#!/bin/sh
#
# Copyright (c) 1999-2005 SWsoft Inc.
# All rights reserved
#

#
# Plesk script
#


set_apache_params()
{
	apache_user="apache"
	apache_UID=80
	apache_group="apache"
	apache_GID=80
	apache_service_name="httpd"
	apache_new="2.0"

	apache_modules_d="/usr/local/psa/apache/libexec/"
	user_apxs="/usr/local/psa/apache/bin/apxs"

	apache_httpd_conf="$HTTPD_CONF_D/httpd.conf"
	apache_httpd_conf2="$HTTPD_CONF_D/httpd2.conf"
	apache_httpd_conf_in="$PRODUCT_ROOT_D/etc/httpd.conf.in"

	apache_httpd_include="$HTTPD_INCLUDE_D/zz010_psa_httpd.conf"

	APACHE_CERT="$HTTPD_CONF_D/httpd.pem"

	apache_pid_file="$APACHE_ROOT/logs/httpd.pid"
	apache_lock_file="$APACHE_ROOT/logs/httpd.lock"
	product_lock_file="$HTTPD_CONF_D/cnf.lock"

	min_suexec_UID=10000
	max_suexec_UID=16000
	min_suexec_GID=$min_suexec_UID
	max_suexec_GID=$max_suexec_UID

	suexec_storage=/usr/local/psa/apache/bin
	suexec=/usr/local/psa/apache/bin/suexec
	suexec_dir=/usr/local/psa/apache/bin
	suexec_file=suexec

	rpm_httpd_bin=/usr/sbin/httpd
}

remove_tmp_state()
{
	if [ -d "/tmp/.state" ]; then
		rm -Rf "/tmp/.state" >> $product_log 2>&1
	fi
}

#admin

set_admin_params()
{

	ADMIN_ROOT=$PRODUCT_ROOT_D/admin

	UTILS_DIR=$ADMIN_ROOT/bin

	admin_user="${product}adm"
	admin_UID=8444
	admin_group="${product}adm"
	admin_GID=8444

	admin_httpsd_conf="$ADMIN_ROOT/conf/httpsd.conf"
	ADMIN_CERT="$ADMIN_ROOT/conf/httpsd.pem"

	admin_pid_file=$ADMIN_ROOT/logs/httpsd.pid
	admin_lock_file=$ADMIN_ROOT/logs/httpsd.lock
}

lock_keyupdate()
{
	export PLESK_KEYUPDATE_DISABLED=installation
}

get_admin_passwd()
{
	if [ -f "$mysql_passwd_file" ]; then
		admin_passwd=`cat "$mysql_passwd_file"`
	fi

	if [ -z "$admin_passwd" ]; then
		admin_passwd="$default_mysql_passwd"
	fi

}

#courier-imap

set_courier_imap_params()
{
	COURIER_IMAP_ROOT_D="$PRODUCT_ROOT_D/courier-imap"
	courier_imap_start="$PRODUCT_RC_D/courier-imap start"
	courier_imap_stop="$PRODUCT_RC_D/courier-imap stop"

	IMAPD_CERT="$COURIER_IMAP_ROOT_D/share/imapd.pem"
	POP3D_CERT="$COURIER_IMAP_ROOT_D/share/pop3d.pem"

	IMAPD_CONF="$COURIER_IMAP_ROOT_D/etc/imapd"
	POP3D_CONF="$COURIER_IMAP_ROOT_D/etc/pop3d"

	MAILPASSWD="$QMAIL_ROOT_D/users/poppasswd"
}

# db_test test_query awk_script
# Runs test_query and processes it with awk_script. If the output is
# not empty, return 0, otherwise return 1. Hint: supply '1' for
# awk_script to test just for the presence of any output.
db_test()
{
	local any_db=
	eval `sh_get_args '--any-db) any_db=yes;;'`

	local test_query="$1"
	local awk_script="$2"

	if [ -n "$any_db" ]; then
		local output="`mysql_raw_anydb -e \"$test_query\" 2>>\"$product_log\"`"
	else
		local output="`mysql_raw -e \"$test_query\" 2>>\"$product_log\"`"
	fi
	local status=$?
	if [ "$status" -ne 0 ]; then
		p_echo "$output"
		die "run the following SQL query: $1"
	fi

	echo -n "$output" | awk -F '\t' -- "$awk_script" | test `wc -l` -ne 0
}

#proftpd

set_ftpd_params()
{

	anonftp_user="${product}ftp"
	anonftp_group="${product}ftp"

	PROFTPD_ROOT="$PRODUCT_ROOT_D/ftpd"
}

set_jdk_params()
{
	jdk_distrib="$PRODUCT_ROOT_D/j2sdk.bin"
}

set_tomcat_params()
{
    set_common_params
 
    tomcat_distrib="$PRODUCT_ROOT_D/jakarta-tomcat.tar"
    prod_conf_t="/etc/psa/psa.conf"
    tomcat_version="4"
    CATALINA_HOME="/usr/local/psa/tomcat4"
    tomcat_user="tomcat4"
    tomcat_group="tomcat4"

    #basename directory. May be different. 
    dist_name="tomcat4"
 
    tomcat_conf="$CATALINA_HOME/conf/$dist_name.conf"
}


init_log()
{
echo >> $product_log	# initializing new output to log
echo "START LOGGING: `date`" >> $product_log
echo "SCRIPT: $0" >> $product_log
chmod 600 "$product_log"

echo >> $product_problems_log	# initializing new output to problems log
echo "START LOGGING: `date`" >> $product_problems_log
echo "SCRIPT: $0" >> $product_problems_log
chmod 600 "$product_problems_log"

problems_occured=0
}

p_echo()
{
echo "$*" >> "$product_log" 2>&1
echo "$*"
}

pnnl_echo()
{
if [ -z $necho_defined ]; then
	# set up echo
	case "`echo 'x\c'`" in
    	'x\c')
			echo="echo"
			echo_keys=" -n"
			nnl=
		;;
		x)
			echo="echo"
			echo_keys=
			nnl="\c"
		;;
		*)
			echo "ERROR: unable to set up echo."
		;;
	esac
	necho_defined=true
fi

${echo} ${echo_keys} "$*${nnl}" >> "$product_log" 2>&1
${echo} ${echo_keys} "$*${nnl}"
}

keyupdate_failure_report()
{
	if test -z "$KEYUPDATE_FAILURE_INFO"; then
		return
	fi

	p_echo
	p_echo " *****************************************************************************"
	p_echo " *                                                                           *"
	p_echo " *  ERROR:      The $PRODUCT_NAME license failed to upgrade. The failure     *"
	p_echo " *              follows:                                                     *"
	p_echo
	p_echo "$KEYUPDATE_FAILURE_INFO"
	p_echo
	p_echo " *              If you did not request the automatic key upgrade,            *"
	p_echo " *              please contact SWsoft, Inc sales department for assistance:  *"
	p_echo " *              ${sales_email}. If you want to proceed with upgrade without *"
	p_echo " *              the license upgrade, please create an empty file             *"
	p_echo " *				$prodkey                                             *"
	p_echo " *                                                                           *"
	p_echo " *****************************************************************************"
	p_echo
}

die()
{
	if [ "X$trigger_uninstall" != "X1" ]; then
		printf "\a\a"
		p_echo
		p_echo "ERROR while trying to $*"
		echo "Check the error reason(see log file: ${product_log}), fix and try again"
		p_echo
		if [ "X$do_patch" != "X1" -a "X$do_reconfigure" != "X1" ]; then
			p_echo "Aborting..."
			p_echo
		fi
	fi

	smart_undo_install

	keyupdate_failure_report

	selinux_close

	exit 1

}

err()
{

	if [ "X$trigger_uninstall" != "X1" ]; then
		p_echo
		p_echo "ERROR!"
		p_echo "Check the error reason(see log file: ${product_log}), fix and try again"
		p_echo
		if [ "X$do_patch" != "X1" -a "X$do_reconfigure" != "X1" ]; then
			p_echo "Exiting..."
			p_echo
		fi
	fi

	smart_undo_install

	exit 1
}

# This function needs for some print warning when some services cannot restart
# if called with arg, then we add arg to variable SR_WARNING and print warning
# message for arg, else print warning message for SR_WARNING
service_restart_warning()
{
	if [ "X$1" != "X" ]; then
		if [ "X${SR_WARNING}" = "X" ]; then
			SR_WARNING=$1
		else
			for i in ${SR_WARNING}; do
				if [ "$i" = "$1" ]; then
					break
				fi
			done
			if [ "$1" != "$i" ]; then
				SR_WARNING=$SR_WARNING" "$1
			fi
		fi
		p_echo "WARNING!"
		p_echo "Some problems occured when $1 restart, check it after installation/upgrade complete"
	        p_echo
	 	p_echo "Continue..."
		p_echo
	else
		if [ "X${SR_WARNING}" != "X" ]; then
			p_echo "WARNING!"
		        p_echo "Some problems occured when following services restart:"
			for i in ${SR_WARNING}; do
				p_echo $i
			done
			p_echo "Don't forget to check it after installation/upgrade complete"
        		p_echo
	       	        p_echo "More information can be found in log file: ${product_log}"
			p_echo
		fi
	fi
}

warn()
{
local inten
inten="$1"
p_echo
p_echo "WARNING!"
pnnl_echo "During the $inten found some problems"
echo "(see log file: ${product_log})"
p_echo
p_echo "Continue..."
p_echo

}

echo_try()
{
	msg="$*"
	pnnl_echo " Trying to $msg... "
}

suc()
{
	p_echo "done"
}

mk_backup()
{
	target="$1"
	dup="$2"
	opts="$3"

	if [ -L "$target" ]; then
		rm "$target"
	elif [ -$opts "$target" ]; then
		if [ ! -$opts "$target.$product_suffo" ]; then
			case "$dup" in
				mv)
					mv -f $target $target.$product_suffo || die "mv -f $target $target.$product_suff"
					;;
				cp)
					cp -fp $target $target.$product_suffo || die "cp -fp $target $target.$product_suff"
					;;
				*)
					p_echo " mk_backup: wrong option -- must be 'cp' or 'mv'"
					die "mk_backup"
					;;
			esac
		else
			case "$dup" in
				mv)
					mv -f $target $target.$product_suff || die "mv -f $target $target.$product_suff"
					;;
				cp)
					cp -fp $target $target.$product_suff || die "cp -fp $target $target.$product_suff"
					;;
				*)
					p_echo " mk_backup: wrong option -- must be 'cp' or 'mv'"
					die "mk_backup"
					;;
			esac
		fi
	else
		case "$opts" in
			f|d)
				;;
			*)
				p_echo " mk_backup: wrong option -- must be 'f' or 'd'"
				die "mk_backup"
				;;
		esac
	fi
}

# accumulates chown and chmod
set_ac()
{
	u_owner="$1"
	g_owner="$2"
	perms="$3"
	node="$4"

	chown $u_owner:$g_owner $node || die "chown $u_owner:$g_owner $node"
	chmod $perms $node || die "chmod $perms $node"
}

detect_vz()         
{                   
    local vzcheck_file
        
    PLESK_VZ=0
    vzcheck_file="/proc/self/status"
                    
    if [ ! -f ${vzcheck_file} ]; then
        return 1; 
    fi              
                    
    grep -q -E '^envID\:[[:space:]]*([[:digit:]]+)$' < ${vzcheck_file} >/dev/null 2>&1
                    
    if [ $? -eq 0 ]; then
        PLESK_VZ=1  
        return 0;
    fi      
    return 1;
}       

call_optional_function()
{
	local type_output="`type \"$1\" 2>/dev/null | head -n 1`"
	case "$type_output" in
		*function)
			"$@"
			;;
		*)
			return 0
			;;
	esac
}

sh_get_args()
{
	echo 'while true; do case "$1" in '"$1"'*) break;; esac; shift; done'
}

# Super server internet library

super_server_type()
{
	case "$super_server" in

		'xinetd' | 'inetd')
			;;
		*)
			# check what super-server installed
			inten="define super-server internet daemon type"
			echo_try "$inten"
			
			local xinetd_pid=`get_pids_byname "xinetd"`
			local inetd_pid=`get_pids_byname "inetd"`
			
			
			if [ -z "$xinetd_pid" ]; then
				if [ -z "$inetd_pid" ]; then
					if [ -f "$xinetd_conf" ]; then
						super_server="xinetd"
						xinetd_dir=`cat /etc/xinetd.conf |grep includedir| awk '{print $2; exit}' -`
					elif [ -f "$inetd_conf" ]; then
						super_server="inetd"
					else
						die "$inten"
					fi
				else
					super_server="inetd"
				fi
			else 
				super_server="xinetd"
				xinetd_dir=`cat /etc/xinetd.conf |grep includedir| awk '{print $2; exit}' -`
			fi				 
				
			p_echo "$super_server"
			;;
	esac
}

restart_super_server()
{
	if [ -n "$CHROOTISH" ]; then
			return 0
	fi

	# if PLESK_INSTALLER_DEBUG = daemons then print process table and network status.
	# Usefull for research bugs like 63469, 51592 and other with listen/restart services.
	if [ "X$PLESK_INSTALLER_DEBUG" = "Xdaemon" ] ; then
		ps axl
		netstal -pl
	fi

	super_server_type

	case "$super_server" in

		'xinetd')

		    inten="restart xinetd daemon"
		    echo_try "$inten"
		    case "$machine" in

 		        linux)
				$PRODUCT_RC_D/xinetd reload >> $product_log 2>&1
			    ;;
	 
		        *)
	            	    # not Linux
			    xinetd_pid=`$ps | grep xinetd | egrep "\?" | grep -v grep | head -1 | awk '{print $1}' -`
				if [ "X${xinetd_pid}" = "X" ]; then
					service_restart_warning "xinetd"
				else
				    $K_USR2 $xinetd_pid >> $product_log 2>&1 && suc || die "$inten"
				fi
	            	    ;;
								 
	            esac

		;;

		'inetd')

			inetd_pid=`$ps | grep inetd | egrep "\?" | grep -v grep | head -1 | awk '{print $1}' -`
			inten="restart inetd daemon"
			echo_try "$inten"

			if [ "X${inetd_pid}" = "X" ]; then
				 service_restart_warning "inetd"
			else
				$K_HUP $inetd_pid >> $product_log 2>&1 && suc || die "$inten"
			fi
		;;
	esac
}

comment_service_xinetd()
{
	#comment service records
	local dir file service grep_res
	service=$1

	inten="comment out record for service $service"
	echo_try "$inten"

	for dir in $xinetd_dir; do

		for file in $dir/*; do

			grep_res=`grep "$service" $file`
			case "$?" in
				0)
					awk "/^[[:space:]]*service[[:space:]]+$service($|[[:space:]]+)/,/.*}.*/ \
						{ print \"#\"\$0; next; }
						{print}
						" <$file >$file.tmp  &&
					mv -f $file.tmp $file || die "$inten" >> $product_log 2>&1
					restart_super_server
					;;
				*)
					;;
			esac

		done;

	done;

	suc

}

comment_service_inetd()
{
	local grep_res
	service=$1

	inten="comment out record for service $service"
	echo_try "$inten"

	grep_res=`grep "^$service[[:space:]]" $inetd_conf`

	case "$?" in
	
		0)
			sed -e "s|^$service|##commented_by_psa $service|g" < "$inetd_conf" > "$inetd_conf.${product}_tmp" \
			&& mv -f "$inetd_conf.${product}_tmp" "$inetd_conf" \
			&& suc || die >> $product_log 2>&1
			restart_super_server
			;;
		*)
			p_echo " no record for service $service found in the $inetd_conf"
			;;
	esac
}

comment_service()
{
	local service
	service=$1
	
	super_server_type

	case "$super_server" in

		'xinetd')
			comment_service_xinetd "$service"
			;;

		'inetd')
			comment_service_inetd "$service"
			;;

		*)
			die "Super server type is undefined"
			;;
	esac

}


remove_xinetd()
{
	local service file
	service=$1;
	
	rm -f $xinetd_dir/${service}_${product}
	
	#uncomment old records
	inten="comment out ${product} record for service $service"

	for file in $xinetd_dir/*; do
		awk "/^[[:space:]]*#[[:space:]]*service[[:space:]]+$service($|[[:space:]]+)/,/.*}.*/ \
			{ print substr(\$0,2); next; }
			{print}
			" <$file >$file.tmp &&
		mv -f $file.tmp $file >> $product_log 2>&1
	done;

	restart_super_server

}

remove_inetd()
{
	local service
	service=$1;

	case "$service" in

		ftp)
			inten="restore ftp service record in the $inetd_conf"

			sed -e "s|^ftp.*/${product}/ftpd/sbin/proftpd.*||g" \
				-e "s|ftp.*/${prev_product}/ftpd/sbin/proftpd.*||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
		    ;;

		smtp)
			inten="restore smtp service record in the $inetd_conf"

			sed -e "s|^smtp.*$QMAIL_ROOT_D/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				-e "s|^smtp.*${product}/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				-e "s|smtp.*${prev_product}/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
		    ;;

		smtps)
			inten="restore smtp service record in the $inetd_conf"

			sed -e "s|^smtps.*$QMAIL_ROOT_D/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				-e "s|^smtps.*${product}/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				-e "s|smtps.*${prev_product}/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
		    ;;

		pop3)
			inten="restore pop3 service record in the $inetd_conf"

			sed -e "s|^pop[-]*3.*/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/pop3$||g" \
				-e "s|^pop[-]*3.*/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/pop3$||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
			
		    ;;
		poppassd)
			# poppassd stream tcp nowait root /usr/sbin/tcpd /${PRODUCT_ROOT_D}/admin/bin/poppassd
			inten="restore poppassd service record in the $inetd_conf"

			sed -e "s|^poppassd.*$PRODUCT_ROOT_D/admin/bin/poppassd.*||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
			;;
		
	esac

	# uncomment old records
	sed -e "s|^##commented_by_psa $service|$service|g" < $inetd_conf > $inetd_conf.${product}_tmp \
	&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1

	restart_super_server

}

remove_super_server()
{
	local service
	service=$1;

	super_server_type

	case "$super_server" in

		xinetd)
			remove_xinetd "$service"
			;;
		inetd)
			remove_inetd "$service"
			;;
	esac
}

setup_xinetd()
{
	local service file rbl_on rbl_server
	service=$1;
	rbl_on=$2;
	rbl_server=$3;
	
	#comment old records
	comment_service "$service"	
	
	#setup
	service=$1;
	inten="set up record for service $service"
	echo_try "$inten"

	case "$service" in

		ftp)
			echo "
service ftp
{
	socket_type		= stream
	protocol		= tcp
	wait			= no
	disable			= no
	user			= root
	instances		= UNLIMITED
	server			= $PRODUCT_ROOT_D/ftpd/sbin/proftpd
	server_args		= -c $PRODUCT_ROOT_D/ftpd/etc/proftpd.conf
}" > "$xinetd_dir/ftp_${product}" || die "$inten"
			;;

		smtp)

			case "$rbl_on" in

				on)				
					echo "
service smtp
{
	socket_type     = stream
	protocol        = tcp
	wait            = no
	disable		= no
	user            = root
	instances       = UNLIMITED
	server          = $QMAIL_ROOT_D/bin/tcp-env
	server_args     = $RBLSMTPD $rbl_server $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $TRUE_BIN $QMAIL_ROOT_D/bin/cmd5checkpw $TRUE_BIN
}" > "$xinetd_dir/smtp_${product}" || die "$inten"
					;;

				*)
					echo "
service smtp
{
	socket_type     = stream
	protocol        = tcp
	wait            = no
	disable		= no
	user            = root
	instances       = UNLIMITED
	server          = $QMAIL_ROOT_D/bin/tcp-env
	server_args     = $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $TRUE_BIN $QMAIL_ROOT_D/bin/cmd5checkpw $TRUE_BIN
}" > "$xinetd_dir/smtp_${product}" || die "$inten"
					;;
			esac	
			;;

		smtps)
			case "$rbl_on" in
				on)				
					echo "
service smtps
{
	socket_type     = stream
	protocol        = tcp
	wait            = no
	disable		= no
	user            = root
	instances       = UNLIMITED
	server          = $QMAIL_ROOT_D/bin/tcp-env
	server_args     = $RBLSMTPD $rbl_server $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $TRUE_BIN $QMAIL_ROOT_D/bin/cmd5checkpw $TRUE_BIN
}" > "$xinetd_dir/smtps_${product}" || die "$inten"
					;;
				*)
					echo "
service smtps
{
	socket_type     = stream
	protocol        = tcp
	wait            = no
	disable		= no
	user            = root
	instances       = UNLIMITED
	server          = $QMAIL_ROOT_D/bin/tcp-env
	server_args     = $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $TRUE_BIN $QMAIL_ROOT_D/bin/cmd5checkpw $TRUE_BIN
}" > "$xinetd_dir/smtps_${product}" || die "$inten"
					;;
			esac	
			;;

		poppassd)
			echo "
service poppassd
{
	socket_type		= stream
	protocol		= tcp
	port			= 106
	wait			= no
	disable			= no
	user			= root
	instances		= 1000
	flags			= KEEPALIVE
	server			= $PRODUCT_ROOT_D/admin/bin/poppassd
}" > "$xinetd_dir/poppassd_${product}" || die "$inten"
			;;
	esac

    case "$machine" in
       Darwin)
echo '#!/bin/sh

name_service='org.xinetd.xinetd'
    
    case "$1" in
        start)
           echo "Plesk: Starting xinetd"
           launchctl start "$name_service"
        ;;
        stop)
           echo "Plesk: Stopping xinetd"
           launchctl stop "$name_service"
        ;;
        restart)
           start
           stop
        ;;
        *)
           echo "Usage: xinetd [start|stop|restart]"
        ;;
    esac 
' > "$PRODUCT_RC_D/xinetd"

     chmod 755 "$PRODUCT_RC_D/xinetd"
       ;;
       *)
       ;;
    esac

	suc
}

setup_inetd()
{
	local service rbl_on rbl_server

	service=$1;
	rbl_on=$2;
	rbl_server=$3;
	
	local ftp_rec smtp_rec pop3_rec 

	ftp_rec="ftp stream tcp nowait root $PRODUCT_ROOT_D/ftpd/sbin/proftpd proftpd -c $PRODUCT_ROOT_D/ftpd/etc/proftpd.conf"
	
	case "$linux_distr" in
		debian)
			maxconn='.1000'
		;;
		*)
		        maxconn=""
		;;
	esac

	case "$rbl_on" in
		on)
			smtp_rec="smtp stream tcp nowait$maxconn root $QMAIL_ROOT_D/bin/tcp-env tcp-env  $RBLSMTPD $rbl_server $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $QMAIL_ROOT_D/bin/true $QMAIL_ROOT_D/bin/cmd5checkpw $QMAIL_ROOT_D/bin/true"
			smtps_rec="smtps stream tcp nowait$maxconn root $QMAIL_ROOT_D/bin/tcp-env tcp-env  $RBLSMTPD $rbl_server $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $QMAIL_ROOT_D/bin/true $QMAIL_ROOT_D/bin/cmd5checkpw $QMAIL_ROOT_D/bin/true"
			;;
		*)
			smtp_rec="smtp stream tcp nowait$maxconn root $QMAIL_ROOT_D/bin/tcp-env tcp-env  $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $QMAIL_ROOT_D/bin/true $QMAIL_ROOT_D/bin/cmd5checkpw $QMAIL_ROOT_D/bin/true"
			smtps_rec="smtps stream tcp nowait$maxconn root $QMAIL_ROOT_D/bin/tcp-env tcp-env  $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $QMAIL_ROOT_D/bin/true $QMAIL_ROOT_D/bin/cmd5checkpw $QMAIL_ROOT_D/bin/true"
			;;
	esac

	case "$machine" in
		BSD*)
			poppassd_rec="poppassd stream tcp nowait/1000 root /usr/libexec/tcpd $PRODUCT_ROOT_D/admin/bin/poppassd"
			;;
		*)
			poppassd_rec="poppassd stream tcp nowait/1000 root /usr/sbin/tcpd $PRODUCT_ROOT_D/admin/bin/poppassd"
			;;
	esac

	case "$service" in

		ftp)
			if [ -x /usr/sbin/update-inetd ]; then

				# Use Debian inetd config manipulation facility
				/usr/sbin/update-inetd --remove "ftp"
				/usr/sbin/update-inetd --add "$ftp_rec"

			else
				grep_res=`egrep "^ftp.*/${product}/ftpd/sbin/proftpd*." $inetd_conf`
				inten="add ftp service (proftpd) record into the $inetd_conf file"
				echo_try $inten

				case "$grep_res" in
					ftp*)
						p_echo
						p_echo " ftp service (proftpd) is already in the $inetd_conf"
						;;
					*)
						comment_service $service
						echo "$ftp_rec" >> $inetd_conf && suc || die
						;;
				esac
			fi
			;;

		smtp)
			if [ -x /usr/sbin/update-inetd ]; then

				# Use Debian inetd config manipulation facility
				/usr/sbin/update-inetd --remove "smtp"
				/usr/sbin/update-inetd --add "$smtp_rec"

			else
				egrep "^smtp.*$QMAIL_ROOT_D/bin/tcp-env.*tcp-env.*$QMAIL_ROOT_D/bin/relaylock.*$" "$inetd_conf" >> $product_log 2>&1
				case "$?" in
					0)
						sed -e "/^smtp/d" < "$inetd_conf" > "$inetd_conf.${product}_tmp" \
						&& mv -f "$inetd_conf.${product}_tmp" "$inetd_conf" || die >> $product_log 2>&1
						;;
					1)
						comment_service $service
						;;
					*)
						err
						;;
				esac

				inten="add smtp service record into the $inetd_conf file"
				echo_try $inten
				echo "$smtp_rec"  >> $inetd_conf  && suc || die $inten
			fi
			;;

		smtps)

			if [ -x /usr/sbin/update-inetd ]; then

				# Use Debian inetd config manipulation facility
				/usr/sbin/update-inetd --remove "smtps"
				/usr/sbin/update-inetd --add "$smtps_rec"

			else

				egrep "^smtps.*$QMAIL_ROOT_D/bin/tcp-env.*tcp-env.*$QMAIL_ROOT_D/bin/relaylock.*$" "$inetd_conf" >> $product_log 2>&1
				case "$?" in
					0)
						sed -e "/^smtps/d" < "$inetd_conf" > "$inetd_conf.${product}_tmp" \
						&& mv -f "$inetd_conf.${product}_tmp" "$inetd_conf" || die >> $product_log 2>&1
						;;
					1)
						comment_service $service
						;;
					*)
						err
						;;
				esac

				inten="add smtps service record into the $inetd_conf file"
				echo_try $inten
				echo "$smtps_rec"  >> $inetd_conf  && suc || die $inten
			fi
			;;

		poppassd)

			if [ -x /usr/sbin/update-inetd ]; then

				# Use Debian inetd config manipulation facility
				/usr/sbin/update-inetd --remove "poppassd"
				/usr/sbin/update-inetd --add "$poppassd_rec"
			else
				#	^poppassd.*$PRODUCT_ROOT_D/admin/bin/poppassd.*
				grep_res=`egrep "^poppassd.*$PRODUCT_ROOT_D/admin/bin/poppassd.*" $inetd_conf`
				inten="add poppassd service record in the $inetd_conf"
				echo_try $inten
		
				case "$grep_res" in
					poppassd*)
						p_echo
						p_echo " poppassd service is already in the $inetd_conf"
						;;
					*)
						comment_service $service
						echo "$poppassd_rec" >> $inetd_conf && suc || die
						;;
				esac
			fi
			;;
	esac

}

setup_super_server()
{
	local service rbl_on rbl_server
	service=$1;
	rbl_on=$2;
	rbl_server=$3;

	super_server_type

	case "$super_server" in

		xinetd)
			setup_xinetd "$service" "$rbl_on" "$rbl_server"
			;;
		inetd)
			setup_inetd "$service" "$rbl_on" "$rbl_server"
			;;
	esac

	restart_super_server
}

get_pid()
{
	local i

	ex_f="$1"
	opt="$2"
	owner="$3"

	min_num=`expr 1`

	case "$opt" in
		false)
			for i in `$ps_long | grep $ex_f | grep -v grep | grep -v httpsdctl | grep -v apachectl | awk '{print $2}' -`; do
				min_num=$i
				break
			done
			;;
		true)
			for i in `$ps_long | grep $ex_f | grep -v grep | grep -v httpsdctl | grep -v apachectl | grep "$owner" | awk '{print $2}' -`; do
				min_num=$i
				break
			done
			;;
		*)
			p_echo "get_pid: wrong parameter"
			die "get_pid $ex_f $opt $owner"
			;;
	esac

	common_var=$min_num
	return $min_num
}

kill_pids()
{
	ex_f="$1"
	owner="$2"

	for i in `$ps_long | grep $ex_f | grep -v grep | grep -v httpsdctl | grep -v apachectl | grep $owner | awk '{print $2}' -`; do
		if [ $i -gt 1 ]; then
			$K_TERM $i >> $product_log 2>&1
		fi
	done
}

get_pids_byname()
{
	proc_name="$1"
	PIDS=`ps axww | awk '$5 ~ "'$proc_name'$" {print $1}'`
	echo $PIDS
}

#lib_test

test_for_root()
{
	my_id="`id`"
	case "$my_id" in
		uid=0\(root\)*)
			;;
		*)	echo "$0: This script must be run as root"
			echo "Log in as root then run this script again."
			echo
			exit 1
			;;
	esac
}
get_userID()
{
# try to get UID
	common_var=`id -u "$1" 2>/dev/null` 

# if id returns 0 the all is ok
	if [ "$?" -eq "0" -a ! -z "$common_var" ]; then
		return 1;
	fi

	return 0;
}

get_groupID()
{
# try to get GID, id -g doesn't show groups without users
    case "$machine" in
       Darwin)
         common_var=`nireport / /groups name gid| grep "$1"| awk '{print $2}'`
       ;;
	   *)
         common_var=`cat /etc/group | awk -F':' '$1 == "'$1'" {print $3}'` 
       ;;
    esac

# We have non-empty value if success
	if [ ! -z "$common_var" ]; then
		return 1;
	fi

	return 0;
}

delete_user()
{
	local rm_user

	rm_user="$1"

	# if it is mailman user, remove its crontab from system
	if [ "X${rm_user}" = "X${mailman_user}" ]; then

		inten="remove crontab of ${rm_user}"
		echo "y" | $crontab -u "${mailman_user}" -r >> $product_log 2>&1 || die "$inten"

	fi

	inten="remove user $rm_user"
	echo_try "$inten"

	case "$machine" in
		BSD)
			echo "y" | pw userdel $rm_user>> $product_log 2>&1 && suc || die "$inten"
			pwd_mkdb /etc/master.passwd >> $product_log 2>&1
		;;
		BSDI)
			rmuser $rm_user>> $product_log 2>&1 && suc || die "$inten"
			pwd_mkdb /etc/master.passwd >> $product_log 2>&1

		;;
		linux|solaris)
			userdel  $rm_user>> $product_log 2>&1 && suc || die "$inten"
		;;
		Darwin)
			niutil -destroy / /users/"$rm_user" >> $product_log 2>&1 && suc || die "$inten"
		;;
	esac
}

delete_group()
{
	local rm_group

	rm_group="$1"

	inten="remove group $rm_group"
	echo_try "$inten"

	case "$machine" in
		BSD)
			pw groupdel $rm_group>> $product_log 2>&1
			pwd_mkdb /etc/master.passwd >> $product_log 2>&1
		;;
		BSDI)
			rmgroup $rm_group>> $product_log 2>&1
			pwd_mkdb /etc/master.passwd >> $product_log 2>&1
		;;
		linux|solaris)
			mk_backup "/etc/group" cp f
			if [ -f "/etc/group" ]; then
				sed -e "/$rm_group/d" < /etc/group > /etc/group.tmp || die $inten
				mv -f /etc/group.tmp /etc/group  >> $product_log 2>&1
				if [ "$?" -ne 0 ]; then
					rsr_backup "/etc/group" cp f
					die $inten
				fi
			fi
#		groupdel  $rm_group>> $product_log 2>&1
		;;
		Darwin)
			niutil -destroy / /groups/"$rm_group" >> $product_log 2>&1 && suc || die "$inten"
		;;
	esac
	suc
}
initial_conf()
{
	DEMO_VERSION="no"
	PRODNAME="psa"
	PRODUCT_NAME="Plesk"
	product_full="Plesk"
	PRODUCT_FULL_NAME="Plesk"

	product_etc="/etc/${PRODNAME}"
	prod_conf_t="/etc/psa/psa.conf"
	prodkey="$product_etc/$PRODNAME.key"

	minimal_changes=""

	MYSQL_VERS="4.1.18"
	POSTGRESQL_VERS="7.4.11"
	EXTERNAL_PACKAGES=""
	EXTERNAL_PACKAGES_DIR=""

	BUILDER_UID="10007"

	PERL5LIB="/usr/local/psa/Library/Perl/5.8.6:/usr/local/psa/Library/Perl/5.8.6/darwin-thread-multi-2level"
	export PERL5LIB

	product_bs=Plesk
        support_contact="http://www.swsoft.com/support"
	sales_email="sales@swsoft.com"

	product_version="8.0.1"
	product_db_version="0801"
	product_build="80061018.20"
	conceived_os_vendor=MacOS
	conceived_os_version="10.4w"
	osrels="mac10.4w"

	# This variable contains all versions, which is supported by
	# cumulative upgrade
	known_product_versions=""

	prev_product="plesk"
	prev_clients_group="${prev_product}cln"

	# GID for mailman
	mm_mailgroup=110

	# plesk default password
	if [ "X$DEMO_VERSION" = "Xyes" ]; then
		PRODUCT_DEFAULT_PASSWORD="plesk"
	else
		PRODUCT_DEFAULT_PASSWORD="setup"
	fi

	my_name_0="`pwd`"
	if [ $? -ne 0 ]; then
		echo "Unable to determine current working directory."
		echo "Please fix the problem and run installation again."
		exit 1
	fi

	my_name_1="`basename ""$0""`"
	my_name_2=`echo ""$0""|sed -e "s/^\.\///"`
	echo $my_name_2 | egrep '^/' >/dev/null 2>&1
	case "$?" in
		0)
			my_name="$my_name_2"
		;;
		1)
			my_name="$my_name_0"/"$my_name_2"
		;;
	    *)
			echo "Unable to determine the name of installer."
			echo "Please fix the problem and run installation again."
			exit 1
		;;
	esac
}

read_conf()
{
	initial_conf

	if [ -s $prod_conf_t ]; then
		tmp_var=`perl -e 'undef $/; $_=<>; s/#.*$//gm;
				s/^\s*(\S+)\s*/$1=/mg;
				print' $prod_conf_t`
		eval $tmp_var
	else
		[ 0$ignore_miss_conf -ne 1 ] && p_echo "Unable to find product configuration file: $prod_conf_t"
		return 1
#		die "find product configuration file: $prod_conf_t"
	fi
	return 0

}

selinux_close()
{
	if [ -z "$SELINUX_ENFORCE" -o "$SELINUX_ENFORCE" = "Disabled" ]; then
		return
	fi

	setenforce "$SELINUX_ENFORCE"
}


#set_params

set_common_params()
{

	PATH=/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin
	LANG=C
	export PATH LANG
	umask 022
	ulimit -n 65535 2>/dev/null

	K_HUP="/bin/kill -HUP"
	K_KILL="/bin/kill -KILL"
	K_TERM="/bin/kill -TERM"
	K_USR2="/bin/kill -USR2"

	users_created=""
	groups_created=""

	certificate_file="$PRODUCT_ROOT_D/etc/httpsd.pem"
	product=${PRODNAME}
	START_SH="$PRODUCT_RC_D/${product}"

	clients_group="${product}cln"
	clients_GID=10001

	services_group="${product}serv"
	services_GID=10003

	product_suff="saved_by_${product}".`date "+%m.%d;%H:%M"`
	product_suffo="saved_by_${product}"

	common_var=0

	services="/etc/services"
	mtab="/etc/mtab"
	xinetd_conf="/etc/xinetd.conf"
	xinetd_dir="/etc/xinetd.d"
	inetd_conf="/etc/inetd.conf"
	syslog_conf="/etc/syslog.conf"
	syslog_conf_ng="/etc/syslog-ng/syslog-ng.conf"
	get_hostname="hostname"
	get_domainname="domainname"

	#VZP used to determine that we're inside SVE
	vza_file="/var/vzagent"

	PREV_PRODUCT_ROOT_D="/usr/local/${prev_product}"

	#default parameters
	tar="tar"
	crontab="/usr/bin/crontab"

	#machine depended parameters
	TARGET_OS="`uname -a`"
	case "$TARGET_OS" in

		BSD/OS*BSDI*i386)
			machine="BSDI"
			sendmail="/usr/sbin/sendmail"
			mail_local="/usr/libexec/mail.local"
			ps="ps axw"
			ps_long="ps axwu"
			dummy_shell="/sbin/nologin"
			dummy_home="/"
			false_shell="/usr/bin/false"
			compress="compress"
			uncompress="uncompress -c"
			uudecode="uudecode -o /dev/stdout"
			uudecode_full="/usr/bin/uudecode"
			ifconfig="/sbin/ifconfig -a"
			inet_str="inet"
			named_osrelease=0
			fstab="/etc/fstab"
			;;

		FreeBSD*i386)
			fstab="/etc/fstab"
			machine="BSD"
			sendmail="/usr/sbin/sendmail"
			mail_local="/usr/libexec/mail.local"
			ps="ps axw"
			ps_long="ps axfwu"
			dummy_shell="/sbin/nologin"
			dummy_home="/"
			false_shell="/usr/bin/false"
			bash_shell="/usr/local/bin/bash"
			rbash_shell="/usr/local/bin/rbash"
			compress="gzip -9 -c"
			uncompress="gunzip -c"
			uudecode="uudecode -p"
			uudecode_full="/usr/bin/uudecode"
			ifconfig="/sbin/ifconfig -a"
			inet_str="inet"
			os_version=`uname -v | sed -e 's/^.*FreeBSD[ \t][ \t]*\([0-9\.][0-9\.]*\)-.*$/\1/'`

			if tar --version | grep bsdtar > /dev/null ; then
				if which gtar > /dev/null; then
				    tar="gtar"
				else
				    echo "Unable to locate gtar on your system."
				    echo "Please, install the archiving software and retry installation."
				    exit 1
				fi
			fi

			named_osrelease=040100 # "must be >= 020218 for  named -u <named> "
			;;
		Darwin*powerpc)
			machine="Darwin"
			sendmail="/usr/sbin/sendmail"
			mail_local=""
			ps="ps axw"
			ps_long="ps axSwu"
			dummy_shell="/usr/bin/false"
			dummy_home="/"
			false_shell="/usr/bin/false"
			bash_shell="/bin/bash"
			rbash_shell="/bin/rbash"
			compress="gzip -9 -c"
			uncompress="gunzip -c"
			uudecode="uudecode -p"
			uudecode_full="/usr/bin/uudecode"
			ifconfig="/sbin/ifconfig -a"
			inet_str="inet"
			named_osrelease=0
			fstab="/etc/fstab.hd"
			;;

		SunOS*5.*sun4*)
			machine="solaris"
			inetd_conf="/etc/inet/inetd.conf"
			services="/etc/inet/services"
			crontab="/bin/crontab"
			useradd_options=""
			sendmail="/usr/lib/sendmail"
			sndml_ini="/etc/init.d/sendmail"
			mail_local="/usr/lib/mail.local"
			ps="ps -e"
			ps_long="ps -aef"
			dummy_shell="/bin/false"
			dummy_home="/"
			false_shell="/bin/false"
			compress="compress"
			uncompress="uncompress"
			uudecode="uudecode -p"
			uudecode_full="/bin/uudecode"
			tar="gtar"
			ifconfig="/usr/sbin/ifconfig -a"
			inet_str="inet"
			named_osrelease=0
			fstab="/etc/fstab"
			;;

		Linux*2.?.*i?86*| \
		Linux*2.?.*x86_64*)
			get_hostname="hostname -f"
			fstab="/etc/fstab"
			if [ -f /etc/slackware-version ]; then
			    machine="linux"
			    linux_distr="slackware"
			    useradd_options=""
			    sendmail="/usr/sbin/sendmail"
			    sndml_ini="/etc/rc.d/init.d/sendmail"
			    mail_local="/usr/libexec/mail.local"
			    ps="ps axw"
			    ps_long="ps axuw"
			    dummy_shell=""
			    dummy_home="/"
			    false_shell="/bin/false"
			    compress="gzip -9 -c"
			    uncompress="gunzip -c"
			    uudecode="uudecode -o /dev/stdout"
			    ifconfig="/sbin/ifconfig -a"
			    inet_str="inet addr"
			    named_osrelease=0
			else
			    machine="linux"
				useradd_options="-M"
				if [ -f /etc/mandrake-release ]; then
			    	linux_distr="mandrake"
				elif [ -f /etc/fedora-release ]; then
			    	linux_distr="fedora"
				elif [ -f /etc/SuSE-release ]; then
			    	linux_distr="suse"
				elif [ -f /etc/debian_version ]; then
			    	linux_distr="debian"
					get_domainname="dnsdomainname"
					useradd_options=""
				else
			    	linux_distr="redhat"
				fi
			    sendmail="/usr/sbin/sendmail"
			    sndml_ini="/etc/init.d/sendmail"
			    mail_local="/usr/libexec/mail.local"
			    ps="ps axw"
			    ps_long="ps axuw"
			    dummy_shell="/bin/false"
			    dummy_home="/"
			    false_shell="/bin/false"
				bash_shell="/bin/bash"
				rbash_shell="/bin/rbash"
			    compress="gzip -9 -c"
			    uncompress="gunzip -c"
			    uudecode="uudecode -o /dev/stdout"
			    uudecode_full="/usr/bin/uudecode"
			    ifconfig="/sbin/ifconfig -a"
			    inet_str="inet addr"
			    named_osrelease=`cat /proc/sys/kernel/osrelease | perl -F"/[.-]/" -n -a  -e 'printf "%02u%02u%02u\n", $F[0],$F[1],$F[2]'`
			fi
			;;
		*)
			echo
			echo "Sorry, but your configuration isn't supported yet"
			echo "uname is $TARGET_OS"
			echo
			echo "For more information, please contact $support_email"
			echo
			;;
	esac

	# setup process
	if [ "X$process" = "X" ]; then
		if   [ "X$do_reconfigure" = "X1" ]; then
	    	process="reconfiguration"
		elif  [ "X$do_upgrade" = "X1" ]; then
	    	process="upgrade"
		else
		    process="installing"
		fi
	fi

#	common_var="real"
#	if [ -f $PRODUCT_ROOT_D/version -a "X$do_patch" = "X" ]; then
#	    common_var=`cat $PRODUCT_ROOT_D/version | tr '[:blank:]' '_'`
	product_log="/tmp/${product}_${product_version}_${conceived_os_vendor}_${conceived_os_version}_build${product_build}_${process}.log"
	product_problems_log="/tmp/${product}_${product_version}_${conceived_os_vendor}_${conceived_os_version}_build${product_build}_problems.log"
	init_log
#	elif [ "X$my_name_1" != "X" ]; then
#	    product_log="/tmp/${my_name_1}.log"
#	else
#	    product_log="/tmp/${product}_default_${process}.log"
#	fi

	detect_vz
}


set_local_params()
{
	set_common_params

	for i in set_apache_params set_admin_params lock_keyupdate set_courier_imap_params set_ftpd_params set_jdk_params set_tomcat_params set_logrotate_params set_mailman_params set_mysqld_params set_named_params set_openssl_params set_pgsql_params set_qmail_params set_spamassassin_params set_vhosts_params set_webalizer_params set_horde_params ; do
		$i
		local res="$?"
		if [ "0$res" -gt 0 ]; then
			return "$res"
		fi
	done
}
set_logrotate_params()
{
	# primary Plesk logrotate config file
	logrotate_conf="${product_etc}/logrotate.conf"

	# directory for logrotate configs of virtual hosts
	logrotate_include_d="${PRODUCT_ROOT_D}/etc/logrotate.d"
}

#all functions in this file are valid for Standard builds only
set_mailman_params()
{
	mailman_user="mailman"
	mailman_group="mailman"
	mailman_UID=78
	mailman_GID=78
	MAILMAN_ROOT_D="${PRODUCT_ROOT_D}"/mailman
	MAILMAN_VHOST_D="${HTTPD_VHOSTS_D}"/mailman
}

remove_modules()
{
	p_echo
	p_echo "===> Removing modules"

	local moduledir
	for moduledir in $PRODUCT_ROOT_D/var/modules/*; do
		if [ -d "$moduledir" -a -x "$moduledir/uninstall" ]; then
			local module=`basename $moduledist`
			echo_try "uninstall $module module"
			"$moduledir/uninstall" && suc || warn "uninstallation of $module module"
		fi
	done
}

#mysql

set_mysqld_params()
{
	mysql_user="mysql"
	mysql_UID=3306
	mysql_group="mysql"
	mysql_GID=3306

	product_db_sql="$PRODUCT_ROOT_D/etc/${PRODNAME}_db.sql"

	mysql_passwd_file="$product_etc/.${PRODNAME}.shadow"
	default_mysql_passwd="$PRODUCT_DEFAULT_PASSWORD"
	prev_mysql_passwd_file="$PREV_PRODUCT_ROOT_D/admin/conf/admin.conf"

#	admin_passwd=${default_mysql_passwd}
	get_admin_passwd

	set_mysql_client_params
	set_mysql_server_params
}

## @@constructor set_mysqld_params

set_mysql_server_params()
{
	MYSQL_ROOT="$PRODUCT_ROOT_D/mysql"
	mysql_bindir="$MYSQL_BIN_D"
	mysql_service="mysqld"
}

set_mysql_client_params()
{
	mysql_client="$MYSQL_BIN_D/mysql"

	# Override these variables as needed
	mysql_db_name="$PRODNAME"
	mysql_auth="-uadmin -p$admin_passwd"
	mysql_args="-N"
	mysql_args_raw="-B -r"

	# For backward compatibility only, should use mysql() and mysql_raw() instead
	mysql=mysql
	mysql_raw=mysql_raw
}

# Invoke mysql
mysql()
{
	mysql_anydb -D$mysql_db_name "$@"
}

mysql_anydb()
{
	if test -z "$DB_IS_MYSQL41_COMPATIBLE"; then
		mysql41_init
	fi

	if test "$DB_IS_MYSQL41_COMPATIBLE" != "compatible"; then
		mysql41_exec_wrapper $mysql_client $mysql_auth $mysql_args "$@" 2>>"$product_log"
	else
		$mysql_client $mysql_auth $mysql_args "$@" 2>>"$product_log"
	fi

	local status=$?
	if [ $status -gt 0 ]; then
		$mysql_client $mysql_auth $mysql_args -D$mysql_db_name $mysql_args_raw -e "show innodb status" >>"$product_log" 2>&1
	fi
	return $status
}

# the function removes the "character set xxx" and "collate xxx" construction
# from -e * arguments, if there are any.
# otherwise, it removes the same things from standard input
mysql41_exec_wrapper()
{
	perl -e '$has_command = 0;
		$program = $ARGV[0];
		splice (@ARGV, 0, 1);
		sub remove_chasets($)
		{
			$refStr = shift;
			$$refStr =~ s/\b(medium|long|tiny)?text\s+character\s+set\s+binary(\s+collate\s+[\w]+)?\b/ $1blob /ig;
            $$refStr =~ s/\b(medium|long|tiny)?text\s+character\s+set\s+[\w]+\s+collate\s+[\w]+_bin\b/ $1blob /ig;
			$$refStr =~ s/(\bcharacter\s+set\s+binary(\s+collate\s+[\w]+)?\b)/ binary /ig;
			$$refStr =~ s/(\bcharacter\s+set\s+[\w]+\s+collate\s+[\w]+_bin\b)/ binary /ig;
			$$refStr =~ s/(\b(character\s+set|collate)\s+[\w]+\b)//ig;
		}
		foreach $n (0 .. $#ARGV) {
			if ($ARGV[$n] eq "-e") {
				$has_command = 1;
				remove_chasets \($ARGV[$n + 1]);
			}
		}
		if ($has_command) {
			exec $program, @ARGV or die "Cannot exeecute mysql";
		} else {
			open out_command, "|-", $program, @ARGV or die "Cannot start mysql";
			while (<STDIN>) {
				remove_chasets \($_);
				print out_command $_;
			}
			close out_command or die($! ? "Mysql returned an error: $!" : "Mysq exited with non-zero status $?");
		}' -- "$@"
}

# Invoke mysql in raw mode
mysql_raw()
{
	mysql $mysql_args_raw "$@"
}

mysql_raw_anydb()
{
	mysql_anydb $mysql_args_raw "$@"
}

mysql41_init()
{
	# not_installed is the default state
	# we must init it to avoid endless cycle
	DB_IS_MYSQL41_COMPATIBLE=not_installed
	if ! mysql_anydb </dev/null >>"$product_log" 2>&1; then
		return
	fi

	if db_test --any-db "SHOW VARIABLES LIKE 'version'" '$2 !~ /^(3|4\.0)\./'; then
		# if database is not yet initiailized, assume it compatible
		# otherwise, check the flag
		if
			db_test --any-db "SHOW DATABASES" '/^psa$/' \
			&& db_test "SHOW TABLES" '/^misc$/' \
			&& ! db_test "SELECT val FROM misc WHERE param = 'mysql41_compatible'" '/true/'
		then
			DB_IS_MYSQL41_COMPATIBLE='not_compatible'
		else
			DB_IS_MYSQL41_COMPATIBLE='compatible'
		fi
	fi
}

#named

set_named_params()
{
	# set up default values
	bind_UID=53
	bind_GID=53
	bind_user="bind";
	bind_group="bind";

	# get UID of named user, if exists
	get_userID $bind_user
	if [ $? -ne 0 ]; then
	    bind_UID=$common_var;
        fi

	# get GID of named group, if exists
	get_groupID $bind_group
	if [ $? -ne 0 ]; then
	    bind_GID=$common_var;
	fi

	# old named is not able to run in non-root environment
	if [ 0$named_osrelease -lt 020218 ]; then
	    bind_user="root";
	    bind_UID=0;
	fi

	# path to directory of internal named
	NAMED_ROOT_D="${PRODUCT_ROOT_D:?'PRODUCT_ROOT_D is undefined'}/named"

	# path to directory of named pid file
	bind_run="${NAMED_RUN_ROOT_D:?'NAMED_RUN_ROOT_D is undefined'}/var/run/named"
	# Named start/stop script
	NAMED_RC_SCRIPT="/usr/local/psa/rc.d/named"
	
	# path to named config file
	named_conf="/etc/named.conf"
	rndc_conf="/etc/rndc.conf"
	rndc_namedb_conf="/etc/namedb/rndc.conf"
	rndc_bind_conf="/etc/bind/rndc.conf"
}
set_openssl_params()
{
    openssl_psa_sbin=${PRODUCT_ROOT_D}/admin/sbin/openssl;
    openssl_psa_bin=${PRODUCT_ROOT_D}/admin/bin/openssl;
    openssl_std_bin=/usr/bin/openssl;
}
set_pgsql_params()
{
	pgsql_user="postgres"
	pgsql_group="postgres"
	pgsql_UID=5432
	pgsql_GID=5432

	# path to postgresql for Standard builds
	PGSQL_ROOT_D="$PRODUCT_ROOT_D/postgresql"
}

#qmail

set_qmail_params()
{
QMAIL_DIR="/usr/local/psa/qmail"
QMAIL_USERS="alias:300:nofiles:false:alias  qmaild:301:nofiles:false:  qmaill:302:nofiles:false:  qmailp:303:nofiles:false:  qmailq:304:qmail:  qmailr:305:qmail:  qmails:306:qmail:"
QMAIL_GROUPS="qmail:304  nofiles:301"
}
#values of variables in set_spamassassin_params are valid for Standard builds only

set_spamassassin_params()
{
	SPAMASSASSIN_ROOT_D=${PRODUCT_ROOT_D}/spamassassin
}

rsr_backup()
{
	target="$1"
	dup="$2"
	opts="$3"
	common_var=0

#	if [ -$opts "$target" ]; then
		if [ -$opts "$target.$product_suff" ]; then
			case "$dup" in
				mv)
					mv -f  $target.$product_suff $target>> $product_log 2>&1
					common_var=1
					return 1
					;;
				cp)
					cp -fp  $target.$product_suff $target>> $product_log 2>&1
					common_var=1
					return 1
					;;
				*)
					p_echo " rsr_backup: wrong option -- must be 'cp' or 'mv'"
					;;
			esac
		else
			if [ -$opts "$target.$product_suffo" ]; then
			    case "$dup" in
				mv)
					mv -f  $target.$product_suffo $target>> $product_log 2>&1
					common_var=1
					return 1
					;;
				cp)
					cp -fp  $target.$product_suffo $target>> $product_log 2>&1
					common_var=1
					return 1
					;;
				*)
					p_echo " rsr_backup: wrong option -- must be 'cp' or 'mv'"
					;;
			    esac
			fi
		fi
#	else
#		case "$opts" in
#			f|d)
#				;;
#			*)
#				p_echo " rsr_backup: wrong option -- must be 'f' or 'd'"
#				;;
#		esac
#	fi
}

restore_named()
{
	cd "$PRODUCT_ROOT_D" >> $product_log 2>&1
	[ -f /etc/sysconfig/named ] && mv -f "/etc/sysconfig/named" "/etc/sysconfig/named.bak"
	rsr_backup "/etc/sysconfig/named" mv f

	[ -L $named_conf ] && rm -f "$named_conf"
	rsr_backup "$named_conf" mv f

	[ -L $rndc_conf ] && rm -f "$rndc_conf"
	rsr_backup "$rndc_conf" mv f

	case "$machine" in
		BSD*)
			rsr_backup /etc/named.boot mv f
			;;
		linux)
		    case "$linux_distr" in
			redhat)
			    chkconfig --add named >> $product_log 2>&1
#			    std_named_sh="/etc/rc.d/init.d/named"
#			    rsr_backup $std_named_sh mv f
#				if [ -f "$std_named_sh" ]; then
#					mv -f "$std_named_sh.${product}" "$std_named_sh"
#				fi
				;;
			slackware)
			    rsr_backup /etc/rc.d/rc.inet2 cp f
				;;
		    esac
			rsr_backup /etc/named.boot mv f
			;;
		solaris)
			rsr_backup /etc/named.boot mv f
			;;
	esac
}


restore_sendmail()
{
	[ -L $sendmail ] && rm -f "$sendmail"
	[ -L /usr/lib/sendmail ] && rm -f "/usr/lib/sendmail"

	rsr_backup "$sendmail" mv f

	case "$machine" in
		BSDI)
			rsr_backup /etc/sendmail.cf mv f
			;;
		*)
			;;
	esac

	if [ -f "$mail_local" ]; then
#		case "$machine" in
#			BSD)
#				chflags schg "$mail_local" >> $product_log 2>&1
#				;;
#			*)
#				;;
#		esac

		rsr_backup "$mail_local" mv f

		chmod 4555 "$mail_local" >> $product_log 2>&1
	fi
	case "$machine" in
		linux )
		    case "$linux_distr" in
			redhat)
			    chkconfig --add sendmail >> $product_log 2>&1
#			    rsr_backup "$sndml_ini" mv f
				;;
			slackware)
			     rsr_backup /etc/rc.d/rc.M mv f
				;;
		    esac
			;;
		solaris)
			rsr_backup "$sndml_ini" mv f
			;;
		*)
			;;
	esac

}

delete_startup_scripts()
{
	cd "$PRODUCT_ROOT_D" >> $product_log 2>&1

	case "$machine" in
		BSD)
			rm -f /usr/local/etc/rc.d/${product}.sh >> $product_log 2>&1
	#		rsr_backup /etc/rc.conf cp f

#			inten="enable standard sendmail & named (within /etc/rc.conf)"
#			echo_try $inten
			sed -e 's/^sendmail_enable="NONE".*//g' \
				-e "s/^#named_enable/named_enable/g" \
				< /etc/rc.conf > /etc/rc.conf.${product}_tmp
			mv -f /etc/rc.conf.${product}_tmp /etc/rc.conf
#			suc
			;;
		BSDI)
			if [ -f /etc/rc.local.${product} ]; then
				cp -p  /etc/rc.local.${product} /etc/rc.local >> $product_log 2>&1
			fi
			;;
		linux)
		    case "$linux_distr" in
			redhat)
			    chkconfig --del ${product}
			    rm -f /etc/rc.d/init.d/${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc0.d/K15${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc1.d/K15${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc2.d/K15${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc3.d/S77${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc4.d/S77${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc5.d/S77${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc6.d/K15${product} >> $product_log 2>&1
				;;
			slackware)
			    if [ -f /etc/rc.d/rc.local.${product} ]; then
				cp -p  /etc/rc.d/rc.local.${product} /etc/rc.d/rc.local >> $product_log 2>&1
			    fi
				;;
		    esac
		    ;;
		solaris)
			rm -f  /etc/init.d/${product} >> $product_log 2>&1
			if [ -f /etc/rc0.d/K01${product} ]; then
				rm -f /etc/rc0.d/K01${product} >> $product_log 2>&1
			fi

			if [ -f /etc/rc1.d/K01${product} ]; then
				rm -f /etc/rc1.d/K01${product} >> $product_log 2>&1
			fi

			if [ -f /etc/rc2.d/S77${product} ]; then
				rm -f /etc/rc2.d/S77${product} >> $product_log 2>&1
			fi
			;;
	esac
}

delete_crontab()
{

	$crontab -l 2>/dev/null > /tmp/crontab.${product}

	sed -e "s/^.*\/${product}\/admin\/sbin\/statistics.*//g" \
		-e "s/^.*\/${product}\/bin\/mysqldump.*//g" \
		-e "s/^.*\/usr\/sbin\/ntpdate.*//g" \
		< /tmp/crontab.${product} > /tmp/crontab.${product}_tmp

	mv -f /tmp/crontab.${product}_tmp /tmp/crontab.${product} >> $product_log 2>&1

	$crontab /tmp/crontab.${product}  >> $product_log 2>&1

	rm -f /tmp/crontab.${product} >> $product_log 2>&1

}

remove_ftpuser()
{
	user=$1
	ftpusers_file="/etc/ftpusers"

	egrep "^$user" $ftpusers_file >> /dev/null 2>&1

	case "$?" in
			0)
				sed -e "/$user/d" < $ftpusers_file > $ftpusers_file.tmp
				mv -f $ftpusers_file.tmp $ftpusers_file
				;;
			1)
				;;
			*)
				;;
	esac

}

remove_product_users_groups()
{

#	delete users of this(unsuccessful) installation
	for i in $users_created; do
		delete_user "$i"
	done
#	delete users with group=psacln (ftpusers and webusers)
	for i in `perl -e '$gid=getgrnam("'$clients_group'"); exit if (($gid eq "") || ($gid == 0)); while(($n,$u,$g) = (getpwent)[0,2,3]) {print "$n\n" if (($gid == $g) && ($u >= 500))}'`
	do
		delete_user "$i"
		remove_ftpuser "$i"
	done
#	delete users psaadm, psaftp
#	delete_user "$admin_user"  >> "$product_log" 2>&1
#	delete_user "$anonftp_user"  >> "$product_log" 2>&1

#	delete groups of this(unsuccessful) installation
	for i in $groups_created; do
		delete_group "$i"
	done
#	delete groups psaadm, psaftp, psacln
	delete_group "$admin_group"  >> "$product_log" 2>&1
	delete_group "$anonftp_group"  >> "$product_log" 2>&1
	delete_group "$clients_group"  >> "$product_log" 2>&1

}


undo_install()
{
	p_echo
	p_echo

	get_pid $PRODUCT_ROOT_D/mysql/bin/safe_mysqld true root
	req_pid=$common_var
	if [ $req_pid -gt 1 ]; then
		p_echo "===>Removing installed ${product_bs} components ... "
		remove_modules

		# kill mysql
		$K_KILL $req_pid >> $product_log 2>&1
		sleep 2
		mysql_pid_file=$mysql_bddir/*.pid
		kill_pids $PRODUCT_ROOT_D/mysql/libexec/mysqld mysql
		sleep 2
		if [ -f "$mysql_pid_file" ]; then
			rm -f "$mysql_pid_file"
		fi
	fi

	$START_SH stop >> "$product_log" 2>&1
	sleep 2

	remove_super_server "ftp"
	remove_super_server "pop3"
	remove_super_server "pop-3"
	remove_super_server "imap4"
	remove_super_server "imap2"
	remove_super_server "imap"
	remove_super_server "smtp"
	remove_super_server "smtps"
	remove_super_server "poppassd"

	remove_product_users_groups

	if [ -f "/etc/ftpchroot" ]; then
	    sed -e "s/^@$clients_group//g" < /etc/ftpchroot > /etc/ftpchroot.tmp
	    mv -f /etc/ftpchroot.tmp /etc/ftpchroot  >> $product_log 2>&1
	fi

	if [ -f /etc/shells ]; then
	    case "$machine" in
		BSD|BSDI)
		    sed -e "s/[/]*sbin[/]*nologin//" < /etc/shells > /etc/shells.tmp
		;;
		linux|solaris)
		    sed -e "s/[/]*bin[/]*false//" < /etc/shells > /etc/shells.tmp
		;;
	    esac
	    mv -f /etc/shells.tmp /etc/shells  >> $product_log 2>&1
	fi

#	remove /tmp/.state for ASP
	remove_tmp_state

	restore_named
	restore_sendmail
#	rsr_backup $inetd_conf mv f
#	rsr_backup /etc/my.cnf mv f
#	rsr_backup /etc/named.boot mv f
	delete_startup_scripts
	delete_crontab

	rm -rf $fp_i_dir  >> $product_log 2>&1
	rsr_backup $fp_i_dir mv d
	cd /usr/local  >> $product_log 2>&1
	rm -Rf $PRODUCT_ROOT_D >> $product_log 2>&1
#	rm -Rf $product_etc
	p_echo "done"

}

smart_undo_install()
{
	[ "X$trigger_uninstall" = "X1" -o "X$do_patch" = "X1" -o "X$do_reconfigure" = "X1" ] && return
	[ "X$PLESK_INSTALLER_NOUNDO" != "X" ] && return
	# trigger_uninstall - trigger what smart_undo_install is already working now(recurrence)
	trigger_uninstall=1

	if [ "X$can_uninstall" = "X1" ]; then
		if [ "X$do_upgrade" = "X1" ]; then
			undo_upgrade
		else
			undo_install
		fi
	fi

	# put suggestions for user what to do
	call_optional_function failure_note
}
undo_upgrade()
{
	p_echo   "    The attempt to upgrade $prev_product_full"
	p_echo   "    from version $prev_version to $product_full $product_version has failed."

	if [ -f "$product_sav_tar" ]; then
	
		p_echo 

		p_echo "    Now restore contents of $product_bs from $product_sav_tar"
		p_echo 
		get_pid $PRODUCT_ROOT_D/mysql/bin/safe_mysqld true root
		req_pid=$common_var
		if [ $req_pid -gt 1 ]; then
			$K_KILL $req_pid >> $product_log 2>&1 
			sleep 2
			mysql_pid_file=$mysql_bddir/*.pid
			kill_pids $PRODUCT_ROOT_D/mysql/libexec/mysqld mysql
			sleep 2
			if [ -f "$mysql_pid_file" ]; then
				rm -f $mysql_pid_file
			fi
		fi

		$START_SH stop >> $product_log 2>&1
		sleep 2

		rm -Rf $PRODUCT_ROOT_D
		setup_super_server "smtp"
		setup_super_server "smtps"
		setup_super_server "ftp"
		setup_super_server "poppassd"
		

		cd /
        	tar xvf $product_sav_tar > /dev/null 2>&1
		case "$?" in
			0)
#				rm -f $product_sav_tar 		
			;;
			*)
				p_echo 
				p_echo 
				p_echo "ERROR: restoration of files from $product_sav_tar has failed."
				p_echo "       Please restore them manually."
				p_echo 
				p_echo "Exiting..."
				p_echo 
				exit 0
			;;
		esac
	fi
	
}

#vhosts

set_vhosts_params()
{
	SKEL_DIR="$HTTPD_VHOSTS_D/.skel"
#	SKEL_CERT_DIR="$SKEL_DIR/0/cert"
#	SKEL_CERT="$SKEL_CERT_DIR/httpd.pem"
	return 0
}

#webalizer

set_webalizer_params()
{
	WEBALIZER_ROOT_D="$PRODUCT_ROOT_D/webalizer"
}
set_horde_params()
{
	horde_datadir="/usr/local/psa/psa-horde"
	horde_confdir="/usr/local/psa/etc/psa-horde"
	horde_sysconfd="$horde_confdir/horde"
	horde_logdir="/usr/local/psa/var/log"
	horde_passwd_file="$product_etc/.webmail.shadow"
	horde_title="Horde Web Based mail client "

	imp_datadir="$horde_datadir/imp"
	imp_sysconfd="$horde_sysconfd/imp"

	turba_datadir="$horde_datadir/turba"
	turba_sysconfd="$horde_sysconfd/turba"

	kronolith_datadir="$horde_datadir/kronolith"
	kronolith_sysconfd="$horde_sysconfd/kronolith"

	ingo_datadir="$horde_datadir/ingo"
	ingo_sysconfd="$horde_sysconfd/ingo"

	mnemo_datadir="$horde_datadir/mnemo"
	mnemo_sysconfd="$horde_sysconfd/mnemo"
	
	passwd_datadir="$horde_datadir/passwd"
	passwd_sysconfd="$horde_sysconfd/passwd"
}

check_opsys()
{
        case "$machine" in
	    Darwin)
		mkdir -p $PRODUCT_ROOT_D
		return
	    ;;
	esac
    p_echo "This installer does not support $machine platform."
    p_echo "Please obtain the appropriate installer for $machine system."
    exit 1
}

hf_files_processing()
{
local inten="set proper permission on hotfixed files"
echo_try $inten

while read line; do
	file=`echo $line |  awk 'NF < 5 || $5 !~ /^nocopy$/ {printf("%s ",$1)}'`
	perms=`echo $line | awk 'NF > 1 {printf("%s %s %s %s",$2,$3,$4,$1)}'`
	[ -z "$perms" ] || eval "set_ac $perms"
done
}

### Some initial parameters
	PATH=/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin
	export PATH

	PRODNAME="psa"
	PRODVERSION="8.0.1"

	build_number="80061018.20"

	read_conf
	product_log="/tmp/${PRODNAME}-hotfix${build_number}.log"
	product_problems_log="/tmp/${PRODNAME}-hotfix${build_number}.log"
	set_local_params
	check_opsys

	test_for_root

### My name define
	my_name_0="`pwd`"
	if [ $? -ne 0 ]; then
                echo "Unable to determine current working directory."
                echo "Please fix the problem and run installation again."
                exit 1
	fi

	my_name_1="`basename ""$0""`"
	my_name_2=`echo ""$0""|sed -e "s/^\.\///"`
	echo $my_name_2 | egrep '^/' >/dev/null 2>&1
	case "$?" in
                0)
                        my_name="$my_name_2"
                ;;
                1)
                        my_name="$my_name_0"/"$my_name_2"
                ;;
            *)
                        err
                ;;
	esac

	if [ -d "$PRODUCT_ROOT_D" ]; then
	    plesk_ver=`awk '{print $1}' $PRODUCT_ROOT_D/version`
	    plesk_rel=`awk '{print $4;}' $PRODUCT_ROOT_D/version`
	    plesk_release=`echo "$plesk_rel" | sed -e 's/\./0/'`
	    PRODRELEASE=`echo "$build_number" | sed -e 's/\./0/'`
	    case "$plesk_ver" in
		$PRODVERSION)
			perl -e "{exit ((\"0$plesk_release\" > \"0$PRODRELEASE\") ? 0 : 1);}"
			if [ 0$? -eq 0 ]; then
				p_echo
				p_echo "The Plesk version ($plesk_ver $plesk_rel) you have does not require this hotfix ($PRODVERSION $build_number)."
				p_echo "Thank you for choosing our products!"
				p_echo
				exit 0
			fi

			START_SH=$PRODUCT_RC_D/${PRODNAME}
			
			### unpack hotfix
			p_echo "Extracting hotfix files"
			cat "$my_name" | $uudecode | tar -x -m -C / -f -

			hf_files_processing < "${PRODUCT_ROOT_D}/tmp/hotfix-80061018.20/filelist"

            sed -e 's/^\(.*\)[ \t][0-9][0-9]*\.[0-9][0-9]*$/\1 '$build_number'/' < "$PRODUCT_ROOT_D/version" > "$PRODUCT_ROOT_D/version.tmp" \
			&& mv -f "$PRODUCT_ROOT_D/version.tmp" "$PRODUCT_ROOT_D/version"

			;;
		*)
			p_echo
			p_echo "You have Plesk version $plesk_ver. In order for this script to work properly,"
			p_echo "please ensure that the version of the Plesk that you're attempting to hotfix"
			p_echo "is $PRODVERSION"
			p_echo "Thank you for choosing our products!"
			p_echo
			exit 0
			;;
	    esac
	else
		p_echo "ERROR: PSA directory '${PRODUCT_ROOT_D}' not found! Install PSA first."
		exit 1
	fi    

	p_echo "Done."
	p_echo
exit 0

begin 644 plesk_patch.tar
M+B\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-3$U-#,S-S,S`#`Q,3,P-``@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W,S,`,#$R,3$U`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+P``````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````P
M,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<S
M,P`P,3,R,#<`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+P``````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-3$U-#,S-S<T`#`Q,S<W-P`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O861M:6XO
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````,#`P,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W,S0`,#$U,#8S`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O````````````````````````````
M````````````````````````````````````````````````````````````
M```````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q
M-30S,S<S-``P,38S-#<`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]F:6QE
M;6%N86=E<B\`````````````````````````````````````````````````
M`````````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S,T`#`R,#8R,0`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M861M:6XO:'1D;V-S+V9I;&5M86YA9V5R+V9I;&5M86YA9V5R+G!H<```````
M````````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#<V-#<`,3`U,34T,S,W,S0`,#(S
M-C(V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B`@("!D:64H(E1H92!F:6QE(&9I;&5M86YA9V5R+G!H<"!I<R!P
M87)T(&]F(%!L97-K(&1I<W1R:6)U=&EO;BX@270@8V%N;F]T(&)E(')U;B!O
M=71S:61E(&]F(%!L97-K(&5N=FER;VYM96YT+EQN(BD["B`@("!?7W!L97-K
M7VQO861E<E]P<F%G;6%?7R@G0B<I.PH_/@I[4+V>/@G\_:$LPOR_R`"1O[W@
M>_FG+4@K9-%&I+ANS1Q>]7&5[VDLI?F]FZ%WGHWH"K55P)@?+%WSV/&_*DDW
M-\@9.L0KZ!;73RC;NQ.G(5\S2]4P1&B7KN7BU-E'P/A[:<XJ*.M"=X)^#S'^
MDH8[MY2^6RALYW./E)[US-D;]$V1<\+\&*-U(;3:H0!Y=O"*NH>G$*EB(^%/
M'$[F15]7E5,EL'=(TF-P;"HH:G,X0<?NN$\C2#)DAZSP1"_'*?85J/I^K-5S
M-?6F(BZQK0$$$1E76:PX?@QFS'!O-99C`+8&Z6:9-%_XD(3D2M_M^&"Y#KRH
MIF&,P_M*>#D=&FA1LSCUOD45H'[CF=)Y>(D9ETZJIPM\]_^'`$X#8\$M$6@D
M=6R5&O5U"6\'NS_W=$5F0Z]9')*2MX=-K@":ZTP<C211AO9YIS/7PW7]G*%6
M#:EU-$%6MB+#$D`J2T^[;E9EU:+JN`T+Z>_&>DU39_B=M87?"=8AE(AKIC+:
M8D2.R&6/,*HC3>-)6Z32/>Z-+8@PJ*<4P"%M8PN/V]4`NL&6.;6.!.C:&/7+
M.4#(I#VH/SS"QGR=4^ARME,D1,=.$2DK2AS#8T4)A"!)FK#:(^3'15I7[FPG
MV43B*.&9R9Q#S581^JOK6^Q9BDG$>$!+`V<9T:'8Y62;(5Y7#LW*I=:;97<!
M&Q^.B>0J2B550'I-D!\._OQ3-&R])\QB:L*VLKJJ%>^1,VR[-F(@JYNZ4GA+
M@L^D"KRG/@#;_9NN"R[BJ*(3*MNJ)R9_\)O@5)<<\9:2C5_:CDR63(X_1RI`
M>]%X&Y>=7W8,78NBGR+BY]-?)J+QK!BCS.Q/!JTS,0(2Y4:7S-S<`3T9E9>)
MIE3%%9'(#0%0U=WV'Z)P\L.&<$ON;_OO<%S%&A^?&)\$K!\+>Z4J3L!JR[!(
M`%Q;=1$ZNYXI>>MX>(1_!=HVXF?Q$\B5P:P'X3"DG$YT[?2UMN]2">EOS[IC
M5(S<A>7H!A>Y3N4>C9K7H;9G*I0_M*#SL77Z<9]"P1.J&T[9*)7.Y3SIE$W?
M4@;)Z977WD9_JNK6O,-0/!H)MRW0@S'')1,,]):)\P;"%*L""=>$A%#O6LA_
M`^`&Y#K06A;OA]=Z+;88!LF5HK"'`/DI7_#PT8!VW_R7A5D;[YII*LC$GA>-
MF^1;:!""*!8T/I.0U(ZU1H_#PW-!MC.ZC5FUXJ&)[-','EN';:66]J8AG?.8
M)<B#%$VE-/MX:79!!FQ$[8BR2]DN023*7GV\TL`%8'2;@54,,ZQA0P&^9JQ:
M#O^-PO6+W->1CXG<L(^A["U/"@NAD[?"'NVLZ/]*QABVQ;M4UHD6L1=B<C5I
M""3(Y_0XFUB"/.P?8`C5>\>2G1"Z7ZC']U)M"#<G%5.]FU*34+6'@06]NKV*
MS.\;W[3Z[3(@#(4S&(D?L!GUY+E=2@19H/JB%NM!XC+7XCJ-_9]34L62$'YO
M(QCAGJU[2D&-8]LS5Z9B$Q&\NR";LO)L%&@4Q)4`+>J?NF5&AUPAS![1R9D!
M>?-<,J["6;7U3&;$V^SP9/X6#E(C&)T3&Z3PB<06&.V9M$:\$;T*\5=2FS>M
MSHF_-5:::454#KR>ECU"`FD$!7S9FBG$90=-(L(:91N[5Z_6&?A2]O>0O,B4
M0A5<+6CD`(><P,^P>;KR2TA70+^`+8G?X>>4$.!;=$.=(LE:.U;J8!:WS\DQ
MD@HB_4@C=OQ(U<0GLN?9F*M<%4S!*C?4"E.D6:/=E3L+;+>+>J<B;*DFJ=XB
M],L+0]:LDZ)U(*T9H1-K,UU^F<CC(+7E-5_@*A?)?M'_[65UHCRFZV@GN1?(
MW%';P?.ZZ9>]MK[VY=R#4O\C>B<YCA(UP$)*8;&`W/W5,KXH9B&MAEI4910E
M2G[`7=VNTG^&OW88O!@">Y+P;RC7Q^59.'2+\JK69[3*J]F$P*XVKB\KV:I"
M3$SE'Q!I_$8PJ+Y_6AOSMJ.MRI-[)!E)H:!@8L-UWO/E#V>E.%[S8WO%&([H
M0::DBRO-4%E3(%UI]OK'V:YYLOR'`6RGPB>BNYC[XAJZ["_S?_#)-\JS[KP2
M$I*NI_\7=,7TT9DG]L'%`\QKSCQ.DCNS>%W6V_54MP^3>C-&W13%RS<0>L)'
M0GM%5(Q`YD-"9"`X"M;.#AC?>(9^:(B37L_92-JA5/W"6(R6CZ'7*CVFMG'H
M!ZE/N9A*F02$5"9%6T'\IJGX[@O,5,5M0S&%F)5*4;25G[=J4$PBUN>A"SV]
MT]_K(?2S:@'L,,X&\,7ULH9;13](^R8FRN]4HHJONRFF6&-:3%5_[=:^@1O3
M]N)&F3=DEG*?R<6%^Z$PP<*JP4MF&OR:2+?69V:%TQ#W(&>LE6S&2VJP\^5=
M,&:%JL"*O=MRRV^-Y6-V+")$8J,R_UX`]W#XM*<%QAYJ^.MEXE!-/,9'DDE!
M#!5F_11)[>Q[<_W5C7$H%<T#*<K<Y(315?&6LLZG4>N\'%T++F;7)S$WJS\Y
MG"93^&P[;:NO1Q=G0AS?HG='-:"5<]Q:+A%Q4`KN\3`#V$],VA-6;1BZV`T\
M@+U=B*@59GHU7.+8&W^E1]LM?;(,N4,^_O1Q'DR75W%:GH>Z$8.O/^R(;]TE
M14`^.&7HJ)7T74HF4V%</06O0<SKL!5S8YGZ,4O<7"OI@%:$4OI>'RX!!G;F
MS`45>S0LRI@:BU1FI84!8Y&UPU>J&4-[>X-1)\GSA';EU0(<(8%47P1=HO2U
M</\UB`F6C_/UDQ0W"?H%%T<6QWM`*%WRS&[:\XRFG5`."-(*A!=TR4;!5[ZM
MS,IK4Z\F--PZAOS<&"M@`4TB0U#NAE3")(P)YUCJ1&BT8G>8$VL$-Z:96L)H
MV[RF0X?V6JR#"'#]^/D*?\S4TF]Y3,BXP&:PY0#Z]?!<4AR1U.\J9)ECGZ$L
MU%?/5>VLWDY99\#%N9'?'WP?%X2JMABF$/NMB:E]3C;VKS^J\O%9#5.UO'5;
M]K1N_#/YX5@H[5_5HV/Z$>];V<_\\2LJ'2ST:I[2KKY`'07]8%WV%*@`U=V>
M'_%YIL/)7!15E7*:"C5<Y+VX,0^F;HL(SG$M6@P,R#DN$B!5\+SZ:D7V!M5.
M>O]RP1EBU9]RA70^DC)R!W.R%+=V>"O<[!T)&1^'G4OIL5]60Q3;:E;E1<<T
MZ<4P+U8K<'&:81W,.[3W345:5CG3(2)$U_C:DI40;0TV#%A(;A4QX.)0N`Q9
M9CQGN$AS*7(Q`3'?&2+TZ'JU3(-`:UZ26%-01V`!1^04X!;^!O7O284(LI-]
M?AH5C6+IR3A8`#X62T%^@!!#?:P>RFLJQFL>:?F0*)>A'*%>>"11=/XBZ(A-
M]";C$D'EZ^U98[P=,JADM</^8:@*0.5,R&NX_61J(UQP+**7A-?V/?J_[1"\
M(9RJ-V:]L9FN-F=U-[W@5-F[(A*]Z<EC:D$AQ.JAXV0S2Y^AVA"]BE>GO.KS
M`Q)SC7;XZFB6!`!*1:DD&YI>_X<153.3LD/-H3;*'_FC?S$I!^D5AFZ\P0OQ
M>^WEB`(]@URB_?EY^!I39R(<S`'H=W4;*#-64D",T5@G:W(TI`=!^IGYC8+(
M(/>\\$Q.G&KD8%I@S9I>STBFSZFB<?_MVJ'6$1R:_3:ABY[_P0OM[!AB6;SZ
M_;+=?68UKZV+8<M(1@M6E<\&#B<[P!TH__E(=HES&9E"M,S)R_.:ME"MI/*H
M5#H4!P81`5$`+P\I6V6>_!]^;A&14[/.&LA_LDV:F_=E&J5HL_6Q6<.@`B?%
MFT]CM35N2;:OO7%F8;<OG8G)^0HZ7*B\?PPS].='ZN.*Y[@89I'!Y?[:S.*5
MN"'?LU\"M\&T[I0'7$B5^H!!ZS/M:\=<)8(!JZ7#,_:S&O3;>6#V77^'9E`D
MUYHB+?)BP*6%G5H<<D0``GQD"D^>X<T84/5?9N!%KD/&I!5;D=[+@&]IX@$!
M=YHK?FVV`Q-?*Z[9JNS6G9V9V=Q:C@0`O4=.)#AC*]#8`GSI[A0SZUI0^76:
M$T,E;CVRF\2W;M[/7-O$[%Q_&H<*]M<!EX(6?*\/X.)[Z@=HW)]0P#8Q9)=N
M(=QM/U\(3T7EU%X6Y2"\[-!H2&Y3#ZP12.F#&BO>^"5"9,#XQF:7H9W%H/BX
M%`RK*)S=V8P$-:QU\EI0*+$^$75T5O-8B'PCG?N$8+G^F$XY1S.]_G$[-C__
ML;_D@IR[T&I71_(&"ARS\1'<>QB8WJQ]=E6WA'<(41Z&2@LK!H)FU/$?>(_M
ME2[W1YDK,MOGSY^+Y-!H&'QI3V.:8%4_#UCSI^[]$)E;X`6FT9JQ8U))9'#W
M.[RHVCMZG='=(U9+H-MVQFKC]%B0(@UO7U5-2%PC>"^=:OC`5QS4(&839NRR
M,Q#1NJ\JT:E/JW8$KY0)VT<D%*BK/U!KRR/.(`O@BE;%$5];LY?T3),8H]Q`
M7>\=;:VF_2C@+5<,XM+9JN[.W=JTIF6DSKQ&%Z@DH:F183Z4%-/I*V"^XMO&
M\\CHQ+M'ED^6C%!']L!;0,6DFTIE&\T\!7#$7X?K),RUUN,P4.=:,RZ\+*;,
MA1[UYY:YT*W9:$^B]4,#'*?>[,@_6&E+ZJM6-'-7;7_(&B8$7TB`+^B2&-`T
MYA/4FL(_O>+KN"Y^RVJN%O;L@(3F&3$PE+&*!=.V7'+#&!@GDYXSPNT*(90N
M%L7Y.,ZU0].<9A!RKY9\%D>_8!*_&!%D(%$ES:2".KO>8X]0L(2.$'3@TJN/
M@CQ[K(?QQW6;-8R6$">%FU2I[G-7M;P1V1#;RGI@D*[;T#??(?\AZX`P]PCI
MICY8'TT`7<$EQ%!:19_%QN?0\B%!7:JXTT9;BXA'/3^S>QR,OL)K8*H'7HJ@
ME(WBVJ.Z4FSGZ]J5SS`0+>5VD0)=NU#[.L4I1-#]&ZP!PQ29>`_GG35]W63]
M:C;'4+<EUNQ\&#396E,VW!0.8P95(.YP0%L;1/*SF00Y\8Y5695,1<91TP\_
MY=]1K;1,_Y:>F!:ZH^^^^^KW$QAOY_89@ETUM2MZ6?=N0B=IMS'L19[JA>BI
MJ#E,5F-.;TAC#9Q2PJM+^6=\K0B:2BX37QB\)4I)@K?$OL18'@MQU`F:[@7L
M[\J9'0&&>)E%W*-03GZ(`#>-C&QK,,1ZM*07&9Y`Q[+P['#,)LCE9(KS.]O$
MV?+)J>9*OLHUV/Z4?JHLI)-.3YGL0(8CKK0*(;?PSZI+F60,'AX\4=%"%X7V
M0J&I<ZY@8TC?$JNUVV&[Z2!$E3,FR$O-#E!TDT.*)9=*JS/8@Q,DHI2_*TJ4
MK;!=6VL[@0TU<0;_/'$;3?H_OP&4QZ5X2ANR+9TT90&1?[B0&5TWE9@I0#87
M34TF0^^NF?G9D&O&@PQ;+86*X%@@^)[O43?NB5H03JCX*B<?;:&T%R&&<*95
M?;YNFD:E,'Z2,`3#._['4NQ/#:4Z?Z+SLN&5$\\6?9`?G%]Z:VXH:M:!R1'8
M13`V5_5HJ*+8(A/08GX3(LZDQ@CW<XSJ):;,`<SA:V,%%$1"$Z-5U#?&%U8?
M+L4DG7_1TB@$V&6@0FLN;#V_29=VT+],"D:SC&6ZTA!DZX&HR](W:V^"HCSE
M6)Z.P:VDA@E1//M&3,KB4H>;U*,0;,GF"BN=.(*UH%""9`P\3-.@?LKT-]31
MP).1BE2OH9UBP-[GZNS6?^NK<D:'P-Z-)*?!L(^I\?YF)"`G2L\BVOFD7K$$
MVGJ/,A26(5Q2T'4M$/\T#IX0J1-'5-^A:)ZKR>;`V`36DA[=C(\3"BQ1-TPD
MM[L\>05:>/G=>.'QB%:I4N.X0D5T57@SI.\J><0JD&U)U0HVVZQLA.^63^J0
M9#8M??G!=[3D%!=R(G(Q&&#+'+!F%C40NN((E9_)H@GV,M\GCIE@E^2E*ISP
M??5]MC]V@FB2\49VYR0IEXO?R"-0"_S'3F1)+U?/#A,VBB"P@!5'0"0\+;H&
M8].=>%-0PBI$S1C!(<8Z#5/&1C2V+8AI5$7-]@7PQY/H!?CFKBNUFI04:?2'
MYG84<^T`BJ)>V]R.,XLL-S*Z#A?F&Q>GV?I"`34T21WE%#WN4..X>-%L]"Z9
MFL%%I04`4_:=\^OO8V\-E"&?1IN]&3<0WDD#&\:+=$$:CK(#2*+`&O;(%7_A
MQ?14OY>V*/MA=>2RR()\.@#PCRNST.XSNN6E>?U[26`7$NW1K[/"9OB9$^E_
M.,OP/U0O\*3P#-5S2WH5@#Q*>)QLT.U/6\-YPE==!9/\.]*8N9<]CB*UA<IQ
MN8GVKO,_EGO^5&^OHND)3`E'E'(/&7XI)SYZI+K"B=]<UX-9C2#4C+YP9RTB
MF?"U%E,Q9VUT_#IM?+GB<`8>(IEIWK5A]"POM_Q50A")3W\1O0*7M5*\"HQ-
MX6NH9:)*+38/FHV=(MTV.6:HF"5-'!0E.J">=]D?CZUE?5Z$$/'.,*3-^"+Y
M';<^/59(=4%<=]33KCLIP;>1A:^,J4AV?%WZW`&"DIN<KVC&HKHTS^W7)O#^
MIH>D2>H=B>AH>N-'2!G_+=YF^(V(+.295/EFQJ<@3<O@AOQG\T/BA8_7.P[F
M58$]UTX(Y:O*5C7G;WOYZ+=+8(8EJ%6"1(S&4_^5D7]C*J::"C:N!J0N#P*E
M4:^=)G.QC<RD)%'^&X4X15&.9?<6'TDP;4BQ:&36*Y)]PEN3`0P+(ER3=VJ[
MUW3:/S0F-$.O=H8!X;'!NI?+<2(K;2C&OS1'K";7B(7HE*<$(2;GT?2*C\&'
MQT:!^&TI-;V:U/R-E_6"$CA@OW%NH@!I!-BZ9(-&J86$SY6=OHE$F'Z3+7N-
MJ=6;3XF6F$O?A"X"!<T!23<!>0Q/4\+B1S.0S$A0:#B0LITA,R$";3=VM1YJ
M/ADPZ'*!#R,*P3K>&H^J]"HD5>K-.>1M$R`S]Y73\-5P[-F-"XOR_J2`__Z\
M(1F!04:M(C#((.:70.WM:PS@I<[/EJ0-[.JP<&PC5[%ITZ$%.K0*H:>====,
M3?&='Z]\G\SZV:RNR_#+)2U.Q\2+&>!%)->M'EQ!8*.).@T%;NY=55P!YN*.
M#/B]6#CW86M@ON>1!.9].^0J%_-/FO+N_S^G=P.#/)W(CI`0[JI0P2R`#81-
MA6Q)IXY=]:I2D.$7/_BAVASMAH$PK3=&4C/1?.6:-22E!\1G%J.WI*1]?]/+
M<8#*^L_9*@;7J:K/S6EO2#A?8HQ\TL+.F(I(;SZ@=XH8T*(S`T6ZRGJ\5=N_
MKD+]-_80RD_(')_.R`%3?T_5T_Q2B2/L6!B!:\<UP!Y&%E+VXF1#AWRNAXPO
MP.2QZ-667:H*9T:<B`(3T5R?'-F;W.^=CL*X"J]&$<RK+EXJHLC!"<]@.\KZ
MX.5>S=#X;TJD9YX1MYQ5SKA"'LCVYFRM?F`JWZ1^4BX<Q,\3.ZT+0(,S.M:E
M_],O+^.ID;'-A<G"J9V*],CV&"D;1VH9K4$F5HJ%6._W'=`9/N/54+0Y`(N@
M.6=#<DWHRTUUE;S6-]Q%.T%/)PR\_4R]ZR]Y]%2^)-D01\MB]\V3PF]*G0A9
MK;_>SIE:R("O_B<V;=\'ZN!$RF_[I"EH;D=,45%(;=S_;WX%5O'U/H[Q]VBH
MU4/7<'(0E1;S06Z0T&'C<BW_B>/N&O3+K0+`&\>U4=8/ZG_^H#L0U\KSY_PD
M=:$-[S3VG_Q:9%`__%?<`^?W\\%]TM$8$Y-Y6J5]OXT(I1)U'I`X$(.9$-*@
M:LVMW<D5UY=<:-Q/H9S3EL,(<70(D0M"XW@P8\(L4S(-MQDZH&D(U`Y](:D8
M\FZ.!?^WAF$44(II5&7XVA4O6S85;F6LA:8$RH*)18>!XMUCHY8W]ILX49Y6
MRC?64T"/EXTSK($>)H<19'FYE"X62JPPL)B)48BZ0%?9VA:!6B4Q0]G6WTV4
MWD%C3%R2KH@#87/_K\5HCH^$F?\!I<L37VB4Y\(3S:DO<4%;S,9GRN13UL^0
M^`)TB<`A,-\&R\MVSM=M82097=1'ODI9Q5L^<6U]GUOP.((L2%Q6M/5'!=SO
MG'#1ZBS-%'@P5R%?XD'2D+2W=@W[T:EV8N27CLJNE@=E@-XV,7DF--_I`[)8
M[AVG<T2@3S!1_<M0UFR?!N>&,AN3,I0B=TGVKWKS!UM_Z5MW>3-M%^WDO7#9
M8*YM#@*L94[3KTC\<Q(6-23T67CFSK-1P2Y-D<F6[Y2R#A9>Q0E\@=B<@A4]
M!6.S$43KHP?G4+IJ>3>=>WX%7R;LS^;?Z;1RHG!1!S!1X6:IA)ZKO3>X6"C-
M`9K#1OM;7N3N0WI`*>1MG0$U;UYAWSRTG>FQ9-[9^.;A4U?,E-$B4NVY\VUP
MS`!E!7-&`X:IPUIVP+-N65LB'[?TNTAI@?>,IB4Y\VFTUX?KR\<CBDDT#'P>
M.P=>8@!Y+#MQTKBM%X:88);6]J5]G+\*WWQ@[O7-SB*97X[462AC\IF(GP`E
M@3H6[_^GU0L`%%K3J8$)A><B21%T")7VR0]F6RH6ZELH>&N_<3^(:V<Q-TJC
MC?#<&1ZCV9>^7Z`Y9]U5_11JXMD=&]*V7\(6]&K7(H',6RMB="F+Z[!,G6,V
M-V@>&@CMHNY6P)3J0")E$1W3ZUFRC4,4#!:LKP4QDU72E"!MUVL5DLP0?3?!
MN0Y)S\$8M&R%]<`E(2;3P?.7A.>"1<''XAIWS9;#=9;(?P[]&/'$_>^F=9+G
MN_Z0)-.25!\E'P0?3]$$`4EX3*;PR3*'_YPR5:RGP09437JK)532,_6#L9_V
MR$JYT%]ADE1W*S"$]+W*<KAAX%:%XZ5*)4]/%D1A\6R_+!"%J#KYYY]2\;RD
M)G1:%T670G>A2O<W,5E%G#K[DZS5C'A:M_TA<5S'&P?!3&R)L0QF3RS%`&I\
M66F5,T$@62"<KSF3E.YTJ2$>'0Y&D8%,ZL3ZCU#;(+&"-^+=%O,*&7_\#0V]
MVW:IEA-48:'TMO(!BF)I&D8Q>9&PZ1P<XJ<F:['M'Q^Y'/L-LW;%;2]T*JH2
M>&T&S"X97_.XUCR&T5JVZ-]MU*-@SHY#UIX49--J"N0OW21VR?S9))X*MVRM
M$&``67R=_[HQ7&@4WN%:D?,7D5Y@_!]'BQ:"I0@8.6^!WF'4$<'8W"PO/*:[
M#_RNV*C)(=XM`N\_"XA)*,I,CT!^7M-[SKMUZ"[5Q(3^,%DBK9%?WI_0M421
MX,:0?I(R9K`1ASL09_O/51PUX#,@#J4]EA)MOY:W"((EVJ!;J@U<.]*)'$B9
MM'U%D%NVBG_@?ZQ<!_UQ'1]?8N?_D%]MX4C#%MB7)_^`\4!K4>F'J^&G,P3P
M41G?PS#GI7!U[8;(TXD9;D5KJ@TH$E3'25\+O]KOZ@%*@<YH5#(PM0O%,G8_
MFN=B"CRX6#;W+W'2`L9P?)VZ$65=NHX:.$Y3G'(+WE^\)",6X?5>ONA&M(YB
M9/")C%(Q]1!70UQ&3+9JZ)@&*C=7P24I^27P6O`PB:]6E&OK[/AO/H:@PYD6
MQ*D[1W`^;#'/@?LLV5_H%`6$-W;:)B]$*;X@_WXF:HT\<O"3L^6!7M<C/J#7
MM5-T7#;RX800ZQ)V(`V<-P4OJ3*K8BZ/-LPD,?W!&JDV/U_8!AN$S$J>B3O-
M1RF.@X][O%XX;L@'C?ZTGH!6FV!)TOL(AGZI7B*BP@PI5;1?%(FC0>I*.N/.
MKQK]Y-`':T%-?P]F8TP&)&+(RP&H!^VFY9!YY8*-92C75-)<G[;MUS?[S^,F
M(A:A:9-?2[6YB19-4D9?-^$4<0,"'<3L6Q2.E"`O4N2MU@+VZW9ORURXK"<C
MJ3\I\[?/6/J?J!VR3C+.JS?JPS)J<>ZSG5QA/T:B:C_7H\/NUYV'X=<P?Y9K
M!=32?"H!MCWO/-`9$9R/Y`*B0(^LG:ZJ&/^MVX1GA#!\%:3NE`-)$L^N#K66
MFI2R1:,``>9=-HD>!@C)]F\"IP4`>+BK^GYPPFK!C^XT-)'+;-+DOES8E8T>
M4`9O`C4OW%3O^@O@"G*<<U37V=74=2*7:N4YELO1C4I(J@Z'-6%^AO_^[\N]
M\#333/@IU_XP8F>WB-++3F'NYQ'S3W).^3;394W/6B_-BMY/O3LJUMFGL3\\
M!A#3H=KP:MN_#4XH+%W,X,\MOY?Q5=W%,"^+S1.0$39+5NO6=BOLQ5/O5DYG
M\%/]E.T^.B8_B'F,(>RJCQ]D+1$YWI<X!;GS^YL*V7NHHV@E%13O]+6;;D@.
MHB5#;N]&]P.PR)N-H*[/AV6EYU>HA%;B5L19VF5D$YF_W[0=;*J3+#*'Q5.?
M+KT6B:^(F6O3TR]]M%X32[G"+"-(`>_,J0%XM6FA20H-4@(`^%7U+;10FN[U
MUOGQ4:4(6W.9]],\=5?O=/2R5N\-B'QTW%TGXC'@?39<Z0Y-$E+FH?^71'YH
MZQV:L`5E$PP!L<3,VDBW02B%),.^[.&MWG:M[;L,IC,K>$*_A&XTG(6[S9<Z
M*]6"LQ>;A=RM-NMG"4)J,[@G_MI\M'KE:?(Z:5:.4C,VDI/.J:U^:P5I1!G%
M7[FC1R2U386CY[#`660RD0:5WD7/8"85B'@@>L,VTR"P`A@_L<-.Q>C@CO[,
M:N_*FW,O^<<8$?"^8/M;)7CIK3.D[OBBLO[7,QO$6=J,"5FF5":'!?WAYS[\
M-K$W*D(AKUTK30S?OHF<'#">5!60IJ"O$"?X7QMDLWAUPZ\$%#@US8/5$F-.
MJE7!X&W50[RXZRSHK.4!;*:IDH*7*-PVN#'I[C6C9YHZII\Y`XMC=H7`2,*`
MF:X5/]EUE,')GI*!#6"KUHRN;6DGBPQ67FTNY67C;G3ROVLG>D*F?>X>R_MH
M8CS(^K:/L6S#`Z&R<(T$MG"J#\'L-(02SV%Q/HJ((+V9;4'9P]GIIE-O@AYF
M(Y:_2X*V+#B\0S5FR/TH$?1$2SM`W(G4?`H$,*G:IM!E$N[(!\%U137!5"R;
M)]NYH[R^DUA&N_Y,8SH`%J482.@'*I8EY7=#J$%5<'1M;]`4FE,\KV^B<R1T
MJ"JNG_;D[/2E+.AMD,']_V[9%O=OV%QHB?T.%3-GR5+_!GF9DD2?DN"`^@9A
MP=V%"*;.M\=+>7+/!V>B1<%2DC::MXMO2YVK,_0P?16+M0;Q>5_)PT6C<C;I
MT+5`1);AW'0@\`]Z%_$/:Q#=;>0A_*]MFW2H1"%L0'Z$]'-OT_BY%2//@E#B
MN,SI2,V#=-FM*F66V9%6<0/V2!^7'ZWMNY?4$F]ZX!=5S%B%]T&6KX*D`1[J
M4>1E*W:"7%9SBUB1_[(O,_"TA?ZB-DL*Y5?[])&%$)JIX$2-^@0U:P']F]B$
M.`2J\7LF#B#%S4/UD`7\E%\QK1T,PPES=R)9.5-JJNZ>%']7\,%M/I)@2U5;
M%#YFOU9#BL[9:,:C\%YR4;\[KD+MD1/#.[;?1?HJV7CA;>I/VT:8&,U!2TK1
M;*=M*U;`H;#(<SW/ZWP42/AB7'<(F8&:G89N-W];K*4=_MK[1=4AUNWKF:9M
M.$C[H2N%VWB3HJ7%]5N:F2M^EA,#8J=2PCQ";\ONH`>@[N`7KD_>KPX:N@:!
MXN+N')RB,<:*E3D@(=NVFR+SK;4,("!<U>)D-Q._I:&L.RNY:24NS5`4JD-F
MF3K(G@N8170A*JH2[+3P/8_@#28I_";ET8<<,"XH*ZQ-C7<6DA?6;6(Z3M)F
M\<=6H15LUX`*&?.!HU/G,J1`*DO+-??/6R/SQJ4T>"*V/\=<H0Z[Y-8,6Z6J
M?EOYK>5Y&:[!&77;;XJLDJ"X*_=A6PW5E>KGMG?X[JCV^%NZ-$YJF'/&`$7&
M<8[`C:WT,^'UZU!L'I0>[#>Z_J;////?@?<%G.VF!87YVTES.0:U8*.A@WX-
M*'6_"X/07#GCW@4C_7B&\)_9U##W`V,GL_XV.=HD#?Y.@N4X:VBY#HJD%R-;
M4:XBA3&/^DL1O7C)FFQ@+EPQV>SM3<\(&%VS\M)?A9FU2(*`HV#B+$V<+Y!>
M+#-HXZF3NZ0<F[_EKP!;JC#^'`^[P0"<<,!(G'H)C8-R3-I/'-+X"]0"4Q]9
MW!#/+3*O#`%_=D2L;H3O"BA"O9L7LH,PR70=MRVQ_F0V#^6_J@E)'98-5\+,
MHBEW9_J%[>,SYO0J_`+'3^.^;>UNK.-R_E35U#MG23RE+:OR)-A&&D31$J0N
MAIE`3H@A:#T)R7;8&S84'V?9!5LQS6EZGE3T7?%:%\E9P$7E^CQISZKC=<JK
MF"81![B^+<<DL6B&WMXB?Z43@?B17#"V7#3(-5789E,=/SG=HVN_"613!`%E
M2^7(@N?O?K7.PL-*`$`A\3%88MHNT+2WP!0\??)7^O^_I=:G5^D=@;;:0B9>
M.]N1O^U"[W!^A7*JQ#?KF<66&'><Y20*NTF#0NM2SN/U5F/_:Q4W//:]4VY<
MA*>I?PA,*=$<]N.L>[TE[.1)0+TU/Q&>$N!]'^)$(118;#/+BU5W]WZ(HR%F
M#57"LJ9F=VO$2NCXVF+5;=:;+5V<`BN:$RN].--A#UT\/$VQ[V#-H,86]QYY
MQJ<BO)>+SCB#HFV0L-KO^3-[P'LR1/PFA-H+2N`^PQ3GF9<;D/,,/$G^-/9Q
M/G+-OFQDL4+,>4*=WNI]C]:IQHF#M936Q:[Q"/2IGS&K+;`BAV#1]&4'O_\<
M$?"B$ZU^;,OO::=CW3M[44;7>_D/=-O<B?5O!CP5>P@`@KXT?E9YB6+KDTM%
M^*Z&41@`K1$'-?D%I%19-X,10(]UTF`_$E$&BR(*KE9`S8$@QCR2SN.F$&&X
M3Q1N']N98)1N]+&;`<TQ_)!7W(Z8(!W=GWLKY('U#:Z3:S1M.TH=L2YKB44$
M29`$W?;MM5'>^_W]38_F'>-C;3B/T".!9J])A(^O$[-3P#@V]/>=TSV?4$;4
M.F0P-DI2Z(\,S5(:_QP;>5PO^6\%Z^M\3B!=P2L!H<LA8$%V<E^X'H`Q1J*B
MRK7@V/K4;MZHR,OJ*<,$Z:>3"CFD0.ME7@VEO[<*11'?L.K.>2BH@*'$1>X!
M>^8C/59BX$^,04ONO;>+\IOY7KQHN_I.73@8T[6'X[I,W.3G-,A=C)R8Z+I<
M%/-PZ<GH$.3*<!$<F/`3P"F7!KME/!YY=AGUT4KMGQSIB>T]W+:8==X'YYMZ
M7EJJP60U^JZ_J@G,WO)E\3Y#W=)-8/K?1*DZ$UF)3[+]*Q=HO2H>IB.3V;PC
MJ`)]U609EQAS53*M(!DF:AL%V_"L*ULL%]OWT1\6":E(M>:..6YKN6VCJ;\$
M$@.Q8R#T+<%-T6_I#QG[U]1S5,3MT`J"'X<9XHXF,7>?LM'UUC[:22:*AES]
M^*E`^&+-?R1[+D1.XH"$*N$\UGG`P$-!J%"LKX44]*:`K6HK48-WD&8*0;C/
M\O<Y*<#/+KYX6N8UM^S@QC[L`O_.F]59$HZ-?'8&J!&,#;[$4E2T7CA90G["
M:/P_V'\4(-H3XLPJK;UDM+\5PR/<%X*'&@;K7`WF?N,SN5<!IKH5W@]&Z0XY
M0-"=3N9YL6TDVG<NS\5_<^E\@+DR2/;Z#BL@_E20^6&5R1\.Y0L=1<UD@2+D
M=G8B+&>3+0OG"FT//)MS)-S4[#]S7(]93`<ZV+6_66ND#\&A(8S);+7CMVJ]
MF=WMRP:$-0&%33#E3OIWUV.+]C<+)Q>,P"K)=J7*+/Y-<@!)Q^P_E@-^K"?]
MO;36\@8@Y>SDEP#7W+^`!M&,8VR?==EMXOK]%.X\[*[>6-!7R2@-=AA(K8GQ
MKGZ,']-K4`B6Z_Z[_B0V;27W=E1,>E0M6U//O8F;(_\(%%<M4(1E*Z'=:1/)
M33.7/H86]?],&/V1`AK5>M6TD1?)6%8D_B,(F.P7.]@4O"C\L5?#X16KJR[/
M$`^FATUO9>T?3+VG_?6@-%W&/?5!N$#A<R_&0'-;<MGF2R`U'98,/J8!_EB!
MUR[F`"!V@!,(MBATS$B0S)%BI`<U-RP1Y#I<Q1ESVV/LHF>28T*Y/NWS\,Y<
M;NM;I!N-#'^D.'98>XRGR%OHZVU7[2F_&93ML]>?.F1O)D9W?QF!%V%3L;BJ
ML!IS/"1WE]TEC::N1Q![%76@=%&-G8M']*76FB*;>H<CS1G?Z.!=UCP_<&AP
M(&5C:&\G/#\G.S\^'`"$#/P71B-M%W.R#>]TR,.W.,.=51=<NK,MTR:A2TD!
M%$YM24P?SO[K"$8LXUZ"TUW;<HL'.RF_B3UF$7@%-UG!;?<1#-93[7)MPO$.
M:6/.T>66.'(5')8%,+-1;6S^@LD8G1\.11\IA'BR$77'>2=;DF&L]73:6S4(
M/F(+"AY"2:*E=;R@9;;B,,;!:D_VV7[>FR9Y.'BW#;\RN[>\K%_IBQ$:+S,[
M**P'CC^FCT'67=>N3AZ3A7-'W(HV-XK&X#)&%;[ZB,O;9QR@4?2EQIDD!\-=
MZIDU)FHVN*G:T?T6^TC+'#R)?IT4B^.J,FL=G7-VC%T28^N31</3$R]-X+82
MVO9O]YHJF7WIMWA390`L?_.1^D-Y);[$.'5W72&_^\*7CHN(</"X@8;<:K</
M<8A(15*HO741OGB/Y79"YX[:`-NE%>`!M@&BJ8<=X,%WMD,+UXV:/MK<RGJL
M(BC@DW`)5S4"TP$+4RG$*051@'8J,I\BY3N52AOCM-KF1MRS.&^4B7SP0F^[
M-"#$L^WU189F:9?WZ\6L0#'0.-4&=]3*:-*NY`&4`'Q`MWU[Z39RR9P/F`M`
M%Y.K+TU\<W7^W_,-UN;`HO/3/6`#U>1N^L!/'MLJ,@H,&SM>+)QV;,8\]L+9
M7Y$B+J7KS_FH"!<`<CX;<'K%K\/HHK%2/ND]HHFS.VA3GMWP&M7&)@8%;)?N
M<XI>?K/RKQP+#-HU3G\52@O)Y[_?7@C=P47NK)C*;WZA#730/"GW'/C^AP@)
M;:2SB,>D'F!G%#R.NC?\ZE5R3\A,BJ&IUY/:57"V"8>L#0&;W[M!!=K:L(+]
M=$"+7259?.D"$OA!&'('@:S$5(G<?KVNG?-/:M<,;>7$(J3B8FX,!TI$5984
M*[BJG#BIS:BJ#>*=[`K)@0:1D^Y!`RLP[Q"@+(UDX7IW8?P&]I\Z0""R,UO;
MO4OCP_`Y86,K,/H@)A]-;5SHP@M$<9V>5$8J8$]"(*\H1?B-L(#2A2$+#4(@
M)HYB\,2(Q"2]3'5W!?IHDZE=AYZ:DF$+Y\HU!+1]\!/20(:+TF?Y5[G/*S;9
M75KRA!@RAF7=QJ,)82D6-([_\'72LM44UB(:>1AM")7@VAF=%R_9"B:G$2O\
MIG3\Q+5T8`C5)%5KS\`=&$D0>S69#^2H/N=BE.ZE@"-+PZ_VJ*F-:D\;DY"M
M\O4M<@4AK]L\&VD@I499MA24-.H8V_S?BU*8Y(8U']51%$43790)HS^SLE>H
ML@*@9:W]2[_4?A2S7LRX[8E@#MAY+_62P5RLKYY@`6]ZU#^*Q6VOBL;[32#T
MHHH6@%"POMG"3DDTYG_/Y!DSU`SX<Q25CW17>&B]5L@+]96C:$$_X0_ZW,+P
M>%&+/S4?5>Z2#=L3Z1W3T;/XI$`'Q4!?/)*ICLE314'3_Y=,!%&V>`YGR/O.
M#74X]MAF\O$D&5E+P2>U6@J,0^Y.?(6_TW76T!4/+;.QTBZXGN1(VWM/2Q'@
M);C.#<BM.$IK+>?RJOS`^Z.!TF:+=9<8`%YH5Z7(,E03$S]W6CCZ66_4->J8
MD$#2@^<CSOY#ZXK<F,AW*$T8V;_ONFQ-B<`LN@(X=T2F.LQ3NG!!4'\O3))>
M+_O6`C'^22"C`Z`=LU,9NX+=IQK6B7'SJ;J&@U,$&P\:V$BV-R9U.W>/2G?1
MXAL58_#J964U(X,,DS(!<GI^DS[!HW*U@TUML;9++3D./ZZL)26ZM:AS<W9_
M/^;SSB;CNQ2D^]"5OX[]C&L[ALH&W?P6.7^.M*UK-W+:4!!C2_=2TG(31N\)
M7C[=3`UM,S'I_B2PL!?P:8E5ZB$7-`MV6W:I![_LGKZQG/)NF)O@`0;L/]G\
M==CV]SS`*\BXV\>IF*IO_4?>$;_7X6!@.S%*8:+_X1O!2VI"]0WJLZGW"/EY
MG;JI*9^:H;[P;C[`+CE'5K-%;7<67Y8G>='TV!D?VB@+T*,*#88B@TW),7QA
MV0"/([X8`LJN7"FK*W\$<W<KC0-MQN)=>PTS[2&:M+Q#$+248B;I%O$P/F(C
M%V*88O2619\J#/YN"]B%"B?I\FT2ROL[7UWQ.EO&NS]P#)7SY8I^?GL18\G1
MY>,Y[G65?5'<J"Y5]O:N^?V]4SA`L$W@)VP##@Z_3"Y'?MF()>A``4A]G5/D
MA!AM74H,>`QW<V.L_ZU,,L`>OAND.%4#6RT)$??G:95XL"9S%XQE&:);=&NS
MC-#CON^&1R&N;/5N?&L;N4*CCB$6^0*M9B^%.@^J"[U;BXH*@HH$5YO6&DQ.
M\;>%>,"^D_O.65:]B:!LZ/H(R3Z4*:20D+2DI<J@T=)N<C#>T<X9Y@RK_KNX
M2`1`3@.X;H\6#9TZ4`43HM9$NLF7O+WVYB0.X/F)W!KSA$Q?LK"#(<.(Q[2B
M6%(&<(XQG5PU]1)0(D?QY(9N!--R5BY#Q\8',_.R?247@15<DA0</+],.@-'
M7)/I21E;`8\XU.M'3U^YR"?0C6-J\(_H_Q5D?X=['>&.4>I!\(*2C/S&77R?
MW_+N@PV#!<&YEND';[*QXHA&!D&=7JO0\?U*(Z]*3)38OC]M,QZGA:)2=F)]
ME8S8%$.?'--'4T5;;-*GYL?#AJQJGHC)(AS>?EN:D=T#4ZK18#XN[10[Z]"P
MCO+<NQ#2*X_K?_F>\>L/?YTQ4?;9^$OF\=8I@2/*H05U<+R:N/-,08<E'%T@
M1ZJLETX\8L_4$4>3=ZE3MX\4PMS"2]_9-#4D8`WH`_TFZ76TYTS%9@7<UP>A
M`S,0/8;R-&+1C%K'L:^"B6#PG:F#[#\ES2^7UBRGS>LD["U"R9^9?H3'S&A.
M933ZOL3"XY"G2%WQ&[FH`N%R`GR\(?9MBW"W3">%`5'QF&(;/%F(.%3VD""U
MD"/O5O20;T@'U\A3DQ;R2#TD?FC[Z#<5JTE6D]=O?8SZ#:@Q";A%S#?I&W!(
M+\%0"',=MBR;D1-J:%@4#QE[.%*D`X>PK8/G+8F?)[XU.?>'\PQ=!U#/O;I6
M=*Y1E/BU2YTI"JS&8RT.QMSHLGOXH]T%52MBG(E)^\J``$<VLWR`4`BR#'R_
MMC&"PATP[.O^\&YDI%]?-U3,A%`VF.M^('X0I23]4LI5BRB2.BEWKTU9D#K)
M%T0NE`NLY#-X:J;$U&8?4\AC-3^N,(=31Y#C-G)4MU6I0[>%#O9YL^4W>S-S
M)X.<^N*]0N[+3GNBYG@=&DOL-9>3YB+9-BJ:4JOB$:F3X(09DLS;?SG3'`PQ
MC9)1ZHP:2F_2OI6W5UU889&O1Z_*:[X#KAH*C'#OM_Y:O5&D`S,_=H=U],9C
M@SI5F:@65>;D--0`FC2):IV8BE^;>_<P9J?6Q?V^B)#.?&51JH`V*P/0PH6Z
MJ'`"+?@4^]EWTTC[B'85D1%TUJP]T\PE.`#.K?(GZ?F`T=PK$+-?549^5TS:
MZE+>P=T)<-AC6"/=`9IL\\#`?`U_-<N@E12WA(B"P``2Q0?;I/9@+,:7B\\!
MGTIL/H7<JN^%%!ITPW%*67RJ-HA)V/N+)')ANG;9XC>".=5`<%Q(YP%$5X;9
M@,VU9IG/+`LU,7Q_DY"I?,?5=9-R2M&'8AF0BS6Q5^I9]];Y=>#E:98<8W9=
M>*6AL#YGS?JC70W#6#(8;(?1,FEP58_S3]%OSP($@Z`.7_W`&/1-@^6Z$:Y6
MS?ITF-W`@A1_!SD$MUE&Q)QVN[Z4?XAE+U%<&6]^^9G,"?V+DG(*(=&^;&MW
MO3XL;M,CNWO3M0+_S1BE"M-WD^?@Q[6<!E\_[)3R(8P-Y!B/(%THQH@"]NHZ
M,(BKIVH[6U#A(4I[K-1-T2`[#G@5P.-8UCV4N]DA6.__FS?D:;`?7:QJK34F
M)B;^*G;_K&?M;H@*_`ZI9+>4"2UCD`4BQULZ2[.Z2.7H4CB[+;`G`%F"8\\"
MQY9(NZ=67TGOVL%X)PE9\G?%A=2)UT*($Q:,!9(:,Y3']"STN_$R4^<Y<]55
MHZ#K?[Z3;7W+S2%!!)414415SG;(3<Z0D$P"G%70FYX>T19E=I&SECEV0&;\
M_`19,,%,,[EI$@1NC4P1.L&@87R[EKS/HN?-/C`?>P[:X[TTI.TR_7T47"T?
MT'\5\8%[=T0KG(>S_+.G[N)O<Z>XE*3Y49NW<+?(SFHIL%$=RA@42MX00`G<
MB^.50RXG<BM+]BEVF0/&ODE9;XF&G1*I&!>[#T\XRGTVOSVR:_?[.*4SS2$Y
MG7H9-+48H-_E3&7:9IJZS4%>US/QJND4<][?O/"*Y>J=HY>=.#KZ%$%I'C@Z
M7G"8F["64$.IIJL6>M-#YRO:<@.F]17X.X>6&L@[2OQ?GLI*KG35M]?1EQCB
M++/'+I.T-0C$/:-S9.7FD_2A[%=^8',M@H]G/K@J9J2BW7[&4H!S;W<3@FV)
M<'DZR4UR#I>.:+&$4$D:V*V5^(B=E&CWKF_,\;W#6I-=O2,)[<F3%<71.CSJ
M=C-01XA;GS;PLMRF8EE]UD16<+##/7G0KYPUP54#*%CFU4EDJB8*5`SZQ7'!
M-3D=9DX9LT4X"/HMW5I8M!99$_E68VEC@F/<6Q"&ET+*N^IZ\\\'\,CH^;AU
M;]/;\^_GZ/\[VN(?RL%^-%#G>3"%6`[6.*$CW63]_Y[/6CU9[$Y\#:A/]/LP
M9U?3ODB;AR`G4?X4I3@9.IL]9A+I)M4/B=XAH)B4TZK@WP]L$L[_$_TJ!C`L
M'3LSV[RNM%H,?M%?M$1L^3U]!*:GE6O(-SA$'?>/-IYPSEUU[/3:-D-.&`,!
M*%TT.$`\G#Y%Z3A4[\;P6B#<W&GQ6]GP:=SD)(U-VAE+TSVG5K0:7NE)/M?%
M-IHQ$,93MAKJ=]%N/<1G[N'Y4Z7[^DA?+];!I8$B(S)?`.A*`_I`A'>]"6$(
MU_Q%HN=)Y_L5G?5C"M+2$<8OGDA9JW;^Q\:E_U>W?3W3.6Z[T4N4%A^74\OX
MT)KXN%W-)S9@9:#A6U6D,C:8UG?B\-DW]]DB5(])#!+XT-H<9?&P4>G>18TL
MXRP>94D.>9H'3;9L6P2'ETLXY\#1X>9U4B<:F.O24.^XS>NYJD^=?FLHV741
M=JDHF;[(%]8S$6?(J`5HN2P18'X6F5AURM5(4/,9TR6=)_\?8>;20KZW:?[,
MXNW6_V`^\0'^BZ,;_-T&"0MHK.?)99M6BCV,[`OLF3S\JL)Y4R>GNG**!5WV
M6D79E4,:ZL#)[[76`OZ>-!2X6BSM=+NOT,)_XZ5L\]I'#DNM]3O/F.1OV(4N
M8>F#MGAB>NM@"A$H"_N-!@=>,)KG_-9TLX$-BJ,@_[\'91P?5UZDEO>KXPJX
M<-G$V71<_2S/>MDF=L59K>KFZ$>2ZU9CDCN;[JLJ&7(H^H^WHQX'.$0'&Q5V
MWVVYE?%F![.^7$7U2&!OM"BY(;^+MAF>>9QHH9O:VV@`?HUNW;X3D6W+PS-O
M0D31?#*(?,9:YJ0W7I(GNZLU*`0FOR6/,FM2*Y#-3U7XJ2I1$IMQ$5-Z:W#5
M'S8C`/00#L==(VNXQU>HDR+B]&`L:;38E+2K$?!%VXA*BP)<+^`N'`\'<.G#
M0^]+\@G`9T-):O>/9BLM271.J^^8P3\FNPST_<D0ZFQGW#O?RCO9&\#`F=UU
M%Q.3M'CW!-3:2H\A-$=UD1*T0=?>R>^:U3/&PZ+KCTL]#BG^(H<VMDT=*A=-
M[8.-(.HH6N"#!7S5?NB2/C?DQ9ZU==)>T!G4<I8*M1>U/O;;C=E]C1>=\=^1
MU!E<#CRXUX`3$7^RD5'NC&E.+HXR[0-<TC]\9(:LJ0Y63G%(:,(A6RU#9&;K
M?.4%X:^+"!'^U'CU"XK%OO0UON"SCP%%LP[@WM[RF4D0'5<U$QD_BNG>*/Q9
M?[VO`$T6[9?(UK"FJT.7KHMM[(&QA)P-;O-=\L8<KD@=NZJX?8QZ\_,^%%J(
MK_)L*J0<26G<"0!A8T!-JS:<='ROAZA\0(QR'17[)"`>37^+'K=;KLT6-'C2
MHO[12'OT"48XJY/6ET)#_FQ<P/!?1\)LM+RLU"P4/ZSGU+8E-YMH+3\^-RF&
MI6[0[?8E%)\WWXB*[3W\ZJ@$6*ZTLF"(\O2%<(&G6BWWLQOJZTM-IOK[G-F9
M[?`2:*IGJ@P<A(,XAP-LO5-Z?*!5%'K),7W:G&N=\Y73`LZP(RGW>$H<)!F<
M;(]3S7+\Q<Y6%_T$HRBG_U!\AO_E0B*!>%M"0"[DM++'@*=(I-EL@517'V5$
M)&M+I&^RQ;YZH8^'VCSYN*K78%@]+^!O6LQ^JD)$?Z!?_`+60';UWO0-NKCZ
M0@*4$^\GI66,CCY0\26AL!7M$[;//VOU^OE5+%LF!^\4?WP:<^EJ+;[UJ"\*
M<>_N2.\%NZF+'O6CI38LZ>>CX'?Y0+:[F.IYPGM&OR[P92%RQU+$GYZB=]1-
M59GR`SFX)BP2L'861J.6`+?G'E:`93L](TBHWW'3+'/1\5IVM$7U6.V+CL6W
M]8YJ-WR&HQ1-5CVMQ)J=VQAPN^)9_&N*=L36_<F96]%^6%_=KI$_>$E_IRF`
M\]>4?4$C)`-UT,>H8/*0;`%0TQ%^N^5*W\"PM@'@8(J)<.8JVZ`K$M"1.\-N
M#<<G8G!'9?03"!A]*5H6GYFW433&2NE>4>OJ&HXK&N]=Y*!-PS=[UEY7WI,L
MQ*L`"G4QTQ^JE?O=GZ+?SE<9H(UA_T=UBDR_>F&LS8*Q:%/<DJ-BS$O7Z(E^
M;Z`3#@1Y;L]RZ56?._:56XT_3"0NX0,0L"B-OUFC'YV_OJ_U)?7CK\UG'FY1
M-;[.A+>:A)V.1G'I+`)NKJ<F2)IU^2<_,I?KH($>-+Z&"+<P6G=!HD+CP(Z4
MAC.HPN+;\GN=.(C=)OH>FS>ZUOT=2<A4-/-[=#>LUU(L`BXW<'XE?G;SG':3
MK8[(N/H',EF5.N*:QW#=R84V-`O>*3$OAXM``+VEW3BHL03^W!*[K__"?N/R
MB_!Q]=Z6%_WQ.7G1AV/KGH5J)3@RK:08$/A9BYI%B(,>"IJ^W'ZO8(6=G6="
MI!ZY^Z8>LE_.[R(G%X!ZAV^?,0R>CT2^2D!99R!+Z[I,[L7ZFTD]Q_!HT$\M
M&!V93(@\O4FMC;,*1DW>138W";,Q.+>T5Q(<1A"8=U0X)E=?\J_;PW$/<+'%
M17NQSW@N5(A-#K/9!Y64!+%O=_B/,>]8XQ:6.V&$OVUNL-F6.U\SI2QP'A_%
ML2_W\;&OYKZ,X-+CTBG5?-YD'Z]1S-+8"7%'1ULQJ3$<HUVEQN1378LOB^HR
MZU<%V$Q)`F`JH]VV$%>W,OQJW'FHO5G7]F)UI``.JVSL7_R.`K`.Y)0CR_EF
M1LWC+)!I$!S44N.N&R30U"9$H'&JZO:%UF(3L<<)]=CILL=*6-,?X:-3&U],
MF9>`]_#.5Q==JT[#WI[TP.\%&<?*[%";<+DPHQ8X'J:R6$\BUU`*R[RD8O@A
MCW8K*;$7_5U+5R2UF/M&;0XZLR[R.@@L)^.)KABQ1?*6%Q@_-'%8?M",K\#5
M4:-*XDZ\F_@UU][&)9S]F>:.',PR,US20/&1Y,+MS#R#6QINAH2[E8=!LW=)
M[[7MSZ@N9XF80$8B'PW&/6U&6EW)8_F.+##P'Y-#H/>6L\A!9U,?F1*R/EE[
M!SBH>A+J07%R/.C';E[HZV/#M$G6HU4C>D!O+;GV&#K*??DN^#BE-=3PM=$&
MHU^<.WA[V>%20,58PB0+8-X##>P7-XAYQ&FAQ!I.2*>$;PXD&P!9X32>4*7Y
M^WL6*F_*3(D!3WVV]!\L)0BG(8I@+Y*WY6UT*]U%OG_&S:AQ<!<Q36>%,&=-
M//L`?IBRBY+%?8>H*29":MW(<0#@(-0W#E]ZUQ$4^8CG@L@![Z#>I1O?B54*
MP]QL$%.$]EGLW_\3-PS4>.8A:'?^O^5_R3?-"3N-L&]A#I>[IGP.@MIL&[NG
MP,!?_)U9$8,N.X1D,ZV[FO%E/Q;R)YVC[,"!1VI)7`6Z`F$8N&6,R)P@TC"3
M78:,<'.*T%HT81M[2D82['47@-"2@!M+(<W,GHI2)U4^D$T(_2N;1DG8!12L
M=1-T$`@R$`*KI]8U]-.DT:OYEMV<9@(313>-O.M^(WV#>%'%!!X6VQ@RH%7A
M!=L:T95U3L-%`..-R+BH=)!=_<9`LBG9R_052.J877V$PR??0LOGC^_DZ@]^
M;56V%ZYZ1I>"I+@H?.<5-.OF-=^JM1'-8=_4>(E8GZ5<2#,%Z:]\:&HC\QA.
MH7@PP`>5':%IR0W3(I_/_ML1/,0@<+X&Q,B@NV?Y^=*587[Q1CVLMD\M\Y*H
ME?!RL8;I+GQ:LAKD-3J2-[,?#$@$7A2,:MKDBO%<R(<;+Y,N)%7<YCP:A*.U
M;_+`*&%)\NUTUBMBG")Y)D))3-[,;HL2=?@Q+B.:$XQTCNJCR"MO\SBTQ%4U
M;O.O90(\LHVR8%S0.G\>L^^>P1(9%*%<TE1D(-NJ'"7!DJNYRF[=_"8GS$\T
MD.\]/L=SJ[]32TE-_9Q#=P;+F(&HRA`_^^NE?9>U:_JK?MNRIFL0NC>_)^WR
M!OG(&Q)SV#7SDV'1$<:Y\;%'L?46-V$`H.DF5=;<7UF]L*HQI?X"NB0=2.<6
MI4'+18*M^`G0UBS+1SW'"XTQG++)(_:FKTB#Z^[`U7:6.<-P#C3GR"&4%_X<
M+E]+RR,.RS;C78`"MT4/+E43U,4$UD"A+G7HYKDC0]!`+5`=(!Z+@!(AI%Z%
M,,U@1AU1>6XG0NV6=_/#!X8MFI]^<W%#FZUB(D.[]TYYJK%!40VVY!_W[X<6
MIE7K+S(+@8/3C&\45[>S2>.%51#E%.@,9?TO1:#6\RAS1!Z'(,0)LN%&'9C=
M,G<KT]F^(_AB[*L=;J_"-'UVB0F[$5(O[/QFE75NR!;-QX=^WV@U754GV5V>
M!\\9*+Y@O1"LW`;C@VX\HS5U54M!A%I6=8X[T-4="8G=D,)69KV5#4!IV#P<
MNH2S_\KXSS>D#*]&VLE@;"V4-09#LFD*>NN4G8?'[@N95Z^PKWHT3.4NI18+
MT`S#V_KQ-X91ZH46BVX%`AJ6\("_Z=I8`*@3Q($W,IKI+<TD3XXD/[!2!9+/
MT8.Z:%**MHU2VJWX6?L-^0P/BVNY6&1.I(".Q<(Q.9.#C,4RD/9>=;%DV5TR
MSJ+4F`#"'"XM=I@FC?TT;#7?'>/+ZZ$&!0A[I15W6CL0P&B&U%_!Y9SX-:M%
MVM4^_F5J(SM[4T;5Q=-4%U%:-G0'/VCTH.84[?(L8P)Q?CNU4/3T9BX.:[J#
M&5(`^_]]/47UYH__VM>[MAR:$`*C:@$WG1D$WI?6ZMAXOB2ZZ_S@O';]<Z8G
M!/-3>"Z&JJ`S21C@%`>^[(/U9:!E/,(L(N!9J>0]IK]SV@$[;6$=".+',B-P
M>EL`^A3U;3NDIT&J!_;EY$B\^#942/[>'I')4;844-B*<`#H-Y*R7;]!.WIM
M#MG?@U_QY/S+C[$'4]]A&Q.`GH(=2P@>#,+%?84P\>E5M1JOJQJE#[(#'L"(
MP?7?I.&Q9"2U$AN<(1I0ZJ9/^`2;[&E`!F(%K,XUQ?6@CS\"&(KJ#8SI^`EG
M,:`Z_#HK)D&P(6&/<>F*_PO@0$D0+9%_).KIQI!`!4Y'BG3,GS`7!JI:@Y47
MSL@QH>4RU5Z;(P(T&P")@)(+.(H$,],8XO<%!]\4_Z$0-HB$!9P3C]!5R:=`
M'F.O-81M.6Y9R%2W)D#K:Z692X@P-OC&G%TU6/A4]E[ZS6G'78>E,"B#AB[\
M0_Y/43N7%,$4\434Q/1W7VD*U0SCC7/OEI%RW6!]=S/GEB`-1Q#!6^FWMN*!
MD4*`BP[6N^OM;A'$P[*7':Q]P72P<*V5@ZJ-==!T^0:Y%=1RC"^IN<PV%^0I
M!"UC0(._^R[QTH'L"I*M&=?Y[I(M]('F9<.K4NMO`8AU'>Y&\I*<I:3/N57$
M<'Q)]:E2JY"^UCK9;#^#6('Z>_[L^.V3NUU^WLR@8B4CD'7"R6=L'.KE:(<!
M,$/_WJ2$%L?>9UR.T2ETL<G?2XC?=(TN#'H&2U6)ML,5R60DILJ<LOE/*O@9
MK*A22NQ;"UJPAO<;!H!Z0)ILD'@M"$%B;.+M3#D2B92SA[KQ/[!]6ZTO&\8!
M%'/,K/CY#[@U8'CU_-$+'>WW3YX;O05S&7X?I2?&7GKSU+U>:Z_SSP^J!;H[
M>U'F^PEF%VWT1FB,.\^AJIWAIT<#*MN[W>*!^*"NH(/\N*$L!4V$>/4J)P9H
M5_,:41Z`MO?]13M#+X*YTL$.>8W27:0JR#7%IG+X=?E;LO1F#UG@C-`T/\D.
M!\&?PR\JK'\?@^L]N`=-L6RVQOLYPS"\?\F@4P30:G@^`\3$$=KF;5@OYGLU
M_'THS"'7:P`\*OSL)$.8D5;Y*':@5%4^6-^Q.ZT69QH;5U@HM0IL[SMEM.^0
M1!J<\"K^!TS@.&GPD*4V73@G;-%U'7SKK(*LF$.>8"TMD!A<^K'*UM_5L_SX
MQ88$20!4`9O%TN-3$\#2:/FW2'M/K,$,QGU.1-XJ*K=!_3$DTO?]R\(^K<3C
M;6KG2K8V'K3](J=[GA)+#X]JQ;6V/5[;U.QAH9FKN)<'U9_9KKJ*J\=$("G:
M3'C,3`@'%_*XL+2+OZ,MG/]$'0Y`^YST"Q5[AV8.62_D;(N+T)VH8?$&-PY;
MG#J2'MD)#*H[PP;0E`_AAQB1H6)9ML359K'[%V$@0O^TOEY<`;@RR'N<J[Z1
M(EZ)4_0!5S5?'V`+D/_FL%20BF]*'+A\Y",4&4P54LM((5W\".)M?NU*:3*_
M4^],\.0TNI&'E0QB5*?#0&XROX$J5U@7;&66P3?HQ!&>7#_UI*X-.Z5"]>TF
MNJ7T,SI:`DB:<X_^QCEC4M:#`FMP[23H+(PJ)S4$J1WUOO<+DU>T\G*:W8-`
M@'*;&H-B=9_*S3J+M7<3UU9ADH2(\(FS"BP914NJB$4D$[:@LD3$4RJF<26Z
M0O#O%N=V8^@>'8!1#!9_1P9,[Q(&;AR%;TAST/@Y1=?D'M&;N%Z_G6.Q,EQ?
M9/++F1D]PXDV#,`&Z<0.<5-;U>S%G6WD>&APD@-H%E[NO'K7U#J]'Z5L"?[N
M.?N9S2XSC"^<^(?,]0MNEB/9;1B>!W.3>U:<^],B@5J^-SRX]6J)?'XV(GAZ
M.D5&;,TS![MZG.4]=!94NK/?MBO6K6')SU#UP]+?A(-";X\?5-GIL6Z1="MN
MFW:[</#8)H8H79(0`B'BZ\8/?<I3*[T"OZ6)UI5P[E8]<ML%-D`GX((!R-]*
M"8GXL)$_R*VR;0;5MK8SHMT.K`A6E>GSVC#CU9]<\1(&GB?#LOJR9#,A:^BC
MS5ZK&J/WK2R',T`<A-POV8Q0`OUXXAD8748]H'@B>0!MJLJ62@>.O$+J@9+G
M_[X9H6A_0O;5.A47NAGL?I&=/R^4N-<%%)9)66TJ)9S(>9^16$^*BT4Z"?ZB
MQI<IDH<[*?`4G*PR`]D@P__2U^S$B.V/]G&*41_B?[DGTAWGS\Q2F<1?#\O(
M)D=J(4@/B[S0G?&JS5C0IO]<`=9BHQW]A`,>\D#5D00R8<9`OYU$`@A,:G@<
MR+IBN\9-%WWG/D.;Z<H>K'E?,9`G)E2]]4\&*\%V>>+5$,_%F>7W)(Z:GTZ?
MB8(3BE#B%!BMPS^C`8BB(+?:&)MDN0R97D&)+;+5[W"E;;I,7D.VM))NY3'"
M7:U5*TH))#U*CIV&[%J)'YTXD&BM1D,[\<$-8E'0$O+-L?[K.'8S17RB#)&4
M[F6><2EH+`([05$65/H]O1J:0V;V*4S8\4;>&_:"(X$C4]IS1:%CMV$=7)(T
MT^OI/&H:!(JEIA-)6&<S0HZ7\>A*ZBYOA:HKC;1Q6),F\-"$J2,["E[6T&51
MZ]\,;.$^OH_K=N1'97[(X,^MG.U^P36_#`&71N)\]_57_>_KS:3[!X*;(^T7
M\64OD\)P?4:%Y'0@ZJR=D#\`'O%SM""_7#%#OD(FW>=+Y"QB>A4*;4`0E&<Y
M*I+/H*G1CU6QRJNA66^"G!Q2)TX#,AO"^72TP8MGE-Z0/TN)'5TPW=M82>!_
MQ9PYO00:_+<?QBP#-[`?]Z54FJHV?*L]=5U*_K5J=H\?J8SM'2%:^42J;A_X
ME5E&%Y'6E?[`+',24.-L7EO]2<*)[\/%NC@KICXIBONZ6(.#%C^3T1`9"W$O
M8Z_[C).7^)6T"\[K;3\K3=6(_#<&7+"!?I;J$X1B-;6YY_X:9$8K]2[3J%)$
M-0!\B1UD["5&[#%P[8^:\M3D%E0?@]3G/36[Q&!;-!F<^LDG!!(.\YJA_CT=
MZ#0)Q0IB?S<TM)51J^?-[.L^6DL)JY8)'L=G%$-7GJS088T!<'[_GO(?ZVH(
M&NMUCM\\SR+`]N]UHC?R-H";'BFC?<*1,@QJW&QS#6:W2.AVS0,GPMY/.$[^
M>+)4#%=@+>-_]UOR->B%0IWG;OP"Q(YNVZJA2H%3+_'2'Q_7FVA?C4E=(F`O
MZ$>J#VN_0!"#/_Y)V/2.VJ/3#";T)FQ#G;WT&X#.]8+T4AQB(0Z3K]MD_CKY
MI5#3)^!+"'#[D",EQW[Y&?M\8RF8G-X7^6I[(PT(0"D`19L><.3SA_(*1=4X
M&6;/*JJ(%N\T39#?[#YV;8I(Y4`/U_BR<`[JJ#I>SLK)1YHA?EF/4>QG5GL9
M89,H!_HY-"5D"<[_>S573\%XS$,2J'Z/$&C"H]+^W+OQ6U4?%H\8Z53C`Q,+
M/IN[(WTFC?H-!T/H"B[*R%W;VG/=AS"^&4";S#)%(VI^B_QCI8P<*R]>9#@C
M_K89J2?#FN!<C(2JP4[ULD\OB>#3N<Y.K[^]DTLMY<,N_C900_4C&)ELIQ8"
M%*;`39<L<F.)B_DJAQ1@`:'K4-9R\D2/P@8?P<JW6;`[CD;5#UD`[[BRH%,J
M8\\=L0N=X,XZ,1/93IPP0D,L98_(TT1(!3WD69^7N)&'HU:>U?J^:=6?U;?N
MX-?ZO^4N2R:4=AQET$QGE8G*9Y.*6NXQ-=X[61=]$R@N0H=FB5?D.H%\9,O[
M[L[W.TPG^H?M^9'4/*.71\#<"/+)-&2X/#:P.I'!T*N`BFO"S#IQV/VIP=`6
M6%R0T*+,+&"P[M\44#E[:Y2&H!?04-Z3,7_:*B2^7\([*#C0D&.4M!M#4[06
M0E1"O6:!`0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R\`````
M````````````````````````````````````````````````````````````
M`````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-3$U-#,S-S,T`#`Q-S0W-@`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O861M:6XO
M:'1D;V-S+W-K:6YS+V%Q=6$O````````````````````````````````````
M````````````````````````````````````````````,#`P,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W,S,`,#(P-#(T`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O87%U82]C<W,O````````
M````````````````````````````````````````````````````````````
M```````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q
M-30S,S<S,P`P,C$R,30`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN
M<R]A<75A+V-S<R]I92YC<W,`````````````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`Q,38U`#$P-3$U-#,S-S,S`#`R,C,R-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````O*B`M+2TM+2TM+2TM(&)I
M9R!I8V]N(&)U='1O;G,@("TM+2TM+2TM+2`J+PT*+G1O;VQS07)E82`N8V]M
M;6]N0G5T=&]N('L-"B`@9&ES<&QA>3H@:6YL:6YE.PT*?0T*+F9O<FU!<F5A
M("YT;V]L<T%R96$@+F-O;6UO;D)U='1O;B!S<&%N+`T*+G1O;VQS07)E82`N
M8V]M;6]N0G5T=&]N('-P86X@>PT*("!D:7-P;&%Y.B!I;FQI;F4M8FQO8VL[
M#0I]#0HN<V-R965N0G5T=&]N<R![#0H@('=O<F0M<W!A8VEN9SH@,#L-"GT-
M"@T*+RH@+2TM+2TM+2TM+2!S;6%L;"!I8V]N(&)U='1O;G,@("TM+2TM+2TM
M+2`J+PT*+FQI<W1!<F5A("YB=71T;VYS("YC;VUM;VY"=71T;VX@8G5T=&]N
M+"![#0H@('1E>'0M:6YD96YT.B`R-7!X.PT*?0T*(V1A<VAB;V%R9"`N9$)O
M>"`N8G5T=&]N<R`N8V]M;6]N0G5T=&]N+`T*+F-O;G1R;VQ6:7-I8FEL:71Y
M5&]O;&)A<B`N;6ES8R`N8V]M;6]N0G5T=&]N+`T*+FQI<W1!<F5A("YB=71T
M;VYS("YC;VUM;VY"=71T;VXL#0HN<F5P;W)T5&]O;',@+F-O;6UO;D)U='1O
M;BP-"BYU<&QE=F5L("YC;VUM;VY"=71T;VX@>PT*("!B86-K9W)O=6YD+7!O
M<VET:6]N.B`P(#9P>#L-"GT-"BYU<&QE=F5L("YC;VUM;VY"=71T;VX@>PT*
M("!M87)G:6XM;&5F=#H@-7!X.PT*?0T*#0H-"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C
M<R]S:VEN<R]A<75A+F-O;7!A8W0O````````````````````````````````
M`````````````````````````````````````#`P,#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S,S`#`R,C`U,0`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+V%Q=6$N8V]M<&%C="]C<W,O````
M````````````````````````````````````````````````````````````
M,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W
M,S,`,#(R-C0Q`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O87%U
M82YC;VUP86-T+V-S<R]I92YC<W,`````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,3$V,P`Q,#4Q-30S,S<S,P`P,C,W-3$`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+RH@+2TM+2TM+2TM+2!B:6<@:6-O
M;B!B=71T;VYS("`M+2TM+2TM+2T@*B\-"BYT;V]L<T%R96$@+F-O;6UO;D)U
M='1O;B![#0H@(&1I<W!L87DZ(&EN;&EN93L-"GT-"BYF;W)M07)E82`N=&]O
M;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;BP-"BYT;V]L<T%R96$@+F-O;6UO
M;D)U='1O;B!S<&%N('L-"B`@9&ES<&QA>3H@:6YL:6YE+6)L;V-K.PT*?0T*
M+G-C<F5E;D)U='1O;G,@>PT*("!W;W)D+7-P86-I;F<Z(#`[#0I]#0H-"B\J
M("TM+2TM+2TM+2T@<VUA;&P@:6-O;B!B=71T;VYS("`M+2TM+2TM+2T@*B\-
M"BYL:7-T07)E82`N8G5T=&]N<R`N8V]M;6]N0G5T=&]N(&)U='1O;BP@>PT*
M("!T97AT+6EN9&5N=#H@,C5P>#L-"GT-"B-D87-H8F]A<F0@+F1";W@@+F)U
M='1O;G,@+F-O;6UO;D)U='1O;BP-"BYC;VYT<F]L5FES:6)I;&ET>51O;VQB
M87(@+FUI<V,@+F-O;6UO;D)U='1O;BP-"BYL:7-T07)E82`N8G5T=&]N<R`N
M8V]M;6]N0G5T=&]N+`T*+G)E<&]R=%1O;VQS("YC;VUM;VY"=71T;VXL#0HN
M=7!L979E;"`N8V]M;6]N0G5T=&]N('L-"B`@8F%C:V=R;W5N9"UP;W-I=&EO
M;CH@,"`V<'@[#0I]#0HN=7!L979E;"`N8V]M;6]N0G5T=&]N('L-"B`@;6%R
M9VEN+6QE9G0Z(#5P>#L-"GT-"@T*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI
M;G,O;&]N9VAO<FXN865R;R\`````````````````````````````````````
M```````````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<S,P`P,C(R-3``(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+V%D;6EN+VAT9&]C<R]S:VEN<R]L;VYG:&]R;BYA97)O+V-S<R\`````````
M`````````````````````````````````````````````````````#`P,#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S,S`#`R
M,S`T,``@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+VQO;F=H;W)N
M+F%E<F\O8W-S+VEE+F-S<P``````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S
M-C0`,3`U,34T,S,W,S,`,#(T,34R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"\J("TM+2TM+2TM+2T@8FEG(&EC;VX@8G5T
M=&]N<R`@+2TM+2TM+2TM("HO#0HN=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@
M>PT*("!D:7-P;&%Y.B!I;FQI;F4[#0I]#0HN9F]R;4%R96$@+G1O;VQS07)E
M82`N8V]M;6]N0G5T=&]N('-P86XL#0HN=&]O;'-!<F5A("YC;VUM;VY"=71T
M;VX@<W!A;B![#0H@(&1I<W!L87DZ(&EN;&EN92UB;&]C:SL-"GT-"BYS8W)E
M96Y"=71T;VYS('L-"B`@=V]R9"US<&%C:6YG.B`P.PT*?0T*#0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]L;VYG:&]R;BYB;&%C:R\`````
M````````````````````````````````````````````````````````````
M`#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S
M-S,S`#`R,C,W-@`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+VQO
M;F=H;W)N+F)L86-K+V-S<R\`````````````````````````````````````
M````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`U,34T,S,W,S,`,#(S,38V`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]A9&UI
M;B]H=&1O8W,O<VMI;G,O;&]N9VAO<FXN8FQA8VLO8W-S+VEE+F-S<P``````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,V-``Q,#4Q-30S,S<S,P`P,C0S,#``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+RH@
M+2TM+2TM+2TM+2!B:6<@:6-O;B!B=71T;VYS("`M+2TM+2TM+2T@*B\-"BYT
M;V]L<T%R96$@+F-O;6UO;D)U='1O;B![#0H@(&1I<W!L87DZ(&EN;&EN93L-
M"GT-"BYF;W)M07)E82`N=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;BP-
M"BYT;V]L<T%R96$@+F-O;6UO;D)U='1O;B!S<&%N('L-"B`@9&ES<&QA>3H@
M:6YL:6YE+6)L;V-K.PT*?0T*+G-C<F5E;D)U='1O;G,@>PT*("!W;W)D+7-P
M86-I;F<Z(#`[#0I]#0H-"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K
M:6YS+VQO;F=H;W)N+GEE;&QO=R\`````````````````````````````````
M````````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W,S,`,#(R-C,U`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]A9&UI;B]H=&1O8W,O<VMI;G,O;&]N9VAO<FXN>65L;&]W+V-S<R\`````
M```````````````````````````````````````````````````````P,#`P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<S,P`P
M,C,T,C4`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]L;VYG:&]R
M;BYY96QL;W<O8W-S+VEE+F-S<P``````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,S8T`#$P-3$U-#,S-S,S`#`R-#4S-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````O*B`M+2TM+2TM+2TM(&)I9R!I8V]N(&)U
M='1O;G,@("TM+2TM+2TM+2`J+PT*+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N
M('L-"B`@9&ES<&QA>3H@:6YL:6YE.PT*?0T*+F9O<FU!<F5A("YT;V]L<T%R
M96$@+F-O;6UO;D)U='1O;B!S<&%N+`T*+G1O;VQS07)E82`N8V]M;6]N0G5T
M=&]N('-P86X@>PT*("!D:7-P;&%Y.B!I;FQI;F4M8FQO8VL[#0I]#0HN<V-R
M965N0G5T=&]N<R![#0H@('=O<F0M<W!A8VEN9SH@,#L-"GT-"@T*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O<&QE<VLN8FQU92\`````````
M````````````````````````````````````````````````````````````
M```P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,S<S-``P,C$U-#(`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]P
M;&5S:RYB;'5E+V-S<R\`````````````````````````````````````````
M`````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-3$U-#,S-S,T`#`R,C,S,@`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O861M
M:6XO:'1D;V-S+W-K:6YS+W!L97-K+F)L=64O8W-S+VEE+F-S<P``````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`V,#,`,3`U,34T,S,W,S0`,#(S-#0P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"\J
M("TM+2TM+2TM+2T@8FEG(&EC;VX@8G5T=&]N<R`@+2TM+2TM+2TM("HO#0HN
M=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@>PT*("!D:7-P;&%Y.B!I;FQI;F4[
M#0I]#0HN9F]R;4%R96$@+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('-P86XL
M#0HN=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;B![#0H@(&1I<W!L87DZ
M(&EN;&EN92UB;&]C:SL-"GT-"BYS8W)E96Y"=71T;VYS('L-"B`@=V]R9"US
M<&%C:6YG.B`P.PT*?0T*#0HO*B!D97-K=&]P('1A8G,@*B\-"B-D87-H8F]A
M<F0@(W-C<F5E;E1A8G,@(W1A8G,@82![#0ID:7-P;&%Y.B!I;FQI;F4M8FQO
M8VL[#0I]#0HC9&%S:&)O87)D("-S8W)E96Y486)S("-T86)S('5L('L-"G!A
M9&1I;F<M8F]T=&]M.B`Q<'@[#0I]#0H-"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S
M:VEN<R]P;&5S:RYC;&%S<VEC+G-I;'9E<B\`````````````````````````
M`````````````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S,T`#`R,S4S-P`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O861M:6XO:'1D;V-S+W-K:6YS+W!L97-K+F-L87-S:6,N<VEL=F5R+V-S
M<R\`````````````````````````````````````````````````````,#`P
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W,S0`
M,#(T,S(W`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O<&QE<VLN
M8VQA<W-I8RYS:6QV97(O8W-S+VEE+F-S<P``````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#4Q-30S,S<S-``P,C4T,C0`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+V%D;6EN+VAT
M9&]C<R]S:VEN<R]P;&5S:RYN871U<F4O````````````````````````````
M`````````````````````````````````````````#`P,#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S,T`#`R,C$Q,0`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+W!L97-K+FYA='5R92]C<W,O
M````````````````````````````````````````````````````````````
M````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T
M,S,W,S0`,#(R-S`Q`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O
M<&QE<VLN;F%T=7)E+V-S<R]I92YC<W,`````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#,V-``Q,#4Q-30S,S<S-``P,C0P,3,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+RH@+2TM+2TM+2TM+2!B:6<@
M:6-O;B!B=71T;VYS("`M+2TM+2TM+2T@*B\-"BYT;V]L<T%R96$@+F-O;6UO
M;D)U='1O;B![#0H@(&1I<W!L87DZ(&EN;&EN93L-"GT-"BYF;W)M07)E82`N
M=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;BP-"BYT;V]L<T%R96$@+F-O
M;6UO;D)U='1O;B!S<&%N('L-"B`@9&ES<&QA>3H@:6YL:6YE+6)L;V-K.PT*
M?0T*+G-C<F5E;D)U='1O;G,@>PT*("!W;W)D+7-P86-I;F<Z(#`[#0I]#0H-
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+W!L97-K+G-E82\`
M````````````````````````````````````````````````````````````
M````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`U,34T,S,W,S,`,#(Q,S8R`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O
M<VMI;G,O<&QE<VLN<V5A+V-S<R\`````````````````````````````````
M```````````````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<S,P`P,C(Q-3(`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]P;&5S:RYS96$O8W-S+VEE+F-S<P``
M`````````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-C`S`#$P-3$U-#,S-S,S
M`#`R,S(V,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````O*B`M+2TM+2TM+2TM(&)I9R!I8V]N(&)U='1O;G,@("TM+2TM+2TM
M+2`J+PT*+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('L-"B`@9&ES<&QA>3H@
M:6YL:6YE.PT*?0T*+F9O<FU!<F5A("YT;V]L<T%R96$@+F-O;6UO;D)U='1O
M;B!S<&%N+`T*+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('-P86X@>PT*("!D
M:7-P;&%Y.B!I;FQI;F4M8FQO8VL[#0I]#0HN<V-R965N0G5T=&]N<R![#0H@
M('=O<F0M<W!A8VEN9SH@,#L-"GT-"@T*+RH@9&5S:W1O<"!T86)S("HO#0HC
M9&%S:&)O87)D("-S8W)E96Y486)S("-T86)S(&$@>PT*9&ES<&QA>3H@:6YL
M:6YE+6)L;V-K.PT*?0T*(V1A<VAB;V%R9"`C<V-R965N5&%B<R`C=&%B<R!U
M;"![#0IP861D:6YG+6)O='1O;3H@,7!X.PT*?0T*#0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]A9&UI;B]H
M=&1O8W,O<VMI;G,O<&QE<VLN<VEL=F5R+P``````````````````````````
M```````````````````````````````````````````P,#`P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<S,P`P,C(Q,38`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]P;&5S:RYS:6QV97(O8W-S
M+P``````````````````````````````````````````````````````````
M`````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,S-S,S`#`R,C<P-@`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS
M+W!L97-K+G-I;'9E<B]C<W,O:64N8W-S````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`U,#<`,3`U,34T,S,W,S,`,#(T,#$W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"\J("TM+2TM+2TM+2T@8FEG
M(&EC;VX@8G5T=&]N<R`@+2TM+2TM+2TM("HO#0HN=&]O;'-!<F5A("YC;VUM
M;VY"=71T;VX@>PT*("!D:7-P;&%Y.B!I;FQI;F4[#0I]#0HN9F]R;4%R96$@
M+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('-P86XL#0HN=&]O;'-!<F5A("YC
M;VUM;VY"=71T;VX@<W!A;B![#0H@(&1I<W!L87DZ(&EN;&EN92UB;&]C:SL-
M"GT-"BYS8W)E96Y"=71T;VYS('L-"B`@=V]R9"US<&%C:6YG.B`P.PT*?0T*
M#0HO*B!D97-K=&]P('1A8G,@*B\-"B-D87-H8F]A<F0@(W-C<F5E;E1A8G,@
M(W1A8G,@82![#0ID:7-P;&%Y.B!I;FQI;F4M8FQO8VL[#0I]#0H-"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]P;&5S:RYV:6]L
M970O````````````````````````````````````````````````````````
M`````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-3$U-#,S-S,S`#`R,C$Q-``@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S
M+W-K:6YS+W!L97-K+G9I;VQE="]C<W,O````````````````````````````
M````````````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W,S,`,#(R-S`T`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O<&QE<VLN=FEO;&5T+V-S<R]I92YC
M<W,````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#4P-P`Q,#4Q-30S,S<S
M,P`P,C0P,34`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+RH@+2TM+2TM+2TM+2!B:6<@:6-O;B!B=71T;VYS("`M+2TM+2TM
M+2T@*B\-"BYT;V]L<T%R96$@+F-O;6UO;D)U='1O;B![#0H@(&1I<W!L87DZ
M(&EN;&EN93L-"GT-"BYF;W)M07)E82`N=&]O;'-!<F5A("YC;VUM;VY"=71T
M;VX@<W!A;BP-"BYT;V]L<T%R96$@+F-O;6UO;D)U='1O;B!S<&%N('L-"B`@
M9&ES<&QA>3H@:6YL:6YE+6)L;V-K.PT*?0T*+G-C<F5E;D)U='1O;G,@>PT*
M("!W;W)D+7-P86-I;F<Z(#`[#0I]#0H-"B\J(&1E<VMT;W`@=&%B<R`J+PT*
M(V1A<VAB;V%R9"`C<V-R965N5&%B<R`C=&%B<R!A('L-"F1I<W!L87DZ(&EN
M;&EN92UB;&]C:SL-"GT-"@T*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O861M:6XO
M:'1D;V-S+W-K:6YS+W!L97-K."YN97<O````````````````````````````
M````````````````````````````````````````````,#`P,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W,S,`,#(Q-#<S`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O<&QE<VLX+FYE=R]C<W,O
M````````````````````````````````````````````````````````````
M```````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q
M-30S,S<S,P`P,C(R-C,`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN
M<R]P;&5S:S@N;F5W+V-S<R]I92YC<W,`````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P-3`W`#$P-3$U-#,S-S,S`#`R,S,W-``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````O*B`M+2TM+2TM+2TM(&)I
M9R!I8V]N(&)U='1O;G,@("TM+2TM+2TM+2`J+PT*+G1O;VQS07)E82`N8V]M
M;6]N0G5T=&]N('L-"B`@9&ES<&QA>3H@:6YL:6YE.PT*?0T*+F9O<FU!<F5A
M("YT;V]L<T%R96$@+F-O;6UO;D)U='1O;B!S<&%N+`T*+G1O;VQS07)E82`N
M8V]M;6]N0G5T=&]N('-P86X@>PT*("!D:7-P;&%Y.B!I;FQI;F4M8FQO8VL[
M#0I]#0HN<V-R965N0G5T=&]N<R![#0H@('=O<F0M<W!A8VEN9SH@,#L-"GT-
M"@T*+RH@9&5S:W1O<"!T86)S("HO#0HC9&%S:&)O87)D("-S8W)E96Y486)S
M("-T86)S(&$@>PT*9&ES<&QA>3H@:6YL:6YE+6)L;V-K.PT*?0T*#0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O=VEN>'`N8FQU
M92\`````````````````````````````````````````````````````````
M```````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#4Q-30S,S<S,P`P,C$U-S``(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C
M<R]S:VEN<R]W:6YX<"YB;'5E+V-S<R\`````````````````````````````
M`````````````````````````````````````#`P,#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S,S`#`R,C,V,``@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+W=I;GAP+F)L=64O8W-S+VEE+F-S
M<P``````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`W,3,`,3`U,34T,S,W
M,S,`,#(S-#<P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"\J("TM+2TM+2TM+2T@8FEG(&EC;VX@8G5T=&]N<R`@+2TM+2TM
M+2TM("HO#0HN=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@>PT*("!D:7-P;&%Y
M.B!I;FQI;F4[#0I]#0HN9F]R;4%R96$@+G1O;VQS07)E82`N8V]M;6]N0G5T
M=&]N('-P86XL#0HN=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;B![#0H@
M(&1I<W!L87DZ(&EN;&EN92UB;&]C:SL-"GT-"BYS8W)E96Y"=71T;VYS('L-
M"B`@=V]R9"US<&%C:6YG.B`P.PT*?0T*#0HO*B!D97-K=&]P('1A8G,@*B\-
M"B-D87-H8F]A<F0@(W-C<F5E;E1A8G,@(W1A8G,@82![#0ID:7-P;&%Y.B!I
M;FQI;F4M8FQO8VL[#0I]#0HC9&%S:&)O87)D("-S8W)E96Y486)S("-T86)S
M(&QI('L-"F9L;V%T.B!L969T.PT*=F5R=&EC86PM86QI9VXZ('1O<#L-"GT-
M"B-D87-H8F]A<F0@(W-C<F5E;E1A8G,@(W1A8G,@=6P@>PT*<&%D9&EN9RUB
M;W1T;VTZ(#%P>#L-"GT-"@``````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+V%D;6EN
M+VAT9&]C<R]S:VEN<R]W:6YX<"YN97<O````````````````````````````
M`````````````````````````````````````````````#`P,#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S,S`#`R,30S,@`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+W=I;GAP+FYE=R]C<W,O
M````````````````````````````````````````````````````````````
M````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U
M,34T,S,W,S0`,#(R,C(S`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI
M;G,O=VEN>'`N;F5W+V-S<R]I92YC<W,`````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#<Q,P`Q,#4Q-30S,S<S-``P,C,S,S,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+RH@+2TM+2TM+2TM+2!B
M:6<@:6-O;B!B=71T;VYS("`M+2TM+2TM+2T@*B\-"BYT;V]L<T%R96$@+F-O
M;6UO;D)U='1O;B![#0H@(&1I<W!L87DZ(&EN;&EN93L-"GT-"BYF;W)M07)E
M82`N=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;BP-"BYT;V]L<T%R96$@
M+F-O;6UO;D)U='1O;B!S<&%N('L-"B`@9&ES<&QA>3H@:6YL:6YE+6)L;V-K
M.PT*?0T*+G-C<F5E;D)U='1O;G,@>PT*("!W;W)D+7-P86-I;F<Z(#`[#0I]
M#0H-"B\J(&1E<VMT;W`@=&%B<R`J+PT*(V1A<VAB;V%R9"`C<V-R965N5&%B
M<R`C=&%B<R!A('L-"F1I<W!L87DZ(&EN;&EN92UB;&]C:SL-"GT-"B-D87-H
M8F]A<F0@(W-C<F5E;E1A8G,@(W1A8G,@;&D@>PT*9FQO870Z(&QE9G0[#0IV
M97)T:6-A;"UA;&EG;CH@=&]P.PT*?0T*(V1A<VAB;V%R9"`C<V-R965N5&%B
M<R`C=&%B<R!U;"![#0IP861D:6YG+6)O='1O;3H@,7!X.PT*?0T*````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+W=I;GAP+FYE
M=RYC;VUP86-T+P``````````````````````````````````````````````
M````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`U,34T,S,W,S,`,#(S,#4W`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O
M8W,O<VMI;G,O=VEN>'`N;F5W+F-O;7!A8W0O8W-S+P``````````````````
M```````````````````````````````````````P,#`P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<S,P`P,C,V-#<`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]W:6YX<"YN97<N8V]M<&%C="]C
M<W,O:64N8W-S````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S$S`#$P-3$U-#,S
M-S,S`#`R-#<U-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````O*B`M+2TM+2TM+2TM(&)I9R!I8V]N(&)U='1O;G,@("TM+2TM
M+2TM+2`J+PT*+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('L-"B`@9&ES<&QA
M>3H@:6YL:6YE.PT*?0T*+F9O<FU!<F5A("YT;V]L<T%R96$@+F-O;6UO;D)U
M='1O;B!S<&%N+`T*+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('-P86X@>PT*
M("!D:7-P;&%Y.B!I;FQI;F4M8FQO8VL[#0I]#0HN<V-R965N0G5T=&]N<R![
M#0H@('=O<F0M<W!A8VEN9SH@,#L-"GT-"@T*+RH@9&5S:W1O<"!T86)S("HO
M#0HC9&%S:&)O87)D("-S8W)E96Y486)S("-T86)S(&$@>PT*9&ES<&QA>3H@
M:6YL:6YE+6)L;V-K.PT*?0T*(V1A<VAB;V%R9"`C<V-R965N5&%B<R`C=&%B
M<R!L:2![#0IF;&]A=#H@;&5F=#L-"G9E<G1I8V%L+6%L:6=N.B!T;W`[#0I]
M#0HC9&%S:&)O87)D("-S8W)E96Y486)S("-T86)S('5L('L-"G!A9&1I;F<M
M8F]T=&]M.B`Q<'@[#0I]#0H`````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]A9&UI
M;B]H=&1O8W,O<VMI;G,O=VEN>'`N;VQI=F5G<F5E;B\`````````````````
M```````````````````````````````````````````````P,#`P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<S-``P,C,P,#$`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]W:6YX<"YO;&EV96=R
M965N+V-S<R\`````````````````````````````````````````````````
M`````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-3$U-#,S-S,T`#`R,S4W,0`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K
M:6YS+W=I;GAP+F]L:79E9W)E96XO8W-S+VEE+F-S<P``````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`V,#4`,3`U,34T,S,W,S0`,#(T-S`Q`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"\J("TM+2TM+2TM+2T@
M8FEG(&EC;VX@8G5T=&]N<R`@+2TM+2TM+2TM("HO#0HN=&]O;'-!<F5A("YC
M;VUM;VY"=71T;VX@>PT*("!D:7-P;&%Y.B!I;FQI;F4[#0I]#0HN9F]R;4%R
M96$@+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('-P86XL#0HN=&]O;'-!<F5A
M("YC;VUM;VY"=71T;VX@<W!A;B![#0H@(&1I<W!L87DZ(&EN;&EN92UB;&]C
M:SL-"GT-"BYS8W)E96Y"=71T;VYS('L-"B`@=V]R9"US<&%C:6YG.B`P.PT*
M?0T*#0HO*B!D97-K=&]P('1A8G,@*B\-"B-D87-H8F]A<F0@(W-C<F5E;E1A
M8G,@(W1A8G,@82![#0IF;&]A=#H@;&5F=#L-"GT-"B-D87-H8F]A<F0@(W-C
M<F5E;E1A8G,@(W1A8G,@;&D@>PT*9FQO870Z(&QE9G0[#0IV97)T:6-A;"UA
M;&EG;CH@=&]P.PT*?0T*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]W:6YX<"YS
M:6QV97(O````````````````````````````````````````````````````
M`````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-3$U-#,S-S,T`#`R,C$T-@`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O861M:6XO:'1D
M;V-S+W-K:6YS+W=I;GAP+G-I;'9E<B]C<W,O````````````````````````
M````````````````````````````````````````,#`P,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W,S0`,#(R-S,V`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O=VEN>'`N<VEL=F5R+V-S<R]I
M92YC<W,`````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#8P-0`Q,#4Q-30S
M,S<S-``P,C0P-#8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+RH@+2TM+2TM+2TM+2!B:6<@:6-O;B!B=71T;VYS("`M+2TM
M+2TM+2T@*B\-"BYT;V]L<T%R96$@+F-O;6UO;D)U='1O;B![#0H@(&1I<W!L
M87DZ(&EN;&EN93L-"GT-"BYF;W)M07)E82`N=&]O;'-!<F5A("YC;VUM;VY"
M=71T;VX@<W!A;BP-"BYT;V]L<T%R96$@+F-O;6UO;D)U='1O;B!S<&%N('L-
M"B`@9&ES<&QA>3H@:6YL:6YE+6)L;V-K.PT*?0T*+G-C<F5E;D)U='1O;G,@
M>PT*("!W;W)D+7-P86-I;F<Z(#`[#0I]#0H-"B\J(&1E<VMT;W`@=&%B<R`J
M+PT*(V1A<VAB;V%R9"`C<V-R965N5&%B<R`C=&%B<R!A('L-"F9L;V%T.B!L
M969T.PT*?0T*(V1A<VAB;V%R9"`C<V-R965N5&%B<R`C=&%B<R!L:2![#0IF
M;&]A=#H@;&5F=#L-"G9E<G1I8V%L+6%L:6=N.B!T;W`[#0I]#0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O861M
M:6XO<&QI8B\`````````````````````````````````````````````````
M````````````````````````````````````````````````,#`P,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W,S0`,#$V,#$Q
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]A9&UI;B]P;&EB+V-L87-S+D-H96-K97(N<&AP````
M````````````````````````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`U-C(V,@`Q
M,#4Q-30S,S<S-``P,C$R,#4`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*("`@(&1I92@B5&AE(&9I;&4@8VQA<W,N
M0VAE8VME<BYP:'`@:7,@<&%R="!O9B!0;&5S:R!D:7-T<FEB=71I;VXN($ET
M(&-A;FYO="!B92!R=6X@;W5T<VED92!O9B!0;&5S:R!E;G9I<F]N;65N="Y<
M;B(I.PH@("`@7U]P;&5S:U]L;V%D97)?<')A9VUA7U\H)T(G*3L*/SX*C,T.
M0!?_#$`K7)VW2+6M3H)9?R_#E]$QM'99T`B=A+%@+1OGD%`O//JH]>"M`'1T
MNS)OP_KG,H!P?5\58BY2^`C`B&IT"(OI)G[4^H&ATGWL,H5*F$%A]O>`,\0<
MO(WI`6S\'*$O+3D_I8UV^:^%.\!7]AM::B=NUGX>ENMR#/5X`JMW)2F8R`A7
MDVR'&?51<RJ49#(71I5C2LR&^CR#[&RJ6;\YZV^Q?T5\D,4V:QGE).X4KIA*
MC=V*-EK%"OV&LJ^AO@>H'P/)LT#LT?<;DAF>WDF]"X/??;HZ%\_!1_:L+(?L
M,`G45HTY;'[$/UP9Z'"!*P3QU92G;J1E$&S+<C!=30)%0U1K?RT-&[T-(89;
M,\!H//&^1RJE;?DEUDXU2JUDCT12^9RT$4PVY1/20)[4Z%/7RSK=^MU-KDV$
MZ4<6!<;A-_MMP6;(F.9^8H"+2/<2?%,N0"5+F&]PY<I5]_CR!B5DAWY[;"@G
MFGCDA<MF$__!A\;OX6SE"LSVZFQ>!*-;:),FGD(D'4Z"W$F\]\C8."0H:-S?
MA2?CJW[I1$>I8Q+I.S"LW+'F(`@9<):1G%J6C4+`DC8A-^$S>]A(F^)>'-VY
M[%KDY".*KM&?7ECV"I#$'9Q)T(C,Z"9<'J<^\I44MBB)GG1BF>+QT%'6P>GL
M0]",DY8YT?8D-K[?7!;;R,>6!DX=R-.\_*!P8UQRL"?5@GE4PH>RSXJ-5RE]
M";_QAJ(FL:Q.!%A-44J]LRFG<F"2.#S6,B:,[,CAIB+#XCH.K#[]V8AF+3N=
M,^!JM\(Z&Z`3,.1-([@$!@SQ^&V(,'C0`'2].<"'YJ&B5+E`]CY_$[`?AQHY
MH8.OD^"&LG$Y[9*`/Z/05H><UZ\,3U+[0P*1$$T4#TJ\#'_)F:P$VO8<1PK'
MW9].WO;^Z&"@2Y0:$Q`6GRU$9!YY6C'W]YJAL4L_"UN/M>^PM6(3>/3T8Q]:
MW-)5V5!9UQGNM+=V4N7C;HI.C[+C@%PUX.HPVJ9XZ/YK-%<;2AXY_&C`D<Y4
MBP8.<=KJAQ.J]GHG)Z56&UB"N%@SU'XPS9/!)8^73@7.MJLH9,F^0K;&3XG;
M0:FBSN.C?OEP,)T\+.!LK3]*:A1,@Y9Q(OHE@,'E2YKXH1ZLOW>6EDS>"F3G
M.@\'`P,4Z@(@SS09/#9`J:H-1OPE1W,P7;5X"Q(P;UNGKOK8UXU%?9O[-+B+
M6$TKB@LM%<RT-I4`DLX<^M*VEL2VH'.5]LE)9>=&9=:\>O0,O/.('`B<1O?[
M8`JQ5A4*]LA#Q_(_;605NP37+MOV>+ZV3XQE6.0;WU7]'A.48M8+HKRB*JH'
M<04HANK]Q!Y.A%M&]5>_=F"412/Z6?@+R_`!V\?`WO?<.*`"?.E2A2@)\U-Y
MV6/)]6621U6$E'(P",HL[FBV_'#5LF*M+-?R^P3-G]/5MS:3=@-N/?P2MC0'
M`V2^]#=9)<X`/8\@,)MV(Z]`5F(M2FTI7A0E"7^[('34_X4M`WHX+M`L=8C0
M@?O#U667RUD7"ZS,P4\7J.+$:Q_A8!"0-I6VN!/ZW`SB6I@AS%#-KG,!VCFE
MN_AX,P33[R#N\5S_9/K>_@G[U9>\(8+YAEFB@-6`+8Q*8%/S@1'=UW?Z70E0
MR\.SB_@3+B%C._F^'GF>;FQ=DKC*]U/._M0%&+&%Y>LDN4%&:<R[#KJ/R*OY
M1XK%</^)0M?HW\HA."GSU1IM>-"CY3#<K#Q\*W*17W);ZHD'<>"^<=T,3.S9
M/@%D#P;F7$I;?O)[[.[(^]UF(,F[B^8I%7>`8_E%D;QSH3-A@'_'?%I?'WNG
MFVV['R+JH0@:7Z5>U3A-T3'H28T."784&0Z!4._<1.Z36.KBI!O,64\7`2P[
MS>G>)C447.>I#*:<'7&(/I.0Z@)TFBZP?Y^B2%<K,3C\<7/B0T"6KU,;U\&`
M'?CP5(']D@$AV"E4"Y-N0A9.I/VEIF&D7O:R';QSVC<M5K/.YT?VY^0PX+C@
M2!%2M'\W\\QISP,*DJ]6T7X;C9?V)]#4@TF2XLE@M&`N>]7L37A')%P!"-A`
M5D4BHV)$,75_M_F96-?I<?J'+\11U';6>-@H\$20]3%-9+Q8S?4(UCX8*@H&
MVEUM@^G_YH%HV(%5M4FD`@]`R[&B9*6Y00'-*9.L/+F\'%F#<C9(4!+$T<W=
M'Y(<&/D^YXQA;Y]D"W`[A[A\?)F'!<.'2ZK-]3$F>F'YTG@S@,"/3?YDHHH/
MR5WQJ\5FNE[G-.H3>>6TG1^M8V"HAY.P?/"_X(M20#HS*)FZ"4+:PS6;IQP>
MYM5#A2SM?3]$YS)N)^JWEE9LW>=`XW5?R_OZ:E'*V19;^TN`H%)?,&'J+!Y^
M11TG<@W=KWC0"[2JIB=2]^:!KZ+_)@OP6B];I"H[!;4VU8?E>/"):D^\->1?
M1)SY'#CNSSL>5YDRZE.UCO"$O^<JP#6];Y\U-/9B,!/IK`^D>+T8[7O&9965
M+-I\JZ5>+@5)(CU9(-X[ZX<[=?%B:HU"@IDPPJ!P7`&R;^P^E++9H'X_*"ZV
MV=\=-#(<Z`A%"$C>79\@*]E.BK/T09@(E[GF3*"-XTK08W@RH0P?'],E?/Q9
M7MP[;]9<^,'Z6#D4;/Q_>&YG*.>E]%LJ+1%#BR:FT$_Q6M=:V6LGZ"%@WW=\
MI1!8P=>WY&1R3K.IN'/HU%F<;T9I6<@\2YN>Y)K\3CF]4D*N\163BT3--/GY
M;Z.8`HY0)@8.QF$I4FA_H>*(B.5)(E0U^N"2I`L55S/2D0E29:6(FZP#GW6J
MH9VV!AL5>!X]58LJZ/S;(YXH2)A]AT,:>555V]<CMD3Y3X5AFU,V-Y-<^J>"
M_BVV)RC%O"R.O]KQ=31$K#2`!>QEVHLPMB'`LK"!ED>5U6DG@%%_F`2U;7:0
MCYUQ7Y=1?'"R'TY=0:D*BUY:WPRX!(AW\_X^TA5NB6L3N+:Z0'/R#F(CH.D%
MA/?[31Z!J52>QVN`GQ<<K=R&)2">"!_YE:L/">#,&_J<@VM(<G:L@2TD$&ZX
M*%IZ#1>944V@N&,E"%_C-S]\A'AR1US.`(I/O`9S'&NR!CS`/=/!D_D*@O9"
MP1E5KMAF@6Y6]`N$;RUT,0CC[*E_C-]J/<]S#FB)DP)*'AV5T(B;L/!7.M6Q
MOE_VT)BH?N>]I:B5/!&[/F5/8'@X2"8-\BQ9V^6XXDEI9D2W>*>O5V=5P[%/
M8*H0$:];)^^C?,C>VEQWG&%=81D=B-#J9</N>,/^\M#6H%?/GNW"A2W![D),
M,(@;,!BVY)KA=-V$%YJA0F05-JK0Y55F&Y'JU`C5?=?A@HGJZL2^?@E)'%=Q
M,#<L>718E/]#*:JO&W>4-2$XZ*1@-]2[5GW=0?WE*@C$0%3/DYG0#C9T7FRG
MA7PTL*QG#6?78<+!I3CV/+<,'$J\S%``,7W?W"@D"K)`/8?P&0*@S<X3$P[D
M<2HM8S/!:V0,79`3486SHNCD[.B317!HM&NM0%J0=ZR@CJSI>1!W>9C>@NC.
M]"?_YFE:S2I53*M?=%8^<!97P-4E<_C\"("+*@H=<MM_LUE$C,5;/^.GU2.3
MB`=$?/O#7D&^`F.B>4>*TV]DN6B`>JU.R-D!X:S._B3IWB>DKD>\P"C2B$=1
MRC[?ZDW8_-`(,_D?LZ?WV,-.,DCQM30UY"T[?J%=#\V/"PGF!"V333''PY8&
M-&:;CQ1A:PE>14VM!(_)%^UO_+AK7DY='76NN[Z./*1B)L,5]M86D:6Q]Y?'
MNPTFI&0(T<_;M.B[>_G[`06\9D5+PW/[GO>^$KFE)FGV"9B.!B7<'+D_NQ7#
MZ6%9LU\E5T'E-^_-3XP*5&WW:1RD4XN.N%L1%?J^F@^`?@).956VJJRZ17[@
MBNH0AH\=8$2VO>.-!Z&-W?;9#)+ZLU@3A_#>,9H4TFB2SM>Z[^CAI\2Z^;1J
ML,L(#/??`?![8.+J"B(B2P8/9;_@WJY)Y[9#[.<T\YF&1']62HM^ZMX%X=&(
M/W=%,;!$05)_[X`RH?S8<WY`>`U9.BB^5'O=\_1^_>+VU724@B?%3,_M].]>
M7?0=7':AGQO<BHV@*RG&[VT-&M!EA9^GC&,R,E51S+#K-*S@2D*S*=AMO$\0
M\6#!*7B;(MHV"K?]%\UER]>=O"`D^6\#C'D""<,P-EAA?&K;B`W&(@G\`VAR
M*B-MG)$NM_$*7>VM^UP!_=1<;O1E.%:,U79FQ<3\04:X[YRPWDRRXA^=/"/D
MS<1APZ^050TS;%?3V$Z9FZ<0F'^UI5E.)!L8T6:CEMT3Z&RD1)O5@<PWI0E5
M!:E3Q"60$]TCV+P]_#>?[XHJE[X<N&E$UC(Q^\U']Z9"B8+5]._U0Y1U(BDO
M$Z900P;UR^L:J'&=)CMQAG-[@LG+Q(^@AVNNIWTN$!H"SMGOON;OAHS*Y*MD
MFLK?#E!#&OM$/G5+B]T=V*5L'5,`/-\7QHZ!D'C*$@(>#\@(1X?^6P"[\M-N
M&BC:D8#'M'B*.>H0?GMZ:V\UERG/VLN3`!#9F^YWK0K@TZ`2-V&TG_.PT)R6
M,P&79@[L)A[115X9K4S7HXX5?$2](&RZR0PU7&NE=GZ]*W9^[84Q-[8VM=C[
MJK26E-!RTK=;HGW%1)I2AZWF+6VY>Z68<)#?8=KC:776N_"G1#UE"RDR%J%\
M3T,F(MT:#P\_/1I*=#ERB_%Z2=ZMUZ0**I;"GV2;/R3,H8RB\T^P!`GU5H01
M2"1O;;6D9%_C)B5Z=38H/6VTR(EP@U&>LZGU>W=<AEX/:<'-<B!:4`:F`^T!
M<08HBX/O18F'_DC2_8FU\R(%I!?-$G*B<=O7``$Y>0#';H40E=XW/0N0CI8A
MB`4U8JL/+LPXR6.HY'I`%I-4&UP:`5[C+A;<'SYO(LDKCL^&40`PL3O6J05#
M$%XO>&\4PC-G6O:M/E`7I^^<QJS56A$5@T[KUX7SA]<1U92S1F%)LR\P]C(_
M'6N'QJF*\9.%@)]D<^C3#0\N?.F)'JCD?37JBJ;[];M-PK&#(T@T7[3&<VY?
M0HJGN\!?L7G'+%9(C3)0NUWLCM5HACGH+5-?RR<T\7.JZX/4<R#Y,F_A3DVO
M"N-Q]-%S_"L$/OE(G7CNP*8']X_X(X@3)!Y,UKY.@-Z!'K!9B7"MR+?[;%YD
MR.AEY/Z:2:4S&^C7^$#@+TXD"Q=0G>(9M!SPG?$[90PTYFH=>:_8J*HRA!!T
M(2T'\3FV`F+W$M+%DG`4'*V8,FLG5"XII#:\I:@V[)70W)(+51F!I"7V["GV
M'L;P*C66BCD$W0_&$Y^-:UR/L+8('<J,_915Q#<##)F%R\G.?E2L?"?:.LSJ
M$"S&EF?NJ4W1'Q<'YHFQUHSQF`08++&@<9@JTO;XH1E]D?USTXR&Z?RTWI4`
MA;];-L=DR)]3Q7DCC<3.Z_<?5BB!=G2I<,KQ$;M!(M.!H5_?*C7_^4)X?WZU
M^L0J5^@Q+(=PNYT49=G3Y0#8KT\E"_78K6_ABAC'<QUYL@/A%:P)RO]8Q7LA
M-\]G+\,.B*SL7?@V3CQCN/I$<XA&!IPG$!Z*<P/;?^5R8J6[-S&1IHML`49@
MK;9-@G&XOU:,-(PYFRHI53B.&-H]M@`<CB[^2N5H=CKMH&#`[UKV%E_";?`O
M7SC#D?U@Z?Y@Q,RN-MNSZJ_`F22\#&A+JX(0:+!9[072`*'&Z@1QNE!W[;+(
M0"(PSC[A(I!,0*4X7?-5"!FYZC&=COAR=\7)ZFU_T>[9%V8L`#O.#X1-3BBO
M*D?X/7V"I2'[<!Z>N%0`_88C4]3ZCHN_C:OT5EC,+CE'L1!*OWC1<$8O"'R-
MX]%1B8'B-9K@3KO3_ZYH])('(!A.LS0CCFAN^UXP[*F$XJZ[[K]O7Q4I#,'T
MY@UWLZ;)W-``6>;_QCIY"AFN4F:2`I_9"RR%:";Q,O-DSO92",#X=E+#<([X
MXH/BY%J<A*`&LG$J-62FL298#4@0E@U\@/]!\U.M8P+(0"D6E2*1.FBS;>7;
MHYFO)"\(A8/UU^*QOML"!T0^#?.8/,`$S:'[PVJA0C$*F:4$MJO42(J3.I]J
MP1^OQ6#),\IW9P?HR@2A!X+2>P_RWQOB3^[%;Y[$O=-!#SI#^EZ1]G3*>P$&
MF[37G4"-SL?:X=\_EYBI8S,MK`\@1;U%_>O`H.G"\P)<YO.K6YZTJ&WI`$+2
M]S&E:&Y<[]KLB*D-XOV#J>5_F)4I/]V8?9^BTP*WEKH"H/5TQ?'^T,R[:%+X
M\.F/#(A?)&P[4H8`^$O##YAT3S0VI1#_U]H=\A'%_BL\5O"8!V3FIVF6>A2>
M0*9@=)50[EA35C,QN3K[-Y8(>X<]7:2><_)$\.#]$R_;1KQDI9[9;/7QDRWN
M43[DV;K8`;,.*&8T.]_35W+61VL^<L6H$J\0DW+9CH<W3;!X$O)SS<Z9)";)
MC"<I!X^`:7!=!H,R9PV3'-:ZJ[W>Q8I#`1%\3UP7S8J4V;=3O4(`'8A=5_TK
MJ0T"5E%9&M<WFOE/TRDBFC$Q!649U<#.-6WX:,`=EU*7:M0J=0KY43LM])W7
M4CZ0FK@,2NZJJN$!XF97RL(=2BSN`$H+3V&\A9]RU]F/8X=?0'L!:GJ-U#4-
M?8Q7=-5F<;NF+AXX>GX[ZS%RF5?^"?UIR72>%7&UP!MG"J(1G9]17=.,Z-H/
M>I`RM?ARP87'PC?RO0T[MMVS=#B`3M`J@<:"/G=RRX,ULTM"U4AQF5U[*V_?
M#N1P^(ABW\7E*O:P!USWC4I%F#B0&TU*:<[S13&X&P'H2Q3!D%^YG36:\_U/
MT8*B(M)OX`?T?AJ#EPJLHA=/?G)@;[\L`/8>)X`>JX4/+7N%$!HW_JK!99I>
M@"[XEI.U(S76N#H]8=P9>"4+>YRS:T^-LAV&KO=KD>B=GDC<_8Q-YKDX[B_E
M1K!`D2C$=B;P>W^C6^F3@ZEG(CV65F>1W!GV%$_\/'TSL;LM_7<\4M'(KL(7
M44/W/,BH1")%3]49J*V)P19E+DX.XW:JA=M/C]5#&X`%@@4L-Y&1`LH:\C.O
MO(!9#BXOYXC:$,H&!8+U7R88S?!W#'E'<_[HI9P8:)CF7+\1_>_Q8`U>2I'&
M8$,F1V>&C2JKHZZ.Y'-#K>U8'TQV3WU:$%T?F#_P/"2%?JE@GG99$+,E%FL2
MAR7,RK^-U+IGUH)5+JF(I%H"[X__&'D/_^*%H(5PYW'YU7=$T^%3T2[X[Q<S
M7+3/&'#%YV3.W8LH##\$^0.CLR`*IF-PZQ;[_!C[&^4D!X^T%4`_]:N-?HQG
M^DT-(]U!G^BM]L"L+7*$.JUT1/!CJ(&:IC>TS-"I3E[$IV:L%,RS7-5)K+<&
MR)*6UD^0AP]R[A2IZ+[TWC)4*YCYP#,#W.N@MO@9V<*.5NYJAAG\/&9P'@W$
M`9]FQ!VF.M5:L9SX+U`EL_KC_GL1-B@'CJ49M!23?K5BW+[^FZ?!'W'9XD?J
M5]DJ$>SA%@H`X$WVD;>^%?Q>Z;W27M]%NO![L7Z^^0VSOT4O2HIPOO"R+*I]
M#"HW#:]H0QV!"@_#C"5([I/6-86$M(KR`OXKLMW-V/MGMC8-^NLHWZ&[`S,Y
M:G]Y+7`5\S3L67;27(AG80P=S.(WN^\U!L,V:)6:4B_>K533A>(;:=CCM:,0
M(0(RD(2/GTW\TAXP..%L4T&H%=L8AMY*$GF<8%*OSX-L]L"GNOSE,H8_OX`%
M#<R4,*HXJW6TWKO*<!X=DZ#ZA.D"^?<,?V6G.-.W%4V!N1[Q,#M(N;^(6&*C
M56)JDQ9I=PX?$LQ'*5R&J.&\90.GV-4LW<("BYB6^4GOG%J7[?&LS&^6@DS\
MG\H1WFZJ7&N[EN<6P)P76&)Q]QLJ3'@E_';.LBG8P&_JG68$-KEO<J];5.L<
M`K+GE>.N._*U)K++=0M=,+(&(<-1GE<Z#U6`^H:^_]I[XJ@(9R2<I<G)6R_>
M`GFD_7Z28X)][8?22]]$RXH[-`ISR-[#.QDHVU3(`,U1H`&>:BU6#WSTZYAH
MCE"0\&:8ZHAJP;0YO@BB'EOO\TD)&?MR?"^CMCGF,53<OW3>'<0W,EV1N*<Z
MW1C=1R:STZ?D#@R->:=:M^RZ-JHXY?FOQ^`/%58VSXD2<<]=N/UL%QAEG3)*
M`J"+WN]M`$8?O@IT1D)R!`;8'27S-$)%I*W?#6DU`=]H.;V@7:(%Z'D"L/<6
M(.T-2`=>#'%Y-,]/;Q.L64;0<2.[&G4J^>N,O8/:P6S)O7^R+[1(<&^&Y6U$
M=\A*+EDD(L\]6[*/=8F4X/19NJ+6U?'LXFXY46VW9'S_F@T-/9U*"(K)DW<7
M_BPY;DT5`(2)4JJM,0G?*1]6;?`(BFQA,>/*N")U[:,DHFP;>Y\RC<+H.C'@
M!S4`Z[:'BP]N:@%RQ".6^61Q-O`8E09`M0$+O*E2NA.A"0ZPPJXB0,QQ)9[+
MGJFNSU7!WW;Z6)#`%S?CGG>9?.^6+&_H0:I%D)8<2;MMXGA*G$L&LI^+SM5[
MIFK.L'^CFM=+X)2W<$PM4!>)>:PDL(L@(@/7^]E7PW4:.3GH4%D"5/<,@D;+
M@/5?+C%2\WP6*1;F*]JH:PO-"),74+MT4X1$CL).;`S6]:GO_P;MD-+%U2'?
MV>N(Q\-2_-\)AS4KCZQUI)>=$8^(:RS4[::,LIRJRR@7XBZDPGXHM'YJZ]P/
MBC3\L<(-=<UL:"=29\O!UF3A!BIL21BBJ]',G^DVVX_%J[>;`T5C`9"+>S;.
M!?A>^')YL#4A8JX0X4!?`JO0'$Q:$*)]"TVS[6&@!4<ROA@-S5X*1+_C4?[Y
M4LWESN7;@E@3!$G1TM'/%.JU.N`D#OBX6J/>R;)6B.J0QN:5[@:7>O?A9]JE
M8M2:1OM@[UE!3I(%(2LTCA-1'3Y5;Z"W,[>1?-[HBN)59(N?[L5J6J&/*C/W
MT)(YWR@_&IWB&`:[UDV@"Y71``':#<;2M9/Q1CR)H%YH>4$W!K\D=OCIT-WP
M8-IV(7GL)]:7<7X:;\=+"B',6LG.0,98OG?C?0UCU(E,VA!4?/XSY=J>1/>)
M_)OIKVP5Y2HC9*5<C\?]I=?L-D[Q@OB>($D-6Z@+H;K\ZAQ&'ZESFCBJ.2N%
MB41`@QX3N].RPVG^>K/>GOT&,H3;/W(\*GK[>A<#3\73K<39*RR<ZZ!53BU2
ML#EPX@#*?+KNL8]V[BUWC8Q:S,%`H@SP$5R'I[J:WPLM35]7;C)X"_Y/U6"$
M#QQM0D*%\%M0R%#BTE%HD8=8<G!4(^2R2ICHT;P)[*54HXAPC$_>(N\.J(`%
M-K^MY3A\ZB'51Y5Z#Q)K5&,+)(B]9H)VHJR]F\\$VI0J'<1JN+YYC(*?UY4R
M'?@+<_Y<&]$<7^0[G%L$TA*U,(70AJ9Q54FF6WEFT.S`LI:9<^J18=Q9L*4"
MMPR4R/7\X,XD*P\S8/69ZYZPBS&^4EB+"[#*@O'UMS*VP#UX/@L!V]X(3Y0*
MIRZ*2PSO)C[P!2&GU#OA!PLS40Z;7;D6?$=-IWYSK0,PG>)GGSWRBF;V'\M\
MF<L?,H-/6!=-(OJ!L,1HJH![(MZN?@DHKR)&WH;?^6^>F%"%WH#83MFVQ'N5
M.X,7&<$9X!6XGJXO'[D(T?<A]C(W`[,2LSA\NN2'@]:8)TG%VROQJ8UE`IGW
M.F!<`XC&AJ9%P#/07PY<J%0M&2(O0".QV88HS+LN:1`/8%$CC7;_6\[C$W++
MCW(Y.7K+^QC&#'T9MTB<*&NVJ$.)`J'^P>XS;-:.W]A1?<]7']7VM=:UTCJ-
M2,(EG>C<#?(R`J/\JY?KY)##HVD714WH'01-=$!\U/9X_K,;>$9BWR-/K4IK
MKV4XHTO_H4B>\.]8(3@DHN3^7:+<W<,V8K8=R12VZRQ$H-D7&WSJOR0.(U[:
MM&F*>G*4PH$SZA:?J.L@%2[$K\.:@C8ZZ8ZD?`4,.:V%3`UOR@P1E>@&^>)0
M5@DO$#;5WDA'0?RZ%UYQ6/)0I@!!50O+MRU=6X<P6KSN>!P!)#.3`8H@%ZM4
MW#>N?WAEGH[J-L6>O]14?DY#-G]:TRCV,>P:4N\6-#G4$=!:JU,LJ7F:]BOD
M$$-`Z67&["(R9DFL*)SK/U._:)ILXCNA'M3[PO0`SH?P$=/I-DX!P!M=^0%/
M,@.PBI$?\%Q*^8H_YBF_]S"`"-.F&+?<K\R[QI2?9QN/#:^N/+5T)()L;8'*
M].<Q2\B*;:D-O5DUW!0),CW/BWDM>V(N`/;)V'"0W/EK<D&WT\EU(U>48U_3
M4NA0LS?NR1EK`6;IQ6ZT0SL8^@2X($L$:FT+LW*9*L(3O/8?_1&L$";91J3P
M-G^'LQW-OE4;9S@?I(1',,(!.)BY6T%`3F30#P1E7FD7CC&0@D2?V:D_[M0B
M3#`,XV)9P&NR9+,*)Q3$QW8SRC*""Y74P1*#_D7:BZ"W4<0A%GJ*'QC%XNTY
M\8:5Z8J).YS'-1,G?<>;(D]F(E'NOA0T2\4U,`39IQ,-`$<&*YJ"KHJ[/L4E
MLTD'Q@^6BZB*6&N3"2,]8^K#W$&%&TOAYD>0%\X4]*0N;F-$H>C@5<'1-X\[
MYS"NJ49]LC5(F?C:)2X!W/@Q?/#SN%BH6@CAY[/ED>T[>Q.^@V$SOGQ?T+K\
M8??D+Y4"5)T_[8;I4N<"*+VW:I<H?E;-;.@UT)KA_2#=4/5^S%UU]"Q:4,3C
M2,$510VMFB"EC,!;./V,^1/U$87'T)GE=!^\'RBQ&/PH8-;*&&T&J*^E51QS
M(#=08'V!'8TLQ'06W![JMQ@.G!RPZ=ANRF;@?4L*UDHB$_CH.[G^G'1RB#^/
M1-K(5_!E-4@0V%DA8D$?A>O(H!SS@(YP>GLVLT0PE;T427=8HO'V(E.P56*9
M_QUGL/A$__,T\<*\G@7)#6.X$$>\LB\]4)E!1"`^Y2]).MK%'"DHR5RB<0JQ
MVR-FJS2Q\NL!]TL55&[*,GKZR)"@4[S[NMI44A^>1M?%_,MLF"6W;]:2;:Z@
M?:C$M/B3M86:!G1S6QECV)%H/NS7M68_^F2E;Q5>(1=`>>SZ:^'\T>0-6^2Y
MC"U35@6`E[B?0C,PS2-L.\]I\(!K#>"1G_.XJ`-93?BC>B;V'-;!ZH&`/%<J
M()@0MYNZ30!TU=`AEY]<ZA>SU*,GQ+J(T&B`57%B`M^?WZ*.+77UVW84&5@9
M)?/QB.L&N\DF;'WD)'/-/NL^G)'](V6K6)O.]N/_D41BQ;6:4:Y`XKZTQ$;F
M$W^H56-Y=7`QQ)(`G^^C:7]F@[VZC6=PU'<`+0N._8O*QZJN,Y.[/A12-"<8
M8%W%KG#S_',-^U.[0(M:%&+STN\*Y3.4711IU#"S+'=PD5QIZ&KE(Q2AGA0>
MQVT11&Y-U(.JZU1]!;2R5,6O'0PC+NI8\N?**W>+*4,?=AY2.YLP#1":!K,\
MIPBBZZQF7+K7T,6[<=%&#D&Q(G>*?Y_BYOMWAT##6KB38+&P&3)$,L7VI_#`
M26JL2#@M,8Q0&];D%:VKDNZ@(:,T)YO0Q.62NYS2Y^Z.H,CANV-*5`H=9YB$
M6?*JXRZ^,U0+DL]VN4KUFZM2<6W$>JA[,7=Z'5VD.?;7R@X'R@)[>08#2)1L
MHMQ:[@P,_8R7,=1F+$]6V06@V;:3&XP:54HG2P.#?/K/O99$>O1M1-\?.SAG
MKBH_<RX]./A:/^VFBXE$>CP?Z98,9_)MVWJ^B&18&CH\]=W=N$;>,'LJ&<FH
M1ZS[0$F:N3E.+<:EX58FQG&AT$[A4T7F8!9">EX/ID(/AYUB)^Z4D/'Y#&".
MPN(BXXB.RK_<W/4S7:7,(6[+("P3<LS(\.V99_28EB;.XH?.P.A>'5C"F!8"
ME]9>`R3P(.?BX^:M8P8TF4<VCAUJ.2>?$1$G\-?$YQDUJHS;N\NQVD78>RUN
M'C7@%./-$V+.F<]QD$1Q*XXV-@$3X9ETD]S&=-U!ML7S;;%)#QS"#"-!POX5
MP.H_00*&:L\3SI:-W(G-/E32B6X_PL0X^')D$9;W6BYP\PK39?""R%=I=?SZ
M+&JIG[;,<XK@YX8'!\W:A\09:4'3#1T);M3GYUX.X75"G711%U"WL1?7BFA9
M,8HV;8FOJ;V;V&=GFFOK'X`:2[L]T*`6XS]CH%SP(%JGR]=\<.W7(Z^:.2SF
M^@N.04E#$&F?X-@]$GFJ#?52(4;.9A5`V34Y,.N9S</*2K(A>[$>$489XFZ\
M^#+TF'Y^6`*#H1I<T4U0Q1_83'C)T8\V:&_H]:IORBAK-:VPQ&4\!)UC-7&+
M)E:S$^SPS1U:W*!!Y7`DE3HK)(IZ;40PNC7<=[/W5\1"!W`*)46:5M'C6$\X
M_J%<50]<C?U6F<N<&;[A/-D+V74/L[KS\!+1'+GE98+';XS>?:V.WUSC7+N]
MPE0R!M)\2S*P^#KU$R$#/C)(W%.MP(G4Z!>[8M+W8ASW'\>/86Y+Z&E!E(/8
MR1/+IV,\":KJTA-5B8'G[2M2%!FXK.WG`\\C9\))?U!_`=7P;2&];Q\VP$,T
M1;;$!<Q^BT89]!Z,<=BK]-MC>EN(`AHUZBHRLL%)"3HA1?_FS>0AC>F9(V%C
M38&4)N(CZB%Q4[>9LQ*!_2.V65?<K!2/&[I)1/GZ\V:);,*:.<IT;A82\B^;
M,FD'.9*I^!&%LH(L<?`XG-QVSV%GR8^W"&39QOK43"2=2KM^_P*'*GJ#5*L#
MW1ZROU-YET\+(K^OJKW&N9H&">O8W$AU_U90CKV8[8L(-+KC4HY=LD4@>J--
MM9+NLY:A64,CF?0J6+SQY]!P`3_QU#C1U*WP",@X]F8`D()R[A9?BE#(CZ:;
MAP#\W-M_PC;$+SE6*W!PD4_6]FH3["8)JHU:Z&^-K*`^G]R&JX4B-4W)VG-V
M<1E+1NLZ*\U+IW%C-LDFV13E66>E?Z@Q%LDS@I0D&L@YU]59$LTYH5<4P4A.
M1_2OY9N8(59?8>Y/<C?IIR6=[N-MP="0:0]8&HX.S[%.4W/X]SQTGW;5GX"O
MO'=-J#&_,U'],G"<^.7\#%A:RZF!:MJ<]N*.EW$[GUT.Y!,;_HN)W*J\;')<
M9:^N5^$@TA'@+]&_FX>=-=9'5V)")],J\9[;3^1J51R'OV5*T6F,J@B09'X'
M8VP<;(H!UY1^A\PB3051H0U>\':06:.%GX>5SN!NH^VB"8JS1`:ZYC5X)O>2
M8=#D01C58IVUP2RY!`-O-N1$HSN,7>M7WR,]$^>!(&Z)&7)CMH5)/$L<>^51
MYQ19-IM"+`ROZFVJN6T5NXOWGJ*5[R")=1W:BKG.$+D)I,CP#*;\K'+-G@!.
M:&[0]ZO%3-%`0.0/"YG+OY9BU,"W8AT:'/>^C=-"6Y%C"F0,;C%]/W1`-(\"
M-)MLM=9FYXW0(H2$1LPO[G*1&2H.K2CSND*%MIW<7^ELV@H[YQZEE4]Y(O1A
M,FR67[!%7<++(5+@'#QDP3WF=7NLK)'2Y(3SCJ:BW*KSCVYC2C)J>$$HL8@!
MKTQZQZG#6/U./,4)NPP)QY@P=LQ]WUK(XF8)?_/$VL2M#F)!X#$8Z6)5@Y13
M[HA9??R$<](]L8?<&<TC:"]YX6D-,9:*6R+.-#6_:UU]`2K:OXD7_9V;XQ\!
MFQ2)$J+S0&>T8[,@@]Y=DFP?N2K;UTFSF@-1S`LA<F<48[H$XQH>\OG39OKX
M`.6B\9O=>=!Y,>\T@K5%+;$MO+V-Y*Z#TZY;=&QILUTDR6?P3HC:3/F>OJ!<
M@^/RX@[8:<T=58=2#"UL,%QTL6H^H)<75W::.5^Q00=R$Q>/?N%[<X\4SMXS
MH0D*^`M*A:K;E(603_4DJTM;XQ\F=.\$OCR4UU'Z%18"[+!%7#$P"06XCP]K
M:Q25$T'*`;MI$G%(_=G.#LZP3>,1F'AZBJ.C2-GQZC59&NC2^)Z'GH64_DPA
M.]!5N"F70BYBT]#XQ)X?@L&NU'4W.L/*,G;-$5M6@#L)TT:6I-?W;L_\%E5[
M&*\"=Z7^,;03@LB,6DQ*?$R8\(ETPPDZN!G9=HF^0S)(R!WK?P^U^Z(K4.,Q
MD3&<`]SN=!D=;9=1OXV(U-I2#GP(@J#;E<7+OR'B#C6'G@OW2&*J_6CV8Y4G
MMW$_*;NGY[5IE18RGQNKW*M)1]-1[G?_AM_,Z4IM[IYP&^:`<KD!BF@T2?""
MC:/<^9@6\MTO4OD%?[CLR/4$$U_*\0S;ZCD-.R1CFOBC&7>!`6K+CV;'[@3Y
MFIO;/@X?*%`U\@WS-*Y$"^;6TS_Y3"G3_+N^S-_-\/$;SHN'EF@$B]2"QE9X
MX&'[UV)(^&-Z,5*T4:J95Z*@=+"K5;_M;!W<$(9HHHX_I\SM-7?Q/5;Q0JUY
M]$BIM]6MF%$0_N_A,->/D?<_`<HKBVR9)M8:0@N6:!\;I-H=@4\QJ924.DZM
M5P>RP!"-CA(%^I/'XW&VG@UIR8#CHJ.--#,2+RVF-_9`%D)!-/58CW<6^YRU
M:=J*F9&_T%!JFW:\I_<'FK*]F?^8:1A_HVZMJA"+@1_'I-19T2@6%LYXG52H
MO`<[%=9]AX*)DC^;CO/UXQ:T[/)=0/00SWV3WB;YFL-GN3S2J^$)/&/)25*8
M\GLU<7S-UTQFUBH3MQV3,]SA138$PZKKD/Y]EFEZP/VU:)F/3I_EU[V)&Y@E
M5:UUT+<J3BW4Y1LLBO1`>@`%3-!A=G=07$C)=0R-U>M->89;:,73SK69JEJE
M8)`S9_Y15=/R;0$)-#4AKF]*P/82CD(X-4``&-*KAP2'M?B#]YWC]F]W_W58
MT(T`NU_XX^DGIIG"LK4*VKEQVX>E?)?QRN*4-[@VK0H4#^`=JG+OW+7=4F$B
M)3J+P316H$Z'2_[B%E__*+2W(YP4Q&]*]E=Z&>\IU4?31P_OLQX#^%7C!^?;
M\U(T"#KU8KY;/JZ#CQDHNPGA.+NB$6$A4ZP^1_K6G_H1M<17NPH^&!E(.;2.
M"W>\YX\JG+4Y"06K[\>AM!F9?V<O1)KUZHS((P7G4P8MSAT-M@Z:&#R5B^VR
MVUZLMG-4IDG]^+4G+9Z'("G^%7[X%>X*?U`"IA`F/XSZF0,!M-;8IL2P9XN>
MU`O)%/K)S)<*U*G?/8+T?R\3`1B[!]N@@XQNUKZV<>$R:T(>T3W5HA,":`6+
M1W^KK1R+<(^F`K2)#K.RO6:QTW]S.Q3TAY#M36QV]:._)7O\=N[C1$HP4$]9
M\.T(`7D*%FU+"&\6#*W:O"=3Y'O&PK(Z2X#`-C8%4+#QW48P]W4R9?M^+D,T
M`>Y_A-XV-1N3BM,Z"*(H-^(9'28H1N_PLWXY^2NP`>9ON[BB9I^M&TO?E\%V
MH\H/W8<OQR&P%1YM*6-'^4^_?KX$M9G#;>L%+\:S:P<UG?`^=[@.9KDYB.+\
MDF(-,\]`]Z^O#F3$&**^N5&ZZ:D16)CRK^&^S_Y9<08\,3EA^S[-F_3#U.2*
M[(2%[NVS%<A*Y%XY!3-N;@K1MOIFSI79$E;XD(5!)@%@5HNP-=V244"B7O/>
M@9NY&[X\[DRDFW+#UZ"M9AS:M/RI2%%7,S[##''/OV:6LH:A#G,U?M^A#!+2
M36;<0*3^).8I%5]MMR%D*3(*ZA_]U=>-`)_WO0<*SW2".Z29YB;N.@D9MFR[
MPFZ+[M^PD'2BM<`X-T/@KC7?$@E6(90L1(L?Y>7!:60FJ[:S*^+FME8^/JI'
M7-E$B_E<&;(`<(\2U)C4.8F9;P?Z?S68`?`GUAHHQIY.,>@?AELK6!+F)F:,
M#C?7">I,WUS*LYI'M:V3VQU8-!:#M?LCV[EE3P^;)]31!B-+?4O`S%4C`^4-
MOI<O.D6!6;V)Y#`#J`L.FX(O55:`.'H9/'<J]8PZH+<_\\":(#%-7:9%&[]0
ML:IA)KO1'_IO^+VNP,TUO@/1&(E7;(Z.(!ODYD(L:,T3P_?QT%,@S/L1=08]
M7K_?K'(Y*N2)!2\1#B/WE(#!M%,??5C"-[1Y`%M0H,`X;LVV\\)8(>7#^E$8
MC#U\`>Y4DBWQ()@(]@3H2=*&TC(15REL-<V+UWXBL]8,9`*6MH'/G-I-8G<!
ME%_D2*A1;7;2^7VAPGIBF;H*0Y'FY6TG)=92_DB^B+66PK2;"FJQ7_ID6*E3
MI2\&;%<,E4&#_'.`[?=V:$CXVA'Y;BLLN%PI4P6J)8!YR*7[W_-0OI>T$:Z(
MQPKBIM+RR$M5C@EG2K<(ZN+Q26=%W@Y/^]:6O0:1RK6PO2=74M^7M3H??9"D
ME5,4G;X,09T)3_0FC$#%PP,B=GDDXFE/DZSC51)S@((T?U%IW0]'`Q2%_=^F
ME(7^72VIP@M"SZ4<-MW'ENKM9.!@X&01]*(U!?28J6.11VM//'WD=E\C^F'<
MK]^U<Q*=KI@RJ:O[P[E8T87[>3ZT=+K7%5*8&`A!MPN=L4M,Y=Z$2N$'G$U$
MHUJ<9QS,KZ2-G1\.'1^R+V%<^+O-3TH.XME!5\SKQC*3"^Z'*LE-<&M:.3!5
MOTK@VXS_]%DST@VVS5'-C;:/"?==!JXDV>AO=!P0FW5IC;\YZZM<PY0#"A;Y
M/C91[&B,=OS?N85C=_W,5$-`Y6IV8`AD!5*EC9:EJB]QM$0`"*%0YW;B&@P*
M0'1N:\KZT"J;*D21BE,@--OY_9W-2;6-]M/^LIXV,D5!K-,G<@K:-2I_1.>^
M-@1\0TSX,OU$_'$AMKO[:=V11I)B!`O_X0+F+9J-U3$>@&(XXV$'RX5]6\")
M$WPP`3TP;`Z@IJRIYLHW#SZ!KO;T:/J,BVP4#_+H:L3Q"U#R9X&7(4"2_I:=
MKUU#</_K'C2=*.4`IK``4?`=01Y*<YI1T!LUJ-@[+NZ994#B0&RB\-V4<0:@
M:32,ML9V>V<'=%W>G)GX"U;_'T6R96RV?"5-]<-C2FV>8(CH$*)UL?>4"OPS
MHM0SM)QL`W^]P@YI8G<IYZ>(XFFA4[.:6N:FR#I(D?CZ]:P&GJ:=D";M43YG
M3%\]Y<./-(5F%UP&7S)3B@[<="LRZJFN9.39[J2W<,>GV<LOHFKV9EWC7D-%
M)7#RNH%/\LQ73<J$-^Q=Y$<R?3\[\)],OKY(CB*A6U88C:XT6X6!,6U"?G(]
M!3QP=^:\AV!*Z;B23%*1]&$2>3@?VG92V/)L[84$&\Y*M#KK`DV*Z"G/R\*>
M;=(]_8=KJ0E,JG;^GX)@Z5/M19*F?$^MW=SHSAR[OK=&_^=J_7K)E`P<S8\$
MI`UG?KC=%W]$W7?$;V;8R--C(>)3_Q;'SEULP6OK>=>SL>,82Q"((@.,R;&V
M5^DGFFSA^'=%:'E!@;E@+\WIBC.EY:7K2_1--G;6#HQ<SH\?;E<$"^2(::I0
M-`*767^$;IL4"Z2#P*7O3K<(UZ8D[H.1)?Q.5/X,3&H`O5FMKEA>*O!%M@DE
M);-KE[A,$X%T8D+EMRR7*>N\C-U'!R)&4MCI&Y0)9$0^TVO2^1<*NMVU`H6*
M$%#.C6C\JL?HBT$O8R(Q;1]7Y+I48]L'+N.,54?\DUU9K\+<CQ3:#6_;-D=D
M/-7'/6$=92.YXEJ[`3:Q46X1A[/I:OYW1#RDZJRF,[1P7?%2.F19%[U"P;*N
MS70*]Q<`?N6TD`H62W*>KC0C389O3_/V^@'J>SW8EU37;!B\U@ETEN8K\Y3A
MMN&P!HAD`A&;%T5P;MTIMQLF[;-W>F"P"X[_#M+;(GQ27>26IIP>W^A?\MNQ
M^903@>:12@)'>;K"IM5#7H:KL'-`(/84B#G?^>WC3F@"M;2D9L.`VDP2TF`(
MM;_&5*$!B']@@3_T7NU0#3,OO:_:?Y=YSX@<B%EWZT*B\5&XOI7U<SI,KAN?
M!2P&*<BBN1S#^5,H*>0+QX]DL5[`FZ+Y]D@*%2I?@']>H2A.O[U\D@J]BMI9
MG">6#^.\V<Y%M>)>'3L?'8S#!AXF>;[J<MY25GMNFC=X@L8T3_\F>>B<51P=
MI!U1+/S6BYXS2UP9$%^79U`BO#F3%=@7;Z'.;D0!#7J+-Y7ULLE:RE5)IF27
M)B&5<?'0O=4SA=D\;[Y,Z&M"`9JE"]=`WL);F%*C6HKW"$6&4AQ&E?K#R`<C
MQV#.(/IL$CZ>$]57R544RE%^R,(D_9]BK[VY'J]UAO%QT*013I.K$ZK^Z:D9
MIS?>3/QI0Q)5Z-N6D=Q8+<>DI/Y*`#W-BZ0A3=8)F$+-!.7/^:Z(4Y5HE_TZ
M=U9F!RN]EE`5'(GI!$#<&Y$!AVCE'"6$Q/)E>HM;^';(FE2#HMS>:_D"HNY6
MM__/9FMF`-0,C1L`1%^*Y,I^>6Y2$.I=75#ML]0VESP7GIT`7@O.X+,IJ_!K
MPA&5P5:2RB:;"IYPHOGT8[O'*_>P>D@<3((("6RA\WBBE(7G;\E]S"$)$[KD
M^3#>P?[,I]K$*-3R?C,25GDHD>%':96`)JFA)MR5+XA`7:_+^BX<@+%?*[>#
M%W=P2U._I-EAC<0U,;$].1\<V`"587<P@P^"W2\MJ"=JF1]"460SPK#DNP?8
M7OH.4,'/K--/FGAJC+"::K4A@7#`L_Q97&6>!&$'][IN./\N5J>&*\WZ>0V-
MY>C>7_9!613P1!3\:"FDH0?54I2-+C)2RW4MZ,B&LQ!4H>*@A4P>!!.UFA;E
M@O^T3*&VR6BXS[[:+Z;9X8+K^R12X81-L\'Z6@U1E^+U>IJUUH,J(((;Z#SI
M))L$K:%H?DYWU`)8?&0O5;2&#4IX9O427[L)`[F6R@G<&Q4/'IC,`L0C<LCM
M_`ZRT=T.GVU+']/H]P:FVY70]$K"S1P&]M\M#7_?UW9\NB@B0+$E[MJ"/%YH
M&UYW#9C.991H6/R)YT*<.QH4&!W0S0!S,"_N$5H\!S7_3>]RH'A&8&JQJ868
MN!]1`!7/K7R.Z__2:C"=?QS#'Y.:;6_["&',);]F&*JK7==#^.72@6D9X>\F
M,BC+@,'EM.]ADSMRJ`RE!$5WVJ-S9&_C^L3:JR<0T&R&VY@)5J1]*C!I32\)
MLM46'\UJK'F^$Y!Y3VOUYK)D2*ZWYS%JR-,O[9E=15>TBW4P.6)WD%QAK\=*
MWJ1VE%NZRU1IXGT.?X&-VWV]";/")DQ<!B3CU,W*KO?37"9C;$3NAPG%RX4#
MD;$;PG'NN7@<;6D@;',32C2$&_`;WWE3Q.&W@=_R1&*YD8O=__-X&HHS'E$]
MA>Z3E<?57)*SYD`^4(74G!!L-"`E"O_+'VBLE/,K$8MQ;3V&,]3R!J6_PI+[
M/#D(P)U_J&"=7U4]%W8J>(?Z2<,]+F4!;8K>,O,`P^]XR.'<M[F2,,\,G6++
M89G08-P;9RC+6*OB,-5N3-&B9^!"8J-C3+5"UBA&%,F;#X[(]>JT(@S.[MT6
M:`[@6]";BJG*A_@[FGL?F@"/[WBM8E?"/VS/V[3T,?Q$9^2%9Y/HPA2R6:1]
MU_E;L]5I=')*'E;.'%KA`,L'IN<"2WNUZ$3MS$P+`;]G4B@FBLS\1J8F4!_S
M^7@'5!(,,-<C(6%#MIXK\Q#$>"*>:)X/;'59HP[ND'>6=&T>!UB`"WN!3>BZ
M5BY\MPX6G;:&==6#%X;@R<:L#N,OM(UFYP^Z>Y-27O`K_AS':8_!Y<TYF@+I
M2D[<F?\7(VXP"K=^]S\8_J=M0CH(6@":H:WKA5P^,%$E<2H=H@$4$720?</Q
MWAQ!5<0!:3"A%)*DN;_BK'$ET0^;+DD@D-YX<CO7FF,ATBJ'YA]XT/.I5]^-
M.^98L)-794=Q:U.>8W4CM2&[:6MZ/+YAP\*OA\IXJJ;:)[C208>LHH\O-@S6
MT*'@(^U^(I?@6(DC(R_0S*&C5?1__L'CIAFW36/9Q(I24^XE%Q`_#%==6K."
M>'QXG\+[HB("X8!D!LAV%1CR/XQG^+,*XWG*H%6"V^2_"N*^F`PLS'"7U=_Q
M+K0HTD0\./U6L5<YC03&>5H][\DK>;S@T8M9\`-=YNZS*[UQ-1:3!]1Y5;6(
MH\\Y8RFDEBIL_%%X-J6X:5L2#/:744.X\PF?+9(?L+X65YN%YD,[/:H"[0U@
M=]!A+BM0`EL.'`!13S4-\I)S>4%'4G;W7)Q?<<.F2*(ZQMZ?L4SF,:R.>%W0
M^*(UM^S\5/^B\_V1[_0<AG!B!1-;?\?K<D10(,9U/XBSI5]P]F0/_L_[*_#.
MC%#%/<*"*',X#"J@%#3L4W7X0,8UD713K__""I?*;C^W.%-3A@,XDRQ1"'WT
MZ'`UQ6"WAC63ZP&0T=A#*)!^M\A5$5RP4!5K.3050)5*.TK6LG^@];A$*6[S
M[9H;T)<EC1JS7[775TZ'A1W;0:E\93<8/^BJWYJX"``42_]D=X\B@]IIE)L=
MF:V]55+L+$>HC5/M1)W(U%#<?J$<7H+,\2*E[I?'S[`MA:'9WCVB2-[=?M4.
M_=_65+`9<)*[Y"ML0!>\*^DT0P_-TV2/[5F/HF+%E0&A4)N8LM"J1\&4NIM3
MM0CCZFMKB.F%;DW9Q00;*NRJ>,,\^M=,F?3\+7=9-4PHF"I(U7@<4KZK\E3C
MU#5TLNE5\:_I<OINJ4-"-7KVB5NI"^#D[_HM"`MWWY6(`A+)YMPQ*;GHNWK*
M(124P0\T$9O4,OA^-K?F83VE`IB,5VBN<`#QXD7E*<-..]V7Y=4(`M4J?_J)
M+HL$-,;(*[7`N;,FZWF7%_F\4$U)^K@.O3LHLG$)ZML66:@U>&EL=0`>/$=P
MUQHF81I.:[,IC=-QWNIK>8>Q8?*XV'Q`2"URT6X8\JI;4O7.20.X7E+.O(C2
M/QW4N`Q#36U(X-DLO+\X\;=0^L-<7L!5'ZA*;UH;&V9.8D4A6B/A$ILA9%*A
M/>>SG_!.T6D/.J5%D1X!8?3MYX#*R>OQ<Y1>(&PY:2$>9?<VX3["'6B'L:/U
M3DWL^J/<N\;S3JF+ES-T_,/`5^5#,A@Q@&!D;R>^_:^Z^%A/3Z!"=>"I/R?=
M4M4:/QU]]"]/-GRK>V#U36$/H[.^<`Z3815$(^S$$9[S/BCVZ+(>8$P(@%["
M('2.SY[J<?YOX*+(V`Z2N!H6G;C@G?I$6?&@5-K[7\E"IFS:"DE?9J[6WOF?
M85^_3VC(;SF?27HI9/>.V*1H\YFL)=?>B#:GV8:!`^EJI!`CEC*DSSS.2UPT
M(7DG7IS+%>G)HW2AX$$]"RWXM1!'REIE+K8/+G0X1BNGE1II%JKQA.0Y.^$=
M-5]B:4P*[&_AYKN.F8]EP*L'LMVK#WQWG_AA+`AS1HS?E3].33EXQ)BM-+.9
M)+A"9+^S5J+`U\)(V@7Z(O*%7Q^:@S:'KL8=+@3PST_>T:-OJ4/%A)HE`V9<
M]O$><>X;6`K,=(U]ZE;YJO['3J4`KJ<J$[%[0TP(8G?29QKWKBT=(4%U6^@;
M@8_CTQ5$.P#?-L=[$NTGRDO0ZFMOX_4Q?81F"X-#0H/BXQ.[/6`Q2;UM73`J
MN/PX]`"]<#!?0)N56TQ$BDMR51%D"0EVT?M!VQ,Z8;Q*_G4W;D=3B5FU0_J,
M]N>D3.M3X*5](E?$B6B&%OT[K1<GWS$2LJ`,*=Z<I;^X(O#_[N6.BT*USO`R
M8"Q5#'BI2*(OXK5SENIM[&H9SI#0A#//.*)U633M$-34,0;/#L'V.RT^UF0>
M._@3:(\O(RS!.W*0NX59PB(6H_"-^!;(WR+]YXFC]CW9P]BR]2>]G8Z_56,4
MAC*FH\NK(HCFF:3&+^2BLJ^T\+<=ATM9V1[90([=G"\5C>J^W(Y$M00%+YF*
MU.;*0]MX,BDCU1YTXUM\[W9)'2_8VG;NG*:2@0$T5A]Z52ZRYPB$A)XR_<%;
MZS?5V#FBS1$\CFX:]+IQ1Q*R*>X)F'!TE"#I.>-G4#OEEDT]T+--S;YK>8QS
M4I*F`>&\!GVWZT,Z/;>&'(<KY19#!@B:HP"I_O#D^FD%C-AQ1KKOI0V-%<\&
MW#4\-<\H*,!T]/=P"\ZB7E]$*BZ]<2(S<*94.D%JABJNN(*8-&CA3C>/O*J`
M'M"IL>(:N_T)SX67W_JC%CW5P$=#=@99WTC^FO$7-6VLV5"(4G`2>_233$*-
ML,D)D`FCI]XX0MK&HHW<4_U*T841;!PU6CC&6>TOO@*?B5Z]CLW6Z%B9_\SC
M^Y4-%)4W!U;#JG<)%;06?_\WA5=3F6N4<??8B:W2/Y8,XS_"L15!HWQ?36]=
M)-J*+$:L>2(\MF>B,&JN6_HE"?HS/9AY(IT,)5XM3,IK6>HQCW^$+5&2_<4$
M=0TU)I-SQQ"&MCMJTK@TM-%&408\3,C^Z/@TIZUG(4)X34-8-/D`_%N;'%@H
M;-,[3:*_E*=8QX>[S=8)5:D\_2:?$Y0WVH[J(^6@NYF1>Z5%K$C]^L,UZ;.<
MKL5:#5'@UAHRPHI/V,FZJJTT/ZKZ/598CI^9RQ/6G&+97%4?G%<->;3/A';N
MRB!1NU.^*L4.GY'=4>:60R!GA^9Y8UU>SNF="*1G$`2\9FI1ON[+'Q=98;G2
M&\C^Z+8LW+,FK8T%@GX5/DDP&<CM%O?[1/<=BP6VP#^->M4"R,RF??9UE8:D
M,.W4'OOKL^/'?=+.ZOR$8S"NVES@>-A-0C=1N^`CW65#YHK$`9(G6@<9(C-8
M_Y4_[0D;I3<;?;J$HOYX+U7WENQE5)[R5E?.&Z,:DJ:6M5J\6`.<FMM%2W'C
MET'-YF9[`1@M!B0_<RC+8/XXIHDO4DT2[_`D!0FSAAE`4',H#ZZJY'>NQ12(
MB2RGP#]0^;IM;3!37TII=?WW>8,H)7Z43GH99;'IQHL@82M2>VH,'J$:QU.E
M`$1`+67",+9KS*X>1[O>T@]:@ONZV=WL;YBC97U/LNQ-2OQ'LB$=.4S4=45*
M#&$-JJ45O=8`;OOUWR^V<X8:9T(R#7L!=9M6L!2_>R4U7KLFSE/!6U64()4X
MK?QJWB>%=&7WM.9NC(.@%6KRP%3[33ZAT*:B,P:X?3J\PEVF:3U!9O5]BBU2
M)O(RUA1_(XY4BM9IJ`)M,DGNTBVX5"9)C50R>!-.F\N&"TS?[!U<_&<4*9PU
M"AS`W?OSEKN"WD%Q3V&G8PD2'07NKJ)+QKXT`X,2X<'<R*3EK5^TDX".6RSU
MFRN?=JQI1Z(C8O+"#/ZVR_0K'81_M?KD'0>#JBIZ/[CE]SN*W,,P.)Q1@DR8
M_]>`X1\2S"U.H2`\]0^,S3A,_V9;DS`.UG:]G@`BV=L?V)<B2>'&>-B`&*U8
MT,4DX*ZM0K);D5OE/0N+\><\K&O,*634B"Z(5[[S.H(/*428R')#RTEZEVI4
MP&9W>YN\VY#!7,2E47Q.55GN+L/GU>P^A7-2Z_/[2TL_S]W%M:?87/!E2[.G
M2<`I6UG`GN#I22,Y=7Z45A([FW=5BJHT#@SEE.]":%20&3S!%L,\>##8$6>A
M-:%D*D@6^0*A9%49(BA+C7OHF>]K="57EO*Z*E2GCS2;?:4CH:&W"$)4YQFH
M(T73D_Z8G4XJ"1A!8.C>V@D92='L]WJ79>FQME>&IC%:AWFUM@0TZE%#N2/;
M/00?ZBI21DY7.N`20(*SZ'%686EL-?1R<&G7D_(%="K:-;D"$"8$'H0A#E`Z
MAL?;V`0[K,+FYPUMX?RZ4O6C+?&4?;F<0P-5^'<J:*C;JRBH&\I54=^VK>K^
MHXS!^_:;+^`OV.$S8I?$>*G&(#^]H\/6<[>F*`>B8\%;T8(LC'F8XCY`9S(.
MNF=:48,#(V=NAR=_^Y6_Z&VWJ3%&_AT0HA$I]@W%JZH-%UFG38I31"(889Y]
M!7:GRDZ53<R%?FB)'P^?ZM^XT-ST4=1;X0R4R'II]?U1#MR)E9;&683\[&W1
M.+.'`"5@^2*@!M/Y,;;'\@VNN&PN>7A'T$0Z'U$-XXP%B('M\"YI1823%'48
M/$"P56T!Z$.#TLH5"2WK/'BZR:^L4UZ-CUTHI9.*10NN!V2_'.YECO0H!^6F
MF/3EGWCE6U_WIF(/7T.RA&Q8OX+92$GV?.5&R3HFI^+P1O+U[';)N%;6@U^;
M+P<D*.\XA&,M79?FX(F6:-V\<&!OD3,(@P&__Y*<CN,*Q/$W]43:TA#]]+^6
M:>H+`MD)%[S@H^NJ0S58_@%:[$GKOD0B.BG"C,8P*JS'/5FWIHPSZ:T*F1T\
MK]<?(6=)86]!!)5D#)+&2S]\\4S'VEB9HJ/6CQU`2ZL3"PTV9^N>.4`/Z.I*
MT["AEP1NVB+(3-F<T4">![[EB$*@B'/R`>43ZT7,\+<?YI,[[$C`"4[PO(KJ
M/_/SD!0MOW.E[>-_WW9"5/QQDAZB()DT/<K.80D-0Z('*9.CWT`E5RC66S_L
M.162N0MB7:IEW0AY3>$=/"LQ?6ERSO0>H"L3\1B)N("-5VPFN,WC?&4!BSB<
ML)A0M0^^UH*HIKR-P!4UL=QR:55KZ!M>:KE9$#IB>[FO88Q?_']=41-90YFC
M;TB#/)YBG$L88==G.X+_=F[9K;1M=:_@%"PS)VN#5I@S]W$1SXPR\(+6CLV9
MHO2)VW#HQ"`41WW3B9Q0\0[#9KVHI*YZ=ZN%%'D.]=BX):P^OK0J&U[^9G(!
M$TDSH(S:+NE@%A@[\=2&+31)FHR&BQL,0S^<=,_8ZIT[0$TWL5H=QU]"K'8'
M)_IGSSE;;MPC.1+E,ML8I7H>1+(#K$Y"WVOYBD`>Q`/TK8G&+`J2-65DEM&,
M&C19ZCB6$#YN+=(RI(AM"N'*P<I$(,8-1JONMN/FH[QB*CY/I<55G.(<9AN9
M#;F0UY<II+(I21=R*GIYCE-*RQ`<)CE5P<I@)&+C*Z4#15K^-,:CMO2=P+'#
M%(PEPT78;./%*(O0[V](ZV30&(B<-&:"H#($LR33,V2OH#7RXM[].3YG@M;Z
MT5H.!&^(2\\,&>CGN/2CV,PB3>Y:0MU[-LD*)O/-[P[?J<2ZPM+V=.CIFMJ]
MMV39U'8RG6@90MW%V;%LK`GMK"F@PSA(51<G-93M]!6^NR0^AW>@[SU?H4:9
M:C%^L?@KPVK49SLT4=6S/E9DK+#J."[ED1:0)BJ2BA;QMZD[@&TNG!(S#'UC
MDX]R46]DD2^[=`?'01(JE3R3';`L7F]T.;X/'06%;)QS276[QV;B8?1TWE6,
M0.\%'9-7<,75.I)F\>N$)'2[]^=:1U&-.&L,*V-D%5<GJH6%8P;]%PJ4UP_M
MA7H6HY$GKK0!PR71H0<U*S=(6Y(F+NXT!B#[^):2Y=<F_3]_6R#QUKPMPJGY
MN739#K7_?:E=5.)4?YR.LY_@?/ZSCTLQOLAOH]S&DBU`[)<2!;:X%0>_V=5_
M3E(@5;1&RJ&RPI&;@0>UCRSD,%_N8E_-/*H3;=46>WO7@5+$[N%O7N_3.^1@
M25Z_4G"56)H\9U%%J;)6T13'ETIE=@E]KM]S)(.3X/45./=RUX>L<Y\/`I>=
MXC:\"IVH^XN$.^#=]FN35"?D#T_;TA^0%A)3`+.&@[<3-94K-\<^#D".%0'.
MN.<UY+T__"TY-VKBCM,NR1LBRQ=TN@,Q#TF\RUM3:>49FG0ML<'8AA0Q\%H4
MKY3&J!.)T+#K1TS$;B_)2U@WZG.]=7@G,/_TTCO8>K`'Q4;+CY2A60O7OA9V
MLO]]2*!N9NM<6ZJLXEN@*'/P?+0$)H2#"!ZM&68(-I;TD#B/0LP4FEEA.HMJ
MC3Z7L?EYW(-(?(N>GF!WAXD04243?)/#:B""W(S7"X.028/?@79.:D<4[5J?
M/#S.V%W*G;?3^;1QAX91;H$Y"]SC<V0LGD]K3OE&3N:LV&.U,([/G4A;I2?#
MOTO2[,1JL^]DAU1C%"TE\H2PI#7*(K8AJ^0K+0OFM68.IG%G*FLZ!O6AY-WI
M>_$"]V<BD5*]-P>UZ8J++SR%0<<I5C!UCUM%M'@X0?IIQ9&YB%VM"%_#&&XE
M1W1\80L94.]K28Q4X83":2D*KI6BK+`ADZ.3+@A`[[TK+,2GF-1$[7LZE]0;
M;>O%!G3B.CO33&.'KX)-%LOK5&F&+*-B'99+-B3:`%_H(:/*Y?DD@GOD'YR+
M`=_O`"]TTB,22!G?UAA3T>V2>?&I^Y>D'&C^BZR%H//0>$\'E_"E`V93\C_V
MQHF'/``@F.6O#BLE(94(CK<).;YKOO*?OO/-MDUTL_)EZ&2;;:_6?-NLY@G&
MP)*%1+R@:F3Y-`D@K\@BS;O)[V-[[4;_K>+DGN\3,E33ZGMBXDI]_Y29W[1E
M6`_)WB8A^5KG5XT',X:4R[36L%U6E?#.ZLEYW&'/V"X).E]UNRD[%(J<!P1T
M\O!AT>#8A]""Z4H@/N0E5<J`T,GB@BUMH;31LLR"$P31UFB;W^#8+Q]00%_J
M,0V`R':4_=:3B0[+V]A)RY:]7=;S+E*2T[JW9!^!:.\@1@,B&?/<DL(L@UG>
M$9QC&@CX5!G`",2,A*SE]R<\D=]`&7K.PG1C*X#1;#,4:@1<WNR%-U>3SH$B
M($CN*Y3A[P^WL6B"GV:8.;HJFV:OXN0DNB^8CVV2QDPC^JAC1Y:@WV1G^*-A
MN44]!O[)VR)S&L<[?!7:C9A)^"K*;O;AGN)BBK-O3C;$*B&L_E8:DMU_T4TC
M$_XM`5@LMK^\[FB&T1,ID1$&%7##L][,B2!2?9&9;>F413^`K$UCEYCS#:6]
MQU'P$!:OD@"`F:OP(>X`GL@=?8D!3H*?765V,BFF^*/9B(-('5.ULFML`EP?
MCNBS5J"WF5R#P5A`[[XSOFCARWW,D^0DYB']U>A9P,0/*UB);N0TS'240@E^
M[ERLN3\`\5JL&",9:*3"=C[?>7`#?%&?W2H9]5^8B9*QAGP`F0%O18$HB]:0
MI\/#+UP#V]I42*I:BMTLF')87WFT@'Y"!(L0)`(5$:[U6NF-[%WI#04[XZ+*
M5@L0SP1-".Q33M#'`Q>CM?X)P-5!+6%OQO3@DZF\^8-67P?`!XD#W[S]UARD
MD;#^J3$GF=#[PY3!M!R.H[E2GRQMC;M=/*=MS.@VG!4'5^458]\7GH!KL6GA
MKZXR.9A_$BRFN'L3I[H0%(+:3C>JC0*;8ISRO4=">G00T4*%-D[8,E6787;Z
M*ZM1>M2-;>.[\-!_X@\OYF,6I&(:6:O[`)I%Z\M`++TPHF="G"-$3B3YJ(O*
MGUX>/2L,%1MY(G^.,$WYFUQ2QDDC&X4*.`'V1;'U\-CNS3;EO_36[16/_SL-
MHIG94;B0_HPZ;O-,V-B`QLE\B^"-80@%!ZV;K*^YVG)5/W>^_@$,X\J0#7^C
M0"^"+)M423..,5V&^U&8>Q_1GT8G^,[K\$MM$-S_-]N&4XT.NOD`AX80QR?'
M7G@WNW/SY<@/.1^,*>75(NMLDJ@Z'W1QRC_CALA#4PF&4-LG=X%LMDD8B8U?
MW,D89FO*S"9!<=H9H/`B-""D4O=]FD!AGSV?R1'3W;APP$^<AQ)"H&#`2V5;
M<T"@X6#HQ29`M)I!T'"VKI]=\6GV[-3#N9QFJ02/53F$'^BT230.ED"]5KC'
M:1K#]RA<A<+\;VD3UDXJP9=6_51QARI*Z(P-7]U"C7K@/Q8'B>.85:,C\6,C
MU@#)P[E(XZM`[8C/:1&<+Z<]W"4@AAP+1HKM7D8!2T_R)?`[M;)_^`%E`2BS
M2";^^F7E%=,YR)ZJ6!W(S<$O\;],:=V24'^FF39!DQRU):TEK$T[]?8X48TT
MGLL-PL1LWX>+73+_?;E^W#BAY@?M\&<08T*N=JGF;9LL2B=FU1<:'`R(K?Q+
MW"XN<VY3XYL$[9'F3)/&@XO[L41,/31O:-H$=B",5?U`,8\W5XRF'V+GPQ^.
M9+NA-0MYTFT;,X(:N[;T,"O@/?+:9A''PLDC1IJXT6FVVT.]_4+S+LHP;HI8
M1H3,1>":1T;BVMWK=0NJ-OBLU,#O#%[J;Y>_?L"%"MCNQH!5GL>:"=[,V;7P
M])\K80>GQWKBOSN>-?MT?3[\4%E,<HW6"ZW>GL)1"ZC,(1MN2^&+\'2W_267
M[]\64,@)#6#RI&>(0UO'^,?=4&8=EG1<\5]/&EY'@,@Z'Z*J))U*AM\UT\E^
MQ#G2RMJ-1==M:':2)2XU#J\\&NUWFI19=[=,4XM+]9X'@LLN"N`'VW]U:&W)
M7OB8G@%\\VH=@8"9]K3*XP.IFS"![*G4DV79Y;>6"([QC4E96N0*&6J7DRV2
MJA(5$2W[NV7LNU=/VS2A'!)'SMD]U)@;SM0ZS=7[ON*@?BC0B+3%?A3[5L_@
M7:FR0Q`$_W]2A_Q316<5+P]66`:F.I@%:T-JTS`"T]E#$Y>,JD]6&:5.O4F4
M(-U#0&8=@MJ,XA4:VVJN693U+5="JXC_U?W>Z--H93$L7/?HC(Y=82J;I\['
MDLHDCR)>!G(DT=+D+&K<V=%WX7[_C&-%G5T;XM"8[6DV#!IDNG+]4HGP2UM)
M9;],N>BG>)B^5&@?.@5K@JXT3T$&%;'S0C*6,U8;?^C7:'.G-`8R&F\6QL]-
M'?0YEIMEQ5@1U*+-\6FWJJ?5JQ!I%J]3+]&;124XK'$>[1=]Y&=`[+MV%2HW
M$EU>MJUMC;KL+?+J=,4#,%=`A/^)&:UO&Z<B,3\<>]-)X"RQ4<<"D5$3.[(O
M1B49CENQJ)PENM>1FV"+Z),"!B)"^L'1^ZJ-]%S^UT;R3KWYR;<$-:SU"INZ
M>BZ>]/@X-CZ8/E#9/)E4-U-S_E\`4-FG7;!!K(K8CX.,+TW+*:YZ#J@7"@P.
MJ]N;P<(U4I?TQDZL\NFP@HWUZW=,^-I!@A-*]_(V&4*H#L$Q_M7-2;PO%"R[
M9Q'A-WX!?,/;\TPWFW`GQOU/+(2)H7S<+!#9%-%K/V50U,0F,FL)VRR;IV^[
MQ$-NGQLO'>O4*O&N7Z$?H3;_,\-^(L,Q_RA:0:@:,;P!IJ5V+ZP2\H;.T?*`
M88KO0XO'JL+T\T1F]D&0VP_EAT`\@#P0\C_DPHX=VPL.9Q'$)HKXW=7)K%SK
MUW-`*HF#0IA[AN*\O95*,=ID:OIB69:UEV%68[$K(?#EH+R<D.WJF4($7&M0
MDF>#ZAX==ZUDKW?X2?BHG`P2P8=6?\U/J3L`=)US0[2>-CM='C+7W!L7IM"P
M-9U(T@=@UE=:%2=?*9UZ$;J[88@=1Z'*2I&FG"]N4>=WF'UEK=I/.Y:E5E\R
M2?0>I#/]CJNE9YZ#]+Q<+&\8CI)`JSO?:B;9=L(.'Z''O;/2,13[>/[.G"3F
M7-R]XY*5O7_>=UN]BDE2BFT(LI4VE*1&0*&.U352]5*5-#:.=.8=>A,%2;@D
M(`:/LY[/[W$R$MF2`JD*K3<)ZK(M,53^]G17!(/_`B57[^F<1;:9H]S3K#1A
M@N=LT(CD%8E3;3#1GK`,ZXX9X+LVW4J?6+2P-HS6Z;,?F)<X^068Z]"@?#OL
M+K?K,-67J(M\:,92=K>>B'EL#R?M*^I.O='&*;.*UX<FE>*@&`Z3IYM>6UOY
M;7L]?,(K;;`OSPRMK1!"<RQ4+#G7+6;XP2P=86GLT/!=`G>_9D5H$PB"\^#;
MABE(D1J'F0<&P5R*(4U#'[&I_$-C*[QE6SDGTGV=<(\H:K,AG<0</R=*:O+D
M!%@8$QLF)GJ8CT/VD9>8C+L@=-@Z:DQ:/3+;ARX*7W7P[.\%CA,E*?B@J,T#
M5"'Q1,"1C0'Y)H,ST@KYR3':;$O0_\_@.>O2#$2$_W=AU?%N]"S/[._^SJ';
MK.^DP%E:\EYM)-)^%]W;EN5083P27'O517_@O_86]_<6]4FV%X-=4A@'4?"O
MF8E&`/A*@,$%11H#V[?E8LS]&@0!:MYK?T['.7T^X#H)/;)O,"_2:7]^F^RK
MH<;?AO*_1@^AY?4/HX,)8`KZSQ(3#FJ]LY*LM+>K.UA$%!3IQO=*L=NSH@^E
M"F=#&L@13_M!F3_[SJQ@O978!=>V'].;RG?CRJ!LK>]-*7WE@V]P&,%G;:,J
M]]O[,\5WCW8/[&%D!CL<-%>)\PII+R_BWS[/"/'-+MS7S^WBRYIOO+0T9>\8
M%KDD`#C)VU'&2KKKHJ:S\$(ZE&M&4(!>(5:96GN@4N$[JV@G9\\M)3;#/J5)
M+/#WD0\*]H/HD(P/7/-(S)IO^!S-.841L(<4+KD#2"(J:"/"2.>,/AP67;M6
M0KL:6O?3I/[Z&PPZ/@%0"9-9KAGP-`H.$><N9EZE>O*$_'9-0>3/7-G*37T.
M0I;=:DH>QLU82!S-]1V>CC+XR_!Q\P7O*KU]'6-TF_=OMES]LQ;S,?+K?%/S
M,=L?N7GU2+@&R^07#ZTB,"BSUB^5A?'OI!34*$Y&Z=;F>2#9?IDU[$&S?6G?
M6L][9'5GBP`.%CA\^`C$]V*5NMQHF:B*]V&BA&G)GCA6Z1?K&=VHTTW;3/2^
MRP-OQV;5H'RH]E>IG@@2J!&J*''QZ5>`_!>M,=[I(9%@JJC+&+@[I6L=7''_
M>+=)U+3TY[D1P;Z`=&(&I01O?RR<TI3)$IZ*$RGGIPUB%B4\$4QLJ-N+'6,/
MOM^2NT*BZ62(3^P,>190L><R=PGGU202;DQPH5UKSUYY(@N!N`OKZ.)VPZ_V
M%`K#`F=*GM%XLT??&Z<8?>J_924O%>%,2JN1$QNH>W*I.?8KX)G/C[AU&#I*
M%@*B&U><45!F"10Y2R`M=C@R.\5\GG.T[OR.XIT>A`HT.S6Q2C7U-^E?>M!O
M%9,4J"8U]NAV'$)TYW*5H&)!"Y;1!)4X2J<QE=NJ+:2K.1Z%?26F%C;]+(2I
MRC3)K]S^,?OM$6P+\%WL!\7,_V"6FE,S*E`&T?8-CY%W8.=G9.`8(@!0`;E5
MB1W4!##7T-7JG*&JL`O<R<@+I1*%&+=6*YD[H$;5&,B9_67D[_K"TT`_EAR&
MWI@C9C&2!-M=!M9AE^-,2M^Z=&;\E.Y6^<;?\\`H32ZP]NFT5DIYEXECZ'99
MS",19E9;$!.N,_=<W'U\_K"R^*1!@#5?%6>[@N$[^F@O4YYX9F3^-=:^<1)U
M]QU=0L5L92S:;,S1SR%(&2D*!*E=B8I_7]F^N._4]HZC7?[Q6!'^LI^#307\
MR"'.HM36VGUY(?7%9J(S@C/H,.7FR4\HCMD06W5R%4YJ'GLBZB!AE>V*1(%]
M/?PV+4LX?-RNM4G4MH'0DMDH;OM3CQI<X8$9>V/CDQ"-+HMP7^"9BHSK/D`J
MB6FEL=A5P]%"D*C8&49-KE\T*=44H\!IP0CW@8S^Z+AIIKD6N!)B#/U"%^MS
M<*&H99Y36WSQ-[\\D%UL6$NZI>8:,9;:RL\,_+M^$'PE./^]^810\.0#;BA.
MN)E^;"O?"U$/KL)L_ZW:=%JO)#S+%SK8C\G:Q&>*7)P&WCHQVK5PF:<Q?>X^
MZ*[J!!-^H\JSZ!T!;'Y_DLO6W9]`AW75=9&NE#*BV`&&]D'^G3%^_PW'-5#W
MSN2K-V1W:PY'BS'QR)!^?;X-C;K*;(.?R8NB+4JM)2##P`[^6%#B;*IHO%KJ
MBJ`Q;4:RA<N`G@*?E/!?UHR$S:EX\^DRKOA=OF?:+Q*C`/@^9C,],.,4AC?#
M+_&5[0J:KOY:`*S]T<(#.&4>H**2;N"T0UB%^J/\PG4C]8.&;#I;O'WR>D4=
M:ZA(=W:AF5>1J"74<-QB)1*0$%H,"/,6=0?[-H%\6XN7V,A9A2(U_FQE[\\D
MJ4H(ZYXR09A]M0-(N]/4"8#YUY6HJ86;5*!DB6F>5_3;4GCRUETX*Q6%U%AR
ME"`&%5E'X_D%T5:L)BD$DC^$ZX>D0R=72Z$A)ZK\R>[8)'D`K0]'D9)\4J[*
M-(P"SORL8<$?Y`*(?")?:ZI6"JP\./"9[+H=BF<V8ESK4VH?"8.[5H/;I410
M'UP$FL=-9UBY;4Q$;39S-L#6$QB'VW8UJ][IF,.^N4'\HYS&:V\,PSQO0Q.A
MQP\-%'[@>Q([3"`FW'7FGSY_)$2F9B\%?KDYH_KU````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]A9&UI;B]P;&EB+V-L87-S+D9I;&5-86YA
M9V5R+G!H<```````````````````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$V
M,S(Q-``Q,#4Q-30S,S<S-``P,C(P,#<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*("`@(&1I92@B5&AE(&9I;&4@
M8VQA<W,N1FEL94UA;F%G97(N<&AP(&ES('!A<G0@;V8@4&QE<VL@9&ES=')I
M8G5T:6]N+B!)="!C86YN;W0@8F4@<G5N(&]U='-I9&4@;V8@4&QE<VL@96YV
M:7)O;FUE;G0N7&XB*3L*("`@(%]?<&QE<VM?;&]A9&5R7W!R86=M85]?*"="
M)RD["C\^"D'*6&2E01UB]!\+"\E,UOM%R_<7+)$-W>^AS%N@THLS5XTF2;]9
MEQ:&>BCECXTW_5(7KSXUY%+W@C"&D!C>J!S)N;-.R.W)E6\SG![5DJOAE*:(
MG8A%2&0&)Z.H'.ATRPLV6&!]+[I_`J5&*";HQ_2ZAO0?A,X9S_V<E`1K?>$H
M&=0&V017$!$G,><]H<Q=<<NP/S^>S=XZ5FQ%0M=KGH9@::H.P(?H"L!;7PC\
MHML?)Q*^2/[$KN$(2)Z/WO>'.=Y+MR!'R96=PBIN;@0_F#&I+9%@4S2XR_S"
M?ZO_$Q2U+[O/M-81[XZ%I@RO&%>(X]QLA5@KAB&<F\69:V@>,<N9ZZJP0A!G
MK]XEKKYYI0+6:U<D-6)^=W>U:ZL"<A59=$`O[1)EN73W4Q];48%P)8,(@C2&
MI#?3XLEE%1"\B;QI$8YE2A6S#H--_D3!ZV@I=G*HL$.%+$+7.,[2EX1-`,>1
M1]:SPTXW6Y6+4J_H&K@HYZ=;<=ZRE=W\N?LLT6Q7IC'LQM&;Y\/4"JV%W!V)
MNC?P:?H44Y"U.&)9/E(-[,<Q[>SQ;#A,TX9*YG@M$NX6-=@`0-[Y'JW/4KJ)
M+Y;$?&5F3\+H=E#=E<&`=5M;#3=<)THM^9Y'6?EWY04@L]+!3T[V;"$=5E.?
M5&J,D-BPON5X+O./DZ@;!?9.381BFQ%?^A^6$&:R(63XU'*K/[MK@HNYC&7M
MT/JBB5?#HZ$?9P>QI2H'ZJ0!T"@G,8>5`LXP95<ML9NTD3?%0!CPMU)/-N'6
M2)@U&D"-0R+M(LD'/=$L"D%J&L5R_/F46%V`QZH1\*\M$4[]=&1$<_JQ']3,
M)L\L)S1V@HW>>.U:TH?#7!ZA.U`\*Y)7!0"=I5&?M$MRO%ZHWE;#"J=H%&2P
M)[QWQ%01.VF@'EA&N43&[9.#:&"0YBR!OF3@D;G]?FS7.3LNZ0+2`>91@^(\
M]W67ZTUWPQ30]G(SY&(`IDBY\[>?:P27M6DF:()2=LL96&ITB-!ZTZH8G@JO
MVKL4,-&8SK";:R9,05!O3WG14\H`@80NXFOC>A7]>D#7VW/BX]ZM:O)4L7+G
M.+XH,TU?'?X0L39A3IDZ(([)$N<Z4.\I$AGIZ*-E)N(D9T8&HAO'N,/%%>T9
M3+%:S*^LZ76!X6,#O6I<WWCH#@=N^55+ZP6>&J!+=ALB075H`9BKAQH:]0'I
MD=KC7367(R#U#+<JRKL`,M\X&KN%Z*J%5/`.GT#+LW/;/)3937FF]LOM.UVA
MXA,+73Z747BR0_8W/8?UJ(6>S,Y_[36)0"CZ>P2&TGA_HD`V;Y]9U'F^5[9E
MC^,-V7(,C4KIZ;<,HB8N-2`V]"*5;))_NN6]UF>^#/$[,'%JR+<77@*&H<^N
M0\!5(0"`;BCKXMQP_J*'H`W?6_;&L'VHB9Q(%,F+NZ2U'U^32&`M!V(#UD7E
MZ_;)'<F#/I71IB2TPIB1I("!,(#HTXFY6?7`0:14'V^IBR1LDZ]@:0;9E]7T
MFE^YL&3['LL^W@&5EPS4IK[-U'/C!@\/)6@=X\QU:XN`_(-_B$8TU$>D\NK#
M(UO30C%PI>G#?Y^MMBTKM?KITJR`\L);^9(=P8/B/QM6^=<M_6CF_]=1`[9X
M>]*5^&;NWN`,FYY3*_0(%B4SD,1L'1R-K/\6HD.Q056^J!R.V5X!-JA#+T]2
MQ04B'YT>V@1"K#G]D_2+FA%>^:E_6"3P/N75(5U3!&7-MO?R9@20[#$1-VV?
MC?)J6*=F^"H19&2C9$GQG"_Y)0>;G5()IL?"'$2]X8+\H@_VXW*>SZIU4J)O
M@=M@\..C']S5;!?R_L@B]J=X#>&*(P6!E)D1H9P@M\P)P:6WHZ:6;D\:F'LQ
M%%GWP.8R(K%(_>0MD'J)K/[?/(<+0\+8#2A(([<@DSI.?`O(05XFS7":B(7S
M<."B"G7&+1C5C3CRW.F9N.P@CX?;EI^-4()H*G%)B/J,;(/]_"HH-?JO")6A
M=[-0(L`,QN,I+OVN->$PL18+[OE8A(@1<S/]DLC=G'1!:":?0+5(XN,:N=Y4
MYV/,!K+M!;:>ME"[`,7*'L"!\\0`)K3LQ(U7MTH08F?`ZB!94<C7B+KRB4Q7
M7B1DG4!]G-GXH;Q2-@]P<_J/]$CWV"O0Q^'$8#4QD=.T[N^P)H1+I*^1Y.'D
M\,?6MUBKT3A30@+'X>]\+5U]V_"!X.@^<M._#KGA1%#]4?`,Z@+W-+7!&X>D
M^2+WQQ4#7@M&.VZOL\M\*9&T06.TYM'&.,-8B_E`7X>D88-="S]^B\QH<&S/
M$\V6OVD*XW+(H`OFS84.@NSU41=I[6OU+E;J$/G*I+.15L)NGI%Y4G'"AO*S
MI>ZXT2_`+(JQ-LT<I0.*VOO5T\$ZVVP*M1Q(!\J(K_N35A"9@-[Y&D7,B:>.
MRC.:LII&84N0V:^@C@$'X:YD^XG!1V"'N="@[CYO44IRE[SV13NO59P5)02:
MJY1Q\&<WFR'Q]#=5_GRO`HYZ@&C&4/<^Y@&G*GZ?YBC)XP,X`)6^XB?L[/SM
MX^@!KXSY=H_IT\_O3<%B2%VZ&937P_3K8NT"U)SR3.QVSYO?=O+U],Q'!^%3
M1)9?U03BXC6P4J<E;CF.M=P%^P\YN3JLN7O2M>5Z*BWOL6SHL.$TQ\8`34#Y
MZ\U"6.]YR'8<`/OF09QF4B&0AQZ64MX\=+R2=-1N@,O:C'G1U$M!)^L/FR0+
M[+.?TAE\T<O2HZ!SA<"*$QQU-'14HVM\I'/3C+Q=\+IR%8P&PG0M`FA_(XKH
MY<4W`K6SAUI2W12^?&,!PD*##=$R#+M^34=!_R2+=@3HG#<VZDK1)Q7@GH;H
MDI9-5W1OQ$)\R%JED%`?QZJ&==46P&0#"YZU'9%%8:.*R9.YZ0TZFK+LXZCX
MK#2[[A5U#Z*6G/.&6%&6/U7*3[XYJ/0&')I?"R?2P3R/7PUKSM!\6<-(TPW*
M*>3B_A0/\F\7\-I!&.FZ!_@Z6"W.R4N&C[L=)$U//B:HVLSL=4M!ZO5J;]A%
M'PVN]G[^JN82Q.@57\M2@(L4.T5A+,_;8T045$/4<YO,87SSZJ]&R#E1L:0"
MA7?":;7.=!A,E=VQ>Y]R4JFYJ;_LTT)^'NRY]*9R8F+GU(8YM@)HW5/T2`VZ
M;MZV=K^S%+MG-`6LRR65AGCA2\;S@*M(4_I^`3U&51%D)$#-4#TPCS?&L/L2
MMDZ:O(ZVMX(?D+*H&WY(S#H24*)V0#C0[<K6&\%)F3.LU(#%!+<0*$FQ++$B
MK^EXWV:'Q[JPT/\OF#+[C>"QC:C"CB!9B%8\8KP4YP8";^9!QF':?F$U=,1Q
M?H4CO<3]9KLH=U_5,GQ0SH$$"G^C`<V@'"&E=<FR]ZV6@F^)9=;UNX,'<1`1
MZ&?HWXT:E`)L/L=?OI$^:];)7%DWAYI;H'3Q9,.$<C;!$F0,GW@!!RI^-MV3
MG*(WO]12N'RI2HZ_UA.Z;=7&IQZ!7V32"L*Z/MS)J:LB#LF$Q68!<MZ>WR@>
MX(!@A_7&$D<B63-.483I)'WJ&1;W>!9JWX9R6D/6(Z7_I(\9>$SYR!Q:2_CJ
M::(FR8?[/8QC+FZ"5A^H,GP]SB>IGUNO4]%_I8;A!62OW&H_?UV=D4=P)5^K
M'G1\PY>^,=]-R]75/4J-""16!F<S_-`'7W53>;@6<DZ&P\00/+8K9,J:*^"9
M)VR=ST*^/M'$^V"6Q(=>V,WSVVVCK%&R(..]PY5BKA^!(R:R0--=3CYBT_NK
MY=_]B^?&M,HGD:$:[O!01/#]8&&8YXXQPZ7L'*#H6#1(N]S3;(J2F&44%K^5
M]!@RD>#.&MY&7D,LHO"-R[Z%RCHT+)F,JF*0AD.*?O?8;JCBQ?*4!OO4O>-6
M#F_2CBCC';<C+*P!>'N;=+(7WV]O)7%&(Y+;H4YW,=L@#[&<8N-_YG0.I5_X
M)5!8_LV]&S:Y:>"'5M][WTM[2ZA^]L)Q;!6#"I@5.D/F<6-!]`T?@OL4#%*C
M^DVAEFWWZA:"<'MA[U,5O]L0FJB)V!):*#)_,T89Z\)9=K'UU(L'\]PC79LX
M;PP,%=>,CI?/GL0W[+OH`C^)=-?<LZACNN;ITI+RK=$4:0B=X$MX_L.`#?FM
M21SHR&YT@&/(`'6FS._Z"=OOQNLR,4U!1K.:1^,-7Y_GLQ$W),*K^!IY7$2L
M<)U`6]B/4L[):`!X:OP0B5/C#WOC0UN>ZDO+[HHS1JB@=KM4P3V]+7TAD+J]
MQL`%_@AP_&&!=BZNU\6)P9V=V7[U%)\K+.8ID#Y"G&8D$4["4,9P@_\Z[=]]
MM#\/$<OE2)G==(?R:_[FID7>2S<-%MD9"\%X(A#8'<CFHFF%%\1KAO!&4&B$
M]BPHMM#!'$:;D_Q/M_V7_!5PO"-W@D1(T`.^@=]+X&(0?0>5E)9C^7"6T6V'
M'D[%;YLW@'#0#'=\=_8_WW,GN^\$AR7!K290C:W&SO0$E1DX\T`_/YO*@],`
M6[)%F5^!`CW(AE@JDWB,%)-,[&[4";+FG4W_=^@(/LD?G&4FQB[;15R!^M*+
MFF;W[5>ZOR=?I;HV'LK@1`G[]T$<P;.TDRMJRIGVS8M^./!>,>VTYNOW-&Y2
MQ)=G\X[8Z(<)[+;882$9E8XP/74WQ1])C$!-Q4,B38T-`&#(MC%.'G&!9BG5
MTO#IMYZ,:+1%U5S$;C#M;0X.2&1\8RYB=OF9,I)*P^MB$A^<W#+/-`]&F*''
M%+KZ\OT%U#P(I-1O_E",*9H`\N`+7H(,B1S4*OE2.#,5P$'&OM@<+C&-??/_
MC/7*34;C0#CM:93F'P@<+XZBE@FR0`W*EIC98&2]9[T\U"OT=GDD2PG?M&&'
M0L0Z2,1VU,8TORU"ZL4E$8M;/,E:?3``@OZ%Z<34[7(GV$HK&K!%8W[V.#3L
M$0"A3NEX2EK6NC-CO,B3&^XJ)+9K&?6>1:CZ23:HV&@@P@^!L04R3LQD&\1V
M+WZ#[[4/7"8]G8K$#\NAMU7D/CP`DXQQ"I%IJ_+:B;44NE3OL6;%L/$;%'8?
M^B,MS(974DGVP34QK'=JTRJXS82*TCNG?.:R^,-M+4]WT#;*5^I:\>L<+$I9
MV>DB9AD=_;ICKYR,^O?>PL][PQ:D!__BA4P@&"9C&12"4W]?_=P2-#L'I&I^
M*LB]Y+:FE#VD7CQ%9\X9/B#$^WJ<Z!;RV:UVA)0/N!OKXJU,8<1AJ^YE+^LN
MEL!"/;?(.=]+BBWY2`I(+^ZX;`N<.2`4AKHUG*;>]#/%^A-?^L@H*%_&3FZH
MRIN=L-;X4DO(292P%$1`U.`->&*\2MZY(*U9D9'72@/(VMJ-&U'VJA&Z:)50
MK["L'GOC-[8#\7#EA;L$^%=)+_.0`PT/"I/4',_-V5]P4&2^[_>)U@'#K.A-
MN!+;8KT8U-.&%N2]-7>)<3=V-=QSQIB3K%>Q+H;^RY89X8K>LM\<>I9-H<:D
ME+.-%!FB@([4SGC32Z8<%X]1[?%;$XWIEVU=AO=DHENB]RFUFF<4IT,.-S3\
M&E%Z6?43I3B!]!K,<^6:@D+W!!\&>)#-^D@MPV\6]/E(HS6T0;0IPU\]9P([
MP!"PY-56M)0J&F(@NJ1II>_)N"/L7P])L16KU@@SJ7UGQ5YVW*JI-2C77X>7
M"LC0V#NS>GT"8Y)@.3SIV2P85G]-V-$NR@&)$`'MR*.HU%B;@BKX6UAN!K,B
M!_70`[6Z@J%8."_K%69&08PY@!H$OB]_`!RED/-V4JKPH@V4O<8#=*X2<?NO
M_B1/#A%CBS!JCV;8M(J9(*B)C/945]&4-V<VC^>&,8U'+1@3$DDR[T1H;[6J
ML7,#5RO@=UF]=SHW\OQ<TWD4B7T]!TAA@BU5EK]V\.X9/XD596/L@'`N)'$>
M^77?,N1`O!*LXL2V14Q]#Y:P(DJO=E>@Q2;QBXY3_G'@6!9KP,=X[R:_#*4'
MI;VQ1A82VZAK!J]WUE])(`%]?QO8MIYFY*(:.".DK=2<:T;C),@2;.)(\L0!
M;S_B7UAN^G(=]86[4UG;_`_QXR`O=E9V]F'"X(Q9_PH$T0#]V66VLG27;MAL
MD1C*Q+A_KAS6PL.#TRHK-S3*&[YXOO3R+%C>F9($W@P@>$:K17_N]O\Y85.N
M\:*BCZ*Y_;9X_6^.*"Q8[8>6LQ;FU#3-@WF&'%>0?V]GAM`B-X-G)!9J2"^G
M8&")8M/8"/2&#0#,.8S*R9:1O"B42"A:G7?Q_;4%]]H`-5Y8);R;,<AQ*C*7
M>MR[_YS^0@"M_;7HL?T_:^EVLIAC#&2VB>TOF>4WM/G0A2:JEA1\XB/'URT:
MTZ#.Z8(!6LHH&@&X/S91V6X\QN\X-TG[V7FY`;R]PDN-S0>SYGQ'MLLB;V`#
M?=F'R:MZ7YE9W0,7LP9NFWD33W(V&8/J/T2;`_69,C#!+,W?>>STWT.+RP5'
M*'`PA7H6PP[8,\AAX<>SF[NKQ/]1#G6^(D-\CJ^A%,-=.&P<+R,M%H4K7B?P
M7??W%W(;TUP\.V1HI&DP5QJ&(QLY?C=3&4^\;"L\]V=>ZIP04.]_A@OYPL$%
MDX5C%.Y]!TZCX%C:NDV@W>6R<+J=<P@,-X[E!`FYWA5WNIT/4Q)?B0KR4Y8A
MU!'_-ZTA[/J!"?JMAFRSAW@YB2(I7L44E-$<#$V]UC`20<9"#U7_[V2-<5JH
M]J[OQ[\N##^V^(7,C<="2+!.I--UR-?\D&A!LK`@*JZFOW.3OQN4;P+V2RGR
MZ/6_YU!_@L$+I+&&R9#OL(J5"%%2C\?OO.]8@9V3Z18*^>.A\;VGU6B:7#='
MCC$PB%LXDWQ%-F+YHPNL[[0[P#5S%-\JLP:W<1F1C8R='(YRX\J$]\6*ST4H
M18%?2RJ\]DS@!WW8N)OET'7M16\3!!5,&PY$II-C?QK78)5)A`"VS*#R5&?X
M0?5=`3"J1ESOU"7U+4^?_WBL%^XB\>5T?WKOGR(M6`-55,X#TIBX_!\=%TOQ
M%ZC.[!)$8$5G_1M:#D=2@[+_?FG7/^HH^5^3RY&I(TZ*E#^SK#855J:OL,K9
M+X&68P]+5L4B!O.NKINFS6^:U3E^\IJV;3OY7[#,\:D\XS)[G_8QJ"H)2N''
MSQII507>2CH1)J-=1XXZ`M^9MQ\HTH8"G]2Z4(%\=\:49ZD<;C/K^4+-&FN@
M=5DD,GP!.DM[<8ND/J_^C+")J2>^R.;53:C(7O1BV<Y5=J+JAT,P&7%@%\YR
MXS,`?[[MT"JS"KUI5S%_HI'OQ$M*`L7_Z4M.65E^!2/C"NIVK_?(*T:'(+B:
ML7;"-JV=.J@Y`Z`Q_>]W8U*Y%S\6=J>VYYPKN*[:AH0G)BRF&-(5-#;:!%\N
M8R!Y<@P+F2B+0V,9,*R0I[`4;MZ+W.E0XHMTHE_G?R9D6!"U`;5[9/\]"WQE
M?J3`VC9,H>(N[SG@57`P<9Z3]U_.=Z]E[[!L9(^.28C.:S;F5W/7PG%(P@1R
M3H2`RN\L*03HDPQ#",,%6&7OOC1?-PH*^9\8/4J?'#,&96ITYIGTW>R:ML5_
M;NMMOW&N.3WD76^0,9[GB]3UMU]>P034:5$N/",-W&)^HTVHX4.Q7\/Q?&86
MWTV@R^7!.!:TOBN2MC'P,5D_@A4?0K6L58/>_B*%P=7*0-1H<8U;Y&YM]XIE
M$X\X*!.5$@1']JGY!]!CZ!L1>WMZ"='_/2;S^\6\AP(2HQF'.9G(\;]9(O$D
M,$&\!K@[U_3P(4;#URC/Q&AWY,^]FHP"=@H&`44_`.`HK4$O]8%,R+'787U\
M&XE?N'Z7E647";0*^$IH6$(+=,7I&#_4C7?[)U(59C=>/1D4G`WK`67*<@G&
M<%JW"=GG]'"I@W9]M6.\,:URJF48&;YS_"-8[C<CKWYCRI-^!I`&?R;GV1L3
M9D?>H^G:P60MK!V8B:X0C.Z8U<H,E-'I/J.;2";9L:#)5JLD!\7A;+MM]62_
M"LR.I)?YK/!];M=E?^5&"_B;VSNI4!:9"`L";BQ.DV0"X4+8=<3M`""R<?I#
M,['%5DPBS]0IGNOECY_ZM0^[AW0C1_&:*"`RY#@5!0;L%27YE3M#/\M=;,<-
MD6P?S/'-',/.&8H?5'IR_#`4Q?`4F6S,"R<><:!QAD]ASA4_#73MI*:*X:L!
M=9L#U?DOA)4BVSTUWW%`"/.<_UXU1;#J\"\F(!I>T>MAQXF"[$<['Y[Q/50W
M_+D(X`C"05@^.20>"B/4-*>I$&S<*8E8`#6DAIE_U`6BJM7#K5BXBC]9S:A3
MFG(3G"EE?E$U?NF%B&LEH(`JHRH/O;U8I$])1I5@4)-H.EP&''QA^#@2:D6P
ML=%G%;2;FH.?G3Q"JZ$GPM*&6_MN<)J!H8XFNHKN,PB\7KG-=;0*?24Y[*KM
MF@D3[&/AE%-J&+-I@2%$MDG%VX)O+4"6?BPNYU?28YMPD.R&.AO"$4<5ES(=
M/SAK,.OYS\FGO2#*5=V8N,Q'40`4$)EL[21HSE3O$%5^,/,Z?OH7/LA1^/1<
M1+%S>F"8TR785H^3SA5G^7>%P^96R3.14Z3%V>!8/0M:*&P_JM;QL-4#GJD@
M0O$?/"=7>9-\E6U5(*D(^8E<V1KA(>2DCA1;<I^85#?ZZQ;1CF4Z5V3[>D^B
M:E]FE[]*X%RX*+-?$<!8TDR7R0,=>K<!BPK&1#X(GM?2'/`1XG3[ME@N9_^M
MIKG*NN_/1DZTZ9JITFU3[DP)&O]>V7MMSK,)@3X^(6UWW=$N90M\/DW`LI*-
MLCB63G*A\H-Z[POFXGWYSW?4A&K\(M;.MU7WG.K^8XC^'ZF-#:U?IL1)I'2`
MHDIC*#_CE1--5&#<@P8'[N1.8T21=*HKC)BK=W8^7YNQHHT8?8T\5"*<W(]/
M(:-R(-71Z2=\M(#&/X<A<<(85BR6JV<ES4!!-@P%M'I*%PAQ.0T`#&A[XJ:I
M=A'B@:IU&E?5$DNNQY(#/$@`?/?P'<\6XG"JR^ANZ<G43\+.PDY:GE!%J286
MO*':34'\D4E1+<I2@X9;VC+$VC,::\R[$HU&KKJ%/)#8667NW5AE$?/7A4Z&
MP\P&9KQUL>['UF(22%Z!:PBXX!T(#23U(T3#??FQD)!YW[-R\%@N'!(I6NZK
M$5N$1'TC8]_$<K)>+D/=5')KLMFD5,T5>DVA,R@:VC2)Q,(T!C((\K5:'M]=
M*$ZI]TZFW^<O+:W!9WQQ;G^B@IDQGDG]]C+T*YU-^2&67;^**A""`&[*V<RC
M6P^20=*LR5PAZQ-\AP^4DTU,@L'"IM.7R.0'#/1(,TG_2!_3]JQUJHG)V4^%
MBZ<(T*#U?8U;Y:86"BS1QNO/YM6>=6!0EY:'\(486&@,K=K-:)2^T>EAV72?
MG)'-Y!.IF^3#58AR)=ZWQ,B`*F]+M2O?E=615,.NGN(@@-WKA6DE%S-;CAM.
MF4*BB',-#<QE5KN@:J@ZW=](Z/(1Z+7?E!?<6+F$^G3HX[)27_,1=K%?J3\6
M?,<N(QW5/(GN!);QW8.L+E:)4\R\;)5P]/=09BG7`[8`%7X.6K*I2?\P7UN#
MR$V"[K#9(UE!:,1?G3CEW8B0:7]C]T2HDD8@#)"EK.W\PVC)`OG^6(<P#:+8
M]^F'<G*0.W?6LBG40F3U\"L$US\1CXVNO2\62`2#S%H4(TTD^VZOT0S@2M$:
M>FTA,<5G_^_28>:FM4:`5PN<TPOY`$HQI3HL6$1`MVR&RH6/\LVW]]HQHN1%
MWLL+P+J2,?M#M5[ARIIU:/A4ZKGQNM)\#GP?Q+[`;'5UOUFT?,68=SZ"YB9=
MD"D52KA%1T7R"7>F9FZ?W".5=!R_2>JZ#OF2642*55HM%K<7\.*;7%F6\-BH
M]BPT+9:%"XVTF)IG&=HY+:N+5R"`N(#&::#8(^BI[YT]6[JN_R+5(Q<IB;J[
M1QH^"O)B%4)!_8?U0!PWV?X;3&J;_<GOZTS*`PV6.^B]$GGH>T5=[KFU:W+Z
M1?WQ+RXMX^Y5<\P`'9JT0.OFVK@GCWP/25\+-8D%;WWEUFAEAB\++>]>+WD`
MXM-"*IZY!!E6(+:<GK`,RY1O2L1/`LWC?9UIN>HKF5G2M*L$4WHRY#$KU/'[
M43>XP9Q;(Y4@/ETVL7A8W96/ZVSWKM):N#C1K2I<AEW]TO-\6V.Q.HC*Z'G@
M>:";#-^^J6DH9\*7S%V9]=2HP=?IKU*GLTQ!E(N'[@S&E-"R_QU;2)],=#O.
M1UZ$KFK`6*#$3/=&.BU+;9L`SC-:!C8]#;=>(:HZ..J]X5(ZW>;3#]^JR4&?
MI_;,E1')E4OE`/M"VJ>V@G09SD;V+Y\'TL?=@UR!8VL6ML'#XK5SIHW>;H##
M>N>-QE1=J9W/::O&;50SD@SGUTOJ.]&,+\C,J6R'UAAJY-J#(NPV\#B%*=[)
M)9702;(`XL$J3''"T9=+=1U!D?3!%W8R^1W'%PAY_,#,8`JJ_79T^%07J)"A
M<N&??K7:UI&&"ZR[#=RZ3Z,JJ9ZFSH38R:>L^F)3_D!A=Q,+$5%3LB\JQ@G)
MZ*C!UV$;V$&9W&L6]KEB@\C!\T:[DENT/?S3WY4__)JGP#@1@2]M@C#_6_)]
MOK3!.:GM"4NM,E25)MCED/IOL=JW)_#$39'N0:_@\RHW(MW8<M;Z55KX?-'(
M/_%$>!L`KC+IW8'DUZ5]P/-5ST'RP557KRW(YI>?1%.U,:,4C-1T,/<%-LO%
MK$+27")18<=.-VZ:/!*`KCPRC86C[7A2Y]&JT^FA]MS.15C]T4S7K8%!)TB,
M#L'%2H?OA1H33F=!Y.@F>[%7H-#>_\M9K$>FGK]EV_WW:96Q4758\P,KMKAZ
M,4Z4*?.KKK&07G@3--U,3)?*MLF0`P"'LYFJ+4P1[6D@L4J97];Y$ACKA+5T
MD(UV9UMUL*^^_H<?<*+\K-GG.W#I#M4Y/S>WP9.G9"CCEP%=&U#%>R#9V,Y5
ML)&2^["PX-4@80K'.%(,YA9/FF764#R$N$1/?S&4^"<O<3M6B*5I$0YK0&([
M'P%91@P%U1NES+#;ISJ*CO^@49[O1))L0MZXD[P+RWD)EN,;+)ZE(=JU.1-H
M):NL.$L:`_.?%G2H#\<8V4#BQ.@Y@]O]-U&$4-(JSI536D(@\]^GYWRW`T'M
M:`&N+]SF=EY%BN^I.%BV$#C3:[R[89`'C^3B)CWV<V[]-+<KG4U7\ZR2!5HE
M@'U=G6BX@UP@RUCR+]2GXW3]MSIVZ*J7::TD`&K47EBFZS1;ZU^()AR3'NT:
M-,@$()9'W[K,\(MM.REV?3,?W\-0S7S%SJQRY)S,++S%!F^:H*0/H[]!+9NJ
MPMIT&>N:6O=]_\NAXSV,K\!;$$R/-!T?&$3PU>96-JFF0#$VNM#@=?#7Y(`<
MC>:.='8XKZ$[->%\Q[A#H7]EW`RO$J0.@P`Y:GPDY,T1G48!T!KLJFE0.':T
MF6`%H'#S@;)XFZ(%!LAA(T008SPQ]&TPC'.O/F]?&NR4@IB2^U%5OQ4E4=CR
MNM]V\2:@T4SK2`9!2#V["+$^O93!UBV=IB;A:&JM66,&<2/WX:>W_SI"/V@7
M*]Y=GH9(=&&O-M^*G/%I<19DNB,5]:%9[!Q9H,_R[7WTN[SN@_\D&[H;%1O[
M\>/Y)`2_^L5SO3+CRH='#5[@40&C_?R?Q"E1N_E!T7G;XWX0T;E1+`Q##E2D
M[3=WF9?J3_&%P?>,_]QE$W^Z?;W7QS/.HM4WA2%J:@R76%ON\0YK3TUQK]<R
M-D$8CAX"^?:]I/SK0]N,#2K@0F42)"M6I9M!M4A+O`IA.'7:6R2<-7Z#9P6\
MYQNF$QMP-B9&R*[UN4EBO+1($</W&I39HE''A"JLD^2G]SA^Z4>3!_O*J/C>
MGY>$UN0\EP;E\#JQ.(:E$P8;*JX81NX0JI8ZK66HR/?548&-TE1-^;;+8%R_
M\4+1D>VGSV0]SKO/^-3%$%JSJ_CX*4)7_HNDP0$HM.@,9"]MOE.BY'[X\=0E
MB&'P10+3_&=<DP<DGDI%_<_U;2B=X(7*<A,[%+$AWO.]ZR<B:+G%O.FR'O7.
MW0=H,LU$\*T;QP(VC_9S(1AR3AH%6EA19-&0H7(^7A&BL>DXG,+:?+(5MZ@2
M2IHX+Q5'U]O5_XF^V8SV4]`I9!G\=\80OPX6/A27_%LV08/)3'H7AYD`MT;U
M(TI>SF49XMSY\;TSY/X:(NWR,`)_0N/68%>5MT';+79:<N`3)3OW"!E5Y2>0
M3=?MFX;RL6SW>HV:RJ0;TOQHN1;M5A:YR]9-$="UI9W0(X0!@1L@^<EB&W6S
M4XB`=51.B7P5;]=/VGJ]E\W8#80FG'4TFZL/2C!W$?OU/XIRQ/_M[\_Y5*8]
M_T]B3+QJ77#B_)`3F0BP[:6[OD>P7(<A>??"R2!$A7<"68X)[TPOIL<U11LO
MR7#3N6P/\_U4Q1O'V@?J^@N__UG<MS>)L9Z4UL4.^&7384[P8%O4M?7T)178
M(8S65`)R2IYY"E`\"$>Z1-PC_.(;G0&D2KQ2.)6RJQ<?9AE,]9?C4L@/7'O^
MC<OB6H?,`G,TK.2/!]6&`5UOIB?)1IQ^#,>%B]#:<<ND!R.'/XQFRU,Q@?2Y
M#T<V/W<":/O(%'.C:N'E&G/#SJCJ]35[C[9"L\K9%]GQ+^_3#QDQ$$Z-061=
M!G?5CD31>JJ2?7Z1:N$+NWR9FYS$WCN.PDXJ_A5%G3T3I3/()"L-HQ,D944Z
M\,8N:(O*D*'V>MSXDC4YB.H_/LM3D4J=&X2*E:L52""ZO;!BK\XZ#C<:6Y/D
MZ4T,[W'0>L*`'9H3A)(`6^*"!R&Z@\VTS:`F"H3Z734'7/-.H+JP?I(0S<+(
M".U-"]IJ7GV>/>8Y`UAO4JSL_T%M<I?UV^JQ%_6"2^NV5G,1N6AJE+EWPZ1A
M=ED^ZZZSZ(85`>$#;X4/P6'?BUC'IMY5U$WU9_/)\@_DKC.V,GR%+>B61J8\
MQ0)_1F"LL0AL7:0'MCWL?\I^0MJ=HA1/=6D6C)=M?2.=00A.P:\I]!+PKF]+
MH+B67`K16`LJ$N9FD&=(/'B6:\MES!M'B_"G0^)B[>'+'""N$+K],D+;J+=<
M8KM]L-P/<)ERR%FI+!\M*R'.<&)ZT6V7()G4!E.EOG3B:798Y@G4#4C%<IJS
ML7X\RNCZO;=LJG/`G*,^5;G&)3RA]9\@^7>*BK!,)"_XOZN")*;#323!"Q4X
MEB2"7I3IN;*@@]V8,T@G6T=KRLQ-0I#QUO<[+(=/[PM5@KW!H\:\&<@LK$W5
MC>I^Y'ZF.KVC0MGJB2&4D=LR11Q73WAK9HB7QH#LB8IQ`DBLRQ[D"#>MC=@?
M.U^[$J1<89P@_JC106Q",H31;$T:57#A5*)J!#J3:T^,6!QI">4TQI-ZT#.+
M/)=PZUKV"'X+Y"'8-I\[B)*<(H0ZB!$&S5RD#4DCD+L0I,U0>_LG9X(-Z`:?
MWVB.;HZ8A\&0=J)4M[2,+54>#9U*'>>0:=%+4@X["Q^R0-:=?$VMT88B:,MC
M%ZBRP3Z(R34D&>S*ZYO2E-)9=1(8/G6P#$3%FVB#R$3IA0>WI0!8ZX246%^K
MU],%*.4^?R;<_[/HTM7]Q#*\Z4Q*HMM(.^"!VNS)&KSYM/;+)(HA4TKX>:!?
MF0GD3;W]W4"SDQHIJ2Q226/2K:#303D6K7BV\(G-CO.GK*84P3HLES"F^#X1
M:!79800@]W6_KAL$;;VH3-EB)G"I_?83K5T0J!*359@QL3GS(O.#2W:AG&\6
MD<6#>'+.IV^LF6"(*NJ:'JFN>:>;)1R%$N:0+/YP^@.-_PED``7C_DY1\54,
MC@8^]?P9G$5@TD]D$@F+5<B6ZG$G'S?Y+9V'0H-%7,;4P#WI*0&'U.+[Q)?$
M[)V<R7M;W-)(G2\1$0%%I0K\^(\K_!F:''YG#)\CZ!P*+5RVS/2+,^!CK0:8
M*QQQ@F>8VLB5&_Y4?S\H&,CXP*!PCGU>,="4-CHW(KL?(4W2AUF'KS`5G&EH
M[`\98@)W"=Z8F\,WU%UZ=/VQ=5PLW-XH9C(:I+#?\9_U&SH0?O0R*U\\AU1E
M@''C[TDIN+2B+.$7FV1?%9(K"BFPU>:.?P$7*4Q:DI@:RIHTX$]DP1_5AI9H
M@7C1ZQ,-J9OT[51W3[@4XAP05^:\UDAVL<\,%,/NQ6F!;3#ETXZQS1F5&?RJ
M3V1]:73ME/3U>X%9U"2=NI]8'\22%<&=VS"()A+9YG15E!>`]9.MI42]@1AT
M,1\CCSDJ71(D8-AA.]W\DBA;X:B`^;;J;&<!=>_YZ.OF@UZ<^'.:S4>1'.\.
M<_S$*5_B5Y4+^,(M=;F]D@PP>,0`3GBO(RB]IF>HC@S'[Y6(M8\30_3K>V)<
M'FXV1^>_TG0:_MD/*>W!L69N!$E7I$CI_O>4V3NU3<;A6('/GS74:$94Z!,+
M.]JD*)\O/N#A84I4[XO?`H@!+O4NHG)D87J*T4]^.[.LB<GT/I<XBI5'3-%S
MA1TRLKZIVB[CNXV:,001)?)8U/4$H8VQ.QV`_Y%EFO4-\8M'!R1&=H4RW""T
M=#&O>2<-6QB[ZY3C;2+?#Q0BZ-AO*>J(A3\HB89-'@,]T19FHAY^JJIP>4$,
MNC%3_'?$X#1&70X@4?=(5B%;8WVAW!1L,J)X&DOS!<:;K^MKZ=7H0"/[E&V?
M'8@)(`-?ILV*/<@N=Y8JQ5UY-59]A=VHA-&7]J\4U<0G1>/ICTWD4PHE!N[D
M76NQI(;!.L9,V$,TC5W,ZJ\TX=#`>1"GLG.:4IOBNOJSVHIL.EJ^>I/)U[;"
M?9S.#X"B(\+IC>IIM'?K\18W0G6P:@M]P_);5QJ!88'(EP)<A*(6>%FXM.8K
MK\:1;FJ``@499SD!3)M":@W[W4D"LI.+$8`ZB&A>..6"@-@@V9)(BA(D!3M_
MG<;X[GY"QA>:\6TS8,<H`YPT?.T1QN,@"W^WMY>0G6!(L1=&@P*77_KR1[AC
MAZ?'!F:;$SD^KI*D<7S$:'FZ_G8_%=-/U_M&U%`%'=DE9HY*-'FKC/7"H>U!
M!L<[B_ES;3R[B=VGJT%50.-="VJH]BWEWNJHVR;DX^6FJ=IZMQX<CW_O;]FB
M0&/'9\Z<9J@UO0X4M=>U)+[VT%1:GX]9&7%A#<+(6+$A;^H)D:%#8U;-5[WM
M'9N`H0A5<=2K@UGBH!6ZHY;U4,5]3;Q=/7P0I?XC6[$CX$FN^,A_6EQO7G*?
M@CSDI]Y'E=AOH&RV2VFW?K,?]]H@N@-OA@6;Z&9AMR>YJL3T:(1*ELI!F66"
M\\R$KLODD*/PG;Q53!VIK$-9CC-\IU)HW>O)$YWFIAU@3HKXI?HKRJ.,F0^\
M>WR6]2E_.3J'Y%/J\A76;W]6Z&">--`,R)I3O8EZ,T:Y^00\&.C0[^K?@M93
M.)/AU-RS4F?(?,;9A6?"JNMBR-!E]+3<_A=D`B)F`M2I6]#*`N='(RL=SA.]
M6P4.`B4?K*R<Y;[AP/'.R4^>&M8\AF;+];^ARSX,#R*4^2D1P4<3,EY#RI<V
M8PJX%([#"7]!Q7&?,UM9'L]:<L9Q3)7'0K$"?.L3HP(&N3@O`^!J+W\:+";.
M-11`R>0J/]3%&^A/=M^^[$Z.T;,@1DK!/=%O!/BE8TF-.7."-R(58VB"$4-5
M57_X(O/G'P48-0]BZDH2R)YDF6\$HJ$E*$;#]GI\(#3<ZR8*7B3ALA1HBYAX
MI63C=/3RF!%0.N5R<%J]L2%"!W;%\W)%+0#)/].R>4=QD_I.,XY7PHWOEA`/
M"?".SA/F7SD#)LN<SIJ92#6PZ5Y\90#O.WA%]E2IO4J&UP8"GX2N^N1I8_/1
M:E3"!L/V/L<IW][TP=5`/XU*N['XT9`K#C;L\$=DS\A5JV?PG+9.CBQ3V8VW
MK'W7?U*/@&=1N3>^\+RUA^2J&]2(2L!(#K8`I(LG"/(Y\NZWAP'?R8[C/$1C
M&I+@;(F&R:$Y;;LXZQN%O]XE8GQQGP),4GSL65=>L1VZ=5CMV=-\+(8U(P#W
M.=H)_*:QR05%+:6RK(N\#ZSB(X.T(55A/:>)CYFB)1S,R!'\&&MIN4!:AF]_
ME":>"!I<\=_RV8Z\89OJ@:8>5HQ)@-R9E.AIYMD`8SPT;2?(55U@57!G--6(
MQ=G5TH1'O)F$_M>'I\K\XDQEZFZ@_&APS&SHC_ZT#7T56FOK?-8C(KH"2`Z:
MC4-("&*=MPJSX.Q!NT=:]=)[-0P.H4T;\8\[BI#B'83S^O]#3SE('"(53\%X
ML!WT+Y8*H@N'Y+;4DS>)E_6$,B5TJQN=RE..PG2,AJPGB_YI(P)54.T').Z#
MNKY]>U?;?]F,GV8"*T2*D&C=YKBT^(*.P@//AG<?4/=:H<+"-\"K*.$;"JOF
MA+:?+;(TZ:BRQ?:(>)5+9,AK_CI,<3XP:Q9*=DHG36I_$0:[L377J'%"/S&-
M9GH)&D1'8(F=)M\H?//8G$96929S-FT]O<(SJ+H*O#K`GH&GV7B%0`"0)57X
M=ZI\\?(6YJGLMNC)>R6%@$.SF74?3BE7F[#Q@4+5,M30YD2O5Y=]K#S.S*`Z
M.6P32CB\/<_JZQ;ZR;EIT"[_7$\FT(S)O/12THJI(79`Y6S-/:2F9`SF8UY=
M':SM3"3Z=NA&A*&-K4&\_YRL(&I'C<2.%T2`&R=@C/7JLF<>0Z8R"K$TN?N^
M'5Z\B`FSE888=AB%RX@-9;[8X,A>Q*.]9=6(7.R905C9&@,\@G03+81(\<85
MV#NJR'P/>MBCA6^1\V?3M#E(32H&[$$;7RB!0,\KG,O`=>P>35G_1(Y\"ZN!
M0L2;1F[P4-TKET[.]=J;#E\[XVINUI#UV>[?8?/Q[N#AS0HN0Y^#B+B-PD\:
M:*`0Z7ODPLX&)/(9;U^L<</\LT3_'\N>H&5F6.\'=VZ12KAC2>Z;#PPRDC@S
M=%Q;LYG^KAA1FS-&STN<!DAZ]J0@Q0W2IW)GEB]QTT?IL-?>]SU93NH_+4,S
M,&*/WY%W1I43PY,K[7E][K'BN/>]$WG@)2!+1NH;P'+.<FHH=EP*LT?*ERG4
M#^P3POC#7GU#YQ$S8T-/1F(N`E&]%7K\R.(!]**M"-U%-=7U_\\@-C!W?UDQ
MT&\KBM<Y'Y&F3RN@):+[SQ<J&,5G.`7:DF%Y%K/"L)PGEWQC^8,#:E`Z\/.H
MM%S]ZPH^V,C'>WVHX8)P?REU^+=:O(#5:W.*<\=X$BT,PW,V6(9"=G#$GB/.
M-)&FW*H;S$J-^W_-^(NT;MWA4IJ]DEP"\]@8AHQ^2AW'C?V#C&?T0$:'F9M(
MFESRYPSBA07U;`$2*CO$&&O71"MRT-+![==8K=>`*A65WP68UY"6UU!2O`)&
M^"<[E26@2TK,`F^Z&!8K/Z278)%>IF\O.KB:80@`&6Z3<[_/YB/K%31+E8]8
MC6N#+,;/_/?9E#DT+?*1$&$1#935(-(OC\8]P0-;S.P3.T/+87<+W$`!B%N]
MW9,O^R/D7:2.(FNPUP</(@=_S+U9%_T@@)'<>6;;8`F!**G!`AKVP>6;!K]3
MN>S*YK2!B5>L4W3A%0BN4TB:O^I>?@_'0-T<X4+Q6]I*[*\D6?#:5O7T2OZ;
M1-2ZR+3Z!"Z<PT7CU+@EX+;URK5AD,,BE&,=9W6%!"DJ?K2W"(TEH)U&W)</
MD$`RX47%>8F126W[7:G>6)UN;<@<`A:%TA^YP`L,>I70!/RM94\.[`J`M&ZY
MVS+8G$SR:H\^!9PS@3,!@MW4$,$IZT(-2\;;)Z_VE(+M:_+/SZZVK==N@V70
M;#DM6F9'QLDT1GE<$G'*3]-7=AY5C"]!P^*L(`\LE%T[*"]5+!P1+HA,X(:L
MHI>9?PL)RAH8/R;#Q=/#UY7]H#&T5+@U2N6)8*>PXQF/M6AB'WGGMI8XJ3KL
MN]16'V_A;>0&AK-:B8*3V#3;/K\+JT2)!U(A8E,8>"*K;ZI^RCB#=@9`!=)B
M`>@I3V=H)XT7CCV1P&^/9ZLHWQWCR+XN4R%'[!5*LJ$01*5N_UNG_LDLQ>IU
M%582L\O!U8O,\4)B^BG,,JRW>3%MH.E>MZ98I'"+3\2H-;AI:YV&1I.?4V"%
M)V(R\CSPPDV[JQD$1G)K[:D'80QI[$(TK3JS!VVW]/,KY)\EN?P9\YOEPS(!
MZ,J$`>*F-,CJNM?"C,?B%^I476:G?HTS(9`U.A(6SD]XF'<8#^%R(F\+2:1]
M?N-X(:R+X.9\J&=;&G0:G*T)[OH0)Z#F-\JJ::!+].%\B2Y+\9W.YVE6)Z'K
M[C5.`24DF]/<A5/<CZ3(:A'],XAVR<A6-<Z5R6#(B*V%2/6]:%W?:<\9:1V(
MCOH"P_(S1?O>I97[S@^J!A!]M^GWH)G'3N:SU=8C7G"),X*;G)/L($QRJ]/I
MX6)T>J_J#-T$5-1L(#EB)%S:[VC=%3_`+HA*+?QBN7JP@NNHH41Z7>P6?(/-
M!ODD1O]&7CE5\XJA5M24YLNCH0!E'J(8?/(T,BN_?,3JDDPSKWYL&D#"!@5B
MOPIOJD2T\:5UIMY<9<"O*8'/FB9-"*!/-'TN3>L##JCQ]"-T7GM(=_1.X?R&
M,"'.X;2B:0<DNI%RYA,FQ0\EE2A-K#P\,8FMXC*-0%8,'O>Y"!;K]3G3RW8V
ME=$Z(-'9D.`C>3.$1*D.1DBI"92=X6>HK@+".*\^IW+J"WWB=7::`J[>@-YC
M*%FOB8J@PO6X"KN!TF/(@$&MC=4":,TO@,G7!8QY3,I_$+&T1$.71@8;TK7S
MQ<=_E$S-!>PUTG3N24PBVNB,-BX"#TI5$A9<X2.&$-II/N*Q^/%&ZXUC/`^4
M'QG_VW=;N:0J]&X6APM;BX$30CB1&;(O)`@ZBY(@6)2U%;9G]Q'F5!/_'.$D
M3E90O0>Z&1N@D!]]!GS.9@X#RV@0^!-)'#7:_7!X*.!;,!D.*;<+A5STT1WN
M(@<'K?CGN7#NPT<_;VT*]T5<U910.*^0S9O7#E#[5#(W%^>?/N)=0"R$<]=J
M@@N%&,O+PY_;K:M2M)AWL0]T[.N?1A(-(VL*>")`!A([4/:O(Q,.`/G1@\>Z
M'S*%/0AAOK>^&&-/A)<R1EDVRM&8L5+%33P(=?Z#`/.E?E3DO->?9$1Y+F1Y
M39"R?%YJC^.Y#;K_6:A&UV)VM%8E?*S<DHV>I)3D/&@%9?<X.PORLH;9I;7R
MVQLU0/!=)MG_G18>R<'--G#+<9[/<YS/^[`*3A\#XIN'"/Y7<72$BUZ.S&(=
MEPBGB#LJ^VL#,>RU_JZ9N_FFIYA"'G$C9E+HG8.\R(:'Y'/03MI]4-S5_`@I
MH42N>Q/`,Q^T:V9V6GIB&.1AWRI\XECA2-8)_#C3@KF407VB-[4&>F`PV4KY
M%@-Z9I1O.(A%Q/V+<&4Q>_!OTNMYH0;*#OL)IEYTD;0`7CQ\87.6*DHP19G?
M!!-T@X1-K22\E(S'7&'J/)?/106$0JY@O!J5E[I1?,IFX,55`>G\9_9CI6Q&
M+'X.8F46C\;RX;KD8\Y;2L-9KJ4'!<&"'K%@>L8P?*JE=DAE1;PG&@)[=?)'
M=/'\;"4CXNV$X:%=PWW(_L%P%E_BK@>GV=PN>"RGZ=^<["EYPL$O)UJX:ECC
M*KSBZZ,\P#T7.S4NK&K,)1.S@I_1=P,1FTV7?)CMAT/Y=P1642L[0M'!U],A
M'.2CF0$FG^S#<D.]+D*;A&6M1%EH?06*:]SMA47<2U2H?-<F/ZM+RZEY-ZO@
MSY25!(B-*#&7MXG(P-_R5Y?='O'UOFW5J&PWMJ\D-HM@7(*XMA[ORC:#)X&B
M'?Y`RZ3-6\=<_7CD%W#J7CSPH275#0O?'XD"\%L;VF3?0?K9N8@CT<'*I_FD
MU3*(-B&VJ?'6![A(B@?7O_@)][S'K.O2ZJNCJ(Y)WR?0SC#U9W;'1DT?MFM[
MBW\+4;?]GFSP^Q*YP/12XD"LF-TL$?D^:D]KTCYA0U,E)!ED(PG[B?;]7PP%
MV<5$81M+1(MYQA,QZE$)X3OO/W+AB:SHY&RF(9.Y!T4_878^2O4J)&Q0Y/QH
M=;K:*N154&9T3DA`^46;HYV#[=_^M7,`J:-)MP@0<G6AK_4#$UCLJB*0+]=P
M3A=^LP9DNE+GC*@GH7<[HM3.#IXJ=SQYNTVO%B28W$O[L&7@9**P(*#TH0"3
M7$@@,'$"-^#"7QU8,UL<I4LZ^1H134I`BH@[R_>=JYV:93`4P-LDR-ZU3EDZ
MQELW$$EPR#-A_;8F3>CCTC2F.$XI/-Y#(?%#([D5^^D?.F&568*<BJP`T/XF
M4C6H&7OU3%68((IF\2#%S:3S'VW<G%;S'EV*_!+*!5?!YMCE^JJ/+K$7.19=
M)E`_&F@0WPI$#K%I&;4,.>I,G;3B`=F&4[\`@@)TO9Y.9?D-"4F:W$9<9#IW
M(&,'D3@N%TKA2379/9('^BTX@$R`!_L5SDG+`C7G=X,3CU84^&W^EZ7@,5K"
M=7H!#EGK@W[$[=5QTU%VFL%%M0#Y&8K@LXKY,R!`NE$:X0.0:H1#N&&HB!VA
M\XMP18@ZN=`+\5XC'=&9\;F26VP?J9/!7'Y[3:\R0[\3U:V,4*73?$A'J&E<
M[+_7;#9-RM@PX/!`,2T)X1R]$BQWH,=0&%*1=SW$4S[-CGS%<^J0Q]N%5TOI
MD?)]Z3V.C`03J9M%'.*Y(3[$\0I3W;?G=LLV25]%HRW$[4P^+X%#<D'*V](6
MX0S!%<:4O94.0LDB(2-1#V=###CG*0NQ0F-AV12*R<^`?RHZHQJ\>N@'T)Y.
M?V1.]V`1,GKC&!]@[0]OHB^L>-&"#$^#L)L<:HFHA>->6)<)8"&)ZE4FMYJ<
MPI7^3Z]46D9WQVMXE&M/4#7=O0\9U8!AS.NVP44B:N_#UNHF(,W$Q,=N@O6\
M_ND=VD$)4JHLPO@B-K*7^4=GU]+SRD\\8=__V#ZIA$0\]G8LE5/"8"5"R=R0
M>8RYGH,:,ROKW?%4M\>7)_1H<:S##:#\E_CR'_']'L_44!>MU8^X@C<X_X=,
M.NRMSB06JCU[9F\2[))K++1<NT(X&&15_(/;54_W7B<&<(ZUG)BD*`AW+)6%
M#U.CT;WI)OY)88D2%DVX,V;Q>[2YSYJT2!"@HB;_3A)'Y%D>DV3<II\.I;<B
M4GEP"5Z6/B+14\04.(IMK5\:<+'-TIK#6)(&ARC/CNYG?U;)*ZH^0C,>G#\6
MFZ)0S*144X]&+7]1_V;3GI:4'#4TE@BD,53`%J''&E.B)@%?+^A-GVT^J5JI
M[^J%P4Q+;\KQ@+X[Q&-5I*&YDQ=8YD!M;A![GLQ(J`PMK=6]A;C6NY#ZT5-+
M'R<'ZNL'D:,-2H3LB%=E+X#^18"*:`#]R5]G$XG@_T-!]L=<"!1!17$"T/QL
M0;J[,<N'K&8`/&%\KTUW;@P:[.O+LDPX2?;=>D&1S=?\POJ25`MW;_\8-%U,
M$&QTYV$E[#3.>QTF]FO3-ZH,:_[-.`ZRL?C7HA(JVG;UBV6YU$-)'QA]K#[(
MO>I:UQ2L8PKX\RON9$'WV14?R0"(3WQMW&G`B13&F\"O\+<*N^/=CH*]"S:D
M^B7\T@\1(^JJP"Y'I:\M/"+4&J"6-LS8!LJ<-O9C)/,W3;O56X[ILU$7AQ6Q
M?+0H6_N,_!]K=&G3!/C>BUY0/*44Q]Q@A=^K1AW:?<A*NG?`%8)&V/IT<X-B
M0B(\>D6/`[F]X$V2&;PC@HGPGB"4-8*>SJ8ZC;DN]7G_RLQ(SL-O*=*4"(JU
M+W;SLA9/.G>41)/M(Z(Y=S@%.N*=EJ7!!BKFA61=N2*<G5@N4">7$11$4?0,
MB3+`$YX4)+=HX(>-")[G"RB=X1!0$$"&9\&>:,P#L7*9-UV3L3!#"@F&Y4G6
M>I")'J]<!X)*L?R,8,TEKN=F^6OM@YFF((8+%C,%%'W\.0D1HK,"PT,!UO7]
M\CY"%!$E)UP/CKWX;\3:0HJ'5>S>&*P7J><J![WG_&[GT9QYJM/73>$B`T$B
MP=>7%H_0M>N;KY/.DLQ#ONYXVXP'<VO,Y4N&>H6@FB_6;`88=^OHRLJ0Y,TM
MMN5NTWZEZ#&A@]4Q*(_X-6*D77J,JOU_`*09IW%[O%WQ],3;"J;E>T&2.SX0
M$TT>@GK&O%@AZ1YN`?3#!:K&GDRF<U?]"$KUI2KZ/&)FSQE41!PH'6'=NP-J
MY+*:HM[3D\PYM!'V'@"\BE7:;(5$C&C[8'@Y"C#TT[0#GLQW`W']H#<'(!=<
M!T;$MZ0;2!'O?A?L80%)'E0'`.B0HE_<J-O^OTL,MQ07PNP>NB]DO]\U4`"G
M4QT8+]A2IU4Q[(-\DY*W:!LS9O_H[[%C+:<:/*9\/IAFC3X[,*^9.G4.T..>
MY7_Z>5A.RWN>U:L+=4P)A>GFLE;\VIBS>N0C#\N@"_/A`F#-@9!;Z;^/3)$C
M3'R>"YWH5Q7ML34U1EDHY-X.Y'&>AD/)&2.OM&"1@B1S72B?W.7E@V0=KLG9
M5>1!6RHG]T;%?G-K2<DBL9^^(*7?`'V2%57QRWA(IWU`Y[-:M+EW/8>73T;,
MGCUS;.CU/ZP>ZZ53F2%+'ZAUX_BBPDR%8>S5O]KG[.#7=Y)$$#[+Z+#+N[><
M2M0&LI.UPF@TLT"A@,LG)$)W;^.W9P,>.\$9V6,J80Z0H+P1V(C\P3V^0(%:
M1+*&I2#.T^Q74MG$$D6Y`I)ZN4GXMSLV3!`"+S9@W?W.,)KSDD^!!4)-J_#I
M6#:Z8"WY+XD:8CNSNOWX!#^2UJ)X_%D/9PZ)05A_.*.M4<#>F8W<#[,B5;'-
MJNG"A,`5<&"79`KD7(><ACE9=8!`@:0&G07XP,\\QPC^EI>7L_N'6<HCQ.;Z
ME[KJ?^)M`KL>2[0,2\"7VA="ZCQNEU>/@Q[%2U(%*D\)&R1FGKX5WGF]*%IK
M*'S\(F<`G5%LMU:VTE_U@:+FN)@8VO`JP'Y2[5NBH>E*(UTD/M/3:@O,K"<,
M#7W8\1RH6=Z42&HDZNPQ5PE*&+?%=)(M;+RGR\J/;>_P`$/TA<E^(NN3_HB[
M"$F^3>)Q-4B<P]`9.FV$ZT9@UCP\87OABH20P]0#U;\L<XSN\`7'.&2$TQ`=
ME5H?G>%M?T?SS&R>\3OX\0X3;/OIC#(30\(L1JV0/H:?\=8M<_;4*F2\?$ZN
MDWTW6S@95,]=Z`5:Z].+68HX4.SY6`3U<>:U'@Z+YR_8$WMYT_K9-D?/+;&'
M46;;F:T.W`_-GQ%T2/C+M/8G<FP1=8F%,HJ4IE[8QU&P*5E13"H"4ZL"`)OX
M)'V.($L^^#9(N&<R/ND!3$Z,[DY8=*;[I^/O5_!/+Y-W%3@^)KH?`R?'CY5W
MCK]WQ0NZ0?U'F*JD@LLZ*T(:$Q:26(Q'FRLKMIQDAJ990HY'9+Y^X(']JRIK
MTF`=%&1C%O_.'/)'.XF2?T#R1@`]S?5M[P#'!7`?ZN4FIV5MB#4)=B4AR,+9
M?/CA9[I9IF)71XU2-R2)3<>>\PW8(7SI9L=^+`N?%Q^;_OQ,-H:\`*T/@C<O
M@\3<P!%@6V(!=*J.X1F>7TL7_(.SLHLPU/0G&\IG\4SW;M86_LNB^'R@Z>TF
M@E*_-J@WFI<G\+0J9&NM&P"8?`#YV6VS..+2P-R3N1"F0<]17.8(97NR1W4)
M-;5VY5[7%J\V6QN2T'R->BJJ[PO6B-T1`ETS"E!,BG>)=@Q.$,7,MC8Q%];*
MBKUHJ:L<];)=-3+<R=^(.FXIC"01*?/T'.71\;1<J4<;Q:B1`PE&D_\?@@HM
MJ>#>8UZT:-?+NN-MF&`0_K^KT=62O#)!Y/TS#S%CKO,J76]/.FC'L4M#TDXR
M8?]U(C`;#!("KE5KXRDK"6:0K''KY448-ZV7!*#=(LEO^E!I@SFG!82[5?6L
M=4CSY'Q*UZWJES5Q)2-)@:3;V9MBD[U\EE99YI^VI5WUK60&5XZ(1QE74K`O
MCG'O-[VZ9C0T<_&V`JS5R6+7JDQ"S[=\/N=I.$\Z2"IE6T&:$\0V8'7ZHWU/
MB7S7#]B,\B";K813="DOW%^7`)$M]V@)PX@X%)"20$Q`:*,/U-%IIBVEB&HO
M12XZQ3F8!TL\]?3#7@<W0M*O2O':4F?4:\4T&@F`.9F$Y(\@<5#QK,8@[DJX
MI0`[O+#U7B^YH)K8)ORL[[;F4G!88JEO193*\R#.*3(4,9/=S:9YZG1-KQ!`
M2[/E6S&'K4:%JW.W/;&C<O0N=B>&9VR!KA]K>HU4^OE]16VB`JX:"K;/:1*T
M`_E'8B81OL]A9YIYC$]B8QU/#Z=R[`%!@6?_:K>72$)"T1*V/O*\WQXP3E(A
M=:-S^^FXU<#J3^LT8/,!SSS'`FJR;GL!N:2_:,%_7WZNACD4)<,DYFC*REBQ
M=8#G)>'CV3A`&?XA%5+\`1S@V.@3HM[TVU&>>3#:!:5G01+'=FO4\*_EXU$)
MXBJC-`99K<U^LX?Q$2`H\V,/3NG97&`R/)>#H4%P5*GVK=@F6$"SA*VJ)#E[
M1=B<QL)NC?QLD#D8H9CR$OR5CT2`$]U!T$^7ZN%^S<.P'O0J_#4<&`CQ_MY?
MPM!Y<A)##Z][V6[/3_/JV+?)8&(Z2+X@I+=53>6-A93Y\A-N4)'P>$17N\21
M^:44:QX+/B!7&M/J$QS^X]V[G<VZ-#D>@A*FF8D4!?)8`=<$/\:(G(KF\C$4
MVU,+$[JOB39+73OYV9J4ZU&D!0?!C@5?(!Q5"@("<%#`-)PF%A?!K1KZ+RZ2
M_N!',UV"79[Q.RB$#;Q0#X%3`QUHZ9<%RH3U(B!R@,)Z9,XC6IU19%>HSY%A
MH"_>"@8Q^6M@PI9O#,-AEZU;JWCA^[.ZL@CX$T*;DWBQKHIP*:<^(80/W>Z.
M\W,RFO%3FO$)K8P!(\9]/FLCNA2,>/LR"CE?RNU,B-(`T&?KU@`VYU9=)(;-
M.?XU%"4?8N-U?1O2C',Z&<J3W)*6#5K.J$KHM6E$"0J$;+.FA4`>JN)3A1Z)
M8F9SNE$9IQ2>Y`;E1+EP.R^H(Z93)!GD!K-<R$)3@:>.8&#@,E$'U@D#U<^&
M,MJW`9$-\A2'[_>W2=C/?-H2WSE5:6S8B$/F-=-/]QNYU]CPKI,?O%;.`$[2
MZPKS;!:%M'6.L/=D8CEB*[2WLUY3UJ+HBGS/M.B,1MKND=9NS5UQA=@SK2B?
ME.GY_UZ!M*YSK`Q<"M4Q(EHG;LN)[]WVS8)B%`W6_W=&2-%//1$7OB@0&.VN
MD]/VS*=[(AWB#D9)#K($0&9).^W1-_KSHV_E#$J`PV_A%ACZQ16A+D_0<&.;
M;O*2=]%HG?H.QZX?'3'+@M=G_SR-Y,$E!)O"HBZ`#2=_BHKPU<"M66CT+[O[
MP[(5)&^#<M,Q`D#LA_7WKMW@WWC])0Y4=J.KF$2(W()HD0T]X%@^:HL-NO"=
MX#DX1L8W$PXGRBTZRCDFHMN"[/+_:;[*,#*,F`02RFR'!0:O!TPX#C[W?8'<
MR6A\>OL9P9W?H@;']E]J#KCE1$S1;SI,O=V@==(9@RC#'.,JG$JE'A2$(H6Q
MU[?"HJL$%->G"MO^RJ8DQD.UV-?\M9&HVA@,6=M()$C-IFT)4=QCKS\*\H^M
MZ$>?V17P_O2HX'$(S&Z:D9G,S=].,LU:?/_=&OGM&$K,*G#3`P5C?1E(1RBU
MA[)30*.+JXU8-J>FNXD]:F_5>/36JG:*'\]R2>&6-+O%(_HXCA0`'0&DX(SA
MQIK7P2(:/H!A.QNE&_G'"/6RX'HU#'!E3U,_$"QC!!WM[Z-/XO)BY[L&,5Z@
MT%8K@=)8"]-6GD,N/T#%5>FXZ2V1CM7_'(?8VGB3<MK][N!SJ@HPI1[A^^YP
M.AVEN)HH_7OV<W[A9^1'3"3W6VZ\=U'??9J>U5$S1_N1?"9IYH`IZ>8F=)E-
M+P+"^@35WK%T#GHA!]=:O\'?HTU/?&?TGC\J.]92(G2/,0BTJQG86J_QA"4;
M'VA:=)1XL8&C&DU=4S4WN4=,NG=.+G62[0_'9)^U9E4SD4R_^J7EW0H"LX(#
MGQ'TQ,@Q\/YAOJJ8JQA--WONZ!3,1A/JUJ6ZD-6[R=M)!;B*X\V3"XQR<%"4
MH@=&4`S6_)U,(EJG&U2.*W+.0YA'WNW@8Z#4&RUH2VB(7D^'Q$[(TY82UI#0
M/C>^.M!(G?*O>=OS@J`O34'<B.Y4B+C19%H7N#D`'@;^0YNL8IFFFV-?)_*@
MX\`((/5G3?0Z$7XA@54(M[&4S4S6.T"ZJ#MU"C<7QX7Q4P<<':Z;.<#92!`=
M?H]K6*!T\A\BW*K]FQN!_-`,O%6]]CHTE`0]>M^2W?$;ELT55-):;N,((!)"
M@B2_D[VPO_O[EMU6!W7%SKEYAEBMHSA'P1/"*#0KB2?D=&QEG<82=5CUOD^J
M$(GO$FAYG:TE!+8TMBN,;>;8G\`.::--7-?79<JUJ<;/PS0L3(9WX+HR"4N@
MDKZN98THZIN$6)43`LY9]EJ";+-@MM6I;$_<Z=)3(>X(4]VEND'0CWI:/IT5
MR[D^8=LDK9V_6^1@)BCKTT.U0\*P]AV+)QLLN#B36(,(JS^"B^I'EL_[A!5'
MX$#C9R)=Q/2?R^G3763FTHAJ"%P)-O=X!GP*`<DU(-+@852*E]O*:BN@NQK_
M5RAK6[,1PI/?!(MD?91'<B.$,^?3-C(HRK@RR:5DQN[C^'TV.5V.<$DS[NMG
M`]J:O\T:?PBLS-M+71_4'"FI.;28A=L9,OUGK^.'U>.D(EU%)GBT!BOF..-.
MG.&YD0,IRW<-1J]O2S\I1M^,F>C\%9\UDS5ADH[ZRG]Y1,_QLS'&SBL:.;-R
M-=>]<,3.O]2UVCVF\YA?62S/.]EG9N*)'UKVM%VX)>/54<%L6%NBP0%&2<!C
M*'>$%B_AWDB?+$9I;V$.+_&N!@>&P;DZ;6$<>8HL*Z-8/KE1ZKX;]L$Z1Y05
M.-0'OH/YL\"Y`KNWC`X=1M((!^.$$Z=5#",Q/X)'$X$`RP,T,U$JF_>QA1*R
M4G68+S+3I][W]!\_I!B9ADOUQ\>S]BSW7RFBQEZ+`7A#D-<+LXJ6<]"5JD)\
M6/2C=Z]LJ\D*AFE4IIH.8\2&\_[X3N-/LO9(R=7<QC;3CLHZMEI#TPB.2-]0
M^?]3AN4^H!675S_.5X?_<L+KS^V__0$"WJC6:?>YR(=Y1YL_9@Z9T--U;-3E
MG+9SGO7U4RHC0B2%<]9J[HVD8F#*3#(6/:>VT="OYC=:AWV]>:+A3"Q&*GDM
MZT)(7)PQ_VI+?>`F>:F"&FZ&#B6U1J2?Y%F()JX&VP[)A)>JD\S(+XA1%%/<
MJ8->Z#=5ZP`[6;HP2;%],(D+XP2>L.\F(ZL6.'0[Z7QG75(V7:M">3<UI#%O
M(0/U94\<PQ@W`J=_3-G6+>16O>*TJLIA;BFX!SX3)N#6V8(JO<C)SA09?[L`
M7A6Y_"X>T&1G_20(XP@3"=8-1L,[9((,R2]_2'0C_)#;[]QD)NK#Z5",SCR6
MX3#!6%"KUL8Y79V%X7-0`H]N'5ZV($=47-^C/`$1U53Q@I\%\L!)PP9ZP2*0
MU7>@?9OZ4JEF$%U6=7*@47F!O?TSYATY_RDQ^[,GZQFJJ9K`65X2)7CK/,QZ
MRF00>NC$$G3314/4.K/2PXNH5=X[L?FF#><+SN_'&?9%_+"T)>03YC%6W:(7
M`#7J-0>46#*]V'O-Z?2(F.[_0<9@Q4&B=1&%5P*9FR!=M^LLI4'E+1#17F.5
M1VYO7YS:LC*OF*:5*+K,IR*EK#L(\^:EGM!EL&_IRC7-V86)T)"I7A$F)EZ#
MBWP2$VZ(%0&_WP7'/'ED%KF`!1)!Q?K+A5DSL+=YXKO&9ZN753>*9+:ZF,H]
M6>W%%\90,MPNCSY7_04:R2[[6T\/,9@'B70IPJFQ/#Q66NQY12$2YV9A7+&[
M4/M@U7*=-=[1R^#Q'Y8NH.H5.!+6B[V>-#N";1+%V16Q+WEK/O.]Y$G6.`6)
M+O3_V-EQE\#`ALHL8`TH24.(BSS.?ZXY&O%RH<YGHAB[H[^`*8[KCU?<Y?!&
MTB'U2)R_7K):1NS&B)F,L'T+2)82BTI&GA+UC[=X8$I"A`N*7#Z%W)K\1+<C
ML,NE;&,[7<1R00(G4@FW@WC5;W`F@"OJ[Q0%^,D2EV+;\?Y2,GLVI6/R[OI)
ML$:AK#YHP%+-AF?,>J*$]+$C=RHG`<+`>:)759="V\6*+`I7>I4N'L]C?<CS
MGC>-G_D@W?/Z1JHH%Q![/WBW+9*]O#'Z:"I1^[1.V(["C#-U=X3]Q'X_-+G-
MJ[6K_4F.,\W1A09,N[V)_LE@B<>-'$C\C');X4,*C(![<P"6'1_/Y:4Z!IAV
M,21UB&KTS>=UGL0N75^Y]0S/*&A0>OE6[Q[Y4B=EM0F8Z?"]THLG5>.6>A<+
M9%U'#_RNS?=@I+K\GW3U.BB^,W#[5TB&*SH7`\OU1FBU;>C+'80Z1AMY-P7+
MZRUJDD^N]::2C&?\/TV+!BY[1?O@K$(@8?U2@(;)VGG\,:G#67::8'F**?T)
ME7UZ*XV?=C-]U01K'M&QH7X"=`%07#FNK+VDW>S'K-@?%`F]WDN5T*=/R%FP
MV+0<RVG)`F%@'=06*-XMVD.N\*<=A_'U\HW6T1AMU5Y@Y*^T?^,ER/:AJMF;
M'",\?%ZX_PM^_NWIVH_&1_LHT9Q//"@).PLG#<&R?]G]3PB!<ZW*L(1&.LQU
M_B0:<7`8@]T#@/@IU=]';E]YXWHPD3A":;3J)LV+U>>\@SVRB\P/%:Y-<^2>
MI-O%:>4:N-IF&AKV7WIO_B6*_V?0/812B<5R&Y.Q;?OENVJ/__M0'5LMV7YU
MJ&UQH7'=6(1UU:CI=('_VVI=*J*]Y:;AH>C&X*&U:L6_.`^S(QC:"O4>A"V=
MF4B6F:Q<;CMZ/`)XB2^%(2&8L689%9M!8OT`==N<"?,?C(':LCN`Z[S75O48
M-B<)['/GV-,O75;(:HJ&6-QJGX8>].#9JGM?&GU!6_=K`&^CCA],)<!/XBDO
M"CA1YJT).5$SCQ!"33^5KE#EBDH:F9+`/V8%,9NX%CHYB:W2WA9(/'SJD_XE
M?=?4D8#KI<]CN]@/>V$J[W6Z]KUY!,"!M^BZX6$YNH7&6RA$EU&[>7#"C/>Y
MTB$I/""N>*R%\9Z-!W`B8'HJMI[5YL7`C#)J]AU?-+%J)/I+G]'8*EF0=580
MW_52D*B?8^*@S)BN^@O3,+K*9!6H[F4RO3WAX<@D-PH3)A7N[\:KO-@!WAK'
M:<>FJ&$W'8:*\/LY9JJXR;+(O.6C"?FMO!<&JEML%J5!4=':"U+"%D1A;?`@
M.'"Z\Q@Y*3@8W0NMA2E7V<L1U0OAB&@](.K=?#5Z$?65OQA`(T+`X.W2@.+<
M>4X_!R#ABI$--9,JR,F4_K[:HY,#U(YYK*=L0:E`@P\#G@2(_K03[NLFI?*K
MX)4.5;"43"7.K7ZC)A?W]SPO;2DTJ8_E>.=ENRKJU4C#(^H/LTU,'%`EZN=8
M7WTTI3?G<8%`B`F[5KYW'"@QT\G38%9;-G[O+&>H/M9IX01`I#LT1A+#N>>)
M?$)`Y.))-"QC41:?G>.8#<#8JM="3(95/*S7KW;X;5B4K/EX(;7^(X/8+OS`
M#AZS69TOY55->7]=^;234"3LLT;2COPRR7;;'O2_NYFHR<ZCA)%4;`LF]?A<
M$P;I-4[P!J?]55%Z,]#(^[J_E+'ZI2WRG6TK*BX^XCQDX#E[S2C>6`<_[.T*
M$8]+9):_K.&4X)]EMW58)2%V.&3Z[0?=N8)D)M*Y"'7>D>^,]%=ZIOP*,M8?
MU\[96]&]W:B[/D@6%LA3ZLP,^S[S!C.-V.#@LHJQ4%%!"C$Y/?`GL6'C/^X`
MJ%=::W%@]\#SN&T5ZDN>^F'9L^KTB5(4:#2GGTMJJ+>4\#``9RVPL!BV-KZ1
MH5"Q<VF/1XW1GDLPAG/D5*"CN=<$E4J0U,I(T58LKQQK*1.\K4J'3YWB)4Z2
MK8H<W7MO<[*^M/4UO'DP!$K0]KZ<\G4#/G<%@;CKGX7-[G]`ZPY*`/4'H[?3
M6;$_6J`UA>UL)@W1")[TJ].C$IT((/=\JZ,(_54'7Q$D5NX8`*C.4@[B`Y=G
M)7/_S8K`H0_^]7N@Z'7R1?,#I"DM*"53LQ?]GR,;N"1RPZH%QL6BB(P;//Z`
M*F2:H;FF?[ZYKI_U0@&42-@,G0;7:ZE`5+;A=KHS.*@NA%\W`D3M_?K_YBX'
M/1&2C*UV`)?''^B88V6X?'`Z]6K@/NH+-]P'R*'!D;M$9G#2ZE$QOY6$(C\#
M0B/FQ4X;B]A<PU"`.-GA59A_)>YXN\8^&9H8EM>QH/:'LW,654\KV"3V;C.2
MY/`O\A93;1#F0/Q&$-E+Q\\A2#S-+/*+H35D8&!J(:8?:'7`#7,T&W9RK6:>
M4QRUP"Q7:G<VQR#1M[ZO3?X2ZN:1(4M?;&H`]J&D\^*M*>C<#0%4W;@:Y?8C
M3BXE,-:K2G^'#J</AW3A#<-*J\(;R<J@M[DK-%R@.Y1%.&B);?W=N_EQ^4<7
MJ':9:]B^O_IVOX>X[D4#6K5&D,=3L!$,[VC&:34=(/X'2"K?N/';9("W,46W
M;E>)(Q1DYX>4*B@QXR;*P9I,:FZ=31UU\SU`U!+)RG5>T?!<P4T#B_]HQ0F"
M[=N[0R$DI7U"^2#XA7_]N:6,TJ(`TAZA8<U42OS.R9V)`I1@3?1JBW#'\@F2
M0)D/YC9]9=56:\V6>:M$I%EW8<\QEJ8W8LTZVG9G:]Q1'FG`OM[>4^IC^4U'
M1@_`]8!6-$!9-WBO$>H\,?2L1OO6]KX20:`%5*?RAD$]EE6"]+Z&/:E>G2D6
M"4GAWN5?TWD_5ASQT9</+=1O_#ON@5E#&:H+#TBN"DH#_`.;UD4D[:)AASB%
MS4R&HE=(N,H7!B-K633+4*^0Z<6V?-7%*AC]\9@4_)$,!FH<+*X`:M2S-(P!
M'=%CR-G(@:G;O,L6MS;)W"N.G?UM-BILR@H2M2043`('"Q#Q18YK;WCM,#8"
M>7VK#X.>E0'2-PPW9NQ/-':,S"^N=X<W>,.=%T0?S=YBOW4_&38FY8]0H'MF
MB@UHY'!66EDO27X+DFKNRLYE$,HT:D@2S9.,UT7!-O.KW0#S"/*_35?1CI\1
MJZ@>9><KI;T*'\2WQUUC#-E)^7JIY\*6&.=$GJ:&,55!WA$>16<N\@[C%`JJ
M]1XK$.+,/_,<Z0CH"H_"W;M0W@A[$)&YM8B$MD:AKXGA[M>;?B>FJ<9SF/.B
MP6UV6IU;>*@792<K=JUR7KBN82&;*(:\*_F'J(`'Z6F20KT<Q[4K),(S8U_T
M\YR(W%2WGF_R+RC8GW<S&1SH+W#T]^;&_%N[8[#FOLYOI=UX;Y>K(%(>OR6N
MJ%URC%8XRKG%V]+;439(-P>-FFS//G&XCGQ;-09!1D$L"F+7K$P\ISSXS2]S
M34^W0S.-706YR[P.TICG]Q]'[*%TI_+ERT\1CMF4VX8)+%K7-"H+?HR84P07
M0Q4_+S4JLRP6DJ<@OJ(E7>`X+_MT>B?-:T1?*_TT'Z(C"(>_\KI%YN_.;=5!
MH,@>7X6`W<7(/6B`C]T&8JX\W)!NS?[7Q3*![OXX+^=&3D8QADD<J)X4<+MW
M"=DDIOG0]@Z&[S-B]=)LDU%ARVY1V02GTZS&CNF2LC^^%S<,-$/!2<,D&F;[
MB0"*+GR&.L0QT(RE@K&2@Z)FQJLJ#?*OBSQ,"D+SEX`*F6+&YB`Y^3<*VP@)
M:KBC*S5<]&+Q$P(JA>N]R;8Z/!HCURKD@M0C>>M%ITSHGLN^`0=U=#!H>A@I
M&'2=IDM*<H9YVDU>_)E)[)^SP/1#L>O%0'\NEII\SEUT5'&Y^]"<^4CBGZ45
M$FFY2AK+1'<2XB1^6UVA*,XRF@T;T'5V:!Q`;6AA^Y$&N)[LVX,"6J[271F7
M^1U4"IC+E2_C\"QUB0("!-FLO,*HAOQB!0RL*Y3(U.<"_Z":2K[Y3(8_Q-DI
MA6R.L"XW5$[19L1B19BU?E76ZEE,F!1"@E-?@Y]B*H\FM+3E-Z]$]/$$4-HP
MJI#:@9B]"A"V=@4EA4%+408.\_&B7%O'ONELK^Z];I<K%?@7$-M1I^*.%:'!
M4R7WD4C0RKKR4/D[D\E'7R&X`_^?96IH=;'!#3GH)ECQ5DJ11*2D_,9+ZTT=
M%O#*"*BB`_!5PSSY=O_1SO5/#@;H!!;ETVV%WAH67-@6\`@!\5M=W:R#C]A,
M:?/FYZ'&\-3$A'[)6RY5U$E&5+/WVH(2&WR79U\TTCB#UUES8T'9,/03/`3#
MNC=#9S9*<?69PD:\-_=S(%^!2S^AKPK-]\Z9($Y@JRCAL9[^*_42&]]W@!\E
M?!@KZI3*X=[A\AOC@[4**5)**B=YVF71%BQ%RH]&WL/&ORY<$C+&F80LQ1F3
M]#KF7D;FFK[-;`YT[=V.>8`4,GXBS14G#`LFEX`<8X`1G%9@9-NL`5KFM"+&
M-X]"-7,\@KEHCN^9"/(PE"IUGG-\_5T.9J&$/JS,AT:>[JI%D$8^."?':1R#
MP$-;#`F2<Z60*H#J\@>4)4#WWQP@>-<CJB-*D\^'(+\GZOFQ)8519W-Y0JZ6
MOBY.[D/6OB;[/#G:"\7S9G8FFYJX!(7XFFSAG;1$O8V?1U@4^0%9\*[$IY00
M7F,9;P3#_*K1.X6;K+>J^,6K_#*G*4.H-=HF0BD=URYCPHOS0QTPH2=(;[,.
M9\.Y7.$DYE1>PB[U.]FSKH&V#OG)^?$9/WYLJQ0O1XL##!NUBB1+[3[G0PX@
M!R0.Y-6/M0V>8DJDB.'IVV7R6CK03B*?\DL(YUH(0#RX1#B\-TIB0\Z6K)&+
MGJHBUW5N5[15:>-^S((/)ILKX]$>VD<YG"/FP%7/R^'`UW$+=:!XIW8#?%F0
M.C0Y`(%?45-^R58^/<"PM6L[SF`%2AK@%/*66:*;S^A8`:W2B8IW)DC925&I
MF%7VG2PKIAM8RA=*<LWI[U,'X=*.V/-!!R6$O``V_0@%@;.6U3"IB.$6&0TU
MTZV:FDB@&@F[M)X)1<IZ?PC7+`!266_=G`<=^GTQYK''8'J(KT,Z:$CK(N!(
MX5\7=1^M<%.$(:Q*:1W$QT^:B._6``#ZN27FA691.+(?58[K[3;D<Q;1M'[K
MN$-V_?S)K)-$FOF,U%$-RHHEN;%S(]+FFZ@T<3O\UL<LT4X8;1@LR"\,XOKX
MU9!'$;?)U2]+GM<+L'!=8'1VS@0<NCOFF]I>SIQDN,!`(M_BNLZ"R=!4=JA+
M3\CM>5-4JS>QT_>;"9.I'I:M^W_P.9`U3Q$G*=TF:42[J>%N/#!6!9P6@/KV
M_IT/&LTOV\H3_(9/N4(V`"IV"(ORU6]M5`$8)8RJ+RPO`*G\^C]"#TE5F,C5
M*.ZUB,.ALC%C=N`ZD1$U#J3L7M,;H>[PDV@@K&#V7/.G$)FOKL/GYW1MR&OD
M<Z,V1]P=',2^>_2'[C<B#)9Y_"M;64*J)T6;%<CF%K(SF"=5P:#I$9CAA*6Z
M(?,O46A5E153*_TH5!A5<)0LHJO%!M0X$9DR0[&ZD#_.EF5;DH<!Q%G159.0
M-M$ML.']/6%VTZHXBU(QV+K2=O1MO!LHN#Z*'!;!1&[89E,9[DQW2"?@HE4X
M&&'9!J]>Q]W6=^>I&R6$UPD&?;][XI5;X/R(,K(31CRI**+DR_P%=3KMP)Y&
M_&4)!FV]V_B*+,GXAGLG'$<N(H5QHI.P1)3]LS4@<B#E?$+%&MXUK**R(9VZ
MUV4KH=`%E>*PFH3VYM98PM_O#5V#50=D=\N4U\)-D/\%>!`#^FB?#D?YB1AE
MYIJ0^6RBC*5QK8@OGJ;`]?UP5Z#A]'R?%3GS=RPTLZ7[OLX#Q[A\QQI?J*):
M#Q6^$B`;SY?MZ]HWQ[<`9W$8I`5AI><LI$4!XE1U/:^QU[[TML2J-O/%_J^H
MD7B>%SX3I3?\R4GDY>K@^VBET0?KCZOD3)-7HD>MK%WY5#'9!@^?+XRM*:GJ
M++T^?6[N`F&A-/U!B$6LY3V=N5&,/J.N5AOWI)#^%FW;G:^&KP^=;`L&^R"7
M7S?J17+!)_3"@\EF0<@H%Q_K]RY%3XK$2VZ/.96OEH@(.F,TFG(JJ>._D\_S
M1BL/S$4*"8=RKJI`C&)JGE;/IU^696([0K5NV@K3!\RMEZ@G4!;`?5]#^;5V
M_RON1S^@RFE=IWSG=FQ/&EE2U/'VA"%7Y1]GP/QL/*X;#Y](A]DM[P<!S5&:
MJ4,R7J.5*!3^"+L2/"4FYPO*G*VC;9]KW>3R1\2S"]3]<B>())_7O2@BF!GE
MN(\A&;V+&5LM;C/NP_ZIE)E>;-D!Y$3_''<[Q!IIL_,KD!-;UU\D.][TVBM_
MKRU5*.+T:!8\\EE`L*&/:@4Z<D[`+D)K[!3O3J\E\.X5BPR?DSK8*05"D)V.
MVN]%,6OY[[UPZ&U:[TEU.^H.-&JD82+GJ!S;<DYXT@=M+_I,;8D-F)L,S%C<
MSQ"NQDY7_-E"*QQQWC7U?F$B>=;=/IF>(VKJGY%:9).WJQ^X7_S1%44RHMG+
M$U>W*[!O01@42YQF<PL+P_6H/KD##0S*)"LX4+@DT>3NI:="C0QOYI]?W/^,
M`4FT[:27WJ9$J;7ZKAPV3;-');N#[VJU^[NXQ%XU*KT!1F>\"&)8*YPZ`9N:
M^`:-5*=6\#%5B.HFJ+B,JY^4C;"_</8SW;*P3:-DOR$PZ<,L'NE+2W`GR*_X
M="&76$&%M&13K-@_`JJ88Z>Q!?XHUF*,(LA)*ID#VU'<.T>604J'X/D8LG*\
MFW;7YR[.WRVOK5.(P<KT.YCC9?>NL2>*D#0-Q_[:A^_VUSTV6Y`2W)H:4AME
M197WR1IT+XLKT$R.PR/J4PI?'UU*JK<'%QQ$PVYZQ3=/(:<PGE7]%0S0`T`K
MT@[8==R\CMCLR8M7F,W!_I-@@U!IXHAZ09T-B,:<:!$"J1?'9=E*?M.X+0'7
M'REV3XR[P7-W?'W5CNYRJ@GI`"BYTU]<$NXP5P3\(K'QQ;U0T?U+OA)T&":]
MEWBGD+9JO>&"K]2*8MWDOM4J5RE@STG;/WD%\+T`$I;?*&-/NL2/$><N#J)8
MLBB!1CT+D"TU.;QS:'$2Q@42+R.87D?+BMD<#79`,^T"$2AXUJ<T0AQ[12";
M:7GO[F)#=.AEG,(N!H1,ABX<1=4`>>(T]..ZPIG2&,9D9:WO7=YK.2OB7R%)
M7_NE)[[^U\65%IW2=1[A<0FLPK16=M`8@.5H>2=]"U3KEH5]US=Z=2S:T)(8
MZEK&D?E"E:!SW@`G40]PYTPE%%VSQ"&$;R^^`;!<W]U@'$'H1ZA$R:#K(^^M
M`^H]@!$2;"N[D:@P:'O2\+%#%?$*XST9WJF@IAURFR*`:_4D)=$W1U9?_>WC
M(OX6-#+;X,?"$X)E+7(O"UG8"RK04T6LMHLY^(P?4#<`U/H"6TTA2W>=8^QI
MGN#'^8;4G9QUI@=C^%GQ+?I+[?0"I\OE1JF%CE\<E+(!(6Y^4K&FX.;1A6%D
M+L@3<`CJ2Q')O7Y4)1.10X.G[#\,67\0]S+C68#$FY%O8B6IY&+R.C2.7AJ2
M(<Q=?"H+]N^BNG"MK[EH$%OQS;7\7W1S<.=QTY^W25T*%+0:B;%924A3C-^W
MJLKT_40N"8F4TL6[>:+R;8,ZZZ=]?XDVU8LK`!&#$HN6%Y$@*(0EX$B?PORN
MO\0@L6#G`B.MQ23!L'&=#16%[FP\^D]6:7)V\,A"]L]:`"861-$D!`NA,GH^
M/E59J.QG3PK^;R">TKK9!]VKI7).:%F*`7WT[VPE!$Q[/_[%$6L0@E$=EP#\
M,<-!+L<.R&CDPME(_@0+KU]^X;^]<O;GV91#'!4(MHNP=DD!BTTPVELIFEZS
M+D`YEV":(FA/^]4!@`M\--RO[!T.U,?SB!)$`A''I4)#DSCV]S0X(TBXMAN^
M2<U$KVZ"U(`^<YBN<&"(24U-_IV>K=NG2PL#%\&]!71-31O8ZBOA*=0&X\\4
M.OCL0@"3T_&)2[^X%+T#/E`1#H_'X[2BS:>N_0;,4_7;\NHEWK"EP*ZNER'V
MJT@LG2>!:Q?(X.M;"J'O:T8Z3/M8\EWA/!Y/4<1Y><UF$:*.=9W(0WY3IO7N
MSSK!QAROF+1IR!>H.9WME%ON/Q$(4T[SW1B0S'J9KJ^Z!KGXB0D%P-N3,8UD
MT\*.)97-^E"[+;+B!*/<Y/9WO0;,,M^7X+'EE3R\OX*P1A,^&!$*C!"S-];[
M(?AJ)6*FA`@V6$F7(F3>)3:/%:[]>1+85OQ259:(N`UF,O*",UC5@OBN\&"P
M9P9P:MI*JF8O[KZM&1C\5D]1_]=+BU_BS)!E/=T#0EM:`I;'<:\4]8DAQQ(5
M.F>'!D:Y&RE="8:.`I,J`92D2#0R#S6[M11Q1KY:-3Q-.EI?R/NCRT*[B8T;
MJ]P6C3K*Q,()K8"J^VG$Y@T/ZLRF*7*!HRD>\^2]SDC[0&[F&'+'SNHU@6^(
M/>.P(U8,\LD)GZ&=RU?3?,#\-7P7WF;2VNQFY+Z.B36#1A@/+-FT\PWL#*'%
MWM6_77?8;_.KTSW9H@=44.^VQ(&9^1,E8-NWHDC]:U5Y8N6#Y7+6/9'X#!?V
M.E!+\Z*79'=53\9NCL)N_TY@PT#OAF`Y!HPYD'H+HE$]K@^NN1\*BW*;"QW6
MC/O_H]40)N,_Y.L^H\X`W^MVFZP8X'(!H8HD8K:TE)4=5O9.>;P)`-5GJFV)
MMJ2^6@PSE'LWQWHXI':`:]USAS+2C2-6(%K<E!=#;'[O1L^!EY"V$GAL3P!)
M.4,N;X7/=8W:('=LG*NA4Q/U\`"L\8##_69"\[@$R5AY3)E+Z?V_B8CG5]T"
M+S3=:N?<%%C=\U$/0[.1.0Q=EF5$`;U(Q2WG.:9M8^`,?N<N4(X6$4FSJ4Z5
MV*@F[-]ME\4LE*W=R.]).;9+4O1,L-%S1=0D"Z:PRFEM,GYG;C]I:B8EAC-:
MXBIBNC=%L)+CZY@#'%%7Q'J)96@R@=F,61\?$^$M(I!AF,(O3;J1I/%FF4A9
M[=Y?L^*S:*#N'>1C+R6?9X6BG'-#\P1WP:WXN6>.W4G]@S&B"(=QBR8]K-MC
M['TQW^!,R(:JI-[C*OZJ_/'5I`XYL*"+@KPR=*S10UUAWEL.PQ(!CFS3D`TP
M`L53`#:W+%<Y"J;JAAK*=,TN;6FS6`_(ZIS*PQ.F/5SN;`M;N.74)CGIX3O%
M+K5#B7&8M>28XX2L)=*WWC8=YTQRE5\[@UISEEJR"VQH,C,QK=60?YZS:GYV
MX$ID4JSSR#\I;;@8*]$L(-X0%)O.^[>)!X)+HW74J+T1JGL;+W-*VN7,TK:Z
M3_HRJ=4O7U:/$J%"2+U9]`,)2:%Q7T(4YD3]GO6NM2X*A[YMF#?IZ?H;=F-=
M(26^.CY<DK+`\/WF3R[_EXCUJEL)@!^)/.1/ECOR2<0>$,!#Y%3E7X`)?HDM
M2VS%L(L,*L-?]2JJ._V\D",4]+P!=9@JIBCH<!;*KV?]G"XV!LS6#&AL-`A,
M`[DC0X3TCDWO73&\\?.W_IT!VJCUO,3!):->UD^A"D64C8ZK7.&Q]A9>R`3J
M2A%_P<SB9ZW)1O=;LYNA675NXC!=40/PQ@B4SPOOJO>*P0#VZP5%&X9I!`-[
MG^S]7/7,!NUTJ'/7CUFTP!B*(<B/8BT7=^4K_<;^F54PF&=O?$9CAU.I@D88
MC4J8,T9%D8R)*!C@T$.@KN\F`*$#1_'H'T(&Y"YS*T!EI)'G!BK/5'%RSON'
M4K.-X'0((D9<[=)0,#`#22M`'K'L'?:0*_=$.W`%YF$$XXNL6=Z'H(DPPEN&
MF=3A%QMOH?H/"^J6]#R_N>5$OWG[5S`Y&E=1&*#1+G/PS4$[FHWOBC^&V70/
M%51)SAZ_NEF^PH#D!7><"_6(RQ(R+JNQ]PIBJS>=CO$GJAE9XU3%TK`14BO*
M-NG='WX!15,N*/,S+HR)]"IME11L^A6UK$1N=]+%1(1T)9=]6X?]?,D\OX'!
MR9PAI+;+UH//YO[("`I1Z!2A7FPAO9ANMQ94XPW>H==JTS%8Z4Y@[H8>I,V-
M@`#^3R/7M=P52WDQK!HL?L+?R(\O-4U&#\JA3F(N(I,;O6$,&>+E.6,Q7M6^
M'OLU]S&,Q4$AT!)RR<-+ZOVJ!TKK/#]P:'`@96-H;R<\/R<[/SX)6RD=6H[X
M_)'C2Y$L13)O4GG5P7.<^9F0!N7M+5TB,&5B8K(8X088-OOHOS^-;BD-ZD?9
M^@IZ@TK(C/3VIUCY6]3`%,B4&T1_V\(O/XDXW!MM6/VV\L'H.%,?V5FT)9%0
MH9.YA1_/K9UMKL/JLBQ!ML+.(\.`2N#29L6)>@Z0)V0$OEH,L9R]NMORB.6.
M^#$#VS`\>8>8U4H8^:;1'S?`V!S\.-0TY<?9;/<[YFRF5+@:?*+%\*"S3>?O
M-1R5]^@YSE></LR']]@$YUM;&4PCV+48%D.RQ++_6$Q^%1J6L)X32,2&]_H`
M(P#3,6ELL>X)A/N[[H`@<N8V!*DH@C3PC%*H71^F!9K'?*'PO*`&$MQV[XG2
MCM_!)A&@+Y$G=;]LQ4B&;`#?WRIO-$19@7<G9'2(Z+3\I6CMZF(.4QN!6)-,
M=TR$-GI\;5'C]%+L4!U0K85J1'&@UM.Q<'#^Y`_"_U)/>!+:`QP8;4UU*\:V
M?_=+@2_>JG7IWX-#&5;-`8H"=M85.,JT;)!NO\?D@E@6>NUBF33<[VSL-L?\
MWRH8]9]DUZ&0-YE&";.6ZD5@)F;-\.EALC;HTWY)HW`,2:+[T$P[NY$J@80$
MN`Q0;"&=TD&S9EW<A*TX[A339E7P"!BG+M/T*;SD2-S=C4V54P$/@$N72"",
MNI:B4]EW?U<C*`3J$@I9]N+`';XYW"4DRRLDM>Y:<9[=/GB9OIV4]OY3ZXV$
MOBU=G>8WE82=%K=BXC[/RY+8@&$LSOO>ZO3@J6Q"-X7#^,KDT?)`#*]LV('Y
MNA]'(3V)T$V?;X0,>`%L5%)O+=6)VQU"6>R5@01M1KFA&T5)'K?#I>BIGO6U
MR7I9%PTE**4[+Z*NGH+UNV]>MHGZV4&B1Y&JP)<2T>O\P):\-T](!01+R2>_
M\/2\:7JIYTH7%&_W!TS@L]@5-P*1!0@J58V,2\F!42M8R;`5H"\5+@V@P+]*
MZ[;R;Q;8^!WNY'`T\D?\5VKC[,/<.$%$/?U"7UQ&66-EP97G'?G"P!G[3=;_
MS`8PV-'%MDY-`,@IM>=[3VI-&V`T%`#64R`9Y)-DQN)Z]Q#;2WH:2=1,I.WX
M?<0OL_F^#MB((+P$.Z9_P<'G:BZBZ[&05,4HHK_R'KQN(3W]#,CIM?:HR6,@
M#F2]"=DY:[BU`74:-T'6"WV>,Z+>TK-Q*R<-3\ZY8Z)B!T6^FIOT9WS55(#+
M\D\O"37_L?ML)7S2^4@)/C2%7!@VV`(1E$R,@ZUGV4T1.%PL.I#.Y4Z.6`5B
M:77>=1'0/15HSISQVM33!GDT@=FCS()^6*;2W$,;_&)&\^M+L$B9E$VB*=^<
M>D)7F#:3SB;=^+*<"Q*V@TPZ#R2*'<0?B&3L/>69I&2HZ)``X1=-_Q(F:BFX
M,>K(RW)%%273:HBF%:$J(Q8KA'_?[B0.5+#\WFX(B3HN<KA<J\5WS99&C_F4
MTSE306>9H3CY6Q-=K&_>3+_.7,3SKX;_I<C$QYVBMN"R%XZ\N=\2<LOTYU#2
M0W)GB*Z>2F5(B14IH@:4'?6?L$Y-DU0?4=E$C.,"V*:/V",FM928\E*YN&_X
M8^J#Z!Z[B1W-9Q<?2=RP`2'0_CR4.*=]*BK-6<MO+*-\A1($K8K[T\L&%3_]
M4I$KKGN!C6ZNT/^OJBG:&<Y<2"6[/$_5U]G*9F6/$(%)=[JJ(DX^#`G*:'%M
M.@(5K#/"1`M0\<U492$7%``??.EI/9;)]_6)0%PE.[PUZ_-Z1PG24@9`:!TF
M'.K3$LLZT+"BH19SJ3G)V:R(X+)I<XEOSC.I4XP'7?9"!**:N#%:JE[P\(1\
MJ<%>,70YC4SL.\E]WVX,YUX5-3[Y(C'CG!XT\R.SO&6A7U"!]OYH^PXGV#I:
M/]PMW&$W(F8!4#RN)DI%;U+VC)Q5>1,N",1],877D\ETXAIY5/UA'-J(G",G
M^1K@_S<GEB\9,1>(4Z`%LGK3^[M2`AT0DYBF=5^[I8%0IP=&;.<)HM7U>&>'
M.\[[BI:U:'9ZH-/.V57?^<?.%NC[3"#1\"!-7?9K]1\VRFM-5-2W,GTK7NI#
M^K;&IP$C;R6TW:^DA:4\(7U!,(]-F97&0,P'QZ<B6K;/CTN\5Y'9SS"Z%=)*
M8%*4%^::>NOQ\E+TLY;;?S+QB1L2;3<;5XM#&U!N?0EF@,@*=P]G?>B9=H2Q
MH_DC;(XX*2-1XF*TSF/@KFGH3$IAO.)\R%-QH+2HK#*+'7\8*=W&5P74E7/2
M2*E2L#IH!Z21=`0HEB/3P"'J_I#SMFR(AQO&NFG!&3@O=;13F:-*+BHF]\72
M3":.=]0?0``N$+CD)6-P@Z$UX>>+UV'2YS=B7\KS=^P\;EU]T$T.T1L'4"F\
M,VF[>X?EM-Z[>Y9I@E5/'EI]36H)ZR%>YMC=Y4.\D)4"GYWL#7%;>9LXP<4-
MH^WJ!2/,&"XS#'+9>UO-)3MIK3^MF6RMGNMQ6X"2ZK^]7M`)HR_"/M-0?U2X
M[ZAY5`CX;@?8(KMS24?S\8N@LL%'`>96G2G)'VYXQ$:NOVLT*+GL-T(9!T<)
MH>J"P][G7&*CAS'%9^R"AU9YWQWQ.^4FF$J62R.&E#13:JA,G<OHX![V/%2Y
MHJ;A_Q[_,WVQ/LB9R#R$:D-5$(5X%!I0BN8$D\<],:L]!N#8F=O-2)L.3RZ4
MCUV&;WFZ&AI6_%K&#2+A(D9_O@_X5H=3L%)99JEB-=)_ZSG`'!M<#PD6B;V`
M;>9HT6<59'/KJ\V=>174Z?\.-1J1]&9+<#/.C.+O5G!!<K3S^;GI9!$U/)E9
M><X1K!NB`)+(P>K)HK2HSRK.F($P8781.TM@HX:9RZPECW3#]:NJN+%F1;?6
MB+EGFQRP<&NUZT6WIM'*E<;PODP..%^&G^4JK*LR)7A],<))QQFB0>;H;G(!
M:6V#N-P=!H6B<S6=Z,'+0@RI"2@!VW!V@%>1=`[B]%H/NLFWOL\\2C05*82Z
M:DA<IU)O3[9"%>7;ESXS4>&`E#DE:>A#>3'H[YP_<T1@I`GSGZV5J@ZKF-^F
MN$3V.<U]D+G3'&B#25.L$SN-5A=4Q%(^Z)\7)M[76&MM!2(N1,WT@N$6\962
M<FJ9-JM=J,NRTJ+)IH.XAN^8G9D@PW/'G/'>CY3XH$JN<>=#':-=URX@!WIL
M;IB74PJW(^Y?[D&;N5`=;[5D[F\--J'Y?\Q@4`:,.DE,D-2I`V5RR"QZ.4R;
M<39C,CX+;8*.W,^%16CAX920HW4?"IN>HD$[<7B'J<K6D<T/<2J_+1=FU7R8
MZMD&8T[29$M!I$'7"PFF_=9T#)TF)O[)J+<O!"PHZQQ.O<.TD,Q09[HU/?A$
M/*W+F-5<_R@2HBL/C0ABE6)9K15:$PFRK)X;I;X7BX?/XI8-E+ZBLN6J1\91
M7B/;NWH06^B)D78@!4TW^"N+3<APOF\"0U<5](-PZOF3>'/23LT@QSC\$=%X
M0#3BIF.X^QY0\E"\BAW)A:=A\R1=6?5+&(;5'O!FMHW1HQ63Q&-B`)F?(257
MP\>`EX)6/6"B5<KO=K*+'(^BU7R$N;#_@`YZ?5%4#Y5,G9@%9X.ZR4T>-EKI
M:_KQ+NZ<;14\&WEHJ4N]Q2HWK<A>76$$PYUX(7]HC`>ZZ^P>'$8@?PJ?98+)
M5Z#>[WU_RPPIP#9STRT-HM/1?5D;A0'0?3?@^^J/I"2\>Y\8;+5U%4F15_V.
MAS"6'AW8-J/#(S=2,>YNZKERU#`"Q??2:)5.]G5P1.[UOH34(IV4JMB'Y1K#
M^7CVDPO/4][8:I.&]&1G;KC.A9,`B-$?8[)3MF0"Z%LQA8/9?LC*FI35;5F+
MSK-QU\J"0LL$;C[[Z:80]`J00T$.N,H8^V=BIM82`.G52*2=YN4B5?!34A*G
M3+]$[$DU:A.3E1;P)J-Z[XB>8*L32<Y4#%7P`#JK]27!L-H(/&$Y)!5.,=^L
MQP*K.!_MR^_$#.K?+YZ>Q.V:;H+[UEO%Q70:9$[$KI^NA7<E[>&W958CHTO\
M0)T'V6@VU1*PG_JJ>:W[Y%7SX-K!UN_1$?J`%A.[RH@IQ(0:8EA#_E"0GZ9_
M^^.I?9I$P3/C25WZ!)1T9V_6XN5#]N=F'VF!;[YWC8G2W6KW)WPPPE!=MBO3
M!X8'KZ"^-?$M/39X4/I9G#9R.W"+]6\U'+U:+"2'9/R%KQ&99_\07S^I83`;
MS3_\$3>F$'VE$YB;=3VYH#QB;8WY3[63MXYIS-K_/4F>HR*3/_OGW)WJI:IN
M\KF925'L<;'Z?U`4:V)AK$D/=9]:VQU[<;S<H4NX2NOB2(X&3W\U8Y@J[,O7
MVWOUB#."L^$!\!^]5X59=I[*X_1GV<<X6\(8=`[ZL"+&-YXCY3]>E[*XC4VD
MZOSPQ:<I,3@5J)*>.7F)$\W&,?&@RRK.(RK#QA5V\')\@_DATYX/VH:%-?`*
M)BIW^K72@`<^5K=\+!W4%D>`*J=I/0RY"HW!YE'BBRH%R"DP,%S,_(Y#V_(G
M.P%&S<&N1J-0LTVWVS7]V2PMR>CC:EZ%C?6OIXO'95!OBQZ_`J\8Y6;8%"V\
M]]_LC=L4*&H;\I\A;!#[A/[B/W@0PMH.Q"I<E:LG9\E]I":GUY=.E,F^4E;!
MS_F^V;[639>_`G3_0-'YS6+#<],VI3&J2-)NX1"TC+-:`(QP7F^M,1H,WYT9
MI#[Y6+,/%4`$$:K&<)#'YI<;JT_Y"0!UL.FOSY`!\GAJA6@6M&;!XH%#.T[U
MTC@,SR7;QLNBXY+J%(7D1PVDMD/S84/:2*4/05,:]:I.!GT`0BD2_6I+O<ZP
MD=[R8?NRO4->.;"V5?N9/"5"9C=4D*9)F;B"T9AT>W>+37U(0-<$IM8-A+XX
M]-DF^T$6V33>8:0#OC.2,_\*J@RTU);'T@OJY?F,L<K4(72FSQ<^Y8<$H+D%
M2(X-R).]*)N*1)D5.ML<[%:>LTM(C*2HC_"9*\D8#O^,"S>?2?'1-WW4#*NA
M<0UHY2=/$@5Y"6[`^=CD8EFU5FT!DXEPK.1J@"6'#-V\_PLU0=*WQG.8@69!
MFGFR2/K-*E)RI`-1?!$]WY@/Z#,5--UR<M50&+D;RPOM6""LFO]A@RA0;GTO
M8R9"01L"?U4E8Z9IP=$CM=X"B]*7%VIC6+#N++Q'8`QXVD/<_.,"F8PZI6CD
ML2C#.B3BEXYZF<XD`C(L-DOGK;S``8%->TZ'\8_@#_;JL#9DG0CJB02,Y#^I
M-H%5>V9I\_IA`6>][7%-^-AX6142IWZD)!!!'H.304I2T:=R(MA'X+?!PT>Q
M\$^?<@9$`-2'O7U@?2+4JJ>1T,6>EH/@LO?#14=1%O^.HY]D+S"R_`B^D\_^
MZ:<USA^?K^AD)&-3=63.:YYXPO.;FW>K/8IK"RTUS._\D":PSJ4>J_82<+97
M)"9<]N=1!)$^]/V<&8%E.-O&N%G),K,/P<>=[*MIX.S'""VB?)`K<RGA0=K!
M_T,/=4#D5OJAD:]'X98_E:M^1JC:X]=;49`[I7;P*-GGXQX8N;%A=%%\&UR%
MF6&W@JN*_H?QAQS\?VP[DEE4\M`+$/B+=]"U>T@HJ>L_8N[11_PQ7AYXDI]=
M+BL12<F\$?%9#F7U?%UR`&@N,Q#LPPX!4EDR'YGR<B*<9Q%:"+K**CG)L5BW
M&-CJ.3]*V`_5KF:0'W%YA.(NC#J-I5:@EJUW:&+@H8_@>7^`/#R61+<9_-R"
M[4]D'RL6\E@W'@C++BP>(I!#JZS'6T;1+3[CGM=(5L)>T<Z,\CF*C"P;>(1Y
MNR:NAV/II!@CDAUNP$6+=O;AK&:GTD=915\RHSI)DV00+6^:8/C5OS?$O\AW
M9CUD.D,NC0Y<D'/T_/P"M(0I7!#[@>UR4<H7/99S)=B>WYB1_`('C<G>]:4Y
M)A7$NF2>1^**^WZH*CV$E?W!3ZU`8W_#+`&39Y;,U?MH@Z]`7I`C^E4!R(65
M#!2(K)\!X$SO8N`GA'@YW)Q_.:-WA($?%!(R].S-%Q[5H@:)>PFU3L8D,IGE
MBEB?K?$'O+(9Y$38F1N=5H)29&0:J8U`]U!0:OF$,@KQ2O?H-S^7"B4M.!@X
M5S&9:T8>I.S9!=QMOE`/[9M><KXAGYM)UNTA:"],7'P*&\<=(V+=8R^*"&9L
M#IAULFS`5]85IJK#B"X#(F(^Y+52ZQ('W4]C3F#?7!#0%,VRB$]](Q&/[OK\
M.S[@N8=4,E58#.W29M@LZXE0T?J**Q<()T&&X.'22[E;"U11F>%05WLLJ^`E
M">\\8'$G6#IL"_W&VPZ<T)`VR7GKQ._VE1LL05R7-%$E%]2&]=D];-;T6$FM
M$%$\_E,*9XAOZS$(PU1UGM1-C2SM.(#$IN]N1X0%4&?^ISG!':+7O\BX,K?6
MPAQJ(N#$B4]\!N49CG<AP:`$2"_4_+MUQ9.%"[R;>N&U+!OI['+76\(D3>[@
M%5FX.E_KPXO#4=N9"!89W::YN4+VQL1DQO'-`.H*__0_?(FJUQPK0$J@V:O'
M$C/<'4LB<7"]BC+BE6BF1K4'(OYETZ4&<LE,=]((58YV(YI2MW?^'A1ND47+
MY'64?)^^UFM]<PHS#7\Q<C0*Q@ULC^=K`5ZA=_Q//XE0V`(#1TV=QMS9,;F4
MNW'T_@6PF_&9%WUX6#LTW3'^I8AW=X^NQQAA($G-:93V%T`;#QCH2%$:]9JK
M2CI`@#5;E%,=8,+A]^&*;.Z?$@_!:;Z9'7EF:99DZ("!-+\E00F,_I\JRV#G
M!4O&WF)N':?R<R"*:/J!M(\=W7#WJAS:2+B=;J.?S4(A6C!K1LF#H>;:+`Y=
MG4DN5%[\2IA\^\G"Z.P7#+\77$XC<A9Q_+^Y-$4^%<!HIG?EFS2P0S)MZ#-T
MQ4N'RFVE_"GF5]"0R]=K`AMP[%-2D1:?Y2+X%V!K3EMF+=@&"8/-9V_\4S#W
M$=19BUV:BINQ0;W*7$261R1;V,Y]#L7Q?5C0@ES="O-7)D]ZSGHWL2AL;K*F
MK_P-NAL-4="6F90N_F($PBFHL%>64E"&H7M:G@-@\\E#F$C11CMDH`0:J\/8
M+!?/<3!,9\"DM>5'+KPU+%-Y'700QH,6AFL`.-.(:DA1SGJ")&U,W^SV(ABG
M`,*LR*],V`?5H;37AJP>SE^(ZTW0G:MUOMI>I/W$2U+N>4SL7O!>X!>LHDN`
M(O=;L>8?R\9P_LG>0G0-5\)A<#`$JA/KN:-7YWQY!;ZZP(5BO1$5&*>PJ2Q#
M"6;U4O,B31-4!!8-4_9=D=';=VP18MS%.:_Z>:T,--$5-B)7EF60'$>=,"I]
M2B;I7NF9!5\&$AI"*/@PJV7@L.^E2>%0TLI!JWHOYO%/.B4!:^)C2)4VB=O;
M&(])<;C41GU>5T)FLX\"T!GWE1XB4/""?ZV(:\,/U+M4_3I[(,E.LUCE]OK3
MDOR^_:0*&,PF,E^PL86#.3)OX"!B<QVSDKS0?WB8[&%"%2.(/!:OSSK3OT_K
MP/VEH`1^JP^ZCV*,QN,DE=GJSD$XD[7%G@G9!QKQ^!Z#$/Z+>?$$SA1ZTLP:
MD*]O2P)&#_?2:CQ#<RN&H^I`$_C:Q+#FE><$U%=Z6+BX@Y(`D]2)%1UH:#X1
MP!U]$$9F`Q>7ZLTB^`6G2/R[O](%Q<9)^6I#OI$F.K6.C*8=Z.RL=`!WLT_A
M4UE3J+L5YJ>%8B\2ZH^OHT=VKCV0>@`>D]]^MK_L*XCZPB-.AO@-_V8+P%"?
M?@J0,NW.)4M0Z)K[(><>/"\-_+I#=(#LN\\<8&70[8"`)!_GMG/O@E5!'4U'
MFANJ<;+Z7WGI,)=>#)3.ZBC%#Y(PFM+5PX]$)@T[?=57*0_CRH@E_0:O3]&W
MD[2?%#R2QRCN(YOI?=#'EMU],;4!TA,DU[F&XS0GSZCV&@H1:!<OB`")F)`"
MQI7Z\L?AC5E/X3-*=T+Z28V_(?Q?@^^I*PZV]LS<;&,KS>IQ,+9,%*13[`*1
M-[!:=0,9(US9%+_J;@(PWOSDZ.[(ROZ"K/`PXT`M&KF,AA"D$A7%03\[K^L2
M`3;`Z[14IG[]XN#R^%G)IOV/[`!_(\.5"50,<OO,V8[<7T[1\$1>90IN(%U\
M]R>=[M@?SE")8<3"#.'(`8Q@P,Q\.*EY)_Q],2!+^-.)!B8?/-BW^F-`%*F.
ME09P'&))/,`+*_&V<#A(0VE`[D<#9?-9-6^".-+([=*S;J*LGWNEB>P[2"'Z
M*)+B!$MHND1F1(,KF5[MUGA?Y$,T3R6*"`LV7#6,^V<<S,?#S73!'D3\P(,H
M97]NX04A'Z%5I:T15W>R26\I4-A*$)_C5K,+I:+[696ZRP(LNT<%C04QXX.+
MI+.*058"9J'VF9*K=ZK7#B.,?O\^+*J9E%!CLV8)ZDF2"I=N8YW`B)2;4?.3
MTIN2RM,G.'6[(F4L&'=8HOTOI:!<FT"WOKK_A,<Z8=.&\]_?Y+:XH"TZ&?M/
M@ZPYYT!WY++6V8O"U_:!.&K&[3R>R'2^&@IWLR&*CZ2=!L<W)H,7^WJ'EW':
M"C77;9+TBACP<22?(#J)+!]@LO9,S>J:MTE[A[CXC9QN#5`Z(3.0RE:_"S"X
MX9@.QJ`/YH"'ICSN^4C+30,!]AT@%O13P,,?7T[5%D]B,I[EB(D1YW3=5,VK
MEBY3L^W>41N2QKP!!*(X'O*&NG8V,C=E/_$8*1H1EPAB@)UT?7R0A>;)"<-1
M(IC8Z'9S-[!'T5;T+)Q']'=]+1[#`:_`T+"'VQI#)LZAKL1$'']C5'',@G5?
M!L,6&]6H$1R$NU7`OP6^MZG!>6-B\D5;'_8GNZ>`]U-JB%*8$M%5AN/#M%,7
MCO<G::G!+\:8UT+5;O_43/T*'N*32@DLX)>G/1V3M62CWZNX5PK@P+OG#8+W
M-L_U<TO$_V\.,%AD;JG"G7O!6*%?(FJ;REF3C%$/RUW$=()]?A$`);9$J68?
M+8E7O3"K],-?G*`+?:-(`T%VX&3#/$,8C-(&'_QNH"#5NPWOINRR#,"1UQ(J
MPW*6E3Z\Z?:8P^KOB:((<_A$Q9Y%5;RDD+^+?LOA]R/=.Y+[SS>EGV5*C)-L
MUIH-K#7[)PP]O)&:$I!@Y-0U2S9210G@&]^`\5*N%EUM1++01*4M`LR#(P:+
M$8G&9/([XS#::#\(4.O57B:,^T&*VF8CW6A6W;+E&Z,%\E/-4A=RK%IW#6A$
M:"8M.@VO;BP31CI/"1%G_/(G<0[3M&H=;5D@G<G^8>HQ>21F@W5.'+?H_8\H
M(F$^=&B)P3,_9(I*:S%S8YD_PHIX7?+LM"EY:>^,#012Z(#2#"</PK`O]$L)
M"F_WQA)FB(]]605<Z2@BFA5"K&ZYEN"_OJ<$QC36-6L$9VQ[R@I2WF)"WO!4
M8.2A%]X[_X2$86\)[[HB8W>L`M,/DFW6V)%LPBA-9R!;O$N=Q"E9XJ!M$Q7"
MO1WNUGYI-RLO<&-I#HWUS72&1&9:^G)B["P")B6#4#W.C3+4X`SD,'5)0=IS
MT2I7#W*1%%FH!`$SDA4]Y7O%L]V0&#'/L0.$=$<#>8=UA<)FMF(;*T&-)$4Y
M!@T=ZE;#38.$'(2+7EFV)+TD^21G2P"B%1[`'O"7RTIUL]W_DR&"P1S</%4)
MRF.%'N4X,DO1/QRORWK_R\F'7/.PA>GXL*T"&1H/;5<SLKZ"&SD>L5?<K6%[
M4'W0WJL"_9K.U#F,N!7%EEUF$7,C<.F1"VARD>;.8(-SYW$3]_OU'$%(VM.S
M:?I%_^L7P\@0FK=#=D!F%HTLSKW@_.FI5V487J1,2ZQ)PCM4+.N&%U9\6#DL
MYT.="9?%`2&S;6%?V,%8DQO)6D>@`:CYQ\7:MYJC40O-2[I#$/'Z.J*R.L5K
M.W;QLHO!+BO1WT%R4ZJ'`$X*6N>+RWUTVF6FE"1I-0"%`_2R?F>AZ3:\DVFL
M;Q3*GF85I6$KSG%O_^6/;F@%<IQR(<*T8[&[V-0VZIV2&RHLV.>=>L%9?RSA
M4MWNCU\)G7L914:BRM7$NJ,[;R(0ZK&A(;-"E*Z')_IY+5K[.HZ%L$GY#+M-
M6K>Y;J7$3G7<VI8TU>FG$W[]9L8O+Q3K#.P(9IPJHE']V(?%D9SG#LQBXT8#
MZ=0?*0X<-%%@<I;"?P&L^0SDN81P;@BNUV+>XT0WXK?TO*]6TZJTI[PMW#*?
MS!7)^CL9(0H"G27?Z2QH0+^_:C@9$(3%_*(MD*ZM[3?B@]I6SWTPT69R(!U,
M-)A^>GXY6D3BW:K<5Z&=KG!9-MF[NX^9F"X."3\V>_&/TC288W\0DYC[;CY[
M2FH9.@A9L@7`:U&63'1V<7)59.=^<DGU88SEO\D`L88/LD!\&^IO)*X4HV^#
M-,E0<2IOSFQ-U&:'P][1_9D[YTV^">"F:UP4<][QB=ZU4'0Q+5:OP^7MN\>^
M9G7U379)`HY5\B;5]7TQ/,UZ4!1E_CV,9?,*_NM,U`R'.%G'Z'6YZHVD6'0Y
MY[LI\Q1,MARE4&OS(W;&X,&/]LK"5B.U-_^M$E%]8#"Q@"L`%P_@"MG+](X`
MPES:QN;WQOI[H<,74&OD]A=;M4SF-^92>=#'7^6R%5MRQECD,#P!RL]5:P+K
MGHXP2"N8:U+9>&@4**\;`50E#Z.8GT*WT1U]]4Y]^X[8@T%$I%SC<:,M;.A<
M72'J1L30G.323&T94[;^VPN8Z#F>3Z,CMMHN\"]09(E]O\9;]=:FN&19H9RX
M*'*"6[$7D-(^F?D<O&JSYI7/2C+L0:)Y42ID2%^;LD1[*]23OI<C2#6"*Z@K
MS*_-3G6!:PVT]O(I5JK=K:X777/$+%O\%][L!P^[&R9RG-="F/U1DIK'TJ\<
M(O[.T-31K(?YT14&=SR4E!:8/3$QNS#,)GV4);Z'^%%"SI_]SJ.P]YD3%3V;
M]T(U!8JT364/IRW\2O64F*CW3/JC%,H[/8HJINOW'N>B1Y8&6?X@84I,HFQK
MF6-WVBG@16Q_PAMXE)460Q^+[15PQ4RA5;GS7S,O]BWBGH@1X[M9]80=&-AX
M=2>L1H,=V@<$@5#&-2RHHXI:.P2\_V3<Z<99L!`:7X^`QVFP=&.IY30%NEMV
M9XMA4#=)_R;&S@#G@TW5(E:"4;.D0>O,#D%H"9.I4/W^[+N8?-"0F4U/S8J;
MT')WJN-%-W]<P-.,F49A36B#"--V,J]FHA-4SD^=P-*QMEZI`\GJ!13XZI!)
M+5=%+;/43L'D&4/TP:GC%G-HG\1EW1A?&+N=L9CO'+G3.6/3N,7@O9"A&KIP
M4!$P;<7;48A(Z-1(T]AI)X_^XY?JH/>*5>K`2Z*_IP3!I]\',.LW.Q9(I_]?
MBDBN";C^E_-^RE)NS6<'0QQH.15\X7`+V#@W-_E)+\6-%*74CJO(/@GP]O'U
M2]+\VG+8K`O'DY9C(;GLC7)Y^\$W5SU;123\D^=;XB=Y1-"+3\!7UKJ[=AHI
MP<EK*&`#O%8+&._)A^CEJ*>OF(5`KGMHU0GR!X_R2M<>&@_17?/$1&R2Z'`8
MU1<;2:^R:N<MS-0QOU6\:G7MZYWG)E<*;GBG8F50/[V?H%I%'C`[%^U$(&S/
M"!9AH:[S&?R]1SWIX)$O8=_M+6<*=^[8;NGH<ZJ,O20QY+Q9MNN%2BE\8Q,4
M7CNT+@7+GJR'DO.I?SY>P]ZDMVMB'MMH1$HYB*%A;M#M<--OJK'O0^E$NK@&
MT(<(JJW;P#`HZ9=F++]K9.P`H#D$8X6/@>WS:D'JZ>(=@&G#I$^P8FV^$0]O
M;]-5V6G5^H&0N""SFQE*=6L&U/L>C'8#L0&J#103M(/57&;$=P@1O'&%LZ?M
MK%C/L%T"9H;4P11+[@K,M$`/X<<^+PAPZX/P(?^U58]"3``U$AU8-BJE+6=Z
MG".3.U#(YR$>ZB'YTZT-VX6V_[1F2&6E->O\D[YC#B,7KEYF=;@#%?.R0\''
M7M_1WD`4+F"/4<#]F*@.&J,0HS]]B2Y!M7+?`$#_XC]9XJ(,L7"5!&0R?[!(
M7->V"OOGQHQ-<TJ'I?%'LJIWQ<EYK08_ZU1V[L-<(IV70<XR\%X&[FM#+"=;
M#=;%-Y?)IIUDRED;P&(4=W<QL<LUH4?:&T;G-'/C*]XS7Z!,"E[.(G!)K]32
MB`3^#"_IH4&I.]:[+S-5;6>3>59A!=>(EM\C^(J(*.%>@QPC,;+;Q04D-<3W
MH\U9%4IE70@>V:5MZV@`A*CH1@8.D>`BE[2`GBF^B^-+AL4)TGO,<*FCL.E\
M*\8+OU7B;2:5#C^@?21IC#-SD)'BQZ&RK+VLHM>KG&0OE$ELJL6SHMR*OQ$Q
MZWVHT(DQ[D[0&7[$%JFD-)KPR="<;.EE'RK[KM[&#'7?<_28#+%<1K?5WSCQ
MOM.XWJ\K5Z&$+86.6_(M29$KP)?N$<ZTEUX1'^^")126_-?)%SS@35I1D(5I
MM=WM?)*^9"RZO5X%0/LK$OZ#I*/:B]UT#7U[2I-VM&G%^C.B/]C=+LP+NN-%
M/&E1PS9(&Q?>A%1&S_+H#:1E-VP=8V!=UHI5R"U)76<VKZ-%<NA78$9=O'K&
M>%-1Q:,Q!X^H&MR;2<-SGM42)0G*)U$G^1.JF,X>EMV*4/@.F;?<ZE)Y,YIF
M9WD\P"[(U"%/&3:A::9\HQ2EU8OA%#-#>YP@`LVC35M/><G%G9ZS\3`-$NBT
MF=WT&BHV]:I=KO5ZGBO^Y_4;/A%P+ET%21+TV6#2],&K,035CE50:H_J+?6U
MP+A=DDB2E`(FP8NY6V!:\(DNO$,CQ86\F"+K!YSZ<^,,>Q<:CP#*@RU#&M&`
M\"E"!<')>>`Q_KNDF&Y<-E@HMS%I&A<45BJG]LX<'69Z+2)QM:`+R;L`UAWT
MY[O54:]M[N3K`_7G,R1R(H<6].E@"H!7GQ!D?Y^=#6]`*B?4]_,[S61M33;7
MXX/#7G#2A553);A$,Y6`PW=/S*Z/NP;_0JO.%'--UYC?NSK;\7">C--Y<4*<
MLLY`G>H6^T=4+%0U!AR'1)<:?(+;C8BB]/K??:$J%"H<@F<]5T`P)XNO@`P9
MPK:H;>8;YE?)?LOO`^`.)/QB8<Q+D&*&`KU*`*#?*`4X/S%%L5R&Y-*0]=[W
M^'AU],*$,#O@F.=[[I47W%E_6OV$=CL9\^/S]+YBA.P!Z*H)'8N3$J6Z/,)9
M%=C90\-RQ77537/USYN%@W$-_K&1?"WGN:W]62['6>13!"`/S8>KED"FQCNS
MD1A+&L(ILLS;>YN#4P^VJGY*!BA)B.USX-)]T:&T1PSY'Z?`]?FKBM+<MFI8
MM&\!G%I3L^=V73'M;O:DM6*+,+X7C22`N[JI!6*VF5N$#"V5*WNU(91T21$K
MT1/+PQ]NG):"<9%*ODM1BVGD-GV838:*;.F5?HZR2W%I"[W-'%S(>W0&:#Q\
M>J*YDU'8=75?(I>(@S[9#G^EJRN?DDG71FQ)YQ13BSR<!_/.<1/R48;`9Q&,
MS7>2GN+TDM40TJ4VVMH7VNL"`HQ$T[:^@1ZO_6AOZ4<H&DV00<M"4I=.8R@G
M_Y9_S7J"$KB)3STBHA194ZQ,>7N99\M@F$[,YEB7AHYUM'0JSZJ0+OQW$H,T
MJ-FGHXV.JY"%#C.E13M`0"RR(]):/<2,2JYL;;0D?:!S\(4@2.A(D_\%K8WG
M\H6TZYDL<->PD8=SMR=/GT9X_,J8VG]9;7X+8YN1'R@M?Y3?1O!`"][9"8MB
MW;!%/0I83ZH*Q4`J"Q=YSE6T)HABU6PV5+''$#0]C5>OC=U8"WD2")=Y66QQ
MXD10>]1IJV'>>.J)->H&\[!>_\<NN(GC2NW8F16'(4>*7RBS9_>R>K2VO\X-
MBIGLKNQ?D"S'\9D5(ML$Z\\Z+'T6=1H'#K:OO6!E"Y6@\$R/4L93[)06#^35
M]W9;P/O"Z2U;:F">]-^/%0O%XZG\^I-UR-'73MRA+!R/[3L0OZE<4M;79$(*
M[K%6?X+\$#%_1K'E"789-J-R\8]3:*>(HZQ3L:\(5([XHYYPOL8-,V-#_,ZR
M?4Z&R>5^?:3*>NX$^R503=%O%!X\[CV0&I$N4+4,LG5*XGU!>)"!8ZQ*0T$_
MF07D\O4X\LF<<(K5V%A^;YN('=IQRZ=S=_$KP&>X%18)\-3JP4`M&X50;@:T
MNFE6&\&D!!/H0J%MWI9N_M(HDQ<*?>WX.:G0AJ[5T5KXKVD8]],T@O')Q]&A
M?UQUS7I)@[&"5"K["M;_XX/93F\=43WE]CH/\H<M7OT'-#9]6R_K"H]<K+ZM
M_XW75K0<T=#B765CT9YL%8.Y!!A(0K,`NGG6>#1/HL6$##$:*QHOZ%3)K/_E
MSN"=TV[A$)P<DP86SW3?H(T@=<J7\#Y7A(,;J<E-;6@WHEZ[@<TUC7K5)\6]
MZW'7_=Z0VYV$H<#H%&O=9ZI:=+?=!S_[Y/*0NX133Q=+E=+*2P4>O;).VBE-
M9M1&*WR)Q'*3-*!!O7:59I1HZ^6#?0&MD$]F-"T8?!]C>NW5XH-`4!Y49;4?
M*<9K-Q)WHW(1/XGYN9T3NPLZ-JJ:-J%-+?#QR`!(7N?.?!%Z'*1^'S8B."\?
M33;UYW_5B,_@\K$)$A!E0&C2C$"^_)+=N-,-T2BX/%6'_R?$)>,YV4S'@&8H
M+/'/$R/"@XZS#=8M;9Z5\3))\"]?W1,*VT\2ROZ_&TLZD;R[U><J4O#;%VTJ
M,]Y)'9B'Z$8B7I.2"`8?EW;HKV3?_D`DDK1O?--W@U)IM0%.*[&VTCFT*3[:
M:1%IC?WAN/TVW');G//=HOGRLU._J2S=F?F`#?;Q3=)VBTH/<UAC<++TZMP,
MX#N[<IY\?<SF+?L*V-[Y6-(5L&TM9&]%5-@36^>7),57AL*@JJD@_+-JA?H8
M.AV)"M^&8]A>E26O*H>6<:LFM.%95C):ZX?(CRFTIM7J,U2N2`?'MW,MHQL^
M`@=Q2YI,*YG6T#%;,M"*T7<(RKR)>5A*3Z31ZBD+"MY^)8NN,LXO2NUCYEX%
M(Z1C8S?RGU!F6Y3@VU,-/EE;$X['.J[H-ZI]YIHY+7.6A-2&G^!;_K&?&731
M78/JPFYQ\7,JR=M<N1-S5Y>^;/$^4`L3%$2W\!^.OAW?V9P6WQ1U'*`?5'#D
M@$+R:M'1+V)1/6.5A903*W7`$,KV/II,.5YG`5"5IUWQO%X,S?,N3!]%!7@A
M'Z"BV62,J$A.*$A0Q_X@G83PP;0.^(V<N)JQI2$RC>!/IEI5*UX7):=NO79K
MTC/`WU#BVW/D%D?5SZL;C$DPG?32E_UOWDZS"=:1\G,.5]L[."D5E=2MB(>>
MP/`>70N'WG54$Q]\[92S3(H/0-57-]+V?B.I2<$,)(A1@#+6KT_`/_ZMU`$9
M7N/6CZ?Q3RI$A:NV3AS8_%9/RW[9PAD<(?)5(50`Q=?%TTPY>:U`:V2S2F73
M5-'-M)^>)@0Y",<!7!,&#;5-X!"L1[*A.36SH*>CJ<;.$3^OI.Q<+T=^;@A^
MMZ;<WJ5JL&1QI/+,Y[$QL&AJ47JY6^[%TF*LD=OU"`U+&FS$T/;_.I:QLF<3
M4S9Y01B<@3=K`63W_VK@^/X2>!IMD5\O8DWV\HWY.[GF&BRV_5EY2)Y:0,Y2
MD5/XZ45ZH4W*`>ZLBOHB8'P])#=F7WUU?PW^QH+(*6MJ1!&.93J15*-'$EC3
MPB!29G$4'2W'TZ:XL9^:]W)]Z])YK$'%SW`T:GW"$""^(;R6*$PRP@S,0%WW
M8/A>]F^,E@TB)9?F0!7ZK9&3Z5W/AU@QKW4`A8+Y\Y&D"Z'IAY(O\X.*!FNO
M^3G3FB.>=UX((^O++J$!(WH1+]_6.6ELW=.8'-;1NTYPP<-V%M;&7'N^_MW?
M7^KD?7;:N@';WO.,*B195TMO?^):J-(WP]-BN9XFF<VPE5P0!"!%..X6S/N^
M%E'_N/^6NG)650GUSR(/4%':8<=+G@>J/ASJVEDAN#/XG\5ZD/(]OW+#1.,[
M3H#5GCUZO-\=S8H8HWN`U6`JT(9+99ZYRI,2O*?3`#AHA*`MU&EZ=^/XD`CO
ML2CQ&K-S2IO[ZB5<Z[N@@(U?HXNMV\@$_WF7]A[Z.8XO[AO,0!#8G-D$7%&/
M3=:M#L_8BE\TY?1[P:FU>XUGE@$AJ38"!]4P69C._(*(KHJW^\LOW_'QY96P
M5106T#N/0PG'C=N:?#<NL]>^1BY-P"4B\48VO1LDX['=BZO:!*J8]1U#'M?"
M-^0F@4L[KZCQ(25S5X)3:-8M?\21)RVU'=.DVY6R[S&20/JU"F5DP\XCQ@I#
M@SS];K78H%<R.+J1)7[\!3Y&:`8V!#RQR=PTXS@7$1]\`!Y-/^1A-LM_@.-@
M\P.#9\OCU/!N.O7NVURPR^AJ0_#9<8K2Y>TE2TY@EA!D,]D=*L!/87YX\$XS
M9FS,PQ\`#NXXV6VT`2KL/(THV&?]+J!1]B&E*O,S;,#S*UH#85W:6^C*Y2J4
MO!D2J69]E;\)@R]7]%O`HM).05+Z-/\(\27XP@`10#V*9K6E`<":*.A;BF:(
M87P):I.TS_.I7%FD5-!R:(1NO86-/83+6[7[Q1EW&.C_?X32<<S@=O:P+F(J
M?7"#M:7SHN,:*$I5J+K=FO>7[)U#\/J/5F+.$G!&_QQF/&P/&1!Q(7^Q5>*3
MRI3%F:?$C&YZA@L@(E6.2#-5"U\9\T_9W2Y!DIM6ZB3Z1'OJV4."1@&*4:4*
M[X6"H&WB-V(4P!\',83`JC;`U<IJOSD=RX3%YAL5',?@0$4&T4I?QW>?6R_\
ML)B/'_O(M'[YFE^$7KW83N4VLZQ>H(JND:.Z%,:K'BR^[M;-1@C1MIPI8*_!
M2!;,-=^\``YG?Y(^%!YE*[315GQS6QY!3_(W`$3Y%/^6:7F5$R]`M"%T'`9=
M7H&GXW&'\*'G)K0QO622-^3*)GZ?H7X*9JT6B/1-R5'S+2M_!YD"5)O0W,#?
M5\/C04U,>G+^/_-O,2[V',0U<(%$6//).0>(_2^>RY[ZWN2\42*.#$-^(["S
M6.7<9#X&D0W;\9D;/56$81;(`)E[>-,9D'VM)9&#EICU/.2O>XV'1`O+*?>$
M2OM2%39!8F?)KJX!*V58NE37>9%YD@J;558D^U`?E%(7LGL?Z/E1A;5I^=3A
MEZOJ.=4)X'UWEFL`%*_0Y/<3RZ8BVD^E^J?G0V*W..,SRY^87!E&X*:,/M;0
M5QNOJJY39$^Y0+R?41E;!&C%RDC:-R\"QI[I`.#)?,[V?USCB[JTZ+1&&N/P
M.K-@8?+TN94)1CDN/@/IZS8,$M7>)2M=T"-[%/5F'(KL0A2@\^1AM$X$)G7-
MY>!+]1CI.BU[\I<;A\A(\<"98^9YF))`5@\]MU)->G_)>+6ZQR!&/DXHW71.
M@5.B+`68DFP^<3NC6"EO=<)SK];RZ`UYN6S6(:DGI0[9?8]XJL4KK(%(R'MN
M=OODPS&T#R@UBCJ#Q);J"*.!8-`$?IL.HEUNAPO'<;=R%<`_[A.&*VH?2%S@
MO::`9^R]UT%``),5('CBW[@B68EK7SKDSI,K#28U'2AZ^9!'O>F-#30).B"-
M\F,5)`R9'Y#Y?M+]]EU`L3JUILB:`R:L>'<4H1,A,TI!91!_G:KB;7C.@5T#
M;J@"-FOPS5?"/]MSDIN1^O`ZD886?5>\PW)IZ<0M:Z`C\A_Q;5"(+&EJGTRN
M#$6!-,*BGAF],QB"\<]V-]Z35Z_!0%(_R^\VM<;C\;K0&Q3@EM%W`O>:Y\D<
MF#M\HLQVT2YOK(3C%2O/)#>)['=:0`PX9QZW_(!W6IH^U5JM7#3?$EL%S@`K
M4C!S\P;3AZ08F%X4E/XI#22@O9?NH5QB2O&9('B\K?+U8EC%C/PX':IAUCZ-
M&RNW5PUBS=K)1XI_210SI)QY8?7^X0`'K;QV_F74:^?.0AC(O9X/!@!*^3`S
ME#OB?>9B5#XF]4"<2<WS&#%CU[7>=E05:5/8!4!78)+#NS&N1Z_BKQ)Z36U:
MQ1[4=(Y7=(;>;:\^K4/>9-T74.[^?X.R$GIIES,6JIR?)NP=PQ$]R5M$!=+^
M1I=[URL$@1[BC;7DUQ(>K?W@2W!4$WSS&&Y#R%4GQ,%T^#D35QF;8M]<L=E<
MDU/G^D_I5T?#.L&2*(*=ZFX:'9]R>947(.2%^,8M1W5L>6E&7\0=]]?$9!(0
MONOJ"E'DD=:J,'Z,;M8`\\\@$.6('45ZD5M$ESI(NN<V1F>C3*T2M]A0)/I(
MG1_U84M@N#NU61HD=Q@Z.LC@A+R3%]IF=6:P4<BC"H1H7U7%2N&/?])520#T
MTF'6.%:^KWYGDX!27D^]C!]!V&G&W%`K@BA^/RWT12A63EL@'#S\#Z:(AA,<
M4?6LE1K>66M\KTH><#*@JH.QS%L5`:BU)=3H0;^&"/$4.3YPR>-#H=/D\,2"
M[.>?4"UW0MEUI$`K78FH/^:F/@G_P:1'KC."4XV^R2*BM_R?,2BF`,C\8T:]
M2!9TO+0UO<L*#<EHGLD55A%7N@:#HOE0?N7"\ZZ#,_AE@AL@ZMWK??6"02^%
MPM#]Y@WT+5Z_G^W#(I9.5`N`J-.?Y5':<Y+FQY^#>W2E?\_VS/HH^K!ZUJJB
M&;`#='W1HD.^RRYN;]>$GHQ&-4`8Z/E^6PK<*KV-:GHCP3``/1F6.$83PH9Q
MWYMGN.'+!\7-)EG([)RP=-.;ARZ+$+Z[WU32X5M$;=$\8A(82JO'`M4O`U1:
MQUMJ79VOD"`:U5E-IHIN_-F]UY"H-"?R1I<;MDQ,?$H<:662^>KS1_7'A@2B
M?S'OZ>M9[1,!TB<LJT#H366%5OM_`S7.FQ2]1!OW>3BNQKO==PHG,&O]F.BR
M1+DO\TY&;"1?#M1P')$'4!^JV93C,YHKE$F6A$3<(U!P6\@(*GI6=B$!']NC
MN";J"MQT,]*]<K(Y1VW\5!98G1G=Q*W"*CL@6VZ]KQV)YB6VYB565<@/:26T
MFNB2<S;P]!_6@F5BY0\974:[%LX/^.Y!_'34T'Z[S6X?J5N:\^:6!ZJ!F@+#
MI3."/_58?56$3^VMQNV'3$969WJB1A-C-#H!$+Q6%R4')\H,B0/'R&EVLXOX
M6/!\Z"H8,4<!Y=)-2`/1,Q*3`(O(U7E_]^0N#5JZ3;K?:ZY8+HP$YOX9]!#(
MSEA?XGJ3JL63%00ZY]\5_=&6Z%LMQ^^D(V&A<,RX+W\'*+D88DB3DR.;(=`]
M46+WAR%7GDT#B^`OY9.B>^)R/.[QAECWM3<#HLR]Z1-V*ZC,3F"0,T4EBD,L
M/S8\C13'-.JTCI[7_]C+.2,(I5!<^`K%?;.CC/I]/ES:2([%LB^N4?X6.YT#
M!J:[?GQZJ<"[[W.[L;GUTE?I9,Q,"5-VI...JBU_RS&?8!HG872`8%:$]@A2
M)1R4)H`+@DCLJIC$%E67K08A_62Y/4)%M#[J=D8,2.DEM?L0@C>8?M`I+S&7
MT+1KTO<"/9>P`ZMG['!<AQNM,!3,841)D#)#OPLLA2O&G+H7HM\L'XCF?0%V
M)\54VD)J8&)7-^/.D@8E%#DA0,I#)X4(%C0&:XF\A#L^OA+6M?%ECR5I%IS:
M\,K3=J[TG@F'E=.36%5\?/XLAPQW='7SJ"UX"E37S)M@O]+C#E<=N"LB/TUU
M'_QS2-6T4J&HYEO3$#!"='5/M)H^/Y;;PP_V+N.'Q+,CLJ?BO9E7[_!/CXD5
M)H<A>XQ\QH+/C^/?]A\@I]"EL?K0WN*6.O&11$&KC1K8IU++#]W$O+U)ORD"
M5R$VF6M.2,;V)%>21$"UH,/DNV-%>R+(#@=HH5-N%BH]YC>M_J_9:['_Y+4R
M`YL:C)0T:9T`ZI_X;&X_;+YP4=*WFP;SC4HC7H>?E_CZO^!C,QF"_`9[W#_Y
M7>/MD-)LL:MZ,U'_P<:_\K[(7.ZIZ8@R,BQB!0Z^!D[8S\UX:PCXZ^A?`YHG
MW=GEAM]C6R.R^3GU:HA..\MW;D;(C+$T`_Y&2Q^LI*Z2:HL\*'0N):&ACO(&
M*%O4<8K@HUQ%SM3B3Z`%D3?@!FF8WTV]";K2(P.<'PI?)'+O[MGH$_=R?@R&
MG^NB^Z>P*<A\>%6=@MTS-'UU\Q%T:C\M#7G#3Y[UCEMH1-*DO)2I^7/$*\>W
MH<DB1=?R!/[)[XJD._NV?B;NXXC'J*"3*:"0&Y>!83*$WX/5<%3S[<R)&CO>
M?S9JXD/=>_;LOL@A;BG2#X7[`VN&HV(B9Z@R>O70C"["!S1_W;>;*EMN6U]/
M^Q_\S!?X.$'!(,X1=F>*5I8B##0@11$@8&3VZ?"NVUR3FJ3-/K'-,QYCM^MG
MF63\9D\RBZJ"F1W:#B-4]4]G$5/AE[]K.)[SS'X9BKON5_P(WW(-AL&_71*K
M_1Z1^)OZ'%E\$:(.],_9%C31]+#-M]471M>I-222/M/9@,%$CW]/OB@?IB_4
M6.AH`ZN_?N_?/W^\_.[\I0S;P)1PP<G3QR2&?@0DCVZUGL8'$?4-N[]`&VK"
M%J7Z\UFB1<M*//&31(98LT*@EG*T]=A);M>$Q'^WR?E9<.S<4N);G7T<QL1_
M$FL,2W<UP4X&JY<4X]-Y'97(4'R--QX^,^TI9>:$:\>9YG\19"&!`-RQ:GS\
M$(TK5D71V*W>3PR5KKWQ^F)&W%<VQ/EGZ^\)T4VP#[E7=0Q/YUX-Z=!PNT"%
M%:=]0!T!.\[_7(S)*S31=M8Z0.<P-TY%[,[<6!&6*(&J)=VT?@/NKTL;<J.R
MJJO5J(HO/!TS:*AUXZ04K/R[D&`"?/2906]]X>I:%GJ.+8-*5<,O>_@H>HS8
M]@ZK5\\FO432PYP(21M7"W1VE6H!O21R.=*-2.95$(<"%F-?U#(!R[D<9'I:
M?D'^G<(0&G!Z;XBZ^.]N"NMH7NQI"JFJD!R,1JS+BJ&'@*GPE1<GQ`)HD4(+
MS:?V"+95WU=J0!<X`8MK.:R"O7YN_1&&)>KAOEP*,<-!;L76!7<K6OB_"FZK
M8B$`?@)U<@K(D.>J+XCV_><_30NH"0&3L0'%7HV2=M,`=%K<5*B81>DXV_0%
M<DLUG"[=44Z++SJ>2J!_6A'[DDK<Z[^!P($W2W!W'SD)2?8TZZRPT,`M8XYI
MB5#R*>,47O^>UF46I'K_*`M*\&L(=FF2+:`'R!>RQNSY'6"E..!5C!L6"X$$
M=B9JB="Q@Q5;C-EO*ZI294&BWJ5_%#_80S"_9MN#^)#U;A6S]<0NDCA>CXGW
M1<]..=(/\IQ;YZM#UQN:FZNY/3P1:DQIG&`Y/-Q,_/K\YPZ(V1J4)]W[W$LK
M1@U=?0+YS^>=OR[^EWU5-;$T[J&6B)@GQITC-3$F';UR3XCFT>OLN8_4]=B_
M*SE/,BEH+X9;KS\S,CZT0'9056]/Q:)IX`2+HJ1BS7%O/>A?ENX,3NV[L',6
M1J/;]YLE&$HB?=14>)MT3=TC_^M/_XY&UY'A5+B""Z)@YP':,KHO6?Z1=Q%<
MCAP<1R76\'Q;AMXZ"KASC/A<GC;_;ZSQ_!U8Q4^^&,UUP!;>7$;)AQIE#D$E
MWPZ7EF89=6>/3Z>D6!FA_#IDA5:(J9;JK,4ON(:K*$*.J;A#\W>'1K9KMF6$
M:1"TIU$MS-]O[&9:>(!KE5(#8;"_SC`S4C^D+PX+_G5_2J0;E!E,S;W*!(VP
M#`HSNKU[85@&?3A^8=]V/4;3Y?R02Q5-6+IF5^:\L;XG.-")+]EIUAO%<#ZI
M13N@O!>]%5Q&INP-5&P\X&?S!*^15?=[]I[3!IWVJ@WWYY[?A`PTLYS#YA"&
MZE"8J!;@T8:N^`-/9)%3[\_P'Z$>*&30Q-BWHI.I+S@D#4<DTNQ1<QP:>'!0
M*F+JJ]GH0!/B7C7$O.8B,MA=:/WI'+-+#Y7Q3G%I*\%.G!GU@U7SK,PJ!68+
MO$,ZZ]O&!>MH'M>7YJIUJ*'^25V(4P-RL!SL@P65$@[F+8D+37ET*)^(6F7D
M'4Q2)QZDP.CH$5"+1M(`DP[ANEVGT\*!<>NY@BR.ZC1X`Y6HY=EH_J%K:*KZ
M;661S]G(&3Y0Q*@39'2:VR$.C"E%_?0?J(%@6MOZ^9C_IU.H^W_JL6TIHK@$
M7/KMXLJH*?7L7F/Q=%(:_>-ER@@RW-F6(*G#O_#@;`Y;2:^Q5V3C**>!TV=8
M;SO\6+K&MKW0KZ`C@ZAF_T>CCJH!X/;0\YD[D!".`%P%/NC43)1Z`&![I6XG
MA_-[G2X]]LX`I)A<;0V<V5\*S1XVL5)8"RUP7D9`<]ZD44[7FGT'M)",3.RW
M`+[N1?E/]L/JG!F\'1O=([C@LWL3`A0R2EF<>G*P,#5!*OLG74Z':HTM:HER
M1<H=8M7\M$X44#E1U>6J&*8U&MX\-;B<K<*L[6H:]=P\6>9"=,+O[E^Q?@RO
MC)M:'&#,PY%>P+81D!Z<B`ZN3_H8U+(#L==L$LQ+?C)(Y34`1!HZY@0@%$TO
M31G4&I4`,A()RJ`7W-3W'BK'G>2[895PCE[-T,J%AU]=!-9*WVP6^M?.0?.$
M*,_3!4R?7:13?PU'K4-;V%1HO)%3,RV4^LDPC&O@`2N0WUP]*3X4C--IT(/X
MO*JT.N(%47^G060^Q@F1.(4LAEQP^`F2RO$FL6-,3T%$+WJ^X_G;"FQTVK>(
M!R71"W<?D+Q?-K)8[<X:D>@3SY6JW+WOT%H.3*0#VWQ:F)A$LK7F=V+'*C4'
M`P8=K56P!YGT@`\]FB/R@ZC!,YIE995*L3QT@*P=3E_=5BN"=`Z2U8<(UR,=
M.H%'J%+*(@P)"PZ_P1V[2JU$7B_EQ+X:!4=VO=R^CED1<J%9P^FVG*6C]5H4
M`'`G4;"E1Q5=AO>M,9>)I/^C2_*72F'#+FB#/KAVO96]XA!),?N?+&0)W!SB
MH#8Y'.<^X\VS/Z3V!-S;O6LPT0OL;^>(@2^[B)X[`E6^Q<?;RUT2QLO/UO-!
M%=TA*R?3OP4*-OI*/8##F\2\CA6"K>J^25>HKX%0VR^'@'9B@7/W)J&)IN:[
M91X)$):DP,Q2)'[D?1"S,O'K/!2YC<^(=>MLH20XY(]<",%OC?X_A&3H1/'5
M7P45!&8-R+[8)JN$0.G;W::]>@==?ITA7J[VV3EL1+OW([ZOH;$R+RYY@?,\
MRT8>Z"MEL#?!!+,G5NL:1>GNSQXWX(GZ*'.Q*OK,4C>YC*\_.29*K`3^!>J$
MN`.E!LJ=DB/B,FU!2OQ("R0Q8?!6WJKJV&1+.4-F]4S0%R.$JK-S5OT032^_
MLIUT$SSE(O(R(P6AK&EN]/B\1HNUY/I\5,.L+2B/^0HA**V/&:5.ZF-K4MH^
M-&877\-GP)F@>L+`2BLK&>7[=B\%YO"0\(;QC6I[UL2O,HD!".Y3SB"+()";
M0U)KVSI9E+#;<^?\J9GQC'T)-W\Y%Q:'+:J*A?2HS8T?'$@'3E*`4"O'!/2_
MZYXD'\,W=A:JRFF!9`4/N];TE@4E640/1X)G++%>\6C)=^/9/ZP?]?9"%D#N
MS_J&>(59R_:T>U?B+1XAR.5#Z[6Q'C51<LG/YU)SLJ=!;;8$FYC6S/LI(K4K
M]W`CP[4YOQOLX=8P@+UN-039+!Z07@L;'T/LMB807/1P2P&"H+P(K4Z7/?ZC
M!XK99YI8GBF<)]Y^CU[E8_9R#9"<NGQ0L$<&`:!-36&VSI*I++5B]2@KM=@O
M@DC1,`:S\?F_5T)>Y^T<),<DE&;!\D#6&_%D@"ZGS+6CJSYP3WN[W"X/>OU8
M`_B[3GB,)"&-YZ??*TBFP[G=2B2[7"#1AWAR1.NG`GR=?S9+&3[/?7)M#1=I
MR/S*C67VVV8*^_>'L:<(_'7<=:LQ@+Y#<A(7K[*--$.71SO3F3S$HS^QR7D3
M8'YQZD\*U9QZQ@BD\)],F!0XO<78RN"3_D6WXS-)SU[&X?,MZ5S)B$H`\H?P
MX/&AIQ?GB])M(!?H5`WSC$H^PV'KH0"=J]J?9#XFK<(6AV:C<H;4Q\*W,R?J
MT-7S]1[+N^$^EHP5YUV)UVB]^^$+GJV9(UI>O-&'([4N0X#R/<F0&G'6\R5R
MLJ`R*]VXM6F7STTV`]_8%CM-:Z$7(`@;MZ3;+_:?@#VT=F+Z?C;Q0-2&0H"G
MI5/9@#;TKY^OP5KI$H%!0PXP'ZL$\DCH"%@Y3O2BY8'^.QSX"MU<55FL,<6I
M-$0-\/D)?5_<P-K`MOS%X:(O/8JXP4V'8:.,^7'@(?M<!.TBMY!X_HA6,#9+
M,\@9BE5=][B,#9(?&\_L?1J`.EFV>O"OTOXL[;9&(F;,T`#*,PC8IG(E!4U<
MRG"]N%@?1H>*QG&_>0V`'(V6I(QKT>C)O",B8(-3?Y??!(IKQKO0/,9D!+4V
M="@M#E<&)'J8LI"G8S#A,NH@V\X.I[TBZVDFP&<5VW7/B)4?"`D]C%7[#RYS
M35D*#$4K]9O>QBL/X3K[&U$;>]A1NH)Q&?*G#-H-$S%B<N"U2T\,G([2>FN/
MB>;9-):5B^:Z,MFW0`L_WO(6TO/JO?N@B+9I&`^=9'\O96"*G21=!^J/1^[W
M<!.-#".Z`;D/V]5;I?8"-_!%)_+18ED6?G4K]@Y0D<;T*CSK[1[_"^CV<.E2
M)N]7@<M,,B/X$!U)'Y/?WDPP2D0>1;[T6[:`X`/1M@+XIY0(MWIP;(*2O9MR
M):Z!]RK#GCO,"(Z8EMD"5X,_M.NP-8?E+S#P?*#<C?QEK;R:^D+9CG!"ARN`
M!IUSG_YPQ<]D?5Q%@*+<$HD#>*>7&,C.[=^_TRB&F5KFQ;3RYYZG:]TACY['
M!^R/2R4WCJ3>2U+Y3VOAVZ0KAHT)\>*ZI$@2P,FD`+472DAQHT`DA+(+H[6X
MT+1T7Z^50F@6(IV$QG*LT"H?,VR6[^(U@/F;(-Z'D?@H-/3^/,Z?RW^2^C9<
M4.BU.7FU\.!_UD+/I-$73,J`QG)N7P29U2DXSSDDI"5Z^F=2DW-Y6&-_I4C"
M<\K]\"\;PFE3DD5;A<^JY%%]]5<2WS#]V^1JMX3Y>+=M32ZG?35%\-C=F'=G
M0;7DJ_E3FEW]47RV2N1NJ7[HB6C,.+B/!T#G;?7OU(M!#!6^IO,_Y4.&*A@B
MB#X5AW>]QKLLV!1P$B`$EP//0&Z]9+A"UD<!OJ2L,.'.'4BZ2:4_0,(N0(6"
MK`[C%5H,\VCJR^U1IIT>1XLG#RI$G71D.2QVE(D;\4ZG!'A/U3:`VN"[WPR[
M\61KI5;J4@/>F54LJ"%KS-(&V+N*3$'C!7);\IK)G@\]'9?8NF_*TE8IY=GQ
M2]V4$?74D[G:C.:YW6ZU+[EZL;$#6U70B<<I*6`^?GX0QX/D1VW#.@].`6#2
M;YNX1(42'PHRL]1HJ2Q>F8Y"?EX=\$##L`U](HASW[]D(L5@Z[XB)/QO0%]-
M=^PIN\S>VFXZU4PRQI;_Y[8":?I'AE;@I2H4-&C9Z\OU#]7+7F8\/W!H<"!E
M8VAO)SP_)SL_/H#+7"?=\$@%IF7_8C0Y%B[H'NI>]F/V3BLF48A[5J66)S\K
M2!JF-Z@IQFPQA&U6J&\@]OF\KY.55ZT3BGRQ6`,#*=F\LERN7487/.N%_K*$
MC-GA`QD`[</:5^!&K0`K$CI\)VWA365!$H-Q7JU4`PE/0^84BA3K>DY[2O`\
M\8H+7$CC9O-YPMILI#L:Z\7K3]MLZVL_[XCS>=YZ-_%8`$X[7!Z$J.],/-PR
M<ISA*G8.7D1H19_!^P5[3Z7OK>0L],FO7]O;O-@L'$8LYI$1X#;HE!G'A=6.
MV$XO3WAN$(62Y2`(GNBSI>W?3ANH4I3PP1VQ=Q[-?FZ!*EUQ3'OSV5J>6MOX
M'>$M45REXC^Y/J:SSRD'3'6P%.B9SK@7<E*G43P\B^:10-6!'\%N@Y:B2L?Y
M6+:ZE7,_!%G`G>P?N.7^[W*\1S,LC7\5._YI5=1G%U)'W7='>S"X<P%M._%^
MWA\[,4+0WDQ;U1_XIA>+_M)C]C-SCD<>:`&FY9U0W2L*`.\C]5A3N>-ST/I/
M7[ADQ:^P__HGN407C^8C0R[)"%>LZ\?RJO98ANFIFW[6##)0D1J>?`&(P910
MUX^49X^V./6NR.S58QJ71I:I#&N!0_F2;/YI:`?$^*?-_0/0IDPTIG2AR2^H
MFQGE]W8*W<:63-($WGDE5W[+##XTXDY:X-@`4#^X:_=D'MR[T1"@KMBXGEP0
M<9!]!'M0WC$I&#>B#9YM^U[>;_NU3US.T9;2#>O^IFX0BJYCF8;-*N>-*V3V
MELI(=[Y;^[\EMQ(SD-FMW_E!O_5666X]5Z$F5-9L1K?*%/<+(LJ(-3O@"5;7
MEJ!=APT1UW^2M^U(/RZ5CQ4L*]7Z?2CUJKZ\+2!$,DRI,L!ULD5A?KO*1T_'
MZB!VPP.V[=47G=\CJ'$NJA)W]5M12'X-ST+?@(>UB9T:4?=,1-W!T4@WK3.I
MCQZ.2_\K:UG8Z1%X`!!I+$<Y7)HMJLP!DD%"HIW-J1<F:E-/HQ"^"/UB[C71
M<`=T*J-[8H(<>W?#)UL":-UG%)?;MU^]'0>LV!92B_Q7`7UJ8T*LT[S!7IF3
M$\A.,"P;K+;KTXT'IIGM,*1LL%,#';$+-MTAT2J0(H.]>+ANZW6Z?'9&:[1"
M<5#QID@N^P;%$`L5'QXJ54"XANF@2AC]/!M.K00C``*:&8]I`@.17H0*G[23
M//^#=C%8M*XV$2\3F/OK5X\?<#;EUNM=J((49IQ.HX"&8\$!/D]`:YSR=-U=
M,/^^.:OV_-.9<=0:B3D5.BL!*>APY0=N.=%';FGXS,,F)8,"K90V'%0CNYW]
M/T*)P!P`._DI?-#_=#\>;)S)/_V<?.^>J,J'Q=-[-RN05F?P""P.ER,)Q,KZ
M8M::0C?TIZFO^Z^QH&?7"UK^SY/030J.EX!D.`=`"%.65X_Q;*>X^K+F_X#0
MJT1`%W+FP>R$W2]?9FJ87+FCR:@[=MTX!T^KGX2UDKP>Y@%;EV)*_3(9/[]#
M0^Z;>YYI_ZU8"$%=0VU.D:ZX4Y-#W:ZY@IF,%'\RG[?(J%+(OWU[20IZ$M$W
M""P3IOGZAVS&M6U+MVIH>=0CJ!*/F!N;^>]U,%\'X$L(\FQ>=4G/N)!,6*Q)
M0KFVW%HSK^9S7AOT7[:_EM6HJ?HBR!I+1O%*N-_I=2"6DP!)`PD_=Y0.G>81
MM)I/;]98+%$,4+/@;BECSUL_UX+Q;@A7K)[M,(106.U\K7V[-G/%FDHM-@"R
M+EX7UD&6"30MY)>`;AZH"/=Z5O.E$4X*<=$$SZPAR&:_[]C41%6!D9(>E>W(
MK]T5@9[5^J$8*J#I;80W?ZP%C`BM)/:TUB;UF],FF43MS+D.>:0D5V\=8IXX
M+20P-Z<P%:%S;L.)QI0)5L:9*-S_\>)IG0_&A[J#4$]4#'Q0^TB7\"ZH6D6P
M_"!OF&J,JE!Z[S!`:V^-NZV#M1J%#9J?.&9^W"P0[Z%!M.D9E)2G7"0]*\'9
M)YBOZ;(*HJ@C*9,:"YOXGJ^:[)'&.9[N!U!1'\A[`YJ9O,D3H=[-K$--"2Q>
M6S_8<><NJ13U8(.EPB.)+(+756P:JCR=`#ZL)SS14O.0^EG$NMN^.I/3D3Z)
MWYC8XX&_YI]*9\KISWV0Q)`'J]JX'3\9,G=>KQR`)2^//D[3AQ.1-G"6HQ.X
MGV_;AJQ#1-ENT2=1-DC54-I-["_+BIIC%Q2PZDE#)#5Y@V=UU\K'..<R;+2;
M[E;#B36R#%$!6U)RT6%"JG8$NZ7]T.RZFFY3X.(YER7(H\%$A[M\@@>M-K+Q
M4S&CO,P(52>;)E+<&4AHV=:0?[&5"L:N(;^XP%CA[L)%K[%O4%@@0/36["U]
M`O2UT<CZ<R%R2N\-E0;]S55+=W]8"#_7=WRIZ5>LL#5826`)"BFVWD.\XJ9B
M/5C4]-]_7C<$F[6+7'3_?9EW-@,-$H/RP6B;TGRN_Q>,+WG)B3\K1,W^8,$2
M;`.P(N"@(>:)T36-O5AV^91)TP[W8JI\W3`(P-`G%.1CQFE5!_4E)[V=RZVO
MC<2B9%XQXR(8$,B&I=MR6O^A,Z>7:7J^R&P,)+^_PMI/,)VJ?:[)1VU9W%&;
MH^;`IA9S[0%ZND<G)'B>=<$G5DAV(:%QD_6;UO-W*VQE9*E[,*_I%@3$RHK;
M&&D^37$69TF'I-A20%B"LL)83::56JB11T<#AOB=`9VB(]\P$L&$T[NG2>G)
M?["<=6"F9)H*Y6IQ;<#.L):N9*L1[U\.\WM(Q<1]41Z,7IV@L;=LA^KK,R.Z
M2J=$X7M+#9;[ZY0_A'KB2[="+Y8`_1\ZX&[7\<\R`9Y!H/!J9N9(DJE?`;Z/
M*2]`37,+Z68K;NR@-I\O8*J]-Y4>2#O7&&.G,^*#</,P8@/B[!5L`])`/<G?
M130'.D47KWQG[-*FNY5X?:'9#UADT\\'!Z/(;?W%N?7/&[A-N*<[ZTGW!%`'
M4+_WCJ)B'^YN::7&:*PIS%^VK`RZ^$VS$NTM"_HRX5$8&='--`=HXS[U)V"T
MZ@N&(_10F`(LR\$>&H7'^N>,2!GAU*[(X.3WF/4W[#/Q;LRD)3)VO:W&M)PF
M0X((7U-&(MF?\0^;_/C6'@7%"\KOX%*\.E'=0,YT`?J67I)PP&]U9/]0Y#1Z
M>BZ6P\,W4LIJBETRPVC^0[&?5ZO1!+1J@3ILOOM-9VW5B&U]>>94G^NGX7\>
MLF!WQONPVBJ69J]KE(%NQ7!$;F"Y#2(R.,4N9,6-DCLW,?WO(41Y!OG&ZA@/
M$^YM5=0-'O%9!B-BDQL5PGS!4T`<_@-GEAFW[[G&<U^8O&)>,JSM=F;[?U-#
M#K>:OLD$;?+A$N5IGDZ^2>9JPZ@%2O$*-U^J/M<4KB,;PF8C=9*=&=M.9,^J
M2<]YS-PJ>\@QM7J;Q)H=A;4]=$=3CK0_2^X-69B4,N5E^&_.2@`JLBI9M-2A
M-S.\0IWU[AI7<=J[DSUK:W"GECQBRH*K9SLYNY=;K#/9HRP%[1EPX5B2U,'Y
M^NGBG#!@#V<0VO"<9$<&_^)EC<;&_O30D'98?$)DM.T\ZRYY3N@'L,<#!0\]
M[Q%MW*$;PY@JO$3_IXU";W,XU7B`>Y_O.;JN<>'3IN7`J&=N:KS8L7))B*2?
M9CKL$R*FDS&<-21"3KVW>XXN1'!44A$'>@B]"T4UKW:N9$3FCI=\K%\B@-Y6
M)S2;"NA,@U\-YNTY"UN8V/0>8Y3PMB-U$#!$@G6<OVRP%8J#1&^Q=34Q';.O
MY3#"%\I77FRUS11MQZ;S.$:\1.9AT\%W-%:*^+_+.G/.SI2V_OBN/SMH>`K]
MR%2RT`=</@FO"VA0)BG:OMG5$@O6R6%JVF\RN@_R#X%',-+G65WT8RT\L?D]
M7C_$)14G%:F@IK3(36<)25UJ(-+L;I4M@@=KF'65Z1#Q,9Y?^H.P8;C]]1(-
M;!IHUILF;&,PM:'S<:69CEP:(<O>AFT#Y+'"J+U*VXV2JUCW$CB#1W9SZLBQ
M[UL]0N8E5T79$W0%2>_XNRV4-3890)NT7#,(`Y[T//Z]<H)_#)+\Z"G):F0^
MLF&OKS(RW7%MHX=1(A(E6?^=\0J#KHV'A*J-I8A"S&H?-#N?]:B<<<?P]5UP
M+(7+L/E&V5HCWEB^HO;YM:04B!+5TVFG/VE=D?_V/TQ^EZ7KOKQAB9XH0^EX
MV)6*%%E=[WF.X5H$YL(IHTFL#A`=O=B?0%HI`SG18B0YE&KZDS3C<HZ97&*U
MH@7GH*C>?=\[?8F>2B*CL,S;>W9&"UV)<E3I)JY)U=R``=HR=F`C01Z[41S[
MQ2$<0R@*467=60C/`3];T7%0KB>+EH%\$`\,:@7C87K/442"`UJO7C*WN8BM
MFOG'52PKZ4G2(558?%6W&4L%PSQOGV_7$WGPEES:WL7B==MXY6=8T23@%^W>
MS*=-3RBMC^5QE'T/77CS66'[:_X::470$`ES&553"'^<I3S=@YE^]8K4==[L
M),F\*G2[6SS#-,/21EMC!=#R6:P<C&J'G4R3L*])WX%T.[K)*DT1*;9-P]1;
M_GGW2$JDS&:3L?^.!H"50B7!!IAF(D1_*IO^@4SJD',EBM1XY^CN?'ZCV56/
M)C:.H;[,9<%.:6VQOF452E#S^63,7V8J]DNL-/9=5<94RT19)+JRY2`;,2^]
M#$4%]X4[KHRC223=CRM$"02E0:N;1^1N+0SCICY=?!;J`(^THF:+G^FJOQ0G
MK?&IXZ>B3"9'"[IX$6$.E2[<S5*`2N78D-^9=)*/D7,Y5":'D:3A&-!D%0/_
MH9I@1QX5J-7?Y3D-F5%*@*E!8?GN9^B`L4]/3G="9@\!5D#<NYUE`I+RM&C?
MB2$;8GYE-H_JKE3;K[2M>9WD#H,+%'U!MQP>AW8(U-@!^T6.9;Y1G<.7T-/@
MDTKG'\10CQ"-34]#OP=(2#D\+&A,V3L1FUI5%VTF>VH.6PS1DG`)N]U.7A=7
M,?@W]&;9KHG9P2I3=@&BYXMR17K0NE,9C5L<+'Y2O"OJD&^7%S"@8ZZ3,0A:
MD'6FWM^&E%S<RWU#\$<<CJ*78P8W6B%F>_[!XA-CG0(!B/@-VSJ<5L\I)*$4
M3$:87M_,=T?5Y8N,!3*KQ=/WY2>!+$\G5**"<RJ2)P4=6W-@9L"\S/Z&H_M'
M$@@>3Q3(49TK#'V@C9(.^]7P\YW2]K&GHI.?X2-ERJ600_[_"S7935>=WOO:
M6,O>T1&ORTF$;Y_R/JPB]57U6G?UG=NQX?F_C]SY/$CXCO);D0O]HI%Z_\C$
M<DY)KY!E`T#7_1?78)LU^(EG%341(&EGP_+IT0Q=Q6.LEC:L]4HG!"`6%;S$
M)F3/-[7/_8X8,#.32QBJ'VEIPT#WYKCWBLOG&>7.&]$`ZC795.V]'+TK-[W&
M>O)(!/6"4?EO-O,X1<WRQL1-Z(Y=N<SRA)E1'\UX^CNS,N/%JH.U@+4\6_`%
MV6#I5<K9#HM2^,R:3EJ]8'25&786TVX!/H-!IQFWR9=Z\@C$(:9JQ1%H(,9=
MG-M@E)LO.S%<?RB`F&2I^="C%2H.H^.++T@C\ON\N>+ZL;%>;V>(#(V="<E_
MIG6ZLA.!)A"38!U8&63#Z8\OCT*GIP0T;GG.XZ)[!DO,*-H#+7U6NF9P/L=+
M+['AWW>&DO45@/1H*;)IHQ(C5Y76L0",<O.<:$[Y@W%-83,9D[BHO10`1F[T
M0(12["=3L'<Y*\UU!KQ=5'V-\UL3!Z0HOTUU-`<.-]H@2W/K7,B#,D(R=X;$
M=$-BZ2*@=73*JQ.]V>Z^4)1N=KP"+AY1&@ZL4>LK&CM:N8:2L2I[2F%0%?DE
MFB2P;W8NXM1LE5<_+KY]2:S=&L#-,QR'RU=,AMDXQD#LD#<AP_NMI9)Q0BMB
M:8+BA']L_BEGL9*0&H3)D]]NW/-Q"Y9U$NI8>NG(<KE!2[IX`:K)_<#6MCBZ
M=T"4P`\>>++*:/;(ZF^8)4,,'E#]I=TQU]!^@K_V.\?FB&^7';HW:@*"F:9?
MQ!+W($:*.B2&$J4%7DVN0&8$7]UJT)6]AT%.:#2^)>CK*9-%^N4\N@7*E.5P
MR;*'Q8[=CI\N7QEC!_4'VA&O+"W):^MT>X]%\P&NC&BW-BX50HV?L%NX7H\O
M2QE$A>>L3//:[:KST'CWY+T!0HODI5WH''@DH0I4.,S&K+0,88+/2M!I*4N$
MNV<-'OHJ29`K>8\';REQ\O(`M/6@9HIU`@Y;W!^`8PTD^$8:0/\0`95G$D"8
M$?[2^IW+70&,8WN.@P>&GX9*_O:?%.$`>7.'V@W/UQDO>+N@VSE<;,;=5BS=
MF@]UJE^%2=>,7'6%EDN@9FI;(`%[I9I?9/=0183\":\##TH"W6%3ZAC&SU9O
M:)Q!@\S]CHKEE;K^9*329@6S;0%9Y6*``BGXN":@J\R!T]C@(Q<?PQI[%WVT
M>6P`J[FFG7'Z-Y2:GT4H;IWMOJ\0#H1&?^'%9JUZ"3F!5I0TGM4C.LDP.?PY
MM<ZL#;Q"9Z"!4FDKH4#+F]T%!P3'L=HWTF0(_Y=7RU6K$F>I+-^7U8_RM%*5
M<27$OGZ[X/*/5>@,7-7=L.XJ75#,!W0;1+.<@47B"#UF>J:G=K*0DA+/3I2-
MO(C'[Z!)*B&$J!#S]VK?C]<I2[WY2P-0D]9$B#MY3O(=<CWXMU\O%)6\028Q
M=T6N=#;)^$\#'CL[P5;1GKQL[;2OK6<A54_=IJ+YU#N<Y)<VQ9FK=[R;Y=;[
M#'Q#_&7N`7;/^*=8W/9%_RSK\:^5UV$\?Y7[83L4TZO?^*-(C.)^O@[`@%$@
M(,^UQ<,;UF%E[<HMMWF,**L2HXJTA#DJY+$`7V11^.:R$SB?H,K'$UTEW:]I
M!>-!=,,E01\M<,2==],QDP;!(_G1UAN--[V\!]WH*E@#]M/V0B8?7W`1*&K$
M?KYMH#")S>,!,T5+G@A6OE)P/&BRJG@Z%W6KS_-)Y(4\)5RIW:UH9QLAXH((
M3?/^(BC6>UC5^*,.TI$:#6@=*2-`_G2&VF^LC,:BN,FKY*.]XI8L5;!)IG(U
M9Q;D]^J?9SJT3_/I(:P[_C%6D*8V&W?.]&D?487\L>*.XTXQ`$0+O;R2+T<?
MR=FR4!N%KS1#*5?>_M8%'D*9(7<V52XX0?(?Y,IP&#*!!P<5`2$1Y\NET2L'
MYED>F;W@:_F^:G#AW>DF>ESSI&?XYZS7+/42-MX$]NO^]-X<_G")9#M;K&MY
MI"XK#(Q?D"A[=_"NCI)$_YN6BWS\=GU[^7!I"D,"M_$66W#LMA/+;Q`IY!GI
M3I-.KQ,&ZFD$JB[3L\ANE4FM)=$IOARW]1PLW!G]+OYPZ*J*9V%VP'/;^O4N
M!4%:8C-(`(56UK>SZ=V.I]#NQTS^C1V\68*N&^6$&%3&2Q3J5/P`WO<-O+?K
M6,#D!J2VY;TJV#L<%*KYG=S4'<-:R@1U5)5<WQK/]P9W`O"UF8J1^>AGTGI^
M(*LG&9",5@A[;TNVYK[S!Q#B%+$MN*"T7;U0"IQ=AF0>Z2]`*F*>UBM$>^C>
M#'#![-]9'"+X^H:#QC9[8ZY=]]LZT61ZMI,=WY7S:J)B#5>D/R,K_%"&>>.$
MD-Y<V<LD5B3'\OX@LZ./V,MRP:6?,9N0*%?INF"%\/,I?0X98UL'YYDH*>'1
MWF#H^/`?K3GJF$?\2Z_`\Q=;E\\DT%\&R(RR@_?^DV5-CFH+AV&S:G(FPR0K
MIRCCF,7^&PQ<NSY8*>BV&T0[I50]UW'U!6E.7';$@Z]!F9+N#U-BS[R,`__+
M`$PC*W[=+"\YT"ZB4G//'W-KHC,YX*L=S9?17;UN[[67Y^?!XL0,DLOP%J9W
MI5*%NVT'X%BO$(S0P\X^156_#$PQ#[:5BF1,YM/\`<`OY2;R;R2?LZB?^5M(
M5BX7GSU(&W$+R`']KC>T3YH2AN>E0P!=;H:$:&/7_Y[[`Z;C!0I&52TR(L(Z
MW^*NRDBR[D+">VL?"`;EJ'+&KKL$>R7@[]^PP&R'DZ@FU]!S%-0[1U(XSD,.
M'2?UK)L274VF*&[$AJWYV,$YBBF=8G!F3X6VW'%AM%4E"9OO:9!*M7;-K;5-
MYN:\814GSB%VMH5S5=DP5;EN(":F-G%Z2WX]SN%<_.']+\1<S1%G/O.8TFX6
M)>-_^HO;Q$)QI[G;1A^`\A/[B?4!YGW:\T<I"4D<IZM!T",1!YM-^"[?`N]>
MF1J);F]PVH8/G:%S<G:[GH",`&?H_EX]H1`3G/I#+"H/@JBEMW@1]$R4D.GR
MP30'FCQ?63R+NZK.&$4<@).VV8SIL*2,U(2<VVNF_CITJ`X"/[(5D85,8#_1
M4,<97UK$EMG:)Y<=^;,6*!1!W^H$/^D!SE#\P@<ALO832E&9VU%Z]4!T"#<W
M9,+^_(>P"51&W`-D79@TRW?HFC[>H*P/01<%XK15)V=7[!D9E*$E)/21,R_V
M&1SZCKWU8"QS/XW_(<X+'[8<'JS!9/Z^J%=TC/?C`%LBRWJ2C82)C1-P^II)
MO!NX:-8;@+#DN>./,X<.P/%&G\H4,=@-4B@Y3/K-O&H10.(X,F'UO$W<7\V]
M^26$KA<-P`*\07O:AH=?+7Y_&QM8Q,?9+<-L.+WP_A&8)*M:UE>I[=-I)0R2
M,RG^^0FW&E.9T/&^38>.NG2D8#A2PO$F^'^0\GMQKEOL:V@B6RAH&TB=(Y?\
M0F;,GB>OY=V3KIR9.\9DVKUH\5(S?6\B"R!&"K\0\D-<"PF1G%0GDE*=&&`(
M/%\X^/4E&@:Z*_<NE&^:D,PI`K8BDB2(=*<MTZ3N0DIG`,@0<I=2",:BW4=H
MIACN8WN"YIII_-&HT;X3:4"S^KL!"AYO7[9.NF-!"R/KE?C8'`@.;O'7.X=P
M94#G58YL+^7_E0]+MS?!)&AF\C%M4B9Z>R86@>DE)BM?4D>^R(W=TL/IE&R5
MC:C,@Y<-5M6X3$`\'R-S:`C;6HV"9&63#]VW\%4;39=AQC3=2'RSJH"ATV;Z
M>X]E"\T!62IJ.76R&5;;VE-NW<[O0L!$U\@<.LSUGD\F8AA(CI![%K:<-08>
M=O+PN:S4`K<=M"S5N(BCNW:Y8>MS`GQ1+JO`O:KJ;15_H6GWJ@9A&#U>WIJF
MXC]K^A*,F1I^F=^7)7=7@U:"8')JNU<B4O#Z?SJU83U99?)V7YDS(H[\TG-F
MX(46BY%)X(J(-QNOVB+\++(Q/TD*#'$2VB[UIBA.$A\1#E?>JO8+U(;9'!<,
M[`?%\JV&5B&U2)1>O#+ZJ\3&99XP*[&9.Z/7*D`_@LAXZ-_V<#1)W`,T^DM&
M'&WL>)FO:@`;;/7:?20AVND,&=!7O^'I/;UF99Z'%(DKMX)FXP7;HX_%*(R'
MU*%A+?"7&K6C<.C2E@A])'BRI!""YPG(J^F=F1%-0R(R_?%HLC5ND/73P_R:
MX4<A.\'X+7!KT=NV0LZI<]2WQ`4N9-H5OB#[=Y//1I]YL_7>D?0F`^9LW+C0
M58'F$W+[7@RA[BN[K"CK9Z+6B(?LQS8=G+<E$"B()"3G]KXP,C2_ZQ3;6+Q)
M9F23ASLDX==IM[Y2A]L0@$1,LCQ=EFYPTA?6V@&T4HY$.'G_TPO3ZIWVCL',
M67SLWDA?ZS`2KE%F/*^'\%2:SRD&++SY@J/C1HGALX67?FD[JE%39DDF:U>!
MZ.V5`]#4&58%)IAW4ZI_$A'X"L4E%5ZIXG6L-^R+AT>_B7[`.$MR'@0X>T-\
M)&12^B4%!J]G4%)/BKZ-_06?&Z_RMYS)Q_!LJ0>)\`$^LT5#;(ZKQ"DYW;$!
M1M"KB)@@?X+:;4Z9IG]V6JF7.;1N@#Z&38OT1(R.$JT``!DQ/3QLJ4Z7'LMW
MJYGE@4[5H-4SI3.!\THW=$'36P_Q/0*J5N\40U>5=]AX^'COT[X/@T"@B%9G
MHJI\N66KT5[%2DE:O'.!XK8,FB8+]SJ3&!V5A1+)8_"=BB-D=K;I'A>@ZR]3
M![K!,"X\</P($TE0_`>B\.^W)HH<X0.-R7FSU=(+0)14(4-$OC2$01E]]YT.
M?&T%XH`-[/U4>^`=6V7OGZ:C$NW:T1HG(&+;!?!T>E5UG@^R]0^2X*#VJB-F
M^7?G[:,'W@1@N!W"E_[8&SR:XR1^7C@4S0]0X$[P1UHYE5AB\SSW:\$)B;*I
M*+;17729P+#4AXUZ._LM8:]V(WQ4'4T*Z['Q:1'%*-B)RGK3;Z04J#/F]K2W
MSCD+GU%U5/M5Y%\VVLNC5]1GI=XPMUOQ("K!!IX#\>N15'$38O?5*B@\H$A@
M.T?U%W<LI<:T[2<K5%`IC\(Z,X*'91B,)8R7_\U`_7[L,WSZ8H<$3'ZE"LAZ
MH>;A1QO+AZ]UQ\4[&":Q2:QQ+@N=F$FR57"'XA[H.3#Y@\'>#)>N2!:@6+`:
M,-W%S)Z5J8KJ#&Y&$YJQZ>*1[F'FP(6#1CE0L_DU&30L9R!RLVI0LI+N\L.&
M/@X%T6^#%PIU4E;V&2M!U@T0$@L^\K.\>$+LEV=-GN3HW2?]LKY#O7GGL^M:
M\OHQY#$9EL^GFAER+I@C(*L7&9SDQ/$W!!Z#T>V3LF<3!D@^[6$.9:0#K9=S
MH&'U@1\8Q%NQJ#(--V+V,?:5%J+D52T%JBL9^,%S,,78[3ZX3SQ%?-J:]@X:
MZ/.)T8M(Z7=9UQCF@XK'\*[TDP,6;.(%2%+TAIB?Z7%3Y]2*&)P-\BF2"I=]
MK5H>73KCU]-#YDTA6VW),FD3V?G@?9]_">DX=_J3U$Q"$&M[3])=@OK2"N4Z
M+@C,XWIMU9GWXAAQA)+NM=E%C>%/3Q2M^-D6E%>?Y`A2RH_I>>SFK!$6.$#J
M'5IYZPH/^A+36BCO28YG+55#1937,]AY=XV>YSD'CM)**"4:W&<B%#NPP!Z@
MVJT@<!IRZ[8:0T$T7;--&V)QF#G4T2I^NHBS3^!1_8T-Z\]'[=SD1]Z.'Y_"
M"K"&,6[RO"8YM;,9K&X8T'LW^^;F?,I-)^DC`O'8/IF85'A+N(94NRYE0/L;
M'^';H%=>TU%RXQT;1::*HFK9RFO^E=L;=4("'[GSYOT-D$2A6381&-D@N+$K
MQY:?FO\KJMHNN>U:<([C,I**`D\D:P5$!>:V!D&4Q<VR:5C9)LK"$[EKQE!I
MJ#H6]-]^MG#-%)_M<O,7OE!M^S`?DC%19NH=N=)C66/38CWIX<<B>3GME_!D
MRHIXS0,UBUE[*A?0[7K4<\=Y?25Q>/JWT?&H5RYGWF""VAA._.XQ+U#9EEBT
M\C4KL!#G!]*N;-)$:2Y1!%.XVN[\$<V9[A##$:+JO7<%-U;'$O[KC=@-TM9:
MIR<OYZ4:5>.U3T%IHI+5TQ.(76C)Q:6=:E'Q=O!_?8R(Q8,I<-6_^=BQ/1&J
M5+$,K+>!.1O;DA@I`G`@3;Y(."R.YAVK$C;N"NB$'BJJP>UF2<&I0V[?63)_
M<)_S#Y07?,JS2XJG4.("/`+H$RNJ^>V$BV*8%-?IO`^`FNH&,_!Y*'4OF%"!
M+QR7=&+I\U_'\\ITK!)'VXE`$\4U^NGKW"O\^ED]W)4OX2@\%[(^CI*%#1;T
MK<)2ZR2?LTO4$SE#7?8Z*E*:/:R+*T_"C8JY0#%?1*PE`0",$Z$41=UW4"YR
MMJ`F;7D<S,VN;%R6XX$]?<4THU9!Y(Q@U/40K(]1%-YG4Z]$<\8KWB3',7$_
MAU:N:Z_Y=''A4-"^7-R:\OU+IG\K,3,&1B"'8>XDU:1>$VHKU\!;O"74H((>
M;CC&`'#OT!Z!I!U6JXO]^ZU=AC6X=TTLRFB52`R0R7.6GR-)6"GLJ<[$8EHX
M=3(10A23_K,QVQ2J#S*>M01JVI>&O`%\HC?96-?W9^YY^X+=LHOV\5NY:8L"
MWCP--98G86.ID>6C*,RDJ3VE-0H*X*L)"[NC@"+@G<_9YZUJ213_T8K#FZY-
M%=<CWW?_G7O2BF87$YGJD'65E#/;(*R1U^Z`+1K!TKQ.8W9<O@;UML>G?RZ'
M6$H[NH#K5_\YFE;7L>6^VM+]0`?/7/9!\LVWH-JL9I*WQU-D#AON95V=V5!H
M61"8(,:4R6&1P$@V@`QG4?+2"HX$ZHY,<L1DM("&,Z">VA]^-#3?I6E+`)MQ
M9O&\>P_QMPPI,S_0X/0=>+SGSFS]'A\LWY_,>5\N@0=):.6%9E<25G,_'7;*
M_&$EXE']4?=70#O,IX"WP5DNF9-0K>;*6P*`'LO6G`CDF>PC7,PPDK_6-(TD
M"4_8`(%.D^7LMA@]K+XQ5W958P"(S"33NL;^77ZM.ES1)=6^Z3SJ/`R!Q<M%
M=BK:`#Y`(('*;`[R1+1*XBW"DJ\BS3`BV5\64%+RG1_M0##5::(-XIWXF:LS
MZG1=^Y;4C/%@M0Z4'(=@NQ-=N9OIXLP_DPMI8QSMM,Q`7N:%^)`-.[ZAFCY,
M-;.9$<7\%#PC@4Q(4@@G=\<J#<=27?#4_RSJ(]P!D$E+Q0<,,LL8G?`I,M-3
M@!T>9/E3-,JAOB]S?QCT_ILXPW#-MV-%")[KMO(U#!-ZA*&=G1^%%4"G'"".
M)#\&(W""<="4PDKTLBWBXG$*10W^"<JZ`&#SR@)9ANQ0_^?(6DX.RD&K]4$?
MS$7,\5#*9CIV/6J.?0B!#M>L&H&(`(Z0G<W]J$*!:]7Y4L!2[,^]E/WG(2-?
M-LF3)(A<VRV@>-G8UK1@B6QP_]?0>-@;AW:5<!<]")G[*>P2BB%7'U(VP`-`
M%X-^L+_DU83!VL:T"MQQ8=&H0EO&,;&E/BGO1^^9#&\@[\KFX-6X#$4LI63%
M-7B#]P=K,P>0QP]S$2&Q"AW*4L@G1PR,?69-"#')011$2#CW23R[1,X/7)_8
MC6W'ZI%(P5^KFM"D+J%QEC``6SLVHC#>5XY<^5SKA!\0@[J$B95O5DA/WTT(
M;DK<^!&_5HE0J^.J@P6LI,.B`#@5\I^S1MR,1R4QD88W6H.MF[O4/-B/6)$!
M,D)D&,MYX8/+=_M?:9OU5`8PUE?S=<+@9SJ2T4\*:\N1:8M8+%4QQS.MDWGN
MUGG/B%^!1'+)01F&S6JJ(VZV0*;CIUAXRVNT31!]YPN3B-&",J>A@VCDZ9-\
MZY<Q_WCV;_CVS+YS\$DTG(K:,K>.]2LX]-(VHPC/\75;G/O^`L3]X&\K4':P
M2K[(F)@6513ED+:0Y7V*RA!TU/^+MZ[^/\"M$UD12AC`=]_T>!P0,YQYHV'Q
MVAM'M<CWI(V8?KVL3&(HR1F%40#I/;VD"[9'0^U2S/>B?P3R.#F^M!5?RE>5
MTW#C%?,2*EA[^&Z@//?F)TA0$&G5+H&PIU4P9?)R=L.5AW;*S1=GD#*DEMJ+
MNK<6*Q5'0M(A@!&^S1"X;M%86[WH&J8&')(Y<TFJ1*EAR[\")A8G8^6;<,N4
M\TC"PI2FC-6:FG*N;G*6#3)UF];P>=#JZ7.K`5$Q)(]I^*2`VGOXHN\L?,5+
MBZ>;5/,?4O-SV]+//\JV=R0&&N^M`[S(DTYXZM2#M0/_.W":D*91UTQ5.-]E
M+&39%\``;M>+=_I,P3J&>Y;V=A0@O<M8T'5306&\BE8MF72N)5+/@-<L(R;[
M0LOJ?KWWF1CDXS1]Z;>5T,)]TG\GN`:"_2_56,B![.X`S_4U+/75_B)A9'0C
MU(7)L?VR,*+FJ?(:$*%=DZ:<?5)IT*?Y79XLRSC.+WB]VX5M%I#>>"AT$?%P
M'WS()*?:U$U[Z!/RXDN&&;!\@DNZ'"B:QFY(WV+-)XYRR>2'D.X-/1V)B!8Z
MP'"CFXO*;_/5^3+Q%D92)N&:A!&YW;.`G;K==#G*J%/(HEK2`G]UM]%88!>1
MY[PMM6%U%.+D(9,RTC@^%<:Y23Z75)M>5;AGE7HC\I1;W=.,JW1$:N[<E.Y_
MH(MO&3_X3U0DO+T!JG:(#"!RQI(]3:+FL;4)4,;HOKLFB%A"-4+$J`R8[';4
M=#'BEGU_@V8XQRT9AMEV``"\CBSNBW!QR[^)#VL:Y9.01*_,'+ZA_[.Z>;82
M4X8;Q<W0$PEY%9+1ZL(&G0;%:MB]$(<C1^L$<BL$H*Y&SM0Q_"M;S!2^-;G%
M[&7<\*-!/<M'B0(S$5<G?52X[Z2AD>SGO[N(DVBE$"B#%L>6^*RSG<E]6$">
M8XL!/4.K[@57S3"UNH94[_@:#V7*%BO846"/3#"1O$5%L%F^6BT[9>N/HR^'
M6]U$4&1#K1*WL#W.PT,1T;D-#4N3Z\.)#ZEI4V3`@2@CJN^QSCA>\MW;@&:P
M<1G@]^,A8SZ'DL0:2/1`IH/*GD3@C0(^/O<03RI$?R!64B+B(IFB5C&%GW48
ME(#-BAVW5M(=`C[T5N?4#DBY&[/`M;+<O@`B$CXH1#9Q;0`_&DU?*6Q&*W\>
M-"53*D]2)F"HEP&!'KAZL6LF1+!?^D1K#N]`PTB3CQ<\[??X_'UM8(),@^#=
M]![F"+_P<QMD<!=W"1-(6=_BNQTU@#>XU'*''SI'D`'S1F\[0:EB8]X6X5ID
M0<7OR0_!N*5(#+%]5%2DV:DG_P\Q3_?"8E*HS;8VJF=!A%KAIH_&>'\WN&N7
M_]$OH.KX^T#3>'2DJ;HY[],_Q<\TQK?#P.<YX$5P2%N[ON"K]`(73[UK!`^"
M:%QNC-L#0N%OI3-:9`QD;0-^]4P+;KP;\&FG:1RB<,=?S?3#/"7O-@\*61^#
M>0B_<56>#0P;/(IO(N>'JDQ,D3>/"OSMGO_:K[FN-?X0`14[!1[PA+VHQ.(:
M2+N;[Q$<9)'!7F'?!.%R%/B2OZ@C2OP3X5\RG<9_$'.D3XAX'=9)+E']IEL!
M=6KRNIR<UTDJO51OG(E,0HO?U!W@E.G@/'3)H>^^*_'-]3'E>JXC,&YL$A-[
MY%:14<#`N)0]0G(@Q](:W#9DN,I,9$!<F=S2\I5.MDP(>CX36V2:%C[[:[VP
M)H)VAI4BZ:HQGVB[:4#^HG#$M+^"9J4&!(S>>HGWZ(E-TAD@`+O+5PSLL]B<
M`'%35Y3]4VVC-,H^%-U5!HY8:1FBX.HS&.557PI,G<C_O=4]UZL2XL'PO0"-
M)Z.\A_VSDU8Y;F6*]9]2XUL4=L#&S$Q_T?V1`:)\P!":KV!</QNFEZ\S@@#2
M,O,A/&`FG1ZVG/A>/O>FF&,L@8Z'$.T?"X!4=]I]$.\>G1(P-:)V7"\#LAI?
M?%)I_@]>&!U3*`XM*QQI_*F,51B(*=R?)X%^='MWQS#?`L4G%1,K._\\U0O4
M$\B$?^L!?@9^Y`TLYCAT&DW\^LB$!"WNR-O^$UID@6B;"5,'N@$%*S,B)"9-
M48>/Y\6X0N$M?+Y"WX,S@=>IL@%X%.FZC1U6IS,KA-&TS@AVQ-C+%M.8OL"J
M10;A8+CLPKJ764VIVP^F\`R5W5(J54`6AV/&V$HO3,FQE)$@-Q;_XQS[)KR)
M0P:HYQTO=TG/TS/K`.B#E5%%6.)(M1!4P8A=N/%@/#6G2>9PE^4OJ5B:KE.`
M0(#L":L5S_KWA+3-27!?74Z-1QTY^[%,(/<HKKUHE\JCN;W.=,KD2!O5>;9>
MP`%VT6(5'FX*#S-Z+Z[7+AQ=)4X`S8FS&3RU.MS,]ZXBFMN^U1BP6NS>8PG!
M6[#W1L@I,[,M=?/ITH`!BQ*_@]V'O\\<UI^%$6QTT"N<Z[T0H88!U!$<\!4S
M6[LN32A^H;)[2+^>GTAV5BGWB5TX'S__O<5,H3'/GG\A(I1(;L'3.Z2<=6EX
MI3,"=.\]SB!$DQ]W648!R:R3#4J%11:$&^I3$H@]&(K3XV#1D2&<2QK968\[
MBKE)E\ZQ7-DAVHUIQ6'^,QN`"1YTD=ZYU!<(*A#'*BLU\%R',;T1GZB/22OG
M/C7]1*7ZC$FUV7O3M6.+^QLFY[2@K(:2C"*%!??PZK7"S-U#W%HM3@LVBLHN
M^#K-(55*DU)>0NWKU3I,$_M>&E^\"8H3S,48@-"\BLO/&O_;E*7ZU`\F>;K@
MFT;FU7$#\(,^@<F+/Q4:-0'Z\T>!9IJ*9VK/*FQU#M6UEY=-&K!AVA/BFLX<
MN2"^Z4R&^IDSTRB_DD/:?]):6=RU3&=L0W2:JV[$,QS-=Z<G?PM,0XNJC4C?
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]A9&UI;B]P;&EB+V-O;6UO
M;E]F=6YC+G!H<#,`````````````````````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#,R-38Q-@`Q,#4Q-30S,S<S-``P,C$Q,C4`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*("`@(&1I92@B
M5&AE(&9I;&4@8V]M;6]N7V9U;F,N<&AP,R!I<R!P87)T(&]F(%!L97-K(&1I
M<W1R:6)U=&EO;BX@270@8V%N;F]T(&)E(')U;B!O=71S:61E(&]F(%!L97-K
M(&5N=FER;VYM96YT+EQN(BD["B`@("!?7W!L97-K7VQO861E<E]P<F%G;6%?
M7R@G0B<I.PH_/@I2[O-R\-/80T1FZ%)WI+U01@C0Y'>_/GS):5H@DMA'8"-9
MUH.I<4D,`N:MWODBCYVPU#?BB6(M1W/H-EAJ)&_1+`_=2E(D-[8[/S\W1R5#
M64>2-+<A)!EQ9$T/*/&!PB`X#R?JN*UU@H6<CEI>)R7;?$U95`56X:I?),AO
M%MU[OPA5F6N'">L)\,S:DHCE`"")C01@?=O<3?IUT@Q0/U-PVG;-\YO6QN=]
M`5[?IEC$<2F@U-K5K:$29/\24A6>Z-7__46[[NU\+0F&$%E4T%0I*0\3M61-
MDF"BMLY25[&:8]A"4*>K8S7+^N((L6-O$\K)I8\MJI-6!#I-9L?2P.+7=7G)
M3)+N?UFI:M_B2GC/E4U%K'^HA8&<II1-_Q4JI?'+3A.VC7I_'PJG>\&77^OO
M89H<*Z&[,@#(^O8(37AN#/!<GK.OSNA"KC6#<;B_V$D)<QSI=I"4I+K3%H4-
MA?0.&(I;H8F?/5=RS5FQ5:2BST>8_-Y=<9^._&WWVX$VNOZLQU&7%6$VY@W9
M3?M)S4P+XD!"[!MF/&ZH21.,\U#I(;Z?;:GVJ^6F:(/XIN_W80%/?KH^*'^]
MAN/1+LA5JGY:X'"(<OM*Z1,A[#F3LLSK[ER\^N]P\W3)*XX,6&&+P&OV2*F*
M=0!WURQW.4>YBC_N(TYV)J,0?#D#_"ZJ@VTEQA'Q\#"WU#M@P/.)J#7P\(]U
M.)]6^G#'"QA*TI6'["P9=W/3=9MW_E30-US$L\A'KF2HC-W!*W4KFAK7E^!P
M/K\S=(B:_%&\Z^0#FLBQ?GX?N3&8D?@:9GF#P)FI)X3.JSUF#MEJTNJ%/2`S
M^4!'K+)-/8T#TC,%Z*^@#^4"\!B=>K8A"_DU'<"Q)K7(5G4P!@<=Q?>2/7RS
M@^[LGJ%[4S'+][J7+7"-WHU]#YJ;_UN'BR4A^%KFLL'JX!AB&*B$JD-(Z?X2
M.T0DMNV.26,U>3HWX+'QBDA&#3*NK8IR6#YDD=];'SUYCGS&;X-]'5&?;-D`
M=B@1,D,7]@Q6AN%.RDP]JAW@^WKH=$1R`S26%V416]S^D6"SS5G5=K6EXIUL
M,).4-RIW#&J+G`43M-)'Q-!2FFRCZ<36=\&"&P",#X#=C+B+=9A?W[72Y=>W
M7.*B'7!>6MR[>1D'97A/KW(Y-O\.Y\HJ$9VT[K$4^RT@];/Y$]D^JN-U'K"D
M/G/GT4)$^_6-#=26UQ3\>(DH9YH7J*+2$YR(V3O,2;+PNU/^_\S#?:1YD;S?
MID1PM@"I0!L\!:8OUE+638)(3A1I`HV4_K5_*P-L""V$FX.@7E!?%B'95F6X
M+J.F_18)M5R^\1$\FUM#*(-KJM&F(S+-LJ=G*X+D117<$E=#V'\PI/5;]9V4
M\ZD(F*9(ZO@'_H3EP/AK/KW%C![EE)#;TG2##Z@C+%W;6XADD,DYP55C:<@5
M2$J)F%OX=!XV+ZZA."W#I4$<W&AF."T'VH?+RJ\:P@8ZB-Z^4?,I_H8!UC1A
MIU(B_DZWIVQJ>?(_%S4+NF+0CZR)2%,MV,U+.CA*1$&&S?"DDH!$!=`W9>*=
MY4#^EW4_0S=5!R/V++::@M->=4.SF7+-!.AFOV=#;5(G:>#TW(K<(7#IC@V<
MM>5436^>(E&=X!&,OUW6^]2W41KN\Y)!.T]"VKKP[U<VG(CR6\*X`4(;@7V3
MQ#LZ3\;96.+U(7"1H88!)%]*_Q?,.AOU=#KL8EG)6(4H+H[DV-@/_7JKR8=N
M^NUX3*+R<+]5\#$<=8Z4%I"P>*-O@I`J>!1(9K$"UU_)=XT/S/-%;REP1)<^
M0!]'UHG%+Q0443GT@VL'VM-M203Z8Q.ZH0K*A]+U(0?D!X.103=2T'M%W43>
M^*:XY4B==\VKTV^F,"0"=87FVM#Q/(YP7L)=&AJA\`#@&#1"C_,%CV"*+/JL
MR,03NJ:5FI.<@K;FI![F-#K52^7X(34@`C)G_>T=B-4R*:LAXA,;@2915A69
MJ>'*PU!';F&]M757L^N?@)&+`=:55@K)N@).#O+FYSHZ+T8ERU2=V/NF\?JM
M(KXWXN>Y,]_,J3A2G^,)4#1^"B':78^C`O4AS/K25FZ4EL/O,%5AICMVS<4D
MFY]F;7PU<>"WV14`9B_:,@(!;58IK-.-,VE;0!(S5#OR5ZJ#"OL]*?_WVL(&
M#--#DX?R;BO"Y7GG]A<]$CYN7+S,TA[OQXZ/IOSC3S5F,D-O!,]?X,J>"WHC
MFZ@Y4SPGQ[8')?*TZ:3,O)TGAN`D2@LRBNVL64)(SEL%D?7`DVK+X./+@ED(
M-&%;ETD(@C2F$&]ODO5[(-4C:N'`LLLS]PBAGNY[6=]-XW,2+Y@53\=GJ<64
M,"#8",GQU*=#SV0-IW"CL">-TP[E"2<J(PA&_%A5OI/ZV"4?`[S^V\G,*E_K
M/YC*-&[4@FFNZL:$,*Z2/9RBMD0KC&1@TFSW!PS]32IQ.L+R<%9'R/NFP]S5
MB@OQU*J+_9X]LE14)*EY8QO.&1L[3RX-@V)'44>79WYAAN&,V!C/*ZUK5*Y[
MPC=PG'KLKZ9-`<@"LK66:<BRPCN4BF3V^.>/=(4C]ARF/>1/X]7-K[%1%F1F
M`-PQ4,[G1X:NW_!$?U`!G9BGTZ&4<4$ZF5T'NQ-M1T#6"^)I!UV]M`FR82^0
M$"\@.%;9;2;)\O!N=AHR7N]SYV8O=_!#OQZ!!)W$/?>`_'6AW._HXXMS9`^C
M!`N1SJGBWZ$MAZ&GU6I7/NV_DREMAE"R5,6<\1TTR%&^RV8-E;"]18U?1Z<Y
M>5OBI></6K)2/T)>SN!EP]6\7H[`OY68M@U0;SLQT[`=?/*):N4!4_2R4#)\
M7%2^AP+M''C/]GAD.HXG+CT07009M.FZ#8HK?XF64VXP2J7OJ9`>6VC$E>P`
MBXG_)C7`RG/!0T8V.7[&*`4%DP%H6*1\L9'O]4@I(<C!P;=J@>Q3%XN,.@S?
MS0@D4\=G$N?WS@RDKHE@H@08@!8VE!?Z/Q9E!;"US/&74#RDL`U-.S;QP&:+
M^ANX-P'?EZZS(B.<L=@X#`9O<CJ!+3=JEG+GFO8$^1]A"[;;OX&IT"%<*$%$
M\S/\V#%+"2_;RN_9=3,A%%;QX*`!R&PM!HA)[4K75N7W*XTGN;?^$&H`J0N/
MYHZ/P]N$>G'1XDV70DX)L]"..TE:ZV(-.]Z2)C[<ZW%>:S6W9,UXG1`RM,T)
ME$;H;<?2%;JV&?M(PL/E,@5Y0*A08'%Q1??C,$K+J!6(K@))&6=7H9O\<XE#
MW\;J8:@X_[D\VX85;1$$.X'*(%@.)<VEVH=6:]NI1U><0T=$A)^*#!+:B_YC
M&G789C0#9-(P=*EG7ITKTL')OHAX]N@:<BX)'YG8G\BBV/^.]'MYGME^2@#&
M$(*)U8JB1@3SXW8]C%D4)V!="V8":>D$O6:"8F]AJV24W3J1\^>)%!B>>+'Q
M"S^WQ"270.,/XRS5(+C,_=`N7.`(ZU.[OU]O'"M4AX^%_X<;%EA7<88!06RU
M*$+)YXE,5E0>Z66DEJU<BY.-D34KKVAJS:4O)P<M"4*L8=J&#\<P`I$T[XJ+
MI[D?^X;D8&``FA1#+0R02;=9^3-:-/VEFOAZ9MJ-<_>?2*XS]36=LR+>A%@P
M-6/G+CMDZT309F9EC-FB<S+H9@W<R>K/](/7MFQ$HA2-TRAHT2U;JZEJ-K5A
M'1+40]=_5!BX=E)P*$.+;#1O_OBMG/9/L1,Q_[8R00X9U2REGJ,H2?C:);-+
MS"PQT!1T\_1:X9,F-DUWVYW9`Q*7*MQR^&TCE_?]8&1T[E2!3*N:D2&')Y;@
M'U-"L#X%T@%QQL=Z^FDT&FT74283DS!?>HH>>VTQZ#C5!9WJ^\9TO)F`PW:W
M*)4Y#NEU[1,=CSG[8V$M,#="AD=MT_M!0TCY;B<ZCGPGU*93#\(%A/.]F2_3
MB@1OE6N/QR68N'V#^BK$!UAK25Q3=<C5J*H@'7F&*W8G?:NJL!91K?OL`G3\
MK7GX7#3F>NE-""XVHRR'[9+*^,=NU@CB8L!MW<W]*B:)\@/3(7`=,T`CR&CT
M*&MWI?8B&>P4,)API5+1=<`0^>LZ?$F)9XF&1/E_?VWG(&S<`F*<VXMR2)UY
MIP1"T0)K,7^+``/@68C?'/6XGI<Q9?O%E21W>CMUR@66-2&-=]=E8(C=/5;$
M6':/!-#7'$EY&3[?_K!NM+,_JB4VBQNGT7:#]XF/3_S58PB24QFCC4=B_J>7
M^+6?C*:I^2NJ:[OM_K',-I#*%PU#0S5`EU_WUU,A$0Z7!F%W<Z.-K`EDO3T[
MS9M[7/X/#EG5U&NU0WID,`WH9DE%UN@S:1)AF5>QB;O2U-N=W^TLQ%(,.41T
MW7(K\VX!:GF/IZ'>CWN8-V6%%TD>8Q,_'JH<2YI'.:/(9N"U#X@Y;D<696F)
M:-)\3YMW`PF6;E8P7!J&0.=:^K-Z9A3N;83Y;\4+IZ_)P:M90_,F\_[(BXU8
M0[\\9&4`'/9$B=2*N*7><@,>SZV>'31=_^WA;W_7J(C@LF!B!1RE3^Z?![G_
MQMU[@Y_K0A<`K*I[I23.`B!=>W#^V:Y(AT'P7Z4'BK!B3%K92+G<0CTLZ"$*
MGU/1WS,-@$0F?Q+.Y*T(8B<9`VROR[V](V'7?.A#<*OD]_=&:/\(^>UW2.E?
MJ]6OIP>6G^N[UF-6L.X6*X@`_$\A*)D^?*H,J49,0-5LMM;]8TWB.L'Z&B,<
MHCR>=X)E-335BS4KUZ^S;\RF1)<X@]B2L9B(R-/=4S/18HR!W]M?Q4Z["P6<
MM>X$ZIM@W=@CI`L(]/+CHZ=1A0\96R=O(^F6@54RO%2G"R+'"OK214<?NSN9
MOX7GO"X7JLKV93>$7P[/[9N8HSOY2ALVY+]N*N3GU4+6@*/JFJ9A0R,53M%_
M9P=LCZ]TU=$UO1]MWP=M9W;MP95YN.8+*74=W#^$PU\L@WH'=;$!`=$\MOKA
MR!50CC1MI.I@";^=51A+96M#H[1%\T]H(0(C&Q6_O!0TGZ/!9^_6,5T>G4"(
MBQF1SM:)[AX4]`RFSM$E1F&%NG"H_";*EDTL%(3VU(M[.[9<TU;-L9JB'")=
M#;C8SGR&6U,DFP?4E-I-9U;QO2*49<EM@P%=)4!H]A!;F'[.6\]%UK3XHZ7Q
MM\(XJ_MZG";*_K1+-G2%SL5X\I=`&3!G3%$'".LIY/FX@,(4BH;3$8R<.;!P
MKH/^MTJ_<&'Z]LXE3O+,0.>M)(HDB=R(8'HU!#\^S]67;JB2,J&D4%8$VGWC
M+DX)`&JW^Z)!0_-QJ<W_<`E3VA`T#XEVLV3>6DA?%"U[6(V*G(V'[P,AMR_#
MF[U>FI+**A^2]#%R.<%*O$3_G?RUUOPCWM6V/XY:NX%Y=EV$GI9$=_U5/HO2
M6I(H(K`GM\=)WR8+$96?"08K'?MFQI4TO7+)(OQ@J.ZILT&F\%;U\D*C..?]
MQ_UPP"=[Y]_]<%GBK?2P!J&G)G#WQ*]Q[)M,-:\TG*"#X0597$?+FI%O9E4D
MV).XQHU+OJGY'AAPC*-F;PM8=00%[C1;4[M^FG[`5\(-R!1$;#!L8Z_7ZB/8
M"+*>:>_OU.M"2#8].HLEJ+#U=S)3.\%^HMW:F>#SD.CQ:^,4EGP457LWO]&<
M^.MX$T>9[M>`B?B9'MEXFRR'BAF6SE(WG?D.%*L>86OY/<IY6_!58S.@MLU4
ML425.C4!./R&DT1@%EXFJ-_)E&(T;3@"OK$9JF4X0[I5YBFKKI$&8'$N+/:Q
M)7?^?GA@I2;J"X:^&F!S-K7*EYB$?+WXKRY-<NT^65(Z,*<A0C0\%FXG;+L-
MO[N&!J$:UR(P00@^%(02A>S9\;HDXU+1<`?3**W'UX%&,[V*8I405&O?"J8"
M/7JL@O)>6K!,E?;!1Y-#OEI!XI$*L@-\V=Z;>-B)I)M06]25_B`"MG3E?I4U
MTGP8H0RQ!F`"QH>JLV)#:*P0/T/=P&0J%NK-DN/EL8_*408M'K&Z>`5;3G2H
M;$P^DV#$SJ/T<2J)Q"^K)Q16U`8NY%"MN_S6^BN&4<VZLB@_;KRD&Z'O;^Y2
M[&S1.2-V4!K(O`6N<9C]78)TU@6OSHNF6]#:*1CKJV^X"?6P<%H>O2O9G&!;
MB7@E(-P+9><URK=91>CK`AL[*F;J']*1-J+JIS`:,]@K,#F?:E#5.\Z\45\K
M#7'9C]40X$ON=5E1/1G;Z+N%T8?FG`A2)<_()O*%6A5HA?_\-@I"!0T-=#J'
MGAQTXU2DCOW4XHM8!`6\<=[QI#@=XPL)-1DWM*,M-#C74)!U)E>COYI3EGG+
M<P#GKQ_\MU<I[(8)2=I2RY(IZC-S8#-[_2X+T-6*=%GSFR`H>2#</RQ'":V%
MW?BK1UN49O@+*)!Y`Y<1WJ3\P86_^&-*%L0VQO:ITC/=@&<J0FXR1/'<`L4L
MECU2V'0Y17'FWH6A];S%$87QD"4+A4<R\B]TNHM[6\4@UP[\&N(8E)E&1>)6
M<&6E%T#C;+MY&\(_0=@(G[\@_(,9:!L4+HGEW.*'PW1JSN-I:-<3!(J;P2XU
MP82O]S\Q1!5"4V]W!$\>[!3+@<V/>^U5**0\>_,!"J)Q(1?#VTW]:'<SX*X:
M6:,=)G?]#^K,G=BXXTK]$UK!9#S"_F-U`UC2`IKUZR9.:@/YHUD3>>5]_X]C
MC4!?G.*#,\F6S:^$.:LE;^DG0W;F"M-\?\/(CHFM)W'*4VW5_,4[RO#`\,/^
MK#5P$I`'B8?X7Q.%&4PK?-V%II4-EY7%BQ^)5_#MX-R%>Z"N"EU`LQD&O#7$
MCW/0]BU(G8M"5J^6O`M%M)&/XB05U8^6M(:I[TRT<[@`%;8O;C]!*W;Y5OZB
M'%Q%<1;,B2!OHS3_ZO/)BCRF`)%#[U!O<)#*#-U3=BK5&95WEFXJK,L+0-\K
M7`3[/J0EO5R4;WVIGP.G$_8"(W]'*;C?EPO?U?6T"+#A((*/@E\6Z;D8V)<\
MJ!;QT>60CDP*8X.!?DG>-YJ_5%I2'(P8DRZ:4:\QM8-PTT%W]F`AK<R*!-Y^
MQ2*;/L:/%4\ZGC=B!,Z[9$EO8C9>3B'\;OVXVGA5"KF5C[00OBU$#!X&B&H7
MP6*YQE%88%L\J:)PJ@KN+C:65@%9O/[S7*OM+3Z],*[KJEHP_>N4Q1R"!2PQ
MY[.P0Q?[H(\MYW]$M@D2_>T[I5S=<7^`F>`I!5KOF-;M#CH3"3-YM3KH"N+H
M[J$9!;=KAVU$!XCMNSF.\0%.HA3*1,1OM"G:%^\MC-9'>C_2`B<GQA?<M^"&
MWFL%.WF#?+LYMJ%HUK7A23-3$;(QW,8&ER'YNF;@YY2/S$"1D8\K7I/AT\UG
MJWR540!;_\3#0^;G$([>QFVK66@.3TJ[??[;[E,F."*:3J?G5#F"9S&F?&;J
M.Q6]Q6-[/X=QQQE@U2/QA;=(@Y(&]OBMKC[G@5S\>3%=V[;!^:6:>J=RE^6:
M&8RK/:&CDC*\0HD``#$N]XY=]RK>\"$6^BG[MB(2I0:DIX]GWOU\3Z1<C&<(
M_;_+G`Z%&?4JD03/4E9-<2H(`$]F)C74[2Q^911;YBCJ&1D57*[..4!8=F!_
MY%"WSX32&ZNEGF!;_1.O^RE';&F=H#:=_I9\\X`BK^H%#$PN?<7')\*ONR^6
M6\K',3_?KA490V.T.%8CQ]YP"LJUUD.6]_F`UFQMG[0Q6]+9W3<D-S.WIJ;)
M9*3&0$CV(MD8PU&H\("`=Z&IH$5CTK]:V^Y,!818S[=H_I],@X?!L3##>:79
M+1^L"6?[K_EJC6-X(]HJC8K""?/^QVHZ[NP9HBD-OW_Q%5Z^7P!$33O<3UE&
MZ9`%S%X/`>8G7\=VR.N@Q[,L!C"7>;64((0O\:YJT=P$[N,KP1?\X?T@L+]#
M$<YT:?F-3?#V7Z)G!A^`YS<+D#$QF["C:$6@W,=A&A:[VN4+FTYG_LM>]GH-
MPJ*6E@D;8=O\+?Y\=Q$PK!9IT2`R$]K6]&;8?9[^<-9,?"_DO6DJ"N%D%\FF
M$4\%^P&3IJ("G^H:^MA?P00`AQJU.00=&RPNZY4>72][W-*&Z]=F'8>]2UED
M([3Z<NVQSN[7+MQ*@JWHS?$+:S2H:[F2,A/#'W#Q4.:['_Q/8"QAKMU@0*J_
MC^(42+T63S+%O__!/<;R'JFY_#%5?@#2C=T$%^XU%!"FL^3%\N3_<&@YL2Z@
MR;Y"]"V+G>!X1$C#TBO\3YDHO)C7//3YBY@?6E\0,'"B)NV`N8W8)%X]&9RQ
MCP5CS!I#CV<S#=#"2PV.W(,#%Y2/R6D'P-1O5#).IUG5ZJZ)JJYX&\X4CSU`
M`6FNP-RTD"=^F31W@S9[[6BV&GR_<CJ\GHXF/VY66(3*)[S6CSL_D,WVSQQD
M<6924*)RX,EB$FK1OW>(&W4=,05]"7:XUW'=?KOYFEP(Y>5"DW,]Z:(7<OG;
MFH/"#"8O<UY&H72P0TAUQ+W)K=R4<H7)+Y"H`Z)#EO3LJL8A^E:\!B2.9^]F
M`>>4X0<DP*SE;:YX5AJ.7&0TZ_$H??>A%9"C*@N1AUK?R8"!.Q)6'9%XSJ?T
MFPK*A"D%8\^`Q.!@*\U_`DO/QAWV]?O10]P=_Y4NU$@'TD<))KA4SZIJ3<#:
M4XXR5"LZ>UB#AG/X+UX:A^6+JPU"Q_1A>JURNS^@8G::8`<'/U/`*5ACZO.0
M(#_UH8C"6<FSQY#HNO&K7=0NTZW2E@:&5QA3\-.A\WKVBX4T;T6DD3_2Q>>=
M8G0QD@BTY4.?BUA;%D7?^V[S."`]R]>@DS^K4.&(EO]`RQ%\+O8DXQ4F89JW
M(6@R%BH'%-\)<ZW!]O&[9KG?9GK<_3#AB/]BL0SR+!BHP;\:D_U^QR=M6X$W
MP[@B>OB@YR`L[VO42JTH'N/GH%+)PQP@I!K#*F>L[G(9%Q;4E-F[.A&@\R;=
M-[]XMV:\Y%C@Q+Q*Z7,QSOV6Y&R38[GD7X0G8I*&3@/H;IW($SGS#4C^=FZ=
M5<A;K!7L9VF<X>FMFNCA5V+J^5PUX5B7/`R!&5XG(G5M"ZDH038&H`S4DC?M
M<(L1[X0=>!P9V5XT@VB`F%3]`ECJ&S`!2H<^`D5@H.[`;KI6=')V00:^J/'I
MZJ/0!P;V^8J#7M=\PUQC^.X$=$5SN$(1A54VF844^UL0U#R/$QV<I4E*3':H
MJ80ST&`SE<.%C_/OB`PGB7"I5>EP6(*YUK'(.!%+C`N6UD%1K.H#PB+ZWSFE
M!K18P5@3[+2UA<0"86[P'V0138Z(-4(TZI]K5UU"4\>.V?F&6/G@<7V5I`XB
M-+X%4*4$*3J2P!C4/'>)5!/N//08L\UNO$M"[NB?\=UP;KX?%"KDX,3%68DG
MG`"W?"^).R,$OMIY18T0Z?TVK92DE_Q@.`'M/ZOCGBD\Y?6`?CSCZ3@F#]Q3
M-9,IZ*O7+7+.#<$)+?,%J##77MW?!RS=)EU%GS8'HYK'%U5'[]K8%#3"(C09
MW,\!AYV`^XYQS7[W'S;^<X(E`:FG;4""R6R34XC1\WS"'@L#Y2RSDTC[:;/`
M$C<'+`S;C*A3$.N:#BXTLL1WG]2#HNB2O"\%IQ__`\1!?!\Q=^2IM![%>@<W
MUG0C_ITKP8(\2S/@P4T,_/XVX1@>55"Z=^\7$I(`-E[F@NXU6:5E$HRX-*6=
M=2QDG4P#HG.&O=`D(HA'_$=C5/]2=RE/_9+?^$D8BL[X6[OU9%_%M6WN6Z@0
M=C$IDO0\.)``N4BWKF"53DCD:U<0A8ERN4*:)$^*-VC_-84YENPP&32T2N:E
M)`/?:=Z!.0!BZ]'-?)4]GK7;OA1E&C15:0P<OG4W:O4M_\'KA9KK;.6HJH/A
MU5=\/9B,QU:0>^W*#V7U%K)N([[=1LG03C7MIZ:?BS1?JK"<TJV`*C376MN$
M%ENA]#*&?G)%O=\OT8/Z,$GZK2[OPBF4<U0"[1['+Y=.4R.VF@J[)>'R20([
M0J<(('-30=05,`PO7,AW"H9`95H<SX*471%;)&!4^IJH;',48\KL%LH6%@N@
MS5)!F]D<)"#1KE!L:<ITO[_NF:30S&4MQX.-+3RHWFX-,D^;`2$79HU*`B0J
MXM2C0,I&/D^V0D8!W/*KC?ERK`[`IAUU!*(JX[-8NFL=:>L'17]'Z_#"\7K.
M1J1O>?=!O,!_6I)S\?H513`BD??<@6%&Y@W=6IK'1M&#N%T,7?=9__7$L-]@
M[%"Z4A\WV?R!B1.6-3WN].7Z[W9VWL0U@W)3J->2]KUV.+=W&R$9Q$_PGI^?
M6>/,Z]I.JZ^92LEB!A)V8L!OK>WNZ>I9(7*5M$W6<)HH\<HKK8?*!$_&,93C
M^-+BY"C%?D"LC+H7TKA9`;L4\5#!4TO!7A@B&+MU(1T]F8"2CEK`E&W+8SZ[
MG'LF"89]4Y9-O9HUD4`V'U_O!PBC4,G,I_J[9#/[$\.2:^22=U3>S;NS9UL<
MJ0H`I#<SZ02K&9&M8*V9B<"K_+W*D%QYM4M^^-I^1)#0D8R8/Z6%CEYR;R&W
M13172D%#6S8E,5R"@.-TG?UE2]W9<9Y3MU[@.61NQBN([:'.V`+HBH.#[B4'
M'+09ANXA`=!&$_`3857<82,`Y,@0W=W1[9<"*PSN3?OZFN!NHH*Q+FF)PH%8
M*PO)!9AE(.WO63`+*GG@.2HI*F1J9(`CA;@VX5\ZN-'H2?.I/;(I(^*`60RT
M&>+;"'ST7W@:@,.\[BJH!#M+IXTD_`2YTL2%ML:]O`"QR<(L-/V]?V=#H9UX
MH_IJ),[L1%30<$-+4=#VT&!1XT7",-]&=+;H921UR=W%U26945_L#*/Q5Q\!
M-L[Y-\#Q__=0VU2;P&X4C#Z%8U%TI3>Z0X!!4',O="LLN*FX7&?=UE8(=GL>
M>3VLT.E;(3B+T6J3>]DLYR8L9JX;Q61A.<4W.G`$52DAL,VLIZD(H\J9^5?'
M9MT;&39+**$@>U?4]&R^]51'E3A#7<!5KI$&,E=)7%!H!K?ZM1^TL7P4OL@!
M;T"+3#]<^7)(.XQZLNCY4]??M'!S'G5P"PN*S)UFXV+KFUEBZ9UE@I;0G-H8
MDJ+?-96;(9-LJ:CI_='BS/-NSE^3@[XX<!0Z&K?IB@Z[GSNO,SAQM55'LM10
MX/`GPK]#L<\DI'M,EW\\Q@I39N]4&3:5,12RVB.ZS^J)#:#2//WF0V9G@CPX
M7RY)Q(**[VS7]E\*)R4`-L$I8-GD$%I>;+1S^N-I#"J<8`1\YW2%72*<"CHL
M%!]5@>\_`XBB%0M/$TF3GR":=<:W6YX<&WNUCE5B3*\#IRI.7<5>\MK>LE>\
MFWGO0XH"?^V!QO%/LWF),$;-AEU8\\R,P!DIX4X]B9,R+?8V/RN.NC8YR3%\
MH\BV0ZS^._H)_*2/%Q8(;0O!H"<C`=GZV)N%)]%C'[TWP9VIC/8;S&(-W-)D
MKN?`-<LGT]>`_#(1X+#ZR!Y5:)):C$A^V`FRN&NL(R><]*G::EPH<TZ+0G&Y
M)+#>P\`)2.TIP%K#9W*#\3&1<]I'=VJ03OI/_**7]>PB8.'K(_@.?,#NM\OE
M1WS\*CCX1WG0T)LM-.J\0TP)I[B9!,W<:ISFKMOTO/<AZI+SGOQ[L!.R78Y2
MR<LRTQC\X#^`I9-=:(/<ENNH)RH9;I]WIX@N2R"=UKT]]#%,YG8^",TA!$9=
MOH8`OA9,&/,ISI;]U(GASQAC#=34/DH5"<.;MIT#7*),ACZL'RJG0JV,85*'
MBQ$RCFUCG<A($BL@?K5MT2^2F*HQ5@*%7#\2&G<`&AON_'%@\XD7DAZ(@@A=
MC!Y;"(XVY,Q'G&5#U-AB(()12!4"0\#P;KR='G(<!(E)^1/EI)W3SINFF;%$
M!9X;#L$\O@]&I+X-_1=J5I=)#W,3Y199J+@C:$\Q7WZX4+ATG4#;CVSX'VX5
MT60NHT>-[)66*>K(>^W/30)_E@8=;@?"M>B_QNC[)-7`Y9(,G@J6UG`&F[KA
MG-3\SG%LZ)F=Y9(&R=>\`NJ,;:+:E&02Z0:WGZDI!="IF""_91.V"G0Q!)EI
MEPX?=4`45#EPJO"?Z<@+[;M$_:TG_$WU$B%R>=C5='SNKIQ![6K"B*"P,&L_
MK\F"174LV!4*P'W`-5RAOI4/PK`!Y#&P]FONN[+-M\:]^CD;8L0P/\3N8L(4
M!L8S]LN:WX!"#BIL_P>>>4SC*"D=>WSY'C<NQ<K4`)@_[:09`<ZBO2KQ"!HA
MC[3%R%WFT+T^BN.JV$MQ_CI;<MMDOL!-ST]"2/;1_:+8^A$+O0%8M0:_N'3`
M5&QEU>5"I=D0&!KZ;F)>"1A$<>&TN]J"K_G.S;_C@-J[38V*S5H-.;**CG!N
M*U=1SB"%$-BRVK2BB*2_"".#G-]_AHZG2/QTEL.RM-4:*VA545A5BD1%(O?.
M+])FP\OG<M?D7TB4#V=H2@BM'WLU$!#8&.-3CV.]Y9#`*ME`$^%PE-X?TZ%S
MD86A/ZO)OP"\F'^2%0D!_5?$W*.SI'*OK3>^"^<-36-G`5(=4SOP;1>0L!!=
M^*=!_DS8^<OSK(SAFS.`&?!6FB#)XP_VNRFJ*3I2MIQ1GSPJ45&#T'&\HU9*
MKS1K6]5DCC&[C9I$H?E-&]*OUF(G$I\F8^/A,E9@A(MD.>2XL!A`]WO&H7])
M7^TUU-)P-.0"UQ2X>B*OV[T(XTJ2ZM[]QC5.O0N(WTO4`PB0ND>J;87D2+6>
MM[M-H<S8K2<7FYA^QGI(8Q?2]()M_>8E3=LZ9K7K\/4+8(./$;7>5HI%Z:!?
M>>"%'H%!U\QUQ%*O*4?,03!4<0Y_--Y6P`*!=ACZLO9LU]ZI%D$J7T]U6D+X
M9S`5;:N$;\J7$EBH@5@VVBK'NW]JL$$E-V4@`V^YT_C1."'3ZG'D4'.Q>P2D
M+&ZO_Z[K<O@0ZFGG8A5G'?D_WZQX<*XC(]\IE'!<OAK<0LRLVJY$RX1"*[H]
M2.*+T4QM=61_1A.`X"5#67;!`U)ZP1YHL2]JN+)IWIGE<_]ID87Z7SSL8Q1U
M;^RGWPK`37YSX$5>9UI9;><+K7<^QOC9%X;[O!$:/OZ_<0HH=,;__Z>M&*QC
MR<C\:'LTZIN&<BF#[:MJ^>KD(D'9;K7(VLO!X>B=2^)CA$"JP_TD>Z3%CXGW
ML@IB7#!SM>E58')#8:A\?L)1?RO"=NN4IH^/?H-IP'MO#^W@H;L`X?!^UH\A
M:=.&:1$2<3NZY1Y-A(3>)WL>V`IH],3O:Y/8=<TXC%+_+OG*&<)%4VJ\#&1B
MMTL"@E+$E*SV\@'J('GQOCD?`_?O._$^'():(QW2<TG@#/_P<PII-;0,>*BD
MBFNBM;BO^]+):P^W7F"EO%/#U5.+(N`NKPK_Q3AQ/&@5L4"AD7LN`42\Z43#
M$Q@BR/H$?I*8DX"HHPM5CBSA8H?8K-6DCTC$'GB7+_B.F43QGR<;G@E#U.K#
MMF^&Q9_R:%#@;CW+'>Q'@1R"RTCM_C[8NH>[32<"]C;+SFCW"`+V8R(4JSAU
M<.[#\JR930."$>N%*\$MSP)@=9+]_;__UG<&_Y<M<S_Q%5\K#J5IGRJJ.4:5
M(7QFX(3+AFLR&S5)0T`S7_F>HU/'0]AS/,[+>JJ24.0/(;O\5A4WY+I4O9.K
M']0SF58,:\#Z%]I*XM4;1J:3QWZ-H>%<N;W`A*)R'>YH2M=.:[!8JPY3:XYS
M(K&<7,6&&!$VI:"L'$)+T01179&(7LN;Y-#5=1Y7:?`]0400XZBHS>9O7^&@
MN7P]5+K6L01B?K^R*J(].@^%3CL'A?!WP("\/J^<*B=T_L]ZC*#IJS7S/<Y!
MM*W97\X0>FA6=6C[^YGDAM66X$1S!9*O3`I+V6A23X&),BC^FI],$E(S`RH8
M0,#"3Z6V'4W31GK$8;$(L0\HY(V-IY5M#=[`YI5.`43HD2Z5(NHUT16KEA4L
MS]%&=Z+@-@13:)-6@U+^J8J'?9/G+G)H>_AM^:`S+]-\#JW;M^JJ\4I$3XZ$
MCUE?9R=CN^B3];Y0/G:#MVL8Q3N(:B\,C)2!2XW.L;WF0<UQM6'-LFRI0Z/:
MWB,GLSG=!)L:"K@#=)65K.4N/]&XF']"S<0[E>--^>?[@`&^:TE@3=255NWS
M=_EJVTWWY(D)KH"UAP8#8Z?J"<@M';&6<*"Q1$LDO8<5G;74<`YS1)ME)CI-
M1`\YE".[D?9#T^IK<3O1"6)N>55RK)8N"1ZKP?(I8&_"C*$I%5[_2BL%I,Y=
MLDI]TYZXY5'BB(L`.NR/QJHANE(IL)Y!JZM6P=C3M/G@JB<V%,*5=B2DS^O`
M7)V"&0$P.R"?C#^,W&<H2?*W.U"TH/=]8M:@^[1GE&.#\[HR36N2Q:F2X#@I
M<A9?C;$Y$5"(B$U/?^.S5B78MD!W5,B!V3,I4HJU`)J?&G54AO`#Z<OST](L
MX]4$<!;W.+F>#P!=E_*!O<835W_'5)]_84@JJDZ';:\(_<GP64&_@Y$\^UDY
M17">@BG`O=HOVHX?^=V61)>+<4]OITP&K[>:%MY*ZRDJ5'XV[P%8)<!IL,6M
M#MSTWD@.[[EO,[#KN94M9TV`19O;Q)(WQ+.@^#8D(>.<!#81[\4PB&+''@#R
M^R.M9(]V1*;AE<8];V]S+R)[^U1+C3/ZR6!0@?6A.IFM,?2$X*_1]8I-BJ>$
MZYA1<;2M2@G(NYV/3K^C^?=,3GS_T0LKA`_F0-16,E7J_@[)Q/N73J;1P"N:
M6)/!^E_/K#YR>&14'X#V^30UFSUG4!KO\ACP7'(PB.Y+1A8FA\%SN!Y"XA*\
M%@G!@(,=XXN)(J*79,44GV'W`+>[RI)J>-NU@D'O%0*L69M-O4.([\<3V2C`
M`X.G.U;W""'3EQ]TQL."J%'OZ2!:YWZO3!^K$P"GX#)K^FLLNQ0.J8,E[)QX
MM3/Y!RMW2'+96XZX9LW%#S+&Y[@ECX^]4CZ&MJ6N^?ZCZJ%F:25:D\U7L'N6
MFGU-J>)Y'(UAV7N2,6G^_Y78UC1W;G\S7&[TCOVH"??T8ZWF,&999G&`VU3S
MP?++HR`8>!9(D?\Q0F/MBB%+^R`7F+$!3DV**'1/9CS.`IC=HA/`Z<N*-/^B
MR=(_<#_RF9KT7&(1$6QUT*/S/)1)NV=M[CYB-K#NONHV(PP(0RE`A1&#E8P3
MF:`2@\7Z)YYQ"T"C<_;63T8.S83$FHM@ZH[IV*2V6>KU[+AQ^OC')OOP:74=
M\O>^T:-(#.?R`WBL59I.F.3^E!'PJMR&#VO$DVUU/3'[>F80[VE=LH;6]#@*
M^Q*?F0"`$$`KVF1F>`/(+^J#P("D)TY-9MA@*HX]5M2'U)]-O__&O_\HZPR"
M3KH#=&I4A'XO<7W\/7K^2]4[2S8?@`=V^&W\OZ[.O38E80E5TEW'=L\IPL2M
M'>A^7)R2<032#WJBPW.A;9D"!)J&U3QZV?5!G+(\H#O+%7#4?K"$R6DC*!EA
M[J,A>9@@K=:9\W^5>:0F-UV.[\,'9<%4U-R+DIT/.0(-,T7B3%/I["L^:,OB
M=,9\3%67A]F\<9A4I59L[W,?7-Y>)-J">_6_5G3_#>8*"NF1@$Z$]"#R!*3\
MT.U=[]D6=@1D,T@%9]P;3:RHB[P!\N8:!G.FL-J;[%N%\RZJ=Z/A*J'.9$L\
M@LX5^MQ9Z'%3C.'/>N<2Y/9H(U[#=+RC1)?/`(J]0?!"M`TYB#OP`C+!OK/=
M_$NR;"1)ZY?O^@SBIJ6NP1[3DHN_:6?`6DK"'2'8@"4;H4.VGKAOM(S6Q=B4
M3'=3'OI6K9<!K7&*IGT--;B`>9ZQ:O':798,W+11I7)&*`N2>S.6#RWS!,2!
M&F]Y]KKT*W_G9F(F]#S_)0GN:ER88-T%((O(#\EGY<:'//HLJA.P5];,H7HF
MO:7X-Z=REHM-L0NMKZ--IAZ]@7W35MFM=K4J08E>&?@.]SP0H^#(2TD=AYX]
M_HAZ)#UIX<,=N.$'\]Z-M';,91]-IC)$$O^L;W52AS#R'A[O\>(*?A!DCR.<
M[(])*IQ+`4'H?``GJU$/HP?/=:#<S_487%[X@1,:,:^GBSJN06PEJ+7/N5]7
MMQ<*"5''Y"^]W^5^QA:%37W7+#LUY=!FR_*4`?YZG[4*LYP4(?=./EI9"8VX
M^:_]/H>R]N8X%5B0V>0>>D>Y1G\BH56PL>C:QD.NZL$<AV8[I<R.8*GKH>C<
MEQ=#?9%FK2B=4)D[!$6=/YK<3\L!`F>^#B'1SSRM%6I'*H4=K*(5,,+:"+:,
M(Q@%$)4>+R*LQO_"P)<M<RMK5G<`;;-*2H,O#YQT(J.&P8AF5XFP='9A[$#2
MD%?-8G&K0$R<T'H"C/R*#'P<4#B9W1;J?]?XZ6$IF'-K,9A.?=Z_3H0[\7PL
M8L#I=I.R5WLI+Z*25R8;`LU;]@D,;>K-+,+Q>3M_GZT3\9$;_I8W@RH%1QVN
M<+^OU@J0W]6<CK)V"9_$;G__J&CY;F<'+I*81B+EB+<T5':U3`K#%XV>`::`
M\XU$,H?!"B-+B(CH8O*!W:\FJ@PN1_L;:H+PK@C-3])Z?\E`X4>9_9QGO7B#
MLZMD]^TMV:BOH_*YD\D=!RVPBV^BOG_7!7_(S^6(0U)ET&,55FT<KN]HTXF!
MP<OK,&,-TO)'\_H-)>;L"%F4ZAN&<NMR6PRQ3&A-/F[P.[K5SV\TP1F%-<MC
MM'\'8@V/XHYSC[0\%(WLMO\/K,3?OCB>^2U]RH$8*U5/ANSJM!Y+M7EKP-=O
M"'PB<-CQT6UV,8:5-7O#-Q3CTJSL:7H-<8X-5L'*-O0=AD=7$/A?_7$,A%0_
MY]*WI`R7A<VJ_VJOL!H3Z=NQC^I74=(.D$6].90.YCH\-1D@D]>*FB)O]?$,
M)96"NHM+O`T(<M_(K:OAAT-X1[Q:I;+IH`3V68(B2*);XB=8S]L#!E8XI4VO
MUP+]\[UCZS^F40=#3)18BPPC1#1"]WA^V=$\(2M0V9O>7D:>C)9;]9VP!IRI
M&!U^!K5!`L\&L#\]WMVN)N=)BXA`!)22WA2@,!@Z/*&L`5L>B/%A@*;S0:<=
MI<NG;L7^P>TS%\3<I54[MK-G<:QN-5+;>=5>L3]BCNFKZ!F?QJP[30,$T../
MGF@LD&;M.DATWX$<(RL1YJ=3)O]$)KYWI`7G0:_#>4W%CQ'I9^:A`8;A7O$=
MV:6)#ZG?$=]&8VY%M(GN&3I/M<$@.P])\*IL]L<>4^7]6]UG)\,1A0I5*?7'
M',2V4$(.U%O6A:HQ4D)]X,?8'589YFR!48V;_TX+8B@<FV)+!?OK32YN:@S@
M_1_7&[`6Y58>U\YDTUR%YX=+,Q!=MPD2=?4*1F@)+[06(EB"?<G!P(\KE)#.
M6U2I"/@)W`W0RL^:/C5KX(Z/(?^,`&;_3N0`+FV^_#4RM=0XI[P*3K>](8V8
ML<GWL2*J$?09-RX0&B`1UI(9>:4M9NF%#PO(M*WI;6HID^U?=RI=G2&<F'-A
M<9&-.Q5A?LEO5O2!=&0)(U^]DU')SWL;U1HF&"AXY&8&2MOJ^(6?*JC^;'."
M0R2,C_1G@+&7JOHL\B12Y:M0]*YL+\W5H]OMJ_Z?!BXK>'=J#`ZF"JS#OC\7
MDR72*JSL0VB:5K'N-JQQ:$3H@>U\7W6*RW5V;LKZZ6*\D=9[XT0O(0Z=6,!,
M-0?:`)-SJ+U2O:V0NT[L%^3F.-B/LKSEHJ3V[+#\J?P_1G0,!JTRC5I*TGR4
M'C)RJ5\MS;I^A-TLVJ7,FOI[\YI[0NI.Q6A(^,Q5TMZW4?5NM`S+#ZW^=^)O
MRU@/]W?.PR\!]69P4X\:#_BNHWZDYV61HHPTFRH"ZN2-H?3#VZ[Y7.7C3?J@
M'/GQCW!#5=B)FARI;G8<F\)W)2*EN=<3;YSVOV3"S)*C<TL:#4W/`(./2:)0
MH\ER:WM=R`KD9+;&X5Y,_;N4[R;UG;OFA"F_9,67(#(W$0OKCCA>E6$'A`D$
MR[/)`A_A.IV$]V@@/7E^D[-!^G#XV']Y!K:N/4HJS9NC?#&34_`K8YU6B6*&
MM3XY"$J<CKA?&93QC4/MAOSB=\<W<Z8@*%^`78R(67T_-1%Z@/<BC;*R:HSL
M%;!@(\;01<T+J[D4?"/R@!?;G4BO&H9<VW&MU'>=UZE*HPI,9R6R%4Z5:8"6
M1R!V*[2'7Z(!S,KV?&"89LZS@O2S>I!M,!LF?'*Q$@\+TT&EP[BPEU(\-SDP
MSC_ZT_=WN=_\HI9M$1JQ6GF(&0')>\E-'^Z/(O*^!GUWWN-'#FOR^B?QVIK5
MS]?\M$*>+W50:^)C)NKS$UEHR5-0M&0(K'A=Q`-^^&DS"2\,V%H*]-@'@Y!Q
M:UL+4XD&&E^(SW8JJCJC+*N&;CNP6_K0>#88-B,G(BZRGCP/PMD[H@UP2%%$
MD,TDE^9)Z2!2?FB>(GHG<-BPI5%YWNG'+]*VZT0K$-'U.S:]_4!;Y3C^23N;
MY1]^E#+O#+1I6DHYS@1;19&FO`FFO,(_)>Y7Z`@9,]4!X$"@<!I()^W+.C/Y
M-Z#@!U6@6A6E6U7>3C`DD[V7)21C8G\K2=_+D#F&P4IEE0_%GOQ$^7U[`GG9
MP#"2H:ORTM%`W8GE6*,%P')=RA"#'AL0;\T7I%G\.VS>0ES<4-YP/T5:>='K
M]@X0/#@E]F,=W=7CY:9>V=7SRHFF0KJ:Q(R;NYBSR9/2?3S.S'=4GSN7BG"O
M*A5A?:+[7IG7<A"`MDAWE*>NPC3*Y[8%Z=71`6^GMNUP+4"0!(;^O,95:ETT
M+V?]LR.\SG=*&3'.)2:NV2,D\]!<&'O6AZ[RK&O,WU9[_XW/Q][(6^TW3RX6
MD3,<UH58.".6NKJ,-S#4<:<SHT>CPQC'VV3[LOKOJ#X0:D!<BZG&4"S*;%TW
M=$0^/AQ8P&0DRU\"KH^PY%Q:4TGJ!.)2*73,,[K/9RUNY*G-T^L)33P.R@LZ
M`K9L*^J'L-;N.*QUQ$C]I(DY.W&\6=`)(-DO?2PO#='/-%OF1CC+OB<;K-K'
MK-)/P;"1<RW!1HDU5?Y/Y)3KS_&?LC_F8IPQ6!5F80:>NII^<N>M%F$FW=$<
M6"$E)-2[DV=O%41%&_^7&SW]5;4SLAL(&508?7%6V;).7[1F*E$8P*&O$'8'
M)!FY?.^_\^2JM<L#N=>L(S&SJ+(G[)T]N/F]W":7I0RF'8EY+ZO[-8`TR&WT
MJK)*KIQX%,0T;;6K`GW<S7>V.P;[JR2LW(DVZ/\7ULIEN"=,_EQRLG3,QX%$
MU`NM4^:QRA!EMP$7M+%;BAUHX':JGTA4^T<1FNJG\5#X]J5]F/PJ&]^IFTJ:
M-!%7,B!PA%7K%.K_72A_VM[?:6T1>02![QH$0%0GC96)XB"`Z"#)**!.W]]-
M:)Z:[6I4](LF+C*ZM#=IW"!8*Z#K+=!LT<U.,],#+51XG`/[6;85(,_7&%<^
MA#N)+W,QRI/96[XACTI+'SJO2N2L[$><6/[X-.SV(G)L^&+:CCK4)U^.4;XM
M[.!7]&_<Q%>O'.%R2#6_29:&^'#IR].S-[L<>,^+<J4$4ZD\_>:;QU/6*&WC
MUQPT:8/,!^>2/QU0'NP/.$1!6ZU;]AH9]=&]J?$O_10)BO=EPD^<$):0#SU!
MJ9^44]G:DO)%"UY$8JQ,:,@TM9BQ/XM7*L<T2&B9!_U]=EM[S_7$V4AN+@<^
MD.[B\%P4:/8'/M/F/[7)@RP+19Z#N=K&G\\`U`+!YO8[_7'/Z4:2&;;BI^$#
MG+)]`IVKIO'YI!5@B,1FH`^EM%^/B*P@XVC/$//>6FA<05+Y*W[!8#`LZ%'D
M#:^U.V'8WZFM=.&PV.8C_JVDJI=\V@:D<<\VB;BL@?B\TJ%6DK`/4<@GOW"P
M[5I1U=".H2`'N-=!"[+##'FA8*%N&L#;*(7E0<KQH]AP[%,V994L14R\Y8L9
M/<!'2K5==A_LGT!F6)%>`)<DI3BS;*%8MR$J)IK.);F]Q,\^"U$GK0_:]A#B
ME'_;\TWF$'"-S=QTDD1VZ2&J.;24TIDF'59R1!J2I;MBK(`9X!@,IRRD%S;<
M-]KW)A]V,HL(`F6N:GX7B!5E!G,FZ'F`UCJW4TW=W;%V19_<Z;07-PBK9J!O
MAC-7Z.^L1;:6L884J^K-TZ6MC1SRPP/$/'Z?2[4*[&T0`IBNX;H)OGZS.,<7
MB$0#8<JM)\5<\QCCXW]5QD#O3$50*0PO-^'J+DU\;Q>\PW)99J\O'A(Z-$QA
MWZ5I3OTELX&;A`L7IKTH"JF)C&`@?006`]GT.$>L4_;6.+VZ*P@H'0LB%8"S
M+_N4[5Q+4\=7)V5.>=WX`K@%B,RN9YM&=;2C45$8JN(-KU3Y^__>Z,,'O8RX
M23:962'Z,VE5?:N(1\D4=NX:!'6XOO.O';>OQJ$QCTU[0=:*FVU"UJ(8D$I#
MU(XE^W&#VB#(!+*!)M@P\S&4DZ#%/PV_`TU$>B:<8DSF&5TYD[59QD:_&+MZ
M=I-=U4?L"Q4P-EEXX_$#]0/7CV#:0/-$_U>4D"NX"L\,-!>B\<M)#,&A@HU7
M%B&(V3N=T,>1Z0LE+_BJ`<(H+9;`UF8G]I`*K]2FE\?UK2JAD>VF^ON-2$!_
MN%];PA?[CC3I3I^/05F4@(PJI;;N;6Q!BKV!.+MVUNE2W?:_ZCB$`2Z=,V26
M8C/>"AS&_`O[_-]41,D1&<-=&#L-A$JY59[<T%!XRTKAAD"\G-+NKS4R1?4A
MXNRDN"&T&VV>TF>7H[7Z`4P^YYFA-5'<8LE:-W31=:DF^AIPA.UNF"A,YX31
MU>0-#B>ESZX5X>TA9FVH&K>;.>*X_<_>4%$3-B,:;1//>V5^%G*+V4@WTYB5
M.$)(8I8<TKW1>L$8Z%.6NZI?I)K`+$(W,U=K@!R[">I:TR*1\E+Y:HA6LX7?
ML)>TPU.USCY.LC_<R>RN"R?,E2H*Q:04FW(\=+YZ>")6-0?UI%11UM=JA%=0
MUO[BCDO)L48-SWJ]J,TT3+@M)#"SIP#S;K`WQ+C!3Q,YKKO.^PJ+Y29>8#A'
M>(`N?6J0!A54&'ON:PYI#<)!NE9\XAU(8\=<R%87VP3D'`5Q@(M^39^[Q`94
M]9/=8MQ_THQ]\:2@WX&AN8$E)1<@Y2$;2"1-&%%;95$6.O9R<#`HX;@3Z#WV
MASKR:'#]:59)II[(LBHHPOR^>:K9..B>FW)>%1\>!_/7O%63'#?6$U]76AM2
M2<@=^I+'KW`>%>Z7#6M\*,5:GD=8"/B%K&2]1MZX_75QEXTD"K!0+C<Z=QE9
M_JZ+"KG*;+QRS\&']EQ+<Y-2_DLCS2C7W+(("KS0P/'7JHZA8]R\-`U(A.0J
M7]Y@QK_-KR9'(+4HD-UXWO:-QO3D[`JK&&'G9P$4/E0#>/MF<:4/+P:AUM^3
M2%]$)DBU%@ZG@O`F24G>8<*0O"CK$A@5QK:*]6V;X9]8]1E\-\Z[CZ.7,M@E
MYRPN)%OGV4?MHU7PO_J$/ST.^.HF;.AU6@//,H;36`N9DLK4UQC$K84K'//D
M&Z^W;N&QN=SWQF+FA18EN;1@8/=/^L_S9RLH%7RRF/#9`+XXOO3"ZB:ST9V?
M2>I89+F,C8MQM-SJEYZ?[I0WX<+(OS/$>VJ[&^B66@-;F)0BDF[;8\F$;E0K
MJX,Q:FL55,5%;5-U\42W#?^*VK.26XW3_Q1&V'I*/'%.0?U7VKIF">EB+4L_
MCI3(N(Y[TT5QM-Q3U</7XK)_];$($-)O3:+T<5;6]+_`6^],:WA`@AF6CN8'
M2AY.#=F6J)=0NH^BQJ\;G\%44H3_B2J)'$H6VN[T*4':8`2ORW$ZSU6`'=$/
MK1MPMTUK8LI*=YN$0TUM!8)U+UR;R&'=RE&*#/V"C^]F#F0+C;UH&W!:YTIB
M1%C:3(Y1VB&H7OKHI>IZ,P%J<?*HMUPH9&V7@P9>LD3$;W_SW0=Y^D7!]+UK
M;\R'M/KDZ4H4@'&,IZ7CP(QB:(?PO-.RDB;6]Y%81S>O36[^UJ]*8SQ/@LE;
MH^0>KHAP+09&[7&#(JL]4JN5J(O_7'D;O9LDTV=B>VRF=!<$=Y1)XI?DY#[-
M<I!PE,'E@H!428;IO:PTZ4!0.WQ4\A<)HD<(\2D18U#&Y^Z$$;/]#SWZPQ(U
MROT@V@7J+H16`#$.**;T+J4A,ET\?#[+!T'%,<W6B'#]$0`;,'4;]"W;D&O%
M"%@4!&POLOEQ7085FB-=O./_IT/UBUG?Z4RK"SE#,E!Q"25U>/C:I-UU4Q5]
M_WF[0%'>%M1G,.Y\N.TU3O%-ACFA@>=L<G9`"@%69*ML_R424@9GA<E18S!U
MHR.,`E6@LR[[^2;T^26P;S=.TG;"M"KF?!LIO89U\Y*\NNW=W%;'Q5VJGUL$
M3WS]#FSP0W,D^%5@)^<E[H;>?$71-MK+;>5>PK.T'A<X,ABO#**\^WJ\3;#0
MR;8ZY$`HJ]4$)5H+\(#/B^UF`9QNNPJ./0N]T(=N^@3T+4O-I.C56\K`#P//
M*JH=>00Q+F-!ASKG!_!!?&9*\P5(RG4$`J9D+>%;+>B?C`WM*1UL4/]$OXBR
M./X[I5H0FBDQO5@/5,-OWO=@EAXB?"\64U;%U:^IYOZ;1FM]^CTM"M#]D]=8
M8'HRW-)K@Q7B)'9?E!Q/>LEQ*F?=DZB,+P2:5+Q$9ZIGB#<C"_,5341CFS9L
M,,$BSHP[VM_%X26@(,.#X>*Y/44F.M_W(>6XO#SZR#PC\X<-^KG9DLU1L!(]
M/$(CFG@+#D//G29TK0S\!UR(3)N*23&2_/F0\(J[)-";,/%=R*E"M'\OLA5I
MF%\%-C9@&UERL5B!PU#U;E_=6YQM1FDJE3'`N8<X[F^B-)8/\4)E<QQMXBUT
M'N\#<NLP>IQ2"7381KL#*O-0/FR1W./5C1M:#!DF$XRN6<<=00&8V:41`YYD
M#>ZH+I2YMG;_D<P+1;Q3ZP2YCWXD+'V9QZP-R:`#2U0G[L3HJ/26_OZBHF]"
M>L]U@8@W/18S_[C[5_#@0(-\8$BDOSS5@_#RB!X2;+_IMEWO-:!"%_E93P?A
M'L4CD7,N46OLN;RO$=)5MH$2+'17F,74)P_W99XJ<YY;9!&TP_U.5?^J$?"`
M%Y)_4%NM38613VF[\A"+;T&2F/]3TJ-9KRN.LGPIU8EP$M:Q[2X`UW1/",;9
M8[+G!J9;SBG1NS=<RM/%Y`KWC!\-;66D^(TKDDZ`>VDR(8%L$'Z0]9EAY[8`
M3,(SN"=[0V']*0SSH2S*+K81_2_!G@>IPI''J6D'[@MSXV](:6D<WTB_L@"]
M^&&-BRM!E+0YOK_)KW0./`O/*5S8QJ<KRE/#O$QUW`K'<2.YX;R&>_A_EA66
M<+%PA\R1`2!`"4E]$J<8C[];HB#LA9RS&S8+MIJ6%%VXX/AU43>L"0QJ:`?<
M_P`PFNWK5K4'&A98G&+F]_3NSPSY?&DJXP2"?QF8>4.$;:DO1C"S@W#H.)H%
M3Z7EJ@H*>Z'9]W^TH+>*C5-;JESXA,ZBEV$K88K8=VDRRO^W"JI/4:21[(%D
MMYLYDA=7T-.I42&8@+D3%"I)?647^.#VR2&!WDZVBP$$J;V75B\'I!PD].CL
MNX*Z*<C!WD\J9-D4SAZC;(#)_;KX%[#KL1?7G>D8Y?#8.@-WX7&&WY`YV?WR
M$$?ID8&35W\%K!W.9A:SEZ2[HJT[8!9*,)GOIV`V!36[A$PQ*ID6IJV8(-P$
MQ5-""K8TT9J,\E&X_5U3;<^F:'_2/^.%MY1V]<?$`,*'S<YMO%AQC7O)?."/
M%?;+J&9`KE7^/9GZW6^#OWIM9T^9#+"]7<_-K\6EM\BW#?/_#6YV]]GLCQP1
M\VBKW7'4(<QZHMR_&*N(9*IB8Z-JFXTM6<G>]'$CX5=X;]O.GY,@-T3DEMK)
MR,$!3#^F#E:7[O5?H^[4>);&B@[!\)?>`V]=_\N3EM\_X[.H6M'^U.>R\?39
M9YK&?-">`:#7E'%[Z,?&1#@F<+GU;_A&DL\-);$";."7U_:E+Z7^WC6QSR3(
M@"F:0&(1-A-JA!WV4/,J>H44KN?KS+V:D@NZ]*D,R4^2_8]D"'4N180=DTY0
MF"VM024W]\,0_A@QI9#,AC!)BEWP3JOP+Y;0:L.$DT;[YWGT-XR(/FZ/?0E5
M_(UX`'R%*!E"$JOL,L:+ENP6\R+M><_6L%RJP5IC7=IB2`QN385625[]E<X)
M[3;R$$_M&!/#:;YN:LD]_1_K[0ONQ*Y+87(35QY+SI*6^C``=>I(NA!5N=?`
MQGLH+G8SJ:0+=RZ!:&EU^2S\A)N15'P(&>!:,>'.143H*L;.89RKMDZ$KI3)
M([3Z:X^%?;=&2$+P=U)W,>W?2N@3&T3HQF1:_J?VS2`@P?LZZ)'Q!5!+'>51
M=RN'%D=4$4E:3WYC^^,4GK1@(4B`(;A16+TN7`:!VY#<R,F+T-E$Z&*0Q#/K
MEP<JQMIAS5UAS=\7?WTL5<A0&>0MD>XF0X&6;L9)G(U8181_"%])H9/?,24A
M@$95QI\E7(FX]9I[24S-/3YX>*Q_CC/XU6=-,Z*@!!0Z4GD(,ZQCA2EE#U,L
M:*2?F&C]<VW@&PK=I6R7UU;7I$LN[?K&MRC"]3(@X3?(Q;A<L6B()/VVG;/?
M`RA6,SC`DD00%R_@V"46/_%U1O\]8Q%8V-M=!D<."9OF>&AH1VD]>3G2P@?6
M&,(Q8FW9,'KW;!R(91PWW41P1R:@(B4B1SRW3>9@78Q.":OO%5X2`5D&R)3K
M:O`YNC.OSFL92&:&&)BIZ9!ZS4O!;5$!^(KA/D(S&&FCHV1R]<>T<&HY-(BG
MJY^W-AJ^.9QXX^S;[W`C,@A*51W-V/%0TA0LZ\HF-;$PXKTD,U_C0>]A[/^$
M/1/HJ_8T-[?#8BBW#S7B#'+?+M03W<:J.W;$@]KO$`LG&XW#E+5*RB>CI8ZU
M3HJ]1*DJN?ZK\1.?MKW'@#?A$^X&"P;__ZLOC,"1>(CY&Y[9O#]3JS=""N\<
MF0$K>^2;S@PAGNF*/%NU=2*5;D'<8K#"*QG,>66C7ED`#'ZU/$*!*M[_T^`I
MP-3:%`!YIN/&75-&K:4/_N.QP-DEYX7\RY"'1ZA0@I$+HIZ3\N6'@L^T-7VX
MM8X0E)N<\`5EBTL:[&%:>RBQ=)2<5>O3XUD>%[P3LPI!@HYY((LN&_!2K83'
MRR[RN!"9*'J03PE/0+`TMUH5CV&%*I2BE0S?WXJ"``O",2>B96IU\J&V))SP
M7B.#A%T5B)>`QECG@2F,SBQ7*=>O6'4(7,LS^`\!-)A7VH-WZVC/:XH7#/X@
M%UP)XA'PCXTJ@@WBUFA6H8I;X^GI61]5=AA1/*3[5^SGRKSWE_.SLXHRZV4!
M<_;MR,;.H[">Y+WAO%\&FZ*@5G.<\X)SII:V'GI27/`[',OSP'*P:``4-_]/
M8]`V)D;ROLZ&(&YAR[2N]G/Y+S%Y2/^;Y$BZ*=/!]T&LF>Z.'M`85<.EO@/?
MS!#1Z",8ZPN`JJFJNAA-_ZW@X'1.S_J\!4-Y'LB+GEN]0VA?F=LV8A80BU0:
M*?R0#\GS'9XX>$HXAJ>\0XMI=U>PMX^,GE)Y,`H+NJ/<&9I+Z0^=0I(5!0UA
M30T;^Z_E":F6"D1G5W*S4W$TZZJ61O<4&(S$XY?@"ZF@(*^80RL1X";(L(93
M1K8^S>C^^E&C!7CP$/U?&C?9?OP$XE*LX;32W,],_GRGB8%KL5=&%`K13+`L
M^K8/VM:@]A0K]>%>%BQ"_N8:G+(]Y!>QTK`_<9D!/U'Z\!7(CG)@UM>K%//3
MPN15&)4T.'$*U\Y$TEUK)+WX+=YG&<T?#@TCG7J/6$40T87_Z[<AR/W`5],V
MOL:+%]I>3]'V\\S(U3^$_2VX#]8G_-F[*S08T_SF8E(X)SY$ZK]O"X)F=[VD
M+!$S$*%?>`*DP0$&#[>IT9*6B)9&T8[G32%W-'QB$R!DY0S)^)7.SB,._])^
M^U:U,.W7E\:Y.$Z3RR#94I[95-)P=B6QK?QN"5(+R\8F>V2U;Z+O\2:7E86<
M!?*)%5A/1KG]A*P0[S)BG.4OFE<0W<=%_(^;>SV\]2($DJ';<!QO#6K$E)0B
MLC?P"/^-3B^.CX3^D5T4$]HYL]J<.EQH?N)*?0^N/Q!RS>GEY9/P%-:NE8$0
M=5A_?V6(N]K/0+'?/IY/'82U15382MD-)B5'/OR/F%=L^1Q5\F#VN,YK??_D
MP.?DV+Y@;$(4#]>S)V+&W;9#%O$`<A&0D]XDU?5QB,B&[0+VUO]`(YJ&2Z%U
MWJ$\8RGJT\V62FJ^H'WRMG3Y`I"W0.=G$J(CW\5'W*?N)4QZUR6'8Z24]X==
MXQ6W&&U!@$2@'Z\M([&%Z(VD%N*YIDS1N?#C0[HZ`RP9[MXON1`FKTIVBF7E
M/@8Y0@4R).L<!XMP1[L[[X-9W'F,16=2E.ICA[-;]O^U*YIW)RJI\'EIY.C8
MKW)]KSH*NQQ[7B[`AY.+I-/O7?.C;"";T/YXW,H0]CG/9:Z;1:>W>W\M0?G$
M29L,9?^27O87L>P7K*H>]D,UR#QN27IHB]JPD/2,@2=4M*3HG$\L^E]X)F70
MQ!)Y/95T]=8TY?7W+?Z?(S/;19YFJD]5>SD!EF\YP^[O\Q\I$-@4=5^M#50=
MSW$S*GJBZ+"VD:C0=+$_G6O!-'66BYS#L14R"8@,<'7NY'5OJO9VR9K97T'E
MG*#K].MNQZE?Z_""^*W\G**3SM-#G_@U+[Y]-EGIP^O"+KGBYK`[G`AE%,%I
MIKPVC)U&Z1"_[Y0:*SO<4ES:'Q>9&+;"6Y2=H-$S.$KPY%Z]:F7X\+K>D^%M
MPO2]=5=$R6?MY#C9`DYL$GL\-DN%=RP:1QWM&WW]YVA^Y/`V$$3+%H)%EU.:
M)>SW]F^@;Y^YYJ+@^B8NF.`).W`#K5'[9M^A:\9AM]C?FL`1H"D'+"6Q-D*0
MUP0DN"C+8XT3EQ>$A?3QG:SH2EU"]+S8Z1T,S9,U/51]P5"%U:JQK2B<VE%S
M-H16QN3H9V#,42PMX.9RI[BB$:DS2H`F$QX]:CHRNWY;H=*KF?4J)`?Z?[RN
MA*'Z4%.\.L!0@K#27#5C2`*F6:=ZN.:/6@#]#<1.]7!-G563UA'`'A'M+0.&
M_'3I\BX7@/>SN?)=544],4"%Q5["C]3,`/Z#N?\:]@>.SVJ[*Z=[9A+$^!Y;
M`C3H6[]4,$L7,@4A`SBF:K"WH=J#8%VA_7IKCB1Q^/3DW=$TTKZIHH48:0@3
M0#\^PS["+/U?^#5,_LMFUJVR39&OX>K'WR-.BTWX"6_[V`K)S'L#5'1.F1\>
MNLSR#0@70V>)FUQ0%SR5`\Q-K(-ZWF>[DQQ&UYN1,.-`(:&I%<EH*;3OJM[A
M,UD.QT,-(TU;%,V%\#[#,4$]%GKE>`\YHI`+B0H5T6M62JC_WXNS^$;I^O^7
M$;^&7^"&KICNFG7W*F=CI`?3'$36,<7-O2FDGAAJV(O[%)<+KTP-GCG5I0%)
M\2'%&*'8*;+F-F_:3N6L`E]#"8K.X>G.[L&-/]]=(RB$],#L\H2$\3F.$!ED
MYOX4TQL!:%]\D:7^K+BFY"<NL0X]NN<XD52UN#=NV2S?I+?]GEDS9(EN\;@1
MKRR^#**V:<I:%#CF?L0?8)$[KBAZQ/8./6..C/79^H$C=2=)RK0XX1!9DJ4*
M99=:VAAJ`$/VA7,$4O3S.2DH:F"]E@J`^%:$P2'JNA.I]L`N?H-C:5-S3&+&
MR.(--+2`Y-)-:[_7`T,LD=I/+"85QV)/[!MD80ISI!L"^"V8T`?VE,%INI2(
M%H#F9F&!=_KX#L>UT[ZSG4HB7>%/3-9B=\EW;.;[#K>$HRW."7'4^8:S8KUM
M.%_3-889:S(S-2?9?;`.\)@=`2X$B%N[@$:)[:EQM'5_#2(]XNJ\H&3%"L%$
MYT+6<8X54:GX],LC7^*0!8WF8?B0F=AT;2B`I`F2H)[C1-L`+N>6EOKY4-OX
MS/^CGO[^$@Q>PT=[.70-L3J^%,8MA<V0VD7F6LO/5XOGPUUD0L]SX,_<LS6!
MTXO:./.,)CH[9TE347"%]*_Y;G1H@0Y_7T0V)P_F1Q4$VS!$?AV0])=-$RQ=
MUE?BE3D`)[6Y5,S!6@*E.H/#^C7]W.ABIQODQB*8EZ,(@%F$]L`'Q!T..NBJ
M)CU8G1VQD3S_5$M0FQ)J2LAW6-#^9R2TD&S+M[8BRMS+Z\;+T/9A@NV=4]FX
M%EZ%ZV.3$*W.:-V%;OJ#,%D-)HAL[>U5T*?;]5.*_#<_DS@>O:"MKX1-FZ,P
MF*)Z7#59V]9_L>Q1"XZT.^ONI/`K:%^*T8NH%LCO:,*^S1%<9,=$,W78P3@+
M:*PG.\4N,P)JA2@7Y5_70QVJ%ZTKG_3;1$"+%-"D/;T2/W4;)PZ\Y?;JX*A9
M7+-:@F*D?@NX>)8FOPF"85.!RY[(Z&REV`^U>G7<GHA*4P:J5RVS0HETWK&J
MJ[^I1/EA8<;#"[<:;*^#Q3\1A]N_2++,`(I$BO!J&ST.9\<(><D$#&*NSQ`K
MX3\.<V$C/?BWS<UKV=1XFAGZ/^9U%`8F8ZD6LB71M&$AU&MR5\0/FD`^M>2%
MUIFW^@]-DWCRF)H?3%2'N:<76$X%.!%'30>DB2I^I^X%3ZW@*C!G"5>YU<T2
M#BC>_K8VW`DWUIGJ9!6LK:F,;&D,9+0GI?5,"?KI'F!&[[:_=[<_7S`#>.EU
MU,/).RJD$J)K+0%=6]+5@7)L:UD?D!AL>^83$?Y2(.FQ%E:703+?3LT!(-I2
ML:^:OS&*0,-^'_+63_FDK2G/*)7/W7,^=\!%OW-=B6'!IER(F;5RW=X$.@#@
MO3&^+42IQ)C%8YO4DT$,P9G_FH-*BPCD9C2@)6W(H:,GTCM^"L8,?(?;#J_=
M^QR5!VNH*5WQ)C@*IU4?*^PHCE$J=@1,'PEZRM%KAD0'%*!M<E/"J.\A_5`V
M'7IPI4U1.CV1.QTA.%@J?SR1"5GZE(/>O),D9ROI5'>-HH^VTV?H8$M.`U%F
M:1KN=N/&UKYG+E"CVGQY]_7G,?YV??^.<D[3;QO%DBTNGT.@(93U"9H75#4O
M;?6<),;Y47.@=Z4A_J6T0Q*O[308ZCU<:X0GL"4RFHQHM@4D,!2[2?Y"=8Z<
M2)\X#U&%NJ%`8S)"2FH5_=A_980T/XM:@0P9K:8773!.R!T0&-779[+-`KXY
MH.?3,A$X&%4.T[@O$"TPMC5A%T;/!9;H8;-D9)A7@$@1LZ\JBU<S):"RE+*J
M^H(/XK8XTLLVS0?E7CG/I3W!4;8VXB1]>:<>G^.]_3%ZSOGK'!;V2[H&42!0
M0*FR7(V,3T0@B^F<-X?BAF?3Y0@G81/SHS:(I]7^G-E<07;8&AEE>&9ILR-W
MX*14JU)&#3MY6TX[@XCVU5GO%Y@*%M'S=$L#;]E>W\-I9G:K&!<?-`,2I>8"
M1Q(V\PJG3]+$\@OJB>;AF$J+UT8MD)C1%WA#OW%BR[#WV04'(PUJ&3[DZQO4
MV$4,;L%S'P6G(33W;]WJN8[5`T*/=-WV(IQ*H4E38;ZL5.HR*?U,*Z#.Q[;-
M$:KE#[Q3G")$#(DF&![S/24`!,G?VEUQWDP97-G`FI(]\):+_(R</4IA/R3W
M%^FP3H%D'<$>3FC4[MF:@_$U=H;/PSP8*+\T#'?"=AZG$)D>VKP&'30U5.+0
M&/>V5U&1G1/D'KWLGC;C?MA6C;8Z8'O?7%&2`17QQKJ:CZ$&?$!$AF177\O7
M`<HSQ+O&*QAT3FN\L;W8GV`F#QU-<=L=99?0Q3`DCJV+0:R6DR$[UE)=.UXN
M`&==-3U[$Z7,39V%]]B$N.P_KI'5QY.8(\8&P_%2IB\&Z<Z[H3OUFQ^KZG/N
M4D=)1]#G(?,&=VK.GU>\@/,]%P\!A8(Z&R)E12Q993Q6=[HI1T2-,?NEWAFG
MRTL6DM(&A0)9^!<\*+"0XV2Z,JM=B8##!PU-B%&M0Q`83&"T#\\+*VI.5NT9
MGQ$*R($Q-I8G"1>E@M)6".G+$:#X3RG]5:7YD@W9A=M,!5A5=01P<N?IVU>W
MSY[IH2HB`"PKS7\?X^GB?/?&(26O"S?#FP=X_(CX/66][9-7;&2]O&8VF84[
MI=#]BU!!C?$[YF.?//-D8<[)1L\D6R6?5MY?=M868?3ZD1L`OY>H-U!A#D;1
M<,&L&G;09VW)@`,.Q,W%GA7'6.2V5:N-X`[N!&M?!F_P$<'([A1B"',+TK*H
M!!`5\9*-+A3_2"HT_,KEC>\%HRMPC4:RBV72Z1!U/Z+#UJ1SUKE-B_)$;1U<
MN>1+2+Z,UTI*4.9RCV<V?"'1X_LA9N#,^2F2Z9:UG-FST/E:`[_Y]G;%@#9`
MYUT!@'YV+#1)MI<L^0IMJH(M-%IF2[0G]1]X)-/U-3USE-L5]QAINOS5W*:Z
M__LH3;4]KYY5`5C@4KO2I'ZWG,R3^-L?X#821H3/O)1`?"_M`%!)LZ*-#JU;
M$CR:*SQ/SKC1G<#E.4R$)6CE"[]:#>Q([#_#,2].TSBG[SY1<N`T"4)KCU#/
MML5'3=!44RD#%^`^.^_-)\C,R]1#\T!;,KK$EF+S50:+JX5OW'W"G6:\[4%N
M8"+^0O(VIJ!R'EU6^V/%69LJ>&PW2[P9Y8B]`?F1&AGOU9;L@\%93>N<*Y-M
M>;3'EN$2`,%%MAH#RG&"3M8<8Y2@O/4,K4\\T,@@DM]+2:1FC%=0LX/+3.N1
M+(22I:[4O[9*PTC(*VM$_&4)S1%HT]502,,0]EX>A9;R$34-IU&Q,6[2/_#T
M,;QNA@9LNE,2MA`!U#HMB^S@@.W[WA24^*H*O"?T4NEBV\#&<":Y3!CQ5G<`
M)C1=FXS<-J>N'+>FIEV[KC:>)F6<ZM4]9N_L&U"/HGP/57NCS\/7>&H_+]EF
M3QH'#2U'^LP0V&D[WSTA;@UF"SD8L'<&27ID_>#[&>H6%=DIKBCU4,'\0+3X
M%>1JTM]HIX]+$0UW5UKXTQM-7OY6+QX^?]\(DZ<0,ANWW1J:N[S0A/FZ!_L&
MTQWULOS,M8_3H$U44Y&`;WM;^Z.K^9&&Y+8OKJWM8[>S%+XX<(?17YG<MG`5
MAS#.21NC8VF8>L]J0$V@5`7<*.\,_T(#)(MC.K:[;8/YKM0U)<R:FS)=OG:X
M5AC9?S`/4X*_VN)=5N:[7`U.+79[&_+&UUK*P?+7'L1QM'-D`D"D]&*H"<UA
M+X<P@+]0J3X(XG):0?"D8)Q\ZV5:4+=R+R$*+_3_J-2P=0+-X2S0\P4Q0LKE
M2#9(;^RIC3]$6%RX1GZIHXXL4(=%N3RQD[&Z.$1N%X70J;5HE'_6"J816+Q^
MRS$Q#[4=<)L=[,2XJFA/5?QC&H>>CX2]FJ1)A)5N_5XK-;E+)ZVSQ^FFZQ_&
M4^(/2[S^\<RB%DC2VKO.7WCW[^$G37Q5R)+7%G1?GGT=[1WQS/B@1"OG..&_
MBT42/QMX7@Q(*DY@-/AS(J6!PG1];>P^0=CAW2_3!-CU**DG4@6\*#D,%S<M
MU,F'TRP/=_QZE0PX*`(SRU?50@3:BF=O:M.5ERW3V0L;4Q`=O]0(6F)3JKR0
M"*OV6+7"LY<3IV8-;;3'JI\[O7&,1"Y97**6@DF%WS%*SFV*G$;!Y4ZI05Q]
M%@OO==XM[=]G]OIQN$+1'N0*%75U_E7YE^WT_)W1?_5$B@'TE)\)2Q^82'P$
MPX[66B:*IY>9<12B14'F%)&$)'1QT%N\="V4,S$D6/84?^^)#$7Z<A\^2ISX
MB0SP*P+OP,D:Y0603WHH).G[4X(W$:X25Z.9I>G.(&/2`;J$EDT2BC191IUA
MAYN<@M+`4"4R"B`N(\T/M"_J25ZA*P7K4-:E1GIY_&H-JVSQ<W0UCV==PP`5
MF)G0$20:\;W=$TZ+96#QPT0GXI&[^W(C)'<*(IN%;(,ZF9-!AVJ+$$)'\$&7
MDOT9[*T3_O#TW7GB%%U'=6EWH.67MWC7<NT`R'_>AV=1?N18B$N9B:VH"`6/
MY)_L)Q#6WBK!VL9#<@]ZB-OK+BK@Q^@EAE8""`AZEC]A4])/HFFA@0#]=KS,
MP8:*B1/.TC4-6C,?N<P:=!P\*_R^6LHH(%Y%I'8,+,3(Q#E?X-07X6I[QR<,
M;LE)LR`L[C<<M[F\HA#3\8.?`OYM`-_PB&SX6MBZB>US3.UR;&ZZ6'4YG(@6
MG)%OZKA2+V!G6@T3+_H(<&^XG!\^G-G+Y$=;6'8E(2T<YIC*@+T1^XRHT;]K
M(4,=W*)C>PU(*QX"%H(LKXO3YED40\K,V"H@J!K;_:2^89;/_>L&:UTHN!-1
M5[\]G*.R^37JZ];/?-FTV@2^6,V2YRL)"$/K<3C6QS^4PG^)U9&:."JR,P8?
M8T:.5RL*$+Z8:O:0@D`?%ZH0-$FNI236RWNG^].TLPSUY;+=37D641J]I80O
MAVG&8]A[0IH2]K,^Z$[(300&`.,'0;I@D!HR@SMLOAUCJDB^<ZE$'*QMW=T5
M:FOGH6UK*S=$I%\L"L=E8:Q#L&S<*4T[L;9(+*<1(.4K%FG2*EH7RT-$WYF'
MQYOT!__0CU!3MBW,FF*WN<FA&:"*'RTQI/7G0V%<R][*[E;C$8V>Y5JDK7MS
MT!H)7&?7[5].C"=5,QNPW\36>`6DX5<]A`_:[B:383B8$F8*TGK5YVOJ8GG8
MZZ@2X,)H#Q]"2(0%^,R2^;@&%#ERZ7BH?NI]&X#3JYQ?ET%"AO7/`OBE:.SC
MM+YANAVT0X?\'[+G44Q/Z-=N_I!+)C7EYA>/<CJTS+LIXVDS?Z94A=BR$,K,
MU$6MEZ%X]O:$Y7Z]HI*`Q*H<>-P%-T\29):(`Y#&"7OB`5&DIV<2%=D+[7P,
MGTU(D(H/?H")H[KTMG@J^*#R"AM&0G^D5WM5<)C56L5B0!3#(VBJLX\6I9A<
MG,13!*E`J16(+XI-XV%2.0"TTL?%-R`[L21"L8Y`J4.(%_K/OPLZ0_X@;2:I
MRX1@_9]^YWHHEHH6=V,3*2I&&1;.L9",JX?NID&S\_IOPC?%1G!/\\*-9-EX
M+40&5+@J<@3"^NA3BPY%__$*/VOA2$<GP9JCHF]C::I++W3\)4<*WER3XC,(
MK)@B4U7(,7`;1%2P.$?`N`V`Y_4\7PQ`!-N2^4"%;11O'JF@E)_YVDS4P9ZS
M>$XNU"L4@^!`.U<?L[[UBEI/+@8__ZLT25]YA`C9]O*4;84EZ@\ET.:9,2`S
MZ`E]!-CW8QT6L)NPFE?A<HT-JN/1RQ*8<H(9&XG';WPP,%6NW#O_09+NE1++
M<ED,0A;+]XI37(M`$B9R('-:>)7:;S6X.4C!$.FL&"#$15K$-YY_F/P>BD_!
M`L&>1;Y:HJB+;Y)8'%OX2^:W9WT,8M;[7ZG#!)I-Z291ISYJK>L4'X@&T(*Z
MFOPJ"0K6>B*KEC%>S#RGD[K%:`K+U=%%J>BSN[>5^&&<<]R?DU8++(Y:/]TA
MO?0T"="7((>XW#%,-<`+[EQ[)P?V&U=9Y-75-OB`TI8M']`F)9]^YVWGA<YK
MY\$\>LSJV9]EF-O+R`C^@S$SA/WC*%T7U6N8WDZ!MHN1E_.>@'Y#(N5)"$8$
M*VPB&%M5&^2!\>GZNA$K.N\)$(3E.<D1]QGB\^R&V-9>7E\GMNUJ-REH:]D`
MIN[]<`M)!M8&";9JP6H?'#J&Q`UI:W_`23L:`*5M(7T2V<;T%%!BF_X18`8D
M-(=R`2M$7,1W,3">^KR$[(PUP1J<1]DIGTH.^@W?C.V47!SA6&_BIT"IY)F]
M%/Z.J^H(/;@,&5^<4"&7;Y'R3D=B2?+/%L_<F47$@)`^IC0.\E=[""VZ8'_:
MY*];L7D-F!ASKCLV;1.64ZDSU]1@K//(4O@L[%*N`7X@K'BL2Z]F7?9^?_+N
MLZ*TBAL^HK!M-YE5S$^6IO(1![:%,X)&3/)C$'>X+>&#4FY<37DBM"?8>+)2
M##7,.HKSE>5T(;;0_?PQK]-PLURB+"]*8N\G@:?^*V;Q:SFM)Z_+TC_V;#JE
M`N7MOLL?BJ.:83=:#_%&]DE4:1#__EOZ]N1318Y><)>"<W6?BIY'&)E#IA5O
M%&-#V;QXD&&$7++#<K^=IGWV'^]X$#5844=5HCS4#2#B+6,#MFNX)UY1JE;;
M[#X-RD)`1T!!%\/OOD-?BQO3H'D51LV*,;U+H$C1R.ET.R%G=$RKU4>65(60
M[JY94LL88=BQO<`-P42XO@X=W6QSL;^32]SH?6A==%81^5N2JQ:9,XUT76I-
MWN%5>+Y@+FAYEVK(PL!==E'%=)]N\U1D2+6LP$0`91JK^>V7$^\20\N"`T/H
M*=>8KO/Y`/SYO$>'E+$XCM7VL<"FD)\.+3T0,I3N-6QF+V"_6C+!#7D*_ST\
M%"Z.57]F?,(_[/D;ZB8?J0<2<(=E*%J.5@W(#%`$>NTKEU'KCSXEJ>+[@">8
M/H<JK$G)&L2O<X5%90[JND@.?^EH^#ZZN!F+U,`^B/@(>/;B^R1$B6:I$H=J
MC2O=F:K5=12`L<[)K2HTNC0B/UP;PIX=$M%!WYZ0-B^XZ+PMAJ<-MQ6/M?,M
MM#$L0.174=VPDNI7N+.6K"EZ,_.IP,@:?N4-P9/0>E$A+8(RT&>;FB.,W:B.
MX*1V$3O7+ZF:_]KY(:L"3'R#\_`!A.)D4.88H*3@A=+0GL&>-IRR4@-6.>&L
M9O2%#=/,=IWKDY:`Y#*E0@@V:-4;$OP^,[Q(GJ@D/&'_L!)3UM<<DX11&"B"
MO^85L58=*PB"P)3;21=,<IN[\D<BP58?U,_Y#F%R"96_.,>K)L+E?>":/L3#
MJTFJSFS5G&"V6<_0N(Y2R.$CI_3,ZC9C5HQ[`8P3#1F:ST/O0Z'+B2-"7CFE
M&=91?2'7UYSEJWO.M\#?7G^2*YX$2#J9VOT?;P(1]1M?B"Y\B+X`6!RG8A)-
MGHED:B<;K.RQ`13CW;0G"T8X.MF:B`70B*XT\U*42>V;HPA'&R6QU79=<AI"
M;V&4%2JQ0.$&AG02F;IT6F%.H#05X)E];U,\CX0`$G=<'S0-NESX]C)K;H58
M&\3E;#KN^,%-:-=ZI\SW(>7M';[>JVM1X/-TH]+T$IR,`@IS,H0P3I@$O5D<
M/PK:#*XU,FF=:`<S8%GQ0"-@1:\Z`LL!]GKK95)SL(3'N;H@__&)OQV0P9&"
M(LKFB@7<1LOSA%+Q/LEM*9(@&B7P'/`DT/MZI`ZAA1\,F5/<T*OIT4_W+`>>
M^!OL\N_(]+O:3WG%@CDA&6S)9@4^8`UMVNWJ=_!7>)(9":UX^./6"I#*[Z2M
MPZ*G@.^!QA&;07AV3QV&0@@FHY84GNL(#$EPR:WWG!=+M#BI6^-%J2R711#C
M;:]2-D#K,GY#QO6NS@,_437LC"OEF7A6ZHC#0#)"0C<<>>W9S-`L-;+>G8QO
M4E,5K2,KDJG8,D/-(2B6K1E9LQ<>6OC-;>X,&TOYM90'B2V#=_%YRZ!&1%_&
MYUN7EH&[K\(Y%@AN"K2MV<,=,90&P_;HOB,=\#I-PR10O2UZ876KLL3ZK$M/
M)$NXG1ZC<@O>_WF&W5SEVA"7.;:>Z1=CME$.+8_RO+%,Y&9G"Z%U@5Z'IG4"
M:Q7)_/V-RM<;^@Y:XFX"&\_I(!B78GIJ'!N_A[\>@B=T.%$I$DXUJ*PC+:HC
M<!H-0SF^KY2$U3&X'!'@L`"/9?VAWF9+,)7'<M=N!V?^'L/>(&B>54K=Z:;9
MP`*7>1=NZH;UK>NL/L1YSU=4C6M%/JNHX#,R!BV%#]2U72R?S<Q?5ZUV)8BE
M?I8L7=%RW024[!HU)2-O!&'MCC!KTJN[-\`B=:,MC&D\(KA_(XI9Z;WN%$4H
M+!#P2S\PQ\X@#BYEQ(B`7,46/I(N[R6;RB>[&@_"ID3*3^-QX.)+<I!E41KK
M0FC<2G'TKW736HI_[4E?)%$R[02Y+C=.\[2YQBK0*"C#OWOM=#^IS2):BXX!
MYIT@R.._.OG;R`-2@)P8F@+[0E@8J392GMFLO1,`'UJ"]#KG"NAJ]2+F[@,3
M.<GF8O^&Y4O7&<U;M7ZM=%]7EZ(^A7>#DIBKBYW00$CFX2:PD1RA[\A`0+M5
M[L.FJ\ZCA(446VGNJZW0-+EUN1<;U6A-1S2F6]<$#*8YS<P/[+('NQ3"4'(,
M1LD+,8=:$#XLW,2JZZGB&F]%!C18337):XDV;IG*E,-5?0SG?\%:1GF5O9N6
MMG%5O'+$V(KU*0+0)QDB6T$-+C(0]XM$)[C6ERN&]NR"O\\0J.82HRQ8Z/ON
MK&T/%+Y;<JS2&!Q^5E=*AVRP/6IHH9RT]Q(?@9:2./AXL!QW_7[:.QQPCX'=
MS7>FB16R_YRI:?#T?C_-C(#/$;R7-0)3:Z`<B%%X/9A>[=%']E`'GT]&ZWF7
MO5',R@X*C@KQ6E?NM1T#,&I^/=<F#]2Y`L((R]8"N<;Y-A"IZ?K!"H!K5N@?
M3MK_5-R(^'GHGAX1J,I@P$M*6_/7ABB7#Z?$ZR<&+[ASBT^C1EH[^GC"`M*9
M]4]I(>3?FP"U(%!(^E=>>TY8%^>BYW.$*G+"YR1-FJC!RKY4X%=F;K=\[)[>
MR@1I*58D93[\44%$6BI4(!1:W1&+9.K\F:@L!&P#S@!5-I7WYH-_+C-73@">
M>AG\R!(:)#8B&+/)^H]5C^.EXT9D4\G8W$@?5@TL")<5!?4#UJ/:,%9VZGM^
M63^1*8^VN,52D2K:"+6'!*.Y\H6%CSMZMC,0Y!(.V!CJ[H?;\[1T6F:A;?[[
MCEJ-2TB,_V<]C:9%1MF+4KK+*A]B--[(QM*IES'9>@H$/!$+.6#.W'D?XKII
M6G3=1"TW5ZI77`O9A7@V9-^M!WK!7&6U9=^+.#ZI:;5_U\Y:.<9D1A/>7?K+
M5PHE7<RL@ANBG;NHOM":N*&(38YR/SRCN+0F1LN77PJ^+\P<<O!7L"^<MSAF
M&'9M,48T?IZT+P=L7K)-#JG!/B(G!0WNIG7UNH@*](BML/V&E1HGID9JM,"Z
M3+C6#+LI8&:'31;95;25[9Z307WWUJ>9''`E0SE.Z]#'P'!L=ZFZ7J<*8/84
M_X5A%=MHEFF-FG+'`6MRH=ZB8:<<]_$1/.K)]WU+B9<5B.!C7A+S"8.'Z<#$
M$*'E1_-`[]]&;"R0A<72J5=`$.)O[<`*D=E(B^/2-Y#X@_&;RS*8/ZD4==]K
M:=Q:IUO/\_M:\_>+O>&I4A;-11@7^F.N87(G<S*N6S)[GQ0L;S#(Q7_07W/_
M$Z7KK3C[\AI^]["J"\6O'@4#1(BG%"><M<[&_ZG?.BQV&WTC=-<K\SE44OKG
M42`PQ15W#)[1UI&[A;&RXM*+0#;Q&[&;L`H311AVH#X>$DV>X[.NT\=T$]S+
M)C6TI']7!`=1):]]3E5Z"(MLE65ID[&;>!=G304)SL^_CW4[A5!7=^^W[TF!
MKOPU?ZWRR<:C<X*E:E-75''5,O7(IO[\^PDGEUHTFQX[6"F#0),#9K[W'6S=
MXZGW+"#M(_Q;%3ADAY7//-W<&;\K*I;<5-4).`<J.'OGT?6\&).IO:K6KL<J
MZ>5)]04=*GD!ROG[8]NV:<:DK&Z2*.Y&OYDTA9LLSCS,6P3-,;**1F(0N9(E
MLO6]AD:J]JP1EM)_GVDSP&D9H<$,`#.ZIQ]]?G>)+P'V"W<Y):"26(LGO>(3
MIOY\<?AO'X`1?<WI_);#1B1%,HX7/5=%Y?9A,',UB=0OT2'&J)!D!:77_7>A
M(.-)[XX'>S`31KZ[FJ+'H%=VY:&5K?G_T"#GA6PJ>T\2P[RWI-8:@IES&62^
M>L3X$CB?1AANFV.>8J6%G6L7@F=:0?8%(,\N5Q'`)&VSWCV5N7\6-:PWY'\,
M@[>GGF&,='V+YPB\6(##5E-1'>M#Q33GRK=G<]]04H3A5M:`YK^-MQM^#@Y'
MHTVVA;^@>S1%OK?&OZFOM,(!@2JY$,3:I4`OJY"]ZIXV.#EJF)F5_W:5?LRH
M9Y>#B40#2[S_1G;#R1J(*N'GEI^R*_,B:_JS%]J(1:I\>Z:G?%?OJK.ZG?DT
MAZ/W$YCH)",39^E\X&P,CJX6'/JV,FSVR`;$!*6]3F'NF+`0``4CH;?3`KT$
M5CU6<M"!+B!_#,-%(0"T:KN:/-@D^5P?QGJ?>!6-DE2"Q!+%\:=!J'HG8%Y9
MRBI_HK13%UE/!<$L6U-*T!0-3@D0''VDQR(2-=ISKSR)Q$'[1(64%$#[KW>;
MZ,E6%I8!VC>%N;(2AV=#ZFB=)'IDS;&&T"P'F'>R0%3`[_:,::O5BU,CSDK[
M`P-T0;-MC#-.HW).`WB\KK6QJJ-M::58V!ZE6%U^`)O.(/6SHVT.O(NGB*IW
M9>;:8<X,4Z`@MRCUI#(Z4D"(WPQ-ZJ(19$'":G.5'7"7:(M?62F@*#]X+&B8
M1-PARP=0U4CILS"#ZXPCOUC%G"NXP-B%<OPUEBR]1Z4$[^[WR1J\OPW<'?H$
MP$#1)[YK>A^?6C(!W5@89H&@_%QUB)WEBYD:.OZ#;F<KC(=BLD`,2(;M)<&K
M?*EA,CF8EQ$Z*Y.:]QGN&$`!O-0>5DH,.&]96JBT>-'#PX_"*T1T32**1HUU
MDXR?)A%A!2JL.=W^9YPR4>]6#=F>8U!:9M5:X.Q,JBE@:7@QSI^3"?IZL2N#
M50S@TTKAHRPX:`TJ2^Q<[/G/T)?4OOMPBNI*BM7U/>\A1F]-I5@4C7:3H@HT
M+W3Y0*7!"P$$&]EA9O8\/W!H<"!E8VAO)SP_)SL_/L2AT)ED=CHZUKOBB<)J
M<XQ#7Z;-E'64]\+2=OM$%G/O-BB>!2U;PIU65QMOSQOM/[A;TUCEWV#9]Z<?
M[\+%TUMZKW]&';SO43_SXR%V21RE%`JN>/9ON+:'"@NZ,8("M51ND8D/+[F2
M5'P-X`P?.[)G&I]UJ"CJCM5EZ-`@%](W'A@<U:?.FJ'.O<,N'E=QV38XFDIR
M<L5#KRBSWQ@[$E]=P+>R(_ASG@IVM6Q'OY3>UU[-8[N+'_=#RYL"Z!:>1F$)
MDP;!EBY<`[H&3B7)90+9W5%RG?7C(%P.;A<W='A5HCI^[C%[;0>S!F01.$DQ
MK`$;7)#:1#%0(U]5W>+E]$C12;KBMDMOFU$V^WT^Y;M,(?8B[&'/\8"L5QFZ
MD6$0G3<4^+_5$,GD2YH=4']V0&T;?X\A=9>ZUC-F1OU:KIM/G>0#(`5S<`4;
M-F"T>]>>B\DZJ2`)/.(Y]M7HG%_XZJQ^R3_7W";5\R[)VFLS=7RR'1Q"3>J9
M@OQT(7Q/3^#?=*QV[V`&LDUZ3HCTXA$U'0M0&ZFUM`OU!<WWA43Z:*LG@FEG
M]R"5!.[8:PVF(I''HH<"09VDJT0@1_)9!C?@7"J0ZY/2ZH4<C(MV[\%QW;EI
MI^R]S>--7B:-_.1$33_S2*\]BTB7&KM/0>O3[G8S`L*%Z[N#H*JB1;4H!:=_
M718@?C+/P0&BUO6?HT19A7<W1H/X['K+L4@R*4Q0?I08?4&""X+"/ZG2G3=2
M:@]>!F)=YX<?MHQYRK*&&X,C@OM&E!\6O@^SZ''4'=V27NB\8A;]C!?[K%ED
M:W\<68RF%Z#(]APFYL.+/8O:C<YY2[ENB<=G$Y(@J3T\[2%C-6O/!;'/#]0Y
MH54SJAGDB5P)(`0LKY9L5/ZX9<_]/&@26H>6&LN+K!-)#E8N+@2E>]]:.7)1
MDC<EN34:U<',F'=36*;G+.)R\8//YY72^*FO?^]?1AK<8A6OHM8ICHI+_GOV
M[(<SH@I7"RJ0^#KO^WLQB#@\>AQ*VQW9O$6]YUE-"N^EK/V(9,YMF!LYMT")
MRR3IT^>UTWT%$UP!Q)&MI+HIQ6]GB\-43UC!ZTL$KP4/T!VH/-Z^0_T1$,;T
M6*9\L!L&H=*ENLJ)ZOLC"^3H78BN<TLT$IQLJ"`83+?XNF5HH7^P"+_2I2KG
M6%L(#RES57@/_N>*!/VV=HV/`_][T/@=`)#Z`L62))J&'60E.8-YM6U9^?A-
MK$A\9];,#VO<F$&^`AW;T<UL\ST6F7XYD@D0/XC8E`;T#`NV/(`-Y(8)(H5M
M`"D6$"*^@":U!7&\$OG]8DYY_MZM<ZE?^?AN$G=?.*OO,LD8CR!6XOGY-\=!
MSWU<\\#!PF$YI2>^H\BHP0I)XGXT0+(P7?6NNQ)/DV7FOX!Z/BD`T8T_CP"A
MQ_T4-LABZ?;PL+T]!E_R762H/S59C-<._8#O,=Y#A->X;UDSWNQD^>\"FJ+O
MRGLS@TLU=0.&2@\O.:BKH=&H^/.'^*/^X<,UBK$."8GL\_VO$]2E%G5C,X#X
M8E0?[+I62@N8=FW<RAZ_.`'S+2<.Y6&6CM>!]!CD=7N/.EZ%`"6&G5F[>S7A
MR23/%[$XC!D89/HG0`(]4([1#V'#CA(WT7%"?W-JF@BQJ:66\`E-HNA&'XD]
M[HO4!+(/&W^\JB$!%AYXV#6]S$:-*`D4.:,4#FS9W(!4B7/S?9=*-YK4KB^Y
MV_'_3PR`=8]+R^.=+^96#4!?Z,/Q:DM;D/Y#<..(3+8S&S2P:(LZH\(#66?R
MH`]OMA)&BKRFKY?48.!=08O8=T9-.AJ!Y3UNKH44/2G&M;?K77BFP!,U:BS'
M\(:]V]>7M<$*4LE1@K+$E?G>270:-X0'%&`F3)JK(2+53#D7IB2;$MJ(FF@]
MB3A7Y6X6/T6PL(QMEI44N77LY;0`?9UF&JQ=2BF]1X#\PIU=5XE(V0'D$1)O
M1(E0=&2N$6Y:G66C8TM&^)K/)G$TL]7TOTE:R."<C]D:.C0,`KX"BL8VFZG%
M5[X^(X>U":17S%M\KQO$'8>V/RV4I`?X8,3:X=W2H43RF"PFM@$9%8^+#A^N
M.\OM_I=[QZR__ZI@"H;A/3S9L(`691&,(':(LZO2:7+]>%NFE%(YF>WDTQ,6
M5SF*BQQA.\K[-A$7O[[P2MGKW)MS=:2;8J2&M45BP'^J!2*;J&1,O"K?AV$%
M^X.\5[7=I]O.RWA+/9C?BM)U%/_8Y:R/)'MA0`2?0CE)&G$"KD.H29`5TD._
M-X6?KC/\S6BP?84*U\X665]^NC]NBO>T$=?("^EI.-Q0U/"2!!2FCNKI?7*X
MC="KCR\1J)F9'<(_\N#V.7DMG&.S'!KIM6H)X:1F$XS)7L8+9L="D3I-JVZF
M"&>7(,&UI'V`X=WDY"C[BW9[TMC$DJJ\X?7#PZY0B/I0SV&=00,=A-:R1:^9
MMA](XUO3S*,>?4HPI$R<(D[8F/'APZ]\7KCF&E57#$0,8;MQ&@$9H+JRT9[)
M/*@^#&J#3N,B;72L+`M/A.J^'JAYG&X$1W%`I-81,J#BP:$R/D3X+^@H+R$<
M,O?5%C236I3;;*=9!?0SG[<QK:`06$;#<NL,,:[#R6%EL]\M%HVABV_C,;A<
MA5#C2N\K:0FV@-+XY`174%78IUS71$NAV3?NU%-&X+$=+1!]C[PL\T(DD,&$
M@N2^UX4`_,7"0JH53\8ORQ,>`L53`VHA\']<'19?CM<?W&2<#%=F1KI-<5!=
M\K!C[P^BQ5,2D?<LI96G1`BD2DB3*HNW)/>5@"3JFH:,-,5Y=VNJ$V$DNSJ?
MRPGD3AI,)8S,1@711[N26<*YR_K6Z,4Q"F0DHP!V^F4J`M`<D9C98-*^?U,V
ML1\ZILHQR#?I])K*65V%I*G0]>I@0H5&UXPT;M2?\F/;Q9!KJG[.X[VG10L=
MFI=@K_CRY1!`F/F795?1'*1,*B5^[&7;0,J:Y&.5VX[A$LDT]_@0:[9_,"!7
M&WWT^AO).(;-A,1&%%_+Q&DWA>37?@!N2B-GN%;,@Y56_L['?;+8Z!==!:)5
M+1]]<37/`:BUG`?IB&_QV[0Z"'^<L`X[)#8QM]CNHL_M]Z)^@>56:\,WOCX4
M/&HKL"*8-Q]MD)&P5D%8*?,D8ACY_[((14_83A8RP2KZ\F9M.9KLN=R^*D=,
M9QC1E8LZ#]*R@BF%2?Z%^I8GUU4G==A*6H3<C-LG9NWVBV]JWL(!E-#5YR&_
M9@-$+Q_P95HHOW@0?>$!Q'8E\F0Q_B'@6%K&RB%?:O9(X9,+<QQ'2%`(-<N4
MQ4U/&_R2H(S>32%D!T14?A.;2W?G)]-0)??D8@KY2ON7@L"[Q+#_K%+"'759
M46K%Z0N%?DH`;5U*R<+S)DID>Y'FYUJD'*U!>#:P42`);ZD!43)2Z\2JMVD^
M;[="`*B5]UI=KULH<T[!I#O;I!?B"!\R*(6;YTIA:X]3(1+6[DT'AO[?>^!O
M36W>,YF/^$.^PG75SV%R",)/\SN@SL.KHH%"Y38`L^<%`8%D&.#$3F:AIU;]
M6GW@44\?QI[_7<<+94_@E$UR>,".<WD0[1UIKZQK=B.09UKQX^M?,[TR$],@
ME^W:LU?1X)L40E2=^_@B&Q\Q;]Z!(`3+G["LS[=V\7;/5$Y5,*/$G/"(#W+I
M.8">P5IRF[VWJ0_KD0!`.>2I,TMWC#R$61(^,$<I4NX.8_:7B3CO8AJA\_YR
M@'M^H4[7_L017#@S%"E`+.?[,UL2(8%F5=<,L#ZW+?5-MF"G])P5T<RWF,^L
MX]*/P<E5#%CF7KP@A9</?01#^&).>5++'F/HI6(#;?FB7%5*4RLLW$+Q3UI,
M?GV!<I3@V?H$3U0&$W1863I0R8<M?-[+7%=\))NS,I]C0)`14-<K<X[XZ-4N
M#()G6;(P4])_C(E.9>JG_?+VM4'9>!T]%YTE!//<TF]?.*NGG;S5<A,P\7H]
M2D]A^>VBM06S7=)</9=3GP:MN>D&H#VT>?([10+C8_-H('-7Z#.0^\L&\5WF
M)@,%/)+"Y>A;NPH6S]N$O^ICD1MC=Z).#*K4;"LYS=^^<^%+JGT2J#<9@>@I
MU'Y\UP'P&,$ZWS?-A?+X&Y?ATVO@:'JY#]I]5SI?'.26V'%*?U5DU#1`]S4A
MCQ!1L]@JZ]^07Q2?*R`UDC%E:?M-WCCC/\0L!$%'>EU=@PQO-/JN=?TMD/.L
M?4F)N-=+P*Q89S"><[I.'-FCATW;N>$DQH7BMNJTE^!S"8>V&#?X`OQ3NO"8
MJNK&=?>\11FS4B7FKJQ>NG];4&G8\/ZJUT2[780*F6@Y%Y>^O_O0HEPCJ_\4
M79X0+SE<?6>I`U@M]\5GYV+WK/U,+9D:B$PI1[@EF!\,@+(0B9O<S\86=9^^
MWPAH?A*!=S[M!<5AZ>>>]G$)5H1R^>O))LAZS:D6YAM&Y2^V[`;(5OG_RHJ+
M%>WW7Z-Y+P=5,/!'SLF9+BD)4%7;>H.4$O6M]0=1S4@O_442\C-=%BWQ4&/1
M9X2=H!)-M*&92!J">Z2DL,/=I@S=4,O\C!\LM`AC1[W<`!%DXV2@/D6\/`6P
M'F.],B+S7HR$;3=T[/NF%N]]I>M[)$D73QP2BU*UNE9:6:&=2UP@JT]MQ!]`
MXT'@\IP!$4#<QJT#I;R5CJ[)8;N[YM5"SL:$O\@6&71KO_5IIDS$]\^MI2P"
M8"C3H>"T&R*V"2Y2)0`\*BS_Z(P]$`YW.^:L#)\D&!"1`MT-J78&45>TM=Q/
M@3#8WI_S7#;+,QFP<$!>2RM857'CU23?DI,*;Z4],G4`UM9EA8\,HYS;*]^0
MLYU?%CWME6<0LS?*<ZS1\J[L.RGKRHQ`\HWF!;+.\<^JI&25D<DA[77W27DG
M[3^>H;A#F<.B+(N\4X=,FF=C(W'468SLJ(I_#4MN-/'&:^T_]L=(@@D#D_59
M)"(S"^M"FR2LU\<FZ>M_4/LD"&:YBU?I@)5D+`.!YC&@6'G.!K"-*K+`H7<I
M=O<L>RP<L+GT:G'180.7>;@G3S<.YR."UZE'%42DAQPA;VVRL-?,/X*Q*/1F
M<%K^K*Z+V[U)%K%"1PC).KS"J)?&V3D=@^ID;%AJY1[1H64I@/1B+<#)V<D\
ML%,^;@0VS;+OF8UM@WT/@Y4.*JVM:,'#8`80H))>+:6@?<BA@-K81+J.E'0E
M]$S31Y6Z[V!B2B9KK75D]M.JJ,MM@,DR1>/UDI;0`I&QQ.-ZHA0V2BV9X6G%
MOP:SQI##?C7+,(Z+IP.8I+.#3(M#4P-VB@EGGYVE5(2_EH<]M3C&FFY)]#BI
M%^?+6"3<E-%3,/6.E0CZ97JH?A)[^N&M!;"A]@IMD&S<"T4%QH/IJ['+&#9P
MJ$6*(4]R**A$(^%5V#T?E!TK5H$'7&3B%M_\&'"YHK#A@9UY#@I"2!F1VI#J
M\*G^]6VH`^VJDON8Q[:Q>EZ/*(8N8I*R"6-("UL?MU1/F,SB.C+6'7]:W-G]
M)`M_7;Y>7NQ\8,JPT,Q>.ECT>50<!>XT''\9=Y;^01DL>RIF;+J02X(02K(I
M2,NVK.?E^>8.P0#V>6Q]1:U4]\$$<F:+W,#=HP^&];YEU9K?%JFC/!.5WX-7
MC5IHH`_GUKT`C=Z-??'CUI9.[%D/AH)$SI5IOK;`V16TMJ8;6/V_L<4UZ39+
M]^UWI@]U]=KEIT0*TB-T!]_LU+*'T0`'M25'KL\U3.D@3['O6[E2ULYMOT.K
M#X(@).OH=(RF&E4I9LE2F32/="UH:+"`F.4&^W_[99>'5KLWPW)O)UPBUJ#_
M06C_=L2*U[3@-0:U*%+5[\S/NK;L[L@I.J+,8>0Y_^=(LN;<,,B+)]J2L:R+
M5$A1*?U`1RMOR,V`HFTC$2NJYT9M`+%D8O##W0"]Z^/-TP'$+='M6"2RF<!#
ML+SIE@Z7(3[+*;TM[8R@Z5A[-(7_;;Y20E@@1BID)?>88_D^_@H1^1,>.HJ;
M>[1.5Q\R&TBZJF02LGPR_"5(-8!ZR&"?KLQ-.(C>M.3ISZL$S$8?&\LR*2\&
M7YC-^^5.I:%\QGY.0;U,M<O5EIY/21F%L]/6"HLI9J:H[!>F=33F"WIN+NI0
M/>X<;#X,NYC'J[!O*)^S,>]$C(WUV)Y#-3;X]RF0ER.P">XVZ^#YO<#G(4QV
MHB]1`F;#7FEK5MB*141TL6PJXG!X0.MTZ[V<B!WARV=M4L\\S'DG186I**,I
M!K+"&_(C#G]8/XA09M=BPJ9-+_?Q0QDF,),64K;5)?VY;K)TUTH'`B+:ZUXO
M3KXBK%+*2NM6:OPZ.T'(LDB+TOQGS0K_B0_'$5QH91?3AR1T6WI4/(27$[)I
MNZ@2110WXFX<[\(_/1!ZK@I3.#'[[Z^+208&JP7SHEJ[.)O=D8XC(I1L9%3G
M21%K?6?-,.)?0]*_DFQHQ9(@G:G(HP-]09K@T&Z&+CQJ!]?,S;SLA?,A:H++
MG!7:^M(71FGL-4!2C%I<Q-A.GUED24E0@,L'?\W^*R3\53GAXL/2@9DLPO+,
M9X<(ZO-!0<QO#P)WHL>TDXTY,A[W3EMV.&#H8:R3'-TP,M[L12E-'(;]G"[<
MD$+QF?DE:.P4RGPGB';LIG(X,^/M#PRFI.@+S):7"EMPMQ[91F]&DPX5!!Q"
M&16\]8(90QEU6HVJBX#M9<6.K!N*,?%I>\!]$Q8MND!,OI(%\W3W2DM1%\.K
MT<C@@_;*9>5&X+S/YHLB.:E16C+G?^1?.,_(.6F0Z\T9!?15[U[,O:4K#(I.
MSG\8'3;0L?*!H7!?1`<"E*J=C&<W6*BCE,.*IDX2QA>,92G1#A_,Z!F[L,F#
M]/3(D%*2;.AFM0=@-KI([\':$&PQ&VJ=O&UZ_991R).,?EMWU^OGR/=`96!/
M53$&?@:5V@V!K8F(*[+95:MC<X'`MWI@F6+12FW)]2R&93:Z/-</40KT_>W8
M>QO95?1+>'?TQ+65C=7$*TH98X`6N`=76E#.`'MD%/(`O&5A\.+9<YT>[4R!
MQY?/5PB/>69C^O>0M`7G*U;:"F'2,=!+E@0,O#RSQ:,'L6QJ8E/@[O?%Y-H4
M^%*QJ%]DA^")^59Q,+?$]BA.AWCGO-[]$RWU?U7?'8YWS!;IB']R<AR#<`,+
MY"B]L%`;0\813K!5V\;_:!Y3,+D!.X!1@AF`LLGA3YR'9//]8K4G5R]OA`Y&
M=R!/O^R6;K'H]T0-%$E^,=*'VU<#E2.A+P\ZX)$:J;D&*&3!5O,J<2\\^J,#
MT;5\W'()TGOG7>6N#=M#/?H0]8O]H=:IQND9O`VN7`OE@+OVTT#[K.-;`Z"]
MM)&O\)U:F>L8$?F)QJ6Y#GT!&#K0L9B*O?.DW!F]-O@O3JWXS_9M=)$V4X0!
M2*W.&KS%;:U(5Y&T4**C0:Q88E%#^X8O^;3.1M01"S0NS<1(4_^(8TE^46[Z
MORDSGHLM;>;NTARL9^4[4D+84:*8<E,15>`QT>NS?%;%4V;WFVMPX#"GEH^_
M%%0"/F@5Y)&Z6JK[ZB<(J!H%D46BUGS.@^*X\<@+,&C#1/D,D*6^:8:I0/W8
M8.)5$Z*2__/UD23_V<KF%C4M@,)F56#8`^NO]_2<+@0,0LP+UVI,P0;IF<Y5
MWZ`X:H3]EA''$:/'_W_#K*10X"]-TNKT25@9H6\3"C:Y$=$1EW=9VNEX<<Y0
M4J?3I4WG5L\%,A>+3(NCDF4?4]]=8U-6[V@1U]/L9F:'G$57)*!6WNZ^$N#H
M[;+;IL8^NRS"?PZK..%U_2!I'FFUL/"NHP\5HWIQ>WJ%E\$X>YGX_,J9C^SI
M9./IG$H`1%-60,Y!R"&6(PUY-+XAU[]KF]FA:#SLB*C.;.1,$/'J3:]MG?V[
MU5Z!Q+J<^;`["R\?"[+QQ%::H#[6R>\*AY'N(9\^NAVNE#I*'1D\'0327XJ/
M>&V-N>%.E.O!+H]1%YM(K:VY1J7J,J2C84H'KXY?\#"O_=@X/T1FAL0U<KW2
M5M`&9KL-#B1S'II_C3YQ:>BS9_A`MS/`AO/3X4JCYCI%9DLS=PBM\K9%IJY`
MES%,(4C.:G<O(AYXNM14TL5:T8XH$Z&/!F&G3(IKJ9HU?C90^KFB?VB-:U[N
MJ*26G\.CB)V2X'+#<O0P6R<UIJ03.>LI<\*YRX<Z.?J%4+7;B5,'<A_L,:8#
MNFCXDZ2?37>E+,OUSP8+8G2'[RV`=Q;G-+[RN$XB(!Y1-=Q<U![7ANBKYY[>
MUM8!_Z>O=N#A>2RQ#R4J_,$F>Q)IJ@>*$NQ[WY`L5T(CJ7HBE9G-DEJY#6&]
M(^`Y4S+RZ:FX<\8`UX8J/Z5<).&LF=VVHP-+(9MP"P7`>+.3%\*'">I1=#*W
M8`H0KR@LP(Y.2FF4GO(`_L]U*4?]C1NN=RB\:GYY`U%<WLXA)2HI[K`;:%+7
MJ`2A2Y,\6B5FGO<NCS-8-9"N%!G5RL@.8614Q\BFA=2)VBHJ;?AAEN+!J6?`
MOX("9F^-#74'W0@.",/=+_HM4XW(:7ML'(@R=-?RJLUY;SPI"'M_,$EZBP_7
MDGBE1T>_*:QO$/+.V06G<">0\)I5?@GZI%7H(8\#9`*A-\>E'6U0<G4[[@VB
M^$5<P\31<RHUZZ7BZRA^8[`EH>K(S6UWTC0R_(OS_;`,<:K]]80'!K>N>(*N
M/1W2M\;[$TT3_V8#WTT5?)JGY[Z)@TSTO#'1JI.6D7<N[!@8;F$:Q`;1YR;M
MQ="=4*HM`#MT493R2!_O3X42<%S:_*[G(.YN+P@8KF0'^BA[C?@&<]"B,"$@
MEC4!#*YK9"TYQY84JACA@V+C!>CM>R=F_>'Z6%$5AH:9?NI\#LO-,)SUSH3Q
MJ\?G2>3J.-G+6[]]1O<R+E05+=SNM?#G!@9VEY@=3%(,OE_20J0#87W&1=+S
MG__MP4IP57R=]TJ*`.&:;HD-`U(\P(Z?QS?^/<@B1*E.R\4(>L\7!9Y=A)P&
M?!CX+`-VT;RS3.1:#R<\7I9:&J7(10$HUJFJ[+'6FV6:Z(G0JBO0J0_S:"7;
M>X@D"O";6.OVOFYJEIP:CCX\<_1AY[7&T?ITXV'1A:J!<V1;KW@B?DH+L]4:
MZ2PRT#O:MI,,)6EMU%/)G&SR\8Z&\?D2+)44/LR10C@GL>6#I;VB0N!9=3P4
MASJHC\(1NT89!"HT)&ZA'K/*L'DALEZ#*>1I3_6CKA3+:UTPRR7+*\!2:KT0
MIF#F;;^)8H/T0Y69XY#"9R(^%V=@>ZPC_"H(8CD8-^*7%KWW6E%@E?4[!:J@
M:+YVLQQ#/"X]][Z2DX^^J3^YQ,:,\EKM`AL.:2`)1!V.=NN4V&68YS"V;/*&
M03J(=A6GPK[?>;PO`#\(N*GJ$O.#$W*]%_N_@EY590<`N@K5/VLO_K(0:F;)
MK?0!PE#7YH6-<=OI9^[UBRA*:[1ADM-V3U<.YP3^C.<&X>Q0O/19RMVC-=_M
MI\E2]C`TJ,_'<6RE$Q-1YP>Y:8$\T2A#M/".MQ90&NEC2ZRH+-4DFRL-;.%U
MG;Z^JE;J&8'IZ4K_7%Z:VJ>0HCD'TL/&M'@55_;Y2.Z<CQA3XH%#!(#N-`DT
MQD\ZA^$2$9ZH@Q/.WRDH90SGL0(D0F@35,N)CCGU!D;&^@M]=RN4-7F0-_N<
MBPH95]RWC.9VAM]3AV@Y-P7B[+,-#]BZ&;K&F)K"J'QJ10V&IE*)(@T;A4V)
M"X`D<BB][H8PH$#L=TI8KS%T_!23/;KUQL?;IU$$']L``>:+=NBUA6QPI'F&
MM^4@9:.Y#0K!S(RJ;YOR.)L&X>?S(%RP!F6J]AWDIX`XW<>T?>S:B<01-W9)
M@FO0(,VN!3K2KM\*QA>?@KQ3\FS@M,X3@8O?ZE[Q$LP9&MU9'K!-KUZ7I%DI
M$A-N\K`N$@I=`O01-)[F[=RQ+6O=.IEZ.W9FPCS.FZMV2Y*E.TMM7MVS.FA^
MDT_@??4T_E308R$\V3^#PFB,C1S'IP_*&)6:Z`[XG3Z=]%/==V4@9AJTLNA*
MYZ&3+_(3.5OE/YBQ,X@V:,,-]+XBKTK0U@S]>EGZ7,_I^>H!%OX"J6Q[Z*)W
M9CTBG;W>ZNH`"*ORA+JR566ZG.^FI_A.<)%TLY_7WG(.^<D=C(6@(*+W2]=:
M"%[UJ0DT<XY4YSTN"0`)7GRFG`F/_,W'Y@=1.9S![:LN>>!!+&)=[Y.NT(MK
M%ZUMVO0+=>(Z$]H1*ZT-"27MHHU4Z54XGKEJUPFENU>NBH".)C5+[U!HU7X8
M'_PW5Q]Z2;#?4,!-=/?YX4V\-4'\)OZ^FH(G5WN_MQB;EL2(1[Z3C[]DO-,A
M,\L(_D-(N^GLR)?(!()L*>00J>V:HA4,0SBV8H@:5':BEVI,?NK_J5$-\>.N
M]5'!??TMSAB\Y!BI9KX5)[GP')0$H'TR#/$FXO6<@-7'>^5')B'O8$_AW_"E
MUF:?T8!`86@=:./+,Q+>YG;S6O)!2N-2**=C1I''WY0ITE13%>UJ4'LC62NH
M&8<K]"TJ:M9`&"W_+2<=<=)1O\%L7)B98H,)5N1)'SNZWM>Q'57$S^0A&E8T
M&19I>8U]"V(8RRC]]\01U%WZ+E02PZV])<7.^WES,/FG?Z$`4,"N:JGW*(+@
MA=D,+"/_S<Y?A>W;_=!3TW>)^N4]F=9B_O2N0]FTYJ46&CHXVRRQ_11+NZCF
MPZB,)&V+>>MKR)#/`5)L1P\WJ:#KEG)-*EE*"#$SK61"SA9NF7PV&<^9C_WG
M!N;CY/X6"T];AT7,]-W+`$H9UL:JV=9`O)F!AU3$I>A?Y/!B*L*,)\RB*^5L
M!XB]S'F1(^7WH16U"'R4B(+`;T17B6.7)=A:RB^9%7]IY>C&:&NI%Y.J+AQ%
MX5FLS=-.FJ4<SE*)(NX"4?6F_`5"9TNJPD8VE$Q<.PL88?L:G>K)0[JS5+%%
MFX'ZWQ-QT+/->J'X9LK@(48IOEV)`0BY(/YTN04BYYL3)*%-S?"1?QI"81V1
M_`B<-)6%=L2J&0L83D8W.N>NT^N%7PO^KCVY=T%H^?9K#6]OQBU1;G<JCHE`
M6KMM_1PXYJ[:S-4DL#,,L-';E,O_L':CJFZ+AX770"UR?VS)_'MW#YK+9&$W
M6R=TVW6+A^1\%X266L!<-L1"F)PGS]@:(JDNNE19M>-.;(%T"0O#-LP4D^0N
M7H=&N22BNP`2Q:9KC]9XXHF;<=%Z?M;-IXC/B'>3G`$F=`B/^+O!>^.+K12`
MV)`Y/'6T>[#-S<;0]A#JTA0Y)"Y)1IWCN5(M*]=0(A#>M[Q$A"/P#T;IN'1B
M:B5/3':-Q&WO%[1+,G?@T2XHCQ`@0#9<!XKO^\Q-+*>07?15Z4.V\\UY7*&`
M;CZ#!7<4FH'UL5VI36WZ:XK=MC&'*6^)50<M=HD*O8_%OO$U3Y]1X:@S/Q-7
M"7><*9Q+<H=F('6C=P%9V900=>,%?6_RB-Z%SE4U!A-&LA:R+VI\8'@HQH&&
M"ZF]#J/4U0&BC'I'TPMRD?&U$DUC,G(\Y'[G<%LQJIJ4<N56>WJL"&!ERJ,I
M3HO(,;%_JUJ1#%!8ZW9];\Y703#-&T%(=;WY6Q\EZ:+*97W(C,K\7^=>_,!=
MY=%=:YU;7^,/"$IF\7_J&KBK,IY9+D3Q`6/;90N;<+]O9=$!C5(3.UDU_3QF
MEWOOAM]Q,4^F.^>9LL*$XF<NS7Y=S]@/MX@-)K;$**$<(7Y)(ZN[`(CR.WD9
MF8(-9&?)4_4>`6OD)$>&@[_W'O3NERK>+T,/S6^B%.2[3.M%>Y)BXKHB:@36
MXS\KPG_ZU&N@7'5\"2T@'X@L&\3&2['_OCY&]-0_-.6%`*9C&&JU\4UOCR>$
MRYQ7B)`SP),U=2D]!39LB$>3G#>R:;N"C1`,(P&\WA9@`"]P3_0<]<X"'Y1G
MCMR3EBL>TYZ(K!J$\9O]_N4;J#)Q!>K,48!E&MP3KT=S@Q-:U2@Z7EAU.P";
M=3[@UFC#^U)CJ\PQ8'11TSHV<(TH'IS;0%\J-;"]TR[@Z-'TYC#*YIKQM@ZS
M/,?_-R7`,&'='DG#.9%PIB95Q166S,DE/A1+IT$%\W'Y/W<A,#TRO4BVG:./
MHFX,.,V($Y[UM@I@V$48ES61]?'-?BD'7)<6#H5$UUE;Y"3!U/\1B(J"J<TT
MM%+P`XR2"9-+)S&64TG!#'O+H51WQ05XJ##IV?T(6\,^\ML$<;3)+Q6QO.$^
M7Q\R9U6MW&U+E0.$MFFWYAN'<O"HV5M6CM-.*$9A0FYY*49VH>X@#E"A:47N
MK[SC9Z<&Q'8_$9+0`&_``Q>(RQV;&"5NQT.1+SRC/%#J?[CESBUR1"O&'E_:
M\2&;&_EXHN$&V.+FG5DY@^P>5LUR?C/*\BYPZSWPUKNE=I(]5(BA`)'P2?=(
M.MIVPQ("0B:W'64@!8?`?BG$(,#\(*O\\(+9CG:Q@Y1&/YO$9KJ,1.H5-%DX
MKE4X&5I?GM7EQ/(9B*:CPP^R#*1[4(K%>W0Y)8$1'P)Y$HTVTV7WB;N8R5(@
M\ZL:3QQVB<1#W5EUWKN0S5WD9O"^(_I_NU$,'@*9^+Z/7Z"+]G'=4!>\QSPQ
M*+4S@D^#!X5]5,,@9N'1XP4,SX.0QSWP>D);X=/4Z==(0.F+EBWU?03BG,E8
MJ%[K+5*D1Z^!V<1],>CKA;PL$.D*X[,T*JBWK?1)6\!!Z(F54SA[.KOE)R<9
M345)V4!I1L>98^@5<S8#:@4^/#N2]W@H&UF5;T[J9@>]&5OTBH`7HX!I:<(&
M^$?_@((7"]_Q*.'$@4L.2:T4B-[KM>/NF6\0\==L]2"_IEO_@']W,"QI"I3\
MF&K`A^+MT'*HB$5]:?3!66BB)N!9PJ&^49R!IK'JQ,)D*54U?-;Z\XM#GDZI
MN,0NH<HZV[2"#,L;G5^"(,$*UKQ6XE9CADX7L`OO_AV;_3`_]*-1P>G<PEO,
MY$GSDXX06T:5ZT>Y/$_-3IQ`Z4%BP310%IH%!1/\!(]K4L@0;(POOG%14O1:
MWG<@67#45M%/H-O50D34__$"BN@0HDG,^85:MDV\6YEK[-^\W@)(V;>I:7,]
M\XV[63P9L$N#33`_`5CO009V?.E^-[L2-+60B.H,H\1([8N54.#PHYF)M57F
M9IF]G<1)5J7<37H'.<%7:"GCX;0M%UJ>J*-U$=;IP\"P(:EZT!ELI+J<HGR@
MMA.$X&M<*V^2Q2@)R^H1%JX;6)OZDSHS6)VF+9;3><H!V3+_EVE<"J]RVI^%
M<&_4GN3V.JZ+-<R06?*!VBAVC*VQ0E'VNW7`J.(946I,IQ67B^2!9,^A"B?J
M@M4A4GUH_Q83A59_0/OH9`EPKZJ4S\"=Z::E7DRC,5U[0LS:TQ_JH77^_*O<
MEIS`LCW,7<^](\B0;_M*-/$D*?C*?^R7C]CDLO/WHG@4#W[F3/A@J_.E'K-.
MH^N,C_/*71`VKVU'65OH^85C0>B%MC*0DMA(D$+$B(F/`4UP4?KB?8Z_%=@-
M"=[Q00`#-?\"A:3TP%[?`$=S?3?8.5B4&\.F'?:`)`+NP9`*DTF64Q+I)K+R
M9XP]S+^=+SN&Y!AON#W/G;_1_B9:V0;\#6,&[F`MCG_2-#]J-R\S*Q&=BH@6
MN1=S)J16@_;L?RN<6_Y"<Z4H<FC!>U\XH/K(P.4LU"T%1#AB?MWWYL1I'*%N
MA3.3`Y/SER">_:S(:)51`$]7\1@;B`!,GHM#[(GOF%H[7Z;*HB+5XF"$P>M!
M,/[/6(OH51)];)2D^#.7O;"1K554LT(A#BYWTX#ILYN7/L2$'9$(]"$N_4+W
M`OWZUDJ`*`$U#,BN\8,1.)8+-L.R(L]T@'`<C;^;S^%)C7_!0EMV@=_RHEZ?
MDU"9]5K"K?1+]E/:YQ3TL%X8.E,S25B;KH$UC1,J!FK=+@0HEI>T=)$'$DRP
M>=YR1C$Y48^/LO(SGUDVR634U?%Y]NA-RP<0SIB_$O9-_?^```?W)5"02Q1F
M3Q"&U\*BU*=W=$:-3J4BDD]K&]$,.(N)WKY;(\R_UP&Y.03KFQ!M%4>9GBF_
MW!=@^5F;JVG/%^Y7WZQ&[ZE=Y9'==)>3<FQ6Q2&(&O,>0PCZ&XZ3YZNFP$(\
MEG3&^_')""B?6L<0HS9R4O>"B/PLJ)0WP(IYO_&O&CN'^(MERN,"/B#:HM)2
MF-RV7`>RY:C.ZM/$$I!U4J7^;13KXZC=28P_[.R?K>+W=&*HA"B=._F3;<8=
M45L<MO12.$@JQ0YR)\,$TBL@V<V8/N0Q4-TZ<3P>\(=C%[*@]"(?)-,-DE![
M0O0-DE`\_4`F6<G0L!]E=]:$?7`P'5A?L)L$*AGD"JEU$!SZ\%%,GL.&+)H[
M[^#"=3LWU<`A^G20B%V*_`Z&M[57-K2`M#N]S:]3<I@N&31EX??5P)E]0$C+
M[GE$#`3\WF.AV<J(QX^&ZHCZ@)=>6"<&AUC1N^TQ/V(.*6RSU/]=C#*T!%'$
M*("QLBB:N);)AM="=X&,FWD\:`PG)!;WD%R0P9G[B1+X?>[W_V-#A:WBO)EE
MK@"QS9TWJ!!\B3$.I7"'%Q^/'.9N1--.PC3J9:,+3'O*HAH1E,,3`)'HJ8:4
M2\S85Z3^ZR<9GR6R>>_.52$:XX_4_N[S$/\&U9D#!]"W=TL6/Y>:C#B3_$%H
M[IZNC$5.A]B_U^IABT?M8`C`B(.M2<TXT\*^TJBXQ%7@B=,%JIPT8J.Q&F5,
M(K]GS>"QQJKL;J:9Z@#^T.6R0;&^KG2>@T0.GX,/9E^1M2^@;4;C;V+DRD8P
MW'OO31DGHH&'ZJQQ92/;-TND=),J^EH1[*W5KV3/F9JH'5IB?S&4R5OH(@-D
M/N@6=8^Q"A[ESY$QBT#=Y=NL,F8BL<2/'9;(I`11##P^2.^5BBUSX!Q'_XNE
MF:\;_V0"_R[A$EJ@(B1SU:L`Y&4V"RON+I$UG[B%;\O'E'?G04=3I.#'[.?A
M5<!!1#`>9GLS4`?V3<HV&V]H,XP&FVZUJM(>!RD"@FIS+K4Q]M3%?HVL;#,D
M2Q!/K\*+`"!3%09C;@I.Q+PK@D?XZ'O__?#W&8*/+6@(CH*D?PCGMSOR4KFD
M95!=2&,<$<J!9M?M6K=6$6`<9<$B;JNQ!+JE&"_!,7,?"-.K,5\.RM)`P%00
M*]MN2X0##K"A"?37.I\5$7T,TF?=:F(@#2O!JC!YQD*/:[D`]+XX'R/[-,`A
M04#4WT$!O#&&X?T:;1;HR6(^[;R"_:7H?>@:2ICN_>"D])$X6G@/&_UG36I7
M\;X'/M#CQ'&-EH<1VSPP+''5PJ_B:N`#HECNL$V)EYK4.5%E8*AW^QX\*GT(
M(K4L"W,=.3#\,@-\$K_O-)MUH[P-6@L47]%43@>@+RS5%]SUC4[5[1:P0#$_
M44K9M-74W?Y)->F"YV>`_/%^@X9OF%<!Q:PE.^J-WWCK32J>^!JB58!THAGT
M2Z?G?>M53/>J8!CDE#+7[-;Z=[()HO<]^GD%$[-QZ;/XHDGP<9Y:R*XH"[?E
M7+AEJAB.8:M7#LO,6]U"B]\RM1/+41/;_O%1RP5@8`#-3<!51186WV@:ARDW
M&:W(6^ZH<!@!AO5>8L_-*_WB7M>$J5[W,I!%82RJ4*!,*Z$/TN3[\<N]#)>*
M42!$WFRP^WW2^^V5@@]>HQXH3C<#&?X+5[0O34C?0<H6T2O"T\`$`%<38>:!
MZQ,GWW,4(&%':RX-^^B1^-H1[7=:Q:J6[=P!I\`)OOZIWC,A]-&H1H:?H.X\
M0C(TT8GD*E@KW0-O16C;!?\'"?K54[I^@,OW829"=I:W78]*I+0=9478E&!<
M"CMTGJ**!TB#;=B`>#(7QH*D+IL90LR2B&`"$UA!,YCJ>=V5KVPKUPE<6NFE
M><B7)XF^^^(#ZNN_-U,C(D9GR%O"%10;OX8LZ\]V2*1546!PT[G[\H&<GPIW
MLG>&,=WF%VDA-82E/S&>2J-!KKWR!#9F,^+KK;(&@])EWX!`(=>?MF*Z71$I
M)=A2+Y3AC>=ZPLK;I>LUE:'[&NOCP3QBX4WWM26O2@DS)`!WK(]N0\==D.HE
MBX9KQ8__E;FA[RD\=*!`3RYK[@NG3;OC</0/64VNRMJ!).EW"#CGEGPT!V[R
M6;ERGN6?HH0/!3G(4BC617EQ25(:I7KH6<9Q2K?B?SF#AF:,AME"")T6<FW/
M'3=XA?;XORF%0S@L>5AB3/TX?Z1EW]&W+E>T2O`;+_Z<$7T$$\A%!,:FM_8$
MCAW+R\+;2+ZU&KN6;K2NC!D@.TKK(>'\+S!H2V*.-#BIM[/D$0SRR&EGXL;F
M";_5^C0PVT.X@%2VGPQ?M.D6#1JSJ;F5EB(V7_66V>12NU8@@\<DW!RR"K2#
M$PLB9:*[Q]+XI%V,VS2N@*Q1R5(?`0F;?2K'/GTG,VBYTZ>U+$0N40K*5M53
M2P-;Y;^$*9&:OGT'OA%:5V1OHB`:9)**&BW>TS7%)MWX;!@+S#J6IXM*H1@+
MP!)I%^&FLINOUDYYXM9LV)&!8CFP?"PLDU6W)N2Q<CO2U#1:DHUOP-E\-D\?
MX@,*;9I*JD#P!"FV"8/^"PFD5WXK30RQ2!S.$Z#^23P>W.VA90HY7K+4G@^$
MJ]K?MOH'`5\:-8QR/1\8-4&9_AYL$^][3U34P##1HY[V<^J!+*]'SI0]YM@R
ME03`C8G_-7N'>K6*=VVG5:MX9'FK-*%"4$3M]XK"(NV3#(^>&`(5G(/`N.P1
M62I@@=PO<_V&LR>;>2<@V4>5?L&[61Q%&:$TV,T;AK8,ZQ3H^!J]==="5.0S
MA%IR3P][Y`77&)S=_";,^5Z=^)S0CA[22.&Z]"-:EF8&&]7WY42VZ;.B,B0>
M4ERED.CUJ_&S*4U],0@!"<Z<4(=6Q5]6H&^#*039W"`XU>VH9QYFXZ3E@!K<
M!A/7S!:WWI^:I8;'(\*4"]PI5^:!0T=-W1]-'J@_ZE-*FY8#*S_;77?^-=+'
MOPDY(2N0*J)W(#OME=J-J*TU^4=$@6?LA?XXJ\QMK.GR>M3-C5#UK0B"%.9!
M`Z=CEX[%GG5EEE9TAU*(56T!78+CT]YB,6&/IXP&-)\\B%V>K]X-?"R9ZJ[#
M0PE4I*"4]).:4A9<(CBKVD:4PU=DSRWST]%_HL$>0HHGL7J#O!Z&TE`N6X)X
MWH"(\AOOWBD^!;<?3J'T5B\./<Y<E5Q]DJ.U\U[20\OT[JJ:6!(3R;&7^@HA
ML&9R>6H$%C-]RR>.TUM.LXA0B$8Z,AQP/O[Y"\]%@":)>$0N%&!7@!@)4.++
M_E1O`8,!=4SNADI]15D9U'^E)",5=]4E"O*-\9)F>#AU@;WS34IDI++@&NX3
M&(1\;3(9&?DM(X#O[*V\#RSB`7^S>+(BJSO;K\Q.^-O(E"KCF>396\NXZ>T$
M,=1R"6[*/@[VJZ@XX),'R0LESB"GZKZ2[7D:U','R)QB^-P&/54(JIC]9-QC
M+R;D]QI$(@IG$3>5_*=U;PCMD&PDXV8+K$2>`KKDA%<Y=;G%%ZH2AOXLZHQ6
M0=8\OLSEC@!U3G!!V_%&A2/6'HO:^75OS),DONXJ<TLF=8UV90%^GQ/H0:7P
M%P*&)E2(1Q!IM8?QXFW;QTB-/3A<4HUE+.*5R]PQ.,LD<`3>J(H,TQD1Y&:3
MV(7N/3PU8$3_6Q=9CBSZ@!8O"'X/]Y:11?:V:31IH)_^K^JA1T[7>).1IC6Q
M^TP.FT8Z&&@NS=H+#0_/#*_$G<V-=Q\T`"#:C.F2`Q.]T5'7(KN3$FG1H\LS
M)\SU_0_MXQQ!PWAD58Y:O%S,FE_65:TL!RWN)EK#.A`NT*![B@RR%2/`_RUJ
M>;:0Z"F12_N?#6D9;24.-!.$#*4>I.N-F>\_0QKV/#;U*@.(.\LF4313R;99
M6FW>E$/P`;'W(<+(W;]T-4HEXICT#&E"-0@P3ZKQ/\9N),K49>E4,0V-OBF2
MB0RCKLE=HZBT.'X*K[+Y:GB.V/S_4`JWM8,RNG*\VU!=[5,VFB,TKX3S,QK-
M61P84++B,Z:*,1Z:,QJ"(Y;6_F,Q;\G)U-%7B'YEX*E8S8WOGR8Z(A=\BZ0V
M97R=X7_CH1LUHVZ@@>\&?G:B^9SOF=YCU+)'T.NO.8S3AF52(7LBAS._-"B/
M"3S>X?N0^LZ3#S50#L2*DUDZ-FQ3ZMG=5A28+1QI_754./+<9D!\[4R:B7IO
M6:GABAW0*?22U\-HZ)@Y.!?B+NF`,WV30>8*+ID%UXOOR%MWZ=P\_%5--COP
M!XEPWJNF5D@U"$42+"VHW2(PO-K,BDP\QR-FYDJ@4`BWK#\[N8/A<.QK@1W0
MQ1F.,1:=4X9-B>4!22'\UJB%LA@O5)Y`26`3KI90;X1BK&8`B%#R5X&A[6HJ
M"?!0/Z=Z#[EK2O7Q`?WUJ[R[<A+&S-3I$"^S:*X0'^NKI)=AXS@FF/2FA)9A
MG!W7@=JI$ZI*Y%0^G6*23&X(N'VS;N>-CAY+8971?8&%&"TH[K3R21KQEL9W
MA#,S&U?.JYJ9F"@H$VW90'@RJT5<%0FB7;>SPF8SG>!]C0H3=W0^Q4:#2BH[
M6JUW//L=:[Z\=1Z='E'1BN$!))IA\E611_VCBAEH!]T->R*O$F',-22"HEU.
MZMB+,8`:P?/,BW$*5%ZEZ-KJ0/J=<%PW`^?E8OB1LCF?Z0(DG),`1/CNON]U
M=0>9H1*:$*[JK\S&=#5#:?]/!*H@99@6(0F8MP%9LK/(#?J%"$<IH!<5$.M*
M0M?QLQ8RZ[H^D7;_HRG(1\,A03'F_[,'@5)U?*S(=+K#/SIMYNG).FJ84;!>
M#A]D.'VXB]#HL;.)ZZ&3\?OJ#!_`N@BN<D$//K(C6V-R3C3/)!-W7=G23VH1
M[LW848BZ#!8\R"?)2;D#U)O+R;00:#\"80A`@=<*KBTS]&@]DQSYC=D$\2HM
M1`,YPZS56<Q^C;IBC`-R*Z6M6_8>,.*9)?@LB.VW6=<T*#*_1_;<KVT<9Z'Y
M#X>@W.(_Q6R<KE6A90JA_/J"B75\U3_\YGH5IE\A@ZYQ$KU5,KG&%P"T2`89
M8>'[9'[%R.'_P[C/7OYL8@9MRC95%;!!`C%`=A(L`K4>M\'B(V2;-ST7#Z*@
MB%.\+P0WQ)8L#:ZB]*G4/P27$"#="X;KHR$>+5"<<MIE>!XH,<L2V-0"":YC
M]A.@C2$*AC__'-/`I%';=2BU?+Q;?1LLUP%2TPBR$CX`1GR0NGO,D%*QLND1
M40GG7[K%XA@RG#FMTQE6@3TD36"G\ZF%&`8">Z#I!@LU6/VB`2[[YR_!3]#S
MG_4#=%_.U:YY0X\X-8T'0CQ@`Q/HL9L>;]Q>>(JDIUY^E^G(K?ETUFC.)KXA
ME-Z%"=F(Y:.T\/CT;$IN(J;)Q4D0\!G0F39TWK8_+CO@JLE!94Z/J1I7J$`N
M1;K71R^$??EY3"`@?E2+T-S8W8?G%AYLS(6E_^EFU%?7X-16^D?$@S.;Z@4L
MB.I;3=_PD&Q86(@W19)=Z+.EY3#LKD-J@-HWZ!`I<=U0R[)@W4;LUN:`B`8M
M+W!0J^Q&")A"".^AK[7LHL/3H3MG6,8+Q:7-S*ZV4.P$MP^'JG]!P=M2HR\4
M#O*`#8UO64L#D?.9&3>*K=:=+G@ETT4J_)=JI7D3U$<1E_$)+G$?<Y&5\SH0
MZ(U1"'JASUXII=`8J<)S,XS_#BPH01$(9JNWB\_M"BL"1*""+#$"5KG,>4<&
M5\NP4KAOYPZHJ;9%Z'*<)PM1/F`[4PTL!:R,0Z*1J/153[*E*Z2XDE_P1*:$
M!*+9P<%4FBL2SC3C\3CILDT_@0-V'@2'&WBD+%"QIT=^-K$++XZ,J,;TW2NG
M2<>N&:LQ16+>/8`D(?@I//2=MOZU$WNJ\]F/,G92LZE_G>=@N\@PD^)4'Z'`
MS#4?=RT`GO.#\M4I0BA9WUC.Q5LA\E:P49Z=R$2S'^#.E,/<T)#3WJFF8&&/
M:0.G1L!@\"R-1$9R$ZCMRHY!JNG2$`V+?@9\G-'JF5PI0+:6*Z%R?>044VU2
M?O2UR7N-SNMZWB5++?!K&4P\4O[X1V22[=(QZ;50JQ!>)XB*#=]#ZCA1MA-F
MS\J]YTZU7S@%50=K+JR5`G(`B)@B_-F\[*,-;>XI]\5_!(\\\:IR+X>K27/*
MM)>^:WQONGN.OXXNX&E8W:7T[JB\W!Z3TMQ3A*Y2)UJT;``K3<"(APWAO=^J
MV,CMCIIM4XBYI*T^I'?,(8#7++#VOSH59)7Z#/XS(JKPS?-U?/=[(4!%/<C7
M-%A$#P?,)59UB)@]&O5%@R?UTC_N?+D('#)\,9QQ-KA1ZK)T(JOI`OZIE`N=
M>,R-G>MA+`S^DI:0[>E6)L![R^/"3LO38-U#]#/"AQ=XKU"GJJ]N:XOM8W[?
M0VS>"LS&JE,94EE^)*1V]%(D6,6N`Z_4M\=AL$&;[&_!J_V3^E@3GM=WNG.:
MKS8KAS])H&1T&VDOE)$,N?0?3J7*@-]OC#0"RYV-4F4%;33S5GUC2-_(8F_=
M@*:D:"O3B?A9B("?#X"PCYSP=RZ<A[YF?6L6&A)0'2@=,I)8U1H_2%V)BR&=
M9KD,,KWV]S@RRX2$F8`]9`$$&RS.7%!7=Q(*8)6F2`J(;_*`FYT`->C3]FJJ
MK)5DKS=`L<<T\D1>"EEY7;*&AQZKX+_>Y0[DUY2F2@$+D6F][UC]@SZ.F8O`
M&5#$DE+?C<EY?]4S@GWR5\[Z=3YH`2L1+(`["Z5+])^8X1_*+'/H3QA.H#+G
M'W-D.=-*<:")YORPM89X&.V^XQJL;]"RL_7N^^P>EQG?V0\7H(SX+&`H,I4&
MRC]*+&8<WVQ^YT&P`&7N:E0*3PQ%T+CLTC51YS+:K.X]O/(!L.?>B*FLOC?-
MBW-K4;C%D-O[+Y#.WF@"CLSTZ8QIXX7OMN"Z?;51`!PO>(B?E=,)5V`$"DL[
M3BD:)QI/QSZBA?BGP]Q23"+":`I+;]!%]5)?(L3%-$'AJA[J-PG9L^-BAU>=
MI>/-T9Q)/:_6J<U.GV[797Q3(<W-N0W;(G`?S:@P]P1\X-N28)",J^.O(@5E
M6+'+7\MEG.^>4<T[6-:LO>C$B@-)'1=$C:ZKV1&AX<X]/0`7W8U.C##G+=#N
M>YIWC%QN#)+M-"^J4LJ)[(/2:S=,]P+H/1E`V\MC;%SF[Q$:75_UKQ^^ER17
M9QYT+%#N41E([R("M_EV:<FL78>[.]+^SRBWJ$3X)R'F)S8N<_H34KV#16L;
M0T?V4>1+@6](H#&GQT&A*7R4F63>8YTPV7*^G.BX;1E@9&A9P!O[?H^!1K!,
M=A0)VT+`B@#RCR=@H:.-[C$D8LU_$M$!N35N=>S>#A7.@@IYS63%!$;^[@[E
M8M'Y\,!F]J)1XVOR1$/BLOA,;]-"B)XY"/I;-K0J*S[BH7*27_K$[YO.3,!+
M:;.Z?!ZKO0#>!)U?,@N!`(-;^_-[JE6$'.:"_HK2&\L<P_#!HM5-3E9)N&AC
MWF+94MN8/Y<5*W34A!,_;4B01.!G<EOL)@G,0?6S*YX,`J4Q&TV_/&Z]IYX]
M])8H/$XBD3/AQ\5$`91YLUY`?7AY6X_[*3^WIU4^2J;:^RNVY)J;]H8AW9D8
MJM6_3#[KLD?*!D_"FJ/+4%YI"4ZTAX%:,JTLW!.28M>[?A/W*@'XF>"U]Z?7
M='WG07;2Y>IS'NA5-5<IQC?(=Q6^A*E(GR&;\3>>DIH8FG=!_<GX19G1J6+M
M[/LP&I4V?ZYO)=32@4F*-^D-)P>/>V*G3SJP@J1^7XF7O%Q`0@0]>`+1SI)X
M&II.'I#H)9.8.&Z60X#*[K7WV\HPR>[@:7%)),1N^^03ZR=`T?RQ/C$W4<L4
M^/$+N_@0<\8(",(MO63Y%("4[:>O\C[Y8`76OA)!Z6C*?=``W61S'B@1QQT=
MLU@!`O^=XH4")S'Z-H.THJA_<P=<D79X&JTBXZU-`O0"U*:0R],$[-NVP+\8
MDPHSBA<3\/25HAZ-JTA(_=\OK+#)4C6]3V1+Q-C\SA\L;CIM<EP4/23%C^D?
M[?(FS8?ZGASS8?"[I!DI1KH*]46$^3&?4$X,(3`5^%#+I9A:M\1R&'TZXKD]
M+7ETKRE%0D8C0GD%`E]6M\AYT*)E(?>HKJY1_TEH^43(WY)M$0X*(1P`EM\W
MYJ"GCV&F'$W3%SDQ%5&JX3;)677`ERX)39(I?=4Z[B@<9]RS+HX#^R(;U+"@
M7/TMFMK8V`!1X'7/Z/$:RPL4JV*LXB41T$'G8WW"LEP5*++8*@*:`<TF@K1N
M.AL;J5Y'-K*/=;JU1@6](.0%'&>?.F=&X0;ZJ91;#M)8GDOOP?J45U#>A9]A
MPQ,@Y56E:,AM@6T_"XT3CV^,]_L8_P9>;X[QJ94L`0[GQK?<N&\#1&C'BL7A
MO/59L:3XT?N*DI/0KLCEYBC=^76=3&/<TQ.M]Z['W!E>-VHB,_CY8Y#HJ7M'
M_-T9/$-_^YV1_9@D+%#W*KT#1@7!_JG\Q?*7/C+E32DAP2>-YOKF@UG++E-C
MA,U(FQWR+I_YSADT2,TFW2IL`&PQA1DW1"/HI,('D2`Z=K?:RQ$JWA3+OI>K
MC8^N9BC:V-%;NF(K2G,-`'S#Z+VF\@/LDHR!`8PQ4U2P'+ZL@7U("K9JZ-C<
ME*>NC.4QO,7L$(<=YFA2#8YJ_;>F!IO0O:[+;^B4`Z>GNXP2_P'3&J=\6\@*
M%<]^[VLX(+U^$:@YGXE3:P-B^8I?IQCP<WEY<#,%&TF956DBJ5@[:2FF=.VO
MM06<4%&0JXFF<6;4[!*PK0[FN"\\V#D/Q)1TVUV.'.%]&:ZH?YB1*KAB%"V,
MZ0)^_FE07707,5URO7)MS?C:]UFK/)9*P])F!3HK\_4PE9_1$;U#:J-7+IN$
MIM(RQ?A@Y-9\K`QKG5,[(U#>7LFRIV5O0CZL9/<$(@$0?RLJO9_9,IA%PN:-
M,F)(I#$PT=6!8(]9A,C]XLM$+5[LF9)F_8I,8YLZ$P6HQW+,^62<8*C'.W?[
MO)]MT1\JI$/.C]/E>BARN1[@)G^O]D"(\N:0N;4W6DQ>CL[`N)%O\U`O;SDG
M=AK-.0;H%;J$,-BTTT^/,FU_12LHT`8[0#OS/5[T1'%6@:+#>G7EN#NS>V@C
MY?QUGR-88&PH20C6J53R_-M:YDG"."9\_KU@Y6LF@T!5!#\/(1PH=?"2=+SP
M_/J/;IOO#O3U7V,AVVN!5'B*S1[_U"F*/G\-P6[0X:$<NZM"_@98/8D_P-\E
M/&XTY5D<A2:I:8-W;7(X()YT=]W/J=Q&V<9D6D@U[R"&ZL*T8VC:G.%#K;@X
M]N%F?"-&5=[/D[\X'O)(M?IO&J4J"_:4BX=\J>>,8[_,TV>ZB8ELN#=2[<$.
MV\&>^:"^OAL2R@T2D9?7%16*MB7JE,1R;-#V\7F\#9OF6]Q-TE]@9S>=!UV-
M<D@S?*J*34AB[]C/X+YK*8H-_`KQKC%/^.[FS-NI=C2$"M*'SM0@;CR^UU_(
M4,2K2Z(=TA#$(CM(1X1%1;7:!H*XT.X</;U&G@NAP\,AK(*.5A^&%K+%5@E!
MZ^8BENBV?E81U@)@21W'Y)A+RN55_`%D;W3L*P4%F!G:$G?'D.^6Q*BTIW>A
M9$$O8N=D1F@EC0B79^Z'PO;.A2QVK[*=/JYD5Z3<L.8L5G^WE@^%R+6&F`VK
M?V`X;#[K74:W+;%)=WP"*^`#PN?AERY[5'./LG,)3K+PYI/[^*D#2$.7@R-W
MIQI3VFM5@O2[A]J<SOR[3P<U>E_7U6_65B_*#A)+X2$@B!8RSGE`L:7$U[4T
M.`,Z&N+TG.1Q.1LX`YC=U8/73OXT!D#\"!/GRZ.5(W)!37T1W7B8./&V#4N*
M9!N,+LD_O%OVRUIKEOO?C8^<L(5V!IN@KZB_L#XX%_Y9^>E0]/Q1F9[F=6Q/
ML.1-"+7/3HN92/3@-[IE87ZQLEWXS*@`_^Z5XT3OU,]'DS8TVT[3$7NHVD_>
MIKC1728P_0OQ%RKA%82>`B$SL7TG`Y"26OH:U)/=A16ABV+F]9$%CE<)+?@!
M&=,4S'<$2QB?LZJ]R+"7Y=QVM!(S0)96JG+^?SN)P'&/XS;<+OGG281P<U5/
M7)F0*?"C0&-U?.M?7(^J9-F^;6>;;<,T,U8QV-0XQR:!X(`!\MCG9-1HOXO\
MM22KS&P,U`5'M0!@F(Y]I#*8'Y0"U8`W-;WM;Z#`1UAQU0,*AAIF"BRLD/-A
M'D3B>QS5\$6AY5%7EJVO-@7PB+0&.A[\<A2C"VI5C9)R;QO;:'8H+"DC8TY-
M&!(/AL>D%"`7$Z=+&YC_E[0.9VU708T^V.="2O.>W4I6R^:.[B]&+H7`P#0`
M!1PO,\B,GW9CTC?+]CVUB1S;L(Y`2NENB9/^"AT>V4>;17!]0[/S,HNP&8H@
M^VGV2@DAW,^IYKN9E%+K?(/.U%:0UMFS6,FQ\V[`E,@,9[$USM"YCT']V120
M/H*,&5J.1H#F%_`&**W$KLBY<P<&PZ4>W?)+V<9/$N&'1/T7[Z"?]F)`D]UY
M'S@!@!4^UIR2$+.]1N2S[,13W`):PC<`5+\,)+FDJVY>J*>Y6SOIOK/!UCQF
ME)T:*,R7['^`\&S9D]0=T+DJ*?$?:JC]&4O$SGWNO*\$:0^Z"%F]SPO1'.)K
MN(&HH@ZL[E].%^T6#Z`]UW^&T:PP!!CUJ&3HFW8\>^.^_GUP&:2A^O28\-*5
MN\^I:AWV&U?8"9^2E%R^1]Q02;]:(4HUO&,%ZKU28/RX0`!7M>04'Z0<!?0D
MRQ?5!3)]UR/?;/#0K/Z9Q/T1KU3`+U5Q>I]"#8J'4#E0#QQ)LKJH3X.EGGL6
MY>3KM%:?AH_]69+*,N,(5(\$ZJ?7;O-^M"/A[PR^Y^=B82_%(D^V,6!Q\G_M
M&+G<>KIPN'@,L)U;>`!0USA]8]Y20AK*K-B[3L,@PSQ\BL\=Y#D#PGBS+<#-
M[O&5":%C@/QJP]HN(<%EGV4Z$<;/HL`0[EC-#@:[I-/X$[8W7)0S.W&3>4,[
M;<B&NT=5KB?FA!<1)H]/99GXD5)[KU/D#]7ME4E'<3IX0F1HL_J1ZFKD\X[,
M>KZ*ML&=9K(N#R'HH0-TI"$;*EB0(;/?J_YN#MP>K-`RC6-`5>A]$JIFHY1&
MHYKE>X=7,4(=9.]QP(RBN.\F<IH<(L:6*X0(3],67&4AL08;S&/>4@0@6"$*
M,O8#RBLO`NS;KW6`)8#=62''>T/FP\;R-B`KNE,8Z!I,&R&*H<MO'`+<=_2V
M'`2S_.V7OQ05Y0Y4+M#(_\>8Q9[SCYA%*1U-L';*"AS/B@9Z0(1P,E*F(V4%
M5=),Y2K'`!\_X/-`:[VS7+^YI"38MB,3$$\*-JP4467_9;K+#0MC+1@+H1#H
M+'DSQ[#+ZPN>((5-0[XX>>8#_MX_@HIR06IJ&FS,UAFY+6DKD\&E.`G8*\MN
M_+;J_J@E(AHX&]]$;01W[3J.GDVU=MUUAD4(7ZIB2Q%_NP`P]]HLAW#(;!CF
M`D$!2=07(;#FW4%=X"=)=[D+N6A"1UYP4+SPZUK,UERT6+R3`5YZ(VV0^QT8
M_6J,$5JZZ0$==]TTE2/"X@<SY3/]L+)Q.`!5A;:X+6C!_X0Z8()8:G'TFQ8L
MX(0:7AK\7`!;#;Y9QK'OD?OH[#8^2!]Y>T`V,\+1R,H91T^D42#^*8E+53<,
M]ISUX?FK$7,\-*=YT4&#^3I]W`J``UYS((5R()9&;Y^K%H4C$@]"EZY\^THE
MZ'>4(MWJ2W+L84TL6&H8Q%+#M>_B$IBC1(T9`DCGM\+OK_JIA'#'6W5'_BWP
MJD;G[.J\ONX!,6C\8QL0U-<[+3IUF7Y."DOE%&\,U5ID$`>8G`Z,YUUE>'SF
MVLW%FI2>E&(4E1MG*LGR0/T:'QY$C!N;60V[+!_94,?Z`:(!RFS*2#S,?EI]
M+4?EI,E>90'JN+O^WO84&OM%(#/*\24F\J+!O10*PT,+T9^6VU"!8&SP7]\)
M\_6`'B0W(BTN?BO(]R`F&8HQ2)I!`CI%HVCD^-3<,;^,YH9,[SI0Q[AG!:31
M;W@$1C7V=!F(0/KY8\_W"J7T48#,U6Y10.!/7/:&AW\,TG\R+\7%F'JLJGIA
M\DH+D>83^N6L[=AP=7>1V4=TEX($93FM+I\[#^6?#SBK3\\\QQ$Y3^3/;:79
M"8+SBG;G]_?-?M;[;AD%=>5-XP+^J)=SZ)S$;;*#$2)WX3FA"-Z3XS0NN`-;
MHMI>#3O-RK9FS!S1>GGB>U0C3%_MD897YW[Z='CB$`OW(C$D=W9))1H,M2XM
M!85`:`@-<IWH<9+X_'4]:56=1P[]06X;W0;,JT:251]A&W$Q%L0`U)Z4K/LR
MDB:-%R/97;6^',0$2L<3*&5T;$0W.@QP5.T3G*X?R?E;+J['=9^V,!?2]ZX4
M<+^+(R+L%6EA/I6R^FZ>@=]H82\SF<$(Y#KQ?/P,N.L)(:@S*CO#]WD/5;-E
MW08$P\V#S12>3\KOF)7]Y.DE.!8IL=XMIWEY4TE64]ZY:-YYM`.,'"A8#8O\
MYOG'%.*>.-PW#Z.Y90/;>E[LC&\H:R'=NFWZCLKP&!S#!6&#MO]W>/7H:(D`
M%#F?*W1Z*5Q!,L6W9M_;$I;B.N[,M)II3M.UP<@"\<4P?2EL28KNT+?)N(YN
MR8*J;]3JIP[S7D.0)?H1F2J@2*APQ:<"N/7\E@BO;Z`D*Q!]YX5YR%>@EFHL
M$D_@3D'J&57VI4=8N*I.2@\74"_9R7:2%=EH>69,2>LC(:\+4*P3O./9B3,Y
MT48L/4.[\#^=4:X,/TUL"TAYEPKOY8MXQ\R*[9;:EU9BK:7ZTDB'.U/X4XL1
MA*!Y<@K<1<GHL*3JQ#HZ.68IBZ"W-#$\O:<8@#2S+P0>Y&Y(H>8$1%8&JN21
M9S>:R?=4$WP;%7O,1YR17R(W+SW_BD)CA?^=^_@30"P"]-:B*;&*%=R_KM`.
M6*D7D;*2+*TC\5>/NFD&2]*M!QAW`:FR"/C@2)2?RQF+CV2,YP9J<Z3FUU':
M!<Z7>JZ3(A]#E8F&QA(Z:-BG*'K2A%/P!N>"L/DJ[=!KS>N$K'K""'93#O%S
MJS+\)Q4%IAP9)=N9PQHA[H?R]'6$R=$%L*>BD]/]%7'&CW7T`%'<IO#GJ9*#
M"X7+M4Z:IVW%H=>&=&BAU9V[";;U!,*&!I,-\,=A(MKV[G;&N#P%/!%660(N
M`JVOM!43%5-U?\]ABM2A:SYR&ICF;/]3M4]3B_Q6F)F?!P?;0X,#O^[N+9J;
MZ7>F$Y!9-(<,UOS;&.3^"#,1`5[54Q:`$C4(&3QME/%4']38^<(,4Z3#E_].
M(4;UOKJ&2>I`&R;1G";182SR+[071F])L#H,Y+9(2-R%T,3L]D#+]AULJFMF
M=V0W(SD(6%C,!F3JEQWV,1Y=\3>OT%:63`DU\VGA0R!US^&H&AQW,,R6-=,;
M$/:/:A<\]?IQYN`[B/95N:NN+W6OW^2U(HWFM;,KA$8`A6W0P(5__<8XW:=9
MBN2C(4Y>43@<,8W!3TF+3(FH$(0,);F[8;%'W*JKES8K=7PLG.=;7&J(Y+_*
MB:[SDVNU#=S")]E^>X<88,B!'9DS).-\='SY^QYWM5KFR0,DNPW=6\WT%O/`
M69,J_!W>$"VEQ6,:AT,?J\52UY.N2IJO@!$K+8I:HA&>8"^<SQP@8!/2=L.8
M%E7F141"0MW75#BZ\!;R+RY4V\Y1WXT5UNPD52GJ36&JO**1LM0<(2G(:KD=
MJ8T$W6NS\3TT9HH!K[Q?FAXO9YLZVSS)0FTRZ1OICQP%,TQ&T$&LFXV,P-"=
MB&J6DVB-UOD%/!0Q)N_%I7,;G>G>J?4T]PS<"W"NU/7TI0JL"@L%I7]KTG:!
MEB2'>7I?G?>9\(]W4`7_+4"`,;$_$0NMG^728+QZC-<_;83^L33D*@T.(M1'
MQYN?EX&5)8L(KCI[USBOBAS'F."G(X2/D3J1#A!DWLV6;;4MX;^+5TH-T>E#
M:17F8*Z*1&ZQA]SZ,%`ZAO'1L>J99LD6/.`Y>;[CT5$4"P<T8ZCHR>6HN<:7
M##>MN5/FUG@SJ*,(_;VTOFM2$LLH(DJ/^Y?BDIY"Z#[H.OA_`]%47L*]U>;T
M"UA216/$"XPTC`WX\AZ0$!$J#.RFK`?TA3>35%GN8#3"(XI/G4;SJ+-_^&#L
MYKLX0'(+8F6]7\B%]>/,+PS=6B]JOH7UMSI)/L6&\D6ANF^`0:#FM8R<'F0N
MQI)O2V7E9^2B_<ZLG:/KBAD`PE'V/(]$51^>D)?\:!S@+RC[\*VWIV7!X6LR
ML@"VH0CDNHM@\$GY?D@.N=A85HP7%^E$CF.K=WAC0EO60+`CYZ6"+KIQA"@^
MH'%BS/C4X=<V(I\R`IA)L6K4)<OVR5"FMVRA@NU`6EI,KDYO7#81\2BY%PZW
MHT+TQH:<$D.WE"J;F37\QE/9_YAF9.05+(=GTE[R-18%D'E)/$(8UN0=&%M+
MV-14*4UW;92?:4:RD?T@LA?GSI9M6Q_S=+BO0F5NN!5=#VO!.<LK"S9ZO*Z*
M&X.[$(8Z;18>UV_:@HEF)R":(<9V_NUBS$`JVTMB)E;2*WSNK2#,+:B8-JO'
MEVL4SY]WUN$R.R@02*P<'O<J$?&3+TKDU23CX^=3F"5CMW.N2W/-,/#15,?A
MG!3BKVG+I=R>M+5^/]*[QM+57/9B7=YR'44PH6'[P&U_[S8"4$G%$+7]WA\#
M*K$T]P#DH<&0P%FXOR'@_J;9L.-*R3K?<'LI56C1:"KT05UV7_NP/R@3*)-^
MF@%//AI,,<*.RR\&/CP`8#NJ*>5,V#A)V%+'>0?U;UO<4YLLZM\Z.4#Y21BX
MZE7`DQ5-P.""?HG*V6_HFA*S3:ZADH``_A_PLD:8=/;J.37>AN&BX,#,11%&
MZQ(7\!-R]'#+3TZ7@*,$;(BFABEOSY9.RRP52.L/0#N%[2$$XD:13&\EF"5%
M1@V9!B$'-YV^\X[L01.,SP"E]ZDC-\K?G:WSAO"''5;)M%BBIHV54?_[!$O6
M-V7<;?8?$6U(R%D$=CDCVEZ_`@OWX%P.#Z6C\:F?#T5_S&)%KL11S('B\6A2
M,S\4/Y8BZ\$%QL$F,A#2S3CAI&UR)1C3RNN"=EOF=FLKF8Z#;9GV)OD?G23G
MGX$ZC1B%P6#4L4N&^<0ZDS5.0HX!2$XU-"*+?[:E9`WL,GQB0^0)<12,=GTI
M)U.H/J06K>&)5Y_%*)XG4('O?"O_%]RMQR47UKX@CRV,]2WFC9AXR+_?K>X`
MQEW3&'IN@67[\7[4*4A__[9@S0%SQ.<H"?BTUL67UDK+33?34)E_1^1(QWFU
MX(F'+HTJ^D0.(G/=_F``)[HS^!'U6G9DNMLO<-W%P_//TG.1S'L`)`QDE1,D
MIO^DUOSH]O)?8[\:^DDMZ]!>6+:2=VC;1'^"XTOQ;'%K7],[!,Y7RK/$RI3P
M1T!;VXLQL7,)NP!RP$?<J[HU,JD=[>5<*COUGEBX_]G^C^\9R4K@8<N]!#9L
MM[%X##-E],Y_BZJLR"N'1]3^*1OCHC1>*I(Z-\K2@:$ADGX.56)+9B<N37D2
M?R#,LPVT%REXR9VYF;DH"GS'1DXDR:FO3-VO<UE38FC5+!#])`/"SQQZ$\AY
M"3.1H8\6$O_G0FC:8;MX##J<97IO=\2/U7EZ.1\]9WO'&++S).L8IUN&OM/>
M>5C?^*Z`[`RVUG?J`X`RJ%"U*U=W$XR+/L7QW-ZU[ID<#/:#YD4W2M=.]CJG
M9"D9-R*2MMVSK>XS&/Z=][J0I)[.['5[FT9*_-,GH@9\D2:;:W"$`?'96R-K
MI<I/E5))E=_$=>+D:M7E,UW\_$IRKMBMG2+!12]8=;B<%O\]VB=.;C]L@T,]
M;2(UY[3"APD9/R3=A-'&O-CZN[AWJ]UY?4A7I1]:'>@BS5;B$C,F&(=#>9U)
M=Z,L3B,_'I/^_F)4IO:.R2OHCU\B(-S>`^:-M(^Z.L")NX]%7>8X:IM^Z/6?
MW<.5C[$S_%W(A]!WVZ\?*?E_]U9EEZU1)/HM8]I`]3DQ=]A/G'IBC=1"]U.&
MQZU@Q=)E@PG.`P,\TGYS/K&S>HC_TWA3WV])/SH@_XP0FL\&F/1U5)C2<2KR
M18IF6\T5K91P/U.KT2Q7_C:!+$OI5"MRG..D`EM-/F]0(D>2\<+;1!*GHI%W
M^@J#=:]'/JA4<*ELH9>IJ#C<L2E/^&UX<)O:>'JK@^LW"_(GHR.#P$VUI+&A
MP`97?\.S--^-W6P5)Z/<-KR2260W8%4&ZPZ*AJJH9>UQXZ]HK;4PQ]V(A6.W
M/Z;/9>KV2./=F;P=$K?&+P5E3_>Q['R<Z/25>I('!X-TCCD3JTL=1X[?<-3U
M@7P_1AA\.L,Z<`+SJ\YY<P<%@YC#P$AZH#^>7/+=>_K8:K@-JO]PQPP:OT5\
M5Q->F:S'-N?#-9'1=4>B'9Q1S/4B>-0@*`Y9T0?(#VOK3$@R;KT>DRX9>18G
MQ<8,"F7ZRAX(I"8TBZXRF;/,<3+:8-"8#UW5[XGH[7.S(@9K$J.2^%"^>$]T
MT]TK(J`8LD.T(H"]?'45">7]HM*+<_3;ALF*9(W059DKRJX\/9K2]!P4\<*E
M4:S[=,2U+D03/;?_GGYF".":HAS#5*G3PV+DL?["E[9]W-.K3R:/N+IX?.%1
M[KU=GRTY,_[&]=\6*A^?>4<G/>;F8+1]>IJ7CI&5XOK<C3(_G7BWM[!?/8_H
M;#*VE,#TJ:/3^#<`4?--Y&P6V=Z2>?AO`"`VYN@XM_^'%'#I#_QO(5JJ0HK,
MXRU!JH2I$`IJY6>%[M*_HQ?J['N**Z#E3%@M;TOERCY$#)?1\R_;A07_VY-6
M]P?0VRH,G0X5H9L`K6`,5-Z*3RZ^9)DN@_TB"(UCCV/9A>.F<,1L_>F"T)PD
MR%_H(?$]&?R.*4UP0A"6HN9+__%#B'G-8+;1[2`27O>NRPD+3?,4]T*`JX-0
M)X8_7WA>;-$?ZQ=D;@`&9XI^(VD$2:W4R_F1WJ,1+\#&S(?-L:?4T,/K&BAA
M&B#W>U^^S7\O/KER/QX^+GK2_\SMW4L9&J8_3]-5!!1B;GI`(?WZ3;7+X.<I
MZ,S/PED4'6HB>3Z*8;+HM>\2R=6$M#?-N1'.&/5)!#4WOX&"<@]C#?MY;]Z&
MW=86]"D_Y(TBW>_J3PU%,5*T"*5+I$R"-^]VI;#&Q7JV<(2F0!G-.-6[`Z'5
M/99;(^N5_QJ.,0;\#="&]\!#\N!A)-+?>NGA=:F5L?QL?V=SR:+)4,[G5J+H
MM$#O5WLO-_7#;4(TSPC'0E1#N_`*87(ZU1#W>66AA,?F8L_\]A1=.[P!!JL>
MZIK5&^AXH@^FQ@64WHY(^K.FG$6]`*NO$N88Q5\>X&WHLN<LAEXGE*X$08EY
M@S@.LS!X=,.(2"KMRQ[%R8]0C4HPO^+P2O*+/MJ!\K#9W,?QESSG[34E/(Q*
M<H7_C'F6>45V>_*3>*V=IZK6ED>TM/`Y7W,I$2N]VB4YZW,+<<4>]*,XNQ6!
M1#0XNJB03GI9/].L1%&4"6,(XC0>J1V%?#J9_7,O>`J>^CZ6^.!OR@]4WYB5
MFC]`7:Z2=J^,DD;5^9V!LJL`C39"JO2]8#T+^(%>DC=M-Q%$OIV<`"G'7]6:
M!EH,@DTC(VXVT<ODQ(DAZD&N^AS4KO-.-*;XT;A>;B%S-OXT]Z&K+T+=NF(1
M2',]69,+,+THQIU=);Z&K2$5)G5KOF/F3J>Z(L)VX^EQFB=#IU=%`>YSE`&L
MGN>3D!+I5\I9!OE:R@K;.!I=87V<H&L\X\5S;Q:&&/C>U@BD=/G'=E6I!T,7
ML13^DP"B?#L*,NQP1IV['\N<`1A[*QJ/)S6H@0NHPWTU&&K[#>%*E6'/:(+<
MX:BCGY>)/+&03D42W3+7NE!J^,]WS,B:#-#+,#/KB;E+01+P:-^&,TD]6L(6
M)4N"Y4L3_T8T?J20/<Y?)I(YDL'#+_07BRS9C:Y=D`=0ZD``R3Z-8#PC>',2
MK[R@WDZ3$!V">#MX7D!4#1_;<?\C5'^3Q>QC1I+@[EGX+X7RAWV*B*I&%%23
M\JM->QI?4"=)9:&(77(#+"HR4*)/\C,'`KC+FW9XN%ZGB+:1#`X--?G2(,!V
M:=72[94?>KXVBTS#N"1%HZF<;Q$4WMX<NJW<?X=@#D0[Z$,"?^;O@YIU`]PK
M1;.RA)ZC2Y/VA%7O=T2F]F<CH14?60XUDCQ_+UB:59$&@3>WW&W4'@;Z.F*K
M'785(D,Y$/4$(.L-*&V^H;"ZL=L1D2)I,LN*ND$KS!/-,5?>LF9/Y+%_4JL_
M'11S.M5.B(]:[0GP_&9IPY+E-Y!)C=A04B/GHF-YD[K+X1+DBZPW%!=]*",Z
M#OGO2ULR^(23K6FI#"70F(\%!H9ZDOMDIK#S,"BQ[!7YN=,%VI7(.TE(R'1P
MYM?QV$"/_U&+W^I4-#ZI)975Q7X7!'@'%YSOX6DH8?FC@/[^13;R84B6O5X8
M7$-GN4-(`9Q@-%Z.GW(V(`HJXT4[-;:MH3F[K3U10C`%D_GJ7#3KR;:UQ],/
M*?[+Q/*XAQPU<C&]0``KN\>^MVF"Z9IE/%0-=?R0Z%O!;D!S8/(-N`\!CR<2
MC$;IO<'&!C/.(=1BY.U&NJF";-?!W#<PM+S9&LCOO))[IM$=--CR+VM_\S5_
M*?A"%'`T@H5)N0)@4H*VG=RU[P`W#Q:T+ZF-#1U';X/J$E?7OI<KN"<GY"-I
MD+8_0!?&@0]TL4MK)<O-]6JSF+S_87*BB,19Y(0).CD#$>`G_UZG,61##&1T
MHZQF0_CI/J/B)=GET!<TYG+I#94$[U(?IIT?YD>>;7@+^'JC(%5L_]Q+GYZ-
M%PA:0AO(ZNS#AG'%Y7:!1R2!NW.L9TL3PK&J*5I$K9-S/S)B0/8>30)BQ$8N
MUT%P57N9ZTHF4RUFOFP$-4RP<G'X5MWSOI`HI!%,IHJ_?.2%V>$W;])I(^3L
MVR9V9!?TA=)I%.`4&]7=JNN9/09+C674)HSM8']604P*(T2GDGO]8(5I:0'B
MFP6='FQR\US[9F(?D>0G3(R:IJ+;BN)CO'B1=4KIZ8J,"$VW!A+`4U%G^7C,
MLD1&['S[I8O@#T&+!"9>-196UC+&G%N'(RX@44?`'_=RDML[4I76(*(,13HM
M[)0IY\6W+"$WQSQYH/0F'!<4T\T+A8#%0*OEG4N-?.)55WT@W\)V'#[K,5^W
M6QWYAS>/J4M^%D"#2%H=O?OU:+DC:=+<5'T#U>=UFK`0R=A05@T&QFKCDN9$
MCD^;O-;ZV$!?QD0M&6K6%BU-^\>OQ0\'%:S2-H6^*)FA.%F6-KEA:12']'_>
M/-NI5#M8<$B9M,S>5G3O*'XG9/.7[^(,W<HAGV)6D[@RCEQ<61.NZTM[Q1U"
MZ.[:^"ILWFMIL0.]$T@58K*AI=YG/*;5)FGM"P>E_;CS>:L">:X[]Z*3OG6/
ML@AXC'+G&MA^V*:&XYNW+)XW8+/+(MBLIIPGWC7_`&(4;?"06?F"(9#K))>V
MITJ^`*U</7AT607MD%<L1%'6HX($?XN;[9*IPR9#/>5%7+)83H:W@<]L&8+H
M"&G1M:$[)+.#4?W:E-))]0"S9G?\H*J*!^ZKH,5N;ZZ^;1K<9U$*[SOVN^,3
M`+:/[9I(^I9ANIBS$19Q&4M+134F;PD>'<,"0A^^L(+I^(NE>0\P)\-MQNY;
M5GX(4I!4Z%TQVT-IX5NN.)>6*V*M?6G"%`N-F>"WECM(?FD)9=6\8GYEOO==
MDFN%'5N"`XZC024D@]_0848ITO:*V!I9]CEP#^WT$(5,2=\+BZ`=:>SU/DP"
MR-33+?>_)<E#]B;F[>(;,R((=#Z5H?Y*X@R9>/^8V,F"I_4F%:FBH-CJ;BC%
MH!K[Q<4I7MPJP$:G3<=E&-#__F3=RIFZ9?XA)1.O`@;ZR:78FF6F%1Z%N&!@
MZ^P8G/#,`BYXT(C69S2ULO!;L0FHN+I6C>2#X;;]X+_3$2</'I^1%F&4<5A`
MEG==P]B(0^GQ$]QK_$U0,$%7ZA4OT`K,1,V[O/U$!4O2%0][#CKR-WX97+[0
MD/][^31-W\M,4/T`T2RBS5PW-SXZW-KCQ2DLZM6J1#F1]`R-;2H:,&-9]IR9
MJA,4[L;@O1Y7BP>T9$`N*/@<]CY;G+`][S.;G*+_)YKX\!%J=VYL;G4"?4>7
MA-\XU<0"->F'9QVZGD">]Y-%_@?9I\<RAT+6O[82!4S*S;T7)E3/AK*I$%L[
M4]UJ+Z@EG8]$7Q^IR@/NE?3<^_S#<;12T'ZX,^OCB?+N#S!&V4*XT5CV+;Z/
M2O.Q?QJ9!^'N:^!4'-,*Y[Q'F8:+*M8!37+\>,ZL_G>O(%BOET(L8S,^L6FN
M,P]:N;Q9S4(+%=@$[%B!LA9ZQ8Q/`FG@TV"=#8Y]/(3B,<"E/"#=N0!Z!JBW
M!J^(=G+'?J`M&1]Y7GGQ/]JJ76K7P?NGUXAD%1+/<YV_1<.Y4X]>Q8H:_L44
M'#KB=X9+_J)Q9)RQ=)5M-=RMW;==<Y$<64:4]7_5T`N.M.+!-';KEJ.XKK1X
M?5O)VQ&R-@F&BDWYV'6VXH8^[MFE>&/\G"1@?(Y23-'/?$Z),6\568\H=U^3
M5&[VU`7_2GOZ6`>CK:;D=6NI>(\Q9A69L.PU9\C`W1#"_/0ND8KO>(A)0(-V
M<)8'6X3]Z`P.%:K@GP:[``M@V^969P>:9>5I^W!16:`'O9GMIX4]$MC"(U.D
M)#*6<4G@FKD,WKA.Y<D<?JZ+B>T.=3Q,NUCS3F85)5_Z-J%.RUN3+04HL/V[
M5>9PTFJX%)P\(QQ;7W/'8B97@G:GZ?RF&EM,*Y(<.4,=R"\)L[8.R)B\5!@R
M)WY=@^CN&]8=KIWBEGFD%TGT4>F8TD1],+#?E_YP&G\8A/(DN%*FL/`,X%29
M^(IFL2JD8(S%)N_WJDABW^=8-/B9^/[L4EX/;/T'D><_TA>(;*'<LE?;1ITL
M_1B:]EMG)UU?2HF6@V;J)&:`:3CP"PPB'AX$I6Y=.)E'_.7Y?\W:(A?VX1I)
M@XTX46]6D%H6N6-RH?1+T()X5H-"HU($*AHGE2@GMJ][7$,[2@3BZ1#VYOZ?
M&GTP3QJAP[9][D\R<X!35.23'=F%QCEN?JM7*4%R"\7:W=C(U-+GI_LYQY4K
MC[;F$'R)-6&G%M10:3F'Z-8'6I6I4B]/)`Z2&+0VL<XST^>P0H(DXUZC:-L)
M?=2L'\!=:WL+<[2,DN/Z2?@7_`"8V5IS;M-=MA2Y`K=]8WB@7_T%LX_EKG%@
M'^KNR/;>%:A&_-P%*=E61L]-L[1GR!!I>GLB)[DRC%#5]S0RE8_1VUG3D_LJ
M<40Q7#0QYX)`BN.F@+^TLJP=',648&8!C*]B3V]Z6SDILB+791%N4_A=5NU$
M*!.$[5K!(4`/1!$*2Z[639ICB0"F.XI1=R!8<:,$O&9T%G`#Q)MTVN?2WCH%
M$I:%>)%H[1D7=:@OD8>,*L`.`54^R`G;YN['[I%@_OJ((*PE=&&;\".<#1?^
MU*XT`#8BX)[MB3/!,L)_D)F=%^K<::$@K`JUDZAT-8>=(TWMHY[667'7?I6`
M+W+5=ZR6(>857#]NOYCZM]NP7>!E([,T`2>NUUA]@X>;,ZY0-A*@5DYWAYV^
MIU("MQJAF`XJQ&:'*@>[C>&HRU7']A4IT\C.YQLJ6/T4BN1K*'G-D$;0XS)I
MVPD8+T^JL=''SKJ0W<G+Q5V!4%GAA6'U19&9E\E!1DZ_?<L%AKL3\7M>+:W_
M\=.[X+%-''YV5`A*^;F)!5)@C8MG&C=47:\?V^$J1M*P<PD:6H"&EJX04%B$
M'%1K'U57[%QU7/%1EK(+,UTI!#;Z%&_H)N4;YJ&_KF,(.$&^.:%E!B=%/%.Y
MRZ<R`T"[L:JNB";)`OT]$D\2`GJ4X=J5W"(/;1)_5>DZ2VU[GW=W8E%[[,X`
M\Z87SIHE<EKV4?>_</E:_*L9&(:Q#C;'H+T?<>G-<CTB_DZK!@4ZKSXK'A+Y
MCS%13Z;BDT\R$.R@;T>#.]MPWS,'ALK]8AEI2=F2'`IE<AJV>H(_6>JZ,M6\
M,??C("!]XA`IP2L$*[>HV;B*=5U@AX@I>>G9N7O$Y\.R?E2NU4E?B&?6(6##
MBO#B>Y?=*0R30N8SKXAZ-?P;PGAU7@/\C)\RE/!YT/5?0>7I6*%TS]&HM,\Y
MX3;[R)ZY)LY#2EW%<-URGM)`?CS8D@RFQ=D)3SQ*U)Y<&Z)A&ZX?A!1V42U:
M>M7W2Y,PX4X5/Y[HE9^825)B5'<O^R^U26.=2?G)W:P%\\8NCR19O0$^5QS)
MOD/88H="!LR>SV+Q)I^;B^WU'/V?O&H_'9Y#T-6>I#2AS8G17S2[=OTL5#DM
M.)_N07-NQ/@<?P:_.V8QZ13:&"^C5H?.YY"`\@71Y517*Y"C%O,)AWNAQ(!_
MR?$A.%\ZFKP+T;?.`_;PEK)R5/3-M%PY@)EV*K*8S[LRUW*OZ8NR5RKSL'$G
MFY*?'P;'IUV#`X39U!ITP8,Z7=*[N`00FPN,O8FXN]F\8MVTV9RXO3_#=G^H
M'LH@3O?%G)0QJU_BS+)J4VY0%/*EC6I=!%)84$N_^5&6T`QDN[1XDWM8N"29
MU=M]__=MIZBS<#\:"R`>Y/[*&APC:\;4*Q`O<3$Y1"3V2;;#Z%5NW0\<`+M;
M@Y?RJ?"#94J.TMQY7-E4Y")@#)C%XV>3%@Z+N&H>>#\$K=>_@_C*:"<T%NIG
M3GH"I32L=;Y;(QF=/]D@07A@(!,[M90`III@+(YW8N3&,Q-?Q(,Z!7RS-_)$
M1B8B>2<3CFGN6S2JU@`9TPS03)H&P#70C3%4CCK"*/N<8RAFF0C90V"9:EOL
M*%N6T'JFCGP^M$NN5AOI=U^1'9,5X.(_;QF'J>`DH6+$$79^8%:_+N/%(Q7+
M!S#F&0W=EWJIGBLA/6?`/1$R0O#?V"WZ0XY:,1"G+/B8$GST\+1R6!>.[CAN
M?DG6M#3:J14FRQ--X$FJ,OI$8V^]N=0M?HQ&=$4>3DH'UG+I(SO>`=Z1B;9A
M:D0[JBVIVBO\=GN[8F[]'R?;E.TD8*`,XFS48R9E3HG22G9K78L-!T,Z14QP
MJCO5'.N99)[#.Y(ZO6<UJ^LZR!Y+5O];$5!W-TW$`M!/*]<_7YQG_$`*>@88
MO#&Y6>8BW=Z?^=I-K0@GY2M:C<I92R:4"7/W?5&=7)U8'?'`/B59SA7&H,BY
MGT'Z[Y-2LVZ3[XFIK:7_9PP=HFZ/WL^(,:7'>C?Z#U:M#<M(;.@R-+^3&&4O
MB_)F[R%)'JM_A<BJAYU0]?KL^`.2Y!HD*Y/TN^RG_-T[F3K]]DS,W[4NQ"YR
M)$HJ*N?:J[N@&`0\U"OXBC5J-QX-AI_2!43)F8*Z"+$G^,$/KB[@/A<F[-^_
M,:>Q%F^'#I;)Y_\[RQ_B-S6*<W?%4^IJYM\=$(XQ:<1F3MC];I/)O46'^M>W
M4FL;]MBRI<XO9"%>5F_+/PY_5Y-1K5HAF(;AZ14.J#:\I!K3H`]UR=))Y7^&
M7Z9Q`C9?4M@9J/+_3-9GX&!*P6YH*2(9?%,B`F``CU\&J=P#OQ/C2`CO\%9T
M>L&H6ZFL7FUUL^@U_;S1(;;K^".-&4=&L7B.2"=<1^4,M\9]!Z@4/A)JZBGK
M1'9>E%XQ;>1KB:MD_1!251T;!G_V1,;"XNH[-NL.A33C>E^4M[$[^!`^-0X&
M]<L.U.?T=_FV[YTU6C\=@-&I4D]2#=.FK<=NT7HC.Y7\1M'-/?M/Q>T&;K[3
M+PV)`5NPB/L.2IOQ6;K`+MQM`49$."F$W)SN($,[-XZGAMRDC;5&9U(NJ@=O
M#$;-W).-F<%I+D-F:'3=,&[R\QG-$$Q;9'!&MR*]5C6U&%MVEP&[-[%%:!SU
MMHV6.BI_`XO=.@C!V$WM\K@^LK:[3;MN0_/-=1]-O4EB)FD.$ZCP1$(]XE)"
M&QAC=UYBE]NC#\)]&3"7^0,K>)>&N?-7&7ABUP*X=M^I?`"4]OIQK(II6Y2@
M%_BY%!CE<XSF]XYVMU/`]X'&5PWS+@8TMT8>^4>5_AK-!<#9KNJB\56IT#]*
MSGO/1<PDGPPCZ]Z%XQ^HD=BH?!'CU.&5F^GQ>X""B<ZC(A6O;R63MZMB,EI5
M.4F<FTO&)>%",1'8KW_3V"5I^J3$TV14:9XI;"]H3'B0MJ1.3EMYU#W_#KSR
M2)5@R8L741?-8B^'[&XLJW`(L3A(\/S"0B@HB:!6!%P<K$&4KH*_H2]>3_$U
MDBR>';34IL$X[/&FT([^;&5WJH1;R/.OR7'9`SU*\T3*V0C12;6G(VE#8T$>
M_7,SU>MRDNF!`<Z%LO8I`,Y(3D.E%-0;M8!S;$,7-*%)SLH%E@@7_Y0WL[D.
MMBT%6_+TUP95PN1`A3F";SK_O,N;(F5+],9F+[6K4!6F=P83?P#]!1V+Q\U&
MFEY8:W\NW8#3UUDN2N8S<366'%.*:[:_>6S7A+$R@S-$![0J(_%=R(\ZR5TT
MQE/(J=<(RZ4/KF79RIZG8UO`4AL$R+!`8.EW=]YCM^-<?RHCNV/J$PCKA*N\
M*4\RG!M_Z7>)-`89-CM18>/A\,KSZQ@0F[CCVF34?@V@XMX=N.X?S]1$8)#3
M?XPJHT6"4YY1O]E,OMIA_4B$Y,ZI%55A5XIH9JIFT0X.:<DOD4935)FJ<=L0
MA:R7UZLG##HMJ^5UFLH:3K[O-58MT#.>/^[K!W!%_('V*`-A."G=T@K.@3$[
MIC]H2)YA<@,I>.U"TO>&W:::#PL]0QIVFK@"(!PV2;UT']G*I>5'\*E5GZRY
M?5K"RP^P:.WAC+U(9KS?E;K^O*38"C@?V83/U/,;;,&U(AEH]O&.@FCJ%,W"
MN[YL_J]$D\\MSP7DDTHR_ONB+/78JGF8LM'H(H-ALBT07>*W_;6^C1?Q8R*,
M^<`[NDS$T=C)N/^;K0?.RK3RV+YST/.*G6>=]<%'WXQW#\I(C<MLF52]V`%A
M_7@B8FUP`EH:3XV^W(U\$=6S,Q_X-XT])52=S>C(R9CS5%8L0KC";)'*(((3
MGG<&]D"[8Y99=I)%/DDB1&QD#0%02ZR"E6''@9W#V>IBE+`+Q"*56#=`%%DG
M$/9G>E'ZYE/3KL*C7(F=[LQ*ZMX_C\.`E(.%IM]^O,OR,E4:>SFY/_>_QQ-?
M$ZK47IJM?;_'89*;UU8VCYR?.QBS%FHT[RKDT%@&IS^/-VV4Y3C(&]G,D_,S
M$Q2`-Y!PF;4*QVRFR9Z<U8Q&E!YRFE%NM(I1R!-Z,(&,``*0K6T:Z_0$;.9-
M*M7F0MZD&F76!R>43Y):Y7S\3%2W,::;5FN.!>Y0"AX+R6/1MW>,M%F\V&>T
MBJ$3DHF9Q]".+E0T:4QW3!:]/YIZ\(<+J#6QO+ZPH*C\1]MQ$W(@=6:A081N
M7,+D,Y4^F8),NP1XFIN..;4Q);524ZXD8VF7>+>2V;D,H`ARE++RP+C!UG4A
MIEAH#4N\Y!53VOH<F\0JS&#F2U]<L.(:PN'W+:N&AI4BA3K-.XFFVD26/M6>
ME33ZZ^8^Q^Y1N3%W4Z2)291`'D+I5(E=5&AL:00F"5^5;8#WIO.XWCI9/E4'
MGYV5W-C!4-O*A0W[4(1KPK<\P29/'H-Z*2M%>EE@4T@R)9HE*SF>F+POZZ*F
MU.8D]L+(Y$7!>,!3>Q:$X/,GMS-P<&/(/$"ZA#EQ;&$<'JN_=T%7792HM08:
M;6^$?2B6XJN/;0=%R*_'7$&BA>`R7?@X\9`MJ],SSL_&KV53+,*^.;_!XY\-
MZLKR?IYCAI,/QFK]BPBF;/50N,D-"MWFZT$?*YHHXP.A43A;5!AL!1M9>UR<
MB]V;W:"(IYO+0;=_6X)#G@%Z,U78`7J5H=JX,@V4HJF%*^-`D6&*N,:;/65J
M6E1&1('\W6&JES@(C8-XCI31^I0B\.[R<6`JPK>\)-PHGM7V#?3S)3_^5UC4
M#=>\+%+8M0`JKNSLU8PJX=D-0WC_.ZQWLEUDO0AV`H09?N3Z"M5)D^[#.*&5
M!$>B[]%*VS(;DF;A;!#J=CS?Q%M0W+Y/:UC3VL>,:&878&P(O[Z/RZ0[<07]
M`VZ1')"Q\E-^@:]IPSSNC]\*BOJFPLL"5]\J*7M]-L5)"\>X6XG5@C#$)(%'
M6)M.8(0'>-76Z'X]Z2A,Z]DXIIU@XFSPD7$<994@C.@SBO*RH14K#RFFY_9R
M6%+(G4S+WPZ_36JY:NT<KR?^Y5DP\7E&#+RIZM\L%Y]%01P/$WRLW;-OR?GN
M2:@S+5WU2(Z?ZRO'$R'.`*AF0BH.LZUN#^*3=]@W=\ICJD%0HBSB]]W&%_`:
MSK2NV(^7C=JBNBRK7C1V=7#EU%"6?579FT9W:U;3&6FHK)/=P2+0>3*+0!\(
M-%*959HJZ[GAN2E+,4?WR'KB,-@V1S*B.F05H1B=D7CO?)KG!JZI1V5SH+.L
MJ#]EA1H3-"#>=CN47RB"!=]>X\_7%K5723RKTM?JS5)[>^NCKD/BZF7^YI`A
M&DO>84I[@%@O5X3)ARPWT3JB-1P@3!6%XFCP%(1O+9-]DD[=YL;YWGJO`O\>
MP+"-DE@\=()4H$:I^*H'_A,3I"M7VZ;)SYX@K8CE;S<M&WQ!B[Q^'T&EPOP-
M4Y"$IA6]7($;:Q!VC./Z6N0-MWQ^UD7-PE^H2><BA?KE9`K1QG!A.B+S%^ZC
M%'RO,Y$!3<8.Q!(FOF"+S[,[3L`G5R+]@V61`B5?33ZDOD((CK]^MUXJ-!J)
MY`IO4EQFP9@A>Q06DHE\"09-'8SO3^]&K:_%B+.V[$%&TV#$:CI'^;]'H7Z=
M\OG^[I@#9#XP\CX&8W09%3WHI\M'JG5P]C_V!]&U0(G339<O-.T>9;R^U>*Z
M73\>8@;5*(.N$$$V%DOL7IY/[=[%D75>1O6PWD_Q;)3XW(G]CM)M82#@V<0]
M?E;*<TL6[8\\>WB92%E2P:O%9GUAP>.&[J4#D,13Y>-ZQ)],*:W"/:&-*`+Q
M[#G.S+#KC%T,(;<FIR1L&YR\VPX4-Y)2)(QN>`JJ%RN%*VD3\O>AQ)U/U$\-
M!_AHWD?9S^E4%![:Z_BT_!5@,C$;?A2),DSE%A"4$_[IOHS\D;R@.D>W8(.F
M?";YY336;[WAT`F/^P=\N=JL[TA25,"[T*!G(VVU5MJ'E.CLVC.#'A\C&$=%
MJF>%D5<PB/,;]5,%?["D+ADEEW"X`\#(^`2%IF*>TAT5%^UYI^.'EENGV'A2
M)39L[$[<DQPG*D+\:D(M#XS-+3I:1\R?BE?0'G1.\R?&^=<^)BW(+[9(6,[D
M$;K[+SM<+&.TT$&Z?'@K]#2\/NB%DCH8_TNF07IKSB5(`1*Z!J6AD[<'-$QG
M+AAVPN%,W86/M0+^GRKT?XMMJ[4$5./%61A_F['-[8-`YE`+5`%-_:3N5H.4
M^Y&[K(M8TU87Z*$B*KTC^Q\/.%HJ=G-;$(4GT&U!&X+'^EAIS!R.EYPS7DU<
MM<4-_97"GC0>W23/-<<PB1ZV_I7,Q-89"WA\$4VFO5XC_0UOZ/H4M[2&:EB/
M&^_<N:3M+JX-KKV<L?SC_68E1#F.>`!XI0Q*7<6I95%.8?+0%)3IDR5DNZ--
M$(N?M1Z1EA%DT+2J&Y7NB/HAU":C.KFW>LQUMTFU:?_`=Z(^:!A-V*D0H--H
M=<ZSTDCA$+]*"^P%S/]^&?$C:U1%$O9_IZ232BM3[C6$!G%>@@A/4D58X6`V
MOHE^R:CJOVG59:E5&)1)L?"UJFU5)%(4;1'VLDB\9SB]%Z^27T!*(9/]4ME&
M5IO$4!>[!_//_N1;M];O;#<=I3QILG7F9];;93NAN<@;*"%8=XJP,?Q=ZP^E
M:\D%7.?W`UL[3,ZS/-V>&JFMAKG5176Y3<.4:OJ,:G.&7_<U<@$K.@RVLFOD
MN$NPG!/Y3".6".\=24K^=9V"?.^53,#$MD5C53`&4`"*KL6#)KR#XMDG6Q![
M:Q4M48='\9AI$UG;O@ID3WFG>VZ`QF[P23*3`;#'W"QY^7GC<1.$LYQ<EZ-9
M`G'\<>+2ZO<_RTZOYA=H!1^?#,9?D!OO:+#/2_#,T7@.$;[QMA$4#;K04$7H
M"SF`14GDO^/@BY1_Z97<.9SK!GL%-/E-KI>C#$3!\+7K87U94]CZGI2[=7Y1
M^(.FG.&6DUA2.(4A**U!0(7([W:=`=W,+Z+_Q>KGQVW9-`>$MJR0@&*;4FW(
M\(Q@F-+(5;<KIS^N;@+.G;');S7Q'I49C-:<^/5XVIC]_(JM>)!^>I#)O9O"
M>9PE`!>I\E1B4BEHL3,.%//[C%X-:WLB=P5O:"=S/;5,B)&SRE444"(BZ,F4
M0LIB91_$M^%Y7Q7E>Q"0\N^Z66[+">MGCK5VM>"JS3Z9]E%NN)7>X%>^:9=>
M46-8%<>K>O<:U'3'X'NSU[6<BU]7\@@%5RBG/E<X!&$6TC#$UCBMU6:1#^$\
M]\WH$B4H?_!A:2Z.VC(B'^G81US&PF5[9EW1F+#];ZK:\.IWW'`Q^$_JHEB.
M@*L482)_EAW,"9]ILC6H);EEU2.A\L"/))S\R!RV67WS\9+/]#A:\1&W/7M,
MN1F*"XI..C8"&JE]'0@%#1L85:BQ0EM'7SC[#>UX4=*`A,DM&X%BGA.\-U+L
MB[E-C=L2I\OR$XR7^XN60U-XK@X\B69BN92I67#:R5KH8E2_9CSD$\BRZW+'
MAUCRMP&EF$D[965`V%!L!\JF&+?LS^H3R!42=K3H<A$#H3-DG4QF4N*A6ND^
MR<*3Y.06/;^TGD'>70EO1DMIM#\ORW-GC)<22]3E2<3Z(`@,"4;3P<E2".;*
M[7I@R53^FL%RC`KK]YX_A9JDG*B?[,I<DB6-D&A4=:RIITFMV!<N@*13:5=W
M\*,,6&0,;%IW5;.GZ4:.?,^_,0'>`1[H"Z/>$HAK_TBB:^*40I3ZHXF"-"(F
M6>U/G$S"FG.QQ^OX.GE)(+^,F&<HVG"5J=UYL;48LJL?[CD['P=1/D6V/%2E
M!-?$2T=I)]D*WP5'IQT2V\'\5FC``;24/ETLB*=$+8G%"$@B[I^QR$@;R6M'
MW;FPP:MMXO`RV$KY3[$\D':80CAQ1TB-GO1S9F);;3N=7&CDQKL!&`N?5-=V
MTXO5P;=VK7WBF^%"E>@:?<'SC!?^07@YNM2.C^F0=P4B:T]E9C2GQ/0C=QIO
M6E4M,-!!//YSW`9PX'0*IMG-Z1CPO[N;P#"22:4PPD@_<=,X^[F>+`7;Z`52
M>WM>$9X<G%HUH`>Z(\4>+@;!M252XZKIA7'\D=P=^'K=:N&IX8)U1@YQFN\2
MXGK%W%7"*?)'+^E9S:TB4/W1R:%-K5]WPQ6![VV+^&AKP&9=](T^RUKPC6Z8
MA/[W3/[VO$9QL>:TJB((&\B@9WGYKCNI^_RD:3._1CN$MMTJ%TNDO(A@U8E"
M:[:"10(!QJ/WD)HB__[(6UHXJC!VG0C0):&O%TF4;5@6&4,&K"-MU0D?,Y$D
MZ*\)Q$>FJ!!Y)Q6D\:2*:6``PBW!%MI:C69K71+O=GK0F\Z;YFE4X./-L`4O
M[QZDQ`\[V1'KR(6-Z]CTQS*5]S&%%,10T:@9UTE@Y9Z35+?B\6]6@Z[/WZ2+
M.FALUA>1I"Z4KN)L,W@F^R!0FT!<.!5*QS[2F/=`ABJ&GQ8M4C:+[4"K'"GT
MY(A^`3)7F>1Z<#>L.;0?/RC^X]$_%YBG<:+:6K>UX?H)D16I4:WDLA^;?W6L
MT+Q0?M>-+BNK*DN\Q5UE34/IZ6WF)G7UYS?8'9^[F)9X0Z^E$!IF]6&=9%/)
M/<W36Q5^";RRV'Q26=P?-Q.OZ+NYQ1HI&BN7@Y"M_6L_#-1P^2L[F;XY14!Y
M)/U`BY>N6\'CE]QACC//&'YW[FKW06$%4;3W1$CV$$NP.OW"(.5VU1(AV^3,
MOXXWQ_E5*<*.#XO.W62/S&/+`D@8T76'SKP&2Q@\^I*.-7Q%:P+L@]QN.6LP
MGH45&AB2]Y/-6G[WX>66-T8<8_B&2JLZK/1;W<8(W3T%$/ES$<9UG)@AQVI8
M)%6G`&*7)'\P_9AB6-5Q_0?+BV7,K$]RX?+X,[!:;<W00#A4]1%'><:[*]\!
M2JE=.J-X`<>7Z#!;_*NX#=Z*U%("^6);<8I,N>7A@4%1R>)VL\&(>6^>=5]U
MM%,>_P]:^;-TVPBB:NNI`W,3C>XH/+AYSYL,"T?E.^#:GI6G42A"64'R=TTI
M+`/P4HHSE3[!Q6VQS_>,GC2065&#!Q'A:OBK+Q))1M$!O'2$84KP(O),DO%T
MV=8,&=:+%BE9#RFQ6PZKHHV<-;WERTG1P(S9_'I;?4BW-"$/)+(DW2`G5VUG
M&M^`P+'C)K>%$YY,!Q$/IT?.=<2C-A\Z*WD$CBVAMF"O4LRJE^XRB*UZNJSL
MS78YX7A:`^L2692\:G;D#OM_N$R^[EVO*HH:$/7>F(839M4%R/</:;EFMNYS
M/6W,&C`QQ'<?,>W>-0W?I>+T8KOD`,)I/WFR23LV^,?0@9$6,!2CRH_3_#Y?
M:[.]M:U^7^50PZUDZICKK1+W#S*)3*J3&('(*PX,7JK5'9A1]H&AH"YXA'EO
MW2G)_@?N@O2CD.I?[7IK4,:NG0#L](RV%57I^I?+@)`J/(.<LF-^8:QU=<0L
MPQD[1!AB'Y+J7;Y;QTI#8E,JNTR8R1V0&+G,?NF'">XO]5DV+<4KCC\%H0C`
MZ&-,RA[.@*NF81A6$!`C;,KJ^(4=1K:*%=W#_()<::7KRHC(<(,BVX_K33/N
MA:T9AO>-391GY5P%>SS7H.Z7PU[/A;ATI+%/UBL1FD=1S.WVC_B?E0VR&Z<\
MU.YL,'0,OI`12JK[/&4&5+N70`<-?IMD'EG2-Q3$L;`F"5F1*,";8SA3#(V+
MIV;O[J:X]>#],!\UOAA7A]GJBOB;X!ZDS3<NKVC`T^EDH6',S3QD;R"8)234
MG'O"0XG^Y+'."$A8\UIB;#)SC=:[;DCH%H&?7$8Z.LAI/0LB,$13WG,!MM<F
MB;]3'-TLHK,.&DU>Z\5IY7:N)XU#Q;/G*KK_+ZYK)]7,#3*B.$]&I.->XB.6
M=V]%\G=7P)M?O=U8<)9GI][;(-R5:A"E\%W7%@$NF%&5E/@NI=]8:SU&RLAV
M&]&\`&C]R'#25U-6Y*6%*&)/6/P.R@4)K)3)ZY$5L&PGZIBBDY9W3!M%;2]V
M\].+O^AR!'89)5DQ[W6OHKN@?P_ZN#$8C``;HJ6*\%;;2=ED1%Z0"%<M9@4-
M+\TYF9P%;;SE2<;1K%,R?"^Q!(&05CO94!P/S="[AB#B7B?BE9.XHXL5Z:0Z
ME@/Y75:1^6UT1<=\KUWQ1.3_I9AQ-AKI*QU3W7G6?Z?4<UGEYA6RBP+[6'XO
MW443LW6A[%]9V<\R:/,II0]QIID;0C3[*[G+@YH+]BWP_K]=XV"F\]J;]K^X
M(=!AF4N1`<COFS'<UR;7`7<+?BJ<D5SIO9NV\\U&V9W&"[JG,5!,KFGWO9(2
M4<^50'4`<C:F=XO?'"-!Y*GG")GFF3P):*A&EAY,7L.S4V9!V(@A#V/0%4/(
M-^R1BM:79UO+W%+2H:G!9_>,J<OO=^),B2;0'XL90&#%PJ(W0$`5+!%5@T7F
M2;8XK3G<5B03Y4IX2$C@8W[920.&,NMWI_`'(43)_.,OK*-OB.X%N4LWW^)7
M9/J$=HZZ)&_QO3H)_I1.I2D.F0Z$Z$SI@$!(0JG<K)3(]8$`^\/FOQ>GCG]#
M1.'E#V`C>B#ON]G-%M]37+$J&F>ES2BHE_LYFW9/!@@Y[RTS'125PWMB<J[.
MS'<G:[S*QVGW'99>OMU$B4.3E6S6(86$YF_'M7)^U*0JU%<3]G":Y*Q[,EBK
M&^FQPS=Q7X0'+L."[LNV&_J(Y1,;R"M.M<15%%_$T6I>CLP`>]IPKAHQO9J+
M6'9Z."%!1?!7A_&NA]6-216=QV4G%C>VL1%`Z\>(REE`)?;L'K)E^&RT!VY.
M*LXCVK"ZJR,GI/K]EW^1->Z_&G_QA0-.MQ)P\K0F$@:OZH+I/E`9F$F,J4YH
M1A$K/K,877?PJP4`EWJ`4#XI^O/+DT)HF;S`F"')'+IISY>Y.E"2[>?;G9*D
MWW556'G)-N,7DX^E.7FB-E$G+;7=LN<RD.9R?C:1-:&KP$'V`]M;TP%='\I^
M\C(,L'BTWM2H&JSYK!C9+#]!03P^OD0DT%?0E.H-Z9OG0^W-G9O9W619MYYP
M-[I65U)_A@UP5/?P$AD^(R10O"`^:#R[%BI@%Z"'IF,)IE$HJMK.@DN';43!
M*TE!TP>%?42+8"=5A'\6]P$A>ER2/ECA@F8A,)QE3Z:*P5(Q`45_D"3LSIS[
M$$K00-T=U>:=\'QA`FLD41/937,$'-Z:MZ]]9@J8OLH#[,?_32JPW1'AC"SM
M"U:B8L2">E0W`W95:=GZWZT:H]^WLT]>Y7]6WIH,<WP'VY2S_]XI8RI-@]\7
MW/R0HQ`?YB[G/BXW^O?"FM7H!41<2;I+Y-^H.5?(+%O9,0X8.PGQC6A%YDM,
MHJ(?-P.WN&8<I&54L5M<ID+?E<F8T/^/:^=PR)7QPL@2.C=4H$";B-*-?B#-
MOO+[H'P`W9]-][U[!DU>LG^%SOV])_BGW=!3?M@I&:ZN$UV/#C0'RCUY0.PE
M#(L>AI]/*M8H\W,LW@C!^)4&-"/1CCX>$$J_@H90N&\^B5/IR`)]9ATX`12F
M1?K\@HC-%6-)=8/>'*8^XX7(^8@:-W,*MJ)1\LZB,"SROV;";R[5TL$BJ')]
M8VZWKL\GBR"1IBQ3UR9:MM)1FNT1N<<,-KJ6^5(&H8I!U2E8`S#>=APS^*E:
M3NWAT2;X._V7;65K:0P0\DH#?;5=2<-8+M+$J,A"C-C<@,&;+<6Q/:^(DF+2
M@7W%@^>\DE#ZOO_->>47@[=DH0"4[%J(6;>KB<+/G(I;`+M.FZWDB#QF=%EG
M*[.HW7C"+0C3U"F[2+?5OE4L=TEX0)"H9+<T22Y<QU=/^>T[I*V?N4;I5)&5
M;U0L*6%A()W=,C\A=$L37UU#H(LQXO0=68&-HK\.;O#VX5F^#6))Z>R7(UP7
MBPKY#247I6#F:.K&\L/A`%%T`QPF4%@=CBF&8AX]'PU2YU]"F>55M1'!"D+A
MRMYQ;A6ZN/'Y@?Y??B^1NO.L-2ATZ3A!MU5@#VAP$,;!/.JJ=G!H/S#D]*N6
M/U.MS+P=F&J+`@I5=#T]IXQGR&S2M!=4M_+43E5I*.GL]:Q]'LBV$_W$/!)+
M8+AJV][SJ6Z3<PU`<E+<$?B1SVT#\4)F+2%'ZYLM"VCKL5Q#V1!:2#7O_'R"
M*FZ6Z`?^_3]?\N!8Z5[42XY*9\)XHE;=G:]JIQ<B_^ZC=0P5%238C=#IP/8!
M8,"AS)%U12#]DWL.'IN*D5VR=PU#D:@V8**/@I.*]_NU%U[)61?64ZA7UD%3
M`7>F8<%-VFHU&#3&5J?8CI6F@,-W:ENG8+A+5PE83BWJ1U'^RC/*T-(G^$63
M4/_>!R>3W$\[5/44[?JX4DB;W.V_+""S96U1:NRGW&@U;=.R/?)Y[+5$U)-N
MK%KA.=2F00^"SH5%KO#I;`RQP5/IF9A\B&9(?YHF<HZD2LLH1A-\#Q3!\:B"
M98!VS0Q\#^83[6]@4R'>'=BP$.#G;\[NJ<YF9^+7FU00>UE-@Z<9O@-A@I>A
MGL%N53Q<XP<+&!Q_I-^`P[%OH$RLY[YAR@P$Q/0JUB(%K=6-34[&7T;[>T`=
MJ>A+$+:*P)`8G"P+R5.EK?V(CU8-9!%LE)_\+3):A[O)%(Q^I-4-_.$*9J.)
MA)1.18CQ)E/-^Z,<=;W;*J8`K+@`I<?,'KH-]8$-.U?][-L@_L.PR%Z1HEI$
M\$1]&9<D*TDA*D._PGBW":3N'"TH>N6^DHA,G]X?D@9/-+E/,\I$5R.3-X@C
M!4Q1'G$:.ZNE"I>(BE&UT:A1TV8DIY8\?T\Y`XH@J,;+CI76R-K[,Z"H8@3T
MLQJZ^&8$*)R3S%^H`)#[+)G]V"U+AKI09ZU,:[?#F/]8*/81`][37_;Z)Z)^
M?_55@.W4D$HEY_1\'?!35.F<90N]7^W.E\=R5F!J@T*Q"C:\>T$Y>RZC#9<Q
M&`65ST%=K4(`O\0K^G=HI&GEP1>*+Q#=RBLOA%NVS+;*O&P,W33[),:S7$N*
MCV(*O`.7NO/JK,VYG3<TK1"JN['I/+3[73OF;1S43CILIB`;@.+S)F8TV1/\
M'*;-F'O-<(U7_RW+Q7P]X"Z2^+M0]IA<6]LT6R>B?+U`UWFB6G[=#9]W;2!;
MN]4@'5^J5UO2VQ>>QK1^S_SN1J3"PQ]@+X]W\+:PL*J&P0ZD>@S/J;4#)@#F
MC%J0JWWFT@7:*'GPB4J-42WO!"ET.?T)$)8U<6I%ZXOY5KJ&9:4MM06M>G3$
M*&1K',0#]TQ1$*Q^Y0K3FO*61QWB"%=YQ)_TXL.8,F\V^/#P<Y)TJ$'\1>8-
M"F2NJ8K.5`&/XW45]N0?DTB`;[9PPREW1\-[KJ^CA'>!6Q=U;+O$Q4ES!2R&
MCPD+^^4@``5\7F):1E-HA"E?`-UG0E.'IC\4=VWN43.FL0C&I)VPV8_HF.XJ
MB0[I&H2DG#>:Y8):0,OM*>893'$FTY1Q)$/N#3>-]-!C_[^ET4!S%<&])RQW
MJ]]S[GR5\8/KQ+H9^C";V.6<)5?L/J2N[#=)<'9B?6Z7$C_)IJ&`5V"&O>]=
M.TR,'4PIT5CJ9_"V$;47V1ZIC6S&Q19T:EN##EWQ=&O'_>;/P#Q1IXY2&3GR
M&.(S:KY;N\XV+W\X44EQJUX32`DCNH4)8S@N7WAY2EV/#)=1/_S\3AI[99!_
M8D3L1QRA<>_IA5=A$#A4W.!\?@\!)!H"*=?Y5$9J7G)@[#_8)/TU`N1%!D@.
M#AMM#J?FH-?[W%FN'?/D)-:!G4O-L9@FO?;)-:'!2D@DSFJX=.$IB>'1D)F?
MY!/(BED)+>/I)/NV*WA%I?JA;J^QDZ<!7'^VO;GV3$`8#D/<YMG@_MT2^^8%
MU9R].-.<QO]Z2+`"#T;+OI*,L`[J$B^2*LRU'.AT(K=M+[\_7SOUHS/CZ=*+
MH#BA/,GTPQYVX9Y!Z'\&VI/<9$B4'-3:5*W8MO/UC8HEO&-FNZ21](XSL*2<
ME:?`K+GY"^62[./ET$!7W0;.5RM!?/3YWE&'!MS_L]4:/]\`F%UM8F_G8P<.
M_<+WV1C`[R6)`;T*QS3FLW)UG")/*>)O/$\3/"S-HT<SWD0EOV6(@U%TG'@X
M][AIS(2-C?)ZM]N?O3DLG;\;P(MD1WJ6/F*MW5N^$B1'5O`M2Q]R[4X2SLKF
MG40OHG1@`SJ*CN-SG*Y(I84`BFW/)%U\Z>U@LGS)MLJ&.WQRZO4C5H]-_VMU
MR4,U[TU]A/(6,IT:R$/!:_R/P:V/0OQ[Z&_BHVYKV85UP"@))DQBG,!+U)96
M16C[1,P#'BL_$X2JW6<*,!,DO)_<EFI@;KA),-A&H(2Q8O@[6>,W=U)2),T(
M.$S7"'\S*]8#!?4[DS2:@?'#=)T*UWNNY\0]GDQ5^`V".`.501*@S.H_",F3
MF*V@R6X3$AYX!/[_GKB!Y8,X0$D`QX+`.4@SB)$X)=Y?1[B"FSF0?$5RPF.E
MSP]$$;`4Z"WUH1%SQ[]4]RUIXR^\3S.@,*6#^7T-3WFBTJ&\U9<[_?/C7O<O
MTE2*7(HN.ITS@1@<%1'[-6S+6;"`O"QN6@;?G7N42N4;P9QI[_G"2Q=BB'6'
M_?K]O@E@W(O4,G59PVXV>-"?+`TEZ2Y\@S.G8`)_IRU8&JD96)#`K\:;SR)!
MZ;7V(/,X01.6,Z;=&H2>V/"T;P:4,S!<XAP3G[!S2.N-'_V*:V]U;>%9]!-Y
MKTHU%"9$.&0,IB;XP8DT+UM'V8NB.=IE]PL?%_MD18ZL'4V=GF-^&G>G*AP)
M\:CSV._6I*[]:PA>A]K$J:&[EK*]QI[G7H?//0*(70V="7S5SA;2]-]BY$/_
M[^!AT]:H)06Y(D`=LM*OWB^R,YZ%+7R\H%K6)+^`-PBY3V[;X96#0+=.@R\E
MWA$S,7/MY@>2JK<MY5DV[%_EU1+,N")FL&_*H`P$4;WL_-XE@<<T3X\/3%!N
M^(G9YM5G=+K^VRMVR5#)J+HK@H\?XEE#="RR"/V?#FI53[?GUU<!2`*7>3<<
M!\X"W^YMY\W85P4=D>SWO`F65Z(C5Z$06A=HH?RP&'\_[D.V$$(`FZJ;9;`S
MU*F)U6[QR/-/]R7/:')($$'ZN#>+U[3(K-[_+/^^BK>)87"O@DY?8H!>YK@&
M\<=K,65JEG8R&H_-E5_]9C5(^'1YC7L>B^C+_L<RX@$M-SV!-K2@!'KA79>R
MC$.W30&<0"_['"*I$4XS7FAM!1BI%,G@']"JD<'L@NVI<UO%CV^A^7N?I_MJ
MAE[EG4DDIED2;Y%DK`B:#V+T785&HQLRK9S28(=@*9&G";5GY*(DE(9[O0A&
MANW0[ZA/RN.'3W=_FJ>O[NV`_":\EGS-O3YL4$B#V0RHOM4,H(_U*5Q,QU$L
M\3IE9E"*=53A*KT>QOQL:;^"U,U&[5K0-0Y'OI+5G`,I<'EL^!-K.6SXUN6,
MQE"R&PFH>TW("#PKS=),81S\Y@(@&HSAD!I#F,XNK;+KU&G,-2T<60<U__%"
M%\)9'R8=/NF*->;TYL<,1@>Y*)5O)RHFL4*=AXTL9G`I@GM?9928._+KW#5(
M>A=[?@+,II)22#`NAU2EO]QOFEWZ'W06KZJ%(F2N''^>#Z2V32;D],01FKQ9
M^6"TY77@DV2Z-KI6P!_$:^:,R%K,[)BSWUPY*O)GZ5#V5A^X1&-(/_>%$K]N
M14R\>&<+QT>61K$Z+.;@2RVQ''T0;UT9M(BM%T884>)K>0C"2`@X48*^KG?/
M=,/,"M<:[GJE7V%R!TG`,P;_$4,UZO#-J4LRQ%\*TL;H8XA$8V")^LE=&;95
MU6'$E<"0/&]-S";4(_`Z9CH_=-*M#JD1#E0PX3)/8467-DBJQW.#Z%YE2/4G
MH8UE:]/O2Z-;#NR0</A!%E#'2P6TFPZ%AR^:LJU\[GFJJ;FK>LT>)@RA)@5K
M&KB/K7M^BZBFBJ*T':<)S[UO%6LPHD3>123&O4&FF9!O"+PM-21H0!)!J0F8
M7F:3#!7?7R20/UBTYH_K=]EY(9+,0P7SZ!:8]&4^7E^$T*><`&UPT")RVW_.
M=B6Q/LB<-U^S)IIF$1!-SN-@'>HW'(ET&0M/,-?=?;PA,%5@>1-0>;XI?LG`
M>REA3SW_F)UJPNF3;VO'*_\9B=[OETS'RUH),YA\>UT;DXO9=T2&M<$VN*E>
M7FJ')X"[(H2TMF3Y7D?=`)J%SQ#:[2T%B9O-A6_9],*?YUA;3%8S-F#N.,$J
M3R(2\AK'#!P?%!=Y&%E=N3C4H,>!V=>"/XB_`QYRMGU[*XS09YJ%]3ZD7LP[
MTN176X4%,0,5*G<#A^I5H&L^<[_)ARS-$6M9AF'#XP;GUMNI#?&D*29%_]LN
M[0B`Y!UN4M>E9/ZJ1106MF)T,>?(]2`RZ9LH\<AI.B8!W.<OPF8"04.+*6+.
MF-Y=`U?W%)GG<N9E62V@M+V7QR>+.#*./>/3N,WB7'^E5+@<Y!:1CR6U6(9Y
ML<2=G$L<6_]C9=P,BV*@,6@QCAM`:)7.?2S#_U0HIA@,RD'`)KG)HVY/KC8E
M#FOLJ/0X&BC*B#9EZW:1%W;:.W>WW)ZT,]8L^%JBY"M._/UC"CSA=N77M-L0
MD_P'1[5QG-WC\N,DP!;3-R090R<NYRL+ZR4U0O^[K`&<J`(Y%4M[3O:J+L^9
M%IFQBM-'T^#:O8^72)1Z%U=2.LYRU4WQ_7;4"_^(!C-I/]0[^1-A'="]<7XE
MSU[F.M]['RSG\9D<UQRB",F]MK%-"*5PU#-3\>FY?VZ0H#\T+!XM^;%GCSGI
M#@?5&/U&38``@BICKY4.<BW_^2M8_^VF:K+&J4E1;*S]!.0]H;V)%7<)0^&'
M<CU@Y7IJ5LPY9(M%A^Z/HEF:=Q*Q%?"L3]OQ>=:R_S4N#%RQ0<"NQ7#<W$8.
MI^ZH`)U"-RFJE8R2-`O>4(('>ABQ-RL`U2[51SN\9CJF\>H^9D8QH@'92AHM
MX,\2,]<B`CE8K;OD=9;S3S5.7&X9.6!%%='3B?U7-]D-U]A+V`-GRG9<W<:4
M3&SOIJ%S,Q1.^(*"62H`7MHZ98VY@ESR@2>^OGDRC<`VI0!,PC<&&RQ;9&_,
M:DRD*!4E#[TI=JT8J?M]S$W9^R_BT0?(=4O1NH;'$OD^+<W-N0\7R*N)QZV6
MP3Z9A[H7QW?BW'?R&C/YQ'PZJ!)/L23DW=E!':ZC0ZO/%P03$]-PHNJ7,_/?
MH%#(C,P+I;^"_]Y>\^;D3[=.WT2<@A;!FWC-54MHL0!:U#&@E^&P?L#G&*A8
MO-FF$Y:WDNH[(5`T1I+"N_GC4C,3B1B?&#Z)5+PS6/\@MR1KSP]4RX125MS]
M<7;TILHK\O&WCHA7/5XP9OOY%&-$6H8>.U%L=R]6N;&27V/OO].#9#\3D/[T
MLIR&H76Y.GU_26HRY,(V^U%,XG>J04#TO!5EED.)O)O>,#:QECF7N(,]+ODQ
M-:@4&PG5[F9WHG;$>$OJ+,`C\[L$Q`?CWPZ)C'>L"3OB#7Y>RG2JI>1XS7.F
MU<(F_3\>YD7TE7,57>EA1857AP1/4*BJA(_T:-H"I-.AP6AYSQ"7Q,HOW$[?
MXUH36EF_]HX1-KAF,;O5Q5+1_9N1JK;-"@Q3H*38?<<:<"2ALY4<8C+VDLFE
MR>A/5=I!AJ/T$\2[-I-N%1DOBX^(3/P$MW/%S4\)G*/QRB7,MNA-F2U\)*/:
M/]8^V!GJ8%7V"N^7,HT;RAULIJ;[:>`&Y*6=XK4M5ILFG,4L5S-`)7;/G$G%
M\,4,*3LH-!H`.?H(NLZM%T[:G.*D?_*?-E'1HS\-M8?5QV);P`/)M8U0;B_7
MR\R=Q,ULC^7_9`K-^D+Q&`7`_Z)<E[4L1<N;:SE@Y.F30\B_8"Y4!S76G(*1
M)VAJI&*-S1'[]/7QRRGRT8Y$_J&J1'_/H"X/3Z$)/H(IHG'_3B,#%KU^R`FC
M=+T`]'I%Y%>'G=08BC70EM>":R\0E19/1A]Y":*E36VS*"\<^K^C=5*E%`4,
M4`,<(@XZ"BL7!YFIOK*BM$NELM'Z6OYPGAD-Z4N&O0J+)G4']34UG"<B$=@1
M-%M#@IWH$U@>.%B"@GB$R`R1WA-%U1<FB%P@%?8'51C`6&S*_>`%:`L0$B([
MXPE'UUKG](?_4KJ48R>WX;.D\;EX4P,25/8EPP)^O#[J(B,J=S>@)LOY2J9]
M*72Y*OLW`RYOG?&?UT("W@/Q!]0RUH@-7LD+BMQB94)1[$S'&J\)/$-OI4I?
M6"1K19)4R[$E9]]%CBY)2DBQ$]DSGT<[$RLNY;SB8$0-5H)T)C2H=$^?5C=8
M,NIE5[\'?K#LW(+.A!$U;P2UO.5TC^W<EIUDO.PO>5T2[0K&GENUQ!)Y3,`Z
MQ8-)X^.69+[^/8?X<>P#V_L,\%7+=P76M>A**`V31@P.3<,X*]A[B!*2M%!>
MX$TK0S`2\'D#QCK(_SFNS!IC?U"+$"3+&6I1!UL:JOD\+P^;F;*6012<6H7U
M5$#\P42[>CH_SQ:47HW0(M$[_FP*]K!*';QB3"X#^\6[RRJAO1A=C6NSV<U4
MK$B3/=6>WJ<GV5RJA,A"%HW+/IQ>@=@^!1KNSVPLI/[#M,`9SER0<V0M9#<X
M#9@_UN,8TQ[P(659"=T,1;T-V&T<P2]VI[2/GIE-9$[U\JE)3-;YK#5%8_JX
MF(*1H""3W&*=T526T2)7W#'OL#-"H!D>QRWH''!P)P-+<V;Y."H^IY*\0`SW
M?F5."B0S=_-MK)`75@VA6*B430I#H:Y?J:<3=EZ=+?VH&EF<JAA5O7V$V%9W
M*RLPZZS0WN=@'11["G,]+;NZ?PY:L!QJU\CP*(2,@85)^[)G=@&.#_1'LE)E
M%`;V68MP<`!SYG?[W%:68U$95LOO6K11)*AN1))?P'#VG#'*#;#K`0>*1FFF
MB>PQM_$;5]=5PQ,/]9^P<:^"4U:9*IOJZ/7#B%\,-*"J7Y'L'H&/2`63Y/?;
MXE7Y,&K<2W7"DQD$?M$,LB+_7U26C621MI-FO^FBU^ZY*L&\[.;'#]E[!GLZ
M;LK:CG1Z<QAI!=(+_^+P6U5L<T0M,4R<L]]U10>S+D2\QB2#R>^32OXKUG.0
M3G74,!SK!O/P\OKZD\D4:L".HAQ#CR*S!"K3;?L(J-UU&QE"98-<NZO096WW
MKIB9.&17H^=(LK5XH^J[52353S@Y^C:29+5,M(B:&LF)L*`KAKVN[S6EX)JG
MX/(@=9Q?'#ZMZC&H8"2(QAHM=]@7]+-K<TD]+CJ[_8S8P\=#^-U](',-3=MV
MXF;P>(-0J_M0/5[)W.2QN]J#OPS#7VAQ/H)1J^*V\E__4/S_4FH>?H/N(?E+
M:_N[S_HU9J6F>LV%G=`+3N8,RQWOO0"%KE0$;ID?LF1$@2&*I*QFCSG]I6L2
M&I72VOJWM%EQ8Y;'!-A)C_)@]Q"DD\V`I:,39%@,5;$Q941:*>>?XB-WD;A)
M7*&L?J4KUX:LJ\-W'"%SGTST'.3:F@A6YB!<WPU'2:=)S=.-XE)!:MC9.(3T
M$:[ZUUIS&+#0S[/LVB[4D:35*`)]T<GAG?.'?M8F&^_@";E#_6=^B1RQ,+K2
M_T%:.,J"`ZL(D\6N'3^LFSV%^U4PU^6C7+/LJK^X[8MZ/CY[XGA@T79U'LV6
MMZ<VCT9ZJ#,K/E++UTO9%_'+AT3`<V-UPK0C+QM/_XZ;#)/*F/N9G2UVP4ZJ
MT2;.=C%5_RX/E&6!`R)J-:[E',$/%0P?L?:'_]`%CO,$A;W<]<#A(>WG>ARF
MI:TYV(C:&HVCOX:+>`1M"(IJ6-1;*<NO<VSKAC[1)FEA%^!4!\DPL\6H20@U
M1Y$!#4,_G*X%V]P(!G.SKLSLPYT"ZR'>-+(.R(:'L7D6##YR!.FW])L+LW(;
M6HKQ'>L8O/_6E(UK_?"\ZI)Z75"F($>L1VR1ZY+ENTN++G*`1N%(1(@-<C/!
MR$QR9$9-'$<B#2A:==DQ4EVVE*-(H-MZ"HQ/95@BZ]=)G,+?9K9RO6[#\Q0Q
MS`#AE`L(UDR-)_21S-IF7YO#\"6EUZ\Q:\`D+A-AF3M%-B4X/V)_7?1A)':3
M54BW]FHUTP_Q_QKO]R;E5$F*O/^,JV_OG5$]5Q(Y9A]!3W2>:M&FG0Y'DL2W
MMUBS#'97.$C@>3B<WKX!S%E@.8Q56LY9O#R&UZ'1L<W30_3TT@!4-``9;4AT
M-,P%[245'GNLMPLR5>."0P\0CEX78W[;&I_3S_2D#UYN`Q`\NRJU;77>KS6^
MLW[]8*]X*,1]4]V.>F5A9X1!6"39#T=L??,DIBLF^&C:"A]\>CB(VRR$7EE5
M&>:;QWMBNQE#B&\1?`E.,C.8^+'-IU)DL2&KSDX+L];G]C04RR)<27;KK`Z8
MU`C:G@DN.:[@`*R`:XL)>Z7,&LXO[L[6#.P_6N?C4B.3TCGMK-4\M"`%@F\5
M&Z&.>O&[[9>ZQ*:!5L1GS&4[T8;UT7NG=!S[XE?(;T\AR^:[9\;0%-@QJJ,\
M=D1]3*GT*<>PMF[*2``+Y2]D1CW*8`NT.O?C+<"S3KT)&W?^-3*]D=&_;U"\
MY><UZ<9I6WFX!HBI<%/6M!"D&1]NEX?Y_4-__HU1M#7$`K3SY8V(+E[DS1[S
M:=F$Q[5K>[!Z*VY@:I,9_4YAU.$[NI_8\FC\SZ+9&[O'Z]]OL-+-]>B7XWB@
M$$YO92WVGU'6ROZ;?6HBQ9,/,:=5SOTR8;A_L8M7S;^2`^6QIOI*<%B`8<="
MOZ*J@N)!LIE[%D3#_DL^%KXB!G*9CIBV'!1-?2=1518,V`<9,)@F@7-/C]_N
ML&!>&H;S5G\8ML$.(B$=T,M^YI=;K-TR4[?&E%RQ[^E9YY=,D5(UD-G;EU"R
MKUQ[W5PR:;(("<\2NCQ?J+Z86L?'H.I-+Z";OL!HON<A6[P;K/^RJRQ5VYB+
MNU)@^IW1C6:X@.*XH!HT0'G4`8&WQ&.0+.,VC!'Q(\[U>)N\KB04?@YO$=X!
M$.I1E@$!FFRS?7UO"LRJG.A9B+,-$O=8%4?MHBO#T,0HY?#HF#HHP=;<Q*)X
M_8$P!&XY<I7<+:.V+^5!IEC$F?4H2YCU:H((]/"K,D>"FH0UZE12]%/Z5Z<9
MV<P:MYOT@6$_LF3Y2"\)-YB@,)30Q?S0N8!Z?(_:09*664793AYHG@P53E>U
M=M,-SAGZZQ>#ZW>C;?!YOT"Q?KYZ.:K*R6ENB533*L2B@[J=3;<RGN6!IKZC
MK)J=YKIHE4V&OVRCO4L9`"2!:98NZWDMIS*-SE()5*9G4[UN!D**]6/[(@9(
M7T&N`J3#:?JED5<\?[_""]H)"G]3V.XC<;^["_,'C'K982LVV_%M"#V:G3EW
M4V(#R72@3:^;?QH8&(S(1WM9^#^:U'"TWYGOU&#.9A<TCP*5(PVO^[:P(,3D
M(S$EYT7;^FI?$6-;UJYLFSU+!W[V:VLJV@AIQ-"E[0%:5GAU<^RN0]:E^/F;
M[/Z'6)9WD,C]>@3KGIYF6<!Q:Q[3H;/0W)/:.9O5J$VQ7XSA</2ZZ^=\]BPU
M5V"<XX?<GL.[$K7;&F@F^(,`]9%;:P47C=GPDH;8MI"2N,?\;J+L5A]-PEM1
M,AUAQ:`U;_&&%2''+T'['$!LX[.$]=>O`?]$7HOHD[W$%)\F,22Z9=?,36IY
M,)SH\\EV=%8U"AA"T9$A;B335#/-^?6_,LMP5B&06":>A[1GK,_":"5:9/YT
MWNH[\L$P-5:;_@_DR@?FK]\&KETV1Q*L.&69N.,P';9[,.C`/A2&X#-^88<5
M<)5;7[F'7Q=\O6>4`((X0YF$;XO#CSJN*$A(9^^C`K<-0+TB^,/'A1BSW]HQ
M]1E%0+7`F^Q#(_SR80K&`!Z1H+NU(5Z3>=1#IP;[<Z17E69KA2HR,_UHV!;V
M0]BOM.M&BP^:ZES%+B@8]HGL?!?T+-9KOR?[7DE[ZA=0RX5SQX)S8^:>9M*J
M;NH-=,E(^A#?FLD*N9T0*B5K-CA.MD-#RX0LE(!=>VNTX.,6JW&9O,K+N6$R
M1:R0?B]D\GOU!%2,]-\Z0Q$KHOTSIV&J@W)?0^SZ-@N',;*!@$.3\7)%?AF5
M<$VM&]D:<KG"X8-`%PXD25_BCL-C;X%^=K#`7IFG<&@`[EK_'2$E)M49,HG8
M=?1@*O`SN=8<H4NKUJ(3:]6ME\C'8%MJ@HZ"EX3+^KV*G4V5O-$:(N-T*R+]
MR6F>8[%BX044#=^Y570#%#5\_=;I<H,?\KB_8Q_=.;<\R+V@S],YPT4A^OS&
MYAY>QH8YI'>I0:VV.<!N"T2+5NRF"1R354CZ3H_L+=R^P"T5`M;OVM=]!H-T
M7.S($Q,GT`KBVP3=`PMO,/86:&AT&.F!O80\D)<Q,5U_O9E';Q7K%WJT2/-/
MP.#D[G.<N[`*80YK$CRKU=^.G=MU66%++T&H@3>U]H\=G#C)G^2*L^X.]"'N
MHB>)\BID`DI%/VV)00),8I@LHK&=$T3>!YG%_>:&R).%Z^&N\XMQ/U!<20.$
MZ41]=0%H)I_ZY$IF%%P[I(L1*A?I*`#,H^\%6<GA>ZCUREJ8[^(8ZPZJE$1G
M$_^WK3Y%H7O^?BHUPQ=#8K*$Z'^V#5022/.=<DQ?L4FVB3E@.%%V'P/0!T?-
M3HM^?">S%X/G7CI$&6%"IR<^[TW6`4Y]C1L:D&2HB+=E6,MAFE2#Y5-=OG)0
MD?GS<0.782<V0U85R<:%.8\2DIHO"?'J,>ZV&N`HM8`I*E3N$#RA?HH,&5_N
M)A4RVME<N&.RU]@'FKX3[X'R]J!`MSJP_>DT&FE>'0*'I##'G'18CMX>0^N9
M[`"J<,>RA&^>C)R26.U8HP/_\A2FI?]!1#TPQ<YH<(W""2#="_31CK\'G#WZ
M!:LEZ[KF0,(',FU]O;:[6&$0#06RKSL;@6=P3Z:8XP]D24-QMR'*PZ%Z.J;U
M:?1IR$3_"$_2`R62I/_V^G-8OQDDX\FM3%#`F7J?;H.QA+";;M4Q4@R=-R-J
MM"VGH0&2Q(H>NBOK''=LKL;@OW._$`BU=?+28P0=+%=#&.'CYZ]<,BS#&6I8
M;*,CGPEOG=8_,I20$9T!#T3[S2![&H.Q<.*2:X^$8LG-)<KQ&I)P:2%M2LGN
M=`]<]%)L5]8;,MX>S[P?)?`+I6)>3W-#+E!8)F/G<[]9<`L6S*_/N@H1I4%Y
M+AE8R\+X!4(`.Y0>'0IEU%5(`);W[?O.%@G)]`^GQ:\!\SCU$R'["GP8!DB8
M/Z&F`>@>>9^?!]O5@1Y"77NWXE3\(?/@DJ3>?`ZK&+AQ\N!]/J":.-:AD!Y-
M@F-4=#^'4K00^8_(MY60=FPF`J3C:M.7Z?A.C,=9!IGOIWJN]_D"UJ\F0DA8
M%309Y41F.I5/P.?Z;X^*S/F;.[-\6QR>'6SU]>S8KB9SDMN*KH_=&U#!7<*7
M9:+'FR-D1A^4(W*$8LU>HVX"><6_9%\,CJH59&FB>+W:?`$RZ^!7*8SYSOE4
M=+HS/#]P:'`@96-H;R<\/PHG.S\^\!0MFI\#0YYC)OR;XRP&`S0WM;-4D<'8
M5=7HO&7.@Y;K0&30L%]X.F27.,V>>I#SQR3['`-G`A;2\!(@P&L;@NCPO()#
MYQY0/T"P&O<]S.-)OHCGO<('8(N&U%9HI[UDF<5]TEW-.T98<&]2>6,/KO/+
M:YP9/"9BGD]T@</?J:"6$;98SU3]@D'H$%&<BS4DNW3KM)K;<2DW+$%&IUEX
MZX$3PM>14=,9MVR1]_9B!'A5AS:*+\A?[JO[9M:NH?QJC+$KATVG#`S#A2(M
M[T2('8`/0\1\?)R+7YZZ8#E#;>1D^S&!M:N[*$W7;;>8\>O*]CLU@GEY0X"&
M0H`9*M%'NL*F%VX^R$:-D8/N'0C5U%96?4)P-UMHK?HD[(>%'T4`%'R1:*85
MYZ9GX).H1,=)93EA3Z&W(H?N.QG(#;\\@S+QVDE$,YOPYN!T#Y0J4%2K@,B.
M.%$MWM5*@/.TXZ4RUL8*ZLYE.'@[Y],@!R-)$:F?><'*#YZZ?"345V)\FQ-#
MO83K_#M!U*]QW[&<C>[0OTW4,ZD,K;/5`YD)=L/8[N?^PD\I`0(*@O\T$>+P
MWY1RE`+:AX=KIJS#$9GL`.R@&`(T!?;G)`CH,$8-HDLS4PZ:ZG=-O%NT!N?5
MO1*H"@K\+OD+(*"3(<N;/%"1$5]2UWM8$Y.2K%6"1-*<J!-ST<'7]+R._Z]&
M[6"QN4`_]$.PI!1L6'QLF_9<KJ@$U@"!;IDD.6_G%U1H9'UW:9GL[O*5$M:0
MZP1C2F:0]&0E-V1+S>IZI@7%VZ'#\8P'[]ZD`*-2^'@M]055DZX,=*WAIK?>
M&N]T>IJ]CVVSE>;[DV(M+F6@;0+M`_.:#M#D$1,/=7ON_5T351UP$3^FBC"K
M&RPM_<);@1ZWE#6KG&BZ#A%1&#Z\"4IY,UHN6]Q%"E\_*ML$L8X](+F/@L%'
MD>MECRM@E^1XS@_*V\X,L$0HLIHK8.2P+:6FJA&>:,["2[_!SOS:F+/]\O@V
MI;J2Q9N<F[KVXB"'CIX`W+<H9E;W`UC:L4C#SB'+3E,!@"MTHQ8@B>E"3\<L
M4,E-A[ZVB?\;A9>W`01W6DC_%A9?J=V1D]=^P^DQF;F`)E_3N2(=D@_GN@!2
MBG8JU,P$,*"]Q(-^@M-?6K0XSUD'AN1FG;J)NX3V,#YQ&KR!_`S=,F>!,XNC
M;F#2ME=][,\N'>QX5$M^HD,#P7TWM^#""Z^$^"*<ERY''`6,.2[KS?.;4_YL
M>N(=BP-A`ZKAO9W+^;+D*T'V#X\S)-NYK+)V_5<.KB?^./33VMB`UHRTM#FL
M5<W'*M6;&[98:-6C;>6RZ(KL(%TOFEA;]4L6_%JTYT0#3@F^9)3U\*0W>F%*
M\_R($GL#GOG>=<*]/LQ;S&-SUXT96EL7UYQ,KIC!SQ#;$"@@(Q]::;(!'AF@
MW[:\K])-L439"J?\SBE8N0JW^LG.$(?;O7"8UE`]5412ZO'2:X^/8Q7GB'3X
MY'O>R2#%7\704O85HV\]!;64J:"X=,'L,X;;SJ%UY&I^2-JV$*A!4IAQVBE&
M^0#/SUJU:=:N.86-O.CD<&G?GFK;!$B%'TG:[0"5^1LLLE<`]0FO3*RYLG&`
MPY]'6+SOL&^4(%WZ0P$]Q$MI@/@QID+P8/#?QA"JR\LIRB>UG.D/*EL!YP@I
MX6#97?D.KKA+T!FPZ_5QNK0%>YI/)Q^#^=7;$2-S&I[Y.9TJ.-'EW.T21R%I
M1$#G;B;_:>Q,EO%^+]LKGD/"VEN$A4*A[0\*&S]:&-]6"MFG@=79C?KET@)^
M,:*';G(H,<.R:LOT.MRW$A2J/]$0?P>0TA_5**F%H=T>JU(MN.R;L+B4_-O`
MQ5YS$4`&#5_DR[#["G1B8AH29@0"FHMA1VY8`?X?J+7Y#.J4SL1&X`U^$JA/
MJ]S6@-XJ57[Y3[9,2QA=M4S;RT2ELM>Z$A4'BI%[7UPH<:RE$"VZ8WMJ2S'T
M#`N4`</^-846.7('KF[Y6OA]N?,FO=]615?T/,DO_88GY1Q_G^K*\@EDE(78
MZ59Z=U*GGRI3T?J:7?'H-O6R%93T'`=(`_*@H0SNSP_O6S+D%DQG^WK#-MC3
M!U)R2[V2`KM[9=CF2&U%$F<;XV=R1K3O$;MXF$)04?U_*=*HN-Q)FI)>H<#&
M>)+4XD(\"FYQ;^%2=)#46UYT"XXRR1W$1(>YR[>DS%$9[\*CL7ZN^95B9/68
M0",VT5.1Q:A/$,$\E@,K32!H%<5[2R^\<:RN\N\JZ!S<Z'6&E.E<NW:J6(*V
M3T$Z6,\P@RS[J,AH-EUK/>P5+-RKPV2%R;1&8,.6'90K@-3BU&5J1LSSL\*$
MO>9ZN<5FKV]%.AT3G^PS)N?(/8VJ@G4%\SA]`R`_WNUS!L\=<!4?>"M<VH4$
M4YDO+XV(.<,[L>C8F@CD%=Q*(@!FS49?07'P&^?`NLC4+E7'-1WK2B'H2/TL
M_SU<,?(M+Z7V$FID7+50JX;^P<8?(E_C5A;AOG!6RZ*Y9:+^R?*Q*U5T3TN^
M_!,C=E^PXSF/:.F?3=U4$UKS=J[:I9.NT&]PA(B?=DXIXF@,:Z@[M@=CYLA*
MW)<IG`>I_GN'+VEGEJ<NGOMWL>MLNWZVJ98;L[V35/`(_,:YR))C63=:!N<F
MSG)B42M19<YSNR$A)K9'\*VLC."4:<NV1).-FZ9SBK#M>ZK*]D)0O'^>FKL=
MFS^$_XATOZ,D[V+5_'4;B!NHD;W?VIH0YI,9T`25:ND@L=6;7L`]A'L,I4U4
MCAJ(0MH<^CRWW_2!S/"C;H#DQCRGJI(`--,HO*^<QQAUX^Z$]B&T^G&D5R*F
M?R]%E%Q<A5&XD7^Z[*4S9;-.T[@+]OD=%BMVKI+XYAZ\;!/0&0,_9.(N]5O1
M@HO`8MOOZ%'7E&RKN.COWV)0^\:V$I7$6?-BN,'J*7F0!*_C0K2:[$I5"SOI
M0+;EVZ+@IRMVCI+Z67WC@V)R,97SFHGH?^C9+GNN/12AMOA.=[!/'TP3?@\@
MBW5><?RZMX?$Q7W3;`UA#"./6=DQKB0^_$G;"C\#L-&=WUM(CU"V%?KOETMW
M7Z#5UNQZ%*:]?*>4;,2Z)9LN,B<V[-7,M*"0V6.9W,)TLLR]`Y""SR'G]81Q
MZ-%B/`T-N7YU]U"ZUUMOSQ-E3:7OT>22'WX@XD0CXVYWKYWMV?P:=R`MLSXE
M6:)#<[89$/5Z9Y>(#./[T@A?,@;P"TEZ)"K[U)I/H7T1+Y1GDZ.5^B5'\]V`
MF;0SP&8#0M2T)\-2%6KWEW]*6?ABV0Z#76I&]K<395(?RR7$*IO2ITL,>1E)
MNCD@!9=Y_O13E>$F8I-%?>'#4G[^[=[$TQ8%6T]K1S,2U$[M11ZUSLE^3LL*
M+8.PI9V2H?_!B7D0@%R#S@'@7;<#';T0:"";G:VZ0'>)_","]G.6U<I(M."9
M=2ZPMY7*$Z6&5DMY<BQ@"B(02X^777S9A8R!"-WGG!QC;80,:]&\NN4YK=)=
M8XA?^56L/B![U"H+F[QH^12QSG3AZN5VPALP(IOWGGQ2;F7H]:4@T]ZAP]-3
M8XO_@DQ:A%7![>68H!&7:.4.8*`3O`9`DE.]^N.BBX.GAGS$72YR&&6MS9^,
M#F_TX!OS5LN.7^%HF:.S!>5*-.<8E'/TUY;!$V.C%S&RG*<@I6!GC?FQ^7SK
M3J;*]1X>@9'CJ.G/>@CE2:$>E]$D^^M4)4(G!ACPSG76$^'I*!/'P*]QV5'4
MW<)'`%IVI4J>;^(9XCFD(4@R/;\3.AMT]M`L',,F]&4XN<4&Z":RN+X(@9N1
M79ZO=L)Q\*[5X=;)N?J($L=9J?3.P.9GU3;>).GP'TH*KI3<VPJT:N1G#`82
M5,>D']8_MTF7G.-H3.BSV"2)KCKL4#V%P_[*7LEKY2(??8AJR>-IBU*?%D5Z
MM@S<#Z"Q:Q[7J9XHC2\KWNIKP3"RH17[SZPQ7@!'5+AFW]0BP^/WE\7S=9I[
MSZX?<)EU4X_I=!8]`#.*\-^G%',`-_>>`B5SZM+>#?_.CN95JXMWTL+'T3M)
M>5<)P'T+8\0MD?]$-`)0]7GG-*UC6ZH*O0/C@#1KI1Y+2L8]+W]*.GVB0>OD
MEB`6+P[N$1K*9HQMQY4*G[%B%Y+NJ`333M'^@I^K'EU5*DEVQ,_"E]!PN)WU
M9NNPLB:5WJ7RJ+2]2V#90CYLYL\S0CEH(L'NA<X`G/)X.F34=/)\N01@JHG0
MY8QFP>,P&=JA?LIPK+*@Q`$UG^P@.O]<8:S_CFT_*_-[4I&=!X-WV^(Z#G^R
M4PT%E;?Q[T!&;#.;SNWWX@Z^O3=CE!31WYZ9QI0DCB#D$O=-QE;38],XARA:
M!^#)C,*P*6?1.*\.T>R%$X\NZ8&G&ZIXKG?F8!1[I%N<\71N>&M(MP*>"_LW
MOIUJ5$]9J];/KXM(E_MF*_V)3+9(@T8(HCR3#)56R2")>B`(L;N:9P#W]&L3
MK/:7V;N)MT()*<P5^@.*S53CV1:.ZK+!^YU3)*_/^OA.5>/N!::'\`+@#T@B
M3><9.EZ_.DFJAR8N_<U%Y4\WW[IJ):GIC_R.N8$.H7D*J^@C()8#XY'@+"2B
M5T>E"')U?.,*CF7`WTJ$,".XR*F]/#"19/'`,$>YQ34+\FR_?P&5,B<T<*_?
M>)21%P0OK]OB6&?Q-_[XCH8TE2GAOVC4=DK)*?-5%^I2H%CO!#=)?LKYHM"X
M^^)PG'Q:V<X"*^'."NDJ'LWH&K;C`15CZZ;^^*5BM<L@/DR9+/"%JFFKX-EC
M>U@-)^@R#=&N`-__3A><$B)VN6I+YK]R/E^[J\E``<,*#4^D2I*G:$2;Q5;+
MNY7A5%C<8K586%'6`H9PVE8Q&I2*`%`^F*J"LC,W-YN"^QTE!4^/<QR,_*1M
MM9*=[!K@9%BJ0Y)W,2XDV]=Q9Q)['IND*"=X]EI6VB0LFAM5='6J^A;RIM9"
MUZ,Y%JHS+D#-T%OS%C+S&8LZ)-2U=8PI??L,,^D_.G7UN`F4>20.#82K)H&E
M=BEI)"B%$1?H4E^/#^?,XZL[F#?8%"I:9-DQS0R,(2E1\D0-9W[^<G4%GBEG
M"MI#S^J`Q6V^)!<A2@@3OW/(QPM%K&KH<D[T>DLC.L;L"SX0X]-4L.9+[Y`9
MS#+__H?G1*!KA@03LZV>#&#G,92$-$;VV/KT\L92'\J57LPZOWQ?7/IP+*4\
MA>Q#N`ASC#[F_$5<#*@L>LCOI5#2'X[><NP=J,GA"T^%931MP1\6^S(KSDY2
MF\1Q835C[4>J,"E->%U,Z?MA5QVD+J'SJ\71X5A9/HXAR\412-^0M!<1^38S
M?4>^[2OK63SJ]/,`1B'+1[X\?!Z1D9".%+5RL`'&7:SR./;E/6Z%)"QFJ>>"
MLJ?[0&-B'GK1:I[>]5"46D3H8=&N[;N5XF+1,B\;Q&6TTD;JG'86.];S_*<U
M(D-!_%'/N3A76_TMZ:+;LZ@^TW=X:NN'MN'.\(<]UOUW\*+>HG\3]_K<`>/C
M7F7#6%85M.`:^B6!'+]%'V;O@-6GSLE&+&V-\&F8<&K/:S8U,M[&5R&T)D_F
M:YPOC\!6O,-LLHN4;,G/'KYH\^-?&3-+M6J;@^KK7?Q3:3^K'19>.A,.9;,O
MF%6A1EPKVLU#WHH?U?!PK)I":(L5C26H2/L3[2#1D]29"%CL$/<%\W-DA-KF
M>9]_1&P<S>5OQ5.8@W5D<"!3&"[&JNON/'-([:)<+NT!^$5WL,)R/=;23'2+
M>)"Y$9RDF`)/\02>]<<()5!B$.ULH5Y?8BDW`DO'XVV'G?D$-V2!)U)WAYJT
M-E$($**.OC(=C!9TECLQ6RAH79+FU5@#1L&].6U;Z9\A@6L])3H`=Y>778(\
M25[J+SRI9L@$^S3'#L6'6>%6B0:%C4+X&T[/KD_8D+#!6%7"YCVP??,A_LNP
M-1E]VHE!`K#I[E<%&DHO^+5DO@=;B3>%^J<2)_?(-H@HB$D'N2-).2@G[Y&$
MUG<+S&SEYH.%J]A;8K3+6G&'9K&%Z1DU.J.KK_SG@TN7V&8@UM,'5I]HL1B*
M#5A#Q?PVU6R`]"`)K`':"5NM9YE<Y;_*8U><2@U,"(5\KMRJ_'D(,9'BM6@6
M1,9$<)<J`0EH?A._A,9G2N]AO@ZH*:,!Y\CY!O)22]51Z\$F@:)=^0[E_6W.
MF6V=P4,A8ZLKT_%,'#I=&U&AOP!,1`6?8%NFJ^X-TVILP@[6F@W125O16MX^
M7P?&R''S;GKEHG0M*!X.`;2B<>Q(U;#@UEX(>X=FU(.703./A`7.J;=LS0.4
MOUM;7T#[P+QM_'%X\Y/8!Q;D95OPN04^(S&GX!%^%Y-(`-?)RX=<7+XA4=]O
M]XM;+"VN$65P=8CGWJC7*92V2ZK-O=.YIE9Y:;Y6?QJ;\.I%D]X%RYCS)X?0
MO;M?/]E26]6%$+05A2+1>&<UKQ,I#2-8L8K"588D3PKB'70C^3EYSPU,F._+
MZQ1P"DHQE]$GNPA2F512LUQ[<=BV"+>QI+3""8^K=D24G^[ZP%Z30V"7V5D*
MRJ2))[.=)E(P7TO;?62GMCQH^6>506]QHKKFH123/?T$3W-'C)44G.(R@`LG
ML%O`<#H*6!DYCGUCDVF96FMT1SJ.6Q)P&VP[A-%%>G)EBS%KY4#=<Y^MI#T?
MZ9\41':^"`#+W\E9!/UFTBP][TD8?5ON_K9[A:=[/5K-:!;QO$A?ZGVI>C]"
M$['>9(1B)>%'R,HE'3%$RLZ/LU(9:!$\!BLF-DP\X=WR6$RP8:D\]#["-)>$
MJN\5Z9T+*-$(*L8E1E_*;O=JJY?X;B^M8W+&(P]<]7>M3D<G#)$'LOQLO^ZA
M]D7@R8WO4X^^+D("(0.WK"SLYHP'E5/X.XMQ!,2=(U3J%4#OIDE>%P2\P8UP
MT0[&P\_[@QO8H8<G;;_*T:.$+GP(Z@7$&&P3=K+4;)*7A:^%9`RQ__>64ZS_
MZ50PH,?Q?[W,+,`"`%(_IF('@_X_LWLC;9T4\DZPPM`%F.P2AC*Z`M"5=^I=
MLJ7H"!IOZA`+*P:ZT6557KS_6%4XDW0H<3B&RXJ@P@O;OPN9<JS*)^/>!QX"
M2[7G?1?EQ6_"1=_49#*DX!Y(JTJV^*WJAD,7]$AUY<:81*,3,T]]RGLP'%E@
M\%L5QS==>\$FTD<3@/FIXTC&($;#L04V1-&NNGV54MI:+(0@,1)8Q0)()>`#
M6*XK9)XQ1BE@E,%'';G87V/0H^DXYHGNUP\E"S5$HWLO3GQ'BGI^#2VNZ1=M
M6L,.F,8B4>JU0]$JI/Y%JW?_"SG&O0C@"Y&[!5MB[C%RSF5.>>/+$"P&TI+M
M%]*-NPTK>17$/-GV-?6I4<C8T55E+>D5XC7"^G4?,PL66K#54CAS!<Y!.TW<
M(<%AEHX?(&>-ZP<$D5Y!&G-@=7EU\T+YI"<G"[@K81#26J46]TS+>YZ/!R#T
MG/3%_=P8_I6<D2GKDC+&+YSI`=YI-!AFH\V9C?3K`N:-L#F]:4@F=D96TLZ(
MHT7%099#LA<+6FXU&[OUO](!R3#Z)Q70WEL0,O(.(!AA^^#BK-RTU:RY"3'<
M\3?\4?3P-[WB9;!<-/0QD^Y7OB&Y=Q:&70CMC9Y=2$#&1!PIH>"?BM5OH=V5
M7H\68<5KHB@'%8)74K).7;+-]9*M(APKQ3S>EDO739Z8.B/<A+I7,]6@/]2Y
M+OS7M[XG!4,;$7V,>6H=RB28N9?$PF;P7G7\6M`=8=):QWW"`SW2<WM<.9;Y
M'V&)4GUOE"3X*6M3Y?'NT6N[8_X)^\&JH1D&S$C88WX-I0RZ/-1,(L1+U&GP
M=5R?T*'B1#@::O8ZUTJU#LHE-4'DA^S?2D*%)7[B6J"@7+M'4B?M>5G#D,B[
M+>D+<S"ART975;.E+9*3;Z_")6H]CXNMMD]'UM?@K:>3<(\M$)GK)#%3RY-Y
MRK!*8%5?*Y&A+@>DE/9;!)O"[Q+M]#MF26+[Q![&[/.8(<!RV?.[E.>3'W5H
MOJ'N7CR)'WJ#Y],XR$5'LRA3PE^'LX9T8679U9M,'?;6&%!EP$WF6@HE.F*U
M5**5``TLA82YGP380$4[$N/T<J>X$3G>81%N%LM);"WIK&H!&<.8KQ-$FL,V
M(HG\-_2Y16"20FP2&WT!@0MA^A'_009;D6CNNSCI3+STJF`H+X4XJ@)RL":1
M<1![;<Q@S_\S#E.A;64$1ML&6;4W,]61B+;OIN#^P<55N8@Q`XN<9CA/L9\7
M+>E!/*6'^,L5T(/"I4:!!NZ_\A]IQ53$7QC:5$!KJ^^:0HN0L*8,;CNRZ,W(
MIPY8Y/T2`5JK)[BVS]H34O"O7Q+DA=ET?S_3R[5#>*W`MZ![?+0%9=P33]9G
M?8^0->%&&?Z34?8E"NY_#!K)\)Q<'#^*98&.RT-X6\;DCH/">8T==7-493)`
M>W4,!GO&M)AY31K<X6@%L"G'Y3=.KM3693&$@<1K'&;?Y&=$<<^"&:#IM`E\
M$*0U#>)\M8:J<0]`;@$<4ZG#WP_.!W?:'CR)=,4$J)ZA$FV96HZX-S%7@B//
M9O`YEYB`NKTH5ZG7602`]ZSJ"3>,#$T'4TD(SFOR(E`LPX]E>`3B!%U5.F0<
M"'74AN)5SKE',Z>_*;889-6J?LL[G5N^>,#E2SK[WFI@Q>O`?N$Y<8/$X&O4
MPG80WT8X3)\+11:/K_V03'T#\_R[%\"=]2Z5S[S5[G9F(0S1X>0+#!I+D9X=
M6G[P:934CEN;I74%IX!\%M@O`X-M(Y@N=S66:/?#4TE2,XH'DBA9(!"Q5;+D
MF@'[(43TN-X2/P`*"TC[+5`GSZ>@@\Y_)@WF+IL=$KG\GSZJH:S'$BRB11M=
MXUKJI,OB/>\.$57CD-,1!J>=CPDEB=-CK.&!5%(RA#1!*<QT\\"(1M19RN5!
MP;F/?R-+X'@:X9+*RY_XA.`XA$1Q^1ICG^Y,;AQ@91)_DUMS)#V%J=`WA1@6
MD'=R@TC+.R<^_-WO`A7MDU?C0O_^MXWF8H28Z[BNW(>F_7.FB'Y,B<FZ4Z->
MD@(47,2W"+<*0)""5DVXZ&_Z<+@6_._;R9@3?%^R^,I90/1\/OM^6:RKXW^6
M$H=Q6K.QYXSLX8TL$`U_+T)GYMU6Z]?@"0\4>:&I.T+\&PJBQ=6[W190<%;.
M(,Y+Q7K1[.N_SCM3E.IM$6^RYPF'Q'9`CTV@/YBN1$9]NTQNF(CQJQ!I5L%C
MZMB`G5XXP#-MFD8K&_1=Z;)Y8F[(.V"6US03H]:'&[>=N6_-3*YPM9VQU;-;
MR<7E-YX*3$3D%YNG0_D%\^DJ;OTZ3)V<*NT.]C)(5O8?@`]-T=8='7-$%6KO
MOE$NC[!Y=][@_2+P]\314O_NT\Q,WB?RI#APPSL(%66RPBU'*WCA+5K=:VD)
MG#NT"A]W?J'M?FWO@)(^4\/"'K0KJ.:^PK%CHP03C`[(ZEE/6+(*M4%ZB2(R
M`3_^7GO3+4G9#>CC'U/*-F[8TSC-JH.3*S/"G-2Q.F)OIVG\F>R<B[4?1/TK
MK=::W0;*1Z1T/:O::2X.@96>5C=11LZJEVMXPL!)$W=;D4Q94DX1[-CSOO3K
M^2A;%UD%%T%?)',_#_C9\9)-6%P(9:8N6*<.W3GW4E]//8P$ZIW*:]$,\X`X
M:H'<B&5C']/^?0^4Z41@I4>SW4)=J,$5)WI&:0CUS_<*`3,?ZG`.X@A5K%_6
M>\:\&W;A?!*ABOBLT98<#[7^W),H[`I84_MP252XM$R<OZ/J><#X%M#/0L0D
MR6$!^=F*QALJR]FI!6HM?K@?#G72R:G8/H)7-QH>Z_DZ4>ZE2,<V-TLZ@@J-
M?CTQ0&'Q/'DQT7Y@4X!VB"303)N,V8;=?L=2@1W?$_H^*Y46'2V'JUE?D\U0
M":LFW$)P6R$9$.UA?"[0%]WN>WF$.U;KX.74DR!A?F;^!YP,I_AK\:PW&*Q#
M"ZYI$197]HFV/PXE2:46[(:!,?A%E$(Z4*$.CIK8V[=YT>YGB(FKZ>5QX-W+
MY;`;(*`#M@=J-W@T<<1]C4^VO?0G((GQAMS9(2G['39E*D_\\Z8M+S*XG^#H
M1*D9GHU=T3&Q+TU.DO$.=^B:O543M'/&P_1ZDY\BIA*TF;%IM00%7X(`FN"H
MMNH[#P*<P('G>+!.-<D(#B_,=JR9KTD)[`8B]1N6.F:*6&@_ZD6(Y8?>51N$
M?7V7FG5$GKH:#G4&6]4=5[D1N@!<K&<D<<^Z(2=L9T?\C74R6("?`&5>Y`>^
MB\:%>,\,ACH^<AUDFD%8]6WW1+X,]K2*H8FP,TF55)4VW0MI=8C%L0,+O)V9
MF\*]ECHJ`&L^]'VAK2B>K/,Y2D,L,`1E%74'N`DQGBHTG0E]EXQGQ3.["NTA
MB08KN-04#6*'>9BH2-?3XU^**WTBUA^=A;Z8<$%1J=!6/)3J;8>WZ'7Y][4$
MQ<<<464QTF*C*/E@)N>82<U5)*PE<U&XO9DR1..4?SHX($OX+V?7%C295O)S
M.7WC:(\[Q5GA,JV@)AQL'KE[O*4S:&9&H<'PZYV"F8,=D#]2XD9#85A.[N($
M-A@8F7,!^JCIB@/ZT[C;5/,9[J">B749*3F-9ZQ@R^4U9[BL3MFH5'L4(F9K
M=\6Q#?CC$C);35RB!&[2ROK_"K%VCF8_Y\P9HX2G#L02U)7:/GD?JY%?"=&#
M[W)%;Q[$)S)#PZ-XC>@P1@G14)&T(J0\/:ZK]V[MN]J`-N4=LAYQYV%^6>O+
M.@O=%]:<M=U/E,_86)N1E`4KEX;)`_ZF5'#'&-D$(^`>LL@76,VS&D]NBIB2
M+-'$`;IQUTL79C?T4?K<A!(;U/>9:-R2OVWMV3S>F/JA+4_I]@LA)$C$:4Z*
M?=9AN(HOLE!1]AVROH<:^_X'P$:BO78T\X_&I^N=\?AK^%X%:I_\'Z`?XP&;
M(BL??Z54[^[D\NRF/+_BV%;!GE*OP8&HTUI+U./O,H#L`M4,S"9PYP[7?;\J
M)GDK#TK("$+B,;.`_\P__;-P<R%MT[5;/>3>+.'(.V,;PZD6;H&*;<I>`"N0
M5METHG_9K(2PMC_?U<B4YKX*:O,]*+G_$(';-A4U-XA!8TAUL]]_T]8J)%@^
MOG7*$5E='B],G=PO)<7X"99G/S5XO<431HY7KR"?ZU`7#7+4M%VUYB4A,U-Z
M]4N=!\98^UV8[@TH;1?"1P_\5:<<B1(M8Y2Q#+78'15UKT59H/(IF`A!P*OO
MT7=1SFENR5FH^*5/R_HGZWIL]$J*DK07D\Q_?+[$T*SV%<_B&UJ4$93XX3<2
M.J@RO)C>A!>,<RX?,]?`?%#6("4XV::I7'024Z/XOC1P3/);L<50#V@9ELPT
M\8Q7_<V.`.KW:M441.9(T]R2-'OW%'=KM,QVQ691[Q9:+IJ:C`FL0+`Y/WZ%
MZ*P)EZ&7>JF\(XG%Z&TT@2E$N=:9D0+*`8P+IB\>YU21$L%Y3S5TL%VSD/OZ
MW(-]]9(&)]%[U$Z;/*KRZB4'55CU:HL+Y6\LT55?UA-PCEW%$RLWFE321>/?
M3Z<ON'"1>N]SOS.@6QR-LBQ./?)]>[/5(!`IJ/BBADKV("%'WR!QC9ZQX!QS
MUAL4Z[JWUKDQ/:4^F?D?K6RKIP4<"O,R_+4*DJ9.[$>(K_`<@OL5IM8A5OYT
M\:IBTE"S'6,'2F892'HNYQ!Q(0=1A_\K#7('',WASMY;LMO,(HB)+9%XDX/R
M]">V(K+U=A>)HO%6'C0#JWK/$:^3+`VM\+E$#^-SDP)WP$I3U+Y73E%P%%6.
M%WV+;LQW.K+I,]&!"J&B[KT$2&5Q:*<"KZ%WOZM&ZU(E>G]V%F&7F5F7IK?D
MU$H&1_^D*\"H$6^5B0?5R\+2PL$LE5]8@3?RGG'T2EB?Z8D<RJR^PQ=;DU&8
M:[W9_38F5M97(4)BAL!NWX6Z`U6Y$E%^S@PED8I5RS)LE8-!+OR1`SXP\6[!
MP-2Z_\L*YS)5:<-6K]I$&_9KK"!Z5W(X22Q!<W(@:?36$%YG"ULKE,=M7++3
M'NVNBKC1*-(]YAFXS7]CA/!LE_?Q@CH:&X\*@'$WBD()D1(L*='FPD<!#L@Z
M*D3(A)`6XT!!$.R`3+CP:>PY-E\ML#ZR'1[J%9HB]*!!$GE'5>=!(_O=+!2)
M2&/+=7L*,631W%<NIW8R+T7+7P#*,;-96J*9DO`T12NXLLP21\A1DAQ5$HMW
MG$XKJ,O$PD9^Q784"Z(H7VI*;S+JH56IA^K`G"3N%SZP&,_8B'+MZ;XQU;?!
M.8-O!J.0_=%/*,)-.@*NU^T=<AD;GLB7$GM3]5J?L=ICVS^[)XL>+$'8S;`<
M&KJ74)G<6T=&R3:!3A^S),/R?Z-%L6L4F]TD4^(`\ZS#_-F<*SMX%E^A9OEZ
MQ<FH]5\BD]J)7YI?3+["&@6'`C"H=,!EB+[IKUEU&I8$D%%F0O+[SK3X=-1@
M$_(R+RQBZ^^;-":D'ZG,88:,]'GC+*[I(6,M8@*NYZTE&0>P&*`M,ZPOHF]2
MXN4C-BA8Q)E0E;FM[1(#@/G*GM\.&^@#`4`^NX;]_?4)FN0+7&;8U3V8.%&'
M4NF*I'/O"WFX8_25J^IT1AV5%]P+[,4\[$/U=O5,N`S,E[8`R3LDU^YD]XZG
MP#!W;G*B?`?H"0<SA#=$+X@RW+W8NSXL/(5DLW9(IMY;0)=(M<]]YFD:=!"B
M_RN%)[-#K<&Z$G@<Q!9^#[:DZ\-L*JZ"?M7'RK9OY'CVU.<_REML[7ZCF['\
MA<5=ZN+>2IT6A'`PVHL$&5EE]@/^)\<)3LO2FQ'^P*JTL\L-N-H2RO0Z!"2<
M:'&0KWX.^A<!YAL&\M7O&C^_^@8_0/;?2=U&HT[/;G6]''2"&/3N[O3IQPW]
M/K<<>5&G\OL@7$;('#M1="D4"HGMI`C<0-C_@:3S'M%&^A#U(]CY%T=*WK81
M#GBQUS>;<O:YF<U+D#8<`,FP>PUT'OXROU(;`BG_3.1Q1_5C5VXKYAOED7(<
M84IUC,8':,&7Q7+N$H+B5:DCBT-QCF>V;D;:O1V)B$*04'4?0\S\[GL!&0.?
M3?!'V/Z%`\K,H0RC=N^)GT0=&T/!3W?NRHMQ`6?2X0#N[A*7499H(R'NX,9\
M[Y"YH:F4H$^@VG>/UPP0E$'8=ZV$%12,!?D$Y*TB<IMWJ4E#B6^94L?`V5GR
M9_FK)_P)#$M:_4"=DRL<>H?$$$G_$AJFOTT>NQ0Z:1P8BJVR3'$`7B`(B;M9
M_-4VQ%J_KAP7.,"9;]01`DDFRMJ_3)"1!RTL]HU8[J`Z,")[7^`A\,X;M]V`
M9$8*U<Z$YN//YI[P<=&4L,J]4HE2E'%"/9GSC8@*]:87<U-:67]X"$,1=]X_
M#$B*(Y*><"=)&M)0^Y>:_,UC@U2.YC-X.*9SE=;_'78_"E&5U5E.^#=]X\VR
M@^(_P22QC.*#'=D1)<^]4`Q>?<6E\F.2QUYQ+#T&XO49DX:;0Y$P$"U!N>\[
M&V,2$TX>WZ=6D*>F"@];0[XD7N</[W/.G7<&*_9(G%<W3*9@(\PW1$-Y`7T%
MZ><E,0<FRPLD=PB+.#L%KM-6HY0C1#_%*Y%K)@NRW;H5'3;L8_17L@,74?L<
M5$!*\MU#TKIVN3+='//^:\\C"KT57`@^D0_M[+EIXK9`52<84BRMM5F5<HCS
M#T92D\/Y*50MLR_=L%KW;%^R(FQYCWCMZ!FVEI%1TUT[Z&!MX`&QB,9[W.U$
M(46I?$6T/<:(C7HY#[%J21S4KZ!Z[R!*>][OH":JM&P=8IS2=I[4'YG%%38R
MG(7R<"9B,@*26>B<+J,9*0/D",^:+*0(VDPFSO)URA_/.&&/K=^NG:(9+PVG
MX1HJ\C@I&@+TA/LX<PLA:H?YJ3$6F0"<55))`#/UMV/(&8Q"/$V&O83.H=&`
M0Z2^+"A.`LD\,/$DB7]U@";?#^A]*QJJXX7X"5+]JLM!D$>J&0TZ9,)C*BSM
M'H-*!DA/PX)T$^6D)C.GT*)Q;NKM3O?R1/GDL2RR!ANF._+*03`_3<M45WGM
M>O.GX:M*MB8GT"`IH1VC/Z.#9!5W.^L2=DMI)JD`2WWV_+,%LK,=[1+CI#HU
M+@K\D%U)TE]MW,NI)GF;R04>Z5S1@,I+1S/0@X?Y_,\4H>X%)HT`^PY]'C8X
MS_/$*JU3^50S2[\RXG0MX#$Z,79_O$`TSM!]$XKS<JCY#G&@JV1E4O^I[WHP
MJ)"\(.CPCPE>Q4*/I#2L"O(A&*M"?*J2H6FAO*6RUW2"[C>V^2_[^:$\&?70
M?XN8*O]EC%2QX)W@D4<"5-R87H,N:B_\HR/)_VZU@_=<-^SI"_3V7C7&9Z)Q
MX;Z"P4[OL-\1*@"]P&H[TGNJ7IAN*I/]`<K/BD7(M@;0(0JC77>KJY_2CL)8
M/+A5[[K_EL1KM05F.G)XYY03+SSEX#\S^E%JU]:)2GE6L2,_">2VC(<NDRRS
MP%)UA,#>V;YW*VW7K9\E32T@7EM[7\\<!5_A>=Z+B/6X[06[ZU0:2,9%7YXI
MFKG:IY6M-%<R:F"2'@;!"2?]SJHND1VAD,[KNB$U2?Y927K;$6^`_+!P56V'
MBT9*F7#0M+>+-2=C\SI'$CI/JQM2WHC?M>MR9KLMW<"D#]IDKE*[Z\U$)T6Z
M7YL,8`^B!J6H*+T6VH`PGNN%I71$H?[6I6!Q\(8GNLKRM4'R<NB3K6UCP'MS
M"?!YX)X*WG>N&&7:&W>#L&I_\\?;-[R9LR+:&DL&[O0LNJ>V>X'-M1(F"1"X
M]KWI<B1K=*<E%D7I9MG"58NA/MY(+`Z\G\:Q]HMJ"+DD0Q6DI+%,F"[>E9A\
M+$W>L'4YQC6Y3<2RM)6<%5'_H1M\V?'5;I'W'`WS9=Z^]$4;,&*G?)`24*F*
M-7?AUZ(@@:^!)[22'?7;>;01H-HZ0;NO[6MXVX).TK8+9/A3='!J4&3KFM#]
MV5ZHUSWZ[2;[O]EI54/._9S?'Q>A,D\2H*5-4WWHR2AW5K,?AZ>FFN"GPD\]
M"),UGT1\`+R+WUP)O1,;0ZB8G7:#QJ=[H"?'+7E$QU;L16Z/Y_JQE;%O2*&4
MN1^`,?F3@YV"9[?"!CDN,[%XR4L^B:@FUZ39H[/Q/R70#+(?9IJ[2Y022BT=
MV2QKU3X6ISF$8-%Q;_<V\GE=S(5;+O8&ODRNI<<#SWOH'F0QZ!B6U(=0^SRR
MD^-F)!Q0=,0JZ#X-WUGNJO/61(`0Z$^HZ-ORF'@8M2]=E/^0'15B@GG[>XOK
M0*%>+1SM85P^JL,7LC64,P+9[!9B)_H?_2B5K_-@"1#ZUXU5\K4E""!CA*N^
M5LN2U!8Z-#1#O]#V3ZZ,5304UQ%F+7Z\2;1E7TM@-EHS>:D2OJ2:2+VA;Z5X
M#R4>Q,1,2]_R$J-R5\%VS'],Q(]L2VYLK8-2`$/4!]&N2V3N(V]]&:UA:I>*
M!2/A(7\"+RVM[GMMY">3L-HE$[-F[*+)G!KP[9I=YT/87Q?"F,2ALPS(T\/Y
M_IO16E*@7UD%/#HN4R&MYA"!<ABE(E7."XJ(@SE!X$PK35'ZY?.&K%R2:S*G
M@\CXA?ZK!43,LQ.F@E_.8)S>\9M!RI*V3I2?W8DMS5VE[`5W%R'1H,%Q$A_0
MOYQW<%4UY>?QB!II/.X'MZWQI-:66XF%!F@D-Z3X=T@?&BUY79D-TE9^1VM9
M$:FEURU%]41C-KIOS<41E*))E\)`<'!E56[G\[39`(_+05?V4&%*L4&P?P5^
MOA^ZP=OVIQ#JPYJA%BCV&J&\''M)0BXK]#.(*=,RF\2L#-Y1:[ME0D2@[Q![
MTA<VZ`GF4N/&@W6Y_[JCM+@B<IN=D-:\@J!X5F=RDY@HE;/%BC^&K'GO@+Y>
MSL5H?L6BWZX4+2LH>:NKIRI^A*>`](E164;U9H#7B(0O/P8/Q0RU!!3R]]^-
M'895#Q?*D1RPX(70O^"]B[8U;:TC$\34P=YCJC"E.E=>7751<V/N?O<]_<`S
M:%BGT@5)81%^I/;Y.@<CZR8[!\%$"J>[U)?L;W9,L(J+@UHU'$$KC56TIAFK
MH?OO^`=YQ'E-"2=)I?6)C2M8_A_Z:4IN#)X27V7]7+I+7R'C5*PW5]S98)+;
M.J5GJ\^R#M&D3%PN0\0&U=*&MS-AU%<V5>$)Y'9TGC'`D<5&QV$A$EKDP9U9
M7,+K`F+V.#RJLR-2!M_P.+CF$*(9]W?;#]*2"]\B%A7G$@FFV4<$Q-_<I>NZ
MO)T%#CI2?1,7HD_\?V-G`G.+OOT[&)\,T]`8E/I-Y.8.WD7,XIB%)O'<G?Z7
M.EA%4_0U7MK4._N`K2;@KL_B01?SV>M\L:I_<^`!<U`#')9DULJ`R7..R#4'
MY_Q;RM-8D0<E=4OK6_#!.BXOMNJFC:.D_`3-2TR%+UN[G#NXZ05\RTSSB5+X
M:I/'33K!I<!CU%F#E30^"C_'V=HV%X/+?^2IX["YX`V!XIFOGVE>Y0_VE["Q
M!W]"@<IM\DS=5^:)EP!HO9X`SO'55^^`(K^RP.A2J<;TM&O`*:RMBY8U9*60
MT2:(^KLJ<;O<=.5MUL`VR[')7$<173W9CQ).CP/%'K9[E--&&(D_%;8S6RVM
M0QW+8R$>6-,1:3\')=:M?-TTZT<.%BV.B&'5W\CN+.5X6@X7^"CGN?A#_M$Z
MH7N_3NCZ^30`Q7M.[(N)6/\A3K7^_Z;A0U%$ST1?L`9?$KN07WO2!VLZ8[5G
M<.#IJU:VSUL(!A/;GK[Q1"IY-Z`+8HR4(+-]I\"MHL`]W#M8)1?CTB&\7!0"
MPJ/;A39B48R*H9.JI2_`J%_A\O3+5?C'<Y>B="A/G)Q]1=9.?IR&<:7.UFQR
MGWGR`NI8IH8:^J!OD?3WNRIH&&*/VI-4J[(.A4-MU7&9/X:=?^E>Y),E2%$:
MO;H/PJ<`43CN!)8OLE4RI>Y5K1RDM#XA%_!=4(H`D%WK5F3O9M,*TOLN4=YY
MVA+6(<%!V(3>0/H>.LE>DN:\R'U7#X[K5T4`C1.P!<MCX&;'EJ>C]];J0<$1
MN*/8\&_\%9$;H+<AO%HC[Z)6_WS_X!S6MI(>0^Y?:>\6D!^WJM#L!0LON=)W
M,ND?H9G^0=NRVB7E@F6R?+T(EQ]K?$!2*%L4<"0TV(V9?)6D4$A?'.UVP('Z
M7H6;>T`OL.A4[5=NU@[)7%HHBE)19?M6:^JU56B-7Y,'U<;M".R^9\#8=M00
MRR^TYE5];9M-`9BH.Z?I)\7>DXHF)!["B.D8`XZ=6TIG]<F1S]3NILW0>>#0
M#-!5#S5""#;^9[N'H876"FW?NR&GI(VWRSQ"&C_4Z0Z?U"T"4M/DPL'52V[L
M@6\_^=]LR>%+2X<(:S@ZJPK:-,'),RN;OV/4^\K>+06E:RLG,<[+6B<]26RM
M&V2[`;!BO5Q8H.Q?MF6JO<>/(GD+89L;3T?[,FPB%_B0IHTQMWU>/9L?&&S\
M,)(B8]08)H[FC+7><X6BX[M[:?JKDG^%F45LOL`^J@/-S^'UC6LS,6M(:G:1
M\G-]^W:A8&DE1A4TX0^J))T^U;S(HL-4W.DVJU-RM*BXK329G,^CIW5'56*5
MITFUJ<R]*HECZ5IA+D)L0[.'EAMX+KYY$(SEP<8=Q(0=Q3F_]8W.PY8:&?>S
MK(&D>Q>K7^/@!I]ZJ1'[$U0"C#)V@$AW(F<.^>+RP^C&X]@WD13$)A@I7:AH
M$.5YZX?'N=>\;==X$-0F#EA72<L>YB*XSK$"VG*B+\R,V0-D.?C$(8C1:&#-
MER>BK9XG&]TLCE<=?U'M:0Z\8`C*:A8>&QV&YH_BJ+FL`J)T5Z^2?/HEC1$.
ME0GYK@O<,(.4#<OEO845<&1$'$%;*9;_&3QIG[OM2F#UMLMRGDH5TB)*@+81
MNKY"[CU^A^%IKIWIXWO*KAGK=Z0&FU]B/MDD=9:')`<V!`W<7!J+DIOO)Z"6
M,+RBMAMSE9;TI<P<'DGJ:$4P!9^B%_JKH'U@#>\F'`B(9B%&7^OT,9N4WE)N
M_=03C?Z?YWOP_ZC=KO:P=:^)MD49!06HE-HU750].@3^"G\5UUY$(?^L+X%V
MQ\+7QE+61XZVKC$7#@1N/D[1?+?U`<VYGI[1&];0@8[@5+G<X1Y+N)40/(;[
MP-3O1!>_+%W?O*Z!WM9QKF9B.##(0N(O^&T@A&-_%1HV8`:5;V'A,*]Z:\]G
M#%O15D.O*0,+:=R7-6'/T@601.4.;[>7:E5,S_EY%1]4@%BLG936.(\P[7\D
M"3+SCF!+$Z_P:"N'.V[-'M2`%IOR[BKTQOES9:'7BK8T5$@6/29)^9I$ZB(O
M(>O7R/")A0C,S!VE#WD*(EXLTD2-X:YK^/0T(`>KRZ*Q2(=@FQ4#@3MC!Y34
MG)@`M<._+C/W(=C5E;03XDI%C9#V7E"R7_=STBYYPL<WBTE("PX.EFJ:+N2Q
M3F-A\[B[ZO8\LD24,,T(_^X"-5LHR5M)DX#VK"NK#WL\A<KF8'^&J<D/(89F
M^6CT&R=RU_ZE+0Z;)!WF$.;P&'?(`!N],V"Y0+:8&OI[RS#SJ8V[@$;!)VZ3
MH&*TQ52+@G0CW"-WY`&G>59/>K&,Z65^UD'?R(GUQ,&K'2B8BY.=X?S0V_;4
M+H6S:M159!X`CO_V<L4KF./\07\*45*K"[(G!%Z2)/7G<GYW!]\VOY7+,^XX
MC!0*TZGZ)0@+:GZ6QK_;@E@'K-KEUKSH(/MV9#\<0CWF,SE2C/SA5:N_'#]*
MA^OCT!=->IX6NTT3+=9WU'<$[3`^BC#YXYG\A.A2M_JA@YW_^<#ZQWS4ET9!
M3)JE:;CU;JEHMU`+7IMT_FD+F=T;G\)@.M*_1UT$0"(2@ABF:=WY5=-\GV,Q
MG2U@&EE'Q?")8'B%(`:>05'[V(OS.FU-49=V`)(78*DI/NXKD7[4.1:FIUK>
MDP&^6$U+R*`-#O9'Z8I32\/V\@!<<6%:;\>B.-QYL+",)F1!E5W6:4PG0^X&
M.D'M5(:`@2YW=3-DR!VG+;(9>:ZDO(F?@RH^O4[1*+6)Z^&[1FQUDBOCR`(#
MTCJ-]&',:).(7?WB;4O%I3-CPA#DPB?YRZ,U]NZT=_9%Q;P_\"F(H'VOEH=)
MGS@AI9<$+L*[2@10>:'N@Y6KW:V3H:@W[Q@J:@O,LU9[KPP:RP_80!.2VTWC
M9]XSPJH\GT&A;H/KDCX.DL:I,ON/_LZ[PG":Y&3.UB/AKUFE1D8CA2U(I`X!
M,`./7]:EKB.^8QS>H%<(-O3($"^3\'.U)OWY."/2M?@]2Q829__X!9'3-G@<
MEV/TFQ%1*SYJNU/HCGBN\^]-62TA2DST5(!_)*F>)K`(;<G*?$@U%3Q+?IJ-
M2,#U:B^MN.[M#X+`"#OO#9X;0%\7WDWR)FEW3[0I#K_4F2O3!!">;B'0<R=4
MVE-$CI900D#O\I(3?%U8A>+#,$ZH>Y;5UH]7TVT2@@"/B7A%[:7_IPLXLH5<
M0S"4,)I*!@4H7CHVZV%&XG(N&3QL]_2CMWJ$^`35K=<#U-D?NX+ZD?B.VIV<
M,$DM%ZQZIPC`D,N\1J,TN0921>5"N?Y\Y]V!U(9C_[WIBF_$AR'TH[DTK[:`
MPH?.66=3H"Z9+/'PD[6I>W37,O!AQ6J+#"O8AHPM5>/>_QNYVKV7P+3==DXB
MT6FDD?A/7,C<QD":G2<+#./P#'NK,C'.L*![GQT%RKI=8&T>M&W*,`[,?QX"
M<L.U#/C6P\>2W=-+YX'N>.)=D]N'T,JN1J%TP&(]HR,LP<E+HBX,HNF6Z\\W
M3G0_I/L^Z/Y\*7AP+#BU(-2N6OW%][C/X^:.)SVB!5]UGX0@$C*!5.^'M:R4
M904RE!7=Q(*"AG[BPA>AYD6O=O%'T9KK%WAPC$*Z(L#H^Z="\VLJW9#)/'>#
MF"T*`K_OAA*YS*<FIM2RC'E\\X^3XM?P:$^7V?@L$WD6H@7N,`_\S.P>?Y6S
MQ*@DMM*N$5=[-S9W4!\7$[U>4'W4P^FO!P5!^]2I`^6'A#(JH*VH2;0>27S/
MEMA#%$J\X2U$AX:Y<1A?LMU#^O&+")<X5Y\SP3=W\*D`;+;Y0#+FZ;OQ9G7H
M.AUAI6YKW5.NYTZ?_G$F:RKCWM%'2]EK?`KGQ+7'SH##7'4N5+S$O*%*@GH'
M1EA''`T-Z63:W0CX*KH/Y5<>:2W^-'@"OCF;\&;.@*=HSLW>=9(0.+V9;*+&
M(N+'.;'W?T(MJ3V4R+0GL"'N2G(Z-5R<JM`>3HF_ZLHAR2#L,31A[J0+AJ74
M09GG_\C9!W7D#M>&&RS8<,+,OEQ^S'97Y(&"VL=Z$LB3&6`_.4M2MR?-@7BA
M-1;(%&%FRZPY+AF];C.#I>I(VQ-S*#H-\Z"C4ET4V<8*YB.+1_@M#332HAJ(
M,?=Y3Y?TN`1#<]=:0Y_>#MWJ4=W_K6(.B6VJ<`O6$)^A8VKY^*!X6C;$[7D,
M<Z%D[.[WQ5E.0/40YW2/PI51,K@X<GV#@,O<'N9WG@_!J6$J/O.C'3\\&+NQ
MK2:+SWJUDDH-D)@+]/M`&G\+>[JG$^0C.]JK"A7'I>K#N&5/-Y=EUHTZ(7(\
M2[BVC,THVFA7]N6<+".RD.3_IW$,F2:(#./RHCORD;Z"5`.@5T#L"YCX>OU:
M=:B=TD-U'&+Y^L6<C4^BMP-(EM$LN_P"3\Y]Y(.1D5VE8^G;?)1D%<"([)";
M5PQ2IM<CP>L,]ZZ9+[&.`[<VAB!D`66798,7VO`I5D!7_N]0/K%C@?*>+$35
M'-@;4R5FW.@-U=HV$V2E`I\$K9L,QS)2B#1PL6?6"=,BE)BPN;L8;)G)QK,A
M`\C=:MH(SY$)V':[AWD3'"6A!HY4(F@KQ#'E>ML57;?<@XJD-.1VAP4=V+CV
MQQ*[JSU:U[\KL-!+1BI>ANC)A+N09T*@[4:-F9#@5\U[.M4J<0.X;V&^`$.C
MT72E-)*JE'>T+6SHN8B*_<GOR"D!!3;7\V!T$85/IJ.;<`Y(ABT!*S.T5PMD
M>5))S0`JVK3"O?E59J`]Z2QI89.Y\WY;J$0Q&+XAXF6G0,7^\YUS*;@'+7\%
MZ\HW)`Y[0HC\P#D[5*@E^;\T;YI7R3M7U\4X(,9XI70R0>,VL2$LHJ`"DU_&
M1F,4)O+M796X^*%B6#@#/#(I`\,KJ8HK2QHO#=\`W2B+9:#$IS07B$3S:<#)
MB7>DAJCQ092@Y$QKH/A3W^[CD7.B,5_9"DRB]']/B.AB`,3]-H+2]`9$1C,Z
M.C*AK[F^P?KAD\?PHRUPD&RZBC:XD>?+*JA:KL2<8_L162J">JV3J)NJS!1K
MFG.SKI>RT&6X.=*.,=K/72O%B54'UL"(NKQ3A1:W`E.-[#O4]U:SJ=E*B5L,
MQX776%]^UD#P=C;75/R,+6W0/2NSDI.<=T3EXP0E1BJ3\/I?GK5`J;RMBY?A
M3#GSUC76ZW/(1.MXLS5H9N]M;9"-FR++05,KDR"N)T'3!7_=AC(VDE?28Q%Y
M;KC)T!FB)Y[\3:/;?<!*--VP;:D-$">I!1MA1-&_Z$:>,:%P;B>/JL]T,[`=
M#*_D3K[9J*$T%"]V"TUC[O#_*P#OW?$5$,^@E#O*J.`IG)W_S,6=1<[MTFHP
M`91"+XRG_MT&HFL?K%GGI3IS,*CJPZZ,5*A2\:MW++(:1^)HN-OVCK!=<RD+
MZ)_6"RW!1`PSL0*JJG;,$29I5:3Y=/VC`KT+2=9PC852VC!I.*#!=HF90,B?
MR[/GC9X"#5RH&+6U']QRA'>_?.^`-W(?$%W)*)VQ;&#QO$O0=W=Y*;&4G0M4
M/HIT%\DYY1N7*PE!4U<Q_OT=7B^05BI?7MA9/Y$!Z2.%+SVY!T^G,E_=FU7@
M+]N'-SOQ6+^MF%7FB("ZO1EDQX,EX)73>0V:'F9@G?99N$_+V9?!L@KD+"T-
M$FY@&]EK[4QG29C]LH%H*0A?Z5'P:PUEI\E.IK>_"]^!I#O/-G[*E-.:2E#2
MX,7S_"S(F:(UCK/:YTJV^I&JL/,1A"(#IO)-1QS\ST;`A^^[DEUXY#SURJTB
MX/W"6BZQ#!_[Y(W1KLIR+Z%Q]QQ7[&#\*RR=@:E:%_\D).%<>R5#HPYRAS+:
MRH\&,;4PEROD&G*_\C>2#X,GMK1BRT"=!A$1W\[=$K[RID:1H@$/.I1RC$RW
MY/,8<>\36BE+7;C=Q)V9LX<X#W-+!Z*HAT&OX&%[$;P.*GQP&_.Y10^C(-*3
ME<!-7A]8N7O,T@[F8<.A&]1B*ZQ_,Y+'$X&8C$LXF[X*8_'\(Y-#Y=!6L.06
MI'P]0X\^!718$@Y@=G$]VC$2GD)P[XPRC"[Z6D]O]'D_9]'G?^/I'S0H6`U%
M=B[:.$Z.XGY<GUX\V3S+$T7$KF1C3*%M$]UA>Z&!'LO/&7`O<#%S_V['\I"Y
M,+!^_AJDWK<VXJ'B+41\#<X'UA4F1+=M8"3D`U3V:<8WR$1!U#38A*]W$J73
M:28J%GAC?G_QBT2$'*IZ.;C4DX:3*/#<X)VSMA-<7SN*TOO!/_9@G(^I)_#J
MTA.C`IE#ZX`E!`5$K45!@<(H<P1.E1/5=#K:D"[@4IZ@@PF@5`X'P@G&:'02
M5.CZH%'MEV]Q_<C+6^`%+@]Z+#Q5\]MUCZDJ'A;"VZE4P$<6EM!*`5X4`PL(
M/BG*%XR]-OGF4=`6X%<F7B9Y)CF1?)_`^6@ZI!\N>(QVS*4,?^XPT90A-@<K
MM(0IS@CI2'<HT7!D0O(\]W-*(`X'-<(,?XG)U,30^;U9R_RK]S_]PJ\R+3A^
M+A)6MP+D%`)&!,J!U^%UI9&G;SH"&AW3WGE]QNJD_S%$2?R-V)\D8UW:1,,`
M+PMVK+S&W4N3HPUYFKN<<?`&8]+4ZX@-FF:P<AIY<\B]&I\J;M`G-C8IEXT]
M'%E;:*CE,ZTT`1K4)D.&2IL0&!+H;J_L-QVJT_7Q*</]8]<DP_<!C@6VTR$:
M6JE?LS[?(]"F8N_8S9)T:7,'JTMIO*QO%66ENGD#SY.%SZ7WG#IQ[?X&HMHR
M!C7&Q+(65GO8>Y3W4(GL#8'^3@Y=Z+/H#ZQ*$AYGE8>\X^:K4).QV\E>1AJF
MX#IB?5SI#)1I?*GJ?Q$.H&"'A&.U(&Y[UX,83#K&&7X`3E-G`YH?HQ*>D[^2
M0>N`EAM6@EW=(/3:L4ETS5!$L\*Q:$8+\V[/0;A04V43;?'[P]5:HLDV_'72
M.O)'0(=)&#9*,2>$VF!.*SJZ!HF'A"HT%5IN1*!SU(/0-X)>EI7\P,\'#%((
M'UX_(A";S/4CUPPQ%@4/QQ1$&#`S"^[+N.PL"@9&GYZR9]7J1,40G;G#J=US
M]K7WFRNB-<57))IGLN<&O4GMA#\(<]\]K"[1?4A?3/&BQ(<#:$M)S:C94S>1
M8.ORXW0=[#BS'#-AC^X-D6\4`253O+2[.VXMY:!>4Y=8UUY#$==IG8D[%2A"
M^Y;0!5#J'^$?4`A$%%$S888!^5ZP`Z@':@YU[GGG*P:PGL8B**O\2`9V*NSI
M'KTD\YN+U8\TDTL=R=9XC?1%T3TS]($,]I-O&CN"6G@=QQNPQ#A6"#,<4IH\
MB.*&K6C(K8CGUBK$KX7P$)F03AOL9V'0DL+QMO57PL<U\OYX1@L!Q9AX[G/R
M+K.T>AC.M&C]VDHA0?J%*:H`EFVH!OO>W*01Y,+V\<CM5E$G:SA=1*!$Y[=_
M`C+38BO;2QCBIFJP`D)2TL9?T/_3%K,'D0C!I'H8HXE!6I28(N::%28,Q*^Y
M+]LG5?&1#36U5$+>DS%%?U$-;7:8QYUKE\>4W1**O6YC/TV5`G[.3FET0DZ)
MBE491G(3_J5]NFJ'*+G@5-A=XIVR_?R+Y2NQ9TG0SNRSL(XIZ8$<TXH?)"H:
MJM9CU(O).6N"M]JOLR7_M*J%YJ<!<3_$A]G%F65P[222M7\A:$;C.CI&0Z8Z
M)2PLW+%*)D^BXK/W<<WB-@3VER"\L-H)-7.H1=:P[^L"[9"5X;G/@9D=Z\,L
M#%ZEC!`A?ZJ/TV:$>V7G&G;X`NI$ZMX,[951YH[NLM(+).@CQ42_3E'U$,MJ
M9CMV\>=J%`IL:I#9)/GWN5/H'E_5RSL?DH!=>>==->L58TD/N%-];\BHU[W0
M4[;'Z$.1<(N#X$FU@@:[Z52R\ALCNN8LY+_Q5>&/K"M*!.%7OXJ@3NO'*';U
MSL5]M;)Z&;W1$="\U1L[\):#SZ?+2!D@7'F6I\K8`>D-3+7$!W^X9_0X><L"
MM@9).R\($]':IQM6^.3\Z;RZGA-0NV=!+/<?\U%?E*9OE=PBR*<+K(YZ#'HB
MNWG9PEYI[32$MA.:P9<@(,ZM,TPR-,71<&Y*A1`-#!1XX?25J[5[HT,`=NML
M$L+!6%"/`=+;A,U&#E_3G;SY#D(@^>\-""%4;@KG3FW/2@?H:Z=X&VE!*6V]
M%P\(Z?58_IP7.KF<,?O^K",EWU+%I,1XMC5G(3*D_)^-_R:`BI=@W37%2]_R
M"50*\%#ZF]3H",C7CKD8M2UC>E'^-MWA/VJ@*[BSR=%\K8$Z4O!E;'/KCS7P
MAH%*J$9''_0,0B;D)BH+YY881Y\*>A"FU-6;^G_+>66V(,6[M8S<Z,11AP]#
M%//?L-@OBZ0$;^W^LM!.C!LS(27R;$E0H+V+0(XJ6@R2MMQ(4'HQ&TG@$9##
MIZNO0^ET!["DC5'0AS3`K6*BOR7BCHF$DPPYS-"MG^\14_B,Q/UE7Q@O0RZ+
MSVWK,_?D]S(QJDS('/\.9H>7WH!%8Q)0F1MM;VCQF;!>PD4`:D3X00/E?KRZ
MOY5(O,[_N;I(7U_%_Y@:%_A*"-:?[1-3:-`_RJ!T@2?;<1TX/A$`DYOA;4>L
MGKR#01IIWF_"^*2#PDV^6/V?8DQC[-IIBJ-^`XS$CIY?]`?@S7Q1/7YHY6?/
M)7H)H*_!G@CX4_MG7S?$L3<N^\[H8&"6W")-ZD_<)_V'TZV.26QRJ]24=(BR
M575)@1;6>K!=*G\R1!%YT).7,!^4I)7A013TQN;.=E1[.W->283ML4%9$L9R
M"E&\.@94S)LJG>%+/1F#2W<?:CDT0>BZOXQNNK';7)7%+?%X;BZ6LI)0?%L/
MZ+1J=S[R4-#58((@ZI3VA?KO$VU"S8%6#+025978B9X1AW@]@<&G\M$#@9=#
M]HD;T+-TD%F8B<`"2CW+MXS-CO'EYB0$P6*&:G,V[H!+"!_C:IS+#MV,5KD?
MYV'CO7>(81/?1!^40+VN-`!A-O&-%T,`P@$<50ZH:U^9%%X,(>*RL[RLHF@^
M;`LBG!5"$?,ZLE+@0Y;6UJ77E;?"T'">JE(G^[<^^YED!S[MT"HEM"4@L*[#
M(3Q!4!B>)!!"S=!]"(BP4D$[MV#9A4@7'_[Z4/N%`U2Z(U0P8E8=D*K\"!@N
M;(A,C=%YS/!N-6J=*T42J>O$IHHX=DXNV@+Y=7^`_,A69V]I0(7O54C$/%1(
M,^32B/M$FA'I*0-GV:(<V#9HP%1ER_51Z&^L6Q*RN!$?W&=Y_TQ/WB\M,QN?
ML#5Y':KW=@0\1DT$R9F`ITO1@3E349EATDU^BV6@%M-Z=0'^>B%.6A[.O'T"
M?O#\P>:,UA.3KS$'S]O-O#!^(=P1N84XW@C/\X>`76^X73W;.,]TSKC!5AF-
ME3566]5@IE:9-GA(+<1=42CD$0X=@S0^9T&(6!KI&GG$`LK&&QV>HO@&S_+.
M1+UR@]8E!W$E=^>8DI*Y_.IUISFU7R:H[&O8O!'`$IU$..TS6.O"@#*R#.`/
MZAD`PG,F:\;O-K6Q'Y>WOK\&OT$50\][$'-9UG__;U,N.G79=HCL?%8ZT>T.
MEC&?O>#*T)H]RK7?Q9*9M1+D@VVOKWL0]6H-:=T=*GP]'H0MIYL30$MF$6WP
M42)==_<GUM:LG.CT'6%!.D".?E&$-5(_;!>DQ$?H<Q^\)%0VR`(4D"8),(CF
M/9:3N5\AD=(WY;Y54859"K/,JOR*,A2]IT2,LB4P-)V*HDANE63.S9E!EA"2
MDDB\!ZL?VQD<<0[_F>C"SE@?]8]*@Q&+(P'N;S2FS952W*YR<'\\M=Z&'!"H
M$:XZ:FLZ/AAA-V8B;=-9#@$QDI)YOQIR;K#^,,M9AG3"1?R-5829E?*`:!&'
MJJ:7^7VEUI"5%VV1XP-<G%'0_\HJE/.>>;X^FRF!2CE!!8SP+17%@#C,+EJ*
M$''-]H)14C1MY^DC;S2.28GCX4PKJ..OE?@+M!]J;Y0RQJ0S#2E+.P#L7M4N
ML&?TJ;70.?`#JZ&AF%NFA9-1XQ%$-56FC+,O5YW&H)DP7GP]MBK+GOXC!P./
MYM[T8--(BAER':H2<$!3E[2!27!N;SAX:$Q(?B00E81P+R4#_ZR/<<0R8,E.
M:A\TR4YS9G1)"%`,H!$EG`O*TP>)TI]V7F?4)4$69/P;8&6WM$7A?,8<;2]>
M?]$85P%[7!3[Z_LZU+OC3]-DM)W"2V_Q.3EV%DZJ8-QDT^!XV<-#ZO-I!:>K
MTF&@V:UKQ9>'I5QG`L[:ZN2+ND;Z0B%:F#1-"(X\\G&$L\^PUK]/](?/WDCD
M!U`U>"&_<<D]769*4X=`&N!>.OFC0M0->Q(>NOWPZ;37+`M3J-T?+`JC1"]!
MDIEL_M;<>N:%LA6?%<`V[*(@M>VRFVA_DU@B<];-]_([.`R!%:Y[L<!8J%E2
M7?G$Y1[D3WJF_%[$6G=%H[3F6ODD(B-)7Q-NWM8-PT-+NA=`)&]!20_:&80(
M)@<[!)Y&_\FLV\_3W2E&X6O?K-Z:$>#V8/;2'^R*+8'J=0\O14RL+<(`Q%AP
M,^.(:%T>XG*I!EK_U>/<"K-C@>K+^1QK`<+J)C[I[)-ZI8HUZ]V5-8)FIOS"
M#515JW5U7+8P031;F]#*6]I6'.N8I6&WI+3F87ZWC/7/A2"Z@_H^H1?B-A6C
M[A)1C#@T]Z=W7QM1;5*/VJWLHU'#<P)8;Q[.T\A>"%P`R;**UG/J%'@^EQ^9
M8I]+#\0SE4`ZW0(+226)58+(3&Q[T`;X\7.\KA1>O^$F((2J!J,8=+*U9<$Q
MK9_:R$AV(GSDCE]RE)LVEQU3]B9KDFLLOZ5&70(TA#'>A.IW97/D[#7\D!DZ
M.(6*O[ON!HYV(:SLUS?N0Z6,5--!Z&%.5*P-PL;X+QN-91R;V]QJJ7FI2<@+
MVR2DF8-G9-LJ?9IR%S62'\@DTFU6HU6I.Q;1"E'<!KD5FW-+[3!"#[?PF&-[
M<Z]4C?Q[+N?"1MS^SB)9KEZ2M+,H*[R6%F6>2)#=8ZRH*,(Z1]65;JZ@J1M[
M/_S)8BS\ELD<*>=71*&#Z*U%L-[[9)R:<:;D\9*%5(S7JV.J_#S$2<8JL/.S
M<#>:8C(YQR"^262VV994^KD-*88X$%U-."*:XSJ3K>'@J[K_7`L51Y4!_.0Z
M.FDHC,+*25<ST4V$=>H,\C>,"+1V?0P8IVO6-N[HUI/?EO:DZ7R>(\+1UIWJ
METM-OP<8%_0L_M"`,)C?/9D$SAF%OD]K)?MXX8[Y;]+T-YI.W$*_'5P4*_A&
M'Z@MYF*]PJM6SK=2F)@H^KC-DW<`,`OL?W(GA>*\[7>:GD6H^,80:OO"/A+.
M0@3;]GCYNK&]RC@XSJ#;+(H2>BAR4&7NMP'OQXU<@SV7^4@;)6HDR!7X\[4X
M0K:U"%$N;MM<)OU?2.J.(DR;<<"C"1P3].(12!0+/8'?9.-R.'^K^0!3\PV!
MWZK#^^B5_1\.Q=+6;FB1_0%;=0,<37K96(7`Q1/'L+L1'7$YY$AZ27NT#U+&
M)[G,.16?M&[PWS(C2.?(07'HPVRZR;-<TH>9.@N!>?YL[T,'@"F#6K>;3IC,
MBN86GND`Z,TZ:38I$#FEDQGB(2EWRCBG?3?$+MQ$+;C,-J))>Q[[S+FUA2OA
M/!PE:9*^.DG>]&G4+97*@!HL"GEB]B]K[KI.=W)'CKTOF>RE"3=LT%<)VPKQ
M1*L66:)N]Z\)9YL$+&ML,VEZ6ZY9F\@`=A\V\@C6M;KJJ!I>-ET+?+K4!NB:
MXE"[']6GW;HY/<XV'OV<^V-D?=&?(6U8KN'T>53&IZNZ*D/J^5[>3YAOE.,^
MKEUPAD?MZ-.?5XRE_#ZNT`($AV[+9L&52/B,_^$^``8?_CIJGG#K*1/QQ'<R
M0>)X!JW\B';S%M3ZN4[3!P8BU1L2)*3<U_'A()\:>;:E?<K#:>FMIJTH<J9;
MBQH;CMU?KIU)Z8FU\@8_):WFD(#&\Y?H%@*0GH)9Q13(K5I%I&O.'7*TD73&
M"Y:]H<R[3T_#S;F>%%X7N%DH*G/_UVQB3/R/BPX4DXQ:0BG?8<&VW`[/\K;W
MJE:;.I];``?]PV)$[AQH`G747[QW5[N03R">3L<#WAG\UH8&[H9K<@?U_K,[
MMB"J=JFC@];NZKCRG2WJR[QY++G)3`*%'4J#"99C[\6Z:4=43@JG4K`E!)+'
MZ,?U5]JV9E"3FN>K8PG9FM;N4P/W?4959S01U2O3D2(F[L&6$4`0S$KLG5W#
M!YED:TV>!\A-E[K(F7PO5!;`B$&G@L,%]*<0C,O"$ZY330TJ1D-:$TT-Y`[D
M3[\!3S#EVY&N9H7[9RXKC%*P&6*]AA7V!Y5$$(XDD8VMXCBRB^]4HX['RVX^
M"KP0@S*XSD2\2R<VI>9+8_6&7>_70T#H$9528*U\FQ!R@.2[KYV/)Z0P3ZF_
MYS@DBA_0/X1S@T'1*@XT-Z14;XP],4G@/9FOB=,G%?<3UNW++V0TJ9<"1MOG
M3^;_N&+<L0EOJY1-*$^53W#B)'"7#'\4LV]'QYJ-Q-\JH6Q'Y36;5T+P]P60
MA_P#ZT`>9H\"&)IAHI_+2OIC6!($NJQY@Z`=:+J-_4.*$V8R*7TDXSE"$!_P
MDXW+Q;,0?0MIC+]LH!OF$9?5?EF[27@:TC<1*$9I0(=TVN>8(JLEY%G#WF[9
MQHFO(DV].T8KKQO&4BHA'(W+'UC,-PV$K`P%M\(2F7RNIX.7$RP]91SX2O7!
M:+!R6KV',*";IRN#)E7W-^DK0U'+8%HUSM%12CY-NSNC!AOM(9=C74`71A'_
M-<(!>F4S++O`G44EN;1'*PH<'^W\K5NM8"(X%(4TSZ%NCO<7#ABNG*6\7DI$
M%?]\8LKES\]V(7E[4C!0;I)B87I[S!NTN6K=R6`7-8B=,A-QP&1%X0ZH%YW_
MF'[%BL1&F.CTTC`F6DGMP71_Y9`\)Z$7.>HE]_MM:KN\UHLAMF#34S4U">D\
MTAO64KJ)R9@0T-L[/ZE^I&>4L)=<?PR]4R;PGDPD=`@+X7:!>2HU)P6#=M\0
M@$!R<L60%;GXS[GRB&2EW0W/7:E\FA!N'P;%206%"02,;.5[J^N.M)V`*:[E
MW'D@_5U]-<<]VES.TW_RO-J6ZA.B+NETW!2Z5DE9QB#55%`;YE;.%EX@#^[-
M1;RJ7/W8K5@;\BSQ5>QR5$!4WFZ&+9CE$![E6,X%LGORC73+NX9?8O;F2*_C
M+D,D.>&>34O*V;J:O09__:3:1JV80P[5,:E-7&95GG/T:P67`.U*7*B*O&63
M\Q1`I&/ZW(Q=5#IIR<H"+S?]>%Y3SS9-NI;KH%A/DT[5?2/&]SSCUN95')^_
M^^K+\#TF2Q<C.;7K7ME[F+5(H<S**SPY.`XB\S99:))84CL]3#&YQ_E&L%%@
MEH<9>[@ITNB]Z,+R+-7>;L6W8%VFI%$"/B\>S#,7?V\3<V?,"XED#U!9PU:V
M>L(UIT*[<PL$$5%R/J(/4:`LK1EW;)\J^"%9P4S.#LE@BL6'C?`Y-5:<W0+:
MCZ4JI<+H"^Y(T);#L_(G)"W`^LJY)S@U'>]=?SB-`&-2LB;;>W5;=OP/,+?6
M\+P4)W^06QL!NHW"^7/]`16,J93]?@W:SUGQ0&7]'RH$$1#9V8;WM$</(GQY
MYCHJ7"!/4C$W8OGJ*=ML!,=@[?3UF:!L/YVX!8/M'D$I(:!I"@(A)/;CV7"F
MHQOGT$9L7_>*!K:DEM8ZDM["2'S/5W>XN1A_$OIL\-YY#C?%1_=D)L*=P!$3
MN^8(-?*<NAQ9VK]=Z]M%UOJT<2#G:^L!H+3WWN@9JGLV_]W;+0.1S]OVL;/X
MPSAPH`S"&DH^HR,9:T6Y:O"L+\F]>RF,`/[46037ZZF_M(ZR#K!A$#,6A#/0
ME3.'-9JR\5M:@Q6DJKE`[:EX%;>^)>OTEFV$N[SS!#*XF/E1L0#O0<;Z%^5U
MHM+D(\\VM4"KMU^L2QUKT/O?.IC/?\JUI]&V3)9\D<TS:='=:M^>KPQ4`.]?
MH&J:E?^ZA";_*`["0P78S>4":@]D.@7STY9QZM(Y#0A7-U=$*XM7<_#*_&"`
M(_=L8C56*Z[Z#S9DE.")/^A2RDFO9MO($F]\[#/L4SIA,:[IXP]4,SGT=]R\
MW-#!-4K22JVSJ,!KW@54B3^8N:#:'-KB@Y@4>,\=S*V0Z`[#]C+]\`9*O"6>
MK+RO@%9L&]ST==>UNPKT%_9B(ZQ]XHG@[$*I]S!R2+/QC2.B,;?9/P/P62U]
M)+26YNJ=23LM?`]1)F-B]V3&\N_`B,_8#J6K2?/W&::F"XD5$&J[@N(R>Z8W
MBX;5S<8HOPR6%=Q<2K!<_YN"TB\ROX7=PGHV?+M-H&&!`:T>`PQH^8C'\.F5
M87<GZ4BBM.DPO,M6`9C.JEY\FW^63.6>-(0$%+3+SBGATWCO'9^D/7I8-%\5
M#L*MCI<ABT6S>BP,C[CI.D\M3H7`^I"B,-`._B-81)]W%<'('9!"@"3GK'XS
M]TUN%<UF7?ED+`&L-1UX9`]`T1!VVP0(YXS'F?.D6F.4*#+Y:O_"2(![G6\\
M.^G(B$(I:2IXTA4"63)';NTQ?1@?PNTY'%C+CV](>P]#`*,C4X*AS8H3M<FW
M]Z[?T7E8V;J!:;06.ND/(IZEKN=._R:C\>*?3I<4+>G;8!R0B!41U)D=4V]X
MAV9D_T5XYE<HZE*9&_5Y%D_P?\$YX=<H7`%Z7<7N87+V*3S9:K$Y*1IS`2#J
MQH9<;5`=WH-W+W]DA7N$1(<Q67J8`_J`<O<"BD1]7]7M+U;O'/-$9]IZ-J[[
MR#FKS@X%&YJH-K1^R$W#SM`C^[TJ;]J23U83+,,)?+)4`Y32;25D].E9AG3^
MNS*CU5WA<Y`!GI+ITG9R'ALI_:&9"QMF_?:E92QY5Y)4W?,'O@,`%S<Z.CGB
MXSVZ@<YMC"#@\ER]Y$M4E)F\L):$$/=PW=#4+:[\"HKQR!%Z(168Z0-6;ST-
MM1P>.OA9MMLY11>/=*.'NCYZ^/YI_^YHX2*,1QBE)68W`H["71=0KI/49HP1
M$COD$^D?!8FJ:-B54@ZA-^_I">.Z/;V+73MM;R[.FU>S3P$)^MG\S:*>2=1\
M]9:<Q14Y9Z5=AV0D7!S7^CCC6V6,=[LU_&_]0S2`W#8N.E8DQ;-FO^>O*!CU
M?7(:9]DI6*)ZX!K8XC[Z"FV"^Y?FSM@+YU&H@A=I4+\D!*E8+%C%U'E5&0<,
M,[0_#)A&XS#3E\VNVY4BX6]?`Q?P#R$$D26SC5'(_D@C$NG"]E,HDK#Y(*K[
MA.:4]KZ;>^VS@_//;F5D!=A]YRKX^!H=@O3F^,9B7A/;M+FXI>MR]',,HW?>
M9]#9A$:8@*._5F1LHE'8F5&*3Q1KXQL@HARW%),Q18`4"QP15"?4-RG.=-!&
M=.R(W5"".-0C^(O?&KAZ1#B([+B'=:U2KKL_?-<B8;K;8<(CQRF,D8$GZ#CW
M))<5M0)Y+?NG1X_NY,)&E&5<&+!1@BAG."[L"9,;JD8^SM^I&<N/D7L2BU(:
MV/P'V]T)F,A._&(MD#J;`/%8,:VW1)'3AMI*6^=+Y^9,@I'18@Q>L9<,K8S+
MUI5S[I'#J%@E?^@_T.(;#<UDTX_YJ,Y+SR@>_Q137JB#%&:1=#UF*:$S1E#O
MLT_@+1]`$+BKC7J-C^730>]T<5L!6ER?T]A[FT23T4)!_!'%N@PMR*LK]#_O
MK$ES?B4=_&=[\7"U`2AS0<DKM`@V8)XFF6=Z=HEV0FXK+2S#"RNA_>Y]#V(?
M@949B[)I*KVG&M=PLJ2-G$_O^]9T$S7LK%*3DVW`OQ4XK?,R.?J^:.%ISYQD
M]&>NIBYVFV#F8?;'O3!TH:"*567+%L,H0-2^ZTL';;N-'W.O9L4OM(QA60<T
M@T_>^`!?BU&&M2'S'^#KUV/_%M`VFH2^<MN.W9K`UN?0/7F*H6!!EB#)R]KQ
M&C:(8P]8&=&`D9U6_UY:+`U!1.`IXQ)[JFE[;-W-+Y<%]Q5S<Q2)7/+,6!H>
M6&H29<'GS]!?__3/%`+J\NA!9'G%^5(:.;+<(Z"6T5NCYT,8B<$?%^%G]1FO
M)J.THC)2*(BXQ:-5NS7^R5_IAK_,/=,:0N-Z73P"*6H;)]3SO()^0K_I->XC
MW"K@[7AHELR[T=N;3V8*V4<'[JD!ZI4T.H6QL?QAR55Y<IR%)N;A@-8R4+SI
M626#7^#^96G4\D'U'.K?/,XRKG!4;A$Z[HC"]2_R#5&UIZC./P38K[G1./8;
MW8,2K:7QE#FOB2HWL9V:,5\`W,0M[]^2(RX_8)[O#:8#!\<I*%;\%-;@Q&J`
MTM-MO2"!1",Q9)USR.ARZ..:[G[L,5R==[Y\S./%B9PW5[4D^]>=YG@Q/)-\
M?8TZ/XWJM(,9*!6Q=]LTK$TK1?CS&K=%KWIQ<%E!2[L*OX7RT#T2.Y$Z$?1:
M)T',0?;,&>P;G0N.0AW,%;[\*"5F2[+V(FA01U<OW9S`WT($KZ*(W.KJ5K=%
M*0+@]UNDD![^\]>@?8MT?3@_'%T04G.(5$X(P:^,]['P?]'^J4);(6@8%`RJ
MA+_8UY:[XD;7-33R_BGU45IP/94XS!'!4!9E.R;R<!@G]<WPO#\GWQ1''HP1
M^&1>`Y9@)RVJQ"Z%Z/BM!3"9@,[!?\R$Q\Y9^WA4B0]BJO035-F9\)/95Q2Q
M)`#O_+0!50^AS%RL9C5H]#D6,M.>S]YU7N=N4W$54#P<)V,#95D#9*N2H?@1
MH?N46^5DP'*]U)!#T+]!3$?M'0A=,CHC"FF%DW@B9<2EE,[*V)U;HD*Q,;\N
M`T3"1G;E9(#'+':@^VY_F#6]E+D=/!JR=<2>]<?%V&H"9/%^?1/ZT,^1EHO6
MF.JA5X0I3XQ/A^QY/)@`E8K!-QF/*QBE>K25J@TM4?[=P^T&4SX'(%EL"F-)
M'CLJ?3]#'JV3EGX)MKY*D<?_&\>M/QAPF1@B0^2?1%%^3WJ`[43M#/9(QO<L
M#9/3RY`E<_SBB__KX=]Y9D(1V2`<9PUS`!:?R4&2=S@2*Q+YUA'!'>S*"/J+
M`ER:]WC1<4$>Q]3MQTKH:'RR,#"J6@\[[WK;0E3?G7H^-\Q^FU?:9]4.AQW)
MTJ#1()/BW.O?WV:8'@QOQX'U!4JI\W#47NI(LH67E<KCS1X1?Y+5X?FKI;"/
MWP[&O0W"8BR?0R7N)21WD$X5H/N;<DW"&LTT<7YE*#=\/T_,=JL"H-<UN?4`
MNVG8S*6FRCY7C'`B\#Y/!KHJ%/.H)[:/-*)Y]?SOI2+=CKW,UZ\KOP!OB!R9
M9-(.L:/_\QR?)R,P4]ETL5&[W::JW[E<EH%^L<M55YDQSB#+6FWAO4X)3EAJ
MH>@@U3RV$\B<HLJ6Y\DLH-[Z1$;^<\=`="?*'+%S7<_\KX;D[4/SD#FPS,.1
M(`1Y3V/`T.=371H+_48X^R<L:51^\KO(4^OF>J7Z</"-_#/ZP'GF^,^O;-NX
M2T-H&4<B$E^,AM2%[++IGNE_3WP!WE/XSC>H52S40IPR6OPP119?>33<:TOT
MBL0PT`JDHFD5H>43^F.AJJ8H3O,YDT:K%=;OJ"5)C6N:W['JFN?.?YE=`%V/
MD%]*ZLAF(A%P3V,&;+6Q([:C$FT6/;R[^=BP('>1&H/='(#*E?I5DI1,?I#%
MZBXQMLO6.D/>/'H35N`X!$C90:A")0S)DV\(1LCT0<+H7LN_4R\5SG&^G8:O
MG1%DYKD&M`(W"MO<Y?`-=XT-JUT)-D88=GKM*W1-$R`P$D8],3VRT\T?P(&^
M<__^XV/6[Q>.JO?+G3@*T4EKY4[B2[._M<6>W>]2(OEG(-*9K]<?-J)&R_8C
MHDA84R2O<6H,\Y6_<V::]TGBHMD'M+AS#JUE*S.-O*ZPX\1*CY#9%,K0S'K[
MO<W/>)#R9N.>G33K?,VW16GA!K)'4/#@CIJ6.5LUSS-PH;3V5//`"D"^6MP-
M/\@Q%=!8W*T@,L?BOETPN?P"W>.<F<BR@6;+N@ZSX>G5UO=H$WO"-ZP=7<=*
M8_>;1.;/L-%,BK5[J1D_0[3;H^UVKOEJ`KK7CL(+7\[$$")E9(HS97\Q=!T<
MF3Y?$6+G@J#[]_5+#>X94P?JMX_Z#4_5YOB#Y\]R#Y9M.`LHQ'L;\ZW$.CZZ
M'WC'$*GJ(:*.M'WA(\5+DF9?>T:\YDH66*7,9HV=POYR&/VZCDN'X#XK_Y/#
MO.:>\[^,^8VDS]$[[(_L5>_^_HT)O?Z8KJ:[0;35WAVCCS#R</HMSG+N,U;Y
MW_W2^QF(H9S9'9NB:@R=!7VW@K'!1)=,.BK!PI=!2-4/<RY*N'BP\U).+!XS
M1@9`K6S-["%RF+4[_9MZD-;FQM9H\7!>)49RFW\Q.5<`*P':4.*HQ1D<?$"S
MMFBU$52&04*7L_IX3]JJPNWQ=T4MZ+N7'DP]IAU'\IYF:@AA:P5TCK#`X"!X
M+""<)>380,=^ZR1I_&:]#:+R=A-B:MOFD#L90I];U7[%\Q\CVW`*3-\$M_T.
M2`R@JN^LT`J#3F$9PZE#R<'_DLF8K;$(7*':NV##`UMH2JKPAL%L-4VYZ>VU
M5C3#T7@-@Y3)!OZHHY!X3:/]A78YMD:F`=E)=6IWABX:D)*WY>5(]&[>)9T2
MD(N`S=T9*"'3,LN5T`HXYVA8LW)F"W&>17.:0U&@OIA#T_&7K!]A,0UCZ=T4
M(G2N@]YH'!EX%WGMVUQ?XE(7%V[JX07Z?P3&@6338:]AX#?,YQ""0#I#U*5B
M5B=67+3)?):)QGXB+!1BAKO]^E:]S@]9EWD1/",=%^^ZNQ"L?C%`AI8YI7_6
M"-^QBS`;?E;BLU!R<-17)T/;_[V:QHTAL;B!0")$'%MSA5$)RKJ\O*.;A\G3
MLB_*(AT"S?WK&7U*T65#+&/NU^S]J@K"MH)I-$KKHE(R,/U0=AS@:8,KG`FU
M,W-!HKM7&Z*KF3^@969O^"T9+AUTQ%8BDS$Y!X6_>IMFS2V)9>)*1PV>VKKC
MU=A]5VA:1'2L<U^JZ[D3),R+L"&<3HTLSCB!)OQ,:8GA"A301;9M*B0`18SD
MAWUU*L;[%;I2^ZLT)*9N(TAO&L)Z3WQ@Q/73MD6Z0::K+92M36E`79NQ[-&F
MC4KAI-PNK]YQKS]3M%\W?RK59-#:(_2Q.;A2U<*UQP^__/Y71LS6SN^AA5>@
M8AE0Q2_]7(@DAX&H`SX(F3#+S\R(W5R_;SV]5K%+R:UH<`]*@$P?>F0#H1IA
MRH&O8^!I#^33/I.0+A=U+-U*0:0UX>#;?\<4M5H'BA<7&&$;&@4(ML3\1B_Y
MZE8#;C;4;$`PFE`&LRY4HWWSQ%#,F*KX7S6!B2>H2C/GR--3B-^0N0L#S$YU
M2TE_\\3])"46WX6-(.$4>B<;URXRU=JJJN1FOHIL2&&-H@5DI%'D+!KQD8Y.
MM4N^O<.<)5BRPTR'U$JE*$E?U-^&S/W^B0,(*!OW,15?]V7P8Z1U^BW;%XLE
M>F"6=5B'Y1+7'*U/D%)]G/1#+TDR(]_"WAO<.9VR?(8-K#<E9W0]7IAGMG$H
M-^(P`+4L-_JL92A[;!Z/1?7U&4V4L*06712$UIG3@[DX<3"K>R`N#A-\MK4:
M&-ZD<51'X'[@\HC2Z42O=01;K`/J,U&VR+]F&N8B\J<N":QXUV@B,Z=2T,?%
M%R*56%(\#>Q.A+R@=':QDN!NM=@=0B%1Y#:;;BXSN@'3TT90ZDZSNV6=)*-X
MRH0\DL#F^`N:,&JC:4TF:=/UXQY-=!<]SI1Y^Q!P\6'#CBI`H,@(?%A&R!YS
M]2@_/6EFT!',*H(BHM(_TJH#:R`GEV1`3."9('6FA;TRMWMFC@Y@)L^23(?T
M=*LU/'K!TNTEG++KF*1-M`5LKNR_7*6FX$6@0N=4>Z#FQUXSH!19U(*A3S'$
M(N+[6:#Y6WX<UD6CJR/&'>A\1P.]JW"N6%&&K%\FQ1]YR<J'.>)\]O'NCC,N
M5Z?[],C[*W.L(QZ$]-5>&$^?6<*J#4_GX?LZ77^<`$U&F6@S0G-&&KSOU0`)
M=V0%&2I]%2IXGJ.Q`]?(FC,7#`1M1H1?2J(B?Y-%C:/EYOK@FW@HS.R@AX*J
MAW1BQ)LBE;6=\/E-L$*>#N$M7QP73R/PYXY71;-JJ&<(SKGBZ;CI,$&O]N=I
MV,_*W6ZLH)3Y`"68DO870=E'JXD"$<825&/C6*2P3C;G)/B1RQ6RO;G;M27H
M/,Z+JVL]%D8XP4O=T%YL\%M>B]N-DVQLL?D9DT3=D[XS0=+92)LSFN5'$"X3
M?.;VCXJ]/@@#58MH+"#'XR`)4V2H,J>6V)KU>HV5&/<_'ND]@HA:''*YZWZ<
MV!9);`LM>^JG*XJWOP@$QM>B;R/KPMWO@3-6MLJ12?C([.HRX9-V,@">,KA7
MMM&0[&W76-7)5%7'.3/PFWSZSFY`AE)DC9@-=)G$2A(2!&Q+V=NH21NNF*P0
M\5V.BB$I1E%P63[*[V&^?SE"?W?[&:\B/W^/N]'4M1&.K?PP>PP>Y*%F[LZN
M#NZ9TNW>&@SAVI@T0OUY7U'=B[V^7;R"V?AE/?-$M.5`^=![][/(308W//+]
M0OE>#BGHEQFA[R$*'R_,^Y$`[/2Z8CE6S@P!Y:HG3PUDJTD2SS0O+52W\%.3
MFNF)EBZHU63>9:4_!KCAVD_A(;[J7(U!D!OH%QTV4XPSET?4X#'<>AAY'V&F
M_=$1:ZP$Z#)L^KL[;2/+4@?"\K%!4BPS+G*+GB?SRSX:<^2+<Y-ZZA[#VN&K
M?KI<&&!T@GX&0]F99<G.87?^W_E.X($K]XYI0<Q_Z)MJLUB+P\8"[S$/M+/J
M!%-G<13\\;`')VN^VY7&.S8+,SKK"3/RUI7'NDQH@0KGYJI0BL>Z\"?VSJJ<
MI)G1*\RJC2KL(DP9AS'1NA[_Z,8A+G`)ZC=U_@JN]JNAU@?7UGZ<@+H7"$9@
MH:[EB:Z!U>]QD^@9LD/&<-V>O#0JAGL2'=T!;D?_P`A=:8W^@>(<Z^D;1X#8
MX\AO1+"&#V\QQ!-'3W2=JX7Q[D2+&(71U(^J;Z3%?T"TZ4#(+TRS>IK;$NPZ
M[2KP-"D/GB5LIDC@\"BPL2O,*@:PYO*%'BUE[IJS8?7CE,LCEQ=;P+X.%':C
M[";>TT=_O^[,SA.G5;4-D/B+K40[^<G/KS<X"+WR#%0>6T[XEOKQ@WGF$T-0
M.A/!L;2O6',$U%-FL6#W3Z-#UTT-K-^+5X9?OU:?A1AIB8Z![+GQ`>IWT.1M
MI)38J=0$=:U+_-'!V1K4=GFK&38^\F+E,*H@C^`[O%6/N5C7ETR!QJV&&`T*
MP[_9%]E2VQM8IRY!<Y`G181K-`G8EGXA<UF593!!+<U&?N7)"+(E@DW<,%P3
MGAUIP\S-.9V/RXQTN-]!6Q;CNZZE%I<6BT98U9BR3N@2!RUWW$F=,&EU9RZ`
M_KT)NUI=L>Z*`0]F^K7*F4L5WN<P/JE!4-T12O<?YK`8PK+L1DSY1=<8N[BP
M[KA$H6WCUC_`N*X*?L%T=XGA51[^-(9/.HIF2"B**_)0;.QZ.*]3K#)6*O9N
M8,6&;6!7&3.LV,WEBY-:AM:^9-HRD]F>@*XBO2]]Q3\5W/M??(T2]+DU[M&.
M$!@LB;RQGP0ZW^/L<6S87##_1SCBY:*<DT1M2(E.<2@PS7WF":KOS./TW+)H
M7?:R<5VFX1RBX46_%85RW-06IT]=Z(\\5@4Z4KH81''8O!77,MY$(B>%K\DE
MVY/'[R2E\0EN^1M]L';P0J2HVZS*Y3%$I/H)7O<:6+,7UAP1^8E.*RJ(44<^
M+TM&:8[`(X!\?`+'8$=;-R;,?(=<IE[/J(7!YA9T0!H0K"`A0T7602]&S/!P
M=Z&;D)ZSSRM5`/LV,-63</S//`$[1IR#!!;<ZB)O<T%5:"W(:V\]^-KG]@:#
MM83T86I%)^QK36A3Y\>O`(X59ESW3!"9%V_T;9.^FH5D;"E[FJEF_B>^\$0/
MODK?'#N13`<<!<*KH]+S:.E^^.78X=MQR%PT\>K[BMUO116.WFC%*<9X/L"&
M5AD,G]JVY@[9GK04OD[^+M'JJF!!<T)<+]8?YNNQ-=%"B54C,IB,(//%JK'S
MZ!>3X0P;L1YU7X3)[J&26?YXPVMG!4,0/7%SUE@(7_4>'&,$<2)+8P!9WVG-
M20FEH(_-;IVD\FRNCA=<C_![6JW(6HKN9=3@L%4%T'!9*F$4:FY8FS^P6X1P
MV1C9EB`8^GZ9^4&O@I4G3PTL[2$?M_2$:A>BY^(*I,.6YE4*Y=]WTFQ4!,'`
M7BC"*^#(D,#63Q"3/1%U8I9H#!\P:N].$D`%)%[S;:8:6E4@U<RBF%?SD(4+
MI'(7QJCQN`_.K$(:CT'/>!729AFO</E31_96X-37KK5(>TN8:*VI#S.R'!R^
MC9G6Y[Z,>0_3<+]RX<A'Z",H&!ULO1?_GBZG!J&IZ?[OA^^(PCMQ5:5MXU$Y
ML:4$Z)F5_0R[F#0;H8`6X!C3,]1[C>C>4I6M:/7#-CJ5ZOG9JI<"ZZWF&#I1
M'GWS.K3/Z*2+!WG0L,@6CE`1)Q&.XD$$_R%G,H)9;.SCRQ75MJ?@BS54:R=1
MR=KOH_I3V,^AY4577W,S^ONC>!G0?^/CO1S/:KPB'<H,*:`[I"DS'M]29]->
MT%3&?31#Q'U^FW?7=#IB*PP`"V=(:K^)_I,+]FIL^(K)TN7E,=SPN0HX>E7;
M^+1WG47E<M$NA;8VTC.L%"6<7H6_Y93>0&;/&+L"M!RY$(`[?)?F@8")^/D-
M#'H,K9[ASY@9EZY>;DW75(>G2W-,>_O8^B!AQDYCY(?\SS?0F#V/Y:5B`U2R
M.2ECIFI5(;>+\HYE(L91XHG.LG0^G6K-_XUSP%'J%_T-8:PYG-54-N(1M1T8
ML<7^>Z*@WJ#.$$I+%Y^R+HI]`0J>5?.&/T0%'_3V)HD&9X'6-=]EG`5@&&+<
MW0[;8VXG`*G47L1ZJ/-@!53ZH7D1"*R1>%2C0MZ7<XIQSX;7<'W"(_;X7EL6
MGTC'G5,XWWXBJKNE<JY)(KY*T1:9+))NV?O0?5O@0HP_9IW0=_#O**O\[((\
MDT]U%8MOD-8M-2/I3,5"F,W&2\AN1SR!<=M+?S3RZ0?043U[XP6JNTZZ[;#Z
M,[GWHE#3)5REAT8:07,MJQ)%DFV>2W1NW,QAWV5NB)NW3F'Q=;J.?S;8Z6<&
MN.0=>;T^(NU;G.EYXZ+<8N-#RWTL"#WKO`=>=YLZQ&UD;\9XSW^(,V208BY5
MJ=2>-:"^*`_!M457CE\3/1[<41V\QH9C)7QD_WQ+SV0ER8_E70_JW;4L44NS
M4)BU9E!*-:'V]#3Y@4)3WCNNNTR21Z>QG4`_0G.DB\(RN?.;M3N2OE(MT@,3
M_/[5H-UW"4/'7/SQG5)\CLC\8QHELO7@QD>VAGC>U3YK0K=),>G?5>MLN92L
M.I%",:R82*J#OJ1PU"4E%H%FX=:]2<)P0F^E[0K'M,(^0"@K<1"UG<6#$1<H
MVC:3>&&/:-#[91?E\LVPTEHS>8LJK_>-./$HCW5O#_G)8*/RN/T#70CY"G+2
M->:EZ2Z+!GYD:)8_\''!DD?[@)S<G1I),)#F7_7TS:=^KJ5WC?PM$\<)6;-^
M:\F?*/-G+(.Y)M3$$83S*E_Q&MR)E(U%1>48X@K8E%<\Q8>;(FLLT%L$7&L:
MX*!>RL.XI]^FL^W?6F>N(Y#VC%<MCQ`:,2828[\Q1$$/+GX=]8]/<&K4CJX6
M7IO"HT1TM7RP1F&*I0K>;(@J^9[K"6'1VQNYA@*TRFUD1GS^3A>2G/^+A%:]
M$NC,.*-K@2W](1FQ//&V5R/X4/R7(S*I9_-WS,/N?#&PM*DA&`/F(LUK(#OE
M$#OO1=4(A`=BF>)]&B$\!9*MBGIET+@\`9W&6IIL,4#],9JT]#!`9IB=[(),
M5/1%MAPPT6@(PAD;("7-0F?,LZO.?P@LLXX-9@1DXK'MJ>QZ/,:/$\Z/46=,
MO#'/BT:4#T6VQLA3%>^9&-J^Y+T+`G!-/KNO%$05S,94?1D&&/@)I9VG]-G2
M)EP6?$)Q),@Y?HRH;J4`B%%#K%2=EN\,F`&!$"2+LU&+W+'LUJIP+3N7MTA$
MH<7NJE3Y>.(#6X=J+M7M(0OK'O4<@_':!`B1;77"EP^,'4ZQT7G^6Q":BYI8
MSI-Z=[\TB02NBVM&"0.RW^.P+06]:D"7F/D:RW1&;C[`'34KSJWK:RVCK%P+
M80^`@)JG6=.AY)J6Z)B4RC[/WI)_DZ";JID_T2&_S)7.7O*U;';IEB+IWNX"
M8')'_\N/E-Y[L":N[KE+EH1)-DHFV&ZZFGR$44]EF3Y2?\4"IUD`(KN#8KB0
M^,\+`USP?M,3)JV"D+0U,HVTQCH9E2]S#>6<CLZH[/>#*]P>CP*^'"@F:U()
ME!ZTA(PI`,`5'\N>`:`=L*J'A;WW_V6UJ;@GR&.W/L-B8D)>58-AF@HP0N8^
MJ.Y__U'N:>EA57;&X(2'`41^4T)LM81%=ELKM&%\7KY$=YO,)MT5I20S'TUC
MM7*]<P39^VL,^4Z>1F&V;\B@M;/:^[-6UIS$`F;!+_!OWX_R2=9D$T!QY[\O
M[4VX`+9E4@/95#AD?'W%(%7E>)J-Z@SC1)2[R>E5ARA*Z*1#V5#;,7ZO9R?]
M:VOI3-5,`NE.^((G9JZ@ZJV.86<IYM*NA0ZZQH-P#9V7'BY-M3.!]!?B=(Z8
MO:A;-S07IC@'^DA'?AK"B8M<:-<$F@G%G,>8U*EB6$P/_*WB/))-*4@FU-7?
MN8X*XX"Y-E83+1'\6!X9&#&]3-RKA77:1NE9TE5GTT$$7:0Z/MH'-MW$[2M#
M":9TT$ZG7B*FEBBI2UE;V<A9R/#H^;M(=/)KY1S%\42_.S!A-)P?<2,:OS3^
M60`LH-2'T].Q)\%5:^[EK^%#3RR8L%7MC>+&?+]K00OBN0@KAF^TSA>@@08(
MNI,^XO0#:A7\C97(E-]A+V^232HC\L$&O,#RTPU&*9=/F&Q0S,&IR:+FS)E/
M4=^"DY#R;P%[UZ<L)8&;O:GZ6(QC(.S_@IS<6!-:"4FHRF$*3/_%#"W5KY/@
M*T*=.V.M3J,<<YI#,J,WJ]$76\[`RP7G9W_C4]>((A!WR?";,J+$"9JK+.WT
MOA<'D\X5+6$^E_[AU)J"FP$+Y(^F4")G=#:+5"?!RW+!A.[-R)8!A(K[*EPJ
M9!:8-`S=P\^*0')-=?!]K?W,2,]_6F\/\B@K1K6ZD*]NUAQ"Q1#R&9X8G4/-
M*+91FNQE2EP#BKD;0\][I![X?Q`_N'YZ(,,"HR\4X&$)&,QVA>>-'FQ3(1@=
MI6O[GPI#.&@$T-D!1DJ^M9^E*RYW^:]F:H]F0:=A')L#DJ7>W_0STT\`G%Z+
MA.':H4RY&_"U2^I1S>NU.@^D#Z=<WG)[FLQ)&Y77856KVY87I-H#NPC#T%:X
MV4_E'>LYU6Q,VG\#8H(QKJ&.5@(&ONMQ=I-8!T+;G?GJ`*7\*XQP9DI'O'.\
MDM",Z_OSTCKV_9[J"0DL(6U]^=4CY96LD$GCSY%5P%3_23-?XL6%*24*FS%E
M3\=^``P'3&FK3:],(J-0;*4Q,QP'H(O772WV(<I+)`@"]B(^\S90E4@=KXXU
MV48:5B%@"@YQ4!J$Z^IW1OIH?+5NL5@MB#LKO`/V5?F(=G-,Y`^H32JV,I:J
M52?(>OH['@:6DI!VE3__I9X2R!^1S?-VO5@IIV:N,^^=5)Z*&F_:K)_`1[\<
M833!22[UH7FI)]J2.4&"#ZFA?'[%1TX]RILP3`@NE;+;T#\>.=0T7\WN0PC3
M!>;NK;CBLTYT,(8[ZJZZRMMYP!P^O/;+^-TA^3-4CG?]JS(1LGNG>5L#$6DM
MTPOSPS\FS+_VJ)A579;L'9M-+<)":4KDW'S>@5V4\\2_O^OL2<%YB>]YXIJ?
M(#[;.Y698+7+]B'1:!XNQ=[?]?AYKZI@JAC._X*ZQ.7#F4-S?_/'=UQ9^-X:
M!V0@8,K%7&<M_!&<U6S1!8S>/=>7(JM04=$>=!A1?'?@*0=-SAW@G-WLT`IU
MB02N2Y^-)F9&U.C9Z6VKV)P'9_>1VYS?"B+&@MMZ1KR[;Y-X(2%7MA@[VR`?
ML,27:!(`(.G$$E0)0TKWC>X,_NP7:RR#+SE&0:_N/E86&;K+_?#%/IQED&$?
M?1%[&^4OH'?Q-VW2L!%*>D33QK`RG^38`_W-S(8"O(6]F'_3`'S&6B%?KA)>
M??T<K@"*7>=Y&"_XU8S2_E_][(=%-_B"4(AWC]926,]B_;=1J!%E642;!F*3
M3/76G445Z7DUB&2#R'FIA)YD^>/E+ZWR>*V1;MN9IO`HE^I,XTEL_S->(OL)
MI`Q]6CP;YE_PU39H.O4UJU$N]U;5$HX$I?;R+8:S7([NIQVFV1+0?;@=#`!%
MUY=5;AF"$L1S287#CN3P:!CH4@_U&N]OP:;,^0I&[Y^PT_CS8J7$L2*&'8/!
M<R%/MG$C#B%SLVO,PGK^]'.DH6,YNY4-!G_%6FL<V4/.C*6\?5;0N?J+PU%M
M<T1;!I+#S`TW<5=F8*:?D(\X!$Y2/C"<3J,&FWV;^Q@@)"QU4JQ:0=R80$51
M$BX8?`T4EM%H+V%DE!I@%O</DWQZ)6(DN^WYM/<>51(\O;1^<#44-2'IFC8W
M`JZ,YVA[5\:8=C;Q,2XF8J'$)N]K6L1F+$+W4:3"8:7,N/31)GVRAX7N5_3T
M(3%GO`#A;3W\`4W5"%T+-PCS!)*256P*&2X_$B`<Y>,OR>]Q&)&\[Z\Q\DA<
M]=GDGCZ$++7M*8R-Q"*]/W^B\N2[ZPH2(>-;@<,33IH&5VL>HV1J7J?H0;56
MUH?`!:7DI%_H#=65Z5I*+HVXL=M3"%`[R\RIV::T$LM-Y?7,YZ4&V68VK@L`
M&1;M+X2]Y5@Z3Y!]4HM1<"M.?8`7@FU8\LY]RQVIZ-884_]M2<-'.*N3FPM$
MR#[`U?WD*X],U*>8AC)+V:/0DO"A<HT3^[\3]L6M]R$7=#9*\^UOCSWI'I^4
M]BH?[#@]E^:0\'=L7\0(831VH69&%/>;W2N']?<`9D#^FG#0D`M_\,^='/=^
MS-V!G'L9:`X&E2C9RM-.R3C\[.0D=X92'V)5/X'%E%MKSF(R_A@U32[6NT#8
M@`4AE%1OHBPQB7T%C%_2E>UJ_JF%[@=E]@S.?NM.4Q6OC_7$'0*7G0`G.4)P
MJ<W2T<YA:ULAA))!H&KB-/:T;O!@^HSVQ4ZKCF\)3AJ[D;RM$RP0L7.%!T!N
ML@=42A%7U5FY@USS;EBLIO%^2LO'J5[4=3X<O3ZTJ3&V\X=-8_OAYBMF_%/"
MTHL1\V[/.X!1=B<7U<&O2BDBE;::,)BP3H',U-/AS]ML,C586#ML-@56O/IW
MR1VIG5GD!`AZ^S!B,-D*/>I_LT*TSOLA9`C9LE&11'</F3EG,D7<,>/:Z@`@
M,4M`5>&P37"WG,T<D+!.,9)8.YU5R#@U7^R8DXG7L^-/EH40+CB[W3;U`%7<
M\'*I\+M^8/1H]@]&<0D]TL8F>A:2V>.L((VEW3C^\$EBY#43Q!:<';"-%<$W
MP'WH[9R;O+_,](?IY*M\T.DSQ8^IKA#[H/G/!"<I\)BW&,GV(+C$<YUD4-2$
M$E._Z\@MZ]"E/^-UW:?6[@$G#PB?/L8&]X1CGBZ[_!XCF6%V:;3&D\V9WNST
M\@=0A(OG,W2F\\T(4SV5JM=78F8.,/%+MK`M[B)EY&B@)5;T9SA1'E?0+0$E
M7D"BH)0"!5,WI/7YJIE*4P:<RR:*PK3#)0%^5G9(T#1DB/?&J&@DS@>]I9SJ
M)(\U>P?^]<S*TTC,,]HJ;_L"?CCHIV^(:G*N*3TIP[B[FB]AH@`@7+R&[:?P
M.1+^[-R`S)NHK?KY#\9@=KX&/3F?%B<.PX]&4*'+?NR\P@9CQHMG(3+.H>W=
M?8=@ZA]Z\^:,817^\&@4>CA+.=H@"7^N$F_N8."G=@+-W+*LL"#)*VNDTD#W
M_JMN<9_=5@P).FM5FU:ZR0^9J(SH*(S2`TIBHI<Q[563Z+GWA+3YDI[&O']&
M.&=^[$G!.W^"A!>;)&G5T/PIC4Y5G0OQSM69F2$8?\-=4$7(&1?YR>G[ECRZ
M4F(^M+59`7*(2;<+O1[XD%_^\7OX/K_P?82R0W0SO^7_5EW\.!8/*#$8!H%7
M)X8STNXQ*AMZ*5,4Y=PA^]X0)K]I<**A4=BY$6%!BVQ1GVB;.0I$13JNNPTZ
MTDN>6I!D[!VV*7!9P>JW[7=)DJ&QZT/+';XB4AC?XFQ4:SL,U*)9:(5VWG2]
MGWY9$7-O4=K82BK.V6]5>_HI[,C$V0H?E,Y2#?"VJN3/9.=9,TAR8?_9(%A,
M7.?AVXT(\B(8W>=/,*><JPB5Q^5EF1=S]I1G(;YU>'_Z&>RK%U`EN-C3"3CX
MQ5_MHMY1U8RKDJB]YH8K,EO%U"1<\9PZXYOCI&F49^X)_G?5[$0?@$:,<J&5
MT;.<+.KSA+?BQ'ABFI@@ZAO'%`KQ)\J%NHRXY^>T78?:P_X>'YRCPP@$(6,$
M'/&^L>)=!1IT6/JG2?F%#/[`^T3?Y7QNB0@FYKUV;ZDNA8.^'"?-,T1:A;@N
M-&;MQ_6W;!5[C\^$@3#B./QPY_(_!]R>NI2W*JLRIS3W/6M:[*NRE,4W++(R
M)BIIG9R2+[9GDH?&LS7UG"PF#SZVFE5&R,.(;D)7WLH_&YRIYN('&]X.*MA>
M8NXC*=;X>++!\CTR1CL_*DP\EHU$!8&3+Y#>#(4S+,.:A)4%V;@'"MSF)!4K
M=P3DZ?XUX+9+*T?M#BW$HYN9')7=);I`H:1?(.HRHIS*LZQ=&3\(@I5Z.OYR
M\*5IHGI4=#=I$W4I7:'46V7(_8*(7GHB@.KG"#^@;;3`T.@2Y$1$RF+@H#SA
MLYZ%.@149>D*U%X)A8%(=88(OK&X5WCSC$9#^"?^T^4'1T8I\ZA-4HW_EE2.
ML7\Y?%AGP)'T.2MS^?+<7:&TU4H=)MK!+>WCT;<OF0>1@^X(,T[WS/E'F\4I
M&/KX[$M)=#'GL&CV_*,%H=[[&R'\/Q8Z;3\##1WX;>D87H\,H8,M=2(:1R_5
M.=>S1^:=V.>X(HF73BF)6LZH[",,_VW1[HOW10@AEH;TK/;9/ZI>92T&AN(H
M<2CHQ(UNIE=G,LD##CI,TG6>3,EMXA:/!0%ZF#%TQ@JEB1UBUM)>L3>BC!"Q
M_IL+^&TLO/I?X^QDQI*GAH7$H91_3!:Q'$/F%8;\54`:4.ZRIR]."T>YF<)%
M<Y.FKD&KSX%*I,QK2"V;SY/9>015MY'M!^FC3':]9K(SK_]%H;7,B'!>W]/N
M-6F:44#Y*MM23:F@M-K\<I)?OK%#)*F,PQH/#,DUIG_3,AW4JSD;3-[`"$@M
M,;+E"JDA/JW.)K/&;6..6IA\#*PYQOF$Q[+Y&]+W%.;"\%$I;,407!)T:6EC
M`K[%LFD"I^P*[],*&SD)T&T77,Y#XA#)X[#4\+:O&?YUL]LM<INT9$H>:](_
M+Z[0=SX*6,.H>]G@E:5BZ&/Q_9D79HJG(WM)2<=U]4]M)SV*7'G248[GWG%A
MWQ$FX"(^B9.J0X#27S(@_9(T$4_-KHX!SVD$5K0WP%:L$C>_Z-MW\PH+2>QJ
M*'HWG'#SI"6R3.I4;H]P_"#^%6.6\.X[?\S:T493`&P!^HLA=.?=[<>U:8M/
M-CC8X/AR;_L.B"&L'^J`O2-,+4R21VXES)$'$V:H>R5K0'QNQUTZ_.LIN2ZS
M!/4OQH\C]_-<(X5;76CPT==_43'&HVH]T!):,1S=[@7;DW)\2>1_JN+)/]5]
M/*G@^P70P8ZD65"SJ@?O!+TUHD@1JN]SBIQ-7(WVB'0_F##3!E/*0)AD"144
M0-T\H?^G.TC(!84Q2*ISE+_</11,;YAMCI>`LTYGFK067'9T2[PI40R;D[$`
MG/R^J<8`(7`?'W.'&-6&$I'F#A4V7QY-BB)RZ?/KN)_(A@NXNR[-$!S%R'W\
M@,:,2S$%E7W&1Z@;'[<.XY"_`4,/#IN>UK=.G^/\(H5V-#X6?B0M71T+9CE,
MRP+4UTM%'M$\/W!H<"!E8VAO)SP_)SL_/BYIS6II<10%>,O,QWOL$3/M*82F
MJJ)TZVAA^P@D5"T7I$UW`OLR.A$-[':NJ'XX:;-LH*WO&XX"^+B%AEI\E4"3
M3WG,>FKI66EK&(S%B]\X>G%7;=O?TF.4H)EIZG/WSTC]G:]T!=)6BAV0FTP?
MAP%PF;&+U%5]+6?'V:%PK1Z@=`YR$^H9S2.TE^R%AO@/OM&(XI5S5KC(U9RJ
M_A,N5,7N%'52S--?>/.%[(<8O-F_LA:T2V,4##-74X6)HJVA\!8@TTDFS"17
M*K5WC1+^R2?$.55&_J@H#QB]\1T>>7@@3#F6*7I$*1XGZ+K6(]@TIP;:BIRY
M9K70TM03-P\A0`S<H6TJ.I@&II.FF$06:6IL`]2[<$JZ>E-QO<;Y^F>)XRP6
MGE`-*?CUA1@R5<9*?(;:#X:W-D!"TK_)1;PR<_3AN/EB3B9&LW>;$"6AA`=/
MX\='XRZLM;>4S@J;:97C%]\QNL8<#O9`YH=BSU3(VW#3)44%M5T_K?]"S*Y;
MJCLQG9MP[$20\8Z\^L91,^I,[$L!5]++!,\&FK&2P.>XOQK]>3SXU3R3;NO!
M@8/3O)@'U+HI@]5L@_"1[S*/(Z'VL0(F1?U_-&>-V6@HATQB$.DE9Y&2^+PZ
M"[F!H#R;G,K@CM,H8P"HI/9NHD\$[]'NXXU6\A\R_U:T]DXB"",.5:#<^54_
M@QZ<<JG(^I<E)`<ZCB`VNBGDQ4WM`M[9P'K?\W<Q:RT$_N>]4?#M<\,$00*`
M[L[PD!J4N#`'424S=X?1*V67&"C](*>3<X;J=;>0+9-X?OO09,0:I2HM2B"!
M(X]YPCDZFKH[V<SSV-C9FG2\3>=3"0<`@)*PE.QXO6Q))WAH.AVS\Q?NG;1K
MV#D]-@23,@F?-!)X/N`WI:,Z%Q7+*1N7/<!1-"QF>B=$Y>&=!)+34WP`M;8[
MKUJ5YJ9GX$;9?5D]]PG-LP*"_ZMC35HE^(,G+US[FO;U-U0`SU.25W5[GN#*
M\CLB`?$U_P;(":;;=#!19S]AN(__#TAP`_!J+844<S#I46<5@*BZI6?Q$HIC
M*-'*8R]^SPT4(CD`7-.FK-KKYSH=M<$\W+WX0'V&8@=91F[<*4\W62WC1<)U
MURP(T(FZBY@D2D"]V(4O.;^Y-;^"793Z4%2N?P?*GY&4#O;E>2SB\Z'VY+XQ
M@NPILCRMAWWBVS6(.Z9V>N[>>%#OO/5Q2R&\"T:?9KHTJ%'O>D@*N&J0>M,8
MEI*=;-;>"MA0(D\ZX5YF-7M@<-(F#,EZRDC3I"+2YM-DTPS8B90(9F>8<PT=
M*#GIOM;75.`[-B#-O;$G^YPE;XZV"M=X-N3BUG8GW<]V9%WZEL1>(SV]^S][
M&0\:5S<2I"A2D>"&T)&#3R$CN@,;#-T/F+1.SN=A[E9^WK`/I@3-!%ECH1OA
M_7&)[;X.@G2D?@#-I%F5IYL.XP>=`O0K$OW6I=V)JP_9V\8O:?-(+B3:-!EV
MAUR+@Z[LRS_PH%%/1AA<DQZ@>^,N,<EXDTF2+2>PQWJ,3M_P<;0N/0=CO'D"
M?BQ-$ZYO\:&%(%SP*CJ'6P@"/P)@/EXJ5TMIIDF\/-$$WB$53&<.D#GGB=QH
MCN6G?WN#SDNW/R\\HH1F`$PD#J?!N+&/2QSH]G*',"9"$)DZBE&'KP]OD1/2
M:TXZ%FZJ`T9-EC$G>W6,NN#YL'6L1.4QWIP3J`MBM/_%8A!1.2"<'$L;?BE5
M^#V2^<^U`I/`GD.\OH30FQPO[\!.QTC[S>7*".NH%?>XS$&EVM7?7/B.S][W
MFLOG0SI_=/8'(T^)DX7G7U5#O*LY3VWPY$;"YDI:L[.-V>X']"]%DG\BD\?N
M#2HVREPD1":"[]U0A194VU>_498=S/MAQ44?97PK%%FCM:+B\W=0[T+EWVE_
MV#56A^X`.<R[>$)Q>WJQ>$*:#@PB#'?,XB`^=Q0B'%NTHZXBUGQIOX%NY91E
MS8NQ:,;:W5B'A11#H6.51JFRKBE3P[F]O1MCG]DX-`>LGXRX`<&(>3_1\1P_
M%,+RQ<C_4"L1O0A8546`/X1+2LMGMQ3NQ1<19X4FAVC9!LTRCI(\T^HZ'7*N
M!H\2D(#);"M"L"F*]#^3Y,^A!)-2;>9BGOEZ&KV"<:@M#`R#IA'7=](A,*!V
MB_"5Q;W:/VN^^9M.@?##7<S$)E8K!H9$6JD\!LH$K8&&4+1),18#;8]A,K:_
MD8X%@:_>S`C(X98)00QC2+%P3+`N_Q/Z8&-P"N/7%=;74=(XJD(R@`Z^)@HE
MUQ]\DJ?_;19&DK\?C3Z9QKIN;.95L'V70)IB=B3-.)>.1Y<T,BI=Z`@`U!M<
M7RQQM@1)D''G)5^/X2QJE2\\TX4\&>P8AXLFI>6LU<%Q:1NRAWLD>XF+9*NM
MB0J#:OH@-M'&5K4^[A3@;\AP]^++W4?5(KBRA#92J/J&HQB#N/F0%".)R5KH
MM3L]\/@+I)*4NYRHMY*.#&W.V!!Y9>F='PFY@]1D>N"PY%+Q.R#$:-OXU&##
M=%`E^;E/8(QH;PQ6*1S$FMD((`(T2>R!#?_7_PGMMTA:PXQ<H;IIJ&8&8\^(
M+&EN9=5C-E?Q(K91!Y$*A+KRZHIS=+77I/-N,$'J4X<&GW3FBFZU(->]A#HF
M1OECK4M/`>H*0>O0@#N*RL]3]2@;L1CTY$#+)[2_LO]!D=)X,LH\_.EVI^BE
M8G?F^0?'75QAP%?$F<'878XTHPXK!)K2-K\H*M+#.RI0D1BG64-3**@TE10^
MUXZC'W^Y%3"Z/MR;UMV=GTD3ZWO%1HPD[B-L6##@(0LL'!02_7LG^D+Q@?*H
M)$-Q^BN?OO:NL!1*!/N;JZX)^+8C]`WF@*(`8RBLD.O*V,N\[=,9?RO])]K"
M+#U4*]$=E[4@PUD)6\@&I-<U,(R@6.PIJ',`N0HO4WSFB?2!VY,YEWKAYM,_
MG]0I:+H_Q!AZ?A.G`[<Z!-2^0T6%)20.LQ?'(GLDPCK2\H.<1E+O>!5F'F3H
M]3>U7)P3VQEK%7U!`C0<1)9+Z87I3]O`B;J&674M7#ZGSL.`%C?E9TW>?B9_
M1+<+-RB1[SW0R(D#2#-J(!Z.SX4TTLIVW$#S>*9=[HUB\#`0T3)R#]M5+"B*
M&5C(8=SS@8=[)T+YP0QR`"IY"+!EUW#+:?G.D*1N.>=#>.=2,I!K*Z=84DCK
M/*%TKDP)[6).>EDUFC$G)(/?\BL)QQ#/!HOO=DI9\,QA$3K)IX!_#OV/F-7*
M]DC^D[L*>9_[B/79W;!!$:<Y,YY1D",QCK,`>-OSJ>JU0>\%!+]KJ.4%CLQ=
M!VE:]9J,4:B46@58A/\[GG+?62%]FW)OJ3VM2:??YC8Q36=&/9:"`<(\R31F
MM`5`JZ:OII1%JL9S@4DK%P^.LED8<?^F*@LS;YJBZS'B$HX5CBXPWMITEZ+F
M3K8V\$CMNZ\V-Y^6=6T1_S5H22J@)<M%E(HT5`2J&]K9$RNGV:0`G9QU[+1N
M#9)DF,\^5M^7F"A>^/];8,=JS&6])UQEC(A&3`W$&S/HTPM4+Y%U=.CH_X'&
MQ(R>#Q0M53-1_^A@F-&(9X$Q9H3)QKUJ,Z*M:&%<DD@CDH*S&:R1"S3"-6=F
MAQ0@J-A'+A9X[D'[BO[,PO+5QVG:R;LY8RCI(>^EK%<2=IDGWIC'-A#MVA@_
M)8V+/(-LRO2EXD]8G"%5XRUB=*DBXI7PE,'4TX'?$!L8/?@T%^%STIII+>%)
M$S2RWISF(#E37`X31CIHP9X4JH7O9;M.0M0U3+B!%D(X!I'H3S[^'A+NY,_=
MI&@XEQ^>,<,A%H7)*^UINP&_#0#XN"?6`BM)R4!*++HPXMH.KKTRYQ/_L(%V
MYHEEK!/OZ?Q"R7/$I%&G]-JOP7$\P$196YN=O7AX]X:L[(>5I2)LM/B&!K?G
MZT3QURGPM2]XM0CR'3X#**<A?B&B('V/<2<9+)&\JI%O<*B*)CMT'1^7H2XG
M>8C(WCP:O"V5=C)LAL"`(EQ6&2I:;:^5;L<31@+:3R055<XX)[++[0#@C/=2
MRQ5Z:8H8.C\E\.4'YK8$ZE\(@O2,OB0&J7-&NVQT$W4H^%`WY7Q]+S:3TT!`
M_-D1#`ZD]NA$[`*6:!*-\_F'1-E/#.)EPM)/*IC=&A2='!23<,0WY'HW^G@`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O861M:6XO
M<&QI8B]L;V-A;&5S+P``````````````````````````````````````````
M````````````````````````````````````````````,#`P,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W,S0`,#$W-#,S`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]A9&UI;B]P;&EB+VQO8V%L97,O96XM55,O````````````
M````````````````````````````````````````````````````````````
M```````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q
M-30S,S<S-``P,C`S-C(`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+V%D;6EN+W!L:6(O;&]C86QE
M<R]E;BU54R]M97-S86=E<U]E;BU54RYP:'``````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`Q-#0S,C<R`#$P-3$U-#,S-S,T`#`R,S<R-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`IG;&]B86P@)%!2
M3T1?3D%-12P@)&QM<V=?87)R.PIG;&]B86P@)&1E9E]D871E7V9O<FUA="P@
M)&1E9E]T:6UE7V9O<FUA="P@)&1E9E]D871E=&EM95]F;W)M870["@HO*BH*
M("H@1F]R(&UO<F4@:6YF;R!A8F]U="!T:6UE(&%N9"!D871E(&9O<FUA="!S
M964Z"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO9G5N8W1I;VXN
M9&%T92YP:'`*("HO"B1D969?9&%T95]F;W)M870)/2`G32!J+"!9)SL*)&1E
M9E]T:6UE7V9O<FUA=`D]("=H.FDZ<R!!)SL*)&1E9E]D871E=&EM95]F;W)M
M870]("=-(&HL(%D@:#II($$G.PH*)&QM<V=?87)R(#T@87)R87D@*`H*("`@
M("`@("`O+R`J*BH@5&AE('-T<FEN9W,@8F5L;W<@:&%V92!B965N(&=E;F5R
M871E9"!A=71O;6%T:6-A;&QY(&9R;VT@0$!#05!424].(&1I<F5C=&EV97,N
M"@H@("`@("`@("=U:5]?861M:6XM:6YF;U]?9&5S8W)I<'1I;VXG(#T^("=%
M9&ET($-0(&%D;6EN:7-T<F%T;W(@<&5R<V]N86P@:6YF;W)M871I;VXN)RP*
M("`@("`@("`G=6E?7V%D;6EN+6EN9F]?7V1O;F4G(#T^("=!9&UI;FES=')A
M=&]R('!E<G-O;F%L(&EN9F]R;6%T:6]N(&AA<R!B965N('5P9&%T960N)RP*
M("`@("`@("`G=6E?7V%D;6EN+6EN9F]?7W-H;W)T+71I=&QE)R`]/B`G061M
M:6X@:6YF;R<L"B`@("`@("`@)W5I7U]A9&UI;BUI;F9O7U]T:71L92<@/3X@
M)T-H86YG92!P97)S;VYA;"!I;F9O)RP*"B`@("`@("`@)W5I7U]A9&UI;BUP
M87-S=V]R9%]?9&5S8W)I<'1I;VXG(#T^("=#:&%N9V4@4&QE<VL@061M:6YI
M<W1R871O<B!P87-S=V]R9"XG+`H@("`@("`@("=U:5]?861M:6XM<&%S<W=O
M<F1?7V1O;F4G(#T^("=0;&5S:R!!9&UI;FES=')A=&]R('!A<W-W;W)D(&AA
M<R!B965N(&-H86YG960N)RP*("`@("`@("`G=6E?7V%D;6EN+7!A<W-W;W)D
M7U]S:&]R="UT:71L92<@/3X@)U!A<W-W;W)D)RP*("`@("`@("`G=6E?7V%D
M;6EN+7!A<W-W;W)D7U]T:71L92<@/3X@)T-H86YG92!P87-S=V]R9"<L"@H@
M("`@("`@("=U:5]?8VQI96YT7U]D97-C<FEP=&EO;B<@/3X@)T-L:65N="`E
M,5PG<R!A8V-O=6YT(&%N9"!D;VUA:6YS+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G1?7V1I<V%B;&5D+7=A<FYI;F<G(#T^("=#;&EE;G0@)3$@:7,@9&ES86)L
M960N)RP*("`@("`@("`G=6E?7V-L:65N=%]?;F]N92UA=F%I;&%B;&4G(#T^
M("=4:&5R92!A<F4@;F\@8VQI96YT(&%C8V]U;G1S(&-O;F9I9W5R960N)RP*
M("`@("`@("`G=6E?7V-L:65N=%]?<VAO<G0M=&ET;&4G(#T^("<E,2<L"B`@
M("`@("`@)W5I7U]C;&EE;G1?7W1I=&QE)R`]/B`G0VQI96YT("4Q)RP*("`@
M("`@("`G=6E?7V-L:65N=%]S96QF7U]D97-C<FEP=&EO;B<@/3X@)TQI<W0@
M;V8@;7D@9&]M86EN<RXG+`H@("`@("`@("=U:5]?8VQI96YT7W-E;&9?7W-H
M;W)T+71I=&QE)R`]/B`G37D@9&]M86EN<R<L"B`@("`@("`@)W5I7U]C;&EE
M;G1?<V5L9E]?=&ET;&4G(#T^("=->2!D;VUA:6YS)RP*("`@("`@("`G=6E?
M7V-L:65N=%]U;FMN;W=N7U]Q=6EC:RUS96%R8V@G(#T^("=#;&EE;G1S)RP*
M"B`@("`@("`@)W5I7U]C;&EE;G0O8F%C:W5P7U]D97-C<FEP=&EO;B<@/3X@
M)T)A8VL@=7`O4F5S=&]R92!C;&EE;G0@<&5R<V]N86P@:6YF;R!A;F0@86-C
M;W5N="!S971T:6YG<R!A;F0O;W(@8VQI96YT(&1O;6%I;G,L('-C:&5D=6QE
M(&)A8VMU<',@=FEA(%!L97-K($)A8VMU<"!-86YA9V5R+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O8F%C:W5P7U]D;VYE)R`]/B`G)RP*("`@("`@("`G=6E?
M7V-L:65N="]B86-K=7!?7W-H;W)T+71I=&QE)R`]/B`G0F%C:W5P)RP*("`@
M("`@("`G=6E?7V-L:65N="]B86-K=7!?7W1I=&QE)R`]/B`G0VQI96YT("4Q
M(&)A8VMU<"<L"B`@("`@("`@)W5I7U]C;&EE;G0O8F%C:W5P7W-E;&9?7V1E
M<V-R:7!T:6]N)R`]/B`G0F%C:R!U<"]297-T;W)E('EO=7(@9&]M86EN<R!A
M;F0O;W(@86-C;W5N="!S971T:6YG<RP@<V-H961U;&4@8F%C:W5P<R!V:6$@
M4&QE<VL@0F%C:W5P($UA;F%G97(N)RP*("`@("`@("`G=6E?7V-L:65N="]B
M86-K=7!?<V5L9E]?9&]N92<@/3X@)R<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M8F%C:W5P7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G0F%C:W5P)RP*("`@("`@
M("`G=6E?7V-L:65N="]B86-K=7!?<V5L9E]?=&ET;&4G(#T^("="86-K=7`@
M36%N86=E<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O8F%C:W5P7W5N:VYO=VY?
M7V1E<V-R:7!T:6]N)R`]/B`G0F%C:R!U<"]297-T;W)E(&-L:65N="!P97)S
M;VYA;"!I;F9O(&%N9"!A8V-O=6YT('-E='1I;F=S(&%N9"]O<B!C;&EE;G0@
M9&]M86EN<RP@<V-H961U;&4@8F%C:W5P<R!V:6$@4&QE<VL@0F%C:W5P($UA
M;F%G97(N)RP*("`@("`@("`G=6E?7V-L:65N="]B86-K=7!?=6YK;F]W;E]?
M<VAO<G0M=&ET;&4G(#T^("="86-K=7`G+`H@("`@("`@("=U:5]?8VQI96YT
M+V)A8VMU<%]U;FMN;W=N7U]T:71L92<@/3X@)T-L:65N="!"86-K=7`G+`H@
M("`@("`@("=U:5]?8VQI96YT+V)A8VMU<%]U;FMN;W=N7U]W:7IA<F0M=&ET
M;&4G(#T^("=#;&EE;G0@0F%C:W5P)RP*("`@("`@("`G=6E?7V-L:65N="]B
M86-K=7!?=6YK;F]W;E]?=VEZ87)D7U\Q7W5N:VYO=VXG(#T^("=396QE8W0@
M82!C;&EE;G0@=VAO<V4@86-C;W5N="!A;F0@9&]M86EN('EO=2!W86YT('1O
M(&)A8VL@=7`N)RP*("`@("`@("`G=6E?7V-L:65N="]B86-K=7!?=6YK;F]W
M;E]?=VEZ87)D7U\R)R`]/B`G5&\@8F%C:R!U<"!T:&4@86-C;W5N="!S971T
M:6YG<R!A;F0O;W(@9&]M86EN<RP@8VQI8VL@0F%C:W5P($YO=RX@5&\@<F5S
M=&]R92!T:&4@97AI<W1I;F<@8F%C:W5P(&9I;&4L(&-L:6-K(&ET<R!N86UE
M+B!4;R!S8VAE9'5L92!B86-K=7!S+"!C;&EC:R!38VAE9'5L960@0F%C:W5P
M+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS7U]D97-C
M<FEP=&EO;B<@/3X@)TQI<W0@;V8@8W5S=&]M(&)U='1O;G,@9F]R(&-L:65N
M="`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS7U]S
M:&]R="UT:71L92<@/3X@)T-U<W1O;2!B=71T;VYS)RP*("`@("`@("`G=6E?
M7V-L:65N="]C=7-T;VTM8G5T=&]N<U]?=&ET;&4G(#T^("=#=7-T;VT@8G5T
M=&]N<R!O9B!C;&EE;G0@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O
M;2UB=71T;VYS7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G3&ES="!O9B!M>2!C
M=7-T;VT@8G5T=&]N<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB
M=71T;VYS7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G37D@8W5S=&]M(&)U='1O
M;G,G+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS7W-E;&9?
M7W1I=&QE)R`]/B`G37D@8W5S=&]M(&)U='1O;G,G+`H@("`@("`@("=U:5]?
M8VQI96YT+V-U<W1O;2UB=71T;VYS7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]
M/B`G3&ES="!O9B!A(&-L:65N="!C=7-T;VT@8G5T=&]N<RXG+`H@("`@("`@
M("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS7W5N:VYO=VY?7W-H;W)T+71I
M=&QE)R`]/B`G0W5S=&]M(&)U='1O;G,G+`H@("`@("`@("=U:5]?8VQI96YT
M+V-U<W1O;2UB=71T;VYS7W5N:VYO=VY?7W1I=&QE)R`]/B`G0VQI96YT(&-U
M<W1O;2!B=71T;VYS)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O8W5S=&]M+6)U
M='1O;G,O8W5S=&]M+6)U='1O;E]?;F]N92UA=F%I;&%B;&4G(#T^("=9;W4@
M9&]N7"=T(&AA=F4@86YY(&-L:65N="UL979E;"!C=7-T;VT@8G5T=&]N<RXG
M+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB
M=71T;VY?7VYO;F4M879A:6QA8FQE7U\Q)R`]/B`G0VQI96YT("4Q(&1O97-N
M7"=T(&AA=F4@86YY(&-U<W1O;2!B=71T;VYS+B<L"@H@("`@("`@("=U:5]?
M8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7U]D
M97-C<FEP=&EO;B<@/3X@)U)E;6]V92!C;&EE;G0M;&5V96P@8W5S=&]M(&)U
M='1O;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS
M+V-U<W1O;2UB=71T;VXO9&5L971E7U]D;VYE)R`]/B`G0VQI96YT+6QE=F5L
M(&-U<W1O;2!B=71T;VX@)3$@:&%S(&)E96X@<F5M;W9E9"XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L
M971E7U]S:&]R="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?7W1I
M=&QE)R`]/B`G4F5M;W9E(&-U<W1O;2!B=71T;VX@)3$G+`H@("`@("`@("=U
M:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E
M7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G4F5M;W9E(&$@8VQI96YT+6QE
M=F5L(&-U<W1O;2!B=71T;VXN)RP*("`@("`@("`G=6E?7V-L:65N="]C=7-T
M;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+V1E;&5T95]U;FMN;W=N7U]S:&]R
M="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O8W5S
M=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?=6YK;F]W;E]?=&ET
M;&4G(#T^("=296UO=F4@8W5S=&]M(&)U='1O;B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?=6YK
M;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G0W5S=&]M($)U='1O;B!296UO=F%L
M)RP*("`@("`@("`G=6E?7V-L:65N="]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM
M8G5T=&]N+V1E;&5T95]U;FMN;W=N7U]W:7IA<F1?7S%?=6YK;F]W;B<@/3X@
M)U-E;&5C="!A(&-L:65N="!W:&]S92!C=7-T;VT@8G5T=&]N('EO=2!W86YT
M('1O(')E;6]V92!A;F0@8VQI8VL@3F5X="`^/BXG+`H@("`@("`@("=U:5]?
M8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7W5N
M:VYO=VY?7W=I>F%R9%]?,U]U;FMN;W=N)R`]/B`G4V5L96-T(&$@8W5S=&]M
M(&)U='1O;B!Y;W4@=V%N="!T;R!R96UO=F4@86YD(&-L:6-K($YE>'0@/CXN
M)RP*("`@("`@("`G=6E?7V-L:65N="]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM
M8G5T=&]N+V1E;&5T95]U;FMN;W=N7U]W:7IA<F1?7S0G(#T^("=#;VYF:7)M
M(')E;6]V:6YG('1H92!C=7-T;VT@8G5T=&]N(&)Y('-E;&5C=&EN9R!T:&4@
M8VAE8VL@8F]X(&]N('1H:7,@<V-R965N(&%N9"!C;&EC:R!&:6YI<V@N)RP*
M"B`@("`@("`@)W5I7U]C;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U
M='1O;B]P<F]P97)T:65S7U]D97-C<FEP=&EO;B<@/3X@)T5D:70@<')O<&5R
M=&EE<R!O9B!C;&EE;G0M;&5V96P@8W5S=&]M(&)U='1O;B`E,2XG+`H@("`@
M("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO
M<')O<&5R=&EE<U]?9&]N92<@/3X@)T-U<W1O;2!B=71T;VX@)3$@<')O<&5R
M=&EE<R!H879E(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]?<VAO
M<G0M=&ET;&4G(#T^("=0<F5F97)E;F-E<R<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7U]T
M:71L92<@/3X@)TUO9&EF>2!C;&EE;G0@8W5S=&]M(&)U='1O;B`E,2<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O
M;B]P<F]P97)T:65S7VYE=U]?9&5S8W)I<'1I;VXG(#T^("=#<F5A=&4@;F5W
M(&-L:65N="UL979E;"!C=7-T;VT@8G5T=&]N+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S
M7VYE=U]?9&]N92<@/3X@)T-U<W1O;2!B=71T;VX@)3$@:&%S(&)E96X@8W)E
M871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U
M<W1O;2UB=71T;VXO<')O<&5R=&EE<U]N97=?7W-H;W)T+71I=&QE)R`]/B`G
M0W)E871E)RP*("`@("`@("`G=6E?7V-L:65N="]C=7-T;VTM8G5T=&]N<R]C
M=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?;F5W7U]T:71L92<@/3X@)T-R96%T
M92!C;&EE;G0@8W5S=&]M(&)U='1O;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?
M=VEZ87)D+71I=&QE)R`]/B`G0W5S=&]M($)U='1O;B!#<F5A=&EO;B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O
M;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\Q7W5N:VYO=VXG(#T^("=396QE
M8W0@82!C;&EE;G0@9F]R('=H;VT@>6]U('=A;GD@=&\@8W)E871E(&$@8W5S
M=&]M(&)U='1O;B!A;F0@8VQI8VL@3F5X="`^/BXG+`H@("`@("`@("=U:5]?
M8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE
M<U]N97=?7W=I>F%R9%]?,U]N97<G(#T^("=#;&EC:R!&:6YI<V@@=&\@8W)E
M871E(&-U<W1O;2!B=71T;VX@=VET:"!T:&4@9&5F:6YE9"!P<F]P97)T:65S
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M
M+6)U='1O;B]P<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G
M161I="!P<F]P97)T:65S(&]F(&$@8VQI96YT+6QE=F5L(&-U<W1O;2!B=71T
M;VXN)RP*("`@("`@("`G=6E?7V-L:65N="]C=7-T;VTM8G5T=&]N<R]C=7-T
M;VTM8G5T=&]N+W!R;W!E<G1I97-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^
M("=0<F]P97)T:65S)RP*("`@("`@("`G=6E?7V-L:65N="]C=7-T;VTM8G5T
M=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?=6YK;F]W;E]?=&ET;&4G
M(#T^("=-;V1I9GD@8VQI96YT(&-U<W1O;2!B=71T;VXG+`H@("`@("`@("=U
M:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R
M=&EE<U]U;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=-;V1I9GEI;F<@0VQI
M96YT+6QE=F5L($-U<W1O;2!"=71T;VXG+`H@("`@("`@("=U:5]?8VQI96YT
M+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]U;FMN
M;W=N7U]W:7IA<F1?7S-?=6YK;F]W;B<@/3X@)U-E;&5C="!W:&EC:"!C=7-T
M;VT@8G5T=&]N('EO=2!W86YT('1O(&UO9&EF>2!A;F0@8VQI8VL@3F5X="`^
M/BXG+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O
M;2UB=71T;VXO<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S0G(#T^("=7
M:&5N(&1O;F4@=VET:"!E9&ET:6YG('!R;W!E<G1I97,@;V8@=&AE(&-U<W1O
M;2!B=71T;VXL(&-L:6-K($9I;FES:"!T;R!A<'!L>2!C:&%N9V5S(&%N9"!E
M>&ET('1H92!W:7IA<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]C=7-T;VTM
M8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?=6YK;VYO=VY?7W=I
M>F%R9%]?,5]U;FMN;W=N)R`]/B`G4V5L96-T(&$@8VQI96YT('=H;W-E(&-U
M<W1O;2!B=71T;VX@>6]U('=A;G0@=&\@;6]D:69Y(&%N9"!C;&EC:R!.97AT
M(#X^+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"-C=7-T;VTM
M8G5T=&]N<U]?=&ET;&4G(#T^("=#=7-T;VT@8G5T=&]N<R<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&%S:&)O87)D(V1O;6%I;G-?7V1E<V-R:7!T:6]N)R`]
M/B`G3F\@9F%V;W)I=&4@9&]M86EN<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&%S:&)O87)D(V1O;6%I;G-?7W1I=&QE)R`]/B`G1&]M86EN<R<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D(V9A=F]R:71E<R]T86)S7U]D97-C
M<FEP=&EO;B<@/3X@)U-H;W<@=&AE(&9O;&QO=VEN9R!T86)S(&EN($9A=F]R
M:71E<SHG+`H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"-F879O<FET
M97-?7W1I=&QE)R`]/B`G1F%V;W)I=&5S)RP*("`@("`@("`G=6E?7V-L:65N
M="]D87-H8F]A<F0C:6YF;R]F;V]T97)?7V1E<V-R:7!T:6]N)R`]/B`G4VAO
M=R!T:&4@9F]L;&]W:6YG(&)U='1O;G,@:6X@=&AE(&9O;W1E<CHG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"-I;F9O7U]D97-C<FEP=&EO;B<@
M/3X@)U-H;W<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;CHG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1A<VAB;V%R9"-I;F9O7U]T:71L92<@/3X@)TEN9F]R
M;6%T:6]N)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H8F]A<F0C;6%I;&YA
M;65S7U]D97-C<FEP=&EO;B<@/3X@)TYO(&9A=F]R:71E(&UA:6QN86UE<R<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D(VUA:6QN86UE<U]?=&ET
M;&4G(#T^("=-86EL;F%M97,G+`H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB
M;V%R9"-Q=6EC:RUS96%R8VA?7W1I=&QE)R`]/B`G475I8VL@<V5A<F-H)RP*
M("`@("`@("`G=6E?7V-L:65N="]D87-H8F]A<F0C<F5C96YT7U]D97-C<FEP
M=&EO;B<@/3X@)TYO(')E8V5N="!P86=E<R<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&%S:&)O87)D(W)E8V5N=%]?=&ET;&4G(#T^("=296-E;G0G+`H@("`@
M("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"-S:&]R=&-U='-?7V1E<V-R:7!T
M:6]N)R`]/B`G3F\@<VAO<G1C=71S)RP*("`@("`@("`G=6E?7V-L:65N="]D
M87-H8F]A<F0C<VAO<G1C=71S7U]T:71L92<@/3X@)U-H;W)T8W5T<R<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D(W-T871I<W1I8W-?7V1E<V-R
M:7!T:6]N)R`]/B`G4VAO=R!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N.B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D(W-T871I<W1I8W-?7W1I
M=&QE)R`]/B`G4W1A=&ES=&EC<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S
M:&)O87)D(W1O;VQS+V9O;W1E<E]?9&5S8W)I<'1I;VXG(#T^("=3:&]W('1H
M92!F;VQL;W=I;F<@8G5T=&]N<R!I;B!T:&4@9F]O=&5R.B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&%S:&)O87)D(W1O;VQS7U]D97-C<FEP=&EO;B<@/3X@
M)U-H;W<@=&AE(&9O;&QO=VEN9R!B=71T;VYS.B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&%S:&)O87)D(W1O;VQS7U]T:71L92<@/3X@)U1O;VQS)RP*("`@
M("`@("`G=6E?7V-L:65N="]D87-H8F]A<F1?7V1E<V-R:7!T:6]N)R`]/B`G
M1&5S:W1O<"!O9B!C;&EE;G0@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M87-H8F]A<F1?7W-H;W)T+71I=&QE)R`]/B`G)3%<)W,@1&5S:W1O<"<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D7U]T:71L92<@/3X@)T1E<VMT
M;W`@;V8@8VQI96YT("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H8F]A
M<F1?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=->2!$97-K=&]P+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D7W-E;&9?7W-H;W)T+71I=&QE)R`]
M/B`G1&5S:W1O<"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D7W-E
M;&9?7W1I=&QE)R`]/B`G37D@1&5S:W1O<"<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&%S:&)O87)D7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G0VQI96YT
M($1E<VMT;W`N)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H8F]A<F1?=6YK
M;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=$97-K=&]P)RP*("`@("`@("`G=6E?
M7V-L:65N="]D87-H8F]A<F1?=6YK;F]W;E]?=&ET;&4G(#T^("=#;&EE;G0@
M1&5S:W1O<"<L"@H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"]C=7-T
M;VUI>F5?7V1E<V-R:7!T:6]N)R`]/B`G0W5S=&]M:7IE($1E<VMT;W`@;V8@
M8VQI96YT("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D+V-U
M<W1O;6EZ95]?9&]N92<@/3X@)U-E='1I;F<@;V8@1&5S:W1O<"!F;W(@8VQI
M96YT("4Q(&AA=F4@8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&%S:&)O87)D+V-U<W1O;6EZ95]?<VAO<G0M=&ET;&4G(#T^("=#=7-T
M;VUI>F4@1&5S:W1O<"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D
M+V-U<W1O;6EZ95]?=&ET;&4G(#T^("=#=7-T;VUI>F4@1&5S:W1O<"!F;W(@
M8VQI96YT("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H8F]A<F0O8W5S
M=&]M:7IE7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G0W5S=&]M:7IE('EO=7(@
M1&5S:W1O<"!C;VYT96YT+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O
M87)D+V-U<W1O;6EZ95]S96QF7U]D;VYE)R`]/B`G66]U<B!$97-K=&]P('-E
M='1I;F=S(&AA=F4@8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&%S:&)O87)D+V-U<W1O;6EZ95]S96QF7U]S:&]R="UT:71L92<@/3X@
M)T-U<W1O;6EZ92!$97-K=&]P)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H
M8F]A<F0O8W5S=&]M:7IE7W-E;&9?7W1I=&QE)R`]/B`G0W5S=&]M:7IE(&UY
M($1E<VMT;W`G+`H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"]C=7-T
M;VUI>F5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=#=7-T;VUI>F4@1&5S
M:W1O<"!F;W(@82!C;&EE;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H
M8F]A<F0O8W5S=&]M:7IE7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G0W5S
M=&]M:7IE($1E<VMT;W`G+`H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R
M9"]C=7-T;VUI>F5?=6YK;F]W;E]?=&ET;&4G(#T^("=#=7-T;VUI>F4@8VQI
M96YT($1E<VMT;W`G+`H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"]C
M=7-T;VUI>F5?=6YK;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G0W5S=&]M:7II
M;F<@0VQI96YT($1E<VMT;W`G+`H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB
M;V%R9"]C=7-T;VUI>F5?=6YK;F]W;E]?=VEZ87)D7U\Q7W5N:VYO=VXG(#T^
M("=396QE8W0@82!C;&EE;G0@=VAO<V4@1&5S:W1O<"!Y;W4@=V%N="!T;R!C
M=7-T;VUI>F4@86YD(&-L:6-K($YE>'0@/CXN)RP*"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&%S:&)O87)D+W-H;W)T8W5T+W!R;W!E<G1I97-?7V1E<V-R:7!T
M:6]N)R`]/B`G161I="!P<F]P97)T:65S(&]F('-H;W)T8W5T("4Q+B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D+W-H;W)T8W5T+W!R;W!E<G1I
M97-?7V1O;F4G(#T^("=0<F]P97)T:65S(&]F('-H;W)T8W5T("4Q(&AA=F4@
M8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D
M+W-H;W)T8W5T+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G161I="<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D+W-H;W)T8W5T+W!R;W!E
M<G1I97-?7W1I=&QE)R`]/B`G161I="!S:&]R=&-U="`E,2<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&%S:&)O87)D+W-H;W)T8W5T+W!R;W!E<G1I97-?;F5W
M7U]D97-C<FEP=&EO;B<@/3X@)T-R96%T92!N97<@<VAO<G1C=70N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D87-H8F]A<F0O<VAO<G1C=70O<')O<&5R=&EE
M<U]N97=?7V1O;F4G(#T^("=3:&]R=&-U="`E,2!H87,@8F5E;B!C<F5A=&5D
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D+W-H;W)T8W5T+W!R
M;W!E<G1I97-?;F5W7U]S:&]R="UT:71L92<@/3X@)T-R96%T92!S:&]R=&-U
M="<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D+W-H;W)T8W5T+W!R
M;W!E<G1I97-?;F5W7U]T:71L92<@/3X@)T-R96%T92!S:&]R=&-U="<L"@H@
M("`@("`@("=U:5]?8VQI96YT+V1E;&5T95]?9&5S8W)I<'1I;VXG(#T^("=2
M96UO=F4@86-C;W5N="!O9B!C;&EE;G0@)3$N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D96QE=&5?7V1O;F4G(#T^("=#;&EE;G0@)3$@:&%S(&)E96X@<F5M
M;W9E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1E;&5T95]?<VAO<G0M=&ET
M;&4G(#T^("=296UO=F4G+`H@("`@("`@("=U:5]?8VQI96YT+V1E;&5T95]?
M=&ET;&4G(#T^("=296UO=F4@8VQI96YT("4Q)RP*("`@("`@("`G=6E?7V-L
M:65N="]D96QE=&5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=296UO=F4@
M82!C;&EE;G0@86-C;W5N="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1E;&5T
M95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&5L971E7W5N:VYO=VY?7W1I=&QE)R`]/B`G4F5M;W9E
M(&-L:65N="<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&5L971E7W5N:VYO=VY?
M7W=I>F%R9"UT:71L92<@/3X@)T-L:65N="!296UO=F%L)RP*("`@("`@("`G
M=6E?7V-L:65N="]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\Q7W5N:VYO=VXG
M(#T^("=396QE8W0@=VAI8V@@8VQI96YT('EO=2!W86YT('1O(')E;6]V92!A
M;F0@8VQI8VL@3F5X="`^/BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1E;&5T
M95]U;FMN;W=N7U]W:7IA<F1?7S(G(#T^("=#;VYF:7)M(&-L:65N="!R96UO
M=F%L(&)Y('-E;&5C=&EN9R!T:&4@8VAE8VL@8F]X(&%N9"!C;&EC:R!&:6YI
M<V@@=&\@8V]M<&QE=&4@=&AE(')E;6]C86P@86YD(&5X:70@=&AE('=I>F%R
M9"XG+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6Y?7V1E<V-R:7!T:6]N
M)R`]/B`G36%N86=E(&1O;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;E]?9&ES86)L960M=V%R;FEN9R<@/3X@)T1O;6%I;B`E,2!I<R!D
M:7-A8FQE9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;E]?;F]N92UA
M=F%I;&%B;&4G(#T^("=9;W4@9&]N7"=T(&AA=F4@86YY(&1O;6%I;G,N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6Y?7VYO;F4M879A:6QA8FQE7U\Q
M)R`]/B`G0VQI96YT("4Q(&1O97-N7"=T(&AA=F4@86YY(&1O;6%I;G,N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6Y?7W-H;W)T+71I=&QE)R`]/B`G
M)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;E]?=&ET;&4G(#T^("=$
M;VUA:6X@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;E]S96QF7U]D
M97-C<FEP=&EO;B<@/3X@)TUA;F%G92!Y;W5R(&1O;6%I;BXG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;E]S96QF7U]D:7-A8FQE9"UW87)N:6YG)R`]
M/B`G66]U<B!D;VUA:6X@:7,@9&ES86)L960N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6Y?<V5L9E]?<75I8VLM<V5A<F-H)R`]/B`G37D@9&]M86EN
M<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN7W-E;&9?7W-H;W)T+71I
M=&QE)R`]/B`G37D@9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6Y?<V5L9E]?=&ET;&4G(#T^("=->2!D;VUA:6XG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;E]U;FMN;W=N7U]Q=6EC:RUS96%R8V@G(#T^("=$;VUA
M:6YS)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V)A8VMU<%]?9&5S
M8W)I<'1I;VXG(#T^("="86-K('5P+U)E<W1O<F4@=&AE(&1O;6%I;BP@<V-H
M961U;&4@=&AE(&1O;6%I;B!B86-K=7!S('9I82!0;&5S:R!"86-K=7`@36%N
M86=E<BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?7V1O
M;F4G(#T^("<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?
M7W-H;W)T+71I=&QE)R`]/B`G0F%C:W5P)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO8F%C:W5P7U]T:71L92<@/3X@)T1O;6%I;B`E,2!B86-K=7`G
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?<V5L9E]?9&5S
M8W)I<'1I;VXG(#T^("="86-K('5P+U)E<W1O<F4@>6]U<B!D;VUA:6XL('-C
M:&5D=6QE('1H92!D;VUA:6X@8F%C:W5P<R!V:6$@4&QE<VL@0F%C:W5P($UA
M;F%G97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8F%C:W5P7W-E
M;&9?7V1O;F4G(#T^("<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B
M86-K=7!?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("="86-K=7`G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?<V5L9E]?=&ET;&4G(#T^("=$
M;VUA:6X@8F%C:W5P)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8F%C
M:W5P7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G0F%C:R!U<"]297-T;W)E
M(&$@9&]M86EN+"!S8VAE9'5L92!A(&1O;6%I;B!B86-K=7!S('9I82!0;&5S
M:R!"86-K=7`@36%N86=E<BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]B86-K=7!?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("="86-K=7`G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?=6YK;F]W;E]?=&ET
M;&4G(#T^("=$;VUA:6X@0F%C:W5P)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO8F%C:W5P7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)T1O;6%I
M;B!"86-K=7`G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?
M=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA
M:6X@>6]U('=A;G0@=&\@8F%C:R!U<"!A;F0@8VQI8VL@3F5X="`^/BXG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?=6YK;F]W;E]?=VEZ
M87)D7U\S)R`]/B`G5&\@8F%C:R!U<"!T:&4@9&]M86EN+"!C;&EC:R!"86-K
M=7`@3F]W+B!4;R!R97-T;W)E('1H92!E>&ES=&EN9R!B86-K=7`@9FEL92P@
M8VQI8VL@:71S(&YA;64N(%1O('-C:&5D=6QE(&)A8VMU<',L(&-L:6-K(%-C
M:&5D=6QE9"!"86-K=7`N)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+V-U<W1O;2UB=71T;VYS7U]D97-C<FEP=&EO;B<@/3X@)TQI<W0@;V8@9&]M
M86EN("4Q(&-U<W1O;2!B=71T;VYS+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+V-U<W1O;2UB=71T;VYS7U]S:&]R="UT:71L92<@/3X@)T-U<W1O
M;2!B=71T;VYS)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M
M+6)U='1O;G-?7W1I=&QE)R`]/B`G0W5S=&]M(&)U='1O;G,@9F]R(&1O;6%I
M;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB=71T
M;VYS7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G3&ES="!O9B!Y;W5R(&-U<W1O
M;2!B=71T;VYS+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O
M;2UB=71T;VYS7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G37D@8W5S=&]M(&)U
M='1O;G,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T
M=&]N<U]S96QF7U]T:71L92<@/3X@)TUY(&-U<W1O;2!B=71T;VYS)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G-?=6YK;F]W
M;E]?9&5S8W)I<'1I;VXG(#T^("=,:7-T(&]F(&1O;6%I;B!C=7-T;VT@8G5T
M=&]N<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T
M=&]N<U]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T-U<W1O;2!B=71T;VYS
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G-?
M=6YK;F]W;E]?=&ET;&4G(#T^("=$;VUA:6X@8W5S=&]M(&)U='1O;G,G+`H*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S
M=&]M+6)U='1O;E]?;F]N92UA=F%I;&%B;&4G(#T^("=9;W4@9&]N7"=T(&AA
M=F4@86YY(&1O;6%I;BUL979E;"!C=7-T;VT@8G5T=&]N<RXG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T
M=&]N7U]N;VYE+6%V86EL86)L95]?,2<@/3X@)T-L:65N="`E,2!D;V5S;EPG
M="!H879E(&%N>2!D;VUA:6XM;&5V96P@8W5S=&]M(&)U='1O;G,N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M
M+6)U='1O;E]?;F]N92UA=F%I;&%B;&5?7S(G(#T^("=4:&5R92!A<F4@;F\@
M8W5S=&]M(&)U='1O;G,@9F]R(&1O;6%I;B`E,2XG+`H*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D
M96QE=&5?7V1E<V-R:7!T:6]N)R`]/B`G4F5M;W9E(&1O;6%I;B!C=7-T;VT@
M8G5T=&]N("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O
M;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7U]D;VYE)R`]/B`G1&]M
M86EN(&-U<W1O;2!B=71T;VX@)3$@:&%S(&)E96X@<F5M;W9E9"XG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM
M8G5T=&]N+V1E;&5T95]?<VAO<G0M=&ET;&4G(#T^("=296UO=F4G+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM
M8G5T=&]N+V1E;&5T95]?=&ET;&4G(#T^("=296UO=F4@8W5S=&]M(&)U='1O
M;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB=71T
M;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7W5N:VYO=VY?7V1E<V-R:7!T:6]N
M)R`]/B`G4F5M;W9E(&$@9&]M86EN+6QE=F5L(&-U<W1O;2!B=71T;VXN)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S
M=&]M+6)U='1O;B]D96QE=&5?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=2
M96UO=F4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T
M=&]N<R]C=7-T;VTM8G5T=&]N+V1E;&5T95]U;FMN;W=N7U]T:71L92<@/3X@
M)U)E;6]V92!D;VUA:6X@8W5S=&]M(&)U='1O;B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L
M971E7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)T-U<W1O;2!"=71T;VX@
M4F5M;W9A;"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB
M=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7W5N:VYO=VY?7W=I>F%R9%]?
M,5]U;FMN;W=N)R`]/B`G4V5L96-T(&$@8VQI96YT(&9R;VT@=VAO<V4@9&]M
M86EN('EO=2!W86YT('1O(')E;6]V92!A(&-U<W1O;2!B=71T;VX@86YD(&-L
M:6-K($YE>'0@/CXN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S
M=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?=6YK;F]W;E]?=VEZ
M87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@9G)O;2!W:&EC
M:"!Y;W4@=V%N="!T;R!R96UO=F4@82!C=7-T;VT@8G5T=&]N(&%N9"!C;&EC
M:R!.97AT(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O
M;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7W5N:VYO=VY?7W=I>F%R
M9%]?-%]U;FMN;W=N)R`]/B`G4V5L96-T(&$@8W5S=&]M(&)U='1O;B!Y;W4@
M=V%N="!T;R!R96UO=F4@86YD(&-L:6-K($YE>'0@/CXN)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O
M;B]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\U)R`]/B`G0V]N9FER;2!R96UO
M=FEN9R!T:&4@8W5S=&]M(&)U='1O;B!B>2!S96QE8W1I;F<@=&AE(&-H96-K
M(&)O>"!A;F0@8VQI8VL@1FEN:7-H('1O(&-O;7!L971E;'D@<F5M;W9E('1H
M92!B=71T;VX@86YD(&5X:70@=&AE('=I>F%R9"XG+`H*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P
M<F]P97)T:65S7U]D97-C<FEP=&EO;B<@/3X@)T5D:70@<')O<&5R=&EE<R!O
M9B!D;VUA:6XM;&5V96P@8W5S=&]M(&)U='1O;B`E,2XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N
M+W!R;W!E<G1I97-?7V1O;F4G(#T^("=#=7-T;VT@8G5T=&]N("4Q('!R;W!E
M<G1I97,@:&%V92!B965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T
M:65S7U]S:&]R="UT:71L92<@/3X@)U!R;W!E<G1I97,G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N
M+W!R;W!E<G1I97-?7W1I=&QE)R`]/B`G36]D:69Y(&1O;6%I;B!C=7-T;VT@
M8G5T=&]N("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M
M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?9&5S8W)I
M<'1I;VXG(#T^("=#<F5A=&4@;F5W(&1O;6%I;BUL979E;"!C=7-T;VT@8G5T
M=&]N+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB=71T
M;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]N97=?7V1O;F4G(#T^("=#
M=7-T;VT@8G5T=&]N("4Q(&AA<R!B965N(&-R96%T960N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O
M;B]P<F]P97)T:65S7VYE=U]?<VAO<G0M=&ET;&4G(#T^("=#<F5A=&4G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T
M;VTM8G5T=&]N+W!R;W!E<G1I97-?;F5W7U]T:71L92<@/3X@)T-R96%T92!D
M;VUA:6X@8W5S=&]M(&)U='1O;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]N
M97=?7W=I>F%R9"UT:71L92<@/3X@)T-U<W1O;2!"=71T;VX@0W)E871I;VXG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C
M=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S%?=6YK;F]W
M;B<@/3X@)U-E;&5C="!A(&-L:65N="!F;W(@=VAO<V4@9&]M86EN('EO=2!W
M86YT('1O(&-R96%T92!A(&-U<W1O;2!B=71T;VX@86YD(&-L:6-K($YE>'0@
M/CXN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O
M;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\R7W5N
M:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@9F]R('=H:6-H('EO=2!W86YT
M('1O(&-R96%T92!A(&-U<W1O;2!B=71T;VX@86YD(&-L:6-K($YE>'0@/CXN
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O
M8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\R7W5N:VYO
M=VXG(#T^("=396QE8W0@82!D;VUA:6X@;VX@=VAI8V@@>6]U('=A;G0@=&\@
M;6]D:69Y(&$@8W5S=&]M(&)U='1O;B!A;F0@8VQI8VL@3F5X="`^/BXG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T
M;VTM8G5T=&]N+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S1?;F5W)R`]/B`G
M0VQI8VL@1FEN:7-H('1O(&-R96%T92!T:&4@8W5S=&]M(&)U='1O;B!A;F0@
M97AI="!T:&4@=VEZ87)D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]U;FMN
M;W=N7U]D97-C<FEP=&EO;B<@/3X@)T5D:70@9&]M86EN+6QE=F5L(&-U<W1O
M;2!B=71T;VX@<')O<&5R=&EE<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?
M=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=0<F]P97)T:65S)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U
M='1O;B]P<F]P97)T:65S7W5N:VYO=VY?7W1I=&QE)R`]/B`G36]D:69Y(&1O
M;6%I;B!C=7-T;VT@8G5T=&]N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7W5N
M:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)TUO9&EF>6EN9R!$;VUA:6X@0W5S
M=&]M($)U='1O;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O
M;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]U;FMN;W=N7U]W
M:7IA<F1?7S1?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&-U<W1O;2!B=71T;VX@
M=VAI8V@@<V5T=&EN9W,@>6]U('=A;G0@=&\@;6]D:69Y(&%N9"!C;&EC:R!.
M97AT(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB
M=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA
M<F1?7S4G(#T^("=7:&5N(&1O;F4@=VET:"!C:&%N9VEN9R!P<F]P97)T:65S
M(&]F('1H92!C=7-T;VT@8G5T=&]N+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@
M8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]D87-H8F]A<F0C8W5S=&]M+6)U='1O;G-?7W1I=&QE
M)R`]/B`G0W5S=&]M(&)U='1O;G,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]D87-H8F]A<F0C9F%V;W)I=&5S+W1A8G-?7V1E<V-R:7!T:6]N)R`]
M/B`G4VAO=R!T:&4@9F]L;&]W:6YG('1A8G,@:6X@1F%V;W)I=&5S.B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R9"-F879O<FET97-?
M7W1I=&QE)R`]/B`G1F%V;W)I=&5S)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO9&%S:&)O87)D(VEN9F\O9F]O=&5R7U]D97-C<FEP=&EO;B<@/3X@
M)U-H;W<@=&AE(&9O;&QO=VEN9R!B=71T;VYS(&EN('1H92!F;V]T97(Z)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D(VEN9F]?7V1E
M<V-R:7!T:6]N)R`]/B`G4VAO=R!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N
M.B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R9"-I;F9O
M7U]T:71L92<@/3X@)TEN9F]R;6%T:6]N)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO9&%S:&)O87)D(VUA:6QN86UE<U]?9&5S8W)I<'1I;VXG(#T^
M("=.;R!F879O<FET92!M86EL;F%M97,G+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]D87-H8F]A<F0C;6%I;&YA;65S7U]T:71L92<@/3X@)TUA:6QN
M86UE<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R9"-Q
M=6EC:RUS96%R8VA?7W1I=&QE)R`]/B`G475I8VL@<V5A<F-H)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D(W)E8V5N=%]?9&5S8W)I
M<'1I;VXG(#T^("=.;R!R96-E;G0@<&%G97,G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]D87-H8F]A<F0C<F5C96YT7U]T:71L92<@/3X@)U)E8V5N
M="<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R9"-S:&]R
M=&-U='-?7V1E<V-R:7!T:6]N)R`]/B`G3F\@<VAO<G1C=71S)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D(W-H;W)T8W5T<U]?=&ET
M;&4G(#T^("=3:&]R=&-U=',G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]D87-H8F]A<F0C<W1A=&ES=&EC<U]?9&5S8W)I<'1I;VXG(#T^("=3:&]W
M('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VXZ)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO9&%S:&)O87)D(W-T871I<W1I8W-?7W1I=&QE)R`]/B`G
M4W1A=&ES=&EC<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB
M;V%R9"-T;V]L<R]F;V]T97)?7V1E<V-R:7!T:6]N)R`]/B`G4VAO=R!T:&4@
M9F]L;&]W:6YG(&)U='1O;G,@:6X@=&AE(&9O;W1E<CHG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F0C=&]O;'-?7V1E<V-R:7!T:6]N
M)R`]/B`G4VAO=R!T:&4@9F]L;&]W:6YG(&)U='1O;G,Z)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D(W1O;VQS7U]T:71L92<@/3X@
M)U1O;VQS)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D
M7U]D97-C<FEP=&EO;B<@/3X@)T1E<VMT;W`@;V8@9&]M86EN(&%D;6EN:7-T
M<F%T;W(@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O
M87)D7U]S:&]R="UT:71L92<@/3X@)R4Q7"=S($1E<VMT;W`G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F1?7W1I=&QE)R`]/B`G1&5S
M:W1O<"!O9B!D;VUA:6X@861M:6X@)3$G+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]D87-H8F]A<F1?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=->2!$
M97-K=&]P+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R
M9%]S96QF7U]S:&]R="UT:71L92<@/3X@)T1E<VMT;W`G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F1?<V5L9E]?=&ET;&4G(#T^("=-
M>2!$97-K=&]P)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O
M87)D7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G1&]M86EN(&%D;6EN:7-T
M<F%T;W(@9&5S:W1O<"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D
M87-H8F]A<F1?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=$97-K=&]P)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D7W5N:VYO=VY?
M7W1I=&QE)R`]/B`G1&]M86EN(&%D;6EN(&1E<VMT;W`G+`H*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D+V-U<W1O;6EZ95]?9&5S8W)I
M<'1I;VXG(#T^("=#=7-T;VUI>F4@1&5S:W1O<"!F;W(@1&]M86EN($%D;6EN
M:7-T<F%T;W(@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S
M:&)O87)D+V-U<W1O;6EZ95]?9&5S8W)I<'1I;VXG(#T^("=#=7-T;VUI>F4@
M1&]M86EN($%D;6EN:7-T<F%T;W(@1&5S:W1O<"XG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]D87-H8F]A<F0O8W5S=&]M:7IE7U]D;VYE)R`]/B`G
M1&5S:W1O<"!O9B!$;VUA:6X@061M:6YI<W1R871O<B`E,2!H87,@8F5E;B!U
M<&1A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R
M9"]C=7-T;VUI>F5?7W-H;W)T+71I=&QE)R`]/B`G0W5S=&]M:7IE($1E<VMT
M;W`G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F0O8W5S
M=&]M:7IE7U]S:&]R="UT:71L92<@/3X@)T-U<W1O;6EZ92!$97-K=&]P)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D+V-U<W1O;6EZ
M95]?=&ET;&4G(#T^("=#=7-T;VUI>F4@1&5S:W1O<"!O9B!$;VUA:6X@061M
M:6X@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F0O
M8W5S=&]M:7IE7U]T:71L92<@/3X@)T-U<W1O;6EZ92!$;VUA:6X@061M:6X@
M1&5S:W1O<"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R
M9"]C=7-T;VUI>F5?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=#=7-T;VUI>F4@
M;7D@1&5S:W1O<"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H
M8F]A<F0O8W5S=&]M:7IE7W-E;&9?7V1O;F4G(#T^("=9;W5R($1E<VMT;W`@
M<V5T=&EN9W,@:&%V92!B965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO9&%S:&)O87)D+V-U<W1O;6EZ95]S96QF7U]S:&]R="UT
M:71L92<@/3X@)T-U<W1O;6EZ92!$97-K=&]P)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO9&%S:&)O87)D+V-U<W1O;6EZ95]S96QF7U]T:71L92<@
M/3X@)T-U<W1O;6EZ92!M>2!$97-K=&]P)RP*"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+V1A<VAB;V%R9"]S:&]R=&-U="]P<F]P97)T:65S7U]D97-C
M<FEP=&EO;B<@/3X@)T5D:70@<')O<&5R=&EE<R!O9B!S:&]R=&-U="`E,2XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F0O<VAO<G1C
M=70O<')O<&5R=&EE<U]?9&]N92<@/3X@)U-H;W)T8W5T("4Q(&AA<R!B965N
M('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O
M87)D+W-H;W)T8W5T+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G161I
M="<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R9"]S:&]R
M=&-U="]P<F]P97)T:65S7U]T:71L92<@/3X@)T5D:70@<VAO<G1C=70@)3$G
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F0O<VAO<G1C
M=70O<')O<&5R=&EE<U]N97=?7V1E<V-R:7!T:6]N)R`]/B`G0W)E871E(&YE
M=R!S:&]R=&-U="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H
M8F]A<F0O<VAO<G1C=70O<')O<&5R=&EE<U]N97=?7V1O;F4G(#T^("=3:&]R
M=&-U="`E,2!H87,@8F5E;B!C<F5A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+V1A<VAB;V%R9"]S:&]R=&-U="]P<F]P97)T:65S7VYE=U]?
M<VAO<G0M=&ET;&4G(#T^("=#<F5A=&4@<VAO<G1C=70G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F0O<VAO<G1C=70O<')O<&5R=&EE
M<U]N97=?7W1I=&QE)R`]/B`G0W)E871E('-H;W)T8W5T)RP*"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B87-E<U]?9&5S8W)I<'1I;VXG(#T^
M("=,:7-T(&]F(&1O;6%I;B`E,2!D871A8F%S97,N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO9&%T86)A<V5S7U]S:&]R="UT:71L92<@/3X@)T1A
M=&%B87-E<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B87-E
M<U]?=&ET;&4G(#T^("=$871A8F%S97,@;V8@9&]M86EN("4Q)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO9&%T86)A<V5S7W-E;&9?7V1E<V-R:7!T
M:6]N)R`]/B`G3&ES="!O9B!Y;W5R(&1A=&%B87-E<RXG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]D871A8F%S97-?<V5L9E]?<VAO<G0M=&ET;&4G
M(#T^("=$871A8F%S97,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D
M871A8F%S97-?<V5L9E]?=&ET;&4G(#T^("=->2!D871A8F%S97,G+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S97-?=6YK;F]W;E]?9&5S
M8W)I<'1I;VXG(#T^("=,:7-T(&]F(&1O;6%I;B!D871A8F%S97,N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%T86)A<V5S7W5N:VYO=VY?7W-H
M;W)T+71I=&QE)R`]/B`G1&%T86)A<V5S)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO9&%T86)A<V5S7W5N:VYO=VY?7W1I=&QE)R`]/B`G1&]M86EN
M(&1A=&%B87-E<R<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A
M8F%S97,O9&%T86)A<V5?7V1E<V-R:7!T:6]N)R`]/B`G1&%T86)A<V4@)3$@
M=7-E<G,@86YD(%=E8D%D;6EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+V1A=&%B87-E<R]D871A8F%S95]?;F]N92UA=F%I;&%B;&4G(#T^("=9
M;W4@9&]N7"=T(&AA=F4@86YY(&1A=&%B87-E<RXG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]D871A8F%S97,O9&%T86)A<V5?7VYO;F4M879A:6QA
M8FQE7U\Q)R`]/B`G0VQI96YT("4Q(&1O97-N7"=T(&AA=F4@86YY(&1A=&%B
M87-E<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S97,O
M9&%T86)A<V5?7VYO;F4M879A:6QA8FQE7U\R)R`]/B`G5&AE<F4@87)E(&YO
M(&1A=&%B87-E<R!O;B!D;VUA:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E7U]S:&]R="UT:71L92<@/3X@
M)R4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%T86)A<V5S+V1A
M=&%B87-E7U]T:71L92<@/3X@)T1A=&%B87-E("4Q('5S97)S)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E7W5N:VYO
M=VY?7V1E<V-R:7!T:6]N)R`]/B`G36%N86=E(&1A=&%B87-E('5S97)S(&%N
M9"!A8V-E<W,@5V5B061M:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO9&%T86)A<V5S+V1A=&%B87-E7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]
M/B`G1&%T86)A<V4@=7-E<G,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]D871A8F%S97,O9&%T86)A<V5?=6YK;F]W;E]?=&ET;&4G(#T^("=-86YA
M9V4@9&%T86)A<V4@=7-E<G,G+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO9&%T86)A<V5S+V1A=&%B87-E+V1E;&5T95]?9&5S8W)I<'1I;VXG(#T^
M("=296UO=F4@9&%T86)A<V4@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E+V1E;&5T95]?9&]N92<@/3X@)T1A
M=&%B87-E("4Q(&AA<R!B965N(')E;6]V960N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E+V1E;&5T95]?<VAO<G0M
M=&ET;&4G(#T^("=296UO=F4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]D871A8F%S97,O9&%T86)A<V4O9&5L971E7U]T:71L92<@/3X@)U)E;6]V
M92!D871A8F%S92`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A
M=&%B87-E<R]D871A8F%S92]D96QE=&5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG
M(#T^("=296UO=F4@82!D871A8F%S92XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]D871A8F%S97,O9&%T86)A<V4O9&5L971E7W5N:VYO=VY?7W-H
M;W)T+71I=&QE)R`]/B`G4F5M;W9E)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E+V1E;&5T95]U;FMN;W=N7U]T:71L
M92<@/3X@)U)E;6]V92!D871A8F%S92<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+V1A=&%B87-E<R]D871A8F%S92]D96QE=&5?=6YK;F]W;E]?=VEZ
M87)D+71I=&QE)R`]/B`G1&%T86)A<V4@4F5M;W9A;"<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+V1A=&%B87-E<R]D871A8F%S92]D96QE=&5?=6YK
M;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@
M9G)O;2!W:&EC:"!W86YT('1O(')E;6]V92!A(&1A=&%B87-E(&%N9"!C;&EC
M:R!.97AT(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B
M87-E<R]D871A8F%S92]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\T7W5N:VYO
M=VXG(#T^("=396QE8W0@82!D871A8F%S92!Y;W4@=V%N="!T;R!R96UO=F4@
M86YD(&-L:6-K($YE>'0@/CXN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO9&%T86)A<V5S+V1A=&%B87-E+V1E;&5T95]U;FMN;W=N7U]W:7IA<F1?
M7S4G(#T^("=#;VYF:7)M(')E;6]V:6YG('1H92!D871A8F%S92!B>2!S96QE
M8W1I;F<@=&AE(&-H96-K(&)O>"!A;F0@8VQI8VL@1FEN:7-H('1O(&-O;7!L
M971E;'D@<F5M;W9E('1H92!D871A8F%S92!A;F0@97AI="!T:&4@=VEZ87)D
M+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S97,O9&%T
M86)A<V4O<')O<&5R=&EE<U]N97<M861H;V-?7W=I>F%R9%]?-%]N97<G(#T^
M("=4:&4@9&%T86)A<V4@=VEL;"!B92!C<F5A=&5D(&EM;65D:6%T96QY(&%F
M=&5R('EO=2!C;&EC:R!.97AT(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+V1A=&%B87-E<R]D871A8F%S92]P<F]P97)T:65S7VYE=U]?9&5S
M8W)I<'1I;VXG(#T^("=#<F5A=&4@82!N97<@9&%T86)A<V4N)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E+W!R;W!E
M<G1I97-?;F5W7U]D;VYE)R`]/B`G1&%T86)A<V4@)3$@:&%S(&)E96X@8W)E
M871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S97,O
M9&%T86)A<V4O<')O<&5R=&EE<U]N97=?7W-H;W)T+71I=&QE)R`]/B`G0W)E
M871E(&1A=&%B87-E)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%T
M86)A<V5S+V1A=&%B87-E+W!R;W!E<G1I97-?;F5W7U]T:71L92<@/3X@)T-R
M96%T92!D871A8F%S92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A
M=&%B87-E<R]D871A8F%S92]P<F]P97)T:65S7VYE=U]?=VEZ87)D+71I=&QE
M)R`]/B`G1&%T86)A<V4@0W)E871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]D871A8F%S97,O9&%T86)A<V4O<')O<&5R=&EE<U]N97=?7W=I
M>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&]M86EN(&]N('=H:6-H
M('EO=2!W86YT('1O(&-R96%T92!A(&1A=&%B87-E(&%N9"!C;&EC:R!.97AT
M(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B87-E<R]D
M871A8F%S92]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\T7VYE=R<@/3X@)T-L
M:6-K($9I;FES:"!T;R!C<F5A=&4@=&AE(&1A=&%B87-E(&%N9"!E>&ET('1H
M92!W:7IA<F0N)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B
M87-E<R]D871A8F%S92]W96)A9&UI;E]?9&5S8W)I<'1I;VXG(#T^("=!8V-E
M<W,@5V5B061M:6X@9F]R(&UA;F%G:6YG(&1A=&%B87-E("4Q+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B87-E<R]D871A8F%S92]W96)A
M9&UI;E]?9&]N92<@/3X@)R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+V1A=&%B87-E<R]D871A8F%S92]W96)A9&UI;E]?<VAO<G0M=&ET;&4G(#T^
M("=796)!9&UI;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B
M87-E<R]D871A8F%S92]W96)A9&UI;E]?=&ET;&4G(#T^("=/<&5N(%=E8D%D
M;6EN(&9O<B!D871A8F%S92`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+V1A=&%B87-E<R]D871A8F%S92]W96)A9&UI;E]U;FMN;W=N7U]D97-C
M<FEP=&EO;B<@/3X@)T%C8V5S<R!796)!9&UI;B!F;W(@;6%N86=I;F<@82!D
M871A8F%S92XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S
M97,O9&%T86)A<V4O=V5B861M:6Y?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^
M("=796)!9&UI;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B
M87-E<R]D871A8F%S92]W96)A9&UI;E]U;FMN;W=N7U]T:71L92<@/3X@)T]P
M96X@5V5B061M:6X@9F]R(&1A=&%B87-E)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E+W=E8F%D;6EN7W5N:VYO=VY?
M7W=I>F%R9"UT:71L92<@/3X@)U=E8D%D;6EN(%-T87)T=7`G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S97,O9&%T86)A<V4O=V5B861M
M:6Y?=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D
M;VUA:6X@9F]R('=H;W-E(&1A=&%B87-E('EO=2!W86YT('1O(&]P96X@5V5B
M061M:6X@86YD(&-L:6-K($YE>'0@/CXN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E+W=E8F%D;6EN7W5N:VYO=VY?
M7W=I>F%R9%]?-%]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&%T86)A<V4@=VAI
M8V@@>6]U('=A;G0@=&\@;6%N86=E('9I82!796)!9&UI;BXG+`H*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO9&5L971E7U]D97-C<FEP=&EO;B<@/3X@
M)U)E;6]V92!D;VUA:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO9&5L971E7U]D;VYE)R`]/B`G1&]M86EN("4Q(&AA<R!B965N(')E;6]V
M960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&5L971E7U]S:&]R
M="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+V1E;&5T95]?=&ET;&4G(#T^("=296UO=F4@9&]M86EN("4Q)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&5L971E7W5N:VYO=VY?7V1E<V-R
M:7!T:6]N)R`]/B`G4F5M;W9E(&$@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+V1E;&5T95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@
M)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1E;&5T95]U
M;FMN;W=N7U]T:71L92<@/3X@)U)E;6]V92!D;VUA:6XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]D96QE=&5?=6YK;F]W;E]?=VEZ87)D+71I=&QE
M)R`]/B`G1&]M86EN(%)E;6]V86PG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=3
M96QE8W0@82!D;VUA:6X@>6]U('=A;G0@=&\@<F5M;W9E(&%N9"!C;&EC:R!.
M97AT(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1E;&5T95]U
M;FMN;W=N7U]W:7IA<F1?7S,G(#T^("=#;VYF:7)M(')E;6]V:6YG('1H92!D
M;VUA:6X@8GD@<V5L96-T:6YG('1H92!C:&5C:R!B;W@@86YD(&-L:6-K($9I
M;FES:"!T;R!C;VUP;&5T96QY(')E;6]V92!I="!A;F0@97AI="!T:&4@=VEZ
M87)D+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG7U]N
M;VYE+6%V86EL86)L92<@/3X@)TAO<W1I;F<@:7,@;F]T(&-O;F9I9W5R960@
M;VX@>6]U<B!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:&]S=&EN9U]?;F]N92UA=F%I;&%B;&5?7S(G(#T^("=(;W-T:6YG(&ES(&YO
M="!C;VYF:6=U<F5D(&]N(&1O;6%I;B`E,2XG+`H*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO:&]S=&EN9R]F:6QE+6UA;F%G97)?7V1E<V-R:7!T:6]N
M)R`]/B`G06-C97-S(&1O;6%I;B`E,2!&:6QE($UA;F%G97(N)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]F:6QE+6UA;F%G97)?7V1O
M;F4G(#T^("<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG
M+V9I;&4M;6%N86=E<E]?<VAO<G0M=&ET;&4G(#T^("=&:6QE(&UA;F%G97(G
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+V9I;&4M;6%N
M86=E<E]?=&ET;&4G(#T^("=-86YA9V4@9FEL97,@;VX@9&]M86EN("4Q)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]F:6QE+6UA;F%G
M97)?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=/<F=A;FEZ92!Y;W5R('=E8G-I
M=&4@9FEL97,@86YD(&1I<F5C=&]R:65S('9I82!0;&5S:R!&:6QE($UA;F%G
M97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]F:6QE
M+6UA;F%G97)?<V5L9E]?9&]N92<@/3X@)R<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O9FEL92UM86YA9V5R7W-E;&9?7W-H;W)T+71I
M=&QE)R`]/B`G1FEL92!M86YA9V5R)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]F:6QE+6UA;F%G97)?<V5L9E]?=&ET;&4G(#T^("=-
M86YA9V4@9FEL97,@;VX@;7D@9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]F:6QE+6UA;F%G97)?=6YK;F]W;E]?9&5S8W)I
M<'1I;VXG(#T^("=/<F=A;FEZ92!A('=E8G-I=&4@9FEL97,@86YD(&1I<F5C
M=&]R:65S('9I82!0;&5S:R!&:6QE($UA;F%G97(N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO:&]S=&EN9R]F:6QE+6UA;F%G97)?=6YK;F]W;E]?
M<VAO<G0M=&ET;&4G(#T^("=&:6QE(&UA;F%G97(G+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]H;W-T:6YG+V9I;&4M;6%N86=E<E]U;FMN;W=N7U]T
M:71L92<@/3X@)TUA;F%G92!F:6QE<R!O;B!D;VUA:6XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+V9I;&4M;6%N86=E<E]U;FMN;W=N
M7U]W:7IA<F0M=&ET;&4G(#T^("=-86YA9VEN9R!&:6QE<R<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O9FEL92UM86YA9V5R7W5N:VYO
M=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&]M86EN('=H
M:6-H(&9I;&5S(&%N9"!D:7)E8W1O<FEE<R!Y;W4@=V%N="!T;R!M86YA9V4@
M=VET:"!&:6QE($UA;F%G97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO:&]S=&EN9R]F:6QE+6UA;F%G97)?=6YK;F]W;E]?=VEZ87)D7U\S+W!R
M;W!E<G1I97-?<&AO<W1I;F<G(#T^("=(;W-T:6YG(&ES(&YO="!Y970@8V]N
M9FEG=7)E9"!O;B!T:&4@9&]M86EN+B!0;&5A<V4@<V5T('5P('!H>7-I8V%L
M(&AO<W1I;F<@86YD(&-L:6-K($YE>'0@/CX@=&\@<')O8V5E9"!T;R!&:6QE
M($UA;F%G97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN
M9R]F:6QE+6UA;F%G97)?=6YK;F]W;E]?=VEZ87)D7U\S+W!R;W!E<G1I97-?
M<V5L9BUP:&]S=&EN9R<@/3X@)TAO<W1I;F<@:7,@;F]T('EE="!C;VYF:6=U
M<F5D(&]N('EO=7(@9&]M86EN+B!0;&5A<V4@<V5T('5P('!H>7-I8V%L(&AO
M<W1I;F<@86YD(&-L:6-K($YE>'0@/CX@=&\@<')O8V5E9"!T;R!&:6QE($UA
M;F%G97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]F
M:6QE+6UA;F%G97)?=6YK;F]W;E]?=VEZ87)D7U\T)R`]/B`G5VAE;B!D;VYE
M('=I=&@@;6%N86=I;F<@9FEL97,@;VX@=&AE(&1O;6%I;BP@8VQI8VL@1FEN
M:7-H('1O(&5X:70@=&AE('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]H;W-T:6YG+V9I;&4M;6%N86=E<E]U;FMN;W=N7U]W:7IA<F1?
M7S1?<V5L9B<@/3X@)U=H96X@9&]N92!W:71H(&UA;F%G:6YG(&9I;&5S(&]N
M('EO=7(@9&]M86EN+"!C;&EC:R!&:6YI<V@@=&\@97AI="!T:&4@=VEZ87)D
M+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W!R;W!E
M<G1I97-?7V1E<V-R:7!T:6]N)R`]/B`G4V5T('5P(&AO<W1I;F<@<V5R=FEC
M97,@9F]R(&1O;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]H;W-T:6YG+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G4V5T('5P
M(&AO<W1I;F<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG
M+W!R;W!E<G1I97-?7W1I=&QE)R`]/B`G4V5T('5P(&AO<W1I;F<@;VX@9&]M
M86EN("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]P
M<F]P97)T:65S7V9O<G=A<F1I;F=?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG
M=7)E(&9O<G=A<F1I;F<@;VX@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]F;W)W87)D:6YG7U]D
M;VYE)R`]/B`G1F]R=V%R9&EN9R!P<F]P97)T:65S(&]N(&1O;6%I;B`E,2!H
M879E(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]H;W-T:6YG+W!R;W!E<G1I97-?9F]R=V%R9&EN9U]?<VAO<G0M=&ET;&4G
M(#T^("=#;VYF:6=U<F4@9F]R=V%R9&EN9R<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]F;W)W87)D:6YG7U]T:71L
M92<@/3X@)T-O;F9I9W5R92!F;W)W87)D:6YG(&]N(&1O;6%I;B`E,2<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]P
M:&]S=&EN9U]?9&5S8W)I<'1I;VXG(#T^("=#;VYF:6=U<F4@=FER='5A;"!H
M;W-T(&9O<B!D;VUA:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO:&]S=&EN9R]P<F]P97)T:65S7W!H;W-T:6YG7U]D;VYE)R`]/B`G4&AY
M<VEC86P@:&]S=&EN9R!S971T:6YG<R!O;B!D;VUA:6X@)3$@:&%V92!B965N
M('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN
M9R]P<F]P97)T:65S7W!H;W-T:6YG7U]S:&]R="UT:71L92<@/3X@)T-O;F9I
M9W5R92!P:'ES:6-A;"!H;W-T:6YG)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W!H;W-T:6YG7U]T:71L92<@/3X@
M)T-O;F9I9W5R92!P:'ES:6-A;"!H;W-T:6YG(&]N(&1O;6%I;B`E,2<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]S
M96QF+69O<G=A<F1I;F=?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG=7)E(&9O
M<G=A<F1I;F<@;VX@>6]U<B!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W-E;&8M9F]R=V%R9&EN9U]?
M9&]N92<@/3X@)T9O<G=A<F1I;F<@;VX@>6]U<B!D;VUA:6X@:&%S(&)E96X@
M8V]N9FEG=7)E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T
M:6YG+W!R;W!E<G1I97-?<V5L9BUF;W)W87)D:6YG7U]S:&]R="UT:71L92<@
M/3X@)T-O;F9I9W5R92!F;W)W87)D:6YG)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W-E;&8M9F]R=V%R9&EN9U]?
M=&ET;&4G(#T^("=#;VYF:6=U<F4@9F]R=V%R9&EN9R<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]S96QF+7!H;W-T
M:6YG7U]D97-C<FEP=&EO;B<@/3X@)T-O;F9I9W5R92!V:7)T=6%L(&AO<W0@
M9F]R('EO=7(@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O<')O<&5R=&EE<U]S96QF+7!H;W-T:6YG7U]D;VYE)R`]/B`G
M4&AY<VEC86P@:&]S=&EN9R!S971T:6YG<R!O;B!Y;W5R(&1O;6%I;B!H879E
M(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H
M;W-T:6YG+W!R;W!E<G1I97-?<V5L9BUP:&]S=&EN9U]?<VAO<G0M=&ET;&4G
M(#T^("=#;VYF:6=U<F4@<&AY<VEC86P@:&]S=&EN9R<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]S96QF+7!H;W-T
M:6YG7U]T:71L92<@/3X@)T-O;F9I9W5R92!P:'ES:6-A;"!H;W-T:6YG)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S
M7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G0VQI8VL@=&\@<V5T('5P(&AO<W1I
M;F<@<V5R=FEC97,@9F]R('EO=7(@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]S96QF7U]S:&]R="UT
M:71L92<@/3X@)U-E="!U<"!H;W-T:6YG)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W-E;&9?7W1I=&QE)R`]/B`G
M4V5T('5P(&AO<W1I;F<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H
M;W-T:6YG+W!R;W!E<G1I97-?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=#
M;VYF:6=U<F4@:&]S=&EN9R!S97)V:6-E<R!F;W(@82!D;VUA:6XN)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W5N
M:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G0V]N9FEG=7)E(&AO<W1I;F<G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W!R;W!E<G1I97-?
M=6YK;F]W;E]?=&ET;&4G(#T^("=#;VYF:6=U<F4@:&]S=&EN9R!O;B!A(&1O
M;6%I;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<')O
M<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=#;VYF:6=U<FEN
M9R!(;W-T:6YG)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN
M9R]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G
M4V5L96-T(&$@9&]M86EN(&9O<B!W:&EC:"!Y;W4@=V%N="!T;R!C;VYF:6=U
M<F4@:&]S=&EN9R!S97)V:6-E<R!A;F0@8VQI8VL@3F5X="`^/BXG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W!R;W!E<G1I97-?=6YK
M;F]W;E]?=VEZ87)D7U\T)R`]/B`G4V5L96-T('1H92!T>7!E(&]F(&AO<W1I
M;F<@<V5R=FEC97,@>6]U('=A;G0@=&\@8V]N9FEG=7)E(&]N('1H92!D;VUA
M:6X@86YD(&-L:6-K($YE>'0@/CXN)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-%]F
M;W)W87)D:6YG)R`]/B`G5VAE;B!D;VYE('=I=&@@8V]N9FEG=7)I;F<@9F]R
M=V%R9&EN9R!O;B!T:&4@9&]M86EN+"!C;&EC:R!&:6YI<V@N)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W5N:VYO
M=VY?7W=I>F%R9%]?-%]P:&]S=&EN9R<@/3X@)U=H96X@9&]N92!W:71H(&-O
M;F9I9W5R:6YG('!H>7-I8V%L(&AO<W1I;F<@;VX@=&AE(&1O;6%I;BP@8VQI
M8VL@1FEN:7-H('1O(&%P<&QY('1H92!C;VYF:6=U<F%T:6]N(&%N9"!E>&ET
M('1H92!W:7IA<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S
M=&EN9R]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-%]S96QF)R`]/B`G
M4V5L96-T('1H92!T>7!E(&]F(&AO<W1I;F<@<V5R=FEC97,@>6]U('=A;G0@
M=&\@8V]N9FEG=7)E(&]N('1H92!D;VUA:6X@86YD(&-L:6-K($YE>'0@/CXN
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T
M:65S7W5N:VYO=VY?7W=I>F%R9%]?-%]S96QF+69O<G=A<F1I;F<G(#T^("=7
M:&5N(&1O;F4@=VET:"!C;VYF:6=U<FEN9R!F;W)W87)D:6YG(&]N('EO=7(@
M9&]M86EN+"!C;&EC:R!&:6YI<V@N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-%]S
M96QF+7!H;W-T:6YG)R`]/B`G5VAE;B!D;VYE('=I=&@@8V]N9FEG=7)I;F<@
M<&AY<VEC86P@:&]S=&EN9R!O;B!Y;W5R(&1O;6%I;BP@8VQI8VL@1FEN:7-H
M+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-I=&4M
M87!P;&EC871I;VYS7U]D97-C<FEP=&EO;B<@/3X@)TUA;F%G92!S:71E(&%P
M<&QI8V%T:6]N<R!O;B!D;VUA:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<U]?<VAO<G0M=&ET
M;&4G(#T^("=3:71E(&%P<&QI8V%T:6]N<R<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G-?7W1I=&QE)R`]
M/B`G36%N86=E('-I=&4@87!P;&EC871I;VYS(&]N(&1O;6%I;B`E,2<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A
M=&EO;G-?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=-86YA9V4@<VET92!A<'!L
M:6-A=&EO;G,@;VX@>6]U<B!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<U]S96QF7U]S:&]R
M="UT:71L92<@/3X@)U-I=&4@87!P;&EC871I;VYS)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<U]S96QF
M7U]T:71L92<@/3X@)TUA;F%G92!M>2!S:71E(&%P<&QI8V%T:6]N<R<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A
M=&EO;G-?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=-86YA9V4@<VET92!A
M<'!L:6-A=&EO;G,@;VX@82!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<U]U;FMN;W=N7U]S
M:&]R="UT:71L92<@/3X@)U-I=&4@87!P;&EC871I;VYS)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<U]U
M;FMN;W=N7U]T:71L92<@/3X@)TUA;F%G92!D;VUA:6X@<VET92!A<'!L:6-A
M=&EO;G,G+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S
M:71E+6%P<&QI8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N7U]D97-C<FEP=&EO
M;B<@/3X@)U)E8V]N9FEG=7)E('-I=&4@87!P;&EC871I;VX@)3$N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T
M:6]N<R]S:71E+6%P<&QI8V%T:6]N7U]N;VYE+6%V86EL86)L92<@/3X@)UEO
M=2!D;VY<)W0@:&%V92!A;GD@:6YS=&%L;&5D('-I=&4@87!P;&EC871I;VYS
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA
M<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;E]?;F]N92UA=F%I;&%B;&5?
M7S$G(#T^("=#;&EE;G0@)3$@9&]E<VY<)W0@:&%V92!A;GD@(&EN<W1A;&QE
M9"!S:71E(&%P<&QI8V%T:6]N<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I
M;VY?7VYO;F4M879A:6QA8FQE7U\R)R`]/B`G3F\@<VET92!A<'!L:6-A=&EO
M;G,@87)E(&-U<G)E;G1L>2!I;G-T86QL960@;VX@9&]M86EN("4Q+B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A
M=&EO;G,O<VET92UA<'!L:6-A=&EO;E]?<VAO<G0M=&ET;&4G(#T^("<E,2<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L
M:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;E]?=&ET;&4G(#T^("=3:71E(&%P
M<&QI8V%T:6]N("4Q)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO
M<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]D96QE
M=&5?7V1E<V-R:7!T:6]N)R`]/B`G56YI;G-T86QL('-I=&4@87!P;&EC871I
M;VX@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S
M:71E+6%P<&QI8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N+V1E;&5T95]?9&]N
M92<@/3X@)U-I=&4@87!P;&EC871I;VX@)3$@:&%S(&)E96X@=6YI;G-T86QL
M960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E
M+6%P<&QI8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N+V1E;&5T95]?<VAO<G0M
M=&ET;&4G(#T^("=296UO=F4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I;VXO
M9&5L971E7U]T:71L92<@/3X@)U)E;6]V92!S:71E(&%P<&QI8V%T:6]N("4Q
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P
M<&QI8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N+V1E;&5T95]U;FMN;W=N7U]D
M97-C<FEP=&EO;B<@/3X@)U5N:6YS=&%L;"!A('-I=&4@87!P;&EC871I;VXN
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P
M<&QI8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N+V1E;&5T95]U;FMN;W=N7U]S
M:&]R="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A
M=&EO;B]D96QE=&5?=6YK;F]W;E]?=&ET;&4G(#T^("=296UO=F4@<VET92!A
M<'!L:6-A=&EO;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I
M;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]D96QE=&5?
M=6YK;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G4VET92!!<'!L:6-A=&EO;B!5
M;FEN<W1A;&PG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG
M+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I;VXO9&5L971E7W5N
M:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&]M86EN
M(&]N('=H:6-H('EO=2!W86YT('1O('5N:6YS=&%L;"!A('-I=&4@87!P;&EC
M871I;VX@86YD(&-L:6-K($YE>'0@/CXN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<R]S:71E+6%P<&QI
M8V%T:6]N+V1E;&5T95]U;FMN;W=N7U]W:7IA<F1?7S5?=6YK;F]W;B<@/3X@
M)U-E;&5C="!A('-I=&4@87!P;&EC871I;VX@>6]U('=A;G0@=&\@=6YI;G-T
M86QL("!A;F0@8VQI8VL@3F5X="`^/BXG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC
M871I;VXO9&5L971E7W5N:VYO=VY?7W=I>F%R9%]?-B<@/3X@)T-O;F9I<FT@
M=6YI;G-T86QL:6YG('1H92!S:71E(&%P<&QI8V%T:6]N(&)Y('-E;&5C=&EN
M9R!T:&4@8VAE8VL@8F]X(&%N9"!C;&EC:R!&:6YI<V@@=&\@8V]M<&QE=&5L
M>2!U;FEN<W1A;&P@:70@86YD(&5X:70@=&AE('=I>F%R9"XG+`H*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N
M<R]S:71E+6%P<&QI8V%T:6]N+W!R;W!E<G1I97-?7V1E<V-R:7!T:6]N)R`]
M/B`G4F5C;VYF:6=U<F4@<VET92!A<'!L:6-A=&EO;B`E,2XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS
M+W-I=&4M87!P;&EC871I;VXO<')O<&5R=&EE<U]?9&]N92<@/3X@)U-I=&4@
M87!P;&EC871I;VX@)3$@8V]N9FEG=7)A=&EO;B!H87,@8F5E;B!U<&1A=&5D
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA
M<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S7U]S:&]R
M="UT:71L92<@/3X@)U)E8V]N9FEG=7)E)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<R]S:71E+6%P<&QI
M8V%T:6]N+W!R;W!E<G1I97-?7W1I=&QE)R`]/B`G4F5C;VYF:6=U<F4@<VET
M92!A<'!L:6-A=&EO;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P
M<F]P97)T:65S7VYE=U]?9&5S8W)I<'1I;VXG(#T^("=);G-T86QL(&$@<VET
M92!A<'!L:6-A=&EO;B!O;B!A(&1O;6%I;BXG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P
M;&EC871I;VXO<')O<&5R=&EE<U]N97=?7V1O;F4G(#T^("=3:71E(&%P<&QI
M8V%T:6]N("4Q(&AA<R!B965N(&EN<W1A;&QE9"XG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M
M87!P;&EC871I;VXO<')O<&5R=&EE<U]N97=?7W-H;W)T+71I=&QE)R`]/B`G
M26YS=&%L;"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O
M<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S
M7VYE=U]?=&ET;&4G(#T^("=);G-T86QL('-I=&4@87!P;&EC871I;VXG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC
M871I;VYS+W-I=&4M87!P;&EC871I;VXO<')O<&5R=&EE<U]N97=?7W=I>F%R
M9"UT:71L92<@/3X@)U-I=&4@07!P;&EC871I;VX@26YS=&%L;&%T:6]N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI
M8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N+W!R;W!E<G1I97-?;F5W7U]W:7IA
M<F1?7S$O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S
M)R`]/B`G4V5T('5P('!R;W!E<G1I97,@;V8@=&AE(&-U<W1O;2!B=71T;VX@
M86YD(&-L:6-K($9I;FES:"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I;VXO
M<')O<&5R=&EE<U]N97=?7W=I>F%R9%]?,B]C=7-T;VTM8G5T=&]N<R]C=7-T
M;VTM8G5T=&]N+W!R;W!E<G1I97,G(#T^("=3970@=7`@<')O<&5R=&EE<R!O
M9B!T:&4@8W5S=&]M(&)U='1O;B!A;F0@8VQI8VL@1FEN:7-H+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO
M;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\R
M7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@;VX@=VAI8V@@>6]U('=A
M;G0@=&\@:6YS=&%L;"!S:71E(&%P<&QI8V%T:6]N(&%N9"!C;&EC:R!.97AT
M(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET
M92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S7VYE
M=U]?=VEZ87)D7U\S+W!R;W!E<G1I97-?<&AO<W1I;F<G(#T^("=(;W-T:6YG
M(&ES(&YO="!Y970@8V]N9FEG=7)E9"!O;B!T:&4@9&]M86EN+B!3970@=7`@
M<&AY<VEC86P@:&]S=&EN9R!A;F0@8VQI8VL@3F5X="`^/B!T;R!P<F]C965D
M('1O(&EN<W1A;&QI;F<@=&AE('-I=&4@87!P;&EC871I;VXN)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N
M<R]S:71E+6%P<&QI8V%T:6]N+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S,O
M<')O<&5R=&EE<U]S96QF+7!H;W-T:6YG)R`]/B`G2&]S=&EN9R!I<R!N;W0@
M>65T(&-O;F9I9W5R960@;VX@>6]U<B!D;VUA:6XN(%-E="!U<"!P:'ES:6-A
M;"!H;W-T:6YG(&%N9"!C;&EC:R!.97AT(#X^('1O('!R;V-E960@=&\@:6YS
M=&%L;&EN9R!T:&4@<VET92!A<'!L:6-A=&EO;BXG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M
M87!P;&EC871I;VXO<')O<&5R=&EE<U]N97=?7W=I>F%R9%]?-5]N97<G(#T^
M("=396QE8W0@82!S:71E(&%P<&QI8V%T:6]N('EO=2!W86YT('1O(&EN<W1A
M;&P@86YD(&-L:6-K($YE>'0@/CXN)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<R]S:71E+6%P<&QI8V%T
M:6]N+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S5?;F5W+65X=')A)R`]/B`G
M1&5F:6YE('=H870@<VAO=6QD(&)E(&1O;F4@=&\@=&AE(&5X=')A(&9I;&5S
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA
M<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S7VYE=U]?
M=VEZ87)D7U\U7VYE=RUI;F9O)R`]/B`G0VQI8VL@3F5X="`^/B!T;R!I;G-T
M86QL('1H92!S:71E(&%P<&QI8V%T:6]N+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L
M:6-A=&EO;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\U7VYE=RUI;G-T86QL
M)R`]/B`G4W!E8VEF>2!T:&4@<VET92!A<'!L:6-A=&EO;B!P87)A;65T97)S
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA
M<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S7VYE=U]?
M=VEZ87)D7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I
M97,G(#T^("=3970@=7`@<')O<&5R=&EE<R!O9B!T:&4@8W5S=&]M(&)U='1O
M;B!A;F0@8VQI8VL@1FEN:7-H+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO
M;B]P<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G4F5C;VYF
M:6=U<F4@82!S:71E(&%P<&QI8V%T:6]N+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L
M:6-A=&EO;B]P<F]P97)T:65S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G
M4F5C;VYF:6=U<F4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T
M:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I;VXO<')O<&5R
M=&EE<U]U;FMN;W=N7U]T:71L92<@/3X@)U)E8V]N9FEG=7)E('-I=&4@87!P
M;&EC871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG
M+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I;VXO<')O<&5R=&EE
M<U]U;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=3:71E($%P<&QI8V%T:6]N
M(%)E8V]N9FEG=7)A=&EO;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P
M<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L
M96-T(&$@9&]M86EN(&]N('=H:6-H('EO=2!W86YT('1O(')E8V]N9FEG=7)E
M(&$@<VET92!A<'!L:6-A=&EO;BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I
M;VXO<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S5?=6YK;F]W;B<@/3X@
M)U-E;&5C="!A('-I=&4@87!P;&EC871I;VX@>6]U('=A;G0@=&\@<F5C;VYF
M:6=U<F4N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S
M:71E+6%P<&QI8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N+W!R;W!E<G1I97-?
M=6YK;F]W;E]?=VEZ87)D7U\V)R`]/B`G4W!E8VEF>2!T:&4@<VET92!A<'!L
M:6-A=&EO;B!P87)A;65T97)S+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G-?7V1E<V-R:7!T:6]N)R`]/B`G3&ES
M="!O9B!D;VUA:6X@)3$@<W5B9&]M86EN<RXG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G-?7W-H;W)T+71I=&QE)R`]
M/B`G4W5B9&]M86EN<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO
M<W1I;F<O<W5B9&]M86EN<U]?=&ET;&4G(#T^("=3=6)D;VUA:6YS(&]F(&1O
M;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O
M<W5B9&]M86EN<U]S96QF7U]D97-C<FEP=&EO;B<@/3X@)TQI<W0@;V8@>6]U
M<B!S=6)D;VUA:6YS+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO
M<W1I;F<O<W5B9&]M86EN<U]S96QF7U]S:&]R="UT:71L92<@/3X@)U-U8F1O
M;6%I;G,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U
M8F1O;6%I;G-?<V5L9E]?=&ET;&4G(#T^("=->2!S=6)D;VUA:6YS)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS7W5N
M:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G4W5B9&]M86EN<R!O9B!A(&1O;6%I
M;BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O
M;6%I;G-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=3=6)D;VUA:6YS)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS
M7W5N:VYO=VY?7W1I=&QE)R`]/B`G4W5B9&]M86EN<R!O9B!A(&1O;6%I;B<L
M"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I
M;G,O<W5B9&]M86EN7U]D97-C<FEP=&EO;B<@/3X@)U!R;W!E<G1I97,@;V8@
M<W5B9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO
M<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA:6Y?7VYO;F4M879A:6QA8FQE)R`]
M/B`G66]U(&1O;EPG="!H879E(&%N>2!S=6)D;VUA:6YS+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA
M:6Y?7VYO;F4M879A:6QA8FQE7U\Q)R`]/B`G0VQI96YT("4Q(&1O97-N7"=T
M(&AA=F4@86YY('-U8F1O;6%I;G,N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I;E]?;F]N92UA=F%I
M;&%B;&5?7S(G(#T^("=4:&5R92!A<F4@;F\@<W5B9&]M86EN<R!O;B!D;VUA
M:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S
M=6)D;VUA:6YS+W-U8F1O;6%I;E]?<VAO<G0M=&ET;&4G(#T^("<E,2<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S
M=6)D;VUA:6Y?7W1I=&QE)R`]/B`G4W5B9&]M86EN("4Q)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I
M;E]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T-O;F9I9W5R92!S=6)D;VUA
M:6X@:&]S=&EN9R!S971T:6YG<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN7W5N:VYO=VY?7W-H
M;W)T+71I=&QE)R`]/B`G4W5B9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I;E]U;FMN;W=N
M7U]T:71L92<@/3X@)T-O;F9I9W5R92!S=6)D;VUA:6XG+`H*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I
M;B]D96QE=&5?7V1E<V-R:7!T:6]N)R`]/B`G4F5M;W9E('-U8F1O;6%I;B`E
M,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O
M;6%I;G,O<W5B9&]M86EN+V1E;&5T95]?9&]N92<@/3X@)U-U8F1O;6%I;B`E
M,2!H87,@8F5E;B!R96UO=F5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO9&5L971E7U]S:&]R
M="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO9&5L971E7U]T:71L
M92<@/3X@)U)E;6]V92!S=6)D;VUA:6X@)3$G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+V1E;&5T
M95]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T1E;&5T92!S=6)D;VUA:6X@
M8V]N9FEG=7)A=&EO;B!A;F0@8V]N=&5N="XG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+V1E;&5T
M95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA
M:6XO9&5L971E7W5N:VYO=VY?7W1I=&QE)R`]/B`G4F5M;W9E('-U8F1O;6%I
M;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M
M86EN<R]S=6)D;VUA:6XO9&5L971E7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@
M/3X@)U-U8F1O;6%I;B!296UO=F%L)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I;B]D96QE=&5?=6YK
M;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@
M9G)O;2!W:&EC:"!Y;W4@=V%N="!T;R!R96UO=F4@82!S=6)D;VUA:6XN)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS
M+W-U8F1O;6%I;B]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\U7W5N:VYO=VXG
M(#T^("=396QE8W0@82!S=6)D;VUA:6X@>6]U('=A;G0@=&\@<F5M;W9E+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN
M<R]S=6)D;VUA:6XO9&5L971E7W5N:VYO=VY?7W=I>F%R9%]?-B<@/3X@)T-O
M;F9I<FT@<F5M;W9I;F<@=&AE('-U8F1O;6%I;B!B>2!S96QE8W1I;F<@=&AE
M(&-H96-K(&)O>"!A;F0@8VQI8VL@9FEN:7-H('1O(&-O;7!L971E;'D@<F5M
M;W9E(&ET(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO<')O
M<&5R=&EE<U]?9&5S8W)I<'1I;VXG(#T^("=#;VYF:6=U<F4@<W5B9&]M86EN
M("4Q(&AO<W1I;F<@<V5T=&EN9W,N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I;B]P<F]P97)T:65S
M7U]D;VYE)R`]/B`G4W5B9&]M86EN("4Q(&-O;F9I9W5R871I;VX@:&%S(&)E
M96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T
M:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?7W-H;W)T+71I
M=&QE)R`]/B`G)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T
M:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?7W1I=&QE)R`]
M/B`G0V]N9FEG=7)E('-U8F1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO<')O<&5R
M=&EE<U]N97<M861H;V-?7W=I>F%R9%]?-5]N97<G(#T^("=.97<@<W5B9&]M
M86EN('=I;&P@8F4@8W)E871E9"!I;6UE9&EA=&5L>2!A9G1E<B!Y;W4@8VQI
M8VL@3F5X="`^/BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T
M:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?;F5W7U]D97-C
M<FEP=&EO;B<@/3X@)T-R96%T92!N97<@<W5B9&]M86EN+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA
M:6XO<')O<&5R=&EE<U]N97=?7V1O;F4G(#T^("=3=6)D;VUA:6X@)3$@:&%S
M(&)E96X@8W)E871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H
M;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?;F5W7U]S
M:&]R="UT:71L92<@/3X@)T-R96%T92!S=6)D;VUA:6XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN
M+W!R;W!E<G1I97-?;F5W7U]T:71L92<@/3X@)T-R96%T92!S=6)D;VUA:6XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I
M;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?;F5W7U]W:7IA<F0M=&ET;&4G(#T^
M("=3=6)D;VUA:6X@0W)E871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?
M;F5W7U]W:7IA<F1?7S)?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&1O;6%I;B!O
M;B!W:&EC:"!Y;W4@=V%N="!T;R!C<F5A=&4@82!S=6)D;VUA:6XN)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U
M8F1O;6%I;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\S+W!R;W!E<G1I97-?
M<&AO<W1I;F<G(#T^("=(;W-T:6YG(&ES(&YO="!Y970@8V]N9FEG=7)E9"!O
M;B!T:&4@9&]M86EN+B!3970@=7`@<&AY<VEC86P@:&]S=&EN9R!A;F0@8VQI
M8VL@3F5X="`^/B!T;R!P<F]C965D('1O('-U8F1O;6%I;B!C<F5A=&EO;BXG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I
M;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S,O<')O<&5R
M=&EE<U]S96QF+7!H;W-T:6YG)R`]/B`G2&]S=&EN9R!I<R!N;W0@>65T(&-O
M;F9I9W5R960@;VX@>6]U<B!D;VUA:6XN(%-E="!U<"!P:'ES:6-A;"!H;W-T
M:6YG(&%N9"!C;&EC:R!.97AT(#X^('1O('!R;V-E960@=&\@<W5B9&]M86EN
M(&-R96%T:6]N+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I
M;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO<')O<&5R=&EE<U]N97=?7W=I>F%R
M9%]?-5]N97<G(#T^("=3<&5C:69Y('1H92!S=6)D;VUA:6X@:&]S=&EN9R!P
M87)A;65T97)S(&%N9"!C;&EC:R!&:6YI<V@@=&\@8W)E871E('1H92!S=6)D
M;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S
M=6)D;VUA:6YS+W-U8F1O;6%I;B]P<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R
M:7!T:6]N)R`]/B`G0V]N9FEG=7)E('-U8F1O;6%I;B!H;W-T:6YG('-E='1I
M;F=S+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B
M9&]M86EN<R]S=6)D;VUA:6XO<')O<&5R=&EE<U]U;FMN;W=N7U]S:&]R="UT
M:71L92<@/3X@)U-U8F1O;6%I;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO<')O<&5R=&EE<U]U
M;FMN;W=N7U]T:71L92<@/3X@)T-O;F9I9W5R92!S=6)D;VUA:6XG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B
M9&]M86EN+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G
M4W5B9&]M86EN($-O;F9I9W5R871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I
M97-?=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D
M;VUA:6X@=VAO<V4@<W5B9&]M86EN('EO=2!W86YT('1O(')E8V]N9FEG=7)E
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M
M86EN<R]S=6)D;VUA:6XO<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S5?
M=6YK;F]W;B<@/3X@)U-E;&5C="!A('-U8F1O;6%I;B!Y;W4@=V%N="!T;R!R
M96-O;F9I9W5R92XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T
M:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?=6YK;F]W;E]?
M=VEZ87)D7U\V)R`]/B`G5VAE;B!D;VYE('=I=&@@8V]N9FEG=7)I;F<@=&AE
M('-U8F1O;6%I;B!H;W-T:6YG('-E='1I;F=S+"!C;&EC:R!&:6YI<V@@=&\@
M87!P;'D@8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<U]?9&5S8W)I
M<'1I;VXG(#T^("=,:7-T(&]F(&1O;6%I;B`E,2!W96(@=7-E<G,N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G-?7W-H
M;W)T+71I=&QE)R`]/B`G5V5B('5S97)S)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G-?7W1I=&QE)R`]/B`G5V5B('5S
M97)S(&]F(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O=V5B+75S97)S7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G3&ES
M="!O9B!Y;W5R('=E8B!U<V5R<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]H;W-T:6YG+W=E8BUU<V5R<U]S96QF7U]S:&]R="UT:71L92<@/3X@
M)U=E8B!U<V5R<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I
M;F<O=V5B+75S97)S7W-E;&9?7W1I=&QE)R`]/B`G37D@=V5B('5S97)S)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G-?
M=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=,:7-T(&]F(&1O;6%I;B!W96(@
M=7-E<G,N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W
M96(M=7-E<G-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=796(@=7-E<G,G
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R
M<U]U;FMN;W=N7U]T:71L92<@/3X@)T1O;6%I;B!W96(@=7-E<G,G+`H*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G,O<')O
M<&5R=&EE<U]?9&5S8W)I<'1I;VXG(#T^("=796(@=7-E<G,@<')E9F5R96YC
M97,@;VX@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O=V5B+75S97)S+W!R;W!E<G1I97-?7V1O;F4G(#T^("=796(@
M=7-E<G,@<')E9F5R96YC97,@:&%V92!B965N('5P9&%T960@;VX@9&]M86EN
M("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B
M+75S97)S+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G4')E9F5R96YC
M97,@9F]R('=E8B!U<V5R<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O=V5B+75S97)S+W!R;W!E<G1I97-?7W1I=&QE)R`]/B`G5V5B
M('5S97)S('!R969E<F5N8V5S(&]N(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W!R;W!E<G1I97-?
M<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=9;W5R('=E8B!U<V5R<R!P<F5F97)E
M;F-E<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B
M+75S97)S+W!R;W!E<G1I97-?<V5L9E]?9&]N92<@/3X@)UEO=7(@=V5B('5S
M97)S('!R969E<F5N8V5S(&AA=F4@8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W!R;W!E<G1I
M97-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=796(@=7-E<G,@<')E9F5R96YC
M97,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU
M<V5R<R]P<F]P97)T:65S7W-E;&9?7W1I=&QE)R`]/B`G37D@=V5B('5S97)S
M('!R969E<F5N8V5S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S
M=&EN9R]W96(M=7-E<G,O<')O<&5R=&EE<U]U;FMN;W=N7U]D97-C<FEP=&EO
M;B<@/3X@)U=E8B!U<V5R<R!P<F5F97)E;F-E<R!O9B!A(&1O;6%I;BXG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]P
M<F]P97)T:65S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G4')E9F5R96YC
M97,@9F]R('=E8B!U<V5R<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O=V5B+75S97)S+W!R;W!E<G1I97-?=6YK;F]W;E]?=&ET;&4G
M(#T^("=796(@=7-E<G,@<')E9F5R96YC97,@;V8@82!D;VUA:6XG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]P<F]P
M97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T
M(&$@9&]M86EN(&9O<B!W:&EC:"!Y;W4@=V%N="!T;R!C;VYF:6=U<F4@=V5B
M('5S97)S('!R969E<F5N8V5S+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VAO<W1I;F<O=V5B+75S97)S+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ
M87)D7U\U)R`]/B`G5VAE;B!D;VYE('=I=&@@961I=&EN9R!T:&4@=V5B('5S
M97)S('!R969E<F5N8V5S+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@8VAA;F=E
M<R!A;F0@97AI="!T:&4@=VEZ87)D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W!R;W!E<G1I97-?=6YK;F]W;E]?
M=VEZ87)D7U\U7W-E;&8G(#T^("=7:&5N(&1O;F4@=VET:"!E9&ET:6YG('EO
M=7(@=V5B('5S97)S('!R969E<F5N8V5S+"!C;&EC:R!&:6YI<V@@=&\@87!P
M;'D@8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]W96(M=7-E<E]?
M9&5S8W)I<'1I;VXG(#T^("=796(@=7-E<B`E,2!P<F]P97)T:65S+B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E
M8BUU<V5R7U]N;VYE+6%V86EL86)L92<@/3X@)UEO=2!D;VY<)W0@:&%V92!A
M;GD@=V5B('5S97)S+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO
M<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R7U]N;VYE+6%V86EL86)L95]?,2<@
M/3X@)T-L:65N="`E,2!D;V5S;EPG="!H879E(&%N>2!W96(@=7-E<G,N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G,O
M=V5B+75S97)?7VYO;F4M879A:6QA8FQE7U\R)R`]/B`G5&AE<F4@87)E(&YO
M('=E8B!U<V5R(&%C8V]U;G1S(&]N(&1O;6%I;B`E,2XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]W96(M=7-E<E]?
M<VAO<G0M=&ET;&4G(#T^("<E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R7U]T:71L92<@/3X@)U=E
M8B!U<V5R("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN
M9R]W96(M=7-E<G,O=V5B+75S97)?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^
M("=#:&%N9V4@<&%S<W=O<F0@9F]R('=E8B!U<V5R(&%C8V]U;G0L(&QI;6ET
M(&1I<VL@<W!A8V4@=7-A9V4@86YD('-E="!U<"!S8W)I<'1S('-U<'!O<G0N
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E
M<G,O=V5B+75S97)?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=796(@=7-E
M<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S
M97)S+W=E8BUU<V5R7W5N:VYO=VY?7W1I=&QE)R`]/B`G0V]N9FEG=7)E('=E
M8B!U<V5R(&%C8V]U;G0G+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:&]S=&EN9R]W96(M=7-E<G,O=V5B+75S97(O9&5L971E7U]D97-C<FEP=&EO
M;B<@/3X@)T1E;&5T92!W96(@=7-E<B!A8V-O=6YT(&%N9"!C;VYT96YT+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S
M+W=E8BUU<V5R+V1E;&5T95]?9&]N92<@/3X@)U=E8B!U<V5R("4Q(&AA<R!B
M965N(')E;6]V960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S
M=&EN9R]W96(M=7-E<G,O=V5B+75S97(O9&5L971E7U]S:&]R="UT:71L92<@
M/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I
M;F<O=V5B+75S97)S+W=E8BUU<V5R+V1E;&5T95]?=&ET;&4G(#T^("=296UO
M=F4@=V5B('5S97(@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H
M;W-T:6YG+W=E8BUU<V5R<R]W96(M=7-E<B]D96QE=&5?=6YK;F]W;E]?9&5S
M8W)I<'1I;VXG(#T^("=$96QE=&4@82!W96(@=7-E<B!A8V-O=6YT(&%N9"!C
M;VYT96YT+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O
M=V5B+75S97)S+W=E8BUU<V5R+V1E;&5T95]U;FMN;W=N7U]S:&]R="UT:71L
M92<@/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO
M<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+V1E;&5T95]U;FMN;W=N7U]T:71L
M92<@/3X@)U)E;6]V92!W96(@=7-E<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+V1E;&5T95]U;FMN
M;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=796(@57-E<B!296UO=F%L)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G,O=V5B
M+75S97(O9&5L971E7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G
M4V5L96-T(&$@9&]M86EN(&9R;VT@=VAI8V@@>6]U('=A;G0@=&\@<F5M;W9E
M(&$@=V5B('5S97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S
M=&EN9R]W96(M=7-E<G,O=V5B+75S97(O9&5L971E7W5N:VYO=VY?7W=I>F%R
M9%]?-5]U;FMN;W=N)R`]/B`G4V5L96-T(&$@=V5B('5S97(@86-C;W5N="!Y
M;W4@=V%N="!T;R!R96UO=F4N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO:&]S=&EN9R]W96(M=7-E<G,O=V5B+75S97(O9&5L971E7W5N:VYO=VY?
M7W=I>F%R9%]?-B<@/3X@)T-O;F9I<FT@<F5M;W9I;F<@=&AE('=E8B!U<V5R
M(&%C8V]U;G0@8GD@<V5L96-T:6YG('1H92!C:&5C:R!B;W@@86YD(&-L:6-K
M(&9I;FES:"!T;R!C;VUP;&5T96QY(')E;6]V92!I="!A;F0@97AI="!T:&4@
M=VEZ87)D+BXG+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN
M9R]W96(M=7-E<G,O=V5B+75S97(O<')O<&5R=&EE<U]?9&5S8W)I<'1I;VXG
M(#T^("=%9&ET('!R;W!E<G1I97,@;V8@=V5B('5S97(@)3$N)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G,O=V5B+75S
M97(O<')O<&5R=&EE<U]?9&]N92<@/3X@)U=E8B!U<V5R("4Q(&%C8V]U;G0@
M:&%V92!B965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO:&]S=&EN9R]W96(M=7-E<G,O=V5B+75S97(O<')O<&5R=&EE<U]?<VAO
M<G0M=&ET;&4G(#T^("<E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R;W!E<G1I97-?7W1I=&QE
M)R`]/B`G0V]N9FEG=7)E('=E8B!U<V5R(&%C8V]U;G0@)3$G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]W96(M=7-E
M<B]P<F]P97)T:65S7VYE=RUA9&AO8U]?=VEZ87)D7U\U7VYE=R<@/3X@)TYE
M=R!W96(@=7-E<B!A8V-O=6YT('=I;&P@8F4@8W)E871E9"!I;6UE9&EA=&5L
M>2!A9G1E<B!Y;W4@8VQI8VL@3F5X="`^/BXG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]W96(M=7-E<B]P<F]P97)T
M:65S7VYE=U]?9&5S8W)I<'1I;VXG(#T^("=#<F5A=&4@;F5W('=E8B!U<V5R
M(&%C8V]U;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN
M9R]W96(M=7-E<G,O=V5B+75S97(O<')O<&5R=&EE<U]N97=?7V1O;F4G(#T^
M("=796(@=7-E<B`E,2!H87,@8F5E;B!C<F5A=&5D+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R
M;W!E<G1I97-?;F5W7U]S:&]R="UT:71L92<@/3X@)T-R96%T92!W96(@=7-E
M<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S
M97)S+W=E8BUU<V5R+W!R;W!E<G1I97-?;F5W7U]T:71L92<@/3X@)T-R96%T
M92!W96(@=7-E<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I
M;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R;W!E<G1I97-?;F5W7U]W:7IA<F0M
M=&ET;&4G(#T^("=796(@=7-E<B!C<F5A=&EO;B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R;W!E
M<G1I97-?;F5W7U]W:7IA<F1?7S)?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&1O
M;6%I;B!O;B!W:&EC:"!Y;W4@=V%N="!T;R!C<F5A=&4@=V5B('5S97(@86-C
M;W5N="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E
M8BUU<V5R<R]W96(M=7-E<B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\S+W!R
M;W!E<G1I97-?<&AO<W1I;F<G(#T^("=(;W-T:6YG(&ES(&YO="!Y970@8V]N
M9FEG=7)E9"!O;B!T:&4@9&]M86EN+B!3970@=7`@<&AY<VEC86P@:&]S=&EN
M9R!A;F0@8VQI8VL@3F5X="`^/B!T;R!P<F]C965D('1O(&-R96%T:6YG('=E
M8B!U<V5R(&%C8V]U;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:&]S=&EN9R]W96(M=7-E<G,O=V5B+75S97(O<')O<&5R=&EE<U]N97=?7W=I
M>F%R9%]?,R]P<F]P97)T:65S7W-E;&8M<&AO<W1I;F<G(#T^("=(;W-T:6YG
M(&ES(&YO="!Y970@8V]N9FEG=7)E9"!O;B!Y;W5R(&1O;6%I;BX@4V5T('5P
M('!H>7-I8V%L(&AO<W1I;F<@86YD(&-L:6-K($YE>'0@/CX@=&\@<')O8V5E
M9"!T;R!C<F5A=&EN9R!W96(@=7-E<B!A8V-O=6YT+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R
M;W!E<G1I97-?;F5W7U]W:7IA<F1?7S5?;F5W)R`]/B`G0VQI8VL@1FEN:7-H
M('1O(&-R96%T92!T:&4@=V5B('5S97(@86-C;W5N="XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]W96(M=7-E<B]P
M<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G0VAA;F=E('!A
M<W-W;W)D(&9O<B!W96(@=7-E<B!A8V-O=6YT+"!L:6UI="!D:7-K('-P86-E
M('5S86=E(&%N9"!S970@=7`@<V-R:7!T<R!S=7!P;W)T+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R
M+W!R;W!E<G1I97-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=796(@=7-E
M<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S
M97)S+W=E8BUU<V5R+W!R;W!E<G1I97-?=6YK;F]W;E]?=&ET;&4G(#T^("=#
M;VYF:6=U<F4@=V5B('5S97(@86-C;W5N="<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R;W!E<G1I
M97-?=6YK;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G0V]N9FEG=7)I;F<@5V5B
M(%5S97(@06-C;W5N="<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO
M<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R;W!E<G1I97-?=6YK;F]W;E]?
M=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@;VX@=VAI
M8V@@>6]U('=A;G0@=&\@<F5C;VYF:6=U<F4@=V5B('5S97(@86-C;W5N="XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R
M<R]W96(M=7-E<B]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-5]U;FMN
M;W=N)R`]/B`G4V5L96-T('=E8B!U<V5R(&%C8V]U;G0@>6]U('=A;G0@=&\@
M<F5C;VYF:6=U<F4N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S
M=&EN9R]W96(M=7-E<G,O=V5B+75S97(O<')O<&5R=&EE<U]U;FMN;W=N7U]W
M:7IA<F1?7S8G(#T^("=7:&5N(&1O;F4@=VET:"!C;VYF:6=U<FEN9R!T:&4@
M=V5B('5S97(@86-C;W5N="P@8VQI8VL@1FEN:7-H('1O(&%P<&QY(&-H86YG
M97,@86YD(&5X:70@=&AE('=I>F%R9"XG+`H*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:6YD:6-A=&]R+61I<VLM<W!A8V4M;&EM:70M=7-A9V5?7V1E
M<V-R:7!T:6]N)R`]/B`G1&ES:R!S<&%C92!U<V%G92!L:6UI="!F;W(@9&]M
M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O
M<BUD:7-K+7-P86-E+6QI;6ET+75S86=E7U]S:&]R="UT:71L92<@/3X@)T1I
M<VL@<W!A8V4@=7-A9V4@;&EM:70G+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]I;F1I8V%T;W(M9&ES:RUS<&%C92UL:6UI="UU<V%G95]?=&ET;&4G
M(#T^("=$:7-K('-P86-E('5S86=E(&QI;6ET(&9O<B!D;VUA:6X@)3$G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M9&ES:RUS<&%C
M92UL:6UI="UU<V%G95]S96QF7U]D97-C<FEP=&EO;B<@/3X@)T1I<VL@<W!A
M8V4@=7-A9V4@;&EM:70@9F]R('EO=7(@9&]M86EN+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUD:7-K+7-P86-E+6QI;6ET+75S
M86=E7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G1&ES:R!S<&%C92!U<V%G92!L
M:6UI="<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUD
M:7-K+7-P86-E+6QI;6ET+75S86=E7W-E;&9?7W1I=&QE)R`]/B`G1&ES:R!S
M<&%C92!U<V%G92!L:6UI="!F;W(@>6]U<B!D;VUA:6XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M9&ES:RUS<&%C92UL:6UI="UU
M<V%G95]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T1I<VL@<W!A8V4@=7-A
M9V4@;&EM:70@9F]R(&$@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VEN9&EC871O<BUD:7-K+7-P86-E+6QI;6ET+75S86=E7W5N:VYO
M=VY?7W-H;W)T+71I=&QE)R`]/B`G1&ES:R!S<&%C92!U<V%G92!L:6UI="<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUD:7-K+7-P
M86-E+6QI;6ET+75S86=E7W5N:VYO=VY?7W1I=&QE)R`]/B`G1&ES:R!S<&%C
M92!U<V%G92!L:6UI="!F;W(@82!D;VUA:6XG+`H*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO:6YD:6-A=&]R+65X<&ER871I;VY?7V1E<V-R:7!T:6]N
M)R`]/B`G1&]M86EN("4Q(&5X<&ER871I;VX@9&%T92`N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+65X<&ER871I;VY?7W-H;W)T
M+71I=&QE)R`]/B`G17AP:7)A=&EO;B!D871E)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO:6YD:6-A=&]R+65X<&ER871I;VY?7W1I=&QE)R`]/B`G
M1&]M86EN("4Q(&5X<&ER871I;VX@9&%T92<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VEN9&EC871O<BUE>'!I<F%T:6]N7W-E;&9?7V1E<V-R:7!T
M:6]N)R`]/B`G66]U<B!D;VUA:6X@97AP:7)A=&EO;B!D871E+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUE>'!I<F%T:6]N7W-E
M;&9?7W-H;W)T+71I=&QE)R`]/B`G17AP:7)A=&EO;B!D871E)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+65X<&ER871I;VY?<V5L
M9E]?=&ET;&4G(#T^("=9;W5R(&1O;6%I;B!E>'!I<F%T:6]N(&1A=&4N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+65X<&ER871I
M;VY?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=$;VUA:6X@97AP:7)A=&EO
M;B!D871E+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O
M<BUE>'!I<F%T:6]N7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G17AP:7)A
M=&EO;B!D871E)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A
M=&]R+65X<&ER871I;VY?=6YK;F]W;E]?=&ET;&4G(#T^("=$;VUA:6X@97AP
M:7)A=&EO;B!D871E)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN
M9&EC871O<BUF=6QL+7-T871U<U]?9&5S8W)I<'1I;VXG(#T^("=#;VUP;&5T
M92!S=&%T=7,@;V8@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VEN9&EC871O<BUF=6QL+7-T871U<U]?<VAO<G0M=&ET;&4G(#T^
M("=#;VUP;&5T92!S=&%T=7,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]I;F1I8V%T;W(M9G5L;"US=&%T=7-?7W1I=&QE)R`]/B`G0V]M<&QE=&4@
M<W1A='5S(&]F(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VEN9&EC871O<BUF=6QL+7-T871U<U]S96QF7U]D97-C<FEP=&EO;B<@
M/3X@)T-O;7!L971E('-T871U<R!O9B!Y;W5R(&1O;6%I;BXG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M9G5L;"US=&%T=7-?<V5L
M9E]?<VAO<G0M=&ET;&4G(#T^("=#;VUP;&5T92!S=&%T=7,G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M9G5L;"US=&%T=7-?<V5L
M9E]?=&ET;&4G(#T^("=#;VUP;&5T92!S=&%T=7,@;V8@>6]U<B!D;VUA:6XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M9G5L;"US
M=&%T=7-?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=#;VUP;&5T92!S=&%T
M=7,@;V8@82!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:6YD:6-A=&]R+69U;&PM<W1A='5S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]
M/B`G0V]M<&QE=&4@<W1A='5S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO:6YD:6-A=&]R+69U;&PM<W1A='5S7W5N:VYO=VY?7W1I=&QE)R`]/B`G
M0V]M<&QE=&4@<W1A='5S(&]F(&$@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VEN9&EC871O<BUI<%]?9&5S8W)I<'1I;VXG(#T^("=)
M4"!A9&1R97-S(&]F(&1O;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]I;F1I8V%T;W(M:7!?7W-H;W)T+71I=&QE)R`]/B`G25`@861D
M<F5S<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUI
M<%]?=&ET;&4G(#T^("=)4"!A9&1R97-S(&]F(&1O;6%I;B`E,2<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUI<%]S96QF7U]D97-C
M<FEP=&EO;B<@/3X@)TE0(&%D9')E<W,@;V8@>6]U<B!D;VUA:6XN)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6EP7W-E;&9?7W-H
M;W)T+71I=&QE)R`]/B`G25`@861D<F5S<R<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VEN9&EC871O<BUI<%]S96QF7U]T:71L92<@/3X@)TE0(&%D
M9')E<W,@;V8@>6]U<B!D;VUA:6XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]I;F1I8V%T;W(M:7!?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=)
M4"!A9&1R97-S(&]F(&$@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VEN9&EC871O<BUI<%]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@
M)TE0(&%D9')E<W,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I
M8V%T;W(M:7!?=6YK;F]W;E]?=&ET;&4G(#T^("=)4"!A9&1R97-S(&]F(&$@
M9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O
M<BUM87@M;6%I;&)O>&5S+6QI;6ET+75S86=E7U]D97-C<FEP=&EO;B<@/3X@
M)TUA:6QB;WAE<R!L:6UI="!U<V%G92!F;W(@9&]M86EN("4Q+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUM87@M;6%I;&)O>&5S
M+6QI;6ET+75S86=E7U]S:&]R="UT:71L92<@/3X@)TUA:6QB;WAE<R!L:6UI
M="!U<V%G92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O
M<BUM87@M;6%I;&)O>&5S+6QI;6ET+75S86=E7U]T:71L92<@/3X@)TUA:6QB
M;WAE<R!L:6UI="!U<V%G92!F;W(@9&]M86EN("4Q)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6UA>"UM86EL8F]X97,M;&EM:70M
M=7-A9V5?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=-86EL8F]X97,@;&EM:70@
M=7-A9V4@9F]R('EO=7(@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VEN9&EC871O<BUM87@M;6%I;&)O>&5S+6QI;6ET+75S86=E7W-E
M;&9?7W-H;W)T+71I=&QE)R`]/B`G36%I;&)O>&5S(&QI;6ET('5S86=E)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6UA>"UM86EL
M8F]X97,M;&EM:70M=7-A9V5?<V5L9E]?=&ET;&4G(#T^("=-86EL8F]X97,@
M;&EM:70@=7-A9V4@9F]R('EO=7(@9&]M86EN)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO:6YD:6-A=&]R+6UA>"UM86EL8F]X97,M;&EM:70M=7-A
M9V5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=-86EL8F]X97,@;&EM:70@
M=7-A9V4@9F]R(&$@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VEN9&EC871O<BUM87@M;6%I;&)O>&5S+6QI;6ET+75S86=E7W5N:VYO
M=VY?7W-H;W)T+71I=&QE)R`]/B`G36%I;&)O>&5S(&QI;6ET('5S86=E)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6UA>"UM86EL
M8F]X97,M;&EM:70M=7-A9V5?=6YK;F]W;E]?=&ET;&4G(#T^("=-86EL8F]X
M97,@;&EM:70@=7-A9V4@9F]R(&$@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VEN9&EC871O<BUM87@M<W5B9&]M86EN<RUL:6UI="UU
M<V%G95]?9&5S8W)I<'1I;VXG(#T^("=3=6)D;VUA:6YS(&QI;6ET('5S86=E
M(&9O<B!D;VUA:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:6YD:6-A=&]R+6UA>"US=6)D;VUA:6YS+6QI;6ET+75S86=E7U]S:&]R="UT
M:71L92<@/3X@)U-U8F1O;6%I;G,@;&EM:70@=7-A9V4G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M;6%X+7-U8F1O;6%I;G,M;&EM
M:70M=7-A9V5?7W1I=&QE)R`]/B`G4W5B9&]M86EN<R!L:6UI="!U<V%G92!F
M;W(@9&]M86EN("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD
M:6-A=&]R+6UA>"US=6)D;VUA:6YS+6QI;6ET+75S86=E7W-E;&9?7V1E<V-R
M:7!T:6]N)R`]/B`G4W5B9&]M86EN<R!L:6UI="!U<V%G92!F;W(@>6]U<B!D
M;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R
M+6UA>"US=6)D;VUA:6YS+6QI;6ET+75S86=E7W-E;&9?7W-H;W)T+71I=&QE
M)R`]/B`G4W5B9&]M86EN<R!L:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VEN9&EC871O<BUM87@M<W5B9&]M86EN<RUL:6UI="UU
M<V%G95]S96QF7U]T:71L92<@/3X@)U-U8F1O;6%I;G,@;&EM:70@=7-A9V4@
M9F]R('EO=7(@9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:6YD:6-A=&]R+6UA>"US=6)D;VUA:6YS+6QI;6ET+75S86=E7W5N:VYO=VY?
M7V1E<V-R:7!T:6]N)R`]/B`G4W5B9&]M86EN<R!L:6UI="!U<V%G92!F;W(@
M82!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A
M=&]R+6UA>"US=6)D;VUA:6YS+6QI;6ET+75S86=E7W5N:VYO=VY?7W-H;W)T
M+71I=&QE)R`]/B`G4W5B9&]M86EN<R!L:6UI="!U<V%G92<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUM87@M<W5B9&]M86EN<RUL
M:6UI="UU<V%G95]U;FMN;W=N7U]T:71L92<@/3X@)U-U8F1O;6%I;G,@;&EM
M:70@=7-A9V4@9F]R(&$@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VEN9&EC871O<BUN86UE7U]D97-C<FEP=&EO;B<@/3X@)TYA;64@
M;V8@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN
M9&EC871O<BUN86UE7U]S:&]R="UT:71L92<@/3X@)T1O;6%I;B!N86UE)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6YA;65?7W1I
M=&QE)R`]/B`G3F%M92!O9B!D;VUA:6X@)3$G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]I;F1I8V%T;W(M;F%M95]S96QF7U]D97-C<FEP=&EO;B<@
M/3X@)TYA;64@;V8@>6]U<B!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:6YD:6-A=&]R+6YA;65?<V5L9E]?<VAO<G0M=&ET;&4G(#T^
M("=$;VUA:6X@;F%M92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN
M9&EC871O<BUN86UE7W-E;&9?7W1I=&QE)R`]/B`G3F%M92!O9B!Y;W5R(&1O
M;6%I;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUN
M86UE7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G3F%M92!O9B!A(&1O;6%I
M;BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M;F%M
M95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T1O;6%I;B!N86UE)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6YA;65?=6YK;F]W
M;E]?=&ET;&4G(#T^("=.86UE(&]F(&$@9&]M86EN)RP*"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUS=&%T95]?9&5S8W)I<'1I;VXG
M(#T^("=(96%L=&@@<W1A=&4@;V8@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUS=&%T95]?<VAO<G0M=&ET;&4G
M(#T^("=(96%L=&@@<W1A=&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]I;F1I8V%T;W(M<W1A=&5?7W1I=&QE)R`]/B`G2&5A;'1H('-T871E(&]F
M(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC
M871O<BUS=&%T95]S96QF7U]D97-C<FEP=&EO;B<@/3X@)TAE86QT:"!S=&%T
M92!O9B!Y;W5R(&1O;6%I;BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]I;F1I8V%T;W(M<W1A=&5?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=(96%L
M=&@@<W1A=&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T
M;W(M<W1A=&5?<V5L9E]?=&ET;&4G(#T^("=(96%L=&@@<W1A=&4@;V8@>6]U
M<B!D;VUA:6XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T
M;W(M<W1A=&5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=(96%L=&@@<W1A
M=&4@;V8@82!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:6YD:6-A=&]R+7-T871E7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G2&5A
M;'1H('-T871E)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A
M=&]R+7-T871E7W5N:VYO=VY?7W1I=&QE)R`]/B`G2&5A;'1H('-T871E(&]F
M(&$@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC
M871O<BUS=&%T=7,M9&5T86EL<U]?9&5S8W)I<'1I;VXG(#T^("=$971A:6QE
M9"!S=&%T=7,@;V8@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]?<VAO<G0M=&ET;&4G
M(#T^("=$971A:6QE9"!S=&%T=7,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]I;F1I8V%T;W(M<W1A='5S+61E=&%I;'-?7W1I=&QE)R`]/B`G1&5T
M86EL960@<W1A='5S(&]F(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]S96QF7U]D97-C
M<FEP=&EO;B<@/3X@)T1E=&%I;&5D('-T871U<R!O9B!Y;W5R(&1O;6%I;BXG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M<W1A='5S
M+61E=&%I;'-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=$971A:6QE9"!S=&%T
M=7,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M<W1A
M='5S+61E=&%I;'-?<V5L9E]?=&ET;&4G(#T^("=$971A:6QE9"!S=&%T=7,@
M;V8@>6]U<B!D;VUA:6XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I
M;F1I8V%T;W(M<W1A='5S+61E=&%I;'-?=6YK;F]W;E]?9&5S8W)I<'1I;VXG
M(#T^("=$971A:6QE9"!S=&%T=7,@;V8@82!D;VUA:6XN)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+7-T871U<RUD971A:6QS7W5N
M:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G1&5T86EL960@<W1A='5S)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+7-T871U<RUD971A
M:6QS7W5N:VYO=VY?7W1I=&QE)R`]/B`G1&5T86EL960@<W1A='5S(&]F(&$@
M9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O
M<BUS=&%T=7-?7V1E<V-R:7!T:6]N)R`]/B`G4W1A='5S(&]F(&1O;6%I;B`E
M,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M<W1A
M='5S7U]S:&]R="UT:71L92<@/3X@)U-T871U<R<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VEN9&EC871O<BUS=&%T=7-?7W1I=&QE)R`]/B`G4W1A
M='5S(&]F(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VEN9&EC871O<BUS=&%T=7-?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=3=&%T
M=7,@;V8@>6]U<B!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO:6YD:6-A=&]R+7-T871U<U]S96QF7U]S:&]R="UT:71L92<@/3X@)U-T
M871U<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUS
M=&%T=7-?<V5L9E]?=&ET;&4G(#T^("=3=&%T=7,@;V8@>6]U<B!D;VUA:6XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M<W1A='5S
M7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G4W1A='5S(&]F(&$@9&]M86EN
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUS=&%T
M=7-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=3=&%T=7,G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M<W1A='5S7W5N:VYO=VY?
M7W1I=&QE)R`]/B`G4W1A='5S(&]F(&$@9&]M86EN)RP*"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUT<F%F9FEC+6QI;6ET+75S86=E
M7U]D97-C<FEP=&EO;B<@/3X@)U1R869F:6,@;&EM:70@=7-A9V4@9F]R(&1O
M;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T
M;W(M=')A9F9I8RUL:6UI="UU<V%G95]?<VAO<G0M=&ET;&4G(#T^("=4<F%F
M9FEC(&QI;6ET('5S86=E)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:6YD:6-A=&]R+71R869F:6,M;&EM:70M=7-A9V5?7W1I=&QE)R`]/B`G5')A
M9F9I8R!L:6UI="!U<V%G92!F;W(@9&]M86EN("4Q)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+71R869F:6,M;&EM:70M=7-A9V5?
M<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=4<F%F9FEC(&QI;6ET('5S86=E(&9O
M<B!Y;W5R(&1O;6%I;BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I
M;F1I8V%T;W(M=')A9F9I8RUL:6UI="UU<V%G95]S96QF7U]S:&]R="UT:71L
M92<@/3X@)U1R869F:6,@;&EM:70@=7-A9V4G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]I;F1I8V%T;W(M=')A9F9I8RUL:6UI="UU<V%G95]S96QF
M7U]T:71L92<@/3X@)U1R869F:6,@;&EM:70@=7-A9V4@9F]R('EO=7(@9&]M
M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+71R
M869F:6,M;&EM:70M=7-A9V5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=4
M<F%F9FEC(&QI;6ET('5S86=E(&9O<B!A(&1O;6%I;BXG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M=')A9F9I8RUL:6UI="UU<V%G
M95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U1R869F:6,@;&EM:70@=7-A
M9V4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M=')A
M9F9I8RUL:6UI="UU<V%G95]U;FMN;W=N7U]T:71L92<@/3X@)U1R869F:6,@
M;&EM:70@=7-A9V4@9F]R(&$@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VQI;6ET<U]?9&5S8W)I<'1I;VXG(#T^("=6:65W(&]R(&5D
M:70@<F5S;W5R8V4@=7-A9V4@;&EM:71S(&9O<B!D;VUA:6X@)3$N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;&EM:71S7U]D;VYE)R`]/B`G3&EM
M:71S(&]F(&1O;6%I;B`E,2!H879E(&)E96X@=7!D871E9"XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]L:6UI='-?7W-H;W)T+71I=&QE)R`]/B`G
M3&EM:71S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;&EM:71S7U]T
M:71L92<@/3X@)U9I97<O161I="!D;VUA:6X@)3$@;&EM:71S)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO;&EM:71S7W-E;&9?7V1E<V-R:7!T:6]N
M)R`]/B`G5FEE=R!M>2!L:6UI=',N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;&EM:71S7W-E;&9?7V1O;F4G(#T^("<G+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]L:6UI='-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=,
M:6UI=',G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]L:6UI='-?<V5L
M9E]?=&ET;&4G(#T^("=6:65W(&UY(&QI;6ET<R<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VQI;6ET<U]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@
M)U9I97<@;W(@961I="!R97-O=7)C92!U<V%G92!L:6UI=',@9F]R(&$@9&]M
M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VQI;6ET<U]U;FMN
M;W=N7U]S:&]R="UT:71L92<@/3X@)TQI;6ET<R<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VQI;6ET<U]U;FMN;W=N7U]T:71L92<@/3X@)U9I97<O
M161I="!D;VUA:6X@;&EM:71S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;&EM:71S7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)U9I97=I;F<O
M161I=&EN9R!$;VUA:6X@3&EM:71S)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;&EM:71S7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G
M4V5L96-T(&$@9&]M86EN('=H;W-E(&QI;6ET<R!Y;W4@=V%N="!T;R!V:65W
M(&]R(&5D:70N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;&EM:71S
M7W5N:VYO=VY?7W=I>F%R9%]?,R<@/3X@)U=H96X@9&]N92!W:71H(&5D:71I
M;F<@=&AE(&1O;6%I;B!L:6UI=',L(&-L:6-K($9I;FES:"!T;R!A<'!L>2!C
M:&%N9V5S(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;&EM:71S7W5N:VYO=VY?7W=I>F%R9%]?,U]S96QF)R`]
M/B`G5VAE;B!D;VYE('=I=&@@=FEE=VEN9R!Y;W5R(&QI;6ET<RP@8VQI8VL@
M1FEN:7-H+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL7U]D
M97-C<FEP=&EO;B<@/3X@)TUA;F%G92!M86EL('-Y<W1E;2!O9B!D;VUA:6X@
M)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;%]?9&ES86)L
M960M=V%R;FEN9R<@/3X@)TUA:6P@<V5R=FEC92!O;B!D;VUA:6X@)3$@:7,@
M9&ES86)L960@+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6Q?
M7W-H;W)T+71I=&QE)R`]/B`G36%I;"<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6Q?7W1I=&QE)R`]/B`G36%N86=E(&UA:6P@;VX@9&]M86EN
M("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;%]S96QF7U]D
M97-C<FEP=&EO;B<@/3X@)T-O;F9I9W5R92!M86EL('-Y<W1E;2!O;B!Y;W5R
M(&1O;6%I;BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL7W-E
M;&9?7V1I<V%B;&5D+7=A<FYI;F<G(#T^("=-86EL('-E<G9I8V4@;VX@>6]U
M<B!D;VUA:6X@:7,@9&ES86)L960N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;%]S96QF7U]S:&]R="UT:71L92<@/3X@)TUA:6PG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL7W-E;&9?7W1I=&QE)R`]/B`G
M36%N86=E(&UA:6PG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG=7)E(&UA:6P@<WES
M=&5M(&]N(&$@9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;%]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)TUA:6PG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL7W5N:VYO=VY?7W1I=&QE)R`]/B`G
M36%N86=E(&UA:6P@;VX@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6PO;6%I;&YA;65?7V1E<V-R:7!T:6]N)R`]/B`G36%N86=E
M(&UA:6P@86-C;W5N="`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+VUA:6QN86UE7U]N;VYE+6%V86EL86)L92<@/3X@)UEO=2!D;VY<
M)W0@:&%V92!A;GD@;6%I;&YA;65S+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6PO;6%I;&YA;65?7VYO;F4M879A:6QA8FQE7U\Q)R`]/B`G
M0VQI96YT("4Q(&1O97-N7"=T(&-H879E(&%N>2!M86EL;F%M97,N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M95]?;F]N92UA
M=F%I;&%B;&5?7S(G(#T^("=4:&5R92!A<F4@;F\@;6%I;&YA;65S(&]N(&1O
M;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA
M:6QN86UE7U]S:&]R="UT:71L92<@/3X@)R4Q)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;6%I;"]M86EL;F%M95]?=&ET;&4G(#T^("=-86EL;F%M
M92`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;65?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=-86YA9V4@>6]U<B!M86EL(&%C
M8V]U;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M95]S96QF7U]Q=6EC:RUS96%R8V@G(#T^("=->2!M86EL;F%M97,G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE7W-E;&9?
M7W-H;W)T+71I=&QE)R`]/B`G37D@;6%I;&YA;64G+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE7W-E;&9?7W1I=&QE)R`]/B`G
M37D@;6%I;&YA;64G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE7W5N:VYO=VY?7W%U:6-K+7-E87)C:"<@/3X@)TUA:6QN86UE
M<R<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%N=&EV:7)U<R]P<F]P97)T:65S7U]D97-C<FEP=&EO;B<@/3X@)T-O;F9I
M9W5R92!A;G1I=FER=7,@<V5R=FEC92!F;W(@;6%I;"!A8V-O=6YT("4Q+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O86YT
M:79I<G5S+W!R;W!E<G1I97-?7V1O;F4G(#T^("=!;G1I=FER=7,@<V5T=&EN
M9W,@9F]R(&UA:6QN86UE("4Q(&AA=F4@8F5E;B!U<&1A=&5D+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O86YT:79I<G5S
M+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G06YT:79I<G5S)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A;G1I=FER
M=7,O<')O<&5R=&EE<U]?=&ET;&4G(#T^("=3970@=7`@86YT:79I<G5S(&9O
M<B!M86EL;F%M92`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA
M:6PO;6%I;&YA;64O86YT:79I<G5S+W!R;W!E<G1I97-?<V5L9E]?9&5S8W)I
M<'1I;VXG(#T^("=#;VYF:6=U<F4@86YT:79I<G5S('-E<G9I8V4@9F]R('EO
M=7(@;6%I;"!A8V-O=6YT+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VUA:6PO;6%I;&YA;64O86YT:79I<G5S+W!R;W!E<G1I97-?<V5L9E]?9&]N
M92<@/3X@)T%N=&EV:7)U<R!S971T:6YG<R!F;W(@>6]U<B!M86EL;F%M92!H
M879E(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+VUA:6QN86UE+V%N=&EV:7)U<R]P<F]P97)T:65S7W-E;&9?7W-H
M;W)T+71I=&QE)R`]/B`G06YT:79I<G5S)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]M86EL;F%M92]A;G1I=FER=7,O<')O<&5R=&EE<U]S
M96QF7U]T:71L92<@/3X@)U-E="!U<"!A;G1I=FER=7,G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%N=&EV:7)U<R]P<F]P
M97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG=7)E(&%N
M=&EV:7)U<R!S97)V:6-E(&9O<B!A(&UA:6P@86-C;W5N="XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%N=&EV:7)U<R]P
M<F]P97)T:65S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G06YT:79I<G5S
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A
M;G1I=FER=7,O<')O<&5R=&EE<U]U;FMN;W=N7U]T:71L92<@/3X@)U-E="!U
M<"!A;G1I=FER=7,@9F]R(&UA:6QN86UE)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]M86EL;F%M92]A;G1I=FER=7,O<')O<&5R=&EE<U]U
M;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=!;G1I=FER=7,@0V]N9FEG=7)A
M=&EO;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;64O86YT:79I<G5S+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\R7W5N
M:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@;VX@9F]R('=H:6-H(&UA:6P@
M86-C;W5N="!Y;W4@=V%N="!T;R!S970@=7`@86YT:79I<G5S+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O86YT:79I<G5S
M+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\T7W5N:VYO=VXG(#T^("=3
M96QE8W0@82!M86EL;F%M92!F;W(@=VAI8V@@>6]U('=A;G0@=&\@<V5T('5P
M(&%N=&EV:7)U<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V%N=&EV:7)U<R]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R
M9%]?-B<@/3X@)U-E;&5C="!W:&5T:&5R(&EN8V]M:6YG(&]R(&]U=&-O;6EN
M9R!M86EL+"!O<B!B;W1H('-H;W5L9"!B92!C:&5C:V5D(&9O<B!V:7)U<V5S
M+B!7:&5N(&1O;F4@=VET:"!C;VYF:6=U<FEN9R!A;G1I=FER=7,@9F]R('1H
M92!M86EL;F%M92P@8VQI8VL@1FEN:7-H('1O(&%P<&QY(&-H86YG97,@86YD
M(&5X:70@=&AE('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+VUA:6QN86UE+V%N=&EV:7)U<R]P<F]P97)T:65S7W5N:VYO=VY?
M7W=I>F%R9%]?-E]S96QF)R`]/B`G5VAE;B!D;VYE('=I=&@@8V]N9FEG=7)I
M;F<@86YT:79I<G5S(&9O<B!Y;W5R(&UA:6P@86-C;W5N="P@8VQI8VL@=&\@
M87!P;'D@8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD
M97)S7U]D97-C<FEP=&EO;B<@/3X@)TQI<W0@;V8@875T;W)E<W!O;F1E<G,@
M;VX@;6%I;&YA;64@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<U]?9&ES86)L960M=V%R;FEN
M9R<@/3X@)U1H92!A=71O<F5S<&]N9&5R<R!S97)V:6-E(&]N(&UA:6QN86UE
M("4Q(&ES(&1I<V%B;&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G-?7W-H;W)T+71I=&QE)R`]
M/B`G)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN
M86UE+V%U=&]R97-P;VYD97)S7U]T:71L92<@/3X@)T%U=&]R97-P;VYD97)S
M(&]N(&UA:6QN86UE("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<U]S96QF7U]D97-C<FEP=&EO
M;B<@/3X@)TUA;F%G92!Y;W5R(&%U=&]R97-P;VYD97)S+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E
M<G-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=->2!A=71O<F5S<&]N9&5R<R<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T
M;W)E<W!O;F1E<G-?<V5L9E]?=&ET;&4G(#T^("=->2!A=71O<F5S<&]N9&5R
M<R<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97)?7VYO;F4M879A:6QA8FQE
M)R`]/B`G66]U(&1O;EPG="!H879E(&%N>2!A=71O<F5S<&]N9&5R<RXG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R
M97-P;VYD97)S+V%U=&]R97-P;VYD97)?7VYO;F4M879A:6QA8FQE7U\Q)R`]
M/B`G0VQI96YT("4Q(&1O97-N7"=T(&AA=F4@86YY(&%U=&]R97-P;VYD97)S
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O
M875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<E]?;F]N92UA=F%I;&%B;&5?
M7S(G(#T^("=4:&5R92!A<F4@;F\@875T;W)E<W!O;F1E<G,@;VX@9&]M86EN
M("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<E]?;F]N92UA=F%I;&%B
M;&5?7S0G(#T^("=4:&5R92!A<F4@;F\@875T;W)E<W!O;F1E<G,@8V]N9FEG
M=7)E9"!O;B!M86EL;F%M92`E,2XG+`H*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N
M9&5R+V%T=&%C:"UD96QE=&5?7V1E<V-R:7!T:6]N)R`]/B`G4F5M;W9E(&%T
M=&%C:&UE;G1S(&9R;VT@875T;W)E<W!O;F1E<B`E,2XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S
M+V%U=&]R97-P;VYD97(O871T86-H+61E;&5T95]?9&]N92<@/3X@)T%T=&%C
M:&UE;G1S(&AA=F4@8F5E;B!R96UO=F5D(&9R;VT@)3$@875T;W)E<W!O;F1E
M<BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O871T86-H+61E;&5T95]?
M<VAO<G0M=&ET;&4G(#T^("=296UO=F4@871T86-H;65N=',G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD
M97)S+V%U=&]R97-P;VYD97(O871T86-H+61E;&5T95]?=&ET;&4G(#T^("=2
M96UO=F4@871T86-H;65N=',@9G)O;2!A=71O<F5S<&]N9&5R("4Q)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S
M<&]N9&5R<R]A=71O<F5S<&]N9&5R+V%T=&%C:"UD96QE=&5?;F5W7U]D97-C
M<FEP=&EO;B<@/3X@)T-L:6-K('1O(')E;6]V92!A='1A8VAM96YT<R!F<F]M
M(&YE=R!A=71O<F5S<&]N9&5R+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E
M<B]A='1A8V@M9&5L971E7VYE=U]?9&]N92<@/3X@)T%T=&%C:&UE;G1S(&AA
M=F4@8F5E;B!R96UO=F5D(&9R;VT@)3$@875T;W)E<W!O;F1E<BXG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P
M;VYD97)S+V%U=&]R97-P;VYD97(O871T86-H+61E;&5T95]N97=?7W-H;W)T
M+71I=&QE)R`]/B`G4F5M;W9E(&%T=&%C:&UE;G1S)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A
M=71O<F5S<&]N9&5R+V%T=&%C:"UD96QE=&5?;F5W7U]T:71L92<@/3X@)U)E
M;6]V92!A='1A8VAM96YT<R!F<F]M(&$@;F5W(&%U=&]R97-P;VYD97(G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R
M97-P;VYD97)S+V%U=&]R97-P;VYD97(O871T86-H+61E;&5T95]U;FMN;W=N
M7U]D97-C<FEP=&EO;B<@/3X@)T1E;&5T92!A;B!A=71O<F5S<&]N9&5R(&%T
M=&%C:&UE;G1S("XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O871T86-H
M+61E;&5T95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U)E;6]V92!A='1A
M8VAM96YT<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I
M;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]A='1A8V@M9&5L
M971E7W5N:VYO=VY?7W1I=&QE)R`]/B`G4F5M;W9E(&%N(&%U=&]R97-P;VYD
M97(@871T86-H;65N=',G+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V%T
M=&%C:%]?9&5S8W)I<'1I;VXG(#T^("=!='1A8V@@9FEL97,@=&\@875T;W)E
M<W!O;F1E<B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O871T86-H
M7U]D;VYE)R`]/B`G071T86-H;65N=',@:&%V92!B965N(&%D9&5D('1O(&%U
M=&]R97-P;VYD97(@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V%T
M=&%C:%]?<VAO<G0M=&ET;&4G(#T^("=!='1A8V@@9FEL97,G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD
M97)S+V%U=&]R97-P;VYD97(O871T86-H7U]T:71L92<@/3X@)T%T=&%C:"!F
M:6QE<R!T;R!A=71O<F5S<&]N9&5R("4Q)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S
M<&]N9&5R+V%T=&%C:%]N97=?7V1E<V-R:7!T:6]N)R`]/B`G061D(&%T=&%C
M:&UE;G0@9FEL97,@9F]R(&YE=R!A=71O<F5S<&]N9&5R+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E
M<G,O875T;W)E<W!O;F1E<B]A='1A8VA?;F5W7U]D;VYE)R`]/B`G071T86-H
M;65N=',@:&%V92!B965N(&%D9&5D('1O(&%U=&]R97-P;VYD97(@)3$N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O
M<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V%T=&%C:%]N97=?7W-H;W)T+71I
M=&QE)R`]/B`G071T86-H(&9I;&5S)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N
M9&5R+V%T=&%C:%]N97=?7W1I=&QE)R`]/B`G071T86-H(&9I;&5S('1O(&YE
M=R!A=71O<F5S<&]N9&5R)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V%T
M=&%C:%]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T%D9"!A='1A8VAM96YT
M(&9I;&5S(&9O<B!A;B!A=71O<F5S<&]N9&5R+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T
M;W)E<W!O;F1E<B]A='1A8VA?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=!
M='1A8V@@9FEL97,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O871T86-H
M7W5N:VYO=VY?7W1I=&QE)R`]/B`G071T86-H(&9I;&5S('1O(&%U=&]R97-P
M;VYD97(G+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V1E;&5T95]?9&5S
M8W)I<'1I;VXG(#T^("=296UO=F4@875T;W)E<W!O;F1E<B`E,2XG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P
M;VYD97)S+V%U=&]R97-P;VYD97(O9&5L971E7U]D;VYE)R`]/B`G075T;W)E
M<W!O;F1E<B`E,2!H87,@8F5E;B!R96UO=F5D+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T
M;W)E<W!O;F1E<B]D96QE=&5?7W-H;W)T+71I=&QE)R`]/B`G4F5M;W9E)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O
M<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V1E;&5T95]?=&ET;&4G(#T^("=2
M96UO=F4@875T;W)E<W!O;F1E<B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O
M;F1E<B]D96QE=&5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=$96QE=&4@
M875T;W)E<W!O;F1E<B!C;VYF:6=U<F%T:6]N(&9O<B!A(&UA:6P@86-C;W5N
M="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O9&5L971E7W5N:VYO=VY?
M7W-H;W)T+71I=&QE)R`]/B`G4F5M;W9E)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S
M<&]N9&5R+V1E;&5T95]U;FMN;W=N7U]T:71L92<@/3X@)U)E;6]V92!A=71O
M<F5S<&]N9&5R)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M
M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V1E;&5T95]U
M;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=!=71O<F5S<&]N9&5R(%)E;6]V
M86PG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O9&5L971E7W5N:VYO=VY?
M7W=I>F%R9%]?,5]U;FMN;W=N)R`]/B`G4V5L96-T(&$@8VQI96YT(&]W;FEN
M9R!T:&4@9&]M86EN(&9R;VT@=VAI8V@@>6]U('=A;G0@=&\@<F5M;W9E(&%U
M=&]R97-P;VYD97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V1E;&5T
M95]U;FMN;W=N7U]W:7IA<F1?7S)?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&1O
M;6%I;B!F<F]M('=H:6-H('EO=2!W86YT('1O(')E;6]V92!A=71O<F5S<&]N
M9&5R+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]D96QE=&5?=6YK;F]W
M;E]?=VEZ87)D7U\T7W5N:VYO=VXG(#T^("=396QE8W0@82!M86EL;F%M92!F
M<F]M('=H:6-H('EO=2!W86YT('1O(')E;6]V92!A=71O<F5S<&]N9&5R+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T
M;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]D96QE=&5?=6YK;F]W;E]?=VEZ
M87)D7U\V7W5N:VYO=VXG(#T^("=0;&5A<V4@<V5L96-T('=H:6-H(&%U=&]R
M97-P;VYD97(@>6]U('=A;G0@=&\@<F5M;W9E+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T
M;W)E<W!O;F1E<B]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\W)R`]/B`G0V]N
M9FER;2!R96UO=FEN9R!T:&4@875T;W)E<W!O;F1E<B!B>2!S96QE8W1I;F<@
M=&AE(&-H96-K(&)O>"!A;F0@8VQI8VL@9FEN:7-H('1O(&-O;7!L971E;'D@
M<F5M;W9E(&ET(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O
M875T;W)E<W!O;F1E<B]P<F]P97)T:65S7U]D97-C<FEP=&EO;B<@/3X@)T-O
M;F9I9W5R92!A=71O<F5S<&]N9&5R("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E
M<W!O;F1E<B]P<F]P97)T:65S7U]D;VYE)R`]/B`G075T;W)E<W!O;F1E<B`E
M,2!C;VYF:6=U<F%T:6]N(&AA<R!B965N('5P9&%T960N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R
M<R]A=71O<F5S<&]N9&5R+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G
M4')E9F5R96YC97,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O<&5R
M=&EE<U]?=&ET;&4G(#T^("=!=71O<F5S<&]N9&5R("4Q('!R969E<F5N8V5S
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A
M=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W!R;W!E<G1I97-?;F5W7U]D
M97-C<FEP=&EO;B<@/3X@)T-R96%T92!N97<@875T;W)E<W!O;F1E<B!F;W(@
M82!M86EL(&%C8V]U;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W!R
M;W!E<G1I97-?;F5W7U]D;VYE)R`]/B`G075T;W)E<W!O;F1E<B`E,2!H87,@
M8F5E;B!C<F5A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA
M:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]P<F]P
M97)T:65S7VYE=U]?<VAO<G0M=&ET;&4G(#T^("=#<F5A=&4G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD
M97)S+V%U=&]R97-P;VYD97(O<')O<&5R=&EE<U]N97=?7W1I=&QE)R`]/B`G
M0W)E871E(&%U=&]R97-P;VYD97(G+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD
M97(O<')O<&5R=&EE<U]N97=?7W=I>F%R9"UT:71L92<@/3X@)T%U=&]R97-P
M;VYD97(@0W)E871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M
M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O
M<&5R=&EE<U]N97=?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@
M9&]M86EN(&9O<B!W:&EC:"!M86EL(&%C8V]U;G0@>6]U('=A;G0@=&\@8W)E
M871E(&%U=&]R97-P;VYD97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R
M+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S1?=6YK;F]W;B<@/3X@)U!L96%S
M92!S96QE8W0@82!M86EL;F%M92!F;W(@=VAI8V@@>6]U('=A;G0@=&\@8W)E
M871E(&%U=&]R97-P;VYD97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R
M+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S8O871T86-H)R`]/B`G4V5L96-T
M(&%T=&%C:&UE;G1S(&%N9"!C;&EC:R!/2R!T;R!R971U<FX@=&\@961I=&EN
M9R!T:&4@875T;W)E<W!O;F1E<B!P<F]P97)T:65S+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O
M875T;W)E<W!O;F1E<B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\V+V%T=&%C
M:"<@/3X@)U-E;&5C="!A='1A8VAM96YT<R!A;F0@8VQI8VL@3TL@=&\@<F5T
M=7)N('1O(&5D:71I;F<@=&AE(&%U=&]R97-P;VYD97(@<')O<&5R=&EE<RXG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U
M=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O<&5R=&EE<U]N97=?7W=I
M>F%R9%]?-B]A='1A8V@M9&5L971E)R`]/B`G0V]N9FER;2!A='1A8VAM96YT
M(')E;6]V86P@86YD(&-L:6-K($]+('1O(')E='5R;B!T;R!E9&ET:6YG('1H
M92!A=71O<F5S<&]N9&5R('!R;W!E<G1I97,N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O
M<F5S<&]N9&5R+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S8O9FEL97,O9&5L
M971E)R`]/B`G0V]N9FER;2!F:6QE<R!R96UO=F%L(&%N9"!C;&EC:R!/2R!T
M;R!R971U<FX@=&\@;6%N86=I;F<@=&AE(&%U=&]R97-P;VYD97(@871T86-H
M;65N=',N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W!R;W!E<G1I97-?
M;F5W7U]W:7IA<F1?7S9?;F5W)R`]/B`G0VQI8VL@1FEN:7-H('1O(&-R96%T
M92!T:&4@875T;W)E<W!O;F1E<BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD
M97(O<')O<&5R=&EE<U]N97=?7W=I>F%R9%]?-R<@/3X@)U=H96X@9&]N92!W
M:71H(&-H86YG:6YG('1H92!A=71O<F5S<&]N9&5R('!R;W!E<G1I97,L(&-L
M:6-K($9I;FES:"!T;R!A<'!L>2!C:&%N9V5S(&%N9"!E>&ET('1H92!W:7IA
M<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W!R;W!E<G1I97-?=6YK
M;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=#:&%N9V4@875T;W)E<W!O;F1E<B!S
M971T:6YG<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA
M:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O<&5R=&EE
M<U]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U!R;W!E<G1I97,G+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P
M;VYD97)S+V%U=&]R97-P;VYD97(O<')O<&5R=&EE<U]U;FMN;W=N7U]T:71L
M92<@/3X@)U)E8V]N9FEG=7)E(&%U=&]R97-P;VYD97(G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S
M+V%U=&]R97-P;VYD97(O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F0M=&ET
M;&4G(#T^("=!=71O<F5S<&]N9&5R(%)E8V]N9FEG=7)I;F<G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD
M97)S+V%U=&]R97-P;VYD97(O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?
M7S)?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&1O;6%I;B!F;W(@=VAI8V@@;6%I
M;"!A8V-O=6YT('EO=2!W86YT('1O(&-O;F9I9W5R92!A=71O<F5S<&]N9&5R
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O
M875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]P<F]P97)T:65S7W5N:VYO
M=VY?7W=I>F%R9%]?-%]U;FMN;W=N)R`]/B`G4V5L96-T(&$@;6%I;&YA;64@
M9F]R('=H:6-H('EO=2!W86YT('1O(&-O;F9I9W5R92!A=71O<F5S<&]N9&5R
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O
M875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]P<F]P97)T:65S7W5N:VYO
M=VY?7W=I>F%R9%]?-B]A='1A8V@G(#T^("=396QE8W0@871T86-H;65N=',@
M86YD(&-L:6-K($]+('1O(')E='5R;B!T;R!E9&ET:6YG('1H92!A=71O<F5S
M<&]N9&5R('!R;W!E<G1I97,N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R
M+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\V+V%T=&%C:"UD96QE=&4G
M(#T^("=#;VYF:7)M(&%T=&%C:&UE;G0@<F5M;W9A;"!A;F0@8VQI8VL@3TL@
M=&\@<F5T=7)N('1O(&5D:71I;F<@=&AE(&%U=&]R97-P;VYD97(@<')O<&5R
M=&EE<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN
M86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O<&5R=&EE<U]U
M;FMN;W=N7U]W:7IA<F1?7S8O9FEL97,O9&5L971E)R`]/B`G0V]N9FER;2!F
M:6QE<R!R96UO=F%L(&%N9"!C;&EC:R!/2R!T;R!R971U<FX@=&\@;6%N86=I
M;F<@=&AE(&%U=&]R97-P;VYD97(@871T86-H;65N=',N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R
M<R]A=71O<F5S<&]N9&5R+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\V
M7W5N:VYO=VXG(#T^("=396QE8W0@=VAI8V@@875T;W)E<W!O;F1E<B!Y;W4@
M=V%N('1O(&UA;F%G92XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M
M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O
M<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S<G(#T^("=7:&5N(&1O;F4@=VET
M:"!C:&%N9VEN9R!T:&4@875T;W)E<W!O;F1E<B!P<F]P97)T:65S+"!C;&EC
M:R!&:6YI<V@@=&\@87!P;'D@8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D
M+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O=&]G9VQE7V1I<V%B;&5?
M7V1E<V-R:7!T:6]N)R`]/B`G1&ES86)L92!A=71O<F5S<&]N9&5R("4Q+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T
M;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]T;V=G;&5?9&ES86)L95]?9&]N
M92<@/3X@)T%U=&]R97-P;VYD97(@)3$@:&%S(&)E96X@9&ES86)L960N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O
M<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W1O9V=L95]D:7-A8FQE7U]S:&]R
M="UT:71L92<@/3X@)T1I<V%B;&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD
M97(O=&]G9VQE7V1I<V%B;&5?7W1I=&QE)R`]/B`G1&ES86)L92!A=71O<F5S
M<&]N9&5R("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M
M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W1O9V=L95]E
M;F%B;&5?7V1E<V-R:7!T:6]N)R`]/B`G16YA8FQE(&%U=&]R97-P;VYD97(@
M)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W1O9V=L95]E;F%B;&5?
M7V1O;F4G(#T^("=!=71O<F5S<&]N9&5R("4Q(&AA<R!B965N(&5N86)L960N
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A
M=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W1O9V=L95]E;F%B;&5?7W-H
M;W)T+71I=&QE)R`]/B`G16YA8FQE)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N
M9&5R+W1O9V=L95]E;F%B;&5?7W1I=&QE)R`]/B`G16YA8FQE(&%U=&]R97-P
M;VYD97(@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA
M:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O=&]G9VQE7W5N
M:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G16YA8FQE(&]R(&1I<V%B;&4@875T
M;W)E<W!O;F1E<B!O;B!A(&UA:6P@86-C;W5N="XG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U
M=&]R97-P;VYD97(O=&]G9VQE7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G
M16YA8FQE+V1I<V%B;&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M
M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O=&]G
M9VQE7W5N:VYO=VY?7W1I=&QE)R`]/B`G16YA8FQE+T1I<V%B;&4@875T;W)E
M<W!O;F1E<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I
M;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]T;V=G;&5?=6YK
M;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G16YA8FQI;F<O1&ES86)L:6YG($%U
M=&]R97-P;VYD97(G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O=&]G9VQE
M7W5N:VYO=VY?7W=I>F%R9%]?,5]U;FMN;W=N)R`]/B`G4V5L96-T(&$@8VQI
M96YT(&]W;FEN9R!T:&4@9&]M86EN(&]N('=H:6-H('EO=2!W86YT('1O(&5N
M86)L92!O<B!D:7-A8FQE(&%U=&]R97-P;VYD97(N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A
M=71O<F5S<&]N9&5R+W1O9V=L95]U;FMN;W=N7U]W:7IA<F1?7S)?=6YK;F]W
M;B<@/3X@)U-E;&5C="!A(&1O;6%I;B!O;B!W:&EC:"!Y;W4@=V%N="!T;R!E
M;F%B;&4@;W(@9&ES86)L92!A=71O<F5S<&]N9&5R+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O
M875T;W)E<W!O;F1E<B]T;V=G;&5?=6YK;F]W;E]?=VEZ87)D7U\T7W5N:VYO
M=VXG(#T^("=396QE8W0@82!M86EL;F%M92!O;B!W:&EC:"!Y;W4@=V%N="!T
M;R!E;F%B;&4@;W(@9&ES86)L92!A=71O<F5S<&]N9&5R+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E
M<G,O875T;W)E<W!O;F1E<B]T;V=G;&5?=6YK;F]W;E]?=VEZ87)D7U\V7W5N
M:VYO=VXG(#T^("=396QE8W0@=VAI8V@@875T;W)E<W!O;F1E<B!Y;W4@=V%N
M="!T;R!E;F%B;&4@;W(@9&ES86)L92XG+`H*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]T;V=G;&5?
M9&ES86)L95]?9&5S8W)I<'1I;VXG(#T^("=$:7-A8FQE(&%U=&]R97-P;VYD
M:6YG('-E<G9I8V4@;VX@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]T;V=G;&5?9&ES86)L
M95]?9&]N92<@/3X@)T%U=&]R97-P;VYD:6YG('-E<G9I8V4@:&%S(&)E96X@
M9&ES86)L960@;VX@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]T;V=G;&5?9&ES86)L95]?
M<VAO<G0M=&ET;&4G(#T^("=$:7-A8FQE)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]T;V=G;&5?
M9&ES86)L95]?=&ET;&4G(#T^("=$:7-A8FQE(&%U=&]R97-P;VYD:6YG('-E
M<G9I8V4@;VX@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+W1O9V=L95]E;F%B;&5?7V1E<V-R
M:7!T:6]N)R`]/B`G16YA8FQE(&%U=&]R97-P;VYD:6YG('-E<G9I8V4@;VX@
M)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]A=71O<F5S<&]N9&5R<R]T;V=G;&5?96YA8FQE7U]D;VYE)R`]/B`G075T
M;W)E<W!O;F1I;F<@<V5R=FEC92!H87,@8F5E;B!E;F%B;&5D(&]N("4Q+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T
M;W)E<W!O;F1E<G,O=&]G9VQE7V5N86)L95]?<VAO<G0M=&ET;&4G(#T^("=%
M;F%B;&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN
M86UE+V%U=&]R97-P;VYD97)S+W1O9V=L95]E;F%B;&5?7W1I=&QE)R`]/B`G
M16YA8FQE(&%U=&]R97-P;VYD97)S('-E<G9I8V4@;VX@)3$G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD
M97)S+W1O9V=L95]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T5N86)L92!O
M<B!D:7-A8FQE(&%U=&]R97-P;VYD:6YG('-E<G9I8V4@9F]R(&$@;6%I;"!A
M8V-O=6YT+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I
M;&YA;64O875T;W)E<W!O;F1E<G,O=&]G9VQE7W5N:VYO=VY?7W-H;W)T+71I
M=&QE)R`]/B`G16YA8FQE+V1I<V%B;&4G+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+W1O9V=L95]U
M;FMN;W=N7U]T:71L92<@/3X@)T5N86)L92]$:7-A8FQE(&%U=&]R97-P;VYD
M97)S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]A=71O<F5S<&]N9&5R<R]T;V=G;&5?=6YK;F]W;E]?=VEZ87)D+71I=&QE
M)R`]/B`G16YA8FQI;F<O1&ES86)L:6YG($%U=&]R97-P;VYD:6YG(%-E<G9I
M8V4@;VX@36%I;&YA;64G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M
M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+W1O9V=L95]U;FMN;W=N7U]W
M:7IA<F1?7S%?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&-L:65N="!O=VYI;F<@
M=&AE(&1O;6%I;B!O;B!W:&EC:"!Y;W4@=V%N="!T;R!E;F%B;&4@;W(@9&ES
M86)L92!A=71O<F5S<&]N9&EN9R!S97)V:6-E(&9O<B!M86EL;F%M92XG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R
M97-P;VYD97)S+W1O9V=L95]U;FMN;W=N7U]W:7IA<F1?7S)?=6YK;F]W;B<@
M/3X@)U-E;&5C="!A(&1O;6%I;B!T:&4@9&]M86EN(&]N('=H:6-H('EO=2!W
M86YT('1O(&5N86)L92!O<B!D:7-A8FQE(&%U=&]R97-P;VYD:6YG('-E<G9I
M8V4@9F]R(&UA:6QN86UE+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O=&]G9VQE7W5N:VYO=VY?
M7W=I>F%R9%]?-%]U;FMN;W=N)R`]/B`G4V5L96-T(&$@;6%I;&YA;64@;VX@
M=VAI8V@@>6]U('=A;G0@=&\@96YA8FQE(&]R(&1I<V%B;&4@875T;W)E<W!O
M;F1I;F<@<V5R=FEC92XG+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]D96QE=&5?7V1E<V-R:7!T:6]N)R`]/B`G4F5M;W9E
M(&UA:6QN86UE("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA
M:6PO;6%I;&YA;64O9&5L971E7U]D;VYE)R`]/B`G36%I;&YA;64@)3$@:&%S
M(&)E96X@<F5M;W9E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M
M86EL+VUA:6QN86UE+V1E;&5T95]?<VAO<G0M=&ET;&4G(#T^("=296UO=F4G
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V1E
M;&5T95]?=&ET;&4G(#T^("=296UO=F4@;6%I;&YA;64@)3$G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V1E;&5T95]U;FMN
M;W=N7U]D97-C<FEP=&EO;B<@/3X@)T1E;&5T92!A(&UA:6P@86-C;W5N="XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V1E
M;&5T95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O9&5L971E7W5N
M:VYO=VY?7W1I=&QE)R`]/B`G4F5M;W9E(&UA:6QN86UE)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]D96QE=&5?=6YK;F]W
M;E]?=VEZ87)D+71I=&QE)R`]/B`G36%I;&YA;64@4F5M;W9A;"<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O9&5L971E7W5N
M:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&]M86EN
M('1O(')E;6]V92!A(&UA:6QN86UE(&9R;VTN)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]D96QE=&5?=6YK;F]W;E]?=VEZ
M87)D7U\T7W5N:VYO=VXG(#T^("=396QE8W0@82!M86EL;F%M92!T;R!R96UO
M=F4N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\U)R`]/B`G0V]N9FER;2!R96UO
M=FEN9R!T:&4@;6%I;&YA;64@8GD@<V5L96-T:6YG('1H92!C:&5C:R!B;W@@
M86YD(&-L:6-K(&9I;FES:"!T;R!C;VUP;&5T96QY(')E;6]V92!I="!A;F0@
M97AI="!T:&4@=VEZ87)D+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+VUA:6QN86UE+V9O<G=A<F1I;F=?7V1E<V-R:7!T:6]N)R`]/B`G
M0V]N9FEG=7)E(&UA:6P@9F]R=V%R9&EN9R!O;B`E,2XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V9O<G=A<F1I;F=?7V1O
M;F4G(#T^("=-86EL(&9O<G=A<F1I;F<@<V5T=&EN9W,@9F]R(&UA:6QN86UE
M("4Q(&AA=F4@8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6PO;6%I;&YA;64O9F]R=V%R9&EN9U]?<VAO<G0M=&ET;&4G
M(#T^("=&;W)W87)D:6YG)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]F;W)W87)D:6YG7U]T:71L92<@/3X@)U-E="!U<"!F
M;W)W87)D:6YG(&9O<B!M86EL;F%M92`E,2<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O9F]R=V%R9&EN9U]S96QF7U]D97-C
M<FEP=&EO;B<@/3X@)T-O;F9I9W5R92`@;6%I;"!F;W)W87)D:6YG(&9O<B!Y
M;W5R(&UA:6P@86-C;W5N="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+VUA:6QN86UE+V9O<G=A<F1I;F=?<V5L9E]?9&]N92<@/3X@)TUA
M:6P@9F]R=V%R9&EN9R!S971T:6YG<R!F;W(@>6]U<B!M86EL;F%M92!H879E
M(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M
M86EL+VUA:6QN86UE+V9O<G=A<F1I;F=?<V5L9E]?<VAO<G0M=&ET;&4G(#T^
M("=&;W)W87)D:6YG)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]M86EL;F%M92]F;W)W87)D:6YG7W-E;&9?7W1I=&QE)R`]/B`G4V5T('5P
M(&9O<G=A<F1I;F<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V9O<G=A<F1I;F=?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^
M("=#;VYF:6=U<F4@9F]R=V%R9&EN9R!S97)V:6-E(&]N(&$@;6%I;"!A8V-O
M=6YT+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;64O9F]R=V%R9&EN9U]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T9O<G=A
M<F1I;F<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN
M86UE+V9O<G=A<F1I;F=?=6YK;F]W;E]?=&ET;&4G(#T^("=3970@=7`@;6%I
M;"!F;W)W87)D:6YG)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]M86EL;F%M92]F;W)W87)D:6YG7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@
M/3X@)TUA:6P@1F]R=V%R9&EN9R!3971U<"<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O9F]R=V%R9&EN9U]U;FMN;W=N7U]W
M:7IA<F1?7S)?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&1O;6%I;B!F;W(@=VAI
M8V@@;6%I;&YA;64@>6]U('=A;G0@=&\@<V5T('5P(&UA:6P@9F]R=V%R9&EN
M9RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V9O<G=A<F1I;F=?=6YK;F]W;E]?=VEZ87)D7U\T7W5N:VYO=VXG(#T^("=3
M96QE8W0@82!M86EL;F%M92!F;W(@=VAI8V@@>6]U('=A;G0@=&\@<V5T('5P
M(&UA:6P@9F]R=V%R9&EN9RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+VUA:6QN86UE+V9O<G=A<F1I;F=?=6YK;F]W;E]?=VEZ87)D7U\U
M)R`]/B`G5VAE;B!D;VYE('=I=&@@8V]N9FEG=7)I;F<@9F]R=V%R9&EN9R!F
M;W(@=&AE(&UA:6QN86UE+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@8V]N9FEG
M=7)A=&EO;B!A;F0@97AI="!T:&4@=VEZ87)D+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O9F]R=V%R9&EN9U]U;FMN;W=N
M7U]W:7IA<F1?7S5?<V5L9B<@/3X@)U=H96X@9&]N92!W:71H(&-O;F9I9W5R
M:6YG(&UA:6P@9F]R=V%R9&EN9R!F;W(@>6]U<B!M86EL;F%M92P@8VQI8VL@
M1FEN:7-H('1O(&%P<&QY(&-O;F9I9W5R871I;VX@86YD(&5X:70@=&AE('=I
M>F%R9"XG+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]M86EL8F]X+W!R;W!E<G1I97-?7V1E<V-R:7!T:6]N)R`]/B`G0V]N
M9FEG=7)E(&UA:6QB;W@@;VX@;6%I;&YA;64@)3$N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]M86EL8F]X+W!R;W!E<G1I
M97-?7V1O;F4G(#T^("=-86EL8F]X("4Q(&-O;F9I9W5R871I;VX@:&%S(&)E
M96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+VUA:6QB;W@O<')O<&5R=&EE<U]?<VAO<G0M=&ET;&4G(#T^
M("=#;VYF:6=U<F4@;6%I;&)O>"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VUA:6PO;6%I;&YA;64O;6%I;&)O>"]P<F]P97)T:65S7U]T:71L92<@
M/3X@)TUA:6QB;W@@)3$@<')O<&5R=&EE<R<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O;6%I;&)O>"]P<F]P97)T:65S7W-E
M;&9?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG=7)E('EO=7(@;6%I;&)O>"XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+VUA
M:6QB;W@O<')O<&5R=&EE<U]S96QF7U]D;VYE)R`]/B`G66]U<B!M86EL8F]X
M(&-O;F9I9W5R871I;VX@:&%S(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+VUA:6QB;W@O<')O<&5R
M=&EE<U]S96QF7U]S:&]R="UT:71L92<@/3X@)T-O;F9I9W5R92!M86EL8F]X
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]M
M86EL8F]X+W!R;W!E<G1I97-?<V5L9E]?=&ET;&4G(#T^("=->2!M86EL8F]X
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]M
M86EL8F]X+W!R;W!E<G1I97-?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=#
M;VYF:6=U<F4@;6%I;&)O>"!O;B!A(&UA:6P@86-C;W5N="XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+VUA:6QB;W@O<')O
M<&5R=&EE<U]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T-O;F9I9W5R92!M
M86EL8F]X)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]M86EL8F]X+W!R;W!E<G1I97-?=6YK;F]W;E]?=&ET;&4G(#T^("=#
M;VYF:6=U<F4@;6%I;&)O>"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VUA:6PO;6%I;&YA;64O;6%I;&)O>"]P<F]P97)T:65S7W5N:VYO=VY?7W=I
M>F%R9"UT:71L92<@/3X@)TUA:6QB;W@@0V]N9FEG=7)A=&EO;B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O;6%I;&)O>"]P
M<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L
M96-T(&$@9&]M86EN('1O(&-O;F9I9W5R92!M86EL8F]X(&]N+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O;6%I;&)O>"]P
M<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-%]U;FMN;W=N)R`]/B`G4V5L
M96-T(&$@;6%I;&YA;64@=&\@8V]N9FEG=7)E(&UA:6QB;W@@;VXN)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]M86EL8F]X
M+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\V)R`]/B`G5VAE;B!D;VYE
M('=I=&@@8V]N9FEG=7)I;F<@;6%I;&)O>"!O;B!T:&4@;6%I;&YA;64L(&-L
M:6-K($9I;FES:"!T;R!A<'!L>2!C:&%N9V5S(&%N9"!E>&ET('1H92!W:7IA
M<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]M86EL8F]X+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\V7W-E;&8G
M(#T^("=7:&5N(&1O;F4@=VET:"!C;VYF:6=U<FEN9R!Y;W5R(&UA:6QB;W@L
M(&-L:6-K($9I;FES:"!T;R!A<'!L>2!C:&%N9V5S(&%N9"!E>&ET('1H92!W
M:7IA<F0N)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I
M;&YA;64O<')O<&5R=&EE<U]?9&5S8W)I<'1I;VXG(#T^("=%9&ET('!R;W!E
M<G1I97,@;V8@;6%I;&YA;64@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7U]D;VYE)R`]/B`G4')O
M<&5R=&EE<R!O9B!M86EL;F%M92`E,2!H879E(&)E96X@=7!D871E9"XG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W!R;W!E
M<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G36%I;&YA;64@<')O<&5R=&EE<R<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<')O
M<&5R=&EE<U]?=&ET;&4G(#T^("=-86EL;F%M92`E,2!P<F]P97)T:65S)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P
M97)T:65S7VYE=RUA9&AO8U]?=VEZ87)D7U\T7VYE=R<@/3X@)TYN97<@;6%I
M;&YA;64@=VEL;"!B92!C<F5A=&5D(&EM;65D:6%T96QY(&%F=&5R('EO=2!C
M;&EC:R!.97AT(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA
M:6PO;6%I;&YA;64O<')O<&5R=&EE<U]N97<M8F5F;W)E+6%N=&EV:7)U<U]?
M=VEZ87)D7U\T7VYE=R<@/3X@)T-L:6-K($YE>'0@/CX@=&\@8W)E871E('1H
M92!M86EL;F%M92!A;F0@<')O8V5E9"!T;R!C;VYF:6=U<FEN9R!A;G1I+79I
M<G5S('-E='1I;F=S+B!#;&EC:R!&:6YI<V@@=&\@:G5S="!C<F5A=&4@=&AE
M(&UA:6QN86UE(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7VYE=RUB
M969O<F4M<W!A;2UF:6QT97)?7W=I>F%R9%]?-"]A;G1I=FER=7,O<')O<&5R
M=&EE<R<@/3X@)U-P96-I9GD@<&%R86UE=&5R<R!O9B!$<BY796(@86YT:79I
M<G5S(&-O;F9I9W5R871I;VXN($-L:6-K($YE>'0@/CX@=&\@<')O8V5E9"!T
M;R!A;G1I+7-P86T@9FEL=&5R(&-O;F9I9W5R871I;VXN($-L:6-K($9I;FES
M:"!T;R!S879E($1R+E=E8B!C;VYF:6=U<F%T:6]N(&%N9"!E>&ET('1H92!W
M:7IA<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]P<F]P97)T:65S7VYE=RUB969O<F4M<W!A;2UF:6QT97)?7W=I>F%R
M9%]?-%]N97<G(#T^("=#;&EC:R!.97AT(#X^('1O(&-R96%T92!T:&4@;6%I
M;&YA;64@86YD('!R;V-E960@=&\@8V]N9FEG=7)I;F<@86YT:2US<&%M(&9I
M;'1E<B!F;W(@=&AE(&UA:6QN86UE+B!#;&EC:R!&:6YI<V@@=&\@:G5S="!C
M<F5A=&4@=&AE(&UA:6QN86UE+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VUA:6PO;6%I;&YA;64O<')O<&5R=&EE<U]N97=?7V1E<V-R:7!T:6]N
M)R`]/B`G0W)E871E(&YE=R!M86EL(&%C8V]U;G0N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7VYE=U]?
M9&]N92<@/3X@)TUA:6QN86UE("4Q(&AA<R!B965N(&-R96%T960N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T
M:65S7VYE=U]?<VAO<G0M=&ET;&4G(#T^("=#<F5A=&4@;6%I;&YA;64G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W!R;W!E
M<G1I97-?;F5W7U]T:71L92<@/3X@)T-R96%T92!M86EL;F%M92<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<')O<&5R=&EE
M<U]N97=?7W=I>F%R9"UT:71L92<@/3X@)T-R96%T:6YG($UA:6QN86UE)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P
M97)T:65S7VYE=U]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D
M;VUA:6X@;VX@=VAI8V@@>6]U('=A;G0@=&\@8W)E871E(&UA:6QN86UE+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<')O
M<&5R=&EE<U]N97=?7W=I>F%R9%]?-"]A;G1I=FER=7,O<')O<&5R=&EE<R<@
M/3X@)T-L:6-K($9I;FES:"!T;R!S879E($1R+E=E8B!C;VYF:6=U<F%T:6]N
M(&%N9"!F:6YI<V@@=&AE('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]M86EL+VUA:6QN86UE+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?
M7S0O<W!A;2UF:6QT97(O<')O<&5R=&EE<R<@/3X@)T-O;F9I9W5R92!T:&4@
M86YT:2US<&%M(&9I;'1E<B!A;F0@8VQI8VL@1FEN:7-H('1O(&%P<&QY(&-H
M86YG97,@86YD(&5X:70@=&AE('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W!R;W!E<G1I97-?;F5W7U]W:7IA
M<F1?7S1?;F5W)R`]/B`G0VQI8VL@1FEN:7-H('1O(&-R96%T92!T:&4@;6%I
M;&YA;64@86YD(&5X:70@=&AE('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W!R;W!E<G1I97-?<V5L9E]?9&5S
M8W)I<'1I;VXG(#T^("=%9&ET('!R;W!E<G1I97,@;V8@>6]U<B!M86EL(&%C
M8V]U;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]P<F]P97)T:65S7W-E;&9?7V1O;F4G(#T^("=0<F]P97)T:65S(&]F
M('EO=7(@;6%I;&YA;64@:&%V92!B965N('5P9&%T960N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7W-E
M;&9?7W-H;W)T+71I=&QE)R`]/B`G36%I;&YA;64@<')O<&5R=&EE<R<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<')O<&5R
M=&EE<U]S96QF7U]T:71L92<@/3X@)T5D:70@;7D@86-C;W5N="<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<')O<&5R=&EE
M<U]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T-H86YG92!P87-S=V]R9"!A
M;F0@:6YT97)F86-E(&%N9"!S97-S:6]N('!R969E<F5N8V5S(&9O<B!A(&UA
M:6P@86-C;W5N="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+W!R;W!E<G1I97-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^
M("=-86EL;F%M92!P<F]P97)T:65S)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7W5N:VYO=VY?7W1I=&QE
M)R`]/B`G161I="!M86EL;F%M92!P<F]P97)T:65S)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7W5N:VYO
M=VY?7W=I>F%R9"UT:71L92<@/3X@)T5D:71I;F<@36%I;&YA;64@4')O<&5R
M=&EE<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;64O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S)?=6YK;F]W;B<@/3X@
M)U-E;&5C="!A(&1O;6%I;B!O;B!W:&EC:"!Y;W4@=V%N="!T;R!C;VYF:6=U
M<F4@;6%I;&YA;64N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]M86EL;F%M92]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-%]U;FMN
M;W=N)R`]/B`G4V5L96-T('=H:6-H(&UA:6QN86UE('EO=2!W86YT('1O(&-O
M;F9I9W5R92XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA
M:6QN86UE+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\U)R`]/B`G5VAE
M;B!D;VYE('=I=&@@8VAA;F=I;F<@;6%I;&YA;64@<')O<&5R=&EE<RP@8VQI
M8VL@1FEN:7-H('1O(&%P<&QY(&-H86YG97,@86YD(&5X:70@=&AE('=I>F%R
M9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\U7W-E;&8G(#T^("=7:&5N
M(&1O;F4@=VET:"!C:&%N9VEN9R!M86EL;F%M92!P<F]P97)T:65S+"!C;&EC
M:R!&:6YI<V@@=&\@87!P;'D@8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D
M+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+W-P86TM9FEL=&5R+W!R;W!E<G1I97-?7V1E<V-R:7!T:6]N)R`]/B`G0V]N
M9FEG=7)E('-P86T@9FEL=&5R(&9O<B!M86EL;F%M92`E,2XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W-P86TM9FEL=&5R
M+W!R;W!E<G1I97-?7V1O;F4G(#T^("=3<&%M(&9I;'1E<B!S971T:6YG<R!F
M;W(@;6%I;&YA;64@)3$@:&%V92!B965N('5P9&%T960N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]S<&%M+69I;'1E<B]P
M<F]P97)T:65S7U]S:&]R="UT:71L92<@/3X@)U-P86T@9FEL=&5R)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]S<&%M+69I
M;'1E<B]P<F]P97)T:65S7U]T:71L92<@/3X@)T-O;F9I9W5R92!S<&%M(&9I
M;'1E<B!F;W(@;6%I;&YA;64@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]M86EL+VUA:6QN86UE+W-P86TM9FEL=&5R+W!R;W!E<G1I97-?96YA
M8FQE7U]D97-C<FEP=&EO;B<@/3X@)T5N86)L92!A;F0@8V]N9FEG=7)E('-P
M86T@9FEL=&5R(&9O<B!M86EL;F%M92`E,2XG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W-P86TM9FEL=&5R+W!R;W!E<G1I
M97-?96YA8FQE7U]D;VYE)R`]/B`G4W!A;2!F:6QT97(@9F]R(&UA:6QN86UE
M("4Q(&AA<R!B965N(&5N86)L960N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]M86EL;F%M92]S<&%M+69I;'1E<B]P<F]P97)T:65S7V5N
M86)L95]?<VAO<G0M=&ET;&4G(#T^("=3<&%M(&9I;'1E<B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<W!A;2UF:6QT97(O
M<')O<&5R=&EE<U]E;F%B;&5?7W1I=&QE)R`]/B`G16YA8FQE+T-O;F9I9W5R
M92!S<&%M(&9I;'1E<B!F;W(@;6%I;&YA;64@)3$G+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W-P86TM9FEL=&5R+W!R;W!E
M<G1I97-?<V5L9BUE;F%B;&5?7V1E<V-R:7!T:6]N)R`]/B`G16YA8FQE(&%N
M9"!C;VYF:6=U<F4@9FEL=&5R(&9O<B!Y;W5R(&UA:6P@86-C;W5N="XG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W-P86TM
M9FEL=&5R+W!R;W!E<G1I97-?<V5L9BUE;F%B;&5?7V1O;F4G(#T^("=3<&%M
M(&9I;'1E<B!F;W(@>6]U<B!M86EL;F%M92!H87,@8F5E;B!E;F%B;&5D+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<W!A
M;2UF:6QT97(O<')O<&5R=&EE<U]S96QF+65N86)L95]?<VAO<G0M=&ET;&4G
M(#T^("=3<&%M(&9I;'1E<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VUA:6PO;6%I;&YA;64O<W!A;2UF:6QT97(O<')O<&5R=&EE<U]S96QF+65N
M86)L95]?=&ET;&4G(#T^("=%;F%B;&4@86YD(&-O;F9I9W5R92!S<&%M(&9I
M;'1E<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;64O<W!A;2UF:6QT97(O<')O<&5R=&EE<U]S96QF7U]D97-C<FEP=&EO;B<@
M/3X@)T-O;F9I9W5R92!S<&%M(&9I;'1E<B!F;W(@>6]U<B!M86EL(&%C8V]U
M;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]S<&%M+69I;'1E<B]P<F]P97)T:65S7W-E;&9?7V1O;F4G(#T^("=3<&%M
M(&9I;'1E<B!S971T:6YG<R!H879E(&)E96X@=7!D871E9"XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W-P86TM9FEL=&5R
M+W!R;W!E<G1I97-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=3<&%M(&9I;'1E
M<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O
M<W!A;2UF:6QT97(O<')O<&5R=&EE<U]S96QF7U]T:71L92<@/3X@)T-O;F9I
M9W5R92!S<&%M(&9I;'1E<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VUA:6PO;6%I;&YA;64O<W!A;2UF:6QT97(O<')O<&5R=&EE<U]U;FMN;W=N
M7U]D97-C<FEP=&EO;B<@/3X@)T-O;F9I9W5R92!S<&%M(&9I;'1E<FEN9R!S
M971T:6YG<R!F;W(@82!M86EL(&%C8V]U;G0N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]S<&%M+69I;'1E<B]P<F]P97)T
M:65S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G4W!A;2!F:6QT97(G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W-P86TM
M9FEL=&5R+W!R;W!E<G1I97-?=6YK;F]W;E]?=&ET;&4G(#T^("=#;VYF:6=U
M<F4@<W!A;2!F:6QT97(@9F]R(&UA:6QN86UE)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]S<&%M+69I;'1E<B]P<F]P97)T
M:65S7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)U-P86T@9FEL=&5R(&-O
M;F9I9W5R871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+W-P86TM9FEL=&5R+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ
M87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@;VX@=VAI8V@@
M;6%I;&YA;64@>6]U('=A;G0@=&\@8V]N9FEG=7)E('-P86T@9FEL=&5R:6YG
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O
M<W!A;2UF:6QT97(O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S1?=6YK
M;F]W;B<@/3X@)U-E;&5C="!O;B!W:&EC:"!M86EL;F%M92!Y;W4@=V%N="!T
M;R!C;VYF:6=U<F4@<W!A;2!F:6QT97)I;F<N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]S<&%M+69I;'1E<B]P<F]P97)T
M:65S7W5N:VYO=VY?7W=I>F%R9%]?-B<@/3X@)U=H96X@9&]N92!W:71H(&-O
M;F9I9W5R:6YG('-P86T@9FEL=&5R(&9O<B!T:&4@;6%I;&YA;64L(&-L:6-K
M($9I;FES:"!T;R!A<'!L>2!C:&%N9V5S(&%N9"!E>&ET('1H92!W:7IA<F0N
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]S
M<&%M+69I;'1E<B]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-E]E;F%B
M;&4G(#T^("=7:&5N('EO=2!C;&EC:R!&:6YI<V@L('-P86T@9FEL=&5R(&9O
M<B!T:&4@;6%I;&YA;64@=VEL;"!B92!E;F%B;&5D+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<W!A;2UF:6QT97(O<')O
M<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S9?<V5L9B<@/3X@)U=H96X@9&]N
M92!W:71H(&-O;F9I9W5R:6YG('-P86T@9FEL=&5R(&9O<B!Y;W5R(&UA:6QN
M86UE+"!C;&EC:R!&:6YI<V@N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;6%I;"]M86EL;F%M92]S<&%M+69I;'1E<B]P<F]P97)T:65S7W5N:VYO
M=VY?7W=I>F%R9%]?-E]S96QF+65N86)L92<@/3X@)U=H96X@>6]U(&-L:6-K
M($9I;FES:"P@<W!A;2!F:6QT97(@9F]R('EO=7(@;6%I;&YA;64@=VEL;"!B
M92!E;F%B;&5D+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+W!R;W!E<G1I97-?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG=7)E(&UA:6P@
M<WES=&5M(&]N(&1O;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]M86EL+W!R;W!E<G1I97-?7V1O;F4G(#T^("=-86EL('-Y<W1E;2!O
M;B!D;VUA:6X@)3$@:&%S(&)E96X@8V]N9FEG=7)E9"XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE
M)R`]/B`G0V]N9FEG=7)E(&UA:6P@<WES=&5M)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;6%I;"]P<F]P97)T:65S7U]T:71L92<@/3X@)TUA;F%G
M92!M86EL(&]N(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VUA:6PO<')O<&5R=&EE<U]S96QF7U]D97-C<FEP=&EO;B<@/3X@)T-O
M;F9I9W5R92!M86EL('-Y<W1E;2!O;B!Y;W5R(&1O;6%I;BXG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+W!R;W!E<G1I97-?<V5L9E]?9&]N
M92<@/3X@)TUA:6P@<WES=&5M(&]N('EO=7(@9&]M86EN(&AA<R!B965N(&-O
M;F9I9W5R960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]P
M<F]P97)T:65S7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G0V]N9FEG=7)E(&UA
M:6P@<WES=&5M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]P
M<F]P97)T:65S7W-E;&9?7W1I=&QE)R`]/B`G36%N86=E(&UA:6PG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+W!R;W!E<G1I97-?=6YK;F]W
M;E]?9&5S8W)I<'1I;VXG(#T^("=#;VYF:6=U<F4@;6%I;"!S>7-T96T@;VX@
M82!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]P
M<F]P97)T:65S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G0V]N9FEG=7)E
M(&UA:6P@<WES=&5M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]P<F]P97)T:65S7W5N:VYO=VY?7W1I=&QE)R`]/B`G36%N86=E(&UA:6P@
M;VX@9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]P
M<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)TUA:6P@<WES
M=&5M(&-O;F9I9W5R871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG
M(#T^("=396QE8W0@82!D;VUA:6X@;VX@=VAI8V@@>6]U('=A;G0@=&\@8V]N
M9FEG=7)E(&UA:6P@<WES=&5M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VUA:6PO<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S0G(#T^("=7
M:&5N(&1O;F4@=VET:"!C;VYF:6=U<FEN9R!T:&4@;6%I;"!S>7-T96TL(&-L
M:6-K($9I;FES:"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\T7W-E;&8G(#T^("=7:&5N
M(&1O;F4@=VET:"!C;VYF:6=U<FEN9R!T:&4@;6%I;"!S>7-T96TL(&-L:6-K
M($9I;FES:"XG+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]T
M;V=G;&5?9&ES86)L95]?9&5S8W)I<'1I;VXG(#T^("=$:7-A8FQE(&UA:6P@
M<V5R=FEC97,@;VX@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6PO=&]G9VQE7V1I<V%B;&5?7V1O;F4G(#T^("=-86EL('-E
M<G9I8V5S(&]N(&1O;6%I;B`E,2!H879E(&)E96X@9&ES86)L960N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]T;V=G;&5?9&ES86)L95]?
M<VAO<G0M=&ET;&4G(#T^("=$:7-A8FQE)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]T;V=G;&5?9&ES86)L95]?=&ET;&4G(#T^("=$:7-A
M8FQE(&UA:6P@;VX@9&]M86EN("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]T;V=G;&5?96YA8FQE7U]D97-C<FEP=&EO;B<@/3X@)T5N
M86)L92!M86EL('-E<G9I8V5S(&9O<B!D;VUA:6X@)3$N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO;6%I;"]T;V=G;&5?96YA8FQE7U]D;VYE)R`]
M/B`G36%I;"!S97)V:6-E<R!O;B!D;VUA:6X@)3$@:&%V92!B965N(&5N86)L
M960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]T;V=G;&5?
M96YA8FQE7U]S:&]R="UT:71L92<@/3X@)T5N86)L92<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VUA:6PO=&]G9VQE7V5N86)L95]?=&ET;&4G(#T^
M("=%;F%B;&4@;6%I;"!O;B!D;VUA:6X@)3$G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL+W1O9V=L95]S96QF+61I<V%B;&5?7V1E<V-R:7!T
M:6]N)R`]/B`G0VQI8VL@=&\@9&ES86)L92!M86EL('-E<G9I8V5S(&]N('EO
M=7(@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO
M=&]G9VQE7W-E;&8M9&ES86)L95]?9&]N92<@/3X@)TUA:6P@<V5R=FEC97,@
M;VX@>6]U<B!D;VUA:6X@:&%V92!B965N(&1I<V%B;&5D+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO=&]G9VQE7W-E;&8M9&ES86)L95]?
M<VAO<G0M=&ET;&4G(#T^("=$:7-A8FQE)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]T;V=G;&5?<V5L9BUD:7-A8FQE7U]T:71L92<@/3X@
M)T1I<V%B;&4@;6%I;"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA
M:6PO=&]G9VQE7W-E;&8M96YA8FQE7U]D97-C<FEP=&EO;B<@/3X@)T-L:6-K
M('1O(&5N86)L92!M86EL('-E<G9I8V5S(&]N('EO=7(@9&]M86EN+B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO=&]G9VQE7W-E;&8M96YA
M8FQE7U]D;VYE)R`]/B`G36%I;"!S97)V:6-E<R!O;B!Y;W5R(&1O;6%I;B!H
M879E(&)E96X@96YA8FQE9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+W1O9V=L95]S96QF+65N86)L95]?<VAO<G0M=&ET;&4G(#T^("=%
M;F%B;&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+W1O9V=L
M95]S96QF+65N86)L95]?=&ET;&4G(#T^("=%;F%B;&4@;6%I;"<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO=&]G9VQE7W-E;&9?7V1E<V-R
M:7!T:6]N)R`]/B`G0VQI8VL@=&\@96YA8FQE(&]R(&1I<V%B;&4@;6%I;"!S
M97)V:6-E<R!O;B!Y;W5R(&1O;6%I;BXG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]M86EL+W1O9V=L95]S96QF7U]S:&]R="UT:71L92<@/3X@)T5N
M86)L92]D:7-A8FQE)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]T;V=G;&5?<V5L9E]?=&ET;&4G(#T^("=%;F%B;&4O1&ES86)L92!M86EL
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]T;V=G;&5?=6YK
M;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=%;F%B;&4@;W(@9&ES86)L92!M86EL
M('-E<G9I8V5S(&]N(&$@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6PO=&]G9VQE7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G
M16YA8FQE+V1I<V%B;&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M
M86EL+W1O9V=L95]U;FMN;W=N7U]T:71L92<@/3X@)T5N86)L92]$:7-A8FQE
M(&UA:6P@;VX@9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]T;V=G;&5?=6YK;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G16YA8FQI
M;F<O1&ES86)L:6YG($UA:6P@4V5R=FEC97,@;VX@1&]M86EN)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]T;V=G;&5?=6YK;F]W;E]?=VEZ
M87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@;VX@=VAI8V@@9&]M86EN('EO
M=2!W86YT('1O(&5N86)L92!O<B!D:7-A8FQE(&UA:6P@<V5R=FEC97,N)RP*
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W!R;W!E<G1I97-?7V1E<V-R
M:7!T:6]N)R`]/B`G4V5T('5P(&1O;6%I;B!A9&UI;FES=')A=&]R(&%C8V]U
M;G0@9F]R(&1O;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]P<F]P97)T:65S7U]D;VYE)R`]/B`G1&]M86EN(&%D;6EN(&%C8V]U;G0@
M)3$@:&%S(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]P<F]P97)T:65S7U]S:&]R="UT:71L92<@/3X@)T1O;6%I;B!P<F]P
M97)T:65S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO<')O<&5R=&EE
M<U]?=&ET;&4G(#T^("=3970@=7`@9&]M86EN(&%D;6EN(&9O<B!D;VUA:6X@
M)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7VYE
M=RUA9&AO8U]?=VEZ87)D7U\R7VYE=R<@/3X@)TYE=R!D;VUA:6X@=VEL;"!B
M92!C<F5A=&5D(&EM;65D:6%T96QY(&%F=&5R('EO=2!C;&EC:R!.97AT(#X^
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W!R;W!E<G1I97-?;F5W
M7U]D97-C<FEP=&EO;B<@/3X@)T-R96%T92!A;F0@8V]N9FEG=7)E(&YE=R!D
M;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO<')O<&5R=&EE
M<U]N97=?7V1O;F4G(#T^("=$;VUA:6X@)3$@:&%S(&)E96X@8W)E871E9"XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7VYE=U]?
M<VAO<G0M=&ET;&4G(#T^("=#<F5A=&4@9&]M86EN)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO<')O<&5R=&EE<U]N97=?7W1I=&QE)R`]/B`G0W)E
M871E(&1O;6%I;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W!R;W!E
M<G1I97-?;F5W7U]W:7IA<F0M=&ET;&4G(#T^("=$;VUA:6X@0W)E871I;VXG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7VYE=U]?
M=VEZ87)D7U\Q7W5N:VYO=VXG(#T^("=396QE8W0@82!C;&EE;G0@9F]R('=H
M;VT@>6]U('=A;G0@=&\@8W)E871E(&$@9&]M86EN+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S(O:&]S
M=&EN9R]P<F]P97)T:65S)R`]/B`G4V5L96-T('1H92!D97-I<F5D(&AO<W1I
M;F<@='EP92!F;W(@=&AE(&1O;6%I;B!A;F0@8VQI8VL@3F5X="`^/BXG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7VYE=U]?=VEZ
M87)D7U\R+VAO<W1I;F<O<')O<&5R=&EE<U]F;W)W87)D:6YG)R`]/B`G5VAE
M;B!D;VYE('=I=&@@8V]N9FEG=7)I;F<@9F]R=V%R9&EN9R!O;B!T:&4@9&]M
M86EN+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@=&AE(&-O;F9I9W5R871I;VX@
M86YD(&5X:70@=&AE('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\R+VAO<W1I;F<O<')O<&5R
M=&EE<U]P:&]S=&EN9R<@/3X@)U=H96X@9&]N92!W:71H(&-O;F9I9W5R:6YG
M('!H>7-I8V%L(&AO<W1I;F<@;VX@=&AE(&1O;6%I;BP@8VQI8VL@1FEN:7-H
M('1O(&%P<&QY(&%L;"!C:&%N9V5S(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO<')O<&5R=&EE<U]N97=?7W=I
M>F%R9%]?,B]L:6UI=',G(#T^("=#;&EC:R!.97AT(#X^('1O('!R;V-E960@
M=&\@8V]N9FEG=7)I;F<@:&]S=&EN9R!F;W(@=&AE(&1O;6%I;BX@0VQI8VL@
M1FEN:7-H('1O(&%P<&QY(&1O;6%I;B!L:6UI=',@86YD(&5X:70@=&AE('=I
M>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S
M7VYE=U]?=VEZ87)D7U\R7VYE=R<@/3X@)T-L:6-K($YE>'0@/CX@=&\@8W)E
M871E('1H92!D;VUA:6X@86YD('!R;V-E960@=&\@8V]N9FEG=7)I;F<@9&]M
M86EN(&QI;6ET<RX@0VQI8VL@1FEN:7-H('1O(&-R96%T92!T:&4@9&]M86EN
M('=I=&AO=70@:71S(&9U<G1H97(@8V]N9FEG=7)I;F<@86YD(&5X:70@=&AE
M('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T
M:65S7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G0VAA;F=E('EO=7(@<&%S<W=O
M<F0@86YD('!E<G-O;F%L(&EN9F\L('-E="!U<"!#4"!A<'!E87)A;F-E(&%N
M9"!V:65W('EO=7(@<&5R;6ES<VEO;G,N)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO<')O<&5R=&EE<U]S96QF7U]D;VYE)R`]/B`G4')O<&5R=&EE
M<R!O9B!Y;W5R(&1O;6%I;B!H879E(&)E96X@=7!D871E9"XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7W-E;&9?7W-H;W)T+71I
M=&QE)R`]/B`G1&]M86EN('!R;W!E<G1I97,G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]P<F]P97)T:65S7W-E;&9?7W1I=&QE)R`]/B`G161I="!M
M>2!A8V-O=6YT)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO<')O<&5R
M=&EE<U]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)U-E="!U<"!D;VUA:6X@
M861M:6YI<W1R871O<B!A8V-O=6YT(&9O<B!A(&1O;6%I;BXG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7W5N:VYO=VY?7W-H;W)T
M+71I=&QE)R`]/B`G1&]M86EN('!R;W!E<G1I97,G+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7W5N:VYO=VY?7W1I=&QE)R`]/B`G
M4V5T('5P(&1O;6%I;B!A9&UI;B!F;W(@9&]M86EN)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F0M=&ET
M;&4G(#T^("=3971T:6YG(%5P($1O;6%I;B!!9&UI;FES=')A=&]R($%C8V]U
M;G0G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7W5N
M:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&]M86EN
M(&9O<B!W:&EC:"!Y;W4@=V%N="!T;R!S970@=7`@9&]M86EN(&%D;6EN:7-T
M<F%T;W(@86-C;W5N="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P
M<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,R<@/3X@)U=H96X@9&]N92!W
M:71H('-P96-I9GEI;F<@<')O<&5R=&EE<R!O9B!D;VUA:6X@861M:6YI<W1R
M871O<B!A8V-O=6YT+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@8VAA;F=E<R!A
M;F0@97AI="!T:&4@=VEZ87)D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\S7W-E;&8G(#T^("=7
M:&5N(&1O;F4@=VET:"!S<&5C:69Y:6YG('!R;W!E<G1I97,@;V8@9&]M86EN
M(&%D;6EN:7-T<F%T;W(@86-C;W5N="P@8VQI8VL@1FEN:7-H('1O(&%P<&QY
M(&-H86YG97,@86YD(&5X:70@=&AE('=I>F%R9"XG+`H*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO=&]G9VQE7V1I<V%B;&5?7V1E<V-R:7!T:6]N)R`]
M/B`G1&ES86)L92!D;VUA:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO=&]G9VQE7V1I<V%B;&5?7V1O;F4G(#T^("=$;VUA:6X@)3$@:&%S
M(&)E96X@9&ES86)L960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M=&]G9VQE7V1I<V%B;&5?7W-H;W)T+71I=&QE)R`]/B`G1&ES86)L92<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W1O9V=L95]D:7-A8FQE7U]T:71L
M92<@/3X@)T1I<V%B;&4@9&]M86EN("4Q)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO=&]G9VQE7V5N86)L95]?9&5S8W)I<'1I;VXG(#T^("=%;F%B
M;&4@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W1O
M9V=L95]E;F%B;&5?7V1O;F4G(#T^("=$;VUA:6X@)3$@:&%S(&)E96X@96YA
M8FQE9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]T;V=G;&5?96YA
M8FQE7U]S:&]R="UT:71L92<@/3X@)T5N86)L92<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+W1O9V=L95]E;F%B;&5?7W1I=&QE)R`]/B`G16YA8FQE
M(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W1O9V=L
M95]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T5N86)L92!O<B!D:7-A8FQE
M(&$@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W1O9V=L
M95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T5N86)L92]D:7-A8FQE)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO=&]G9VQE7W5N:VYO=VY?7W1I
M=&QE)R`]/B`G16YA8FQE+T1I<V%B;&4@9&]M86EN)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO=&]G9VQE7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@
M/3X@)T5N86)L:6YG+T1I<V%B;&EN9R!$;VUA:6XG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]T;V=G;&5?=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO
M=VXG(#T^("=396QE8W0@=VAI8V@@9&]M86EN('EO=2!W86YT('1O(&5N86)L
M92!O<B!D:7-A8FQE+B<L"@H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O
M<BUC;VUP86YY+6YA;65?7V1E<V-R:7!T:6]N)R`]/B`G0V]M<&%N>2!N86UE
M(&]F(&-L:65N="`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O
M<BUC;VUP86YY+6YA;65?7W-H;W)T+71I=&QE)R`]/B`G0V]M<&%N>2!N86UE
M)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M8V]M<&%N>2UN86UE
M7U]T:71L92<@/3X@)T-O;7!A;GD@;F%M92!O9B!C;&EE;G0@)3$G+`H@("`@
M("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUC;VUP86YY+6YA;65?<V5L9E]?
M9&5S8W)I<'1I;VXG(#T^("=9;W5R(&-O;7!A;GD@;F%M92<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O:6YD:6-A=&]R+6-O;7!A;GDM;F%M95]S96QF7U]S:&]R
M="UT:71L92<@/3X@)T-O;7!A;GD@;F%M92<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O:6YD:6-A=&]R+6-O;7!A;GDM;F%M95]S96QF7U]T:71L92<@/3X@)UEO
M=7(@8V]M<&%N>2!N86UE)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T
M;W(M8V]M<&%N>2UN86UE7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G0V]M
M<&%N>2!N86UE(&]F(&$@8VQI96YT+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M:6YD:6-A=&]R+6-O;7!A;GDM;F%M95]U;FMN;W=N7U]S:&]R="UT:71L92<@
M/3X@)T-O;7!A;GD@;F%M92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A
M=&]R+6-O;7!A;GDM;F%M95]U;FMN;W=N7U]T:71L92<@/3X@)T-O;7!A;GD@
M;F%M92!O9B!A(&-L:65N="<L"@H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC
M871O<BUC;VYT86-T+6YA;65?7V1E<V-R:7!T:6]N)R`]/B`G0V]N=&%C="!N
M86UE(&]F(&-L:65N="`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC
M871O<BUC;VYT86-T+6YA;65?7W-H;W)T+71I=&QE)R`]/B`G0V]N=&%C="!N
M86UE)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M8V]N=&%C="UN
M86UE7U]T:71L92<@/3X@)T-O;G1A8W0@;F%M92!O9B!C;&EE;G0@)3$G+`H@
M("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUC;VYT86-T+6YA;65?<V5L
M9E]?9&5S8W)I<'1I;VXG(#T^("=9;W5R(&-O;G1A8W0@;F%M92<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+6-O;G1A8W0M;F%M95]S96QF7U]S
M:&]R="UT:71L92<@/3X@)T-O;G1A8W0@;F%M92<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O:6YD:6-A=&]R+6-O;G1A8W0M;F%M95]S96QF7U]T:71L92<@/3X@
M)UEO=7(@8V]N=&%C="!N86UE)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I
M8V%T;W(M8V]N=&%C="UN86UE7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G
M0V]N=&%C="!N86UE(&]F(&$@8VQI96YT+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O:6YD:6-A=&]R+6-O;G1A8W0M;F%M95]U;FMN;W=N7U]S:&]R="UT:71L
M92<@/3X@)T-O;G1A8W0@;F%M92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD
M:6-A=&]R+6-O;G1A8W0M;F%M95]U;FMN;W=N7U]T:71L92<@/3X@)T-O;G1A
M8W0@;F%M92!O9B!A(&-L:65N="<L"@H@("`@("`@("=U:5]?8VQI96YT+VEN
M9&EC871O<BUD:7-K+7-P86-E+6QI;6ET+75S86=E7U]D97-C<FEP=&EO;B<@
M/3X@)T1I<VL@<W!A8V4@;&EM:70@=7-A9V4@9F]R(&-L:65N="`E,2XG+`H@
M("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUD:7-K+7-P86-E+6QI;6ET
M+75S86=E7U]S:&]R="UT:71L92<@/3X@)T1I<VL@<W!A8V4@;&EM:70@=7-A
M9V4G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUD:7-K+7-P86-E
M+6QI;6ET+75S86=E7U]T:71L92<@/3X@)T1I<VL@<W!A8V4@;&EM:70@=7-A
M9V4@9F]R(&-L:65N="`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A
M=&]R+61I<VLM<W!A8V4M;&EM:70M=7-A9V5?<V5L9E]?9&5S8W)I<'1I;VXG
M(#T^("=9;W5R(&1I<VL@<W!A8V4@;&EM:70@=7-A9V4G+`H@("`@("`@("=U
M:5]?8VQI96YT+VEN9&EC871O<BUD:7-K+7-P86-E+6QI;6ET+75S86=E7W-E
M;&9?7W-H;W)T+71I=&QE)R`]/B`G1&ES:R!S<&%C92!L:6UI="!U<V%G92<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+61I<VLM<W!A8V4M;&EM
M:70M=7-A9V5?<V5L9E]?=&ET;&4G(#T^("=9;W5R(&1I<VL@<W!A8V4@;&EM
M:70@=7-A9V4G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUD:7-K
M+7-P86-E+6QI;6ET+75S86=E7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G
M1&ES:R!S<&%C92!L:6UI="!U<V%G92!F;W(@82!C;&EE;G0N)RP*("`@("`@
M("`G=6E?7V-L:65N="]I;F1I8V%T;W(M9&ES:RUS<&%C92UL:6UI="UU<V%G
M95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T1I<VL@<W!A8V4@;&EM:70@
M=7-A9V4G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUD:7-K+7-P
M86-E+6QI;6ET+75S86=E7W5N:VYO=VY?7W1I=&QE)R`]/B`G1&ES:R!S<&%C
M92!L:6UI="!U<V%G92!F;W(@82!C;&EE;G0G+`H*("`@("`@("`G=6E?7V-L
M:65N="]I;F1I8V%T;W(M96UA:6Q?7V1E<V-R:7!T:6]N)R`]/B`G16UA:6P@
M861D<F5S<R!O9B!C;&EE;G0@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]I
M;F1I8V%T;W(M96UA:6Q?7W-H;W)T+71I=&QE)R`]/B`G16UA:6P@861D<F5S
M<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+65M86EL7U]T:71L
M92<@/3X@)T5M86EL(&%D9')E<W,@;V8@8VQI96YT("4Q)RP*("`@("`@("`G
M=6E?7V-L:65N="]I;F1I8V%T;W(M96UA:6Q?<V5L9E]?9&5S8W)I<'1I;VXG
M(#T^("=9;W5R(&5M86EL(&%D9')E<W,G+`H@("`@("`@("=U:5]?8VQI96YT
M+VEN9&EC871O<BUE;6%I;%]S96QF7U]S:&]R="UT:71L92<@/3X@)T5M86EL
M(&%D9')E<W,G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUE;6%I
M;%]S96QF7U]T:71L92<@/3X@)UEO=7(@96UA:6P@861D<F5S<R<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+65M86EL7W5N:VYO=VY?7V1E<V-R
M:7!T:6]N)R`]/B`G16UA:6P@861D<F5S<R!O9B!A(&-L:65N="XG+`H@("`@
M("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUE;6%I;%]U;FMN;W=N7U]S:&]R
M="UT:71L92<@/3X@)T5M86EL(&%D9')E<W,G+`H@("`@("`@("=U:5]?8VQI
M96YT+VEN9&EC871O<BUE;6%I;%]U;FMN;W=N7U]T:71L92<@/3X@)T5M86EL
M(&%D9')E<W,@;V8@82!C;&EE;G0G+`H*("`@("`@("`G=6E?7V-L:65N="]I
M;F1I8V%T;W(M9G5L;"US=&%T=7-?7V1E<V-R:7!T:6]N)R`]/B`G0V]M<&QE
M=&4@<W1A='5S(&9O<B!C;&EE;G0@)3$N)RP*("`@("`@("`G=6E?7V-L:65N
M="]I;F1I8V%T;W(M9G5L;"US=&%T=7-?7W-H;W)T+71I=&QE)R`]/B`G0V]M
M<&QE=&4@<W1A='5S)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M
M9G5L;"US=&%T=7-?7W1I=&QE)R`]/B`G0V]M<&QE=&4@<W1A='5S(&9O<B!C
M;&EE;G0@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUF=6QL
M+7-T871U<U]S96QF7U]D97-C<FEP=&EO;B<@/3X@)UEO=7(@8V]M<&QE=&4@
M<W1A='5S)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M9G5L;"US
M=&%T=7-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=#;VUP;&5T92!S=&%T=7,G
M+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUF=6QL+7-T871U<U]S
M96QF7U]T:71L92<@/3X@)UEO=7(@8V]M<&QE=&4@<W1A='5S)RP*("`@("`@
M("`G=6E?7V-L:65N="]I;F1I8V%T;W(M9G5L;"US=&%T=7-?=6YK;F]W;E]?
M9&5S8W)I<'1I;VXG(#T^("=#;VUP;&5T92!S=&%T=7,@9F]R(&$@8VQI96YT
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+69U;&PM<W1A='5S
M7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G0V]M<&QE=&4@<W1A='5S)RP*
M("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M9G5L;"US=&%T=7-?=6YK
M;F]W;E]?=&ET;&4G(#T^("=#;VUP;&5T92!S=&%T=7,@9F]R(&$@8VQI96YT
M)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+6UA>"UD;VUA:6YS
M+6QI;6ET+75S86=E7U]D97-C<FEP=&EO;B<@/3X@)TUA>&EM=6T@9&]M86EN
M<R!L:6UI="!U<V%G92!F;W(@8VQI96YT("4Q+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O:6YD:6-A=&]R+6UA>"UD;VUA:6YS+6QI;6ET+75S86=E7U]S:&]R
M="UT:71L92<@/3X@)TUA>&EM=6T@9&]M86EN<R!L:6UI="!U<V%G92<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+6UA>"UD;VUA:6YS+6QI;6ET
M+75S86=E7U]T:71L92<@/3X@)TUA>&EM=6T@9&]M86EN<R!L:6UI="!U<V%G
M92!F;W(@8VQI96YT("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T
M;W(M;6%X+61O;6%I;G,M;&EM:70M=7-A9V5?<V5L9E]?9&5S8W)I<'1I;VXG
M(#T^("=9;W5R(&UA>&EM=6T@9&]M86EN<R!L:6UI="!U<V%G92<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+6UA>"UD;VUA:6YS+6QI;6ET+75S
M86=E7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G36%X:6UU;2!D;VUA:6YS(&QI
M;6ET('5S86=E)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M;6%X
M+61O;6%I;G,M;&EM:70M=7-A9V5?<V5L9E]?=&ET;&4G(#T^("=9;W5R(&UA
M>&EM=6T@9&]M86EN<R!L:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O:6YD:6-A=&]R+6UA>"UD;VUA:6YS+6QI;6ET+75S86=E7W5N:VYO=VY?
M7V1E<V-R:7!T:6]N)R`]/B`G36%X:6UU;2!D;VUA:6YS(&QI;6ET('5S86=E
M(&9O<B!A(&-L:65N="<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R
M+6UA>"UD;VUA:6YS+6QI;6ET+75S86=E7W5N:VYO=VY?7W-H;W)T+71I=&QE
M)R`]/B`G36%X:6UU;2!D;VUA:6YS(&QI;6ET('5S86=E)RP*("`@("`@("`G
M=6E?7V-L:65N="]I;F1I8V%T;W(M;6%X+61O;6%I;G,M;&EM:70M=7-A9V5?
M=6YK;F]W;E]?=&ET;&4G(#T^("=-87AI;75M(&1O;6%I;G,@;&EM:70@=7-A
M9V4@9F]R(&$@8VQI96YT)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A
M=&]R+6UA>"UM86EL8F]X97,M;&EM:70M=7-A9V5?7V1E<V-R:7!T:6]N)R`]
M/B`G36%X:6UU;2!M86EL8F]X97,@;&EM:70@=7-A9V4@9F]R(&-L:65N="`E
M,2XG+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUM87@M;6%I;&)O
M>&5S+6QI;6ET+75S86=E7U]S:&]R="UT:71L92<@/3X@)TUA>&EM=6T@;6%I
M;&)O>&5S(&QI;6ET('5S86=E)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I
M8V%T;W(M;6%X+6UA:6QB;WAE<RUL:6UI="UU<V%G95]?=&ET;&4G(#T^("=-
M87AI;75M(&UA:6QB;WAE<R!L:6UI="!U<V%G92!F;W(@8VQI96YT("4Q)RP*
M("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M;6%X+6UA:6QB;WAE<RUL
M:6UI="UU<V%G95]S96QF7U]D97-C<FEP=&EO;B<@/3X@)UEO=7(@;6%X:6UU
M;2!M86EL8F]X97,@;&EM:70@=7-A9V4G+`H@("`@("`@("=U:5]?8VQI96YT
M+VEN9&EC871O<BUM87@M;6%I;&)O>&5S+6QI;6ET+75S86=E7W-E;&9?7W-H
M;W)T+71I=&QE)R`]/B`G36%X:6UU;2!M86EL8F]X97,@;&EM:70@=7-A9V4G
M+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUM87@M;6%I;&)O>&5S
M+6QI;6ET+75S86=E7W-E;&9?7W1I=&QE)R`]/B`G66]U<B!M87AI;75M(&UA
M:6QB;WAE<R!L:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD
M:6-A=&]R+6UA>"UM86EL8F]X97,M;&EM:70M=7-A9V5?=6YK;F]W;E]?9&5S
M8W)I<'1I;VXG(#T^("=-87AI;75M(&UA:6QB;WAE<R!L:6UI="!U<V%G92!F
M;W(@82!C;&EE;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M
M;6%X+6UA:6QB;WAE<RUL:6UI="UU<V%G95]U;FMN;W=N7U]S:&]R="UT:71L
M92<@/3X@)TUA>&EM=6T@;6%I;&)O>&5S(&QI;6ET('5S86=E)RP*("`@("`@
M("`G=6E?7V-L:65N="]I;F1I8V%T;W(M;6%X+6UA:6QB;WAE<RUL:6UI="UU
M<V%G95]U;FMN;W=N7U]T:71L92<@/3X@)TUA>&EM=6T@;6%I;&)O>&5S(&QI
M;6ET('5S86=E(&9O<B!A(&-L:65N="<L"@H@("`@("`@("=U:5]?8VQI96YT
M+VEN9&EC871O<BUS=&%T95]?9&5S8W)I<'1I;VXG(#T^("=3=&%T92!O9B!C
M;&EE;G0@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M<W1A
M=&5?7W-H;W)T+71I=&QE)R`]/B`G4W1A=&4G+`H@("`@("`@("=U:5]?8VQI
M96YT+VEN9&EC871O<BUS=&%T95]?=&ET;&4G(#T^("=3=&%T92!O9B!C;&EE
M;G0@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUS=&%T95]S
M96QF7U]D97-C<FEP=&EO;B<@/3X@)UEO=7(@<W1A=&4G+`H@("`@("`@("=U
M:5]?8VQI96YT+VEN9&EC871O<BUS=&%T95]S96QF7U]S:&]R="UT:71L92<@
M/3X@)U-T871E)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M<W1A
M=&5?<V5L9E]?=&ET;&4G(#T^("=9;W5R('-T871E)RP*("`@("`@("`G=6E?
M7V-L:65N="]I;F1I8V%T;W(M<W1A=&5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG
M(#T^("=3=&%T92!O9B!A(&-L:65N="XG+`H@("`@("`@("=U:5]?8VQI96YT
M+VEN9&EC871O<BUS=&%T95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U-T
M871E)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M<W1A=&5?=6YK
M;F]W;E]?=&ET;&4G(#T^("=3=&%T92!O9B!A(&-L:65N="<L"@H@("`@("`@
M("=U:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]?9&5S8W)I
M<'1I;VXG(#T^("=$971A:6QE9"!S=&%T=7,@9F]R(&-L:65N="`E,2XG+`H@
M("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]?
M<VAO<G0M=&ET;&4G(#T^("=$971A:6QE9"!S=&%T=7,G+`H@("`@("`@("=U
M:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]?=&ET;&4G(#T^
M("=$971A:6QE9"!S=&%T=7,@9F]R(&-L:65N="`E,2<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O:6YD:6-A=&]R+7-T871U<RUD971A:6QS7W-E;&9?7V1E<V-R
M:7!T:6]N)R`]/B`G66]U<B!D971A:6QE9"!S=&%T=7,G+`H@("`@("`@("=U
M:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]S96QF7U]S:&]R
M="UT:71L92<@/3X@)T1E=&%I;&5D('-T871U<R<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O:6YD:6-A=&]R+7-T871U<RUD971A:6QS7W-E;&9?7W1I=&QE)R`]
M/B`G66]U<B!D971A:6QE9"!S=&%T=7,G+`H@("`@("`@("=U:5]?8VQI96YT
M+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]U;FMN;W=N7U]D97-C<FEP=&EO
M;B<@/3X@)T1E=&%I;&5D('-T871U<R!F;W(@82!C;&EE;G0N)RP*("`@("`@
M("`G=6E?7V-L:65N="]I;F1I8V%T;W(M<W1A='5S+61E=&%I;'-?=6YK;F]W
M;E]?<VAO<G0M=&ET;&4G(#T^("=$971A:6QE9"!S=&%T=7,G+`H@("`@("`@
M("=U:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]U;FMN;W=N
M7U]T:71L92<@/3X@)T1E=&%I;&5D('-T871U<R!F;W(@82!C;&EE;G0G+`H*
M("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M<W1A='5S7U]D97-C<FEP
M=&EO;B<@/3X@)U-T871U<R!F;W(@8VQI96YT("4Q+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O:6YD:6-A=&]R+7-T871U<U]?<VAO<G0M=&ET;&4G(#T^("=3
M=&%T=7,G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7-?
M7W1I=&QE)R`]/B`G4W1A='5S(&9O<B!C;&EE;G0@)3$G+`H@("`@("`@("=U
M:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7-?<V5L9E]?9&5S8W)I<'1I;VXG
M(#T^("=9;W5R('-T871U<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A
M=&]R+7-T871U<U]S96QF7U]S:&]R="UT:71L92<@/3X@)U-T871U<R<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+7-T871U<U]S96QF7U]T:71L
M92<@/3X@)UEO=7(@<W1A='5S)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I
M8V%T;W(M<W1A='5S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G4W1A='5S
M(&9O<B!A(&-L:65N="XG+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O
M<BUS=&%T=7-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=3=&%T=7,G+`H@
M("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7-?=6YK;F]W;E]?
M=&ET;&4G(#T^("=3=&%T=7,@9F]R(&$@8VQI96YT)RP*"B`@("`@("`@)W5I
M7U]C;&EE;G0O:6YD:6-A=&]R+71R869F:6,M;&EM:70M=7-A9V5?7V1E<V-R
M:7!T:6]N)R`]/B`G5')A9F9I8R!L:6UI="!U<V%G92!F;W(@8VQI96YT("4Q
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+71R869F:6,M;&EM
M:70M=7-A9V5?7W-H;W)T+71I=&QE)R`]/B`G5')A9F9I8R!L:6UI="!U<V%G
M92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+71R869F:6,M;&EM
M:70M=7-A9V5?7W1I=&QE)R`]/B`G5')A9F9I8R!L:6UI="!U<V%G92!F;W(@
M8VQI96YT("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M=')A
M9F9I8RUL:6UI="UU<V%G95]S96QF7U]D97-C<FEP=&EO;B<@/3X@)UEO=7(@
M=')A9F9I8R!L:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD
M:6-A=&]R+71R869F:6,M;&EM:70M=7-A9V5?<V5L9E]?<VAO<G0M=&ET;&4G
M(#T^("=4<F%F9FEC(&QI;6ET('5S86=E)RP*("`@("`@("`G=6E?7V-L:65N
M="]I;F1I8V%T;W(M=')A9F9I8RUL:6UI="UU<V%G95]S96QF7U]T:71L92<@
M/3X@)UEO=7(@=')A9F9I8R!L:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O:6YD:6-A=&]R+71R869F:6,M;&EM:70M=7-A9V5?=6YK;F]W;E]?
M9&5S8W)I<'1I;VXG(#T^("=4<F%F9FEC(&QI;6ET('5S86=E(&9O<B!A(&-L
M:65N="XG+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUT<F%F9FEC
M+6QI;6ET+75S86=E7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G5')A9F9I
M8R!L:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R
M+71R869F:6,M;&EM:70M=7-A9V5?=6YK;F]W;E]?=&ET;&4G(#T^("=4<F%F
M9FEC(&QI;6ET('5S86=E(&9O<B!A(&-L:65N="<L"@H@("`@("`@("=U:5]?
M8VQI96YT+VEP+7!O;VQ?7V1E<V-R:7!T:6]N)R`]/B`G061D+U)E;6]V92!)
M4"!A9&1R97-S97,@86YD(&%S<VEG;B!34TP@8V5R=&EF:6-A=&5S(&9O<B!C
M;&EE;G0@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]I<"UP;V]L7U]S:&]R
M="UT:71L92<@/3X@)TE0('!O;VPG+`H@("`@("`@("=U:5]?8VQI96YT+VEP
M+7!O;VQ?7W1I=&QE)R`]/B`G0VQI96YT("4Q($E0('!O;VPG+`H@("`@("`@
M("=U:5]?8VQI96YT+VEP+7!O;VQ?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=6
M:65W('EO=7(@25`@<&]O;"XG+`H@("`@("`@("=U:5]?8VQI96YT+VEP+7!O
M;VQ?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=)4"!P;V]L)RP*("`@("`@("`G
M=6E?7V-L:65N="]I<"UP;V]L7W-E;&9?7W1I=&QE)R`]/B`G37D@25`@<&]O
M;"<L"@H@("`@("`@("=U:5]?8VQI96YT+VEP+7!O;VPO<')O<&5R=&EE<U]?
M9&5S8W)I<'1I;VXG(#T^("=3970@=7`@25`@<&]O;"!F;W(@8VQI96YT("4Q
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O:7`M<&]O;"]P<F]P97)T:65S7U]D
M;VYE)R`]/B`G0VQI96YT("4Q($E0('!O;VP@:&%S(&)E96X@=7!D871E9"XG
M+`H@("`@("`@("=U:5]?8VQI96YT+VEP+7!O;VPO<')O<&5R=&EE<U]?<VAO
M<G0M=&ET;&4G(#T^("=)4"!P;V]L)RP*("`@("`@("`G=6E?7V-L:65N="]I
M<"UP;V]L+W!R;W!E<G1I97-?7W1I=&QE)R`]/B`G4V5T('5P($E0('!O;VP@
M9F]R(&-L:65N="`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O:7`M<&]O;"]P
M<F]P97)T:65S7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G5FEE=R!Y;W5R($E0
M('!O;VPN)RP*("`@("`@("`G=6E?7V-L:65N="]I<"UP;V]L+W!R;W!E<G1I
M97-?<V5L9E]?9&]N92<@/3X@)R<L"B`@("`@("`@)W5I7U]C;&EE;G0O:7`M
M<&]O;"]P<F]P97)T:65S7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G37D@25`@
M<&]O;"<L"B`@("`@("`@)W5I7U]C;&EE;G0O:7`M<&]O;"]P<F]P97)T:65S
M7W-E;&9?7W1I=&QE)R`]/B`G37D@25`@<&]O;"<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O:7`M<&]O;"]P<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N
M)R`]/B`G061D+U)E;6]V92!)4"!A9&1R97-S97,@=&\O9G)O;2!C;&EE;G0@
M25`@<&]O;"P@86YD(&UA;F%G92!34TP@8V5R=&EF:6-A=&5S+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O:7`M<&]O;"]P<F]P97)T:65S7W5N:VYO=VY?7W-H
M;W)T+71I=&QE)R`]/B`G25`@<&]O;"<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M:7`M<&]O;"]P<F]P97)T:65S7W5N:VYO=VY?7W1I=&QE)R`]/B`G4V5T('5P
M(&-L:65N="!)4"!P;V]L)RP*("`@("`@("`G=6E?7V-L:65N="]I<"UP;V]L
M+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G0VQI96YT
M($E0(%!O;VP@0V]N9FEG=7)A=&EO;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M:7`M<&]O;"]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,5]U;FMN;W=N
M)R`]/B`G4V5L96-T(&$@8VQI96YT('=H;W-E($E0('!O;VP@>6]U('=A;G0@
M=&\@8V]N9FEG=7)E+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O:7`M<&]O;"]P
M<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,R<@/3X@)U=H96X@9&]N92!W
M:71H(&5D:71I;F<@=&AE(&-L:65N="!)4"!P;V]L+"!C;&EC:R!&:6YI<V@@
M=&\@87!P;'D@8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@
M("`@("=U:5]?8VQI96YT+VQI;6ET<U]?9&5S8W)I<'1I;VXG(#T^("=6:65W
M(&]R(&5D:70@;&EM:71S(&]F(&-L:65N="`E,2XG+`H@("`@("`@("=U:5]?
M8VQI96YT+VQI;6ET<U]?9&]N92<@/3X@)TQI;6ET<R!O9B!C;&EE;G0@)3$@
M:&%V92!B965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N="]L:6UI
M='-?7W-H;W)T+71I=&QE)R`]/B`G3&EM:71S)RP*("`@("`@("`G=6E?7V-L
M:65N="]L:6UI='-?7W1I=&QE)R`]/B`G5FEE=R!O<B!E9&ET(&QI;6ET<R!O
M9B!C;&EE;G0@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+VQI;6ET<U]S96QF
M7U]D97-C<FEP=&EO;B<@/3X@)U9I97<@;7D@;&EM:71S+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O;&EM:71S7W-E;&9?7V1O;F4G(#T^("<G+`H@("`@("`@
M("=U:5]?8VQI96YT+VQI;6ET<U]S96QF7U]S:&]R="UT:71L92<@/3X@)TQI
M;6ET<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O;&EM:71S7W-E;&9?7W1I=&QE
M)R`]/B`G5FEE=R!M>2!L:6UI=',G+`H@("`@("`@("=U:5]?8VQI96YT+VQI
M;6ET<U]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)U9I97<@;W(@961I="!L
M:6UI=',@;V8@82!C;&EE;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]L:6UI
M='-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=,:6UI=',G+`H@("`@("`@
M("=U:5]?8VQI96YT+VQI;6ET<U]U;FMN;W=N7U]T:71L92<@/3X@)U9I97<@
M;W(@961I="!L:6UI=',@;V8@82!C;&EE;G0G+`H@("`@("`@("=U:5]?8VQI
M96YT+VQI;6ET<U]U;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=6:65W:6YG
M(&]R(&5D:71I;F<@82!C;&EE;G0@;&EM:71S)RP*("`@("`@("`G=6E?7V-L
M:65N="]L:6UI='-?=6YK;F]W;E]?=VEZ87)D7U\Q7W5N:VYO=VXG(#T^("=0
M;&5A<V4@<V5L96-T(&$@8VQI96YT('=H;W-E(&QI;6ET<R!T;R!V:65W(&]R
M(&5D:70N)RP*("`@("`@("`G=6E?7V-L:65N="]L:6UI='-?=6YK;F]W;E]?
M=VEZ87)D7U\R)R`]/B`G069T97(@961I=&EN9R!T:&4@8VQI96YT(&QI;6ET
M<RP@8VQI8VL@1FEN:7-H+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O;&EM:71S
M7W5N:VYO=VY?7W=I>F%R9%]?,E]S96QF)R`]/B`G069T97(@=FEE=VEN9R!Y
M;W5R(&QI;6ET<RP@8VQI8VL@1FEN:7-H+B<L"@H@("`@("`@("=U:5]?8VQI
M96YT+W!E<FUI<W-I;VYS7U]D97-C<FEP=&EO;B<@/3X@)U9I97<@;W(@961I
M="!P97)M:7-S:6]N<R!F;W(@8VQI96YT(&%C8V]U;G0@)3$N)RP*("`@("`@
M("`G=6E?7V-L:65N="]P97)M:7-S:6]N<U]?9&]N92<@/3X@)U!E<FUI<W-I
M;VYS(&]F(&-L:65N="`E,2!H879E(&)E96X@=7!D871E9"XG+`H@("`@("`@
M("=U:5]?8VQI96YT+W!E<FUI<W-I;VYS7U]S:&]R="UT:71L92<@/3X@)U!E
M<FUI<W-I;VYS)RP*("`@("`@("`G=6E?7V-L:65N="]P97)M:7-S:6]N<U]?
M=&ET;&4G(#T^("=#;&EE;G0@)3$@<&5R;6ES<VEO;G,G+`H@("`@("`@("=U
M:5]?8VQI96YT+W!E<FUI<W-I;VYS7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G
M5FEE=R!Y;W5R('!E<FUI<W-I;VYS+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M<&5R;6ES<VEO;G-?<V5L9E]?9&]N92<@/3X@)R<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O<&5R;6ES<VEO;G-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=097)M
M:7-S:6]N<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O<&5R;6ES<VEO;G-?<V5L
M9E]?=&ET;&4G(#T^("=->2!P97)M:7-S:6]N<R<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O<&5R;6ES<VEO;G-?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=6
M:65W(&]R(&5D:70@<&5R;6ES<VEO;G,@9F]R(&$@8VQI96YT(&%C8V]U;G0N
M)RP*("`@("`@("`G=6E?7V-L:65N="]P97)M:7-S:6]N<U]U;FMN;W=N7U]S
M:&]R="UT:71L92<@/3X@)U!E<FUI<W-I;VYS)RP*("`@("`@("`G=6E?7V-L
M:65N="]P97)M:7-S:6]N<U]U;FMN;W=N7U]T:71L92<@/3X@)U9I97<O161I
M="!C;&EE;G0@<&5R;6ES<VEO;G,G+`H@("`@("`@("=U:5]?8VQI96YT+W!E
M<FUI<W-I;VYS7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)U9I97=I;F<O
M161I=&EN9R!#;&EE;G0@4&5R;6ES<VEO;G,G+`H@("`@("`@("=U:5]?8VQI
M96YT+W!E<FUI<W-I;VYS7W5N:VYO=VY?7W=I>F%R9%]?,2]P<F]P97)T:65S
M7W-E;&8G(#T^("=7:&5N(&1O;F4@=VET:"!V:65W:6YG('EO=7(@<&5R;6ES
M<VEO;G,L(&-L:6-K($9I;FES:"!T;R!T;R!A<'!L>2!C:&%N9V5S(&%N9"!E
M>&ET('1H92!W:7IA<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]P97)M:7-S
M:6]N<U]U;FMN;W=N7U]W:7IA<F1?7S%?=6YK;F]W;B<@/3X@)U-E;&5C="!A
M(&-L:65N="!W:&]S92!P97)M:7-S:6]N<R!Y;W4@=V%N="!T;R!V:65W+V5D
M:70N)RP*("`@("`@("`G=6E?7V-L:65N="]P97)M:7-S:6]N<U]U;FMN;W=N
M7U]W:7IA<F1?7S(G(#T^("=7:&5N(&1O;F4@=VET:"!E9&ET:6YG('1H92!C
M;&EE;G0@<&5R;6ES<VEO;G,L(&-L:6-K($9I;FES:"!T;R!A<'!L>2!C:&%N
M9V5S(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*"B`@("`@("`@)W5I7U]C;&EE
M;G0O<')E9F5R96YC97-?7V1E<V-R:7!T:6]N)R`]/B`G161I="!S97-S:6]N
M(&%N9"!I;G1E<F9A8V4@<')E9F5R96YC97,@9F]R(&-L:65N="`E,2XG+`H@
M("`@("`@("=U:5]?8VQI96YT+W!R969E<F5N8V5S7U]D;VYE)R`]/B`G4')E
M9F5R96YC97,@9F]R(&-L:65N="`E,2!H879E(&)E96X@=7!D871E9"XG+`H@
M("`@("`@("=U:5]?8VQI96YT+W!R969E<F5N8V5S7U]S:&]R="UT:71L92<@
M/3X@)U!R969E<F5N8V5S)RP*("`@("`@("`G=6E?7V-L:65N="]P<F5F97)E
M;F-E<U]?=&ET;&4G(#T^("=#;&EE;G0@)3$@<')E9F5R96YC97,G+`H@("`@
M("`@("=U:5]?8VQI96YT+W!R969E<F5N8V5S7W-E;&9?7V1E<V-R:7!T:6]N
M)R`]/B`G161I="!Y;W5R('-E<W-I;VX@86YD(&EN=&5R9F%C92!P<F5F97)E
M;F-E<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O<')E9F5R96YC97-?<V5L9E]?
M9&]N92<@/3X@)UEO=7(@<')E9F5R96YC97,@:&%V92!B965N('5P9&%T960N
M)RP*("`@("`@("`G=6E?7V-L:65N="]P<F5F97)E;F-E<U]S96QF7U]S:&]R
M="UT:71L92<@/3X@)TUY('!R969E<F5N8V5S)RP*("`@("`@("`G=6E?7V-L
M:65N="]P<F5F97)E;F-E<U]S96QF7U]T:71L92<@/3X@)TUY('!R969E<F5N
M8V5S)RP*("`@("`@("`G=6E?7V-L:65N="]P<F5F97)E;F-E<U]U;FMN;W=N
M7U]D97-C<FEP=&EO;B<@/3X@)T5D:70@0U`@<V5S<VEO;B!A;F0@:6YT97)F
M86-E('!R969E<F5N8V5S(&9O<B!A(&-L:65N="XG+`H@("`@("`@("=U:5]?
M8VQI96YT+W!R969E<F5N8V5S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G
M4')E9F5R96YC97,G+`H@("`@("`@("=U:5]?8VQI96YT+W!R969E<F5N8V5S
M7W5N:VYO=VY?7W1I=&QE)R`]/B`G161I="!C;&EE;G0@<')E9F5R96YC97,G
M+`H@("`@("`@("=U:5]?8VQI96YT+W!R969E<F5N8V5S7W5N:VYO=VY?7W=I
M>F%R9"UT:71L92<@/3X@)T5D:71I;F<@0VQI96YT(%!R969E<F5N8V5S)RP*
M("`@("`@("`G=6E?7V-L:65N="]P<F5F97)E;F-E<U]U;FMN;W=N7U]W:7IA
M<F1?7S%?=6YK;F]W;B<@/3X@)U-E;&5C="!C;&EE;G0@=VAO<V4@<V5S<VEO
M;B!A;F0@:6YT97)F86-E('!R969E<F5N8V5S('EO=2!W86YT('1O(&UA;F%G
M92XG+`H@("`@("`@("=U:5]?8VQI96YT+W!R969E<F5N8V5S7W5N:VYO=VY?
M7W=I>F%R9%]?,B<@/3X@)T%F=&5R(&5D:71I;F<@=&AE(&-L:65N="!P<F5F
M97)E;F-E<RP@8VQI8VL@1FEN:7-H+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M<')E9F5R96YC97-?=6YK;F]W;E]?=VEZ87)D7U\R7W-E;&8G(#T^("=!9G1E
M<B!E9&ET:6YG('EO=7(@<')E9F5R96YC97,L(&-L:6-K($9I;FES:"XG+`H*
M("`@("`@("`G=6E?7V-L:65N="]P<F]P97)T:65S7U]D97-C<FEP=&EO;B<@
M/3X@)T5D:70@<&5R<V]N86P@:6YF;W)M871I;VX@;V8@8VQI96YT("4Q+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O<')O<&5R=&EE<U]?9&]N92<@/3X@)U!E
M<G-O;F%L(&EN9F]R;6%T:6]N(&]F(&-L:65N="`E,2!H87,@8F5E;B!U<&1A
M=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O<')O<&5R=&EE<U]?<VAO<G0M
M=&ET;&4G(#T^("=097)S;VYA;"!I;F9O<FUA=&EO;B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O<')O<&5R=&EE<U]?=&ET;&4G(#T^("=#;&EE;G0@)3$@<&5R
M<V]N86P@:6YF;R<L"B`@("`@("`@)W5I7U]C;&EE;G0O<')O<&5R=&EE<U]N
M97<M861H;V-?7W=I>F%R9%]?,5]N97<G(#T^("=4:&4@8VQI96YT(&%C8V]U
M;G0@=VEL;"!B92!C<F5A=&5D(&EM;65D:6%T96QY(&%F=&5R('EO=2!C;&EC
M:R!.97AT(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O<')O<&5R=&EE<U]N
M97=?7V1E<V-R:7!T:6]N)R`]/B`G0W)E871E(&YE=R!C;&EE;G0@86-C;W5N
M="XG+`H@("`@("`@("=U:5]?8VQI96YT+W!R;W!E<G1I97-?;F5W7U]D;VYE
M)R`]/B`G0VQI96YT("4Q(&AA<R!B965N(&-R96%T960N)RP*("`@("`@("`G
M=6E?7V-L:65N="]P<F]P97)T:65S7VYE=U]?<VAO<G0M=&ET;&4G(#T^("=#
M<F5A=&4@8VQI96YT)RP*("`@("`@("`G=6E?7V-L:65N="]P<F]P97)T:65S
M7VYE=U]?=&ET;&4G(#T^("=#<F5A=&4@8VQI96YT)RP*("`@("`@("`G=6E?
M7V-L:65N="]P<F]P97)T:65S7VYE=U]?=VEZ87)D+71I=&QE)R`]/B`G0VQI
M96YT($-R96%T:6]N)RP*("`@("`@("`G=6E?7V-L:65N="]P<F]P97)T:65S
M7VYE=U]?=VEZ87)D7U\Q+VEP+7!O;VPO<')O<&5R=&EE<R<@/3X@)U=H96X@
M9&]N92!W:71H(&-O;F9I9W5R:6YG('1H92!C;&EE;G0@25`@<&]O;"P@8VQI
M8VL@1FEN:7-H('1O(&-O;7!L971E+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M<')O<&5R=&EE<U]N97=?7W=I>F%R9%]?,2]L:6UI=',G(#T^("=#;&EC:R!.
M97AT(#X^('1O('!R;V-E960@=&\@8V]N9FEG=7)I;F<@8VQI96YT('!E<FUI
M<W-I;VYS+B!#;&EC:R!&:6YI<V@@=&\@87!P;'D@=&AE(&QI;6ET<R!A;F0@
M97AI="!T:&ES('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT+W!R;W!E
M<G1I97-?;F5W7U]W:7IA<F1?7S$O<&5R;6ES<VEO;G,G(#T^("=#;&EC:R!.
M97AT(#X^('1O('!R;V-E960@=&\@8V]N9FEG=7)I;F<@8VQI96YT($E0('!O
M;VPN($-L:6-K($9I;FES:"!T;R!A<'!L>2!T:&4@<&5R;6ES<VEO;G,@86YD
M(&5X:70@=&AI<R!W:7IA<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]P<F]P
M97)T:65S7VYE=U]?=VEZ87)D7U\Q7VYE=R<@/3X@)T-L:6-K($YE>'0@/CX@
M=&\@8W)E871E('1H92!C;&EE;G0@86-C;W5N="!A;F0@<')O8V5E9"!T;R!C
M;VYF:6=U<FEN9R!R97-O=7)C92!U<V%G92!L:6UI=',N($-L:6-K($9I;FES
M:"!T;R!C<F5A=&4@=&AE(&%C8V]U;G0@=VET:&]U="!I=',@9G5R=&AE<B!C
M;VYF:6=U<FEN9RXG+`H@("`@("`@("=U:5]?8VQI96YT+W!R;W!E<G1I97-?
M<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=%9&ET('EO=7(@<&5R<V]N86P@:6YF
M;W)M871I;VXN)RP*("`@("`@("`G=6E?7V-L:65N="]P<F]P97)T:65S7W-E
M;&9?7V1O;F4G(#T^("=9;W5R('!E<G-O;F%L(&EN9F]R;6%T:6]N(&AA<R!B
M965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N="]P<F]P97)T:65S
M7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G37D@<&5R<V]N86P@:6YF;W)M871I
M;VXG+`H@("`@("`@("=U:5]?8VQI96YT+W!R;W!E<G1I97-?<V5L9E]?=&ET
M;&4G(#T^("=->2!P97)S;VYA;"!I;F9O)RP*("`@("`@("`G=6E?7V-L:65N
M="]P<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G161I="!A
M(&-L:65N="!P97)S;VYA;"!I;F9O<FUA=&EO;BXG+`H@("`@("`@("=U:5]?
M8VQI96YT+W!R;W!E<G1I97-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=0
M97)S;VYA;"!I;F9O<FUA=&EO;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O<')O
M<&5R=&EE<U]U;FMN;W=N7U]T:71L92<@/3X@)T5D:70@8VQI96YT('!E<G-O
M;F%L(&EN9F\G+`H@("`@("`@("=U:5]?8VQI96YT+W!R;W!E<G1I97-?=6YK
M;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G161I=&EN9R!#;&EE;G0@4&5R<V]N
M86P@26YF;W)M871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT+W!R;W!E<G1I
M97-?=6YK;F]W;E]?=VEZ87)D7U\Q7W5N:VYO=VXG(#T^("=396QE8W0@8VQI
M96YT('=H;W-E('!E<G-O;F%L(&EN9F\@>6]U('=A;G0@=&\@8VAA;F=E+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA
M<F1?7S(G(#T^("=7:&5N(&1O;F4@=VET:"!E9&ET:6YG('1H92!C;&EE;G0@
M:6YF;RP@8VQI8VL@1FEN:7-H('1O(&%P<&QY(&-H86YG97,N)RP*("`@("`@
M("`G=6E?7V-L:65N="]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,E]S
M96QF)R`]/B`G5VAE;B!D;VYE('=I=&@@961I=&EN9R!Y;W5R(&EN9F\L(&-L
M:6-K($9I;FES:"!T;R!A<'!L>2!C:&%N9V5S+B<L"@H@("`@("`@("=U:5]?
M8VQI96YT+W1O9V=L95]D:7-A8FQE7U]D97-C<FEP=&EO;B<@/3X@)T1I<V%B
M;&4@8VQI96YT(&%C8V]U;G0@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]T
M;V=G;&5?9&ES86)L95]?9&]N92<@/3X@)T-L:65N="`E,2!H87,@8F5E;B!D
M:7-A8FQE9"XG+`H@("`@("`@("=U:5]?8VQI96YT+W1O9V=L95]D:7-A8FQE
M7U]S:&]R="UT:71L92<@/3X@)T1I<V%B;&4G+`H@("`@("`@("=U:5]?8VQI
M96YT+W1O9V=L95]D:7-A8FQE7U]T:71L92<@/3X@)T1I<V%B;&4@8VQI96YT
M("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]T;V=G;&5?96YA8FQE7U]D97-C
M<FEP=&EO;B<@/3X@)T5N86)L92!C;&EE;G0@86-C;W5N="`E,2XG+`H@("`@
M("`@("=U:5]?8VQI96YT+W1O9V=L95]E;F%B;&5?7V1O;F4G(#T^("=#;&EE
M;G0@)3$@:&%S(&)E96X@96YA8FQE9"XG+`H@("`@("`@("=U:5]?8VQI96YT
M+W1O9V=L95]E;F%B;&5?7W-H;W)T+71I=&QE)R`]/B`G16YA8FQE)RP*("`@
M("`@("`G=6E?7V-L:65N="]T;V=G;&5?96YA8FQE7U]T:71L92<@/3X@)T5N
M86)L92!C;&EE;G0@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+W1O9V=L95]U
M;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T5N86)L92!O<B!D:7-A8FQE(&$@
M8VQI96YT(&%C8V]U;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]T;V=G;&5?
M=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=%;F%B;&4O9&ES86)L92<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O=&]G9VQE7W5N:VYO=VY?7W1I=&QE)R`]/B`G
M16YA8FQE+T1I<V%B;&4@82!C;&EE;G0G+`H@("`@("`@("=U:5]?8VQI96YT
M+W1O9V=L95]U;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=%;F%B;&EN9R]$
M:7-A8FQI;F<@0VQI96YT($%C8V]U;G0G+`H@("`@("`@("=U:5]?8VQI96YT
M+W1O9V=L95]U;FMN;W=N7U]W:7IA<F1?7S%?=6YK;F]W;B<@/3X@)U-E;&5C
M="!A(&-L:65N="!A8V-O=6YT('EO=2!W86YT('1O(&5N86)L92]D:7-A8FQE
M+B<L"@H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G-?7V1E<V-R:7!T:6]N
M)R`]/B`G4V5R=F5R+7=I9&4@8W5S=&]M(&)U='1O;G,N)RP*("`@("`@("`G
M=6E?7V-U<W1O;2UB=71T;VYS7U]S:&]R="UT:71L92<@/3X@)T-U<W1O;2!B
M=71T;VYS)RP*("`@("`@("`G=6E?7V-U<W1O;2UB=71T;VYS7U]T:71L92<@
M/3X@)U-E<G9E<BUW:61E(&-U<W1O;2!B=71T;VYS)RP*"B`@("`@("`@)W5I
M7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N7U]N;VYE+6%V86EL86)L
M92<@/3X@)UEO=2!D;VY<)W0@8W5R<F5N=&QY(&AA=F4@86YY(&-U<W1O;2!B
M=71T;VYS+B<L"@H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M
M+6)U='1O;B]D96QE=&5?7V1E<V-R:7!T:6]N)R`]/B`G4F5M;W9E('-E<G9E
M<BUW:61E(&-U<W1O;2!B=71T;VX@)3$N)RP*("`@("`@("`G=6E?7V-U<W1O
M;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7U]D;VYE)R`]/B`G4V5R
M=F5R+7=I9&4@8W5S=&]M(&)U='1O;B`E,2!H87,@8F5E;B!R96UO=F5D+B<L
M"B`@("`@("`@)W5I7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+V1E
M;&5T95]?<VAO<G0M=&ET;&4G(#T^("=296UO=F4G+`H@("`@("`@("=U:5]?
M8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?7W1I=&QE)R`]
M/B`G4F5M;W9E(&-U<W1O;2!B=71T;VX@)3$G+`H@("`@("`@("=U:5]?8W5S
M=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?=6YK;F]W;E]?9&5S
M8W)I<'1I;VXG(#T^("=296UO=F4@<V5R=F5R+7=I9&4@8W5S=&]M(&)U='1O
M;BXG+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O
M;B]D96QE=&5?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=296UO=F4G+`H@
M("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE
M=&5?=6YK;F]W;E]?=&ET;&4G(#T^("=296UO=F4@8W5S=&]M(&)U='1O;B<L
M"B`@("`@("`@)W5I7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+V1E
M;&5T95]U;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=#=7-T;VT@8G5T=&]N
M(')E;6]V86PG+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M
M+6)U='1O;B]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^
M("=396QE8W0@=VAI8V@@<V5R=F5R+7=I9&4@8W5S=&]M(&)U='1O;B!Y;W4@
M=V%N="!T;R!R96UO=F4N)RP*("`@("`@("`G=6E?7V-U<W1O;2UB=71T;VYS
M+V-U<W1O;2UB=71T;VXO9&5L971E7W5N:VYO=VY?7W=I>F%R9%]?,R<@/3X@
M)T-O;F9I<FT@<F5M;W9I;F<@=&AE('-E<G9E<BUW:61E(&-U<W1O;2!B=71T
M;VX@8GD@<V5L96-T:6YG('1H92!C:&5C:R!B;W@@86YD(&-L:6-K(&9I;FES
M:"!T;R!C;VUP;&5T96QY(')E;6]V92!I="!A;F0@97AI="!T:&4@=VEZ87)D
M+B<L"@H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O
M;B]P<F]P97)T:65S7U]D97-C<FEP=&EO;B<@/3X@)T5D:70@<')O<&5R=&EE
M<R!O9B!S97)V97(M=VED92!C=7-T;VT@8G5T=&]N("4Q+B<L"B`@("`@("`@
M)W5I7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?
M7V1O;F4G(#T^("=0<F]P97)T:65S(&]F(&-U<W1O;2!B=71T;VX@)3$@:&%V
M92!B965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V-U<W1O;2UB=71T;VYS
M+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]?<VAO<G0M=&ET;&4G(#T^("=0
M<F]P97)T:65S)RP*("`@("`@("`G=6E?7V-U<W1O;2UB=71T;VYS+V-U<W1O
M;2UB=71T;VXO<')O<&5R=&EE<U]?=&ET;&4G(#T^("=-;V1I9GD@<V5R=F5R
M(&-U<W1O;2!B=71T;VX@)3$G+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O
M;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?9&5S8W)I<'1I;VXG
M(#T^("=#<F5A=&4@;F5W('-E<G9E<BUW:61E(&-U<W1O;2!B=71T;VXN)RP*
M("`@("`@("`G=6E?7V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O
M<&5R=&EE<U]N97=?7V1O;F4G(#T^("=#=7-T;VT@8G5T=&]N("4Q(&AA<R!B
M965N(&-R96%T960G+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S
M=&]M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?<VAO<G0M=&ET;&4G(#T^("=#
M<F5A=&4G+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U
M='1O;B]P<F]P97)T:65S7VYE=U]?=&ET;&4G(#T^("=#<F5A=&4@<V5R=F5R
M(&-U<W1O;2!B=71T;VXG+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O
M8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D+71I=&QE)R`]
M/B`G0W5S=&]M(&)U='1O;B!C<F5A=&EO;B<L"B`@("`@("`@)W5I7U]C=7-T
M;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?;F5W7U]W:7IA
M<F1?7S)?;F5W)R`]/B`G0VQI8VL@1FEN:7-H('1O(&-R96%T92!T:&4@8W5S
M=&]M(&)U='1O;BXG+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S
M=&]M+6)U='1O;B]P<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]
M/B`G161I="!P<F]P97)T:65S(&]F(&$@<V5R=F5R+7=I9&4@8W5S=&]M(&)U
M='1O;BXG+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U
M='1O;B]P<F]P97)T:65S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G4')O
M<&5R=&EE<R<L"B`@("`@("`@)W5I7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM
M8G5T=&]N+W!R;W!E<G1I97-?=6YK;F]W;E]?=&ET;&4G(#T^("=-;V1I9GD@
M<V5R=F5R+7=I9&4@8W5S=&]M(&)U='1O;B<L"B`@("`@("`@)W5I7U]C=7-T
M;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?=6YK;F]W;E]?
M=VEZ87)D+71I=&QE)R`]/B`G36]D:69Y:6YG(%-E<G9E<BUW:61E($-U<W1O
M;2!"=71T;VXG+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M
M+6)U='1O;B]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N
M)R`]/B`G4V5L96-T('=H:6-H(&-U<W1O;2!B=71T;VX@>6]U('=A;G0@=&\@
M;6]D:69Y+B<L"B`@("`@("`@)W5I7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM
M8G5T=&]N+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\S)R`]/B`G5VAE
M;B!D;VYE('=I=&@@;6]D:69Y:6YG('1H92!S97)V97(M=VED92!C=7-T;VT@
M8G5T=&]N+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@8VAA;F=E<R!A;F0@97AI
M="!T:&4@=VEZ87)D+B<L"@H@("`@("`@("=U:5]?9&%S:&)O87)D(V-L:65N
M='-?7V1E<V-R:7!T:6]N)R`]/B`G3F\@9F%V;W)I=&4@8VQI96YT<R<L"B`@
M("`@("`@)W5I7U]D87-H8F]A<F0C8VQI96YT<U]?=&ET;&4G(#T^("=#;&EE
M;G1S)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"-C=7-T;VTM8G5T=&]N<U]?
M=&ET;&4G(#T^("=#=7-T;VT@8G5T=&]N<R<L"B`@("`@("`@)W5I7U]D87-H
M8F]A<F0C9&]M86EN<U]?9&5S8W)I<'1I;VXG(#T^("=.;R!F879O<FET92!D
M;VUA:6YS)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"-D;VUA:6YS7U]T:71L
M92<@/3X@)T1O;6%I;G,G+`H@("`@("`@("=U:5]?9&%S:&)O87)D(V9A=F]R
M:71E<R]T86)S7U]D97-C<FEP=&EO;B<@/3X@)U-H;W<@=&AE(&9O;&QO=VEN
M9R!T86)S(&EN($9A=F]R:71E<SHG+`H@("`@("`@("=U:5]?9&%S:&)O87)D
M(V9A=F]R:71E<U]?=&ET;&4G(#T^("=&879O<FET97,G+`H@("`@("`@("=U
M:5]?9&%S:&)O87)D(VEN9F\O9F]O=&5R7U]D97-C<FEP=&EO;B<@/3X@)U-H
M;W<@=&AE(&9O;&QO=VEN9R!B=71T;VYS(&EN('1H92!F;V]T97(Z)RP*("`@
M("`@("`G=6E?7V1A<VAB;V%R9"-I;F9O7U]D97-C<FEP=&EO;B<@/3X@)U-H
M;W<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;CHG+`H@("`@("`@("=U:5]?
M9&%S:&)O87)D(VEN9F]?7W1I=&QE)R`]/B`G4V5R=F5R($EN9F]R;6%T:6]N
M)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"-M86EL;F%M97-?7V1E<V-R:7!T
M:6]N)R`]/B`G3F\@9F%V;W)I=&4@;6%I;&YA;65S)RP*("`@("`@("`G=6E?
M7V1A<VAB;V%R9"-M86EL;F%M97-?7W1I=&QE)R`]/B`G36%I;&YA;65S)RP*
M("`@("`@("`G=6E?7V1A<VAB;V%R9"-Q=6EC:RUS96%R8VA?7W1I=&QE)R`]
M/B`G475I8VL@<V5A<F-H)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"-R96-E
M;G1?7V1E<V-R:7!T:6]N)R`]/B`G3F\@<F5C96YT('!A9V5S)RP*("`@("`@
M("`G=6E?7V1A<VAB;V%R9"-R96-E;G1?7W1I=&QE)R`]/B`G4F5C96YT)RP*
M("`@("`@("`G=6E?7V1A<VAB;V%R9"-S:&]R=&-U='-?7V1E<V-R:7!T:6]N
M)R`]/B`G3F\@<VAO<G1C=71S)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"-S
M:&]R=&-U='-?7W1I=&QE)R`]/B`G4VAO<G1C=71S)RP*("`@("`@("`G=6E?
M7V1A<VAB;V%R9"-S=&%T:7-T:6-S+V9O;W1E<E]?9&5S8W)I<'1I;VXG(#T^
M("=3:&]W('1H92!F;VQL;W=I;F<@8G5T=&]N<R!I;B!T:&4@9F]O=&5R.B<L
M"B`@("`@("`@)W5I7U]D87-H8F]A<F0C<W1A=&ES=&EC<U]?9&5S8W)I<'1I
M;VXG(#T^("=3:&]W('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VXZ)RP*("`@
M("`@("`G=6E?7V1A<VAB;V%R9"-S=&%T:7-T:6-S7U]T:71L92<@/3X@)U-T
M871I<W1I8W,G+`H@("`@("`@("=U:5]?9&%S:&)O87)D(W1O;VQS+V9O;W1E
M<E]?9&5S8W)I<'1I;VXG(#T^("=3:&]W('1H92!F;VQL;W=I;F<@8G5T=&]N
M<R!I;B!T:&4@9F]O=&5R.B<L"B`@("`@("`@)W5I7U]D87-H8F]A<F0C=&]O
M;'-?7V1E<V-R:7!T:6]N)R`]/B`G4VAO=R!T:&4@9F]L;&]W:6YG(&)U='1O
M;G,Z)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"-T;V]L<U]?=&ET;&4G(#T^
M("=4;V]L<R<L"B`@("`@("`@)W5I7U]D87-H8F]A<F1?7V1E<V-R:7!T:6]N
M)R`]/B`G061M:6YI<W1R871O<B!$97-K=&]P+B<L"B`@("`@("`@)W5I7U]D
M87-H8F]A<F1?7W-H;W)T+71I=&QE)R`]/B`G1&5S:W1O<"<L"B`@("`@("`@
M)W5I7U]D87-H8F]A<F1?7W1I=&QE)R`]/B`G061M:6YI<W1R871O<B!$97-K
M=&]P)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9%]S96QF7U]D97-C<FEP=&EO
M;B<@/3X@)TUY($1E<VMT;W`N)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9%]S
M96QF7U]S:&]R="UT:71L92<@/3X@)T1E<VMT;W`G+`H@("`@("`@("=U:5]?
M9&%S:&)O87)D7W-E;&9?7W1I=&QE)R`]/B`G37D@1&5S:W1O<"<L"@H@("`@
M("`@("=U:5]?9&%S:&)O87)D+V-U<W1O;6EZ95]?9&5S8W)I<'1I;VXG(#T^
M("=#=7-T;VUI>F4@061M:6YI<W1R871O<B!$97-K=&]P+B<L"B`@("`@("`@
M)W5I7U]D87-H8F]A<F0O8W5S=&]M:7IE7U]D;VYE)R`]/B`G061M:6X@1&5S
M:W1O<"!H87,@8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@)W5I7U]D87-H8F]A
M<F0O8W5S=&]M:7IE7U]S:&]R="UT:71L92<@/3X@)T-U<W1O;6EZ92!$97-K
M=&]P)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"]C=7-T;VUI>F5?7W1I=&QE
M)R`]/B`G0W5S=&]M:7IE($%D;6EN($1E<VMT;W`G+`H@("`@("`@("=U:5]?
M9&%S:&)O87)D+V-U<W1O;6EZ95]S96QF7U]D97-C<FEP=&EO;B<@/3X@)T-U
M<W1O;6EZ92!Y;W5R($1E<VMT;W`N)RP*("`@("`@("`G=6E?7V1A<VAB;V%R
M9"]C=7-T;VUI>F5?<V5L9E]?9&]N92<@/3X@)UEO=7(@1&5S:W1O<"!H87,@
M8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@)W5I7U]D87-H8F]A<F0O8W5S=&]M
M:7IE7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G0W5S=&]M:7IE($1E<VMT;W`G
M+`H@("`@("`@("=U:5]?9&%S:&)O87)D+V-U<W1O;6EZ95]S96QF7U]T:71L
M92<@/3X@)T-U<W1O;6EZ92!M>2!$97-K=&]P)RP*"B`@("`@("`@)W5I7U]D
M87-H8F]A<F0O<VAO<G1C=70O<')O<&5R=&EE<U]?9&5S8W)I<'1I;VXG(#T^
M("=%9&ET('-H;W)T8W5T("4Q+B<L"B`@("`@("`@)W5I7U]D87-H8F]A<F0O
M<VAO<G1C=70O<')O<&5R=&EE<U]?9&]N92<@/3X@)U-H;W)T8W5T("4Q(&AA
M<R!B965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"]S:&]R
M=&-U="]P<F]P97)T:65S7U]S:&]R="UT:71L92<@/3X@)T5D:70G+`H@("`@
M("`@("=U:5]?9&%S:&)O87)D+W-H;W)T8W5T+W!R;W!E<G1I97-?7W1I=&QE
M)R`]/B`G161I="!S:&]R=&-U="`E,2<L"B`@("`@("`@)W5I7U]D87-H8F]A
M<F0O<VAO<G1C=70O<')O<&5R=&EE<U]N97=?7V1E<V-R:7!T:6]N)R`]/B`G
M0W)E871E(&YE=R!S:&]R=&-U="XG+`H@("`@("`@("=U:5]?9&%S:&)O87)D
M+W-H;W)T8W5T+W!R;W!E<G1I97-?;F5W7U]D;VYE)R`]/B`G4VAO<G1C=70@
M)3$@:&%S(&)E96X@8W)E871E9"XG+`H@("`@("`@("=U:5]?9&%S:&)O87)D
M+W-H;W)T8W5T+W!R;W!E<G1I97-?;F5W7U]S:&]R="UT:71L92<@/3X@)T-R
M96%T92!S:&]R=&-U="<L"B`@("`@("`@)W5I7U]D87-H8F]A<F0O<VAO<G1C
M=70O<')O<&5R=&EE<U]N97=?7W1I=&QE)R`]/B`G0W)E871E(&YE=R!S:&]R
M=&-U="<L"@H@("`@("`@("=U:5]?:6YD:6-A=&]R+6-L:65N=',M;G5M8F5R
M7U]D97-C<FEP=&EO;B<@/3X@)TYU;6)E<B!O9B!C;&EE;G1S+B<L"B`@("`@
M("`@)W5I7U]I;F1I8V%T;W(M8VQI96YT<RUN=6UB97)?7W-H;W)T+71I=&QE
M)R`]/B`G3G5M8F5R(&]F(&-L:65N=',G+`H@("`@("`@("=U:5]?:6YD:6-A
M=&]R+6-L:65N=',M;G5M8F5R7U]T:71L92<@/3X@)TYU;6)E<B!O9B!C;&EE
M;G1S)RP*"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M8W!U7U]D97-C<FEP=&EO
M;B<@/3X@)T-052XG+`H@("`@("`@("=U:5]?:6YD:6-A=&]R+6-P=5]?<VAO
M<G0M=&ET;&4G(#T^("=#4%4G+`H@("`@("`@("=U:5]?:6YD:6-A=&]R+6-P
M=5]?=&ET;&4G(#T^("=#4%4G+`H*("`@("`@("`G=6E?7VEN9&EC871O<BUD
M:7-K+75S86=E7U]D97-C<FEP=&EO;B<@/3X@)T1I<VL@<W!A8V4@=7-A9V4N
M)RP*("`@("`@("`G=6E?7VEN9&EC871O<BUD:7-K+75S86=E7U]S:&]R="UT
M:71L92<@/3X@)T1I<VL@<W!A8V4@=7-A9V4G+`H@("`@("`@("=U:5]?:6YD
M:6-A=&]R+61I<VLM=7-A9V5?7W1I=&QE)R`]/B`G1&ES:R!S<&%C92!U<V%G
M92<L"@H@("`@("`@("=U:5]?:6YD:6-A=&]R+61O;6%I;G,M;G5M8F5R7U]D
M97-C<FEP=&EO;B<@/3X@)TYU;6)E<B!O9B!D;VUA:6YS+B<L"B`@("`@("`@
M)W5I7U]I;F1I8V%T;W(M9&]M86EN<RUN=6UB97)?7W-H;W)T+71I=&QE)R`]
M/B`G3G5M8F5R(&]F(&1O;6%I;G,G+`H@("`@("`@("=U:5]?:6YD:6-A=&]R
M+61O;6%I;G,M;G5M8F5R7U]T:71L92<@/3X@)TYU;6)E<B!O9B!D;VUA:6YS
M)RP*"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M:&]S=&YA;65?7V1E<V-R:7!T
M:6]N)R`]/B`G2&]S=&YA;64N)RP*("`@("`@("`G=6E?7VEN9&EC871O<BUH
M;W-T;F%M95]?<VAO<G0M=&ET;&4G(#T^("=(;W-T;F%M92<L"B`@("`@("`@
M)W5I7U]I;F1I8V%T;W(M:&]S=&YA;65?7W1I=&QE)R`]/B`G2&]S=&YA;64G
M+`H*("`@("`@("`G=6E?7VEN9&EC871O<BUL:6-E;G-E+65X<&ER871I;VY?
M7V1E<V-R:7!T:6]N)R`]/B`G3&EC96YS92!K97D@97AP:7)A=&EO;B!D871E
M+B<L"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M;&EC96YS92UE>'!I<F%T:6]N
M7U]S:&]R="UT:71L92<@/3X@)TQI8V5N<V4@:V5Y(&5X<&ER871I;VX@9&%T
M92<L"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M;&EC96YS92UE>'!I<F%T:6]N
M7U]T:71L92<@/3X@)TQI8V5N<V4@:V5Y(&5X<&ER871I;VX@9&%T92<L"@H@
M("`@("`@("=U:5]?:6YD:6-A=&]R+6QI8V5N<V4M:V5Y+6ED7U]D97-C<FEP
M=&EO;B<@/3X@)TQI8V5N<V4@:V5Y(&YU;6)E<BXG+`H@("`@("`@("=U:5]?
M:6YD:6-A=&]R+6QI8V5N<V4M:V5Y+6ED7U]S:&]R="UT:71L92<@/3X@)TQI
M8V5N<V4@:V5Y(&YU;6)E<B<L"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M;&EC
M96YS92UK97DM:61?7W1I=&QE)R`]/B`G3&EC96YS92!K97D@;G5M8F5R)RP*
M"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M;&]A9"UA=F%R86=E7U]D97-C<FEP
M=&EO;B<@/3X@)T%V97)A9V4@;&]A9"XG+`H@("`@("`@("=U:5]?:6YD:6-A
M=&]R+6QO860M879A<F%G95]?<VAO<G0M=&ET;&4G(#T^("=!=F5R86=E(&QO
M860G+`H@("`@("`@("=U:5]?:6YD:6-A=&]R+6QO860M879A<F%G95]?=&ET
M;&4G(#T^("=!=F5R86=E(&QO860G+`H*("`@("`@("`G=6E?7VEN9&EC871O
M<BUM96TM=7-A9V5?7V1E<V-R:7!T:6]N)R`]/B`G365M;W)Y('5S86=E+B<L
M"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M;65M+75S86=E7U]S:&]R="UT:71L
M92<@/3X@)TUE;6]R>2!U<V%G92<L"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M
M;65M+75S86=E7U]T:71L92<@/3X@)TUE;6]R>2!U<V%G92<L"@H@("`@("`@
M("=U:5]?:6YD:6-A=&]R+6]S7U]D97-C<FEP=&EO;B<@/3X@)T]P97)A=&EN
M9R!S>7-T96TN)RP*("`@("`@("`G=6E?7VEN9&EC871O<BUO<U]?<VAO<G0M
M=&ET;&4G(#T^("=/<&5R871I;F<@<WES=&5M)RP*("`@("`@("`G=6E?7VEN
M9&EC871O<BUO<U]?=&ET;&4G(#T^("=/<&5R871I;F<@<WES=&5M)RP*"B`@
M("`@("`@)W5I7U]I;F1I8V%T;W(M=7!T:6UE7U]D97-C<FEP=&EO;B<@/3X@
M)U5P=&EM92XG+`H@("`@("`@("=U:5]?:6YD:6-A=&]R+75P=&EM95]?<VAO
M<G0M=&ET;&4G(#T^("=5<'1I;64G+`H@("`@("`@("=U:5]?:6YD:6-A=&]R
M+75P=&EM95]?=&ET;&4G(#T^("=5<'1I;64G+`H*("`@("`@("`G=6E?7VEN
M9&EC871O<BUV97)S:6]N7U]D97-C<FEP=&EO;B<@/3X@)U!L97-K('9E<G-I
M;VXN)RP*("`@("`@("`G=6E?7VEN9&EC871O<BUV97)S:6]N7U]S:&]R="UT
M:71L92<@/3X@)U!L97-K('9E<G-I;VXG+`H@("`@("`@("=U:5]?:6YD:6-A
M=&]R+79E<G-I;VY?7W1I=&QE)R`]/B`G4&QE<VL@=F5R<VEO;B<L"@H@("`@
M("`@("=U:5]?;&EC96YS95]?9&5S8W)I<'1I;VXG(#T^("=6:65W('EO=7(@
M;&EC96YS92!I;F9O+"!O<F1E<B!N97<@;&EC96YS92!K97DL(')E=')I979E
M(&%N9"!U<&QO860@8V]M;6]N(&%N9"!A9&1I=&EO;F%L(&QI8V5N<V4@:V5Y
M<RXG+`H@("`@("`@("=U:5]?;&EC96YS95]?<VAO<G0M=&ET;&4G(#T^("=,
M:6-E;G-E)RP*("`@("`@("`G=6E?7VQI8V5N<V5?7W1I=&QE)R`]/B`G36%N
M86=E(%!L97-K(&QI8V5N<V4G+`H*("`@("`@("`G=6E?7VYE=W,O9&ES;6ES
M<U]?9&5S8W)I<'1I;VXG(#T^("=#;&EC:R!T;R!C;VUP;&5T96QY(&-L;W-E
M('1H92!.97=S(&9R86UE+B!0;&5S:R!W:6QL(&YO="!S:&]W('1H:7,@9G)A
M;64@=6YT:6P@3F5W<R!A<G1I8VQE<R!A<F4@=7!D871E9"XG+`H@("`@("`@
M("=U:5]?;F5W<R]D:7-M:7-S7U]D;VYE)R`]/B`G4&QE<VL@3F5W<R!H879E
M(&)E96X@8VQO<V5D+B<L"B`@("`@("`@)W5I7U]N97=S+V1I<VUI<W-?7W1I
M=&QE)R`]/B`G0VQO<V4@;F5W<R<L"@H@("`@("`@("=U:5]?<V5R=F5R7U]D
M97-C<FEP=&EO;B<@/3X@)U-E<G9E<B!M86YA9V5M96YT+B<L"B`@("`@("`@
M)W5I7U]S97)V97)?7W-H;W)T+71I=&QE)R`]/B`G4V5R=F5R)RP*("`@("`@
M("`G=6E?7W-E<G9E<E]?=&ET;&4G(#T^("=397)V97(@;6%N86=E;65N="<L
M"@H@("`@("`@("=U:5]?<V5R=F5R+V%U=&]I;G-T86QL97)?7V1E<V-R:7!T
M:6]N)R`]/B`G57!D871E('EO=7(@8V]N=')O;"!P86YE;"!O<B!I=',@8V]M
M<&]N96YT<RXG+`H@("`@("`@("=U:5]?<V5R=F5R+V%U=&]I;G-T86QL97)?
M7W-H;W)T+71I=&QE)R`]/B`G57!D871E<B<L"B`@("`@("`@)W5I7U]S97)V
M97(O875T;VEN<W1A;&QE<E]?=&ET;&4G(#T^("=5<&1A=&5R)RP*"B`@("`@
M("`@)W5I7U]S97)V97(O:6YT97)F86-E7U]D97-C<FEP=&EO;B<@/3X@)U-E
M="!U<"!$97-K=&]P('!R97-E=',L(&EN=&5R9F%C92!T96UP;&%T97,L('-K
M:6YS(&%N9"!L;V-A;&5S+B<L"B`@("`@("`@)W5I7U]S97)V97(O:6YT97)F
M86-E7U]S:&]R="UT:71L92<@/3X@)TEN=&5R9F%C92!P<F5F97)E;F-E<R<L
M"B`@("`@("`@)W5I7U]S97)V97(O:6YT97)F86-E7U]T:71L92<@/3X@)U-E
M="!U<"!S97)V97(@:6YT97)F86-E('!R969E<F5N8V5S)RP*"B`@("`@("`@
M)W5I7U]S97)V97(O:6YT97)F86-E+V1A<VAB;V%R9"UP<F5S971S7U]D97-C
M<FEP=&EO;B<@/3X@)TUA;F%G92!$97-K=&]P('!R97-E=',N)RP*("`@("`@
M("`G=6E?7W-E<G9E<B]I;G1E<F9A8V4O9&%S:&)O87)D+7!R97-E='-?7W-H
M;W)T+71I=&QE)R`]/B`G1&5S:W1O<"!P<F5S971S)RP*("`@("`@("`G=6E?
M7W-E<G9E<B]I;G1E<F9A8V4O9&%S:&)O87)D+7!R97-E='-?7W1I=&QE)R`]
M/B`G36%N86=E($1E<VMT;W`@<')E<V5T<R<L"@H@("`@("`@("=U:5]?<V5R
M=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]D96QE=&5?7V1E<V-R
M:7!T:6]N)R`]/B`G4F5M;W9E($1E<VMT;W`@<')E<V5T<RXG+`H@("`@("`@
M("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]D96QE
M=&5?7V1O;F4G(#T^("=396QE8W1E9"!D97-K=&]P('!R97-E=',@:&%V92!B
M965N(')E;6]V960N)RP*("`@("`@("`G=6E?7W-E<G9E<B]I;G1E<F9A8V4O
M9&%S:&)O87)D+7!R97-E=',O9&5L971E7U]S:&]R="UT:71L92<@/3X@)U)E
M;6]V92<L"B`@("`@("`@)W5I7U]S97)V97(O:6YT97)F86-E+V1A<VAB;V%R
M9"UP<F5S971S+V1E;&5T95]?=&ET;&4G(#T^("=296UO=F4@1&5S:W1O<"!P
M<F5S971S)RP*("`@("`@("`G=6E?7W-E<G9E<B]I;G1E<F9A8V4O9&%S:&)O
M87)D+7!R97-E=',O9&5L971E7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G
M4F5M;W9E(&$@1&5S:W1O<"!P<F5S970G+`H@("`@("`@("=U:5]?<V5R=F5R
M+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]D96QE=&5?=6YK;F]W;E]?
M<VAO<G0M=&ET;&4G(#T^("=296UO=F4G+`H@("`@("`@("=U:5]?<V5R=F5R
M+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]D96QE=&5?=6YK;F]W;E]?
M=&ET;&4G(#T^("=296UO=F4@82!$97-K=&]P('!R97-E="<L"@H@("`@("`@
M("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]P<F5S
M970O<')O<&5R=&EE<U]?9&5S8W)I<'1I;VXG(#T^("=%9&ET($1E<VMT;W`@
M<')E<V5T("4Q+B<L"B`@("`@("`@)W5I7U]S97)V97(O:6YT97)F86-E+V1A
M<VAB;V%R9"UP<F5S971S+W!R97-E="]P<F]P97)T:65S7U]D;VYE)R`]/B`G
M1&5S:W1O<"!P<F5S970@)3$@:&%S(&)E96X@=7!D871E9"XG+`H@("`@("`@
M("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]P<F5S
M970O<')O<&5R=&EE<U]?<VAO<G0M=&ET;&4G(#T^("<E,2<L"B`@("`@("`@
M)W5I7U]S97)V97(O:6YT97)F86-E+V1A<VAB;V%R9"UP<F5S971S+W!R97-E
M="]P<F]P97)T:65S7U]T:71L92<@/3X@)T5D:70@1&5S:W1O<"!P<F5S970@
M)3$G+`H@("`@("`@("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M
M<')E<V5T<R]P<F5S970O<')O<&5R=&EE<U]N97=?7V1E<V-R:7!T:6]N)R`]
M/B`G0W)E871E(&YE=R!$97-K=&]P('!R97-E="!B87-E9"!O;B!T:&4@<')E
M<V5T("4Q+B<L"B`@("`@("`@)W5I7U]S97)V97(O:6YT97)F86-E+V1A<VAB
M;V%R9"UP<F5S971S+W!R97-E="]P<F]P97)T:65S7VYE=U]?9&]N92<@/3X@
M)T1E<VMT;W`@<')E<V5T("4Q(&AA<R!B965N(&-R96%T960N)RP*("`@("`@
M("`G=6E?7W-E<G9E<B]I;G1E<F9A8V4O9&%S:&)O87)D+7!R97-E=',O<')E
M<V5T+W!R;W!E<G1I97-?;F5W7U]S:&]R="UT:71L92<@/3X@)T-O<'D@)3$G
M+`H@("`@("`@("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E
M<V5T<R]P<F5S970O<')O<&5R=&EE<U]N97=?7W1I=&QE)R`]/B`G0V]P>2!$
M97-K=&]P('!R97-E="`E,2<L"B`@("`@("`@)W5I7U]S97)V97(O:6YT97)F
M86-E+V1A<VAB;V%R9"UP<F5S971S+W!R97-E="]P<F]P97)T:65S7VYE=U]?
M=VEZ87)D+71I=&QE)R`]/B`G1&5S:W1O<"!0<F5S970@0W)E871I;VXG+`H@
M("`@("`@("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T
M<R]P<F5S970O<')O<&5R=&EE<U]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@
M)T5D:70@82!$97-K=&]P('!R97-E="XG+`H@("`@("`@("=U:5]?<V5R=F5R
M+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]P<F5S970O<')O<&5R=&EE
M<U]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T5D:70G+`H@("`@("`@("=U
M:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]P<F5S970O
M<')O<&5R=&EE<U]U;FMN;W=N7U]T:71L92<@/3X@)T5D:70@1&5S:W1O<"!P
M<F5S970G+`H@("`@("`@("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A
M<F0M<')E<V5T<R]P<F5S970O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F0M
M=&ET;&4G(#T^("=%9&ET:6YG(&$@1&5S:W1O<"!P<F5S970G+`H@("`@("`@
M("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]P<F5S
M970O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S1?=6YK;F]W;B<@/3X@
M)U-E;&5C="!W:&EC:"!$97-K=&]P('!R97-E="!Y;W4@=V%N="!T;R!E9&ET
M+B<L"@H@("`@("`@("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M
M<')E<V5T<R]U<&QO861?7V1E<V-R:7!T:6]N)R`]/B`G57!L;V%D($1E<VMT
M;W`@<')E<V5T<R!T;R!S97)V97(N)RP*("`@("`@("`G=6E?7W-E<G9E<B]I
M;G1E<F9A8V4O9&%S:&)O87)D+7!R97-E=',O=7!L;V%D7U]D;VYE)R`]/B`G
M1&5S:W1O<"!P<F5S971S(&AA=F4@8F5E;B!U<&QO861E9"XG+`H@("`@("`@
M("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]U<&QO
M861?7W-H;W)T+71I=&QE)R`]/B`G57!L;V%D)RP*("`@("`@("`G=6E?7W-E
M<G9E<B]I;G1E<F9A8V4O9&%S:&)O87)D+7!R97-E=',O=7!L;V%D7U]T:71L
M92<@/3X@)U5P;&]A9"!$97-K=&]P('!R97-E=',G+`H*("`@("`@("`G=6E?
M7W-E<G9E<B]I<"UA9&1R97-S97-?7V1E<V-R:7!T:6]N)R`]/B`G061D($E0
M(&%D9')E<W-E<R!T;R!A;F0@<F5M;W9E(&9R;VT@=&AE(&YE='=O<FL@:6YT
M97)F86-E<RXG+`H@("`@("`@("=U:5]?<V5R=F5R+VEP+6%D9')E<W-E<U]?
M<VAO<G0M=&ET;&4G(#T^("=)4"!A9&1R97-S97,G+`H@("`@("`@("=U:5]?
M<V5R=F5R+VEP+6%D9')E<W-E<U]?=&ET;&4G(#T^("=-86YA9V4@25`@861D
M<F5S<V5S)RP*"B`@("`@("`@)W5I7U]S97)V97(O;6%I;%]?9&5S8W)I<'1I
M;VXG(#T^("=#;VYF:6=U<F4@<V5R=F5R+7=I9&4@;6%I;"!S>7-T96TN)RP*
M("`@("`@("`G=6E?7W-E<G9E<B]M86EL7U]S:&]R="UT:71L92<@/3X@)TUA
M:6PG+`H@("`@("`@("=U:5]?<V5R=F5R+VUA:6Q?7W1I=&QE)R`]/B`G4V5R
M=F5R+7=I9&4@;6%I;"!P<F5F97)E;F-E<R<L"@H@("`@("`@("=U:5]?<V5R
M=F5R+W!R969E<F5N8V5S7U]D97-C<FEP=&EO;B<@/3X@)U-E="!U<"!S97)V
M97(@<')E9F5R96YC97,N)RP*("`@("`@("`G=6E?7W-E<G9E<B]P<F5F97)E
M;F-E<U]?9&]N92<@/3X@)U-E<G9E<B!P<F5F97)E;F-E<R!H879E(&)E96X@
M=7!D871E9"XG+`H@("`@("`@("=U:5]?<V5R=F5R+W!R969E<F5N8V5S7U]S
M:&]R="UT:71L92<@/3X@)U!R969E<F5N8V5S)RP*("`@("`@("`G=6E?7W-E
M<G9E<B]P<F5F97)E;F-E<U]?=&ET;&4G(#T^("=397)V97(@<')E9F5R96YC
M97,G+`H*("`@("`@("`G=6E?7W-E<G9E<B]S97)V:6-E<U]?9&5S8W)I<'1I
M;VXG(#T^("=3=&%R="P@<W1O<"!O<B!R97-T87)T(&-O;G1R;VP@<&%N96P@
M<V5R=FEC97,N)RP*("`@("`@("`G=6E?7W-E<G9E<B]S97)V:6-E<U]?<VAO
M<G0M=&ET;&4G(#T^("=397)V:6-E<R<L"B`@("`@("`@)W5I7U]S97)V97(O
M<V5R=FEC97-?7W1I=&QE)R`]/B`G36%N86=E('-E<G9I8V5S)RP*"B`@("`@
M("`@)W5I7U]S97)V97(O<W1A=&ES=&EC<U]?9&5S8W)I<'1I;VXG(#T^("=6
M:65W('-Y<W1E;2!S=&%T:7-T:6-S+B<L"B`@("`@("`@)W5I7U]S97)V97(O
M<W1A=&ES=&EC<U]?<VAO<G0M=&ET;&4G(#T^("=S=&%T:7-T:6-S)RP*("`@
M("`@("`G=6E?7W-E<G9E<B]S=&%T:7-T:6-S7U]T:71L92<@/3X@)U-Y<W1E
M;2!S=&%T:7-T:6-S)RP*"B`@("`@("`@)W5I7U]S=7!P;W)T7U]D97-C<FEP
M=&EO;B<@/3X@)U-U8FUI="!A(')E<75E<W0@9F]R(%!L97-K('1E8VAN:6-A
M;"!S=7!P;W)T+B<L"B`@("`@("`@)W5I7U]S=7!P;W)T7U]D;VYE)R`]/B`G
M5&5C:&YI8V%L('-U<'!O<G0@<&%G92!H87,@8F5E;B!O<&5N960N)RP*("`@
M("`@("`G=6E?7W-U<'!O<G1?7W-H;W)T+71I=&QE)R`]/B`G4W5P<&]R="<L
M"B`@("`@("`@)W5I7U]S=7!P;W)T7U]T:71L92<@/3X@)U1E8VAN:6-A;"!S
M=7!P;W)T)RP*"B`@("`@("`@+R\@*BHJ(%1H92!S=')I;F=S(&%B;W9E(&AA
M=F4@8F5E;B!G96YE<F%T960@875T;VUA=&EC86QL>2!F<F]M($!`0T%05$E/
M3B!D:7)E8W1I=F5S+@H*"2\O(&%K<W,@<&%R=`H*"2=?7U]?9&5T86EL<R<@
M/3X@)R@E,2DG+`H))U]?7U]L:7-T7V5M<'1Y)R`]/B`G)RP*"2=?7U]?;&ES
M=%]F:7)S=%]I=&5M)R`]/B`G)3$G+`H))U]?7U]L:7-T7VET96TG(#T^("<L
M("4Q)RP*"2=?7U]?;&ES=%]L87-T7VET96TG(#T^("<L("4Q)RP*"@DG7U]S
M:&]W7VAI9&5?=&ET;&4G(#T^("=-:6YI;6EZ92]297-T;W)E)RP*"2=?7U50
M3$]!1%]%4E)?1D]235]325I%)R`]/B`B57!L;V%D960@9FEL92!E>&-E961S
M('1H92!A;&QO=V5D('-I>F4@;V8@)3$B+`H))U]?55!,3T%$7T524E])3DE?
M4TE:12<@/3X@(E5P;&]A9&5D(&9I;&4@97AC965D<R!T:&4@86QL;W=E9"!S
M:7IE(BP*"2=?7U503$]!1%]%4E)?3D]?1DE,12<@/3X@(DYO(&9I;&4@<F5C
M96EV960B+`H))U]?55!,3T%$7T524E]/2R<@/3X@(D9I;&4@<W5C8V5S<V9U
M;&QY('5P;&]A9&5D(BP*"2=?7U503$]!1%]%4E)?4$%25$E!3"<@/3X@(D9I
M;&4@=V%S('!A<G1I86QL>2!U<&QO861E9"P@<&QE87-E('1R>2!A9V%I;B(L
M"@DG7U]A9&UI;E]S97)V97)?;F]T7W)E<W!O;F0G(#T^("))9B`E,2!D;V5S
M(&YO="!R97-P;VYD+"!P;&5A<V4@86-C97-S('1H92!S97)V97(@86YD(')E
M<W1A<G0@=&AE(&%D;6EN:7-T<F%T:79E('=E8B!S97)V97(@96YG:6YE(&UA
M;G5A;&QY+B(L"@DG7U]A8V-O=6YT<R<@/3X@(D%C8V]U;G1S(BP*"2=?7V%D
M9')E<W,G(#T^(")!9&1R97-S(BP*"2=?7V%D9')E<W-E<R<@/3X@(D%D9')E
M<W-E<R(L"@DG7U]A8VQ?<F5C;W)D<R<)/3X@)T%#3"!296-O<F1S)RP*"2=?
M7V%D;6EN7W)E<&]S:71O<GDG(#T^(")!9&UI;FES=')A=&]R)W,@<F5P;W-I
M=&]R>2(L"@DG7U]A;&PG(#T^(")!3$PB+`H))U]?86QL;W=?;75L=&EP;'E?
M;&]G:6XG(#T^(")!;&QO=R!M=6QT:7!L92!S97-S:6]N<R(L"@DG7U]A;&QO
M=V5D)R`]/B`B06QL;W=E9"(L"@DG7U]A;F]N9G1P7W-T871U<R<@/3X@(D%N
M;VYY;6]U<R!&5%`B+`H))U]?87!A8VAE7V5R<F1O8W,G(#T^(")#=7-T;VT@
M17)R;W(@1&]C=6UE;G1S(BP*"2=?7V%P86-H95]R97-T87)T)R`]/B`B+BXN
M)3$@=V5B+7-E<G9E<B!I<R!B96EN9R!R97-T87)T960L('!L96%S92!W86ET
M+BXN(BP*"2=?7V%S<"<@/3X@(DUI8W)O<V]F="!!4U`B+`H))U]?87-P7V1O
M=%]N970G(#T^(")-:6-R;W-O9G0@05-0+DY%5"(L"@DG7U]A<W!?9&]T7VYE
M=%]S=7!P;W)T)R`]/B`B36EC<F]S;V9T($%34"Y.150@<W5P<&]R="(L"@DG
M7U]A<W!?=6YI>%]S=7!P;W)T)R`]/B`B07!A8VAE($%34"!S=7!P;W)T(BP*
M"2=?7V%S<%]W:6Y?<W5P<&]R="<@/3X@(DUI8W)O<V]F="!!4U`@<W5P<&]R
M="(L"@DG7U]A='1A8VAM96YT<R<@/3X@(D%T=&%C:&UE;G1S(BP*"2=?7V%T
M=&%C:&UE;G1S7VQI<W0G(#T^(")!='1A8VAM96YT<R(L"@DG7U]A=71H;W(G
M(#T^("=!=71H;W(G+`H))U]?875T;W)E<W!?;F%M95]A;')E861Y7V5X:7-T
M<R<@/3X@(D%U=&]R97-P;VYD97(@=VET:"!N86UE("4Q(&%L<F5A9'D@97AI
M<W1S+B(L"@DG7U]A=71O<F5S<&]N9&5R)R`]/B`B075T;W)E<W!O;F1E<B`@
M(BP*"2=?7V%U=&]R97-P;VYD97)S)R`]/B`B075T;W)E<W!O;F1E<G,B+`H)
M)U]?875T;W)E<W!O;F1E<G-?;&ES="<@/3X@(D%U=&]R97-P;VYD97)S(BP*
M"2=?7V%U=&]R97-P;VYD97)?871T86-H;65N=%]F:6QE<R<@/3X@(D%U=&]R
M97-P;VYD97(@071T86-H;65N="!&:6QE<R(L"@DG7U]A=71O7W5P9&%T97-?
M;&ES="<@/3X@)T%V86EL86)L92!5<&1A=&5S)RP*"2=?7V%V86EL)R`]/B`B
M079A:6QA8FQE(BP*"2=?7V)I;F1?<W1A='5S)R`]/B`B1$Y3(%-E<G9E<B!S
M=&%T=7,B+`H))U]?8G5?:7-?;F]T7VEN<W1A;&QE9"<@/3X@(E1H:7,@<V5R
M=FEC92!I<R!N;W0@8W5R<F5N=&QY(&%V86EL86)L92P@8F5C875S92!T:&4@
M8F%C:W5P('5T:6QI=&EE<R!W97)E(&YO="!I;G-T86QL960N(BP*"2=?7V)U
M7VYO=%]S=7!P;W)T7VEN7VME>2<@/3X@(D)A8VMU<"!C87!A8FEL:71Y(&ES
M(&YO="!S=7!P;W)T960@8GD@=&AE(&QI8V5N<V4@:V5Y+B(L"@DG7U]B>71E
M<R<@/3X@(F)Y=&5S(BP*"2=?7V-A;E]N;W1?=7-E7W)E<V5R=F5D7W=O<F1S
M)R`]/B`B66]U(&-A;FYO="!U<V4@=&AE(')E<V5R=F5D('=O<F1S+B(L"@DG
M7U]C97)T:69I8V%T92<@/3X@(D-E<G1I9FEC871E(BP*"2=?7V-E<G1I9FEC
M871E<R<@/3X@(D-E<G1I9FEC871E<R(L"@DG7U]C97)T:69I8V%T97-?;&ES
M="<@/3X@(D-E<G1I9FEC871E<R(L"@DG7U]C9VE?<W5P<&]R="<@/3X@(D-'
M22!S=7!P;W)T(BP*"2=?7V-H86YG95]D871E)R`]/B`B36]D:69I8V%T:6]N
M(&1A=&4B+`H))U]?8VAO;W-E7VQO9V\G(#T^(")#:&]O<V4@;F5W(&QO9V\@
M9FEL92(L"@DG7U]C:71Y)R`]/B`B0VET>2(L"@DG7U]C;%]N;W1?97AI<W0G
M(#T^(")#;&EE;G0@86-C;W5N="!D;V5S(&YO="!E>&ES="XB+`H))U]?8VQI
M96YT)R`]/B`B0VQI96YT(BP*"2=?7V-L:65N=%]C87)D)R`]/B`B0VQI96YT
M(&-A<F0B+`H))U]?8VQI96YT7V-O;G1A8W1?;F%M92<@/3X@(D-L:65N="!C
M;VYT86-T(&YA;64B+`H))U]?8VQI96YT7V9O<FTG(#T^(")#;&EE;G0@9F]R
M;2(L"@DG7U]C;&EE;G1?:7!?<&]O;"<@/3X@(D-L:65N="=S($E0('!O;VPB
M+`H))U]?8VQI96YT7VQI;6ET<R<@/3X@(D-L:65N="!A8V-O=6YT(&QI;6ET
M<R(L"@DG7U]C;&EE;G1?<&5R;6ES<VEO;G,G(#T^(")#;&EE;G0@<&5R;6ES
M<VEO;G,B+`H))U]?8VQI96YT7W!R969E<F5N8V5S)R`]/B`B0VQI96YT('!R
M969E<F5N8V5S(BP*"2=?7V-L:65N=%]S=&%T=7,G(#T^(")#;&EE;G0@<W1A
M='5S(BP*"2=?7V-L:65N=%]N86UE)R`]/B`B0VQI96YT)W,@;F%M92(L"@DG
M7U]C;&EE;G1?=&]T86PG(#T^(")#;&EE;G0@5&]T86PB+`H))U]?8VQI96YT
M7W=I=&A?;&]G:6Y?;F%M95]A;')E861Y7V5X:7-T<R<@/3X@(D-L:65N="!W
M:71H(&QO9VEN(&YA;64@7"(E,5PB(&%L<F5A9'D@97AI<W1S+B(L"@DG7U]C
M;&EE;G1?9&]M=7-E<E]W:71H7VQO9VEN7V%L<F5A9'E?97AI<W1S)R`]/B`B
M3&]G:6X@;F%M92`G)3$G(&ES(&%L<F5A9'D@:6X@=7-E(&)Y('1H92!A9&UI
M;FES=')A=&]R(&]F(&1O;6%I;B`G)3$G+B(L"@DG7U]C;&EE;G1S)R`]/B`B
M0VQI96YT<R(L"@DG7U]C;&EE;G1S7V=L;V)A;%]C:&%N9V5S)R`]/B`B1W)O
M=7`@3W!E<F%T:6]N<R!O;B!#;&EE;G0@06-C;W5N=',B+`H))U]?8VQI96YT
M<U]L:7-T)R`]/B`B0VQI96YT<R(L"@DG7U]C;61?;F]T7V9O=6YD)R`]/B`B
M56YK;F]W;B!C;VUM86YD.B`E,2(L"@DG7U]C;VQD9G5S:6]N7VYO=%]S=7!P
M;W)T7VEN7VME>2<@/3X@(D-O;&1&=7-I;VX@:7,@;F]T('-U<'!O<G1E9"!B
M>2!T:&4@;&EC96YS92!K97DB+`H))U]?8V]L9&9U<VEO;E]S=&%T=7,G(#T^
M("=#;VQD1G5S:6]N('-T871U<R<L"@DG7U]C;VQD9G5S:6]N7W-U<'!O<G0G
M(#T^(")#;VQD1G5S:6]N('-U<'!O<G0B+`H))U]?8V]M;6%N9"<@/3X@)T-O
M;6UA;F0G+`H))U]?8V]M;65N=',G(#T^(")#;VUM96YT<R(L"@DG7U]C;VUP
M86YY7VYA;64G(#T^(")#;VUP86YY(&YA;64B+`H))U]?8V]M<&]N96YT7W9E
M<G-I;VXG(#T^(")#;VUP;VYE;G0@=F5R<VEO;B(L"@DG7U]A;&QO=U]Z;VYE
M7W1R86YS9F5R7VQI<W0G(#T^("=#;VUM;VX@06QL;W<@6F]N92!4<F%N<V9E
M<B!!0TPG+`H))U]?8V]M<&]N96YT7VYO=%]I;G-T86QL960G(#T^(")#;VUP
M;VYE;G0@)3$@=V%S(&YO="!I;G-T86QL960B+`H))U]?8V]N9FER;5]D96PG
M(#T^(")9;W4@;75S="!C;VYF:7)M(&1E;&5T:6]N+B(L"@DG7U]C;VYF:7)M
M7W-T;W`G(#T^(")9;W4@;75S="!C;VYF:7)M('!R;V-E<W,@<W1O<'!I;F<N
M(BP*"2=?7V-O;F9I<FU?<&%S<W=D)R`]/B`B0V]N9FER;2`E,2!087-S=V]R
M9"(L"@DG7U]C;VYF:7)M7W!A<W-W9%]S:6YG;&4G(#T^(")#;VYF:7)M(%!A
M<W-W;W)D(BP*"2=?7V-O;F9I<FU?<F5M;W9A;"<@/3X@(D-O;F9I<FT@<F5M
M;W9A;"(L"@DG7U]C;VYH96QP)R`]/B`B0V]N=&5X="!H96QP('1I<"(L"@DG
M7U]C;VYT86-T7VYA;64G(#T^(")#;VYT86-T(&YA;64B+`H))U]?8V]U;G1R
M>2<@/3X@(D-O=6YT<GDB+`H))U]?8V]U;G1R:65S)R`]/B`G0V]U;G1R>2<L
M"@DG7U]C;W5N=')Y7W5N:VYO=VXG(#T^("=5;F%B;&4@=&\@<F5C;V=N:7IE
M('1H92!C;W5N=')Y('-U8F-O9&4N)RP*"2=?7V-R96%T95]D;VUA:6XG(#T^
M("=#<F5A=&4@;F5W(&1O;6%I;B<L"@DG7U]C<GEP=&5D)R`]/B`G96YC<GEP
M=&5D)RP*"2=?7V-P7V%C8V5S<R<@/3X@(D-O;G1R;VP@<&%N96P@86-C97-S
M(BP*"2=?7V-P7W5S97(G(#T^(")#;VYT<F]L(%!A;F5L(%5S97(B+`H))U]?
M8W)E871E)R`]/B`B0W)E871E(BP*"2=?7V-R96%T95]C;&EE;G1?=&5M<&QA
M=&5?=VET:&]U=%]T96UP;&%T92<@/3X@(D-R96%T92!C;&EE;G0@=VET:&]U
M="!T96UP;&%T92(L"@DG7U]C<F5A=&5?9&]M86EN7V9O<B<@/3X@(D-R96%T
M92!N97<@9&]M86EN(&9O<B`\8CXE,3PO8CXB+`H))U]?8W)E871E7V1O;6%I
M;E]T96UP;&%T95]W:71H;W5T7W1E;7!L871E)R`]/B`B0W)E871E(&1O;6%I
M;B!W:71H;W5T('1E;7!L871E(BP*"2=?7V-R96%T:6]N7V1A=&4G(#T^(")#
M<F5A=&EO;B!D871E(BP*"2=?7V-R;VYT86)?=6YI>"<@/3X@(D-R;VYT86(B
M+`H))U]?8W)O;G1A8E]W:6XG(#T^(")38VAE9'5L97(B+`H))U]?8W1?8VUD
M)R`]/B`B0V]M;6%N9"(L"@DG7U]C=%]D;VTG(#T^(")$87D@;V8@=&AE($UO
M;G1H(BP*"2=?7V-T7V1O;5\G(#T^(")$32(L"@DG7U]C=%]D;W<G(#T^(")$
M87D@;V8@=&AE(%=E96LB+`H))U]?8W1?9&]W7R<@/3X@(D17(BP*"2=?7V-T
M7V5N86)L960G(#T^(")3=&%T=7,B+`H))U]?8W1?96YA8FQE9%\G(#T^(")3
M(BP*"2=?7V-T7VAO=7(G(#T^(")(;W5R(BP*"2=?7V-T7VAO=7)?)R`]/B`B
M2"(L"@DG7U]C=%]M:6YU=&4G(#T^(")-:6YU=&4B+`H))U]?8W1?;6EN=71E
M7R<@/3X@(DUI;B(L"@DG7U]C=%]M;VYT:"<@/3X@(DUO;G1H(BP*"2=?7V-T
M7VUO;G1H7R<@/3X@(DTB+`H))U]?8W1?;6]N=&A?96YT97)?861V)R`]/B`B
M16YT97(@=&AE('9A;'5E(BP*"2=?7V-T7VAI;G1?=6YI>%]F;W)M870G(#T^
M(")I;B!53DE8(&-R;VYT86(@9F]R;6%T(&4N9RXB+`H))U]?8W1?;6]N=&A?
M96YT97(G(#T^(")396QE8W0@=&AE(&UO;G1H(BP*"2=?7V-T7V1O=U]E;G1E
M<E]A9'8G(#T^(")%;G1E<B!T:&4@=F%L=64B+`H))U]?8W1?9&]W7V5N=&5R
M)R`]/B`B4V5L96-T('1H92!D87D@;V8@=V5E:R(L"@DG7U]C=%]M;VYT:%]J
M86XG(#T^("=*86YU87)Y)RP*"2=?7V-T7VUO;G1H7V9E8B<@/3X@)T9E8G)U
M87)Y)RP*"2=?7V-T7VUO;G1H7VUA<B<@/3X@)TUA<F-H)RP*"2=?7V-T7VUO
M;G1H7V%P<B<@/3X@)T%P<FEL)RP*"2=?7V-T7VUO;G1H7VUA>2<@/3X@)TUA
M>2<L"@DG7U]C=%]M;VYT:%]J=6XG(#T^("=*=6YE)RP*"2=?7V-T7VUO;G1H
M7VIU;"<@/3X@)TIU;'DG+`H))U]?8W1?;6]N=&A?875G)R`]/B`G075G=7-T
M)RP*"2=?7V-T7VUO;G1H7W-E<"<@/3X@)U-E<'1E;6)E<B<L"@DG7U]C=%]M
M;VYT:%]O8W0G(#T^("=/8W1O8F5R)RP*"2=?7V-T7VUO;G1H7VYO=B<@/3X@
M)TYO=F5M8F5R)RP*"2=?7V-T7VUO;G1H7V1E8R<@/3X@)T1E8V5M8F5R)RP*
M"2=?7V-T7V1O=U]S=6XG(#T^("=3=6YD87DG+`H))U]?8W1?9&]W7VUO;B<@
M/3X@)TUO;F1A>2<L"@DG7U]C=%]D;W=?='5E)R`]/B`G5'5E<V1A>2<L"@DG
M7U]C=%]D;W=?=V5D)R`]/B`G5V5D;F5S9&%Y)RP*"2=?7V-T7V1O=U]T:'4G
M(#T^("=4:'5R<V1A>2<L"@DG7U]C=%]D;W=?9G)I)R`]/B`G1G)I9&%Y)RP*
M"2=?7V-T7V1O=U]S870G(#T^("=3871U<F1A>2<L"@DG7U]C=7-T;VU?8G5T
M=&]N)R`]/B`B0W5S=&]M(&)U='1O;B(L"@DG7U]C=7-T;VU?8G5T=&]N<R<@
M/3X@(D-U<W1O;2!B=71T;VYS(BP*"2=?7V-U<W1O;5]B=71T;VYS7VQI<W0G
M(#T^(")#=7-T;VT@8G5T=&]N<R(L"@DG7U]D86EL>2<@/3X@(D1A:6QY(BP*
M"2=?7V1A;&EA<U]N;W1?97AI<W0G(#T^("=$;VUA:6X@86QI87,@9&]E<R!N
M;W0@97AI<W0N)RP*"2=?7V1A=&%B87-E7VYO=%]A8W1I=F%T960G(#T^("(E
M,2!W87,@;F]T(&%C=&EV871E9"!I;B!T:&4@<V5R=F5R(&%D;6EN:7-T<F%T
M:6]N('-E8W1I;VXN(BP*"2=?7V1A=&%B87-E7VYO=%]I;G-T86QL960G(#T^
M(")$871A8F%S92`E,2!I<R!N;W0@:6YS=&%L;&5D+B(L"@DG7U]D871A8F%S
M95]N;W1?<G5N)R`]/B`B1&%T86)A<V4@)3$@:7,@;F]T(')U;FYI;F<N(BP*
M"2=?7V1A=&%B87-E<R<@/3X@(D1A=&%B87-E<R(L"@DG7U]D871A8F%S97-?
M;&ES="<@/3X@(D1A=&%B87-E<R(L"@DG7U]D871A8F%S95]T>7!E7VYO=%]S
M=7!P;W)T961?8GE?:V5Y)R`]/B`G5&AI<R!T>7!E(&]F(&1A=&%B87-E(&ES
M(&YO="!S=7!P;W)T960@8GD@>6]U<B!L:6-E;G-E(&ME>2<L"@DG7U]D871E
M7VEM;65D:6%T96QY)R`]/B`B=&]D87DB+`H))U]?9&%T95]N979E<B<@/3X@
M(FYE=F5R(BP*"2=?7V1A>2AS*2<@/3X@(D1A>2AS*2(L"@DG7U]D87DP)R`]
M/B`B4W5N(BP*"2=?7V1A>3$G(#T^(")-;VXB+`H))U]?9&%Y,B<@/3X@(E1U
M97,B+`H))U]?9&%Y,R<@/3X@(E=E9"(L"@DG7U]D87DT)R`]/B`B5&AU<G,B
M+`H))U]?9&%Y-2<@/3X@(D9R:2(L"@DG7U]D87DV)R`]/B`B4V%T(BP*"2=?
M7V1A>7,G(#T^("(E,2!D87DH<RDB+`H))U]?1&%Y<R<@/3X@(D1A>7,B+`H)
M)U]?9&)?861M:6Y?;&]G:6Y?96UP='DG(#T^(")9;W4@:&%V92!E;G1E<F5D
M(&%N(&5M<'1Y(&QO9VEN+"!D:7-A8FQI;F<@8V]N=')O;"!O=F5R("4Q(&EN
M('1H92!I;G1E<F9A8V4N($1O('EO=2!W86YT('1O('!R;V-E960_(BP*"2=?
M7V1B7V%L<F5A9'E?97AI<W0G(#T^(")$871A8F%S92`E,2!A;')E861Y(&5X
M:7-T<RXB+`H))U]?9&)?96YG:6YE)R`]/B`B1&%T86)A<V4@16YG:6YE(BP)
M+R\@:6YD:7)E8W0*"2=?7V1B7W1Y<&4G(#T^(")$871A8F%S92!T>7!E(BP*
M"2=?7V1B7W5S97(G(#T^(")$871A8F%S92!U<V5R(BP*"2=?7V1B7W5S97)S
M)R`]/B`B1&%T86)A<V4@=7-E<G,B+`H))U]?9&)?<V5R=F5R)R`]/B`G1&%T
M86)A<V4@<V5R=F5R)RP*"2=?7V1E8W)E;65N="<@/3X@(D1E8W)E87-E("@M
M*2(L"2\O(&EN9&ER96-T"@DG7U]D969?9&]M86EN)R`]/B`B1&5F875L="!D
M;VUA:6XB+`H))U]?9&5F875L=%]F;W)?;7ES<6PG(#T^("=D969A=6QT(&9O
M<B!->5-13"<L"@DG7U]D969A=6QT7V9O<E]P;W-T9W)E<W%L)R`]/B`G9&5F
M875L="!F;W(@4&]S=&=R95-13"<L"@DG7U]D96QE=&4G(#T^(")$96QE=&4B
M+`H))U]?9&5M;R<@/3X@(E1H:7,@9G5N8W1I;VX@:7,@9&ES86)L960@:6X@
M9&5M;R!V97)S:6]N+B(L"@DG7U]D:7)E8W1O<GDG(#T^(")$:7)E8W1O<GDB
M+`H))U]?9&ES86)L95]L;V-K7W-C<F5E;B<@/3X@)U!R979E;G0@=7-E<G,@
M9G)O;2!W;W)K:6YG('=I=&@@=&AE(&-O;G1R;VP@<&%N96P@=6YT:6P@:6YT
M97)F86-E('-C<F5E;G,@87)E(&-O;7!L971E;'D@;&]A9&5D+B<L"@DG7U]D
M:7-M:7-S7VYE=W,_)R`]/B`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&-O
M;7!L971E;'D@:&ED92!T:&4@;F5W<R!B;&]C:S]<;EQN5&AE(&YE=W,@=VEL
M;"!N;W0@8F4@<VAO=VX@86YY;6]R92!U;G1I;"!T:&5R92!I<R!S;VUE(&UO
M<F4@;F5W<R!S;VUE9&%Y+B!)9B!Y;W4@=V]U;&0@<F%T:&5R(&QI:V4@=&\@
M<V5E('1H97-E(&YE=W,@86=A:6X@<V]M971I;64L('EO=2!C86X@;6EN:6UI
M>F4@=&AE(&)L;V-K(&EN<W1E860@8GD@8VQI8VMI;F<@;VX@:71S('1I=&QE
M(&)A<BXB+`H))U]?9&5F875L=%]B86-K=7!?8V]M;65N="<@/3X@(B4Q(&)A
M8VMU<"Y<;D-R96%T:6]N(&1A=&4Z("4R(BP*"2=?7V1E<V-R:7!T:6]N)R`]
M/B`B1&5S8W)I<'1I;VXB+`H))U]?9&ES86)L960G(#T^(")D:7-A8FQE9"(L
M"@DG7U]D:7-K7W-P86-E7VQI;6ET)R`]/B`B1&ES:R!S<&%C92!L:6UI="(L
M"@DG7U]D:7-K7W5S86=E7V)Y)R`]/B`B1&ES:R!S<&%C92!U<V5D(&)Y("4Q
M(BP*"2=?7V1N<R<@/3X@(D1.4R(L"@DG7U]D;G-?<F5C;W)D7V%L<F5A9'E?
M97AI<W0G(#T^(")$3E,@<F5C;W)D(&%L<F5A9'D@97AI<W1S+B(L"@DG7U]D
M;G-?;6%S=&5R7W-H;W5L9%]B95]R96UO=&4G(#T^(")9;W4@<VAO=6QD(&AA
M=F4@='=O(&1I9F9E<F5N="!A=71H;W)I=&%T:79E(&YA;64@<V5R=F5R<R!O
M;B!S97!A<F%T92!H;W-T<RXB+`H))U]?9&YS7W)E8V]R9%]N;W1?97AI<W0G
M(#T^(")$3E,@<F5C;W)D(&1O97,@;F]T(&5X:7-T+B(L"@DG7U]D;G-?<V5R
M=F5R)R`]/B`B1$Y3('-E<G9E<B(L"2\O(&EN9&ER96-T"@DG7U]D;VU?:61?
M:7-?=6YD969I;F5D)R`]/B`B1&]M86EN(&ED(&ES('5N9&5F:6YE9"XB+`H)
M)U]?9&]M7VYA;64G(#T^(")$;VUA:6X@;F%M92(L"@DG7U]D;VU?;F%M95]I
M<U]I;G9A;&ED)R`]/B`B1&]M86EN(&YA;64@:7,@:6YV86QI9"X@4&QE87-E
M(&UA:V4@<W5R92!Y;W5R(&1O;6%I;B!N86UE(&-O;7!R:7-E<R!O;FQY(&%L
M<&AA;G5M97)I8RP@9&]T(&%N9"!H>7!H96X@<WEM8F]L<RP@86YD(&ES(&YO
M="!G<F5A=&5R('1H86X@,C4U('-Y;6)O;',@:6X@;&5N9W1H+B!%86-H('!A
M<G0@;V8@=&AE(&1O;6%I;B!N86UE(&)E='=E96X@9&]T<R!S:&]U;&0@;F]T
M(&5X8V5E9"`V,R!S>6UB;VQS+B(L"@DG7U]D;VU?;F]T7V5X:7-T)R`]/B`B
M1&]M86EN(&1O97,@;F]T(&5X:7-T+B(L"@DG7U]D;VUA:6XG(#T^(")$;VUA
M:6X@)3$B+`H))U]?9&]M86EN7V9O<FTG(#T^(")$;VUA:6X@9F]R;2(L"@DG
M7U]D;VUA:6Y?:7-?='5R;F5D7V]F9E]F;W)?8F%C:W5P)R`]/B`B1&]M86EN
M("4Q(&ES('1E;7!O<F%R:6QY('1U<FYE9"!O9F8@9F]R(&)A8VMU<"]R97-T
M;W)I;F<@86YD(&ES(&YO="!C=7)R96YT;'D@879A:6QA8FQE+B(L"@DG7U]D
M;VUA:6Y?;&EM:71S)R`]/B`B1&]M86EN(&QI;6ET<R(L"@DG7U]D;VUA:6Y?
M;F%M92<@/3X@(D1O;6%I;B!N86UE(BP*"2=?7VUA:6Q?;F%M95]I;E]!4T-)
M25]F;W)M)R`]/B`B36%I;"!N86UE(&EN($%30TE)(&9O<FUA="(L"@DG7U]M
M97-S86=E7V5R<F]R)R`]/B`G17)R;W(G+`H))U]?;65S<V%G95]W87)N:6YG
M)R`]/B`G5V%R;FEN9R<L"@DG7U]M97-S86=E7VEN9F\G(#T^("=);F9O<FUA
M=&EO;B<L"@DG7U]D;VUA:6Y?;F%M95]I;E]!4T-)25]F;W)M)R`]/B`B1&]M
M86EN(&YA;64@:6X@05-#24D@9F]R;6%T(BP*"2=?7V1O;6%I;E]R97!O<VET
M;W)Y)R`]/B`B4F5P;W-I=&]R>2!O9B!D;VUA:6X@)3$B+`H))U]?9&]M86EN
M7W-T871U<R<@/3X@(D1O;6%I;B!S=&%T=7,B+`H))U]?9&]M86EN7V1N<R<@
M/3X@)T1O;6%I;B!$3E,@>F]N92<L"@DG7U]D;VUA:6Y?=&]T86PG(#T^(")$
M;VUA:6X@5&]T86PB+`H))U]?9&]M86EN7W5S97(G(#T^(")$;VUA:6X@861M
M:6YI<W1R871O<B(L"@DG7U]D;VUA:6YS)R`]/B`B1&]M86EN<R(L"@DG7U]D
M;VUA:6YS7V=L;V)A;%]C:&%N9V5S)R`]/B`B1W)O=7`@3W!E<F%T:6]N<R!O
M;B!$;VUA:6YS(BP*"2=?7VUA:6QN86UE<U]G;&]B86Q?8VAA;F=E<R<@/3X@
M(D=R;W5P($]P97)A=&EO;G,@;VX@36%I;"!.86UE<R(L"@DG7U]M:6=R871I
M;VY?;6%N86=E<B<@/3X@)TUI9W)A=&EO;B!-86YA9V5R)RP*"2=?7V)A8VMU
M<%]M86YA9V5R)R`]/B`G0F%C:W5P($UA;F%G97(G+`H))U]?9&]M86EN<U]L
M:7-T)R`]/B`B1&]M86EN<R(L"@DG7U]D;VUA:6Y?<F5S;VQV97-?=&]?86YO
M=&AE<E]I<"<@/3X@(E1H92!D;VUA:6X@<F5S;VQV97,@=&\@86YO=&AE<B!)
M4"!A9&1R97-S("@E,2DN(%!L96%S92!C;W)R96-T($1.4R!S971T:6YG<RXB
M+`H))U]?9&]U8FQE7W=W=U]W87)N:6YG)R`]/B`B5&AE(&1O;6%I;B!N86UE
M(&)E9VEN<R!W:71H('=W=RP@86QT:&]U9V@@=&AE(%=75R!P<F5F:7@@:7,@
M96YA8FQE9"Y<;E!R;V-E960@86YY=V%Y/R(L"@DG7U]D<VUA:6PG(#T^(")-
M86EL('-E<G9I8V4B+`H))U]?9'-M86EL;&ES="<@/3X@(DUA:6QI;F<@;&ES
M="!S97)V:6-E(BP*"2=?7V1S<E]D8B<@/3X@(D1"(BP*"2=?7V1S<E]D;F%M
M92<@/3X@(D1O;6%I;B!N86UE(BP*"2=?7V1S<E]D=2<@/3X@(D15(BP*"2=?
M7V1S<E]M82<@/3X@(DU!(BP*"2=?7V1S<E]M9R<@/3X@(DU'(BP*"2=?7V1S
M<E]M;"<@/3X@(DU,(BP*"2=?7V1S<E]M;B<@/3X@(DU";W@B+`H))U]?9'-R
M7VUR)R`]/B`B35(B+`H))U]?9'-R7W!N86UE)R`]/B`B0VQI96YT)W,@;F%M
M92(L"@DG7U]D<W)?<V0G(#T^(")31"(L"@DG7U]D<W)?='(G(#T^(")44B(L
M"@DG7U]D<W)?=W4G(#T^(")752(L"@DG7U]D<W1O;6-A="<@/3X@(E1O;6-A
M="!S97)V:6-E(BP*"2=?7V1U;7!?;F%M92<@/3X@(D)A8VMU<"!F:6QE(&YA
M;64B+`H))U]?9'5M<'-?=&]T7W-I>F4G(#T^(")4;W1A;"!S:7IE(&]F(&)A
M8VMU<"!F:6QE<R(L"@DG7U]E;6%I;"<@/3X@(D4M;6%I;"(L"@DG7U]E;6%I
M;%]A9&1R7VES7VEN=F%L:60G(#T^(")%+6UA:6P@861D<F5S<R!I<R!I;G9A
M;&ED+B(L"@DG7U]E;F%B;&5D)R`]/B`B96YA8FQE9"(L"@DG7U]E;G1E<E]C
M97)T7W1E>'0G(#T^(")%;G1E<B!C97)T:69I8V%T92!T97AT(BP*"2=?7V5N
M=&5R7VQO9V]?=7)L)R`]/B`B16YT97(@;F5W(%523"!F;W(@;&]G;R(L"@DG
M7U]E;G1E<E]S:7IE)R`]/B`B16YT97(@<VEZ92(L"@DG7U]E=F5N="<@/3X@
M)T5V96YT)RP*"2=?7V5V96YT7VAA;F1L97(G(#T^("=%=F5N="!H86YD;&5R
M)RP*"2=?7V5V96YT7VAA;F1L97)S)R`]/B`G179E;G0@:&%N9&QE<G,G+`H)
M)U]?97AC;'5S:79E)R`]/B`B17AC;'5S:79E(BP*"2=?7V5X<&ER871I;VY?
M9&%T92<@/3X@(D5X<&ER871I;VX@9&%T92(L"@DG7U]F87@G(#T^(")&87@B
M+`H))U]?9FEL92<@/3X@(D9I;&4B+`H))U]?9FEL95]I<U]E;7!T>2<@/3X@
M(D9I;&4@:7,@96UP='DN(BP*"2=?7V9I;&5?;F%M92<@/3X@(D9I;&4@;F%M
M92(L"@DG7U]F:6QE7W1Y<&4G(#T^("=&:6QE('1Y<&4G+`H))U]?9FEL96UA
M;F%G97(G(#T^(")&:6QE($UA;F%G97(B+`H))U]?9FEL97!A=&A?:7-?96UP
M='DG(#T^(")0871H('1O(&9I;&4@:7,@96UP='DB+`H))U]?9FEL97-?;&ES
M="<@/3X@(D9I;&5S(BP*"2=?7V9P7W-S;%]U;FEX7W-U<'!O<G0G(#T^(")&
M<F]N=%!A9V4@;W9E<B!34TP@<W5P<&]R="(L"@DG7U]F<%]S<VQ?=VEN7W-U
M<'!O<G0G(#T^(")-:6-R;W-O9G0@1G)O;G1086=E(&]V97(@4U-,('-U<'!O
M<G0B+`H))U]?9G!?=6YI>%]A=71H)R`]/B`B1G)O;G1086=E(&%U=&AO<FEN
M9R(L"@DG7U]F<%]U;FEX7W-U<'!O<G0G(#T^(")&<F]N=%!A9V4@<W5P<&]R
M="(L"@DG7U]F<%]W:6Y?875T:"<@/3X@(DUI8W)O<V]F="!&<F]N=%!A9V4@
M875T:&]R:6YG(BP*"2=?7V9P7W=I;E]S=7!P;W)T)R`]/B`B36EC<F]S;V9T
M($9R;VYT4&%G92!S=7!P;W)T(BP*"2=?7V9R;VYT<&%G92<@/3X@(DUI8W)O
M<V]F="!&<F]N=%!A9V4B+`H))U]?9G1P)R`]/B`B1E10(BP)+R\@*VEN9&ER
M96-T"@DG7U]F='!?<V5T=&EN9W,G(#T^(")&5%`@<V5T=&EN9W,B+`H))U]?
M9G1P7W-E<G8G(#T^(")&5%`@<V5R=F5R(BP)+R\@:6YD:7)E8W0*"2=?7V9T
M<%]S97)V97)?<&%R86UE=&5R<U]A<F5?96UP='DG(#T^(")9;W4@<VAO=6QD
M('-E="!T:&4@1E10(&%C8V]U;G0@<')O<&5R=&EE<R!F:7)S="$B+`H))U]?
M9G1P7W-T871U<R<@/3X@(D944"!S97)V97(@<W1A='5S(BP*"2=?7V9U;&Q?
M9&%Y,"<@/3X@(E-U;F1A>2(L"@DG7U]F=6QL7V1A>3$G(#T^(")-;VYD87DB
M+`H))U]?9G5L;%]D87DR)R`]/B`B5'5E<V1A>2(L"@DG7U]F=6QL7V1A>3,G
M(#T^(")7961N97-D87DB+`H))U]?9G5L;%]D87DT)R`]/B`B5&AU<G-D87DB
M+`H))U]?9G5L;%]D87DU)R`]/B`B1G)I9&%Y(BP*"2=?7V9U;&Q?9&%Y-B<@
M/3X@(E-A='5R9&%Y(BP*"2=?7V9U;&Q?;6]N=&@Q)R`]/B`B2F%N=6%R>2(L
M"@DG7U]F=6QL7VUO;G1H,3`G(#T^(")/8W1O8F5R(BP*"2=?7V9U;&Q?;6]N
M=&@Q,2<@/3X@(DYO=F5M8F5R(BP*"2=?7V9U;&Q?;6]N=&@Q,B<@/3X@(D1E
M8V5M8F5R(BP*"2=?7V9U;&Q?;6]N=&@R)R`]/B`B1F5B<G5A<GDB+`H))U]?
M9G5L;%]M;VYT:#,G(#T^(")-87)C:"(L"@DG7U]F=6QL7VUO;G1H-"<@/3X@
M(D%P<FEL(BP*"2=?7V9U;&Q?;6]N=&@U)R`]/B`B36%Y(BP*"2=?7V9U;&Q?
M;6]N=&@V)R`]/B`B2G5N92(L"@DG7U]F=6QL7VUO;G1H-R<@/3X@(DIU;'DB
M+`H))U]?9G5L;%]M;VYT:#@G(#T^(")!=6=U<W0B+`H))U]?9G5L;%]M;VYT
M:#DG(#T^(")397!T96UB97(B+`H))U]?9V5N97)A;"<@/3X@(D=E;F5R86PB
M+`H))U]?9VEG82<@/3X@(D<B+`H))U]?9W)O=7`G(#T^(")'<F]U<"(L"@DG
M7U]H)R`]/B`B2"(L"@DG7U]H87)D7V1I<VM?<75O=&$G(#T^(")(87)D(&1I
M<VL@<75O=&$B+`H))U]?:&%R9%]D:7-K7W%U;W1A7VYO=%]S=7!P;W)T960G
M(#T^(")H87)D(&1I<VL@<75O=&$@:7,@;F]T('-U<'!O<G1E9"(L"@DG7U]H
M96%D97)?=&5X=%]I<U]I;G9A;&ED)R`]/B`B2&5A9&5R('1E>'0@:7,@:6YV
M86QI9"XB+`H))U]?:&5L<"<@/3X@(DAE;'`B+`H))U]?:&5L<%]T;W!I8U]N
M;W1?9F]U;F0G(#T^("=4:&4@:&5L<"!T;W!I8R!Y;W4@<F5Q=65S=&5D("@E
M,2D@9&]E<R!N;W0@97AI<W0N)RP*"2=?7VAO;64G(#T^(")(;VUE(BP*"2=?
M7VAO<W1I;F<G(#T^(")(;W-T:6YG(BP*"2=?7VAO<W1I;F=?:7!?9&YS7VEP
M7VYO=%]E<75I=B<@/3X@(DYO;F4@;V8@25`@861D<F5S<V5S('-P96-I9FEE
M9"!I;B!!($1.4R!R96-O<F1S(&UA=&-H('1H92!)4"!A9&1R97-S('5S960@
M9F]R(&AO<W1I;F<B+`H))U]?:&]S=&EN9U]S8W)I<'1I;F<G(#T^(")(;W-T
M:6YG('-C<FEP=&EN9R!S=7!P;W)T(BP*"2=?7VAO<W1I;F=?<V5T=7!?<&%G
M95]T:71L92<@/3X@(E!H>7-I8V%L(&AO<W1I;F<@<V5T=7`@<&%G92!F;W(@
M9&]M86EN("4Q(BP*"2=?7VAO<W1I;F=?=&ET;&4G(#T^(")(;W-T:6YG("@E
M,2DB+`H))U]?:&]S=&EN9U]T>7!E)R`]/B`B2&]S=&EN9R!T>7!E(BP*"2=?
M7VAO<W1N86UE)R`]/B`B2&]S=&YA;64B+`H))U]?:&]S=&YA;65?:7-?96UP
M='DG(#T^(")(;W-T;F%M92!I<R!E;7!T>2XB+`H))U]?2&]U<G,G(#T^("=(
M;W5R<R<L"@DG7U]H<W1?='EP95]I;F-O<G)E8W0G(#T^(")(;W-T:6YG('1Y
M<&4@:7,@:6YC;W)R96-T+B(L"@DG7U]H='1P)R`]/B`B2%144"(L"2\O:6YD
M:7)E8W0*"2=?7VAT>7!E)R`]/B`B2"(L"@DG7U]I9&QE7W1I;64G(#T^("))
M9&QE('1I;64B+`H))U]?:69A8V4G(#T^("));G1E<F9A8V4B+`H))U]?:6UA
M9V4G(#T^("));6%G92(L"@DG7U]I;6%P7W-T871U<R<@/3X@(DE-05`@4V5R
M=F5R('-T871U<R(L"@DG7U]I;B<@/3X@(DEN(BP*"2=?7VEN7R4G(#T^(")I
M;B`E(BP*"2=?7VEN8V]R<F5C=%]D871A8F%S97-?;&]G:6Y?<&%S<R<@/3X@
M(EEO=2!S<&5C:69I960@:6YC;W)R96-T(&-R961E;G1I86QS(&9O<B!A8V-E
M<W,@=&\@4&]S=&=R95-13"XB+`H))U]?:6YC;W)R96-T7VEP7V]R7VYE='=O
M<FM?861D<F5S<R<@/3X@)TEN8V]R<F5C="!)4"!A9&1R97-S(&]R(&YE='=O
M<FLN)RP*"2=?7VEN8W)E;65N="<@/3X@(DEN8W)E87-E("@K*2(L"2\O(&EN
M9&ER96-T"@DG7U]I;F9O)R`]/B`G26YF;R<L"@DG7U]I;G-T86QL)R`]/B`B
M26YS=&%L;"(L"@DG7U]I;G-T86QL7W!R969I>"<@/3X@(DEN<W1A;&P@<')E
M9FEX(BP*"2=?7VEN=&5R9F%C95]S:VEN)R`]/B`B26YT97)F86-E('-K:6XB
M+`H))U]?:6YV86QI9%]C97)T7VED)R`]/B`B26YV86QI9"!C97)T:69I8V%T
M92!I9"(L"@DG7U]I;G9A;&ED7V-O;G1E>'0G(#T^("));G9A;&ED(&-O;G1E
M>'0Z("4Q(BP*"2=?7VEN=F%L:61?9&)?=7-R7VYA;64G(#T^(")$871A8F%S
M92!U<V5R(&YA;64@:7,@:6YV86QI9"XB+`H))U]?:6YV86QI9%]D:7)?;F%M
M92<@/3X@(D1I<F5C=&]R>2!N86UE(&ES(&EN=F%L:60B+`H))U]?:6YV86QI
M9%]D;VU?;F%M92<@/3X@(D1O;6%I;B!N86UE(&ES(&EN=F%L:60N(BP*"2=?
M7VEN=F%L:61?9FEL96YA;64G(#T^("));G9A;&ED(&9I;&5N86UE+B!$;R!N
M;W0@=7-E('-I;F=L92!Q=6]T97,@86YD+V]R(%PB+BXO7"(@8V]M8FEN871I
M;VXN(BP*"2=?7VEN=F%L:61?:60G(#T^("));G9A;&ED(&ED96YT:69I97(N
M(BP*"2=?7VEN=F%L:61?;6%X7V)U='1O;E]L96XG(#T^("));F%P<')O<')I
M871E('9A;'5E(&9O<B!N=6UB97(@;V8@8VAA<F%C=&5R<RX@66]U('-H;W5L
M9"!U<V4@;VYL>2!D:6=I=',N(BP*"2=?7VEN=F%L:61?;6%X7VQE='1E<E]S
M:7IE)R`]/B`B36%X:6UU;2!L971T97(@<VEZ92!I<R!I;G9A;&ED+B(L"@DG
M7U]I;G9A;&ED7W!D:7)?;F%M92<@/3X@(E!R;W1E8W1E9"!D:7)E8W1O<GD@
M;F%M92!I<R!I;G9A;&ED+B(L"@DG7U]I;G9A;&ED7W)E<W1A<G1?87!A8VAE
M7VEN=&5R=F%L)R`]/B`B07!A8VAE(')E<W1A<G0@:6YT97)V86P@:7,@:6YV
M86QI9"(L"@DG7U]I;G9A;&ED7W1M<&Q?;F%M92<@/3X@(E1E;7!L871E(&YA
M;64@:7,@:6YV86QI9"XB+`H))U]?:6YV86QI9%]V86QU92<@/3X@(DEM<')O
M<&5R('9A;'5E+B(L"@DG7U]I<%]A9&1R)R`]/B`B25`@061D<F5S<R(L"@DG
M7U]I<%]A9&1R97-S7V%N9%]M87-K)R`]/B`B25`@061D<F5S<R!A;F0@4W5B
M;F5T($UA<VLB+`H))U]?:7!?;6%S:R<@/3X@(E-U8FYE="!-87-K(BP*"2=?
M7VEP7V%L:6%S7U]M87-K)R`]/B`B25`@061D<F5S<R!A;F0@4W5B;F5T($UA
M<VLB+`H))VEP7V%L:6%S7U]M87-K)R`]/B`B25`@061D<F5S<R!A;F0@4W5B
M;F5T($UA<VLB+`H))U]?:7!?861D<E]F;W)M)R`]/B`B25`@061D<F5S<R!F
M;W)M(BP*"2=?7VEP7V%D9')?:7-?:6YV86QI9"<@/3X@(DE0(&%D9')E<W,@
M:7,@:6YV86QI9"XB+`H))U]?:7!?861D<E]L:7-T)R`]/B`B25`@061D<F5S
M<V5S(BP*"2=?7VEP7V%D9')E<W-?9&]E<U]N;W1?97AI<W0G(#T^("))4"!A
M9&1R97-S(&1O97,@;F]T(&5X:7-T+B(L"@DG7U]I<%]A9&1R97-S97,G(#T^
M("))4"!!9&1R97-S97,B+`H))U]?:7!?861D<F5S<U]A;F1?;6%S:U]H:6YT
M)R`]/B`G12YG+B`E,2<L"@DG7U]I<U]O=VYE<B<@/3X@(D\B+`H))U]?:F%V
M85]E;F=I;F4G(#T^(")*879A(BP)+R\@:6YD:7)E8W0*"2=?7VID:R<@/3X@
M(DI$2R(L"@DG7U]K8B<@/3X@(DM"(BP*"2=?7VMB<',G(#T^(")+0B]S(BP*
M"2=?7VMB>71E<R<@/3X@(FMI;&]B>71E<R(L"@DG7U]K97E?;&EM:71S7V5X
M8V5E9&EN9R<@/3X@(E1H:7,@86-T:6]N(&5X8V5E9',@=&AE(&QI;6ET<R!D
M969I;F5D(&)Y('EO=7(@<V]F='=A<F4@;&EC96YS92X@268@>6]U(')E8V5I
M=F5D('1H:7,@;65S<V%G92!Y;W4@;6%Y(&-O;G1A8W0@>6]U<B!P<F]V:61E
M<B!O<B!T:&4@;6%N=69A8W1U<F5R('1O(&-L87)I9GD@;W(@97AT96YD('1H
M92!L:6UI=',@;V8@=&AI<R!L:6-E;G-E+B(L"@DG7U]K:6QO)R`]/B`B2R(L
M"@DG7U]K97EW;W)D<R<@/3X@)TME>7=O<F1S)RP*"2=?7VQA;F=?=6YK;F]W
M;B<@/3X@)U5N86)L92!T;R!R96-O9VYI>F4@=&AE(&QA;F=U86=E+B<L"@DG
M7U]L86YG=6%G97,G(#T^("=,86YG=6%G92<L"@DG7U]L96%R;E]M;W)E)R`]
M/B`G3&5A<FX@;6]R92<L"@DG7U]L;V-A;&5S)R`]/B`B3&%N9W5A9V4@<&%C
M:W,B+`H))U]?;&EM:70G(#T^("),:6UI="(L"@DG7U]L:6UI=',G(#T^("),
M:6UI=',B+`H))U]?;&EN:U]U<FQ?:7-?:6YV86QI9"<@/3X@(DQO9V\@55),
M(&ES(&EN=F%L:60N(BP*"2=?7VQI<W1S)R`]/B`B36%I;&EN9R!L:7-T<R(L
M"@DG7U]L:71E<F%L7V)Y=&5S)R`]/B`B0B(L"@DG7U]P<F]C97-S:6YG)R`]
M/B`B4&QE87-E('=A:70N/&)R/DQO861I;F<@+BXN(BP*"2=?7VQO8V%L92<@
M/3X@(DEN=&5R9F%C92!L86YG=6%G92(L"@DG7U]L;V-A;&5?:7-?;F]T7V1E
M9FEN960G(#T^("));G1E<F9A8V4@;&%N9W5A9V4@:7,@;F]T(&1E9FEN960N
M(BP*"2=?7VQO8V%L7W-E<G9E<E]M>7-Q;"<@/3X@)TQO8V%L($UY4U%,('-E
M<G9E<B<L"@DG7U]L;V-A;%]S97)V97)?<&]S=&=R97-Q;"<@/3X@)TQO8V%L
M(%!O<W1G<F5344P@<V5R=F5R)RP*"2=?7VQO9U]F:6QE<R<@/3X@(DQO9R!F
M:6QE<R(L"@DG7U]C;VYF:6=?9FEL97,G(#T^("=#;VYF:6<@9FEL97,G+`H)
M)U]?8VAR;V]T7V9I;&5S)R`]/B`G0VAR;V]T960@96YV:7)O;FUE;G0G+`H)
M)U]?;&]G:6XG(#T^("(E,2!,;V=I;B(L"@DG7U]L;V=I;C$G(#T^("),;V=I
M;B(L"@DG7U]L;V=I;E]D:7-A8FQE9"<@/3X@(DQO9VEN(&1I<V%B;&5D(BP*
M"2=?7VQO9VEN7V5N86)L960G(#T^("),;V=I;B!E;F%B;&5D(BP*"2=?7VQO
M9VEN7VEN8V]R<F5C="<@/3X@(DQO9VEN(&ES(&EN8V]R<F5C="XB+`H))U]?
M;&]G:6Y?;F%M92<@/3X@(B4Q(&QO9VEN(&YA;64B+`H))U]?;&]G:6Y?;F%M
M95]I<U]I;G9A;&ED)R`]/B`B)3$@;&]G:6X@;F%M92!I<R!I;G9A;&ED+B(L
M"@DG7U]L;V=O;E]T:6UE)R`]/B`B3&]G;VX@=&EM92(L"@DG7U]L;V=O=70G
M(#T^("),;V<@;W5T(BP*"2=?7VUA)R`]/B`B36%I;"!A;&EA<V5S(BP*"2=?
M7VUA:6PG(#T^(")-86EL(BP*"2=?7VUA:6Q?86QI87-?;F%M92<@/3X@(DUA
M:6P@86QI87,@;F%M92(L"@DG7U]M86EL7V5X8VAA;F=E<E]N86UE7VES7VEN
M=F%L:60G(#T^(")-86EL(&5X8VAA;F=E<B!N86UE(&ES(&EN=F%L:60N(BP*
M"2=?7VUA:6Q?9W)O=7!S)R`]/B`B36%I;"!G<F]U<',B+`H))U]?;6%I;%]L
M:7-T7V5N9VEN92<@/3X@(DUA:6QI;F<@;&ES="!S;V9T=V%R92(L"@DG7U]M
M86EL7VYA;64G(#T^(")-86EL(&YA;64B+`H))U]?;6%I;%]N86UE7V9O<FTG
M(#T^(")-86EL(&YA;64@9F]R;2(L"@DG7U]M86EL7VYA;65S)R`]/B`B36%I
M;"!N86UE<R(L"@DG7U]M86EL7VYA;65S7VQI<W0G(#T^(")-86EL(&YA;65S
M(BP*"2=?7VUA:6Q?<V5R=B<@/3X@(DUA:6P@<V5R=F5R(BP*"2=?7VUA:6Q?
M=7-E<B<@/3X@)TUA:6P@=7-E<B<L"@DG7U]M86EL9W)O=7`G(#T^(")-86EL
M(&=R;W5P(BP*"2=?7VUA:6QL:7-T)R`]/B`B36%I;&EN9R!L:7-T(BP*"2=?
M7VUA:6QL:7-T<R<@/3X@(DUA:6QI;F<@;&ES=',B+`H))U]?;6%I;&QI<W1?
M;65M8F5R<R<@/3X@)TUA:6QI;F<@;&ES="!M96UB97)S)RP*"2=?7VUA:6QL
M:7-T7VUE;6)E<B<@/3X@)TUA:6QI;F<@;&ES="!M96UB97(G+`H))U]?;6%I
M;&YA;64G(#T^(")-86EL(&YA;64B+`H))U]?;6%I;&YA;65?<F5D:7)?<V5L
M9B<@/3X@(DUA:6P@;F%M92!C86YN;W0@8F4@<F5D:7)E8W1E9"!T;R!I='-E
M;&8N(BP*"2=?7VUA<W1E<B<@/3X@(DUA<W1E<B(L"@DG7U]M87A?9&]M7VYU
M;5]R96%C:&5D7V9O<E]C;"<@/3X@(E1H92!L:6UI="!O;B!N=6UB97(@;V8@
M9&]M86EN<R!H87,@8F5E;B!R96%C:&5D(&9O<B!T:&ES(&-L:65N="!A8V-O
M=6YT+B(L"@DG7U]M87A?9FEL95]S:7IE7V%V86EL86)L92<@/3X@(DUA>&EM
M=6T@9FEL97-I>F4@86QL;W=E9"`E,2(L"@DG7U]M87A?<W5B9&]M7VYU;5]R
M96%C:&5D7V9O<E]C;"<@/3X@(E1H92!L:6UI="!O;B!N=6UB97(@;V8@<W5B
M9&]M86EN<R!H87,@8F5E;B!R96%C:&5D(&9O<B!T:&ES(&-L:65N="!A8V-O
M=6YT+B(L"@DG7U]M87A?<W5B9&]M7VYU;5]R96%C:&5D7V9O<E]D;VTG(#T^
M(")4:&4@;&EM:70@;VX@;G5M8F5R(&]F('-U8F1O;6%I;G,@:&%S(&)E96X@
M<F5A8VAE9"!F;W(@=&AE(&1O;6%I;BXB+`H))U]?;6%X7W-U8F1O;5]N=6U?
M<F5A8VAE9%]F;W)?:V5Y)R`]/B`B5&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!S
M=6)D;VUA:6YS(&%L;&]W960@8GD@=&AE(&QI8V5N<V4@:V5Y(&AA<R!B965N
M(')E86-H960N(BP*"2=?7VUA>%]T<F%F9FEC7VQI;6ET)R`]/B`B5')A9F9I
M8R!L:6UI="(L"@DG7U]M87AI;75M7V5X8VQ?:7!?;G5M)R`]/B`B36%I;"!N
M86UE<R(L"@DG7U]M8B<@/3X@(DU"(BP*"2=?7VUB>71E<R<@/3X@(FUE9V%B
M>71E<R(L"@DG7U]M8E]M;VYT:"<@/3X@(DU"+VUO;G1H(BP*"2=?7VUE9V$G
M(#T^(")-(BP*"2=?7TUI;G5T97,G(#T^("=-:6YU=&5S)RP*"2=?7VUL<U]N
M;W1?:6Y?:V5Y)R`]/B`B66]U<B!P<F]D=6-T(&ME>2!D;V5S(&YO="!S=7!P
M;W)T(&UU;'1I;&EN9W5A;"!I;G1E<F9A8V4N(BP*"2=?7VUO9&EF:6-A=&EO
M;E]D871E)R`]/B`B36]D:69I8V%T:6]N(&1A=&4B+`H))U]?;6]D=6QE)R`]
M/B`B36]D=6QE(BP*"2=?7VUO9'5L97,G(#T^(")-;V1U;&5S(BP*"2=?7VUO
M;G1H)R`]/B`B36]N=&@B+`H))U]?;6]N=&@H<RDG(#T^(")-;VYT:"AS*2(L
M"@DG7U]M;VYT:#$G(#T^(")*86XB+`H))U]?;6]N=&@Q,"<@/3X@(D]C="(L
M"@DG7U]M;VYT:#$Q)R`]/B`B3F]V(BP*"2=?7VUO;G1H,3(G(#T^(")$96,B
M+`H))U]?;6]N=&@R)R`]/B`B1F5B(BP*"2=?7VUO;G1H,R<@/3X@(DUA<B(L
M"@DG7U]M;VYT:#0G(#T^(")!<')I;"(L"@DG7U]M;VYT:#4G(#T^(")-87DB
M+`H))U]?;6]N=&@V)R`]/B`B2G5N92(L"@DG7U]M;VYT:#<G(#T^(")*=6QY
M(BP*"2=?7VUO;G1H."<@/3X@(D%U9R(L"@DG7U]M;VYT:#DG(#T^(")397!T
M(BP*"2=?7VUO;G1H;'DG(#T^(")-;VYT:&QY(BP*"2=?7VUO;G1H<R<@/3X@
M(DUO;G1H<R(L"@DG7U]M;W9E9%]P97)M86YE;G1L>2<@/3X@)TUO=F5D(%!E
M<FUA;F5N=&QY)RP*"2=?7VUS<W%L)R`]/B`B36EC<F]S;V9T(%-13"!S97)V
M97(B+`H))U]?;7-S<6Q?<W1A='5S)R`]/B`B36EC<F]S;V9T(%-13"!S97)V
M97(@<W1A='5S(BP*"2=?7VUU;'1I<&QY7VQO9VEN7V1E;GDG(#T^(")5;F%B
M;&4@=&\@;&]G('EO=2!O;BX@06YO=&AE<B!U<V5R('=I=&@@=&AE('-A;64@
M;&]G:6X@;F%M92`H)3$I(&ES(&%L<F5A9'D@;&]G9V5D(&EN('1O('1H92!C
M;VYT<F]L('!A;F5L+B(L"@DG7U]M>7-Q;"<@/3X@(DUY4U%,(BP*"2=?7VUY
M<W%L7W-T871U<R<@/3X@(E-13"!S97)V97(@<W1A='5S(BP*"2=?7VUY<W%L
M7W9E<G-I;VXG(#T^(")->7-Q;"!V97)S:6]N(BP*"2=?7VYA;64G(#T^(").
M86UE(BP*"2=?7VYA;65?:6YV86QI9"<@/3X@(DYA;64@:7,@:6YV86QI9"XB
M+`H))U]?;F%M97-E<G9E<B<@/3X@(FYA;65S97)V97(B+`H))U]?;F5T=V]R
M:R<@/3X@(DYE='=O<FLB+`H))U]?;F5T=V]R:W,G(#T^(").971W;W)K<R(L
M"@DG7U]N971W;W)K<U]L:7-T)R`]/B`B3F5T=V]R:W,B+`H))U]?;F5W7W!A
M<W-W9"<@/3X@(DYE=R`E,2!P87-S=V]R9"(L"@DG7U]N97=?<&%S<W=D7W-I
M;F=L92<@/3X@(DYE=R!P87-S=V]R9"(L"@DG7U]N;R<@/3X@(DYO(BP*"2=?
M7VYO7VEP7V%D9')E<W-?=VET:%]P<F]P97)L>5]T>7!E7V%V86EL86)L92<@
M/3X@(E5N86)L92!T;R!R97-T;W)E('1H92!B86-K960@=7`@9&%T82!B96-A
M=7-E('1H97)E(&%R92!N;R!S=6ET86)L92!)4"!A9&1R97-S97,@<F5Q=6ER
M960@9F]R(')E<W1O<FEN9RXB+`H))U]?;F]?8VQI96YT<U]S<&5C:69I960G
M(#T^(").;R!C;&EE;G0@86-C;W5N=',@<W!E8VEF:65D+B(L"@DG7U]N;U]C
M;VUM96YT<R<@/3X@(DYO(&-O;6UE;G1S+B(L"@DG7U]N;U]I<%]S<&5C:69I
M960G(#T^(").;R!I<"!S<&5C:69I960N(BP*"2=?7VYO7W-I=&5?87!P<U]S
M<&5C:69I960G(#T^(").;R!S:71E(&%P<&QI8V%T:6]N<R!S96QE8W1E9"XB
M+`H))U]?;F]C:&%N9V4G(#T^(")$;R!N;W0@8VAA;F=E(BP*"2=?7VYO;&]G
M:6XG(#T^(")&;W)B:61D96XB+`H))U]?;F]N92<@/3X@(DYO;F4B+`H))U]?
M;F]T7V-O;F9I9W5R960G(#T^(").;W0@8V]N9FEG=7)E9"(L"@DG7U]N;W1?
M<W5P<&]R=&5D7V)Y7V9T<"<@/3X@(BAN;W0@<W5P<&]R=&5D(&)Y($944"!S
M97)V97(I(BP*"2=?7VYO=%]S=7!P;W)T961?8GE?;6%I;&UN9R<@/3X@(FYO
M="!S=7!P;W)T960@8GD@=&AE(&UA:6P@<V5R=F5R(BP*"2=?7VYO=&EF:6-A
M=&EO;B<@/3X@(DYO=&EF:6-A=&EO;B(L"@DG7U]N;W1I9FEC871I;VYS)R`]
M/B`B3F]T:69I8V%T:6]N<R(L"@DG7U]N=6U?9&ES<&QA>65D)R`]/B`B)3$@
M;V8@)3(@9&ES<&QA>65D(BP*"2=?7VYU;5]I<U]I;G9A;&ED)R`]/B`B3G5M
M8F5R(&ES(&EN=F%L:60N(BP*"2=?7V]B:F5C=%]N;W1?9F]U;F0G(#T^("=/
M8FIE8W0@;F]T(&9O=6YD.B`E,2<L"@DG7U]O9E]A;&PG(#T^("(E(&]F($%L
M;"(L"@DG7U]O9F8G(#T^(")/9F8B+`H))U]?;VLG(#T^(")/2R(L"@DG7U]O
M;&1?<&%S<W=D)R`]/B`B3VQD("4Q('!A<W-W;W)D(BP*"2=?7V]L9%]P87-S
M=V1?<VEN9VQE)R`]/B`B3VQD('!A<W-W;W)D(BP*"2=?7V]N)R`]/B`B3VXB
M+`H))U]?;W1H97)S)R`]/B`B3W1H97)S(BP*"2=?7V]T:&5R7VEP7U]W:6QL
M7V)E7V%D9&5D)R`]/B`G3W1H97(@879A:6QA8FQE($E0(&%D9')E<W-E<R`H
M=VEL;"!B92!A9&1E9"!T;R!T:&4@8VQI96YT7"=S($E0('!O;VPI)RP*"2=?
M7V]U="<@/3X@(D]U="(L"@DG7U]O=VYE<B<@/3X@(D]W;F5R(BP*"2=?7W`G
M(#T^(")0(BP*"2=?7W!A<W-W9"<@/3X@(B4Q(%!A<W-W;W)D(BP*"2=?7W!A
M<W-W9%]S:6YG;&4G(#T^(")087-S=V]R9"(L"@DG7U]P87-S=V1?:&EN="<@
M/3X@(D%T(&QE87-T(#4@8VAA<F%C=&5R<RP@;F\@;F%T:6]N86P@8VAA<F%C
M=&5R<R(L"@DG7U]P87-S=V1?:7-?:6YV86QI9"<@/3X@(B4Q(%!A<W-W;W)D
M(&ES(&EN=F%L:60N(BP*"2=?7W!A<W-W9%]N;W1?;6%T8V@G(#T^(")087-S
M=V]R9',@9&\@;F]T(&UA=&-H(2(L"@DG7U]P871H)R`]/B`B4&%T:"(L"@DG
M7U]P97)L7W5N:7A?<W5P<&]R="<@/3X@(FUO9%]P97)L('-U<'!O<G0B+`H)
M)U]?<&5R;%]W:6Y?<W5P<&]R="<@/3X@(E!E<FP@<W5P<&]R="(L"@DG7U]P
M97)M7V1E;FEE9"<@/3X@(E!E<FUI<W-I;VX@9&5N:65D+B(L"@DG7U]P97)M
M:7-S:6]N<R<@/3X@(E!E<FUI<W-I;VYS(BP*"2=?7W!E<G-O;F%L7VYA;64G
M(#T^(")097)S;VYA;"!N86UE(BP*"2=?7W!G7V%D;6EN7VYO=%]A8W1I=F%T
M960G(#T^(")0;W-T9W)E4U%,('=A<R!N;W0@86-T:79A=&5D(&EN('1H92!S
M97)V97(@861M:6YI<W1R871I;VX@<V5C=&EO;BXB+`H))U]?<&=?;F]T7VEN
M<W0G(#T^(")0;W-T9W)E4U%,('=A<R!N;W0@:6YS=&%L;&5D+B(L"@DG7U]P
M9U]N;W1?<G5N7V]R7VEN<W0G(#T^(")0;W-T9W)E4U%,('=A<R!N;W0@:6YS
M=&%L;&5D(&]R(&ES(&YO="!R=6YN:6YG+B(L"@DG7U]P:&]N92<@/3X@(E!H
M;VYE(BP*"2=?7W!H;W-T:6YG)R`]/B`B4&AY<VEC86P@:&]S=&EN9R(L"@DG
M7U]P:'!?<W5P<&]R="<@/3X@(E!(4"!S=7!P;W)T(BP*"2=?7W!H<%]S869E
M7VUO9&4G(#T^(")02%`@)W-A9F5?;6]D92<@;VXB+`H))U]?<&AP7W9E<G-I
M;VXG(#T^(")02%`@=F5R<VEO;B(L"@DG7U]P:'ES:6-A;"<@/3X@(E!H>7-I
M8V%L(&AO<W1I;F<B+`H))U]?<&QE<VM?<W1A=%]P9&ER)R`]/B`B4')O=&5C
M="!D:7)E8W1O<GD@)R]P;&5S:RUS=&%T+R<B+`H))U]?<&QE<VM?<W1A=%]D
M:7)?;F%M92<@/3X@(D1O;6%I;B!S=&%T:7-T:6-S(BP*"2=?7W!L97-K7W-T
M871?<')O=&5C="<@/3X@(F%C8V5S<VEB;&4@=FEA('!A<W-W;W)D('!R;W1E
M8W1E9"!D:7)E8W1O<GD@)R]P;&5S:RUS=&%T+R<B+`H))U]?<&QE<VM?<W1A
M=%]P<F]T96-T7VEN<W1A;&PG(#T^(")A8V-E<W-I8FQE('9I82!P87-S=V]R
M9"!P<F]T96-T960@9&ER96-T;W)Y("<O<&QE<VLM<W1A="\G(BP*"2=?7W!L
M97-K7W-T871?=V5B<W1A=%]N;W1?86-T:79A=&4G(#T^(")796(@<W1A=&ES
M=&EC<R!A<F4@;F]T(&5N86)L960N(BP*"2=?7W!O<#-?:6UA<"<@/3X@(E!/
M4#,O24U!4"(L"2\O(&EN9&ER96-T"@DG7U]P;W`S7W-T871U<R<@/3X@(E!/
M4#,@<V5R=F5R('-T871U<R(L"@DG7U]P;W!E;E]E<G)O<B<@/3X@(D%N(&5R
M<F]R(&]C8W5R<F5D('=H:6QE(&-A;&QI;F<@=&AE('!O<&5N(&9U;F-T:6]N
M+B(L"@DG7U]P;W)T)R`]/B`G4&]R="<L"@DG7U]P;W-T9W)E<R<@/3X@(E!O
M<W1G<F5344PB+`H))U]?<&]S=&=R97-Q;"<@/3X@(E!O<W1G<F5344PB+`H)
M)U]?<&]S=&=R97-Q;%]S=&%T=7,G(#T^(")0;W-T9W)E4U%,('-T871U<R(L
M"@DG7U]P<F5F97)E;F-E<R<@/3X@(E!R969E<F5N8V5S(BP*"2=?7V%D;6EN
M:7-T<F%T;W)?<')E9F5R96YC97,G(#T^(")!9&UI;FES=')A=&]R)W,@4')E
M9F5R96YC97,B+`H))U]?86-C;W5N=%]P<F5F97)E;F-E<R<@/3X@(D%C8V]U
M;G0@4')E9F5R96YC97,B+`H))U]?:6YT97)F86-E7W!R969E<F5N8V5S7V=E
M;F5R86PG(#T^("='96YE<F%L)RP*"2=?7VEN=&5R9F%C95]P<F5F97)E;F-E
M<U]D969A=6QT)R`]/B`G1&5F875L="!);G1E<F9A8V4@4')E9F5R96YC97,G
M+`H))U]?:6YT97)F86-E7W!R969E<F5N8V5S7V%D;6EN)R`]/B`B061M:6YI
M<W1R871O<B=S($EN=&5R9F%C92!0<F5F97)E;F-E<R(L"@DG<V5R=F5R7W!R
M969E<F5N8V5S7U]D969A=6QT7VET;7!L)R`]/B`G1&5F875L="!I;G1E<F9A
M8V4@8W5S=&]M:7IA=&EO;B!T96UP;&%T92<L"@DG<V5R=F5R7W!R969E<F5N
M8V5S7U]A9&UI;E]I=&UP;"<@/3X@(D%D;6EN:7-T<F%T;W(G<R!I;G1E<F9A
M8V4@8W5S=&]M:7IA=&EO;B!T96UP;&%T92(L"@DG7U]I;G1E<F9A8V5?=&5M
M<&QA=&4G(#T^("=);G1E<F9A8V4@8W5S=&]M:7IA=&EO;B!T96UP;&%T92<L
M"@DG7U]S>7-T96U?<')E9F5R96YC97,G(#T^(")3>7-T96T@<')E9F5R96YC
M97,B+`H))U]?:6YT97)F86-E7W!R969E<F5N8V5S)R`]/B`B26YT97)F86-E
M('!R969E<F5N8V5S(BP*"2=?7W!R:6]R:71Y)R`]/B`G4')I;W)I='DG+`H)
M)U]?<')I;W)I='E?:&EG:&5S="<@/3X@)VAI9VAE<W0G+`H))U]?<')I;W)I
M='E?:&EG:"<@/3X@)VAI9V@G+`H))U]?<')I;W)I='E?;F]R;6%L)R`]/B`G
M;F]R;6%L)RP*"2=?7W!R:6]R:71Y7VQO=R<@/3X@)VQO=R<L"@DG7U]P<FEO
M<FET>5]L;W=E<W0G(#T^("=L;W=E<W0G+`H))U]?<')I;W)I='E?;W1H97(G
M(#T^("=C=7-T;VTG+`H))U]?<')O8V5E9#\G(#T^(")$;R!Y;W4@=V%N="!T
M;R!P<F]C965D/R(L"@DG7U]P<F]C96YT)R`]/B`B)2(L"@DG7U]P<F]T96-T
M7V1I<E]U<V5R)R`]/B`B4')O=&5C=&5D(&1I<F5C=&]R>2!U<V5R(BP*"2=?
M7W!R;W1E8W1?9&ER7W5S97)S)R`]/B`B4')O=&5C=&5D(&1I<F5C=&]R>2!U
M<V5R<R(L"@DG7U]P<F]T96-T7V1I<G,G(#T^(")0<F]T96-T960@9&ER96-T
M;W)I97,B+`H))U]?<')O=FED97)?8V]N=&%C=%]N86UE)R`]/B`B4')O=FED
M97(G<R!C;VYT86-T(&YA;64B+`H))U]?<'0G(#T^(")U;FET<R(L"@DG7U]P
M>71H;VY?=6YI>%]S=7!P;W)T)R`]/B`B;6]D7W!Y=&AO;B!S=7!P;W)T(BP*
M"2=?7W!Y=&AO;E]W:6Y?<W5P<&]R="<@/3X@(E!Y=&AO;B!S=7!P;W)T(BP*
M"2=?7W%U;W1A)R`]/B`B475O=&$B+`H))U]?<B<@/3X@(E(B+`H))U]?<F5C
M;VYF:6=U<F4G(#T^(")296-O;F9I9W5R92(L"@DG7U]R96-O<F1?='EP92<@
M/3X@(E)E8V]R9"!T>7!E(BP*"2=?7W)E;&5A<V4G(#T^(")296QE87-E(BP*
M"2=?7W)E;6]T95]D8E]N;W1?<W5P<&]R=&5D7V)Y7VME>2<@/3X@)U)E;6]T
M92!D871A8F%S92!H;W-T:6YG(&ES(&YO="!S=7!P;W)T960@8GD@>6]U<B!L
M:6-E;G-E(&ME>2XG+`H))U]?<F5M;W9E)R`]/B`B4F5M;W9E(BP*"2=?7W)E
M;6]V95]C;VYF:7)M871I;VXG(#T^(")296UO=F%L(&-O;F9I<FUA=&EO;B(L
M"@DG7U]R97!O<G0G(#T^(")297!O<G0B+`H))U]?<F5P;W)T7V%U=&\G(#T^
M("=$96QI=F5R>2!S8VAE9'5L92<L"@DG7U]R97!O<G1?9F]R;2<@/3X@(E)E
M<&]R="!F;W)M(BP*"2=?7W)E<&]R=%]S:7IE7VYA)R`]/B`B4V5R=FEC92!I
M<R!U;F%V86EL86)L92(L"@DG7U]R97!O<G1S7VQI<W0G(#T^(")297!O<G1S
M(BP*"2=?7W)E<75E<W1E9"<@/3X@(E)E<75E<W1E9"(L"@DG7U]R97%U:7)E
M9%]F:65L9',G(#T^(")297%U:7)E9"!F:65L9',B+`H))U]?<F5S<%]N86UE
M7VEN=F%L:60G(#T^(")!=71O<F5S<&]N9&5R(&YA;64@:7,@:6YV86QI9"X@
M57-E(&]N;'D@86QP:&%N=6UE<FEC+"!D;W1S+"!U;F1E<G-C;W)E(&%N9"!W
M:&ET92!S<&%C97,@<WEM8F]L<RXB+`H))U]?8R<@/3X@(D$B+"`O+R!!8V-E
M<W,@=&\@8V]N=')O;"!P86YE;`H))U]?<R<@/3X@(E,B+`H))U]?<V5R=F5R
M7VYA;65?:7-?:6YV86QI9"<@/3X@(E-E<G9E<B!N86UE(&ES(&EN=F%L:60N
M(BP*"2=?7W-C<F5E;G-H;W1S)R`]/B`G4V-R965N<VAO=',G+`H))U]?<V-R
M:7!T7W=A<FYI;F<G(#T^(")">2!R96UO=FEN9R!T:&4@<V-R:7!T:6YG(&-A
M<&%B:6QI='D@9G)O;2!T:&ES(&1O;6%I;B!A;&P@:6YF;'5E;F-E9"!S8W)I
M<'1S('=I;&P@8F4@9&ES<&QA>65D(&EN('!L86EN('1E>'0@=VAE;B!C86QL
M960@8GD@82!B<F]W<V5R+B`@270@:7,@861V:7-A8FQE(&9O<B!T:&4@861M
M:6YI<W1R871O<B!T;R!R96UO=F4@86QL(&1E<&5N9&5N="!S8W)I<'1S(&9R
M;VT@=&AE(&=I=F5N(&1O;6%I;BXB+`H))U]?<V5C)R`]/B`B4V5C;VYD<R(L
M"@DG7U]S965?;&ES=%]O9E]L;V=G961?:6XG(#T^(")3964@=&AE(&QI<W0@
M;V8@8W5R<F5N=&QY(&QO9V=E9"!O;B!U<V5R<RXB+`H))U]?<V5L96-T7V-E
M<G1S7W1O7W)E;6]V92<@/3X@(E-E;&5C="!C97)T:69I8V%T97,@=&\@8F4@
M<F5M;W9E9"XB+`H))U]?<V5L96-T7V-L:65N='-?=&]?<F5M;W9E)R`]/B`B
M4V5L96-T(&-L:65N="!A8V-O=6YT<R!T;R!B92!R96UO=F5D+B(L"@DG7U]S
M96QE8W1?9&]M86EN<U]T;U]D969A=6QT7VAO<W0G(#T^(")396QE8W0@82!D
M;VUA:6X@=&\@<V5T(&%S(&1E9F%U;'0N(BP*"2=?7W-E;&5C=%]D;VUA:6YS
M7W1O7W)E;6]V92<@/3X@(E-E;&5C="!D;VUA:6YS('1O(&)E(')E;6]V960N
M(BP*"2=?7W-E;&5C=%]F:6QE<U]T;U]R96UO=F4G(#T^(")396QE8W0@9FEL
M97,@=&\@8F4@<F5M;W9E9"XB+`H))U]?<V5L96-T7VEP)R`]/B`B4V5L96-T
M(&%N($E0(&%D9')E<W,B+`H))U]?<V5L96-T7VEP7W1O7W)E;6]V92<@/3X@
M(E-E;&5C="!A;B!)4"!A9&1R97-S('1O(&)E(')E;6]V960N(BP*"2=?7W-E
M;&5C=%]T96UP;&%T92<@/3X@(E-E;&5C="!T96UP;&%T92(L"@DG7U]S96QE
M8W1?=&5M<&QA=&5S7W1O7W)E;6]V92<@/3X@(E-E;&5C="!T96UP;&%T97,@
M=&\@8F4@<F5M;W9E9"XB+`H))U]?<V5R=F5R)R`]/B`B4V5R=F5R(BP*"2=?
M7W-E<G9E<G-?;&ES="<@/3X@(E-L879E(%-E<G9E<G,B+`H))U]?<V5R=F5R
M7W1O=&%L)R`]/B`B4V5R=F5R(%1O=&%L(BP*"2=?7W-E<G9I8V4G(#T^(")3
M97)V:6-E(BP*"2=?7W-E<G9I8V5S)R`]/B`B4V5R=FEC97,B+`H))U]?<V5S
M<VEO;G,G(#T^(")397-S:6]N<R(L"@DG7U]S97-S:6]N<U]L:7-T)R`]/B`B
M4V5S<VEO;G,B+`H))U]?<V5T)R`]/B`B16YA8FQE(BP*"2=?7W-E='5P7VQO
M9V]?<')E9B<@/3X@(E-E="!U<"!L;V=O('!R;W!E<G1I97,B+`H))U]?<VAA
M<F5D)R`]/B`B4VAA<F5D(BP*"2=?7W-H961U;&5D7V)A8VMU<"<@/3X@(E-H
M961U;&5D($)A8VMU<"(L"@DG7U]S:&5L;%]A8V-E<W-?=V%R;FEN9R<@/3X@
M(D%L;&]W:6YG('-H96QL(&%C8V5S<R!T;R!T:&4@<WES=&5M(&ES(&AI9VAL
M>2!D86YG97)O=7,@9F]R('1H92!S>7-T96T@<V5C=7)I='DN($%L;&]W(&%C
M8V5S<R!T;R!T:&4@<WES=&5M(&]N;'D@:68@>6]U(&-L96%R;'D@=6YD97)S
M=&%N9"!W:&%T('EO=2!A<F4@9&]I;F<L(&%N9"!O;FQY('1O('1R=7-T960@
M=7-E<G,N($1O('EO=2!R96%L;'D@=V%N="!T;R!A;&QO=R!A8V-E<W,_(BP*
M"2=?7W-I=&5A<'!?;F]T7W-U<'!O<G1?:6Y?:V5Y)R`]/B`B4VET92!A<'!L
M:6-A=&EO;G,@87)E(&YO="!S=7!P;W)T960@8GD@=&AE(&QI8V5N<V4@:V5Y
M(BP*"2=?7W-I=&5A<'!?8V%N;F]T7W)E8V]N9FEG=7)E7W=I=&A?<F5M;W1E
M7V1A=&%B87-E)R`]/B`G5&AE(&-O;F9I9W5R871I;VX@;V8@=&AI<R!S:71E
M(&%P<&QI8V%T:6]N(&AA<R!B965N(&-H86YG960@;6%N=6%L;'DN($EN(&]R
M9&5R('1O('!R;W1E8W0@=&AE(&UA;G5A;"!M;V1I9FEC871I;VYS+"!R96-O
M;F9I9W5R871I;VX@=&AR;W5G:"!0;&5S:R!I<R!D:7-A;&QO=V5D+B<L"@DG
M7U]S:71E87!P7VQO8V%L7V1B7V1I<V%L;&]W960G(#T^("=!(')E;6]T92!D
M871A8F%S92!S97)V97(@:&%S(&)E96X@<V5L96-T960@87,@=&AE(&1E9F%U
M;'0@9&%T86)A<V4@;&]C871I;VXL(&)U="!T:&ES('-I=&4@87!P;&EC871I
M;VX@:7,@=6YA8FQE('1O('5S92!A(')E;6]T92!D871A8F%S92X@5&AE('-I
M=&4@87!P;&EC871I;VX@8V%N;F]T(&)E(&EN<W1A;&QE9"X@06X@=7!G<F%D
M92!O9B!T:&4@<VET92!A<'!L:6-A=&EO;B!P86-K86=E(&ES(')E8V]M;65N
M9&5D+B<L"@DG7U]S:71E87!P7W)E;6]T95]D871A8F%S92<@/3X@)U1H92!D
M871A8F%S92!C86X@8F4@:&]S=&5D(&]N(&$@<F5M;W1E('-E<G9E<BXG+`H)
M)U]?<VET95]A<'!L:6-A=&EO;B<@/3X@(E-I=&4@07!P;&EC871I;VXB+`H)
M)U]?<VET95]A<'!L:6-A=&EO;E]P86-K86=E)R`]/B`B4VET92!!<'!L:6-A
M=&EO;B!086-K86=E(BP*"2=?7W-I=&5?87!P;&EC871I;VY?<&%C:V%G97,G
M(#T^(")3:71E($%P<&QI8V%T:6]N(%!A8VMA9V5S(BP*"2=?7W-I=&5?87!P
M;&EC871I;VYS)R`]/B`B4VET92!!<'!L:6-A=&EO;G,B+`H))U]?<VET95]M
M86YA9V5M96YT)R`]/B`B5V5B(%!U8FQI<VAI;F<B+`DO+R!I;F1I<F5C=`H)
M)U]?<VEZ92<@/3X@(E-I>F4B+`H))U]?<VME;&5T;VXG(#T^(")3:V5L971O
M;B(L"@DG7U]S:VEN<R<@/3X@)U-K:6YS)RP*"2=?7W-M='`G(#T^(")33510
M(BP)+R\@:6YD:7)E8W0*"2=?7W-M='!?<W1A='5S)R`]/B`B4TU44"!S97)V
M97(@<W1A='5S(BP*"2=?7W-O;65?9FEE;&1S7V%R95]E;7!T>5]O<E]I;G9A
M;&ED)R`]/B`B4V]M92!F:65L9',@87)E(&5M<'1Y(&]R(&-O;G1A:6X@86X@
M:6UP<F]P97(@=F%L=64N(BP*"2=?7W-O;65?9FEE;&1S7V%R95]E;7!T>5]O
M<E]I;G9A;&ED7V]R7VQO;F<G(#T^(")3;VUE(&9I96QD<R!A<F4@96UP='D@
M;W(@8V]N=&%I;B!A;B!I;7!R;W!E<B!V86QU92X@5&AE('9A;'5E<R!S:&]U
M;&0@8F4@;&EM:71E9"!T;R`V-"!C:&%R86-T97)S+B!)9B!Y;W4@87)E('5S
M:6YG(&%N(&EN=&5R;F%T:6]N86QI>F5D(&1O;6%I;B!N86UE+"!M86ME('-U
M<F4@96%C:"!P87)T(&]F('1H92!D;VUA:6X@;F%M92!B971W965N(&1O=',@
M9&]E<R!N;W0@97AC965D(#8S('-Y;6)O;',@=VAE;B!T<F%N<V9O<FUE9"!T
M;R!!4T-)22!F;W)M870N(BP*"2=?7W-P86UA<W-A<W-I;B<@/3X@(E-P86U!
M<W-A<W-I;B(L"@DG7U]S<&%M87-S87-S:6Y?<W1A='5S)R`]/B`B4W!A;4%S
M<V%S<VEN('-T871U<R(L"@DG7U]S<&QI=&5D7V)A8VMU<"<@/3X@(BAM=6QT
M:79O;'5M92!B86-K=7`I(BP*"2=?7W-P;&ET7V)A8VMU<%]F:6QE)R`]/B`B
M0W)E871E(&$@;75L=&EV;VQU;64@8F%C:W5P(BP*"2=?7W-P;&ET7V)A8VMU
M<%]S:7IE)R`]/B`B5F]L=6UE('-I>F4B+`H))U]?<W!L:71?8F%C:W5P7VQE
M<W-?=&AA;E\U,#`G(#T^(")6;VQU;64@<VEZ97,@;&5S<R!T:&%N(#4P,"!M
M96=A8GET97,@87)E(&YO="!S=7!P;W)T960B+`H))U]?<W-I)R`]/B`B4U-)
M(BP*"2=?7W-S:5]S=7!P;W)T)R`]/B`B4U-)('-U<'!O<G0B+`H))U]?<W-L
M)R`]/B`G4U-,)RP*"2=?7W-S;%]S=7!P;W)T)R`]/B`B4U-,('-U<'!O<G0B
M+`H))U]?<V%M95]S<VPG(#T^(")5<V4@82!S:6YG;&4@9&ER96-T;W)Y(&9O
M<B!H;W5S:6YG(%-33"!A;F0@;F]N+5-33"!C;VYT96YT(BP*"2=?7W-A;65?
M<W-L7V-U)R`]/B`B0V]M;6]N(%-33"].;VXM4U-,(&-O;G1E;G0B+`H))U]?
M<W1A=&4G(#T^(")3=&%T92]0<F]V:6YC92(L"@H))U]?<W1A='5S7U]!8W1I
M=F4G(#T^("=!8W1I=F4G+`H))U]?<W1A='5S7U]A8W1I=F4G(#T^("=A8W1I
M=F4G+`H))U]?<W1A='5S7U]087-S:79E)R`]/B`G1&ES86)L960G+`H))U]?
M<W1A='5S7U]P87-S:79E)R`]/B`G9&ES86)L960G+`H))U]?<W1A='5S7U]O
M9F8G(#T^("=D:7-A8FQE9"<L"@DG7U]S=&%T=7-?7W=I=&A?<&%R96YT)R`]
M/B`G9&ES86)L960G+`H))U]?<W1A='5S7U]B86-K=7!?<F5S=&]R92<@/3X@
M)W1E;7!O<F%R:6QY('-U<W!E;F1E9"!F;W(@8F%C:VEN9R!U<"!O<B!R97-T
M;W)I;F<G+`H))U]?<W1A='5S7U]A9&UI;B<@/3X@)V1I<V%B;&5D(&)Y(&%D
M;6EN)RP*"2=?7W-T871U<U]?<F5S<V5L97(G(#T^("=D:7-A8FQE9"!B>2!R
M97-E;&QE<B<L"@DG7U]S=&%T=7-?7V-L:65N="<@/3X@)V1I<V%B;&5D(&)Y
M(&-L:65N="<L"@DG7U]S=&%T=7-?7W5N:VYO=VXG(#T^("=S=&%T=7,@:7,@
M=6YK;F]W;B<L"@H))U]?<W1A='5S7V]F)R`]/B`B)3$@<W1A='5S(BP*"@DO
M+R!E;F0@;V8@86MS<R!P87)T"@H)+R\@<VAR86UK;R!P87)T"@H))U]?<W1U
M;FYE;"<@/3X@(E-T=6YN96PB+`H))U]?<W1U;FYE;%]S97)V97(G(#T^(")3
M='5N;F5L('-E<G9E<B(L"2\O(&EN9&ER96-T"@DG7U]S=6)D;VUA:6XG(#T^
M(")3=6)D;VUA:6XB+`H))U]?<W5B9&]M86EN7VYA;64G(#T^(")3=6)D;VUA
M:6X@;F%M92(L"@DG7U]S=6)D;VUA:6Y?;F%M95]I;E]!4T-)25]F;W)M)R`]
M/B`B26X@05-#24D@9F]R;6%T(BP*"2=?7W-U8F1O;6%I;G,G(#T^(")3=6)D
M;VUA:6YS(BP*"2=?7W-U8F1O;6%I;G-?;&ES="<@/3X@(E-U8F1O;6%I;G,B
M+`H))U]?<W5B9&]M86EN<U]N;W1?<W5P<&]R=%]I;E]K97DG(#T^(")3=6)D
M;VUA:6X@;W!E<F%T:6]N<R!A<F4@;F]T('-U<'!O<G1E9"!B>2!T:&4@;&EC
M96YS92!K97DB+`H))U]?<WES7W5S97)?='EP92<@/3X@(D944"!U<V5R(BP*
M"2=?7W-Y<U]U<V5R7W1Y<&5?;6%I;B<@/3X@(E5S92!T:&4@1E10('5S97(@
M86-C;W5N="!O9B!T:&4@;6%I;B!D;VUA:6XB+`H))U]?<WES7W5S97)?='EP
M95]N871I=F4G(#T^(")#<F5A=&4@82!S97!A<F%T92!&5%`@=7-E<B!A8V-O
M=6YT(&9O<B!T:&ES('-U8F1O;6%I;B(L"@DG7U]T)R`]/B`B5"(L"@DG7U]T
M87)G971?9&]M86EN)R`]/B`B5&%R9V5T(&1O;6%I;B(L"@DG7U]T87-K)R`]
M/B`G5&%S:R<L"@DG7U]T87-K<U]L:7-T)R`]/B`G5&%S:W,G+`H))U]?=&5M
M<&QA=&4G(#T^(")496UP;&%T92(L"@DG7U]T96UP;&%T95]N;W1?86-C97!T
M960G(#T^(")5;F%B;&4@=&\@86-C97!T('1H92!T96UP;&%T93H@=&AE(&9O
M;&QO=VEN9R!L:6UI=&%T:6]N<R!A<F4@97AC965D960N(BP*"2=?7W1E;7!L
M871E<R<@/3X@(E1E;7!L871E<R(L"@DG7U]T96UP;&%T97-?;&ES="<@/3X@
M(E1E;7!L871E<R(L"@DG7U]T97)A)R`]/B`B5"(L"@DG7U]T97AT)R`]/B`B
M5&5X="(L"@DG7U]T:71L92<@/3X@(E1I=&QE(BP*"2=?7W1O;6-A="<@/3X@
M(E1O;6-A="(L"@DG7U]T;VUC871?;F]T7W-U<'!O<G1?:6Y?:V5Y)R`]/B`B
M5&]M8V%T(&ES(&YO="!S=7!P;W)T960@8GD@=&AE(&QI8V5N<V4@:V5Y(BP*
M"2=?7W-P86UA<W-A<W-I;E]N;W1?<W5P<&]R=%]I;E]K97DG(#T^(")3<&%M
M07-S87-S:6X@:7,@;F]T('-U<'!O<G1E9"!B>2!T:&4@;&EC96YS92!K97DB
M+`H))U]?=&]M8V%T7W-T871U<R<@/3X@(E1O;6-A="!S=&%T=7,B+`H))U]?
M=&]O;',G(#T^(")4;V]L<R(L"@DG7U]T;W1A;"<@/3X@(E1O=&%L("4Q(BP*
M"2=?7W1O=&%L7W-I>F4G(#T^(")4;W1A;"!S:7IE(BP*"2=?7W1O=&%L7W5S
M960G(#T^(")4;W1A;"!5<V5D(BP*"2=?7W1T<R<@/3X@(DAE;'`@1&5S:R(L
M"@DG7U]T<F%F9FEC)R`]/B`B5')A9F9I8R(L"@DG7U]T<F%F9FEC7V)Y7V-L
M:65N="<@/3X@(E1R869F:6,@8GD@8VQI96YT(BP*"2=?7W1R869F:6-?8GE?
M9&]M86EN)R`]/B`B5')A9F9I8R!B>2!D;VUA:6XB+`H))U]?=')A9F9I8U]B
M>5]S97)V:6-E)R`]/B`B5')A9F9I8R!B>2!S97)V:6-E(BP*"2=?7W1R869F
M:6-?:&ES=&]R>2<@/3X@(E1R869F:6,@:&ES=&]R>2(L"@DG7U]U;F%B;&5?
M8VAA;F=E7VQO8V%L92<@/3X@(E5N86)L92!T;R!C:&%N9V4@=&AE(&EN=&5R
M9F%C92!L86YG=6%G93H@)3$B+`H))U]?=6YA8FQE7V-R96%T95]N97=?9&]M
M)R`]/B`B56YA8FQE('1O(&-R96%T92!N97<@9&]M86EN.B`E,2(L"@DG7U]U
M;F%B;&5?9&5F:6YE7V1O;5]N86UE)R`]/B`B56YA8FQE('1O(&1E9FEN92!D
M;VUA:6X@;F%M93H@)3$B+`H))U]?=6YA8FQE7V1E9FEN95]N96-E<W-A<GE?
M<')O<&5R=&EE<R<@/3X@(E5N86)L92!T;R!D969I;F4@86QL(')E<75I<F5D
M('!R;W!E<G1I97,N(BP*"2=?7W5N86)L95]D969I;F5?<')O<&5R=&EE<R<@
M/3X@(E5N86)L92!T;R!D969I;F4@<')O<&5R=&EE<SH@)3$B+`H))U]?=6YA
M8FQE7V5X96-?=71I;"<@/3X@(E5N86)L92!T;R!E>&5C=71E('5T:6QI='DZ
M("4Q(BP*"2=?7W5N86)L95]G96YE<F%T95]C97)T)R`]/B`B56YA8FQE('1O
M(&=E;F5R871E(&-E<G1I9FEC871E.B`E,2(L"@DG7U]U;F%B;&5?9V5N97)A
M=&5?8W-R)R`]/B`B56YA8FQE('1O(&=E;F5R871E($-34CH@)3$B+`H))U]?
M=6YA8FQE7V=E=%]D;G-?85]R96-S)R`]/B`B56YA8FQE('1O(')E=')I979E
M(&EP(&%D9')E<W-E<R!F;W(@02!$3E,@<F5C;W)D<R!F;W(@=&AI<R!H;W-T
M:6YG(&%C8V]U;G0Z("4Q(BP*"2=?7W5N86)L95]G971?;6)O>%]Q=6]T82<@
M/3X@(E5N86)L92!T;R!R971R:65V92!T:&4@:6YF;W)M871I;VX@;VX@=&AE
M(&UA:6QB;W@@<VEZ92!L:6UI="XB+`H))U]?=6YA8FQE7W)E9&ER96-T7W1O
M7VUY<V5L9B<@/3X@(E5N86)L92!T;R!R961I<F5C="!T;R!O;F5S96QF+B(L
M"@DG7U]U;F%B;&5?<F5M;W9E7V-L:65N="<@/3X@(E5N86)L92!T;R!R96UO
M=F4@8VQI96YT.B`E,2(L"@DG7U]U;F%B;&5?<V5T7W5P7VUB;WA?<75O=&$G
M(#T^(")5;F%B;&4@=&\@<V5T('1H92!M86EL8F]X('-I>F4@;&EM:70@9F]R
M('1H92!D;VUA:6XZ("4Q(BP*"2=?7W5N86)L95]S971U<%]P87-S)R`]/B`B
M56YA8FQE('1O('-E="!P87-S=V]R9#H@)3$B+`H))U]?=6YA8FQE7W1O7V-R
M96%T95]N97=?86-C;W5N="<@/3X@(E5N86)L92!T;R!C<F5A=&4@;F5W(&%C
M8V]U;G0Z("4Q(BP*"2=?7W5N86)L95]T;U]D969I;F5?9&)?<VEZ92<@/3X@
M(E5N86)L92!T;R!D969I;F4@=&AE(&1A=&%B87-E('-I>F4B+`H))U]?=6YA
M8FQE7W1O7V5N86)L95]S:&]R=%]N86UE<R<@/3X@(E5N86)L92!T;R!A;&QO
M=R!T:&4@=7-E(&]F('-H;W)T(&UA:6P@;F%M97,@9F]R(%!/4#,O24U!4"!A
M8V-O=6YT<RXB+`H))U]?=6YA8FQE7W1O7V9E=&-H7V1A=&%?9G)O;5]S=6)M
M:70G(#T^(")5;F%B;&4@=&\@9F5T8V@@=&AE('-U8FUI='1E9"!D871A.B`E
M,2(L"@DG7U]U;F%B;&5?=&]?;W!E;E]F:6QE)R`]/B`B56YA8FQE('1O(&]P
M96X@=&AE(&9I;&4@)3$Z("4R+B(L"@DG7U]U;F%B;&5?=&]?=7!D871E7W-U
M8F1O;6%I;B<@/3X@(E5N86)L92!T;R!M86ME(&-H86YG97,@=&\@=&AE('-U
M8F1O;6%I;CH@)3$B+`H))U]?=6YA8FQE7W5P9&%T95]C;%]D871A)R`]/B`B
M56YA8FQE('1O('5P9&%T92!C;&EE;G0@9&%T83H@)3$B+`H))U]?=6YA8FQE
M7W5P9&%T95]D8E]P87)A;7,G(#T^(")5;F%B;&4@=&\@=7!D871E(&1A=&%B
M87-E('!A<F%M971E<G,Z("4Q(BP*"2=?7W5N86)L95]U<&1A=&5?9&]M7V1A
M=&$G(#T^(")5;F%B;&4@=&\@=7!D871E(&1O;6%I;B!D871A.B`E,2(L"@DG
M7U]U;F1E9FEN960G(#T^(")U;F1E9FEN960B+`H))U]?=6YI;G-T86QL)R`]
M/B`B56YI;G-T86QL(BP*"2=?7W5N:VYO=VY?97)R;W(G(#T^(")5;FMN;W=N
M(&5R<F]R(BP*"2=?7W5N;&EM:71E9"<@/3X@(E5N;&EM:71E9"(L"@DG7U]U
M;FQI;6ET961?;&]W97(G(#T^(")5;FQI;6ET960B+`H))U]?=6YS970G(#T^
M(")$:7-A8FQE(BP*"2=?7W5P9&%T92<@/3X@(E5P9&%T92(L"@DG7U]U<&QO
M861?8V5R=%]F:6QE)R`]/B`B57!L;V%D(&-E<G1I9FEC871E(&9I;&4@(BP*
M"2=?7W5P;&]A9&5D7V9I;&5?:7-?:6YV86QI9"<@/3X@(E5P;&]A9&5D(&9I
M;&4@:7,@:6YV86QI9#H@)3$B+`H))U]?=7)L)R`]/B`B55),(BP*"2=?7W5S
M86=E)R`]/B`B1&ES:R!U<V%G92(L"@DG7U]U<V5D)R`]/B`B57-E9"(L"@DG
M7U]U<V5R)R`]/B`B57-E<B(L"@DG7U]U<V5R7V%L<F5A9'E?97AI<W0G(#T^
M(")5<V5R("4Q(&%L<F5A9'D@97AI<W1S+B(L"@DG7U]U<V5R7V%L<F5A9'E?
M97AI<W1S)R`]/B`B57-E<B`E,2!A;')E861Y(&5X:7-T<RXB+`H))U]?=7-E
M<E]A;')E861Y7VQO9V=E9"<@/3X@(D%N;W1H97(@=7-E<B!W:71H('1H92!S
M86UE(&QO9VEN("@E,2D@:7,@86QR96%D>2!L;V=G960@;VX@=&\@=&AE("!C
M;VYT<F]L('!A;F5L+B(L"@DG7U]V86QU92<@/3X@(E9A;'5E(BP*"2=?7W9E
M<G-I;VXG(#T^(")697)S:6]N(BP*"2=?7W9H7W1Y<&4G(#T^(")6:7)T=6%L
M(&AO<W0@='EP92(L"@DG7U]V:&]S='-?87!A8VAE7W-T871U<R<@/3X@(E=E
M8B!S97)V97(@<W1A='5S(BP*"2=?7W=R;VYG7V-H87)S971?8V]N=F5R<VEO
M;B<@/3X@)U=R;VYG(&-H87)S970L(&-O;G9E<G-I;VX@9G)O;2`B)3$B('1O
M("(E,B(@:7,@;F]T(&%L;&]W960G+`H))U]?=V%R;FEN9U\G(#T^(")787)N
M:6YG(2(L"@DG7U]W87)N:6YG7V5X8VQ?:7!?;G5M)R`]/B`B17AC;'5S:79E
M($E0(&%D9')E<W,B+`H))U]?=V%R;FEN9U]E>'!I<F%T:6]N)R`]/B`B17AP
M:7)A=&EO;B!D871E(BP*"2=?7W=E8E]A<'!S)R`]/B`B2F%V82!A<'!L:6-A
M=&EO;G,B+`H))U]?=V5B7W-C<FEP=&EN9R<@/3X@(E=E8B!S8W)I<'1I;F<B
M+`DO+R!I;F1I<F5C=`H))U]?=V5B7W-E<G8G(#T^(")796(@<V5R=F5R(BP)
M+R\@:6YD:7)E8W0*"2=?7W=E8E]S=&%T:7-T:6,G(#T^(")796(@<W1A=&ES
M=&EC<R(L"2\O(&EN9&ER96-T"@DG7U]W96)M86EL)R`]/B`B5V5B36%I;"(L
M"2\O("MI;F1I<F5C=`H))U]?=V5B<W1A=%]N;W1?:6YS=&%L;&5D)R`]/B`B
M5V5B86QI>F5R(&ES(&YO="!C=7)R96YT;'D@:6YS=&%L;&5D(&]N('1H92!S
M97)V97(N($-O;G1A8W0@=&AE('-E<G9E<B!A9&UI;FES=')A=&]R('1O(&AA
M=F4@=&AE(%=E8F%L:7IE<B!I;G-T86QL960N(BP*"2=?7W=E8G-T871?<W5P
M<&]R="<@/3X@(E=E8B!S=&%T:7-T:6-S(BP*"2=?7W=E8G5S97(G(#T^(")7
M96(@=7-E<B(L"@DG7U]W96)U<V5R<U]L:7-T)R`]/B`B5V5B('5S97)S(BP*
M"2=?7W=E96ML>2<@/3X@(E=E96ML>2(L"@DG7U]W:&%T<U]N97=?:6Y?=F5R
M<VEO;B<@/3X@(E=H870G<R!N97<@:6X@4&QE<VL@)3$_(BP*"2=?7W=R;VYG
M7VAO<W1I;F=?='EP95]?;F]N92<@/3X@)U1H97)E(&ES(&YO('!H>7-I8V%L
M(&AO<W1I;F<@8V]N9FEG=7)E9"!O;B!T:&ES(&1O;6%I;BXG+`H))U]?=W)O
M;F=?:&]S=&EN9U]T>7!E7U]S=&1?9G=D)R`]/B`G5&AI<R!D;VUA:6X@:&%S
M('-T86YD87)D(&9O<G=A<F1I;F<@8V]N9FEG=7)E9"X@5&AI<R!O<&5R871I
M;VX@:7,@879A:6QA8FQE(&]N;'D@9F]R(&1O;6%I;G,@=VET:"!P:'ES:6-A
M;"!H;W-T:6YG+B<L"@DG7U]W<F]N9U]H;W-T:6YG7W1Y<&5?7V9R;5]F=V0G
M(#T^("=4:&ES(&1O;6%I;B!H87,@9G)A;64@9F]R=V%R9&EN9R!C;VYF:6=U
M<F5D+B!4:&ES(&]P97)A=&EO;B!I<R!A=F%I;&%B;&4@;VYL>2!F;W(@9&]M
M86EN<R!W:71H('!H>7-I8V%L(&AO<W1I;F<N)RP*"2=?7W=U)R`]/B`B5V5B
M('5S97)S(BP*"2=?7W=W=R<@/3X@(E=75R(L"@DG7U]W=W=?<')E9FEX)R`]
M/B`B5U=7('!R969I>"(L"@DG7U]W=W=?<')E9FEX7W=A<U]C:&%N9V5D)R`]
M/B`B5U=7('!R969I>"!W87,@8VAA;F=E9"X@0F4@<W5R92!T;R!M;V1I9GD@
M=&AE(%-33"!C97)T:69I8V%T92!A8V-O<F1I;F=L>2XB+`H))U]?>65A<B<@
M/3X@(EEE87(B+`H))U]?>65A<BAS*2<@/3X@(EEE87(H<RDB+`H))U]?>65S
M)R`]/B`B665S(BP*"2=?7WEO=2<@/3X@(EEO=2(L"@DG7U]Z:7!?8V]D92<@
M/3X@(E!O<W1A;"]:25`@8V]D92(L"@DG7U]F;W)M7VYO<FUA;"<@/3X@(DYO
M<FUA;"(L"@DG7U]F;W)M7V%D=F%N8V5D)R`]/B`B061V86YC960B+`H*"2=?
M7VUA>%]D;VUA:6YS7VQI;6ET7W5S86=E)R`]/B`G)3$@;V8@)3(@9&]M86EN
M*',I('5S960[("4S(&%V86EL86)L92<L"@DG7U]M87A?9&]M86EN<U]N;U]L
M:6UI=%]U<V%G92<@/3X@)R4Q(&]F('5N;&EM:71E9"!D;VUA:6YS('5S960G
M+`H))U]?;6%X7VUA:6QB;WAE<U]L:6UI=%]U<V%G92<@/3X@)R4Q(&]F("4R
M(&UA:6QB;W@H97,I('5S960[("4S(&%V86EL86)L92<L"@DG7U]M87A?;6%I
M;&)O>&5S7VYO7VQI;6ET7W5S86=E)R`]/B`G)3$@;V8@=6YL:6UI=&5D(&UA
M:6QB;WAE<R!U<V5D)RP*"2=?7V1I<VM?<W!A8V5?;&EM:71?=7-A9V4G(#T^
M("<E,2!O9B`E,B!U<V5D.R`E,R!A=F%I;&%B;&4G+`H))U]?9&ES:U]S<&%C
M95]N;U]L:6UI=%]U<V%G92<@/3X@)R4Q(&]F('5N;&EM:71E9"!D:7-K('-P
M86-E('5S960G+`H))U]?=')A9F9I8U]L:6UI=%]U<V%G92<@/3X@)R4Q(&]F
M("4R('5S960[("4S(&%V86EL86)L92<L"@DG7U]T<F%F9FEC7VYO7VQI;6ET
M7W5S86=E)R`]/B`G)3$@;V8@=6YL:6UI=&5D('1R869F:6,@=7-E9"<L"@DG
M7U]M87A?<W5B9&]M86EN<U]L:6UI=%]U<V%G92<@/3X@)R4Q(&]F("4R('-U
M8F1O;6%I;BAS*2!U<V5D.R`E,R!A=F%I;&%B;&4G+`H))U]?;6%X7W-U8F1O
M;6%I;G-?;F]?;&EM:71?=7-A9V4G(#T^("<E,2!O9B!U;FQI;6ET960@<W5B
M9&]M86EN<R!U<V5D)RP*"@DG7U]M96U?=7-A9V5?:6YF;R<@/3X@)R4Q(&]F
M("4R('5S960[("4S(&%V86EL86)L92<L"@DG7U]D:7-K7W5S86=E7VEN9F\G
M(#T^("<E,2!O9B`E,B!U<V5D.R`E,R!A=F%I;&%B;&4G+`H*"2=A8W1I;VYL
M;V=?7V-O;F9I<FU?8VQE86Y?;&]G)R`]/B`B07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O(&1E;&5T92!T:&4@<V5L96-T960@86-T:6]N(&QO9R!R96-O<F1S
M/R(L"@DG86-T:6]N;&]G7U]D:6=I=%]E>'!E8W1E9"<@/3X@(D$@;G5M8F5R
M(&5X<&5C=&5D.B`E,2(L"@DG86-T:6]N;&]G7U]D;VYT7W)E;6]V95]R96-S
M)R`]/B`B9&\@;F]T(')E;6]V92!R96-O<F1S(BP*"2=A8W1I;VYL;V=?7V9R
M;VU?9&%T92<@/3X@(F9R;VTZ(BP*"2=A8W1I;VYL;V=?7VEN8V]R<F5C=%]R
M;W1A=&EO;B<@/3X@(DEN=F%L:60@;&]G(')O=&%T:6]N('!A<F%M971E<G,@
M<W!E8VEF:65D.B`E,2(L"@DG86-T:6]N;&]G7U]J<U]I;F-O<G)E8W1?9&%T
M92<@/3X@(DEN=F%L:60@9&%T92!S<&5C:69I960B+`H))V%C=&EO;FQO9U]?
M:G-?:6YC;W)R96-T7VYU;5]P97)I;V1S)R`]/B`B26YV86QI9"!R;W1A=&EO
M;B!P97)I;V0@<W!E8VEF:65D(BP*"2=A8W1I;VYL;V=?7VIS7VEN8V]R<F5C
M=%]N=6U?<F5C;W)D<R<@/3X@(DEN=F%L:60@;G5M8F5R(&]F(')E8V]R9',@
M<W!E8VEF:65D(BP*"2=A8W1I;VYL;V=?7VQO9V=E9%]A8W1I;VYS)R`]/B`B
M3&]G9V5D(&%C=&EO;G,B+`H))V%C=&EO;FQO9U]?<&5R:6]D7V1A>2<@/3X@
M(F1A>7,B+`H))V%C=&EO;FQO9U]?<&5R:6]D7VUO;G1H)R`]/B`B;6]N=&AS
M(BP*"2=A8W1I;VYL;V=?7W!E<FEO9%]W965K)R`]/B`B=V5E:W,B+`H))V%C
M=&EO;FQO9U]?<V5T=&EN9W,G(#T^(")!8W1I;VX@;&]G('-E='1I;F=S(BP*
M"2=A8W1I;VYL;V=?7W-T;W)E7VQO9W-?:6Y?9&(G(#T^(")3=&]R92!R96-O
M<F1S(&EN('1H92!D871A8F%S92(L"@DG86-T:6]N;&]G7U]S=&]R95]N=6UB
M97(G(#T^(")E;G1R:65S(BP*"2=A8W1I;VYL;V=?7W1O7V1A=&4G(#T^(")T
M;SHB+`H))V%C=&EO;FQO9U]?=6YK;F]W;E]R;W1?<&5R:6]D)R`]/B`B56YK
M;F]W;B!R;W1A=&EO;B!P97)I;V0Z("4Q(BP*"2=A8W1I;VYL;V=?7W5N:VYO
M=VY?<F]T7W1Y<&4G(#T^(")5;FMN;W=N(')O=&%T:6]N('1Y<&4Z("4Q(BP*
M"2=A8W1I;VYL;V=?7W=R;VYG7V1A=&5?<&5R:6]D)R`]/B`B26YV86QI9"!D
M871E(BP*"2=A8W1I;VYL;V=?7W-E<W-I;VY?<')E9F5R96YC97,G(#T^("=,
M;V=I;B!S971T:6YG<R<L"@H))V%C=&EO;FQO9U]?861M:6Y?:6YF;R<@/3X@
M)T%D;6EN:7-T<F%T;W(@:6YF;W)M871I;VXG+`H))V%C=&EO;FQO9U]?<V5R
M=FEC92<@/3X@)U-E<G9I8V4G+`H))V%C=&EO;FQO9U]?:7!?861D<B<@/3X@
M)TE0(&%D9')E<W,G+`H))V%C=&EO;FQO9U]?8VQI96YT)R`]/B`G0VQI96YT
M(&%C8V]U;G0G+`H))V%C=&EO;FQO9U]?8VQI96YT7W-T871U<R<@/3X@)T-L
M:65N="!A8V-O=6YT('-T871U<R<L"@DG86-T:6]N;&]G7U]C;&EE;G1?<')E
M9F5R96YC97,G(#T^(")#;&EE;G0G<R!I;G1E<F9A8V4@<')E9F5R96YC97,B
M+`H))V%C=&EO;FQO9U]?8VQI96YT7VQI;6ET<R<@/3X@)T-L:65N="!A8V-O
M=6YT(&QI;6ET<R<L"@DG86-T:6]N;&]G7U]C;&EE;G1?;&EM:71?<VEZ92<@
M/3X@(D1I<VL@<W!A8V4@;&EM:70@9F]R(&-L:65N="!A8V-O=6YT(BP*"2=A
M8W1I;VYL;V=?7V-L:65N=%]L:6UI=%]T<F%F9FEC)R`]/B`B5')A9F9I8R!L
M:6UI="!F;W(@8VQI96YT(&%C8V]U;G0B+`H))V%C=&EO;FQO9U]?8VQI96YT
M7W!E<FUI<W-I;VYS)R`]/B`B0VQI96YT)W,@<&5R;6ES<VEO;G,B+`H))V%C
M=&EO;FQO9U]?8VQI96YT7VEP7W!O;VPG(#T^(")#;&EE;G0G<R!)4"!P;V]L
M(BP*"2=A8W1I;VYL;V=?7V-L:65N=%]S:71E87!P)R`]/B`B0VQI96YT)W,@
M<VET92!A<'!L:6-A=&EO;B!P;V]L(BP*"2=A8W1I;VYL;V=?7V1O;6%I;E]U
M<V5R)R`]/B`G1&]M86EN(&%D;6EN:7-T<F%T;W(@86-C;W5N="<L"@DG86-T
M:6]N;&]G7U]D;VUA:6XG(#T^("=$;VUA:6XG+`H))V%C=&EO;FQO9U]?9&]M
M86EN7V]W;F5R)R`]/B`G1&]M86EN(&]W;F5R)RP*"2=A8W1I;VYL;V=?7V1O
M;6%I;E]S=&%T=7,G(#T^("=$;VUA:6X@<W1A='5S)RP*"2=A8W1I;VYL;V=?
M7V1O;6%I;E]D;G,G(#T^("=$;VUA:6X@1$Y3('IO;F4G+`H))V%C=&EO;FQO
M9U]?<W5B9&]M86EN)R`]/B`G4W5B9&]M86EN)RP*"2=A8W1I;VYL;V=?7V1A
M<VAB;V%R9%]P<F5S970G(#T^("=$97-K=&]P('!R97-E="<L"@DG86-T:6]N
M;&]G7U]D;VUA:6Y?86QI87,G(#T^("=$;VUA:6X@86QI87,G+`H))V%C=&EO
M;FQO9U]?9&]M86EN7V%L:6%S7V1N<R<@/3X@)T1O;6%I;B!A;&EA<R!$3E,@
M>F]N92<L"@DG86-T:6]N;&]G7U]D;VUA:6Y?;&EM:71S)R`]/B`G1&]M86EN
M(&QI;6ET<R<L"@DG86-T:6]N;&]G7U]D;VUA:6Y?;&EM:71?<VEZ92<@/3X@
M)T1I<VL@<W!A8V4@;&EM:70@9F]R(&1O;6%I;B<L"@DG86-T:6]N;&]G7U]D
M;VUA:6Y?;&EM:71?=')A9F9I8R<@/3X@)U1R869F:6,@;&EM:70@9F]R(&1O
M;6%I;B<L"@DG86-T:6]N;&]G7U]C<%]U<V5R)R`]/B`G0V]N=')O;"!P86YE
M;"!U<V5R)RP*"2=A8W1I;VYL;V=?7VUA:6QN86UE)R`]/B`G36%I;"!N86UE
M)RP*"2=A8W1I;VYL;V=?7VUA:6QL:7-T)R`]/B`G36%I;&EN9R!L:7-T)RP*
M"2=A8W1I;VYL;V=?7W!H;W-T:6YG)R`]/B`G4&AY<VEC86P@:&]S=&EN9R<L
M"@DG86-T:6]N;&]G7U]F;W)W87)D:6YG)R`]/B`G4W1A;F1A<F0@;W(@9G)A
M;64@9F]R=V%R9&EN9R!H;W-T:6YG)RP*"2=A8W1I;VYL;V=?7W=E8G5S97(G
M(#T^("=796(@=7-E<B!A8V-O=6YT)RP*"2=A8W1I;VYL;V=?7W-I=&5?87!P
M;&EC871I;VXG(#T^("=3:71E(&%P<&QI8V%T:6]N)RP*"2=A8W1I;VYL;V=?
M7W-I=&5?87!P;&EC871I;VY?<&%C:V%G92<@/3X@)U-I=&4@87!P;&EC871I
M;VX@<&%C:V%G92<L"@DG86-T:6]N;&]G7U]L:6-E;G-E)R`]/B`G3&EC96YS
M92!K97DG+`H*"2=A8W1I;VYL;V=?7VQI;6ET7W)E86-H960G(#T^("=R96%C
M:&5D)RP*"2=A8W1I;VYL;V=?7V%D9&5D)R`]/B`G861D960G+`H))V%C=&EO
M;FQO9U]?<F5M;W9E9"<@/3X@)W)E;6]V960G+`H))V%C=&EO;FQO9U]?8VAA
M;F=E)R`]/B`G8VAA;F=E9"<L"@DG86-T:6]N;&]G7U]U<&1A=&4G(#T^("=U
M<&1A=&5D)RP*"2=A8W1I;VYL;V=?7V5X<&ER960G(#T^("=E>'!I<F5D)RP*
M"2=A8W1I;VYL;V=?7V-R96%T92<@/3X@)V-R96%T960G+`H))V%C=&EO;FQO
M9U]?9&5L971E)R`]/B`G9&5L971E9"<L"@DG86-T:6]N;&]G7U]S97)V:6-E
M7W-T;W`G(#T^("=S=&]P<&5D)RP*"2=A8W1I;VYL;V=?7W-E<G9I8V5?<F5S
M=&%R="<@/3X@)W)E<W1A<G1E9"<L"@DG86-T:6]N;&]G7U]S97)V:6-E7W-T
M87)T)R`]/B`G<W1A<G1E9"<L"@DG86-T:6]N;&]G7U]L;V=I;B<@/3X@)VQO
M9V=E9"!I;B<L"@DG86-T:6]N;&]G7U]L;V=O=70G(#T^("=L;V=G960@;W5T
M)RP*"2=A8W1I;VYL;V=?7VEN<W1A;&PG(#T^("=I;G-T86QL960G+`H))V%C
M=&EO;FQO9U]?=6YI;G-T86QL)R`]/B`G=6YI;G-T86QL960G+`H))V%C=&EO
M;FQO9U]?<F5C;VYF:6=U<F4G(#T^("=R96-O;F9I9W5R960G+`H*"2=A9&UI
M;E]E9%]?961I=%]A9&UI;FES=')A=&]R7VEN9F\G(#T^(")%9&ET(&%D;6EN
M:7-T<F%T;W(@:6YF;W)M871I;VXB+`H))V%D;6EN7V5D7U]I7W=O=6QD7VQI
M:V5?<F5C:65V95]A;FYO=6YC92<@/3X@(DD@=V]U;&0@;&EK92!T;R!R96-E
M:79E('!E<FEO9&EC(&4M;6%I;',@9G)O;2!35W-O9G0L($EN8RX@86YN;W5N
M8VEN9R!N97<@<')O9'5C=',L(&1I<V-O=6YT<R!A;F0@;6]R92XB+`H))V%D
M;6EN7V5D7U]C<F5A=&5?9&5F875L=%]C;&EE;G0G(#T^("))('=O=6QD(&QI
M:V4@=&\@8W)E871E(&$@9&5F875L="!C;&EE;G0@86-C;W5N="XB+`H))V%D
M;6EN7V5D7U]U;F%B;&5?=7!D871E)R`]/B`B56YA8FQE('1O('5P9&%T92!A
M9&UI;FES=')A=&]R(&EN9F]R;6%T:6]N.B`E,2(L"@DG86YO;F9T<%]?86QL
M;W=?=7!L;V%D7VEN8V]M:6YG)R`]/B`B06QL;W<@=7!L;V%D:6YG('1O(&EN
M8V]M:6YG(&1I<F5C=&]R>2(L"@DG86YO;F9T<%]?86QL;W=?8W)E871E7V1I
M<G,G(#T^("=!;&QO=R!C<F5A=&EO;B!O9B!D:7)E8W1O<FEE<R!I;B!T:&4@
M:6YC;VUI;F<@9&ER96-T;W)Y)RP*"2=A;F]N9G1P7U]A;&QO=U]D;W=N;&]A
M9%]I;F-O;6EN9R<@/3X@)T%L;&]W(&1O=VYL;V%D:6YG(&9R;VT@=&AE(&EN
M8V]M:6YG(&1I<F5C=&]R>2<L"@DG86YO;F9T<%]?86YO;F9T<%]F;W)?9&]M
M86EN)R`]/B`B06YO;GEM;W5S($944"!A8V-O=6YT(&9O<B!T:&4@9&]M86EN
M(BP*"2=A;F]N9G1P7U]D:7-P;&%Y7VQO9VEN)R`]/B`G1&ES<&QA>2!L;V=I
M;B!M97-S86=E)RP*"2=A;F]N9G1P7U]L;V=I;E]T97AT)R`]/B`G365S<V%G
M92!T97AT)RP*"2=A;F]N9G1P7U]L;V=I;E]T97AT7VQI;6ET)R`]/B`B26YV
M86QI9"!M97-S86=E('1E>'0@;&5N9W1H+B!3:&]U;&0@8F4@9G)O;2`Q('1O
M(#8U-3,S(&-H87)A8W1E<G,N(BP*"2=A;F]N9G1P7U]L;V=I;E]T97AT7V%S
M8VEI)R`]/B`B02!M97-S86=E('1E>'0@8V%N(&-O;G1A:6X@;VYL>2!!4T-)
M22!C:&%R86-T97)S+B(L"@DG86YO;F9T<%]?96YA8FQE9%]O;E]O=&AE<E]I
M<"<@/3X@(FES('5S960@;VX@86YO=&AE<B!)4"!A9&1R97-S(BP*"2=A;F]N
M9G1P7U]I;G9A;&ED7V)A;F1W:61T:"<@/3X@(DEN=F%L:60@9&]W;FQO860@
M8F%N9'=I9'1H('9A;'5E+"!O;FQY(&1I9VET<R!A<F4@86QL;W=E9"XB+`H)
M)V%N;VYF='!?7VEN=F%L:61?;6%X7V-O;FXG(#T^("));G9A;&ED(&YU;6)E
M<B!O9B!M87AI;75M('-I;75L=&%N96]U<R!C;VYN96-T:6]N<RP@;VYL>2!D
M:6=I=',@87)E(&%L;&]W960B+`H))V%N;VYF='!?7VEN=F%L:61?<75O=&$G
M(#T^("));G9A;&ED(&1I<VL@<W!A8V4@=F%L=64L(&]N;'D@9&EG:71S(&%R
M92!A;&QO=V5D+B(L"@DG86YO;F9T<%]?:7!?861D<F5S7W1Y<&5?<VAA<F5D
M)R`]/B`B2&]S=&EN9R!I<R!B87-E9"!O;B!T:&4@<VAA<F5D(&EP(&%D9')E
M<W,N(BP*"2=A;F]N9G1P7U]L:6UI=%]I;F-O;6EN9U]D:7-K7W-P86-E)R`]
M/B`B3&EM:70@9&ES:R!S<&%C92!I;B!T:&4@:6YC;VUI;F<@9&ER96-T;W)Y
M(BP*"2=A;F]N9G1P7U]L:6UI=%]M87AI;75M7V)A;F1W:61T:"<@/3X@(DQI
M;6ET(&1O=VYL;V%D(&)A;F1W:61T:"!F;W(@=&AI<R!V:7)T=6%L($944"!D
M;VUA:6XB+`H))V%N;VYF='!?7VQI;6ET7VUA>&EM=6U?8V]N;F5C=&EO;G,G
M(#T^("),:6UI="!N=6UB97(@;V8@<VEM=6QT86YE;W5S(&-O;FYE8W1I;VYS
M(BP*"2=A;F]N9G1P7U]U;F%B;&5?8W)E871E)R`]/B`B56YA8FQE('1O(&-R
M96%T92!A;F]N>6UO=7,@1E10(&%C8V]U;G0Z("4Q(BP*"2=A;F]N9G1P7U]U
M;F%B;&5?96YA8FQE)R`]/B`B1F%I;&5D('1O(&5N86)L92!A;F]N>6UO=7,@
M1E10(&%C8V]U;G0Z("4Q(BP*"2=A;F]N9G1P7U]U;F%B;&5?:6YI="<@/3X@
M(E5N86)L92!T;R!I;FET:6%L:7IE(&%N;VYY;6]U<R!&5%`@86-C;W5N=#H@
M)3$B+`H))V%N;VYF='!?7W5N86)L95]P=71?8V]N9B<@/3X@(E5N86)L92!T
M;R!P=70@8V]N9FEG=7)A=&EO;B!F:6QE.B`E,2(L"@DG86YO;F9T<%]?=6YA
M8FQE7W-E=%]Q=6]T82<@/3X@(E5N86)L92!T;R!S970@=&AE(&EN8V]M:6YG
M(&1I<F5C=&]R>2!D:7-K('-P86-E(&QI;6ET.B`E,2(L"@DG86YO;F9T<%]?
M=6YA8FQE7W5P9&%T92<@/3X@(E5N86)L92!T;R!U<&1A=&4@86YO;GEM;W5S
M($944"!A8V-O=6YT('!R;W!E<G1I97,Z("4Q(BP*"2=A=71H7U]U<&1A=&5?
M861M:6Y?:6YF;R<@/3X@(E!L96%S92!E;G1E<B!A9&UI;FES=')A=&]R)W,@
M:6YF;W)M871I;VXN(%1H:7,@:6YF;W)M871I;VX@:7,@<F5Q=6ER960@=&\@
M;W!E<F%T92`E,2XB+`H))V%U=&A?7W5P9&%T95]C;%]E;6%I;%]A;F1?<&AO
M;F4G(#T^(")0;&5A<V4@96YT97(@>6]U<B!E+6UA:6P@86YD('!H;VYE(&YU
M;6)E<BX@5&AE>2!W:6QL(&)E('5S960@=&\@;F]T:69Y('EO=2!O9B!P;W-S
M:6)L92!P<F]B;&5M<RXB+`H))V%U=&A?7WEO=5]N;W1?:&%V95]P97)M)R`]
M/B`B66]U(&1O(&YO="!H879E('!E<FUI<W-I;VYS('1O(&UA;F%G92!T:&ES
M(&1O;6%I;BXB+`H))V%U=&A?7VME>5]E>'!I<F5D7V%D;6EN)R`]/B`G66]U
M<B!L:6-E;G-E(&ME>2!H87,@97AP:7)E9"X@5&\@8V]N=&EN=64@=7-I;F<@
M>6]U<B!#;VYT<F]L(%!A;F5L('EO=2!M=7-T('!U<F-H87-E(&$@;F]N+65X
M<&ER:6YG(&-O;6UE<F-I86P@;&EC96YS92XG+`H))V%U=&A?7VME>5]E>'!I
M<F5D7V-L:65N="<@/3X@)U1H92!L:6-E;G-E(&ME>2!H87,@97AP:7)E9"X@
M4&QE87-E(&-O;G1A8W0@>6]U<B!S97)V:6-E('!R;W9I9&5R+B<L"@DG875T
M;VEN<W1A;&QE<E]?;F]T7VEN<W1A;&QE9"<@/3X@)T%U=&]I;G-T86QL97(@
M8V]M<&]N96YT(&ES(&YO="!I;G-T86QL960N)RP*"2=A=71O:6YS=&%L;&5R
M7U]R96QE87-E7V%C=&EO;B<@/3X@)T%V86EL86)L92!O<&5R871I;VYS)RP*
M"2=A=71O:6YS=&%L;&5R7U]R96QE87-E7V%C=&EO;E]I8V]N)R`]/B`G4R<L
M"@DG875T;VEN<W1A;&QE<E]?<F5L96%S95]A8W1I;VY?=7!G<F%D92<@/3X@
M)U5P9W)A9&EN9R!T;R!T:&4@;F5W(&-O;G1R;VP@<&%N96P@=F5R<VEO;B<L
M"@DG875T;VEN<W1A;&QE<E]?<F5L96%S95]A8W1I;VY?=7!D871E)R`]/B`G
M57!D871I;F<@;W(@861D:6YG(&YE=R!C;VUP;VYE;G1S)RP*"2=A=71O:6YS
M=&%L;&5R7U]R96QE87-E7V%C=&EO;E]U<#)D871E)R`]/B`G66]U(&AA=F4@
M86X@=7`@=&\@9&%T92!V97)S:6]N)RP*"2=A=71O:6YS=&%L;&5R7U]C;VUP
M;VYE;G1?86-T:6]N)R`]/B`G4W1A='5S)RP*"2=A=71O:6YS=&%L;&5R7U]C
M;VUP;VYE;G1?86-T:6]N7VEC;VXG(#T^("=3)RP*"2=A=71O:6YS=&%L;&5R
M7U]C;VUP;VYE;G1?86-T:6]N7VEN<W1A;&PG(#T^("=.;W0@:6YS=&%L;&5D
M)RP*"2=A=71O:6YS=&%L;&5R7U]C;VUP;VYE;G1?86-T:6]N7W5P9&%T92<@
M/3X@)T%N('5P9&%T92!I<R!A=F%I;&%B;&4G+`H))V%U=&]I;G-T86QL97)?
M7V-O;7!O;F5N=%]A8W1I;VY?=7!G<F%D92<@/3X@)T%N('5P9&%T92!I<R!A
M=F%I;&%B;&4G+`H))V%U=&]I;G-T86QL97)?7V-O;7!O;F5N=%]A8W1I;VY?
M=7`R9&%T92<@/3X@)UEO=2!H879E(&%N('5P('1O(&1A=&4@=F5R<VEO;B<L
M"@DG875T;VEN<W1A;&QE<E]?8V]M<&]N96YT7V%C=&EO;E]E<G)O<B<@/3X@
M)U5P9&%T97,@87)E(&YO="!A=F%I;&%B;&4G+`H))V%U=&]I;G-T86QL97)?
M7V-O;7!O;F5N=%]S97)V97)B=6EL9'1I;64G(#T^("=,871E<W0@<F5L96%S
M92<L"@DG875T;VEN<W1A;&QE<E]?8V]M<&]N96YT7VQO8V%L8G5I;&1T:6UE
M)R`]/B`G66]U<B!R96QE87-E)RP*"2=A=71O:6YS=&%L;&5R7U]C;VUP;VYE
M;G0G(#T^("=#;VUP;VYE;G0G+`H))V%U=&]I;G-T86QL97)?7V-O;7!O;F5N
M=',G(#T^("=#;VUP;VYE;G1S)RP*"2=A=71O:6YS=&%L;&5R7U]C;VUP;VYE
M;G1S7W1I=&QE)R`]/B`G)3$@0V]M<&]N96YT<R<L"@DG875T;VEN<W1A;&QE
M<E]?8V]M<&]N96YT7V1E<&5N9&5N8WE?;F]T92<@/3X@)W)E<75I<F5D(&9O
M<B!I;G-T86QL871I;VX@;V8@=&AE(&-O;7!O;F5N=',@>6]U('-E;&5C=&5D
M)RP*"2=A=71O:6YS=&%L;&5R7U]I;G-T86QL7V-O;F9I<FTG(#T^("=997,L
M($D@=VES:"!T;R!I;G-T86QL('1H97-E(&-O;7!O;F5N=',G+`H))V%U=&]I
M;G-T86QL97)?7VEN<W1A;&Q?8V]N9FER;5]R97%U97-T)R`]/B`G4&QE87-E
M('-E;&5C="!T:&4@8VAE8VMB;W@@=&\@8V]N9FER;2XG+`H))V%U=&]I;G-T
M86QL97)?7VEN<W1A;&Q?=&ET;&4G(#T^("=#;VYF:7)M($EN<W1A;&QA=&EO
M;B!O9B!T:&4@4V5L96-T960@0V]M<&]N96YT<R<L"@DG875T;VEN<W1A;&QE
M<E]?:V5R;F5L7W5P9&%T95]C;VYF:7)M)R`]/B`G0V]N9FER;2!T:&4@:V5R
M;F5L('5P9&%T92<L"@DG875T;VEN<W1A;&QE<E]?:V5Y7W5P9&%T95]C;VYF
M:7)M)R`]/B`G0V]N9FER;2!S:VEP<&EN9R!K97D@=7!D871E(&%N9"!I;G-T
M86QL:6YG('1H92!D969A=6QT(&ME>2<L"@DG875T;VEN<W1A;&QE<E]?:V5Y
M7W5P9&%T95]C;VYF:7)M7W)E<75E<W0G(#T^("=0;&5A<V4@8VAE8VL@=&AE
M(&-H96-K8F]X('1O(&-O;F9I<FTN)RP*"2=A=71O:6YS=&%L;&5R7U]K97E?
M=7!D871E7V9A:6QE9"<@/3XG/'`^4&QE<VL@:7,@=6YA8FQE('1O('5P9&%T
M92!Y;W5R('!R;V1U8W0@;&EC96YS92X\+W`^)PH)"2X@)SQP/B4Q/"]P/B<*
M"0DN("<\<#Y#;VYT:6YU:6YG('=I=&@@=&AE('5P9W)A9&4@=VET:&]U="!H
M879I;F<@86X@87!P<F]P<FEA=&4@<')O9'5C="!L:6-E;G-E('=I;&P@<F5S
M=6QT(&EN('1H92!I;G-T86QL871I;VX@;V8@82!D969A=6QT(&QI8V5N<V4@
M=VET:"!L:6UI=&5D(&9U;F-T:6]N86QI='DN($%D;6EN:7-T<F%T;W)S(&%R
M92!A9'9I<V5D('1O(&9I<G-T(&%C<75I<F4@=&AE(&%P<')O<')I871E(&QI
M8V5N<V4@8F5F;W)E(&-O;G1I;G5I;F<@=VET:"!T:&4@<')O9'5C="!U<&=R
M861E+CPO<#XG+`H))V%U=&]I;G-T86QL97)?7V5M86EL)R`]/B`G4V5N9"!N
M;W1I8V4@=&\G+`H))V%U=&]I;G-T86QL97)?7V5M86EL7V%D;6EN)R`]/B`B
M061M:6YI<W1R871O<B=S(&4M;6%I;"(L"@DG875T;VEN<W1A;&QE<E]?96UA
M:6Q?96UA:6PG(#T^("=#=7-T;VT@92UM86EL(&%D9')E<W,N+BXG+`H))V%U
M=&]I;G-T86QL97)?7W)E;&5A<V4G(#T^("=296QE87-E(&YA;64G+`H))V%U
M=&]I;G-T86QL97)?7W)E;&5A<V5S)R`]/B`G079A:6QA8FQE(')E;&5A<V5S
M)RP*"2=A=71O:6YS=&%L;&5R7U]R96QE87-E<U]T:71L92<@/3X@)U!L97-K
M(%5P9&%T97(G+`H))V%U=&]I;G-T86QL97)?7W-E;&5C=%]C;VUP;VYE;G1S
M7W1O7VEN<W1A;&PG(#T^("=396QE8W0@=&AE(&-O;7!O;F5N=',@=&\@8F4@
M:6YS=&%L;&5D)RP*"2=A=71O:6YS=&%L;&5R7U]S=&%T=7-?97)R;W(G(#T^
M("=%<G)O<CH@)3$N)RP*"2=A=71O:6YS=&%L;&5R7U]S=&%T=7-?:6YS=&%L
M;%]E<G)O<B<@/3X@)TEN<W1A;&QA=&EO;B!C;W5L9"!N;W0@8F4@<W1A<G1E
M9#H@)3$N)RP*"2=A=71O:6YS=&%L;&5R7U]S=&%T=7-?:6YS=&%L;%]B=7-Y
M)R`]/B`G26YS=&%L;&%T:6]N(&-O=6QD(&YO="!B92!S=&%R=&5D.B!A;F]T
M:&5R(&EN<W1A;&QA=&EO;B!P<F]C961U<F4@:7,@8W5R<F5N=&QY(')U;FYI
M;F<N)RP*"2=A=71O:6YS=&%L;&5R7U]S=&%T=7-?:6YS=&%L;%]O:R<@/3X@
M)TEN<W1A;&QA=&EO;B!S=&%R=&5D+B!9;W4@=VEL;"!B92!N;W1I9FEE9"!O
M9B!I;G-T86QL871I;VX@<')O9W)E<W,@8GD@92UM86EL("@E,2DN)RP*"2=A
M=71O:6YS=&%L;&5R7U]S=&%T=7-?<75E<GE?8G5S>2<@/3X@)TEN<W1A;&QA
M=&EO;B!I<R!I;B!P<F]G<F5S<RXG+`H))V%U=&]I;G-T86QL97)?7W-T871U
M<U]Q=65R>5]E<G)O<B<@/3X@)U5N86)L92!T;R!R971R:65V92!I;G-T86QL
M871I;VX@<W1A='5S.B`E,2<L"@DG875T;VEN<W1A;&QE<E]?8V]N9FEG=7)E
M7W1I=&QE)R`]/B`G57!D871E<B!3971T:6YG<R<L"@DG875T;VEN<W1A;&QE
M<E]?<')E9F5R96YC97-?;&5G96YD)R`]/B`G4V5T=&EN9W,G+`H))V%U=&]I
M;G-T86QL97)?7W-O=7)C95]T>7!E)R`]/B`G4V]U<F-E('1Y<&4G+`H))V%U
M=&]I;G-T86QL97)?7W-O=7)C95]T>7!E7VEN=F%L:60G(#T^("=);G9A;&ED
M('-O=7)C92!T>7!E)RP*"2=A=71O:6YS=&%L;&5R7U]S;W5R8V5?='EP95]P
M;&5S:R<@/3X@)U!L97-K('5P9&%T92!S97)V97(G+`H))V%U=&]I;G-T86QL
M97)?7W-O=7)C95]T>7!E7VYE='=O<FLG(#T^("=.971W;W)K('-T;W)A9V4G
M+`H))V%U=&]I;G-T86QL97)?7W-O=7)C95]I;G9A;&ED)R`]/B`G26YV86QI
M9"!S;W5R8V4G+`H))V%U=&]I;G-T86QL97)?7W-O=7)C95]I;G9A;&ED7VYE
M='=O<FLG(#T^("=);G9A;&ED('-O=7)C92!54DP@*'-A;7!L93H@:'1T<#HO
M+W-O=7)C92P@9G1P.B\O<V]U<F-E*2<L"@DG875T;VEN<W1A;&QE<E]?<V]U
M<F-E)R`]/B`G4V]U<F-E(%523"<L"@DG875T;VEN<W1A;&QE<E]?=&%R9V5T
M)R`]/B`G5&5M<&]R87)Y(&1O=VYL;V%D(&1I<F5C=&]R>2<L"@DG875T;VEN
M<W1A;&QE<E]?=&%R9V5T7VEN=F%L:60G(#T^(")3<&5C:69Y(&%B<V]L=71E
M('!A=&@B+`H))V%U=&]I;G-T86QL97)?7V-H96-K7W5P9&%T97,G(#T^("=#
M:&5C:R!F;W(@=7!D871E<R!U<&]N(&%D;6EN:7-T<F%T;W)<)W,@;&]G:6X@
M=&\@8V]N=')O;"!P86YE;"XG+`H))V%U=&]I;G-T86QL97)?7V-H96-K7W5P
M9&%T97-?=V%R;FEN9R<@/3X@)TYE=R`\82!H<F5F/2(E,2(^=7!D871E<SPO
M83X@87)E(&%V86EL86)L92!F;W(@)3(@)RP*"2=B86-K=7!?7W!E<FEO9"<)
M/3X@)T)A8VMU<"!P97)I;V0G+`H))V)A8VMU<%]?<F5P;W-I=&]R>2<]/B`G
M0F%C:W5P(&9I;&5S(')E<&]S:71O<GD@;&]C871I;VXG+`H))V)A8VMU<%]?
M;6%X7V1U;7!?9FEL97,G"3T^("=.=6UB97(@;V8@8F%C:W5P(&9I;&5S('-T
M;W)E9"!I;B!R97!O<VET;W)Y)RP*"2=B86-K=7!?7V9I;&5N86UE7W!R969I
M>"<]/B`G061D('!R969I>"!T;R!B86-K=7`@9FEL92!N86UE<R<L"@DG8F%C
M:W5P7U]E<G)O<E]N;W1I9GE?96UA:6PG(#T^("=396YD(&YO=&EF:6-A=&EO
M;B!O;B!E<G)O<G,@:68@86YY(&]C8W5R(&1U<FEN9R!B86-K=7`@=&\@96UA
M:6PG+`H))V)A8VMU<%]?9'5M<%]I;F9O)R`]/B`B0F%C:W5P(&EN9F]R;6%T
M:6]N(BP*"2=B86-K=7!?7V1U;7!?9FEL95]N86UE7VYO=%]D969I;F5D)R`]
M/B`B0F%C:W5P(&9I;&4@;F%M92!I<R!N;W0@<W!E8VEF:65D(BP*"2=B86-K
M=7!?7V9T<%]A8V-O=6YT)R`]/B`B1E10(&%C8V]U;G0@9F]R(')E;6]T92!R
M97!O<VET;W)Y(BP*"2=B86-K=7!?7V-R;VY?8F%C:W5P7W1A<VM?<')E9G,G
M(#T^(")38VAE9'5L960@0F%C:W5P(BP*"2=B86-K=7!?7V9T<%]A8V-O=6YT
M7V9O<E]B86-K=7`G(#T^(")&5%`@86-C;W5N="!P<F5F97)E;F-E<R(L"@DG
M8F%C:W5P7U]L;V-A;%]F:6QE)R`]/B`G3&]C86P@8F%C:W5P(&9I;&4G+`H)
M)V)A8VMU<%]?9&]M86EN7V1U;7!S)R`]/B`G;&]C86P@<F5P;W-I=&]R>2<L
M"@DG8F%C:W5P7U]D;VUA:6Y?9G1P)R`]/B`G<F5M;W1E($944"!S97)V97(G
M+`H))V)A8VMU<%]?=W)O;F=?<&%T:"<@/3X@(DEN8V]R<F5C="!P871H('1O
M('1H92!B86-K=7`@9FEL97,@<F5P;W-I=&]R>3H@1&\@;F]T('5S92!T:&4@
M<V5Q=65N8V4@;V8@8VAA<F%C=&5R<R`N+B\N+B\B+`H))V)A8VMU<%]?=6YA
M8FQE7W1O7V-O;FYE8W1?=&]?9G1P7W-E<G9E<B<]/B`B56YA8FQE('1O(&-O
M;FYE8W0@=&\@1E10('-E<G9E<CH@)3$B+`H))V)A8VMU<%]?8F%C:W5P7W1A
M<VM?9&]E<U]N;W1?97AI<W0G(#T^(")"86-K=7`@=&%S:R!D;V5S(&YO="!E
M>&ES="P@>6]U('-H;W5L9"!C<F5A=&4@:70@8F5F;W)E('1U<FYI;F<@;VXN
M(BP*"2=B86-K=7!?7W)E<W1O<F5?<&%R86US)R`]/B`B4F5S=&]R92!P87)A
M;65T97)S(BP*"2=B86-K=7!?7V-O;F9I<FUA=&EO;B<@/3X@(E=A<FYI;F<Z
M('1H92!D;VUA:6X@=VEL;"!N;W0@8F4@879A:6QA8FQE(&1U<FEN9R!B86-K
M=7`O<F5S=&]R:6YG+B(L"@DG8F%C:W5P7U]D=6UP9FEL95]I<U]N;W1?97AI
M<W0G(#T^(")"86-K=7`@9FEL92!D;V5S(&YO="!E>&ES="XB+`H))V)A8VMU
M<%]?8F%C:W5P7VUE=&AO9"<)/3X@)T)A8VMU<"!M971H;V0G+`H))V)A8VMU
M<%]?9'5M<&9I;&5?;F%M92<@/3X@(D)A8VMU<"!F:6QE(&YA;64B+`H))V)A
M8VMU<%]?9'5M<&9I;&5?;F%M95]I<U]I;G9A;&ED)R`]/B`B0F%C:W5P(&9I
M;&4@;F%M92!I<R!I;G9A;&ED.B!5<V4@;VYL>2!A;'!H86YU;65R:6,L(&1A
M<V@L(&1O="!A;F0@=6YD97)S8V]R92!S>6UB;VQS+"!D;R!N;W0@=7-E(&YA
M;64@;&EK92!D97-C<FEP=&EO;BXJ(&%S(&)A8VMU<"!F:6QE(&YA;64N(BP*
M"2=B86-K=7!?7V1U;7!F:6QE7VYA;65?:7-?;F]T7V1E9FEN960G(#T^(")"
M86-K=7`@9FEL92!N86UE(&ES('5N9&5F:6YE9"XB+`H))V)A8VMU<%]?96UA
M:6Q?<F5Q=6ER960G(#T^(")9;W5R(&4M;6%I;"!A9&1R97-S(&ES(')E<75I
M<F5D('1O(&ME97`@>6]U(&EN9F]R;65D(&]F('1H92!B86-K=7`O<F5S=&]R
M:6YG('!R;V-E9'5R92!P<F]G<F5S<RX@4&QE87-E('-P96-I9GD@>6]U<B!E
M+6UA:6P@:6X@=&AE(&%C8V]U;G0@9&5T86EL<RXB+`H))V)A8VMU<%]?97)R
M;W)?9'5R:6YG7V)A8VMU<"<@/3X@(E5N86)L92!T;R!C<F5A=&4@=&AE(&)A
M8VMU<"!F:6QE.B`E,2(L"@DG8F%C:W5P7U]I;G!U=%]E;6%I;%]W87)N:6YG
M)R`]/B`B66]U('-H;W5L9"!E:71H97(@<W!E8VEF>2!E+6UA:6P@9F]R(&YO
M=&EF:6-A=&EO;B!O<B!D97-E;&5C="!T:&4@8VAE8VMB;W@N(BP*"2=B86-K
M=7!?7VUA:V5?9&]W;FQO860G(#T^(")D;R!N;W0@<W1O<F4@=&AE(&)A8VMU
M<"!F:6QE(&EN(')E<&]S:71O<GDL(&]N;'D@9&]W;FQO860@:70B+`H))V)A
M8VMU<%]?;6%K95]D=6UP)R`]/B`G8W)E871E(&)A8VMU<"!F:6QE(&%N9"!S
M=&]R92!I;B!L;V-A;"!R97!O<VET;W)Y)RP*"2=B86-K=7!?7VUA:V5D=6UP
M7W1O7V9T<"<@/3X@)V-R96%T92!B86-K=7`@9FEL92!A;F0@<W1O<F4@;VX@
M<F5M;W1E($944"!S97)V97(G+`H))V)A8VMU<%]?9G1P7W-E<G9E<B<@/3X@
M(D944"!S97)V97(B+`H))V)A8VMU<%]?9G1P7V)A<V5D:7(G(#T^(")0871H
M('1O(&)A8VMU<"!F:6QE<R!R97!O<VET;W)Y(&]N($944"!S97)V97(B+`H)
M)V)A8VMU<%]?;F]T:69I8V%T:6]N7V5M86EL)R`]/B`B3F]T:69Y(&)Y(&4M
M;6%I;"(L"@DG8F%C:W5P7U]N;W1I9GE?96UA:6Q?:7-?:6YV86QI9"<@/3X@
M(DEN8V]R<F5C="!E+6UA:6P@861D<F5S<R!F;W(@8F%C:W5P+W)E<W1O<FEN
M9R!P<F]G<F5S<R!N;W1I9FEC871I;VX@:7,@<W!E8VEF:65D+B(L"@DG8F%C
M:W5P7U]R97-T;W)E7VEP)R`]/B`B25`@861D<F5S<R!F;W(@<F5S=&]R871I
M;VXB+`H))V)A8VMU<%]?<V5L96-T7V1U;7!F:6QE)R`]/B`B4V5L96-T(&$@
M8F%C:W5P(&9I;&4N(BP*"2=B86-K=7!?7W1I;64G(#T^(")"86-K=7`@=&EM
M92(L"@DG8F%C:W5P7U]V:65W7V1U;7!?:6YF;R<@/3X@(E9I97<@=&AE(&)A
M8VMU<"!I;F9O<FUA=&EO;B!F;W(@9&]M86EN("4Q(BP*"2=B86-K=7!?7W=R
M;VYG7V1O;6%I;E]N86UE)R`]/B`B5&AE(&)A8VMU<"!F:6QE(&-O;G1A:6YS
M('1H92!D871A(&]F(&1O;6%I;B`E,2!A;F0@=&AE<F5F;W)E(&-A;FYO="!B
M92!R97-T;W)E9"!O;B!D;VUA:6X@)3(B+`H))V)A8VMU<%]?:6YC;W)R96-T
M7V9T<%]U<V5R7V]R7W!A<W-W9"<@/3X@(DEN8V]R<F5C="!&5%`@=7-E<B!O
M<B!P87-S=V]R9"X@4&QE87-E(&-O<G)E8W0@1E10($%C8V]U;G0@4')O<&5R
M=&EE<R(L"@DG8F%C:W5P7U]A8V-E<W-?9&5N:65D)R`]/B`B06-C97-S(&1E
M;FEE9"X@4&QE87-E(&-O<G)E8W0@1E10($%C8V]U;G0@4')O<&5R=&EE<R(L
M"@DG8F%C:W5P7U]C;W5L9&YO=%]R97-O;'9E7VAO<W0G(#T^(")#;W5L9&XG
M="!R97-O;'9E(&AO<W0@)3$B+`H))V)A8VMU<%]?<F5S=&]R95]F<F]M)R`]
M/B`B4F5S=&]R92`E,2(L"@DG8F%C:W5P7U]D;VUA:6Y?<V5S<VEO;E]F86EL
M960G(#T^("=$;VUA:6X@)3$@=V%S(&YO="!B86-K960@=7`G+`H))V)A8VMU
M<%]?8VQI96YT7W-E<W-I;VY?9F%I;&5D)R`]/B`G0VQI96YT("4Q('=A<R!N
M;W0@8F%C:V5D('5P)RP*"2=B86-K=7!?7V1O;6%I;E]S97-S:6]N7W)E<W1O
M<F5?9F%I;&5D)R`]/B`G1&]M86EN("4Q('=A<R!N;W0@<F5S=&]R960G+`H)
M)V)A8VMU<%]?8VQI96YT7W-E<W-I;VY?<F5S=&]R95]F86EL960G(#T^("=#
M;&EE;G0@)3$@=V%S(&YO="!R97-T;W)E9"<L"@DG8F%C:W5P7U]D;VUA:6Y?
M<V5S<VEO;E]C;VUP;&5T92<@/3X@)T1O;6%I;B`E,2!W87,@8F%C:V5D('5P
M)RP*"2=B86-K=7!?7V1O;6%I;E]S97-S:6]N7V)A8VMU<"<@/3X@)T)A8VMU
M<"!O9B!D;VUA:6X@)3$G+`H))V)A8VMU<%]?8VQI96YT7W-E<W-I;VY?8F%C
M:W5P)R`]/B`G0F%C:W5P(&]F(&-L:65N="`E,2<L"@DG8F%C:W5P7U]D;VUA
M:6Y?<W1O<%]T:71L92<@/3X@)T-A;F-E;&QI;F<@8F%C:W5P(&]F(&1O;6%I
M;B`E,2<L"@DG8F%C:W5P7U]C;&EE;G1?<W1O<%]T:71L92<@/3X@)T-A;F-E
M;&QI;F<@8F%C:W5P(&]F(&-L:65N="`E,2<L"@DG8F%C:W5P7U]D;VUA:6Y?
M<F5S=&]R95]S=&]P7W1I=&QE)R`]/B`G0V%N8V5L;&QI;F<@<F5S=&]R92!O
M9B!D;VUA:6X@)3$G+`H))V)A8VMU<%]?8VQI96YT7W)E<W1O<F5?<W1O<%]T
M:71L92<@/3X@)T-A;F-E;&QI;F<@<F5S=&]R92!O9B!C;&EE;G0@)3$G+`H)
M)V)A8VMU<%]?9&]M86EN7W-E<W-I;VY?8F%C:W5P7W-T;W`G(#T^("=9;W4@
M87)E(&%B;W5T('1O(&-A;F-E;"!T:&4@86-T:79E(&)A8VMU<"!P<F]C97-S
M(2!"86-K=7`@9FEL92!W:6QL(&YO="!B92!C<F5A=&5D+B<L"@DG8F%C:W5P
M7U]B86-K=7!?<W1O<%]C;VYF:7)M)R`]/B`G665S+"!)('=A;G0@=&\@<W1O
M<"!T:&4@8F%C:W5P('!R;V-E<W,G+`H))V)A8VMU<%]?<F5S=&]R95]S=&]P
M7V-O;F9I<FTG(#T^("=997,L($D@=V%N="!T;R!S=&]P('1H92!R97-T;W)E
M('!R;V-E<W,G+`H))V)A8VMU<%]?9&]M86EN7W-E<W-I;VY?<F5S=&]R92<@
M/3X@)U)E<W1O<F4@;V8@9&]M86EN("4Q)RP*"2=B86-K=7!?7V1O;6%I;E]S
M97-S:6]N7W)E<W1O<F5?<W1O<"<@/3X@)UEO=2!A<F4@86)O=70@=&\@8V%N
M8V5L('1H92!A8W1I=F4@<F5S=&]R92!P<F]C97-S(2<L"@DG8F%C:W5P7U]D
M;VUA:6Y?8F%C:W5P7V9I;&5?:6YF;R<@/3X@)T1O;6%I;B!"86-K=7`@1FEL
M92!);F9O<FUA=&EO;B<L"@DG8F%C:W5P7U]D;VUA:6Y?8F%C:W5P7V9I;&5?
M;&ES="<@/3X@)V5X:7-T:6YG(&)A8VMU<"!F:6QE<R<L"@DG8F%C:W5P7U]D
M;VUA:6Y?8F%C:W5P7W!R;V=R97-S)R`]/B`G4')O9W)E<W,@;V8@9&]M86EN
M("4Q(&)A8VMU<"<L"@DG8F%C:W5P7U]D;VUA:6Y?<F5S=&]R95]P<F]G<F5S
M<R<@/3X@)U!R;V=R97-S(&]F(&1O;6%I;B`E,2!R97-T;W)E)RP*"2=B86-K
M=7!?7V1O;6%I;E]B86-K=7!?<')O9W)E<W-?96QA<'-E9%]T:6UE)R`]/B`G
M16QA<'-E9"!T:6UE.B`E,2<L"@DG8F%C:W5P7U]D;VUA:6Y?<F5S=&]R95]P
M<F]G<F5S<U]E;&%P<V5D7W1I;64G(#T^("=%;&%P<V5D('1I;64Z("4Q)RP*
M"2=B86-K=7!?7VEP7VUA<%]L96=E;F0G(#T^("=)4"!-87!P:6YG)RP*"2=B
M86-K=7!?7VEP7VUA<%]L:7-T7V-O=6YT)R`]/B`G25`@061D<F5S<V5S)RP*
M"2=B86-K=7!?7V1O;6%I;E]R97-T;W)E7W-E<W-I;VY?8V]M<&QE=&4G(#T^
M("=$;VUA:6X@)3$@:7,@<F5S=&]R960G+`H))V)A8VMU<%]?9&]M86EN7W)E
M<W1O<F5?<V5S<VEO;E]C;VUP;&5T95]M97-S86=E)R`]/B`G1&]M86EN("4Q
M(&AA<R!B965N(')E<W1O<F5D)RP*"2=B86-K=7!?7V1O;6%I;E]B86-K=7!?
M9FEL95]D96QE=&4G(#T^("=4:&4@9F]L;&]W:6YG(&)A8VMU<"!F:6QE<R!W
M:6QL(&)E(')E;6]V960Z)RP*"2=B86-K=7!?7V1O;6%I;E]B86-K=7!?9FEL
M95]F;W)?<F5M;W9E)R`]/B`G4V5L96-T(&)A8VMU<"!F:6QE<R!Y;W4@=VES
M:"!T;R!R96UO=F4G+`H))V)A8VMU<%]?8F%C:W5P7V]V97)W<FET95]F:6QE
M7V-O;F9I<FTG(#T^("=297!L86-E;65N="!C;VYF:7)M871I;VXG+`H))V)A
M8VMU<%]?8F%C:W5P7V]V97)W<FET95]F:6QE7V-O;F9I<FU?=&5X="<@/3X@
M)T)A8VMU<"!F:6QE('=I=&@@=&AE(&YA;64@(B4Q(B!A;')E861Y(&5X:7-T
M<RX@1&\@>6]U('=A;G0@=&\@<F5P;&%C92!I=#\G+`H))V)A8VMU<%]?8F%C
M:W5P7V-O;F9I<FU?;W9E<G=R:71E)R`]/B`G0V]N9FER;2!F:6QE(')E<&QA
M8V5M96YT)RP*"2=B86-K=7!?7V)A8VMU<%]O=F5R=W)I=&5?;&5G96YG)R`]
M/B`G4F5P;&%C92<L"@DG8F%C:W5P7U]B86-K=7!?;F]T7V-O;G1A:6Y?9&]M
M86EN)R`]/B`G0F%C:W5P(&9I;&4@9&]E<R!N;W0@8V]N=&%I;B!I;F9O<FUA
M=&EO;B!A8F]U="!D;VUA:6X@)3$G+`H))V)A8VMU<%]?8F%C:W5P7VYO=%]C
M;VYT86EN7V-L:65N="<@/3X@)T)A8VMU<"!F:6QE(&1O97,@;F]T(&-O;G1A
M:6X@:6YF;W)M871I;VX@86)O=70@8VQI96YT("4Q)RP*"2=B86-K=7!?7V)A
M8VMU<%]C;&EE;G1?:6YF;R<@/3X@(D)A8VMU<"!C;&EE;G0G<R!P<F5F97)E
M;F-E<R!A;F0@86-C;W5N="!D971A:6QS(BP*"2=B86-K=7!?7V-L:65N=%]B
M86-K=7!?<')O9W)E<W,G(#T^("=0<F]G<F5S<R!O9B!#;&EE;G0@)3$@0F%C
M:W5P)RP*"2=B86-K=7!?7V-L:65N=%]S97-S:6]N7V-O;7!L971E)R`]/B`G
M0VQI96YT("4Q(&ES(&)A8VME9"!U<"<L"@DG8F%C:W5P7U]C;&EE;G1?8F%C
M:W5P7V9I;&5?:6YF;R<@/3X@)T-L:65N="!"86-K=7`@1FEL92!);F9O<FUA
M=&EO;B<L"@DG8F%C:W5P7U]R97-T;W)E7V-L:65N=%]I;F9O)R`]/B`B4F5S
M=&]R92!C;&EE;G0G<R!P<F5F97)E;F-E<R!A;F0@86-C;W5N="!D971A:6QS
M(BP*"2=B86-K=7!?7V-L:65N=%]S97-S:6]N7W)E<W1O<F4G(#T^("=297-T
M;W)I;F<@0VQI96YT("4Q)RP*"2=B86-K=7!?7V-L:65N=%]D8E]S97)V97)?
M;6%P)R`]/B`G1&%T86)A<V4@4V5R=F5R<R!-87!P:6YG)RP*"2=B86-K=7!?
M7V1O;6%I;E]D8E]S97)V97)?;6%P)R`]/B`G1&%T86)A<V4@4V5R=F5R<R!-
M87!P:6YG)RP*"2=B86-K=7!?7V-L:65N=%]R97-T;W)E7W-E<W-I;VY?8V]M
M<&QE=&5?;65S<V%G92<@/3X@)T-L:65N="`E,2!H87,@8F5E;B!R97-T;W)E
M9"XG+`H))V)A8VMU<%]?8VQI96YT7W)E<W1O<F5?<V5S<VEO;E]C;VUP;&5T
M92<@/3X@)T-L:65N="`E,2!R97-T;W)E9"<L"@DG8F%C:W5P7U]R97-T;W)E
M7W-E;&5C=%]S;VUE)R`]/B`G4&QE87-E('-E;&5C="!O8FIE8W1S('EO=2!W
M:7-H('1O(')E<W1O<F4N)RP*"2=B86-K=7!?7V-L:65N=%]R97-T;W)E7W!R
M;V=R97-S)R`]/B`G4')O9W)E<W,@;V8@0VQI96YT("4Q(%)E<W1O<F4G+`H)
M)V)A8VMU<%]?;F5W7V)A8VMU<"<@/3X@)T-R96%T:6YG($YE=R!"86-K=7`G
M+`H))V)A8VMU<%]?9&]N92<@/3X@)T1O;F4Z)RP*"2=B86-K=7!?7V1O;F5?
M9&]M86EN<R<@/3X@)R4Q(&1O;6%I;BAS*2!O=70@;V8@)3(G+`H))V)A8VMU
M<%]?9&]N95]C;&EE;G1S)R`]/B`G)3$@8VQI96YT*',I(&]U="!O9B`E,B<L
M"@DG8F%C:W5P7U]R96UA:6YI;F<G(#T^("=296UA:6YI;F<Z)RP*"2=B86-K
M=7!?7W)E;6%I;FEN9U]D;VUA:6YS)R`]/B`G)3$@9&]M86EN*',I)RP*"2=B
M86-K=7!?7W)E;6%I;FEN9U]C;&EE;G1S)R`]/B`G)3$@8VQI96YT*',I)RP*
M"2=B86-K=7!?7V]V97)A;&Q?8F%C:W5P7W!R;V=R97-S)R`]/B`G3W9E<F%L
M;"!B86-K=7`@<')O9W)E<W,G+`H))V)A8VMU<%]?8V]M;65N=%]N7V$G(#T^
M("=N+V$G+`H))V)A8VMU<%]?8V]M;6%N9%]I9VYO<F4G(#T^("=#;VUM86YD
M("(E,2(@:7,@:6=N;W)E9"<L"@DG8F%C:W5P7U]N;W1?8F%C:W5P7V9I;&4G
M(#T^("=.;W0@82!B86-K=7`@9FEL92<L"@DG8F%C:W5P7U]D8E]S97)V97)?
M;6%P<&EN9R<@/3X@)U-E;&5C="!T:&4@9&%T86)A<V4@<V5R=F5R(&-O;F9I
M9W5R960@:6X@4&QE<VL@=&\@=VAI8V@@>6]U('=I<V@@=&\@;6%P('1H92!D
M871A8F%S92!S97)V97(@9G)O;2!B86-K=7`N)RP*"2=B86-K=7!?7W5N86)L
M95]U<&1A=&4G(#T^("=5;F%B;&4@=&\@=7!D871E('-C:&5D=6QE9"!B86-K
M=7`@:6YF;W)M871I;VXZ("4Q)RP*"2=B86-K=7!?7VYO7V]B:F5C=',G(#T^
M("=T:&5R92!A<F4@;F\@;V)J96-T<R!F;W(@8F%C:W5P)RP*"2=B86-K=7!?
M7V-L:5]W87)N:6YG7VYO=%]E;F]U9VA?:7`G(#T^("=705).24Y'.B!N;W0@
M96YO=6=H($E0(&%D9')E<W-E<R!T;R!P97)F;W)M(&1E9F%U;'0@25`@;6%P
M<&EN9SH@)RP*"2=B=%]B86-K=7!?;F]W)R`]/B`B0F%C:W5P($YO=R(L"@DG
M8G1?;F5W7W)E<W1O<F4G(#T^(")297-T;W)E(BP*"2=B=%]B86-K=7!?<V-H
M961U;&4G(#T^(")38VAE9'5L960@0F%C:W5P(BP*"2=B86-K=7!?97AI<W1?
M8F%C:W5P<R<@/3X@(D5X:7-T:6YG(&)A8VMU<"!F:6QE<R(L"@DG8F%C:W5P
M7V1I86QO9U]?<&%G95]T:71L92<@/3X@(D)A8VMU<"!&:6QE($-R96%T:6]N
M(BP*"2=B86-K=7!?9&EA;&]G7U]P;&5A<V5?=V%I="<@/3X@(E1H92!B86-K
M=7`@<')O8V5S<R!I<R!A8F]U="!T;R!B96=I;BX@)3$@5&AI<R!O<&5R871I
M;VX@;6EG:'0@=&%K92!S;VUE('1I;64N("4R(%!L96%S92!W86ET+BXN("4S
M(BP*"2=D=6UP7V9I;&5?7VEN8V]R<F5C=%]F:6QE;F%M92<@/3X@(E1H92!F
M:6QE<R!Y;W4@<W!E8VEF:65D(&%R92!N;W0@<&%R=',@;V8@=&AE('-A;64@
M;75L=&DM=F]L=6UE(&)A8VMU<"XB+`H))V1U;7!?9FEL95]?:6YC;W)R96-T
M7W-E<75E;F-E)R`]/B`B5W)O;F<@<V5Q=65N8V4@;V8@=F]L=6UE<R!S<&5C
M:69I960A(BP*"2=B=%]A8V-E<'0G(#T^(")!8V-E<'0B+`H))V)T7V%C8V5S
M<R<@/3X@(D%C8V5S<R(L"@DG8G1?86-T:6]N7VQO9R<@/3X@(D%C=&EO;B!,
M;V<B+`H))V)T7V%D9"<@/3X@(D%D9"(L"@DG8G1?861D7V-L:65N="<@/3X@
M(D%D9"!.97<@0VQI96YT(BP*"2=B=%]D871A8F%S95]S97)V97)?861D)R`]
M/B`G061D($1A=&%B87-E(%-E<G9E<B<L"@DG8G1?861D7VYE=U]C871E9V]R
M>2<@/3X@(D%D9"!.97<@0V%T96=O<GDB+`H))V)T7V%D9%]N97=?<')I;W)I
M='DG(#T^(")!9&0@3F5W(%!R:6]R:71Y(BP*"2=B=%]A9&1?;F5W7W%U975E
M)R`]/B`B061D($YE=R!1=65U92(L"@DG8G1?861D7VYE=U]T:6-K970G(#T^
M(")!9&0@3F5W(%1I8VME="(L"@DG8G1?861D7W-E<G9I8V5S)R`]/B`B061D
M(%-E<G9I8V5S(BP*"2=B=%]A9&1?861D<F5S<U]T;U]A8VPG(#T^("=!9&0@
M3F5W($%D9')E<W,G+`H))V)T7V%D9%]T;R<@/3X@(CP\($%D9"(L"@DG8G1?
M=&]?861D)R`]/B`B061D(#X^(BP*"2=B=%]T;U]E>&-L=7-I=F4G(#T^("(\
M/"!%>&-L=7-I=F4B+`H))V)T7W1O7W-H87)E9"<@/3X@(E-H87)E9"`^/B(L
M"@DG8G1?86YO;F9T<%]S=&%T<R<@/3X@(D%N;VXN1E10(%-T871S(BP*"2=B
M=%]A;F]N>6UO=7-?9G1P)R`]/B`B06YO;GEM;W5S($944"(L"@DG8G1?871T
M86-H)R`]/B`B071T86-H(BP*"2=B=%]A=71O:6YS=&%L;&5R)R`]/B`G57!D
M871E<B<L"@DG8G1?8F%C:R<@/3X@(CP\($)A8VLB+`H))V)T7V)A8VMU<"<@
M/3X@(D)A8VL@=7`B+`H))V)T7V)U>5]C97)T<R<@/3X@(D)U>2!#97)T<R(L
M"@DG8G1?8FQO8VME9%]D;VUA:6YS)R`]/B`G0FQA8VL@3&ES="<L"@DG8G1?
M8FQO8VME9%]D;VUA:6Y?861D)R`]/B`G061D($1O;6%I;B<L"@DG8G1?8V%N
M8V5L)R`]/B`B0V%N8V5L(BP*"2=B=%]C87)D)R`]/B`B0V%R9"(L"@DG8G1?
M8V5R="<@/3X@(D-E<G1I9FEC871E(BP*"2=B=%]C97)T7V%D9"<@/3X@(D%D
M9"!.97<@0V5R=&EF:6-A=&4B+`H))V)T7V-E<G1?8G5Y)R`]/B`B0G5Y($-E
M<G0B+`H))V)T7V-E<G1?<F5Q=65S="<@/3X@(E)E<75E<W0B+`H))V)T7V-E
M<G1?<V5L9E]S:6=N)R`]/B`B4V5L9BU3:6=N960B+`H))V)T7V-E<G1?=FEE
M=R<@/3X@(E9I97<@0V5R=',B+`H))V)T7V-E<G1I9FEC871E<R<@/3X@(D-E
M<G1I9FEC871E<R(L"@DG8G1?8V9?8V]N9FEG=7)E)R`]/B`B0V]L9$9U<VEO
M;B!3971T:6YG<R(L"@DG8G1?8VAA;F=E7W!A<W-W9"<@/3X@(D-H86YG92!0
M87-S=V]R9"(L"@DG8G1?8VQE86Y?;&]G)R`]/B`B0VQE87(@3&]G(BP*"2=B
M=%]C;&5A<B<@/3X@(D-L96%R(BP*"2=B=%]C;&EE;G1?=&5M<&QA=&5S)R`]
M/B`B0VQI96YT(%1E;7!L871E<R(L"@DG8G1?8VQI96YT<R<@/3X@(D-L:65N
M=',B+`H))V)T7V-O9&5P86=E7V-H86YG92<@/3X@)T-H86YG92!%;F-O9&EN
M9R<L"@DG8G1?8V]M<%]I;F9O)R`]/B`B0V]M<&]N96YT($EN9F\B+`H))V)T
M7V-O;6UO;E]A8VPG(#T^("=#;VUM;VX@04-,)RP*"2=B=%]C;VYF:6=U<F5?
M;6%I;&QI<W1S)R`]/B`B4V5T(%5P($UA:6QM86XB+`H))V)T7V-O;F9I9W5R
M95]O9&)C)R`]/B`B3T1"0R!3971T:6YG<R(L"@DG8G1?8V]P>2<@/3X@(D-O
M<'DB+`H))V)T7V-O<'E?;6]V92<@/3X@(D-O<'DO36]V92(L"@DG8G1?8W)E
M871E)R`]/B`B0W)E871E(BP*"2=B=%]C<F5A=&5?86-C;W5N="<@/3X@(D-R
M96%T92!.97<@06-C;W5N="(L"@DG8G1?8W)E871E7V1I<B<@/3X@(D%D9"!.
M97<@1&ER96-T;W)Y(BP*"2=B=%]C<F5A=&5?9FEL92<@/3X@(D%D9"!.97<@
M1FEL92(L"@DG8G1?8V]U;G1?<VEZ92<@/3X@(D-A;&-U;&%T92!3:7IE(BP*
M"2=B=%]C<F]N=&%B7W5N:7@G(#T^(")#<F]N=&%B(BP*"2=B=%]C<F]N=&%B
M7W=I;B<@/3X@(E-C:&5D=6QE<B(L"@DG8G1?8W5S=&]M7V)U='1O;E]N97<G
M(#T^(")!9&0@3F5W($)U='1O;B(L"@DG8G1?8W5S=&]M7V)U='1O;G,G(#T^
M(")#=7-T;VT@0G5T=&]N<R(L"@DG8G1?8W5S=&]M:7IE)R`]/B`B0W5S=&]M
M:7IE(BP*"2=B=%]D871A8F%S97,G(#T^(")$871A8F%S97,B+`H))V)T7V1A
M=&%B87-E7W-E<G9E<G,G(#T^("=$871A8F%S92!397)V97)S)RP*"2=B=%]D
M8E]U<W)?;F5W)R`]/B`B061D($YE=R!$871A8F%S92!5<V5R(BP*"2=B=%]D
M8E]N97<G(#T^(")!9&0@3F5W($1A=&%B87-E(BP*"2=B=%]D8E]P:'!M>6%D
M;6EN)R`]/B`B37E344P@061M:6XB+`H))V)T7V1B7W!H<'!G861M:6XG(#T^
M(")0;W-T9W)E4U%,($%D;6EN(BP*"2=B=%]D8G5S97)?9&5F875L="<@/3X@
M(D1E9F%U;'0@9F]R($1"(%=E8D%D;6EN(BP*"2=B=%]D96-L:6YE)R`]/B`B
M1&5C;&EN92(L"@DG8G1?9&5F875L="<@/3X@(D1E9F%U;'0B+`H))V)T7V1E
M9F%U;'1S)R`]/B`B1&5F875L=',B+`H))V)T7V1E;&5T92<@/3X@(D1E;&5T
M92(L"@DG8G1?9&ER96-T;W)I97,G(#T^(")$:7)E8W1O<FEE<R(L"@DG8G1?
M9&ES86)L92<@/3X@(D1I<V%B;&4B+`H))V)T7V1N<R<@/3X@(D1.4R(L"@DG
M8G1?9&YS7V%D9"<@/3X@(D%D9"!.97<@4F5C;W)D(BP*"2=B=%]D;G-R96-O
M<F1?861D)R`]/B`B061D($YE=R!296-O<F0B+`H))V)T7V1N<U]S;V$G(#T^
M(")33T$@4')E9F5R96YC97,B+`H))V)T7V1N<U]P<F5F97)E;F-E<R<@/3X@
M(D1.4R!0<F5F97)E;F-E<R(L"@DG8G1?9&]?8F%C:W5P)R`]/B`B0F%C:R!5
M<"(L"@DG8G1?9&]?<F5S=&]R92<@/3X@(E)E<W1O<F4B+`H))V)T7V1O7W5P
M;&]A9"<@/3X@(E5P;&]A9"(L"@DG8G1?9&]M86EN7W1E;7!L871E<R<@/3X@
M(D1O;6%I;B!496UP;&%T97,B+`H))V)T7V1O;6%I;E]U<V5R)R`]/B`B1&]M
M86EN($%D;6EN:7-T<F%T;W(B+`H))V)T7V1O;6%I;E]U<V5R7W!A<W-W9"<@
M/3X@(D1O;6%I;B!!9&UI;FES=')A=&]R(%!A<W-W;W)D(BP*"2=B=%]D;VUA
M:6YS)R`]/B`B1&]M86EN<R(L"@DG8G1?9&]W;FQO860G(#T^(")$;W=N;&]A
M9"(L"@DG8G1?9&]W;FQO861?;&]G)R`]/B`B1&]W;FQO860B+`H))V)T7V5D
M:70G(#T^(")%9&ET(BP*"2=B=%]E;F%B;&4G(#T^(")%;F%B;&4B+`H))V)T
M7V5V96YT;6=R)R`]/B`G179E;G0@36%N86=E<B<L"@DG8G1?979E;G1?:&%N
M9&QE<E]A9&0G(#T^("=!9&0@3F5W($5V96YT($AA;F1L97(G+`H))V)T7V5X
M<&]R="<@/3X@)T5X<&]R="<L"@DG8G1?97AT<F%S)R`]/B`B17AT<F%S(BP*
M"2=B=%]F:6QE7VUA;F%G97(G(#T^(")&:6QE($UA;F%G97(B+`H))V)T7V9I
M;FES:"<@/3X@(D9I;FES:"(L"@DG8G1?9G1P7V%C8V]U;G0G(#T^(")&5%`@
M06-C;W5N="!0<F]P97)T:65S(BP*"2=B=%]F;W)G971?<&%S<W=O<F0G(#T^
M(")&;W)G;W0@4&%S<W=O<F0_(BP*"2=B=%]F<%]S<VQ?=V5B861M:6XG(#T^
M(")&4"U34TP@5V5B861M:6XB+`H))V)T7V9P7W=E8F%D;6EN)R`]/B`B1E`@
M5V5B861M:6XB+`H))V)T7V9T<%]S=&%T<R<@/3X@(D944"!3=&%T<R(L"@DG
M8G1?9V5T7W!A<W-W;W)D)R`]/B`B1V5T(%!A<W-W;W)D(BP*"2=B=%]G;&]B
M86Q?8VAA;F=E<R<@/3X@(D=R;W5P($]P97)A=&EO;G,B+`H))V)T7VAE;'`G
M(#T^(")(96QP(BP*"2=B=%]H:61E7V%L:6%S97,G(#T^(")(:61E($%L:6%S
M97,B+`H))V)T7VAI9&5?=&]O;&)A<B<@/3X@)TAI9&4@=&]O;&)A<B<L"@DG
M8G1?:&ED95]S=6)D;VUA:6YS)R`]/B`B2&ED92!3=6)D;VUA:6YS(BP*"2=B
M=%]H;VUE)R`]/B`B2&]M92(L"@DG8G1?:&]S=&EN9R<@/3X@(DAO<W1I;F<B
M+`H))V)T7VEN<W1A;&PG(#T^("));G-T86QL(BP*"2=B=%]I;G1E<F9A8V5?
M;6%N86=E;65N="<@/3X@(DEN=&5R9F%C92!-86YA9V5M96YT(BP*"2=B=%]I
M<%]A;&EA<VEN9R<@/3X@(DE0($%D9')E<W-E<R(L"@DG8G1?:7!?861D)R`]
M/B`B061D($YE=R!)4"!!9&1R97-S(BP*"2=B=%]I<%]P;V]L)R`]/B`B25`@
M4&]O;"(L"@DG8G1?:V5Y7VEN9F\G(#T^("),:6-E;G-E($UA;F%G96UE;G0B
M+`H))V)T7VME>5]B=7EO;FQI;F5?861D;VYS)R`]/B`G3W)D97(@0V]N=')O
M;"!086YE;"!!9&0M3VYS)RP*"2=B=%]K97E?8G5Y;VYL:6YE7W5P9W)A9&5S
M)R`]/B`G3W)D97(@0V]N=')O;"!086YE;"!5<&=R861E<R<L"@DG8G1?:V5Y
M7V)U>6]N;&EN95]N97<G(#T^("=/<F1E<B!.97<@2V5Y)RP*"2=B=%]K97E?
M=7!D871E)R`]/B`G4F5T<FEE=F4@2V5Y<R<L"@DG8G1?:V5Y7W5P;&]A9"<@
M/3X@)U5P;&]A9"!+97DG+`H))V)T7VME>5]D;W=N;&]A9"<@/3X@)T1O=VYL
M;V%D($ME>2<L"@DG8G1?:V5Y7W)E=F5R="<@/3X@)U)O;&P@0F%C:R!+97DG
M+`H))V)T7VQI;6ET<R<@/3X@(DQI;6ET<R(L"@DG8G1?;&]C86QE7V%D9"<@
M/3X@)T%D9"!,;V-A;&4G+`H))V)T7VQO8V%L97,G(#T^("=,;V-A;&5S)RP*
M"2=B=%]L;V=?;6%N86=E<B<@/3X@(DQO9R!-86YA9V5R(BP*"2=B=%]L;V=I
M;B<@/3X@(DQO9VEN(BP*"2=B=%]L;V=O)R`]/B`B3&]G;R!3971U<"(L"@DG
M8G1?;&]G;U]D969A=6QT)R`]/B`B1&5F875L="!,;V=O(BP*"2=B=%]L;V=O
M7W-E;F1?;&EN:R<@/3X@(D%T=&%C:"!,:6YK(BP*"2=B=%]L;V=O7W-E;F1?
M;&]G;R<@/3X@(D%T=&%C:"!,;V=O(BP*"2=B=%]L;V=O=70G(#T^("),;V<@
M3W5T(BP*"2=B=%]L;V=R;W1A=&EO;B<@/3X@(DQO9R!2;W1A=&EO;B(L"@DG
M8G1?;6%I;"<@/3X@(DUA:6PB+`H))V)T7VUA:6Q?86QI87-?861D)R`]/B`B
M061D($YE=R!-86EL($%L:6%S(BP*"2=B=%]M86EL7V%L:6%S97,G(#T^(")-
M86EL($%L:6%S97,B+`H))V)T7VUA:6Q?9W)O=7!?861D)R`]/B`B061D($YE
M=R!-96UB97(B+`H))V)T7VUA:6Q?9W)O=7!S)R`]/B`B1W)O=7!S(BP*"2=B
M=%]M86EL7V1R=V5B)R`]/B`G1'(N5V5B)RP*"2=B=%]M86EL7VYA;65?861D
M)R`]/B`B061D($YE=R!-86EL($YA;64B+`H))V)T7VUA:6Q?<')E9F5R96YC
M97,G(#T^(")0<F5F97)E;F-E<R(L"@DG8G1?;6%I;%]G<F]U<"<@/3X@(DUA
M:6P@1W)O=7`B+`H))V)T7VUA:6Q?;6%I;&)O>"<@/3X@(DUA:6QB;W@B+`H)
M)V)T7VUA:6Q?<F5D:7)E8W0G(#T^(")2961I<F5C="(L"@DG8G1?;6%I;%]R
M97-P7V%D9"<@/3X@(D%D9"!.97<@075T;W)E<W!O;F1E<B(L"@DG8G1?;6%I
M;%]R97-P7V%T=&%C:%]A9&0G(#T^(")!9&0@3F5W($%T=&%C:&UE;G0B+`H)
M)V)T7VUA:6Q?<F5S<%]F:6QE<R<@/3X@(D%T=&%C:&UE;G0@1FEL97,B+`H)
M)V)T7VUA:6Q?<F5S<&]N9&5R<R<@/3X@(D%U=&]R97-P;VYD97)S(BP*"2=B
M=%]M86EL7W-P86UF:6QT97(G(#T^(")3<&%M($9I;'1E<B(L"@DG8G1?;6%I
M;%]W96)M86EL)R`]/B`B5V5B36%I;"(L"@DG8G1?;6%I;&QI<W1?;F5W)R`]
M/B`B061D($YE=R!-86EL:6YG($QI<W0B+`H))V)T7VUA:6QL:7-T7VUE;6)E
M<E]N97<G(#T^(")!9&0@3F5W($UE;6)E<B(L"@DG8G1?;6%I;&QI<W1S)R`]
M/B`B36%I;&EN9R!,:7-T<R(L"@DG8G1?;6%I;&UA;B<@/3X@(DUA:6QM86XB
M+`H))V)T7VUA:V5?9'5M<"<@/3X@(D-R96%T92!"86-K=7`B+`H))V)T7VUA
M;F%G92<@/3X@(DUA;F%G92(L"@DG8G1?;6%S=&5R)R`]/B`B36%S=&5R(BP*
M"2=B=%]M:6=R871I;VY?;6%N86=E<B<@/3X@)TUI9W)A=&EO;B!-86YA9V5R
M)RP*"2=B=%]M:6=R871E)R`]/B`G36EG<F%T92<L"@DG8G1?;6]D=6QE<U]A
M9&0G(#T^("=!9&0@36]D=6QE)RP*"2=B=%]M;V1U;&5S7VUA;F%G92<@/3X@
M)TUA;F%G92!-;V1U;&5S)RP*"2=B=%]M;W9E)R`]/B`B36]V92(L"@DG8G1?
M;7!C)R`]/B`B37E0;&5S:RYC;VTB+`H))V)T7VYE=U]C;&EE;G0G(#T^(")!
M9&0@3F5W($-L:65N="!!8V-O=6YT(BP*"2=B=%]N97=?9&]M86EN)R`]/B`B
M061D($YE=R!$;VUA:6XB+`H))V)T7VYE>'0G(#T^(").97AT(#X^(BP*"2=B
M=%]N97AT7W!A9V4G(#T^(").97AT(BP*"2=B=%]N971W;W)K7V%D9"<@/3X@
M(D%D9"!.97<@3F5T=V]R:R(L"@DG8G1?;F]T:69I8V%T:6]N<R<@/3X@(DYO
M=&EF:6-A=&EO;G,B+`H))V)T7V]D8F-?9'-N7V%D9"<@/3X@(D%D9"!.97<@
M3T1"0R!$4TXB+`H))V)T7V]F9B<@/3X@(D]F9B(L"@DG8G1?;VLG(#T^(")/
M2R(L"@DG8G1?;VXG(#T^(")/;B(L"@DG8G1?;VY?;V9F)R`]/B`B3VXO3V9F
M(BP*"2=B=%]P9%]N97<G(#T^(")!9&0@3F5W($1I<F5C=&]R>2(L"@DG8G1?
M<&1?=7-E<E]N97<G(#T^(")!9&0@3F5W(%5S97(B+`H))V)T7W!E<FUI<W-I
M;VYS)R`]/B`B4&5R;6ES<VEO;G,B+`H))V)T7W!H<&UY861M:6XG(#T^(")0
M:'!->4%D;6EN(BP*"2=B=%]P:'!P9V%D;6EN)R`]/B`B4&AP4&=!9&UI;B(L
M"@DG8G1?<&]S=&=R95]S<6PG(#T^(")0;W-T9W)E4U%,(BP*"2=B=%]P<F5F
M97)E;F-E<R<@/3X@(E!R969E<F5N8V5S(BP*"2=B=%]P<F5V7W!A9V4G(#T^
M(")0<F5V(BP*"2=B=%]P<F5V:65W)R`]/B`G4VET92!0<F5V:65W)RP*"2=B
M=%]P<FEN="<@/3X@(E!R:6YT(BP*"2=B=%]R96)O;W0G(#T^(")296)O;W0B
M+`H))V)T7W)E9G)E<V@G(#T^(")2969R97-H(BP*"2=B=%]R96=I<W1E<B<@
M/3X@(E)E9VES=&5R(BP*"2=B=%]R96UO=F4G(#T^(")296UO=F4B+`H))V)T
M7W)E;6]V95]F<F]M)R`]/B`B4F5M;W9E(#X^(BP*"2=B=%]F<F]M7W)E;6]V
M92<@/3X@(CP\(%)E;6]V92(L"@DG8G1?<F5M;W9E7W-E;&5C=&5D)R`]/B`B
M4F5M;W9E(%-E;&5C=&5D(BP*"2=B=%]R97!A:7)?:7`G(#T^(")297!A:7(@
M25`B+`H))V)T7W)E<&]R="<@/3X@(E)E<&]R="(L"@DG8G1?<F5P;W)T7V%U
M=&\G(#T^("=297!O<G0@1&5L:79E<GDG+`H))V)T7W)E<&]R=%]A=71O7VYE
M=R<@/3X@)T%D9"!$96QI=F5R>2!38VAE9'5L92<L"@DG8G1?<F5P;W)T7VYE
M=R<@/3X@(D%D9"!.97<@3&%Y;W5T(BP*"2=B=%]R97)E861?:7`G(#T^(")2
M97)E860@25`B+`H))V)T7W)E<V5T)R`]/B`B4F5S970B+`H))V)T7W)E<W1A
M<G1?<V5R=FEC97,G(#T^(")397)V:6-E($UA;F%G96UE;G0B+`H))V)T7W-A
M=F4G(#T^(")3879E(BP*"2=B=%]S96%R8V@G(#T^(")396%R8V@B+`H))V)T
M7W-E;F1?8GE?96UA:6PG(#T^(")396YD($)Y($4M36%I;"(L"@DG8G1?<V5N
M9%]F:6QE)R`]/B`B4V5N9"!&:6QE(BP*"2=B=%]S96YD7VUA:6PG(#T^(")3
M96YD($UA:6PB+`H))V)T7W-E;F1?<&%S<W=D)R`]/B`B4V5N9"!087-S=V]R
M9"(L"@DG8G1?<V5N9%]T97AT)R`]/B`B4V5N9"!497AT(BP*"2=B=%]S97)V
M97(G(#T^(")397)V97(B+`H))V)T7W-E<G9E<E]A9&0G(#T^(")!9&0@3F5W
M(%-E<G9E<B(L"@DG8G1?<V5R=F5R7W!R969E<F5N8V5S)R`]/B`B4V5R=F5R
M(%!R969E<F5N8V5S(BP*"2=B=%]S97)V97)S7VQI<W0G(#T^(")397)V97)S
M(BP*"2=B=%]S97-S:6]N7W-E='5P)R`]/B`B3&]G:6X@4V5T=&EN9W,B+`H)
M)V)T7W-E<W-I;VYS)R`]/B`B4V5S<VEO;G,B+`H))V)T7W-E="<@/3X@(E-E
M="(L"@DG8G1?<V5T7V%S7V1E9F%U;'0G(#T^(")3970@07,@1&5F875L="(L
M"@DG8G1?<V5T=7`G(#T^(")3971U<"(L"@DG8G1?<VAO=U]A;&EA<V5S)R`]
M/B`B4VAO=R!!;&EA<V5S(BP*"2=B=%]S:&]W7V%L;"<@/3X@(E-H;W<@06QL
M(BP*"2=B=%]S:&]W7W-U8F1O;6%I;G,G(#T^(")3:&]W(%-U8F1O;6%I;G,B
M+`H))V)T7W-H=71D;W=N)R`]/B`B4VAU="!$;W=N(BP*"2=B=%]S:71E7V%P
M<'!K9W,G(#T^(")!<'!L:6-A=&EO;B!6875L="(L"@DG8G1?<VET95]A<'!P
M;V]L)R`]/B`B07!P;&EC871I;VX@4&]O;"(L"@DG8G1?<VET95]A<'!S)R`]
M/B`B07!P;&EC871I;VX@5F%U;'0B+`H))V)T7W-I=&5?87!P7V%D9"<@/3X@
M(D%D9"!.97<@07!P;&EC871I;VXB+`H))V)T7W-I=&5?87!P7W!K9U]N97<G
M(#T^(")!9&0@3F5W($%P<&QI8V%T:6]N(%!A8VMA9V4B+`H))V)T7V%D9&ET
M:6]N86Q?:V5Y7W5P;&]A9"<@/3X@)U5P;&]A9"!.97<@2V5Y)RP*"2=B=%]A
M9&1I=&EO;F%L7VME>5]D;W=N;&]A9"<@/3X@)T1O=VYL;V%D($ME>2<L"@DG
M8G1?861D:71I;VYA;%]K97E?<F5M;W9E)R`]/B`G4F5M;W9E($ME>2<L"@DG
M8G1?861D:71I;VYA;%]K97E?86-T:79A=&4G(#T^("=!8W1I=F%T92<L"@DG
M8G1?<VET95]B=6EL9&5R)R`]/B`B36%M8F\@0TU3(BP*"2=B=%]S:V5L971O
M;B<@/3X@(E-K96QE=&]N(BP*"2=B=%]S:VEN<R<@/3X@)U-K:6YS)RP*"2=B
M=%]S:VEN7V%D9"<@/3X@)T%D9"!.97<@4VMI;B<L"@DG8G1?<VMI;E]M86YU
M86PG(#T^("=3:VEN<R!2969E<F5N8V4G+`H))V)T7W-K:6Y?9&]W;FQO860G
M(#T^("=$;W=N;&]A9"!3:VEN)RP*"2=B=%]S:VEN7W)E<&QA8V4G(#T^("=5
M<&1A=&4@4VMI;B<L"@DG8G1?<W!A;6%S<V%S<VEN)R`]/B`B4W!A;4%S<V%S
M<VEN(BP*"2=B=%]S<&%M87-S87-S:6Y?=')A:6XG(#T^(")4<F%I;FEN9R(L
M"@DG8G1?<W!A;69I;'1E<B<@/3X@(E-P86T@1FEL=&5R(BP*"2=B=%]S<VAT
M97)M)R`]/B`G4U-((%1E<FUI;F%L)RP*"2=B=%]S=&%T:7-T:6-S)R`]/B`B
M4W1A=&ES=&EC<R(L"@DG8G1?<W5B9&]M86EN7VYE=R<@/3X@(D%D9"!.97<@
M4W5B9&]M86EN(BP*"2=B=%]S=6)D;VUA:6YS)R`]/B`B4W5B9&]M86EN<R(L
M"@DG8G1?<W5B;6ET)R`]/B`B4W5B;6ET(BP*"2=B=%]S=6UM87)Y7W)E<&]R
M="<@/3X@(E-U;6UA<GD@4F5P;W)T(BP*"2=B=%]S=7!P;W)T)R`]/B`B4W5P
M<&]R="(L"@DG8G1?<W=I=&-H)R`]/B`B4W=I=&-H(BP*"2=B=%]S>7-T96U?
M=&EM92<@/3X@(E-Y<W1E;2!4:6UE(BP*"2=B=%]T87-K7VYE=R<@/3X@(D%D
M9"!.97<@5&%S:R(L"@DG8G1?9&]M7W1M<&Q?861D)R`]/B`G061D($YE=R!$
M;VUA:6X@5&5M<&QA=&4G+`H))V)T7V-L7W1M<&Q?861D)R`]/B`G061D($YE
M=R!#;&EE;G0@5&5M<&QA=&4G+`H))V)T7V-R;VY?8F%C:W5P)R`]/B`G4V-H
M961U;&5D($)A8VMU<"!3971T:6YG<R<L"@DG8G1?=&5S="<@/3X@(E1E<W0@
M0V]N;F5C=&EO;B(L"@DG8G1?=&5X="<@/3X@(E1E>'0B+`H))V)T7W1O=6-H
M)R`]/B`B5&]U8V@B+`H))V)T7W1R869F:6,G(#T^(")4<F%F9FEC(BP*"2=B
M=%]T<F%F9FEC7VAI<W1O<GDG(#T^(")4<F%F9FEC($AI<W1O<GDB+`H))V)T
M7W1T<U]G;&]B86Q?;&ES="<@/3X@(E-E<G9E<G,B+`H))V)T7W1T<U]T:6-K
M971S7V%L;"<@/3X@(D%L;"(L"@DG8G1?='1S7W1I8VME='-?86QL;W!E;F5D
M)R`]/B`B06QL($]P96YE9"(L"@DG8G1?='1S7W1I8VME='-?8VQO<V5D)R`]
M/B`B0VQO<V5D(BP*"2=B=%]T='-?=&EC:V5T<U]N97<G(#T^(").97<B+`H)
M)V)T7W1T<U]T:6-K971S7W)E;W!E;F5D)R`]/B`B4F5O<&5N960B+`H))V)T
M7W1T<U]C871S)R`]/B`B0V%T96=O<FEE<R(L"@DG8G1?='1S7V=E;F5R86Q?
M8V]N9FEG)R`]/B`B1V5N97)A;"!3971T:6YG<R(L"@DG8G1?='1S7VUA:6Q?
M9V%T92<@/3X@(DUA:6P@1V%T92!3971T:6YG<R(L"@DG8G1?='1S7W!R:6]R
M:71I97,G(#T^(")0<FEO<FET:65S(BP*"2=B=%]T='-?<75E=65S)R`]/B`B
M475E=65S(BP*"2=B=%]U<%]L979E;"<@/3X@(E5P($QE=F5L(BP*"2=B=%]U
M<&1A=&4G(#T^(")5<&1A=&4B+`H))V)T7W5P;&]A9"<@/3X@(E5P;&]A9"(L
M"@DG8G1?=7!L;V%D7V9R;VU?9G1P)R`]/B`B1E10(%5P;&]A9"(L"@DG8G1?
M=V5B7V%P<%]N97<G(#T^(")!9&0@3F5W($IA=F$@07!P;&EC871I;VXB+`H)
M)V)T7W=E8E]A<'!S)R`]/B`B5&]M8V%T(BP*"2=B=%]W96)?<W1A=',G(#T^
M(")796(@4W1A=',B+`H))V)T7W=E8E]S=&%T<U]S<VPG(#T^(")796(@4W1A
M=',@4U-,(BP*"2=B=%]W96)?=7-E<E]A9&0G(#T^(")!9&0@3F5W(%=E8B!5
M<V5R(BP*"2=B=%]W96)?=7-E<G,G(#T^(")796(@57-E<G,B+`H))V)T7W=E
M8F%D;6EN)R`]/B`B1$(@5V5B061M:6XB+`H))V)T7W=E8F%L:7IE<B<@/3X@
M(E=E8F%L:7IE<B(L"@DG8G1?=V5B86QI>F5R7W!R969E<F5N8V5S)R`]/B`B
M5V5B(%-T871I<W1I8W,@4')E9F5R96YC97,B+`H))V)T7VAI9&1E;BUR969E
M<G)E<BUA9&0G(#T^("=(:61E($5N=')I97,G+`H))V)T7V=R;W5P+7)E9F5R
M<F5R+6%D9"<@/3X@)T=R;W5P(%)E9F5R<F5R<R<L"@DG8G1?=VAA='-?;F5W
M7V9U;&PG(#T^(")3964@=&AE(&9U;&P@;&ES="!O9B!C:&%N9V5S(BP*"2=B
M=%]W:&ET95]L:7-T)R`]/B`B5VAI=&4@3&ES="(L"@DG8G1?=VAI=&5?;&ES
M=%]A9&0G(#T^(")!9&0@3F5T=V]R:R(L"@DG8V5R=%]?861D7VYE=U]C97)T
M)R`]/B`B061D($YE=R!#97)T:69I8V%T92(L"@DG8V5R=%]?861M:6Y?<V5R
M=F5R7VYO=%]R97-P;VYD)R`]/B`B268@)3$@9&]E<R!N;W0@<F5S<&]N9"P@
M<&QE87-E(&%C8V5S<R!T:&4@<V5R=F5R(&%N9"!R97-T87)T('1H92!A9&UI
M;FES=')A=&EV92!W96(@<V5R=F5R(&5N9VEN92!M86YU86QL>2XB+`H))V-E
M<G1?7V-E<G1S7W1R86YS9F5R<F5D7W1O7V%D;6EN7W)E<"<@/3X@(E1H92!F
M;VQL;W=I;F<@8V5R=&EF:6-A=&5S(&%R92!S=&EL;"!I;B!U<V4@86YD('1H
M97)E9F]R92!C86YN;W0@8F4@<F5M;W9E9"`Z("4Q.R!!;&P@;V8@=&AE;2!W
M:6QL(&)E('!L86-E9"!T;R!T:&4@861M:6YI<W1R871O<B=S(&-E<G1I9FEC
M871E(')E<&]S:71O<GDN(BP*"2=C97)T7U]C:&]O<V5?8V5R="<@/3X@(E-E
M;&5C="!A(&-E<G1I9FEC871E(&9I;&4N(BP*"2=C97)T7U]I;G9A;&ED7W5P
M;%]C97)T)R`]/B`B57!L;V%D960@8V5R=&EF:6-A=&4@:7,@:6YV86QI9"XB
M+`H))V-E<G1?7VYO7V-E<G1?;W)?<'9T:V5Y)R`]/B`B56YA8FQE('1O(&EN
M<W1A;&P@=&AE(&1E9F%U;'0@8V5R=&EF:6-A=&4Z(&YO(&-E<G1I9FEC871E
M('=I=&@@<')I=F%T92!K97D@<V5L96-T960N(BP*"2=C97)T7U]O;FQY7V]N
M95]C97)T7V-A;E]B95]D969A=6QT)R`]/B`B3VYL>2!O;F4@8V5R=&EF:6-A
M=&4@8V%N(&)E('-E="!A<R!D969A=6QT+B(L"@DG8V5R=%]?;VYL>5]O;F5?
M8V5R=%]C86Y?<V5T=7!?;VY?8W`G(#T^(")/;FQY(&]N92!C97)T:69I8V%T
M92!C86X@8F4@:6YS=&%L;&5D(&EN=&\@=&AE($-O;G1R;VP@4&%N96PN(BP*
M"2=C97)T7U]P<FEV871E7VME>5]F;W5N9"<@/3X@(E1H92!P<FEV871E(&ME
M>2!F;W(@=&AE('5P;&]A9&5D(&-E<G1I9FEC871E('=A<R!F;W5N9"!U;F1E
M<B!N86UE("4Q+B!#97)T:69I8V%T92!W87,@<W5C8V5S<V9U;&QY(&%D9&5D
M+B(L"@DG8V5R=%]?<V5L96-T7V-E<G1?9F]R7VEN<W1A;&Q?;VY?8W`G(#T^
M(")396QE8W0@=&AE(&-E<G1I9FEC871E('1O(&EN<W1A;&P@:6YT;R!T:&4@
M0V]N=')O;"!086YE;"XB+`H))V-E<G1?7W-E;&5C=%]C97)T7V9O<E]S971?
M9&5F875L="<@/3X@(E-E;&5C="!A(&-E<G1I9FEC871E('1O('-E="!A<R!D
M969A=6QT+B(L"@DG8V5R=%]?<W-L7V-E<G1?<F5L;V%D)R`]/B`B+BXN4U-,
M(&-E<G1I9FEC871E(&ES(&)E:6YG(')E;&]A9&5D+"!P;&5A<V4@=V%I="XN
M+B(L"@DG8V5R=%]?=&ET;&5?8W`G(#T^(")#97)T:69I8V%T92!R97!O<VET
M;W)Y(BP*"2=C97)T7U]T:71L95]D;VUA:6XG(#T^(")#97)T:69I8V%T92!R
M97!O<VET;W)Y(&9O<B!D;VUA:6X@/&(^)3$\+V(^(BP*"2=C97)T7U]U;F%B
M;&5?9FEN9%]A<'!R7W!V=%]K97DG(#T^(")5;F%B;&4@=&\@9FEN9"!T:&4@
M87!P<F]P<FEA=&4@<')I=F%T92!K97D@9F]R('1H92!C97)T:69I8V%T92XB
M+`H))V-E<G1?7W5N86)L95]I;G-T86QL7V-E<G1?;VY?8W`G(#T^(")5;F%B
M;&4@=&\@:6YS=&%L;"!T:&4@8V5R=&EF:6-A=&4@:6YT;R!T:&4@0V]N=')O
M;"!086YE;#H@=&AE('!R:79A=&4@:V5Y(&%N9"!C97)T:69I8V%T92!C;VYT
M96YT<R!A<F4@;6ES<VEN9RXB+`H))V-E<G1?7W5N86)L95]T;U]U<&QO860G
M(#T^("=5;F%B;&4@=&\@:6YS=&%L;"!T:&4@8V5R=&EF:6-A=&4@:6YT;R!T
M:&4@0V]N=')O;"!086YE;#H@)3$G+`H))V-E<G1?7W5N86)L95]T;U]D96QE
M=&5?8V5R=&EF:6-A=&5S)R`]/B`B56YA8FQE('1O(')E;6]V92!C97)T:69I
M8V%T97,Z("(L"@DG8V5R=%]?=7!L;V%D7V-E<G0G(#T^(")5<&QO860@8V5R
M=&EF:6-A=&4@9FEL92!A;F0@9FEN9"!M871C:&EN9R!P<FEV871E(&ME>2!I
M;B!T:&4@<F5P;W-I=&]R>2XB+`H))V-E<G1?7W5P;&]A9%]C97)T7V)Y7W!V
M=%]K97DG(#T^(")&:6YD('1H92!A<'!R;W!R:6%T92!P<FEV871E(&ME>2!T
M;R!T:&4@8V5R=&EF:6-A=&4B+`H))V-E<G1?861D7U]B:71S)R`]/B`B0FET
M<R(L"@DG8V5R=%]A9&1?7V-A7V-E<G0G(#T^(")#02!C97)T:69I8V%T92(L
M"@DG8V5R=%]A9&1?7V-E<G0G(#T^(")#97)T:69I8V%T92(L"@DG8V5R=%]A
M9&1?7V-E<G1?;F%M92<@/3X@(D-E<G1I9FEC871E(&YA;64B+`H))V-E<G1?
M861D7U]C:71Y)R`]/B`B3&]C871I;VX@*$-I='DI(BP*"2=C97)T7V%D9%]?
M96YT97)?8V5R=%]N86UE)R`]/B`B16YT97(@8V5R=&EF:6-A=&4@;F%M92XB
M+`H))V-E<G1?861D7U]E;G1E<E]P=G1?:V5Y7V-E<G1?9FEL92<@/3X@(D5N
M=&5R('!R:79A=&4@:V5Y(&%N9"!C97)T:69I8V%T92!F:6QE+B(L"@DG8V5R
M=%]A9&1?7V5N=&5R7W!V=%]K97E?8V5R=%]T97AT)R`]/B`B16YT97(@<')I
M=F%T92!K97D@86YD(&-E<G1I9FEC871E('1E>'0N(BP*"2=C97)T7V%D9%]?
M;W)G86YI>F%T:6]N7VYA;64G(#T^(")/<F=A;FEZ871I;VX@;F%M92`H8V]M
M<&%N>2DB+`H))V-E<G1?861D7U]O<F=A;FEZ871I;VY?=6YI=%]N86UE)R`]
M/B`B3W)G86YI>F%T:6]N(&1E<&%R=&UE;G0O9&EV:7-I;VX@;F%M92(L"@DG
M8V5R=%]A9&1?7W!R:79A=&5?:V5Y7V%N9%]C<W)?<V5N=%]E;6%I;"<@/3X@
M(E1H92!G96YE<F%T960@<')I=F%T92!K97D@86YD($-34B!H879E(&)E96X@
M<V5N="!T;R!E+6UA:6PZ("4Q(BP*"2=C97)T7V%D9%]?<'9T7VME>2<@/3X@
M(E!R:79A=&4@:V5Y(BP*"2=C97)T7V%D9%]?<W1A=&4G(#T^(")3=&%T92!O
M<B!P<F]V:6YC92(L"@DG8V5R=%]A9&1?7W1I=&QE7V-P)R`]/B`B0W)E871E
M(&$@;F5W(%-33"!C97)T:69I8V%T92(L"@DG8V5R=%]A9&1?7W1I=&QE7V1O
M;6%I;B<@/3X@(D-R96%T92!A(&YE=R!34TP@8V5R=&EF:6-A=&4@9F]R(&1O
M;6%I;B`\8CXE,3PO8CXB+`H))V-E<G1?861D7U]U;F%B;&5?<V5T7V-A7V-E
M<G0G(#T^(")5;F%B;&4@=&\@<V5T('1H92!#02!C97)T:69I8V%T93H@)3$B
M+`H))V-E<G1?861D7U]U;F%B;&5?<V5T7V-E<G0G(#T^(")5;F%B;&4@=&\@
M<V5T('1H92!C97)T:69I8V%T93H@)3$B+`H))V-E<G1?861D7U]U;F%B;&5?
M<V5T7W!R:79A=&5?:V5Y)R`]/B`B56YA8FQE('1O('-E="!T:&4@<')I=F%T
M92!K97DZ("4Q(BP*"2=C97)T7V%D9%]?=7!L;V%D7V-E<G1?9FEL97,G(#T^
M(")5<&QO860@8V5R=&EF:6-A=&4@9FEL97,B+`H))V-E<G1?861D7U]U<&QO
M861?8V5R=%]T97AT)R`]/B`B57!L;V%D(&-E<G1I9FEC871E(&%S('1E>'0B
M+`H))V-E<G1?961I=%]?8V]M<&]N96YT7V%B<V5N="<@/3X@(D-O;7!O;F5N
M="!I<R!M:7-S:6YG(BP*"2=C97)T7V5D:71?7V-S<B<@/3X@(D-34B(L"@DG
M8V5R=%]E9&ET7U]O=F5R;&]A9%]C85]C97)T7V-O;F9I<FT_)R`]/B`B3W9E
M<G=R:71E('1H92!E>&ES=&EN9R!#02!C97)T:69I8V%T93\B+`H))V-E<G1?
M961I=%]?;W9E<FQO861?8V5R=%]C;VYF:7)M/R<@/3X@(D]V97)W<FET92!T
M:&4@97AI<W1I;F<@0V5R=&EF:6-A=&4_(BP*"2=C97)T7V5D:71?7W)E;6]V
M95]C85]C;VYF:7)M/R<@/3X@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R
M96UO=F4@=&AE($-!(&-E<G1I9FEC871E/R(L"@DG8V5R=%]E9&ET7U]T:71L
M95]C<"<@/3X@(E-33"!C97)T:69I8V%T92(L"@DG8V5R=%]E9&ET7U]T:71L
M95]D;VUA:6XG(#T^(")34TP@8V5R=&EF:6-A=&4@9F]R(&1O;6%I;B`\8CXE
M,3PO8CXB+`H))V-E<G1I9FEC871E<U]L:7-T7U]C97)T:69I8V%T95]U<V5D
M7V%S7V1E9F%U;'0G(#T^(")O;F4@;V8@=&AE(&-E<G1I9FEC871E('EO=2!A
M<F4@9V]I;F<@=&\@9&5L971E(&ES('5S960@87,@=&AE($1E9F%U;'0@0V5R
M=&EF:6-A=&4N(BP*"2=C97)T:69I8V%T97-?;&ES=%]?8V5R=&EF:6-A=&5S
M)R`]/B`B4U-,(&-E<G1I9FEC871E<R(L"@DG8V5R=&EF:6-A=&5S7VQI<W1?
M7V-E<G1I9FEC871E<U]A<W-I9VYE9%]O;E]I<"<@/3X@(F]N92!O<B!S979E
M<F%L(&-E<G1I9FEC871E<R!A<F4@87-S:6=N960@=&\@=&AE($E0(&%D9')E
M<W-E<RXB+`H))V-E<G1I9FEC871E<U]L:7-T7U]T86)?=&ET;&5?8V%?8V5R
M="<@/3X@(D$B+`H))V-E<G1I9FEC871E<U]L:7-T7U]T86)?=&ET;&5?8V5R
M="<@/3X@(D,B+`H))V-E<G1I9FEC871E<U]L:7-T7U]T86)?=&ET;&5?8W-R
M)R`]/B`B4B(L"@DG8V5R=&EF:6-A=&5S7VQI<W1?7W1A8E]T:71L95]I<%]U
M<V%G92<@/3X@(E5S960B+`H))V-E<G1I9FEC871E<U]L:7-T7U]T86)?=&ET
M;&5?;F%M92<@/3X@(D-E<G1I9FEC871E($YA;64B+`H))V-E<G1I9FEC871E
M<U]L:7-T7U]T86)?=&ET;&5?<'9T7VME>2<@/3X@(DLB+`H))V-F7V-O;F9?
M7W!A9V5?=&ET;&4G(#T^(")#;VQD1G5S:6]N(%-E='1I;F=S(BP*"2=C9E]C
M;VYF7U]P871H)R`]/B`B0V]L9$9U<VEO;B!I;G-T86QL871I;VX@<&%T:"(L
M"@DG8V9?8V]N9E]?=W)O;F=?<&%T:%]E;G1E<F5D)R`]/B`B26YC;W)R96-T
M(&EN<W1A;&QA=&EO;B!P871H+B(L"@DG8VA?<&%S<U]?861M:6Y?<&%S<R<@
M/3X@(D%D;6EN:7-T<F%T;W(G<R!P87-S=V]R9"(L"@DG8VA?<&%S<U]?;VQD
M7W!A<W,G(#T^(")/;&0@<&%S<W=O<F0B+`H))V-H7W!A<W-?7W!A<W-?8V]N
M9FER;2<@/3X@(D-O;F9I<FTB+`H))V-H7W!A<W-?7W5N86)L95]C:&%N9V5?
M861M:6Y?<&%S<R<@/3X@(E5N86)L92!T;R!C:&%N9V4@=&AE(&%D;6EN:7-T
M<F%T;W(G<R!P87-S=V]R9#H@)3$B+`H))V-H7W!A<W-?8GE?<V5C<F5T7U]E
M;6%I;%]S=6)J96-T)R`]/B`G4&QE<VL@<&%S<W=O<F0@<F5M:6YD97(G+`H*
M"@DG8VA?<&%S<U]B>5]S96-R971?7V5M86EL7V)O9'DG(#T^(")$96%R("4R
M+%QN("4S7&Y<;B!4;R!S970@=7`@82!N97<@<&%S<W=O<F0L('!L96%S92!F
M;VQL;W<@=&AE(&QI;FLZ("4Q(BP*"2=C:%]P87-S7V)Y7W-E8W)E=%]?;65S
M<V%G95]S96YD)R`]/B`G)3$G+`H))V-H7W!A<W-?8GE?<V5C<F5T7U]M97-S
M86=E7W-E;F1?97)R;W(G(#T^("=5;F%B;&4@=&\@<V5N9"!T:&4@<V5C<F5T
M(&-O9&4Z("4Q)RP*"2=C:%]P87-S7V)Y7W-E8W)E=%]?;65S<V%G95]S96-R
M971?<F5Q=65S=%]A9&UI;B<@/3X@)U1H92!I;G-T<G5C=&EO;G,@;VX@8VAA
M;F=I;F<@>6]U<B!P87-S=V]R9"!H879E(&)E96X@<V5N="!T;R!Y;W5R(&4M
M;6%I;"XG+`H))V-H7W!A<W-?8GE?<V5C<F5T7U]E;6%I;%]S96-R971?<F5Q
M=65S=%]A9&UI;B<@/3X@(EEO=2!R97%U97-T960@=&AE(&-O;G1R;VP@<&%N
M96P@=&\@<V5N9"!Y;W4@>6]U<B!P87-S=V]R9"!B>2!E+6UA:6PN($9O<B!S
M96-U<FET>2!R96%S;VYS+"!A9&UI;FES=')A=&]R)W,@<&%S<W=O<F0@8V%N
M;F]T(&)E('-E;G0@8GD@92UM86EL+B!(;W=E=F5R+"!Y;W4@8V%N('-E="!U
M<"!A(&YE=R!P87-S=V]R9"!U<VEN9R!T:&4@<V5C<F5T(&-O9&4@>6]U('=I
M;&P@9FEN9"!I;B!T:&ES(&QE='1E<BXB+`H))V-H7W!A<W-?8GE?<V5C<F5T
M7U]M97-S86=E7W-E8W)E=%]R97%U97-T7V-R>7!T960G(#T^(")9;W4@<F5Q
M=65S=&5D('1H92!C;VYT<F]L('!A;F5L('1O('-E;F0@>6]U('EO=7(@<&%S
M<W=O<F0@8GD@92UM86EL+B!!<R!Y;W4@<&%S<W=O<F0@=V%S('-T;W)E9"!I
M;B!T:&4@<WES=&5M(&EN('1H92!E;F-R>7!T960@9F]R;2P@:70@;6%D92!N
M;R!S96YS92!T;R!S96YD(&ET(&)Y(&4M;6%I;#H@>6]U('=O=6QD('-I;7!L
M>2!N;W0@8F4@86)L92!T;R!U<V4@:70N($AO=V5V97(L('EO=2!C86X@<V5T
M('5P(&$@;F5W('!A<W-W;W)D('5S:6YG('1H92!S96-R970@8V]D92!Y;W4@
M=VEL;"!F:6YD(&EN('1H:7,@;&5T=&5R+B(L"@DG8VA?<&%S<U]B>5]S96-R
M971?7V5M86EL7W-E8W)E=%]R97%U97-T7V-R>7!T960G(#T^(")9;W5R('!A
M<W-W;W)D(&-O=6QD(&YO="!B92!S96YT(&)E8V%U<V4@:70@:7,@<W1O<F5D
M(&EN('1H92!E;F-R>7!T960@9F]R;2XB+`H))V-H7W!A<W-?8GE?<V5C<F5T
M7U]M97-S86=E7W=R;VYG7VQO9VEN)R`]/B`B5&AE(&QO9VEN(&YA;64@>6]U
M('-P96-I9FEE9"!D;V5S(&YO="!M871C:"!T:&4@<V5C<F5T(&-O9&4N($$@
M;F5W('-E8W)E="!C;V1E('=A<R!G96YE<F%T960@86YD('-E;G0@=&\@>6]U
M<B!E+6UA:6PN(BP*"2=C:%]P87-S7V)Y7W-E8W)E=%]?96UA:6Q?=W)O;F=?
M;&]G:6XG(#T^("=9;W4@=')I960@=&\@<V5T('5P(&$@;F5W('!A<W-W;W)D
M('5S:6YG('1H92!S96-R970@8V]D92!B=70@96YT97)E9"!T:&4@=W)O;F<@
M;&]G:6X@;F%M92X@66]U('=I;&P@9FEN9"!A(&YE=R!S96-R970@8V]D92!I
M;B!T:&ES(&QE='1E<BXG+`H*"2=C:%]P87-S7V)Y7W-E8W)E=%]?:6YV86QI
M9%]S96-R970G(#T^("=);G9A;&ED('-E8W)E="!C;V1E(2<L"@DG8VA?<&%S
M<U]B>5]S96-R971?7W1I=&QE)R`]/B`G0VAA;F=E(%EO=7(@4&%S<W=O<F0G
M+`H))V-H7W!A<W-?8GE?<V5C<F5T7U]S96-R970G(#T^("=396-R970@8V]D
M92<L"@H))V-H96-K7VUA:6Q?8WEC;&5?7V%L:6%S97,G(#T^(")-86EL(&-Y
M8VQI;F<@:7,@9&5T96-T960L('1H92!A9&1R97-S(%PB)3%<(B!I<R!C;VYT
M86EN960@:6X@=&AE(&%L:6%S97,@;V8@=&AI<R!M86EL(&YA;64N(BP*"2=C
M:&5C:U]M86EL7V-Y8VQE7U]A=71O<F5S<&]N9&5R<R<@/3X@(DUA:6P@8WEC
M;&EN9R!I<R!D971E8W1E9"P@=&AE(&%D9')E<W,@7"(E,5PB(&ES(&-O;G1A
M:6YE9"!I;B!T:&4@875T;W)E<W!O;F1E<G,@;V8@=&AI<R!M86EL(&YA;64N
M(BP*"2=C:&5C:U]M86EL7V-Y8VQE7U]M86EL7V=R;W5P<R<@/3X@(DUA:6P@
M8WEC;&EN9R!I<R!D971E8W1E9"P@=&AE(&%D9')E<W,@7"(E,5PB(&ES(&-O
M;G1A:6YE9"!I;B!T:&4@;6%I;"!G<F]U<"!O9B!T:&ES(&UA:6P@;F%M92XB
M+`H))V-H96-K7VUA:6Q?8WEC;&5?7VUA:6Q?;F%M92<@/3X@(DUA:6P@8WEC
M;&EN9R!I<R!D971E8W1E9"P@=&AE(&%D9')E<W,@7"(E,5PB(&-O:6YC:61E
M<R!W:71H('1H:7,@;6%I;"!N86UE+B(L"@DG8VAE8VM?;6%I;%]C>6-L95]?
M<F5D:7)E8W0G(#T^(")-86EL(&-Y8VQI;F<@:7,@9&5T96-T960L('1H92!A
M9&1R97-S(%PB)3%<(B!C;VEN8VED97,@=VET:"!T:&4@<F5D:7)E8W0@;V8@
M=&AI<R!M86EL(&YA;64N(BP*"2=C:&M?:G-?7V5N=&5R7VQO9VEN7V%N9%]P
M87-S=V0G(#T^(")%;G1E<B!L;V=I;B!N86UE(&%N9"!P87-S=V]R9"XB+`H)
M)V-H:U]J<U]?96YT97)?;&]G:6Y?;F%M92<@/3X@(D5N=&5R(&QO9VEN(&YA
M;64N(BP*"2=C:&M?:G-?7V5N=&5R7W!A<W-W9"<@/3X@(D5N=&5R('!A<W-W
M;W)D+B(L"@H))V)T7V-H86YG95]O=VYE<B<@/3X@(D-H86YG92!/=VYE<B(L
M"@DG8VAO=VY?7W-E;&5C=%]T:71L92<@/3X@(E-E;&5C="!T:&4@;F5W(&]W
M;F5R(BP*"2=C:&]W;E]?8VAE8VM?=&ET;&4G(#T^(")#:&%N9V4@9&]M86EN
M(&]W;F5R(BP*"2=C:&]W;E]?;F5W7V]W;F5R)R`]/B`B3F5W(&]W;F5R(BP*
M"2=C:&]W;E]?<V5L96-T961?9&]M86EN<R<@/3X@(E-E;&5C=&5D(&1O;6%I
M;G,B+`H))V-H;W=N7U]L:6UI='-?;&5G96YD)R`]/B`B4F5S;W5R8V5S(BP*
M"2=C:&]W;E]?;&EM:71?;F%M92<@/3X@(E)E<V]U<F-E(&YA;64B+`H))V-H
M;W=N7U]L:6UI=%]V86QU92<@/3X@(D%L;&]C871E9"!R97-O=7)C97,B+`H)
M)V-H;W=N7U]L:6UI=%]A<W-I9VYE9%]B969O<F4G(#T^(")"969O<F4@=')A
M;G-F97(B+`H))V-H;W=N7U]L:6UI=%]A<W-I9VYE9%]A9G1E<B<@/3X@(D%F
M=&5R('1R86YS9F5R(BP*"2=C:&]W;E]?97)R;W)?9&]M86EN<U]E>&-L=61E
M)R`]/B`B4V]M92!P<F]B;&5M<R!W97)E(&5N8V]U;G1E<F5D(&1U<FEN9R!A
M='1E;7!T('1O('1R86YS9F5R('-O;64@;V8@=&AE(&1O;6%I;G,@=&\@82!N
M97<@;W=N97(N(%1H97-E(&1O;6%I;G,@;F%M97,@87)E(&AI9VAL:6=H=&5D
M+B(L"@DG8VAO=VY?7V5R<F]R7VQI;6ET<R<@/3X@(D1O;6%I;B!T<F%N<V9E
M<B!I<R!I;7!O<W-I8FQE+B!4:&ES(&1O;6%I;B!R97%U:7)E<R!M;W)E(')E
M<V]U<F-E<R!T:&%N(&1E<W1I;F%T:6]N('5S97(@86-C;W5N="!C86X@<')O
M=FED92XB+`H))V-H;W=N7U]E<G)O<E]N;U]D;VUA:6YS)R`]/B`B56YA8FQE
M('1O(&-O;G1I;G5E(&1O;6%I;B!T<F%N<V9E<CH@;F\@9&]M86EN<R!S96QE
M8W1E9"XB+`H))V-H;W=N7U]E<G)O<E]E;7!T>5]I<%]P;V]L)R`]/B`B56YA
M8FQE('1O(&-O;G1I;G5E(&1O;6%I;B!T<F%N<V9E<CH@25`@<&]O;"!O9B!T
M:&4@8VQI96YT(&ES(&5M<'1Y+B!0;&5A<V4@87-S:6=N(&%N($E0(&%D9')E
M<W,@=&\@=&AE(&-L:65N="!F:7)S="XB+`H))V-H;W=N7U]I<%]N;W1?:6Y?
M8VQI96YT7W!O;VPG(#T^(")4:&4@25`@861D<F5S<R!A<W-O8VEA=&5D('=I
M=&@@=&AI<R!D;VUA:6X@=V%S(&YO="!A<W-I9VYE9"!T;R!)4"!P;V]L(&]F
M('1H92!N97<@9&]M86EN(&]W;F5R+B(L"@DG8VAO=VY?7V%L<F5A9'E?;W=N
M961?8GE?8VQI96YT)R`]/B`B5&AI<R!D;VUA:6X@;F%M92!A;')E861Y(&)E
M;&]N9W,@=&\@=&AI<R!U<V5R+B(L"@DG8VAO=VY?7W!L96%S95]S96QE8W1?
M;F5W7V1O;6%I;E]O=VYE<B<@/3X@)U!L96%S92!S96QE8W0@=&AE(&YE=R!O
M=VYE<B!F;W(@=&AI<R!D;VUA:6XN)RP*"2=C:&]W;E]?;VQD7VEP7V%D9')E
M<W,G(#T^("=4:&4@8W5R<F5N="!)4"!A9&1R97-S)RP*"2=C:&]W;E]?;F5W
M7VEP7V%D9')E<W,G(#T^("=4:&4@;F5W($E0(&%D9')E<W,G+`H))V-H;W=N
M7U]I<%]A9&1R97-S7W=A<FXG(#T^("=4:&4@25`@861D<F5S<R!A<W-O8VEA
M=&5D('=I=&@@=&AI<R!D;VUA:6X@9&]E<R!N;W0@8F5L;VYG('1O('1H92!P
M;V]L(&]F('1H92!N97<@9&]M86EN(&]W;F5R.B!P;&5A<V4@8VAE8VL@=&AE
M('9A;'5E<R!S96QE8W1E9"!F;W(@25`@;6%P<&EN9R<L"@H)+R\@96YD(&]F
M('-H<F%M:V\@<&%R=`H*"@DO+R!S97)G92!P87)T"@H))V-H:U]J<U]?=V%R
M;FEN9U]A8F]U=%]L;V=I;E]S>6YT87@G(#T^(")9;W4@8V%N('5S92!L;W=E
M<F-A<V4@86QP:&%N=6UE<FEC+"!D87-H(&%N9"!U;F1E<G-C;W)E('-Y;6)O
M;',@:6X@=&AE(&QO9VEN(&YA;64N(%1H92!L;V=I;B!N86UE('-H;W5L9"!B
M96=I;B!W:71H(&%N(&%L<&AA8F5T:6,@<WEM8F]L+B!4:&4@<&%S<W=O<F0@
M<VAO=6QD(&YO="!C;VYT86EN('1H92!L;V=I;B!N86UE+B(L"@DG8VAK7VIS
M7U]W87)N:6YG7V%B;W5T7V9T<%]L;V=I;E]S>6YT87@G(#T^(")9;W4@8V%N
M('5S92!A;'!H86YU;65R:6,L(&1A<V@@86YD('5N9&5R<V-O<F4@<WEM8F]L
M<R!I;B!T:&4@;&]G:6X@;F%M92XB+`H))V-H:U]J<U]?=V%R;FEN9U]A8F]U
M=%]L;V=I;E]S>6YT87A?=VEN)R`]/B`B66]U(&-A;B!U<V4@;&]W97)C87-E
M(&%L<&AA;G5M97)I8RP@9&%S:"!A;F0@=6YD97)S8V]R92!S>6UB;VQS(&EN
M('1H92!L;V=I;B!N86UE+B!4:&4@;&]G:6X@;F%M92!S:&]U;&0@8F5G:6X@
M=VET:"!A;B!A;'!H86)E=&EC('-Y;6)O;"XB+`H))V-H:U]J<U]?=V%R;FEN
M9U]A8F]U=%]P87-S=V1?<WEN=&%X)R`]/B`B1&\@;F]T('5S92!Q=6]T97,L
M('-P86-E(&%N9"!N871I;VYA;"!A;'!H86)E="!C:&%R86-T97)S(&EN(&$@
M<&%S<W=O<F0N7&Y4:&4@<&%S<W=O<F0@;&5N9W1H('-H;W5L9"!B92!F<F]M
M(#4@=&\@,30@8VAA<F%C=&5R<RX@5&AE('!A<W-W;W)D('-H;W5L9"!N;W0@
M8V]N=&%I;B!T:&4@;&]G:6X@;F%M92XB+`H))V-H:U]J<U]?=V%R;FEN9U]A
M8F]U=%]P;&5S:U]L;V=I;E]S>6YT87@G(#T^(")9;W4@8V%N('5S92!L;W=E
M<F-A<V4@86QP:&%N=6UE<FEC+"!D87-H(&%N9"!U;F1E<G-C;W)E('-Y;6)O
M;',@:6X@=&AE(&QO9VEN(&YA;64N(%1H92!L;V=I;B!N86UE('-H;W5L9"!B
M96=I;B!W:71H(&%N(&%L<&AA8F5T:6,@<WEM8F]L+B(L"@DG8VAK7VIS7U]W
M87)N:6YG7V%B;W5T7W!L97-K7VQO9VEN7W-Y;G1A>%]W:6XG(#T^(")9;W4@
M8V%N('5S92!L;W=E<F-A<V4@86QP:&%N=6UE<FEC+"!D87-H(&%N9"!U;F1E
M<G-C;W)E('-Y;6)O;',@:6X@=&AE(&QO9VEN(&YA;64N(%1H92!L;V=I;B!N
M86UE('-H;W5L9"!B96=I;B!W:71H(&%N(&%L<&AA8F5T:6,@<WEM8F]L+B(L
M"@DG8VAK7VIS7U]W87)N:6YG7V%B;W5T7W!L97-K7W!A<W-W9%]S>6YT87@G
M(#T^(")$;R!N;W0@=7-E('%U;W1E<RP@<W!A8V4@86YD(&YA=&EO;F%L(&%L
M<&AA8F5T(&-H87)A8W1E<G,@:6X@82!P87-S=V]R9"Y<;E1H92!P87-S=V]R
M9"!S:&]U;&0@8F4@8F5T=V5E;B`U(&%N9"`Q-"!C:&%R86-T97)S(&%N9"!S
M:&]U;&0@;F]T(&-O;G1A:6X@=&AE(&QO9VEN(&YA;64N(BP*"2=C:&M?:G-?
M7W=A<FYI;F=?86)O=71?<&%M7W!A<W-W9%]E<G)O<B<@/3X@(E=R;VYG('-Y
M<W1E;2!U<V5R(&%C8V]U;G0@<W!E8VEF:6-A=&EO;CH@)3$B+`H))V-L7V5D
M7U]E9&ET7V-L)R`]/B`B)3$G<R!A8V-O=6YT(&1E=&%I;',B+`H))V-L7VQI
M;6ET<U]?8VPG(#T^(")#;&EE;G0@)3$G<R!L:6UI=',B+`H))V-L7VQO9V]?
M7W-E='5P7VQO9V]?<')E9B<@/3X@(E-E="!L;V=O('!R;W!E<G1I97,@9F]R
M(&-L:65N="`E,2(L"@DG8VQ?;F5W7U]E;G1E<E]N97=?8VQ?9&%T82<@/3X@
M(D5N=&5R('1H92!I;F9O<FUA=&EO;B!O;B!N97<@8VQI96YT(BP*"2=C;%]P
M97)M7U]A;&Q?:7`G(#T^(")!;&P@879A:6QA8FQE($E0<R(L"@DG8VQ?<&5R
M;5]?86QL7VEP7V)A<V5D7VAS=%]W:6QL7V)E7VYB)R`]/B`B06QL(&EP+6)A
M<V5D(&AO<W1I;F<@86-C;W5N=',@9F]R(&-L:65N="!W:6QL(&)E('1R86YS
M9F5R<F5D('1O($YA;64M8F%S960N(BP*"2=C;%]P97)M7U]A;&QO=U]C;&EE
M;G1?8W)E871E7V1O;6%I;B<@/3X@(E1H92!F:65L9',@>6]U(&%R92!T<GEI
M;F<@=&\@<V5L96-T(&%R92!O;FQY(&%P<&QI8V%B;&4@=&\@0VQI96YT<R!W
M:&\@87)E(&%L;&]W960@=&\@8W)E871E(&1O;6%I;G,N(BP*"2=C;%]P97)M
M7U]A;&QO=U]C<F5A=&5?;F)?=U]I<"<@/3X@(D-L:65N="!C86X@8W)E871E
M($YA;64M8F%S960@:&]S=&EN9R!U<VEN9R`E,2(L"@DG8VQ?<&5R;5]?86QL
M;W=?8W)E871I;VY?:7!?8F%S961?:&]S=&EN9R<@/3X@(D%L;&]W($E0+6)A
M<V5D(&AO<W1I;F<@86-C;W5N=',@8W)E871I;VXB+`H))V-L7W!E<FU?7V%V
M86EL86)L95]I<',G(#T^(")!=F%I;&%B;&4@25!S(BP*"2=C;%]P97)M7U]C
M:&%N9V5?;&EM:71S)R`]/B`B1&]M86EN(&QI;6ET<R!A9&IU<W1M96YT(BP*
M"2=C;%]P97)M7U]C;%]D:7-K7W-P86-E)R`]/B`B5&]T86P@9&ES:R!S<&%C
M92!A=F%I;&%B;&4B+`H))V-L7W!E<FU?7V-L7V5X<&ER871I;VXG(#T^(")#
M;&EE;G0@86-C;W5N="!V86QI9&ET>2!P97)I;V0B+`H))V-L7W!E<FU?7V-L
M7VUA>%]B;W@G(#T^(")-87AI;75M(&YU;6)E<B!O9B!M86EL8F]X97,B+`H)
M)V-L7W!E<FU?7V-L7VUA>%]D8B<@/3X@(DUA>&EM=6T@;G5M8F5R(&]F(&1A
M=&%B87-E<R(L"@DG8VQ?<&5R;5]?8VQ?;6%X7V1O;2<@/3X@(DUA>&EM=6T@
M;G5M8F5R(&]F(&1O;6%I;G,B+`H))V-L7W!E<FU?7V-L7VUA>%]M86EL;&ES
M=',G(#T^(")-87AI;75M(&YU;6)E<B!O9B!M86EL:6YG(&QI<W1S(BP*"2=C
M;%]P97)M7U]C;%]M87A?;6<G(#T^(")-87AI;75M(&YU;6)E<B!O9B!M86EL
M(&=R;W5P<R(L"@DG8VQ?<&5R;5]?8VQ?;6%X7W)E9&ER)R`]/B`B36%X:6UU
M;2!N=6UB97(@;V8@<F5D:7)E8W1S(BP*"2=C;%]P97)M7U]C;%]M87A?<F5S
M<"<@/3X@(DUA>&EM=6T@;G5M8F5R(&]F(&%U=&]R97-P;VYD97)S(BP*"2=C
M;%]P97)M7U]C;%]M87A?<W5B9&]M)R`]/B`B36%X:6UU;2!N=6UB97(@;V8@
M<W5B9&]M86EN<R(L"@DG8VQ?<&5R;5]?8VQ?;6%X7W1R869F:6,G(#T^(")4
M;W1A;"!A;6]U;G0@;V8@=')A9F9I8R!A=F%I;&%B;&4B+`H))V-L7W!E<FU?
M7V-L7VUA>%]W96)A<'!S)R`]/B`B36%X:6UU;2!N=6UB97(@;V8@2F%V82!A
M<'!L:6-A=&EO;G,B+`H))V-L7W!E<FU?7V-L7VUA>%]W=2<@/3X@(DUA>&EM
M=6T@;G5M8F5R(&]F('=E8B!U<V5R<R(L"@DG8VQ?<&5R;5]?8VQ?;6)O>%]Q
M=6]T82<@/3X@(E1H92!M86EL8F]X('-I>F4@;&EM:70@<V5T(&9O<B!T:&ES
M('5S97(@86-C;W5N="(L"@DG8VQ?<&5R;5]?8W)E871E7V1O;6%I;G,G(#T^
M(")$;VUA:6X@8W)E871I;VXB+`H))V-L7W!E<FU?7V-U<G)E;G1?;6%X:6UU
M;5]E>'!?9&%T92<@/3X@(E1H92!C=7)R96YT(&UA>&EM=6T@=F%L=64@;V8@
M9&]M86EN('9A;&ED:71Y('!E<FEO9"!I<R`E,3L@<F5Q=65S=&5D("4R7&XB
M+`H))V-L7W!E<FU?7V-U<G)E;G1?;6%X:6UU;5]M86EL8F]X7W%U;W1A)R`]
M/B`B5&AE(&-U<G)E;G1L>2!D969I;F5D(&QI;6ET(&]N(&%M;W5N="!O9B!D
M:7-K('-P86-E(&%L;&]C871E9"!F;W(@:&]U<VEN9R!M86EL8F]X97,@=6YD
M97(@=&AI<R!U<V5R(&%C8V]U;G0@:7,@)3$[(')E<75E<W1E9"`E,EQN(BP*
M"2=C;%]P97)M7U]C=7)R96YT7W1O=&%L7W)E<75E<W1E9"<@/3X@(E1H92!C
M=7)R96YT('1O=&%L('9A;'5E(&]F(&1O;6%I;B!L:6UI=',@9F]R("4Q(&ES
M("4R.R!R97%U97-T960@)3-<;B(L"@DG8VQ?<&5R;5]?8W5R<F5N=%]T;W1A
M;%]R97%U97-T961?9&]M)R`]/B`B0W5R<F5N="!N=6UB97(@;V8@)3$@8F5L
M;VYG:6YG('1O('1H:7,@8VQI96YT(&ES("4R.R!R97%U97-T960@)3-<;B(L
M"@DG8VQ?<&5R;5]?9&ES:U]S<&%C92<@/3X@(FUA>&EM=6T@86UO=6YT(&]F
M(&1I<VL@<W!A8V4B+`H))V-L7W!E<FU?7V1A<VAB;V%R9%]S=&1G=6DG(#T^
M("=5<V5R(&EN=&5R9F%C92<L"@DG8VQ?<&5R;5]?;6%N86=E7V1A<VAB;V%R
M9"<@/3X@)T1E<VMT;W`@;6%N86=E;65N="<L"@DG8VQ?<&5R;5]?9&%S:&)O
M87)D7V%N9%]S=&1G=6DG(#T^("=$97-K=&]P(&%N9"!S=&%N9&%R9"!I;G1E
M<F9A8V4@87)E(&%L;&]W960G+`H))V-L7W!E<FU?7V1A<VAB;V%R9%]O;FQY
M)R`]/B`G3VYL>2!$97-K=&]P(&EN=&5R9F%C92!I<R!A;&QO=V5D)RP*"2=C
M;%]P97)M7U]S=&1G=6E?;VYL>2<@/3X@)T]N;'D@<W1A;F1A<F0@:6YT97)F
M86-E(&ES(&%L;&]W960G+`H))V-L7W!E<FU?7V5D:71?8VPG(#T^(")#;&EE
M;G0@)3$G<R!P97)M:7-S:6]N<R(L"@DG8VQ?<&5R;5]?97AP7V1A=&5?97AC
M965D960G(#T^(")4:&4@=F%L:61I='D@<&5R:6]D('EO=2!A<F4@=')Y:6YG
M('1O('-E="!E>&-E961S('1H92!L:6UI="!S<&5C:69I960@=VET:&EN(&EN
M9&EV:61U86P@9&]M86EN<R!R96QA=&5D('1O('1H:7,@8VQI96YT+EQN(BP*
M"2=C;%]P97)M7U]I;G9A;&ED7W9A;'5E)R`]/B`B26YV86QI9"!V86QU92P@
M;VYL>2!D:6=I=',@87)E(&%L;&]W960N(BP*"2=C;%]P97)M7U]L:6UI=%]D
M:7-K7W-P86-E)R`]/B`B)3$@3&EM:70@=&AE('1O=&%L(&%M;W5N="!O9B!D
M:7-K('-P86-E(BP*"2=C;%]P97)M7U]L:6UI=%]E>'!I<F%T:6]N)R`]/B`B
M)3$@3&EM:70@=&AE('9A;&ED:71Y('!E<FEO9"!F;W(@=&AE(&-L:65N="!A
M8V-O=6YT(BP*"2=C;%]P97)M7U]L:6UI=%]M87A?8F]X)R`]/B`B)3$@3&EM
M:70@=&AE(&UA>&EM=6T@;G5M8F5R(&]F(&UA:6QB;WAE<R(L"@DG8VQ?<&5R
M;5]?;&EM:71?;6%X7V1B)R`]/B`B)3$@3&EM:70@=&AE(&UA>&EM=6T@;G5M
M8F5R(&]F(&1A=&%B87-E<R(L"@DG8VQ?<&5R;5]?;&EM:71?;6%X7V1O;2<@
M/3X@(B4Q($QI;6ET('1H92!M87AI;75M(&YU;6)E<B!O9B!D;VUA:6YS(BP*
M"2=C;%]P97)M7U]L:6UI=%]M87A?;6%I;&QI<W1S)R`]/B`B)3$@3&EM:70@
M=&AE(&UA>&EM=6T@;G5M8F5R(&]F(&UA:6QI;F<@;&ES=',B+`H))V-L7W!E
M<FU?7VQI;6ET7VUA>%]M9R<@/3X@(B4Q($QI;6ET('1H92!M87AI;75M(&YU
M;6)E<B!O9B!M86EL(&=R;W5P<R(L"@DG8VQ?<&5R;5]?;&EM:71?;6%X7W)E
M9&ER)R`]/B`B)3$@3&EM:70@=&AE(&UA>&EM=6T@;G5M8F5R(&]F(')E9&ER
M96-T<R(L"@DG8VQ?<&5R;5]?;&EM:71?;6%X7W)E<W`G(#T^("(E,2!,:6UI
M="!T:&4@;6%X:6UU;2!N=6UB97(@;V8@875T;W)E<W!O;F1E<G,B+`H))V-L
M7W!E<FU?7VQI;6ET7VUA>%]S=6)D;VTG(#T^("(E,2!,:6UI="!T:&4@;6%X
M:6UU;2!N=6UB97(@;V8@<W5B9&]M86EN<R(L"@DG8VQ?<&5R;5]?;&EM:71?
M;6%X7W1R869F:6,G(#T^("(E,2!,:6UI="!T:&4@=&]T86P@86UO=6YT(&]F
M('1R869F:6,B+`H))V-L7W!E<FU?7VQI;6ET7VUA>%]W96)A<'!S)R`]/B`B
M)3$@3&EM:70@=&AE(&UA>&EM=6T@;G5M8F5R(&]F($IA=F$@87!P;&EC871I
M;VYS(BP*"2=C;%]P97)M7U]L:6UI=%]M87A?=W4G(#T^("(E,2!,:6UI="!T
M:&4@;6%X:6UU;2!N=6UB97(@;V8@=V5B('5S97)S(BP*"2=C;%]P97)M7U]L
M:6UI=%]M8F]X7W%U;W1A)R`]/B`B)3$@4V5T('1H92!M86EL8F]X('%U;W1A
M(BP*"2=C;%]P97)M7U]L:6UI='-?97AC965D960G(#T^(")/;F4@;W(@<V5V
M97)A;"!L:6UI=',@>6]U(&%R92!T<GEI;F<@=&\@<V5T(&%R92!A;')E861Y
M(&5X8V5E9&5D(&)Y('1H92!L:6UI=',@9&5F:6YE9"!W:71H:6X@:6YD:79I
M9'5A;"!D;VUA:6YS(&)E;&]N9VEN9R!T;R!T:&ES(&-L:65N="Y<;E1H92!T
M;W1A;"!L:6UI="!F;W(@=&AE(&-L:65N="!M=7-T(&)E(&UO<F4@;W(@97%U
M86P@=&\@=&AE('1O=&%L('-U;2!O9B!T:&4@9&]M86EN(&QI;6ET<R!D969I
M;F5D(&9O<B!T:&ES(&-L:65N="!A8V-O=6YT+EQN(BP*"2=C;%]P97)M7U]M
M86EL8F]X7W%U;W1A7V5X8V5E9&5D)R`]/B`B5&AE(&QI;6ET(&]N(&%M;W5N
M="!O9B!D:7-K('-P86-E(&%L;&]C871E9"!F;W(@:&]U<VEN9R!M86EL8F]X
M97,@>6]U(&%R92!T<GEI;F<@=&\@<V5T(&5X8V5E9',@=&AE(&QI;6ET(&1E
M9FEN960@=VET:&EN(&EN9&EV:61U86P@9&]M86EN<R!R96QA=&5D('1O('1H
M:7,@8VQI96YT(&%C8V]U;G0N7&XB+`H))V-L7W!E<FU?7VUA:6QB;WA?<75O
M=&%?97AC965D<U]S97)V97)?;&EM:70G(#T^(")4:&4@;&EM:70@;VX@86UO
M=6YT(&]F(&1I<VL@<W!A8V4@86QL;V-A=&5D(&9O<B!H;W5S:6YG(&UA:6QB
M;WAE<R!Y;W4@87)E('1R>6EN9R!T;R!S970@97AC965D<R!T:&4@;&EM:71A
M=&EO;B!I;7!O<V5D(&%T('1H92!S97)V97(@;&5V96PN(BP*"2=C;%]P97)M
M7U]M86ME7V1U;7!S)R`]/B`B0F%C:W5P+W)E<W1O<F4@9G5N8W1I;VYS(BP*
M"2=C;%]P97)M7U]M86YA9V5?86YO;F9T<"<@/3X@(D%N;VYY;6]U<R!&5%`@
M;6%N86=E;65N="(L"@DG8VQ?<&5R;5]R96UO=&5?86-C97-S7VEN=&5R9F%C
M92<@/3X@(D%B:6QI='D@=&\@=7-E(')E;6]T92!834P@:6YT97)F86-E(BP*
M"2=C;%]P97)M7U]M86YA9V5?8W)O;G1A8E]W:6XG(#T^(")38VAE9'5L97(@
M;6%N86=E;65N="(L"@DG8VQ?<&5R;5]?;6%N86=E7V-R;VYT86)?=6YI>"<@
M/3X@(D-R;VYT86(@;6%N86=E;65N="(L"@DG8VQ?<&5R;5]?;6%N86=E7V1N
M<R<@/3X@(D1.4R!Z;VYE(&UA;F%G96UE;G0B+`H))V-L7W!E<FU?7VUA;F%G
M95]F='!?<&%S<W=O<F0G(#T^(")-86YA9V4@1E10('!A<W-W;W)D(BP*"2=C
M;%]P97)M7U]M86YA9V5?;&]G)R`]/B`B3&]G(')O=&%T:6]N(&UA;F%G96UE
M;G0B+`H))V-L7W!E<FU?7VUA;F%G95]M86EL;&ES=',G(#T^(")-86EL:6YG
M(&QI<W1S(&UA;F%G96UE;G0B+`H))V-L7W!E<FU?7VUA;F%G95]N;W1?8VAR
M;V]T7W-H96QL)R`]/B`G3F]N+6-H<F]O=&5D('-H96QL(&UA;F%G96UE;G0G
M+`H))V-L7W!E<FU?7VUA;F%G95]D<G=E8B<@/3X@)T1R+E=E8B!A;G1I=FER
M=7,@;6%N86=E;65N="<L"@DG8VQ?<&5R;5]?;6%N86=E7W!H;W-T:6YG)R`]
M/B`B4&AY<VEC86P@:&]S=&EN9R!M86YA9V5M96YT(BP*"2=C;%]P97)M7U]M
M86YA9V5?<75O=&$G(#T^(")(87)D(&1I<VL@<75O=&$@87-S:6=N;65N="(L
M"@DG8VQ?<&5R;5]?;6%N86=E7W-H7V%C8V5S<R<@/3X@(DUA;F%G96UE;G0@
M;V8@<VAE;&P@86-C97-S('1O('-E<G9E<B(L"@DG8VQ?<&5R;5]?;6%N86=E
M7W-H7V%C8V5S<U]D:7-A8FQE9"<@/3X@)T-L:65N="!C86YN;W0@86QL;W<@
M;W(@9&ES86QL;W<@<VAE;&P@86-C97-S)RP*"2=C;%]P97)M7U]M86YA9V5?
M<VA?86-C97-S7V-H<F]O=&5D)R`]/B`G0VQI96YT(&-A;B!A;&QO=R!A8V-E
M<W,@;VYL>2!T;R!A(&-H<F]O=&5D(&5N=FER;VYM96YT)RP*"2=C;%]P97)M
M7U]M86YA9V5?<VA?86-C97-S7V%N>2<@/3X@)T-L:65N="!C86X@86QL;W<@
M86-C97-S('1O(&%N>2!T>7!E(&]F('-H96QL)RP*"2=C;%]P97)M7U]M86YA
M9V5?<W5B9&]M86EN<R<@/3X@(E-U8F1O;6%I;G,@;6%N86=E;65N="(L"@DG
M8VQ?<&5R;5]?;6%N86=E7V1O;6%I;E]A;&EA<V5S)R`]/B`B1&]M86EN(&%L
M:6%S97,@;6%N86=E;65N="(L"@DG8VQ?<&5R;5]?;6%N86=E7W=E8F%P<',G
M(#T^(")*879A(&%P<&QI8V%T:6]N<R!M86YA9V5M96YT(BP*"2=C;%]P97)M
M7U]M87A?8F]X)R`]/B`B;6%X:6UU;2!N=6UB97(@;V8@;6%I;&)O>&5S(BP*
M"2=C;%]P97)M7U]M87A?9&(G(#T^(")M87AI;75M(&YU;6)E<B!O9B!D871A
M8F%S97,B+`H))V-L7W!E<FU?7VUA>%]D;VTG(#T^(")D;VUA:6YS(BP*"2=C
M;%]P97)M7U]M87A?;6%I;&QI<W1S)R`]/B`B;6%X:6UU;2!N=6UB97(@;V8@
M;6%I;&EN9R!L:7-T<R(L"@DG8VQ?<&5R;5]?;6%X7VUG)R`]/B`B;6%X:6UU
M;2!N=6UB97(@;V8@;6%I;"!G<F]U<',B+`H))V-L7W!E<FU?7VUA>%]R961I
M<B<@/3X@(FUA>&EM=6T@;G5M8F5R(&]F(')E9&ER96-T<R(L"@DG8VQ?<&5R
M;5]?;6%X7W)E<W`G(#T^(")M87AI;75M(&YU;6)E<B!O9B!A=71O<F5S<&]N
M9&5R<R(L"@DG8VQ?<&5R;5]?;6%X7W-U8F1O;2<@/3X@(G-U8F1O;6%I;G,B
M+`H))V-L7W!E<FU?7VUA>%]T<F%F9FEC)R`]/B`B;6%X:6UU;2!A;6]U;G0@
M;V8@=')A9F9I8R(L"@DG8VQ?<&5R;5]?;6%X7W=E8F%P<',G(#T^(")M87AI
M;75M(&YU;6)E<B!O9B!*879A(&%P<&QI8V%T:6]N<R(L"@DG8VQ?<&5R;5]?
M;6%X7W=U)R`]/B`B;6%X:6UU;2!N=6UB97(@;V8@=V5B('5S97)S(BP*"2=C
M;%]P97)M7U]M8F]X7W%U;W1A)R`]/B`B;6%I;&)O>"!Q=6]T82(L"@DG8VQ?
M<&5R;5]?;F]T7V%L;&]W7V-R96%T95]N8E]H<W0G(#T^(")#;&EE;G0@8V%N
M;F]T(&-R96%T92!.86UE+6)A<V5D(&AO<W1I;F<N(BP*"2=C;%]P97)M7U]C
M<%]A8V-E<W,G(#T^("=!8V-E<W,@=&\@8V]N=')O;"!P86YE;"<L"@DG8VQ?
M<&5R;5]?<V5L96-T7VEP7V%D9')S)R`]/B`B4V5L96-T(&EP(&%D9')E<W-E
M<R(L"@DG8VQ?<&5R;5]?<VET95]B=6EL9&5R)PD]/B`G57-E(&]F($UA;6)O
M(&-O;G1E;G0@;6%N86=E;65N="!S>7-T96TG+`H))V-L7W!E<FU?7W1H:7-?
M:7!?=7-E9%]V<G1?:'-T)R`]/B`B5&AI<R!I<"!A9&1R97-S(&ES('5S960@
M8GD@=FER='5A;"!H;W-T:6YG+EQN5&\@9&5L971E('1H:7,@:7`@861D<F5S
M<RP@<F5M;W9E(&AO<W1I;F<@<V5R=FEC92!O<B!C:&%N9V4@:71S('1Y<&4@
M=&\@3F%M92UB87-E9"XB+`H))V-L7W!E<FU?7W5N86)L95]O9F9?:7!B7V-R
M96%T:6YG)R`]/B`B0VQI96YT(&%L<F5A9'D@:&%S($E0+6)A<V5D(&AO<W1I
M;F<@<V5R=FEC92!S970M=7`N(%1O(&1E86-T:79A=&4@=&AI<R!F96%T=7)E
M(&9O<B!T:&4@0VQI96YT+"!D97-E;&5C="!T:&4@7")$;VUA:6X@8W)E871I
M;VY<(B!C:&5C:V)O>"!O<B!R96UO=F4@86QL($E0+6)A<V5D(&AO<W1I;F<@
M86-C;W5N=',N(BP*"2=C;%]P97)M7U]U;F%B;&5?;V9F7VYB7V-R96%T:6YG
M)R`]/B`B0VQI96YT(&%L<F5A9'D@:&%S($YA;64M8F%S960@:&]S=&EN9R!S
M97)V:6-E('-E="UU<"X@5&\@9&5A8W1I=F%T92!T:&ES(&9E871U<F4@9F]R
M('1H92!#;&EE;G0L(&1E<V5L96-T('1H92!<(D1O;6%I;B!C<F5A=&EO;EPB
M(&-H96-K8F]X(&]R(')E;6]V92!A;&P@3F%M92UB87-E9"!H;W-T:6YG(&%C
M8V]U;G1S+B(L"@DG8VQ?<&5R;5]?=6YA8FQE7W-E=%]D;VUA:6Y?;&EM:70G
M(#T^(")5;F%B;&4@=&\@;&EM:70@=&AE(&UA>&EM=6T@;G5M8F5R(&]F(&1O
M;6%I;G,Z(&-L:65N="!A;')E861Y(&AA<R`E,2!D;VUA:6YS(BP*"2=C;%]P
M97)M7U]U;F%B;&5?=7!D871E7V-L:65N=%]L:6UI=&%T:6]N<R<@/3X@(E5N
M86)L92!T;R!M;V1I9GD@=&AE(&QI;6ET<R!O9B!C;&EE;G0@86-C;W5N=#H@
M)3$B+`H))V-L7W!R969?7V5D:71?8VPG(#T^(")#;&EE;G0@)3$G<R!P<F5F
M97)E;F-E<R(L"@DG8VQ?=')A9F9I8U]H:7-T;W)Y7U]T:71L92<@/3X@(D-L
M:65N="`\8CXE,3PO8CXG<R!T<F%F9FEC(&AI<W1O<GDB+`H))V-L87-S7V%N
M;VYF='!?7V-R96%T95]F='!?9&]M86EN)R`]/B`B3F\@=FER='5A;"!&5%`@
M9&]M86EN(&9O<B!T:&ES(&1O;5]I9"P@=')Y(&-R96%T:6YG(&ET(&9I<G-T
M+B(L"@DG8VQA<W-?86YO;F9T<%]?:6YC;VUI;F=?9&ES:U]S<&%C95]S:&]U
M;&1?8F5?;&]W97(G(#T^(")4:&4@9&ES:R!S<&%C92!L:6UI="!Y;W4@87)E
M('1R>6EN9R!T;R!S970@*"4Q*2!S:&]U;&0@;F]T(&5X8V5E9"!T:&4@=&]T
M86P@9&ES:R!S<&%C92!L:6UI="!D969I;F5D(&%T('1H92!D;VUA:6X@;&5V
M96P@*"4R*2(L"@DG8VQA<W-?86YO;F9T<%]?:6YV86QI9%]I;G!U=%]O;FQY
M7V1I9VET<R<@/3X@(DEN=F%L:60@=F%L=64@<W!E8VEF:65D+"!O;FQY(&1I
M9VET<R!A<F4@86QL;W=E9"(L"@DG8VQA<W-?86YO;F9T<%]?=6YA8FQE7V-H
M86YG95]O=VYE<G-H:7!S)R`]/B`B56YA8FQE('1O(&-H86YG92!O=VYE<G-H
M:7`@;W(@<&5R;6ES<VEO;G,@9F]R('1H92!Q=6]T82!F:6QE.B`E,2(L"@DG
M8VQA<W-?86YO;F9T<%]?=6YA8FQE7V-O<'E?<75O=&%?9FEL92<@/3X@(E5N
M86)L92!T;R!C;W!Y('1H92!Q=6]T82!F:6QE.B`E,2(L"@DG8VQA<W-?86YO
M;F9T<%]?=6YA8FQE7V=E=%]D:7-K7W5S86=E)R`]/B`B56YA8FQE('1O(')E
M=')I979E(&1I<VL@=7-A9V4@:6YF;W)M871I;VX@;VX@=&AE(&EN8V]M:6YG
M(&1I<F5C=&]R>3H@)3$B+`H))V-L87-S7V%N;VYF='!?7W5N86)L95]P87)S
M95]Q=6]T85]F:6QE)R`]/B`B56YA8FQE('1O('!A<G-E('1H92!Q=6]T82!F
M:6QE+B(L"@DG8VQA<W-?86YO;F9T<%]?=6YA8FQE7W)E861?<75O=&%?9FEL
M92<@/3X@(E5N86)L92!T;R!R96%D('1H92!Q=6]T82!F:6QE.B`E,2(L"@DG
M8VQA<W-?86YO;F9T<%]?=6YA8FQE7W5P9&%T95]Q=6]T82<@/3X@(E5N86)L
M92!T;R!U<&1A=&4@<75O=&$Z('1H92!F:6QE<R!I;B!T:&4@:6YC;VUI;F<@
M9&ER96-T;W)Y('5S92`E,2!+0G,@;V8@9&ES:R!S<&%C92P@=VAI8V@@97AC
M965D<R!T:&4@;F5W('%U;W1A('9A;'5E(BP*"2=C;&%S<U]A;F]N9G1P7U]U
M;F%B;&5?=W)I=&5?=&5M<%]F:6QE)R`]/B`B56YA8FQE('1O('=R:71E('1O
M('1H92!T96UP;W)A<GD@9FEL93H@)3$B+`H))V-L87-S7V)S9&]M86EN7U]W
M87)N7VUA>%]D871E7U\G(#T^(")4:&4@=F%L:61I='D@<&5R:6]D('=A<R!S
M970@=&\@)3$B+`H))V-L87-S7V-L:65N=%]?8VQI96YT7V-R96%T:6]N7VYO
M=&EF:6-A=&EO;B<@/3X@(D-L:65N="!C<F5A=&EO;B!N;W1I8V4N(BP*"2=C
M;&%S<U]C;&EE;G1?7V-L:65N=%]W:71H7V-O;G1A8W1?;F%M95]A;')E861Y
M7V5X:7-T<R<@/3X@(D-L:65N="!W:71H(&YA;64@)3$@86QR96%D>2!E>&ES
M=',N(BP*"2=C;&%S<U]C;&EE;G1?7V-L:65N=%]W:71H7VQO9VEN7VYA;65?
M861M:6Y?86QR96%D>5]E>&ES=',G(#T^(")4:&4@=7-E<B!W:71H(&QO9VEN
M(&YA;64@861M:6X@86QR96%D>2!E>&ES=',N(BP*"2=C;&%S<U]C;&EE;G1?
M7V1I<VM?<W!A8V4G(#T^(")$:7-K('-P86-E(BP*"2=C;&%S<U]C;&EE;G1?
M7VEN=F%L:61?;6%X7V1O;2<@/3X@(DEN=F%L:60@;G5M8F5R(&]F(&1O;6%I
M;G,@=F%L=64L(&]N;'D@9&EG:71S(&%R92!A;&QO=V5D+B(L"@DG8VQA<W-?
M8VQI96YT7U]L:6UI=%]E>&-E960G(#T^("(E,3H@<F5Q=65S=&5D("T@)3(L
M(&UA>&EM=6T@879A:6QA8FQE("T@)3,B+`H))V-L87-S7V-L:65N=%]?;&EM
M:71?97AC965D7W5N;&EM:71E9"<@/3X@(B4Q.B!R97%U97-T960@+2!U;FQI
M;6ET960L(&UA>&EM=6T@879A:6QA8FQE("T@)3(B+`H))V-L87-S7V-L:65N
M=%]?;6%X7V)O>"<@/3X@(DUA:6QB;WAE<R(L"@DG8VQA<W-?8VQI96YT7U]M
M87A?9&(G(#T^(")$871A8F%S97,B+`H))V-L87-S7V-L:65N=%]?;6%X7VUA
M:6QL:7-T<R<@/3X@(DUA:6QI;F<@;&ES=',B+`H))V-L87-S7V-L:65N=%]?
M;6%X7VUG)R`]/B`B36%I;"!G<F]U<',B+`H))V-L87-S7V-L:65N=%]?;6%X
M7W)E9&ER)R`]/B`B4F5D:7)E8W1S(BP*"2=C;&%S<U]C;&EE;G1?7VUA>%]R
M97-P)R`]/B`B075T;W)E<W!O;F1E<G,B+`H))V-L87-S7V-L:65N=%]?;6%X
M7W-U8F1O;2<@/3X@(E-U8F1O;6%I;G,B+`H))V-L87-S7V-L:65N=%]?;6%X
M7W1R869F:6,G(#T^(")-87AI;75M('1R869F:6,B+`H))V-L87-S7V-L:65N
M=%]?;6%X7W=E8F%P<',G(#T^(")*879A(&%P<&QI8V%T:6]N<R(L"@DG8VQA
M<W-?8VQI96YT7U]M87A?=W4G(#T^(")796(@=7-E<G,B+`H))V-L87-S7V-L
M:65N=%]?;6)O>%]Q=6]T82<@/3X@(DUA:6QB;W@@<75O=&$B+`H))V-L87-S
M7V-L:65N=%]?=6YA8FQE7V1E9FEN95]C;%]S=&%T=7,G(#T^(")5;F%B;&4@
M=&\@9&5F:6YE('-T871U<R!O9B!C;&EE;G0@86-C;W5N=#H@)3$B+`H))V-L
M87-S7V-L:65N=%]?=6YA8FQE7V1E9FEN95]I;F%C=&EV95]D;VTG(#T^(")5
M;F%B;&4@=&\@9&5F:6YE(&EN86-T:79E(&1O;6%I;G,@)3$B+`H))V-L87-S
M7V-L:65N=%]?=6YA8FQE7V1E;%]I<"<@/3X@(E5N86)L92!T;R!R96UO=F4@
M25!S.B`E,2(L"@DG8VQA<W-?9&)?7V1B7VYA;65?;F]T7W-E="<@/3X@(D1A
M=&%B87-E(&YA;64@:7,@;F]T(&1E9FEN960N(BP*"2=C;&%S<U]D8E]?9&)?
M;F]T7V5X:7-T7V9O<E]C=7)R7V1O;2<@/3X@(E1H92!D871A8F%S92!D;V5S
M(&YO="!E>&ES="!F;W(@=&AI<R!D;VUA:6XN(BP*"2=C;&%S<U]D8E]?:6YV
M86QI9%]D8E]O<E]D;VU?;F%M92<@/3X@(E1H92!D;VUA:6X@;W(@9&%T86)A
M<V4@:60@:7,@:6YV86QI9"!O<B!D871A8F%S92!N86UE(&ES(&YO="!D969I
M;F5D+B(L"@DG8VQA<W-?9&)?7VEN=F%L:61?<&%S<R<@/3X@(E1H92!P87-S
M=V]R9"!I<R!I;G9A;&ED+B(L"@DG8VQA<W-?9&)?7VUA:6QG<G!?;65M8F5R
M7V5X:7-T)R`]/B`B5&AE(&UA:6P@9W)O=7`@;65M8F5R(&%L<F5A9'D@97AI
M<W1S+B(L"@DG8VQA<W-?9&)?7V%C8V5S<U]H;W-T<U]N;W1S=7!P;W)T)R`]
M/B`G06-C97-S(&AO<W1S('-E='1I;F<@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M=&AI<R!D871A8F%S92!T>7!E)RP*"2=C;&%S<U]D8E]?=6YA8FQE7V%D9"<@
M/3X@)U5N86)L92!T;R!A9&0@86-C97-S(&AO<W0@<F5C;W)D.B`E,2<L"@DG
M8VQA<W-?9&)?7W5N86)L95]D96PG(#T^("=5;F%B;&4@=&\@9&5L971E(&%C
M8V5S<R!H;W-T(')E8V]R9#H@)3$G+`H))V-L87-S7V1B7U]I;F-?=7-E<E]N
M;W1?97AI<W0G(#T^("=$871A8F%S92!U<V5R("(E,2(@9&]E<R!N;W0@97AI
M<W0G+`H))V-L87-S7V1B7U]I;F-?86-C97-S7W)E8V]R9%]E>&ES="<@/3X@
M)U1H:7,@86-C97-S(')E8V]R9"!A;')E861Y(&5X:7-T<R<L"@DG8VQA<W-?
M9&)?7VEN8U]A8V-E<W-?<F5C;W)D7VYO=%]E>&ES="<@/3X@)T=I=F5N(&%C
M8V5S<R!R96-O<F0@9&]E<R!N;W0@97AI<W0G+`H))V-L87-S7V1B7U]I;F-?
M=6YA8FQE7V1E;%]L87-T7W)E8V]R9"<@/3X@)U5N86)L92!T;R!D96QE=&4@
M=&AE(&QA<W0@86-C97-S(&AO<W0@<F5C;W)D)RP*"2=C;&%S<U]D;VUT;7!L
M961I=&9O<FU?7V1N<U]M87-T97(G(#T^(")-87-T97(B+`H))V-L87-S7V1O
M;71M<&QE9&ET9F]R;5]?9&YS7W-L879E)R`]/B`B4VQA=F4B+`H))V-L87-S
M7V1O;71M<&QE9&ET9F]R;5]?9&YS7W1Y<&4G(#T^(")4>7!E(&]F(&1O;6%I
M;B!$3E,@>F]N92(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?861M:6XG
M(#T^(")A9&UI;B(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?8VQI96YT
M)R`]/B`B8VQI96YT(BP*"2=C;&%S<U]N;W1I9FEC871I;VYF;W)M7U]C;&EE
M;G1?8W)E871I;VY?=&5X="<@/3X@(D-L:65N="!!8V-O=6YT($-R96%T:6]N
M(BP*"2=C;&%S<U]N;W1I9FEC871I;VYF;W)M7U]C;&EE;G1?97AP7W=A<FYI
M;F=?=&5X="<@/3X@(D-L:65N="!!8V-O=6YT($5X<&ER871I;VX@5V%R;FEN
M9R(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?8VQI96YT7V5X<&ER871I
M;VY?=&5X="<@/3X@(D-L:65N="!!8V-O=6YT($5X<&ER960B+`H))V-L87-S
M7VYO=&EF:6-A=&EO;F9O<FU?7V1A>7,G(#T^("(@9&%Y<R!I;B!A9'9A;F-E
M(BP*"2=C;&%S<U]N;W1I9FEC871I;VYF;W)M7U]D;VUA:6Y?8W)E871I;VY?
M=&5X="<@/3X@(D1O;6%I;B!#<F5A=&EO;B(L"@DG8VQA<W-?;F]T:69I8V%T
M:6]N9F]R;5]?9&]M86EN7V5X<%]W87)N:6YG7W1E>'0G(#T^(")$;VUA:6X@
M17AP:7)A=&EO;B!787)N:6YG(BP*"2=C;&%S<U]N;W1I9FEC871I;VYF;W)M
M7U]D;VUA:6Y?97AP:7)A=&EO;E]T97AT)R`]/B`B1&]M86EN($5X<&ER960B
M+`H))V-L87-S7VYO=&EF:6-A=&EO;F9O<FU?7V1O;6%I;E]L:6UI='-?97AC
M965D7W1E>'0G(#T^(")!8V-O=6YT($QI;6ET($YO=&EC97,B+`H))V-L87-S
M7VYO=&EF:6-A=&EO;F9O<FU?7V1O;6%I;E]U<V5R)R`]/B`B9&]M86EN(&%D
M;6EN:7-T<F%T;W(B+`H))V-L87-S7VYO=&EF:6-A=&EO;F9O<FU?7V5M86EL
M7V%D9')E<W,G(#T^(")E+6UA:6P@861D<F5S<R(L"@DG8VQA<W-?;F]T:69I
M8V%T:6]N9F]R;5]?979E;G0G(#T^(")%=F5N="(L"@DG8VQA<W-?;F]T:69I
M8V%T:6]N9F]R;5]?97AP:7)A=&EO;E]T:6UE)R`]/B`B4V5N9"!%>'!I<F%T
M:6]N(%=A<FYI;F=S("(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?:6YV
M86QI9%]E;6%I;"<@/3X@(DEN8V]R<F5C="!E+6UA:6P@861D<F5S<R!S<&5C
M:69I960N(BP*"2=C;&%S<U]N;W1I9FEC871I;VYF;W)M7U]I;G9A;&ED7V5X
M<%]T:6UE)R`]/B`B3G5M8F5R(&]F(&1A>7,@:7,@:6YV86QI9"XB+`H))V-L
M87-S7VYO=&EF:6-A=&EO;F9O<FU?7W-E;F1?;F]T:69?=&\G(#T^(")396YD
M(&YO=&EC92!T;R(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?=&EC:V5T
M7V-L;W-E9%]T97AT)R`]/B`B5&EC:V5T($-L;W-E9"(L"@DG8VQA<W-?;F]T
M:69I8V%T:6]N9F]R;5]?=&EC:V5T7V-O;6UE;G1E9%]T97AT)R`]/B`B5&EC
M:V5T($-O;6UE;G1E9"(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?=&EC
M:V5T7V-R96%T961?=&5X="<@/3X@(E1I8VME="!#<F5A=&5D(BP*"2=C;&%S
M<U]N;W1I9FEC871I;VYF;W)M7U]T:6-K971?<F5O<&5N961?=&5X="<@/3X@
M(E1I8VME="!296]P96YE9"(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?
M=&ET;&4G(#T^(").;W1I9FEC871I;VX@<W5B<V-R:7!T:6]N(BP*"2=C;&%S
M<U]S<VQC97)T:69I8V%T95]?8V%?;F]T7W-I9VYS)R`]/B`B(%1H92!#02!C
M97)T:69I8V%T92!D;V5S(&YO="!S:6=N('1H92!C97)T:69I8V%T92XB+`H)
M)V-L87-S7W-S;&-E<G1I9FEC871E7U]C85]N;W1?<VEG;G-?=V%R;B<@/3X@
M(E=A<FYI;F<Z('1H92!#02!C97)T:69I8V%T92!D;V5S(&YO="!S:6=N('1H
M92!C97)T:69I8V%T92XB+`H))V-L87-S7W-S;&-E<G1I9FEC871E7U]I;F-O
M;7!A=&EB;&5?<'9T7VME>5]C97)T)R`]/B`B26YC;VUP871I8FQE('!R:79A
M=&4@:V5Y+V-E<G1I9FEC871E('!A:7(B+`H))V-L87-S7W-S;&-E<G1I9FEC
M871E7U]I;G9A;&ED7V-E<G1?9F]R;6%T)R`]/B`B26YV86QI9"!C97)T:69I
M8V%T92!F;W)M870N(BP*"2=C;&%S<U]S<VQC97)T:69I8V%T95]?:6YV86QI
M9%]P<FEV871E7VME>5]F;W)M870G(#T^("));G9A;&ED('!R:79A=&4@:V5Y
M(&9O<FUA="XB+`H))V-L87-S7W-S;&-E<G1I9FEC871E7U]P<F]B7VEN=F%L
M:61?<')I=E]K97DG(#T^(")0<F]B86)L>2P@=&AE('!R:79A=&4@:V5Y(&9O
M<FUA="!I<R!I;G9A;&ED+B(L"@DG8VQA<W-?=')A9F9I8VAI<W1O<GE?7VYO
M7V1A=&%?879A:6QA8FQE)R`]/B`B3F\@9&%T82!A=F%I;&%B;&4N(BP*"2=C
M;&%S<U]T<F%F9FEC:&ES=&]R>5]?<F5T96Y?<')E9B<@/3X@)U1R869F:6,@
M<W1A=&ES=&EC<R!R971E;G1I;VX@<')E9F5R96YC97,G+`H))V-L87-S7W1R
M869F:6-H:7-T;W)Y7U]T<F%F9FEC7W5S86=E)R`]/B`B5')A9F9I8R!U<V%G
M92(L"@DG8VQI96YT=')A9F9I8VQI<W1?:&5A9&5R)R`]/B`B5')A9F9I8R!A
M="!D;VUA:6YS(BP*"2=C;&EE;G1T<F%F9FEC;&ES=%]H96%D97)?;V9?8VQI
M96YT7U\G(#T^(")4<F%F9FEC(&%T('1H92!D;VUA:6YS(&]F(&-L:65N="`E
M,2(L"@H))V-L:7-T7U]F:7)S="<@/3X@)T9I<G-T)RP*"2=C;&ES=%]?;&%S
M="<@/3X@)TQA<W0G+`H))V-L:7-T7U]P<F5V)R`]/B`G)FQT.R9L=#LG+`H)
M)V-L:7-T7U]N97AT)R`]/B`G)F=T.R9G=#LG+`H))V-L:7-T7U]P86=E)R`]
M/B`G4&%G97,G+`H))V-L:7-T7U]P86=E7W-I>F4G(#T^("=.=6UB97(@;V8@
M96YT<FEE<R!P97(@<&%G92<L"@DG8VQI<W1?7VEN9F\G(#T^("<E-"`E,2!T
M;W1A;"<L"@DG8VQI<W1?7VEN9F]?96UP='DG(#T^("=.;R`E,2<L"@DG8VQI
M<W1?7VEN9F]?9FEL=&5R)R`]/B`G)34@)3$@9F]U;F0G+`H))V-L:7-T7U]I
M;F9O7W!A9VEN9R<@/3X@)R4R+24S("4Q(&]F("4T('1O=&%L)RP*"2=C;&ES
M=%]?:6YF;U]P86=I;F=?9FEL=&5R)R`]/B`G)3(M)3,@)3$@;V8@)34@9F]U
M;F0G+`H))V-L:7-T7U]S96%R8VA?<VAO=R<@/3X@)U-H;W<@4V5A<F-H)RP*
M"2=C;&ES=%]?<V5A<F-H7VAI9&4G(#T^("=(:61E(%-E87)C:"<L"@H))V-M
M9%]D;G-?7V%?9&YS7W)E8V]R9%]A;')E861Y7V5X:7-T)R`]/B`B4W5C:"!!
M(')E8V]R9"!A;')E861Y(&5X:7-T<RXB+`H))V-M9%]D;G-?7V-A;F]N:6-A
M;%]D;VU?;F%M95]I<U]I;G9A;&ED)R`]/B`B0V%N;VYI8V%L(&1O;6%I;B!N
M86UE(&ES(&EN=F%L:60N(BP*"2=C;61?9&YS7U]C;F%M95]D;G-?<F5C;W)D
M7V%L<F5A9'E?97AI<W0G(#T^(")3=6-H($-.04U%(')E8V]R9"!A;')E861Y
M(&5X:7-T<RXB+`H))V-M9%]D;G-?7V-N86UE7VEN7W)R7V-O;6)I;F%T:6]N
M)R`]/B`G5&AE<F4@:7,@:6YC;W)R96-T(&-O;6)I;F%T:6]N(&]F(')E<V]U
M<F-E(')E8V]R9',@:6X@=&AE('IO;F4G+`H))V-M9%]D;G-?7V-N86UE7V-O
M97AI<W1?=VET:%]D871A)R`]/B`G02!#3D%-12!R96-O<F0@8V%N;F]T(&-O
M97AI<W0@=VET:"!O=&AE<B!R97-O=7)C92!R96-O<F1S(&EN('1H92!S86UE
M('IO;F4N)RP*"2=C;61?9&YS7U]D;G-?<F5C;W)D7W1Y<&5?:7-?:6YV86QI
M9"<@/3X@(E)E<V]U<F-E(')E8V]R9"!T>7!E(&ES(&EN=F%L:60N(BP*"2=C
M;61?9&YS7U]E>'1?:&]S=%]I<U]N;W1?<F5S;VQV960G(#T^(")5;F%B;&4@
M=&\@<F5S;VQV92!T:&4@8V%N;VYI8V%L(&YA;64@)3$N(BP*"2=C;61?9&YS
M7U]D;VUA:6Y?<F5S=&]R95]D;G-?>F]N95]F86EL961?861D7W)E8V]R9"<@
M/3X@)U5N86)L92!T;R!R97-T;W)E('1H92!$3E,@>F]N93H@86X@97)R;W(@
M;V-C=7)E9"!W:&EL92!A9&1I;F<@=&AE("4Q(')E8V]R9"<L"@DG8VUD7V1N
M<U]?;6%I;%]D;VU?;F%M95]I<U]I;G9A;&ED)R`]/B`B36%I;"!E>&-H86YG
M97(@;F%M92!I<R!I;G9A;&ED+B(L"@DG8VUD7V1N<U]?;7A?<')I;W)I='E?
M:7-?:6YV86QI9"<@/3X@(DU8('!R:6]R:71Y(&ES(&EN=F%L:60N(BP*"2=C
M;61?9&YS7U]N86UE7W-E<G9E<E]I<U]I;G9A;&ED)R`]/B`B3F%M92!S97)V
M97(@:7,@:6YV86QI9"XB+`H))V-M9%]D;G-?7VYE='=O<FM?;6%S:U]S:&]U
M;&1?8F5?,C1?,39?;W)?."<@/3X@(DYE='=O<FL@;6%S:R!V86QU92!S:&]U
M;&0@8F4@,C0L(#$V(&]R(#@N(BP*"2=C;61?9&YS7U]T:&ES7V1N<U]R96-O
M<F1?86QR96%D>5]E>&ES=',G(#T^(")3=6-H(')E<V]U<F-E(')E8V]R9"!A
M;')E861Y(&5X:7-T<RXB+`H))V-M9%]D;G-?7W5N86)L95]A9&1?<F5C;W)D
M)R`]/B`B56YA8FQE('1O(&%D9"`G)3$G(')E8V]R9#H@)3(B+`H))V-M9%]D
M;G-?7W5N86)L95]A9&1?85]R96-O<F0G(#T^(")5;F%B;&4@=&\@861D($$@
M<F5C;W)D.B`E,2(L"@DG8VUD7V1N<U]?=6YA8FQE7V%D9%]C;F%M95]R96-O
M<F0G(#T^(")5;F%B;&4@=&\@861D($-.04U%(')E8V]R9#H@)3$B+`H))V-M
M9%]D;G-?7W5N86)L95]A9&1?9&YS7W)E8V]R9"<@/3X@(E5N86)L92!T;R!A
M9&0@<F5S;W5R8V4@<F5C;W)D.B`E,2(L"@DG8VUD7V1N<U]?=6YA8FQE7V%D
M9%]E>'1?;G-?<F5C;W)D)R`]/B`B56YA8FQE('1O(&%D9"!%6%1?3E,@<F5C
M;W)D.B`E,2(L"@DG8VUD7V1N<U]?=6YA8FQE7V%D9%]N<U]R96-O<F0G(#T^
M(")5;F%B;&4@=&\@861D($Y3(')E8V]R9#H@)3$B+`H))V-M9%]D;G-?7W5N
M86)L95]A9&1?<'1R7W)E8V]R9"<@/3X@(E5N86)L92!T;R!A9&0@4%12(')E
M8V]R9#H@)3$B+`H))V-M9%]D;G-?7W5N86)L95]A9&1?='AT7W)E8V]R9"<@
M/3X@(E5N86)L92!T;R!A9&0@5%A4(')E8V]R9#H@)3$B+`H))V-M9%]D;G-?
M7W5N86)L95]C<F5A=&5?9&YS7WIO;F4G(#T^(")5;F%B;&4@=&\@8W)E871E
M('1H92!$3E,@>F]N92`E,2(L"@DG8VUD7V1N<U]?=6YA8FQE7V1E9FEN95]D
M;G-?<F5C;W)D)R`]/B`B56YA8FQE('1O(&1E9FEN92!T:&4@<F5S;W5R8V4@
M<F5C;W)D("4Q(BP*"2=C;61?9&YS7U]U;F%B;&5?9V5T7V1E9F%U;'1?9&YS
M7WIO;F5?<W1A='5S7W-E=%]T<G5E)R`]/B`B56YA8FQE('1O(')E=')I979E
M('1H92!D969A=6QT($1.4R!Z;VYE('-T871U<SH@)3$B+`H))V-M9%]D;G-?
M7W5N86)L95]I;G-E<G1?85]R96-O<F0G(#T^(")5;F%B;&4@=&\@:6YS97)T
M($$@<F5C;W)D.B`E,2(L"@DG8VUD7V1N<U]?=6YA8FQE7VEN<V5R=%]M>%]R
M96-O<F0G(#T^(")5;F%B;&4@=&\@:6YS97)T($U8(')E8V]R9#H@)3$B+`H)
M)V-M9%]D;G-?7W5N86)L95]I;G-E<G1?;G-?<F5C;W)D)R`]/B`B56YA8FQE
M('1O(&EN<V5R="!.4R!R96-O<F0Z("4Q(BP*"2=C;61?9&YS7U]U;F%B;&5?
M<V5T7V1N<U]Z;VYE7W-T871U<R<@/3X@(E5N86)L92!T;R!S970@=&AE($1.
M4R!Z;VYE('-T871U<SH@)3$B+`H))V-M9%]D;VUA:6YS7U]D;VU?86QR96%D
M>5]E>&ES=',G(#T^(")$;VUA:6X@)3$@86QR96%D>2!E>&ES=',N(BP*"2=C
M;61?9&]M86EN<U]?9&YS7W)E8V]R9%]A;')E861Y7V5X:7-T<R<@/3X@(E-U
M8V@@1$Y3(')E8V]R9"!F;W(@9&]M86EN("4Q(&%L<F5A9'D@97AI<W1S+B(L
M"@DG8VUD7V1O;6%I;G-?7V1O;5]A;')E861Y7V5X:7-T<S$G(#T^(")4:&5R
M92!A<F4@)3(@<W5B9&]M86EN<R!I;B!T:&ES(&1O;6%I;BX@1&]M86EN("4Q
M(&%L<F5A9'D@97AI<W1S+B(L"@DG8VUD7V1O;6%I;G-?7V1O;5]A;')E861Y
M7V5X:7-T<S(G(#T^(")T:&4@<W5B9&]M86EN("4Q(&%L<F5A9'D@97AI<W1S
M+B(L"@DG8VUD7V1O;6%I;G-?7W-U8F1O;5]A;')E861Y7V5X:7-T<R<@/3X@
M(E1H92!S=6)D;VUA:6X@=VET:"!S=6-H(&YA;64@86QR96%D>2!E>&ES=',N
M(BP*"2=C;61?9&]M86EN<U]?9&%L:6%S7V%L<F5A9'E?97AI<W1S)R`]/B`B
M5&AI<R!A;&EA<R!A;')E861Y(&5X:7-T<RXB+`H))V-M9%]D;VUA:6YS7U]U
M;F%B;&5?9&5L7VUA:6Q?9F]R7V1O;2<@/3X@(E5N86)L92!T;R!D96QE=&4@
M=&AE(&UA:6P@<V5R=FEC97,@9F]R(&1O;6%I;CH@)3$B+`H))V-M9%]D;VUA
M:6YS7U]U;F%B;&5?9&5L971E7V%N;VYY;6]U<U]F='`G(#T^(")5;F%B;&4@
M=&\@9&5L971E(&%N;VYY;6]U<R!&5%`@86-C;W5N="!F;W(@9&]M86EN.B`E
M,2(L"@DG8VUD7V1O;6%I;G-?7W5N86)L95]U<&1A=&5?9&]M7W!A<F%M)R`]
M/B`B56YA8FQE('1O('5P9&%T92!T:&4@9&]M86EN('!A<F%M971E<G,Z("4Q
M+B(L"@DG8VUD7V1O;6%I;G-?7W5N86)L95]R96YA;65?8VQI96YT7V5X:7-T
M)R`]/B`B9&]M86EN(&%D;6EN:7-T<F%T;W(G<R!L;V=I;B!N86UE(&ES(&%L
M<F5A9'D@:6X@=7-E+B(L"@DG8VUD7VAO<W1I;F=?7VAS=%]T>7!E7VES7VYO
M=%]P:'ES:6-A;%]H<W0G(#T^(")(;W-T:6YG('1Y<&4@:7,@;F]T('!H>7-I
M8V%L+B(L"@DG8VUD7VAO<W1I;F=?7W5N86)L95]C<F5A=&5?=7-E<B<@/3X@
M(E5N86)L92!T;R!C<F5A=&4@=7-E<B`E,CH@)3$B+`H))V-M9%]H;W-T:6YG
M7U]U;F%B;&5?9&5F:6YE7VEP7V%D9')?9F]R7VYA;65?8F%S961?=FER='5A
M;%]H;W-T<R<@/3X@(E5N86)L92!T;R!D969I;F4@25`@861D<F5S<R!F;W(@
M=&AE(&YA;64M8F%S960@=FER='5A;"!H;W-T<SH@)3$B+`H))V-M9%]H;W-T
M:6YG7U]U;F%B;&5?9&5L7V]L9%]H<W0G(#T^(")5;F%B;&4@=&\@9&5L971E
M('1H92!P<F5V:6]U<VQY('-E="!U<"!H;W-T:6YG.B`E,2(L"@DG8VUD7VAO
M<W1I;F=?7W5N86)L95]D96Q?<')O=&5C=&5D7V1I<F5C=&]R>2<@/3X@(E5N
M86)L92!T;R!D96QE=&4@<')O=&5C=&5D(&1I<F5C=&]R>3H@)3$B+`H))V-M
M9%]H;W-T:6YG7U]U;F%B;&5?9&5L7W=E8E]U<V5R)R`]/B`B56YA8FQE('1O
M(&1E;&5T92!W96(@=7-E<CH@)3$B+`H))V-M9%]H;W-T:6YG7U]U;F%B;&5?
M;6%K92]U<&1A=&5?=FER='5A;%]H;W-T)R`]/B`B56YA8FQE('1O(&-R96%T
M92!O<B!U<&1A=&4@=&AE(%9I<G1U86P@2&]S=#H@)3$B+`H))V-M9%]H;W-T
M:6YG7U]U;F%B;&5?;6%K95]F<F%M95]F;W)W87)D7VAS="<@/3X@(E5N86)L
M92!T;R!S970@=7`@=&AE(&9R86UE(&9O<G=A<F1I;F<@:&]S=&EN9RXB+`H)
M)V-M9%]H;W-T:6YG7U]U;F%B;&5?<F5B=6EL9%]F='!?8V]N9FEG)R`]/B`B
M56YA8FQE('1O(')E8G5I;&0@=&AE('!R;V9T<&0@8V]N9FEG=7)A=&EO;B!F
M:6QE.B`E,2(L"@DG8VUD7VAO<W1I;F=?7W5N86)L95]S971?=7!?<W-L)R`]
M/B`B56YA8FQE('1O('-E="!U<"!34TP@)3$B+`H))V-M9%]H;W-T:6YG7U]U
M;F%B;&5?=6YP<F]T96-T7W-S;%]D:7)E8W1O<GDG(#T^(")5;F%B;&4@=&\@
M<F5M;W9E('!R;W1E8W1I;VX@9G)O;2!T:&4@4U-,(&1I<F5C=&]R>3H@)3$B
M+`H))V-M9%]H;W-T:6YG7U]U;F%B;&5?=7!D871E7V1E<W1?=7)L)R`]/B`B
M56YA8FQE('1O('5P9&%T92!T:&4@9&5S=&EN871I;VX@55),("4Q(BP*"2=C
M;61?:&]S=&EN9U]?=6YA8FQE7W5P9&%T95]D;G-?>F]N95]F;W)?9&]M7W5N
M86)L95]E>&5C7W5T:6PG(#T^(")5;F%B;&4@=&\@=7!D871E('1H92!$3E,@
M>F]N92!F;W(@=&AE(&1O;6%I;CH@=71I;&ET>2!E>&5C=71I;VX@9F%I;&5D
M+B(L"@DG8VUD7VAO<W1I;F=?7W5N86)L95]U<&1A=&5?9G1P7W!A<W-W9"<@
M/3X@(E5N86)L92!T;R!U<&1A=&4@1E10('!A<W-W;W)D("4Q(BP*"2=C;61?
M:&]S=&EN9U]?=6YA8FQE7W5P9&%T95]U<V5R)R`]/B`B56YA8FQE('1O('5P
M9&%T92!U<V5R("4R.B`E,2(L"@DG8VUD7VAO<W1I;F=?7W5N:VYO=VY?:'-T
M7W1Y<&4G(#T^(")5;FMN;W=N(&AO<W1I;F<@='EP92XB+`H))V-M9%]H;W-T
M:6YG7U]Y;W5?;F]T7VAA=F5?<&5R;6ES<VEO;E]D96Q?:'-T)R`]/B`B66]U
M(&1O(&YO="!H879E('1H92!P97)M:7-S:6]N('1O('1E<FUI;F%T92!H;W-T
M:6YG('-E<G9I8V4N(BP*"2=C;61?;6%I;%]?861D<E]A;')E861Y7W5S961?
M:6Y?;6%I;%]R961I<F5C="<@/3X@(D%D9')E<W,@)3$@:7,@86QR96%D>2!B
M96EN9R!U<V5D(&EN(&$@;6%I;"!R961I<F5C="XB+`H))V-M9%]M86EL7U]A
M;&EA<U]A;')E861Y7V5X:7-T<R<@/3X@(F%L:6%S(&%L<F5A9'D@97AI<W1S
M+B(L"@DG8VUD7VUA:6Q?7V%U=&]R97-P7VED7V%N9%]M86EL;F%M95]I9%]N
M;W1?;6%T8V@G(#T^(")!=71O<F5S<&]N9&5R(&ED(&%N9"!M86EL(&YA;64@
M:60@9&\@;F]T(&UA=&-H(2(L"@DG8VUD7VUA:6Q?7V%U=&]R97-P7VED7VES
M7W5N9&5F:6YE9"<@/3X@(D%U=&]R97-P;VYD97(@:60@:7,@=6YD969I;F5D
M+B(L"@DG8VUD7VUA:6Q?7VUA:6Q?86QI87-?86QR96%D>5]E>&ES='-?:6Y?
M;6%I;%]N86UE)R`]/B`B5&AE(&UA:6P@86QI87,@=VET:"!S=6-H(&YA;64@
M86QR96%D>2!E>&ES=',@9F]R('1H92!M86EL(&YA;64@)3$B+`H))V-M9%]M
M86EL7U]M86EL7VYA;65?86QR96%D>5]E>&ES='-?:6Y?;6%I;&QI<W1S)R`]
M/B`B36%I;"!N86UE("4Q(&ES(&%L<F5A9'D@:6X@82!M86EL:6YG(&QI<W0B
M+`H))V-M9%]M86EL7U]M86EL7VYA;65?86QR961Y7V5X:7-T7VEN7V1O;2<@
M/3X@(E1H92!M86EL(&YA;64@)3$@:7,@86QR96%D>2!I;B!T:&4@9&]M86EN
M(BP*"2=C;61?;6%I;%]?;6%I;%]N86UE7VYO=%]E>&ES="<@/3X@(E1H92!M
M86EL(&YA;64@9&]E<R!N;W0@97AI<W0N(BP*"2=C;61?;6%I;%]?;6%I;%]N
M86UE7W!A<W-W9%]P87)T)R`]/B`B5&AE('!A<W-W;W)D('-H;W5L9"!N;W0@
M8V]N=&%I;B!M86EL(&YA;64@87,@:71S('!A<G0N(BP*"2=C;61?;6%I;%]?
M;6%I;%]P87-S=V1?:6YC;W)R96-T)R`]/B`B7&Y4:&4@<&%S<W=O<F0@:7,@
M:6YC;W)R96-T+"!U<V4@870@;&5A<W0@-2!C:&%R86-T97)S+B!4:&4@<&%S
M<W=O<F0@<VAO=6QD(&YO="!C;VYT86EN(&UA:6P@;F%M92!A<R!I=',@<&%R
M="Y<;D]N;'D@3&%T:6X@8VAA<F%C=&5R<RP@;F\@9&EC=&EO;F%R>2!W;W)D
M<R`H;W!T:6]N86PI+B(L"@DG8VUD7VUA:6Q?7VUA:6Q?<F5D:7)E8W1?861D
M<E]I<U]I;G9A;&ED)R`]/B`B36%I;"!R961I<F5C="!A9&1R97-S(&ES(&EN
M=F%L:60N(BP*"2=C;61?;6%I;%]?;6%I;&QI<W1?86QR96%D>5]E>&ES=%]I
M;E]T:&ES7V1O;2<@/3X@(DUA:6QI;F<@;&ES="`E,2!A;')E861Y(&5X:7-T
M<R!O;B!T:&ES(&1O;6%I;BXB+`H))V-M9%]M86EL7U]M86EL;&ES=%]A;')E
M861Y7V5X:7-T<R<@/3X@(FUA:6QI;F<@;&ES="!A;')E861Y(&5X:7-T<RXB
M+`H))V-M9%]M86EL7U]M86EL;F%M95]A;')E861Y7V5X:7-T7VEN7VUG)R`]
M/B`B36%I;"!N86UE("4Q(&ES(&%L<F5A9'D@:6X@82!M86EL(&=R;W5P+B(L
M"@DG8VUD7VUA:6Q?7VUA:6QN86UE7V%L<F5A9'E?97AI<W1?:6Y?<F5D:7(G
M(#T^(")-86EL(&YA;64@)3$@:7,@86QR96%D>2!I;B!A(')E9&ER96-T+B(L
M"@DG8VUD7VUA:6Q?7VUA:6QN86UE7V%L<F5A9'E?97AI<W1?:6Y?=&AI<U]D
M;VTG(#T^(")-86EL(&YA;64@)3$@86QR96%D>2!E>&ES=',@:6X@=&AI<R!D
M;VUA:6XN(BP*"2=C;61?;6%I;%]?;6%I;&YA;65?86QR96%D>5]E>&ES=',G
M(#T^(")M86EL(&YA;64@86QR96%D>2!E>&ES=',N(BP*"2=C;61?;6%I;%]?
M;6%I;&YA;65?:7-?:6YV86QI9"<@/3X@(DUA:6P@;F%M92`E,2!I<R!I;G9A
M;&ED+B(L"@DG8VUD7VUA:6Q?7VUA:6QN86UE7W5N86)L95]U<&1A=&4G(#T^
M(")5;F%B;&4@=&\@=7!D871E('1H92!M86EL(&YA;64@<')O<&5R=&EE<SHB
M+`H))V-M9%]M86EL7U]M87A?875T;W)E<W!?<F5A8VAE9%]F;W)?=&AI<U]D
M;VTG(#T^(")-87AI;75M(&YU;6)E<B!O9B!A=71O<F5S<&]N9&5R<R!I<R!R
M96%C:&5D(&9O<B!T:&ES(&1O;6%I;BXB+`H))V-M9%]M86EL7U]M87A?;6%I
M;%]G<F]U<'-?;G5M7VAA<U]B965N7W)E86-H961?9F]R7W1H:7-?9&]M)R`]
M/B`B;6%X:6UU;2!N=6UB97(@;V8@;6%I;"!G<F]U<',@:&%S(&)E96X@<F5A
M8VAE9"!F;W(@=&AI<R!D;VUA:6XN(BP*"2=C;61?;6%I;%]?;6%X7VYU;5]O
M9E]R961I<F5C='-?:&%S7V)E96Y?<F5A8VAE9%]F;W)?=&AI<U]D;VTG(#T^
M(")M87AI;75M(&YU;6)E<B!O9B!R961I<F5C=',@:&%S(&)E96X@<F5A8VAE
M9"!F;W(@=&AI<R!D;VUA:6XN(BP*"2=C;61?;6%I;%]?;6%X7W!O<W1B;WAE
M<U]N=6U?:&%S7V)E96Y?<F5A8VAE9"<@/3X@(FUA>&EM=6T@;G5M8F5R(&]F
M(&UA:6QB;WAE<R!H87,@8F5E;B!R96%C:&5D+B(L"@DG8VUD7VUA:6Q?7VYO
M7VUE;6)E<G-?<W!E8VEF:65D)R`]/B`B;F\@;65M8F5R<R!S<&5C:69I960N
M(BP*"2=C;61?;6%I;%]?=&AE7W!A<W-W9%]I<U]T;V]?<VEM<&QE7V-H;V]S
M95]A;F]T:&5R)R`]/B`B5&AE('!A<W-W;W)D(&ES('1O;R!S:6UP;&4L('!L
M96%S92!C:&]O<V4@86YO=&AE<BXB+`H))V-M9%]M86EL7U]T:&ES7V%D9')?
M86QR96%D>5]E>&ES=%]I;E]M9U]O<E]M;B<@/3X@(E1H:7,@861D<F5S<R!I
M<R!A;')E861Y(&EN(&$@;6%I;"!G<F]U<"!O<B!M86EL(&YA;64N(BP*"2=C
M;61?;6%I;%]?=6YA8FQE7V1E9FEN95]A=71O<F5S<%]I9"<@/3X@(E5N86)L
M92!T;R!D969I;F4@875T;W)E<W!O;F1E<B!I9"`E,2(L"@DG8VUD7VUA:6Q?
M7W5N86)L95]D96Q?;6%I;%]F;W)?9&]M)R`]/B`B56YA8FQE('1O(')E;6]V
M92!T:&4@;6%I;"!S97)V:6-E(&9R;VT@9&]M86EN("4Q(BP*"2=C;61?;6%I
M;%]?=6YA8FQE7V1E;%]M86EL7W)E9&ER96-T:6]N)R`]/B`B56YA8FQE('1O
M(')E;6]V92!M86EL(')E9&ER96-T:6]N("4Q(BP*"2=C;61?;6%I;%]?=6YA
M8FQE7W)E;6]V95]A=71O<F5S<"<@/3X@(E5N86)L92!T;R!R96UO=F4@875T
M;W)E<W!O;F1E<G,Z("4Q(BP*"2=C;61?;6%I;%]?=6YA8FQE7W)E;6]V95]M
M86EL7V=R;W5P7VUE;6)E<G,G(#T^(")5;F%B;&4@=&\@<F5M;W9E('1H92!M
M86EL(&=R;W5P(&UE;6)E<G,Z("4Q(BP*"2=C;61?;6%I;%]?=6YA8FQE7W)E
M;6]V95]R961I<F5C="<@/3X@(E5N86)L92!T;R!R96UO=F4@<F5D:7)E8W0Z
M("4Q(BP*"2=C;61?;6%I;%]?=6YA8FQE7W1U<FY?;V9F7VUA:6Q?9W)O=7`G
M(#T^(")&86EL960@=&\@9&ES86)L92!T:&4@;6%I;"!G<F]U<#H@)3$B+`H)
M)V-M9%]M86EL7U]U;F%B;&5?=7!D871E7VUA:6Q?<F5D:7)E8W0G(#T^(")5
M;F%B;&4@=&\@=7!D871E('1H92!M86EL(')E9&ER96-T("4Q(BP*"2=C;61?
M;6%I;%]?=6YA8FQE7W5P9&%T95]M8F]X7W%U;W1A)R`]/B`B56YA8FQE('1O
M('5P9&%T92!T:&4@;6%I;&)O>"!Q=6]T82XB+`H))V-M9%]M86EL7U]U<&QO
M861E9%]F:6QE7VES7W1O;U]B:6<G(#T^(")5<&QO861E9"!F:6QE('-I>F4@
M:7,@=&]O(&QA<F=E+B(L"@DG8VUD7VUA:6Q?7V%D9&ET:6]N86QL>2<@/3X@
M(D%D9&ET:6]N86QL>3H@(BP*"2=C;61?<&1?7VEN=F%L:61?;&]G:6XG(#T^
M("));F-O<G)E8W0@;&]G:6XN(BP*"2=C;61?<&1?7W1H:7-?=7-E<E]A;')E
M861Y7V5X:7-T)R`]/B`B4W5C:"!U<V5R(&%L<F5A9'D@97AI<W1S+B(L"@DG
M8VUD7W!D7U]U;F%B;&5?9&5F:6YE7VAS=%]T>7!E)R`]/B`B56YA8FQE('1O
M(&1E9FEN92!H;W-T:6YG('1Y<&4N(BP*"2=C;61?<&1?7W5N86)L95]U<&1?
M<&1?=7-R)R`]/B`B56YA8FQE('1O('5P9&%T92!P<F]T96-T960@9&ER96-T
M;W)Y('5S97(@<')O<&5R=&EE<SH@)3$B+`H))V-M9%]P9%]?=7-E<E]I<U]U
M;F1E9FEN960G(#T^(")5<V5R(&ES('5N9&5F:6YE9"XB+`H))V-M9%]S97)V
M97)?7VYO7V5N;W5G:%]F<F5E7V1I<VM?<W!A8V4G(#T^(").;W0@96YO=6=H
M(&1I<VL@<W!A8V4N(BP*"2=C;61?<V5R=F5R7U]O;&1?<&%S<W=D7VES7VEN
M8V]R<F5C=%]P;&5A<V5?=')Y7V%G86EN)R`]/B`B;VQD('!A<W-W;W)D(&ES
M(&EN8V]R<F5C="X@4&QE87-E+"!T<GD@86=A:6XN(BP*"2=C;61?=V5B7W5S
M<E]?;6%X7W=E8E]U<V5R<U]R96%C:&5D7V9O<E]T:&ES7V1O;2<@/3X@(FUA
M>&EM=6T@=V5B('5S97)S(&QI;6ET(&ES(')E86-H960@9F]R('1H:7,@9&]M
M86EN+B(L"@DG8VUD7W=E8E]U<W)?7W5N86)L95]C<F5A=&5?=7-E<B<@/3X@
M(G5N86)L92!T;R!C<F5A=&4@<WES=&5M('5S97(Z("4Q(BP*"2=C;61?=V5B
M7W5S<E]?=6YA8FQE7V1E9FEN95]M87A?=V5B7W5S97)S7VQI;6ET)R`]/B`B
M=6YA8FQE('1O(&1E9FEN92!M87AI;75M('=E8B!U<V5R<R!L:6UI=#H@)3$B
M+`H))V-M9%]W96)?=7-R7U]U<V5R7V%L<F5A9'E?97AI<W1S)R`]/B`B=7-E
M<B!A;')E861Y(&5X:7-T<RXB+`H))V-M9%]W96)?=7-R7U]W96)?=7-E<E]N
M86UE7VES7VEN=F%L:60G(#T^(")W96(@=7-E<B!N86UE("4Q(&ES(&EN=F%L
M:60N(BP*"2=C;61?=V5B7W5S<E]?=V5B7W5S97)?;F]T7V5X:7-T)R`]/B`B
M=V5B('5S97(@9&]E<R!N;W0@97AI<W0N(BP*"2=C;VUM;VY?9G5N8U]?97AE
M8U]B861?87)G=6UE;G0G(#T^(")E>&5C(&%R9W5M96YT('-H;W5L9"!N;W0@
M8V]N=&%I;B!S:6YG;&4@<75O=&4@<WEM8F]L+B(L"@DG8V]M;6]N7V%C;%]?
M861D7V%D9')E<W,G(#T^("=!9&0@=&\@0V]M;6]N($%L;&]W(%IO;F4@5')A
M;G-F97(@04-,)RP*"2=C;VUM;VY?86-L7V%D9%]R96-O<F0G(#T^("=!9&0@
M82!!0TP@<F5C;W)D)RP*"2=E;G1E<E]I<%]O<E]N971W;W)K7V%D9')E<W,G
M(#T^("=%;G1E<B!)4"!O<B!N971W;W)K(&%D9')E<W,G+`H))U]?96]L)R`]
M/B`G3&EN92!B<F5A:W,G+`H))V5O;%]?;F]N92<@/3X@)V1O(&YO="!M;V1I
M9GDG+`H))V5O;%]?;&8G(#T^("=I;B!5;FEX('-T>6QE)RP*"2=E;VQ?7V-R
M)R`]/B`G:6X@36%C3U,@<W1Y;&4G+`H))V5O;%]?8W)L9B<@/3X@)VEN(%=I
M;F1O=W,@<W1Y;&4G+`H))V5O;%]?8FEN87)Y7V9I;&4G(#T^("=5;F%B;&4@
M=&\@8VAA;F=E(&QI;F4@8G)E86L@<W1Y;&4@:6X@8FEN87)Y(&9I;&4N)RP*
M"2=C;VUP7VEN9F]?7VAE861E<B<@/3X@)T-O;7!O;F5N=',G+`H))V-O;7!?
M:6YF;U]?8V]M<%]N86UE)R`]/B`B0V]M<&]N96YT(&YA;64B+`H))V-O;7!?
M:6YF;U]?8V]M<%]V97)S:6]N)R`]/B`B0V]M<&]N96YT('9E<G-I;VXB+`H)
M)V-O;7!?:6YF;U]?=&ET;&4G(#T^("));F9O<FUA=&EO;B!O;B`E,2!C;VUP
M;VYE;G1S(BP*"2=C;VYF:6=U<F5?7V9U;&Q?:&]S=&YA;65?:&EN="<@/3X@
M)U-P96-I9GD@=&AE(&9U;&QY('%U86QI9FEE9"!D;VUA:6X@;F%M92!F;W(@
M=&AI<R!S97)V97(N($5X86UP;&4Z(&AO<W1N86UE+F1O;6%I;BYC;VTG+`H)
M)V-O;F9I9W5R95]?9&5F875L=%]I<%]A9&1R97-S7VAI;G0G(#T^("=3<&5C
M:69Y('1H92!)4"!A9&1R97-S('1H870@=VEL;"!B92!U<V5D(&%S('1H92!M
M86EN('-E<G9E<B!)4"!A9&1R97-S+B!396QE8W0@86X@97AI<W1I;F<@25`@
M861D<F5S<R!O<B!C;&EC:R!!9&0@25`@061D<F5S<R!T;R!A9&0@82!N97<@
M25`@861D<F5S<R!T;R!T:&4@<WES=&5M+B!)9B!Y;W4@=V%N="!T:&4@;F5W
M($E0(&%D9')E<W,@=&\@8F4@<VAA<F5D(&)E='=E96X@<V5V97)A;"!C;&EE
M;G0@86-C;W5N=',L('-E;&5C="!T:&4@4VAA<F5D(&-H96-K(&)O>"XG+`H)
M)V-O;F9I9W5R95]?9&5F875L=%]I<%]A9&1R97-S7VAI;G1?<V5L96-T7V]N
M;'DG(#T^("=3<&5C:69Y('1H92!)4"!A9&1R97-S('1H870@=VEL;"!B92!U
M<V5D(&%S('1H92!M86EN($E0(&%D9')E<W,@9F]R('1H:7,@<V5R=F5R+B<L
M"@DG8V]N9FEG=7)E7U]S:&%R961?:7!?861D<F5S<U]H:6YT)R`]/B`G66]U
M(&-A;B!C:&%N9V4@=&AE('1Y<&4@;V8@97AI<W1I;F<@25`@861D<F5S<V5S
M(&9R;VT@97AC;'5S:79E('1O('-H87)E9"X@4VAA<F5D($E0(&%D9')E<W-E
M<R!C86X@8F4@87-S:6=N960@=&\@;75L=&EP;&4@8VQI96YT(&%C8V]U;G1S
M+B!4;R!C:&%N9V4@=&AE($E0(&%D9')E<W,@='EP92!F<F]M(&5X8VQU<VEV
M92!T;R!S:&%R960L('-E;&5C="!)4"!A9&1R97-S97,@:6X@=&AE(&QI<W0@
M;V8@97AC;'5S:79E($E0(&%D9')E<W-E<RP@86YD(&-L:6-K(%-H87)E9"XG
M+`H))U]?9&5F875L=%]I<%]A9&1R97-S)R`]/B`G1&5F875L="!)4"!!9&1R
M97-S)RP*"2=C;VYF:6=U<F5?7V1E9F%U;'1?:7!?<V5L96-T)R`]/B`G4V5L
M96-T(&%N(&%D9')E<W,G+`H))V-O;F9I9W5R95]?9&5F875L=%]I<%]N97<G
M(#T^("=!9&0@25`@061D<F5S<R<L"@DG8V]N9FEG=7)E7U]I<%]I;G1E<F9A
M8V4G(#T^("=);G1E<F9A8V4G+`H))V-O;F9I9W5R95]?:7!?861D<F5S<R<@
M/3X@)TE0($%D9')E<W,G+`H))V-O;F9I9W5R95]?:7!?<VAA<F5D)R`]/B`G
M4VAA<F5D)RP*"2=C;VYF:6=U<F5?7W-E;&5C=%]E>&QU<VEV95]I<',G(#T^
M("=%>&-L=7-I=F4@25`@861D<F5S<V5S)RP*"2=C;VYF:6=U<F5?7W-E;&5C
M=%]S:&%R961?:7!S)R`]/B`G4VAA<F5D($E0(&%D9')E<W-E<R<L"@DG8V]N
M9FEG=7)E7U]A9&UI;E]P87-S=V]R9%]C:&%N9V4G(#T^(")0;&5A<V4@8VAA
M;F=E('1H92!D969A=6QT(&%D;6EN:7-T<F%T;W(@<&%S<W=O<F0N(BP*"2=C
M;VYF:6=U<F5?7V5R<F]R7VYA;65D7W)E<W1A<G0G(#T^(").86UE9"!R97-T
M87)T(&5R<F]R+B!&;W(@<')O<&5R(&YA;65D('=O<FL@>6]U('-H;W5L9"!R
M97-T87)T(&ET+B(L"@DG8V]N9FEG=7)E7U]F:6QL7V9O;&QO=VEN9U]F:65L
M9',G(#T^(")&:6QL('1H92!R97%U97-T960@:6YF;W)M871I;VX@:6YT;R!T
M:&4@87!P<F]P<FEA=&4@9FEE;&1S+B!4:&ES(&EN9F]R;6%T:6]N(&ES(')E
M<75I<F5D(&9O<B`E,2!T;R!W;W)K+B(L"@DG8V]N9FEG=7)E7U]F=6QL7VAO
M<W1N86UE)R`]/B`B1G5L;"!H;W-T;F%M92(L"@DG8V]N9FEG=7)E7U]U;F%B
M;&5?8V]N9FEG=7)E)R`]/B`B56YA8FQE('1O(&-O;F9I9W5R93H@)3$B+`H)
M)V-P7V%C8V5S<U]A9&UI;E]D96YY)R`]/B`B06-C97-S(&9O<B!A9&UI;FES
M=')A=&]R(&9R;VT@861D<F5S<R`G)3$G(&ES(')E<W1R:6-T960@:6X@86-C
M;W)D86YC92!W:71H($E0($%C8V5S<R!R97-T<FEC=&EO;B!P;VQI8WD@8W5R
M<F5N=&QY(&%P<&QI960N(BP*"2=C<%]A8V-E<W-?8W5R<E]I<%]A8V-E<W-?
M9&5N>2<@/3X@(E=A<FYI;F<A(2$@5&AE(&%C8V5S<R!R97-T<FEC=&EO;B!P
M;VQI8WD@86YD('1H92!L:7-T(&]F(&YE='=O<FMS(&%R92!C=7)R96YT;'D@
M8V]N9FEG=7)E9"!T:&4@=V%Y('EO=2!W:6QL(&YO="!B92!A8FQE('1O(&QO
M9VEN('=I=&@@861M:6YI<W1R871O<B=S(')I9VAT<R!F<F]M('EO=7(@25`@
M861D<F5S<R`G)3$G+B(L"@DG8W!?86-C97-S7V5D:71?:&5A9&5R)R`]/B`B
M3F5T=V]R:R!E9&ET:6YG(BP*"2=C<%]A8V-E<W-?97AI<W1S)R`]/B`B5&AE
M(&YE='=O<FL@:7,@86QR96%D>2!I;B!T:&4@25`@86-C97-S(')E<W1R:6-T
M:6]N(&QI<W0N(BP*"2=C<%]A8V-E<W-?:&5A9&5R)R`]/B`B25`@86-C97-S
M(')E<W1R:6-T:6]N(&UA;F%G96UE;G0B+`H))V-P7V%C8V5S<U]P;VQI8WDG
M(#T^(")#;VYT<F]L('!A;F5L(&%C8V5S<R!W:71H(&%D;6EN:7-T<F%T;W(G
M<R!P<FEV:6QE9V5S(BP*"2=C<%]A8V-E<W-?<&]L:6-Y7V%L;&]W)R`]/B`B
M06QL;W=E9"P@97AC;'5D:6YG('1H92!N971W;W)K<R!I;B!T:&4@;&ES="XB
M+`H))V-P7V%C8V5S<U]P;VQI8WE?9&5N>2<@/3X@(D1E;FEE9"!F<F]M('1H
M92!N971W;W)K<R!T:&%T(&%R92!N;W0@;&ES=&5D+B(L"@DG8W!?86-C97-S
M7W)E;6]V95]H96%D97(G(#T^(").971W;W)K(')E;6]V86PB+`H))V-P7V%C
M8V5S<U]S96QE8W1?:7`G(#T^(")396QE8W0@;VYE(&]R('-E=F5R86P@;F5T
M=V]R:W,@9G)O;2!T:&4@25`@86-C97-S(')E<W1R:6-T:6]N(&QI<W0N(BP*
M"2=C<%]A8V-E<W-?<W=I=&-H7V-O;F9I<FUA=&EO;B<@/3X@(D-H86YG92!T
M:&4@86-C97-S('!O;&EC>3\B+`H))V-P7V%C8V5S<U]S=VET8VA?9&5N>5]E
M<G)O<B<@/3X@(E5N86)L92!T;R!C:&%N9V4@=&AE(&%C8V5S<R!P;VQI8WDZ
M(&YO(&YE='=O<FMS('-P96-I9FEE9"(L"@DG8W!?86-C97-S7W-W:71C:%]D
M96YY7VYO=R<@/3X@(E1H92!A8V-E<W,@<&]L:6-Y('=A<R!C:&%N9V5D(&)E
M8V%U<V4@=&AE<F4@87)E(&YO(&YE='=O<FMS('-P96-I9FEE9"XB+`H))V-P
M7V%C8V5S<U]?;F5T=V]R:U]A9&1R97-S)R`]/B`G4W5B;F5T(&]R($E0(&%D
M9')E<W,G+`H))V-P7V%C8V5S<U]?;F5T=V]R:U]M87-K)R`]/B`G4W5B;F5T
M(&UA<VLG+`H))V-R96%T95]D;VUA:6Y?=V%R;E]?)R`]/B`B5&AE(&9O;&QO
M=VEN9R!E>&-E<'1I;VYS('=E<F4@;6%D92!D=7)I;F<@9&]M86EN(&-R96%T
M:6]N.B(L"@DG8W)E871E7V1O;6%I;E]?8VQI96YT7W-E;&5C="<@/3X@)U-E
M;&5C="!T:&4@8VQI96YT('1O(&-R96%T92!T:&4@9&]M86EN(&9O<B<L"@DG
M8W)O;G1A8E]?8W)O;G1A8E]E;G1R>5]E>&ES=',G(#T^(")4:&4@)3$@=&%S
M:R!A;')E861Y(&5X:7-T<R(L"@DG8W)O;G1A8E]?8W)O;G1A8E]E;G1R>5]N
M;W1?97AI<W1S)R`]/B`B5&AE("4Q('1A<VL@9&]E<R!N;W0@97AI<W0B+`H)
M)V-R;VYT86)?7VEN=F%L:61?=F%L=65S7V9O=6YD)R`]/B`B5&AE<F4@87)E
M(&EN8V]R<F5C="!P87)A;65T97(@=F%L=65S(BP*"2=C<F]N=&%B7V5D:71?
M7V-R;VYT86)?;V9?7R<@/3X@(D5D:71I;F<@=&AE("4Q('1A<VL@;V8@)3(B
M+`H))V-R;VYT86)?961I=%]?8VUD7VUA>%]L96XG(#T^(")4:&4@8V]M;6%N
M9"!Y;W4@<W!E8VEF:65D(&5X8V5E9',@=&AE(&%L;&]W960@;&5N9W1H("@E
M,2!S>6UB;VQS*2XB+`H))V-R;VYT86)?;&ES=%]?;6%I;%]T;U]?)R`]/B`B
M4V5N9"`E,2!M97-S86=E<R!T;R!A9&1R97-S("4R(BP*"2=C<F]N=&%B7VQI
M<W1?7VUA:6Q?=&]?:7-?:6YV86QI9"<@/3X@(E1H92!A9&1R97-S(&9O<B`E
M,2!M97-S86=E<R!D96QI=F5R>2!I<R!I;F-O<G)E8W0B+`H))V-R;VYT86)?
M;&ES=%]?<F5M;W9E7V]N7W5S97)?7R<@/3X@(E)E;6]V92!T:&4@<V-H961U
M;&5D('1A<VMS(&]F("4R(BP*"2=C<F]N=&%B7VQI<W1?7W-E;&5C=%]T;U]R
M96UO=F4G(#T^(")396QE8W0@=&AE("4Q('1A<VMS('1O(&)E(')E;6]V960N
M(BP*"2=C<F]N=&%B7VQI<W1?7W-H;W=?8W)O;G1A8E]O9E]?)R`]/B`B4VAO
M=R`E,2!O9B`E,B(L"@DG8W)O;G1A8E]L:7-T7U]S>7-U<V5R7VQI<W1?96UP
M='DG(#T^(")4:&5R92!A<F4@;F\@)3$@=&%S:W,@879A:6QA8FQE(BP*"2=C
M<F]N=&%B7VQI<W1?7W1A<VMS)R`]/B`B)3$@=&%S:W,B+`H*"2=C=7-T;VU?
M8G5T=&]N7U]S;W)T7VME>2<)"3T^("=0<FEO<FET>2<L"@DG8W5S=&]M7V)U
M='1O;E]?<&QA8V4G"0D)/3X@)TQO8V%T:6]N)RP*"2=C=7-T;VU?8G5T=&]N
M7U]P;&%C95]N879I9V%T:6]N)PD]/B`G3F%V:6=A=&EO;B!P86YE;"<L"@DG
M8W5S=&]M7V)U='1O;E]?<&QA8V5?861M:6XG"0D]/B`G061M:6YI<W1R871O
M<EPG<R!$97-K=&]P)RP*"2=C=7-T;VU?8G5T=&]N7U]P;&%C95]C;&EE;G0G
M"0D]/B`G0VQI96YT7"=S($1E<VMT;W`@+R!(;VUE('!A9V4G+`H))V-U<W1O
M;5]B=71T;VY?7W!L86-E7V1O;6%I;B<)"3T^("=$;VUA:6X@3W=N97)<)W,@
M1&5S:W1O<"`O($AO;64@<&%G92<L"@DG8W5S=&]M7V)U='1O;E]?<'5B;&EC
M)PD)"3T^("=6:7-I8FQE('1O(&%L;"!S=6(M;&]G:6YS)RP*"2=C=7-T;VU?
M8G5T=&]N7U]I;6%G92<)"0D]/B`G0F%C:V=R;W5N9"!I;6%G92<L"@DG8W5S
M=&]M7V)U='1O;E]?8V]N:&5L<"<)"3T^(")#;VYT97AT(&AE;'`@=&EP(&-O
M;G1E;G1S(BP*"2=C=7-T;VU?8G5T=&]N7U]E9&ET)PD)"3T^(")#=7-T;VT@
M0G5T=&]N(%!R;W!E<G1I97,B+`H))V-U<W1O;5]B=71T;VY?7VEN8VQU9&5?
M8VQI96YT7V-N86UE)PD]/B`B26YC;'5D92!C;&EE;G0G<R!C;VUP86YY(&YA
M;64B+`H))V-U<W1O;5]B=71T;VY?7VEN8VQU9&5?8VQI96YT7V5M86EL)R`]
M/B`B26YC;'5D92!C;&EE;G0G<R!E+6UA:6PB+`H))V-U<W1O;5]B=71T;VY?
M7VEN8VQU9&5?8VQI96YT7VED)R`]/B`B26YC;'5D92!C;&EE;G0@:60B+`H)
M)V-U<W1O;5]B=71T;VY?7VEN8VQU9&5?8VQI96YT7W!N86UE)R`]/B`B26YC
M;'5D92!C;&EE;G0G<R!C;VYT86-T(&YA;64B+`H))V-U<W1O;5]B=71T;VY?
M7VEN8VQU9&5?9&]M86EN7VED)R`]/B`B26YC;'5D92!D;VUA:6X@:60B+`H)
M)V-U<W1O;5]B=71T;VY?7VEN8VQU9&5?9&]M86EN7VYA;64G(#T^("));F-L
M=61E(&1O;6%I;B!N86UE(BP*"2=C=7-T;VU?8G5T=&]N7U]I;F-L=61E7V9T
M<%]U<V5R)R`]/B`B26YC;'5D92!&5%`@3&]G:6XB+`H))V-U<W1O;5]B=71T
M;VY?7VEN8VQU9&5?9G1P7W!A<W,G(#T^("));F-L=61E($944"!P87-S=V]R
M9"(L"@DG8W5S=&]M7V)U='1O;E]?:6YT97)N86Q?;W!E;B<@/3X@(D]P96X@
M55),(&EN('1H92!#;VYT<F]L(%!A;F5L(BP*"2=C=7-T;VU?8G5T=&]N7U]T
M97AT)R`]/B`B0G5T=&]N(&QA8F5L(BP*"2=C=7-T;VU?8G5T=&]N7U]U<FPG
M(#T^(")54DPB+`H*"2=C=7-T;VU?8G5T=&]N<U]?96UP='E?<V5L96-T:6]N
M)R`]/B`B4V5L96-T('1H92!B=71T;VYS('1O(&)E(')E;6]V960N(BP*"2=C
M=7-T;VU?8G5T=&]N<U]?;F%M92<@/3X@(DQA8F5L(BP*"2=C=7-T;VU?8G5T
M=&]N<U]?<'5B;&EC)R`]/B`G02<L+R]"=71T;VX@86-C97-S:6)I;&ET>2!P
M<F]P97)T>0H))V-U<W1O;5]B=71T;VYS7U]S;W)T7VME>2<@/3X@)U!R:6]R
M:71Y)RP@+R]4:&ES(&ES('1H92!L:7-T('1I=&QE('=H:6-H(&EN9&EC871E
M<R!T:&4@;W)D97(@;V8@=&AE(&-U<G)E;G0@8G5T=&]N"@DG8W5S=&]M7V)U
M='1O;G-?7W!L86-E)R`]/B`G3"<L+R],;V-A=&EO;@H))V-U<W1O;5]B=71T
M;VYS7U]R96UO=F4G(#T^(")4:&4@9F]L;&]W:6YG(&)U='1O;G,@=VEL;"!B
M92!R96UO=F5D.B(L"@DG8G1?9&]M86EN7V%L:6%S97,G(#T^("=$;VUA:6X@
M06QI87-E<R<L"@DG8G1?9&]M86EN7V%L:6%S7V%D9"<@/3X@)T%D9"!$;VUA
M:6X@06QI87,G+`H))W!B7U]D;VUA:6Y?86QI87-E<R<@/3X@)T1O;6%I;B!A
M;&EA<V5S)RP*"2=D87-H8F]A<F1?7VYA=E]B=71T;VY?;F%M92<@/3X@(D1E
M<VMT;W`B+`H))V1A;&EA<U]?;&ES=%]T:71L92<@/3X@)T1O;6%I;B!A;&EA
M<V5S(&]F('1H92!D;VUA:6X@)3$G+`H))V1A;&EA<U]?;&ES=%]L96=E;F0G
M(#T^("=$;VUA:6X@86QI87-E<R<L"@DG9&%L:6%S7U]L:7-T7VAE861E<B<@
M/3X@)T1O;6%I;B!A;&EA<V5S)RP*"2=D86QI87-?7VQI<W1?<W1A='5S)R`]
M/B`G4R<L"@DG9&%L:6%S7U]L:7-T7VYA;64G(#T^("=$;VUA:6X@86QI87,@
M;F%M92<L"@DG9&%L:6%S7U]L:7-T7V%S8VEI7VYA;64G(#T^("=);B!!4T-)
M22!F;W)M870G+`H))V1A;&EA<U]?<F5M;W9E7W1I=&QE)R`]/B`G5&AE(&9O
M;&QO=VEN9R!D;VUA:6X@86QI87-E<R!O9B!T:&4@9&]M86EN("4Q('=I;&P@
M8F4@<F5M;W9E9#HG+`H))V1A;&EA<U]?<V5L96-T7V1O;6%I;E]A;&EA<V5S
M7W1O7W)E;6]V92<@/3X@)U-E;&5C="!T:&4@9&]M86EN(&%L:6%S97,@=&\@
M8F4@<F5M;W9E9"XG+`H))V1A;&EA<U]?8V]N=')O;%]T:71L92<@/3X@)T1O
M;6%I;B!A;&EA<R`E,2<L"@DG9&%L:6%S7U]C;VYT<F]L7VEN9F]?;&5G96YD
M)R`]/B`G26YF;R<L"@DG9&%L:6%S7U]C;VYT<F]L7W-T871U<U]T:71L92<@
M/3X@)U,G+`H))V1A;&EA<U]?8V]N=')O;%]N86UE7W1I=&QE)R`]/B`G4V5R
M=FEC92!N86UE)RP*"2=D86QI87-?7V-O;G1R;VQ?9&5T86EL<U]T:71L92<@
M/3X@)T1E=&%I;',G+`H))V1A;&EA<U]?<V5R=FEC95]M86EL)R`]/B`G36%I
M;"<L"@DG9&%L:6%S7U]S97)V:6-E7W=E8B<@/3X@)U=E8B<L"@DG9&%L:6%S
M7U]D;VUA:6Y?<V5R=FEC95]M86EL7V5N86)L960G(#T^("=-86EL('-E<G9I
M8V4@:7,@96YA8FQE9"!O;B!T:&4@9&]M86EN+B<L"@DG9&%L:6%S7U]D;VUA
M:6Y?<V5R=FEC95]M86EL7V1I<V%B;&5D)R`]/B`G36%I;"!S97)V:6-E(&ES
M(&1I<V%B;&5D(&]N('1H92!D;VUA:6XN)RP*"2=D86QI87-?7V1O;6%I;E]S
M97)V:6-E7VUA:6Q?;7@G(#T^("<E,2!U<V5D(&%S(&UA:6P@97AC:&%N9V5R
M+B<L"@DG9&%L:6%S7U]E9&ET7W1I=&QE)R`]/B`G1&]M86EN(&%L:6%S('!R
M969E<F5N8V5S)RP*"2=D86QI87-?7V%D9%]T:71L92<@/3X@)T%D9"!D;VUA
M:6X@86QI87,G+`H))V1A;&EA<U]?961I=%]L96=E;F0G(#T^("=0<F5F97)E
M;F-E<R<L"@DG9&%L:6%S7U]E9&ET7VYA;64G(#T^("=$;VUA:6X@86QI87,@
M;F%M92<L"@DG9&%L:6%S7U]I;G9A;&ED7W9A;'5E<R<@/3X@)U1H92!D;VUA
M:6X@;F%M92!Y;W4@<W!E8VEF:65D(&ES(&EN=F%L:60N($1O;6%I;B!N86UE
M<R!C86X@8V]M<')I<V4@;&5T=&5R<RP*9&EG:71S(&%N9"!H>7!H96YS+B!%
M86-H('!A<G0@;V8@=&AE(&1O;6%I;B!N86UE(&)E='=E96X@9&]T<R!S:&]U
M;&0@;F]T(&)E"FQO;F=E<B!T:&%N(#8S('-Y;6)O;',N)RP*"2=D86QI87-?
M7V1O;6%I;E]A;')E861Y7V5X:7-T<R<@/3X@)TEN8V]R<F5C="!N86UE(&]F
M(&1O;6%I;B!A;&EA<R`E,2P@9&]M86EN("4Q(&%L<F5A9'D@97AI<W1S+B<L
M"@DG9&%L:6%S7U]W=W=?<')E9FEX7V1O;6%I;E]A;')E861Y7V5X:7-T<R<@
M/3X@)TEN8V]R<F5C="!N86UE(&]F(&1O;6%I;B!A;&EA<R!W=W<N)3$L('1H
M:7,@86QI87,@:7,@86QR96%D>2!C<F5A=&5D(&9O<B!T:&4@9&]M86EN("4Q
M+B<L"@DG9&%L:6%S7U]W96)M86EL7V5N86)L961?9&]M86EN7V%L<F5A9'E?
M97AI<W1S)R`]/B`G26YC;W)R96-T(&1O;6%I;B!A;&EA<R!N86UE.B!4:&5R
M92!I<R!A;')E861Y("!T:&4@9&]M86EN(&YA;64@=V5B;6%I;"XE,2XG+`H)
M)V1A;&EA<U]?;&ES='-?96YA8FQE9%]D;VUA:6Y?86QR96%D>5]E>&ES=',G
M(#T^("=);F-O<G)E8W0@9&]M86EN(&%L:6%S(&YA;64Z($$@9&]M86EN('=I
M=&@@;F%M92`@;&ES=',N)3$@86QR96%D>2!E>&ES=',N)RP*"2=D86QI87-?
M7W-U8F1O;5]A;')E861Y7V5X:7-T<R<@/3X@)TEN8V]R<F5C="!D;VUA:6X@
M86QI87,@;F%M93H@02!D;VUA:6X@=VET:"!N86UE("4Q(&%L<F5A9'D@97AI
M<W1S+B<L"@DG9&%L:6%S7U]D;G-?<F5C;W)D7V%L<F5A9'E?97AI<W1S)R`]
M/B`G4W5C:"!R97-O=7)C92!R96-O<F0@:7,@86QR96%D>2!I;B!T:&4@>F]N
M92!O9B!T:&4@9&]M86EN("`E,2XG+`H))V1A;&EA<U]?9&%L:6%S7V%L<F5A
M9'E?97AI<W1S)R`]/B`G1&]M86EN(&%L:6%S("4Q(&%L<F5A9'D@97AI<W1S
M+B<L"@DG9&%L:6%S7U]M86EL7W1U<FY?;VY?9F%I;&5D)R`]/B`G56YA8FQE
M('1O('1U<FX@;VX@;6%I;"!S97)V:6-E.B`E,2<L"@DG9&%L:6%S7U]W96)?
M='5R;E]O;E]F86EL960G(#T^("=5;F%B;&4@=&\@='5R;B!O;B!796(@<V5R
M=FEC93H@)3$G+`H))V1A=&%B87-E<U]?9&)?861M:6Y?;&]G:6XG(#T^("(E
M,2!A9&UI;FES=')A=&]R)W,@;&]G:6XB+`H))V1A=&%B87-E<U]?;F]T7VEN
M<W1A;&QE9"<@/3X@(BAN;W0@:6YS=&%L;&5D*2(L"@DG9&%T86)A<V5S7U]N
M;W1?<W5P<&]R=&5D7VQI8V5N<V4G(#T^("(H;F]T('-U<'!O<G1E9"!B>2!Y
M;W5R(&QI8V5N<V4@:V5Y*2(L"@DG9&%T86)A<V5S7U]T:71L92<@/3X@(D1A
M=&%B87-E($UA;F%G96UE;G0@86YD($%D;6EN:7-T<F%T;W(G<R!#<F5D96YT
M:6%L<R(L"@DG9&%T86)A<V5S7U]U;F%B;&5?8V]N;F5C="<@/3X@(E5N86)L
M92!T;R!A8V-E<W,@9&%T86)A<V4N($EN8V]R<F5C="!P87)A;65T97)S+B(L
M"@DG9&%T86)A<V5S7U]I;F-O<G)E8W1?9&)?861M:6Y?;&]G:6XG(#T^("=4
M:&4@;&]G:6X@;F%M92!C86X@8V]N=&%I;B!O;FQY(&%L<&AA;G5M97)I8RP@
M9&%S:"!A;F0@=6YD97)S8V]R92!S>6UB;VQS+"!A;F0@<VAO=6QD(&)E9VEN
M('=I=&@@86X@86QP:&%B971I8R!S>6UB;VPN)RP*"2=D871A8F%S97-?7VEN
M8V]R<F5C=%]D8E]A9&UI;E]P87-S=V0G(#T^("=4:&4@<&%S<W=O<F0@<VAO
M=6QD(&YO="!C;VYT86EN('1H92!L;V=I;B!N86UE+B<L"@DG9&%T86)A<V5?
M:&]S=&EN9U]P<F5F97)E;F-E<U]F;W)M7U]A;&QO=U]S:71E87!P7VQO8V%L
M7V1B7W1E>'0G(#T^("=);G-T86QL871I;VX@;V8@<VET92!A<'!L:6-A=&EO
M;G,@=&AA="!D;R!N;W0@<W5P<&]R="!R96UO=&4@9&%T86)A<V5S)RP*"2=D
M871A8F%S95]H;W-T:6YG7W!R969E<F5N8V5S7V9O<FU?7V%L;&]W7W-I=&5A
M<'!?;&]C86Q?9&)?=')U95]T97AT)R`]/B`G06QL;W<@;&]C86P@:&]S=&EN
M9R!O9B!D871A8F%S97,@9F]R('1H97-E('-I=&4@87!P;&EC871I;VYS)RP*
M"2=D871A8F%S95]H;W-T:6YG7W!R969E<F5N8V5S7V9O<FU?7V%L;&]W7W-I
M=&5A<'!?;&]C86Q?9&)?9F%L<V5?=&5X="<@/3X@)T1I<V%L;&]W(&EN<W1A
M;&QA=&EO;B!O9B!T:&5S92!S:71E(&%P<&QI8V%T:6]N<R<L"@DG9&%T86)A
M<V5?:&]S=&EN9U]P<F5F97)E;F-E<U]F;W)M7U]A;&QO=U]S:71E87!P7VQO
M8V%L7V1B7VAI;G0G(#T^("=4:&ES('!R969E<F5N8V4@:7,@;VYL>2!I;B!E
M9F9E8W0@=VAE;B!A(')E;6]T92!D871A8F%S92!S97)V97(@:7,@<V5L96-T
M960@87,@9&5F875L="XG+`H))V1A=&%B87-E7VAO<W1I;F=?<')E9F5R96YC
M97-?9F]R;5]?=&ET;&4G(#T^("=$871A8F%S92!H;W-T:6YG('!R969E<F5N
M8V5S)RP*"2=D871A8F%S95]S97)V97)S7V9O<FU?7W1I=&QE)R`]/B`G1&%T
M86)A<V4@<V5R=F5R<R<L"@DG9&%T86)A<V5?<V5R=F5R<U]F;W)M7U]S97)V
M97)?;&ES=%]L96=E;F0G(#T^("=$871A8F%S92!S97)V97)S)RP))V1A=&%B
M87-E7W-E<G9E<G-?9F]R;5]?<F5M;W9E7V5M<'1Y7W-E;&5C=&EO;B<@/3X@
M)TYO(&1A=&%B87-E('-E<G9E<G,@<V5L96-T960N)RP*"2=D871A8F%S95]S
M97)V97)S7V9O<FU?7W)E;6]V95]T:71L92<@/3X@)U1H92!F;VQL;W=I;F<@
M9&%T86)A<V4@<V5R=F5R<R!W:6QL(&)E(')E;6]V960Z)RP*"2=D871A8F%S
M95]S97)V97)?9&%T86)A<V5?;&ES=%]?8VQI96YT)R`]/B`G0VQI96YT)RP*
M"2=D871A8F%S95]S97)V97)?9&%T86)A<V5?;&ES=%]?9&]M86EN)R`]/B`G
M1&]M86EN)RP*"2=D871A8F%S95]S97)V97)?9&%T86)A<V5?;&ES=%]?:&5A
M9&5R)R`]/B`G1&%T86)A<V5S)RP*"2=D871A8F%S95]S97)V97)?9&%T86)A
M<V5?;&ES=%]?;F%M92<@/3X@)TYA;64G+`H))V1A=&%B87-E7W-E<G9E<E]D
M871A8F%S97-?9F]R;5]?9&%T86)A<V5S7VQI<W1?;&5G96YD)R`]/B`G1&%T
M86)A<V5S)RP*"2=D871A8F%S95]S97)V97)?9&%T86)A<V5S7V9O<FU?7W)E
M;6]V95]E;7!T>5]S96QE8W1I;VXG(#T^("=.;R!D871A8F%S97,@<V5L96-T
M960N)RP*"2=D871A8F%S95]S97)V97)?9&%T86)A<V5S7V9O<FU?7W)E;6]V
M95]T:71L92<@/3X@)U1H92!F;VQL;W=I;F<@9&%T86)A<V5S('=I;&P@8F4@
M<F5M;W9E9#HG+`H))V1A=&%B87-E7W-E<G9E<E]D871A8F%S97-?9F]R;5]?
M=&%B)R`]/B`G1&%T86)A<V5S("@E,2DG+`H))V1A=&%B87-E7W-E<G9E<E]E
M9&ET7V9O<FU?7V%D;6EN7VQO9VEN)R`]/B`B061M:6YI<W1R871O<B=S(&QO
M9VEN(&YA;64B+`H))V1A=&%B87-E7W-E<G9E<E]E9&ET7V9O<FU?7V%D;6EN
M7W!A<W-W;W)D7V]L9"<@/3X@(D-U<G)E;G0@861M:6YI<W1R871O<B=S('!A
M<W-W;W)D(BP*"2=D871A8F%S95]S97)V97)?961I=%]F;W)M7U]A9&UI;E]P
M87-S=V]R9"<@/3X@(DYE=R!A9&UI;FES=')A=&]R)W,@<&%S<W=O<F0B+`H)
M)V1A=&%B87-E7W-E<G9E<E]E9&ET7V9O<FU?7V%D;6EN7W!A<W-W;W)D,B<@
M/3X@(D-O;F9I<FT@;F5W(&%D;6EN:7-T<F%T;W(G<R!P87-S=V]R9"(L"@DG
M9&%T86)A<V5?<V5R=F5R7V5D:71?9F]R;5]?9&5F875L="<@/3X@)U5S92!T
M:&ES('-E<G9E<B!A<R!D969A=6QT(&9O<B`E,2<L"@DG9&%T86)A<V5?<V5R
M=F5R7V5D:71?9F]R;5]?9'5P;&EC871E)R`]/B`G02!D871A8F%S92!S97)V
M97(@=VET:"!T:&ES(&-O;6)I;F%T:6]N(&]F(&AO<W0@861D<F5S<R!A;F0@
M<&]R="!N=6UB97(@:7,@86QR96%D>2!R96=I<W1E<F5D+B<L"@DG9&%T86)A
M<V5?<V5R=F5R7V5D:71?9F]R;5]?:&]S="<@/3X@)TAO<W0@;F%M92!O<B!)
M4"!A9&1R97-S)RP*"2=D871A8F%S95]S97)V97)?961I=%]F;W)M7U]L96=E
M;F1?875T:&5N=&EC871I;VXG(#T^("=!=71H96YT:6-A=&EO;B<L"@DG9&%T
M86)A<V5?<V5R=F5R7V5D:71?9F]R;5]?;&5G96YD7V=E;F5R86PG(#T^("='
M96YE<F%L)RP*"2=D871A8F%S95]S97)V97)?961I=%]F;W)M7U]P87-S=V]R
M9%]W87)N:6YG7W!O<W1G<F5S<6PG(#T^("=)9B!Y;W4@8VAA;F=E('1H92!L
M;V=I;B!O<B!P87-S=V]R9"!B96QO=RP@=&AE(%!O<W1G<F5344P@=7-E<B!A
M8V-O=6YT('=I=&@@861M:6YI<W1R871I=F4@<FEG:'1S('=I;&P@8F4@=7!D
M871E9"XG+`H))V1A=&%B87-E7W-E<G9E<E]E9&ET7V9O<FU?7W!O<G0G(#T^
M("=0;W)T(&YU;6)E<B<L"@DG9&%T86)A<V5?<V5R=F5R7V5D:71?9F]R;5]?
M<&]R=%]H:6YT)R`]/B`G3&5A=F4@8FQA;FL@9F]R('1H92!D969A=6QT('!O
M<G0@;G5M8F5R)RPG9&%T86)A<V5?<V5R=F5R7V5D:71?9F]R;5]?=&%B)R`]
M/B`G1&%T86)A<V4@<V5R=F5R)RP*"2=D871A8F%S95]S97)V97)?961I=%]F
M;W)M7U]T:71L95]N97<G(#T^("=.97<@9&%T86)A<V4@<V5R=F5R)RP*"2=D
M871A8F%S95]S97)V97)?961I=%]F;W)M7U]T:71L95]E9&ET)R`]/B`G1&%T
M86)A<V4@<V5R=F5R("4Q)RP*"2=D871A8F%S95]S97)V97)?961I=%]F;W)M
M7U]T>7!E)R`]/B`G1&%T86)A<V4@<V5R=F5R('1Y<&4G+`H))V1A=&%B87-E
M7W-E<G9E<E]E9&ET7V9O<FU?7W5N:7A?<V]C:V5T)R`]/B`G*&QO8V%L(&-O
M;FYE8W1I;VXI)RP*"2=D871A8F%S95]S97)V97)?97)R;W)?7V-O;G-U;'1?
M861M:6XG(#T^("=0;&5A<V4@8V]N=&%C="!T:&4@<V5R=F5R(&%D;6EN:7-T
M<F%T;W(N)RP*"2=D871A8F%S95]S97)V97)?97)R;W)?7VQA<W1?7V-O;FYE
M8W1I;VY?9F%I;&5D)R`]/B`G5&AE(&QA<W0@871T96UP="!T;R!C;VYT<F]L
M('1H:7,@9&%T86)A<V4@<V5R=F5R(&9A:6QE9"!B96-A=7-E(&]F(&YE='=O
M<FL@<')O8FQE;7,N)RP*"2=D871A8F%S95]S97)V97)?97)R;W)?7VQA<W1?
M7W!E<FUI<W-I;VY?9&5N:65D)R`]/B`G5&AE(&QA<W0@871T96UP="!T;R!C
M;VYT<F]L('1H:7,@9&%T86)A<V4@<V5R=F5R(&9A:6QE9"!B96-A=7-E('1H
M92!S=7!P;&EE9"!A8V-O=6YT(&1O97,@;F]T('!O<W-E<W,@861M:6YI<W1R
M871I=F4@<')I=FEL96=E<RXG+`H))V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?
M;&%S=%]?8W)E9&5N=&EA;'-?;F]T7W-E="<@/3X@(EEO=2!N965D('1O('-U
M<'!L>2!V86QI9"!A9&UI;FES=')A=&]R)W,@;&]G:6X@86YD('!A<W-W;W)D
M(&)E9F]R92!0;&5S:R!C86X@8V]N;F5C="!T;R!T:&ES('-E<G9E<BXB+`H)
M)V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?;&%S=%]?;W1H97)?97)R;W(G(#T^
M("=4:&4@;&%S="!A='1E;7!T('1O(&-O;G1R;VP@=&AI<R!D871A8F%S92!S
M97)V97(@9F%I;&5D+B<L"@DG9&%T86)A<V5?<V5R=F5R7V5R<F]R7U]R96%L
M7U]C;VYN96-T:6]N7V9A:6QE9"<@/3X@)T-O;FYE8W1I;VX@=&\@=&AE(&1A
M=&%B87-E('-E<G9E<B!H87,@9F%I;&5D(&)E8V%U<V4@;V8@;F5T=V]R:R!P
M<F]B;&5M<SHG+`H))V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?<F5A;%]?<&5R
M;6ES<VEO;E]D96YI960G(#T^("=#;VYN96-T:6]N('1O('1H92!D871A8F%S
M92!S97)V97(@:&%S(&9A:6QE9"!B96-A=7-E('1H92!S=7!P;&EE9"!A8V-O
M=6YT(&1O97,@;F]T('!O<W-E<W,@861M:6YI<W1R871I=F4@<')I=FEL96=E
M<SHG+`H))V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?<F5A;%]?9'5P;&EC871E
M7V]B:F5C="<@/3X@)T-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E('-E<G9E
M<B!H87,@9F%I;&5D(&)E8V%U<V4@;V8@82!N86UE(&-L87-H.B<L"@DG9&%T
M86)A<V5?<V5R=F5R7V5R<F]R7U]R96%L7U]U;F%C8V5P=&%B;&5?;F%M92<@
M/3X@)T-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E('-E<G9E<B!H87,@9F%I
M;&5D(&)E8V%U<V4@;V8@86X@:6YV86QI9"!O8FIE8W0@;F%M93HG+`H))V1A
M=&%B87-E7W-E<G9E<E]E<G)O<E]?<F5A;%]?=6YA8V-E<'1A8FQE7W!A<W-W
M;W)D)R`]/B`G0V]N;F5C=&EO;B!T;R!T:&4@9&%T86)A<V4@<V5R=F5R(&AA
M<R!F86EL960@8F5C875S92!O9B!A;B!U;F%C8V5P=&%B;&4@<&%S<W=O<F0Z
M)RP*"2=D871A8F%S95]S97)V97)?97)R;W)?7W)E86Q?7V-R961E;G1I86QS
M7VYO=%]S970G(#T^(")0;&5S:R!C86YN;W0@8V]N;F5C="!T;R!T:&4@9&%T
M86)A<V4@<V5R=F5R(&)E8V%U<V4@=F%L:60@861M:6YI<W1R871O<B=S(&QO
M9VEN(&%N9"!P87-S=V]R9"!H879E(&YO="!B965N('-P96-I9FEE9"XB+`H)
M)V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?<F5A;%]?;W1H97)?97)R;W(G(#T^
M("=#;VYN96-T:6]N('1O('1H92!D871A8F%S92!S97)V97(@:&%S(&9A:6QE
M9#HG+`H))V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?=&5S=%]?8V]N;F5C=&EO
M;E]F86EL960G(#T^("=497-T(&-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E
M('-E<G9E<B!H87,@9F%I;&5D(&)E8V%U<V4@;V8@;F5T=V]R:R!P<F]B;&5M
M<SHG+`H))V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?=&5S=%]?<&5R;6ES<VEO
M;E]D96YI960G(#T^("=497-T(&-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E
M('-E<G9E<B!H87,@9F%I;&5D(&)E8V%U<V4@=&AE('-U<'!L:65D(&%C8V]U
M;G0@9&]E<R!N;W0@<&]S<V5S<R!A9&UI;FES=')A=&EV92!P<FEV:6QE9V5S
M.B<L"@DG9&%T86)A<V5?<V5R=F5R7V5R<F]R7U]T97-T7U]D=7!L:6-A=&5?
M;V)J96-T)R`]/B`G5&5S="!C;VYN96-T:6]N('1O('1H92!D871A8F%S92!S
M97)V97(@:&%S(&9A:6QE9"!B96-A=7-E(&]F(&$@;F%M92!C;&%S:#HG+`H)
M)V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?=&5S=%]?=6YA8V-E<'1A8FQE7VYA
M;64G(#T^("=497-T(&-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E('-E<G9E
M<B!H87,@9F%I;&5D(&)E8V%U<V4@;V8@86X@:6YV86QI9"!O8FIE8W0@;F%M
M93HG+`H))V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?=&5S=%]?=6YA8V-E<'1A
M8FQE7W!A<W-W;W)D)R`]/B`G5&5S="!C;VYN96-T:6]N('1O('1H92!D871A
M8F%S92!S97)V97(@:&%S(&9A:6QE9"!B96-A=7-E(&]F(&%N('5N86-C97!T
M86)L92!P87-S=V]R9#HG+`H))V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?=&5S
M=%]?8W)E9&5N=&EA;'-?;F]T7W-E="<@/3X@(EEO=2!N965D('1O('-U<'!L
M>2!V86QI9"!A9&UI;FES=')A=&]R)W,@;&]G:6X@86YD('!A<W-W;W)D(&)E
M9F]R92!0;&5S:R!C86X@8V]N;F5C="!T;R!T:&ES('-E<G9E<BXB+`H))V1A
M=&%B87-E7W-E<G9E<E]E<G)O<E]?=&5S=%]?;W1H97)?97)R;W(G(#T^("=4
M97-T(&-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E('-E<G9E<B!H87,@9F%I
M;&5D.B<L"@DG9&%T86)A<V5?<V5R=F5R7VQI<W1?7VAE861E<B<@/3X@)T1A
M=&%B87-E('-E<G9E<G,G+`H))V1A=&%B87-E7W-E<G9E<E]L:7-T7U]L87-T
M7V5R<F]R)R`]/B`G4R<L"@DG9&%T86)A<V5?<V5R=F5R7VQI<W1?7W1Y<&4G
M(#T^("=397)V97(@='EP92<L"@DG9&%T86)A<V5?<V5R=F5R7VQI<W1?7VAO
M<W0G(#T^("=(;W-T(&YA;64G+`H))V1A=&%B87-E7W-E<G9E<E]L:7-T7U]P
M;W)T)R`]/B`G4&]R="<L"@DG9&%T86)A<V5?<V5R=F5R7VQI<W1?7V1B8V]U
M;G0G(#T^("=$871A8F%S97,G+`H))V1B7U]C<F5A=&5?;F5W7V1B)R`]/B`B
M061D(&YE=R!D871A8F%S92(L"@DG9&)?7V1B7V%D9"<@/3X@(D%D9"!.97<@
M1&%T86)A<V4B+`H))V1B7U]D8E]F;W)?9&]M)R`]/B`B1&%T86)A<V5S(&9O
M<B!D;VUA:6X@)3$B+`H))V1B7U]D8E]I9%]U;F1E9FEN960G(#T^(")$871A
M8F%S92!I9"!I<R!U;F1E9FEN960N(BP*"2=D8E]?9&)?;F%M92<@/3X@(D1A
M=&%B87-E(&YA;64B+`H))V1B7U]D8E]N;W1?97AI<W0G(#T^(")$871A8F%S
M92!D;V5S(&YO="!E>&ES="XB+`H))V1B7U]D8E]T>7!E)R`]/B`B5'EP92(L
M"@DG9&)?7V1B7W-E<G9E<B<@/3X@(D1A=&%B87-E('-E<G9E<B(L"@DG9&)?
M<V5R=F5R7VYO=%]E>&ES="<@/3X@(D1A=&%B87-E('-E<G9E<B!D;V5S(&YO
M="!E>&ES="XB+`H))V1B7U]D8E]U<V5R7VYO=%]E>&ES="<@/3X@(D1A=&%B
M87-E('5S97(@9&]E<R!N;W0@97AI<W0N(BP*"2=D8E]?9&]M86EN7VYO=%]E
M>&ES="<@/3X@(D1O;6%I;B!D;V5S(&YO="!E>&ES="XB+`H))V1B7U]E;G1E
M<E]D8E]N86UE)R`]/B`B16YT97(@;F5W(&1A=&%B87-E(&YA;64N(BP*"2=D
M8E]?:6YV86QI9%]D8E]I9"<@/3X@(D1A=&%B87-E(&ED96YT:69I97(@:7,@
M:6YV86QI9"XB+`H))V1B7U]I;G9A;&ED7V1B7VYA;64G(#T^(")$871A8F%S
M92!N86UE(&ES(&EN=F%L:60N(%1H92!D871A8F%S92!N86UE('-H;W5L9"!C
M;VYT86EN(&]N;'D@3&%T:6X@86QP:&%B970@<WEM8F]L<RP@9&EG:71S(&]R
M(&1A<V@N($ET(&-A;FYO="!B92!L;VYG97(@=&AA;B`V,R!S>6UB;VQS+B(L
M"@DG9&)?7VUA>%]D8E]R96%C:&5D7V9O<E]D;VTG(#T^(")4:&4@;&EM:70@
M;VX@;G5M8F5R(&]F(&1A=&%B87-E<R!I<R!R96%C:&5D(&9O<B!T:&ES(&1O
M;6%I;BXB+`H))V1B7U]N;VYD969A=6QT7W-E<G9E<E]N;W1?86QL;W=E9"<@
M/3X@)T]N;'D@=&AE(&%D;6EN:7-T<F%T;W(@8V%N(&-H;V]S92!S97)V97)S
M(&9O<B!D871A8F%S92!H;W-T:6YG+B<L"@DG9&)?7W!O<W1G<F5S7VYO=%]C
M;VYN96-T7V9O<E]A9&UI;B<@/3X@(E5N86)L92!T;R!C;VYN96-T('1O(%!O
M<W1G<F5344PN($5N86)L92!0;W-T9W)E4U%,('-U<'!O<G0@;VX@=&AE('-E
M<G9E<B!A9&UI;FES=')A=&EO;B!P86=E+B(L"@DG9&)?7W!O<W1G<F5S7VYO
M=%]C;VYN96-T7V9O<E]C;&EE;G0G(#T^(")5;F%B;&4@=&\@8V]N;F5C="!T
M;R!0;W-T9W)E4U%,+B!2969E<B!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A
M=&]R(&9O<B!H96QP+B(L"@DG9&)?7W)E;6]V95]D8E]O;E]D;VUA:6XG(#T^
M(")4:&4@9F]L;&]W:6YG(&1A=&%B87-E<R!W:6QL(&)E(')E;6]V960@9G)O
M;2!T:&4@9&]M86EN("4Q.B(L"@DG9&)?7W)E;6]V95]D8E]O;E]D;VUA:6Y?
M;V9?8VPG(#T^(")4:&4@9F]L;&]W:6YG(&1A=&%B87-E<R!F;W(@9&]M86EN
M("4R(&]W;F5D(&)Y(&-L:65N="`E,2!W:6QL(&)E(')E;6]V960Z(BP*"2=D
M8E]?<F5M;W9E7V1B7VQI;FME9%]R97-O=7)C92<@/3X@)U1H:7,@9&%T86)A
M<V4@:7,@:6X@=7-E(&)Y(&$@<VET92!A<'!L:6-A=&EO;BX@270@8V%N(&)E
M(')E;6]V960@;VYL>2!A9G1E<B!U;FEN<W1A;&QI;F<@=&AI<R!S:71E(&%P
M<&QI8V%T:6]N+B<L"@DG9&)?7W)E;6]V95]D8E]U<V5R<R<@/3X@(E1H92!F
M;VQL;W=I;F<@=7-E<G,@;V8@9&%T86)A<V4@)3(@:6X@9&]M86EN("4Q('=I
M;&P@8F4@<F5M;W9E9#HB+`H))V1B7U]R96UO=F5?9&)?=7-E<G-?;V9?8VPG
M(#T^(")4:&4@9F]L;&]W:6YG('5S97)S(&]F(&1A=&%B87-E("4S(&EN(&1O
M;6%I;B`E,B!O=VYE9"!B>2!T:&4@8VQI96YT("4Q('=I;&P@8F4@<F5M;W9E
M9#HB+`H))V1B7U]S96QE8W1?9&)?9F]R7W)E;6]V92<@/3X@(E-E;&5C="!T
M:&4@9&%T86)A<V5S('1O(&)E(')E;6]V960N(BP*"2=D8E]?<V5L96-T7V1B
M7W5S97)S7V9O<E]R96UO=F4G(#T^(")396QE8W0@=&AE(&1A=&%B87-E('5S
M97)S('1O(&)E(')E;6]V960N(BP*"2=D8E]?=6YA8FQE7V-R96%T95]D8E]U
M<V5R)R`]/B`B56YA8FQE('1O(&-R96%T92!T:&4@9&%T86)A<V4@=7-E<CH@
M)3$B+`H))V1B7U]U;F%B;&5?9&5F:6YE7V1B7VYA;64G(#T^(")5;F%B;&4@
M=&\@9&5F:6YE('1H92!D871A8F%S92!N86UE.B`E,2(L"@DG9&)?7W5N86)L
M95]D969I;F5?9&)?=7-E<B<@/3X@(E5N86)L92!T;R!D969I;F4@=&AE(&1A
M=&%B87-E('5S97(Z("4Q(BP*"2=D8E]?=6YA8FQE7V1E9FEN95]D8E]U<V5R
M<R<@/3X@(E5N86)L92!T;R!D969I;F4@9&%T86)A<V4@=7-E<G,Z("4Q(BP*
M"2=D8E]?=6YA8FQE7W-E;&5C=%]D;VU?;F%M92<@/3X@(E5N86)L92!T;R!S
M96QE8W0@9&]M86EN(&YA;64Z("4Q(BP*"2=D8E]E9&ET7U]D8E]F;W)?9&]M
M)R`]/B`B57-E<G,@9F]R(&1A=&%B87-E("4Q(&]N(&1O;6%I;B`E,B(L"@DG
M9&)?961I=%]?:6YV86QI9%]D8E]N86UE)R`]/B`B5&AE(&1A=&%B87-E(&YA
M;64@:7,@:6YV86QI9"XB+`H))V1B7V5D:71?7VYO7W5S97)S)R`]/B`B5&AE
M<F4@87)E(&YO('5S97)S('=I=&@@8W)E9&5N=&EA;',@9F]R('1H:7,@9&%T
M86)A<V4N(BP*"2=D8E]E9&ET7U]U;F%B;&5?9&5F:6YE7V1B7W5S<G,G(#T^
M(")5;F%B;&4@=&\@9&5F:6YE('1H92!D871A8F%S92!U<V5R<SH@)3$B+`H)
M)V1B7V5D:71?7W5N86)L95]S96QE8W1?9&)?=7-R)R`]/B`B56YA8FQE('1O
M('-E;&5C="!T:&4@9&%T86)A<V4@=7-E<BXB+`H))V1B7V5D:71?7V1B7W5S
M97)?<&%S<W=O<F1?9F]R7R<@/3X@(E!L96%S92!T>7!E(&EN('1H92!P87-S
M=V]R9"!T;R!L;V<@:6X@87,@=&AE(&1A=&%B87-E('5S97(@)3$@(BP*"2=D
M8E]L:7-T7U]T86)?=&ET;&5?9&)?='EP92<@/3X@(E0B+`H))V1B7W5S<E]E
M9&ET7U]A9&1?9&)?=7-R)R`]/B`B5&AE(&1A=&%B87-E('5S97(@861D:71I
M;VXB+`H))V1B7W5S<E]E9&ET7U]D8E]U<W)?;F%M92<@/3X@(D1A=&%B87-E
M('5S97(@;F%M92(L"@DG9&)?=7-R7V5D:71?7V5D:71?9&)?=7-R)R`]/B`B
M4V5T('5P(&-R961E;G1I86QS(&9O<B!D871A8F%S92!U<V5R(&%C8V]U;G0B
M+`H))V1B7W5S<E]E9&ET7U]F;W)?9&(G(#T^("(@:6X@)3$@9&%T86)A<V4B
M+`H))V1B7W5S<E]E9&ET7U]N;W1?8W)E871E7W!A<W,G(#T^(")4:&ES(&]P
M97)A=&EO;B!W:6QL(')E<W5L="!I;B!C<F5A=&EN9R!A(&1A=&%B87-E('5S
M97(@86-C;W5N="!W:71H;W5T('!A<W-W;W)D+EQN1&\@>6]U('=I<V@@=&\@
M8W)E871E(&$@=7-E<B!W:71H;W5T(&%S<VEG;FEN9R!A('!A<W-W;W)D/R(L
M"@DG9&)U<V5R7U]O;FQY7V]N95]U<V5R7V-A;E]B95]D969A=6QT)R`]/B`B
M3VYL>2!O;F4@=7-E<B!C86X@8F4@<V5T(&%S(&1E9F%U;'0N(BP*"2=D8E]S
M97)V97)?7V-A;FYO=%]D96QE=&5?9&5F875L="<@/3X@(E1H92!D969A=6QT
M(&1A=&%B87-E('-E<G9E<B!C86YN;W0@8F4@9&5L971E9"XB+`H))V1B7W-E
M<G9E<E]?8V%N;F]T7V1E;&5T95]L;V-A;"<@/3X@(E1H92!L;V-A;"!D871A
M8F%S92!S97)V97(@8V%N;F]T(&)E(&1E;&5T960N(BP*"2=D8E]S97)V97)?
M7V-A;FYO=%]D96QE=&5?=7-E9"<@/3X@)T$@9&%T86)A<V4@<V5R=F5R(&-A
M;FYO="!B92!D96QE=&5D('=H:6QE('1H97)E(&%R92!D871A8F%S97,@:&]S
M=&5D(&]N(&ET+B<L"@DG9&5M;U]?9&ES86)L961?:6Y?9&5M;R<@/3X@(E1H
M:7,@;W!E<F%T:6]N(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&1E;6\@=F5R
M<VEO;BXB+`H))V1N<U]?861D7V1N<U]M87-T97)?<V5R=F5R)R`]/B`B061D
M($1.4R!M87-T97(@<V5R=F5R(BP*"2=D;G-?7V%D9%]D;G-?<F5C;W)D)R`]
M/B`B061D(')E<V]U<F-E(')E8V]R9"(L"@DG9&YS7U]A9&1?;F%M97-E<G9E
M<B<@/3X@(D%D9"!N86UE<V5R=F5R(BP*"2=D;G-?7V1N<U]R96-O<F1?;F]T
M7V5X:7-T)R`]/B`B5&AE<F4@:7,@;F\@<W5C:"!R97-O=7)C92!R96-O<F0@
M:6X@=&AE('IO;F4N(BP*"2=D;G-?7V1N<U]Z;VYE7V9O<E]D;VUA:6XG(#T^
M(")$3E,@>F]N92!F;W(@=&AE(&1O;6%I;B(L"@DG9&YS7U]D;G-?>F]N95]L
M96=E;F0G(#T^("=297-O=7)C92!R96-O<F1S)RP*"2=D;G-?7V1N<U]Z;VYE
M7VUA<W1E<E]T:71L92<@/3X@)U1H:7,@<V5R=F5R(&%C=',@87,@82!P<FEM
M87)Y(&YA;65S97)V97(@9F]R('1H92!$3E,@>F]N92`E,2<L"@DG9&YS7U]D
M;G-?>F]N95]S;&%V95]T:71L92<@/3X@)U1H:7,@<V5R=F5R(&%C=',@87,@
M82!S96-O;F1A<GD@;F%M97-E<G9E<B!F;W(@=&AE($1.4R!Z;VYE("4Q)RP*
M"2=D;G-?7V1N<U]Z;VYE7V]F9E]T:71L92<@/3X@)TYA;65S97)V97)S(&9O
M<B!T:&4@1$Y3('IO;F4@)3$G+`H))V1N<U]?861D7V1N<U]R96-O<F1?;6%S
M=&5R7W1I=&QE)R`]/B`G061D(')E<V]U<F-E(')E8V]R9"!T;R!T:&4@>F]N
M92<L"@DG9&YS7U]A9&1?9&YS7W)E8V]R9%]S;&%V95]T:71L92<@/3X@)T%D
M9"!P<FEM87)Y($1.4R!S97)V97(G+`H))V1N<U]?861D7V1N<U]R96-O<F1?
M;V9F7W1I=&QE)R`]/B`G061D(&YA;65S97)V97(G+`H))V1N<U]?961I=%]D
M;G-?<F5C;W)D7VUA<W1E<E]T:71L92<@/3X@)T5D:70@<F5S;W5R8V4@<F5C
M;W)D)RP*"2=D;G-?7V5D:71?9&YS7W)E8V]R9%]S;&%V95]T:71L92<@/3X@
M)T5D:70@<V5R=F5R(')E8V]R9"<L"@DG9&YS7U]E9&ET7V1N<U]R96-O<F1?
M;V9F7W1I=&QE)R`]/B`G161I="!N86UE<V5R=F5R)RP*"2=D;G-?7V1N<U]R
M96-O<F1?:6YV86QI9%]V86QU97,G(#T^("=4:&5R92!A<F4@:6YC;W)R96-T
M('!A<F%M971E<B!V86QU97,N)RP*"2=D;G-?7V1N<U]Z;VYE7VEN=F%L:61?
M=F%L=65S)R`]/B`G5&AE<F4@87)E(&EN8V]R<F5C="!P87)A;65T97(@=F%L
M=65S+B<L"@DG9&YS7U]D;G-?<V]A7W1I=&QE)R`]/B`G4T]!(%!R969E<F5N
M8V5S)RP*"2=D;G-?7V1N<U]S;V%?;&5G96YD)R`]/B`G4T]!(%!R969E<F5N
M8V5S)RP*"2=D;G-?7V1N<U]S;V%?='1L)R`]/B`G5%1,)RP*"2=D;G-?7V1N
M<U]S;V%?<F5F<F5S:"<@/3X@)U)E9G)E<V@G+`H))V1N<U]?9&YS7W-O85]R
M971R>2<@/3X@)U)E=')Y)RP*"2=D;G-?7V1N<U]S;V%?97AP:7)E)R`]/B`G
M17AP:7)E)RP*"2=D;G-?7V1N<U]S;V%?;6EN:6UU;2<@/3X@)TUI;FEM=6TG
M+`H))V1N<U]?9&YS7W-O85]T=&Q?97)R;W(G(#T^("=45$P@=F%L=64@:7,@
M:6YV86QI9"X@270@8V%N(&)E(&9R;VT@,2!S96-O;F0@=&\@-C@@>65A<G,N
M)RP*"2=D;G-?7V1N<U]S;V%?<F5F<F5S:%]E<G)O<B<@/3X@)U)E9G)E<V@@
M=F%L=64@:7,@:6YV86QI9"X@270@8V%N(&)E(&9R;VT@,2!S96-O;F0@=&\@
M-C@@>65A<G,N)RP*"2=D;G-?7V1N<U]S;V%?<F5T<GE?97)R;W(G(#T^("=2
M971R>2!V86QU92!I<R!I;G9A;&ED+B!)="!C86X@8F4@9G)O;2`Q('-E8V]N
M9"!T;R`V."!Y96%R<RXG+`H))V1N<U]?9&YS7W-O85]E>'!I<F5?97)R;W(G
M(#T^("=%>'!I<F4@=F%L=64@:7,@:6YV86QI9"X@270@8V%N(&)E(&9R;VT@
M,2!S96-O;F0@=&\@-C@@>65A<G,N)RP*"2=D;G-?7V1N<U]S;V%?;6EN:6UU
M;5]E<G)O<B<@/3X@)TUI;FEM=6T@=F%L=64@:7,@:6YV86QI9"X@270@8V%N
M(&)E(&9R;VT@,2!S96-O;F0@=&\@-C@@>65A<G,N)RP*"2=D;G-?7V1N<U]D
M969A=6QT7W1I=&QE)R`]/B`G4F5S=&]R92!T:&4@1$Y3('IO;F4N)RP*"2=D
M;G-?7V1N<U]D969A=6QT7VQE9V5N9"<@/3X@)UIO;F4@<F5S=&]R:6YG(&]P
M=&EO;G,N)RP*"2=D;G-?7V1N<U]D969A=6QT7W1E>'0G(#T^("=#:&]O<V4@
M=&AE('-E='1I;F=S(&9O<B!R97-T;W)I;F<@=&AE($1.4R!Z;VYE+"!C;VYF
M:7)M('1H96T@86YD(&-L:6-K($]++B<L"@DG9&YS7U]D;G-?9&5F875L=%]C
M;VYF:7)M)R`]/B`G0V]N9FER;2!R97-T;W)I;F<@;V8@1$Y3('IO;F4N)RP*
M"2=D;G-?7V1N<U]D969A=6QT7V-O;F9I<FU?<F5Q=6ER960G(#T^("=0;&5A
M<V4@8V]N9FER;2!R97-T;W)I;F<@;V8@1$Y3('IO;F4N)RP*"@DG9&YS7W1?
M7V1N<U]D969A=6QT7W1I=&QE)R`]/B`G4F5S=&]R92!T:&4@;W)I9VEN86P@
M1$Y3('IO;F4@=&5M<&QA=&4N)RP*"2=D;G-?=%]?9&YS7V1E9F%U;'1?;&5G
M96YD)R`]/B`G4F5S=&]R:6YG(&]P=&EO;G,N)RP*"2=D;G-?=%]?9&YS7V1E
M9F%U;'1?=&5X="<@/3X@)T-H;V]S92!T:&4@<V5T=&EN9W,@9F]R(')E<W1O
M<FEN9R!T:&4@1$Y3('IO;F4@=&5M<&QA=&4L(&-O;F9I<FT@=&AE;2!A;F0@
M8VQI8VL@3TLN)RP*"2=D;G-?=%]?9&YS7V1E9F%U;'1?8V]N9FER;2<@/3X@
M)T-O;F9I<FT@<F5S=&]R:6YG(&]F($1.4R!Z;VYE('1E;7!L871E+B<L"@DG
M9&YS7W1?7V1N<U]D969A=6QT7V-O;F9I<FU?<F5Q=6ER960G(#T^("=0;&5A
M<V4@8V]N9FER;2!R97-T;W)I;F<@;V8@1$Y3('IO;F4@=&5M<&QA=&4N)RP*
M"2=D;G-?=%]?9&YS7WIO;F5?;V9F7W)E;6]V95]T:71L92<@/3X@(E1H92!F
M;VQL;W=I;F<@<F5S;W5R8V4@<F5C;W)D<R!F;W(@1$Y3('IO;F4@=&5M<&QA
M=&4@=VEL;"!B92!R96UO=F5D.B(L"@DG9&YS7W1?7V1N<U]Z;VYE7VUA<W1E
M<E]R96UO=F5?=&ET;&4G(#T^(")4:&4@9F]L;&]W:6YG(')E<V]U<F-E(')E
M8V]R9',@=VEL;"!B92!R96UO=F5D(&9R;VT@1$Y3('IO;F4@=&5M<&QA=&4Z
M(BP*"2=D;G-?=%]?861D7V1N<U]R96-O<F1?;6%S=&5R7W1I=&QE)R`]/B`G
M061D(')E<V]U<F-E(')E8V]R9"!T;R!T:&4@>F]N92!T96UP;&%T92<L"@DG
M9&YS7W1?7V%D9%]D;G-?<F5C;W)D7V]F9E]T:71L92<@/3X@)T%D9"!N86UE
M<V5R=F5R)RP*"2=D;G-?=%]?961I=%]D;G-?<F5C;W)D7VUA<W1E<E]T:71L
M92<@/3X@)T5D:70@<F5S;W5R8V4@<F5C;W)D)RP*"2=D;G-?=%]?961I=%]D
M;G-?<F5C;W)D7V]F9E]T:71L92<@/3X@)T5D:70@;F%M97-E<G9E<B<L"@DG
M9&YS7W1?7W-E;&5C=%]R96-O<F1?=&]?<F5M;W9E)R`]/B`G4V5L96-T(')E
M8V]R9',@=&\@8F4@<F5M;W9E9"!F<F]M('1H92!$3E,@=&5M<&QA=&4N)RP*
M"@DG9&YS7U]U;FET7W-E8V]N9',G(#T^("=S96-O;F1S)RP*"2=D;G-?7W5N
M:71?;6EN=71E<R<@/3X@)VUI;G5T97,G+`H))V1N<U]?=6YI=%]H;W5R<R<@
M/3X@)VAO=7)S)RP*"2=D;G-?7W5N:71?9&%Y<R<@/3X@)V1A>7,G+`H))V1N
M<U]?=6YI=%]W965K<R<@/3X@)W=E96MS)RP*"2=D;G-?7V1N<U]Z;VYE7V]F
M9E]R96UO=F5?=&ET;&4G(#T^(")4:&4@9F]L;&]W:6YG(')E<V]U<F-E(')E
M8V]R9',@=VEL;"!B92!R96UO=F5D(&9R;VT@=&AE('IO;F4@)3$Z(BP*"2=D
M;G-?7V1N<U]Z;VYE7VUA<W1E<E]R96UO=F5?=&ET;&4G(#T^(")4:&4@9F]L
M;&]W:6YG(')E<V]U<F-E(')E8V]R9',@9F]R($1.4R!Z;VYE("4Q('=I;&P@
M8F4@<F5M;W9E9#HB+`H))V1N<U]?9&YS7WIO;F5?<VQA=F5?<F5M;W9E7W1I
M=&QE)R`]/B`B5&AE(&9O;&QO=VEN9R!P<FEM87)Y(&YA;65S97)V97(@<F5C
M;W)D<R!F;W(@)3$@=VEL;"!B92!R96UO=F5D.B(L"@DG9&YS7U]D;G-?>F]N
M95]S=&%T=7,G(#T^(")$3E,@>F]N92!S=&%T=7,N(BP*"2=D;G-?7V1N<U]Z
M;VYE7W1E;7!L871E)R`]/B`B1$Y3('IO;F4@=&5M<&QA=&4B+`H))V1N<U]?
M9&YS7WIO;F5?=&5M<&QA=&5?<F5S=&]R95]D969A=6QT)R`]/B`B4F5S=&]R
M92!T:&4@9&5F875L="!$3E,@>F]N92!T96UP;&%T92(L"@DG9&YS7U]D;G-?
M>F]N95]T96UP;&%T95]R97-T;W)E7V1E9F%U;'1?8V]N9FER;2<@/3X@(E)E
M<W1O<FEN9R!T:&4@<W1A;F1A<F0@1$Y3('IO;F4@=&5M<&QA=&4@=VEL;"!D
M:7-C87)D('1H92!C=7)R96YT;'D@=7-E9"!T96UP;&%T92P@<')O8V5E9"!A
M;GEW87D_(BP*"2=D;G-?7V1N<U]Z;VYE7W1E;7!L871E7W)E<W1O<F5?9&5F
M875L=%]E<G)O<B<@/3X@(D5R<F]R(')E<W1O<FEN9R!T:&4@1$Y3('IO;F4@
M=&5M<&QA=&4Z(BP*"2=D;G-?7VAO<W0G(#T^(")(;W-T(BP*"2=D;G-?7VEN
M=F%L:61?:7!?861D<F5S<R<@/3X@(DE0(&%D9')E<W,@;V8@;F5W(&UA<W1E
M<B!$3E,@<V5R=F5R(&ES(&EN=F%L:60@;W(@96UP='DN(BP*"2=D;G-?7VEP
M7V%D9')E<W,G(#T^("))4"!!9&1R97-S(BP*"2=D;G-?7VUA<W1E<E]D;G-?
M='EP92<@/3X@(FES(&$@;6%S=&5R($1.4R!S97)V97(B+`H))V1N<U]?;6%S
M=&5R<R<@/3X@(D1.4R!M87-T97(@<V5R=F5R<R(L"@DG9&YS7U]S;V%?;6EN
M:6UU;5]T;V]?;&%R9V4G(#T^("=#86-H:6YG(&YE9V%T:79E(')E<W!O;G-E
M<R!F;W(@;6]R92!T:&%N('1H<F5E(&AO=7)S(&ES(&YO="!R96-O;6UE;F1E
M9"XG+`H))V1N<U]?<V5L96-T7VUA<W1E<G-?=&]?<F5M;W9E)R`]/B`B4V5L
M96-T(')E8V]R9',@=&\@8F4@<F5M;W9E9"XB+`H))V1N<U]?<V5L96-T7W1E
M;7!L871E7W)E8V]R9%]T;U]R96UO=F4G(#T^("=396QE8W0@<F5C;W)D<R!T
M;R!B92!R96UO=F5D+B<L"@DG9&YS7U]S96QE8W1?8V]M;6]N7V%C;%]R96-O
M<F1?=&]?<F5M;W9E)R`]/B`G4V5L96-T($%#3"!R96-O<F1S(&9O<B!R96UO
M=FEN9RXG+`H))V1N<U]?<V5L96-T7W)E8V]R9%]T;U]R96UO=F4G(#T^("=3
M96QE8W0@<F5S;W5R8V4@<F5C;W)D<R!T;R!B92!R96UO=F5D+B<L"@DG9&YS
M7U]N86UE<V5R=F5R<U]F;W)?9&]M86EN)R`]/B`B3F%M97-E<G9E<G,@9F]R
M('1H92!D;VUA:6XB+`H))V1N<U]?;G,G(#T^(").86UE('-E<G9E<B(L"@DG
M9&YS7U]N<U]R96-O<F0G(#T^(").86UE('-E<G9E<G,B+`H))V1N<U]?<F5M
M;W9E7V1N<U]M87-T97)S7V]N7V1O;6%I;B<@/3X@(E1H92!F;VQL;W=I;F<@
M1$Y3(&UA<W1E<B!S97)V97)S(&9O<B!D;VUA:6X@)3(@;W=N960@8GD@8VQI
M96YT("4Q('=I;&P@8F4@<F5M;W9E9#HB+`H))V1N<U]?<F5M;W9E7V1N<U]Z
M;VYE7V]F7V1O;6%I;E]?)R`]/B`B1$Y3(')E8V]R9',@<F5M;W9A;"!F<F]M
M(&1O;6%I;B`E,2(L"@DG9&YS7U]R96UO=F5?9&YS7WIO;F5?=&5M<&QA=&5?
M7R<@/3X@(E1H92!F;VQL;W=I;F<@<F5S;W5R8V4@<F5C;W)D<R!W:6QL(&)E
M(')E;6]V960@9G)O;2!T:&4@=&5M<&QA=&4Z(BP*"2=D;G-?7W)E;6]V95]C
M;VUM;VY?86-L7W)E8V]R9"<@/3X@(E1H92!F;VQL;W=I;F<@04-,(')E8V]R
M9',@=VEL;"!B92!R96UO=F5D(BP*"2=D;G-?7W)E;6]V95]T:&ES7V1N<U]R
M96-O<F0_)R`]/B`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(')E;6]V92!T
M:&ES($1.4R!R96-O<F0_(BP*"2=D;G-?7W)E<W1O<F5?9&5F875L="<@/3X@
M(E)E<W1O<FEN9R!T:&4@1$Y3('IO;F4@8GD@=&AE('1E;7!L871E(BP*"2=D
M;G-?7W)E<W1O<F5?9&5F875L=%]C;VYF:7)M)R`]/B`B4F5S=&]R:6YG('1H
M92!$3E,@>F]N92!W:6QL(&1I<V-A<F0@=&AE(&-U<G)E;G0@1$Y3('IO;F4@
M8V]N9FEG=7)A=&EO;BP@<')O8V5E9"!A;GEW87D_(BP*"2=D;G-?7W)E<W1O
M<F5?9&5F875L=%]E<G)O<B<@/3X@(D5R<F]R(')E<W1O<FEN9R!$3E,@>F]N
M93HB+`H))V1N<U]?<VQA=F5?9&YS7W1Y<&4G(#T^(")I<R!A('-E8V]N9&%R
M>2!N86UE('-E<G9E<B(L"@DG9&YS7U]S=6)D;VUA:6Y?9&YS7W)E8U]R96UO
M=F5D)R`]/B`B5&AE($$@<F5C;W)D(&AA<R!B965N(')E;6]V960@9G)O;2!T
M:&4@<W5B9&]M86EN('IO;F4@)3$B+`H))V1N<U]?='EP92<@/3X@(E)E8V]R
M9"!T>7!E(BP*"2=D;G-?7W5N86)L95]A8W1I=F%T92]D96%C=&EV871E7V1N
M<R<@/3X@(E5N86)L92!T;R!A8W1I=F%T92]D96%C=&EV871E($1.4SH@)3$B
M+`H))V1N<U]?=6YA8FQE7V%D9%]D;G-?;6%S=&5R7V1U<&QI8V%T95]E;G1R
M>2<@/3X@(E5N86)L92!T;R!A9&0@1$Y3(&UA<W1E<B!S97)V97(Z(&1U<&QI
M8V%T92!E;G1R>2XB+`H))V1N<U]?=6YA8FQE7V1E9FEN95]D;G-?<F5C;W)D
M)R`]/B`B56YA8FQE('1O(&1E9FEN92!T:&4@1$Y3(')E8V]R9#H@)3$B+`H)
M)V1N<U]?=6YA8FQE7V=E=%]D;G-?=&5M<&QA=&5?<W1A='5S)R`]/B`B56YA
M8FQE('1O(')E=')I979E('1H92!$3E,@=&5M<&QA=&4@<W1A='5S+B(L"@DG
M9&YS7U]U;F%B;&5?<F5M;W9E7V1N<U]R96,G(#T^(")5;F%B;&4@=&\@<F5M
M;W9E('1H92!$3E,@<F5C;W)D.B`E,2(L"@DG9&YS7U]V86PG(#T^(")686QU
M92(L"@DG9&YS7U]W87)N:6YG<U]?)R`]/B`B5&AE(')E<W5L="!O9B!$3E,@
M>F]N92!M;V1I9FEC871I;VXZ(BP*"2=D;G-?7WEO=5]N;W1?:&%V95]P97)M
M7VUA;F%G95]D;G,G(#T^(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T
M;R!M86YA9V4@=&AE($1.4R!Z;VYE(&9O<B!T:&ES(&1O;6%I;BXB+`H))V1N
M<U]?>F]N95]R96-O<F0G(#T^(")$3E,@<F5C;W)D<R(L"@DG9&YS7U]D;G-?
M<')E9F5R96YC97-?9F]R;2<@/3X@)T1.4R!P<F5F97)E;F-E<R<L"@DG9&YS
M7U]D;G-?<F5C=7)S:6]N7W-E='1I;F=S)R`]/B`G1$Y3(')E8W5R<VEO;B!S
M971T:6YG<R<L"@DG9&YS7U]A;&QO=U]R96-U<G-I;VXG(#T^("=!;&QO=R!R
M96-U<G-I;VXG+`H))V1N<U]A9&1?7V%D9%]R96-?9F]R7WIO;F4G(#T^(")!
M9&0@)3$@9F]R('IO;F4@)3(B+`H))V1N<U]A9&1?7V-A;F]N:6-A;%]D;VU?
M;F%M95]I<U]I;G9A;&ED)R`]/B`B0V%N;VYI8V%L(&1O;6%I;B!N86UE(&ES
M(&EN=F%L:60N(BP*"2=D;G-?861D7U]E;G1E<E]C86YO;FEC86Q?;F%M92<@
M/3X@(D5N=&5R(&$@8V%N;VYI8V%L(&YA;64B+`H))V1N<U]A9&1?7V5N=&5R
M7V1O;5]N86UE)R`]/B`B16YT97(@9&]M86EN(&YA;64B+`H))V1N<U]A9&1?
M7V5N=&5R7VEP7V%D9')E<W,G(#T^(")%;G1E<B!)4"!A9&1R97-S(BP*"2=D
M;G-?861D7U]E;G1E<E]I<%]M87-K)R`]/B`B16YT97(@25`O;6%S:R(L"@DG
M9&YS7V%D9%]?96YT97)?;6%I;%]D;VUA:6XG(#T^(")%;G1E<B!M86EL(&1O
M;6%I;B(L"@DG9&YS7V%D9%]?96YT97)?;6%I;%]E>&-H86YG97(G(#T^(")%
M;G1E<B!M86EL(&5X8VAA;F=E<B(L"@DG9&YS7V%D9%]?96YT97)?;F%M97-E
M<G9E<B<@/3X@(D5N=&5R(&YA;65S97)V97(B+`H))V1N<U]A9&1?7V5N=&5R
M7W1X=%]R96-O<F0G(#T^(")%;G1E<B!46%0@<F5C;W)D(BP*"2=D;G-?861D
M7U]I;G9A;&ED7VEP)R`]/B`B25`@861D<F5S<R!I<R!I;G9A;&ED+B(L"@DG
M9&YS7V%D9%]?;&]W)R`]/B`B;&]W(BP*"2=D;G-?861D7U]M86EL7V1O;5]N
M86UE7VES7VEN=F%L:60G(#T^(")-86EL(&1O;6%I;B!N86UE(&ES(&EN=F%L
M:60N(BP*"2=D;G-?861D7U]N86UE<V5R=F5R7VES7VEN=F%L:60G(#T^(").
M86UE<V5R=F5R(&ES(&EN=F%L:60N(BP*"2=D;G-?861D7U]R96-O<F0G(#T^
M("(E,2!R96-O<F0B+`H))V1N<U]A9&1?7W-E;&5C=%]P<F5F97)?9F]R7VUA
M:6Q?97AC:&%N9V5?<V5R=F5R)R`]/B`B4W!E8VEF>2!P<FEO<FET>2!O9B!M
M86EL(&5X8VAA;F=E('-E<G9E<B(L"@DG9&YS7V%D9%]?=6YA8FQE7VEN<V5R
M=%]N97=?9&YS7W)E8R<@/3X@(E5N86)L92!T;R!I;G-E<G0@;F5W($1.4R!R
M96-O<F0Z("4Q(BP*"2=D;G-?861D7U]V97)Y7VAI9V@G(#T^(")V97)Y(&AI
M9V@B+`H))V1N<U]C:&5C:U]?=&5S=%]D;G-?>F]N92<@/3X@(E1E<W0@1$Y3
M('IO;F4@)3$@;VX@)3(B+`H))V1N<U]C:&5C:U]?=6YA8FQE7V=E=%]D;VU?
M<')O<&5R=&EE<R<@/3X@(E5N86)L92!T;R!R971R:65V92!D;VUA:6X@<')O
M<&5R=&EE<SH@)3$B+`H))V1O;5]C=')L7U]A;&QO=V5D)R`]/B`B06QL;W=E
M9"(L"@DG9&]M7V-T<FQ?7V1B)R`]/B`B1&%T86)A<V5S(BP*"2=D;VU?8W1R
M;%]?9&5L7VAS=%]O;E]D;VTG(#T^(")!<F4@>6]U('-U<F4@>6]U('=A;G0@
M=&\@<F5M;W9E(&AO<W1I;F<@8V]N9FEG=7)A=&EO;B!F<F]M(&1O;6%I;B`E
M,3\B+`H))V1O;5]C=')L7U]D:7-K7W-P86-E)R`]/B`B1&ES:R!S<&%C92(L
M"@DG9&]M7V-T<FQ?7V1O;5]A9&TG(#T^(")$;VUA:6X@)3$@;V8@)3(B+`H)
M)V1O;5]C=')L7U]D;VU?8VPG(#T^(")$;VUA:6X@)3$B+`H))V1O;5]C=')L
M7U]D;VUA:6Y?:&%S7V9O<G=A<F1I;F=?=VET:%]U;F1E9FEN961?9G=D7W5R
M;"<@/3X@(D1O;6%I;B!H87,@9F]R=V%R9&EN9R!S970@=7`@=VET:"!U;F1E
M9FEN960@9F]R=V%R9&EN9R!54DPB+`H))V1O;5]C=')L7U]D;VUA:6Y?:&%S
M7V9R86UE7V9O<G=A<F1I;F<G(#T^(")$;VUA:6X@:&%S(&9R86UE(&9O<G=A
M<F1I;F<@=&\@=&AE(%523"`E,2(L"@DG9&]M7V-T<FQ?7V1O;6%I;E]H87-?
M;F]?:&]S=&EN9R<@/3X@(D1O;6%I;B!H87,@;F\@:&]S=&EN9R!C;VYF:6=U
M<F5D(BP*"2=D;VU?8W1R;%]?9&]M86EN7VAA<U]P:'ES:6-A;%]H;W-T:6YG
M)R`]/B`B1&]M86EN(&AA<R!P:'ES:6-A;"!H;W-T:6YG(&]N($E0("4Q(BP*
M"2=D;VU?8W1R;%]?9&]M86EN7VAA<U]S=&%N9&%R9%]F;W)W87)D:6YG)R`]
M/B`B1&]M86EN(&AA<R!S=&%N9&%R9"!F;W)W87)D:6YG('1O('1H92!54DP@
M)3$B+`H))V1O;5]C=')L7U]M86EL;&ES=',G(#T^(")-86EL:6YG(&QI<W1S
M(BP*"2=D;VU?8W1R;%]?;6)O>&5S)R`]/B`B36%I;&)O>&5S(BP*"2=D;VU?
M8W1R;%]?;6<G(#T^(")-86EL(&=R;W5P<R(L"@DG9&]M7V-T<FQ?7W)E9&ER
M)R`]/B`B4F5D:7)E8W1S(BP*"2=D;VU?8W1R;%]?<F5S;W5R8V5?;F%M92<@
M/3X@(E)E<V]U<F-E(BP*"2=D;VU?8W1R;%]?<F5S<"<@/3X@(D%U=&]R97-P
M;VYD97)S(BP*"2=D;VU?8W1R;%]?<W5B9&]M)R`]/B`B4W5B9&]M86EN<R(L
M"@DG9&]M7V-T<FQ?7W1R869F:6,G(#T^(")4<F%F9FEC(BP*"2=D;VU?8W1R
M;%]?=6YA8FQE7V%C=&EV871E+V1E86-T:79A=&5?9&]M)R`]/B`B56YA8FQE
M('1O(&%C=&EV871E+V1E86-T:79A=&4@9&]M86EN.B`E,2(L"@DG9&]M7V-T
M<FQ?7W5S960G(#T^(")5<V5D(BP*"2=D;VU?8W1R;%]?=V5B87!P<R<@/3X@
M(DIA=F$@87!P;&EC871I;VYS(BP*"2=D;VU?8W1R;%]?>6]U7W=A;G1?8VAA
M;F=E7W1H95]S=&%T=7-?;V9?=&AE7V1O;6%I;C\_)R`]/B`B07)E('EO=2!S
M=7)E('EO=2!W86YT('1O(&-H86YG92!T:&4@<W1A=&4@;V8@9&]M86EN/R(L
M"@DO+R!E;F0@;V8@<V5R9V4@<&%R=`H*"2\O(&UA=F5R:6-K('!A<G0*"@DG
M9&]M7V-T<FQ?7W=U)R`]/B`B5V5B('5S97)S(BP*"2=D;VU?<')E9E]?8F]U
M;F-E7W=I=&A?<&AR87-E)R`]/B`B0F]U;F-E('=I=&@@;65S<V%G92(L"@DG
M9&]M7W!R969?7V-A=&-H7V%D9'(G(#T^(")&;W)W87)D('1O(&%D9')E<W,B
M+`H))V1O;5]P<F5F7U]R96IE8W0G(#T^("=296IE8W0G+`H))V1O;5]P<F5F
M7U]C;VYF:7)M7V1O;6%I;E]R96UO=FEN9R<@/3X@(E!L96%S92P@9&\@;F]T
M(&9O<F=E="!T;R!I;F9O<FT@=&AE(&1O;6%I;B!V:7-I=&]R<R!O9B!T:&4@
M9&]M86EN(&YA;64@8VAA;F=E+B!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@
M<F5N86UE('1H92!D;VUA:6X_(BP*"2=D;VU?<')E9E]?9&)?:6YC;VYS>7-T
M96YC>2<@/3X@(F1A=&%B87-E(&EN8V]N<VES=&5N8WDN(BP*"2=D;VU?<')E
M9E]?9&)S)R`]/B`B9&%T86)A<V5S(BP*"2=D;VU?<')E9E]?9&5L971E7W1R
M869F:6-?<W1A="<@/3X@(E)E=&%I;B!T<F%F9FEC('-T871I<W1I8W,B+`H)
M)V1O;5]P<F5F7U]D96QE=&5?=')A9F9I8U]S=&%T7V]L9&5R)R`]/B`B4F5T
M86EN('1R869F:6,@<W1A=&ES=&EC<R(L"@DG9&]M7W!R969?7V1O7VYO=%]U
M<V5?<WEM8F]L7V%P;W-T<F]F)R`]/B`B1&\@;F]T('5S92!A<&]S=')O<&AE
M+"!R979E<G-E(&%P;W-T<F]P:&4L('-E;6EC;VQO;B!O<B!E;7!T>2!V86QU
M92!I;B!T:&4@8F]U;F-E(&UE<W-A9V4@9FEE;&0N(BP*"2=D;VU?<')E9E]?
M9&]M7VQE=F5L7VYA;65?8V]N9FQI8W0G(#T^(")4:&4@9&]M86EN(&%D;6EN
M:7-T<F%T;W(G<R!L;V=I;B!N86UE(&-O;F9L:6-T<R!W:71H(&QO9VEN(&YA
M;64@;V8@;VYE(&]F('1H92!C;&EE;G1S+B(L"@DG9&]M7W!R969?7VEN=F%L
M:61?9&ES:U]S<&%C95]L:6UI="<@/3X@(DEN=F%L:60@9&ES:R!S<&%C92!L
M:6UI="XB+`H))V1O;5]P<F5F7U]I;G9A;&ED7V5X<&ER871I;VY?9&%T95]L
M:6UI="<@/3X@(DEN=F%L:60@=F%L:61I='D@<&5R:6]D+B(L"@DG9&]M7W!R
M969?7VEN=F%L:61?;6%X7W1R869F:6-?;&EM:70G(#T^("));G9A;&ED('1R
M869F:6,@;&EM:70N(BP*"2=D;VU?<')E9E]?;&EM:71S7V]F7V1O;2<@/3X@
M(DQI;6ET<R!F;W(@9&]M86EN("4Q(BP*"2=D;VU?<')E9E]?;6%I;%]G<G!S
M)R`]/B`B;6%I;"!G<F]U<',B+`H))V1O;5]P<F5F7U]M86EL7VYO;F5X:7-T
M96YT7W5S97(G(#T^(")-86EL('1O(&YO;F5X:7-T96YT('5S97(B+`H))V1O
M;5]P<F5F7U]M86EL7W)E9&ER<R<@/3X@(FUA:6P@<F5D:7)E8W1S(BP*"2=D
M;VU?<')E9E]?;6%I;%]R97-P<R<@/3X@(FUA:6P@875T;W)E<W!O;F1E<G,B
M+`H))V1O;5]P<F5F7U]M87A?;&EM:71?:7-?:6YV86QI9"<@/3X@(B4Q(&ES
M(&EN=F%L:60N(BP*"2=D;VU?<')E9E]?;6%X7VYU;5]O9E\E;V)J96-T<U]I
M<U]I;G9A;&ED)R`]/B`B36%X:6UU;2!N=6UB97(@;V8@)3$@:7,@:6YV86QI
M9"XB+`H))V1O;5]P<F5F7U]N97=?;&EM:71?;&5S<U]C=7)R96YT;'E?=7-E
M9"<@/3X@(B4Q.B!R97%U97-T960@+2`E,BP@8W5R<F5N=&QY('5S960@+2`E
M,R(L"@DG9&]M7W!R969?7V]L9&5R7W1H870G(#T^("(@9F]R("(L"@DG9&]M
M7W!R969?7W!O<W1B;WAE<R<@/3X@(FUA:6QB;WAE<R(L"@DG9&]M7W!R969?
M7W!R969E<F5N8V5S7V]F7V1O;2<@/3X@(E!R969E<F5N8V5S(&9O<B!D;VUA
M:6X@)3$B+`H))V1O;5]P<F5F7U]R961I<F5C=%]T;U]I='-E;&8G(#T^(")4
M:&4@9&]M86EN('=I;&P@:&%V92!T:&4@9F]R=V%R9&EN9R!S970@=&\@:71S
M96QF(BP*"2=D;VU?<')E9E]?=')A9E]S=&%T7W=I;&Q?;F]T7V1E;&5T92<@
M/3X@(E1R869F:6,@<W1A=&ES=&EC<R!W:6QL(&YO="!B92!D96QE=&5D+B(L
M"@DG9&]M7W!R969?7W1R869F:6-?;&]G9VEN9U]P97)I;V1?8V]U;&1N=%]B
M95]L;W=E<B<@/3X@(EEO=2!S<&5C:69I960@=&AE(&1O;6%I;B!T<F%F9FEC
M('-T871I<W1I8W,@<F5T96YT:6]N('1I;64@=&\@8F4@;&5S<R!T:&%N('1H
M92!T;W1A;"!V86QU92!D969I;F5D(&9O<B!T:&4@<V5R=F5R("@E,2!M;VYT
M:"AS*2DN(%1H92!S=&%T:7-T:6-S(')E=&5N=&EO;B!P97)I;V0@:7,@<V5T
M(&5Q=6%L('1O('1H92!D969A=6QT('9A;'5E(&9O<B!T:&4@<V5R=F5R("@E
M,2!M;VYT:"AS*2DN(BP*"2=D;VU?<')E9E]?=6YA8FQE7V%D9%]W=W=?<')E
M9FEX7VEN7V1O;2<@/3X@(E5N86)L92!T;R!A9&0@82!W=W<@<')E9FEX('1O
M(&1O;6%I;CH@)3$B+`H))V1O;5]P<F5F7U]U;F%B;&5?9&5F:6YE7W!H>7-I
M8V%L7VAS=%]P87)A;2<@/3X@(E5N86)L92!T;R!D969I;F4@<&AY<VEC86P@
M:&]S=&EN9R!P87)A;65T97)S.B`E,2(L"@DG9&]M7W!R969?7W5N86)L95]R
M96YA;65?9&]M86EN)R`]/B`B56YA8FQE('1O(')E;F%M92!T:&4@9&]M86EN
M(BP*"2=D;VU?<')E9E]?=6YA8FQE7W-E=%]U<%]M8F]X7W%U;W1A)R`]/B`B
M56YA8FQE('1O('-E="!T:&4@;6%I;&)O>"!Q=6]T82!F;W(@=&AI<R!D;VUA
M:6XZ("4Q(BP*"2=D;VU?<')E9E]?=6YA8FQE7W-E=%]U<%]W96)?=7-E<E]S
M8W)I<'0G(#T^(")5;F%B;&4@=&\@<V5T('5P('-C<FEP=&EN9R!F;W(@=V5B
M('5S97)S.B`E,2(L"@DG9&]M7W!R969?7W5N;&EM:71E9"<@/3X@(E5N;&EM
M:71E9"(L"@DG9&]M7W!R969?7W=E8E]U<W)S)R`]/B`B=V5B('5S97)S(BP*
M"2=D;VU?<')E9E]?=V5B=7-E<G-?<V-R:7!T)R`]/B`B06QL;W<@=&AE('=E
M8B!U<V5R<R!S8W)I<'1I;F<B+`H))V1O;5]P<F5F7U]Y;W5?86QR96%D>5]H
M879E7R5O8FIE8W0G(#T^(")9;W4@86QR96%D>2!H879E("4Q(BP*"2=D;VU?
M8VQI7U]W87)N:6YG7VEG;F]R95]Q=6]T82<@/3X@)U=!4DY)3D<Z($]P=&EO
M;B`B+6AA<F1?<75O=&$B(&ES(&EG;F]R960Z(&AA<F0@9&ES:R!Q=6]T82!I
M<R!N;W0@<W5P<&]R=&5D)RP*"2=D;VU?=7-E<E]C;&EE;G1?;&]G:6Y?97AI
M<W0G(#T^(")5;F%B;&4@=&\@86QL;W<@9&]M86EN(&%D;6EN:7-T<F%T;W(G
M<R!A8V-E<W,@=&\@8V]N=')O;"!P86YE;"!O;B!T:&4@9&]M86EN("4Q.B!L
M;V=I;B!N86UE(&ES(&%L<F5A9'D@:6X@=7-E+B(L"@DG9&]M7W1R869F:6-?
M:&ES=&]R>5]?=&ET;&4G(#T^(")$;VUA:6X@/'-P86X@8VQA<W,]7")N86UE
M7"(^)3$\+W-P86X^('1R869F:6,@:&ES=&]R>2XB+`H))V1O;6%I;E]?<W5B
M9&]M86EN7V5X:7-T<R<@/3X@(E1H97)E(&ES(&$@<W5B9&]M86EN('=I=&@@
M;F%M92`E,2XE,BXB+`H))V1O;6%I;E]?9&%L:6%S7V5X:7-T<R<@/3X@(E1H
M97)E(&ES(&$@9&]M86EN(&%L:6%S('=I=&@@;F%M92`E,2XE,BXB+`H))V1O
M;6%I;E]?=6YA8FQE7W1O7W1U<FY?;VY?<V5R=FEC92<@/3X@(D9A:6QE9"!T
M;R!E;F%B;&4@=&AE("4Q('-E<G9I8V4B+`H))V1O;6%I;G-?7V-H86YG95]T
M:&5?<W1A='5S7V]F7V1O;6%I;C\G(#T^(")!<F4@>6]U('-U<F4@>6]U('=A
M;G0@=&\@8VAA;F=E('1H92!S=&%T=7,@;V8@9&]M86EN("4Q/R(L"@DG9&]M
M86EN<U]?8VQI96YT7VEN9F\G(#T^("(E,2!D;VUA:6YS+"`E,B!A8W1I=F4@
M9&]M86EN<RP@)3,@9&ES:R!S<&%C92!U<V5D+"`E-"!T<F%F9FEC('5S960B
M+`H))V1O;6%I;G-?7V-L:65N=%]I;F9O7VAI9&EN9U]T<F%F9FEC)R`]/B`B
M)3$@9&]M86EN<RP@)3(@86-T:79E(&1O;6%I;G,L("4S(&1I<VL@<W!A8V4@
M=7-E9"(L"@DG9&]M86EN<U]?<F5M;W9E7V1O;2<@/3X@(E1H92!F;VQL;W=I
M;F<@9&]M86EN<R!W:6QL(&)E(')E;6]V960Z(BP*"2=D;VUA:6YS7U]R96UO
M=F5?9&]M7V9O<E]C;"<@/3X@(E1H92!F;VQL;W=I;F<@9&]M86EN<R!O=VYE
M9"!B>2!C;&EE;G0@)3$@=VEL;"!B92!R96UO=F5D.B(L"@DG9&]M86EN<U]?
M<V5L96-T7V1O;5]F;W)?<F5M;W9E)R`]/B`B4V5L96-T(&1O;6%I;G,@=&\@
M8F4@<F5M;W9E9"XB+`H))V1O;6%I;G-?7W5N86)L95]T;U]C:&%N9V5?8VQI
M96YT7W-T871U<R<@/3X@(E5N86)L92!T;R!C:&%N9V4@=&AE(&-L:65N="!A
M8V-O=6YT('-T871U<SH@)3$B+`H))V1O;6%I;G-?7W5N86)L95]U<&1A=&5?
M87!A8VAE7W-E='1I;F=S)R`]/B`B56YA8FQE('1O('5P9&%T92!!<&%C:&4@
M<V5T=&EN9W,B+`H))V1O;6%I;G-?7WEO=5]D;U]N;W1?:&%V95]P97)M:7-S
M:6]N<U]T;U]D96QE=&5?9&]M86EN<R<@/3X@(EEO=2!D;R!N;W0@:&%V92!P
M97)M:7-S:6]N<R!T;R!D96QE=&4@9&]M86EN<RXB+`H))V1O;6%I;G-?7WEO
M=5]W86YT7V-H86YG95]T:&5?<W1A='5S7V]F7W1H95]C;#\_)R`]/B`B07)E
M('EO=2!S=7)E('EO=2!W86YT('1O(&-H86YG92!T:&4@<W1A=&4@;V8@8VQI
M96YT(&%C8V]U;G0_(BP*"2=D;VUA:6YS7U]Y;W5?=V%N=%]C:&%N9V5?=&AE
M7V-P7V%C8V5S<U]O9E]T:&5?8VP_/R<@/3X@(D%R92!Y;W4@<W5R92!Y;W4@
M=V%N="!T;R!P97)F;W)M('1H:7,@;W!E<F%T:6]N/R(L"@DG9&]M86EN<U]L
M:7-T7U]U;F%B;&5?<F5M;W9E7V1O;7,G(#T^(")5;F%B;&4@=&\@<F5M;W9E
M(&1O;6%I;G,Z("4Q(BP*"2=D;VUA:6YT<F%F9FEC;&ES=%]H96%D97)?;V9?
M9&]M86EN7U\G(#T^(")4<F%F9FEC(&%T(&1O;6%I;B`E,2(L"@DG9'-?7V%N
M;VYY;6]U<U]F='`G(#T^(")!;F]N>6UO=7,@1E10(BP*"2=D<G=E8E]?<&%G
M971I=&QE)R`]/B`G1'(N5V5B($%N=&EV:7)U<R!0<F5F97)E;F-E<R<L"@DG
M9')W96)?7V1R=V5B)R`]/B`G06YT:79I<G5S(&UA:6P@8VAE8VMI;F<G+`H)
M)V1R=V5B7U]D<G=E8E]D:7)E8W1I;VXG(#T^("=#:&5C:VEN9R!M86EL(&9O
M<B!V:7)U<V5S)RP*"2=D<G=E8E]?9')W96)?9&ER96-T:6]N7V]F9B<@/3X@
M)T1I<V%B;&5D)RP*"2=D<G=E8E]?9')W96)?9&ER96-T:6]N7V%N>2<@/3X@
M)TEN8V]M:6YG(&%N9"!O=71G;VEN9R!M86EL)RP*"2=D<G=E8E]?9')W96)?
M9&ER96-T:6]N7V9R;VTG(#T^("=/=71G;VEN9R!M86EL(&]N;'DG+`H))V1R
M=V5B7U]D<G=E8E]D:7)E8W1I;VY?=&\G(#T^("=);F-O;6EN9R!M86EL(&]N
M;'DG+`H))V1R=V5B7U]D:7-A8FQE7W)E87-O;E]K97DG(#T^("=$<BY796(@
M:7,@;F]T('-U<'!O<G1E9"!B>2!T:&4@;&EC96YS92!K97DN)RP*"2=D<G=E
M8E]?9&ES86)L95]R96%S;VY?<&5R;2<@/3X@)UEO=2!H879E(&YO('!E<FUI
M<W-I;VX@=&\@;6%N86=E($1R+E=E8B!A;G1I=FER=7,N)RP*"2=D<G=E8E]?
M9&ES86)L95]R96%S;VY?:6YS=&%L;"<@/3X@)T1R+E=E8B!A;G1I=FER=7,@
M:7,@;F]T(&EN<W1A;&QE9"XG+`H))V1S7U]D;G,G(#T^(")$3E,@6F]N92(L
M"@DG9'-?7VUA:6PG(#T^(")-86EL(BP*"2=D<U]?=&]M8V%T)R`]/B`B5&]M
M8V%T(BP*"2=D<W)?7V]F7V-L:65N=%]T:71L92<@/3X@(D1O;6%I;B!3=6UM
M87)Y(%)E<&]R="!O9B`E,2(L"@DG9'-R7U]R97!O<G1?:&%S7V)E96Y?<V5N
M=%]E;6%I;"<@/3X@(D1O;6%I;B!3=6UM87)Y(%)E<&]R="!H87,@8F5E;B!S
M96YT('1O(&4M;6%I;#H@)3$B+`H))V1S<E]?=&ET;&4G(#T^(")$;VUA:6X@
M4W5M;6%R>2!297!O<G0B+`H))V1U;7!?9FEL95]?<F5M;W9E)PD]/B`B4F5M
M;W9E(BP*"2=D=6UP7V9I;&5?7V%D9"<)/3X@(E-P96-I9GD@=&AE(&YE>'0@
M=F]L=6UE(BP*"2=D=6UP<U]L:7-T7U]D96QE=&EO;E]P86=E7W1I=&QE)R`]
M/B`B5&AE(&9O;&QO=VEN9R!B86-K=7`@9FEL97,@;V8@9&]M86EN("4Q('=I
M;&P@8F4@<F5M;W9E9#HB+`H))V1U;7!S7VQI<W1?7W5P;&%D7V1U;7!?9FEL
M97,G(#T^(")5<&QO860@8F%C:W5P(&9I;&4B+`H))V1U;7!S7VQI<W1?7V1U
M;7!?9FEL97,G(#T^(")"86-K=7`@9FEL97,B+`H))V1U;7!S7VQI<W1?7V1U
M;7!F:6QE7V%L<F5A9'E?97AI<W1S)R`]/B`B5&AE(&9I;&4@)3$@86QR96%D
M>2!E>&ES=',N(BP*"2=D=6UP<U]L:7-T7U]D=6UP9FEL95]I<U]I;G9A;&ED
M)R`]/B`B5&AE(&9I;&4@)3$@:7,@;F]T(&$@=F%L:60@9&]M86EN(&)A8VMU
M<"!F:6QE+B(L"@DG9'5M<'-?;&ES=%]?<&%G95]T:71L92<@/3X@(D)A8VMU
M<"!F:6QE<R!R97!O<VET;W)Y(BP*"2=D=6UP<U]U<&QO861?7W!A9V5?=&ET
M;&4G(#T^(")5<&QO861I;F<@0F%C:W5P($9I;&5S('1O(%)E<&]S:71O<GDB
M+`H))V1U;7!S7VQI<W1?7W)E<&]S:71O<GE?:7-?;F]T7V5X:7-T)R`]/B`B
M0F%C:W5P(&9I;&5S(')E<&]S:71O<GD@9&]E<R!N;W0@97AI<W0B+`H))V1U
M;7!S7VQI<W1?7W1O=&%L7W-I>F4G(#T^(")4;W1A;"!S:7IE.B`E,2(L"@DG
M9'5M<'-?;&ES=%]?=6YA8FQE7W1O7W)E;6]V92<@/3X@(E5N86)L92!T;R!R
M96UO=F4@=&AE(&)A8VMU<"!F:6QE.B`E,2(L"@DG9'5M<'-?;&ES=%]?9'5M
M<&9I;&5?8V%N7V-O;F9L:6-T)R`]/B`B5&AE(&9I;&4@;F%M92!Y;W4@<W!E
M8VEF:65D(&-O;F9L:6-T<R!W:71H(&9I;&4@)3'"H%!L96%S92P@<W!E8VEF
M>2!A;F]T:&5R(&9I;&4@;F%M92XB+`H))V1U<W)?961?7V%L;&]W7V1L7W5S
M<E]A8V-E<W,G(#T^(")!;&QO=R!D;VUA:6X@861M:6YI<W1R871O<B=S(&%C
M8V5S<R(L"@DG9'5S<E]E9%]?:6YF;W)M871I;VXG(#T^(")%9&ET('1H92!P
M<F]P97)T:65S(&]F(&1O;6%I;B!A9&UI;FES=')A=&]R)W,@86-C;W5N="(L
M"@DG9'5S<E]E9%]?;&]C86QE)R`]/B`B1&]M86EN(&%D;6EN:7-T<F%T;W(G
M<R!L86YG=6%G92(L"@DG9'5S<E]E9%]?<VMI;B<@/3X@(D1O;6%I;B!A9&UI
M;FES=')A=&]R)W,@:6YT97)F86-E('-K:6XB+`H))V5S<U]?97)R;W(G(#T^
M(")%<G)O<B(L"@DG979E;G1?:&%N9&QE<E]E9&ET7U]T:71L92<@/3X@)T5V
M96YT($AA;F1L97(@4')O<&5R=&EE<R<L"@DG979E;G1?:&%N9&QE<G-?<F5M
M;W9E7U]T:71L92<@/3X@)U)E;6]V92!T:&4@<V5L96-T960@979E;G0@:&%N
M9&QE<G,G+`H))V5V96YT7VAA;F1L97)S7W)E;6]V95]?<V5L96-T7V5V96YT
M7VAA;F1L97)S7V9O<E]R96UO=F4G(#T^("=396QE8W0@=&AE(&5V96YT(&AA
M;F1L97)S('1O(&)E(')E;6]V960N)RP*"2=E=F5N=%]H86YD;&5R<U]L:7-T
M7U]T:71L92<@/3X@)T5V96YT($UA;F%G97(G+`H))V5X86UP;&5?7R<@/3X@
M(D5X86UP;&4Z("4Q(BP*"2=E>'1R87-?7V)U>5]N97=?:V5Y)R`]/B`B66]U
M<B!C=7)R96YT(&QI8V5N<V4@:V5Y(&1O97,@;F]T(&%L;&]W('EO=2!T;R!M
M;V1I9GD@=&AE<V4@;V)J96-T<RX@268@>6]U('=I<V@@=&\@8F4@86)L92!T
M;R!D;R!T:&%T+"!Y;W4@<VAO=6QD('!U<F-H87-E(&$@;F5W(&QI8V5N<V4@
M:V5Y(BP*"@DG9F5A='5R95]?9&5S:W1O<%]?:&5A9&5R)R`]/B`G1&5S:W1O
M<"<L"@DG9F5A='5R95]?9&5S:W1O<%]?861M:6XG(#T^("=4:&4@<&%G92!Y
M;W4@87)E(&-U<G)E;G1L>2!O;B!I<R!T:&4@;F5W('1A<VLM;W)I96YT960@
M1&5S:W1O<"P@=VAI8V@@9VEV97,@>6]U('%U:6-K(&%C8V5S<R!T;R!Y;W5R
M(&1A:6QY('1A<VMS+"!R97-O=7)C97,@=7-A9V4@<W1A=&ES=&EC<RP@86YD
M(&]F9F5R<R!A(&AA;F1Y('-T;W)A9V4@9F]R('EO=7(@9F%V;W)I=&4@<&QA
M8V5S(&EN(%!L97-K+B!$97-K=&]P(&ES(&%C8V5S<VEB;&4@9G)O;2!T:&4@
M;&5F="!M96YU(&%T(&%N>2!T:6UE+B<L"@DG9F5A='5R95]?9&5S:W1O<%]?
M8VQI96YT)R`]/B`G5&AE('!A9V4@>6]U(&%R92!C=7)R96YT;'D@;VX@:7,@
M=&AE(&YE=R!T87-K+6]R:65N=&5D($1E<VMT;W`L('=H:6-H(&=I=F5S('EO
M=2!Q=6EC:R!A8V-E<W,@=&\@>6]U<B!D86EL>2!T87-K<RP@<F5S;W5R8V5S
M('5S86=E('-T871I<W1I8W,L(&%N9"!O9F9E<G,@82!H86YD>2!S=&]R86=E
M(&9O<B!Y;W5R(&9A=F]R:71E('!L86-E<R!I;B!0;&5S:RX@1&5S:W1O<"!I
M<R!A8V-E<W-I8FQE(&9R;VT@=&AE(&QE9G0@;65N=2!A="!A;GD@=&EM92XG
M+`H))V9E871U<F5?7V1E<VMT;W!?7V1O;6%I;B<@/3X@)U1H92!P86=E('EO
M=2!A<F4@8W5R<F5N=&QY(&]N(&ES('1H92!N97<@=&%S:RUO<FEE;G1E9"!$
M97-K=&]P+"!W:&EC:"!G:79E<R!Y;W4@<75I8VL@86-C97-S('1O('EO=7(@
M9&%I;'D@=&%S:W,L(')E<V]U<F-E<R!U<V%G92!S=&%T:7-T:6-S+"!A;F0@
M;V9F97)S(&$@:&%N9'D@<W1O<F%G92!F;W(@>6]U<B!F879O<FET92!P;&%C
M97,@:6X@4&QE<VLN($1E<VMT;W`@:7,@86-C97-S:6)L92!F<F]M('1H92!L
M969T(&UE;G4@870@86YY('1I;64N)RP*"2=F96%T=7)E7U]D;VUA:6Y?86QI
M87-E<U]?:&5A9&5R)R`]/B`G1&]M86EN($%L:6%S97,G+`H))V9E871U<F5?
M7V1O;6%I;E]A;&EA<V5S7U]C;&EE;G0G(#T^("=4:&ES(&YE=R!F96%T=7)E
M(&%L;&]W<R!Y;W4@=&\@<V5T('5P(&%L=&5R;F%T:79E(&YA;65S(&9O<B!Y
M;W5R(&1O;6%I;G,@=VET:"!N;R!A9&1I=&EO;F%L(&-O<W0N($1O;6%I;B!A
M;&EA<V5S(&%C="!A<R!N:6-K;F%M97,@9F]R('EO=7(@=V5B<VET97,@86YD
M(&4M;6%I;"!A9&1R97-S97,N(%1H:7,@9F5A='5R92!I<R!A8V-E<W-I8FQE
M(&)Y('-E;&5C=&EN9R!A(&1O;6%I;B!O;B!Y;W5R($AO;64@4&%G92!A;F0@
M8VQI8VMI;F<@7"=$;VUA:6X@06QI87-E<UPG+B<L"@DG9F5A='5R95]?9&]M
M86EN7V%L:6%S97-?7V1O;6%I;B<@/3X@)U1H:7,@;F5W(&9E871U<F4@86QL
M;W=S('EO=2!T;R!S970@=7`@86QT97)N871I=F4@;F%M97,@9F]R('EO=7(@
M9&]M86EN('=I=&@@;F\@861D:71I;VYA;"!C;W-T+B!$;VUA:6X@86QI87-E
M<R!A8W0@87,@;FEC:VYA;65S(&9O<B!Y;W5R('=E8G-I=&4@86YD(&4M;6%I
M;"!A9&1R97-S97,N(%1H:7,@9F5A='5R92!I<R!A8V-E<W-I8FQE(&)Y(&-L
M:6-K:6YG(%PG1&]M86EN($%L:6%S97-<)R!O;B!Y;W5R($AO;64@<&%G92XG
M+`H))V9E871U<F5?7V1O;6%I;E]A;&EA<V5S7U]Q=6EC:U]L:6YK)R`]/B`G
M1V\@=&\@1&]M86EN($%L:6%S97,@;6%N86=E;65N="<L"@DG9F5A='5R95]?
M=V%T8VAD;V<R7U]H96%D97(G(#T^("=7871C:&1O9R`R+C`G+`H))V9E871U
M<F5?7W=A=&-H9&]G,E]?861M:6XG(#T^("=4:&4@<V5C;VYD(&5D:71O;B!O
M9B!7871C:&1O9R!M;V1U;&4@(&UO;FET;W)S('9I=&%L(%!L97-K('-E<G9I
M8V5S(&QI:V4@07!A8VAE(%=E8B!397)V97(L(&YO=&EF>6EN9R!Y;W4@=FEA
M(&4M;6%I;"!I;B!C87-E(&]F('-E<G9I8V4@:7-S=65S+B!7871C:&1O9R`R
M+C`@;F]W(&%L<V\@;6]N:71O<G,@>6]U<B!H87)D(&1I<VMS('1O(&5N<W5R
M92!Y;W4@=V]N7"=T(')U;B!O=70@;V8@<W1O<F%G92!U;F5X<&5C=&5D;'DL
M('-C86YS('EO=7(@<V5R=F5R(&9O<B!S96-U<FET>2!V=6QN97)A8FEL:71I
M97,@<W5C:"!A<R!R;V]T:VET<RP@8F%C:V1O;W)S(&%N9"!L;V-A;"!E>'!L
M;VET<RP@86YD(&1I<W!L87ES($-052!A;F0@4D%-('5S86=E('-T871I<W1I
M8W,N(%1O(&%C8V5S<R!7871C:&1O9R`R+C`L(&-L:6-K($UO9'5L97,@:6X@
M=&AE(&QE9G0@;65N=2P@=&AE;B!C;&EC:R!7871C:&1O9R!O;B!T:&4@($UO
M9'5L97,@<&%G92XG+`H))V9E871U<F5?7W=A=&-H9&]G,E]?<75I8VM?;&EN
M:R<@/3X@)T=O('1O(%=A=&-H9&]G(#(N,"<L"@DG9F5A='5R95]?<F5M;W1E
M7V1B7U]H96%D97(G(#T^("=296UO=&4@1&%T86)A<V4@2&]S=&EN9R<L"@DG
M9F5A='5R95]?<F5M;W1E7V1B7U]A9&UI;B<@/3X@)TEN(&%D9&ET:6]N('1O
M(&AO<W1I;F<@;&]C86P@9&%T86)A<V5S+"!0;&5S:R`X(&-A;B!H;W-T('5S
M97)S7"<@9&%T82!O;B!R96UO=&4@9&%T86)A<V4@<V5R=F5R<RX@66]U(&-A
M;B!E=F5N(&AA=F4@<V5V97)A;"!0;&5S:R!S97)V97)S(&AO<W1I;F<@=&AE
M:7(@=7-E<G-<)R!D871A8F%S97,@;VX@82!S:6YG;&4@9&5D:6-A=&5D(&UA
M8VAI;F4N($)O=&@@37E344P@*&EN8VQU9&EN9R!->5-13"`T+C$I(&%N9"!0
M;W-T9W)E4U%,(&%R92!S=7!P;W)T960N(%1O(&%C8V5S<R!$871A8F%S92!3
M97)V97)S(&UA;F%G96UE;G0@<&%G92P@8VQI8VL@1&%T86)A<V4@4V5R=F5R
M<R!O;B!397)V97(@061M:6YI<W1R871I;VX@<&%G92XG+`H))V9E871U<F5?
M7W)E;6]T95]D8E]?<75I8VM?;&EN:R<@/3X@)T=O('1O($1A=&%B87-E(%-E
M<G9E<G,@;6%N86=E;65N="<L"@DG9F5A='5R95]?;6%I;%]Q=65U95]?:&5A
M9&5R)R`]/B`G36%I;"!1=65U92!-86YA9V5M96YT)RP*"2=F96%T=7)E7U]M
M86EL7W%U975E7U]A9&UI;B<@/3X@)U1H:7,@;F5W(&9E871U<F4@86QL;W=S
M(&%D;6EN:7-T<F%T;W)S('1O(&UA;F%G92!T:&4@46UA:6P@;65S<V%G92!Q
M=65U92!D:7)E8W1L>2!F<F]M(%!L97-K+B!7:71H('1H:7,@9F5A='5R92P@
M>6]U(&-A;B!M86YU86QL>2!D96QE=&4@<W!A;2!A;F0@;W1H97(@=6YW86YT
M960@;6%I;"!F<F]M('1H92!Q=65U92P@=7-I;F<@<75I8VL@86YD(&EN='5I
M=&EV92!S;W)T:6YG(&]P=&EO;G,N(%1O(&%C8V5S<R!-86EL('%U975E(&UA
M;F%G96UE;G0@<&%G92P@8VQI8VL@36%I;"!O;B!T:&4@4V5R=F5R($%D;6EN
M:7-T<F%T:6]N('!A9V4@86YD('-E;&5C="!T:&4@36%I;"!1=65U92!T86(N
M)RP*"2=F96%T=7)E7U]M86EL7W%U975E7U]Q=6EC:U]L:6YK)R`]/B`G1V\@
M=&\@36%I;"!1=65U92!M86YA9V5M96YT)RP*"2=F96%T=7)E7U]S;V%?7VAE
M861E<B<@/3X@)T1.4R!33T$@4F5C;W)D<R!-86YA9V5M96YT)RP*"2=F96%T
M=7)E7U]S;V%?7V-L:65N="<@/3X@)U-T87)T($]F($%U=&AO<FET>2`H4T]!
M*2!R96-O<F1S(&%R92!S<&5C:6%L('1Y<&4@;V8@1$Y3(')E8V]R9',@=&AA
M="!D969I;F4@=&AE('!A<F%M971E<G,@;V8@1$Y3(')E8V]R9',@8V%C:&EN
M9RX@4W1A<G1I;F<@=VET:"!0;&5S:R`X+"!Y;W4@:&%V92!F=6QL(&-O;G1R
M;VP@;W9E<B!$3E,@4T]!(')E8V]R9',L('=H:6-H(&QE=',@>6]U('-P96-I
M9GD@=F%R:6]U<R!T:6UE;W5T<R!T;R!F:6YE+71U;F4@=&AE(&1O;6%I;B!N
M86UE('-E<G9I8V4N(%1O(&%C8V5S<R!33T$@<F5C;W)D<R!M86YA9V5M96YT
M+"!S96QE8W0@82!D;VUA:6X@;VX@>6]U<B!(;VUE('!A9V4L(&-L:6-K($1.
M4R!A;F0@8VQI8VL@4T]!(%!R969E<F5N8V5S+B<L"@DG9F5A='5R95]?<V]A
M7U]D;VUA:6XG(#T^("=3=&%R="!/9B!!=71H;W)I='D@*%-/02D@<F5C;W)D
M<R!A<F4@<W!E8VEA;"!T>7!E(&]F($1.4R!R96-O<F1S('1H870@9&5F:6YE
M('1H92!P87)A;65T97)S(&]F($1.4R!R96-O<F1S(&-A8VAI;F<N(%-T87)T
M:6YG('=I=&@@4&QE<VL@."P@>6]U(&AA=F4@9G5L;"!C;VYT<F]L(&]V97(@
M1$Y3(%-/02!R96-O<F1S+"!W:&EC:"!L971S('EO=2!S<&5C:69Y('9A<FEO
M=7,@=&EM96]U=',@=&\@9FEN92UT=6YE('1H92!D;VUA:6X@;F%M92!S97)V
M:6-E+B!4;R!A8V-E<W,@4T]!(')E8V]R9',@;6%N86=E;65N="P@8VQI8VL@
M1$Y3(&]N('EO=7(@2&]M92!P86=E(&%N9"!C;&EC:R!33T$@4')E9F5R96YC
M97,N)RP*"2=F96%T=7)E7U]S;V%?7W%U:6-K7VQI;FLG(#T^("=';R!T;R!3
M3T$@4F5C;W)D<R!M86YA9V5M96YT('!A9V4G+`H*"2=F:6QE;6%N86=E<E]?
M:71E;7,G(#T^("=F:6QE<R!A;F0@9&ER96-T;W)I97,@:6X@)3$G+`H))V9I
M;&5M86YA9V5R7U]C:&1I<E]E<G)O<E]?)R`]/B`B56YA8FQE('1O(&-H86YG
M92!D:7)E8W1O<GD@=&\@)3$Z("4R(BP*"2=F:6QE;6%N86=E<E]?8VAM;V1?
M9&ER)R`]/B`B0VAA;F=E('!E<FUI<W-I;VYS(&9O<B!D:7)E8W1O<GD@)3$B
M+`H))V9I;&5M86YA9V5R7U]C:&UO9%]E<G)O<E]?)R`]/B`B56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N<R!F;W(@9FEL92`E,3H@)3(B+`H))V9I;&5M
M86YA9V5R7U]C:&UO9%]F:6QE)R`]/B`B0VAA;F=E('!E<FUI<W-I;VYS(&9O
M<B!F:6QE("4Q(BP*"2=F:6QE;6%N86=E<E]?8V]P>5]E<G)O<E]?)R`]/B`B
M56YA8FQE('1O(&-O<'D@)3$@=&\@)3(Z("4S(BP*"2=F:6QE;6%N86=E<E]?
M8V]P>5]M;W9E)R`]/B`B0V]P>2`H;6]V92D@9FEL97,@9G)O;2`E,2(L"@DG
M9FEL96UA;F%G97)?7V-O=6YT7W-I>F5?7R<@/3X@)U-E;&5C=&EO;B!S:7IE
M.B`E,2<L"@DG9FEL96UA;F%G97)?7V-O=6YT7W-I>F5?97)R;W)?7R<@/3X@
M)U5N86)L92!T;R!C86QC=6QA=&4@<VEZ92!F;W(@)3$Z("4R)RP*"2=F:6QE
M;6%N86=E<E]?8V]U;G1?<VEZ95]N;W1E)R`]/B`G5&AE('1O=&%L('-I>F4@
M;V8@9FEL97,@86YD('-U8F1I<F5C=&]R:65S+B<L"@DG9FEL96UA;F%G97)?
M7V-R96%T95]D:7(G(#T^(")$:7)E8W1O<GD@8W)E871I;VXB+`H))V9I;&5M
M86YA9V5R7U]C<F5A=&5?9&ER7V5R<F]R7U\G(#T^(")5;F%B;&4@=&\@8W)E
M871E(&1I<F5C=&]R>2`E,3H@)3(B+`H))V9I;&5M86YA9V5R7U]C<F5A=&5?
M9FEL92<@/3X@(D9I;&4@8W)E871I;VXB+`H))V9I;&5M86YA9V5R7U]C<F5A
M=&5?9FEL95]?)R`]/B`B0W)E871E(&9I;&4@)3$B+`H))V9I;&5M86YA9V5R
M7U]C<F5A=&5?9FEL95]E<G)O<E]?)R`]/B`B56YA8FQE('1O(&-R96%T92!F
M:6QE("4Q.B`E,B(L"@DG9FEL96UA;F%G97)?7V-R96%T95]F:6QE7VAT;6PG
M(#T^(")5<V4@:'1M;"!T96UP;&%T92(L"@DG9FEL96UA;F%G97)?7V1E;6\G
M(#T^(")4:&ES(&]P97)A=&EO;B!I<R!N;W0@879A:6QA8FQE(&EN('1H92!D
M96UO('9E<G-I;VXN(BP*"2=F:6QE;6%N86=E<E]?9&5S=&EN871I;VXG(#T^
M(")$97-T:6YA=&EO;B(L"@DG9FEL96UA;F%G97)?7V1I<E]N;W1?97AI<W1S
M)R`]/B`B1&ER96-T;W)Y("4Q(&1O97,@;F]T(&5X:7-T+B(L"@DG9FEL96UA
M;F%G97)?7V1I<FYA;64G(#T^(")$:7)E8W1O<GD@;F%M92(L"@DG9FEL96UA
M;F%G97)?7V9I;&5N86UE)R`]/B`B1FEL92!N86UE(BP*"2=F:6QE;6%N86=E
M<E]?:7-?;F]?<W5C:"<@/3X@(E1H97)E(&ES(&YO(&9I;&4@;W(@9&ER96-T
M;W)Y('=I=&@@;F%M92`E,2(L"@DG9FEL96UA;F%G97)?7V)I;F%R>5]D871A
M7V%C8V5S<R<@/3X@)U1H:7,@9FEL92!M87D@8F4@82!B:6YA<GD@9FEL92X@
M1&\@>6]U('=A;G0@=&\@;W!E;B!I=#\G+`H))V9I;&5M86YA9V5R7U]E9&ET
M)R`]/B`B161I="!F:6QE("4Q(BP*"2=F:6QE;6%N86=E<E]?961I=%]E<G)O
M<E]?)R`]/B`B56YA8FQE('1O(&5D:70@9FEL92`E,3H@)3(B+`H))V9I;&5M
M86YA9V5R7U]E;7!T>5]S96QE8W1I;VXG(#T^(").;R!F:6QE*',I('-E;&5C
M=&5D+B(L"@DG9FEL96UA;F%G97)?7V9I;&5?97AI<W1S)R`]/B`B1FEL92`E
M,2!A;')E861Y(&5X:7-T<RXB+`H))V9I;&5M86YA9V5R7U]M;W9E7V5R<F]R
M7U\G(#T^(")5;F%B;&4@=&\@;6]V92`E,2!T;R`E,CH@)3,B+`H))V9I;&5M
M86YA9V5R7U]N97=?9&ER)R`]/B`B1&ER96-T;W)Y(&YA;64B+`H))V9I;&5M
M86YA9V5R7U]N97=?9&ER7W1I=&QE)R`]/B`B0W)E871E(&YE=R!D:7)E8W1O
M<GD@:6X@)3$B+`H))V9I;&5M86YA9V5R7U]N97=?9FEL95]T:71L92<@/3X@
M(D-R96%T92!N97<@9FEL92!I;B`E,2(L"@DG9FEL96UA;F%G97)?7VYO=%]A
M;&QO=V5D)R`]/B`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C:&%N9V4@<&5R
M;6ES<VEO;G,@9F]R('1H92!F:6QE+B(L"@DG9FEL96UA;F%G97)?7W)?;6]D
M92<@/3X@(E)E860@;6]D92(L"@DG9FEL96UA;F%G97)?7W)?<&5R;5]D:7(G
M(#T^("),:7-T(&1I<F5C=&]R>2(L"@DG9FEL96UA;F%G97)?7W)?<&5R;5]F
M:6QE)R`]/B`B4F5A9"!D871A(BP*"2=F:6QE;6%N86=E<E]?<F5M;W9E)R`]
M/B`B4F5M;W9E(&9I;&5S(&9R;VT@)3$B+`H))V9I;&5M86YA9V5R7U]R96UO
M=F5?97)R;W)?7R<@/3X@(E5N86)L92!T;R!R96UO=F4@9FEL92`E,3H@)3(B
M+`H))V9I;&5M86YA9V5R7U]R96YA;65?9&ER)R`]/B`B4F5N86UE(&1I<F5C
M=&]R>2`E,2(L"@DG9FEL96UA;F%G97)?7W)E;F%M95]E<G)O<E]?)R`]/B`B
M56YA8FQE('1O(')E;F%M92`E,2!T;R`E,CH@)3,B+`H))V9I;&5M86YA9V5R
M7U]R96YA;65?9FEL92<@/3X@(E)E;F%M92!F:6QE("4Q(BP*"2=F:6QE;6%N
M86=E<E]?<V5T7W=I;E]P97)M:7-S:6]N<U]D:7(G(#T^(")3970@<&5R;6ES
M<VEO;G,@9F]R("4Q(&9O;&1E<B(L"@DG9FEL96UA;F%G97)?7W-E=%]W:6Y?
M<&5R;6ES<VEO;G-?9FEL92<@/3X@(E-E="!P97)M:7-S:6]N<R!F;W(@)3$@
M9FEL92(L"@DG9FEL96UA;F%G97)?7W-H;W<G(#T^(")3:&]W(&9I;&4@)3$B
M+`H))V9I;&5M86YA9V5R7U]S:&]W7V5R<F]R7U\G(#T^(")5;F%B;&4@=&\@
M<VAO=R!F:6QE("4Q.B`E,B(L"@DG9FEL96UA;F%G97)?7W-O=7)C92<@/3X@
M(E-O=7)C92(L"@DG9FEL96UA;F%G97)?7W1O=6-H7V-O;F9I<FTG(#T^(")!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@8VAA;F=E('1H92!T:6UE<W1A;7`@
M;V8@=&AE('-E;&5C=&5D(&9I;&5S/R(L"@DG9FEL96UA;F%G97)?7W1O=6-H
M7V5R<F]R7U\G(#T^(")5;F%B;&4@=&\@8VAA;F=E('1H92!T:6UE<W1A;7`@
M9F]R(&9I;&4@)3$Z("4R(BP*"2=F:6QE;6%N86=E<E]?;F]?<&5R;7-?;W)?
M=6YS=7!P;W)T961?9FEL95]T>7!E)R`]/B`G56YA8FQE('1O(')E860@=&AE
M(&9I;&4@;W(@=&AE(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N)RP*
M"2=F:6QE;6%N86=E<E]?=7!L;V%D7V5R<F]R7U\G(#T^(")5;F%B;&4@=&\@
M=7!L;V%D("4Q('1O("4R.B`E,R(L"@DG9FEL96UA;F%G97)?7W5P;&]A9%]F
M:6QE)R`]/B`B57!L;V%D(&9I;&4B+`H))V9I;&5M86YA9V5R7U]U<&QO861?
M9FEL95]S<F,G(#T^(")&:6QE('-O=7)C92(L"@DG9FEL96UA;F%G97)?7W5S
M97)N86UE)R`]/B`B57-E<B(L"@DG9FEL96UA;F%G97)?7W=?;6]D92<@/3X@
M(E=R:71E(&UO9&4B+`H))V9I;&5M86YA9V5R7U]W7W!E<FU?9&ER)R`]/B`B
M0W)E871E(&9I;&5S(BP*"2=F:6QE;6%N86=E<E]?=U]P97)M7V9I;&4G(#T^
M(")7<FET92!D871A(BP*"2=F:6QE;6%N86=E<E]?>%]M;V1E)R`]/B`B17AE
M8W5T92]S96%R8V@@;6]D92(L"@DG9FEL96UA;F%G97)?7WA?<&5R;5]D:7(G
M(#T^(")4<F%V97)S92!D:7)E8W1O<GDB+`H))V9I;&5M86YA9V5R7U]X7W!E
M<FU?9FEL92<@/3X@(D5X96-U=&4@9FEL92(L"@DG9FEL96UA;F%G97)?7W5N
M86)L95]T;U]R97-O;'9E7W)E86QP871H)R`]/B`B56YA8FQE('1O(')E<V]L
M=F4@<&%T:"!T;R!F:6QE("4Q(BP@+R]T;R!C:&5C:PH))V9I;&5M86YA9V5R
M7U]A8V-E<W-?=&]?<F5A;'!A=&A?9&5N:65D)R`]/B`B4&5R;6ES<VEO;B!D
M96YI960@=&\@)3$@+3X@)3(B+"`O+W1O(&-H96-K"@DG9V-H7U]A8W1I;VXG
M(#T^(")!8W1I;VXB+`H))V=C:%]?869T97)?9&5C<F5A<VEN9U]F;W)?=&AE
M7W9A;'5E7VYU;6)E<E]W:6QL7V)E8V%M95]N96=A=&EV92<@/3X@(D%F=&5R
M(&1E8W)E87-I;F<@=&AE('-P96-I9FEE9"!V86QU92P@:70@=VEL;"!B96-O
M;64@;F5G871I=F4N(BP*"2=G8VA?7V-A=&AE9V]R>2<@/3X@(D-A=&5G;W)Y
M(BP*"2=G8VA?7V-L:65N=%]P86=E7W1I=&QE)R`]/B`B1W)O=7`@;W!E<F%T
M:6]N<R!O;B!C;&EE;G0@86-C;W5N=',B+`H))V=C:%]?8VQI96YT<U]S96QE
M8W1I;VXG(#T^(")-;V1I9FEE9"!A8V-O=6YT<R`H)3$I(BP*"2=G8VA?7V1O
M;6%I;E]P86=E7W1I=&QE)R`]/B`B1W)O=7`@;W!E<F%T:6]N<R!O;B!D;VUA
M:6YS(BP*"2=G8VA?7V1O;6%I;G-?<V5L96-T:6]N)R`]/B`B36]D:69I960@
M9&]M86EN<R`H)3$I(BP*"2=G8VA?7VUA:6QN86UE<U]S96QE8W1I;VXG(#T^
M(")-;V1I9FEE9"!M86EL(&YA;65S("@E,2DB+`H))V=C:%]?:&]S=&EN9R<@
M/3X@(DAO<W1I;F<B+`H))V=C:%]?:&]S=&EN9U]A<&%C:&5?97)R;W)?9&]C
M<R<@/3X@(D-U<W1O;2!E<G)O<B!D;V-U;65N=',B+`H))V=C:%]?:&]S=&EN
M9U]C9VDG(#T^(")#1TD@<W5P<&]R="(L"@DG9V-H7U]H;W-T:6YG7VQO9U]R
M;W1A=&EO;B<@/3X@(DQO9R!R;W1A=&EO;B!S=&%T=7,B+`H))V=C:%]?:&]S
M=&EN9U]L;V=?<F]T871I;VY?8V]M<')E<W,G(#T^("),;V<@9FEL97,@8V]M
M<')E<W-I;VXB+`H))V=C:%]?:&]S=&EN9U]L;V=?<F]T871I;VY?;6%I;'1O
M)R`]/B`B1&5L:79E<B!P<F]C97-S960@;&]G(&9I;&5S('1O(BP*"2=G8VA?
M7VAO<W1I;F=?;&]G7W)O=&%T:6]N7VUA>%]F:6QE<R<@/3X@(DYU;6)E<B!O
M9B!L;V<@9FEL92!I;G-T86YC97,B+`H))V=C:%]?:&]S=&EN9U]L;V=?<F]T
M871I;VY?<&5R:6]D)R`]/B`B3&]G(')O=&%T:6]N(&-O;F1I=&EO;B(L"@DG
M9V-H7U]H;W-T:6YG7VQO9U]R;W1A=&EO;E]T:71L92<@/3X@(DQO9R!R;W1A
M=&EO;B(L"@DG9V-H7U]H;W-T:6YG7W!D:7)?<&QE<VM?<W1A="<@/3X@(E!R
M;W1E8W0@9&ER96-T;W)Y("<O<&QE<VLM<W1A="\G(BP*"2=G8VA?7VAO<W1I
M;F=?<&AP)R`]/B`B4$A0('-U<'!O<G0B+`H))V=C:%]?:&]S=&EN9U]S:&5L
M;"<@/3X@(E-H96QL(&%C8V5S<R(L"@DG9V-H7U]H;W-T:6YG7W-S:2<@/3X@
M(E-322!S=7!P;W)T(BP*"2=G8VA?7VAO<W1I;F=?<W-L)R`]/B`B4U-,('-U
M<'!O<G0B+`H))V=C:%]?:&]S=&EN9U]T>7!E)R`]/B`B2&]S=&EN9R(L"@DG
M9V-H7U]H;W-T:6YG7W=E8G-T870G(#T^(")796(@<W1A=&ES=&EC<R(L"@DG
M9V-H7U]I;G9A;&ED7V1A=&5?=F%L=64G(#T^("));F-O<G)E8W0@9&%T92!V
M86QU92XB+`H))V=C:%]?:6YV86QI9%]L;V=R;W1A=&5?<&%R86US)R`]/B`B
M3&]G(')O=&%T:6]N(&-O;F9I9R!I<R!N;W0@>65T(&-R96%T960@9F]R('1H
M:7,@9&]M86EN+"!T;R!C<F5A=&4@:70@>6]U(&YE960@=&\@9FEL;"!O=70@
M86QL('1H92!F:65L9',@97AC97!T(&9O<B`E,2XB+`H))V=C:%]?:71?:7-?
M:6UP;W-S:6)L95]T;U]D96-R96%S95]N=6UB97)?;6]R95]T:&%N7S$P,%]P
M97)C96YT<R<@/3X@(E5N86)L92!T;R!D96-R96%S92!T:&4@;G5M8F5R(&)Y
M(&UO<F4@=&AA;B`Q,#`E+B(L"@DG9V-H7U]I=%]I<U]I;7!O<W-I8FQE7W1O
M7VEN8W)E87-E7V]R7V1E8W)E87-E7W5N;&EM:71E9%]V86QU92<@/3X@(E5N
M86)L92!T;R!I;F-R96%S92!O<B!D96-R96%S92!T:&4@=F%L=64@+2!I="!I
M<R!U;FQI;6ET960N(BP*"2=G8VA?7VQI;5]D:7-K7W-P86-E)R`]/B`B3&EM
M:70@=&]T86P@9&ES:R!S<&%C92(L"@DG9V-H7U]L:6U?97AP:7)A=&EO;B<@
M/3X@(DQI;6ET('1H92!V86QI9&ET>2!P97)I;V0B+`H))V=C:%]?;&EM7VUA
M>%]B;W@G(#T^("),:6UI="!T:&4@;G5M8F5R(&]F(&UA:6QB;WAE<R(L"@DG
M9V-H7U]L:6U?;6%X7V1B)R`]/B`B3&EM:70@=&AE(&YU;6)E<B!O9B!D871A
M8F%S97,B+`H))V=C:%]?;&EM7VUA>%]D;VTG(#T^("),:6UI="!T:&4@;G5M
M8F5R(&]F(&1O;6%I;G,B+`H))V=C:%]?;&EM7VUA>%]M86EL;&ES=',G(#T^
M("),:6UI="!T:&4@;G5M8F5R(&]F(&UA:6QI;F<@;&ES=',B+`H))V=C:%]?
M;&EM7VUA>%]M9R<@/3X@(DQI;6ET('1H92!N=6UB97(@;V8@;6%I;"!G<F]U
M<',B+`H))V=C:%]?;&EM7VUA>%]R961I<B<@/3X@(DQI;6ET('1H92!N=6UB
M97(@;V8@;6%I;"!R961I<F5C=',B+`H))V=C:%]?;&EM7VUA>%]R97-P)R`]
M/B`B3&EM:70@=&AE(&YU;6)E<B!O9B!M86EL(&%U=&]R97-P;VYD97)S(BP*
M"2=G8VA?7VQI;5]M87A?<W5B9&]M)R`]/B`B3&EM:70@=&AE(&YU;6)E<B!O
M9B!S=6)D;VUA:6YS(BP*"2=G8VA?7VQI;5]M87A?=')A9F9I8R<@/3X@(DQI
M;6ET('1O=&%L(&%M;W5N="!O9B!T<F%F9FEC(BP*"2=G8VA?7VQI;5]M87A?
M=V5B87!P<R<@/3X@(DQI;6ET('1H92!N=6UB97(@;V8@2F%V82!A<'!L:6-A
M=&EO;G,B+`H))V=C:%]?;&EM7VUA>%]W=2<@/3X@(DQI;6ET('1H92!N=6UB
M97(@;V8@=V5B('5S97)S(BP*"2=G8VA?7VQI;5]M8F]X7W%U;W1A)R`]/B`B
M4V5T('1H92!M86EL8F]X('%U;W1A(BP*"2=G8VA?7VQI;5]T>7!E)R`]/B`B
M3&EM:70B+`H))V=C:%]?;&EM:71?;75S=%]B95]I;G1E9V5R7W!O<VET:79E
M7VYU;6)E<B<@/3X@(E1H92!L:6UI="!V86QU92!M=7-T(&)E(&$@<&]S:71I
M=F4@:6YT96=E<BXB+`H))V=C:%]?;F5W7VQI;6ET7W9A;'5E7V)E='=E96Y?
M>F5R;U]A;F1?:V)Y=&4G(#T^(")4:&4@;F5W(&QI;6ET('9A;'5E(&-A;B!B
M92!E:71H97(@,"P@,2!+:6QO8GET92!O<B!G<F5A=&5R+B(L"@DG9V-H7U]N
M97=?;&EM:71?=F%L=65?8F5T=V5E;E]Z97)O7V%N9%]M8GET92<@/3X@(E1H
M92!N97<@;&EM:70@=F%L=64@8V%N(&)E(&5I=&AE<B`P+"`Q($UE9V%B>71E
M(&]R(&=R96%T97(N(BP*"2=G8VA?7VQI;6ET7W9A;'5E7VES7V]U=%]O9E]R
M86YG92<@/3X@(E1H92!L:6UI="!V86QU92!S<&5C:69I960@97AC965D<R!T
M:&4@<F%N9V4@;V8@86QL;W=A8FQE('9A;'5E<RXB+`H))V=C:%]?;&EM:71S
M)R`]/B`B3&EM:71S(BP*"2=G8VA?7VUA:6QN86UE7W!A9V5?=&ET;&4G(#T^
M("='<F]U<"!O<&5R871I;VYS(&]N(&UA:6P@;F%M97,G+`H))V=C:%]?;6Y?
M;F]?875T;W)E<W!O;F1E<B<@/3X@)U1H97)E(&%R92!N;R!A=71O<F5S<&]N
M9&5R<R!S970M=7`@9F]R('1H92!M86EL(&YA;64N)RP*"2=G8VA?7VYE=U]C
M;&EE;G1?;&EM:71?:7-?;&5S<U]T:&%N7V1O;6%I;E]L:6UI=',G(#T^(")4
M:&4@<W!E8VEF:65D(&QI;6ET('9A;'5E(&ES(&QE<W,@=&AA;B!T:&4@=&]T
M86P@;V8@86QL(&QI;6ET<R!D969I;F5D(&9O<B!T:&ES(&-L:65N="=S(&1O
M;6%I;G,B+`H))V=C:%]?;F5W7VQI;6ET7W9A;'5E7W=I;&Q?8F5C86UE7V]U
M=%]O9E]R86YG92<@/3X@(D-H86YG:6YG('1H92!V86QU92!T;R!T:&4@;&5V
M96P@<W!E8VEF:65D('=I;&P@<F5S=6QT(&EN(&5X8V5E9&EN9R!T:&4@;6%X
M:6UU;2!A;&QO=V%B;&4@9&EG:70@=F%L=64N(BP*"2=G8VA?7VYO7V-L:65N
M='-?<V5L96-T960G(#T^(").;R!C;&EE;G0@86-C;W5N=',@<V5L96-T960B
M+`H))V=C:%]?;F]?9&]M86EN<U]S96QE8W1E9"<@/3X@(DYO(&1O;6%I;G,@
M<V5L96-T960B+`H))V=C:%]?;F]?;6%I;&YA;65S7W-E;&5C=&5D)R`]/B`G
M3F\@;6%I;"!N86UE<R!S96QE8W1E9"<L"@DG9V-H7U]P87)A;65T<B<@/3X@
M(E!A<F%M971E<B(L"@DG9V-H7U]P97)M7V-H86YG95]L:6UI=',G(#T^(")!
M8FEL:71Y('1O(&UO9&EF>2!D;VUA:6X@;&EM:71S(BP*"2=G8VA?7W!E<FU?
M8W)E871E7V1O;6%I;G,G(#T^(")!8FEL:71Y('1O(&-R96%T92!D;VUA:6YS
M(BP*"2=G8VA?7W!E<FU?='EP92<@/3X@(E!E<FUI<W-I;VXB+`H))V=C:%]?
M<&5R;6ES<VEO;G,G(#T^(")097)M:7-S:6]N<R(L"@DG9V-H7U]P<F5F7V%L
M;&]W7W-C<FEP=&EN9R<@/3X@(D%L;&]W('1H92!W96(@=7-E<G,@<V-R:7!T
M:6YG(BP*"2=G8VA?7W!R969?9&5L971E7W-T871I<W1I8R<@/3X@(E)E=&%I
M;B!T<F%F9FEC('-T871I<W1I8W,@9F]R(BP*"2=G8VA?7W!R969?;6%I;&UA
M;E]N;W1?:6YS=&%L;&5D7V]R7V-O;F8G(#T^(")-86EL;6%N(%-E<G9E<B!%
M>'1E;G-I;VYS(&%R92!N;W0@8W5R<F5N=&QY(&EN<W1A;&QE9"!O<B!P<F]P
M97)L>2!C;VYF:6=U<F5D(&]N('1H92!S97)V97(N(BP*"2=G8VA?7W!R969?
M;F]N97AI<W0G(#T^(")-86EL('1O(&YO;F5X:7-T96YT('5S97(B+`H))V=C
M:%]?<')E9E]T>7!E)R`]/B`B4')E9F5R96YC92(L"@DG9V-H7U]P<F5F7W=E
M8E]M86EL)R`]/B`B5V5B36%I;"(L"@DG9V-H7U]P<F5F7W=W=U]P<F5F:7@G
M(#T^(")75U<@<')E9FEX(BP*"2=G8VA?7W!R969E<F5N8V5S)R`]/B`B4')E
M9F5R96YC97,B+`H))V=C:%]?<F5J96-T:6]N)R`]/B`B4F5J96-T:6]N(')E
M87-O;B(L"@DG9V-H7U]S97)V7V%N;VYY;6]U<U]F='`G(#T^(")!;F]N>6UO
M=7,@1E10(BP*"2=G8VA?7W-E<G9?9&YS)R`]/B`B1$Y3('IO;F4B+`H))V=C
M:%]?<V5R=E]M86EL)R`]/B`B36%I;"(L"@DG9V-H7U]S97)V7VUA:6QL:7-T
M<R<@/3X@(DUA:6QI;F<@;&ES=',B+`H))V=C:%]?<V5R=E]T;VUC870G(#T^
M(")4;VUC870B+`H))V=C:%]?<V5R=E]T>7!E)R`]/B`B4V5R=FEC92(L"@DG
M9V-H7U]S97)V:6-E<R<@/3X@(E-E<G9I8V5S(BP*"2=G8VA?7W)E:F5C=%]L
M96=E;F0G(#T^(")4:&4@9W)O=7`@;W!E<F%T:6]N<R!H879E(&)E96X@<W5C
M8V5S<V9U;&QY('!E<F9O<FUE9"P@97AC97!T(&9O<B!T:&4@9F]L;&]W:6YG
M(&]B:F5C=',Z(BP*"2=G8VA?7W9A;'5E)R`]/B`B5F%L=64B+`H))V=C:%]?
M=F%L=65?;75S=%]B95]I;G1E9V5R7W!O<VET:79E7VYU;6)E<B<@/3X@(E1H
M92!V86QU92!M=7-T(&)E(&$@<&]S:71I=F4@:6YT96=E<BXB+`H))V=E=%]P
M87-S=V]R9%]?861M:6Y?<&%S<W=O<F0G(#T^(")4:&4@861M:6YI<W1R871O
M<B=S('!A<W-W;W)D(&-A;FYO="!B92!S96YT(&)Y(&4M;6%I;"!F;W(@<V5C
M=7)I='D@<F5A<V]N<RX@66]U(&-A;B!L;V]K(&ET('5P(&EN('1H92`O971C
M+W!S82\N<'-A+G-H861O=R!F:6QE(&QO8V%T960@;VX@>6]U<B!0;&5S:R!H
M;W-T+"!O;F-E('EO=2!A<F4@;&]G9V5D(&]N(&%S('5S97(@<F]O="XB+`H)
M)V=E=%]P87-S=V]R9%]?96YC<GEP=&5D7W!A<W-W;W)D)R`]/B`B56YA8FQE
M('1O('-E;F0@=&AE('!A<W-W;W)D(&EN9F]R;6%T:6]N.B!T:&4@<&%S<W=O
M<F0@:7,@<W1O<F5D(&5N8W)Y<'1E9"XB+`H))V=E=%]P87-S=V]R9%]?:6YV
M86QI9%]L;V=I;E]O<E]E;6%I;"<@/3X@(DED96YT:69I8V%T:6]N(&9A:6QE
M9#H@:6YV86QI9"!L;V=I;B!O<B!E+6UA:6P@861D<F5S<R!S<&5C:69I960N
M(%!L96%S92P@=')Y(&%G86EN+B(L"@DG9V5T7W!A<W-W;W)D7U]L86)E;"<@
M/3X@(D=E="!P87-S=V]R9"(L"@DG9V5T7W!A<W-W;W)D7U]M86EL7V5R<F]R
M)R`]/B`B06X@97)R;W(@;V-C=7)E9"!W:&EL92!A='1E;7!T:6YG('1O('-E
M;F0@=&AE('!A<W-W;W)D('1O(&4M;6%I;"`E,3H@)3(B+`H))V=E=%]P87-S
M=V]R9%]?;6%I;%]O:R<@/3X@(E1H92!P87-S=V]R9"!H87,@8F5E;B!S=6-C
M97-S9G5L;'D@<V5N="!T;R!E+6UA:6PZ("4Q+B(L"@DG9V5T7W!A<W-W;W)D
M7U]M97-S86=E)R`]/B`B66]U<B!L;V=I;B!N86UE(&9O<B!A8V-E<W-I;F<@
M=&AE('-Y<W1E;3H@)3%<;EEO=7(@<&%S<W=O<F0@:7,@)3(B+`H))V=E=%]P
M87-S=V]R9%]?<W5B:F5C="<@/3X@(E!A<W-W;W)D(&9O<B!A8V-E<W,@=&\@
M<WES=&5M(BP*"2=G971?<&%S<W=O<F1?7W=A<FYI;F<G(#T^("(\8CY!='1E
M;G1I;VXA(2$\+V(^/&)R/EQN4V5N9&EN9R!P87-S=V]R9"!B>2!E+6UA:6P@
M:7,@:6YS96-U<F4A/&)R/EQN16YT97(@>6]U<B!L;V=I;B!N86UE(&%N9"!E
M+6UA:6P@<F5G:7-T97)E9"!I;B!T:&4@<WES=&5M(&9O<B!P87-S=V]R9"!D
M96QI=F5R>2XB+`H))V=R;W5P<U]?879A:6QA8FQE)R`]/B`B079A:6QA8FQE
M(&UA:6P@9W)O=7!S(BP*"2=G<F]U<'-?7V=R;W5P<U]F;W)?;6%I;&YA;64G
M(#T^(")-86EL(&=R;W5P<R!F;W(@=&AE(&UA:6P@;F%M92`E,2(L"@DG9W)O
M=7!S7U]M96UB97)?;V8G(#T^(")-96UB97(@;V8@=&AE(&9O;&QO=VEN9R!M
M86EL(&=R;W5P<R(L"@DG:&5L<%]?:&5L<%]A<F5A)R`]/B`B2&5L<"!A<F5A
M+B(L"@DG:'-T7V1E9E]?875T:%]D:7-A8FQE9"<@/3X@(F1I<V%B;&5D(BP*
M"2=H<W1?9&5F7U]A=71H7V5N86)L960G(#T^(")E;F%B;&5D(BP*"2=H<W1?
M9&5F7U]C:&%N9V5?8W5R<E]D;G-?:7`G(#T^(")4:&4@8W5R<F5N="!)4"!A
M9&1R97-S(&]F('1H92!!($1.4R!R96-O<F0@=VEL;"!B92!C:&%N9V5D(BP*
M"2=H<W1?9&5F7U]C<E]H;W-T:6YG7VEP7V1N<U]I<%]N;W1?97%U:78G(#T^
M(").;VYE(&]F('1H92!)4"!A9&1R97-S97,@;V8@=&AE($$@1$Y3(')E8V]R
M9"!M871C:"!W:71H($E0(&%D9')E<W,@87-S:6=N960@=&\@=&AE(&AO<W1I
M;F<@86-C;W5N="!B96EN9R!C<F5A=&5D(BP*"2=H<W1?9&5F7U]D97-T7W5R
M;"<@/3X@(D1E<W1I;F%T:6]N(%523"(L"@DG:'-T7V1E9E]?9&ES:U]Q=6]T
M82<@/3X@(D1I<VL@<75O=&$B+`H))VAS=%]D969?7V1I<VM?<W!A8V5?;&EM
M:71?97AC965D7VEN8V]M:6YG7W%U;W1A)R`]/B`B5&AE(&1I<VL@<W!A8V4@
M;&EM:70@>6]U(&%R92!T<GEI;F<@=&\@<V5T(&ES(&5X8V5E9&5D(&)Y('1H
M92!D:7-K('-P86-E(&QI;6ET(&EN('1H92!A;F]N>6UO=7,@1E10(&EN8V]M
M:6YG(&1I<F5C=&]R>2X@5&AE(&1I<VL@<W!A8V4@;&EM:70@:6X@=&AE(&%N
M;VYY;6]U<R!&5%`@:6YC;VUI;F<@9&ER96-T;W)Y(&UU<W0@;F]T(&5X8V5E
M9"!T:&4@9&]M86EN(&1I<VL@<W!A8V4@;&EM:70N(BP*"2=H<W1?9&5F7U]F
M<%]A9&UI;E]L;V=I;B<@/3X@(D9R;VYT4&%G92!!9&UI;FES=')A=&]R)W,@
M3&]G:6XB+`H))VAS=%]D969?7V9P7V%D;6EN7VQO9VEN7VES7VEN=F%L:60G
M(#T^(")&<F]N=%!A9V4@061M:6YI<W1R871O<B=S($QO9VEN(&ES(&EN=F%L
M:60N(BP*"2=H<W1?9&5F7U]F<%]A9&UI;E]P87-S=V0G(#T^(")&<F]N=%!A
M9V4@061M:6XG<R!087-S=V]R9"(L"@DG:'-T7V1E9E]?9G!?97AT96YT:6]N
M7W-U<'!O<G0G(#T^(")&<F]N=%!A9V4@97AT96YS:6]N<R!S=7!P;W)T+B(L
M"@DG:'-T7V1E9E]?9G)A;65?9F]R=V%R9&EN9U]D969I;FET:6]N)R`]/B`B
M1G)A;64@9F]R=V%R9&EN9R!A<W-I9VYM96YT(&9O<B!D;VUA:6X@)3$B+`H)
M)VAS=%]D969?7V9T<'5S97)?9F]R7VAS=%]N;W1?97AI<W1?:6Y?<WES=&5M
M)R`]/B`B5T%23DE.1RX@1E10('5S97(@)3$@:7,@=7-E9"!I;B!A(&AO<W1I
M;F<@86-C;W5N="!B=70@9&]E<R!N;W0@97AI<W0@:6X@=&AE('-Y<W1E;2XB
M+`H))VAS=%]D969?7VAS=%]T>7!E7VES7VYO=%]D969I;F5D)R`]/B`B2&]S
M=&EN9R!T>7!E(&ES(&YO="!D969I;F5D(BP*"2=H<W1?9&5F7U]I<%]B87-E
M9"<@/3X@(DE0+6)A<V5D(BP*"2=H<W1?9&5F7U]N86UE7V)A<V5D7W!O=V5R
M7V%N;VYY;6]U<U]F='!?9&]W;B<@/3X@(E1R86YS9F5R<FEN9R!Y;W5R(&AO
M<W1I;F<@86-C;W5N="!T;R!S:&%R960@:7`@861D<F5S<R!W:6QL(&1I<V%B
M;&4@>6]U<B!A;F]N>6UO=7,@1E10(&1O;6%I;BX@4')O8V5E9"!A;GEW87D_
M(BP*"2=H<W1?9&5F7U]P87-S=V]R9%]I<U]I;G9A;&ED7W!A<W-W;W)D7W-Y
M;G1A>"<@/3X@(E!A<W-W;W)D(&ES(&EN=F%L:60N7&Y$;R!N;W0@=7-E('-I
M;F=L92!Q=6]T92!A;F0@;F%T:6]N86P@86QP:&%B970@8VAA<F%C=&5R<R!I
M;B!A('!A<W-W;W)D+EQN5&AE('!A<W-W;W)D(&QE;F=T:"!S:&]U;&0@8F4@
M9G)O;2`U('1O(#$T(&-H87)A8W1E<G,N(%1H92!P87-S=V]R9"!S:&]U;&0@
M;F]T(&-O;G1A:6X@=&AE('5S97(@;F%M92XB+`H))VAS=%]D969?7W-H96QL
M)R`]/B`B4VAE;&P@86-C97-S('1O('-E<G9E<B!W:71H($944"!U<V5R)W,@
M8W)E9&5N=&EA;',B+`H))VAS=%]D969?7W-T86YD87)D7V9O<G=A<F1I;F=?
M9&5F:6YI=&EO;B<@/3X@(E-T86YD87)D(&9O<G=A<F1I;F<@87-S:6=N;65N
M="!F;W(@9&]M86EN("4Q(BP*"2=H<W1?9&5F7U]T:71L95]N86UE7V)A<V5D
M)R`]/B`B3F%M92UB87-E9"(L"@DG:'-T7V1E9E]?=6YA8FQE7V-R96%T92]U
M<&1A=&5?<&AY<VEC7VAS="<@/3X@(E5N86)L92!T;R!C<F5A=&4O=7!D871E
M('!H>7-I8V%L(&AO<W1I;F<Z("4Q(BP*"2=H<W1?9&5F7U]U;F%B;&5?8W)E
M871E+W5P9&%T95]S=&1?9G=D)R`]/B`B56YA8FQE('1O(&-R96%T92]U<&1A
M=&4@<W1A;F1A<F0@9F]R=V%R9&EN9SH@)3$B+`H))VAS=%]D969?7W5N86)L
M95]C<F5A=&5?9F]R=V%R9&EN9U]M>7-E;&8G(#T^(")5;F%B;&4@=&\@8W)E
M871E(&9O<G=A<F1I;F<@=&\@=&AE(&1O;6%I;B!I='-E;&8N(BP*"2=H<W1?
M9&5F7U]U;F%B;&5?='5R;E]S<VQ?;V9F7W=H:6QE7V9P7W-S;%]O;B<@/3X@
M(E5N86)L92!T;R!T=7)N(&]F9B!34TP@<W5P<&]R=#H@1G)O;G1086=E(&]V
M97(@4U-,('-U<'!O<G0@:7,@96YA8FQE9"XB+`H))VAS=%]D969?7W5N86)L
M95]T=7)N7V9P7W-S;"<@/3X@(E5N86)L92!T;R!T=7)N(&]N($9R;VYT4&%G
M92!O=F5R(%-33"!S=7!P;W)T.B!34TP@<W5P<&]R="!I<R!D:7-A8FQE9"XB
M+`H))VAS=%]D969?7W5N86)L95]T=7)N7V]N7W-S;%]C97)T7VYO=%]D969I
M;F5D)R`]/B`B56YA8FQE('1O('1U<FX@;VX@4U-,('-U<'!O<G0Z(&YO(%-3
M3"!C97)T:69I8V%T92!I;G-T86QL960B+`H))VAS=%]D969?7W5R;%]I<U]I
M;G9A;&ED)R`]/B`B55),(&ES(&EN=F%L:60N(BP*"2=H<W1?9&5F7U]V:7)T
M=6%L7VAO<W1?86-C97-S)R`]/B`B5FER='5A;"!H;W-T(&%C8V5S<R!F;W(@
M9&]M86EN("4Q(BP*"2=H<W1?9&5F7U]V:7)T=6%L7VAO<W1?=7-E<U]N;VY?
M97AI<W1E9%]I<%]A9&1R97-S)R`]/B`B5T%23DE.1RX@5&AI<R!V:7)T=6%L
M(&AO<W0@:7,@=7-I;F<@82!N;VYE>&ES=&5N="!)4"!A9&1R97-S(&9O<B!H
M;W-T:6YG+B(L"@DG:'-T7V1E9E]?>6]U7VAA=F5?;F]?:7!S)R`]/B`B66]U
M(&AA=F4@;F\@:7`@861D<F5S<V5S(&%V86EL86)L92!A;F0@>6]U(&%R92!N
M;W0@86QL;W=E9"!T;R!C<F5A=&4@3F%M92UB87-E9"!H;W-T:6YG+B(L"@DG
M:'-T7V1E9E]?>6]U7W1U<FYE9%]O9F9?9G!?<W-L7W-U<'!O<G1?86QL7V9P
M7W-E='1I;F=S7W=I;&Q?8F5?9&5S=')O>65D7V]K/R<@/3X@(EEO=2!H879E
M('1U<FYE9"!O9F8@=&AE($9R;VYT4&%G92!O=F5R(%-33"!S=7!P;W)T+B!!
M;&P@1G)O;G1086=E('-E='1I;F=S('=I;&P@8F4@9&ES8V%R9&5D+B!$;R!Y
M;W4@=V%N="!T;R!P<F]C965D/R(L"@DG:'-T7V1E9E]?>6]U7W1U<FYE9%]O
M9F9?9G!?<W5P<&]R=%]A;&Q?9G!?<V5T=&EN9W-?=VEL;%]B95]D97-T<F]Y
M961?;VL_)R`]/B`B66]U(&AA=F4@='5R;F5D(&]F9B!T:&4@1G)O;G1086=E
M('-U<'!O<G0N($%L;"!&<F]N=%!A9V4@<V5T=&EN9W,@=VEL;"!B92!D:7-C
M87)D960N($1O('EO=2!W86YT('1O('!R;V-E960_(BP*"2=H<W1?<V5L7U]H
M96%D97(G(#T^("`@(E1O(&AO<W0@82!W96(@<VET92!O;B!T:&ES(&UA8VAI
M;F4L('-E;&5C="!T:&4@4&AY<VEC86P@:&]S=&EN9R!O<'1I;VXN(%5P;VX@
M8V]M<&QE=&EO;B!O9B!T:&ES('!R;V-E9'5R92P@>6]U<B!C;VYT<F]L('!A
M;F5L('=I;&P@<V5T('5P('1H92!D;VUA:6X@;F%M92!S97)V97(@;VX@=&AI
M<R!M86-H:6YE('1O('-E<G9E('1H92!N97<@9&]M86EN(&YA;64@86YD('!R
M97!A<F4@=&AE('=E8B!S97)V97(@=&\@<V5R=F4@=&AE(&YE=R!W96(@<VET
M93H@82!N97<@>F]N92!F:6QE('=I=&@@87!P<F]P<FEA=&4@<F5S;W5R8V4@
M<F5C;W)D<R!W:6QL(&)E(&%D9&5D('1O('1H92!D;VUA:6X@;F%M92!S97)V
M97(G<R!C;VYF:6=U<F%T:6]N(&9I;&5S+"!A('=E8B!S<&%C92!W:6QL(&)E
M(&-R96%T960@:6YS:61E('1H92!W96(@<V5R=F5R)W,@9&ER96-T;W)Y+"!A
M;F0@;F5C97-S87)Y('5S97(@86-C;W5N=',@=VEL;"!B92!C<F5A=&5D(&]N
M('1H92!S97)V97(N7&Y.;W1E.B!)9B!T:&4@<VET92!I<R!H;W-T960@;VX@
M86YO=&AE<B!M86-H:6YE+"!A;F0@>6]U('=I<V@@=&\@<V5T('5P('EO=7(@
M8V]N=')O;"!P86YE;"=S($1.4R!S97)V97(@;VYL>2!T;R!S97)V92!T:&4@
M1$Y3('IO;F4@9F]R('1H870@<VET92P@<V5L96-T(&5I=&AE<B!&<F%M92!F
M;W)W87)D:6YG(&]R(%-T86YD87)D(&9O<G=A<F1I;F<@;W!T:6]N+B!7:71H
M('-T86YD87)D(&9O<G=A<F1I;F<L(&$@=7-E<B!I<R!R961I<F5C=&5D('1O
M('1H92!S:71E(&%N9"!T:&4@86-T=6%L('-I=&4G<R!54DP@:7,@<VAO=VX@
M:6X@=&AE('5S97(G<R!B<F]W<V5R+"!S;R!T:&4@=7-E<B!A;'=A>7,@:VYO
M=W,@=&AA="!H92!O<B!S:&4@:7,@<F5D:7)E8W1E9"!T;R!A;F]T:&5R(%52
M3"X@5VET:"!F<F%M92!F;W)W87)D:6YG+"!A('5S97(@:7,@<F5D:7)E8W1E
M9"!T;R!T:&4@<VET92!W:71H;W5T(&MN;W=I;F<@=&AA="!T:&4@<VET92!A
M8W1U86QL>2!R97-I9&5S(&%T(&%N;W1H97(@;&]C871I;VXN(BP*"2=H<W1?
M<V5L7U]P:'ES:6-A;%]H<W0G"3T^(")0:'ES:6-A;"!H;W-T:6YG(BP*"2=H
M<W1?<V5L7U]S96QE8W1?:'-T7W1Y<&4G(#T^(")396QE8W0@=&AE('1Y<&4@
M;V8@:&]S=&EN9R!F;W(@=&AE(&1O;6%I;B(L"@DG:'-T7W-E;%]?<V5L96-T
M7VAS=%]T>7!E7W=A<FYI;F<G(#T^(")396QE8W0@=&AE('1Y<&4@;V8@:&]S
M=&EN9R!F;W(@=&AE(&1O;6%I;B$B+`H))VAS=%]S96Q?7W-T86YD87)D7V9R
M=R<)/3X@(E-T86YD87)D(&9O<G=A<F1I;F<B+`H))VAS=%]S96Q?7V9R86UE
M7V9R=R<)/3X@(D9R86UE(&9O<G=A<F1I;F<B+`H))U]?8VAO;W-E7VAS=%]T
M>7!E)R`]/B`B4V5L96-T('1H92!R97%U:7)E9"!H;W-T:6YG('1Y<&4N(BP*
M"2=?7V9R86UE7V9R=R<@/3X@(D9R86UE(&9O<G=A<F1I;F<B+`H))U]?:&]S
M=&EN9U]E>&ES=',G(#T^(")5;F%B;&4@=&\@8W)E871E(&AO<W1I;F<L(&%S
M(&ET(&ES(&%L<F5A9'D@8V]N9FEG=7)E9"!F;W(@=&AI<R!D;VUA:6XN(%EO
M=2!W:6QL(&)E(')E9&ER96-T960@=&\@=&AE(&AO<W1I;F<@;6%N86=E;65N
M="!P86=E+B(L"@DG7U]N;U]H<W1?8V]N9B<@/3X@(E1H97)E(&ES(&YO(&AO
M<W1I;F<@8V]N9FEG=7)E9"!F;W(@>6]U<B!D;VUA:6XN(BP*"2=?7W!H>7-I
M8V%L7VAS="<@/3X@(E!H>7-I8V%L(&AO<W1I;F<B+`H))U]?<V5L96-T7VAS
M=%]T>7!E)R`]/B`B4V5L96-T('1H92!T>7!E(&]F(&AO<W1I;F<@9F]R('1H
M92!D;VUA:6XB+`H))U]?<W1A;F1A<F1?9G)W)R`]/B`B4W1A;F1A<F0@9F]R
M=V%R9&EN9R(L"@DG7U]W87)N:6YG)R`]/B`B5V%R;FEN9R$@06QL(&]F('1H
M92!P<F5V:6]U<VQY('-E="!P87)A;65T97)S('=I;&P@8F4@9&ES8V%R9&5D
M+B!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@8VAA;F=E('1H92!H;W-T:6YG
M('1Y<&4_(BP*"2=I7V-L7R$G(#T^(")297-O=7)C92!U<V%G92!O9B!T:&4@
M8VQI96YT(&ES(&5X8V5E9&EN9R!L:6UI=',N(BP*"2=I7V-L7V]F9B<@/3X@
M(D-L:65N="!I<R!I;F%C=&EV92XB+`H))VE?8VQ?;V9F7V)Y7V%D;6EN)R`]
M/B`B0VQI96YT(&%C8V]U;G0@:7,@9&ES86)L960@8GD@861M:6YI<W1R871O
M<BXB+`H))VE?8VQ?;V9F7V5X<&ER960G(#T^(")#;&EE;G0@86-C;W5N="!I
M<R!E>'!I<F5D+B(L"@DG:5]C;%]O:R<@/3X@(E)E<V]U<F-E('5S86=E(&]F
M('1H92!C;&EE;G0@:7,@=VET:&EN(&QI;6ET<RXB+`H))VE?8VQ?;VXG(#T^
M(")#;&EE;G0@:7,@86-T:79E+B(L"@DG:5]D;VU?(2<@/3X@(D1I<VL@<W!A
M8V4@86YD+V]R('1R869F:6,@;&EM:71S(&%R92!E>&-E961E9"!I;B!T:&4@
M9&]M86EN+B(L"@DG:5]D;VU?;V9F)R`]/B`B1&]M86EN(&ES(&EN86-T:79E
M+B(L"@DG:5]D;VU?;V9F7V)A8VMU<%]R97-T;W)E)R`]/B`B1&]M86EN(&ES
M('1E;7!O<F%R:6QY(&1I<V%B;&5D(&9O<B!B86-K=7`O<F5S=&]R:6YG+B(L
M"@DG:5]D;VU?;V9F7V)Y7V%D;6EN)R`]/B`B1&]M86EN(&ES(&1I<V%B;&5D
M(&)Y(&%D;6EN:7-T<F%T;W(B+`H))VE?9&]M7V]F9E]B>5]C;&EE;G0G(#T^
M(")$;VUA:6X@:7,@9&ES86)L960@8GD@8VQI96YT(BP*"2=I7V1O;5]O9F9?
M8GE?<F5S96QL97(G(#T^(")$;VUA:6X@:7,@9&ES86)L960@8GD@<F5S96QL
M97(B+`H))VE?9&]M7V]F9E]E>'!I<F5D)R`]/B`B1&]M86EN(&ES(&5X<&ER
M960B+`H))VE?9&]M7V]F9E]W:71H7W!A<F5N="<@/3X@(D-L:65N="!I<R!D
M:7-A8FQE9"!A;&]N9R!W:71H(&AI<R]H97(@9&]M86EN(BP*"2=I7V1O;5]O
M:R<@/3X@(D1O;6%I;B!I<R!A;&P@<FEG:'0N(BP*"2=I7V1O;5]O;B<@/3X@
M(D1O;6%I;B!I<R!A8W1I=F4N(BP*"2=I<%]A9&1R7U]A;')E861Y7V5X:7-T
M<R<@/3X@(DE0(&%D9')E<W,@)3$@86QR96%D>2!E>&ES=',N(BP*"2=I<%]A
M9&1R7U]C86YT7V%D9"<@/3X@(DE0("4Q(&1O97,@;F]T(&5X:7-T(&]R(&)E
M;&]N9W,@=&\@25`@<&]O;"!O9B!A;F]T:&5R(&-L:65N="(L"@DG:7!?861D
M<E]?8VQ?9&]M86EN<U]L:7-T7V9O<E]I<"<@/3X@(E1H92!D;VUA:6YS(&]F
M(&-L:65N="`E,2!T:&%T('5S92`E,B!I<"!A9&1R97-S("4S(BP*"2=I<%]A
M9&1R7U]C;%]L:7-T7V9O<E]I<"<@/3X@(D-L:65N=',@=7-I;F<@)3$@25`@
M861D<F5S<R`E,B(L"@DG:7!?861D<E]?8VQ?;&ES=%]F;W)?:7!?861D)R`]
M/B`B061D($E0(&%D9')E<W,@=&\@8VQI96YT<R!P;V]L(BP*"2=I<%]A9&1R
M7U]D;VUA:6YS7VQI<W1?9F]R7VEP)R`]/B`B1&]M86EN<R!U<VEN9R`E,2!)
M4"!A9&1R97-S("4R(BP*"2=I<%]A9&1R7U]I<%]U<V5D7V)Y7VAS=%]O<E]F
M<G<G(#T^("))4"!A9&1R97-S("4Q(&ES('5S960@9F]R(&AO<W1I;F<@;W(@
M9F]R=V%R9&EN9RXB+`H))VEP7V%D9')?7W)E;6]V95]I<%]A9&1R)R`]/B`B
M5&AE<V4@:7`@861D<F5S<V5S('=I;&P@8F4@<F5M;W9E9"!F<F]M('1H92!S
M>7-T96TZ(BP*"2=I<%]A9&1R7U]S96QE8W1?8VQI96YT<R<@/3X@(E-E;&5C
M="!C;&EE;G1S(BP*"2=I<%]A9&1R7U]S96QE8W1?:7!?861D<E]T;U]R96UO
M=F4G(#T^(")396QE8W0@=&AE($E0(&%D9')E<W,@=&\@8F4@<F5M;W9E9"XB
M+`H))VEP7V%D9')?7W5N86QL;W=E9%]B>5]L:6-E;G-E)R`]/B`B4&QE<VL@
M:7,@;F]T(&QI8V5N<V5D('1O('=O<FL@;VX@25`@861D<F5S<R`E,2Y<;D%L
M;&]W960@25`@<F%N9V5S(&%R93H@)3(N(BP*"2=I<%]A;&EA<U]?861D7VEP
M)R`]/B`B061D($E0(&%D9')E<W,B+`H))VEP7V%L:6%S7U]A9&1R7V%L<F5A
M9'E?97AI<W0G(#T^(")A9&1R97-S(&%L<F5A9'D@97AI<W1S+B(L"@DG:7!?
M86QI87-?7V%L:6%S7VUA;F%G92<@/3X@(DE0(&%D9')E<W-E<R!M86YA9V5M
M96YT(BP*"2=I<%]A;&EA<U]?86QI87-E<R<@/3X@(DE0($%D9')E<W-E<R`B
M+`H))VEP7V%L:6%S7U]I;G1E<F9A8V4G(#T^("));G1E<F9A8V4@(BP*"2=I
M<%]A;&EA<U]?:6YV86QI9%]I<%]N;5]B<V1?=G)T7VAS=',G(#T^("(E,2!)
M4"!A9&1R97-S(&9O<B!N86UE+6)A<V5D('9I<G1U86P@:&]S=&EN9R!I<R!I
M;G9A;&ED+B(L"@DG:7!?86QI87-?7VEN=F%L:61?:7!?;W)?;F5T;6%S:R<@
M/3X@(DEN=F%L:60@25`@861D<F5S<R]N971M87-K('!A:7(N(BP*"2=I<%]A
M;&EA<U]?:7!?8V%N7VYO=%]B95]D96QE=&5D)R`]/B`B5&AI<R!I<R!T:&4@
M;6%I;B!S97)V97(@25`L('=H:6-H(&-A;FYO="!B92!R96UO=F5D+B(L"@DG
M:7!?86QI87-?7VEP7VYO=%]E>&ES="<@/3X@(FEP(&%D9')E<W,@)3$@9&]E
M<R!N;W0@97AI<W0N(BP*"2=I<%]A;&EA<U]?:7!?861D<F5S<U]A;F1?;6%S
M:R<@/3X@)TE0(&%D9')E<W,@86YD('-U8FYE="!M87-K)RP*"2=I<%]A;&EA
M<U]?<F5M;W9E7W-E;&5C=&5D7VEP7V%L:6%S97,_)R`]/B`B07)E('EO=2!S
M=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<V5L96-T960@25`@861D<F5S
M<V5S/R(L"@DG:7!?86QI87-?7W-E;&5C=%]I<"<@/3X@(E-E;&5C="!A="!L
M96%S="!O;F4@25`@861D<F5S<R!F<F]M('1H92!L:7-T('1O(')E;6]V92!I
M="XB+`H))VEP7V%L:6%S7U]T:&ES7VEP7W5S961?9F]R7V1O;6%I;B<@/3X@
M(B@E,2D@=&AI<R!)4"!A9&1R97-S(&ES('5S960@9F]R(&1O;6%I;B`E,BXB
M+`H))VEP7V%L:6%S7U]T:&ES7VEP7W5S961?9F]R7VYM7V)S9%]V<G1?:'-T
M<R<@/3X@(B@E,2D@=&AI<R!)4"!A9&1R97-S(&ES('5S960@9F]R(&YA;64M
M8F%S960@=FER='5A;"!H;W-T<RXB+`H))VEP7V%L:6%S7U]T>7!E)R`]/B`B
M25`@='EP92(L"@DG:7!?86QI87-?7W5N86)L95]A9&1?:7`G(#T^(")5;F%B
M;&4@=&\@861D($E0.B`E,2(L"@DG:7!?86QI87-?7W5N86)L95]R96UO=F5?
M:7`G(#T^(")5;F%B;&4@=&\@<F5M;W9E($E0.B`E,2(L"@DG:7!?8W1R;%]?
M86YO;GEM;W5S7V9T<%]E>&ES='-?:6Y?9&]M86EN)R`]/B`B66]U(&-A;FYO
M="!C:&%N9V4@=&AE($E0(&%D9')E<W,@='EP92!T;R!S:&%R960L(&%S(&ET
M('=I;&P@;6%K92!!;F]N>6UO=7,@1E10(&9O<B!D;VUA:6X@)R4Q)R!U;F%V
M86EL86)L92XB+`H))VEP7V-T<FQ?7VEP7V%D9'(G(#T^("))4"!A9&1R97-S
M("4R(&]N('1H92!I;G1E<F9A8V4@)3$B+`H))VEP7V-T<FQ?7VEP7V5X:7-T
M<U]M86YY7W!O;VQS)R`]/B`B66]U(&-A;FYO="!C:&%N9V4@25`@='EP92X@
M25`@861D<F5S<R!B96QO;F=S('1O('1H92!P;V]L<R!O9B!S979E<F%L(&-L
M:65N=',@870@=&AE('-A;64@=&EM92XB+`H))VEP7V-T<FQ?7W-S;%]C97)T
M)R`]/B`B4U-,($-E<G1I9FEC871E(BP*"2=I<%]P;V]L7U]I<%]A9&1R97-S
M7VES7V%B<V5N9%]I;E]P;V]L)R`]/B`B25`@861D<F5S<R!I<R!M:7-S:6YG
M+B(L"@DG:7!?<&]O;%]?:7!?<&]O;%]F;W)?8VQI96YT)R`]/B`B25`@<&]O
M;"!O9B!C;&EE;G0@)3$B+`H))VEP7W!O;VQ?7VYO7V-L:65N<U]A=F%I;"<@
M/3X@(E1H97)E(&%R92!N;R!C;&EE;G1S(&%V86EL86)L92(L"@DG:7!?<&]O
M;%]?;F]?=F%C86YT7VEP<R<@/3X@(E1H97)E(&%R92!N;R!V86-A;G0@25!S
M(BP*"2=I<%]P;V]L7U]P;V]L7VES7V5M<'1Y)R`]/B`B0VQI96YT)W,@25`@
M<&]O;"!I<R!E;7!T>2X@5&\@861D(&%N($E0(&%D9')E<W,L('EO=2!S:&]U
M;&0@=7-E('1H92!#;&EE;G0G<R!)4"!P;V]L(&UA;F%G96UE;G0@9G5N8W1I
M;VYS(&%V86EL86)L92!F<F]M('1H92!#;&EE;G0G<R!(;VUE(%!A9V4N(BP*
M"2=I<%]P;V]L7U]R96UO=F5?:7!?861D<B<@/3X@(E1H97-E(&EP(&%D9')E
M<W-E<R!W:6QL(&)E(')E;6]V960@9G)O;2!T:&4@<&]O;"`E,3HB+`H))VEP
M7W!O;VQ?7W-E;&5C=%]F<F5E7VEP<R<@/3X@(E9A8V%N="!)4',B+`H))VEP
M7W!O;VQ?7W5S961?:7!S)R`]/B`B0VQI96YT)W,@25`@<&]O;"(L"@DG;&EC
M96YS95]?:5]A9W)E92<@/3X@(DD@86=R964@=&\@=&AE('1E<FUS(&]F('1H
M:7,@;&EC96YS92!A9W)E96UE;G0N(BP*"2=L:6-E;G-E7U]N;W1?<VAO=R<@
M/3X@(D1O(&YO="!S:&]W(&ET(&%G86EN+B(L"@DG;&EC96YS95]?=6YA8FQE
M7V]P96Y?;&EC96YS95]F:6QE)R`]/B`B56YA8FQE('1O(&]P96X@=&AE(&QI
M8V5N<V4@9FEL93H@)3$B+`H))VQI8V5N<V5?7WEO=5]S:&]U;&1?86-C97!T
M)R`]/B`B26X@;W)D97(@=&\@=7-E("104D]$7TY!344@>6]U('-H;W5L9"!A
M9W)E92!T;R!T:&4@=&5R;7,@;V8@=&AI<R!L:6-E;G-E+B(L"@DG;&EM:71?
M7V1A=&5?:6Y?<&%S="<@/3X@(E9A;&ED:71Y('!E<FEO9"!I<R!I;G9A;&ED
M+B`E,2!I<R!I;B!T:&4@<&%S="XB+`H))VQI;6ET7U]D:7-K7W-P86-E)R`]
M/B`B1&ES:R!S<&%C92(L"@DG;&EM:71?7V5N=&5R7V1A=&4G(#T^(")%;G1E
M<B!D871E(BP*"2=L:6UI=%]?97AP:7)A=&EO;B<@/3X@(E9A;&ED:71Y('!E
M<FEO9"(L"@DG;&EM:71?7VUA>%]B;W@G(#T^(")-87AI;75M(&YU;6)E<B!O
M9B!M86EL8F]X97,B+`H))VQI;6ET7U]M87A?9&(G(#T^(")-87AI;75M(&YU
M;6)E<B!O9B!D871A8F%S97,B+`H))VQI;6ET7U]M87A?9&]M)R`]/B`B36%X
M:6UU;2!N=6UB97(@;V8@9&]M86EN<R(L"@DG;&EM:71?7VUA>%]M86EL;&ES
M=',G(#T^(")-87AI;75M(&YU;6)E<B!O9B!M86EL:6YG(&QI<W1S(BP*"2=L
M:6UI=%]?;6%X7VUG)R`]/B`B36%X:6UU;2!N=6UB97(@;V8@;6%I;"!G<F]U
M<',B+`H))VQI;6ET7U]M87A?<F5D:7(G(#T^(")-87AI;75M(&YU;6)E<B!O
M9B!M86EL(')E9&ER96-T<R(L"@DG;&EM:71?7VUA>%]R97-P)R`]/B`B36%X
M:6UU;2!N=6UB97(@;V8@;6%I;"!A=71O<F5S<&]N9&5R<R(L"@DG;&EM:71?
M7VUA>%]S=6)D;VTG(#T^(")-87AI;75M(&YU;6)E<B!O9B!S=6)D;VUA:6YS
M(BP*"2=L:6UI=%]?;6%X7W1R869F:6,G(#T^(")-87AI;75M(&%M;W5N="!O
M9B!T<F%F9FEC(BP*"2=L:6UI=%]?;6%X7W=E8F%P<',G(#T^(")-87AI;75M
M(&YU;6)E<B!O9B!*879A(&%P<&QI8V%T:6]N<R(L"@DG;&EM:71?7VUA>%]W
M=2<@/3X@(DUA>&EM=6T@;G5M8F5R(&]F('=E8B!U<V5R<R(L"@DG;&EM:71?
M7VUB;WA?<75O=&$G(#T^(")3970@=&AE(&UA:6QB;W@@<75O=&$B+`H))VQI
M;6ET7U]U;FET<U]D:7-K7W-P86-E)R`]/B`B34(B+`H))VQI;6ET7U]U;FET
M<U]M87A?8F]X)R`]/B`B;6%I;&)O>&5S(BP*"2=L:6UI=%]?=6YI='-?;6%X
M7VUN)R`]/B`B;F%M97,B+`H))VQI;6ET7U]U;FET<U]M87A?9&(G(#T^(")D
M871A8F%S97,B+`H))VQI;6ET7U]U;FET<U]M87A?8VPG(#T^(")C;&EE;G1S
M(BP*"2=L:6UI=%]?=6YI='-?;6%X7V1O;2<@/3X@(F1O;6%I;G,B+`H))VQI
M;6ET7U]U;FET<U]M87A?;6%I;&QI<W1S)R`]/B`B;6%I;&EN9R!L:7-T<R(L
M"@DG;&EM:71?7W5N:71S7VUA>%]M9R<@/3X@(FUA:6P@9W)O=7!S(BP*"2=L
M:6UI=%]?=6YI='-?;6%X7W)E9&ER)R`]/B`B<F5D:7)E8W1S(BP*"2=L:6UI
M=%]?=6YI='-?;6%X7W)E<W`G(#T^(")A=71O<F5S<&]N9&5R<R(L"@DG;&EM
M:71?7W5N:71S7VUA>%]S=6)D;VTG(#T^(")S=6)D;VUA:6YS(BP*"2=L:6UI
M=%]?=6YI='-?;6%X7W1R869F:6,G(#T^(")-0B]M;VYT:"(L"@DG;&EM:71?
M7W5N:71S7VUA>%]W96)A<'!S)R`]/B`B2F%V82!A<'!L:6-A=&EO;G,B+`H)
M)VQI;6ET7U]U;FET<U]M87A?=W4G(#T^(")W96(@=7-E<G,B+`H))VQI;6ET
M7U]U;FET<U]M8F]X7W%U;W1A)R`]/B`B2T(B+`H*"2=L;V-A;&5?=7!L;V%D
M7U]T:71L92<@/3X@)T%D9"!,;V-A;&4G+`H))VQO8V%L95]U<&QO861?7V9I
M;&5?;F%M92<@(#T^("=0871H('1O('1H92!L86YG=6%G92!P86-K(&9I;&4@
M;&]C871I;VXG+`H))VQO8V%L95]U<&QO861?7W5N86)L95]T;U]I;G-T86QL
M)R`@/3X@)U5N86)L92!T;R!I;G-T86QL('1H92!L86YG=6%G92!P86-K(&9I
M;&4G+`H))VQO8V%L97-?;&ES=%]?=&ET;&4G("`@("`@(#T^("=,86YG=6%G
M92!P86-K<R!R97!O<VET;W)Y)RP*"2=L;V-A;&5S7VQI<W1?7VQE9V5N9"<@
M("`@("`@/3X@)T%V86EL86)L92!L86YG=6%G97,G+`H))VQO8V%L97-?;&ES
M=%]?86-T:79E7W1I=&QE)PD]/B`G4R<L"@DG;&]C86QE<U]L:7-T7U]L;V-A
M;&5?=&ET;&4G"3T^("=,86YG=6%G92!P86-K)RP*"2=L;V-A;&5S7VQI<W1?
M7VQA;F=?=&ET;&4G"0D]/B`G3&%N9W5A9V4G+`H))VQO8V%L97-?;&ES=%]?
M8V]U;G1R>5]T:71L92<)/3X@)T-O=6YT<GDG+`H))VQO8V%L97-?;&ES=%]?
M=7-E9%]T:71L92<)"3T^("=5<V5D)RP*"@DG;&]C86QE<U]R96UO=F5?7W1I
M=&QE)R`@("`@/3X@)TQO8V%L97,@4F5M;W9A;"<L"@DG;&]C86QE<U]R96UO
M=F5?7W-E;&5C=%]L;V-A;&5S7V9O<E]R96UO=F4G(#T^("=396QE8W0@=&AE
M(&QO8V%L97,@=&\@8F4@<F5M;W9E9"XG+`H))VQO8V%L97-?7V-A;E]N;W1?
M<F5M;W9E)R`@(#T^("=5;F%B;&4@=&\@<F5M;W9E('1H92!L86YG=6%G92!P
M86-K(&9O<B!L;V-A;&4@)3$Z("4R)RP*"@DG;&]G7V9I;&5?=FEE=V5R7U]F
M:6QE7VYA;65?:7-?=6YD969I;F5D)R`]/B`B4W!E8VEF>2!T:&4@;&]G(&9I
M;&5N86UE(&9O<B!V:65W:6YG+B(L"@DG;&]G7V9I;&5S7U]D96QE=&EO;E]P
M86=E7W1I=&QE)R`]/B`B5&AE(&9O;&QO=VEN9R!L;V<@9FEL97,@9F]R(&1O
M;6%I;B`E,2!W:6QL(&)E(')E;6]V960Z(BP*"2=L;V=?9FEL97-?7VEN=F%L
M:61?=F%L=65?;&EN97-?9F]R7W9I97<G(#T^("));G9A;&ED(&YU;6)E<B!O
M9B!L:6YE<R!S<&5C:69I960N(BP*"2=L;V=?9FEL97-?7VQI;F5S7V]F7VQO
M9V9I;&5?9F]R7W9I97<G(#T^("),:6YE<R!O9B!L;V<@9FEL92!T;R!B92!D
M:7-P;&%Y960@*&9R;VT@=&AE(&5N9"!O9B!T:&4@9FEL92DB+`H))VQO9U]F
M:6QE<U]?;&]G7V9I;&5?8V%N7VYO=%]B95]D96QE=&5D)R`]/B`B5&AI<R!L
M;V<@9FEL92!I<R!A8W1I=F4@86YD('1H97)E9F]R92!C86YN;W0@8F4@9&5L
M971E9"XB+`H))VQO9U]F:6QE<U]?;&]G7V9I;&5S)R`]/B`B3&]G(&9I;&5S
M(BP*"2=L;V=?9FEL97-?7W!A9V5?=&ET;&4G(#T^("),;V<@9FEL97,@;6%N
M86=E;65N="!F;W(@9&]M86EN("4Q(BP*"2=L;V=?9FEL97-?7W-E;&5C=%]F
M:6QE<U]F;W)?<F5M;W9E)R`]/B`B3F\@;&]G(&9I;&5S('-E;&5C=&5D(&9O
M<B!R96UO=F%L+B(L"@DG;&]G7V9I;&5S7U]T;W1A;%]L;V=F:6QE<U]S:7IE
M)R`]/B`B3&]G(&9I;&5S('1O=&%L('-I>F4Z("4Q(BP*"2=L;V=?<F]T7U]C
M;VUP<F5S<R<@/3X@(D-O;7!R97-S(&QO9R!F:6QE<R(L"@DG;&]G7W)O=%]?
M;&]G7W)O=%]P97)I;V0G(#T^("),;V<@<F]T871I;VX@8V]N9&ET:6]N(BP*
M"2=L;V=?<F]T7U]L;V=?<F]T7W-I>F4G(#T^(")B>2!S:7IE(BP*"2=L;V=?
M<F]T7U]L;V=?<F]T7W1I;64G(#T^(")B>2!T:6UE(BP*"2=L;V=?<F]T7U]L
M;V=R;W1A=&EO;E]E;F%B;&4G(#T^(")%;F%B;&4@;&]G(')O=&%T:6]N(BP*
M"2=L;V=?<F]T7U]M86EL)R`]/B`B4V5N9"!P<F]C97-S960@;&]G(&9I;&5S
M('1O(&4M;6%I;"(L"@DG;&]G7W)O=%]?;6%X7VYU;6)E<E]O9E]L;V=F:6QE
M<R<@/3X@(DUA>&EM=6T@;G5M8F5R(&]F(&QO9R!F:6QE<R(L"@DG;&]G7W)O
M=%]?<&%G95]T:71L92<@/3X@(DQO9R!R;W1A=&EO;B!P<F5F97)E;F-E<R!F
M;W(@9&]M86EN("4Q(BP*"2=L;V=?<F]T7U]T:6UE7W!E<FEO9"<@/3X@(G!E
M<FEO9"(L"@DG;&]G:6Y?=7!?7V%C8V5S<U]D96YI961?86-C;W5N=%]D:7-A
M8FQE9"<@/3X@(D%C8V5S<R!D96YI960N(%EO=7(@86-C;W5N="!H87,@8F5E
M;B!D:7-A8FQE9"XB+`H))VQO9VEN7W5P7U]D969A=6QT7VQO8V%L92<@/3X@
M)U5S97(@9&5F875L="<L"@DG;&]G:6Y?=7!?7V5N=&5R7VQO9VEN7V%N9%]P
M87-S=V0G(#T^(")%;G1E<B!Y;W5R(&QO9VEN(&YA;64@86YD('!A<W-W;W)D
M+B(L"@DG;&]G:6Y?=7!?7V9O<F=O=%]P87-S=V]R9%]L86)E;"<@/3X@(D9O
M<F=O="!Y;W5R('!A<W-W;W)D/R(L"@DG;&]G:6Y?=7!?7V9O<F=O=%]P87-S
M=V]R9%]T97AT)R`]/B`B268@>6]U(&9O<F=O="!Y;W5R('!A<W-W;W)D('=E
M('=I;&P@=')Y('1O(&AE;'`@>6]U(&)Y('-E;F1I;F<@:70@;W5T('1O('EO
M=7(@92UM86EL+B(L"@DG;&]G:6Y?=7!?7VQO9VEN7VAA<U]B965N7VQO8VME
M9"<@/3X@(D%C8V5S<R!D96YI960N(BP*"2=L;V=I;E]U<%]?;&]G:6Y?;&%B
M96Q?<&QE<VLG(#T^("),;V=I;B!4;R`E,2(L"@DG;&]G:6Y?=7!?7VQO9VEN
M7W1E>'0G(#T^(")%;G1E<B!T:&4@;&]G:6X@;F%M92!I;G1O(%PB3&]G:6Y<
M(B!A;F0@<&%S<W=O<F0@:6YT;R!T:&4@7")087-S=V]R9%PB(&9I96QD<R!R
M97-P96-T:79E;'DN(%1H96X@8VQI8VL@7"),;V=I;EPB+B(L"@DG;&]G:6Y?
M=7!?7W5N86)L95]T;U]C:&5C:U]P87-S)R`]/B`B56YA8FQE('1O(&-H96-K
M('!A<W-W;W)D.B`E,2(L"@DG;&]C86QE<U]L:7-T7U]M;'-?;&EM:70G(#T^
M(")4:&4@;&EM:70@;VX@=&AE(&UA>&EM=6T@;G5M8F5R(&]F(&QA;F=U86=E
M('!A8VMS(&ES(&5X8V5E9&5D+B!!8W1I=F4@;&%N9W5A9V5S("4Q+B!!;&QO
M=V5D(&QA;F=U86=E<R`E,BXB+`H))VQO9VEN7W5P7U]S:&]R=%]W87)N:6YG
M7VQI;6ET<U]L:6-E;F-E7VME>2<@/3X@(D%C8V5S<R!T;R!T:&4@8V]N=')O
M;"!P86YE;"!I<R!T96UP;W)A<FEL>2!U;F%V86EL86)L92X@4&QE87-E(&-O
M;G1A8W0@>6]U<B!P<F]V:61E<B!F;W(@9&5T86EL<RXB+`H))VQO9VEN7W5P
M7U]G<F%C95]P97)I;V0G(#T^("=9;W4@87)E(&-U<G)E;G1L>2!O<&5R871I
M;F<@=VET:&EN('1H92!G<F%C92!P97)I;V0@;V8@>6]U<B!P<F]D=6-T(&QI
M8V5N<V4@*"4S*2X@5&\@=7!D871E('EO=7(@<')O9'5C="!L:6-E;G-E('5S
M92!T:&4@4F5T<FEE=F4@2V5Y<R!F=6YC=&EO;B!O9B`E,4QI8V5N<V4@36%N
M86=E<B4R+B<L"@DG;&]G:6Y?=7!?7W!A<G1N97)?;&EC96YS95]M97-S86=E
M)R`]/B`G66]U(&%R92!C=7)R96YT;'D@;W!E<F%T:6YG('=I=&@@82!L:6UI
M=&5D('!R;V1U8W0@;&EC96YS92!T:&%T(')E<75I<F5S(')E9VES=')A=&EO
M;B!P<FEO<B!T;R!A8W1I=F%T:6YG('1H92!F=6QL(&9E871U<F4@<V5T+B`@
M5&\@=7!D871E('EO=7(@<')O9'5C="!L:6-E;G-E('-E;&5C="!T:&4@4F5T
M<FEE=F4@2V5Y<R!O<'1I;VX@9G)O;2!W:71H:6X@)3%,:6-E;G-E($UA;F%G
M97(E,BXG+`H))VUA7U]C<F5A=&5?=&ET;&4G(#T^("=#<F5A=&EN9R!M86EL
M(&%L:6%S(&9O<B`E,2<L"@DG;6%?7V5D:71?=&ET;&4G(#T^(")%9&ET(&UA
M:6P@86QI87,@)3$B+`H))VUA7U]E;G1E<E]N97=?86QI87,G(#T^(")%;G1E
M<B!N97<@86QI87,N(BP*"2=M85]?:6YV86QI9%]A;&EA<R<@/3X@(DEN=F%L
M:60@;6%I;"!A;&EA<RXB+`H))VUA7U]M86EL7V%L:6%S97-?;6%I;&YA;64G
M(#T^(")-86EL(&%L:6%S97,@9F]R(&UA:6P@;F%M92`E,2(L"@DG;6%?7VUA
M:6QN86UE7V1O97-?;F]T7V5X:7-T)R`]/B`B36%I;"!N86UE(&1O97,@;F]T
M(&5X:7-T+B(L"@DG;6%?7W-E;&5C=%]M85]F;W)?<F5M;W9E)R`]/B`B4V5L
M96-T(&UA:6P@86QI87-E<R!T;R!B92!R96UO=F5D+B(L"@DG;6%?7W5N86)L
M95]T;U]A9&1?;F5W7VUA)R`]/B`B56YA8FQE('1O(&%D9"!N97<@;6%I;"!A
M;&EA<SH@)3$B+`H))VUA:6Q?7V%L;&]W7W-H;W)T7W!O<#-?;F%M97,G(#T^
M(").86UE<R!F;W(@4$]0,R])34%0(&UA:6P@86-C;W5N=',B+`H))VUA:6Q?
M7V%L;&]W7W-H;W)T7W!O<#-?;F%M97-?9&ES86)L960G(#T^(")/;FQY('5S
M92!O9B!F=6QL(%!/4#,O24U!4"!M86EL(&%C8V]U;G1S(&YA;65S(&ES(&%L
M;&]W960B+`H))VUA:6Q?7V%L;&]W7W-H;W)T7W!O<#-?;F%M97-?96YA8FQE
M9"<@/3X@(E5S92!O9B!S:&]R="`H=V5B;6%S=&5R*2!A;F0@9G5L;"`H=V5B
M;6%S=&5R0&1O;6%I;BYC;VTI(%!/4#,O24U!4"!M86EL(&%C8V]U;G0@;F%M
M97,@:7,@86QL;W=E9"(L"@DG;6%I;%]?8F%D9&]M86EN7V5X:7-T<R<@/3X@
M(E5N86)L92!T;R!A9&0@9&]M86EN('1O('1H92!B;&%C:R!L:7-T.B!S=6-H
M(&1O;6%I;B!A;')E861Y(&5X:7-T<R(L"@DG;6%I;%]?8FQO8VM?;6%I;%]F
M<F]M7V1O;7,G(#T^(")";&%C:R!,:7-T(BP*"2=M86EL7U]B;&]C:V5R<R<@
M/3X@(D)L;V-K960@9&]M86EN<R(L"@DG;6%I;%]?8FQO8VME<G-?<F5M;W9E
M)R`]/B`B4F5M;W9E(&)L;V-K960@9&]M86EN<R(L"@DG;6%I;%]?8FQO8VME
M<E]A9&0G(#T^(")!9&0@9&]M86EN<R!T;R!B;&%C:R!L:7-T(BP*"2=M86EL
M7U]C;&]S960G(#T^(")C;&]S960B+`H))VUA:6Q?7V-R>7!T961?<&%S<W=D
M7VUA=&-H)R`]/B`B5&AE<F4@87)E(&UA:6P@;F%M97,@;6%T8VAI;F<@=&AE
M(&5N8W)Y<'1E9"!P87-S=V]R9',N(BP*"2=M86EL7U]D;VU?:6Y?;&ES="<@
M/3X@(D1O;6%I;B!I<R!A;')E861Y(&EN('1H92!B;&%C:R!L:7-T+B(L"@DG
M;6%I;%]?96YA8FQE7W)B;"<@/3X@(D5N86)L92!-05!3('-P86T@<')O=&5C
M=&EO;B(L"@DG;6%I;%]?96YT97)?<F)L7W-E<G9E<B<@/3X@(E1Y<&4@:6X@
M=&AE($U!4%,@>F]N92XB+`H))VUA:6Q?7V5N=&5R7W)I9VAT7VEP7VUA<VLG
M(#T^(")%;G1E<B!T:&4@:7`@;6%S:R!B971W965N(#$@86YD(#,R(BP*"2=M
M86EL7U]E;G1E<E]R:6=H=%]I<%]M87-K7S(T)R`]/B`B16YT97(@=&AE(&EP
M(&UA<VL@8F5T=V5E;B`R-"!A;F0@,S(B+`H))VUA:6Q?7VEN<W1A;&Q?<F)L
M<VUT<&1?<')O9W)A;2<@/3X@(DEN<W1A;&P@=&AE(')B;'-M='`@<V]F='=A
M<F4N(BP*"2=M86EL7U]I;G9A;&ED7V1O;5]N86UE)R`]/B`B1&]M86EN(&YA
M;64@)3$@:7,@:6YV86QI9"XB+`H))VUA:6Q?7VEN=F%L:61?<&]P7VQO8VM?
M=&EM92<@/3X@(E!/4#,@;&]C:R!T:6UE(&ES(&EN=F%L:60N(BP*"2=M86EL
M7U]I;G9A;&ED7W)B;%]S97)V97(G(#T^(")-05!3('IO;F4@;F%M92!I<R!I
M;G9A;&ED+B(L"@DG;6%I;%]?:7!?86YD7VUA<VLG(#T^("))4"!A9&1R97-S
M+VUA<VLB+`H))VUA:6Q?7VEP7V%N9%]M87-K7V5X:7-T<R<@/3X@(E-U8V@@
M:7`@861D<F5S<R]N971M87-K('!A:7(@86QR96%D>2!E>&ES=',N(BP*"2=M
M86EL7U]I<%]O<E]M87-K7VES7VEN=F%L:60G(#T^("))4"!A9&1R97-S+VYE
M="!M87-K('!A:7(@:7,@:6YV86QI9"XB+`H))VUA:6Q?7VQO8VM?=&EM92<@
M/3X@(FQO8VL@=&EM92(L"@DG;6%I;%]?;6%I;%]O<'1I;VYS)R`]/B`B36%X
M:6UU;2!L971T97(@<VEZ92!A;F0@<F5L87D@;6]D92!P87)A;65T97)S(BP*
M"2=M86EL7U]M86EL;F%M97-?<&%S<W=D7VUA=&-H)R`]/B`B5&AE<F4@87)E
M(&UA:6P@;F%M92!A;F0@<&%S<W=O<F0@<&%I<G,@;6%T8VAI;F<N(BP*"2=M
M86EL7U]S96QE8W1?9&]M86EN<U]F;W)?<F5M;W9E)R`]/B`B4V5L96-T('1H
M92!D;VUA:6YS('1O(&)E(')E;6]V960N(BP*"@DO+R!E;F0@;V8@;6%V97)I
M8VL@<&%R=`H*"@DO+R!K;V]P97(@<&%R=`H*"2=M86EL7U]M87A?<VEZ92<@
M/3X@(DUA>&EM=6T@;&5T=&5R('-I>F4B+`H))VUA:6Q?7VUB;WA?<75O=&$G
M(#T^(")-86EL8F]X('%U;W1A(BP*"2=M86EL7U]M:6XG(#T^(")-:6XB+`H)
M)VUA:6Q?7W1O=&%L7V9I;&5S7W-I>F4G(#T^(")4;W1A;"!R97!O<VET;W)Y
M('-I>F4Z("4Q(BP*"2=M86EL7U]F:6QE;F%M95]A;')E861Y7VEN7W)E<&]S
M:71O<GDG(#T^(")&:6QE('=I=&@@<W5C:"!N86UE(&ES(&%L<F5A9'D@:6X@
M<F5P;W-I=&]R>2(L"@DG;6%I;%]?;F]?=VAI=&5?;&ES=%]M87-K7V9E871U
M<F5?,C0G(#T^(")0;&5A<V4L('5S92`R-"!O<B!H:6=H97(@87,@;6%S:R!V
M86QU92Y<;EEO=7(@;6%I;"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S971T
M:6YG(&UA<VMS+B!792!C86X@;VYL>2!E;75L871E('-E='1I;F<@;6%S:R!F
M;W(@=F%L=65S(&YO="!L97-S('1H86X@,C0N(BP*"2=M86EL7U]O<&5N)R`]
M/B`B;W!E;B(L"@DG;6%I;%]?;W!E;E]R96QA>5]W87)N:6YG)R`]/B`B4V5T
M=&EN9R!Y;W5R(&UA:6P@<F5L87D@=&\@;W!E;B!E>'!O<V5S('EO=7(@;6%I
M;"!S97)V97(@=&\@<W!A;6UI;F<@86)U<V4N7&Y<;DET('-H;W5L9"!O;FQY
M(&)E('5S960@9F]R('1E;7!O<F%R>2!T97-T:6YG(&]F('EO=7(@;6%I;"!S
M97)V97(@;W(@:6X@:6YS=&%N8V5S('=H97)E('EO=2!A<F4@;W!E<F%T:6YG
M(%!L97-K(&9R;VT@:6YT97)N86P@;F5T=V]R:R!N;W0@86-C97-S:6)L92!V
M:6$@=&AE($EN=&5R;F5T+EQN7&Y!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@
M:V5E<"!T:&ES('-E='1I;F<_(BP*"2=M86EL7U]P;W`S)R`]/B`B4$]0,R(L
M"@DG;6%I;%]?<')E9F5R96YC97,G(#T^(")-86EL('!R969E<F5N8V5S(BP*
M"2=M86EL7U]R8FQ?>F]N97,G(#T^(")-05!3('IO;F5S(BP*"2=M86EL7U]R
M96QA>5]F<F]M7VEP)R`]/B`B5VAI=&4@3&ES="(L"@DG;6%I;%]?<F5L87EI
M;F<G(#T^(")296QA>6EN9R(L"@DG;6%I;%]?<F5Q<E]A=71H)R`]/B`B875T
M:&]R:7IA=&EO;B!I<R!R97%U:7)E9#H@(BP*"2=M86EL7U]S;71P)R`]/B`B
M4TU44"(L"@DG;6%I;%]?=6YA8FQE7V%D9%]N97=?;6%I;%]N86UE)R`]/B`B
M56YA8FQE('1O(&%D9"!N97<@;6%I;"!N86UE.B`E,2(L"@DG;6%I;%]?=VAI
M=&5?;&ES="<@/3X@(E=H:71E($QI<W0B+`H))VUA:6Q?7W=H:71E7VQI<W1?
M861D)R`]/B`G061D($YE=R!.971W;W)K)RP*"2=M86EL7U]W:&ET95]L:7-T
M7W)E;6]V92<@/3X@)U1H92!F;VQL;W=I;F<@;F5T=V]R:W,@=VEL;"!B92!R
M96UO=F5D.B<L"@DG;6%I;%]?=VAI=&5?;&ES=%]M96UB97(G(#T^("=!;&QO
M=V5D(&YE='=O<FMS)RP*"2=M86EL7U]W:&ET95]L:7-T7V5M<'1Y7W-E;&5C
M=&EO;E]F;W)?<F5M;W9E)R`]/B`G4V5L96-T('1H92!E;G1R:65S('1O(&)E
M(')E;6]V960N)RP*"2=M86EL7W%U975E7U]T;V]L<U]L96=E;F0G(#T^("=4
M;V]L<R<L"@DG;6%I;%]Q=65U95]?:6YF;U]L96=E;F0G(#T^("=);F9O)RP*
M"2=M86EL7W%U975E7U]M97-S86=E<U]L:7-T7VQE9V5N9"<@/3X@)TUE<W-A
M9V5S(&EN(&UA:6P@<75E=64G+`H))VUA:6Q?<75E=65?7W$G(#T^("=1)RP*
M"2=M86EL7W%U975E7U]S=6)J96-T)R`]/B`G4W5B:F5C="<L"@DG;6%I;%]Q
M=65U95]?96YV96QO<&5?<V5N9&5R)R`]/B`G4V5N9&5R)RP*"2=M86EL7W%U
M975E7U]E;G9E;&]P95]R96-I<&EE;G1S)R`]/B`G4F5C:7!I96YT<R<L"@DG
M;6%I;%]Q=65U95]?9&%T92<@/3X@)T1A=&4G+`H))VUA:6Q?<75E=65?7V%G
M92<@/3X@)T%G92<L"@DG;6%I;%]Q=65U95]?<VEZ92<@/3X@)U-I>F4G+`H)
M)VUA:6Q?<75E=65?7VUE<W-A9V5S)R`]/B`G;65S<V%G97,G+`H))VUA:6Q?
M<75E=65?7VEN9F]?=&5X="<@/3X@)TUE<W-A9V5S(&EN('%U975E.B`E,2!N
M;W0@<')E<')O8V5S<V5D+"`E,B!L;V-A;"P@)3,@<F5M;W1E+"`E-"!T;W1A
M;"XG+`H))VUA:6Q?<75E=65?7W-E;&5C=%]?86QL)R`]/B`G06QL)RP*"2=M
M86EL7W%U975E7U]S96QE8W1?7W1O9&\G(#T^("=.;W0@4')E<')O8V5S<V5D
M)RP*"2=M86EL7W%U975E7U]S96QE8W1?7W)E;6]T92<@/3X@)U)E;6]T92<L
M"@DG;6%I;%]Q=65U95]?<V5L96-T7U]L;V-A;"<@/3X@)TQO8V%L)RP*"2=M
M86EL7W%U975E7U]S96QE8W1?7VQO8V%L7V%N9%]R96UO=&4G(#T^("=,;V-A
M;"!A;F0@4F5M;W1E)RP*"2=M86EL7W%U975E7U]Q=65U92<@/3X@)U%U975E
M<R<L"@DG;6%I;%]Q=65U95]?96YV96QO<&4G(#T^("=%;G9E;&]P92<L"@DG
M;6%I;%]Q=65U95]?<V5N9&5R)R`]/B`G4V5N9&5R)RP*"2=M86EL7W%U975E
M7U]R96-I<&EE;G0G(#T^("=296-I<&EE;G0G+`H))VUA:6Q?<75E=65?7W-T
M87)T7V1A=&4G(#T^("=3=&%R="<L"@DG;6%I;%]Q=65U95]?96YD7V1A=&4G
M(#T^("=%;F0G+`H))VUA:6Q?<75E=65?7VUI;E]A9V4G(#T^("=-:6YI;75M
M)RP*"2=M86EL7W%U975E7U]M87A?86=E)R`]/B`G36%X:6UU;2<L"@DG;6%I
M;%]Q=65U95]?;6EN7W-I>F4G(#T^("=-:6YI;75M)RP*"2=M86EL7W%U975E
M7U]M87A?<VEZ92<@/3X@)TUA>&EM=6TG+`H))VUA:6Q?<75E=65?7V5M<'1Y
M7W-E;&5C=&EO;B<@/3X@)TYO(&UE<W-A9V5S('-E;&5C=&5D+B<L"@DG;6%I
M;%]Q=65U95]?<F5M;W9E7VUE<W-A9V5S7V-O;F9I<FTG(#T^("=$;R!Y;W4@
M<F5A;&QY('=A;G0@=&\@<F5M;W9E('1H92!S96QE8W1E9"!M97-S86=E<R!F
M<F]M('1H92!Q=65U93\G+`H))VUA:6Q?<75E=65?7VYO=%]A;&QO=V5D7V)Y
M7VQI8V5N<V5?:V5Y)R`]/B`G36%I;"!Q=65U92!M86YA9V5M96YT(&ES(&YO
M="!A;&QO=V5D(&)Y('1H92!L:6-E;G-E(&ME>2XG+`H))V)T7W-H;W=?861V
M86YC961?<V5A<F-H)R`]/B`G4VAO=R!!9'9A;F-E9"!396%R8V@G+`H))V)T
M7VAI9&5?861V86YC961?<V5A<F-H)R`]/B`G2&ED92!!9'9A;F-E9"!396%R
M8V@G+`H))VUA:6QL:7-T7U\G(#T^(")-86EL:6YG(&QI<W0@)3$B+`H))VUA
M:6QL:7-T7U]A;')E861Y7V5X:7-T<R<@/3X@(DUA:6QI;F<@;&ES="!A;')E
M861Y(&5X:7-T<RXB+`H))VUA:6QL:7-T7U]C<F5A=&5?;6%I;&QI<W1?9F]R
M)R`]/B`B0W)E871E(&$@;6%I;&EN9R!L:7-T(&9O<B!D;VUA:6X@)3$B+`H)
M)VUA:6QL:7-T7U]E;6%I;%]?)R`]/B`B36%I;&EN9R!L:7-T(&%D;6EN:7-T
M<F%T;W(G<R!E;6%I;"`E,2(L"@DG;6%I;&QI<W1?7VEN=F%L:61?96UA:6PG
M(#T^(")!9&UI;FES=')A=&]R)W,@96UA:6P@:7,@:6YV86QI9"(L"@DG;6%I
M;&QI<W1?7VEN=F%L:61?;F%M92<@/3X@(E1H92!M86EL:6YG(&QI<W0@;F%M
M92!I<R!I;G9A;&ED(BP*"2=M86EL;&ES=%]?:6YV97)T7V]N7V]F9C\G(#T^
M(")#:&%N9V4@=&AE('-T871E(&]F('-E;&5C=&5D(&UA:6QI;F<@;&ES=',_
M(BP*"2=M86EL;&ES=%]?:6YV97)T7V]N7V]F9E]O;F4_)R`]/B`B0VAA;F=E
M('1H92!S=&%T92!O9B!T:&4@;6%I;&EN9R!L:7-T/R(L"@DG;6%I;&QI<W1?
M7VUA:6Q?86QI87-?86QR96%D>5]E>&ES='-?:6Y?=&AI<U]D;VUA:6XG(#T^
M(")4:&4@;6%I;"!A;&EA<R`E,2!A;')E861Y(&5X:7-T<R!I;B!T:&ES(&1O
M;6%I;B(L"@DG;6%I;&QI<W1?7VYA;65?7R<@/3X@(DUA:6QI;F<@;&ES="!N
M86UE("4Q(BP*"2=M86EL;&ES=%]?;F5W7U\G(#T^(")#<F5A=&4@;F5W(&UA
M:6QI;F<@;&ES="`E,2(L"@DG;6%I;&QI<W1?7VYO=&EF>5]?)R`]/B`B3F]T
M:69Y(&%D;6EN:7-T<F%T;W(@;V8@=&AE(&UA:6QI;F<@;&ES="!C<F5A=&EO
M;B(L"@DG;6%I;&QI<W1S7U\G(#T^(")-86EL:6YG(&QI<W1S("4Q(BP*"2=M
M86EL;&ES='-?7VQI;6ET7V-L7VUA>%]M86EL;&ES=',G(#T^(")4:&4@;&EM
M:70@;VX@;G5M8F5R(&]F(&UA:6QI;F<@;&ES=',@:&%S(&)E96X@<F5A8VAE
M9"!F;W(@=&AE(&-L:65N="`H;&EM:70Z("4Q+"!U<V5D.B`E,BDB+`H))VUA
M:6QL:7-T<U]?;&EM:71?9&]M7VUA>%]M86EL;&ES=',G(#T^(")4:&4@;&EM
M:70@;VX@;G5M8F5R(&]F(&UA:6QI;F<@;&ES=',@:&%S(&)E96X@<F5A8VAE
M9"!F;W(@=&AE(&1O;6%I;BXB+`H))VUA:6QL:7-T<U]?;&ES="<@/3X@(DUA
M:6QI;F<@;&ES=',B+`H))VUA:6QL:7-T<U]?;&ES='-?;V9?9&]M86EN7U\G
M(#T^(")-86EL:6YG(&QI<W1S(&EN(&1O;6%I;B`E,2(L"@DG;6%I;&QI<W1S
M7U]M86EL;6%N7VYO=%]I;G-T86QL961?;W)?8V]N9B<@/3X@(EQN36%I;&UA
M;B!397)V97(@17AT96YS:6]N<R!A<F4@;F]T(&-U<G)E;G1L>2!I;G-T86QL
M960@;W(@8V]N9FEG=7)E9%QN;VX@=&AE('-E<G9E<BX@0V]N=&%C="!T:&4@
M<V5R=F5R(&%D;6EN:7-T<F%T;W(@=&\@:&%V92!T:&4@36%I;&UA;B!397)V
M97(@17AT96YS:6]N<R!I;G-T86QL960@;W(@<')O<&5R;'D@8V]N9FEG=7)E
M9"XB+`H))VUA:6QL:7-T<U]?<F5M;W9E7VUA:6QL:7-T<U]O;E]D;VUA:6XG
M(#T^(")296UO=FEN9R!M86EL:6YG(&QI<W1S(&9R;VT@9&]M86EN("4Q+B(L
M"@DG;6%I;&QI<W1S7U]S96QE8W1?;6%I;&QI<W1?9F]R7VEN=F5R=%]O;E]O
M9F8G(#T^(")9;W4@<VAO=6QD('-E;&5C="!A="!L96%S="!O;F4@;6%I;&EN
M9R!L:7-T+B(L"@DG;6%I;&QI<W1S7U]S96QE8W1?;6%I;&QI<W1?9F]R7W)E
M;6]V92<@/3X@(E-E;&5C="!T:&4@;6%I;&EN9R!L:7-T<R!T;R!B92!R96UO
M=F5D+B(L"@DG;6%I;&QI<W1S7U]S96QE8W1?;6%I;&QI<W1S7W1O7W)E;6]V
M92<@/3X@(E-E;&5C="!O;F4@;W(@<V5V97)A;"!M86EL:6YG(&QI<W1S('1O
M(&)E(')E;6]V960N(BP*"2=M86EL;&ES='-?7W-T871U<R<@/3X@(DUA:6QI
M;F<@;&ES="!S97)V:6-E(&ES(&5N86)L960B+`H))VUA:6QL:7-T<U]?=6YA
M8FQE7W1O7V1E;&5T95]?)R`]/B`B56YA8FQE('1O(&1E;&5T92!T:&4@;6%I
M;&EN9R!L:7-T.B`E,2(L"@DG;6%I;&QI<W1S7U]D:7-A8FQE9%]T97AT)R`]
M/B`G66]U(&-A;FYO="!M86YA9V4@=&AE(&UA:6QI;F<@;&ES=',@8F5C875S
M92!T:&4@36%I;&UA;B!C;VUP;VYE;G0@:7,@;F]T(&EN<W1A;&QE9"!O<B!C
M;VYF:6=U<F5D+B<L"@DG;6%I;&QI<W1S7U]D:7-A8FQE9%]T97AT7V%D;6EN
M)R`]/B`G66]U(&-A;FYO="!M86YA9V4@=&AE(&UA:6QI;F<@;&ES=',@8F5C
M875S92!T:&4@36%I;&UA;B!C;VUP;VYE;G0@:7,@;F]T(&EN<W1A;&QE9"!O
M<B!C;VYF:6=U<F5D+B!0;&5A<V4@=7-E('1H92!-86EL;6%N(&-O;F9I9W5R
M871I;VX@9G5N8W1I;VX@870@=&AE(%-E<G9E<B!!9&UI;FES=')A=&EO;B!0
M86=E+B<L"@DG;6%I;&QI<W1S7U]D:7-A8FQE9%]T97AT7W5S97(G(#T^("=9
M;W4@8V%N;F]T(&UA;F%G92!T:&4@;6%I;&EN9R!L:7-T<R!B96-A=7-E('1H
M92!-86EL;6%N(&-O;7!O;F5N="!I<R!N;W0@:6YS=&%L;&5D(&]R(&-O;F9I
M9W5R960N(%!L96%S92!C;VYT86-T('EO=7(@<V5R=F5R(&%D;6EN:7-T<F%T
M;W(@=&\@:&%V92!T:&4@36%I;&UA;B!I;G-T86QL960N)RP*"2=M86EL;&ES
M='-?8V]N9E]?<&%G95]T:71L92<@/3X@(D-O;F9I9W5R:6YG($UA:6QI;F<@
M3&ES=',@36%N86=E<B(L"@DG;6%I;&QI<W1S7V-O;F9?7W-U8V-E<W-F=6PG
M(#T^("=4:&4@36%I;&UA;B!S;V9T=V%R92!H87,@8F5E;B!S=6-C97-S9G5L
M;'D@8V]N9FEG=7)E9"P@<V\@=&AE(%-E="!5<"!-86EL;6%N(&)U='1O;B!W
M:6QL(&YO(&QO;F=E<B!B92!A8V-E<W-I8FQE(&9R;VT@=&AE(%-E<G9E<B!!
M9&UI;FES=')A=&EO;B!S8W)E96XN)RP*"2=M86EL;&ES=%]M96UB97)?961I
M=%]?=&ET;&4G(#T^(")!9&0@3F5W(%-U8G-C<FEB97(B+`H))VUA:6QL:7-T
M7VUE;6)E<G-?7W1I=&QE)R`]/B`G)3$@4W5B<V-R:6)E<G,G+`H))VUA:6QL
M:7-T7VUE;6)E<G-?7W-E;&5C=%]F;W)?<F5M;W9E)R`]/B`B4V5L96-T('1H
M92!S=6)S8W)I8F5R<R!T;R!B92!R96UO=F5D+B(L"@DG;6%I;&QI<W1?;65M
M8F5R<U]R96UO=F5?7W1I=&QE)R`]/B`G4F5M;W9E(&UA:6QI;F<@;&ES="!S
M=6)S8W)I8F5R<R<L"@DG;6%I;&QI<W1?;65M8F5R7U]A;')E861Y7V5X:7-T
M<R<@/3X@)TUA:6QI;F<@;&ES="!S=6)S8W)I8F5R(&%L<F5A9'D@97AI<W1S
M+B<L"@DG;6%I;&QI<W1?;65M8F5R7U]N;W1?97AI<W1S)R`]/B`G5&AE<F4@
M:7,@;F\@<W5C:"!U<V5R(&]N('1H92!M86EL:6YG(&QI<W0N)RP*"2=M86YA
M9V5R7U]A8V-E<W-?9&5N:65D)R`]/B`B06-C97-S(&1E;FEE9#H@)3$B+`H)
M)VUA;F%G97)?7V%D;6EN)R`]/B`B061M:6YI<W1R871O<B(L"@DG;6%N86=E
M<E]?8VQI96YT)R`]/B`B0VQI96YT(BP*"2=M86YA9V5R7U]D;VUA:6XG(#T^
M(")$;VUA:6XB+`H))VUA;F%G97)?7V1O;6%I;E]C;%]L:6UI=%]E>&-E961I
M;F<G(#T^(")4:&4@;&EM:70@;VX@;G5M8F5R(&]F(&1O;6%I;G,@:7,@<F5A
M8VAE9"!F;W(@=&AI<R!C;&EE;G0@86-C;W5N="(L"@DG;6%N86=E<E]?9&]M
M86EN7VES7VYO=%]Y;W5R<R<@/3X@(D1O;6%I;B`E,2!D;V5S(&YO="!B96QO
M;F<@=&\@>6]U(BP*"2=M86YA9V5R7U]D;VUA:6Y?:V5Y7VQI;6ET7V5X8V5E
M9&EN9R<@/3X@(E1H92!L:6UI="!O;B!D;VUA:6X@8W)E871I;VX@9&5F:6YE
M9"!B>2!Y;W5R(&QI8V5N<V4@:V5Y(&ES(')E86-H960B+`H))VUA;F%G97)?
M7VYO7W!E<FU?=&]?8V%L;"<@/3X@(EEO=2!D;R!N;W0@:&%V92!T:&4@<&5R
M;6ES<VEO;B!T;R!C86QL("4Q(BP*"2=M86YA9V5R7U]N;U]P97)M7W1O7V-R
M96%T95]D;VUA:6YS)R`]/B`B66]U(&1O(&YO="!H879E('1H92!P97)M:7-S
M:6]N('1O(&-R96%T92!D;VUA:6YS(BP*"2=M86YA9V5R7U]N;U]P97)M7W1O
M7VUO9&EF>5]D;VUA:6XG(#T^(")9;W4@9&\@;F]T(&AA=F4@=&AE('!E<FUI
M<W-I;VX@=&\@;6]D:69Y(&1O;6%I;B`E,2(L"@DG;6%N86=E<E]?;F]?<&5R
M;5]T;U]M;V1I9GE?9&]M86EN<R<@/3X@(EEO=2!D;R!N;W0@:&%V92!T:&4@
M<&5R;6ES<VEO;B!T;R!M;V1I9GD@9&]M86EN<R(L"@DG;6%N86=E<E]?;F]?
M<&5R;5]T;U]R96UO=F5?9&]M86EN)R`]/B`B66]U(&1O(&YO="!H879E('1H
M92!P97)M:7-S:6]N('1O(')E;6]V92!D;VUA:6X@)3$B+`H))VUA;F%G97)?
M7VYO7W!E<FU?=&]?<F5M;W9E7V1O;6%I;G,G(#T^(")9;W4@9&\@;F]T(&AA
M=F4@=&AE('!E<FUI<W-I;VX@=&\@<F5M;W9E(&1O;6%I;G,B+`H))VUA;F%G
M97)?7VYO9&5?9&]E<VYT7V5X:7-T)R`]/B`B)3$@9&]E<R!N;W0@97AI<W0B
M+`H))VUA;F%G97)?7W5S97)?9&ES86)L960G(#T^(")9;W5R(&%C8V]U;G0@
M:7,@9&ES86)L960N(%EO=2!C86YN;W0@;W!E<F%T92!T:&4@<WES=&5M+B(L
M"@DG;6)O>%]Q=6]T85]U;G-U<'!O<G1E9"<@/3X@(FYO="!S=7!P;W)T960@
M8GD@=&AE(&UA:6P@<V5R=F5R(BP*"2=M;E]?871T86-H7W)E;6]V92<@/3X@
M(E)E;6]V92!A='1A8VAM96YT<R(L"@DG;6Y?7V%T=&%C:%]S96QE8W1?9F]R
M7W)E;6]V92<@/3X@(E-E;&5C="!A='1A8VAM96YT<R!T;R!B92!R96UO=F5D
M+B(L"@DG;6Y?7V-R96%T95]T:71L92<@/3X@(D-R96%T92!M86EL(&YA;64B
M+`H))VUN7U]E9&ET7W1I=&QE)R`]/B`B4')E9F5R96YC97,B+`H))VUN7U]F
M:6QE<U]L:7-T7W1I=&QE)R`]/B`B071T86-H;65N="!&:6QE<R(L"@DG;6Y?
M7V9I;&5S7W)E;6]V92<@/3X@(E)E;6]V92!F:6QE<R!F<F]M(&%T=&%C:&UE
M;G1S(')E<&]S:71O<GDN(%1H:7,@9FEL97,@87)E('!O<W-I8FQY('5S960@
M8GD@875T;W)E<W!O;F1E<G,N(%1H97D@=VEL;"!B92!R96UO=F5D(&9R;VT@
M8F]T:#H@=&AE(')E<&]S:71O<GD@86YD(&%U=&]R97-P;VYD97)S('5S:6YG
M('1H96TN(BP*"2=M;E]?9FEL97-?<V5L96-T7V9O<E]R96UO=F4G(#T^(")3
M96QE8W0@9FEL97,@=&\@8F4@<F5M;W9E9"XB+`H))VUN7U]M86EL7V%L:6%S
M7V9O<FTG(#T^(")-86EL(&%L:6%S(&9O<FTB+`H))VUN7U]M86EL7V%L:6%S
M97-?;&ES="<@/3X@(DUA:6P@86QI87-E<R(L"@DG;6Y?7VUA:6QB;W@G(#T^
M(")-86EL8F]X(&UA;F%G96UE;G0B+`H))VUN7U]R961I<E]R96UO=F4G(#T^
M(")296UO=F4@;65M8F5R<R(L"@DG;6Y?7W)E9&ER7W-E;&5C=%]F;W)?<F5M
M;W9E)R`]/B`B4V5L96-T('1H92!M96UB97)S('1O(&)E(')E;6]V960N(BP*
M"2=M;E]?<F5S<%]R96UO=F4G(#T^(")296UO=F4@;6%I;"!A=71O<F5S<&]N
M9&5R<R(L"@DG;6Y?7W)E<W!?<V5L96-T7V9O<E]R96UO=F4G(#T^(")396QE
M8W0@=&AE(&%U=&]R97-P;VYD97)S('1O(&)E(')E;6]V960N(BP*"2=M;E]?
M<V5L96-T7V9I;&5S7V9O<E]A='1A8V@G(#T^(")396QE8W0@=&AE(&9I;&5S
M('1O(&)E(&%T=&%C:&5D+B(L"@DG;6Y?7W-E;&5C=%]M;E]F;W)?<F5M;W9E
M)R`]/B`B4V5L96-T('1H92!M86EL(&YA;65S('1O(&)E(')E;6]V960N(BP*
M"2=M;E]?=6YA8FQE7V1E9FEN95]M;B<@/3X@(E5N86)L92!T;R!D969I;F4@
M;6%I;"!N86UE<SH@)3$B+`H))VUN7U]U;F%B;&5?<F5M;W9E7VUB;WA?<75O
M=&$G(#T^(")5;F%B;&4@=&\@<F5S970@=&AE(&QI;6ET(&]N(&UA:6QB;W@@
M<VEZ93H@)3$B+`H))VUN7U]U<&QO861?9FEL92<@/3X@(E5P;&]A9"!F:6QE
M(BP*"2=M;E]E9&ET7U]A9&1?;6%I;%]G<F]U<%]M96UB97)S7V]R7W1U<FY?
M;V9F7V)O>"<@/3X@(EEO=2!S:&]U;&0@861D(&$@;6%I;"!G<F]U<"!M96UB
M97(@8F5F;W)E(&5N86)L:6YG('1H92!M86EL(&=R;W5P+B(L"@DG;6Y?961I
M=%]?861D7W)E<W!?;W)?='5R;E]O9F9?8F]X)R`]/B`B66]U('-H;W5L9"!A
M9&0@875T;W)E<W!O;F1E<B!O<B!D97-E;&5C="!T:&4@875T;W)E<W!O;F1E
M<B!C:&5C:V)O>"XB+`H))VUN7V5D:71?7V%T=&%C:&UE;G1S)R`]/B`B071T
M86-H;65N=',B+`H))VUN7V5D:71?7V1O;5]Q=6]T85]L97-S7W1H96Y?<75O
M=&$G(#T^(")4:&4@<VEZ92!O9B!T:&ES(&UA:6QB;W@@;75S="!N;W0@97AC
M965D('1H92!L:6UI="!O;B!A;6]U;G0@;V8@9&ES:R!S<&%C92!A;&QO8V%T
M960@9F]R(&AO=7-I;F<@;6%I;&)O>&5S(&EN('1H:7,@9&]M86EN+B(L"@DG
M;6Y?961I=%]?96YT97)?97AT97)N86Q?<F-P;G1?96UA:6PG(#T^(")%;G1E
M<B!E>'1E<FYA;"!M86EL(&=R;W5P(&UE;6)E<B=S(&4M;6%I;"(L"@DG;6Y?
M961I=%]?96YT97)?;6%I;%]R961I<E]O<E]T=7)N7V]F9E]B;W@G(#T^(")9
M;W4@<VAO=6QD(&5N=&5R(&$@;6%I;"!R961I<F5C="!O<B!D97-E;&5C="!T
M:&4@<F5D:7)E8W0@8VAE8VMB;W@N(BP*"2=M;E]E9&ET7U]E>'1?<F-P;G1?
M96UA:6Q?:6YV86QI9"<@/3X@(D5X=&5R;F%L(')E8VEP:65N="!E+6UA:6P@
M861D<F5S<R!I<R!I;G9A;&ED+B(L"@DG;6Y?961I=%]?9FEL95]E>&ES=',G
M(#T^(")&:6QE(&5X:7-T<RX@3W9E<G=R:71E/R(L"@DG;6Y?961I=%]?9FEL
M97-?9&5L9%]F<F]M7W)E<&]S:71O<GDG(#T^(")4:&5S92!F:6QE<R!W:6QL
M(&)E(&1E;&5T960@9G)O;2!R97!O<VET;W)Y(&%N9"!A=71O<F5S<&]N9&5R
M<R!C;VYT86EN:6YG('1H96TN($1O('EO=2!W86YT('1O('!R;V-E960_(BP*
M"2=M;E]E9&ET7U]M86EL7VYA;64G(#T^(")-86EL(&YA;64B+`H))VUN7V5D
M:71?7VUA:6Q?;F%M95]I;G9A;&ED)R`]/B`B36%I;"!N86UE(&ES(&EN=F%L
M:60N(BP*"2=M;E]E9&ET7U]M86EL7W)E9&ER)R`]/B`B36%I;"!R961I<F5C
M=',B+`H))VUN7V5D:71?7VUA:6Q?<F5D:7)?861D)R`]/B`B061D($UA:6P@
M1W)O=7`@365M8F5R(BP*"2=M;E]E9&ET7U]M86EL7W)E<W!S)R`]/B`B36%I
M;"!A=71O<F5S<&]N9&5R<R(L"@DG;6Y?961I=%]?;6%I;&)O>"<@/3X@(DUA
M:6QB;W@B+`H))VUN7V5D:71?7VUA:6QG<F]U<"<@/3X@(DUA:6P@9W)O=7`B
M+`H))VUN7V5D:71?7VUA:6QG<F]U<%]A9&1R97-S97,G(#T^(")-86EL(&=R
M;W5P(&UE;6)E<G,B+`H))VUN7V5D:71?7VUA:6QG<F]U<%]D:7-A8FQE9"<@
M/3X@(D%V86EL86)L92!O;FQY('=H96X@;6%I;"!N86UE(&ES(&%L<F5A9'D@
M861D960B+`H))VUN7V5D:71?7VUA>%]D;VU?<75O=&$G(#T^(")$969A=6QT
M(&9O<B!T:&4@9&]M86EN("@E,2DB+`H))VUN7V5D:71?7VUB;WA?<75O=&%?
M:6YV86QI9"<@/3X@(DEC;W)R96-T(&UA:6QB;W@@<VEZ92!S<&5C:69I960N
M(BP*"2=M;E]E9&ET7U]N97=?<F5S<%]N86UE)R`]/B`B3F5W(&%U=&]R97-P
M;VYD97(@;F%M92(L"@DG;6Y?961I=%]?;F]?875T;W)E<W!O;F1E<G,G(#T^
M(")9;W4@<VAO=6QD(&%D9"!A="!L96%S="!O;F4@875T;W)E<W!O;F1E<B!B
M969O<F4@='5R;FEN9R!T:&4@875T;W)E<W!O;F1E<B!S97)V:6-E(&]N+V]F
M9BXB+`H))VUN7V5D:71?7VYO7V9I;&5?<V5L)R`]/B`B3F\@9FEL97,@<V5L
M96-T960N(BP*"2=M;E]E9&ET7U]N;U]M86EL7V%D9')E<W-E<R<@/3X@(DYO
M(&4M;6%I;"!A9&1R97-S97,@:&%V92!B965N(&5N=&5R960@;W(@<V5L96-T
M960N(BP*"2=M;E]E9&ET7U]N;VYE)R`]/B`B3F]N92(L"@DG;6Y?961I=%]?
M;F]T7V-R96%T95]P87-S)R`]/B`B5&AI<R!W:6QL(&YO="!C<F5A=&4@82!P
M87-S=V]R9"!F;W(@=&AI<R!A8V-O=6YT+EQN5VET:&]U="!P87-S=V]R9"P@
M=7-E<B!W:6QL(&YO="!B92!A8FQE('1O('9I97<@86YD+V]R('-E;F0@;6%I
M;"XB+`H))VUN7V5D:71?7W)E9&ER7V5M86EL7VEN=F%L:60G(#T^(")2961I
M<F5C="!E+6UA:6P@861D<F5S<R!I<R!I;G9A;&ED+B(L"@DG;6Y?961I=%]?
M<F5D:7)E8W0G(#T^(")2961I<F5C="(L"@DG;6Y?961I=%]?<F5D:7)E8W1?
M861D<B<@/3X@(E)E9&ER96-T(&%D9')E<W,B+`H))VUN7V5D:71?7W)E;6]V
M95]A=71O<F5S<#\G(#T^(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M
M;W9E('1H92!A=71O<F5S<&]N9&5R/R(L"@DG;6Y?961I=%]?<F5M;W9E7W)C
M<&YT<S\G(#T^(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H
M97-E(')E8VEP:65N=',_(BP*"2=M;E]E9&ET7U]R97!O<VET;W)Y)R`]/B`B
M4F5P;W-I=&]R>2(L"@DG;6Y?961I=%]?<F5S<'-?871T86-H)R`]/B`B075T
M;W)E<W!O;F1E<B!A='1A8VAM96YT(&9I;&5S(BP*"2=M;E]E9&ET7U]S96QE
M8W1?<F-P;G1?9G)O;5]L:7-T)R`]/B`B4V5L96-T(&%T(&QE87-T(&]N92!R
M96-I<&EE;G0@9G)O;2!T:&4@;&ES="!T;R!R96UO=F4@:70N(BP*"2=M;E]E
M9&ET7U]S96QE8W1?<F5G:7-T97)E9%]U<V5R<R<@/3X@(E-E;&5C="!R96=I
M<W1E<F5D('5S97)S(BP*"2=M;E]E9&ET7U]S96QE8W1E9%]P;W-T8F]X7VAA
M=F5?;F]T7W-E='5P7W!A<W-W9"<@/3X@(EEO=2!H879E(&-H;W-E;B!T;R!H
M879E(&$@;6%I;&)O>"!B=70@:&%V92!N;W0@<V5T('5P('1H92!P87-S=V]R
M9"!F;W(@:70N(BP*"2=M;E]E9&ET7U]U;F%B;&5?86-T7V1E86-T7VUA:6Q?
M9W)O=7`G(#T^(")5;F%B;&4@=&\@86-T:79A=&4O9&5A8W1I=F%T92!M86EL
M(&=R;W5P.B`E,2(L"@DG;6Y?961I=%]?=6YA8FQE7V%C=%]D96%C=%]M86EL
M7W)E9&ER)R`]/B`B56YA8FQE('1O(&%C=&EV871E+V1E86-T:79A=&4@;6%I
M;"!R961I<F5C=#H@)3$B+`H))VUN7V5D:71?7W5N86)L95]A8W1?9&5A8W1?
M<&]S=&)O>"<@/3X@(E5N86)L92!T;R!A8W1I=F%T92]D96%C=&EV871E(&UA
M:6QB;W@Z("4Q(BP*"2=M;E]E9&ET7U]U;F%B;&5?86-T7V1E86-T7W)E<W`G
M(#T^(")5;F%B;&4@=&\@86-T:79A=&4O9&5A8W1I=F%T92!A=71O<F5S<&]N
M9&5R<SH@)3$B+`H))VUN7V5D:71?7W5N86)L95]A9&1?871T86-H)R`]/B`B
M56YA8FQE('1O(&%D9"!A='1A8VAM96YT(&9I;&4Z("4Q(BP*"2=M;E]E9&ET
M7U]U;F%B;&5?861D7VUA:6Q?9W)O=7!?;65M8F5R)R`]/B`B56YA8FQE('1O
M(&%D9"!M86EL(&=R;W5P(&UE;6)E<CH@)3$B+`H))VUN7V5D:71?7W5N86)L
M95]A9&1?<F5S<"<@/3X@(E5N86)L92!T;R!A9&0@875T;W)E<W!O;F1E<CH@
M)3$B+`H))VUN7V5D:71?7W5N86)L95]C:&%N9V5?;6%I;%]N86UE)R`]/B`B
M56YA8FQE('1O(&-H86YG92!M86EL(&YA;64Z("4Q(BP*"2=M;E]E9&ET7U]U
M;F%B;&5?9&5A8W1I=F%T95]M86EL7V=R;W5P)R`]/B`B56YA8FQE('1O(&1E
M86-T:79A=&4@;6%I;"!G<F]U<#H@)3$B+`H))VUN7V5D:71?7W5N86)L95]D
M96%C=&EV871E7W)E<W`G(#T^(")5;F%B;&4@=&\@9&5A8W1I=F%T92!M86EL
M(&%U=&]R97-P;VYD97)S.B`E,2(L"@DG;6Y?961I=%]?=6YA8FQE7V1E9FEN
M95]R97-P7VED)R`]/B`B56YA8FQE('1O(&1E9FEN92!A=71O<F5S<&]N9&5R
M(&ED.B`E,2(L"@DG;6Y?961I=%]?=6YA8FQE7W)E;6]V95]A='1A8V@G(#T^
M(")5;F%B;&4@=&\@<F5M;W9E(&%T=&%C:&UE;G0@9FEL92AS*3H@)3$B+`H)
M)VUN7V5D:71?7W5N86)L95]R96UO=F5?875T;W)E<W`G(#T^(")5;F%B;&4@
M=&\@<F5M;W9E(&%U=&]R97-P;VYD97(Z("4Q(BP*"2=M;E]E9&ET7U]U;F%B
M;&5?<F5M;W9E7VUA:6Q?9W)O=7!?;65M8F5R)R`]/B`B56YA8FQE('1O(')E
M;6]V92!M86EL(&=R;W5P(&UE;6)E<G,Z("4Q(BP*"2=M;E]E9&ET7U]U;F%B
M;&5?<V5T=7!?;6%I;%]R961I<B<@/3X@(E5N86)L92!T;R!S970@=7`@;6%I
M;"!R961I<F5C="!A9&1R97-S.B`E,2(L"@DG;6Y?961I=%]?=W)O;F=?=V%Y
M)PD)"3T^("=4:&4@;65S<V%G97,@861D<F5S<V5D('1O("4Q('=I;&P@;F]T
M(&)E(&1E;&EV97)E9"P@87,@=&AE(&UA:6P@;F%M92!I<R!N96ET:&5R(&$@
M;6%I;&)O>"P@;F]R(')E9&ER96-T+"!M86EL(&=R;W5P+"!O<B!A=71O<F5S
M<&]N9&5R+B<L"@DG;6Y?;&ES=%]?;6%I;%]N86UE<U]F;W)?9&]M86EN)R`]
M/B`B36%I;"!N86UE<R!F;W(@9&]M86EN("4Q(BP*"2=M;E]L:7-T7U]S85]C
M86YN;W1?=6YA8FQE)R`]/B`B0V%N;F]T(&5N86)L92!S<&%M(&9I;'1E<FEN
M9R(L"@DG;6Y?;&ES=%]?=&%B7V-P7V%C8V5S<R<@/3X@(DPB+`H))VUN7VQI
M<W1?7W1A8E]T:71L95]C;&EE;G0G(#T^("=#;&EE;G0G+`H))VUN7VQI<W1?
M7W1A8E]T:71L95]D;VUA:6XG(#T^("=$;VUA:6XG+`H))VUN7VQI<W1?7W1A
M8E]T:71L95]A=71O<F5S<"<@/3X@(D$B+`H))VUN7VQI<W1?7W1A8E]T:71L
M95]B;W@G(#T^(")"(BP*"2=M;E]L:7-T7U]T86)?=&ET;&5?9W)O=7`G(#T^
M(")'(BP*"2=M;E]L:7-T7U]T86)?=&ET;&5?;F%M92<@/3X@(DYA;64B+`H)
M)VUN7VQI<W1?7W1A8E]T:71L95]R961I<F5C="<@/3X@(E(B+`H))VUN7VQI
M<W1?7W1A8E]T:71L95]S<&%M9FEL=&5R)R`]/B`B4R(L"@DG;6Y?;&ES=%]?
M=&%B7W1I=&QE7V1R=V5B)R`]/B`G058G+`H))VUN7VQI<W1?7W5N86)L95]R
M96UO=F5?;6YS)R`]/B`B56YA8FQE('1O(')E;6]V92!T:&4@;6%I;"!N86UE
M<SH@)3$B+`H*"2=M;V1S7VUA;F%G7U]T:71L92<)"0D)/3X@)TUO9'5L97,@
M;6%N86=E;65N="<L"@DG;6]D<U]M86YA9U]?96UP='E?<V5L96-T:6]N7V9O
M<E]R96UO=F4G(#T^("=396QE8W0@=&AE(&UO9'5L97,@=&\@8F4@<F5M;W9E
M9"XG+`H))VUO9'-?;6%N86=?7V-A;E]N;W1?<F5M;W9E)PD]/B`G56YA8FQE
M('1O(')E;6]V92!M;V1U;&4@)3$Z("4R)RP*"2=M;V1S7W)E;6]V95]?=&ET
M;&4G"0D)/3X@)TUO9'5L92!R96UO=F%L)RP*"2=M;V1U;&5?=7!L;V%D7U]T
M:71L92<@/3X@)U5P;&]A9"!.97<@36]D=6QE)RP*"2=M;V1U;&5?=7!L;V%D
M7U]F:6QE7VYA;64G"3T^("=0871H('1O('1H92!M;V1U;&4@<&%C:V%G92!F
M:6QE)RP*"2=M;V1U;&5?=7!L;V%D7U]M;V1U;&5?=V%S7VEN<W1A;&QE9"<@
M/3X@)U1H:7,@;6]D=6QE(&ES(&%L<F5A9'D@:6YS=&%L;&5D+B!)9B!Y;W4@
M=VES:"!T;R!I;G-T86QL(&$@;F5W97(@=F5R<VEO;B!O9B!T:&ES(&UO9'5L
M92P@<&QE87-E(&1E:6YS=&%L;"!T:&4@;6]D=6QE('1H<F]U9V@@=&AE(&-O
M;G1R;VP@<&%N96PL(&%N9"!T:&5N('1R>2!I;G-T86QL:6YG+B<L"@DG;6]D
M=6QE7W5P;&]A9%]?=6YA8FQE7W1O7VEN<W1A;&PG"3T^("=5;F%B;&4@=&\@
M:6YS=&%L;"!T:&4@;6]D=6QE('!A8VMA9V4@9FEL92<L"@H))VUP8U]?=6YA
M8FQE7V)U>5]C97)T7W5N86)L95]G96YE<F%T95]C<W(G(#T^(")5;F%B;&4@
M=&\@<'5R8VAA<V4@82!C97)T:69I8V%T93H@=6YA8FQE('1O(&=E;F5R871E
M('1H92!#4U(Z("4Q(BP*"2=M<&-?7W5N86)L95]B=7E?8V5R=%]U;F%B;&5?
M<W1O<F5?<')I=F%T95]K97DG(#T^(")5;F%B;&4@=&\@<'5R8VAA<V4@82!C
M97)T:69I8V%T93H@=6YA8FQE('1O('-T;W)E('1H92!P<FEV871E(&ME>3H@
M)3$B+`H))VYE=W-?87)T:6-L97-?=&ET;&4G(#T^("=0;&5S:R!.97=S)RP*
M"2=N879?7V-U<W1O;5]B=71T;VYS)R`]/B`G0W5S=&]M)RP*"2=N879?7V=E
M;F5R86PG(#T^("='96YE<F%L)RP*"2=N879?7W-Y<W1E;2<@/3X@)U-Y<W1E
M;2<L"@DG;F%V7U]H96QP7V%N9%]S=7!P;W)T)R`]/B`G2&5L<"`F(%-U<'!O
M<G0G+`H))VYO7W!S85]M86EL<U]M871C:&5D)R`]/B`B3F\@;6%I;"!A8V-O
M=6YT<R!M871C:&EN9R!Y;W5R(&-R:71E<FEA(BP*"2=N;W1I9FEC871I;VY?
M=&5X=%]?:6YV86QI9%]T97AT7VQE;F=T:"<@/3X@(DEN=F%L:60@;F]T:6-E
M('1E>'0@;&5N9W1H+B!3:&]U;&0@8F4@9G)O;2`Q('1O(#8U-3,S(&-H87)A
M8W1E<G,N(BP*"2=N;W1I9FEC871I;VY?=&5X=%]?=&5X="<@/3X@(DYO=&EC
M92!T97AT(BP*"2=N;W1I9FEC871I;VY?=&5X=%]?=&ET;&4G(#T^(")%9&ET
M(&YO=&EC92(L"@DG;F]T:69I8V%T:6]N7W1E>'1?7W5N86)L95]S971?=&5X
M="<@/3X@(E5N86)L92!T;R!M;V1I9GD@;F]T:6-E('1E>'0Z("(L"@DG;F]T
M:69I8V%T:6]N<U]?=6YA8FQE7W1O7W5P9&%T92<@/3X@(E5N86)L92!T;R!U
M<&1A=&4@;F]T:69I8V%T:6]N.B`E,2(L"@DG;V1B8U]?8V%N=%]A9&1?9'-N
M)R`]/B`B56YA8FQE('1O(&%D9"!$4TX@)3$Z("4R(BP*"2=O9&)C7U]C86YT
M7V)U:6QD7V-O;FYE8W1I;VY?<W1R:6YG)R`]/B`B56YA8FQE('1O(&-O;FYE
M8W0@=7-I;F<@=&AE('!A<F%M971E<G,@<W!E8VEF:65D+"!P;&5A<V4@=')Y
M(&%G86EN('5S:6YG(&1I9F9E<F5N="!P87)A;65T97)S+B!5=&EL:71Y(&AA
M<R!R971U<FYE9#H@)3$B+`H))V]D8F-?7V-A;G1?8V]N;F5C="<@/3X@(E5N
M86)L92!T;R!C;VYN96-T('1O('1H92!D871A('-O=7)C92!U<VEN9R!T:&4@
M9&5F:6YE9"!S971T:6YG<RX@4V5R=F5R(&AA<R!R971U<FYE9#H@)3$B+`H)
M)V]D8F-?7V-A;G1?9&5L971E7V1S;B<@/3X@(E5N86)L92!T;R!D96QE=&4@
M1%-.("4Q.B`E,B(L"@DG;V1B8U]?8V%N=%]G971?9')I=F5R<R<@/3X@(E5N
M86)L92!T;R!R971R:65V92!A(&QI<W0@;V8@3T1"0R!D<FEV97)S.B`E,2(L
M"@DG;V1B8U]?8V%N=%]G971?;&ES="<@/3X@(E5N86)L92!T;R!R971R:65V
M92!A(&QI<W0@;V8@97AI<W1I;F<@1%-.<SH@)3$B+`H))V]D8F-?7V-A;G1?
M<&%R<V5?<W1R:6YG)R`]/B`B56YA8FQE('1O('!A<G-E('1H92!C;VYN96-T
M:6]N('-T<FEN9R(L"@DG;V1B8U]?8V]N;F5C=%]S=6-C97-S)R`]/B`B0V]N
M;F5C=&EO;B!S=6-C97-S9G5L(BP*"2=O9&)C7U]D<FEV97)?;F]T7W-E="<@
M/3X@(D1R:79E<B!I<R!N;W0@<V5T(BP*"2=O9&)C7U]D<FEV97)?;W)?;F%M
M95]N;W1?<V5T)R`]/B`B1')I=F5R(&]R(&YA;64@;V8@=&AE($]$0D,@8V]N
M;F5C=&EO;B!W97)E(&YO="!S970B+`H))V]D8F-?7V1S;E]A;')E861Y7V5X
M:7-T<R<@/3X@(D133B!W:71H('1H:7,@;F%M92`H)3$I(&%L<F5A9'D@97AI
M<W1S(&EN('1H92!S>7-T96TB+`H))V]D8F-?7V1S;E]N;W1?97AI<W1S)R`]
M/B`B5&AI<R!$4TX@9&]E<R!N;W0@97AI<W0B+`H))V]D8F-?7V5N=&5R7V-O
M;FYE8W1I;VY?<&%R86US)R`]/B`B66]U('-H;W5L9"!S<&5C:69Y('1H92!O
M<'1I;VYS('1O(&)E('5S960@8GD@=&AE(&1R:79E<BX@069T97(@>6]U(&AA
M=F4@<W5P<&QI960@86QL('1H92!R97%U:7)E9"!D871A+"!Y;W4@=VEL;"!N
M965D('1O(&-L:6-K($9I;FES:"!I;B!O<F1E<B!T;R!C;VUP;&5T92!T:&4@
M3T1"0R!$4TX@8V]N9FEG=7)A=&EO;BXB+`H))V]D8F-?7V5N=&5R7V1S;E]N
M86UE)R`]/B`B16YT97(@1%-.(&YA;64B+`H))V]D8F-?7VEN=F%L:61?9'-N
M7VYA;64G(#T^(")7<F]N9R!S>6YT87@@9F]R($]$0D,@8V]N;F5C=&EO;B!N
M86UE("@E,2DZ('!L96%S92!U<V4@;VYL>2!A;'!H86YU;65R:6,@<WEM8F]L
M<RXB+`H))V]D8F-?7VYO7W-U8VA?9')I=F5R)R`]/B`B3T1"0R!D<FEV97(@
M=VET:"!S=6-H(&YA;64@*"4Q*2!I<R!N;W0@<W5P<&]R=&5D(BP*"2=O9&)C
M7U]R96UO=F5?<&%G95]T:71L92<@/3X@(E1H92!F;VQL;W=I;F<@3T1"0R!$
M4TX@8V]N;F5C=&EO;G,@=VEL;"!B92!R96UO=F5D.B(L"@DG;V1B8U]?<V5L
M96-T7V1S;E]T;U]R96UO=F4G(#T^(")396QE8W0@1%-.<R!T;R!B92!R96UO
M=F5D+B(L"@DG;V1B8U]A9&1?;F5W)R`]/B`B061D(&YE=R!$4TX@8V]N;F5C
M=&EO;B(L"@DG;V1B8U]D<FEV97(G(#T^(")$<FEV97(B+`H))V]D8F-?9'-N
M7V1E<V-R:7!T:6]N)R`]/B`B0V]N;F5C=&EO;B!D97-C<FEP=&EO;B(L"@DG
M;V1B8U]D<VY?;&ES="<@/3X@(D]$0D,@1%-.(&-O;FYE8W1I;VYS(BP*"2=O
M9&)C7V1S;E]N86UE)R`]/B`B0V]N;F5C=&EO;B!N86UE(BP*"2=O9&)C7V1S
M;E]S>7-T96TG(#T^(")3>7-T96T@1%-.(BP*"2=O9&)C7V1S;E]T97AT)R`]
M/B`B3T1"0R!$4TXB+`H))V]D8F-?<F5Q7V9I96QD7VYO=%]S970G(#T^(")2
M97%U:7)E9"!P87)A;65T97)S(&%R92!N;W0@<W5P<&QI960N(BP*"2=P8E]?
M86QI87-E<R<@/3X@(D%L:6%S97,B+`H))W!B7U]A;F]N9G1P)R`]/B`B06YO
M;GEM;W5S($944"(L"@DG<&)?7V%U=&]I;G-T86QL97)?<F5L96%S97,G(#T^
M("=5<&1A=&5R)RP*"2=P8E]?8V5R="<@/3X@(D-E<G1I9FEC871E<R(L"@DG
M<&)?7V-L7W!O;VPG(#T^("))4"!A9&1R97-S97,B+`H))W!B7U]C;%]P;V]L
M7V-T<FPG(#T^("(E,2(L"@DG<&)?7V-L7W!R968G(#T^(")0<F5F97)E;F-E
M<R(L"@DG<&)?7V-L7W)P="<@/3X@(E)E<&]R="(L"@DG<&)?7V-L7W)P=%]L
M:7-T)R`]/B`B0W5S=&]M:7IE(BP*"2=P8E]?8VQ?=&5M<&QA=&5S)R`]/B`B
M0VQI96YT('1E;7!L871E<R(L"@DG<&)?7V-L7W1R869F:6,G(#T^(")4<F%F
M9FEC(BP*"2=P8E]?8VQ?=')A9F9I8U]H:7-T;W)Y)R`]/B`B5')A9F9I8R!H
M:7-T;W)Y(BP*"2=P8E]?8VQ?=')A9F9I8U]O9B<@/3X@(E1R869F:6,@;V8@
M)3$B+`H))W!B7U]C;&EE;G0G(#T^("(E,2(L"@DG<&)?7V-L:65N=',G(#T^
M(")#;&EE;G1S(BP*"2=P8E]?8V]M<%]I;F9O)R`]/B`B0V]M<&]N96YT(&EN
M9F\B+`H))W!B7U]C;VUM;VY?86-L)R`]/B`G06QL;W<@5')A;G-F97(@04-,
M)RP*"2=P8E]?8W!?86-C97-S)R`]/B`B06-C97-S(BP*"2=P8E]?8W)O;G1A
M8B<@/3X@(E-C:&5D=6QE<B(L"@DG<&)?7V-U<W1O;5]B=71T;VYS)R`]/B`B
M0W5S=&]M($)U='1O;G,B+`H))W!B7U]D8B<@/3X@(D1A=&%B87-E<R(L"@DG
M<&)?7V1B7V5D:70G(#T^("(E,2(L"@DG<&)?7V1B7W-E<G9E<E]E9&ET)R`]
M/B`G)3$G+`H))W!B7U]D8E]S97)V97)S)R`]/B`G1&%T86)A<V4@<V5R=F5R
M<R<L"@DG<&)?7V1L7W5S<E]E9"<@/3X@(D1O;6%I;B!A9&UI;FES=')A=&]R
M(BP*"2=P8E]?9&YS)R`]/B`B1$Y3(BP*"2=P8E]?9&YS7W1E;7!L871E)R`]
M/B`B1$Y3(BP*"2=P8E]?9&YS7W0G(#T^(")$3E,B+`H))W!B7U]D;VU?8W1R
M;"<@/3X@(B4Q(BP*"2=P8E]?9&]M7VQI;2<@/3X@(D1O;6%I;B!L:6UI=',B
M+`H))W!B7U]D;VU?<')E9B<@/3X@(E!R969E<F5N8V5S(BP*"2=P8E]?9&]M
M7W-U;5]R97!O<G0G(#T^(")$;VUA:6X@4W5M;6%R>2!297!O<G0B+`H))W!B
M7U]D;VU?=&5M<&QA=&5S)R`]/B`B1&]M86EN(%1E;7!L871E<R(L"@DG<&)?
M7V1O;5]T<F%F9FEC)R`]/B`B5')A9F9I8R!O9B`E,2(L"@DG<&)?7V1O;5]T
M<F%F9FEC7VAI<W1O<GDG(#T^(")4<F%F9FEC($AI<W1O<GDB+`H))W!B7U]D
M;VUA:6YS)R`]/B`B1&]M86EN<R(L"@DG<&)?7V1U;7!S7VQI<W0G(#T^(")"
M86-K=7`@1FEL97,@4F5P;W-I=&]R>2(L"@DG<&)?7V5V96YT7VAA;F1L97)S
M)R`]/B`G179E;G0@;6%N86=E<B<L"@DG<&)?7V9O<G=A<F1I;F=?<V5T=7`G
M(#T^(")&;W)W87)D:6YG(%-E='5P(BP*"2=P8E]?9FEL96UA;F%G97(G(#T^
M(")&:6QE($UA;F%G97(B+`H))W!B7U]G;&]B86QC:&%N9V5S)R`]/B`B1W)O
M=7`@3W!E<F%T:6]N<R(L"@DG<&)?7VEP7V%L:6%S:6YG)R`]/B`B25`@061D
M<F5S<V5S(BP*"2=P8E]?:7!?9&]M86EN<R<@/3X@(D1O;6%I;G,B+`H))W!B
M7U]I<%]C;&EE;G1S)R`]/B`B25`@061D<F5S<V5S(')E;6]V86PB+`H))W!B
M7U]L:6-E;G-E7VUA;F%G96UE;G0G(#T^("=,:6-E;G-E($UA;F%G96UE;G0G
M+`H))W!B7U]L;V-A;&5S)R`]/B`G3&]C86QE<R<L"@DG<&)?7VQO9U]F:6QE
M<R<@/3X@(DQO9R!F:6QE<R(L"@DG<&)?7VUA:6PG(#T^("=-86EL)RP*"2=P
M8E]?;6%I;%]B;&]C:V5D7V1O;6%I;G,G(#T^("=";&%C:R!L:7-T)RP*"2=P
M8E]?;6%I;%]N86UE7V9I;&5S)R`]/B`B071T86-H;65N="!F:6QE<R(L"@DG
M<&)?7VUA:6Q?;F%M95]E9&ET)R`]/B`B)3$B+`H))W!B7U]M86EL7VYA;65?
M;6%I;%]G<F]U<"<@/3X@(DUA:6P@9W)O=7`B+`H))W!B7U]M86EL7VYA;65?
M<F5D:7)E8W1S)R`]/B`B4F5D:7)E8W1S(BP*"2=P8E]?;6%I;%]N86UE7W)E
M<W!?871T86-H7V%D9"<@/3X@(DYE=R!A='1A8VAM96YT(BP*"2=P8E]?;6%I
M;%]N86UE7W)E<W!?961I="<@/3X@(B4Q(BP*"2=P8E]?;6%I;%]N86UE7W)E
M<W!O;F1E<G,G(#T^(")!=71O<F5S<&]N9&5R<R(L"@DG<&)?7VUA:6Q?;F%M
M97,G(#T^(")-86EL(BP*"2=P8E]?;6%I;%]W:&ET95]L:7-T)R`]/B`G5VAI
M=&4@;&ES="<L"@DG<&)?7VUA:6QL:7-T<R<@/3X@(DUA:6QI;F<@;&ES=',B
M+`H))W!B7U]M;V1U;&5S)R`]/B`G36]D=6QE<R<L"@DG<&)?7VUO9'5L97-?
M;6%N86=E;65N="<@/3X@)TUA;F%G92!-;V1U;&5S)RP*"2=P8E]?;F]T:69I
M8V%T:6]N<R<@/3X@(DYO=&EF:6-A=&EO;G,B+`H))W!B7U]O9&)C)R`]/B`B
M3T1"0R(L"@DG<&)?7W!H;W-T:6YG7W-E='5P)R`]/B`B4&AY<VEC86P@:&]S
M=&EN9R!S971U<"(L"@DG<&)?7W!R=&1?9&ER<R<@/3X@(E!R;W1E8W1E9"!D
M:7)E8W1O<FEE<R(L"@DG<&)?7W!R=&1I<E]E9&ET)R`]/B`B)3$B+`H))W!B
M7U]R97!O<G0G(#T^(")297!O<G0B+`H))W!B7U]R97!O<G1?875T;R<@/3X@
M(D1E;&EV97)Y('-C:&5D=6QE(&9O<B`E,2(L"@DG<&)?7W)E<&]R=%]L:7-T
M)R`]/B`B0W5S=&]M:7IE(BP*"2=P8E]?<V5R=F5R)R`]/B`B4V5R=F5R(BP*
M"2=P8E]?<V5R=F5R7VEN9F\G(#T^(")3;&%V92!S97)V97(@:6YF;W)M871I
M;VXB+`H))W!B7U]S97)V97)?=')A9F9I8R<@/3X@(E-E<G9E<B!T<F%F9FEC
M(BP*"2=P8E]?<V5R=F5R<U]L:7-T)R`]/B`B4VQA=F4@<V5R=F5R(&%C8V]U
M;G1S(BP*"2=P8E]?<V5S<VEO;G,G(#T^(")397-S:6]N<R(L"@DG<&)?7W-A
M<'!?<&]O;"<@/3X@(D%P<&QI8V%T:6]N(%!O;VPB+`H))W!B7U]S:71E87!P
M7VEN<W1A;&PG(#T^(")3:71E($%P<&QI8V%T:6]N($EN<W1A;&QA=&EO;B(L
M"@DG<&)?7W-I=&5?87!P7W!K9W,G(#T^(")3:71E($%P<&QI8V%T:6]N(%!A
M8VMA9V5S(BP*"2=P8E]?<VET95]A<'!S)R`]/B`B4VET92!!<'!L:6-A=&EO
M;G,B+`H))W!B7U]A9&1I=&EO;F%L7VME>5]I;F9O)R`]/B`G2V5Y(%!R;W!E
M<G1I97,G+`H))W!B7U]A9&1I=&EO;F%L7VME>5]P<F]P97)T:65S)R`]/B`G
M2V5Y(%!R;W!E<G1I97,G+`H))W!B7U]S:V5L971O;B<@/3X@(E-K96QE=&]N
M($UA;F%G96UE;G0B+`H))W!B7U]S:VEN<R<@/3X@)U-K:6YS)RP*"2=P8E]?
M<VMI;E]I;F9O)R`]/B`G)3$G+`H))W!B7U]S<&%M87-S87-S:6XG(#T^(")3
M<&%M07-S87-S:6XB+`H))W!B7U]S=&%T:7-T:6-S)R`]/B`B4W1A=&ES=&EC
M<R(L"@DG<&)?7W-U8F1O;6%I;G,G(#T^(")3=6)D;VUA:6YS(BP*"2=P8E]?
M=&5M<&QA=&5S)R`]/B`B5&5M<&QA=&5S(BP*"2=P8E]?=&EC:V5T<R<@/3X@
M(E1I8VME=',B+`H))W!B7U]T=',G(#T^(")4:6-K971S(BP*"2=P8E]?=V5B
M7V%P<',G(#T^(")4;VUC870B+`H))W!B7U]W96)?=7-E<G,G(#T^(")796(@
M=7-E<G,B+`H))W!B7U]W96)A;&EZ97)?<')E9F5R96YC97,G(#T^("=796(@
M4W1A=&ES=&EC<R!0<F5F97)E;F-E<R<L"@DG<&1I<E]?96YT97)?9&ER7VYA
M;64G(#T^(")%;G1E<B!D:7)E8W1O<GD@;F%M92XB+`H))W!D:7)?7VEN=F%L
M:61?:'-T)R`]/B`B2&]S=&EN9R!T>7!E(&ES(&EN=F%L:60N($UU<W0@8F4@
M<&AY<VEC86PN(BP*"2=P9&ER7U]P9%]I9%]I<U]U;F1E9FEN960G(#T^(")0
M<F]T96-T960@9&ER96-T;W)Y(&ED(&ES('5N9&5F:6YE9"XB+`H))W!D:7)?
M7W!D:7)?97AI<W0G(#T^(")$:7)E8W1O<GD@=VET:"!T:&ES(&YA;64@:7,@
M86QR96%D>2!P<F]T96-T960N(BP*"2=P9&ER7U]P9&ER7VYO=%]E>&ES="<@
M/3X@(E!R;W1E8W1E9"!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(BP*"2=P
M9&ER7U]P9&ER7W5S<E]N;W1?97AI<W0G(#T^(")0<F]T96-T960@9&ER96-T
M;W)Y('5S97(@9&]E<R!N;W0@97AI<W0N(BP*"2=P9&ER7U]P<F1I<G-?9F]R
M7V1O;6%I;B<@/3X@(E!R;W1E8W1E9"!D:7)E8W1O<FEE<R!F;W(@9&]M86EN
M("4Q(BP*"2=P9&ER7U]R96UO=F5?<&1I<E]U<W)S)R`]/B`B5&AE(&9O;&QO
M=VEN9R!U<V5R<R!O9B!P<F]T96-T960@9&ER96-T;W)Y("4R(&EN(&1O;6%I
M;B`E,2!W:6QL(&)E(')E;6]V960Z(BP*"2=P9&ER7U]R96UO=F5?<&1I<G-?
M;VY?9&]M)R`]/B`B5&AI<R!O<&5R871I;VX@=VEL;"!R97-U;'0@:6X@<F5M
M;W9I;F<@<')O=&5C=&EO;B!F<F]M('1H92!D:7)E8W1O<FEE<R!O9B!D;VUA
M:6X@)3(@;W=N960@8GD@8VQI96YT("4Q+"!T:&4@9&ER96-T;W)I97,@=&AE
M;7-E;'9E<R!W:6QL(&YO="!B92!E<F%S960N(BP*"2=P9&ER7U]S96QE8W1?
M<&1I<E]U<W)S7V9O<E]R96UO=F4G(#T^(")396QE8W0@=&AE('!R;W1E8W1E
M9"!D:7)E8W1O<GD@=7-E<G,@=&\@8F4@<F5M;W9E9"XB+`H))W!D:7)?7W-E
M;&5C=%]P9&ER<U]T;U]R96UO=F4G(#T^(")396QE8W0@=&AE(&1I<F5C=&]R
M:65S('1O(')E;6]V92!P<F]T96-T:6]N(&9R;VTN(BP*"2=P9&ER7U]U;F%B
M;&5?9&5F:6YE7W!D:7)?=7-E<G,G(#T^(")5;F%B;&4@=&\@9&5F:6YE('1H
M92!P<F]T96-T960@9&ER96-T;W)Y('5S97)S+B(L"@DG<&1I<E]?=6YA8FQE
M7V1E9FEN95]P9&ER<U]P<F]P97)T:65S)R`]/B`B56YA8FQE('1O('-E="!T
M:&4@<')O=&5C=&5D(&1I<F5C=&]R:65S)R!P<F]P97)T:65S.B`E,2(L"@DG
M<&1I<E]?=6YA8FQE7W-E;&5C=%]D;VU?<&%R86TG(#T^(")5;F%B;&4@=&\@
M<V5L96-T(&1O;6%I;B!P87)A;65T97)S.B`E,2(L"@DG<&1I<E]E9%]?8W)E
M871E7W!D:7)?9F]R7V1O;6%I;B<@/3X@(D-R96%T92!N97<@<')O=&5C=&5D
M(&1I<F5C=&]R>2!O;B!D;VUA:6X@)3$B+`H))W!D:7)?961?7V1I<E]A;')E
M861Y7W!R;W1E8W0G(#T^(")4:&ES(&1I<F5C=&]R>2!I<R!A;')E861Y('!R
M;W1E8W1E9"XB+`H))W!D:7)?961?7VAE861?='AT)R`]/B`B2&5A9&5R(%1E
M>'0B+`H))W!D:7)?961?7VEN=F%L:61?;&]G:6XG(#T^(")5<V5R(&YA;64@
M:7,@:6YV86QI9"XB+`H))W!D:7)?961?7VQO9VEN7V5X:7-T<R<@/3X@(E-U
M8V@@=7-E<B!A;')E861Y(&5X:7-T<RX@5')Y(&%N;W1H97(@;&]G:6X@;F%M
M92XB+`H))W!D:7)?961?7VYE=U]U<W(G(#T^(").97<@=7-E<B(L"@DG<&1I
M<E]E9%]?;F]N7W-S;"<@/3X@(DYO;BU34TPB+`H))W!D:7)?961?7V-G:5]B
M:6XG(#T^(")C9VDM8FEN(BP*"2=P9&ER7V5D7U]P871H)R`]/B`B1&ER96-T
M;W)Y(&YA;64B+`H))W!D:7)?961?7W!D:7)?9F]R7V1O;6%I;B<@/3X@(E!R
M;W1E8W1E9"!D:7)E8W1O<GD@)3$@;VX@9&]M86EN("4R(BP*"2=P9&ER7V5D
M7U]P9&ER7VQO8V%T:6]N)R`]/B`B1&ER96-T;W)Y(&QO8V%T:6]N(BP*"2=P
M9&ER7V5D7U]P9&ER7W5S97)S)R`]/B`B4')O=&5C=&5D(&1I<F5C=&]R>2!U
M<V5R<R(L"@DG<&1I<E]E9%]?<W-L)R`]/B`B4U-,(BP*"2=P9&ER7V5D7U]S
M<VQ?;F]T7W-U<'!O<G1E9%]D;VUA:6XG(#T^(")34TP@:7,@;F]T('-U<'!O
M<G1E9"!I;B!T:&ES(&1O;6%I;BXB+`H))W!D:7)?961?7W-S;%]O<E]N;VYS
M<VQ?<VAO=6QD7V)E7V-H96-K960G(#T^(")!="!L96%S="!O;F4@8VAE8VMB
M;W@@<VAO=6QD(&)E('-E;&5C=&5D(&9R;VT@4U-,(&%N9"!.;VXM4U-,(&-H
M96-K8F]X97,N(BP*"2=P9&ER7V5D7U]U;F%B;&5?8W)?<&1I<E]U<W(G(#T^
M(")5;F%B;&4@=&\@8W)E871E('1H92!P<F]T96-T960@9&ER96-T;W)Y('5S
M97(Z("4Q(BP*"2=P9&ER7V5D7U]U;F%B;&5?8W)E871E7W!D:7(G(#T^(")5
M;F%B;&4@=&\@8W)E871E('1H92!P<F]T96-T960@9&ER96-T;W)Y.B`E,2(L
M"@DG<&1I<E]E9%]?=6YA8FQE7V1E9FEN95]H<W1?='EP92<@/3X@(E5N86)L
M92!T;R!D969I;F4@=&AE(&AO<W1I;F<@='EP92XB+`H))W!D:7)?961?7W5N
M86)L95]U<&1A=&5?<&1I<B<@/3X@(E5N86)L92!T;R!U<&1A=&4@=&AE('!R
M;W1E8W1E9"!D:7)E8W1O<GDZ("4Q(BP*"2=P9&ER7V5D7U]W<F]N9U]S>6UB
M;VQ?:6Y?:&5A9&5R)R`]/B`B4&QE87-E+"!D;R!N;W0@=7-E('-Y;6)O;"`E
M,2!I;B!T:&4@9&ER96-T;W)Y(&AE861E<B(L"@DG<&1I<E]U<W)?961?7V-R
M96%T95]P9&ER7W5S<E]F;W)?<&0G(#T^(")#<F5A=&4@=7-E<B!F;W(@=&AE
M('!R;W1E8W1E9"!D:7)E8W1O<GD@)3$B+`H))W!D:7)?=7-R7V5D7U]N;W1?
M8W)E871E7W!A<W,G(#T^(")4:&ES('=I;&P@;F]T(&-R96%T92!A('!A<W-W
M;W)D(&9O<B!T:&4@;F5W('!R;W1E8W1E9"!D:7)E8W1O<GD@=7-E<BY<;E=I
M=&AO=70@<&%S<W=O<F0@=&AE('5S97(@=VEL;"!N;W0@8F4@86)L92!T;R!L
M;V<@:6XN(BP*"2=P9&ER7W5S<E]E9%]?<&%S<U]F;W)?<&1I<E]U<W(G(#T^
M(")087-S=V]R9"!F;W(@=&AE('!R;W1E8W1E9"!D:7)E8W1O<GD@=7-E<B`E
M,2(L"@DG<&1I<E]U<W)?961?7W5N86)L95]S96QE8W1?<&1I<E]U<W(G(#T^
M(")5;F%B;&4@=&\@<V5L96-T('1H92!P<F]T96-T960@9&ER96-T;W)Y('5S
M97(Z("4Q(BP*"2=P9&ER7W5S<G-?;&ES=%]?=6YA8FQE7V1E9FEN95]P9&ER
M7W5S<G,G(#T^(")5;F%B;&4@=&\@9&5F:6YE('1H92!P<F]T96-T960@9&ER
M96-T;W)Y('5S97)S.B`E,2(L"@DG<&1I<E]U<W)S7VQI<W1?7W5N86)L95]R
M96UO=F5?<&1?=7-R<R<@/3X@(E5N86)L92!T;R!R96UO=F4@=&AE('!R;W1E
M8W1E9"!D:7)E8W1O<GD@=7-E<G,Z("4Q(BP*"2=P9&ER<U]L:7-T7U]N86UE
M)R`]/B`B3F%M92(L"@DG<&1I<G-?;&ES=%]?=&%B7W1I=&QE7VYO;E]S96-U
M<F5?9&ER)R`]/B`B3B(L"@DG<&1I<G-?;&ES=%]?=&%B7W1I=&QE7W-E8W5R
M95]D:7(G(#T^(")3(BP*"2=P9&ER<U]L:7-T7U]T86)?=&ET;&5?8V=I7V)I
M;E]D:7(G(#T^(")#(BP*"2=P9&ER<U]L:7-T7U]U;F%B;&5?<F5M;W9E7W!D
M:7)S)R`]/B`B56YA8FQE('1O(')E;6]V92!T:&4@<')O=&5C=&5D(&1I<F5C
M=&]R:65S.B`E,2(L"@DG<&AO<W1I;F=?7V%N;VYF='!?9&ES86)L960G(#T^
M(")!;F]N>6UO=7,@1E10('-E<G9I8V4@:7,@9&ES86)L960@;VX@=&AI<R!D
M;VUA:6X@87,@=&AI<R!)4"!A9&1R97-S(&ES(&%L<F5A9'D@8F5I;F<@=7-E
M9"!F;W(@86YO;GEM;W5S($944"!S97)V:6-E(&]N(&%N;W1H97(@9&]M86EN
M+B(L"@DG<&AO<W1I;F=?7V%N;VYF='!?96YC<GEP="<)/3X@)U1H92!P87-S
M=V]R9"!O9B!&5%`@=7-E<B!I<R!E;F-R>7!T960L(&%N9"!T:&5R969O<F4@
M8V%N;F]T(&)E('5S960@9F]R('!R;W1E8W1I;F<@9&ER96-T;W)Y("]P;&5S
M:RUS=&%T+RX@4&QE87-E(')E96YT97(@>6]U<B!&5%`@<&%S<W=O<F0L(&]R
M(&1E<V5L96-T('1H92!O<'1I;VX@(F%C8V5S<VEB;&4@=FEA('!A<W-W;W)D
M('!R;W1E8W1E9"!D:7)E8W1O<GD@7"<O<&QE<VLM<W1A="]<)R(G+`H))W!H
M;W-T:6YG7U]I<%]C:&%N9V5?=V%R;FEN9R<@/3X@(DE0(&%D9')E<W,@8VAA
M;F=E9"X@5&AE(&-O<G)E<W!O;F1I;F<@8VAA;F=E<R!W97)E(&%L<V\@;6%D
M92!I;B!T:&4@9&]M86EN)W,@1$Y3('IO;F4N(BP*"2=P:&]S=&EN9U]?;W1H
M97)?:&]S=&EN9U]E>&ES='-?;VY?:7`G(#T^(")5;F%B;&4@=&\@8VAA;F=E
M('1H92!C97)T:69I8V%T92!B96-A=7-E('1H:7,@:7`@861D<F5S<R!I<R!B
M96EN9R!U<V5D(&EN(&]N92!O<B!S979E<F%L(&AO<W1I;F<@86-C;W5N=',N
M(BP*"2=P:&]S=&EN9U]?=6YA8FQE7W1O7V-H86YG95]C97)T:69I8V%T92<@
M/3X@(E5N86)L92!T;R!I;G-T86QL('1H92!C97)T:69I8V%T93H@)3$B+`H)
M)W!H;W-T:6YG7U]U;F%B;&5?=&]?8VAA;F=E7VEP7V%D9')E<W,G(#T^(")5
M;F%B;&4@=&\@8VAA;F=E('1H92!I<"!A9&1R97-S.B`E,2(L"@DG<&AO<W1I
M;F=?7W5N86)L95]T;U]S971?8V5R="<@/3X@(E5N86)L92!T;R!S970@=&AE
M('-S;"!C97)T:69I8V%T93H@)3$B+`H))W!H;W-T:6YG7U]U;F%B;&5?=7!D
M871E)R`]/B`B56YA8FQE('1O('5P9&%T92!H;W-T:6YG('!R969E<F5N8V5S
M.B`E,2(L"@DG<&AO<W1I;F=?7W5N86)L95]M86YA9V4G(#T^(")5;F%B;&4@
M=&\@;6%N86=E(&AO<W1I;F<Z("4Q(BP*"@DG<&EC:V5R7V%U=&]R97-P;VYD
M97)?7W1I=&QE)R`]/B`G075T;W)E<W!O;F1E<B!S96QE8W1I;VXG+`H))W!I
M8VME<E]C;&EE;G1?7W1I=&QE)R`]/B`G0VQI96YT('-E;&5C=&EO;B<L"@DG
M<&EC:V5R7V1A=&%B87-E7U]T:71L92<@/3X@)T1A=&%B87-E('-E;&5C=&EO
M;B<L"@DG<&EC:V5R7V1O;6%I;E]?=&ET;&4G(#T^("=$;VUA:6X@<V5L96-T
M:6]N)RP*"2=P:6-K97)?;6%I;&YA;65?7W1I=&QE)R`]/B`G36%I;&YA;64@
M<V5L96-T:6]N)RP*"2=P:6-K97)?<VET95]A<'!L:6-A=&EO;E]?=&ET;&4G
M(#T^("=3:71E(&%P<&QI8V%T:6]N('-E;&5C=&EO;B<L"@DG<&EC:V5R7W-U
M8F1O;6%I;E]?=&ET;&4G(#T^("=3=6)D;VUA:6X@<V5L96-T:6]N)RP*"2=P
M:6-K97)?=V5B7W5S97)?7W1I=&QE)R`]/B`G5V5B('5S97(@<V5L96-T:6]N
M)RP*"2=P:6-K97)?8W5S=&]M7V)U='1O;E]?=&ET;&4G(#T^("=#=7-T;VT@
M8G5T=&]N('-E;&5C=&EO;B<L"@H))W!L97-K7V=U:61E)R`]/B`B4&QE<VL@
M57-E<B=S($=U:61E(BP*"2=P;&5S:U]K97E?7V%C=&EO;E]L;V=S)R`]/B`B
M06)I;&ET>2!T;R!U<V4@86-T:6]N(&QO9V=I;F<B+`H))W!L97-K7VME>5]?
M87!P7W9A=6QT)R`]/B`B06)I;&ET>2!T;R!U<V4@87!P;&EC871I;VX@=F%U
M;'0B+`H))W!L97-K7VME>5]?8F%C:W5P)R`]/B`B06)I;&ET>2!T;R!U<V4@
M=&AE(&)A8VMU<"!F=6YC=&EO;G,B+`H))W!L97-K7VME>5]?8VQI96YT7W1E
M;7!L<R<@/3X@(D%B:6QI='D@=&\@;6%N86=E(&-L:65N="!T96UP;&%T97,B
M+`H))W!L97-K7VME>5]?8VQI96YT<R<@/3X@(DUA>&EM=6T@;G5M8F5R(&]F
M(&-L:65N="!A8V-O=6YT<R(L"@DG<&QE<VM?:V5Y7U]C;VQD9G5S:6]N)R`]
M/B`B06)I;&ET>2!T;R!U<V4@0V]L9$9U<VEO;B(L"@DG<&QE<VM?:V5Y7U]D
M;VUA:6YS)R`]/B`B36%X:6UU;2!N=6UB97(@;V8@9&]M86EN<R(L"@DG<&QE
M<VM?:V5Y7U]D87-H8F]A<F0G(#T^("=!8FEL:71Y('1O('5S92!$97-K=&]P
M(&EN=&5R9F%C92<L"@DG<&QE<VM?:V5Y7U]S=&1G=6DG(#T^("=!8FEL:71Y
M('1O('5S92!S=&%N9&%R9"!I;G1E<F9A8V4G+`H))W!L97-K7VME>5]?;6%N
M86=E7V1A<VAB;V%R9"<@/3X@)T%B:6QI='D@=&\@;6%N86=E($1E<VMT;W`G
M+`H))W!L97-K7VME>5]?:V5Y7VEP7W)A;F=E<R<@/3X@)UEO=2!C86X@=7-E
M(%!L97-K(&]N;'D@=VET:"!T:&4@9F]L;&]W:6YG($E0(&%D9')E<W-E<SHG
M+`H))W!L97-K7VME>5]?9')W96(G(#T^(")!8FEL:71Y('1O('5S92!$<BY7
M96(@86YT:79I<G5S(BP*"2=P;&5S:U]K97E?7V5V96YT7VUA;F%G97(G(#T^
M(")!8FEL:71Y('1O('5S92!E=F5N="!M86YA9V5R(BP*"2=P;&5S:U]K97E?
M7V5X<&ER871I;VYS)R`]/B`B06)I;&ET>2!T;R!M86YA9V4@9&]M86EN(&%N
M9"!C;&EE;G0@86-C;W5N="!E>'!I<F%T:6]N(&1A=&5S(BP*"2=P;&5S:U]K
M97E?7V=R;W5P7V]P<R<@/3X@(D%B:6QI='D@=&\@<&5R9F]R;2!G;&]B86P@
M;W!E<F%T:6]N<R!O;B!O8FIE8W1S("AG<F]U<"!O<&5R871I;VYS*2(L"@DG
M<&QE<VM?:V5Y7U]E>'!I<F%T:6]N)R`]/B`B2V5Y(&5X<&ER871I;VX@9&%T
M92(L"@DG<&QE<VM?:V5Y7U]K97E?;G5M8F5R)R`]/B`B2V5Y(&YU;6)E<B(L
M"@DG<&QE<VM?:V5Y7U]L86YG=6%G97,G(#T^(")-87AI;75M(&YU;6)E<B!O
M9B!L86YG=6%G92!P86-K<R(L"@DG<&QE<VM?:V5Y7U]M86EL;F%M97,G(#T^
M(")-87AI;75M(&YU;6)E<B!O9B!M86EL(&%C8V]U;G1S(BP*"2=P;&5S:U]K
M97E?7VUI9W)A=&EO;E]M86YA9V5R)R`]/B`B06)I;&ET>2!T;R!U<V4@36EG
M<F%T:6]N($UA;F%G97(B+`H))W!L97-K7VME>5]?;7-S<6PG(#T^(")!8FEL
M:71Y('1O('5S92!-:6-R;W-O9G0@4U%,(%-E<G9E<B(L"@DG<&QE<VM?:V5Y
M7U]M>7!L97-K7V9U;F,G(#T^(")-4$,@9G5N8W1I;VYA;&ET>2(L"@DG<&QE
M<VM?:V5Y7U]M>7!L97-K7VUA;F%G92<@/3X@(D%D;6EN:7-T<F%T;W(@8V%N
M(&UA;F%G92!-4$,@<V5R=FEC92!A8V-E<W-I8FEL:71Y(BP*"2=P;&5S:U]K
M97E?7VUY<&QE<VM?<V5R=F5R7VED)R`]/B`B35!#('-L879E('-E<G9E<B!I
M9&5N=&EF:65R(BP*"2=P;&5S:U]K97E?7VYO=&EF:6-A=&EO;G,G(#T^(")!
M8FEL:71Y('1O(&UA;F%G92!N;W1I9FEC871I;VYS(BP*"2=P;&5S:U]K97E?
M7W!O<W1G<F5S<6PG(#T^(")!8FEL:71Y('1O('5S92!0;W-T9W)E4U%,(BP*
M"2=P;&5S:U]K97E?7W%M86EL7W%U975E)R`]/B`G06)I;&ET>2!T;R!M86YA
M9V4@;6%I;"!Q=65U92<L"@DG<&QE<VM?:V5Y7U]R96UO=&5?9&(G(#T^("=!
M8FEL:71Y('1O('5S92!R96UO=&4@9&%T86)A<V4@:&]S=&EN9R<L"@DG<&QE
M<VM?:V5Y7U]S:71E8G5I;&1E<B<@/3X@(D%B:6QI='D@=&\@=7-E($UA;6)O
M($--4R(L"@DG<&QE<VM?:V5Y7U]S;&%V95]S97)V97)S)R`]/B`B4VQA=F4@
M<V5R=F5R<R!L:6UI="(L"@DG<&QE<VM?:V5Y7U]S<&%M87-S87-S:6XG(#T^
M(")!8FEL:71Y('1O('5S92!3<&%M07-S87-S:6XB+`H))W!L97-K7VME>5]?
M<W5B9&]M86EN<R<@/3X@(D%B:6QI='D@=&\@;6%N86=E('-U8F1O;6%I;G,B
M+`H))W!L97-K7VME>5]?<WES7V%C8V5S<R<@/3X@(D%B:6QI='D@=&\@;6%N
M86=E('-H96QL(&%C8V5S<R(L"@DG<&QE<VM?:V5Y7U]T;VUC870G(#T^(")!
M8FEL:71Y('1O('5S92!4;VUC870B+`H))W!L97-K7VME>5]?=')A9F9I8U]R
M97!O<G1S)R`]/B`B06)I;&ET>2!T;R!U<V4@=')A9F9I8R!R97!O<G1I;F<B
M+`H))W!L97-K7VME>5]?='1S)R`]/B`B06)I;&ET>2!T;R!U<V4@2&5L<"!$
M97-K(BP*"2=P;&5S:U]K97E?7W9I<G1U;WIZ;R<@/3X@(E9A;&ED(&9O<B!6
M:7)T=6]Z>F\@;VYL>2(L"@DG<&QE<VM?:V5Y7U]W96)U<V5R<R<@/3X@(DUA
M>&EM=6T@;G5M8F5R(&]F('=E8B!U<V5R<R(L"@DG<&QE<VM?:V5Y7U]L:6-E
M;G-E7W5P9&%T95]D871E)R`]/B`G3F5X="!L:6-E;G-E(&ME>2!U<&1A=&4G
M+`H))W!L97-K7VME>5]?875T;VEN<W1A;&QE<E]C;VYF:6<G(#T^("=!8FEL
M:71Y('1O(&UA;F%G92!U<&1A=&5R('!R969E<F5N8V5S)RP*"2=P;&5S:U]K
M97E?=7!D871E7U]T:71L92<@/3X@)TME>2!5<&1A=&4@4W1A='5S)RP*"2=P
M;&5S:U]K97E?=7!D871E7U]L96=E;F0G(#T^("=+97D@57!D871E(%-T871U
M<R<L"@DG<&QE<VM?:V5Y7W5P9&%T95]?;F5W7V%D9&ET:6]N86Q?:V5Y)R`]
M/B`G3F5W(&%D9&ET:6]N86P@:V5Y(')E8V5I=F5D)RP*"@DG<&QE<VM?:V5Y
M7U]C:&5C:U]W<F]N9R<@"0D)"3T^("=4:&4@;&EC96YS92!K97D@:7,@;F]T
M('9A;&ED+B!4;R!U<V4@=&AE(&-O;G1R;VP@<&%N96PL(&]B=&%I;B!A;F0@
M:6YS=&%L;"!A(&YE=R!F=6QL>2!F96%T=7)E9"!L:6-E;G-E(&ME>2XG+`H)
M)W!L97-K7VME>5]?=7!L;V%D7V-H96-K7W=R;VYG)PD)"3T^("=4:&4@=7!L
M;V%D960@;&EC96YS92!K97D@:7,@;F]T('9A;&ED+B<L"@DG<&QE<VM?:V5Y
M7U]R979E<G1?8VAE8VM?=W)O;F<G"0D)/3X@)U1H92!P<F5V:6]U<VQY(&EN
M<W1A;&QE9"!L:6-E;G-E(&ME>2!I<R!N;W0@=F%L:60N)RP*"2=P;&5S:U]K
M97E?7W5P9&%T95]C:&5C:U]W<F]N9R<)"0D]/B`G5&AE('5P9&%T960@;&EC
M96YS92!K97D@:7,@;F]T('9A;&ED+B<L"@H))W!L97-K7VME>5]?:V5Y7V5X
M<&ER960G"0D)"3T^("=9;W5R(&QI8V5N<V4@:V5Y(&AA<R!E>'!I<F5D+B!4
M;R!C;VYT:6YU92!U<VEN9R!Y;W5R(&-O;G1R;VP@<&%N96PL('EO=2!M=7-T
M('!U<F-H87-E(&$@;F]N+65X<&ER:6YG(&-O;6UE<F-I86P@;&EC96YS92XG
M+`H))W!L97-K7VME>5]?=FER=6]Z>F]?;VYL>5]K97DG"0D)/3X@)U1H92!L
M:6-E;G-E(&ME>2!I<R!I;G1E;F1E9"!O;FQY(&9O<B!U<V4@=VET:"!0;&5S
M:R!I;G-I9&4@5FER='5O>GIO('9I<G1U86P@<')I=F%T92!S97)V97)S+B<L
M"@DG<&QE<VM?:V5Y7U]E87-Y7VUI<W5S960G"0D)"3T^("=4:&4@;&EC96YS
M92!K97D@9F]R(%!L97-K($5A<WD@86QL;W=S('-E<G9I;F<@;VYL>2!O;F4@
M8VQI96YT(&%C8V]U;G0N(%EO=2!H879E("4Q(&-L:65N=',N)RP*"2=P;&5S
M:U]K97E?7VEP7W)A;F=E<U]E>&-E961E9"<)"0D]/B`G66]U(&-A;B!U<V4@
M=&AI<R!L:6-E;G-E9"!0;&5S:R!C;W!Y(&]N;'D@=VET:"!T:&4@9F]L;&]W
M:6YG($E0(&%D9')E<W-E<SH@)3(N(%1H92!F;VQL;W=I;F<@25`@861D<F5S
M<V5S(&%R92!N;W0@8V]V97)E9"!B>2!Y;W5R(&QI8V5N<V4Z("4Q+B<L("\O
M)3$@=6YA;&QO=V5D(&%D9')E<W-E<R!L:7-T('-E<&%R871E9"!B>2!C;VUM
M82P@)3(@86QL;W=E9"!I<"!A9&1R97-S97,@;&ES="!S97!A<F%T960@8GD@
M8V]M;6$*"2=P;&5S:U]K97E?7VQI;6ET<U]E>&-E961E9"<)"0D]/B`G5&AE
M(&%M;W5N="!O9B!C=7)R96YT;'D@=7-E9"!R97-O=7)C97,@;W9E<G)I9&5S
M('1H92!L:6UI=',@9&5F:6YE9"!B>2!Y;W5R(&QI8V5N<V4N)RP*"2=P;&5S
M:U]K97E?7VQI;6ET<U]E>&-E961E9%]L:6U?9&]M)PD]/B`G5&AE(&YU;6)E
M<B!O9B!W96(@<VET97,@:&]S=&5D(&]N('1H92!S97)V97(@97AC965D<R!T
M:&4@;&EM:71S(&1E9FEN960@8GD@>6]U<B!L:6-E;G-E+B!9;W4@:&%V92`E
M,B!S:71E<R!H;W-T960[('EO=7(@;&EC96YS92!A;&QO=W,@:&]S=&EN9R!O
M;FQY("4Q('-I=&5S+B<L("\O("4Q(&QI;6ET('9A;'5E+"`E,B!U<V5D('9A
M;'5E+"`E,R!D96QT82!V86QU90H))W!L97-K7VME>5]?;&EM:71S7V5X8V5E
M9&5D7VQI;5]C;"<)"3T^("=4:&4@;G5M8F5R(&]F('-E<G9E9"!C;&EE;G0@
M86-C;W5N=',@97AC965D<R!T:&4@;&EM:71S(&1E9FEN960@8GD@>6]U<B!L
M:6-E;G-E+B!9;W4@:&%V92`E,B!C;&EE;G0@86-C;W5N=',@8W5R<F5N=&QY
M('-E<G9E9#L@>6]U<B!L:6-E;G-E(&%L;&]W<R!S97)V:6YG(&]N;'D@)3$@
M8VQI96YT(&%C8V]U;G1S+B<L("\O)3$@;&EM:70@=F%L=64L("4R('5S960@
M=F%L=64L("4S(&1E;'1A('9A;'5E"@DG<&QE<VM?:V5Y7U]L:6UI='-?97AC
M965D961?;&EM7VUN)PD)/3X@)U1H92!N=6UB97(@;V8@<V5R=F5D(&4M;6%I
M;"!A8V-O=6YT<R!E>&-E961S('1H92!L:6UI=',@9&5F:6YE9"!B>2!Y;W5R
M(&QI8V5N<V4N(%EO=2!H879E("4R(&4M;6%I;"!A8V-O=6YT<R!C=7)R96YT
M;'D@<V5R=F5D.R!Y;W5R(&QI8V5N<V4@86QL;W=S('-E<G9I;F<@;VYL>2`E
M,2!E+6UA:6P@86-C;W5N=',N)RP@+R\@)3$@;&EM:70@=F%L=64L("4R('5S
M960@=F%L=64L("4S(&1E;'1A('9A;'5E"@DG<&QE<VM?:V5Y7U]L:6UI='-?
M97AC965D961?;&EM7W=U)PD)/3X@)U1H92!N=6UB97(@;V8@<V5R=F5D('=E
M8B!U<V5R(&%C8V]U;G1S(&5X8V5E9',@=&AE(&QI;6ET<R!D969I;F5D(&)Y
M('EO=7(@;&EC96YS92X@66]U(&AA=F4@)3(@=V5B('5S97(@86-C;W5N=',@
M8W5R<F5N=&QY('-E<G9E9#L@>6]U<B!L:6-E;G-E(&%L;&]W<R!S97)V:6YG
M(&]N;'D@)3$@=V5B('5S97(@86-C;W5N=',N)RP@+R\@)3$@;&EM:70@=F%L
M=64L("4R('5S960@=F%L=64L("4S(&1E;'1A('9A;'5E"@DG<&QE<VM?:V5Y
M7U]L:6UI='-?97AC965D961?34Q3)PD)/3X@)U1H92!N=6UB97(@;V8@8W5R
M<F5N=&QY('5S960@;&%N9W5A9V4@<&%C:W,@97AC965D<R!T:&4@;&EM:71S
M(&1E9FEN960@8GD@>6]U<B!L:6-E;G-E+B!4:&5R92!A<F4@)3(@;&%N9W5A
M9V4@<&%C:W,@:6YS=&%L;&5D.R!Y;W5R(&QI8V5N<V4@86QL;W=S(&EN<W1A
M;&QI;F<@;VYL>2`E,2!L86YG=6%G92!P86-K<RXG+"`O+R`E,2!L:6UI="!V
M86QU92P@)3(@=7-E9"!V86QU92P@)3,@9&5L=&$@=F%L=64*"@DG<&QE<VM?
M:V5Y7U]K97E?9FEL95]I;G9A;&ED)R`]/B`G5&AE('5P;&]A9&5D(&ME>2!F
M:6QE(&ES(&YO="!V86QI9"!O<B!D;V5S(&YO="!C;VYT86EN(&$@;&EC96YS
M92!K97DN)RP*"2=K97E?7W1I=&QE)R`]/B`G3&EC96YS92!-86YA9V5M96YT
M)RP*"2=K97E?7W5P;&]A9%]T:71L92<@/3X@)TQI8V5N<V4@2V5Y(%5P;&]A
M9"<L"@DG:V5Y7U]U<&QO861?;&5G96YD)R`]/B`G3&EC96YS92!K97D@=7!L
M;V%D)RP*"2=K97E?7V9I;&4G(#T^("=0871H('1O('1H92!L:6-E;G-E(&ME
M>2!F:6QE(&QO8V%T:6]N)RP*"2=K97E?7VYO7VME>5]F:6QE7VEN7WII<"<@
M/3X@)U1H92!U<&QO861E9"`N>FEP(&9I;&4@9&]E<R!N;W0@8V]N=&%I;B!K
M97D@9FEL92<L"@DG:V5Y7U]K97E?=7!L;V%D)R`]/B`G3&EC96YS92!+97D@
M26YS=&%L;&%T:6]N)RP*"2=K97E?7V]V97)W<FET95]C;VYF:7)M871I;VXG
M(#T^("=297!L86-E('1H92!C=7)R96YT;'D@:6YS=&%L;&5D(&QI8V5N<V4@
M:V5Y('=I=&@@=&AE('-E;&5C=&5D(&]N92<L"@DG:V5Y7U]O=F5R=W)I=&5?
M8V]N9FER;6%T:6]N7W)E<75I<F5D)R`]/B`G4&QE87-E(&-O;F9I<FT@=&AE
M(&QI8V5N<V4@:V5Y(')E<&QA8V5M96YT+B<L"@DG:V5Y7U]L:6UI='-?97AC
M965D961?8V]N9FER;6%T:6]N)R`]/B`G1&\@;F]T(&-H96-K('1H92!L:6UI
M=',@;VX@<F5S;W5R8V4@=7-A9V4@9&5F:6YE9"!B>2!T:&4@:V5Y)RP*"2=K
M97E?7W1A8G-?<&QE<VLG(#T^("=0;&5S:R!,:6-E;G-E($ME>2<L"@DG:V5Y
M7U]T86)S7V%D9&ET:6]N86PG(#T^("=!9&1I=&EO;F%L($QI8V5N<V4@2V5Y
M<R<L"@DG:V5Y7W)E=F5R=%]?=&ET;&4G(#T^("=,:6-E;G-E($ME>2!2;VQL
M8F%C:R<L"@DG:V5Y7W)E=F5R=%]?;&5G96YD)R`]/B`G2V5Y(')O;&QB86-K
M(&-O;F9I<FUA=&EO;B<L"@DG:V5Y7W)E=F5R=%]?=&5X="<@/3X@)U1H92!L
M:6-E;G-E(&ME>2!W:71H('1H92!F;VQL;W=I;F<@<')O<&5R=&EE<R!W:6QL
M(&)E(')E<W1O<F5D.B<L"@DG861D:71I;VYA;%]K97E?7VEN9F\G(#T^("=!
M9&1I=&EO;F%L($ME>2!0<F]P97)T:65S)RP*"2=A9&1I=&EO;F%L7VME>5]?
M<')O<%]N86UE)R`]/B`G4')O<&5R='DG+`H))V%D9&ET:6]N86Q?:V5Y7U]P
M<F]P7W9A;'5E)R`]/B`G5F%L=64G+`H))V%D9&ET:6]N86Q?:V5Y7U]D97-C
M<E]N86UE)R`]/B`G2V5Y(&YA;64G+`H))V%D9&ET:6]N86Q?:V5Y7U]D97-C
M<E]K97E?;G5M8F5R)R`]/B`G2V5Y(&YU;6)E<B<L"@DG861D:71I;VYA;%]K
M97E?7V1E<V-R7VQI;5]D871E)R`]/B`G17AP:7)A=&EO;B!D871E)RP*"2=A
M9&1I=&EO;F%L7VME>5]?9&5S8W)?;&EC96YS95]U<&1A=&5?9&%T92<@/3X@
M)TYE>'0@;&EC96YS92!K97D@=7!D871E)RP*"2=A9&1I=&EO;F%L7VME>5]?
M<F5M;W9E7W1I=&QE)R`]/B`B5&AE('-I=&4@87!P;&EC871I;VX@:V5Y('=I
M=&@@=&AE(&9O;&QO=VEN9R!P<F]P97)T:65S('=I;&P@8F4@<F5M;W9E9#HB
M+`H))V%D9&ET:6]N86Q?:V5Y<U]?<F5M;W9E7W1I=&QE)R`]/B`B5&AE(&9O
M;&QO=VEN9R!A9&1I=&EO;F%L(&ME>7,@=VEL;"!B92!R96UO=F5D.B(L"@DG
M861D:71I;VYA;%]K97ES7U]S96QE8W1?=&]?<F5M;W9E)R`]/B`G4V5L96-T
M('1H92!A9&1I=&EO;F%L(&ME>7,@=&\@8F4@<F5M;W9E9"XG+`H))V%D9&ET
M:6]N86Q?:V5Y7U]F:6QE7VEN=F%L:60G(#T^("=4:&4@=7!L;V%D960@:V5Y
M(&9I;&4@:7,@;F]T('9A;&ED(&]R(&1O97,@;F]T(&-O;G1A:6X@82!L:6-E
M;G-E(&ME>2XG+`H))V%D9&ET:6]N86Q?:V5Y7U]F:6QE7VEN8V]M<&%T:6)L
M92<@/3X@)U1H92!U<&QO861E9"!K97D@9FEL92!I<R!N;W0@=F%L:60@9F]R
M('1H:7,@87!P;&EC871I;VXN)RP*"2=A9&1I=&EO;F%L7VME>5]?;F]T7V5X
M:7-T<R<@/3X@)TYO(&QI8V5N<V4@:V5Y(&EN<W1A;&QE9"XG+`H))V%D9&ET
M:6]N86Q?:V5Y<U]?;&5G96YD)R`]/B`G061D:71I;VYA;"!K97ES)RP*"2=A
M9&1I=&EO;F%L7VME>7-?7VQI<W1?:&5A9&5R)R`]/B`G061D:71I;VYA;"!K
M97ES)RP*"2=A9&1I=&EO;F%L7VME>5]U<&1A=&5?7W1I=&QE)R`]/B`G57!D
M871I;F<@061D:71I;VYA;"!+97DN)RP*"2=A9&1I=&EO;F%L7VME>5]U<&1A
M=&5?7VQE9V5N9"<@/3X@)U-T871U<R!O9B!A9&1I=&EO;F%L(&ME>2!U<&1A
M=&4N)RP*"2=A9&1I=&EO;F%L7VME>5]U<&1A=&5?7VYE=U]K97DG(#T^("=!
M9&1I=&EO;F%L($ME>2!0<F]P97)T:65S)RP*"2=A9&1I=&EO;F%L7VME>5]U
M<&1A=&5?7W)E<W5L=%]R97-P;VYS92<@/3X@)TQI8V5N<VEN9R!S97)V97(@
M<F5S<&]N<V4Z("4Q)RP*"2=A9&1I=&EO;F%L7VME>5]U<&1A=&5?7W)E<W5L
M=%]N971W;W)K)R`]/B`G56YA8FQE('1O(&-O;FYE8W0@=&\@=&AE(&QI8V5N
M<VEN9R!S97)V97(N(%!L96%S92!M86ME('-U<F4@=&AA="!Y;W5R(&YE='=O
M<FL@86QL;W=S(&-O;6UU;FEC871I;VX@=&\@)3$Z("4R+B<L"@DG861D:71I
M;VYA;%]K97E?=7!D871E7U]R97-U;'1?;&]C:R<@/3X@)TME>2!U<&1A=&4@
M:7,@86QR96%D>2!I;B!P<F]G<F5S<R<L"@DG861D:71I;VYA;%]K97E?=7!D
M871E7U]R97-U;'1?:6YT97)N86Q?97)R;W(G(#T^("=%<G)O<B!O8V-U<G)E
M9"!W:&EL92!U<&1A=&EN9R!T:&4@;&EC96YS92!K97DZ("4Q)RP*"@DG8G1?
M861D:71I;VYA;%]K97E?<F5V97)T)R`]/B`G4F]L;"!"86-K($ME>2<L"@DG
M8G1?861D:71I;VYA;%]K97E?=7!D871E)R`]/B`G4F5T<FEE=F4@061D:71I
M;VYA;"!+97DG+`H))V%D9&ET:6]N86Q?:V5Y7W)E=F5R=%]?=&ET;&4G(#T^
M("=0;&5A<V4@8V]N9FER;2!T:&4@;W!E<F%T:6]N)RP*"2=A9&1I=&EO;F%L
M7VME>5]R979E<G1?7VQE9V5N9"<@/3X@)U!R;W!E<G1I97,@;V8@=&AE('!R
M979I;W5S;'D@=7-E9"!A9&1I=&EO;F%L(&ME>2<L"@DG861D:71I;VYA;%]K
M97E?<F5V97)T7U]C;VYF:7)M7W1E>'0G(#T^("=2;VQL(&)A8VL@:V5Y)RP*
M"2=A9&1I=&EO;F%L7VME>5]R979E<G1?7V-O;F9I<FU?<F5Q=6ER960G(#T^
M("=0;&5A<V4@8V]N9FER;2!T:&4@;W!E<F%T:6]N+B<L"@H))W!R;V-E961?
M=&]?8VQ?<&]O;"<@/3X@(E!R;V-E960@=&\@8V]N9FEG=7)I;F<@8VQI96YT
M)W,@25`@<&]O;"(L"@DG<')O8V5E9%]T;U]H;W-T:6YG7W-E='5P)R`]/B`B
M4')O8V5E9"!T;R!H;W-T:6YG('-E='5P(BP*"2=R96UO=F5#97)T<U]?<F5M
M;W9E7V-E<G1I9FEC871E<U]C<"<@/3X@(E1H92!F;VQL;W=I;F<@8V5R=&EF
M:6-A=&5S('=I;&P@8F4@<F5M;W9E9#H@(BP*"2=R96UO=F5#97)T<U]?<F5M
M;W9E7V-E<G1I9FEC871E<U]D;VUA:6XG(#T^(")4:&4@9F]L;&]W:6YG(&-E
M<G1I9FEC871E<R!O=VYE9"!B>2`E,2!W:6QL(&)E(')E;6]V960Z("(L"@DG
M<F5M;W9E0VQI96YT<TE07W)E;6]V95]C;&EE;G1S7VEP)R`]/B`B5&AI<R!)
M4"!A9&1R97-S('=I;&P@8F4@<F5M;W9E9"!F<F]M('1H92!P;V]L<R!O9B!T
M:&4@9F]L;&]W:6YG(&-L:65N=',Z(BP*"2=R96UO=F5#;&EE;G1S4VET94%P
M<%]R96UO=F5?8VQI96YT<R<@/3X@(E1H:7,@<VET92!A<'!L:6-A=&EO;B!W
M:6QL(&)E(')E;6]V960@9G)O;2!T:&4@<&]O;',@;V8@=&AE(&9O;&QO=VEN
M9R!C;&EE;G1S.B(L"@DG<F5M;W9E0VQI96YT<U]?<F5M;W9E7V-L:65N='-?
M9&]M86EN<R<@/3X@(E1H92!F;VQL;W=I;F<@8VQI96YT(&%C8V]U;G1S(&%N
M9"!T:&5I<B!D;VUA:6YS('=I;&P@8F4@<F5M;W9E9#HB+`H))W)E;6]V94UA
M:6Q!;&EA<V5S7U]R96UO=F5?;6%I;%]A;&EA<V5S)R`]/B`B5&AE(&9O;&QO
M=VEN9R!M86EL(&%L:6%S97,@9F]R('1H92!M86EL(&YA;64@)3$@=VEL;"!B
M92!R96UO=F5D.B(L"@DG<F5M;W9E36%I;$YA;65S7U]R96UO=F5?;6%I;&YA
M;65S)R`]/B`B5&AE(&9O;&QO=VEN9R!M86EL(&YA;65S(&%N9"!A;&EA<V5S
M('=I;&P@8F4@<F5M;W9E9"!F<F]M('1H92!D;VUA:6X@)3$Z(BP*"2=R96UO
M=F5-86EL3F%M97-?7W)E;6]V95]M86EL;F%M97-?;V9?8VPG(#T^(")4:&4@
M9F]L;&]W:6YG(&UA:6P@;F%M97,@86YD(&%L:6%S97,@=VEL;"!B92!R96UO
M=F5D(&9R;VT@9&]M86EN("4R(&]W;F5D(&)Y(&-L:65N="`E,3HB+`H))W)E
M;6]V94UA:6Q.86UE<U]?=&AE<V5?;6%I;&YA;65S7W=I;&Q?;F]T7V1E;&5T
M92<@/3X@(E1H97-E(&UA:6P@;F%M97,@=VEL;"!N;W0@8F4@9&5L971E9"XB
M+`H))W)E;6]V95-E<W-I;VYS7U]R96UO=F5?=&ET;&4G(#T^(")4:&4@9F]L
M;&]W:6YG('-E<W-I;VYS('=I;&P@8F4@96YD960Z(BP*"2=R96UO=F5&='!3
M97-S:6]N<U]?<F5M;W9E7W1I=&QE)R`]/B`B5&AE(&9O;&QO=VEN9R!&5%`@
M<V5S<VEO;G,@=VEL;"!B92!E;F1E9#HB+`H))W)E;6]V951E;7!L871E<U]?
M<F5M;W9E7W1E;7!L871E<R<@/3X@(E1H92!F;VQL;W=I;F<@=&5M<&QA=&5S
M('=I;&P@8F4@<F5M;W9E9#HB+`H))W)E<&]R=%]A=71O7U]L:7-T7W1I=&QE
M)R`]/B`G1"<L"@DG<F5P;W)T7V%U=&]?7VQI<W1?875T;R<@/3X@)T9R97%U
M96YC>2<L"@DG<F5P;W)T7V%U=&]?7VQI<W1?;&%S="<@/3X@)TQA<W0@9&5L
M:79E<GD@9&%T92<L"@DG<F5P;W)T7V%U=&]?7VQI<W1?<F5C:7!I96YT)R`]
M/B`G1&5L:79E<B!T;R<L"@DG<F5P;W)T7V%U=&]?7VQI<W1?<V5L96-T)R`]
M/B`G4F5P;W)T(&]N)RP*"2=R97!O<G1?875T;U]?=&ET;&4G(#T^("=$96QI
M=F5R>2!38VAE9'5L97,@9F]R("4Q)RP*"2=R97!O<G1?875T;U]?<F5C:7!I
M96YT7V5M86EL)R`]/B`G=&AE(&4M;6%I;"!A9&1R97-S($D@<W!E8VEF>2<L
M"@DG<F5P;W)T7V%U=&]?7W)E8VEP:65N=%]A9&UI;B<@/3X@)W1H92!S97)V
M97(@861M:6YI<W1R871O<B<L"@DG<F5P;W)T7V%U=&]?7W)E8VEP:65N=%]C
M;&EE;G0G(#T^("=T:&4@8VQI96YT)RP*"2=R97!O<G1?875T;U]?<F5C:7!I
M96YT7V1O;6%I;B<@/3X@)W1H92!D;VUA:6X@861M:6YI<W1R871O<B<L"@DG
M<F5P;W)T7V%U=&]?961I=%]?<V5L96-T)R`]/B`G4F5P;W)T(&]N)RP*"2=R
M97!O<G1?875T;U]?<V5L96-T7V-L:65N=%]R97!O<G1?86QL)R`]/B`G86QL
M(&-L:65N=',G+`H))W)E<&]R=%]A=71O7U]S96QE8W1?8VQI96YT7W)E<&]R
M=%]C=7)R96YT)R`]/B`G=&AI<R!C;&EE;G0G+`H))W)E<&]R=%]A=71O7U]S
M96QE8W1?8VQI96YT7W)E<&]R=%]O=&AE<E]C;&EE;G0G(#T^("<E,2<L"@DG
M<F5P;W)T7V%U=&]?7W-E;&5C=%]D;VUA:6Y?<F5P;W)T7V%L;"<@/3X@)V%L
M;"!D;VUA:6YS)RP*"2=R97!O<G1?875T;U]?<V5L96-T7V1O;6%I;E]R97!O
M<G1?;W1H97)?8VQI96YT)R`]/B`G86QL(&1O;6%I;G,@;V8@)3$G+`H))W)E
M<&]R=%]A=71O7U]S96QE8W1?9&]M86EN7W)E<&]R=%]C;&EE;G0G(#T^("=A
M;&P@9&]M86EN<R!O9B!T:&ES(&-L:65N="<L"@DG<F5P;W)T7V%U=&]?7W-E
M;&5C=%]D;VUA:6Y?<F5P;W)T7V-U<G)E;G0G(#T^("=T:&ES(&1O;6%I;B<L
M"@DG<F5P;W)T7V%U=&]?7W-E;&5C=%]D;VUA:6Y?<F5P;W)T7V]T:&5R7V1O
M;6%I;B<@/3X@)R4Q)RP*"2=R97!O<G1?875T;U]?;&5G96YD)R`]/B`G1&5L
M:79E<GD@<V-H961U;&5S)RP*"2=R97!O<G1?875T;U]?<V5L96-T7V9O<E]R
M96UO=F4G(#T^(")396QE8W0@=&AE(&1E;&EV97)Y('-C:&5D=6QE<R!T;R!B
M92!R96UO=F5D+B(L"@DG<F5P;W)T7V%U=&]?<F5M;W9E7U]T:71L92<@/3X@
M(E1H92!F;VQL;W=I;F<@<F5P;W)T(&1E;&EV97)Y('-C:&5D=6QE<R!W:6QL
M(&)E(')E;6]V960Z(BP*"2=R97!O<G1?875T;U]E9&ET7U]T:71L92<@/3X@
M)T1E;&EV97)Y(%-C:&5D=6QE(%!R;W!E<G1I97,G+`H))W)E<&]R=%]A=71O
M7V5D:71?7W)E8VEP:65N="<@/3X@)T1E;&EV97(@=&\G+`H))W)E<&]R=%]A
M=71O7V5D:71?7W1A<F=E="<@/3X@)U)E<&]R="!O;B<L"@DG<F5P;W)T7V%U
M=&]?961I=%]?875T;R<@/3X@)T1E;&EV97)Y(&9R97%U96YC>2<L"@DG<F5S
M<%]E9&ET7U]A;'=A>7-?<F5S<&]N9"<@/3X@(F%L=V%Y<R!R97-P;VYD(BP*
M"2=R97-P7V5D:71?7W)E<&QY7W-U8FIE8W0G(#T^(")297!L>2!S=6)J96-T
M(BP*"2=R97-P7V5D:71?7V%N<W=E<E]T>'0G(#T^(")297!L>2!W:71H('1E
M>'0B+`H))W)E<W!?961I=%]?871T86-H)R`]/B`B071T86-H(&9I;&5S(BP*
M"2=R97-P7V5D:71?7V1E9F%U;'1?<W5B:F5C="<@/3X@(E)E.B`E,2(L"@DG
M<F5S<%]E9&ET7U]F;W(G(#T^(")F;W(@(BP*"2=R97-P7V5D:71?7V9R=U]R
M<7-T7V5M86EL)R`]/B`B57!O;B!A=71O;6%T:6,@<F5S<&]N<V4L(&9O<G=A
M<F0@=&AE(&]R:6=I;F%L(&UE<W-A9V4@=&\@=&AE('-P96-I9FEE9"!E+6UA
M:6PB+`H))W)E<W!?961I=%]?9G=D7V5M86EL7VEN=F%L:60G(#T^(")$97-T
M:6YA=&EO;B!E+6UA:6P@861D<F5S<R!I<R!I;G9A;&ED+B(L"@DG<F5S<%]E
M9&ET7U]I;E]B;V1Y)R`]/B`B=VAE;B!S<&5C:69I960@=V]R9',@87)E(&9O
M=6YD(&EN('1H92!M97-S86=E(&)O9'DB+`H))W)E<W!?961I=%]?:6Y?<W5B
M:F5C="<@/3X@(G=H96X@<W!E8VEF:65D('=O<F1S(&%R92!F;W5N9"!I;B!M
M97-S86=E('-U8FIE8W0B+`H))W)E<W!?961I=%]?:6YV86QI9%]R97-P7V9R
M97$G(#T^(")297-P;VYS92!F<F5Q=65N8WD@:7,@:6YV86QI9"XB+`H))W)E
M<W!?961I=%]?:6YV86QI9%]R<7-T7W1X="<@/3X@(DEN=F%L:60@<F5Q=65S
M="!T97AT+B(L"@DG<F5S<%]E9&ET7U]I;G9A;&ED7W-T;W)E7VQI;5]N=6TG
M(#T^("),:6UI="!V86QU92!I<R!I;G9A;&ED+B(L"@DG<F5S<%]E9&ET7U]L
M:6UI='-?=&ET;&4G(#T^("),:6UI=',B+`H))W)E<W!?961I=%]?;6%X:6UU
M;5]A;&QO=V5D7W)E<W!?9G)E<5]R96%C:&5D)R`]/B`B3G5M8F5R(&]F(&UA
M>&EM=6T@<F5S<&]N<V5S('!E<B!D87D@97AC965D<R!T:&4@9&5F:6YE9"!R
M871E+B!!;&QO=V5D.B`E,2P@<F5Q=65S=&5D.B`E,B(L"@DG<F5S<%]E9&ET
M7U]N;U]F:6QE<U]S96PG(#T^(").;R!F:6QE<R!S96QE8W1E9"XB+`H))W)E
M<W!?961I=%]?;F]?='AT7W-U<'!L:65D)R`]/B`B3F\@=&5X="!S=7!P;&EE
M9"XB+`H))W)E<W!?961I=%]?<F5P;'E?=&ET;&4G(#T^(")297!L>2(L"@DG
M<F5S<%]E9&ET7U]R97!L>5]T;U]A9&1R97-S)R`]/B`B4F5T=7)N(&%D9')E
M<W,B+`H))W)E<W!?961I=%]?<F5P;'E?=&]?:6YV86QI9"<@/3X@(E)E='5R
M;B!A9&1R97-S(&ES(&EN=F%L:60N(BP*"2=R97-P7V5D:71?7W)E<&QY7W5N
M:7%?96UA:6PG(#T^(")297!L>2!T;R!T:&4@=6YI<75E(&4M;6%I;"!A9&1R
M97-S(&YO="!M;W)E('1H86XB+`H))W)E<W!?961I=%]?8V]N9&ET:6]N<U]T
M:71L92<@/3X@(D-O;F1I=&EO;G,B+`H))W)E<W!?961I=%]?<F5S<"<@/3X@
M(D%U=&]R97-P;VYD97(@("(L"@DG<F5S<%]E9&ET7U]R97-P7VYA;64G(#T^
M(")!=71O<F5S<&]N9&5R(&YA;64B+`H))W)E<W!?961I=%]?<F5S<%]N;W1?
M97AI<W0G(#T^(")!=71O<F5S<&]N9&5R(&1O97,@;F]T(&5X:7-T+B(L"@DG
M<F5S<%]E9&ET7U]R97-P7W-T871U<R<@/3X@(D%U=&]R97-P;VYD97(@<W1A
M='5S(BP*"2=R97-P7V5D:71?7W)Q<W1?='AT)R`]/B`G4W!E8VEF>2!T:&4@
M8V]N9&ET:6]N(&9O<B!T:&ES(&%U=&]M871I8R!R97!L>2<L"@DG<F5S<%]E
M9&ET7U]S96QE8W1?9FEL97-?;VY?<V5R=F5R7V9O<E]A='1A8V@G(#T^(")3
M96QE8W0@=&AE(&9I;&5S('EO=2!W86YT('1O(&%T=&%C:"(L"@DG<F5S<%]E
M9&ET7U]S=&]R95]U<%]T;R<@/3X@(E-T;W)E('5P('1O(BP*"2=R97-P7V5D
M:71?7W-U8FI?;&EN95]I;G9A;&ED)R`]/B`B4W5B:F5C="!L:6YE(&ES(&EN
M8V]R<F5C="XB+`H))W)E<W!?961I=%]?=&5X=%]T;V]?8FEG)R`]/B`B5&AE
M(')E<&QY(&UE<W-A9V4@=&5X="!I<R!T;V\@;&%R9V4N(BP*"2=R97-P7V5D
M:71?7W1I;65S7VEN7V%?9&%Y)R`]/B`B=&EM97,@82!D87DN(BP*"2=R97-P
M7V5D:71?7W5N86)L95]D969I;F5?<F5S<%]C;VYD)R`]/B`B56YA8FQE('1O
M(&1E9FEN92!T:&4@875T;W)E<W!O;F1E<B!C;VYD:71I;VXZ("4Q(BP*"2=R
M97-P7V5D:71?7W5N86)L95]D969I;F5?<F5S<%]S=&%T=7,G(#T^(")5;F%B
M;&4@=&\@9&5F:6YE(&%U=&]R97-P;VYD97(@<W1A='5S.B`E,2(L"@DG<F5S
M<%]E9&ET7U]U;F%B;&5?='5R;E]O;E]R97-P)R`]/B`B56YA8FQE('1O('1U
M<FX@;VX@=&AE(&%U=&]R97-P;VYD97(Z("4Q(BP*"2=R97-P7V5D:71?7W5N
M:7%?96UA:6PG(#T^(")U;FEQ=64@92UM86EL(&%D9')E<W-E<R(L"@DG<F5S
M<%]E9&ET7U]C;VYT96YT7W1Y<&4G(#T^("=-86EL('-E;F1I;F<@9F]R;6%T
M)RP*"2=R97-P7V5D:71?7V-O;G1E;G1?='EP95]T97AT)R`]/B`G4&QA:6X@
M=&5X="<L"@DG<F5S<%]E9&ET7U]C;VYT96YT7W1Y<&5?:'1M;"<@/3X@)TA4
M34PG+`H))W)E<W!?961I=%]?8VAA<G-E="<@/3X@)T5N8V]D:6YG)RP*"2=R
M97-T87)T7U]C;VQD9G5S:6]N)R`]/B`B0V]L9$9U<VEO;B`H)3$I(BP*"2=R
M97-T87)T7U]C;VQD9G5S:6]N7VEN<W1A;&QA=&EO;E]T>7!E)R`]/B`B26YS
M=&%L;&%T:6]N('1Y<&4Z("4Q(BP*"2=R97-T87)T7U]D;G,G(#T^("=$3E,@
M4V5R=F5R("@E,2DG+`H))W)E<W1A<G1?7V1R=V5B)R`]/B`G1'(N5V5B(&%N
M=&EV:7)U<R<L"@DG<F5S=&%R=%]?;6%I;"<@/3X@(DE-05`O4$]0,R!397)V
M97(@*"4Q*2(L"@DG<F5S=&%R=%]?;7-S<6PG(#T^(")-:6-R;W-O9G0@4U%,
M('-E<G9E<B(L"@DG<F5S=&%R=%]?<&]S=&=R97-Q;"<@/3X@(E!O<W1G<F53
M44PB+`H))W)E<W1A<G1?7W!S82<@/3X@(E-E<G9I8V5S(&UA;F%G96UE;G0B
M+`H))W)E<W1A<G1?7W-M='`G(#T^(")33510(%-E<G9E<B`H)3$I(BP*"2=R
M97-T87)T7U]S<&%M87-S87-S:6XG(#T^(")3<&%M07-S87-S:6XB+`H))W)E
M<W1A<G1?7W-T=6YN96PG(#T^(")3='5N;F5L(BP*"2=R97-T87)T7U]T;VUC
M870G(#T^(")4;VUC870B+`H))W)E<W1A<G1?7W=E8B<@/3X@(E=E8B!397)V
M97(@*"4Q*2(L"@DG<FU?9&]M86EN<U]?<V]M95]D;VUA:6YS7V%R95]N;W1?
M97AI<W0G(#T^(")3;VUE(&]F('1H92!S<&5C:69I960@9&]M86EN<R!D;R!N
M;W0@97AI<W0N(%1H97D@:&%V92!B965N('!O<W-I8FQY(')E;6]V960@8GD@
M86YO=&AE<B!U<V5R+B(L"@DG<G!T7V-L7V1O;5]D871A7V)A<V5S)R`]/B`B
M1$)A<V5S(BP*"2=R<'1?8VQ?9&]M7VUA:6Q?9W)O=7!S)R`]/B`B34=R;W5P
M<R(L"@DG<G!T7V-L7V1O;5]M86EL7VQI<W1S)R`]/B`B34QI<W1S(BP*"2=R
M<'1?8VQ?9&]M7VUA:6Q?<F5S<',G(#T^(")!4F5S<"XB+`H))W)P=%]C;%]D
M;VU?<&]S=&)O>&5S)R`]/B`B34)O>&5S(BP*"2=R<'1?8VQ?9&]M7W)E9&ER
M96-T<R<@/3X@(E)E9&ER+B(L"@DG<G!T7V-L7V1O;5]S=6)D;VUA:6YS)R`]
M/B`B4W5B9&]M(BP*"2=R<'1?8VQ?9&]M7W=E8E]U<V5R<R<@/3X@(E=5<V5R
M<R(L"@DG<G!T7V-L7V1O;5]W96)A<'!S)R`]/B`B5T%P<',B+`H))W)P=%]C
M;%]R97!O<G1?9F]R7V-L7U\G(#T^(")297!O<G0@;VX@8VQI96YT("4Q(BP*
M"2=R<'1?8VQ?<V5C=&EO;E]D;VUA:6YS)R`]/B`B1&]M86EN<R(L"@DG<G!T
M7V-L7W-E8W1I;VY?9G5L;%]D;VUA:6YS)R`]/B`B1&]M86EN<R(L"@DG<G!T
M7V-L7W-E8W1I;VY?9V5N97)A;"<@/3X@(D=E;F5R86PB+`H))W)P=%]C<F5A
M=&4G(#T^(")#<F5A=&4@<F5P;W)T(BP*"2=R<'1?96UP='DG(#T^(")4:&4@
M<F5P;W)T('-H;W5L9"!C;VYT86EN(&%T(&QE87-T(&]N92!S96-T:6]N(BP*
M"2=R<'1?9&5F875L=%]R97!O<G0G(#T^(")5<V4@87,@9&5F875L="!R97!O
M<G0B+`H))W)P=%]D;VU?<F5P;W)T7V9O<E]D;VU?7R<@/3X@(D1O;6%I;B!R
M97!O<G0@9F]R("4Q(BP*"2=R<'1?9&]M7W-E8W1I;VY?9&%T86)A<V5S)R`]
M/B`B1&%T86)A<V5S(BP*"2=R<'1?9&]M7W-E8W1I;VY?9G5L;%]D871A8F%S
M97,G(#T^(")$871A8F%S97,B+`H))W)P=%]D;VU?<V5C=&EO;E]F=6QL7VUA
M:6QL:7-T<R<@/3X@(DUA:6QI;F<@;&ES=',B+`H))W)P=%]D;VU?<V5C=&EO
M;E]F=6QL7VUA:6QN86UE<R<@/3X@(DUA:6P@;F%M97,B+`H))W)P=%]D;VU?
M<V5C=&EO;E]F=6QL7W=E8G5S97)S)R`]/B`B5V5B('5S97)S(BP*"2=R<'1?
M9&]M7W-E8W1I;VY?9G5L;%]S:71E87!P<R<@/3X@)U-I=&4@87!P;&EC871I
M;VYS)RP*"2=R<'1?9&]M7W-E8W1I;VY?9G5L;%]T;VUC870G(#T^(")*879A
M(&%P<&QI8V%T:6]N<R(L"@DG<G!T7V1O;5]S96-T:6]N7V=E;F5R86PG(#T^
M(")'96YE<F%L(BP*"2=R<'1?9&]M7W-E8W1I;VY?:&]S=&EN9R<@/3X@(DAO
M<W1I;F<B+`H))W)P=%]D;VU?<V5C=&EO;E]L:7-T7W1O;6-A="<@/3X@(DIA
M=F$@87!P;&EC871I;VYS(BP*"2=R<'1?9&]M7W-E8W1I;VY?;6%I;&QI<W1S
M)R`]/B`B36%I;&EN9R!L:7-T<R(L"@DG<G!T7V1O;5]S96-T:6]N7VUA:6QN
M86UE<R<@/3X@(DUA:6P@;F%M97,B+`H))W)P=%]D;VU?<V5C=&EO;E]S:71E
M87!P<R<@/3X@)U-I=&4@87!P;&EC871I;VYS)RP*"2=R<'1?9&]M7W-E8W1I
M;VY?=&]M8V%T)R`]/B`B2F%V82!A<'!L:6-A=&EO;G,B+`H))W)P=%]D;VU?
M<V5C=&EO;E]W96)U<V5R<R<@/3X@(E=E8B!U<V5R<R(L"@DG<G!T7V1O;5]T
M:71L95]W85]S=&%T=7,G(#T^(")3(BP*"2=R<'1?961I=%]?)R`]/B`B161I
M="!R97!O<G0@)3$B+`H))W)P=%]E;G1E<E]E;6%I;%]A9&1R97-S)R`]/B`B
M16YT97(@=&AE(&4M;6%I;"!A9&1R97-S('1H92!R97!O<G0@=VEL;"!B92!D
M96QI=F5R960@=&\N(BP*"2=R<'1?;&ES="<@/3X@(D-U<W1O;2!R97!O<G0@
M;&%Y;W5T<R(L"@DG<G!T7VYA;64G(#T^(")297!O<G0@;F%M92(L"@DG<G!T
M7W)E;6]V95]R97!O<G1S)R`]/B`B5&AE(&9O;&QO=VEN9R!R97!O<G0@;&%Y
M;W5T<R!W:6QL(&)E(')E;6]V960Z(BP*"2=R<'1?<F5P;W)T<R<@/3X@(E)E
M<&]R=',B+`H))W)P=%]S96-T:6]N7V9U;&PG(#T^(")&=6QL(BP*"2=R<'1?
M<V5C=&EO;E]N;VYE)R`]/B`B3F]N92(L"@DG<G!T7W-E8W1I;VY?<W5M;6%R
M>2<@/3X@(E-U;6UA<GDB+`H))W)P=%]S96QE8W1?<F5P;W)T<U]F;W)?<F5M
M;W9E)R`]/B`B4V5L96-T('1H92!R97!O<G0@;&%Y;W5T<R!T;R!B92!R96UO
M=F5D+B(L"@DG<G!T7V1E9F%U;'1?9G5L;"<@/3X@)T9U;&P@4F5P;W)T)RP*
M"2=R<'1?9&5F875L=%]S=6UM87)Y)R`]/B`G4W5M;6%R>2!297!O<G0G+`H*
M"2\O(&5N9"!O9B!K;V]P97(@<&%R=`H*"2\O(&=R97D@<&%R="`H<G-E<W-I
M;VX@<W5P<&]R="D*"2=R<V5S<VEO;E]N;U]A<&E?<G!C7V5R<FUS9R<@/3X@
M(E!L97-K($%022!24$,@:7,@;F]T(&EN<W1A;&QE9"!O;B!T:&4@<F5M;W1E
M(&AO<W0N($-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<B!F;W(@
M<W5P<&]R="XB+`H))W)S97-S:6]N7VYO7V%C8V]U;G1?97)R;7-G)R`]/B`B
M56YA8FQE('1O(&%C8V5S<R!T:&4@<F5M;W1E('-E<G9I8V4@=6YD97(@>6]U
M<B!A8V-O=6YT+B!4:&4@;6]S="!C;VUM;VX@<F5A<V]N(&ES('1H870@=&AE
M('-E<G9I8V4@9F]R('EO=7(@86-C;W5N="!I<R!N;W0@86-T:79A=&5D('EE
M="X@4&QE87-E+"!W86ET(&9O<B!S979E<F%L(&UI;G5T97,L(&%N9"!T:&5N
M('1R>2!A9V%I;BX@268@>6]U(&5N8V]U;G1E<B!T:&ES(&5R<F]R(&%G86EN
M+"!C;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(BP*"2=R<V5S
M<VEO;E]N;U]D;VUA:6Y?97)R;7-G)R`]/B`B56YA8FQE('1O(&%C8V5S<R!T
M:&4@<F5M;W1E('-E<G9I8V4@9F]R('1H:7,@9&]M86EN+B!4:&4@;6]S="!C
M;VUM;VX@<F5A<V]N(&ES('1H870@=&AE('-E<G9I8V4@9F]R('1H:7,@9&]M
M86EN(&ES(&YO="!A8W1I=F%T960@>65T+B!0;&5A<V4L('=A:70@9F]R('-E
M=F5R86P@;6EN=71E<RP@86YD('1H96X@=')Y(&%G86EN+B!)9B!Y;W4@96YC
M;W5N=&5R('1H:7,@97)R;W(@86=A:6XL(&-O;G1A8W0@>6]U<B!S>7-T96T@
M861M:6YI<W1R871O<BXB+`H))W)S97-S:6]N7W5N:VYO=VY?97)R;7-G)R`]
M/B`B5&AE(')E;6]T92!S97)V97(@:&%S(')E:F5C=&5D('1H92!A='1E;7!T
M('1O(&5S=&%B;&ES:"!A('-E<W-I;VXN($-O;G1A8W0@>6]U<B!S>7-T96T@
M861M:6YI<W1R871O<B!F;W(@<W5P<&]R="X@5&AE(&5R<F]R('=A<SH@)3$B
M+`H))W)S97-S:6]N7W5N:VYO=VXR7V5R<FUS9R<@/3X@(E5N:VYO=VX@97)R
M;W(@=VAI;&4@97-T86)L:7-H:6YG(&$@<F5M;W1E('-E<W-I;VXN($UO<W0@
M<')O8F%B;'D@=&AE(')E;6]T92!S97)V97(@9&]E<R!N;W0@<F5S<&]N9"!P
M<F]P97)L>2!O<B!D;V5S(&YO="!A;G-W97(@870@86QL+B!!<VL@>6]U<B!S
M>7-T96T@861M:6YI<W1R871O<B!T;R!C:&5C:R!F;W(@97)R;W(@9&5T86EL
M<R!I;B!T:&4@07!A8VAE(&5R<F]R(&QO9RXB+`H))W)S97-S:6]N7VYO7V-O
M;FYE8W1?97)R;7-G)R`]/B`B56YA8FQE('1O(&%C8V5S<R!T:&4@<F5M;W1E
M('-E<G9I8V4Z(&-O;FYE8W1I;F<@=&\@<F5M;W1E('-E<W-I;VX@9F%I;&5D
M+B!#;VYT86-T('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(@9F]R('-U<'!O
M<G0N(BP*"2\O(&5N9"!O9B!G<F5Y('!A<G0*"@DO+R!P:70@<&%R=`H*"2=R
M<'1?<V5N9%]R97!O<G1?8GE?96UA:6Q?97)R;W)?7R<@/3X@(D5R<F]R('-E
M;F1I;F<@=&AE(')E<&]R=#H@)3$B+`H))W)P=%]S96YD7W)E<&]R=%]B>5]E
M;6%I;%]O:U]?)R`]/B`B5&AE(')E<&]R="!H87,@8F5E;B!S96YT('1O("4Q
M+B(L"@DG<V%?86-T:6]N7V1E;"<@/3X@(D1E;&5T92(L"@DG<V%?86-T:6]N
M7V1E<V,G(#T^(")7:&%T('1O(&1O('=I=&@@<W!A;2!M86EL(BP*"2=S85]A
M8W1I;VY?<V%V92<@/3X@(DUA<FL@87,@<W!A;2!A;F0@<W1O<F4@:6X@;6%I
M;&)O>"(L"@DG<V%?861M:6Y?8FQA8VML:7-T)R`]/B`B061M:6YI<W1R871O
M<B=S(&)L86-K(&QI<W0B+`H))W-A7V%D;6EN7W=H:71E;&ES="<@/3X@(D%D
M;6EN:7-T<F%T;W(G<R!W:&ET92!L:7-T(BP*"2=S85]B;&%C:VQI<W0G(#T^
M(")";&%C:R!L:7-T(BP*"2=S85]B;&%C:VQI<W1?9&5S8R<@/3X@(D%L=V%Y
M<R!M87)K(&%S('-P86T@;6%I;"!F<F]M(&%D9')E<W,B+`H))W-A7V)Y7W1A
M9R<@/3X@(F)Y('1A9R(L"@DG<V%?8V9G7W5S95]P;VQI8WDG(#T^(")5<V%G
M92!P;VQI8WD@<V5T=&EN9W,B+`H))W-A7V-O;F9?;&ES=%]B;&%C:R<@/3X@
M(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-E;&5C=&5D
M('!A='1E<FYS(&9R;VT@=&AE(&)L86-K(&QI<W0_(BP*"2=S85]C;VYF7VQI
M<W1?:6=N;W)E)R`]/B`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V
M92!T:&4@<V5L96-T960@<&%T=&5R;G,@9G)O;2!T:&4@:6=N;W)E(&QI<W0_
M(BP*"2=S85]C;VYF7VQI<W1?=VAI=&4G(#T^(")!<F4@>6]U('-U<F4@>6]U
M('=A;G0@=&\@<F5M;W9E('1H92!S96QE8W1E9"!P871T97)N<R!F<F]M('1H
M92!W:&ET92!L:7-T/R(L"@DG<V%?9&)?9&5L7V-O;F9I<FTG(#T^(")!<F4@
M>6]U('-U<F4@>6]U('=A;G0@=&\@8VQE87(@=&AE(%-P86U!<W-A<W-I;B=S
M(&1A=&%B87-E/R(L"@DG<V%?96UL7VEN7VEG;F]R96QI<W0G(#T^(")%+6UA
M:6P@:7,@:6X@=&AE(&EG;F]R92!L:7-T(BP*"2=S85]E;6Q?<&%T=&5R;B<@
M/3X@(D4M;6%I;"!P871T97)N(BP*"2=S85]E;7!T>5]E;6%I;"<@/3X@(D-A
M;FYO="!A9&0@96UP='D@92UM86EL('!A='1E<FXN(BP*"2=S85]E>&ES='-?
M96UA:6PG(#T^(")3=6-H(&4M;6%I;"!P871T97)N(&%L<F5A9'D@97AI<W1S
M+B(L"@DG<V%?9&ES86)L961?7VUA:6QN86UE7VYO=%]F:6QT97)I;F<G(#T^
M(")4:&4@8W5R<F5N="!S97)V97(@<V5T=&EN9W,@9&\@;F]T(&%L;&]W('1O
M('5S92!M86EL(&9I;'1E<FEN9R!F;W(@=&AI<R!M86EL(&YA;64B+`H))W-A
M7V1I<V%B;&5D7U]F:6QT97)I;F=?:7-?9&ES86)L960G(#T^("=3<&%M(&9I
M;'1E<FEN9R!W87,@9&ES86)L960@8GD@=&AE('-E<G9E<B!A9&UI;FES=')A
M=&]R)RP*"2=S85]E;F%B;&5?9FEL=&5R)R`]/B`B16YA8FQE('-P86T@9FEL
M=&5R:6YG(BP*"2=S85]H:71S7W)E<2<@/3X@(DAI=',@<F5Q=6ER960@9F]R
M('-P86TB+`H))W-A7VAI='-?;F]T7VYU;6)E<B<@/3X@)U1H92!N=6UB97(@
M>6]U('-P96-I9FEE9"!I<R!I;G9A;&ED+B!9;W4@<VAO=6QD('5S92!A('!O
M<VET:79E(&EN=&5G97(N)RP*"2=S85]I9VYO<F5L:7-T)R`]/B`B4V5R=F5R
M+7=I9&4@:6=N;W)E(&QI<W0B+`H))W-A7VEG;F]R96QI<W1?9&5S8R<@/3X@
M(D1O(&YO="!F:6QT97(@;6%I;"!F;W(@=&AE<V4@86-C;W5N=',B+`H))W-A
M7VUO9&EF>5]S=6)J)R`]/B`B36]D:69Y('-P86T@;6%I;"!S=6)J96-T(BP*
M"2=S85]P871T97)N7VEN7V)L86-K;&ES="<@/3X@(E!A='1E<FX@86QR96%D
M>2!E>&ES=',@:6X@8FQA8VL@;&ES="(L"@DG<V%?<&%T=&5R;E]I;E]I9VYO
M<F5L:7-T)R`]/B`B4&%T=&5R;B!A;')E861Y(&5X:7-T<R!I;B!I9VYO<F4@
M;&ES="(L"@DG<V%?<&%T=&5R;E]I;E]W:&ET96QI<W0G(#T^(")0871T97)N
M(&%L<F5A9'D@97AI<W1S(&EN('=H:71E(&QI<W0B+`H))W-A7W!A='1E<FY?
M:7-?:6YV86QI9"<@/3X@(E!A='1E<FX@:7,@:6YV86QI9"XB+`H))V)T7W-A
M7V-L96%R7V1B)R`]/B`G0VQE87(@4W!A;2!&:6QT97(@1&%T86)A<V4G+`H)
M)V)T7W-A7V9O<F=E="<@/3X@)T9O<F=E="!)="<L"@DG8G1?<V%?;&5A<FY?
M87-?<W!A;2<@/3X@(DET)W,@4W!A;2$B+`H))V)T7W-A7VQE87)N7V%S7VYO
M;G-P86TG(#T^("))="=S($YO="!3<&%M(BP*"2=S85]T<F%I;F5R7U]P86=E
M7W1I=&QE)R`]/B`G4W!A;2!F:6QT97(@=')A:6YI;F<G+`H))W-A7W1R86EN
M97)?7W1O;VQS7VQE9V5N9"<@/3X@)U1O;VQS)RP*"2=S85]T<F%I;F5R7U]I
M;F9O7VQE9V5N9"<@/3X@)TEN9F\G+`H))W-A7W1R86EN97)?7VUE<W-A9V5S
M7VQI<W1?;&5G96YD)R`]/B`G365S<V%G97,@:6X@>6]U<B!M86EL8F]X)RP*
M"2=S85]T<F%I;F5R7U]C)R`]/B`G5"<L"@DG<V%?=')A:6YE<E]?;"<@/3X@
M)TPG+`H))W-A7W1R86EN97)?7W-U8FIE8W0G(#T^("=3=6)J96-T)RP*"2=S
M85]T<F%I;F5R7U]F<F]M)R`]/B`G1G)O;2<L"@DG<V%?=')A:6YE<E]?9&%T
M92<@/3X@)T1A=&4G+`H))W-A7W1R86EN97)?7VEN9F]?=&5X="<@/3X@)TUE
M<W-A9V5S(&QE87)N960Z("4Q(&%S('-P86TL("4R(&%S(&YO;BUS<&%M+"`E
M,R!T;W1A;"XG+`H))W-A7W1R86EN97)?7VUE<W-A9V5S)R`]/B`G;65S<V%G
M92AS*2<L"@DG<V%?=')A:6YE<E]?<V5L96-T7U]A;&PG(#T^("=!;&PG+`H)
M)W-A7W1R86EN97)?7W-E;&5C=%]?<W!A;5]O;FQY)R`]/B`G4W!A;2<L"@DG
M<V%?=')A:6YE<E]?<V5L96-T7U]H86U?;VYL>2<@/3X@)TYO;BU3<&%M)RP*
M"2=S85]T<F%I;F5R7U]S96QE8W1?7W5N:VYO=VY?;VYL>2<@/3X@)U5N:VYO
M=VXG+`H))W-A7W1R86EN97)?7V-A;FYO=%]R96UO=F5?;65S<V%G97,G(#T^
M("=#86YN;W0@<F5M;W9E('1H92!S96QE8W1E9"!M97-S86=E<R!F<F]M('1H
M92!M86EL8F]X+B<L"@DG<V%?=')A:6YE<E]?<F5M;W9E7VUE<W-A9V5S7V-O
M;F9I<FTG(#T^("=!<F4@>6]U('-U<F4@=&AA="!Y;W4@=VES:"!T;R!R96UO
M=F4@=&AE('-E;&5C=&5D(&UE<W-A9V5S(&9R;VT@=&AE(&UA:6QB;W@_)RP*
M"2=S85]S96QE8W1?96UA:6PG(#T^(")396QE8W0@870@;&5A<W0@;VYE(&4M
M;6%I;"!P871T97)N(&9R;VT@=&AE(&QI<W0@=&\@<F5M;W9E(&ET+B(L"@DG
M<V%?<W)V7V)L86-K;&ES="<@/3X@(E-E<G9E<BUW:61E(&)L86-K(&QI<W0B
M+`H))W-A7W-R=E]C9F<G(#T^(")397)V97(@=VED92!S971T:6YG<R(L"@DG
M<V%?<W)V7W-E='1I;F=S)R`]/B`B4V5R=F5R('-E='1I;F=S(BP*"2=S85]S
M<G9?=VAI=&5L:7-T)R`]/B`B4V5R=F5R+7=I9&4@=VAI=&4@;&ES="(L"@DG
M<V%?=7-E7W-R=E]S971T:6YG<R<@/3X@(E5S92!S97)V97(@=VED92!S971T
M:6YG<R(L"@DG<V%?=7-E<E]B;&%C:VQI<W0G(#T^(")5<V5R)W,@8FQA8VL@
M;&ES="(L"@DG<V%?=7-E<E]W:&ET96QI<W0G(#T^(")5<V5R)W,@=VAI=&4@
M;&ES="(L"@DG<V%?=7-R7V1I<V%B;&5D7V)Y7W-R=B<@/3X@(D%D;6EN:7-T
M<F%T;W(@:&%S(&1I<V%B;&5D('5S97(M8V]N9FEG=7)E9"!S<&%M(&9I;'1E
M<FEN9R(L"@DG<V%?=7-R7VYO7W!O<W1B;W@G(#T^(")5<V5R(&AA<R!N;R!M
M86EL8F]X(&5N86)L960B+`H))W-A7W5S<E]S971T:6YG<R<@/3X@(E!E<G-O
M;F%L('-E='1I;F=S(BP*"2=S85]W:&ET96QI<W0G(#T^(")7:&ET92!L:7-T
M(BP*"2=S85]W:&ET96QI<W1?9&5S8R<@/3X@(DYE=F5R(&UA<FL@87,@<W!A
M;2!M86EL(&9R;VT@861D<F5S<R(L"@DG<V5R=F5R7U]A9&UI;E]I;F9O)R`]
M/B`B061M:6YI<W1R871O<B!I;F9O<FUA=&EO;B(L"@DG<V5R=F5R7U]C=')L
M7W!A;F5L)R`]/B`B0V]N=')O;"!086YE;"(L"@DG<V5R=F5R7U]E;G1E<E]B
M=6=?97-S96YC95]B96QO=R<@/3X@(D5N=&5R('1H92!B=6<@9&5S8W)I<'1I
M;VX@8F5L;W<B+`H))W-E<G9E<E]?<&]W97)?;6%N86=E;65N="<@/3X@(E!O
M=V5R(&UA;F%G96UE;G0B+`H))W-E<G9E<E]?<V5R=FEC97,G(#T^(")397)V
M:6-E<R(L"@DG<V5R=F5R7U]S>7-T96TG(#T^(")3>7-T96TB+`H))W-E<G9E
M<E]?=&ET;&4G(#T^(")397)V97(@061M:6YI<W1R871I;VXB+`H))W-E<G9E
M<E]?=V%R;FEN9U]R96)O;W0G(#T^(")787)N:6YG(2!4:&4@<WES=&5M('=I
M;&P@;F]W(&)E(')E8F]O=&5D+B!0<F]C965D/R(L"@DG<V5R=F5R7U]W87)N
M:6YG7W-H=71D;W=N)R`]/B`B5T%23DE.1SH@5&AI<R!O<&5R871I;VX@=VEL
M;"!S:'5T('1H92!S97)V97(@9&]W;BX@(%1H92!S97)V97(@8V%N;F]T7&YB
M92!R97-T87)T960@<F5M;W1E;'D@8GD@;65A;G,@;V8@=&AI<R!S;V9T=V%R
M92X@07)E('EO=2!S=7)E('EO=2!W86YT('1O('!R;V-E960_(BP*"2=S97)V
M97)?7W=I;&Q?<F5B;V]T)R`]/B`B5&AE('-Y<W1E;2!W:6QL(&YO=R!B92!R
M96)O;W1E9"XB+`H))W-E<G9E<E]?=VEL;%]S:'5T9&]W;B<@/3X@(E1H92!S
M>7-T96T@:7,@<VAU='1I;F<@9&]W;BXB+`H))W-E<G9E<E]P<F5F97)E;F-E
M<U]?861M:6Y?;&%N9W5A9V4G(#T^(")!9&UI;FES=')A=&]R)W,@:6YT97)F
M86-E(&QA;F=U86=E(BP*"2=S97)V97)?<')E9F5R96YC97-?7V%D;6EN7W-K
M:6XG(#T^(")!9&UI;FES=')A=&]R)W,@:6YT97)F86-E('-K:6XB+`H))W-E
M<G9E<E]P<F5F97)E;F-E<U]?86QL;W=?861M:6Y?;75L=&EP;'E?;&]G:6XG
M(#T^(")!;&QO=R!M=6QT:7!L92!S97-S:6]N<R!U;F1E<B!A9&UI;FES=')A
M=&]R)W,@;&]G:6XB+`H))W-E<G9E<E]P<F5F97)E;F-E<U]?8V]U;G1?9&ES
M:U]S<&%C92<@/3X@(DEN8VQU9&4@:6X@=&AE(&1I<VL@<W!A8V4@=7-A9V4@
M8V%L8W5L871I;VXB+`H))W-E<G9E<E]P<F5F97)E;F-E<U]?8V]U;G1?=')A
M9F9I8R<@/3X@(DEN8VQU9&4@:6X@=&AE('1R869F:6,@8V%L8W5L871I;VXB
M+`H))W-E<G9E<E]P<F5F97)E;F-E<U]?8V]U;G1?='EP92<@/3X@)U=H96X@
M8V%L8W5L871I;F<@9&ES:R!S<&%C92!U<V%G92P@8V]U;G0G+`H))W-E<G9E
M<E]P<F5F97)E;F-E<U]?8V]U;G1?='EP95]?8GET92<@/3X@)V9I;&4@<VEZ
M92<L"@DG<V5R=F5R7W!R969E<F5N8V5S7U]C;W5N=%]T>7!E7U]B;&]C:R<@
M/3X@)V%M;W5N="!O9B!D:7-K('-P86-E('5S960G+`H))W-E<G9E<E]P<F5F
M97)E;F-E<U]?9&5F875L=%]L86YG=6%G92<@/3X@(D1E9F%U;'0@;&]C86QE
M(BP*"2=S97)V97)?<')E9F5R96YC97-?7V1E9F%U;'1?<VMI;B<@/3X@(D1E
M9F%U;'0@<VMI;B(L"@DG<V5R=F5R7W!R969E<F5N8V5S7U]D:7-P;&%Y)R`]
M/B`B1&ES<&QA>2(L"@DG<V5R=F5R7W!R969E<F5N8V5S7U]I;F-L=61E7V1A
M=&%B87-E<R<@/3X@(F1A=&%B87-E<R(L"@DG<V5R=F5R7W!R969E<F5N8V5S
M7U]I;F-L=61E7V1O;6%I;F1U;7!S)R`]/B`B9&]M86EN(&)A8VMU<"!F:6QE
M<R(L"@DG<V5R=F5R7W!R969E<F5N8V5S7U]I;F-L=61E7VEN8V]M:6YG)R`]
M/B`B;VYL>2!I;F)O=6YD('1R869F:6,B+`H))W-E<G9E<E]P<F5F97)E;F-E
M<U]?:6YC;'5D95]I;F-O;6EN9U]A;F1?;W5T9V]I;F<G(#T^(")I;F)O=6YD
M(&%N9"!O=71B;W5N9"!T<F%F9FEC(BP*"2=S97)V97)?<')E9F5R96YC97-?
M7VEN8VQU9&5?;&]G<R<@/3X@(FQO9R!F:6QE<R(L"@DG<V5R=F5R7W!R969E
M<F5N8V5S7U]I;F-L=61E7VUA:6QB;WAE<R<@/3X@(FUA:6QB;WAE<R(L"@DG
M<V5R=F5R7W!R969E<F5N8V5S7U]I;F-L=61E7VUA:6QL:7-T<R<@/3X@(FUA
M:6QI;F<@;&ES=',B+`H))W-E<G9E<E]P<F5F97)E;F-E<U]?:6YC;'5D95]O
M=71G;VEN9R<@/3X@(F]N;'D@;W5T8F]U;F0@=')A9F9I8R(L"@DG<V5R=F5R
M7W!R969E<F5N8V5S7U]I;F-L=61E7W=E8F%P<',G(#T^(")*879A(&%P<&QI
M8V%T:6]N<R(L"@DG<V5R=F5R7W!R969E<F5N8V5S7U]K965P7W-T871S)R`]
M/B`B4F5T86EN('1R869F:6,@<W1A=&ES=&EC<R!F;W(B+`H))W-E<G9E<E]P
M<F5F97)E;F-E<U]?;6%X7V)U='1O;E]L96YG=&@G(#T^(")"=71T;VX@;&%B
M96P@;&5N9W1H(BP*"2=S97)V97)?<')E9F5R96YC97-?7W)E<W1A<G1?87!A
M8VAE7VEN=&5R=F%L)R`]/B`B07!A8VAE(')E<W1A<G0@:6YT97)V86PB+`H)
M)W-E<G9E<E]P<F5F97)E;F-E<U]?<W1A=%]W87)N:6YG)R`]/B`B5&AE(&-H
M86YG97,@;6%D92!T;R!T:&4@9&ES:R!S<&%C92!U<V%G92!C86QC=6QA=&EO
M;B!S8VAE;64@=VEL;"!T86ME(&5F9F5C="!O;FQY(&1U<FEN9R!N97AT('-T
M871I<W1I8W,@8V%L8W5L871I;VXN(BP*"2=S97)V97)?<')E9F5R96YC97-?
M7W1I=&QE)R`]/B`B4V5R=F5R('!R969E<F5N8V5S(BP*"2=S97)V97)?;6%I
M;%]?=&ET;&4G(#T^(")397)V97(M=VED92!M86EL('!R969E<F5N8V5S(BP*
M"2=M86EL7U]T86)S7W!R969E<F5N8V5S)R`]/B`B4')E9F5R96YC97,B+`H)
M)VUA:6Q?7W1A8G-?=VAI=&5?;&ES="<@/3X@(E=H:71E($QI<W0B+`H))VUA
M:6Q?7W1A8G-?8FQO8VME9%]D;VUA:6YS)R`]/B`B0FQA8VL@3&ES="(L"@DG
M;6%I;%]?=&%B<U]M86EL7W%U975E)R`]/B`B36%I;"!1=65U92(L"@DG<V5R
M=F5R7W!R969E<F5N8V5S7U]U<V5?=F]C86)U;&%R>2<@/3X@(D-H96-K('1H
M92!P87-S=V]R9',@9F]R(&UA:6QB;WAE<R!I;B!T:&4@9&EC=&EO;F%R>2(L
M"@DG<V5R=F5R<U]L:7-T7U]A8V-O=6YT7V1I<V%B;&5D)R`]/B`B26YF;W)M
M871I;VX@<75E<GD@:7,@9&ES86)L960@9F]R('1H:7,@<V5R=F5R+B(L"@DG
M<V5R=F5R<U]L:7-T7U]P;&5A<V5?=V%I="<@/3X@(E%U97)Y:6YG('-L879E
M('-E<G9E<G,N("4Q(%1H:7,@;W!E<F%T:6]N(&UI9VAT('1A:V4@<V]M92!T
M:6UE+B`E,B!0;&5A<V4@=V%I="XN+B(L"@DG<V5R=F5R<U]L:7-T7U]R96UO
M=F5?<&%G95]T:71L92<@/3X@(E1H92!F;VQL;W=I;F<@<VQA=F4@<V5R=F5R
M(&%C8V]U;G1S('=I;&P@8F4@<F5M;W9E9#HB+`H))W-E<G9E<G-?;&ES=%]?
M<V5L96-T7W-L879E7W-E<G9E<G-?=&]?<F5M;W9E)R`]/B`B4V5L96-T('1H
M92!S;&%V92!S97)V97)S('1O(&)E(')E;6]V960N(BP*"2=S97)V97)S7VQI
M<W1?7W1O=&%L7V9I;&5S)R`]/B`B4VQA=F4@<V5R=F5R<R(L"@DG<V5R=F5R
M<U]L:7-T7U]U;F%B;&5?=&]?9V5T7W-L879E<U]N=6UB97(G(#T^(")5;F%B
M;&4@=&\@9&5T97)M:6YE('1H92!N=6UB97(@;V8@<VQA=F4@<V5R=F5R<R(L
M"@DG<V5R=F5R<U]L:7-T7U]U;F%B;&5?=&]?<F5M;W9E)R`]/B`B56YA8FQE
M('1O(')E;6]V92!T:&4@<VQA=F4@<V5R=F5R(&%C8V]U;G0Z("4Q(BP*"2=S
M97)V97)S7VQI<W1?7WEO=5]H879E7W1O;U]M86YY7W-L879E<R<@/3X@(EEO
M=2!H879E(&UO<F4@<VQA=F4@<V5R=F5R<R!A8V-O=6YT<R!S970@=7`@=&AA
M;B!I="!I<R!A;&QO=V5D(&)Y('EO=7(@;&EC96YS92!K97DN(BP*"2=S97)V
M97)T<F%F9FEC;&ES=%]H96%D97(G(#T^(")397)V97(@=')A9F9I8R(L"@DG
M<V5S<VEO;E]?:6YV86QI9%]I9&QE7W1I;64G(#T^(")397-S:6]N(&ED;&4@
M=&EM92!I<R!I;G9A;&ED+B(L"@DG<V5S<VEO;E]?:6YV86QI9%]L;V=I;E]A
M='1E;7!T<R<@/3X@(DEN=F%L:60@;&]G:6X@871T96UP=',@=F%L=64@<VAO
M=6QD(&)E(&$@<&]S:71I=F4@:6YT96=E<BXB+`H))W-E<W-I;VY?7VEN=F%L
M:61?;&]G:6Y?:6YT97)V86PG(#T^("));G9A;&ED(&QO9VEN(&EN=&5R=F%L
M('9A;'5E('-H;W5L9"!B92!A('!O<VET:79E(&EN=&5G97(N(BP*"2=S97-S
M:6]N7U]I;G9A;&ED7VQO9VEN7VQO8VM?=&EM92<@/3X@(DEN=F%L:60@;&]G
M:6X@;&]C:R!T:6UE('9A;'5E('-H;W5L9"!B92!A('!O<VET:79E(&EN=&5G
M97(N(BP*"2=S97-S:6]N<U]?86=R965M96YT)R`]/B`B665S+"!)('=I<V@@
M=&\@96YD('1H97-E('-E<W-I;VYS+B(L"@DG<V5S<VEO;G-?7VEN=E]L;V=I
M;E]A='1E;7!T<R<@/3X@(DEN=F%L:60@;&]G:6X@871T96UP=',B+`H))W-E
M<W-I;VYS7U]I;G9?;&]G:6Y?:6YT97)V86PG(#T^("));G9A;&ED(&QO9VEN
M(&EN=&5R=F%L(BP*"2=S97-S:6]N<U]?:6YV7VQO9VEN7VQO8VM?=&EM92<@
M/3X@(DEN=F%L:60@;&]G:6X@;&]C:R!T:6UE(BP*"2=S97-S:6]N<U]?;6EN
M)R`]/B`B36EN=71E<R(L"@DG<V5S<VEO;G-?7W)E<75I<F5D7V9I96QD<R<@
M/3X@(E)E<75I<F5D(&9I96QD<RXB+`H))W-E<W-I;VYS7U]S96QE8W1?<V5S
M<VEO;G-?9F]R7W)E;6]V92<@/3X@(E-E;&5C="!T:&4@<V5S<VEO;G,@=&\@
M8F4@96YD960N(BP*"2=S97-S:6]N<U]?<V5S<VEO;E]I9&QE7W1I;64G(#T^
M(")397-S:6]N(&ED;&4@=&EM92(L"@DG<V5S<VEO;G-?7W-E<W-I;VY?<V5T
M=7`G(#T^("),;V=I;B!3971T:6YG<R(L"@DG<V5S<VEO;G-?7W-E<W-I;VYS
M7VUA;F%G96UE;G0G(#T^(")397-S:6]N<R!-86YA9V5M96YT(BP*"2=S97-S
M:6]N<U]?=6YA8FQE7W-E='5P7VEN=F%L:61?;&]G:6Y?871T96UP=',G(#T^
M(")5;F%B;&4@=&\@<V5T('5P('1H92!N=6UB97(@;V8@:6YV86QI9"!L;V=I
M;B!A='1E;7!T<SH@)3$B+`H))W-E<W-I;VYS7U]U;F%B;&5?<V5T=7!?:6YV
M86QI9%]L;V=I;E]I;G1E<G9A;"<@/3X@(E5N86)L92!T;R!S970@=7`@:6YV
M86QI9"!L;V=I;B!I;G1E<G9A;#H@)3$B+`H))W-E<W-I;VYS7U]U;F%B;&5?
M<V5T=7!?:6YV86QI9%]L;V=I;E]L;V-K7W1I;64G(#T^(")5;F%B;&4@=&\@
M<V5T('5P(&EN=F%L:60@;&]G:6X@;&]C:R!T:6UE.B`E,2(L"@DG<V5S<VEO
M;G-?7W5N86)L95]S971U<%]S97-S:6]N7VED;&4G(#T^(")5;F%B;&4@=&\@
M<V5T('5P('-E<W-I;VX@:61L92!T:6UE.B`E,2(L"@DG<V5S<VEO;G-?7W1A
M8G-?8W!?<V5S<VEO;G,G(#T^("=#4"!397-S:6]N<R<L"@DG<V5S<VEO;G-?
M7W1A8G-?9G1P7W-E<W-I;VYS)R`]/B`G1E10(%-E<W-I;VYS)RP*"2=S97-S
M:6]N<U]?9G1P7W-E<W-I;VYS7VQO9VEN)R`]/B`G1E10('5S97(@;&]G:6XG
M+`H))W-E<W-I;VYS7U]F='!?<V5S<VEO;G-?9&]M86EN)R`]/B`G1&]M86EN
M(&YA;64G+`H))W-E<W-I;VYS7U]F='!?<V5S<VEO;G-?<&%T:"<@/3X@)T-U
M<G)E;G0@;&]C871I;VXG+`H))W-E<W-I;VYS7U]F='!?<V5S<VEO;G-?9FEL
M92<@/3X@)T9I;&4@;F%M92<L"@DG<V5S<VEO;G-?7V9T<%]S97-S:6]N<U]A
M8W1I;VXG(#T^("=3=&%T=7,G+`H))W-E<W-I;VYS7U]F='!?<V5S<VEO;G-?
M<W!E960G(#T^("=3<&5E9"P@2T(O4R<L"@DG<V5S<VEO;G-?7V9T<%]S97-S
M:6]N<U]C;VUP)R`]/B`G4')O9W)E<W,L("4G+`H*"@DG<VET95]A<'!S7U]A
M8V-E<W-?;&5V96PG(#T^("=!8V-E<W,@;&5V96PG+`H))W-I=&5?87!P<U]?
M86-C97-S7VQE=F5L7V-O;6UE<F-I86PG(#T^("=#;VUM97)C:6%L)RP*"2=S
M:71E7V%P<'-?7V%C8V5S<U]L979E;%]F<F5E)R`]/B`G1G)E92<L"@DG<VET
M95]A<'!S7U]A8W1I;VY?:6YS=&%L;&5R)R`]/B`B4VET92!A<'!L:6-A=&EO
M;B!I;G-T86QL871I;VXB+`H))W-I=&5?87!P<U]?86-T:6]N7W)E8V]N9FEG
M=7)E)R`]/B`B4VET92!A<'!L:6-A=&EO;B!R96-O;F9I9W5R:6YG(BP*"2=S
M:71E7V%P<'-?7V5X=')A7V9I;&5S7W1I=&QE)R`]/B`G5VAA="!T;R!D;R!W
M:71H('1H92!F:6QE<S\G+`H))W-I=&5?87!P<U]?97AT<F%?9FEL97-?=V%R
M;FEN9R<@/3X@)U1H92!C;VYT96YT<R!O9B!T:&4@9&ER96-T;W)Y("4Q('=I
M;&P@8F4@<F5W<FET=&5N('1O(&5N<W5R92!T:&4@8VQE86X@:6YS=&%L;&%T
M:6]N(&%N9"!P<F]P97(@=V]R:R!O9B!T:&4@87!P;&EC871I;VXN(%-O+"!I
M9B!Y;W4@:&%V92!A;GD@=F%L=6%B;&4@9&%T82!S=&]R960@=VET:&EN('1H
M92!D;VUA:6XL('EO=2!S:&]U;&0@8F%C:R!T:&5M('5P(&]R(&UO=F4@=&\@
M86YO=&AE<B!L;V-A=&EO;B!B969O<F4@>6]U('!R;V-E960@=VET:"!T:&4@
M:6YS=&%L;&%T:6]N+B!9;W4@8V%N(&)R;W=S92!T:&4@9&]M86EN(&-O;G1E
M;G0@=VET:"`E,BXG+`H))W-I=&5?87!P<U]?97AT<F%?9FEL97-?=V%R;FEN
M9U]B<F]W<V4G(#T^("=B<F]W<V4@=&AE(&1O;6%I;B!C;VYT96YT('=I=&@@
M1FEL92!-86YA9V5R)RP*"2=S:71E7V%P<'-?7V5X=')A7V9I;&5S7VQE9V5N
M9"<@/3X@)U=H870@=&\@9&\@=VET:"!T:&4@9FEL97,_)RP*"2=S:71E7V%P
M<'-?7V5X=')A7V9I;&5S7V1E;&5T92<@/3X@)U)E;6]V92!A;&P@9FEL97,@
M:6X@=&AE(&1O8W5M96YT(')O;W0@9&ER96-T;W)Y+B<L"@DG<VET95]A<'!S
M7U]E>'1R85]F:6QE<U]K965P)R`]/B`G2V5E<"!E>&ES=&EN9R!F:6QE<RP@
M=VAE;B!P;W-S:6)L92X@3F]T92!T:&%T(&%P<&QI8V%T:6]N(&9I;&5S('=I
M;&P@;W9E<G=R:71E('1H92!E>&ES=&EN9R!F:6QE<R!A;GEW87DL(&%N9"!T
M:&4@97AT<F$@9FEL97,@;6%Y(&-A=7-E(&%P<&QI8V%T:6]N('1O(&)E:&%V
M92!I;F-O<G)E8W1L>2XG+`H))W-I=&5?87!P<U]?;F]?=F%C86YT7W-I=&5?
M87!P<R<@/3X@(EEO=2!H879E(&YO(&-O;6UE<F-I86P@<VET92!A<'!L:6-A
M=&EO;G,@=&\@861D+B(L"@DG<VET95]A<'!S7U]C;%]L:7-T7V9O<E]A<'`G
M(#T^(")#;&EE;G1S('5S:6YG(&-O;6UE<F-I86P@<VET92!A<'!L:6-A=&EO
M;B`E,2(L"@DG<VET95]A<'!S7U]C;%]L:7-T7V9O<E]A<'!?861D)R`]/B`B
M4V5L96-T('1H92!C;&EE;G1S('=H;R!S:&]U;&0@=7-E('1H:7,@87!P;&EC
M871I;VXB+`H))W-I=&5?87!P<U]?8W5S=&]M7V)U='1O;E]L979E;"<@/3X@
M)U=O=6QD('EO=2!L:6ME('1O(&-R96%T92!A(&YE=R!C=7-T;VT@8G5T=&]N
M(&9O<B!A8V-E<W-I;F<@=&AI<R!A<'!L:6-A=&EO;C\G+`H))W-I=&5?87!P
M<U]?8W5S=&]M7V)U='1O;E]L979E;%]F86QS95]D;VUA:6Y?=7-E<E]O;FQY
M)R`]/B`G3F\G+`H))W-I=&5?87!P<U]?8W5S=&]M7V)U='1O;E]L979E;%]D
M;VUA:6Y?=7-E<E]O;FQY)R`]/B`G665S)RP*"2=S:71E7V%P<'-?7V-U<W1O
M;5]B=71T;VY?;&5V96Q?9F%L<V4G(#T^("=.;R<L"@DG<VET95]A<'!S7U]C
M=7-T;VU?8G5T=&]N7VQE=F5L7V1O;6%I;B<@/3X@)UEE<RP@86YD(&UA:V4@
M:70@879A:6QA8FQE(&9O<B!T:&4@8W5R<F5N="!D;VUA:6X@;VYL>2XG+`H)
M)W-I=&5?87!P<U]?8W5S=&]M7V)U='1O;E]L979E;%]C;&EE;G0G(#T^("=9
M97,L(&%N9"!M86ME(&ET(&%V86EL86)L92!F;W(@86QL(&1O;6%I;G,@;V8@
M=&AE(&-L:65N="XG+`H))W-I=&5?87!P<U]?8W5S=&]M7V)U='1O;E]L979E
M;%]A9&UI;B<@/3X@)UEE<RP@86YD(&UA:V4@:70@879A:6QA8FQE(&9O<B!A
M;&P@9&]M86EN<RXG+`H))W-I=&5?87!P<U]?9&5S8W)I<'1I;VXG(#T^(")$
M97-C<FEP=&EO;B(L"@DG<VET95]A<'!S7U]D:7)?=7-E9%]B>5]S87!P7U\G
M(#T^(")4:&4@9&ER96-T;W)Y(%PB)3%<(B!I<R!U<V5D(&)Y(&%N;W1H97(@
M<VET92!A<'!L:6-A=&EO;B(L"@DG<VET95]A<'!S7U]D:7)?=7-E9%]B>5]F
M<%]?)R`]/B`B5&AE(&1I<F5C=&]R>2!<(B4Q7"(@:7,@=7-E9"!B>2!T:&4@
M1G)O;G1086=E(&%P<&QI8V%T:6]N(BP*"2=S:71E7V%P<'-?7V1I<E]U<V5D
M7V)Y7W5N:VYO=VY?7R<@/3X@(E1H92!D:7)E8W1O<GD@7"(E,5PB(&%L<F5A
M9'D@97AI<W1S(BP*"2=S:71E7V%P<'-?7V9I;&5?;F%M92<@/3X@(E-I=&4@
M87!P;&EC871I;VX@<&%C:V%G92!F:6QE;F%M92(L"@DG<VET95]A<'!S7U]I
M;G-T86QL871I;VY?;G5M8F5R)R`]/B`B26YS=&%N8V5S(BP*"2=S:71E7V%P
M<'-?7VEN<W1A;&QE9%]I;E]?)R`]/B`B:6YS=&%L;&5D(&EN("4Q(BP*"2=S
M:71E7V%P<'-?7VEN=F%L:61?:6YS=&%L;%]P<F5F:7@G(#T^("));G9A;&ED
M(&EN<W1A;&QA=&EO;B!P<F5F:7@B+`H))W-I=&5?87!P<U]?:6YV86QI9%]P
M86-K86=E)R`]/B`B4VET92!A<'!L:6-A=&EO;B!P86-K86=E(&ES(&EN=F%L
M:60N(BP*"2=S:71E7V%P<'-?7V5R<F]R7W1E<W1?<&%C:V%G92<@/3X@(E1H
M:7,@<&%C:V%G92!F:6QE(&ES(&EN=F%L:60N7&XE,2(L"@DG<VET95]A<'!S
M7U]E<G)O<E]T97-T7W!A8VMA9V5?=F%U;'0G(#T^(")4:&ES(&9I;&4@:7,@
M;F]T(&$@=F%L:60@<VET92!A<'!L:6-A=&EO;B!P86-K86=E+EQN)3$B+`H)
M)W-I=&5?87!P<U]?97)R;W)?861D7W!A8VMA9V5?7R<@/3X@(E5N86)L92!T
M;R!I;G-T86QL('1H92!S:71E(&%P<&QI8V%T:6]N('!A8VMA9V4N7&XE,2(L
M"@DG<VET95]A<'!S7U]K97E?<W1A='5S)R`]/B`G3&EC96YS:6YG)RP*"2=S
M:71E7V%P<'-?7VME>5]S=&%T=7-?9G)E92<@/3X@)T1I<W1R:6)U=&5D(&9R
M965L>2X@3F\@;&EC96YS92!K97D@<F5Q=6ER960G+`H))W-I=&5?87!P<U]?
M:V5Y7W-T871U<U]O:R<@/3X@)U1H92!R97%U:7)E9"!L:6-E;G-E(&ME>2!I
M<R!I;G-T86QL960G+`H))W-I=&5?87!P<U]?:V5Y7W-T871U<U]P<F]B;&5M
M)R`]/B`G5&AE(')E<75I<F5D(&QI8V5N<V4@:V5Y(&ES(&YO="!I;G-T86QL
M960G+`H))W-I=&5?87!P<U]?;F%M92<@/3X@(DYA;64B+`H))W-I=&5?87!P
M<U]?;F]?9&]M86EN<R<@/3X@)U1H92!S:71E(&%P<&QI8V%T:6]N(&-A;FYO
M="!B92!I;G-T86QL960N(%1H97)E(&ES(&%L<F5A9'D@86YO=&AE<B!S:71E
M(&%P<&QI8V%T:6]N(&EN<W1A;&QE9"!I;B!T:&4@<F]O="!D:7)E8W1O<GD@
M;V8@=&AI<R!D;VUA:6XN($-O;G-I9&5R(&-R96%T:6YG(&$@<W5B9&]M86EN
M(&9O<B!T:&4@<VET92!A<'!L:6-A=&EO;BXG+`H))W-I=&5?87!P<U]?<&%C
M:V%G95]I;F9O7R<@/3X@(E-I=&4@07!P;&EC871I;VX@4&%C:V%G92!);F9O
M<FUA=&EO;B(L"@DG<VET95]A<'!S7U]P86-K86=E7VEN=&5G<F%T960G(#T^
M(")B=6EL="UI;B!P86-K86=E+"!C86YN;W0@8F4@<F5M;W9E9"(L"@DG<VET
M95]A<'!S7U]P;V]L7W1I=&QE)R`]/B`G07!P;&EC871I;VX@<&]O;"!O9B`E
M,2<L"@DG<VET95]A<'!S7U]P;V]L7W)E;6]V95]T:71L92<@/3X@(E1H92!F
M;VQL;W=I;F<@<VET92!A<'!L:6-A=&EO;B!P86-K86=E<R!W:6QL(&)E(')E
M;6]V960@9G)O;2!T:&4@<&]O;#HB+`H))W-I=&5?87!P<U]?<&]O;%]S96QE
M8W1?<&%C:V%G97-?=&]?<F5M;W9E)R`]/B`G4V5L96-T('1H92!S:71E(&%P
M<&QI8V%T:6]N('!A8VMA9V5S('1O(&)E(')E;6]V960N)RP*"2=S:71E7V%P
M<'-?7W!O;VQ?<V5L96-T7W!A8VMA9V5S7W1O7V%D9"<@/3X@)U-E;&5C="!T
M:&4@<VET92!A<'!L:6-A=&EO;B!P86-K86=E<R!T;R!A9&0@=&\@=&AE('!O
M;VPN)RP*"2=S:71E7V%P<'-?7W!O;VQ?861D7W1I=&QE)R`]/B`G061D('-I
M=&4@87!P;&EC871I;VX@<&%C:V%G97,@=&\@=&AE('!O;VPG+`H))W-I=&5?
M87!P<U]?<F5L96%S92<@/3X@(E)E;&5A<V4B+`H))W-I=&5?87!P<U]?<F5Q
M=6ER97-?879A:6)L95]T:71L92<@/3X@(D%V86EL86)L92(L"@DG<VET95]A
M<'!S7U]R97%U:7)E<U]E<G)O<B<@/3X@(E1H92!S:71E(&%P<&QI8V%T:6]N
M(')E<75I<F5S('1H92!R97-O=7)C97,L('=H:6-H(&%R92!N;W0@8W5R<F5N
M=&QY(&%V86EL86)L92(L"@DG<VET95]A<'!S7U]R97%U:7)E<U]E<G)O<E]?
M)R`]/B`B5&AE('-I=&4@87!P;&EC871I;VX@<F5Q=6ER97,@=&AE(')E<V]U
M<F-E<RP@=VAI8V@@87)E(&YO="!C=7)R96YT;'D@879A:6QA8FQE.EQN)3$B
M+`H))W-I=&5?87!P<U]?<F5Q=6ER97-?97)R;W)?9&5S8W)I<'1I;VY?7R<@
M/3X@(B4Q+"`E,BX@<F5Q=6ER960Z("4S+B!A=F%I;&%B;&4Z("4T+B(L"@DG
M<VET95]A<'!S7U]R97%U:7)E<U]E<G)O<E]H;W-T:6YG7U\G(#T^(")4:&4@
M<F5Q=6ER960@<F5S;W5R8V4@:7,@;F]T(&5N86)L960@:6X@9&]M86EN(&AO
M<W1I;F<@9F5A='5R97,N(BP*"2=S:71E7V%P<'-?7W)E<75I<F5S7V5R<F]R
M7VQI;6ET<U]?)R`]/B`B5&AE(')E<75I<F5D(')E<V]U<F-E(&ES(&YO="!A
M=F%I;&%B;&4@9'5E('1O(&1O;6%I;B!L:6UI=',@9&5F:6YE9"XB+`H))W-I
M=&5?87!P<U]?<F5Q=6ER97-?97)R;W)?<WES=&5M7V1I<VM?<W!A8V5?7R<@
M/3X@(DYO="!E;F]U9V@@9G)E92!D:7-K('-P86-E(&]N("4Q+B!0;&5A<V4@
M9G)E92!U<"!S;VUE(&1I<VL@<W!A8V4@86YD('1R>2!I;G-T86QL:6YG('1H
M:7,@87!P;&EC871I;VX@86=A:6XN(BP*"2=S:71E7V%P<'-?7W)E<75I<F5S
M7V5R<F]R7W9E<G-I;VY?7R<@/3X@(E1H92!C;VUP;VYE;G0@=F5R<VEO;B!O
M;B!T:&4@<V5R=F5R(&1O97,@;F]T('-A=&ES9GD@=&AE('-I=&4@87!P;&EC
M871I;VXG<R!R97%U:7)E;65N=',N(BP*"2=S:71E7V%P<'-?7W)E<75I<F5S
M7V5R<F]R7W-U8F1O;6%I;E]?)R`]/B`B5&AE(')E<75I<F5D(')E<V]U<F-E
M(&ES(&YO="!E;F%B;&5D(&EN('-U8F1O;6%I;B!F96%T=7)E<RXB+`H))W-I
M=&5?87!P<U]?<F5Q=6ER97-?97)R;W)?=&ET;&4G(#T^(")$97-C<FEP=&EO
M;B(L"@DG<VET95]A<'!S7U]R97%U:7)E<U]N86UE7W1I=&QE)R`]/B`B4F5Q
M=6ER960B+`H))W-I=&5?87!P<U]?<F5Q=6ER97-?='EP95]T:71L92<@/3X@
M(E1Y<&4B+`H))W-I=&5?87!P<U]?<F5Q=6ER97-?=F%L=65?=&ET;&4G(#T^
M(")686QU92(L"@DG<VET95]A<'!S7U]R97-O=7)C95]U<V5D7V)Y7W-A<'`G
M(#T^(")4:&ES(')E<V]U<F-E(&ES('5S960@8GD@86X@:6YS=&%L;&5D('-I
M=&4@87!P;&EC871I;VXB+`H))W-I=&5?87!P<U]?<F]O=%]U<V5D7V)Y7W-A
M<'`G(#T^(")4:&ES(')E<V]U<F-E(&ES('5S960@8GD@86X@:6YS=&%L;&5D
M('-I=&4@87!P;&EC871I;VXB+`H))W-I=&5?87!P<U]?<V5L96-T7V%P<%]P
M:V=?=&]?:6YS=&%L;"<@/3X@(E-E;&5C="!T:&4@<VET92!A<'!L:6-A=&EO
M;B!P86-K86=E('1O(&EN<W1A;&PB+`H))W-I=&5?87!P<U]?<V5L96-T7V%P
M<%]P:V=S7W1O7W5N:6YS=&%L;"<@/3X@(E-E;&5C="!T:&4@<VET92!A<'!L
M:6-A=&EO;B!P86-K86=E<R!T;R!U;FEN<W1A;&PB+`H))W-I=&5?87!P<U]?
M<V5L96-T7V%P<%]T;U]A<'!L:6-A=&EO;B<@/3X@(E-E;&5C="!T:&4@<VET
M92!A<'!L:6-A=&EO;B!T;R!O<&5N(BP*"2=S:71E7V%P<'-?7W-E;&5C=%]A
M<'!?=&]?<F5C;VYF:6=U<F4G(#T^(")396QE8W0@=&AE('-I=&4@87!P;&EC
M871I;VX@=&\@<F5C;VYF:6=U<F4B+`H))W-I=&5?87!P<U]?<V5L96-T7V%P
M<'-?=&]?=6YI;G-T86QL)R`]/B`B4V5L96-T('1H92!S:71E(&%P<&QI8V%T
M:6]N<R!T;R!U;FEN<W1A;&PB+`H))W-I=&5?87!P<U]?<V5L96-T7V-L:65N
M=',G(#T^(")396QE8W0@8VQI96YT<R(L"@DG<VET95]A<'!S7U]S:71E7V%P
M<%]P:V=S)R`]/B`B4VET92!A<'!L:6-A=&EO;B!P86-K86=E<R(L"@DG<VET
M95]A<'!S7U]S:71E7V%P<%]P:V=S7V%D9"<@/3X@(D%D9"!N97<@<VET92!A
M<'!L:6-A=&EO;B!P86-K86=E(BP*"2=S:71E7V%P<'-?7W-I=&5?87!P7W!K
M9W-?;6%N86=E;65N="<@/3X@(D%P<&QI8V%T:6]N(%9A=6QT(BP*"2=S:71E
M7V%P<'-?7W-I=&5?87!P<R<@/3X@(E-I=&4@07!P;&EC871I;VYS(BP*"2=S
M:71E7V%P<'-?7W-I=&5?87!P<U]M86YA9V5M96YT)R`]/B`B26YS=&%L;&5D
M($%P<&QI8V%T:6]N<R(L"@DG<VET95]A<'!S7U]S:71E7V%P<%]P:V=S7VEN
M<W1A;&QA=&EO;B<@/3X@)TEN<W1A;&QA=&EO;CH@<V5L96-T('1H92!A<'!L
M:6-A=&EO;B!T;R!B92!I;G-T86QL960G+`H))W-I=&5?87!P<U]?<VET95]A
M<'!?<&MG<U]I;G-T86YC97,G(#T^("=);G-T86QL871I;VYS(&]F('1H92`E
M,2!!<'!L:6-A=&EO;B<L"@DG<VET95]A<'!S7U]U;FEN<W1A;&Q?<V%P<"<@
M/3X@(E5N:6YS=&%L;"!A<'!L:6-A=&EO;G,@9G)O;2!D;VUA:6X@)3$B+`H)
M)W-I=&5?87!P<U]?=6YI;G-T86QL7W-A<'!P:V<G(#T^(")5;FEN<W1A;&P@
M87!P;&EC871I;VX@<&%C:V%G97,B+`H))W-I=&5?87!P<U]?=7!L;V%D7W-I
M=&5?87!P7W!K9U]T:71L92<@/3X@(E5P;&]A9"!N97<@<VET92!A<'!L:6-A
M=&EO;B!P86-K86=E(BP*"2=S:71E7V%P<'-?7W9E<G-I;VXG(#T^(")697)S
M:6]N(BP*"2=S:71E7V)U:6QD97)?<F5Q=6ER97,G(#T^("<E,2`M("4S)RP*
M"2=S:V5L971O;E]?861M:6Y?;&%B96PG(#T^(")!9&UI;FES=')A=&]R(&1E
M9FEN960@<VME;&5T;VXB+`H))W-K96QE=&]N7U]C;&EE;G1?;&%B96PG(#T^
M("(E,2!D969I;F5D('-K96QE=&]N(BP*"2=S:V5L971O;E]?861M:6Y?<&%G
M92<@/3X@(E-K96QE=&]N(&UA;F%G96UE;G0B+`H))W-K96QE=&]N7U]F:6QE
M<U]L:7-T)R`]/B`B4VME;&5T;VX@8V]N=&5N=',B+`H))W-K96QE=&]N7U]A
M<F-H:79E<E]N;W1?:6YS=&%L;&5D)R`]/B`B56YA8FQE('1O('5N<&%C:R!T
M:&4@<VME;&5T;VXN($%R8VAI=F5R(&ES('!O<W-I8FQY(&YO="!I;G-T86QL
M960@;VX@=&AE('-E<G9E<BX@0V]N=&%C="!T:&4@)%!23T1?3D%-12!A9&UI
M;FES=')A=&]R('1O(&AA=F4@=&AE(&%R8VAI=F5R('-O9G1W87)E(&EN<W1A
M;&QE9"XB+`H))W-K96QE=&]N7U]C;&EE;G1?<&%G92<@/3X@(E9I<G1U86P@
M:&]S="!S:V5L971O;B!M86YA9V5M96YT(BP*"2=S:V5L971O;E]?87)C:&EV
M95]C;W)R=7!T960G(#T^(")!<F-H:79E(&-H96-K(&1I<V-O=F5R960@=&AA
M="!T:&4@87)C:&EV92!F:6QE(&ES(&5I=&AE<B!C;W)R=7!T(&]R('1H:7,@
M87)C:&EV92!T>7!E(&ES(&YO="!S=7!P;W)T960N(BP*"2=S:V5L971O;E]?
M87)C:&EV95]T;V]?;&%R9V4G(#T^(")!<F-H:79E(&-H96-K(&1I<V-O=F5R
M960@=&AA="!T:&4@87)C:&EV92!F:6QE(&ES('1O;R!L87)G92XB+`H))W-K
M96QE=&]N7U]N;W1?<W5P<&]R=&5D7V%R8VAI=F5?='EP92<@/3X@(E1H:7,@
M='EP92!O9B!A<F-H:79E("AF:6QE("4Q*2!I<R!N;W0@<W5P<&]R=&5D(BP*
M"2=S:V5L971O;E]?=7!L;V%D7V%R8VAI=F5?9FEL92<@/3X@(E5P;&]A9"!S
M:V5L971O;B!A<F-H:79E(&9I;&4B+`H))W-K:6Y?9&]W;FQO861?7W1I=&QE
M)R`]/B`G1&]W;FQO860@4VMI;B<L"@DG<VMI;E]D;W=N;&]A9%]N;W=?7W1I
M=&QE)R`]/B`G4VMI;B!D;W=N;&]A9"!I;B!P<F]G<F5S<R<L"@DG<VMI;E]D
M;W=N;&]A9%]N;W=?7W1E>'0G(#T^("=4:&4@<VMI;B!P86-K86=E(&-R96%T
M:6]N(&ES(&EN('!R;V=R97-S+CQB<CY4:&ES('!R;V-E9'5R92!M87D@=&%K
M92!S;VUE('1I;64N/&)R/B!/;F-E('1H92!D:6%L;V<*=VEN9&]W(&%P<&5A
M<G,L('EO=2!C86X@8V]N=&EN=64@;W!E<F%T:6YG('1H92!C;VYT<F]L('!A
M;F5L+B<L"@DG<VMI;E]F:6QE7U]H96QP7V9O<E]U<VEN9U]T>7!E<R<@/3X@
M(E!L96%S92P@=7-E('1H92!S:VEN(&%R8VAI=F5S(&EN(&]N92!O9B!T:&4@
M9F]L;&]W:6YG(&9O<FUA=',B+`H))W-K:6Y?:6YF;U]?=&ET;&4G(#T^("=3
M:VEN(%!R;W!E<G1I97,G+`H))W-K:6Y?;6YG7V5R<E]?<G!M7VYO=%]S:VEN
M)PD]/B`G5&AI<R!24$T@:7,@;F]T(&$@8V]N=')O;"!P86YE;"!S:VEN('!A
M8VMA9V4G+`H))W-K:6Y?;6YG7V5R<E]?<'-A7VEN<W1A;&Q?;F]R96QO8R<@
M/3X@)T9A:6QE9"!T;R!I;G-T86QL(')P;2UB87-E9"!S:VEN(&EN('1H92!S
M<&5C:69I960@;&]C871I;VXN)RP*"2=S:VEN7VUN9U]E<G)?7V%L<F5A9'E?
M97AI<W1S)R`]/B`G5&AE('-K:6X@:6YS=&%L;&%T:6]N(&1I<F5C=&]R>2!A
M;')E861Y(&5X:7-T<RP@86YD('1H97)E(&ES(&$@<VMI;B!P86-K86=E(&1E
M<&QO>65D+B<L"@DG<VMI;E]M;F=?97)R7U]R<&U?=7!G<F%D95]N;VYR<&TG
M(#T^("=4:&4@=7!L;V%D960@9FEL92!I<R!N;W0@82!V86QI9"!24$T@<VMI
M;B!P86-K86=E+B<L"@DG<VMI;E]M;F=?97)R7U]R<&U?=7!G<F%D95]N;W-K
M:6XG(#T^("=4:&4@=7!L;V%D960@9FEL92!I<R!N;W0@82!V86QI9"!S:VEN
M('!A8VMA9V4N)RP*"2=S:VEN7VUN9U]E<G)?7W)P;5]U<&=R861E7V)A<V4G
M(#T^(")4:&4@=7!L;V%D960@9FEL92!I<R!N;W0@82!V86QI9"`D4%)/1%].
M04U%('-K:6X@<&%C:V%G92XB+`H))W-K:6Y?;6YG7V5R<E]?<G!M7W5P9W)A
M9&5?;W1H97(G(#T^("=5;F%B;&4@=&\@:6YS=&%L;"!T:&4@<VMI;CH@:6YV
M86QI9"!S:VEN(&9O<FUA="XG+`H))W-K:6Y?;6YG7V5R<E]?;F]?85]S:VEN
M)R`]/B`B5&AE('5P;&]A9&5D(&9I;&4@:7,@;F]T(&$@=F%L:60@)%!23T1?
M3D%-12!S:VEN('!A8VMA9V4N(BP*"2=S:VEN7W5P;&]A9%]?=&ET;&4G(#T^
M("=5<&QO860@3F5W(%-K:6XG+`H))W-K:6Y?=7!L;V%D7U]A;')E861Y7V5X
M:7-T<R<@/3X@(E1H92!S:VEN("<E,2<@86QR96%D>2!E>&ES=',B+`H))W-K
M:6Y?=7!L;V%D7U]U;F%B;&5?=&]?87!P;'DG(#T^(")4:&4@=7!L;V%D960@
M9FEL92!D;V5S(&YO="!C;VYT86EN(&$@4&QE<VL@<VMI;BP@;W(@=&AE(&%R
M8VAI=F4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N(BP*"2=S:VEN7W5P;&]A
M9%]?9FEL95]N86UE)R`]/B`G4&%T:"!T;R!T:&4@<VMI;B!P86-K86=E(&9I
M;&4G+`H))W-K:6YS7VQI<W1?7W1I=&QE)R`]/B`G4VMI;G,@4F5P;W-I=&]R
M>2<L"@DG<VMI;G-?<F5M;W9E7U]T:71L92<@/3X@)U-K:6X@4F5M;W9A;"<L
M"@DG<VMI;G-?<F5M;W9E7U]S96QE8W1?<VMI;G-?9F]R7W)E;6]V92<@/3X@
M)U-E;&5C="!T:&4@<VMI;G,@=&\@8F4@<F5M;W9E9"XG+`H))W-L879E7V-E
M<G1?7W!A9V5?=&ET;&4G(#T^(")3;&%V92!S97)V97(@)3$@8V5R=&EF:6-A
M=&4@<V5T=7`N(BP*"2=S;&%V95]S97)V97)?7V%D;6EN7V%P86-H95]I<U]N
M;W1?=V]R:R<@/3X@(D%D;6EN(&%P86-H92!S97)V97(@9&]E<R!N;W0@9G5N
M8W1I;VXZ('1H92!P;W)T(')E:F5C=',@8V]N;F5C=&EO;G,N(BP*"2=S;&%V
M95]S97)V97)?7V%L;%]O:R<@/3X@(D%L;"!S97)V:6-E<R!F=6YC=&EO;B!P
M<F]P97)L>2!A;F0@=&AE<F4@87)E(&YO('!R;V)L96T@9&]M86EN<R!O<B!C
M;&EE;G1S(&]N('1H92!S;&%V92!S97)V97(N(BP*"2=S;&%V95]S97)V97)?
M7V)A9%]C;&EE;G1S)R`]/B`B5&AE<F4@87)E('!R;V)L96T@8VQI96YT<R!O
M;B!T:&4@<VQA=F4@<V5R=F5R+B(L"@DG<VQA=F5?<V5R=F5R7U]B861?9&]M
M86EN<R<@/3X@(E1H97)E(&%R92!P<F]B;&5M(&1O;6%I;G,@;VX@=&AE('-L
M879E('-E<G9E<BXB+`H))W-L879E7W-E<G9E<E]?8F%D7V1O;6%I;G-?86YD
M7V-L:65N=',G(#T^(")4:&5R92!A<F4@<')O8FQE;2!C;&EE;G1S(&%N9"!D
M;VUA:6YS(&]N('1H92!S;&%V92!S97)V97(N(BP*"2=S;&%V95]S97)V97)?
M7V-E<G1?9FEL96YA;65?:7-?96UP='DG(#T^(")5<&QO861E9"!S;&%V92!S
M97)V97(@8V5R=&EF:6-A=&4@9FEL96YA;64@:7,@96UP='DN(BP*"2=S;&%V
M95]S97)V97)?7V-E<G1?:7-?:6YV86QI9"<@/3X@(E1H92!C97)T:69I8V%T
M92!U<V5D(&9O<B!T:&ES('-E<W-I;VX@9&ED(&YO="!P87-S('1H92!V97)I
M9FEC871I;VXN(BP*"2=S;&%V95]S97)V97)?7V-E<G1?:7-?;F]T7W-E="<@
M/3X@(E-33"!C97)T:69I8V%T92!F;W(@=&AI<R!S;&%V92!S97)V97(@=V%S
M(&YO="!I;G-T86QL960N(BP*"2=S;&%V95]S97)V97)?7V-E<G1?=&5X=&9I
M96QD7VES7V5M<'1Y)R`]/B`B57!L;V%D960@<VQA=F4@<V5R=F5R(&-E<G1I
M9FEC871E(&ES(&5M<'1Y+B(L"@DG<VQA=F5?<V5R=F5R7U]C;W5L9&YT7V-O
M;FYE8W0G(#T^(")&86EL960@=&\@8V]N;F5C="!T;R!H;W-T+B(L"@DG<VQA
M=F5?<V5R=F5R7U]D97-C<FEP=&EO;B<@/3X@(D1E<V-R:7!T:6]N(BP*"2=S
M;&%V95]S97)V97)?7V1O7VYO=%]R97%U97-T)R`]/B`B1&\@;F]T(')E<75E
M<W0@:6YF;W)M871I;VX@9G)O;2!T:&4@<V5R=F5R(BP*"2=S;&%V95]S97)V
M97)?7V5N=&5R<')I<V5?:7-?;F]T7W-U<'!O<G1E9"<@/3X@(E1H92`D4%)/
M1%].04U%('9E<G-I;VX@<G5N;FEN9R!O;B!T:&ES('-E<G9E<B!D;V5S(&YO
M="!S=7!P;W)T('1H92!-87-T97(@9F5A='5R92XB+`H))W-L879E7W-E<G9E
M<E]?9F]L;&]W:6YG7W-E<G9I8V5S7VES7VYO=%]W;W)K)R`]/B`B5&AE(&9O
M;&QO=VEN9R!S97)V:6-E<R!D;R!N;W0@9G5N8W1I;VX@;VX@=&AE('-L879E
M('-E<G9E<CH@)3$N(BP*"2=S;&%V95]S97)V97)?7VEN=F%L:61?;&]G:6Y?
M;W)?<&%S<W=O<F0G(#T^("));F-O<G)E8W0@;&]G:6X@86YD('!A<W-W;W)D
M+B(L"@DG<VQA=F5?<V5R=F5R7U]K97E?;&EM:71S)R`]/B`B66]U<B!K97D@
M86QL;W=S(&-R96%T:6YG("4Q('-L879E('-E<G9E<G,@86-C;W5N=',@;VYL
M>2XB+`H))W-L879E7W-E<G9E<E]?<&%G95]T:71L92<@/3X@(E-L879E('-E
M<G9E<B!A8V-O=6YT(BP*"2=S;&%V95]S97)V97)?7W)E<75E<W1?=&EM96]U
M="<@/3X@(E-E<G9E<B!D871A(')E=')I979A;"!T:6UE;W5T+B(L"@DG<VQA
M=F5?<V5R=F5R7U]S96QE8W1?<VQA=F5?<V5R=F5R<U]F;W)?<F5M;W9E)R`]
M/B`B4V5L96-T('-L879E('-E<G9E<B!A8V-O=6YT<R!T;R!B92!R96UO=F5D
M+B(L"@DG<VQA=F5?<V5R=F5R7U]S97)V97)?86-C;W5N=%]A;')E861Y7V5X
M:7-T)R`]/B`B<V5R=F5R(&%C8V]U;G0@=VET:"!S=6-H(&AO<W1N86UE(&%L
M<F5A9'D@97AI<W1S+B(L"@DG<VQA=F5?<V5R=F5R7U]S97)V97)?:6YF;U]I
M<U]N;W1?879A:6QA8FQE)R`]/B`B4VQA=F4@<V5R=F5R(&EN9F]R;6%T:6]N
M(&ES(&YO="!C=7)R96YT;'D@879A:6QA8FQE+B(L"@DG<VQA=F5?<V5R=F5R
M7U]S;VUE7W-E<G9I8V5S7VES7VYO=%]W;W)K)R`]/B`B4V]M92!S97)V:6-E
M<R!D;R!N;W0@9G5N8W1I;VX@;VX@=&AE('-L879E('-E<G9E<BXB+`H))W-L
M879E7W-E<G9E<E]?=6YA8FQE7V1E9FEN95]H;W-T;F%M92<@/3X@(E5N86)L
M92!T;R!D969I;F4@=&AE('-L879E('-E<G9E<B!H;W-T;F%M93H@)3$B+`H)
M)W-L879E7W-E<G9E<E]?=6YA8FQE7W1O7W)E<V]L=F5?:&]S=&YA;64G(#T^
M(")5;F%B;&4@=&\@<F5S;VQV92!T:&4@:&]S=&YA;64N(BP*"2=S;&%V95]S
M97)V97)?7W5N86)L95]T;U]S971?8V5R=&EF:6-A=&4G(#T^(")5;F%B;&4@
M=&\@:6YS=&%L;"!T:&4@8V5R=&EF:6-A=&4@=&\@=&AE('-L879E('-E<G9E
M<CH@)3$B+`H))W-L879E7W-E<G9E<E]?=6YA8FQE7W1O7W5P9&%T92<@/3X@
M(E5N86)L92!T;R!U<&1A=&4@=&AE('-L879E('-E<G9E<B!P<F5F97)E;F-E
M<SH@)3$B+`H))W-L879E7W-E<G9E<E]?=6YK;F]W;E]E<G)O<B<@/3X@(E-E
M<G9E<B!R971U<FYE9"!U;FMN;W=N(&5R<F]R+B(L"@DG<W!A;6%S<V%S<VEN
M7U]T:71L92<@/3X@(E-P86T@9FEL=&5R(&-O;F9I9W5R871I;VXB+`H))W-P
M87=?7V5D:71?9FEL95]?)R`]/B`G5UE325=91R!E9&ET;W(Z("4Q)RP*"2=S
M<&%W;E]?=6YA8FQE7W1O7V5D:71?;F]?8F]D>2<@/3X@)U5N86)L92!T;R!E
M9&ET('1H:7,@9FEL92!B96-A=7-E(&ET(&1O97,@;F]T(&-O;G1A:6X@=&AE
M(#QB;V1Y/B!T86<N)RP*"2=S<&9?<&%R86UE=&5R<R<@/3X@)T5N86)L92!3
M4$8@<W!A;2!P<F]T96-T:6]N)RP*"2=S<&9?8F5H879I;W(G(#T^("=34$8@
M8VAE8VMI;F<@;6]D92<L"@DG<W!F7W)U;&5S)R`]/B`G4U!&(&QO8V%L(')U
M;&5S)RP*"2=S<&9?9W5E<W,G(#T^("=34$8@9W5E<W,G+`H))W-P9E]E>'`G
M(#T^("=34$8@97AP;&%N871I;VX@=&5X="<L"@DG<W!F7U]U;F%B;&5?=7!D
M871E)R`]/B`G56YA8FQE('1O('5P9&%T92!34$8@<&%R86UE=&5R<R<L"@DG
M<W!F7V)H=E]?8W)E871E7VAE861E<G-?;F]?8FQO8VLG(#T^("=/;FQY(&-R
M96%T92!296-E:79E9"U34$8@:&5A9&5R<RP@;F5V97(@8FQO8VLG+`H))W-P
M9E]B:'9?7W5S95]T;7!?97)R;W)S)R`]/B`G57-E('1E;7!O<F%R>2!E<G)O
M<B!N;W1I8V5S('=H96X@>6]U(&AA=F4@1$Y3(&QO;VMU<"!P<F]B;&5M<R<L
M"@DG<W!F7V)H=E]?<F5J96-T7VEF7V9A:6PG(#T^("=296IE8W0@;6%I;',@
M=VAE;B!34$8@<F5S;VQV97,@=&\@(F9A:6PB("AD96YY*2<L"@DG<W!F7V)H
M=E]?<F5J96-T7VEF7W-O9G1F86EL)R`]/B`G4F5J96-T(&UA:6QS('=H96X@
M4U!&(')E<V]L=F5S('1O(")S;V9T9F%I;"(G+`H))W-P9E]B:'9?7W)E:F5C
M=%]I9E]N975T<F%L)R`]/B`G4F5J96-T(&UA:6QS('=H96X@4U!&(')E<V]L
M=F5S('1O(")N975T<F%L(B<L"@DG<W!F7V)H=E]?<F5J96-T7VEF7VYO7W!A
M<W,G(#T^("=296IE8W0@;6%I;',@=VAE;B!34$8@9&]E<R!N;W0@<F5S;VQV
M92!T;R`B<&%S<R(G+`H))W-S:'1E<FU?7W1I=&QE)R`]/B`G4V5C=7)E(%-H
M96QL(%1E<FUI;F%L)RP*"2=S<VAT97)M7U]P87-S=V]R9%]A=71H96YT:6-A
M=&EO;E]W87)N:6YG)R`]/B`G3F]T93H@4&%S<W=O<F0@875T:&5N=&EC871I
M;VX@:7,@9&ES86)L960@:6X@=&AE(&QO8V%L(%-32"!S97)V97(@8V]N9FEG
M=7)A=&EO;BX@268@>6]U(&%R92!U;F%B;&4@=&\@8V]N;F5C="!U<VEN9R!T
M:&4@4U-((%1E<FUI;F%L+"!A<VL@=&AE(&%D;6EN:7-T<F%T;W(@=&\@<V5T
M(")087-S=V]R9$%U=&AE;G1I8V%T:6]N('EE<R(@:6X@=&AE("]E=&,O<W-H
M+W-S:&1?8V]N9FEG(&9I;&4N)RP*"2=S<VAT97)M7U]P87-S=V]R9%]A=71H
M96YT:6-A=&EO;E]W87)N:6YG7V%D;6EN)R`]/B`G3F]T93H@4&%S<W=O<F0@
M875T:&5N=&EC871I;VX@:7,@9&ES86)L960@:6X@=&AE(&QO8V%L(%-32"!S
M97)V97(@8V]N9FEG=7)A=&EO;BX@268@>6]U(&%R92!U;F%B;&4@=&\@8V]N
M;F5C="!U<VEN9R!T:&4@4U-((%1E<FUI;F%L+"!P;&5A<V4@<V5T(")087-S
M=V]R9$%U=&AE;G1I8V%T:6]N('EE<R(@:6X@=&AE("]E=&,O<W-H+W-S:&1?
M8V]N9FEG(&9I;&4N)RP*"2=S=&%T:7-T:6-S7U]A8W1I=F5?9&]M86EN<R<@
M/3X@(D%C=&EV92!D;VUA:6YS(BP*"2=S=&%T:7-T:6-S7U]C;&EE;G1S)R`]
M/B`B0VQI96YT<R(L"@DG<W1A=&ES=&EC<U]?<W5B9&]M86EN<R<@/3X@(E-U
M8F1O;6%I;G,B+`H))W-T871I<W1I8W-?7V-P=2<@/3X@(D-052(L"@DG<W1A
M=&ES=&EC<U]?9&%T86)A<V5S)R`]/B`B1&%T86)A<V5S(BP*"2=S=&%T:7-T
M:6-S7U]D8E]U<V5R<R<@/3X@(D1A=&%B87-E('5S97)S(BP*"2=S=&%T:7-T
M:6-S7U]D:7)S)R`]/B`B1&ER96-T;W)I97,B+`H))W-T871I<W1I8W-?7V1O
M;5]A8W1I=F4G(#T^(")!8W1I=F4B+`H))W-T871I<W1I8W-?7V1O;5]P87-S
M:79E)R`]/B`B4&%S<VEV92(L"@DG<W1A=&ES=&EC<U]?9&]M7W!R;V)L96TG
M(#T^(")0<F]B;&5M(BP*"2=S=&%T:7-T:6-S7U]D;VUA:6YS)R`]/B`B1&]M
M86EN<R(L"@DG<W1A=&ES=&EC<U]?9&]M86EN<U]W:71H7VAO<W0G(#T^(")$
M;VUA:6YS('=I=&@@:&]S=&EN9R(L"@DG<W1A=&ES=&EC<U]?9&]M<R<@/3X@
M(D1O;6%I;G,@(BP*"2=S=&%T:7-T:6-S7U]F:6QE<WES=&5M)R`]/B`B1FEL
M97-Y<W1E;2(L"@DG<W1A=&ES=&EC<U]?9V5N97)A;"<@/3X@(D=E;F5R86PB
M+`H))W-T871I<W1I8W-?7VAD9%]A=F%I;&%B;&4G(#T^(")!=F%I;&%B;&4B
M+`H))W-T871I<W1I8W-?7VAD9%]C87!A8VET>2<@/3X@(D-A<&%C:71Y(BP*
M"2=S=&%T:7-T:6-S7U]H9&1?=&]T86PG(#T^(")4;W1A;"(L"@DG<W1A=&ES
M=&EC<U]?:&1D7W5S86=E)R`]/B`B2&%R9"!$:7-K(%5S86=E(BP*"2=S=&%T
M:7-T:6-S7U]H9&1?=7-E9"<@/3X@(E5S960B+`H))W-T871I<W1I8W-?7VEP
M)R`]/B`B25`@861D<F5S<R(L"@DG<W1A=&ES=&EC<U]?:V5Y7VYU;6)E<B<@
M/3X@(DME>2!N=6UB97(B+`H))W-T871I<W1I8W-?7VPQ)R`]/B`B3&%S="`Q
M(&UI;G5T92(L"@DG<W1A=&ES=&EC<U]?;#$U)R`]/B`B3&%S="`Q-2!M:6YU
M=&5S(BP*"2=S=&%T:7-T:6-S7U]L-2<@/3X@(DQA<W0@-2!M:6YU=&5S(BP*
M"2=S=&%T:7-T:6-S7U]L82<@/3X@(D-052!U<V%G92(L"@DG<W1A=&ES=&EC
M<U]?;6%I;%]A=71O<F5S<&]N9&5R<R<@/3X@(D%U=&]R97-P;VYD97)S(BP*
M"2=S=&%T:7-T:6-S7U]M86EL7V)O>&5S)R`]/B`B36%I;&)O>&5S(BP*"2=S
M=&%T:7-T:6-S7U]M86EL7V=R;W5P<R<@/3X@(DUA:6P@9W)O=7!S(BP*"2=S
M=&%T:7-T:6-S7U]M86EL7VQI<W1S)R`]/B`B36%I;&EN9R!L:7-T<R(L"@DG
M<W1A=&ES=&EC<U]?;6%I;%]R961I<F5C=',G(#T^(")-86EL(')E9&ER96-T
M<R(L"@DG<W1A=&ES=&EC<U]?;65M)R`]/B`B365M;W)Y(%5S86=E(BP*"2=S
M=&%T:7-T:6-S7U]M96U?=7-A9V4G(#T^(")5<V%G92(L"@DG<W1A=&ES=&EC
M<U]?;65M;W)Y7V)U9F9E<B<@/3X@(D)U9F9E<B(L"@DG<W1A=&ES=&EC<U]?
M;65M;W)Y7V-A8VAE9"<@/3X@(D-A8VAE9"(L"@DG<W1A=&ES=&EC<U]?;65M
M;W)Y7V9R964G(#T^(")&<F5E(BP*"2=S=&%T:7-T:6-S7U]M96UO<GE?<VAA
M<F5D)R`]/B`B4VAA<F5D(BP*"2=S=&%T:7-T:6-S7U]M96UO<GE?=&]T86PG
M(#T^(")4;W1A;"(L"@DG<W1A=&ES=&EC<U]?;65M;W)Y7W5S960G(#T^(")5
M<V5D(BP*"2=S=&%T:7-T:6-S7U]O<R<@/3X@(D]3(BP*"2=S=&%T:7-T:6-S
M7U]P<F]B;&5M7V-L:65N=',G(#T^(")0<F]B;&5M(&-L:65N=',B+`H))W-T
M871I<W1I8W-?7W!R;V)L96U?9&]M86EN<R<@/3X@(E!R;V)L96T@9&]M86EN
M<R(L"@DG<W1A=&ES=&EC<U]?<W=A<"<@/3X@(E-W87`@=7-A9V4B+`H))W-T
M871I<W1I8W-?7W-W87!?9G)E92<@/3X@(D9R964B+`H))W-T871I<W1I8W-?
M7W-W87!?=&]T86PG(#T^(")4;W1A;"(L"@DG<W1A=&ES=&EC<U]?<W=A<%]U
M<V%G92<@/3X@(E5S86=E(BP*"2=S=&%T:7-T:6-S7U]S=V%P7W5S960G(#T^
M(")5<V5D(BP*"2=S=&%T:7-T:6-S7U]S>7-T96U?<W1A="<@/3X@(E-Y<W1E
M;2!S=&%T:7-T:6-S(BP*"2=S=&%T:7-T:6-S7U]U;F%B;&5?9&5F:6YE7V%C
M=&EV95]D;VUS)R`]/B`B56YA8FQE('1O(&1E=&5R;6EN92!T:&4@;G5M8F5R
M(&]F(&%C=&EV92!D;VUA:6YS.B`E,2(L"@DG<W1A=&ES=&EC<U]?=6YA8FQE
M7V1E9FEN95]I;F%C=&EV95]D;VUS)R`]/B`B56YA8FQE('1O(&1E=&5R;6EN
M92!T:&4@;G5M8F5R(&]F(&EN86-T:79E(&1O;6%I;G,Z("4Q(BP*"2=S=&%T
M:7-T:6-S7U]U<%]T:6UE)R`]/B`B4WES=&5M(%5P=&EM93H@(BP*"2=S=&%T
M:7-T:6-S7U]V97(G(#T^(")697)S:6]N(BP*"2=S=&%T:7-T:6-S7U]W96)?
M87!P<R<@/3X@(DIA=F$@87!P;&EC871I;VYS(BP*"2=S=&%T:7-T:6-S7U]W
M96)?=7-E<G,G(#T^(")796(@=7-E<G,B+`H))W-T871U<U]?8VQI96YT7VAA
M<U]R96%S;VYS7W1O7V)E7V]F9B<@/3X@(E1H92!C;&EE;G0@86-C;W5N="!I
M<R!S=&EL;"!D:7-A8FQE9"X@5&AE(')E87-O;CH@)3$B+`H))W-T871U<U]?
M9&]M86EN7VAA<U]R96%S;VYS7W1O7V)E7V]F9B<@/3X@(E1H92!D;VUA:6X@
M:7,@<W1I;&P@9&ES86)L960N(%1H92!R96%S;VXZ("4Q(BP*"2=S=6)D;VUA
M:6Y?7V-R96%T95]?)R`]/B`B0W)E871E(&$@<W5B9&]M86EN(&EN('1H92!D
M;VUA:6X@)3$B+`H))W-U8F1O;6%I;E]?961I=%]?)R`]/B`B36%N86=E('-U
M8F1O;6%I;B`E,2(L"@DG<W5B9&]M86EN7U]I;G9A;&ED7VYA;64G(#T^("))
M;G9A;&ED('-U8F1O;6%I;B!N86UE.B!U<V4@;VYL>2!A;'!H86YU;65R:6,@
M86YD(&1A<V@@<WEM8F]L<RXB+`H))W-U8F1O;6%I;G-?7V9U;&Q?;F%M95]L
M;VYG)R`]/B`B5&AE(&9U;&P@;F%M92!O9B!S=6)D;VUA:6X@:7,@=&]O(&QO
M;F<N(BP*"2=S=6)D;VUA:6YS7U]L:7-T7V]F7V1O;6%I;B<@/3X@(E-U8F1O
M;6%I;G,@:6X@=&AE(&1O;6%I;B`E,2(L"@DG<W5B9&]M86EN<U]?;6%I;&QI
M<W1S7V5N86)L961?:6Y?9&]M86EN)R`]/B`B26YC;W)R96-T('-U8F1O;6%I
M;B!N86UE(&QI<W1S+B4Q+"!O;B!D;VUA:6X@)3$@=&AE($UA:6QI;F<@;&ES
M=',@87)E(&5N86)L960N(BP*"2=S=6)D;VUA:6YS7U]D86QI87-?97AI<W1S
M)R`]/B`G5&AE(&1O;6%I;B!A;&EA<R!W:71H('-U8V@@;F%M92!A;')E9'D@
M97AI<W1S+B<L"@DG<W5B9&]M86EN<U]?;F%M95]E>&ES=',G(#T^(")4:&4@
M<W5B9&]M86EN('=I=&@@<W5C:"!N86UE(&%L<F5A9'D@97AI<W1S+B(L"@DG
M<W5B9&]M86EN<U]?<F5G=6QA<E]D;VUA:6Y?97AI<W1S)R`]/B`B5&AE(&1O
M;6%I;B!W:71H('-U8V@@;F%M92!A;')E9'D@97AI<W1S+B(L"@DG<W5B9&]M
M86EN<U]?<F5M;W9E7W-U8F1O;6%I;G-?;VY?9&]M86EN)R`]/B`B5&AE(&9O
M;&QO=VEN9R!S=6)D;VUA:6YS(&9O<B!D;VUA:6X@)3$@=VEL;"!B92!R96UO
M=F5D.B(L"@DG<W5B9&]M86EN<U]?<V5L96-T7W-U8F1O;6%I;G-?9F]R7W)E
M;6]V92<@/3X@(E-E;&5C="!T:&4@<W5B9&]M86EN<R!T;R!B92!R96UO=F5D
M+B(L"@DG<W5B9&]M86EN<U]?=&%R9V5T7V9O;&1E<E]E>&ES=',G(#T^(")4
M:&4@9&ER96-T;W)Y("4Q(&9O<B!S=6)D;VUA:6X@86QR96%D>2!E>&ES=',N
M(BP*"2=S=6)D;VUA:6YS7U]W96)M86EL7V5N86)L961?:6Y?9&]M86EN)R`]
M/B`B26YC;W)R96-T('-U8F1O;6%I;B!N86UE('=E8FUA:6PN)3$L(&]N(&1O
M;6%I;B`E,2!T:&4@5V5B;6%I;"!I<R!E;F%B;&5D+B(L"@DG<W5B9&]M86EN
M<U]?9&YS7W)E8V]R9%]A;')E861Y7V5X:7-T<R<@/3X@)U-U8V@@<F5S;W5R
M8V4@<F5C;W)D(&ES(&%L<F5A9'D@:6X@=&AE('IO;F4@)3$N)RP*"2=S=6)D
M;VUA:6YS7U]W=W=?<')E9FEX7VEN7V1O;6%I;B<@/3X@(DEN8V]R<F5C="!S
M=6)D;VUA:6X@;F%M93H@=&AE(&1O;6%I;B`E,2!A;')E861Y(&AA<R!T:&4@
M5U=7(&%L:6%S+B(L"@DG<W5B9&]M86EN<U]?8W)E871I;VY?:6Y?9&YS7W-L
M879E)R`]/B`B4&QE<VLG<R!N86UE('-E<G9E<B!I<R!A8W1I;F<@87,@82!S
M96-O;F1A<GD@*'-L879E*2!N86UE('-E<G9E<B!F;W(@=&AI<R!D;VUA:6XN
M($9O<B!Y;W5R('-U8F1O;6%I;B!T;R!R97-O;'9E('!R;W!E<FQY+"!M86ME
M('-U<F4@=&AA="!T:&4@>F]N92!F:6QE(&]N('1H92!P<FEM87)Y("AM87-T
M97(I('-E<G9E<B!C;VYT86EN<R!T:&4@<F5C;W)D("4Q(BP*"2=S>7-?=7-E
M<E]?871T<FEB=71E<U]N;W1?8VAA;F=E9"<@/3X@(EQN5&AE(&9O;&QO=VEN
M9R!S>7-T96T@=7-E<B!A='1R:6)U=&5S('=E<F4@;F]T(&-H86YG960Z("4Q
M(BP*"2=S>7-?=7-E<E]?;F]?86-C97-S7W=I=&AO=71?<&%S<W=O<F0G(#T^
M(")9;W4@9&ED(&YO="!S970@82!P87-S=V]R9"X@5&AE('-Y<W1E;2!U<V5R
M('=I;&P@8F4@8W)E871E9"P@8G5T('=I;&P@;F]T(&)E(&%B;&4@=&\@;&]G
M(&EN('1O('1H92!S>7-T96TL('5N=&EL(&AE+W-H92!I<R!G:79E;B!A('!A
M<W-W;W)D+B!7;W5L9"!Y;W4@;&EK92!T;R!P<F]C965D/R(L"@DG<WES7W5S
M97)?7VYO7VAA<F1?<75O=&$G(#T^(")N;W0@<W5P<&]R=&5D(BP*"2=S>7-U
M<V5R7U]Z97)O7W%U;W1A7VES7W5N;&EM:71E9"<@/3X@(C`@9F]R('5N;&EM
M:71E9"(L"@DG=&5M<&QA=&5?7VYU;5]E>&-L7VEP<R<@/3X@(D%L;&]C871E
M(&5X8VQU<VEV92!I<"!A9&1R97-S97,@=&\@=&AE(&-L:65N="(L"@DG=&5M
M<&QA=&5?7W-E;%]S:%]I<',G(#T^(")396QE8W0@<VAA<F5D(&EP(&%D9')E
M<W-E<R(L"@DG=&5M<&QA=&5?7V%V7W-H7VEP<R<@/3X@(D%V86EL86)L92!S
M:&%R960@:7`@861D<F5S<V5S(BP*"2=T96UP;&%T95]?=7!?=&]?97AC;%]I
M<"<@/3X@(E5P('1O("4Q(&EP(&%D9')E<W-E<R(L"@DG=&5M<&QA=&5S7U]A
M;&Q?8VQI96YT<R<@/3X@(F%L;"!C;&EE;G1S(BP*"2=T96UP;&%T97-?7V-L
M7V1O;6%I;E]T96UP;&%T97,G(#T^(")496UP;&%T97,@9F]R("4Q(BP*"2=T
M96UP;&%T97-?7V-L7W1E;7!L871E<R<@/3X@(D-L:65N="!T96UP;&%T97,B
M+`H))W1I;65?7V1A>2<@/3X@(D1A>2(L"@DG=&EM95]?9&]M7VYA;65?:7`G
M(#T^(")$;VUA:6X@;F%M92!O<B!)4"(L"@DG=&EM95]?:&]U<G,G(#T^(")(
M;W5R<R(L"@DG=&EM95]?:6YV86QI9%]I<"<@/3X@(DEN=F%L:60@25`@861D
M<F5S<R!O<B!D;VUA:6X@;F%M92XB+`H))W1I;65?7VEN=F%L:61?>65A<B<@
M/3X@(EEE87(@:7,@:6YV86QI9"X@4VAO=6QD(&)E(&)E='=E96X@,3DW,2!A
M;F0@,C`S-BXB+`H))W1I;65?7VEN=F%L:61?;6]N=&@G(#T^(")-;VYT:"!I
M<R!I;G9A;&ED+B!3:&]U;&0@8F4@8F5T=V5E;B`Q(&%N9"`Q,BXB+`H))W1I
M;65?7VEN=F%L:61?9&%Y)R`]/B`B1&%Y(&ES(&EN=F%L:60N(%-H;W5L9"!B
M92!B971W965N(#$@86YD(#,Q+B(L"@DG=&EM95]?:6YV86QI9%]H;W5R<R<@
M/3X@(DAO=7)S(&ES(&EN=F%L:60N(%-H;W5L9"!B92!B971W965N(#`@86YD
M(#(T+B(L"@DG=&EM95]?:6YV86QI9%]M:6YU=&5S)R`]/B`B36EN=71E<R!I
M<R!I;G9A;&ED+B!3:&]U;&0@8F4@8F5T=V5E;B`P(&%N9"`U.2XB+`H))W1I
M;65?7VEN=F%L:61?<V5C;VYD<R<@/3X@(E-E8V]N9',@:7,@:6YV86QI9"X@
M4VAO=6QD(&)E(&)E='=E96X@,"!A;F0@-3DN(BP*"2=T:6UE7U]M:6YU=&5S
M)R`]/B`B36EN=71E<R(L"@DG=&EM95]?;6]N=&@G(#T^(")-;VYT:"(L"@DG
M=&EM95]?<V5C)R`]/B`B4V5C;VYD<R(L"@DG=&EM95]?<WEN7W-Y<U]T:6UE
M)R`]/B`B4WEN8VAR;VYI>F4@<WES=&5M('1I;64B+`H))W1I;65?7W-Y<W1E
M;5]D871E)R`]/B`B4WES=&5M($1A=&4@86YD(%1I;64B+`H))W1I;65?7W-Y
M<W1E;5]D871E7W1I=&QE)R`]/B`B4WES=&5M($1A=&4@86YD(%1I;64B+`H)
M)W1I;65?7W1I;65Z;VYE7W1I=&QE)R`]/B`G5&EM92!Z;VYE)RP*"2=T:6UE
M7U]T:6UE>F]N92<@/3X@)UEO=7(@=&EM92!Z;VYE)RP*"2=T:6UE7U]P;&5A
M<V5?<V5L96-T7W1I;65Z;VYE)R`]/B`G4&QE87-E+"!S96QE8W0@82!T:6UE
M('IO;F4G+`H))U]?<&QE87-E7W-E;&5C=%]C;W5N=')Y)R`]/B`G4&QE87-E
M+"!S96QE8W0@>6]U<B!C;W5N=')Y)RP*"2=T:6UE7U]U;F%B;&5?<V5T7W1I
M;64G(#T^(")5;F%B;&4@=&\@<V5T('1H92!S>7-T96T@=&EM93H@)3$B+`H)
M)W1I;65?7WEE87(G(#T^(")996%R(BP*"2=T;7!L7U]C<F5A=&4G(#T^(")#
M<F5A=&4@=&5M<&QA=&4B+`H))W1M<&Q?7V5D:71?7R<@/3X@(D5D:70@=&5M
M<&QA=&4@)3$B+`H))W1M<&Q?7VQO9W)O=&%T:6]N7W=A<FXG(#T^("),;V<@
M<F]T871I;VX@;VX@=&AE(&1O;6%I;B!C<F5A=&5D(&)Y('1H:7,@=&5M<&QA
M=&4@=VEL;"!B92!P97)F;W)M960@;VYL>2!I;B!C87-E(&]F('-U8G-E<75E
M;G0@<&AY<VEC86P@:&]S=&EN9R!A8V-O=6YT(&-R96%T:6]N(&9O<B!I="XB
M+`H))W1M<&Q?7VYA;64G(#T^(")496UP;&%T92!N86UE(BP*"2=T;7!L7U]N
M86UE7VEN=F%L:60G(#T^(")496UP;&%T92!N86UE(&ES(&EN=F%L:60@;W(@
M96UP='DN(BP*"2=T;7!L7U]D;VU?97AI<W0G(#T^(")$;VUA:6X@=&5M<&QA
M=&4@=VET:"!S=6-H(&YA;64@86QR96%D>2!E>&ES=',@:6X@861M:6YI<W1R
M871O<B=S(&]R(&-L:65N="=S('1E;7!L871E<R!P;V]L+B(L"@DG=&UP;%]?
M=7-E7VYE>'1?:7!?861D<B<@/3X@(DYE>'0@=F%C86YT(&EP(&%D9')E<W,@
M=VEL;"!B92!U<V5D(BP*"2=T;V]L<V)A<E]?;&]G;W5T/R<@/3X@(D%R92!Y
M;W4@<W5R92!Y;W4@=VES:"!T;R!L;V<@;W5T/R(L"@DG=')A9F9I8U]?;F]?
M<&5R:6]D<U]F;W5N9"<@/3X@(E5N86)L92!T;R!D:7-P;&%Y('1H92!T<F%F
M9FEC('-T871I<W1I8W,N(%1H:7,@9G5N8W1I;VX@=VEL;"!B92!A=F%I;&%B
M;&4@;VYL>2!A9G1E<B!T:&4@;F5X="!S=&%T:7-T:6-S(&-A;&-U;&%T:6]N
M+B(L"@DG='1S)R`]/B`B2&5L<"!$97-K(BP*"2=T='-?7V-A;G1?8VQO<V5?
M8VQO<V5D)R`]/B`B66]U(&-A;FYO="!C;&]S92!A;B!A;')E861Y(&-L;W-E
M9"!T:6-K970B+`H))W1T<U]?8V%N=%]D96Q?8V%T7W1I8VME=',G(#T^(")5
M;F%B;&4@=&\@9&5L971E('1H92!C871E9V]R>3H@:70@:7,@=7-E9"!B>2!C
M97)T86EN('1I8VME=',@;W(@87-S:6=N960@87,@9&5F875L="!C871E9V]R
M>2XB+`H))W1T<U]?8V%N=%]D96Q?<')I;W)I='E?=&EC:V5T<R<@/3X@(E5N
M86)L92!T;R!D96QE=&4@=&AE('!R:6]R:71Y.B!I="!I<R!U<V5D(&)Y(&-E
M<G1A:6X@=&EC:V5T<R!O<B!A<W-I9VYE9"!A<R!D969A=6QT('!R:6]R:71Y
M+B(L"@DG='1S7U]C86YT7V1E;%]Q=65U95]T:6-K971S)R`]/B`B56YA8FQE
M('1O(&1E;&5T92!T:&4@<75E=64Z(&ET(&ES('5S960@8GD@8V5R=&%I;B!T
M:6-K971S(&]R(&%S<VEG;F5D(&%S(&1E9F%U;'0@<75E=64N(BP*"2=T='-?
M7V-A;G1?;W!E;E]N;W1?8VQO<V5D)R`]/B`B66]U(&-A;FYO="!R96]P96X@
M82!N;VXM8VQO<V5D('1I8VME="(L"@DG='1S7U]C871E9V]R>2<@/3X@(D-A
M=&5G;W)Y(BP*"2=T='-?7V-A=&5G;W)Y7V%L<F5A9'E?97AI<W1S7U\G(#T^
M("=#871E9V]R>2`E,2!A;')E861Y(&5X:7-T<RXG+`H))W1T<U]?8V%T<R<@
M/3X@(D-A=&5G;W)I97,B+`H))W1T<U]?8V]N9E]C86Y?<&]S="<@/3X@(D%L
M;&]W(&-U<W1O;65R<R!T;R!S=6)M:70@=&EC:V5T<R(L"@DG='1S7U]C;VYF
M7V1E9E]C871E9V]R>2<@/3X@(D1E9F%U;'0@0V%T96=O<GDB+`H))W1T<U]?
M96YA8FQE9"<@/3X@(D5N86)L960B+`H))W1T<U]?9V5N97)A;%]C;VYF:6<G
M(#T^(")(96QP($1E<VL@4V5T=&EN9W,B+`H))W1T<U]?<')I;W)I=&EE<U]L
M:7-T)R`]/B`B4')I;W)I=&EE<R(L"@DG='1S7U]P=6)L:6-?;F%M92<@/3X@
M(DYO=&EF:6-A=&EO;B!396YD97(G<R!.86UE(BP*"2=T='-?7W!U8FQI8U]E
M;6%I;"<@/3X@(DYO=&EF:6-A=&EO;B!396YD97(G<R!2971U<FX@061D<F5S
M<R(L"@DG='1S7U]C;VYF7V1E9E]P<FEO<FET>2<@/3X@(D1E9F%U;'0@4')I
M;W)I='DB+`H))W1T<U]?8V]N9E]D969?<75E=64G(#T^(")$969A=6QT(%%U
M975E(BP*"2=T='-?7V-O;F9?96YA8FQE9"<@/3X@(D5N86)L960B+`H))W1T
M<U]?8V]N9FEG=7)A=&EO;B<@/3X@(DAE;'`@1&5S:R!3971T:6YG<R(L"@DG
M='1S7U]E9&ET7V-A="<@/3X@(D5D:70@8V%T96=O<GDB+`H))W1T<U]?961I
M=%]P<FEO<FET>2<@/3X@(D5D:70@<')I;W)I='DB+`H))W1T<U]?961I=%]Q
M=65U92<@/3X@(D5D:70@<75E=64B+`H))W1T<U]?97)R7W-E;%]Q<&,G(#T^
M(")9;W4@<VAO=6QD('-E;&5C="!T:&4@9&5F875L="!Q=65U92P@<')I;W)I
M='D@86YD(&-A=&5G;W)Y('1O(&%L;&]W('1I8VME="!S=6)M:7-S:6]N+B(L
M"@DG='1S7U]G;%]C;G1?8VQO<V5D)R`]/B`B0VQO<V5D(BP*"2=T='-?7V=L
M7V-N=%]N97<G(#T^(").97<B+`H))W1T<U]?9VQ?8VYT7V]P96YE9"<@/3X@
M(D]P96XB+`H))W1T<U]?9VQ?8VYT7W)E;W!E;F5D)R`]/B`B4F5O<&5N960B
M+`H))W1T<U]?9VQ?<V5R=F5R7VYA;64G(#T^(")397)V97(@2&]S=&YA;64B
M+`H))W1T<U]?9VQ?<V5R=F5R<R<@/3X@(E-E<G9E<G,B+`H))W1T<U]?9VQ?
M='1S7V-A;E]P;W-T)R`]/B`B5&EC:V5T(%-U8FUI<W-I;VXB+`H))W1T<U]?
M9VQ?='1S7V5N86)L960G(#T^(")(96QP($1E<VL@:7,@86-T:79A=&5D(BP*
M"2=T='-?7V=L7W5N:VYO=VXG(#T^(")5;FMN;W=N(BP*"2=T='-?7V=L7W5P
M9&%T960G(#T^(")5<&1A=&5D(BP*"2=T='-?7V=L;V)A;%]T=',G(#T^(")'
M;&]B86P@2&5L<"!$97-K(BP*"2=T='-?7VQO8U]C;VYF7W1I=&QE)R`]/B`B
M3&]C86P@2&5L<"!$97-K(%-E='1I;F=S(BP*"2=T='-?7VQO8U]I;F9O)R`]
M/B`B5&]T86P@)3$L('1O=&%L(&]P96X@)3(@*"!N97<@)3,L(')E;W!E;F5D
M("4T*2P@=&]T86P@8VQO<V5D("4U('1I8VME=',N(BP*"2=T='-?7VQO8U]T
M:6-K971S7W1I=&QE)R`]/B`B3&]C86P@5&EC:V5T<R(L"@DG='1S7U]M86EL
M9V%T95]C;VYF:6<G(#T^(")(96QP($1E<VL@36%I;"!'871E(%-E='1I;F=S
M(BP*"2=T='-?7VYE=R<@/3X@(DYE=R!4:6-K970B+`H))W1T<U]?<&]P7W-E
M<G9E<B<@/3X@(E!/4#,@4V5R=F5R(BP*"2=T='-?7W!O<%]U<V5R;F%M92<@
M/3X@(E!/4#,@3&]G:6XB+`H))W1T<U]?<')I;W)I=&EE<R<@/3X@(E!R:6]R
M:71I97,B+`H))W1T<U]?<')I;W)I='DG(#T^(")0<FEO<FET>2(L"@DG='1S
M7U]P<FEO<FET>5]A;')E861Y7V5X:7-T<U]?)R`]/B`B4')I;W)I='D@)3$@
M86QR96%D>2!E>&ES=',N(BP*"2=T='-?7W%U97)Y7W!E<FEO9"<@/3X@(E%U
M97)Y(&UA:6P@;VYC92!I;B(L"@DG='1S7U]Q=65R>5]P97)I;V1?;6EN=71E
M<R<@/3X@(FUI;B(L"@DG='1S7U]Q=65U97,G(#T^(")1=65U97,B+`H))W1T
M<U]?<75E=65S7VQI<W0G(#T^(")1=65U97,@;&ES="(L"@DG='1S7U]Q=65U
M92<@/3X@(E%U975E(BP*"2=T='-?7W%U975E7V%L<F5A9'E?97AI<W1S7U\G
M(#T^("=1=65U92`E,2!A;')E861Y(&5X:7-T<RXG+`H))W1T<U]?<F5M;W9E
M7V-A=',G(#T^(")296UO=F4@8V%T96=O<FEE<R(L"@DG='1S7U]R96UO=F5?
M<')I;W)I=&5S)R`]/B`B4F5M;W9E('!R:6]R:71I97,B+`H))W1T<U]?<F5M
M;W9E7W%U975E<R<@/3X@(E)E;6]V92!Q=65U97,B+`H))W1T<U]?<F5P;W)T
M97)?='EP95]A9&UI;B<@/3X@(D%D;6EN:7-T<F%T;W(B+`H))W1T<U]?<F5P
M;W)T97)?='EP95]C;&EE;G0G(#T^(")#;&EE;G0B+`H))W1T<U]?<F5P;W)T
M97)?='EP95]D;VUA:6XG(#T^(")$;VUA:6XB+`H))W1T<U]?<F5P;W)T97)?
M='EP95]E;6%I;"<@/3X@(D4M;6%I;"(L"@DG='1S7U]R97!O<G1E<E]T>7!E
M7VUA:6QN86UE)R`]/B`B36%I;"!N86UE(BP*"2=T='-?7W-E;&5C=%]C871S
M7W1O7W)E;6]V92<@/3X@(E-E;&5C="!C871E9V]R:65S('1O(&)E(')E;6]V
M960N(BP*"2=T='-?7W-E;&5C=%]E=F5N=%]T>7!E)R`]/B`B4V5L96-T(&5V
M96YT('1Y<&4@9F]R(&-O;6UE;G0@<W5B;6ES<VEO;B(L"@DG='1S7U]S96QE
M8W1?<')I;W)I=&5S7W1O7W)E;6]V92<@/3X@(E-E;&5C="!P<FEO<FET:65S
M('1O(&)E(')E;6]V960N(BP*"2=T='-?7W-E;&5C=%]Q=65U97-?=&]?<F5M
M;W9E)R`]/B`B4V5L96-T('%U975E<R!T;R!B92!R96UO=F5D+B(L"@DG='1S
M7U]S=&%R=%]T:6-K971?<W5B:B<@/3X@(E1I8VME="!S=6)J96-T(&UU<W0@
M<W1A<G0@=VET:"(L"@DG='1S7U]T979?8VQO<V5D)R`]/B`B0VQO<V5D(BP*
M"2=T='-?7W1E=E]C;VUM96YT960G(#T^(")#;VUM96YT960B+`H))W1T<U]?
M=&5V7V-R96%T960G(#T^(")#<F5A=&5D(BP*"2=T='-?7W1E=E]R96]P96YE
M9"<@/3X@(E)E;W!E;F5D(BP*"2=T='-?7W1I8VME="<@/3X@(E1I8VME="(L
M"@DG='1S7U]T:6-K971?8F]D>2<@/3X@(E1I8VME="!";V1Y(BP*"2=T='-?
M7W1I8VME=%]C871E9V]R>2<@/3X@(D-A=&5G;W)Y(BP*"2=T='-?7W1I8VME
M=%]I9"<@/3X@(DED(BP*"2=T='-?7W1I8VME=%]M86EL8VQ?;F%M92<@/3X@
M(E)E<&]R=&5R($YA;64B+`H))W1T<U]?=&EC:V5T7VUO9&EF:65D)R`]/B`B
M36]D:69I960B+`H))W1T<U]?=&EC:V5T7W%U975E)R`]/B`B475E=64B+`H)
M)W1T<U]?=&EC:V5T7W)E<&]R=&5R7W1Y<&4G(#T^(")297!O<G1E<B!4>7!E
M(BP*"2=T='-?7W1I8VME=%]S=&%T=7,G(#T^(")4:6-K970@4W1A='5S(BP*
M"2=T='-?7W1I8VME=%]S=6)J96-T)R`]/B`B5&EC:V5T(%-U8FIE8W0B+`H)
M)W1T<U]?=&EC:V5T7W1I=&QE:60G(#T^(")4:6-K970@)3$B+`H))W1T<U]?
M=&EC:V5T<R<@/3X@(E1I8VME=',B+`H))W1T<U]?=&EC:V5T<U]L:7-T)R`]
M/B`B5&EC:V5T<R(L"@DG='1S7U]T:6-K971S7W-U;6UA<GDG(#T^(")4:6-K
M971S(%-U;6UA<GDB+`H))W1T<U]?=&YE=E]C;&]S92<@/3X@(D-L;W-E('1I
M8VME="(L"@DG='1S7U]T;F5V7V-O;6UE;G0G(#T^(")#;VUM96YT('1I8VME
M="(L"@DG='1S7U]T;F5V7W)E;W!E;B<@/3X@(E)E;W!E;B(L"@DG='1S7U]T
M<U]A;&PG(#T^(")!;&PB+`H))W1T<U]?='-?86QL;W!E;F5D)R`]/B`B06QL
M(&]P96XB+`H))W1T<U]?='-?8VQO<V5D)R`]/B`B0VQO<V5D(BP*"2=T='-?
M7W1S7VYE=R<@/3X@(DYE=R(L"@DG='1S7U]T<U]R96]P96YE9"<@/3X@(E)E
M;W!E;F5D(BP*"2=T='-?7W1T<R<@/3X@(DAE;'`@1&5S:R(L"@DG='1S7V-A
M;G1?<&]S="<@/3X@(E1I8VME="!S=6)M:7-S:6]N(&ES(&1I<V%B;&5D(BP*
M"2=T='-?979?7VAI<W1O<GDG(#T^(")4:6-K970@2&ES=&]R>2(L"@DG='1S
M7VYO=%]A8W1I=F%T960G(#T^(")(96QP($1E<VL@:7,@;F]T(&%C=&EV871E
M9"XB+`H))W1T<U]T:6-K971?7V1O)R`]/B`B5&EC:V5T($5V96YT(BP*"2=T
M='-?=&EC:V5T7U]N97=?8V]M;65N="<@/3X@(DYE=R!#;VUM96YT(BP*"2=T
M='-?=&EC:V5T7U]P=6)L:6,G(#T^(")6:7-I8FQE('1O(&-L:65N="(L"@DG
M='1S7W1I8VME=%]?<')I=F%T92<@/3X@(DEN=FES:6)L92!T;R!C;&EE;G0B
M+`H))W1T<U]T:6-K971?9&]?<V5C=&EO;B<@/3X@(DYE=R!%=F5N="(L"@DG
M=FA?8F%S961?7VYO7V9R965?:7!?9F]R7W9H)R`]/B`B5&AE<F4@87)E(&YO
M('9A8V%N="!)4"!A9&1R97-S97,@9F]R('1H92!)4"UB87-E9"!V:7)T=6%L
M(&AO<W1I;F<N(%!L96%S92P@861D(&%N($E0(&%D9')E<W,N(BP*"@DG=FES
M:6)I;&ET>5]?861M:6YO;FQY)R`]/B`G061M:6X@3VYL>2<L"@DG=FES:6)I
M;&ET>5]?8G5T=&]N7W-E=',G(#T^("="=71T;VX@<V5T<R<L"@DG=FES:6)I
M;&ET>5]?8V]N=')O;"<@/3X@)T-L:6-K('1O(&-U<W1O;6EZ92!T:&ES(&-O
M;G1R;VPN)RP*"2=V:7-I8FEL:71Y7U]C=7)R96YT7V-U<W1O;6EZ871I;VYS
M)R`]/B`G0W5R<F5N="!C=7-T;VUI>F%T:6]N<R<L"@DG=FES:6)I;&ET>5]?
M8W5R<F5N=%]C=7-T;VUI>F%T:6]N<U]B96QO=R<@/3X@)U1H92!F;VQL;W=I
M;F<@8G5T=&]N<R!H879E(&-U<W1O;2!S971T:6YG<RX@0VQI8VL@=&AE;2!T
M;R!C:&%N9V4@=&AE<V4@<V5T=&EN9W,N)RP*"2=V:7-I8FEL:71Y7U]C=7)R
M96YT7V-U<W1O;6EZ871I;VYS7V9O<FUS)R`]/B`G4V]M92!C;VYT<F]L<R!O
M;B!F;W)M<R!H879E(&-U<W1O;2!S971T:6YG<RXG+`H))W9I<VEB:6QI='E?
M7V-U<W1O;6EZ871I;VY?9F]O=&YO=&4G(#T^("=#;&EC:R!/2R!T;R!F:6YI
M<V@@8W5S=&]M:7IA=&EO;B!O9B!T:&ES('-C<F5E;BXG+`H))W9I<VEB:6QI
M='E?7V1E9F%U;'0G(#T^("=$969A=6QT)RP*"2=V:7-I8FEL:71Y7U]E>'!O
M<G1?;F]T92<@/3X@(E1H92!C=7-T;VUI>F%T:6]N('-E='1I;F=S('EO=2!M
M861E(&%R92!A8F]U="!T;R!B92!E>'!O<G1E9"X@02!S:&5L;"!S8W)I<'0@
M=VEL;"!N;W<@8F4@9&]W;FQO861E9"!T;R!Y;W5R(&-O;7!U=&5R+B!4;R!A
M<'!L>2!T:&5S92!S971T:6YG<R!T;R!A;F]T:&5R(%!L97-K('-E<G9E<BP@
M;W9E<G=R:71I;F<@86YY(&5X:7-T:6YG(&EN=&5R9F%C92!M86YA9V5M96YT
M('-E='1I;F=S+"!P;&5A<V4@=7!L;V%D(&%N9"!E>&5C=71E('1H92!S8W)I
M<'0@=&AE<F4N7&Y<;E!L96%S92!N;W1E('1H870L(&EF('EO=2!H879E(&UA
M9&4@86YY(&-H86YG97,@;VX@=&AI<R!S8W)E96X@8G5T(&AA=F5N)W0@>65T
M(&-L:6-K960@3TLL('1H92!D871A(&5X<&]R=&5D('=I;&P@;F]T(&EN8VQU
M9&4@>6]U<B!L871E<W0@8VAA;F=E<RXB+`H))W9I<VEB:6QI='E?7V9O<FU?
M8V]N=')O;'-?<F5S970G(#T^("=!;&P@8V]N=')O;',@;VX@9F]R;7,@=VEL
M;"!B92!R97-E="!T;R!D969A=6QT('-E='1I;F=S)RP*"2=V:7-I8FEL:71Y
M7U]H:61E)R`]/B`G2&ED92<L"@DG=FES:6)I;&ET>5]?:&ED95]D:7-A8FQE
M9"<@/3X@)TAI9&4@86QL(&=R87EE9"!O=70@8G5T=&]N<R!B>2!D969A=6QT
M)RP*"2=V:7-I8FEL:71Y7U]H:61E7W5N879A:6QA8FQE7VQI;6ET<R<@/3X@
M)TAI9&4@9G)O;2!U<V5R<R!T:&4@;&EM:70@;6%N86=E;65N=`IC;VYT<F]L
M<R!T:&5Y(&%R92!N;W0@86QL;W=E9"!T;R!O<&5R871E)RP*"2=V:7-I8FEL
M:71Y7U]H:61E7W5N879A:6QA8FQE7W!E<FUI<W-I;VYS)R`]/B`G2&ED92!F
M<F]M('5S97)S('1H92!P97)M:7-S:6]N"FUA;F%G96UE;G0@8V]N=')O;',@
M=&AE>2!A<F4@;F]T(&%L;&]W960@=&\@;W!E<F%T92<L"@DG=FES:6)I;&ET
M>5]?;F]?8W5R<F5N=%]C=7-T;VUI>F%T:6]N<R<@/3X@)T%L;"!B=71T;VYS
M(&]N(%!L97-K('-C<F5E;G,@:&%V92!D969A=6QT('-E='1I;F=S+B<L"@DG
M=FES:6)I;&ET>5]?<F5S971?86QL)R`]/B`G4F5S970@86QL('1O(&1E9F%U
M;'0G+`H))W9I<VEB:6QI='E?7W)E<V5T7W-C<F5E;B<@/3X@)U)E<W1O<F4@
M;W)I9VEN86P@;&%Y;W5T(&]F('1H:7,@<V-R965N)RP*"2=V:7-I8FEL:71Y
M7U]R;V]T7V]V97)R:61E7W!A<G-E7V5R<F]R)R`]/B`G5&AE<F4@:7,@82!S
M>6YT87@@97)R;W(@:6X@9FEL92`E,2!I;B!L:6YE("4R(2<L"@DG=FES:6)I
M;&ET>5]?<V-R965N7W1I=&QE)R`]/B`G26YT97)F86-E(&UA;F%G96UE;G0G
M+`H))W9I<VEB:6QI='E?7W-E=%]C97)T7W!U8VAA<VEN9R<@/3X@)TAI9&4@
M8G5T=&]N<R!F;W(@8V5R=&EF:6-A=&4@<'5R8VAA<VEN9R<L"@DG=FES:6)I
M;&ET>5]?<V5T7V1O;6%I;E]R96=I<W1R871I;VXG(#T^("=(:61E(&)U='1O
M;G,@9F]R(&1O;6%I;B!R96=I<W1R871I;VXG+`H))W9I<VEB:6QI='E?7W-E
M=%]E>'1R87,G(#T^("=(:61E(&)U='1O;G,@9F]R(&5X=')A('-E<G9I8V5S
M)RP*"2=V:7-I8FEL:71Y7U]S971?;6%I;%]B;W5N8V4G(#T^("=(:61E(&-O
M;G1R;VQS(&9O<B!B;W5N8V4@;65S<V%G97,@9F]R(&YO;BUE>&ES=&5N="!M
M86EL(&%D9')E<W-E<R<L"@DG=FES:6)I;&ET>5]?<VAO=R<@/3X@)U-H;W<G
M+`H))W9I<VEB:6QI='E?7W-H;W=?=&]O;&)A<B<@/3X@)U-H;W<@26YT97)F
M86-E(&UA;F%G96UE;G0@=&]O;&)A<B<L"@DG=FES:6)I;&ET>5]?<W1A;F1B
M>5]F;V]T;F]T92<@/3X@)T-L:6-K('1O(&-U<W1O;6EZ92!C;VYT<F]L<R!O
M;B!T:&ES('-C<F5E;BXG+`H))W9I<VEB:6QI='E?7W-T86YD8GE?9F]O=&YO
M=&5?;F]C;VYT<F]L<R<@/3X@)U1H97)E(&%R92!N;R!C=7-T;VUI>F%B;&4@
M8V]N=')O;',@;VX@=&AI<R!S8W)E96XN)RP*"2=I;G1E<F9A8V5?<')E9F5R
M96YC97,G(#T^("=);G1E<F9A8V4@<')E9F5R96YC97,G+`H))VET;7!L7U]L
M:7-T7W1I=&QE)R`]/B`G26YT97)F86-E('1E;7!L871E<R!M86YA9V5M96YT
M)RP*"2=P8E]?:6YT97)F86-E7W1E;7!L871E<R<@/3X@)TEN=&5R9F%C92!M
M86YA9V5M96YT)RP*"2=B=%]I;G1E<F9A8V5?=&5M<&QA=&5?861D)R`]/B`G
M061D($EN=&5R9F%C92!496UP;&%T92<L"@DG:71M<&Q?7VQI<W1?;&5G96YD
M)R`]/B`G26YT97)F86-E('1E;7!L871E<R<L"@DG:71M<&Q?7VQI<W1?;F%M
M92<@/3X@)TEN=&5R9F%C92!T96UP;&%T92!N86UE)RP*"2=I=&UP;%]?;&ES
M=%]U<V%G92<@/3X@)U5S86=E)RP*"2=I=&UP;%]?;&ES=%]H96%D97(G(#T^
M("=);G1E<F9A8V4@=&5M<&QA=&5S)RP*"2=I=&UP;%]?<V5L96-T7W1E;7!L
M871E<U]T;U]R96UO=F4G(#T^("=396QE8W0@=&AE(&EN=&5R9F%C92!T96UP
M;&%T97,@=&\@8F4@<F5M;W9E9"XG+`H))VET;7!L7U]S96QE8W1?=&5M<&QA
M=&5?=&]?;6%K95]D969A=6QT)R`]/B`G4V5L96-T(&%N(&EN=&5R9F%C92!T
M96UP;&%T92!T;R!M86ME(&ET(&1E9F%U;'0N)RP*"2=I=&UP;%]?;F%M92<@
M/3X@)TEN=&5R9F%C92!T96UP;&%T92!N86UE)RP*"2=B=%]S:&]W7VET;7!L
M7W1O;VQB87(G(#T^("=3:&]W(%1O;VQB87(G+`H))VET;7!L7U]U<&QO861?
M=&ET;&4G(#T^("=5<&QO860@:6YT97)F86-E('1E;7!L871E)RP*"2=I=&UP
M;%]?=7!L;V%D7VQE9V5N9"<@/3X@)U5P;&]A9"!I;G1E<F9A8V4@=&5M<&QA
M=&4G+`H))VET;7!L7U]F:6QE7VYA;64G(#T^("=0871H('1O(&EN=&5R9F%C
M92!T96UP;&%T92!F:6QE)RP*"2=I=&UP;%]?:6YV86QI9%]V86QU97,G(#T^
M("=);G9A;&ED('9A;'5E<R<L"@DG:71M<&Q?7V%L<F5A9'E?97AI<W0G(#T^
M("=);G1E<F9A8V4@=&5M<&QA=&4@=VET:"!N86UE("(E,2(@86QR96%D>2!E
M>&ES=',N)RP*"2=I=&UP;%]?=7!L;V%D7VEN=F%L:61?='EP92<@/3X@)TYO
M="!S=7!P;W)T960@9FEL92!T>7!E+B<L"@DG:71M<&Q?7WAM;%]L;V%D7V9A
M:6QE9"<@/3X@)UA-3"!F:6QE(&ES(&EN('1H92!W<F]N9R!F;W)M870N)RP*
M"2=I=&UP;%]?961I=%]T:71L92<@/3X@)T5D:70@:6YT97)F86-E('1E;7!L
M871E("4Q)RP*"2=I=&UP;%]?861D7W1I=&QE)R`]/B`G061D(&YE=R!I;G1E
M<F9A8V4@=&5M<&QA=&4G+`H))VET;7!L7U]C;%]L:7-T7V9O<E\G(#T^("=#
M;&EE;G1S('5S:6YG("4Q(&EN=&5R9F%C92!T96UP;&%T92<L"@DG:71M<&Q?
M7V-L7VQI<W1?861D)R`]/B`G4V5L96-T('1H92!C;&EE;G1S('=H;R!S:&]U
M;&0@=7-E('1H:7,@:6YT97)F86-E('1E;7!L871E)RP*"2=I=&UP;%]?<F5M
M;W9E7W1I=&QE)R`]/B`G5&AE(&9O;&QO=VEN9R!I;G1E<F9A8V4@=&5M<&QA
M=&5S('=I;&P@8F4@<F5M;W9E9#HG+`H))VET;7!L7U]R96UO=F5?8VQI96YT
M<R<@/3X@)U1H92!F;VQL;W=I;F<@8VQI96YT<R!W:6QL(&YO(&QO;F=E<B!U
M<V4@=&AI<R!I;G1E<F9A8V4@8W5S=&]M:7IA=&EO;B!T96UP;&%T93HG+`H)
M)W!B7U]I;G1E<F9A8V5?8VQI96YT<R<@/3X@)T-L:65N=',@=7-I;F<@)3$G
M+`H*"2=W96)A;&EZ97)?<')E9F5R96YC97-?7W1I=&QE)R`]/B`G5V5B(%-T
M871I<W1I8W,@4')E9F5R96YC97,G+`H))W=E8F%L:7IE<E]P<F5F97)E;F-E
M<U]?=&%B7VAI9&1E;E]R969E<G)E<G,G(#T^("=(:61D96X@4F5F97)R97)S
M)RP*"2=W96)A;&EZ97)?<')E9F5R96YC97-?7W1A8E]G<F]U<%]R969E<G)E
M<G,G(#T^("='<F]U<&5D(%)E9F5R<F5R<R<L"@H))W=E8F%L:7IE<E]H:61D
M96Y?<F5F97)R97)?7V5D:71?=&ET;&4G(#T^("=(:61D96X@16YT<GD@4')O
M<&5R=&EE<R<L"@DG=V5B86QI>F5R7VAI9&1E;E]R969E<G)E<E]?961I=%]L
M96=E;F0G(#T^("=(:61D96X@16YT<FEE<R<L"@DG=V5B86QI>F5R7VAI9&1E
M;E]R969E<G)E<E]?<F5F97)R97)?='EP92<@/3X@)T5N=')Y('1Y<&4G+`H)
M)W=E8F%L:7IE<E]H:61D96Y?<F5F97)R97)?7W)E9F5R<F5R)R`]/B`G4F5F
M97)R97(G+`H))W=E8F%L:7IE<E]H:61D96Y?<F5F97)R97)?7VQI<W1?:&5A
M9&5R)R`]/B`G2&ED9&5N(%)E9F5R<F5R<R<L"@DG=V5B86QI>F5R7VAI9&1E
M;E]R969E<G)E<E]?;&ES=%]L96=E;F0G(#T^("=(:61D96X@4F5F97)R97)S
M)RP*"2=W96)A;&EZ97)?:&ED9&5N7W)E9F5R<F5R7U]R969E<G)E<E]D:7)E
M8W1?<F5Q=65S="<@/3X@)T1I<F5C="!R97%U97-T)RP*"2=W96)A;&EZ97)?
M:&ED9&5N7W)E9F5R<F5R7U]R969E<G)E<E]C=7-T;VU?<F5F97)R97(G(#T^
M("=2969E<G)E<B<L"@DG=V5B86QI>F5R7VAI9&1E;E]R969E<G)E<E]?<F5M
M;W9E7V5M<'1Y7W-E;&5C=&EO;B<@/3X@)TYO(&5N=')I97,@<V5L96-T960G
M+`H))W=E8F%L:7IE<E]H:61D96Y?<F5F97)R97)?7W)E;6]V95]T:71L92<@
M/3X@)U1H92!F;VQL;W=I;F<@<F5F97)R97)S('=I;&P@;F\@;&]N9V5R(&)E
M(&AI9&1E;CHG+`H))W=E8F%L:7IE<E]H:61D96Y?<F5F97)R97)?7V%L<F5A
M9'E?97AI<W0G(#T^("=3=6-H(&5N=')Y(&%L<F5A9'D@97AI<W1S+B<L"@H)
M)W=E8F%L:7IE<E]G<F]U<%]R969E<G)E<E]?;&ES=%]H96%D97(G(#T^("='
M<F]U<"!2969E<G)E<G,G+`H))W=E8F%L:7IE<E]G<F]U<%]R969E<G)E<E]?
M;&ES=%]L96=E;F0G(#T^("='<F]U<"!2969E<G)E<G,G+`H))W=E8F%L:7IE
M<E]G<F]U<%]R969E<G)E<E]?961I=%]T:71L92<@/3X@)U)E9F5R<F5R($=R
M;W5P(%!R;W!E<G1I97,G+`H))W=E8F%L:7IE<E]G<F]U<%]R969E<G)E<E]?
M961I=%]L96=E;F0G(#T^("=2969E<G)E<B!'<F]U<"!0<F]P97)T:65S)RP*
M"2=W96)A;&EZ97)?9W)O=7!?<F5F97)R97)?7V=R;W5P)R`]/B`G1W)O=7`G
M+`H))W=E8F%L:7IE<E]G<F]U<%]R969E<G)E<E]?<F5F97)R97(G(#T^("=2
M969E<G)E<B<L"@DG=V5B86QI>F5R7V=R;W5P7W)E9F5R<F5R7U]A;')E861Y
M7V5X:7-T)R`]/B`G02!G<F]U<"!R969E<G)E<B!W:71H('-U8V@@;F%M92!A
M;')E861Y(&5X:7-T<RXG+`H))W=E8F%L:7IE<E]G<F]U<%]R969E<G)E<E]?
M<F5M;W9E7V5M<'1Y7W-E;&5C=&EO;B<@/3X@)TYO(')E9F5R<F5R<R!S96QE
M8W1E9"<L"@DG=V5B86QI>F5R7V=R;W5P7W)E9F5R<F5R7U]R96UO=F5?=&ET
M;&4G(#T^("=4:&4@9F]L;&]W:6YG(')E9F5R<F5R('-I=&5S('=I;&P@8F4@
M=6YG<F]U<&5D.B<L"@H))W=E8E]A<'!S7U]D;VUA:6Y?;&EM:71?97AC965D
M960G(#T^(")5;F%B;&4@=&\@861D(&YE=R!*879A(&%P<&QI8V%T:6]N.B!D
M;VUA:6X@;&EM:70@:7,@97AC965D960B+`H))W=E8E]A<'!S7U]H879E7VYO
M7W!E<FUI<W-I;VYS)R`]/B`B56YA8FQE('1O(&UA;F%G92!*879A(&%P<&QI
M8V%T:6]N<SH@8VQI96YT(&]R(&1O;6%I;B!L979E;"!U<V5R(&1O97,@;F]T
M(&AA=F4@=&AE(&%P<')O<')I871E('!E<FUI<W-I;VX@;W(@9&]M86EN(&ES
M(&YO="!A8W1I=F4N(BP*"2=W96)?87!P<U]?;VYL>5]W87)?9FEL92<@/3X@
M(D]N;'D@+G=A<B!F:6QE<R!C86X@8F4@:6YS=&%L;&5D(&%S(&$@2F%V82!A
M<'!L:6-A=&EO;BXB+`H))W=E8E]A<'!S7U]R96UO=F5?=V5B87!P<U]O;E]D
M;VTG(#T^(")4:&4@9F]L;&]W:6YG($IA=F$@87!P;&EC871I;VYS(&9O<B!D
M;VUA:6X@)3(@;W=N960@8GD@8VQI96YT("4Q('=I;&P@8F4@<F5M;W9E9#HB
M+`H))W=E8E]A<'!S7U]S96QE8W1?=V%R7V9I;&4G(#T^(")396QE8W0@2F%V
M82!A<'!L:6-A=&EO;B!F:6QE+B(L"@DG=V5B7V%P<'-?7W-E;&5C=%]W96)A
M<'!S7W1O7W)E;6]V92<@/3X@(E-E;&5C="!T:&4@2F%V82!A<'!L:6-A=&EO
M;G,@=&\@8F4@<F5M;W9E9"XB+`H))W=E8E]A<'!S7U]T:71L92<@/3X@(DIA
M=F$@87!P;&EC871I;VYS(&9O<B!D;VUA:6X@)3$B+`H))W=E8E]A<'!S7U]A
M9&1?=&ET;&4G(#T^(")!9&1I;F<@3F5W($IA=F$@07!P;&EC871I;VXB+`H)
M)W=E8E]A<'!S7U]T;VUC871?;6%Y7V)E7VYO=%]W;W)K)R`]/B`B4&]S<VEB
M;&4@<F5A<V]N("T@5&]M8V%T('-E<G9I8V4@:7,@;F]T(&-U<G)E;G1L>2!R
M=6YN:6YG(&]N('1H92!S97)V97(N(BP*"2=W96)?87!P<U]?=&]M8V%T7W-T
M871U<R<@/3X@(E1O;6-A="!S=&%T=7,B+`H))W=E8E]A<'!S7U]U;F%B;&5?
M=&]?<W1A<G1?=V5B87!P)R`]/B`B56YA8FQE('1O('-T87)T('5P($IA=F$@
M87!P;&EC871I;VXZ("4Q(BP*"2=W96)?87!P<U]?=6YA8FQE7W1O7V1O=VY?
M=V5B87!P)R`]/B`B56YA8FQE('1O('-H=70@9&]W;B!*879A(&%P<&QI8V%T
M:6]N.B`E,2(L"@DG=V5B7V%P<'-?7W5P;&]A9%]W87)?9FEL92<@/3X@(E5P
M;&]A9"!705(@9FEL92(L"@DG=V5B7V%P<'-?7W=A<E]F:6QE)R`]/B`B5T%2
M(&9I;&4B+`H))W=E8E]A<'!S7U]W96)?87!P7V-O=6QD;G1?;F%M961?;6%N
M86=E<B<@/3X@(D%N(&%P<&QI8V%T:6]N(&-A;FYO="!B92!N86UE9"!A<R!M
M86YA9V5R(BP*"2=W96)?87!P<U]?=V5B7V%P<%]F:6QE;F%M95]I;G9A;&ED
M)R`]/B`B07!P;&EC871I;VX@9FEL96YA;64@:7,@:6YV86QI9"X@57-E(&]N
M;'D@86QP:&%N=6UE<FEC(&-H87)A8W1E<G,L(&1O="!A;F0@:'EP:&5N('-Y
M;6)O;',N(BP*"2=W96)?87!P<U]?=V5B87!P7V5X:7-T<R<@/3X@(D$@2F%V
M82!A<'!L:6-A=&EO;B!W:71H('-U8V@@;F%M92!A;')E861Y(&5X:7-T<RXB
M+`H*"2=W=5]?861D:71I;VYA;%]F96%T=7)E<R<@/3X@(D%D9&ET:6]N86P@
M9F5A='5R97,B+`H))W=U7U]A=%]D;VUA:6YS7W1E>'0G(#T^(")%;F%B;&4@
M=V5B=7-E<D`E,2!A8V-E<W,@9F]R;6%T(BP*"2=W=5]?96YT97)?=V5B7W5S
M97)?;F%M92<@/3X@(D5N=&5R(&YE=R!W96(@=7-E<B!N86UE+B(L"@DG=W5?
M7VYE=U]W=2<@/3X@(D%D9"!N97<@=V5B('5S97(@;V8@9&]M86EN(#QB/B4Q
M/"]B/B(L"@DG=W5?7W)E;6]V95]W=5]O;E]D;VTG(#T^(")4:&4@9F]L;&]W
M:6YG('=E8B!U<V5R<R!O9B!D;VUA:6X@)3$@=VEL;"!B92!R96UO=F5D.B(L
M"@DG=W5?7W)E;6]V95]W=5]O;E]D;VU?;V9?8VPG(#T^(")4:&4@9F]L;&]W
M:6YG('=E8B!U<V5R<R!O9B!D;VUA:6X@)3(@;W=N960@8GD@8VQI96YT("4Q
M('=I;&P@8F4@<F5M;W9E9#HB+`H))W=U7U]S96QE8W1?=W5?9F]R7W)E;6]V
M92<@/3X@(E-E;&5C="!T:&4@=V5B('5S97)S('1O(&)E(')E;6]V960N(BP*
M"2=W=5]?=6YA8FQE7V-R96%T92<@/3X@(E5N86)L92!T;R!C<F5A=&4@=V5B
M('5S97(Z("4Q(BP*"2=W=5]?=6YA8FQE7W)E;6]V95]W=2<@/3X@(E5N86)L
M92!T;R!R96UO=F4@=V5B('5S97)S.B`E,2(L"@DG=W5?7W=E8E]U<V5R<U]D
M;VUA:6XG(#T^(")796(@=7-E<G,@;V8@9&]M86EN("4Q(BP*"2=W=5]?=W5?
M:61?=6YD969I;F5D)R`]/B`B5V5B('5S97(@:60@:7,@=6YD969I;F5D+B(L
M"@DG=W5?7W=U7VYA;64G(#T^(")796(@=7-E<B!N86UE(BP*"2=W=5]E9&ET
M7U]D:7-K7W%U;W1A)R`]/B`B1&ES:R!Q=6]T82(L"@DG=W5?961I=%]?:6YV
M86QI9%]P87-S)R`]/B`B4&%S<W=O<F0@:7,@:6YV86QI9"XB+`H))W=U7V5D
M:71?7VEN=F%L:61?<75O=&$G(#T^(")4:&4@<W!E8VEF:65D(&1I<VL@<W!A
M8V4@<75O=&$@=F%L=64@:7,@:6YV86QI9"X@4&QE87-E+"!E;G1E<B!A('!O
M<VET:79E(&EN=&5G97(N(BP*"2=W=5]E9&ET7U]N;W1?8W)E871E7W!A<W,G
M(#T^(")4:&ES(&%C=&EO;B!W:6QL(&YO="!C<F5A=&4@82!P87-S=V]R9"!F
M;W(@=&AE(&YE=R!W96(@=7-E<BY<;E=I=&AO=70@<&%S<W=O<F0@=&AE('5S
M97(@=VEL;"!N;W0@8F4@86)L92!T;R!L;V<@:6XN(BP*"2=W=5]E9&ET7U]P
M87-S=V1?9F]R7W=U)R`]/B`B4')O<&5R=&EE<R!O9B!W96(@=7-E<B`@)3$B
M+`H))W=U7V5D:71?7W5N86)L95]U<&1A=&4G(#T^(")5;F%B;&4@=&\@=7!D
M871E('1H92!W96(@=7-E<B!P<F]P97)T>3H@)3$B+`H*"2=D87-H8F]A<F1?
M7V)O;VMM87)K7V)U='1O;E]T:71L95]F879O<FET95]E9&ET)PD)/3X@)T5D
M:70@1F%V;W)I=&4G+`H))V1A<VAB;V%R9%]?8F]O:VUA<FM?8G5T=&]N7W1I
M=&QE7V9A=F]R:71E7V%D9"<)"0D]/B`G061D('1O(&9A=F]R:71E<R<L"@DG
M9&%S:&)O87)D7U]B;V]K;6%R:U]B=71T;VY?=&ET;&5?<VAO<G1C=71?961I
M="<)"3T^("=%9&ET(%-H;W)T8W5T)RP*"2=D87-H8F]A<F1?7V)O;VMM87)K
M7V)U='1O;E]T:71L95]S:&]R=&-U=%]A9&0G"0D)/3X@)T-R96%T92!S:&]R
M=&-U="<L"@H))V1A<VAB;V%R9%]?8F]O:VUA<FM?8G5T=&]N7V1E<V-R:7!T
M:6]N7V9A=F]R:71E7V5D:70G"3T^("=%9&ET('!R;W!E<G1I97,@;V8@<VAO
M<G1C=70@=&\@(B4Q(BXG+`H))V1A<VAB;V%R9%]?8F]O:VUA<FM?8G5T=&]N
M7V1E<V-R:7!T:6]N7V9A=F]R:71E7V%D9"<)/3X@)T%D9"`B)3$B('1O(&9A
M=F]R:71E<RXG+`H))V1A<VAB;V%R9%]?8F]O:VUA<FM?8G5T=&]N7V1E<V-R
M:7!T:6]N7W-H;W)T8W5T7V5D:70G"3T^("=%9&ET('!R;W!E<G1I97,@;V8@
M<VAO<G1C=70@=&\@(B4Q(BXG+`H))V1A<VAB;V%R9%]?8F]O:VUA<FM?8G5T
M=&]N7V1E<V-R:7!T:6]N7W-H;W)T8W5T7V%D9"<)/3X@)T-R96%T92!S:&]R
M=&-U="!T;R`B)3$B+B<L"@H))V1A<VAB;V%R9%]?8F]O:VUA<FM?=&ET;&5?
M9F%V;W)I=&5?961I="<)/3X@)T5D:71I;F<@4')O<&5R=&EE<R!O9B!3:&]R
M=&-U="!T;R`B)3$B)RP*"2=D87-H8F]A<F1?7V)O;VMM87)K7W1I=&QE7V9A
M=F]R:71E7V%D9"<)/3X@)T%D9&EN9R`B)3$B('1O($9A=F]R:71E<R<L"@DG
M9&%S:&)O87)D7U]B;V]K;6%R:U]T:71L95]S:&]R=&-U=%]E9&ET)PD]/B`G
M161I=&EN9R!0<F]P97)T:65S(&]F(%-H;W)T8W5T('1O("(E,2(G+`H))V1A
M<VAB;V%R9%]?8F]O:VUA<FM?=&ET;&5?<VAO<G1C=71?861D)PD]/B`G0W)E
M871I;F<@<VAO<G1C=70@=&\@(B4Q(B<L"@H))V1A<VAB;V%R9%]?<V5C=&EO
M;E]S:&]W7W1I=&QE)PD)"0D]/B`G4F5S=&]R92<L"@DG9&%S:&)O87)D7U]S
M96-T:6]N7VAI9&5?=&ET;&4G"0D)"3T^("=-:6YI;6EZ92<L"@DG9&%S:&)O
M87)D7U]S:&]R=&-U=%]P<F]P97)T:65S7W1I=&QE)PD)/3X@)U-H;W)T8W5T
M(%!R;W!E<G1I97,G+`H))V1A<VAB;V%R9%]?<VAO<G1C=71?=&ET;&4G"0D)
M"0D]/B`G5&ET;&4G+`H))V1A<VAB;V%R9%]?<VAO<G1C=71?=&ET;&5?9&5F
M875L="<)"0D]/B`G57-E(&1E9F%U;'0G+`H))V1A<VAB;V%R9%]?<VAO<G1C
M=71?9&5S8W)I<'1I;VXG"0D)/3X@)T1E<V-R:7!T:6]N)RP*"2=D87-H8F]A
M<F1?7W-H;W)T8W5T7V1E<V-R:7!T:6]N7V1E9F%U;'0G"3T^("=5<V4@9&5F
M875L="<L"@DG9&%S:&)O87)D7U]S:&]R=&-U=%]T:71L95]I;G9A;&ED7W9A
M;'5E)PD]/B`G5&AE('1I=&QE('-H;W5L9"!C;VYT86EN(&9R;VT@,2!T;R`R
M-34@8VAA<F%C=&5R<RXG+`H))V1A<VAB;V%R9%]?<VAO<G1C=71?9&5S8W)I
M<'1I;VY?:6YV86QI9%]V86QU92<)/3X@)U1H92!D97-C<FEP=&EO;B!S:&]U
M;&0@8V]N=&%I;B!F<F]M(#$@=&\@,C4U(&-H87)A8W1E<G,N)RP*"@DG9&%S
M:&)O87)D7U]P<F5S971S7V5X<&]R=%]F86EL960G"3T^("=%<G)O<B!O8V-U
M<G)E9"!D=7)I;F<@97AP;W)T:6YG('-E;&5C=&5D($1E<VMT;W`@<')E<V5T
M<SH@)3$G+`H))V1A<VAB;V%R9%]?<')E<V5T7V5R<F]R)PD)/3X@)T5R<F]R
M(&]C8W5R<F5D(&EN($1E<VMT;W`@<')E<V5T("(E,2(G+`H))V1A<VAB;V%R
M9%]?<')E<V5T7V5R<F]R7U\G"0D]/B`G17)R;W(@;V-C=7)R960@:6X@1&5S
M:W1O<"!P<F5S970@(B4Q(CH@)3(G+`H*"2=D87-H8F]A<F1?7W!R97-E=%]U
M<&QO861?9F%I;&5D)PD]/B`G17)R;W(@;V-C=7)R960@9'5R:6YG(&EM<&]R
M=&EN9R!$97-K=&]P('!R97-E=',@9G)O;2!F:6QE.B`E,2<L"@DG9&%S:&)O
M87)D7U]P<F5S971?<F5P;&%C95]N86UE7V-O;F9L:6-T)PD]/B`G4')E<V5T
M<R!W:71H('1H92!N86UE<R!C;VYT86EN960@:6X@=&AE(&9I;&4@86QR96%D
M>2!E>&ES="!I;B!0;&5S:RX@5&\@<F5P;&%C92!E>&ES=&EN9R!P<F5S971S
M('=I=&@@=&AE('5P;&]A9&5D(&]N97,L('-E;&5C="!T:&4@;W9E<G=R:71I
M;F<@8V]N9FER;6%T:6]N(&-H96-K8F]X+B<L"@DG9&%S:&)O87)D7U]P<F5S
M971?=7!L;V%D7W)E<&QA8V5?8V]N9FER;6%T:6]N)R`]/B`G3W9E<G=R:71E
M('!R97-E=',@=VET:"!T:&4@<V%M92!N86UE(&%N9"!T>7!E+B<L"@H))V1A
M<VAB;V%R9%]?<')E<V5T7W5P;&]A9%]T:71L92<)/3X@)U5P;&]A9&EN9R!$
M97-K=&]P(%!R97-E=',G+`H))V1A<VAB;V%R9%]?<')E<V5T7W5P;&]A9%]L
M96=E;F0G"3T^("=5<&QO860@1&5S:W1O<"!P<F5S971S)RP*"2=D87-H8F]A
M<F1?7W!R97-E=%]U<&QO861?9FEL96YA;64G"3T^("=$97-K=&]P('!R97-E
M=',@9FEL92!L;V-A=&EO;B<L"@H))V1A<VAB;V%R9%]?<')E<V5T7VYA;65?
M97AI<W1S)PD)/3X@)T1E<VMT;W`@4')E<V5T("!W:71H(&YA;64@)3$@86QR
M96%D>2!E>&ES=',N)RP*"2=?7V1A<VAB;V%R9%]P<F5S970G"0D)"3T^("=$
M97-K=&]P('!R97-E="<L"@DG9&%S:&)O87)D7U]P<F5S971S7W!R:79A=&4G
M"0D]/B`G0W5S=&]M:7IE9"!$97-K=&]P)RP*"@DG9&%S:&)O87)D7U]P<F5S
M971S7VQI<W1?;&5G96YD)PD]/B`G1&5S:W1O<"!P<F5S971S)RP*"2=D87-H
M8F]A<F1?7W!R97-E='-?;&ES=%]I=&5M)PD)/3X@)T1E<VMT;W`@<')E<V5T
M<R<L"@DG9&%S:&)O87)D7U]P<F5S971S7VQI<W1?8V]P>2<)"3T^("=#;W!Y
M($1E<VMT;W`@<')E<V5T)RP*"2=D87-H8F]A<F1?7W!R97-E='-?='EP92<)
M"3T^("=4)RP*"2=D87-H8F]A<F1?7W!R97-E=%]T>7!E)PD)/3X@)U1Y<&4G
M+`H))V1A<VAB;V%R9%]?<')E<V5T7W1Y<&5?861M:6XG"0D]/B`G061M:6YI
M<W1R871O<EPG<R!D97-K=&]P('!R97-E="<L"@DG9&%S:&)O87)D7U]P<F5S
M971?='EP95]C;&EE;G0G"0D]/B`G0VQI96YT7"=S(&1E<VMT;W`@<')E<V5T
M)RP*"2=D87-H8F]A<F1?7W!R97-E=%]T>7!E7V1O;6%I;B<)"3T^("=$;VUA
M:6X@;W=N97)<)W,@9&5S:W1O<"!P<F5S970G+`H))V1A<VAB;V%R9%]?<')E
M<V5T<U]N86UE)PD)/3X@)T1E<VMT;W`@<')E<V5T(&YA;64G+`H))V1A<VAB
M;V%R9%]?<')E<V5T7VYA;64G("`)"3T^("=.86UE)RP*"2=D87-H8F]A<F1?
M7W!R97-E=%]D969A=6QT)PD)/3X@)T1E9F%U;'0G+`H))V1A<VAB;V%R9%]?
M<')E<V5T7V1I<V%B;&5D7W1A<VMS)PD]/B`G079A:6QA8FQE('1A<VMS)RP*
M"2=D87-H8F]A<F1?7W!R97-E=%]E;F%B;&5D7W1A<VMS)PD]/B`G4V5L96-T
M960@=&%S:W,G+`H*"2=D87-H8F]A<F1?7V1E;&5T95]P<F5S971?8W5S=&]M
M7W!R97-E="<@/3X@)T-U<W1O;2!$97-K=&]P('!R97-E="!C86YN;W0@8F4@
M<F5M;W9E9"XG+`H))V1A<VAB;V%R9%]?9&5L971E7W!R97-E=%]P<FEV871E
M7W!R97-E="<@/3X@)U!R:79A=&4@1&5S:W1O<"!P<F5S970@8V%N;F]T(&)E
M(')E;6]V960N)RP*"2=D87-H8F]A<F1?7V1E;&5T95]P<F5S971?9&5F875L
M=%]P<F5S970G(#T^("=$969A=6QT($1E<VMT;W`@<')E<V5T(&-A;FYO="!B
M92!R96UO=F5D+B<L"@H))V1A<VAB;V%R9%]?=W)O;F=?<')E<V5T7W1Y<&4G
M"0D]/B`G26YC;VUP871I8FQE($1E<VMT;W`@<')E<V5T('1Y<&4N)RP*"@DG
M<&)?7V1A<VAB;V%R9"<)"0D)/3X@)T1E<VMT;W`G+`H*"2=D87-H8F]A<F1?
M7W!R97-E='-?>&UL7VQO861?97)R;W(G"3T^("=5;F%B;&4@=&\@:6UP;W)T
M(&1E<VMT;W`@<')E<V5T<SH@5&AE('5P;&]A9&5D(%A-3"!F:6QE(&-O;G1A
M:6YS(&$@<WEN=&%X(&5R<F]R+B<L"@DG9&%S:&)O87)D7U]P<F5S971S7WAM
M;%]V86QI9&%T:6]N7V5R<F]R)PD]/B`G56YA8FQE('1O(&EM<&]R="!D97-K
M=&]P('!R97-E=',Z(%1H92!U<&QO861E9"!834P@9FEL92!C;VYT86EN<R!A
M('-Y;G1A>"!E<G)O<BXG+`H))V1A<VAB;V%R9%]?<')E<V5T<U]X;6Q?=F5R
M<VEO;E]E<G)O<B<)"3T^("=5;F%B;&4@=&\@:6UP;W)T(&1E<VMT;W`@<')E
M<V5T<SH@5&AE('5P;&]A9&5D(%A-3"!F:6QE('=A<R!C<F5A=&5D(&)Y(%!L
M97-K('9E<G-I;VX@)3(@=VAI8V@@:7,@96%R;&EE<B!T:&%N('1H92!C=7)R
M96YT('9E<G-I;VX@*"4Q*2XG+`H*"2=D87-H8F]A<F1?7W!R97-E=%]R96UO
M=F5?96UP='E?<V5L96-T:6]N)PD]/B`G3F\@<')E<V5T<R!S96QE8W1E9"X@
M4V5L96-T(&1E<VMT;W`@<')E<V5T<R!Y;W4@=V%N="!T;R!R96UO=F4N)RP*
M"2=D87-H8F]A<F1?7W!R97-E=%]R96UO=F5?=&ET;&4G"0D)/3X@)U1H92!F
M;VQL;W=I;F<@1&5S:W1O<"!P<F5S971S('=I;&P@8F4@<F5M;W9E9#HG+`H*
M"2=D87-H8F]A<F1?7W!R97-E=%]E9&ET7W1I=&QE)PD)"0D]/B`G161I=&EN
M9R!$97-K=&]P(%!R97-E="<L"@DG9&%S:&)O87)D7U]D87-H8F]A<F1?8W5S
M=&]M:7IE7W1I=&QE)PD)/3X@)T-U<W1O;6EZ:6YG($1E<VMT;W`G+`H*"2=S
M97)V97)?:6YT97)F86-E7U]P86=E7W1I=&QE)PD]/B`G4V5R=F5R($EN=&5R
M9F%C92!0<F5F97)E;F-E<R<L"@DG<V5R=F5R7VEN=&5R9F%C95]?=&%B<U]L
M;V-A;&5S)R`]/B`G3&]C86QE<R<L"@DG<V5R=F5R7VEN=&5R9F%C95]?=&%B
M<U]S:VEN<R<)(#T^("=3:VEN<R<L"@DG<V5R=F5R7VEN=&5R9F%C95]?=&%B
M<U]D87-H8F]A<F1?<')E<V5T<R<@/3X@)T1E<VMT;W`@4')E<V5T<R<L"@DG
M<V5R=F5R7VEN=&5R9F%C95]?=&%B<U]I;G1E<F9A8V5?=&5M<&QA=&5S)R`]
M/B`G26YT97)F86-E(%1E;7!L871E<R<L"@DG8G1?<V5R=F5R7VEN=&5R9F%C
M92<)/3X@)TEN=&5R9F%C92!0<F5F97)E;F-E<R<L"@DG<&)?7W-E<G9E<E]I
M;G1E<F9A8V4G"3T^("=);G1E<F9A8V4@4')E9F5R96YC97,G+`H*"2=B=%]W
M:7IA<F1?;F5X="<@/3X@)TYE>'0@/CXG+`H))V)T7W=I>F%R9%]P<F5V)R`]
M/B`G/#P@0F%C:R<L"@H))U]?;&EM:71?97AC965D961?;6%X7V1O;5]S97)V
M97(G"0D)"3T^("=397)V97(@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R
M(&]F(&1O;6%I;G,N(%!L96%S92!C;VYT86-T('1O('1H92!S97)V97(@861M
M:6YI<W1R871O<BXG+`H))U]?;&EM:71?97AC965D961?;6%X7W-U8F1O;5]S
M97)V97(G"0D)/3X@)U-E<G9E<B!R96%C:&5D('1H92!L:6UI="!O;B!N=6UB
M97(@;V8@<W5B9&]M86EN<RX@4&QE87-E(&-O;G1A8W0@=&\@=&AE('-E<G9E
M<B!A9&UI;FES=')A=&]R+B<L"@DG7U]L:6UI=%]E>&-E961E9%]M87A?9&]M
M86EN7V%L:6%S97-?<V5R=F5R)PD]/B`G4V5R=F5R(')E86-H960@=&AE(&QI
M;6ET(&]N(&YU;6)E<B!O9B!D;VUA:6X@86QI87-E<RX@4&QE87-E(&-O;G1A
M8W0@=&\@=&AE('-E<G9E<B!A9&UI;FES=')A=&]R+B<L"@DG7U]L:6UI=%]E
M>&-E961E9%]M87A?=W5?<V5R=F5R)PD)"0D]/B`G4V5R=F5R(')E86-H960@
M=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!W96(@=7-E<B`@86-C;W5N=',N(%!L
M96%S92!C;VYT86-T('1O('1H92!S97)V97(@861M:6YI<W1R871O<BXG+`H)
M)U]?;&EM:71?97AC965D961?;6%X7VUN7W-E<G9E<B<)"0D)/3X@)U-E<G9E
M<B!R96%C:&5D('1H92!L:6UI="!O;B!N=6UB97(@;V8@92UM86EL(&YA;65S
M+B!0;&5A<V4@8V]N=&%C="!T;R!T:&4@<V5R=F5R(&%D;6EN:7-T<F%T;W(N
M)RP*"@DG7U]L:6UI=%]E>&-E961E9%]M87A?8VQ?=7-E<F%D;6EN)PD)/3X@
M)UEO=2!H879E(')E86-H960@=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!C;&EE
M;G0@86-C;W5N=',@9&5F:6YE9"!B>2!Y;W5R(&QI8V5N<V4@:V5Y+B!!;&QO
M=V5D.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D.B`E-2<L"@DG7U]L:6UI=%]E
M>&-E961E9%]M87A?9&]M7W5S97)A9&UI;B<)"3T^("=9;W4@:&%V92!R96%C
M:&5D('1H92!L:6UI="!O;B!N=6UB97(@;V8@9&]M86EN<R!D969I;F5D(&)Y
M('EO=7(@;&EC96YS92!K97DN($%L;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q
M=6ER960Z("4U+B<L"@DG7U]L:6UI=%]E>&-E961E9%]M87A?<W5B9&]M7W5S
M97)A9&UI;B<)"3T^("=9;W4@:&%V92!R96%C:&5D('1H92!L:6UI="!O;B!N
M=6UB97(@;V8@<W5B9&]M86EN<R!D969I;F5D(&)Y('EO=7(@;&EC96YS92!K
M97DN($%L;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG
M7U]L:6UI=%]E>&-E961E9%]D:7-K7W-P86-E7W5S97)A9&UI;B<)"3T^("=9
M;W4@:&%V92!N;R!F<F5E(&1I<VL@<W!A8V4@;&5F="X@5&]T86P@86UO=6YT
M(&]F(&%V86EL86)L92!D:7-K('-P86-E.B`E,BX@57-E9#H@)3,N(%)E<75I
M<F5D.B`E-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7W=U7W5S97)A9&UI
M;B<)"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R
M(&]F('=E8B!U<V5R("!A8V-O=6YT<R!D969I;F5D(&)Y('EO=7(@;&EC96YS
M92!K97DN($%L;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L
M"@DG7U]L:6UI=%]E>&-E961E9%]M87A?9&)?=7-E<F%D;6EN)PD)"3T^("=9
M;W4@:&%V92!R96%C:&5D('1H92!L:6UI="!O;B!N=6UB97(@;V8@9&%T86)A
M<V5S(&1E9FEN960@8GD@>6]U<B!L:6-E;G-E(&ME>2X@06QL;W=E9#H@)3(N
M(%5S960Z("4S+B!297%U:7)E9#H@)34N)RP*"2=?7VQI;6ET7V5X8V5E9&5D
M7VUA>%]B;WA?=7-E<F%D;6EN)PD)"3T^("=9;W4@:&%V92!R96%C:&5D('1H
M92!L:6UI="!O;B!N=6UB97(@;V8@;6%I;&)O>&5S(&1E9FEN960@8GD@>6]U
M<B!L:6-E;G-E(&ME>2X@06QL;W=E9#H@)3(N(%5S960Z("4S+B!297%U:7)E
M9#H@)34N)RP*"2=?7VQI;6ET7V5X8V5E9&5D7VUA>%]M;E]U<V5R861M:6XG
M"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F
M(&4M;6%I;"!N86UE<R!D969I;F5D(&)Y('EO=7(@;&EC96YS92!K97DN($%L
M;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG7U]L:6UI
M=%]E>&-E961E9%]M87A?<F5D:7)?=7-E<F%D;6EN)PD)/3X@)UEO=2!H879E
M(')E86-H960@=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!M86EL(&9O=V%R9&5R
M<R`H<F5D:7)E8W1S*2!D969I;F5D(&)Y('EO=7(@;&EC96YS92!K97DN($%L
M;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG7U]L:6UI
M=%]E>&-E961E9%]M87A?;6=?=7-E<F%D;6EN)PD)"3T^("=9;W4@:&%V92!R
M96%C:&5D('1H92!L:6UI="!O;B!N=6UB97(@;V8@;6%I;"!G<F]U<',@*&4M
M;6%I;"!F;W)W87)D97)S('=I=&@@;75L=&EP;&4@<F5C:7!I96YT<RD@9&5F
M:6YE9"!B>2!Y;W5R(&QI8V5N<V4@:V5Y+B!!;&QO=V5D.B`E,BX@57-E9#H@
M)3,N(%)E<75I<F5D.B`E-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7W)E
M<W!?=7-E<F%D;6EN)PD)/3X@)UEO=2!H879E(')E86-H960@=&AE(&QI;6ET
M(&]N(&YU;6)E<B!O9B`@875T;W)E<W!O;F1E<G,@9&5F:6YE9"!B>2!Y;W5R
M(&QI8V5N<V4@:V5Y+B!!;&QO=V5D.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D
M.B`E-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7VUA:6QL:7-T<U]U<V5R
M861M:6XG"3T^("=9;W4@:&%V92!R96%C:&5D('1H92!L:6UI="!O;B!N=6UB
M97(@;V8@;6%I;&EN9R!L:7-T<R!D969I;F5D(&)Y('EO=7(@;&EC96YS92!K
M97DN($%L;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG
M7U]L:6UI=%]E>&-E961E9%]M87A?=V5B87!P<U]U<V5R861M:6XG"3T^("=9
M;W4@:&%V92!R96%C:&5D('1H92!L:6UI="!O;B!N=6UB97(@;V8@2F%V82!A
M<'!L:6-A=&EO;G,@9&5F:6YE9"!B>2!Y;W5R(&QI8V5N<V4@:V5Y+B!!;&QO
M=V5D.B`E,BX@26YS=&%L;&5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@H))U]?
M;&EM:71?97AC965D961?;6%X7V1O;5]U<V5R8VQI96YT)PD)/3X@)UEO=2!H
M879E(')E86-H960@=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!D;VUA:6YS+B`@
M06QL;W=E9#H@)3(N(%5S960Z("4S+B!297%U:7)E9#H@)34N)RP*"2=?7VQI
M;6ET7V5X8V5E9&5D7VUA>%]S=6)D;VU?=7-E<F-L:65N="<)/3X@)UEO=2!H
M879E(')E86-H960@=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!S=6)D;VUA:6YS
M("X@06QL;W=E9#H@)3(N(%5S960Z("4S+B!297%U:7)E9#H@)34N)RP*"2=?
M7VQI;6ET7V5X8V5E9&5D7V1I<VM?<W!A8V5?=7-E<F-L:65N="<)/3X@)UEO
M=2!H879E(')E86-H960@=&AE(&1I<VL@<W!A8V4@=7-A9V4@;&EM:70N("!!
M;&QO=V5D.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D.B`E-2XG+`H))U]?;&EM
M:71?97AC965D961?;6%X7W1R869F:6-?=7-E<F-L:65N="<)/3X@)UEO=2!H
M879E(')E86-H960@=&AE(&QI;6ET(&]N(&%M;W5N="!O9B!B86YD=VED=&@N
M($%L;&]W960Z("4R+B!5<V5D.B`E,RXG+`H))U]?;&EM:71?97AC965D961?
M;6%X7W=U7W5S97)C;&EE;G0G"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@
M;&EM:70@;VX@;G5M8F5R(&]F('=E8B!U<V5R(&%C8V]U;G1S+B!!;&QO=V5D
M.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D.B`E-2XG+`H))U]?;&EM:71?97AC
M965D961?;6%X7V1B7W5S97)C;&EE;G0G"0D]/B`G66]U(&AA=F4@<F5A8VAE
M9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F(&1A=&%B87-E<R`N($%L;&]W960Z
M("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG7U]L:6UI=%]E>&-E
M961E9%]M87A?8F]X7W5S97)C;&EE;G0G"0D]/B`G66]U(&AA=F4@<F5A8VAE
M9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F(&UA:6QB;WAE<R`N($%L;&]W960Z
M("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG7U]L:6UI=%]E>&-E
M961E9%]M87A?<F5D:7)?=7-E<F-L:65N="<)"3T^("=9;W4@:&%V92!R96%C
M:&5D('1H92!L:6UI="!O;B!N=6UB97(@;V8@;6%I;"!F;W)W87)D97)S("AR
M961I<F5C=',I+B!!;&QO=V5D.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D.B`E
M-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7VUG7W5S97)C;&EE;G0G"0D]
M/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F(&UA
M:6P@9F]R=V%R9&5R<R!W:71H(&UU;'1I<&QE(')E8VEP:65N=',@*&UA:6P@
M9W)O=7!S*2X@06QL;W=E9#H@)3(N(%5S960Z("4S+B!297%U:7)E9#H@)34N
M)RP*"2=?7VQI;6ET7V5X8V5E9&5D7VUA>%]R97-P7W5S97)C;&EE;G0G"0D]
M/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F("!A
M=71O<F5S<&]N9&5R<RX@06QL;W=E9#H@)3(N(%5S960Z("4S+B!297%U:7)E
M9#H@)34N)RP*"2=?7VQI;6ET7V5X8V5E9&5D7VUA>%]M86EL;&ES='-?=7-E
M<F-L:65N="<)/3X@)UEO=2!H879E(')E86-H960@=&AE(&QI;6ET(&]N(&YU
M;6)E<B!O9B!M86EL:6YG(&QI<W1S+B!!;&QO=V5D.B`E,BX@57-E9#H@)3,N
M(%)E<75I<F5D.B`E-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7W=E8F%P
M<'-?=7-E<F-L:65N="<)/3X@)UEO=2!H879E(')E86-H960@=&AE(&QI;6ET
M(&]N(&YU;6)E<B!O9B!*879A(&%P<&QI8V%T:6]N<RX@06QL;W=E9#H@)3(N
M($EN<W1A;&QE9#H@)3,N(%)E<75I<F5D.B`E-2<L"@DG7U]L:6UI=%]E>&-E
M961E9%]E>'!I<F%T:6]N7W5S97)C;&EE;G0G"3T^("=9;W5R(&%C8V]U;G0@
M97AP:7)E9"!O;B`E,BXG+`H*"2=?7VQI;6ET7V5X8V5E9&5D7VUA>%]S=6)D
M;VU?=7-E<F1O;6%I;B<)/3X@)UEO=2!H879E(')E86-H960@=&AE(&QI;6ET
M(&]N(&YU;6)E<B!O9B!S=6)D;VUA:6YS("X@06QL;W=E9#H@)3(N(%5S960Z
M("4S+B!297%U:7)E9#H@)34N)RP*"2=?7VQI;6ET7V5X8V5E9&5D7V1I<VM?
M<W!A8V5?=7-E<F1O;6%I;B<)/3X@)UEO=2!H879E(')E86-H960@=&AE(&1I
M<VL@<W!A8V4@=7-A9V4@;&EM:70N("!!;&QO=V5D.B`E,BX@57-E9#H@)3,N
M(%)E<75I<F5D.B`E-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7W1R869F
M:6-?=7-E<F1O;6%I;B<)/3X@)UEO=2!H879E(')E86-H960@=&AE(&QI;6ET
M(&]N(&%M;W5N="!O9B!B86YD=VED=&@N($%L;&]W960Z("4R+B!5<V5D.B`E
M,RXG+`H))U]?;&EM:71?97AC965D961?;6%X7W=U7W5S97)D;VUA:6XG"0D]
M/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F('=E
M8B!U<V5R(&%C8V]U;G1S+B!!;&QO=V5D.B`E,BX@57-E9#H@)3,N(%)E<75I
M<F5D.B`E-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7V1B7W5S97)D;VUA
M:6XG"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R
M(&]F(&1A=&%B87-E<R`N($%L;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER
M960Z("4U+B<L"@DG7U]L:6UI=%]E>&-E961E9%]M87A?8F]X7W5S97)D;VUA
M:6XG"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R
M(&]F(&UA:6QB;WAE<R`N($%L;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER
M960Z("4U+B<L"@DG7U]L:6UI=%]E>&-E961E9%]M87A?<F5D:7)?=7-E<F1O
M;6%I;B<)"3T^("=9;W4@:&%V92!R96%C:&5D('1H92!L:6UI="!O;B!N=6UB
M97(@;V8@;6%I;"!F;W)W87)D97)S("AR961I<F5C=',I+B!!;&QO=V5D.B`E
M,BX@57-E9#H@)3,N(%)E<75I<F5D.B`E-2XG+`H))U]?;&EM:71?97AC965D
M961?;6%X7VUG7W5S97)D;VUA:6XG"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T
M:&4@;&EM:70@;VX@;G5M8F5R(&]F(&UA:6P@9F]R=V%R9&5R<R!W:71H(&UU
M;'1I<&QE(')E8VEP:65N=',@*&UA:6P@9W)O=7!S*2X@06QL;W=E9#H@)3(N
M(%5S960Z("4S+B!297%U:7)E9#H@)34N)RP*"2=?7VQI;6ET7V5X8V5E9&5D
M7VUA>%]R97-P7W5S97)D;VUA:6XG"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T
M:&4@;&EM:70@;VX@;G5M8F5R(&]F("!A=71O<F5S<&]N9&5R<RX@06QL;W=E
M9#H@)3(N(%5S960Z("4S+B!297%U:7)E9#H@)34N)RP*"2=?7VQI;6ET7V5X
M8V5E9&5D7VUA>%]M86EL;&ES='-?=7-E<F1O;6%I;B<)/3X@)UEO=2!H879E
M(')E86-H960@=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!M86EL:6YG(&QI<W1S
M+B!!;&QO=V5D.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D.B`E-2XG+`H))U]?
M;&EM:71?97AC965D961?;6%X7W=E8F%P<'-?=7-E<F1O;6%I;B<)/3X@)UEO
M=2!H879E(')E86-H960@=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!*879A(&%P
M<&QI8V%T:6]N<RX@06QL;W=E9#H@)3(N($EN<W1A;&QE9#H@)3,N(%)E<75I
M<F5D.B`E-2<L"@DG7U]L:6UI=%]E>&-E961E9%]E>'!I<F%T:6]N7W5S97)D
M;VUA:6XG"3T^("=9;W5R(&%C8V]U;G0@97AP:7)E9"!O;B`E,BXG+`H*"@DG
M86-T:6]N;&]G7U]D8E]S97)V97(G(#T^("=$871A8F%S92!S97)V97(G+`H)
M)V1A<VAB;V%R9%]?<')E<V5T<U]S96QE8W1?=&]?9&]W;FQO860G(#T^("=.
M;R!D97-K=&]P('!R97-E=',@<V5L96-T960N(%!L96%S92!S96QE8W0@=&AE
M('!R97-E=',@>6]U('=A;G0@=&\@9&]W;FQO860N)RP*"2=M:6=R871I;VY?
M=7!L;V%D7V9O<FU?;65S)R`]/B`G57!L;V%D:6YG(&UI9W)A=&EO;B!A9V5N
M="!T;R!H;W-T("4Q+B<L"@DG;6EG<F%T:6]N7W5P;&]A9%]A9V5N=%]F86QS
M92<@/3X@)T9A:6QE9"!T;R!U<&QO860@=&AE(&UI9W)A=&EO;B!A9V5N="<L
M"@DG;6EG<F%T:6]N7W5P;&]A9%]A9V5N="<@/3X@)TUI9W)A=&EO;B!!9V5N
M="!5<&QO860G+`H))VUI9W)A=&EO;E]U<&QO861?86=E;G1?;VXG(#T^("=5
M<&QO861I;F<@36EG<F%T:6]N($%G96YT('1O("4Q)RP*"2=M:6=R871I;VY?
M:&]S=%]I;F9O)R`]/B`G26YF;W)M871I;VX@;VX@4V]U<F-E($AO<W0@)3$G
M+`H))VUI9W)A=&EO;E]G971?86-C;W5N=%]A;F1?9&]M86EN<R<@/3X@)U-E
M;&5C="!O8FIE8W1S('1H870@>6]U('=I<V@@=&\@;6EG<F%T92!F<F]M(&AO
M<W0@)3$G+`H))VUI9W)A=&EO;E]M97-S86=E7VQE9V5N9"<@/3X@)TEN9F]R
M;6%T:6]N)RP*"2=M:6=R871I;VY?:&]S=%]D971A:6QS)R`]/B`G2&]S="!D
M971A:6QS)RP*"2=M:6=R871I;VY?:&]S=%]I;F9O7V]S)R`]/B`G3W!E<F%T
M:6YG('-Y<W1E;2<L"@DG;6EG<F%T:6]N7VAO<W1?:6YF;U]L;V%D879G)R`]
M/B`G3&]A9"!A=F5R86=E(&]N('1H92!H;W-T)RP*"2=M:6=R871I;VY?:&]S
M=%]I;F9O7VAO<W1I;F=P;&%T9F]R;2<@/3X@)TAO<W1I;F<@<&QA=&9O<FTO
M=F5R<VEO;B<L"@DG;6EG<F%T:6]N7VAO<W1?:6YF;U]C;&EE;G1S)R`]/B`G
M3G5M8F5R(&]F(&-L:65N=',G+`H))VUI9W)A=&EO;E]H;W-T7VEN9F]?9&]M
M86EN<R<@/3X@)TYU;6)E<B!O9B!D;VUA:6YS)RP*"2=M:6=R871I;VY?:&]S
M=%]I;F9O7VAO<W0G(#T^("=397)V97(G+`H))VUI9W)A=&EO;E]G971?86-C
M;W5N=%]D;VUA:6Y?;65S)R`]/B`G1&]W;FQO861I;F<@82!L:7-T(&]F(&%C
M8V]U;G1S(&%N9"!D;VUA:6YS(&9R;VT@=&AE('-O=7)C92!H;W-T("4Q+B<L
M"@DG;6EG<F%T:6]N7VUA:6Y?9&]W;FQO860Q)R`]/B`B5')A;G-F97)R:6YG
M(&9I;&4Z("4Q7&Y3:7IE.B`E,EQN3&5F="!T;R!T<F%N<V9E<CH@)3,B+`H)
M)VUI9W)A=&EO;E]M86EN7V1O=VYL;V%D,B<@/3X@(DAO<W0Z("4Q7&Y4<F%N
M<V9E<G)E9#H@)3(@9FEL97,L("4S7&Y,969T.B`E-"!F:6QE<RP@)35<;E1R
M86YS9F5R('-P965D.B`E-B(L"@DG;6EG<F%T:6]N7W-E;&5C=%]A8V-O=6YT
M)R`]/B`G4V5L96-T('1H92!C;&EE;G0@86-C;W5N="<L"@DG;6EG<F%T:6]N
M7VEP7VUA<%]P86=E)R`]/B`G25`@;6%P<&EN9R!F;W(@;6EG<F%T:6YG(&1A
M=&$@9G)O;2`E,2<L"@DG;6EG<F%T:6]N7V1B7W-E<G9R95]M87!?<&%G92<@
M/3X@)T1A=&%B87-E('-E<G9E<G,@;6%P<&EN9R!F;W(@;6EG<F%T:6YG(&1A
M=&$@9G)O;2`E,2<L"@DG;6EG<F%T:6]N7V1B7W-E<G9R95]M87!?;&5G96YD
M)R`]/B`G1$(@<V5R=F5R<R!M87!P:6YG)RP*"2=M:6=R871I;VY?:7!?;6%P
M)R`]/B`G25`@36%P<&EN9R<L"@DG;6EG<F%T:6]N7VEP7VUA<%]A;&5R="<@
M/3X@)U!L96%S92!S<&5C:69Y(&UA<'!I;F<@9F]R(&%L;"!)4"!A9&1R97-S
M97,G+`H))VUI9W)A=&EO;E]S=&]P7W!A9V4G(#T^("=3=&]P(&UI9W)A=&EN
M9R!D871A(&9R;VT@:&]S="`E,2<L"@DG;6EG<F%T:6]N7W-T;W!?;65S<V%G
M92<@/3X@)U-T;W`@=&AE(&UI9W)A=&EO;B!P<F]C97-S)RP*"2=M:6=R871I
M;VY?9&5P;&]Y7VEN9F\Q)R`]/B`G1&5P;&]Y:6YG("4Q("4R)RP*"2=M:6=R
M871I;VY?9&5P;&]Y7VEN9F\R)R`]/B`B5&]T86P@86-C;W5N=',O;&5F="`E
M,2\E,EQN5&]T86P@9&]M86EN<R]L969T("4S+R4T7&XB+`H))VUI9W)A=&EO
M;E]N;W1I9GDG(#T^("=.;W1I9GD@=7-E<G,@=7!O;B!C<F5A=&EO;B!O9B!E
M86-H('-Y<W1E;2!O8FIE8W0G+`H))VUI9W)A=&EO;E]K965P7V%R8VAI=F5S
M)R`]/B`G2V5E<"!T:&4@=&5M<&]R87)Y(&9I;&5S)RP*"2=M:6=R871I;VY?
M<V5T=&EN9R<@/3X@)T1E<&QO>6UE;G0@4V5T=&EN9W,G+`H))VUI9W)A=&EO
M;E]S971T:6YG7VQE9R<@/3X@)T1E<&QO>6UE;G0@<V5T=&EN9W,G+`H))VUI
M9W)A=&EO;E]D97!L;WE?<')O9W)E<W,G(#T^("=$97!L;WEM96YT('!R;V=R
M97-S)RP*"2=M:6=R871I;VY?9&5P;&]Y7VEN9F\G(#T^("=$97!L;WEM96YT
M('!R;V=R97-S(&9O<B!H;W-T("4Q)RP*"2=M:6=R871I;VY?:&]S="<@/3X@
M)U-O=7)C92!H;W-T)RP*"2=M:6=R871I;VY?<&%S<W=O<F0G(#T^("=,;V=I
M;B!P87-S=V]R9"<L"@DG;6EG<F%T:6]N7W!L871F;W)M)R`]/B`G4V]U<F-E
M('!L871F;W)M)RP*"2=M:6=R871I;VY?=')A;G-L971E)R`]/B`G0V]N=F5R
M=&EN9R!D=6UP('1O(%!L97-K(&9O<FUA="<L"@DG;6EG<F%T:6]N7V%G96YT
M7W=A:70G(#T^("=786ET:6YG('1H92!R97-P;VYS92!F<F]M(&%G96YT)RP*
M"2=M:6=R871I;VY?96YD7V1E<&QO>5]I;F9O)R`]/B`G1&%T82!M:6=R871I
M;VX@9G)O;2!H;W-T("4Q(&AA<R!B965N(&-O;7!L971E9"XG+`H))VUI9W)A
M=&EO;E]D97!L;WE?9&5T86EL<R<@/3X@)T1E=&%I;',G+`H))VUI9W)A=&EO
M;E]W<F]N9U]A9V5N="<@/3X@)T%G96YT(&ES(&YO="!S=6ET86)L92!F;W(@
M=&AE(&=I=F5N(&AO<W0N)RP*"2=M:6=R871I;VY?<V5L96-T7W-O;64G(#T^
M("=396QE8W0@=&AE(&]B:F5C=',@=&\@;6EG<F%T92XG+`H))VUI9W)A=&EO
M;E]D;W=L;V%D)R`]/B`G1&]W;FQO861I;F<@8V]N=&5N="!F<F]M(&AO<W0@
M)3$G+`H))VUI9W)A=&EO;E]D;W=L;V%D7W!R;V=R97-S)R`]/B`G1&]W;FQO
M860@<')O9W)E<W,G+`H))VUI9W)A=&EO;E]D;W=L;V%D7V-U<G)E;G0G(#T^
M("=$;W=N;&]A9&EN9R!C=7)R96YT(&9I;&4G+`H))VUI9W)A=&EO;E]X;6Q?
M9&5S8R<@/3X@)T1O=VYL;V%D:6YG('1H92!D=6UP(&1E<V-R:7!T:6]N+B<L
M"@DG;6EG<F%T:6]N7VYO7V5R<F]R<R<@/3X@)U1H92!M:6=R871I;VX@:&%S
M(&)E96X@8V]M<&QE=&5D+B<L"@DG;6EG<F%T:6]N7W5N86)L95]G971?86-C
M;W5N=%]A;F1?9&]M86EN<R<@/3X@)U5N86)L92!T;R!R971R:65V92!A(&QI
M<W0@;V8@86-C;W5N=',@86YD(&1O;6%I;G,Z("<L"@DG;6EG<F%T:6]N7W5N
M86)L95]T<F%N<VQA=&4G(#T^("=5;F%B;&4@=&\@8V]N=F5R="!T:&4@9&%T
M82!T;R!0;&5S:R!F;W)M870Z("<L"@DG;6EG<F%T:6]N7W5N86)L95]D=6UP
M7W)E=')I979E)R`]/B`G1F%I;&5D('1O(')E=')I979E('1H92!D871A.B`G
M+`H))VUI9W)A=&EO;E]U;F%B;&5?87)C:&EV95]H;W-T)R`]/B`G56YA8FQE
M('1O(&-R96%T92!A(&1E<V-R:7!T:6]N(&9O<B!T:&4@;6EG<F%T960@;V)J
M96-T<SH@)RP*"2=M:6=R871I;VY?<V5L96-T7V%C8V]U;G1?<&%G92<@/3X@
M)U-E;&5C="!T:&4@8VQI96YT(&%C8V]U;G0@=&\@=VAI8V@@>6]U('=I<V@@
M=&\@;6EG<F%T92!T:&4@9&]M86EN<R<L"@DG;6EG<F%T:6]N7W5N86)L95]D
M97!L;WDG(#T^("=5;F%B;&4@=&\@9&5P;&]Y('1H92!M:6=R871E9"!O8FIE
M8W1S.B`G+`H))V)T7VUI9W)A=&EO;E]M;W)E)R`]/B`G36EG<F%T92!M;W)E
M)RP*"2=B=%]M:6=R871I;VY?8F5G:6XG(#T^("=&:6YI<V@G+`H))VUI9W)A
M=&EO;E]S96QE8W1?97AI<W1?:7`G(#T^("=396QE8W0@9&5S=&EN871I;VX@
M25`G+`H))VUI9W)A=&EO;E]S96QE8W1?97AI<W1?9&)?<V5R=F5R)R`]/B`G
M4V5L96-T(&1E<W1I;F%T:6]N($1"('-E<G9E<B<L"@DG;6EG<F%T:6]N7V1O
M;6%I;E]C;W5N="<@/3X@)TYU;6)E<B!O9B!D;VUA:6YS)RP*"2=M:6=R871I
M;VY?86-C;W5N="<@/3X@)T%C8V]U;G0G+`H))VUI9W)A=&EO;E]D96UO7W=A
M<B<@/3X@(E=A<FYI;F<A(%1H:7,@:7,@=&AE($UI9W)A=&EO;B!-86YA9V5R
M(&1E;6\N($YO(&%C8V]U;G1S(&%N9"!D;VUA:6YS('=I;&P@8F4@86-T=6%L
M;'D@;6EG<F%T960N(%QN4&QE87-E('-P96-I9GD@=&AE(&1E<VER960@=F%L
M=65S+B(L"@DG;6EG<F%T:6]N7V1O=VYL;V%D7VYO=%]S<&%C92<@/3X@)TYO
M="!E;F]U9V@@9&ES:R!S<&%C92$G+`H))V)T7VUI9W)A=&EO;E]I9VYO<F4G
M(#T^("=)9VYO<F4G+`H))V)T7VUI9W)A=&EO;E]R971R>2<@/3X@)U)E=')Y
M)RP*"2=M:6=R871I;VY?9'5M<%]A;&PG(#T^("=-:6=R871E(&%L;"!C;&EE
M;G1S(&%N9"!D;VUA:6YS)RP*"2=M:6=R871I;VY?9&5T86EL<R<@/3X@)TUI
M9W)A=&EO;B!D971A:6QS)RP*"2=M:6=R871I;VY?;&EM:71?97)R;W(G(#T^
M(")4:&4@;G5M8F5R(&]F('MT>7!E?2!Y;W4@87)E('1R>6EN9R!T;R!C<F5A
M=&4@=V]U;&0@;W9E<G)I9&4@=&AE(&QI;6ET<R!D969I;F5D(&)Y('1H92!L
M:6-E;G-E(&ME>2`M("4Q+EQN66]U(&-A;B!C<F5A=&4@;VYL>2`E,B![='EP
M97T@;6]R92XB+`H))VUI9W)A=&EO;E]I9&QE)R`]/B`G4')E<&%R:6YG(&9O
M<B!E>&5C=71I;VXG+`H))VUI9W)A=&EO;E]R96UO=F5?86=E;G0G(#T^("=2
M96UO=F4@86=E;G0G+`H))VUI9W)A=&EO;E]S=&]P7VQA8FQE)R`]/B`G4W1O
M<'!I;F<G+`H))VUI9W)A=&EO;E]R96UO=F5?87)C:&EV92<@/3X@)U)E;6]V
M92!T96UP;W)A<GD@9FEL97,G+`H))VUI9W)A=&EO;E]N;U]O8FIE8W0G(#T^
M("=4:&5R92!A<F4@;F\@;V)J96-T<R!F;W(@;6EG<F%T:6]N(&]N('1H92!R
M96UO=&4@:&]S="XG+`H))VUI9W)A=&EO;E]N;U]D;VUA:6XG(#T^("=.;R!D
M;VUA:6YS('=E<F4@9F]U;F0G+`H))V)T7VUI9W)A=&5?<VEN9VQE)R`]/B`G
M4VEN9VQE+4AO<W0@36EG<F%T:6]N)RP*"2=M:6=R871I;VY?8V]M<')E<W,G
M(#T^("=$871A(&-O;7!R97-S:6]N)RP*"2=M:6=R871I;VY?;6]D92<@/3X@
M)TUI9W)A=&EO;B!M;V1E)RP*"2=M:6=R871I;VY?9'5M<%]M97-S86=E,2<@
M/3X@(D-U<G)E;G1L>2!D=6UP:6YG('1H92!A8V-O=6YT.B`E,5QN0W5R<F5N
M="!D;VUA:6XZ("4R7&Y!8V-O=6YT<R!L969T('1O(&1U;7`Z("4S7&Y$;VUA
M:6YS(&QE9G0@=&\@9'5M<#H@)30B+`H))VUI9W)A=&EO;E]D=6UP7W!R;V=R
M97-S)R`]/B`G1'5M<&EN9R!P<F]G<F5S<R<L"@DG;6EG<F%T:6]N7V1U;7!?
M8W5R<F5N="<@/3X@)T1U;7!I;F<@9&%T82<L"@DG;6EG<F%T:6]N7V%G96YT
M7W!A=&@G(#T^("=$:7)E8W1O<GD@;VX@=&AE('-O=7)C92!H;W-T('=H97)E
M($UI9W)A=&EO;B!-86YA9V5R('=I;&P@<&QA8V4@86QL(&1A=&$@8F5F;W)E
M('1R86YS9F5R<FEN9R!T:&5M)RP*"2=M:6=R871I;VY?9'5M<%]N;V5X:7-T
M)R`]/B`G1F]R('1H92!S:6YG;&4M:&]S="!M:6=R871I;VXL('EO=2!S:&]U
M;&0@<&QA8V4@=&AE(&1U;7`@=&\@(B4Q(BXG+`H))VUI9W)A=&EO;E]S=61O
M7W!A<W-W;W)D)R`]/B`G4W5D;R!P87-S=V]R9"<L"@DG;6EG<F%T:6]N7W-U
M9&]?<F]O="<@/3X@)W)O;W0G+`H))VUI9W)A=&EO;E]S=61O7V]T:&5R<R<@
M/3X@)V]T:&5R)RP*"2=M:6=R871I;VY?8F%C:V5N9%]C<F%S:%]O9F9?;65S
M<R<@/3X@)TUI9W)A=&EO;B!-86YA9V5R(&)A8VL@96YD('1E<FUI;F%T960@
M8F5C875S92!O9B!U;F5X<&5C=&5D(&5R<F]R+B!0;&5A<V4@8V]N=&%C="!S
M=7!P;W)T+B<L"@DG;6EG<F%T:6]N7W-I;F=L95]N;W1E7VUE<W,G(#T^("=5
M<V4@=&AI<R!F96%T=7)E('1O(&EM<&]R="!T:&4@9&%T82!C<F5A=&5D(&)Y
M('1H92!M:6=R871I;VX@86=E;G0N)RP*"2=M:6=R871I;VY?<VEN9VQE7VUO
M9&4G(#T^("=$871A(&EM<&]R="<L"@DG;6EG<F%T:6]N7VYO<FUA;%]M;V1E
M)R`]/B`G36EG<F%T:6]N)RP*"2=M:6=R871I;VY?<V5L96-T7V-L:65N="<@
M/3X@)U-E;&5C="!C;&EE;G0G+`H))VUI9W)A=&EO;E]F<F]M)R`]/B`G("AM
M:6=R871I;VX@9G)O;2!H;W-T("4Q*2<L"@DG;6EG<F%T:6]N7W-E;&5C=%]M
M;V1E)R`]/B`G4V5L96-T(&UI9W)A=&EO;B!M;V1E)RP*"2=M:6=R871I;VY?
M<V5L96-T7V-L:65N=%]I;E]L:7-T)R`]/B`G5&\@<V5L96-T(&$@8VQI96YT
M+"!C;&EC:R!O;B!T:&4@8VQI96YT(&YA;64G+`H))VUI9W)A=&EO;E]S:6YG
M;&5?:6YF;R<@/3X@)TEM<&]R=&EN9R!D871A(&9R;VT@)3$G+`H))VUI9W)A
M=&EO;E]D=6UP7VEN9F\G(#T^("=$=6UP(&1E=&%I;',G+`H))VUI9W)A=&EO
M;E]S96QE8W1?<VEN9VQE7VUO9&4G(#T^("=396QE8W0@:6UP;W)T(&UO9&4G
M+`H))VUI9W)A=&EO;E]S96QE8W1?<VEN9VQE7VET96TG(#T^("=396QE8W0@
M;V)J96-T<R!F;W(@:6UP;W)T)RP*"2=M:6=R871I;VY?<VEN9VQE7V%L;"<@
M/3X@)TEM<&]R="!A;&PG+`H))VUI9W)A=&EO;E]A9&1?9G)E95]I<"<@/3X@
M)SQB/DYO=&4Z/"]B/B!">2!S96QE8W1I;F<@82!V86-A;G0@25`@861D<F5S
M<R!Y;W4@=VEL;"!A9&0@:70@=&\@8VQI96YT7"=S($E0('!O;VPN)RP*"2=M
M:6=R871I;VY?:7!?=F%C86YT)R`]/B`G5F%C86YT)RP*"2=M:6=R871I;VY?
M<VEN9VQE7W1R86YS)R`]/B`G0V]N=F5R=&EN9R!D871A('1O(&YA=&EV92!0
M;&5S:R!F;W)M870G+`H))VUI9W)A=&EO;E]S96QE8W1?:7`G(#T^("=396QE
M8W0@25`G+`H))VUI9W)A=&EO;E]N;U]C:&5C:U]S<&%C92<@/3X@)T1O(&YO
M="!C:&5C:R!F;W(@86UO=6YT(&]F(&9R964@9&ES:R!S<&%C92!D=7)I;F<@
M;6EG<F%T:6]N)RP*"2=M:6=R871I;VY?9G-?:6YF;U]M;W5N='!O:6YT)R`]
M/B`G36]U;G0@<&]I;G0G+`H))VUI9W)A=&EO;E]F<U]I;F9O7W1Y<&4G(#T^
M("=4>7!E)RP*"2=M:6=R871I;VY?9G-?:6YF;U]T;W1A;"<@/3X@)U1O=&%L
M)RP*"2=M:6=R871I;VY?9G-?:6YF;U]F<F5E)R`]/B`G1G)E92<L"@DG;6EG
M<F%T:6]N7V9S7VQE9V5N="<@/3X@)U-O=7)C92!H;W-T('!A<G1I=&EO;B<L
M"@DG;6EG<F%T:6]N7V9S7W5S86=E)R`]/B`G57-A9V4G+`H))VUI9W)A=&EO
M;E]L;V-A;%]F<U]L96=E;G0G(#T^("=7;W)K:6YG(&1I<F5C=&]R>2<L"@DG
M;6EG<F%T:6]N7W-T;W)A9V5?9&ER)R`]/B`G1&ER96-T;W)Y(&]N('1H:7,@
M<V5R=F5R('1O('=H:6-H(&%L;"!D871A('=I;&P@8F4@=')A;G-F97)R960G
M+`H))VUI9W)A=&EO;E]U<&QO861?<V-O=6YT)R`]/B`G4F5T<FEE=FEN9R!I
M;F9O<FUA=&EO;B!O;B!T:&4@:&]S="`E,2!I<R!I;B!P<F]C97-S)RP*"2=M
M:6=R871I;VY?=7!L;V%D7W-C;W5N=%]O;B<@/3X@)U)E=')I979I;F<@:6YF
M;W)M871I;VX@;VX@=&AE(&AO<W0@)3$G+`H))VUI9W)A=&EO;E]S;W5R8V5?
M<&QA=&9O<FTG(#T^("=-:6=R871I;VX@<&QA=&9O<FTG+`H))VUI9W)A=&EO
M;E]P;&%T9F]R;5]D971E8U]F86EL)R`]/B`G075T;VUA=&EC(&1E=&5C=&EO
M;B!O9B!H;W-T:6YG('!L871F;W)M(&9A:6QE9"X@4&QE87-E('-E;&5C="!P
M;&%T9F]R;2!M86YU86QL>2!F<F]M('1H92!C;VUB;R!B;W@@8F5L;W<N)RP*
M"2=M:6=R871I;VY?<V5L96-T7W!L871F;W)M)R`]/B`G+2T@4V5L96-T('!L
M871F;W)M("TM)RP*"2=M:6=R871I;VY?;F]?8VQI96YT)R`]/B`G66]U(&AA
M=F4@;F\@8VQI96YT(&%C8V]U;G1S(&]N('1H92!D97-T:6YA=&EO;B!H;W-T
M('1O(&UI9W)A=&4@9&]M86EN<R!T;R<L"@DG;6EG<F%T:6]N7W1E;7!L871E
M7VQE9V5N9"<@/3X@)T-R96%T:6]N(&]F(&1O;6%I;G,@8GD@=&5M<&QA=&4G
M+`H))VUI9W)A=&EO;E]C;&EE;G1?=&5M<&QA=&4G(#T^("=5<V4@82!T96UP
M;&%T92!F;W(@8W)E871I;F<@8VQI96YT(&%C8V]U;G1S)RP*"2=M:6=R871I
M;VY?9&]M86EN7W1E;7!L871E)R`]/B`G57-E(&$@=&5M<&QA=&4@9F]R(&-R
M96%T:6YG(&1O;6%I;G,G+`H))VUI9W)A=&EO;E]R96%C:&5D7VQI;6ET)R`]
M/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F("4Q
M+B<L"@DG;6EG<F%T:6]N7W)E86-H961?;&EM:71?8VQI96YT)R`]/B`G8VQI
M96YT(&%C8V]U;G1S)RP*"2=M:6=R871I;VY?<F5A8VAE9%]L:6UI=%]D;VUA
M:6XG(#T^("=D;VUA:6YS)RP*"2=M:6=R871I;VY?<V5S<VEO;E]L:7-T)R`]
M/B`G4&QE<VL@36EG<F%T:6]N($UA;F%G97(G+`H))VUI9W)A=&EO;E]C=7)R
M96YT7VUI9W)A=&EO;G-?;&ES="<@/3X@)T-U<G)E;G0@;6EG<F%T:6]N<R<L
M"@DG;6EG<F%T:6]N7V-U<G)E;G1?;6EG<F%T:6]N)R`]/B`G0W5R<F5N="!M
M:6=R871I;VYS)RP*"2=B=%]M:6=R871I;VY?<V5S<VEO;E]A9&0G(#T^("=3
M=&%R="!A(&YE=R!M:6=R871I;VXG+`H))VUI9W)A=&EO;E]S97-S:6]N7VQI
M<W1?7V]B:F5C=',G(#T^("=-:6=R871I;F<@;V)J96-T<R<L"@DG;6EG<F%T
M:6]N7W-E<W-I;VY?;&ES=%]?<W1A<G1?9&%T92<@/3X@)U-T87)T(&1A=&4G
M+`H))VUI9W)A=&EO;E]S97-S:6]N7VQI<W1?7V5L87!S960G(#T^("=%;&%P
M<V5D('1I;64G+`H))VUI9W)A=&EO;E]S97-S:6]N7VQI<W1?7W!R;V=R97-S
M)R`]/B`G4')O9W)E<W,G+`H))VUI9W)A=&EO;E]S97-S:6]N7VQI<W1?7VYO
M=%]S96QE8W1E9"<@/3X@)TYO="!Y970@<V5L96-T960G+`H))VUI9W)A=&EO
M;E]S=&%T95]D97-C7V9A:6QE9"<@/3X@)T9A:6QE9"!M:6=R871I;VXG+`H)
M)VUI9W)A=&EO;E]S=&%T95]D97-C7V%W86ET:6YG7W-T87)T)R`]/B`G5V%I
M=&EN9R!F;W(@82!S=&%R="<L"@DG;6EG<F%T:6]N7W-T871E7V1E<V-?87=A
M:71I;F=?86=E;G1?<&%R86TG(#T^("=0;&5A<V4@<W!E8VEF>2!M:6=R871I
M;VX@<&%R86UE=&5R<R<L"@DG;6EG<F%T:6]N7W-T871E7V1E<V-?<V5L96-T
M7V]B:F5C="<@/3X@)U-E;&5C="!T:&4@8G5S:6YE<W,@;V)J96-T<R!T;R!M
M:6=R871E)RP*"2=M:6=R871I;VY?<W1A=&5?9&5S8U]S96QE8W1?8VQI96YT
M)R`]/B`G4V5L96-T('1H92!C;&EE;G0@9F]R(&UI9W)A=&EO;B<L"@DG;6EG
M<F%T:6]N7W-T871E7V1E<V-?:7!?;6%P)R`]/B`G25`@;6%P<&EN9R<L"@DG
M;6EG<F%T:6]N7W-T871E7V1E<V-?9&)?<V5R=F5R7VUA<"<@/3X@)T1"('-E
M<G9E<B!M87!P:6YG)RP*"2=M:6=R871I;VY?<W1A=&5?9&5S8U]A<&E?;6EG
M<F%T:6]N)R`]/B`G36EG<F%T:6]N(&UA9&4@8GD@;65A;G,@;V8@4E!#)RP*
M"2=M:6=R871I;VY?<W1A=&5?9&5S8U]D=6UP:6YG)R`]/B`G4F5T<FEE=FEN
M9R!D871A(&9R;VT@<F5M;W1E(&AO<W0G+`H))VUI9W)A=&EO;E]S97-S:6]N
M7V9A:6QE9"<@/3X@)TUI9W)A=&EO;B!F<F]M(&AO<W0@)3$@9F%I;&5D)RP*
M"2=M:6=R871I;VY?8V]M<&QE=&5D)R`]/B`G5&AE(&UI9W)A=&EO;B!H87,@
M8F5E;B!C;VUP;&5T960N)RP*"2=M:6=R871I;VY?;F]?861M:6Y?9&]M7W1E
M;7!L871E)R`]/B`G5&AE<F4@87)E(&YO(&%D;6EN:7-T<F%T;W)<)W,@9&]M
M86EN('1E;7!L871E<R<L"@DG;6EG<F%T:6]N7V5R<F]R7V9I;&4G(#T^("=&
M:6QE)RP*"2=M:6=R871I;VY?97)R;W)?;&EN92<@/3X@)TQI;F4G+`H))VUI
M9W)A=&EO;E]E<G)O<E]C;VYT97AT)R`]/B`G0V]N=&5X="<L"@DG;6EG<F%T
M:6]N7V5R<F]R7W1E>'0G(#T^("=497AT)RP*"2=M:6=R871I;VY?97)R;W)?
M='EP92<@/3X@)U1Y<&4G+`H))VUI9W)A=&EO;E]E<G)O<E]N86UE)R`]/B`G
M3F%M92<L"@DG;6EG<F%T:6]N7VYO7VEP7V%V86EL86)L92<@/3X@)TYO($E0
M(&%D9')E<W-E<R!A=F%I;&%B;&4G+`H))VUI9W)A=&EO;E]A;FYO;E]F='!?
M;&]S="<@/3X@)T%F=&5R($E0(&UA<'!I;F<L('EO=2!W:6QL(&YO="!B92!A
M8FQE('1O('5S92!A;F]N>6UO=7,@1E10('-E<G9I8V4@(&]N("(E,2(N)RP*
M"2=P8E]M:6=R871I;VY?9G)O;2<@/3X@)TUI9W)A=&EO;B!F<F]M("4Q)RP*
M"2=M:6=R871I;VY?8VUD7VEG;F]R960G(#T^("=4:&4@8V]M;6%N9"`B)3$B
M('=A<R!I9VYO<F5D+B<L"@DG;6EG<F%T:6]N7V1B7W-E<G9E<E]N;W1?9FEN
M9"<@/3X@)U1H92!D871A8F%S92!W:6QL(&YO="!B92!R97-T;W)E9#H@=&AE
M(&%P<')O<')I871E(&1A=&%B87-E('-E<G9E<B!F;W(@=&AI<R!D871A8F%S
M92!I<R!N;W0@:6YS=&%L;&5D+B<L"@DG;6EG<F%T:6]N7VYO=%]U;F%B;&5?
M;6EG<F%T95]S;VUE)R`]/B`G36EG<F%T:6]N(&-A;FYO="!C;VYT:6YU93H@
M96ET:&5R('1H92!S96QE8W1E9"!O8FIE8W1S(&%R92!A;')E861Y(&UI9W)A
M=&5D(&]R('1H97D@8V%N;F]T(&)E(&UI9W)A=&5D(&)E8V%U<V4@9&]M86EN
M(&YA;64@;W(@=7-E<B!A8V-O=6YT(&YA;64@:7,@:6YV86QI9"XG+`HI.PHO
M+W)E<75I<F5?;VYC92@G;&]C86QE<R]E;BU54R]U:5]C87!T:6]N<RYI;F,G
M*3L*/SX*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O861M:6XO<V)I;B\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W,S0`,#$V,#$V`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]A9&UI;B]S8FEN+V9I;&5M;F<`````````````````````````````
M```````````````````````````````````````````````````````````P
M,#`P-34P`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$W-C0V,``Q,#4Q-30S,S<S
M-``P,3<S-S0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````_NWZS@```!(``````````@````T```8D````A0````$````X7U]0
M04=%6D523P```````````````!`````````````````````````````````$
M`````0```8Q?7U1%6%0````````````````0````P`````````#```````<`
M```%````!0````!?7W1E>'0`````````````7U]415A4````````````````
M&6```(<````)8`````(``````````(``!````````````%]?<&EC<WEM8F]L
M7W-T=6)?7U1%6%0```````````````"@8````````)!@`````@``````````
M@```"``````````D7U]S>6UB;VQ?<W1U8@```%]?5$585```````````````
M`*!@````````D&`````"``````````"````(`````````!1?7W!I8W-Y;6)O
M;'-T=6(Q7U]415A4````````````````H&````U```"08`````4`````````
M`(``!`@`````````(%]?8W-T<FEN9P````````!?7U1%6%0`````````````
M``"MH```(F```)V@`````@```````````````@```````````````0```A1?
M7T1!5$$```````````````#0````0````,`````0``````<````#````!P``
M``!?7V1A=&$`````````````7U]$051!````````````````T`````#,``#`
M``````(``````````````````````````%]?;FQ?<WEM8F]L7W!T<@!?7T1!
M5$$```````````````#0S````"P``,#,`````@``````````````!@```&H`
M````7U]L85]S>6UB;VQ?<'1R`%]?1$%400```````````````-#X```!J```
MP/@````"```````````````'````=0````!?7V1Y;&0`````````````7U]$
M051!````````````````TJ`````<``#"H`````(`````````````````````
M`````%]?8V]N<W0```````````!?7T1!5$$```````````````#2O````%``
M`,*\`````@``````````````````````````7U]B<W,``````````````%]?
M1$%400```````````````-,,```P*0`````````"```````````````!````
M``````!?7V-O;6UO;@``````````7U]$051!```````````````!`T`````\
M``````````0```````````````$```````````````$````X7U],24Y+141)
M5``````````!$````#````#0````+3`````'`````0`````````$````#@``
M`!P````,+W5S<B]L:6(O9'EL9`````````P````T````&$2B1Q(`!0````4`
M`"]U<W(O;&EB+VQI8FEC;VYV+C(N9'EL:6(````````,````,````!A$HD<2
M``$"`@`!```O=7-R+VQI8B]L:6)Z+C$N9'EL:6(````````,````.````!A$
MHD<2```)!P``"0<O=7-R+VQI8B]L:6)C<GEP=&\N,"XY+C<N9'EL:6(`````
M``P````T````&$2B1Q(`6`````$``"]U<W(O;&EB+VQI8E-Y<W1E;2Y"+F1Y
M;&EB```````"````&```T`````&\``#J#```$R0````+````4`````````"R
M````L@```)H```%,````<```````````````````````````````````YI``
M``#?`````````````````````````!8````0``#DT````'`````%````L```
M``$````H```98```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````?#H+>#@A__Q4(0`T.````)`!``"4(?_`
M@'H``#B:``0[8P`!5WL0.GRDVA0]8```86L9H'UI`Z9.@`0A?^``"'P(`J:_
M@?_PD`$`")0A_Z!"GP`%?^@"IGQ\&WA\G2-X?+XK>$@`!2$\7P`!DX*V3#Q?
M``&3HK90/%\``9/"ME0\7P`!@$*W&(&"```OC```09X`#'V)`Z9.@`0A/%\`
M`8!"MR"!@@``+XP``$&>``Q]B0.F3H`$(4@`AFD\7P`!@8*V7(`,```O@```
M0;X`#'V)`Z9.@`0A2``!Y4@``NT\?P`!.&.3\#B!`#A(``3Q@&$`."^#``!!
MG@`(2`"&13@````\7P`!@$*W')`"``"!70``+XH``$"^`(A(``!(?$L3>'TB
M2W@O@``O0+X`"'UH6WB(`@``.2(``7P`!W5`@O_@+X@``$&>`!0X"``!/%\`
M`9`"MEA(```,/%\``9%"MEB`'@``+X```$"^``Q_QO-X2```%'_&\WB$!@`$
M+X```$">__A_@^-X?Z3K>'_%\W@XQ@`$2``'M4@`A66("@``?``'=4&B_[0X
M2@`!?4M3>#D```!+__]P?`@"ID*?``5]B`*F/8P``7P(`Z8YC(4\?8D#IDZ`
M!"!\"`*F0I\`!7V(`J8]C```?`@#ICF,!VA]B0.F3H`$('P(`J9"GP`%?8@"
MICV,``%\"`.F.8R%/'V)`Z9.@`0@?`@"ID*?``5]B`*F/8P``'P(`Z8YC`.X
M?8D#IDZ`!"!\"`*F0I\`!7V(`J8]C```?`@#ICF,`81]B0.F3H`$('P(`J9"
MGP`%?8@"ICV,``!\"`.F.8P`6'V)`Z9.@`0@?`@"ID*?``5]B`*F/8P``7P(
M`Z8YC(2<?8D#IDZ`!"!\"`*F0I\`!7V(`J8]C```?`@#ICF,`N!]B0.F3H`$
M('P(`J:3X?_\D`$`")0A_Z!"GP`%?^@"ICQ_``$X8Y&,.($`.$@``OV!@0`X
M?8D#IDZ`!"$X(0!@@`$`"'P(`Z:#X?_\3H``('P(`J9"GP`%?8@"ICV,``!\
M"`.F.8P"T'V)`Z9.@`0@B`,``'P`!W5-@@`@?&(;>"^``"]!G@`,.$(``4@`
M``PX8@`!?&(;>(@"``!\``=U0(+_X$Z``""(!```?`('=4"B`$`X8``!3H``
M(#DC``&(`P`!?``'='^`$`!`G@`X?61;>'TC2W@Y9``!B`0``7P"!W5`@O_8
M.&```4Z``""(`P``?``'='^`$`!`O@`02___V#A@``!.@``@.&```$Z``"!\
M"`*FOV'_[)`!``B4(?^`0I\`!7_H`J8\?P`!.&.0L#B!`#A(``'Q/'\``3AC
MD,0X@0`\2``!X3Q_``$X8Y#<.($`0$@``=$\?P`!.&.0]#B!`$1(``'!/'\`
M`3ACD10X@0!(2``!L8&!`#@OC```09X`V(`!`#PO@```09X`S(`!`$`O@```
M09X`P(`!`$0O@```09X`M(`!`$@O@```09X`J'V)`Z9.@`0A?'T;>4&B`)@[
MP```/Y\``3]_``%_P_-X@8$`/'V)`Z9.@`0A2__^C3B<D3!+__Z]+X,``$&^
M`%Q_P_-X@8$`0'V)`Z9.@`0A+X,``$&>`$0XFY$X.*``!(&!`$1]B0.F3H`$
M(2^#``!!G@`H@8$`2'V)`Z9.@`0A+`,``$&B`!1\;!MX?&D#IDZ`!"%(```0
M.]X``7^>Z`!`GO]\."$`@(`!``A\"`.FNV'_[$Z``"!\"`*F0I\`!7V(`J8]
MC```?`@#ICF,_C!]B0.F3H`$('P(`J9"GP`%?8@"ICV,``!\"`.F.8S]V'V)
M`Z9.@`0@?`@"ID*?``5]B`*F/8P``'P(`Z8YC`!P?8D#IDZ`!"`]8``!@6O2
MH"R+``!,Y@`@.*``3CR```!@A*Z`.&```C@```1$```"8````#A@`#LX```!
M1````G_@``A_X``(/8```8`,TJ!\"0.F/8```&&,$`!.@`0@/6```8%KTJ1]
M:0.F3H`$('P(`J:_H?_TD`$`")0A_Z!\/@MXD'X`>)">`'PX8``!.(``*$@`
M@C%\8!MXD!X`0(!>`$"`'@!XD`(`!(!>`$"`'@!\D`(`"(!>`$`X```HD`(`
M`(.^`$`X8`$M2`"!V9!]`!`X8`$M@)X`0$@`@:F`(0``@`$`"'P(`Z:[H?_T
M3H``('P(`J9"GP`%?8@"ICV,``%\"`.F.8R!B'V)`Z9.@`0@?`@"ID*?``5]
MB`*F/8P``7P(`Z8YC(&(?8D#IDZ`!"!\"`*F0I\`!7V(`J8]C``!?`@#ICF,
M@8A]B0.F3H`$('P(`J:_P?_XD`$`")0A_Z!\/@MXD'X`>)">`'PX````D!X`
M2#A@`2U(`($ID'X`0#@>`$"0'@!$@%X`1(`"```O@```0)X`"$@``'B`7@!$
M@$(``(!"``2`'@!X?X(``$">`$R`7@!$@$(``(!"``B`'@!\?X(``$">`#2`
M7@!$@`(``)`>`$B!/@!$@%X`2(`"`!"0"0``@%X`2(`"```O@``H09X`'$@`
M@&F`7@!$@$(``#@"`!"0'@!$2___?#A@`2V`G@!`2`"`:8`>`$@O@```09X`
M-(!>`$B``@`,+X```$&>`!R`7@!(@`(`#(!^`$A\#`-X?8D#IDZ`!"&`?@!(
M2`!_[8`A``"``0`(?`@#IKO!__A.@``@?`@"ID*?``5]B`*F/8P``'P(`Z8Y
MC'_,?8D#IDZ`!"!\"`*F0I\`!7V(`J8]C```?`@#ICF,?^Q]B0.F3H`$('P(
M`J9"GP`%?8@"ICV,``!\"`.F.8Q_K'V)`Z9.@`0@?`@"ID*?``5]B`*F/8P`
M`'P(`Z8YC'_,?8D#IDZ`!"!\"`*FO\'_^)`!``B4(?^@?#X+>$*?``5_Z`*F
M2`!_&3Q?``&`0J[T@`(`")`>`$"`'@!`+X```$&>`!R`7@!`H`(`!%0`!#XK
M@``"0)T`"$@``!P\7P`!@&*N-$@`?KD\7P`!@&*N,$@`?HV`(0``@`$`"'P(
M`Z:[P?_X3H``('P(`J9"GP`%?8@"ICV,``!\"`.F.8Q^;'V)`Z9.@`0@?`@"
MID*?``5]B`*F/8P``'P(`Z8YC'YL?8D#IDZ`!"!\"`*F0I\`!7V(`J8]C```
M?`@#ICF,?FQ]B0.F3H`$('P(`J:^X?_<D`$`")0A^X!"GP`%?^@"IGQZ&WA\
MG"-X?+<K>#M@```[````.R```(`$```\7P`!@$*N))`"``!(``\52`""<7Q]
M&W@\?P`!.&.,$#B```!(`"$1?YT8`$&>`"Q(`()1+X,``$&^`"`X8``!.(``
M`3R_``$XI8P8/-\``3C&C!!(``ME2`"""2^#``!`O@`02`"!W3A@``!(`(&U
M+YH``D&]`!PX8``!.(```3R_``$XI8Q@?T;3>$@`"RV#O``$@]P`"#Q_``$X
M8XR@?Z3K>#B@``5(`(%9+X,``$">`$`OF@`$0)T`(#Q_``$X8XRH?\3S>#B@
M``I(`($U+X,``$&>`#`X8``!.(```3R_``$XI8RT2``*T4@``!A(`(%Q+X,`
M`$"^``Q_H^MX2``PZ7_#\W@\GP`!.(2,T#B@``-(`(#M+X,``$">`!`_?P`!
M.WN,U$@``VA_P_-X/)\``3B$C-PXH``$2`"`Q2^#``!`G@`0/W\``3M[C.!(
M``-`?\/S>#R?``$XA(SL.*```T@`@)TO@P``0)X`$#]_``$[>XSP2``#&'_#
M\W@\GP`!.(2,^#B@``9(`(!U+X,``$">`!`_?P`!.WN-`$@``O!_P_-X/)\`
M`3B$C0PXH``#2`"`32^#``!`G@`0/W\``3M[C1!(``+(?\/S>#R?``$XA(T8
M.*``!D@`@"4O@P``0)X`$#]_``$[>XT@2``"H'_#\W@\GP`!.(2-,#B@``-(
M`'_]+X,``$">`!`_?P`!.WN--$@``GA_P_-X/)\``3B$C3PXH``&2`!_U2^#
M``!`G@`0/W\``3M[C41(``)0?\/S>#R?``$XA(U0.*``!D@`?ZTO@P``0)X`
M$#]_``$[>XU82``"*'_#\W@\GP`!.(2-9#B@``5(`'^%+X,``$">`!`_?P`!
M.WN-;$@``@!_P_-X/)\``3B$C7PXH``%2`!_72^#``!`G@!`+YH`!$"=`#B`
M?``4/)\``3B$C80XH``,2`!_.2^#``!`G@`(.R```8!\``R`G``0?R7+>$@`
M`OU(``&$?\/S>#R?``$XA(V0.*``#$@`?P5\8QMY0((`-"^:``1`O@`L/%\`
M`8!"KB"08@``@'P`#$@`!<E\9!MX/'\``3ACC9Q(`'ZQ2``!.'_#\W@\GP`!
M.(2,J#B@``M(`'ZY+X,``$">`"POF@`$0)T`)(!\``R`G``0+YH`!D"^``B#
M'``4?P7#>$@`!Q%(``#X?\/S>#R?``$XA(V@.*``"4@`?G4O@P``0)X`3"^:
M``1`O@!$@]P`#'_#\W@X@0!`2`!^%7Q]&WA(`"(Q+X,``$&>`!@X8``!.(``
M`3R_``$XI8VL2```N'^CZWA(`'W)2```D'_#\W@\GP`!.(2-U#B@``5(`'X1
M+X,``$">`(`OF@`%0+X`>(!\``P\GP`!.(2-A#B@``Q(`'WM+X,``$">``@[
M(``!@]P`$'_#\WA_),MX2``9E7R%(WA\9!MX+X3__T">`"`OA?__0+X`&#A@
M``$X@``!/+\``3BEC=Q(```L/'\``3ACC?Q(`'UY.&```$@`"C%(```<.&``
M`3B```$\OP`!.*6.!'_&\WA(``<M+YH``D"=`"`X7``(.!K__GP)`Z:``@``
MD`+_^#A"``1"`/_T5T(0.GQ"XA0X````D`+_^$@`?+U\?AMY0*(`2#A@``$X
M@``"2`!\B4@`?&4[H___+X,``T"]`!Q_H^MX2`!\,7^@ZW@[O?__+X```T&=
M_^Q_8]MX?X3C>'[ENWA(`'OQ?\/S>#B!!$`XH``"2`![P2^#__]`O@`,.&``
M`4@`"7&``01`<`<`?T&"`%@OAP!_09X`($&B`!PX8``!.(```#R_``$XI8XP
M?V;;>$@`!EF`X01`5.`&?B^``']`O@!(.&```3B````\OP`!.*6.;']FVWA\
MYT9P2``&+4@``"B``01`5`+"/T&B`!PX8``!.(```#R_``$XI8ZH?V;;>$@`
M!@4X8``*2`![!3A@``!(``C=.&```(`!!(@X(02`?`@#IKKA_]Q.@``@?`@"
MIK]A_^R0`0`(E"'_0$*?``5_Z`*F?'P;>'R=(WA\NRMX/%\``8/"J`PX````
MD!X``#Q?``&`0J@(D`(``#R?``$XA(BX.*``!D@`>]4O@P``0)X`$#@```&0
M'@``2```>'^#XW@\GP`!.(2(P#B@``5(`'NM+X,``$">``PX```!2```,'^#
MXW@\GP`!.(2(R#B@``5(`'N)+X,``$">`"0X```!/%\``8!"J`R0`@``/%\`
M`8!"J`B0`@``2```&#A@``$X@``!/+\``3BEB-!(``4%?Z/K>#B!`$!(`'GA
M+X/__T"^`"A(`'FU@&,``$@`>8U\9AMX.&```3B```$\OP`!.*6(]$@`!,V@
M`0!(5``$)B^`0`!`O@`4?Z/K>']DVWA(```]2```$'^CZWA_9-MX2``"`2^#
M``!!O@`,.&```4@`!WDX8```@`$`R#@A`,!\"`.FNV'_[$Z``"!\"`*FOR'_
MY)`!``B4(?]`0I\`!7_H`J9\?AMX?)LC>$@`>-U\?!MY0*(`*$@`>1&`8P``
M2`!XZ7QF&W@X8``!.(```3R_``$XI8>D2``$*7_#\WA(`'B).T```&-:H``\
M7P`!@R*FI$@``0P[O@`(?Z/K>#B!`$!(`'CE+X/__T"^`$Q_H^MX.($`0$@`
M>!$O@P``0)X`%*`!`$A4``0F?X#0`$&>`"A(`'B5@&,``$@`>&U\9AMX.&``
M`3B```$\OP`!.*6'D$@``ZV@`0!(5``$)B^`0`!`G@"0@!D``"^```!!G@"0
M.)X`"("A`&`OFP``09X`((`!`'Q4"4W^@$$`>%1"2"Q])A-X5`=(+$@```R`
MP0!P@.$`=#Q_``$X8X>X2`!Y>8!A`$Q(`!MA?'T;>(!A`%!(`!O=?&4;>#Q_
M``$X8X?(?Z3K>$@`>5&@@0!(/'\``3ACA]!4A`7^2`!Y/4@``!`X?@`(?V3;
M>$@``&5_@^-X2`!W17Q^&WE`@O[L?X/C>$@`=O4X8```@`$`R#@A`,!\"`.F
MNR'_Y$Z``"!\"`*FD`$`")0A_U`X@0!`2`!WJ2!C__\@`P``?&`9%(`!`+@X
M(0"P?`@#IDZ``"!\"`*FOX'_\)`!``B4(>]00I\`!7_H`J9\?1MX?)PC>#_?
M``$[WH8$?\/S>$@`=ET@HQ``.&$`0'^DZWA(`'8M.Z$00#AA`$!_I.MX2`!W
M/2^#__]`O@!P.&$`0'^DZWA(`'9I+X,``$">`#B@`1!(5``$)CA```!@0J``
M?X`0`$"^`"!_P_-X2`!V`7QE&W@X80!`?\3S>$@`=;%(```H2`!VR8!C``!(
M`':A?&8;>#A@``$X@``!/+\``3BEA;Q(``'A/%\``8!"I-2``@``+X```$&>
M`(`OG```09X`((`!$'Q4"4W^@$$0>%1"2"Q])A-X5`=(+$@```R`P1!P@.$0
M=#Q_``$X8X7D.($`0("A$&!(`'>U@&$03$@`&9U\?1MX@&$04$@`&AE\91MX
M/'\``3ACA?1_I.MX2`!WC:"!$$@\?P`!.&.%_%2$!?Y(`'=Y.&```(`!$+@X
M(1"P?`@#IKN!__!.@``@?`@"IK^!__"0`0`(E"'OL$*?``5_Z`*F?'P;>'R>
M(WA\O2MX/%\``3A"A*R``@``@2(`!(%B``B!0@`,D`$`0)$A`$2180!(D4$`
M3(`"`!"!(@`4@6(`&*!"`!R0`0!0D2$`5)%A`%BP00!<.&$`7CB````XH`_B
M2`!T17^GZWE`H@`,//\``3CGA,PX80!`.(`0`#R_``$XI83<?\;S>$@`<_TX
M80!`2`!SU2^#__]`O@`<.&```#B```$\OP`!.*6$[$@``'%(```X2`!UT7^#
MXW@X@0!`2``,_2^#``!!O@`H.&```#B```$\OP`!.*6%$'^&XW@XX0!`2```
M.3A@__](```<.&$`0#B``:1(`'--.&$`0$@`=@4X8```@`$06#@A$%!\"`.F
MNX'_\$Z``"!\"`*FOL'_V)`!``B4(?^00I\`!7_H`J9\=QMX?)8C>)#!`)20
MX0"8D0$`G)$A`*"100"D?+@K>$@`=)&#0P``.Z`0`#A@$`!(`'>!?'X;>4"B
M`!P\?P`!.&.$`'[DNWA^Q;-X2``!24@``3`[(0"4?\/S>'^DZWA_!<-X?R;+
M>$@`=RE\?!MX?X/H`$&\`#0[8P`!?\/S>']DVWA(`';M?&`;>4&"`!Q_?=MX
M?!X#>']DVWA_!<-X?R;+>$@`=NU(`'0)DT,``$@`=`&``P``+X```$&>`*0[
M0```/S\``3LYA"A_?.A108(`2$@`<]U\?1MX2`!SU8!C``!(`'.M?&<;>'Q^
MXA1_9-MX?R7+>(#=``!(`')5.````7^#V`!`G``(.````'P:`WE!@@!,?)KB
M%'_#\W@XA``!2`!V37QC&WE!@@`T?'X;>$@`<WU\?1MX2`!S=8!C``!(`'--
M?&<;>'Q^XA1_1--X?R7+>(#=``!(`''U?\/S>'[DNWA^Q;-X2```*2^>``!!
MG@`,?\/S>$@`</6``0!X."$`<'P(`Z:ZP?_83H``('P(`J:_8?_LD`$`")0A
M_Z!"GP`%?^@"IGQ]&WA\FR-X.X```#Q?``&`8I_$+X,``$&^``Q(`'6)?'P;
M>"^<``!!G@`@/'\``8!CH)`X8P"P/)\``3B$@I1_A>-X2`!U07^CZW@\7P`!
M@\*@D#B>`+!(`'4-?Z/K>$@`<<5\?1H4B`/__WP`!W0O@``*09X`$#A@``HX
MG@"P2`!TQ3Q?``&#PJ"0.'X`L$@`=)4OG```09X`&#A^`%@\GP`!.(2"E'^%
MXWA(`'39?Z/K>#Q?``&#PJ"0.)X`6$@`=*5_H^MX2`!Q77Q]&A2(`___?``'
M="^```I!G@`0.&``"CB>`%A(`'1=/'\``8!CH)`X8P!82`!T+2^;``!!O@`,
M?V/;>$@``!TX8```@`$`:#@A`&!\"`.FNV'_[$Z``"!\"`*FD`$`")0A_[!(
M`&[5?`@"IK^!__"0`0`(E"'_L$*?``5_Z`*F?'P;>'R=(WA\@R-X2``JF7Q^
M&WE!@@`4B!X``'P`!W0O@```0)X`'#A@``$X@``!/+\``3BE@5!_INMX2__\
MM9/<``"``0!8."$`4'P(`Z:[@?_P3H``('P(`J:_@?_PD`$`")0A_[!"GP`%
M?^@"ICQ?``&`0IX,+X(``$"^"0`\?P`!.&.!$$@`*AU\?1MY08(`%(@=``!\
M``=T+X```$">`!@X8``!.(```3R_``$XI8$@2__\/3Q?``&3HIX,/'\``3AC
M@41(`"G=?'T;>4&"`!2('0``?``'="^```!`G@`8.&```3B```$\OP`!.*6!
M5$O_^_T\7P`!DZ*>%#Q_``$X8X%X2``IG7Q]&WE!@@`4B!T``'P`!W0O@```
M0)X`&#A@``$X@``!/+\``3BE@8A+__N]/%\``9.BGA@\?P`!.&.!K$@`*5U\
M?1MY08(`%(@=``!\``=T+X```$">`!@X8``!.(```3R_``$XI8&\2__[?3Q?
M``&3HIX</'\``3AC@>!(`"D=?'T;>4&"`!2('0``?``'="^```!`G@`8.&``
M`3B```$\OP`!.*6![$O_^ST\7P`!DZ*>(#Q_``$X8X(,2``HW7Q]&WE!@@`4
MB!T``'P`!W0O@```0)X`&#A@``$X@``!/+\``3BE@AQ+__K]/%\``9.BGB0\
M?P`!.&."0$@`*)U\?1MY08(`%(@=``!\``=T+X```$">`!@X8``!.(```3R_
M``$XI8)42__ZO3Q?``&3HIXH/'\``3AC@GQ(`"A=?'T;>4&"`!2('0``?``'
M="^```!`G@`8.&```3B```$\OP`!.*6"B$O_^GT\7P`!DZ*>+#Q_``$X8X*H
M2``H'7Q]&WE!@@`4B!T``'P`!W0O@```0)X`&#A@``$X@``!/+\``3BE@KA+
M__H]/%\``9.BGC`\?P`!.&.>-#R?``$XA(+<2__]&3Q_``$X8X+H2``GR7Q]
M&WE!@@`4B!T``'P`!W0O@```0)X`&#A@``$X@``!/+\``3BE@OQ+__GI/%\`
M`9.BGC@\?P`!.&.#)$@`)XE\?1MY08(`%(@=``!\``=T+X```$">`!@X8``!
M.(```3R_``$XI8,P2__YJ3Q?``&3HIY`/'\``3AC@U!(`"=)?'T;>4&"`!2(
M'0``?``'="^```!`G@`8.&```3B```$\OP`!.*6#7$O_^6D\7P`!DZ*>1#Q_
M``$X8X-\2``G"7Q]&WE!@@`4B!T``'P`!W0O@```0)X`&#A@``$X@``!/+\`
M`3BE@XA+__DI/%\``9.BGD@\?P`!.&.#J$@`)LE\?1MY08(`%(@=``!\``=T
M+X```$">`!@X8``!.(```3R_``$XI8.T2__XZ3Q?``&3HIY,/'\``3AC@]1(
M`":)?'T;>4&"`!2('0``?``'="^```!`G@`8.&```3B```$\OP`!.*6#X$O_
M^*D\7P`!DZ*>4#Q_``$X8X0`2``F27Q]&WE!@@`4B!T``'P`!W0O@```0)X`
M&#A@``$X@``!/+\``3BEA!!+__AI/%\``9.BGE0\?P`!.&.$-$@`)@E\?1MY
M08(`%(@=``!\``=T+X```$">`!@X8``!.(```3R_``$XI81$2__X*3Q?``&3
MHIY8/'\``3ACA&A(`"7)?'T;>4&"`!2('0``?``'="^```!`G@`8.&```3B`
M``$\OP`!.*6$>$O_]^D\7P`!DZ*>7#Q_``$X8X2<2``EB7Q]&WE!@@`4B!T`
M`'P`!W0O@```0)X`&#A@``$X@``!/+\``3BEA*Q+__>I/%\``9.BGF`\?P`!
M.&.$T$@`)4E\?1MY08(`%(@=``!\``=T+X```$">`!@X8``!.(```3R_``$X
MI8382__W:3Q?``&3HIX\/'\``3ACA/1(`"4)?'T;>4&"`!2('0``?``'="^`
M``!`G@`8.&```3B```$\OP`!.*6%!$O_]RD\7P`!DZ*>9#Q_``$X8X4H2``D
MR7Q]&WE!@@`4B!T``'P`!W0O@```0)X`&#A@``$X@``!/+\``3BEA3A+__;I
M/%\``9.BGF@\?P`!.&.%7$@`)(E\?1MY08(`%(@=``!\``=T+X```$">`!@X
M8``!.(```3R_``$XI85H2__VJ3Q?``&3HIYL/[\``3N]GG`\?P`!.&.%B$@`
M(]F0?0``/[\``3N]GG0X8``!.(`0`$@`:7V0?0``/Y\``3N<G@R`?```2`!J
M27QE&WB`?0``@)P``$@`:AF`?0``/)\``3B$A9Q(`&YI/[\``3N]GG@X8``!
M.(`0`$@`:360?0``@'P``$@`:@E\91MX@'T``("<``!(`&G9@'T``#R?``$X
MA(6T2`!N*3^_``$[O9Y\.&```3B`$`!(`&CUD'T``(!\``!(`&G)?&4;>(!]
M``"`G```2`!IF8!]```\GP`!.(2%R$@`;>D_OP`!.[V>@#A@``$X@!``2`!H
MM9!]``"`?```2`!IB7QE&WB`?0``@)P``$@`:5F`?0``/)\``3B$A=Q(`&VI
M/[\``3N]GH0X8``!.(`0`$@`:'60?0``@'P``$@`:4E\91MX@'T``("<``!(
M`&D9@'T``#R?``$XA(7P2`!M:3^_``$[O9Z(.&```3B`$`!(`&@UD'T``(!\
M``!(`&D)?&4;>(!]``"`G```2`!HV8!]```\GP`!.(2&"$@`;2D_OP`!.[V>
MC#A@``$X@!``2`!G]9!]``"`?```2`!HR7QE&WB`?0``@)P``$@`:)F`?0``
M/)\``3B$AB!(`&SI/[\``3N]GI`X8``!.(`0`$@`9[60?0``@'P``$@`:(E\
M91MX@'T``("<``!(`&A9@'T``#R?``$XA(8T2`!LJ3^_``$[O9Z4.&```3B`
M$`!(`&=UD'T``(!\``!(`&A)?&4;>(!]``"`G```2`!H&8!]```\GP`!.(2&
M3$@`;&D_OP`!.[V>F#A@``$X@!``2`!G-9!]``"`?```2`!H"7QE&WB`?0``
M@)P``$@`9]F`?0``/)\``3B$AF!(`&PI/[\``3N]GIPX8``!.(`0`$@`9O60
M?0``@'P``$@`9\E\91MX@'T``("<``!(`&>9@'T``#R?``$XA(9X2`!KZ3Q_
M``$X8X:02`!KO3Q?``&08IZ@@'P``$@`9XTX8P`22`!K97Q]&WB`G```2`!K
M>7^CZW@\GP`!.(2&H$@`:ZD\7P`!DZ*>$(`!`%@X(0!0?`@#IKN!__!.@``@
M?`@"IK\!_^"0`0`(E"'OH$*?``5_Z`*F?'D;>'R:(WA(`&QI.````"^#``!!
MO@+$?T/3>#B```%(`"6!?'@;>4&"`!!(`"1I+X,``$">`"@X8```.(```#R_
M```XI7U\?T;3>$O_\OU_`\-X2``DC4@``DR(&0``?``'="^``"U`G@`DB!D`
M`7P`!W0O@```0+X`%#Q_``&`8Y6<2`!KS4@``!!_(\MX.(```$@`:YU\>QMX
M+X,``$"\`"A(`&=M@&,``$@`9T5\9QMX.&```#B````\OP``.*5]J$@``8B(
M&@``?``'="^``"U`G@`HB!H``7P`!W0O@```0+X`&#Q_``&`8Y6<.&,`6$@`
M:UU(```0?T/3>#B`!@%(`&LM?'P;>"^#``!`O`!82`!F_8!C``!(`&;5?&<;
M>#A@```X@```/+\``#BE?:A(``#`.Z``!'^#XW@X@0!`?\7S>$@`:JE\8QMY
M0((`$$@`9KV3HP``2___X'^#\`!`G@#\?V/;>#B!`$`XH!``2`!JG7Q^&WE!
M@?^\+Y[__T"^`"A(`&:)@&,``$@`9F%\:!MX.&```#B````\OP``.*5]Q$@`
M`-@\?P`!@&.5G#AC`%A(`&J9?YP8`$&>`$A_@^-X2`!FZ2^#``!!O@`X2`!F
M/8!C``!(`&85?&<;>#A@```X@```/+\``#BE?>Q_1M-X2__Q47\#PWA(`",!
M2```F#Q_``&`8Y6<2`!J07^;&`!!G@"4?V/;>$@`9I$O@P``0;X`A$@`9>6`
M8P``2`!EO7QG&W@X8```.(```#R_```XI7WL?R;+>$O_\/E_`\-X2``BJ4@`
M`$A(`&6Q@&,``$@`98E\:!MX.&```#B````\OP``.*5^#'\FRWA_1]-X2__P
MP7\#PWA(`")Q?X/C>$@`9AE_8]MX2`!F$3@```%(```P?P/#>$@`(E$O@P``
M0;X`'#A@```X@```/+\``#BE?C!_1M-X2__P>3@```!\`P-X@`$0:#@A$&!\
M"`.FNP'_X$Z``"!\"`*FOD'_R)`!``B4(>^`0I\`!7_H`J9\=1MX?)@C>'RT
M*WA\TS-X?/([>#B```!(`&D1?'D;>"^#__]`O@`@.&```3B```$\OP``.*5[
M5'ZFJWA_!\-X2__P`7\#PWA(`&/A?'X;>#AC``A(`&>U?'<;>4"B`!@X8``!
M.(```3R_```XI7M\2__OT7[CNWA_!,-X?\7S>$@`8XD\7P``.$)[D($B``!]
M=_(4@`(`!'TW\2Z0"P`$?N.[>$@`8N5\>AMX+X/__T"^`"`X8``!.(```3R_
M```XI7N8?J:K>'\'PWA+_^]U.L$`0$@``%@[@```?YSP0$"<`$Q^V[-X?T/3
M>'R;XA1\O/!02`!G]7Q]&W@O@___0+X`(#A@``$X@``!/+\``#BE>\1^IJMX
M?P?#>$O_[R5_W?!0?YSP0$&<_\!_(\MX.($`0#B@$`!(`&?1?'X;>4""_Y@O
MGO__0+X`(#A@``$X@``!/+\``#BE>_!^IJMX?P?#>$O_[MU_0]-X?H2C>'YE
MFWA(`&=5+X/__T"^`"`X8``!.(```3R_```XI7P8?J:K>'\'PWA+_^ZI?T/3
M>'Y$DWA(`&<%+X/__T"^`"`X8``!.(```3R_```XI7Q$?J:K>'\'PWA+_^YY
M?T/3>$@`8]DO@___0+X`(#A@``$X@``!/+\``#BE?'!^IJMX?P?#>$O_[DU_
M(\MX2`!CK7[CNWA_!,-X2`!F@2^#__]`O@`@.&```3B```$\OP``.*5\G'ZF
MJWA_!\-X2__N%7[CNWA(`&"5@`$0B#@A$(!\"`.FND'_R$Z``"!\"`*FOP'_
MX)`!``B4(?\P?'@;>'R9(W@[8!``.($`0$@`8?TY`/__.2#__R^#``!!G`%`
M+YD``$&>`!"#@0!X@Z$`?$@```R#@0!P@Z$`=*`!`$A4``0F+X!``$&>`$23
M@0"@DZ$`I,@!`*`OF0``09X`(%>I3?Y7@$@L?2(#>%>C2"R000"@D&$`I,@!
M`*#8`0"@@0$`H($A`*1(``#4?V/;>$@`91DY`/__.2#__WQ^&WE!@@"\2```
M('_:\W@[>Q``?\/S>']DVWA(`&2Q?'X;>4&"`%!_P_-X?V3;>$@`9ETO@P``
M09[_U'\#PWA(`&%M+X,``$&<`"1_(\MX2```C7^](!1_G!D4?\/S>$@`84TO
M@P``0+P`('_#\WA(```(?T/3>$@`7U4Y`/__.2#__T@``#Q_P_-X2`!?07^+
MXWA_K.MX+YD``$&>`!Q5B4W^5X!(+'TB`WA5@T@L?$L3>'QL&WA]:%MX?8EC
M>'T#0WA])$MX@`$`V#@A`-!\"`.FNP'_X$Z``"!\"`*F?$``)K]!_^B0`0`(
MD$$`!)0A_T!"GP`%?^@"IGQZ&W@[@```.Z```#Q_```X8WC02`!@O3D@```Y
M0```?'L;>4&"`.0N&@``2```O#O#``B(`P`(?``'="^``"Y`G@`HB!X``7P`
M!W5!H@"<+X``+D"^`!2('@`"?``'="^```!!G@"$?\/S>#B!`$!(`&`!+X,`
M`$&<`'!!D@`0@$$`>(!A`'Q(```,@$$`<(!A`'1_O1@4?YP1%*`!`$A4``0F
M+X!``$"^`$!_P_-X2`!@`2^#``!!G``P?T/3>$O__R%_O2`4?YP9%#Q_```X
M8WC42`!?W7^)XWA_JNMX+X,``$&<`"1_8]MX2`!?I7QC&WE`@O\\?V/;>$@`
M7U5_B>-X?ZKK>'TC2WA]1%-X@`$`R#@A`,"!80`$?`@#IKM!_^A]<($@3H``
M('P(`J:_8?_LD`$`")0A_Z!"GP`%?^@"IGQ[&WA\GB-X?+TK>'S<,WA(`&3=
M?&(;>4"B`"`X@```/+\``#BE=Y1_9MMX2__JV3A@__](```X+YX``$&>``R`
M`@`(D!X``"^=``!!G@`,@`(`#)`=```OG```09X`#(`"`!R0'```.&```(`!
M`&@X(0!@?`@#IKMA_^Q.@``@?`@"II`!``B4(?^@+X0``$&>`!`X@```.*$`
M0$@```PX@0!`.*```#C```!+__\]+X/__T"^``PX````D`$`0(!A`$"``0!H
M."$`8'P(`Z9.@``@?`@"ID*?``5]2`*F?`@#IH@#``!\"0-X+X```$&>`$P\
M2@`!@6*,?'T@!W0Y(```*X``_T&=`!Q4`A`Z?$):%(`"`#1P`@0`08(`"#D@
M``$X````+XD``$&>`!2-(P`!+XD``$">_\0X```!?`,#>$Z``"!\"`*FO\'_
M^)`!``B4(?^P0I\`!7_H`J9\?AMX2`!>:3@```"0`P``?\/S>$@`8UE\8QMY
M0*(`-$@`7DV`8P``2`!>)7QG&W@X8```.(```#R_```XI794?\;S>$O_Z6$X
M8```2```"(!C``B``0!8."$`4'P(`Z:[P?_X3H``('P(`J:_P?_XD`$`")0A
M_[!"GP`%?^@"IGQ^&WA(`%WI.````)`#``!_P_-X2`!BN7_`\W@O@P``0+X`
M,$@`7<F`8P``2`!=H7QG&W@X8```.(```#R_```XI77H?\;S>$O_Z-TX````
M?`,#>(`!`%@X(0!0?`@#IKO!__A.@``@?`@"IK_!__B0`0`(E"'_H$*?``5_
MZ`*F?'X;>$O__G$O@P``09X`)'_#\W@\GP``.(1U?#BA`$!(`&(-@&$`0$O_
M_T%(```,?\/S>$O__K6``0!H."$`8'P(`Z:[P?_X3H``('P(`J:_P?_XD`$`
M")0A_[!"GP`%?^@"IGQ^&WA(`&(E?&,;>4"B`#1(`%SY@&,``$@`7-%\9QMX
M.&```#B````\OP``.*5U''_&\WA+_^@-.&```$@```B`8P`(@`$`6#@A`%!\
M"`.FN\'_^$Z``"!\"`*FO\'_^)`!``B4(?^P0I\`!7_H`J9\?AMX2`!A-7QD
M&WE`H@`D/'\``3ACC$@X@!``/+\``#BE=-!_QO-X2`!;$4@``"@\?P`!.&.,
M2("$```XH`__2`!;63Q?``$X0HQ(.````)@"#_\\?P`!.&.,2(`!`%@X(0!0
M?`@#IKO!__A.@``@?`@"IK_!__B0`0`(E"'_L$*?``5_Z`*F?'X;>$@`8.U\
M9!MY0*(`)#Q_``$X8YO`.(`0`#R_```XI71(?\;S>$@`6HE(```H/'\``3AC
MF\"`A```.*`/_T@`6M$\7P`!.$*;P#@```"8`@__/'\``3ACF\"``0!8."$`
M4'P(`Z:[P?_X3H``('P(`J:_8?_LD`$`")0AST!\?1MX?)XC>#B!`$!(`%KE
M+X,``$">`#B@`0!(5``$)B^`0`!`O@`H?\/S>#B!`$!(`%K!+X,``$">`!2@
M`0!(5``$)B^`0`!!G@`,.&```$@``)`[@2"@?X/C>#B`$`!(`%^Q?Z/K>$@`
M6LD[80"@?V/;>#B`$`!(`%^9?\/S>$@`6K$[H1"@?Z/K>#B`$`!(`%^!?X/C
M>$@`6IE_H^MX2`!:$7Q^&W@[@```?Z/K>']DVWA_Q?-X2`!@.2^#``!`G@`<
M?$'R%(@"`*!\``=T+X``+T"^``@[@``!?X/C>(`!,,@X(3#`?`@#IKMA_^Q.
M@``@.$```'QC&WE!@@`4B`,``'P`!W0O@```0)X`"#A```%\0Q-X3H``('P(
M`J:_H?_TD`$`")0ASU!"GP`%?^@"IGQ^&W@X81"@.(```#B@$`!(`%D-/'\`
M`3ACJ@PX@```.*`0`$@`6/DX82"@.(`0`$@`7JTO@P``0+X`%#B````\OP``
M.*5RF$@``.!_P_-X.($`0$@`6BDO@P``0;X`(#A@```X@```/+\``#BE<KA_
MQO-X2__E(4@``+0[H0"@?Z/K>'_$\W@XH!``2`!8T:`!`$A4``0F+X!``$&>
M`%1_H^MX.(``+T@`7O5\9!MY08(`&#@```"8!```.&$0H#B$``%(```D.Z$`
MH#AA$*!_I.MX.*`0`$@`6(5_H^MX/)\``#B$<APXH!``2`!8<3AA`*!(`%D)
M+X,``$">`!P\?P`!.&.J##B`$`!(`%W1+X,``$">`"`X8```.(```#R_```X
MI7+82__D;3A@``!(``!HB`$0H'P`!W0O@```0;X`2#Q_``$X8ZH,2`!8,2"C
M$``\?P`!.&.J##R?```XA',`2`!7V3Q_``$X8ZH,2`!8#2"C$``\?P`!.&.J
M##B!$*!(`%>Y.&$@H$@`6'$\?P`!.&.J#(`!,+@X(3"P?`@#IKNA__1.@``@
M?`@"IK]A_^R0`0`(E"'O@$*?``5_Z`*F?)LC>#O`)Q!\?1MY08(`4(@=``!\
M`P=T5&``,4""`"A48A`Z/3\``8$IABA\0DH4@`(`-'``!0!\``#05``/_D@`
M`!0X@`4`2`!?T3!#__]\`AD0+X```$">`!@X8``!.(```3R_```XI7%`2__C
M93O>``%_P_-X2`!<P2^#``!`GO_P*Y[__$"=`"`X8```.(```#R_```XI7%4
M2__C-3A@``%(``#$/'\``#AC<61+__EE?'P;>4"B`"`X8``!.(```3R_```X
MI7%L/-\``#C&<61+_^+]DZ$`.#Q?```X0G&`D$$`/).A`$"3@0!$DZ$`2#AA
M`&`X@!``/+\``#BE<9!_INMX?Z?K>'_(\WA_J>MX?VK;>$@`5B$X80!@2`!>
MV7Q]&WE`H@`\/'\``#AC<HA+__GA?'P;>']CVW@X@`'H2`!>E7]CVWA_Q/-X
M?X7C>$@`7F5_8]MX.(`!Z$@`59E_H^MX@`$0B#@A$(!\"`.FNV'_[$Z``"!\
M"`*FOZ'_])`!``B4(>^P0I\`!7_H`J9\G2-X?'X;>4&"`%"('@``?`,'=%1@
M`#%`@@`H5&(0.CT_``&!*824?$)*%(`"`#1P``4`?```T%0`#_Y(```4.(`%
M`$@`7D$P0___?`(9$"^```!`G@`8.&```3B```$\OP``.*5P_$O_X=5_P_-X
M2`!;M3@````O@P``0;X`Y#Q_```X8W$0?\3S>#B@``$XP``!2``FB2^#``!!
MO@`8.&```#B````\OP``.*5Q($O_X8U_P_-X2``#>3AA`$`X@!``/+\``#BE
M<4!_QO-X2`!4U3AA`$!(`%V-.&$`0#B`$``\OP``.*5Q8'_&\WA(`%2U.&$`
M0$@`76U\?AMY0((`7"^=``!!G@!4B!T``'P`!W0O@```0;X`1'^CZW@\7P`!
M@$*$F(""``!+__HY+X,``$&^`"A(`%%E+X,``$&>`!!_H^MX2``C,4@``!!_
MH^MX.(```4@`'*%_P/-X?`,#>(`!$%@X(1!0?`@#IKNA__1.@``@?`@"IK]!
M_^B0`0`(E"'?H$*?``5_Z`*F?'L;>'R>(W@[0``!/%\``#A";^R``@``@2(`
M!(%B``B!0@`,D`$`0)$A`$2180!(D4$`3(`"`!"!(@`4B$(`&)`!`%"1(0!4
MF$$`6#AA`%DX@```.*`/YT@`4]U_8]MX?\3S>$@`67$X````+X,``$&>`A@O
MFP``09X`I(@;``!\`P=T5&``,4""`"A48A`Z/3\``8$I@P1\0DH4@`(`-'``
M!0!\``#05``/_D@``!0X@`4`2`!<03!#__]\`AD0+X```$&>`%@OG@``09X`
M4(@>``!\`P=T5&``,4""`"A48A`Z/3\``8$I@P1\0DH4@`(`-'``!0!\``#0
M5``/_D@``!0X@`4`2`!;[3!#__]\`AD0+X```$">`!@X8``!.(```3R_```X
MI7`(2__?@3NA$$!_H^MX.(`0`#R_```XI7`H?V;;>$@`4LU_H^MX/)\``#B$
M<#Q(`%L=?'X;>4"B`!PX8``!.(```3R_```XI7!`?V;;>$O_WS4X80!`2`!2
M=7Q\&WE`H@`D?\/S>$@`6L4X8``!.(```3R_```XI7!L.,$`0$O_WP4[H1!`
M2```6"^:``!!G@`XB`$00'P`!W0O@``C0+X`)(@!$$%\``=T+X``($&>`#"(
M`1!"?``'="^```I!G@`@.T```'^CZWA(`%*A?&4;>'^#XWA_I.MX2`!743AA
M$$`X@!``?\7S>$@`6B$O@P``0)[_F#NA$$!_H^MX.(`0`#R_```XI7"P?V;;
M>$@`4=U_H^MX2`!:E3NA$$!_H^MX.(`0`#R_```XI7#0?V;;>#CA`$!(`%&U
M?Z/K>$@`6FU_P_-X2`!9Y7^#XWA(`%.=.&$`0$@`694X```!?`,#>(`!(&@X
M(2!@?`@#IKM!_^A.@``@?`@"IK^A__20`0`(E"'_H$*?``5_Z`*F?'X;>$@`
M4[E\8QMY0((`K$@`62TO@___0)X`&#Q_```X8VXP2`!8^3A@``-(``"(/'\`
M`#AC;D`X@``"2`!6H7Q]&W@X8```2`!3%3A@``%(`%,-.&```D@`4P5_H^MX
M.(```$@`4SE_H^MX.(```4@`4RU_H^MX.(```D@`4R%_H^MX2`!2V7_#\WA(
M``.9.&#__SB```](`%A%.&`G$$@`6!TX8/__.(``"4@`6#$X8```2`!823B!
M`$`XH``"2`!272^#__]`O@`H2`!1\8!C``!(`%')?&<;>#A@```X@```/+\`
M`#BE;DQ(```L@`$`0'`'`']!@@!8+X<`?T&>`"1!H@`@.&```#B````\OP``
M.*5N@'_&\WA+_]S92```5(#A`$!4X`9^+X``?T"^`$PX8```.(```#R_```X
MI6[`?\;S>'SG1G!+___0@`$`0%0"PC]!H@`D.&```#B````\OP``.*5O`'_&
M\WA+_]R%.&#__T@```@X8```@`$`:#@A`&!\"`.FNZ'_]$Z``"!\"`*FOZ'_
M])`!``B4(>^P0I\`!7_H`J9\?AMX?)TC>$O_]FTX`/__+X,``$">`%POG0``
M09X`$#R?```XA&UT2```##R?```XA&U\/'\``#AC;81_Q?-X.,```$@`0_5_
MP_-X2__]\2^=``!!G@`0?\/S>$@`".U(```,?\/S>$@`!VU\8!MX?`,#>(`!
M$%@X(1!0?`@#IKNA__1.@``@?`@"IK_!__B0`0`(E"'OL$*?``5_Z`*F?)XC
M>'QC&WE!@@"<B`,``'P#!W148``Q0((`*%1B$#H]/P``@2E^`'Q"2A2``@`T
M<``%`'P``-!4``_^2```%#B`!0!(`%>M,$/__WP"&1`O@```09X`4"^>``!!
MG@!(B!X``'P#!W148``Q0((`(%1B$#H]/P``@2E^`'Q"2A2``@`T5`"O_D@`
M`!0X@`@`2`!783!#__]\`AD0+X```$">`!@X8``!.(```3R_```XI6SP2__:
M]3A@``&``1!8."$04'P(`Z:[P?_X3H``('P(`J:_H?_TD`$`")0A[[!"GP`%
M?^@"IGR=(WA\?AMY08(`G(@>``!\`P=T5&``,4""`"A48A`Z/3\``($I?1A\
M0DH4@`(`-'``!0!\``#05``/_D@``!0X@`4`2`!6Q3!#__]\`AD0+X```$&>
M`%`OG0``09X`2(@=``!\`P=T5&``,4""`"!48A`Z/3\``($I?1A\0DH4@`(`
M-%0`K_Y(```4.(`(`$@`5GDP0___?`(9$"^```!`G@`8.&```3B```$\OP``
M.*5L*$O_V@TX80!`.(`0`#R_```XI6Q$?Z;K>'_'\WA(`$U9.&$`0$@`5A&`
M`1!8."$04'P(`Z:[H?_T3H``('P(`J:_P?_XD`$`")0A_Z!"GP`%?^@"IGQ^
M&W@X`/__D`$`0)`!`$0X@0!`.*$`1#C!`$A+_^Z!+X/__T"^`!PX8``!.(``
M`3R_```XI6M<?\;S>$O_V7V`80!(2`!-W2^#__]`O@`@.&```3B```$\OP``
M.*5K<'_&\WB`X0!(2__948#!`$`KA@`=0;T`&#A@``$X@``!/+\``#BE:Y!+
M_]DQ?\/S>("!`$1(`%/-+X/__T"^`"Q(`$WA@&,``$@`3;E\9QMX.&```3B`
M``$\OP``.*5KM'_&\WA+_]CU@&$`1$@`3U4O@P``0;X`'#A@``$X@``!/+\`
M`#BE:^"`P0!$2__8S8!A`$!(`$]-+X,``$&^`!PX8``!.(```3R_```XI6OX
M@,$`0$O_V*4X8```@`$`:#@A`&!\"`.FN\'_^$Z``"!\"`*FOV'_[)`!``B4
M(?\P0I\`!7_H`J9\>QMX/%\``#A"?)B!(@``@`(`!(!"``B1(0!`D`$`1)!!
M`$@[P0!`+XD``$&>`&`[H```8[V`0#N````\?P``.&-JW']DVWB`O@``2``+
MX3B!`%!(`$T%+X,``$">`!R@`0!8<`#P0'^`Z`!`O@`,@'X``$@``!Q(`$S!
MDX,``(0>``0O@```0)[_M#A@``"``0#8."$`T'P(`Z:[8?_L3H``('P(`J:_
M@?_PD`$`")0A_U!"GP`%?^@"IGQ]&WA\G"-X2`!1E7Q^&WE`H@`D.&```3B`
M``$\OP``.*5J*#S?```XQFI`?Z?K>$O_UX6`?@`<2`!+Y2^#__]`O@`<.&``
M`3B```$\OP``.*5J4(#>`!Q+_]==/'\``#AC:G`X@0!`2`!,-2^#__]!G@!8
MH`$`2%0`!"8O@$``0+X`2'^CZWB`G@`,2```42^<``!`O@`T@'X`'$O__I$O
M@P``0+X`)#A@``$X@``!/+\``#BE:G0\WP``.,9J0'^GZWA+_];Q@`$`N#@A
M`+!\"`.FNX'_\$Z``"!\"`*FOX'_\)`!``B4(?^`0I\`!7_H`J9\?!MX?)TC
M>#Q?```X0GKT@`(``($B``2!8@`(@$(`#)`!`%"1(0!4D6$`6)!!`%PX80!@
M.($`4$@`*=$O@P``0)X`*#Q_```X8VG8.(```3B@`#(\WP``@,9Y%#C&`+!(
M`%#I2```R#Q_```X8VH,2```T3Q_```X8VH,.(`&`3B@`:1(`$\E?'X;>"^#
M__]`O@`8.&```3B```$\OP``.*5J&$O_UAT\?P``.&-J/'^DZWA_A>-X2``)
MQ7Q]&W@X````D`$`.#A@__]_Q/-X.*```H#!`&!\QS-X/1\``#D(:FQ_J>MX
M/5\``#E*:G!(`"VM+X/__T"^`!@X8``!.(```3R_```XI6I\2__5M7^CZWA(
M`$@U?\/S>$@`2PU(`$II.````)`#``"``0"(."$`@'P(`Z:[@?_P3H``('P(
M`J:_P?_XD`$`")0A_[!"GP`%?^@"IGQ^&WA(`%#-+X/__T"^`"Q(`$HA@`,`
M`"^```)!G@`<.&```3B```$\OP``.*5I1'_&\WA+_]4U@`$`6#@A`%!\"`.F
MN\'_^$Z``"!\"`*FOZ'_])`!``B4(?^@0I\`!7_H`J9\?AMX?)TC>$@`2L4O
M@___09X`-"^#``!`O@`8?\/S>'^DZWA(`$]).&#__T@`1J$X@0!`.*```$@`
M2?6`80!`2```'#A@``$X@``!/+\``#BE:/1+_]2Q.&#__X`!`&@X(0!@?`@#
MIKNA__1.@``@?`@"II`!``B4(?^P2```%8`!`%@X(0!0?`@#IDZ``"!\"`*F
MOZ'_])`!``B4(?]@0I\`!7_H`J9\91MX.````)`!`(`\7P``.$)XH(`"``"!
M(@`$@6(`"(%"``R0`0!`D2$`1)%A`$B100!,@`(`$($B`!2`0@`8D`$`4)$A
M`%2000!8/%\``#A">+R``@``@2(`!(%B``B!0@`,D`$`8)$A`&2180!HD4$`
M;(`"`!"`0@`4D`$`<)!!`'0X80"`/)\``#B$:&Q(`$X5.&#__X`!`(`O@```
M09X`J(`!`("0`0!,D`$`;#Q_```X8VA<.($`0$O__H5\8QMY08(`+'Q]1G"`
M80"`2`!&%3@```"0`0"`:[T`:2`=``!_H.D4.'W__T@``%P\?P``.&-H7#B!
M`&!+__Y%?'T;>(!A`(!(`$7=.````)`!`(`X8```?[WK>4&"`"Q_H$9P<Z(`
M?T""`!0O@`!I09X`%"^`_YQ!G@`,.&#__T@```@X8```@`$`J#@A`*!\"`.F
MNZ'_]$Z``"!\"`*FD^'__)`!``B4(?^P0I\`!7_H`J8X8``!.(```3R_```X
MI6=`/-\``#C&9U1+_]+1.&#__X`!`%@X(0!0?`@#IH/A__Q.@``@?`@"IK^A
M__20`0`(E"'_L$*?``5_Z`*F?'T;>$@``$U\?AMY08(`%(@>``!\``=T+X``
M`$">`!PX8``!.(```3R_```XI6<4?Z;K>$O_TFE_P_-X@`$`6#@A`%!\"`.F
MNZ'_]$Z``"!\"`*FOH'_T)`!``B4(?\P0I\`!7_H`J9\=!MX.\```$@`1A5\
M>1MX/%\``8!"IJPO@@``0+X!9#Q_```X8V;$/)\``#B$8<1(`$[-.````'QW
M&WE!@@+4?N.[>$@`2ODX@0!`2`!.D2^#``!`G@!8/[\``3N]IJR`80!T.&,`
M`D@`2960?0``+X,``$&>`#@_OP`!.[VFK(!]``"`@0!T.*```7[FNWA(`$X-
M+X,``4&^`""`?0``2`!$'3@```"0'0``?N.[>$@`3@U(``)8/3\``3DIIK"!
M80!TD6D``#Q?``&`0J:L.````'P"6:X[H```@`D``'^=`$!`G`"4/Q\``3L8
MIJP\7P``@J)TC'TZ2WB`6```?`+HKGP`!W0O@``*0+X`7'_=$A0ZP$``?KRK
M>#M@``!(```,FWX``#O>__^('@``?`,'=%1@`#%`@@`85&(0.GQ"XA2``@`T
M5`"7_D@``!1^Q+-X2`!-*3!#__]\`AD0+X```$">_\`[O0`!@!H``'^=`$!!
MG/^(?N.[>$@`34$[H```/%\``8!"IK!_G1!`0)P!:#[_``$Z]Z:L.T!``#Q?
M``"#@G2,/Q\``3L8IK!^];MX?Q;#>'\;PWB`%P``?]T"%$@```@[W@`!B'X`
M`%1@`#%`@@`85&(0.GQ"XA2``@`T5`"7_D@``!1_1--X2`!,C3!#__]\`AD0
M+X```$">_\A_P_-X?H2C>'\ERWA(`$9M+X,``$">`*!\?LBN5&``,4""`!A4
M8A`Z?$+B%(`"`#14`)?^2```%#B`0`!(`$P],$/__WP"&1`O@```0;X`:'_>
MRA0\7P``@X)TC$@```@[W@`!B%X``'Q`!W5!@@"(+X``"D&>`(!40P8^5&``
M,4""`!A48A`Z?$+B%(`"`#14`)?^2```%#B`0`!(`$O=,$/__WP"&1`O@```
M0)[_M$@``$2`&```?YT`0$"<`"R!=0``@38``'^BZW@[O0`!?`L0KGP`!W0O
M@```09X`#'^=2$!!G/_D@!L``'^=`$!!G/[(/%\``8!"IK!_P/-X?YT00$&\
M``@X````?`,#>(`!`-@X(0#0?`@#IKJ!_]!.@``@?`@"II/A__R0`0`(E"'_
ML$*?``5_Z`*F?&0;>#Q_```X8TX`2`!`37QE&W@\?P``.&-CH#Q?``"`0G%4
M@((``$@``HF``0!8."$`4'P(`Z:#X?_\3H``(#@```!\8QMY08(`'#A```&`
M`P``+X```$&]``@X0```?$`3>'P#`WA.@``@.````7QC&WE!@@`0@`,``"!`
M``!\`@$4?`,#>$Z``"!\"`*FD`$`")0A_[!(```5@`$`6#@A`%!\"`.F3H``
M('P(`J:_H?_TD`$`")0A_[!"GP`%?^@"ICN@```X`/__?'X;>4&"`&2`?@``
M+X,``$"=`#Q(`$-]+X,``$"\`#!(`$+1@&,``$@`0JE\9QMX.&```#B```$\
MOP``.*5B](#>``1+_\WE.Z#__X!^``0O@P``0;X`"$@`0%E_P_-X2`!`47^@
MZWA\`P-X@`$`6#@A`%!\"`.FNZ'_]$Z``"!\"`*FD`$`")0A_[!\AB-X.(`&
M`CB@``)(``!!@`$`6#@A`%!\"`.F3H``('P(`J:0`0`(E"'_L'R&(W@X@`8"
M.*``!D@``!6``0!8."$`4'P(`Z9.@``@?`@"IK]!_^B0`0`(E"'_H$*?``5_
MZ`*F?'P;>'R;(WA\NBMX?-TS>#A@``A(`$3M.````'Q^&WE!@@"\.````)`>
M``"0'@`$+YT``$&>`!!_@^-X2__]\4@``!0\?P``.&-B+'^$XWA(``"ED'X`
M!']DVW@XH`&D2`!%P9!^```O@P``0+P`,$@`09&`8P``2`!!:7QG&W@X8```
M.(```#R_```XI6(P@-X`!$O_S*5(``!`@'X``']$TWA(`$E]?\#S>"^#``!!
MO@`L@'X``$@`0>E(`$%%@$,``&A"`",@`@``?$`1%#A"__^07@``?\#S>'P#
M`WB``0!H."$`8'P(`Z:[0?_H3H``('P(`J:0`0`(E"'_L)"!`&R0H0!PD,$`
M=)#A`'B1`0!\D2$`@)%!`(0X@0!L2```%8`!`%@X(0!0?`@#IDZ``"!\"`*F
MD^'__)`!``B4(?^@0I\`!7_H`J9\8AMX?(4C>#@```"0`0!`.&$`0'Q$$WA(
M`$C=+X/__T"^`"A(`$"1@&,``$@`0&E\9AMX.&```3B```$\OP``.*5A!$O_
MRZF`80!`@`$`:#@A`&!\"`.F@^'__$Z``"!\"`*FOT'_Z)`!``B4(?^@?'P;
M>'S;,WA\^CMX?1U#>'T&0WA(```Q?X/C>']DVWA_1=-X?Z;K>$@``YTX8```
M@`$`:#@A`&!\"`.FNT'_Z$Z``"!\"`*FOL'_V)`!``B4(?\P0I\`!7_H`J9\
M>1MX?)@C>'RW*WA\UC-X.($`0$@`/S4O@___0+X`/$@`/\F``P``+X```D"^
M`"Q(`#^Y@&,``$@`/Y%\9QMX.&```3B```$\OP``.*5@8'\FRWA+_\K-H`$`
M2%0"!"8X````8`"@`'^"``!!G@+H.````&``@`!_@@``0+X`0'\CRWA_!,-X
M?N6[>$@`1GTO@___0+X"P$@`/U&`8P``2``_*7QG&W@X8``!.(```3R_```X
MI6!\2``"E#Q_```X8U>H.(``!$@`0T%\>AMX+X/__T"^`"A(`#\1@&,``$@`
M/NE\9AMX.&```3B```$\OP``.*5@I$O_RBE_(\MX2``^J7Q[&WE`H@`L2``^
MW8!C``!(`#ZU?&<;>#A@``$X@``!/+\``#BE8-A_)LMX2__)\7\CRWA(`#Y1
M+X/__T"^`"Q(`#ZE@&,``$@`/GU\9QMX.&```3B```$\OP``.*5@]'\FRWA+
M_\FY.X```&.<@`!(``$,.[X`"'^CZW@X@0!`2``]Q2^#__]`O@`\2``^68`#
M```O@``"09X`Y$@`/DF`8P``2``^(7QG&W@X8``!.(```3R_```XI6$4?Z;K
M>$O_R5V@`0!(5``$)B^`0`!`O@!8.]X`"'_#\W@\GP``.(17J#B@``)(`#]]
M+X,``$&>`(Q_P_-X/)\``#B$5ZPXH``#2``_82^#``!!O@!P?\/S>'\$PWA^
MY;MX.,```4O__<5(``!8H`$`2%0`!"9_@.``0+X`2#O>``A_P_-X?P3#>'[E
MNWA(`$2]+X/__T"^`"Q(`#V1@&,``$@`/6E\9QMX.&```3B```$\OP``.*5@
M?'_&\WA+_\BE?V/;>$@`/.5\?AMY0(+^[']#TWA(`$7U+X/__T&>`!1_0]-X
M2``]Y2^#__]`O@`H2``].8!C``!(`#T1?&8;>#A@``$X@``!/+\``#BE83Q+
M_\A1?V/;>$@`/%$O@___0+X`+$@`/06`8P``2``\W7QG&W@X8``!.(```3R_
M```XI6%H?R;+>$O_R!DOE@``0;X`1'\CRWA_!,-X?N6[>$@`0^DO@___0+X`
M+$@`/+V`8P``2``\E7QG&W@X8``!.(```3R_```XI6&$?R;+>$O_Q]&``0#8
M."$`T'P(`Z:ZP?_83H``('P(`J:^P?_8D`$`")0A_S!"GP`%?^@"IGQY&WA\
MF"-X?+8K>'S7,W@X@0!`2``[M2^#__]`O@`\2``\28`#```O@``"0+X`+$@`
M/#F`8P``2``\$7QG&W@X8``!.(```3R_```XI5S@?R;+>$O_QTV@`0!(5`($
M)C@```!@`*``?X(``$&>`MPX````8`"``'^"``!`O@`\?R/+>%<$!#Y(`#I!
M+X/__T"^`KA(`#O5@&,``$@`.ZU\9QMX.&```3B```$\OP``.*5>($@``HP\
M?P``.&-4*#B```1(`#_%?'H;>"^#__]`O@`H2``[E8!C``!(`#MM?&8;>#A@
M``$X@``!/+\``#BE721+_\:M?R/+>$@`.RU\>QMY0*(`+$@`.V&`8P``2``[
M.7QG&W@X8``!.(```3R_```XI5U8?R;+>$O_QG5_(\MX2``ZU2^#__]`O@`L
M2``[*8!C``!(`#L!?&<;>#A@``$X@``!/+\``#BE771_)LMX2__&/3N```!C
MG(``2``!"#N^``A_H^MX.($`0$@`.DDO@___0+X`/$@`.MV``P``+X```D&>
M`.!(`#K-@&,``$@`.J5\9QMX.&```3B```$\OP``.*5=E'^FZWA+_\7AH`$`
M2%0`!"8O@$``0+X`6#O>``A_P_-X/)\``#B$5"@XH``"2``\`2^#``!!G@"(
M?\/S>#R?```XA%0L.*```T@`.^4O@P``0;X`;'_#\WA_!,-X?L6S>#C```%+
M__W)2```5*`!`$A4``0F?X#@`$"^`$0[W@`(?\/S>%<$!#Y(`#B%+X/__T"^
M`"Q(`#H9@&,``$@`.?%\9QMX.&```3B```$\OP``.*5>0'_&\WA+_\4M?V/;
M>$@`.6U\?AMY0(+^\']#TWA(`$)]+X/__T&>`!1_0]-X2``Z;2^#__]`O@`H
M2``YP8!C``!(`#F9?&8;>#A@``$X@``!/+\``#BE7;Q+_\39?V/;>$@`.-DO
M@___0+X`+$@`.8V`8P``2``Y97QG&W@X8``!.(```3R_```XI5WH?R;+>$O_
MQ*$OEP``0;X`0'\CRWA6Q`0^2``WM2^#__]`O@`L2``Y28!C``!(`#DA?&<;
M>#A@``$X@``!/+\``#BE7FA_)LMX2__$78`!`-@X(0#0?`@#IKK!_]A.@``@
M?`@"IK\A_^20`0`(E"'_0$*?``5_Z`*F?'H;>'R9(W@X@0!`2``X22^#__]`
MO@`42``XW8`#```O@``"09X"]*`!`$A4`@0F.````&``H`!_@@``09X`%#@`
M``!@`(``?X(``$">`$A_0]-X2``_02^#__]`O@*\2``XE8`#```O@``"09X"
MK$@`.(6`8P``2``X77QG&W@X8``!.(```3R_```XI5L02``"@#Q_```X8U"T
M.(``!$@`/'5\>QMX+X/__T"^`"A(`#A%@&,``$@`.!U\9AMX.&```3B```$\
MOP``.*59L$O_PUU_0]-X2``WW7Q\&WE`H@`L2``X$8!C``!(`#?I?&<;>#A@
M``$X@``!/+\``#BE6>1_1M-X2__#)7]#TWA(`#>%+X/__T"^`21(`#?9@&,`
M`$@`-[%\9QMX.&```3B```$\OP``.*5:`']&TWA(``#X.[X`"'^CZW@X@0!`
M2``W!2^#__]`O@`\2``WF8`#```O@``"09X`U$@`-XF`8P``2``W87QG&W@X
M8``!.(```3R_```XI5H@?Z;K>$O_PIV@`0!(5``$)B^`0`!`G@!0.]X`"'_#
M\W@\GP``.(10M#B@``)(`#B]+X,``$&>`'Q_P_-X/)\``#B$4+@XH``#2``X
MH2^#``!!O@!@?\/S>#B```%+__X!2```4#O>``A_P_-X2``]G2^#__]`O@`\
M2``V\8`#```O@``"09X`+$@`-N&`8P``2``VN7QG&W@X8``!.(```3R_```X
MI5LP?\;S>$O_P?5_@^-X2``V-7Q^&WE`@O[\?V/;>$@`/T4O@___09X`%']C
MVWA(`#<U+X/__T"^`"A(`#:)@&,``$@`-F%\9AMX.&```3B```$\OP``.*5:
M2$O_P:%_@^-X2``UH2^#__]`O@`L2``V58!C``!(`#8M?&<;>#A@``$X@``!
M/+\``#BE6G1_1M-X2__!:2^9``!!O@!,?T/3>$@`/J$O@___0+X`/$@`-A6`
M`P``+X```D&>`"Q(`#8%@&,``$@`-=U\9QMX.&```3B```$\OP``.*5;7']&
MTWA+_\$9@`$`R#@A`,!\"`.FNR'_Y$Z``"!\"`*FOL'_V)`!``B4(?\P0I\`
M!7_H`J9\>1MX?)@C>'RW*WA\UC-X.($`0$@`-/TO@___0+X`/$@`-9&``P``
M+X```D"^`"Q(`#6!@&,``$@`-5E\9QMX.&```3B```$\OP``.*56*'\FRWA+
M_\"5H`$`2%0"!"8X````8`"@`'^"``!!G@*D.````&``@`!_@@``0+X`(#A@
M```X@``!/+\``#BE6#A_)LMX2__`54@``G@\?P``.&--<#B```1(`#DI?'H;
M>"^#__]`O@`H2``T^8!C``!(`#31?&8;>#A@``$X@``!/+\``#BE5FQ+_\`1
M?R/+>$@`-)%\?!MY0*(`+$@`-,6`8P``2``TG7QG&W@X8``!.(```3R_```X
MI5:@?R;+>$O_O]E_(\MX2``T.2^#__]`O@`L2``TC8!C``!(`#1E?&<;>#A@
M``$X@``!/+\``#BE5KQ_)LMX2_^_H3M@``!C>X``2``!,#N^``A_H^MX.($`
M0$@`,ZTO@___0+X`/$@`-$&``P``+X```D&>`0A(`#0Q@&,``$@`-`E\9QMX
M.&```3B```$\OP``.*56W'^FZWA+_[]%H`$`2%0`!"8O@$``0+X`6#O>``A_
MP_-X/)\``#B$37`XH``"2``U92^#``!!G@"P?\/S>#R?```XA$UT.*```T@`
M-4DO@P``0;X`E'_#\WA_!,-X?N6[>#C```%+__WE2```?*`!`$A4``0F?X#8
M`$"^`&POE@``0;X`9'\#PWA(`#*I.*,``3A^``A_!,-X2``XV2^#``!`O@!$
M?P/#>'[DNWA(`#;E+X/__T"^`#!(`#-9@&,``$@`,S%\:!MX.&```3B```$\
MOP``.*589'\&PWA^Y[MX2_^^:7^#XWA(`#*I?'X;>4""_LA_0]-X2``[N2^#
M__]!G@`4?T/3>$@`,ZDO@___0+X`*$@`,OV`8P``2``RU7QF&W@X8``!.(``
M`3R_```XI5<$2_^^%7^#XWA(`#(5+X/__T"^`"Q(`#+)@&,``$@`,J%\9QMX
M.&```3B```$\OP``.*57,'\FRWA+_[W=@`$`V#@A`-!\"`.FNL'_V$Z``"!\
M"`*FOZ'_])`!``B4(>]00I\`!7_H`J9\?1MX/]\``#O>7]2`'@``+X```$&^
M`"B`7@``?Z/K>(""``!+_]:Q+X,``$">`!"$'@`$+X```$">_^"`'@``+X``
M`$"^`!PX8``!.(```3R_```XI558?Z;K>$O_O5%_H^MX.($00$@`,BTO@P``
M09X`&#A@``$X@``!/+\``#BE59Q(``",@%X``#AA`$`X@!``/+\``#BE5="`
MP@``//\``(#G7]!(`#!M.&$`0$@`.B4O@P``0+X`&#A@``$X@``!/+\``#BE
M5=Q+_[SA.&```#B```$\OP``.*56''^FZW@XX0!`2_^\Q7^CZW@X@0!`2``.
M!2^#``!!O@`8.&```3B```$\OP``.*561$O_O)V``1"X."$0L'P(`Z:[H?_T
M3H``('P(`J:_(?_DD`$`")0A_T!"GP`%?^@"IC]_```[>UZ4@!L``"^```!!
MG@$H/S\``#LY7I"`6P``@&(``$@`,-%\?!MY0*(`-$@`,06`8P``2``PW7QG
M&WB`6P``.&```#B```$\OP``.*52)(#"``!+_[P52```W(!;``"`8@``2``P
M;7\ZRWA(``"@.]T`"'_#\W@X@0!`2``PU2^#__]`O@`8.&```#B```$\OP``
M.*55-$@``&R@`0!(5``$)B^`0`!`O@!D@'H``$@`+Z%\91MX.]T`"'_#\WB`
MF@``2``US2^#``!`O@!`/'\``#AC/<P\GP``.(156'_%\W@XP```2``B:2^#
M``!!O@`<.&```#B```$\OP``.*557'_&\WA+_[MA?X/C>$@`+Z%\?1MY0(+_
M6#Q_```X8U602``OK80;``0O@```0)[^Z(`!`,@X(0#`?`@#IKLA_^1.@``@
M?`@"II`!``B4(?^@D($`0#B!`$`X````D`0`!$@``!6``0!H."$`8'P(`Z9.
M@``@?`@"IGQ``":^`?_`D`$`")!!``24(>\@0I\`!7_H`J9\>QMX?)<C>'R^
M*WA\VC-X.J```#B```%+_^T1?'P;>4&"`!!+_^OY+X,``$">`#A(`"]I@&,`
M`$@`+T%\9QMX.&```#B````\OP``.*53^']FVWA+_[I]?X/C>$O_[`U(``=L
M?V/;>#B!$$!(`"]-+X,``$&^`#Q(`"\A@`,``"^```)!G@`H2``O$8!C``!(
M`"[I?&<;>#A@```X@```/+\``#BE5"A(``;8.J```2^>``%!G@'H09T`$"^>
M``!!G@`42``&#"^>``)!G@-@2``&`"^:``!!G@!T+YH``4"^!?!_8]MX/)\`
M`#B$5%!(`#:I?'@;>4&"`TQ_`\-X?N2[>$@`!NU_`\-X2``V32^#``!!O@6\
M2``N@8!C``!(`"Y9?&<;>#A@```X@```/+\``#BE171_9MMX2_^YE7^#XWA+
M_^M%2``&A#AA`$`X@!``/+\``#BE5%1_9MMX2``LV3AA`$`\GP``.(147$@`
M-BE\=AMY0*(`+$@`+AV`8P``2``M]7QF&W@_OP``@[U=)#A]`+`\GP``.(14
M8$@`!1Q^P[-X?N2[>$@`!D5_8]MX/)\``#B$2F!(`#7=?'@;>4"B`$Q(`"W1
M@&,``$@`+:E\9QMX.&```#B````\OP``.*548']FVWA+_[CE?L.S>$@`-65+
M__](.&$`0'[$LWA(`"_U+X/__T&>!8`X80!`.(`0`'\%PWA(`#0]+X,``$">
M_]A_`\-X2``U+2^#``!`G@/T?L.S>$@`-1TO@P``0+[^U#AA`$`X@!``/+\`
M`#BE5%1_9MMX2``KW3AA`$!_9-MX2``PL2^#``!!O@1@2``M)8!C``!(`"S]
M?&8;>#^_``"#O5TD.'T`L#R?```XA%1\2``$)"^5``!`OOZ@?V/;>#R?```X
MA$I@2``TZ7QX&WE!@@&,.&$`0#B`$``\OP``.*545']FVWA(`"MI.&$`0#R?
M```XA%1<2``TN7QV&WE!@@&P.R$`0$@``+0X80!`2``KP7Q^&W@[0```?$/*
M%(@"__]\``=T+X``"D"^``@[P___?OV[>(`7```O@```0;X`2(!]```X@0!`
M?\7S>$@`,<$O@P``0)X`)(!=``!\`O"N?``'="^```I!G@`,+X```$">``@[
M0``!A!T`!"^```!`GO_`+YH``$"^`#`X80!`?L2S>$@`+GDO@___0+X`'#A@
M``$X@``!/+\``#BE5)Q_9MMX2_^W,3AA`$`X@`__?P7#>$@`,JDO@P``0)[_
M/'\#PWA(`#.9+X,``$">`F!^P[-X2``SB2^#``!`OOU`.&$`0#B`$``\OP``
M.*545']FVWA(`"I).&$`0']DVWA(`"\=+X,``$&^`LQ(`"N1@&,``$@`*VE\
M9QMX.&```#B````\OP``.*54O$O__1!_8]MX/)\``#B$2F!(`#-A?'@;>4"B
M`"A(`"M5@&,``$@`*RU\9QMX.&```#B````\OP``.*548$O__-0X80!`.(`0
M`#R_```XI514?V;;>$@`*;TX80!`/)\``#B$5%Q(`#,-?'8;>4"B`$A(`"L!
M@&,``$@`*ME\9AMX/[\``(.]720X?0"P/)\``#B$5&`XH0!`2``M63A]`+!(
M`"SQ?X/C>$O_Y[E_`\-X2``"\#HA`$`OF@``?F``)E9SX`8OF@`"?D``)E92
MX`9^,(MX2``!!#AA`$!(`"FU?'X;>#L@``!\0XH4B`+__WP`!W0O@``*0+X`
M"#O#__]^_;MX@!<``"^```!!G@#,+AH``59SP#Y^<@$@5G-`/E92H#Y^40$@
M5E)@/GX4@WB`?0``2``I77QE&WB`70``?$(:%(@"__]\``=T+X```$">``@X
MH___09(`/$&1``Q!B@`D2```5$"N`%`X80!`@)T``$@`,KTO@P``09X`/$@`
M`#0X80!`?X7P0$"=`!A(```H?X7P0$&]`"!\9:!0?&/R%("=``!(`"\I+X,`
M`$">``@[(``!+YD``$"^`!`X80!`?L2S>$@`+`F$'0`$+X```$">_UPX80!`
M.(`/_W\%PWA(`#!-+X,``$">_NQ_`\-X2``Q/2^#``!!G@`X2``I<8!C``!(
M`"E)?&<;>#A@```X@```/+\``#BE171_9MMX2_^TA7^#XWA+_^8U2``!;'[#
MLWA(`##Y+X,``$"^^K`X80!`.(`0`#R_```XI514?V;;>$@`)[DX80!`?V3;
M>$@`+(TO@P``0;X`/$@`*0&`8P``2``HV7QF&W@_OP``@[U=)#A]`+`\GP``
M.(14O#BA`$!(`"M9.'T`L$@`*O%+__IT+Y4``$">`'A_8]MX@($03("A$%!(
M`"_5+X,``$"\`"A(`"BI@&,``$@`*(%\9QMX.&```#B````\OP``.*54W$O_
M^BA_8]MXH($02$@`)MTO@P``0+P`*$@`*'&`8P``2``H27QG&W@X8```.(``
M`#R_```XI54,2__Y\'^#XWA+_^4Y.````"^#``!!O@!T2``H.8!C``!(`"@1
M?&<;>#A@```X@```/+\``#BE53Q_9MMX2_^S34@``$1(`"@-@&,``$@`)^5\
M9QMX.&```#B````\OP``.*55;']FVWA+_[,A?X/C>$O_Y-%_`\-X2``OF7[#
MLWA(`"^1.````7P#`WB``1#H."$0X(%A``1\"`.FN@'_P'UC@2!.@``@?`@"
MIK^!__"0`0`(E"'_L$*?``5_Z`*F?'P;>'R>(WB`!```+X```$&^`&"`?@``
M2``FF7Q]&WB`?@``.(```7^EZWA_AN-X2``M(8!>``!\0NH4B`+__WP`!W0O
M@``*09X`'#Q_```X8TV$.(```3B@``%_AN-X2``L\80>``0O@```0)[_J(`!
M`%@X(0!0?`@#IKN!__!.@``@?`@"IK_!__B0`0`(E"'_L$*?``5_Z`*F?'X;
M>#B`!@%(`"L-?&,;>4"@`#1(`";A@&,``$@`)KE\9QMX.&```#B````\OP``
M.*5,['_&\WA+_['U.&#__T@```Q(`"=1.&```(`!`%@X(0!0?`@#IKO!__A.
M@``@?`@"IK_!__B0`0`(E"'_L$*?``5_Z`*F?'X;>#B``@%(`"J5?&,;>4"@
M`#1(`"9I@&,``$@`)D%\9QMX.&```#B````\OP``.*5,H'_&\WA+_[%].&#_
M_T@```Q(`";9.&```(`!`%@X(0!0?`@#IKO!__A.@``@?`@"IK]!_^B0`0`(
ME"'_H$*?``5_Z`*F?'T;>'R;(WA\NBMX?-PS>#B``"](`"[1?'X;>4&"`#!_
MGN@`09X`*#@```"8'@``?Z/K>']DVWA_1=-X5X8%_DO__ZDX```OF!X``'^C
MZWA_A.-X2``L\2^#__]`O@`\2``EI8`#```O@``109X`;$@`)96`8P``2``E
M;7QG&W@X8``!.(```3R_```XI4Q(?Z;K>$O_L*E_H^MX?V3;>']%TWA(`"R!
M+X/__T"^`"Q(`"55@&,``$@`)2U\9QMX.&```#B```$\OP``.*5,:'^FZWA+
M_[!I@`$`:#@A`&!\"`.FNT'_Z$Z``"!\"`*FOT'_Z)`!``B4(?^@0I\`!7_H
M`J9\8!MX?)PC>'R[*WA\VC-X/'\``#AC12Q\!`-X2__CV7Q]&WA_A.-X?V7;
M>']&TWA+__ZU?Z/K>$@`(HF``0!H."$`8'P(`Z:[0?_H3H``('P(`J:_8?_L
MD`$`")0A_Z!"GP`%?^@"IGQ^&WA\G"-X?+LK>'S=,WA(`"2).````)`#``!_
MP_-X?Z3K>$@`*[4O@P``09X`.$@`)&F``P``+X``$4&^`"A(`"19@&,``$@`
M)#%\9QMX.&```#B````\OP``.*5+$$@``)1_P_-X?X3C>']EVWA(`"M)+X,`
M`$&>`#A(`"0=@`,``"^```)!O@`H2``D#8!C``!(`"/E?&<;>#A@```X@```
M/+\``#BE2S!(``!(?\/S>'^DZWA(`")!+X,``$&^`$1(`"/5@`,``"^```)!
MO@`T2``CQ8!C``!(`".=?&<;>#A@```X@```/+\``#BE2U!_QO-X2_^NV3A@
M__](```(.&```(`!`&@X(0!@?`@#IKMA_^Q.@``@?`@"IK^A__20`0`(E"'_
M4$*?``5_Z`*F?'T;>'R>(W@X@0!`2``C>2^#``!`O@!X?\/S>#B!`$!(`"-E
M+X,``$"^`!PX@```/+\``#BE2CQ_QO-X2_^N84@``$1_H^MX?\3S>$@`)IDO
M@P``0;X`.$@`(PV`8P``2``BY7QH&W@X8```.(```#R_```XI4I\?Z;K>'_'
M\WA+_ZX=.&#__T@```@X8```@`$`N#@A`+!\"`.FNZ'_]$Z``"!\"`*FOV'_
M[)`!``B4(?]`0I\`!7_H`J9\?AMX?)TC>'R\*WA\VS-X2``BF3@```"0`P``
M?\/S>#B!`$!(`"*E+X,``$"^`(1_P_-X?Z3K>'^%XWA(`"F-+X,``$&^`"A(
M`")A@&,``$@`(CE\9QMX.&```#B````\OP``.*5)X$@``#A_P_-X?V3;>$@`
M()4O@P``0;X`-$@`(BF`8P``2``B`7QG&W@X8```.(```#R_```XI4H`?\;S
M>$O_K3TX8/__2```"#A@``"``0#(."$`P'P(`Z:[8?_L3H``('P(`J:_P?_X
MD`$`")0A_[!"GP`%?^@"ID@`*8E\?AMY0:(`*$@`(;V`8P``2``AE7QF&W@X
M8```.(```#R_```XI4E`2_^LU7_#\WB``0!8."$`4'P(`Z:[P?_X3H``('P(
M`J:_@?_PD`$`")0A_U!\?!MX.````)`#``!\GB-X@`0``"^```!!G@!`.Z``
M`(!^```X@0!`2``A:2^#``!`O@`4@!X``)`<```X8``!2```'$@`(2V3HP``
MA!X`!"^```!`GO_,.&```(`!`+@X(0"P?`@#IKN!__!.@``@?`@"IK^A__20
M`0`(E"'_L$*?``5_Z`*FD($`;)"A`'"0P0!TD.$`>)$!`'R1(0"`D4$`A'Q]
M&W@X8```.$$`;#DB``0OA```09X`'#AC``%](DMX.2D`!(`"```O@```0)[_
M[%1C$#HX8P`$2``CE7Q^&WE`H@`H2``@B8!C``!(`"!A?&8;>#A@``$X@``!
M/+\``#BE2(!+_ZNA.&```#A!`&PY(@`$@`(``)`>```O@```09X`)'_+\W@X
M8P`!?2)+>#DI``2``@``E`L`!"^```!`GO_H5&`0.CA```!\7@$N?Z/K>'_$
M\W@XH```2```*7Q]&WA_P_-X2``=Q7^CZWB``0!8."$`4'P(`Z:[H?_T3H``
M('P(`J:_@?_PD`$`")0A_Z!"GP`%?^@"IGQ\&WA\AB-X?+XK>#AA`$`X@0!$
M?X7C>$@`!C5\?1MY08(`:"^>``!`G@!@@($`0"^$``!!O@`4/'\``(!C35PX
M8P"P2``B#8#A`$0OAP``09X`(#A@```X@``!/+\``#BE1WQ_AN-X2_^JH4@`
M`!PX8```.(```3R_```XI4>4?X;C>$O_JH6`80!`2``=!8!A`$1(`!S]?Z/K
M>(`!`&@X(0!@?`@#IKN!__!.@``@?`@"IK^!__"0`0`(E"'_L$*?``5_Z`*F
M?'P;>)"A`'"0P0!TD.$`>)$!`'R1(0"`D4$`A'R=(W@X8```.$$`<#DB``0O
MA0``09X`'#AC``%](DMX.2D`!(`"```O@```0)[_[%1C$#HX8P`$2``AM7Q^
M&WE`H@`H2``>J8!C``!(`!Z!?&8;>#A@``$X@``!/+\``#BE1J!+_ZG!.&``
M`#A!`'`Y(@`$@`(``)`>```O@```09X`)'_+\W@X8P`!?2)+>#DI``2``@``
ME`L`!"^```!`GO_H5&`0.CA```!\7@$N?X/C>'^DZWA_Q?-X2``"97Q]&WA_
MP_-X2``;Y7^CZWB``0!8."$`4'P(`Z:[@?_P3H``('P(`J:_8?_LD`$`")0A
M_Z!"GP`%?^@"IGQ\&WA\FR-XD,$`A)#A`(B1`0",D2$`D)%!`)1\O2MX.&``
M`#A!`(0Y(@`$+X8``$&>`!PX8P`!?2)+>#DI``2``@``+X```$">_^Q48Q`Z
M.&,`!$@`()U\?AMY0*(`*$@`'9&`8P``2``=:7QF&W@X8``!.(```3R_```X
MI46(2_^HJ3A@```X00"$.2(`!(`"``"0'@``+X```$&>`"1_R_-X.&,``7TB
M2W@Y*0`$@`(``)0+``0O@```0)[_Z%1@$#HX0```?%X!+G^#XWA_9-MX?Z7K
M>'_&\WA(``.1?'T;>'_#\WA(`!K)?Z/K>(`!`&@X(0!@?`@#IKMA_^Q.@``@
M?`@"IK]!_^B0`0`(E"'_H$*?``5_Z`*F?'P;>'R;(WA\NBMXD.$`B)$!`(R1
M(0"0D4$`E'S=,W@X8```.$$`B#DB``0OAP``09X`'#AC``%](DMX.2D`!(`"
M```O@```0)[_[%1C$#HX8P`$2``?@7Q^&WE`H@`H2``<=8!C``!(`!Q-?&8;
M>#A@``$X@``!/+\``#BE1&Q+_Z>-.&```#A!`(@Y(@`$@`(``)`>```O@```
M09X`)'_+\W@X8P`!?2)+>#DI``2``@``E`L`!"^```!`GO_H5&`0.CA```!\
M7@$N?X/C>']DVWA_1=-X?Z;K>'_'\WA(``6=?'T;>'_#\WA(`!FI?Z/K>(`!
M`&@X(0!@?`@#IKM!_^A.@``@?`@"IK[!_]B0`0`(E"'W8$*?``5_Z`*F?'D;
M>'R>(WA\O2MX.````)`!"%B0`0A<.T```#K@``"30P``.&$(4$@`)6TO@___
M0+X`&#A@``$X@``!/+\``#BE0YA+_Z:I@&$(4#MC``$X@``$.*``!$@`)1TO
M@___0+X`&#A@``$X@``!/+\``#BE0[Q+_Z9Y.&```("!"%0XH``"?\;S>'^G
MZWA(``31?'@;>(`!"%`O@/__09X!%#O!`$`[@``!.Z```#K`__]_P_-X.(``
M`#B@"`!(`!FY@$$(4"^"__]!G@`<5$#H^E1"!OY_@A`P?3X`+GQ"2WA\7@$N
MDX$(0).A"$1(`!K)DZ,``']CVW@X@0!`.*```#C````XX0A`2``D32^#``!`
MG0!`@$$(4"^"``!`G0"(5$#H^E1"!OY\'@`N?``6,'`"``%!H@!P.&$(4'\D
MRW@XH0A8.,$(7$@`$YU(``!82``:99.C``!_`\-X.($(8#B@``%(`!JQ+X,`
M`$&^`#A(`!I%@`,``"^```!`G@`4@`$(8'P:1G!P`@!_08(`"#M`__^`80A0
M2``:O9+!"%`ZX``!@`$(4"^`__]`GO\$+Y<``$"^`$Q(`!G]DN,``'\#PW@X
M@0A@.*```4@`&DD[0/__+X,``$&^`"A(`!G9@`,``"^```!`G@`4@`$(8'P:
M1G!P`@!_08(`"#M`__^`>0``+X,``$&>`!`X````@$$(7'P#$:Y_0]-X@`$(
MJ#@A"*!\"`.FNL'_V$Z``"!\"`*FOJ'_U)`!``B4(?=00I\`!7_H`J9\>AMX
M?)DC>'R^*WA\W3-X.````)`!"&"0`0ADD`$(:)`!"&P[````.L```),#``"3
M!```.&$(4$@`(Q4O@___09X`%#AA"%A(`",%+X/__T"^`!@X8``!.(```3R_
M```XI4%02_^D08-A"%B``0A0?YL``$"<``A\&P-X.WL``8!A"%`X@``$.*``
M!$@`(J$O@___09X`'(!A"%@X@``$.*``!$@`(HDO@___0+X`&#A@``$X@``!
M/+\``#BE071+_Z/E.&```("!"%2`H0A<?\;S>'^GZWA(``(]?'<;>(`!"%`O
M@/__0+X`$(`!"%@O@/__09X!B#O!`$`[H``!.X```#J@__]_P_-X.(```#B@
M"`!(`!<9@$$(4"^"__]!G@`<5$#H^E1"!OY_HA`P?3X`+GQ"2WA\7@$N@$$(
M6"^"__]!G@`<5$#H^E1"!OY_HA`P?3X`+GQ"2WA\7@$NDZ$(0).!"$1(`!@%
MDX,``']CVW@X@0!`.*```#C````XX0A`2``AB2^#``!`G0!X@$$(4"^"``!`
MG0`P5$#H^E1"!OY\'@`N?``6,'`"``%!H@`8.&$(4']$TW@XH0A@.,$(9$@`
M$-F`00A8+X(``$"=`)140.CZ5$(&_GP>`"Y\`!8P<`(``4&B`'PX80A8?R3+
M>#BA"&@XP0AL2``0H4@``&1(`!=IDX,``'[CNW@X@0AP.*```4@`%[4O@P``
M0;X`1$@`%TF``P``+X```$">`!2``0AP?!A&<'`"`']!@@`(.P#__X!A"%A(
M`!?!DJ$(6(!A"%!(`!>UDJ$(4#K```&``0A0+X#__T">_IR``0A8+X#__T">
M_I`OE@``0+X`3$@`%NF2PP``?N.[>#B!"'`XH``!2``7-3L`__\O@P``0;X`
M*$@`%L6``P``+X```$">`!2``0AP?!A&<'`"`']!@@`(.P#__X!Z```O@P``
M09X`$#@```"`00AD?`,1KH"9```OA```09X`$#@```"`00AL?`01KG\#PWB`
M`0BX."$(L'P(`Z:ZH?_43H``('P(`J:_(?_DD`$`")0A_Z!"GP`%?^@"IGQ]
M&WA\G"-X?+LK>'S9,WA\^CMX2``7+7Q^&W@O@___0+X`&#A@``$X@``!/+\`
M`#BE/GA+_Z%%+YX``$"^`+!_H^MX.(```$@`#JDO@___09X`+'^#XW@X@``!
M2``.E2^#__]!O@`8?V/;>#B```)(``Z!+X/__T">`#!(`!7%@&,``$@`%9U\
M91MX/'\``(!C0\PX8P"P/)\``#B$/IA(`!@A2```0$@`#\%_(\MX?T33>$@`
M&RU(`!6)@&,``$@`%6%\9AMX/'\``(!C0\PX8P"P/)\``#B$/KA_)<MX2``7
MX3A@__](`!)9?\/S>(`!`&@X(0!@?`@#IKLA_^1.@``@?`@"IK\A_^20`0`(
ME"'OD$*?``5_Z`*F?'T;>'R<(WA\NBMX?-DS>#_?``"`?D*P2``937^=&`!!
MG@`8@'Y"L#AC`%A(`!DY?YP8`$">`!PX8```.(```#R_```XI3W`2_^@%4@`
M`C`X81!`2``>L4@`%<U\>QMY08`!^$&"`1"`81!$2``563O!`$`[@```/%\`
M`(.B0K!(```L?$/R%)N"__\X8```.(```#R_```XI350?\;S>$O_G[TX?0"P
M2``6G8!A$$`X@0!`.*`/_T@`&&U\8QMY08'_Q(!A$$!(`!3]?V/;>#B!$$@X
MH``"2``4K2^#__]`O@`H2``408!C``!(`!09?&<;>#A@```X@```/+\``#BE
M/?A(```L@`$02'`'`']!@@!8+X<`?T&>`"1!H@`@.&```#B````\OP``.*4^
M/']FVWA+_Y\I2``!1(#A$$A4X`9^+X``?T"^`"`X8```.(```#R_```XI3YP
M?V;;>'SG1G!+___0@`$02'P#1G!(``$0.&```$@`%$TX8``!2``413A@``)(
M`!0]@&$00$@`%#5_H^MX.(```$@`%&E_@^-X.(```4@`%%V`81!$.(```D@`
M%%%_0]-X?R3+>$@`&06081!(2``378!C``!(`!,U?&4;>#Q?``"#PD*P.'X`
ML#R?```XA#ZD2``5N4@`$S6``P``+X``#D"^`!P\?P``.&,^R#B```$XH`!8
M.-X`L$@``"`\?P``.&,_)#B```$XH``"/-\``(#&0K`XQ@"P2``8L3Q_``"`
M8T*P.&,`L$@`%0&`81!$2``3>8!A$$A(```L2``2S8!C``!(`!*E?&8;>#A@
M``$X@``!/+\``#BE/RA+_YWE.&#__X`!$'@X(1!P?`@#IKLA_^1.@``@?`@"
MIKZ!_]"0`0`(E"'O<$*?``5_Z`*F?'8;>'R4(WA\OBMX.J```#AA$%!(`!Q%
M2``387QZ&WE!@`,@0($"M#K@$`"`81!42``2Z3O````X8!``2``5/9!V``"`
M81!0.(```T@`&^U@90`$@&$04#B```1(`!O=.Z$`0'^CZW@X@```.*`(`$@`
M$,D[80A`?V/;>#B````XH`@`2``0M8`!$%!4">CZ5``&_CN```%_@``P?$GH
M+GP`$WA\">DN2``1T9*C``"3@1!`DJ$01(!A$%`X8P`!?Z3K>']EVWA_9MMX
M..$00$@`&TD[@0!`.V$(0#L```$[(```2``!`(!A$%!48.CZ5&(&_GP<`"Y\
M`!8P<`(``4&"`&2`E@``?+ZX4'R>(A0XI?__2``597Q]&W@O@___0+X`%$@`
M$56``P``+X``!$">`1@OG0``0)T`S'_>ZA0X%___?YX``$&\`#0Z]Q``@'8`
M`'[DNWA(`!/AD'8``$@``!Q_0]-X.($06#B@``%(`!%I?X/0`$&>`,A_@^-X
M.(```#B@"`!(``^Q?V/;>#B````XH`@`2``/H8`!$%!4">CZ5``&_G\``#!\
M2>`N?``3>'P)X2Y(`!#!DR,``),!$$"3(1!$@&$04#AC``%_A.-X?V7;>']F
MVW@XX1!`2``:.4@`$)6``P``+X```$&>_OA(`!"%@`,``"^```1!GO[H@%8`
M`#@```!\`O&N+Y4``$"^`!B2H1!8?T/3>#B!$%@XH```2``0L8`!$%A\'D9P
M<`(`?T&"`#Q(```T.J```4O__\!(`!`Q@&,``$@`$`E\9AMX.&```#B```$\
MOP``.*4\G$O_FTE+__^8.\#__R^>``!!G@!8+YX`_T"^`"`X8```.(```3R_
M```XI3R\@-8``$O_FQE(```D.&```#B```$\OP``.*4\R'Z&HWA_Q_-X@18`
M`$O_FO6`=@``2``-=3@```"0%@``?\/S>$@``)2`81!02``0/3A@``%(`!`U
M.&```D@`$"T[H1!0@'T`!#B```%(`!!=@'T`!#B```)(`!!1?H.C>'_$\WA(
M`!4%2``/88!C``!(``\Y?&4;>#Q_```X8SSL?H2C>$@`$*4X8/__2``,/4@`
M#SF`8P``2``/$7QF&W@X8``!.(```3R_```XI3T`2_^:43A@``"``1"8."$0
MD'P(`Z:Z@?_03H``('P(`J:_@?_PD`$`")0A_[!"GP`%?^@"IGQ\&WB0H0!P
MD,$`=)#A`'B1`0!\D2$`@)%!`(1\G2-X.&```#A!`'`X`@`$+X4``$&>`!PX
M8P`!?`(#>#@"``2`0@``+X(``$">_^Q48Q`Z.&,`"$@`$9%\?AMY0*(`*$@`
M#H6`8P``2``.77QF&W@X8``!.(```3R_```XI3F`2_^9G9.^```X8``!.$$`
M<#@"``2`0@``+X(``$&>`"@Y/@`$D$D``#DI``0X8P`!?`(#>#@"``2`0@``
M+X(``$">_^148!`Z.$```'Q>`2Y_@^-X?Z3K>'_%\WA+__MY?'T;>'_#\WA(
M``N]?Z/K>(`!`%@X(0!0?`@#IKN!__!.@``@?`@"IK^A__20`0`(E"'^`$*?
M``5_Z`*FD($"')"A`B"0P0(DD.$"*)$!`BR1(0(PD4$"-'Q^&W@Y00(<D&$`
M0#E@``$Y(0!$+XL`8T&=`"1]0E-X.4H`!(`"``"0"0``.2D`!#EK``$O@```
M0)[_W#@```"0`0'02``.:2^#``!`O@!<2``-_3A@``%(``WU.&```D@`#>T\
M?P``.&,I3#B```)(`!%=?'T;>#B```!(``X1?Z/K>#B```%(``X%?Z/K>#B`
M``)(``WY?\/S>#B!`$!(`!*M2``*"3AA`>!(`!:!@&$!X%1C!GY\8P#05&,/
M_H`!`@@X(0(`?`@#IKNA__1.@``@?`@"IK^A__20`0`(E"'N$$*?``5_Z`*F
MD($2#)"A$A"0P1(4D.$2&)$!$AR1(1(@D4$2)'Q]&W@X@``O2``5_2^#``!!
MO@`D.&```#B````\OP``.*4W>'^FZWA+_Y>U.&#__T@``)@[P1(,.&$`0#B`
M$``\OP``.*4WO#Q?``"`0CI8@,(``'^GZWA(``KM.`$`0)`!$$`Y8``!.2$0
M1"^+`&-!G0`D?\+S>#O>``2``@``D`D``#DI``0Y:P`!+X```$">_]POBP!C
M09T`&%5@$#I\00(4.````)`"$$!(```,.````)`!$=`X80!`.($00#B@``!+
M_^OY@`$1^#@A$?!\"`.FNZ'_]$Z``"!\"`*FD`$`")0A_A"0@0(,D*$"$)#!
M`A20X0(8D0$"')$A`B"100(D.4$"#)!A`$`Y(``!.6$`1"^)`&-!G0`D?4)3
M>#E*``2``@``D`L``#EK``0Y*0`!+X```$">_]POB0!C09T`&%4I$#HX````
M.$$`0'P)$2Y(```,.````)`!`=`X@0!`.*```$O_ZU6``0'X."$!\'P(`Z9.
M@``@?`@"IK^A__20`0`(E"'OL$*?``5_Z`*F?'T;>'R>(W@X@``O2``492^#
M``!!O@`D.&```#B````\OP``.*4UR'^FZWA+_Y8=.&#__T@``#@X80!`.(`0
M`#R_```XI38,/%\``(!".*B`P@``?Z?K>$@`"5DX80!`?\3S>#B@``!+_^K!
M@`$06#@A$%!\"`.FNZ'_]$Z``"!\"`*FD`$`")0A_[`XH```2__JF8`!`%@X
M(0!0?`@#IDZ``"!\"`*FOP'_X)`!``B4(?^@0I\`!7_H`J9\>!MX.R```'R#
M(W@\GP``.(0E'$@`$4%\>QMY0*(`&#Q_```X8S5@.(```3B@`%Q(```L.T`0
M`#N@```X8!`!2``-%7Q\&WE`H@!4/'\``#AC-<`X@``!.*``)CS?``"`QC?@
M.,8`L$@`#ZTX8/__2```J#Q_```X8S7H.(```3B@`$D\WP``@,8WX#C&`+!(
M``^%.Z```$@``$PX````?!SIKD@``"Q_G=``0+X`'#M=$`!_@^-X.)T0`4@`
M#%E\?!MY0:+_L'_<Z:X[O0`!?V/;>$@`$L%\?AMX+X/__T">_\@X````?!SI
MKG]CVWA(`!!%+X/__T"^``P[(/__2```$'Q@1G%!@@`(?!D#>).8``!_(\MX
M@`$`:#@A`&!\"`.FNP'_X$Z``"!\"`*FO\'_^)`!``B4(?^@0I\`!7_H`J9\
M9!MX.````)`!`$`X80!`2__^E7Q^&W@O@___0+X`+$@`"/&`8P``2``(R7QF
M&W@X8```.(```3R_```XI33P2_^4"4@``$0O@P``09X`/(!!`$"(`@``?``'
M="^```!`G@`,/%\``#A"-1PX8```.(```3R_```XI34H?\;S>'Q'$WA+_Y/%
M@&$`0$@`!D5_P_-X@`$`:#@A`&!\"`.FN\'_^$Z``"!\"`*FOZ'_])`!``B4
M(?^P0I\`!7_H`J:0@0!LD*$`<)#!`'20X0!XD0$`?)$A`("100"$?'T;>#A@
M```X00!L.2(`!"^$``!!G@`<.&,``7TB2W@Y*0`$@`(``"^```!`GO_L5&,0
M.CAC``1(``K]?'X;>4"B`"A(``?Q@&,``$@`!\E\9AMX.&```3B```$\OP``
M.*4OZ$O_DPDX8```.$$`;#DB``2``@``D!X``"^```!!G@`D?\OS>#AC``%]
M(DMX.2D`!(`"``"4"P`$+X```$">_^A48!`Z.$```'Q>`2Y_H^MX?\3S>#B@
M``!+_^>1?'T;>'_#\WA(``4M?Z/K>(`!`%@X(0!0?`@#IKNA__1.@``@?`@"
MIK^A__20`0`(E"'_L$*?``5_Z`*F?'X;>'R=(WA_@R``09X`2"^#__]`O@`D
M/'\``#AC(KPX@``"2``+-7Q^&W@X8/__+Y[__T&>`"!_P_-X?Z3K>$@`!]E\
M?1MX?\/S>$@`!XU_H^MX@`$`6#@A`%!\"`.FNZ'_]$Z``"!\"`*FOV'_[)`!
M``B4(?^@0I\`!7_H`J9\>QMX?)PC>'R^*WA\W3-X.`7__'^&`$!!O``X@(4`
M`#B$$`"0A0``@'P``$@`"4V0?```+X,``$"^`!@X8``!.(```3R_```XI3+\
M2_^1I8`<``"`G0``@+X``'RD*%"`>P``?(`B%#BE__](``I-?&,;>4&A`$R`
M>P``2``&W3@`__^0&P``2``&,8!C``!(``8)?&4;>#Q_``"`8S1$.&,`L#R?
M```XA#,42``(C4@`!@DX````D`,``$@``!"`'0``?`,"%)`=``"``0!H."$`
M8'P(`Z:[8?_L3H``('P(`J:_H?_TD`$`")0A_[!(``:)?'T;>#O```-_GA@`
M0+P`&'_#\WA(``91.]X``7^>Z`!!G/_P2``%H3@```"0`P``@`$`6#@A`%!\
M"`.FNZ'_]$Z``"!\"`*F?$``)K^!__"0`0`(D$$`!)0A_U!"GP`%?^@"IGQ\
M&WA\O2MX?(,C>4"B`!P\?P``.&,QX$@`#FDX````?&,;>4&"`+1\?AMY08(`
MJ(@>``!\``=T+X```$&>`)@N'0``?\/S>#B``#I(``X5?'T;>4&"`!!\GNA0
M.[T``4@``!!_P_-X2``$&7QD&W@\?P``.&,QZ'_%\WA_AN-X2__#U7Q^&W@X
M@0!`2``$]2^#``!`G@`@09(`%*`!`$AP``!)+X``24"^``Q_P/-X2```*'_#
M\WA(``)I?[[K>4&"`!2('@``?``'="^```!`GO]T.````'P#`WB``0"X."$`
ML(%A``1\"`.FNX'_\'UP@2!.@``@?`@"II/A__R0`0`(E"'_4$*?``5_Z`*F
M/%\``(!B,;PO@___0+X`9#Q_```X8S#@.($`0$@`!%4O@P``0)X`.*`!`$A4
M``0F.$```&!"@`!_@!``0+X`((`!`'2`00!P?$D#>4""`!`\7P``.````4@`
M``P\7P``.````)`",;P\7P``@&(QO(`!`+@X(0"P?`@#IH/A__Q.@``@?`@"
MIK^!__"0`0`(E"'_L$*?``5_Z`*F/[\``#N]8VQ\?AMX.X,`#XB^```[W@`!
M?Z/K>#R?```XA#!02``-L3N]``)_GN``0)W_X#Q_```X8V-L@`$`6#@A`%!\
M"`.FNX'_\$Z``"!\"`*FD^'__)`!``B4(>^P0I\`!7_H`J9\9AMX?(<C>#AA
M`$`X@!``/+\``#BE(/!(``'5.&$`0$@``DU\9!MX.&$`0#B@``!(``T=2___
M38`!$%@X(1!0?`@#IH/A__Q.@``@?`@"ID*?``5]:`*F/6L``'P(`Z:%BS"0
M?8D#IDZ`!"!\"`*F0I\`!7UH`J8]:P``?`@#IH6+,'1]B0.F3H`$('P(`J9"
MGP`%?6@"ICUK``!\"`.FA8LP6'V)`Z9.@`0@?`@"ID*?``5]:`*F/6L``'P(
M`Z:%BS`\?8D#IDZ`!"!\"`*F0I\`!7UH`J8]:P``?`@#IH6+,"!]B0.F3H`$
M('P(`J9"GP`%?6@"ICUK``!\"`.FA8LP!'V)`Z9.@`0@?`@"ID*?``5]:`*F
M/6L``'P(`Z:%BR_H?8D#IDZ`!"!\"`*F0I\`!7UH`J8]:P``?`@#IH6++\Q]
MB0.F3H`$('P(`J9"GP`%?6@"ICUK``!\"`.FA8LOL'V)`Z9.@`0@?`@"ID*?
M``5]:`*F/6L``'P(`Z:%BR^4?8D#IDZ`!"!\"`*F0I\`!7UH`J8]:P``?`@#
MIH6++WA]B0.F3H`$('P(`J9"GP`%?6@"ICUK``!\"`.FA8LO7'V)`Z9.@`0@
M?`@"ID*?``5]:`*F/6L``'P(`Z:%BR]`?8D#IDZ`!"!\"`*F0I\`!7UH`J8]
M:P``?`@#IH6++R1]B0.F3H`$('P(`J9"GP`%?6@"ICUK``!\"`.FA8LO"'V)
M`Z9.@`0@?`@"ID*?``5]:`*F/6L``'P(`Z:%BR[L?8D#IDZ`!"!\"`*F0I\`
M!7UH`J8]:P``?`@#IH6++M!]B0.F3H`$('P(`J9"GP`%?6@"ICUK``!\"`.F
MA8LNM'V)`Z9.@`0@?`@"ID*?``5]:`*F/6L``'P(`Z:%BRZ8?8D#IDZ`!"!\
M"`*F0I\`!7UH`J8]:P``?`@#IH6++GQ]B0.F3H`$('P(`J9"GP`%?6@"ICUK
M``!\"`.FA8LN8'V)`Z9.@`0@?`@"ID*?``5]:`*F/6L``'P(`Z:%BRY$?8D#
MIDZ`!"!\"`*F0I\`!7UH`J8]:P``?`@#IH6++BA]B0.F3H`$('P(`J9"GP`%
M?6@"ICUK``!\"`.FA8LN#'V)`Z9.@`0@?`@"ID*?``5]:`*F/6L``'P(`Z:%
MBRWP?8D#IDZ`!"!\"`*F0I\`!7UH`J8]:P``?`@#IH6++=1]B0.F3H`$('P(
M`J9"GP`%?6@"ICUK``!\"`.FA8LMN'V)`Z9.@`0@?`@"ID*?``5]:`*F/6L`
M`'P(`Z:%BRV<?8D#IDZ`!"!\"`*F0I\`!7UH`J8]:P``?`@#IH6++8!]B0.F
M3H`$('P(`J9"GP`%?6@"ICUK``!\"`.FA8LM9'V)`Z9.@`0@?`@"ID*?``5]
M:`*F/6L``'P(`Z:%BRU(?8D#IDZ`!"!\"`*F0I\`!7UH`J8]:P``?`@#IH6+
M+2Q]B0.F3H`$('P(`J9"GP`%?6@"ICUK``!\"`.FA8LM$'V)`Z9.@`0@?`@"
MID*?``5]:`*F/6L``'P(`Z:%BRST?8D#IDZ`!"!\"`*F0I\`!7UH`J8]:P``
M?`@#IH6++-A]B0.F3H`$('P(`J9"GP`%?6@"ICUK``!\"`.FA8LLO'V)`Z9.
M@`0@?`@"ID*?``5]:`*F/6L``'P(`Z:%BRR@?8D#IDZ`!"!\"`*F0I\`!7UH
M`J8]:P``?`@#IH6++(1]B0.F3H`$('P(`J9"GP`%?6@"ICUK``!\"`.FA8LL
M:'V)`Z9.@`0@?`@"ID*?``5]:`*F/6L``'P(`Z:%BRQ,?8D#IDZ`!"!\"`*F
M0I\`!7UH`J8]:P``?`@#IH6++#!]B0.F3H`$('P(`J9"GP`%?6@"ICUK``!\
M"`.FA8LL%'V)`Z9.@`0@?`@"ID*?``5]:`*F/6L``'P(`Z:%BROX?8D#IDZ`
M!"!\"`*F0I\`!7UH`J8]:P``?`@#IH6+*]Q]B0.F3H`$('P(`J9"GP`%?6@"
MICUK``!\"`.FA8LKP'V)`Z9.@`0@?`@"ID*?``5]:`*F/6L``'P(`Z:%BRND
M?8D#IDZ`!"!\"`*F0I\`!7UH`J8]:P``?`@#IH6+*XA]B0.F3H`$('P(`J9"
MGP`%?6@"ICUK``!\"`.FA8LK;'V)`Z9.@`0@?`@"ID*?``5]:`*F/6L``'P(
M`Z:%BRM0?8D#IDZ`!"!\"`*F0I\`!7UH`J8]:P``?`@#IH6+*S1]B0.F3H`$
M('P(`J9"GP`%?6@"ICUK``!\"`.FA8LK&'V)`Z9.@`0@?`@"ID*?``5]:`*F
M/6L``'P(`Z:%BRK\?8D#IDZ`!"!\"`*F0I\`!7UH`J8]:P``?`@#IH6+*N!]
MB0.F3H`$('P(`J9"GP`%?6@"ICUK``!\"`.FA8LJQ'V)`Z9.@`0@?`@"ID*?
M``5]:`*F/6L``'P(`Z:%BRJH?8D#IDZ`!"!\"`*F0I\`!7UH`J8]:P``?`@#
MIH6+*HQ]B0.F3H`$('P(`J9"GP`%?6@"ICUK``!\"`.FA8LJ<'V)`Z9.@`0@
M?`@"ID*?``5]:`*F/6L``'P(`Z:%BRI4?8D#IDZ`!"!\"`*F0I\`!7UH`J8]
M:P``?`@#IH6+*CA]B0.F3H`$('P(`J9"GP`%?6@"ICUK``!\"`.FA8LJ''V)
M`Z9.@`0@?`@"ID*?``5]:`*F/6L``'P(`Z:%BRH`?8D#IDZ`!"!\"`*F0I\`
M!7UH`J8]:P``?`@#IH6+*>1]B0.F3H`$('P(`J9"GP`%?6@"ICUK``!\"`.F
MA8LIR'V)`Z9.@`0@?`@"ID*?``5]:`*F/6L``'P(`Z:%BRFL?8D#IDZ`!"!\
M"`*F0I\`!7UH`J8]:P``?`@#IH6+*9!]B0.F3H`$('P(`J9"GP`%?6@"ICUK
M``!\"`.FA8LI='V)`Z9.@`0@?`@"ID*?``5]:`*F/6L``'P(`Z:%BRE8?8D#
MIDZ`!"!\"`*F0I\`!7UH`J8]:P``?`@#IH6+*3Q]B0.F3H`$('P(`J9"GP`%
M?6@"ICUK``!\"`.FA8LI('V)`Z9.@`0@?`@"ID*?``5]:`*F/6L``'P(`Z:%
MBRD$?8D#IDZ`!"!\"`*F0I\`!7UH`J8]:P``?`@#IH6+*.A]B0.F3H`$('P(
M`J9"GP`%?6@"ICUK``!\"`.FA8LHS'V)`Z9.@`0@?`@"ID*?``5]:`*F/6L`
M`'P(`Z:%BRBP?8D#IDZ`!"!\"`*F0I\`!7UH`J8]:P``?`@#IH6+*)1]B0.F
M3H`$('P(`J9"GP`%?6@"ICUK``!\"`.FA8LH>'V)`Z9.@`0@?`@"ID*?``5]
M:`*F/6L``'P(`Z:%BRA<?8D#IDZ`!"!\"`*F0I\`!7UH`J8]:P``?`@#IH6+
M*$!]B0.F3H`$('P(`J9"GP`%?6@"ICUK``!\"`.FA8LH)'V)`Z9.@`0@?`@"
MID*?``5]:`*F/6L``'P(`Z:%BR@(?8D#IDZ`!"!\"`*F0I\`!7UH`J8]:P``
M?`@#IH6+)^Q]B0.F3H`$('P(`J9"GP`%?6@"ICUK``!\"`.FA8LGT'V)`Z9.
M@`0@?`@"ID*?``5]:`*F/6L``'P(`Z:%BR>T?8D#IDZ`!"!\"`*F0I\`!7UH
M`J8]:P``?`@#IH6+)YA]B0.F3H`$('P(`J9"GP`%?6@"ICUK``!\"`.FA8LG
M?'V)`Z9.@`0@?`@"ID*?``5]:`*F/6L``'P(`Z:%BR=@?8D#IDZ`!"!\"`*F
M0I\`!7UH`J8]:P``?`@#IH6+)T1]B0.F3H`$('P(`J9"GP`%?6@"ICUK``!\
M"`.FA8LG*'V)`Z9.@`0@?`@"ID*?``5]:`*F/6L``'P(`Z:%BR<,?8D#IDZ`
M!"!\"`*F0I\`!7UH`J8]:P``?`@#IH6+)O!]B0.F3H`$('P(`J9"GP`%?6@"
MICUK``!\"`.FA8LFU'V)`Z9.@`0@?`@"ID*?``5]:`*F/6L``'P(`Z:%BR:X
M?8D#IDZ`!"!\"`*F0I\`!7UH`J8]:P``?`@#IH6+)IQ]B0.F3H`$('P(`J9"
MGP`%?6@"ICUK``!\"`.FA8LF@'V)`Z9.@`0@?`@"ID*?``5]:`*F/6L``'P(
M`Z:%BR9D?8D#IDZ`!"!\"`*F0I\`!7UH`J8]:P``?`@#IH6+)DA]B0.F3H`$
M('P(`J9"GP`%?6@"ICUK``!\"`.FA8LF+'V)`Z9.@`0@?`@"ID*?``5]:`*F
M/6L``'P(`Z:%BR80?8D#IDZ`!"!\"`*F0I\`!7UH`J8]:P``?`@#IH6+)?1]
MB0.F3H`$('P(`J9"GP`%?6@"ICUK``!\"`.FA8LEV'V)`Z9.@`0@?`@"ID*?
M``5]:`*F/6L``'P(`Z:%BR6\?8D#IDZ`!"!\"`*F0I\`!7UH`J8]:P``?`@#
MIH6+):!]B0.F3H`$('P(`J9"GP`%?6@"ICUK``!\"`.FA8LEA'V)`Z9.@`0@
M?`@"ID*?``5]:`*F/6L``'P(`Z:%BR5H?8D#IDZ`!"!\"`*F0I\`!7UH`J8]
M:P``?`@#IH6+)4Q]B0.F3H`$('P(`J9"GP`%?6@"ICUK``!\"`.FA8LE,'V)
M`Z9.@`0@?`@"ID*?``5]:`*F/6L``'P(`Z:%BR44?8D#IDZ`!"``````7U]D
M>6QD7VUO9%]T97)M7V9U;F-S````7U]D>6QD7VUA:V5?9&5L87EE9%]M;V1U
M;&5?:6YI=&EA;&EZ97)?8V%L;',`````7U]D>6QD7VEM86=E7V-O=6YT``!?
M7V1Y;&1?9V5T7VEM86=E7VYA;64```!?7V1Y;&1?9V5T7VEM86=E7VAE861E
M<@!?7V1Y;&1?3E-,;V]K=7!3>6UB;VQ);DEM86=E`````%]?9'EL9%].4T%D
M9')E<W-/9E-Y;6)O;`````!L:6)O8FIC`%]?;V)J8TEN:70``%1H92!K97)N
M96P@<W5P<&]R="!F;W(@=&AE(&1Y;F%M:6,@;&EN:V5R(&ES(&YO="!P<F5S
M96YT('1O(')U;B!T:&ES('!R;V=R86TN"@``<'-A861M``!!=71H96YT:6-A
M=&EO;B!F86EL960L('EO=2!A<F4@;F]T("5S(&]R(')O;W0@+2!C86YN;W0@
M<W1A<G0@<')O9W)A;6TN"@!3>7-T96T@17)R;W(Z(&EN=F%L:60@87)G=6UE
M;G0@;G5M8F5R("5D+"!M=7-T(&)E(#,@;W(@;6]R90H`````<F]O=`````!C
M<#)T96UP;F%M``!.;W0@86QL;W=E9"!U<V5R("=R;V]T)PH`````;',``"]B
M:6XO;',`8V%T`"]B:6XO8V%T`````&-P```O8FEN+V-P`&-H;6]D````+V)I
M;B]C:&UO9```;78``"]B:6XO;78`=&]U8V@````O=7-R+V)I;B]T;W5C:```
M<FT``"]B:6XO<FT`;6MD:7(````O8FEN+VUK9&ER``!R;61I<@```"]B:6XO
M<FUD:7(``&9I;&4`````+W5S<B]B:6XO9FEL90```&QI<W0`````+2UI;BUB
M;&]C:W,`9FEL95]E>&ES=',`)6D*`')E86QP871H`````%5N86)L92!T;R!R
M96-I979E(')E86P@<&%T:"!F;W(@)R5S)PH```!S:7IE`````%5N86)L92!T
M;R!G970@<VEZ92!F;W(@)R5S)PH`````)6QL9`H```!7<F]N9R!C;VUM86YD
M(&YA;64@;W(@<&%R86UE=&5R(&YU;6)E<CH@)7,*`%5N86)L92!T;R!E>&5C
M=71E("5S(&-O;6UA;F0Z(&1A96UO;B!K:6QL960@8GD@<VEG;F%L("5I"@``
M`%5N86)L92!T;R!E>&5C=71E("5S(&-O;6UA;F0Z(&1A96UO;B!S=&]P<&5D
M(&)Y('-I9VYA;"`E:0H``$5R<F]R(&]C8W5R960@9'5R:6YG("5S(&-O;6UA
M;F0N"@```&9I;&5S````9&ER<P````!B;W1H`````%=R;VYG(&-O;6UA;F0@
M;W!T:6]N('1O(&QI<W0@9FEL97,*`'-T870@9F%I;&5D.B`E<PH`````;W!E
M;F1I<B!F86EL960Z("5S"@`E<PDE;'4))6QL=0D`````)7,))7,)```E,#-O
M"@```"`H8G)O:V5N('-Y;6QI;FLI````+W1M<"]P<V$M875T;W)E<W!O;F1E
M<BU86%A86%@```!P<V$M=&5M<"UF:6QE````)7,O)7,M6%A86%A8`````$5R
M<F]R(&1U<FEN9R!T96UP;W)A<GD@;F%M92!C<F5A=&4*`%5N86)L92!T;R!C
M;W!Y('1H92!F:6QE("5S('1O("5S"@```$-A;B=T(&%L;&]C871E(&UE;6]R
M>2!F;W(@97)R;W(@;65S<V%G90`*4WES=&5M(&5R<F]R("5D.B`E<P`````E
M<SH@`````$5R<F]R.B`E<R!N;W0@9&5F:6YE9"!I;B!P<F]D=6-T(&-O;F9I
M9R!F:6QE`````%!23T150U1?4D]/5%]$``!%<G)O<CH@4%)/1%5#5%]23T]4
M7T0@;F]T(&1E9FEN960*``!(5%101%]62$]35%-?1```17)R;W(Z($A45%!$
M7U9(3U-44U]$(&YO="!D969I;F5D"@``2%144$1?0T].1E]$`````$5R<F]R
M.B!(5%101%]#3TY&7T0@;F]T(&1E9FEN960*`````$A45%!$7TE.0TQ51$5?
M1`!%<G)O<CH@2%144$1?24Y#3%5$15]$(&YO="!D969I;F5D"@!(5%101%]"
M24Y?1`!%<G)O<CH@2%144$1?0DE.7T0@;F]T(&1E9FEN960*`%%-04E,7U)/
M3U1?1`````!%<G)O<CH@44U!24Q?4D]/5%]$(&YO="!D969I;F5D"@````!1
M34%)3%]-04E,3D%-15-?1````$5R<F]R.B!134%)3%]-04E,3D%-15-?1"!N
M;W0@9&5F:6YE9`H```!&5%!$7T-/3D8```!%<G)O<CH@1E101%]#3TY&(&YO
M="!D969I;F5D"@```$944$1?0T].1E])3D,```!%<G)O<CH@1E101%]#3TY&
M7TE.0R!N;W0@9&5F:6YE9`H```!&5%!$7T))3E]$``!.04U%1%]254Y?4D]/
M5%]$`````$5R<F]R.B!.04U%1%]254Y?4D]/5%]$(&YO="!D969I;F5D"@``
M``!714)?4U1!5`````!%<G)O<CH@5T5"7U-4050@;F]T(&1E9FEN960*````
M`$Q/1U)/5$%410```$5R<F]R.B!,3T=23U1!5$4@;F]T(&1E9FEN960*````
M35E344Q?5D%27T0`17)R;W(Z($U94U%,7U9!4E]$(&YO="!D969I;F5D"@!-
M65-13%]"24Y?1`!%<G)O<CH@35E344Q?0DE.7T0@;F]T(&1E9FEN960*`%!'
M4U%,7T))3E]$`$5R<F]R.B!01U-13%]"24Y?1"!N;W0@9&5F:6YE9`H`4$=3
M44Q?1$%405]$`````$5R<F]R.B!01U-13%]$051!7T0@;F]T(&1E9FEN960*
M`````$U!24Q-04Y?4D]/5%]$``!%<G)O<CH@34%)3$U!3E]23T]47T0@;F]T
M(&1E9FEN960*``!-04E,34%.7U9!4E]$````17)R;W(Z($U!24Q-04Y?5D%2
M7T0@;F]T(&1E9FEN960*````4%)/1%5#5%]20U]$`````$5R<F]R.B!04D]$
M54-47U)#7T0@;F]T(&1E9FEN960*`````$1535!?1```17)R;W(Z($1535!?
M1"!N;W0@9&5F:6YE9`H``$-!5$%,24Y!7TA/344```!%<G)O<CH@0T%404Q)
M3D%?2$]-12!N;W0@9&5F:6YE9`H```!$4E=%0E]23T]47T0`````17)R;W(Z
M($125T5"7U)/3U1?1"!N;W0@9&5F:6YE9`H`````1%)714)?151#7T0`17)R
M;W(Z($125T5"7T540U]$(&YO="!D969I;F5D"@!#55),7T-!7T)53D1,15]&
M24Q%`"]A9&UI;B]C;VYF+W-E='1I;F=S`````"]A9&UI;B]B:6XO9&YS;6YG
M````+V%D;6EN+V)I;B]M86EL;6YG```O861M:6XO8FEN+W5S97)M;F<``"]A
M9&UI;B]B:6XO9G!?=W)A<'!E<@```"]A9&UI;B]B:6XO<FU?<&1?=7-R````
M`"]A9&UI;B]B:6XO;6%K95]V<G0`+V%D;6EN+V)I;B]W96)S<G9M;F<`````
M+V%D;6EN+V)I;B]R;5]F<FT````O861M:6XO8FEN+VEN=&5R9F%C90`````O
M861M:6XO8FEN+V1O;6%I;FUN9P`````O<V)I;B]C:&MC;VYF:6<`+W9A<B]C
M97)T:69I8V%T97,```!%<G)O<B!O8V-U<G)E9"!W:&EL92!L;V-K:6YG('1H
M92!F:6QE("5S"@```%5N86)L92!T;R!O<&5N(&9I;&4@)7,Z("5S``!%<G)O
M<B!W:&EL92!C;W!Y:6YG(&9I;&4@)7,@=&\@)7,Z("5S````56YA8FQE('1O
M(&-L;W-E(&9I;&4@)7,Z("5S"@````!5;F%B;&4@=&\@8V]P>2!F:6QE("5S
M('1O("5S.B`E<PH```!%<G)O<B!O8V-U<G)E9"!W:&EL92!U;FQO8VMI;F<@
M=&AE(&9I;&4@)7,*`&-O<'E?9FEL95]A=&]M:6,H)7,@+3X@)7,I.B!O<&5N
M(&9A:6QE9`!!;&QO8V%T:6]N(&9A:6QE9````"Y86%A86%@`8V]P>5]F:6QE
M7V%T;VUI8R@E<R`M/B`E<RDZ(&UK<W1E;7`@9F%I;&5D``!C;W!Y7V9I;&5?
M871O;6EC*"5S("T^("5S*3H@=W)I=&4@9F%I;&5D`````&-O<'E?9FEL95]A
M=&]M:6,H)7,@+3X@)7,I.B!R96%D(&9A:6QE9`!C;W!Y7V9I;&5?871O;6EC
M*"5S("T^("5S*3H@8VAO=VX@9F%I;&5D`````&-O<'E?9FEL95]A=&]M:6,H
M)7,@+3X@)7,I.B!C:&UO9"!F86EL960`````8V]P>5]F:6QE7V%T;VUI8R@E
M<R`M/B`E<RDZ(&9L=7-H(&9A:6QE9`````!C;W!Y7V9I;&5?871O;6EC*"5S
M("T^("5S*3H@<F5N86UE(&9A:6QE9````"X````N+@``56YA8FQE('1O(&=E
M='!W;F%M(&9O<B!U<V5R("5S``!G971G<FYA;2@E<RDZ("5S`````&=E=&=R
M9VED*"5D*3H@)7,`````)60``%5N86)L92!T;R!F:6YD('5I9"!F;W(@=7-E
M<B`E<SH@)7,``"5U``!5;F%B;&4@=&\@<V%V92!C=7)R96YT('!A=&@*````
M`%-U8V@@<&%T:"`G)7,G(&1O97,@;F]T(&5X:7-T"@``56YA8FQE('1O(&=E
M="!R96%L('!A=&@@:6YF;W)M871I;VX*`````"\```!%<G)O<CH@96UP='D@
M57-E<@```$U!6%5)1"!R96%C:&5D"@!P<V%C;&X``$=R;W5P("5S(&YO="!F
M;W5N9```+W5S<B]B:6XO9F%L<V4``&YI=71I;"`M8W)E871E("\@+W5S97)S
M+R5S("8F(`EN:75T:6P@+6-R96%T97!R;W`@+R`O=7-E<G,O)7,@=6ED("5U
M("8F(`EN:75T:6P@+6-R96%T97!R;W`@+R`O=7-E<G,O)7,@:&]M92`B)7,B
M("8F(`EN:75T:6P@+6-R96%T97!R;W`@+R`O=7-E<G,O)7,@<VAE;&P@(B5S
M(B`F)B`);FEU=&EL("UC<F5A=&5P<F]P("\@+W5S97)S+R5S(&=I9"`E9"`F
M)B`);FEU=&EL("UC<F5A=&5P<F]P("\@+W5S97)S+R5S('!A<W-W9"`B*B(`
M<'-A<V5R=@!%<G)O<CH@96UP='D@=7-E<@```"]E=&,O9G1P=7-E<G,```!5
M;F%B;&4@=&\@96YA8FQE(&9T<"!A8V-E<W,*`````&5C:&\@)WEE<R=\8W)O
M;G1A8B`M<B`M=2`G)7,G````;FEU=&EL("UD97-T<F]Y("\@+W5S97)S+R5S
M`"]T;7`O8W)O;G1A8BUT;7`M6%A86%A86`````!%<G)O<CH@96UP='D@57-E
M<B!O<B!.97=5<V5R`````&-R;VYT86(@+6P@+74@)R5S)P``<@```$524D]2
M.B!5;F%B;&4@=&\@;W!E;B!C<F]N=&%B(&]F('5S97(@)R5S)PH`15)23U(Z
M(%5N86)L92!T;R!C<F5A=&4@=&5M<"!F:6QE("<E<R<@;F%M92!T;R!S=&]R
M92!U<V5R(&-R;VYT86(*``!E8VAO("=Y)R!\(&-R;VYT86(@+7(@+74@)R5S
M)P```&-R;VYT86(@+74@)R5S)R`G)7,G`````'-E='-I9"@I(&9A:6QE9``O
M9&5V+VYU;&P```!%<G)O<B!O8V-U<F5D(&1U<FEN9R!C;&]S92!U<V5R("<E
M<R<@<V5S<VEO;CH@)7,*````56YA8FQE('1O(&-L;W-E('5S97(@)R5S)R!S
M97-S:6]N.B!D865M;VX@:VEL;&5D(&)Y('-I9VYA;"`E:0H``%5N86)L92!T
M;R!C;&]S92!U<V5R("<E<R<@<V5S<VEO;CH@9&%E;6]N('-T;W!P960@8GD@
M<VEG;F%L("5I"@!#;&]S92!U<V5R("<E<R<@<V5S<VEO;B!F86EL960*`&%L
M;&]W````9&5N>0````!C<F]N=&%B;6YG``!%<G)O<CH@96UP='D@57-E<B!O
M<B!(;VUE1&ER`````$5R<F]R.B!E;7!T>2!5<V5R(&]R(%-H96QL```O=7-R
M+V)I;B]C:'!A<W,@+7,@)R5S)R`G)7,G`````%5S97(@)7,@;F]T(&9O=6YD
M````0V%N;F]T(&-H9&ER('1O("5S(&AO;65D:7(@)7,```!#86YN;W0@<G5N
M(&%S(&9O<F)I9&1E;B!U:60Z("5D"@````!5;F%B;&4@=&\@:6YI="!N97<@
M9W)O=7!S(&9O<B!U<V5R("5S.B`E<P```$9A:6QE9"!T;R!S971G:60Z("5D
M"@```$9A:6QE9"!T;R!S971U:60Z("5D"@```"]B:6XO8F%S:````"]B:6XO
M<V@`)7,E<P`````E<R@I.B!U<V5R("5S(&YO="!F;W5N9`!S971U<%]C:')O
M;W0`````<V5T=7!?8VAR;V]T.B!C:&1I<B@E<RD@9F%I;&5D``!E=&,`)7,H
M*3H@3F\@8VAR;V]T960@<VAE;&P@9F]R("5S(&9O=6YD`````"]B:6XO9W)E
M<````"]U<W(O8FEN+V=R97`````O=7-R+VQO8V%L+V)I;B]G<F5P`&UK7V=R
M;W5P.B!G<F5P(&YO="!F;W5N9"P@;F]T('=R:71I;F<@9W)O=7!S(&9I;&4*
M``!E=&,O9W)O=7````!M:U]G<F]U<#H@;W!E;B@O971C+V=R;W5P*2!F86EL
M960```!><'-A<V5R=CI\7EM>.ETJ.EM>.ETJ.B@P?"5D*3I\6RPZ725S*"Q;
M7CI=*GPI)``M10``+V5T8R]G<F]U<```;6M?9W)O=7`Z(&=R97`@97AE8W5T
M:6]N(&9A:6QE9`!U;FQI;FLH)7,I(&9A:6QE9````%5N86)L92!T;R!F;W)K
M```O=7-R+V)I;B]N:75T:6P`+W5S97)S+R5S````+6-R96%T97!R;W``<&%S
M<W=D```J````875T:&5N=&EC871I;VY?875T:&]R:71Y)SM"87-I8SLG````
M3F]T(&EM<&QE;65N=&5D.B`E<P!E;F%B;&5?=7-E<@!%<G)O<CH@)7,@;F]T
M(&1E9FEN960````O<')I=F%T92]E=&,O<'-A+W!S82YC;VYF````)7,O=F%R
M+VQO8VLO9FEL97,O)7,`````06X@97)R;W(@;V-C=7)E9"!D=7)I;F<@8VQO
M<VEN9R`G)7,G(&9I;&4Z("5S"@``)7,``%5N86)L92!T;R!O<&5N(&9I;&4@
M(B5S(CH@)7,N````0V%N;F]T(&%L;&]C871E(&UE;6]R>3H@)7,``%]?9&5L
M971E9````%5N86)L92!T;R!G970@96YT<GD@)7,Z("5S"@!5;F%B;&4@=&\@
M8VAO=VX@9&ER96-T;W)Y(&5N=')Y("5S.B`E<PH`56YA8FQE('1O(&=E="!F
M:6QE(&1E<V-R:7!T;W(@;V8@8W5R<F5N="!D:7(Z("5S"@```%5N86)L92!T
M;R!O<&5N(&1I<B`E<SH@)7,*``!5;F%B;&4@=&\@8VAA;F=E(&1I<B`E<SH@
M)7,*`````%5N86)L92!T;R!C:&5C:R!D:7)E8W1O<GD@96YT<GD@)7,Z("5S
M"@!5;F%B;&4@=&\@<F5S=&]R92`F(&-L;W-E(&-U<G)E;G0@9&ER.B`E<PH`
M`%5N86)L92!T;R!C;&]S92!D:7(@)7,Z("5S"@!5;F%B;&4@=&\@8VAO=VX@
M9&ER("5S.B`E<PH`56YA8FQE('1O(&-H;6]D(&5N=')Y("5S.B`E<PH```!5
M;F%B;&4@=&\@8VAM;V0@9&ER96-T;W)Y(&5N=')Y("5S.B`E<PH`56YA8FQE
M('1O(&-H;6]D(&1I<B`E<SH@)7,*`%5N86)L92!T;R!U;FQI;FL@96YT<GD@
M)7,Z("5S"@``56YA8FQE('1O('5N;&EN:R!D:7)E8W1O<GD@96YT<GD@)7,Z
M("5S"@````!5;F%B;&4@=&\@<F5M;W9E(&1I<B`E<SH@)7,*`````$ET)W,@
M82!R96=U;&%T(&5N=')Y*&YO="!D:7)E8W1O<GDI.B`E<PH`````56YA8FQE
M('1O(')E;F%M92!D:7)E8W1O<GD@96YT<GD@)7,@=&\@)7,Z("5S"@``9&5F
M97)R961?<F5M;W9E*"DZ(&YO="!S=7!P;W)T960@9&ER96-T;W)Y(&9O<B!D
M969E<G)E9"!R96UO=F4Z("5S"@!D969E<G)E9%]R96UO=F4H*3H@8V%N)W0@
M<W1A="!D:7)E8W1O<GDL('-K:7`@:70N"@``)7,O)7-86%A86%@`9&5F97)R
M961?<F5M;W9E*"DZ(%5N86)L92!C<F5A=&4@9FEL96YA;64@9F]R(&1E;&5T
M92!D:7)E8W1O<GD*`&1E9F5R<F5D7W)E;6]V92@I.B!R96YA;64@9&ER("5S
M('1O("5S"@!D969E<G)E9%]R96UO=F4H*3H@56YA8FQE('1O(')E;F%M92!D
M:7)E8W1O<GD*``!5;F%B;&4@=&\@<W1A="!F:6QE("5S+"!S:VEP<&5D"@``
M```M<F8`0V%N)W0@<F5M;W9E(&1I<F5C=&]R>2`E<R`H=VEL;"!T<GD@:6X@
M;F5X="!T:6UE*0H``"T```!%<G)O<B!O8V-U<G)E9"!W:&EL92!L;V-K:6YG
M('1H92!F:6QE("5S.B`E<PH```!F:6QE7W-T<CH@56YA8FQE('1O('-T870@
M9FEL92`E<SH@)7,*````80```"5S+G1M<```=P```%5N86)L92!T;R!O<&5N
M(&9I;&4@)7,Z("5S"@!5;F%B;&4@=&\@<F5N86UE(&9I;&4@)7,Z("5S"@``
M`&-A;FYO="!W<FET92!A(&QI;F4@=&\@)7,N=&UP````17)R;W(@=VAI;&4@
M<F5N86UE(&9I;&4@)7,Z("5S"@!F:6QE7W-T<CH@15)23U(Z(%5N86)L92!T
M;R!C:&]W;B!F:6QE("5S.B`E<P````!F:6QE7W-T<CH@15)23U(Z(%5N86)L
M92!T;R!C:&UO9"!F:6QE("5S.B`E<P````!%<G)O<B!O8V-U<G)E9"!W:&EL
M92!U;FQO8VMI;F<@=&AE(&9I;&4@)7,Z("5S"@!5;F%B;&4@=&\@9G!U=',@
M=&\@9FEL92`E<SH@)7,*``H```!5;F%B;&4@=&\@=')U;F-A=&4@;W(@8W)E
M871E(&9I;&4@)7,Z("5S`````%5N86)L92!T;R!C<F5A=&4@9FEL92`E<SH@
M)7,`````0V%N;F]T(&-R96%T92!D:7)E8W1O<GD@)7,Z("5S``!#86YN;W0@
M8VAO=VX@)7,Z("5S`$524D]2.B!5;F%B;&4@=&\@;6MD:7(@)7,Z("5S"@``
M15)23U(Z(%5N86)L92!T;R!C:&]W;B`E<SH@)7,*``!%4E)/4CH@56YA8FQE
M('1O(&-H;6]D("5S.B`E<PH``$1I<F5C=&]R>2!R96YA;64@97)R;W(Z('1A
M<F=E="!D:7)E8W1O<GD@)7,@86QR96%D>2!E>&ES=',N"@````!296UA;6EN
M9R`E<R!T;R`E<R!F86EL960Z("5S"@```$524D]2.B!U;F%B;&4@=&\@8VAO
M=VX@)7,Z("5S"@``15)23U(Z('5N86)L92!T;R!C:&UO9"`E<SH@)7,*``!5
M;F%B;&4@=&\@8VQO<V4@=&AE(&9I;&4Z("5S"@```&UA;&QO8R@I(&9A:6QE
M9#H@)7,`)7,@97AE8W5T:6]N(&9A:6QE9#H*)7,`)7,@97AE8W5T:6]N(&9A
M:6QE9"`H;F\@;W5T<'5T*0!F;W)K7V5X96-V7V=E=&]U=&5R<CH@<&EP92@I
M(&9A:6QE9`!F;W)K7V5X96-V7V=E=&]U=&5R<CH@9F-N=&PH3U].3TY"3$]#
M2RD@9F%I;&5D``!F;W)K7V5X96-V7W!I<&5S.B!F;W)K*"D@9F%I;&5D`&9O
M<FM?97AE8W8Z(&1U<"@I(&9A:6QE9#H@)7,*````9F]R:U]E>&5C=CH@97AE
M8W8H(B5S(BD@9F%I;&5D.B`E<PH`=F%L=65S(#`L,2PR(&YO="!A;&QO=V5D
M(&9O<B!V87)I86)L97,@9F1?:6X@)B!F9%]O=70*``!%<G)O<B!O8V-U<F5D
M(&1U<FEN9R!W86ET:6YG('1H92!C:&EL9"!P<F]C97-S('=I=&@@<&ED.B`E
M9#H@)7,*`````%1H92!C:&EL9"!P<F]C97-S('=I=&@@<&ED("5D(&MI;&QE
M9"!B>2!S:6=N86P@)6D*``!4:&4@8VAI;&0@<')O8V5S<R!W:71H('!I9"`E
M9"!S=&]P<&5D(&)Y('-I9VYA;"`E:0H`17)R;W(@;V-C=7)E9"!D=7)I;F<@
M97AE8W8H*3H*)7,`````+"!P;W-S:6)L92!R96%S;VX@+2!.54Q,('!A<F%M
M971E<B!I<R!A8G-E;G0@:6X@=71I;%]E>&5C*'!A=&@L(&%R9S$L(&%R9S(L
M($Y53$PI(&-A;&PN"@`````N"@``17)R;W(@;V-C=7)E9"!D=7)I;F<@9F]R
M:R@I.@HE<P!#86YN;W0@<F5A9"!C:&EL9"!O=71P=70Z"B5S`````&5R<F]R
M.@HE<P```'5T:6QI='D@)7,@9F%I;&5D("AR97-U;'0])60I.@HE<P```$-A
M;FYO="!E>&5C("5S.@HE<P``0V%N;F]T(&9O<FLH*3H*)7,```!#86YN;W0@
M86QL;V-A=&4@8G5F9F5R.@HE<P``571I;&ET>2!N86UE("<E<R<@:7,@:6YV
M86QI9"X@57-E(&]N;'D@=71I;&ET>2!N86UE('=I=&AO=70@<&%T:"X````E
M<R]A9&UI;B]B:6XO)7,`<&]P96Y?97AE8SH@9F%I;&5D('1O(&5X96-U=&4@
M8V]M;6%N9#H@9F]R:R!O<B!P:7!E(&-A;&QS(&9A:6QE9"P@;W(@8V%N;F]N
M(&%L;&]C871E(&UE;6]R>0H`````<&]P96Y?97AE8SH@9F%I;&5D('1O(&%L
M;&]C871E(&UE;6]R>0H``'!O<&5N7V5X96,Z('=A<FYI;F<Z(&9A:6QE9"!T
M;R!A;&QO8V%T92!M96UO<GD@9F]R(&-O;6UA;F0@;W5T<'5T(&)U9F9E<@H`
M``!P;W!E;E]E>&5C.B!F86EL960@=&\@97AE8W5T92!C;VUM86YD.B`E<PH`
M`&5R<F]R.B!N;VYE`'!O<&5N7V5X96,Z(&-O;6UA;F0@9F%I;&5D(&-O9&4Z
M("5D("P@)7,*````0V%N;F]T(&%L;&]C871E(&UE;6]R>0``9F]R:U]E>&5C
M*CH@<F5A9"AP:7!E*2!F86EL960Z("5S"@``4$%42``````E+BIS+R5S`"]D
M978O:&1V,0```"4P,G@```````````````````````"MH```(<P``"`P```?
M3```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````P\@``-`H``#0/`````#_____````
M```````````````````!`W0``0-X``#0'`````````````#0*```T"```!\D
M```?)```'R0``!\D```?)```'R0``!\D```?)```'R0``!\D```?)```'R0`
M`!\D```?)```'R0``!\D```?)```'R0``!\D```?)```'R0``!\D```?)```
M'R0``!\D```?)```'R0``!\D```?)```'R0``!\D```?)```'R0``!\D```?
M)```'R0``!\D```?)```'R0``!\D```?)```'R0``!\D```?)```'R0``!\D
M```?)```'R0``!\D```?)```'R0``!\D```?)```'R0``!\D```?)```'R0`
M`!\D```?)```'R0``!\D```?)```'R0``!\D```?)```'R0``!\D```?)```
M'R0``!\D```?)```'R0``!\D```?)```'R0``!\D```?)```'R0``!\D```?
M)```'R0``!\D```?)```'R0``!\D```?)```'R0``!\D```?)```'R0``!\D
M```?)```'R0``!\D```?)```'R0``!\D```?)```'R0``!\D```?)```'R0`
M`!\D```?)```'R0``!\DC^`0`(_@$`@``````````````````!\D````````
MP.P``,#X````````P7P``,&(``#!F````````,*4``#"L```O````,*D``#"
MO```PL0```````#"E```PK```+P```#"I```PL@`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````#7QD`0`````98```#82`````````````
M#::`````````````#;AD`0`````9H```#;ED`0`"```9H```#=)D`0`"```9
MH```#?`\````````````#?\.!@````#0$`````!$`0"U```9H`````!$`0#`
M```9Q`````!$`0##```9R`````!$`0#$```9T`````!$`0#%```9V`````!$
M`0#'```9X`````!$`0#(```9]`````!$`0#)```9_`````!$`0#*```:$```
M``!$`0#-```:&`````!$`0#4```:'`````!$`0#5```:,`````!$`0#>```:
M.`````!$`0#B```:/`````!$`0#P```:0`````!$`0#Q```:4`````!$`0#R
M```:7`````!$`0#U```:8`````!$`0#W```:<`````!$`0#Z```:B`````!$
M`0#Y```:E`````!$`0#]```:I`````!$`0#^```:K`````!$`0$````:O```
M``!$`0$+```:Q`````!$`0$0```:Z`````!$`0#Y```;``````!$`0$0```;
M'`````!$`0$0```;/`````!$`0$0```;/`````!$`0$0```;7`````!$`0#R
M```;7`````!$`0#R```;?`````!$`0#P```;?`````!$`0#P```;G`````!$
M`0#B```;G`````!$`0#B```;O`````!$`0#>```;O`````!$`0#>```;W```
M``!$`0#-```;W`````!$`0#-```;_`````!$`0#````;_`````!$`0#````<
M'```#B\D`0"U```9H```#D.`````````````#D]```"R````'```#GI```"S
M````'0``#J)```"T````'@``#JZ`````````````#KF`````````````#L5`
M``"W````"P``#LY```"Y````!@``#M>```"\````.```#O#``0`````9H```
M#O'@`0`````<'```#O(D```````"?```#O,.`0`````<'`````!$`0$K```<
M'`````!$`0$N```<-`````!$`0$P```<1`````!$`0$Q```<4`````!$`0$N
M```<9`````!$`0$N```<A```#PDD`0$K```<'```#R6```$L````.```#RW`
M`0`````<'```#R[@`0`````<A```#R\D````````:```#S`.`0`````<A```
M``!$`0$_```<A`````!$`0%#```<A`````!$`0%$```<E`````!$`0%#```<
MK`````!$`0%(```<N```#SXD`0$_```<A```#V!```$^`````P``#VQ```%`
M`````@``#W5```%!`````P``#X'``0`````<A```#X+@`0`````<O```#X,D
M````````.```#X0.`0`````<O`````!$`0%-```<O`````!$`0%1```<O```
M``!$`0%-```<T`````!$`0%2```<U`````!$`0%-```<[`````!$`0%1```<
M\`````!$`0%2```=!`````!$`0%4```=)```#Y<D`0%-```<O```#[!```%,
M`````P``#[I```%,````!```#\0D````````;```#\4.`0`````=*`````!$
M`0%9```=*`````!$`0%C```=0`````!$`0%E```=4`````!$`0%G```=8```
M``!$`0%I```=<`````!$`0%K```=@`````!$`0%P```=D`````!$`0%Q```=
MG`````!$`0%R```=J`````!$`0%S```=M`````!$`0%T```=P`````!$`0%W
M```=S`````!$`0%X```=U`````!$`0%Z```=Z`````!$`0%[```=^`````!$
M`0%\```=_`````!$`0%_```>#`````!$`0&"```>)`````!$`0&$```>0```
M``!$`0&%```>3`````!$`0&&```>5`````!$`0&'```>9`````!$`0%X```>
M:`````!$`0&,```><`````!$`0%\```>A`````!$`0%\```>I`````!$`0%[
M```>I`````!$`0%[```>Q`````!$`0%C```>Q`````!$`0%C```>Y```#]4D
M`0%9```=*```#^M```%:````'@``$#"`````````````$$5```%:````'0``
M$%.```%<````.```$'^```%=````/```$*V```%>````0```$.V```%?````
M1```$1V```%@````2```$5#``0`````=*```$5'@`0`````>Y```$5(D````
M```!O```$5,F!@!Y``#0$```$8D@```M````````$9<@```N````````$:4@
M```O````````$;0@```P````````$<9D`0`````>Y```$<<."0````#2H```
M$>P.!0````"N@```$?H."0````#2I````"`>`0`````?/````#,>`0`````>
MY````$4>`0`````9H````%8>`0`````?)```$A,.`0`````?3```$C8.`0``
M```@,```$EP.`0`````QD```$F8."P````#3#```$FX."P````#C#```$G8.
M"P````#S#```$GX.`0````!7P```$H@.`0````!9&```$I0.`0````!9?```
M$IT.!0````#"E```$J0.!0````#"I```$K`."P````$##```$K@."P````$#
M$```$L4.!@````#0O```$M0.`0````![N```$N,.`0````!]1```$O$.`0``
M``"0T```$P@.`0````"<D```$Q4.!@````#0R```$QP."P````$#%```!7`/
M!@````#0>```!7\/!@````#0)```!8\/!@````#0M```!9X/!@````#0A```
M"P`/!@````#0N```!;,/!@````#0C```!;L/!@````#0L```!<8/!@````#0
M@```!=,/!@````#0?```!>$/!@````#04```!>D/!@````#0F```!?4/!@``
M``#02```!@$/!@````#00```!@P/!@````#01```!AL/!@````#0-```!B@/
M!@````#0+```!C8/!@````#0,```!D</!@````#0*```!E</!@````#0K```
M!F(/!@````#06```!FT/!@````#0;```!GT/!@````#0<```!HP/!@````#0
MD```!I4/!@````#0H```!I\/!@````#08```!JP/!@````#07```!KD/!@``
M``#03`````0/!@`0``#0``````P/!@`0``#0!```!LL/!@````#09```!M@/
M!@````#0:```!N8/!@````#0=```!O0/!@````#0(````XX/!@````#0'```
M!P0/!@````#0/```!Q</!@````#0.```!R4/!@````#0J```!RT/!@````#0
MG```!S@/!@````#0B```!T</!@````#0E```!U`/!@````#0I```!UL/!@``
M``#05````'4/`0`````AS````!0/!@`0``#0#````-4#```0```0````":(/
M`0````!B5````Z$/`0`````R`````/$/#``0``$#0````0@/#``0``$#1```
M`24/#``0``$#2```"Q`/`0````!FX```"QP/`0````!C8````4L/#``0``$#
M3```#`(/`0````"=B````\T/`0`````[.```!Y@/`0`````^0```"`T/`0``
M``!",````U0/`0`````M9```"ZH/`0````!\5```"[T/`0````!\S```";@/
M`0````!PU````]@/#`````$#=```".8/`0````!:)```"R@/`0````!R%```
M`5X/#``0``$#4````7@/#``0``$#5````9,/#``0``$#6````;`/#``0``$#
M7````<H/#``0``$#8````>L/#``0``$#9````@T/#``0``$#:````C$/#``0
M``$#;```#`T/`0````"<$```"/0/`0````!;F````$T/!@`0``#0"```!1D/
M`0`````P1````^T/#`````$#>````V`/`0`````KR```"\H/`0````"`H```
M"=</`0````!S>```"Y0/`0````!SJ```"0$/`0````!6$```#!H/`0````"=
MX```">$/`0````"!X```#"@/`0````"$0```##L/`0````"%6```#%$/`0``
M``""8```#&$/`0````":^```">P/`0````"&=```"VT/`0````"5@```#'4/
M`0````".)```#(0/`0````"'E```#)</`0````")W```#*T/`0````"49```
M#,,/`0````"#>```#-,/`0````"-"```!\(/`0````!@,````_H/`0````!`
MI```""0/`0````!%7```"#,/`0````!$W```"$0/`0````!%W```!`@/`0``
M``!'.```"MD/`0````"?_```"+L/`0````!([```"%(/`0````!&0```!!@/
M`0````!&L```"1$/`0````!:!```"I0/`0````!@$```!\T/`0````!?Y```
M"%\/`0````!$:```!$</`0````!(Q```",H/`0````!'P````W`/`0`````H
MP````WP/`0`````K^````X4/`0`````J)````G(/`0`````BK```"]H/`0``
M``!^L```"^0/`0````!^2```!&</`0`````NF```"J</`0````!?C```!]@/
M`0````!@\```"K8/`0````!A2```"L`/`0````!A'```"_`/`0````"!@```
M!(,/`0````!4R```#.4/`0````"7F```#/`/`0````"8T```"&H/`0````!#
M?```"B\/`0````">^```!(T/`0````!$%```#0`/`0````":.```#0P/`0``
M``"8]```!*$/`0`````Q@```#6H/`0````"?E```!V4/`0````!<3```!W`/
M`0````!;Y````G@/#``0``$#<```"X$/`0````!_Y```!_4/`0````!@4```
M"D,/`0````!J5```"SP/`0````!MF```"28/`0````!6S```"U4/`0````!C
M#```"30/`0````!0C```"4D/`0````!2.```"54/`0````!*L```"5X/`0``
M``!,1```"6</`0````!2V```"7$/`0````!-U```"7H/`0````!3P```"FP/
M`0````"6B```#2(/`0````"8.```"N4/`0````!BE````&\/`0`````98```
M#6X!``,!````````"'<!``0``````````Y@!``0!`````````)L!``0!````
M`````HD!``0`````````"84!``0!````````!24!``0``````````+X!``0`
M`````````IH!``0!`````````KT!``0!````````"9$!``0!`````````N,!
M``0!`````````O$!``0!`````````Q<!``0!`````````S\!``0!````````
M"9@!``0!`````````.D!``0!````````!2L!``0!`````````T8!``0!````
M`````ZX!``0!`````````[4!``0!````````";$!``0!`````````[P!``0!
M`````````\,!``0!`````````]\!``0!`````````E(!``0`````````"<D!
M``0!`````````^4!``0!`````````ED!``0!````````"V4!``0!````````
M!ZH!``0!````````![(!``0!````````"G<!``0!````````#3(!``0!````
M````!34!``0!````````"=`!``0!````````![H!``0!````````"M(!``0!
M````````"G\!``0!`````````_0!``0!````````!3T!``0!````````!48!
M``0!````````!4T!``0!````````"H8!``0!`````````TX!``0!````````
M"HT!``0!````````"?X!``0!````````#3D!``0!````````"!P!``0!````
M````!"<!``0!````````#3\!``0!````````!#8!``0!````````"(L!``0!
M````````")4!``0!````````")\!``0!````````"*D!``0!````````!#\!
M``0!````````#4<!``0!````````"@8!``0!````````"A(!``0!````````
M!%`!``0!`````````E\!``0`````````!50!``0!````````!%<!``0!````
M````!%\!``0!````````"A@!``0!````````!'$!``0!````````"WD!``0!
M````````!^$!``0!````````!'H!``0!````````"A\!``0!````````"B<!
M``0!````````#4X!``0!````````"CP!``0!````````!)D!``0!````````
M!*H!``0!````````!+,!``0!````````!^<!``0!````````!+D!``0!````
M````!5P!``0!````````!,(!``0!````````!^T!``0!````````"_H!``0!
M````````"XT!``0!````````#50!``0!````````!,P!``0!````````"DP!
M``0!````````!-0!``0!````````!-P!``0!````````#7,!``0!````````
M"+,!``0!````````!.8!``0!````````!X`!``0!````````#5P!``0!````
M````!_X!``0!````````!X@!``0!````````!Y`!``0!````````!.P!``0!
M````````!/8!``0!````````!/X!``0!````````"-0!``0!````````!0<!
M``0!````````"-T!``0!````````"Z(!``0!````````"E0!``0!````````
M"EP!``0!````````"F0!``0!````````"O4!``0!````````!64!``0!````
M````#60!``0!````````!1`!``0!````````"`8!``0!````````!"L```#E
M```!2P```84```&&```!C````<H```(,```")@```B@```(L```"-@```C@`
M``(]```#60```]@```/O```#_@``!#````1W```$>@``!'P```2@```$H0``
M!1,```4Y```%30``!4\```51```%9@``!6@```5J```%:P``!6P```5Z```%
M@```!8<```61```%K0``!:X```6S```%N@``!;P```7!```%P@``!=D```7V
M```&%@``!AH```8A```&(P``!B0```8M```&+P``!FH```9L```&B@``!N0`
M``<#```'>0``""````@T```(@P``",X```C1```(XP``".D```CK```)JP``
M":T```F\```)O@``"<````G)```)W```"F$```IF```*>P``"GP```J!```*
M@P``"IT```JM```*M0``"MX```L5```+.P``"T````MZ```+A```"Y0```NA
M```+JP``"ZP```NM```+L```"[(```NS```+O0``"\$```O"```+PP``"\@`
M``O,```,50``#-X```SG```,^```#4@```UW```->@``#<\```%H```!3P``
M`5P```%5```!5````5<```%X```!6@```5D```%8```!7@```6````&.```!
MI````8P```&O```!L0```:X```%C```!B````9H```%?```!D0```:T```%.
M```!IP```9<```&Z```!9P```6(```%]```!9````7,```&8```!G````98`
M``&+```!H0```:,```%_```!A````6X```%U```!=@```70```%=```!FP``
M`;@```&*```!JP```:P```&H```!G0```6H```%K```!NP```9D```&0```!
M<````:H```%\```!@P```:8```&````!@0```8(```&R```!L````5L```%F
M```!>@```88```&V```!AP```58```&3```!H@```;4```%O```!D@```94`
M``%A```!C0```;0```%1```!=P```6P```%Y```!<@```7$```&W```!CP``
M`9\```%I```!LP```9X```&%```!?@```7L```&I```!N0```:````%M```!
ME````4P```&E```!B0```64```%3```!4````.\```#^````TP```5(```%-
M````PP```-(```%H```!3P```5P```%5```!5````5<```%X```!6@```5D`
M``%8```!7@```6````&.```!I````8P```&O```!L0```:X```%C```!B```
M`9H```%?```!D0```:T```%.```!IP```9<```&Z```!9P```6(```%]```!
M9````7,```&8```!G````98```&+```!H0```:,```%_```!A````6X```%U
M```!=@```70```%=```!FP```;@```&*```!JP```:P```&H```!G0```6H`
M``%K```!NP```9D```&0```!<````:H```%\```!@P```:8```&````!@0``
M`8(```&R```!L````5L```%F```!>@```88```&V```!AP```58```&3```!
MH@```;4```%O```!D@```94```%A```!C0```;0```%1```!=P```6P```%Y
M```!<@```7$```&W```!CP```9\```%I```!LP```9X```&%```!?@```7L`
M``&I```!N0```:````%M```!E````4P```&E`````%].6$%R9V,`7TY807)G
M=@!?7U]P<F]G;F%M90!?7V1Y;&1?9G5N8U]L;V]K=7``7U]D>6QD7VEN:71?
M8VAE8VL`7U]S=&%R=`!?96YV:7)O;@!D>6QD7W-T=6)?8FEN9&EN9U]H96QP
M97(`<W1A<G0`7U]?9&%R=VEN7V=C8S-?<')E<F5G:7-T97)?9G)A;65?:6YF
M;P!?7U]K97EM9W)?9'=A<F8R7W)E9VES=&5R7W-E8W1I;VYS`%]?8W1H<F5A
M9%]I;FET7W)O=71I;F4`7U]M:%]E>&5C=71E7VAE861E<@!?871E>&ET`%]C
M871C:%]E>&-E<'1I;VY?<F%I<V4`7V-A=&-H7V5X8V5P=&EO;E]R86ES95]S
M=&%T90!?8V%T8VA?97AC97!T:6]N7W)A:7-E7W-T871E7VED96YT:71Y`%]C
M;&]C:U]A;&%R;5]R97!L>0!?9&]?;6%C:%]N;W1I9GE?9&5A9%]N86UE`%]D
M;U]M86-H7VYO=&EF>5]N;U]S96YD97)S`%]D;U]M86-H7VYO=&EF>5]P;W)T
M7V1E;&5T960`7V1O7VUA8VA?;F]T:69Y7W-E;F1?;VYC90!?9&]?<V5Q;F]S
M7VUA8VA?;F]T:69Y7V1E861?;F%M90!?9&]?<V5Q;F]S7VUA8VA?;F]T:69Y
M7VYO7W-E;F1E<G,`7V1O7W-E<6YO<U]M86-H7VYO=&EF>5]P;W)T7V1E;&5T
M960`7V1O7W-E<6YO<U]M86-H7VYO=&EF>5]S96YD7V]N8V4`7V5R<FYO`%]E
M>&ET`%]M86-H7VEN:71?<F]U=&EN90!?;6%I;@!?<F5C96EV95]S86UP;&5S
M`%]?7VME>6UG<E]G;&]B86P`7U]D>6QD7W)E9VES=&5R7V9U;F-?9F]R7V%D
M9%]I;6%G90!?7V1Y;&1?<F5G:7-T97)?9G5N8U]F;W)?<F5M;W9E7VEM86=E
M`%]?:6YI=%]K97EM9W(`7U]K97EM9W)?9V5T7V%N9%]L;V-K7W!R;V-E<W-W
M:61E7W!T<@!?7VME>6UG<E]S971?86YD7W5N;&]C:U]P<F]C97-S=VED95]P
M='(`7V%B;W)T`%]C86QL;V,`7V9R964`7V-P,G1E;7!N86T`7V9I;&5?97AI
M<W1A;F-E`%]L:7-T7V9I;&5S`%]L<U]F:6QE`%]L<U]T<F5E`%]04D]'3D%-
M10!?7U]E<G)O<@!?875T;W!R97!E;F0`7V-H9&ER`%]C:&UO9`!?8VQO<V4`
M7V-L;W-E9&ER`%]C;W!Y7V9I;&4`7V1F;&%G`%]D=7`R`%]E>&5C=F4`7V9F
M;&%G`%]F;W)K`%]G971?9&ER7W-I>F4`7V=E=%]G<F]U<%]N86UE`%]G971?
M=7-E<E]N86UE`%]G971D=&%B;&5S:7IE`%]G971E=6ED`%]G971U:60`7VES
M96UP='D`7VQS=&%T`%]M96UC;7``7VUE;7-E=`!?;65S<VQO9S(`7VUK<W1E
M;7``7V]P96YD:7(`7W!?<V5T=6ED`%]P;&5S:U]U9VED`%]P<FEN=&8`7W!S
M865X:70`7W!U=&-H87(`7W!U=',`7W)E861D:7(`7W)E86QP871H`%]S971G
M:60`7W-E='5I9`!?<VYP<FEN=&8`7W-T870`7W-T<F5R<F]R`%]S=')L96X`
M7W-T<FYC870`7W-T<FYC<'D`7W=A:71P:60`7V5X7VUE<W-L;V<`7U]?<T8`
M7V)A<V5N86UE`%]F9FQU<V@`7V9P<FEN=&8`7V9P=71C`%]F<'5T<P!?;6%L
M;&]C`%]R96%L;&]C`%]V<VYP<FEN=&8`7T-!5$%,24Y!7TA/344`7T-%4E1)
M1DE#051%4U]$`%]#2$M#3TY&24=?0TU$`%]#55),7T-!7T)53D1,15]&24Q%
M`%]$3E--3D<`7T1/34%)3DU.1P!?1%)714)?151#7T0`7T125T5"7U)/3U1?
M1`!?1%5-4%]$`%]&4%]74D%04$52`%]&5%!$7T))3E]$`%]&5%!$7T-/3D8`
M7T944$1?0T].1E])3D,`7TA45%!$7T))3E]$`%](5%101%]#3TY&7T0`7TA4
M5%!$7TE.0TQ51$5?1`!?2%144$1?5DA/4U137T0`7TE.5$521D%#10!?3$]'
M4D]4051%`%]-04E,34%.7U)/3U1?1`!?34%)3$U!3E]605)?1`!?34%)3$U.
M1P!?34%+15]64E0`7TU94U%,7T))3E]$`%]-65-13%]605)?1`!?3D%-141?
M4E5.7U)/3U1?1`!?4$=344Q?0DE.7T0`7U!'4U%,7T1!5$%?1`!?4%)/1%5#
M5%]20U]$`%]04D]$54-47U)/3U1?1`!?44U!24Q?34%)3$Y!34537T0`7U%-
M04E,7U)/3U1?1`!?4DU?1E)-`%]235]01%]54U(`7U-%5%1)3D=37T9)3$4`
M7U5315)-3D<`7U=%0E-25DU.1P!?5T5"7U-4050`7W)E861?8V]N9@!?<F5A
M9%]C;VYF7W-A9F4`7W-T<F-A=`!?<W1R8W!Y`%]S=')D=7``7V-O<'E?9FEL
M95]A=&]M:6,`7V9C:&UO9`!?9F-H;W=N`%]F:6QE;F\`7V9R965?;&]C:P!?
M:7-?;&]C:V5D`%]M:U]L;V-K`%]O<&5N`%]R96%D`%]R96YA;64`7W)M7VQO
M8VL`7W-T<F-M<`!?=W)I=&4`7V-O=6YT7V-U<E]D:7(`7V=E=&-W9`!?9V5T
M7V=I9%]B>5]I9`!?9V5T7V=I9%]B>5]N86UE`%]G971?9W)O=7!?:60`7V=E
M=%]U<V5R7VED`%]I<U]N=6UB97(`7W!L97-K7V=E='!W`%]?1&5F875L=%)U
M;F5,;V-A;&4`7V=E=&=R9VED`%]G971G<FYA;0!?9V5T<'=N86T`7V=E='!W
M=6ED`%]S<V-A;F8`7V=E=%]R96%L7W!A=&@`7VES<W5B9&ER`%]S=')N8VUP
M`%]S=')R8VAR`%]D:7-A8FQE7W5S97(`7V5N86)L95]U<V5R`%]F:6YD7V-H
M<F]O=%]S:`!?:6YV86QI9&%T95]P87-S=V]R9`!?<V5T=7!?8VAR;V]T`%]U
M<V5R7W-E<W-I;VYS7V-L;W-E`%]U<V5R86-C97-S`%]U<V5R861D`%]U<V5R
M9&5L`%]U<V5R:&]M90!?=7-E<FUO9`!?=7-E<G-H96QL`%]?7VUA<VMR=6YE
M`%]?97AI=`!?87-P<FEN=&8`7V%S<')I;G1F7W-A9F4`7V-H;W=N`%]D969E
M<G)E9%]R96UO=F4`7V5X96-V`%]F9V5T<P!?9FEL95]S='(`7V9I;F1?9FEL
M90!?9F]R:U]E>&5C;%]P:7!E<P!?9G=R:71E`%]I;FET9W)O=7!S`%]K:6QL
M`%]M:V1I<@!?<&-L;W-E`%]P97)R;W(`7W!L97-K7VQY8V]S`%]P;W!E;@!?
M<FU?=')E90!?<V5T<VED`%]S>7-T96T`7W5N;&EN:P!?=7-L965P`%]U=&EL
M7V5X96,`7V9C;&]S90!?9F]P96X`7V9R96%D`%]F<W1A=`!?:7-?86QR96%D
M>5]L;V-K960`7VUK7V9L;V-K7W!A=&@`7VUK7VQO8VM?`%]M:U]N;VYB;&]C
M:U]L;V-K`%]F;&]C:P!?9V5T7VUD-7-U;0!?=F%S<')I;G1F7W-A9F4`7W9A
M<W!R:6YT9@!?1$5,151%1%]04D5&25@`7V-H;6]D7W1R964`7V-H;W=N7W1R
M964`7V1O7V1E9F5R<F5D7W)E;6]V90!?<V%V95]R97-T;W)E7W1R965?9FEL
M97,`7W1R965?<V5T7W!E<FUS`%]F8VAD:7(`7V9O<FM?97AE8W8`7VUK=&5M
M<`!?<F5N86UE7V1I<@!?<FUD:7(`7V9I;&5?<W1R:6YG<P!?<W1R<W1R`%]C
M<F5A=&5?96UP='E?9FEL90!?8W)E871E7V9I;&4`7V9I;&5?<V5T7W!E<FUS
M`%]M86ME7V1I<@!?;6%K95]D:7)?<`!?<%]F8VQO<V4`7W)I;F1E>`!?8VQO
M<V5?86QL`%]D=7`R7V-U<W1O;0!?9FEN9%]C;VUM86YD`%]F;W)K7V5X96-L
M7V=E=&]U=`!?9F]R:U]E>&5C;%]G971O=71E<G(`7V9O<FM?97AE8VQ?;&]G
M`%]F;W)K7V5X96-L7VQO9U]O;&0`7V9O<FM?97AE8W9?9F0`7V9O<FM?97AE
M8W9?9V5T;W5T`%]F;W)K7V5X96-V7V=E=&]U=&5R<@!?9F]R:U]E>&5C=E]G
M971O=71P=70`7V9O<FM?97AE8W9?;&]G`%]F;W)K7V5X96-V7W!I<&5S`%]P
M871H7V5X96,`7W!A=&A?97AE8U]A<F=S`%]P;W!E;E]E>&5C`%]P;W!E;E]E
M>&5C7V=E=&]U='!U=`!?=71I;%]E>&5C7V%R9W,`7V9C;G1L`%]G971C`%]G
M971E;G8`7VEN9&5X`%]P:7!E`%]S96QE8W0`7W-T<F-H<@!?=V%I=`!?<'0`
M7TU$-0!?<W!R:6YT9@!S=&%R="YS`&EN=#IT,3UR,3LM,C$T-S0X,S8T.#LR
M,30W-#@S-C0W.P!C:&%R.G0R/7(R.S`[,3(W.P``+U-O=7)C94-A8VAE+T-S
M=2]#<W4M-3<O`"]3;W5R8V5#86-H92]#<W4O0W-U+34W+V-R="YC`&=C8S)?
M8V]M<&EL960N`%]P;VEN=&5R7W1O7U]D87)W:6Y?9V-C,U]P<F5R96=I<W1E
M<E]F<F%M95]I;F9O`%]S=&%R=#I&*#`L,2D]*#`L,2D`=F]I9#IT*#`L,2D`
M87)G8SI0*#`L,BD]<B@P+#(I.RTR,30W-#@S-C0X.S(Q-#<T.#,V-#<[`&%R
M9W8Z4"@P+#,I/2HH,"PT*3TJ*#`L-2D]<B@P+#4I.S`[,3(W.P!E;G9P.E`H
M,"PS*0!I;G0Z="@P+#(I`&-H87(Z="@P+#4I`'`Z<B@P+#0I`'$Z<B@P+#,I
M`'1E<FTZ*#`L-BD]*B@P+#<I/68H,"PQ*0````!?7V-A;&Q?;6]D7VEN:71?
M9G5N8W,`7V-A;&Q?;6]D7VEN:71?9G5N8W,Z9B@P+#$I`'`Z*#`L-BD`````
M7V-R=%]B87-E;F%M90!C<G1?8F%S96YA;64Z9B@P+#@I/2HH,"PY*3UK*#`L
M-2D`<&%T:#I0*#`L."D`<SIR*#`L."D`;&%S=#IR*#`L."D`````7V-R=%]S
M=')B96=I;G-W:71H`&-R=%]S=')B96=I;G-W:71H.F8H,"PR*0!S,3I0*#`L
M."D`<S(Z4"@P+#@I``!?7V-A;&Q?;V)J8TEN:70`7V-A;&Q?;V)J8TEN:70Z
M9B@P+#$I`&DZ<B@P+#$P*3UR*#`L,3`I.S`P,#`P,#`P,#`P,#`P,#`P,#`P
M,#`P,#LP,#`P,#`P,#`P,#`P,S<W-S<W-S<W-S<[`'5N<VEG;F5D(&EN=#IT
M*#`L,3`I`&-O=6YT.G(H,"PQ,"D`7V1Y;&1?:6UA9V5?8V]U;G1?9FXZ*#`L
M,3$I/2HH,"PQ,BD]9B@P+#$P*0!?9'EL9%]G971?:6UA9V5?;F%M95]F;CHH
M,"PQ,RD]*B@P+#$T*3UF*#`L."D`7V1Y;&1?9V5T7VEM86=E7VAE861E<E]F
M;CHH,"PQ-2D]*B@P+#$V*3UF*#`L,3<I/2HH,"PQ."D]:R@P+#$I`$Y33&]O
M:W5P4WEM8F]L26Y);6%G95]F;CHH,"PQ.2D]*B@P+#(P*3UF*#`L,3<I`$Y3
M061D<F5S<T]F4WEM8F]L7V9N.B@P+#(Q*3TJ*#`L,C(I/68H,"PR,RD]*B@P
M+#$I`````'!O:6YT97)?=&]?7V1A<G=I;E]G8V,S7W!R97)E9VES=&5R7V9R
M86UE7VEN9F\Z4R@P+#8I`$Y807)G8SI'*#`L,BD`3EA!<F=V.D<H,"PS*0!E
M;G9I<F]N.D<H,"PS*0!?7W!R;V=N86UE.D<H,"PT*0``9'EL9%]L87IY7W-Y
M;6)O;%]B:6YD:6YG7V5N=')Y7W!O:6YT`&5R<F]R7VUE<W-A9V4`9'EL9%]F
M=6YC7VQO;VMU<%]P;VEN=&5R`%]D87)W:6Y?=6YW:6YD7V1Y;&1?861D7VEM
M86=E7VAO;VL`7V1A<G=I;E]U;G=I;F1?9'EL9%]R96UO=F5?:6UA9V5?:&]O
M:P!?<F5A9%]V87(`7V)U9F8N,`!?8G5F9BXQ`%]B=69F+C``7VUK7V=R;W5P
M`%]T<GE?=6YL:6YK`%]D;U]E>&5C`%]C;60N,`!?=7-E<G1M<&PN,0!?8V]N
M9BXP`%]C;VYF7W-I>F4N,0!?9&5F97)R961?9&ER<P!?=W)I=&5?<W1R:6YG
M<P!?;6%K95]D:7)?<F5C`%]F;W)K7V5X96-V=E]G971O=71P=70`7W)E861?
M=&]?8G5F`%]R97,N,`!?8G5F9BXP````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O971C+P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`U,34T,S,W-S0`,#$T-34R`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]E=&,O<'-A
M+6AO<F1E+P``````````````````````````````````````````````````
M```````````````````````````````````````````P,#`P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<W-``P,38T,S0`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O:&]R9&4O````````````````````
M````````````````````````````````````````````````````````````
M`````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,S-S<T`#`Q-S4S-0`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O971C+W!S82UH;W)D92]H;W)D
M92\N:'1A8V-E<W,`````````````````````````````````````````````
M````````````````````````````,#`P,#0T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,38`,3`U,34T,S,W-S0`,#(Q,S(V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$1E;GD@9G)O;2!A;&P*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O:&]R9&4O8V]N9BYP:'``
M````````````````````````````````````````````````````````````
M`````````````#`P,#`T-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P,3(V
M`#$P-3$U-#,S-S<T`#`R,3$W,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*B!#3TY&24<@4U1!4E0N($1/($Y/
M5"!#2$%.1T4@04Y95$A)3D<@24X@3U(@049415(@5$A)4R!,24Y%+B`J+PHO
M+R`D2&]R9&4Z(&AO<F1E+V-O;F9I9R]C;VYF+GAM;"QV(#$N-S0N,BXT,2`R
M,#`V+S`X+S`T(#$W.C$S.C(U(&IA;B!%>'`@)`HO*BH**B!0;&5S:R!P<F5D
M969I;F5D(&-O;F9I9W5R871I;VX@9F]R($AO<F1E,PHJ*B\*"B1C;VYF6R=D
M96)U9U]L979E;"==(#T@15]%4E)/4CL*)&-O;F9;)VUA>%]E>&5C7W1I;64G
M72`](#`["B1C;VYF6R=U<V5?<W-L)UT@/2`R.PHD8V]N9ELG<V5R=F5R)UU;
M)VYA;64G72`]("1?4T525D526R=315)615)?3D%-12==.PHD8V]N9ELG<V5R
M=F5R)UU;)W!O<G0G72`]("1?4T525D526R=315)615)?4$]25"==.PHD8V]N
M9ELG8V]M<')E<W-?<&%G97,G72`]('1R=64["B1C;VYF6R=U;6%S:R==(#T@
M,#<W.PHD8V]N9ELG<V5S<VEO;B==6R=N86UE)UT@/2`G2&]R9&4S)SL*)&-O
M;F9;)W-E<W-I;VXG75LG8V%C:&5?;&EM:71E<B==(#T@)VYO8V%C:&4G.PHD
M8V]N9ELG<V5S<VEO;B==6R=T:6UE;W5T)UT@/2`P.PHD8V]N9ELG8V]O:VEE
M)UU;)V1O;6%I;B==(#T@)%]315)615);)U-%4E9%4E].04U%)UT["B1C;VYF
M6R=C;V]K:64G75LG<&%T:"==(#T@)R\G.PHD8V]N9ELG<W%L)UU;)W!E<G-I
M<W1E;G0G72`](&9A;'-E.PHD8V]N9ELG<W%L)UU;)VAO<W1S<&5C)UT@/2`G
M;&]C86QH;W-T)SL*)&-O;F9;)W-Q;"==6R=U<V5R;F%M92==(#T@)VAO<F1E
M)SL*)&-O;F9;)W-Q;"==6R=S;V-K970G72`]("<O=F%R+VQI8B]M>7-Q;"]M
M>7-Q;"YS;V-K)SL*)&-O;F9;)W-Q;"==6R=P<F]T;V-O;"==(#T@)W5N:7@G
M.PHD8V]N9ELG<W%L)UU;)V1A=&%B87-E)UT@/2`G:&]R9&4G.PH*+R\@9V5T
M('!A<W-W;W)D(&9R;VT@+V5T8R]P<V$O+G=E8FUA:6PN<VAA9&]W(`II9B`H
M(2@D9F0@/2!F;W!E;B@B+V5T8R]P<V$O+G=E8FUA:6PN<VAA9&]W(BP@(G(B
M*2DI('L*("!E8VAO("(\<V-R:7!T/F%L97)T*"=5;F%B;&4@=&\@9V5T('=E
M8FUA:6P@<&%S<W=O<F0A)RD\+W-C<FEP=#XB.PH@(&5X:70H*3L*?0IF<V-A
M;F8H)&9D+"`B)7,B+"`D8G5F9BD["F9C;&]S92@D9F0I.PH*)&-O;F9;)W-Q
M;"==6R=P87-S=V]R9"==(#T@<')E9U]R97!L86-E*"(O7&XO(BP@(B(L("1B
M=69F*3L*)&-O;F9;)W-Q;"==6R=C:&%R<V5T)UT@/2`G=71F."<["B1C;VYF
M6R=S<6PG75LG<&AP='EP92==(#T@)VUY<W%L)SL*)&-O;F9;)V%U=&@G75LG
M861M:6YS)UT@/2!A<G)A>2@I.PHD8V]N9ELG875T:"==6R=C:&5C:VEP)UT@
M/2!T<G5E.PHD8V]N9ELG875T:"==6R=C:&5C:V)R;W=S97(G72`]('1R=64[
M"B1C;VYF6R=A=71H)UU;)V%L=&5R;F%T95]L;V=I;B==(#T@9F%L<V4["B1C
M;VYF6R=A=71H)UU;)W)E9&ER96-T7V]N7VQO9V]U="==(#T@9F%L<V4["@HD
M8V]N9ELG875T:"==6R=D<FEV97(G72`]("=C;VUP;W-I=&4G.PHD8V]N9ELG
M875T:"==6R=P87)A;7,G75LG9')I=F5R<R==(#T@87)R87DH"B`@("`G:6UP
M)R`]/B!A<G)A>2@G9')I=F5R)R`]/B`G87!P;&EC871I;VXG+`H@("`@("`@
M("`@("`@("`@("`@)W!A<F%M<R<@/3X@87)R87DH)V%P<"<@/3X@)VEM<"<I
M*2P*("`@("=M:6UP)R`]/B!A<G)A>2@G9')I=F5R)R`]/B`G87!P;&EC871I
M;VXG+`H@("`@("`@("`@("`@("`@("`@("=P87)A;7,G(#T^(&%R<F%Y*"=A
M<'`G(#T^("=M:6UP)RDI*3L*"B1C;VYF6R=A=71H)UU;)W!A<F%M<R==6R=L
M;V=I;G-C<F5E;E]S=VET8V@G72`]("=?:&]R9&5?<V5L96-T7VQO9VEN<V-R
M965N)SL*"6EF("@A9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?<V5L96-T7VQO
M9VEN<V-R965N)RDI('L*"0EF=6YC=&EO;B!?:&]R9&5?<V5L96-T7VQO9VEN
M<V-R965N*"D*"0E["@D)"4!D969I;F4H2$]21$5?0D%312PG+W5S<B]S:&%R
M92]P<V$M:&]R9&4G*3L*"0D)<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G
M+VQI8B](;W)D92]"<F]W<V5R+G!H<"<["@D)"21B<F]W<V5R(#T@;F5W($)R
M;W=S97(H*3L*"0D):68@*"1B<F]W<V5R+3YI<TUO8FEL92@I("8F("1'3$]"
M04Q36R=R96=I<W1R>2==+3YA<'!L:6-A=&EO;G-;)VUI;7`G72E["@D)"0ER
M971U<FX@)VUI;7`G.PH)"0E]"@D)"7)E='5R;B`G:6UP)SL@"@D)?0I]"@HD
M8V]N9ELG<VEG;G5P)UU;)V%L;&]W)UT@/2!F86QS93L*)&-O;F9;)VQO9R==
M6R=P<FEO<FET>2==(#T@4$5!4E],3T=?15)2.PHD8V]N9ELG;&]G)UU;)VED
M96YT)UT@/2`G2$]21$4G.PHD8V]N9ELG;&]G)UU;)W!A<F%M<R==(#T@87)R
M87DH*3L*)&-O;F9;)VQO9R==6R=N86UE)UT@/2`G+W5S<B]L;V-A;"]P<V$O
M=F%R+VQO9R]P<V$M:&]R9&4N;&]G)SL*)&-O;F9;)VQO9R==6R=P87)A;7,G
M75LG87!P96YD)UT@/2!T<G5E.PHD8V]N9ELG;&]G)UU;)W1Y<&4G72`]("=F
M:6QE)SL*)&-O;F9;)VQO9R==6R=E;F%B;&5D)UT@/2!T<G5E.PHD8V]N9ELG
M;&]G7V%C8V5S<VME>7,G72`](&9A;'-E.PHD8V]N9ELG<')E9G,G75LG<&%R
M86US)UU;)V1R:79E<F-O;F9I9R==(#T@)VAO<F1E)SL*)&-O;F9;)W!R969S
M)UU;)V1R:79E<B==(#T@)W-Q;"<["B1C;VYF6R=D871A=')E92==6R=P87)A
M;7,G75LG9')I=F5R8V]N9FEG)UT@/2`G:&]R9&4G.PHD8V]N9ELG9&%T871R
M964G75LG9')I=F5R)UT@/2`G<W%L)SL*)&-O;F9;)V=R;W5P)UU;)V1R:79E
M<B==(#T@)V1A=&%T<F5E)SL*)&-O;F9;)V-A8VAE)UU;)V1E9F%U;'1?;&EF
M971I;64G72`](#$X,#`["B1C;VYF6R=C86-H92==6R=P87)A;7,G75LG9&ER
M)UT@/2!(;W)D93HZ9V5T5&5M<$1I<B@I.PHD8V]N9ELG8V%C:&4G75LG<&%R
M86US)UU;)V=C)UT@/2`X-C0P,#L*)&-O;F9;)V-A8VAE)UU;)V1R:79E<B==
M(#T@)V9I;&4G.PHD8V]N9ELG;6%I;&5R)UU;)W!A<F%M<R==6R=H;W-T)UT@
M/2`G;&]C86QH;W-T)SL*)&-O;F9;)VUA:6QE<B==6R=P87)A;7,G75LG875T
M:"==(#T@)S`G.PHD8V]N9ELG;6%I;&5R)UU;)W1Y<&4G72`]("=S;71P)SL*
M)&-O;F9;)W9F<R==6R=P87)A;7,G75LG=F9S<F]O="==(#T@)R]T;7`G.PHD
M8V]N9ELG=F9S)UU;)W1Y<&4G72`]("=F:6QE)SL*)&-O;F9;)W-E<W-I;VYH
M86YD;&5R)UU;)W1Y<&4G72`]("=N;VYE)SL*)&-O;F9;)VUI;64G75LG;6%G
M:6-?9&(G72`]("<@+W5S<B]S:&%R92]M:7-C+VUA9VEC)SL*)&-O;F9;)W!R
M;V)L96US)UU;)V5M86EL)UT@/2`G=V5B;6%S=&5R0&5X86UP;&4N8V]M)SL*
M)&-O;F9;)W!R;V)L96US)UU;)VUA:6QD;VUA:6XG72`]("=E>&%M<&QE+F-O
M;2<["B1C;VYF6R=P<F]B;&5M<R==6R=T:6-K971S)UT@/2!F86QS93L*)&-O
M;F9;)VUE;G4G75LG87!P<R==(#T@87)R87DH*3L*)&-O;F9;)VUE;G4G75LG
M86QW87ES)UT@/2!F86QS93L*)&-O;F9;)VUE;G4G75LG;&EN:W,G75LG:&5L
M<"==(#T@)V%L;"<["B1C;VYF6R=M96YU)UU;)VQI;FMS)UU;)VAE;'!?86)O
M=70G72`]('1R=64["B1C;VYF6R=M96YU)UU;)VQI;FMS)UU;)V]P=&EO;G,G
M72`]("=A=71H96YT:6-A=&5D)SL*)&-O;F9;)VUE;G4G75LG;&EN:W,G75LG
M<')O8FQE;2==(#T@)VYE=F5R)SL*)&-O;F9;)VUE;G4G75LG;&EN:W,G75LG
M;&]G:6XG72`]("=A;&PG.PHD8V]N9ELG;65N=2==6R=L:6YK<R==6R=L;V=O
M=70G72`]("=A=71H96YT:6-A=&5D)SL*)&-O;F9;)VAO;VMS)UU;)W!E<FUS
M9&5N:65D)UT@/2!F86QS93L*)&-O;F9;)VAO;VMS)UU;)W5S97)N86UE)UT@
M/2!F86QS93L*)&-O;F9;)VAO;VMS)UU;)W!R96%U=&AE;G1I8V%T92==(#T@
M9F%L<V4["B1C;VYF6R=H;V]K<R==6R=P;W-T875T:&5N=&EC871E)UT@/2!F
M86QS93L*)&-O;F9;)VAO;VMS)UU;)V%U=&AL9&%P)UT@/2!F86QS93L*)&-O
M;F9;)W!O<G1A;"==6R=F:7AE9%]B;&]C:W,G72`](&%R<F%Y*"D["B1C;VYF
M6R=A8V-O=6YT<R==6R=D<FEV97(G72`]("=N=6QL)SL*)&-O;F9;)VEM<W`G
M75LG96YA8FQE9"==(#T@9F%L<V4["B1C;VYF6R=K;VQA8B==6R=E;F%B;&5D
M)UT@/2!F86QS93L*)&-O;F9;)W1O:V5N)UU;)W!A<F%M<R==6R=D<FEV97)C
M;VYF:6<G72`]("=H;W)D92<["B1C;VYF6R=T;VME;B==6R=D<FEV97(G72`]
M("=S<6PG.PHD8V]N9ELG8W-S)UU;)V-A8VAE9"==(#T@=')U93L*+RH@0T].
M1DE'($5.1"X@1$\@3D]4($-(04Y'12!!3EE42$E.1R!)3B!/4B!"149/4D4@
M5$A)4R!,24Y%+B`J+PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O971C+W!S82UH;W)D92]H;W)D92]C;VYF+GAM;```````````````
M````````````````````````````````````````````````````````````
M,#`P,#0T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`R,#0Q,C,`,3`U,34T,S,W
M-S0`,#(Q,C`T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_>&UL('9E<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D93H@:&]R
M9&4O8V]N9FEG+V-O;F8N>&UL+'8@,2XW-"XR+C0Q(#(P,#8O,#@O,#0@,3<Z
M,3,Z,C4@:F%N($5X<"`D("TM/@H\8V]N9FEG=7)A=&EO;CX*(#QC;VYF:6=T
M86(@;F%M93TB9V5N97)A;"(@9&5S8STB1V5N97)A;"(^"B`@/&-O;F9I9VAE
M861E<CY'96YE<F%L($AO<F1E(%-E='1I;F=S/"]C;VYF:6=H96%D97(^"B`@
M/&-O;F9I9W!H<"!N86UE/2)D96)U9U]L979E;"(@9&5S8STB5&AE('9A;'5E
M('1O('-E=`H@(&5R<F]R7W)E<&]R=&EN9R@I('1O+@H@(%-E92!H='1P.B\O
M=W=W+G!H<"YN970O;6%N=6%L+V9U;F-T:6]N+F5R<F]R+7)E<&]R=&EN9RYP
M:'`@9F]R(&UO<F4*("!I;F9O<FUA=&EO;B!A;F0@<&]S<VEB;&4@=F%L=65S
M+B(^15]!3$P@)F%M<#L@?D5?3D]424-%/"]C;VYF:6=P:'`^"B`@/&-O;F9I
M9VEN=&5G97(@;F%M93TB;6%X7V5X96-?=&EM92(@9&5S8STB268@=V4@;F5E
M9"!T;R!P97)F;W)M(&$@;&]N9PH@(&]P97)A=&EO;BP@=VAA="!S:&]U;&0@
M=V4@<V5T(&UA>%]E>&5C=71I;VY?=&EM92!T;R`H:6X@<V5C;VYD<RD_(#`@
M;65A;G,@;F\*("!L:6UI=#L@:&]W979E<BP@82!V86QU92!O9B`P('=I;&P@
M8V%U<V4@82!W87)N:6YG(&EF('EO=2!A<F4@<G5N;FEN9R!I;B!S869E"B`@
M;6]D92X@4V5E(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO9G5N8W1I;VXN
M<V5T+71I;64M;&EM:70N<&AP(&9O<B!M;W)E"B`@:6YF;W)M871I;VXN(CXP
M/"]C;VYF:6=I;G1E9V5R/@H@(#QC;VYF:6=E;G5M(&YA;64](G5S95]S<VPB
M('%U;W1E/2)F86QS92(@9&5S8STB1&5T97)M:6YE<R!H;W<@=V4@9V5N97)A
M=&4*("!F=6QL(%523',@*&9O<B!L;V-A=&EO;B!H96%D97)S(&%N9"!S=6-H
M*2XF;'0[8G(@+R9G=#M.3U1%.B!)9B!Y;W4@8VAO;W-E('1O"B`@86QW87ES
M(&=E;F5R871E(&AT='!S(%523',L('EO=2!-55-4(&AA<F1C;V1E('1H92!C
M;W)R96-T($A45%!3('!O<G0@;G5M8F5R"B`@:6X@=&AE('-E<G9E<B!P;W)T
M('-E='1I;F<@8F5L;W<N($]T:&5R=VES92!(;W)D92!W:6QL(&)E('5N86)L
M92!T;R!G96YE<F%T90H@(&-O<G)E8W0@2%144%,@55),<R!W:&5N(&$@=7-E
M<B!T<FEE<R!T;R!A8V-E<W,@2&]R9&4@=FEA(&$@;F]N+4A45%!3('!O<G0N
M(CXR"B`@(#QV86QU97,^"B`@("`\=F%L=64@9&5S8STB07-S=6UE('1H870@
M=V4@87)E(&YO="!U<VEN9R!34TP@86YD(&YE=F5R(&=E;F5R871E(&AT='!S
M(%523',N(CXP/"]V86QU93X*("`@(#QV86QU92!D97-C/2)!<W-U;64@=&AA
M="!W92!A<F4@=7-I;F<@4U-,(&%N9"!A;'=A>7,@9V5N97)A=&4@:'1T<',@
M55),<RXB/C$\+W9A;'5E/@H@("`@/'9A;'5E(&1E<V,](D%T=&5M<'0@=&\@
M875T;RUD971E8W0L(&%N9"!G96YE<F%T92!54DQS(&%P<')O<')I871E;'DB
M/C(\+W9A;'5E/@H@("`@/'9A;'5E(&1E<V,](D%S<W5M92!T:&%T('=E(&%R
M92!N;W0@=7-I;F<@4U-,(&%N9"!G96YE<F%T92!H='1P<R!54DQS(&]N;'D*
M("`@(&9O<B!L;V=I;BXB/C,\+W9A;'5E/@H@("`\+W9A;'5E<SX*("`\+V-O
M;F9I9V5N=6T^"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<V5R=F5R(CX*("`@
M/&-O;F9I9W!H<"!N86UE/2)N86UE(B!D97-C/2)7:&%T('-E<G9E<B!N86UE
M('-H;W5L9"!W92!U<V4_(%EO=2=L;"!P<F]B86)L>0H@("!K;F]W(&EF('EO
M=2!N965D('1O(&-H86YG92!T:&ES(&1E9F%U;'0[(&]N;'D@:6X@<VET=6%T
M:6]N<R!W:&5R92!Y;W4@;F5E9"!T;PH@("!O=F5R<FED92!W:&%T($%P86-H
M92!T:&EN:W,@=&AE('-E<G9E<B!N86UE"B`@(&ES+B(^)%]315)615);)U-%
M4E9%4E].04U%)UT\+V-O;F9I9W!H<#X*("`@/&-O;F9I9W!H<"!N86UE/2)P
M;W)T(B!D97-C/2)7:&%T('!O<G0@;G5M8F5R(&ES('1H92!W96)S97)V97(@
M<G5N;FEN9R!O;C\*("`@06=A:6XL('EO=2!S:&]U;&1N)W0@;F5E9"!T;R!C
M:&%N9V4@=&AE(&1E9F%U;'0L(&%N9"!Y;W4@<')O8F%B;'D@:VYO=R!I="!I
M9@H@("!Y;W4@9&\N(%1H92!E>&-E<'1I;VX@:7,@:68@>6]U(&AA=F4@8VAO
M<V5N('1O(&%L=V%Y<R!G96YE<F%T92!H='1P<R!54DQS+"!A<PH@("!D97-C
M<FEB960@86)O=F4N(CXD7U-%4E9%4ELG4T525D527U!/4E0G73PO8V]N9FEG
M<&AP/@H@(#PO8V]N9FEG<V5C=&EO;CX*("`\8V]N9FEG8F]O;&5A;B!N86UE
M/2)C;VUP<F5S<U]P86=E<R(@9&5S8STB268@=&AI<R!O<'1I;VX@:7,@<V5T
M('1O('1R=64L(&%N9`H@('EO=2!H879E('1H92!P:'`@>FQI8B!E>'1E;G-I
M;VXL('!A9V5S(&]V97(@82!C97)T86EN('-I>F4@=VEL;"!B92!C;VUP<F5S
M<V5D"B`@86YD('-E;G0@=&\@=&AE(&)R;W=S97(@87,@9WII<"UE;F-O9&5D
M(&1A=&$@:6X@;W)D97(@=&\@<V%V90H@(&)A;F1W:61T:"X@5&AE<F4@:7,@
M82!#4%4M=7-A9V4@<&5N86QT>2!T;R!P87D@9F]R('1H:7,L(&)U="!T:&4@
M9&5C<F5A<V4@:6X*("!P86=E('-I>F4@8V%N(&)E(&1R86UA=&EC("@W,&L@
M=&\@=6YD97(@,3!K(&9O<B!A(&9U;&P@;6%I;&)O>"!P86=E*2P@86YD(&ES
M"B`@;6]R92!T:&%N('=O<G1H(&ET(&]V97(@86YY=&AI;F<@8G5T(&%N(&5X
M=')E;65L>2!F87-T"B`@;&EN:RXB/G1R=64\+V-O;F9I9V)O;VQE86X^"B`@
M/&-O;F9I9VEN=&5G97(@;F%M93TB=6UA<VLB(&]C=&%L/2)T<G5E(B!D97-C
M/2)7:&%T('5M87-K('-H;W5L9"!W92!R=6X@=VET:#\@5&AI<R!W:6QL(&%F
M9F5C="!T:&4@<&5R;6ES<VEO;G,@;VX@86YY('1E;7!O<F%R>2!F:6QE<R!T
M:&%T(&%R92!C<F5A=&5D+B!4:&ES('9A;'5E(&ES(&%N(&EN=&5G97(N(CXP
M-S<\+V-O;F9I9VEN=&5G97(^"B`@/&-O;F9I9W-T<FEN9R!N86UE/2)T;7!D
M:7(B(')E<75I<F5D/2)F86QS92(@9&5S8STB268@>6]U('=A;G0@=&\@=7-E
M(&$*("!T96UP;W)A<GD@9&ER96-T;W)Y(&]T:&5R('1H86X@=&AE('-Y<W1E
M;2!D969A=6QT(&]R('1H92!O;F4@<W!E8VEF:65D(&EN"B`@<&AP)W,@=7!L
M;V%D7W1M<%]D:7(@=F%L=64L(&5N=&5R(&ET(&AE<F4N(B\^"B`@/&-O;F9I
M9W-E8W1I;VX@;F%M93TB<V5S<VEO;B(^"B`@(#QC;VYF:6=S=')I;F<@;F%M
M93TB;F%M92(@9&5S8STB5VAA="!N86UE('-H;W5L9"!W92!U<V4@9F]R('1H
M92!S97-S:6]N('1H870*("`@2&]R9&4@87!P<R!S:&%R93\@268@>6]U('=A
M;G0@=&\@<VAA<F4@<V5S<VEO;G,@=VET:"!O=&AE<B!A<'!L:6-A=&EO;G,@
M;VX*("`@>6]U<B!W96)S97)V97(L('EO=2!W:6QL(&YE960@=&\@;6%K92!S
M=7)E('1H870@=&AE>2!A<F4@=7-I;F<@=&AE('-A;64*("`@<V5S<VEO;B!N
M86UE+B`@3F]T93H@4V5S<VEO;B!N86UE<R!M=7-T(&-O;G-I<W0@;V8@;VYL
M>2!A;'!H86YU;65R:6,*("`@8VAA<F%C=&5R<RXB/DAO<F1E/"]C;VYF:6=S
M=')I;F<^"B`@(#QC;VYF:6=B;V]L96%N(&YA;64](G5S95]O;FQY7V-O;VMI
M97,B(&1E<V,](E-H;W5L9"!W92!O;FQY(&%L;&]W('-E<W-I;VX*("`@:6YF
M;W)M871I;VX@=&\@8F4@<W1O<F5D(&EN(&$@<V5S<VEO;B!C;V]K:64@86YD
M(&YO="!B92!P87-S960@8GD@55),("A'150I"B`@('!A<F%M971E<G,_(%1H
M:7,@:7,@;VX@8GD@9&5F875L="!B96-A=7-E('!A<W-I;F<@<V5S<VEO;B!I
M;F9O<FUA=&EO;B!I;@H@("!T:&4@55),(&ES(&$@<V5C=7)I='D@<FES:RX@
M0V]N<VED97(@8V%R969U;&QY(&)E9F]R92!T=7)N:6YG(&ET(&]F9BXB/@H@
M("!T<G5E/"]C;VYF:6=B;V]L96%N/@H@("`\8V]N9FEG<W1R:6YG(&YA;64]
M(F-A8VAE7VQI;6ET97(B(&1E<V,](E=H870@8V%C:&EN9R!L979E;"!S:&]U
M;&0@=V4@=7-E"B`@(&9O<B!T:&4@<V5S<VEO;C\@1$\@3D]4($-(04Y'12!4
M2$E3(%5.3$534R!93U4@)FQT.W-T<F]N9R9G=#M214%,3%DF;'0[+W-T<F]N
M9R9G=#L@2TY/5PH@("!72$%4(%E/52!!4D4@1$])3D<N(%-E='1I;F<@=&AI
M<R!T;R!A;GET:&EN9R!O=&AE<B!T:&%N("=N;V-A8VAE)R!W:6QL(&%L;6]S
M=`H@("!C97)T86EN;'D@<F5S=6QT(&EN('-E=F5R96QY(&)R;VME;B!S8W)I
M<'0@8F5H879I;W(N(CYN;V-A8VAE/"]C;VYF:6=S=')I;F<^"B`@(#QC;VYF
M:6=I;G1E9V5R(&YA;64](G1I;65O=70B(&1E<V,](DAO=R!L;VYG('-H;W5L
M9"!S97-S:6]N<R!L87-T("AI;B!S96-O;F1S*3\@,"!M96%N<PH@("!T:&%T
M('1H92!S97-S:6]N(&5N9',@=VAE;B!T:&4@=7-E<B!C;&]S97,@=&AE:7(@
M8G)O=W-E<BX@4V5T(&]T:&5R('9A;'5E<PH@("!W:71H(&-A<F4@+2!S964*
M("`@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]F=6YC=&EO;BYS97-S
M:6]N+7-E="UC;V]K:64M<&%R86US+G!H<"XB/C`\+V-O;F9I9VEN=&5G97(^
M"B`@/"]C;VYF:6=S96-T:6]N/@H@(#QC;VYF:6=S96-T:6]N(&YA;64](F-O
M;VMI92(^"B`@(#QC;VYF:6=P:'`@;F%M93TB9&]M86EN(B!D97-C/2)7:&%T
M(&1O;6%I;B!S:&]U;&0@=V4@<V5T(&-O;VMI97,@9G)O;3\@268*("`@>6]U
M(&AA=F4@82!C;'5S=&5R('1H870@;F5E9',@=&\@<VAA<F4@8V]O:VEE<RP@
M=&AI<R!M:6=H="!B92`G+F5X86UP;&4N8V]M)PH@("`M('1H92!L96%D:6YG
M("<N)R!I<R!I;7!O<G1A;G0N($UO<W0@;&EK96QY+"!T:&]U9V@L('EO=2!W
M;VXG="!H879E('1O(&-H86YG90H@("!T:&4@9&5F875L="XB/B1?4T525D52
M6R=315)615)?3D%-12==/"]C;VYF:6=P:'`^"B`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB<&%T:"(@9&5S8STB5VAA="!P871H('-H;W5L9"!W92!S970@8V]O
M:VEE<R!T;S\@5&AI<PH@("!S:&]U;&0@;6%T8V@@=VAE<F4@2&]R9&4@:7,@
M;VX@>6]U<B!W96)S97)V97(@+2!I9B!I="!I<R!A="`O:&]R9&4L('1H96X@
M=&AI<PH@("!S:&]U;&0@8F4@)R]H;W)D92<N($EF($AO<F1E(&ES(&EN<W1A
M;&QE9"!A<R!T:&4@9&]C=6UE;G0@<F]O="P@=&AE;B!T:&ES"B`@(&YE961S
M('1O(&)E("<O)R`M($Y/5"`G)RXF;'0[8G(@+R9G=#LF;'0[<W1R;VYG)F=T
M.T)55"9L=#LO<W1R;VYG)F=T.RP@:68@244@=VEL;"!B90H@("!U<V5D('1O
M(&%C8V5S<R!(;W)D92!M;V1U;&5S+"!Y;W4@<VAO=6QD(')E860@=&AI<R!F
M:7)S="`H9&ES8W5S<VEN9R!I<W-U97,*("`@=VET:"!)12=S($-O;G1E;G0@
M061V:7-O<BDZ"B`@(&AT='`Z+R]L:7-T<RYH;W)D92YO<F<O87)C:&EV97,O
M:6UP+U=E96LM;V8M36]N+3(P,#,P,3$S+S`R.3$T.2YH=&UL(CXO:&]R9&4\
M+V-O;F9I9W-T<FEN9SX*("`\+V-O;F9I9W-E8W1I;VX^"B`\+V-O;F9I9W1A
M8CX*"B`\8V]N9FEG=&%B(&YA;64](G-Q;"(@9&5S8STB1&%T86)A<V4B/@H@
M(#QC;VYF:6=S96-T:6]N(&YA;64](G-Q;"(^"B`@(#QC;VYF:6=H96%D97(^
M2&]R9&4@1&%T86)A<V4@4V5T=&EN9W,\+V-O;F9I9VAE861E<CX*("`@/&-O
M;F9I9V1E<V-R:7!T:6]N/B9L=#MS=')O;F<F9W0[3D]413HF;'0[+W-T<F]N
M9R9G=#L@5&AE<V4@87)E(&]N;'D@=&AE"B`@("9L=#ME;29G=#MD969A=6QT
M)FQT.R]E;29G=#L@=F%L=65S(&9O<B!A;GD@9&%T86)A<V4@9')I=F5N(&)A
M8VME;F1S+B!9;W4*("`@<W1I;&P@;F5E9"!T;R!C;VYF:6=U<F4@=&AE(&1I
M9F9E<F5N="!S>7-T96US(&QI:V4@(E!R969E<F5N8V5S(B!O<@H@("`B1&%T
M851R964B('1O(&%C='5A;&QY("9L=#ME;29G=#MU<V4F;'0[+V5M)F=T.R!A
M(&1A=&%B87-E"B`@(&)A8VME;F0N/"]C;VYF:6=D97-C<FEP=&EO;CX*("`@
M/&-O;F9I9W-Q;"!S=VET8VAN86UE/2)P:'!T>7!E(B!B87-E8V]N9FEG/2)T
M<G5E(B`O/@H@(#PO8V]N9FEG<V5C=&EO;CX*(#PO8V]N9FEG=&%B/@H*(#QC
M;VYF:6=T86(@;F%M93TB875T:"(@9&5S8STB075T:&5N=&EC871I;VXB/@H@
M(#QC;VYF:6=S96-T:6]N(&YA;64](F%U=&@B/@H@("`\8V]N9FEG:&5A9&5R
M/DAO<F1E($%U=&AE;G1I8V%T:6]N/"]C;VYF:6=H96%D97(^"B`@(#QC;VYF
M:6=L:7-T(&YA;64](F%D;6EN<R(@9&5S8STB5VAI8V@@=7-E<G,@<VAO=6QD
M(&)E('1R96%T960@87,*("`@861M:6YI<W1R871O<G,@*')O;W0L('-U<&5R
M+75S97(I(&)Y($AO<F1E/R(@<F5Q=6ER960](F9A;'-E(B\^"B`@(#QC;VYF
M:6=B;V]L96%N(&YA;64](F-H96-K:7`B(&1E<V,](E-H;W5L9"!W92!A;'=A
M>7,@<W1O<F4@86YD('9A;&ED871E"B`@('1H92!)4"!A9&1R97-S(&]F('1H
M92!C;&EE;G0@*&%S('-E96X@8GD@=&AE('=E8B!S97)V97(I(&EN('1H92!S
M97-S:6]N/PH@("!$;VEN9R!S;R!W:6QL(&AE;'`@:6YC<F5A<V4@<V5C=7)I
M='D@8GD@96YS=7)I;F<@=&AA="!A;B!A='1A8VME<B!F<F]M"B`@(&%N;W1H
M97(@:&]S="!C86YN;W0@=')Y('1O(&AI:F%C:R!T:&4@<V5S<VEO;BXB/G1R
M=64\+V-O;F9I9V)O;VQE86X^"B`@(#QC;VYF:6=B;V]L96%N(&YA;64](F-H
M96-K8G)O=W-E<B(@9&5S8STB4VAO=6QD('=E(&%L=V%Y<R!S=&]R92!A;F0@
M=F%L:61A=&4*("`@=&AE(&)R;W=S97(@<W1R:6YG(&]F('1H92!C;&EE;G0@
M*&%S('-E96X@8GD@=&AE('=E8B!S97)V97(I(&EN('1H92!S97-S:6]N/PH@
M("!$;VEN9R!S;R!W:6QL(&AE;'`@:6YC<F5A<V4@<V5C=7)I='D@8GD@96YS
M=7)I;F<@=&AA="!A;B!A='1A8VME<B!F<F]M"B`@(&%N;W1H97(@:&]S="!C
M86YN;W0@=')Y('1O(&AI:F%C:R!T:&4@<V5S<VEO;BXB/G1R=64\+V-O;F9I
M9V)O;VQE86X^"B`@(#QC;VYF:6=S=')I;F<@;F%M93TB86QT97)N871E7VQO
M9VEN(B!D97-C/2))9B!T:&ES(&ES(&YO="!F86QS92P@:70@:7,*("`@87-S
M=6UE9"!T;R!B92!T:&4@55),(&]F(&%N(&%L=&5R;F%T92!L;V=I;B!S8W)E
M96X@=VAI8V@@=VEL;"!B92!U<V5D(&EN"B`@('!L86-E(&]F(&AO<F1E)W,@
M9&5F875L="!L;V=I;B!S8W)E96XN(CYF86QS93PO8V]N9FEG<W1R:6YG/@H@
M("`\8V]N9FEG<W1R:6YG(&YA;64](G)E9&ER96-T7V]N7VQO9V]U="(@9&5S
M8STB268@=&AI<R!I<R!N;W0@9F%L<V4L(&ET(&ES"B`@(&%S<W5M960@=&\@
M8F4@=&AE(%523"!O9B!A;B!A;'1E<FYA=&4@;&]G;W5T('!A9V4@=VAI8V@@
M=7-E<G,@=VEL;"!B92!S96YT"B`@('1O('=H96X@=&AE>2!L;V<@;W5T+B(^
M9F%L<V4\+V-O;F9I9W-T<FEN9SX*("`@/&-O;F9I9W-W:71C:"!N86UE/2)D
M<FEV97(B(&1E<V,](E=H870@8F%C:V5N9"!S:&]U;&0@=V4@=7-E(&9O<@H@
M("!A=71H96YT:6-A=&EN9R!U<V5R<R!T;R!(;W)D93\B/@H*("`@(#QC87-E
M(&YA;64](F%P<&QI8V%T:6]N(B!D97-C/2),970@82!(;W)D92!A<'!L:6-A
M=&EO;B!H86YD;&4*("`@(&%U=&AE;G1I8V%T:6]N(CX*("`@("`\8V]N9FEG
M<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\8V]N9FEG96YU;2!N86UE
M/2)A<'`B(&1E<V,](E1H92!A<'!L:6-A=&EO;B!W:&EC:"!I<R!P<F]V:61I
M;F<*("`@("`@875T:&5N=&EC871I;VXB/FEM<`H@("`@("`@/'9A;'5E<SX*
M("`@("`@("`\8V]N9FEG<W!E8VEA;"!N86UE/2)L:7-T+6AO<F1E+6%P<',B
M+SX*("`@("`@(#PO=F%L=65S/@H@("`@("`\+V-O;F9I9V5N=6T^"B`@("`@
M/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C87-E/@H*("`@(#QC87-E(&YA;64]
M(F%U=&\B(&1E<V,](D%U=&]M871I8R!A=71H96YT:6-A=&EO;B!A<R!A(&-E
M<G1A:6X@=7-E<B(^"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US
M(CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)U<V5R;F%M92(@9&5S8STB
M5&AE('5S97)N86UE('1O(&%U=&AE;G1I8V%T92!E=F5R>6]N92!A<R(^:&]R
M9&5?=7-E<CPO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](G!A<W-W;W)D(B!D97-C/2)4:&4@<&%S<W=O<F0@=&\@=7-E(&9O<B!T
M:&4@=7-E<B=S(&-R961E;G1I86QS(B!R97%U:7)E9#TB9F%L<V4B+SX*("`@
M("`@/&-O;F9I9V)O;VQE86X@;F%M93TB<F5Q=65S='5S97(B(&1E<V,](D%L
M;&]W('5S97)N86UE('1O(&)E('!A<W-E9"!B>2!'150L(%!/4U0@;W(@8V]O
M:VEE/R(^9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@("`@/"]C;VYF:6=S96-T
M:6]N/@H@("`@/"]C87-E/@H*("`@(#QC87-E(&YA;64](F-O;7!O<VET92(@
M9&5S8STB0V]M<&]S:71E(&%U=&AE;G1I8V%T:6]N(CX*("`@("`\8V]N9FEG
M9&5S8W)I<'1I;VX^"B`@("`@(%1H:7,@875T:&5N=&EC871I;VX@9')I=F5R
M(&YE961S(&UA;G5A;"!C;VYF:6=U<F%T:6]N(&YO="!P;W-S:6)L90H@("`@
M("!T:')O=6=H('1H:7,@:6YT97)F86-E+B!!9&0@=&AE(&%P<')O<')I871E
M(&-O;F9I9W5R871I;VX@;&EN97,@870@=&AE"B`@("`@(&5N9"!O9B!T:&4@
M9V5N97)A=&5D(&-O;F9I9W5R871I;VX@9FEL92X*("`@("`\+V-O;F9I9V1E
M<V-R:7!T:6]N/@H@("`@/"]C87-E/@H*("`@(#QC87-E(&YA;64](F9T<"(@
M9&5S8STB1E10(&%U=&AE;G1I8V%T:6]N(CX*("`@("`\8V]N9FEG<V5C=&EO
M;B!N86UE/2)P87)A;7,B/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](FAO
M<W1S<&5C(B!D97-C/2)4:&4@:&]S=&YA;64@;W(@25`@861D<F5S<R!O9B!T
M:&4@1E10"B`@("`@('-E<G9E<B(^;&]C86QH;W-T/"]C;VYF:6=S=')I;F<^
M"B`@("`@(#QC;VYF:6=I;G1E9V5R(&YA;64](G!O<G0B(&1E<V,](E1H92!S
M97)V97(@<&]R="!T;R!C;VYN96-T"B`@("`@('1O(CXR,3PO8V]N9FEG:6YT
M96=E<CX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^"@H@("`@
M/&-A<V4@;F%M93TB:'1T<"(@9&5S8STB2%144"`H0F%S:6,@075T:&5N=&EC
M871I;VXO+FAT<&%S<W=D*0H@("`@875T:&5N=&EC871I;VXB/@H@("`@(#QC
M;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB:'1P87-S=V1?9FEL92(@<F5Q=6ER960](F9A;'-E(B!D97-C
M/2)4:&4@;&]C871I;VX@;V8*("`@("`@=&AE(&AT<&%S<W=D(&9I;&4@8V]N
M=&%I;FEN9R!T:&4@=7-E<B!N86UE<R!A;F0@<&%S<W=O<F1S(B\^"B`@("`@
M(#QC;VYF:6=E;G5M(&YA;64](F5N8W)Y<'1I;VXB(&1E<V,](E-P96-I9FEE
M<R!W:&%T(&MI;F0@;V8@<&%S<W=O<F1S(&%R90H@("`@("!I;B!T:&4@:'1P
M87-S=V0@9FEL92(^9&5S"B`@("`@("`\=F%L=65S/@H@("`@("`@(#QV86QU
M93YA<')M9#4\+W9A;'5E/@H@("`@("`@(#QV86QU93YC<GEP=#PO=F%L=64^
M"B`@("`@("`@/'9A;'5E/F-R>7!T+6)L;W=F:7-H/"]V86QU93X*("`@("`@
M("`\=F%L=64^8W)Y<'0M9&5S/"]V86QU93X*("`@("`@("`\=F%L=64^8W)Y
M<'0M;60U/"]V86QU93X*("`@("`@("`\=F%L=64^;60U+6)A<V4V-#PO=F%L
M=64^"B`@("`@("`@/'9A;'5E/FUD-2UH97@\+W9A;'5E/@H@("`@("`@(#QV
M86QU93YP;&%I;CPO=F%L=64^"B`@("`@("`@/'9A;'5E/G-H83PO=F%L=64^
M"B`@("`@("`@/'9A;'5E/G-M9#4\+W9A;'5E/@H@("`@("`@(#QV86QU93YS
M<VAA/"]V86QU93X*("`@("`@(#PO=F%L=65S/@H@("`@("`\+V-O;F9I9V5N
M=6T^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C87-E/@H*("`@(#QC
M87-E(&YA;64](FEM87`B(&1E<V,](DE-05`@875T:&5N=&EC871I;VXB/@H@
M("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@(#QC;VYF
M:6=S=VET8V@@;F%M93TB:6UA<&-O;F9I9R(@9&5S8STB0V]N9FEG=7)A=&EO
M;B!T>7!E(CX*("`@("`@(#QC87-E(&YA;64](F1S;B(@9&5S8STB1%-.(CX*
M("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F1S;B(@9&5S8STB5&AE(&9U
M;&P@24U!4"!C;VYN96-T:6]N"B`@("`@("`@<W1R:6YG(CY[;&]C86QH;W-T
M.C$T,R]I;6%P+VYO=&QS?3PO8V]N9FEG<W1R:6YG/@H@("`@("`@/"]C87-E
M/@H@("`@("`@/&-A<V4@;F%M93TB<V5P87)A=&4B(&1E<V,](E-E<&%R871E
M('9A;'5E<R(^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)H;W-T<W!E
M8R(@9&5S8STB5&AE(&AO<W1N86UE(&]R($E0(&%D9')E<W,@;V8@=&AE"B`@
M("`@("`@<V5R=F5R(CYL;V-A;&AO<W0\+V-O;F9I9W-T<FEN9SX*("`@("`@
M("`\8V]N9FEG:6YT96=E<B!N86UE/2)P;W)T(B!D97-C/2)4:&4@<V5R=F5R
M('!O<G0@=&\@=VAI8V@@=V4@=VEL;`H@("`@("`@(&-O;FYE8W0N($E-05`@
M:7,@9V5N97)A;&QY(#$T,RP@=VAI;&4@24U!4"U34TP@:7,@9V5N97)A;&QY
M"B`@("`@("`@.3DS+B(^,30S/"]C;VYF:6=I;G1E9V5R/@H@("`@("`@(#QC
M;VYF:6=E;G5M(&YA;64](G!R;W1O8V]L(B!D97-C/2)4:&4@8V]N;F5C=&EO
M;B!P<F]T;V-O;"(^:6UA<"]N;W1L<PH@("`@("`@("`\=F%L=65S/@H@("`@
M("`@("`@/'9A;'5E/FEM87`\+W9A;'5E/@H@("`@("`@("`@/'9A;'5E/FEM
M87`O;F]V86QI9&%T92UC97)T/"]V86QU93X*("`@("`@("`@(#QV86QU93YI
M;6%P+VYO=&QS/"]V86QU93X*("`@("`@("`@(#QV86QU93YI;6%P+W1L<SPO
M=F%L=64^"B`@("`@("`@("`\=F%L=64^:6UA<"]T;',O;F]V86QI9&%T92UC
M97)T/"]V86QU93X*("`@("`@("`@(#QV86QU93YI;6%P+W-S;#PO=F%L=64^
M"B`@("`@("`@("`\=F%L=64^:6UA<"]S<VPO;F]V86QI9&%T92UC97)T/"]V
M86QU93X*("`@("`@("`@/"]V86QU97,^"B`@("`@("`@/"]C;VYF:6=E;G5M
M/@H@("`@("`@/"]C87-E/@H@("`@("`\+V-O;F9I9W-W:71C:#X*("`@("`\
M+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^"@H@("`@/&-A<V4@;F%M93TB
M:6US<"(@9&5S8STB24U34"!S97)V97(@875T:&5N=&EC871I;VXB("\^"@H@
M("`@/&-A<V4@;F%M93TB:7!B87-I8R(@9&5S8STB4VEM<&QE($E0(&)A<V5D
M(&%U=&AE;G1I8V%T:6]N(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P
M87)A;7,B/@H@("`@("`\8V]N9FEG;&ES="!N86UE/2)B;&]C:W,B(&1E<V,]
M(D$@;&ES="!O9B!#2412(&UA<VMS('=H:6-H(&%R92!A;&QO=V5D"B`@("`@
M(&%C8V5S<R(O/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*
M"B`@("`\8V%S92!N86UE/2)I<&UA<"(@9&5S8STB25`@8F%S960@875T:&5N
M=&EC871I;VXB/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^
M"B`@("`@(#QC;VYF:6=L:7-T(&YA;64](F)L;V-K<R(@9&5S8STB02!L:7-T
M(&]F($-)1%(@;6%S:W,@=VAI8V@@87)E(&%L;&]W960*("`@("`@86-C97-S
M(B\^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C87-E/@H*("`@(#QC
M87-E(&YA;64](FMR8C4B(&1E<V,](DME<F)E<F]S(&%U=&AE;G1I8V%T:6]N
M(B\^"@H@("`@/&-A<V4@;F%M93TB:V]L86(B(&1E<V,](DMO;&%B(&%U=&AE
M;G1I8V%T:6]N(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B
M/@H@("`@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)L;V=I;E]B;&]C:R(@9&5S
M8STB4VAO=6QD('1H92!L;V=I;B!B92!B;&]C:V5D(&%F=&5R(&$@9VEV96X@
M;G5M8F5R(&]F(&9A:6QE9"!L;V=I;G,_(CX*("`@("`@9F%L<V4\+V-O;F9I
M9V)O;VQE86X^"B`@("`@(#QC;VYF:6=I;G1E9V5R(&YA;64](FQO9VEN7V)L
M;V-K7V-O=6YT(B!D97-C/2)!9G1E<B!H;W=M86YY(&9A:6QE9"!L;V=I;G,@
M=&AE(&QO9VEN('-H;W5L9"!B92!B;&]C:V5D/R(^,SPO8V]N9FEG:6YT96=E
M<CX*("`@("`@/&-O;F9I9VEN=&5G97(@;F%M93TB;&]G:6Y?8FQO8VM?=&EM
M92(@9&5S8STB2&]W;6%N>2!M:6YU=&5S('1H92!L;V=I;B!S:&]U;&0@8F4@
M8FQO8VME9#\B/C4\+V-O;F9I9VEN=&5G97(^"B`@("`@/"]C;VYF:6=S96-T
M:6]N/@H@("`@/"]C87-E/@H*("`@(#QC87-E(&YA;64](FQD87`B(&1E<V,]
M(DQ$05`@875T:&5N=&EC871I;VXB/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA
M;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB:&]S='-P
M96,B(&1E<V,](E1H92!H;W-T;F%M92!O9B!T:&4@3$1!4"!S97)V97(B/FQO
M8V%L:&]S=#PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](F)A<V5D;B(@9&5S8STB5&AE(&)A<V4@1$X@9F]R('1H92!,1$%0('-E
M<G9E<B(O/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F)I;F1D;B(@<F5Q
M=6ER960](F9A;'-E(B!D97-C/2)4:&4@1$X@=7-E9"!T;R!B:6YD('1O('1H
M92!,1$%0('-E<G9E<B(O/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G!A
M<W-W;W)D(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H92!P87-S=V]R9"!U
M<V5D('1O(&)I;F0@=&\@=&AE($Q$05`@<V5R=F5R(B\^"B`@("`@(#QC;VYF
M:6=E;G5M(&YA;64](G9E<G-I;VXB(&1E<V,](DQ$05`@4')O=&]C;VP@5F5R
M<VEO;B(^,PH@("`@("`@/'9A;'5E<SX*("`@("`@("`\=F%L=64@9&5S8STB
M3$1!4'8R("A$97!R96-A=&5D*2(^,CPO=F%L=64^"B`@("`@("`@/'9A;'5E
M(&1E<V,](DQ$05!V,R(^,SPO=F%L=64^"B`@("`@("`\+W9A;'5E<SX*("`@
M("`@/"]C;VYF:6=E;G5M/@H@("`@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)A
M9"(@9&5S8STB27,@=&AI<R!A;B!!1"!S97)V97(_(CYF86QS93PO8V]N9FEG
M8F]O;&5A;CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)U:60B(&1E<V,]
M(E1H92!U<V5R;F%M92!S96%R8V@@:V5Y("AS970@=&\@<V%M86-C;W5N=&YA
M;64@9F]R($%$*2(O/@H@("`@("`\8V]N9FEG96YU;2!N86UE/2)E;F-R>7!T
M:6]N(B!D97-C/2)!;&=O<FET:&T@=&\@96YC<GEP="!P87-S=V]R9',B/FUD
M-2UH97@*("`@("`@(#QV86QU97,^"B`@("`@("`@/'9A;'5E(&1E<V,](F%P
M<FUD-2(^87!R;60U/"]V86QU93X*("`@("`@("`\=F%L=64@9&5S8STB8W)Y
M<'0B/F-R>7!T/"]V86QU93X*("`@("`@("`\=F%L=64@9&5S8STB8W)Y<'0M
M9&5S(CYC<GEP="UD97,\+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C/2)C
M<GEP="UM9#4B/F-R>7!T+6UD-3PO=F%L=64^"B`@("`@("`@/'9A;'5E(&1E
M<V,](F-R>7!T+6)L;W=F:7-H(CYC<GEP="UB;&]W9FES:#PO=F%L=64^"B`@
M("`@("`@/'9A;'5E(&1E<V,](FUD-2UB87-E-C0B/FUD-2UB87-E-C0\+W9A
M;'5E/@H@("`@("`@(#QV86QU92!D97-C/2)M9#4M:&5X(CYM9#4M:&5X/"]V
M86QU93X*("`@("`@("`\=F%L=64@9&5S8STB;7-A9"(^;7-A9#PO=F%L=64^
M"B`@("`@("`@/'9A;'5E(&1E<V,](G!L86EN(CYP;&%I;CPO=F%L=64^"B`@
M("`@("`@/'9A;'5E(&1E<V,](G-S:&$B/G-S:&$\+W9A;'5E/@H@("`@("`@
M(#QV86QU92!D97-C/2)S;60U(CYS;60U/"]V86QU93X*("`@("`@(#PO=F%L
M=65S/@H@("`@("`\+V-O;F9I9V5N=6T^"@H@("`@("`\8V]N9FEG;&ES="!N
M86UE/2)N97=U<V5R7V]B:F5C=&-L87-S(B!D97-C/2)7:&%T(&]B:F5C=&-L
M87-S97,@<VAO=6QD(&$@;F5W('5S97(@86-C;W5N="!B92!M96UB97(@;V8_
M(%1H97-E(&]B:F5C=&-L87-S97,@<VAO=6QD(&-O=F5R('1H92!C;BQS;BQU
M<V5R4&%S<W=O<F0@871T<FEB=71E<R!A<R!W96QL(&%S('1H92!U<V5R;F%M
M92!S96%R8V@@:V5Y(CYS:&%D;W=!8V-O=6YT+&EN971/<F=097)S;VX\+V-O
M;F9I9VQI<W0^"@H@("`@("`\8V]N9FEG<W=I=&-H(&YA;64](F9I;'1E<E]T
M>7!E(B!D97-C/2)(;W<@=&\@<W!E8VEF>2!A(&9I;'1E<B!F;W(@=&AE('5S
M97(@;&ES=',B/F]B:F5C=&-L87-S"B`@("`@("`\8V%S92!N86UE/2)O8FIE
M8W1C;&%S<R(@9&5S8STB3VYE(&]R(&UO<F4@;V)J96-T8VQA<W,@9FEL=&5R
M<R(^"B`@("`@("`@/&-O;F9I9VQI<W0@;F%M93TB;V)J96-T8VQA<W,B(&1E
M<V,](E1H92!O8FIE8W1C;&%S<R!F:6QT97(@=7-E9"!T;R!S96%R8V@@9F]R
M('5S97)S+B!#86X@8F4@82!S:6YG;&4@;V)J96-T8VQA<W,@;W(@82!L:7-T
M+B(O/@H@("`@("`@/"]C87-E/@H@("`@("`@/&-A<V4@;F%M93TB9G)E92(@
M9&5S8STB02!C;VUP;&5T92!,1$%0(&9I;'1E<B!E>'!R97-S:6]N(CX*("`@
M("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F9I;'1E<B(@9&5S8STB5&AE($Q$
M05`@4D9#(&9O<FUA='1E9"!F:6QT97(@=7-E9"!T;R!S96%R8V@@9F]R('5S
M97)S+B(O/@H@("`@("`@/"]C87-E/@H@("`@("`\+V-O;F9I9W-W:71C:#X*
M"B`@("`@(#QC;VYF:6=S=VET8V@@;F%M93TB<&%S<W=O<F1?97AP:7)A=&EO
M;B(@9&5S8STB16YA8FQE('1H92!C<F5A=&EN9R!O9B!A8V-O=6YT<R!W:71H
M(&5X<&ER:6YG('!A<W-W;W)D<S\@*$YO=&4Z($YE=R!U<V5R<R!S:&]U;&0@
M:&%V92!T:&4@<VAA9&]W06-C;W5N="!O8FIE8W1C;&%S<RDB/FYO"B`@("`@
M("`\8V%S92!N86UE/2)N;R(@9&5S8STB;F\B("\^"B`@("`@("`\8V%S92!N
M86UE/2)Y97,B(&1E<V,](GEE<R(^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N
M86UE/2)M:6YA9V4B(&1E<V,](D%F=&5R(&AO=R!M86YY(&1A>7,@;6%Y(&$@
M<&%S<W=O<F0@8F4@8VAA;F=E9"!A9V%I;C\B/C4\+V-O;F9I9W-T<FEN9SX*
M("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](FUA>&%G92(@9&5S8STB2&]W
M(&UA;GD@9&%Y<R!W:6QL(&$@<&%S<W=O<F0@<F5M86EN('9A;&ED/R(^,S`\
M+V-O;F9I9W-T<FEN9SX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G=A
M<FYA9V4B(&1E<V,](DAO=R!M86YY(&1A>7,@8F5F;W)E(&5X<&ER97)Y('-H
M;W5L9"!A('5S97(@8F4@=V%R;F5D/R(^-3PO8V]N9FEG<W1R:6YG/@H@("`@
M("`@/"]C87-E/@H@("`@("`\+V-O;F9I9W-W:71C:#X*("`@("`\+V-O;F9I
M9W-E8W1I;VX^"B`@("`\+V-A<V4^"@H@("`@/&-A<V4@;F%M93TB;&]G:6XB
M(&1E<V,](DQO9VEN("AS=2D@875T:&5N=&EC871I;VXB/@H@("`@(#QC;VYF
M:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB;&]C871I;VXB(&1E<V,](DQO8V%T:6]N(&]F('1H92!S=2!B:6YA
M<GDB/B]B:6XO<W4\+V-O;F9I9W-T<FEN9SX*("`@("`\+V-O;F9I9W-E8W1I
M;VX^"B`@("`\+V-A<V4^"@H@("`@/&-A<V4@;F%M93TB;6-A;"(@9&5S8STB
M34-!3"!A=71H96YT:6-A=&EO;B(^"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M
M93TB<&%R86US(CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)C86QE;F1A
M<B(@9&5S8STB5&AE($U#04P@8V%L96YD87(@;F%M92(O/@H@("`@(#PO8V]N
M9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*"B`@("`\8V%S92!N86UE/2)P86TB
M(&1E<V,](E!!32`H4&QU9V=A8FQE($%U=&AE;G1I8V%T:6]N($UO9'5L97,I
M(&%U=&AE;G1I8V%T:6]N(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P
M87)A;7,B/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G-E<G9I8V4B(&1E
M<V,](E1H92!N86UE(&]F('1H92!004T@<V5R=FEC92!T;R!U<V4@=VAE;B!A
M=71H96YT:6-A=&EN9R(^<&AP/"]C;VYF:6=S=')I;F<^"B`@("`@/"]C;VYF
M:6=S96-T:6]N/@H@("`@/"]C87-E/@H*("`@(#QC87-E(&YA;64](G!A<W-W
M9"(@9&5S8STB<&%S<W=D(&9I;&4@875T:&5N=&EC871I;VXB/@H@("`@(#QC
M;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB9FEL96YA;64B(&1E<V,](E1H92!P87-S=V0@9FEL92!T;R!U
M<V4B/B]E=&,O<&%S<W=D/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=B
M;V]L96%N(&YA;64](FQO8VLB(&1E<V,](E-H;W5L9"!W92!L;V-K('1H92!P
M87-S=V0@9FEL93\B/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@("`@(#PO8V]N
M9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*"B`@("`\8V%S92!N86UE/2)R861I
M=7,B(&1E<V,](E)A9&EU<R!A=71H96YT:6-A=&EO;B(^"B`@("`@/&-O;F9I
M9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9W-T<FEN9R!N
M86UE/2)H;W-T(B!D97-C/2)4:&4@4D%$2553(&AO<W0@=&\@=7-E("A)4"!A
M9&1R97-S(&]R(&9U;&QY('%U86QI9FEE9"!H;W-T;F%M92DB/FQO8V%L:&]S
M=#PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)P
M;W)T(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H92!P;W)T('1O('5S92!O
M;B!T:&4@4D%$2553('-E<G9E<B(O/@H@("`@("`\8V]N9FEG96YU;2!N86UE
M/2)M971H;V0B(&1E<V,](E1H92!2041)55,@;65T:&]D('1O('5S92!F;W(@
M=F%L:61A=&EN9R!T:&4@<F5Q=65S="(^4$%0"B`@("`@("`\=F%L=65S/@H@
M("`@("`@(#QV86QU92!D97-C/2)005`B/E!!4#PO=F%L=64^"B`@("`@("`@
M/'9A;'5E(&1E<V,](D-(05!?340U("AN;W0@<W5P<&]R=&5D(&%T('1H92!M
M;VUE;G0I(CY#2$%07TU$-3PO=F%L=64^"B`@("`@("`@/'9A;'5E(&1E<V,]
M(DU30TA!4'8Q("AN;W0@<W5P<&]R=&5D(&%T('1H92!M;VUE;G0I(CY-4T-(
M05!V,3PO=F%L=64^"B`@("`@("`@/'9A;'5E(&1E<V,](DU30TA!4'8R("AN
M;W0@<W5P<&]R=&5D(&%T('1H92!M;VUE;G0I(CY-4T-(05!V,CPO=F%L=64^
M"B`@("`@("`\+W9A;'5E<SX*("`@("`@/"]C;VYF:6=E;G5M/@H@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](FYA<R(@<F5Q=6ER960](F9A;'-E(B!D97-C
M/2)4:&4@4D%$2553($Y!4R!I9&5N=&EF:65R('1O('5S92XB("\^"B`@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB<V5C<F5T(B!D97-C/2)4:&4@4D%$2553
M('-H87)E9"!S96-R970@<W1R:6YG(&9O<B!T:&4*("`@("`@:&]S="X@5&AE
M(%)!1$E54R!P<F]T;V-O;"!I9VYO<F5S(&%L;"!B=70@=&AE(&QE861I;F<@
M,3(X(&)Y=&5S(&]F('1H90H@("`@("!S:&%R960@<V5C<F5T+B(O/@H@("`@
M("`\8V]N9FEG:6YT96=E<B!N86UE/2)R971R:65S(B!R97%U:7)E9#TB9F%L
M<V4B(&1E<V,](E1H92!M87AI;75M(&YU;6)E<@H@("`@("!O9B!R97!E871E
M9"!R97%U97-T<R!T;R!M86ME(&)E9F]R92!G:79I;F<@=7`@6S-=(B\^"B`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<W5F9FEX(B!R97%U:7)E9#TB9F%L
M<V4B(&1E<V,](E1H92!D;VUA:6X@;F%M92!T;R!A9&0*("`@("`@=&\@=6YQ
M=6%L:69I960@=7-E<B!N86UE<R(O/@H@("`@("`\8V]N9FEG:6YT96=E<B!N
M86UE/2)T:6UE;W5T(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H92!T:6UE
M;W5T(&9O<@H@("`@("!R96-E:79I;F<@<F5P;&EE<R!F<F]M('1H92!S97)V
M97(@*&EN('-E8V]N9',I(%LS72(O/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*
M("`@(#PO8V%S93X*"B`@("`\8V%S92!N86UE/2)S87-L(B!D97-C/2)305-,
M(&%U=&AE;G1I8V%T:6]N(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P
M87)A;7,B/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F%P<"(@9&5S8STB
M5&AE(&YA;64@;V8@=&AE(&%U=&AE;G1I8V%T:6YG"B`@("`@(&%P<&QI8V%T
M:6]N(CYH;W)D93PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG
M(&YA;64](G-E<G9I8V4B(&1E<V,](E1H92!N86UE(&]F('1H92!305-,('-E
M<G9I8V4@=&\@=7-E"B`@("`@('=H96X@875T:&5N=&EC871I;F<B/G!H<#PO
M8V]N9FEG<W1R:6YG/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S
M93X*"B`@("`\8V%S92!N86UE/2)S;6(B(&1E<V,](E--0B!A=71H96YT:6-A
M=&EO;B(^"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)H;W-T<W!E8R(@9&5S8STB25`L($1.
M4R!.86UE+"!O<B!.971":6]S($YA;64@;V8@=&AE"B`@("`@(%--0B!S97)V
M97(@=&\@875T:&5N=&EC871E('=I=&@B/FQO8V%L:&]S=#PO8V]N9FEG<W1R
M:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F1O;6%I;B(@9&5S8STB
M5&AE(&1O;6%I;B!N86UE('1O(&%U=&AE;G1I8V%T92!W:71H(B\^"B`@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB9W)O=7`B(')E<75I<F5D/2)F86QS92(@
M9&5S8STB3W!T:6]N86P@9W)O=7`@;F%M90H@("`@("!T:&%T('1H92!U<V5R
M(&UU<W0@8F4@82!M96UB97(@;V8B+SX*("`@("`\+V-O;F9I9W-E8W1I;VX^
M"B`@("`\+V-A<V4^"@H@("`@/&-A<V4@;F%M93TB<W%L(B!D97-C/2)344P@
M875T:&5N=&EC871I;VXB/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A
M<F%M<R(^"B`@("`@(#QC;VYF:6=S<6P@<W=I=&-H;F%M93TB9')I=F5R8V]N
M9FEG(B`O/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G1A8FQE(B!R97%U
M:7)E9#TB9F%L<V4B(&1E<V,](E1H92!N86UE(&]F('1H92!A=71H"B`@("`@
M('1A8FQE(&EN('1H92!D871A8F%S92!;:&]R9&5?=7-E<G-=(B\^"B`@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB=7-E<FYA;65?9FEE;&0B(')E<75I<F5D
M/2)F86QS92(@9&5S8STB5&AE(&YA;64@;V8@=&AE"B`@("`@('5S97)N86UE
M(&9I96QD(&EN('1H92!A=71H('1A8FQE(%MU<V5R7W5I9%TB+SX*("`@("`@
M/&-O;F9I9W-T<FEN9R!N86UE/2)P87-S=V]R9%]F:65L9"(@<F5Q=6ER960]
M(F9A;'-E(B!D97-C/2)4:&4@;F%M92!O9B!T:&4*("`@("`@<&%S<W=O<F0@
M9FEE;&0@:6X@=&AE(&%U=&@@=&%B;&4@6W5S97)?<&%S<UTB+SX*("`@("`@
M/&-O;F9I9W-T<FEN9R!N86UE/2)S;V9T7V5X<&ER871I;VY?9FEE;&0B(')E
M<75I<F5D/2)F86QS92(@9&5S8STB5&AE"B`@("`@(&YA;64@;V8@82!F:65L
M9"!C;VYT86EN:6YG(&$@54Y)6"!T:6UE<W1A;7`N("!7:&5N(&$@=7-E<B!L
M;V=S(&EN(&%F=&5R"B`@("`@('1H92!S<&5C:69I960@=&EM92P@:68@)W!A
M<W-W9"<@:7,@:6YS=&%L;&5D+"!T:&%T('5S97(@=VEL;"!B92!A<VME9"!T
M;PH@("`@("!C:&%N9V4@:&ES(&]R(&AE<B!P87-S=V]R9"X@(%1H:7,@9F5A
M='5R92!I<R!D:7-A8FQE9"!B>2!D969A=6QT+B(O/@H@("`@("`\8V]N9FEG
M<W1R:6YG(&YA;64](FAA<F1?97AP:7)A=&EO;E]F:65L9"(@<F5Q=6ER960]
M(F9A;'-E(B!D97-C/2)4:&4*("`@("`@;F%M92!O9B!A(&9I96QD(&-O;G1A
M:6YI;F<@82!53DE8('1I;65S=&%M<"X@($$@=7-E<B!W:6QL(&YO="!B92!A
M8FQE('1O"B`@("`@(&QO9R!I;B!A9G1E<B!T:&4@<W!E8VEF:65D('1I;64N
M("!4:&ES(&9E871U<F4@:7,@9&ES86)L960@8GD@9&5F875L="XB+SX*("`@
M("`@/&-O;F9I9VEN=&5G97(@;F%M93TB<V]F=%]E>'!I<F%T:6]N7W=I;F1O
M=R(@<F5Q=6ER960](F9A;'-E(@H@("`@("!D97-C/2)4:&ES(&ES(&AO=R!O
M9G1E;BP@:6X@9&%Y<RP@=&AE('5S97(@;75S="!C:&%N9V4@:&ES(&]R(&AE
M<@H@("`@("!P87-S=V]R9"X@(%=H96X@=&AE('5S97(G<R!P87-S=V]R9"!I
M<R!U<&1A=&5D+"!T:&4@)G%U;W0[<V]F="9Q=6]T.PH@("`@("!E>'!I<F%T
M:6]N(&ES('-E="!T:&ES(&UA;GD@9&%Y<R!I;B!T:&4@9G5T=7)E+B`@268@
M;F]T('!R;W9I9&5D+`H@("`@("!T:&4@=7-E<B=S('!A<W-W;W)D('=I;&P@
M;F]T(&5X<&ER92!B>2!D969A=6QT+B(O/@H@("`@("`\8V]N9FEG:6YT96=E
M<B!N86UE/2)H87)D7V5X<&ER871I;VY?=VEN9&]W(B!R97%U:7)E9#TB9F%L
M<V4B(&1E<V,](E1H90H@("`@("!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@9W)A
M8V4@<&5R:6]D('1H92!U<V5R(&AA<R!T;R!C:&%N9V4@:&ES(&]R(&AE<@H@
M("`@("!P87-S=V]R9"!A9G1E<B!I="!H87,@97AP:7)E9"X@($EF(&YO="!P
M<F]V:61E9"P@=&AE(&=R86-E('!E<FEO9"!W:6QL"B`@("`@(&YO="!E>'!I
M<F4N(B\^"B`@("`@(#QC;VYF:6=E;G5M(&YA;64](F5N8W)Y<'1I;VXB(')E
M<75I<F5D/2)F86QS92(@9&5S8STB5&AE(&5N8W)Y<'1I;VX@=&\@=7-E"B`@
M("`@('1O('-T;W)E('1H92!P87-S=V]R9"!I;B!T:&4@=&%B;&4B/FUD-2UH
M97@*("`@("`@(#QV86QU97,^"B`@("`@("`@/'9A;'5E/F-R>7!T/"]V86QU
M93X*("`@("`@("`\=F%L=64^8W)Y<'0M8FQO=V9I<V@\+W9A;'5E/@H@("`@
M("`@(#QV86QU93YC<GEP="UD97,\+W9A;'5E/@H@("`@("`@(#QV86QU93YC
M<GEP="UM9#4\+W9A;'5E/@H@("`@("`@(#QV86QU93YM9#4M8F%S938T/"]V
M86QU93X*("`@("`@("`\=F%L=64^;60U+6AE>#PO=F%L=64^"B`@("`@("`@
M/'9A;'5E/G!L86EN/"]V86QU93X*("`@("`@("`\=F%L=64^<VAA/"]V86QU
M93X*("`@("`@("`\=F%L=64^<VUD-3PO=F%L=64^"B`@("`@("`@/'9A;'5E
M/G-S:&$\+W9A;'5E/@H@("`@("`@/"]V86QU97,^"B`@("`@(#PO8V]N9FEG
M96YU;3X*("`@("`@/&-O;F9I9V)O;VQE86X@;F%M93TB<VAO=U]E;F-R>7!T
M:6]N(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E!R97!E;F0@=&AE"B`@("`@
M(&5N8W)Y<'1I;VX@:6X@=&AE('!A<W-W;W)D(&9I96QD/R(^9F%L<V4\+V-O
M;F9I9V)O;VQE86X^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C87-E
M/@H*("`@(#QC87-E(&YA;64](F-U<W1O;7-Q;"(@9&5S8STB4U%,(&%U=&AE
M;G1I8V%T:6]N('<O8W5S=&]M+6UA9&4@<75E<FEE<R(^"B`@("`@/&-O;F9I
M9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9V5N=6T@;F%M
M93TB<&AP='EP92(@9&5S8STB5&AE(&YA;64@;V8@=&AE(&1A=&%B87-E(CYM
M>7-Q;`H@("`@("`@/'9A;'5E<SX*("`@("`@("`\=F%L=64@9&5S8STB36EC
M<F]S;V9T(%-13"!397)V97(B/FUS<W%L/"]V86QU93X*("`@("`@("`\=F%L
M=64@9&5S8STB37E344PB/FUY<W%L/"]V86QU93X*("`@("`@("`\=F%L=64@
M9&5S8STB3T1"0R(^;V1B8SPO=F%L=64^"B`@("`@("`@/'9A;'5E(&1E<V,]
M(D]R86-L92`X(CYO8VDX/"]V86QU93X*("`@("`@("`\=F%L=64@9&5S8STB
M4&]S=&=R95-13"(^<&=S<6P\+W9A;'5E/@H@("`@("`@/"]V86QU97,^"B`@
M("`@(#PO8V]N9FEG96YU;3X*("`@("`@/&-O;F9I9W-W:71C:"!N86UE/2)P
M<F]T;V-O;"(@9&5S8STB5VAA="!P<F]T;V-O;"!W:6QL('=E('5S92!T;R!C
M;VYN96-T('1O('1H92!D871A8F%S93\B/G5N:7@*("`@("`@(#QC87-E(&YA
M;64](G5N:7@B(&1E<V,](E5.25@@4V]C:V5T<R(^"B`@("`@("`@/&-O;F9I
M9W-T<FEN9R!N86UE/2)S;V-K970B(')E<75I<F5D/2)F86QS92(@9&5S8STB
M3&]C871I;VX@;V8@54Y)6"!S;V-K970B/CPO8V]N9FEG<W1R:6YG/@H@("`@
M("`@/"]C87-E/@H@("`@("`@/&-A<V4@;F%M93TB=&-P(B!D97-C/2)40U`O
M25`B/@H@("`@("`@(#QC;VYF:6=I;G1E9V5R(&YA;64](G!O<G0B(')E<75I
M<F5D/2)F86QS92(@9&5S8STB4&]R="!T:&4@1$(@:7,@<G5N;FEN9R!O;BP@
M:68@;F]N+7-T86YD87)D(CXU-#,R/"]C;VYF:6=I;G1E9V5R/@H@("`@("`@
M/"]C87-E/@H@("`@("`\+V-O;F9I9W-W:71C:#X*("`@("`@/&-O;F9I9W-T
M<FEN9R!N86UE/2)H;W-T<W!E8R(@9&5S8STB5VAA="!H;W-T;F%M92!I<R!T
M:&4@9&%T86)A<V4@<V5R=F5R(')U;FYI;F<@;VXL(&]R('=H870@:7,@=&AE
M(&YA;64@;V8@=&AE('-Y<W1E;2!$4TX@=&\@=7-E/R(^;&]C86QH;W-T/"]C
M;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=7-E<FYA
M;64B(&1E<V,](E=H870@=7-E<FYA;64@9&\@=V4@875T:&5N=&EC871E('1O
M('1H92!D871A8F%S92!S97)V97(@87,_(CYH;W)D93PO8V]N9FEG<W1R:6YG
M/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G!A<W-W;W)D(B!R97%U:7)E
M9#TB9F%L<V4B(&1E<V,](E=H870@<&%S<W=O<F0@9&\@=V4@875T:&5N=&EC
M871E('1O('1H92!D871A8F%S92!S97)V97(@=VET:#\B+SX*("`@("`@/&-O
M;F9I9W-T<FEN9R!N86UE/2)D871A8F%S92(@9&5S8STB5VAA="!D871A8F%S
M92!N86UE+W1A8FQE<W!A8V4@87)E('=E('5S:6YG/R(^:&]R9&4\+V-O;F9I
M9W-T<FEN9SX*("`@("`@/&-O;F9I9V1E<V-R:7!T:6]N/@H@("`@("`@4V]M
M92!S<&5C:6%L('1O:V5N<R!C86X@8F4@=7-E9"!I;B!T:&4@<W%L('%U97)Y
M+B!4:&5Y(&%R92!R97!L86-E9"!A=`H@("`@("`@=&AE('%U97)Y('-T86=E
M.B9L=#MU;"9G=#L*("`@("`@("9L=#ML:29G=#LB7$PB('=I;&P@8F4@<F5P
M;&%C960@8GD@=&AE('5S97(G<R!L;V=I;B9L=#LO;&DF9W0["B`@("`@("`F
M;'0[;&DF9W0[(EQ0(B!W:6QL(&)E(')E<&QA8V5D(&)Y('1H92!U<V5R)W,@
M<&%S<W=O<F0F;'0[+VQI)F=T.PH@("`@("`@)FQT.VQI)F=T.R)<3R(@=VEL
M;"!B92!R97!L86-E9"!B>2!T:&4@;VQD('5S97(G<R!L;V=I;B`H<F5Q=6ER
M960@9F]R"B`@("`@("!U<&1A=&4I)FQT.R]L:29G=#LF;'0[+W5L)F=T.PH@
M("`@("`@16<Z(")314Q%0U0@*B!&4D]-('5S97)S(%=(15)%('5I9"`](%Q,
M($%.1"!P87-S=V0@/2!<4"!!3D0@8FEL;&EN9R`]"B`@("`@("`G<&%I9"<B
M"B`@("`@(#PO8V]N9FEG9&5S8W)I<'1I;VX^"B`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB<75E<GE?875T:"(@9&5S8STB075T:&5N=&EC871E('1H92!U
M<V5R(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<75E<GE?861D(B!D
M97-C/2)!9&0@=7-E<B(O/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G%U
M97)Y7W5P9&%T92(@9&5S8STB57!D871E('5S97(B+SX*("`@("`@/&-O;F9I
M9W-T<FEN9R!N86UE/2)Q=65R>5]R96UO=F4B(&1E<V,](E)E;6]V92!U<V5R
M(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<75E<GE?;&ES="(@9&5S
M8STB3&ES="!U<V5R<R(O/@H@("`@("`\8V]N9FEG96YU;2!N86UE/2)E;F-R
M>7!T:6]N(B!D97-C/2)4:&4@96YC<GEP=&EO;B!T;R!U<V4@=&\@<W1O<F4@
M=&AE"B`@("`@('!A<W-W;W)D(&EN('1H92!T86)L92(^;60U+6AE>`H@("`@
M("`@/'9A;'5E<SX*("`@("`@("`\=F%L=64^87!R;60U/"]V86QU93X*("`@
M("`@("`\=F%L=64^8W)Y<'0\+W9A;'5E/@H@("`@("`@(#QV86QU93YC<GEP
M="UB;&]W9FES:#PO=F%L=64^"B`@("`@("`@/'9A;'5E/F-R>7!T+61E<SPO
M=F%L=64^"B`@("`@("`@/'9A;'5E/F-R>7!T+6UD-3PO=F%L=64^"B`@("`@
M("`@/'9A;'5E/FUD-2UB87-E-C0\+W9A;'5E/@H@("`@("`@(#QV86QU93YM
M9#4M:&5X/"]V86QU93X*("`@("`@("`\=F%L=64^<&QA:6X\+W9A;'5E/@H@
M("`@("`@(#QV86QU93YS:&$\+W9A;'5E/@H@("`@("`@(#QV86QU93YS;60U
M/"]V86QU93X*("`@("`@("`\=F%L=64^<W-H83PO=F%L=64^"B`@("`@("`\
M+W9A;'5E<SX*("`@("`@/"]C;VYF:6=E;G5M/@H@("`@("`\8V]N9FEG8F]O
M;&5A;B!N86UE/2)S:&]W7V5N8W)Y<'1I;VXB(&1E<V,](E!R97!E;F0@=&AE
M(&5N8W)Y<'1I;VX@:6X@=&AE"B`@("`@('!A<W-W;W)D(&9I96QD/R(^9F%L
M<V4\+V-O;F9I9V)O;VQE86X^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@
M/"]C87-E/@H*("`@(#QC87-E(&YA;64](F-Y<G-Q;"(@9&5S8STB4U%,(&EM
M<&QE;65N=&%T:6]N(&9O<B!T:&4@0WER=7,@24U!4"!S97)V97(B/@H@("`@
M(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S
M=')I;F<@;F%M93TB8WER861M:6XB(&1E<V,](E1H92!U<V5R;F%M92!O9B!T
M:&4@8WER=7,*("`@("`@861M:6YI<W1R871O<B(O/@H@("`@("`\8V]N9FEG
M<W1R:6YG(&YA;64](F-Y<G!A<W,B(&1E<V,](E1H92!P87-S=V]R9"!F;W(@
M=&AE(&-Y<G5S"B`@("`@(&%D;6EN:7-T<F%T;W(B+SX*("`@("`@/&-O;F9I
M9W-T<FEN9R!N86UE/2)I;6%P7V1S;B(@9&5S8STB5&AE(&9U;&P@24U!4"!$
M4TX*("`@("`@*&DN92X@>VQO8V%L:&]S=#HY.3,O:6UA<"]S<VPO;F]V86QI
M9&%T92UC97)T?2DB+SX*("`@("`@/&-O;F9I9V5N=6T@;F%M93TB<&AP='EP
M92(@9&5S8STB5&AE(&YA;64@;V8@=&AE(&1A=&%B87-E(CYM>7-Q;`H@("`@
M("`@/'9A;'5E<SX*("`@("`@("`\=F%L=64@9&5S8STB36EC<F]S;V9T(%-1
M3"!397)V97(B/FUS<W%L/"]V86QU93X*("`@("`@("`\=F%L=64@9&5S8STB
M37E344PB/FUY<W%L/"]V86QU93X*("`@("`@("`\=F%L=64@9&5S8STB37E3
M44P@*&UY<W%L:2DB/FUY<W%L:3PO=F%L=64^"B`@("`@("`@/'9A;'5E(&1E
M<V,](D]$0D,B/F]D8F,\+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C/2)/
M<F%C;&4@."(^;V-I.#PO=F%L=64^"B`@("`@("`@/'9A;'5E(&1E<V,](E!O
M<W1G<F5344PB/G!G<W%L/"]V86QU93X*("`@("`@(#PO=F%L=65S/@H@("`@
M("`\+V-O;F9I9V5N=6T^"B`@("`@(#QC;VYF:6=S=VET8V@@;F%M93TB<')O
M=&]C;VPB(&1E<V,](E=H870@<')O=&]C;VP@=VEL;"!W92!U<V4@=&\@8V]N
M;F5C="!T;R!T:&4@9&%T86)A<V4_(CYU;FEX"B`@("`@("`\8V%S92!N86UE
M/2)U;FEX(B!D97-C/2)53DE8(%-O8VME=',B/@H@("`@("`@(#QC;VYF:6=S
M=')I;F<@;F%M93TB<V]C:V5T(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](DQO
M8V%T:6]N(&]F(%5.25@@<V]C:V5T(CX\+V-O;F9I9W-T<FEN9SX*("`@("`@
M(#PO8V%S93X*("`@("`@(#QC87-E(&YA;64](G1C<"(@9&5S8STB5$-0+TE0
M(CX*("`@("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)P;W)T(B!R97%U:7)E
M9#TB9F%L<V4B(&1E<V,](E!O<G0@=&AE($1"(&ES(')U;FYI;F<@;VXL(&EF
M(&YO;BUS=&%N9&%R9"(^-30S,CPO8V]N9FEG:6YT96=E<CX*("`@("`@(#PO
M8V%S93X*("`@("`@/"]C;VYF:6=S=VET8V@^"B`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB:&]S='-P96,B(&1E<V,](E=H870@:&]S=&YA;64@:7,@=&AE
M(&1A=&%B87-E('-E<G9E<B!R=6YN:6YG(&]N+"!O<B!W:&%T(&ES('1H92!N
M86UE(&]F('1H92!S>7-T96T@1%-.('1O('5S93\B/FQO8V%L:&]S=#PO8V]N
M9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G5S97)N86UE
M(B!D97-C/2)7:&%T('5S97)N86UE(&1O('=E(&%U=&AE;G1I8V%T92!T;R!T
M:&4@9&%T86)A<V4@<V5R=F5R(&%S/R(^:&]R9&4\+V-O;F9I9W-T<FEN9SX*
M("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P87-S=V]R9"(@<F5Q=6ER960]
M(F9A;'-E(B!D97-C/2)7:&%T('!A<W-W;W)D(&1O('=E(&%U=&AE;G1I8V%T
M92!T;R!T:&4@9&%T86)A<V4@<V5R=F5R('=I=&@_(B\^"B`@("`@(#QC;VYF
M:6=S=')I;F<@;F%M93TB9&%T86)A<V4B(&1E<V,](E=H870@9&%T86)A<V4@
M;F%M92]T86)L97-P86-E(&%R92!W90H@("`@("!U<VEN9S\B/FAO<F1E/"]C
M;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=&%B;&4B
M(&1E<V,](E1H92!N86UE(&]F('1H92!A=71H('1A8FQE(&EN('1H90H@("`@
M("!D871A8F%S92(^:&]R9&5?=7-E<G,\+V-O;F9I9W-T<FEN9SX*("`@("`@
M/&-O;F9I9W-T<FEN9R!N86UE/2)U<V5R;F%M95]F:65L9"(@9&5S8STB5&AE
M(&YA;64@;V8@=&AE('5S97)N86UE(&9I96QD"B`@("`@(&EN('1H92!A=71H
M('1A8FQE(CYU<V5R7W5I9#PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG
M<W1R:6YG(&YA;64](G!A<W-W;W)D7V9I96QD(B!D97-C/2)4:&4@;F%M92!O
M9B!T:&4@<&%S<W=O<F0@9FEE;&0*("`@("`@:6X@=&AE(&%U=&@@=&%B;&4B
M/G5S97)?<&%S<SPO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG
M(&YA;64](F1O;6%I;E]F:65L9"(@9&5S8STB268@<V5T('1O(&%N>71H:6YG
M(&]T:&5R('1H86X*("`@("`@)VYO;F4G('1H:7,@:7,@=7-E9"!A<R!F:65L
M9"!N86UE('=H97)E(&1O;6%I;B!I<PH@("`@("!S=&]R960B/FYO;F4\+V-O
M;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9V5N=6T@;F%M93TB96YC<GEP=&EO
M;B(@9&5S8STB5&AE(&5N8W)Y<'1I;VX@=&\@=7-E('1O('-T;W)E('1H90H@
M("`@("!P87-S=V]R9"!I;B!T:&4@=&%B;&4B/FUD-2UH97@*("`@("`@(#QV
M86QU97,^"B`@("`@("`@/'9A;'5E/F%P<FUD-3PO=F%L=64^"B`@("`@("`@
M/'9A;'5E/F-R>7!T/"]V86QU93X*("`@("`@("`\=F%L=64^8W)Y<'0M8FQO
M=V9I<V@\+W9A;'5E/@H@("`@("`@(#QV86QU93YC<GEP="UD97,\+W9A;'5E
M/@H@("`@("`@(#QV86QU93YC<GEP="UM9#4\+W9A;'5E/@H@("`@("`@(#QV
M86QU93YM9#4M8F%S938T/"]V86QU93X*("`@("`@("`\=F%L=64^;60U+6AE
M>#PO=F%L=64^"B`@("`@("`@/'9A;'5E/G!L86EN/"]V86QU93X*("`@("`@
M("`\=F%L=64^<VAA/"]V86QU93X*("`@("`@("`\=F%L=64^<VUD-3PO=F%L
M=64^"B`@("`@("`@/'9A;'5E/G-S:&$\+W9A;'5E/@H@("`@("`@/"]V86QU
M97,^"B`@("`@(#PO8V]N9FEG96YU;3X*("`@("`@/&-O;F9I9VQI<W0@;F%M
M93TB9F]L9&5R<R(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)!(&QI<W0@;V8@
M9F]L9&5R<R!T;R!C<F5A=&4@=6YD97(*("`@("`@=7-E<FYA;64B+SX*("`@
M("`@/&-O;F9I9VEN=&5G97(@;F%M93TB<75O=&$B(')E<75I<F5D/2)F86QS
M92(@9&5S8STB5&AE('%U;W1A("AI;@H@("`@("!K:6QO8GET97,I('1O(&=R
M86YT(&]N('1H92!M86EL8F]X(B\^"B`@("`@(#QC;VYF:6=B;V]L96%N(&YA
M;64](G5N:7AH:65R(B!D97-C/2)4:&4@=F%L=64@;V8@:6UA<&0N8V]N9B=S
M"B`@("`@('5N:7AH:65R87)C:'ES97`@<V5T=&EN9RX@0VAE8VL@=&AI<R!I
M9B!T:&4@=F%L=64@:7,@=')U92!I;@H@("`@("!I;6%P9"YC;VYF+B(^9F%L
M<V4\+V-O;F9I9V)O;VQE86X^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@
M/"]C87-E/@H*("`@(#QC87-E(&YA;64](GEA:&]O(B!D97-C/2)986AO;R$@
M875T:&5N=&EC871I;VXB+SX*("`@/"]C;VYF:6=S=VET8V@^"B`@/"]C;VYF
M:6=S96-T:6]N/@H@/"]C;VYF:6=T86(^"@H@/&-O;F9I9W1A8B!N86UE/2)S
M:6=N=7`B(&1E<V,](E-I9VX@57`B/@H@(#QC;VYF:6=S96-T:6]N(&YA;64]
M(G-I9VYU<"(^"B`@(#QC;VYF:6=H96%D97(^2&]R9&4@4VEG;B!5<#PO8V]N
M9FEG:&5A9&5R/@H@("`\8V]N9FEG<W=I=&-H(&YA;64](F%L;&]W(B!D97-C
M/2)!;&QO=R!N;VXM<F5G:7-T97)E9"!U<V5R<R!T;R!R96=I<W1E<B!A;F0*
M("`@<')O=FED92!A(&QI;FL@;VX@=&AE(&QO9VEN('-C<F5E;C\B/F9A;'-E
M"B`@("`\8V%S92!N86UE/2)T<G5E(B!D97-C/2)997,B/@H@("`@(#QC;VYF
M:6=B;V]L96%N(&YA;64](F%P<')O=F4B(&1E<V,](D%D;6EN(&AA<R!T;R!A
M<'!R;W9E(&%N>2!U<V5R('-U8FUI='1E9`H@("`@(')E9VES=')A=&EO;B!R
M97%U97-T<S\@*%=!4DY)3D<Z(%-E='1I;F<@=&\@9F%L<V4@=V]U;&0@;65A
M;B!T:&%T(&5V97)Y('5S97(*("`@("!W:&\@<VEG;G,@=7`@=V]U;&0@:&%V
M92!A=71O;6%T:6,@86-C97-S('1O('EO=7(@:&]R9&4@<WES=&5M+BDB/G1R
M=64\+V-O;F9I9V)O;VQE86X^"B`@("`@/&-O;F9I9V)O;VQE86X@;F%M93TB
M<')E<')O8V5S<R(@9&5S8STB4&%S<R!T:&4@=7-E<B!S=6)M:71T960@:6YF
M;W)M871I;VX*("`@("!T:')O=6=H('1H92!?:&]R9&5?:&]O:U]S:6=N=7!?
M<')E<')O8V5S<R!F=6YC=&EO;B!I;B!H;V]K<RYP:'`@8F5F;W)E"B`@("`@
M<')O8V5S<VEN9R!T:&4@<F5Q=65S=#\B/F9A;'-E/"]C;VYF:6=B;V]L96%N
M/@H@("`@(#QC;VYF:6=B;V]L96%N(&YA;64](G%U975E(B!D97-C/2)087-S
M('1H92!U<V5R('-U8FUI='1E9"!I;F9O<FUA=&EO;@H@("`@('1H<F]U9V@@
M=&AE(%]H;W)D95]H;V]K7W-I9VYU<%]Q=65U92!F=6YC=&EO;B!I;B!H;V]K
M<RYP:'`@869T97(@<')O8V5S<VEN9PH@("`@('1H92!R97%U97-T(&)U="!B
M969O<F4@86-T=6%L;'D@<75E=65I;F<@:70_(CYF86QS93PO8V]N9FEG8F]O
M;&5A;CX*("`@(#PO8V%S93X*("`@(#QC87-E(&YA;64](F9A;'-E(B!D97-C
M/2).;R(@+SX*("`@/"]C;VYF:6=S=VET8V@^"B`@/"]C;VYF:6=S96-T:6]N
M/@H@/"]C;VYF:6=T86(^"@H@/&-O;F9I9W1A8B!N86UE/2)L;V<B(&1E<V,]
M(DQO9V=I;F<B/@H@(#QC;VYF:6=S96-T:6]N(&YA;64](FQO9R(^"B`@(#QC
M;VYF:6=H96%D97(^2&]R9&4@3&]G9VEN9SPO8V]N9FEG:&5A9&5R/@H@("`\
M8V]N9FEG<W=I=&-H(&YA;64](F5N86)L960B('%U;W1E/2)F86QS92(@9&5S
M8STB4VAO=6QD($AO<F1E(&QO9R!E<G)O<G,@86YD(&]T:&5R('5S969U;`H@
M("!I;F9O<FUA=&EO;C\B/G1R=64*("`@(#QC87-E(&YA;64](G1R=64B(&1E
M<V,](EEE<R(^"B`@("`@/&-O;F9I9V5N=6T@;F%M93TB<')I;W)I='DB('%U
M;W1E/2)F86QS92(@9&5S8STB5VAA="!L979E;"!O9B!M97-S86=E<PH@("`@
M('-H;W5L9"!W92!L;V<_($5A8V@@;&5V96P@;&]G<R!I='-E;&8@86YD(&%L
M;"!T:&]S92!T:&%T(&-O;64@8F5F;W)E(&ET.@H@("`@(%!%05)?3$]'7T%,
M15)4('=O=6QD(&]N;'D@;&]G(&%L97)T<R!A;F0@96UE<F=E;F-I97,L(&)U
M="!014%27TQ/1U]$14)51PH@("`@('=O=6QD(&QO9R!E=F5R>71H:6YG+B(^
M4$5!4E],3T=?3D]424-%"B`@("`@(#QV86QU97,^"B`@("`@("`\=F%L=64@
M9&5S8STB4$5!4E],3T=?14U%4D<B/E!%05)?3$]'7T5-15)'/"]V86QU93X*
M("`@("`@(#QV86QU92!D97-C/2)014%27TQ/1U]!3$525"(^4$5!4E],3T=?
M04Q%4E0\+W9A;'5E/@H@("`@("`@/'9A;'5E(&1E<V,](E!%05)?3$]'7T-2
M250B/E!%05)?3$]'7T-2250\+W9A;'5E/@H@("`@("`@/'9A;'5E(&1E<V,]
M(E!%05)?3$]'7T524B(^4$5!4E],3T=?15)2/"]V86QU93X*("`@("`@(#QV
M86QU92!D97-C/2)014%27TQ/1U]705).24Y'(CY014%27TQ/1U]705).24Y'
M/"]V86QU93X*("`@("`@(#QV86QU92!D97-C/2)014%27TQ/1U].3U1)0T4B
M/E!%05)?3$]'7TY/5$E#13PO=F%L=64^"B`@("`@("`\=F%L=64@9&5S8STB
M4$5!4E],3T=?24Y&3R(^4$5!4E],3T=?24Y&3SPO=F%L=64^"B`@("`@("`\
M=F%L=64@9&5S8STB4$5!4E],3T=?1$5"54<B/E!%05)?3$]'7T1%0E5'/"]V
M86QU93X*("`@("`@/"]V86QU97,^"B`@("`@/"]C;VYF:6=E;G5M/@H@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB:61E;G0B(&1E<V,](E=H870@:61E;G1I
M9FEE<B!S:&]U;&0@=V4@=7-E(&EN('1H90H@("`@(&QO9W,_(CY(3U)$13PO
M8V]N9FEG<W1R:6YG/@H*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A
M;7,B/@H@("`@("`\8V]N9FEG<&QA8V5H;VQD97(O/@H@("`@(#PO8V]N9FEG
M<V5C=&EO;CX*"B`@("`@/&-O;F9I9W-W:71C:"!N86UE/2)T>7!E(B!D97-C
M/2)7:&%T(&QO9R!D<FEV97(@<VAO=6QD('=E('5S93\B/F9I;&4*("`@("`@
M/&-A<V4@;F%M93TB8V]N<V]L92(@9&5S8STB0V]N<V]L92(^"B`@("`@("`\
M8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`@(#QC;VYF:6=P
M:'`@;F%M93TB<W1R96%M(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H92!O
M=71P=70@<W1R96%M('1O"B`@("`@("`@=7-E(B\^"B`@("`@("`@/&-O;F9I
M9V)O;VQE86X@;F%M93TB8G5F9F5R:6YG(B!R97%U:7)E9#TB9F%L<V4B(&1E
M<V,](E-H;W5L9"!T:&4*("`@("`@("!O=71P=70@8F4@8G5F9F5R960@=6YT
M:6P@<VAU=&1O=VX_(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*("`@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](FQI;F5&;W)M870B(')E<75I<F5D/2)F86QS
M92(@9&5S8STB3&]G(&QI;F4@9F]R;6%T"B`@("`@("`@<W!E8VEF:6-A=&EO
M;B(O/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=&EM949O<FUA="(@
M<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:6UE('-T86UP"B`@("`@("`@9F]R
M;6%T(B\^"B`@("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`@(#PO8V%S93X*
M"B`@("`@(#QC87-E(&YA;64](F1I<W!L87DB(&1E<V,](D1I<W!L87DB/@H@
M("`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](F5R<F]R7W!R97!E;F0B(')E<75I<F5D/2)F
M86QS92(@9&5S8STB5&AI<R!S=')I;F<*("`@("`@("!W:6QL(&)E('!R97!E
M;F1E9"!T;R!T:&4@;&]G(&]U='!U="(O/@H@("`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB97)R;W)?87!P96YD(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,]
M(E1H:7,@<W1R:6YG"B`@("`@("`@=VEL;"!B92!A<'!E;F1E9"!T;R!T:&4@
M;&]G(&]U='!U="(O/@H@("`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@("`\
M+V-A<V4^"@H@("`@("`\8V%S92!N86UE/2)E<G)O<E]L;V<B(&1E<V,](D5R
M<F]R($QO9R(^"B`@("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B
M/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB9&5S=&EN871I;VXB(')E
M<75I<F5D/2)F86QS92(@9&5S8STB3W!T:6]N86P*("`@("`@("!D97-T:6YA
M=&EO;B!V86QU92!F;W(@97)R;W)?;&]G*"DN(%-E90H@("`@("`@(&AT='`Z
M+R]W=W<N:6YD96QI8FQE+F]R9R]P96%R+TQO9R]G=6ED92YH=&UL(V5R<F]R
M+6QO9RUT>7!E<R!F;W(@;6]R90H@("`@("`@(&1E=&%I;',N(B\^"B`@("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)E>'1R85]H96%D97)S(B!R97%U:7)E
M9#TB9F%L<V4B(&1E<V,](D%D9&ET:6]N86P*("`@("`@("!H96%D97)S('1O
M('!A<W,@=&\@=&AE(&UA:6PH*2!F=6YC=&EO;B!W:&5N('1H92!014%27TQ/
M1U]465!%7TU!24P@='EP90H@("`@("`@(&ES('-P96-I9FEE9"(O/@H@("`@
M("`@/"]C;VYF:6=S96-T:6]N/@H@("`@("`\+V-A<V4^"@H@("`@("`\8V%S
M92!N86UE/2)F:6QE(B!D97-C/2)&:6QE(CX*("`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB;F%M92(@9&5S8STB4&%T:"!T;R!T:&4@;&]G"B`@("`@("!F
M:6QE(CXO=&UP+VAO<F1E+FQO9SPO8V]N9FEG<W1R:6YG/@H@("`@("`@/&-O
M;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@("`\8V]N9FEG8F]O
M;&5A;B!N86UE/2)A<'!E;F0B(')E<75I<F5D/2)F86QS92(@9&5S8STB4VAO
M=6QD(&YE=R!L;V<*("`@("`@("!E;G1R:65S(&)E(&%P<&5N9&5D('1O(&%N
M(&5X:7-T:6YG(&QO9R!F:6QE/R!)9B!T:&ES(&ES(&9A;'-E+"!N97<@;&]G
M(&9I;&5S"B`@("`@("`@=VEL;"!O=F5R=W)I=&4@97AI<W1I;F<@;VYE<RXB
M/G1R=64\+V-O;F9I9V)O;VQE86X^"B`@("`@("`@/&-O;F9I9VEN=&5G97(@
M;F%M93TB;6]D92(@;V-T86P](G1R=64B(')E<75I<F5D/2)F86QS92(@9&5S
M8STB3V-T86P*("`@("`@("!R97!R97-E;G1A=&EO;B!O9B!T:&4@;&]G(&9I
M;&4G<R!P97)M:7-S:6]N<R!M;V1E(B\^"B`@("`@("`@/&-O;F9I9W!H<"!N
M86UE/2)E;VPB(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE(&5N9"UO9BUL
M:6YE(&-H87)A8W1E<@H@("`@("`@('-E<75E;F-E(B\^"B`@("`@("`@/&-O
M;F9I9W-T<FEN9R!N86UE/2)L:6YE1F]R;6%T(B!R97%U:7)E9#TB9F%L<V4B
M(&1E<V,](DQO9R!L:6YE(&9O<FUA=`H@("`@("`@('-P96-I9FEC871I;VXB
M+SX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G1I;65&;W)M870B(')E
M<75I<F5D/2)F86QS92(@9&5S8STB5&EM92!S=&%M<`H@("`@("`@(&9O<FUA
M="(O/@H@("`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@("`\+V-A<V4^"@H@
M("`@("`\8V%S92!N86UE/2)M86EL(B!D97-C/2)-86EL(CX*("`@("`@(#QC
M;VYF:6=S=')I;F<@;F%M93TB;F%M92(@9&5S8STB5&AE(')E8VEP:65N="!F
M;W(@=&AE(&UE<W-A9V4B+SX*("`@("`@(#QC;VYF:6=S96-T:6]N(&YA;64]
M(G!A<F%M<R(^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)F<F]M(B!R
M97%U:7)E9#TB9F%L<V4B(&1E<V,](E9A;'5E(&9O<B!T:&4*("`@("`@("!M
M97-S86=E)W,@1G)O;3H@:&5A9&5R(B\^"B`@("`@("`@/&-O;F9I9W-T<FEN
M9R!N86UE/2)S=6)J96-T(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E9A;'5E
M(&9O<B!T:&4*("`@("`@("!M97-S86=E)W,@4W5B:F5C=#H@:&5A9&5R(B\^
M"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P<F5A;6)L92(@<F5Q=6ER
M960](F9A;'-E(B!D97-C/2)0<F5A;6)L92!F;W(@=&AE"B`@("`@("`@;65S
M<V%G92(O/@H@("`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@("`\+V-A<V4^
M"@H@("`@("`\8V%S92!N86UE/2)M8V%L(B!D97-C/2)-8V%L(CX*("`@("`@
M(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@("`@/&-O;F9I
M9W-T<FEN9R!N86UE/2)C86QE;F1A<B(@9&5S8STB5&AE($U#04P@8V%L96YD
M87(@;F%M92(O/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=7-E<FYA
M;64B(&1E<V,](D-O;FYE8W0@=&\@34-!3"!A<R(O/@H@("`@("`@(#QC;VYF
M:6=S=')I;F<@;F%M93TB<&%S<W=O<F0B(&1E<V,](E!A<W-W;W)D('1O(&-O
M;FYE8W0@=VET:"(O/@H@("`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@("`\
M+V-A<V4^"@H@("`@("`\8V%S92!N86UE/2)N=6QL(B!D97-C/2).=6QL(B\^
M"@H@("`@("`\8V%S92!N86UE/2)S<6PB(&1E<V,](E-13"(^"B`@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](FYA;64B(&1E<V,](E1H92!T86)L92!T;R!L
M;V<*("`@("`@('1O(CYL;V=?=&%B;&4\+V-O;F9I9W-T<FEN9SX*("`@("`@
M(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@("`@/&-O;F9I
M9W!H<"!N86UE/2)D<VXB(&1E<V,](D$@1&%T82!3;W5R8V4*("`@("`@("!.
M86UE(CXD8V]N9ELG<W%L)UT\+V-O;F9I9W!H<#X*("`@("`@(#PO8V]N9FEG
M<V5C=&EO;CX*("`@("`@/"]C87-E/@H*("`@("`@/&-A<V4@;F%M93TB<W%L
M:71E(B!D97-C/2)344QI=&4B/@H@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE
M/2)N86UE(B!D97-C/2)4:&4@=&%B;&4@=&\@;&]G"B`@("`@("!T;R(^;&]G
M7W1A8FQE/"]C;VYF:6=S=')I;F<^"B`@("`@("`\8V]N9FEG<V5C=&EO;B!N
M86UE/2)P87)A;7,B/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB9FEL
M96YA;64B(&1E<V,](E!A=&@@=&\@86X@4W%L:71E(&1A=&%B87-E(B\^"B`@
M("`@("`@/&-O;F9I9VEN=&5G97(@;F%M93TB;6]D92(@;V-T86P](G1R=64B
M(')E<75I<F5D/2)F86QS92(@9&5S8STB3V-T86P*("`@("`@("!M;V1E('5S
M960@=&\@;W!E;B!T:&4@9&%T86)A<V4@6S`V-C9=(B\^"B`@("`@("`@/&-O
M;F9I9V)O;VQE86X@;F%M93TB<&5R<VES=&5N="(@<F5Q=6ER960](F9A;'-E
M(B!D97-C/2)5<V4@80H@("`@("`@('!E<G-I<W1E;G0@8V]N;F5C=&EO;B(^
M9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@("`@("`\+V-O;F9I9W-E8W1I;VX^
M"B`@("`@(#PO8V%S93X*"B`@("`@(#QC87-E(&YA;64](G-Y<VQO9R(@9&5S
M8STB4WES;&]G(CX*("`@("`@(#QC;VYF:6=P:'`@;F%M93TB;F%M92(@<75O
M=&4](F9A;'-E(B!D97-C/2)3>7-L;V<@9F%C:6QI='D@=&\@=7-E(B\^"B`@
M("`@(#PO8V%S93X*"B`@("`@(#QC87-E(&YA;64](G=I;B(@9&5S8STB5VEN
M9&]W(CX*("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB;F%M92(@9&5S8STB
M3F%M92!O9B!T:&4@;W!E;F5D('=I;F1O=R(O/@H@("`@("`@/&-O;F9I9W-E
M8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](G1I=&QE(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H92!T:71L92!O
M9B!T:&4*("`@("`@("!O=71P=70@=VEN9&]W(B\^"B`@("`@("`\+V-O;F9I
M9W-E8W1I;VX^"B`@("`@(#PO8V%S93X*("`@("`\+V-O;F9I9W-W:71C:#X*
M"B`@("`\+V-A<V4^"B`@("`\8V%S92!N86UE/2)F86QS92(@9&5S8STB3F\B
M+SX*("`@/"]C;VYF:6=S=VET8V@^"B`@/"]C;VYF:6=S96-T:6]N/@H@(#QC
M;VYF:6=B;V]L96%N(&YA;64](FQO9U]A8V-E<W-K97ES(B!D97-C/2)3:&]U
M;&0@2&]R9&4@;&]G('-T871I<W1I8W,@86)O=70*("`@=7-E9"!A8V-E<W,@
M:V5Y<S\@5&AI<R!I<R!O;FQY('5S969U;"!F;W(@=')A;G-L871O<G,@;V8@
M=&AE"B`@(%5)+B!9;W4@86QS;R!N965D('1O('-E="!T:&4@;&]G(&QE=F5L
M('1O(&%T(&QE87-T"B`@(%!%05)?3$]'7TE.1D\N(CYF86QS93PO8V]N9FEG
M8F]O;&5A;CX*(#PO8V]N9FEG=&%B/@H*(#QC;VYF:6=T86(@;F%M93TB<')E
M9G,B(&1E<V,](E!R969E<F5N8V4@4WES=&5M(CX*("`\8V]N9FEG<V5C=&EO
M;B!N86UE/2)P<F5F<R(^"B`@(#QC;VYF:6=H96%D97(^4')E9F5R96YC92!3
M>7-T96T@4V5T=&EN9W,\+V-O;F9I9VAE861E<CX*("`@/&-O;F9I9VEN=&5G
M97(@;F%M93TB;6%X<VEZ92(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@
M<VEZ92!O9B!T:&4*("`@<')E9F5R96YC97,@9FEE;&0@:6X@>6]U<B!B86-K
M96YD(&EN(&)Y=&5S+B!(;W)D92!W:6QL(')E:F5C="!A;GD@=W)I=&4@=&\*
M("`@=&AE('!R969E<F5N8V5S(&)A8VME;F0@:68@:71S(&QE;F=T:"!E>&-E
M961S('1H:7,@=F%L=64N($QE879E(&5M<'1Y('1O"B`@('-K:7`@=&AI<R!C
M:&5C:VEN9RX@12YG+B!->5-13"!S=&]R97,@=&AE('!R969E<F5N8V4@9&%T
M82!I;B!A($Q/3D=415A4"B`@(&9I96QD+B!4:&ES(&9I96QD(&-A;B!H;VQD
M(#0R.30Y-C<R.34@8GET97,@<V\@;6]S="!L:6ME;'D@8VAE8VMI;F<@:7,@
M;F]T"B`@(&YE961E9"X@2&]W979E<B!O=&AE<B!$0B!I;G-T86QL871I;VYS
M(&UA>2!O;FQY(&AA=F4@82!S=&]R86=E('-I>F4@;V8@-C0*("`@2T(@*#8U
M-3,U(&)Y=&5S*2X@5&AE<V4@:6YS=&%L;&%T:6]N<R!W;W5L9"!W86YT('1O
M('1U<FX@8VAE8VMI;F<@;VXN(B\^"B`@(#QC;VYF:6=S=VET8V@@;F%M93TB
M9')I=F5R(B!D97-C/2)7:&%T('!R969E<F5N8V5S(&1R:79E<B!S:&]U;&0@
M=V4@=7-E/R(^<V5S<VEO;@H@("`@(#QC87-E(&YA;64](G-Q;"(@9&5S8STB
M4U%,($1A=&%B87-E(CX*("`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R
M86US(CX*("`@("`@(#QC;VYF:6=S<6P@<W=I=&-H;F%M93TB9')I=F5R8V]N
M9FEG(CX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G1A8FQE(B!R97%U
M:7)E9#TB9F%L<V4B(&1E<V,](E1H92!N86UE(&]F('1H90H@("`@("`@('!R
M969E<F5N8V4@=&%B;&4@:6X@=&AE(&1A=&%B87-E(%MH;W)D95]P<F5F<UTB
M+SX*("`@("`@(#PO8V]N9FEG<W%L/@H@("`@("`\+V-O;F9I9W-E8W1I;VX^
M"B`@("`@/"]C87-E/@H@("`@(#QC87-E(&YA;64](FQD87`B(&1E<V,](DQ$
M05`B/@H@("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)H;W-T<W!E8R(@9&5S8STB5&AE(&AO
M<W1N86UE(&]F('1H92!,1$%0('-E<G9E<B(^;&]C86QH;W-T/"]C;VYF:6=S
M=')I;F<^"B`@("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)P;W)T(B!D97-C
M/2)4:&4@<&]R="!O9B!T:&4@3$1!4"!S97)V97(B/C,X.3PO8V]N9FEG:6YT
M96=E<CX*("`@("`@(#QC;VYF:6=E;G5M(&YA;64](G9E<G-I;VXB(&1E<V,]
M(DQ$05`@4')O=&]C;VP@5F5R<VEO;B(^,PH@("`@("`@(#QV86QU97,^"B`@
M("`@("`@(#QV86QU92!D97-C/2),1$%0=C(@*$1E<')E8V%T960I(CXR/"]V
M86QU93X*("`@("`@("`@/'9A;'5E(&1E<V,](DQ$05!V,R(^,SPO=F%L=64^
M"B`@("`@("`@/"]V86QU97,^"B`@("`@("`\+V-O;F9I9V5N=6T^"B`@("`@
M("`\8V]N9FEG<W1R:6YG(&YA;64](F)A<V5D;B(@9&5S8STB5&AE(&)A<V4@
M1$X@9F]R('1H92!,1$%0('-E<G9E<B(O/@H@("`@("`@/&-O;F9I9V)O;VQE
M86X@;F%M93TB9F5T8VAD;B(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)3:&]U
M;&0@2&]R9&4@8FEN9`IA<R!E86-H('5S97(@9F]R('1H870@=7-E<B=S('=R
M:71E(&]P97)A=&EO;G,_(B\^"B`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64]
M(G)O;W1D;B(@<F5Q=6ER960](F9A;'-E(B!D97-C/2))9B!N;W0L('!R;W9I
M9&4@=&AE"D1.(&]F('1H92!R;V]T("AA9&UI;FES=')A=&EV92D@86-C;W5N
M="!T;R!B:6YD(&9O<B!W<FET92!O<&5R871I;VYS(B\^"B`@("`@("`\8V]N
M9FEG<W1R:6YG(&YA;64](G!A<W-W;W)D(B!R97%U:7)E9#TB9F%L<V4B(&1E
M<V,](E1H92!P87-S=V]R9"!O9B!T:&4@<F]O="!$3B!F;W(@8FEN9"!A=71H
M96YT:6-A=&EO;B(O/@H@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)U:60B
M(&1E<V,](E1H92!U<V5R;F%M92!S96%R8V@@:V5Y(B\^"B`@("`@(#PO8V]N
M9FEG<V5C=&EO;CX*("`@("`\+V-A<V4^"B`@("`@/&-A<V4@;F%M93TB<V5S
M<VEO;B(@9&5S8STB4$A0(%-E<W-I;VYS(B\^"B`@("`@/&-A<V4@;F%M93TB
M:V]L86(B(&1E<V,](DMO;&%B("A,1$%0*2(@+SX*("`@("`\8V%S92!N86UE
M/2)I;7-P(B!D97-C/2))35-0(%-E<G9E<B(@+SX*("`@/"]C;VYF:6=S=VET
M8V@^"B`@/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF:6=T86(^"@H@/&-O;F9I
M9W1A8B!N86UE/2)D871A=')E92(@9&5S8STB1&%T851R964@4WES=&5M(CX*
M("`\8V]N9FEG<V5C=&EO;B!N86UE/2)D871A=')E92(^"B`@(#QC;VYF:6=H
M96%D97(^1&%T851R964@4WES=&5M(%-E='1I;F=S/"]C;VYF:6=H96%D97(^
M"B`@(#QC;VYF:6=S=VET8V@@;F%M93TB9')I=F5R(B!D97-C/2)7:&%T(&)A
M8VME;F0@<VAO=6QD('=E('5S92!F;W(@2&]R9&4*("`@1&%T851R964@<W1O
M<F%G93\B/FYU;&P*("`@("`\8V%S92!N86UE/2)N=6QL(B!D97-C/2).;VYE
M(B\^"B`@("`@/&-A<V4@;F%M93TB<W%L(B!D97-C/2)344P@1&%T86)A<V4B
M/@H@("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`@
M/&-O;F9I9W-Q;"!S=VET8VAN86UE/2)D<FEV97)C;VYF:6<B/@H@("`@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB=&%B;&4B(')E<75I<F5D/2)F86QS92(@
M9&5S8STB5&AE(&YA;64@;V8@=&AE"B`@("`@("`@9&%T82!T86)L92!I;B!T
M:&4@9&%T86)A<V4@6VAO<F1E7V1A=&%T<F5E72(O/@H@("`@("`@(#QC;VYF
M:6=S=')I;F<@;F%M93TB=&%B;&5?871T<FEB=71E<R(@<F5Q=6ER960](F9A
M;'-E(B!D97-C/2)4:&4@;F%M90H@("`@("`@(&]F('1H92!D871A(&%T=')I
M8G5T97,@=&%B;&4@:6X@=&AE(&1A=&%B87-E"B`@("`@("`@6VAO<F1E7V1A
M=&%T<F5E7V%T=')I8G5T97-=(B\^"B`@("`@("`\+V-O;F9I9W-Q;#X*("`@
M("`@/"]C;VYF:6=S96-T:6]N/@H@("`@(#PO8V%S93X*("`@/"]C;VYF:6=S
M=VET8V@^"B`@/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF:6=T86(^"@H@/&-O
M;F9I9W1A8B!N86UE/2)G<F]U<"(@9&5S8STB1W)O=7!S(CX*("`\8V]N9FEG
M<V5C=&EO;B!N86UE/2)G<F]U<"(^"B`@(#QC;VYF:6=H96%D97(^1W)O=7!S
M(%-E='1I;F=S/"]C;VYF:6=H96%D97(^"B`@(#QC;VYF:6=D97-C<FEP=&EO
M;CX*("`@(%1H92!(;V]K<R!B86-K96YD(&5X=&5N9',@=&AE($1A=&%4<F5E
M(&)A8VME;F0@=&\@86QL;W<@:&]O:W,@=&\@97AT96YD(&$*("`@(&=R;W5P
M('1O(&1Y;F%M:6-A;&QY(&EN8VQU9&4@;65M8F5R<R!I;G1O(&$@9W)O=7`N
M("!3964@:&]O:W,N<&AP+F1I<W0@9F]R"B`@("!A;B!E>&%M<&QE+@H@("`\
M+V-O;F9I9V1E<V-R:7!T:6]N/@H@("`\8V]N9FEG<W=I=&-H(&YA;64](F1R
M:79E<B(@9&5S8STB5VAA="!B86-K96YD('-H;W5L9"!W92!U<V4@9F]R($AO
M<F1E"B`@($=R;W5P<S\B/F1A=&%T<F5E"B`@("`@/&-A<V4@;F%M93TB9&%T
M871R964B(&1E<V,](D1A=&%4<F5E(B\^"B`@("`@/&-A<V4@;F%M93TB:&]O
M:W,B(&1E<V,](DAO;VMS(B\^"@H@("`@(#QC87-E(&YA;64](FQD87`B(&1E
M<V,](DQ$05`B/@H@("`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US
M(CX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](FAO<W1S<&5C(B!D97-C
M/2)4:&4@:&]S=&YA;64@;V8@=&AE($Q$05`@<V5R=F5R(CYL;V-A;&AO<W0\
M+V-O;F9I9W-T<FEN9SX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F)A
M<V5D;B(@9&5S8STB5&AE(&)A<V4@1$X@9F]R('1H92!,1$%0('-E<G9E<B(O
M/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB8FEN9&1N(B!R97%U:7)E
M9#TB9F%L<V4B(&1E<V,](E1H92!$3B!U<V5D('1O(&)I;F0@=&\@=&AE($Q$
M05`@<V5R=F5R(B\^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P87-S
M=V]R9"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@<&%S<W=O<F0@=7-E
M9"!T;R!B:6YD('1O('1H92!,1$%0('-E<G9E<B(O/@H@("`@("`@(#QC;VYF
M:6=E;G5M(&YA;64](G9E<G-I;VXB(&1E<V,](DQ$05`@4')O=&]C;VP@5F5R
M<VEO;B(^,PH@("`@("`@("`\=F%L=65S/@H@("`@("`@("`@/'9A;'5E(&1E
M<V,](DQ$05!V,B`H1&5P<F5C871E9"DB/C(\+W9A;'5E/@H@("`@("`@("`@
M/'9A;'5E(&1E<V,](DQ$05!V,R(^,SPO=F%L=64^"B`@("`@("`@(#PO=F%L
M=65S/@H@("`@("`@(#PO8V]N9FEG96YU;3X*("`@("`@("`\8V]N9FEG<W1R
M:6YG(&YA;64](F=I9"(@9&5S8STB5&AE(&=R;W5P('-E87)C:"!K97DB/F-N
M/"]C;VYF:6=S=')I;F<^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)M
M96UB97)U:60B(&1E<V,](D=R;W5P(&UE;6)E<G-H:7`@9FEE;&0B/FUE;6)E
M<E5I9#PO8V]N9FEG<W1R:6YG/@H@("`@("`@(#QC;VYF:6=L:7-T(&YA;64]
M(FYE=V=R;W5P7V]B:F5C=&-L87-S(B!D97-C/2)7:&%T(&]B:F5C=&-L87-S
M97,@<VAO=6QD(&$@;F5W(&=R;W5P(&)E(&UE;6)E<B!O9C\@5&AE<V4@;V)J
M96-T8VQA<W-E<R!S:&]U;&0@8V]V97(@=&AE(&UA:6P@86YD(&=I9&YU;6)E
M<B!A='1R:6)U=&5S(&%S('=E;&P@87,@=&AE(&=R;W5P('-E87)C:"!K97DB
M/G!O<VEX1W)O=7`L:&]R9&5'<F]U<#PO8V]N9FEG;&ES=#X*("`@("`@("`\
M8V]N9FEG<W=I=&-H(&YA;64](F9I;'1E<E]T>7!E(B!D97-C/2)(;W<@=&\@
M<W!E8VEF>2!A(&9I;'1E<B!F;W(@=&AE(&=R;W5P(&QI<W1S(CYO8FIE8W1C
M;&%S<PH@("`@("`@("`\8V%S92!N86UE/2)O8FIE8W1C;&%S<R(@9&5S8STB
M3VYE(&]R(&UO<F4@;V)J96-T8VQA<W,@9FEL=&5R<R(^"B`@("`@("`@("`\
M8V]N9FEG;&ES="!N86UE/2)O8FIE8W1C;&%S<R(@9&5S8STB5&AE(&]B:F5C
M=&-L87-S(&9I;'1E<B!U<V5D('1O('-E87)C:"!F;W(@9W)O=7!S+B!#86X@
M8F4@82!S:6YG;&4@;V)J96-T8VQA<W,@;W(@82!L:7-T+B(^<&]S:7A'<F]U
M<#PO8V]N9FEG;&ES=#X*("`@("`@("`@/"]C87-E/@H@("`@("`@("`\8V%S
M92!N86UE/2)F<F5E(B!D97-C/2)!(&-O;7!L971E($Q$05`@9FEL=&5R(&5X
M<')E<W-I;VXB/@H@("`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)F:6QT
M97(B(&1E<V,](E1H92!,1$%0(%)&0R!F;W)M871T960@9FEL=&5R('5S960@
M=&\@<V5A<F-H(&9O<B!G<F]U<',N(B\^"B`@("`@("`@(#PO8V%S93X*("`@
M("`@("`\+V-O;F9I9W-W:71C:#X*("`@("`@/"]C;VYF:6=S96-T:6]N/@H@
M("`@(#PO8V%S93X*"B`@(#PO8V]N9FEG<W=I=&-H/@H@(#PO8V]N9FEG<V5C
M=&EO;CX*(#PO8V]N9FEG=&%B/@H*(#QC;VYF:6=T86(@;F%M93TB8V%C:&4B
M(&1E<V,](D-A8VAE(%-Y<W1E;2(^"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB
M8V%C:&4B/@H@("`\8V]N9FEG:&5A9&5R/D-A8VAE(%-Y<W1E;2!3971T:6YG
M<SPO8V]N9FEG:&5A9&5R/@H@("`\8V]N9FEG:6YT96=E<B!N86UE/2)D969A
M=6QT7VQI9F5T:6UE(B!D97-C/2)(;W<@;&]N9RP@:6X@<V5C;VYD<RP@<VAO
M=6QD"B`@(&]B:F5C=',@8F4@8V%C:&5D(&)Y(&1E9F%U;'0_(CXQ.#`P/"]C
M;VYF:6=I;G1E9V5R/@H@("`\8V]N9FEG<W=I=&-H(&YA;64](F1R:79E<B(@
M9&5S8STB268@>6]U('=A;G0@=&\@96YA8FQE('1H92!(;W)D92!#86-H92P*
M("`@<V5L96-T(&$@9')I=F5R(&AE<F4N(%1H:7,@:7,@=7-E9"!T;R!S<&5E
M9"!U<"!P;W)T:6]N<R!O9B!(;W)D92!B>2!S=&]R:6YG"B`@(&-O;6UO;FQY
M('!R;V-E<W-E9"!O8FIE8W1S('1O(&1I<VLN(CYF:6QE"B`@("`\8V%S92!N
M86UE/2)N;VYE(B!D97-C/2)$;VXG="!C86-H92!A;GD@;V)J96-T<R(O/@H@
M("`@/&-A<V4@;F%M93TB9FEL92(@9&5S8STB4W1O<F4@;V)J96-T<R!I;B!F
M:6QE<WES=&5M(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B
M/@H@("`@("`\8V]N9FEG<&AP(&YA;64](F1I<B(@<F5Q=6ER960](F9A;'-E
M(B!D97-C/2)4:&4@;&]C871I;VX@=&\@<W1O<F4@=&AE"B`@("`@(&-A8VAE
M9"!F:6QE<R(^2&]R9&4Z.F=E=%1E;7!$:7(H*3PO8V]N9FEG<&AP/@H@("`@
M("`\8V]N9FEG<W1R:6YG(&YA;64](G!R969I>"(@<F5Q=6ER960](F9A;'-E
M(B!D97-C/2)4:&4@9FEL96YA;64@<')E9FEX('1O"B`@("`@('5S92!F;W(@
M=&AE(&-A8VAE(&9I;&5S+B(O/@H@("`@("`\8V]N9FEG:6YT96=E<B!N86UE
M/2)G8R(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)097)F;W)M(&=A<F)A9V4*
M("`@("`@8V]L;&5C=&EO;B!O;B!C86-H92!F:6QE<S\@26YP=70@=&AE(&YU
M;6)E<B!O9B!S96-O;F1S(&]L9"!T:&4@9FEL92!H87,*("`@("`@=&\@8F4@
M=VET:&]U="!M;V1I9FEC871I;VX@8F5F;W)E('1H92!C86-H92!S>7-T96T@
M8V%N(&1E;&5T92!T:&4@9FEL92X*("`@("`@26YP=70@,"!T;R!S:VEP(&=A
M<F)A9V4@8V]L;&5C=&EO;BXB/C@V-#`P/"]C;VYF:6=I;G1E9V5R/@H@("`@
M("!A9G1E<B!W:&EC:"!C86-H90H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@
M(#PO8V%S93X*("`@(#QC87-E(&YA;64](GIP<S0B(&1E<V,](E5S92!T:&4@
M6F5N9"!097)F;W)M86YC92!3=6ET92!O=71P=70@8V%C:&4B+SX*("`@/"]C
M;VYF:6=S=VET8V@^"B`@/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF:6=T86(^
M"@H@/&-O;F9I9W1A8B!N86UE/2)T;VME;B(@9&5S8STB5&]K96X@4WES=&5M
M(CX*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)T;VME;B(^"B`@(#QC;VYF:6=H
M96%D97(^5&]K96X@4WES=&5M(%-E='1I;F=S/"]C;VYF:6=H96%D97(^"B`@
M(#QC;VYF:6=I;G1E9V5R(&YA;64](G1I;65O=70B(')E<75I<F5D/2)F86QS
M92(@9&5S8STB5&AE('!E<FEO9"`H:6X*("`@<V5C;VYD<RD@869T97(@=VAI
M8V@@86X@:60@:7,@<'5R9V5D(B\^"B`@(#QC;VYF:6=S=VET8V@@;F%M93TB
M9')I=F5R(B!D97-C/2))9B!Y;W4@=V%N="!T;R!E;F%B;&4@1F]R;2!4;VME
M;G,L('-E;&5C=`H@("!A(&1R:79E<B!H97)E+B!4:&ES(&ES('5S960@8GD@
M=&AE($AO<F1E.CI&;W)M.CH@05!)(&%N9"!S;VUE(&]T:&5R('!A<G1S"B`@
M(&]F($AO<F1E('1O(&5N<W5R92!T:&%T(&$@9F]R;2!C86X@;VYL>2!B92!S
M=6)M:71T960@;VYC92XB/FYO;F4*("`@(#QC87-E(&YA;64](FYO;F4B(&1E
M<V,](D1I<V%B;&4@1F]R;2!4;VME;G,B+SX*("`@(#QC87-E(&YA;64](F9I
M;&4B(&1E<V,](DQO8V%L(&9I;&5S>7-T96T@=&]K96X@<W1O<F%G92(^"B`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)T;VME;E]D:7(B(')E<75I<F5D/2)F
M86QS92(@9&5S8STB5&AE(&1I<F5C=&]R>2!W:&5R90H@("`@('1O(&ME97`@
M=&]K96X@9FEL97,B+SX*("`@(#PO8V%S93X*("`@(#QC87-E(&YA;64](G-Q
M;"(@9&5S8STB4U%,+6)A<V5D('1O:V5N('-T;W)A9V4B/@H@("`@(#QC;VYF
M:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S<6P@<W=I
M=&-H;F%M93TB9')I=F5R8V]N9FEG(CX*("`@("`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB=&%B;&4B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE(&YA;64@
M;V8@=&AE"B`@("`@("!T;VME;G,@=&%B;&4@:6X@=&AE(&1A=&%B87-E(%MH
M;W)D95]T;VME;G-=(B\^"B`@("`@(#PO8V]N9FEG<W%L/@H@("`@(#PO8V]N
M9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*("`@/"]C;VYF:6=S=VET8V@^"B`@
M/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF:6=T86(^"@H@/&-O;F9I9W1A8B!N
M86UE/2)M86EL97(B(&1E<V,](DUA:6QE<B(^"B`@/&-O;F9I9W-E8W1I;VX@
M;F%M93TB;6%I;&5R(CX*("`@/&-O;F9I9VAE861E<CY-86EL97(\+V-O;F9I
M9VAE861E<CX*("`@/&-O;F9I9W-W:71C:"!N86UE/2)T>7!E(B!D97-C/2)7
M:&%T(&UE=&AO9"!S:&]U;&0@=V4@=7-E(&9O<B!S96YD:6YG"B`@(&UA:6P_
M(CYS96YD;6%I;`H@("`@/&-A<V4@;F%M93TB;G5L;"(@9&5S8STB1&ES86)L
M92!M86EL:6YG(B`O/@H@("`@/&-A<V4@;F%M93TB<V5N9&UA:6PB(&1E<V,]
M(E5S92!T:&4@;&]C86P@<V5N9&UA:6P@8FEN87)Y(CX*("`@("`\8V]N9FEG
M<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](G-E;F1M86EL7W!A=&@B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE
M(&QO8V%T:6]N"B`@("`@(&]F('1H92!S96YD;6%I;"!B:6YA<GD@;VX@=&AE
M(&9I;&5S>7-T96T*("`@("`@6R]U<W(O<V)I;B]S96YD;6%I;%TB/B]U<W(O
M;&EB+W-E;F1M86EL/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB<V5N9&UA:6Q?87)G<R(@<F5Q=6ER960](F9A;'-E(B!D97-C
M/2)!;GD@97AT<F$*("`@("`@<&%R86UE=&5R<R!T;R!P87-S('1O('1H92!S
M96YD;6%I;"!O<B!S96YD;6%I;"!W<F%P<&5R"B`@("`@(&)I;F%R>2(^+6]I
M/"]C;VYF:6=S=')I;F<^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C
M87-E/@H@("`@/&-A<V4@;F%M93TB<VUT<"(@9&5S8STB57-E(&$@4TU44"!S
M97)V97(B/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB:&]S="(@<F5Q=6ER960](F9A;'-E
M(B!D97-C/2)4:&4@<V5R=F5R('1O(&-O;FYE8W0*("`@("`@=&\@6VQO8V%L
M:&]S=%TB+SX*("`@("`@/&-O;F9I9VEN=&5G97(@;F%M93TB<&]R="(@<F5Q
M=6ER960](F9A;'-E(B!D97-C/2)4:&4@<&]R="!T;R!C;VYN96-T"B`@("`@
M('1O(%LR-5TB+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)L;V-A;&AO
M<W0B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE(&QO8V%L(&AO<W1N86UE
M"B`@("`@("\@9&]M86EN(%ML;V-A;&AO<W1=(B\^"B`@("`@(#QC;VYF:6=E
M;G5M(&YA;64](F%U=&@B(&1E<V,](E--5%`@875T:&5N=&EC871I;VXB/C`*
M("`@("`@(#QV86QU97,^"B`@("`@("`@/'9A;'5E(&1E<V,](DYO(&%U=&AE
M;G1I8V%T:6]N(CXP/"]V86QU93X*("`@("`@("`\=F%L=64@9&5S8STB0F5S
M="!A=F%I;&%B;&4@875T:&5N=&EC871I;VXB/C$\+W9A;'5E/@H@("`@("`@
M(#QV86QU93Y$24=%4U0M340U/"]V86QU93X*("`@("`@("`\=F%L=64^0U)!
M32U-1#4\+W9A;'5E/@H@("`@("`@(#QV86QU93Y,3T=)3CPO=F%L=64^"B`@
M("`@("`@/'9A;'5E/E!,04E./"]V86QU93X*("`@("`@(#PO=F%L=65S/@H@
M("`@("`\+V-O;F9I9V5N=6T^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB
M=7-E<FYA;64B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE('5S97)N86UE
M('1O('5S92!F;W(@4TU44"!A=71H(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB<&%S<W=O<F0B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE('!A
M<W-W;W)D('1O('5S92!F;W(@4TU44"!A=71H(B\^"B`@("`@/"]C;VYF:6=S
M96-T:6]N/@H@("`@/"]C87-E/@H@("`\+V-O;F9I9W-W:71C:#X*("`\+V-O
M;F9I9W-E8W1I;VX^"B`\+V-O;F9I9W1A8CX*"B`\8V]N9FEG=&%B(&YA;64]
M(G9F<R(@9&5S8STB5FER='5A;"!&:6QE(%-T;W)A9V4B/@H@(#QC;VYF:6=S
M96-T:6]N(&YA;64](G9F<R(^"B`@(#QC;VYF:6=H96%D97(^5FER='5A;"!&
M:6QE(%-T;W)A9V4\+V-O;F9I9VAE861E<CX*("`@/&-O;F9I9W-W:71C:"!N
M86UE/2)T>7!E(B!D97-C/2))9B!A(%9&4R`H=FER='5A;"!F:6QE<WES=&5M
M*2!B86-K96YD(&ES"B`@(')E<75I<F5D+"!W:&EC:"!O;F4@<VAO=6QD('=E
M('5S93\B/F9I;&4*("`@(#QC87-E(&YA;64](F9I;&4B(&1E<V,](D9I;&5S
M(&]N('1H92!L;V-A;"!S>7-T96TB/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA
M;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=F9S<F]O
M="(@9&5S8STB5VAE<F4@;VX@=&AE(')E86P@9FEL97-Y<W1E;2!S:&]U;&0*
M("`@("`@2&]R9&4@=7-E(&%S(')O;W0@;V8@=&AE('9I<G1U86P@9FEL97-Y
M<W1E;3\B/B]T;7`\+V-O;F9I9W-T<FEN9SX*("`@("`\+V-O;F9I9W-E8W1I
M;VX^"B`@("`\+V-A<V4^"B`@("`\8V%S92!N86UE/2)S<6PB(&1E<V,](E-1
M3"!D871A8F%S92(^"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US
M(CX*("`@("`@/&-O;F9I9W-Q;"!S=VET8VAN86UE/2)D<FEV97)C;VYF:6<B
M/@H@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)V9G-?=&%B;&4B(&1E<V,]
M(E1H92!N86UE(&]F('1H92!61E,@=&%B;&4@:6X@=&AE"B`@("`@("!D871A
M8F%S92!;:&]R9&5?=F9S72(@<F5Q=6ER960](F9A;'-E(B\^"B`@("`@(#PO
M8V]N9FEG<W%L/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*
M("`@/"]C;VYF:6=S=VET8V@^"B`@/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF
M:6=T86(^"@H@/&-O;F9I9W1A8B!N86UE/2)S97-S:6]N(B!D97-C/2)#=7-T
M;VT@4V5S<VEO;B!(86YD;&5R(CX*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)S
M97-S:6]N:&%N9&QE<B(^"B`@(#QC;VYF:6=H96%D97(^0W5S=&]M(%-E<W-I
M;VX@2&%N9&QE<CPO8V]N9FEG:&5A9&5R/@H@("`\8V]N9FEG<W=I=&-H(&YA
M;64](G1Y<&4B(&1E<V,](E=H870@<V5S<VEO;FAA;F1L97(@9')I=F5R('-H
M;W5L9"!W90H@("!U<V4_(CYN;VYE"B`@("`\8V%S92!N86UE/2)N;VYE(B!D
M97-C/2)5<V4@=&AE(&1E9F%U;'0@4$A0("AF:6QE+6)A<V5D*2!S97-S:6]N
M(&AA;F1L97(B+SX*("`@(#QC87-E(&YA;64](F5X=&5R;F%L(B!D97-C/2)5
M<V4@>6]U<B!O=VX@8W5S=&]M('-E<W-I;VX@:&%N9&QE<B(^"B`@("`@/&-O
M;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9W-T<FEN
M9R!N86UE/2)O<&5N(B!D97-C/2)9;W5R(&]P96XH*2!F=6YC=&EO;B(O/@H@
M("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F-L;W-E(B!D97-C/2)9;W5R(&-L
M;W-E*"D@9G5N8W1I;VXB+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)R
M96%D(B!D97-C/2)9;W5R(')E860H*2!F=6YC=&EO;B(O/@H@("`@("`\8V]N
M9FEG<W1R:6YG(&YA;64](G=R:71E(B!D97-C/2)9;W5R('=R:71E*"D@9G5N
M8W1I;VXB+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)D97-T<F]Y(B!D
M97-C/2)9;W5R(&1E<W1R;WDH*2!F=6YC=&EO;B(O/@H@("`@("`\8V]N9FEG
M<W1R:6YG(&YA;64](F=C(B!D97-C/2)9;W5R(&=C*"D@9G5N8W1I;VXB+SX*
M("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^"B`@("`\8V%S92!N
M86UE/2)D8FTB(&1E<V,](D1"32!B87-E9"!S97-S:6]N<R(O/@H@("`@/&-A
M<V4@;F%M93TB;7ES<6PB(&1E<V,](DUY4U%,(&)A<V5D('-E<W-I;VYS(CX*
M("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\8V]N
M9FEG8F]O;&5A;B!N86UE/2)P97)S:7-T96YT(B!D97-C/2)297%U97-T('!E
M<G-I<W1E;G0@8V]N;F5C=&EO;G,_(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*
M("`@("`@/&-O;F9I9V)O;VQE86X@;F%M93TB<F]W;&]C:VEN9R(@9&5S8STB
M4VAO=6QD('=E('5S92!R;W<M;&5V96P@;&]C:VEN9PH@("`@("!A;F0@=')A
M;G-A8W1I;VYS/R!4:&ES(&ES('-T<F]N9VQY(')E8V]M;65N9&5D+"!B=70@
M<F5Q=6ER97,@82!T86)L90H@("`@("!T>7!E('1H870@:7,@=')A;G-A8W1I
M;VXM<V%F92!A;F0@<W5P<&]R=',@<F]W+6QE=F5L(&QO8VMI;F<L(&QI:V4*
M("`@("`@26YN;T1"+B!)9B!Y;W4@9&]N)W0@:&%V92!S=6-H(&$@=&%B;&4@
M='EP92P@9&ES86)L92!T:&ES('-E='1I;F<@86YD('=E"B`@("`@('=I;&P@
M=7-E('1A8FQE+6QE=F5L(&QO8VMI;F<@86YD(&YO(&QO8VMI;F<*("`@("`@
M:6YS=&5A9"XB/G1R=64\+V-O;F9I9V)O;VQE86X^"B`@("`@(#QC;VYF:6=S
M=VET8V@@;F%M93TB<')O=&]C;VPB(&1E<V,](E=H870@<')O=&]C;VP@=VEL
M;"!W92!U<V4@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4_(CYU;FEX"B`@
M("`@("`\8V%S92!N86UE/2)U;FEX(B!D97-C/2)53DE8(%-O8VME=',B/@H@
M("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<V]C:V5T(B!R97%U:7)E9#TB
M9F%L<V4B(&1E<V,](DQO8V%T:6]N(&]F(%5.25@@<V]C:V5T(CX\+V-O;F9I
M9W-T<FEN9SX*("`@("`@(#PO8V%S93X*("`@("`@(#QC87-E(&YA;64](G1C
M<"(@9&5S8STB5$-0+TE0(CX*("`@("`@("`\8V]N9FEG:6YT96=E<B!N86UE
M/2)P;W)T(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E!O<G0@=&AE($1"(&ES
M(')U;FYI;F<@;VXL(&EF(&YO;BUS=&%N9&%R9"(^,S,P-CPO8V]N9FEG:6YT
M96=E<CX*("`@("`@(#PO8V%S93X*("`@("`@/"]C;VYF:6=S=VET8V@^"B`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB:&]S='-P96,B(&1E<V,](E=H870@
M:&]S=&YA;64@:7,@=&AE(&1A=&%B87-E('-E<G9E<B!R=6YN:6YG(&]N+"!O
M<B!W:&%T(&ES('1H92!N86UE(&]F('1H92!S>7-T96T@1%-.('1O('5S93\B
M/FQO8V%L:&]S=#PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG
M(&YA;64](G5S97)N86UE(B!D97-C/2)7:&%T('5S97)N86UE(&1O('=E(&%U
M=&AE;G1I8V%T92!T;R!T:&4@9&%T86)A<V4@<V5R=F5R(&%S/R(^:&]R9&4\
M+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P87-S
M=V]R9"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)7:&%T('!A<W-W;W)D(&1O
M('=E(&%U=&AE;G1I8V%T92!T;R!T:&4@9&%T86)A<V4@<V5R=F5R('=I=&@_
M(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB9&%T86)A<V4B(&1E<V,]
M(E=H870@9&%T86)A<V4@;F%M92]T86)L97-P86-E(&%R92!W92!U<VEN9S\B
M/FAO<F1E/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M
M93TB=&%B;&4B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE(&YA;64@;V8@
M=&AE('-E<W-I;VX@=&%B;&4@:6X@=&AE(&1A=&%B87-E(%MH;W)D95]S97-S
M:6]N:&%N9&QE<ETB+SX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A
M<V4^"B`@("`\8V%S92!N86UE/2)O8VDX(B!D97-C/2)/<F%C;&4@8F%S960@
M<V5S<VEO;G,B/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^
M"B`@("`@(#QC;VYF:6=B;V]L96%N(&YA;64](G!E<G-I<W1E;G0B(&1E<V,]
M(E)E<75E<W0@<&5R<VES=&5N="!C;VYN96-T:6]N<S\B/@H@("`@("!F86QS
M93PO8V]N9FEG8F]O;&5A;CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)H
M;W-T<W!E8R(@9&5S8STB1&%T86)A<V4@;F%M92!O<B!%87-Y($-O;FYE8W0*
M("`@("`@<&%R86UE=&5R(CYH;W)D93PO8V]N9FEG<W1R:6YG/@H@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](G5S97)N86UE(B!D97-C/2)7:&%T('5S97)N
M86UE(&1O('=E(&%U=&AE;G1I8V%T92!T;PH@("`@("!T:&4@9&%T86)A<V4@
M<V5R=F5R(&%S/R(^:&]R9&4\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I
M9W-T<FEN9R!N86UE/2)P87-S=V]R9"(@<F5Q=6ER960](F9A;'-E(B!D97-C
M/2)7:&%T('!A<W-W;W)D(&1O('=E"B`@("`@(&%U=&AE;G1I8V%T92!T;R!T
M:&4@9&%T86)A<V4@<V5R=F5R('=I=&@_(B\^"B`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB=&%B;&4B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE(&YA
M;64@;V8@=&AE('-E<W-I;VX*("`@("`@=&%B;&4@:6X@=&AE(&1A=&%B87-E
M(%MH;W)D95]S97-S:6]N:&%N9&QE<ETB+SX*("`@("`\+V-O;F9I9W-E8W1I
M;VX^"B`@("`\+V-A<V4^"B`@("`\8V%S92!N86UE/2)P9W-Q;"(@9&5S8STB
M4&]S=&=R95-13"!B87-E9"!S97-S:6]N<R(^"B`@("`@/&-O;F9I9W-E8W1I
M;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9V)O;VQE86X@;F%M93TB
M<&5R<VES=&5N="(@9&5S8STB4F5Q=65S="!P97)S:7-T96YT(&-O;FYE8W1I
M;VYS/R(^9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@("`@(#QC;VYF:6=S=VET
M8V@@;F%M93TB<')O=&]C;VPB(&1E<V,](E=H870@<')O=&]C;VP@=VEL;"!W
M92!U<V4@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4_(CYU;FEX"B`@("`@
M("`\8V%S92!N86UE/2)U;FEX(B!D97-C/2)53DE8(%-O8VME=',B/@H@("`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<V]C:V5T(B!R97%U:7)E9#TB9F%L
M<V4B(&1E<V,](DQO8V%T:6]N(&]F(%5.25@@<V]C:V5T(CX\+V-O;F9I9W-T
M<FEN9SX*("`@("`@(#PO8V%S93X*("`@("`@(#QC87-E(&YA;64](G1C<"(@
M9&5S8STB5$-0+TE0(CX*("`@("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)P
M;W)T(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E!O<G0@=&AE($1"(&ES(')U
M;FYI;F<@;VXL(&EF(&YO;BUS=&%N9&%R9"(^-30S,CPO8V]N9FEG:6YT96=E
M<CX*("`@("`@(#PO8V%S93X*("`@("`@/"]C;VYF:6=S=VET8V@^"B`@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB:&]S='-P96,B(&1E<V,](E=H870@:&]S
M=&YA;64@:7,@=&AE(&1A=&%B87-E('-E<G9E<B!R=6YN:6YG(&]N+"!O<B!W
M:&%T(&ES('1H92!N86UE(&]F('1H92!S>7-T96T@1%-.('1O('5S93\B/FQO
M8V%L:&]S=#PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](G5S97)N86UE(B!D97-C/2)7:&%T('5S97)N86UE(&1O('=E(&%U=&AE
M;G1I8V%T92!T;R!T:&4@9&%T86)A<V4@<V5R=F5R(&%S/R(^:&]R9&4\+V-O
M;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P87-S=V]R
M9"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)7:&%T('!A<W-W;W)D(&1O('=E
M(&%U=&AE;G1I8V%T92!T;R!T:&4@9&%T86)A<V4@<V5R=F5R('=I=&@_(B\^
M"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB9&%T86)A<V4B(&1E<V,](E=H
M870@9&%T86)A<V4@;F%M92]T86)L97-P86-E(&%R92!W92!U<VEN9S\B/FAO
M<F1E/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB
M=&%B;&4B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE(&YA;64@;V8@=&AE
M('-E<W-I;VX@=&%B;&4@:6X@=&AE(&1A=&%B87-E(%MH;W)D95]S97-S:6]N
M:&%N9&QE<ETB+SX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^
M"B`@("`\8V%S92!N86UE/2)S87!D8B(@9&5S8STB57-E(%!%05(G<R!$0B!A
M8G-T<F%C=&EO;B!L87EE<B!W+T]$0D,B/@H@("`@(#QC;VYF:6=S96-T:6]N
M(&YA;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB:&]S
M='-P96,B(&1E<V,](E=H870@:&]S=&YA;64@:7,@=&AE(&1A=&%B87-E('-E
M<G9E<B!R=6YN:6YG(&]N+"!O<B!W:&%T(&ES('1H92!N86UE(&]F('1H92!S
M>7-T96T@1%-.('1O('5S93\B/FQO8V%L:&]S=#PO8V]N9FEG<W1R:6YG/@H@
M("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G5S97)N86UE(B!D97-C/2)7:&%T
M('5S97)N86UE(&1O('=E(&%U=&AE;G1I8V%T92!T;R!T:&4@9&%T86)A<V4@
M<V5R=F5R(&%S/R(^:&]R9&4\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I
M9W-T<FEN9R!N86UE/2)P87-S=V]R9"(@<F5Q=6ER960](F9A;'-E(B!D97-C
M/2)7:&%T('!A<W-W;W)D(&1O('=E(&%U=&AE;G1I8V%T92!T;R!T:&4@9&%T
M86)A<V4@<V5R=F5R('=I=&@_(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M
M93TB9&%T86)A<V4B(&1E<V,](E=H870@9&%T86)A<V4@;F%M92]T86)L97-P
M86-E(&%R92!W92!U<VEN9S\B/FAO<F1E/"]C;VYF:6=S=')I;F<^"B`@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB=&%B;&4B(&1E<V,](E1H92!N86UE(&]F
M('1H92!S97-S:6]N('1A8FQE(&EN('1H92!D871A8F%S92(O/@H@("`@(#PO
M8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*("`@(#QC87-E(&YA;64](G-Q
M;"(@9&5S8STB57-E(%!%05(G<R!$0B!A8G-T<F%C=&EO;B!L87EE<B(^"B`@
M("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I
M9V)O;VQE86X@;F%M93TB<&5R<VES=&5N="(@9&5S8STB4F5Q=65S="!P97)S
M:7-T96YT(&-O;FYE8W1I;VYS/R(^9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@
M("`@(#QC;VYF:6=S=VET8V@@;F%M93TB<')O=&]C;VPB(&1E<V,](E=H870@
M<')O=&]C;VP@=VEL;"!W92!U<V4@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A
M<V4_(CYU;FEX"B`@("`@("`\8V%S92!N86UE/2)U;FEX(B!D97-C/2)53DE8
M(%-O8VME=',B/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<V]C:V5T
M(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](DQO8V%T:6]N(&]F(%5.25@@<V]C
M:V5T(CX\+V-O;F9I9W-T<FEN9SX*("`@("`@(#PO8V%S93X*("`@("`@(#QC
M87-E(&YA;64](G1C<"(@9&5S8STB5$-0+TE0(CX*("`@("`@("`\8V]N9FEG
M:6YT96=E<B!N86UE/2)P;W)T(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E!O
M<G0@=&AE($1"(&ES(')U;FYI;F<@;VXL(&EF(&YO;BUS=&%N9&%R9"(^-30S
M,CPO8V]N9FEG:6YT96=E<CX*("`@("`@(#PO8V%S93X*("`@("`@/"]C;VYF
M:6=S=VET8V@^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB:&]S='-P96,B
M(&1E<V,](E=H870@:&]S=&YA;64@:7,@=&AE(&1A=&%B87-E('-E<G9E<B!R
M=6YN:6YG(&]N+"!O<B!W:&%T(&ES('1H92!N86UE(&]F('1H92!S>7-T96T@
M1%-.('1O('5S93\B/FQO8V%L:&]S=#PO8V]N9FEG<W1R:6YG/@H@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](G5S97)N86UE(B!D97-C/2)7:&%T('5S97)N
M86UE(&1O('=E(&%U=&AE;G1I8V%T92!T;R!T:&4@9&%T86)A<V4@<V5R=F5R
M(&%S/R(^:&]R9&4\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN
M9R!N86UE/2)P87-S=V]R9"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)7:&%T
M('!A<W-W;W)D(&1O('=E(&%U=&AE;G1I8V%T92!T;R!T:&4@9&%T86)A<V4@
M<V5R=F5R('=I=&@_(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB9&%T
M86)A<V4B(&1E<V,](E=H870@9&%T86)A<V4@;F%M92]T86)L97-P86-E(&%R
M92!W92!U<VEN9S\B/FAO<F1E/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF
M:6=S=')I;F<@;F%M93TB=&%B;&4B(')E<75I<F5D/2)F86QS92(@9&5S8STB
M5&AE(&YA;64@;V8@=&AE('-E<W-I;VX@=&%B;&4@:6X@=&AE(&1A=&%B87-E
M(%MH;W)D95]S97-S:6]N:&%N9&QE<ETB+SX*("`@("`\+V-O;F9I9W-E8W1I
M;VX^"B`@("`\+V-A<V4^"B`@("`\8V%S92!N86UE/2)M96UC86-H92(@9&5S
M8STB365M8V%C:&4@<V5R=F5R(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE
M/2)P87)A;7,B/@H@("`@("`\8V]N9FEG;&ES="!N86UE/2)H;W-T<W!E8R(@
M9&5S8STB5VAA="!H;W-T;F%M92!I<R!T:&4@;65M8V%C:&4@<V5R=F5R"B`@
M("`@(')U;FYI;F<@;VXL(&]R('=H870@:7,@=&AE(&YA;64@;V8@=&AE('-Y
M<W1E;2!$4TX@=&\@=7-E/R`@4W!E8VEF>0H@("`@("!M=6QT:7!L92!S97)V
M97)S('-E<&%R871E9"!B>2!C;VUM87,N(CYL;V-A;&AO<W0\+V-O;F9I9VQI
M<W0^"B`@("`@(#QC;VYF:6=L:7-T(&YA;64](G!O<G0B(')E<75I<F5D/2)F
M86QS92(@9&5S8STB4&]R="AS*2!T:&4@;65M8V%C:&4*("`@("`@<V5R=F5R
M(&ES(')U;FYI;F<@;VXN($EF(&UO<F4@=&AA;B!O;F4@:&]S="!I<R!U<V5D
M+"!S<&5C:69Y('!O<G1S(&9O<@H@("`@("!R97-P96-T:79E('-E<G9E<G,L
M('-E<&%R871E9"!B>2!C;VUM87,B/C$Q,C$Q/"]C;VYF:6=L:7-T/@H@("`@
M("`\8V]N9FEG8F]O;&5A;B!N86UE/2)P97)S:7-T96YT(B!R97%U:7)E9#TB
M9F%L<V4B(&1E<V,](E)E<75E<W0*("`@("`@<&5R<VES=&5N="!C;VYN96-T
M:6]N('1O('-E<G9E<BXB/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@("`@("`\
M8V]N9FEG8F]O;&5A;B!N86UE/2)C;VUP<F5S<VEO;B(@<F5Q=6ER960](F9A
M;'-E(B!D97-C/2)%;F%B;&4*("`@("`@8V]M<')E<W-I;VX@9F]R('-T;W)I
M;F<@96YT<FEE<R!O;B!S97)V97(N(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*
M("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)L;V-K7V1I<B(@9&5S8STB4W!E
M8VEF>2!A(&1I<F5C=&]R>2!T;R!W:&EC:"!T:&4*("`@("`@<V5S<VEO;B!L
M;V-K<R!S:&]U;&0@8F4@=W)I='1E;B(^+W1M<#PO8V]N9FEG<W1R:6YG/@H@
M("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*("`@/"]C;VYF:6=S
M=VET8V@^"B`@/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF:6=T86(^"@H@/&-O
M;F9I9W1A8B!N86UE/2)I;6%G92(@9&5S8STB26UA9V4@36%N:7!U;&%T:6]N
M(CX*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)I;6%G92(^"B`@(#QC;VYF:6=H
M96%D97(^26UA9V4@36%N:7!U;&%T:6]N/"]C;VYF:6=H96%D97(^"B`@(#QC
M;VYF:6=S=')I;F<@;F%M93TB8V]N=F5R="(@<F5Q=6ER960](F9A;'-E(B!D
M97-C/2)(;W)D92!R97%U:7)E<R!E:71H97(*("`@1T0@<W5P<&]R="!B=6EL
M="UI;B!T;R!02%`@*"TM=VET:"UG9"D@;W(@=&AE($EM86=E36%G:6-K('-O
M9G1W87)E"B`@('!A8VMA9V4@*&AT='`Z+R]W=W<N:6UA9V5M86=I8VLN;W)G
M+RD@=&\@9&\@:6UA9V4*("`@;6%N:7!U;&%T:6]N+V-R96%T:6]N+B!)9B!U
M<VEN9R!);6%G94UA9VEC:RP@<W!E8VEF>2!T:&4@9G5L;"!P871H"B`@(&YA
M;64@=&\@=&AE("=C;VYV97)T)R!P<F]G<F%M+B!/;B!7:6YD;W=S+"!T:&ES
M('!A=&@@*F-A;FYO="H@:&%V90H@("!S<&%C97,@:6X@:70N(%5S92!$3U,M
M<W1Y;&4@86)B<F5V:6%T:6]N<R!I9B!N96-E<W-A<GDZ(%!R;V=R87XQ"B`@
M(&EN<W1E860@;V8@4')O9W)A;2!&:6QE<RP@9F]R(&EN<W1A;F-E+B!)9B!U
M<VEN9R!'1"P@;W(@=7-I;F<*("`@;F5I=&AE<BP@;&5A=F4@=&AI<R!F:65L
M9"!B;&%N:RXB+SX*("`\+V-O;F9I9W-E8W1I;VX^"B`\+V-O;F9I9W1A8CX*
M"B`\8V]N9FEG=&%B(&YA;64](FUI;64B(&1E<V,](DU)344@1&5T96-T:6]N
M(CX*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)M:6UE(CX*("`@/&-O;F9I9VAE
M861E<CY-24U%($1E=&5C=&EO;CPO8V]N9FEG:&5A9&5R/@H@("`\8V]N9FEG
M<W1R:6YG(&YA;64](FUA9VEC7V1B(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,]
M(DQO8V%T:6]N(&]F('1H92!-24U%"B`@(&UA9VEC(&1A=&%B87-E+B!5<W5A
M;&QY("]U<W(O<VAA<F4O;6ES8R]M86=I8R!O<B`O971C+VUA9VEC+B(O/@H@
M(#PO8V]N9FEG<V5C=&EO;CX*(#PO8V]N9FEG=&%B/@H*(#QC;VYF:6=T86(@
M;F%M93TB9V5O:7`B(&1E<V,](DAO<W1N86UE+29G=#M#;W5N=')Y($QO;VMU
M<"(^"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB9V5O:7`B/@H@("`\8V]N9FEG
M:&5A9&5R/DAO<W1N86UE+29G=#M#;W5N=')Y($QO;VMU<#PO8V]N9FEG:&5A
M9&5R/@H@("`\8V]N9FEG<W1R:6YG(&YA;64](F1A=&%F:6QE(B!R97%U:7)E
M9#TB9F%L<V4B(&1E<V,](DAO<F1E+"!B>2!D969A=6QT+"!C86X*("`@9&\@
M2&]S=&YA;64@+29G=#L@0V]U;G1R>2!L;V]K=7`@=7-I;F<@=&AE('1O<"!L
M979E;"!D;VUA:6X@*&4N9RX@)W5K)RP*("`@)V1E)RD@;V8@=&AE(&AO<W1N
M86UE+B`@2&]W979E<BP@;6%N>2!P;W!U;&%R('1O<"!L979E;"!D;VUA:6YS
M"B`@("AE+F<N("=C;VTG+"`G;F5T)RD@<W!A;B!M;W)E('1H86X@;VYE(&-O
M=6YT<GDN("!);B!T:&5S92!I;G-T86YC97,L($AO<F1E"B`@(&-A;B!U<V4@
M=&AE($UA>$UI;F0@1V5O25`@2&]S=&YA;64@=&\@0V]U;G1R>2!L;V]K=7`@
M=&\@=')Y('1O(&1E=&5R;6EN90H@("!T:&4@8V]R<F5C="!C;W5N=')Y+B`@
M5&\@86-T:79A=&4@=&AI<R!F=6YC=&EO;F%L:71Y+"!T:&4@1V5O25`N9&%T
M(&-O=6YT<GD*("`@9&%T86)A<V4@;75S="!B92!P<F5S96YT(&]N('EO=7(@
M;&]C86P@<WES=&5M+B`@5&AI<R!F:6QE(&-A;B!B92!D;W=N;&]A9&5D"B`@
M(&9R964@;V8@8VAA<F=E(&9R;VT@:'1T<#HO+W=W=RYM87AM:6YD+F-O;2]D
M;W=N;&]A9"]G96]I<"]D871A8F%S92\N("!)9@H@("!T:&ES(&1A=&%B87-E
M(&ES('!R97-E;G0L('-P96-I9GD@=&AE(&9U;&P@<&%T:"!N86UE('1O('1H
M92!D871A8F%S92!B96QO=RX*("`@268@96UP='DL('1H92!'96])4"!L;V]K
M=7`@=VEL;"!N;W0@8F4@<&5R9F]R;65D+B(O/@H@(#PO8V]N9FEG<V5C=&EO
M;CX*(#PO8V]N9FEG=&%B/@H*(#QC;VYF:6=T86(@;F%M93TB<')O8FQE;7,B
M(&1E<V,](E!R;V)L96T@4F5P;W)T:6YG(CX*("`\8V]N9FEG<V5C=&EO;B!N
M86UE/2)P<F]B;&5M<R(^"B`@(#QC;VYF:6=H96%D97(^4')O8FQE;2!297!O
M<G1I;F<\+V-O;F9I9VAE861E<CX*("`@/&-O;F9I9W-W:71C:"!N86UE/2)T
M:6-K971S(B!D97-C/2))9B!A('1I8VME="!S>7-T96T@=VET:"!A"B`@('1I
M8VME=',O861D5&EC:V5T($%022!M971H;V0@:7,@<')E<V5N="P@<VAO=6QD
M('=E(&-R96%T92!T:6-K971S(&9O<@H@("!P<F]B;&5M(')E<&]R=',@:6YS
M=&5A9"!O9B!E;6%I;&EN9R!T:&5M/R(^9F%L<V4*("`@(#QC87-E(&YA;64]
M(G1R=64B(&1E<V,](EEE<R(^"B`@("`@/&-O;F9I9W!H<"!N86UE/2)T:6-K
M971?<&%R86US(B!D97-C/2)%;G1E<B!A<R!A(%!(4"!A<G)A>2!A;GD*("`@
M("!A9&1I=&EO;F%L(&%R9W5M96YT<R!F;W(@=&AE(&-R96%T960@=&EC:V5T
M("AQ=65U92P@<W1A=&4L('!R:6]R:71Y+`H@("`@(&5T8RDN($5X86UP;&4@
M9F]R(%=H=7!S.B!A<G)A>2@G<75E=64G(#T^(#(L("=S=&%T92<@/3X@,2P@
M)W!R:6]R:71Y)R`]/B`Q+`H@("`@("=T>7!E)R`]/B`Q*2X@66]U('=I;&P@
M;F5E9"!T;R!L;V]K('5P('1H92!A<'!R;W!R:6%T92!)1',@:6X@5VAU<',G
M<PH@("`@(&1A=&%B87-E+"!O<B!W:&%T979E<B!I<R!A<'!R;W!R:6%T92!F
M;W(@=&AE('1I8VME="!S>7-T96T@>6]U(&%R90H@("`@('5S:6YG+B(^87)R
M87DH*3PO8V]N9FEG<&AP/@H@("`@/"]C87-E/@H@("`@/&-A<V4@;F%M93TB
M9F%L<V4B(&1E<V,](DYO(CX*("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F5M
M86EL(B!D97-C/2)7:&5R92!S:&]U;&0@<')O8FQE;2!R97!O<G0@96UA:6QS
M(&)E('-E;G0_(CX*("`@("!W96)M87-T97)`97AA;7!L92YC;VT\+V-O;F9I
M9W-T<FEN9SX*("`@("`\8V]N9FEG<W1R:6YG(&YA;64](FUA:6QD;VUA:6XB
M(&1E<V,](DEF($AO<F1E(&-A;FYO="!D971E<FUI;F4@82!U<V5R)W,*("`@
M("!E;6%I;"!A9&1R97-S+"!T:&ES(&1O;6%I;B!W:6QL(&)E(&%P<&5N9&5D
M('1O('1H96ER"B`@("`@=7-E<FYA;64N(CYE>&%M<&QE+F-O;3PO8V]N9FEG
M<W1R:6YG/@H@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=7-E<FYA;64B(')E
M<75I<F5D/2)F86QS92(@9&5S8STB268@<F5Q=6ER:6YG(%--5%`*("`@("!A
M=71H96YT:6-A=&EO;B!W:71H;W5T(&$@9VQO8F%L(%--5%`@=7-E<B`H:6X@
M<V5C=&EO;B`F<75O=#M-86EL97(F<75O=#L*("`@("!A;F0@86QL;W=I;F<@
M<')O8FQE;2!R97!O<G1I;F<@9F]R(&YO="!A=71H96YT:6-A=&5D('5S97)S
M("AI;B!S96-T:6]N"B`@("`@)G%U;W0[365N=2!3971T:6YG<R9Q=6]T.RDL
M('=H870@=7-E<FYA;64@<VAO=6QD(&)E('5S92!F;W(@4TU44`H@("`@(&%U
M=&AE;G1I8V%T:6]N/R(O/@H@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<&%S
M<W=O<F0B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE('!A<W-W;W)D('1O
M('5S92(O/@H@("`@/"]C87-E/@H@("`\+V-O;F9I9W-W:71C:#X*("`\+V-O
M;F9I9W-E8W1I;VX^"B`\+V-O;F9I9W1A8CX*"B`\8V]N9FEG=&%B(&YA;64]
M(FUE;G4B(&1E<V,](DUE;G4@4V5T=&EN9W,B/@H@(#QC;VYF:6=H96%D97(^
M365N=2!3971T:6YG<SPO8V]N9FEG:&5A9&5R/@H@(#QC;VYF:6=S96-T:6]N
M(&YA;64](FUE;G4B/@H@("`\8V]N9FEG;75L=&EE;G5M(&YA;64](F%P<',B
M(&1E<V,](E-E;&5C="!A;GD@87!P;&EC871I;VYS('1H870@<VAO=6QD(&)E
M"B`@(&QI;FME9"!I;B!(;W)D92=S(&UE;G4B/@H@("`@/'9A;'5E<SX*("`@
M("`\8V]N9FEG<W!E8VEA;"!N86UE/2)L:7-T+6AO<F1E+6%P<',B("\^"B`@
M("`\+W9A;'5E<SX*("`@/"]C;VYF:6=M=6QT:65N=6T^"@H@("`\8V]N9FEG
M8F]O;&5A;B!N86UE/2)A;'=A>7,B(&1E<V,](E-H;W5L9"!W90H@("`F;'0[
M<W1R;VYG)F=T.V%L=V%Y<R9L=#LO<W1R;VYG)F=T.R!D:7-P;&%Y('1H92!(
M;W)D90H@("!F<F%M97-E=#\B/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H*("`@
M/&-O;F9I9W-E8W1I;VX@;F%M93TB;&EN:W,B/@H@("`@/&-O;F9I9V5N=6T@
M;F%M93TB:&5L<"(@9&5S8STB4VAO=6QD('=E(&1I<W!L87D@:&5L<"!L:6YK
M<R!I;B!T:&4*("`@(&UE;G4_(CYA;&P*("`@("`\=F%L=65S/@H@("`@("`\
M=F%L=64@9&5S8STB06QL('5S97)S(CYA;&P\+W9A;'5E/@H@("`@("`\=F%L
M=64@9&5S8STB075T:&5N=&EC871E9"!U<V5R<R(^875T:&5N=&EC871E9#PO
M=F%L=64^"B`@("`@(#QV86QU92!D97-C/2).979E<B(^;F5V97(\+W9A;'5E
M/@H@("`@(#PO=F%L=65S/@H@("`@/"]C;VYF:6=E;G5M/@H@("`@/&-O;F9I
M9V)O;VQE86X@;F%M93TB:&5L<%]A8F]U="(@9&5S8STB4VAO=6QD('=E(&1I
M<W!L87D@=&AE(&%B;W5T(&QI;FL@:6X*("`@('1H92!H96QP(&UE;G4_(CYT
M<G5E/"]C;VYF:6=B;V]L96%N/@H@("`@/&-O;F9I9V5N=6T@;F%M93TB;W!T
M:6]N<R(@9&5S8STB4VAO=6QD('=E(&1I<W!L87D@;W!T:6]N<R!L:6YK<R!I
M;B!T:&4*("`@(&UE;G4_(%EO=2!S=&EL;"!N965D('1O(&-O;F9I9W5R92!A
M('!R969E<F5N8V4@8F%C:V5N9"!I;B!T:&4*("`@("9Q=6]T.U!R969E<F5N
M8V4@4WES=&5M)G%U;W0[('-E8W1I;VXN(CYA=71H96YT:6-A=&5D"B`@("`@
M/'9A;'5E<SX*("`@("`@/'9A;'5E(&1E<V,](D%L;"!U<V5R<R(^86QL/"]V
M86QU93X*("`@("`@/'9A;'5E(&1E<V,](D%U=&AE;G1I8V%T960@=7-E<G,B
M/F%U=&AE;G1I8V%T960\+W9A;'5E/@H@("`@("`\=F%L=64@9&5S8STB3F5V
M97(B/FYE=F5R/"]V86QU93X*("`@("`\+W9A;'5E<SX*("`@(#PO8V]N9FEG
M96YU;3X*("`@(#QC;VYF:6=E;G5M(&YA;64](G!R;V)L96TB(&1E<V,](E-H
M;W5L9"!W92!D:7-P;&%Y('!R;V)L96T@<F5P;W)T:6YG(&QI;FMS"B`@("!I
M;B!T:&4@;65N=3\B/F%L;`H@("`@(#QV86QU97,^"B`@("`@(#QV86QU92!D
M97-C/2)!;&P@=7-E<G,B/F%L;#PO=F%L=64^"B`@("`@(#QV86QU92!D97-C
M/2)!=71H96YT:6-A=&5D('5S97)S(CYA=71H96YT:6-A=&5D/"]V86QU93X*
M("`@("`@/'9A;'5E(&1E<V,](DYE=F5R(CYN979E<CPO=F%L=64^"B`@("`@
M/"]V86QU97,^"B`@("`\+V-O;F9I9V5N=6T^"B`@("`\8V]N9FEG96YU;2!N
M86UE/2)L;V=I;B(@9&5S8STB4VAO=6QD('=E(&1I<W!L87D@82!L;V=I;B!L
M:6YK(&EN('1H92!M96YU"B`@("!W:&5N(&YO="!L;V=G960@:6X_(CYA;&P*
M("`@("`\=F%L=65S/@H@("`@("`\=F%L=64@9&5S8STB06QL('5S97)S(CYA
M;&P\+W9A;'5E/@H@("`@("`\=F%L=64@9&5S8STB3F5V97(B/FYE=F5R/"]V
M86QU93X*("`@("`\+W9A;'5E<SX*("`@(#PO8V]N9FEG96YU;3X*("`@(#QC
M;VYF:6=E;G5M(&YA;64](FQO9V]U="(@9&5S8STB4VAO=6QD('=E(&1I<W!L
M87D@82!L;V=O=70@;&EN:R!I;B!T:&4*("`@(&UE;G4@=VAE;B!L;V=G960@
M:6X_(CYA=71H96YT:6-A=&5D"B`@("`@/'9A;'5E<SX*("`@("`@/'9A;'5E
M(&1E<V,](D%U=&AE;G1I8V%T960@=7-E<G,B/F%U=&AE;G1I8V%T960\+W9A
M;'5E/@H@("`@("`\=F%L=64@9&5S8STB3F5V97(B/FYE=F5R/"]V86QU93X*
M("`@("`\+W9A;'5E<SX*("`@(#PO8V]N9FEG96YU;3X*("`@(#QC;VYF:6=E
M;G5M(&YA;64](FQO9VEN(B!D97-C/2)3:&]U;&0@=V4@9&ES<&QA>2!A(&QO
M9VEN(&QI;FL@:6X@=&AE(&UE;G4*("`@('=H96X@;F]T(&QO9V=E9"!I;C\B
M/F%L;`H@("`@(#QV86QU97,^"B`@("`@(#QV86QU92!D97-C/2)!;&P@=7-E
M<G,B/F%L;#PO=F%L=64^"B`@("`@(#QV86QU92!D97-C/2).979E<B(^;F5V
M97(\+W9A;'5E/@H@("`@(#PO=F%L=65S/@H@("`@/"]C;VYF:6=E;G5M/@H@
M("`@/&-O;F9I9V5N=6T@;F%M93TB;&]G;W5T(B!D97-C/2)3:&]U;&0@=V4@
M9&ES<&QA>2!A(&QO9V]U="!L:6YK(&EN('1H90H@("`@;65N=2!W:&5N(&QO
M9V=E9"!I;C\B/F%U=&AE;G1I8V%T960*("`@("`\=F%L=65S/@H@("`@("`\
M=F%L=64@9&5S8STB075T:&5N=&EC871E9"!U<V5R<R(^875T:&5N=&EC871E
M9#PO=F%L=64^"B`@("`@(#QV86QU92!D97-C/2).979E<B(^;F5V97(\+W9A
M;'5E/@H@("`@(#PO=F%L=65S/@H@("`@/"]C;VYF:6=E;G5M/@H@("`\+V-O
M;F9I9W-E8W1I;VX^"B`@/"]C;VYF:6=S96-T:6]N/@H*("`\8V]N9FEG<V5C
M=&EO;B!N86UE/2)L;V=O(CX*("`@/&-O;F9I9W-T<FEN9R!N86UE/2)I;6%G
M92(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@55),(&]F(&%N(&EM86=E
M(&9O<@H@("!T:&4@=&]P(&]F('1H92!(;W)D92!M96YU+B!4:&4@:6UA9V4@
M<VAO=6QD(&)E(&YO(&QA<F=E<B!T:&%N(#$T,"!P:7AE;',*("`@=VED92!B
M>2`T,"!P:7AE;',@:&EG:"!T;R!P<F5V96YT('1H92!F<F%M92!F<F]M('-C
M<F]L;&EN9RXB+SX*("`@/&-O;F9I9W-T<FEN9R!N86UE/2)L:6YK(B!R97%U
M:7)E9#TB9F%L<V4B(&1E<V,](DEF(&$@;&]G;R!I<R!D:7-P;&%Y960@:6X*
M("`@=&AE($AO<F1E(&UE;G4L('=H870@55),("AI9B!A;GDI('-H;W5L9"!I
M="!L:6YK('1O/R(O/@H@(#PO8V]N9FEG<V5C=&EO;CX*(#PO8V]N9FEG=&%B
M/@H*(#QC;VYF:6=T86(@;F%M93TB:&]O:W,B(&1E<V,](D-U<W1O;2!&=6YC
M=&EO;B!(;V]K<R(^"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB:&]O:W,B/@H@
M("`\8V]N9FEG:&5A9&5R/D-U<W1O;2!&=6YC=&EO;B!(;V]K<SPO8V]N9FEG
M:&5A9&5R/@H@("`\8V]N9FEG9&5S8W)I<'1I;VX^"B`@("!4:&5R92!A<F4@
M97AA;7!L92!F=6YC=&EO;G,@9F]R(&%L;"!H;V]K<R!I;B!H;W)D92]C;VYF
M:6<O:&]O:W,N<&AP+F1I<W0N"B`@(#PO8V]N9FEG9&5S8W)I<'1I;VX^"B`@
M(#QC;VYF:6=B;V]L96%N(&YA;64](G!E<FUS9&5N:65D(B!D97-C/2))9B!T
M:&ES(&ES(&-H96-K960L('1H90H@("!F=6YC=&EO;B!?<&5R;7-?:&]O:U]D
M96YI960H*2!W:6QL(&)E(&-A;&QE9"!T;R!R971U<FX@86X@97)R;W(@;65S
M<V%G92!I9@H@("!A('!E<FUI<W-I;VX@:&%S(&)E96X@9&5N:65D+B!/=&AE
M<G=I<V4@82!S=&%N9&%R9"!M97-S86=E('=I;&P@8F4@<VAO=VX*("`@86YD
M('1H92!U<V5R('=O;B=T('-E92!A;GD@86-T:6]N('=I9&=E=',@=&AA="!H
M92!D;V5S;B=T(&AA=F4@86-C97-S"B`@('1O+B(^9F%L<V4\+V-O;F9I9V)O
M;VQE86X^"B`@(#QC;VYF:6=B;V]L96%N(&YA;64](G5S97)N86UE(B!D97-C
M/2))9B!T:&ES(&ES(&-H96-K960L('1H92!F=6YC=&EO;@H@("!?=7-E<FYA
M;65?:&]O:U]F<F]M8F%C:V5N9"@I('=I;&P@8F4@=7-E9"!T;R!S970@=&AE
M('5S97(@;F%M92!A="!L;V=I;@H@("!T:6UE+B!4:&4@8V]U;G1E<G!A<G0@
M9G5N8W1I;VX@7W5S97)N86UE7VAO;VM?=&]B86-K96YD*"D@=VEL;"!B92!U
M<V5D('1O"B`@(&-O;G9E<G0@=7-E<B!N86UE<R!B86-K+"!F;W(@97AA;7!L
M92!W:&5N('-H;W=I;F<@;F%M92!L:7-T<R!T;R!T:&4*("`@=7-E<BXB/F9A
M;'-E/"]C;VYF:6=B;V]L96%N/@H@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)P
M<F5A=71H96YT:6-A=&4B(&1E<V,](DEF('1H:7,@:7,@8VAE8VME9"!A;F0@
M=&AE"B`@(&9U;F-T:6]N(%]H;W)D95]H;V]K7W!R96%U=&AE;G1I8V%T92@I
M(')E='5R;G,@9F%L<V4L(&%U=&AE;G1I8V%T:6]N('=I;&P*("`@9F%I;"XB
M/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@("`\8V]N9FEG8F]O;&5A;B!N86UE
M/2)P;W-T875T:&5N=&EC871E(B!D97-C/2))9B!T:&ES(&ES(&-H96-K960@
M86YD('1H90H@("!F=6YC=&EO;B!?:&]R9&5?:&]O:U]P;W-T875T:&5N=&EC
M871E*"D@<F5T=7)N<R!F86QS92P@875T:&5N=&EC871I;VX@=VEL;`H@("!F
M86EL+B(^9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@(#QC;VYF:6=B;V]L96%N
M(&YA;64](F%U=&AL9&%P(B!D97-C/2))9B!T:&ES(&ES(&-H96-K960L('1H
M92!F=6YC=&EO;@H@("!?:&]R9&5?:&]O:U]A=71H;&1A<"@I('=I;&P@8F4@
M=7-E9"!T;R!C<F5A=&4@86YD('-E="!T:&4@871T<FEB=71E<R!N965D960*
M("`@=&\@861D+V5D:70O9&5L971E('5S97)S(&)Y('1H92!,1$%0($%U=&@@
M9')I=F5R+B(^9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@/"]C;VYF:6=S96-T
M:6]N/@H@/"]C;VYF:6=T86(^"@H@/&-O;F9I9W1A8B!N86UE/2)B;&]C:R(@
M9&5S8STB4&]R=&%L($)L;V-K($-O;F9I9W5R871I;VXB/@H@(#QC;VYF:6=S
M96-T:6]N(&YA;64](G!O<G1A;"(^"B`@(#QC;VYF:6=H96%D97(^1FEX960@
M0FQO8VMS/"]C;VYF:6=H96%D97(^"B`@(#QC;VYF:6=M=6QT:65N=6T@;F%M
M93TB9FEX961?8FQO8VMS(B!M=6QD97-C/2)7:&EC:"!B;&]C:W,@<VAO=6QD
M(&%L=V%Y<R!B90H@("`@9&ES<&QA>65D(&EN('1H92!P;W)T86P_(CX*("`@
M(#QV86QU97,^"B`@("`@/&-O;F9I9W-P96-I86P@;F%M93TB;&ES="UB;&]C
M:W,B("\^"B`@("`\+W9A;'5E<SX*("`@/"]C;VYF:6=M=6QT:65N=6T^"B`@
M/"]C;VYF:6=S96-T:6]N/@H@(#QC;VYF:6=H96%D97(^=V5A=&AE<BYC;VT@
M0V]N9FEG=7)A=&EO;CPO8V]N9FEG:&5A9&5R/@H@(#QC;VYF:6=S96-T:6]N
M(&YA;64](G=E871H97)D;W1C;VTB/@H@("`\8V]N9FEG9&5S8W)I<'1I;VX^
M"B`@("!5<V4@;V8@=&AE('=E871H97(N8V]M(&)L;V-K(')E<75I<F5S(&9R
M964@<F5G:7-T<F%T:6]N(&9O<B!T:&4@6$U,"B`@("!F965D(&%T(&AT='`Z
M+R]W=W<N=V5A=&AE<BYC;VTO<V5R=FEC97,O>&UL;V%P+FAT;6PN"B`@("!!
M9G1E<B!R96=I<W1R871I;VXL(&%N(&5M86EL('=I;&P@8F4@<F5T=7)N960@
M=VET:"!T:&4@4&%R=&YE<B!)1"!A;F0*("`@(&QI8V5N<V4@:V5Y+B9L=#MB
M<B`O)F=T.PH@("`@3D]413H@=V5A=&AE<BYC;VT@9W5I9&5L:6YE<R!R97%U
M:7)E(')E9VES=')A=&EO;B!A;F0@=7-E(&]F('1H92!R971U<FYE9`H@("`@
M=F%L=65S+"!B=70@=&AE(&%P<&QI8V%T:6]N(&%P<&5A<G,@=&\@9G5N8W1I
M;VX@=VET:"!A;GD@<W1R:6YG('9A;'5E<RX*("`@/"]C;VYF:6=D97-C<FEP
M=&EO;CX*("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P87)T;F5R7VED(B!R97%U
M:7)E9#TB9F%L<V4B(&1E<V,](E1H92!P87)T;F5R($DN1"X*("`@9G)O;2!W
M96%T:&5R+F-O;2(O/@H@("`\8V]N9FEG<W1R:6YG(&YA;64](FQI8V5N<V5?
M:V5Y(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H92!L:6-E;G-E(&ME>0H@
M("!F<F]M('=E871H97(N8V]M(B\^"B`@/"]C;VYF:6=S96-T:6]N/@H*("`\
M8V]N9FEG:&5A9&5R/D9O<G1U;F4@0V]N9FEG=7)A=&EO;CPO8V]N9FEG:&5A
M9&5R/@H@(#QC;VYF:6=S96-T:6]N(&YA;64](F9O<G1U;F4B/@H@("`\8V]N
M9FEG<W1R:6YG(&YA;64](F5X96-?<&%T:"(@<F5Q=6ER960](F9A;'-E(B!D
M97-C/2)0871H('1O(&9O<G1U;F4*("`@97AE8W5T86)L92P@92YG+B`O=7-R
M+V=A;65S+V9O<G1U;F4B+SX*("`\+V-O;F9I9W-E8W1I;VX^"@H@(#QC;VYF
M:6=H96%D97(^06-C;W5N="!);F9O($-O;F9I9W5R871I;VX\+V-O;F9I9VAE
M861E<CX*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)A8V-O=6YT<R(^"B`@(#QC
M;VYF:6=S=VET8V@@;F%M93TB9')I=F5R(B!D97-C/2)7:&%T("!D<FEV97(@
M<VAO=6QD('=E('5S93\B/FYU;&P*("`@(#QC87-E(&YA;64](FYU;&PB(&1E
M<V,](FYU;&PB+SX*("`@(#QC87-E(&YA;64](FQO8V%L:&]S="(@9&5S8STB
M;&]C86QH;W-T(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B
M/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G%U;W1A7W!A=&@B(&1E<V,]
M(E!A=&@@=&\@=&AE('%U;W1A('!R;V=R86TB/B]U<W(O8FEN+W%U;W1A/"]C
M;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB9W)E<%]P
M871H(B!D97-C/2)0871H('1O('1H92!G<F5P('!R;V=R86TB/B]B:6XO9W)E
M<#PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)T
M<F%N<VQA=&5-;W5N=%!O:6YT(B!D97-C/2)3:&]U;&0@=V4@=')A;G-L871E
M(&AO;64@9&ER96-T;W)I97,@=&\@;6]U;G0@<&]I;G0@9&5V:6-E(&YA;65S
M/R(^9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@("`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB=')A;G-L871I;VY486)L92(@9&5S8STB1FEL92!T;R!T<F%N<VQA
M=&4@9&ER96-T;W)Y(&YA;65S('1O(&UO=6YT('!O:6YT(&1E=FEC92!N86UE
M<S\B/B]E=&,O;71A8CPO8V]N9FEG<W1R:6YG/@H@("`@(#PO8V]N9FEG<V5C
M=&EO;CX*("`@(#PO8V%S93X*("`@(#QC87-E(&YA;64](FQD87`B(&1E<V,]
M(DQ$05`B/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB:&]S="(@9&5S8STB3$1!4"!S97)V
M97(O:&]S="(^;&]C86QH;W-T/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF
M:6=I;G1E9V5R(&YA;64](G!O<G0B(')E<75I<F5D/2)F86QS92(@9&5S8STB
M4&]R="!,1$%0(&ES(')U;FYI;F<@;VXL(&EF(&YO;BUS=&%N9&%R9"(^,S@Y
M/"]C;VYF:6=I;G1E9V5R/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F)A
M<V5D;B(@9&5S8STB8F%S961N('-T<FEN9R(^;SUE>&%M<&QE+F-O;2QC/553
M/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB871T
M<B(@9&5S8STB3$1!4"!A='1R:6)U=&4@=&\@<V5A<F-H(&]N(CYU:60\+V-O
M;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9V5N=6T@;F%M93TB=F5R<VEO;B(@
M9&5S8STB3$1!4"!0<F]T;V-O;"!697)S:6]N(CXS"B`@("`@("`\=F%L=65S
M/@H@("`@("`@(#QV86QU92!D97-C/2),1$%0=C(@*$1E<')E8V%T960I(CXR
M/"]V86QU93X*("`@("`@("`\=F%L=64@9&5S8STB3$1!4'8S(CXS/"]V86QU
M93X*("`@("`@(#PO=F%L=65S/@H@("`@("`\+V-O;F9I9V5N=6T^"B`@("`@
M/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C87-E/@H@("`\+V-O;F9I9W-W:71C
M:#X*("`\+V-O;F9I9W-E8W1I;VX^"B`\+V-O;F9I9W1A8CX*(#QC;VYF:6=T
M86(@;F%M93TB:6US<"(@9&5S8STB24U34"!S97)V97(@<V5T=&EN9W,B/@H@
M(#QC;VYF:6=S96-T:6]N(&YA;64](FEM<W`B/@H@("`\8V]N9FEG9&5S8W)I
M<'1I;VX^"B`@(`E)9B!Y;W4@<&QA;B!T;R!U<V4@86YY(&]F($AO<F1E)W,@
M24U34"!S97)V97(@<W5P<&]R="P@96YA8FQE('1H:7,@;W!T:6]N(&%N9`H@
M("`)8V]N9FEG=7)E('1H92!S97)V97(@<V5T=&EN9W,@8F5L;W<N("!.;W1E
M('1H870@>6]U(&UU<W0@<W1I;&P@8V]N9FEG=7)E+V5N86)L90H@("`)<W!E
M8VEF:6,@24U34"!S=7!P;W)T(&EN('1H92!A<'!R;W!R:6%T92!S96-T:6]N
M+@H@("`\+V-O;F9I9V1E<V-R:7!T:6]N/@H@("`\8V]N9FEG<W=I=&-H(&YA
M;64](F5N86)L960B/F9A;'-E"B`@("`\8V%S92!N86UE/2)F86QS92(@9&5S
M8STB1&ES86)L960B("\^"B`@("`\8V%S92!N86UE/2)T<G5E(B!D97-C/2)%
M;F%B;&5D(CX*("`@("`\8V]N9FEG:&5A9&5R/DE-4U`@4V5R=F5R(%-E='1I
M;F=S/"]C;VYF:6=H96%D97(^"B`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)S
M97)V97(B(&1E<V,](E-E<G9E<B!!9&1R97-S.B(^;&]C86QH;W-T/"]C;VYF
M:6=S=')I;F<^"B`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P;W)T(B!D97-C
M/2)397)V97(@<&]R=#HB/C0P-CPO8V]N9FEG<W1R:6YG/@H@("`@(#QC;VYF
M:6=S=VET8V@@;F%M93TB875T:%]M971H;V0B(&1E<V,](E1H92!A=71H96YT
M:6-A=&EO;B!M971H;V0@=&\@=7-E(CYP;&%I;G1E>'0*("`@("`@/&-A<V4@
M;F%M93TB<&QA:6YT97AT(B!D97-C/2)0;&%I;G1E>'0B("\^"B`@("`@(#QC
M87-E(&YA;64](F-R86U?;60U(B!D97-C/2)#4D%-+4U$-2(@+SX*("`@("`@
M/&-A<V4@;F%M93TB:6UT97-T(B!D97-C/2)#>7)U<R!I;71E<W0B/@H@("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)S;V-K970B(&1E<V,](E!A=&@@=&\@
M=&AE(&1I<F5C=&]R>2!T:&%T('=I;&P@:&]L9"!T:&4@<V]C:V5T+@H@("`@
M("`@*%1H92!S;V-K970@=VEL;"!B92!N86UE9"`G:6US<%]U<V5R;F%M92YS
M8VLG*2XB/B]T;7`O/"]C;VYF:6=S=')I;F<^"B`@("`@("`\8V]N9FEG<W1R
M:6YG(&YA;64](F-O;6UA;F0B(&1E<V,](E!A=&@@=&\@:6UT97-T(&)I;F%R
M>2(^+V-Y<G5S+W5S<B]C>7)U<R]B:6XO:6UT97-T/"]C;VYF:6=S=')I;F<^
M"B`@("`@("`\8V]N9FEG96YU;2!N86UE/2)A=71H7VUE8VAA;FES;2(@9&5S
M8W)I<'1I;VX](E=H870@875T:&5N=&EC871I;VX@;65T:&]D(&1O('EO=2!W
M86YT"B`@("`@("!T;R!U<V4@=VET:"!T:&4@:6UT97-T('5T:6QI='D_(CX*
M("`@("`@("`\=F%L=65S/@H@("`@("`@("`\=F%L=64@9&5S8STB4&QA:6YT
M97AT("A,3T=)3BDB/DQ/1TE./"]V86QU93X*("`@("`@("`@/'9A;'5E(&1E
M<V,](D=34T%022(^9W-S87!I/"]V86QU93X*("`@("`@("`\+W9A;'5E<SX*
M("`@("`@(#PO8V]N9FEG96YU;3X*("`@("`@/"]C87-E/@H@("`@(#PO8V]N
M9FEG<W=I=&-H/@H@("`@/"]C87-E/@H@("`\+V-O;F9I9W-W:71C:#X*("`\
M+V-O;F9I9W-E8W1I;VX^"B`\+V-O;F9I9W1A8CX*"B`\8V]N9FEG=&%B(&YA
M;64](FMO;&%B(B!D97-C/2)+;VQA8B!'<F]U<'=A<F4@4V5R=F5R(CX*("`\
M8V]N9FEG<V5C=&EO;B!N86UE/2)K;VQA8B(^"B`@(#QC;VYF:6=D97-C<FEP
M=&EO;CX*("`@("9L=#MS=')O;F<F9W0[*BHJ($E&(%E/52!(059%($Y/($E$
M14$@5TA!5"!+3TQ!0B!)4R!42$5.(%E/52!#04X@4T%&14Q9"B`@("!)1TY/
M4D4@5$A)4R!404(@*BHJ)FQT.R]S=')O;F<F9W0[)FQT.V)R("\F9W0["B`@
M("!+;VQA8B!I<R!I;B!N;R!W87D@<F5Q=6ER960@9F]R(&YO<FUA;"!(;W)D
M92!U<V%G92X@268L(&AO=V5V97(L('EO=0H@("`@:6YT96YD('1O('5S92!(
M;W)D92!A<R!A('=E8F-L:65N="!F;W(@2V]L86(@=&AE;B!Y;W4@=VEL;"!N
M965D('1O(&5N<W5R90H@("`@=&AA="!T:&4@9F]L;&]W:6YG(&9I96QD<R!C
M;W)R97-P;VYD('1O('1H;W-E(')E<75I<F5D(&)Y('EO=7(@2V]L86(*("`@
M(&EN<W1A;&QA=&EO;BX@(%EO=2!C86X@9FEN9"!S;VUE(&]F('1H92!R97%U
M:7)E9"!V86QU97,@:6X@=&AE"B`@("`F;'0[8V]D929G=#L@)$M/3$%"7U)/
M3U0O971C+VMO;&%B+VMO;&%B+F-O;F8F;'0[+V-O9&4F9W0[(&-O;F9I9W5R
M871I;VX*("`@(&9I;&4N(%!L96%S92!N;W1E('1H870@=&AE(&]L9"!I0V%L
M+W9#87)D('-T;W)A9V4@9F]R;6%T(&AA<R!B965N(&1R;W!P960*("`@(&EN
M(&9A=F]U<B!O9B!T:&4@;F5W(%A-3"!S=&]R86=E(&9O<FUA="`F86UP.V%M
M<#L@24U!4"!F;VQD97(@86YN;W1A=&EO;G,["B`@("!S=6)S97%U96YT;'D@
M=&AE($AO<F1E($MO;&%B(&UO9'5L97,@=VEL;"!O;FQY('=O<FL@=VET:"!V
M97)S:6]N(#(@;V8@=&AE"B`@("!+;VQA8B!S97)V97(N)FQT.V)R("\F9W0[
M"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!F:6YD(&]U="!M;W)E(&%B;W5T
M($MO;&%B('1H96X@<&QE87-E('9I<VET('1H92!+;VQA8@H@("`@8V]M;75N
M:71Y('=E8G-I=&4@870@:'1T<#HO+W=W=RYK;VQA8BYO<F<O"B`@(#PO8V]N
M9FEG9&5S8W)I<'1I;VX^"B`@(#QC;VYF:6=S=VET8V@@;F%M93TB96YA8FQE
M9"(@<75O=&4](F9A;'-E(B!D97-C/2)(;W)D92]+;VQA8B!I;G1E9W)A=&EO
M;@H@("`@<W1A='5S(CYF86QS90H@("`@/&-A<V4@;F%M93TB9F%L<V4B(&1E
M<V,](D1I<V%B;&5D(B`O/@H@("`@/&-A<V4@;F%M93TB=')U92(@9&5S8STB
M16YA8FQE9"(^"B`@("`@/&-O;F9I9VAE861E<CY+;VQA8B!,1$%0(%-E<G9E
M<B!3971T:6YG<SPO8V]N9FEG:&5A9&5R/@H@("`@(#QC;VYF:6=S96-T:6]N
M(&YA;64](FQD87`B/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G-E<G9E
M<B(@9&5S8STB4V5R=F5R"B`@("`@(&%D9')E<W,Z(CYL;V-A;&AO<W0\+V-O
M;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9VEN=&5G97(@;F%M93TB<&]R="(@
M9&5S8STB4V5R=F5R('!O<G0Z(CXS.#D\+V-O;F9I9VEN=&5G97(^"B`@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB8F%S961N(B!D97-C/2)"87-E($1..B(^
M9&,]97AA;7!L92P*("`@("`@9&,]8V]M/"]C;VYF:6=S=')I;F<^"B`@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB8FEN9&1N(B!D97-C/2)":6YD($1..B(^
M8VX];6%N86=E<BP@8VX]:6YT97)N86PL"B`@("`@(&1C/65X86UP;&4L(&1C
M/6-O;3PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64]
M(F)I;F1P=R(@9&5S8STB0FEN9"!087-S=V]R9#HB/G!A<W-W;W)D/"]C;VYF
M:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<&AP9&XB(&1E
M<V,](E-E87)C:"!$3CHB/F-N/6YO8F]D>2P@8VX]:6YT97)N86PL"B`@("`@
M(&1C/65X86UP;&4L(&1C/6-O;3PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N
M9FEG<W1R:6YG(&YA;64](G!H<'!W(B!D97-C/2)396%R8V@*("`@("`@4&%S
M<W=O<F0Z(CYP87-S=V]R9#PO8V]N9FEG<W1R:6YG/@H@("`@(#PO8V]N9FEG
M<V5C=&EO;CX*("`@("`\8V]N9FEG:&5A9&5R/DMO;&%B($-Y<G5S($E-05`@
M4V5R=F5R(%-E='1I;F=S/"]C;VYF:6=H96%D97(^"B`@("`@/&-O;F9I9W-E
M8W1I;VX@;F%M93TB:6UA<"(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB
M<V5R=F5R(B!D97-C/2)397)V97(*("`@("`@861D<F5S<SHB/FUA:6PN97AA
M;7!L92YC;VT\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9VEN=&5G97(@
M;F%M93TB<&]R="(@9&5S8STB4V5R=F5R('!O<G0Z(CXQ-#,\+V-O;F9I9VEN
M=&5G97(^"B`@("`@(#QC;VYF:6=I;G1E9V5R(&YA;64](G-I979E<&]R="(@
M9&5S8STB4VEE=F4@<&]R=#HB/C(P,#`\+V-O;F9I9VEN=&5G97(^"B`@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB;6%I;&1O;6%I;B(@9&5S8STB1&5F875L
M=`H@("`@("!M86EL9&]M86EN.B(^97AA;7!L92YC;VT\+V-O;F9I9W-T<FEN
M9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)A9&UI;G5S97(B(&1E<V,]
M(D%D;6EN:7-T<F%T;W(*("`@("`@=7-E<CHB/FUA;F%G97(\+V-O;F9I9W-T
M<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)A9&UI;G!W(B!D97-C
M/2)!9&UI;FES=')A=&]R"B`@("`@('!A<W-W;W)D.B(^<&%S<W=O<F0\+V-O
M;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9V)O;VQE86X@;F%M93TB=FER=&1O
M;6%I;G,B(&1E<V,](E9I<G1U86P*("`@("`@9&]M86EN<SHB/G1R=64\+V-O
M;F9I9V)O;VQE86X^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`\8V]N9FEG
M8F]O;&5A;B!N86UE/2)G<F]U<&QD87`B(&1E<V,](DEF('1H:7,@:7,@8VAE
M8VME9"P@=&AE(&9U;F-T:6]N"B`@(%]H;W)D95]H;V]K7V=R;W5P;&1A<"@I
M('=I;&P@8F4@=7-E9"!T;R!C<F5A=&4@86YD('-E="!T:&4@871T<FEB=71E
M<R!N965D960*("`@=&\@861D+V5D:70O9&5L971E(&=R;W5P<R!B>2!T:&4@
M3$1!4"!'<F]U<"!D<FEV97(N(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*("`@
M("`\8V]N9FEG:&5A9&5R/DMO;&%B(%--5%`@4V5R=F5R(%-E='1I;F=S/"]C
M;VYF:6=H96%D97(^"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<VUT<"(^
M"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<V5R=F5R(B!D97-C/2)397)V
M97(*("`@("`@861D<F5S<SHB/FQO8V%L:&]S=#PO8V]N9FEG<W1R:6YG/@H@
M("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)P;W)T(B!D97-C/2)397)V97(@
M<&]R=#HB/C(U/"]C;VYF:6=I;G1E9V5R/@H@("`@(#PO8V]N9FEG<V5C=&EO
M;CX*("`@(#PO8V%S93X*("`@/"]C;VYF:6=S=VET8V@^"B`@/"]C;VYF:6=S
M96-T:6]N/@H@/"]C;VYF:6=T86(^"CPO8V]N9FEG=7)A=&EO;CX*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R
M9&4O:&]R9&4O:&]O:W,N<&AP````````````````````````````````````
M`````````````````````````````````````#`P,#`T-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,3(R,S(P`#$P-3$U-#,S-S<T`#`R,3,V-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@2&]R9&4@2&]O:W,@8V]N9FEG=7)A=&EO;B!F:6QE+@H@*@H@*B!42$4@
M2$]/2U,@4%)/5DE$140@24X@5$A)4R!&24Q%($%212!%6$%-4$Q%4R!/3DQ9
M+B`@1$\@3D]4($5.04),12!42$5-"B`J($),24Y$3%D@248@64]5($1/($Y/
M5"!+3D]7(%=(050@64]5($%212!$3TE.1RX@(%E/52!(059%(%1/($-54U1/
M34E:12!42$5-"B`J(%1/($U!5$-((%E/55(@4U!%0TE&24,@3D5%1%,@04Y$
M(%-94U1%32!%3E9)4D].345.5"X*("H*("H@5&AI<R!F:6QE(&ES('=H97)E
M('EO=2!D969I;F4@86YY(&AO;VMS+"!F;W(@<')E9F5R96YC97,@;W(@9V5N
M97)A;"!(;W)D90H@*B!U<V4L('1H870@>6]U<B!I;G-T86QL871I;VX@=7-E
M<RX@5&AE(&9U;F-T:6]N<R!I;B!T:&ES(&9I;&4@8V%N('9A<W1L>0H@*B!C
M:&%N9V4@:&]W('EO=7(@:6YS=&%L;&%T:6]N(&)E:&%V97,L('-O(&UA:V4@
M<W5R92!T;R!T97-T(&]U="!A;GD@8VAA;F=E<PH@*B!H97)E(&)E9F]R92!D
M;VEN9R!T:&5M(&EN(&$@<')O9'5C=&EO;B!E;G9I<F]N;65N="X*("H*("H@
M2&]O:R!F=6YC=&EO;B!N86UE<R!A<F4@875T;VUA=&EC86QL>2!D971E<FUI
M;F5D+B!4:&4@9F]R;6%T(&]F('1H92!N86UE"B`J(&ES.@H@*@H@*B!?/'1Y
M<&4@;V8@:&]O:SY?:&]O:U\\;F%M92!O9B!H;V]K/BX*("H*("H@5'EP97,@
M;V8@:&]O:W,@=&AA="!A<F4@9&5F:6YE9"!I;B!T:&ES(&9I;&4@87)E("=P
M<F5F<R<@*&AO;VMS('1O('-E="!T:&4*("H@=F%L=64@;V8@<')E9F5R96YC
M97,I+"`G:&]R9&4G("AH;V]K<R!F;W(@=&AE($AO<F1E($9R86UE=V]R:R!S
M8W)I<'1S*2!A;F0*("H@)V%P<"<@*'=H97)E(&%P<"!I<R!A;GD@2&]R9&4@
M87!P;&EC871I;VX@;F%M92P@;&EK92`G:6UP)RD@:&]O:W,@=&AA="!A<F4*
M("H@87!P;&EC871I;VX@<W!E8VEF:6,N"B`J"B`J(%-O+"!A(&AO;VL@=&\@
M<V5T('1H92!P<F5F97)E;F-E("=T:&5M92<@=V]U;&0@8F4@;F%M960*("H@
M(E]P<F5F<U]H;V]K7W1H96UE(BX*("H*("H@3D]412`Q.B!(879I;F<@82!H
M;V]K(&9U;F-T:6]N(&EN('1H:7,@9FEL92!D;V5S($Y/5"!M96%N('1H870@
M=&AE(&AO;VL*("H@=VEL;"!A=71O;6%T:6-A;&QY(&)E('5S960N(%E/52!-
M55-4(&5N86)L92!T:&4@:&]O:RX@1F]R('!R969E<F5N8V5S+"!S970*("H@
M)VAO;VLG(#T^('1R=64@:6X@=&AA="!P<F5F97)E;F-E<R!A='1R:6)U=&5S
M.R!F;W(@;W1H97(@:&]O:W,L('1H97)E('=I;&P*("H@8F4@82!C;VYF:6=U
M<F%T:6]N(&]P=&EO;B!I;B!E86-H(&%P<&QI8V%T:6]N)W,@8V]N9BYP:'`@
M9FEL92!S=6-H(&%S"B`J("1C;VYF6R=H;V]K<R==6R=H;V]K;F%M92==('=H
M:6-H(&UU<W0@8F4@<V5T('1O('1R=64N"B`J"B`J($Y/5$4@,CH@4')E9F5R
M96YC97,@:&]O:W,@87)E($].3%D@97AE8W5T960@;VX@;&]G:6XN(%!R969E
M<F5N8V5S(&%R90H@*B!C86-H960@9'5R:6YG(&$@=7-E<G,@<V5S<VEO;B!A
M;F0L('1O(&%V;VED('5N;F5C97-S87)Y(&]V97)H96%D(&5V97)Y('1I;64*
M("H@82!P<F5F97)E;F-E(&ES(&%C8V5S<V5D+"!T:&4@<F5S=6QT<R!O9B!H
M;V]K<R!A<F4@8V%C:&5D(&%S('=E;&PN(%1H:7,*("H@;&5A9',@=&\@+BXN
M"B`J"B`J($Y/5$4@,SH@06YY('!R969E<F5N8V4@=&AA="!I<R!.3U0@3$]#
M2T5$+"!T:&%T(&ES('-E="!B>2!A(&AO;VLL(%=)3$P@0D4*("H@4T%6140@
M5TE42"!42$%4(%9!3%5%+B!4:&ES(&UE86YS('-E=F5R86P@=&AI;F=S.@H@
M*B`Q*2!5<V5R<R!W:6QL(&=E="!T:&4@<F5S=6QT<R!O9B!T:&4@:&]O:R!S
M970@9F]R('1H96T@:6X@=&AE:7(*("H@("`@<')E9F5R96YC97,N"B`J(#(I
M($)Y('9I<G1U92!O9B!T:&ES+"!T:&4@;F5X="!T:6UE('1H97D@;&]G(&EN
M(&%N9"!L;V%D('1H96ER"B`J("`@('!R969E<F5N8V5S+"!T:&4@:&]O:R!W
M:6QL($Y/5"!B92!C86QL960L(&)E8V%U<V4@:6X@=&AE:7(@;&%S="!S97-S
M:6]N+`H@*B`@("!W92!S879E9"!T:&4@<F5S=6QT<R!O9B!T:&4@:&]O:R!F
M;W(@=&AE;2X@2&]W979E<BP@:68@=&AE('!R969E<F5N8V4@:7,*("H@("`@
M;&]C:V5D+"!T:&4@<F5S=6QT(&]F('1H92!H;V]K('=I;&P@;F5V97(@8F4@
M<V%V960N"B`J"B`J("1(;W)D93H@:&]R9&4O8V]N9FEG+VAO;VMS+G!H<"YD
M:7-T+'8@,2XW,RXV+C$S(#(P,#8O,#4O,C,@,#(Z,3,Z-#(@<V5L<VMY($5X
M<"`D"B`J+PH*+R\@17AA;7!L92!T:&5M92!H;V]K(&9U;F-T:6]N+B!4:&ES
M('-H;W=S(&AO=R!Y;W4@8V%N(&%C8V5S<R!T:&EN9W,@;&EK92!T:&4*+R\@
M8W5R<F5N=&QY(&QO9V=E9"!I;B!U<V5R+"!G;&]B86P@=F%R:6%B;&5S+"!S
M97)V97(@8V]N9FEG+"!E=&,N($ET(&ES;B=T+`HO+R!H;W=E=F5R+"!S;VUE
M=&AI;F<@>6]U('!R;V)A8FQY('=A;G0@=&\@86-T=6%L;'D@=7-E(&EN('!R
M;V1U8W1I;VXL(&)Y"B\O('9I<G1U92!O9B!D96UO;G-T<F%T:6YG(&%L;"!T
M:&]S92X@.BD*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?<')E9G-?:&]O
M:U]T:&5M92<I*2!["B\O("`@("!F=6YC=&EO;B!?<')E9G-?:&]O:U]T:&5M
M92@D=7-E<FYA;64@/2!N=6QL*0HO+R`@("`@>PHO+R`@("`@("`@(&EF("A!
M=71H.CIG971!=71H*"D@(3T@)V-H=6-K)RD@>PHO+R`@("`@("`@("`@("!R
M971U<FX@)VUO>FEL;&$G.PHO+R`@("`@("`@('T*+R\*+R\@("`@("`@("!G
M;&]B86P@)')E9VES=')Y.PHO+R`@("`@("`@('-W:71C:"`H)')E9VES=')Y
M+3YG971!<'`H*2D@>PHO+R`@("`@("`@(&-A<V4@)VEM<"<Z"B\O("`@("`@
M("`@("`@(')E='5R;B`G8G)O=VXG.PHO+PHO+R`@("`@("`@(&-A<V4@)W1U
M<F)A)SH*+R\@("`@("`@("`@("`@<F5T=7)N("=O<F%N9V4G.PHO+PHO+R`@
M("`@("`@(&-A<V4@)VMR;VYO;&ET:"<Z"B\O("`@("`@("`@("`@(')E='5R
M;B`G9W)E96XG.PHO+PHO+R`@("`@("`@(&1E9F%U;'0Z"B\O("`@("`@("`@
M("`@(')E='5R;B`G)SL*+R\@("`@("`@("!]"B\O("`@("!]"B\O('T*"B\O
M($5X86UP;&4@9G)O;5]A9&1R(&AO;VL@9G5N8W1I;VXN(%1(25,@1E5.0U1)
M3TX@05-354U%4R!42$%4(%E/52!!4D4@55-)3D<*+R\@04X@3$1!4"!315)6
M15(@86YD('1H870@>6]U<B`O971C+VQD87`N8V]N9B!O<B!W:&5R979E<B!I
M="!I<R!C;W)R96-T;'D@<V5T"B\O('1O(&$@=F%L:60@:&]S="X*+R\*+R\@
M66]U(&=E="!P87-S960@3D]42$E.1SL@>6]U(&%R92!R97-P;VYS:6)L92!F
M;W(@8G)I;F=I;F<@:6X@=&\@<V-O<&4@86YY"B\O(&EN9F]R;6%T:6]N('EO
M=2!N965D+B!9;W4@8V%N(")G;&]B86PB(&%N>71H:6YG(&5L<V4@>6]U(&YE
M960N(%)E='5R;B!A;@HO+R!A9&1R97-S("T@96ET:&5R(&IU<W0@=&AE('5S
M97)`('-I9&4@;W(@82!F=6QL(&%D9')E<W,@+2!A;F0@:70@=VEL;"!B90HO
M+R!U<V5D+@HO+PHO+R!)9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!C;V1E('EO
M=2!W:6QL(&YE960@=&\@=6YC;VUM96YT(&ET(&)E;&]W+@H*+R\@:68@*"%F
M=6YC=&EO;E]E>&ES=',H)U]P<F5F<U]H;V]K7V9R;VU?861D<B<I*2!["B\O
M("`@("!F=6YC=&EO;B!?<')E9G-?:&]O:U]F<F]M7V%D9'(H)&YA;64@/2!N
M=6QL*0HO+R`@("`@>PHO+R`@("`@("`@(&EF("AI<U]N=6QL*"1N86UE*2D@
M>PHO+R`@("`@("`@("`@("`D;F%M92`]($%U=&@Z.F=E=$%U=&@H*3L*+R\@
M("`@("`@("!]"B\O("`@("`@("`@:68@*"%E;7!T>2@D;F%M92DI('L*+R\@
M("`@("`@("`@("`@)&)A<V5?8V]N=&5X="`]("=O/6UY;W)G)SL*+R\@("`@
M("`@("`@("`@)'-C;W!E(#T@)W-U8B<["B\O"B\O("`@("`@("`@("`@("\O
M(%EO=2!W:6QL('!R;V)A8FQY(&YE960@=&\@<F5P;&%C92!C9#T@=VET:"!U
M:60].R!T:&ES"B\O("`@("`@("`@("`@("\O('-Y;G1A>"!I<R!F;W(@3F5T
M=V%R92`U+C$@;FQD87`N"B\O("`@("`@("`@("`@("1C;60@(#T@)R]U<W(O
M8FEN+VQD87!S96%R8V@@+6(@)R`N("1B87-E7V-O;G1E>'0@+B`G("US("<@
M+B`D<V-O<&4@+B`G(&-N/2<["B\O("`@("`@("`@("`@("1C;60@+CT@97-C
M87!E4VAE;&Q#;60H075T:#HZ9V5T075T:"@I*3L*+R\@("`@("`@("`@("`@
M)&-M9"`N/2`G('P@+W5S<B]B:6XO9W)E<"!M86EL('P@+W5S<B]B:6XO87=K
M(%PG>W!R:6YT("0R?5PG)SL*+R\@("`@("`@("`@("`@)&UA:6QS(#T@8"1C
M;61@.PHO+R`@("`@("`@("`@("`D;6%I;%]A<G)A>2`](&5X<&QO9&4H(EQN
M(BP@)&UA:6QS*3L*+R\*+R\@("`@("`@("`@("`@+R\@4V5N9"!B86-K('1H
M92!F:7)S="!E;6%I;"!F;W5N9"P@;F]T('1H92!W:&]L92!L:7-T+@HO+R`@
M("`@("`@("`@("`D;6%I;"`]("1M86EL7V%R<F%Y6R<P)UT["B\O"B\O("`@
M("`@("`@("`@("\O($EF(&YO(&5M86EL(&%D9')E<W,@:7,@9F]U;F0L('1H
M96X@=&AE(&QO9VEN(&YA;64@=VEL;`HO+R`@("`@("`@("`@("`O+R!B92!U
M<V5D+@HO+R`@("`@("`@("`@("!R971U<FX@*&5M<'1Y*"1M86EL*2`_("<G
M(#H@)&UA:6PI.PHO+R`@("`@("`@('T*+R\*+R\@("`@("`@("!R971U<FX@
M)R<["B\O("`@("!]"B\O('T*"B\O($AE<F4@:7,@86YO=&AE<B!W87D@;V8@
M9&]I;F<@=&AE('-A;64@=&AI;F<N"@HO+R!I9B`H(69U;F-T:6]N7V5X:7-T
M<R@G7W!R969S7VAO;VM?9G)O;5]A9&1R)RDI('L*+R\@("`@(&9U;F-T:6]N
M(%]P<F5F<U]H;V]K7V9R;VU?861D<B@D=7-E<B`](&YU;&PI"B\O("`@("![
M"B\O("`@("`@("`@)&QD87!397)V97(@/2`G,3<R+C,Q+C`N,C,V)SL*+R\@
M("`@("`@("`D;&1A<%!O<G0@/2`G,S@Y)SL*+R\@("`@("`@("`D<V5A<F-H
M0F%S92`]("=O/6UY;W)G)SL*+R\*+R\@("`@("`@("`D9',@/2!`;&1A<%]C
M;VYN96-T*"1L9&%P4V5R=F5R+"`D;&1A<%!O<G0I.PHO+PHO+R`@("`@("`@
M(&EF("AI<U]N=6QL*"1U<V5R*2D@>PHO+R`@("`@("`@("`@("`D=7-E<B`]
M($%U=&@Z.F=E=$%U=&@H*3L*+R\@("`@("`@("!]"B\O"B\O("`@("`@("`@
M+R\@66]U('=I;&P@<')O8F%B;'D@;F5E9"!T;R!R97!L86-E(&-N/2!W:71H
M('5I9#T[('1H:7,*+R\@("`@("`@("`O+R!S>6YT87@@:7,@9F]R($YE='=A
M<F4@-2XQ(&YL9&%P+@HO+R`@("`@("`@("1S96%R8VA297-U;'0@/2!`;&1A
M<%]S96%R8V@H)&1S+"`D<V5A<F-H0F%S92P@)V-N/2<@+B`D=7-E<BD["B\O
M("`@("`@("`@)&EN9F]R;6%T:6]N(#T@0&QD87!?9V5T7V5N=')I97,H)&1S
M+"`D<V5A<F-H4F5S=6QT*3L*+R\@("`@("`@("!I9B`H)&EN9F]R;6%T:6]N
M6S!=6R=M86EL)UU;,%T@(3T@)R<I('L*+R\@("`@("`@("`@("`@)&YA;64@
M/2`D:6YF;W)M871I;VY;,%U;)VUA:6PG75LP73L*+R\@("`@("`@("!](&5L
M<V4@>PHO+R`@("`@("`@("`@("`D;F%M92`]("1I;F9O<FUA=&EO;ELP75LG
M8VXG75LP73L*+R\@("`@("`@("!]"B\O"B\O("`@("`@("`@;&1A<%]C;&]S
M92@D9',I.PHO+PHO+R`@("`@("`@(')E='5R;B`H96UP='DH)&YA;64I(#\@
M)'5S97(@.B`D;F%M92D["B\O("`@("!]"B\O('T*"B\O($AE<F4@:7,@86X@
M97AA;7!L92!F=6QL;F%M92!H;V]K(&9U;F-T:6]N('1O('-E="!T:&4@9G5L
M;&YA;64@9G)O;2!T:&4@1T5#3U,*+R\@:6YF;W)M871I;VX@:6X@=&AE('!A
M<W-W9"!F:6QE+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]P<F5F<U]H
M;V]K7V9U;&QN86UE)RDI('L*+R\@("`@(&9U;F-T:6]N(%]P<F5F<U]H;V]K
M7V9U;&QN86UE*"1U<V5R(#T@;G5L;"D*+R\@("`@('L*+R\@("`@("`@("!I
M9B`H:7-?;G5L;"@D=7-E<BDI('L*+R\@("`@("`@("`@("`@)'5S97(@/2!!
M=71H.CIG971"87)E075T:"@I.PHO+R`@("`@("`@('T*+R\@("`@("`@("`D
M87)R87D@/2!P;W-I>%]G971P=VYA;2@D=7-E<BD["B\O("`@("`@("`@)&=E
M8V]S7V%R<F%Y(#T@97AP;&]D92@G+"<L("1A<G)A>5LG9V5C;W,G72D["B\O
M("`@("`@("`@<F5T=7)N("AE;7!T>2@D9V5C;W-?87)R87DI(#\@)'5S97(@
M.B`D9V5C;W-?87)R87E;,%TI.PHO+R`@("`@?0HO+R!]"@HO+R!4:&ES(&ES
M(&%N;W1H97(@97AA;7!L92!O9B!H;W<@=&\@9V5T('1H92!U<V5R)W,@9G5L
M;"!N86UE+"!I;B!T:&ES(&-A<V4*+R\@9G)O;2!A;B!L9&%P('-E<G9E<BX@
M26X@=&AI<R!E>&%M<&QE('=E(&QO;VL@:68@82!3<&%N:7-H(&YA;64@97AI
M<W1S(&%N9`HO+R!R971U<FX@=&AI<R!O<B!T:&4@<W1A;F1A<F0@)V-N)R!E
M;G1R>2!I9B!N;W0N"@HO+R!I9B`H(69U;F-T:6]N7V5X:7-T<R@G7W!R969S
M7VAO;VM?9G5L;&YA;64G*2D@>PHO+R`@("`@9G5N8W1I;VX@7W!R969S7VAO
M;VM?9G5L;&YA;64H)'5S97(@/2!N=6QL*0HO+R`@("`@>PHO+R`@("`@("`@
M("1L9&%P4V5R=F5R(#T@)VQD87`N97AA;7!L92YC;VTG.PHO+R`@("`@("`@
M("1L9&%P4&]R="`]("<S.#DG.PHO+R`@("`@("`@("1S96%R8VA"87-E(#T@
M)V]U/7!E;W!L92QO/65X86UP;&4N8V]M)SL*+R\@("`@("`@("`D;&1A<&-H
M87)S970@/2`G=71F+3@G.PHO+R`@("`@("`@("1O=71P=71C:&%R<V5T(#T@
M3DQ3.CIG971#:&%R<V5T*"D["B\O"B\O("`@("`@("`@)&1S(#T@0&QD87!?
M8V]N;F5C="@D;&1A<%-E<G9E<BP@)&QD87!0;W)T*3L*+R\*+R\@("`@("`@
M("!I9B`H:7-?;G5L;"@D=7-E<BDI('L*+R\@("`@("`@("`@("`@)'5S97(@
M/2!!=71H.CIG971!=71H*"D["B\O("`@("`@("`@?0HO+R`@("`@("`@("1S
M96%R8VA297-U;'0@/2!`;&1A<%]S96%R8V@H)&1S+"`D<V5A<F-H0F%S92P@
M)W5I9#TG("X@)'5S97(I.PHO+R`@("`@("`@("1I;F9O<FUA=&EO;B`]($!L
M9&%P7V=E=%]E;G1R:65S*"1D<RP@)'-E87)C:%)E<W5L="D["B\O("`@("`@
M("`@:68@*"1I;F9O<FUA=&EO;ELP75LG8VX[;&%N9RUE<R==6S!=("$]("<G
M*2!["B\O("`@("`@("`@("`@("1N86UE(#T@)&EN9F]R;6%T:6]N6S!=6R=C
M;CML86YG+65S)UU;,%T["B\O("`@("`@("`@?2!E;'-E('L*+R\@("`@("`@
M("`@("`@)&YA;64@/2`D:6YF;W)M871I;VY;,%U;)V-N)UU;,%T["B\O("`@
M("`@("`@?0HO+PHO+R`@("`@("`@(&QD87!?8VQO<V4H)&1S*3L*+R\*+R\@
M("`@("`@("`D;F%M92`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&YA;64L
M("1L9&%P8VAA<G-E="P@)&]U='!U=&-H87)S970I.PHO+R`@("`@("`@(')E
M='5R;B`H96UP='DH)&YA;64I(#\@)'5S97(@.B`D;F%M92D["B\O("`@("!]
M"B\O('T*"B\O($AE<F4@:7,@86X@97AA;7!L92!S:6=N871U<F4@:&]O:R!F
M=6YC=&EO;B!T;R!S970@=&AE('-I9VYA='5R92!F<F]M('1H90HO+R!S>7-T
M96T@=&%G;&EN97,@9FEL93L@=&AE('-T<FEN9R`B)51!1R4B("AI9B!P<F5S
M96YT(&EN(&$@=7-E<B=S('-I9VYA='5R92D*+R\@=VEL;"!B92!R97!L86-E
M9"!B>2!T:&4@8V]N=&5N="!O9B!T:&4@9FEL92`B+W5S<B]S:&%R92]T86=L
M:6YE(B`H9V5N97)A=&5D"B\O(&)Y('1H92`B5&%25"(@=71I;&ET>2DN"B\O
M"B\O($YO=&EC92!H;W<@=V4@9VQO8F%L(&EN('1H92`D<')E9G,@87)R87D@
M=&\@9V5T('1H92!U<V5R)W,@8W5R<F5N=`HO+R!S:6=N871U<F4N"@HO+R!I
M9B`H(69U;F-T:6]N7V5X:7-T<R@G7W!R969S7VAO;VM?<VEG;F%T=7)E)RDI
M('L*+R\@("`@(&9U;F-T:6]N(%]P<F5F<U]H;V]K7W-I9VYA='5R92@D=7-E
M<FYA;64@/2!N=6QL*0HO+R`@("`@>PHO+R`@("`@("`@("1S:6<@/2`D1TQ/
M0D%,4ULG<')E9G,G72T^9V5T5F%L=64H)W-I9VYA='5R92<I.PHO+R`@("`@
M("`@(&EF("AP<F5G7VUA=&-H*"<O)51!1R4O)RP@)'-I9RDI('L*+R\@("`@
M("`@("`@("`@)'1A9R`](&!C870@+W5S<B]S:&%R92]T86=L:6YE8#L*+R\@
M("`@("`@("`@("`@)'-I9R`]('!R96=?<F5P;&%C92@G?"5404<E?"<L("1T
M86<L("1S:6<I.PHO+R`@("`@("`@('T*+R\@("`@("`@("!R971U<FX@)'-I
M9SL*+R\@("`@('T*+R\@?0H*+R\@244@;VX@36%C(&AA;F=S('=H96X@=&AE
M<F4@87)E('-E=F5R86P@:6-O;G,@=&\@8F4@;&]A9&5D+B!!="!L96%S="!O
M;B!S;VUE"B\O('-Y<W1E;7,N(%1H:7,@:&]O:R!D:7-A8FQE<R!T:&4@<VAO
M=U]I8V]N<R!P<F5F97)E;F-E(&9R;VT@2W)O;F]N;&ET:"!F;W(*+R\@=&AE
M<V4@8G)O=W-E<G,N"@HO+R!I9B`H(69U;F-T:6]N7V5X:7-T<R@G7W!R969S
M7VAO;VM?<VAO=U]I8V]N<R<I*2!["B\O("`@("!F=6YC=&EO;B!?<')E9G-?
M:&]O:U]S:&]W7VEC;VYS*"D*+R\@("`@('L*+R\@("`@("`@("!G;&]B86P@
M)&)R;W=S97(["B\O("`@("`@("`@:68@*"1B<F]W<V5R+3YG9710;&%T9F]R
M;2@I(#T]("=M86,G("8F"B\O("`@("`@("`@("`@("1B<F]W<V5R+3YG971"
M<F]W<V5R*"D@/3T@)VUS:64G*2!["B\O("`@("`@("`@("`@(')E='5R;B!F
M86QS93L*+R\@("`@("`@("!](&5L<V4@>PHO+R`@("`@("`@("`@("!R971U
M<FX@=')U93L*+R\@("`@("`@("!]"B\O("`@("!]"B\O('T*"B\O(%1H:7,@
M:&]O:R!I<R!C86QL960@=VAE;B!A('5S97(@<W5B;6ET<R!A('-I9VYU<"!R
M97%U97-T+B`@270@86QL;W=S"B\O(&$@8VAA;F-E('1O(&%L=&5R(&]R('9A
M;&ED871E('1H92!D871A('-U8FUI='1E9"!B>2!A('5S97(@8F5F;W)E(&%N
M>0HO+R!A='1E;7!T<R!A<F4@;6%D92!T;R!A9&0@=&AE;2!T;R!T:&4@<WES
M=&5M+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]H;W)D95]H;V]K7W-I
M9VYU<%]P<F5P<F]C97-S)RDI('L*+R\@("`@(&9U;F-T:6]N(%]H;W)D95]H
M;V]K7W-I9VYU<%]P<F5P<F]C97-S*"1I;F9O*2!["B\O("`@("`@("`@)&EN
M9F];)W5S97)?;F%M92==(#T@4W1R:6YG.CIL;W=E<B@D:6YF;ULG=7-E<E]N
M86UE)UTI.PHO+R`@("`@("`@(')E='5R;B`D:6YF;SL*+R\@("`@('T*+R\@
M?0H*+R\@5&AI<R!H;V]K(&ES(&-A;&QE9"!W:&5N(&$@<VEG;G5P(&ES('%U
M975E9"!F;W(@861M:6YI<W1R871I=F4@87!P<F]V86PN"B\O(%1H:7,@97AA
M;7!L92!S96YD<R!A(&YO=&EF:6-A=&EO;B!M97-S86=E('1O('1H92!W96(@
M<V5R=F5R"B\O(&%D;6EN:7-T<F%T;W(G<R!E+6UA:6P@861D<F5S<RX*"B\O
M(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?:&]O:U]S:6=N=7!?<75E
M=65D)RDI('L*+R\@("`@(&9U;F-T:6]N(%]H;W)D95]H;V]K7W-I9VYU<%]Q
M=65U961?=V%L:V1A=&$H)&9I96QD<RP@)&1A=&$I"B\O("`@("!["B\O("`@
M("`@("`@)&US9R`]("<G.PHO+R`@("`@("`@(&9O<F5A8V@@*"1D871A(&%S
M("1F:65L9"`]/B`D=F%L=64I('L*+R\@("`@("`@("`@("`@:68@*"1F:65L
M9"`]/2`G<&%S<W=O<F0G('Q\("1F:65L9"`]/2`G=7)L)RD@>PHO+R`@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B\O("`@("`@("`@("`@('T*+R\*+R\@
M("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1V86QU92DI('L*+R\@("`@("`@
M("`@("`@("`@("1M<V<@+CT@7VAO<F1E7VAO;VM?<VEG;G5P7W%U975E9%]W
M86QK9&%T82@D9FEE;&1S+"`D=F%L=64I.PHO+R`@("`@("`@("`@("!](&5L
M<V4@>PHO+R`@("`@("`@("`@("`@("`@)&9I96QD(#T@:7-S970H)&9I96QD
M<ULD9FEE;&1=6R=L86)E;"==*2`_"B\O("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9FEE;&1S6R1F:65L9%U;)VQA8F5L)UT@.B`D9FEE;&0["B\O("`@
M("`@("`@("`@("`@("`D;7-G("X]("(D9FEE;&0Z("1V86QU95QN(CL*+R\@
M("`@("`@("`@("`@?0HO+R`@("`@("`@('T*+R\@("`@("`@("!R971U<FX@
M)&US9SL*+R\@("`@('T*+R\*+R\@("`@(&9U;F-T:6]N(%]H;W)D95]H;V]K
M7W-I9VYU<%]Q=65U960H)'5S97))1"P@)&1A=&$I"B\O("`@("!["B\O("`@
M("`@("`@<F5Q=6ER95]O;F-E("=-86EL+G!H<"<["B\O("`@("`@("`@9VQO
M8F%L("1C;VYF+"`D<F5G:7-T<GD["B\O"B\O("`@("`@("`@)&AE861E<G,@
M/2!A<G)A>2@*+R\@("`@("`@("`@("`@)U1O)R`@("`@(#T^("1?4T525D52
M6R=315)615)?041-24XG72P*+R\@("`@("`@("`@("`@)T9R;VTG("`@(#T^
M("1?4T525D526R=315)615)?041-24XG72P*+R\@("`@("`@("`@("`@)U-U
M8FIE8W0G(#T^("=.97<@)R`N("1R96=I<W1R>2T^9V5T*"=N86UE)RP@)VAO
M<F1E)RD@+B`G(%-I9VYU<"<*+R\@("`@("`@("`I.PHO+PHO+R`@("`@("`@
M("1E>'1R849I96QD<R`]($AO<F1E.CIC86QL2&]O:R@G7VAO<F1E7VAO;VM?
M<VEG;G5P7V=E=&5X=')A)RD["B\O"B\O("`@("`@("`@)&US9R`@/2!?*")!
M(&YE=R!S:6=N=7`@:&%S(&)E96X@<F5C96EV960@86YD(&ES(&%W86ET:6YG
M('EO=7(@87!P<F]V86PN(BD["B\O("`@("`@("`@)&US9R`N/2`B7&Y<;B([
M"B\O("`@("`@("`@)&US9R`N/2!?:&]R9&5?:&]O:U]S:6=N=7!?<75E=65D
M7W=A;&MD871A*"1E>'1R849I96QD<RP@)&1A=&$I.PHO+R`@("`@("`@("1M
M<V<@+CT@(EQN(CL*+R\@("`@("`@("`D;7-G("X]('-P<FEN=&8H7R@B66]U
M(&-A;B!A<'!R;W9E('1H:7,@<VEG;G5P(&%T("5S(BDL($AO<F1E.CIA<'!L
M:6-A=&EO;E5R;"@G861M:6XO=7-E<BYP:'`G+"!T<G5E+"`M,2DI.PHO+PHO
M+R`@("`@("`@("1M86EL97(@/2!-86EL.CIF86-T;W)Y*"1C;VYF6R=M86EL
M97(G75LG='EP92==+"`D8V]N9ELG;6%I;&5R)UU;)W!A<F%M<R==*3L*+R\@
M("`@("`@("!R971U<FX@)&UA:6QE<BT^<V5N9"@D7U-%4E9%4ELG4T525D52
M7T%$34E.)UTL("1H96%D97)S+"`D;7-G*3L*+R\@("`@('T*+R\@?0H*+R\@
M2&5R92!I<R!A;B!E>&%M<&QE(%]H;W)D95]H;V]K7W-I9VYU<%]G971E>'1R
M82!F=6YC=&EO;BX@270@<F5T=7)N<R!A;GD*+R\@97AT<F$@9FEE;&1S('=H
M:6-H(&YE960@=&\@8F4@9FEL;&5D(&EN('=H96X@82!N;VX@<F5G:7-T97)E
M9"!U<V5R('=I<VAE<PHO+R!T;R!S:6=N('5P+@HO+R!4:&4@97AA;7!L92!H
M97)E('1A:V5S('1H92!H>7!O=&AE=&EC86P@8V%S92!W:&5R92!W92!W;W5L
M9"!W86YT('1O('-T;W)E"B\O(&5X=')A(&EN9F]R;6%T:6]N(&%B;W5T(&$@
M=7-E<B!I;G1O(&$@='5R8F$@<W%L(&%D9')E<W,@8F]O:RX@06QL('1H:7,*
M+R\@9G5N8W1I;VX@9&]E<R!T:&5N(&ES('1O(&EN8VQU9&4@=&AE(&%T=')I
M8G5T97,N<&AP(&9I;&4@9G)O;2!T:&4@='5R8F$*+R\@8V]N9FEG(&1I<F5C
M=&]R>2!A;F0@<F5T=7)N('1H92`D871T<FEB=71E<R!A<G)A>2X*+R\@3W1H
M97)W:7-E(&%N>2!S=')U8W1U<F4@=&AA="!W;W5L9"!R971U<FX@86X@87)R
M87D@=VET:"!T:&4@9F]L;&]W:6YG"B\O('-Y;G1A>"!W;W5L9"!B92!V86QI
M9#H*+R\@("`D<V]M96%R<F%Y6R=S;VUE9FEE;&1N86UE)UT@/2!A<G)A>2@N
M+BX*+R\@("`@("!L86)E;"`@("`M('1H92!T97AT('1H870@=&AE('5S97(@
M=VEL;"!S964@871T86-H960@=&\@=&AI<R!F:65L9`HO+R`@("`@('1Y<&4@
M("`@("T@86YY(&%L;&]W960@2&]R9&5?1F]R;2!F:65L9"!T>7!E"B\O("`@
M("`@<&%R86US("`@+2!A;GD@86QL;W=E9"!P87)A;65T97(@=&\@2&]R9&5?
M1F]R;2!F:65L9"!T>7!E<PHO+R`@("`@(')E<75I<F5D("T@8F]O;&5A;BP@
M=')U92!O<B!F86QS92!W:&5T:&5R('1H:7,@9FEE;&0@:7,@;6%N9&%T;W)Y
M"B\O("`@("`@<F5A9&]N;'D@+2!B;V]L96%N+"!T<G5E(&]R(&9A;'-E('=H
M971H97(@=&AI<R!E9&ET86)L90HO+R`@("`@(&1E<V,@("`@("T@86YY(&AE
M;'`@=&5X="!A='1A8VAE9"!T;R!T:&4@9FEE;&0*+R\@3D]413H@66]U($1/
M($Y%140@5'5R8F$@=&\@8F4@8V]R<F5C=&QY(&EN<W1A;&QE9"!B969O<F4@
M>6]U(&-A;B!U<V4@=&AI<PHO+R!E>&%M<&QE(&)E;&]W+@H*+R\@:68@*"%F
M=6YC=&EO;E]E>&ES=',H)U]H;W)D95]H;V]K7W-I9VYU<%]G971E>'1R82<I
M*2!["B\O("`@("!F=6YC=&EO;B!?:&]R9&5?:&]O:U]S:6=N=7!?9V5T97AT
M<F$H*0HO+R`@("`@>PHO+R`@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["B\O
M("`@("`@("`@<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G+"`G
M='5R8F$G*2`N("<O8V]N9FEG+V%T=')I8G5T97,N<&AP)SL*+R\@("`@("`@
M("!R971U<FX@)&%T=')I8G5T97,["B\O("`@("!]"B\O('T*"B\O($9O;&QO
M=VEN9R!O;B!F<F]M('1H92!E>&%M<&QE(&EN('1H92!A8F]V92!F=6YC=&EO
M;BP@=&AI<R!I<R!H;W<@82!S86UP;&4*+R\@7VAO<F1E7VAO;VM?<VEG;G5P
M7V%D9&5X=')A(&9U;F-T:6]N('=O=6QD(&QO;VL@;&EK92X*+R\@2&5R92!W
M92!C;VYN96-T('1O('1H92!D871A8F%S92!U<VEN9R!T:&4@<W%L('!A<F%M
M971E<G,@8V]N9FEG=7)E9"!I;@HO+R`D8V]N9B!A;F0@<W1O<F4@=&AE(&5X
M=')A(&9I96QD<R!I;B!T=7)B85]O8FIE8W1S+"!U<VEN9R!T:&4@)'5S97))
M9"!A<R!T:&4*+R\@:V5Y(&9O<B!T:&4@;V)J96-T(&%N9"!V86QU97,@9G)O
M;2!T:&4@)&5X=')A(&%R<F%Y+@HO+R!9;W4@8V]U;&0@8W)E871E('EO=7(@
M;W=N('-Q;"!S>6YT87@@;W(@8V]D92!T;R!S=&]R92!T:&ES(&EN('=H:6-H
M979E<@HO+R!B86-K96YD('EO=2!R97%U:7)E+@HO+R!.3U1%.B!9;W4@1$\@
M3D5%1"!4=7)B82!T;R!B92!C;W)R96-T;'D@:6YS=&%L;&5D(&)E9F]R92!Y
M;W4@8V%N('5S92!T:&ES"B\O(&5X86UP;&4@8F5L;W<N($ET(&%L<V\@87-S
M=6UE<R!T:&%T('EO=2!A<F4@=7-I;F<@86X@4U%,(&)A8VME;F0N"@HO+R!I
M9B`H(69U;F-T:6]N7V5X:7-T<R@G7VAO<F1E7VAO;VM?<VEG;G5P7V%D9&5X
M=')A)RDI('L*+R\@("`@(&9U;F-T:6]N(%]H;W)D95]H;V]K7W-I9VYU<%]A
M9&1E>'1R82@D=7-E<DE$+"`D97AT<F$I"B\O("`@("!["B\O("`@("`@("`@
M9VQO8F%L("1C;VYF.PHO+PHO+R`@("`@("`@(')E<75I<F5?;VYC92`G1$(N
M<&AP)SL*+R\@("`@("`@("`D7V1B(#T@)D1".CIC;VYN96-T*"1C;VYF6R=S
M<6PG72P@=')U92D["B\O"B\O("`@("`@("`@)&9I96QD<R`](&%R<F%Y*"D[
M"B\O("`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"D["B\O("`@("`@("`@9F]R
M96%C:"`H)&5X=')A(&%S("1F:65L9"`]/B`D=F%L=64I('L*+R\@("`@("`@
M("`@("`@)&9I96QD<UM=(#T@)V]B:F5C=%\G("X@4W1R:6YG.CIL;W=E<B@D
M9FEE;&0I.PHO+R`@("`@("`@("`@("`D=F%L=65S6UT@/2`D7V1B+3YQ=6]T
M92A3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1V86QU92P@3DQ3.CIG971#:&%R
M<V5T*"DL("1C;VYF6R=S<6PG75LG8VAA<G-E="==*2D["B\O("`@("`@("`@
M?0HO+R`@("`@("`@("1F:65L9'-;72`]("=O8FIE8W1?:60G.PHO+R`@("`@
M("`@("1V86QU97-;72`]("1?9&(M/G%U;W1E*"1U<V5R240I.PHO+PHO+R`@
M("`@("`@("1Q=65R>2`@/2`G24Y315)4($E.5$\@='5R8F%?;V)J96-T<R`H
M(&]W;F5R7VED+"`G("X@:6UP;&]D92@G+"`G+"`D9FEE;&1S*2`N("<I)SL*
M+R\@("`@("`@("`D<75E<GD@+CT@)R!604Q515,@*"!<)V%D;6EN7"<L("<@
M+B!I;7!L;V1E*"<L("<L("1V86QU97,I("X@)RDG.PHO+R`@("`@("`@("1R
M97-U;'0@/2`D7V1B+3YQ=65R>2@D<75E<GDI.PHO+PHO+R`@("`@("`@(')E
M='5R;B!I<U]A*"1R97-U;'0L("=014%27T5R<F]R)RD@/R`D<F5S=6QT(#H@
M=')U93L*+R\@("`@('T*+R\@?0H*+R\@2&5R92!I<R!A;B!E>&%M<&QE(%]H
M;W)D95]H;V]K7W!R96%U=&AE;G1I8V%T92!T:&%T(&UA:V4@2&]R9&4@<F5S
M<&5C="!T:&4*+R\@56YI>"!C;VYV96YT:6]N(&]F(&YO="!A;&QO=VEN9R!L
M;V=I;B!W:&5N(&$@9FEL92!N86UE9"`O971C+VYO;&]G:6X@97AI<W0N"B\O
M(%1H:7,@9G5N8W1I;VX@9V5T('!A<W-E9"!T:&4@=7-E<FYA;64L(&-R961E
M;G1I86P@86YD(')E86QM(&EN9F]R;6%T:6]N(&)U=`HO+R!T:&5Y(&%R92!N
M;W0@=7-E9"!I;B!T:&ES(&5X86UP;&4N"@HO+R!I9B`H(69U;F-T:6]N7V5X
M:7-T<R@G7VAO<F1E7VAO;VM?<')E875T:&5N=&EC871E)RDI('L*+R\@("`@
M(&9U;F-T:6]N(%]H;W)D95]H;V]K7W!R96%U=&AE;G1I8V%T92@D=7-E<DE$
M+"`D8W)E9&5N=&EA;"P@)')E86QM*0HO+R`@("`@>PHO+R`@("`@("`@(')E
M='5R;B`A9FEL95]E>&ES=',H)R]E=&,O;F]L;V=I;B<I.PHO+R`@("`@?0HO
M+R!]"@HO+R!(97)E(&ES(&%N(&5X86UP;&4@;V8@=F%L:61A=&EN9R!T:&4@
M=7-E<B=S(')I9VAT('1O(&QO9VEN('1O($AO<F1E(&)Y"B\O(&-O;G-U;'1I
M;F<@9W)O=7`@;65M8F5R<VAI<"!I;B!A;B!,1$%0(&1I<F5C=&]R>2X@(%1H
M870@=V%Y+"!I9B!Y;W5R($AO<F1E"B\O(&EN<W1A;&QA=&EO;B!I<R!C;VYF
M:6=U<F5D('1O(&%U=&AE;G1I8V%T92!A9V%I;G-T($E-4"!W:&EC:"!I;B!T
M=7)N"B\O(&%U=&AE;G1I8V%T92!V:6$@24U!4"P@:70@:7,@<W1I;&P@<&]S
M<VEB;&4@=&\@;&EM:70@86-C97-S('1O($AO<F1E(&)Y"B\O(&=R;W5P(&UE
M;6)E<G-H:7`N("!4:&4@9F]L;&]W:6YG(&5X86UP;&4@:&%D(&)E96X@;6%D
M92!W:71H(&%N($U3($%C=&EV90HO+R!$:7)E8W1O<GD@:6X@;6EN9"X@($YO
M=&4@=&AA="!I9B!T:&4@3$1!4"!D:7)E8W1O<GD@:7,@=6YA=F%I;&%B;&4@
M;W(@<V]M90HO+R!O=&AE<B!E<G)O<B!O8V-U<BP@875T:&5N=&EC871I;VX@
M=VEL;"!F86EL+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]H;W)D95]H
M;V]K7W!O<W1A=71H96YT:6-A=&4G*2D@>PHO+R`@("`@9G5N8W1I;VX@7VAO
M<F1E7VAO;VM?<&]S=&%U=&AE;G1I8V%T92@D=7-E<DE$+"`D8W)E9&5N=&EA
M;"P@)')E86QM*0HO+R`@("`@>PHO+R`@("`@("`@("1L9&%P4V5R=F5R(#T@
M)V%D+F5X86UP;&4N8V]M)SL*+R\@("`@("`@("`D;&1A<%!O<G0@/2`G,S@Y
M)SL*+R\@("`@("`@("`O+R!.;W1E('1H870@8W)E9&5N=&EA;"!I<R!S96YT
M('!L86EN+71E>'0@:6X@=&AI<R!C87-E+"!S;R!D;VXG="!U<V4*+R\@("`@
M("`@("`O+R!P<FEV:6QE9V5D(&%C8V]U;G0@:&5R92!O<B!S971U<"!34TP@
M*&)Y('5S:6YG('!O<G0@-C,V(&%B;W9E*2X*+R\@("`@("`@("`D8FEN9&1N
M(#T@)V-N/5=I=&AO=710<FEV:6QE9V4L9&,]=6QA=F%L+61E=BQD8SUC82<[
M"B\O("`@("`@("`@)&)I;F1P=R`]("=296UE;6)E<B!T:&ES(&ES('-E;G0@
M:6X@=&AE(&-L96%R('5N;&5S<R!34TP@:7,@=7-E9"<["B\O("`@("`@("`@
M)'-E87)C:$)A<V4@/2`G;W4]4&5O<&QE+&1C/65X86UP;&4L9&,]8V]M)SL*
M+R\@("`@("`@("`O+R!!='1R:6)U=&4@=&\@;6%T8V@@)'5S97))1"!A9V%I
M;G-T(&EN('-E87)C:`HO+R`@("`@("`@("1U<V5R071T<B`]("=S04U!8V-O
M=6YT3F%M92<["B\O("`@("`@("`@+R\@1W)O=7`@;65M8F5R<VAI<"!A='1R
M:6)U=&4L(&YE960@=&\@8F4@86QL(&QO=V5R8V%S90HO+R`@("`@("`@("1G
M<F]U<$%T='(@/2`G;65M8F5R;V8G.PHO+R`@("`@("`@("\O($%T=')I8G5T
M92!T;R!C:&5C:R!F;W(@<FEG:'0@=&\@=7-E($AO<F1E"B\O("`@("`@("`@
M)&=R;W5P9&X@/2`G8VX]2&]R9&55<V5R+&]U/5!E;W!L92QD8SUE>&%M<&QE
M+&1C/6-O;2<["B\O("`@("`@("`@)')E="`]('1R=64["B\O"B\O("`@("`@
M("`@)&1S(#T@0&QD87!?8V]N;F5C="@D;&1A<%-E<G9E<BP@)&QD87!0;W)T
M*3L*+R\*+R\@("`@("`@("!I9B`H0&QD87!?8FEN9"@D9',L("1B:6YD9&XL
M("1B:6YD<'<I*2!["B\O("`@("`@("`@("`@("1S96%R8VA297-U;'0@/2!`
M;&1A<%]S96%R8V@H)&1S+"`D<V5A<F-H0F%S92P@)'5S97)!='1R("X@)STG
M("X@)'5S97))1"P@87)R87DH)&=R;W5P071T<BDL(#`L(#$L(#4I.PHO+R`@
M("`@("`@("`@("!I9B`H)&EN9F]R;6%T:6]N(#T@0&QD87!?9V5T7V5N=')I
M97,H)&1S+"`D<V5A<F-H4F5S=6QT*2D@>PHO+R`@("`@("`@("`@("`@("`@
M+R\@;6%K92!P871T97)N(&-A<V4M:6YS96YS:71I=F4*+R\@("`@("`@("`@
M("`@("`@("1P871T97)N(#T@)R\G("X@)&=R;W5P9&X@+B`G+VDG.PHO+R`@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)&EN9F]R;6%T:6]N6S!=6R1G<F]U
M<$%T=')=(&%S("1G<F]U<"D@>PHO+R`@("`@("`@("`@("`@("`@("`@(&EF
M("AP<F5G7VUA=&-H*"1P871T97)N+"`D9W)O=7`I*2!["B\O("`@("`@("`@
M("`@("`@("`@("`@("`@("1R970@/2!T<G5E.PHO+R`@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*+R\@("`@("`@("`@("`@("`@("`@("!]"B\O
M("`@("`@("`@("`@("`@("!]"B\O("`@("`@("`@("`@('T*+R\@("`@("`@
M("!]"B\O"B\O("`@("`@("`@;&1A<%]C;&]S92@D9',I.PHO+R`@("`@("`@
M(')E='5R;B`D<F5T.PHO+R`@("`@?0HO+R!]"@HO+R!(97)E(&ES(&%N(&5X
M86UP;&4@;V8@8W)E871I;F<@8W)E9&5N=&EA;',@;F5E9&5D(&)Y('1H92!,
M1$%0($%U=&@@9')I=F5R"B\O(&9O<B!A9&1I;F<O9&5L971I;F<O=7!D871I
M;F<@=7-E<G,N"@HO+R!I9B`H(69U;F-T:6]N7V5X:7-T<R@G7VAO<F1E7VAO
M;VM?875T:&QD87`G*2D@>PHO+R`@("`@9G5N8W1I;VX@7VAO<F1E7VAO;VM?
M875T:&QD87`H)'5S97))1"P@)&-R961E;G1I86QS(#T@;G5L;"D*+R\@("`@
M('L*+R\@("`@("`@("`D96YT<GE;)V1N)UT@/2`G=6ED/2<@+B`D=7-E<DE$
M("X@)RQO=3U096]P;&4L9&,]97AA;7!L92YC;VTG.PHO+R`@("`@("`@(&EF
M("AI<W-E="@D8W)E9&5N=&EA;',I("8F(&ES<V5T*"1C<F5D96YT:6%L<ULG
M=7-E<E]F=6QL;F%M92==*2D@>PHO+R`@("`@("`@("`@("`D96YT<GE;)V-N
M)UT@/2`D8W)E9&5N=&EA;'-;)W5S97)?9G5L;&YA;64G73L*+R\@("`@("`@
M("!](&5L<V4@>PHO+R`@("`@("`@("`@("`D96YT<GE;)V-N)UT@/2`D=7-E
M<DE$.PHO+R`@("`@("`@('T*+R\@("`@("`@("`D96YT<GE;)W-N)UT@/2`D
M=7-E<DE$.PHO+R`@("`@("`@("1E;G1R>5LG;V)J96-T8VQA<W,G75LP72`]
M("=T;W`G.PHO+R`@("`@("`@("1E;G1R>5LG;V)J96-T8VQA<W,G75LQ72`]
M("=P97)S;VXG.PHO+R`@("`@("`@("1E;G1R>5LG;V)J96-T8VQA<W,G75LR
M72`]("=Q;6%I;'5S97(G.PHO+R`@("`@("`@("1E;G1R>5LG;V)J96-T8VQA
M<W,G75LS72`]("=#;W5R:65R36%I;$%#8V]U;G0G.PHO+R`@("`@("`@("1E
M;G1R>5LG;6%I;&AO<W0G72`]("=M86EL+F5X86UP;&4N8V]M)SL*+R\@("`@
M("`@("`D96YT<GE;)VUA:6Q-97-S86=E4W1O<F4G72`]("<O:&]M92]M86EL
M+R<@+B`D=7-E<DE$.PHO+R`@("`@("`@("1E;G1R>5LG:&]M941I<F5C=&]R
M>2==(#T@)R]H;VUE+VUA:6PO)R`N("1U<V5R240["B\O("`@("`@("`@)&5N
M=')Y6R=M86EL8F]X)UT@/2`D96YT<GE;)VAO;65$:7)E8W1O<GDG72`N("<O
M36%I;&1I<B<["B\O("`@("`@("`@)&5N=')Y6R=U:60G72`]("1U<V5R240[
M"B\O("`@("`@("`@)&5N=')Y6R=A8V-O=6YT4W1A='5S)UT@/2`G86-T:79E
M)SL*+R\@("`@("`@("`D96YT<GE;)VUA:6Q1=6]T82==(#T@)S$P-#@U-S8P
M,%,G.PHO+R`@("`@("`@("1E;G1R>5LG;6%I;"==(#T@)'5S97))1#L*+R\@
M("`@("`@("`D96YT<GE;)W5I9$YU;6)E<B==(#T@-3`Q.PHO+R`@("`@("`@
M("1E;G1R>5LG9VED3G5M8F5R)UT@/2`U,#$["B\O"B\O("`@("`@("`@+R\@
M;F5E9"!T;R!C:&5C:R!F;W(@;F5W('5S97)S("AP87-S=V]R9"D@86YD(&5D
M:71E9"!U<V5R<R`H=7-E<E]P87-S7S(I"B\O("`@("`@("`@:68@*&ES<V5T
M*"1C<F5D96YT:6%L<RD@)B8@:7-S970H)&-R961E;G1I86QS6R=P87-S=V]R
M9"==*2D@>PHO+R`@("`@("`@("`@("`D96YT<GE;)W5S97)087-S=V]R9"==
M(#T@("=[340U?2<@+B!B87-E-C1?96YC;V1E*&U(87-H*$U(05-(7TU$-2P@
M)&-R961E;G1I86QS6R=P87-S=V]R9"==*2D["B\O("`@("`@("`@?2!E;'-E
M:68@*&ES<V5T*"1C<F5D96YT:6%L<RD@)B8@:7-S970H)&-R961E;G1I86QS
M6R=U<V5R7W!A<W-?,B==*2D@>PHO+R`@("`@("`@("`@("`D96YT<GE;)W5S
M97)087-S=V]R9"==(#T@("=[340U?2<@+B!B87-E-C1?96YC;V1E*&U(87-H
M*$U(05-(7TU$-2P@)&-R961E;G1I86QS6R=U<V5R7W!A<W-?,B==*2D["B\O
M("`@("`@("`@?0HO+R`@("`@("`@("1E;G1R>5LG9&5L:79E<GE-;V1E)UT@
M/2`G;F]L;V-A;"<["B\O("`@("`@("`@<F5T=7)N("1E;G1R>3L*+R\@("`@
M('T*+R\@?0H*+R\@5&AI<R!F=6YC=&EO;B!I<R!C86QL960@=VAE;B!A($AO
M<F1E7U-H87)E(&]B:F5C="!I<R!C<F5A=&5D+B!)="!T86ME<R!A"B\O(')E
M9F5R96YC92!T;R!T:&4@2&]R9&5?4VAA<F4@;V)J96-T('1H870@:7,@8F5I
M;F<@8W)E871E9"!A<R!W96QL(&%S('1H"B\O(&YA;64@;V8@=&AE(&%P<&QI
M8V%T:6]N(&9O<B!W:&EC:"!T:&4@2&]R9&5?4VAA<F4@;V)J96-T(&ES(&)E
M:6YG(&-R96%T960@87,*+R\@<&%R86UE=&5R<RX@5&AE(')E='5R;B!V86QU
M92!I<R!I9VYO<F5D+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]H;W)D
M95]H;V]K7W-H87)E7VEN:70G*2D@>PHO+R`@("`@9G5N8W1I;VX@7VAO<F1E
M7VAO;VM?<VAA<F5?:6YI="@F)'-H87)E7V]B:F5C="P@)&%P<"D*+R\@("`@
M('L*+R\@("`@("`@("!I9B`H)$=,3T)!3%-;)V-O;F8G75LG:V]L86(G75LG
M96YA8FQE9"==*2!["B\O("`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O2V]L86(N<&AP)SL*+R\@("`@("`@("`@("`@2V]L86(Z.G-Y;F-H<F]N
M:7-E4VAA<F5S*"1S:&%R95]O8FIE8W0L("1A<'`I.PHO+R`@("`@("`@('T*
M+R\@("`@('T*+R\@?0H*+R\@5&AE(&9O;&QO=VEN9R!T:')E92!F=6YC=&EO
M;G,@87)E(&5X86UP;&5S(&]F('1H;W-E('1H870@8V%N(&)E(&-A;&QE9"!W
M:&5N"B\O(&%D9&EN9RP@;6]D:69Y:6YG(&%N9"!R96UO=FEN9R!S:&%R97,L
M(')E<W!E8W1I=F5L>2X@5&AE>2!A<F4@8V%L;&5D('=I=&@*+R\@=&AE('-H
M87)E('1H870@:7,@8F5I;F<@861D960L(&UO9&EF:65D(&]R(')E;6]V960@
M87,@=&AE:7(@<VEN9VQE"B\O('!A<F%M971E<BX@($EF(&$@4$5!4E]%<G)O
M<B!O8FIE8W0@:7,@<F5T=7)N960@=&AE(')E<W!E8W1I=F4@<VAA<F4*+R\@
M;W!E<F%T:6]N('=I;&P@9F%I;"!W:71H('1H92!E<G)O<B!R97-U;'0N"@HO
M+R!I9B`H(69U;F-T:6]N7V5X:7-T<R@G7VAO<F1E7VAO;VM?<VAA<F5?861D
M)RDI('L*+R\@("`@(&9U;F-T:6]N(%]H;W)D95]H;V]K7W-H87)E7V%D9"@F
M)'-H87)E*0HO+R`@("`@>PHO+R`@("`@("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O2V]L86(N<&AP)SL*+R\@("`@("`@("!R971U<FX@2V]L86(Z.G5P9&%T
M95-H87)E*"1S:&%R92D["B\O("`@("!]"B\O('T*"B\O(&EF("@A9G5N8W1I
M;VY?97AI<W1S*"=?:&]R9&5?:&]O:U]S:&%R95]M;V1I9GDG*2D@>PHO+R`@
M("`@9G5N8W1I;VX@7VAO<F1E7VAO;VM?<VAA<F5?;6]D:69Y*"8D<VAA<F4I
M"B\O("`@("!["B\O("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]+;VQA
M8BYP:'`G.PHO+R`@("`@("`@(')E='5R;B!+;VQA8CHZ=7!D871E4VAA<F4H
M)'-H87)E*3L*+R\@("`@('T*+R\@?0HO+PHO+R!I9B`H(69U;F-T:6]N7V5X
M:7-T<R@G7VAO<F1E7VAO;VM?<VAA<F5?<F5M;W9E)RDI('L*+R\@("`@(&9U
M;F-T:6]N(%]H;W)D95]H;V]K7W-H87)E7W)E;6]V92@F)'-H87)E*0HO+R`@
M("`@>PHO+R`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O2V]L86(N<&AP
M)SL*+R\@("`@("`@("!R971U<FX@2V]L86(Z.G)E;6]V95-H87)E*"1S:&%R
M92D["B\O("`@("!]"B\O('T*"B\O(%1H:7,@97AA;7!L92!I<R!O9B!A(&9U
M;F-T:6]N('1H870@8V%N(&)E(&-A;&QE9"!W:&5N(&$@<VAA<F4@;&ES=&EN
M9R!I<PHO+R!R97%U97-T960N($ET('1A:V5S(&$@=7-E<FED+"!A('!E<FUI
M<W-I;VYS(&QE=F5L+"!A;B!O<'1I;VYA;"!S=')I;F<*+R\@8V]N=&%I;FEN
M9R!A('5S97)I9"!T;R!R97-T<FEC="!T:&4@;W=N97(@;V8@=&AE('-H87)E
M<R!R971U<FYE9"P@86YD('1H90HO+R!R97-U;'0@;V8@=&AE(&-O<G)E<W!O
M;F1I;F<@2&]R9&5?4VAA<F4Z.FQI<W13:&%R97,H*2!C86QL(&%S(&ET<PHO
M+R!P87)A;65T97)S+B!!<R!I<R!T:&4@8V%S92!I;B!T:&4@<')E=FEO=7,@
M=&AR964@9G5N8W1I;VYS+"!I9B!A(%!%05)?17)R;W(*+R\@<F5S=6QT(&ES
M(')E='5R;F5D('1H92!(;W)D95]3:&%R93HZ;&ES=%-H87)E<R@I(&-A;&P@
M=&AA="!T<FEG9V5R960@=&AI<PHO+R!H;V]K('=I;&P@9F%I;"!W:71H('1H
M92!R971U<FYE9"!R97-U;'0N"@HO+R!I9B`H(69U;F-T:6]N7V5X:7-T<R@G
M7VAO<F1E7VAO;VM?<VAA<F5?;&ES="<I*2!["B\O("`@("!F=6YC=&EO;B!?
M:&]R9&5?:&]O:U]S:&%R95]L:7-T*"1U<V5R:60L("1P97)M+"`D;W=N97(L
M("8D<VAA<F5?;&ES="D*+R\@("`@('L*+R\@("`@("`@("!G;&]B86P@)')E
M9VES=')Y.PHO+R`@("`@("`@("\O97)R;W)?;&]G*"=.=6UB97(@;V8@)R`N
M("1'3$]"04Q36R=R96=I<W1R>2==+3YG971!<'`H*2`N("<@<VAA<F5S)R`N
M("@D;W=N97(@/PHO+R`@("`@("`@("\O("`@("<@;W=N960@8GD@)R`N("1O
M=VYE<B`Z("<G*2`N("<@879A:6QA8FQE('1O("<@+B`D=7-E<FED("X@)R!A
M="!P97)M<R!L979E;"`G("X*+R\@("`@("`@("`O+R`@("`D<&5R;2`N("<Z
M("<@+B`@8V]U;G0H)'-H87)E7VQI<W0I*3L*+R\@("`@("`@("!R971U<FX@
M=')U93L*+R\@("`@('T*+R\@?0H*+R\@2&5R92!I<R!A;B!E>&%M<&QE(%]U
M<V5R;F%M95]H;V]K7V9R;VUB86-K96YD(&9U;F-T:6]N+B!)="!A<'!E;F1S
M('1H90HO+R!V:7)T=6%L(&1O;6%I;B!T;R!T:&4@=7-E<B!N86UE+@HO+PHO
M+R!E>"X@)$A45%!?2$]35"`]("=M86EL+FUY9&]M86EN+F-O;2<L("1U<V5R
M240@/2`G;7EN86UE)R!R971U<FYS.@HO+R`@("=M>6YA;65`;7ED;VUA:6XN
M8V]M)PH*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]U<V5R;F%M95]H;V]K
M7V9R;VUB86-K96YD)RDI('L*+R\@("`@(&9U;F-T:6]N(%]U<V5R;F%M95]H
M;V]K7V9R;VUB86-K96YD*"1U<V5R240I"B\O("`@("!["B\O("`@("`@("`@
M)'9D;VUA:6X@/2!G971E;G8H)TA45%!?2$]35"<I.PHO+R`@("`@("`@("1V
M9&]M86EN(#T@<')E9U]R97!L86-E*"=\7FUA:6Q<+GQI)RP@)R<L("1V9&]M
M86EN*3L*+R\@("`@("`@("`D=F1O;6%I;B`](%-T<FEN9SHZ;&]W97(H)'9D
M;VUA:6XI.PHO+PHO+R`@("`@("`@(')E='5R;B`D=7-E<DE$("X@)T`G("X@
M)'9D;VUA:6X["B\O("`@("!]"B\O('T*"B\O($AE<F4@:7,@86X@97AA;7!L
M92!?=7-E<FYA;65?:&]O:U]T;V)A8VME;F0@9G5N8W1I;VX@87,@82!C;W5N
M=&5R<&%R="!O9B!T:&4*+R\@<')E=FEO=7,@97AA;7!L92X@270@<W1R:7!S
M('1H92!V:7)T=6%L(&1O;6%I;B!F<F]M('1H92!U<V5R(&YA;64N"B\O"B\O
M(&5X+B`D2%144%](3U-4(#T@)VUA:6PN;7ED;VUA:6XN8V]M)RP@)'5S97))
M1"`]("=M>6YA;64G(')E='5R;G,Z"B\O("`@)VUY;F%M94!M>61O;6%I;BYC
M;VTG"@HO+R!I9B`H(69U;F-T:6]N7V5X:7-T<R@G7W5S97)N86UE7VAO;VM?
M=&]B86-K96YD)RDI('L*+R\@("`@(&9U;F-T:6]N(%]U<V5R;F%M95]H;V]K
M7W1O8F%C:V5N9"@D=7-E<DE$*0HO+R`@("`@>PHO+R`@("`@("`@("1V9&]M
M86EN(#T@9V5T96YV*"=(5%107TA/4U0G*3L*+R\@("`@("`@("`D=F1O;6%I
M;B`]('!R96=?<F5P;&%C92@G?%YM86EL7"Y\:2<L("<G+"`D=F1O;6%I;BD[
M"B\O("`@("`@("`@)'9D;VUA:6X@/2`G0"<@+B!3=')I;F<Z.FQO=V5R*"1V
M9&]M86EN*3L*+R\*+R\@("`@("`@("!I9B`H<W5B<W1R*"1U<V5R240L("US
M=')L96XH)'9D;VUA:6XI*2`]/2`D=F1O;6%I;BD@>PHO+R`@("`@("`@("`@
M("`D=7-E<DE$(#T@<W5B<W1R*"1U<V5R240L(#`L("US=')L96XH)'9D;VUA
M:6XI*3L*+R\@("`@("`@("!]"B\O"B\O("`@("`@("`@<F5T=7)N("1U<V5R
M240["B\O("`@("!]"B\O('T*"B\O($AE<F4@:7,@86X@97AA;7!L92!?=7-E
M<FYA;65?:&]O:U]F<F]M8F%C:V5N9"!F=6YC=&EO;BX@270@8V]N=F5R=',@
M=&AE('5S97(*+R\@;F%M92!T;R!A;&P@;&]W97(@8V%S92X@5&AI<R!M:6=H
M="!B92!N96-E<W-A<GD@:68@86X@875T:&5N=&EC871I;VX@8F%C:V5N9`HO
M+R!I<R!C87-E(&EN<V5N<VET:79E('1O('1A:V4@:6YT;R!A8V-O=6YT('1H
M870@2&]R9&4G<R!P<F5F97)E;F-E('-Y<W1E;2!I<PHO+R!C87-E('-E;G-I
M=&EV92X*+R\*+R\@97@N("1U<V5R240@/2`G37E.86UE)R!R971U<FYS.B`G
M;7EN86UE)PH*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]U<V5R;F%M95]H
M;V]K7V9R;VUB86-K96YD)RDI('L*+R\@("`@(&9U;F-T:6]N(%]U<V5R;F%M
M95]H;V]K7V9R;VUB86-K96YD*"1U<V5R240I"B\O("`@("!["B\O("`@("`@
M("`@<F5T=7)N(%-T<FEN9SHZ;&]W97(H)'5S97))1"D["B\O("`@("!]"B\O
M('T*"B\O($AE<F4@:7,@86X@97AA;7!L92!?<&5R;7-?:&]O:U]D96YI960@
M9G5N8W1I;VXN("!)="!I<R!C86QL960@:68@82!U<V5R"B\O('1R:65S('1O
M(&UA:V4@86X@86-T:6]N('1H870@:7,@=6YD97(@<&5R;6ES<VEO;B!C;VYT
M<F]L(&%N9"!T:&%T(&AE"B\O(&1O97-N)W0@:&%V92!S=69F:6-I96YT('!E
M<FUI<W-I;VYS(&9O<BX@($ET(&-A;B!B92!U<V5D('1O('-H;W<@=&AE('5S
M97(@80HO+R!C=7-T;VT@;65S<V%G92!I;F-L=61I;F<@2%1-3"!C;V1E("AY
M;W4@:&%V92!T;R!T86ME(&-A<F4@86)O=70@2%1-3`HO+R!E<V-A<&EN9R!O
M;B!Y;W5R(&]W;BDL(&]R('1O(&EN=&5R<G5P="!T:&4@8V]D92!F;&]W(&%N
M9"!S96YD('1H92!U<V5R('1O(&$*+R\@9&EF9F5R96YT('!A9V4@9F]R(&5X
M86UP;&4N"@HO+R!I9B`H(69U;F-T:6]N7V5X:7-T<R@G7W!E<FUS7VAO;VM?
M9&5N:65D)RDI('L*+R\@("`@(&9U;F-T:6]N(%]P97)M<U]H;V]K7V1E;FEE
M9"@D<&5R;6ES<VEO;BD*+R\@("`@('L*+R\@("`@("`@("!I9B`H*"1P;W,@
M/2!S=')P;W,H)'!E<FUI<W-I;VXL("<Z)RDI(#T]/2!F86QS92D@>PHO+R`@
M("`@("`@("`@("`D87!P(#T@)'!E<FUI<W-I;VX["B\O("`@("`@("`@?2!E
M;'-E('L*+R\@("`@("`@("`@("`@)&%P<"`]('-U8G-T<B@D<&5R;6ES<VEO
M;BP@,"P@)'!O<RD["B\O("`@("`@("`@?0HO+PHO+R`@("`@("`@(')E='5R
M;B!S<')I;G1F*"=097)M:7-S:6]N(&1E;FEE9"X@0VQI8VL@/&$@:')E9CTB
M:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]U<&=R861E+G!H<#]A<'`])7,B/DA%
M4D4\+V$^('1O('5P9W)A9&4@)7,N)RP*+R\@("`@("`@("`@("`@("`@("`@
M("`@("`D87!P+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=N86UE)RDI
M.PHO+R`@("`@?0HO+R!]"@HO+R!4:&ES(&ES(&%N(&5X86UP;&4@;V8@82!G
M<F]U<"!H;V]K+B`@5&\@=7-E(&ET('EO=2!M=7-T('-E="!T:&4@9W)O=7`*
M+R\@9')I=F5R('1O(&AO;VMS(&EN(&-O;F8N<&AP+B`@5&AE;B!Y;W4@;75S
M="!C<F5A=&4@82!)5%]D97!A<G1M96YT(&=R;W5P"B\O("AB96-A=7-E('1H
M870@:7,@:&]W('=E(&MN;W<@=VAA="!H;V]K('1O(&-A;&PI+B`@66]U(&-A
M;B!A9&0@=7-E<G,@=&\@=&AE"B\O(&=R;W5P(&%S(&YO<FUA;"P@86YD(&EN
M(&%D9&ET:6]N('1H:7,@9G5N8W1I;VX@=VEL;"!B92!C86QL960@=&\*+R\@
M9'EN86UI8V%L;'D@:6YC;'5D92!U<V5R<R!I;B!T:&4@9W)O=7`N("!);B!T
M:&ES(&5X86UP;&4@=V4@=VEL;"!L;V]K('5P"B\O('=H971H97(@;W(@;F]T
M('1H:7,@=7-E<B!I<R!P87)T(&]F('1H92!)5"!D97!A<G1M96YT('5S:6YG
M(&%N(&5X=&5R;F%L"B\O(&1A=&%B87-E+@H*+R\@:68@*"%F=6YC=&EO;E]E
M>&ES=',H)U]G<F]U<%]H;V]K7TE47V1E<&%R=&UE;G0G*2D@>PHO+R`@("`@
M9G5N8W1I;VX@7V=R;W5P7VAO;VM?251?9&5P87)T;65N="@D=7-E<DYA;64I
M"B\O("`@("!["B\O("`@("`@("`@9VQO8F%L("1C;VYF.PHO+PHO+R`@("`@
M("`@("1D97!T(#T@)TE4)SL*+R\@("`@("`@("!I;F-L=61E7V]N8V4@)T1"
M+G!H<"<["B\O("`@("`@("`@)%]D8B`]("9$0CHZ8V]N;F5C="@D8V]N9ELG
M<W%L)UTL('1R=64I.PHO+R`@("`@("`@("1Q=65R>2`]("=314Q%0U0@0T]5
M3E0H*BD@1E)/32!D97!A<G1M96YT<R!72$5212!U<V5R7VYA;64@/2`_($%.
M1"!D97!A<G1M96YT(#T@/R<["B\O("`@("`@("`@)'9A;'5E<R`](&%R<F%Y
M*"1U<V5R3F%M92P@)&1E<'0I.PHO+R`@("`@("`@("1R97-U;'0@/2`D7V1B
M+3YG971/;F4H)'%U97)Y+"`D=F%L=65S*3L*+R\@("`@("`@("!I9B`H(6ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2`F)B`D<F5S=6QT(#X@,"D@>PHO
M+R`@("`@("`@("`@("!R971U<FX@=')U93L*+R\@("`@("`@("!](&5L<V4@
M>PHO+R`@("`@("`@("`@("!R971U<FX@9F%L<V4["B\O("`@("`@("`@?0HO
M+R`@("`@?0HO+R!]"@HO+R!4:&ES(&ES(&%N(&5X86UP;&4@;V8@82!P;W-T
M+7!U<V@@:&]O:SL@:70@:7,@8V%L;&5D(')I9VAT(&%F=&5R(&%N"B\O(&%P
M<&QI8V%T:6]N(&ES('!U<VAE9"!S=6-C97-S9G5L;'D@;VYT;R!T:&4@87!P
M('-T86-K+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]H;W)D95]H;V]K
M7W!O<W1?<'5S:&%P<"<I*2!["B\O("`@("!F=6YC=&EO;B!?:&]R9&5?:&]O
M:U]P;W-T7W!U<VAA<'`H)&%P<"D*+R\@("`@('L*+R\@("`@("`@("!I9B`H
M:6Y?87)R87DH)&%P<"P@87)R87DH)VMR;VYO;&ET:"<L("=T=7)B82<L("=H
M;W)D92<L("=I;F=O)RDI('Q\"B\O("`@("`@("`@("`@("!S=')P;W,H)%]3
M15)615);)U!(4%]314Q&)UTL("=P<F5F<RYP:'`G*2`A/3T@9F%L<V4I('L*
M+R\@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("1'3$]"04Q36R=R96=I<W1R
M>2==+3YG970H)V9I;&5R;V]T)RP@)V1I;7`G*2`N("<O;&EB+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7-/=F5R<FED92YP:'`G.PHO+R`@("`@("`@
M("`@("`D1TQ/0D%,4ULG;F]T:69I8V%T:6]N)UT@/2`F3F]T:69I8V%T:6]N
M.CIS:6YG;&5T;VXH*3L*+R\@("`@("`@("`@("`@)$=,3T)!3%-;)VYO=&EF
M:6-A=&EO;B==+3YA='1A8V@H)W-T871U<R<L(&YU;&PL("=.;W1I9FEC871I
M;VY?3&ES=&5N97)?9&EM<%]S=&%T=7-/=F5R<FED92<I.PHO+R`@("`@("`@
M('T*+R\@("`@('T*+R\@?0H*+R\@2&5R92!I<R!A;B!E>&%M<&QE(%]I;7!?
M:&]O:U]T<F%I;&5R(&9U;F-T:6]N('1O('-E="!T:&4@=')A:6QE<B!F<F]M
M('1H90HO+R!S>7-T96T@=&%G;&EN97,@9FEL93L@=&AE('-T<FEN9R`B0$!4
M04=`0"(@*&EF('!R97-E;G0@:6X@82!T<F%I;&5R*2!W:6QL(&)E"B\O(')E
M<&QA8V5D(&)Y('1H92!C;VYT96YT(&]F('1H92!F:6QE("(O=7-R+W-H87)E
M+W1A9VQI;F4B("AG96YE<F%T960@8GD@=&AE"B\O(")485)4(B!U=&EL:71Y
M*2X*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?:6UP7VAO;VM?=')A:6QE
M<B<I*2!["B\O("`@("!F=6YC=&EO;B!?:6UP7VAO;VM?=')A:6QE<B@D=')A
M:6QE<BD*+R\@("`@('L*+R\@("`@("`@("!I9B`H<')E9U]M871C:"@G+T!`
M5$%'0$`O)RP@)'1R86EL97(I*2!["B\O("`@("`@("`@("`@("1T86<@/2!@
M8V%T("]U<W(O<VAA<F4O=&%G;&EN96`["B\O("`@("`@("`@("`@("1T<F%I
M;&5R(#T@<')E9U]R97!L86-E*"=\0$!404=`0'PG+"`D=&%G+"`D=')A:6QE
M<BD["B\O("`@("`@("`@?0HO+R`@("`@("`@(')E='5R;B`D=')A:6QE<CL*
M+R\@("`@('T*+R\@?0H*+R\@2&5R92!I<R!A;B!A;F]T:&5R(&5X86UP;&4@
M7VEM<%]H;V]K7W1R86EL97(@9G5N8W1I;VX@=&\@<V5T('1H92!T<F%I;&5R
M"B\O(&9R;VT@=&AE($Q$05`@9&ER96-T;W)Y(&9O<B!E86-H(&1O;6%I;BX@
M5&AI<R!F=6YC=&EO;B!R97!L86-E<R!T:&4@8W5R<F5N=`HO+R!T<F%I;&5R
M('=I=&@@=&AE(&1A=&$@:70@9V5T<R!F<F]M(&ES<&UA;D1O;6%I;E-I9VYA
M='5R92X*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?:6UP7VAO;VM?=')A
M:6QE<B<I*2!["B\O("`@("!F=6YC=&EO;B!?:6UP7VAO;VM?=')A:6QE<B@D
M=')A:6QE<BD*+R\@("`@('L*+R\@("`@("`@("`D=F1O;6%I;B`](&=E=&5N
M=B@G2%144%](3U-4)RD["B\O("`@("`@("`@)'9D;VUA:6X@/2!P<F5G7W)E
M<&QA8V4H)WQ>+BH_7"Y\:2<L("<G+"`D=F1O;6%I;BD["B\O("`@("`@("`@
M)'9D;VUA:6X@/2!3=')I;F<Z.FQO=V5R*"1V9&]M86EN*3L*+R\@("`@("`@
M("`D;&1A<%-E<G9E<B`]("=L;V-A;&AO<W0G.PHO+R`@("`@("`@("1L9&%P
M4&]R="`]("<S.#DG.PHO+R`@("`@("`@("1S96%R8VA"87-E(#T@)VES<&UA
M;D1O;6%I;CTG("X@)'9D;VUA:6X@("X@(BQO/6ES<&UA;B(["B\O"B\O("`@
M("`@("`@)&1S(#T@0&QD87!?8V]N;F5C="@D;&1A<%-E<G9E<BP@)&QD87!0
M;W)T*3L*+R\@("`@("`@("`D<V5A<F-H4F5S=6QT(#T@0&QD87!?<V5A<F-H
M*"1D<RP@)'-E87)C:$)A<V4L("=U:60])R`N("1V9&]M86EN*3L*+R\@("`@
M("`@("`D:6YF;W)M871I;VX@/2!`;&1A<%]G971?96YT<FEE<R@D9',L("1S
M96%R8VA297-U;'0I.PHO+R`@("`@("`@("1T<F%I;&5R/2`D:6YF;W)M871I
M;VY;,%U;)VES<&UA;F1O;6%I;G-I9VYA='5R92==6S!=.PHO+R`@("`@("`@
M(&QD87!?8VQO<V4H)&1S*3L*+R\*+R\@("`@("`@("!R971U<FX@)'1R86EL
M97(["B\O("`@("!]"B\O('T*"B\O($AE<F4@:7,@86X@97AA;7!L92!?:6UP
M7VAO;VM?=FEN9F\@9G5N8W1I;VXN($EF("1T>7!E(#T]("=V9&]M86EN)RP@
M=&AI<PHO+R!F=6YC=&EO;B!R971U<FYS('1H92!(5%107TA/4U0@=F%R:6%B
M;&4@869T97(@<F5M;W9I;F<@=&AE("=M86EL+B<*+R\@<W5B9&]M86EN+@HO
M+PHO+R!)9B`D='EP92`]/2`G=7-E<FYA;64G+"!T:&ES(&9U;F-T:6]N(')E
M='5R;G,@82!U;FEQ=64@=7-E<FYA;64@8V]M<&]S960@;V8*+R\@)%]315-3
M24].6R=I;7`G75LG=7-E<B==("L@=F1O;6%I;BX*+R\*+R\@97@N("1(5%10
M7TA/4U0@/2`G;6%I;"YM>61O;6%I;BYC;VTG+"`D7U-%4U-)3TY;)VEM<"==
M6R=U<V5R)UT@/2`G;7EN86UE)SH*+R\@("`D=F1O;6%I;B`@/2`G;7ED;VUA
M:6XN8V]M)PHO+R`@("1U<V5R;F%M92`]("=M>6YA;65?;7ED;VUA:6Y?8V]M
M)PH*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]I;7!?:&]O:U]V:6YF;R<I
M*2!["B\O("`@("!F=6YC=&EO;B!?:6UP7VAO;VM?=FEN9F\H)'1Y<&4@/2`G
M=7-E<FYA;64G*0HO+R`@("`@>PHO+R`@("`@("`@("1V9&]M86EN(#T@9V5T
M96YV*"=(5%107TA/4U0G*3L*+R\@("`@("`@("`D=F1O;6%I;B`]('!R96=?
M<F5P;&%C92@G?%YM86EL7"Y\:2<L("<G+"`D=F1O;6%I;BD["B\O("`@("`@
M("`@)'9D;VUA:6X@/2!3=')I;F<Z.FQO=V5R*"1V9&]M86EN*3L*+R\*+R\@
M("`@("`@("!I9B`H)'1Y<&4@/3T@)W5S97)N86UE)RD@>PHO+R`@("`@("`@
M("`@("!R971U<FX@<')E9U]R97!L86-E*"=\7"Y\)RP@)U\G+"`D7U-%4U-)
M3TY;)VEM<"==6R=U<V5R)UT@+B`G7R<@+B`D=F1O;6%I;BD["B\O("`@("`@
M("`@?2!E;'-E:68@*"1T>7!E(#T]("=V9&]M86EN)RD@>PHO+R`@("`@("`@
M("`@("!R971U<FX@)'9D;VUA:6X["B\O("`@("`@("`@?2!E;'-E('L*+R\@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)VEN=F%L:60@
M='EP93H@)R`N("1T>7!E*3L*+R\@("`@("`@("!]"B\O("`@("!]"B\O('T*
M"B\O($AE<F4@:7,@86X@97AA;7!L92!O9B!T:&4@7VEM<%]H;V]K7V9E=&-H
M;6%I;%]F:6QT97(@9G5N8W1I;VX@=&\@<G5N"B\O(%-P86U!<W-A<W-I;B!O
M;B!E;6%I;"!B969O<F4@:70@:7,@=W)I='1E;B!T;R!T:&4@;6%I;&)O>"X*
M+R\@3F]T93H@=&\@=7-E('1H92!S<&%M87-S87-S:6X@:6YS=&5A9"!O9B!S
M<&%M9"P@8VAA;F=E("=S<&%M8R<@=&\*+R\@)W-P86UA<W-A<W-I;B`M4"<@
M86YD(&%D9"!A;GD@;W1H97(@:6UP;W)T86YT(&%R9W5M96YT<RP@8G5T(')E
M86QI>F4@<W!A;6,*+R\@:7,@355#2"!F87-T97(@=&AA;B!S<&%M87-S87-S
M:6XN"B\O(%=!4DY)3D<Z($UA:V4@<W5R92!T;R!U<V4@=&AE("TM;F]A9&0M
M9G)O;2!F:6QT97(@;VX@<W!A;60@;W(@<W!A;6%S<V%S<VEN"@HO+R!I9B`H
M(69U;F-T:6]N7V5X:7-T<R@G7VEM<%]H;V]K7V9E=&-H;6%I;%]F:6QT97(G
M*2D@>PHO+R`@("`@9G5N8W1I;VX@7VEM<%]H;V]K7V9E=&-H;6%I;%]F:6QT
M97(H)&UE<W-A9V4I"B\O("`@("!["B\O("`@("`@("`@+R\@5VAE<F4@9&]E
M<R!3<&%M07-S87-S:6X@;&EV92P@86YD('=H870@=7-E<FYA;64@<VAO=6QD
M('=E('5S90HO+R`@("`@("`@("\O(&9O<B!P<F5F97)E;F-E<S\*+R\@("`@
M("`@("`D8VUD(#T@)R]U<W(O;&]C86PO8FEN+W-P86UC)SL*+R\@("`@("`@
M("`D=7-E<FYA;64@/2!!=71H.CIG971!=71H*"D["B\O("`@("`@("`@+R\@
M268@>6]U('5S92!T:&4@7W-A;5]H;V]K7W5S97)N86UE*"D@:&]O:RP@=6YC
M;VUM96YT('1H92!N97AT(&QI;F4*+R\@("`@("`@("`O+R1U<V5R;F%M92`]
M(%]S86U?:&]O:U]U<V5R;F%M92@D=7-E<FYA;64I.PHO+R`@("`@("`@("1U
M<V5R;F%M92`](&5S8V%P97-H96QL87)G*"1U<V5R;F%M92D["B\O"B\O("`@
M("`@("`@+R\@06QS;RP@=V4@<F5M;W9E('1H92!F:6QE(&]U<G-E;'9E<SL@
M=&AI<R!H;V]K(&UA>2!B92!C86QL960*+R\@("`@("`@("`O+R!H=6YD<F5D
M<R!O9B!T:6UE<R!P97(@<G5N(&1E<&5N9&EN9R!O;B!H;W<@;6%N>2!M97-S
M86=E<R!W92!F971C:`HO+R`@("`@("`@("1F:6QE(#T@2&]R9&4Z.F=E=%1E
M;7!&:6QE*"=H;W)D92<L(&9A;'-E*3L*+R\*+R\@("`@("`@("`O+R!#86QL
M(%-P86U!<W-A<W-I;CL@<&EP92!T:&4@;F5W(&UE<W-A9V4@=&\@;W5R('1E
M;7!F:6QE"B\O("`@("`@("`@)&9P(#T@<&]P96XH(B1C;60@+74@)'5S97)N
M86UE(#X@)&9I;&4B+"`G=R<I.PHO+R`@("`@("`@(&9W<FET92@D9G`L("1M
M97-S86=E*3L*+R\@("`@("`@("!P8VQO<V4H)&9P*3L*+R\*+R\@("`@("`@
M("`O+R!296%D('1H92!N97<@;65S<V%G92!F<F]M('1H92!T96UP;W)A<GD@
M9FEL90HO+R`@("`@("`@("1M97-S86=E(#T@9FEL95]G971?8V]N=&5N=',H
M)&9I;&4I.PHO+R`@("`@("`@('5N;&EN:R@D9FEL92D["B\O("`@("`@("`@
M<F5T=7)N("1M97-S86=E.PHO+R`@("`@?0HO+R!]"@HO+R!(97)E(&ES(&%N
M(&5X86UP;&4@<VEG;F%T=7)E(&AO;VL@9G5N8W1I;VX@=&\@<V5T('1H92!S
M:6=N871U<F4@9G)O;2!T:&4*+R\@<WES=&5M('1A9VQI;F5S(&9I;&4[('1H
M92!S=')I;F<@(B5404<E(B`H:68@<')E<V5N="!I;B!A('5S97(G<R!S:6=N
M871U<F4I"B\O('=I;&P@8F4@<F5P;&%C960@8GD@=&AE(&-O;G1E;G0@;V8@
M=&AE(&9I;&4@(B]U<W(O<VAA<F4O=&%G;&EN92(@*&=E;F5R871E9`HO+R!B
M>2!T:&4@(E1A4E0B('5T:6QI='DI+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES
M=',H)U]I;7!?:&]O:U]S:6=N871U<F4G*2D@>PHO+R`@("`@9G5N8W1I;VX@
M7VEM<%]H;V]K7W-I9VYA='5R92@D<VEG*0HO+R`@("`@>PHO+R`@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"<O)51!1R4O)RP@)'-I9RDI('L*+R\@("`@("`@
M("`@("`@)'1A9R`](&!C870@+W5S<B]S:&%R92]T86=L:6YE8#L*+R\@("`@
M("`@("`@("`@)'-I9R`]('!R96=?<F5P;&%C92@G+R5404<E+R<L("1T86<L
M("1S:6<I.PHO+R`@("`@("`@('T*+R\*+R\@("`@("`@("!R971U<FX@)'-I
M9SL*+R\@("`@('T*+R\@?0H*+R\@5&AI<R!I<R!A;B!E>&%M<&QE(&AO;VL@
M9G5N8W1I;VX@9F]R('1H92!)35`@<F5D:7)E8W1I;VX@<V-H96UE+B!4:&ES
M"B\O(&9U;F-T:6]N(&ES(&-A;&QE9"!W:&5N('1H92!U<V5R(&]P96YS(&$@
M;6%I;&)O>"!I;B!)35`L(&%N9"!A;&QO=W,@=&AE"B\O(&-L:65N="!T;R!B
M92!R961I<F5C=&5D(&)A<V5D(&]N('1H92!M86EL8F]X(&YA;64N(%1H92!R
M971U<FX@=F%L=64@;V8@=&AI<PHO+R!F=6YC=&EO;B!S:&]U;&0@8F4@82!V
M86QI9"!P86=E('=I=&AI;B!A(&AO<F1E(&%P<&QI8V%T:6]N('=H:6-H('=I
M;&P@8F4*+R\@<&QA8V5D(&EN(&$@(DQO8V%T:6]N(B!H96%D97(@=&\@<F5D
M:7)E8W0@=&AE(&-L:65N="X@(%1H92!O;FQY('!A<F%M971E<@HO+R!I<R!T
M:&4@;F%M92!O9B!T:&4@;6%I;&)O>"!W:&EC:"!T:&4@=7-E<B!H87,@;W!E
M;F5D+B`@268@86X@96UP='D@<W1R:6YG"B\O(&ES(')E='5R;F5D('1H92!U
M<V5R(&ES(&YO="!R961I<F5C=&5D+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES
M=',H)U]I;7!?:&]O:U]M8F]X7W)E9&ER96-T)RDI('L*+R\@("`@(&9U;F-T
M:6]N(%]I;7!?:&]O:U]M8F]X7W)E9&ER96-T*"1M86EL8F]X*0HO+R`@("`@
M>PHO+R`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O2V]L86(N<&AP)SL*
M+R\*+R\@("`@("`@("!I9B`H<W1R<&]S*"1M86EL8F]X+"`B24Y"3U@O0V%L
M96YD87(B*2`A/3T@9F%L<V4*+R\@("`@("`@("`@("`@?'P@<')E9U]M871C
M:"@B(5YU<V5R+UM>+UTK+T-A;&5N9&%R(2(L("1M86EL8F]X*2D@>PHO+R`@
M("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G
M=V5B<F]O="<L("=K<F]N;VQI=&@G*3L*+R\@("`@("`@("!](&5L<V5I9B`H
M<W1R<&]S*"1M86EL8F]X+"`B24Y"3U@O5&%S:W,B*2`A/3T@9F%L<V4*+R\@
M("`@("`@("`@("`@?'P@<')E9U]M871C:"@B(5YU<V5R+UM>+UTK+U1A<VMS
M(2(L("1M86EL8F]X*2D@>PHO+R`@("`@("`@("`@("!R971U<FX@)$=,3T)!
M3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O="<L("=N86<G*3L*+R\@("`@
M("`@("!](&5L<V5I9B`H<W1R<&]S*"1M86EL8F]X+"`B24Y"3U@O3F]T97,B
M*2`A/3T@9F%L<V4*+R\@("`@("`@("`@("`@?'P@<')E9U]M871C:"@B(5YU
M<V5R+UM>+UTK+TYO=&5S(2(L("1M86EL8F]X*2D@>PHO+R`@("`@("`@("`@
M("!R971U<FX@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O="<L
M("=M;F5M;R<I.PHO+R`@("`@("`@('T@96QS96EF("AS=')P;W,H)&UA:6QB
M;W@L("))3D)/6"]#;VYT86-T<R(I("$]/2!F86QS90HO+R`@("`@("`@("`@
M("!\?"!P<F5G7VUA=&-H*"(A7G5S97(O6UXO72LO0V]N=&%C=',A(BP@)&UA
M:6QB;W@I*2!["B\O("`@("`@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG<F5G
M:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@)W1U<F)A)RD["B\O("`@("`@("`@
M?0HO+PHO+R`@("`@("`@(')E='5R;B`G)SL*+R\@("`@('T*+R\@?0H*+R\@
M5&AI<R!I<R!A;B!E>&%M<&QE(&AO;VL@9G5N8W1I;VX@9F]R('1H92!)35`@
M;6%I;&)O>"!I8V]N('-C:&5M92X@5&AI<PHO+R!F=6YC=&EO;B!I<R!C86QL
M960@=VAE;B!T:&4@9F]L9&5R(&QI<W0@:7,@8W)E871E9"!A;F0@82`B<W1A
M;F1A<F0B(&9O;&1E<@HO+R!I<R!T;R!B92!D:7-P;&%Y960@+2!I="!A;&QO
M=W,@8W5S=&]M(&9O;&1E<B!I8V]N<R!T;R!B92!S<&5C:69I960N"B\O("@B
M4W1A;F1A<F0B(&UE86YS(&%L;"!F;VQD97)S(&5X8V5P="!T:&4@24Y"3U@L
M('-E;G0M;6%I;"!F;VQD97)S(&%N9`HO+R!T<F%S:"!F;VQD97)S+BD*+R\@
M268@82!M86EL8F]X(&YA;64@9&]E<VXG="!A<'!E87(@:6X@=&AE(&)E;&]W
M(&QI<W0L('1H92!D969A=6QT(&UA:6QB;W@*+R\@:6-O;B!I<R!D:7-P;&%Y
M960N"@HO+R!I9B`H(69U;F-T:6]N7V5X:7-T<R@G7VEM<%]H;V]K7VUB;WA?
M:6-O;G,G*2D@>PHO+R`@("`@9G5N8W1I;VX@7VEM<%]H;V]K7VUB;WA?:6-O
M;G,H*0HO+R`@("`@>PHO+R`@("`@("`@('-T871I8R`D;F5W;6%I;&)O>&5S
M.PHO+PHO+R`@("`@("`@(&EF("@A96UP='DH)&YE=VUA:6QB;WAE<RDI('L*
M+R\@("`@("`@("`@("`@<F5T=7)N("1N97=M86EL8F]X97,["B\O("`@("`@
M("`@?0HO+PHO+R`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O2V]L86(N
M<&AP)SL*+R\*+R\@("`@("`@("`D:V,@/2!N97<@2V]L86)?0WER=7,H)$=,
M3T)!3%-;)V-O;F8G75LG:V]L86(G75LG<V5R=F5R)UTI.PHO+R`@("`@("`@
M("1M86EL8F]X97,@/2`D:V,M/FQI<W1-86EL0F]X97,H*3L*+R\@("`@("`@
M("`D;F5W;6%I;&)O>&5S(#T@87)R87DH*3L*+R\*+R\@("`@("`@("!F;W)E
M86-H("@D;6%I;&)O>&5S(&%S("1B;W@I('L*+R\@("`@("`@("`@("`@)&)O
M>"`]('!R96=?<F5P;&%C92@B+UY[6UY]72M]+R(L("(B+"`D8F]X*3L*+R\@
M("`@("`@("`@("`@:68@*'-T<G!O<R@D8F]X+"`B24Y"3U@O0V%L96YD87(B
M*2`A/3T@9F%L<V4*+R\@("`@("`@("`@("`@("`@('Q\('!R96=?;6%T8V@H
M(B%>=7-E<B];7B]=*R]#86QE;F1A<B$B+"`D8F]X*2D@>PHO+R`@("`@("`@
M("`@("`@("`@)&YE=VUA:6QB;WAE<ULD8F]X72`]($AO<F1E.CII;6<H"B\O
M("`@("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E
M="@G:6-O;B<L("=K<F]N;VQI=&@G*2P*+R\@("`@("`@("`@("`@("`@("`@
M("!?*")#86QE;F1A<B(I+`HO+R`@("`@("`@("`@("`@("`@("`@("=W:61T
M:#TB,38B(&AE:6=H=#TB,38B('-T>6QE/2)V97)T:6-A;"UA;&EG;CIM:61D
M;&4B)RP*+R\@("`@("`@("`@("`@("`@("`@("`G)PHO+R`@("`@("`@("`@
M("`@("`@*3L*+R\@("`@("`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D8F]X
M+"`B24Y"3U@O5&%S:W,B*2`A/3T@9F%L<V4*+R\@("`@("`@("`@("`@("`@
M('Q\('!R96=?;6%T8V@H(B%>=7-E<B];7B]=*R]487-K<R$B+"`D8F]X*2D@
M>PHO+R`@("`@("`@("`@("`@("`@)&YE=VUA:6QB;WAE<ULD8F]X72`]($AO
M<F1E.CII;6<H"B\O("`@("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)W)E
M9VES=')Y)UTM/F=E="@G:6-O;B<L("=N86<G*2P*+R\@("`@("`@("`@("`@
M("`@("`@("!?*")487-K<R(I+`HO+R`@("`@("`@("`@("`@("`@("`@("=W
M:61T:#TB,38B(&AE:6=H=#TB,38B('-T>6QE/2)V97)T:6-A;"UA;&EG;CIM
M:61D;&4B)RP*+R\@("`@("`@("`@("`@("`@("`@("`G)PHO+R`@("`@("`@
M("`@("`@("`@*3L*+R\@("`@("`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D
M8F]X+"`B24Y"3U@O3F]T97,B*2`A/3T@9F%L<V4*+R\@("`@("`@("`@("`@
M("`@('Q\('!R96=?;6%T8V@H(B%>=7-E<B];7B]=*R].;W1E<R$B+"`D8F]X
M*2D@>PHO+R`@("`@("`@("`@("`@("`@)&YE=VUA:6QB;WAE<ULD8F]X72`]
M($AO<F1E.CII;6<H"B\O("`@("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;
M)W)E9VES=')Y)UTM/F=E="@G:6-O;B<L("=M;F5M;R<I+`HO+R`@("`@("`@
M("`@("`@("`@("`@(%\H(DYO=&5S(BDL"B\O("`@("`@("`@("`@("`@("`@
M("`@)W=I9'1H/2(Q-B(@:&5I9VAT/2(Q-B(@<W1Y;&4](G9E<G1I8V%L+6%L
M:6=N.FUI9&1L92(G+`HO+R`@("`@("`@("`@("`@("`@("`@("<G"B\O("`@
M("`@("`@("`@("`@("`I.PHO+R`@("`@("`@("`@("!](&5L<V5I9B`H<W1R
M<&]S*"1B;W@L("))3D)/6"]#;VYT86-T<R(I("$]/2!F86QS90HO+R`@("`@
M("`@("`@("`@("`@?'P@<')E9U]M871C:"@B(5YU<V5R+UM>+UTK+T-O;G1A
M8W1S(2(L("1B;W@I*2!["B\O("`@("`@("`@("`@("`@("`D;F5W;6%I;&)O
M>&5S6R1B;WA=(#T@2&]R9&4Z.FEM9R@*+R\@("`@("`@("`@("`@("`@("`@
M("`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=I8V]N)RP@)W1U<F)A)RDL
M"B\O("`@("`@("`@("`@("`@("`@("`@7R@B0V]N=&%C=',B*2P*+R\@("`@
M("`@("`@("`@("`@("`@("`G=VED=&@](C$V(B!H96EG:'0](C$V(B!S='EL
M93TB=F5R=&EC86PM86QI9VXZ;6ED9&QE(B<L"B\O("`@("`@("`@("`@("`@
M("`@("`@)R<*+R\@("`@("`@("`@("`@("`@("D["B\O("`@("`@("`@("`@
M('T*+R\@("`@("`@("!]"B\O"B\O("`@("`@("`@<F5T=7)N("1N97=M86EL
M8F]X97,["B\O("`@("!]"B\O('T*"B\O(%1H:7,@:7,@86X@97AA;7!L92!H
M;V]K(&9U;F-T:6]N(&9O<B!T:&4@24U0('-P86T@<F5P;W)T:6YG(&)O=6-E
M(&]P=&EO;BX*+R\@5&AI<R!F=6YC=&EO;B!I<R!C86QL960@=VAE;B!T:&4@
M;65S<V%G92!I<R!A8F]U="!T;R!B92!B;W5N8V5D("T@:70*+R\@=VEL;"!R
M971U<FX@=&AE(&5M86EL(&%D9')E<W,@=&\@8F]U;F-E('1O+B`@5&AI<R!I
M<R!H86YD>2!F;W(@<W!A;0HO+R!R97!O<G1I;F<@<V]F='=A<F4@*&4N9RX@
M1%-004TI('=H:6-H(&AA<R!D:69F97)E;G0@92UM86EL(&%L:6%S97,@9F]R
M"B\O('-P86T@<F5P;W)T:6YG(&9O<B!E86-H('5S97(N"@HO+R!I9B`H(69U
M;F-T:6]N7V5X:7-T<R@G7VEM<%]H;V]K7W-P86U?8F]U;F-E)RDI('L*+R\@
M("`@(&9U;F-T:6]N(%]I;7!?:&]O:U]S<&%M7V)O=6YC92@D86-T:6]N*0HO
M+R`@("`@>PHO+R`@("`@("`@("1P<F5F:7@@/2`H)&%C=&EO;B`]/2`G<W!A
M;2<I(#\@)W-P86TM)R`Z("=F<"TG.PHO+R`@("`@("`@(')E='5R;B`D<')E
M9FEX("X@075T:#HZ9V5T0F%R94%U=&@H*2`N("=`97AA;7!L92YC;VTG.PHO
M+R`@("`@?0HO+R!]"@HO+R!(97)E(&%N(&5X86UP;&4@7W-A;5]H;V]K7W5S
M97)N86UE(&9U;F-T:6]N('1O('-E="!T:&4@=7-E<FYA;64@=&AA=`HO+R!3
M<&%M07-S87-S:6X@<V5E<R!T;R!O;F4@9&EF9F5R96YT(&9R;VT@=&AE($AO
M<F1E('5S97)N86UE+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]S86U?
M:&]O:U]U<V5R;F%M92<I*2!["B\O("`@("!F=6YC=&EO;B!?<V%M7VAO;VM?
M=7-E<FYA;64H)&AO<F1E7W5I9"D*+R\@("`@('L*+R\@("`@("`@("!I9B`H
M<W1R<W1R*"1H;W)D95]U:60L("=`)RDI('L*+R\@("`@("`@("`@("`@)'!A
M<G1S(#T@97AP;&]D92@G0"<L("1H;W)D95]U:60I.PHO+R`@("`@("`@("`@
M("!R971U<FX@)'!A<G1S6S!=.PHO+R`@("`@("`@('T@96QS92!["B\O("`@
M("`@("`@("`@(')E='5R;B`D:&]R9&5?=6ED.PHO+R`@("`@("`@('T*+R\@
M("`@('T*+R\@?0H*+R\@2&5R92!I<R!A;B!E>&%M<&QE(%]T=7)B85]H;V]K
M7V5N8V]D95]P87-S=V]R9"`H86YD(&1E8V]D92DN(&5N8V]D92!I<PHO+R!C
M86QL960@=VAE;B!W92!S=&]R92!A('9A;'5E.R!D96-O9&4@=VAE;B!W92!D
M:7-P;&%Y(&ET+B`@4&%S<W=O<F1S('-H;W5L9`HO+R!B92!-1#4@96YC;V1E
M9"P@8G5T(&YO="!D:7-P;&%Y960N"B\O"B\O($E-4$]25$%.5#H@5&AE(&QA
M<W0@<&%R86UE=&5R(&EN('1H97-E(&5X86UP;&5S("@F)&]B:F5C="D@:7,@
M;VYL>0HO+R!P87-S960@8GD@5'5R8F$@,BXQ(&%N9"!L871E<BX@268@>6]U
M(&%R92!U<VEN9R!4=7)B82`R+C`L('1H96X@>6]U"B\O(&UU<W0@<F5M;W9E
M('1H92`F)&]B:F5C="!P87)A;65T97(N"@HO+R!I9B`H(69U;F-T:6]N7V5X
M:7-T<R@G7W1U<F)A7VAO;VM?96YC;V1E7W!A<W-W;W)D)RDI('L*+R\@("`@
M(&9U;F-T:6]N(%]T=7)B85]H;V]K7V5N8V]D95]P87-S=V]R9"@D;F5W7W!A
M<W-W;W)D+"`D;VQD7W!A<W-W;W)D+"`F)&-O;G1A8W0I"B\O("`@("!["B\O
M("`@("`@("`@:68@*&ES7VYU;&PH)&YE=U]P87-S=V]R9"D@?'P@)&YE=U]P
M87-S=V]R9"`]/2`G)R!\?`HO+R`@("`@("`@("`@("`D;F5W7W!A<W-W;W)D
M(#T]("=;3F]T($1I<W!L87EE9%TG*2!["B\O("`@("`@("`@("`@(')E='5R
M;B`D;VQD7W!A<W-W;W)D.PHO+R`@("`@("`@('T@96QS92!["B\O("`@("`@
M("`@("`@(')E='5R;B!M9#4H)&YE=U]P87-S=V]R9"D["B\O("`@("`@("`@
M?0HO+R`@("`@?0HO+R`@("`@9G5N8W1I;VX@7W1U<F)A7VAO;VM?9&5C;V1E
M7W!A<W-W;W)D*"1P87-S=V]R9"P@)B1C;VYT86-T*0HO+R`@("`@>PHO+R`@
M("`@("`@(&EF("AS=')S='(H)%]315)615);)U!(4%]314Q&)UTL("=E9&ET
M;V)J96-T)RDI('L*+R\@("`@("`@("`@("`@<F5T=7)N(&YU;&P["B\O("`@
M("`@("`@?2!E;'-E('L*+R\@("`@("`@("`@("`@<F5T=7)N("=;3F]T($1I
M<W!L87EE9%TG.PHO+R`@("`@("`@('T*+R\@("`@('T*+R\@?0H*+R\@2&5R
M92!I<R!A;B!E>&%M<&QE(%]P87-S=V1?:&]O:U]U<V5R;F%M92!F=6YC=&EO
M;B!T;R!T<F%N<VQA=&4@=VAA="!T:&4*+R\@=7-E<B!E;G1E<G,L(&EN('1H
M92!U<V5R;F%M92!B;W@L(&EN=&\@=VAA="!T:&4@8F%C:V5N9"!E>'!E8W1S
M+B!)9B!W92!W86YT"B\O('1O(&%D9"!`97AA;7!L92YC;VT@=&\@=&AE(&5N
M9"!O9B!T:&4@=7-E<FYA;64@=&AE;B!E;F%B;&4@=&AE(&AO;VL@86YD('5S
M90HO+R!T:&ES(&9U;F-T:6]N+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H
M)U]P87-S=V1?:&]O:U]U<V5R;F%M92<I*2!["B\O("`@("!F=6YC=&EO;B!?
M<&%S<W=D7VAO;VM?=7-E<FYA;64H)'5S97)I9"D*+R\@("`@('L*+R\@("`@
M("`@("!R971U<FX@)'5S97)I9"`N("=`97AA;7!L92YC;VTG.PHO+R`@("`@
M?0HO+R!]"@HO+R!(97)E(&ES(&%N(&5X86UP;&4@7W!A<W-W9%]H;V]K7V1E
M9F%U;'1?=7-E<FYA;64@9G5N8W1I;VX@=&\@<V5T('1H90HO+R!U<V5R;F%M
M92!T:&4@<&%S<W=D(&UO9'5L92!S965S('=H96X@<F5S971T:6YG('!A<W-W
M;W)D<R!B87-E9"!O;B!U<V5R:60*+R\@86YD(')E86QM+B`@5&AE(&1E9F%U
M;'0@:7,@=&\@=&%K92!A('5S97)N86UE(&]F('5S97)`9&]M86EN+G1L9"!A
M;F0@8VAA;F=E"B\O(&ET('1O('5S97(N("!)9B!W92!W86YT('1O(&QE879E
M(&ET('5N=&]U8VAE9"P@96YA8FQE('1H92!H;V]K(&%N9"!U<V4@=&AI<PHO
M+R!F=6YC=&EO;BX*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?<&%S<W=D
M7VAO;VM?9&5F875L=%]U<V5R;F%M92<I*2!["B\O("`@("!F=6YC=&EO;B!?
M<&%S<W=D7VAO;VM?9&5F875L=%]U<V5R;F%M92@D=7-E<FED*0HO+R`@("`@
M>PHO+R`@("`@("`@(')E='5R;B`D=7-E<FED.PHO+R`@("`@?0HO+R!]"@HO
M+R!(97)E(&ES(&%N(&5X86UP;&4@7W!A<W-W9%]H;V]K7W5S97)D;B!F=6YC
M=&EO;B!T:&%T('EO=2!C86X@=7-E('1O('!R;W9I9&4*+R\@>6]U<B!L9&%P
M('-E<G9E<B!W:71H(&$@=7-E<F1N('-O('1H870@>6]U(&1O(&YO="!H879E
M('1O('!E<F9O<FT@86YO;GEM;W5S"B\O(&)I;F1S+B!4:&4@9G5N8W1I;VX@
M=&%K97,@075T:#HZ9V5T075T:"@I(&%S(&$@<&%R86UE=&5R"@HO+R!I9B`H
M(69U;F-T:6]N7V5X:7-T<R@G7W!A<W-W9%]H;V]K7W5S97)D;B<I*2!["B\O
M("`@("!F=6YC=&EO;B!?<&%S<W=D7VAO;VM?=7-E<F1N*"1A=71H*0HO+R`@
M("`@>PHO+R`@("`@("`@(')E='5R;B`G=6ED/2<@+B`D875T:"`N("<L;SUE
M>&%M<&QE+F-O;2<["B\O("`@("!]"B\O('T*"B\O(%1H:7,@:7,@86X@97AA
M;7!L92!O9B!A(&AO;VL@=&\@<V5T(&-U<W1O;2!T86=S('1O(&)E(&EN8VQU
M9&5D(&EN(&$@1VEA<&5T;PHO+R!P86=E('1E;7!L871E+B!);B!T:&ES(&5X
M86UP;&4@82!T86<@8V]N=&%I;FEN9R!T:&4@8W5R<F5N="!D871E(&ES('-E
M="!T;PHO+R!T:&4@)'1E;7!L871E(&]B:F5C="!A;F0@=VAI8V@@:7,@=&AE
M;B!A=F%I;&%B;&4@:6X@=&AE('!A9V4@=&5M<&QA=&4@87,Z"B\O("`@("`\
M=&%G.F1A=&4@+SX*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?9VEA<&5T
M;U]H;V]K7W-E='1A9W,G*2D@>PHO+R`@("`@9G5N8W1I;VX@7V=I87!E=&]?
M:&]O:U]S971T86=S*"8D=&5M<&QA=&4I"B\O("`@("!["B\O("`@("`@("`@
M)'1E;7!L871E+3YS970H)V1A=&4G+"!S=')F=&EM92@G)6$L("5E("5B("59
M)RDI.PHO+R`@("`@?0HO+R!]"@HO+R!4:&ES(&ES(&%N(&5X86UP;&4@;V8@
M82!G<F]U<"!H;V]K+B`@5&\@=7-E(&ET('EO=2!M=7-T('-E="!T:&4@9W)O
M=7`*+R\@9')I=F5R('1O(&AO;VMS(&EN(&-O;F8N<&AP+B`@5&AE;B!Y;W4@
M;75S="!C<F5A=&4@82!)5%]D97!A<G1M96YT(&=R;W5P"B\O("AB96-A=7-E
M('1H870@:7,@:&]W('=E(&MN;W<@=VAA="!H;V]K('1O(&-A;&PI+B`@66]U
M(&-A;B!A9&0@=7-E<G,@=&\@=&AE"B\O(&=R;W5P(&%S(&YO<FUA;"P@86YD
M(&EN(&%D9&ET:6]N('1H:7,@9G5N8W1I;VX@=VEL;"!B92!C86QL960@=&\*
M+R\@9'EN86UI8V%L;'D@:6YC;'5D92!U<V5R<R!I;B!T:&4@9W)O=7`N("!)
M;B!T:&ES(&5X86UP;&4@=V4@=VEL;"!L;V]K('5P"B\O('=H971H97(@;W(@
M;F]T('1H:7,@=7-E<B!I<R!P87)T(&]F('1H92!)5"!D97!A<G1M96YT('5S
M:6YG(&%N(&5X=&5R;F%L"B\O(&1A=&%B87-E+@H*+R\@1&5F875L="!+;VQA
M8B!H;V]K<SH*:68@*"%E;7!T>2@D1TQ/0D%,4ULG8V]N9B==6R=K;VQA8B==
M6R=E;F%B;&5D)UTI*2!["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TMO;&%B
M+G!H<"<["B`@("!I9B`H(69U;F-T:6]N7V5X:7-T<R@G7VAO<F1E7VAO;VM?
M<VAA<F5?:6YI="<I*2!["B`@("`@("`@9G5N8W1I;VX@7W5S97)N86UE7VAO
M;VM?9G)O;6)A8VME;F0H)'5S97))1"D*("`@("`@("!["B`@("`@("`@("`@
M("\O($-O;FYE8W0@=&\@=&AE($Q$05`@<V5R=F5R+@H@("`@("`@("`@("`D
M9',@/2!L9&%P7V-O;FYE8W0H"B`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG
M8V]N9B==6R=K;VQA8B==6R=L9&%P)UU;)W-E<G9E<B==+`H@("`@("`@("`@
M("`@("`@)$=,3T)!3%-;)V-O;F8G75LG:V]L86(G75LG;&1A<"==6R=P;W)T
M)UT*("`@("`@("`@("`@*3L*("`@("`@("`@("`@:68@*"$D9',I('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D=7-E<DE$.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&QD87!?<V5T7V]P=&EO;B@D9',L($Q$05!?3U!47U!23U1/
M0T],7U9%4E-)3TXL(#,I.PH@("`@("`@("`@("`O+R!":6YD(&%N;VYY;6]U
M<VQY+@H@("`@("`@("`@("`D<F5S=6QT(#T@0&QD87!?8FEN9"@D9',I.PH@
M("`@("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D=7-E<DE$.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("\O($9I
M;F0@=&AE('5S97(G<R!$3BX*("`@("`@("`@("`@)')E<W5L="`](&QD87!?
M<V5A<F-H*`H@("`@("`@("`@("`@("`@)&1S+`H@("`@("`@("`@("`@("`@
M)$=,3T)!3%-;)V-O;F8G75LG:V]L86(G75LG;&1A<"==6R=B87-E9&XG72P*
M("`@("`@("`@("`@("`@("=U:60])R`N("1U<V5R240*("`@("`@("`@("`@
M*3L*("`@("`@("`@("`@)&5N=')Y(#T@;&1A<%]F:7)S=%]E;G1R>2@D9',L
M("1R97-U;'0I.PH@("`@("`@("`@("!I9B`H)&5N=')Y(#T]/2!F86QS92D@
M>PH@("`@("`@("`@("`@("`@+R\@5&AE('5S97(@86QR96%D>2!A=71H96YT
M:6-A=&5D('=I=&@@:&ES(&5M86EL(&%D9')E<W,N"B`@("`@("`@("`@("`@
M("!R971U<FX@)'5S97))1#L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M96UA:6P@/2!L9&%P7V=E=%]V86QU97,H)&1S+"`D96YT<GDL("=M86EL)RD[
M"B`@("`@("`@("`@(')E='5R;B`D96UA:6Q;,%T["B`@("`@("`@?0H@("`@
M("`@(&9U;F-T:6]N(%]H;W)D95]H;V]K7W-H87)E7VEN:70H)B1S:&%R95]O
M8FIE8W0L("1A<'`I"B`@("`@("`@>PH@("`@("`@("`@("!+;VQA8CHZ<WEN
M8VAR;VYI<V53:&%R97,H)'-H87)E7V]B:F5C="P@)&%P<"D["B`@("`@("`@
M?0H@("`@("`@(&9U;F-T:6]N(%]H;W)D95]H;V]K7W-H87)E7V%D9"@F)'-H
M87)E*0H@("`@("`@('L*("`@("`@("`@("`@<F5T=7)N($MO;&%B.CIU<&1A
M=&53:&%R92@D<VAA<F4I.PH@("`@("`@('T*("`@("`@("!F=6YC=&EO;B!?
M:&]R9&5?:&]O:U]S:&%R95]M;V1I9GDH)B1S:&%R92D*("`@("`@("!["B`@
M("`@("`@("`@(')E='5R;B!+;VQA8CHZ=7!D871E4VAA<F4H)'-H87)E*3L*
M("`@("`@("!]"B`@("`@("`@9G5N8W1I;VX@7VAO<F1E7VAO;VM?<VAA<F5?
M<F5M;W9E*"8D<VAA<F4I"B`@("`@("`@>PH@("`@("`@("`@("!R971U<FX@
M2V]L86(Z.G)E;6]V95-H87)E*"1S:&%R92D["B`@("`@("`@?0H@("`@("`@
M(&9U;F-T:6]N(%]I;7!?:&]O:U]M8F]X7W)E9&ER96-T*"1M86EL8F]X*0H@
M("`@("`@('L*("`@("`@("`@("`@<W=I=&-H("A+;VQA8CHZ9V5T36%I;&)O
M>%1Y<&4H)&UA:6QB;W@I*2!["B`@("`@("`@("`@(&-A<V4@)V5V96YT)SH*
M("`@("`@("`@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^
M9V5T*"=W96)R;V]T)RP@)VMR;VYO;&ET:"<I.PH*("`@("`@("`@("`@8V%S
M92`G=&%S:R<Z"B`@("`@("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;)W)E
M9VES=')Y)UTM/F=E="@G=V5B<F]O="<L("=N86<G*3L*"B`@("`@("`@("`@
M(&-A<V4@)VYO=&4G.@H@("`@("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q3
M6R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G;6YE;6\G*3L*"B`@("`@
M("`@("`@(&-A<V4@)V-O;G1A8W0G.@H@("`@("`@("`@("`@("`@<F5T=7)N
M("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G='5R8F$G
M*3L*"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!R971U
M<FX@)R<["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@9G5N8W1I
M;VX@7VEM<%]H;V]K7VUB;WA?:6-O;G,H*0H@("`@("`@('L*("`@("`@("`@
M("`@<W1A=&EC("1I8V]N<SL*"B`@("`@("`@("`@(&EF("@A96UP='DH)&EC
M;VYS*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1I8V]N<SL*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)&9O;&1E<G,@/2!+;VQA8CHZ;&ES=$9O
M;&1E<G,H*3L*"B`@("`@("`@("`@("1I8V]N<R`](&%R<F%Y*"D["@H@("`@
M("`@("`@("!F;W)E86-H("@D9F]L9&5R<R!A<R`D9F]L9&5R*2!["B`@("`@
M("`@("`@("`@("`D;F%M92`]('!R96=?<F5P;&%C92@G+UY[6UY]72M]+R<L
M("<G+"`D9F]L9&5R6S!=*3L*"B`@("`@("`@("`@("`@("!S=VET8V@@*"1F
M;VQD97);,5TI('L*("`@("`@("`@("`@("`@(&-A<V4@)V5V96YT)SH*("`@
M("`@("`@("`@("`@("`@("`D:6-O;G-;)&YA;65=(#T@2&]R9&4Z.FEM9R@*
M("`@("`@("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)W)E9VES=')Y)UTM
M/F=E="@G:6-O;B<L("=K<F]N;VQI=&@G*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@7R@B0V%L96YD87(B*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M)W=I9'1H/2(Q-B(@:&5I9VAT/2(Q-B(@<W1Y;&4](G9E<G1I8V%L+6%L:6=N
M.FUI9&1L92(G+`H@("`@("`@("`@("`@("`@("`@("`@("`G)PH@("`@("`@
M("`@("`@("`@("`@("D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("`@("`@8V%S92`G=&%S:R<Z"B`@("`@("`@("`@("`@("`@
M("`@)&EC;VYS6R1N86UE72`]($AO<F1E.CII;6<H"B`@("`@("`@("`@("`@
M("`@("`@("`@("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)VEC;VXG+"`G
M;F%G)RDL"B`@("`@("`@("`@("`@("`@("`@("`@(%\H(E1A<VMS(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("=W:61T:#TB,38B(&AE:6=H=#TB,38B
M('-T>6QE/2)V97)T:6-A;"UA;&EG;CIM:61D;&4B)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@)R<*("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)VYO
M=&4G.@H@("`@("`@("`@("`@("`@("`@("1I8V]N<ULD;F%M95T@/2!(;W)D
M93HZ:6UG*`H@("`@("`@("`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG<F5G
M:7-T<GDG72T^9V5T*"=I8V]N)RP@)VUN96UO)RDL"B`@("`@("`@("`@("`@
M("`@("`@("`@(%\H(DYO=&5S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("=W:61T:#TB,38B(&AE:6=H=#TB,38B('-T>6QE/2)V97)T:6-A;"UA;&EG
M;CIM:61D;&4B)RP*("`@("`@("`@("`@("`@("`@("`@("`@)R<*("`@("`@
M("`@("`@("`@("`@("`I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@("`@(&-A<V4@)V-O;G1A8W0G.@H@("`@("`@("`@("`@
M("`@("`@("1I8V]N<ULD;F%M95T@/2!(;W)D93HZ:6UG*`H@("`@("`@("`@
M("`@("`@("`@("`@("`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=I8V]N
M)RP@)W1U<F)A)RDL"B`@("`@("`@("`@("`@("`@("`@("`@(%\H(D-O;G1A
M8W1S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("=W:61T:#TB,38B(&AE
M:6=H=#TB,38B('-T>6QE/2)V97)T:6-A;"UA;&EG;CIM:61D;&4B)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@)R<*("`@("`@("`@("`@("`@("`@("`I
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!R971U<FX@)&EC;VYS.PH@
M("`@("`@('T*("`@('T*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O:&]R9&4O;6EM
M95]D<FEV97)S+G!H<```````````````````````````````````````````
M`````````````````````#`P,#`T-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#,V-3,W`#$P-3$U-#,S-S<T`#`R,C<T-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H
M;W)D92]C;VYF:6<O;6EM95]D<FEV97)S+G!H<"YD:7-T+'8@,2XY-RXV+CD@
M,C`P-B\P-"\P-B`R,3HS,CHQ-"!J86X@17AP("0*("H*("H@1&5C:61E('=H
M:6-H(&]U='!U="!D<FEV97)S('EO=2!W86YT('1O(&%C=&EV871E(&9O<B!A
M;&P@2&]R9&4*("H@87!P;&EC871I;VYS+B!);F1I=FED=6%L($AO<F1E(&%P
M<&QI8V%T:6]N<R!C86X@;W9E<G)I9&4@=&AE<V4@<V5T=&EN9W,*("H@:6X@
M=&AE:7(@8V]N9FEG+VUI;65?9')I=F5R<RYP:'`@9FEL97,N"B`J"B`J(%1H
M92!A=F%I;&%B;&4@9')I=F5R<R!A<F4Z"B`J("TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM"B`J(&-S<R`@("`@("`@("`@($-34R!3='EL97,*("H@9&5B
M("`@("`@("`@("`@1&5B:6%N('!A8VMA9V5S"B`J(&5N<FEC:&5D("`@("`@
M($5N<FEC:&5D('1E>'0@9F]R;6%T"B`J(&5N<V-R:7!T("`@("`@($=.52!E
M;G-C<FEP=`H@*B!H=&UL("`@("`@("`@("!(5$U,(&1A=&$*("H@:6UA9V5S
M("`@("`@("`@26UA9V4@9FEL97,*("H@;7-W;W)D("`@("`@("`@36EC<F]S
M;V9T(%=O<F0@9FEL97,@=FEA('=V2'1M;`H@*B!M<V5X8V5L("`@("`@("!-
M:6-R;W-O9G0@17AC96P@9FEL97,@=FEA('AL:'1M;`H@*B!M<W!O=V5R<&]I
M;G0@("!-:6-R;W-O9G0@4&]W97)P;VEN="!F:6QE<R!V:6$@<'!T:'1M;`H@
M*B!O;V\@("`@("`@("`@("!/<&5N3V9F:6-E+F]R9R]3=&%R3V9F:6-E($1O
M8W5M96YT<PH@*B!P9&8@("`@("`@("`@("!0;W)T86)L92!$;V-U;65N="!&
M;W)M870@*%!$1BD@9FEL97,*("H@<&AP("`@("`@("`@("`@5&AE(&EN=&5R
M;F%L(%!(4#0@<WEN=&%X(&AI9VAL:6=H=&EN9R!E;F=I;F4*("H@<&QA:6X@
M("`@("`@("`@4F5T=7)N('1E>'0L('=I=&@@;&EN:W,@;6%D92!C;&EC:V%B
M;&4@86YD(&]T:&5R($A434P*("H@("`@("`@("`@("`@("`@9FEL=&5R960@
M;W5T"B`J(')A<B`@("`@("`@("`@(%)!4B!A<F-H:79E<PH@*B!R97!O<G0@
M("`@("`@("!297!O<G0@;65S<V%G97,@*%)&0R`S-#4R*0H@*B!R9F,X,C(@
M("`@("`@("!$:6=E<W1E9"!M97-S86=E<R`H4D9#(#(P-#8@6S4N,BXQ72D*
M("H@<FEC:'1E>'0@("`@("`@4FEC:'1E>'0@=&5X="!F;W)M870@*%)&0R`Q
M,S0Q(%LW+C$N,UTI"B`J(')P;2`@("`@("`@("`@(%)032!P86-K86=E<PH@
M*B!S96-U<FET>2`@("`@("!396-U<F4@;75L=&EP87)T<R`H4D9#(#$X-#<I
M"B`J('-I;7!L92`@("`@("`@($]U='!U="!T97AT('=I=&AO=70@;6]D:69I
M8V%T:6]N"B`J('-R8VAI9VAL:71E("`@(%-O=7)C92!(:6=H;&EG:'0*("H@
M=&=Z("`@("`@("`@("`@5&%R8F%L;',L(&EN8VQU9&EN9R!G>FEP<&5D(&]N
M97,*("H@=&YE9B`@("`@("`@("`@35,M5$Y%1B!A='1A8VAM96YT<PH@*B!V
M8V%R9"`@("`@("`@("!V0V%R9',*("H@=V5B8W!P("`@("`@("`@5V5B($,@
M4&QU<R!0;'5S"B`J('II<"`@("`@("`@("`@(%II<"!F:6QE<PH@*B\*)&UI
M;65?9')I=F5R<U]M87!;)VAO<F1E)UU;)W)E9VES=&5R960G72`](&%R<F%Y
M*`H@("`@)V-S<R<L("=E;G)I8VAE9"<L("=H=&UL)RP@)VEM86=E<R<L("=O
M;V\G+"`G<&1F)RP@)W!H<"<L("=P;&%I;B<L("=R87(G+`H@("`@)W)E<&]R
M="<L("=R9F,X,C(G+"`G<FEC:'1E>'0G+"`G<V5C=7)I='DG+"`G<VEM<&QE
M)RP@)W1G>B<L("=T;F5F)RP*("`@("=V8V%R9"<L("=Z:7`G+`H@("`@+R\@
M5&AE(&9O;&QO=VEN9R!M:6UE(&1R:79E<G,@<F5Q=6ER92!E>'1E<FYA;"!A
M<'!L:6-A=&EO;G,@=&\@8F4*("`@("\O(&EN<W1A;&QE9"X*("`@("\O("=D
M96(G+"`G96YS8W)I<'0G+"`G;7-W;W)D)RP@)VUS97AC96PG+"`G;7-P;W=E
M<G!O:6YT)RP@)W)P;2<L"B`@("`O+R`G<W)C:&EG:&QI=&4G+"`G=V5B8W!P
M)PHI.PH*"B\J*@H@*B!)9B!Y;W4@=V%N="!T;R!S<&5C:69I8V%L;'D@;W9E
M<G)I9&4@86YY($U)344@='EP92!T;R!B92!H86YD;&5D(&)Y"B`J(&$@<W!E
M8VEF:6,@9')I=F5R+"!T:&5N(&5N=&5R(&ET(&AE<F4N("!.;W)M86QL>2P@
M=&AI<R!I<R!S869E('1O"B`J(&QE879E+"!B=70@:70G<R!U<V5F=6P@=VAE
M;B!M=6QT:7!L92!D<FEV97)S(&AA;F1L92!T:&4@<V%M92!-24U%"B`J('1Y
M<&4L(&%N9"!Y;W4@=V%N="!T;R!S<&5C:69Y(&5X86-T;'D@=VAI8V@@;VYE
M('-H;W5L9"!H86YD;&4@:70N"B`J+PHD;6EM95]D<FEV97)S7VUA<%LG:&]R
M9&4G75LG;W9E<G)I9&5S)UT@/2!A<G)A>2@I.PH*"B\J*@H@*B!$<FEV97(@
M<W!E8VEF:6,@<V5T=&EN9W,N($AE<F4L('EO=2!H879E('1O(&-O;F9I9W5R
M92!E86-H(&1R:79E<@H@*B!W:&EC:"!Y;W4@8VAO<V4@=&\@86-T:79A=&4@
M86)O=F4N($1E9F%U;'0@<V5T=&EN9W,@:&%V92!B965N"B`J(&9I;&QE9"!I
M;B!F;W(@=&AE;2P@86YD(&EF('EO=2!H879E;B=T(&%C=&EV871E9"!I="P@
M=&AE;B!J=7-T"B`J(&QE879E(&ET(&%S(&ET(&ES("T@:70@=V]N)W0@9V5T
M(&QO861E9"X*("H*("H@5&AE("=H86YD;&5S)R!S971T:6YG(&)E;&]W('-H
M;W5L9&XG="!B92!C:&%N9V5D(&EN(&UO<W0*("H@8VER8W5M<W1A;F-E<RX@
M270@<F5G:7-T97)S(&$@<V5T(&]F($U)344@='EP92!T:&%T('1H92!D<FEV
M97(@8V%N"B`J(&AA;F1L92X@5&AE("=X+65X=&5N<VEO;B<@34E-12!T>7!E
M(&ES(&$@<W!E8VEA;"!O;F4@=&\@2&]R9&4@=&AA=`H@*B!M87!S(&$@9FEL
M92!E>'1E;G-I;VX@=&\@82!-24U%('1Y<&4N($ET)W,@=7-E9G5L('=H96X@
M>6]U(&MN;W<*("H@=&AA="!A;&P@9FEL97,@96YD:6YG(&EN("<N8R<@87)E
M($,@9FEL97,L(&9O<B!E>&%M<&QE+B!9;W4@8V%N('-E=`H@*B!T:&4@34E-
M12!S=6)T>7!E('1O("<J)R!T;R!M871C:"!A;&P@<&]S<VEB;&4@<W5B='EP
M97,*("H@*&DN92X@)VEM86=E+RHG*2X*("H*("H@5&AE("=I8V]N<R<@96YT
M<GD@:7,@9F]R('1H92!D<FEV97(@=&\@<F5G:7-T97(@=F%R:6]U<R!I8V]N
M<R!F;W(*("H@=&AE($U)344@='EP97,@:70@:&%N9&QE<RX@5&AE(&%R<F%Y
M(&-O;G-I<W1S(&]F(&$@)V1E9F%U;'0G(&EC;VX*("H@9F]R('1H870@9')I
M=F5R+"!A;F0@8V%N(&%L<V\@:6YC;'5D92!S<&5C:69I8R!-24U%+71Y<&5S
M('=H:6-H(&-A;@H@*B!H879E('1H96ER(&]W;B!I8V]N<RX@66]U(&-A;B!S
M970@=&AE($U)344@<W5B='EP92!T;R`G*B<@=&\@;6%T8V@*("H@86QL('!O
M<W-I8FQE('-U8G1Y<&5S("AI+F4N("=I;6%G92\J)RDN"B`J+PH*+RHJ"B`J
M($1E9F%U;'0@9')I=F5R('-E='1I;F=S"B`J+PHD;6EM95]D<FEV97)S6R=H
M;W)D92==6R=D969A=6QT)UU;)VEC;VYS)UT@/2!A<G)A>2@*("`@("=D969A
M=6QT)R`@("`@("`@("`@("`@("`@("`@("`@/3X@)W1E>'0N<&YG)RP*("`@
M("=A=61I;R\J)R`@("`@("`@("`@("`@("`@("`@("`@/3X@)V%U9&EO+G!N
M9R<L"B`@("`G;65S<V%G92\J)R`@("`@("`@("`@("`@("`@("`@(#T^("=M
M86EL+G!N9R<L"B`@("`G=6YK;F]W;B\J)R`@("`@("`@("`@("`@("`@("`@
M(#T^("=B:6YA<GDN<&YG)RP*("`@("=V:61E;R\J)R`@("`@("`@("`@("`@
M("`@("`@("`@/3X@)W9I9&5O+G!N9R<L"B`@("`G87!P;&EC871I;VXO<&=P
M+7-I9VYA='5R92<@("`@(#T^("=E;F-R>7!T:6]N+G!N9R<L"B`@("`G87!P
M;&EC871I;VXO>"UP:V-S-RUS:6=N871U<F4G(#T^("=E;F-R>7!T:6]N+G!N
M9R<L"B`@("`G87!P;&EC871I;VXO;V-T970M<W1R96%M)R`@("`@(#T^("=B
M:6YA<GDN<&YG)RD["@H*+RHJ"B`J($1E9F%U;'0@=&5X="!D<FEV97(@<V5T
M=&EN9W,*("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W-I;7!L92==6R=I
M;FQI;F4G72`]('1R=64["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W-I;7!L
M92==6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@("=T97AT+RHG*3L*)&UI;65?
M9')I=F5R<ULG:&]R9&4G75LG<VEM<&QE)UU;)VEC;VYS)UT@/2!A<G)A>2@*
M("`@("=D969A=6QT)R`]/B`G=&5X="YP;F<G*3L*"@HO*BH*("H@4&QA:6X@
M=&5X="!D<FEV97(@<V5T=&EN9W,*("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E
M)UU;)W!L86EN)UU;)VEN;&EN92==(#T@=')U93L*)&UI;65?9')I=F5R<ULG
M:&]R9&4G75LG<&QA:6XG75LG:&%N9&QE<R==(#T@87)R87DH"B`@("`G=&5X
M="]P;&%I;B<I.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=P;&%I;B==6R=I
M8V]N<R==(#T@87)R87DH"B`@("`G9&5F875L="<@/3X@)W1E>'0N<&YG)RD[
M"@H*+RHJ"B`J(%!(4"!D<FEV97(@<V5T=&EN9W,*("HO"B1M:6UE7V1R:79E
M<G-;)VAO<F1E)UU;)W!H<"==6R=I;FQI;F4G72`]('1R=64["B1M:6UE7V1R
M:79E<G-;)VAO<F1E)UU;)W!H<"==6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@
M("=A<'!L:6-A=&EO;B]X+7!H<"<L("=X+65X=&5N<VEO;B]P:'!S)RP*("`@
M("=X+65X=&5N<VEO;B]P:'`S<R<L("=A<'!L:6-A=&EO;B]X+6AT='!D+7!H
M<"<L"B`@("`G87!P;&EC871I;VXO>"UH='1P9"UP:'`S)RP@)V%P<&QI8V%T
M:6]N+W@M:'1T<&0M<&AP<R<I.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=P
M:'`G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G(#T^("=P:'`N
M<&YG)RD["@H*+RHJ"B`J($-34R!D<FEV97(@<V5T=&EN9W,*("HO"B1M:6UE
M7V1R:79E<G-;)VAO<F1E)UU;)V-S<R==6R=I;FQI;F4G72`]('1R=64["B1M
M:6UE7V1R:79E<G-;)VAO<F1E)UU;)V-S<R==6R=H86YD;&5S)UT@/2!A<G)A
M>2@*("`@("=T97AT+V-S<R<L("=X+65X=&5N<VEO;B]C<W,G*3L*)&UI;65?
M9')I=F5R<ULG:&]R9&4G75LG8W-S)UU;)VEC;VYS)UT@/2!A<G)A>2@*("`@
M("=D969A=6QT)R`]/B`G:'1M;"YP;F<G*3L*"@HO*BH*("H@16YR:6-H960@
M=&5X="!D<FEV97(@<V5T=&EN9W,*("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E
M)UU;)VAT;6PG75LG:6YL:6YE)UT@/2!F86QS93L*)&UI;65?9')I=F5R<ULG
M:&]R9&4G75LG:'1M;"==6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@("=T97AT
M+VAT;6PG*3L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG:'1M;"==6R=I8V]N
M<R==(#T@87)R87DH"B`@("`G9&5F875L="<@/3X@)VAT;6PN<&YG)RD["@H*
M+RHJ"B`J($5N<FEC:&5D('1E>'0@9')I=F5R('-E='1I;F=S"B`J+PHD;6EM
M95]D<FEV97)S6R=H;W)D92==6R=E;G)I8VAE9"==6R=I;FQI;F4G72`]('1R
M=64["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)V5N<FEC:&5D)UU;)VAA;F1L
M97,G72`](&%R<F%Y*`H@("`@)W1E>'0O96YR:6-H960G*3L*)&UI;65?9')I
M=F5R<ULG:&]R9&4G75LG96YR:6-H960G75LG:6-O;G,G72`](&%R<F%Y*`H@
M("`@)V1E9F%U;'0G(#T^("=T97AT+G!N9R<I.PH*"B\J*@H@*B!2:6-H=&5X
M="!T97AT(&1R:79E<B!S971T:6YG<PH@*B\*)&UI;65?9')I=F5R<ULG:&]R
M9&4G75LG<FEC:'1E>'0G75LG:6YL:6YE)UT@/2!T<G5E.PHD;6EM95]D<FEV
M97)S6R=H;W)D92==6R=R:6-H=&5X="==6R=H86YD;&5S)UT@/2!A<G)A>2@*
M("`@("=T97AT+W)I8VAT97AT)RD["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;
M)W)I8VAT97AT)UU;)VEC;VYS)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`]
M/B`G=&5X="YP;F<G*3L*"@HO*BH*("H@5V5B($,@4&QU<R!0;'5S(&1R:79E
M<B!S971T:6YG<PH@*B!H='1P.B\O=V5B8W!P+G-O=7)C969O<F=E+FYE="\*
M("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W=E8F-P<"==6R=L;V-A=&EO
M;B==(#T@)R]U<W(O8FEN+W=E8F-P<"<["B1M:6UE7V1R:79E<G-;)VAO<F1E
M)UU;)W=E8F-P<"==6R=I;FQI;F4G72`]('1R=64["B1M:6UE7V1R:79E<G-;
M)VAO<F1E)UU;)W=E8F-P<"==6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@("=T
M97AT+WAM;"<L("=T97AT+W-G;6PG+"`G87!P;&EC871I;VXO>&UL)RP*("`@
M("=A<'!L:6-A=&EO;B]X+7-H)RP@)V%P<&QI8V%T:6]N+W@M:F%V87-C<FEP
M="<L("=A<'!L:6-A=&EO;B]X+71C;"<L"B`@("`G>"UE>'1E;G-I;VXO87-M
M)RP@)V%P<&QI8V%T:6]N+W@M87-P)RP@)W@M97AT96YS:6]N+V)A<R<L"B`@
M("`G>"UE>'1E;G-I;VXO8W,G+"`G=&5X="]X+6-S<F,G+"`G>"UE>'1E;G-I
M;VXO<F,G+`H@("`@)W1E>'0O>"UC*RMS<F,G+"`G=&5X="]X+6,K*W-R8R<L
M("=T97AT+W@M8RLK<W)C)RP*("`@("=T97AT+W@M8VAD<B<L("=X+65X=&5N
M<VEO;B]B870G+"`G=&5X="]X+69O<G1R86XG+`H@("`@)W@M97AT96YS:6]N
M+V8W-R<L("=X+65X=&5N<VEO;B]F.3`G+"`G>"UE>'1E;G-I;VXO9F]R)RP*
M("`@("=X+65X=&5N<VEO;B]F=&XG+"`G=&5X="]X+6IA=F$G+"`G87!P;&EC
M871I;VXO>"UJ879A<V-R:7!T)RP*("`@("=T97AT+W-G;6PG+"`G=&5X="]X
M;6PG+"`G=&5X="]X+7!A<V-A;"<L"B`@("`G87!P;&EC871I;VXO>"UC9VDG
M+"`G87!P;&EC871I;VXO>"UP97)L)RP@)V%P<&QI8V%T:6]N+W@M<'ET:&]N
M)RP*("`@("=T97AT+W@M<W%L)RP@)W1E>'0O>"UT8VPG+`H@("`@)V%P<&QI
M8V%T:6]N+W@M<VAE;&QS8W)I<'0G+"`G>"UE>'1E;G-I;VXO=FAD)RP@)W@M
M97AT96YS:6]N+W9H9&PG*3L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG=V5B
M8W!P)UU;)VEC;VYS)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`@("`@("`@
M("`@("`@("`@(#T^("=T97AT+G!N9R<L"B`@("`G=&5X="]X;6PG("`@("`@
M("`@("`@("`@("`]/B`G>&UL+G!N9R<L"B`@("`G=&5X="]X+6-S<F,G("`@
M("`@("`@("`@("`]/B`G<V]U<F-E+6,N<&YG)RP*("`@("=T97AT+W@M8VAD
M<B<@("`@("`@("`@("`@(#T^("=S;W5R8V4M:"YP;F<G+`H@("`@)W1E>'0O
M>"UJ879A)R`@("`@("`@("`@("`@/3X@)W-O=7)C92UJ879A+G!N9R<L"B`@
M("`G87!P;&EC871I;VXO>"UJ879A<V-R:7!T)R`]/B`G<V-R:7!T+6IS+G!N
M9R<I.PH*+RHJ"B`J(%-O=7)C92U(:6=H;&EG:'0@9')I=F5R('-E='1I;F=S
M"B`J(&AT='`Z+R]W=W<N9VYU+F]R9R]S;V9T=V%R92]S<F,M:&EG:&QI=&4O
M"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=S<F-H:6=H;&ET92==6R=L
M;V-A=&EO;B==(#T@)R]U<W(O8FEN+W-O=7)C92UH:6=H;&EG:'0G.PHD;6EM
M95]D<FEV97)S6R=H;W)D92==6R=S<F-H:6=H;&ET92==6R=I;FQI;F4G72`]
M('1R=64["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W-R8VAI9VAL:71E)UU;
M)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)W1E>'0O>"UC<W)C)RP@)W1E>'0O
M>"UC*RMS<F,G+"`G=&5X="]X+6IA=F$G+`H@("`@)V%P<&QI8V%T:6]N+W@M
M<&5R;"<L("=A<'!L:6-A=&EO;B]X+7!Y=&AO;B<L("=T97AT+W@M8RLK<W)C
M)RP*("`@("=T97AT+V-P<"<I.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=S
M<F-H:6=H;&ET92==6R=I8V]N<R==(#T@87)R87DH"B`@("`G9&5F875L="<@
M("`@("`@("`@("`@("`@("`]/B`G=&5X="YP;F<G+`H@("`@)W1E>'0O>"UC
M<W)C)R`@("`@("`@("`@("`@/3X@)W-O=7)C92UC+G!N9R<L"B`@("`G=&5X
M="]X+6,K*W-R8R<@("`@("`@("`@("`]/B`G<V]U<F-E+6,N<&YG)RP*("`@
M("=T97AT+V-P<"<@("`@("`@("`@("`@("`@(#T^("=S;W5R8V4M8RYP;F<G
M+`H@("`@)W1E>'0O>"UJ879A)R`@("`@("`@("`@("`@/3X@)W-O=7)C92UJ
M879A+G!N9R<I.PH*+RHJ"B`J($=.52!%;G-C<FEP="!D<FEV97(@<V5T=&EN
M9W,*("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)V5N<V-R:7!T)UU;)VQO
M8V%T:6]N)UT@/2`G+W5S<B]B:6XO96YS8W)I<'0G.PHD;6EM95]D<FEV97)S
M6R=H;W)D92==6R=E;G-C<FEP="==6R=I;FQI;F4G72`]('1R=64["B1M:6UE
M7V1R:79E<G-;)VAO<F1E)UU;)V5N<V-R:7!T)UU;)VAA;F1L97,G72`](&%R
M<F%Y*`H@("`@)V%P<&QI8V%T:6]N+W@M8V=I)RP@)V%P<&QI8V%T:6]N+W@M
M<VAE;&QS8W)I<'0G+"`G87!P;&EC871I;VXO>"UJ879A<V-R:7!T)RP*("`@
M("=A<'!L:6-A=&EO;B]X+7!E<FPG+"`G87!P;&EC871I;VXO>&UL)RP@)W1E
M>'0O>&UL)RP*("`@("=T97AT+V1I9F8G+"`G=&5X="]X+61I9F8G+"`G=&5X
M="]X+7!A=&-H)RP@)W1E>'0O>"UC<W)C)RP*("`@("=X+65X=&5N<VEO;B]C
M<R<L("=T97AT+W@M:F%V82<L("=T97AT+W@M8VAD<B<L("=T97AT+W@M8RLK
M<W)C)RP*("`@("=T97AT+W@M8RLK:&1R)RP@)W@M97AT96YS:6]N+W9H9"<L
M("=X+65X=&5N<VEO;B]V:&1L)RP@)W1E>'0O>"US<6PG+`H@("`@)W@M97AT
M96YS:6]N+W9B)RP@)W@M97AT96YS:6]N+W9B82<L("=T97AT+W@M96UA8W,M
M;&ES<"<L("=T97AT+W@M=&5X)RD["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;
M)V5N<V-R:7!T)UU;)VEC;VYS)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`@
M("`@("`@("`@("`@("`@(#T^("=T97AT+G!N9R<L"B`@("`G=&5X="]X;6PG
M("`@("`@("`@("`@("`@("`]/B`G>&UL+G!N9R<L"B`@("`G87!P;&EC871I
M;VXO>&UL)R`@("`@("`@("`]/B`G>&UL+G!N9R<L"B`@("`G=&5X="]X+6-S
M<F,G("`@("`@("`@("`@("`]/B`G<V]U<F-E+6,N<&YG)RP*("`@("=T97AT
M+W@M8VAD<B<@("`@("`@("`@("`@(#T^("=S;W5R8V4M:"YP;F<G+`H@("`@
M)W1E>'0O>"UJ879A)R`@("`@("`@("`@("`@/3X@)W-O=7)C92UJ879A+G!N
M9R<L"B`@("`G87!P;&EC871I;VXO>"UJ879A<V-R:7!T)R`]/B`G<V-R:7!T
M+6IS+G!N9R<I.PH*"B\J*@H@*B!487(@9')I=F5R('-E='1I;F=S"B`J(%1O
M(&%C8V5S<R!G>FEP<&5D(&9I;&5S+"!T:&4@>FQI8B!L:6)R87)Y(&UU<W0@
M:&%V92!B965N(&)U:6QT(&EN=&\@4$A0"B`J("AW:71H('1H92`M+7=I=&@M
M>FQI8B!O<'1I;VXI+@H@*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG=&=Z
M)UU;)VEN;&EN92==(#T@=')U93L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG
M=&=Z)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)V%P<&QI8V%T:6]N+W@M
M8V]M<')E<W-E9"UT87(G+`H@("`@)V%P<&QI8V%T:6]N+W@M=&%R)RP*("`@
M("=A<'!L:6-A=&EO;B]X+71G>B<L"B`@("`G87!P;&EC871I;VXO>"UG>FEP
M)RP*("`@("=A<'!L:6-A=&EO;B]X+6=T87(G+`H@("`@)V%P<&QI8V%T:6]N
M+V=Z:7`G+`H@("`@)V%P<&QI8V%T:6]N+W@M9WII<"UC;VUP<F5S<V5D)RD[
M"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W1G>B==6R=I8V]N<R==(#T@87)R
M87DH"B`@("`G9&5F875L="<@/3X@)V-O;7!R97-S960N<&YG)RD["@H*+RHJ
M"B`J(%II<"!F:6QE(&1R:79E<B!S971T:6YG<PH@*B\*)&UI;65?9')I=F5R
M<ULG:&]R9&4G75LG>FEP)UU;)VEN;&EN92==(#T@=')U93L*)&UI;65?9')I
M=F5R<ULG:&]R9&4G75LG>FEP)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@
M)V%P<&QI8V%T:6]N+WII<"<L"B`@("`G87!P;&EC871I;VXO>"UC;VUP<F5S
M<V5D)RP*("`@("=A<'!L:6-A=&EO;B]X+7II<"UC;VUP<F5S<V5D)RD["B1M
M:6UE7V1R:79E<G-;)VAO<F1E)UU;)WII<"==6R=I8V]N<R==(#T@87)R87DH
M"B`@("`G9&5F875L="<@/3X@)V-O;7!R97-S960N<&YG)RD["@H*+RHJ"B`J
M(%)!4B!A<F-H:79E(&1R:79E<B!S971T:6YG<PH@*B\*)&UI;65?9')I=F5R
M<ULG:&]R9&4G75LG<F%R)UU;)VEN;&EN92==(#T@=')U93L*)&UI;65?9')I
M=F5R<ULG:&]R9&4G75LG<F%R)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@
M)V%P<&QI8V%T:6]N+W@M<F%R)RP*("`@("=A<'!L:6-A=&EO;B]X+7)A<BUC
M;VUP<F5S<V5D)RD["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W)A<B==6R=I
M8V]N<R==(#T@87)R87DH"B`@("`G9&5F875L="<@/3X@)V-O;7!R97-S960N
M<&YG)RD["@H*+RHJ"B`J($U3(%=O<F0@9')I=F5R('-E='1I;F=S"B`J(%1H
M:7,@9')I=F5R(')E<75I<F5S('=V5V%R92!T;R!B92!I;G-T86QL960N"B`J
M('=V5V%R92!H;VUE<&%G93H@:'1T<#HO+W=V=V%R92YS;W5R8V5F;W)G92YN
M970O"B`J"B`J(%1H92`G;&]C871I;VXG(&5N=')Y('-H;W5L9"!P;VEN="!T
M;R!T:&4@)W=V2'1M;"<@<')O9W)A;2P@3D]4('1H90H@*B`G=W9787)E)R!P
M<F]G<F%M+@H@*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG;7-W;W)D)UU;
M)VQO8V%T:6]N)UT@/2`G+W5S<B]B:6XO=W9(=&UL)SL*)&UI;65?9')I=F5R
M<ULG:&]R9&4G75LG;7-W;W)D)UU;)VEN;&EN92==(#T@9F%L<V4["B1M:6UE
M7V1R:79E<G-;)VAO<F1E)UU;)VUS=V]R9"==6R=H86YD;&5S)UT@/2!A<G)A
M>2@*("`@("=A<'!L:6-A=&EO;B]V;F0N;7,M=V]R9"<L"B`@("`G87!P;&EC
M871I;VXO;7-W;W)D)RP**3L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG;7-W
M;W)D)UU;)VEC;VYS)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`]/B`G;7-W
M;W)D+G!N9R<L"BD["@H*+RHJ"B`J($U3($5X8V5L(&1R:79E<B!S971T:6YG
M<PH@*B!4:&ES(&1R:79E<B!R97%U:7)E<R!X;&AT;6P@=&\@8F4@:6YS=&%L
M;&5D+@H@*B!X;&AT;6P@:&]M97!A9V4Z(&AT='`Z+R]C:&EC86=O+G-O=7)C
M969O<F=E+FYE="]X;&AT;6PO"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D92==
M6R=M<V5X8V5L)UU;)VQO8V%T:6]N)UT@/2`G+W5S<B]L;V-A;"]B:6XO>&QH
M=&UL)SL*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG;7-E>&-E;"==6R=I;FQI
M;F4G72`](&9A;'-E.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=M<V5X8V5L
M)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)V%P<&QI8V%T:6]N+W9N9"YM
M<RUE>&-E;"<L"B`@("`G87!P;&EC871I;VXO;7-E>&-E;"<L"B`@("`G87!P
M;&EC871I;VXO>"UM<V5X8V5L)RD["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;
M)VUS97AC96PG75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G(#T^
M("=M<V5X8V5L+G!N9R<I.PH*"B\J*@H@*B!-4R!0;W=E<G!O:6YT(&1R:79E
M<B!S971T:6YG<PH@*B!4:&ES(&1R:79E<B!R97%U:7)E<R!P<'1H=&UL+"!I
M;F-L=61E9"!W:71H('AL:'1M;"P@=&\@8F4@:6YS=&%L;&5D+@H@*B!X;&AT
M;6P@:&]M97!A9V4Z(&AT='`Z+R]C:&EC86=O+G-O=7)C969O<F=E+FYE="]X
M;&AT;6PO"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=M<W!O=V5R<&]I
M;G0G75LG;&]C871I;VXG72`]("<O=7-R+VQO8V%L+V)I;B]P<'1H=&UL)SL*
M)&UI;65?9')I=F5R<ULG:&]R9&4G75LG;7-P;W=E<G!O:6YT)UU;)VEN;&EN
M92==(#T@9F%L<V4["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)VUS<&]W97)P
M;VEN="==6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@("=A<'!L:6-A=&EO;B]V
M;F0N;7,M<&]W97)P;VEN="<L"B`@("`G87!P;&EC871I;VXO;7-P;W=E<G!O
M:6YT)RD["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)VUS<&]W97)P;VEN="==
M6R=I8V]N<R==(#T@87)R87DH"B`@("`G9&5F875L="<@/3X@)VUS<&]W97)P
M;VEN="YP;F<G*3L*"@HO*BH*("H@=D-A<F0@9')I=F5R('-E='1I;F=S"B`J
M+PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=V8V%R9"==6R=H86YD;&5S)UT@
M/2!A<G)A>2@*("`@("=T97AT+W@M=F-A<F0G+`H@("`@)W1E>'0O>"UV8V%L
M96YD87(G*3L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG=F-A<F0G75LG:6-O
M;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G(#T^("=V8V%R9"YP;F<G*3L*
M"@HO*BH*("H@4E!-(&1R:79E<B!S971T:6YG<PH@*B\*)&UI;65?9')I=F5R
M<ULG:&]R9&4G75LG<G!M)UU;)VQO8V%T:6]N)UT@/2`G+W5S<B]B:6XO<G!M
M)SL*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<G!M)UU;)VEN;&EN92==(#T@
M9F%L<V4["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W)P;2==6R=H86YD;&5S
M)UT@/2!A<G)A>2@*("`@("=A<'!L:6-A=&EO;B]X+7)P;2<I.PHD;6EM95]D
M<FEV97)S6R=H;W)D92==6R=R<&TG75LG:6-O;G,G72`](&%R<F%Y*`H@("`@
M)V1E9F%U;'0G(#T^("=R<&TN<&YG)RD["@H*+RHJ"B`J($1E8FEA;B!P86-K
M86=E(&1R:79E<B!S971T:6YG<PH@*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G
M75LG9&5B)UU;)VQO8V%T:6]N)UT@/2`G+W5S<B]B:6XO9'!K9R<["B1M:6UE
M7V1R:79E<G-;)VAO<F1E)UU;)V1E8B==6R=I;FQI;F4G72`](&9A;'-E.PHD
M;6EM95]D<FEV97)S6R=H;W)D92==6R=D96(G75LG:&%N9&QE<R==(#T@87)R
M87DH"B`@("`G87!P;&EC871I;VXO>"UD96(G+`H@("`@)V%P<&QI8V%T:6]N
M+W@M9&5B:6%N+7!A8VMA9V4G*3L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG
M9&5B)UU;)VEC;VYS)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`]/B`G9&5B
M+G!N9R<I.PH*"B\J*@H@*B!396-U<F4@;75L=&EP87)T<R`H4D9#(#$X-#<I
M"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=S96-U<FET>2==6R=I;FQI
M;F4G72`]('1R=64["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W-E8W5R:71Y
M)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)VUU;'1I<&%R="]E;F-R>7!T
M960G+"`G;75L=&EP87)T+W-I9VYE9"<I.PHD;6EM95]D<FEV97)S6R=H;W)D
M92==6R=S96-U<FET>2==6R=I8V]N<R==(#T@87)R87DH"B`@("`G9&5F875L
M="<@/3X@)V5N8W)Y<'1I;VXN<&YG)RD["@H*+RHJ"B`J($EM86=E('-E='1I
M;F=S"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=I;6%G97,G75LG:6YL
M:6YE)UT@/2!F86QS93L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG:6UA9V5S
M)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)VEM86=E+RHG*3L*)&UI;65?
M9')I=F5R<ULG:&]R9&4G75LG:6UA9V5S)UU;)VEC;VYS)UT@/2!A<G)A>2@*
M("`@("=D969A=6QT)R`]/B`G:6UA9V4N<&YG)RD["@H*+RHJ"B`J($U3+51.
M148@071T86-H;65N="`H87!P;&EC871I;VXO;7,M=&YE9BD@<V5T=&EN9W,*
M("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W1N968G75LG:6YL:6YE)UT@
M/2!F86QS93L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG=&YE9B==6R=H86YD
M;&5S)UT@/2!A<G)A>2@*("`@("=A<'!L:6-A=&EO;B]M<RUT;F5F)RD["B1M
M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W1N968G75LG:6-O;G,G72`](&%R<F%Y
M*`H@("`@)V1E9F%U;'0G(#T^("=T97AT+G!N9R<I.PH*"B\J*@H@*B!$:6=E
M<W0@;65S<V%G92`H4D9#(#(P-#8@6S4N,BXQ72D@<V5T=&EN9W,*("HO"B1M
M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W)F8S@R,B==6R=I;FQI;F4G72`](&9A
M;'-E.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=R9F,X,C(G75LG:&%N9&QE
M<R==(#T@87)R87DH"B`@("`G;65S<V%G92]R9F,X,C(G+`H@("`@)W@M97AT
M96YS:6]N+V5M;"<I.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=R9F,X,C(G
M75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G(#T^("=M86EL+G!N
M9R<I.PH*"B\J*@H@*B!297!O<G0@;65S<V%G97,@*%)&0R`S-#4R*0H@*B\*
M)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<F5P;W)T)UU;)VEN;&EN92==(#T@
M=')U93L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<F5P;W)T)UU;)VAA;F1L
M97,G72`](&%R<F%Y*`H@("`@)VUU;'1I<&%R="]R97!O<G0G*3L*)&UI;65?
M9')I=F5R<ULG:&]R9&4G75LG<F5P;W)T)UU;)VEC;VYS)UT@/2!A<G)A>2@*
M("`@("=D969A=6QT)R`]/B`G;6%I;"YP;F<G*3L*"@HO*BH*("H@3W!E;D]F
M9FEC92YO<F<O4W1A<D]F9FEC92!S971T:6YG<PH@*B\*)&UI;65?9')I=F5R
M<ULG:&]R9&4G75LG;V]O)UU;)VEN;&EN92==(#T@9F%L<V4["B1M:6UE7V1R
M:79E<G-;)VAO<F1E)UU;)V]O;R==6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@
M("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YC86QC)RP*("`@("=A<'!L:6-A
M=&EO;B]V;F0N<W5N+GAM;"YC86QC+G1E;7!L871E)RP*("`@("=A<'!L:6-A
M=&EO;B]V;F0N<W5N+GAM;"YD<F%W)RP*("`@("=A<'!L:6-A=&EO;B]V;F0N
M<W5N+GAM;"YD<F%W+G1E;7!L871E)RP*("`@("=A<'!L:6-A=&EO;B]V;F0N
M<W5N+GAM;"YI;7!R97-S)RP*("`@("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM
M;"YI;7!R97-S+G1E;7!L871E)RP*("`@("=A<'!L:6-A=&EO;B]V;F0N<W5N
M+GAM;"YM871H)RP*("`@("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YW<FET
M97(G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+G=R:71E<BYG;&]B
M86PG+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+G=R:71E<BYT96UP
M;&%T92<L"B`@("`G87!P;&EC871I;VXO=FYD+G-T87)D:79I<VEO;BYC86QC
M)RP*("`@("=A<'!L:6-A=&EO;B]V;F0N<W1A<F1I=FES:6]N+F1R87<G+`H@
M("`@)V%P<&QI8V%T:6]N+W9N9"YS=&%R9&EV:7-I;VXN:6UP<F5S<R<L"B`@
M("`G87!P;&EC871I;VXO=FYD+G-T87)D:79I<VEO;BYM871H)RP*("`@("=A
M<'!L:6-A=&EO;B]V;F0N<W1A<F1I=FES:6]N+G=R:71E<B<I.PHD;6EM95]D
M<FEV97)S6R=H;W)D92==6R=O;V\G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@
M)V1E9F%U;'0G(#T^("=O;V]?8V%L8RYP;F<G+`H@("`@)V%P<&QI8V%T:6]N
M+W9N9"YS=6XN>&UL+F-A;&,G("`@("`@("`@("`@(#T^("=O;V]?8V%L8RYP
M;F<G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=&%R9&EV:7-I;VXN8V%L8R<@
M("`@("`@(#T^("=O;V]?8V%L8RYP;F<G+`H@("`@)V%P<&QI8V%T:6]N+W9N
M9"YS=6XN>&UL+F-A;&,N=&5M<&QA=&4G("`@(#T^("=O;V]?8V%L8RYP;F<G
M+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+F1R87<G("`@("`@("`@
M("`@(#T^("=O;V]?9')A=RYP;F<G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS
M=&%R9&EV:7-I;VXN9')A=R<@("`@("`@(#T^("=O;V]?9')A=RYP;F<G+`H@
M("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+F1R87<N=&5M<&QA=&4G("`@
M(#T^("=O;V]?9')A=RYP;F<G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN
M>&UL+FEM<')E<W,G("`@("`@("`@(#T^("=O;V]?:6UP<F5S<RYP;F<G+`H@
M("`@)V%P<&QI8V%T:6]N+W9N9"YS=&%R9&EV:7-I;VXN:6UP<F5S<R<@("`@
M(#T^("=O;V]?:6UP<F5S<RYP;F<G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS
M=6XN>&UL+FEM<')E<W,N=&5M<&QA=&4G(#T^("=O;V]?:6UP<F5S<RYP;F<G
M+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+FUA=&@G("`@("`@("`@
M("`@(#T^("=O;V]?;6%T:"YP;F<G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS
M=&%R9&EV:7-I;VXN;6%T:"<@("`@("`@(#T^("=O;V]?;6%T:"YP;F<G+`H@
M("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+G=R:71E<B<@("`@("`@("`@
M(#T^("=O;V]?=W)I=&5R+G!N9R<L"B`@("`G87!P;&EC871I;VXO=FYD+G-T
M87)D:79I<VEO;BYW<FET97(G("`@("`@/3X@)V]O;U]W<FET97(N<&YG)RP*
M("`@("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YW<FET97(N9VQO8F%L)R`@
M("`]/B`G;V]O7W=R:71E<BYP;F<G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS
M=6XN>&UL+G=R:71E<BYT96UP;&%T92<@(#T^("=O;V]?=W)I=&5R+G!N9R<I
M.PH*"B\J*@H@*B!0;W)T86)L92!$;V-U;65N="!&;W)M870@*%!$1BD@9FEL
M97,*("H@64]5(%-(3U5,1"!.3U0@3D]234%,3%D@04Q415(@5$A)4R!31514
M24Y'+@H@*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<&1F)UU;)VEN;&EN
M92==(#T@9F%L<V4["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W!D9B==6R=H
M86YD;&5S)UT@/2!A<G)A>2@*("`@("=A<'!L:6-A=&EO;B]P9&8G*3L*)&UI
M;65?9')I=F5R<ULG:&]R9&4G75LG<&1F)UU;)VEC;VYS)UT@/2!A<G)A>2@*
M("`@("=D969A=6QT)R`]/B`G<&1F+G!N9R<I.PH`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]E=&,O<'-A+6AO<F1E+VAO<F1E
M+VUO=&0N<&AP````````````````````````````````````````````````
M```````````````````````````P,#`P-#0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#0S,``Q,#4Q-30S,S<W-``P,C$R,#0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/"$M+2!4:&ES(&9I;&4@8V]N
M=&%I;G,@86YY(")-97-S86=E($]F(%1H92!$87DB(%1Y<&4@:6YF;W)M871I
M;VX@+2T^"CPA+2T@270@=VEL;"!B92!I;F-L=61E9"!B96QO=R!T:&4@;&]G
M+6EN(&9O<FT@;VX@=&AE(&QO9VEN('!A9V4N("TM/@H*/&)R("\^"CQT86)L
M92!W:61T:#TB,3`P)2(^/'1R/CQT9"!A;&EG;CTB8V5N=&5R(CX\:6UG('-R
M8STB=&AE;65S+V=R87!H:6-S+VAO<F1E+7!O=V5R,2YP;F<B(&%L=#TB4&]W
M97)E9"!B>2!(;W)D92(@+SX\+W1D/CPO='(^/"]T86)L93X*"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O971C+W!S82UH;W)D92]H;W)D92]N;',N<&AP````
M````````````````````````````````````````````````````````````
M````````````,#`P,#0T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-C`P,S0`
M,3`U,34T,S,W-S0`,#(Q,#0S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!.3%,@*$YA=&EO;F%L($QA
M;F=U86=E(%-U<'!O<G0I(&-O;F9I9W5R871I;VX@9FEL92X*("H*("H@)$AO
M<F1E.B!H;W)D92]C;VYF:6<O;FQS+G!H<"YD:7-T+'8@,2XU.2XQ,"XW(#(P
M,#8O,#0O,3D@,C,Z,S8Z,C(@:F%N($5X<"`D"B`J+PH*+RHJ"B`J*B!$969A
M=6QT<PH@*BHO"@HO*B!4:&4@;&%N9W5A9V4@=&\@9F%L;"!B86-K(&]N(&EF
M('=E(&-A;FYO="!D971E<FUI;F4@;VYE(&%N>2!O=&AE<@H@("!W87D@*'5S
M97(@8VAO:6-E(&]R('!R969E<F5N8V5S*2X@268@96UP='DL('=E('=I;&P@
M=')Y('1O(&YE9V]T:6%T90H@("!W:71H('1H92!B<F]W<V5R('5S:6YG($A4
M5%!?04-#15!47TQ!3D=504=%+B`J+PHD;FQS6R=D969A=6QT<R==6R=L86YG
M=6%G92==(#T@)R<["@H*+RHJ"B`J*B!,86YG=6%G90H@*BHO"@HD;FQS6R=L
M86YG=6%G97,G75LG87)?3TTG72`]("=!<F%B:6,@*$]M86XI("@F(W@P-C(W
M.R8C>#`V-#0[)B-X,#8S.3LF(W@P-C,Q.R8C>#`V,C@[)B-X,#8T83LF(W@P
M-C(Y.RDG.PHD;FQS6R=L86YG=6%G97,G75LG87)?4UDG72`]("=!<F%B:6,@
M*%-Y<FEA*2`H)B-X,#8R-SLF(W@P-C0T.R8C>#`V,SD[)B-X,#8S,3LF(W@P
M-C(X.R8C>#`V-&$[)B-X,#8R.3LI)SL*)&YL<ULG;&%N9W5A9V5S)UU;)VED
M7TE$)UT@/2`G0F%H87-A($EN9&]N97-I82<["B1N;'-;)VQA;F=U86=E<R==
M6R=B<U]"02==(#T@)T)O<V%N<VMI)SL*)&YL<ULG;&%N9W5A9V5S)UU;)V)G
M7T)')UT@/2`G0G5L9V%R:6%N("@F(W@P-#$Q.R8C>#`T-&$[)B-X,#0S8CLF
M(W@P-#,S.R8C>#`T,S`[)B-X,#0T,#LF(W@P-#0Q.R8C>#`T,V$[)B-X,#0S
M.#LI)SL*)&YL<ULG;&%N9W5A9V5S)UU;)V-A7T53)UT@/2`G0V%T86PF86=R
M879E.R<["B1N;'-;)VQA;F=U86=E<R==6R=Z:%]#3B==(#T@)T-H:6YE<V4@
M*%-I;7!L:69I960I("@F(W@W8C@P.R8C>#1F-3,[)B-X-&4R9#LF(W@V-3@W
M.RDG.PHD;FQS6R=L86YG=6%G97,G75LG>FA?5%<G72`]("=#:&EN97-E("A4
M<F%D:71I;VYA;"D@*"8C>#9B-C,[)B-X.6%D-#LF(W@T93)D.R8C>#8U.#<[
M*2<["B1N;'-;)VQA;F=U86=E<R==6R=C<U]#6B==(#T@)T-Z96-H("@F(W@P
M,3!C.V5S:WDI)SL*)&YL<ULG;&%N9W5A9V5S)UU;)V1A7T1+)UT@/2`G1&%N
M<VLG.PHD;FQS6R=L86YG=6%G97,G75LG9&5?1$4G72`]("=$975T<V-H)SL*
M)&YL<ULG;&%N9W5A9V5S)UU;)V5N7U53)UT@/2`G16YG;&ES:"`H06UE<FEC
M86XI)SL*)&YL<ULG;&%N9W5A9V5S)UU;)V5N7T=")UT@/2`G16YG;&ES:"`H
M0G)I=&ES:"DG.PHD;FQS6R=L86YG=6%G97,G75LG96Y?0T$G72`]("=%;F=L
M:7-H("A#86YA9&EA;BDG.PHD;FQS6R=L86YG=6%G97,G75LG97-?15,G72`]
M("=%<W!A)FYT:6QD93MO;"<["B1N;'-;)VQA;F=U86=E<R==6R=E=%]%12==
M(#T@)T5E<W1I)SL*)&YL<ULG;&%N9W5A9V5S)UU;)V9R7T92)UT@/2`G1G)A
M;B9C8V5D:6P[86ES)SL*)&YL<ULG;&%N9W5A9V5S)UU;)V=L7T53)UT@/2`G
M1V%L96=O)SL*)&YL<ULG;&%N9W5A9V5S)UU;)V5L7T=2)UT@/2`G1W)E96L@
M*"8C>#`S.34[)B-X,#-B8CLF(W@P,V)B.R8C>#`S8C<[)B-X,#-B9#LF(W@P
M,V(Y.R8C>#`S8F$[)B-X,#-A8SLI)SL*)&YL<ULG;&%N9W5A9V5S)UU;)VAE
M7TE,)UT@/2`G2&5B<F5W("@F(W@P-44R.R8C>#`U1#$[)B-X,#5%.#LF(W@P
M-40Y.R8C>#`U14$[*2<["B1N;'-;)VQA;F=U86=E<R==6R=I<U])4R==(#T@
M)R9)86-U=&4[<VQE;G-K82<["B1N;'-;)VQA;F=U86=E<R==6R=I=%])5"==
M(#T@)TET86QI86YO)SL*)&YL<ULG;&%N9W5A9V5S)UU;)VIA7TI0)UT@/2`G
M2F%P86YE<V4@*"8C>#8U934[)B-X-C<R8SLF(W@X83EE.RDG.PHD;FQS6R=L
M86YG=6%G97,G75LG:VU?2T@G72`]("=+:&UE<B`H)B-X,3<X,3LF(W@Q-V0R
M.R8C>#$W.3@[)B-X,3=C,CLF(W@Q-SEA.RDG.PHD;FQS6R=L86YG=6%G97,G
M75LG:V]?2U(G72`]("=+;W)E86X@*"8C>&0U-6,[)B-X860V9#LF(WAC-6(T
M.RDG.PHD;FQS6R=L86YG=6%G97,G75LG;'9?3%8G72`]("=,871V:64F(W@P
M,38Q.W4G.PHD;FQS6R=L86YG=6%G97,G75LG;'1?3%0G72`]("=,:65T=79I
M)B-X,#$W,SLG.PHD;FQS6R=L86YG=6%G97,G75LG;6M?34LG72`]("=-86-E
M9&]N:6%N("@F(W@P-#%C.R8C>#`T,S`[)B-X,#0S83LF(W@P-#,U.R8C>#`T
M,S0[)B-X,#0S93LF(W@P-#-D.R8C>#`T-#$[)B-X,#0S83LF(W@P-#,X.RDG
M.PHD;FQS6R=L86YG=6%G97,G75LG:'5?2%4G72`]("=-86=Y87(G.PHD;FQS
M6R=L86YG=6%G97,G75LG;FQ?3DPG72`]("=.961E<FQA;F1S)SL*)&YL<ULG
M;&%N9W5A9V5S)UU;)VYB7TY/)UT@/2`G3F]R<VL@8F]K;29A<FEN9SML)SL*
M)&YL<ULG;&%N9W5A9V5S)UU;)VYN7TY/)UT@/2`G3F]R<VL@;GEN;W)S:R<[
M"B1N;'-;)VQA;F=U86=E<R==6R=F85])4B==(#T@)U!E<G-I86X@*"8C>#`V
M-#$[)B-X,#8R-SLF(W@P-C,Q.R8C>#`V,S,[)B-X,#8T.3LI)SL*)&YL<ULG
M;&%N9W5A9V5S)UU;)W!L7U!,)UT@/2`G4&]L<VMI)SL*)&YL<ULG;&%N9W5A
M9V5S)UU;)W!T7U!4)UT@/2`G4&]R='5G=29E8VER8SMS)SL*)&YL<ULG;&%N
M9W5A9V5S)UU;)W!T7T)2)UT@/2`G4&]R='5G=29E8VER8SMS($)R87-I;&5I
M<F\G.PHD;FQS6R=L86YG=6%G97,G75LG<F]?4D\G72`]("=2;VTF86-I<F,[
M;B9A=6UL.R<["B1N;'-;)VQA;F=U86=E<R==6R=R=5]252==(#T@)U)U<W-I
M86X@*"8C>#`T,C`[)B-X,#0T,SLF(W@P-#0Q.R8C>#`T-#$[)B-X,#0S83LF
M(W@P-#,X.R8C>#`T,SD[*2<["B1N;'-;)VQA;F=U86=E<R==6R=S:U]32R==
M(#T@)U-L;W9A:R`H4VQO=F5N)B-X,#$P9#MI;F$I)SL*)&YL<ULG;&%N9W5A
M9V5S)UU;)W-L7U-))UT@/2`G4VQO=F5N:6%N("A3;&]V96XF(W@P,38Q.R8C
M>#`Q,&0[:6YA*2<["B1N;'-;)VQA;F=U86=E<R==6R=F:5]&22==(#T@)U-U
M;VUI)SL*)&YL<ULG;&%N9W5A9V5S)UU;)W-V7U-%)UT@/2`G4W9E;G-K82<[
M"B1N;'-;)VQA;F=U86=E<R==6R=T:%]42"==(#T@)U1H86D@*"8C>#!E-#0[
M)B-X,&4Q-SLF(W@P93(R.RDG.PHD;FQS6R=L86YG=6%G97,G75LG=')?5%(G
M72`]("=4)G5U;6P[<FLF8V-E9&EL.V4G.PHD;FQS6R=L86YG=6%G97,G75LG
M=6M?54$G72`]("=5:W)A:6YI86X@*"8C>#`T,C,[)B-X,#0S83LF(W@P-#0P
M.R8C>#`T,S`[)B-X,#0U-SLF(W@P-#-D.R8C>#`T-#$[)B-X,#0T8SLF(W@P
M-#-A.R8C>#`T,S`[*2<["@H*+RHJ"B`J*B!!;&EA<V5S(&9O<B!L86YG=6%G
M97,@=VET:"!D:69F97)E;G0@8G)O=W-E<B!A;F0@9V5T=&5X="!C;V1E<PH@
M*BHO"@HD;FQS6R=A;&EA<V5S)UU;)V%R)UT@/2`G87)?4UDG.PHD;FQS6R=A
M;&EA<V5S)UU;)V)G)UT@/2`G8F=?0D<G.PHD;FQS6R=A;&EA<V5S)UU;)V)S
M)UT@/2`G8G-?0D$G.PHD;FQS6R=A;&EA<V5S)UU;)V-A)UT@/2`G8V%?15,G
M.PHD;FQS6R=A;&EA<V5S)UU;)V-S)UT@/2`G8W-?0UHG.PHD;FQS6R=A;&EA
M<V5S)UU;)V1A)UT@/2`G9&%?1$LG.PHD;FQS6R=A;&EA<V5S)UU;)V1E)UT@
M/2`G9&5?1$4G.PHD;FQS6R=A;&EA<V5S)UU;)V5L)UT@/2`G96Q?1U(G.PHD
M;FQS6R=A;&EA<V5S)UU;)V5N)UT@/2`G96Y?55,G.PHD;FQS6R=A;&EA<V5S
M)UU;)V5S)UT@/2`G97-?15,G.PHD;FQS6R=A;&EA<V5S)UU;)V5T)UT@/2`G
M971?144G.PHD;FQS6R=A;&EA<V5S)UU;)V9A)UT@/2`G9F%?25(G.PHD;FQS
M6R=A;&EA<V5S)UU;)V9I)UT@/2`G9FE?1DDG.PHD;FQS6R=A;&EA<V5S)UU;
M)V9R)UT@/2`G9G)?1E(G.PHD;FQS6R=A;&EA<V5S)UU;)V=L)UT@/2`G9VQ?
M15,G.PHD;FQS6R=A;&EA<V5S)UU;)VAE)UT@/2`G:&5?24PG.PHD;FQS6R=A
M;&EA<V5S)UU;)VAU)UT@/2`G:'5?2%4G.PHD;FQS6R=A;&EA<V5S)UU;)VED
M)UT@/2`G:61?240G.PHD;FQS6R=A;&EA<V5S)UU;)VES)UT@/2`G:7-?25,G
M.PHD;FQS6R=A;&EA<V5S)UU;)VET)UT@/2`G:71?250G.PHD;FQS6R=A;&EA
M<V5S)UU;)VIA)UT@/2`G:F%?2E`G.PHD;FQS6R=A;&EA<V5S)UU;)VMM)UT@
M/2`G:VU?2T@G.PHD;FQS6R=A;&EA<V5S)UU;)VMO)UT@/2`G:V]?2U(G.PHD
M;FQS6R=A;&EA<V5S)UU;)VQT)UT@/2`G;'1?3%0G.PHD;FQS6R=A;&EA<V5S
M)UU;)VQV)UT@/2`G;'9?3%8G.PHD;FQS6R=A;&EA<V5S)UU;)VUK)UT@/2`G
M;6M?34LG.PHD;FQS6R=A;&EA<V5S)UU;)VYL)UT@/2`G;FQ?3DPG.PHD;FQS
M6R=A;&EA<V5S)UU;)VYN)UT@/2`G;FY?3D\G.PHD;FQS6R=A;&EA<V5S)UU;
M)VYO)UT@/2`G;F)?3D\G.PHD;FQS6R=A;&EA<V5S)UU;)W!L)UT@/2`G<&Q?
M4$PG.PHD;FQS6R=A;&EA<V5S)UU;)W!T)UT@/2`G<'1?4%0G.PHD;FQS6R=A
M;&EA<V5S)UU;)W)O)UT@/2`G<F]?4D\G.PHD;FQS6R=A;&EA<V5S)UU;)W)U
M)UT@/2`G<G5?4E4G.PHD;FQS6R=A;&EA<V5S)UU;)W-K)UT@/2`G<VM?4TLG
M.PHD;FQS6R=A;&EA<V5S)UU;)W-L)UT@/2`G<VQ?4TDG.PHD;FQS6R=A;&EA
M<V5S)UU;)W-V)UT@/2`G<W9?4T4G.PHD;FQS6R=A;&EA<V5S)UU;)W1H)UT@
M/2`G=&A?5$@G.PHD;FQS6R=A;&EA<V5S)UU;)W1R)UT@/2`G=')?5%(G.PHD
M;FQS6R=A;&EA<V5S)UU;)W5K)UT@/2`G=6M?54$G.PH*"B\J*@H@*BH@0VAA
M<G-E=',*("HJ+PH*)&YL<ULG8VAA<G-E=',G75LG87)?3TTG72`]("=W:6YD
M;W=S+3$R-38G.PHD;FQS6R=C:&%R<V5T<R==6R=A<E]362==(#T@)W=I;F1O
M=W,M,3(U-B<["B1N;'-;)V-H87)S971S)UU;)V)G7T)')UT@/2`G=VEN9&]W
M<RTQ,C4Q)SL*)&YL<ULG8VAA<G-E=',G75LG8G-?0D$G72`]("=)4T\M.#@U
M.2TR)SL*)&YL<ULG8VAA<G-E=',G75LG8W-?0UHG72`]("=)4T\M.#@U.2TR
M)SL*)&YL<ULG8VAA<G-E=',G75LG96Q?1U(G72`]("=)4T\M.#@U.2TW)SL*
M)&YL<ULG8VAA<G-E=',G75LG9F%?25(G72`]("=55$8M."<["B1N;'-;)V-H
M87)S971S)UU;)VAE7TE,)UT@/2`G551&+3@G.PHD;FQS6R=C:&%R<V5T<R==
M6R=H=5](52==(#T@)TE33RTX.#4Y+3(G.PHD;FQS6R=C:&%R<V5T<R==6R=J
M85]*4"==(#T@)U-(24947TI)4R<["B1N;'-;)V-H87)S971S)UU;)VMM7TM(
M)UT@/2`G551&+3@G.PHD;FQS6R=C:&%R<V5T<R==6R=K;U]+4B==(#T@)T55
M0RU+4B<["B1N;'-;)V-H87)S971S)UU;)VQT7TQ4)UT@/2`G25-/+3@X-3DM
M,3,G.PHD;FQS6R=C:&%R<V5T<R==6R=L=E],5B==(#T@)W=I;F1O=W,M,3(U
M-R<["B1N;'-;)V-H87)S971S)UU;)VUK7TU+)UT@/2`G25-/+3@X-3DM-2<[
M"B1N;'-;)V-H87)S971S)UU;)W!L7U!,)UT@/2`G25-/+3@X-3DM,B<["B1N
M;'-;)V-H87)S971S)UU;)W)U7U)5)UT@/2`G=VEN9&]W<RTQ,C4Q)SL*)&YL
M<ULG8VAA<G-E=',G75LG<G5?4E4N2T])."U2)UT@/2`G2T])."U2)SL*)&YL
M<ULG8VAA<G-E=',G75LG<VM?4TLG72`]("=)4T\M.#@U.2TR)SL*)&YL<ULG
M8VAA<G-E=',G75LG<VQ?4TDG72`]("=)4T\M.#@U.2TR)SL*)&YL<ULG8VAA
M<G-E=',G75LG=&A?5$@G72`]("=425,M-C(P)SL*)&YL<ULG8VAA<G-E=',G
M75LG=')?5%(G72`]("=)4T\M.#@U.2TY)SL*)&YL<ULG8VAA<G-E=',G75LG
M=6M?54$G72`]("=+3TDX+54G.PHD;FQS6R=C:&%R<V5T<R==6R=Z:%]#3B==
M(#T@)T=",C,Q,B<["B1N;'-;)V-H87)S971S)UU;)WIH7U17)UT@/2`G0DE'
M-2<["@H*+RHJ"B`J*B!-=6QT:6)Y=&4@8VAA<G-E=',*("HJ+PH*)&YL<ULG
M;75L=&EB>71E)UU;)T))1S4G72`]('1R=64["B1N;'-;)VUU;'1I8GET92==
M6R=%54,M2U(G72`]('1R=64["B1N;'-;)VUU;'1I8GET92==6R='0C(S,3(G
M72`]('1R=64["B1N;'-;)VUU;'1I8GET92==6R=32$E&5%]*25,G72`]('1R
M=64["B1N;'-;)VUU;'1I8GET92==6R=55$8M."==(#T@=')U93L*"@HO*BH*
M("HJ(%)I9VAT+71O+6QE9G0@;&%N9W5A9V5S"B`J*B\*"B1N;'-;)W)T;"==
M6R=A<E]/32==(#T@=')U93L*)&YL<ULG<G1L)UU;)V%R7U-9)UT@/2!T<G5E
M.PHD;FQS6R=R=&PG75LG9F%?25(G72`]('1R=64["B1N;'-;)W)T;"==6R=H
M95])3"==(#T@=')U93L*"@HO*BH*("HJ(%!R969E<G)E9"!C:&%R<V5T<R!F
M;W(@96UA:6P@=')A9F9I8R!I9B!N;W0@=&AE(&QA;F=U86=E<R<@9&5F875L
M=`H@*BH@8VAA<G-E=',N"B`J*B\*"B1N;'-;)V5M86EL<R==6R=J85]*4"==
M(#T@)TE33RTR,#(R+4I0)SL*"@HO*BH*("HJ($%V86EL86)L92!C:&%R<V5T
M<R!F;W(@;W5T9V]I;F<@96UA:6P@=')A9F9I8RX*("HJ+PH*)&YL<ULG96YC
M;V1I;F=S)UU;)W=I;F1O=W,M,3(U-B==(#T@7R@B07)A8FEC("A7:6YD;W=S
M+3$R-38I(BD["B1N;'-;)V5N8V]D:6YG<R==6R=!4DU30TE)+3@G72`](%\H
M(D%R;65N:6%N("A!4DU30TE)+3@I(BD["B1N;'-;)V5N8V]D:6YG<R==6R=)
M4T\M.#@U.2TQ,R==(#T@7R@B0F%L=&EC("A)4T\M.#@U.2TQ,RDB*3L*)&YL
M<ULG96YC;V1I;F=S)UU;)TE33RTX.#4Y+3$T)UT@/2!?*")#96QT:6,@*$E3
M3RTX.#4Y+3$T*2(I.PHD;FQS6R=E;F-O9&EN9W,G75LG25-/+3@X-3DM,B==
M(#T@7R@B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB*3L*)&YL<ULG
M96YC;V1I;F=S)UU;)T=",C,Q,B==(#T@7R@B0VAI;F5S92!3:6UP;&EF:65D
M("A'0C(S,3(I(BD["B1N;'-;)V5N8V]D:6YG<R==6R="24<U)UT@/2!?*")#
M:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(I.PHD;FQS6R=E;F-O9&EN9W,G
M75LG2T])."U2)UT@/2!?*")#>7)I;&QI8R`H2T])."U2*2(I.PHD;FQS6R=E
M;F-O9&EN9W,G75LG=VEN9&]W<RTQ,C4Q)UT@/2!?*")#>7)I;&QI8R`H5VEN
M9&]W<RTQ,C4Q*2(I.PHD;FQS6R=E;F-O9&EN9W,G75LG2T])."U5)UT@/2!?
M*")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB*3L*)&YL<ULG96YC;V1I
M;F=S)UU;)TE33RTX.#4Y+3<G72`](%\H(D=R965K("A)4T\M.#@U.2TW*2(I
M.PHD;FQS6R=E;F-O9&EN9W,G75LG25-/+3@X-3DM."U))UT@/2!?*")(96)R
M97<@*$E33RTX.#4Y+3@M22DB*3L*)&YL<ULG96YC;V1I;F=S)UU;)TE33RTR
M,#(R+4I0)UT@/2!?*")*87!A;F5S92`H25-/+3(P,C(M2E`I(BD["B1N;'-;
M)V5N8V]D:6YG<R==6R=%54,M2U(G72`](%\H(DMO<F5A;B`H155#+4M2*2(I
M.PHD;FQS6R=E;F-O9&EN9W,G75LG25-/+3@X-3DM,3`G72`](%\H(DYO<F1I
M8R`H25-/+3@X-3DM,3`I(BD["B1N;'-;)V5N8V]D:6YG<R==6R=)4T\M.#@U
M.2TS)UT@/2!?*")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB*3L*)&YL
M<ULG96YC;V1I;F=S)UU;)U1)4RTV,C`G72`](%\H(E1H86D@*%1)4RTV,C`I
M(BD["B1N;'-;)V5N8V]D:6YG<R==6R=)4T\M.#@U.2TY)UT@/2!?*")4=7)K
M:7-H("A)4T\M.#@U.2TY*2(I.PHD;FQS6R=E;F-O9&EN9W,G75LG551&+3@G
M72`](%\H(E5N:6-O9&4@*%541BTX*2(I.PHD;FQS6R=E;F-O9&EN9W,G75LG
M5DE30TE))UT@/2!?*")6:65T;F%M97-E("A625-#24DI(BD["B1N;'-;)V5N
M8V]D:6YG<R==6R=)4T\M.#@U.2TQ)UT@/2!?*")797-T97)N("A)4T\M.#@U
M.2TQ*2(I.PHD;FQS6R=E;F-O9&EN9W,G75LG25-/+3@X-3DM,34G72`](%\H
M(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(I.PIA<V]R="@D;FQS6R=E;F-O9&EN
M9W,G72D["@H*+RHJ"B`J*B!-=6QT:2UL86YG=6%G92!S<&5L;&EN9R!S=7!P
M;W)T"B`J*B\*"B1N;'-;)W-P96QL:6YG)UU;)V-S7T-:)UT@/2`G+50@;&%T
M:6XR("UD(&-Z96-H)SL*)&YL<ULG<W!E;&QI;F<G75LG9&%?1$LG72`]("<M
M9"!D86YS:R<["B1N;'-;)W-P96QL:6YG)UU;)V1E7T1%)UT@/2`G+50@;&%T
M:6XQ("UD(&1E=71S8V@G.PHD;FQS6R=S<&5L;&EN9R==6R=E;%]'4B==(#T@
M)RU4(&QA=&EN,2`M9"!E;&QI;FEK82<["B1N;'-;)W-P96QL:6YG)UU;)V5N
M7T-!)UT@/2`G+60@8V%N861I86XG.PHD;FQS6R=S<&5L;&EN9R==6R=E;E]'
M0B==(#T@)RUD(&)R:71I<V@G.PHD;FQS6R=S<&5L;&EN9R==6R=E;E]54R==
M(#T@)RUD(&%M97)I8V%N)SL*)&YL<ULG<W!E;&QI;F<G75LG97-?15,G72`]
M("<M9"!E<W!A;F]L)SL*)&YL<ULG<W!E;&QI;F<G75LG9G)?1E(G72`]("<M
M9"!F<F%N8V%I<R<["B1N;'-;)W-P96QL:6YG)UU;)VET7TE4)UT@/2`G+50@
M;&%T:6XQ("UD(&ET86QI86XG.PHD;FQS6R=S<&5L;&EN9R==6R=N;%].3"==
M(#T@)RUD(&YE9&5R;&%N9',G.PHD;FQS6R=S<&5L;&EN9R==6R=P;%]03"==
M(#T@)RUD('!O;&ES:"<["B1N;'-;)W-P96QL:6YG)UU;)W!T7T)2)UT@/2`G
M+60@8G(G.PHD;FQS6R=S<&5L;&EN9R==6R=P=%]05"==(#T@)RU4(&QA=&EN
M,2`M9"!P;W)T=6=U97-E)SL*)&YL<ULG<W!E;&QI;F<G75LG<G5?4E4G72`]
M("<M9"!R=7-S:6%N)SL*)&YL<ULG<W!E;&QI;F<G75LG<VQ?4TDG72`]("<M
M9"!S;&]V96YS:V\G.PHD;FQS6R=S<&5L;&EN9R==6R=S=E]312==(#T@)RUD
M('-V96YS:V$G.PH*)$=,3T)!3%-;)VYL<R==(#T@)B1N;',["@H*+RHJ"B`J
M*B!4:6UE>F]N97,*("HJ+PH*)'1Z6R=!9G)I8V$O06)I9&IA;B==(#T@)T%F
M<FEC82]!8FED:F%N)SL*)'1Z6R=!9G)I8V$O06-C<F$G72`]("=!9G)I8V$O
M06-C<F$G.PHD='I;)T%F<FEC82]!9&1I<U]!8F%B82==(#T@)T%F<FEC82]!
M9&1I<R!!8F%B82<["B1T>ELG069R:6-A+T%L9VEE<G,G72`]("=!9G)I8V$O
M06QG:65R<R<["B1T>ELG069R:6-A+T%S;65R82==(#T@)T%F<FEC82]!<VUE
M<F$G.PHD='I;)T%F<FEC82]"86UA:V\G72`]("=!9G)I8V$O0F%M86MO)SL*
M)'1Z6R=!9G)I8V$O0F%N9W5I)UT@/2`G069R:6-A+T)A;F=U:2<["B1T>ELG
M069R:6-A+T)A;FIU;"==(#T@)T%F<FEC82]"86YJ=6PG.PHD='I;)T%F<FEC
M82]":7-S874G72`]("=!9G)I8V$O0FES<V%U)SL*)'1Z6R=!9G)I8V$O0FQA
M;G1Y<F4G72`]("=!9G)I8V$O0FQA;G1Y<F4G.PHD='I;)T%F<FEC82]"<F%Z
M>F%V:6QL92==(#T@)T%F<FEC82]"<F%Z>F%V:6QL92<["B1T>ELG069R:6-A
M+T)U:G5M8G5R82==(#T@)T%F<FEC82]"=6IU;6)U<F$G.PHD='I;)T%F<FEC
M82]#86ER;R==(#T@)T%F<FEC82]#86ER;R<["B1T>ELG069R:6-A+T-A<V%B
M;&%N8V$G72`]("=!9G)I8V$O0V%S86)L86YC82<["B1T>ELG069R:6-A+T-E
M=71A)UT@/2`G069R:6-A+T-E=71A)SL*)'1Z6R=!9G)I8V$O0V]N86MR>2==
M(#T@)T%F<FEC82]#;VYA:W)Y)SL*)'1Z6R=!9G)I8V$O1&%K87(G72`]("=!
M9G)I8V$O1&%K87(G.PHD='I;)T%F<FEC82]$87)?97-?4V%L86%M)UT@/2`G
M069R:6-A+T1A<B!E<R!386QA86TG.PHD='I;)T%F<FEC82]$:FEB;W5T:2==
M(#T@)T%F<FEC82]$:FEB;W5T:2<["B1T>ELG069R:6-A+T1O=6%L82==(#T@
M)T%F<FEC82]$;W5A;&$G.PHD='I;)T%F<FEC82]%;%]!86EU;B==(#T@)T%F
M<FEC82]%;"!!86EU;B<["B1T>ELG069R:6-A+T9R965T;W=N)UT@/2`G069R
M:6-A+T9R965T;W=N)SL*)'1Z6R=!9G)I8V$O1V%B;W)O;F4G72`]("=!9G)I
M8V$O1V%B;W)O;F4G.PHD='I;)T%F<FEC82](87)A<F4G72`]("=!9G)I8V$O
M2&%R87)E)SL*)'1Z6R=!9G)I8V$O2F]H86YN97-B=7)G)UT@/2`G069R:6-A
M+TIO:&%N;F5S8G5R9R<["B1T>ELG069R:6-A+TMA;7!A;&$G72`]("=!9G)I
M8V$O2V%M<&%L82<["B1T>ELG069R:6-A+TMH87)T;W5M)UT@/2`G069R:6-A
M+TMH87)T;W5M)SL*)'1Z6R=!9G)I8V$O2VEG86QI)UT@/2`G069R:6-A+TMI
M9V%L:2<["B1T>ELG069R:6-A+TMI;G-H87-A)UT@/2`G069R:6-A+TMI;G-H
M87-A)SL*)'1Z6R=!9G)I8V$O3&%G;W,G72`]("=!9G)I8V$O3&%G;W,G.PHD
M='I;)T%F<FEC82],:6)R979I;&QE)UT@/2`G069R:6-A+TQI8G)E=FEL;&4G
M.PHD='I;)T%F<FEC82],;VUE)UT@/2`G069R:6-A+TQO;64G.PHD='I;)T%F
M<FEC82],=6%N9&$G72`]("=!9G)I8V$O3'5A;F1A)SL*)'1Z6R=!9G)I8V$O
M3'5B=6UB87-H:2==(#T@)T%F<FEC82],=6)U;6)A<VAI)SL*)'1Z6R=!9G)I
M8V$O3'5S86MA)UT@/2`G069R:6-A+TQU<V%K82<["B1T>ELG069R:6-A+TUA
M;&%B;R==(#T@)T%F<FEC82]-86QA8F\G.PHD='I;)T%F<FEC82]-87!U=&\G
M72`]("=!9G)I8V$O36%P=71O)SL*)'1Z6R=!9G)I8V$O36%S97)U)UT@/2`G
M069R:6-A+TUA<V5R=2<["B1T>ELG069R:6-A+TUB86)A;F4G72`]("=!9G)I
M8V$O36)A8F%N92<["B1T>ELG069R:6-A+TUO9V%D:7-H=2==(#T@)T%F<FEC
M82]-;V=A9&ES:'4G.PHD='I;)T%F<FEC82]-;VYR;W9I82==(#T@)T%F<FEC
M82]-;VYR;W9I82<["B1T>ELG069R:6-A+TYA:7)O8FDG72`]("=!9G)I8V$O
M3F%I<F]B:2<["B1T>ELG069R:6-A+TYD:F%M96YA)UT@/2`G069R:6-A+TYD
M:F%M96YA)SL*)'1Z6R=!9G)I8V$O3FEA;65Y)UT@/2`G069R:6-A+TYI86UE
M>2<["B1T>ELG069R:6-A+TYO=6%K8VAO='0G72`]("=!9G)I8V$O3F]U86MC
M:&]T="<["B1T>ELG069R:6-A+T]U86=A9&]U9V]U)UT@/2`G069R:6-A+T]U
M86=A9&]U9V]U)SL*)'1Z6R=!9G)I8V$O4&]R=&\M3F]V;R==(#T@)T%F<FEC
M82]0;W)T;RU.;W9O)SL*)'1Z6R=!9G)I8V$O4V%O7U1O;64G72`]("=!9G)I
M8V$O4V%O(%1O;64G.PHD='I;)T%F<FEC82]4:6UB=6MT=2==(#T@)T%F<FEC
M82]4:6UB=6MT=2<["B1T>ELG069R:6-A+U1R:7!O;&DG72`]("=!9G)I8V$O
M5')I<&]L:2<["B1T>ELG069R:6-A+U1U;FES)UT@/2`G069R:6-A+U1U;FES
M)SL*)'1Z6R=!9G)I8V$O5VEN9&AO96LG72`]("=!9G)I8V$O5VEN9&AO96LG
M.PHD='I;)T%M97)I8V$O061A:R==(#T@)T%M97)I8V$O061A:R<["B1T>ELG
M06UE<FEC82]!;F-H;W)A9V4G72`]("=!;65R:6-A+T%N8VAO<F%G92<["B1T
M>ELG06UE<FEC82]!;F=U:6QL82==(#T@)T%M97)I8V$O06YG=6EL;&$G.PHD
M='I;)T%M97)I8V$O06YT:6=U82==(#T@)T%M97)I8V$O06YT:6=U82<["B1T
M>ELG06UE<FEC82]!<F%G=6%I;F$G72`]("=!;65R:6-A+T%R86=U86EN82<[
M"B1T>ELG06UE<FEC82]!<G5B82==(#T@)T%M97)I8V$O07)U8F$G.PHD='I;
M)T%M97)I8V$O07-U;F-I;VXG72`]("=!;65R:6-A+T%S=6YC:6]N)SL*)'1Z
M6R=!;65R:6-A+T)A<F)A9&]S)UT@/2`G06UE<FEC82]"87)B861O<R<["B1T
M>ELG06UE<FEC82]"96QE;2==(#T@)T%M97)I8V$O0F5L96TG.PHD='I;)T%M
M97)I8V$O0F5L:7IE)UT@/2`G06UE<FEC82]"96QI>F4G.PHD='I;)T%M97)I
M8V$O0F]A7U9I<W1A)UT@/2`G06UE<FEC82]";V$@5FES=&$G.PHD='I;)T%M
M97)I8V$O0F]G;W1A)UT@/2`G06UE<FEC82]";V=O=&$G.PHD='I;)T%M97)I
M8V$O0F]I<V4G72`]("=!;65R:6-A+T)O:7-E)SL*)'1Z6R=!;65R:6-A+T)U
M96YO<U]!:7)E<R==(#T@)T%M97)I8V$O0G5E;F]S($%I<F5S)SL*)'1Z6R=!
M;65R:6-A+T-A;6)R:61G95]"87DG72`]("=!;65R:6-A+T-A;6)R:61G92!"
M87DG.PHD='I;)T%M97)I8V$O0V%N8W5N)UT@/2`G06UE<FEC82]#86YC=6XG
M.PHD='I;)T%M97)I8V$O0V%R86-A<R==(#T@)T%M97)I8V$O0V%R86-A<R<[
M"B1T>ELG06UE<FEC82]#871A;6%R8V$G72`]("=!;65R:6-A+T-A=&%M87)C
M82<["B1T>ELG06UE<FEC82]#87EE;FYE)UT@/2`G06UE<FEC82]#87EE;FYE
M)SL*)'1Z6R=!;65R:6-A+T-A>6UA;B==(#T@)T%M97)I8V$O0V%Y;6%N)SL*
M)'1Z6R=!;65R:6-A+T-H:6-A9V\G72`]("=!;65R:6-A+T-H:6-A9V\G.PHD
M='I;)T%M97)I8V$O0VAI:'5A:'5A)UT@/2`G06UE<FEC82]#:&EH=6%H=6$G
M.PHD='I;)T%M97)I8V$O0V]R9&]B82==(#T@)T%M97)I8V$O0V]R9&]B82<[
M"B1T>ELG06UE<FEC82]#;W-T85]2:6-A)UT@/2`G06UE<FEC82]#;W-T82!2
M:6-A)SL*)'1Z6R=!;65R:6-A+T-U:6%B82==(#T@)T%M97)I8V$O0W5I86)A
M)SL*)'1Z6R=!;65R:6-A+T-U<F%C86\G72`]("=!;65R:6-A+T-U<F%C86\G
M.PHD='I;)T%M97)I8V$O1&%W<V]N)UT@/2`G06UE<FEC82]$87=S;VXG.PHD
M='I;)T%M97)I8V$O1&%W<V]N7T-R965K)UT@/2`G06UE<FEC82]$87=S;VX@
M0W)E96LG.PHD='I;)T%M97)I8V$O1&5N=F5R)UT@/2`G06UE<FEC82]$96YV
M97(G.PHD='I;)T%M97)I8V$O1&5T<F]I="==(#T@)T%M97)I8V$O1&5T<F]I
M="<["B1T>ELG06UE<FEC82]$;VUI;FEC82==(#T@)T%M97)I8V$O1&]M:6YI
M8V$G.PHD='I;)T%M97)I8V$O161M;VYT;VXG72`]("=!;65R:6-A+T5D;6]N
M=&]N)SL*)'1Z6R=!;65R:6-A+T5I<G5N97!E)UT@/2`G06UE<FEC82]%:7)U
M;F5P92<["B1T>ELG06UE<FEC82]%;%]386QV861O<B==(#T@)T%M97)I8V$O
M16P@4V%L=F%D;W(G.PHD='I;)T%M97)I8V$O1F]R=&%L97IA)UT@/2`G06UE
M<FEC82]&;W)T86QE>F$G.PHD='I;)T%M97)I8V$O1VQA8V5?0F%Y)UT@/2`G
M06UE<FEC82]';&%C92!"87DG.PHD='I;)T%M97)I8V$O1V]D=&AA8B==(#T@
M)T%M97)I8V$O1V]D=&AA8B<["B1T>ELG06UE<FEC82]';V]S95]"87DG72`]
M("=!;65R:6-A+T=O;W-E($)A>2<["B1T>ELG06UE<FEC82]'<F%N9%]4=7)K
M)UT@/2`G06UE<FEC82]'<F%N9"!4=7)K)SL*)'1Z6R=!;65R:6-A+T=R96YA
M9&$G72`]("=!;65R:6-A+T=R96YA9&$G.PHD='I;)T%M97)I8V$O1W5A9&5L
M;W5P92==(#T@)T%M97)I8V$O1W5A9&5L;W5P92<["B1T>ELG06UE<FEC82]'
M=6%T96UA;&$G72`]("=!;65R:6-A+T=U871E;6%L82<["B1T>ELG06UE<FEC
M82]'=6%Y87%U:6PG72`]("=!;65R:6-A+T=U87EA<75I;"<["B1T>ELG06UE
M<FEC82]'=7EA;F$G72`]("=!;65R:6-A+T=U>6%N82<["B1T>ELG06UE<FEC
M82](86QI9F%X)UT@/2`G06UE<FEC82](86QI9F%X)SL*)'1Z6R=!;65R:6-A
M+TAA=F%N82==(#T@)T%M97)I8V$O2&%V86YA)SL*)'1Z6R=!;65R:6-A+TAE
M<FUO<VEL;&\G72`]("=!;65R:6-A+TAE<FUO<VEL;&\G.PHD='I;)T%M97)I
M8V$O26YD:6%N82]+;F]X)UT@/2`G06UE<FEC82]);F1I86YA+TMN;W@G.PHD
M='I;)T%M97)I8V$O26YD:6%N82]-87)E;F=O)UT@/2`G06UE<FEC82]);F1I
M86YA+TUA<F5N9V\G.PHD='I;)T%M97)I8V$O26YD:6%N82]6979A>2==(#T@
M)T%M97)I8V$O26YD:6%N82]6979A>2<["B1T>ELG06UE<FEC82]);F1I86YA
M<&]L:7,G72`]("=!;65R:6-A+TEN9&EA;F%P;VQI<R<["B1T>ELG06UE<FEC
M82]);G5V:6LG72`]("=!;65R:6-A+TEN=79I:R<["B1T>ELG06UE<FEC82])
M<6%L=6ET)UT@/2`G06UE<FEC82])<6%L=6ET)SL*)'1Z6R=!;65R:6-A+TIA
M;6%I8V$G72`]("=!;65R:6-A+TIA;6%I8V$G.PHD='I;)T%M97)I8V$O2G5J
M=7DG72`]("=!;65R:6-A+TIU:G5Y)SL*)'1Z6R=!;65R:6-A+TIU;F5A=2==
M(#T@)T%M97)I8V$O2G5N96%U)SL*)'1Z6R=!;65R:6-A+TME;G1U8VMY+TUO
M;G1I8V5L;&\G72`]("=!;65R:6-A+TME;G1U8VMY+TUO;G1I8V5L;&\G.PHD
M='I;)T%M97)I8V$O3&%?4&%Z)UT@/2`G06UE<FEC82],82!087HG.PHD='I;
M)T%M97)I8V$O3&EM82==(#T@)T%M97)I8V$O3&EM82<["B1T>ELG06UE<FEC
M82],;W-?06YG96QE<R==(#T@)T%M97)I8V$O3&]S($%N9V5L97,G.PHD='I;
M)T%M97)I8V$O3&]U:7-V:6QL92==(#T@)T%M97)I8V$O3&]U:7-V:6QL92<[
M"B1T>ELG06UE<FEC82]-86-E:6\G72`]("=!;65R:6-A+TUA8V5I;R<["B1T
M>ELG06UE<FEC82]-86YA9W5A)UT@/2`G06UE<FEC82]-86YA9W5A)SL*)'1Z
M6R=!;65R:6-A+TUA;F%U<R==(#T@)T%M97)I8V$O36%N875S)SL*)'1Z6R=!
M;65R:6-A+TUA<G1I;FEQ=64G72`]("=!;65R:6-A+TUA<G1I;FEQ=64G.PHD
M='I;)T%M97)I8V$O36%Z871L86XG72`]("=!;65R:6-A+TUA>F%T;&%N)SL*
M)'1Z6R=!;65R:6-A+TUE;F1O>B==(#T@)T%M97)I8V$O365N9&]Z)SL*)'1Z
M6R=!;65R:6-A+TUE;F]M:6YE92==(#T@)T%M97)I8V$O365N;VUI;F5E)SL*
M)'1Z6R=!;65R:6-A+TUE<FED82==(#T@)T%M97)I8V$O365R:61A)SL*)'1Z
M6R=!;65R:6-A+TUE>&EC;U]#:71Y)UT@/2`G06UE<FEC82]-97AI8V\@0VET
M>2<["B1T>ELG06UE<FEC82]-:7%U96QO;B==(#T@)T%M97)I8V$O36EQ=65L
M;VXG.PHD='I;)T%M97)I8V$O36]N=&5R<F5Y)UT@/2`G06UE<FEC82]-;VYT
M97)R97DG.PHD='I;)T%M97)I8V$O36]N=&5V:61E;R==(#T@)T%M97)I8V$O
M36]N=&5V:61E;R<["B1T>ELG06UE<FEC82]-;VYT<F5A;"==(#T@)T%M97)I
M8V$O36]N=')E86PG.PHD='I;)T%M97)I8V$O36]N='-E<G)A="==(#T@)T%M
M97)I8V$O36]N='-E<G)A="<["B1T>ELG06UE<FEC82].87-S874G72`]("=!
M;65R:6-A+TYA<W-A=2<["B1T>ELG06UE<FEC82].97=?66]R:R==(#T@)T%M
M97)I8V$O3F5W(%EO<FLG.PHD='I;)T%M97)I8V$O3FEP:6=O;B==(#T@)T%M
M97)I8V$O3FEP:6=O;B<["B1T>ELG06UE<FEC82].;VUE)UT@/2`G06UE<FEC
M82].;VUE)SL*)'1Z6R=!;65R:6-A+TYO<F]N:&$G72`]("=!;65R:6-A+TYO
M<F]N:&$G.PHD='I;)T%M97)I8V$O4&%N86UA)UT@/2`G06UE<FEC82]086YA
M;6$G.PHD='I;)T%M97)I8V$O4&%N9VYI<G1U;F<G72`]("=!;65R:6-A+U!A
M;F=N:7)T=6YG)SL*)'1Z6R=!;65R:6-A+U!A<F%M87)I8F\G72`]("=!;65R
M:6-A+U!A<F%M87)I8F\G.PHD='I;)T%M97)I8V$O4&AO96YI>"==(#T@)T%M
M97)I8V$O4&AO96YI>"<["B1T>ELG06UE<FEC82]0;W)T+6%U+5!R:6YC92==
M(#T@)T%M97)I8V$O4&]R="UA=2U0<FEN8V4G.PHD='I;)T%M97)I8V$O4&]R
M=&]?5F5L:&\G72`]("=!;65R:6-A+U!O<G1O(%9E;&AO)SL*)'1Z6R=!;65R
M:6-A+U!O<G1?;V9?4W!A:6XG72`]("=!;65R:6-A+U!O<G0@;V8@4W!A:6XG
M.PHD='I;)T%M97)I8V$O4'5E<G1O7U)I8V\G72`]("=!;65R:6-A+U!U97)T
M;R!2:6-O)SL*)'1Z6R=!;65R:6-A+U)A:6YY7U)I=F5R)UT@/2`G06UE<FEC
M82]286EN>2!2:79E<B<["B1T>ELG06UE<FEC82]286YK:6Y?26YL970G72`]
M("=!;65R:6-A+U)A;FMI;B!);FQE="<["B1T>ELG06UE<FEC82]296-I9F4G
M72`]("=!;65R:6-A+U)E8VEF92<["B1T>ELG06UE<FEC82]296=I;F$G72`]
M("=!;65R:6-A+U)E9VEN82<["B1T>ELG06UE<FEC82]2:6]?0G)A;F-O)UT@
M/2`G06UE<FEC82]2:6\@0G)A;F-O)SL*)'1Z6R=!;65R:6-A+U)O<V%R:6\G
M72`]("=!;65R:6-A+U)O<V%R:6\G.PHD='I;)T%M97)I8V$O4V%N=&EA9V\G
M72`]("=!;65R:6-A+U-A;G1I86=O)SL*)'1Z6R=!;65R:6-A+U-A;G1O7T1O
M;6EN9V\G72`]("=!;65R:6-A+U-A;G1O($1O;6EN9V\G.PHD='I;)T%M97)I
M8V$O4V%O7U!A=6QO)UT@/2`G06UE<FEC82]386\@4&%U;&\G.PHD='I;)T%M
M97)I8V$O4V-O<F5S8GES=6YD)UT@/2`G06UE<FEC82]38V]R97-B>7-U;F0G
M.PHD='I;)T%M97)I8V$O4VAI<')O8VLG72`]("=!;65R:6-A+U-H:7!R;V-K
M)SL*)'1Z6R=!;65R:6-A+U-T7TIO:&YS)UT@/2`G06UE<FEC82]3="!*;VAN
M<R<["B1T>ELG06UE<FEC82]3=%]+:71T<R==(#T@)T%M97)I8V$O4W0@2VET
M=',G.PHD='I;)T%M97)I8V$O4W1?3'5C:6$G72`]("=!;65R:6-A+U-T($QU
M8VEA)SL*)'1Z6R=!;65R:6-A+U-T7U1H;VUA<R==(#T@)T%M97)I8V$O4W0@
M5&AO;6%S)SL*)'1Z6R=!;65R:6-A+U-T7U9I;F-E;G0G72`]("=!;65R:6-A
M+U-T(%9I;F-E;G0G.PHD='I;)T%M97)I8V$O4W=I9G1?0W5R<F5N="==(#T@
M)T%M97)I8V$O4W=I9G0@0W5R<F5N="<["B1T>ELG06UE<FEC82]496=U8VEG
M86QP82==(#T@)T%M97)I8V$O5&5G=6-I9V%L<&$G.PHD='I;)T%M97)I8V$O
M5&AU;&4G72`]("=!;65R:6-A+U1H=6QE)SL*)'1Z6R=!;65R:6-A+U1H=6YD
M97)?0F%Y)UT@/2`G06UE<FEC82]4:'5N9&5R($)A>2<["B1T>ELG06UE<FEC
M82]4:6IU86YA)UT@/2`G06UE<FEC82]4:6IU86YA)SL*)'1Z6R=!;65R:6-A
M+U1O<G1O;&$G72`]("=!;65R:6-A+U1O<G1O;&$G.PHD='I;)T%M97)I8V$O
M5F%N8V]U=F5R)UT@/2`G06UE<FEC82]686YC;W5V97(G.PHD='I;)T%M97)I
M8V$O5VAI=&5H;W)S92==(#T@)T%M97)I8V$O5VAI=&5H;W)S92<["B1T>ELG
M06UE<FEC82]7:6YN:7!E9R==(#T@)T%M97)I8V$O5VEN;FEP96<G.PHD='I;
M)T%M97)I8V$O66%K=71A="==(#T@)T%M97)I8V$O66%K=71A="<["B1T>ELG
M06UE<FEC82]996QL;W=K;FEF92==(#T@)T%M97)I8V$O665L;&]W:VYI9F4G
M.PHD='I;)T%N=&%R8W1I8V$O0V%S97DG72`]("=!;G1A<F-T:6-A+T-A<V5Y
M)SL*)'1Z6R=!;G1A<F-T:6-A+T1A=FES)UT@/2`G06YT87)C=&EC82]$879I
M<R<["B1T>ELG06YT87)C=&EC82]$=6UO;G1$57)V:6QL92==(#T@)T%N=&%R
M8W1I8V$O1'5M;VYT1%5R=FEL;&4G.PHD='I;)T%N=&%R8W1I8V$O36%W<V]N
M)UT@/2`G06YT87)C=&EC82]-87=S;VXG.PHD='I;)T%N=&%R8W1I8V$O36--
M=7)D;R==(#T@)T%N=&%R8W1I8V$O36--=7)D;R<["B1T>ELG06YT87)C=&EC
M82]086QM97(G72`]("=!;G1A<F-T:6-A+U!A;&UE<B<["B1T>ELG06YT87)C
M=&EC82]3;W5T:%]0;VQE)UT@/2`G06YT87)C=&EC82]3;W5T:"!0;VQE)SL*
M)'1Z6R=!;G1A<F-T:6-A+U-Y;W=A)UT@/2`G06YT87)C=&EC82]3>6]W82<[
M"B1T>ELG06YT87)C=&EC82]6;W-T;VLG72`]("=!;G1A<F-T:6-A+U9O<W1O
M:R<["B1T>ELG07)C=&EC+TQO;F=Y96%R8GEE;B==(#T@)T%R8W1I8R],;VYG
M>65A<F)Y96XG.PHD='I;)T%S:6$O061E;B==(#T@)T%S:6$O061E;B<["B1T
M>ELG07-I82]!;&UA='DG72`]("=!<VEA+T%L;6%T>2<["B1T>ELG07-I82]!
M;6UA;B==(#T@)T%S:6$O06UM86XG.PHD='I;)T%S:6$O06YA9'ER)UT@/2`G
M07-I82]!;F%D>7(G.PHD='I;)T%S:6$O07%T874G72`]("=!<VEA+T%Q=&%U
M)SL*)'1Z6R=!<VEA+T%Q=&]B92==(#T@)T%S:6$O07%T;V)E)SL*)'1Z6R=!
M<VEA+T%S:&=A8F%T)UT@/2`G07-I82]!<VAG86)A="<["B1T>ELG07-I82]"
M86=H9&%D)UT@/2`G07-I82]"86=H9&%D)SL*)'1Z6R=!<VEA+T)A:')A:6XG
M72`]("=!<VEA+T)A:')A:6XG.PHD='I;)T%S:6$O0F%K=2==(#T@)T%S:6$O
M0F%K=2<["B1T>ELG07-I82]"86YG:V]K)UT@/2`G07-I82]"86YG:V]K)SL*
M)'1Z6R=!<VEA+T)E:7)U="==(#T@)T%S:6$O0F5I<G5T)SL*)'1Z6R=!<VEA
M+T)I<VAK96LG72`]("=!<VEA+T)I<VAK96LG.PHD='I;)T%S:6$O0G)U;F5I
M)UT@/2`G07-I82]"<G5N96DG.PHD='I;)T%S:6$O0V%L8W5T=&$G72`]("=!
M<VEA+T-A;&-U='1A)SL*)'1Z6R=!<VEA+T-H=6YG:VEN9R==(#T@)T%S:6$O
M0VAU;F=K:6YG)SL*)'1Z6R=!<VEA+T-O;&]M8F\G72`]("=!<VEA+T-O;&]M
M8F\G.PHD='I;)T%S:6$O1&%M87-C=7,G72`]("=!<VEA+T1A;6%S8W5S)SL*
M)'1Z6R=!<VEA+T1H86MA)UT@/2`G07-I82]$:&%K82<["B1T>ELG07-I82]$
M:6QI)UT@/2`G07-I82]$:6QI)SL*)'1Z6R=!<VEA+T1U8F%I)UT@/2`G07-I
M82]$=6)A:2<["B1T>ELG07-I82]$=7-H86YB92==(#T@)T%S:6$O1'5S:&%N
M8F4G.PHD='I;)T%S:6$O1V%Z82==(#T@)T%S:6$O1V%Z82<["B1T>ELG07-I
M82](87)B:6XG72`]("=!<VEA+TAA<F)I;B<["B1T>ELG07-I82](;VYG7TMO
M;F<G72`]("=!<VEA+TAO;F<@2V]N9R<["B1T>ELG07-I82](;W9D)UT@/2`G
M07-I82](;W9D)SL*)'1Z6R=!<VEA+TER:W5T<VLG72`]("=!<VEA+TER:W5T
M<VLG.PHD='I;)T%S:6$O2F%K87)T82==(#T@)T%S:6$O2F%K87)T82<["B1T
M>ELG07-I82]*87EA<'5R82==(#T@)T%S:6$O2F%Y87!U<F$G.PHD='I;)T%S
M:6$O2F5R=7-A;&5M)UT@/2`G07-I82]*97)U<V%L96TG.PHD='I;)T%S:6$O
M2V%B=6PG72`]("=!<VEA+TMA8G5L)SL*)'1Z6R=!<VEA+TMA;6-H871K82==
M(#T@)T%S:6$O2V%M8VAA=&MA)SL*)'1Z6R=!<VEA+TMA<F%C:&DG72`]("=!
M<VEA+TMA<F%C:&DG.PHD='I;)T%S:6$O2V%S:&=A<B==(#T@)T%S:6$O2V%S
M:&=A<B<["B1T>ELG07-I82]+871M86YD=2==(#T@)T%S:6$O2V%T;6%N9'4G
M.PHD='I;)T%S:6$O2W)A<VYO>6%R<VLG72`]("=!<VEA+TMR87-N;WEA<G-K
M)SL*)'1Z6R=!<VEA+TMU86QA7TQU;7!U<B==(#T@)T%S:6$O2W5A;&$@3'5M
M<'5R)SL*)'1Z6R=!<VEA+TMU8VAI;F<G72`]("=!<VEA+TMU8VAI;F<G.PHD
M='I;)T%S:6$O2W5W86ET)UT@/2`G07-I82]+=7=A:70G.PHD='I;)T%S:6$O
M36%C86\G72`]("=!<VEA+TUA8V%O)SL*)'1Z6R=!<VEA+TUA9V%D86XG72`]
M("=!<VEA+TUA9V%D86XG.PHD='I;)T%S:6$O36%N:6QA)UT@/2`G07-I82]-
M86YI;&$G.PHD='I;)T%S:6$O375S8V%T)UT@/2`G07-I82]-=7-C870G.PHD
M='I;)T%S:6$O3FEC;W-I82==(#T@)T%S:6$O3FEC;W-I82<["B1T>ELG07-I
M82].;W9O<VEB:7)S:R==(#T@)T%S:6$O3F]V;W-I8FER<VLG.PHD='I;)T%S
M:6$O3VUS:R==(#T@)T%S:6$O3VUS:R<["B1T>ELG07-I82]0:&YO;5]096YH
M)UT@/2`G07-I82]0:&YO;2!096YH)SL*)'1Z6R=!<VEA+U!Y;VYG>6%N9R==
M(#T@)T%S:6$O4'EO;F=Y86YG)SL*)'1Z6R=!<VEA+U%A=&%R)UT@/2`G07-I
M82]1871A<B<["B1T>ELG07-I82]286YG;V]N)UT@/2`G07-I82]286YG;V]N
M)SL*)'1Z6R=!<VEA+U)I>6%D:"==(#T@)T%S:6$O4FEY861H)SL*)'1Z6R=!
M<VEA+U-A:6=O;B==(#T@)T%S:6$O4V%I9V]N)SL*)'1Z6R=!<VEA+U-A;6%R
M:V%N9"==(#T@)T%S:6$O4V%M87)K86YD)SL*)'1Z6R=!<VEA+U-E;W5L)UT@
M/2`G07-I82]396]U;"<["B1T>ELG07-I82]3:&%N9VAA:2==(#T@)T%S:6$O
M4VAA;F=H86DG.PHD='I;)T%S:6$O4VEN9V%P;W)E)UT@/2`G07-I82]3:6YG
M87!O<F4G.PHD='I;)T%S:6$O5&%I<&5I)UT@/2`G07-I82]486EP96DG.PHD
M='I;)T%S:6$O5&%S:&ME;G0G72`]("=!<VEA+U1A<VAK96YT)SL*)'1Z6R=!
M<VEA+U1B:6QI<VDG72`]("=!<VEA+U1B:6QI<VDG.PHD='I;)T%S:6$O5&5H
M<F%N)UT@/2`G07-I82]496AR86XG.PHD='I;)T%S:6$O5&AI;7!H=2==(#T@
M)T%S:6$O5&AI;7!H=2<["B1T>ELG07-I82]4;VMY;R==(#T@)T%S:6$O5&]K
M>6\G.PHD='I;)T%S:6$O56IU;F=?4&%N9&%N9R==(#T@)T%S:6$O56IU;F<@
M4&%N9&%N9R<["B1T>ELG07-I82]5;&%A;F)A871A<B==(#T@)T%S:6$O56QA
M86YB86%T87(G.PHD='I;)T%S:6$O57)U;7%I)UT@/2`G07-I82]5<G5M<6DG
M.PHD='I;)T%S:6$O5FEE;G1I86YE)UT@/2`G07-I82]6:65N=&EA;F4G.PHD
M='I;)T%S:6$O5FQA9&EV;W-T;VLG72`]("=!<VEA+U9L861I=F]S=&]K)SL*
M)'1Z6R=!<VEA+UEA:W5T<VLG72`]("=!<VEA+UEA:W5T<VLG.PHD='I;)T%S
M:6$O665K871E<FEN8G5R9R==(#T@)T%S:6$O665K871E<FEN8G5R9R<["B1T
M>ELG07-I82]997)E=F%N)UT@/2`G07-I82]997)E=F%N)SL*)'1Z6R=!=&QA
M;G1I8R]!>F]R97,G72`]("=!=&QA;G1I8R]!>F]R97,G.PHD='I;)T%T;&%N
M=&EC+T)E<FUU9&$G72`]("=!=&QA;G1I8R]"97)M=61A)SL*)'1Z6R=!=&QA
M;G1I8R]#86YA<GDG72`]("=!=&QA;G1I8R]#86YA<GDG.PHD='I;)T%T;&%N
M=&EC+T-A<&5?5F5R9&4G72`]("=!=&QA;G1I8R]#87!E(%9E<F1E)SL*)'1Z
M6R=!=&QA;G1I8R]&865R;V4G72`]("=!=&QA;G1I8R]&865R;V4G.PHD='I;
M)T%T;&%N=&EC+TIA;E]-87EE;B==(#T@)T%T;&%N=&EC+TIA;B!-87EE;B<[
M"B1T>ELG071L86YT:6,O36%D96ER82==(#T@)T%T;&%N=&EC+TUA9&5I<F$G
M.PHD='I;)T%T;&%N=&EC+U)E>6MJ879I:R==(#T@)T%T;&%N=&EC+U)E>6MJ
M879I:R<["B1T>ELG071L86YT:6,O4V]U=&A?1V5O<F=I82==(#T@)T%T;&%N
M=&EC+U-O=71H($=E;W)G:6$G.PHD='I;)T%T;&%N=&EC+U-T86YL97DG72`]
M("=!=&QA;G1I8R]3=&%N;&5Y)SL*)'1Z6R=!=&QA;G1I8R]3=%](96QE;F$G
M72`]("=!=&QA;G1I8R]3="!(96QE;F$G.PHD='I;)T%U<W1R86QI82]!9&5L
M86ED92==(#T@)T%U<W1R86QI82]!9&5L86ED92<["B1T>ELG075S=')A;&EA
M+T)R:7-B86YE)UT@/2`G075S=')A;&EA+T)R:7-B86YE)SL*)'1Z6R=!=7-T
M<F%L:6$O0G)O:V5N7TAI;&PG72`]("=!=7-T<F%L:6$O0G)O:V5N($AI;&PG
M.PHD='I;)T%U<W1R86QI82]$87)W:6XG72`]("=!=7-T<F%L:6$O1&%R=VEN
M)SL*)'1Z6R=!=7-T<F%L:6$O2&]B87)T)UT@/2`G075S=')A;&EA+TAO8F%R
M="<["B1T>ELG075S=')A;&EA+TQI;F1E;6%N)UT@/2`G075S=')A;&EA+TQI
M;F1E;6%N)SL*)'1Z6R=!=7-T<F%L:6$O3&]R9%](;W=E)UT@/2`G075S=')A
M;&EA+TQO<F0@2&]W92<["B1T>ELG075S=')A;&EA+TUE;&)O=7)N92==(#T@
M)T%U<W1R86QI82]-96QB;W5R;F4G.PHD='I;)T%U<W1R86QI82]097)T:"==
M(#T@)T%U<W1R86QI82]097)T:"<["B1T>ELG075S=')A;&EA+U-Y9&YE>2==
M(#T@)T%U<W1R86QI82]3>61N97DG.PHD='I;)T5U<F]P92]!;7-T97)D86TG
M72`]("=%=7)O<&4O06US=&5R9&%M)SL*)'1Z6R=%=7)O<&4O06YD;W)R82==
M(#T@)T5U<F]P92]!;F1O<G)A)SL*)'1Z6R=%=7)O<&4O071H96YS)UT@/2`G
M175R;W!E+T%T:&5N<R<["B1T>ELG175R;W!E+T)E;&9A<W0G72`]("=%=7)O
M<&4O0F5L9F%S="<["B1T>ELG175R;W!E+T)E;&=R861E)UT@/2`G175R;W!E
M+T)E;&=R861E)SL*)'1Z6R=%=7)O<&4O0F5R;&EN)UT@/2`G175R;W!E+T)E
M<FQI;B<["B1T>ELG175R;W!E+T)R871I<VQA=F$G72`]("=%=7)O<&4O0G)A
M=&ES;&%V82<["B1T>ELG175R;W!E+T)R=7-S96QS)UT@/2`G175R;W!E+T)R
M=7-S96QS)SL*)'1Z6R=%=7)O<&4O0G5C:&%R97-T)UT@/2`G175R;W!E+T)U
M8VAA<F5S="<["B1T>ELG175R;W!E+T)U9&%P97-T)UT@/2`G175R;W!E+T)U
M9&%P97-T)SL*)'1Z6R=%=7)O<&4O0VAI<VEN874G72`]("=%=7)O<&4O0VAI
M<VEN874G.PHD='I;)T5U<F]P92]#;W!E;FAA9V5N)UT@/2`G175R;W!E+T-O
M<&5N:&%G96XG.PHD='I;)T5U<F]P92]$=6)L:6XG72`]("=%=7)O<&4O1'5B
M;&EN)SL*)'1Z6R=%=7)O<&4O1VEB<F%L=&%R)UT@/2`G175R;W!E+T=I8G)A
M;'1A<B<["B1T>ELG175R;W!E+TAE;'-I;FMI)UT@/2`G175R;W!E+TAE;'-I
M;FMI)SL*)'1Z6R=%=7)O<&4O27-T86YB=6PG72`]("=%=7)O<&4O27-T86YB
M=6PG.PHD='I;)T5U<F]P92]+86QI;FEN9W)A9"==(#T@)T5U<F]P92]+86QI
M;FEN9W)A9"<["B1T>ELG175R;W!E+TMI978G72`]("=%=7)O<&4O2VEE=B<[
M"B1T>ELG175R;W!E+TQI<V)O;B==(#T@)T5U<F]P92],:7-B;VXG.PHD='I;
M)T5U<F]P92],:G5B;&IA;F$G72`]("=%=7)O<&4O3&IU8FQJ86YA)SL*)'1Z
M6R=%=7)O<&4O3&]N9&]N)UT@/2`G175R;W!E+TQO;F1O;B<["B1T>ELG175R
M;W!E+TQU>&5M8F]U<F<G72`]("=%=7)O<&4O3'5X96UB;W5R9R<["B1T>ELG
M175R;W!E+TUA9')I9"==(#T@)T5U<F]P92]-861R:60G.PHD='I;)T5U<F]P
M92]-86QT82==(#T@)T5U<F]P92]-86QT82<["B1T>ELG175R;W!E+TUI;G-K
M)UT@/2`G175R;W!E+TUI;G-K)SL*)'1Z6R=%=7)O<&4O36]N86-O)UT@/2`G
M175R;W!E+TUO;F%C;R<["B1T>ELG175R;W!E+TUO<V-O=R==(#T@)T5U<F]P
M92]-;W-C;W<G.PHD='I;)T5U<F]P92]/<VQO)UT@/2`G175R;W!E+T]S;&\G
M.PHD='I;)T5U<F]P92]087)I<R==(#T@)T5U<F]P92]087)I<R<["B1T>ELG
M175R;W!E+U!R86=U92==(#T@)T5U<F]P92]0<F%G=64G.PHD='I;)T5U<F]P
M92]2:6=A)UT@/2`G175R;W!E+U)I9V$G.PHD='I;)T5U<F]P92]2;VUE)UT@
M/2`G175R;W!E+U)O;64G.PHD='I;)T5U<F]P92]386UA<F$G72`]("=%=7)O
M<&4O4V%M87)A)SL*)'1Z6R=%=7)O<&4O4V%N7TUA<FEN;R==(#T@)T5U<F]P
M92]386X@36%R:6YO)SL*)'1Z6R=%=7)O<&4O4V%R86IE=F\G72`]("=%=7)O
M<&4O4V%R86IE=F\G.PHD='I;)T5U<F]P92]3:6UF97)O<&]L)UT@/2`G175R
M;W!E+U-I;69E<F]P;VPG.PHD='I;)T5U<F]P92]3:V]P:F4G72`]("=%=7)O
M<&4O4VMO<&IE)SL*)'1Z6R=%=7)O<&4O4V]F:6$G72`]("=%=7)O<&4O4V]F
M:6$G.PHD='I;)T5U<F]P92]3=&]C:VAO;&TG72`]("=%=7)O<&4O4W1O8VMH
M;VQM)SL*)'1Z6R=%=7)O<&4O5&%L;&EN;B==(#T@)T5U<F]P92]486QL:6YN
M)SL*)'1Z6R=%=7)O<&4O5&ER86YE)UT@/2`G175R;W!E+U1I<F%N92<["B1T
M>ELG175R;W!E+U5Z:&=O<F]D)UT@/2`G175R;W!E+U5Z:&=O<F]D)SL*)'1Z
M6R=%=7)O<&4O5F%D=7HG72`]("=%=7)O<&4O5F%D=7HG.PHD='I;)T5U<F]P
M92]6871I8V%N)UT@/2`G175R;W!E+U9A=&EC86XG.PHD='I;)T5U<F]P92]6
M:65N;F$G72`]("=%=7)O<&4O5FEE;FYA)SL*)'1Z6R=%=7)O<&4O5FEL;FEU
M<R==(#T@)T5U<F]P92]6:6QN:75S)SL*)'1Z6R=%=7)O<&4O5V%R<V%W)UT@
M/2`G175R;W!E+U=A<G-A=R<["B1T>ELG175R;W!E+UIA9W)E8B==(#T@)T5U
M<F]P92]:86=R96(G.PHD='I;)T5U<F]P92]:87!O<F]Z:'EE)UT@/2`G175R
M;W!E+UIA<&]R;WIH>64G.PHD='I;)T5U<F]P92]:=7)I8V@G72`]("=%=7)O
M<&4O6G5R:6-H)SL*)'1Z6R=);F1I86XO06YT86YA;F%R:79O)UT@/2`G26YD
M:6%N+T%N=&%N86YA<FEV;R<["B1T>ELG26YD:6%N+T-H86=O<R==(#T@)TEN
M9&EA;B]#:&%G;W,G.PHD='I;)TEN9&EA;B]#:')I<W1M87,G72`]("=);F1I
M86XO0VAR:7-T;6%S)SL*)'1Z6R=);F1I86XO0V]C;W,G72`]("=);F1I86XO
M0V]C;W,G.PHD='I;)TEN9&EA;B]#;VUO<F\G72`]("=);F1I86XO0V]M;W)O
M)SL*)'1Z6R=);F1I86XO2V5R9W5E;&5N)UT@/2`G26YD:6%N+TME<F=U96QE
M;B<["B1T>ELG26YD:6%N+TUA:&4G72`]("=);F1I86XO36%H92<["B1T>ELG
M26YD:6%N+TUA;&1I=F5S)UT@/2`G26YD:6%N+TUA;&1I=F5S)SL*)'1Z6R=)
M;F1I86XO36%U<FET:75S)UT@/2`G26YD:6%N+TUA=7)I=&EU<R<["B1T>ELG
M26YD:6%N+TUA>6]T=&4G72`]("=);F1I86XO36%Y;W1T92<["B1T>ELG26YD
M:6%N+U)E=6YI;VXG72`]("=);F1I86XO4F5U;FEO;B<["B1T>ELG4&%C:69I
M8R]!<&EA)UT@/2`G4&%C:69I8R]!<&EA)SL*)'1Z6R=086-I9FEC+T%U8VML
M86YD)UT@/2`G4&%C:69I8R]!=6-K;&%N9"<["B1T>ELG4&%C:69I8R]#:&%T
M:&%M)UT@/2`G4&%C:69I8R]#:&%T:&%M)SL*)'1Z6R=086-I9FEC+T5A<W1E
M<B==(#T@)U!A8VEF:6,O16%S=&5R)SL*)'1Z6R=086-I9FEC+T5F871E)UT@
M/2`G4&%C:69I8R]%9F%T92<["B1T>ELG4&%C:69I8R]%;F1E<F)U<GDG72`]
M("=086-I9FEC+T5N9&5R8G5R>2<["B1T>ELG4&%C:69I8R]&86MA;V9O)UT@
M/2`G4&%C:69I8R]&86MA;V9O)SL*)'1Z6R=086-I9FEC+T9I:FDG72`]("=0
M86-I9FEC+T9I:FDG.PHD='I;)U!A8VEF:6,O1G5N869U=&DG72`]("=086-I
M9FEC+T9U;F%F=71I)SL*)'1Z6R=086-I9FEC+T=A;&%P86=O<R==(#T@)U!A
M8VEF:6,O1V%L87!A9V]S)SL*)'1Z6R=086-I9FEC+T=A;6)I97(G72`]("=0
M86-I9FEC+T=A;6)I97(G.PHD='I;)U!A8VEF:6,O1W5A9&%L8V%N86PG72`]
M("=086-I9FEC+T=U861A;&-A;F%L)SL*)'1Z6R=086-I9FEC+T=U86TG72`]
M("=086-I9FEC+T=U86TG.PHD='I;)U!A8VEF:6,O2&]N;VQU;'4G72`]("=0
M86-I9FEC+TAO;F]L=6QU)SL*)'1Z6R=086-I9FEC+TIO:&YS=&]N)UT@/2`G
M4&%C:69I8R]*;VAN<W1O;B<["B1T>ELG4&%C:69I8R]+:7)I=&EM871I)UT@
M/2`G4&%C:69I8R]+:7)I=&EM871I)SL*)'1Z6R=086-I9FEC+TMO<W)A92==
M(#T@)U!A8VEF:6,O2V]S<F%E)SL*)'1Z6R=086-I9FEC+TMW86IA;&5I;B==
M(#T@)U!A8VEF:6,O2W=A:F%L96EN)SL*)'1Z6R=086-I9FEC+TUA:G5R;R==
M(#T@)U!A8VEF:6,O36%J=7)O)SL*)'1Z6R=086-I9FEC+TUA<G%U97-A<R==
M(#T@)U!A8VEF:6,O36%R<75E<V%S)SL*)'1Z6R=086-I9FEC+TUI9'=A>2==
M(#T@)U!A8VEF:6,O36ED=V%Y)SL*)'1Z6R=086-I9FEC+TYA=7)U)UT@/2`G
M4&%C:69I8R].875R=2<["B1T>ELG4&%C:69I8R].:75E)UT@/2`G4&%C:69I
M8R].:75E)SL*)'1Z6R=086-I9FEC+TYO<F9O;&LG72`]("=086-I9FEC+TYO
M<F9O;&LG.PHD='I;)U!A8VEF:6,O3F]U;65A)UT@/2`G4&%C:69I8R].;W5M
M96$G.PHD='I;)U!A8VEF:6,O4&%G;U]086=O)UT@/2`G4&%C:69I8R]086=O
M(%!A9V\G.PHD='I;)U!A8VEF:6,O4&%L874G72`]("=086-I9FEC+U!A;&%U
M)SL*)'1Z6R=086-I9FEC+U!I=&-A:7)N)UT@/2`G4&%C:69I8R]0:71C86ER
M;B<["B1T>ELG4&%C:69I8R]0;VYA<&4G72`]("=086-I9FEC+U!O;F%P92<[
M"B1T>ELG4&%C:69I8R]0;W)T7TUO<F5S8GDG72`]("=086-I9FEC+U!O<G0@
M36]R97-B>2<["B1T>ELG4&%C:69I8R]287)O=&]N9V$G72`]("=086-I9FEC
M+U)A<F]T;VYG82<["B1T>ELG4&%C:69I8R]386EP86XG72`]("=086-I9FEC
M+U-A:7!A;B<["B1T>ELG4&%C:69I8R]486AI=&DG72`]("=086-I9FEC+U1A
M:&ET:2<["B1T>ELG4&%C:69I8R]487)A=V$G72`]("=086-I9FEC+U1A<F%W
M82<["B1T>ELG4&%C:69I8R]4;VYG871A<'4G72`]("=086-I9FEC+U1O;F=A
M=&%P=2<["B1T>ELG4&%C:69I8R]4<G5K)UT@/2`G4&%C:69I8R]4<G5K)SL*
M)'1Z6R=086-I9FEC+U=A:V4G72`]("=086-I9FEC+U=A:V4G.PHD='I;)U!A
M8VEF:6,O5V%L;&ES)UT@/2`G4&%C:69I8R]786QL:7,G.PHD='I;)U!A8VEF
M:6,O66%P)UT@/2`G4&%C:69I8R]987`G.PH*)$=,3T)!3%-;)W1Z)UT@/2`F
M)'1Z.PH`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O:&]R9&4O<')E9G,N<&AP````````
M````````````````````````````````````````````````````````````
M`````#`P,#`T-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0Q,S0W`#$P-3$U
M-#,S-S<T`#`R,3,W-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]C;VYF:6<O
M<')E9G,N<&AP+F1I<W0L=B`Q+C@U+C(N-R`R,#`V+S`V+S(R(#$X.C0W.C4U
M(&-H=6-K($5X<"`D"B`J"B`J(%!R969E<F5N8V5S($EN9F]R;6%T:6]N"B`J
M(#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`J($-H86YG97,@>6]U(&UA:V4@
M=&\@=&AE('!R969S+G!H<"!F:6QE*',I('=I;&P@;F]T(&)E(')E9FQE8W1E
M9"!U;G1I;"!T:&4*("H@=7-E<B!L;V=S(&]U="!A;F0@;&]G<R!I;B!A9V%I
M;BX*("H*("H@268@>6]U(&-H86YG92!T:&5S92!P<F5F97)E;F-E<R!I;B!A
M('!R;V1U8W1I;VX@<WES=&5M+"!Y;W4@=VEL;`H@*B!N965D('1O(&1E;&5T
M92!A;GD@:&]R9&5?<')E9G,@:6X@>6]U<B!P<F5F97)E;F-E<R!D871A8F%S
M92X*("H*("H@<')E9D=R;W5P<R!A<G)A>0H@*B`M+2TM+2TM+2TM+2TM+2TM
M"B`J("1P<F5F1W)O=7!S(&%R92!F;W(@9&ES<&QA>2!P=7)P;W-E<R!W:&5N
M('EO=2!P<F5S<R!T:&4@;W!T:6]N<R!B=71T;VXN"B`J(%1H92!O<'1I;VYS
M(&-H;VEC92!W:6QL(&%P<&5A<B!W:&5N('EO=2!S970@>6]U<B!P<F5F97)E
M;F-E<R!D<FEV97(*("H@:6X@=&AE(&AO<F1E+V-O;F9I9R]C;VYF+G!H<"!F
M:6QE+@H@*@H@*B`D<')E9D=R;W5P<R!A<G)A>2!D969I;FET:6]N.@H@*B`@
M("!C;VQU;6XZ("!7:&%T(&-O;'5M;B!H96%D('1H:7,@9W)O=7`@=VEL;"!G
M;R!U;F1E<@H@*B`@("`@;&%B96PZ("!,86)E;"!F;W(@=&AE(&=R;W5P(&]F
M('-E='1I;F=S"B`J("`@("`@9&5S8SH@($1E<V-R:7!T:6]N('1H870@=VEL
M;"!S:&]W('5N9&5R(&QA8F5L"B`J("`@;65M8F5R<SH@($QI<W0@;V8@<')E
M9F5R96YC97,@<W5P<&]R=&5D(&)Y('1H:7,@9W)O=7`*("H*("H@7W!R969S
M(&%R<F%Y"B`J("TM+2TM+2TM+2TM+0H@*B!4:&4@)%]P<F5F<R!A<G)A>2=S
M(&%R92!L:7-T960@:6X@=&AE('-A;64@;W)D97(@87,@;&ES=&5D(&EN('1H
M90H@*B!M96UB97)S(&5L96UE;G0@;V8@)'!R969'<F]U<',N"B`J"B`J("`@
M=F%L=64Z(%1H:7,@96YT<GD@=VEL;"!E:71H97(@:&]L9"!A(&YU;6)E<B!O
M<B!A('1E>'0@=F%L=64@8F%S960@;VX@=&AE"B`J("`@("`@("`@('!R969E
M<F5N8V4@='EP93H*("H@("`@("`@("`@("!I;7!L:6-I=#H@(%-E92!0<F5F
M97)E;F-E('1Y<&4*("H@("`@("`@("`@("`@("`@=&5X=#H@(%1E>'0@=F%L
M=64*("H@("`@("`@("`@("`@(&YU;6)E<CH@($YU;6)E<B!V86QU90H@*B`@
M("`@("`@("`@(&-H96-K8F]X.B`@5F%L=64@<VAO=6QD(&)E(#`@9F]R('5N
M8VAE8VME9"P@,2!F;W(@8VAE8VME9`H@*B`@("`@("`@("`@("`@<V5L96-T
M.B`@5F%L=64@87-S;V-I871E9"!W:71H('1H870@<V5L96-T:6]N(&QI<W0*
M("H*("H@(&QO8VME9#H@06QL;W<@<')E9F5R96YC92!T;R!B92!C:&%N9V5D
M(&9R;VT@54D*("H@("`@("`@("`@("`@=')U93H@($1O(&YO="!S:&]W('1H
M:7,@<')E9F5R96YC92!I;B!T:&4@54D*("H@("`@("`@("`@("!F86QS93H@
M(%-H;W<@=&AI<R!P<F5F97)E;F-E(&EN('1H92!522!A;F0@86QL;W<@8VAA
M;F=I;F<*("H*("H@('-H87)E9#H@4VAA<F4@=VET:"!O=&AE<B!H;W)D92!A
M<'!S"B`J("`@("`@("`@("`@('1R=64Z("!3:&%R92!T:&ES('!R968@=VET
M:"!O=&AE<B!(;W)D92!A<'!S"B`J("`@("`@("`@("`@9F%L<V4Z("!+965P
M('1H:7,@<')E9B!L;V-A;"!T;R!T:&4@8W5R<F5N="!A<'`*("H*("H@("`@
M='EP93H@4')E9F5R96YC92!T>7!E"B`J("`@("`@("`@("`@('-P96-I86PZ
M("!0<F]V:61E<R!A(%5)('=I9&=E=`H@*B`@("`@("`@("`@("`@<V5L96-T
M.B`@4')O=FED97,@82!S96QE8W1I;VX@;&ES="!I;B!T:&4@54D*("H@("`@
M("`@("`@("!C:&5C:V)O>#H@(%!R;W9I9&5S(&$@8VAE8VMB;W@*("H@("`@
M("`@("`@("!I;7!L:6-I=#H@(%!R;W9I9&5S('-T;W)A9V4@9F]R("=S<&5C
M:6%L)R!T>7!E<PH@*B`@("`@("`@("`@('!A<W-W;W)D.B`@4')O=FED97,@
M82!T97AT8F]X(&9O<B!P87-S=V]R9"!E;G1R>2X*("H@("`@("`@("`@("`@
M("`@96YU;3H@(%5S92!S=&%T:6,@;&ES="!O9B!E;&5M96YT<RXN+G-I;6EL
M87(@=&\@)W-E;&5C="<*("H*("H@("`@96YU;3H@4W1A=&EC(&QI<W0@;V8@
M96QE;65N=',N"B`J"B`J(&5S8V%P960Z($9O<B!A;B!E;G5M(&]R(&$@<V5L
M96-T+"!A<F4@=&AE(&ME>7,@86YD('9A;'5E<R!A;')E861Y(&AT;6PM97-C
M87!E9#\*("H@("`@("`@("`@1&5F875L=',@=&\@9F%L<V4@:68@;F]T('!R
M97-E;G0N"B`J"B`J("`@(&AO;VLZ($-A;&P@82!H;V]K(&9U;F-T:6]N(&9O
M<B!T:&4@=F%L=64@;V8@=&AI<R!P<F5F97)E;F-E"B`J("`@("`@("`@("`@
M('1R=64Z("!7:6QL(&-A;&P@=&AE(&9U;F-T:6]N(%]P<F5F<U]H;V]K7SQP
M<F5F;F%M93X*("H@("`@("`@("`@("`@("`@("`@('1O(&9I;&P@:6X@=&AE
M('9A;'5E(&]F('1H:7,@<')E9F5R96YC92X*("H@("`@("`@("`@("`@("`@
M("`@(%-E92!H;V]K<RYP:'`@9F]R(&UO<F4@9&5T86EL<RX*("H@("`@("`@
M("`@("!F86QS93H@($YO<FUA;"!B96AA=FEO=7(@+2!N;R!H;V]K(&ES(&-A
M;&QE9"X*("HO"@HD<')E9D=R;W5P<ULG:61E;G1I=&EE<R==(#T@87)R87DH
M"B`@("`G8V]L=6UN)R`]/B!?*")9;W5R($EN9F]R;6%T:6]N(BDL"B`@("`G
M;&%B96PG(#T^(%\H(E!E<G-O;F%L($EN9F]R;6%T:6]N(BDL"B`@("`G9&5S
M8R<@/3X@7R@B0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O
M<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I
M;',N(BDL"B`@("`G;65M8F5R<R<@/3X@87)R87DH)V1E9F%U;'1?:61E;G1I
M='DG+"`G:61E;G1I='ES96QE8W0G+"`G9&5L971E:61E;G1I='DG+`H@("`@
M("`@("`@("`@("`@("`@("`@("=I9"<L("=F=6QL;F%M92<L("=F<F]M7V%D
M9'(G*0HI.PH*)&%U=&@@/2`F075T:#HZ<VEN9VQE=&]N*"1'3$]"04Q36R=C
M;VYF)UU;)V%U=&@G75LG9')I=F5R)UTI.PII9B`H:7-?82@D875T:"P@)T%U
M=&@G*2`F)B`D875T:"T^:&%S0V%P86)I;&ET>2@G=7!D871E)RDI('L*("`@
M("1P<F5F1W)O=7!S6R=F;W)G;W1P87-S)UT@/2!A<G)A>2@*("`@("`@("`G
M8V]L=6UN)R`]/B!?*")9;W5R($EN9F]R;6%T:6]N(BDL"B`@("`@("`@)VQA
M8F5L)R`]/B!?*")!8V-O=6YT(%!A<W-W;W)D(BDL"B`@("`@("`@)V1E<V,G
M(#T^(%\H(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R
M('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB*2P*("`@("`@("`G
M;65M8F5R<R<@/3X@87)R87DH)W-E8W5R:71Y7W%U97-T:6]N)RP@)W-E8W5R
M:71Y7V%N<W=E<B<L("=A;'1E<FYA=&5?96UA:6PG*0H@("`@*3L*?0H*)'!R
M969'<F]U<'-;)VQA;F=U86=E)UT@/2!A<G)A>2@*("`@("=C;VQU;6XG(#T^
M(%\H(EEO=7(@26YF;W)M871I;VXB*2P*("`@("=L86)E;"<@/3X@7R@B3&]C
M86QE(&%N9"!4:6UE(BDL"B`@("`G9&5S8R<@/3X@7R@B4V5T('EO=7(@<')E
M9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(I
M+`H@("`@)VUE;6)E<G,G(#T^(&%R<F%Y*"=L86YG=6%G92<L("=T:6UE>F]N
M92<L("=T=V5N='E&;W5R)RP@)V1A=&5?9F]R;6%T)RD**3L*"B1P<F5F1W)O
M=7!S6R=C871E9V]R:65S)UT@/2!A<G)A>2@*("`@("=C;VQU;6XG(#T^(%\H
M(EEO=7(@26YF;W)M871I;VXB*2P*("`@("=L86)E;"<@/3X@7R@B0V%T96=O
M<FEE<R!A;F0@3&%B96QS(BDL"B`@("`G9&5S8R<@/3X@7R@B36%N86=E('1H
M92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@
M=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O
M<FEE<RXB*2P*("`@("=M96UB97)S)R`]/B!A<G)A>2@G8V%T96=O<GEM86YA
M9V5M96YT)RD**3L*"B1P<F5F1W)O=7!S6R=D:7-P;&%Y)UT@/2!A<G)A>2@*
M("`@("=C;VQU;6XG(#T^(%\H(D]T:&5R($EN9F]R;6%T:6]N(BDL"B`@("`G
M;&%B96PG(#T^(%\H(D1I<W!L87D@3W!T:6]N<R(I+`H@("`@)V1E<V,G(#T^
M(%\H(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M
M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS
M+B(I+`H@("`@)VUE;6)E<G,G(#T^(&%R<F%Y*"=I;FET:6%L7V%P<&QI8V%T
M:6]N)RP@)W-H;W=?;&%S=%]L;V=I;B<L("=T:&5M92<L"B`@("`@("`@("`@
M("`@("`@("`@("`@)W-U;6UA<GE?<F5F<F5S:%]T:6UE)RP@)W-H;W=?<VED
M96)A<B<L("=S:61E8F%R7W=I9'1H)RP*("`@("`@("`@("`@("`@("`@("`@
M("`G;6]Z7W-I9&5B87(G+"`G;65N=5]V:65W)RP@)VUE;G5?<F5F<F5S:%]T
M:6UE)RP*("`@("`@("`@("`@("`@("`@("`@("`G=VED9V5T7V%C8V5S<VME
M>2<L("=A;'!H85]F:6QT97(G*0HI.PH*)'!R969'<F]U<'-;)VQO9VEN=&%S
M:W,G72`](&%R<F%Y*`H@("`@)V-O;'5M;B<@/3X@7R@B3W1H97(@26YF;W)M
M871I;VXB*2P*("`@("=L86)E;"<@/3X@7R@B3&]G:6X@5&%S:W,B*2P*("`@
M("=D97-C)R`]/B!S<')I;G1F*%\H(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@
M=7!O;B!L;V=O;B!T;R`E<RXB*2P@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E
M="@G;F%M92<I*2P*("`@("=M96UB97)S)R`]/B!A<G)A>2@G9&]?;6%I;G1E
M;F%N8V4G+"`G8V]N9FER;5]M86EN=&5N86YC92<I"BD["@HD<')E9D=R;W5P
M<ULG<F5M;W1E)UT@/2!A<G)A>2@*("`@("=C;VQU;6XG(#T^(%\H(D]T:&5R
M($EN9F]R;6%T:6]N(BDL"B`@("`G;&%B96PG(#T^(%\H(E)E;6]T92!397)V
M97)S(BDL"B`@("`G9&5S8R<@/3X@7R@B4V5T('5P(')E;6]T92!S97)V97)S
M('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(BDL
M"B`@("`G=7)L)R`]/B`G<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`G"BD[
M"@HO+R!&;W(@86QT97)N871E($E-4U`@875T:&5N=&EC871I;VXN"FEF("@A
M96UP='DH)$=,3T)!3%-;)V-O;F8G75LG:6US<"==6R=E;F%B;&5D)UTI*2![
M"B`@("`D<')E9D=R;W5P<ULG:6US<&%U=&@G72`](&%R<F%Y*`H@("`@("`@
M("=C;VQU;6XG(#T^(%\H(D]T:&5R($EN9F]R;6%T:6]N(BDL"B`@("`@("`@
M)VQA8F5L)R`]/B!?*")!;'1E<FYA=&4@24U34"!,;V=I;B(I+`H@("`@("`@
M("=D97-C)R`]/B!?*")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E
M;G0@9F]R($E-4U`@<V5R=F5R+B(I+`H@("`@("`@("=M96UB97)S)R`]/B!A
M<G)A>2@G:6US<%]A=71H7W5S97(G+"`G:6US<%]A=71H7W!A<W,G*0H@("`@
M*3L*?0H*+R\@1&5T97)M:6YE(&9U;F-T:6]N86QI='D@;V8@<FEC:'1E>'0@
M961I=&]R"B1P<F5F1W)O=7!S6R=R:6-H=&5X="==(#T@87)R87DH"B`@("`G
M8V]L=6UN)R`]/B!?*")/=&AE<B!);F9O<FUA=&EO;B(I+`H@("`@)VQA8F5L
M)R`]/B!?*")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B*2P*("`@("=D97-C
M)R`]/B!?*")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@
M5&5X="!E9&ET;W(N(BDL"B`@("`G;65M8F5R<R<@/3X@87)R87DH)V-O;G1E
M>'1M96YU)RP@)W1A8FQE;W!E<F%T:6]N<R<L("=L:7-T='EP92<I+`HI.PII
M9B`H)')E9VES=')Y+3YH87-);G1E<F9A8V4H)VEM86=E<R<I*2!["B`@("`D
M<')E9D=R;W5P<ULG<FEC:'1E>'0G75LG;65M8F5R<R==6UT@/2`G86YS96QI
M;6%G92<["GT*"B\O(%!E<G-O;F%L($EN9F]R;6%T:6]N('!R969E<F5N8V5S
M"@HO+R!D969A=6QT(&ED96YT:71Y"B\O(%-E="!L;V-K960@=&\@=')U92!I
M9B!Y;W4@9&]N)W0@=V%N="!T:&4@=7-E<G,@=&\@:&%V92!M=6QT:7!L92!I
M9&5N=&ET:65S+@HD7W!R969S6R=D969A=6QT7VED96YT:71Y)UT@/2!A<G)A
M>2@*("`@("=V86QU92<@/3X@,"P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@
M("`@)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E)R`]/B`G96YU;2<L"B`@
M("`G96YU;2<@/3X@*&ES<V5T*"1I9&5N=&ET>2D@)B8@:7-?;V)J96-T*"1I
M9&5N=&ET>2DI(#\@)&ED96YT:71Y+3YG971!;&PH)VED)RD@.B!A<G)A>2@I
M+`H@("`@)V1E<V,G(#T^(%\H(EEO=7(@9&5F875L="!I9&5N=&ET>3HB*0HI
M.PH*+R\@:61E;G1I=&EE<R!A<G)A>0HO+R!$;VXG="!C:&%N9V4@86YY=&AI
M;F<@:&5R92X*)%]P<F5F<ULG:61E;G1I=&EE<R==(#T@87)R87DH"B`@("`G
M=F%L=64G(#T^("=A.C`Z>WTG+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@
M("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G(#T^("=I;7!L:6-I="<*
M*3L*"B\O(&ED96YT:71Y('-E;&5C=&EO;B!W:61G970*)%]P<F5F<ULG:61E
M;G1I='ES96QE8W0G72`](&%R<F%Y*`H@("`@)W-H87)E9"<@/3X@=')U92P*
M("`@("=T>7!E)R`]/B`G<W!E8VEA;"<**3L*"B\O(&1E;&5T92!B=71T;VX*
M)%]P<F5F<ULG9&5L971E:61E;G1I='DG72`](&%R<F%Y*`H@("`@)W1Y<&4G
M(#T^("=S<&5C:6%L)RP*("`@("=S:&%R960G(#T^('1R=64**3L*"B\O(&ED
M96YT:71Y(&YA;64*+R\@268@>6]U(&QO8VL@=&AI<R!P<F5F97)E;F-E+"!Y
M;W4@;75S="!S<&5C:69Y(&$@=F%L=64@;W(@82!H;V]K(&9O<B!I="!I;@HO
M+R!H;W)D92]C;VYF:6<O:&]O:W,N<&AP+@HD7W!R969S6R=I9"==(#T@87)R
M87DH"B`@("`G=F%L=64G(#T^("<G+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L
M"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G(#T^("=T97AT)RP*
M("`@("=D97-C)R`]/B!?*"))9&5N=&ET>2=S(&YA;64Z(BD**3L*"B\O('5S
M97(@9G5L;"!N86UE(&9O<B!&<F]M.B!L:6YE"B\O($EF('EO=2!L;V-K('1H
M:7,@<')E9F5R96YC92P@>6]U(&UU<W0@<W!E8VEF>2!A('9A;'5E(&]R(&$@
M:&]O:R!F;W(@:70@:6X*+R\@:&]R9&4O8V]N9FEG+VAO;VMS+G!H<"X*)%]P
M<F5F<ULG9G5L;&YA;64G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`G)RP*
M("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@=')U92P*
M("`@("=T>7!E)R`]/B`G=&5X="<L"B`@("`G9&5S8R<@/3X@7R@B66]U<B!F
M=6QL(&YA;64Z(BD**3L*"B\O('5S97(@<')E9F5R<F5D(&5M86EL(&%D9')E
M<W,@9F]R($9R;VTZ(&QI;F4*+R\@268@>6]U(&QO8VL@=&AI<R!P<F5F97)E
M;F-E+"!Y;W4@;75S="!S<&5C:69Y(&$@=F%L=64@;W(@82!H;V]K(&9O<B!I
M="!I;@HO+R!H;W)D92]C;VYF:6<O:&]O:W,N<&AP+@HD7W!R969S6R=F<F]M
M7V%D9'(G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`G)RP*("`@("=L;V-K
M960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E
M)R`]/B`G=&5X="<L"B`@("`G9&5S8R<@/3X@(%\H(EEO=7(@1G)O;3H@861D
M<F5S<SHB*0HI.PH*+R\@=7-E<B!S96-U<FET>2!Q=65S=&EO;@HD7W!R969S
M6R=S96-U<FET>5]Q=65S=&EO;B==(#T@87)R87DH"B`@("`G=F%L=64G(#T^
M("<G+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T
M<G5E+`H@("`@)W1Y<&4G(#T^("=T97AT)RP*("`@("=D97-C)R`]/B!?*")%
M;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S
M:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@
M)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB*0HI.PH*+R\@=7-E
M<B!S96-U<FET>2!A;G-W97(*)%]P<F5F<ULG<V5C=7)I='E?86YS=V5R)UT@
M/2!A<G)A>2@*("`@("=V86QU92<@/3X@)R<L"B`@("`G;&]C:V5D)R`]/B!F
M86QS92P*("`@("=S:&%R960G(#T^('1R=64L"B`@("`G='EP92<@/3X@)W1E
M>'0G+`H@("`@)V1E<V,G(#T^(%\H(DEN<V5R="!T:&4@<F5Q=6ER960@86YS
M=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB*0HI.PH*+R\@=7-E<B!A
M;'1E<FYA=&4@96UA:6P*)%]P<F5F<ULG86QT97)N871E7V5M86EL)UT@/2!A
M<G)A>2@*("`@("=V86QU92<@/3X@)R<L"B`@("`G;&]C:V5D)R`]/B!F86QS
M92P*("`@("=S:&%R960G(#T^('1R=64L"B`@("`G='EP92<@/3X@)W1E>'0G
M+`H@("`@)V1E<V,G(#T^(%\H(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O
M('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(I"BD[
M"@HO+R!U<V5R(&QA;F=U86=E"B1?<')E9G-;)VQA;F=U86=E)UT@/2!A<G)A
M>2@*("`@("=V86QU92<@/3X@)R<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*
M("`@("=S:&%R960G(#T^('1R=64L"B`@("`G='EP92<@/3X@)W-E;&5C="<L
M"B`@("`G97-C87!E9"<@/3X@=')U92P*("`@("=D97-C)R`]/B!?*")396QE
M8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(BD**3L*"B\O('5S97(@=&EM
M92!Z;VYE"B1?<')E9G-;)W1I;65Z;VYE)UT@/2!A<G)A>2@*("`@("=V86QU
M92<@/3X@)R<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G
M(#T^('1R=64L"B`@("`G='EP92<@/3X@)W-E;&5C="<L"B`@("`G9&5S8R<@
M/3X@7R@B66]U<B!C=7)R96YT('1I;64@>F]N93HB*0HI.PH*+R\@=&EM92!F
M;W)M870*)%]P<F5F<ULG='=E;G1Y1F]U<B==(#T@87)R87DH"B`@("`G=F%L
M=64G(#T^(&9A;'-E+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA
M<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G(#T^("=C:&5C:V)O>"<L"B`@("`G
M9&5S8R<@/3X@7R@B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(I"BD["@HO+R!D
M871E(&9O<FUA=`HD7W!R969S6R=D871E7V9O<FUA="==(#T@87)R87DH"B`@
M("`G=F%L=64G(#T^("<E>"<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@
M("=S:&%R960G(#T^('1R=64L"B`@("`G='EP92<@/3X@)V5N=6TG+`H@("`@
M)V5N=6TG(#T^(&%R<F%Y*`H@("`@("`@("<E>"<@/3X@<W1R9G1I;64H)R5X
M)RDL"B`@("`@("`@)R59+25M+25D)R`]/B!S=')F=&EM92@G)5DM)6TM)60G
M*2P*("`@("`@("`G)60O)6TO)5DG(#T^('-T<F9T:6UE*"<E9"\E;2\E62<I
M+`H@("`@("`@("<E02`E0B`E9"P@)5DG(#T^('-T<F9T:6UE*"<E02`E0B`E
M9"P@)5DG*2P*("`@("`@("`G)4$L("5D+B`E0B`E62<@/3X@<W1R9G1I;64H
M)R5!+"`E9"X@)4(@)5DG*2P*("`@("`@("`G)4$L("5D("5"("59)R`]/B!S
M=')F=&EM92@G)4$L("5D("5"("59)RDL"B`@("`@("`@)R5A+"`E8B`E92P@
M)5DG(#T^('-T<F9T:6UE*"<E82P@)6(@)64L("59)RDL"B`@("`@("`@)R5A
M+"`E8B`E92P@)7DG(#T^('-T<F9T:6UE*"<E82P@)6(@)64L("5Y)RDL"B`@
M("`@("`@)R5A+"`E8B`E92<@/3X@<W1R9G1I;64H)R5A+"`E8B`E92<I+`H@
M("`@("`@("<E82P@)64@)6(@)5DG(#T^('-T<F9T:6UE*"<E82P@)64@)6(@
M)5DG*2P*("`@("`@("`G)6$L("5E("5B("5Y)R`]/B!S=')F=&EM92@G)6$L
M("5E("5B("5Y)RDL"B`@("`@("`@)R5A("5D("5B("59)R`]/B!S=')F=&EM
M92`H)R5A("5D("5B("59)RDL"B`@("`@("`@)R5A("5X)R`]/B!S=')F=&EM
M92`H)R5A("5X)RDL"B`@("`@("`@)R5A("59+25M+25D)R`]/B!S=')F=&EM
M92`H)R5A("59+25M+25D)RDL"B`@("`@("`@)R5E("5B("59)R`]/B!S=')F
M=&EM92@G)64@)6(@)5DG*2P*("`@("`@("`G)64N("5B("59)R`]/B!S=')F
M=&EM92@G)64N("5B("59)RDL"B`@("`@("`@)R5E+B`E;2`E62<@/3X@<W1R
M9G1I;64H)R5E("5M("59)RDL"B`@("`@("`@)R5E+B`E;2XG(#T^('-T<F9T
M:6UE*"<E92X@)6TN)RDL"B`@("`@("`@)R5E+B`E0B<@/3X@<W1R9G1I;64H
M)R5E+B`E0B<I+`H@("`@("`@("<E92X@)4(@)5DG(#T^('-T<F9T:6UE*"<E
M92X@)4(@)5DG*2P*("`@("`@("`G)64N("5"("5Y)R`]/B!S=')F=&EM92@G
M)64N("5"("5Y)RDL"B`@("`@("`@)R5"("5E+"`E62<@/3X@<W1R9G1I;64H
M)R5"("5E+"`E62<I+`H@("`@*2P*("`@("=D97-C)R`]/B!?*")#:&]O<V4@
M:&]W('1O(&1I<W!L87D@9&%T97,Z(BDI.PH*+R\@54D@=&AE;64*)%]P<F5F
M<ULG=&AE;64G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`G8FQU97=H:71E
M)RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@=')U
M92P*("`@("=T>7!E)R`]/B`G<V5L96-T)RP*("`@("=D97-C)R`]/B!?*")3
M96QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(BD**3L*"B\O(&-A=&5G;W)I97,*
M)%]P<F5F<ULG8V%T96=O<FEE<R==(#T@87)R87DH"B`@("`G=F%L=64G(#T^
M("<G+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T
M<G5E+`H@("`@)W1Y<&4G(#T^("=I;7!L:6-I="<**3L*"B\O(&-A=&5G;W)Y
M(&-O;&]R<PHD7W!R969S6R=C871E9V]R>5]C;VQO<G,G72`](&%R<F%Y*`H@
M("`@)W9A;'5E)R`]/B`G)RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@
M)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E)R`]/B`G:6UP;&EC:70G"BD[
M"@HO+R!522!F;W(@8V%T96=O<GD@;6%N86=E;65N="X*)%]P<F5F<ULG8V%T
M96=O<GEM86YA9V5M96YT)UT@/2!A<G)A>2@*("`@("=T>7!E)R`]/B`G<W!E
M8VEA;"<**3L*"B1?<')E9G-;)W-U;6UA<GE?<F5F<F5S:%]T:6UE)UT@/2!A
M<G)A>2@*("`@("=V86QU92<@/3X@,S`P+`H@("`@)VQO8VME9"<@/3X@9F%L
M<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G96YU
M;2<L"B`@("`G96YU;2<@/3X@87)R87DH,"`]/B!?*").979E<B(I+`H@("`@
M("`@("`@("`@("`@("`@(#,P(#T^(%\H(D5V97)Y(#,P('-E8V]N9',B*2P*
M("`@("`@("`@("`@("`@("`@("`V,"`]/B!?*")%=F5R>2!M:6YU=&4B*2P*
M("`@("`@("`@("`@("`@("`@("`S,#`@/3X@7R@B179E<GD@-2!M:6YU=&5S
M(BDL"B`@("`@("`@("`@("`@("`@("`@.3`P(#T^(%\H(D5V97)Y(#$U(&UI
M;G5T97,B*2P*("`@("`@("`@("`@("`@("`@("`Q.#`P(#T^(%\H(D5V97)Y
M(&AA;&8@:&]U<B(I*2P*("`@("=D97-C)R`]/B!?*")2969R97-H(%!O<G1A
M;"!6:65W.B(I"BD["@HD7W!R969S6R=S:&]W7W-I9&5B87(G72`](&%R<F%Y
M*`H@("`@)W9A;'5E)R`]/B!T<G5E+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L
M"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G(#T^("=C:&5C:V)O
M>"<L"B`@("`G9&5S8R<@/3X@<W!R:6YT9BA?*")3:&]W('1H92`E<R!-96YU
M(&]N('1H92!L969T/R(I+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=N
M86UE)RP@)VAO<F1E)RDI"BD["@HD7W!R969S6R=S:61E8F%R7W=I9'1H)UT@
M/2!A<G)A>2@*("`@("=V86QU92<@/3X@,3<U+`H@("`@)VQO8VME9"<@/3X@
M9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G
M;G5M8F5R)RP*("`@("=D97-C)R`]/B!S<')I;G1F*%\H(E=I9'1H(&]F('1H
M92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L
M;V<M:6XI.B(I+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=N86UE)RP@
M)VAO<F1E)RDI"BD["@HD7W!R969S6R=M;WI?<VED96)A<B==(#T@87)R87DH
M"B`@("`G='EP92<@/3X@)VQI;FLG+`H@("`@)WAU<FPG(#T^('-P<FEN=&8H
M)VIA=F%S8W)I<'0Z:68@*'=I;F1O=RYS:61E8F%R("8F('=I;F1O=RYS:61E
M8F%R+F%D9%!A;F5L*2!W:6YD;W<N<VED96)A<BYA9&1086YE;"A<)R5S7"<L
M(%PG)7-<)RP@7"<E<UPG*3L@96QS92!A;&5R="A<)R5S7"<I.R<L"B`@("`@
M("`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=N
M86UE)RP@)VAO<F1E)RDL"B`@("`@("`@("`@("`@("`@("`@("!5=&EL.CIA
M9&1087)A;65T97(H2&]R9&4Z.G5R;"@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^
M9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G+W-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<"<L('1R=64L("TQ*2P@)VUO>F)A<B<L("<Q)RDL"B`@("`@
M("`@("`@("`@("`@("`@("!(;W)D93HZ=7)L*"1'3$]"04Q36R=R96=I<W1R
M>2==+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<')E9G,N<&AP)RP@
M=')U92P@+3$I+`H@("`@("`@("`@("`@("`@("`@("`@861D<VQA<VAE<RA?
M*")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R
M92!T:&4@<VED96)A<B!I<R!O<&5N+B(I*2DL"B`@("`G9&5S8R<@/3X@<W!R
M:6YT9BA?*")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B
M*2P@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G;F%M92<L("=H;W)D92<I
M*0HI.PH*)%]P<F5F<ULG;65N=5]V:65W)UT@/2!A<G)A>2@*("`@("=V86QU
M92<@/3X@)V)O=&@G+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA
M<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G(#T^("=E;G5M)RP*("`@("=E;G5M
M)R`]/B!A<G)A>2@G=&5X="<@/3X@7R@B5&5X="!/;FQY(BDL"B`@("`@("`@
M("`@("`@("`@("`@)VEC;VXG(#T^(%\H(DEC;VYS($]N;'DB*2P*("`@("`@
M("`@("`@("`@("`@("`G8F]T:"<@/3X@7R@B26-O;G,@=VET:"!T97AT(BDI
M+`H@("`@)V1E<V,G(#T^(%\H(DUE;G4@;6]D93HB*0HI.PH*)%]P<F5F<ULG
M;65N=5]R969R97-H7W1I;64G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`S
M,#`L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^('1R
M=64L"B`@("`G='EP92<@/3X@)V5N=6TG+`H@("`@)V5N=6TG(#T^(&%R<F%Y
M*#`@/3X@7R@B3F5V97(B*2P*("`@("`@("`@("`@("`@("`@("`S,"`]/B!?
M*")%=F5R>2`S,"!S96-O;F1S(BDL"B`@("`@("`@("`@("`@("`@("`@-C`@
M/3X@7R@B179E<GD@;6EN=71E(BDL"B`@("`@("`@("`@("`@("`@("`@,3(P
M(#T^(%\H(D5V97)Y(#(@;6EN=71E<R(I+`H@("`@("`@("`@("`@("`@("`@
M(#,P,"`]/B!?*")%=F5R>2`U(&UI;G5T97,B*2DL"B`@("`G9&5S8R<@/3X@
M7R@B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(BD**3L*"@HO+R!,
M;V=I;B]-86EN=&5N86YC92!487-K<R!P<F5F97)E;F-E<PH*+R\@5&\@9&ES
M86)L92!M86EN=&5N86YC92!E;G1I<F5L>2P@<V5T("=V86QU92<@/2!F86QS
M92!A;F0*+R\@)VQO8VME9"<@/2!T<G5E(&9O<B!A;&P@;V8@=&AE<V4N(%1O
M(&IU<W0@='5R;B!I="!O9F8@8GD@9&5F875L="P*+R\@<V5T("=V86QU92<@
M9F%L<V4@9F]R(&1O7VUA:6YT96YA;F-E+@HO+R!P97)F;W)M(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,_"B1?<')E9G-;)V1O7VUA:6YT96YA;F-E)UT@/2!A
M<G)A>2@*("`@("=V86QU92<@/3X@=')U92P*("`@("=L;V-K960G(#T^(&9A
M;'-E+`H@("`@)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E)R`]/B`G8VAE
M8VMB;W@G+`H@("`@)V1E<V,G(#T^(%\H(E!E<F9O<FT@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!O;B!L;V=I;C\B*2P*("`@("=H96QP)R`]/B`G<')E9G,M
M9&]?;6%I;G1E;F%N8V4G*3L*"B\O(&QA<W0@=&EM92!M86EN=&5N86YC92!W
M87,@<G5N+@HO+R!V86QU92!I<R!A(%5.25@@=&EM97-T86UP(&]F('1H92!L
M87-T('1I;64@;6%I;G1E;F%N8V4@<F%N(&9O<B!T:&4@=7-E<BX*)%]P<F5F
M<ULG;&%S=%]M86EN=&5N86YC92==(#T@87)R87DH"B`@("`G=F%L=64G(#T^
M(#`L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^('1R
M=64L"B`@("`G='EP92<@/3X@)VEM<&QI8VET)PHI.PH*+R\@8V]N9FER;2!W
M:&5N(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_($EF(&9A;'-E+"!T
M:&5Y('=I;&P*+R\@8F4@<&5R9F]R;65D('=I=&@@;F\@:6YP=70@9G)O;2]C
M:&5C:R!W:71H('1H92!U<V5R+@HD7W!R969S6R=C;VYF:7)M7VUA:6YT96YA
M;F-E)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@=')U92P*("`@("=L;V-K
M960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E
M)R`]/B`G8VAE8VMB;W@G+`H@("`@)V1E<V,G(#T^(%\H(D%S:R!F;W(@8V]N
M9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS
M/R(I+`H@("`@)VAE;'`G(#T^("=P<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E
M)RD["@HO+R!%;F0@3&]G:6XO36%I;G1E;F%N8V4@<')E9F5R96YC97,*"@HO
M+R!W:&%T(&%P<&QI8V%T:6]N('-H;W5L9"!W92!G;R!T;R!A9G1E<B!L;V=I
M;C\*)%]P<F5F<ULG:6YI=&EA;%]A<'!L:6-A=&EO;B==(#T@87)R87DH"B`@
M("`G=F%L=64G(#T^("=H;W)D92<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*
M("`@("=S:&%R960G(#T^('1R=64L"B`@("`G='EP92<@/3X@)W-E;&5C="<L
M"B`@("`G9&5S8R<@/3X@<W!R:6YT9BA?*")7:&%T(&%P<&QI8V%T:6]N('-H
M;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(I+"`D1TQ/0D%,4ULG<F5G
M:7-T<GDG72T^9V5T*"=N86UE)RDI"BD["@HO+R!S:&]U;&0@=V4@8W)E871E
M(&%C8V5S<R!K97ES/PHD7W!R969S6R=W:61G971?86-C97-S:V5Y)UT@/2!A
M<G)A>2@*("`@("=V86QU92<@/3X@=')U92P*("`@("=L;V-K960G(#T^(&9A
M;'-E+`H@("`@)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E)R`]/B`G8VAE
M8VMB;W@G+`H@("`@)V1E<V,G(#T^(%\H(E-H;W5L9"!A8V-E<W,@:V5Y<R!B
M92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(I"BD["@HO+R!S:&]U;&0@=V4@
M;F]T('5S92!T:&4@86QP:&$@:6UA9V4@;&]A9&5R(&9O<B!)13\*)%]P<F5F
M<ULG86QP:&%?9FEL=&5R)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@9F%L
M<V4L"B`@("`G;&]C:V5D)R`]/B!T<G5E+`H@("`@)W-H87)E9"<@/3X@=')U
M92P*("`@("=T>7!E)R`]/B`G8VAE8VMB;W@G+`H@("`@)V1E<V,G(#T^(%\H
M(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X
M<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R
M;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB*0HI.PH*+R\@=&AE(&QA>6]U="!O
M9B!T:&4@<&]R=&%L('!A9V4N"B1?<')E9G-;)W!O<G1A;%]L87EO=70G72`]
M(&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`G83HP.GM])RP*("`@("=L;V-K960G
M(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`G='EP92<@
M/3X@)VEM<&QI8VET)PHI.PH*+R\@=&AE(')E;6]T92!S97)V97)S+@HD7W!R
M969S6R=R96UO=&5?<W5M;6%R:65S)UT@/2!A<G)A>2@*("`@("=V86QU92<@
M/3X@)V$Z,#I[?2<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R
M960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=I;7!L:6-I="<**3L*"B\O
M(&QA<W0@;&]G:6X@=&EM92!O9B!U<V5R"B\O('9A;'5E(&ES(&$@<V5R:6%L
M:7IE9"!A<G)A>2!O9B!T:&4@54Y)6"!T:6UE<W1A;7`@;V8@=&AE(&QA<W0*
M+R\@;&]G:6XL(&%N9"!T:&4@:&]S="!T:&%T('1H92!L87-T(&QO9VEN('=A
M<R!F<F]M+@HD7W!R969S6R=L87-T7VQO9VEN)UT@/2!A<G)A>2@*("`@("=V
M86QU92<@/3X@)V$Z,#I[?2<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@
M("=S:&%R960G(#T^('1R=64L"B`@("`G='EP92<@/3X@)VEM<&QI8VET)PHI
M.PH*+R\@<VAO=R!T:&4@;&%S="!L;V=I;B!T:6UE(&]F('5S97(*)%]P<F5F
M<ULG<VAO=U]L87-T7VQO9VEN)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@
M=')U92P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@
M=')U92P*("`@("=T>7!E)R`]/B`G8VAE8VMB;W@G+`H@("`@)V1E<V,G(#T^
M(%\H(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B*0HI
M.PH*:68@*"%E;7!T>2@D1TQ/0D%,4ULG8V]N9B==6R=I;7-P)UU;)V5N86)L
M960G72DI('L*("`@("1?<')E9G-;)VEM<W!?875T:%]U<V5R)UT@/2!A<G)A
M>2@*("`@("`@("`G=F%L=64G(#T^("<G+`H@("`@("`@("=L;V-K960G(#T^
M(&9A;'-E+`H@("`@("`@("=S:&%R960G(#T^(&9A;'-E+`H@("`@("`@("=T
M>7!E)R`]/B`G=&5X="<L"B`@("`@("`@)V1E<V,G(#T^(%\H(D%L=&5R;F%T
M92!)35-0(%5S97)N86UE(BD*("`@("D["@H@("`@)%]P<F5F<ULG:6US<%]A
M=71H7W!A<W,G72`](&%R<F%Y*`H@("`@("`@("=V86QU92<@/3X@)R<L"B`@
M("`@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`@("`@)W-H87)E9"<@/3X@
M9F%L<V4L"B`@("`@("`@)W1Y<&4G(#T^("=P87-S=V]R9"<L"B`@("`@("`@
M)V1E<V,G(#T^(%\H(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(BD*("`@("D[
M"GT*"B\O(%)I8V@@5&5X="!%9&ET;W(@<')E9F5R96YC97,N"@HD7W!R969S
M6R=C;VYT97AT;65N=2==(#T@87)R87DH"B`@("`G=F%L=64G(#T^('1R=64L
M"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^('1R=64L
M"B`@("`G='EP92<@/3X@)V-H96-K8F]X)RP*("`@("=D97-C)R`]/B!?*")%
M;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(I"BD["@HD7W!R969S
M6R=T86)L96]P97)A=&EO;G,G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B!F
M86QS92P*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@
M=')U92P*("`@("=T>7!E)R`]/B`G8VAE8VMB;W@G+`H@("`@)V1E<V,G(#T^
M(%\H(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B*0HI.PH*)%]P
M<F5F<ULG;&ES='1Y<&4G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B!T<G5E
M+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E
M+`H@("`@)W1Y<&4G(#T^("=C:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@7R@B
M06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B*0HI.PH*:68@
M*"1R96=I<W1R>2T^:&%S26YT97)F86-E*"=I;6%G97,G*2D@>PH@("`@)%]P
M<F5F<ULG86YS96QI;6%G92==(#T@87)R87DH"B`@("`@("`@)W9A;'5E)R`]
M/B!T<G5E+`H@("`@("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@("`@("=S
M:&%R960G(#T^('1R=64L"B`@("`@("`@)W1Y<&4G(#T^("=C:&5C:V)O>"<L
M"B`@("`@("`@)V1E<V,G(#T^(%\H(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA
M9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(BD*("`@("D["GT*
M"B\O($5N9"!2:6-H(%1E>'0@161I=&]R('!R969E<F5N8V5S+@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]E=&,O<'-A+6AO<F1E+VAO<F1E+W)E9VES
M=')Y+G!H<```````````````````````````````````````````````````
M```````````````````P,#`P-#0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-C<P-P`Q,#4Q-30S,S<W-``P,C(Q,C8`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(')E9VES=')Y+G!H
M<"`M+2!(;W)D92!A<'!L:6-A=&EO;B!R96=I<W1R>2X*("H*("H@)$AO<F1E
M.B!H;W)D92]C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0L=B`Q+C(U-2XR+C$W
M(#(P,#8O,#<O,C$@,34Z-#DZ-#8@:F%N($5X<"`D"B`J"B`J(%1H:7,@8V]N
M9FEG=7)A=&EO;B!F:6QE(&ES('5S960@8GD@2&]R9&4@=&\@9&5T97)M:6YE
M('=H:6-H($AO<F1E"B`J(&%P<&QI8V%T:6]N<R!A<F4@:6YS=&%L;&5D(&%N
M9"!W:&5R92P@87,@=V5L;"!A<R!H;W<@=&AE>2!I;G1E<F%C="X*("H*("H@
M07!P;&EC871I;VX@<F5G:7-T<GD*("H@+2TM+2TM+2TM+2TM+2TM+2TM+2T*
M("H@5&AE(&9O;&QO=VEN9R!S971T:6YG<R!R96=I<W1E<B!I;G-T86QL960@
M2&]R9&4@87!P;&EC871I;VYS+@H@*B!">2!D969A=6QT+"!(;W)D92!A<W-U
M;65S('1H870@=&AE(&%P<&QI8V%T:6]N(&1I<F5C=&]R:65S(&QI=F4*("H@
M:6YS:61E('1H92!H;W)D92!D:7)E8W1O<GDN"B`J"B`J($%T=')I8G5T92`@
M("`@5'EP92`@("`@1&5S8W)I<'1I;VX*("H@+2TM+2TM+2TM("`@("`M+2TM
M("`@("`M+2TM+2TM+2TM+0H@*B!F:6QE<F]O="`@("`@('-T<FEN9R`@(%1H
M92!B87-E(&9I;&5S>7-T96T@<&%T:"!F;W(@=&AE(&UO9'5L92=S(&9I;&5S
M+@H@*B!W96)R;V]T("`@("`@('-T<FEN9R`@(%1H92!B87-E(%5222!F;W(@
M=&AE(&UO9'5L92X*("H@:G-U<FD@("`@("`@("!S=')I;F<@("!4:&4@8F%S
M92!54DD@9F]R('-T871I8R!J879A<V-R:7!T(&9I;&5S+@H@*B!J<V9S("`@
M("`@("`@('-T<FEN9R`@(%1H92!B87-E(&9I;&5S>7-T96T@<&%T:"!F;W(@
M<W1A=&EC(&IA=F%S8W)I<'0@9FEL97,N"B`J('1H96UE<W5R:2`@("`@<W1R
M:6YG("`@5&AE(&)A<V4@55))(&9O<B!T:&4@=&AE;65S+B!4:&ES(&-A;B!B
M92!U<V5D('1O"B`J("`@("`@("`@("`@("`@("`@("`@("`@<V5R=F4@86QL
M(&EC;VYS(&%N9"!S='EL92!S:&5E=',@9G)O;2!A('-E<&%R871E"B`J("`@
M("`@("`@("`@("`@("`@("`@("`@<V5R=F5R+@H@*B!T:&5M97-F<R`@("`@
M('-T<FEN9R`@(%1H92!B87-E(&9I;&4@<WES=&5M(&1I<F5C=&]R>2!F;W(@
M=&AE('1H96UE<RX*("H@:6-O;B`@("`@("`@("!S=')I;F<@("!4:&4@55))
M(&9O<B!A;B!I8V]N('1O('-H;W<@:6X@;65N=7,@9F]R('1H92!M;V1U;&4N
M"B`J("`@("`@("`@("`@("`@("`@("`@("`@4V5T=&EN9R!T:&ES('=I;&P@
M;W9E<G)I9&4@=&AE(&1E9F%U;'0@=&AE;64M8F%S960*("H@("`@("`@("`@
M("`@("`@("`@("`@("!L;V=I8R!I;B!T:&4@8V]D92X*("H@;F%M92`@("`@
M("`@("!S=')I;F<@("!4:&4@;F%M92!U<V5D(&EN(&UE;G5S(&%N9"!D97-C
M<FEP=&EO;G,@9F]R(&$@;6]D=6QE"B`J('-T871U<R`@("`@("`@<W1R:6YG
M("`@)VEN86-T:79E)RP@)VAI9&1E;B<L("=N;W1O;VQB87(G+"`G:&5A9&EN
M9R<L"B`J("`@("`@("`@("`@("`@("`@("`@("`@)V)L;V-K)RP@)V%D;6EN
M)RP@;W(@)V%C=&EV92<N"B`J('!R;W9I9&5S("`@("`@<W1R:6YG("`@4V5R
M=FEC92!T>7!E<R!T:&4@;6]D=6QE('!R;W9I9&5S+@H@*B!I;FET:6%L7W!A
M9V4@('-T<FEN9R`@(%1H92!I;FET:6%L("AD969A=6QT*2!P86=E("AF:6QE
M;F%M92D@9F]R('1H92!M;V1U;&4N"B`J('1E;7!L871E<R`@("`@<W1R:6YG
M("`@5&AE(&9I;&5S>7-T96T@<&%T:"!T;R!T:&4@=&5M<&QA=&5S(&1I<F5C
M=&]R>2X*("H@;65N=5]P87)E;G0@("!S=')I;F<@("!4:&4@;F%M92!O9B!T
M:&4@)VAE861I;F<G(&=R;W5P('1H870@=&AI<R!A<'`@<VAO=6QD"B`J("`@
M("`@("`@("`@("`@("`@("`@("`@<VAO=R!U<"!U;F1E<BX*("H@=&%R9V5T
M("`@("`@("!S=')I;F<@("!4:&4@*&]P=&EO;F%L*2!T87)G970@9G)A;64@
M9F]R('1H92!L:6YK+@H@*B!U<FP@("`@("`@("`@('-T<FEN9R`@(%1H92`H
M;W!T:6]N86PI(%523"!O9B`G:&5A9&EN9R<@96YT<FEE<RX*("HO"@HO+R!7
M92!T<GD@=&\@875T;VUA=&EC86QL>2!D971E<FUI;F4@=&AE('!R;W!E<B!W
M96)R;V]T(&9O<B!(;W)D90HO+R!H97)E+B!4:&ES('-T:6QL(&%S<W5M97,@
M=&AA="!A<'!L:6-A=&EO;G,@;&EV92!U;F1E<B!H;W)D92\N($EF"B\O('1H
M:7,@<F5S=6QT<R!I;B!I;F-O<G)E8W0@<F5S=6QT<R!F;W(@>6]U+"!S:6UP
M;'D@8VAA;F=E('1H92!T=V\*+R\@=7-E<R!O9B!T:&4@)'=E8G)O;W0@=F%R
M:6%B;&4@:6X@=&AE("=H;W)D92<@<W1A;GIA(&)E;&]W+@HO+PHO+R!.;W1E
M(&9O<B!7:6YD;W=S('5S97)S.B!T:&4@8F5L;W<@87-S=6UE<R!T:&%T('EO
M=7(@4$A07U-%3$8*+R\@=F%R:6%B;&4@=7-E<R!F;W)W87)D('-L87-H97,N
M($EF(&ET(&1O97,@;F]T+"!Y;W4G;&P@:&%V92!T;R!T=V5A:PHO+R!T:&ES
M+@II9B`H:7-S970H)%]315)615);)U!(4%]314Q&)UTI*2!["B`@("`D=V5B
M<F]O="`]('!R96=?<W!L:70H)SLO.R<L("1?4T525D526R=02%!?4T5,1B==
M+"`R+"!04D5'7U-03$E47TY/7T5-4%19*3L*("`@("1W96)R;V]T(#T@<W1R
M<W1R*&1I<FYA;64H7U]&24Q%7U\I+"!$25)%0U1/4EE?4T5005)!5$]2("X@
M87)R87E?<VAI9G0H)'=E8G)O;W0I*3L*("`@(&EF("@D=V5B<F]O="`A/3T@
M9F%L<V4I('L*("`@("`@("`D=V5B<F]O="`]('!R96=?<F5P;&%C92AA<G)A
M>2@G+UQ<7%PO)RP@)SLO8V]N9FEG)#LG*2P@87)R87DH)R\G+"`G)RDL("1W
M96)R;V]T*3L*("`@('T@96QS96EF("@D=V5B<F]O="`]/3T@9F%L<V4I('L*
M("`@("`@("`D=V5B<F]O="`]("<G.PH@("`@?2!E;'-E('L*("`@("`@("`D
M=V5B<F]O="`]("<O:&]R9&4G.PH@("`@?0I](&5L<V4@>PH@("`@)'=E8G)O
M;W0@/2`G+VAO<F1E)SL*?0H*)'1H:7,M/F%P<&QI8V%T:6]N<ULG:&]R9&4G
M72`](&%R<F%Y*`H@("`@)V9I;&5R;V]T)R`]/B`G+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E)RP*("`@("=W96)R;V]T)R`]/B`D=V5B<F]O="P*("`@("=I
M;FET:6%L7W!A9V4G(#T^("=L;V=I;BYP:'`G+`H@("`@)VYA;64G(#T^(%\H
M(DAO<F1E(BDL"B`@("`G<W1A='5S)R`]/B`G86-T:79E)RP*("`@("=T96UP
M;&%T97,G(#T^("<O=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S
M)RP*("`@("=P<F]V:61E<R<@/3X@)VAO<F1E)PHI.PH*+RH@"B`J($AA8VL@
M=&\@;6%K92!R96=I<W1E<FEN9R!O9B!P86-K86=E<R!E87-Y('=I=&AO=70@
M961I=&EN9PH@*B!C;VYF:6=U<F%T:6]N(&9I;&5S+"!S=&]L96X@9G)O;2!$
M96)I86X*("HO"@II9B`H)&0@/2!`;W!E;F1I<B@G+W5S<B]L;V-A;"]P<V$O
M971C+W!S82UH;W)D92]H;W)D92]R96=I<W1R>2YD)RDI('L*("`@('=H:6QE
M("@D9B`](')E861D:7(H)&0I*2![(`H@("`@("`@(&EF("AE<F5G*"(N<&AP
M)"(L("1F*2D@>PH@("`@("`@("`@("!I;F-L=61E7V]N8V4@)R\O=7-R+VQO
M8V%L+W!S82]E=&,O<'-A+6AO<F1E+VAO<F1E+W)E9VES=')Y+F0O)R`N("1F
M.PH@("`@("`@('T*("`@('T*("`@(&-L;W-E9&ER*"1D*3L*?0H`````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`U,34T,S,W-S0`,#$U-C8Q`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O861M:6XO````````````````````````````````````````````````
M```````````````````````````````````````````P,#`P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<T-``P,38W-#8`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]C;61S:&5L;"YP:'``````````
M````````````````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,C4S`#$P-3$U
M-#,S-S0T`#`R,3(U-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]A9&UI;B]C
M;61S:&5L;"YP:'`L=B`Q+CDN,3`N-B`R,#`V+S`R+S(T(#(R.C0X.C(Y(&-H
M=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D
M969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXG
M*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<[
M"G)E<75I<F5?;VYC92`G2&]R9&4O365N=2YP:'`G.PIR97%U:7)E7V]N8V4@
M)TAO<F1E+TAE;'`N<&AP)SL*"FEF("@A075T:#HZ:7-!9&UI;B@I*2!["B`@
M("!(;W)D93HZ9F%T86PH)T9O<F)I9&1E;BXG+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PI]"@HD=&ET;&4@/2!?*")#;VUM86YD(%-H96QL(BD["G)E<75I<F4@
M2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["G)E<75I
M<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN
M8R<["@IE8VAO("<\9&EV('-T>6QE/2)P861D:6YG.C$P<'@B/B<["FEF("@D
M8V]M;6%N9"`]('1R:6TH571I;#HZ9V5T1F]R;41A=&$H)V-M9"<I*2D@>PH@
M("`@96-H;R`G/&@Q(&-L87-S/2)H96%D97(B/B<@+B!?*")#;VUM86YD(BD@
M+B`G.CPO:#$^/&)R("\^)SL*("`@(&5C:&\@)SQP(&-L87-S/2)T97AT(CX\
M8V]D93XG("X@;FPR8G(H:'1M;'-P96-I86QC:&%R<R@D8V]M;6%N9"DI("X@
M)SPO8V]D93X\+W`^)SL*"B`@("!E8VAO("<\8G(@+SX\:#$@8VQA<W,](FAE
M861E<B(^)R`N(%\H(E)E<W5L=',B*2`N("<Z/"]H,3X\8G(@+SXG.PH@("`@
M96-H;R`G/'!R92!C;&%S<STB=&5X="(^)SL*"B`@("`D8VUD<R`](&5X<&QO
M9&4H(EQN(BP@)&-O;6UA;F0I.PH@("`@9F]R96%C:"`H)&-M9',@87,@)&-M
M9"D@>PH@("`@("`@("1C;60@/2!T<FEM*"1C;60I.PH@("`@("`@(&EF("AS
M=')L96XH)&-M9"DI('L*("`@("`@("`@("`@=6YS970H)')E<W5L=',I.PH@
M("`@("`@("`@("!F;'5S:"@I.PH@("`@("`@("`@("!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H<VAE;&Q?97AE8R@D8VUD*2D["B`@("`@("`@?0H@("`@?0H*
M("`@(&5C:&\@)SPO<')E/CQB<B`O/B<["GT*/SX*"CQF;W)M(&%C=&EO;CTB
M/#]P:'`@96-H;R`D7U-%4E9%4ELG4$A07U-%3$8G72`_/B(@;65T:&]D/2)P
M;W-T(CX*/#]P:'`@571I;#HZ<&9O<FU);G!U="@I(#\^"CQT97AT87)E82!C
M;&%S<STB9FEX960B(&YA;64](F-M9"(@<F]W<STB,3`B(&-O;',](C8P(CX*
M/#]P:'`@:68@*"%E;7!T>2@D8V]M;6%N9"DI(&5C:&\@:'1M;'-P96-I86QC
M:&%R<R@D8V]M;6%N9"D@/SX\+W1E>'1A<F5A/@H\8G(@+SX*/&EN<'5T('1Y
M<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@
M7R@B17AE8W5T92(I(#\^(B`O/@H\/W!H<"!E8VAO($AE;'`Z.FQI;FLH)V%D
M;6EN)RP@)V%D;6EN+6-M9'-H96QL)RD@/SX*"CPO9F]R;3X*/"]D:78^"CP_
M<&AP"@IR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+69O;W1E
M<BYI;F,G.PH`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O861M:6XO9&%T871R964N<&AP````````````````
M```````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#<R,P`Q,#4Q-30S,S<T
M-``P,C$R-38`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O861M:6XO9&%T871R
M964N<&AP+'8@,2XW+C(N-"`R,#`V+S`R+S`Q(#`Y.C,P.C0V('-E;'-K>2!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IA;B!38VAN96ED97(@
M/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"F9U;F-T:6]N(&%D
M9%1R964H)'!A<F5N="P@)'!A<F5N=%]I9"P@)&EN9&5N="`](#$I"GL*("`@
M(&=L;V)A;"`D9&%T871R964L("1T<F5E.PH*("`@("1N;V1E<R`]("1D871A
M=')E92T^9V5T0GE)9"A$051!5%)%15]&3U)-051?1DQ!5"P@)'!A<F5N=%]I
M9"P@=')U92P@)'!A<F5N="P@,2D["B`@("`D97AP86YD960@/2`D=')E92T^
M:7-%>'!A;F1E9"@D<&%R96YT*3L*("`@("1U<FP@/2!(;W)D93HZ=7)L*"=D
M871A=')E92YP:'`G*3L*("`@(&9O<F5A8V@@*"1N;V1E<R!A<R`D:60@/3X@
M)&YO9&4I('L*("`@("`@("!I9B`H)&ED(#T]("1P87)E;G1?:60I('L*("`@
M("`@("`@("`@8V]N=&EN=64["B`@("`@("`@?0H@("`@("`@("1T<F5E+3YA
M9&1.;V1E*"1P87)E;G0@+B`G.B<@+B`D:60L("1P87)E;G0L("1D871A=')E
M92T^9V5T4VAO<G1.86UE*"1N;V1E*2P@)&EN9&5N="P@9F%L<V4L(&%R<F%Y
M*"=U<FPG(#T^(%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G<VAO=R<L("1D
M871A=')E92T^9V5T4&%R86TH)V=R;W5P)RD@+B`G.B<@+B`D:60I("X@)R-S
M:&]W)RDI.PH@("`@("`@(&EF("@D97AP86YD960I('L*("`@("`@("`@("`@
M861D5')E92@D<&%R96YT("X@)SHG("X@)&ED+"`D:60L("1I;F1E;G0@*R`Q
M*3L*("`@("`@("!]"B`@("!]"GT*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D
M:7)N86UE*%]?1DE,15]?*2`N("<O+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%
M7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O
M365N=2YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TAE;'`N<&AP)SL*<F5Q
M=6ER95]O;F-E("=(;W)D92]4<F5E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R
M9&4O1&%T851R964N<&AP)SL*"FEF("@A075T:#HZ:7-!9&UI;B@I*2!["B`@
M("!(;W)D93HZ875T:&5N=&EC871I;VY&86EL=7)E4F5D:7)E8W0H*3L*?0H*
M)'1R964@/2`F2&]R9&5?5')E93HZ9F%C=&]R>2@G9&%T871R964G+"`G:'1M
M;"<I.PHD=')E92T^<V5T3W!T:6]N*"=A;'1E<FYA=&4G+"!T<G5E*3L*"B1D
M<FEV97(@/2`D8V]N9ELG9&%T871R964G75LG9')I=F5R)UT["B1C;VYF:6<@
M/2!(;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=D871A=')E92<L("1C;VYF6R=D
M871A=')E92==6R=D<FEV97(G72D["B1D871A=')E92`]("9$871A5')E93HZ
M<VEN9VQE=&]N*"1C;VYF6R=D871A=')E92==6R=D<FEV97(G72D["B1R;V]T
M<R`]("1D871A=')E92T^9V5T1W)O=7!S*"D["@II9B`H:7-?82@D<F]O=',L
M("=014%27T5R<F]R)RDI('L*("`@("1N;W1I9FEC871I;VXM/G!U<V@H)')O
M;W1S*3L*?2!E;'-E('L*("`@(&9O<F5A8V@@*"1R;V]T<R!A<R`D<F]O="D@
M>PH@("`@("`@("1T<F5E+3YA9&1.;V1E*"1R;V]T+"!N=6QL+"`D<F]O="P@
M,"P@9F%L<V4I.PH@("`@("`@("1D871A=')E92`]("9$871A5')E93HZ<VEN
M9VQE=&]N*"1D<FEV97(L(&%R<F%Y7VUE<F=E*"1C;VYF:6<L(&%R<F%Y*"=G
M<F]U<"<@/3X@)')O;W0I*2D["B`@("`@("`@861D5')E92@D<F]O="P@1$%4
M0512145?4D]/5"D["B`@("!]"GT*"FEF("@D<VAO=R`](%5T:6PZ.F=E=$9O
M<FU$871A*"=S:&]W)RDI('L*("`@(&QI<W0H)')O;W0L("1I9"D@/2!E>'!L
M;V1E*"<Z)RP@)'-H;W<I.PH@("`@)&1A=&%T<F5E(#T@)D1A=&%4<F5E.CIS
M:6YG;&5T;VXH)&1R:79E<BP@87)R87E?;65R9V4H)&-O;F9I9RP@87)R87DH
M)V=R;W5P)R`]/B`D<F]O="DI*3L*("`@("1D871A(#T@)&1A=&%T<F5E+3YG
M971$871A*"1I9"D["B`@("`D871T<FEB=71E<R`]("1D871A=')E92T^9V5T
M071T<FEB=71E<R@D:60I.PI]"@HD=&ET;&4@/2!?*")$871A5')E92!"<F]W
M<V5R(BD["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A
M9&5R+FEN8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]C
M;VUM;VXM:&5A9&5R+FEN8R<["B1N;W1I9FEC871I;VXM/FYO=&EF>2@I.PHD
M=')E92T^<F5N9&5R5')E92@I.PII9B`H)'-H;W<I('L*("`@(&5C:&\@)SQB
M<B`O/CQD:78@8VQA<W,](G1E>'0B('-T>6QE/2)W:&ET92US<&%C93IP<F4B
M/CQA(&ED/2)S:&]W(CX\+V$^)SL*("`@('!R:6YT7W(H)&1A=&$I.PH@("`@
M<')I;G1?<B@D871T<FEB=71E<RD["B`@("!E8VAO("<\+V1I=CXG.PI]"G)E
M<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<[
M"@``````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O861M:6XO9W)O=7!S+G!H<```
M````````````````````````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,#$T
M,@`Q,#4Q-30S,S<T-``P,C`W-S4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O
M861M:6XO9W)O=7!S+G!H<"QV(#$N-3`N,BXV(#(P,#8O,#<O,3,@,#DZ,#$Z
M-3,@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO
M"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G
M+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP
M:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N<&AP)SL*<F5Q=6ER95]O
M;F-E("=(;W)D92]'<F]U<"YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+U1R
M964N<&AP)SL*"FEF("@A075T:#HZ:7-!9&UI;B@I*2!["B`@("!(;W)D93HZ
M875T:&5N=&EC871I;VY&86EL=7)E4F5D:7)E8W0H*3L*?0H*)&=R;W5P<R`]
M("9'<F]U<#HZ<VEN9VQE=&]N*"D["B1A=71H(#T@)D%U=&@Z.G-I;F=L971O
M;B@D8V]N9ELG875T:"==6R=D<FEV97(G72D["@HD9F]R;2`](&YU;&P["B1R
M96QO860@/2!F86QS93L*)&%C=&EO;DE$(#T@571I;#HZ9V5T1F]R;41A=&$H
M)V%C=&EO;DE$)RD["B1C:60@/2!5=&EL.CIG971&;W)M1&%T82@G8VED)RD[
M"@IS=VET8V@@*"1A8W1I;VY)1"D@>PIC87-E("=A9&1C:&EL9"<Z"B`@("!I
M9B`H)&-I9"`]/2!$051!5%)%15]23T]4*2!["B`@("`@("`@)&9O<FT@/2`G
M861D8VAI;&0N:6YC)SL*("`@("`@("`D9VYA;64@/2!?*")!;&P@1W)O=7!S
M(BD["B`@("!](&5L<V4@>PH@("`@("`@("1G<F]U<"`]("8D9W)O=7!S+3YG
M971'<F]U<$)Y260H)&-I9"D["B`@("`@("`@:68@*"%I<U]A*"1G<F]U<"P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D9VYA;64@/2`D9W)O=7`M
M/F=E=%-H;W)T3F%M92@I.PH@("`@("`@("`@("`D9F]R;2`]("=A9&1C:&EL
M9"YI;F,G.PH@("`@("`@('T*("`@('T*("`@(&)R96%K.PH*8V%S92`G861D
M8VAI;&1F;W)M)SH*("`@("1P87)E;G0@/2`D8VED.PH@("`@:68@*"1P87)E
M;G0@/3T@1$%40512145?4D]/5"D@>PH@("`@("`@("1C:&EL9"`]("8D9W)O
M=7!S+3YN97='<F]U<"A5=&EL.CIG971&;W)M1&%T82@G8VAI;&0G*2D["B`@
M("`@("`@)')E<W5L="`]("1G<F]U<',M/F%D9$=R;W5P*"1C:&EL9"D["B`@
M("!](&5L<V4@>PH@("`@("`@("1C:&EL9"`]("8D9W)O=7!S+3YN97='<F]U
M<"A5=&EL.CIG971&;W)M1&%T82@G8VAI;&0G*2P@)'!A<F5N="D["B`@("`@
M("`@)')E<W5L="`]("1G<F]U<',M/F%D9$=R;W5P*"1C:&EL9"D["B`@("!]
M"B`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E<W5L="P@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U
M<V@H<W!R:6YT9BA?*")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB*2P@
M)&-H:6QD+3YG9713:&]R=$YA;64H*2P@)')E<W5L="T^9V5T365S<V%G92@I
M*2P@)VAO<F1E+F5R<F]R)RD["B`@("!](&5L<V4@>PH@("`@("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")<(B5S7"(@=V%S(&%D9&5D('1O
M('1H92!G<F]U<',@<WES=&5M+B(I+"`D8VAI;&0M/F=E=%-H;W)T3F%M92@I
M*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("`D9W)O=7`@/2`D8VAI;&0[
M"B`@("`@("`@)&9O<FT@/2`G961I="YI;F,G.PH@("`@("`@("1R96QO860@
M/2!T<G5E.PH@("`@?0H@("`@8G)E86L["@IC87-E("=D96QE=&4G.@H@("`@
M)&=R;W5P(#T@)B1G<F]U<',M/F=E=$=R;W5P0GE)9"@D8VED*3L*("`@(&EF
M("@A:7-?82@D9W)O=7`L("=014%27T5R<F]R)RDI('L*("`@("`@("`D9F]R
M;2`]("=D96QE=&4N:6YC)SL*("`@('T*("`@(&)R96%K.PH*8V%S92`G9&5L
M971E9F]R;2<Z"B`@("!I9B`H571I;#HZ9V5T1F]R;41A=&$H)V-O;F9I<FTG
M*2`]/2!?*")$96QE=&4B*2D@>PH@("`@("`@("1G<F]U<"`]("8D9W)O=7!S
M+3YG971'<F]U<$)Y260H)&-I9"D["B`@("`@("`@:68@*&ES7V$H)&=R;W5P
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1N;W1I9FEC871I;VXM
M/G!U<V@H7R@B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O
M=7`N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1R97-U;'0@/2`D9W)O=7!S+3YR96UO=F5'<F]U<"@D9W)O=7`L
M('1R=64I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H
M*'-P<FEN=&8H7R@B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(I+"`D
M9W)O=7`M/F=E=%-H;W)T3F%M92@I+"`D<F5S=6QT+3YG971-97-S86=E*"DI
M+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B4W5C
M8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(I+"`D9W)O=7`M/F=E=%-H;W)T
M3F%M92@I*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("`@("`@("`@("1C
M:60@/2!N=6QL.PH@("`@("`@("`@("`@("`@)')E;&]A9"`]('1R=64["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]"B`@("!B<F5A:SL*"F-A<V4@
M)V5D:70G.@H@("`@)&=R;W5P(#T@)B1G<F]U<',M/F=E=$=R;W5P0GE)9"@D
M8VED*3L*("`@(&EF("@A:7-?82@D9W)O=7`L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`D9F]R;2`]("=E9&ET+FEN8R<["B`@("!](&5L<V5I9B`H*"1C
M871E9V]R>2`](%5T:6PZ.F=E=$9O<FU$871A*"=C871E9V]R>2<I*2`A/3T@
M;G5L;"D@>PH@("`@("`@("1G<F]U<"`]("8D9W)O=7!S+3YG971'<F]U<"@D
M8V%T96=O<GDI.PH@("`@("`@(&EF("@A:7-?82@D9W)O=7`L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@)&9O<FT@/2`G961I="YI;F,G.PH@("`@
M("`@('T@96QS96EF("A5=&EL.CIG971&;W)M1&%T82@G875T;V-R96%T92<I
M*2!["B`@("`@("`@("`@("1P87)E;G0@/2!5=&EL.CIG971&;W)M1&%T82@G
M<&%R96YT)RD["B`@("`@("`@("`@("1G<F]U<"`]("8D9W)O=7!S+3YN97='
M<F]U<"@D8V%T96=O<GDI.PH@("`@("`@("`@("`D<F5S=6QT(#T@)&=R;W5P
M<RT^861D1W)O=7`H)&=R;W5P+"`D<&%R96YT*3L*("`@("`@("`@("`@:68@
M*"%I<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@("1F;W)M(#T@)V5D:70N:6YC)SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*("`@(&)R96%K.PH*8V%S92`G961I=&9O<FTG.@H@("`@)&=R
M;W5P(#T@)B1G<F]U<',M/F=E=$=R;W5P0GE)9"@D8VED*3L*"B`@("`O+R!M
M86ME(&$@8V]P>2!O9B!T:&4@9W)O=7`@<V\@=V4@8V%N(')E<W1O<F4@:70@
M:68@=&AE<F4@:7,@86X@97)R;W(N"B`@("`D<F5S=&]R92`]("1G<F]U<#L*
M"B`@("`O+R!!9&0@86YY(&YE=R!U<V5R<RX*("`@("1N97=U<V5R(#T@571I
M;#HZ9V5T1F]R;41A=&$H)VYE=U]U<V5R)RD["B`@("!I9B`H(65M<'1Y*"1N
M97=U<V5R*2D@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D;F5W=7-E<BDI('L*
M("`@("`@("`@("`@9F]R96%C:"`H)&YE=W5S97(@87,@)&YE=RD@>PH@("`@
M("`@("`@("`@("`@)&=R;W5P+3YA9&15<V5R*"1N97<L(&9A;'-E*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1G<F]U
M<"T^861D57-E<B@D;F5W=7-E<BP@9F%L<V4I.PH@("`@("`@('T*("`@('T*
M"B`@("`O+R!296UO=F4@86YY('5S97)S(&UA<FME9"!F;W(@<'5R9VEN9RX*
M("`@("1R96UO=F5S(#T@571I;#HZ9V5T1F]R;41A=&$H)W)E;6]V92<I.PH@
M("`@:68@*"%E;7!T>2@D<F5M;W9E<RD@)B8@:7-?87)R87DH)')E;6]V97,I
M*2!["B`@("`@("`@9F]R96%C:"`H)')E;6]V97,@87,@)'5S97(@/3X@)&IU
M;FLI('L*("`@("`@("`@("`@)&=R;W5P+3YR96UO=F55<V5R*"1U<V5R+"!F
M86QS92D["B`@("`@("`@?0H@("`@?0H*("`@("\O(%-E="!T:&4@96UA:6P@
M861D<F5S<R!O9B!T:&4@9W)O=7`N"B`@("`D9W)O=7`M/G-E="@G96UA:6PG
M+"!5=&EL.CIG971&;W)M1&%T82@G96UA:6PG*2D["@H@("`@+R\@4V%V92!T
M:&4@9W)O=7`@=&\@=&AE(&)A8VME;F0N"B`@("`D<F5S=6QT(#T@)&=R;W5P
M+3YS879E*"D["@H@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)')E<W5L="T^9V5T
M365S<V%G92@I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`O+R!R97-T;W)E
M(&)A8VMU<"!C;W!Y"B`@("`@("`@)&=R;W5P(#T@)')E<W1O<F4["B`@("!]
M(&5L<V4@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?
M*")5<&1A=&5D(%PB)7-<(BXB*2P@)&=R;W5P+3YG9713:&]R=$YA;64H*2DL
M("=H;W)D92YS=6-C97-S)RD["B`@("!]"@H@("`@)&9O<FT@/2`G961I="YI
M;F,G.PH@("`@)')E;&]A9"`]('1R=64["B`@("!B<F5A:SL*?0H*<W=I=&-H
M("@D9F]R;2D@>PIC87-E("=A9&1C:&EL9"YI;F,G.@H@("`@)&YO=&EF:6-A
M=&EO;BT^<'5S:"@G9&]C=6UE;G0N861D7V-H:6QD+F-H:6QD+F9O8W5S*"DG
M+"`G:F%V87-C<FEP="<I.PH@("`@8G)E86L["@IC87-E("=E9&ET+FEN8R<Z
M"B`@("`O*B!3970@=7`@=&AE(&QI<W1S+B`J+PH@("`@)'5S97)S(#T@)&=R
M;W5P+3YL:7-T57-E<G,H*3L*("`@(&EF("AI<U]A*"1U<V5R<RP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)'5S97)S
M+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`D=7-E<G,@/2!A<G)A>2@I.PH@
M("`@?0H@("`@)&%L;%]U<V5R<R`]("1G<F]U<"T^;&ES=$%L;%5S97)S*"D[
M"B`@("!I9B`H:7-?82@D86QL7W5S97)S+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D86QL7W5S97)S+"`G:&]R9&4N
M97)R;W(G*3L*("`@("`@("`D86QL7W5S97)S(#T@87)R87DH*3L*("`@('T*
M("`@("1I;FAE<FET961?=7-E<G,@/2!A<G)A>5]D:69F*"1A;&Q?=7-E<G,L
M("1U<V5R<RD["@H@("`@:68@*"1A=71H+3YH87-#87!A8FEL:71Y*"=L:7-T
M)RDI('L*("`@("`@("`D=7-E<E]L:7-T(#T@)&%U=&@M/FQI<W15<V5R<R@I
M.PH@("`@("`@(&EF("AI<U]A*"1U<V5R7VQI<W0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D=7-E<E]L:7-T
M+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@)'5S97)?;&ES="`](&%R
M<F%Y*"D["B`@("`@("`@?0H@("`@("`@('-O<G0H)'5S97)?;&ES="D["B`@
M("!](&5L<V4@>PH@("`@("`@("1U<V5R7VQI<W0@/2!A<G)A>2@I.PH@("`@
M?0H@("`@8G)E86L["@I]"@HD=&ET;&4@/2!?*")'<F]U<"!!9&UI;FES=')A
M=&EO;B(I.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+6AE
M861E<BYI;F,G.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O861M:6XO
M8V]M;6]N+6AE861E<BYI;F,G.PHD;F]T:69I8V%T:6]N+3YN;W1I9GDH87)R
M87DH)VQI<W1E;F5R<R<@/3X@)W-T871U<R<I*3L*:68@*"%E;7!T>2@D9F]R
M;2DI('L*("`@(')E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]G
M<F]U<',O)R`N("1F;W)M.PI]"@HO*B!'970@=&AE('!E<FUS('1R964N("HO
M"B1N;V1E<R`]("1G<F]U<',M/FQI<W1'<F]U<',H=')U92D["B1N;V1E<UM$
M051!5%)%15]23T]472`]($1!5$%44D5%7U)/3U0["@HO*B!3970@=7`@<V]M
M92!N;V1E('!A<F%M<RX@*B\*)'-P86-E<B`]("<F;F)S<#LF;F)S<#LF;F)S
M<#LF;F)S<#LG.PHD:6-O;F1I<B`](&%R<F%Y*"=I8V]N9&ER)R`]/B`D<F5G
M:7-T<GDM/F=E=$EM86=E1&ER*"DI.PHD9W)O=7!?;F]D92`]("1I8V]N9&ER
M("L@87)R87DH)VEC;VXG(#T^("=G<F]U<"YP;F<G*3L*)&%D9"`]($AO<F1E
M.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO9W)O=7!S+G!H<#]A8W1I;VY)1#UA
M9&1C:&EL9"<I.PHD961I="`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G861M
M:6XO9W)O=7!S+G!H<#]A8W1I;VY)1#UE9&ET)RD["B1D96QE=&4@/2!(;W)D
M93HZ87!P;&EC871I;VY5<FPH)V%D;6EN+V=R;W5P<RYP:'`_86-T:6]N240]
M9&5L971E)RD["B1E9&ET7VEM9R`]($AO<F1E.CII;6<H)V5D:70N<&YG)RP@
M7R@B161I="!'<F]U<"(I*3L*)&1E;&5T95]I;6<@/2!(;W)D93HZ:6UG*"=D
M96QE=&4N<&YG)RP@7R@B1&5L971E($=R;W5P(BDI.PH*+RH@4V5T('5P('1H
M92!T<F5E+B`J+PHD=')E92`]($AO<F1E7U1R964Z.F9A8W1O<GDH)V%D;6EN
M7V=R;W5P<R<L("=J879A<V-R:7!T)RD["B1T<F5E+3YS971/<'1I;VXH87)R
M87DH)V%L=&5R;F%T92<@/3X@=')U92P@)VAI9&5(96%D97)S)R`]/B!T<G5E
M*2D["B1T<F5E+3YS971(96%D97(H87)R87DH87)R87DH)W=I9'1H)R`]/B`G
M-3`E)RDI*3L*"B\J($5X<&QI8VET;'D@8VAE8VL@9F]R(#X@,"!S:6YC92!W
M92!C86X@8F4@8V%L;&5D('=I=&@@8W5R<F5N="`]("TQ"B`J(&9O<B!T:&4@
M<F]O="!N;V1E+B`J+PII9B`H)&-I9"`^(#`I('L*("`@("1C:61?<&%R96YT
M<R`]("1G<F]U<',M/F=E=$=R;W5P4&%R96YT3&ES="@D8VED*3L*("`@(&EF
M("AI<U]A*"1C:61?<&%R96YT<RP@)U!%05)?15)R;W(G*2D@>PH@("`@("`@
M($AO<F1E.CIF871A;"@D8VED7W!A<F5N=',L(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("!]"GT*"F9O<F5A8V@@*"1N;V1E<R!A<R`D:60@/3X@)&YO9&4I
M('L*("`@("1N;V1E7W!A<F%M<R`]("@D8VED(#T]("1I9"D@/R!A<G)A>2@G
M8VQA<W,G(#T^("=S96QE8W1E9"<I(#H@87)R87DH*3L*("`@(&EF("@D:60@
M/3T@1$%40512145?4D]/5"D@>PH@("`@("`@("1A9&1?:6UG(#T@2&]R9&4Z
M.FEM9R@G9W)O=7`N<&YG)RP@7R@B061D($YE=R!'<F]U<"(I*3L*("`@("`@
M("`D861D7VQI;FL@/2!(;W)D93HZ;&EN:RA5=&EL.CIA9&1087)A;65T97(H
M)&%D9"P@)V-I9"<L("1I9"DL(%\H(D%D9"!.97<@1W)O=7`B*2D@+B`D861D
M7VEM9R`N("<\+V$^)SL*"B`@("`@("`@)&)A<V5?;F]D95]P87)A;7,@/2`D
M:6-O;F1I<B`K(&%R<F%Y*"=I8V]N)R`]/B`G861M:6YI<W1R871I;VXN<&YG
M)RD["B`@("`@("`@)'1R964M/F%D9$YO9&4H)&ED+"!N=6QL+"!?*")!;&P@
M1W)O=7!S(BDL(#`L('1R=64L("1B87-E7VYO9&5?<&%R86US("L@)&YO9&5?
M<&%R86US+"!A<G)A>2@D<W!A8V5R+"`D861D7VQI;FLI*3L*("`@('T@96QS
M92!["B`@("`@("`@)&YO9&5?<&%R86US6R=U<FPG72`](%5T:6PZ.F%D9%!A
M<F%M971E<B@D961I="P@)V-I9"<L("1I9"D["B`@("`@("`@)&%D9%]I;6<@
M/2!(;W)D93HZ:6UG*"=G<F]U<"YP;F<G+"!?*")!9&0@0VAI;&0@1W)O=7`B
M*2D["B`@("`@("`@)&%D9%]L:6YK(#T@2&]R9&4Z.FQI;FLH571I;#HZ861D
M4&%R86UE=&5R*"1A9&0L("=C:60G+"`D:60I+"!?*")!9&0@0VAI;&0@1W)O
M=7`B*2D@+B`D861D7VEM9R`N("<\+V$^)SL*("`@("`@("`D9&5L971E7VQI
M;FL@/2!(;W)D93HZ;&EN:RA5=&EL.CIA9&1087)A;65T97(H)&1E;&5T92P@
M)V-I9"<L("1I9"DL(%\H(D1E;&5T92!'<F]U<"(I*2`N("1D96QE=&5?:6UG
M("X@)SPO83XG.PH*("`@("`@("`D<&%R96YT7VED(#T@)&=R;W5P<RT^9V5T
M1W)O=7!087)E;G0H)&ED*3L*("`@("`@("`D9W)O=7!?97AT<F$@/2!A<G)A
M>2@D<W!A8V5R+"`D861D7VQI;FLL("1D96QE=&5?;&EN:RD["B`@("`@("`@
M)'1R964M/F%D9$YO9&4H)&ED+"`D<&%R96YT7VED+"`D9W)O=7!S+3YG971'
M<F]U<%-H;W)T3F%M92@D;F]D92DL("1G<F]U<',M/F=E=$QE=F5L*"1I9"D@
M*R`Q+"`H:7-S970H)&-I9%]P87)E;G1S6R1I9%TI*2`_('1R=64@.B!F86QS
M92P@)&=R;W5P7VYO9&4@*R`D;F]D95]P87)A;7,L("1G<F]U<%]E>'1R82D[
M"B`@("!]"GT*"F5C:&\@)SQH,2!C;&%S<STB:&5A9&5R(CXG("X@2&]R9&4Z
M.FEM9R@G9W)O=7`N<&YG)RD@+B`G("<@+B!?*")'<F]U<',B*2`N("<\+V@Q
M/B<["B1T<F5E+3YR96YD97)4<F5E*"D["G)E<75I<F4@2$]21$5?5$5-4$Q!
M5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O861M:6XO:6YD97@N<&AP````````````````
M````````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3(U-P`Q,#4Q-30S
M,S<T-``P,C`U-S,`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O861M:6XO:6YD
M97@N<&AP+'8@,2XQ-2XX+C,@,C`P-B\P,2\P,2`R,3HR.#HP-2!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:&%R;&5S($HN($AA9V5N
M8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E
M9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I
M.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*
M<F5Q=6ER95]O;F-E("=(;W)D92]-96YU+G!H<"<["@II9B`H(4%U=&@Z.FES
M061M:6XH*2D@>PH@("`@2&]R9&4Z.F9A=&%L*"=&;W)B:61D96XN)RP@7U]&
M24Q%7U\L(%]?3$E.15]?*3L*?0H*)'1I=&QE(#T@7R@B061M:6YI<W1R871I
M;VXB*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUH96%D
M97(N:6YC)SL*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V%D;6EN+V-O
M;6UO;BUH96%D97(N:6YC)SL*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G
M+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O861M:6XO;&]C86QE+P``````````
M````````````````````````````````````````````````````````````
M```````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#4Q-30S,S<T-``P,C`R,#4`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]A9&UI
M;B]L;V-A;&4O96Y?55,O````````````````````````````````````````
M`````````````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S0T`#`R,3(Q-@`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+V%D;6EN+VQO8V%L92]E;E]54R]H96QP+GAM;```````
M````````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,R,38`,3`U,34T,S,W-#0`
M,#(R-C<R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_>&UL('9E<G-I;VX])S$N,"<_/@H\(2TM("1(;W)D93H@:&]R9&4O
M861M:6XO;&]C86QE+V5N7U53+VAE;'`N>&UL+'8@,2XS(#(P,#,O,#8O,30@
M,#0Z,C@Z,C$@8VAU8VL@17AP("0@+2T^"CQH96QP/@H*/&5N=')Y(&ED/2)A
M9&UI;BUP:'!S:&5L;"(^"B`@("`\=&ET;&4^061M:6X@5&]O;',Z(%!(4"!3
M:&5L;#PO=&ET;&4^"B`@("`\:&5A9&EN9SY(;W<@=&\@=7-E('1H92!02%`@
M4VAE;&P\+VAE861I;F<^"B`@("`\<&%R83Y4:&4@4$A0(&-O;6UA;F0@<VAE
M;&P@;&5T<R!Y;W4@97AE8W5T92!A<F)I=')A<GD@4$A0"B`@("`@("`@("!S
M=&%T96UE;G1S(&]N('1H92!S97)V97(N(%1H97-E(&-O;6UA;F1S(&%R92!E
M>&5C=71E9"!U<VEN9PH@("`@("`@("`@=&AE(#QC;V1E/F5V86PH*3PO8V]D
M93X@9G5N8W1I;VXL(&%N9"!E>&5C=71E(&EN('1H92!C;VYT97AT"B`@("`@
M("`@("!O9B!T:&4@8W5R<F5N="!S97-S:6]N+B!4:&ES('-H96QL(&ES(&EN
M=&5N9&5D('1O('1R>2!O=70*("`@("`@("`@('-Y;G1A>"!A;F0@97AE8W5T
M92!S;VUE('-I;7!L92!A<F)I=')A<GD@8V]D92X@3F]T92!T:&%T('1O"B`@
M("`@("`@("!G970@86YY(&]U='!U="P@>6]U(&UU<W0@96-H;R!O<B!P<FEN
M="!S;VUE=&AI;F<@:6X@>6]U<@H@("`@("`@("`@8V]D92!F<F%G;65N="X\
M+W!A<F$^"CPO96YT<GD^"@H\96YT<GD@:60](F%D;6EN+7-Q;'-H96QL(CX*
M("`@(#QT:71L93Y!9&UI;B!4;V]L<SH@4U%,(%-H96QL/"]T:71L93X*("`@
M(#QH96%D:6YG/DAO=R!T;R!U<V4@=&AE(%-13"!3:&5L;#PO:&5A9&EN9SX*
M("`@(#QP87)A/E1H92!344P@<75E<GD@<VAE;&P@;&5T<R!Y;W4@97AE8W5T
M92!A<F)I=')A<GD@4U%,"B`@("`@("`@("!S=&%T96UE;G1S(&]N('EO=7(@
M9&%T86)A<V4N(%1H97-E(&-O;6UA;F1S(&%R92!E>&5C=71E9`H@("`@("`@
M("`@86=A:6YS="!T:&4@9&%T86)A<V4@9&5F:6YE9"!I;B`D8V]N9ELG<W%L
M)UT@=7-I;F<@=&AE"B`@("`@("`@("!014%2.CI$0B!C;&%S<V5S+B!9;W4@
M8V%N('5S92!T:&ES('1O;VP@=&\@9&\@<75E<FEE<R!I;G1O"B`@("`@("`@
M("!T:&4@9&%T86)A<V4L('1O(&1O(&-O;7!L:6-A=&5D(%-13"!U<&1A=&5S
M+"!D96QE=&5S+"!E=&,N+`H@("`@("`@("`@;W(@=&\@9&\@<VEM<&QE(&1A
M=&$@8V]L;&5C=&EO;BX@270@<V5N9',@4U%,('%U97)I97,@=&\@=&AE"B`@
M("`@("`@("!D871A8F%S92!D:7)E8W1L>2P@86YD('=I;&P@<F5P;W)T(')E
M='5R;B!C;V1E<R!A;F0@8V]M<&QE=&4*("`@("`@("`@(')E<W5L="!S971S
M+CPO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB861M:6XM8VUD<VAE;&PB
M/@H@("`@/'1I=&QE/D%D;6EN(%1O;VQS.B!#;VUM86YD(%-H96QL/"]T:71L
M93X*("`@(#QH96%D:6YG/DAO=R!T;R!U<V4@=&AE($-O;6UA;F0@4VAE;&P\
M+VAE861I;F<^"B`@("`\<&%R83Y4:&4@8V]M;6%N9"!S:&5L;"!L971S('EO
M=2!E>&5C=71E(&%R8FET<F%R>2!S:&5L;`H@("`@("`@("`@8V]M;6%N9',@
M;VX@>6]U<B!S97)V97(N(%EO=2!C86X@=7-E('1H:7,@=&\@9&\@<75I8VL*
M("`@("`@("`@('-H96QL(&]P97)A=&EO;G,@;W(@=VAE;B!A('-H96QL(&ES
M(&YO="!O=&AE<G=I<V4@879A:6QA8FQE+@H@("`@("`@("`@/"]P87)A/@H\
M+V5N=')Y/@H*/"]H96QP/@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]A9&UI;B]L;V-A;&4O9FE?1DDO````````````````````````
M`````````````````````````````````````````````````#`P,#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S0T`#`R,3$V
M,0`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D;6EN+VQO8V%L92]F:5]&22]H
M96QP+GAM;```````````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0R-C$`
M,3`U,34T,S,W-#0`,#(R-C,V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_>&UL('9E<G-I;VX](C$N,"(_/@H\(2TM("1(
M;W)D93H@:&]R9&4O861M:6XO;&]C86QE+V9I7T9)+VAE;'`N>&UL+'8@,2XQ
M+C$R+C(@,C`P-B\P,B\R."`Q-#HP,CHS-2!J86X@17AP("0@+2T^"CQH96QP
M/@H@(#QE;G1R>2!I9#TB861M:6XM<&AP<VAE;&PB(&UD-3TB9#4P,3<U.3%E
M9C1A,V8S.60Y-S@W8C4X,6$P86)B834B('-T871E/2)U<'1O9&%T92(^"B`@
M("`\=&ET;&4^66QL)B-X130[<&ED;VX@='DF(WA&-CMK86QU=#H@4$A0+6MO
M;65N=&]T=6QK:VD\+W1I=&QE/@H@("`@/&AE861I;F<^36ET96X@4$A0+6MO
M;65N=&]T=6QK:VEA(&LF(WA%-#MY=&5T)B-X130[)B-X130[;CPO:&5A9&EN
M9SX*("`@(#QP87)A/@H@("`@4$A0+6MO;65N=&]T=6QK:VES<V$@=F]I('-U
M;W)I='1A82!P86QV96QI;65L;&$@;6ET)B-X130[('1A:&%N<V$*("`@(%!(
M4"UK;VUE;G1O:F$N($XF(WA%-#MM)B-X130[(&MO;65N;F]T('-U;W)I=&5T
M86%N(#QC;V1E/F5V86PH*3PO8V]D93X*("`@(&9U;FMT:6]N('-I<R8C>$4T
M.VQL)B-X130[(&IA(&YY:WEI<V5N(&ES='5N;F]N(&MO;G1E:W-T:7-S82X@
M5"8C>$4T.VTF(WA%-#L*("`@(&MO;65N=&]T=6QK:VD@;VX@96YS:7-I:F%I
M<V5S=&D@=&%R:V]I=&5T='4@<WEN=&%K<VEN"B`@("!T87)K:7-T=6MS965N
M(&IA('EK<VEN:V5R=&%I<V5N(&MO;V1I;B!S=6]R:71U:W-E96XN($AU;VUA
M82P*("`@(&5T="8C>$4T.R!T=6QO<W1A86MS97-I(&IO=&%K:6XL(&YI:6X@
M<VEN=6X@<&ET)B-X130[)B-X130[(&LF(WA%-#MY='0F(WA%-#LF(WA%-#L@
M96-H;R!J80H@("`@<')I;G0@:V]M96YT;VIA+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB861M:6XM<W%L<VAE;&PB(&UD-3TB-6)D,F9C
M8CEC.38W.&4V,F-A,30Q-38V86(X9C1C-&8B('-T871E/2)U<'1O9&%T92(^
M"B`@("`\=&ET;&4^66QL)B-X130[<&ED;VX@='DF(WA&-CMK86QU=#H@4U%,
M+6MO;65N=&]T=6QK:VD\+W1I=&QE/@H@("`@/&AE861I;F<^36ET96X@4U%,
M+6MO;65N=&]T=6QK:VEA(&LF(WA%-#MY=&5T)B-X130[)B-X130[;CPO:&5A
M9&EN9SX*("`@(#QP87)A/@H@("`@4U%,+6MO;65N=&]T=6QK:7-S82!V;VD@
M<W5O<FET=&%A(&UI="8C>$4T.R!T86AA;G-A(%-13"UL875S96MK96ET82P@
M:F]T:V$*("`@('-U;W)I=&5T86%N('1I971O:V%N;F%S<V$N($LF(WA%-#MY
M=&5T="8C>$4T.W8F(WA%-#L@=&EE=&]K86YT82!O;@H@("`@;28C>$4T.R8C
M>$4T.W)I=&5L='D@)&-O;F9;)W-Q;"==(&IA('-I="8C>$4T.R!K)B-X130[
M>71E="8C>$4T.R8C>$4T.VX@4$5!4CI$0BUL=6]K86X*("`@(&%V=6QL82X@
M(%9O:70@:R8C>$4T.WET="8C>$4T.R8C>$4T.R!T)B-X130[="8C>$4T.R!T
M>28C>$8V.VMA;'5J82!T96AD)B-X130[:W-E<VD@:WES96QY:B8C>$4T.PH@
M("`@=&EE=&]K86YT86%N+"!P)B-X130[:79I='0F(WA%-#LF(WA%-#MK<V5S
M:2!T:65T;VIA('1I971O:V%N;F%S<V$L"B`@("!P;VES=&%A:W-E<VD@=&EE
M=&]J82!T:65T;VMA;FYA<W1A(&IN92X@=&%I(&AA:V5A('1I971O:F$*("`@
M('1I971O:V%N;F%S=&$N(%-13"UK;VUE;FYO="!L)B-X130[:&5T970F(WA%
M-#LF(WA%-#MN('-U;W)A86X@=&EE=&]K86YN86QL90H@("`@:F$@<&%L=75A
M<G9O;F$@='5L964@<W1A='5S:V]O9&D@:F$@:WES96QY;B!P86QA=71T86UA
M"B`@("!A<G9O+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M861M:6XM8VUD<VAE;&PB(&UD-3TB.61B8F4U.3,W,S5E96)B8C,T9&4Y.3%A
M-3=B.3AB.68B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^66QL)B-X
M130[<&ED;VX@='DF(WA&-CMK86QU=#H@2V]M96YT;W1U;&MK:3PO=&ET;&4^
M"B`@("`\:&5A9&EN9SY-:71E;B!K;VUE;G1O='5L:VMI82!K)B-X130[>71E
M="8C>$4T.R8C>$4T.VX\+VAE861I;F<^"B`@("`\<&%R83X*("`@($MO;65N
M=&]T=6QK:6X@879U;&QA('9O:70@<W5O<FET=&%A(&MO;65N=&]J82!W=W<M
M<&%L=F5L:6UE;&QA+B!6;VET(&LF(WA%-#MY='0F(WA%-#LF(WA%-#L@="8C
M>$4T.W0F(WA%-#L@=&]I;6EN=&]A(&MU;B!H86QU870@;F]P96%S=&D@<W5O
M<FET=&%A(&IO;FMU;B!K;VUE;FYO;B!P86QV96QI;65L;&$@:F$@:V]M96YT
M;W1U;&MK:2!E:2!O;&4@;75U=&5N(&LF(WA%-#MY=&5T="8C>$4T.W9I<W,F
M(WA%-#LN"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D;6EN+VQO
M8V%L92]H=5](52\`````````````````````````````````````````````
M````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`U,34T,S,W-#0`,#(Q,C$U`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O861M:6XO;&]C86QE+VAU7TA5+VAE;'`N>&UL````````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S<V,P`Q,#4Q-30S,S<T-``P,C(W
M,#``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]X;6P@=F5R<VEO;CTB,2XP(B!E;F-O9&EN9STB:7-O+3@X-3DM,B(_/@H\
M(2TM($AO<F1E(#,N,2!!9&UI;B!H96QP.B!H=5](52`D2&]R9&4Z(&AO<F1E
M+V%D;6EN+VQO8V%L92]H=5](52]H96QP+GAM;"QV(#$N,2XR+C$@,C`P-B\P
M,R\P,R`Q,SHT-#HQ,2!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I
M9#TB861M:6XM<&AP<VAE;&PB('-T871E/2)U<'1O9&%T92(@;60U/2)D-3`Q
M-S4Y,65F-&$S9C,Y9#DW.#=B-3@Q83!A8F)A-2(^"B`@("`\=&ET;&4^061M
M:6YI<WIT<N%C:?-S(&5S>FOV>O9K.B!A(%!(4"!3:&5L;#PO=&ET;&4^"B`@
M("`\:&5A9&EN9SY!(%!(4"!3:&5L;"!H87-Z;N%L871A/"]H96%D:6YG/@H@
M("`@/'!A<F$^02!02%`@<&%R86YC<^ER=&5L;65Z]2!S96?M='/I9^EV96P@
M=&5T<WKU;&5G97,@4$A0('!A<F%N8W-O:V%T"B`@("`@("`@("!H86IT:&%T
M(';I9W)E(&$@<WIE<G9E<F5N+B!%>F5K970@82!P87)A;F-S;VMA="!A(&?I
M<"!A>B`*("`@("`@("`@(#QC;V1E/F5V86PH*3PO8V]D93X@9OQG9W;I;GD@
M<V5G[71SZ6?I=F5L+"!A>B!A:W1UX6QI<V%N(.ER=NEN>65S"B`@("`@("`@
M("!S97-S:6]N(&ME<F5TZ6)E;B!H86IT:F$@=NEG<F4N($4@<&%R86YC<^ER
M=&5L;65Z]2!CZ6QJ82P@:&]G>0H@("`@("`@("`@:VD@='5D:G5N:R!P<O-B
MX6QN:2!T971S>O5L96=E<RP@96=Y<WIE<OMB8B!K\V1RZ7-Z;&5T96ME="X@
M"B`@("`@("`@("!!:&AO>B!A>F]N8F%N+"!H;V=Y(&+A<FUI;'EE;B!O=71P
M=71O="!LX7-S=6YK+"!A(&OS9&YA:R!E8VAO"B`@("`@("`@("!V86=Y('!R
M:6YT('!A<F%N8W-O:V%T(&ME;&P@=&%R=&%L;6%Z;FEA+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB861M:6XM<W%L<VAE;&PB('-T871E
M/2)U<'1O9&%T92(@;60U/2(U8F0R9F-B.6,Y-C<X938R8V$Q-#$U-C9A8CAF
M-&,T9B(^"B`@("`\=&ET;&4^061M:6YI<WIT<N%C:?-S(&5S>FOV>O9K.B!A
M>B!344P@4VAE;&P\+W1I=&QE/@H@("`@/&AE861I;F<^07H@4U%,(%-H96QL
M(&AA<WINX6QA=&$\+VAE861I;F<^"B`@("`\<&%R83Y!>B!344P@<&%R86YC
M<^ER=&5L;65Z]2!S96?M='/I9^EV96P@=&5T<WKU;&5G97,@4U%,('!A<F%N
M8W-O=`H@("`@("`@("`@:&%J=&AA="!VZ6=R92!A>B!A9&%T8N%Z:7-O;BX@
M17IE:V5T(&$@<&%R86YC<V]K870@82!GZ7`@82!014%2.CI$0@H@("`@("`@
M("`@<NEVZ6X@:&%J=&IA(';I9W)E(&$@)&-O;F9;)W-Q;"==+6)E;B!M96=A
M9&]T="!A9&%T8F%Z:7-O;BX*("`@("`@("`@($5Z>F5L(&%Z(&5S>FOV>GIE
M;"!L96OI<F1E>NES96ME="P@8F]N>6]L=6QT(%-13"!M\V1O<^UTX7-O:V%T
M+`H@("`@("`@("`@=/9R;.ES96ME="!H86IT:&%T(';I9W)E+"!V86=Y(&%D
M871O:V%T(&=Y^VIT:&5T+B!!>B!344P@<&%R86YC<V]K870*("`@("`@("`@
M(&OV>G9E=&QE;OQL(&%Z(&%D871BX7II<VYA:R!K_&QD:2P@;6%J9"!V:7-S
M>F%A9&IA(&%Z(&5R961MZ6YY:_-D;VMA=`H@("`@("`@("`@:6QL+B!A(&MA
M<&]T="!A9&%T;VMA="X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](F%D;6EN+6-M9'-H96QL(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB.61B
M8F4U.3,W,S5E96)B8C,T9&4Y.3%A-3=B.3AB.68B/@H@("`@/'1I=&QE/D%D
M;6EN:7-Z='+A8VGS<R!E<WIK]GKV:SH@82!P87)A;F-S<V]R/"]T:71L93X*
M("`@(#QH96%D:6YG/D$@<&%R86YC<W-O<B!H87-Z;N%L871A/"]H96%D:6YG
M/@H@("`@/'!A<F$^02!P87)A;F-S<V]R('-E9^UT<^EGZ79E;"!P87)A;F-S
M;VMA="!H86IT:&%T(';I9W)E(&$@<WIE<G9E<F5N+@H@("`@("`@("`@17H@
M96=Y+65G>2!P87)A;F-S(&=Y;W)S(';I9W)E:&%J=.%SX7)A(&KS+"!V86=Y
M(&%R<F$@87H@97-E=')E+"!H80H@("`@("`@("`@;>%S(&WS9&]N(&YE;2!K
MZ7!E<R!A('-Z97)V97(@<&%R86YC<^ER=&5L;65Z]6KI:&5Z("A#;VUM86YD
M(%-H96QL*0H@("`@("`@("`@:G5T;FEA+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H\+VAE;'`^"@`````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+V%D;6EN+W!E<FUS+P``````````````````````````````````````
M````````````````````````````````````````````,#`P,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-#0`,#(P,#<T`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O861M:6XO<&5R;7,O861D8VAI;&0N<&AP
M````````````````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#8S,P`Q,#4Q
M-30S,S<T-``P,C(S-#<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP+'8@,2XR-RXR+C0@,C`P-B\P,2\P,2`R,3HR
M.#HP-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P
M,#4M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)
M3$5?7RD@+B`G+RXN+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@
M)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N<&AP
M)SL*"FEF("@A075T:#HZ:7-!9&UI;B@I*2!["B`@("!(;W)D93HZ875T:&5N
M=&EC871I;VY&86EL=7)E4F5D:7)E8W0H*3L*?0H*+RH@4V5T('5P('1H92!F
M;W)M('9A<FEA8FQE<RX@*B\*<F5Q=6ER95]O;F-E("=(;W)D92]687)I86)L
M97,N<&AP)SL*)'9A<G,@/2`F5F%R:6%B;&5S.CIG971$969A=6QT5F%R:6%B
M;&5S*"D["B1P97)M7VED(#T@)'9A<G,M/F=E="@G<&5R;5]I9"<I.PH*)'!E
M<FUI<W-I;VX@/2`F)'!E<FUS+3YG971097)M:7-S:6]N0GE)9"@D<&5R;5]I
M9"D["FEF("AI<U]A*"1P97)M:7-S:6]N+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(DEN=F%L:60@<&%R96YT('!E<FUI
M<W-I;VXN(BDL("=H;W)D92YE<G)O<B<I.PH@("`@)'5R;"`]($AO<F1E.CIA
M<'!L:6-A=&EO;E5R;"@G861M:6XO<&5R;7,O:6YD97@N<&AP)RP@=')U92D[
M"B`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@)'5R;"D["B`@("!E>&ET.PI]
M"@HO*B!3970@=7`@9F]R;2X@*B\*<F5Q=6ER95]O;F-E("=(;W)D92]097)M
M<R]522YP:'`G.PHD=6D@/2`F;F5W(%!E<FUS7U5)*"1P97)M<RD["B1U:2T^
M<V5T5F%R<R@D=F%R<RD["B1U:2T^<V5T=7!!9&1&;W)M*"1P97)M:7-S:6]N
M*3L*"FEF("@D=6DM/G9A;&ED871E061D1F]R;2@D:6YF;RDI('L*("`@(&EF
M("@D:6YF;ULG<&5R;5]I9"==(#T]($1!5$%44D5%7U)/3U0I('L*("`@("`@
M("`D8VAI;&0@/2`F)'!E<FUS+3YN97=097)M:7-S:6]N*"1I;F9O6R=C:&EL
M9"==*3L*("`@("`@("`D<F5S=6QT(#T@)'!E<FUS+3YA9&1097)M:7-S:6]N
M*"1C:&EL9"D["B`@("!](&5L<V4@>PH@("`@("`@("1P3V(@/2`F)'!E<FUS
M+3YG971097)M:7-S:6]N0GE)9"@D:6YF;ULG<&5R;5]I9"==*3L*("`@("`@
M("`D;F%M92`]("1P3V(M/F=E=$YA;64H*2`N("<Z)R`N($1A=&%4<F5E.CIE
M;F-O9&5.86UE*"1I;F9O6R=C:&EL9"==*3L*("`@("`@("`D8VAI;&0@/2`F
M)'!E<FUS+3YN97=097)M:7-S:6]N*"1N86UE*3L*("`@("`@("`D<F5S=6QT
M(#T@)'!E<FUS+3YA9&1097)M:7-S:6]N*"1C:&EL9"D["B`@("!]"B`@("!I
M9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(EPB)7-<(B!W87,@;F]T(&-R
M96%T960Z("5S+B(I+"`D<&5R;7,M/F=E=%1I=&QE*"1C:&EL9"T^9V5T3F%M
M92@I*2P@)')E<W5L="T^9V5T365S<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD[
M"B`@("!](&5L<V4@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R
M:6YT9BA?*")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S
M>7-T96TN(BDL("1P97)M<RT^9V5T5&ET;&4H)&-H:6QD+3YG971.86UE*"DI
M*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("`D=7)L(#T@2&]R9&4Z.F%P
M<&QI8V%T:6]N57)L*"=A9&UI;B]P97)M<R]E9&ET+G!H<"<L('1R=64I.PH@
M("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@)W!E<FU?
M:60G+"`D8VAI;&0M/F=E=$ED*"DL(&9A;'-E*3L*("`@("`@("!H96%D97(H
M)TQO8V%T:6]N.B`G("X@)'5R;"D["B`@("`@("`@97AI=#L*("`@('T*?0H*
M)'1I=&QE(#T@7R@B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB*3L*<F5Q
M=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*
M<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V%D;6EN+V-O;6UO;BUH96%D
M97(N:6YC)SL*)&YO=&EF:6-A=&EO;BT^;F]T:69Y*&%R<F%Y*"=L:7-T96YE
M<G,G(#T^("=S=&%T=7,G*2D["@HO*B!296YD97(@=&AE(&9O<FT@86YD('1R
M964N("HO"B1U:2T^<F5N9&5R1F]R;2@G861D8VAI;&0N<&AP)RD["F5C:&\@
M)SQB<B`O/B<["B1U:2T^<F5N9&5R5')E92@D<&5R;5]I9"D["@IR97%U:7)E
M($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O861M:6XO<&5R;7,O
M9&5L971E+G!H<```````````````````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P-#8Q-@`Q,#4Q-30S,S<T-``P,C(P-38`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@
M:&]R9&4O861M:6XO<&5R;7,O9&5L971E+G!H<"QV(#$N,3DN."XT(#(P,#8O
M,#$O,#$@,C$Z,C@Z,#4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY
M+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O
M<'ER:6=H="`R,#`U+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I
M<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I.PIR97%U:7)E7V]N8V4@2$]2
M1$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D
M92]-96YU+G!H<"<["@II9B`H(4%U=&@Z.FES061M:6XH*2D@>PH@("`@2&]R
M9&4Z.F%U=&AE;G1I8V%T:6]N1F%I;'5R95)E9&ER96-T*"D["GT*"B\J(%-E
M="!U<"!T:&4@9F]R;2!V87)I86)L97,N("HO"G)E<75I<F5?;VYC92`G2&]R
M9&4O5F%R:6%B;&5S+G!H<"<["B1V87)S(#T@)E9A<FEA8FQE<SHZ9V5T1&5F
M875L=%9A<FEA8FQE<R@I.PHD<&5R;5]I9"`]("1V87)S+3YG970H)W!E<FU?
M:60G*3L*)&-A=&5G;W)Y(#T@)'9A<G,M/F=E="@G8V%T96=O<GDG*3L*)'!E
M<FUI<W-I;VX@/2`F)'!E<FUS+3YG971097)M:7-S:6]N0GE)9"@D<&5R;5]I
M9"D["@HO*B!)9B!T:&4@<&5R;6ES<VEO;B!F971C:&5D(&ES(&%N(&5R<F]R
M(')E='5R;B!T;R!P97)M:7-S:6]N<R!L:7-T+B`J+PII9B`H:7-?82@D<&5R
M;6ES<VEO;BP@)U!%05)?17)R;W(G*2D@>PH@("`@)&YO=&EF:6-A=&EO;BT^
M<'5S:"A?*")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M
M:7-S:6]N+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("1U<FP@/2!(;W)D93HZ
M87!P;&EC871I;VY5<FPH)V%D;6EN+W!E<FUS+VEN9&5X+G!H<"<L('1R=64I
M.PH@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1U<FPI.PH@("`@97AI=#L*
M?0H*+RH@4V5T('5P(&9O<FTN("HO"G)E<75I<F5?;VYC92`G2&]R9&4O4&5R
M;7,O54DN<&AP)SL*)'5I(#T@)FYE=R!097)M<U]522@D<&5R;7,I.PHD=6DM
M/G-E=%9A<G,H)'9A<G,I.PHD=6DM/G-E='5P1&5L971E1F]R;2@D<&5R;6ES
M<VEO;BD["@II9B`H)&-O;F9I<FUE9"`]("1U:2T^=F%L:61A=&5$96QE=&5&
M;W)M*"1I;F9O*2D@>PH@("`@)')E<W5L="`]("1P97)M<RT^<F5M;W9E4&5R
M;6ES<VEO;B@D<&5R;6ES<VEO;BP@=')U92D["B`@("!I9B`H:7-?82@D<F5S
M=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^
M<'5S:"AS<')I;G1F*%\H(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB
M*2P@)'!E<FUS+3YG9714:71L92@D<&5R;6ES<VEO;BT^9V5T3F%M92@I*2P@
M)')E<W5L="T^9V5T365S<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@("!]
M(&5L<V4@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?
M*")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(BDL("1P97)M<RT^9V5T
M5&ET;&4H)'!E<FUI<W-I;VXM/F=E=$YA;64H*2DI+"`G:&]R9&4N<W5C8V5S
M<R<I.PH@("`@("`@("1U<FP@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH)V%D
M;6EN+W!E<FUS+VEN9&5X+G!H<"<L('1R=64I.PH@("`@("`@(&AE861E<B@G
M3&]C871I;VXZ("<@+B`D=7)L*3L*("`@("`@("!E>&ET.PH@("`@?0I](&5L
M<V5I9B`H)&-O;F9I<FUE9"`]/3T@9F%L<V4I('L*("`@("1N;W1I9FEC871I
M;VXM/G!U<V@H<W!R:6YT9BA?*")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L
M971E9"XB*2P@)'!E<FUS+3YG9714:71L92@D<&5R;6ES<VEO;BT^9V5T3F%M
M92@I*2DL("=H;W)D92YS=6-C97-S)RD["B`@("`D=7)L(#T@2&]R9&4Z.F%P
M<&QI8V%T:6]N57)L*"=A9&UI;B]P97)M<R]I;F1E>"YP:'`G+"!T<G5E*3L*
M("`@(&AE861E<B@G3&]C871I;VXZ("<@+B`D=7)L*3L*("`@(&5X:70["GT*
M"B1T:71L92`](%\H(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(BD["G)E
M<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<[
M"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]C;VUM;VXM:&5A
M9&5R+FEN8R<["B1N;W1I9FEC871I;VXM/FYO=&EF>2AA<G)A>2@G;&ES=&5N
M97)S)R`]/B`G<W1A='5S)RDI.PH*+RH@4F5N9&5R('1H92!F;W)M(&%N9"!T
M<F5E+B`J+PHD=6DM/G)E;F1E<D9O<FTH)V1E;&5T92YP:'`G*3L*96-H;R`G
M/&)R("\^)SL*)'5I+3YR96YD97)4<F5E*"1P97)M7VED*3L*"G)E<75I<F4@
M2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M861M:6XO<&5R;7,O961I="YP:'``````````````````````````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`Q,#8U-@`Q,#4Q-30S,S<T-``P,C$U-#(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J("1(;W)D93H@:&]R9&4O861M:6XO<&5R;7,O961I="YP:'`L=B`Q+C,X
M+C(N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C`U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($IA;B!38VAN96ED97(@/&IA
M;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I
M9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%
M7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*<F5Q=6ER
M95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?
M;VYC92`G2&]R9&4O365N=2YP:'`G.PH*:68@*"%!=71H.CII<T%D;6EN*"DI
M('L*("`@($AO<F1E.CIA=71H96YT:6-A=&EO;D9A:6QU<F52961I<F5C="@I
M.PI]"@HO*B!3970@=7`@=&AE(&9O<FT@=F%R:6%B;&5S+B`J+PIR97%U:7)E
M7V]N8V4@)TAO<F1E+U9A<FEA8FQE<RYP:'`G.PHD=F%R<R`]("9687)I86)L
M97,Z.F=E=$1E9F%U;'1687)I86)L97,H*3L*)'!E<FU?:60@/2`D=F%R<RT^
M9V5T*"=P97)M7VED)RD["B1C871E9V]R>2`]("1V87)S+3YG970H)V-A=&5G
M;W)Y)RD["@HO*B!3964@:68@=V4@;F5E9"!T;R`H86YD(&%R92!S=7!P;W-E
M9"!T;RD@875T;V-R96%T92!T:&4@<&5R;6ES<VEO;BX@*B\*:68@*"1C871E
M9V]R>2`A/3T@;G5L;"D@>PH@("`@)'!E<FUI<W-I;VX@/2`F)'!E<FUS+3YG
M971097)M:7-S:6]N*"1C871E9V]R>2D["B`@("!I9B`H:7-?82@D<&5R;6ES
M<VEO;BP@)U!%05)?17)R;W(G*2`F)B!5=&EL.CIG971&;W)M1&%T82@G875T
M;V-R96%T92<I*2!["@H@("`@("`@("\J($-H96-K('1O('-E92!I9B!T:&4@
M<&5R;6ES<VEO;B!W92!A<F4@8V]P>6EN9R!F<F]M(&5X:7-T<R!B969O<F4@
M=V4*("`@("`@("`@*B!A=71O8W)E871E+B`J+PH@("`@("`@("1C;W!Y1G)O
M;2`](%5T:6PZ.F=E=$9O<FU$871A*"=A=71O8W)E871E7V-O<'DG*3L*("`@
M("`@("!I9B`H)&-O<'E&<F]M("8F("$D<&5R;7,M/F5X:7-T<R@D8V]P>49R
M;VTI*2!["B`@("`@("`@("`@("1C;W!Y1G)O;2`](&YU;&P["B`@("`@("`@
M?0H*("`@("`@("`D<&%R96YT(#T@)'9A<G,M/F=E="@G<&%R96YT)RD["B`@
M("`@("`@)'!E<FUI<W-I;VX@/2`F)'!E<FUS+3YN97=097)M:7-S:6]N*"1C
M871E9V]R>2D["B`@("`@("`@)')E<W5L="`]("1P97)M<RT^861D4&5R;6ES
M<VEO;B@D<&5R;6ES<VEO;BP@)'!A<F5N="D["B`@("`@("`@:68@*"%I<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)&9O<FT@
M/2`G961I="YI;F,G.PH@("`@("`@("`@("`D<&5R;5]I9"`]("1P97)M<RT^
M9V5T4&5R;6ES<VEO;DED*"1P97)M:7-S:6]N*3L*("`@("`@("!]"@H@("`@
M("`@(&EF("@D8V]P>49R;VTI('L*("`@("`@("`@("`@+RH@5V4@:&%V92!A
M=71O8W)E871E9"!T:&4@<&5R;6ES<VEO;B!A;F0@=V4@:&%V92!B965N('1O
M;&0@=&\*("`@("`@("`@("`@("H@8V]P>2!A;B!E>&ES=&EN9R!P97)M:7-S
M:6]N(&9O<B!T:&4@9&5F875L=',N("HO"B`@("`@("`@("`@("1C;W!Y1G)O
M;4]B:B`]("8D<&5R;7,M/F=E=%!E<FUI<W-I;VXH)&-O<'E&<F]M*3L*("`@
M("`@("`@("`@)'!E<FUI<W-I;VXM/F%D9$=U97-T4&5R;6ES<VEO;B@D8V]P
M>49R;VU/8FHM/F=E=$=U97-T4&5R;6ES<VEO;G,H*2P@9F%L<V4I.PH@("`@
M("`@("`@("`D<&5R;6ES<VEO;BT^861D1&5F875L=%!E<FUI<W-I;VXH)&-O
M<'E&<F]M3V)J+3YG971$969A=6QT4&5R;6ES<VEO;G,H*2P@9F%L<V4I.PH@
M("`@("`@("`@("`D<&5R;6ES<VEO;BT^861D0W)E871O<E!E<FUI<W-I;VXH
M)&-O<'E&<F]M3V)J+3YG971#<F5A=&]R4&5R;6ES<VEO;G,H*2P@9F%L<V4I
M.PH@("`@("`@("`@("!F;W)E86-H("@D8V]P>49R;VU/8FHM/F=E=%5S97)0
M97)M:7-S:6]N<R@I(&%S("1U<V5R(#T^("1U<&5R;2D@>PH@("`@("`@("`@
M("`@("`@)'!E<FUI<W-I;VXM/F%D9%5S97)097)M:7-S:6]N*"1U<V5R+"`D
M=7!E<FTL(&9A;'-E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!F;W)E
M86-H("@D8V]P>49R;VU/8FHM/F=E=$=R;W5P4&5R;6ES<VEO;G,H*2!A<R`D
M9W)O=7`@/3X@)&=P97)M*2!["B`@("`@("`@("`@("`@("`D<&5R;6ES<VEO
M;BT^861D1W)O=7!097)M:7-S:6]N*"1G<F]U<"P@)&=P97)M+"!F86QS92D[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O
M*B!792!H879E(&%U=&]C<F5A=&5D('1H92!P97)M:7-S:6]N(&%N9"!W92!D
M;VXG="!H879E(&%N"B`@("`@("`@("`@("`J(&5X:7-T:6YG('!E<FUI<W-I
M;VX@=&\@8V]P>2X@(%-E92!I9B!S;VUE(&1E9F%U;'1S('=E<F4*("`@("`@
M("`@("`@("H@<W5P<&QI960N("HO"B`@("`@("`@("`@("1A9&1097)M<R`]
M(%5T:6PZ.F=E=$9O<FU$871A*"=A=71O8W)E871E7V=U97-T)RD["B`@("`@
M("`@("`@(&EF("@D861D4&5R;7,I('L*("`@("`@("`@("`@("`@("1P97)M
M:7-S:6]N+3YA9&1'=65S=%!E<FUI<W-I;VXH)&%D9%!E<FUS+"!F86QS92D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&%D9%!E<FUS(#T@571I;#HZ
M9V5T1F]R;41A=&$H)V%U=&]C<F5A=&5?9&5F875L="<I.PH@("`@("`@("`@
M("!I9B`H)&%D9%!E<FUS*2!["B`@("`@("`@("`@("`@("`D<&5R;6ES<VEO
M;BT^861D1&5F875L=%!E<FUI<W-I;VXH)&%D9%!E<FUS+"!F86QS92D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&%D9%!E<FUS(#T@571I;#HZ9V5T
M1F]R;41A=&$H)V%U=&]C<F5A=&5?8W)E871O<B<I.PH@("`@("`@("`@("!I
M9B`H)&%D9%!E<FUS*2!["B`@("`@("`@("`@("`@("`D<&5R;6ES<VEO;BT^
M861D0W)E871O<E!E<FUI<W-I;VXH)&%D9%!E<FUS+"!F86QS92D["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("`@("`@)'!E<FUI<W-I;VXM/G-A=F4H
M*3L*("`@('T@96QS92!["B`@("`@("`@)'!E<FU?:60@/2`D<&5R;7,M/F=E
M=%!E<FUI<W-I;VY)9"@D<&5R;6ES<VEO;BD["B`@("!]"B`@("`D=F%R<RT^
M<V5T*"=P97)M7VED)RP@)'!E<FU?:60I.PI](&5L<V4@>PH@("`@)'!E<FUI
M<W-I;VX@/2`F)'!E<FUS+3YG971097)M:7-S:6]N0GE)9"@D<&5R;5]I9"D[
M"GT*"B\J($EF('1H92!P97)M:7-S:6]N(&9E=&-H960@:7,@86X@97)R;W(@
M<F5T=7)N('1O('1H92!P97)M:7-S:6]N<R!L:7-T+B`J+PII9B`H:7-?82@D
M<&5R;6ES<VEO;BP@)U!%05)?17)R;W(G*2D@>PH@("`@)&YO=&EF:6-A=&EO
M;BT^<'5S:"A?*")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R
M;6ES<VEO;BXB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`D=7)L(#T@2&]R9&4Z
M.F%P<&QI8V%T:6]N57)L*"=A9&UI;B]P97)M<R]I;F1E>"YP:'`G+"!T<G5E
M*3L*("`@(&AE861E<B@G3&]C871I;VXZ("<@+B`D=7)L*3L*("`@(&5X:70[
M"GT*"G)E<75I<F5?;VYC92`G2&]R9&4O4&5R;7,O54DN<&AP)SL*)'5I(#T@
M)FYE=R!097)M<U]522@D<&5R;7,I.PHD=6DM/G-E=%9A<G,H)'9A<G,I.PHD
M=6DM/G-E='5P161I=$9O<FTH)'!E<FUI<W-I;VXI.PH*:68@*"1U:2T^=F%L
M:61A=&5%9&ET1F]R;2@D:6YF;RDI('L*("`@("\J(%5P9&%T92!A;F0@<V%V
M92!T:&4@<&5R;6ES<VEO;G,N("HO"B`@("`D<&5R;6ES<VEO;BT^=7!D871E
M4&5R;6ES<VEO;G,H)&EN9F\I.PH@("`@)'!E<FUI<W-I;VXM/G-A=F4H*3L*
M("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")5<&1A=&5D(%PB
M)7-<(BXB*2P@)'!E<FUS+3YG9714:71L92@D<&5R;6ES<VEO;BT^9V5T3F%M
M92@I*2DL("=H;W)D92YS=6-C97-S)RD["B`@("`D=7)L(#T@571I;#HZ861D
M4&%R86UE=&5R*"=A9&UI;B]P97)M<R]E9&ET+G!H<"<L("=P97)M7VED)RP@
M)'!E<FUI<W-I;VXM/F=E=$ED*"DI.PH@("`@)'5R;"`]($AO<F1E.CIA<'!L
M:6-A=&EO;E5R;"@D=7)L+"!T<G5E*3L*("`@(&AE861E<B@G3&]C871I;VXZ
M("<@+B`D=7)L*3L*("`@(&5X:70["GT*"B1T:71L92`](%\H(E!E<FUI<W-I
M;VYS($%D;6EN:7-T<F%T:6]N(BD["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53
M("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!
M5$53("X@)R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8R<["B1N;W1I9FEC871I
M;VXM/FYO=&EF>2AA<G)A>2@G;&ES=&5N97)S)R`]/B`G<W1A='5S)RDI.PH*
M+RH@4F5N9&5R('1H92!F;W)M(&%N9"!T<F5E+B`J+PHD=6DM/G)E;F1E<D9O
M<FTH)V5D:70N<&AP)RD["F5C:&\@)SQB<B`O/B<["B1U:2T^<F5N9&5R5')E
M92@D<&5R;5]I9"D["@IR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M
M;6]N+69O;W1E<BYI;F,G.PH`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]P97)M
M<R]I;F1E>"YP:'``````````````````````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`Q-C4R`#$P-3$U-#,S-S0T`#`R,3<R,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E
M.B!H;W)D92]A9&UI;B]P97)M<R]I;F1E>"YP:'`L=B`Q+C$P+C$P+C,@,C`P
M-B\P,2\P,2`R,3HR.#HP-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y
M.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@
M0V]P>7)I9VAT(#(P,#4M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@
M9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+RXN)RD["G)E<75I<F5?;VYC92!(
M3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO
M<F1E+TUE;G4N<&AP)SL*"FEF("@A075T:#HZ:7-!9&UI;B@I*2!["B`@("!(
M;W)D93HZ875T:&5N=&EC871I;VY&86EL=7)E4F5D:7)E8W0H*3L*?0H*)'!E
M<FU?:60@/2!5=&EL.CIG971&;W)M1&%T82@G<&5R;5]I9"<I.PH*)'1I=&QE
M(#T@7R@B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB*3L*<F5Q=6ER92!(
M3U)$15]414U03$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*<F5Q=6ER
M92!(3U)$15]414U03$%415,@+B`G+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC
M)SL*)&YO=&EF:6-A=&EO;BT^;F]T:69Y*&%R<F%Y*"=L:7-T96YE<G,G(#T^
M("=S=&%T=7,G*2D["@IR97%U:7)E7V]N8V4@)TAO<F1E+U!E<FUS+U5)+G!H
M<"<["B1U:2`]("9N97<@4&5R;7-?54DH)'!E<FUS*3L*)'5I+3YR96YD97)4
M<F5E*"1P97)M7VED*3L*"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C
M;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]A9&UI
M;B]P:'!S:&5L;"YP:'``````````````````````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`U-30S`#$P-3$U-#,S-S0T`#`R,3,P-0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M)$AO<F1E.B!H;W)D92]A9&UI;B]P:'!S:&5L;"YP:'`L=B`Q+C(T+C$P+C@@
M,C`P-B\P,B\R-"`R,CHT.#HR.2!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"
M05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TUE
M;G4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92](96QP+G!H<"<["@II9B`H
M(4%U=&@Z.FES061M:6XH*2D@>PH@("`@2&]R9&4Z.F%U=&AE;G1I8V%T:6]N
M1F%I;'5R95)E9&ER96-T*"D["GT*"B1T:71L92`](%\H(E!(4"!3:&5L;"(I
M.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI
M;F,G.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O861M:6XO8V]M;6]N
M+6AE861E<BYI;F,G.PH*)&%P<'-?=&UP(#T@)')E9VES=')Y+3YL:7-T07!P
M<R@I.PHD87!P<R`](&%R<F%Y*"D["F9O<F5A8V@@*"1A<'!S7W1M<"!A<R`D
M87!P*2!["B`@("`D87!P<ULD87!P72`]("1R96=I<W1R>2T^9V5T*"=N86UE
M)RP@)&%P<"D["GT*87-O<G0H)&%P<',I.PHD87!P;&EC871I;VX@/2!5=&EL
M.CIG971&;W)M1&%T82@G87!P)RP@)VAO<F1E)RD["C\^"CQD:78@<W1Y;&4]
M(G!A9&1I;F<Z,3!P>"(^"CQF;W)M(&%C=&EO;CTB/#]P:'`@96-H;R`D7U-%
M4E9%4ELG4$A07U-%3$8G72`_/B(@;65T:&]D/2)P;W-T(CX*/#]P:'`@571I
M;#HZ<&9O<FU);G!U="@I(#\^"@H\:#$@8VQA<W,](FAE861E<B(^/#]P:'`@
M96-H;R!?*")!<'!L:6-A=&EO;B(I(#\^/"]H,3X\8G(@+SX*/'-E;&5C="!N
M86UE/2)A<'`B/@H\/W!H<"!F;W)E86-H("@D87!P<R!A<R`D87!P(#T^("1N
M86UE*3H@/SX*("`\;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO("1A<'`@/SXB
M/#]P:'`@:68@*"1A<'!L:6-A=&EO;B`]/2`D87!P*2!E8VAO("<@<V5L96-T
M960](G-E;&5C=&5D(B<@/SX^/#]P:'`@96-H;R`D;F%M92`_/CPO;W!T:6]N
M/@H\/W!H<"!E;F1F;W)E86-H.R`_/@H\+W-E;&5C=#X\8G(@+SX\8G(@+SX*
M/#]P:'`*"FEF("@D8V]M;6%N9"`]('1R:6TH571I;#HZ9V5T1F]R;41A=&$H
M)W!H<"<I*2D@>PH@("`@:68@*$!F:6QE7V5X:7-T<R@D<F5G:7-T<GDM/F=E
M="@G9FEL97)O;W0G+"`D87!P;&EC871I;VXI("X@)R]L:6(O8F%S92YP:'`G
M*2D@>PH@("`@("`@(&EN8VQU9&4@)')E9VES=')Y+3YG970H)V9I;&5R;V]T
M)RP@)&%P<&QI8V%T:6]N*2`N("<O;&EB+V)A<V4N<&AP)SL*("`@('T@96QS
M92!["B`@("`@("`@)')E9VES=')Y+3YP=7-H07!P*"1A<'!L:6-A=&EO;BD[
M"B`@("!]"@H@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+U9I97=E<BYP
M:'`G.PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+U9I97=E<B]S;W5R
M8V4N<&AP)SL*("`@("1P<F5T='D@/2!H:6=H;&EG:'1?<W1R:6YG*"<\/W!H
M<"`G("X@)&-O;6UA;F0L('1R=64I.PH@("`@)'!R971T>2`]('-T<E]R97!L
M86-E*&%R<F%Y*"<F;'0[/W!H<"`G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("<\9F]N="!C;VQO<CTB(S`P,#`P,"(^/&9O;G0@8V]L;W(]
M(B,P,#<W,#`B/B9L=#L_/"]F;VYT/CQF;VYT(&-O;&]R/2(C,#`P,$)"(CYP
M:'`@/"]F;VYT/B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(EQR7&XB+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(")<<B(L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(EQN(BP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G/&)R("\^)RDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87DH)R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(EQN(BDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'!R971T>2D["B`@("`D<')E='1Y(#T@34E-15]6:65W
M97)?4V]U<F-E.CIL:6YE3G5M8F5R*'1R:6TH)'!R971T>2DI.PH*("`@(&5C
M:&\@)SQH,2!C;&%S<STB:&5A9&5R(CXG("X@7R@B4$A0($-O9&4B*2`N("<\
M+V@Q/CQB<B`O/B<["B`@("!E8VAO("1P<F5T='D["@H@("`@96-H;R`G/&)R
M("\^/&@Q(&-L87-S/2)H96%D97(B/B<@+B!?*")297-U;'1S(BD@+B`G/"]H
M,3X\8G(@+SXG.PH@("`@96-H;R`G/'!R92!C;&%S<STB=&5X="(^)SL*("`@
M(&5V86PH)&-O;6UA;F0I.PH@("`@96-H;R`G/"]P<F4^/&)R("\^)SL*?0H_
M/@H*/'1E>'1A<F5A(&-L87-S/2)F:7AE9"(@;F%M93TB<&AP(B!R;W=S/2(Q
M,"(@8V]L<STB-C`B/@H\/W!H<"!I9B`H(65M<'1Y*"1C;VUM86YD*2D@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1C;VUM86YD*2`_/CPO=&5X=&%R96$^"CQB
M<B`O/@H\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU
M93TB/#]P:'`@96-H;R!?*")%>&5C=71E(BD@/SXB("\^"CP_<&AP(&5C:&\@
M2&5L<#HZ;&EN:R@G861M:6XG+"`G861M:6XM<&AP<VAE;&PG*2`_/@H*/"]F
M;W)M/@H\+V1I=CX*/#]P:'`*"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@
M)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D;6EN+W-E<W-I;VYS+G!H<```
M````````````````````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0P,C0`
M,3`U,34T,S,W-#0`,#(Q,S(U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+V%D
M;6EN+W-E<W-I;VYS+G!H<"QV(#$N,BXR+C,@,C`P-B\P,2\P,2`R,3HR.#HP
M-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#4M,C`P-B!#:'5C:R!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*
M0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N
M+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP
M)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-96YU+G!H<"<["G)E<75I<F5?;VYC
M92`G2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP)SL*"FEF("@A075T:#HZ:7-!
M9&UI;B@I*2!["B`@("!(;W)D93HZ875T:&5N=&EC871I;VY&86EL=7)E4F5D
M:7)E8W0H*3L*?0H*)'1Y<&4@/2`A96UP='DH)&-O;F9;)W-E<W-I;VYH86YD
M;&5R)UU;)W1Y<&4G72D@/R`D8V]N9ELG<V5S<VEO;FAA;F1L97(G75LG='EP
M92==(#H@)VYO;F4G.PII9B`H)'1Y<&4@/3T@)V5X=&5R;F%L)RD@>PH@("`@
M)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")#86XG="!A9&UI;FES=&5R(&5X=&5R
M;F%L('-E<W-I;VX@:&%N9&QE<G,N(BDL("=H;W)D92YE<G)O<B<I.PI](&5L
M<V4@>PH@("`@)'-H(#T@)E-E<W-I;VY(86YD;&5R.CIS:6YG;&5T;VXH)'1Y
M<&4I.PI]"@HD=&ET;&4@/2!?*")397-S:6]N($%D;6EN(BD["G)E<75I<F4@
M2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["G)E<75I
M<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN
M8R<["B1N;W1I9FEC871I;VXM/FYO=&EF>2AA<G)A>2@G;&ES=&5N97)S)R`]
M/B`G<W1A='5S)RDI.PH*:68@*"%E;7!T>2@D<V@I*2!["B`@("`D=7-E<G,@
M/2`D<V@M/FQI<W1!=71H96YT:6-A=&5D57-E<G,H*3L*("`@("1C;W5N="`]
M("1S:"T^8V]U;G1!=71H96YT:6-A=&5D57-E<G,H*3L*("`@(&5C:&\@)SQH
M,2!C;&%S<STB:&5A9&5R(CXG("X@7R@B0W5R<F5N="!5<V5R<R(I.PH@("`@
M:68@*&ES7V$H)'5S97)S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@96-H
M;R`G/"]H,3X\<"!C;&%S<STB:&5A9&5R8F]X(CX\96T^)R`N('-P<FEN=&8H
M7R@B3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(BDL("1U<V5R<RT^9V5T365S
M<V%G92@I*2`N("<\+V5M/CPO<#XG.PH@("`@?2!E;'-E('L*("`@("`@("!E
M8VAO("<@*"<@+B`D8V]U;G0@+B`G*3PO:#$^)SL*("`@("`@("!E8VAO("<\
M=6P@8VQA<W,](FAE861E<F)O>"!L:6YE9%)O=R(^)SL*("`@("`@("!F;W)E
M86-H("@D=7-E<G,@87,@)'5S97(I('L*("`@("`@("`@("`@96-H;R`G/&QI
M/B<@+B!H=&UL<W!E8VEA;&-H87)S*"1U<V5R*2`N("<\+VQI/B<["B`@("`@
M("`@?0H@("`@("`@(&5C:&\@)SPO=6P^)SL*("`@('T*"B`@("!E8VAO("<\
M8G(@+SXG.PH*("`@("1I9',@/2`D<V@M/F=E=%-E<W-I;VY)1',H*3L*("`@
M(&5C:&\@)SQH,2!C;&%S<STB:&5A9&5R(CXG("X@7R@B0W5R<F5N="!397-S
M:6]N<R(I("X@)SPO:#$^)SL*("`@(&EF("AI<U]A*"1I9',L("=014%27T5R
M<F]R)RDI('L*("`@("`@("!E8VAO("<\<"!C;&%S<STB:&5A9&5R8F]X(CX\
M96T^)R`N('-P<FEN=&8H7R@B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S
M(BDL("1I9',M/F=E=$UE<W-A9V4H*2D@+B`G/"]E;3X\+W`^)SL*("`@('T@
M96QS92!["B`@("`@("`@96-H;R`G/'5L(&-L87-S/2)H96%D97)B;W@@;&EN
M9612;W<B/B<["B`@("`@("`@9F]R96%C:"`H)&ED<R!A<R`D=7-E<BD@>PH@
M("`@("`@("`@("!E8VAO("<\;&D^)R`N(&AT;6QS<&5C:6%L8VAA<G,H)'5S
M97(I("X@)SPO;&D^)SL*("`@("`@("!]"B`@("`@("`@96-H;R`G/"]U;#XG
M.PH@("`@?0I]"@IR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N
M+69O;W1E<BYI;F,G.PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D;6EN+W-E
M='5P+P``````````````````````````````````````````````````````
M````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`U,34T,S,W-#0`,#(P,3`V`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O861M:6XO<V5T=7`O8V]N9FEG+G!H<```````````````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,38W,0`Q,#4Q-30S,S<T-``P,C(P
M-S(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O861M:6XO<V5T=7`O8V]N9FEG
M+G!H<"QV(#$N,C0N-"XQ,"`R,#`V+S`S+S,P(#$P.C$U.C,P('-E;'-K>2!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H87)L97,@2BX@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P
M,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N
M("<O+BXO+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B
M87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O1F]R;2YP:'`G.PIR97%U
M:7)E7V]N8V4@)TAO<F1E+T9O<FTO06-T:6]N+G!H<"<["G)E<75I<F5?;VYC
M92`G2&]R9&4O1F]R;2]296YD97)E<BYP:'`G.PIR97%U:7)E7V]N8V4@)TAO
M<F1E+T-O;F9I9RYP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+U9A<FEA8FQE
M<RYP:'`G.PH*:68@*"%!=71H.CII<T%D;6EN*"DI('L*("`@($AO<F1E.CIF
M871A;"@G1F]R8FED9&5N+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["GT*"FEF
M("@A571I;#HZ97AT96YS:6]N17AI<W1S*"=D;VUX;6PG*2`F)B`A571I;#HZ
M97AT96YS:6]N17AI<W1S*"=D;VTG*2D@>PH@("`@2&]R9&4Z.F9A=&%L*"=9
M;W4@;F5E9"!T:&4@9&]M>&UL(&]R(&1O;2!02%`@97AT96YS:6]N('1O('5S
M92!T:&4@8V]N9FEG=7)A=&EO;B!T;V]L+B<L(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["GT*"B1A<'`@/2!5=&EL.CIG971&;W)M1&%T82@G87!P)RD["B1A<'!N
M86UE(#T@)')E9VES=')Y+3YG970H)VYA;64G+"`D87!P*3L*)'1I=&QE(#T@
M<W!R:6YT9BA?*"(E<R!3971U<"(I+"`D87!P;F%M92D["@II9B`H)&%P<"`]
M/3T@;G5L;"`F)@H@("`@:6Y?87)R87DH)&%P<"P@)')E9VES=')Y+3YL:7-T
M07!P<RAA<G)A>2@G:6YA8W1I=F4G+"`G:&ED9&5N)RP@)VYO=&]O;&)A<B<L
M("=A8W1I=F4G+"`G861M:6XG*2DI*2!["B`@("`D;F]T:69I8V%T:6]N+3YP
M=7-H*%\H(DEN=F%L:60@87!P;&EC871I;VXN(BDL("=H;W)D92YE<G)O<B<I
M.PH@("`@)'5R;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO<V5T
M=7`O:6YD97@N<&AP)RP@=')U92D["B`@("!H96%D97(H)TQO8V%T:6]N.B`G
M("X@)'5R;"D["B`@("!E>&ET.PI]"@HD=F%R<R`](%9A<FEA8FQE<SHZ9V5T
M1&5F875L=%9A<FEA8FQE<R@I.PHD9F]R;2`]("9N97<@0V]N9FEG1F]R;2@D
M=F%R<RP@)&%P<"D["B1F;W)M+3YS971"=71T;VYS*'-P<FEN=&8H7R@B1V5N
M97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(I+"`D87!P;F%M92DI.PII9B`H9FEL
M95]E>&ES=',H)')E9VES=')Y+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G
M+V-O;F9I9R]C;VYF+G!H<"YB86LG*2D@>PH@("`@)&9O<FTM/F%P<&5N9$)U
M='1O;G,H7R@B4F5V97)T($-O;F9I9W5R871I;VXB*2D["GT*"B1P:'`@/2`G
M)SL*:68@*%5T:6PZ.F=E=$9O<FU$871A*"=S=6)M:71B=71T;VXG*2`]/2!?
M*")2979E<G0@0V]N9FEG=7)A=&EO;B(I*2!["B`@("`D<&%T:"`]("1R96=I
M<W1R>2T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]C;VYF:6<G.PH@("`@
M:68@*$!C;W!Y*"1P871H("X@)R]C;VYF+G!H<"YB86LG+"`D<&%T:"`N("<O
M8V]N9BYP:'`G*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B
M4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T
M;R!S964@8VAA;F=E<RXB*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("!`
M=6YL:6YK*"1P871H("X@)R]C;VYF+G!H<"YB86LG*3L*("`@('T@96QS92![
M"B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")#;W5L9"!N;W0@<F5V
M97)T(&-O;F9I9W5R871I;VXN(BDL("=H;W)D92YE<G)O<B<I.PH@("`@?0I]
M(&5L<V5I9B`H)&9O<FTM/G9A;&ED871E*"1V87)S*2D@>PH@("`@)&-O;F9I
M9R`]("9N97<@2&]R9&5?0V]N9FEG*"1A<'`I.PH@("`@)'!H<"`]("1C;VYF
M:6<M/F=E;F5R871E4$A00V]N9FEG*"1V87)S*3L*("`@("1P871H(#T@)')E
M9VES=')Y+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G+V-O;F9I9R<["B`@
M("!I9B`H9FEL95]E>&ES=',H)'!A=&@@+B`G+V-O;F8N<&AP)RDI('L*("`@
M("`@("!I9B`H0&-O<'DH)'!A=&@@+B`G+V-O;F8N<&AP)RP@)'!A=&@@+B`G
M+V-O;F8N<&AP+F)A:R<I*2!["B`@("`@("`@("`@("1N;W1I9FEC871I;VXM
M/G!U<V@H<W!R:6YT9BA?*")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU
M<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(BDL(%5T:6PZ.G)E86Q0871H*"1P
M871H("X@)R]C;VYF+G!H<"YB86LG*2DL("=H;W)D92YS=6-C97-S)RD["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S
M:"AS<')I;G1F*%\H(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG
M=7)A=&EO;B!F:6QE("5S+B(I+"!5=&EL.CIR96%L4&%T:"@D<&%T:"`N("<O
M8V]N9BYP:'`N8F%K)RDI+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@('T*
M("`@('T*("`@(&EF("@D9G`@/2!`9F]P96XH)'!A=&@@+B`G+V-O;F8N<&AP
M)RP@)W<G*2D@>PH@("`@("`@("\J($-A;B!W<FET92P@<V\@;W5T<'5T('1O
M(&9I;&4N("HO"B`@("`@("`@9G=R:71E*"1F<"P@4W1R:6YG.CIC;VYV97)T
M0VAA<G-E="@D<&AP+"!.3%,Z.F=E=$-H87)S970H*2P@)VES;RTX.#4Y+3$G
M*2D["B`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@("`@)&YO=&EF:6-A=&EO
M;BT^<'5S:"AS<')I;G1F*%\H(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(I+"!5
M=&EL.CIR96%L4&%T:"@D<&%T:"`N("<O8V]N9BYP:'`G*2DL("=H;W)D92YS
M=6-C97-S)RD["B`@("`@("`@)')E9VES=')Y+3YC;&5A<D-A8VAE*"D["B`@
M("`@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N($AO<F1E.CIA<'!L:6-A=&EO
M;E5R;"@G861M:6XO<V5T=7`O:6YD97@N<&AP)RP@=')U92DI.PH@("`@("`@
M(&5X:70["B`@("!](&5L<V4@>PH@("`@("`@("\J($-A;FYO="!W<FET92X@
M*B\*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B0V]U
M;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A
M;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C
M;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO
M=R!T;R`E<RXB*2P@571I;#HZ<F5A;%!A=&@H)'!A=&@@+B`G+V-O;F8N<&AP
M)RDL($AO<F1E.CIL:6YK*$AO<F1E.CIU<FPH)VEN9&5X+G!H<"<I("X@)R-U
M<&1A=&4G+"!?*")3971U<"(I*2`N(%\H(E-E='5P(BD@+B`G/"]A/B<L(%5T
M:6PZ.G)E86Q0871H*"1P871H("X@)R]C;VYF+G!H<"<I*2P@)VAO<F1E+G=A
M<FYI;F<G+"!A<G)A>2@G8V]N=&5N="YR87<G*2D["B`@("`@("`@+RH@4V%V
M92!T;R!S97-S:6]N+B`J+PH@("`@("`@("1?4T534TE/3ELG7V-O;F9I9R==
M6R1A<'!=(#T@)'!H<#L*("`@('T*?2!E;'-E:68@*"1F;W)M+3YI<U-U8FUI
M='1E9"@I*2!["B`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(E1H97)E('=A
M<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S
M('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+B(I+"`G:&]R9&4N97)R
M;W(G*3L*?0H*+RH@4F5N9&5R('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN("HO
M"G)E<75I<F5?;VYC92`G2&]R9&4O54DO5F%R4F5N9&5R97(N<&AP)SL*)')E
M;F1E<F5R(#T@)FYE=R!(;W)D95]&;W)M7U)E;F1E<F5R*"D["B1R96YD97)E
M<BT^<V5T071T<D-O;'5M;E=I9'1H*"<U,"4G*3L*)&9O<FT@/2!5=&EL.CIB
M=69F97)/=71P=70H87)R87DH)&9O<FTL("=R96YD97)!8W1I=F4G*2P@)')E
M;F1E<F5R+"`D=F%R<RP@)V-O;F9I9RYP:'`G+"`G<&]S="<I.PH*"B\J(%-E
M="!U<"!T:&4@=&5M<&QA=&4N("HO"G)E<75I<F5?;VYC92`G2&]R9&4O5&5M
M<&QA=&4N<&AP)SL*)'1E;7!L871E(#T@)FYE=R!(;W)D95]496UP;&%T92@I
M.PHD=&5M<&QA=&4M/G-E="@G<&AP)RP@:'1M;'-P96-I86QC:&%R<R@D<&AP
M*2P@=')U92D["B\J($-R96%T92!T:&4@;&EN:R!F;W(@=&AE(&1I9F8@<&]P
M=7`@;VYL>2!I9B!S=&]R960@:6X@<V5S<VEO;BX@*B\*:68@*"%E;7!T>2@D
M7U-%4U-)3TY;)U]C;VYF:6<G75LD87!P72DI('L*("`@($AO<F1E.CIA9&13
M8W)I<'1&:6QE*"=P;W!U<"YJ<R<L("=H;W)D92<L('1R=64I.PH@("`@)'5R
M;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO<V5T=7`O9&EF9BYP
M:'`G*3L*("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@)V%P
M<"<L("1A<'`I.PH@("`@)&QI;FL@/2!(;W)D93HZ;&EN:R@G(R<L("<G+"`G
M)RP@)R<L("=P;W!U<"A<)R<@+B`D=7)L("X@)UPG+"`V-#`L(#0X,"D[(')E
M='5R;B!F86QS93LG*2`N(%\H(G-H;W<@9&EF9F5R96YC97,B*2`N("<\+V$^
M)SL*("`@("1T96UP;&%T92T^<V5T*"=D:69F7W!O<'5P)RP@)&QI;FLI.PI]
M"B1T96UP;&%T92T^<V5T*"=F;W)M)RP@)&9O<FTI.PHD=&5M<&QA=&4M/G-E
M="@G;F]T:69Y)RP@571I;#HZ8G5F9F5R3W5T<'5T*&%R<F%Y*"1N;W1I9FEC
M871I;VXL("=N;W1I9GDG*2DI.PHD=&5M<&QA=&4M/G-E=$]P=&EO;B@G9V5T
M=&5X="<L('1R=64I.PH*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O
M;6UO;BUH96%D97(N:6YC)SL*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G
M+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC)SL*96-H;R`D=&5M<&QA=&4M/F9E
M=&-H*$A/4D1%7U1%35!,051%4R`N("<O861M:6XO<V5T=7`O8V]N9FEG+FAT
M;6PG*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUF;V]T
M97(N:6YC)SL*````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+V%D;6EN+W-E='5P+V1I9F8N<&AP````````````
M````````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8U,#<`,3`U,34T,S,W
M-#0`,#(Q-3,W`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!38W)I<'0@=&\@<VAO=R!T:&4@9&EF9F5R
M96YC97,@8F5T=V5E;B!T:&4@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W
M;'D*("H@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN"B`J"B`J("1(;W)D93H@
M:&]R9&4O861M:6XO<V5T=7`O9&EF9BYP:'`L=B`Q+C0N,3`N-2`R,#`V+S`U
M+S(S(#`R.C$S.C0R('-E;'-K>2!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M-"TR,#`V(%1H92!(;W)D92!0<F]J96-T("AH='1P.B\O=W=W+FAO<F1E+F]R
M9R\I"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("HO"@ID969I;F4H)TA/4D1%7T)!4T4G+"!D
M:7)N86UE*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*<F5Q=6ER95]O;F-E($A/
M4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R
M9&4O1F]R;2YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T-O;F9I9RYP:'`G
M.PIR97%U:7)E7V]N8V4@)TAO<F1E+U1E;7!L871E+G!H<"<["FEN8VQU9&5?
M;VYC92`G5&5X="]$:69F+G!H<"<["FEN8VQU9&5?;VYC92`G5&5X="]$:69F
M+U)E;F1E<F5R+G!H<"<["@II9B`H(4%U=&@Z.FES061M:6XH*2D@>PH@("`@
M2&]R9&4Z.F9A=&%L*"=&;W)B:61D96XN)RP@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*?0H*+RH@4V5T('5P('1H92!D:69F(')E;F1E<F5R+B`J+PHD<F5N9&5R
M7W1Y<&4@/2!5=&EL.CIG971&;W)M1&%T82@G<F5N9&5R)RP@)VEN;&EN92<I
M.PII;F-L=61E7V]N8V4@)U1E>'0O1&EF9B]296YD97)E<B\G("X@)')E;F1E
M<E]T>7!E("X@)RYP:'`G.PHD8VQA<W,@/2`G5&5X=%]$:69F7U)E;F1E<F5R
M7R<@+B`D<F5N9&5R7W1Y<&4["B1R96YD97)E<B`]("9N97<@)&-L87-S*"D[
M"@HO*BH*("H@4')I=F%T92!F=6YC=&EO;B!T;R!R96YD97(@=&AE(&1I9F9E
M<F5N8V5S(&9O<B!A('-P96-I9FEC(&%P<"X*("HO"F9U;F-T:6]N(%]G971$
M:69F*"1A<'`I"GL*("`@(&=L;V)A;"`D<F5N9&5R97(L("1R96=I<W1R>3L*
M"B`@("`O*B!296%D('1H92!E>&ES=&EN9R!C;VYF:6=U<F%T:6]N+B`J+PH@
M("`@)&-U<G)E;G1?8V]N9FEG(#T@)R<["B`@("`D<&%T:"`]("1R96=I<W1R
M>2T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]C;VYF:6<G.PH@("`@)&-U
M<G)E;G1?8V]N9FEG(#T@0&9I;&5?9V5T7V-O;G1E;G1S*"1P871H("X@)R]C
M;VYF+G!H<"<I.PH*("`@("\J($-A;&-U;&%T92!T:&4@9&EF9F5R96YC97,N
M("HO"B`@("`D9&EF9B`]("9N97<@5&5X=%]$:69F*&5X<&QO9&4H(EQN(BP@
M)&-U<G)E;G1?8V]N9FEG*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M97AP;&]D92@B7&XB+"`D7U-%4U-)3TY;)U]C;VYF:6<G75LD87!P72DI.PH@
M("`@)&1I9F8@/2`D<F5N9&5R97(M/G)E;F1E<B@D9&EF9BD["B`@("!I9B`H
M(65M<'1Y*"1D:69F*2D@>PH@("`@("`@(')E='5R;B`D9&EF9CL*("`@('T@
M96QS92!["B`@("`@("`@<F5T=7)N(%\H(DYO(&-H86YG92XB*3L*("`@('T*
M?0H*)&1I9F9S(#T@87)R87DH*3L*+RH@3VYL>2!B;W1H97(@=&\@9&\@86YY
M=&AI;F<@:68@=&AE<F4@:7,@86YY(&-O;F9I9RX@*B\*:68@*"%E;7!T>2@D
M7U-%4U-)3TY;)U]C;VYF:6<G72DI('L*("`@("\J(%-E="!U<"!T:&4@=&]G
M9VQE(&)U='1O;B!F;W(@:6YL:6YE+W5N:69I960N("HO"B`@("`D=7)L(#T@
M2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=A9&UI;B]S971U<"]D:69F+G!H<"<I
M.PH@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G<F5N9&5R
M)RP@*"1R96YD97)?='EP92`]/2`G:6YL:6YE)RD@/R`G=6YI9FEE9"<@.B`G
M:6YL:6YE)RD["@H@("`@:68@*"1A<'`@/2!5=&EL.CIG971&;W)M1&%T82@G
M87!P)RDI('L*("`@("`@("`O*B!(86YD;&4@82!S:6YG;&4@87!P(')E<75E
M<W0N("HO"B`@("`@("`@)'1O9V=L95]R96YD97)E<B`]($AO<F1E.CIL:6YK
M*"1U<FP@+B`G(R<@+B`D87!P*2`N("@H)')E;F1E<E]T>7!E(#T]("=I;FQI
M;F4G*2`_(%\H(G5N:69I960B*2`Z(%\H(FEN;&EN92(I*2`N("<\+V$^)SL*
M("`@("`@("`D9&EF9B`](%]G971$:69F*"1A<'`I.PH@("`@("`@(&EF("@D
M<F5N9&5R7W1Y<&4@(3T@)VEN;&EN92<I('L*("`@("`@("`@("`@)&1I9F8@
M/2!H=&UL<W!E8VEA;&-H87)S*"1D:69F*3L*("`@("`@("!]"B`@("`@("`@
M)&1I9F9S6UT@/2!A<G)A>2@G87!P)R`@/3X@)&%P<"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("=D:69F)R`]/B`D9&EF9BP*("`@("`@("`@("`@("`@
M("`@("`@("`@("=T;V=G;&5?<F5N9&5R97(G(#T^("1T;V=G;&5?<F5N9&5R
M97(I.PH@("`@?2!E;'-E('L*("`@("`@("`O*B!,:7-T(&%L;"!T:&4@87!P
M<R!W:71H(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+B`J+PH@("`@("`@(&MS
M;W)T*"1?4T534TE/3ELG7V-O;F9I9R==*3L*("`@("`@("!F;W)E86-H("@D
M7U-%4U-)3TY;)U]C;VYF:6<G72!A<R`D87!P(#T^("1C;VYF:6<I('L*("`@
M("`@("`@("`@)'1O9V=L95]R96YD97)E<B`]($AO<F1E.CIL:6YK*"1U<FP@
M+B`G(R<@+B`D87!P*2`N("@H)')E;F1E<E]T>7!E(#T]("=I;FQI;F4G*2`_
M(%\H(G5N:69I960B*2`Z(%\H(FEN;&EN92(I*2`N("<\+V$^)SL*("`@("`@
M("`@("`@)&1I9F8@/2!?9V5T1&EF9B@D87!P*3L*("`@("`@("`@("`@:68@
M*"1R96YD97)?='EP92`A/2`G:6YL:6YE)RD@>PH@("`@("`@("`@("`@("`@
M)&1I9F8@/2!H=&UL<W!E8VEA;&-H87)S*"1D:69F*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D9&EF9G-;72`](&%R<F%Y*"=A<'`G("`]/B`D87!P
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D:69F)R`]/B`D9&EF
M9BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&]G9VQE7W)E;F1E
M<F5R)R`]/B`D=&]G9VQE7W)E;F1E<F5R*3L*("`@("`@("!]"B`@("!]"GT*
M"B\J(%-E="!U<"!T:&4@=&5M<&QA=&4N("HO"B1T96UP;&%T92`]("9N97<@
M2&]R9&5?5&5M<&QA=&4H*3L*)'1E;7!L871E+3YS971/<'1I;VXH)V=E='1E
M>'0G+"!T<G5E*3L*)'1E;7!L871E+3YS970H)V1I9F9S)RP@)&1I9F9S+"!T
M<G5E*3L*"B1T:71L92`](%\H(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B
M*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUH96%D97(N
M:6YC)SL*96-H;R`D=&5M<&QA=&4M/F9E=&-H*$A/4D1%7U1%35!,051%4R`N
M("<O861M:6XO<V5T=7`O9&EF9BYH=&UL)RD["G)E<75I<F4@2$]21$5?5$5-
M4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]A9&UI;B]S971U<"]I;F1E>"YP:'``````````
M````````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(R,C4Q`#$P-3$U-#,S
M-S0T`#`R,3<S,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]A9&UI;B]S971U
M<"]I;F1E>"YP:'`L=B`Q+C(X+C0N,3(@,C`P-B\P,R\R."`Q,CHS,3HP."!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:&%R;&5S($HN
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,3DY
M.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+RXN+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L
M:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+U1E;7!L871E+G!H
M<"<["@II9B`H(4%U=&@Z.FES061M:6XH*2D@>PH@("`@2&]R9&4Z.F9A=&%L
M*"=&;W)B:61D96XN)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*?0H*+RHJ"B`J
M(%)E='5R;G,@=&AE($-64R!V97)S:6]N(&9O<B!A(&=I=F5N(&9I;&4N"B`J
M+PIF=6YC=&EO;B!?9V5T5F5R<VEO;B@D9FEL92D*>PH@("`@)'-I>F4@/2!`
M9FEL97-I>F4H)&9I;&4I.PH@("`@:68@*"$D<VEZ92!\?"`A:7-?<F5S;W5R
M8V4H)&9P(#T@0&9O<&5N*"1F:6QE+"`G<B<I*2D@>PH@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*("`@("1D871A(#T@0&9R96%D*"1F<"P@)'-I>F4I
M.PH@("`@:68@*'!R96=?;6%T8V@H)R]<)"XJ/V-O;F9<+GAM;"QV("@N*C\I
M("XJ7"0O)RP@)&1A=&$L("1M871C:"DI('L*("`@("`@("!R971U<FX@)&UA
M=&-H6S%=.PH@("`@?2!E;'-E('L*("`@("`@("!R971U<FX@9F%L<V4["B`@
M("!]"GT*"B\J*@H@*B!$;V5S(&%N($944"!U<&QO860@=&\@<V%V92!T:&4@
M8V]N9FEG=7)A=&EO;BX*("HO"F9U;F-T:6]N(%]U<&QO861&5%`H)'!A<F%M
M<RD*>PH@("`@9VQO8F%L("1R96=I<W1R>2P@)&YO=&EF:6-A=&EO;CL*"B`@
M("!R97%U:7)E7V]N8V4@)U9&4RYP:'`G.PH@("`@)'!A<F%M<ULG:&]S='-P
M96,G72`]("=L;V-A;&AO<W0G.PH@("`@)'9F<R`]("961E,Z.G-I;F=L971O
M;B@G9G1P)RP@)'!A<F%M<RD["B`@("!I9B`H:7-?82@D=F9S+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F
M*%\H(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@
M1E10.B`E<R(I+"`D<&%R86US6R=H;W-T<W!E8R==+"`D=F9S+3YG971-97-S
M86=E*"DI+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("!]"@H@("`@+RH@3&]O<"!T:')O=6=H('1H92!C;VYF:6<@86YD('=R
M:71E('1O($944"X@*B\*("`@("1N;U]E<G)O<G,@/2!T<G5E.PH@("`@9F]R
M96%C:"`H)%]315-324].6R=?8V]N9FEG)UT@87,@)&%P<"`]/B`D8V]N9FEG
M*2!["B`@("`@("`@)'!A=&@@/2`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G
M+"`D87!P*2`N("<O8V]N9FEG)SL*("`@("`@("`O*B!4<GD@=&\@8F%C:R!U
M<"!T:&4@8W5R<F5N="!C;VYF+G!H<"X@*B\*("`@("`@("!I9B`H)'9F<RT^
M97AI<W1S*"1P871H+"`G8V]N9BYP:'`G*2D@>PH@("`@("`@("`@("!I9B`H
M*"1R97-U;'0@/2`D=F9S+3YR96YA;64H)'!A=&@L("=C;VYF+G!H<"<L("1P
M871H+"`G+V-O;F8N<&AP+F)A:R<I*2`]/3T@=')U92D@>PH@("`@("`@("`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")3=6-C97-S9G5L;'D@<V%V
M960@8F%C:W5P(&-O;F9I9W5R871I;VXN(BDL("=H;W)D92YS=6-C97-S)RD[
M"B`@("`@("`@("`@('T@96QS96EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H
M<W!R:6YT9BA?*")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I
M;VXZ("5S(BDL("1R97-U;'0M/F=E=$UE<W-A9V4H*2DL("=H;W)D92YE<G)O
M<B<I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"A?*")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C
M;VYF:6=U871I;VXN(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`D=W)I=&4@/2`D=F9S+3YW<FET941A=&$H
M)'!A=&@L("=C;VYF+G!H<"<L("1C;VYF:6<I.PH@("`@("`@(&EF("AI<U]A
M*"1W<FET92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D;F]?97)R
M;W)S(#T@9F%L<V4["B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H
M<W!R:6YT9BA?*")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@
M7"(E<UPB.B`E<R(I+"`D87!P+"`D=W)I=&4M/F=E=$UE<W-A9V4H*2DL("=H
M;W)D92YE<G)O<B<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1N
M;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")3=6-C97-S9G5L;'D@=W)O
M=&4@)7,B*2P@571I;#HZ<F5A;%!A=&@H)'!A=&@@+B`G+V-O;F8N<&AP)RDI
M+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@("`@("`@("!U;G-E="@D7U-%4U-)
M3TY;)U]C;VYF:6<G75LD87!P72D["B`@("`@("`@?0H@("`@?0H@("`@)')E
M9VES=')Y+3YC;&5A<D-A8VAE*"D["B`@("!R971U<FX@)&YO7V5R<F]R<SL*
M?0H*+RH@4V5T('5P('-O;64@:6-O;G,N("HO"B1S=6-C97-S(#T@2&]R9&4Z
M.FEM9R@G86QE<G1S+W-U8V-E<W,N<&YG)RP@)R<L("<G+"`D<F5G:7-T<GDM
M/F=E=$EM86=E1&ER*"=H;W)D92<I*3L*)'=A<FYI;F<@/2!(;W)D93HZ:6UG
M*"=A;&5R=',O=V%R;FEN9RYP;F<G+"`G)RP@)R<L("1R96=I<W1R>2T^9V5T
M26UA9V5$:7(H)VAO<F1E)RDI.PHD97)R;W(@/2!(;W)D93HZ:6UG*"=A;&5R
M=',O97)R;W(N<&YG)RP@)R<L("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER
M*"=H;W)D92<I*3L*"B1C;VYF7W5R;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R
M;"@G861M:6XO<V5T=7`O8V]N9FEG+G!H<"<I.PHD82`]("1R96=I<W1R>2T^
M;&ES=$%P<',H87)R87DH)VEN86-T:79E)RP@)VAI9&1E;B<L("=N;W1O;VQB
M87(G+"`G86-T:79E)RP@)V%D;6EN)RDI.PHD87!P<R`](&%R<F%Y*"D["B1I
M(#T@+3$["F9O<F5A8V@@*"1A(&%S("1A<'`I('L*("`@("\J(%-K:7`@87!P
M(&EF(&YO(&-O;F8N>&UL(&9I;&4N("HO"B`@("`D<&%T:"`]("1R96=I<W1R
M>2T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]C;VYF:6<G.PH@("`@:68@
M*"%F:6QE7V5X:7-T<R@D<&%T:"`N("<O8V]N9BYX;6PG*2D@>PH@("`@("`@
M(&-O;G1I;G5E.PH@("`@?0H*("`@("1I*RL["B`@("`D<&%T:"`]("1R96=I
M<W1R>2T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]C;VYF:6<G.PH*("`@
M("1C;VYF7VQI;FL@/2!5=&EL.CIA9&1087)A;65T97(H)&-O;F9?=7)L+"`G
M87!P)RP@)&%P<"D["B`@("`D8V]N9E]L:6YK(#T@2&]R9&4Z.FQI;FLH)&-O
M;F9?;&EN:RP@<W!R:6YT9BA?*")#;VYF:6=U<F4@)7,B*2P@)&%P<"DI.PH@
M("`@)&%P<'-;)&E=6R=S;W)T)UT@/2`D<F5G:7-T<GDM/F=E="@G;F%M92<L
M("1A<'`I("X@)R`H)R`N("1A<'`@+B`G*2<["B`@("`D87!P<ULD:5U;)VYA
M;64G72`]("1C;VYF7VQI;FL@+B`D87!P<ULD:5U;)W-O<G0G72`N("<\+V$^
M)SL*("`@("1A<'!S6R1I75LG=F5R<VEO;B==(#T@)R<["B`@("!I9B`H:7-?
M<F5A9&%B;&4H)')E9VES=')Y+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G
M+VQI8B]V97)S:6]N+G!H<"<I*2!["B`@("`@("`@<F5Q=6ER92`D<F5G:7-T
M<GDM/F=E="@G9FEL97)O;W0G+"`D87!P*2`N("<O;&EB+W9E<G-I;VXN<&AP
M)SL*("`@("`@("`D=F5R<VEO;E]C;VYS=&%N="`](%-T<FEN9SHZ=7!P97(H
M)&%P<"D@+B`G7U9%4E-)3TXG.PH@("`@("`@(&EF("AD969I;F5D*"1V97)S
M:6]N7V-O;G-T86YT*2D@>PH@("`@("`@("`@("`D87!P<ULD:5U;)W9E<G-I
M;VXG72`](&-O;G-T86YT*"1V97)S:6]N7V-O;G-T86YT*3L*("`@("`@("!]
M"B`@("!]"B`@("!I9B`H(69I;&5?97AI<W1S*"1P871H("X@)R]C;VYF+G!H
M<"<I*2!["B`@("`@("`@+RH@3F\@8V]N9BYP:'`@97AI<W1S+B`J+PH@("`@
M("`@("1A<'!S6R1I75LG8V]N9B==(#T@)&-O;F9?;&EN:R`N("1E<G)O<B`N
M("<\+V$^)SL*("`@("`@("`D87!P<ULD:5U;)W-T871U<R==(#T@7R@B36ES
M<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N
M;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN(BD["B`@
M("!](&5L<V4@>PH@("`@("`@("\J($$@8V]N9BYP:'`@97AI<W1S+"!G970@
M=&AE('AM;"!V97)S:6]N+B`J+PH@("`@("`@(&EF("@H)'AM;%]V97(@/2!?
M9V5T5F5R<VEO;B@D<&%T:"`N("<O8V]N9BYX;6PG*2D@/3T](&9A;'-E*2![
M"B`@("`@("`@("`@("1A<'!S6R1I75LG8V]N9B==(#T@)&-O;F9?;&EN:R`N
M("1W87)N:6YG("X@)SPO83XG.PH@("`@("`@("`@("`D87!P<ULD:5U;)W-T
M871U<R==(#T@7R@B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF
M:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(BD["B`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@('T*("`@("`@("`O*B!'970@=&AE
M(&=E;F5R871E9"!P:'`@=F5R<VEO;BX@*B\*("`@("`@("!I9B`H*"1P:'!?
M=F5R(#T@7V=E=%9E<G-I;VXH)'!A=&@@+B`G+V-O;F8N<&AP)RDI(#T]/2!F
M86QS92D@>PH@("`@("`@("`@("`O*B!.;R!V97)S:6]N(&9O=6YD(&EN(&=E
M;F5R871E9"!P:'`L('-U9V=E<W0@<F5G96YA<F%T:6YG"B`@("`@("`@("`@
M("`J(&IU<W0@:6X@8V%S92X@*B\*("`@("`@("`@("`@)&%P<'-;)&E=6R=C
M;VYF)UT@/2`D8V]N9E]L:6YK("X@)'=A<FYI;F<@+B`G/"]A/B<["B`@("`@
M("`@("`@("1A<'!S6R1I75LG<W1A='5S)UT@/2!?*").;R!V97)S:6]N(&9O
M=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U
M<F%T:6]N+B(I.PH@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("!]"@H@
M("`@("`@(&EF("@D>&UL7W9E<B`A/2`D<&AP7W9E<BD@>PH@("`@("`@("`@
M("`O*B!697)S:6]N<R!A<F4@;F]T('1H92!S86UE+"!C;VYF:6=U<F%T:6]N
M(&ES(&]U="!O9B!D871E+B`J+PH@("`@("`@("`@("`D87!P<ULD:5U;)V-O
M;F8G72`]("1C;VYF7VQI;FL@+B`D97)R;W(@+B`G/"]A/B<["B`@("`@("`@
M("`@("1A<'!S6R1I75LG<W1A='5S)UT@/2!?*")#;VYF:6=U<F%T:6]N(&ES
M(&]U="!O9B!D871E+B(I.PH@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`O*B!#;VYF:6=U<F%T:6]N(&ES(&]K
M+B`J+PH@("`@("`@("`@("`D87!P<ULD:5U;)V-O;F8G72`]("1C;VYF7VQI
M;FL@+B`D<W5C8V5S<R`N("<\+V$^)SL*("`@("`@("`@("`@)&%P<'-;)&E=
M6R=S=&%T=7,G72`](%\H(D%P<&QI8V%T:6]N(&ES(')E861Y+B(I.PH@("`@
M("`@('T*("`@('T*?0H*+RH@4V]R="!T:&4@87!P<R!B>2!N86UE+B`J+PIR
M97%U:7)E7V]N8V4@)TAO<F1E+T%R<F%Y+G!H<"<["DAO<F1E7T%R<F%Y.CIA
M<G)A>5-O<G0H)&%P<',L("=S;W)T)RD["@HO*B!3970@=7`@86YY(&%C=&EO
M;G,@=&AA="!M87D@8F4@;V9F97)E9"X@*B\*)&%C=&EO;G,@/2!A<G)A>2@I
M.PHD9G1P9F]R;2`]("<G.PII9B`H(65M<'1Y*"1?4T534TE/3ELG7V-O;F9I
M9R==*2D@>PH@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)W!O<'5P+FIS)RP@
M)VAO<F1E)RP@=')U92D["B`@("`D=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N
M57)L*"=A9&UI;B]S971U<"]D:69F+G!H<"<I.PH@("`@)&%C=&EO;B`](%\H
M(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD
M('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BXB*3L*("`@("1A
M8W1I;VYS6UT@/2!A<G)A>2@G:6-O;B<@/3X@2&]R9&4Z.FEM9R@G<V5A<F-H
M+G!N9R<L("<G+"`G86QI9VX](FUI9&1L92(G+"`D<F5G:7-T<GDM/F=E=$EM
M86=E1&ER*"=H;W)D92<I*2P*("`@("`@("`@("`@("`@("`@("`@("`G;&EN
M:R<@/3X@2&]R9&4Z.FQI;FLH)R,G+"`G)RP@)R<L("<G+"`G<&]P=7`H7"<G
M("X@)'5R;"`N("=<)RPV-#`L(#0X,"D[(')E='5R;B!F86QS93LG*2`N("1A
M8W1I;VX@+B`G/"]A/B<I.PH*("`@("1U<FP@/2!(;W)D93HZ87!P;&EC871I
M;VY5<FPH)V%D;6EN+W-E='5P+W-C<FEP=',N<&AP)RD["B`@("`O*B!!8W1I
M;VX@=&\@9&]W;FQO860@=&AE(&-O;F9I9W5R871I;VX@=7!G<F%D92!02%`@
M<V-R:7!T+B`J+PH@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L
M+"!A<G)A>2@G<V5T=7`G(#T^("=C;VYF)RP@)W1Y<&4G(#T^("=P:'`G*2D[
M"B`@("`D86-T:6]N(#T@7R@B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@4$A0('-C<FEP="XB*3L*("`@("1A8W1I;VYS6UT@/2!A<G)A
M>2@G:6-O;B<@/3X@2&]R9&4Z.FEM9R@G9&]W;FQO860N<&YG)RP@)R<L("=A
M;&EG;CTB;6ED9&QE(B<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E
M)RDI+`H@("`@("`@("`@("`@("`@("`@("`@("=L:6YK)R`]/B!(;W)D93HZ
M;&EN:R@D=7)L*2`N("1A8W1I;VX@+B`G/"]A/B<I.PH@("`@+RH@06-T:6]N
M('1O('-A=F4@=&AE(&-O;F9I9W5R871I;VX@=7!G<F%D92!02%`@<V-R:7!T
M+B`J+PH@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G<V%V
M92<L("=T;7`G*3L*("`@("1A8W1I;VX@/2!?*")3879E(&=E;F5R871E9"!C
M;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S
M('1E;7!O<F%R>2!D:7)E8W1O<GDN(BD["B`@("`D86-T:6]N<UM=(#T@87)R
M87DH)VEC;VXG(#T^($AO<F1E.CII;6<H)W-A=F4N<&YG)RP@)R<L("=A;&EG
M;CTB;6ED9&QE(B<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI
M+`H@("`@("`@("`@("`@("`@("`@("`@("=L:6YK)R`]/B!(;W)D93HZ;&EN
M:R@D=7)L*2`N("1A8W1I;VX@+B`G/"]A/B<I.PH*("`@("\J(%-E="!U<"!T
M:&4@9F]R;2!F;W(@1E10('5P;&]A9"!O9B!S8W)I<'1S+B`J+PH@("`@<F5Q
M=6ER95]O;F-E("=(;W)D92]&;W)M+G!H<"<["B`@("!R97%U:7)E7V]N8V4@
M)TAO<F1E+U9A<FEA8FQE<RYP:'`G.PH*("`@("1V87)S(#T@)E9A<FEA8FQE
M<SHZ9V5T1&5F875L=%9A<FEA8FQE<R@I.PH@("`@)&9T<&9O<FT@/2`F2&]R
M9&5?1F]R;3HZ<VEN9VQE=&]N*"<G+"`D=F%R<RD["B`@("`D9G1P9F]R;2T^
M<V5T5&ET;&4H7R@B1E10('5P;&]A9"!O9B!S971U<"(I*3L*("`@("1F='!F
M;W)M+3YS971"=71T;VYS*%\H(E5P;&]A9"(I+"!T<G5E*3L*("`@("1F='!F
M;W)M+3YA9&1687)I86)L92A?*")5<V5R;F%M92(I+"`G=7-E<FYA;64G+"`G
M=&5X="<L('1R=64L(&9A;'-E+"!N=6QL+"!A<G)A>2@G)RP@,C`I*3L*("`@
M("1F='!F;W)M+3YA9&1687)I86)L92A?*")087-S=V]R9"(I+"`G<&%S<W=O
M<F0G+"`G<&%S<W=O<F0G+"!F86QS92D["@H@("`@:68@*"1F='!F;W)M+3YV
M86QI9&%T92@D=F%R<RDI('L*("`@("`@("`D9G1P9F]R;2T^9V5T26YF;R@D
M=F%R<RP@)&EN9F\I.PH@("`@("`@("1U<&QO860@/2!?=7!L;V%D1E10*"1I
M;F9O*3L*("`@("`@("!I9B`H)'5P;&]A9"D@>PH@("`@("`@("`@("`D;F]T
M:69I8V%T:6]N+3YP=7-H*%\H(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S
M971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(I+"`G:&]R9&4N<W5C8V5S<R<I
M.PH@("`@("`@("`@("`D=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=A
M9&UI;B]S971U<"]I;F1E>"YP:'`G+"!T<G5E*3L*("`@("`@("`@("`@:&5A
M9&5R*"=,;V-A=&EO;CH@)R`N("1U<FPI.PH@("`@("`@("`@("!E>&ET.PH@
M("`@("`@('T*("`@('T*("`@("\J(%)E;F1E<B!T:&4@9F]R;2X@*B\*("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O1F]R;2]296YD97)E<BYP:'`G.PH@("`@
M)')E;F1E<F5R(#T@)FYE=R!(;W)D95]&;W)M7U)E;F1E<F5R*"D["B`@("`D
M9G1P9F]R;2`](%5T:6PZ.F)U9F9E<D]U='!U="AA<G)A>2@D9G1P9F]R;2P@
M)W)E;F1E<D%C=&EV92<I+"`D<F5N9&5R97(L("1V87)S+"`G:6YD97@N<&AP
M)RP@)W!O<W0G*3L*?0H*:68@*&9I;&5?97AI<W1S*$AO<F1E.CIG971496UP
M1&ER*"D@+B`G+VAO<F1E7W-E='5P7W5P9W)A9&4N<&AP)RDI('L*("`@("\J
M($%C=&EO;B!T;R!R96UO=F4@=&AE(&-O;F9I9W5R871I;VX@=7!G<F%D92!0
M2%`@<V-R:7!T+B`J+PH@("`@)'5R;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R
M;"@G861M:6XO<V5T=7`O<V-R:7!T<RYP:'`G*3L*("`@("1U<FP@/2!5=&EL
M.CIA9&1087)A;65T97(H)'5R;"P@)V-L96%N)RP@)W1M<"<I.PH@("`@)&%C
M=&EO;B`](%\H(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T
M96UP;W)A<GD@9&ER96-T;W)Y+B(I.PH@("`@)&%C=&EO;G-;72`](&%R<F%Y
M*"=I8V]N)R`]/B!(;W)D93HZ:6UG*"=D96QE=&4N<&YG)RP@)R<L("=A;&EG
M;CTB;6ED9&QE(B<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI
M+`H@("`@("`@("`@("`@("`@("`@("`@("=L:6YK)R`]/B!(;W)D93HZ;&EN
M:R@D=7)L*2`N("1A8W1I;VX@+B`G/"]A/B<I.PI]"@HO*B!3970@=7`@=&AE
M('1E;7!L871E+B`J+PHD=&5M<&QA=&4@/2`F;F5W($AO<F1E7U1E;7!L871E
M*"D["B1T96UP;&%T92T^<V5T*"=A<'!S)RP@)&%P<',I.PHD=&5M<&QA=&4M
M/G-E="@G86-T:6]N<R<L("1A8W1I;VYS+"!T<G5E*3L*)'1E;7!L871E+3YS
M970H)V9T<&9O<FTG+"`D9G1P9F]R;2P@=')U92D["B1T96UP;&%T92T^<V5T
M*"=N;W1I9GDG+"!5=&EL.CIB=69F97)/=71P=70H87)R87DH)&YO=&EF:6-A
M=&EO;BP@)VYO=&EF>2<I*2D["B1T96UP;&%T92T^<V5T3W!T:6]N*"=G971T
M97AT)RP@=')U92D["@HD=&ET;&4@/2!S<')I;G1F*%\H(B5S(%-E='5P(BDL
M("1R96=I<W1R>2T^9V5T*"=N86UE)RP@)VAO<F1E)RDI.PI(;W)D93HZ861D
M4V-R:7!T1FEL92@G<W1R:7!E+FIS)RP@)VAO<F1E)RP@=')U92D["G)E<75I
M<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["G)E
M<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]C;VUM;VXM:&5A9&5R
M+FEN8R<["F5C:&\@)'1E;7!L871E+3YF971C:"A(3U)$15]414U03$%415,@
M+B`G+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PG*3L*<F5Q=6ER92!(3U)$15]4
M14U03$%415,@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'``````````````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`Q,#4Q,@`Q,#4Q-30S,S<T-``P,C(S,#4`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M($=E;F5R871E<R!U<&=R861E('-C<FEP=',@9F]R($AO<F1E)W,@<V5T=7`N
M($-U<G)E;G1L>2!A;&QO=W,@=&AE(&=E;F5R871I;VX*("H@;V8@4$A0('5P
M9W)A9&4@<V-R:7!T<R!F;W(@8V]N9BYP:'`@9FEL97,@96ET:&5R(&%S(&1O
M=VYL;V%D(&]R('-A=F5D('1O('1H90H@*B!S97)V97(G<R!T96UP;W)A<GD@
M9&ER96-T;W)Y+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+V%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP+'8@,2XY+C$P+C8@,C`P-B\P-B\Q-B`P.#HR-#HR-R!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:&%R;&5S($HN($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,3DY.2TR
M,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("HO"@ID969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N
M("<O+BXO+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B
M87-E+G!H<"<["@II9B`H(4%U=&@Z.FES061M:6XH*2D@>PH@("`@2&]R9&4Z
M.F9A=&%L*"=&;W)B:61D96XN)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*?0H*
M+RH@1V5T(&9O<FT@9&%T82X@*B\*)'-E='5P(#T@571I;#HZ9V5T1F]R;41A
M=&$H)W-E='5P)RD["B1T>7!E(#T@571I;#HZ9V5T1F]R;41A=&$H)W1Y<&4G
M*3L*)'-A=F4@/2!5=&EL.CIG971&;W)M1&%T82@G<V%V92<I.PHD8VQE86X@
M/2!5=&EL.CIG971&;W)M1&%T82@G8VQE86XG*3L*"B1F:6QE;F%M92`]("=H
M;W)D95]S971U<%]U<&=R861E+G!H<"<["@HO*B!#:&5C:R!I9B!T:&ES(&ES
M(&]N;'D@82!R97%U97-T('1O(&-L96%N('5P+B`J+PII9B`H)&-L96%N(#T]
M("=T;7`G*2!["B`@("`D=&UP7V1I<B`]($AO<F1E.CIG971496UP1&ER*"D[
M"B`@("`D<&%T:"`](%5T:6PZ.G)E86Q0871H*"1T;7!?9&ER("X@)R\G("X@
M)&9I;&5N86UE*3L*("`@(&EF("AU;FQI;FLH)'1M<%]D:7(@+B`G+R<@+B`D
M9FEL96YA;64I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I
M;G1F*%\H(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(I
M+"`D<&%T:"DL("=H;W)D92YS=6-C97-S)RD["B`@("!](&5L<V4@>PH@("`@
M("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")#;W5L9"!N;W0@
M9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB*2P@571I;#HZ
M<F5A;%!A=&@H)'!A=&@I*2P@)VAO<F1E+F5R<F]R)RD["B`@("!]"B`@("`D
M<F5G:7-T<GDM/F-L96%R0V%C:&4H*3L*("`@("1U<FP@/2!(;W)D93HZ87!P
M;&EC871I;VY5<FPH)V%D;6EN+W-E='5P+VEN9&5X+G!H<"<L('1R=64I.PH@
M("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1U<FPI.PH@("`@97AI=#L*?0H*
M)&1A=&$@/2`G)SL*:68@*"1S971U<"`]/2`G8V]N9B<@)B8@)'1Y<&4@/3T@
M)W!H<"<I('L*("`@("\J($$@8FET('5G;'D@:&5R92P@<V%V92!02%`@8V]D
M92!I;G1O(&$@<W1R:6YG(&9O<B!C<F5A=&EN9R!T:&4@<V-R:7!T"B`@("`@
M*B!T;R!B92!R=6X@870@=&AE(&-O;6UA;F0@<')O;7!T+B`J+PH@("`@)&1A
M=&$@/2`G(R$O=7-R+V)I;B]P:'`G("X@(EQN(CL*("`@("1D871A("X]("<\
M/W!H<"<@+B`B7&XB.PH@("`@9F]R96%C:"`H)%]315-324].6R=?8V]N9FEG
M)UT@87,@)&%P<"`]/B`D<&AP*2!["B`@("`@("`@)'!A=&@@/2`D<F5G:7-T
M<GDM/F=E="@G9FEL97)O;W0G+"`D87!P*2`N("<O8V]N9FEG)SL*("`@("`@
M("`O*B!!9&0@8V]D92!T;R!S879E(&)A8VMU<"X@*B\*("`@("`@("`D9&%T
M82`N/2`G:68@*&9I;&5?97AI<W1S*%PG)R`N("1P871H("X@)R]C;VYF+G!H
M<%PG*2D@>R<@+B`B7&XB.PH@("`@("`@("1D871A("X]("<@("`@:68@*$!C
M;W!Y*%PG)R`N("1P871H("X@)R]C;VYF+G!H<%PG+"!<)R<@+B`D<&%T:"`N
M("<O8V]N9BYP:'`N8F%K7"<I*2![)R`N(")<;B(["B`@("`@("`@)&1A=&$@
M+CT@)R`@("`@("`@96-H;R!<)R<@+B!?*")3=6-C97-S9G5L;'D@<V%V960@
M8F%C:W5P(&-O;F9I9W5R871I;VXN(BD@+B`G7"<@+B`B7&XB.R<@+B`B7&XB
M.PH@("`@("`@("1D871A("X]("<@("`@?2!E;'-E('LG("X@(EQN(CL*("`@
M("`@("`D9&%T82`N/2`G("`@("`@("!E8VAO(%PG)R`N(%\H(D-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB*2`N("=<)R`N(")<;B([
M)R`N(")<;B(["B`@("`@("`@)&1A=&$@+CT@)R`@("!])R`N(")<;B(["B`@
M("`@("`@)&1A=&$@+CT@)WTG("X@(EQN(CL*"B`@("`@("`@)&1A=&$@+CT@
M)VEF("@D9G`@/2!`9F]P96XH7"<G("X@)'!A=&@@+B`G+V-O;F8N<&AP7"<L
M(%PG=UPG*2D@>R<@+B`B7&XB.PH@("`@("`@("1D871A("X]("<@("`@9G=R
M:71E*"1F<"P@7"<G.PH@("`@("`@("1D871A("X](%-T<FEN9SHZ8V]N=F5R
M=$-H87)S970H<W1R7W)E<&QA8V4H87)R87DH)UQ<)RP@)UPG)RDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@G7%Q<7"<L("=<7%PG)RDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&AP*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($Y,4SHZ9V5T0VAA
M<G-E="@I+"`G:7-O+3@X-3DM,2<I.PH@("`@("`@("1D871A("X]("=<)RD[
M)R`N(")<;B(["B`@("`@("`@)&1A=&$@+CT@)R`@("!F8VQO<V4H)&9P*3LG
M("X@(EQN(CL*("`@("`@("`D9&%T82`N/2`G("`@(&5C:&\@7"<G("X@<W!R
M:6YT9BA?*")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(I+"`D87!P*2`N("=<
M)R`N(")<;B([)R`N(")<;B(["B`@("`@("`@)&1A=&$@+CT@)WT@96QS92![
M)R`N(")<;B(["B`@("`@("`@)&1A=&$@+CT@)R`@("!E8VAO(%PG)R`N('-P
M<FEN=&8H7R@B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB*2P@
M)&%P<"D@+B`G7"<@+B`B7&XB.R<@+B`B7&XB.PH@("`@("`@("1D871A("X]
M("=])R`N(")<;EQN(CL*("`@('T*?0H*:68@*"1S879E(#T]("=T;7`G*2![
M"B`@("`D=&UP7V1I<B`]($AO<F1E.CIG971496UP1&ER*"D["B`@("`O*B!!
M9&0@<V5L9BUD97-T<G5C="!C;V1E+B`J+PH@("`@)&1A=&$@+CT@)V5C:&\@
M7"=396QF+61E<W1R=6-T:6YG+BXN7"<@+B`B7&XB.R<@+B`B7&XB.PH@("`@
M)&1A=&$@+CT@)VEF("AU;FQI;FLH7U]&24Q%7U\I*2![)R`N(")<;B(["B`@
M("`D9&%T82`N/2`G("`@(&5C:&\@7"<G("X@7R@B57!G<F%D92!S8W)I<'0@
M9&5L971E9"XB*2`N("=<)R`N(")<;B([)R`N(")<;B(["B`@("`D9&%T82`N
M/2`G?2!E;'-E('LG("X@(EQN(CL*("`@("1D871A("X]("<@("`@96-H;R!<
M)R<@+B!S<')I;G1F*%\H(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y5
M04Q,62!&4D]-("5S+B(I+"`D=&UP7V1I<BD@+B`G7"<@+B`B7&XB.R<@+B`B
M7&XB.PH@("`@)&1A=&$@+CT@)WTG("X@(EQN(CL*("`@("\J(%1H92!S8W)I
M<'0@<VAO=6QD(&)E('-A=F5D('1O('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E
M8W1O<GDN("HO"B`@("`D<&%T:"`](%5T:6PZ.G)E86Q0871H*"1T;7!?9&ER
M("X@)R\G("X@)&9I;&5N86UE*3L*("`@(&EF("@D9G`@/2!`9F]P96XH)'1M
M<%]D:7(@+B`G+R<@+B`D9FEL96YA;64L("=W)RDI('L["B`@("`@("`@9G=R
M:71E*"1F<"P@)&1A=&$I.PH@("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@
M(&-H;6]D*"1T;7!?9&ER("X@)R\G("X@)&9I;&5N86UE+"`P-S<W*3L*("`@
M("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B4V%V960@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB*2P@)'!A=&@I+"`G:&]R
M9&4N<W5C8V5S<R<I.PH@("`@?2!E;'-E('L*("`@("`@("`D;F]T:69I8V%T
M:6]N+3YP=7-H*'-P<FEN=&8H7R@B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB*2P@)'!A=&@I+"`G:&]R9&4N97)R
M;W(G*3L*("`@('T*("`@("1U<FP@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH
M)V%D;6EN+W-E='5P+VEN9&5X+G!H<"<L('1R=64I.PH@("`@:&5A9&5R*"=,
M;V-A=&EO;CH@)R`N("1U<FPI.PH@("`@97AI=#L*?2!E;'-E('L*("`@("\J
M($]U='!U="!S8W)I<'0@=&\@8G)O=W-E<B!F;W(@9&]W;FQO860N("HO"B`@
M("`D8G)O=W-E<BT^9&]W;FQO861(96%D97)S*"1F:6QE;F%M92P@)W1E>'0O
M<&QA:6XG+"!F86QS92P@<W1R;&5N*"1D871A*2D["B`@("!E8VAO("1D871A
M.PI]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]S<6QS:&5L
M;"YP:'``````````````````````````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#$S,S$R`#$P-3$U-#,S-S0T`#`R,3,P-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H
M;W)D92]A9&UI;B]S<6QS:&5L;"YP:'`L=B`Q+C$X+C$P+CD@,C`P-B\P,B\R
M-"`R,CHT.#HR.2!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR
M,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)
M3$5?7RD@+B`G+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L
M:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N<&AP)SL*
M<F5Q=6ER95]O;F-E("=(;W)D92](96QP+G!H<"<["G)E<75I<F5?;VYC92`G
M1$(N<&AP)SL*"FEF("@A075T:#HZ:7-!9&UI;B@I*2!["B`@("!(;W)D93HZ
M9F%T86PH)T9O<F)I9&1E;BXG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PI]"@HD
M=&ET;&4@/2!?*")344P@4VAE;&PB*3L*2&]R9&4Z.F%D9%-C<FEP=$9I;&4H
M)W-T<FEP92YJ<R<L("=H;W)D92<L('1R=64I.PIR97%U:7)E($A/4D1%7U1%
M35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G.PIR97%U:7)E($A/4D1%
M7U1%35!,051%4R`N("<O861M:6XO8V]M;6]N+6AE861E<BYI;F,G.PH*/SX*
M/&1I=B!S='EL93TB<&%D9&EN9SHQ,'!X(CX*/&9O<FT@;F%M93TB<W%L<VAE
M;&PB(&%C=&EO;CTB/#]P:'`@96-H;R`D7U-%4E9%4ELG4$A07U-%3$8G72`_
M/B(@;65T:&]D/2)P;W-T(CX*/#]P:'`@571I;#HZ<&9O<FU);G!U="@I(#\^
M"@H\/W!H<`H*)&1B:"`]("9$0CHZ8V]N;F5C="@D8V]N9ELG<W%L)UTI.PII
M9B`H:7-?82@D9&)H+"`G4$5!4E]%<G)O<B<I*2!["B`@("!(;W)D93HZ9F%T
M86PH)&1B:"P@7U]&24Q%7U\L(%]?3$E.15]?*3L*?0HD9&)H+3YS971/<'1I
M;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?3$]715)#05-%('P@
M1$)?4$]25$%"24Q)5%E?15)23U)3*3L*"FEF("A5=&EL.CIG971&;W)M1&%T
M82@G;&ES="UT86)L97,G*2D@>PH@("`@)&1E<V-R:7!T:6]N(#T@)TQ)4U0@
M5$%"3$53)SL*("`@("1R97-U;'0@/2`D9&)H+3YG971,:7-T3V8H)W1A8FQE
M<R<I.PI](&5L<V5I9B`H571I;#HZ9V5T1F]R;41A=&$H)VQI<W0M9&)S)RDI
M('L*("`@("1D97-C<FEP=&EO;B`]("=,25-4($1!5$%"05-%4R<["B`@("`D
M<F5S=6QT(#T@)&1B:"T^9V5T3&ES=$]F*"=D871A8F%S97,G*3L*?2!E;'-E
M:68@*"1C;VUM86YD(#T@=')I;2A5=&EL.CIG971&;W)M1&%T82@G<W%L)RDI
M*2!["B`@("`O+R!+965P(&$@8V%C:&4@;V8@<')I;W(@<75E<FEE<R!F;W(@
M8V]N=F5N:65N8V4N"B`@("!I9B`H(6ES<V5T*"1?4T534TE/3ELG7W-Q;%]Q
M=65R>5]C86-H92==*2D@>PH@("`@("`@("1?4T534TE/3ELG7W-Q;%]Q=65R
M>5]C86-H92==(#T@87)R87DH*3L*("`@('T*("`@(&EF("@H)&ME>2`](&%R
M<F%Y7W-E87)C:"@D8V]M;6%N9"P@)%]315-324].6R=?<W%L7W%U97)Y7V-A
M8VAE)UTI*2`A/3T@9F%L<V4I('L*("`@("`@("!U;G-E="@D7U-%4U-)3TY;
M)U]S<6Q?<75E<GE?8V%C:&4G75LD:V5Y72D["B`@("!]"B`@("!A<G)A>5]U
M;G-H:69T*"1?4T534TE/3ELG7W-Q;%]Q=65R>5]C86-H92==+"`D8V]M;6%N
M9"D["B`@("!W:&EL92`H8V]U;G0H)%]315-324].6R=?<W%L7W%U97)Y7V-A
M8VAE)UTI(#X@,C`I('L*("`@("`@("!A<G)A>5]P;W`H)%]315-324].6R=?
M<W%L7W%U97)Y7V-A8VAE)UTI.PH@("`@?0H*("`@("\O(%!A<G-E(&]U="!T
M:&4@<75E<GD@<F5S=6QT<RX*("`@("1R97-U;'0@/2`D9&)H+3YQ=65R>2A3
M=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1C;VUM86YD+"!.3%,Z.F=E=$-H87)S
M970H*2P@)&-O;F9;)W-Q;"==6R=C:&%R<V5T)UTI*3L*?0H*:68@*&ES<V5T
M*"1R97-U;'0I*2!["B`@("!I9B`H:7-S970H)&-O;6UA;F0I*2!["B`@("`@
M("`@96-H;R`G/&@Q(&-L87-S/2)H96%D97(B/B<@+B!?*")1=65R>2(I("X@
M)SPO:#$^/&)R("\^/'!R92!C;&%S<STB=&5X="(^)R`N(&AT;6QS<&5C:6%L
M8VAA<G,H)&-O;6UA;F0I("X@)SPO<')E/B<["B`@("!]"@H@("`@96-H;R`G
M/&@Q(&-L87-S/2)H96%D97(B/B<@+B!?*")297-U;'1S(BD@+B`G/"]H,3X\
M8G(@+SXG.PH*("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("!E8VAO("<\<')E(&-L87-S/2)T97AT(CXG.R!V87)?9'5M
M<"@D<F5S=6QT*3L@96-H;R`G/"]P<F4^)SL*("`@('T@96QS92!["B`@("`@
M("`@:68@*&ES7V]B:F5C="@D<F5S=6QT*2D@>PH@("`@("`@("`@("!E8VAO
M("<\=&%B;&4@8V5L;'-P86-I;F<](C$B(&-L87-S/2)I=&5M('-T<FEP960B
M/B<["B`@("`@("`@("`@("1F:7)S="`]('1R=64["B`@("`@("`@("`@("1I
M(#T@,#L*("`@("`@("`@("`@=VAI;&4@*"1R;W<@/2`D<F5S=6QT+3YF971C
M:%)O=RA$0E]&151#2$U/1$5?05-33T,I*2!["B`@("`@("`@("`@("`@("!I
M9B`H)&9I<G-T*2!["B`@("`@("`@("`@("`@("`@("`@96-H;R`G/'1R/B<[
M"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)')O=R!A<R`D:V5Y(#T^
M("1V86PI('L*("`@("`@("`@("`@("`@("`@("`@("`@96-H;R`G/'1H(&%L
M:6=N/2)L969T(CXG("X@*&5M<'1Y*"1K97DI(#\@)R9N8G-P.R<@.B!H=&UL
M<W!E8VEA;&-H87)S*%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&ME>2P@)&-O
M;F9;)W-Q;"==6R=C:&%R<V5T)UTI*2D@+B`G/"]T:#XG.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!E8VAO("<\+W1R/B<[
M"B`@("`@("`@("`@("`@("`@("`@)&9I<G-T(#T@9F%L<V4["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!E8VAO("<\='(^)SL*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1R;W<@87,@)'9A;"D@>PH@("`@("`@("`@
M("`@("`@("`@(&5C:&\@)SQT9"!C;&%S<STB9FEX960B/B<@+B`H96UP='DH
M)'9A;"D@/R`G)FYB<W`[)R`Z(&AT;6QS<&5C:6%L8VAA<G,H4W1R:6YG.CIC
M;VYV97)T0VAA<G-E="@D=F%L+"`D8V]N9ELG<W%L)UU;)V-H87)S970G72DI
M*2`N("<\+W1D/B<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!E8VAO("<\+W1R/B<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96-H
M;R`G/"]T86)L93XG.PH@("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D<F5S
M=6QT*2D@>PH@("`@("`@("`@("!E8VAO("<\=&%B;&4@8V5L;'-P86-I;F<]
M(C$B(&-L87-S/2)I=&5M('-T<FEP960B/B<["B`@("`@("`@("`@("1F:7)S
M="`]('1R=64["B`@("`@("`@("`@("1I(#T@,#L*("`@("`@("`@("`@9F]R
M96%C:"`H)')E<W5L="!A<R`D=F%L*2!["B`@("`@("`@("`@("`@("!I9B`H
M)&9I<G-T*2!["B`@("`@("`@("`@("`@("`@("`@96-H;R`G/'1R/CQT:"!A
M;&EG;CTB;&5F="(^)R`N("AI<W-E="@D9&5S8W)I<'1I;VXI(#\@:'1M;'-P
M96-I86QC:&%R<R@D9&5S8W)I<'1I;VXI(#H@)R9N8G-P.R<I("X@)SPO=&@^
M/"]T<CXG.PH@("`@("`@("`@("`@("`@("`@("1F:7)S="`](&9A;'-E.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96-H;R`G/'1R/CQT
M9"!C;&%S<STB9FEX960B/B<@+B`H96UP='DH)'9A;"D@/R`G)FYB<W`[)R`Z
M(&AT;6QS<&5C:6%L8VAA<G,H4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D=F%L
M+"`D8V]N9ELG<W%L)UU;)V-H87)S970G72DI*2`N("<\+W1D/CPO='(^)SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E8VAO("<\+W1A8FQE/B<["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@96-H;R`G/'-T<F]N9SXG("X@
M7R@B4W5C8V5S<R(I("X@)SPO<W1R;VYG/B<["B`@("`@("`@?0H@("`@?0H*
M("`@(&5C:&\@)SQB<B`O/B<["GT*/SX*"CP_<&AP(&EF("AI<W-E="@D7U-%
M4U-)3TY;)U]S<6Q?<75E<GE?8V%C:&4G72D@)B8*("`@("`@("`@(&-O=6YT
M*"1?4T534TE/3ELG7W-Q;%]Q=65R>5]C86-H92==*2DZ(#\^"B`@/'-E;&5C
M="!N86UE/2)Q=65R>5]C86-H92(@;VYC:&%N9V4](F1O8W5M96YT+G-Q;'-H
M96QL+G-Q;"YV86QU92`](&1O8W5M96YT+G-Q;'-H96QL+G%U97)Y7V-A8VAE
M6V1O8W5M96YT+G-Q;'-H96QL+G%U97)Y7V-A8VAE+G-E;&5C=&5D26YD97A=
M+G9A;'5E.R(^"B`@/#]P:'`@9F]R96%C:"`H)%]315-324].6R=?<W%L7W%U
M97)Y7V-A8VAE)UT@87,@)'%U97)Y*3H@/SX*("`@(#QO<'1I;VX@=F%L=64]
M(CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D<75E<GDI(#\^(CX\/W!H
M<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'%U97)Y*2`_/CPO;W!T:6]N/@H@
M(#P_<&AP(&5N9&9O<F5A8V@[(#\^"B`@/"]S96QE8W0^"B`@/&EN<'5T('1Y
M<&4](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B4&%S=&4B*2`_/B(@
M8VQA<W,](F)U='1O;B(@;VYC;&EC:STB9&]C=6UE;G0N<W%L<VAE;&PN<W%L
M+G9A;'5E(#T@9&]C=6UE;G0N<W%L<VAE;&PN<75E<GE?8V%C:&5;9&]C=6UE
M;G0N<W%L<VAE;&PN<75E<GE?8V%C:&4N<V5L96-T961);F1E>%TN=F%L=64[
M(B`O/@H@(#QI;G!U="!T>7!E/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO
M(%\H(E)U;B(I(#\^(B!C;&%S<STB8G5T=&]N(B!O;F-L:6-K/2)D;V-U;65N
M="YS<6QS:&5L;"YS<6PN=F%L=64@/2!D;V-U;65N="YS<6QS:&5L;"YQ=65R
M>5]C86-H95MD;V-U;65N="YS<6QS:&5L;"YQ=65R>5]C86-H92YS96QE8W1E
M9$EN9&5X72YV86QU93L@9&]C=6UE;G0N<W%L<VAE;&PN<W5B;6ET*"D[(B`O
M/@H@(#QB<B`O/@H\/W!H<"!E;F1I9CL@/SX*"CQT97AT87)E82!C;&%S<STB
M9FEX960B(&YA;64](G-Q;"(@<F]W<STB,3`B(&-O;',](C8P(CX*/#]P:'`@
M:68@*"%E;7!T>2@D8V]M;6%N9"DI(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D
M8V]M;6%N9"D@/SX\+W1E>'1A<F5A/@H\8G(@+SX*/&EN<'5T('1Y<&4](G-U
M8FUI="(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B17AE
M8W5T92(I(#\^(B`O/@H\:6YP=70@='EP93TB8G5T=&]N(B!C;&%S<STB8G5T
M=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")#;&5A<B!1=65R>2(I(#\^(B!O
M;F-L:6-K/2)D;V-U;65N="YS<6QS:&5L;"YS<6PN=F%L=64])R<B("\^"CP_
M<&AP(&EF("@A96UP='DH)&-O;6UA;F0I*3H@/SX*/&EN<'5T('1Y<&4](G)E
M<V5T(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")297-T
M;W)E($QA<W0@475E<GDB*2`_/B(@+SX*/#]P:'`@96YD:68[(#\^"CP_<&AP
M(&EF("@D9&)H+3YG9713<&5C:6%L475E<GDH)W1A8FQE<R<I("$]/2!N=6QL
M*3H@/SX\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!N86UE
M/2)L:7-T+71A8FQE<R(@=F%L=64](CP_<&AP(&5C:&\@7R@B3&ES="!486)L
M97,B*2`_/B(@+SX@/#]P:'`@96YD:68[(#\^"CP_<&AP(&EF("@D9&)H+3YG
M9713<&5C:6%L475E<GDH)V1A=&%B87-E<R<I("$]/2!N=6QL*3H@/SX\:6YP
M=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!N86UE/2)L:7-T+61B
M<R(@=F%L=64](CP_<&AP(&5C:&\@7R@B3&ES="!$871A8F%S97,B*2`_/B(@
M+SX@/#]P:'`@96YD:68[(#\^"CP_<&AP(&5C:&\@2&5L<#HZ;&EN:R@G861M
M:6XG+"`G861M:6XM<W%L<VAE;&PG*2`_/@H*/"]F;W)M/@H\+V1I=CX*/#]P
M:'`*"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R
M+FEN8R<["@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D;6EN+W1E;7!L871E<RYP
M:'``````````````````````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,34Q
M,S8`,3`U,34T,S,W-#0`,#(Q-#8S`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!(;W)D92!496UP;&%T
M92!!9&UI;@H@*@H@*B`D2&]R9&4Z(&AO<F1E+V%D;6EN+W1E;7!L871E<RYP
M:'`L=B`Q+C$U+C$P+C,@,C`P-B\P,2\P,2`R,3HR.#HP-2!J86X@17AP("0*
M("H*("H@1FER<W0@<W1A8B!A="!A('1E;7!L871E(&QO861E<B!F;W(@:&]R
M9&4L('1O(&)E('5S960@8GD@=&AE(&AO<F1E"B`J(&%D;6EN('1O(&QO860@
M86QT97)N871E(&EN9&EV:61U86P@=&5M<&QA=&5S(&]R(&5N=&ER92!T:&5M
M97,@9F]R('1H90H@*B!(;W)D95]496UP;&%T92!S>7-T96TN"B`J("T@9VEV
M97,@82!L:7-T(&]F(&%C=&EV92!H;W)D92!A<'!S(&%N9"!T:&5I<B`O=&5M
M<&QA=&5S(&1I<F5C=&]R>0H@*B`@(&-O;G1E;G1S('1O(&-H;V]S92!F<F]M
M"B`J("T@=7-E<B!C86X@9')I;&P@9&]W;B!T;R!A('-P96-I9FEC(&9I;&4@
M86YD(&QO860@87,@;6%N>2!A;'1E<FYA=&4*("H@("!T96UP;&%T97,@87,@
M<F5Q=6ER960*("H@+2!I="!A;&QO=W,@<V%V:6YG(&]F('1E;7!L871E<R!O
M;FQY(&]N(&%C='5A;"!F:6QE<R`H86YD(&YO=`H@*B`@(&1I<F5C=&]R:65S
M*2!A;F0@9&]E<R!N;W0@<VAO=R!H:61D96X@9FEL97,N"B`J("T@=&AE(&%L
M=&5R;F%T92!T96UP;&%T97,@87)E('-T;W)E9"!I;B!T:&4@5D93('5N9&5R
M('1H92!D:7)E8W1O<GD*("H@("!P871H.@H@*B`@("`@("YH;W)D95]T96UP
M;&%T97,O)&%P<"]S;VUE=&5M<&QA=&5D:7(O=&5M<&QA=&5F:6QE"B`J("`@
M<V\@=&AA="!D:7)E8W1O<GD@=V]U;&0@8V]N=&%I;B!A;&P@=&AE(&%L=&5R
M;F%T:79E<R!F;W(@=&AA=`H@*B`@('1E;7!L871E+@H@*B`M(%1/1$\Z(&1O
M;B=T('-H;W<@8V5R=&%I;B!O=&AE<B!F:6QE<RP@;&EK92!#5E,@9&ER96-T
M;W)I97,[(&-O;6UE;G1S.PH@*B`@('1H96UE('-E;&5C=&EO;B!A;F0@<W1O
M<FEN9R!I;B!T:&4@5D93('5N9&5R.@H@*B`@("`@("YH;W)D95]T96UP;&%T
M97,O)&%P<"]?=&AE;65S+R1T:&5M92]S;VUE=&5M<&QA=&5D:7(O=&5M<&QA
M=&5F:6QE"B`J("`@=&\@8F4@86)L92!T;R!C86QL('5P(&%N(&5N=&ER92!T
M:&5M92!G<F]U<"!O9B!T96UP;&%T97,_(&)E='1E<B!E<G)O<@H@*B`@(&-H
M96-K:6YG.R!D;W=N;&]A9&EN9R!O9B!O<FEG:6YA;"!T96UP;&%T97,[('1H
M92!A<'!L:6-A=&EO;B!S:61E(&]F"B`J("`@86QL;W=I;F<@82!D:69F97)E
M;G0@=&5M<&QA=&4@=&\@8F4@8VAO<V5N+W!R969S+V5T8RX*("H*("H@0V]P
M>7)I9VAT(#(P,#,M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I
M<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?
M0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-
M96YU+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O5F%R:6%B;&5S+G!H<"<[
M"@II9B`H(4%U=&@Z.FES061M:6XH*2D@>PH@("`@2&]R9&4Z.F9A=&%L*"=&
M;W)B:61D96XN)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*?0HD875T:"`]("9!
M=71H.CIS:6YG;&5T;VXH)&-O;F9;)V%U=&@G75LG9')I=F5R)UTI.PH*9G5N
M8W1I;VX@7W-E=%9A;'5E<U1O2V5Y<R@D:6XI('L*("`@("1O=70@/2!A<G)A
M>2@I.PH@("`@9F]R96%C:"`H)&EN(&%S("1V86QU92D@>PH@("`@("`@("1O
M=71;)'9A;'5E72`]("1V86QU93L*("`@('T*("`@(&%S;W)T*"1O=70I.PH@
M("`@<F5T=7)N("1O=70["GT*"B\J(%-E="!U<"!61E,N("HO"G)E<75I<F5?
M;VYC92`G5D93+G!H<"<["B1V9G-?='EP92`]("1C;VYF6R=V9G,G75LG='EP
M92==.PHD=F9S7V%R9W,@/2!(;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=V9G,G
M+"`D=F9S7W1Y<&4I.PHD=F9S7V%R9W-;)W5S97(G72`]($%U=&@Z.F=E=$%U
M=&@H*3L*)'9F<R`]("961E,Z.G-I;F=L971O;B@D=F9S7W1Y<&4L("1V9G-?
M87)G<RD["@I`9&5F:6YE*"=414U03$%415-?5D937U!!5$@G+"`G+FAO<F1E
M7W1E;7!L871E<R<I.PH*+RH@4F5Q=6ER92!(;W)D95]&;W)M(&QI8G,N("HO
M"G)E<75I<F5?;VYC92`G2&]R9&4O1F]R;2YP:'`G.PIR97%U:7)E7V]N8V4@
M)TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D
M92]&;W)M+T%C=&EO;BYP:'`G.PH*+RH@4V5T('5P($AO<F1E7T9O<FTN("HO
M"B1V87)S(#T@)E9A<FEA8FQE<SHZ9V5T1&5F875L=%9A<FEA8FQE<R@I.PHD
M9F]R;2`]("9(;W)D95]&;W)M.CIS:6YG;&5T;VXH)U1E;7!L871E<T9O<FTG
M+"`D=F%R<RD["B1A8W1I;VX@/2`F2&]R9&5?1F]R;5]!8W1I;VXZ.F9A8W1O
M<GDH)W-U8FUI="<I.PH*+RH@4V5T('5P(&9O<FT@9FEE;&1S+B`J+PHD87!P
M<R`](%]S971686QU97-4;TME>7,H)')E9VES=')Y+3YL:7-T07!P<R@I*3L*
M)'-E;&5C=%]A<'`@/2`F)&9O<FTM/F%D9%9A<FEA8FQE*%\H(D%P<&QI8V%T
M:6]N(BDL("=A<'`G+"`G96YU;2<L('1R=64L(&9A;'-E+"!N=6QL+"!A<G)A
M>2@D87!P<RDI.PHD<V5L96-T7V%P<"T^<V5T06-T:6]N*"1A8W1I;VXI.PHD
M9F]R;2T^861D2&ED9&5N*"<G+"`G;VQD7V%P<"<L("=T97AT)RP@9F%L<V4L
M(&9A;'-E*3L*"B\J(%-E="!U<"!S;VUE('9A<FEA8FQE<RX@*B\*)&9O<FUN
M86UE(#T@)'9A<G,M/F=E="@G9F]R;6YA;64G*3L*)&%P<"`]("1V87)S+3YG
M970H)V%P<"<I.PHD;VQD7V%P<"`]("1V87)S+3YG970H)V]L9%]A<'`G*3L*
M)'1E;7!L871E7W!A=&@@/2`D=F%R<RT^9V5T*"=T96UP;&%T95]P871H)RD[
M"B1T96UP;&%T95]O<FEG(#T@)'9A<G,M/F=E="@G=&5M<&QA=&5?;W)I9R<I
M.PHD;VQD7W1E;7!L871E7V]R:6<@/2`D=F%R<RT^9V5T*"=O;&1?=&5M<&QA
M=&5?;W)I9R<I.PHD:&%S7V-H86YG960@/2!F86QS93L*"FEF("@D87!P("$]
M("1O;&1?87!P*2!["B`@("`D:&%S7V-H86YG960@/2!T<G5E.PH@("`@)'1E
M;7!L871E7W!A=&@@/2`G)SL*("`@("1T96UP;&%T95]O<FEG(#T@)R<["B`@
M("`D;VQD7W1E;7!L871E7V]R:6<@/2`G)SL*?0HD=F%R<RT^<V5T*"=O;&1?
M87!P)RP@)&%P<"D["FEF("@D=&5M<&QA=&5?;W)I9R`A/2`D;VQD7W1E;7!L
M871E7V]R:6<I('L*("`@("1H87-?8VAA;F=E9"`]('1R=64["GT*)'9A<G,M
M/G-E="@G;VQD7W1E;7!L871E7V]R:6<G+"`D=&5M<&QA=&5?;W)I9RD["@II
M9B`H(6ES7VYU;&PH)&%P<"DI('L*("`@(&EF("@D=&5M<&QA=&5?;W)I9R`]
M/2`G+BXG*2!["B`@("`@("`@)'!A=&A?<&%R=',@/2!E>'!L;V1E*"<O)RP@
M)'1E;7!L871E7W!A=&@I.PH@("`@("`@(&%R<F%Y7W!O<"@D<&%T:%]P87)T
M<RD["B`@("`@("`@)'1E;7!L871E7W!A=&@@/2!I;7!L;V1E*"<O)RP@)'!A
M=&A?<&%R=',I.PH@("`@("`@("1T96UP;&%T95]O<FEG(#T@)R<["B`@("!]
M"@H@("`@+RH@1V5T('1H92!F=6QL('1E;7!L871E('!A=&@@;VX@=&AE(&9I
M;&4@<WES=&5M+B`J+PH@("`@)'1E;7!L871E7W!A=&A?9G5L;"`]("1R96=I
M<W1R>2T^9V5T*"=T96UP;&%T97,G+"`D87!P*2`N("<O)R`N("1T96UP;&%T
M95]P871H.PH*("`@("\J($EF('-E;&5C=&5D('1E;7!L871E(&ES(&1I<F5C
M=&]R>2!A9&0@=&\@=&5M<&QA=&4@<&%T:"X@*B\*("`@(&EF("@A96UP='DH
M)'1E;7!L871E7V]R:6<I("8F"B`@("`@("`@:7-?9&ER*"1T96UP;&%T95]P
M871H7V9U;&P@+B`G+R<@+B`D=&5M<&QA=&5?;W)I9RDI('L*("`@("`@("`D
M=&5M<&QA=&5?<&%T:"`N/2`G+R<@+B`D=&5M<&QA=&5?;W)I9SL*("`@("`@
M("`D=&5M<&QA=&5?<&%T:%]F=6QL("X]("<O)R`N("1T96UP;&%T95]O<FEG
M.PH@("`@?0H*("`@("1F;W)M+3YA9&1687)I86)L92AS<')I;G1F*%\H(D]R
M:6=I;F%L('1E;7!L871E<R!I;B`E<SHB*2P@)'1E;7!L871E7W!A=&@I+"`G
M;W)I9U]T96UP;&%T97-?:&5A9&5R)RP@)VAE861E<B<L(&9A;'-E+"!F86QS
M92D["@H@("`@+RH@061D('1H92!P871H('1O('1H92!H:61D96X@=F%R(&EN
M('1H92!F;W)M+B`J+PH@("`@)&9O<FTM/F%D9$AI9&1E;B@G)RP@)W1E;7!L
M871E7W!A=&@G+"`G=&5X="<L(&9A;'-E+"!F86QS92D["B`@("`D=F%R<RT^
M<V5T*"=T96UP;&%T95]P871H)RP@)'1E;7!L871E7W!A=&@I.PH*("`@("\J
M($=E="!D:7)E8W1O<GD@;&ES="!F;W(@8VAO<V5N(&1I<F5C=&]R>2!I;B!T
M96UP;&%T97,N("HO"B`@("!I9B`H)'1E;7!L871E<U]D:7(@/2!O<&5N9&ER
M*"1T96UP;&%T95]P871H7V9U;&PI*2!["B`@("`@("`@=VAI;&4@*&9A;'-E
M("$]/2`H)&9I;&4@/2!R96%D9&ER*"1T96UP;&%T97-?9&ER*2DI('L*("`@
M("`@("`@("`@+RH@1&]N)W0@<VAO=R!C=7)R96YT(&1I<BP@:&ED9&5N(&9I
M;&5S(&%N9"!O;FQY('-H;W<@)RXN)PH@("`@("`@("`@("`@*B!I9B!N;W0@
M:6X@<F]O="!D:7(@;V8@86X@87!P)W,@=&5M<&QA=&5S+B`J+PH@("`@("`@
M("`@("!I9B`H)&9I;&4@(3T@(BXB("8F("$H)&9I;&4@/3T@)RXN)R`F)B!E
M;7!T>2@D=&5M<&QA=&5?<&%T:"DI("8F"B`@("`@("`@("`@("`@("`A*"1F
M:6QE("$]("<N+B<@)B8@<W5B<W1R*"1F:6QE+"`P+"`Q*2`]/2`G+B<I*2![
M"B`@("`@("`@("`@("`@("`D=&5M<&QA=&5S6UT@/2`D9FEL93L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!C;&]S961I<B@D=&5M<&QA=&5S
M7V1I<BD["B`@("`@("`@)'1E;7!L871E<R`](%]S971686QU97-4;TME>7,H
M)'1E;7!L871E<RD["B`@("`@("`@)'8@/2`F)&9O<FTM/F%D9%9A<FEA8FQE
M*%\H(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(BDL("=T96UP;&%T
M95]O<FEG)RP@)V5N=6TG+"!T<G5E+"!F86QS92P@;G5L;"P@87)R87DH)'1E
M;7!L871E<RDI.PH@("`@("`@("1V+3YS971!8W1I;VXH)&%C=&EO;BD["B`@
M("`@("`@)&9O<FTM/F%D9$AI9&1E;B@G)RP@)V]L9%]T96UP;&%T95]O<FEG
M)RP@)W1E>'0G+"!F86QS92P@9F%L<V4I.PH@("`@?0H*("`@("\J($]N;'D@
M<V5T('5P('1H97-E('9A<G,@:68@=&AE(&-H;W-E;B!T96UP;&%T92!I<R!A
M(&9I;&4N("HO"B`@("!I9B`H:7-?9FEL92@D=&5M<&QA=&5?<&%T:%]F=6QL
M("X@)R\G("X@)'1E;7!L871E7V]R:6<I*2!["B`@("`@("`@)&9O<FTM/F%D
M9%9A<FEA8FQE*%\H(D%L=&5R;F%T92!T96UP;&%T97,B*2P@)V%L=%]T96UP
M;&%T97-?:&5A9&5R)RP@)VAE861E<B<L(&9A;'-E+"!F86QS92D["@H@("`@
M("`@("\J($=E="!T:&4@86QR96%D>2!S879E9"!A;'1E<FYA=&4@=&5M<&QA
M=&5S+B`J+PH@("`@("`@("1V9G-?<&%T:"`](%1%35!,051%4U]61E-?4$%4
M2"`N("<O)R`N("1A<'`@+B`D=&5M<&QA=&5?<&%T:"`N("<O)R`N("1T96UP
M;&%T95]O<FEG.PH@("`@("`@("1T96UP;&%T97-?86QT(#T@87)R87E?:V5Y
M<R@D=F9S+3YL:7-T1F]L9&5R*"1V9G-?<&%T:"P@;G5L;"P@9F%L<V4I*3L*
M("`@("`@("`D=&5M<&QA=&5S7V%L="`](&%R<F%Y*"<G(#T^("<G*2`K(%]S
M971686QU97-4;TME>7,H)'1E;7!L871E<U]A;'0I.PH@("`@("`@("1F;W)M
M+3YA9&1687)I86)L92A?*")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E
M;7!L871E(BDL("=D96QE=&5?=&5M<&QA=&5?86QT)RP@)V5N=6TG+"!F86QS
M92P@9F%L<V4L(&YU;&PL(&%R<F%Y*"1T96UP;&%T97-?86QT*2D["@H@("`@
M("`@("1F;W)M+3YA9&1687)I86)L92A?*"));G-E<G0@86QT97)N871E('1E
M;7!L871E(BDL("=T96UP;&%T95]A;'0G+"`G9FEL92<L(&9A;'-E+"!F86QS
M92D["B`@("!]"GT*"FEF("@D9F]R;6YA;64@)B8@(21H87-?8VAA;F=E9"D@
M>PH@("`@+RH@26YS97)T:6YG(&$@;F5W(&%L=&5R;F%T92!T96UP;&%T92X@
M*B\*("`@("1F;W)M+3YV86QI9&%T92@D=F%R<RD["@H@("`@:68@*"1F;W)M
M+3YI<U9A;&ED*"DI('L*("`@("`@("`D9F]R;2T^9V5T26YF;R@D=F%R<RP@
M)&EN9F\I.PH@("`@("`@(&EF("@A96UP='DH)&EN9F];)V1E;&5T95]T96UP
M;&%T95]A;'0G72DI('L*("`@("`@("`@("`@)'9F<RT^9&5L971E1FEL92@D
M=F9S7W!A=&@L("1I;F9O6R=D96QE=&5?=&5M<&QA=&5?86QT)UTI.PH@("`@
M("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1I;F9O6R=T96UP;&%T95]A;'0G
M75LG<VEZ92==*2D@>PH@("`@("`@("`@("`D=F9S+3YW<FET92@D=F9S7W!A
M=&@L("1I;F9O6R=T96UP;&%T95]A;'0G75LG;F%M92==+"`D:6YF;ULG=&5M
M<&QA=&5?86QT)UU;)W1M<%]N86UE)UTL('1R=64I.PH@("`@("`@('T*("`@
M('T*?0H*)'1I=&QE(#T@7R@B5&5M<&QA=&4@061M:6YI<W1R871I;VXB*3L*
M<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC
M)SL*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V%D;6EN+V-O;6UO;BUH
M96%D97(N:6YC)SL*)&YO=&EF:6-A=&EO;BT^;F]T:69Y*&%R<F%Y*"=L:7-T
M96YE<G,G(#T^("=S=&%T=7,G*2D["@HO*B!296YD97(@=&AE(&9O<FTN("HO
M"B1R96YD97)E<B`]("9N97<@2&]R9&5?1F]R;5]296YD97)E<B@I.PHD9F]R
M;2T^<F5N9&5R06-T:79E*"1R96YD97)E<BP@)'9A<G,L("=T96UP;&%T97,N
M<&AP)RP@)W!O<W0G*3L*"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C
M;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+V%D;6EN+W5S97(N<&AP````````````````````````
M````````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C,W-S<`,3`U,34T,S,W-#0`
M,#(P-#4U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+V%D;6EN+W5S97(N<&AP
M+'8@,2XT-RXQ,"XW(#(P,#8O,#$O,#$@,C$Z,C@Z,#4@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$
M15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["G)E<75I<F5?
M;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N
M8V4@)TAO<F1E+TUE;G4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]&;W)M
M+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O5F%R:6%B;&5S+G!H<"<["G)E
M<75I<F5?;VYC92`G2&]R9&4O1F]R;2]296YD97)E<BYP:'`G.PIR97%U:7)E
M7V]N8V4@)TAO<F1E+U9A<FEA8FQE<RYP:'`G.PH*:68@*"%!=71H.CII<T%D
M;6EN*"DI('L*("`@($AO<F1E.CIF871A;"@G1F]R8FED9&5N+B<L(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["GT*)&%U=&@@/2`F075T:#HZ<VEN9VQE=&]N*"1C
M;VYF6R=A=71H)UU;)V1R:79E<B==*3L*"FEF("@D8V]N9ELG<VEG;G5P)UU;
M)V%L;&]W)UT@)B8@)&-O;F9;)W-I9VYU<"==6R=A<'!R;W9E)UTI('L*("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O075T:"]3:6=N=7`N<&AP)SL*("`@("1S
M:6=N=7`@/2`F075T:%]3:6=N=7`Z.G-I;F=L971O;B@I.PI]"@HD=F%R<R`]
M("9687)I86)L97,Z.F=E=$1E9F%U;'1687)I86)L97,H*3L*)&%D9$9O<FT@
M/2`F;F5W($AO<F1E7T9O<FTH)'9A<G,L(%\H(D%D9"!A(&YE=R!U<V5R.B(I
M+"`G861D=7-E<B<I.PHD861D1F]R;2T^<V5T0G5T=&]N<RA?*")!9&0@=7-E
M<B(I+"!?*")297-E="(I*3L*"B1V87)S+3YS970H)V9O<FTG+"`G861D)RD[
M"B1A9&1&;W)M+3YA9&1(:61D96XH)R<L("=F;W)M)RP@)W1E>'0G+"!T<G5E
M+"!T<G5E*3L*)&%D9$9O<FTM/F%D9%9A<FEA8FQE*%\H(E5S97)N86UE(BDL
M("=U<V5R7VYA;64G+"`G=&5X="<L('1R=64I.PHD861D1F]R;2T^861D5F%R
M:6%B;&4H7R@B4&%S<W=O<F0B*2P@)W!A<W-W;W)D)RP@)W!A<W-W;W)D8V]N
M9FER;2<L(&9A;'-E+"!F86QS92P@7R@B='EP92!T:&4@<&%S<W=O<F0@='=I
M8V4@=&\@8V]N9FER;2(I*3L*"B\J(%5S92!H;V]K<R!G970@86YY(&5X=')A
M(&9I96QD<R!F;W(@;F5W(&%C8V]U;G1S+B`J+PHD97AT<F$@/2!(;W)D93HZ
M8V%L;$AO;VLH)U]H;W)D95]H;V]K7W-I9VYU<%]G971E>'1R82<I.PII9B`H
M(6ES7V$H)&5X=')A+"`G4$5!4E]%<G)O<B<I("8F("%E;7!T>2@D97AT<F$I
M*2!["B`@("!F;W)E86-H("@D97AT<F$@87,@)&9I96QD7VYA;64@/3X@)&9I
M96QD*2!["B`@("`@("`@)')E861O;FQY(#T@:7-S970H)&9I96QD6R=R96%D
M;VYL>2==*2`_("1F:65L9%LG<F5A9&]N;'DG72`Z(&YU;&P["B`@("`@("`@
M)&1E<V,@/2!I<W-E="@D9FEE;&1;)V1E<V,G72D@/R`D9FEE;&1;)V1E<V,G
M72`Z(&YU;&P["B`@("`@("`@)&9I96QD7W!A<F%M<R`](&ES<V5T*"1F:65L
M9%LG<&%R86US)UTI(#\@)&9I96QD6R=P87)A;7,G72`Z(&%R<F%Y*"D["@H@
M("`@("`@("1A9&1&;W)M+3YA9&1687)I86)L92@D9FEE;&1;)VQA8F5L)UTL
M("=E>'1R85LG("X@)&9I96QD7VYA;64@+B`G72<L("1F:65L9%LG='EP92==
M+"`D9FEE;&1;)W)E<75I<F5D)UTL("1R96%D;VYL>2P@)&1E<V,L("1F:65L
M9%]P87)A;7,I.PH@("`@?0I]"@H*+R\@4')O8V5S<R!F;W)M<RX@57-E(%5T
M:6PZ.F=E=%!O<W0H*2!I;G-T96%D(&]F(%5T:6PZ.F=E=$9O<FU$871A*"D*
M+R\@9F]R(&$@;&]T(&]F('1H92!D871A(&)E8V%U<V4@=V4@=V%N="!T;R!A
M8W1I=F5L>2!I9VYO<F4@1T54(&1A=&$*+R\@:6X@<V]M92!C87-E<R`M(&%D
M9&EN9R]M;V1I9GEI;F<@=7-E<G,@+2!A<R!A('-E8W5R:71Y('!R96-A=71I
M;VXN"G-W:71C:"`H571I;#HZ9V5T1F]R;41A=&$H)V9O<FTG*2D@>PIC87-E
M("=A9&0G.@H@("`@)&%D9$9O<FTM/G9A;&ED871E*"1V87)S*3L*"B`@("!I
M9B`H)&%D9$9O<FTM/FES5F%L:60H*2`F)B`D=F%R<RT^9V5T*"=F;W)M;F%M
M92<I(#T]("=A9&1U<V5R)RD@>PH@("`@("`@("1A9&1&;W)M+3YG971);F9O
M*"1V87)S+"`D:6YF;RD["@H@("`@("`@(&EF("AE;7!T>2@D:6YF;ULG=7-E
M<E]N86UE)UTI*2!["B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H
M7R@B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(I+"`G
M:&]R9&4N97)R;W(G*3L*"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&-R961E;G1I86QS(#T@87)R87DH)W!A<W-W;W)D)R`]/B`D:6YF;ULG<&%S
M<W=O<F0G72D["B`@("`@("`@("`@(&EF("AI<W-E="@D:6YF;ULG97AT<F$G
M72DI('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O6R=E>'1R82==
M(&%S("1F:65L9"`]/B`D=F%L=64I('L*("`@("`@("`@("`@("`@("`@("`D
M8W)E9&5N=&EA;'-;)&9I96QD72`]("1V86QU93L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*&ES7V$H)')E="`]
M("1A=71H+3YA9&15<V5R*"1I;F9O6R=U<V5R7VYA;64G72P@)&-R961E;G1I
M86QS*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E1H97)E('=A<R!A('!R;V)L96T@
M861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(I+"`D:6YF;ULG=7-E
M<E]N86UE)UTL("1R970M/F=E=$UE<W-A9V4H*2DL("=H;W)D92YE<G)O<B<I
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1I;F9O6R=E>'1R82==*2D@>PH@("`@("`@("`@("`@("`@("`@("1R
M97-U;'0@/2!(;W)D93HZ8V%L;$AO;VLH)U]H;W)D95]H;V]K7W-I9VYU<%]A
M9&1E>'1R82<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@D:6YF;ULG=7-E<E]N86UE)UTL("1I;F9O6R=E
M>'1R82==*2D["B`@("`@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B061D960@7"(E<UPB('1O
M('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG
M;G5P(&EN9F]R;6%T:6]N.B`E<RXB*2P@)&EN9F];)W5S97)?;F%M92==+"`D
M<F5S=6QT+3YG971-97-S86=E*"DI+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&EF("A5=&EL.CIG971&;W)M1&%T82@G<F5M;W9E475E=65D4VEG
M;G5P)RDI('L*("`@("`@("`@("`@("`@("`@("`D<VEG;G5P+3YR96UO=F51
M=65U9613:6=N=7`H)&EN9F];)W5S97)?;F%M92==*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R
M:6YT9BA?*")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T
M96TN(BDL("1I;F9O6R=U<V5R7VYA;64G72DL("=H;W)D92YS=6-C97-S)RD[
M"B`@("`@("`@("`@("`@("`D861D1F]R;2T^=6YS971687)S*"1V87)S*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@(&)R96%K.PH*8V%S
M92`G<F5M;W9E7V8G.@H@("`@)&9?=7-E<E]N86UE(#T@571I;#HZ9V5T1F]R
M;41A=&$H)W5S97)?;F%M92<I.PH@("`@)')E;6]V95]F;W)M(#T@=')U93L*
M("`@(&)R96%K.PH*8V%S92`G<F5M;W9E)SH*("`@("1F7W5S97)?;F%M92`]
M(%5T:6PZ.F=E=$9O<FU$871A*"=U<V5R7VYA;64G*3L*("`@(&EF("AE;7!T
M>2@D9E]U<V5R7VYA;64I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S
M:"A?*")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(I
M+"`G:&]R9&4N;65S<V%G92<I.PH@("`@?2!E;'-E:68@*%5T:6PZ.F=E=$9O
M<FU$871A*"=S=6)M:70G*2`A/3T@7R@B0V%N8V5L(BDI('L*("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT(#T@)&%U=&@M/G)E;6]V955S97(H)&9?=7-E<E]N
M86UE*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D;F]T:69I8V%T
M:6]N+3YP=7-H*'-P<FEN=&8H7R@B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO
M=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B*2`N("1R97-U;'0M/F=E
M=$UE<W-A9V4H*2P@)&9?=7-E<E]N86UE*2P@)VAO<F1E+F5R<F]R)RD["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S
M:"AS<')I;G1F*%\H(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M
M('1H92!S>7-T96TN(BDL("1F7W5S97)?;F%M92DL("=H;W)D92YS=6-C97-S
M)RD["B`@("`@("`@?0H@("`@?0H@("`@)'9A<G,M/G)E;6]V92@G=7-E<E]N
M86UE)RD["B`@("!B<F5A:SL*"F-A<V4@)V-L96%R7V8G.@H@("`@)&9?=7-E
M<E]N86UE(#T@571I;#HZ9V5T1F]R;41A=&$H)W5S97)?;F%M92<I.PH@("`@
M)&-L96%R7V9O<FT@/2!T<G5E.PH@("`@8G)E86L["@IC87-E("=C;&5A<B<Z
M"B`@("`D9E]U<V5R7VYA;64@/2!5=&EL.CIG971&;W)M1&%T82@G=7-E<E]N
M86UE)RD["B`@("!I9B`H96UP='DH)&9?=7-E<E]N86UE*2D@>PH@("`@("`@
M("1N;W1I9FEC871I;VXM/G!U<V@H7R@B66]U(&UU<W0@<W!E8VEF>2!A('5S
M97)N86UE('1O(&-L96%R(&]U="XB*2P@)VAO<F1E+FUE<W-A9V4G*3L*("`@
M('T@96QS96EF("A5=&EL.CIG971&;W)M1&%T82@G<W5B;6ET)RD@(3T](%\H
M(D-A;F-E;"(I*2!["B`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1A=71H
M+3YR96UO=F55<V5R1&%T82@D9E]U<V5R7VYA;64I+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?
M*")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@
M7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(BD@+B`D<F5S=6QT+3YG971-97-S
M86=E*"DL("1F7W5S97)?;F%M92DL("=H;W)D92YE<G)O<B<I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R
M:6YT9BA?*")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB
M)7-<(B!F<F]M('1H92!S>7-T96TN(BDL("1F7W5S97)?;F%M92DL("=H;W)D
M92YS=6-C97-S)RD["B`@("`@("`@?0H@("`@?0H@("`@)'9A<G,M/G)E;6]V
M92@G=7-E<E]N86UE)RD["B`@("!B<F5A:SL*"F-A<V4@)W5P9&%T95]F)SH*
M("`@("1F7W5S97)?;F%M92`](%5T:6PZ.F=E=$9O<FU$871A*"=U<V5R7VYA
M;64G*3L*("`@("1U<&1A=&5?9F]R;2`]('1R=64["B`@("!B<F5A:SL*"F-A
M<V4@)W5P9&%T92<Z"B`@("`D=7-E<E]N86UE7S$@/2!5=&EL.CIG9710;W-T
M*"=U<V5R7VYA;64G*3L*("`@("1U<V5R7VYA;65?,B`](%5T:6PZ.F=E=%!O
M<W0H)W5S97)?;F%M93(G+"`D=7-E<E]N86UE7S$I.PH@("`@)&9U;&QN86UE
M(#T@571I;#HZ9V5T4&]S="@G=7-E<E]F=6QL;F%M92<I.PH@("`@)&5M86EL
M(#T@571I;#HZ9V5T4&]S="@G=7-E<E]E;6%I;"<I.PH*("`@(&EF("@D875T
M:"T^:&%S0V%P86)I;&ET>2@G=7!D871E)RDI('L*("`@("`@("`D=7-E<E]P
M87-S7S$@/2!5=&EL.CIG9710;W-T*"=U<V5R7W!A<W-?,2<I.PH@("`@("`@
M("1U<V5R7W!A<W-?,B`](%5T:6PZ.F=E=%!O<W0H)W5S97)?<&%S<U\R)RD[
M"@H@("`@("`@(&EF("AE;7!T>2@D=7-E<E]N86UE7S$I*2!["B`@("`@("`@
M("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B66]U(&UU<W0@<W!E8VEF>2!T
M:&4@=7-E<FYA;64@=&\@=7!D871E+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@
M("`@("!](&5L<V5I9B`H96UP='DH)'5S97)?<&%S<U\Q*2!\?"!E;7!T>2@D
M=7-E<E]P87-S7S(I*2!["B`@("`@("`@("`@("\O($1O;B=T('5P9&%T92P@
M8G5T(&1O;B=T(&-O;7!L86EN+@H@("`@("`@('T@96QS96EF("@D=7-E<E]P
M87-S7S$@(3T@)'5S97)?<&%S<U\R*2!["B`@("`@("`@("`@("1N;W1I9FEC
M871I;VXM/G!U<V@H7R@B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(BDL("=H;W)D
M92YE<G)O<B<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R97-U
M;'0@/2`D875T:"T^=7!D871E57-E<B@D=7-E<E]N86UE7S$L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=7-E<E]N86UE7S(L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G<&%S<W=O<F0G(#T^("1U<V5R7W!A<W-?,2DI.PH@("`@("`@('T*("`@
M('T*"B`@("!I9B`H:7-S970H)')E<W5L="D@)B8@:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS
M<')I;G1F*%\H(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB
M.B`E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=7-E<E]N86UE7S$L("1R97-U;'0M/F=E=$UE<W-A9V4H*2DL("=H;W)D92YE
M<G)O<B<I.PH@("`@?2!E;'-E('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO
M<F1E+TED96YT:71Y+G!H<"<["B`@("`@("`@)&ED96YT:71Y(#T@)DED96YT
M:71Y.CIS:6YG;&5T;VXH)VYO;F4G+"`D=7-E<E]N86UE7S$I.PH@("`@("`@
M("1I9&5N=&ET>2T^<V5T5F%L=64H)V9U;&QN86UE)RP@)&9U;&QN86UE*3L*
M("`@("`@("`D:61E;G1I='DM/G-E=%9A;'5E*"=F<F]M7V%D9'(G+"`D96UA
M:6PI.PH@("`@("`@("1I9&5N=&ET>2T^<V%V92@I.PH*("`@("`@("`D;F]T
M:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B4W5C8V5S<V9U;&QY('5P9&%T
M960@7"(E<UPB(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1U<V5R7VYA;65?,BDL("=H;W)D92YS=6-C97-S)RD["B`@("!]"B`@
M("`D=F%R<RT^<F5M;W9E*"=U<V5R7VYA;64G*3L*("`@(&)R96%K.PH*8V%S
M92`G87!P<F]V95]F)SH*("`@("1T:&ES4VEG;G5P(#T@)'-I9VYU<"T^9V5T
M475E=65D4VEG;G5P*%5T:6PZ.F=E=$9O<FU$871A*"=U<V5R7VYA;64G*2D[
M"B`@("`D:6YF;R`]("1T:&ES4VEG;G5P+3YG971$871A*"D["@H@("`@)'9A
M<G,M/G-E="@G<&%S<W=O<F0G+`H@("`@("`@("`@("`@("!A<G)A>2@G;W)I
M9VEN86PG(#T^("1I;F9O6R=P87-S=V]R9"==+`H@("`@("`@("`@("`@("`@
M("`@("`G8V]N9FER;2<@/3X@)&EN9F];)W!A<W-W;W)D)UTI*3L*("`@('5N
M<V5T*"1I;F9O6R=P87-S=V]R9"==*3L*("`@("1V87)S+3YS970H)V5X=')A
M)RP@)&EN9F\I.PH*("`@("1V87)S+3YS970H)W)E;6]V95%U975E9%-I9VYU
M<"<L('1R=64I.PH@("`@)&%D9$9O<FTM/F%D9$AI9&1E;B@G)RP@)W)E;6]V
M95%U975E9%-I9VYU<"<L("=B;V]L96%N)RP@=')U92D["B`@("!B<F5A:SL*
M"F-A<V4@)W)E;6]V97%U975E9%]F)SH*("`@("1F7W5S97)?;F%M92`](%5T
M:6PZ.F=E=$9O<FU$871A*"=U<V5R7VYA;64G*3L*("`@("1R96UO=F5Q=65U
M961?9F]R;2`]('1R=64["B`@("!B<F5A:SL*"F-A<V4@)W)E;6]V97%U975E
M9"<Z"B`@("`D<F5S=6QT(#T@)'-I9VYU<"T^<F5M;W9E475E=65D4VEG;G5P
M*%5T:6PZ.F=E=$9O<FU$871A*"=U<V5R7VYA;64G*2D["B`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)&YO=&EF:6-A
M=&EO;BT^<'5S:"@D<F5S=6QT*3L*("`@('T@96QS92!["B`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E1H92!S:6=N=7`@<F5Q=65S
M="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB*2P@571I;#HZ9V5T1F]R;41A
M=&$H)W5S97)?;F%M92<I*2D["B`@("!]"B`@("!B<F5A:SL*?0H*)'1I=&QE
M(#T@7R@B57-E<B!!9&UI;FES=')A=&EO;B(I.PI(;W)D93HZ861D4V-R:7!T
M1FEL92@G<W1R:7!E+FIS)RP@)VAO<F1E)RP@=')U92D["G)E<75I<F4@2$]2
M1$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["G)E<75I<F4@
M2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8R<[
M"B1N;W1I9FEC871I;VXM/FYO=&EF>2AA<G)A>2@G;&ES=&5N97)S)R`]/B`G
M<W1A='5S)RDI.PH*:68@*&ES<V5T*"1U<&1A=&5?9F]R;2D@)B8@)&%U=&@M
M/FAA<T-A<&%B:6QI='DH)VQI<W0G*2D@>PH@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92])9&5N=&ET>2YP:'`G.PH@("`@)&ED96YT:71Y(#T@)DED96YT:71Y
M.CIS:6YG;&5T;VXH)VYO;F4G+"`D9E]U<V5R7VYA;64I.PH@("`@<F5Q=6ER
M92!(3U)$15]414U03$%415,@+B`G+V%D;6EN+W5S97(O=7!D871E+FEN8R<[
M"GT@96QS96EF("AI<W-E="@D<F5M;W9E7V9O<FTI("8F("1A=71H+3YH87-#
M87!A8FEL:71Y*"=L:7-T)RD@)B8@)&%U=&@M/FAA<T-A<&%B:6QI='DH)W)E
M;6]V92<I*2!["B`@("!R97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O861M
M:6XO=7-E<B]R96UO=F4N:6YC)SL*?2!E;'-E:68@*&ES<V5T*"1C;&5A<E]F
M;W)M*2D@>PH@("`@<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V%D;6EN
M+W5S97(O8VQE87(N:6YC)SL*?2!E;'-E:68@*&ES<V5T*"1R96UO=F5Q=65U
M961?9F]R;2DI('L*("`@(')E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A
M9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,G.PI](&5L<V5I9B`H)&%U=&@M
M/FAA<T-A<&%B:6QI='DH)V%D9"<I*2!["B`@("!R97%U:7)E($A/4D1%7U1%
M35!,051%4R`N("<O861M:6XO=7-E<B]A9&0N:6YC)SL*("`@(&EF("@D8V]N
M9ELG<VEG;G5P)UU;)V%L;&]W)UT@)B8@)&-O;F9;)W-I9VYU<"==6R=A<'!R
M;W9E)UTI('L*("`@("`@("!R97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8R<["B`@("!]"GT@96QS92!["B`@("!R
M97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O861M:6XO=7-E<B]N;V%D9"YI
M;F,G.PI]"@II9B`H)&%U=&@M/FAA<T-A<&%B:6QI='DH)VQI<W0G*2D@>PH*
M("`@("\J($EF('=E(&%R96XG="!S=7!P;&EE9"!W:71H(&$@<&%G92!N=6UB
M97(L(&1E9F%U;'0@=&\@<&%G92`P+B`J+PH@("`@)'!A9V4@/2!5=&EL.CIG
M971&;W)M1&%T82@G<&%G92<L(#`I.PH@("`@)'-E87)C:%]P871T97)N(#T@
M571I;#HZ9V5T1F]R;41A=&$H)W-E87)C:%]P871T97)N)RP@)R<I.PH*("`@
M("1U<V5R<R`]("1A=71H+3YL:7-T57-E<G,H*3L*("`@(&EF("AI<U]A*"1U
M<V5R<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@($AO<F1E.CIF871A;"@D
M=7-E<G,L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("!]"@H@("`@+RH@4F5T
M=7)N<R!O;FQY('5S97)S('1H870@;6%T8V@@=&AE('-P96-I9FEE9"!P871T
M97)N+B`J+PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]!<G)A>2YP:'`G.PH@
M("`@)'5S97)S(#T@<')E9U]G<F5P*"<O)R`N("1S96%R8VA?<&%T=&5R;B`N
M("<O)RP@)'5S97)S*3L*("`@('-O<G0H)'5S97)S*3L*"B`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+U5)+U!A9V5R+G!H<"<["B`@("`D=FEE=W5R;"`](%5T
M:6PZ.F%D9%!A<F%M971E<B@G861M:6XO=7-E<BYP:'`G+"`G<V5A<F-H7W!A
M='1E<FXG+"`D<V5A<F-H7W!A='1E<FXI.PH*("`@("1N=6UI=&5M(#T@8V]U
M;G0H)'5S97)S*3L*("`@("1P97)P86=E(#T@,C`["@H@("`@)&UI;B`]("1P
M86=E("H@)'!E<G!A9V4["B`@("!W:&EL92`H)&UI;B`^("1N=6UI=&5M*2![
M"B`@("`@("`@)'!A9V4M+3L*("`@("`@("`D;6EN(#T@)'!A9V4@*B`D<&5R
M<&%G93L*("`@('T*("`@("1M87@@/2`D;6EN("L@)'!E<G!A9V4["@H@("`@
M)'-T87)T(#T@*"1P86=E("H@)'!E<G!A9V4I("L@,3L*("`@("1E;F0@/2!M
M:6XH)&YU;6ET96TL("1S=&%R="`K("1P97)P86=E("T@,2D["@H@("`@<F5Q
M=6ER92!(3U)$15]414U03$%415,@+B`G+V%D;6EN+W5S97(O;&ES="YI;F,G
M.PI](&5L<V4@>PH@("`@<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V%D
M;6EN+W5S97(O;F]L:7-T+FEN8R<["GT*"G)E<75I<F4@2$]21$5?5$5-4$Q!
M5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@`N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+V1O8W,O````````````````````````````````````````
M````````````````````````````````````````````````````,#`P,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-#,`,#$V
M-C`U`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O9&]C<R]#2$%.1T53````````
M````````````````````````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#(R-3<W
M,P`Q,#4Q-30S,S<T,P`P,3<V,C``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+2TM+2TM"G8S+C$N,PHM+2TM+2T*"EMC:FA=
M(%-%0U522519.B!686QI9&%T92!'150M8F%S960@55),('!A<F%M971E<G,@
M<')O=FED960@=&\@2&]R9&4G<PH@("`@("!I;F1E>"YP:'`N"EMJ86Y=(%-U
M<'!O<G0@:6UP;W)T:6YG(&]F(&-O;6)I;F5D(&1A=&4O=&EM92!F:65L9',@
M*$)U9R`C,S$Q-BDN"EMJ86Y=($QO9R!A('=A<FYI;F<@:68@=7-I;F<@<V5T
M=&EN9W,@=&AA="!B<F5A:R!S97-S:6]N<RX*6VIA;ET@1FEX('!A<G-E(&5R
M<F]R('1H870@8G)O:V4@4WEN8TU,('-Y;F-H<F]N:7IA=&EO;B`H0G5G(",T
M,38X*2X*6VIA;ET@4W5P<&]R="!+;VQA8B!G<F]U<"!!0TQS("AC<V%C8V%`
M=&AE8W-L+F]R9RP@4F5Q=65S="`C,C(W,"DN"EMJ86Y=($9I>"!U;G-E<FEA
M;&EZ92@I(&5R<F]R<R!I;B!S97-S:6]N('9I97=E<B`H0G5G(",S-3@V*2X*
M"@HM+2TM+2T*=C,N,2XR"BTM+2TM+0H*6V-J:%T@4T5#55))5%DZ(%)E;6]V
M92!U;G5S960@:6UA9V4@<')O>'D@8V]D92!F<F]M(&1E<F5F97)R97(N"EMC
M:FA=(%-%0U522519.B!#;&]S92!84U,@<')O8FQE;7,@:6X@9&5R969E<G)E
M<B`H244@;VYL>2DL(&AE;'`@=FEE=V5R(&%N9`H@("`@("!P<F]B;&5M(')E
M<&]R=&EN9R!S8W)E96XN"EMC:FA=($AA;F1L92!E<G)O<G,@9V5N97)A=&5D
M(&1U<FEN9R!834PM4E!#(&-A;&QS('!R;W!E<FQY"B`@("`@("A"96X@2VQA
M;F<@/&)E;D!A;&MA;&]I9"YN970^+"!"=6<@(S0P.3<I+@I;:F%N72!!9&0@
M861D:71I;VYA;"!I;F1E>&5S('1O('!R969E<F5N8V4@=&%B;&4@*&HN8F5N
M;VET0&9R964N9G(L($)U9R`C-#`W.2DN"EMJ86Y=($9I>"!P<F5F97)E;F-E
M(&-A8VAE("A"=6<@(S0P-SDI+@I;:F%N72!!9&0@8V]N9FEG=7)A=&EO;B!O
M<'1I;VX@=&\@9&ES86)L92!'150M8F%S960@<V5S<VEO;G,N"EMJ86Y=($9I
M>"!P<F5F97)E;F-E<R!A8V-E<W,@9F]R('-P96-I86P@2V]L86(@=7-E<G,@
M*'=R;V)E;$!G96YT;V\N;W)G+`H@("`@("!"=6<@(S0P-#DI+@I;;6US72!&
M:7@@<V5T=&EN9R!D969A=6QT(&-H87)S970@9F]R(&YO;BU-24U%(&UE<W-A
M9V5S("A"=6<@(S,X,#0I+@I;:F%N72!!9&0@<V5V97)A;"!M971H;V1S('1O
M(&UA;FEP=6QA=&4@9W)O=7!S(&%N9"!S:&%R97,@=&\@2&]R9&4G<R!!4$DN
M"EMJ86Y=(%)E='5R;B!S97)I86QI>F5D(%!(4"!V86QU97,@=&AR;W5G:"!T
M:&4@4D535"!I;G1E<F9A8V4@:68@<&%S<VEN9R!A"B`@("`@(')E<W1#;VYT
M96YT5'EP92!P87)A;65T97(@;V8@)V%P<&QI8V%T:6]N+W@M:'1T<&0M<&AP
M)RX*6V-J:%T@3VYL>2!A;&QO=R!U<V5R<R!T;R!A<W-I9VX@4VAA<F4@<&5R
M;6ES<VEO;G,@9F]R(&=R;W5P<R!T:&5Y(&%R90H@("`@("!M96UB97)S(&]F
M+@I;:F%N72!!;&QO=R!T;R!D:7-A8FQE(%9&4R!B86-K96YD<R!I;B!T:&4@
M87!P;&EC871I;VYS)R!C;VYF:6=U<F%T:6]N<RX*6VUM<UT@57!D871E('1H
M92!-24U%($-O;G1E;G0M5'EP92!C:&%R<V5T('!A<F%M971E<B!I;B!A($U)
M344@;65S<V%G92!W:&5N('=E"B`@("`@(&-O;G9E<G0@=&AE(&-O;G1E;G1S
M(&9O<B!V:65W:6YG(&EN('1H92!B<F]W<V5R("A"=6<@(S,W,CDI+@I;8VIH
M72!&:7@@2&]R9&5?1F]R;5]4>7!E7V%S<VEG;B!J879A<V-R:7!T("A"=6<@
M(S,W-#`I+@I;:F%N72!!9&0@=7!G<F%D92!S8W)I<'1S(&9O<B!/<F%C;&4N
M"EMC:FA=($EN8VQU9&4@4$%42%])3D9/('=H96YE=F5R(%%515)97U-44DE.
M1R!I<R!R97%U97-T960@:6X@2&]R9&4Z.G-E;&95<FPH*0H@("`@("`H0G5G
M(",S-S`S*2X*6VIA;ET@061D(&=E;F5R:6,@4U%,('5P9W)A9&4@<V-R:7!T
M("A$86YI96P@02X@4F%M86QE>0H@("`@("`\9&%N:65L+G)A;6%L97E`9')A
M:V4N961U/BDN"@H*+2TM+2TM"G8S+C$N,0HM+2TM+2T*"EMC:FA=(%-%0U52
M2519.B!&:7@@<F5M;W1E(&-O9&4@97AE8W5T:6]N('9U;&YE<F%B:6QI='D@
M9F]U;F0@8GD@2F%N(%-C:&YE:61E<BX*6V-J:%T@1FEX(&5X<&]R="!A;F0@
M<WEN8VAR;VYI>F%T:6]N(&]F(&5V96YT<R!A8W)O<W,@9&%Y;&EG:'0@<V%V
M:6YG('1I;64*("`@("`@8VAA;F=E<RX*6VIA;ET@061D('!R;W!E<B!L;V-K
M:6YG('1O(&UY<W%L('-E<W-I;VX@:&%N9&QE<B`H0G5G(",S-C8P*2X*6V-J
M:%T@:64N8W-S(&ES(&YO="!N96-E<W-A<GD@9F]R($E%-RP@<V\@<F5N86UE
M(&%P<')O<')I871E;'D@*$)U9R`C,S8W,2DN"EMJ86Y=($9I>"!Q=6]T82!S
M=7!P;W)T(&9O<B!S;VUE(%9&4R!D<FEV97)S("A"=6<@(S,V-#<I+@I;8VIH
M72!"971T97(@3W!E<F$@36EN:2!D971E8W1I;VX@*$)U9R`C,CDV,2DN"EMJ
M86Y=($9I>"!M96YU('=R87!P:6YG('=I=&@@2V]L86(@86YD(%!U<G!L92!T
M:&5M92`H0G5G(",S-3DT*2X*"@HM+2TM"G8S+C$*+2TM+0H*6V-J:%T@4F5M
M;W9E(&)O9W5S($-O;G1E;G0M3&]C871I;VX@:&5A9&5R(&EN('1H92!734P@
M36]B:6QE(')E;F1E<F5R"B`@("`@("A"=6<@(S,T-S8I+@I;:F%N72!!9&0@
M;W!T:6]N('1O(&)L;V-K($MO;&%B(&%U=&AE;G1I8V%T:6]N(&%F=&5R(&9A
M:6QE9"!L;V=I;G,*("`@("`@*'1O:V]E0&MD92YO<F<L(%)E<75E<W0@(S,T
M-S0I+@I;:F%N72!!;&QO=R!T;R!S970@:&5I9VAT(&]F(&EF<F%M92!P;W)T
M86P@8FQO8VL@*'1E=F%N<T!T86-H;VUE=')Y+F-O;2P*("`@("`@4F5Q=65S
M="`C,S4P-"DN"EMC:FA=(%5P9&%T92!4;V]L5&EP<R!*879A4V-R:7!T(&]B
M:F5C="!T;R!A;&QO=R!T;V]L=&EP<R!O;B!N;VXM/&$^(&5L96UE;G1S+@I;
M;6US72!3;W)T(&%N($E-05!?5')E92!O8FIE8W0@8GD@9&ES<&QA>2!N86UE
M+"!N;W0@9G5L;"!M86EL8F]X(&YA;64N"EMM87-=($UA:V4@<W5R92!D871A
M8F%S92!P;W)T86)I;&ET>2!O<'1I;VYS(&%R92!A<'!L:65D(&EN($AI<W1O
M<GD@;6]D=6QE+@H@("`@("`H0G5G(",S-#@R*0H*"BTM+2TM+2TM"G8S+C$M
M4D,S"BTM+2TM+2TM"@I;:F%N72!-86ME('-U<F4@=&AA="!+;VQA8B!U<V5R
M<R!A;'=A>7,@:&%V92!T:&4@<V%M92!U<V5R(&YA;64@*$)U9R`C,3,Q-RDN
M"EMJ86Y=($9I>"!M;W9I;F<@;V)J96-T<R!W:71H($MO;&%B(&1R:79E<G,@
M*'1O:V]E0&MD92YO<F<L($)U9R`C,C@Q,2DN"EMJ86Y=($%D9"!R97-E="!B
M=71T;VX@=&\@:6UA9V4@9F]R;2!F:65L9',N"EMJ86Y=($9I>"!S96QE8W1I
M;VX@;V8@9&5F875L="!I9&5N=&ET>2`H0G5G(",S-#$V*2X*6VUA<UT@061D
M($AE8G)E=R!T<F%N<VQA=&EO;BX*6VUA<UT@061D('-U<'!O<G0@9F]R(%)&
M0R`T,S$T+7-T>6QE($E-05`@04-,<RX*6VUM<UT@0V]R<F5C=&QY(&5N8V]D
M92`W+6)I="!-24U%(&UE<W-A9V5S('=I=&@@3E5,3"!C:&%R86-T97)S("A"
M=6<@(S,S.34I+@I;:F%N72!(:61E(&%P<&QI8V%T:6]N<R!W:71H('-T871U
M<R`G;F]T;V]L8F%R)R!F<F]M(&]P=&EO;G,@;65N=2`H0G5G(",S,S@S*2X*
M"@HM+2TM+2TM+0IV,RXQ+5)#,@HM+2TM+2TM+0H*6VIA;ET@061D($MH;65R
M('1R86YS;&%T:6]N("A,96%N9R!#:'5M<V]B96X@/'-O8F5N0&MH;65R;W,N
M:6YF;SXI+@I;;6US72!(86YD;&4@<75O=&5D('1E>'0@=VAE;B!P87)S:6YG
M($U$3B!R97%U97-T<R`H0G5G(",S,S0P*2X*6V)E;ET@0F5T=&5R('-U<'!O
M<G0@9F]R($U3+5-13"X*6VIA;ET@4VAO=R!C;W)R96-T(&%D9')E<W,@:6X@
M;&%S="UL;V=I;B!M97-S86=E(&EF(&-O;FYE8W1I;F<@=&AR;W5G:"!A('!R
M;WAY"B`@("`@("A"=6<@(S,R.#@I+@I;;6US72!!;&QO=R!A9&UI;B!T;R!D
M:7-A8FQE(&)R;W=S97(@<W1R:6YG(&-H96-K<R`H0G5G(",S,C@R*2X*6VIA
M;ET@0V]R<F5C=&QY(&5N8V]D92!E;6%I;"!G<F]U<"!N86UE<R`H0G5G(",S
M,C,T*2X*6V-J:%T@061D(&$@9&ES<&QA>2!M971H;V0@9F]R(&AO=7)-:6YU
M=&5396-O;F0@9F]R;2!F:65L9',@*$)U9R`C,S$V-2DN"EMC:FA=($AO<F1E
M)W,@<')E9F5R96YC97,@;F]W(&%R92!R969E<G)E9"!T;R!A<R!';&]B86P@
M3W!T:6]N<R!S;R!T:&4@=7-E<@H@("`@("!D;V5S;B=T(&YE960@=&\@:VYO
M=R!W:&%T($AO<F1E(&ES+"!A;F0@86QW87ES(&%P<&5A<B!A="!T:&4@=&]P
M(&]F"B`@("`@(&QI<W1S(&]F(&%P<',@9F]R('=H:6-H('!R969E<F5N8V5S
M(&%R92!A=F%I;&%B;&4N"EMJ86Y=($%D9"!U<&=R861E(&EN<W1R=6-T:6]N
M<R`H2V5V:6X@37EE<B!K979I;E]M>65R0&EU,3,N;W)G+"!"=6<@(S,R,C(I
M+@I;8VIH72!!<'!L:6-A=&EO;G,@=VAI8V@@9&\@;F]T(&AA=F4@82!C;VYF
M:6<O<')E9G,N<&AP(&9I;&4@;F\@;&]N9V5R"B`@("`@(&%P<&5A<B!I;B!L
M:7-T<R!O9B!A<'!L:6-A=&EO;G,@=&\@<V5T(&]P=&EO;G,@9F]R('1O(&%V
M;VED(&-O;F9U<VEO;BX*"@HM+2TM+2TM+0IV,RXQ+5)#,0HM+2TM+2TM+0H*
M6V-J:%T@36%K92!T:&4@;&]C:R!D:7)E8W1O<GD@9F]R('1H92!M96UC86-H
M960@4V5S<VEO;DAA;F1L97(@8V]N9FEG=7)A8FQE"B`@("`@("A"=6<@(S,Q
M,C`I+@I;;6US72!5<&1A=&4@5&5X=%]&;&]W960Z.B!T;R!S=7!P;W)T(%)&
M0R`S-C<V+@I;8VIH72!&:7@@;W5T<'5T(&5S8V%P:6YG(&]F($AO<F1E7T9O
M<FU?5'EP95]C96QL<&AO;F4@:6X@54E?5F%R4F5N9&5R97)?:'1M;"X*6V-J
M:%T@06QL;W<@8VAO;W-I;F<@6TYO;F5=(&%S(&$@9&%T86)A<V4@9F]R("1C
M;VYF6R=S<6PG72`H0G5G(",R-S4T*2X*6VIA;ET@061D($EC96QA;F1I8R!T
M<F%N<VQA=&EO;B`H0FIO<FX@1&%V:61S<V]N(#QB:F]S<VE`<VYE<G!A+FES
M/BDN"EMM;7-=(%=O<FL@87)O=6YD(&)R;VME;B!I;6%P7SAB:70H*2!I;7!L
M96UE;G1A=&EO;B!I;@H@("`@("!-24U%.CIQ=6]T9610<FEN=&%B;&5%;F-O
M9&4@*$)U9R`C,CDW-2DN"EMM;7-=($%D9"!G87)B86=E(&-O;&QE8W1I;VX@
M=&\@2&]R9&5?0V%C:&4N"EMC:FA=($9I>"!'<F]U<#HZ;&ES=$%L;%5S97)S
M("A#87)L;W,@4&5D<FEN86-I+"!"=6<@(S(Y,S<I+@I;:F%N72!!9&0@:&EG
M:"!C;VYT<F%S="!T:&5M92`H=&UE<G)I='1`96UA:6PN87)I>F]N82YE9'4L
M(%)E<75E<W0@(S$U.3@I+@I;:F%N72!+965P<R!S:61E8F%R(&5X<&%N<VEO
M;B!S=&%T92!A8W)O<W,@<V5S<VEO;G,@*%)E<75E<W0@(S$U-C0I+@I;:F%N
M72!!9&0@8V]N9FEG=7)A=&EO;B!F;W(@;6%I;"!D;VUA:6X@=7-E9"!F;W(@
M<')O8FQE;2!R97!O<G1S"B`@("`@("AD=7-T:6Y`>7=L8W,N;W)G+"!297%U
M97-T(",Q,S<V*2X*6V-J:%T@061D(&1Y;F%M:6,@=&%B;&4@<F4M<V]R=&EN
M9R!T:')O=6=H(&IA=F%S8W)I<'0N"EMC:FA=($EN<W!E8W0@;65T:&]D('-I
M9VYA='5R97,@<V\@=&AA="!T:&4@4D535"!D<FEV97(@:7-N)W0@9&5P96YD
M96YT(&]N"B`@("`@('1H92!O<F1E<B!O9B!'150@<&%R86UE=&5R<RX*6V-J
M:%T@061D(&AO<F1E+V=E=%!R969E<F5N8V4@86YD(&AO<F1E+W-E=%!R969E
M<F5N8V4@05!)(&UE=&AO9',N"EMC:FA=($%D9"!A(&QI<W0@;V8@86-T:79E
M('5S97)S(&%N9"!A8W1I=F4@<V5S<VEO;G,@=&\@=&AE(&%D;6EN(&%R96$N
M"EMC:FA=($%D9"!U;F]B=')U<VEV92!J879A<V-R:7!T('1O;VQT:7!S(&)A
M<V5D(&]N('1H92!T:71L92!A='1R:6)U=&4N"EMJ86Y=($UO=F4@<VED96)A
M<B!C;VQL87!S92]E>'!A;F0@8G5T=&]N(&)E;&]W('1H92!M96YU(&)A<B`H
M3VQI=F5R($MU:&P*("`@("`@/&]K=6AL0&YE=&-O;&]G;F4N9&4^*2X*6VIA
M;ET@061D($ED96%S('1H96UE("A2;V5L($=L;W5D96UA;G,@/')O96Q`9VQO
M=61E;6%N<RYI;F9O/BDN"EMC:FA=($UO=F4@2&]R9&5?2&ES=&]R>2!D871A
M('1O(&ET<R!O=VX@4U%,('1A8FQE("A"=6<@(S(R.3@I+@I;:F%N72!!9&0@
M2&]R9&5?1F]R;5]T>7!E7V9I9VQE="!F;W(@0T%05$-(02!F:65L9',@=VET
M:"!F:6=L970@9F]N=',N"EMJ86Y=($%D9"!(;W)D95]&;W)M7U1Y<&5?9&)L
M;V]K=7`@9F]R(&9O<FT@9FEE;&1S('=I=&@@9&%T86)A<V4@;&]O:W5P<PH@
M("`@("`H4F5Q=65S="`C,S(R*2X*6VIA;ET@061D(&-O;F9I9W5R871I;VX@
M=&\@9&ES86)L92`B06)O=70B(&QI;FMS(&EN(&AE;'`@=VEN9&]W<R`H(DUA
M='1H97<*("`@("`@32X@1V%M8FQE(B`\:&]R9&4M9&5V0&UG86UB;&4N8V$^
M*2X*6V-J:%T@06QL;W<@<V5N9&EN9R!P<F]B;&5M(')E<&]R=',@=&\@82!T
M:6-K970@<WES=&5M('5S:6YG('1H90H@("`@("!T:6-K971S+V%D9%1I8VME
M="!!4$D@8V%L;"`H0G5G(",Q.3$W*2X*6V-J:%T@1&5F:6YE(%)43"!S='EL
M97,@=FEA(&%N(&%D9&ET:6]N86P@<W1Y;&5S:&5E="X*6V-J:%T@57-A8FEL
M:71Y(&EM<')O=F5M96YT<R!T;R!T:&4@:61E;G1I=&EE<R!M86YA9V5M96YT
M('!A9V4@*$)U9R`C,3@T-BDN"EMB96Y=($%D9"!,1$%0('-U<'!O<G0@=&\@
M1W)O=7`@<&%C:V%G92X*6V-J:%T@061D(%--0B!D<FEV97(@=&\@5D93('!A
M8VMA9V4N"EMC:FA=($%L;&]W(&-R96%T:6]N(&]F(&5X<&ER:6YG(&%C8V]U
M;G1S(&EN($Q$05`*("`@("`@*%)O96P@1VQO=61E;6%N<R`\<F]E;$!G;&]U
M9&5M86YS+FEN9F\^*2X*6V-J:%T@061D(&-O;F9I9W5R871I;VX@;W!T:6]N
M('1O('-E87)C:"!F;W(@=&AE('5S97(G<R!$3B!I;B!T:&4@4')E9G-?;&1A
M<`H@("`@("!D<FEV97(@*$)U9R`C,3<X-BDN"EMJ86Y=($%L;&]W('1O('-P
M96-I9GD@=&AE(&]B:F5C=&-L87-S(&9O<B!N97<@=7-E<G,@861D960@=&AR
M;W5G:"!,1$%0"B`@("`@("A2;V5L($=L;W5D96UA;G,@/')O96Q`9VQO=61E
M;6%N<RYI;F9O/BDN"EMJ86Y=($%D9"!P87-S=V]R9"!E>'!I<F%T:6]N(&%N
M9"!P87-S=V]R9"!E;F-R>7!T:6]N('1O($Q$05`@875T:&5N=&EC871I;VX*
M("`@("`@9')I=F5R("A2;V5L($=L;W5D96UA;G,@/')O96Q`9VQO=61E;6%N
M<RYI;F9O/BDN"EMJ86Y=($%D9"!P97)M:7-S:6]N<R!T;R!R97-T<FEC="!N
M=6UB97(@;V8@<&]R=&%L(&)L;V-K<RX*6VIA;ET@061D(&-O;F9I9W5R871I
M;VX@9F]R(&9I>&5D('!O<G1A;"!B;&]C:W,N"EMJ;69=($%D9"!A=61I;R!N
M;W1I9FEC871I;VX@;&ES=&5N97(L(&UA:V4@<&]R=&%L(&AA;F1L92!A=61I
M;R!N;W1I9FEC871I;VYS"B`@("`@(&)Y(&)L;V-K<R`H92YG+B!T:&4@24U0
M(&9O;&1E<B!S=6UM87)Y*2X*6VUM<UT@0V%C:&4@8V5R=&%I;B!R96=I<W1R
M>2!D871A('1O('!R979E;G0@=6YN965D960@9FEL92!L;V%D:6YG+W!A<G-I
M;F<*("`@("`@869T97(@=&AE(&EN:71I86P@;&]G:6XN"EMM87-=($%D9"!S
M=7!P;W)T(&9O<B!C;W5N=&EN9R!A=71H96YT:6-A=&5D('-E<W-I;VYS('9I
M82!397-S:6]N2&%N9&QE<G,N"EMC:FA=(%)E+7=O<FL@5&%B<R!S;R!T:&%T
M(&)A8VMG<F]U;F0@:6UA9V5S(&-A;B!B92!U<V5D(&EN(&-R96%T:79E('=A
M>7,N"EMJ86Y=($%D9"`B37D@06-C;W5N="!);F9O<FUA=&EO;B(@8FQO8VL@
M=&AA="!M:6UI8W,@=&AE($%C8V]U;G1S(&UO9'5L92X*6VIA;ET@26UP<F]V
M92!R96YD97)I;F<@9F]R(')I9VAT+71O+6QE9G0@;&%N9W5A9V5S("A!;6ER
M:V%B:7(@365T84Y%5"!,=&0N*2X*6VIA;ET@061D('-U<'!O<G0@9F]R(&%R
M8FET<F%R>2P@;F]N+6)O;VQE86X@<&5R;6ES<VEO;B!V86QU97,N"EMB96Y=
M($%D9"!A;'1E<FYA=&5?;&]G:6X@86YD(')E9&ER96-T7V]N7VQO9V]U="!F
M96%T=7)E<RX*6VIA;ET@061D(&=E;F5R:6,@4TU44"!D<FEV97(@=&\@3F5T
M7U--4R!P86-K86=E("A)86X@175R92`\:65U<F5`<&AP+FYE=#XI+@I;;6IR
M72!.971?24U34"!W:6QL(&YO=R!A=71O;6%T:6-A;&QY(&-R96%T92!U<V5R
M)W,@9&5F875L="!A9&1R97-S8F]O:R!I9@H@("`@("!I="!D;V5S(&YO="!A
M;')E861Y(&5X:7-T(&EN<W1E860@;V8@:G5S="!C;VUP;&%I;FEN9R!A8F]U
M="!I="X*6V-J:%T@061D('-E;&5C="!A;&PL(&YO;F4L(&%N9"!I;G9E<G0@
M;W!T:6]N86QL>2!T;R!(;W)D95]&;W)M7U1Y<&5?<V5T"B`@("`@(&9I96QD
M<R`H1'5C:R`\9'5C:T!O8F%L82YN970^*2X*6V-J:%T@4')E9F5R96YC97,@
M;W9E<G9I97<@:7,@;F]W(&)U:6QT('=I=&@@82!D969I;FET:6]N(&QI<W0@
M*#QD;#XI('-T>6QE9`H@("`@("!W:71H($-34RX*6VIA;ET@061D('-O<G0H
M*2!M971H;V0@=&\@2&]R9&5?5')E92!C;&%S<RX*6VUD:ET@0VAA;F=E(&%N
M>2!O=71P=70@;V8@/&(^(&%N9"`\:3X@=&%G<R!T;R`\<W1R;VYG/B!A;F0@
M/&5M/B!F;W(@8F5T=&5R"B`@("`@(&%C8V5S<VEB:6QI='D@<W5P<&]R="X*
M6VIM9ET@06QL;W<@2&]R9&4@=&5M<&QA=&5S('1O(&EN8VQU9&4@87!P;&EC
M871I;VX@8FQO8VMS+@I;:F%N72!!9&0@97AT96YD960@9F]R96-A<W1S('1O
M('=E871H97)D;W1C;VT@0FQO8VL@*%)I8VL@16UE<GD*("`@("`@/')I8VM`
M96UE<GDN:&]M96QI;G5X+FYE=#XI+@I;8VIH72!!;&QO=R!F;W(@87)B:71R
M87)Y(&%T=')I8G5T92!F:6QT97)S('=H96X@;&ES=&EN9R!O<B!C;W5N=&EN
M9R!3:&%R90H@("`@("!O8FIE8W1S("A$=6-K(#QD=6-K0&]B86QA+FYE=#XI
M+@I;8VIH72!!9&0@1&%T851R964Z.F=E=%-O<G1E9%1R964H*2`H1'5C:R`\
M9'5C:T!O8F%L82YN970^*2X*6VUJ<ET@4W5P<&]R="!F;W(@:6UT97-T(&%U
M=&AE;G1I8V%T:6]N(&%D9&5D('1O(%!R969S7VEM<W`N"EMC:FA=($%D9"!2
M15-4(%)00R!D<FEV97(@*'-R<F%F84!U<V,N97,L($)U9R`C,34P,"DN"EMC
M:FA=($%D9"!S=7!P;W)T(&9O<B!F971C:&EN9R!T:&4@:&EG:&5S="!A;F0@
M;&]W97-T(&ED<R!I;B!A;GD@1&%T851R964*("`@("`@9W)O=7`@*$1U8VL@
M/&1U8VM`;V)A;&$N;F5T/BDN"EMC:FA=($%D9"!$871A5')E93HZ<V]R=$)Y
M071T<FEB=71E<R@I(&9O<B!S;W)T:6YG($1A=&%4<F5E3V)J96-T<R!B87-E
M9"!O;@H@("`@("!T:&5I<B!A='1R:6)U=&5S("A$=6-K(#QD=6-K0&]B86QA
M+FYE=#XI+@I;;6IR72!);FET:6%L('-U<'!O<G0@861D960@=&\@3F5T7TE-
M4U`@9F]R(&EM=&5S="!D<FEV97(@*'!R;W9I9&5S('!E<G-I<W1E;G0*("`@
M("`@24U34"!C;VYN96-T:6]N<R!U<VEN9R!#>7)U<R!I;71E<W0@=71I;&ET
M>2DN"EMJ86Y=($%D9"!M87`@;&EN:W,@=&\@54L@86YD($%U<W1R86QI86X@
M861D<F5S<R!F:65L9',*("`@("`@*'1U<F)A+FQI<W1`<W5B;W)B:70N8V]M
M+"!"=6<@(S$T-C$I+@I;;6US72!$971E8W1I;VX@;V8@(G!H:7-H:6YG(B!T
M86-T:6-S(&EN('1H92!(5$U,($U)345?5FEE=V5R("A4;V1D($UE<G)I='0*
M("`@("`@/'1M97)R:71T0&5M86EL+F%R:7IO;F$N961U/BP@0G5G(",Q-#,T
M*2X*6VUM<UT@5&5X=%]&;&]W960@<&%C:V%G92!N;W<@8V]R<F5C=&QY(&AA
M;F1L97,@;75L=&EB>71E(&-H87)A8W1E<G,N"EMM;7-=($UA:6YT96YA;F-E
M(&-O;F9I<FUA=&EO;B!P86=E<R!N;W<@<F5N9&5R960@=FEA($AO<F1E7U1E
M;7!L871E("A6:6QI=7,*("`@("`@4W5M<VMA<R`\=FEL:75S0&QN:RYL=#XI
M+@I;:F%N72!!;&QO=R!T;R!S<&5C:69Y(&-H87)S970@;V8@:6UP;W)T960@
M0U-6(&9I;&5S+@I;:F%N72!!9&0@1FEL95]#4U8@<&%C:V%G92X*6VIA;ET@
M4VAO=R!A<'!L:6-A=&EO;B!N86UE<R!I;B!P97)M:7-S:6]N<R!A9&UI;FES
M=')A=&EO;BX*6VIM9ET@06QL;W<@=&AE(&%U=&@@8F%C:V5N9"!T;R!R97%U
M97-T(&$@<&%S<W=O<F0@8VAA;F=E+"!S=7!P;W)T(&5X<&ER:6YG"B`@("`@
M('!A<W-W;W)D(&EN('1H92!344P@8F%C:V5N9"X*6V-J:%T@4VAO=R!M96YU
M(&-H:6QD<F5N(&9O<B!E=F5R>2!A<'!L:6-A=&EO;B!W:71H('!R969E<F5N
M8V5S('5N9&5R($]P=&EO;G,*("`@("`@:6X@=&AE('-I9&5B87(@;65N=2`H
M0G5G(",Q,#4X*2X*6VUM<UT@06QL;W<@:6YD:79I9'5A;"!-24U%7U9I97=E
M<G,@=&\@;W9E<G)I9&4@=&AE($-O;G1E;G0M1&ES<&]S:71I;VX@34E-10H@
M("`@("!P87)A;65T97(@86YD(&9O<F-E('9I97=I;F<@:6YL:6YE+@H*"BTM
M+2TM+2T*=C,N,"XQ,0HM+2TM+2TM"@I;8VIH72!314-54DE463H@4F5M;W9E
M('5N=7-E9"!I;6%G92!P<F]X>2!C;V1E(&9R;VT@9&5R969E<G)E<BX*6V-J
M:%T@4T5#55))5%DZ($-L;W-E(%A34R!P<F]B;&5M<R!I;B!D97)E9F5R<F5R
M("A)12!O;FQY*2P@:&5L<"!V:65W97(@86YD"B`@("`@('!R;V)L96T@<F5P
M;W)T:6YG('-C<F5E;BX*"@HM+2TM+2TM"G8S+C`N,3`*+2TM+2TM+0H*6V-J
M:%T@4T5#55))5%DZ($9I>"!R96UO=&4@8V]D92!E>&5C=71I;VX@=G5L;F5R
M86)I;&ET>2!F;W5N9"!B>2!*86X@4V-H;F5I9&5R+@H*"BTM+2TM+0IV,RXP
M+CD*+2TM+2TM"@I;8VIH72!&:7@@<VAO=W-T;W!P97(@8G5G(&EN($AO<F1E
M7T9O<FT@<V5L96-T(&9I96QD<R`H0G5G(",S,3(S*2X*"@HM+2TM+2T*=C,N
M,"XX"BTM+2TM+0H*6V-J:%T@5VAE;B!D96QE=&EN9R!A;B!I9&5N=&ET>2P@
M9&]N)W0@<VAO=R!T:&4@9&5L971E9"!I9&5N=&ET>0H@("`@("!I;B!T:&4@
M9&5F875L="!I9&5N=&ET>2!S96QE8W0@9')O<&1O=VX@;VX@=&AE(&YE>'0@
M<&%G92!L;V%D+@I;8VIH72!&:7@@97-C87!I;F<@;V8@9&%T82!I;B!T:&4@
M<')E9F5R96YC97,@=&5M<&QA=&5S+@I;8VIH72!&:7@@97-C87!I;F<@;V8@
M9&%T82!I;B!T:&4@9&%T82!I;7!O<G0@=&5M<&QA=&5S+@I;8VIH72!&:7@@
M;W5T<'5T(&5S8V%P:6YG(&]F($AO<F1E7T9O<FU?5'EP95]C96QL<&AO;F4@
M:6X@54E?5F%R4F5N9&5R97)?:'1M;"X*6V-J:%T@4T5#55))5%DZ($-L;W-E
M('-E=F5R86P@6%-3('!R;V)L96US(&EN('1H92!S:&%R92!E9&ET('=I;F1O
M=RX*6VIA;ET@1FEX('=E871H97(N8V]M('!O<G1A;"!B;&]C:RX*"@HM+2TM
M+2T*=C,N,"XW"BTM+2TM+0H*6VIA;ET@4T5#55))5%DZ($9I>"!84U,@=G5L
M;F5R86)I;&ET:65S(&EN(&=Z:7`O=&%R(&%N9"!C<W,@34E-12!V:65W97)S
M+@I;8VIH72!!9&0@;6ES<VEN9R!#3TU-250@:6X@37E344P@4V5S<VEO;DAA
M;F1L97(@9')I=F5R"B`@("`@("AD9V5H;$!I;G9E<G-E+F-A+"!"=6<@(S(W
M,S$I+@H*"BTM+2TM+0IV,RXP+C8*+2TM+2TM"@I;:F%N72!087-S(&%L;"!5
M4DP@<&%R86UE=&5R<R!W:&5R92!L:6YK:6YG(&5M86EL(&%D9')E<W-E<R`H
M4F5Q=65S="`C,34S,"DN"EMJ86Y=(%-H;W<@5V]R9"!V:65W97(@8V]N=&5N
M="!W:71H(&-O<G)E8W0@8VAA<G-E="`H<V=R;VYD:6Y`8W-B9BYQ8RYC82P*
M("`@("`@0G5G(",R-S,W*2X*"@HM+2TM+2TM+2TM"G8S+C`N-BU20S$*+2TM
M+2TM+2TM+0H*6V-J:%T@1FEX('1R86YS86-T:6]N<R!A;F0@8FEN87)Y(&1A
M=&$@:6X@4&]S=&=R95-13"!S97-S:6]N(&AA;F1L97(*("`@("`@*&-B<T!C
M=',N=6-L82YE9'4L($)U9R`C,C<T.2P@(S(W.#DI+@I;:F%N72!&:7@@<VED
M96)A<B!M96YU(&QA>6]U="!F;W(@3W!E<F$@*$)U9R`C,C<R,BDN"EMC:FA=
M($%D9"`\<')E/B!T;R!S=7!P;W)T960@:&5L<"!T86=S("AV:6IA>2YM86AR
M<F%`97,N96%S>6YE="YN970L"B`@("`@($)U9R`C,C8S,RDN"EMC:FA=($9I
M>"!V86QI9&%T:6]N(&]N(&EP861D<F5S<R!(;W)D95]&;W)M(&9I96QD<R`H
M0G5G(",R-3@S*2X*6V-J:%T@061D($%U=&@Z.F=E=$%U=&A$;VUA:6XH*2`H
M0G5G(",R-3<S*2X*6VUJ<ET@061D(&%B:6QI='D@=&\@96YA8FQE+V1I<V%B
M;&4@24U34"!G;&]B86QL>2!V:6$@8V]N9FEG=7)A=&EO;B!S971T:6YG<RX*
M6VIA;ET@1FEX(&-A;&5N9&%R('!O<'5P('=I=&@@4V%F87)I(&)R;W=S97)S
M("AT+GIE;&Q`9VUX+F1E+"!"=6<@(S(T-#@I+@I;8VIH72!7:&5N('5S:6YG
M($-'22!02%`L(%-#4DE05%].04U%(&UA>2!C;VYT86EN('1H92!P871H('1O
M('1H92!02%`@8FEN87)Y"B`@("`@(&EN<W1E860@;V8@=&AE('-C<FEP="!B
M96EN9R!R=6X[('5S92!02%!?4T5,1B!I;G-T96%D("A"=6<@(S(T,#$I+@I;
M:F%N72!&:7@@<VAA<FEN9R!W:71H(&=R;W5P<R!I9B!U<VEN9R!G<F]U<"!H
M;V]K<R`H0G5G(",R,CDR*2X*"@HM+2TM+2T*=C,N,"XU"BTM+2TM+0H*6VUM
M<UT@1FEX(%9&4R=S(&%U=&]C<F5A=&50871H*"D@9F]R(&1I<F5C=&]R>2!P
M871H<R!C;VYT86EN:6YG('1H92!R;V]T"B`@("`@(&1I<F5C=&]R>2X*6VIA
M;ET@1FEX(&-Y<G-Q;"!A=71H96YT:6-A=&EO;B!D<FEV97(@=VET:"!U;FEX
M:&EE<F%R8VAY<V5P(&5N86)L960*("`@("`@*'-G<F]N9&EN0&-S8F8N<6,N
M8V$L($)U9R`C,C,V-RDN"EMM;7-=($9I>"!N97-T960@24U!4"!!3D0@<V5A
M<F-H97,N"EMM;7-=($EN('-Q;"!61E,@9')I=F5R+"!A;&QO=R!T:&4@=7-E
M(&]F("<O)R!A="!T:&4@8F5G:6YN:6YG(&]F(&$@<&%T:"!T;PH@("`@("!I
M;F1I8V%T92!T:&4@8F%S92!D:7)E8W1O<GDN"EMJ86Y=($9I>"!R971U<FYI
M;F<@=&\@;&%S="!P86=E(&%F=&5R('-E;F1I;F<@<')O8FQE;2!R97!O<G0@
M*$)U9R`C,C,U,"DN"EMM;7-=($9I>"!A(&)U9R!T:&%T(&-A=7-E9"!H;V]K
M(&-O9&4@=&\@8F4@<G5N('5N;F5C97-S87)I;'D@869T97(@82!U<V5R"B`@
M("`@(&ES(&%L<F5A9'D@;&]G9V5D(&EN+@H*"BTM+2TM+2TM+2T*=C,N,"XU
M+5)#,@HM+2TM+2TM+2TM"@I;8VIH72!&:7@@82!F87(M<F5A8VAI;F<@1&%T
M851R964@8G5G(&EN(&QO861I;F<@<&%R96YT(&ED<R`H0G5G(",R,C`S*2X*
M"@HM+2TM+2TM+2TM"G8S+C`N-2U20S$*+2TM+2TM+2TM+0H*6VIA;ET@061D
M($)O<VYI86X@=')A;G-L871I;VX@*%9E9')A;B!,:G5B;W9I8R`\=FQJ=6)O
M=FEC0'-M87)T;F5T+F)A/BDN"EMC:FA=($QE="!(;W)D95]4<F5E(&AA;F1L
M92!A;&P@:6YD96YT(&-A;&-U;&%T:6]N(&)A<V5D(&]N('!A<F5N="]C:&EL
M9`H@("`@("!R96QA=&EO;G-H:7!S("A"=6<@(S(Q.3@I+@I;8VIH72!!9&0@
M:6YI=&EA;"!,1$%0(%-E<W-I;VY(86YD;&5R(&1R:79E<BX*6V-J:%T@57-E
M(')O=RUL979E;"!L;V-K:6YG(&]R('1R86YS86-T:6]N<R!W:&5R92!P;W-S
M:6)L92!T;R!A=F]I9`H@("`@("!S97-S:6]N(&-O<G)U<'1I;VX@:6X@4V5S
M<VEO;DAA;F1L97(@*$)U9R`C,34X,"DN"EMM;7-=($%D9"!T:&4@;65M8V%C
M:&5D(%-E<W-I;VY(86YD;&5R.CH@9')I=F5R("A2;VYG+45N($9A;B`\<F%F
M86Y`8W-I92YO<F<^*2X*6VUM<UT@1FEX('9E<FEF:6-A=&EO;B!O9B!-24U%
M('-T<FEN9W,@=VET:"!E<V-A<&5D('%U;W1E<R`H0G5G(",R,38X*2X*6VIA
M;ET@1FEX(&=E;F5R871I;VX@;V8@9G)E92!P97)I;V1S(&EN(&9R964O8G5S
M>2!C;V1E('=I=&@@;W9E<FQA<'!I;F<@979E;G1S+@I;:F%N72!$;VXG="!S
M:&]W($]P=&EO;G,@8G5T=&]N(&EN('!R;V)L96T@<F5P;W)T:6YG('!A9V4N
M"EMJ86Y=($%D9"!5=&EL.CIR96%L4&%T:"@I(&UE=&AO9"X*6VUA<UT@26YC
M;'5D92!V97)S:6]N(&YU;6)E<G,@9F]R(&%P<&QI8V%T:6]N<R!O;B!!9&UI
M;B!3971U<"!S8W)E96XN("A"=6<*("`@("`@(S$T,C`I"EMM87-=($-H86YG
M92!)34%0($%U=&@@9')I=F5R('1O('5S92!I;6%P+VYO=&QS(&)Y(&1E9F%U
M;'0@:6X@;F]N+4133B!M;V1E('1O"B`@("`@(&UA=&-H($133B!M;V1E+@I;
M;6%S72!!9&0@=&QS(&%N9"!S96QF+7-I9VYE9"!C97)T:69I8V%T92!C;VYF
M:6=U<F%T:6]N(&]P=&EO;G,@=&\@24U!4"!!=71H"B`@("`@(&1R:79E<BX@
M*$)U9R`C,3,U-RD*6V-J:%T@4F5C;V=N:7IE($]P97)A(#@K(&%S('!R;W9I
M9&EN9R!A9'9A;F-E9"!F96%T=7)E<R`H0G5G(",R,#8V*2X*6V-J:%T@1FEX
M(')E861I;F<@;V8@8FEN87)Y(&9I;&5S(&]N(%=I;F1O=W,@:6X@5D-?<W9N
M("A"=6<@(S(P,S8I+@I;;6%S72!&:7@@4U%,("=,24M%)R!C87-E+6EN<V5N
M<VET:79E(&-O;7!A<FES;VXN("A"=6<@(S(P,S`I"EMJ86Y=($%L;&]W(&-H
M87)S970@87=A<F4@24U!4"!S96%R8VAE<RX*6VIA;ET@1FEX($=O;V=L92!S
M96%R8V@@8FQO8VL@9F]R(&YO;BUA<V-I:2!C:&%R86-T97)S("A"=6<@(S$S
M,CDI+@I;:F%N72!!9&0@<75I8VLM:6YS=&%L;"!I;G-T<G5C=&EO;G,N"EMJ
M86Y=($EM<')O=F4@<&5R9F]R;6%N8V4@;V8@<V5V97)A;"!F<F%M97=O<FL@
M<&%C:V%G97,N"EMM;7-=($9I>"!-24U%7T-O;G1E;G1S.CH@8V%C:&EN9R!I
M;B!02%`@-2`H0G5G(",Q-#$P*2X*6VIA;ET@1FEX(%9#(%-63B!B86-K96YD
M('1O('-U<'!O<G0@=7-E<B!N86UE<R!W:71H('-P86-E<PH@("`@("`H<VAI
M;6UA;FYI;F=`9VUA:6PN8V]M+"!"=6<@(S$Y,3DI+@I;8VIH72!%<V-A<&4@
M2%1-3"!I;B!I9&5N=&ET>2!N86UE<R`H0G5G(",Q.3$P*2X*6VUA<UT@57-E
M('5P9&%T960@4&]S=&=R95-13"!F=6YC=&EO;B!N86UE<RX*6V)E;ET@57!D
M871E(&%P<&QI8V%T:6]N(&QI<W0@:6X@:&]R9&4G<R!,1$%0('-C:&5M80I;
M8VIH72!%;F9O<F-E(&UA>&QE;F=T:"!R97-T<FEC=&EO;G,@:6X@2&]R9&5?
M1F]R;2!V86QI9&%T:6]N("A"=6<@(S$X.34I+@I;:F%N72!$:7-A8FQE('=E
M871H97(N8V]M($)L;V-K(&EF(&YO="!C;VYF:6=U<F5D+@I;8VIH72!);F-L
M=61E('-O=7)C97)O;W0@:6X@5D,@8V%C:&4@:V5Y<R`H0G5G(",Q-S@S*2X*
M6VIA;ET@061D(%-13"!S8W)I<'0@86YD(&EN<W1R=6-T:6]N<R!F;W(@35-$
M12!D871A8F%S97,@*$)U9W,@(S$X-C(L(",Q.#<P+`H@("`@("!J969F0&EM
M86=E+7-R8RYC;VTI+@I;:F%N72!!;&QO=R!P;W)T86P@8FQO8VMS('1O(&)E
M(&QA<F=E<B!T:&%N('1W;R!C;VQU;6XO<F]W<R`H0G5G<R`C,3$X.2P@,38S
M,BDN"EMJ86Y=($%D9"!33510(&%U=&AE;G1I8V%T:6]N('1O('!R;V)L96T@
M<F5P;W)T:6YG("A"=6<@(S$Q,C@I+@I;:F%N72!3=7!P;W)T(&AE;'`@9FEL
M97,@:6X@861M:6X@9&ER96-T;W)Y('=I=&@@=')A;G-L871I;VYS+G!H<"`H
M0G5G(",Q,S0T*2X*6VIA;ET@1FEX960@4U%,(&)I;F1I;F<@9F]R($]$0D,@
M86YD($U34U%,(&1R:79E<G,@*$)U9R`C,3@Q-BDN"EMJ86Y=($%D9"!C;VYF
M:6=U<F%T:6]N(&]P=&EO;B!T;R!S970@;&]C871I;VX@;V8@34E-12!M86=I
M8R!D871A8F%S92X*6VUM<UT@36%K92!S=7)E(&AE861E<G,@:6X@82!-24U%
M7U!A<G0@87)E(&5N8V]D960@=VET:"!T:&4@<V%M92!C:&%R86-T97(*("`@
M("`@<V5T('5S960@:6X@=&AA="!-24U%7U!A<G0@*$)U9R`C,34Y,2DN"EMM
M;7-=($%D9"!,:7-T+4AE861E<G,@;&ES=&5D(&EN(%)&0R`R,S8Y('1O('1H
M92!L:7-T(&]F($U)344@2&5A9&5R<R!T:&%T"B`@("`@(&-A;B!O;FQY(&%P
M<&5A<B!O;F-E(&EN(&$@<VEN9VQE(&AE861E<B`H0G5G(",Q-S8V*2X*6V-J
M:%T@1FEX('1Y<&\@:6X@<&%R<VEN9R!O9B!&4D5%0E5362!D871A("A"=6<@
M(S$U.3`I+@I;:F%N72!3=7!P;W)T(%-13&ET92!A;F0@3W)A8VQE(&EN(&%L
M;"!344P@8F%C:V5N9"!C;VYF:6=U<F%T:6]N<RX*6V-J:%T@57-E(&)I;F0@
M=F%R:6%B;&5S(&EN('1H92!!=71H+"!61E,L(&%N9"!397-S:6]N2&%N9&QE
M<B!344P@9')I=F5R<RP*("`@("`@86YD(&EN('-C<FEP=',O<F5M;W9E7W!R
M969S+G!H<"`H<V5L<VMY0&-O;'5M8FEA+F5D=2P@0G5G<R`C,38V-2P*("`@
M("`@(S$V-C8L(",Q-C8W+"`C,38V."P@(S$V-S<I+@I;8VIH72!S97-S:6]N
M7W-E=%]C;V]K:65?<&%R86US*"D@97AP96-T<R!A(')E;&%T:79E('1I;65O
M=70[('-E=&-O;VMI92!W86YT<PH@("`@("!A8G-O;'5T92X@1V\@8F%C:R!T
M;R!A(&-O;F9I9VEN=&5G97(@9F]R("1C;VYF6R=S97-S:6]N)UU;)W1I;65O
M=70G72!A;F0*("`@("`@861D('1I;64H*2!T;R!T:&%T('9A;'5E(&EN('-E
M=&-O;VMI92@I(&-A;&QS("A"=6=S(",Q,S`R+"`C,38U."DN"B`@("`@(%1(
M25,@34%9($)214%+($-/3D9)1U52051)3TY3(%-%5"!43R!54T4@4$A0($-/
M1$4N($U!2T4@4U5212!43R!54$1!5$4*("`@("`@64]54B`D8V]N9ELG<V5S
M<VEO;B==6R=T:6UE;W5T)UT@4T545$E.1R!!1E1%4B!54$=2041)3D<N"EMC
M:FA=(%5S92!B:6YD('9A<FEA8FQE<R!I;B!T:&4@4')E9G,@86YD(%1O:V5N
M(%-13"!D<FEV97)S"B`@("`@("AS96QS:WE`8V]L=6UB:6$N961U+"!"=6=S
M(",Q-C4R+"`C,38U,RDN"EMM;7-=(%!R=6YE(&5X<&%N9&5D(&9O;&1E<G,@
M=&AA="!N;R!L;VYG97(@97AI<W0@:6X@24U!4%]4<F5E("A"=6<@(S$U,3<I
M+@I;8VIH72!$;VXG="!T<GD@=&\@8V]M<')E<W,@;W5T<'5T(&EF(%I04R!C
M;VUP<F5S<VEO;B!I<R!O;B`H0G5G(",Q-C(V*2X*6V-J:%T@268@86X@87!P
M(&]N;'D@:&%S(&]N92!P<F5F1W)O=7`L(&%L=V%Y<R!S:&]W('1H870@<')E
M9D=R;W5P(&EN<W1E860*("`@("`@;V8@<VAO=VEN9R!A;B!O=F5R=FEE=R!S
M8W)E96X@=VET:"!O;FQY(&]N92!E;G1R>2X*"@HM+2TM+2T*=C,N,"XT"BTM
M+2TM+0H*6V-J:%T@57-E(&9U;&QY('%U86QI9FEE9"!54DQS(&EN('1H92!!
M;G-E;$EM86=E($A434Q!<F5A('!L=6=I;B`H0G5G(",Q,C4Y*2X*6V-J:%T@
M4T5#55))5%DZ($-L;W-E(%A34R!W:&5N('-E='1I;F<@=&AE('!A<F5N="!F
M<F%M92=S('!A9V4@=&ET;&4@8GD*("`@("`@:F%V87-C<FEP="X*6V)L8UT@
M061D(%!O<W1G<F5344P@=7!G<F%D92!S8W)I<'0@*$)R860@5VET=&4@/&)R
M861`9&ES=&%N=&AA>F4N8V]M*0I;8VIH72!!=F]I9"!D:79I<VEO;B!B>2!Z
M97)O(&EF(&%L;"!P<F5F97)E;F-E<R!A<F4@;&]C:V5D("A"=6<@(S$V,C<I
M+@I;:F%N72!&:7@@<VED96)A<B!R969R97-H:6YG('=I=&@@3W!E<F$N"@H*
M+2TM+2TM+2TM+0IV,RXP+C0M4D,R"BTM+2TM+2TM+2T*"EMJ86Y=($EM<')O
M=F4@(FQO9VEN(B!A=71H96YT:6-A=&EO;B!D<FEV97(@*$)U9R`C,34W,2DN
M"EMJ86Y=(%-H;W<@9&%T86)A<V4@<W!E8VEF:6,@8V]N;F5C=&EO;B!P87)A
M;65T97)S(&EN(&=L;V)A;"!344P@8V]N9FEG=7)A=&EO;@H@("`@("!T;V\N
M"EMJ86Y=($9I>"!L969T(&UE;G4@;W9E<F9L;W<@:6X@244@86YD(%-A9F%R
M:2`H0G5G(",Q-3(V*2X*6VIA;ET@1FEX(&%U=&]C<F5A=&EN9R!O9B!D:7)E
M8W1O<FEE<R!A;F0@=7!D871I;F<@;V8@97AI<W1I;F<@9FEL97,@:6X@=&AE
M"B`@("`@('-Q;%]F:6QE(%9&4R!D<FEV97(@*&5D9&EE0&]M96=A=V%R92YC
M;VTL($)U9W,@(S$U-3(@86YD(",Q-34S*2X*6VIA;ET@36%K92!W<F%P<&EN
M9R!M96YU<R!V:7-I8FQE('=I=&@@1V5C:V\@,2XT(&)R;W=S97)S("AE+F<N
M($YE='-C87!E(#<N,2DN"EMJ86Y=(%5S92!344P@8FEN9&EN9R!F;W(@<V]M
M92!$871A5')E92!O<&5R871I;VYS+@I;:F%N72!&:7@@1&%T851R964@4U%,
M('-U<'!O<G0@9F]R($]R86-L92X*6VIA;ET@1FEX(%-13"!C;VYF:6=U<F%T
M:6]N(&9O<B!/<F%C;&4N"EMM;7-=($UA:V4@<W5R92!61E,@9V%R8F%G92!C
M;VQL96-T:6]N(&ES(&1O;F4@<F5C=7)S:79E;'DN"@H*+2TM+2TM+2TM+0IV
M,RXP+C0M4D,Q"BTM+2TM+2TM+2T*"EMJ86Y=($%D9"!(;W)D95]4<F5E7W-E
M;&5C="!C;&%S<R`H0F5N($-H879E="`\8F5N0&AO<F1E+F]R9SXI+@I;;6IR
M72!&:7@@3F5T7TE-4U`@=&\@<')O<&5R;'D@:&%N9&QE(&UU;'1I<&QE(&QI
M;F5S(&EN(&%D9')E<W-B;V]K(&9I96QD<RX*6VIA;ET@1FEX($U)344@9&5C
M;V1I;F<@;V8@<W1R:6YG<R!T:&%T(&-O;G1A:6X@(B4B(&EN(&UU;'1I8GET
M92!S97%U96YC97,*("`@("`@*$)U9R`C,30R,RDN"EMC:FA=($-O;G1R;VP@
M<W!A8V4@=6YD97(@=&AE(&UE;G4@8F%R('=I=&@@82!T:&5M96%B;&4@<W1Y
M;&4@*$)U9R`C,30R,2DN"EMC:FA=($9I>"!(;W)D95]4<F5E('=I=&@@=&AE
M(&UU;'1I;&EN92!O<'1I;VX@<V\@=&AA="!R;W<@<W1Y;&5S(&5X=&5N9"!O
M=F5R"B`@("`@('1H92!W:&]L92!H96EG:'0@;V8@=&AE(')O=RX*6V-J:%T@
M268@8V]N9FEG=7)A=&EO;B!F:6QE<R!T:&%T(&AA=F4@82`N9&ES="!V97)S
M:6]N(&%R92!M:7-S:6YG+`H@("`@("!(;W)D95]497-T.CIC;VYF:6=&:6QE
M<TUI<W-I;F<H*2!W:6QL(&-O<'D@=&AE(&1E9F%U;'1S(&]V97(@:68@2&]R
M9&4*("`@("`@8V%N('=R:71E('1O('1H92!F:6QE<WES=&5M("A"=6<@(S$P
M,34I+@I;8VIH72!&:7@@06YS96Q);6%G92!(5$U,07)E82!P;'5G:6X@*$)U
M9R`C,30W,"DN"EMC:FA=($IU<W0@<F5T<FEE=F4@=6ED('=H96X@;&ES=&EN
M9R!U<V5R<R!I;B!T:&4@3$1!4"!!=71H96YT:6-A=&EO;B!D<FEV97(N"EMC
M:FA=($%D9"!C:&]R85!R969S('1O('1H92!H;W)D95!E<G-O;B!,1$%0('-C
M:&5M82`H0G5G(",Q-#4R*2X*6V-J:%T@)W)O;W1D;B<@:7,@;F]T(')E<75I
M<F5D(&9O<B!,1$%0('!R969E<F5N8V5S("A"=6<@(S$T-3,I+@I;;6US72!&
M:7@@24U!4"!T:')E860@8W)E871I;VX@=VAE;B!T:&4@8F%S92!L979E;"!C
M;VYT86EN<R!M;W)E('1H86X@;VYE"B`@("`@(&UE<W-A9V4N"EMJ86Y=($%L
M;&]W('9#87)D<R!W:71H(&QO=V5R8V%S92!F:65L9"!D97-C<FEP=&]R<RX*
M6VIA;ET@26UP<F]V92!T87(O9WII<"!-24U%('9I97=E<B!T;R!B971T97(@
M<VAO=R!U;GII<'!E9"!C;VYT96YT+@I;;6IR72!"971T97(@97)R;W(@:&%N
M9&QI;F<@:6X@3F5T7TE-4U`N"EMM;7-=(%-P965D(&EM<')O=F5M96YT<R!A
M;F0@<V]R=&EN9R!F:7AE<R!F;W(@24U!4%]4<F5E+@I;;6US72!)34%07U1R
M964@;F]W(&AA;F1L97,@;F]N+75P<&5R8V%S960@)TE.0D]8)R!S=')I;F=S
M(')E='5R;F5D(&9R;VT@=&AE"B`@("`@(&UA:6P@<V5R=F5R("A"=6<@(S$Y
M.2DN"EMM;7-=(%)E8G5I;&0@8V5R=&%I;B!I;G1E<FYA;"!-24U%7U!A<G0@
M9&%T82!W:&5N(')E=')I979I;F<@9G)O;2!A(&-A8VAE+@I;:F%N72!3:&]W
M(&1A=&%B87-E('-P96-I9FEC(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!I;B!C
M;VYF:6=U<F%T:6]N('-C<F5E;BX*6VUM<UT@24U!4%]4<F5E(&YO=R!C;W)R
M96-T;'D@=7!D871E9"!W:&5N('-U8G-C<FEB:6YG+W5N<W5B<V-R:6)I;F<@
M9G)O;2!A"B`@("`@(&UA:6QB;W@@*$)U9R`C,3$Q,2DN"EMM;7-=($UA:V4@
M24U!4"!S96%R8VAE<R!O9B!N;VXM(G-T86YD87)D(B!H96%D97)S('=O<FL@
M=VET:"!T:&4@3D]4(&1I<F5C=&EV90H@("`@("`H0G5G(",Q,S8X*2X*6VIA
M;ET@1FEX960@9&]U8FQE(&QI;F4@;G5M8F5R<R!I;B!3;W5R8V4M:&EG:&QI
M9VAT($U)344@=FEE=V5R("A"=6<@(S$S.#,I+@I;;6US72!&:7@@24U!4%]4
M:')E860@=VAE;B!D96%L:6YG('=I=&@@=&AE(&9I<G-T(&UE<W-A9V4@:6X@
M=&AE(&UA:6QB;W@*("`@("`@*$)U9R`C,3(U-RDN"EMC:FA=($9I>"!M96YU
M(&AE:6=H=',@:6X@4V%F87)I+@I;:F%N72!#871C:"!E<G)O<G,@9G)O;2!C
M;VYF:6=U<F%T:6]N(&9I;&5S('1O(&%V;VED(&)L86YK('!A9V5S+@I;:F%N
M72!3=7!P;W)T(&UI;65?;6%G:6,@97AT96YS:6]N(&%G86EN(&EF(&9I;&5I
M;F9O(&ES(&YO="!P<F5S96YT+@H*"BTM+2TM+0IV,RXP+C,*+2TM+2TM"@I;
M;6IR72!.971?24U34"!N;W<@8V]R<F5C=&QY(&AA;F1L97,@861D<F5S<V)O
M;VL@;F%M97,@8V]N=&%I;FEN9R!S<&%C97,*("`@("`@*$)U9R`C,3(X-BDN
M"EMC:FA=($EM<&QE;65N="!C;&5A<B@I(&EN('1H92!,1$%0('!R969S(&1R
M:79E<B`H0G5G(",Q,S,U*2X*6V-J:%T@1&]N)W0@;&ES="!U;FEN<W1A;&QE
M9"!A<'!L:6-A=&EO;G,@87,@:6YI=&EA;%]A<'!L:6-A=&EO;B!O<'1I;VYS
M"B`@("`@("A"=6<@(S$S,C0I+@I;:F%N72!&:7@@<&]S=&%U=&AE;G1I8V%T
M92!H;V]K+"!N;W0@8V]M<&QE=&5L>2!D96YY:6YG(&%C8V5S<R!A9G1E<B!A
M(&9A:6QE9`H@("`@("!L;V=I;B`H0G5G(",Q,S(P*2X*6VIA;ET@0VAE8VMB
M;WAE<R!I;B!P;W)T86P@8FQO8VL@<V5T=7`@9F]R;7,@87)E(&-O<G)E8W1L
M>2!C:&5C:V5D(&YO=PH@("`@("`H0G5G(",Q,C0W*2X*6VUM<UT@06QL;W<@
M24U!4"!S96%R8VAE<R!T;R!W;W)K(&]N(&AE861E<G,@=VET:"!M=6QT:7!L
M92!E;G1R:65S"B`@("`@("AK;VQB0&)I=&QA8BYH=2D@*$)U9R`C,3,S,"DN
M"EMM;7-=($-O<G)E8W1L>2!S;W)T($E.0D]8('-U8F9O;&1E<G,@:6X@24U!
M4%]3;W)T("A"=6<@(S$R.3$I+@I;8VIH72!4=7)N(&]F9B!&;W)M(%1O:V5N
M<R!I;B!T:&4@8V]N9FEG=7)A=&EO;B!I;G1E<F9A8V4N"EMJ86Y=(%-O<G0@
M=7-E<B!A;F0@9W)O=7`@;&ES=',@:6X@<&5R;6ES<VEO;G,@:6YT97)F86-E
M("A"=6<@(S$S,#4I+@I;:F%N72!!;&QO=R!T;R!E;G1E<B!02%`@8V]D92!I
M;B!T:&4@<V5S<VEO;B!T:6UE;W5T(&-O;F9I9W5R871I;VX@*$)U9R`C,3,P
M,BDN"@H*+2TM+2TM+2TM+0IV,RXP+C,M4D,Q"BTM+2TM+2TM+2T*"EMM;7-=
M($9I>"!B=6<@:6X@5&5X=%]&;&]W960@=VAE<F4@=6YQ=6]T960@;&EN97,@
M8V]U;&0@;F]T(&)E(&9L;W=E9"X*6V-J:%T@1FEX(&QO9VEC('!R;V)L96US
M('=I=&@@=&AE($UY4U%,(&%N9"!/0TDX('-E<W-I;VX@:&%N9&QE<G,@=&AA
M=`H@("`@("!P<F5V96YT960@=&AE;2!F<F]M(&AA;F1L:6YG(')E<W1A<G1I
M;F<@82!S97-S:6]N(&-L96%N;'D@*$)U9R`C,3`Y-RDN"EMC:FA=($9I>"!P
M97)S:7-T96YC92!O9B`D8V]N9ELG;6%I;&5R)UU;)W!A<F%M<R==6R=A=71H
M)UT@:6X@=&AE(%-E='5P(%5)"B`@("`@("A"=6<@(S$R.#<I+@I;:F%N72!)
M;7!R;W9E('!E<F9O<FUA;F-E(&]F($1A=&%4<F5E(&]P97)A=&EO;G,@;&EK
M92!R96%D:6YG(&5M86EL(&UE<W-A9V4*("`@("`@:&ES=&]R:65S+@I;:F%N
M72!,;V<@<W5C8V5S<V9U;"!L;V=I;G,@86YD(&QO9V]U=',@=VET:"!T:&4@
M3D]424-%(&QE=F5L("A6:6QI=7,@4W5M<VMA<PH@("`@("`\=FEL:75S0&QN
M:RYL=#XI+@I;8VIH72!%;F-O9&4@2%1-3"!E;G1I=&EE<R!I;B!(;W)D95]&
M;W)M7U1Y<&5?;&]N9W1E>'0@9&ES<&QA>2`H0G5G(",Q,C8W*2X*6VUM<UT@
M1FEX('-E<W-I;VX@:&%N9&QI;F<@=&\@96YS=7)E('9A<FEA8FQE<R!A<F4@
M<&5R<VES=&5N="!A8W)O<W,@9G5N8W1I;VX*("`@("`@8V%L;',@*$=A<GD@
M5VEN9&AA;2`\=VEN9&AA;6=`96UA:6PN87)I>F]N82YE9'4^*2X*6VUM<UT@
M26UP<F]V96UE;G1S('1O(%=E8D-04"!-24U%7U9I97=E<B!R96YD97)E9"!O
M=71P=70N"EMM;7-=($UO<F4@9FEX97,@9F]R(%523',@=VET:"`G)F%M<"<@
M=VAE;B!P87-S:6YG('1H<F]U9V@@=&AE('-A;FET:7IE<BX*6VIA;ET@36%K
M92!W<F%P<&EN9R!M96YU<R!L;V]K:6YG(&YI8V5R(&EN($=E8VMO(&%N9"!+
M2%1-3"!B87-E9"!B<F]W<V5R<RX*6VIA;ET@1FEX($U)344@=FEE=V5R(&9O
M<B!G>FEP(&9I;&5S('1H870@9&]N)W0@8V]N=&%I;B!T87(@9FEL97,N"EMC
M:FA=($9I>"!V:7-I8FEL:71Y(&]F(#QA(#X@=&%G<R!I;G-I9&4@<VUA;&QH
M96%D97(@8FQO8VMS(&9O<B!T:&4@0V]R;F9L;W=E<@H@("`@("!T:&5M92`H
M0G5G(",Q,C`V*2X*6V-J:%T@1&\@;F]T(&-A8VAE(&IA=F%S8W)I<'0@<V5R
M=F5D('9I82!S97)V:6-E<R]J879A<V-R:7!T+G!H<"`H0G5G(",Q,30P*2X*
M6V-J:%T@1FEX(&UA;F%G96UE;G0@;V8@8V%T96=O<FEE<R!T:&%T(&-O;G1A
M:6X@<75O=&5S("A"=6<@(S$R,#(I+@I;8VIH72!(86YD;&4@861D<F5S<V5S
M('1H870@87)E(&%L<F5A9'D@<W5R<F]U;F1E9"!B>2!Q=6]T97,@:6X*("`@
M("`@34E-13HZ7W)F8S@R,D5N8V]D92@I("A"=6<@(S$Q-#,I+@I;8VIH72!&
M:7@@5D-?<W9N)W,@:&%N9&QI;F<@;V8@9&ER96-T;W)Y(&YA;65S('=I=&@@
M<W!A8V5S("A"=6<@(S$Q,C,I+@I;8VIH72!&:7@@8V%C:&EN9R!L;V=I8R!T
M:&%T('=A<R!C875S:6YG(%9#('1O(&YO="!P<F]P97)L>2!R969R97-H(&]B
M:F5C=',@:6X*("`@("`@82!T:6UE;'D@;6%N;F5R+@I;:F%N72!!;&QO=R!T
M;R!S970@9FEX960@=&%B;&4@8V5L;"!W:61T:',@:6X@5UE325=91R!E9&ET
M;W(N"@H*+2TM+2TM"G8S+C`N,@HM+2TM+2T*"EMC:FA=($UA:V4@<W5R92!N
M;W0@=&\@=&AR;W<@97)R;W)S('=H96X@8F%D(&5M86EL<R!A<F4@<W5P<&QI
M960@:6X*("`@("`@<V5R=FEC97,O<')O8FQE;2YP:'`@*$)U9R`C,3`W,"DN
M"EMJ86Y=($9I>"!W<F]N9R!C:&%R<V5T(&]F(')E9G)E<VAE9"!M96YU(&9R
M86UE(&EF(&YO="!U<VEN9R!55$8M."`H0G5G<PH@("`@("`C,3`U,BP@(S$P
M-34I+@I;:F%N72!&:7@@;&5F="!M96YU('1R964@8V]L;&%P<VEN9R!A9G1E
M<B!E86-H(')E9G)E<V@@*$)U9R`C,3`W,BDN"EMJ86Y=($9I>"!S:61E8F%R
M(&)E:6YG(&QO861E9"!T=VEC92!I9B!N;W0@=7-I;F<@8V]O:VEE<R`H0G5G
M(",Q,#<V*2X*"@HM+2TM+2T*=C,N,"XQ"BTM+2TM+0H*6VIA;ET@5&5S="!F
M;W(@<V5S<VEO;BYA=71O7W-T87)T+@I;;6US72!&:7@@<&%R<VEN9R!O9B!H
M96%D97(@=VET:"!U;F1I<V-L;W-E9"UR96-I<&EE;G1S("A"=6<@(S$P-3<I
M+@I;8VIH72!!9&0@82!B<F]W<V5R('%U:7)K(&9O<B!B<F]W<V5R<R!T:&%T
M(&1O;B=T('-U<'!O<G0@;W9E<F9L;W<Z:&ED9&5N(&EN"B`@("`@('1A8FQE
M(&-E;&QS("A+2%1-3"DN"EMJ86Y=($9I>"!A<'!L:6-A=&EO;B!L:6YK<R!I
M9B!N;W0@=7-I;F<@8V]O:VEE<R`H0G5G(",Q,#(Y*2X*6VUM<UT@1FEX(&1I
M<V%B;&EN9R!O9B!M86EN=&5N86YC92!C;VYF:7)M871I;VYS("A"=6<@(S$P
M,C<I+@I;8VIH72!&:7@@86QI9VYM96YT(&]F($AE;'`@=VEN9&]W(&AE861E
M<B!I;B!-4TE%("A"=6<@(S$P,C,I+@I;8VIH72!&:7@@=&AE($AO<F1E7T)L
M;V-K(&=R87!H:6-S('1O(&)E(&EN9&5X960L(&YO="!G<F%Y<V-A;&4@*$)U
M9R`C,3`U,2DN"EMC:FA=(%-%0U522519.B!#;&]S92!S979E<F%L(%A34R!V
M=6QN97)A8FEL:71I97,N"EMM;7-=($UA:V4@<W5R92!E>'1E<FYA;"!54DPG
M<R!W;W)K(&-O<G)E8W1L>2!W:&5N('1H92!54DP@8V]N=&%I;G,@)R9A;7`G
M(&%S"B`@("`@('1H92!D96QI;6ET97(N"EMC:FA=($9I>"!I;F9I;FET92!L
M;V]P('=I=&@@075T:%]A<'!L:6-A=&EO;B!D<FEV97(@*$)U9R`C,3`P-"DN
M"EMC:FA=($YE=F5R('-E="!A;B!E;7!T>2!(;W)D95]4<F5E(&-O;VMI92`H
M0G5G(",Q,#(R*2X*6VUM<UT@1FEX(&1I<W!L87EI;F<@;V8@9F]L9&5R<R!I
M;B!)34%07U1R964Z.B!F;W(@24U!4"!S97)V97)S('1H870@9&]N)W0@=7-E
M"B`@("`@("=)3D)/6"<@87,@=&AE:7(@9&5L:6UI=&5R("A"=6<@(S$P,30I
M+@I;8VIH72!(3U)$15]-14Y57TU!4TM?3D].12!N;W<@<F5A;&QY(&UE86YS
M(&]N;'D@97AP;&EC:71L>2!A9&1E9"!M96YU(&ET96US"B`@("`@(&%R92!D
M:7-P;&%Y960N"EMC:FA=($EG;F]R92!(,R!I;B!V97)S:6]N(&-O;7!A<FES
M;VYS("A"=6<@(S$P,3<I+@I;8VIH72!$871A5')E95]N=6QL(&YO=R!S='5B
M<R!O=70@=&AE(&9U;&P@1&%T851R964@05!)('1O(&%V;VED(&9A=&%L(&5R
M<F]R<PH@("`@("!W:&5N(&YO="!U<VEN9R!A('!E<FUA;F5N="!B86-K96YD
M+@I;:F%N72!&:7@@9&5L971I;F<@;V8@:61E;G1I=&EE<R`H0G5G(",Q,#$X
M*2X*"@HM+2TM"G8S+C`*+2TM+0H*6V-J:%T@5')Y('1O(&-A=&-H(&1A;F=E
M<F]U<R!54DQS(&EN('1H92!D97)E9F5R<F5R("AG;RYP:'`I+@I;8VIH72!)
M;7!R;W9E('1R964@9W)A<&AI8W,@9F]R(')I9VAT+71O+6QE9G0@;&%N9W5A
M9V5S("A686AI9"!':&%F87)P;W5R"B`@("`@(#QV86AI9$!G:&%F87)P;W5R
M+F-O;3XI+@I;;6US72!&:7@@24U!4%]4<F5E(&1I<W!L87D@:68@9F]L9&5R
M(&-O;G1A:6YS('1H92!T97AT("=P;W`S)RX*6V-J:%T@1FEX('1H92!(;W)D
M95]&;W)M(&1A=&4@<&EC:V5R('!O<'5P(&EN($MO;G%U97)O<B]3869A<FD@
M*$)U9R`C.38S*2X*6VIA;ET@4W!A8V5S(&EN('1R964@=FEE=W,@=VET:"!)
M;G1E<FYE="!%>'!L;W)E<B!H879E(&)E96X@9FEX960N"@H*+2TM+2TM+2T*
M=C,N,"U20S,*+2TM+2TM+2T*"EMC:FA=($%L=V%Y<R!R96QO860@9G)A;65S
M970@869T97(@;&]G9VEN9R!I;B`H0G5G(",X,30I+@I;8VIH72!&:7@@;65N
M=2!R96YD97)I;F<@9F]R($E%(#4N,"]-86,N"EMC:FA=(%1U<FX@;V9F(%!.
M1R!T<F%N<W!A<F5N8WD@9F]R($E%(&)Y(&1E9F%U;'0N"EMC:FA=($%L;&]W
M('1O('!A<W,@86X@87)R87D@;V8@871T<FEB=71E<R!T;R!(;W)D93HZ:6UG
M*"DN"EMC:FA=($%L;&]W('1O('-E="!A('!A<W-W;W)D(&9O<B!T:&4@875T
M;R!A=71H96YT:6-A=&EO;B!D<FEV97(N"EMJ86Y=($%D9"!O<'1I;VX@9F]R
M(&YU;&P@9')I=F5R('1O(&UA:6QE<B!C;VYF:6=U<F%T:6]N+@I;:F%N72!&
M:7@@8V]N9FEG=7)A=&EO;B!O9B!:4%,@8V%C:&4N"EMJ86Y=($9I>"!S;VUE
M(&IA=F%S8W)I<'0@97)R;W)S('=I=&@@244@-2XP+@I;8VIH72!4:&4@(DAO
M<F1E(%!U<G!L92(@=&AE;64@:7,@;F]W('-I;7!L>2!A;F]T:&5R('1H96UE
M('1H870@:6YH97)I=',@9G)O;0H@("`@("!T:&4@9VQO8F%L($-34R!S971T
M:6YG<RP@:6YS=&5A9"!O9B!B96EN9R!B;W1H('1H92!P87)E;G0@=&AE;64@
M87,@=V5L;`H@("`@("!A<R!A('5S97(M8VAO;W-E86)L92!O<'1I;VXN("!4
M:&4@9&5F875L="!G<F%P:&EC<R!A<F4@;F]W(&EN(&$*("`@("`@=&]P+6QE
M=F5L('1H96UE<R]G<F%P:&EC<R!D:7)E8W1O<GD@87,@=V5L;"!F;W(@=7-E
M(&)Y(&%L;"!T:&5M97,N"@H*+2TM+2TM+2T*=C,N,"U20S(*+2TM+2TM+2T*
M"EMJ86Y=(%-H;W<@=&%B('=I=&@@=&AE(&9I96QD('1H870@9&ED;B=T('9A
M;&ED871E(&]N('-U8FUI='1E9"!F;W)M<RX*6VUM<UT@061D(&$@9V5N97)I
M8R!-24U%7U9I97=E<B!T:&%T('=I;&P@9&ES<&QA>2!T:&4@<F%W('1E>'0@
M;V8@=&5X="\J"B`@("`@('!A<G1S('1H870@=V4@9&\@;F]T(&AA=F4@82!S
M<&5C:69I8R!V:65W97(@9F]R+@H*"BTM+2TM+2TM"G8S+C`M4D,Q"BTM+2TM
M+2TM"@I;8VIH72!5<V4@2$]21$5?345.55]-05-+7RH@8V]N<W1A;G1S(&9O
M<B!D971E<FUI;FEN9R!W:&%T(&QI;FMS(&%R92!S:&]W;@H@("`@("!O;B!M
M96YU<RX*6VIA;ET@0W)E871E(&1E9F%U;'0@<&%R86UE=&5R<R!W:&5N(&%D
M9&EN9R!A(&YE=R!B;&]C:R!T;R!T:&4@<&]R=&%L+@I;;6US72!!=71O9&5T
M96-T(&5X86-T('9E<G-I;VX@;V8@244@*#4N,"LI(&]N(&QO9VEN(&%N9"!T
M=7)N(&]F9B!C;VUP<F5S<VEO;@H@("`@("!O;FQY(&9O<B!B=6=G>2!V97)S
M:6]N<RX*6V-J:%T@57-E(&%N($E%(&)E:&%V:6]R(&9O<B!H86YD;&EN9R!A
M;'!H82!T<F%N<W!A<F5N8WD@=VET:"!03D<@:6UA9V5S"B`@("`@(&EN<W1E
M860@;V8@86X@;VYL;V%D(&AA;F1L97(N"EMM;7-=($%L;&]W(&%L;"!F;VQD
M97)S('1O(&)E('!R92UF971C:&5D('=H96X@:6YT:6%L:7II;F<@24U!4%]4
M<F5E.CHN"EMM;7-=($%D9&5D(&5X=&5N<VEO;G,@=&\@=&AE(&9O<FT@<F5N
M9&5R97(@9F]R('1H92!F:6QE('-E;&5C=&EO;B!!4$DN"EMC:FA=(%)E;F1E
M<B!A;&P@;65N=7,@87,@/'5L/B!T86=S+"!F;W)M871T960@=VET:"!#4U,N
M"EMM;7-=($%D9&5D(&5X86UP;&4@;V8@7VEM<%]H;V]K7W-P86U?8F]U;F-E
M('1O(&-O;F9I9R]H;V]K<RYP:'`N9&ES="X*"@HM+2TM+2TM+2T*=C,N,"U"
M151!"BTM+2TM+2TM+0H*6V-J:%T@06QL;W<@=&\@:6YS97)T(&EM86=E<R!F
M<F]M(&=A;&QE<FEE<R!I;B!T:&4@5UE325=91R!(5$U,(&5D:71O<B`H1'5C
M:PH@("`@("`\9'5C:T!O8F%L82YN970^+"!2;V5L($=L;W5D96UA;G,@/')O
M96Q`9VQO=61E;6%N<RYI;F9O/BDN"EMM9&I=($%L;"!(;W)D92!I8V]N<R!C
M:&%N9V5D(&9R;VT@1TE&('1O(%!.1RX*6VUD:ET@061D("]T:&5M97,@9&ER
M96-T;W)Y(&%N9"!G<F]U<"!A;&P@;V8@96%C:"!T:&5M92=S(&9I;&5S('5N
M9&5R(&$@<W5B9&ER"B`@("`@(&]F('1H:7,@9&ER96-T;W)Y+@I;:F%N72!3
M=VET8V@@9G)O;2!D>6YA;6EC('1O('-T871I8R!#4U,@9FEL97,N"EMM;7-=
M($%D9"!S=7!P;W)T(&9O<B!-97-S86=E($1I<W!O<VET:6]N($YO=&EF:6-A
M=&EO;G,@*%)&0R`R,CDX*2X*6VIA;ET@061D(%1A8FQE3W!E<F%T:6]N<RP@
M0V]N=&5X=$UE;G4@86YD($QI<W14>7!E('!L=6=I;G,@=&\@<FEC:"!T97AT
M"B`@("`@(&5D:71O<BX*6VIA;ET@061D($1A=&%4<F5E(&)R;W=S97(@=&\@
M861M:6X@:6YT97)F86-E+@I;8VIH72!4:&4@2&]R9&5?0V%C:&4Z.B!!4$D@
M:&%S(&)E96X@8V]M<&QE=&5L>2!R97=R:71T96X@=&\@=&%K90H@("`@("!A
M9'9A;G1A9V4@;V8@=&AE(&YE=R!:4%,T(&%P:2!F;W(@8V]N=&5N="!C86-H
M:6YG+"!W:&EC:"!A;&QO=W,*("`@("`@82!M;W)E(&9A;6EL:6%R(&-A8VAI
M;F<@05!)(&]V97)A;&PN(%1H92!O;&0@>G!S(&1R:79E<B!H87,@8F5E;@H@
M("`@("!D<F]P<&5D(&)E8V%U<V4@;V8@=&AI<RX*6VIA;ET@061D(%!E<G-I
M86X@*%=E<W1E<FXI('1R86YS;&%T:6]N("A686AI9"!':&%F87)P;W5R"B`@
M("`@(#QV86AI9$!G:&%F87)P;W5R+F-O;3XI+@I;:F%N72!$<F]P('5S86=E
M(&]F(&%R9U]S97!A<F%T;W(N;W5T<'5T+@I;:F%N72!-86ME('-I9&5B87(@
M=VED=&@@82!P<F5F97)E;F-E("A2:6-K($5M97)Y(#QR:6-K0&5M97)Y+FAO
M;65L:6YU>"YN970^*2X*6V-J:%T@5&AE(%!R969S7W-Q;"!D<FEV97(@;F]W
M('5S97,@1$(Z.G!R97!A<F4O1$(Z.F5X96-U=&4@9F]R(&)E='1E<B!S=7!P
M;W)T"B`@("`@(&]F(&QA<F=E(&9I96QD<R!O;B!D871A8F%S92!B86-K96YD
M<R!S=6-H(&%S($]R86-L92X*6V-J:%T@4W5P<&]R="!C=7-T;VT@9FEE;&0@
M;6%P<&EN9W,@:6X@0U-6(&5X<&]R=',L(&%N9"!A9&0@86X@3W5T;&]O:R!E
M>'!O<G0*("`@("`@='EP92X*6V-J:%T@5&AE($AO<F1E('-I9&5B87(@;65N
M=2!I<R!N;W<@8G5I;'0@=VET:"!(;W)D95]4<F5E+@I;:F%N72!314-54DE4
M63H@0VQO<V4@86X@6%-3(&AO;&4@:6X@=&AE($A434P@=FEE=V5R+"!A('9A
M<FEA=&EO;B!T;R!T:&4@;VYE"B`@("`@(')E<&]R=&5D(&EN(&AT='`Z+R]W
M=W<N9W)E>6UA9VEC+F-O;2]S96-U<FET>2]A9'9I<V]R:65S+V=M,#`U+6UC
M+RX*6VIA;ET@061D(&-O;F9I9W5R871I;VX@;W!T:6]N('1O(&5N86)L92!3
M4TP@9F]R(&QO9VEN<R!O;FQY+@I;:F%N72!296UO=F4@<VAA<F4@='EP92`H
M<')I=F%T92]P=6)L:6,I+@I;:F%N72!!9&0@9G)A;65W;W)K('1O(&-L96%R
M(&]U="!U<V5R(&1A=&$L(&4N9RX@=VAE;B!R96UO=FEN9R!U<V5R<RX*6VIA
M;ET@061D(&%C8V5S<R!K97ES+@I;:F%N72!$;VXG="!R97%U:7)E(&)L;V-K
M<R!T;R!B92!R96=I<W1E<F5D(&EN('1H92!A<'!L:6-A=&EO;G,G($%027,N
M"EMC:FA=($EN=')O9'5C92!A("=?9&5F875L=%\G(&-O;&]R(&%N9"!B971T
M97(@:&%N9&QI;F<@;V8@=7-E<BUS<&5C:69I960*("`@("`@56YF:6QE9"!C
M;VQO<G,N"EMJ86Y=($%L;&]W('1H96UE<R!T;R!U<V4@=&AE:7(@;W=N(&EC
M;VX@<V5T<RX*6V-J:%T@0V%T96=O<FEE<R!A;F0@8V%T96=O<GD@8V]L;W(@
M;&%B96QS(&%R92!N;W<@:&%N9&QE9"!G;&]B86QL>2!B>2!(;W)D92P*("`@
M("`@86YD('!R;W9I9&5D('1O(&%L;"!A<'!L:6-A=&EO;G,@=&AA="!U<V4@
M=&AE;2X*6VIA;ET@261E;G1I=&EE<R!A<F4@;F]W(&UA;F%G960@=VET:"!T
M:&4@<')E9F5R96YC97,@8V]D92!A;F0@8V%N(&)E(&%C8V5S<V5D"B`@("`@
M(&9R;VT@979E<GD@87!P;&EC871I;VXN"EMM;7-=($AA;F1L92!21D,@,C(S
M,2!E;F-O9&5D('!A<F%M971E<B!V86QU97,N"EMM;7-=($%D9"!)34%07U-O
M<G0@8VQA<W,@=&\@<')O=FED92!S;W)T:6YG(&9O<B!)34%0(&UA:6QB;W@@
M;&ES=',N"EMJ86Y=($%D9"!U<V5R(&UA;F%G96UE;G0@=&\@24U!4"!A=71H
M96YT:6-A=&EO;B!D<FEV97(N"EMJ86Y=($%D9"!)34%07T%D;6EN(&-L87-S
M('1O(&UA;F%G92!)34%0(&UA:6QB;WAE<RX*6VUM<UT@061D960@82!G96YE
M<FEC('1E>'0O:'1M;"!-24U%7U9I97=E<B!D<FEV97(@9F]R(&%L;"!(;W)D
M92!A<'!L:6-A=&EO;G,*("`@("`@=&AA="!A='1E;7!T<R!T;R!S86YI=&EZ
M92!M86QI8VEO=7,@8V]D92!H:61D96X@:6X@2%1-3"X*6VUM<UT@061D960@
M82!G96YE<FEC(&UE<W-A9V4O<F9C.#(R($U)345?5FEE=V5R(&1R:79E<BX*
M6V-J:%T@4F5M;W9E($A/4D1%7TQ)0E,@8V]N<W1A;G0@86YD(&%S<W5M92!L
M:6)R87)I97,@87)E(&EN('1H92!I;F-L=61E7W!A=&@N"EMJ86Y=($%D9"!S
M96%R8VAI;F<@86YD('!A9VEN9R!T;R!T:&4@=7-E<B!A9&UI;FES=')A=&EO
M;B!I;G1E<F9A8V4@*$IO96P*("`@("`@5F%N9&%L(#QJ=F%N9&%L0&EN9F]T
M96-K+G%C+F-A/BDN"@H*+2TM+2TM+2TM+0IV,RXP+4%,4$A!"BTM+2TM+2TM
M+2T*"EMJ86Y=($%C8V5S<R!K97ES(&%R92!N;R!L;VYG97(@9V5N97)A=&5D
M(&%U=&]M871I8V%L;'D@8G5T(&1E9FEN960@8GD@=&AE"B`@("`@(&1E=F5L
M;W!E<G,@86YD('1R86YS;&%T;W)S+@I;8VIH72!4:&4@;F5W('-E<G9I8V5S
M+W!R969S+G!H<"!F:6QE(&ES(&YO=R!T:&4@;VYL>2!522!P86=E(&YE8V5S
M<V%R>0H@("`@("!F;W(@<')E9F5R96YC97,@9F]R(&%L;"!A<'!L:6-A=&EO
M;G,@+2!A;&P@87!P+W!R969S+G!H<"!F:6QE<PH@("`@("!A<F4@;F]W(&]B
M<V]L971E+@I;8VIH72!0<F5F<SHZ9V5T4')E9B@I(&AA<R!B965N(&1E<')E
M8V%T960@86YD(&ES(&YO(&QO;F=E<B!P<F5S96YT+@I;8VIH72!(;W)D93HZ
M+"!296=I<W1R>3HZ+"!A;F0@=&AE(&QA<W0@;V8@=&AE(&QI8G,@=&AA="!A
M<F4@;6]V:6YG('-H;W5L9"!B90H@("`@("!M;W9E9"!T;R!F<F%M97=O<FL@
M<&%C:V%G97,@;F]W+@I;8VIH72!%9&ET;W(Z.BP@365N=2YP:'`L($Y,4SHZ
M+"!A;F0@4VEG;G5P+G!H<"!H879E(&%L;"!B965N(&UO=F5D('1O"B`@("`@
M(&9R86UE=V]R:R!P86-K86=E<RX*6VUM<UT@36]V960@=&AE($E-05`@5')E
M92!G96YE<F%T:6]N(&-L87-S(&9R;VT@24U0('1O(&9R86UE=V]R:R!S;R!I
M="!C86X*("`@("`@8F4@=7-E9"!B>2!O=&AE<B!A<'!L:6-A=&EO;G,N"EMM
M9&I=(%-E='5P(&YO=R!H87,@82!M;W)E(&EN9F]R;6%T:79E(&9O<FUA="X@
M5&AE($-64R!V97)S:6]N('1A9R!I<R!C;W!I960*("`@("`@9G)O;2!T:&4@
M8V]N9BYX;6P@9FEL92!I;G1O('1H92!C;VYF+G!H<"!F:6QE('-O('1H870@
M:70@8F4@=7-E9"!T;R!W87)N"B`@("`@('=H:6-H(&%P<&QI8V%T:6]N<R!N
M965D('1H96ER(&-O;F8@=7!D871E9"X*6V-J:%T@57-E(&IA=F%S8W)I<'0@
M=&\@875T;V1E=&5C="!W:&5T:&5R(&]R(&YO="!T:&4@9G)A;65S970@:7,@
M<')E<V5N="X*6V-J:%T@2&]R9&5?2&ES=&]R>2P@2&]R9&5?3&EN:W,L(&%N
M9"!(;W)D95]396%R8V@@:&%V92!B965N(&UO=F5D('1O"B`@("`@(&9R86UE
M=V]R:R!P86-K86=E<RX*6V-J:%T@06QL;W<@87!P<R!I;F-L=61I;F<@:&]R
M9&4O;&EB+V)A<V4N<&AP('1O('-P96-I9GD@=&AA="!A(&1I9F9E<F5N=`H@
M("`@("!R96=I<W1R>2!A<'!L:6-A=&EO;B!S:&]U;&0@86-T=6%L;'D@8F4@
M<'5S:&5D(&]N=&\@=&AE(%)E9VES=')Y"B`@("`@(&%P<&QI8V%T:6]N('-T
M86-K+B!4:&ES(&QE=',@=&AE(&9I8W1I;VX@;V8@<')O8FQE;2YP:'`@8F5I
M;F<@:71S"B`@("`@(&]W;B!A<'!L:6-A=&EO;B!P;&%Y(&YI8V5L>2!W:71H
M('1H92!N97<@<&5R;6ES<VEO;G,@8VAE8VMI;F<N"EMC:FA=(%1H92!N97<@
M87!P;&EC871I;VX@<&5R;6ES<VEO;G,@8VAE8VMI;F<@:&%S(&)E96X@;6]D
M:69I960@=&\*("`@("`@86QL;W<@86-C97-S('1O(&%L;"!A=71H96YT:6-A
M=&5D('5S97)S(&)Y(&1E9F%U;'0L(&%N9"!T;R!D96YY"B`@("`@(&=U97-T
M(&%C8V5S<R!B>2!D969A=6QT+B!!;&P@=F%R:6%T:6]N<R!O;B!T:&%T(&UU
M<W0@8F4@<V5T"B`@("`@(&5X<&QI8VET;'DN"EMC:FA=(%)E;6]V92!T:&4@
M1W5E<W0@4V5R=FEC97,@;&EN:SL@:70G<R!B965N(&]B<V]L971E9"!B>0H@
M("`@("`D8V]N9ELG;65N=2==6R=A;'=A>7,G72X*6V-J:%T@5F%R:6]U<R`D
M;F]?875T:"!A;F0@)'-E;&9?8V]N=&%I;F5D7V%U=&@@9FQA9W,@:&%V92!B
M965N('-T86YD87)D:7IE9`H@("`@("!I;G1O(&%N($%55$A?2$%.1$Q%4B!C
M;VYS=&%N="P@=VAI8V@@:68@9&5F:6YE9"!S:6=N86QS('1H92!A<'!L:6-A
M=&EO;@H@("`@("!T:&%T(&ET('-H;W5L9"!N;W0@8VAE8VL@<&5R;6ES<VEO
M;G,@=7!O;B!C86QL:6YG("1R96=I<W1R>2T^<'5S:$%P<"@I+`H@("`@("!A
M<R!T:&4@8V%L;&EN9R!S8W)I<'0@=VEL;"!H86YD;&4@=&AA="!I='-E;&8L
M(&]R(&ES(&$@<WES=&5M+6QE=F5L(&-R;VX*("`@("`@:F]B+W-C<FEP="]E
M=&,N"EMC:FA=($%D9"!A;B!O<'1I;VX@=&\@)')E9VES=')Y+3YP=7-H07!P
M*"D@=&\@<W!E8VEF>2!W:&5T:&5R(&]R(&YO="!T;R!C:&5C:PH@("`@("!A
M<'!L:6-A=&EO;B!P97)M:7-S:6]N<RX*6V-J:%T@5&AE("=A;&QO=U]G=65S
M=',G('-E='1I;F<L(&%N9"`D<F5G:7-T<GDM/F%L;&]W1W5E<W1S*"DL(&AA
M=F4@8F5E;@H@("`@("!R96UO=F5D(&EN(&9A=F]R(&]F($AO<F1E7U!E<FUS
M(&%P<&QI8V%T:6]N('!E<FUI<W-I;VYS+@I;;6US72!!9&1E9"!T:&4@=&5X
M="]R:6-H=&5X="!-24U%7U9I97=E<BX*6VIA;ET@26YS=&%N=&EA=&4@=&AE
M(&=L;V)A;"!097)M<R!O8FIE8W0@:6X@4F5G:7-T<GDN<&AP+@I;8VIH72!#
M871E9V]R>2!H87,@8F5E;B!M;W9E9"!T;R!A(&9R86UE=V]R:R!P86-K86=E
M+"!A;F0@86QS;R!R96YA;65D"B`@("`@('1O($1A=&%4<F5E('-O('1H870@
M:70@:&%S(&$@;6]R92!I;G1U:71I=F4@;F%M92!F;W(@=&AE($%022X*6VIA
M;ET@061D($EN9&]N97-I86X@;&%N9W5A9V4@*%-L86UI;B`\<VQA;6EN0'5N
M96HN86,N:60^*2X*6VIA;ET@061D($%U=&A?;&]G:6X@8VQA<W,N"EMJ86Y=
M($%D9"!(;W)D93HZ97AT97)N86Q5<FPH*2X*6VUD:ET@4&5R;7,@:7,@;F]W
M(&$@9VQO8F%L;'D@879A:6QA8FQE(&]B:F5C="P@<V5T(&)Y('1H92!R96=I
M<W1R>2=S"B`@("`@(&QO861097)M<R@I+@I;:F%N72!!9&0@(D%B;W5T(B!P
M86=E(&9O<B!T:&4@:&5L<"!S>7-T96TN"EMJ86Y=($%D9"!33T%0('-E<G9E
M<B!T;R!24$,@9G)A;65W;W)K+@I;8VIH72!-;W9E(%!R969S54D@=&\@4')E
M9G,O54DN<&AP(&9O<B!P86-K86=E(&-O;G-I<W1E;F-Y+@I;;6US72!!9&1E
M9"!.3%-?1V5O25`Z.B!T;R!D;R!(;W-T;F%M92`M/B!#;W5N=')Y(&QO;VMU
M<',N("!.3%,Z.B!W:6QL(&1O"B`@("`@(&QO;VMU<',@8GD@9&5F875L="!N
M;W<@=7-I;F<@8V]U;G1R>2!43$0@8V]D97,N"EMM:7)=($%D9"!P<F5P<F]C
M97-S(&AO;VL@9F]R(%-I9VYU<"!S>7-T96TN"EMJ86Y=($UO=F4@2&]R9&5?
M0TQ)+"!(;W)D95]#86-H92P@2&]R9&5?0VEP:&5R+"!(;W)D95]#;VUP<F5S
M<RP*("`@("`@2&]R9&5?5&]K96X@86YD($AO<F1E7U5T:6P@<&%C:V%G97,@
M=&\@=&AE(&9R86UE=V]R:R!M;V1U;&4N"EMC:FA=(%)E;W)G86YI>F4@82!N
M=6UB97(@;V8@9FEL97,@9G)O;2!T:&4@=&]P(&QE=F5L(&%N9"!F<F]M('5T
M:6PO(&EN=&\@80H@("`@("!N97<@<V5R=FEC97,O(&1I<F5C=&]R>2!A;F0@
M82!N=6UB97(@;V8@<V5R=FEC97,O*B!S=6)D:7)E8W1O<FEE<RX*("`@("`@
M5&AI<R!S:&]U;&0@9VEV92!U<R!A(&)E='1E<B!B87-E(&9O<B!E>'!A;F1I
M;F<@=&AE('-E<G9I8V5S('!R;W9I9&5D"B`@("`@(&)Y('1H92!C;W)E($AO
M<F1E(&UO9'5L92!I;B!T:&4@9G5T=7)E+@I;;6%X72!!9&0@<W5P<&]R="!F
M;W(@/&(^(&%N9"`\:3X@=&%G<R!T;R!T:&4@2&5L<"!X;6P@<&%R<V5R+@I;
M8VIH72!!9&0@=&AE($AO<F1E7TAI<W1O<GD@05!)+"!F;W(@<W1O<FEN9R!T
M:6UE<W1A;7!E9"!E=F5N=',@9F]R"B`@("`@(&%R8FET<F%R>2!O8FIE8W1S
M+@I;8VIH72!(;W)D95]496UP;&%T92!N;W<@86QL;W=S(&EF.B!C;VYD:71I
M;VYS(&]N(&%R<F%Y('9A;'5E<PH@("`@("`H3G5N;R!,;W5R96ER;R`\;G5N
M;T!C;RYS87!O+G!T/BDN"EMJ86Y=(%1H92!A9&UI;FES=')A=&]R(&-A;B!N
M;W<@9F]R8V4@=&AE(&1E9F%U;'0@;&%N9W5A9V4@:6X@;FQS+G!H<`H@("`@
M("`H171I96YN92!';WEE<B`\971I96YN92YG;WEE<D!L:6YU>'%U96)E8RYC
M;VT^*2X*6VUD:ET@2&]R9&5?1F]R;2!N;W<@<W5P<&]R=',@<V5T=&EN9R!O
M9B!A(&AE;'`@:6-O;B!L:6YK960@=&\@:&5L<"YX;6PN"EMC:FA=(&UI;65?
M;6%P<&EN9RYP:'`@:7,@;F\@;&]N9V5R(&$@8V]N9FEG(&9I;&4[(')E<&QA
M8V5D('=I=&@*("`@("`@;6EM92YM87!P:6YG+G!H<"!I;G-I9&4@=&AE($U)
M344@<&%C:V%G92X*6V-J:%T@061D($=O;V=L92!S96%R8V@@87!P;&5T("A*
M;V4@5VEL<V]N(#QJ;V4N=VEL<V]N0&UI;F1C86YD>2YO<F<^*2X*6VIA;ET@
M551&+3@@<W5P<&]R="!I<R!E;F%B;&5D(&)Y(&1E9F%U;'0@;F]W+@I;:F%N
M72!4:&5M97,@87)E(&YO=R!A=71O;6%T:6-A;&QY(')E860@9G)O;2!T:&4@
M8V]N9FEG+W1H96UE<R!D:7)E8W1O<GDN"EMC:FA=($%D9"!S=7!P;W)T(&9O
M<B!O=&AE<B!K:6YD<R!O9B!S97)V97)S(&%N9"!O=&AE<B!K:6YD<R!O9B!R
M97-P;VYS97,@=&\*("`@("`@<G!C+G!H<"!A;F0@=&AE(%)00SHZ($%022X*
M6VIW;5T@061D('-U<'!O<G0@9F]R(&%P<')O=FEN9R!Q=65U960@<VEG;G5P
M(&%P<&QI8V%T:6]N<RX*6V-J:%T@1W)O=7!S(&-A;B!N;W<@:&%V92!A;B!E
M;6%I;"!A9&1R97-S(&%S<V]C:6%T960@=VET:"!T:&5M+@I;8VIH72!-86ME
M($AO<F1E+6QE=F5L($)L;V-K<R!C;VYF:6=U<F%B;&4@=&AR;W5G:"!T:&4@
M<F5G:7-T<GDL(&%L;&]W:6YG"B`@("`@(&5A<VEE<B!A9&1I;F<@;V8@;F5W
M(&)L;V-K<R`H2F]E(%=I;'-O;B`\:F]E+G=I;'-O;D!M:6YD8V%N9'DN;W)G
M/BDN"EMC:FA=($-A=&5G;W)Y5')E92!I<R!N;W<@9&5P<F5C871E9"!I;B!F
M879O<B!O9B!(;W)D95]4<F5E+@I;8VIH72!-;W9E('1H92!A9&UI;B!P97)M
M:7-S:6]N<R!A;F0@9W)O=7!S('!A9V5S('1O('5S92!(;W)D95]4<F5E+@I;
M;6%X72!!9&0@7V-O;7!A<F5087-S=V]R9',H*2!F=6YC=&EO;B!T;R!!=71H
M7W-Q;"!T;R!C;W)R96-T;'D@8V]M<&%R90H@("`@("!A;&P@8W)Y<'1E9"!P
M87-S=V]R9',@<VEM:6QA<B!T;R!T:&4@4&%S<W=D(&UO9'5L92X*6VUA>%T@
M061D(&-R>7!T+61E<R`H=VAI8V@@:7,@=&AE('-A;64@87,@8W)Y<'0I+"!C
M<GEP="UM9#4L(&%N9"!C<GEP="UB;&]W9FES:`H@("`@("!E;F-R>7!T:6]N
M('1Y<&5S+"!T;R!M871C:"!087-S=V0@;6]D=6QE+@I;;6%X72!!9&0@;W!T
M:6]N86P@<VAO=U]E;F-R>7!T:6]N('!A<F%M('1O($%U=&A?<W%L+"!T;R!M
M871C:"!087-S=V0@;6]D=6QE+@I;;6US72!!9&1E9"!)4"!!9&1R97-S(&-H
M96-K('1O($%U=&@Z.F%U=&AE;G1I8V%T92@I('1O(&EN8W)E87-E('-E8W5R
M:71Y+@I;:F%N72!296UO=F4@3DQ3.CID96-I;6%L1G)O;4QO8V%L92@I(&%N
M9"!.3%,Z.F1E8VEM86Q4;TQO8V%L92@I+@I;8VIH72!(;W)D95]61E,Z.B!I
M<R!N;W<@5D93.CH@86=A:6XL(&%N9"!H87,@;F\@97AT97)N86P@2&]R9&4@
M9&5P96YD86YC:65S+@I;8VIH72!2;W5N9"!O=70@=&AE('9A<FEO=7,@<VAE
M;&P@=&]O;',@=VET:"!A(&-O;6UA;F0@<VAE;&PN"EMC:FA=($%D9"!S:61E
M8F%R+G!H<"!A;F0@87!P<F]P<FEA=&4@<')E9G,@96YT<FEE<R!F;W(@=7-I
M;F<@2&]R9&4@=VET:"!T:&4*("`@("`@;65N=2!A<R!A($UO>FEL;&$@<VED
M96)A<BX*6VUM<UT@061D($E-05!?0V%C:&4Z.B!C;&%S<R!T;R!H86YD;&4@
M8V%C:&5D($E-05`@<V5R=F5R(&1A=&$N"EMC:FA=($UA:V4@9V5T0V%T96=O
M<FEE<T)Y071T<FEB=71E<R@I(&UU8V@@;6]R92!S;W!H:7-T:6-A=&5D("T@
M:70@8V%N"B`@("`@(&YO=R!H86YD;&4@82!P<F5T='D@;75C:"!A<F)I=')A
M<GD@;&]G:6,@=')E92`M(&%N9"!U<V4@:70@=&\@;W!T:6UI>F4*("`@("`@
M2&]R9&5?4VAA<F4Z.FQI<W13:&%R97,H*2X*6V-J:%T@061D(&=E=$-A=&5G
M;W)I97-">4%T=')I8G5T97,H*2P@86YD('5S92!I="!I;@H@("`@("!'<F]U
M<#HZ9V5T1W)O=7!-96UB97)S:&EP<R@I+@I;8VIH72!!9&0@8V]D92!T:&%T
M(&QE=',@82!#871E9V]R>4]B:F5C="!S=6)C;&%S<R!D969I;F4@82!M87!P
M:6YG(&9R;VT@:71S"B`@("`@(&EN=&5R;F%L(&1A=&$@=&\@=&AE(&YE=R!H
M;W)D95]C871E9V]R>5]A='1R:6)U=&5S('1A8FQE+@I;;6US72!)34%07U-E
M87)C:#HZ(&YO=R!U<V5S(&$@24U!4%]396%R8VA?475E<GDZ.B!O8FIE8W0@
M=&\@8G5I;&0@=&AE"B`@("`@(&%C='5A;"!)34%0('-E87)C:"X*6VUM<UT@
M061D960@82!S96-U<F4@9&5L971E('1E;7`@9FEL92!O<'1I;VX@=&AA="!W
M:6QL(&]V97)W<FET92!A;GD@=&5M<"!F:6QE"B`@("`@('=I=&@@<F%N9&]M
M(&1A=&$@8F5F;W)E('5N;&EN:VEN9RX*6VIA;ET@061D($QA=F5N9&5R('1H
M96UE("A::6%U<B!286AM86X@/'II84!Q86QA8V]M+F-O;3XI+@I;8VIH72!(
M;W)D95]496UP;&%T93HZ(&ES(&YO=R!C87!A8FQE(&]F('1R86YS;&%T:6YG
M('1E>'0@:6YS:61E"B`@("`@(#QG971T97AT/CPO9V5T=&5X=#X@=&%G<RX*
M6V-J:%T@2&]R9&5?36]B:6QE.CH@;F]W('!R;W!E<FQY('-U<'!O<G1S(&UU
M;'1I<&QE('-U8FUI="!E;&5M96YT<R!I;B!F;W)M<RX*6VUA8UT@061D(&=E
M;F5R:6,@0WER=7,@875T:"!D<FEV97(L($%U=&A?8WER=7,N"EMM86-=($%D
M9"!O<'1I;VYA;"!E;F-R>7!T:6]N('!A<F%M('1O($%U=&A?<W%L+"!T;R!M
M871C:"!087-S=V0@;6]D=6QE+@I;:F%N72!!9&0@;F5W(&AO;VMS("AR97!L
M86-I;F<@7VAO<F1E7VAO;VM?=7-E<FYA;64I('1O(&-O;G9E<G0@=7-E<B!N
M86UE<PH@("`@("!F<F]M('1H92!B86-K96YD('1O($AO<F1E(&%N9"!B86-K
M+@I;8VIH72!!9&0@82!N97<@05!)(&-A;&PL($%U=&@Z.FES075T:&5N=&EC
M871E9"@D<F5A;&T@/2!N=6QL*2P@9F]R"B`@("`@(&1E=&5R;6EN:6YG('=H
M971H97(@;W(@;F]T(&$@=7-E<B!I<R!L;V=G960@:6X@=&\@=&AE(&-U<G)E
M;G0*("`@("`@<F5A;&T@*&)Y(&1E9F%U;'0@;G5L;"DN($%U=&@Z.F=E=$%U
M=&@H*2!I<R!S=&EL;"!U<V5D('1O(&=E=`H@("`@("!T:&4@8W5R<F5N="!U
M<V5R+"!B=70@;F]W('EO=2!D;VXG="!N965D('1O(&MN;W<@=&AE(&%U=&@@
M<F5A;&T*("`@("`@=&\@9V5T('1H92!C=7)R96YT('5S97(@+2!J=7-T('1O
M(&-H96-K(&%U=&AE;G1I8V%T:6]N+@I;8VIH72!$2%1-3"!D871E('!I8VME
M<B!N;W<@;W!E;G,@<FEG:'0@;W9E<B!T:&4@:6UA9V4@=7-E9"!T;R!A;F-H
M;W(@:70N"EMC:FA=(%1H92!L87-T7VQO9VEN('!R969E<F5N8V4@:7,@;F]W
M(&5N=&ER96QY(&AA;F1L960@8GD@2&]R9&4N"EMM;7-=($%D9"!(;W)D95]4
M97-T.CH@8VQA<W,O=&5M<&QA=&5S('1O(&%I9"!I;B!C<F5A=&EN9R!T97-T
M+G!H<"!S8W)I<'1S+@I;;6US72!-;W9E(&-O;7!L97@@24U!4"!S96%R8VAI
M;F<@8V]D92!F<F]M($E-4%]396%R8V@Z.B!T;R!)34%07U-E87)C:#HZ+@I;
M8VIH72!292UW;W)K('1H92!(;W)D92!,1$%0('-C:&5M82!B:71S('1O(&)E
M(&UO<F4@8V]R<F5C="!A;F0*("`@("`@8V]N<VES=&5N="`H061A;2!4875N
M;R!7:6QL:6%M<R`\861A;4!M;W)R:7-O;BUI;F0N8V]M/BDN"EMM;7-=($%D
M9"!$3TT@=&]O;'1I<"!C87!A8FEL:71Y('9I82!(;W)D93HZ;&EN:U1O;VQT
M:7`H*2X*6VUM<UT@061D(&=A<F)A9V4@8V]L;&5C=&EO;B!C;&%S<R`H2&]R
M9&5?5D937T=#.CHI(&9O<B!61E,N"EMM;7-=($%D9"!T:6UE;W5T('1O(%!'
M4"!K97ES97)V97(@;&]O:W5P+@I;8VIH72!!9&0@;F%V:6=A=&EO;B!F;W(@
M<')E=FEO=7,O;F5X="!P<F5F97)E;F-E<R!B;&]C:R!I;B!0<F5F<U5)"B`@
M("`@("A-871H:65U($-,04)!550@/&UA=&AI974N8VQA8F%U=$!F<F5E+F9R
M/BDN"EMC:FA=($%D9"!(;W)D95],:6YK<R!!4$D@*&HN:'5I;FEN:T!W86YA
M9&]O+FYL*2X*6V-J:%T@061D(&UO<F4@:6YT<F]S<&5C=&EO;BP@:6X@=&AE
M(&9O<FT@;V8@9V5T0V]N=&5N=%1Y<&4H*2!A;F0*("`@("`@9V5T3&EN:R@I
M+"!T;R!T:&4@2&]R9&5?26UA9V4Z.B!!4$DN"EMC:FA=($%D9"!U=&EL+V-A
M8VAE=FEE=RYP:'`@9F]R('9I97=I;F<@86YY(&1A=&$@=VET:"!A($-O;G1E
M;G0M='EP90H@("`@("!P=70@:6YT;R!T:&4@8V%C:&4N"EMC:FA=($%D9"!(
M;W)D95]#86-H93HZ8V%C:&5/8FIE8W0H*2!F;W(@=7-E(&EN(&-A8VAI;F<@
M=&AE(')E<W5L=',@;V8*("`@("`@;F]N+7-T871I8R!O8FIE8W0@;65T:&]D
M<RX*6V-J:%T@4F5N86UE($-A8VAE.CH@=&\@2&]R9&5?0V%C:&4Z.BX*6V-J
M:%T@36]V92!#86-H95]S97-S:6]N.CH@=&\@2&]R9&5?4V5S<VEO;D]B:F5C
M=',Z.BX*6VUM<UT@061D960@2&]R9&4Z.F5X=&5N<VEO;D5X:7-T<R@I('1O
M(&-A8VAE(&5X=&5N<VEO;E]L;V%D960H*2!C86QL<RX*6V-J:%T@061D($Y,
M4SHZ9&5C:6UA;%1O3&]C86QE*"D@86YD($Y,4SHZ9&5C:6UA;$9R;VU,;V-A
M;&4H*2!T;R!H86YD;&4*("`@("`@8V]N=F5R=&EN9R!B971W965N(&1I9F9E
M<F5N="!D96-I;6%L('!O:6YT('-E<&%R871O<G,N"EMC:FA=($%D9&5D($U)
M345?2&5A9&5R<SHZ+@I;;6US72!-;W9E9"!G>FEP(&%N9"!T87(@9FEL92!H
M86YD;&EN9R!T;R!(;W)D95]#;VUP<F5S<U\J.CH@;6]D=6QE<RX*6VUM<UT@
M36]V960@6DE0(&AA;F1L:6YG('1O('1H92!(;W)D95]#;VUP<F5S<U]Z:7`Z
M.B!M;V1U;&4N"EMM;7-=($UO=F5D(%1.148@:&%N9&QI;F<@=&\@=&AE($AO
M<F1E7T-O;7!R97-S7W1N968Z.B!M;V1U;&4N"EMM;7-=($%D9&5D($AO<F1E
M7T-O;7!R97-S.CH@05!)("T@=7-E9"!T;R!C;VUP<F5S<R]D96-O;7!R97-S
M(&1A=&$N"EMM9&I=($%D9&5D('1H92!$3TT@8V%L96YD87(@9&%T92!P:6-K
M97(@=&\@2&]R9&5?1F]R;2P@8F%S960@;VX@=V]R:R!B>0H@("`@("!-:6ME
M($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/B!A;F0@0G)I86X@
M2V5I9F5R"B`@("`@(#QB<FEA;D!V86QI;F]R+FYE=#XN"EMM;7-=($%D9&5D
M(&UU;'1I<&%R="]R97!O<G0@34E-15]6:65W97(Z.BX*6VUM<UT@061D960@
M34E-13HZ9V5N97)A=&5-97-S86=E240H*2!T;R!G96YE<F%T92!-24U%+6-O
M;7!L:6%N="!M97-S86=E($E$<RX*6V-J:%T@061D(&-O;6UA;F0M;&EN92!S
M971U<"YP:'`@<V-R:7!T+B!2:6=H="!N;W<L('1H:7,@;VYL>2!G96YE<F%T
M97,O=7!D871E<PH@("`@("!C;VYF:6=U<F%T:6]N<SL@>6]U(&-A;FYO="`J
M961I="H@82!C;VYF:6=U<F%T:6]N('=I=&@@:70N"EMJ86Y=($%D9"!3=')I
M;F<Z.B!C;&%S<R!W:71H(&QO8V%L92]C:&%R<V5T('-A9F4@<W1R:6YG(&9U
M;F-T:6]N<RX*6VUM<UT@061D960@2&]R9&4Z.F%U=&AE;G1I8V%T:6]N1F%I
M;'5R95)E9&ER96-T*"DN"EMM;7-=($%D9&5D($)R;W=S97(Z.F5S8V%P94I3
M0V]D92@I('1O(&5S8V%P92!C97)T86EN(&-H87)A8W1E<G,@:6X*("`@("`@
M:F%V87-C<FEP="!C;V1E(&1E<&5N9&EN9R!O;B!T:&4@8G)O=W-E<B!T>7!E
M+@I;:F%N72!!9&0@3DQ3.CIS=')T;VQO=V5R*"D@86YD('5S92!I="!E=F5R
M>7=H97)E('=H97)E(&QO8V%L92!I;F1E<&5N9&%N8V4*("`@("`@:7,@;F5C
M97-S87)Y+@I;:F%N72!!9&0@5'5R:VES:"!T<F%N<VQA=&EO;B`H1V5N8V\@
M66EL;6%Z(#QG96YC;WEI;&UA>D!Y86AO;RYC;VT^*2X*6VUM<UT@061D("=L
M:6YK)R!P87)A;65T97(@=&\@=&AE('!R969E<F5N8V5S(&-O;F9I9R!T;R!A
M;&QO=R!F;W(@:&5L<"!L:6YK<PH@("`@("!T;R!B92!A9&1E9"!T;R!T:&4@
M<')E9F5R96YC97,@<&%G97,N"EMM;7-=($%N;W1H97(@36%I;G1E;F%N8V4Z
M.B!R97=R:71E("T@;F]W('-T;W)E(&%L;"!D871A(&EN('1H92!C86-H960*
M("`@("`@36%I;G1E;F%N8V5?5&%S:VQI<W0@;V)J96-T+@I;;6US72!!9&1E
M9"!C:&5C:R!T;R!0<F5F<SHZ('1O(&5N<W5R92!T:&4@9&%T82!S=&]R960@
M9&]E<R!N;W0@97AC965D('1H90H@("`@("!M87AI;75M('-T;W)A9V4@<VEZ
M92!O9B!T:&4@<')E9F5R96YC97,@<W1O<F%G92!S>7-T96TN"EMJ86Y=($%D
M9"!55$8M."!S=7!P;W)T+B!!;GD@8V]N=&5N="!W:71H(&%N>2!C:&%R<V5T
M(&-A;B!N;W<@8F4@9&ES<&QA>65D('=I=&@*("`@("`@86YY('1R86YS;&%T
M:6]N+@I;;6US72!!9&0@3DQ3.CIC:&5C:T-H87)S970H*2!T;R!D971E<FUI
M;F4@=VAE=&AE<B!A(&=I=F5N(&-H87)A8W1E<B!S970@:7,*("`@("`@=F%L
M:60@;VX@=&AE(&-U<G)E;G0@<WES=&5M+@I;8VIH72!$97!R96-A=&5D(%)E
M9VES=')Y.CII;F-L=61E1FEL97,H*2!A;F0@4F5G:7-T<GDZ.G-H=71D;W=N
M*"DN"EMM;7-=($%D9"!S=7!P;W)T(&EN($U)345?36%G:6,Z.B!T;R!U<V4@
M=&AE(%5.25@@9FEL92!F=6YC=&EO;B!T;R!D971E<FUI;F4*("`@("`@=&AE
M($U)344@='EP92!O9B!U;FMN;W=N(&9I;&5S+@I;;6US72!!9&1E9"!A;B!E
M>&%M<&QE(&-R;VX@<V-R:7!T('1O(&1E;&5T92!O;&0@=&5M<&]R87)Y(&9I
M;&5S+@I;;6US72!#;W)R96-T;'D@9V5T(&-H87)S970@:6YF;W)M871I;VX@
M9F]R($U)345?4&%R=',@:6X@34E-15]3=')U8W1U<F4N"EMM;7-=(%)E=W)O
M=&4@34E-15]-97-S86=E('1O(&5X=&5N9"!-24U%7U!A<G0N"EMC:FA=($%D
M9"!O<F1E<FEN9R!E>'1E;G-I;VYS('1O('1H92!#871E9V]R>3HZ(&9R86UE
M=V]R:PH@("`@("`H36%R:V\@/&UA<FMO0&]B;&\N8V]M/BDN"EMC:FA=($%D
M9"!A('-I;7!L92!T96UP;&%T92!E;F=I;F4L(&1E<FEV960@9G)O;2!B5&5M
M<&QA=&4L"B`@("`@(&9O<B!(;W)D92!A<'!L:6-A=&EO;G,@=&\@=7-E+@I;
M8VIH72!!9&0@075T:%]Y86AO;SHZ('=H:6-H(&QE=',@>6]U(&AA=F4@;F\@
M;&]C86P@875T:"!A;F0@<F5L>2!O;@H@("`@("!986AO;R$@;6%I;"!U<V5R
M;F%M97,N"EMM;7-=($UO=F5D(%-E<G9E<B!C;VYF:6=U<F%T:6]N(&-H96-K
M:6YG(&9U;F-T:6]N<R!T;R!397)V97(Z.BX*6V-J:%T@5&AE('5S97(@861M
M:6X@<&%G92!C86X@;F]W('-E="!F=6QL;F%M92!A;F0@9G)O;5]A9&1R('!R
M969E<F5N8V5S"B`@("`@(&9O<B!A;GD@=7-E<B!A<R!L;VYG(&%S('1H92!!
M=71H(&)A8VME;F0@:7,@8V%P86)L92!O9B!A="!L96%S=`H@("`@("!L:7-T
M:6YG('5S97)S("AD;V5S;B=T(&AA=F4@=&\@8F4@86)L92!T;R!U<&1A=&4@
M=&AE;2DN"EMC:FA=(%-H87)E.CH@:7,@;F]W($AO<F1E7U-H87)E.CHL(&%N
M9"!I<R!R97=O<FME9"!T;R!H;VQD('!E<FUI<W-I;VYS"B`@("`@(&EN=&5R
M;F%L;'DN(%=E(&-A;B!N;W<@87-S:6=N(&=R;W5P+V1E9F%U;'0O9W5E<W0@
M<&5R;6ES<VEO;G,*("`@("`@;6]R92!E87-I;'DN"EMJ86Y=($%D9"!24$,Z
M.G!A<G-E57)L*"DN"EMJ86Y=($%D9"!24$,@8F%S960@<F5M;W1E('-U;6UA
M<FEE<RX*6V-J:%T@061D(&$@4U%,(%-H96QL('1O('1H92!(;W)D92!A9&UI
M;B!S96-T:6]N+@I;8VIH72!$;VXG="!P<F5F:7@@2&]R9&4@861M:6X@;65N
M=6ET96US('=I=&@@(DAO<F1E(B!T;R!S879E('-P86-E+@I;8VIH72!(;W)D
M95]&;W)M.CH@9F]R;7,@;F]W('5S92!T:&4@2&]R9&5?5&]K96XZ.B!!4$D@
M8GD@9&5F875L="!T;PH@("`@("!M86ME('-U<F4@=&AA="!T:&5Y(&-A;FYO
M="!B92!R96QO861E9"X*6V-J:%T@4F5N86UE(%1O:V5N.CH@=&\@2&]R9&5?
M5&]K96XZ.B!F;W(@9G5T=7)E('!A8VMA9VEN9RX*6VIA;ET@061D(%)E9VES
M=')Y.CIL:7-T05!)<R@I(&%N9"!296=I<W1R>3HZ;&ES=$UE=&AO9',H*2X*
M6V-J:%T@5&AE(%!E<FUS.CH@<WES=&5M(&YO=R!S=7!P;W)T<R!D969A=6QT
M(&%N9"!G=65S="!P97)M:7-S:6]N<RX*6V-J:%T@07!P;&EC871I;VYS(&-A
M;B!N;W<@<')O=FED92!I;F1I=FED=6%L(')E9VES=')Y(&UE=&AO9',L(&YO
M="!J=7-T('=H;VQE"B`@("`@(&EN=&5R9F%C97,N($%P<&QI8V%T:6]N<R!C
M86X@;W9E<G)I9&4@82!S:6YG;&4@;65T:&]D(&]U="!O9B!A;B!I;G1E<F9A
M8V4*("`@("`@87,@=V5L;"`M(&%N(&%P<"!P<F]V:61I;F<@82!M86EL+V9I
M;'1E<B!W:&EL92!)35`@<')O=FED97,@;6%I;"\J+"!E+F<N"EMC:FA=(%)E
M;F%M960@1F]R;5-P<F]C:V5T.CH@=&\@2&]R9&5?1F]R;3HZ(&%N9"!'<F%P
M:%-P<F]C:V5T.CH@=&\*("`@("`@2&]R9&5?1W)A<&@Z.B!F;W(@8V]N<VES
M=&5N8WD@86YD(&9U='5R92!014%2('!A8VMA9VEN9RX*6VUI<ET@061D960@
M97AA;7!L92!O9B!?:6UP7VAO;VMS7V9E=&-H;6%I;%]F:6QT97(@=&\@8V]N
M9FEG+VAO;VMS+G!H<"YD:7-T"EMM;7-=($%D9&5D('1H92!-24U%7T-O;G1E
M;G1S.CH@8VQA<W,[(&9U;F-T:6]N<R!T;R!H96QP(&EN('1H92!O=71P=70*
M("`@("`@;V8@34E-12!C;VYT96YT+@I;8VIH72!297=R:71E('1H92!#871E
M9V]R>3HZ('-Y<W1E;2!T;R!A;&QO=R!M=6QT:7!L92!L96%V97,@=VET:"!T
M:&4@<V%M90H@("`@("!N86UE("AA<R!L;VYG(&%S('1H97D@:&%V92!D:69F
M97)E;G0@<&%R96YT<RD@86YD(')E=W)I=&4@979E<GET:&EN9PH@("`@("`H
M4&5R;7,Z.BP@1W)O=7`Z.BP@4VAA<F4Z.BP@971C+BD@=&\@=7-E(&ET+@I;
M8VIH72!-;W9E(%]F:6QE0VQE86YU<"@I(&EN=&\@2&]R9&4Z.B!A<R!(;W)D
M93HZ9&5L971E0713:'5T9&]W;B@I+`H@("`@("!A;F0@861D($AO<F1E.CI?
M9&5L971E0713:'5T9&]W;B@I('1O(&1O('1H92!A8W1U86P@9&5L971I;F<N
M"EMC:FA=($EN:71I86P@<W5P<&]R="!F;W(@8V]N9FEG=7)I;F<@=&AE('-U
M;6UA<GD@<V-R965N"B`@("`@("A%<FEC(%)E8VAL:6X@/&5R:6-`:'!C86QC
M+F]R9SXI+@I;8VIH72!!9&0@82!S>7-T96T@9F]R(&1E9FEN:6YG(&=E;F5R
M:6,@:&]O:W,@9F]R(&%N>2!P<F5F97)E;F-E+@H@("`@("!3964@:&]R9&4O
M8V]N9FEG+VAO;VMS+G!H<"YD:7-T(&9O<B!L;W1S(&]F(&5X86UP;&5S(&%N
M9"!D;V-S+@I;8VIH72!!9&0@82!C;VQO<G!I8VME<B!U=&EL:71Y('1O($AO
M<F1E"B`@("`@("A-:6-H865L($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL
M+F-O+FYZ/BDN"EMC:FA=($%D9"!A(&=U97-T('-E<G9I8V5S(&5N=')Y('!A
M9V4@86YD(&QI;FMS('1O(&ET(&9R;VT@86QL"B`@("`@(&QO9VEN('!A9V5S
M+@I;:F%N72!!9&0@=')A;G-L871I;VX@:&5L<&5R('-C<FEP="X*6VUM<UT@
M4W1Y;&5S:&5E="!L:6YK(&=E;F5R871I;VX@:&%N9&QE9"!B>2!(;W)D93HZ
M<W1Y;&5S:&5E=$QI;FLH*2X*6V-J:%T@061D('1H92!N97<@0V]N9FEG.CH@
M05!)(&%N9"!S971U<"YP:'`L(&$@<WES=&5M('=H:6-H(')E861S"B`@("`@
M(&-O;F9I9W5R871I;VYS(&9R;VT@6$U,(&9I;&5S(&%N9"!E>&ES=&EN9R!C
M;VYF+G!H<"!F:6QE<RP*("`@("`@=&%K:6YG(&-A<F4@;V8@;65R9V5S(&%N
M9"!A9&1I;F<@;F5W('!A<F%M971E<G,N($-U<G)E;G1L>2!W90H@("`@("!H
M879E(&$@=V5B('=I>F%R9"X*6V-J:%T@8W-S+G!H<"!N;W<@<W5P<&]R=',@
M;&]A9&EN9R!#4U,@8VQA<W-E<R!F;W(@;75L=&EP;&4@87!P;&EC871I;VYS
M+@I;;6US72!296UO=F5D('1H92!397-S:6]N0V%C:&4@8VQA<W,N($5Q=6EV
M86QE;G0@8V]D92!I<R!N;W<@879A:6QA8FQE(&EN"B`@("`@('1H92!#86-H
M95]S97-S:6]N.CH@8VQA<W,N"EMM;7-=($%D9&5D($E%(&)R;VME;BUB<F]W
M<V5R(&1O=VYL;V%D:6YG(&-O9&4@=&\@0G)O=W-E<CHZ+@I;;6US72!!9&1E
M9"!A('-E<W-I;VX@9')I=F5R('1O($-A8VAE.CHN"EMC:FA=(%)E;F%M92!C
M;VYF:6<O:&]R9&4N<&AP('1O(&-O;F9I9R]C;VYF+G!H<"X*6V-J:%T@36]V
M92!C;V]K:65?9&]M86EN+"!C;V]K:65?<&%T:"P@<V5R=F5R7VYA;64L(&%N
M9"!S97)V97)?<&]R="!I;G1O"B`@("`@(&AO<F1E+V-O;F8N<&AP+@I;8VIH
M72!!9&0@82!P87)A;65T97(@9F]R('-E='1I;F<@=&AE('-E<W-I;VX@8V%C
M:&5?;&EM:71E<BX*6V-J:%T@061D($U)345?5FEE=V5R7W1E>'0@=&\@2&]R
M9&4N"EMC:FA=(%)E=W)I=&4@86QL(&9A8W1O<GDO<VEN9VQE=&]N(&UE=&AO
M9',@=&\@86QL;W<@:6YD:79I9'5A;"!A<'!L:6-A=&EO;G,*("`@("`@=&\@
M<')O=FED92!A(&-U<W1O;2!B86-K96YD+"!A;F0@=&\@86QL;W<@<VET97,@
M=&\@<')O=FED92!C=7-T;VT*("`@("`@8F%C:V5N9',@:6X@=&AE:7(@:6YC
M;'5D95]P871H('-E='1I;F=S+@I;;6US72!(86YD;&EN9R!O9B!#;VYT96YT
M+51Y<&4@<&%R86UE=&5R<R!M;W9E9"!T;R!-24U%7U!A<G0@9G)O;2!-24U%
M7TUE<W-A9V4N"EMM;7-=($-R>7!T7W!G<#HZ(&-A;B!N;W<@=7!L;V%D(&ME
M>7,@=&\@82!P=6)L:6,@:V5Y<V5R=F5R+@I;;6US72!296YA;65D('1H92!,
M86YG.CH@8VQA<W,@=&\@3DQ3.CH@86YD(&UO=F5D('1H92!T:6UE>F]N92!S
M971T:6YG"B`@("`@(&UE=&AO9"!I;G1O(&ET+@I;;6US72!4:&4@;&]C86P@
M=&EM97IO;F4@8V%N(&YO=R!B92!S970@=FEA('1H92!(;W)D93HZ<V5T5&EM
M97IO;F4H*2!C86QL+@I;;6US72!!;&P@8G)O=W-E<B!H96%D97)S(&9O<B!D
M;W=N;&]A9&EN9R!A(&9I;&4@:&%V92!B965N(&UO=F5D('1O('1H90H@("`@
M("!"<F]W<V5R.CH@8VQA<W,N"EMC:FA=($%D9"!F:6QE<R!T;R!U=&EL('1O
M('-U<'!O<G0@96UB961D:6YG(&$@1U5)(&5D:71O<B!I;G1O(&]U<B!P86=E
M<RX*6VUM<UT@34E-13HZ(&YO(&QO;F=E<B!E>'!O<G1S("1M:6UE7W1Y<&5S
M(&%N9"`D;6EM95]E;F-O9&EN9W,@87,@9VQO8F%L"B`@("`@('9A<FEA8FQE
M<R`M(')A=&AE<BP@34E-13HZ='EP92@I(&%N9"!-24U%.CIE;F-O9&EN9R@I
M('-H;W5L9"!B92!U<V5D+@I;;6US72!4:&4@=&=Z($U)345?5FEE=V5R(&YO
M=R!L:7-T<R!A;&P@9FEL97,@=VET:&]U="!U<VEN9R!A;B!E>'1E<FYA;"!H
M96QP97(*("`@("`@<')O9W)A;2`H36EC:&%E;"!#;V-H<F%N92`\;6EK94!G
M<F%F=&]N:&%L;"YC;RYN>CXI+@I;;6US72!4:&4@<F%R($U)345?5FEE=V5R
M(&YO=R!L:7-T<R!A;&P@9FEL97,@=VET:&]U="!U<VEN9R!A;B!E>'1E<FYA
M;"!H96QP97(*("`@("`@<')O9W)A;2`H36EC:&%E;"!#;V-H<F%N92`\;6EK
M94!G<F%F=&]N:&%L;"YC;RYN>CXI+@I;;6US72!4:&4@>FEP($U)345?5FEE
M=V5R(&YO=R!L:7-T<R!A;&P@9FEL97,@=VET:&]U="!U<VEN9R!A;B!E>'1E
M<FYA;"!H96QP97(*("`@("`@<')O9W)A;2`H36EC:&%E;"!#;V-H<F%N92`\
M;6EK94!G<F%F=&]N:&%L;"YC;RYN>CXI+@I;;6US72!-86EN=&5N86YC93HZ
M(&YO=R!U<V5S('-E<W-I;VX@=F%R:6%B;&5S('1O('!R;W9I9&4@;75C:"!C
M;&5A;F5R(&%N9"!M;W)E"B`@("`@(')O8G5S="!P97)F;W)M86YC92X*6VUM
M<UT@35,M5$Y%1B!A='1A8VAM96YT<R!A<F4@;F]W(&AA;F1L960@8V]M<&QE
M=&5L>2!V:6$@4$A0(')A=&AE<B!T:&%N('=I=&@*("`@("`@86X@97AT97)N
M86P@<')O9W)A;2X*6VUM<UT@061D960@87!P;&EC871I;VXO;7,M=&YE9B!-
M24U%7U9I97=E<BX*6VUM<UT@2&]R9&5?0W)Y<'1?<&=P(&-L87-S(&-A;B!Q
M=65R>2!P=6)L:6,@:V5Y<V5R=F5R<RX*6VUM<UT@34E-15]3=')U8W1U<F4Z
M.G!A<G-E34E-14AE861E<G,H*2!C86X@;F]W('!A<G-E(&%L;"!H96%D97)S
M(&]F(&$@34E-10H@("`@("!M97-S86=E(&%N9"!R971U<FX@86X@;V)J96-T
M+@I;:F%N72!!9&0@34E-13HZ<F9C.#(R5W)I=&5!9&1R97-S*"D@=&\@<F5P
M;&%C92!I;6%P7W)F8S@R,E]W<FET95]A9&1R97-S*"DN"EMM;7-=($%D9&5D
M(%,O34E-12!-24U%7U9I97=E<BX*6VIO;ET@4W5P<&]R="!R969E<G)A;',@
M8F5T=V5E;B!,1$%0('-E<G9E<G,@:6X@=&AE($Q$05`@<')E9F5R96YC97,@
M9')I=F5R"B`@("`@("A+979I;B!(:6QD96)R86YD(#QK979I;D!H<2YE;G-O
M<&]R="YC;VT^*2X*6V-J:%T@34E-15]3=')U8W1U<F4Z.G!A<G-E*"D@;F]W
M(')E='5R;G,@82!-24U%7TUE<W-A9V4@;V)J96-T"B`@("`@("A-:6-H865L
M($T@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3XI+@I;
M8VIH72!#;VYF:6=U<F4@861M:6YI<W1R871I;VX@<V5R=FEC97,@:6X@=&AE
M(%)E9VES=')Y"B`@("`@("A-87)C=7,@22X@4GEA;B`\;6%R8W5S0')I8F]F
M;&%V:6XN;F5T/BDN"EMC:FA=($%D9"!!4$D@;65T:&]D<R!F;W(@9V5T=&EN
M9R!T:&4@<')E9F5R96YC97,@86YD(&ED96YT:71I97,@;V8@=7-E<G,*("`@
M("`@;W1H97(@=&AA;B!T:&4@;&]G9V5D+6EN('5S97(N"EMC:FA=($%L;&]W
M('-E='1I;F<@=&AE($-O;G1E;G0M1&ES<&]S:71I;VX@;V8@34E-15]087)T
M(&]B:F5C=',N"EMC:FA=($%D9"!#<GEP=#HZ(&9R86UE=V]R:R`H36EC:&%E
M;"!-(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^*2X*
M6VUA>%T@061D($)R;W=N($AO<F1E('1H96UE("A-87)C;R!/8F%I9"`\;6%R
M8V]`;75W+F5D=3XI+@I;:F]N72!!;&QO=R!T:&4@3$1!4"!V97)S:6]N('1O
M(&)E('-P96-I9FEE9"!F;W(@=&AE($Q$05`@<')E9F5R96YC97,@9')I=F5R
M+@I;:F%N72!!9&0@=&AE;64@<')E9F5R96YC92X*6VIA;ET@061D(&-A;&QB
M86-K(&9U;G1I;VX@9F]R('!R969E<F5N8V5S+@I;:F]N72!296UO=F4@=&AE
M("1C;VYF6R=M96YU)UU;)V9L;V%T:6YG7V)A<B==(&9U;F-T:6]N86QI='DN
M"EMJ86Y=($QO860@;VYL>2!L;V=I;B!P86=E(&]N('-T87)T=7`@86YD(')E
M9&ER96-T('1O(&9R86UE<V5T(&%F=&5R(&QO9VEN+@I;8VIH72!$;VXG="!A
M;&QO=R!A;F]N>6UO=7,@86-C97-S('1O('!R;V)L96TN<&AP+@I;8VIH72!!
M9&0@96Y?1T(@;&]C86QE+@I;8VIH72!296UO=F4@97AT96YS:6]N<R!O;B!T
M96UP;W)A<GD@9FEL97,[('1H:7,@:7,@82!T96UP(')A8V4@:&]L92X*6V-J
M:%T@06QL;W<@9F]R(&%U=&\M8W)E871I;VX@;V8@<&5R;6ES<VEO;G,@*&UU
M;'1I<&QE(&QE=F5L<R!O9B!H:65R87)C:'DI+@I;8VIH72!!9&0@861D:6YG
M+W)E;6]V:6YG(&]F('5S97)S(&9R;VT@9W)O=7!S+@I;8VIH72!#<F5A=&4@
M=&5M<"!F:6QE<R!W:71H('1H92!R:6=H="!E>'1E;G-I;VX@:6X@34E-15]6
M:65W97)?96YS8W)I<'0Z.B!S;PH@("`@("!E;G-C<FEP="!H87,@;6]R92!C
M;'5E<R!T;R!G=65S<R!F:6QE('1Y<&4N"EMC:FA=(%1H92!A9&UI;FEN<W1R
M871I;VX@:6YT97)F86-E(&9O<B!'<F]U<',@86YD(%!E<FUI<W-I;VYS(&ES
M(&YO=PH@("`@("!M;W-T;'D@9G5N8W1I;VYA;"X*6V-J:%T@36%K92!A<'!L
M:6-A=&EO;B!A=71H96YT:6-A=&EO;B!A;B!!=71H.CH@9')I=F5R+"!I;G-T
M96%D(&]F(&$@<W!E8VEA;`H@("`@("!296=I<W1R>2!C87-E+@I;8VIH72!&
M:7@@<')O8FQE;7,@=VET:"!T:&4@3F]T:69I8V%T:6]N('-T86-K(&%N9"!R
M96=I<W1E<E]G;&]B86QS(&)E:6YG(&]F9BX*6VIO;ET@06QT97(@2&]R9&4Z
M.FEM9R@I('1O(&5X<&QI8VET;'D@86-C97!T(&%N(&%L=#TB(B!A='1R:6)U
M=&4N"B`@("`@($AO<F1E.CII;6<H*2!N;W<@9V5N97)A=&5S('1I=&QE/2(B
M(&%T=')I8G5T97,@8F%S960@;VX@=&AE(&%L=#TB(B!T97AT+`H@("`@("!T
M;V\N"EMC:FA=($YO=&EF:6-A=&EO;CHZ;F]T:69Y*"D@<&%S<V5S('1H92!M
M97-S86=E('-T86-K('1O(&%L;"!L:7-T96YE<G,L('-O('1H870*("`@("`@
M;&ES=&5N97)S(&1O;B=T(&AA=F4@=&\@:VYO=R!A8F]U="!T:&4@;65S<V%G
M92!S=&%C:RP@86YD(&%P<"!W<FET97)S"B`@("`@(&1O;B=T(&AA=F4@=&\@
M:VYO=R!A8F]U="!A;&P@<&]S<VEB;&4@;&ES=&5N97)S+@I;8VIH72!297!L
M86-E('1H92!(3U)$15\J(&UE<W-A9V4@8V]N<W1A;G1S('=I=&@@)VAO<F1E
M+F5R<F]R)RP@971C+B!F;W(*("`@("`@9W)E871E<B!F;&5X:6)I;&ET>2X*
M6V-J:%T@4F5M;W9E($AO<F1E.CIR86ES94UE<W-A9V4H*2!N;W<@=&AA="!T
M:&4@3F]T:69I8V%T:6]N('-Y<W1E;0H@("`@("!P<F]V:61E<R!T:&%T(&9U
M;F-T:6]N86QI='DN"EMC:FA=(%5S92!T:&4@;F5W($YO=&EF:6-A=&EO;B!S
M>7-T96TN"EMC:FA=(%)E;6]V92!O=&AE<B!296=I<W1R>2!G970H*2!M971H
M;V1S+@I;:F]N72!296UO=F4@<W5P<&]R="!F;W(@=&AE(&AO<F1E7VQA;F=U
M86=E(&-O;VMI92X*6VIA;ET@36]V92!T:&4@;6%I;G1E;F%C92!F<F%M97=O
M<FL@9G)O;2!)35`@=&\@2&]R9&4@*$UI8VAA96P@32!3;'5S87)Z"B`@("`@
M(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/BDN"@H*+2TM+2TM"G8R
M+C(N.0HM+2TM+2T*"EMJ86Y=(%-%0U522519.B!&:7@@<&]T96YT:6%L(%A3
M4R!V=6QN97)A8FEL:71Y(&1U92!T;R!N;W0@<')O<&5R;'D@97-C87!E9`H@
M("`@("!E<G)O<B!M97-S86=E<RX*"@HM+2TM+2T*=C(N,BXX"BTM+2TM+0H*
M6VIA;ET@4T5#55))5%DZ($-L;W-E(%A34R!W:&5N('-E='1I;F<@=&AE('!A
M<F5N="!F<F%M92=S('!A9V4@=&ET;&4@8GD*("`@("`@:F%V87-C<FEP="`H
M8VIH*2X*"@HM+2TM+2T*=C(N,BXW"BTM+2TM+0H*6V-J:%T@4F5S=&]R92!C
M;VUP871I8FEL:71Y('=I=&@@4$A0(#0N,2X*6VIA;ET@4T5#55))5%DZ($9I
M>"!P;W1E;G1I86P@6%-3('9U;&YE<F%B:6QI='D@:6X@=&AE(&AE;'`@=VEN
M9&]W+@I;:F%N72!&:7@@8VAA<G-E="!F;W(@3&%T=FEA;B!T<F%N<VQA=&EO
M;B`H0G5G(",V-38I+@H*"BTM+2TM+0IV,BXR+C8*+2TM+2TM"@I;:F%N72!5
M<V4@1$(Z.G!R97!A<F4O1$(Z.F5X96-U=&4@3TY,62!F;W(@3W)A8VQE('1O
M(&%V;VED(&EM<&QI8VET;'D@<F5Q=6ER:6YG"B`@("`@(%!(4"`T+C(@9F]R
M(&%L;"!O=&AE<B!21$)-<RX*6V-J:%T@1FEX($]R86-L92!S97-S:6]N(&AA
M;F1L97(N"EMC:FA=($%D9"!344P@<V-R:7!T<R!F;W(@3W)A8VQE(&%N9"!0
M;W-T9W)E4U%,('-E<W-I;VX@:&%N9&QE<G,N"EMJ86Y=($1O;B=T('-T<FEP
M('1R86EL:6YG('-P86-E<R!F<F]M('-I9VYA='5R92!D87-H97,@:6X@24U0
M+@H*"BTM+2TM+2TM+2T*=C(N,BXV+5)#,0HM+2TM+2TM+2TM"@I;8VIH72!&
M:7@@<W5P<&]R="!F;W(@8W5S=&]M('-E<W-I;VX@:&%N9&QE<G,N"EMC:FA=
M(%5S92!$0CHZ<')E<&%R92]$0CHZ97AE8W5T92!I;B!T:&4@4')E9G-?<W%L
M(&1R:79E<B!F;W(@8F5T=&5R('-U<'!O<G0*("`@("`@;V8@;&%R9V4@9FEE
M;&1S(&]N(&1A=&%B87-E<R!S=6-H(&%S($]R86-L92X*6VIA;ET@4VAO=R!T
M:&4@=7-E<B=S(&9U;&P@;F%M92!O;B!T:&4@<W5M;6%R>2!S8W)E96X@9&ER
M96-T;'D@869T97(@;&]G9VEN9PH@("`@("!I;B`H1"X@061A;2!+87)I;2`\
M861A;4!A:V%R<V]F="YC;VT^*2X*6VIA;ET@1FEX(&IA=F%S8W)I<'0@97)R
M;W(@:6X@(E!R;V)L96TB('!A9V4@=VET:"!S;VUE('1R86YS;&%T:6]N<R`H
M0G5G(",V,2DN"EMC:FA=($9I>"!H86YD;&EN9R!O9B!0;W-T9W)E4U%,(&)L
M;V)S("A"=6<@(S0T*2X*"@HM+2TM+2T*=C(N,BXU"BTM+2TM+0H*6VIA;ET@
M061D($EN9&]N97-I86X@;&%N9W5A9V4@*%-L86UI;B`\<VQA;6EN0'5N96HN
M86,N:60^*2X*6VIA;ET@061D($=A;&EC:6%N('1R86YS;&%T:6]N("A2869A
M96P@5F%R96QA(%!E="`\<W)R869A0'5S8RYE<SXL($=U:6QL97)M;PH@("`@
M("!-96YD97H@/&=U:6QL94!U<V,N97,^*2X*6VUM<UT@1FEX(&1O=VYL;V%D
M:6YG(&]F(&9I;&5S('=I=&@@<W!A8V5S(&EN($UO>FEL;&$N"@H*+2TM+2TM
M"G8R+C(N-`HM+2TM+2T*"EMM9&I=(%-%0U522519.B!!9&0@9&5R969E<F5R
M('1O('-T<FEP(&]F9B!S97-S:6]N(&EN9F]R;6%T:6]N(&9R;VT@;&EN:W,@
M=&\*("`@("`@=&AE(&]U='-I9&4@;V8@=&AE($AO<F1E('-Y<W1E;2!T;R!P
M<F]T96-T(&%G86EN<W0@<V5S<VEO;B!H:6IA8VMI;F<N"EMM;7-=(%-%0U52
M2519.B!!9&0@8V]D92!T;R!P<F]T96-T(&%G86EN<W0@<V5S<VEO;B!F:7AA
M=&EO;B!I<W-U97,N"EMJ86Y=($9I>"!A(&)U9R!W:71H(&EM<&]R=&EN9R!V
M0V%R9"`R+C$@9&%T82X*6VIA;ET@061D($%R86)I8R`H4WER:6$I('1R86YS
M;&%T:6]N("A0;&%T:6YU;2!$979E;&]P;65N="!496%M"B`@("`@(#QD979T
M96%M0'!L871I;G5M+7-Y+FYE=#XI+@I;:F%N72!!9&0@36%C961O;FEA;B!T
M<F%N<VQA=&EO;B`H4W1O:F%N(%!E<V]V(#QS<W!`975R96MA+F-O;2YM:SXI
M+@I;;6ER72!&:7@@82!B=6<@=&AA="!I;F-O<G)E8W1L>2!Q=6]T97,@<')E
M9B!V86QU97,@*$)U9R`C,3(R-"D*6V-J:%T@1FEX(&$@8G5G('1H870@<')E
M=F5N=&5D(&QO9V=I;F<N"EMM;7-=($1"('-E<W-I;VX@:&%N9&QE<G,@9&\@
M;F]T('5S92!P97)S:7-T96YT(&-O;FYE8W1I;VYS(&)Y(&1E9F%U;'0N"@H*
M+2TM+2TM"G8R+C(N,PHM+2TM+2T*"EMM;7-=($9I>"!P87)S92!E<G)O<B!I
M;B!(;W)D95]#:7!H97)?0FQO8VM-;V1E7V]F8C8T.CHN"@H*+2TM+2TM"G8R
M+C(N,@HM+2TM+2T*"EMM;7-=($]P=&EM:7IA=&EO;B!O9B!396-R970Z.B!A
M;F0@2&]R9&5?0VEP:&5R.CH@9')I=F5R<RX*6VIA;ET@061D($-A=&%L86X@
M=')A;G-L871I;VX@*$%N9V5L<R!'=6EM97+@(#QA;F=E;',N1W5I;65R84!U
M86(N97,^*2X*6VUM<UT@061D960@82!2041)55,@075T:#HZ(&1R:79E<BX*
M6VUI<ET@061D960@82!386UB82!!=71H.CH@9')I=F5R+@I;8VIH72!!9&1E
M9"!T:&4@2&]R9&5?26UA9V4Z.B!C;&%S<RX*"@HM+2TM+2T*=C(N,BXQ"BTM
M+2TM+0H*6VIA;ET@1FEX(&EN8V]M<&%T:6)I;&ET>2!W:71H(%!(4"`\(#0N
M,BXP(&EN('1H92!344P@5D93(&1R:79E<BX*6VIA;ET@1FEX('5N9&5F:6YE
M9"!V87)I86)L92!I;B!#:7!H97(N<&AP("AC:F@I+@I;;6US72!#;VUP;&5T
M92!M97)G:6YG(&]F(%-13"!S97-S:6]N(&AA;F1L97(N"@H*+2TM+0IV,BXR
M"BTM+2T*"EMC:FA=($%D9"!S=7!P;W)T(&9O<B!U<V5R+61E9FEN960@<V5S
M<VEO;B!H86YD;&5R<PH@("`@("`H36EK92!#;V-H<F%N92`\;6EK94!G<F%F
M=&]N:&%L;"YC;RYN>CXI+@I;;6%C72!#:&%N9V4@4V5C<F5T.CH@9G)O;2!U
M<VEN9R!014%2($-R>7!T7TA#14U$-2!T;R!T:&4@2&]R9&5?0VEP:&5R(&-L
M87-S+@I;;6%C72!!9&0@2&]R9&5?0VEP:&5R.CH@8VQA<W,@=&\@<')O=FED
M92!A(&-O;6UO;B!A8G-T<F%C=&5D(&EN=&5R9F%C92!T;PH@("`@("!V87)I
M;W5S($-I<&AE<G,@9F]R(&5N8W)Y<'1I;VX@;V8@87)B:71R87)Y(&QE;F=T
M:"!P:65C97,@;V8@9&%T82X*6VUM<UT@0V]R<F5C=&QY(&=E="!C:&%R<V5T
M(&EN9F]R;6%T:6]N(&9O<B!-24U%7U!A<G1S(&EN($U)345?4W1R=6-T=7)E
M+@I;:F%N72!!9&0@3&%T=FEA;B!T<F%N<VQA=&EO;B`H2V%S<&%R<R!+87!E
M;FEE:W,@/&MA<W!A<G-`<F-C+FQV/BDN"EMJ86Y=($%D9"!2;VUA;FEA;B!T
M<F%N<VQA=&EO;B`H0V]R;F5L:74@3553050@/&-M=7-A=$!T:6%M870N:V5Y
M<WES+G)O/BDN"EMJ;VY=($%D9&5D('-U<'!O<G0@9F]R(&%N(#QE<F5F/B!E
M;G1I='D@=&\@=&AE(&AE;'`@<WES=&5M+B`@5&AI<R!A;&QO=W,@86X*("`@
M("`@97AT97)N86P@;&EN:R!T;R!B92!E;6)E9&1E9"!I;B!A(&AE;'`@96YT
M<GDN("@\9RYH;W)T0'5N<W<N961U+F%U/BD*6V-J:%T@4F5N86UE(%9&4SHZ
M('1O($AO<F1E7U9&4SHZ(&9O<B!014%2('!A8VMA9VEN9RX*6V-J:%T@5D93
M.CH@:7,@;F]W('!A8VMA9V5D('-O('1H870@:70@8V%N(&)E(&5X<&]R=&5D
M(&%S(&$@4$5!4B!C;VUP;VYE;G0N"EMC:FA=($%D9"!A(&UU;'1I+75S97(@
M4U%,(%9&4R!B86-K96YD("A-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH
M86QL+F-O+FYZ/BDN"EMC:FA=(%1H92!61E,@87!I(&YO=R!C;VYS:7-T96YT
M;'D@=&%K97,@82!T96UP(&9I;&4@:6X@=&AE('=R:71E*"D@;65T:&]D"B`@
M("`@(&%C<F]S<R!A;&P@8F%C:V5N9',@*$UI8VAA96P@5F%R9VAE<V4@/&UI
M:V4N=F%R9VAE<V5`87-C96QL871E8V@N8V]M/BDN"EMC:FA=($%D9"!A(%9&
M4R!!4$D@9F]R('-T;W)A9V4@;V8@9FEL97,@:6X@86X@86)S=')A8W1E9"!F
M:6QE<WES=&5M+@I;8VIH72!!9&0@82!P<F5F97)E;F-E('1O(&%L;&]W(&UA
M:6YT96YA;F-E(&]P<R!W:71H(&YO(&-O;F9I<FUA=&EO;B!S8W)E96X*6V-J
M:%T@4F5P;&%C92`G<VAO=R<@871T<FEB=71E(&EN('1H92!R96=I<W1R>2!W
M:71H(&$@;6]R92!F;&5X:6)L92`G<W1A=&4G"B`@("`@(&%T=')I8G5T92X*
M6VIA;ET@06QL;W<@<V5T=&EN9R!T:&4@;G5M8F5R(&]F(&-O;'5M;G,@:6X@
M=&AE('-U;6UA<GD@<V-R965N(&%S(&$@=7-E<@H@("`@("!P<F5F97)E;F-E
M("A"<FEA;B!+96EF97(@/&)R:6%N0'9A;&EN;W(N;F5T/BDN"EMC:FA=($%D
M9"!(;W)D93HZ9V5T1V5T*"D@86YD($AO<F1E.CIG9710;W-T*"DN"EMC:FA=
M($%D9"!A;B!I;FET:6%L7V%P<&QI8V%T:6]N('!R969E<F5N8V4@<V\@=7-E
M<G,@8V%N('-E;&5C="!A;B!A<'`*("`@("`@=&\@8F4@=&%K96X@=&\@:6YS
M=&5A9"!O9B!T:&4@2&]R9&4@4W5M;6%R>2!O;B!L;V=I;BX*6V-J:%T@36%K
M92!T97AT+"!I8V]N+"!O<B!B;W1H(&UE;G5S(&$@=7-E<B!P<F5F97)E;F-E
M"B`@("`@("A+86%L2"$@/&MA86QH0'-M;VPN;W)G/BDN"EMC:FA=($%D9"!A
M('!A<F%M971E<B!F;W(@<V5T=&EN9R!T:&4@<V5S<VEO;B!T:6UE;W5T+@I;
M8VIH72!!9&0@82!P87)A;65T97(@9F]R('-E='1I;F<@=&AE('-E<W-I;VX@
M9&5L:6UI=&5R+@I;;6US72!!9&0@34E-15]-86=I8SHZ9FEL96YA;654;TU)
M344H*2X*6VIA;ET@57-E(&%R9U]S97!A<F%T;W(N;W5T<'5T(&EN<W1E860@
M;V8@:&%R9&-O9&EN9R`G)B<@*$1A=FED(%5L979I=&-H"B`@("`@(#QD879I
M9'5`979E<GED;G,N;F5T/BDN"EMJ86Y=($%D9"!.;W1I9FEC871I;VXZ.F-O
M=6YT*"D@*$1A=FED(%5L979I=&-H(#QD879I9'5`979E<GED;G,N;F5T/BDN
M"EMC:FA=($%D9"!!=71H.CII<T%D;6EN*"DN"EMC:FA=($%L;&]W(&QO861I
M;F<@;V8@<W5B+6-L87-S97,@9G)O;2!S979E<F%L(&%D9&ET:6]N86P@<V]U
M<F-E<RX*6VIA;ET@4F5M;W9E(')E9F5R96YC97,@=&\@;F]T('EE="!R96QE
M87-E9"!A<'!L:6-A=&EO;G,@*$=O;&QE;2P@5')O;&PI+@I;8VIH72!297=R
M:71E($-A=&5G;W)Y7W-Q;"!I;7!L96UE;G1A=&EO;B!T;R!B92!M=6-H(&UO
M<F4@969F:6-I96YT+@I;:F%N72!!9&0@3&ET:'5A;FEA;B!T<F%N<VQA=&EO
M;B`H1&%R:75S($UA='5L:6%U<VMA<R`\9&%R:75S0&QN:RYL=#XI+@I;;6US
M72!!9&0@2&]R9&4Z.F-O;7!R97-S3W5T<'5T*"DN"EMM;7-=($%D9"!A(&ME
M<F)E<F]S($%U=&@Z.B!D<FEV97(N"EMJ86Y=($%D9"!"=6QG87)I86X@=')A
M;G-L871I;VX@*$UI<F]S;&%V(%!E;F1E=B`\<&5N9&5V0&AO=&UA:6PN8V]M
M/BDN"EMJ86Y=(%)E;6]V92!D97!R96-A=&5D($1".CII<U=A<FYI;F<H*2!C
M86QL<RX*6VUM<UT@061D($AO<F1E.CIC<F5A=&5496UP1&ER*"DN"EMC:FA=
M($%D9"!(;W)D93HZ=7-I;F=34TQ#;VYN96-T:6]N*"DN"EMC:FA=(%)E<&QA
M8V4@/#\]('=I=&@@/#]P:'`@96-H;R!T;R!R96UO=F4@=&AE('-H;W)T7V]P
M96Y?=&%G<R!R97%U:7)E;65N="X*6VIA;ET@061D(%1E>'0Z.G1O2%1-3"@I
M+"!497AT.CIH:6=H;&EG:'11=6]T97,H*2!A;F0@5&5X=#HZ9&EM4VEG;F%T
M=7)E*"DN"EMC:FA=($%D9"!296=I<W1R>3HZ;&ES=$%P<',H*2X*6V-J:%T@
M061D(%!R969S.CIG9710<F5F*"D@9F]R(&=E='1I;F<@<')E9F5R96YC97,@
M9F]R('-O;65O;F4@;W1H97(@=&AA;B!T:&4*("`@("`@;&]G9V5D+6EN('5S
M97(N"EMC:FA=($%D9"!T:&4@86)I;&ET>2!T;R!L;V%D(&ED96YT:71I97,@
M9F]R('-O;65O;F4@;W1H97(@=&AA;B!T:&4@;&]G9V5D+6EN"B`@("`@('5S
M97(N"EMM;7-=($%D9"!(;W)D93HZ<F5M;W9E4&%R86UE=&5R*"DN"EMM;7-=
M($%L;"!B<F]W<V5R(&AE861E<G,@9F]R(&1O=VYL;V%D:6YG(&$@9FEL92!H
M879E(&)E96X@;6]V960@=&\@=&AE"B`@("`@($)R;W=S97(Z.B!C;&%S<RX*
M6VIA;ET@061D(&1E=&5C=&EO;B!F;W(@551&(&-A<&%B:6QI='D@=&\@0G)O
M=W-E<B!C;&%S<RX*6VUM<UT@061D960@:6UA9V5S($U)345?5FEE=V5R+@I;
M8FIN72!!9&0@4&]S=&=R95-13"!C;VUM86YD(&9L86<@*%)I8VAA<F0@1R!+
M;VYL;VX@/%)'2V]N;&]N0#%-86EL4&QA8V4N8V]M/BDN"@H*+2TM+0IV,BXQ
M"BTM+2T*"EMJ86Y=($%D9"!(=6YG87)I86X@=')A;G-L871I;VX@*$QA<WIL
M;R!,+B!4;W)N;V-I(#QT;W)L87-Z0'AE;FEA+G-O=&4N:'4^*2X*6VIA;ET@
M061D($YO<G=E9VEA;B!.>6YO<G-K('1R86YS;&%T:6]N("A097(M4W1I86X@
M5F%T;F4@/'!S=D!O<G-T82YO<F<^*2X*6VIO;ET@36%J;W(@;W9E<FAA=6P@
M=&\@=&AE($Q$05`@<')E9F5R96YC97,@9')I=F5R+B!.;W1E('1H92!C:&%N
M9V5S('1O"B`@("`@(&-O;F9I9R]H;W)D92YP:'`@86YD('-C<FEP=',O;&1A
M<"]H;W)D92YS8VAE;6$@=VAE;B!U<&=R861I;F<N"EMJ86Y=($%D9"!3;&]V
M96YI86X@=')A;G-L871I;VX@*$IU<F4@2W)A<V]V:6,@/&IU<F5K0')C8RUI
M<F,N<VD^*2X*6V-J:%T@061D(&$@2&]R9&4@<')E9F5R96YC97,@<V-R965N
M+"!A;F0@82!P<F5F97)E;F-E('1O(')E9G)E<V@@=&AE('-U;6UA<GD*("`@
M("`@<V-R965N+@I;8VIH72!!9&0@=&5X="]E;G)I8VAE9"!-24U%7U9I97=E
M<@H@("`@("`H17)I8R!2;W-T971T97(@/&5R:6,N<F]S=&5T=&5R0'!H>7-I
M8W,N=71E>&%S+F5D=3XI+@I;:F%N72!);7!R;W9E(&QA;F=U86=E('-E;&5C
M=&EO;BX*6VIA;ET@061D($IA<&%N97-E('1R86YS;&%T:6]N("A"+DHN($)L
M86-K(#QW:6QL:6%M+F)L86-K0'-U;BYC;VT^*2X*6V-J:%T@0VQO<V4@82!P
M;W1E;G1I86P@<')O8FQE;2!W:71H(')E9VES=&5R7V=L;V)A;',@3VX@86YD
M("1J<U]O;DQO860N"EMJ86Y=($%D9"!0<F5F<SHZ:7-$969A=6QT*"D@;65T
M:&]D('1O(&1E=&5R;6EN92!I9B!A('!R969E<F5N8V4G<R!V86QU92!I<PH@
M("`@("!S970@8GD@=&AE('5S97(@;W(@=&AE(&1E9F%U;'0@=F%L=64@9G)O
M;2!P<F5F<RYP:'`N"EMJ;VY=($]V97)H875L960@3$1!4"!P<F5F97)E;F-E
M<R!D<FEV97(N"EMC:FA=($UA:V4@2&]R9&4Z.F1I<W!E;$UA9VEC475O=&5S
M*"D@<F5C=7)S:79E+"!S;R!T:&%T(&ET(&AA;F1L97,@87)R87ES+@I;8VIH
M72!(879E(%-E8W)E=#HZ<V5T2V5Y*"D@8VAE8VL@9F]R('1H92!S97-S:6]N
M(&-O;VMI92!E>'!L:6-I=&QY+"!T;R!A=F]I9`H@("`@("!P<F]B;&5M<R!W
M:71H(&]L9"!C;V]K:65S(&)E:6YG('-E;G0@=&\@82!S:71E('=H96X@=&AE
M>2!A<F4@<F5A;&QY"B`@("`@(&1I<V%B;&5D+@I;8VIH72!!9&0@82!0<F5F
M<U5)(&-L87-S(&9O<B!H86YD;&EN9R!T:&4@9F]R;2!P<F]C97-S:6YG(&%N
M9"!522!G96YE<F%T:6]N"B`@("`@(&9O<B!U<V5R('!R969E<F5N8V5S.R!T
M:&ES(&-O9&4@=V%S(&1U<&QI8V%T960@86QL('1H<F]U9V@@2&]R9&4N"EMC
M:FA=($%D9"!A(&UA<'!I;F<@9G5N8W1I;VX@=&\@=&AE(&5N<V-R:7!T(&1R
M:79E<B!W:&EC:"!M87!S(&9I;&4*("`@("`@97AT96YS:6]N<R!T;R!E;G-C
M<FEP="!L86YG=6%G92!C;V1E<RP@86YD('!A<W,@=&AE(&QA;F=U86=E"B`@
M("`@(&1I<F5C=&QY('1O(&5N<V-R:7!T+"!T;R!A=F]I9"!H879I;F<@=&\@
M=7-E(&$@9FEL92!E>'1E;G-I;VXN"EMC:FA=($9I>"!-24U%7TUA9VEC.CI-
M24U%5&]%>'0H*2!T;R!W;W)K('=I=&@@>"UE>'1E;G-I;VXO97AT('1Y<&5S
M+@I;8VIH72!!9&0@34E-15]-86=I8SHZ34E-151O17AT*"D@=&\@;6%P($U)
M344@='EP97,@=&\@9FEL92!E>'1E;G-I;VYS+@I;8VIH72!297=R:71E(%!E
M<FUS.CH@=&\@=7-E('1H92!#871E9V]R:65S(&)A8VME;F0N"EMJ86Y=($-H
M86YG92!T:&4@3F]R=V5G:6%N($)O:VUA;"!L;V-A;&4@9G)O;2!N;U]"3TL@
M=&\@;F)?3D\@86YD(&UA:V4@:70@=&AE"B`@("`@(&1E9F%U;'0@;&%N9W5A
M9V4@9F]R($YO<G=E9VEA;B!U<V5R<RX*6V-J:%T@36%K92!(;W)D92=S(&QO
M9VEN('-C<F5E;B!N:6-E<CL@:6YC;'5D92!R96%S;VYS(&EN(&ET+@I;8VIH
M72!5<V4@2$]21$5?5$5-4$Q!5$53(&9O<B!A;&P@=&5M<&QA=&4@<&%T:',N
M"EMC:FA=(%5S92`D<F5G:7-T<GDM/F=E="@I(&9O<B!A;&P@4F5G:7-T<GD@
M:6YF;W)M871I;VXN"EMC:FA=(%)E;6]V960@861M:6YI<W1R871I;VX@8V]D
M92!W:&EC:"!I<R!I;F-O;7!L971E(&%N9"!C;VYF=7-I;F<@=&\@=7-E<G,N
M"EMJ86Y=($%D9"!%<W1O;FEA;B!T<F%N<VQA=&EO;B`H5&]O;6%S($%A<R`\
M=&]O;6%S+F%A<T!R86%D+G1A<G1U+F5E/BDN"EMJ86Y=($%D9"!3;&]V86L@
M=')A;G-L871I;VX@*$QE;R!-<F%F:V\@/&QE;T!O96PN<VL^*2X*6VIO;ET@
M16YA8FQE('1H92`B<&]R=&%B:6QI='DB(&]P=&EO;B!I;B!T:&4@4$5!4B!$
M0B`H<W%L*2!D<FEV97)S+@I;8VIH72!5<V4@2&]R9&4G<R`G:6YI=&EA;%]P
M86=E)R!C;VYF:6=U<F%T:6]N('9A;'5E(&EN('1H92!(;W)D92!F<F%M97-E
M="X*6VIA;ET@061D(%!O<G1U9W5E<R!T<F%N<VQA=&EO;B`H3G5N;R!,;W5R
M96ER;R`\;G5N;T!E=&@N<'0^*2X*6VIA;ET@4F5B=6EL9"!T:&4@;&%N9W5A
M9V4@<V5L96-T:6]N(&QO9VEC+B!4:&4@;&%N9W5A9V4@<V5L96-T960@;VX@
M=&AE(&QO9VEN"B`@("`@('-C<F5E;B!I<R!N;W<@<F5S<&5C=&5D(&%N9"!T
M:&4@<VET92=S('-T86YD87)D(&QA;F=U86=E(&ES(&1E9FEN960@:6X*("`@
M("`@;&%N9RYP:'`@:6YS=&5A9"!O9B!E86-H(&%P<&QI8V%T:6]N)W,@<')E
M9F5R96YC97,N"EMJ86Y=($%D9"!J879A<V-R:7!T('1O('-E="!T:&4@9G)A
M;65S970G<R!P86=E('1I=&QE("A-:6-H865L($-O8VAR86YE"B`@("`@(#QM
M:6ME0&=R869T;VYH86QL+F-O+FYZ/BDN"EMJ86Y=($%D9"!5:W)A:6YI86X@
M=')A;G-L871I;VX@*$%N9')I>2!+;W!Y<W1Y86YS:WD@/&%N<FE`<&]L>6YE
M="YL=FEV+G5A/BDN"EMJ86Y=(%5P9&%T92!G971T97AT(&1O8W5M96YT871I
M;VX@86YD($UA:V5F:6QE<R!F;W(@4V]L87)I<R!A;F0@1&5B:6%N+@I;:F]N
M72!-86EN=&5N86YC92!F:7AE<R!F<F]M($UI8VAA96P@32!3;'5S87)Z(#QS
M;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/BX*6VIA;ET@061D($1A;FES
M:"!T<F%N<VQA=&EO;B`H36%R=&EN($QI<W0M4&5T97)S96X@/&UA<G1I;D!L
M:7-T+7!E=&5R<V5N+F1K/BDN"@H*+2TM+0IV,BXP"BTM+2T*"EMJ86Y=($%D
M9"!.;W)W96=I86X@0F]O:VUA;"!T<F%N<VQA=&EO;B`H3WES=&5I;B!3=&5I
M;6QE<B`\;WES=&5I;D!R97AT82YN970^*2X*6V%V<VU=($%D9"`N:'1A8V-E
M<W,@9FEL97,@=&\@9&5N>2!A8V-E<W,@=&\@9&%T82!D:7)E8W1O<FEE<RX*
M6VIA;ET@061D($9I;FYI<V@@=')A;G-L871I;VX@*$QE96YA($AE:6YO(#QL
M:6EN=4!U=&$N9FD^*2X*6V-J:%T@1FEX(&]N92!L87-T('!R;V)L96T@=VET
M:"!03U`S(&%N9"!M=6QT:7!A<G0O86QT97)N871I=F4@871T86-H;65N=',N
M"@H*+2TM+2TM+2T*=C(N,"U20S0*+2TM+2TM+2T*"EMR:6-H72!);F-L=61E
M(')E=W)I='1E;B!A;F0@<F5O<F=A;FEZ960@9&]C=6UE;G1A=&EO;BX*6V-J
M:%T@061D(&%N($U34&]W97)P;VEN="!-24U%7U9I97=E<BX*6VIA;ET@5&AE
M(&QA;F=U86=E(&-O;VMI92!W87,@<F5M;W9E9"!I;B!F879O<B!O9B!N97<@
M;65T:&]D<R!I;B!T:&4@3&%N9SHZ"B`@("`@(&-L87-S('1H870@<V5L96-T
M('1H92!L86YG=6%G92!A;F0@<V5T('1H92!G971T97AT(&1O;6%I;BX*6V%V
M<VU=($EN8VQU9&4@0VAO<F$@:6X@=&AI<R!R96QE87-E(&-Y8VQE+"!B=70@
M;F]T('-H;W=I;F<@:6X@=&AE('1O;VQB87(N"EMC:FA=($%D9"!-24U%7U9I
M97=E<E]Z:7`N"EMC:FA=(%1R:6T@<F5G:7-T<GDN<&AP+F1I<W0@=&\@;VYL
M>2!L:7-T(&%P<',@:6X@=&AI<R!R96QE87-E(&-Y8VQE+@I;:F%N72!!9&0@
M9&5L971E3V)J96-T*"D@;65T:&]D('1O('1H92!397-S:6]N0V%C:&4@8VQA
M<W,N"EMB:FY=($-H86YG92`G96XG(&%N9"`G96Y?14XG(&QO8V%L97,@=&\@
M)V5N7U53)R`H9&5F875L="DN"@H*+2TM+2TM+2T*=C(N,"U20S,*+2TM+2TM
M+2T*"EMC:FA=(%)E8V]G;FEZ92!A(&9E=R!086QM+FYE="!B<F]W<V5R<R!A
M;F0@<V5T('%U:7)K<R]F96%T=7)E<R!A8V-O<F1I;F=L>2X*6V-J:%T@4W5P
M<&]R="!F;W(@861D:6YG(&%N9"!L:7-T:6YG($Q$05`@=7-E<G,@9VEV96X@
M82!S970@<V-H96UA+@I;8VIH72!3970@=&AE('-E<W-I;VX@8V]O:VEE('!A
M<F%M971E<G,@=VET:"!O=7(@8V]O:VEE7W!A=&@O8V]O:VEE7V1O;6%I;@H@
M("`@("!S971T:6YG<RX@5&AI<R!M96%N<R!T:&%T('EO=2!C86X@8F4@;&]G
M9V5D(&EN=&\@;75L=&EP;&4@2&]R9&4*("`@("`@:6YS=&%L;&%T:6]N<R!O
M;B!T:&4@<V%M92!S97)V97(@*&1I9F9E<F5N="!P871H<RD@86YD(&YO="!H
M879E('1H90H@("`@("!S97-S:6]N<R!I;G1E<F9E<F4N"EMC:FA=(%5S92`G
M:&]S='-P96,G(&-O;G-I<W1E;G1L>2!I;B!!=71H(&1R:79E<G,N"@H*+2TM
M+2TM+2T*=C(N,"U20S$*+2TM+2TM+2T*"EMJ86Y=($%D9"!"<F%Z:6QI86X@
M4&]R='5G=65S92!T<F%N<VQA=&EO;B`H0V%R;&]S($1A;FEE;"!+:6)R:70@
M/&MI8G)I=$!T97)R82YC;VTN8G(^*2X*6VIA;ET@061D($=R965K('1R86YS
M;&%T:6]N("A3=&5F86YO<R!)+B!$:6UI=')I;W4@/'-D:6UI=')I0'1E:6%T
M:"YG<CXI+@I;:F%N72!!9&0@=D-A<F0@34E-12!D<FEV97(N($-H86YG960@
M8V]N9FEG+VUI;65?9')I=F5R<RYP:'`N9&ES="X*6VIA;ET@061D(%-W961I
M<V@@=')A;G-L871I;VX@*$%N9')E87,@1&%H;.EN(#QA;F1R96%S0&1A:&QE
M;BYW<SXI+@I;:F%N72!!9&0@2V]R96%N('1R86YS;&%T:6]N("A*+DD@2VEM
M(#QA<&]R:65`;F5T:6%N+F-O;3XI+@H*"BTM+2TM+0IV,2XS+C4*+2TM+2TM
M"@I;:F]N72!!9&1E9"`D9FEL92!A;F0@)&QI;F4@<&%R86UE=&5R<R!T;R!(
M;W)D93HZ9F%T86PH*2X*6VIO;ET@4F5M;W9E9"!T:&4@4%)%1E-?*B!A;F0@
M05542%\J(&-O;G-T86YT<R!I;B!F879O<B!O9B!014%27T5R<F]R(&]B:F5C
M=',N"EMA=G-M72!$;VXG="!D97!E;F0@;VX@=&AE(')E9VES=')Y(&)E:6YG
M(&%V86EL86)L92!W:&5N(&1I<W!L87EI;F<*("`@("`@=&AE("=(;W)D92!I
M<R!N;W0@8V]N9FEG=7)E9"<@;65S<V%G92X*6V-J:%T@0VQE86X@=7`@=&AE
M($ED96YT:71Y(&-L87-S('1O(&)E(&$@9V5N97)A;&EZ960L(&-L96%N('!I
M96-E(&]F('1H90H@("`@("!F<F%M97=O<FL@=&AA="!C86X@8F4@=7-E9"!I
M;B!O=&AE<B!A<'!S(&%N9"!S=6)C;&%S<V5D(&EF(&YE8V5S<V%R>2X*6V-J
M:%T@36%K92!F86EL=7)E('1O(&-O;FYE8W0@=&\@=&AE('!R969E<F5N8V5S
M(&1A=&%S;W5R8V4@82!F871A;"!E<G)O<BX*6V-J:%T@061D960@=&AE(%-E
M<FEA;&EZ93HZ(&-L87-S(&9O<B!V87)I;W5S(&UE=&AO9',@;V8@96YC87!S
M=6QA=&EN9R!D871A"B`@("`@("AS=&5P:"`\<VAU=&AE<D!Y86AO;RYF<CXI
M+@I;8VIH72!!9&1E9"!T:&4@8V%P86)I;&ET>2!T;R!G970@875T:&5N=&EC
M871I;VX@8W)E9&5N=&EA;',@;W1H97(@=&AA;@H@("`@("!U<V5R;F%M92!B
M86-K(&9R;VT@=&AE($%U=&@@9G)A;65W;W)K+"!A;F0@8V]M<&QE=&5D('1H
M90H@("`@("!A=71H96YT:6-A=&EO;B!R96%L;2!F=6YC=&EO;F%L:71Y+@I;
M:F]N72!!;&QO=R!T:&4@=&%B;&4@8V5L;"!A;F0@;&EN:R!#4U,@8VQA<W-E
M<R!T;R!B92!S<&5C:69I960@=VAE;B!C<F5A=&EN9PH@("`@("!M96YU(&ET
M96US+@I;:F%N72!!9&0@<F5G:7-T<GD@;65T:&]D(&9O<B!L:6YK:6YG('1O
M(&$@;F%G('1A<VLN"EMJ86Y=($%D9"!I9&5N=&ET>2!C;&%S<RX*6VUA>%T@
M061D(%)E9VES=')Y.CIG971.86UE*"D@9F]R('%U97)Y:6YG(&%P<&QI8V%T
M:6]N(&YA;65S+@I;8VIH72!(;W)D92!N;W<@<')O=FED97,@=&AE($AO<F1E
M.CIL;V=-97-S86=E*"D@;65T:&]D(&9O<B!L;V=G:6YG(&]F"B`@("`@(&EN
M9F]R;6%T:6]N(&%C8V]R9&EN9R!T;R!C;VYF:6=U<F%B;&4@<')I;W)I=&EE
M<RP@971C+@I;:F%N72!!9&0@9G5N8W1I;VYA;&ET>2!T;R!M87`@9&%T92!A
M;F0@=&EM92!F:65L9',@=&\@=&AE($1A=&$@8VQA<W,N"EMC:FA=($%D9"!T
M:&4@8F5G:6YN:6YG<R!O9B!A('5S97(@861M:6YI<W1R871I;VX@<WES=&5M
M+@I;8VIH72!!9&0@0VAI;F5S92`H5')A9&ET:6]N86PI('1R86YS;&%T:6]N
M("A$879I9"!#:&%N9PH@("`@("`\9&%V:61`=&AB=6\N9V]V+G1W/BDN"EMJ
M86Y=($%D9"!)=&%L:6%N('1R86YS;&%T:6]N("A':6]V86YN:2!-96YE9VAE
M='1I(#QG;65N96=H971T:4!I;F9V:6,N:70^*2X*6VIA;ET@061D($1A=&$@
M8VQA<W,@9F]R(&EM<&]R=&EN9R!A;F0@97AP;W)T:6YG(&1A=&$N"EMJ;VY=
M($-L96%N960@=7`@=&AE(&AE;'`@<WES=&5M(&$@8FET+@I;8VIH72!!9&0@
M2&]R9&4Z.F9A=&%L*"D@9F]R(&1I<W!L87EI;F<@4$5!4E]%<G)O<B!O8FIE
M8W1S(&%N9"!A8F]R=&EN9RX*6V%V<VU=($5X=&5N9"!(;W)D93HZ9V5T5&5M
M<$9I;&4H*2!T;R!A;&QO=R!D:7)E8W1O<GD@=&\@8F4@;W9E<G)I9&1E;BX*
M6V%V<VU=($%L;&]W('1E;7!O<F%R>2!F:6QE<R!T;R!B92!U;G)E9VES=&5R
M960@9G)O;2!D96QE=&EO;BX*6V%V<VU=($%D9"!A($-A8VAE(&9R86UE=V]R
M:R!F;W(@<&5R<VES=&5N=&QY('-T;W)I;F<@;V)J96-T<RP@86QO;F<*("`@
M("`@('=I=&@@82!F:6QE<WES=&5M(&1R:79E<BX*6VIA;ET@061D(%!O;&ES
M:"!T<F%N<VQA=&EO;BX*6V-J:%T@1FEX(&$@<')O8FQE;2!W:71H("1R96=I
M<W1R>2T^8V%L;"@I(&%N9"!S=VET8VAI;F<@87!P;&EC871I;VX*("`@("`@
M8V]N=&5X=',N"EMC:FA=($=E="!R:60@;V8@=&AE(&EN=F]K92@I(&UE=&AO
M9',@:6X@=&AE(')E9VES=')Y+@I;8VIH72!$;VXG="!R92UI;F-L=61E(&%P
M<&QI8V%T:6]N(&-O;F9I9R!F:6QE<SL@<V%V92!C;VYF:6=S(&EN(&$@8V%C
M:&4@<V\*("`@("`@=&AA="!W92!C86X@:G5S="!P;VEN="`D1TQ/0D%,4ULG
M8V]N9B==(&%T('1H92!O;&0@8V]N9FEG(&]N"B`@("`@("1R96=I<W1R>2T^
M<&]P07!P*"DL(&5T8RX*6VIA;ET@061D($9R96YC:"!T<F%N<VQA=&EO;B`H
M1G)E9&5R:6,@5')U9&5A=2`\9G1R=61E875`0T%-+D]21SXI+@I;8VIH72!!
M9&0@0WIE8V@@=')A;G-L871I;VX@*'!C:'ET:6Q`87-P+F]G:2YE9'4I+@I;
M:F%N72!!9&0@;F5W('1I;65Z;VYE(&AA;F1L:6YG('=I=&@@8VQE87)T97AT
M('1I;65Z;VYE(&YA;65S(&EN(&QA;F<N<&AP+@I;8VIH72!!9&0@4G5S<VEA
M;B!T<F%N<VQA=&EO;B`H26=N870@26MR>6%N;W8@/&EG;F%T0&EB9"YR=3XI
M+@I;:F]N72!.97<@;65T:&]D<R!I;B!"<F]W<V5R+G!H<"!F;W(@<F5T<FEE
M=FEN9R!V97)S:6]N<RX@/&EZ>GE`<75M<F%N+F]R9SX*6VIO;ET@0G)O=W-E
M<BYP:'`@;F]W(&1E=&5C=',@3W!E<F$N(#QI>GIY0'%U;7)A;BYO<F<^"EMC
M:FA=($UO=F4@=&AE(&QA;F=U86=E(&%N9"!C:&%R<V5T(&1E9F%U;'1S(&EN
M=&\@8V]N9FEG+VQA;F<N<&AP+"!A;F0@861D(&$*("`@("`@4F5G:7-T<GD@
M;65T:&]D('1O(&=E="!T:&4@8W5R<F5N="!C:&%R<V5T+@I;8VIH72!-87`@
M8G)O=W-E<B!C;V1E<R!S=6-H(&%S("=N;"<@=&\@=&AE(&9U;&P@8V]D92`H
M)VYL7TY,)RP@971C+BDN"EMA=G-M72!297!L86-E("1C;VYF6R=P871H<R==
M('=I=&@@=&AE("1R96=I<W1R>2!E<75I=F%L96YT<RX*6V%V<VU=($%D9"!F
M;W5R(')E9VES=')Y(&9U;F-T:6]N<R!T;R!Q=65R>2!W96)R;V]T<R!A;F0@
M<&%T:',N"EMA=G-M72!-86YY($U)345?5FEE=V5R(&-H86YG97,Z($%022!T
M=V5A:W,L(&YE=R!D<FEV97)S+"!W;W)K<R!W:71H($E-4"X*6V-J:%T@)&-O
M;F9;)W5S97(G75LG;VYL:6YE7VAE;'`G72!I<R!N;W<@82!(;W)D92UL979E
M;"!S971T:6YG+@I;879S;5T@16YA8FQE(&%P<&QI8V%T:6]N<R!T;R!H879E
M(&QO8V%L($U)345?5FEE=V5R(&1R:79E<G,@:6X@861D:71I;VX*("`@("`@
M('1O('1H92!G;&]B86P@2&]R9&4@;VYE<RX*6V%V<VU=(%-H=69F;&4@87)O
M=6YD('1H92!-24U%7U9I97=E<B!!4$DZ(&=E=$1R:79E<B@I(&ES(&YO=R!P
M<FEV871E"EMA=G-M72!!9&0@86X@)VEN:71I86Q?<&%G92<@;W!T:6]N('1O
M('1H92!R96=I<W1R>2P@=&\@;&5T('5S(&QI;FL@:6YT;PH@("`@("!A;GD@
M<&%G92!I;G-I9&4@86X@87!P;&EC871I;VXN"EMC:FA=($%D9"!A(&9R86UE
M=V]R:RUL979E;"!B87-E+G!H<"!F:6QE(&%N9"!M86ME(&9R86UE=V]R:R!S
M8W)I<'1S('5S92!I="X*6V-J:%T@061D(')E+6]R9V%N:7IE9"!B=70@<W1I
M;&P@;6]S=&QY(&]U="!O9B!D871E($A%3%`O3$E35%,O4T]54D-%(&9I;&5S
M"B`@("`@("A*;W-H($UI;&QE<B`\:F]S:&QI<W1S0&YE8F]N970N8V]M/BDN
M"EMC:FA=($%D9"!A('!A<F%M971E<B!T:&%T(&1E=&5R;6EN97,@=VAE=&AE
M<B!O<B!N;W0@87!P<R!A<F4@;&EN:V5D(&]N('1H90H@("`@("!(;W)D92!M
M96YU8F%R+@I;8VIH72!#;&5A<B!T:&4@=VAO;&4@<V5S<VEO;B!W:&5N('1H
M92!U<V5R(&QO9W,@;W5T(&]F($AO<F1E+@I;:F]N72!!9&1E9"!0<F5F<SHZ
M:7-%;7!T>2@I(&9O<B!D971E<FUI;FEN9R!W:&5T:&5R(&$@<')E9F5R96YC
M92!I<R!E;7!T>2X*6VIO;ET@061D960@86X@)&]N8VQI8VL@<&%R86UE=&5R
M('1O($AO<F1E.CIL:6YK*"D@9F]R('-P96-I9GEI;F<@86X@86YC:&]R)W,*
M("`@("`@)V]N8VQI8VLG($IA=F%38W)I<'0@979E;G0N"EMC:FA=(%5S92!T
M:&4@*G5R;"@I(&9U;F-T:6]N<R!M;W)E(&-O;G-I<W1E;G1L>2!T;R!M86ME
M('-U<F4@=&AA=`H@("`@("!C;V]K:64M;&5S<R!S97-S:6]N<R!W;W)K+@I;
M8VIH72!-;V1I9GD@8W-S+G!H<"!T;R!U<V4@=&AE(%)E9VES=')Y('1O(&=E
M="!A<'!L:6-A=&EO;B!F:6QE('!A=&AS+@I;8VIH72!!9&0@8V]O:VEE7W!A
M=&@@86YD(&-O;VMI95]D;VUA:6X@<V5T=&EN9W,@9F]R('!E;W!L92!W:&\@
M:V5E<"!A<'!S"B`@("`@(&]U='-I9&4@;V8@=&AE($AO<F1E('=E8G)O;W0@
M;W(@;VX@;75L=&EP;&4@<V5R=F5R<RX*"@HM+2TM+2T*=C$N,RXT"BTM+2TM
M+0H*6V-J:%T@061D(&$@2&]R9&4@<W5M;6%R>2!F<F%M97=O<FLL('=H:6-H
M('5S97,@=&AE(%)E9VES=')Y('1O(&=E=`H@("`@("!S=6UM87)I97,@;V8@
M879A:6QA8FQE(&1A=&$@+2!T87-K<RP@979E;G1S+"!E=&,N("T@9F]R('1H
M92!(;W)D90H@("`@("!L;V=I;B!S8W)E96XN"EMC:FA=(%1H92!P<F5F97)E
M;F-E<R!S971T:6YG<R!S:&]U;&0@8F4@2&]R9&4M=VED92P@86YD('-O(&AA
M=F4@8F5E;B!M;W9E9"!T;PH@("`@("!H;W)D92]C;VYF:6<O:&]R9&4N<&AP
M+@I;8VIH72!-;W9E('!R969S+F=I9B!A;F0@9V5N97)I8R!P<F5F<R!T96UP
M;&%T97,@:6YT;R!(;W)D92X*6V-J:%T@36]V92!S971T:6YG(&]F('1H92!G
M971T97AT(&1O;6%I;B!I;G1O('1H92!296=I<W1R>2X*6VIO;ET@4VEM<&QI
M9FEE9"!T:&4@<')E9F5R96YC92!S>7-T96TG<R!C;&5A;G5P(&9U;F-T:6]N
M<RX*6VIO;ET@365R9V4@9&]C='EP92YI;F,@:6YT;R!C;VUM;VXM:&5A9&5R
M+FEN8RX*6VIO;ET@061D960@5&5X=#HZ:'1M;'-P86-E<R@I(&%N9"!497AT
M.CIH=&UL86QL<W!A8V5S*"DN"EMC:FA=($%D9"!A;B!O<'1I;VX@=&\@2&]R
M9&4Z.F=E=%1E;7!&:6QE*"D@=&\@;F]T(&1E;&5T92!T:&4@9FEL92!A="!T
M:&4*("`@("`@96YD(&]F('1H92!R97%U97-T+@I;8VIH72!!9&0@82`F<VEN
M9VQE=&]N*"D@;65T:&]D('1O('1H92!296=I<W1R>2!C;&%S<RX*6VIO;ET@
M061D960@3F%G(&EN=&5R9F%C92!T;R!T:&4@<F5G:7-T<GDN"EMJ;VY=($5X
M<&%N9&5D('1H92!R96=I<W1R>2!T;R!H86YD;&4@:6UP;W)T:6YG(&%P<&QI
M8V%T:6]N+7-P96-I9FEC"B`@("`@(&-O;F9I9W5R871I;VX@=F%L=65S+@I;
M;6%X72!!9&0@875T:"]L;V=I;B!A;F0@875T:"]L;V=O=70@;W!T:6]N<R!F
M;W(@1V]L;&5M(&EN('1H92!R96=I<W1R>2X*6VUA>%T@061D(%)E9VES=')Y
M.CIG971-971H;V0@9G5N8W1I;VXN"EMM87A=($%D9"!C;VYT86-T<R]S;W5R
M8V5S('-E<G9I8V4@=&\@=&AE(')E9VES=')Y+@I;8VIH72!296YA;64@=&AE
M($-O;FYE8W1I;VX@8VQA<W-E<R!T;R!4;VME;BX*6V-J:%T@4F5N86UE('1H
M92!/8FIE8W13=&]R92!C;&%S<R!T;R!397-S:6]N0V%C:&4N"EMJ;VY=($%D
M9&EN9R!$=71C:"!L86YG=6%G92X*6V%V<VU=($%D9"!I8V]N('-U<'!O<G0@
M=&\@=&AE($U)345?5FEE=V5R(&9R86UE=V]R:PI;879S;5T@57!D871E('1H
M92!-24U%7U9I97=E<B!!4$D@=&\@:6YC;'5D92!G971$<FEV97(H*2!A;F0@
M9V5T26-O;B@I"EMJ;VY=($]V97)H875L960@=&AE('!R969E<F5N8V5S(&-A
M8VAI;F<@<WES=&5M(&$@8FET+@I;8VIH72!5<&1A=&4@0G)O=W-E<CHZ('1O
M(')E8V]G;FEZ92!)138N"EMJ;VY=($%D9&5D($AO<F1E+7=I9&4@86YD(&1R
M:79E<BUS<&5C:69I8R!C;&5A;G5P(&UE=&AO9',@=&\@=&AE('!R969E<F5N
M8V5S"B`@("`@('-Y<W1E;2X*6V-J:%T@4F5M;W9E('1H92!S=')T;VQO=V5R
M*"D@9G)O;2!,86YG.CIS96QE8W0H*2!W:&EC:"!W87,@<')E=F5N=&EN9PH@
M("`@("!P<F]P97(@;&]C86QE(&YA;65S("AL:6ME('!T7T)2*2!F<F]M('=O
M<FMI;F<@8V]R<F5C=&QY+@I;;6%X72!!9&1E9"!A=71H96YT:6-A=&EO;B!H
M86YD;&5R('1O('1H92!296=I<W1R>2X*6VIO;ET@5&AE("=S97-S:6]N)R!P
M<F5F97)E;F-E<R!D<FEV97(@;F]W(&AO;F]R<R!P<F5F97)E;F-E('-C;W!E
M+@I;;6%X72!-861E('-I=&5N86UE('1I=&QE(&-O;F9I9W5R86)L92X*6VIO
M;ET@4F5W;W)K960@=&AE($UE;G4Z.F-U<W1O;4ET96TH*2!T;R!A8V-E<'0@
M4$A0(&1A=&$@<W1R=6-T=7)E<R!I;G-T96%D"B`@("`@(&]F(&$@<W1R:6YG
M(&]F(&5N8V]D960@<&%R86UE=&5R<RX*6V%V<VU=($%D9&5D($U)345?5FEE
M=V5R(&9R86UE=V]R:R!T;R!H86YD;&4@<F5N9&5R:6YG(&9I;&5S(&EN=&\@
M2%1-3`H@("`@("`@*&%N9"!O=&AE<BD@9F]R;6%T<R!I;B!A('5S97(M97AT
M96YS:6)L92!F87-H:6]N("AE>'!E<FEM96YT86PI"EMA=G-M72!.97<@34E-
M15]-86=I8R!A;F0@;6EM95]M87!P:6YG+G!H<"!C;VYF:6<@9FEL92`H97AP
M97)I;65N=&%L*0I;879S;5T@5'=O(&YE=R!T96UP;W)A<GD@9FEL92!H86YD
M;&EN9R!F=6YC=&EO;G,L($AO<F1E.CIG971496UP1FEL92@I(&%N9`H@("`@
M("!(;W)D93HZ9V5T5&5M<$1I<B@I('1O('1A:V4@8V%R92!O9B!T:&4@:&]U
M<V5K965P:6YG(&]F('1E;7`@9FEL97,N"EMM87A=($%D9&5D(&-O;G1A8W1S
M+V%D9"!S97)V:6-E('1O(')E9VES=')Y+@I;8VIH72!296=I<W1R>3HZ8V%L
M;"@I(&ES(&YO=R!296=I<W1R>3HZ;&EN:R@I+B!4:&5R92!I<R!A(&YE=PH@
M("`@("!296=I<W1R>3HZ8V%L;"@I('=H:6-H(&%C='5A;&QY(')E='5R;G,@
M=&AE(')E<W5L="!O9B!A(&9U;F-T:6]N(&-A;&P*("`@("`@;6%D92!T;R!A
M;F]T:&5R(&%P<&QI8V%T:6]N+@I;8VIH72!&:7@@1$(@<75E<GD@<F5S=6QT
M(&-H96-K:6YG(&EN('-Q;"!D<FEV97)S+@I;8VIH72!&:7@@:&5L<"!S;R!T
M:&%T(&=E;F5R:6,@:&5L<"!L:6YK<R`H;VX@;65N=2!B87)S*2!S:&]W('1H
M92!T;W!I8R!L:7-T"B`@("`@(&-O<G)E8W1L>2X*6V-J:%T@36%K92!T:&4@
M;&]G:6X@9F]R;2!N:6-E<BP@86YD(&%D9"!A(&QO9V]U="!L:6YK+@I;8VIH
M72!-86ME('-U<F4@86QL(&]F('1H92!S<6P@9')I=F5R<R!U<V4@1$(Z.G%U
M;W1E4W1R:6YG*"D@;VX@86QL('-T<FEN9W,N"EMC:FA=(%)E<&QA8V4@82!`
M;7ES<6Q?<75E<GDH*2!T:&%T('=A<R!H:61I;F<@:6X@0V]N;F5C=&EO;B]S
M<6PN<&AP('=I=&@*("`@("`@)'1H:7,M/F1B+3YQ=65R>2@I+@I;8VIH72!2
M971U<FX@8F%S96YA;64H)&QA;F=U86=E*2!F<F]M($QA;F<Z.E-E;&5C="@I
M('1O(&%V;VED('!O<W-I8FQE"B`@("`@(&5X<&QO:71S+@I;8VIH72!!9&0@
M4F5G:7-T<GDZ.FAA<TUE=&AO9"@I(&9O<B!C:&5C:VEN9R!I9B!A('!I96-E
M(&]F(&9U;F-T:6]N86QI='D@:&%S"B`@("`@(&)E96X@<F5G:7-T97)E9"!W
M:71H($AO<F1E+@I;:F]N72!!;F]T:&5R(&QA<F=E(&]V97)H875L('1O('1H
M92!P<F5F97)E;F-E<R!S>7-T96TN("!.;W1E('1H870@=&AE"B`@("`@(&ES
M0VAA;F=E86)L92@I(&9U;F-T:6]N(&AA<R!B965N(')E;F%M960@:7-,;V-K
M960H*2X@(%1H97)E(&ES(&%L<V\*("`@("`@<W5P<&]R="!F;W(@<')E9F5R
M96YC92!S8V]P92`H=FEA(&ES4VAA<F5D*"D@86YD('-E=%-H87)E9"@I*2X*
M6VIO;ET@061D960@8V%P86EB;&ET>2!T97-T<R!T;R!T:&]S92!D<FEV97)S
M('1H870@<F5Q=6ER92!N;VXM<W1A;F1A<F0@4$A0"B`@("`@(&5X=&5N<VEO
M;G,@*&AA;F1L960@8GD@2&]R9&4Z.F9U;F-T:6]N0VAE8VLH*2DN"EMJ;VY=
M($%D9&5D(&%N($%U=&A?3$1!4"!(;W)D92!A=71H96YT:6-A=&EO;B!D<FEV
M97(N"EMC:FA=($%D9"!L:71T;&4@<VYI<'!E="UT96UP;&%T97,@9F]R(&1Y
M;F%M:6-A;&QY(&)U:6QD:6YG('!R969E<F5N8V4@1U5)<RX*6V-J:%T@4F5N
M86UE('1H92!!=71H(&EN=&5R9F%C92=S(&%U=&@H*2!M971H;V0@=&\@875T
M:&5N=&EC871E*"D@=&\@879O:60*("`@("`@;W9E<FQA<'!I;F<@=&AE(&YA
M;64@;V8@=&AE(&-O;G-T<G5C=&]R(&9O<B!T:&4@075T:"!P87)E;G0@8VQA
M<W,N"EMC:FA=(%1H92!C;VYF:6=U<F%T:6]N(&%R<F%Y(&ES(&YO=R!S:6UP
M;'D@)&-O;F8N($%N>2!S971T:6YG<R!T:&%T(&UU<W0@8F4*("`@("`@86-C
M97-S:6)L92!U;F-H86YG960@*&YO="!O=F5R<FED9&5N*2!S:&]U;&0@8F4@
M<'5T(&EN=&\@)&-O;F9;)VAO<F1E)UTN"B`@("`@($5V97)Y=&AI;F<@96QS
M92!I<R!F86ER(&=A;64@9F]R(&%P<&QI8V%T:6]N<R!T;R!O=F5R<FED92X*
M6V-J:%T@061D(&$@=VUL+W=A<"!L;V=I;B!F;W)M+@I;;6%X72!!9&0@86X@
M075T:%]&5%`@2&]R9&4@875T:&5N=&EC871I;VX@9')I=F5R+@I;8VIH72!!
M9&0@86X@075T:%]-0T%,($AO<F1E(&%U=&AE;G1I8V%T:6]N(&1R:79E<BX*
M6V-J:%T@5&AE($AO<F1E(&QO9VEN(&9O<FT@;F]W(&%C='5A;&QY(&1O97,@
M<V]M971H:6YG+B!,;V=G:6YG(&EN('1O(&ET"B`@("`@(&=E=',@>6]U(&$@
M=&]K96X@:6X@>6]U<B!S97-S:6]N('-A>6EN9R!T:&%T('EO=2=V92!A=71H
M96YT:6-A=&5D(&%N9`H@("`@("!W:&\@>6]U(&%R92X@07!P<R!C86X@=&AE
M;B!U<V4@=&AI<R!I;F9O<FUA=&EO;B!T;R!A;&QO=R!O<B!D96YY"B`@("`@
M(&%C8V5S<RP@86YD('1O(&ED96YT:69Y('5S97)S+@I;8VIH72!4:&4@9F]R
M;6%T(&]F('1H92!C;VYF:6<O<F5G:7-T<GDN<&AP(&9I;&4@:&%S(&-H86YG
M960@9')A<W1I8V%L;'D@=&\*("`@("`@8F4@;6]R92!R96%D86)L92!A;F0@
M;&5S<R!I;F1I<F5C="X@5&AE<F4@:7,@86QS;R!A(&YE=R!A<'`@<&%R86UE
M=&5R+`H@("`@("`G86QL;W=?9W5E<W1S)RP@=VAI8V@@9&5F:6YE<R!W:&5T
M:&5R(&]R(&YO="!A('5S97(@:7,@86QL;W=E9"!T;PH@("`@("!A8V-E<W,@
M=&AE(&%P<&QI8V%T:6]N('=I=&AO=70@;&]G9VEN9R!I;B!T;R!(;W)D92X*
M6V-J:%T@5&AE($%U=&@Z.B!C;&%S<V5S(&YO=R!E>'!E8W0@=&\@<F5C96EV
M92!A('5S97)I9"!A;F0@86X@87)R87D@;V8*("`@("`@8W)E9&5N=&EA;',N
M(%)I9VAT(&YO=R!A;&P@8F%C:V5N9',@87-S=6UE('1H870@=&AO<V4@8W)E
M9&5N=&EA;',*("`@("`@8V]N=&%I;B!A('!A<W-W;W)D+"!B=70@=&AE('=A
M>2!I<R!C;&5A<B!T;R!H879E(&]T:&5R(&MI;F1S(&]F(&%U=&@*("`@("`@
M*$E0+"!T:6UE+6)A<V5D+"!W:&%T979E<BDN"EMJ;VY=($%D9&5D(&$@;F5W
M('!A<F%M971E<B!T;R!T:&4@3$1!4"!P<F5F97)E;F-E<R!D<FEV97(Z("=A
M;'=A>7-?8FEN9"<N"EMC:FA=($%D9&5D(&$@365N=3HZ(&-L87-S('1H870@
M86QL(&UO9'5L97,@8V%N('5S92!T;R!G96YE<F%T92!M96YU(&ET96US+@I;
M:F]N72!#;&5A;F5D('5P('1H92!,1$%0('!R969E<F5N8V5S(&1R:79E<B!A
M(&)I="X*6VIO;ET@061D960@<V5S<VEO;BUL979E;"!P<F5F97)E;F-E<R!C
M86-H:6YG('1O('1H92!P<F5F97)E;F-E<R!S>7-T96TN"EMC:FA=($AA=F4@
M2&]R9&4Z.FQI;FLH*2!M86ME('-U<F4@=&AA="!T:&4@<W1A='5S('1E>'0@
M:7,@<V%F92!F;W(*("`@("`@:F%V87-C<FEP="`H:'1M;&5N=&ET:65S+"!A
M9&1S;&%S:&5S*2X*6V-J:%T@1FEX($]B:F5C=%-T;W)E('1O('=O<FL@=VAE
M;B!R96=I<W1E<E]G;&]B86QS(#T@3VXN"EMJ;VY=($%D9&5D(&$@4V5S<VEO
M;BUB87-E9"!P<F5F97)E;F-E<R!D<FEV97(N"@H*+2TM+2TM"G8Q+C,N,PHM
M+2TM+2T*"EMC:FA=($9U<G1H97(@<F5V86UP('1H92!-24U%(&EN=&5R9F%C
M92X@0F4@8V]N<VES=&5N="!I;B!C87!I=&%L:7IA=&EO;@H@("`@("`H86-R
M;VYY;7,@87)E(&-A<&ET86QI>F5D*2P@8G)E86L@;W5T($U)345?4W1R=6-T
M=7)E(&%N9"!-24U%7TUE<W-A9V4*("`@("`@:6YT;R!S97!E<F%T92!F:6QE
M<RP@86YD('!U="!A;&P@;65T:&]D<R!I;G1O(&-L87-S97,N"EMC:FA=($%D
M9"!(;W)D93HZ9V5T1F]R;41A=&$H*2!T;R!F971C:"!A('9A<FEA8FQE(&9R
M;VT@96ET:&5R"B`@("`@("1(5%107U!/4U1?5D%24R!O<B`D2%144%]'151?
M5D%24R`H86YD('1O(&-L96%N(&UA9VEC('%U;W1E<RP@:68*("`@("`@;F5C
M97-S87)Y*2X*6V-J:%T@4F5M;W9E('1H92!,;V<Z.B!C;&%S<RX@5&AI<R!I
M<R!P87)T(&]F(%!%05(@;F]W+@I;8VIH72!!9&0@82!397-S:6]N0V%C:&4Z
M.B!C;&%S<RX@5&AI<R!I<R!I;G1E;F1E9"!F;W(@<W1O<FEN9R!O8FIE8W1S
M(&EN"B`@("`@('1H92!S97-S:6]N(&EN=&5N9&5D(&9O<B!N96%R+71E<FT@
M=7-E+"!A;F0@=VEL;"!C=7)R96YT;'D@<W1A<G0*("`@("`@=&AR;W=I;F<@
M;W5T(&]B:F5C=',@=VAE;B!M;W)E('1H86X@,C`@87)E('!U="!I;BX@5&AI
M<R!W:6QL(&AO<&5F=6QL>0H@("`@("!K965P(&%N>2!O;F4@<V5S<VEO;B!F
M<F]M(&=R;W=I;F<@=&]O(&QA<F=E+@I;8VIH72!5<V4@=&AE(&YE=R!014%2
M(&-L87-S($UA:6Q?<F9C.#(R.CH@=&\@<&%R<V4@861D<F5S<R!L:7-T<RP@
M<V\@=&AA=`H@("`@("!W92!G970@<F9C(#@R,B!G<F]U<"!S=7!P;W)T("AM
M>2UB=61D:65S.B!J;VY`:&]R9&4L;W)G+`H@("`@("!M87A`:&]R9&4N;W)G
M.RDL('=H:6-H(&EM87!?<F9C.#(R7W!A<G-E7V%D<FQI<W0H*2!D;V5S;B=T
M(&AA=F4N"EMM87A=($UA:V4@2&]R9&4@6$A434P@,2XP(&-O;7!L:6%N="X*
M6V-J:%T@061D(&$@9F5W(&9I96QD<R!T;R!T:&4@<')O8FQE;2!R97!O<G0@
M86YD('1R>2!T;R!M86ME(&ET(&UO<F4@9G)I96YD;'DN"EMC:FA=($9L97-H
M(&]U="!T:&4@36EM93HZ(&-L87-S+@I;8VIH72!-;W9E('1R:6U%;6%I;$%D
M9')E<W,H*2!I;G1O('1H92!N97<@36EM93HZ(&-L87-S+@I;8VIH72!-;W9E
M('-E=%]E;G9?:6Y?<W1R:6YG*"D@=&\@5&5X=#HZ97AP86YD16YV:7)O;FUE
M;G0H*2X*6V-J:%T@4F5N86UE(&AO<F1E7V-L96%N=7`H*2!T;R!?9FEL94-L
M96%N=7`H*2X*6V-J:%T@5&AE('IL:6(@;6]D=6QE(&YO=R!S=7!P;&EE<R!A
M(&=Z96YC;V1E*"D@9G5N8W1I;VX@=&AA="!O8G-O;&5T97,*("`@("`@2%14
M4%]#86-H93HZ9WI%;F-O9&4H*2X*6V-J:%T@36]D:69Y($AO<F1E.CIU<FPH
M*2!S;R!T:&%T(&ET(&1E9F%U;'1S("1C;VYF6R=U<V5?<W-L)UT@=&\@,@H@
M("`@("`H875T;RUD971E8W0@8W5R<F5N="!M;V1E*2X*6V-J:%T@36]D97)N
M:7IE('-O;64@;V8@=&AE($AO<F1E(&9R;VYT96YD("AS=&EL;"!L;W1S('1O
M(&1O(&AE<F4I.R!G970@<FED"B`@("`@(&]F('!A8VMA9V4N2%1-3$1O8W5M
M96YT+G!H<"!O;F-E(&%N9"!F;W(@86QL+@I;879S;5T@0G)E86MD;W=N(&%L
M;"!S<&5C:6%L(&-H87)A8W1E<G,@:6X@55),<R!T;R!E;G1I=&EE<RP@=&\@
M879O:60*("`@("`@86UB:6=U:71Y(&EN(&AO=R!V87)I;W5S(&)R;W=S97)S
M('!A<G-E('1H96TN"EMC:FA=($%D9"!(;W)D93HZ<F%I<V5-97-S86=E*"D@
M9F]R(&-R96%T:6YG($AO<F1E(&UE<W-A9V5S('1O(&)E(&1I<W!L87EE9`H@
M("`@("!T;R!T:&4@=7-E<BX*6V-J:%T@4V]M92!G96YE<F%L(%5)('1W96%K
M<R`M(&9O;G0@<VEZ92P@971C+@I;8VIH72!296UO=F4@<F9C9&%T92@I(&EN
M(&9A=F]R(&]F('1H92!N97<@)W(G('!A<F%M971E<B!T;R!D871E+@I;8VIH
M72!!9&1E9"!A<'!L:6-A=&EO;B`G=V5B<F]O="<@86YD("=F:6QE<F]O="<@
M<')O<&5R=&EE<R!T;R!T:&4@<F5G:7-T<GD*("`@("`@8V]N9FEG(&9I;&4N
M(%1H97-E(&%L;&]W(&UO<F4@9FQE>&EB:6QI='D@:6X@<&QA8VEN9R!A<'!S
M+"!A;F0@;&5T('1H90H@("`@("!R96=I<W1R>2!W;W)K(&9R;VT@;6]R92!P
M;&%C97,N"EMC:FA=($UO=F5D('!A8VMA9V4N4F5G:7-T<GDN<&AP('1O(%)E
M9VES=')Y+G!H<"X*6V-J:%T@0V]M;65N=&5D(&-O;F9I9R]H;W)D92YP:'`N
M9&ES="!H96%V:6QY+@I;8VIH72!!9&0@82!396-R970Z.B!C;&%S<R!T;R!(
M;W)D92YP:'`@=&AA="!P<F]V:61E<R!A('1R86YS<&%R96YT"B`@("`@(&EN
M=&5R9F%C92!T;R!E:71H97(@=&AE(&UC<GEP="!E>'1E;G-I;VX@*'!R969E
M<G)E9"D@;W(@=&AE(%!%05(*("`@("`@0W)Y<'1?2$-%340U.CH@8VQA<W,N
M"EMJ;VY=($%C8V5P="!A('5S97(M9&5F:6YE9"!F=6YC=&EO;B!F;W(@<&5R
M9F]R;6EN9R!U<V5R;F%M92!L;V]K=7!S(&EN('1H90H@("`@("!P<F5F97)E
M;F-E<R!C;V1E+B`@5&AE('!R969E<F5N8V5S(&-O;G-T<G5C=&]R(&QO;VMS
M(&9O<B!T:&4@9G5N8W1I;VX*("`@("`@:6X@)'!A<F%M<ULG=7-E<E]H;V]K
M)UTN"EMC:FA=($-H96-K($A45%!?14Y67U9!4E,@9F]R('1H92!U<V5R+6%G
M96YT(&%S('=E;&P@87,@2%144%]315)615)?5D%24RX*6V-J:%T@4F5M;W9E
M(&UA:6QF<F]M*"D@:6X@9F%V;W(@;V8@=&AE(%!%05(@36%I;#HZ(&EN=&5R
M9F%C92X@061J=7-T('1H90H@("`@("!C;VYF(&9I;&5S(&%N9"!P<F]B;&5M
M+G!H<"!A8V-O<F1I;F=L>2X*6V-J:%T@061D(&$@<V5T(&]F(&EN=F]K92@I
M(&UE=&AO9',@=&\@=&AE(%)E9VES=')Y.CH@8VQA<W,@9F]R(&1I<F5C=&QY
M"B`@("`@(&EN=F]K:6YG('-E<G9I8V5S("AI92P@86-T=6%L;'D@<&]P<&EN
M9R!U<"!A('=I;F1O=RD@:6YS=&5A9"!O9@H@("`@("!P<FEN=&EN9R!L:6YK
M<R!T;R!I;G9O:V4@=&AE;2X*6V-J:%T@0VQE86X@=7`@<&%C:V%G92Y-:6UE
M+G!H<"!A(&)I=#L@9&]N)W0@<V5T(&$@8VAA<G-E="!O;B!-24U%('!A<G1S
M"B`@("`@('1H870@87)E;B=T('1E>'0N"EMC:FA=($%D9&5D(&$@9FEL92!D
M<FEV97(@9F]R('1H92!#;VYN96-T:6]N.CH@8VQA<W,N"EMC:FA=($%D9&5D
M(&$@5T%0(&EN9&5X('1O('!R;W9I9&4@<75I8VL@;&EN:W,@=&\@86QL($AO
M<F1E('=I<F5L97-S('!A9V5S+@I;8VIH72!!9&0@8F%S:6,@5T%0(&)R;W=S
M97(@9&5T96-T:6]N('1O($)R;W=S97(Z.BX@0W5R<F5N=&QY('1H:7,@:7,@
M;V8@=&AE"B`@("`@(")I="!D971E8W1S('1H92!P:&]N92!)(&AA=F4@86YD
M('1H92!S:6UU;&%T;W(@22!U<V4B('9A<FEE='D[(&ET(&ES"B`@("`@(%]V
M97)Y7R!F87(@9G)O;2!C;VUP;&5T92X*6V-J:%T@061D960@36%X($MA;&EK
M82=S($-O;FYE8W1I;VXZ.B!C;&%S<R!F;W(@8V]N;F5C=&EO;B!T<F%C:VEN
M9RX*6V-J:%T@2%144%]#86-H93HZ(&YO=R!C;VUP<F5S<V5S(&-O;G1E;G0@
M=VET:&]U="!T:&4@=7-E(&]F(&$@=&5M<"!F:6QE+@I;8VIH72!&;&5S:&5D
M(&]U="!T:&4@075T:#HZ(&-L87-S('=I=&@@=&AE(&%B:6QI='D@=&\@8V%C
M:&4@875T:&]R:7IA=&EO;@H@("`@("!I;B!T:&4@<V5S<VEO;BX*6VIO;ET@
M4F5M;W9E9"!T:&4@<V-R:7!T960@=V]R9'=R87`@:6X@9F%V;W(@;V8@=&AE
M(&YA=&EV92!F=6YC=&EO;BX@($UO=F5D"B`@("`@('1H92!W<F%P7VUE<W-A
M9V4H*2!F=6YC=&EO;B!T;R!497AT.CIW<F%P*"DN"EMJ;VY=(%-T86YD87)D
M:7IE(&]N('1H92!R9F-D871E*"D@9G5N8W1I;VX@:6X@;&EB+TAO<F1E+G!H
M<"X*6V-J:%T@5&AE('!R969S(&1R:79E<G,@;F]W(&5X<&5C="`D<&%R86US
M6R=H;W-T<W!E8R==+"!F;W(@8V]N<VES=&5N8WD@=VET:`H@("`@("!014%2
M+@I;8VIH72!4:&4@4$5!4B!S<6P@<')E9G,@9')I=F5R(&YO=R!W;W)K<RX*
M6V-J:%T@36]V92!H;W)D92!C;VYF:6=U<F%T:6]N('9A;'5E<R!T:&%T('-H
M;W5L9"!N;W0@8F4@;W9E<G)I9&1E9"!B>0H@("`@("!M;V1U;&5S(&EN=&\@
M)&AO<F1E6R=H;W)D92==6UT@=&\@86QL;W<@;6]D=6QE<R!T;R!D;PH@("`@
M("!O=F5R<FED:6YG+VEN:&5R:71A;F-E(&]F(&]T:&5R(&]P=&EO;G,N"EMC
M:FA=($%D9"!T:&4@2%144%]#86-H93HZ(&-L87-S('1O($AO<F1E+G!H<"!F
M;W(@151A9R!G96YE<F%T:6]N+"!G>FEP"B`@("`@(&-O;7!R97-S:6]N(&]F
M(&AT='`@8V]N=&5N="P@971C+@I;8VIH72!297!L86-E("1H;W)D95LG;&]C
M86QH;W-T)UT@=VET:"`D2%144%]315)615)?5D%24ULG4T525D527TY!344G
M72X*6V-J:%T@4F5J96-T(&]U=')I9VAT(&5N=F5L;W!E($9R;VT@861D<F5S
M<V5S('=I=&@@<W!A8V5S(&EN('1H96TN"EMC:FA=(%%U;W1E('1H92!F<F]M
M(&%D9')E<W,@<&%S<V5D('1O('-E;F1M86EL('1O('!R979E;G0@<VAE;&P@
M97AP;&]I=',N"EMC:FA=(%5P9&%T92!"<F]W<V5R+G!H<"!T;R!U<V4@2%14
M4%]315)615)?5D%24RP@8V]N<V]L:61A=&4@=&AE(&IA=F%S8W)I<'0*("`@
M("`@=F5R<VEO;B!I;F9O<FUA=&EO;BP@86YD(&%D9"!S<VQ?9&]W;FQO861?
M:&%C:R!F;W(@8G)O=W-E<G,@=&AA="!N965D"B`@("`@(&1O=VYL;V%D<R!T
M;R!B92!C86-H96%B;&4N"EMJ;VY=($%D9"!497AT.CIF:6QT97(@=&\@;&EB
M+TAO<F1E+G!H<"X*6V-J:%T@0VAE8VL@=&AE(')E='5R;B!V86QU92!O9B!P
M8VQO<V4H*2!C;W)R96-T;'D@:6X@;6%I;&9R;VTH*2X*6VIO;ET@4V5C=7)I
M='D@9FEX(&9O<B`D9G)O;2!V86QU92!I;B!M86EL9G)O;2@I+B`\8W=`8V]C
M+6%G+FYE=#X*6VIO;ET@4VEL96YC92!S97-S:6]N7W-T87)T('=A<FYI;F=S
M+@I;:F]N72!!9&1E9"!N97<@?&5X=')A?"!S=6)S=&ET=71I;VX@=&\@8V]N
M9FEG+W)E9VES=')Y+G!H<"!F;W(@97AT<F$L"B`@("`@(&YO;BUS=&%N9&%R
M9"!P87)A;65T97(@<&%S<VEN9RX*6VIO;ET@4F5M;W9E(&)U:6QD55),*"DN
M("!)="=S(&)E96X@<F5P;&%C960@8GD@2&]R9&4Z.G5R;"@I+@I;:F]N72!2
M97-T<G5C='5R960@=&AE(%-13"!P<F5F97)E;F-E<R!S8VAE;6$N"EMC:FA=
M($%D9&5D("1H;W)D95LG<V5S<VEO;E]N86UE)UT@=&\@8V]N=')O;"!T:&4@
M<V5S<VEO;B!N86UE(&=L;V)A;&QY+@I;8VIH72!397-S:6]N.CH@9&]E<VXG
M="!R96%L;'D@8G5Y('5S(&%N>71H:6YG+"!S;R!W92=V92!M;W9E9"!T:&4@
M=71I;&ET>0H@("`@("!M971H;V1S('1H870@9&\@:6YT;R!(;W)D93HZ+"!A
M;F0@87)E(&IU<W0@=7-I;F<@<&AP-"!S97-S:6]N(&-A;&QS"B`@("`@(&5L
M<V5W:&5R92X*6V-J:%T@061D960@=&AE(&)E9VEN;FEN9W,@;V8@57-E<B!A
M;F0@075T:"!I;G1E<F9A8V5S+"!W:71H(&$@8F%R92UB;VYE<PH@("`@("!W
M;W)K:6YG($%U=&A?<W%L(&EM<&QE;65N=&%T:6]N+@I;:F]N72!297=R;W1E
M('1H92!397-S:6]N(&-L87-S(&9O<B!I;G-T86YT:6%T:6]N('=I=&@@:&]O
M:W,@9F]R"B`@("`@('5S97(M9&5F:6YE9"!S97-S:6]N(&AA;F1L97)S+@I;
M8VIH72!4:&4@8F%R92UB;VYE<R!I;7!L96UE;G1A=&EO;B!O9B!T:&4@4&5R
M;7,@<V-H96UE+"!W:71H(&$@<W%L(&1R:79E<BP*("`@("`@=V]R:W,N($EF
M('EO=2!P87-S(&ET(&$@9G5L;"!P871H(&ET('=I;&P@=')A=F5R<V4@=7`@
M:70L(')E='5R;FEN9PH@("`@("!T:&4@9FER<W0@<&5R;6ES<VEO;B!I="!F
M:6YD<RX*6VIO;ET@36]V960@=&AE(&QA;F=U86=E(&AA;F1L:6YG(&9U;F-T
M:6]N<R!I;B!(;W)D92YP:'`@:6YT;R!T:&5I<B!O=VX*("`@("`@8VQA<W-E
M9"!N86UE9"!,86YG+@I;8VIH72!-;W)E(&-O;G-I<W1E;G0O8W-S+6)A<V5D
M(&QO;VL@9F]R('1H92!H96QP('-Y<W1E;2X*6V-J:%T@4W1A<G1I;F<@=&\@
M<F5M;W9E(&%L;"!U<V5S(&]F(&-A;&PM=&EM92!P87-S+6)Y+7)E9F5R96YC
M92X*6V-J:%T@061D960@8W-S+G!H<"!F;W(@875T;VUA9VEC86P@9V5N97)A
M=&EO;B!O9B!S='EL97-H965T<R!F;W(@87!P<RX*6VIO;ET@4')O;6]T960@
M=&AE(%=E8D-L:65N="!C;&%S<R!F<F]M(&QI8B](;W)D92YP:'`@=&\@:71S
M(&]W;B!C;VUP;VYE;G0*("`@("`@;F%M960@0G)O=W-E<BYP:'`N"EMC:FA=
M(%5S92!W;W)D=W)A<"!I;B!A('-L:6=H=&QY(&1I9F9E<F5N="!W87DL('=H
M:6-H('-E96US('1O('!R;V1U8V4@;75C:`H@("`@("!P<F5T=&EE<B!Q=6]T
M:6YG(&]F(&UE<W-A9V5S+@I;:F]N72!!9&1E9"!0<F5F<R]M>7-Q;"YP:'`@
M9')I=F5R(&9R;VT@36%X($MA;&EK82`\;6%X0'1H92UT<FEU;79I<F%T92YN
M970^+@I;:F]N72!.97<@6$U,+6)A<V5D(&AE;'`@<W5B<WES=&5M+@I;8VIH
M72!296YA;65D('!A8VMA9V4N:&]R9&4N<&AP('1O($AO<F1E+G!H<"X*6V-J
M:%T@061D(&EM9R@I(&%N9"!P:6UG*"D@9G5N8W1I;VYS('1O('1H92!(;W)D
M93HZ(&-L87-S('-O('1H870@;6]D=6QE<PH@("`@("!U<VEN9R!O;FQY('-T
M>6QE<VAE971S(&1O;B=T(&YE960@=&AE($A434Q$;V-U;65N="!P86-K86=E
M+@I;8VIH72!/;6ET('1H92!S97-S:6]N(&YA;64O:60@9G)O;2!T:&4@55),
M(&EF('=E(&-A;B!V97)I9GD@=&AA="!C;V]K:65S"B`@("`@(&%R92!B96EN
M9R!A8V-E<'1E9"X*6VIO;ET@3F5W('=R87!?;65S<V%G92!F=6YC=&EO;B!T
M:&%T('5S97,@=&AE(&YA=&EV92!W;W)D=W)A<"!F=6YC=&EO;B!I9B!I=`H@
M("`@("!E>&ES=',N"EMJ;VY=(%5P9&%T:6YG(&AE861E<B!C;VUM96YT(&-O
M<'ER:6=H="!I;F9O<FUA=&EO;BX*6VIO;ET@4F5P;W)T(&UO9'5L92!V97)S
M:6]N<R!I;B!T97-T+G!H<"!O=71P=70N"EMC:FA=(&UI;65?96YC87!S=6QA
M=&4H*2!N;W<@=7-E<R!A;B!A<G)A>2!I;G-T96%D(&]F(&%N(&]B:F5C="X*
M6VIO;ET@4F5M;W9E9"!T:&4@)%]H=&UL6R=C;VUP;W-E*B==('-I>FEN9R!P
M87)A;65T97)S(&9R;VT@8V]N9FEG+VAT;6PN<&AP+@I;8VIH72!,96%V92!"
M8V,Z(&]U="!O9B!T:&4@:&5A9&5R<R!T:&%T(&%R92!P87-S960@=&\@<V5N
M9&UA:6PN"EMJ;VY=(%)E=W)I=&4@82!G;V]D('!O<G1I;VX@;V8@=&AE('-C
M<FEP=',O<V5T7W!E<FUS+G-H('-C<FEP="!S;PH@("`@("!T:&%T(&ET(&5N
M9F]R8V5S(&%N(&5X=')E;65L>2!H:6=H(&QE=F5L(&]F('-E8W5R:71Y+@I;
M8VIH72!4:&4@=F%L:61?;&%N9R@I(&9U;F-T:6]N(&YO=R!R97%U:7)E<R`D
M;FQS6R=L86YG=6%G97,G75L\;&%N9W5A9V4^70H@("`@("!T;R!B92!S970@
M9F]R(&$@;&%N9W5A9V4@=&\@8F4@8V]N<VED97)E9"!V86QI9"`H:6YS=&5A
M9"!O9B!J=7-T('1H90H@("`@("!L;V-A;&4@9&ER96-T;W)Y(&5X:7-T:6YG
M*2X*6V-J:%T@061D960@82`F<VEN9VQE=&]N*"D@;65T:&]D('1O(&UA:V4@
M:70@96%S:65R('1O(&]N;'D@8W)E871E(&]N92!L;V<*("`@("`@:6YS=&%N
M8V4L(&YO(&UA='1E<B!W:&5N('EO=2!N965D(&ET+@I;8VIH72!.;W<@;6%I
M;&9R;VTH*2!W;W)K<R!F;W(@<F5C:7!I96YT(&%D9')E<W-E<R!W:71H('-I
M;F=L92!Q=6]T97,@;W(*("`@("`@;W1H97(@8VAA<F%C=&5R<R!T:&%T(&YE
M960@=&\@8F4@97-C87!E9"!I;B!T:&5M+@I;8VIH72!,;V<@8VQA<W,@;F]W
M(&AA<R!A;B!M8V%L(&EN<W1A;F-E+"!A(&-O;7!O<VET92`H9F]R(&=R;W5P
M:6YG(&UU;'1I<&QE"B`@("`@(&QO9R!B86-K96YD<RDL(&%N9"!O8G-E<G9E
M<G,@<F5G:7-T97(@=&AE(&QE=F5L(&]F(&5V96YT<R!T:&5Y('=A;G0@=&\*
M("`@("`@:&5A<B!A8F]U="P@86YD(&]N;'D@9V5T(&YO=&EF:65D(&]F(&5V
M96YT<R!A<R!I;7!O<G1A;G0@;W(@;6]R90H@("`@("!I;7!O<G1A;G0@=&AA
M;B!T:&%T(&QE=F5L+@I;8VIH72!!9&1E9"!A($QO9SHZ(&9R86UE=V]R:R!A
M;F0@<WES;&]G(&EM<&QE;65N=&%T:6]N+"!I;F-L=61I;F<@80H@("`@("!,
M;V=?;V)S97)V97(@8VQA<W,@:6YT96YD960@=&\@<VET(&]N('1O<"!O9B!,
M;V(@;V)J96-T<R!A;F0@=&%K90H@("`@("!A8W1I;VX@:6X@97AC97!T:6]N
M86P@8VER8W5M<W1A;F-E<RX*6V-J:%T@36%K92!S=7)E('1O(&%L=V%Y<R!S
M96YD(&$@8VAA<G-E="!W:71H(&5M86EL<RX*6V-J:%T@26UP<F]V960@=&AE
M(&UI;65?9&5C;V1E*"D@86YD(&UI;65?96YC;V1E*"D@9G5N8W1I;VYS+@I;
M8VIH72!5<&1A=&5D('1E<W0N<&AP('1O(')E8V]G;FEZ92!P:'`T('-T86)L
M92!R96QE87-E<RX*6VIO;ET@4F5M;W9E9"!A;&P@;V8@=&AE(&QO8V%L92\J
M+FQA;F<@9&5P96YD96YC:65S+@I;:F]N72!!<W-U;64@=&AE(&)R;W=S97(@
M:7,@9G)A;65S+6-A<&%B;&4@8GD@9&5F875L="X*6V-J:%T@061D(&AO<F1E
M7V-L96%N=7`H)&9I;&5N86UE*2P@=VAI8V@@=&%K97,@8V%R92!O9B!D96QE
M=&EN9R!F:6QE<R!T:&%T"B`@("`@('-H;W5L9"!B92!U;FQI;FME9"!R96=A
M<F1L97-S(&]F('=H971H97(@;W(@;F]T('1H92!R97%U97-T(&ES"B`@("`@
M(&-A;F-E;&5D(&)Y('1H92!U<V5R(&)E9F]R92!W92!F:6YI<V@@97AE8W5T
M:6YG+@I;8VIH72!296UO=F4@<&AP;&EB(&1E<&5N9&%N8WD@:6X@9F%V;W(@
M;V8@<&AP-"!S97-S:6]N<R]014%2+@I;8VIH72!297!L86-E('5S92!W:71H
M(')E<75I<F5?;VYC92X*6V-J:%T@1FEX960@=7`@<V5L96-T7VQA;F<H*2!T
M;R!W;W)K("AI9&5N=&EC86P@=&\@,2XR(&YO=RD*6V-J:%T@2&]R9&4@:7,@
M;F]W('5N9&5R('1H92!,1U!,+@I;8VIH72!&:7@@;6%I;&9R;VTH*2!S;R!I
M="!D;V5S;B=T('-E;F0@97AT<F$@:&5A9&5R<R!W:&5N('5S:6YG(&UA:6PH
M*0I;8VIH72!!9&1I;F<@82`G;6%R9VEN<R<@871T<FEB=71E('1O($A434Q$
M;V-U;65N="!T;R!E;F%B;&4@='5R;FEN9R!O9F8*("`@("`@9&]C=6UE;G0@
M;6%R9VEN<RX*"@HM+2TM+2T*=C$N,RXR"BTM+2TM+0H*6V-J:%T@4F5P;&%C
M960@;6]D=6QE+EA-3%]21$8N<&AP('=I=&@@82!W;W)K:6YG(&-O<'DN"@H*
M+2TM+2TM"G8Q+C,N,0HM+2TM+2T*"EMC:FA=(%)E=F%M<&5D('1H92!-:6UE
M365S<V%G92!C;&%S<R!T;R!B92!M=6-H('-M86QL97(@86YD('-I;7!L97(N
M"EMC:FA=(%)E<&QA8V5D('1H92!-:6UE4&%R=$1A=&$@8VQA<W,@=VET:"!A
M('-E="!O9B!F=6YC=&EO;G,@=&AA="!M;W)E"B`@("`@(&-L96%N;'D@86YD
M(&-O<G)E8W1L>2!I;7!L96UE;G0@=&AE($U)344@<W1A;F1A<F0N"EMC:FA=
M('-E;&5C=%]L86YG*"D@;F]W(&-H96-K<R!F;W(@96X@=VAE;B!T:&4@8G)O
M=W-E<B!R97%U97-T<R!E;E]'0BP@971C+@I;8VIH72!297!L86-E9"!A;&P@
M8V%L;',@=&\@97)E9RH@9G5N8W1I;VYS('=I=&@@<')E9RH@9G5N8W1I;VYS
M+"!F;W(@<W!E960N"B`@("`@($)E8V%U<V4@;V8@=&AI<R!W92!N;W<@<F5Q
M=6ER92!P:'`@,RXP+C$R(&]R(&QA=&5R+@H*"BTM+2TM+0IV,2XS+C`*+2TM
M+2TM"@I;("`@72!'97)M86X@=7!D871E9`I;("`@72!&:7AE9"!T:&4@8G)O
M:V5N("=B86-K)R!L:6YK(&EN('-E='5P+G!H<#,@9F]R(&YO;BU%;F=L:7-H
M('5S97)S"EL@("!=(&UA;F%G97(N<&AP,RP@9&(N;&EB+"!A;F0@8V]H;W)T
M<R!A<F4@;F]W(&=O;F4N(%1H97D@=V5R92!A;&P@=6YM86EN=&%I;F5D+"!O
M=70@;V8@9&%T92P@86YD(&YO="!V97)Y('5S969U;"X*("`@("`@5F%R:6]U
M<R!B=6EL9"!S8W)I<'1S(&%R92!U<&1A=&5D('1O(')E9FQE8W0@=&AI<RX*
M6VIO;ET@4F5M;W9E9"!C;VYF:6<O9&5F875L=',N<&AP,R!I;B!P<F5F97)E
M;F-E(&]F(&AO<F1E+G!H<#,*6R`@(%T@1FEX960@82!S971U<"YP:'`S(&)U
M9R!W:&5R92`B('=A<R!U<V5D(&EN<W1E860@;V8@)R!F;W(@)&1E9F%U;'0@
M=F%L=65S("AM:6ME*0I;("`@72!.97<@1FEN;FES:"!T<F%N<VQA=&EO;G,@
M*%1H86YK<R!T;SH@;&5O+FIA87-K96QA:6YE;D!K;VQU;6)U<RYF:2D*6R`@
M(%T@1FEX960@;'EN>"!S=7!P;W)T(&ES<W5E('=I=&@@;&]G:6XN<&AP,PI;
M("`@72!&:7AE9"!S:6=N=7`N<&AP,R!P<F]B;&5M<PI;("`@72!&:7AE9"!P
M<F]B;&5M+G!H<#,@<')O8FQE;7,@*&QY;G@@<W5P<&]R="D*6R`@(%T@061D
M960@9&%T86)A<V4@8W)E871I;VX@<V-R:7!T<R!F;W(@8G5I;&1I;F<@<&AP
M;&EB(&-O;7!L:6%N('1A8FQE<PI;("`@72!-;W9E9"!A;&P@9&]C=6UE;G1A
M=&EO;B`H97AC97!T(%)%041-12!A;F0@0T]064E.1RD@:6YT;R!D;V-S+R!S
M=6)D:7(*6R`@(%T@061D960@82!C86-H:6YG(&-L87-S('-O('1H870@8V%C
M:&EN9R!C86X@8F4@='5R;F5D(&]N('!E<B!P86=E(&EF(&YE961E9`H*"BTM
M+2TM+0IV,2XQ+C$*+2TM+2TM"@I;("`@72!(;W)D92!U;F1E<G-T86YD<R!&
M<F5N8V@@*'1H86YK<R!T;R!-871H:65U($-L86)A=70*("`@("`@/&-L86)A
M=6QT0&UU;'1I;6%N:6$N8V]M/BD*6R`@(%T@36%J;W(@9G)A;65S970@<F5D
M97-I9VX*6R`@(%T@075T;R!R96=I<W1R871I;VXO8V]N9VER=6%T:6]N(&]F
M(&UO9'5L97,*"@HM+2TM+2T*=C$N,"XS"BTM+2TM+0H*6R`@(%T@2&]R9&4@
M:7,@;F]W('=E8B!S=7)F86)L92X*6R`@(%T@2&]R9&4@:&%N9&QE<R!L>6YX
M("AP<V5U9&]L>2D*6R`@(%T@17AT96YD86)L92!M96YU<RX@*&UE;G4N='AT
M(&EN(&AO<F1E+V-O;F9I9RD*6R`@(%T@4VEG;G5P+"!P<F]B;&5M(')E<&]R
M=&EN9RP@:&5L<"!F=6YC=&EO;G,@87)E(&YO=R!P87)T(&]F(&AO<F1E"@``
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]D;V-S+T-/1$E.1U]35$%.
M1$%21%,`````````````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#8Q
M-3`V`#$P-3$U-#,S-S0S`#`R,3$P-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*
M($AO<F1E($-O9&EN9R!3=&%N9&%R9',*/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]"@HZ3&%S="!U<&1A=&4Z("`@)$1A=&4Z(#(P,#8O,#,O,3<@,#8Z,3@Z
M,#<@)`HZ4F5V:7-I;VXZ("`@("`@)%)E=FES:6]N.B`Q+C@T+C$P+C$U("0*
M.D%U=&AO<G,Z("`@("`@($IO;B!087)I<V4L($-H=6-K($AA9V5N8G5C:`HZ
M0V]N=&%C=#H@("`@("`@9&5V0&QI<W1S+FAO<F1E+F]R9PH*+BX@8V]N=&5N
M=',Z.B!#;VYT96YT<PHN+B!S96-T:6]N+6YU;6)E<FEN9SHZ"@I);F1E;G1I
M;F<*/3T]/3T]/3T]"@I5<V4@86X@:6YD96YT(&]F(#0@<W!A8V5S+"!W:71H
M(&YO('1A8G,N"@H*0V]N=')O;"!3=')U8W1U<F5S"CT]/3T]/3T]/3T]/3T]
M/3T]/0H*5&AE<V4@:6YC;'5D92!@8&EF8&`L(&!@9F]R8&`L(&!@=VAI;&5@
M8"P@8&!S=VET8VA@8"P@971C+B`@2&5R92!I<R!A;B!E>&%M<&QE"F!@:69@
M8"!S=&%T96UE;G0L('-I;F-E(&ET(&ES('1H92!M;W-T(&-O;7!L:6-A=&5D
M(&]F('1H96TZ.@H*("!I9B`H*&-O;F1I=&EO;C$I('Q\("AC;VYD:71I;VXR
M*2D@>PH@("`@("!A8W1I;VXQ.PH@('T@96QS96EF("@H8V]N9&ET:6]N,RD@
M)B8@*&-O;F1I=&EO;C0I*2!["B`@("`@(&%C=&EO;C(["B`@?2!E;'-E('L*
M("`@("`@9&5F875L=&%C=&EO;CL*("!]"@I-=6QT:2UL:6YE(&EF(&-O;F1I
M=&EO;G,@87)E(&)R86-E9"!T:&ES('=A>3HZ"@H@(&EF("@H8V]N9&ET:6]N
M,2D@?'P@*&-O;F1I=&EO;C(I('Q\("AC;VYD:71I;VXS*2!\?`H@("`@("`H
M8V]N9&ET:6]N-"DI('L*("`@("`@86-T:6]N,3L*("!]"@I#;VYT<F]L('-T
M871E;65N=',@<VAO=6QD(&AA=F4@;VYE('-P86-E(&)E='=E96X@=&AE(&-O
M;G1R;VP@:V5Y=V]R9"!A;F0*;W!E;FEN9R!P87)E;G1H97-I<RP@=&\@9&ES
M=&EN9W5I<V@@=&AE;2!F<F]M(&9U;F-T:6]N(&-A;&QS+@H*1&\@;F]T(&]M
M:70@=&AE(&-U<FQY(&)R86-E<R!U;F1E<B!A;GD@8VER8W5M<W1A;F-E+B`@
M26X@=&AE(&-A<V4@;V8@82!L87)G90IN=6UB97(@;V8@<VAO<G0@=&5S=',@
M86YD(&%C=&EO;G,L('1H92!F;VQL;W=I;F<@:7,@86-C97!T86)L93HZ"@H@
M(&EF("AC;VYD:71I;VXI("`@>R!A8W1I;VX[('T*("!I9B`H8V]N9&ET:6]N
M(#(I('L@86-T:6]N(#([('T*("`N+BX*"D9O<B!S=VET8V@@<W1A=&5M96YT
M<SHZ"@H@('-W:71C:"`H8V]N9&ET:6]N*2!["B`@8V%S92`Q.@H@("`@("!A
M8W1I;VXQ.PH@("`@("!B<F5A:SL*"B`@8V%S92`R.@H@("`@("!A8W1I;VXR
M.PH@("`@("!B<F5A:SL*"B`@9&5F875L=#H*("`@("`@9&5F875L=&%C=&EO
M;CL*("`@("`@8G)E86L["B`@?0H*"D9U;F-T:6]N($-A;&QS"CT]/3T]/3T]
M/3T]/3T]"@I&=6YC=&EO;G,@<VAO=6QD(&)E(&-A;&QE9"!W:71H(&YO('-P
M86-E<R!B971W965N('1H92!F=6YC=&EO;B!N86UE+"!T:&4*;W!E;FEN9R!P
M87)E;G1H97-I<RP@86YD('1H92!F:7)S="!P87)A;65T97([('-P86-E<R!B
M971W965N(&-O;6UA<R!A;F0@96%C:`IP87)A;65T97(L(&%N9"!N;R!S<&%C
M92!B971W965N('1H92!L87-T('!A<F%M971E<BP@=&AE(&-L;W-I;F<@<&%R
M96YT:&5S:7,L"F%N9"!T:&4@<V5M:6-O;&]N+B`@2&5R92=S(&%N(&5X86UP
M;&4Z.@H*("`D=F%R(#T@9F]O*"1B87(L("1B87HL("1Q=75X*3L*"D%S(&1I
M<W!L87EE9"!A8F]V92P@=&AE<F4@<VAO=6QD(&)E(&]N92!S<&%C92!O;B!E
M:71H97(@<VED92!O9B!A;B!E<75A;',@<VEG;@IU<V5D('1O(&%S<VEG;B!T
M:&4@<F5T=7)N('9A;'5E(&]F(&$@9G5N8W1I;VX@=&\@82!V87)I86)L92X@
M($EN('1H92!C87-E(&]F(&$*8FQO8VL@;V8@<F5L871E9"!A<W-I9VYM96YT
M<RP@;6]R92!S<&%C92!M87D@8F4@:6YS97)T960@=&\@<')O;6]T90IR96%D
M86)I;&ET>3HZ"@H@("1S:&]R="`@("`@("`@(#T@9F]O*"1B87(I.PH@("1L
M;VYG7W9A<FEA8FQE(#T@9F]O*"1B87HI.PH*"D9U;F-T:6]N($1E9FEN:71I
M;VYS"CT]/3T]/3T]/3T]/3T]/3T]/3T]"@I&=6YC=&EO;B!D96-L87)A=&EO
M;G,@9F]L;&]W('1H92`B0E-$+T%L;&UA;B(@8V]N=F5N=&EO;CHZ"@H@(&9U
M;F-T:6]N(&9O;T9U;F-T:6]N*"1A<F<Q+"`D87)G,B`]("<G*0H@('L*("`@
M("`@:68@*&-O;F1I=&EO;BD@>PH@("`@("`@("`@<W1A=&5M96YT.PH@("`@
M("!]"B`@("`@(')E='5R;B`D=F%L.PH@('T*"D%R9W5M96YT<R!W:71H(&1E
M9F%U;'0@=F%L=65S(&=O(&%T('1H92!E;F0@;V8@=&AE(&%R9W5M96YT(&QI
M<W0N("!!;'=A>7,*871T96UP="!T;R!R971U<FX@82!M96%N:6YG9G5L('9A
M;'5E(&9R;VT@82!F=6YC=&EO;B!I9B!O;F4@:7,@87!P<F]P<FEA=&4N"@I&
M=6YC=&EO;G,@=7-E9"!O;FQY(&EN('1H92!C=7)R96YT('-C<FEP="]C;&%S
M<R`H92YG+B!P<FEV871E(&UE;6)E<B!M971H;V1S*0IS:&]U;&0@8F5G:6X@
M=VET:"!A(&!@7V!@(&-H87)A8W1E<B`H92YG+B!@8%]E>&%M<&QE3&EB<F%R
M>6!@*2X@(%1H:7,@:&5L<',*9&ES=&EN9W5I<V@@=&AE<V4@<')I=F%T92!F
M=6YC=&EO;B!C86QL<R!F<F]M(&]T:&5R+"!P=6)L:6,@9G5N8W1I;VX@8V%L
M;',N"@H*0VQA<W,@1&5F:6YI=&EO;G,*/3T]/3T]/3T]/3T]/3T]/3T*"D-L
M87-S(&1E9FEN:71I;VYS(&9O;&QO=R!T:&4@(DLF4B]+97)N96PB(&-O;G9E
M;G1I;VXZ.@H*("!C;&%S<R!3;VUE7T-L87-S('L*"B`@("`@('9A<B`D7W9A
M<FEA8FQE.PH*("`@("`@9G5N8W1I;VX@9F]O1G5N8W1I;VXH*0H@("`@("![
M"B`@("`@("`@("!S=&%T96UE;G0["B`@("`@('T*"B`@?0H*3F]T92!T:&4@
M8FQA;FL@;&EN97,@870@=&AE(&)E9VEN;FEN9R!A;F0@96YD(&]F('1H92!C
M;&%S<R!D969I;FET:6]N+@H*"DYA;6EN9R!,:6)R87)I97,*/3T]/3T]/3T]
M/3T]/3T]/0H*3&EB<F%R:65S("AA;GD@9FEL92!L;V-A=&5D(&EN('1H92!@
M8&QI8B]@8"!D:7)E8W1O<GD@;V8@=&AE(&%P<&QI8V%T:6]N*0IS:&]U;&0@
M8F4@;F%M960@=VET:"!C87!I=&%L(&QE='1E<G,@870@=&AE(&)E9VEN;FEN
M9R!O9B!E86-H('=O<F0N("!5<V4*<W1U9&QY8V%P<R!F;W(@;F%M:6YG.R!A
M('-E<W-I;VX@8V%C:&4@8VQA<W,@=V]U;&0@8F4@<W1O<F5D(&EN"F!@;&EB
M+U-E<W-I;VY#86-H92YP:'!@8"X*"DEF('1H92!L:6)R87)Y+V-L87-S(&ES
M(&5X=&5N9&5D+"!T:&4@97AT96YD:6YG(&9I;&5S('-H;W5L9"!B92!S=&]R
M960@:6X@80ID:7)E8W1O<GD@=6YD97(@8&!L:6(O8&`@=VET:"!T:&4@<V%M
M92!N86UE(&%S('1H92!O<FEG:6YA;"!L:6)R87)Y+@I3=6)C;&%S<V5S(&9O
M;&QO=R!T:&4@97AA8W0@<V%M92!N86UI;F<@<F5Q=6ER96UE;G1S+"!E>&-E
M<'0@=&AA="!I9B!T:&4*<W5B8VQA<W,@:7,@:6YS=&%N=&EA=&5D(&)Y(&$@
M9F%C=&]R>2!M971H;V0L(&ET('-H;W5L9"!B92!A;&P@;&]W97)C87-E+@H*
M17AA;7!L90HM+2TM+2TM"@I4:&4@(D5X86UP;&4@3&EB<F%R>2(@;&EB<F%R
M>2!S:&]U;&0@8F4@<V%V960@87,@8&!L:6(O17AA;7!L94QI8G)A<GDN<&AP
M8&`N"D%N>2!F:6QE(&5X=&5N9&EN9R!T:&4@;&EB<F%R>2]C;&%S<R!S:&]U
M;&0@8F4@<W1O<F5D(&EN('1H92!D:7)E8W1O<GD*8&!L:6(O17AA;7!L94QI
M8G)A<GDO8&`N"@H*0V]M;65N=',*/3T]/3T]/3T*"DEN;&EN92!D;V-U;65N
M=&%T:6]N(&9O<B!C;&%S<V5S('-H;W5L9"!F;VQL;W<@=&AE(&!*879A9&]C
M(&-O;G9E;G1I;VY@7RX*"BXN(%]*879A9&]C(&-O;G9E;G1I;VXZ(&AT='`Z
M+R]J879A+G-U;BYC;VTO<')O9'5C=',O:F1K+VIA=F%D;V,O=W)I=&EN9V1O
M8V-O;6UE;G1S+VEN9&5X+FAT;6P*"E%U:6-K(&5X86UP;&4@9F]R('!R:79A
M=&4@=F%R:6%B;&4@9&5F:6YI=&EO;B!F;W(@2&]R9&4Z.@H*("`@("\J*@H@
M("`@("H@5F%R:6%B;&4@9&5S8W)I<'1I;VXN"B`@("`@*@H@("`@("H@0'9A
M<B!D871A='EP90H@("`@("HO"@I1=6EC:R!E>&%M<&QE(&9U;F-T:6]N(&1E
M9FEN:71I;VX@9F]R($AO<F1E.CH*"B`@("`O*BH*("`@("`J(%1H92!D97-C
M<FEP=&EO;B!O9B!T:&4@9G5N8W1I;VX@9V]E<R!H97)E+@H@("`@("H*("`@
M("`J($!A8V-E<W,@6W!R:79A=&4@?"!P<F]T96-T961="B`@("`@*B!;1&]N
M)W0@8F]T:&5R('=I=&@@(G!U8FQI8R(@<VEN8V4@:70@:7,@=&AE(&1E9F%U
M;'0@:68@;F]T('-P96-I9FEE9"Y="B`@("`@*@H@("`@("H@0'!A<F%M(&1A
M=&%T>7!E("1V87)I86)L96YA;64@("!$97-C<FEP=&EO;B!O9B!V87)I86)L
M92X*("`@("`J($!P87)A;2!D871A='EP92`D=F%R:6%B;&4R;F%M92`@1&5S
M8W)I<'1I;VX@;V8@=F%R:6%B;&4R+@H@("`@("H@+BXN"B`@("`@*B!;26YS
M97)T(#(@<W!A8V5S(&%F=&5R('1H92!L;VYG97-T("1V87)I86)L92!D969I
M;FET:6]N+"!A;F0@=&AE;B!L:6YE"B`@("`@*B`@=7`@86QL(&1E<V-R:7!T
M:6]N<R!W:71H('1H:7,@9&5S8W)I<'1I;VY="B`@("`@*@H@("`@("H@0')E
M='5R;B!D871A='EP92`@1&5S8W)I<'1I;VX@;V8@<F5T=7)N('9A;'5E+@H@
M("`@("H@6T]N8V4@86=A:6XL(&EN<V5R="`R('-P86-E<R!A9G1E<B!T:&4@
M9&%T871Y<&4L(&%N9"!L:6YE('5P(&%L;`H@("`@("H@('-U8G-E<75E;G0@
M;&EN97,L(&EF(&%N>2P@=VET:"!T:&ES(&-H87)A8W1E<BY="B`@("`@*@H@
M("`@("H@0&%B<W1R86-T(%M/;FQY(&EF(&YE8V5S<V%R>5T*("`@("`J"B`@
M("`@*B!`<VEN8V4@2&]R9&4@>"YX(%M/;FQY(&EF(&YE8V5S<V%R>2`M('5S
M92!I9B!F=6YC=&EO;B!I<R!A9&1E9"!T;R!T:&4*("`@("`J(&-U<G)E;G0@
M<F5L96%S92!V97)S:6]N<R!T;R!I;F1I8V%T92!T:&%T('1H92!F=6YC=&EO
M;B!H87,@;F]T(&)E96X*("`@("`J(&%V86EL86)L92!I;B!P<F5V:6]U<R!V
M97)S:6]N<RY="B`@("`@*B\*"@I);F-L=61I;F<@0V]D90H]/3T]/3T]/3T]
M/3T]/0H*268@>6]U(&%R92!I;F-L=61I;F<@82!C;&%S<RP@9G5N8W1I;VX@
M;&EB<F%R>2P@;W(@86YY=&AI;F<@96QS92!W:&EC:"!W;W5L9`IC875S92!A
M('!A<G-E(&5R<F]R(&EF(&EN8VQU9&5D('1W:6-E+"!A;'=A>7,@=7-E(&!I
M;F-L=61E7V]N8V5@7RX@(%1H:7,@=VEL;`IE;G-U<F4@=&AA="!N;R!M871T
M97(@:&]W(&UA;GD@9F%C=&]R>2!M971H;V1S('=E('5S92!O<B!H;W<@;75C
M:"!D>6YA;6EC"FEN8VQU<VEO;B!W92!D;RP@=&AE(&QI8G)A<GD@=VEL;"!O
M;FQY(&)E(&EN8VQU9&5D(&]N8V4N"@I)9B!Y;W4@87)E(&EN8VQU9&EN9R!A
M('-T871I8R!F:6QE;F%M92P@<W5C:"!A<R!A(&-O;F8@9FEL92!O<B!A('1E
M;7!L871E('1H870*:7,@*F%L=V%Y<RH@=7-E9"P@=7-E(&!R97%U:7)E8%\N
M"@I)9B!Y;W4@87)E(&1Y;F%M:6-A;&QY(&EN8VQU9&EN9R!A(&9I;&5N86UE
M+"!O<B!W86YT('1H92!C;V1E('1O(&]N;'D@8F4@=7-E9`IC;VYD:71I;VYA
M;&QY("AA;B!O<'1I;VYA;"!T96UP;&%T92DL('5S92!@:6YC;'5D96!?+@H*
M+BX@7VEN8VQU9&5?;VYC93H@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E
M;B]F=6YC=&EO;BYI;F-L=61E+6]N8V4N<&AP"BXN(%]R97%U:7)E.B!H='1P
M.B\O=W=W+G!H<"YN970O;6%N=6%L+V5N+V9U;F-T:6]N+G)E<75I<F4N<&AP
M"BXN(%]I;F-L=61E.B!H='1P.B\O=W=W+G!H<"YN970O;6%N=6%L+V5N+V9U
M;F-T:6]N+FEN8VQU9&4N<&AP"@H*4$A0($-O9&4@5&%G<PH]/3T]/3T]/3T]
M/3T]"@I!;'=A>7,@=7-E(&!@/#]P:'`@/SY@8"!T;R!D96QI;6ET(%!(4"!C
M;V1E+"!N;W0@=&AE(&!@/#\@/SY@8"!S:&]R=&AA;F0N"E1H:7,@:7,@<F5Q
M=6ER960@9F]R(%!%05(@8V]M<&QI86YC92!A;F0@:7,@86QS;R!T:&4@;6]S
M="!P;W)T86)L92!W87D@=&\*:6YC;'5D92!02%`@8V]D92!O;B!D:69F97)I
M;F<@;W!E<F%T:6YG('-Y<W1E;7,@86YD('-E='5P<RX*"DEN('1E;7!L871E
M<RP@;6%K92!S=7)E('1O('5S92!T:&ES(&%S('=E;&P@*&!@/#]P:'`@96-H
M;R`D=F%R;F%M92`_/F!@*2P@87,*=&AE('-H;W)T8W5T('9E<G-I;VX@*&!@
M/#\]("1V87(@/SY@8"D@9&]E<R!N;W0@=V]R:R!W:71H(&!S:&]R=%]O<&5N
M7W1A9V!?"G1U<FYE9"!O9F8N"@HN+B!?<VAO<G1?;W!E;E]T86<Z(&AT='`Z
M+R]W=W<N<&AP+FYE="]M86YU86PO96XO8V]N9FEG=7)A=&EO;BYD:7)E8W1I
M=F5S+G!H<"-I;FDN<VAO<G0M;W!E;BUT86<*"@I(96%D97(@0V]M;65N="!"
M;&]C:W,*/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@I!;&P@<V]U<F-E(&-O9&4@
M9FEL97,@:6X@=&AE($AO<F1E(&1I<W1R:6)U=&EO;B!S:&]U;&0@8V]N=&%I
M;B!T:&4@9F]L;&]W:6YG"F-O;6UE;G0@8FQO8VL@87,@=&AE(&AE861E<CH*
M"D5X86UP;&4@9F]R(&!,1U!,8%\G960@2&]R9&4@8V]D93HZ"@H@("`@+RHJ
M"B`@("`@*B!4:&4@2&]R9&5?1F]O.CH@8VQA<W,@<')O=FED97,@86X@05!)
M(&9O<B!V87)I;W5S(&9O;PH@("`@("H@=&5C:&YI<75E<R!T:&%T(&-A;B!B
M92!U<V5D(&)Y($AO<F1E(&%P<&QI8V%T:6]N<RX*("`@("`J"B`@("`@*B`D
M2&]R9&4*("`@("`J"B`@("`@*B!#;W!Y<FEG:'0@,3DY.2TR,#`Q($]R:6=I
M;F%L($%U=&AO<B`\875T:&]R0&5X86UP;&4N8V]M/@H@("`@("H@0V]P>7)I
M9VAT(#(P,#$@66]U<B!.86UE(#QY;W5`97AA;7!L92YC;VT^"B`@("`@*@H@
M("`@("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("`@("`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@("`@("H*("`@("`J($!A=71H;W(@($]R:6=I
M;F%L($%U=&AO<B`\875T:&]R0&5X86UP;&4N8V]M/@H@("`@("H@0&%U=&AO
M<B`@66]U<B!.86UE(#QY;W5`97AA;7!L92YC;VT^"B`@("`@*B!`<VEN8V4@
M("!(;W)D92`S+C`*("`@("`J($!P86-K86=E($AO<F1E7U!A8VMA9V4*("`@
M("`J+PH*+BX@7TQ'4$PZ(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC
M96YS97,O;&=P;"UL:6-E;G-E+G!H<`H*17AA;7!L92!F;W(@8$=03&!?)V5D
M(&%P<&QI8V%T:6]N(&-O9&4Z.@H*("`@("\J*@H@("`@("H@5&AE($%P<%]"
M87(Z.B!C;&%S<R!C;VYT86EN<R!A;&P@9G5N8W1I;VYS(')E;&%T960@=&\@
M:&%N9&QI;F<*("`@("`J(&)A<G,@:6X@07!P+@H@("`@("H*("`@("`J("1(
M;W)D90H@("`@("H*("`@("`J($-O<'ER:6=H="`Q.3DY+3(P,#$@3W)I9VEN
M86P@075T:&]R(#QA=71H;W)`97AA;7!L92YC;VT^"B`@("`@*B!#;W!Y<FEG
M:'0@,C`P,2!9;W5R($YA;64@/'EO=4!E>&%M<&QE+F-O;3X*("`@("`J"B`@
M("`@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H1U!,*2X@268@>6]U"B`@("`@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+V=P;"YH=&UL+@H@("`@("H*("`@("`J($!A=71H;W(@($]R:6=I;F%L
M($%U=&AO<B`\875T:&]R0&5X86UP;&4N8V]M/@H@("`@("H@0&%U=&AO<B`@
M66]U<B!.86UE(#QY;W5`97AA;7!L92YC;VT^"B`@("`@*B!`<VEN8V4@("!!
M<'`@,2XP"B`@("`@*B!`<&%C:V%G92!A<'`*("`@("`J+PH*"BXN(%]'4$PZ
M(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O9W!L+6QI8V5N
M<V4N<&AP"@I4:&5R92=S(&YO(&AA<F0@<G5L92!T;R!D971E<FUI;F4@=VAE
M;B!A(&YE=R!C;V1E(&-O;G1R:6)U=&5R('-H;W5L9"!B92!A9&1E9`IT;R!T
M:&4@;&ES="!O9B!A=71H;W)S(&9O<B!A(&=I=F5N('-O=7)C92!F:6QE+B`@
M26X@9V5N97)A;"P@=&AE:7(@8VAA;F=E<PIS:&]U;&0@9F%L;"!I;G1O('1H
M92`B<W5B<W1A;G1I86PB(&-A=&5G;W)Y("AM96%N:6YG('-O;65W:&5R92!A
M<F]U;F0@,3`E('1O"C(P)2!O9B!C;V1E(&-H86YG97,I+B`@17AC97!T:6]N
M<R!C;W5L9"!B92!M861E(&9O<B!R97=R:71I;F<@9G5N8W1I;VYS(&]R"F-O
M;G1R:6)U=&EN9R!N97<@;&]G:6,N"@I3:6UP;&4@8V]D92!R96]R9V%N:7IA
M=&EO;B!O<B!B=6<@9FEX97,@=V]U;&0@;F]T(&IU<W1I9GD@=&AE(&%D9&ET
M:6]N(&]F(&$*;F5W(&EN9&EV:61U86P@=&\@=&AE(&QI<W0@;V8@875T:&]R
M<RX*"@I#5E,@5&%G<PH]/3T]/3T]/0H*26YC;'5D92!T:&4@/&1O;&QA<CY(
M;W)D93H@/&1O;&QA<CX@0U93('9E;F1O<B!T86<@:6X@96%C:"!F:6QE+B`@
M07,@96%C:"!F:6QE"FES(&5D:71E9"P@861D('1H:7,@=&%G(&EF(&ET)W,@
M;F]T('EE="!P<F5S96YT("AO<B!R97!L86-E(&5X:7-T:6YG(&9O<FUS"G-U
M8V@@87,@/&1O;&QA<CY)9#QD;VQL87(^+"`B3&%S="!-;V1I9FEE9#HB+"!E
M=&,N*2X*"D580T505$E/3CH@1&]N)W0@:6YC;'5D92!T:&5S92!I;B!T96UP
M;&%T97,N"@H*17AA;7!L92!54DQS"CT]/3T]/3T]/3T]/0H*57-E(&!@97AA
M;7!L92YC;VU@8"!F;W(@86QL(&5X86UP;&4@55),<RP@<&5R(&!21D,@,C8P
M-F!?+@H*+BX@7U)&0R`R-C`V.B!H='1P.B\O=W=W+F9A<7,N;W)G+W)F8W,O
M<F9C,C8P-BYH=&UL"@H*<&AP+FEN:2!S971T:6YG<PH]/3T]/3T]/3T]/3T]
M/3T]"@I!;&P@2&]R9&4@8V]D92!S:&]U;&0@=V]R:R!W:71H(&!R96=I<W1E
M<E]G;&]B86QS8%\@9&ES86)L960N("!4:&ES(&UE86YS"G5S:6YG(&!@)%]#
M3T]+245@8"P@8&`D7U-%4U-)3TY@8"P@8&`D7U-%4E9%4F!@(&%N9"!@8"1?
M14Y68&`@=&\@86-C97-S(&%L;`IC;V]K:64L('-E<W-I;VXL('-E<G9E<B!A
M;F0@96YV:7)O;FUE;G0@9&%T82P@<F5S<&5C=&EV96QY+@H*5&\@<F5T<FEE
M=F4@<&]S=&5D(&1A=&$@*&EN('1H92!G;&]B86P@8&`D7T=%5&!@(&%N9"!@
M8"1?4$]35&!@('9A<FEA8FQE<RDL"GEO=2!S:&]U;&0@;F]R;6%L;'D@=7-E
M(&!5=&EL.CIG971&;W)M1&%T82@I8%\@=VAI8V@@=VEL;"!A=71O;6%T:6-A
M;&QY(')U;@I@571I;#HZ9&ES<&5L36%G:6-1=6]T97,H*6!?+B!4:&ES('=I
M;&P@96YS=7)E('1H870@86QL($AO<F1E(&-O9&4@=VEL;"!W;W)K"G)E9V%R
M9&QE<W,@;V8@=&AE('-E='1I;F<@;V8@8&UA9VEC7W%U;W1E<U]G<&-@7RX@
M5&AE(&]N;'D@=&EM92!Y;W4@<VAO=6QD(&YO=`IU<V4@8%5T:6PZ.F=E=$9O
M<FU$871A*"E@7R!I<R!I9B!Y;W4@=V%N="!T;R!D:7)E8W1L>2!A8V-E<W,@
M82!'150@;W(@4$]35`IV87)I86)L92!I;G-T96%D.R!I;B!T:&ES(&-A<V4L
M('EO=2!S:&]U;&0@=7-E(&!5=&EL.CIG971'970H*6!?(&]R"F!5=&EL.CIG
M9710;W-T*"E@7R!R97-P96-T:79E;'DN"@I!;&P@2&]R9&4@8V]D92!S:&]U
M;&0@=V]R:R!W:71H(&!E<G)O<E]R97!O<G1I;F=@7R`]($5?04Q,+B!&86EL
M=7)E('1O(&1O('-O"G=O=6QD(')E<W5L="!I;B!U9VQY(&]U='!U="P@97)R
M;W(@;&]G<R!G971T:6YG(&9I;&QE9"!W:71H(&QO=',@;V8@=V%R;FEN9PIM
M97-S86=E<RP@;W(@979E;B!D;W=N<FEG:'0@8G)O:V5N('-C<FEP=',N"@I.
M;R!(;W)D92!C;V1E('-H;W5L9"!A<W-U;64@=&AA="`G+B<@:7,@:6X@=&AE
M(&EN8VQU9&4@<&%T:"X@06QW87ES('-P96-I9GD*)RXO)R!I;B!F<F]N="!O
M9B!A(&9I;&5N86UE('=H96X@>6]U(&%R92!I;F-L=61I;F<@82!F:6QE(&EN
M('1H92!S86UE"F1I<F5C=&]R>2X*"BXN(%]R96=I<W1E<E]G;&]B86QS.B!H
M='1P.B\O=W=W+G!H<"YN970O;6%N=6%L+V5N+W-E8W5R:71Y+G)E9VES=&5R
M9VQO8F%L<RYP:'`*+BX@7VUA9VEC7W%U;W1E<U]G<&,Z(&AT='`Z+R]W=W<N
M<&AP+FYE="]M86YU86PO96XO<F5F+FEN9F\N<&AP(VEN:2YM86=I8RUQ=6]T
M97,M9W!C"BXN(%]E<G)O<E]R97!O<G1I;F<Z(&AT='`Z+R]W=W<N<&AP+FYE
M="]M86YU86PO96XO<F5F+F5R<F]R9G5N8RYP:'`C:6YI+F5R<F]R+7)E<&]R
M=&EN9PHN+B!?571I;#HZ9V5T1F]R;41A=&$H*3H@:'1T<#HO+V1E=BYH;W)D
M92YO<F<O87!I+V9R86UE=V]R:R](;W)D95]5=&EL+U5T:6PN:'1M;"-M971H
M;V1G971&;W)M1&%T80HN+B!?571I;#HZ9&ES<&5L36%G:6-1=6]T97,H*3H@
M:'1T<#HO+V1E=BYH;W)D92YO<F<O87!I+V9R86UE=V]R:R](;W)D95]5=&EL
M+U5T:6PN:'1M;"-M971H;V1D:7-P96Q-86=I8U%U;W1E<PHN+B!?571I;#HZ
M9V5T1V5T*"DZ(&AT='`Z+R]D978N:&]R9&4N;W)G+V%P:2]F<F%M97=O<FLO
M2&]R9&5?571I;"]5=&EL+FAT;6PC;65T:&]D9V5T1V5T"BXN(%]5=&EL.CIG
M9710;W-T*"DZ(&AT='`Z+R]D978N:&]R9&4N;W)G+V%P:2]F<F%M97=O<FLO
M2&]R9&5?571I;"]5=&EL+FAT;6PC;65T:&]D9V5T4&]S=`H*"EA(5$U,(#$N
M,"!#;VUP;&EA;F-E"CT]/3T]/3T]/3T]/3T]/3T]/3T]"@I!;&P@=&%G(&YA
M;65S(&%N9"!P87)A;65T97)S(&UU<W0@8F4@;&]W97(@8V%S92!I;F-L=61I
M;F<@:F%V87-C<FEP="!E=F5N=`IH86YD;&5R<SHZ"@H@("`@/&9O;G0@8V]L
M;W(](B-&1D9&1D8B/BXN+CPO9F]N=#X*("`@(#QA(&AR968](FAT='`Z+R]E
M>&%M<&QE+F-O;2(@;VYM;W5S96]V97(](G-T871U<STG)R(@;VYM;W5S96]U
M=#TB<W1A='5S/2<G(CXN+BX\+V$^"@I!;&P@=&%G('!A<F%M971E<G,@;75S
M="!B92!O9B!A('9A;&ED('!A<F%M971E<CTB=F%L=64B(&9O<FT@*&YU;65R
M:6,@=F%L=65S"FUU<W0@86QS;R!B92!S=7)R;W5N9&5D(&)Y('%U;W1E<RDN
M("!&;W(@<&%R86UE=&5R<R!T:&%T(&AA9"!N;R!V86QU92!I;B!(5$U,+`IT
M:&4@<&%R86UE=&5R(&YA;64@:7,@=&AE('9A;'5E+B`@1F]R(&5X86UP;&4Z
M.@H*("`@(#QI;G!U="!T>7!E/2)C:&5C:V)O>"(@8VAE8VME9#TB8VAE8VME
M9"(^"B`@("`\<V5L96-T(&YA;64](F5X86UP;&4B/@H@("`@("`@(#QO<'1I
M;VX@<V5L96-T960](G-E;&5C=&5D(B!V86QU93TB,2(^17AA;7!L93PO;W!T
M:6]N/@H@("`@/"]S96QE8W0^"B`@("`\=&0@;F]W<F%P/2)N;W=R87`B/D5X
M86UP;&4\+W1D/@H*06QL('1A9W,@;75S="!B92!P<F]P97)L>2!C;&]S960N
M("!486=S('=H97)E(&-L;W-I;F<@:7,@9F]R8FED9&5N(&UU<W0@96YD"G=I
M=&@@82!S<&%C92!A;F0@82!S;&%S:#HZ"@H@("`@/&)R("\^"B`@("`\:'(@
M+SX*("`@(#QI;6<@<W)C/2)E>&%M<&QE+F=I9B(@86QT/2)%>&%M<&QE(B`O
M/@H@("`@/&EN<'5T('1Y<&4](G-U8FUI="(@=F%L=64](D5X86UP;&4B("\^
M"@I!;&P@9F]R;2!D969I;FET:6]N<R!M=7-T(&)E(&]N('1H96ER(&]W;B!L
M:6YE(&%N9"!E:71H97(@9G5L;'D@9&5F:6YE9"!W:71H:6X*82!@8#QT9#X\
M+W1D/F!@('!A:7(@;W(@8F4@;W5T<VED92!T86)L92!T86=S+B`@1F]R;7,@
M;75S="!A;'-O(&%L=V%Y<R!H879E(&%N"F%C=&EO;B!P87)A;65T97(Z.@H*
M("`@(#QF;W)M(&UE=&AO9#TB<&]S="(@86-T:6]N/2)H='1P.B\O97AA;7!L
M92YC;VTO97AA;7!L92YC9VDB/@H@("`@/'1A8FQE/@H@("`@("`@(#QT<CX\
M=&0^97AA;7!L93PO=&0^/"]T<CX*("`@(#PO=&%B;&4^"B`@("`\+V9O<FT^
M"@H@("`@/'1A8FQE/@H@("`@("`@(#QT<CX\=&0^"B`@("`@("`@("`@(#QF
M;W)M(&%C=&EO;CTB:F%V87-C<FEP=#IV;VED*#`I(B!O;G-U8FUI=#TB<F5T
M=7)N(&9A;'-E.R(^"B`@("`@("`@("`@(#PO9F]R;3X*("`@("`@("`\+W1D
M/CPO='(^"B`@("`\+W1A8FQE/@H*06QL($IA=F%38W)I<'0@=&%G<R!M=7-T
M(&AA=F4@82!V86QI9"!T>7!E('!A<F%M971E<CHZ"@H@("`@/'-C<FEP="!T
M>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H@("`@/"$M+0H@("`@+BXN"B`@("`O
M+R`M+3X*("`@(#PO<V-R:7!T/@H*3F]T:&EN9R!M87D@87!P96%R(&%F=&5R
M(&!@/"]H=&UL/F!@+"!T:&5R969O<F4@:6YC;'5D92!A;GD@8V]M;6]N(&9O
M;W1E<G,*869T97(@86QL(&]T:&5R(&]U='!U="X*"D%L;"!I;6%G97,@;75S
M="!H879E(&%N(&!@86QT8&`@871T<FEB=71E.CH*"B`@("`\:6UG('-R8STB
M97AA;7!L92YG:68B(&%L=#TB/#]P:'`@96-H;R!?*")%>&%M<&QE(BD@/SXB
M("\^"B`@("`\/W!H<"!E8VAO($AO<F1E.CII;6<H)V5X86UP;&4N9VEF)RP@
M7R@B17AA;7!L92(I*2`_/B`@("`@("`@("`@("`@("`@("A/;B!T:&4@2$5!
M1"!B<F%N8V@I"B`@("`\/W!H<"!E8VAO($AO<F1E.CII;6<H)V5X86UP;&4N
M9VEF)RP@)V%L=#TB)R`N(%\H(D5X86UP;&4B*2`N("<B)RD@/SX@("A/;B!T
M:&4@4D5,14Y'7S(@8G)A;F-H*0H*26YP=70@9FEE;&1S(&]F('1Y<&4@(FEM
M86=E(B!D;R!N;W0@86QL;W<@=&AE(&)O<F1E<B!A='1R:6)U=&4@86YD(&UA
M>2!R96YD97(*=VET:"!A(&)O<F1E<B!O;B!S;VUE(&)R;W=S97)S+B`@57-E
M('1H92!F;VQL;W=I;F<@:6YS=&5A9#HZ"@H@("`\82!H<F5F/2(B(&]N8VQI
M8VL](F1O8W5M96YT+F9O<FUN86UE+G-U8FUI="@I.R!R971U<FX@9F%L<V4[
M(CX\/W!H<"!E8VAO($AO<F1E.CII;6<H(F5X86UP;&4N9VEF(BP@7R@B17AA
M;7!L92(I*2`_/CPO83X*"@I$871A8F%S92!.86UI;F<@0V]N=F5N=&EO;G,*
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@I!;&P@9&%T86)A<V4@=&%B
M;&5S('5S960@8GD@2&]R9&4@<F5S;W5R8V5S(&%N9"!(;W)D92!A<'!L:6-A
M=&EO;G,@;F5E9"!T;PIM86ME('-U<F4@=&AA="!T:&5I<B!T86)L92!A;F0@
M9FEE;&0@;F%M97,@=V]R:R!I;B!A;&P@9&%T86)A<V5S+B`@36%N>0ID871A
M8F%S97,@<F5S97)V92!W;W)D<R!L:6ME("=U:60G+"`G=7-E<B<L(&5T8RX@
M9F]R(&EN=&5R;F%L('5S92P@86YD(&9O<F)I9`IW;W)D<R!T:&%T(&%R92!3
M44P@:V5Y=V]R9',@*'-E;&5C="P@=VAE<F4L(&5T8RXI+B`@06QS;RP@86QL
M(&YA;65S('-H;W5L9"!B90IL;W=E<F-A<V4L('=I=&@@=6YD97)S8V]R97,@
M*"=?)RD@=&\@<V5P87)A=&4@=V]R9',L('1O(&%V;VED(&-A<V4@<V5N<VET
M:79I='D*:7-S=65S+@H*02!G;V]D('=A>2!T;R!D;R!T:&ES(&9O<B!F:65L
M9"!N86UE<R!I<R!T;R!M86ME('1H92!F:65L9"!N86UE"G1A8FQE;F%M95]F
M:65L9&YA;64N"@I/=&AE<B!G96YE<F%L(&=U:61E;&EN97,Z(%1A8FQE(&YA
M;65S('-H;W5L9"!B92!P;'5R86P@*'5S97)S*3L@9FEE;&0@;F%M97,*<VAO
M=6QD(&)E('-I;F=U;&%R("AU<V5R7VYA;64I+@H*"E)E9W5L87(@17AP<F5S
M<VEO;B!5<V4*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*06QW87ES('5S92!T
M:&4@8'!R96=?8%\@9G5N8W1I;VYS(&EF('!O<W-I8FQE(&EN<W1E860@;V8@
M8&5R96=?8%\@*&%N9`I@<')E9U]S<&QI="@I8%\@:6YS=&5A9"!O9B!@<W!L
M:70H*6!?*3L@=&AE>2!A<F4@:6YC;'5D960@:6X@4$A0(&)Y(&1E9F%U;'0*
M86YD(&UU8V@@;6]R92!E9F9I8VEE;G0@86YD(&UU8V@@9F%S=&5R('1H86X@
M8&5R96=?8%\N"@HJ*DY%5D52*BH@=7-E(&$@<F5G=6QA<B!E>'!R97-S:6]N
M('1O(&UA=&-H(&]R(')E<&QA8V4@82!S=&%T:6,@<W1R:6YG+@I@97AP;&]D
M92@I8%\@*&EN('!L86-E(&]F(&!S<&QI="@I8%\I+"!@<W1R7W)E<&QA8V4H
M*6!?+"!@<W1R<&]S*"E@7RP@;W(*8'-T<G1R*"E@7R!D;R!T:&4@:F]B(&UU
M8V@@;6]R92!E9F9I8VEE;G1L>2X*"BXN(%]P<F5G7SH@:'1T<#HO+W=W=RYP
M:'`N;F5T+VUA;G5A;"]E;B]R968N<&-R92YP:'`*+BX@7V5R96=?.B!H='1P
M.B\O=W=W+G!H<"YN970O;6%N=6%L+V5N+W)E9BYR96=E>"YP:'`*+BX@7W!R
M96=?<W!L:70H*3H@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]F=6YC
M=&EO;BYP<F5G+7-P;&ET+G!H<`HN+B!?<W!L:70H*3H@:'1T<#HO+W=W=RYP
M:'`N;F5T+VUA;G5A;"]E;B]F=6YC=&EO;BYS<&QI="YP:'`*+BX@7V5X<&QO
M9&4H*3H@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]F=6YC=&EO;BYE
M>'!L;V1E+G!H<`HN+B!?<W1R7W)E<&QA8V4H*3H@:'1T<#HO+W=W=RYP:'`N
M;F5T+VUA;G5A;"]E;B]F=6YC=&EO;BYS='(M<F5P;&%C92YP:'`*+BX@7W-T
M<G!O<R@I.B!H='1P.B\O=W=W+G!H<"YN970O;6%N=6%L+V5N+V9U;F-T:6]N
M+G-T<G!O<RYP:'`*+BX@7W-T<G1R*"DZ(&AT='`Z+R]W=W<N<&AP+FYE="]M
M86YU86PO96XO9G5N8W1I;VXN<W1R='(N<&AP"@H*4&%R86UE=&5R(%!A<W-I
M;F<*/3T]/3T]/3T]/3T]/3T]/3T*"D]B:F5C=',@<VAO=6QD(&)E('!A<W-E
M9"!B>2!R969E<F5N8V4N("!%=F5R>71H:6YG(&5L<V4L(&EN8VQU9&EN9R!A
M<G)A>7,L"G-H;W5L9"!B92!P87-S960@8GD@=F%L=64@=VAE<F5V97(@<V5M
M86YT:6-A;&QY('!O<W-I8FQE+@H*6UIE;F0@16YG:6YE(#(Z(&]B:F5C=',@
M<VAO=6QD(&%L<V\@8F4@<&%S<V5D(&)Y('9A;'5E70H*5&AI<R!P<F%C=&EC
M92!T86ME<R!F=6QL(&%D=F%N=&%G92!O9B!R969E<F5N8V4@8V]U;G1I;F<N
M"@HN+B!.;W1E.CH@5&AE(&!T97)N87)Y(&]P97)A=&]R8%\@875T;VUA=&EC
M86QL>2!R971U<FYS(&$@8V]P>2!O9B!I=',*("`@("`@("`@(&]P97)A;F1S
M+"!S;R!D;VXG="!U<V4@:70@=VET:"!O8FIE8W1S+"!O<B!I9B!Y;W4@87)E
M('-U<F4@>6]U('=A;G0*("`@("`@("`@('1O(')E='5R;B!A;B!O8FIE8W0@
M8V]P>2X*"BXN(%]@=&5R;F%R>2!O<&5R871O<F`Z(&AT='`Z+R]W=W<N<&AP
M+FYE="]M86YU86PO96XO;&%N9W5A9V4N;W!E<F%T;W)S+F-O;7!A<FES;VXN
M<&AP(VQA;F=U86=E+F]P97)A=&]R<RYC;VUP87)I<V]N+G1E<FYA<GD*"@I,
M;VYG($QI;F5S"CT]/3T]/3T]/3T*"E=R87`@;&EN97,@870@.#`@8VAA<F%C
M=&5R<RP@:6YC;'5D:6YG(&-O;6UE;G1S+"!U;FQE<W,@=&AI<R!S979E<F5L
M>2!I;7!A8W1S"G1H92!C;&%R:71Y(&]F('1H92!C;V1E+B`@06QW87ES('=R
M87`@8V]M;65N=',N"@H*3&EN92!"<F5A:W,*/3T]/3T]/3T]/3T*"D]N;'D@
M=7-E(%5.25@@<W1Y;&4@;V8@;&EN96)R96%K("A@8%QN8&`I+"!N;W0@5VEN
M9&]W<R]$3U,O36%C('-T>6QE"BA@8%QR7&Y@8"DN"@I5<VEN9R!V:6TL('1O
M(&-O;G9E<G0@9G)O;2!$3U,@<W1Y;&4@='EP93HZ"@H@("`@.G-E="!F9CUU
M;FEX"@I5<VEN9R!V:2P@=&\@8V]N=F5R="!F<F]M($1/4R!S='EL92!T>7!E
M.CH*"B`@("`Z9R]>32]S+R\O9PH**$YO=&4@=&AA="!T:&4@8&!>36!@(&ES
M(&$@8V]N=')O;"!C:&%R86-T97(L(&%N9"!T;R!R97!R;V1U8V4@:70@=VAE
M;B!Y;W4*='EP92!I;B!T:&4@=FD@8V]M;6%N9"!Y;W4@:&%V92!T;R!P860@
M:70@9FER<W0@=7-I;F<@=&AE('-P96-I86P@8&!>5F!@"F-H87)A8W1E<BXI
M"@H*4')I=F%T92!687)I86)L97,*/3T]/3T]/3T]/3T]/3T]/3T*"E9A<FEA
M8FQE<R!U<V5D(&5X8VQU<VEV96QY('=I=&AI;B!A(&-L87-S('-H;W5L9"!B
M96=I;B!W:71H(&$@=6YD97)S8V]R92`H)U\G*0IC:&%R86-T97(N("!!;B!E
M>&%M<&QE(&-L87-S('9A<FEA8FQE(&1E9FEN:71I;VXZ("!@8'9A<B`D7W9A
M<FEA8FQE;F%M93M@8`H*"D%R<F%Y($1E9FEN:71I;VYS"CT]/3T]/3T]/3T]
M/3T]/3T]"@I7:&5N(&1E9FEN:6YG(&%R<F%Y<RP@;W(@;F5S=&5D(&%R<F%Y
M<RP@=7-E('1H92!F;VQL;W=I;F<@9F]R;6%T+"!W:&5R90II;F1E;G1A=&EO
M;B!I<R!N;W1E9"!V:6$@=&AE(&-L;W-I;F<@<&%R96YT:&5S:7,@8VAA<F%C
M=&5R<SHZ"@H@("`@)&%R<F%Y;F%M95LG:6YD97@G72`](&%R<F%Y*`H@("`@
M("`@("=N86UE,2<@/3X@)W9A;'5E,2<L"B`@("`@("`@)VYA;64R)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@)W-U8FYA;64Q)R`]/B`G<W5B=F%L=64Q)RP*
M("`@("`@("`@("`@)W-U8FYA;64R)R`]/B`G<W5B=F%L=64R)PH@("`@("`@
M("D*("`@("D["@I4:&4@;VYL>2!E>&-E<'1I;VX@<VAO=6QD(&)E(&9O<B!E
M;7!T>2!O<B!S:&]R="!A<G)A>7,@=&AA="!F:70@;VX@;VYE(&QI;F4L"G=H
M:6-H(&UA>2!B92!W<FET=&5N(&%S.CH*"B`@("`D87)R87EN86UE6R=I;F1E
M>"==(#T@87)R87DH*3L*"@I);G1E<FYA=&EO;F%L:7IA=&EO;B`H23$X;BD*
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@I-87)K(&%L;"!S=')I;F=S
M('!R97-E;G1E9"!T;R!T:&4@=7-E<B!A<R!G971T97AT('-T<FEN9W,@8GD@
M8V%L;&EN9R!T:&4*9V5T=&5X="!S:&]R=&-U="!F=6YC=&EO;B`H8&!?*"E@
M8"DZ.@H*("`@(&5C:&\@7R@B2&5L;&\@=V]R;&0B*3L*"D1O;B=T('5S92!T
M:&4@9V5T=&5X="!F=6YC=&EO;G,@9F]R('-T<FEN9W,@=&AA="!W:6QL(&)E
M('=R:71T96X@=&\@82!L;V<@9FEL90IO<B!O=&AE<G=I<V4@<')E<V5N=&5D
M('1O('1H92!A9&UI;FES=')A=&]R+@H*5&AE(%-T<FEN9SHZ(&-L87-S(&-O
M;G1A:6YS('-E=F5R86P@<W1R:6YG(&UA;FEP=6QA=&EO;B!M971H;V1S('1H
M870@87)E+"!A<PIO<'!O<V5D('1O('1H96ER(%!(4"!E<75I=F%L96YT<RP@
M;&]C86QE(&%N9"!C:&%R<V5T('-A9F4N"@I5<V4@4W1R:6YG.CIC;VYV97)T
M0VAA<G-E="@I(&EF('EO=2!N965D('1O(&-O;G9E<G0@8F5T=V5E;B!D:69F
M97)E;G0*8VAA<F%C=&5R('-E="!E;F-O9&EN9W,@*&9O<B!E>&%M<&QE+"!B
M971W965N('5S97(@:6YP=70@86YD(&$@<W1O<F%G92!B86-K96YD"F]R(&1A
M=&$@9G)O;2!A;B!E>'1E<FYA;"!S;W5R8V4@86YD('1H92!U<V5R(&EN=&5R
M9F%C92DN("!9;W4@9&]N)W0@;F5E9"!T;PIC87)E(&EF('1H92!C:&%R86-T
M97(@<V5T<R!A<F4@<F5A;&QY(&1I9F9E<F5N="X*"E5S92!T:&4@4W1R:6YG
M.CIL;W=E<B@I(&%N9"!3=')I;F<Z.G5P<&5R*"D@;65T:&]D<R!W:71H;W5T
M(&$@<V5C;VYD"G!A<F%M971E<B!I9B!Y;W4@;F5E9"!T;R!P97)F;W)M(&$@
M;&]C86QE+6EN9&5P96YD96YT('-T<FEN9R!C;VYV97)S:6]N+@I4:&%T)W,@
M=&AE(&-A<V4@9F]R(&%L;"!S=')I;F=S('1H870@87)E(&9U<G1H97(@<')O
M8V5S<V5D(&]R(&EN=&5R<')E=&5D(&)Y"F-O9&4N("!5<V4@=&AE<V4@;65T
M:&]D<R!W:71H('1H92!S96-O;F0@<&%R86UE=&5R('-E="!T;R!T<G5E(&9O
M<B!S=')I;F=S"G1H870@;F5E9"!T;R!B92!C;VYV97)T960@8V]R<F5C=&QY
M(&%C8V]R9&EN9R!T;R!T:&4@8W5R<F5N="`H;W(@<W!E8VEF:65D*0IC:&%R
M86-T97(@<V5T+@H*57-E('1H92!O=&AE<B!3=')I;F<Z.B!E<75I=F%L96YT
M<R!O9B!02%`@<W1R:6YG(&9U;F-T:6]N<R!T;R!M86YI<'5L871E"G-T<FEN
M9W,@8V]R<F5C=&QY(&%C8V]R9&EN9R!T;R!T:&4@8W5R<F5N="`H;W(@<W!E
M8VEF:65D*2!C:&%R86-T97(@<V5T(&)U=`IU<V4@=&AE(%!(4"!F=6YC=&EO
M;G,@9F]R(&-O9&4O;6%C:&EN92!P<F]C97-S960@<W1R:6YG<RX*"@I%<G)O
M<B!C:&5C:VEN9PH]/3T]/3T]/3T]/3T]/0H*2&]R9&4@8V]D92!S:&]U;&0@
M=7-E(&!014%27T5R<F]R8%\@;V)J96-T<R!T;R!R971U<FX@;6]S="!E<G)O
M<B!C;VYD:71I;VYS"F9R;VT@;&EB<F%R>2!C86QL<RP@86YD(&UA;GD@=&EM
M97,@=V4@=VEL;"!S:6UP;'D@<&%S<R!B86-K(&$@8%!%05)?17)R;W)@7PIO
M8FIE8W0@9V5N97)A=&5D(&)Y(&%N('5N9&5R;'EI;F<@;&EB<F%R>2`H<W5C
M:"!A<R!-86EL(&]R(%!%05(@1$(I+@H*1F]R('1H97-E(&-A<V5S+"!U<V4@
M=&AE(&9O;&QO=VEN9R!S='EL92!O9B!C;V1E(&)L;V-K('1O(&-H96-K(&9O
M<B!S=6-C97-S"F%F=&5R(&%N>2!C86QL('=H:6-H(&-O=6QD(&=E;F5R871E
M(&%N(&5R<F]R(&-O;F1I=&EO;CHZ"@H@("`@)')E<W5L="`]("1S;VUE=&AI
M;F<M/F-A;&PH)VUA>2!E<G)O<B<I.PH@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("\O($AA;F1L92!E<G)O<B!C;VYD
M:71I;VXN"B`@("!](&5L<V4@>PH@("`@("`@("\O(%-U8V-E961E9"X*("`@
M('T*"DYO=&4@=&AA="!@:7-?82@I8%\@8VAE8VMS(&9O<B!S=6)C;&%S<V5S
M(&]F('1H92!N86UE9"!C;&%S<RP@87,@=V5L;"P@<V\@:68*=&AE(&]B:F5C
M="!Y;W4@9V5T(&)A8VL@:7,@<F5A;&QY(&$@8$1"7T5R<F]R8%\@;V)J96-T
M+"!T:&ES('=I;&P@<W1I;&P@8V%T8V@*:70@*'-I;F-E(&!$0E]%<G)O<F!?
M(&5X=&5N9',@8%!%05)?17)R;W)@7RDN"@I#86QL:6YG(%!%05(Z.FES17)R
M;W(H*2!R97-U;'1S(&EN('1H92!S86UE(&)E:&%V:6]R+"!B=70@:7-?82@I
M"F%C8V]M<&QI<VAE<R!T:&4@<V%M92!R97-U;'0@=VET:"!A('-I;F=L92!N
M871I=F4@4$A0(&9U;F-T:6]N(&-A;&PN"@HN+B!?4$5!4E]%<G)O<CH@:'1T
M<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO8V]R92YP96%R+G!E87(M97)R
M;W(N<&AP"BXN(%]$0E]%<G)O<CH@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU
M86PO96XO<&%C:V%G92YD871A8F%S92YD8BYD8BUE<G)O<BYP:'`*+BX@7VES
M7V$H*3H@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]F=6YC=&EO;BYI
M<RUA+G!H<`H*"D5X:7-T96YC92!C:&5C:VEN9PH]/3T]/3T]/3T]/3T]/3T]
M/3T*"D]F=&5N('EO=2=L;"!N965D('1O(&-H96-K('=H971H97(@;W(@;F]T
M(&$@=F%R:6%B;&4@;W(@<')O<&5R='D@97AI<W1S+@I4:&5R92!A<F4@<V5V
M97)A;"!C87-E<R!H97)E.@H*82X@268@>6]U(&YE960@=&\@:VYO=R!I9B!A
M('9A<FEA8FQE(&5X:7-T<R!A="!A;&P@86YD(&ES(&YO="!@8&YU;&Q@8"P@
M=7-E"F!I<W-E="@I8%\Z.@H*("`@("\O($-H96-K('1O('-E92!I9B`D<&%R
M86T@:7,@9&5F:6YE9"X*("`@(&EF("AI<W-E="@D<&%R86TI*2!["B`@("`@
M("`@+R\@)'!A<F%M(&UA>2!B92!F86QS92P@8G5T(&ET)W,@=&AE<F4N"B`@
M("!]"@IB+B!)9B!Y;W4@;F5E9"!T;R!K;F]W(&EF(&$@=F%R:6%B;&4@97AI
M<W1S($%.1"!H87,@82!N;VXM96UP='D@=F%L=64@*&YO=`I@8&YU;&Q@8"P@
M,"P@8&!F86QS96!@+"!E;7!T>2!S=')I;F<@;W(@=6YD969I;F5D*2P@=7-E
M("%@96UP='DH*6!?.CH*"B`@("`O+R!-86ME('-U<F4@=&AA="`D86YS=V5R
M(&5X:7-T<RP@:7,@;F]T(&%N(&5M<'1Y('-T<FEN9RP@86YD(&ES"B`@("`O
M+R!N;W0@,#H*("`@(&EF("@A96UP='DH)&%N<W=E<BDI('L*("`@("`@("`O
M+R`D86YS=V5R(&AA<R!S;VUE(&YO;BUF86QS92!C;VYT96YT+@H@("`@?2!E
M;'-E('L*("`@("`@("`O+R`H8F]O;"DD86YS=V5R('=O=6QD(&)E(&9A;'-E
M+@H@("`@?0H*07,@<&]I;G1E9"!O=70@:6X@=&AE(&-O;6UE;G0@;V8@=&AE
M(&5L<V4@8VQA=7-E+"!@96UP='DH*6!?(&5S<V5N=&EA;&QY(&1O97,*=&AE
M('-A;64@8VAE8VL@87,@8&ES<V5T*"E@7R`M+2!I<R!T:&ES('9A<FEA8FQE
M(&1E9FEN960@:6X@=&AE(&-U<G)E;G0@<V-O<&4_"BTM(&%N9"!T:&5N+"!I
M9B!I="!I<RP@<F5T=7)N<R!W:&%T('1H92!V87)I86)L92!W;W5L9"!E=F%L
M=6%T92!T;R!A<R!A"F)O;VQE86XN(%1H:7,@;65A;G,@=&AA="`P+"!W:&EL
M92!P;W1E;G1I86QL>2!V86QI9"!I;G!U="P@:7,@(F5M<'1Y(B`M('-O(&EF
M"C`@:7,@=F%L:60@9&%T82!F;W(@>6]U<B!C87-E+"!D;VXG="!U<V4@(6!E
M;7!T>2@I8%\N"@IC+B!)9B!Y;W4@:VYO=R!Y;W4@87)E('=O<FMI;F<@=VET
M:"!A(&UI>&5D('9A<FEA8FQE('1H96X@=7-I;F<@:G5S=`I@:7-S970H*6!?
M(&%N9"!@96UP='DH*6!?(&-O=6QD(&-A=7-E('5N97AP96-T960@<F5S=6QT
M<RP@9F]R(&5X86UP;&4@:68*=&5S=&EN9R!F;W(@82!K97D@86YD('1H92!V
M87)I86)L92!I<R!A8W1U86QL>2!A('-T<FEN9SHZ"@H@("`@)&9O;R`]("=B
M87(G.PH@("`@:68@*&ES<V5T*"1F;V];)W-O;65K97DG72DI('L*("`@("`@
M("`O+R!4:&ES('=I;&P@979A;'5A=&4@=&\@5%)512$*("`@('T*"DEF('EO
M=2!K;F]W('1H870@=&AE<F4@:7,@82!P;W-S:6)I;&ET>2!O9B!A(&UI>&5D
M('1Y<&4@=F%R:6%B;&4@=&AE('-O;'5T:6]N"FEN('1H:7,@8V%S92!W;W5L
M9"!B92!T;R!A9&0@86X@8&ES7V%R<F%Y*"E@7R!C:&5C:R!I;B!T:&4@8&!I
M9B@I8&`@<W1A=&5M96YT+@H*9"X@57-E(&!A<G)A>5]K97E?97AI<W1S*"E@
M7R!W:&5N('EO=2!W86YT('1O(&-H96-K(&EF(&%N(&%R<F%Y(&ME>2!I<R!D
M969I;F5D"F5V96X@:68@:70@:&%S(&$@=F%L=64@;V8@8&!N=6QL8&`Z.@H*
M("`@("\O($UA:V4@<W5R92!W92!H879E(&$@8VAA<G-E="!P87)A;65T97(N
M(%9A;'5E(&-O=6QD(&%L<V\@8F4@;G5L;"X*("`@(&EF("@A87)R87E?:V5Y
M7V5X:7-T<R@G8VAA<G-E="<L("1P87)A;7,I*2!["B`@("`@("`@2&]R9&4Z
M.F9A=&%L*"=);F-O;7!L971E(&-O;F9I9W5R871I;VXN)RD["B`@("!]"@I0
M;&5A<V4@;F]T92!T:&%T(&!A<G)A>5]K97E?97AI<W1S*"E@7R!I<R!A('!E
M<F9O<FUA;F-E(&AI="`H,C4E+3$P,"4I(&%N9`IS:&]U;&0@;VYL>2!B92!U
M<V5D('=H96X@;F5C97-S87)Y+B!);G-T96%D('1R>2!T;R!U<V4@(6!E;7!T
M>2@I8%\@;W(*8&ES<V5T*"E@7R!I;G-T96%D+@H*+BX@7VES<V5T*"DZ(&AT
M='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO9G5N8W1I;VXN:7-S970N<&AP
M"BXN(%]E;7!T>2@I.B!H='1P.B\O=W=W+G!H<"YN970O;6%N=6%L+V5N+V9U
M;F-T:6]N+F5M<'1Y+G!H<`HN+B!?:7-?87)R87DH*3H@:'1T<#HO+W=W=RYP
M:'`N;F5T+VUA;G5A;"]E;B]F=6YC=&EO;BYI<RUA<G)A>2YP:'`*+BX@7V%R
M<F%Y7VME>5]E>&ES=',H*3H@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E
M;B]F=6YC=&EO;BYA<G)A>2UK97DM97AI<W1S+G!H<`H*"E%U;W1E<PH]/3T]
M/3T*"EEO=2!S:&]U;&0@86QW87ES('5S92!S:6YG;&4@<75O=&4@*"<I(&-H
M87)A8W1E<G,@87)O=6YD('-T<FEN9W,L(&5X8V5P="!W:&5R90ID;W5B;&4@
M<75O=&4@*"(I(&-H87)A8W1E<G,@87)E(')E<75I<F5D+B`@06QL(&QI=&5R
M86P@<W1R:6YG<R!S:&]U;&0@8F4@:6X*<VEN9VQE('%U;W1E<RX@($$@8V]M
M<&%R:7-O;B!O9B!S:6YG;&4@86YD(&1O=6)L92!Q=6]T92!U<V%G92!F;VQL
M;W=S.@H*4VEN9VQE(%%U;W1E<SH*("`J(%9A<FEA8FQE<R!I;B!T:&4@<W1R
M:6YG(&%R92!N;W0@<&%R<V5D(&]R(&5X<&%N9&5D+@H@("H@3F5W(&QI;F4@
M<WEM8F]L<R!C86X@8F4@:6YC;'5D960@87,@;&ET97)A;"!L:6YE(&5N9',@
M*&YO="!R96-O;6UE;F1E9"DN"B`@*B!4;R!I;F-L=61E(&$@<VEN9VQE('%U
M;W1E(&-H87)A8W1E<BP@97-C87!E(&ET('=I=&@@82!@8%Q@8"`H8F%C:W-L
M87-H*0H@("`@8VAA<F%C=&5R+"!A<R!I;CH@8&!E8VAO("=(97)E7"=S(&%N
M(&5X86UP;&4G.V!@"B`@*B!4;R!S<&5C:69Y(&$@8&!<8&`@*&)A8VMS;&%S
M:"D@8VAA<F%C=&5R+"!D;W5B;&4@:70Z(&!@96-H;R`G8SI<7'1E;7`G.V!@
M"@I$;W5B;&4@475O=&5S.@H@("H@4&%R<V5S(&%N9"!E>'!A;F1S('9A<FEA
M8FQE<R!I;B!T:&4@<W1R:6YG+@H@("H@57-E<R!A9'9A;F-E9"`H8'-P<FEN
M=&9@7RUS='EL92D@97-C87!E('-E<75E;F-E<R!L:6ME(&!@7&Y@8"P@8&!<
M)&!@+`H@("`@8&!<=&!@+"!E=&,N"B`@*B!3:&]U;&0@8F4@=7-E9"!I;B!T
M:&4@9V5T=&5X="!S:&]R=&-U="!@8%\H(B(I8&`@9F]R;6%T+@H@("H@57-E
M('=I=&@@8V%R92P@87,@;6%N>2!C;W)R96-T(&QO;VMI;F<@<W1R:6YG<R!A
M<F4@<F5A;&QY(&EN=F%L:60N"@I4:&4@9F]L;&]W:6YG(&%R92!A;&P@:6YC
M;W)R96-T.CH*"B`@("!E8VAO(")4;V1A>2!I<R!T:&4@)&1A=&5;)V1A>2==
M(&]F("1D871E6R=M;VYT:"==(@H@("`@)%]315-324].6VEN9&5X72`]("1?
M4T534TE/3ELB;VQD7VEN9&5X(ET["@HN+B!?<W!R:6YT9CH@:'1T<#HO+W=W
M=RYP:'`N;F5T+W-P<FEN=&8*"@ID969I;F4H*0H]/3T]/3T]/0H*4W5R<')I
M<VEN9VQY(&5N;W5G:"P@8&1E9FEN92@I8%\@:7,@82!S;VUE=VAA="!S;&]W
M(&9U;F-T:6]N(&EN(%!(4"`H87,@;V8@4$A0"C0N,RYX*2!S;R!E>&-E<W-I
M=F4@=7-E(&ES(&1I<V-O=7)A9V5D+@H*57-I;F<@8&1E9FEN92@I8%\@:6X@
M8VQA<W-E<R!S:&]U;&0@8F4@3TL@+2!W92!W:6QL('-A8W)I9FEC92!A('1I
M;GD@8FET(&]F"G-P965D(&9O<B!R96%D86)I;&ET>2!O9B!C;V1E+B`@8&1E
M9FEN92@I8%\@<VAO=6QD($Y/5"!B92!U<V5D(&9O<B!A8W1I;VY)1',@+0IU
M<V4@82!P;&%I;B!O;&0@<W1R:6YG(&EN<W1E860N("!&;W(@86YY=&AI;F<@
M96QS92P@=7-E('EO=7(@8F5S="!J=61G;65N="X*"D%D9&ET:6]N86QL>2P@
M979E<GD@8V]N<W1A;G0@<VAO=6QD(&)E('!R969I>&5D('=I=&@@8&!(3U)$
M15]@8"P@:71S('!A8VMA9V4*;F%M92P@;W(@=&AE(&%P<&QI8V%T:6]N(&YA
M;64N"@HN+B!?9&5F:6YE*"DZ(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO
M96XO9G5N8W1I;VXN9&5F:6YE+G!H<`H*"E-E8W5R:71Y($-O;G-I9&5R871I
M;VYS"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@I4:&4@9F]L;&]W:6YG(&%R
M92!A(&YO;BUE>&AA=7-T:79E(&QI<W0@;V8@9F5A='5R97,O9G5N8W1I;VYS
M('1O('1A:V4*<W!E8VEA;"!C87)E('=I=&@Z"@I02%`@0V]D92!%>&5C=71I
M;VXZ"BTM+2TM+2TM+2TM+2TM+2TM+2T*"G)E<75I<F4L(&EN8VQU9&4L(')E
M<75I<F5?;VYC92P@:6YC;'5D95]O;F-E("T@0V%R969U;&QY(&%U9&ET(&%N
M>0IV87)I86)L97,@=7-E9"!I;B!T:&5S92!F=6YC=&EO;G,L(&%N9"!C:&5C
M:R!T:&4@<V]U<F-E(&]F(&%N>0IC;VYS=&%N=',@87,@=V5L;"X*"F5V86P@
M+2!/8G9I;W5S(&1A;F=E<B!I9B!U<V5R(&EN<'5T(&ES('-U<'!L:65D('1O
M(&ET(&EN('5N8V]N=')O;&QE9"!C;VYD:71I;VYS+@H*<')E9U]R97!L86-E
M("T@5&AE("]E(&UO9&EF:65R(&-A=7-E<R!T:&4@<F5P;&%C96UE;G0@<W1R
M:6YG('1O(&)E"F5V86QU871E9"!A<R!02%`@8V]D92X*"D-O;6UA;F0@17AE
M8W5T:6]N.@HM+2TM+2TM+2TM+2TM+2TM+2T*"F5X96,@+2!%>&5C=71E<R!A
M('-P96-I9FEE9"!C;VUM86YD(&%N9"!R971U<FYS('1H92!L87-T(&QI;F4@
M;V8@;W5T<'5T+@H*<&%S<W1H<G4@+2!%>&5C=71E<R!A('-P96-I9FEE9"!C
M;VUM86YD(&%N9"!W<FET97,@=&AE(&]U='!U="!T;R!35$1/550N"@I@8"`H
M8F%C:W1I8VMS*2`M($5X96-U=&5S('1H92!S<&5C:69I960@8V]M;6%N9"!A
M;F0@<F5T=7)N<R!A;&P@=&AE"F]U='!U="!I;B!A;B!A<G)A>2X*"G-Y<W1E
M;2`M($QI:V4@<&%S<W1H<G4H*2!B=70@9&]E<VXG="!H86YD;&4@8FEN87)Y
M(&1A=&$N"@IP;W!E;B`M($5X96-U=&5S(&$@<W!E8VEF:65D(&-O;6UA;F0@
M86YD(&-O;FYE8W1S(&ET<R!O=71P=70@;W(@:6YP=70*<W1R96%M('1O(&$@
M4$A0(&9I;&4@9&5S8W)I<'1O<BX*"D9I;&4@1&ES8VQO<W5R93H*+2TM+2TM
M+2TM+2TM+2TM+0H*1FEL92!F=6YC=&EO;G,@=VAI8V@@8V%N(&)E('!O=&5N
M=&EA;&QY('5S960@=&\@;W!E;B!R96UO=&4@;W(*=6YI;G1E;F1E9"!F:6QE
M<SH@9F]P96XL(')E861F:6QE+"!F:6QE+"!F:6QE7V=E=%]C;VYT96YT<RX*
M"@I/<'1I;6EZ871I;VYS"CT]/3T]/3T]/3T]/3T*"E1H92!F;VQL;W=I;F<@
M;W!T:6UI>F%T:6]N<R!S:&]U;&0@8F4@=7-E9"P@:68@<&]S<VEB;&4Z"@IE
M>'1E;G-I;VY?;&]A9&5D*"D*+2TM+2TM+2TM+2TM+2TM+2TM"E1H:7,@87!P
M96%R<R!T;R!B92!A;B!E>'!E;G-I=F4@4$A0(&-A;&PN("!5<V4@571I;#HZ
M97AT96YS:6]N17AI<W1S*"D*:6YS=&5A9"P@=VAI8V@@=VEL;"!C86-H92!T
M:&4@<F5S=6QT<R!O9B!T:&4@8V%L;"X*"D-O;F-A=&5N871E('-T<FEN9W,*
M+2TM+2TM+2TM+2TM+2TM+2TM+0I"=6EL9&EN9R!A('-T<FEN9R!W:71H(&-O
M;F-A=&5N871I;VX@*'1H92`B+B(@;W!E<F%T;W(I('5S:6YG"G-I;F=L92UQ
M=6]T960@<W1R:6YG<R!A;F0@=F%R:6%B;&5S(&ES(&9A<W1E<B!T:&%N('5S
M:6YG(&%N"FEN=&5R<&]L871E9"!S=')I;F<@*&$@<W1R:6YG(&EN<VED92!D
M;W5B;&4@<75O=&5S('=I=&@@=F%R:6%B;&5S"FEN<VED92!T:&4@<W1R:6YG
M(&ET<V5L9BDN("!);B!A9&1I=&EO;BP@8V]N8V%T96YA=&EO;B!I<R!E87-I
M97(@=&\*<F5A9"!A;F0@875D:70@9F]R(&QO9VEC(&%N9"!S96-U<FET>2!P
M<F]B;&5M<RX*"E!R92UI;F-R96UE;G0O9&5C<F5M96YT"BTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM"D)E8V%U<V4@;V8@=&AE('=A>2!C;VUP:6QE<G,O:6YT
M97)P<F5T97)S('=O<FLL('!O<W0M:6YC<F5M96YT:6YG"B@D=F%R*RLI(')E
M<75I<F5S('-T;W)I;F<@8F]T:"!T:&4@;W)I9VEN86P@86YD(&YE=R!V86QU
M97,@;V8@=&AE"G9A<FEA8FQE(&EN(&UE;6]R>2!B96-A=7-E('1H92!O;&0@
M=F%L=64@;6%Y(&)E('5S960@869T97(@=&AE"F]P97)A=&EO;B!I;B!Q=65S
M=&EO;B!I<R!C;VUP;&5T92X@($)Y(&-O;7!A<FES;VXL('!R92UI;F-R96UE
M;G1I;F<**"LK)'9A<BD@86QM;W-T(&YE=F5R(&YE961S('1O('-T;W)E(&)O
M=&@@=F%L=65S+B`@270G<R!A(&UA<F=I;F%L"G-P965D=7`@8G5T(&ET)W,@
M86QS;R!S:6UP;'D@8VAA;F=I;F<@=&AE(&]R9&5R(&]F(&$@9F5W(&-H87)A
M8W1E<G,N"@I,;V]P<PHM+2TM+0I-86ME('-U<F4@=&AA="!Y;W4@9&\@;F]T
M(&-O;G1I;G5E('1O(&1E9FEN92!T:&4@<V%M92!V87)I86)L92!W:71H:6X@
M80IL;V]P+B`@26YS=&5A9"P@9&5C;&%R92!T:&4@=F%R:6%B;&4@82!S:6YG
M;&4@=&EM92!B969O<F4@=&AE(&QO;W`@:7,@<G5N+@H*07)R87D*+2TM+2T*
M079O:60@9G)E<75E;G0@87)R87D@86-C97-S97,N("!)9B!Y;W4@=7-E(&%N
M(&%R<F%Y(&]R(&%N(&%R<F%Y(&UE;6)E<B!I;B!A"FQO;W`L(&%S<VEG;B!I
M="!T;R!A('9A<FEA8FQE(&9I<G-T.CH*"B`@("`D82`](&%R<F%Y*"=X)R`]
M/B`G>2<I.PH@("`@)&5N=')I97,@/2!A<G)A>2@N+BXI.PH*("`@("1L96YG
M=&@@/2!C;W5N="@D96YT<FEE<RD["B`@("`D>"`]("1A6R=X)UT["B`@("!F
M;W(@*"1I(#T@,#L@)&D@/"`D;&5N9W1H.R`K*R1I*2!["B`@("`@("`@96-H
M;R`D>#L*("`@('T*"E5S97(@9&5F:6YE9"!F=6YC=&EO;G,*+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+0I5<V5R(&1E9FEN960@9G5N8W1I;VYS(&%R92!M;W)E
M(&5X<&5N<VEV92!T:&%N(")R96=U;&%R(B!F=6YC=&EO;G,N("!5<V4@=&AE
M;0IO;FQY(&EF('1H97D@:6UP<F]V92!T:&4@8V]D92!R96%D86)I;&ET>2!M
M;W)E('1H96X@<F5G=6QA<B!F=6YC=&EO;G,N"@I$:7-K($DO3PHM+2TM+2TM
M+0I$:7-K(')E860@86YD('=R:71E(&]P97)A=&EO;G,@87)E('-L;W<N("!)
M9B!P;W-S:6)L92!R96%D(&%N9"!W<FET92!F:6QE<R!I;@IL87)G92!C:'5N
M:W,N("!!8V-O<F1I;F<@=&\@4$A0(&1O8W5M96YT871I;VXL(&9I;&5?9V5T
M7V-O;G1E;G1S*"D@:7,*<&]T96YT:6%L;'D@;75C:"!F87-T97(@=&AA;B!U
M<VEN9R!F;W!E;B@I+V9R96%D*"DO9F-L;W-E*"DN"@H*4U1$24XO4U1$3U54
M+U-41$524@H]/3T]/3T]/3T]/3T]/3T]/3T]"@I4;R!A8V-E<W,@96ET:&5R
M(%-41$E.+"!35$1/550L(&]R(%-41$524BP@=&AE(&9O;&QO=VEN9R!C;V1E
M('-H;W5L9"!B92!U<V5D.CH*"B`@("!W:&EL92`H(69E;V8H6U-41$E.?%-4
M1$]55'Q35$1%4E)=*2D@>PH@("`@("`@("1L:6YE(#T@9F=E=',H6U-41$E.
M?%-41$]55'Q35$1%4E)=*3L*("`@("`@("`O+R!P<F]C97-S("1L:6YE(&AE
M<F4*("`@('T*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]D;V-S
M+T-/3E1224)55$E.1P``````````````````````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`S,30T`#$P-3$U-#,S-S0S`#`R,#0T,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````]/3T]/3T]/3T]/3T]
M/3T]/3T]/0H@2&]R9&4Z($AO=R!T;R!(96QP"CT]/3T]/3T]/3T]/3T]/3T]
M/3T]"@HZ3&%S="!U<&1A=&4Z("`@)$1A=&4Z(#(P,#0O,#DO,C0@,C$Z,#(Z
M,#$@)`HZ4F5V:7-I;VXZ("`@("`@)%)E=FES:6]N.B`Q+C0@)`HZ0V]N=&%C
M=#H@("`@("`@8V]R94!H;W)D92YO<F<*"E1H97)E(&%R92!M86YY('=A>7,@
M:6X@=VAI8V@@>6]U(&-A;B!H96QP(&]U="!I;B!T:&4@9&5V96QO<&UE;G0@
M;V8@86YY(&]F('1H90I(;W)D92!P<F]J96-T<RX@5&AE(&9I<G-T(&%N9"!B
M97-T('=A>2!Y;W4@87)E(&%L<F5A9'D@9&]I;F<Z('EO=2=R92!U<VEN9PIT
M:&5M+B!/;F4@;V8@=&AE(&ME>7,@=&\@82!G<F5A="!P<F]D=6-T(&ES(&ET
M<R!U<V5R<RX@5VET:&]U="!U<V5R<R!W92!C86XG=`IF:6YD(&)U9W,@;W(@
M9V5T(&9E961B86-K(&]N('=H870G<R!G;V]D(&%N9"!W:&%T)W,@8F%D+@H*
M270@:7,@9&%R;B!N96%R(&EM<&]S<VEB;&4@9F]R('1H92!D979E;&]P97)S
M('1O('1E<W0@=&AE(&-O9&4@;VX@979E<GD*3W!E<F%T:6YG(%-Y<W1E;2!A
M;F0@979E<GD@9&EF9F5R96YT('9E<G-I;VX@;V8@5V5B($)R;W=S97(@879A
M:6QA8FQE('1O(&UA:V4*<W5R92!T:&4@8V]D92!R=6YS('-M;V]T:&QY(&5V
M97)Y=VAE<F4N("!,:6YU>"!I<R!N;W0@5VEN9&]W<RP@86YD($E%(&ES(&YO
M=`I-;WII;&QA+"!A;F0@:70@:7,@*&9R97%U96YT;'DI(&1I9F9I8W5L="!T
M;R!T;R!P<F5D:6-T(&)E:&%V:6]R(&)E='=E96X*<&QA=&9O<FUS+V)R;W=S
M97)S+@H*5VET:"!T:&ES('-A:60L(&]N92!O9B!T:&4@8F5S="!W87ES('EO
M=2!C86X@:&5L<"!I<R!T;R!T97-T+B!)9B!Y;W4@8V%N(&AE;'`*=7,@<VUO
M;W1H(&]U="!T:&4@8V]D92!A8W)O<W,@86QL("AO<B!E=F5N(&%N>2D@<&QA
M=&9O<FUS+"!Y;W4G<F4@9&]I;F<@80IG<F5A="!S97)V:6-E('1O('1H92!P
M<F]J96-T+@H*3F]W+"!I9B!T:&%T)W,@;F]T(&5N;W5G:"!A;F0@>6]U('=A
M;G0@=&\@9&EG(&EN(&%N9"!H96QP(&-O9&4L('EO=2!S:&]U;&0*9FER<W0@
M<W5B<V-R:6)E('1O('1H92!P<F]J96-T(&QI<W1S+"!P87)T:6-U;&%R;'D@
M=&AE(&=E;F5R86P@2&]R9&4*9&5V96QO<&5R<R!L:7-T(&1E=D!L:7-T<RYH
M;W)D92YO<F<@*'-E92!H='1P.B\O=W=W+FAO<F1E+F]R9R]M86EL+R!F;W(*
M:6YF;W)M871I;VX@;VX@<W5B<V-R:6)I;F<@=&\@=&AE(&UA:6QI;F<@;&ES
M=',I+B`@061D:71I;VYA;&QY+"!Y;W4@*BI-55-4*BH*<F5A9"!T:&4@8$AO
M<F1E($-O9&EN9R!3=&%N9&%R9'-@7R!T;R!E;G-U<F4@=&AA="!T:&4@8V]D
M92!Y;W5R('-U8FUI='1I;F<*=VEL;"!W86YT('1O(&)E(&%N86QY>F5D(&%N
M9"!P;W1E;G1I86QL>2!C;VUM:71T960@8GD@=&AE(&1E=F5L;W!E<G,N("!9
M;W4*<VAO=6QD('!R;V)A8FQY(')E860@=&AE('9A<FEO=7,@4D5!1$U%(&9I
M;&5S("AF;W(@=&AA="!M871T97(L(&%L;"!T:&4*9&]C=6UE;G1A=&EO;B!I
M;B!T:&4@8&!D;V-S+V!@(&1I<F5C=&]R>2D@9F]R('1H92!P87)T:6-U;&%R
M(&%P<&QI8V%T:6]N('EO=0IA<F4@=V]R:VEN9R!O;B!A;'-O+@H*+BX@7V!(
M;W)D92!#;V1I;F<@4W1A;F1A<F1S8#H@/V8]0T]$24Y'7U-404Y$05)$4RYH
M=&UL````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O9&]C<R]#3U!9
M24Y'````````````````````````````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`V,3(W,P`Q,#4Q-30S,S<T,P`P,3<V-3$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````"0D@($=.52!,24)205)9($=%
M3D5204P@4%5"3$E#($Q)0T5.4T4*"0D@("`@("`@5F5R<VEO;B`R+"!*=6YE
M(#$Y.3$*"B!#;W!Y<FEG:'0@*$,I(#$Y.3$@1G)E92!3;V9T=V%R92!&;W5N
M9&%T:6]N+"!);F,N"B`@("`)"2`@("`U.2!496UP;&4@4&QA8V4L(%-U:71E
M(#,S,"P@0F]S=&]N+"!-02`@,#(Q,3$M,3,P-R`@55-!"B!%=F5R>6]N92!I
M<R!P97)M:71T960@=&\@8V]P>2!A;F0@9&ES=')I8G5T92!V97)B871I;2!C
M;W!I97,*(&]F('1H:7,@;&EC96YS92!D;V-U;65N="P@8G5T(&-H86YG:6YG
M(&ET(&ES(&YO="!A;&QO=V5D+@H*6U1H:7,@:7,@=&AE(&9I<G-T(')E;&5A
M<V5D('9E<G-I;VX@;V8@=&AE(&QI8G)A<GD@1U!,+B`@270@:7,*(&YU;6)E
M<F5D(#(@8F5C875S92!I="!G;V5S('=I=&@@=F5R<VEO;B`R(&]F('1H92!O
M<F1I;F%R>2!'4$PN70H*"0D)("`@(%!R96%M8FQE"@H@(%1H92!L:6-E;G-E
M<R!F;W(@;6]S="!S;V9T=V%R92!A<F4@9&5S:6=N960@=&\@=&%K92!A=V%Y
M('EO=7(*9G)E961O;2!T;R!S:&%R92!A;F0@8VAA;F=E(&ET+B`@0GD@8V]N
M=')A<W0L('1H92!'3E4@1V5N97)A;"!0=6)L:6,*3&EC96YS97,@87)E(&EN
M=&5N9&5D('1O(&=U87)A;G1E92!Y;W5R(&9R965D;VT@=&\@<VAA<F4@86YD
M(&-H86YG90IF<F5E('-O9G1W87)E+2UT;R!M86ME('-U<F4@=&AE('-O9G1W
M87)E(&ES(&9R964@9F]R(&%L;"!I=',@=7-E<G,N"@H@(%1H:7,@;&EC96YS
M92P@=&AE($QI8G)A<GD@1V5N97)A;"!0=6)L:6,@3&EC96YS92P@87!P;&EE
M<R!T;R!S;VUE"G-P96-I86QL>2!D97-I9VYA=&5D($9R964@4V]F='=A<F4@
M1F]U;F1A=&EO;B!S;V9T=V%R92P@86YD('1O(&%N>0IO=&AE<B!L:6)R87)I
M97,@=VAO<V4@875T:&]R<R!D96-I9&4@=&\@=7-E(&ET+B`@66]U(&-A;B!U
M<V4@:70@9F]R"GEO=7(@;&EB<F%R:65S+"!T;V\N"@H@(%=H96X@=V4@<W!E
M86L@;V8@9G)E92!S;V9T=V%R92P@=V4@87)E(')E9F5R<FEN9R!T;R!F<F5E
M9&]M+"!N;W0*<')I8V4N("!/=7(@1V5N97)A;"!0=6)L:6,@3&EC96YS97,@
M87)E(&1E<VEG;F5D('1O(&UA:V4@<W5R92!T:&%T('EO=0IH879E('1H92!F
M<F5E9&]M('1O(&1I<W1R:6)U=&4@8V]P:65S(&]F(&9R964@<V]F='=A<F4@
M*&%N9"!C:&%R9V4@9F]R"G1H:7,@<V5R=FEC92!I9B!Y;W4@=VES:"DL('1H
M870@>6]U(')E8V5I=F4@<V]U<F-E(&-O9&4@;W(@8V%N(&=E="!I=`II9B!Y
M;W4@=V%N="!I="P@=&AA="!Y;W4@8V%N(&-H86YG92!T:&4@<V]F='=A<F4@
M;W(@=7-E('!I96-E<R!O9B!I=`II;B!N97<@9G)E92!P<F]G<F%M<SL@86YD
M('1H870@>6]U(&MN;W<@>6]U(&-A;B!D;R!T:&5S92!T:&EN9W,N"@H@(%1O
M('!R;W1E8W0@>6]U<B!R:6=H=',L('=E(&YE960@=&\@;6%K92!R97-T<FEC
M=&EO;G,@=&AA="!F;W)B:60*86YY;VYE('1O(&1E;GD@>6]U('1H97-E(')I
M9VAT<R!O<B!T;R!A<VL@>6]U('1O('-U<G)E;F1E<B!T:&4@<FEG:'1S+@I4
M:&5S92!R97-T<FEC=&EO;G,@=')A;G-L871E('1O(&-E<G1A:6X@<F5S<&]N
M<VEB:6QI=&EE<R!F;W(@>6]U(&EF"GEO=2!D:7-T<FEB=71E(&-O<&EE<R!O
M9B!T:&4@;&EB<F%R>2P@;W(@:68@>6]U(&UO9&EF>2!I="X*"B`@1F]R(&5X
M86UP;&4L(&EF('EO=2!D:7-T<FEB=71E(&-O<&EE<R!O9B!T:&4@;&EB<F%R
M>2P@=VAE=&AE<B!G<F%T:7,*;W(@9F]R(&$@9F5E+"!Y;W4@;75S="!G:79E
M('1H92!R96-I<&EE;G1S(&%L;"!T:&4@<FEG:'1S('1H870@=V4@9V%V90IY
M;W4N("!9;W4@;75S="!M86ME('-U<F4@=&AA="!T:&5Y+"!T;V\L(')E8V5I
M=F4@;W(@8V%N(&=E="!T:&4@<V]U<F-E"F-O9&4N("!)9B!Y;W4@;&EN:R!A
M('!R;V=R86T@=VET:"!T:&4@;&EB<F%R>2P@>6]U(&UU<W0@<')O=FED90IC
M;VUP;&5T92!O8FIE8W0@9FEL97,@=&\@=&AE(')E8VEP:65N=',@<V\@=&AA
M="!T:&5Y(&-A;B!R96QI;FL@=&AE;0IW:71H('1H92!L:6)R87)Y+"!A9G1E
M<B!M86MI;F<@8VAA;F=E<R!T;R!T:&4@;&EB<F%R>2!A;F0@<F5C;VUP:6QI
M;F<*:70N("!!;F0@>6]U(&UU<W0@<VAO=R!T:&5M('1H97-E('1E<FUS('-O
M('1H97D@:VYO=R!T:&5I<B!R:6=H=',N"@H@($]U<B!M971H;V0@;V8@<')O
M=&5C=&EN9R!Y;W5R(')I9VAT<R!H87,@='=O('-T97!S.B`H,2D@8V]P>7)I
M9VAT"G1H92!L:6)R87)Y+"!A;F0@*#(I(&]F9F5R('EO=2!T:&ES(&QI8V5N
M<V4@=VAI8V@@9VEV97,@>6]U(&QE9V%L"G!E<FUI<W-I;VX@=&\@8V]P>2P@
M9&ES=')I8G5T92!A;F0O;W(@;6]D:69Y('1H92!L:6)R87)Y+@H*("!!;'-O
M+"!F;W(@96%C:"!D:7-T<FEB=71O<B=S('!R;W1E8W1I;VXL('=E('=A;G0@
M=&\@;6%K92!C97)T86EN"G1H870@979E<GEO;F4@=6YD97)S=&%N9',@=&AA
M="!T:&5R92!I<R!N;R!W87)R86YT>2!F;W(@=&AI<R!F<F5E"FQI8G)A<GDN
M("!)9B!T:&4@;&EB<F%R>2!I<R!M;V1I9FEE9"!B>2!S;VUE;VYE(&5L<V4@
M86YD('!A<W-E9"!O;BP@=V4*=V%N="!I=',@<F5C:7!I96YT<R!T;R!K;F]W
M('1H870@=VAA="!T:&5Y(&AA=F4@:7,@;F]T('1H92!O<FEG:6YA;`IV97)S
M:6]N+"!S;R!T:&%T(&%N>2!P<F]B;&5M<R!I;G1R;V1U8V5D(&)Y(&]T:&5R
M<R!W:6QL(&YO="!R969L96-T(&]N"G1H92!O<FEG:6YA;"!A=71H;W)S)R!R
M97!U=&%T:6]N<RX*#`H@($9I;F%L;'DL(&%N>2!F<F5E('!R;V=R86T@:7,@
M=&AR96%T96YE9"!C;VYS=&%N=&QY(&)Y('-O9G1W87)E"G!A=&5N=',N("!7
M92!W:7-H('1O(&%V;VED('1H92!D86YG97(@=&AA="!C;VUP86YI97,@9&ES
M=')I8G5T:6YG(&9R964*<V]F='=A<F4@=VEL;"!I;F1I=FED=6%L;'D@;V)T
M86EN('!A=&5N="!L:6-E;G-E<RP@=&AU<R!I;B!E9F9E8W0*=')A;G-F;W)M
M:6YG('1H92!P<F]G<F%M(&EN=&\@<')O<')I971A<GD@<V]F='=A<F4N("!4
M;R!P<F5V96YT('1H:7,L"G=E(&AA=F4@;6%D92!I="!C;&5A<B!T:&%T(&%N
M>2!P871E;G0@;75S="!B92!L:6-E;G-E9"!F;W(@979E<GEO;F4G<PIF<F5E
M('5S92!O<B!N;W0@;&EC96YS960@870@86QL+@H*("!-;W-T($=.52!S;V9T
M=V%R92P@:6YC;'5D:6YG('-O;64@;&EB<F%R:65S+"!I<R!C;W9E<F5D(&)Y
M('1H92!O<F1I;F%R>0I'3E4@1V5N97)A;"!0=6)L:6,@3&EC96YS92P@=VAI
M8V@@=V%S(&1E<VEG;F5D(&9O<B!U=&EL:71Y('!R;V=R86US+B`@5&AI<PIL
M:6-E;G-E+"!T:&4@1TY5($QI8G)A<GD@1V5N97)A;"!0=6)L:6,@3&EC96YS
M92P@87!P;&EE<R!T;R!C97)T86EN"F1E<VEG;F%T960@;&EB<F%R:65S+B`@
M5&AI<R!L:6-E;G-E(&ES('%U:71E(&1I9F9E<F5N="!F<F]M('1H92!O<F1I
M;F%R>0IO;F4[(&)E('-U<F4@=&\@<F5A9"!I="!I;B!F=6QL+"!A;F0@9&]N
M)W0@87-S=6UE('1H870@86YY=&AI;F<@:6X@:70@:7,*=&AE('-A;64@87,@
M:6X@=&AE(&]R9&EN87)Y(&QI8V5N<V4N"@H@(%1H92!R96%S;VX@=V4@:&%V
M92!A('-E<&%R871E('!U8FQI8R!L:6-E;G-E(&9O<B!S;VUE(&QI8G)A<FEE
M<R!I<R!T:&%T"G1H97D@8FQU<B!T:&4@9&ES=&EN8W1I;VX@=V4@=7-U86QL
M>2!M86ME(&)E='=E96X@;6]D:69Y:6YG(&]R(&%D9&EN9R!T;R!A"G!R;V=R
M86T@86YD('-I;7!L>2!U<VEN9R!I="X@($QI;FMI;F<@82!P<F]G<F%M('=I
M=&@@82!L:6)R87)Y+"!W:71H;W5T"F-H86YG:6YG('1H92!L:6)R87)Y+"!I
M<R!I;B!S;VUE('-E;G-E('-I;7!L>2!U<VEN9R!T:&4@;&EB<F%R>2P@86YD
M(&ES"F%N86QO9V]U<R!T;R!R=6YN:6YG(&$@=71I;&ET>2!P<F]G<F%M(&]R
M(&%P<&QI8V%T:6]N('!R;V=R86TN("!(;W=E=F5R+"!I;@IA('1E>'1U86P@
M86YD(&QE9V%L('-E;G-E+"!T:&4@;&EN:V5D(&5X96-U=&%B;&4@:7,@82!C
M;VUB:6YE9"!W;W)K+"!A"F1E<FEV871I=F4@;V8@=&AE(&]R:6=I;F%L(&QI
M8G)A<GDL(&%N9"!T:&4@;W)D:6YA<GD@1V5N97)A;"!0=6)L:6,@3&EC96YS
M90IT<F5A=',@:70@87,@<W5C:"X*"B`@0F5C875S92!O9B!T:&ES(&)L=7)R
M960@9&ES=&EN8W1I;VXL('5S:6YG('1H92!O<F1I;F%R>2!'96YE<F%L"E!U
M8FQI8R!,:6-E;G-E(&9O<B!L:6)R87)I97,@9&ED(&YO="!E9F9E8W1I=F5L
M>2!P<F]M;W1E('-O9G1W87)E"G-H87)I;F<L(&)E8V%U<V4@;6]S="!D979E
M;&]P97)S(&1I9"!N;W0@=7-E('1H92!L:6)R87)I97,N("!790IC;VYC;'5D
M960@=&AA="!W96%K97(@8V]N9&ET:6]N<R!M:6=H="!P<F]M;W1E('-H87)I
M;F<@8F5T=&5R+@H*("!(;W=E=F5R+"!U;G)E<W1R:6-T960@;&EN:VEN9R!O
M9B!N;VXM9G)E92!P<F]G<F%M<R!W;W5L9"!D97!R:79E('1H90IU<V5R<R!O
M9B!T:&]S92!P<F]G<F%M<R!O9B!A;&P@8F5N969I="!F<F]M('1H92!F<F5E
M('-T871U<R!O9B!T:&4*;&EB<F%R:65S('1H96US96QV97,N("!4:&ES($QI
M8G)A<GD@1V5N97)A;"!0=6)L:6,@3&EC96YS92!I<R!I;G1E;F1E9"!T;PIP
M97)M:70@9&5V96QO<&5R<R!O9B!N;VXM9G)E92!P<F]G<F%M<R!T;R!U<V4@
M9G)E92!L:6)R87)I97,L('=H:6QE"G!R97-E<G9I;F<@>6]U<B!F<F5E9&]M
M(&%S(&$@=7-E<B!O9B!S=6-H('!R;V=R86US('1O(&-H86YG92!T:&4@9G)E
M90IL:6)R87)I97,@=&AA="!A<F4@:6YC;W)P;W)A=&5D(&EN('1H96TN("`H
M5V4@:&%V92!N;W0@<V5E;B!H;W<@=&\@86-H:65V90IT:&ES(&%S(')E9V%R
M9',@8VAA;F=E<R!I;B!H96%D97(@9FEL97,L(&)U="!W92!H879E(&%C:&EE
M=F5D(&ET(&%S(')E9V%R9',*8VAA;F=E<R!I;B!T:&4@86-T=6%L(&9U;F-T
M:6]N<R!O9B!T:&4@3&EB<F%R>2XI("!4:&4@:&]P92!I<R!T:&%T('1H:7,*
M=VEL;"!L96%D('1O(&9A<W1E<B!D979E;&]P;65N="!O9B!F<F5E(&QI8G)A
M<FEE<RX*"B`@5&AE('!R96-I<V4@=&5R;7,@86YD(&-O;F1I=&EO;G,@9F]R
M(&-O<'EI;F<L(&1I<W1R:6)U=&EO;B!A;F0*;6]D:69I8V%T:6]N(&9O;&QO
M=RX@(%!A>2!C;&]S92!A='1E;G1I;VX@=&\@=&AE(&1I9F9E<F5N8V4@8F5T
M=V5E;B!A"B)W;W)K(&)A<V5D(&]N('1H92!L:6)R87)Y(B!A;F0@82`B=V]R
M:R!T:&%T('5S97,@=&AE(&QI8G)A<GDB+B`@5&AE"F9O<FUE<B!C;VYT86EN
M<R!C;V1E(&1E<FEV960@9G)O;2!T:&4@;&EB<F%R>2P@=VAI;&4@=&AE(&QA
M='1E<B!O;FQY"G=O<FMS('1O9V5T:&5R('=I=&@@=&AE(&QI8G)A<GDN"@H@
M($YO=&4@=&AA="!I="!I<R!P;W-S:6)L92!F;W(@82!L:6)R87)Y('1O(&)E
M(&-O=F5R960@8GD@=&AE(&]R9&EN87)Y"D=E;F5R86P@4'5B;&EC($QI8V5N
M<V4@<F%T:&5R('1H86X@8GD@=&AI<R!S<&5C:6%L(&]N92X*#`H)"2`@1TY5
M($Q)0E)!4ED@1T5.15)!3"!054),24,@3$E#14Y310H@("!415)-4R!!3D0@
M0T].1$E424].4R!&3U(@0T]064E.1RP@1$E35%))0E5424].($%.1"!-3T1)
M1DE#051)3TX*"B`@,"X@5&AI<R!,:6-E;G-E($%G<F5E;65N="!A<'!L:65S
M('1O(&%N>2!S;V9T=V%R92!L:6)R87)Y('=H:6-H"F-O;G1A:6YS(&$@;F]T
M:6-E('!L86-E9"!B>2!T:&4@8V]P>7)I9VAT(&AO;&1E<B!O<B!O=&AE<B!A
M=71H;W)I>F5D"G!A<G1Y('-A>6EN9R!I="!M87D@8F4@9&ES=')I8G5T960@
M=6YD97(@=&AE('1E<FUS(&]F('1H:7,@3&EB<F%R>0I'96YE<F%L(%!U8FQI
M8R!,:6-E;G-E("AA;'-O(&-A;&QE9"`B=&AI<R!,:6-E;G-E(BDN("!%86-H
M(&QI8V5N<V5E(&ES"F%D9')E<W-E9"!A<R`B>6]U(BX*"B`@02`B;&EB<F%R
M>2(@;65A;G,@82!C;VQL96-T:6]N(&]F('-O9G1W87)E(&9U;F-T:6]N<R!A
M;F0O;W(@9&%T80IP<F5P87)E9"!S;R!A<R!T;R!B92!C;VYV96YI96YT;'D@
M;&EN:V5D('=I=&@@87!P;&EC871I;VX@<')O9W)A;7,**'=H:6-H('5S92!S
M;VUE(&]F('1H;W-E(&9U;F-T:6]N<R!A;F0@9&%T82D@=&\@9F]R;2!E>&5C
M=71A8FQE<RX*"B`@5&AE("),:6)R87)Y(BP@8F5L;W<L(')E9F5R<R!T;R!A
M;GD@<W5C:"!S;V9T=V%R92!L:6)R87)Y(&]R('=O<FL*=VAI8V@@:&%S(&)E
M96X@9&ES=')I8G5T960@=6YD97(@=&AE<V4@=&5R;7,N("!!(")W;W)K(&)A
M<V5D(&]N('1H90I,:6)R87)Y(B!M96%N<R!E:71H97(@=&AE($QI8G)A<GD@
M;W(@86YY(&1E<FEV871I=F4@=V]R:R!U;F1E<@IC;W!Y<FEG:'0@;&%W.B!T
M:&%T(&ES('1O('-A>2P@82!W;W)K(&-O;G1A:6YI;F<@=&AE($QI8G)A<GD@
M;W(@80IP;W)T:6]N(&]F(&ET+"!E:71H97(@=F5R8F%T:6T@;W(@=VET:"!M
M;V1I9FEC871I;VYS(&%N9"]O<B!T<F%N<VQA=&5D"G-T<F%I9VAT9F]R=V%R
M9&QY(&EN=&\@86YO=&AE<B!L86YG=6%G92X@("A(97)E:6YA9G1E<BP@=')A
M;G-L871I;VX@:7,*:6YC;'5D960@=VET:&]U="!L:6UI=&%T:6]N(&EN('1H
M92!T97)M(")M;V1I9FEC871I;VXB+BD*"B`@(E-O=7)C92!C;V1E(B!F;W(@
M82!W;W)K(&UE86YS('1H92!P<F5F97)R960@9F]R;2!O9B!T:&4@=V]R:R!F
M;W(*;6%K:6YG(&UO9&EF:6-A=&EO;G,@=&\@:70N("!&;W(@82!L:6)R87)Y
M+"!C;VUP;&5T92!S;W5R8V4@8V]D92!M96%N<PIA;&P@=&AE('-O=7)C92!C
M;V1E(&9O<B!A;&P@;6]D=6QE<R!I="!C;VYT86EN<RP@<&QU<R!A;GD@87-S
M;V-I871E9`II;G1E<F9A8V4@9&5F:6YI=&EO;B!F:6QE<RP@<&QU<R!T:&4@
M<V-R:7!T<R!U<V5D('1O(&-O;G1R;VP@8V]M<&EL871I;VX*86YD(&EN<W1A
M;&QA=&EO;B!O9B!T:&4@;&EB<F%R>2X*"B`@06-T:79I=&EE<R!O=&AE<B!T
M:&%N(&-O<'EI;F<L(&1I<W1R:6)U=&EO;B!A;F0@;6]D:69I8V%T:6]N(&%R
M92!N;W0*8V]V97)E9"!B>2!T:&ES($QI8V5N<V4[('1H97D@87)E(&]U='-I
M9&4@:71S('-C;W!E+B`@5&AE(&%C="!O9@IR=6YN:6YG(&$@<')O9W)A;2!U
M<VEN9R!T:&4@3&EB<F%R>2!I<R!N;W0@<F5S=')I8W1E9"P@86YD(&]U='!U
M="!F<F]M"G-U8V@@82!P<F]G<F%M(&ES(&-O=F5R960@;VYL>2!I9B!I=',@
M8V]N=&5N=',@8V]N<W1I='5T92!A('=O<FL@8F%S960*;VX@=&AE($QI8G)A
M<GD@*&EN9&5P96YD96YT(&]F('1H92!U<V4@;V8@=&AE($QI8G)A<GD@:6X@
M82!T;V]L(&9O<@IW<FET:6YG(&ET*2X@(%=H971H97(@=&AA="!I<R!T<G5E
M(&1E<&5N9',@;VX@=VAA="!T:&4@3&EB<F%R>2!D;V5S"F%N9"!W:&%T('1H
M92!P<F]G<F%M('1H870@=7-E<R!T:&4@3&EB<F%R>2!D;V5S+@H@(`H@(#$N
M(%EO=2!M87D@8V]P>2!A;F0@9&ES=')I8G5T92!V97)B871I;2!C;W!I97,@
M;V8@=&AE($QI8G)A<GDG<PIC;VUP;&5T92!S;W5R8V4@8V]D92!A<R!Y;W4@
M<F5C96EV92!I="P@:6X@86YY(&UE9&EU;2P@<')O=FED960@=&AA=`IY;W4@
M8V]N<W!I8W5O=7-L>2!A;F0@87!P<F]P<FEA=&5L>2!P=6)L:7-H(&]N(&5A
M8V@@8V]P>2!A;@IA<'!R;W!R:6%T92!C;W!Y<FEG:'0@;F]T:6-E(&%N9"!D
M:7-C;&%I;65R(&]F('=A<G)A;G1Y.R!K965P(&EN=&%C=`IA;&P@=&AE(&YO
M=&EC97,@=&AA="!R969E<B!T;R!T:&ES($QI8V5N<V4@86YD('1O('1H92!A
M8G-E;F-E(&]F(&%N>0IW87)R86YT>3L@86YD(&1I<W1R:6)U=&4@82!C;W!Y
M(&]F('1H:7,@3&EC96YS92!A;&]N9R!W:71H('1H90I,:6)R87)Y+@H*("!9
M;W4@;6%Y(&-H87)G92!A(&9E92!F;W(@=&AE('!H>7-I8V%L(&%C="!O9B!T
M<F%N<V9E<G)I;F<@82!C;W!Y+`IA;F0@>6]U(&UA>2!A="!Y;W5R(&]P=&EO
M;B!O9F9E<B!W87)R86YT>2!P<F]T96-T:6]N(&EN(&5X8VAA;F=E(&9O<B!A
M"F9E92X*#`H@(#(N(%EO=2!M87D@;6]D:69Y('EO=7(@8V]P>2!O<B!C;W!I
M97,@;V8@=&AE($QI8G)A<GD@;W(@86YY('!O<G1I;VX*;V8@:70L('1H=7,@
M9F]R;6EN9R!A('=O<FL@8F%S960@;VX@=&AE($QI8G)A<GDL(&%N9"!C;W!Y
M(&%N9`ID:7-T<FEB=71E('-U8V@@;6]D:69I8V%T:6]N<R!O<B!W;W)K('5N
M9&5R('1H92!T97)M<R!O9B!396-T:6]N(#$*86)O=F4L('!R;W9I9&5D('1H
M870@>6]U(&%L<V\@;65E="!A;&P@;V8@=&AE<V4@8V]N9&ET:6]N<SH*"B`@
M("!A*2!4:&4@;6]D:69I960@=V]R:R!M=7-T(&ET<V5L9B!B92!A('-O9G1W
M87)E(&QI8G)A<GDN"@H@("`@8BD@66]U(&UU<W0@8V%U<V4@=&AE(&9I;&5S
M(&UO9&EF:65D('1O(&-A<G)Y('!R;VUI;F5N="!N;W1I8V5S"B`@("!S=&%T
M:6YG('1H870@>6]U(&-H86YG960@=&AE(&9I;&5S(&%N9"!T:&4@9&%T92!O
M9B!A;GD@8VAA;F=E+@H*("`@(&,I(%EO=2!M=7-T(&-A=7-E('1H92!W:&]L
M92!O9B!T:&4@=V]R:R!T;R!B92!L:6-E;G-E9"!A="!N;PH@("`@8VAA<F=E
M('1O(&%L;"!T:&ER9"!P87)T:65S('5N9&5R('1H92!T97)M<R!O9B!T:&ES
M($QI8V5N<V4N"@H@("`@9"D@268@82!F86-I;&ET>2!I;B!T:&4@;6]D:69I
M960@3&EB<F%R>2!R969E<G,@=&\@82!F=6YC=&EO;B!O<B!A"B`@("!T86)L
M92!O9B!D871A('1O(&)E('-U<'!L:65D(&)Y(&%N(&%P<&QI8V%T:6]N('!R
M;V=R86T@=&AA="!U<V5S"B`@("!T:&4@9F%C:6QI='DL(&]T:&5R('1H86X@
M87,@86X@87)G=6UE;G0@<&%S<V5D('=H96X@=&AE(&9A8VEL:71Y"B`@("!I
M<R!I;G9O:V5D+"!T:&5N('EO=2!M=7-T(&UA:V4@82!G;V]D(&9A:71H(&5F
M9F]R="!T;R!E;G-U<F4@=&AA="P*("`@(&EN('1H92!E=F5N="!A;B!A<'!L
M:6-A=&EO;B!D;V5S(&YO="!S=7!P;'D@<W5C:"!F=6YC=&EO;B!O<@H@("`@
M=&%B;&4L('1H92!F86-I;&ET>2!S=&EL;"!O<&5R871E<RP@86YD('!E<F9O
M<FUS('=H871E=F5R('!A<G0@;V8*("`@(&ET<R!P=7)P;W-E(')E;6%I;G,@
M;65A;FEN9V9U;"X*"B`@("`H1F]R(&5X86UP;&4L(&$@9G5N8W1I;VX@:6X@
M82!L:6)R87)Y('1O(&-O;7!U=&4@<W%U87)E(')O;W1S(&AA<PH@("`@82!P
M=7)P;W-E('1H870@:7,@96YT:7)E;'D@=V5L;"UD969I;F5D(&EN9&5P96YD
M96YT(&]F('1H90H@("`@87!P;&EC871I;VXN("!4:&5R969O<F4L(%-U8G-E
M8W1I;VX@,F0@<F5Q=6ER97,@=&AA="!A;GD*("`@(&%P<&QI8V%T:6]N+7-U
M<'!L:65D(&9U;F-T:6]N(&]R('1A8FQE('5S960@8GD@=&AI<R!F=6YC=&EO
M;B!M=7-T"B`@("!B92!O<'1I;VYA;#H@:68@=&AE(&%P<&QI8V%T:6]N(&1O
M97,@;F]T('-U<'!L>2!I="P@=&AE('-Q=6%R90H@("`@<F]O="!F=6YC=&EO
M;B!M=7-T('-T:6QL(&-O;7!U=&4@<W%U87)E(')O;W1S+BD*"E1H97-E(')E
M<75I<F5M96YT<R!A<'!L>2!T;R!T:&4@;6]D:69I960@=V]R:R!A<R!A('=H
M;VQE+B`@268*:61E;G1I9FEA8FQE('-E8W1I;VYS(&]F('1H870@=V]R:R!A
M<F4@;F]T(&1E<FEV960@9G)O;2!T:&4@3&EB<F%R>2P*86YD(&-A;B!B92!R
M96%S;VYA8FQY(&-O;G-I9&5R960@:6YD97!E;F1E;G0@86YD('-E<&%R871E
M('=O<FMS(&EN"G1H96US96QV97,L('1H96X@=&AI<R!,:6-E;G-E+"!A;F0@
M:71S('1E<FUS+"!D;R!N;W0@87!P;'D@=&\@=&AO<V4*<V5C=&EO;G,@=VAE
M;B!Y;W4@9&ES=')I8G5T92!T:&5M(&%S('-E<&%R871E('=O<FMS+B`@0G5T
M('=H96X@>6]U"F1I<W1R:6)U=&4@=&AE('-A;64@<V5C=&EO;G,@87,@<&%R
M="!O9B!A('=H;VQE('=H:6-H(&ES(&$@=V]R:R!B87-E9`IO;B!T:&4@3&EB
M<F%R>2P@=&AE(&1I<W1R:6)U=&EO;B!O9B!T:&4@=VAO;&4@;75S="!B92!O
M;B!T:&4@=&5R;7,@;V8*=&AI<R!,:6-E;G-E+"!W:&]S92!P97)M:7-S:6]N
M<R!F;W(@;W1H97(@;&EC96YS965S(&5X=&5N9"!T;R!T:&4*96YT:7)E('=H
M;VQE+"!A;F0@=&AU<R!T;R!E86-H(&%N9"!E=F5R>2!P87)T(')E9V%R9&QE
M<W,@;V8@=VAO('=R;W1E"FET+@H*5&AU<RP@:70@:7,@;F]T('1H92!I;G1E
M;G0@;V8@=&AI<R!S96-T:6]N('1O(&-L86EM(')I9VAT<R!O<B!C;VYT97-T
M"GEO=7(@<FEG:'1S('1O('=O<FL@=W)I='1E;B!E;G1I<F5L>2!B>2!Y;W4[
M(')A=&AE<BP@=&AE(&EN=&5N="!I<R!T;PIE>&5R8VES92!T:&4@<FEG:'0@
M=&\@8V]N=')O;"!T:&4@9&ES=')I8G5T:6]N(&]F(&1E<FEV871I=F4@;W(*
M8V]L;&5C=&EV92!W;W)K<R!B87-E9"!O;B!T:&4@3&EB<F%R>2X*"DEN(&%D
M9&ET:6]N+"!M97)E(&%G9W)E9V%T:6]N(&]F(&%N;W1H97(@=V]R:R!N;W0@
M8F%S960@;VX@=&AE($QI8G)A<GD*=VET:"!T:&4@3&EB<F%R>2`H;W(@=VET
M:"!A('=O<FL@8F%S960@;VX@=&AE($QI8G)A<GDI(&]N(&$@=F]L=6UE(&]F
M"F$@<W1O<F%G92!O<B!D:7-T<FEB=71I;VX@;65D:75M(&1O97,@;F]T(&)R
M:6YG('1H92!O=&AE<B!W;W)K('5N9&5R"G1H92!S8V]P92!O9B!T:&ES($QI
M8V5N<V4N"@H@(#,N(%EO=2!M87D@;W!T('1O(&%P<&QY('1H92!T97)M<R!O
M9B!T:&4@;W)D:6YA<GD@1TY5($=E;F5R86P@4'5B;&EC"DQI8V5N<V4@:6YS
M=&5A9"!O9B!T:&ES($QI8V5N<V4@=&\@82!G:79E;B!C;W!Y(&]F('1H92!,
M:6)R87)Y+B`@5&\@9&\*=&AI<RP@>6]U(&UU<W0@86QT97(@86QL('1H92!N
M;W1I8V5S('1H870@<F5F97(@=&\@=&AI<R!,:6-E;G-E+"!S;PIT:&%T('1H
M97D@<F5F97(@=&\@=&AE(&]R9&EN87)Y($=.52!'96YE<F%L(%!U8FQI8R!,
M:6-E;G-E+"!V97)S:6]N(#(L"FEN<W1E860@;V8@=&\@=&AI<R!,:6-E;G-E
M+B`@*$EF(&$@;F5W97(@=F5R<VEO;B!T:&%N('9E<G-I;VX@,B!O9B!T:&4*
M;W)D:6YA<GD@1TY5($=E;F5R86P@4'5B;&EC($QI8V5N<V4@:&%S(&%P<&5A
M<F5D+"!T:&5N('EO=2!C86X@<W!E8VEF>0IT:&%T('9E<G-I;VX@:6YS=&5A
M9"!I9B!Y;W4@=VES:"XI("!$;R!N;W0@;6%K92!A;GD@;W1H97(@8VAA;F=E
M(&EN"G1H97-E(&YO=&EC97,N"@P*("!/;F-E('1H:7,@8VAA;F=E(&ES(&UA
M9&4@:6X@82!G:79E;B!C;W!Y+"!I="!I<R!I<G)E=F5R<VEB;&4@9F]R"G1H
M870@8V]P>2P@<V\@=&AE(&]R9&EN87)Y($=.52!'96YE<F%L(%!U8FQI8R!,
M:6-E;G-E(&%P<&QI97,@=&\@86QL"G-U8G-E<75E;G0@8V]P:65S(&%N9"!D
M97)I=F%T:79E('=O<FMS(&UA9&4@9G)O;2!T:&%T(&-O<'DN"@H@(%1H:7,@
M;W!T:6]N(&ES('5S969U;"!W:&5N('EO=2!W:7-H('1O(&-O<'D@<&%R="!O
M9B!T:&4@8V]D92!O9@IT:&4@3&EB<F%R>2!I;G1O(&$@<')O9W)A;2!T:&%T
M(&ES(&YO="!A(&QI8G)A<GDN"@H@(#0N(%EO=2!M87D@8V]P>2!A;F0@9&ES
M=')I8G5T92!T:&4@3&EB<F%R>2`H;W(@82!P;W)T:6]N(&]R"F1E<FEV871I
M=F4@;V8@:70L('5N9&5R(%-E8W1I;VX@,BD@:6X@;V)J96-T(&-O9&4@;W(@
M97AE8W5T86)L92!F;W)M"G5N9&5R('1H92!T97)M<R!O9B!396-T:6]N<R`Q
M(&%N9"`R(&%B;W9E('!R;W9I9&5D('1H870@>6]U(&%C8V]M<&%N>0II="!W
M:71H('1H92!C;VUP;&5T92!C;W)R97-P;VYD:6YG(&UA8VAI;F4M<F5A9&%B
M;&4@<V]U<F-E(&-O9&4L('=H:6-H"FUU<W0@8F4@9&ES=')I8G5T960@=6YD
M97(@=&AE('1E<FUS(&]F(%-E8W1I;VYS(#$@86YD(#(@86)O=F4@;VX@80IM
M961I=6T@8W5S=&]M87)I;'D@=7-E9"!F;W(@<V]F='=A<F4@:6YT97)C:&%N
M9V4N"@H@($EF(&1I<W1R:6)U=&EO;B!O9B!O8FIE8W0@8V]D92!I<R!M861E
M(&)Y(&]F9F5R:6YG(&%C8V5S<R!T;R!C;W!Y"F9R;VT@82!D97-I9VYA=&5D
M('!L86-E+"!T:&5N(&]F9F5R:6YG(&5Q=6EV86QE;G0@86-C97-S('1O(&-O
M<'D@=&AE"G-O=7)C92!C;V1E(&9R;VT@=&AE('-A;64@<&QA8V4@<V%T:7-F
M:65S('1H92!R97%U:7)E;65N="!T;PID:7-T<FEB=71E('1H92!S;W5R8V4@
M8V]D92P@979E;B!T:&]U9V@@=&AI<F0@<&%R=&EE<R!A<F4@;F]T"F-O;7!E
M;&QE9"!T;R!C;W!Y('1H92!S;W5R8V4@86QO;F<@=VET:"!T:&4@;V)J96-T
M(&-O9&4N"@H@(#4N($$@<')O9W)A;2!T:&%T(&-O;G1A:6YS(&YO(&1E<FEV
M871I=F4@;V8@86YY('!O<G1I;VX@;V8@=&AE"DQI8G)A<GDL(&)U="!I<R!D
M97-I9VYE9"!T;R!W;W)K('=I=&@@=&AE($QI8G)A<GD@8GD@8F5I;F<@8V]M
M<&EL960@;W(*;&EN:V5D('=I=&@@:70L(&ES(&-A;&QE9"!A(")W;W)K('1H
M870@=7-E<R!T:&4@3&EB<F%R>2(N("!3=6-H(&$*=V]R:RP@:6X@:7-O;&%T
M:6]N+"!I<R!N;W0@82!D97)I=F%T:79E('=O<FL@;V8@=&AE($QI8G)A<GDL
M(&%N9`IT:&5R969O<F4@9F%L;',@;W5T<VED92!T:&4@<V-O<&4@;V8@=&AI
M<R!,:6-E;G-E+@H*("!(;W=E=F5R+"!L:6YK:6YG(&$@(G=O<FL@=&AA="!U
M<V5S('1H92!,:6)R87)Y(B!W:71H('1H92!,:6)R87)Y"F-R96%T97,@86X@
M97AE8W5T86)L92!T:&%T(&ES(&$@9&5R:79A=&EV92!O9B!T:&4@3&EB<F%R
M>2`H8F5C875S92!I=`IC;VYT86EN<R!P;W)T:6]N<R!O9B!T:&4@3&EB<F%R
M>2DL(')A=&AE<B!T:&%N(&$@(G=O<FL@=&AA="!U<V5S('1H90IL:6)R87)Y
M(BX@(%1H92!E>&5C=71A8FQE(&ES('1H97)E9F]R92!C;W9E<F5D(&)Y('1H
M:7,@3&EC96YS92X*4V5C=&EO;B`V('-T871E<R!T97)M<R!F;W(@9&ES=')I
M8G5T:6]N(&]F('-U8V@@97AE8W5T86)L97,N"@H@(%=H96X@82`B=V]R:R!T
M:&%T('5S97,@=&AE($QI8G)A<GDB('5S97,@;6%T97)I86P@9G)O;2!A(&AE
M861E<B!F:6QE"G1H870@:7,@<&%R="!O9B!T:&4@3&EB<F%R>2P@=&AE(&]B
M:F5C="!C;V1E(&9O<B!T:&4@=V]R:R!M87D@8F4@80ID97)I=F%T:79E('=O
M<FL@;V8@=&AE($QI8G)A<GD@979E;B!T:&]U9V@@=&AE('-O=7)C92!C;V1E
M(&ES(&YO="X*5VAE=&AE<B!T:&ES(&ES('1R=64@:7,@97-P96-I86QL>2!S
M:6=N:69I8V%N="!I9B!T:&4@=V]R:R!C86X@8F4*;&EN:V5D('=I=&AO=70@
M=&AE($QI8G)A<GDL(&]R(&EF('1H92!W;W)K(&ES(&ET<V5L9B!A(&QI8G)A
M<GDN("!4:&4*=&AR97-H;VQD(&9O<B!T:&ES('1O(&)E('1R=64@:7,@;F]T
M('!R96-I<V5L>2!D969I;F5D(&)Y(&QA=RX*"B`@268@<W5C:"!A;B!O8FIE
M8W0@9FEL92!U<V5S(&]N;'D@;G5M97)I8V%L('!A<F%M971E<G,L(&1A=&$*
M<W1R=6-T=7)E(&QA>6]U=',@86YD(&%C8V5S<V]R<RP@86YD('-M86QL(&UA
M8W)O<R!A;F0@<VUA;&P@:6YL:6YE"F9U;F-T:6]N<R`H=&5N(&QI;F5S(&]R
M(&QE<W,@:6X@;&5N9W1H*2P@=&AE;B!T:&4@=7-E(&]F('1H92!O8FIE8W0*
M9FEL92!I<R!U;G)E<W1R:6-T960L(')E9V%R9&QE<W,@;V8@=VAE=&AE<B!I
M="!I<R!L96=A;&QY(&$@9&5R:79A=&EV90IW;W)K+B`@*$5X96-U=&%B;&5S
M(&-O;G1A:6YI;F<@=&AI<R!O8FIE8W0@8V]D92!P;'5S('!O<G1I;VYS(&]F
M('1H90I,:6)R87)Y('=I;&P@<W1I;&P@9F%L;"!U;F1E<B!396-T:6]N(#8N
M*0H*("!/=&AE<G=I<V4L(&EF('1H92!W;W)K(&ES(&$@9&5R:79A=&EV92!O
M9B!T:&4@3&EB<F%R>2P@>6]U(&UA>0ID:7-T<FEB=71E('1H92!O8FIE8W0@
M8V]D92!F;W(@=&AE('=O<FL@=6YD97(@=&AE('1E<FUS(&]F(%-E8W1I;VX@
M-BX*06YY(&5X96-U=&%B;&5S(&-O;G1A:6YI;F<@=&AA="!W;W)K(&%L<V\@
M9F%L;"!U;F1E<B!396-T:6]N(#8L"G=H971H97(@;W(@;F]T('1H97D@87)E
M(&QI;FME9"!D:7)E8W1L>2!W:71H('1H92!,:6)R87)Y(&ET<V5L9BX*#`H@
M(#8N($%S(&%N(&5X8V5P=&EO;B!T;R!T:&4@4V5C=&EO;G,@86)O=F4L('EO
M=2!M87D@86QS;R!C;VUP:6QE(&]R"FQI;FL@82`B=V]R:R!T:&%T('5S97,@
M=&AE($QI8G)A<GDB('=I=&@@=&AE($QI8G)A<GD@=&\@<')O9'5C92!A"G=O
M<FL@8V]N=&%I;FEN9R!P;W)T:6]N<R!O9B!T:&4@3&EB<F%R>2P@86YD(&1I
M<W1R:6)U=&4@=&AA="!W;W)K"G5N9&5R('1E<FUS(&]F('EO=7(@8VAO:6-E
M+"!P<F]V:61E9"!T:&%T('1H92!T97)M<R!P97)M:70*;6]D:69I8V%T:6]N
M(&]F('1H92!W;W)K(&9O<B!T:&4@8W5S=&]M97(G<R!O=VX@=7-E(&%N9"!R
M979E<G-E"F5N9VEN965R:6YG(&9O<B!D96)U9V=I;F<@<W5C:"!M;V1I9FEC
M871I;VYS+@H*("!9;W4@;75S="!G:79E('!R;VUI;F5N="!N;W1I8V4@=VET
M:"!E86-H(&-O<'D@;V8@=&AE('=O<FL@=&AA="!T:&4*3&EB<F%R>2!I<R!U
M<V5D(&EN(&ET(&%N9"!T:&%T('1H92!,:6)R87)Y(&%N9"!I=',@=7-E(&%R
M92!C;W9E<F5D(&)Y"G1H:7,@3&EC96YS92X@(%EO=2!M=7-T('-U<'!L>2!A
M(&-O<'D@;V8@=&AI<R!,:6-E;G-E+B`@268@=&AE('=O<FL*9'5R:6YG(&5X
M96-U=&EO;B!D:7-P;&%Y<R!C;W!Y<FEG:'0@;F]T:6-E<RP@>6]U(&UU<W0@
M:6YC;'5D92!T:&4*8V]P>7)I9VAT(&YO=&EC92!F;W(@=&AE($QI8G)A<GD@
M86UO;F<@=&AE;2P@87,@=V5L;"!A<R!A(')E9F5R96YC90ID:7)E8W1I;F<@
M=&AE('5S97(@=&\@=&AE(&-O<'D@;V8@=&AI<R!,:6-E;G-E+B`@06QS;RP@
M>6]U(&UU<W0@9&\@;VYE"F]F('1H97-E('1H:6YG<SH*"B`@("!A*2!!8V-O
M;7!A;GD@=&AE('=O<FL@=VET:"!T:&4@8V]M<&QE=&4@8V]R<F5S<&]N9&EN
M9PH@("`@;6%C:&EN92UR96%D86)L92!S;W5R8V4@8V]D92!F;W(@=&AE($QI
M8G)A<GD@:6YC;'5D:6YG('=H871E=F5R"B`@("!C:&%N9V5S('=E<F4@=7-E
M9"!I;B!T:&4@=V]R:R`H=VAI8V@@;75S="!B92!D:7-T<FEB=71E9"!U;F1E
M<@H@("`@4V5C=&EO;G,@,2!A;F0@,B!A8F]V92D[(&%N9"P@:68@=&AE('=O
M<FL@:7,@86X@97AE8W5T86)L92!L:6YK960*("`@('=I=&@@=&AE($QI8G)A
M<GDL('=I=&@@=&AE(&-O;7!L971E(&UA8VAI;F4M<F5A9&%B;&4@(G=O<FL@
M=&AA=`H@("`@=7-E<R!T:&4@3&EB<F%R>2(L(&%S(&]B:F5C="!C;V1E(&%N
M9"]O<B!S;W5R8V4@8V]D92P@<V\@=&AA="!T:&4*("`@('5S97(@8V%N(&UO
M9&EF>2!T:&4@3&EB<F%R>2!A;F0@=&AE;B!R96QI;FL@=&\@<')O9'5C92!A
M(&UO9&EF:65D"B`@("!E>&5C=71A8FQE(&-O;G1A:6YI;F<@=&AE(&UO9&EF
M:65D($QI8G)A<GDN("`H270@:7,@=6YD97)S=&]O9`H@("`@=&AA="!T:&4@
M=7-E<B!W:&\@8VAA;F=E<R!T:&4@8V]N=&5N=',@;V8@9&5F:6YI=&EO;G,@
M9FEL97,@:6X@=&AE"B`@("!,:6)R87)Y('=I;&P@;F]T(&YE8V5S<V%R:6QY
M(&)E(&%B;&4@=&\@<F5C;VUP:6QE('1H92!A<'!L:6-A=&EO;@H@("`@=&\@
M=7-E('1H92!M;V1I9FEE9"!D969I;FET:6]N<RXI"@H@("`@8BD@06-C;VUP
M86YY('1H92!W;W)K('=I=&@@82!W<FET=&5N(&]F9F5R+"!V86QI9"!F;W(@
M870*("`@(&QE87-T('1H<F5E('EE87)S+"!T;R!G:79E('1H92!S86UE('5S
M97(@=&AE(&UA=&5R:6%L<PH@("`@<W!E8VEF:65D(&EN(%-U8G-E8W1I;VX@
M-F$L(&%B;W9E+"!F;W(@82!C:&%R9V4@;F\@;6]R90H@("`@=&AA;B!T:&4@
M8V]S="!O9B!P97)F;W)M:6YG('1H:7,@9&ES=')I8G5T:6]N+@H*("`@(&,I
M($EF(&1I<W1R:6)U=&EO;B!O9B!T:&4@=V]R:R!I<R!M861E(&)Y(&]F9F5R
M:6YG(&%C8V5S<R!T;R!C;W!Y"B`@("!F<F]M(&$@9&5S:6=N871E9"!P;&%C
M92P@;V9F97(@97%U:79A;&5N="!A8V-E<W,@=&\@8V]P>2!T:&4@86)O=F4*
M("`@('-P96-I9FEE9"!M871E<FEA;',@9G)O;2!T:&4@<V%M92!P;&%C92X*
M"B`@("!D*2!697)I9GD@=&AA="!T:&4@=7-E<B!H87,@86QR96%D>2!R96-E
M:79E9"!A(&-O<'D@;V8@=&AE<V4*("`@(&UA=&5R:6%L<R!O<B!T:&%T('EO
M=2!H879E(&%L<F5A9'D@<V5N="!T:&ES('5S97(@82!C;W!Y+@H*("!&;W(@
M86X@97AE8W5T86)L92P@=&AE(')E<75I<F5D(&9O<FT@;V8@=&AE(")W;W)K
M('1H870@=7-E<R!T:&4*3&EB<F%R>2(@;75S="!I;F-L=61E(&%N>2!D871A
M(&%N9"!U=&EL:71Y('!R;V=R86US(&YE961E9"!F;W(*<F5P<F]D=6-I;F<@
M=&AE(&5X96-U=&%B;&4@9G)O;2!I="X@($AO=V5V97(L(&%S(&$@<W!E8VEA
M;"!E>&-E<'1I;VXL"G1H92!S;W5R8V4@8V]D92!D:7-T<FEB=71E9"!N965D
M(&YO="!I;F-L=61E(&%N>71H:6YG('1H870@:7,@;F]R;6%L;'D*9&ES=')I
M8G5T960@*&EN(&5I=&AE<B!S;W5R8V4@;W(@8FEN87)Y(&9O<FTI('=I=&@@
M=&AE(&UA:F]R"F-O;7!O;F5N=',@*&-O;7!I;&5R+"!K97)N96PL(&%N9"!S
M;R!O;BD@;V8@=&AE(&]P97)A=&EN9R!S>7-T96T@;VX*=VAI8V@@=&AE(&5X
M96-U=&%B;&4@<G5N<RP@=6YL97-S('1H870@8V]M<&]N96YT(&ET<V5L9B!A
M8V-O;7!A;FEE<PIT:&4@97AE8W5T86)L92X*"B`@270@;6%Y(&AA<'!E;B!T
M:&%T('1H:7,@<F5Q=6ER96UE;G0@8V]N=')A9&EC=',@=&AE(&QI8V5N<V4*
M<F5S=')I8W1I;VYS(&]F(&]T:&5R('!R;W!R:65T87)Y(&QI8G)A<FEE<R!T
M:&%T(&1O(&YO="!N;W)M86QL>0IA8V-O;7!A;GD@=&AE(&]P97)A=&EN9R!S
M>7-T96TN("!3=6-H(&$@8V]N=')A9&EC=&EO;B!M96%N<R!Y;W4@8V%N;F]T
M"G5S92!B;W1H('1H96T@86YD('1H92!,:6)R87)Y('1O9V5T:&5R(&EN(&%N
M(&5X96-U=&%B;&4@=&AA="!Y;W4*9&ES=')I8G5T92X*#`H@(#<N(%EO=2!M
M87D@<&QA8V4@;&EB<F%R>2!F86-I;&ET:65S('1H870@87)E(&$@=V]R:R!B
M87-E9"!O;B!T:&4*3&EB<F%R>2!S:61E+6)Y+7-I9&4@:6X@82!S:6YG;&4@
M;&EB<F%R>2!T;V=E=&AE<B!W:71H(&]T:&5R(&QI8G)A<GD*9F%C:6QI=&EE
M<R!N;W0@8V]V97)E9"!B>2!T:&ES($QI8V5N<V4L(&%N9"!D:7-T<FEB=71E
M('-U8V@@82!C;VUB:6YE9`IL:6)R87)Y+"!P<F]V:61E9"!T:&%T('1H92!S
M97!A<F%T92!D:7-T<FEB=71I;VX@;V8@=&AE('=O<FL@8F%S960@;VX*=&AE
M($QI8G)A<GD@86YD(&]F('1H92!O=&AE<B!L:6)R87)Y(&9A8VEL:71I97,@
M:7,@;W1H97)W:7-E"G!E<FUI='1E9"P@86YD('!R;W9I9&5D('1H870@>6]U
M(&1O('1H97-E('1W;R!T:&EN9W,Z"@H@("`@82D@06-C;VUP86YY('1H92!C
M;VUB:6YE9"!L:6)R87)Y('=I=&@@82!C;W!Y(&]F('1H92!S86UE('=O<FL*
M("`@(&)A<V5D(&]N('1H92!,:6)R87)Y+"!U;F-O;6)I;F5D('=I=&@@86YY
M(&]T:&5R(&QI8G)A<GD*("`@(&9A8VEL:71I97,N("!4:&ES(&UU<W0@8F4@
M9&ES=')I8G5T960@=6YD97(@=&AE('1E<FUS(&]F('1H90H@("`@4V5C=&EO
M;G,@86)O=F4N"@H@("`@8BD@1VEV92!P<F]M:6YE;G0@;F]T:6-E('=I=&@@
M=&AE(&-O;6)I;F5D(&QI8G)A<GD@;V8@=&AE(&9A8W0*("`@('1H870@<&%R
M="!O9B!I="!I<R!A('=O<FL@8F%S960@;VX@=&AE($QI8G)A<GDL(&%N9"!E
M>'!L86EN:6YG"B`@("!W:&5R92!T;R!F:6YD('1H92!A8V-O;7!A;GEI;F<@
M=6YC;VUB:6YE9"!F;W)M(&]F('1H92!S86UE('=O<FLN"@H@(#@N(%EO=2!M
M87D@;F]T(&-O<'DL(&UO9&EF>2P@<W5B;&EC96YS92P@;&EN:R!W:71H+"!O
M<B!D:7-T<FEB=71E"G1H92!,:6)R87)Y(&5X8V5P="!A<R!E>'!R97-S;'D@
M<')O=FED960@=6YD97(@=&AI<R!,:6-E;G-E+B`@06YY"F%T=&5M<'0@;W1H
M97)W:7-E('1O(&-O<'DL(&UO9&EF>2P@<W5B;&EC96YS92P@;&EN:R!W:71H
M+"!O<@ID:7-T<FEB=71E('1H92!,:6)R87)Y(&ES('9O:60L(&%N9"!W:6QL
M(&%U=&]M871I8V%L;'D@=&5R;6EN871E('EO=7(*<FEG:'1S('5N9&5R('1H
M:7,@3&EC96YS92X@($AO=V5V97(L('!A<G1I97,@=VAO(&AA=F4@<F5C96EV
M960@8V]P:65S+`IO<B!R:6=H=',L(&9R;VT@>6]U('5N9&5R('1H:7,@3&EC
M96YS92!W:6QL(&YO="!H879E('1H96ER(&QI8V5N<V5S"G1E<FUI;F%T960@
M<V\@;&]N9R!A<R!S=6-H('!A<G1I97,@<F5M86EN(&EN(&9U;&P@8V]M<&QI
M86YC92X*"B`@.2X@66]U(&%R92!N;W0@<F5Q=6ER960@=&\@86-C97!T('1H
M:7,@3&EC96YS92P@<VEN8V4@>6]U(&AA=F4@;F]T"G-I9VYE9"!I="X@($AO
M=V5V97(L(&YO=&AI;F<@96QS92!G<F%N=',@>6]U('!E<FUI<W-I;VX@=&\@
M;6]D:69Y(&]R"F1I<W1R:6)U=&4@=&AE($QI8G)A<GD@;W(@:71S(&1E<FEV
M871I=F4@=V]R:W,N("!4:&5S92!A8W1I;VYS(&%R90IP<F]H:6)I=&5D(&)Y
M(&QA=R!I9B!Y;W4@9&\@;F]T(&%C8V5P="!T:&ES($QI8V5N<V4N("!4:&5R
M969O<F4L(&)Y"FUO9&EF>6EN9R!O<B!D:7-T<FEB=71I;F<@=&AE($QI8G)A
M<GD@*&]R(&%N>2!W;W)K(&)A<V5D(&]N('1H90I,:6)R87)Y*2P@>6]U(&EN
M9&EC871E('EO=7(@86-C97!T86YC92!O9B!T:&ES($QI8V5N<V4@=&\@9&\@
M<V\L(&%N9`IA;&P@:71S('1E<FUS(&%N9"!C;VYD:71I;VYS(&9O<B!C;W!Y
M:6YG+"!D:7-T<FEB=71I;F<@;W(@;6]D:69Y:6YG"G1H92!,:6)R87)Y(&]R
M('=O<FMS(&)A<V5D(&]N(&ET+@H*("`Q,"X@16%C:"!T:6UE('EO=2!R961I
M<W1R:6)U=&4@=&AE($QI8G)A<GD@*&]R(&%N>2!W;W)K(&)A<V5D(&]N('1H
M90I,:6)R87)Y*2P@=&AE(')E8VEP:65N="!A=71O;6%T:6-A;&QY(')E8V5I
M=F5S(&$@;&EC96YS92!F<F]M('1H90IO<FEG:6YA;"!L:6-E;G-O<B!T;R!C
M;W!Y+"!D:7-T<FEB=71E+"!L:6YK('=I=&@@;W(@;6]D:69Y('1H92!,:6)R
M87)Y"G-U8FIE8W0@=&\@=&AE<V4@=&5R;7,@86YD(&-O;F1I=&EO;G,N("!9
M;W4@;6%Y(&YO="!I;7!O<V4@86YY(&9U<G1H97(*<F5S=')I8W1I;VYS(&]N
M('1H92!R96-I<&EE;G1S)R!E>&5R8VES92!O9B!T:&4@<FEG:'1S(&=R86YT
M960@:&5R96EN+@I9;W4@87)E(&YO="!R97-P;VYS:6)L92!F;W(@96YF;W)C
M:6YG(&-O;7!L:6%N8V4@8GD@=&AI<F0@<&%R=&EE<R!T;PIT:&ES($QI8V5N
M<V4N"@P*("`Q,2X@268L(&%S(&$@8V]N<V5Q=65N8V4@;V8@82!C;W5R="!J
M=61G;65N="!O<B!A;&QE9V%T:6]N(&]F('!A=&5N=`II;F9R:6YG96UE;G0@
M;W(@9F]R(&%N>2!O=&AE<B!R96%S;VX@*&YO="!L:6UI=&5D('1O('!A=&5N
M="!I<W-U97,I+`IC;VYD:71I;VYS(&%R92!I;7!O<V5D(&]N('EO=2`H=VAE
M=&AE<B!B>2!C;W5R="!O<F1E<BP@86=R965M96YT(&]R"F]T:&5R=VES92D@
M=&AA="!C;VYT<F%D:6-T('1H92!C;VYD:71I;VYS(&]F('1H:7,@3&EC96YS
M92P@=&AE>2!D;R!N;W0*97AC=7-E('EO=2!F<F]M('1H92!C;VYD:71I;VYS
M(&]F('1H:7,@3&EC96YS92X@($EF('EO=2!C86YN;W0*9&ES=')I8G5T92!S
M;R!A<R!T;R!S871I<V9Y('-I;75L=&%N96]U<VQY('EO=7(@;V)L:6=A=&EO
M;G,@=6YD97(@=&AI<PI,:6-E;G-E(&%N9"!A;GD@;W1H97(@<&5R=&EN96YT
M(&]B;&EG871I;VYS+"!T:&5N(&%S(&$@8V]N<V5Q=65N8V4@>6]U"FUA>2!N
M;W0@9&ES=')I8G5T92!T:&4@3&EB<F%R>2!A="!A;&PN("!&;W(@97AA;7!L
M92P@:68@82!P871E;G0*;&EC96YS92!W;W5L9"!N;W0@<&5R;6ET(')O>6%L
M='DM9G)E92!R961I<W1R:6)U=&EO;B!O9B!T:&4@3&EB<F%R>2!B>0IA;&P@
M=&AO<V4@=VAO(')E8V5I=F4@8V]P:65S(&1I<F5C=&QY(&]R(&EN9&ER96-T
M;'D@=&AR;W5G:"!Y;W4L('1H96X*=&AE(&]N;'D@=V%Y('EO=2!C;W5L9"!S
M871I<V9Y(&)O=&@@:70@86YD('1H:7,@3&EC96YS92!W;W5L9"!B92!T;PIR
M969R86EN(&5N=&ER96QY(&9R;VT@9&ES=')I8G5T:6]N(&]F('1H92!,:6)R
M87)Y+@H*268@86YY('!O<G1I;VX@;V8@=&AI<R!S96-T:6]N(&ES(&AE;&0@
M:6YV86QI9"!O<B!U;F5N9F]R8V5A8FQE('5N9&5R(&%N>0IP87)T:6-U;&%R
M(&-I<F-U;7-T86YC92P@=&AE(&)A;&%N8V4@;V8@=&AE('-E8W1I;VX@:7,@
M:6YT96YD960@=&\@87!P;'DL"F%N9"!T:&4@<V5C=&EO;B!A<R!A('=H;VQE
M(&ES(&EN=&5N9&5D('1O(&%P<&QY(&EN(&]T:&5R(&-I<F-U;7-T86YC97,N
M"@I)="!I<R!N;W0@=&AE('!U<G!O<V4@;V8@=&AI<R!S96-T:6]N('1O(&EN
M9'5C92!Y;W4@=&\@:6YF<FEN9V4@86YY"G!A=&5N=',@;W(@;W1H97(@<')O
M<&5R='D@<FEG:'0@8VQA:6US(&]R('1O(&-O;G1E<W0@=F%L:61I='D@;V8@
M86YY"G-U8V@@8VQA:6US.R!T:&ES('-E8W1I;VX@:&%S('1H92!S;VQE('!U
M<G!O<V4@;V8@<')O=&5C=&EN9R!T:&4*:6YT96=R:71Y(&]F('1H92!F<F5E
M('-O9G1W87)E(&1I<W1R:6)U=&EO;B!S>7-T96T@=VAI8V@@:7,*:6UP;&5M
M96YT960@8GD@<'5B;&EC(&QI8V5N<V4@<')A8W1I8V5S+B`@36%N>2!P96]P
M;&4@:&%V92!M861E"F=E;F5R;W5S(&-O;G1R:6)U=&EO;G,@=&\@=&AE('=I
M9&4@<F%N9V4@;V8@<V]F='=A<F4@9&ES=')I8G5T960*=&AR;W5G:"!T:&%T
M('-Y<W1E;2!I;B!R96QI86YC92!O;B!C;VYS:7-T96YT(&%P<&QI8V%T:6]N
M(&]F('1H870*<WES=&5M.R!I="!I<R!U<"!T;R!T:&4@875T:&]R+V1O;F]R
M('1O(&1E8VED92!I9B!H92!O<B!S:&4@:7,@=VEL;&EN9PIT;R!D:7-T<FEB
M=71E('-O9G1W87)E('1H<F]U9V@@86YY(&]T:&5R('-Y<W1E;2!A;F0@82!L
M:6-E;G-E92!C86YN;W0*:6UP;W-E('1H870@8VAO:6-E+@H*5&AI<R!S96-T
M:6]N(&ES(&EN=&5N9&5D('1O(&UA:V4@=&AO<F]U9VAL>2!C;&5A<B!W:&%T
M(&ES(&)E;&EE=F5D('1O"F)E(&$@8V]N<V5Q=65N8V4@;V8@=&AE(')E<W0@
M;V8@=&AI<R!,:6-E;G-E+@H*("`Q,BX@268@=&AE(&1I<W1R:6)U=&EO;B!A
M;F0O;W(@=7-E(&]F('1H92!,:6)R87)Y(&ES(')E<W1R:6-T960@:6X*8V5R
M=&%I;B!C;W5N=')I97,@96ET:&5R(&)Y('!A=&5N=',@;W(@8GD@8V]P>7)I
M9VAT960@:6YT97)F86-E<RP@=&AE"F]R:6=I;F%L(&-O<'ER:6=H="!H;VQD
M97(@=VAO('!L86-E<R!T:&4@3&EB<F%R>2!U;F1E<B!T:&ES($QI8V5N<V4@
M;6%Y(&%D9`IA;B!E>'!L:6-I="!G96]G<F%P:&EC86P@9&ES=')I8G5T:6]N
M(&QI;6ET871I;VX@97AC;'5D:6YG('1H;W-E(&-O=6YT<FEE<RP*<V\@=&AA
M="!D:7-T<FEB=71I;VX@:7,@<&5R;6ET=&5D(&]N;'D@:6X@;W(@86UO;F<@
M8V]U;G1R:65S(&YO="!T:'5S"F5X8VQU9&5D+B`@26X@<W5C:"!C87-E+"!T
M:&ES($QI8V5N<V4@:6YC;W)P;W)A=&5S('1H92!L:6UI=&%T:6]N(&%S(&EF
M"G=R:71T96X@:6X@=&AE(&)O9'D@;V8@=&AI<R!,:6-E;G-E+@H*("`Q,RX@
M5&AE($9R964@4V]F='=A<F4@1F]U;F1A=&EO;B!M87D@<'5B;&ES:"!R979I
M<V5D(&%N9"]O<B!N97<*=F5R<VEO;G,@;V8@=&AE($QI8G)A<GD@1V5N97)A
M;"!0=6)L:6,@3&EC96YS92!F<F]M('1I;64@=&\@=&EM92X*4W5C:"!N97<@
M=F5R<VEO;G,@=VEL;"!B92!S:6UI;&%R(&EN('-P:7)I="!T;R!T:&4@<')E
M<V5N="!V97)S:6]N+`IB=70@;6%Y(&1I9F9E<B!I;B!D971A:6P@=&\@861D
M<F5S<R!N97<@<')O8FQE;7,@;W(@8V]N8V5R;G,N"@I%86-H('9E<G-I;VX@
M:7,@9VEV96X@82!D:7-T:6YG=6ES:&EN9R!V97)S:6]N(&YU;6)E<BX@($EF
M('1H92!,:6)R87)Y"G-P96-I9FEE<R!A('9E<G-I;VX@;G5M8F5R(&]F('1H
M:7,@3&EC96YS92!W:&EC:"!A<'!L:65S('1O(&ET(&%N9`HB86YY(&QA=&5R
M('9E<G-I;VXB+"!Y;W4@:&%V92!T:&4@;W!T:6]N(&]F(&9O;&QO=VEN9R!T
M:&4@=&5R;7,@86YD"F-O;F1I=&EO;G,@96ET:&5R(&]F('1H870@=F5R<VEO
M;B!O<B!O9B!A;GD@;&%T97(@=F5R<VEO;B!P=6)L:7-H960@8GD*=&AE($9R
M964@4V]F='=A<F4@1F]U;F1A=&EO;BX@($EF('1H92!,:6)R87)Y(&1O97,@
M;F]T('-P96-I9GD@80IL:6-E;G-E('9E<G-I;VX@;G5M8F5R+"!Y;W4@;6%Y
M(&-H;V]S92!A;GD@=F5R<VEO;B!E=F5R('!U8FQI<VAE9"!B>0IT:&4@1G)E
M92!3;V9T=V%R92!&;W5N9&%T:6]N+@H,"B`@,30N($EF('EO=2!W:7-H('1O
M(&EN8V]R<&]R871E('!A<G1S(&]F('1H92!,:6)R87)Y(&EN=&\@;W1H97(@
M9G)E90IP<F]G<F%M<R!W:&]S92!D:7-T<FEB=71I;VX@8V]N9&ET:6]N<R!A
M<F4@:6YC;VUP871I8FQE('=I=&@@=&AE<V4L"G=R:71E('1O('1H92!A=71H
M;W(@=&\@87-K(&9O<B!P97)M:7-S:6]N+B`@1F]R('-O9G1W87)E('=H:6-H
M(&ES"F-O<'ER:6=H=&5D(&)Y('1H92!&<F5E(%-O9G1W87)E($9O=6YD871I
M;VXL('=R:71E('1O('1H92!&<F5E"E-O9G1W87)E($9O=6YD871I;VX[('=E
M('-O;65T:6UE<R!M86ME(&5X8V5P=&EO;G,@9F]R('1H:7,N("!/=7(*9&5C
M:7-I;VX@=VEL;"!B92!G=6ED960@8GD@=&AE('1W;R!G;V%L<R!O9B!P<F5S
M97)V:6YG('1H92!F<F5E('-T871U<PIO9B!A;&P@9&5R:79A=&EV97,@;V8@
M;W5R(&9R964@<V]F='=A<F4@86YD(&]F('!R;VUO=&EN9R!T:&4@<VAA<FEN
M9PIA;F0@<F5U<V4@;V8@<V]F='=A<F4@9V5N97)A;&QY+@H*"0D)("`@($Y/
M(%=!4E)!3E19"@H@(#$U+B!"14-!55-%(%1(12!,24)205)9($E3($Q)0T5.
M4T5$($92144@3T8@0TA!4D=%+"!42$5212!)4R!.3PI705)204Y462!&3U(@
M5$A%($Q)0E)!4EDL(%1/(%1(12!%6%1%3E0@4$5234E45$5$($)9($%04$Q)
M0T%"3$4@3$%7+@I%6$-%4%0@5TA%3B!/5$A%4E=)4T4@4U1!5$5$($E.(%=2
M251)3D<@5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"]/4@I/5$A%4B!005)4
M2453(%!23U9)1$4@5$A%($Q)0E)!4ED@(D%3($E3(B!7251(3U54(%=!4E)!
M3E19($]&($%.60I+24Y$+"!%251(15(@15A04D534T5$($]2($E-4$Q)140L
M($E.0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$(%1/+"!42$4*24U03$E%1"!7
M05)204Y42453($]&($U%4D-(04Y404))3$E462!!3D0@1DE43D534R!&3U(@
M02!005)424-53$%2"E!54E!/4T4N("!42$4@14Y425)%(%))4TL@05,@5$\@
M5$A%(%%504Q)5%D@04Y$(%!%4D9/4DU!3D-%($]&(%1(10I,24)205)9($E3
M(%=)5$@@64]5+B`@4TA/54Q$(%1(12!,24)205)9(%!23U9%($1%1D5#5$E6
M12P@64]5($%34U5-10I42$4@0T]35"!/1B!!3$P@3D5#15-305)9(%-%4E9)
M0TE.1RP@4D5004E2($]2($-/4E)%0U1)3TXN"@H@(#$V+B!)3B!.3R!%5D5.
M5"!53DQ%4U,@4D5154E2140@0ED@05!03$E#04),12!,05<@3U(@04=2145$
M(%1/($E."E=2251)3D<@5TE,3"!!3ED@0T]065))1TA4($A/3$1%4BP@3U(@
M04Y9($]42$52(%!!4E19(%=(3R!-05D@34]$2499"D%.1"]/4B!2141)4U12
M24)55$4@5$A%($Q)0E)!4ED@05,@4$5234E45$5$($%"3U9%+"!"12!,24%"
M3$4@5$\@64]5"D9/4B!$04U!1T53+"!)3D-,541)3D<@04Y9($=%3D5204PL
M(%-014-)04PL($E.0TE$14Y404P@3U(*0T].4T51545.5$E!3"!$04U!1T53
M($%225-)3D<@3U54($]&(%1(12!54T4@3U(@24Y!0DE,2519(%1/(%5312!4
M2$4*3$E"4D%262`H24Y#3%5$24Y'($)55"!.3U0@3$E-251%1"!43R!,3U-3
M($]&($1!5$$@3U(@1$%402!"14E.1PI214Y$15)%1"!)3D%#0U52051%($]2
M($Q/4U-%4R!355-404E.140@0ED@64]5($]2(%1(25)$(%!!4E1)15,@3U(@
M00I&04E,55)%($]&(%1(12!,24)205)9(%1/($]015)!5$4@5TE42"!!3ED@
M3U1(15(@4T]&5%=!4D4I+"!%5D5.($E&"E-50T@@2$],1$52($]2($]42$52
M(%!!4E19($A!4R!"145.($%$5DE3140@3T8@5$A%(%!/4U-)0DE,2519($]&
M(%-50T@*1$%-04=%4RX*"@D)("`@("!%3D0@3T8@5$5235,@04Y$($-/3D1)
M5$E/3E,*#`H@("`@("`@("`@($AO=R!T;R!!<'!L>2!4:&5S92!497)M<R!T
M;R!9;W5R($YE=R!,:6)R87)I97,*"B`@268@>6]U(&1E=F5L;W`@82!N97<@
M;&EB<F%R>2P@86YD('EO=2!W86YT(&ET('1O(&)E(&]F('1H92!G<F5A=&5S
M=`IP;W-S:6)L92!U<V4@=&\@=&AE('!U8FQI8RP@=V4@<F5C;VUM96YD(&UA
M:VEN9R!I="!F<F5E('-O9G1W87)E('1H870*979E<GEO;F4@8V%N(')E9&ES
M=')I8G5T92!A;F0@8VAA;F=E+B`@66]U(&-A;B!D;R!S;R!B>2!P97)M:71T
M:6YG"G)E9&ES=')I8G5T:6]N('5N9&5R('1H97-E('1E<FUS("AO<BP@86QT
M97)N871I=F5L>2P@=6YD97(@=&AE('1E<FUS(&]F('1H90IO<F1I;F%R>2!'
M96YE<F%L(%!U8FQI8R!,:6-E;G-E*2X*"B`@5&\@87!P;'D@=&AE<V4@=&5R
M;7,L(&%T=&%C:"!T:&4@9F]L;&]W:6YG(&YO=&EC97,@=&\@=&AE(&QI8G)A
M<GDN("!)="!I<PIS869E<W0@=&\@871T86-H('1H96T@=&\@=&AE('-T87)T
M(&]F(&5A8V@@<V]U<F-E(&9I;&4@=&\@;6]S="!E9F9E8W1I=F5L>0IC;VYV
M97D@=&AE(&5X8VQU<VEO;B!O9B!W87)R86YT>3L@86YD(&5A8V@@9FEL92!S
M:&]U;&0@:&%V92!A="!L96%S="!T:&4*(F-O<'ER:6=H="(@;&EN92!A;F0@
M82!P;VEN=&5R('1O('=H97)E('1H92!F=6QL(&YO=&EC92!I<R!F;W5N9"X*
M"B`@("`\;VYE(&QI;F4@=&\@9VEV92!T:&4@;&EB<F%R>2=S(&YA;64@86YD
M(&$@8G)I968@:61E82!O9B!W:&%T(&ET(&1O97,N/@H@("`@0V]P>7)I9VAT
M("A#*2`\>65A<CX@(#QN86UE(&]F(&%U=&AO<CX*"B`@("!4:&ES(&QI8G)A
M<GD@:7,@9G)E92!S;V9T=V%R93L@>6]U(&-A;B!R961I<W1R:6)U=&4@:70@
M86YD+V]R"B`@("!M;V1I9GD@:70@=6YD97(@=&AE('1E<FUS(&]F('1H92!'
M3E4@3&EB<F%R>2!'96YE<F%L(%!U8FQI8PH@("`@3&EC96YS92!A<R!P=6)L
M:7-H960@8GD@=&AE($9R964@4V]F='=A<F4@1F]U;F1A=&EO;CL@96ET:&5R
M"B`@("!V97)S:6]N(#(@;V8@=&AE($QI8V5N<V4L(&]R("AA="!Y;W5R(&]P
M=&EO;BD@86YY(&QA=&5R('9E<G-I;VXN"@H@("`@5&AI<R!L:6)R87)Y(&ES
M(&1I<W1R:6)U=&5D(&EN('1H92!H;W!E('1H870@:70@=VEL;"!B92!U<V5F
M=6PL"B`@("!B=70@5TE42$]55"!!3ED@5T%24D%.5%D[('=I=&AO=70@979E
M;B!T:&4@:6UP;&EE9"!W87)R86YT>2!O9@H@("`@34520TA!3E1!0DE,2519
M(&]R($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%+B`@4V5E('1H
M92!'3E4*("`@($QI8G)A<GD@1V5N97)A;"!0=6)L:6,@3&EC96YS92!F;W(@
M;6]R92!D971A:6QS+@H*("`@(%EO=2!S:&]U;&0@:&%V92!R96-E:79E9"!A
M(&-O<'D@;V8@=&AE($=.52!,:6)R87)Y($=E;F5R86P@4'5B;&EC"B`@("!,
M:6-E;G-E(&%L;VYG('=I=&@@=&AI<R!L:6)R87)Y.R!I9B!N;W0L('=R:71E
M('1O('1H92!&<F5E"B`@("!&;W5N9&%T:6]N+"!);F,N+"`U.2!496UP;&4@
M4&QA8V4L(%-U:71E(#,S,"P@0F]S=&]N+"!-02`@,#(Q,3$M,3,P-R`@55-!
M"@I!;'-O(&%D9"!I;F9O<FUA=&EO;B!O;B!H;W<@=&\@8V]N=&%C="!Y;W4@
M8GD@96QE8W1R;VYI8R!A;F0@<&%P97(@;6%I;"X*"EEO=2!S:&]U;&0@86QS
M;R!G970@>6]U<B!E;7!L;WEE<B`H:68@>6]U('=O<FL@87,@82!P<F]G<F%M
M;65R*2!O<B!Y;W5R"G-C:&]O;"P@:68@86YY+"!T;R!S:6=N(&$@(F-O<'ER
M:6=H="!D:7-C;&%I;65R(B!F;W(@=&AE(&QI8G)A<GDL(&EF"FYE8V5S<V%R
M>2X@($AE<F4@:7,@82!S86UP;&4[(&%L=&5R('1H92!N86UE<SH*"B`@66]Y
M;V1Y;F4L($EN8RXL(&AE<F5B>2!D:7-C;&%I;7,@86QL(&-O<'ER:6=H="!I
M;G1E<F5S="!I;B!T:&4*("!L:6)R87)Y(&!&<F]B)R`H82!L:6)R87)Y(&9O
M<B!T=V5A:VEN9R!K;F]B<RD@=W)I='1E;B!B>2!*86UE<R!286YD;VT@2&%C
M:V5R+@H*("`\<VEG;F%T=7)E(&]F(%1Y($-O;VX^+"`Q($%P<FEL(#$Y.3`*
M("!4>2!#;V]N+"!0<F5S:61E;G0@;V8@5FEC90H*5&AA="=S(&%L;"!T:&5R
M92!I<R!T;R!I="$*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O9&]C<R]#4D5$2513````````````````````````````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`Q-#,S,``Q,#4Q-30S,S<T,P`P,3<V,C8`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]"B!(;W)D92!$979E;&]P;65N="!496%M"CT]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*"D-O<F4@1&5V96QO<&5R<PH]/3T]
M/3T]/3T]/3T]/3T*"D-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@I*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@I-:6-H865L(%-L=7-A
M<GH@/'-L=7-A<GI`:&]R9&4N;W)G/@H*"DQO8V%L:7IA=&EO;@H]/3T]/3T]
M/3T]/3T*"CT]/3T]/3T]/3T]/3T]/3T]/3T]/2`@(#T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0I!<F%B
M:6,@*%-Y<FEA*2`@("`@("`@("!0;&%T:6YU;2!$979E;&]P;65N="!496%M
M(#QD979T96%M0'!L871I;G5M+7-Y+FYE=#X*0F]S;FEA;B`@("`@("`@("`@
M("`@("`@06QE;B!387)K:6YO=FEC(#QA;&5N0&QI;G5X+F]R9RYB83X*("`@
M("`@("`@("`@("`@("`@("`@("`@5F5D<F%N($QJ=6)O=FEC(#QV;&IU8F]V
M:6-`<VUA<G1N970N8F$^"D)R87II;&EA;B!0;W)T=6=U97-E("`@($-A<FQO
M<R!$86YI96P@2VEB<FET(#QK:6)R:71`=&5R<F$N8V]M+F)R/@H@("`@("`@
M("`@("`@("`@("`@("`@("!&86)I;R!';VUE<R`\9FQG;VUS0'5O;"YC;VTN
M8G(^"D)U;&=A<FEA;B`@("`@("`@("`@("`@($UI<F]S;&%V(%!E;F1E=B`\
M<&5N9&5V0&AO=&UA:6PN8V]M/@I#871A;&%N("`@("`@("`@("`@("`@("!!
M;F=E;',@1W5I;65RX"`\86YG96QS+D=U:6UE<F%`=6%B+F5S/@H@("`@("`@
M("`@("`@("`@("`@("`@("!*;W)D:2!':7)A;'0@/'!R;VIE8W1E+FLR0'5P
M8VYE="YE<SX*0VAI;F5S92`H4VEM<&QI9FEE9"D@("`@5V%N9TAE;F=796X@
M/'=H=T!M>3$V.2YC;VT^"B`@("`@("`@("`@("`@("`@("`@("`@($QI86]B
M:6X@/&QI86]B:6Y`:FET92YN970^"D-H:6YE<V4@*%1R861I=&EO;F%L*2`@
M($1A=FED($-H86YG(#QD879I9$!T;78N9V]V+G1W/@I#>F5C:"`@("`@("`@
M("`@("`@("`@("!0879E;"!#:'ET:6P@/'!A:F%`87-P+F]G:2YE9'4^"D1A
M;FES:"`@("`@("`@("`@("`@("`@($UA<G1I;B!,:7-T+5!E=&5R<V5N(#QM
M87)T:6Y`;&ES="UP971E<G-E;BYD:SX*("`@("`@("`@("`@("`@("`@("`@
M("`@0G)I86X@5')U96QS96X@/&AO<F1E*VDQ.&Y`8G)I86YT<G5E;'-E;BYD
M:SX*1'5T8V@@("`@("`@("`@("`@("`@("`@2F%N($MU:7!E<G,@/&IR:W5I
M<&5R<T!L875W97)S8V]L;&5G92YN;#X*("`@("`@("`@("`@("`@("`@("`@
M("`@4&5T97(@07)I96X@/'!E=&5R+F%R:65N0&-C+FMU;&5U=F5N+F%C+F)E
M/@H@("`@("`@("`@("`@("`@("`@("`@("!(86X@4W!R=7ET(#QH86XN<W!R
M=7ET0&EJ<W-E;&=R;V5P+FYL/@I%<W1O;FEA;B`@("`@("`@("`@("`@("!4
M;V]M87,@06%S(#QT;V]M87,N86%S0')A860N=&%R='4N964^"D9I;FYI<V@@
M("`@("`@("`@("`@("`@($QE96YA($AE:6YO(#QL:6EN=4!U=&$N9FD^"D9R
M96YC:"`@("`@("`@("`@("`@("`@($9R961E<FEC(%1R=61E874@/&9T<G5D
M96%U0&-A;2YO<F<^"B`@("`@("`@("`@("`@("`@("`@("`@(%1H:65R<GD@
M5&AO;6%S(#QT:&EE<G)Y0'!O;7!O+FYE=#X*("`@("`@("`@("`@("`@("`@
M("`@("`@0F5N;VET(%-T+4%N9'+I(#QB96Y`8F5N;VET<W0M86YD<F4N;F5T
M/@H@("`@("`@("`@("`@("`@("`@("`@("!0:65R<F4@3&%C:&%N8V4@/'!L
M0'!I97)R96QA8VAA;F-E+FYE=#X*("`@("`@("`@("`@("`@("`@("`@("`@
M1W)E9V]R>2!#;VQP87)T(#QG8V]L<&%R=$!E=F]L:7@N;F5T/@I'86QI8VEA
M;B`@("`@("`@("`@("`@("!2869A96P@5F%R96QA(#QR869A96PN=F%R96QA
M0'5S8RYE<SX*("`@("`@("`@("`@("`@("`@("`@("`@1W5I;&QE<FUO($UE
M;F1E>B`\9W5I;&QE0'5S8RYE<SX*1V5R;6%N("`@("`@("`@("`@("`@("`@
M2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*1W)E96L@("`@("`@("`@
M("`@("`@("`@4W1E9F%N;W,@22X@1&EM:71R:6]U(#QS=7!P;W)T0'1E:6%T
M:"YG<CX*("`@("`@("`@("`@("`@("`@("`@("`@4VEL;&EG87)D;W,@6')I
M<W1O9F]R;W,*("`@("`@("`@("`@("`@("`@("`@("`@06YA9VYO<W1O<&]U
M;&]S($%P;W-T;VQI<PH@("`@("`@("`@("`@("`@("`@("`@("!+;VYS=&%N
M=&EN;W,@0RX@36EL;W-I<R`\:VUI;&]S:7-`>6%H;V\N8V]M/@I(96)R97<@
M("`@("`@("`@("`@("`@("!-871T(%-E;'-K>2`\<V5L<VMY0&-O;'5M8FEA
M+F5D=3X*2'5N9V%R:6%N("`@("`@("`@("`@("`@3&%S>FQO($PN(%1O<FYO
M8VD@/'1O<FQA<WI`>&5N:6$N<V]T92YH=3X*26-E;&%N9&EC("`@("`@("`@
M("`@("`@0FIO<FX@1&%V:61S<V]N(#QB:F]S<VE`<VYE<G!A+FES/@I);F1O
M;F5S:6%N("`@("`@("`@("`@("!3;&%M:6X@/'-L86UI;D!U;F5J+F%C+FED
M/@H@("`@("`@("`@("`@("`@("`@("`@("!*86UE<R!$;V4@/&IA;65S0&%C
M=&EO;FUE<W-A9V4N8V]M/@I)=&%L:6%N("`@("`@("`@("`@("`@("!086]L
M82!#87)P96YT97(@/'!C87)P96YT97)`:6YF=FEC+FET/@H@("`@("`@("`@
M("`@("`@("`@("`@("!':6]V86YN:2!-96YE9VAE='1I(#QG;65N96=H971T
M:4!I;F9V:6,N:70^"B`@("`@("`@("`@("`@("`@("`@("`@($9E9&5R:6-O
M($=I86YN:6-I(#QG:6%N;FEC:4!N96]M961I82YI=#X*("`@("`@("`@("`@
M("`@("`@("`@("`@36%R8V\@4&ER;W9A;F\@/&UA<F-O+G!I<F]V86YO0'5N
M:6)O8V-O;FDN:70^"B`@("`@("`@("`@("`@("`@("`@("`@($-R:7-T:6%N
M($UA;F]N:2`\8W)I<W1I86XN;6%N;VYI0&YE=&AE<VES+FET/@I*87!A;F5S
M92`@("`@("`@("`@("`@("!"+DHN($)L86-K(#QW:6QL:6%M+F)L86-K0'-U
M;BYC;VT^"B`@("`@("`@("`@("`@("`@("`@("`@(%1A:V5S:&D@36]R:7-H
M:6UA(#QT;4!O;F5P;W-T+FYE=#X*("`@("`@("`@("`@("`@("`@("`@("`@
M2&ER;VUI($MI;75R82`\:&ER;VUI0'1A8RYT<W5K=6)A+F%C+FIP/@I+:&UE
M<B`@("`@("`@("`@("`@("`@("!,96%N9R!#:'5M<V]B96X@/'-O8F5N0&MH
M;65R;W,N:6YF;SX*2V]R96%N("`@("`@("`@("`@("`@("`@2BY)($MI;2`\
M87!O<FEE0&YE=&EA;BYC;VT^"B`@("`@("`@("`@("`@("`@("`@("`@($II
M;FAY;VL@2&5O(#QN;W9E;6)R94!O=7)N871U<F4N;W)G/@I,871V:6%N("`@
M("`@("`@("`@("`@("!+87-P87)S($MA<&5N:65K<R`\:V%S<&%R<T!R8V,N
M;'8^"DQI=&AU86YI86X@("`@("`@("`@("`@($1A<FEU<R!-871U;&EA=7-K
M87,@/&1A<FEU<T!L;FLN;'0^"B`@("`@("`@("`@("`@("`@("`@("`@(%9I
M;&EU<R!3=6US:V%S(#QV:6QI=7-`;&YK+FQT/@I-86-E9&]N:6%N("`@("`@
M("`@("`@("!3=&]J86X@4&5S;W8@/'-S<$!E=7)E:V$N8V]M+FUK/@I.;W)W
M96=I86X@0F]K;6%A;"`@("`@("!/>7-T96EN(%-T96EM;&5R(#QO>7-T96EN
M0')E>'1A+FYE=#X*("`@("`@("`@("`@("`@("`@("`@("`@5&]R<W1E:6X@
M4RX@2&%N<V5N(#QH=6QE8F]E<D!T96-H8F5E+FYO/@H@("`@("`@("`@("`@
M("`@("`@("`@("!!;F1R96%S($=U;FQE:6MS:V%A<R`\86YD<F5A<T!G=6YL
M96EK<VMA87,N;F\^"B`@("`@("`@("`@("`@("`@("`@("`@(%1R;VYD($)J
M^')S=&%D(#QT<F)`;F1N+FYO/@H@("`@("`@("`@("`@("`@("`@("`@("!4
M:&]M87,@0VAR+B!$86AL(#QT8V1`;F1N+FYO/@H@("`@("`@("`@("`@("`@
M("`@("`@("!'96ER($\N($AO9V)E<F<@/&AO<F1E0'-K>61I=F5R+FYO/@I.
M;W)W96=I86X@3GEN;W)S:R`@("`@("!097(M4W1I86X@5F%T;F4@/'!S=D!O
M<G-T82YO<F<^"E!E<G-I86X@("`@("`@("`@("`@("`@($UE=&%.150@06UI
M<FMA8FER(#QP97)S:6%N+6AO<F1E0&UE=&%N971W;W)K:6YG+F-O;3X*4&]L
M:7-H("`@("`@("`@("`@("`@("`@36%R:75S>B!:>6YE;"`\;6%R:75S>D!M
M871H+G5W8BYE9'4N<&P^"B`@("`@("`@("`@("`@("`@("`@("`@($MR>GES
M>G1O9B!+;WIL;W=S:VD@/&MO>FEK,4!O,BYP;#X*4&]R='5G=65S92`@("`@
M("`@("`@("`@3G5N;R!,;W5R96ER;R`\;G5N;T!E=&@N<'0^"B`@("`@("`@
M("`@("`@("`@("`@("`@($UA;G5E;"!-96YE>F5S(&1E(%-E<75E:7)A(#Q-
M86YU96PN4V5Q=65I<F$^"E)O;6%N:6%N("`@("`@("`@("`@("`@($-O<FYE
M;&EU($UU<V%T(#QC;75S871`=&EA;6%T+FME>7-Y<RYR;SX*4G5S<VEA;B`@
M("`@("`@("`@("`@("`@26=N870@26MR>6%N;W8@/&EG;F%T0&EB9"YR=3X*
M("`@("`@("`@("`@("`@("`@("`@("`@1F5D;W(@02X@1F5T:7-O=B`\9F%F
M0'-S8RYR=3X*("`@("`@("`@("`@("`@("`@("`@("`@06QE>&5Y(%IA:VAA
M<F]V(#QA;&5X0&)K<RYB>3X*4VQO=F%K("`@("`@("`@("`@("`@("`@3&5O
M($UR869K;R`\;&5O0&]E;"YS:SX*("`@("`@("`@("`@("`@("`@("`@("`@
M279A;B!.;W)I<R`\;F]R:7-`8F=S+G-K/@I3;&]V96YI86X@("`@("`@("`@
M("`@("!*=7)E($MR87-O=FEC(#QJ=7)E:T!R8V,M:7)C+G-I/@H@("`@("`@
M("`@("`@("`@("`@("`@("!-871I8R!$;VQA<B`\;6%T:6-`;65D:75M+G-I
M/@I3<&%N:7-H("`@("`@("`@("`@("`@("!28?IL($%L=F%R97H@5F5N96=A
M<R`\<F%V0'1E8V]M86XN=6-O;"YM>#X*("`@("`@("`@("`@("`@("`@("`@
M("`@36%N=65L(%!E<F5Z($%Y86QA(#QM<&5R87EA0&%L8V%Z86)A+G5N97@N
M97,^"E-W961I<V@@("`@("`@("`@("`@("`@($%N9')E87,@1&%H;.EN(#QA
M;F1R96%S0&1A:&QE;BYW<SX*("`@("`@("`@("`@("`@("`@("`@("`@2F]A
M<75I;2!(;VUR:6=H875S96X@/&IO:&]`=V5B8G!L871S96XN<V4^"E1U<FMI
M<V@@("`@("`@("`@("`@("`@($=E;F-O(%EI;&UA>B`\9V5N8V]Y:6QM87I`
M>6%H;V\N8V]M/@H@("`@("`@("`@("`@("`@("`@("`@("!)<W1A;F)U;"!4
M96-H;FEC86P@56YI=F5R<VET>2!)5"!$97!A<G1M96YT"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QI='5B:6U`:71U+F5D=2YT<CX*("`@("`@("`@("`@
M("`@("`@("`@("`@4V5R=F5T($?\;F5Y(#QS9W5N97E`;65T=2YE9'4N='(^
M"B`@("`@("`@("`@("`@("`@("`@("`@($%H;65T(-9Z=/QR:R`\;V%H;65T
M0&UE='4N961U+G1R/@I5:W)A:6YI86X@("`@("`@("`@("`@("!!;F1R:7D@
M2V]P>7-T>6%N<VMY(#QA;G)I0'!O;'EN970N;'9I=BYU83X*/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@H*5&AE;65S"CT]/3T]/0H*/3T]
M/3T]/3T]/3T]/2`@(#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]"D)A<F)I92`@("`@("`@("!!=&EF($=H869F87(@/&%G:&%F
M9F%R0&1E=F5L;W!E<BYC:#X*0G)O=VX@("`@("`@("`@($UA<F-O($]B86ED
M(#QM87)C;T!M=7<N961U/@I#86UO=69L86=E("`@("`@071I9B!':&%F9F%R
M(#QA9VAA9F9A<D!D979E;&]P97(N8V@^"D-H97)R>2`@("`@("`@("!#:')I
M<W1O<&AE($=U:6QL;W5X(#QR;V]T:7A`8F]O=&EX+FYE=#X*1W)E96X@("`@
M("`@("`@($YA8V5R($QA<F%D:FD@/&QA<F%D:FE`='5X9F%M:6QY+F]R9SX*
M1W)E>2`@("`@("`@("`@($YA8V5R($QA<F%D:FD@/&QA<F%D:FE`='5X9F%M
M:6QY+F]R9SX*3&%V96YD97(@("`@("`@(%II875R(%)A:&UA;B`\>FEA0'%A
M;&%C;VTN8V]M/@I,:6=H="U";'5E("`@("`@071I9B!':&%F9F%R(#QA9VAA
M9F9A<D!D979E;&]P97(N8V@^"DUO>FEL;&$@("`@("`@("!-:6-H865L($-O
M8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@I/<F%N9V4@("`@("`@
M("`@4F]N;FEE($=A<F-I82`\<F]N;FEE0&UK,BYN970^"E-I;7!L97@@("`@
M("`@("!#87)I860@26QMX')A(#QC87)I861`861N>"YN970^"E-U;B`@("`@
M("`@("`@("!#:')I<W1O<&AE($=U:6QL;W5X(#QR;V]T:7A`8F]O=&EX+FYE
M=#X*/3T]/3T]/3T]/3T]/2`@(#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]"@H*0V]N=')I8G5T:6]N<PH]/3T]/3T]/3T]/3T]
M"@I(5$U,('1O(%1E>'0@0V]N=F5R=&5R.B!*;VX@06)E<FYA=&AY(#QJ;VY`
M8VAU9V=N=71T+F-O;3X*"@I);F%C=&EV92!$979E;&]P97)S"CT]/3T]/3T]
M/3T]/3T]/3T]/3T*"BT@279A;B!%+B!-;V]R92!)22`\<FMR=7-T>4!T9'EC
M+F-O;3X*+2!-:6ME($AA<F1Y(#QM:6ME0&ET<W!R;VIE8W1S+F-O;3X*+2!*
M;VX@4&%R:7-E(#QJ;VY`8W-H+G)I="YE9'4^"BT@06YI;"!-861H879A<&5D
M9'D@/&%N:6Q`<F5C;VEL+F]R9SX*+2!2:6-H($QA9F9E<G1Y(#QR:6-H0&AO
M<F1E+F]R9SX*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+V1O8W,O2$%#2TE.1P``````````````````````
M````````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,38W,C(`,3`U,34T,S,W
M-#,`,#$W-C`T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B!(;W)D92!$
M979E;&]P;65N="!297-O=7)C97,*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T*"CI,87-T('5P9&%T93H@("`D1&%T93H@,C`P-B\P,B\P,2`P.3HR
M,#HR.2`D"CI2979I<VEO;CH@("`@("`D4F5V:7-I;VXZ(#$N-RXQ,"XQ("0*
M.D%U=&AO<CH@("`@("`@($EV86X@12X@36]O<F4@24D@/')K<G5S='E`=&1Y
M8RYC;VT^+"!-:6ME($AA<F1Y"B`@("`@("`@("`@("`@("`\;6EK96A`<W!A
M<FLN8V]M/@HZ0V]N=&%C=#H@("`@("`@:&]R9&5`;&ES=',N:&]R9&4N;W)G
M"@HN+B!C;VYT96YT<SHZ($-O;G1E;G1S"BXN('-E8W1I;VXM;G5M8F5R:6YG
M.CH*"D]N;&EN92!R97-O=7)C97,@9F]R(&1E=F5L;W!I;F<@=VET:"!(;W)D
M92`H:6YC;'5D:6YG($AO<F1E($9R86UE=V]R:R!!4$D*9&]C=6UE;G1A=&EO
M;BD@87)E(&%V86EL86)L92!A=#H*"B`@(&AT='`Z+R]D978N:&]R9&4N;W)G
M+R`@(`H*"DAA8VMI;F<@;VX@2&]R9&4@9G)O;2!#5E,*/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/0H*2&]R9&4@86YD(&ET<R!M;V1U;&5S('5S92!#5E,@
M9F]R('-O=7)C92!C;VYT<F]L+B`@0U93(&ES('=E;&PM9&]C=6UE;G1E9"P@
M8G5T"G1H92!M86YU86P@<&%G92!A<W-U;65S('EO=2!A;')E861Y(&MN;W<@
M:&]W(&ET('=O<FMS+B`@06X@97AC96QL96YT(&=U:61E('1O"F=E='1I;F<@
M<W1A<G1E9"!W:71H($-64R!I<R`B3W!E;B!3;W5R8V4@1&5V96QO<&UE;G0@
M=VET:"!#5E,B(&)Y($MA<FP@1F]G96PN"DET)W,@<'5B;&ES:&5D(&)Y($-O
M<FEO;&ES+"!A;F0@=&AE('1E8VAN:6-A;"!P87)T(&]F('1H92!B;V]K(&ES
M(&%V86EL86)L90IF;W(@9G)E92!O;B!T:&4@5V5B(&%T"@H@("!H='1P.B\O
M8W9S8F]O:RYR960M8F5A;BYC;VTO"@I4:&4@<&%P97(@=F5R<VEO;B!I;F-L
M=61E<R!C:&%P=&5R<R!O;B!O<F=A;FEZ:6YG(&%N9"!M86YA9VEN9R!/<&5N
M(%-O=7)C90ID979E;&]P;65N="X@(%EO=2!C86X@;V)T86EN(&$@0U93(&-L
M:65N="!F;W(@>6]U<B!O<&5R871I;F<@<WES=&5M(&%T"D-64TA/344L(&%T
M"@H@("!H='1P.B\O=W=W+F-V<VAO;64N;W)G+V1O=VYL;V%D<RYH=&UL"@IO
M9B!T:&5M(&UA>2!B92!F;W5N9"!A="!H='1P.B\O=W=W+F-Y8VQI8RYC;VT@
M+2!T:&5Y('-U<'!O<G0@0U93(&-O;6UE<F-I86QL>2P*979E;B!T:&]U9V@@
M:70@:7,@86X@;W!E;B!S;W5R8V4@<')O9W)A;2X*"EEO=2!W:6QL(&YE960@
M82!#5E,@8VQI96YT('1O(&1O(&%N>2!O9B!T:&4@9F]L;&]W:6YG("AC:&5C
M:R!O=70@=&AE($-Y8VQI8PIH;VUE<&%G92!I9B!Y;W4@9&]N)W0@:&%V92!O
M;F4I+@H*1F]R('1H;W-E(&%L<F5A9'D@9F%M:6QI87(@=VET:"!#5E,L('1H
M92!A;F]N>6UO=7,@0U934D]/5"!I<SHZ"@H@("`Z<'-E<G9E<CIC=G-R96%D
M0&%N;VYC=G,N:&]R9&4N;W)G.B]R97!O<VET;W)Y"@H*1&]W;FQO861I;F<@
M2&]R9&4@;6]D=6QE<R!F<F]M($-64PHM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM"@I9;W4@=VEL;"!W86YT('1O(&1O('1H:7,@:68@>6]U
M('=A;G0@8FQE961I;F<@961G92!C;V1E+@H*,2X@1V\@=&\@=&AE(&1I<F5C
M=&]R>2!Y;W4@=V%N="!T;R!D;W=N;&]A9"!T:&4@8V]D92!T;SHZ"@H@("`@
M("!C9"!^+W=O<FL*"C(N(%-E="!@8$-64U)/3U1@8"!T;R!T:&4@;&]C871I
M;VX@;V8@=&AE($-64R!R97!O<VET;W)Y+B`@66]U(&-O=6QD(&%L<V\@<&%S
M<PH@("!C=G,@=&AE(&YA;64@;V8@=&AE($-64R!R;V]T('=I=&@@=&AE(&!@
M+61@8"!O<'1I;VXN("!"92!S=7)E('1O(&YO=&4@=&AE"B`@(&-O;&]N(&!@
M.F!@(&EN(&9R;VYT(&]F(&!@<'-E<G9E<F!@+@H*("`@*&EN('-H+"!K<V@L
M(&)A<V@L('IS:"DZ.@H*("`@("`@0U934D]/5#TZ<'-E<G9E<CIC=G-R96%D
M0&%N;VYC=G,N:&]R9&4N;W)G.B]R97!O<VET;W)Y"B`@("`@(&5X<&]R="!#
M5E-23T]4"@H@("`H:6X@8W-H+"!T8W-H*3HZ"@H@("`@("!S971E;G8@0U93
M4D]/5"`Z<'-E<G9E<CIC=G-R96%D0&%N;VYC=G,N:&]R9&4N;W)G.B]R97!O
M<VET;W)Y"@HS+B!,;V=I;B!T;R!T:&4@86YO;GEM;W5S($-64R!R97!O<VET
M;W)Y+B`@5VAE;B!P<F]M<'1E9"!F;W(@82!P87-S=V]R9"P@96YT97(*("`@
M8&!H;W)D96!@.CH*("`@("`@"B`@("`@(&-V<R!L;V=I;@H*-"X@0VAE8VL@
M;W5T('1H92!M;V1U;&4@>6]U('=A;G0@=&\@9&]W;FQO860@9G)O;2!T:&4@
M<F5P;W-I=&]R>2X@(%)E<&QA8V4*("`@8&!-3T153$5@8"!W:71H(&AO<F1E
M+"!I;7`L('1U<F)A+"!T<F]L;"P@86YD('-O(&9O<G1H+B`@*%1H92!@8"UZ
M,V!@('1E;&QS"B`@(&-V<R!T;R!C;VUP<F5S<R!T:&4@9&%T82!I="!S96YD
M<R!O=F5R('1H92!N971W;W)K+"!U;F-O;7!R97-S:6YG(&ET('=H96X*("`@
M>6]U(#\_/S\Z.@H*("`@("`@8W9S("UZ,R!C;R!-3T153$4*"B`@($EF('EO
M=2!W86YT('1O(&-H96-K(&]U="!A('!A<G1I8W5L87(@8G)A;F-H(&]F(&$@
M;6]D=6QE("AF;W(@97AA;7!L92P@=&AE"B`@(&!@4D5,14Y'7S-@8"!B<F%N
M8V@@;V8@24U0*2P@:6YC;'5D92!T:&4@8G)A;F-H('1A9R!L:6ME('-O+"!R
M97!L86-I;F<*("`@8&!404=@8"!W:71H('1H92!N86UE(&]F('1H92!B<F%N
M8V@Z.@H*("`@("`@8W9S("UZ,R!C;R`M<B!404<@34]$54Q%"@HU+B!!<R!Y
M;W4@=V]R:R!W:71H('1H92!S;V9T=V%R92P@>6]U(&-A;B!P97)I;V1I8V%L
M;'D@=7!D871E('EO=7(@=')E92!T;PH@("!M871C:"!T:&4@;6%S=&5R('1R
M964@870@86YY('1I;64L(&9R;VT@=&AE('1O<"!D:7)E8W1O<GD@;V8@=&AE
M"B`@(&UO9'5L92X@(%5S:6YG(&!@:&]R9&5@8"!A<R!A;B!E>&%M<&QE(&UO
M9'5L93HZ"@H@("`@("!C9"!^+W=O<FLO:&]R9&4*("`@("`@8W9S("UZ,R!U
M<&1A=&4*"@I/8G1A:6YI;F<@82!#5E,@86-C;W5N=`HM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+0H*268@>6]U)W)E(&=O:6YG('1O(&)E(&$@<F5G=6QA<B!C
M;VYT<FEB=71O<B!T;R!(;W)D92P@=&AE;B!Y;W4@8V%N(')E<75E<W0@80I#
M5E,@86-C;W5N="!I;B!O<F1E<B!T;R!C;VUM:70@>6]U<B!C:&%N9V5S('1O
M('1H92!R97!O<VET;W)Y('EO=7)S96QF+B`@*$EF"GEO=2=R92!O;FQY(&=O
M:6YG('1O(&)E(&-O;G1R:6)U=&EN9R!O;F-E(&EN(&$@=VAI;&4L('1H97)E
M('1R=6QY(&ES(&YO(&YE960*9F]R('EO=2!T;R!H879E(&]N92P@87,@<&]S
M=&EN9R!Y;W5R(&-H86YG97,@=&\@=&AE(&%P<&QI8V%T:6]N)W,@;6%I;&EN
M9R!L:7-T"G=I;&P@<W5F9FEC92!T;R!G970@>6]U<B!C:&%N9V5S(')E=FEE
M=V5D(&%N9"!I;F-L=61E9"XI"@I)9B!Y;W4@9&\@9V5T(&-O;6UI="!A8V-E
M<W,@=&\@=&AE($-64R!T<F5E+"!Y;W4@=VEL;"!H879E('1H92!A8FEL:71Y
M('1O(&UE<W,*<V]M92!T:&EN9W,@=7`N("!.;W0@9F]R(&=O;V0L(&UI;F0@
M>6]U+"!A<R!#5E,@86QL;W=S('5P9&%T97,@=&\@8F4@8F%C:V5D"F]F9BP@
M8G5T('EO=2!S=&EL;"!N965D('1O(')E;65M8F5R('=H870@>6]U)W)E(&1O
M:6YG(&%N9"!B92!C87)E9G5L('=H870@>6]U"F-O;6UI="!A;F0@=VAE;B!Y
M;W4@8V]M;6ET(&ET+B`@0F5C875S92!O9B!T:&ES+"!W92!P<F5F97(@=&AA
M="!Y;W4@<W5B;6ET"GEO=7(@=V]R:R!T;R!T:&4@;6%I;&EN9R!L:7-T(&9O
M<B!A('=H:6QE('-O('=E(&-A;B!T96QL('EO=2!K;F]W('=H870@>6]U)W)E
M"F1O:6YG+@H*268@>6]U)W)E(&YO="!A(&-O;6UI='1E<BP@=&AE(&)E<W0@
M=V%Y('1O('-U8FUI="!A('!A=&-H(&ES('1O('-E;F0@:70@96ET:&5R"G1O
M('1H92!A<'!L:6-A=&EO;B=S(&UA:6QI;F<@;&ES="!O<B!T;R!D979`;&ES
M=',N:&]R9&4N;W)G+B`@1F]R(&UO<F4*:6YF;W)M871I;VX@;VX@2&]R9&4@
M;6%I;&EN9R!L:7-T<RP@<V5E"@H@("!H='1P.B\O=W=W+FAO<F1E+F]R9R]M
M86EL+PH*"D-O;6UI='1I;F<@8VAA;F=E<R!T;R!#5E,*+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+0H*3VYC92!Y;W4@:&%V92!A($-64R!A8V-O=6YT+"!Y
M;W4@=VEL;"!N965D('1O(&QO9R!I;G1O('1H92!#5E,@<V5R=F5R('-O(&ET
M"FMN;W=S('=H;R!Y;W4@87)E(&%N9"!C86X@9W)A;G0@>6]U('1H92!A<'!R
M;W!R:6%T92!R:6=H=',@=&\@=V]R:R!O;B!T:&4*<V]U<F-E<RX*"E1H92!@
M8$-64U)/3U1@8"!I<R!D:69F97)E;G0@9F]R(&-O;6UI='1E<G,[(&EN<W1E
M860@;V8@=&AE(')E<&]S:71O<GD@;&ES=&5D"F%B;W9E+"!S970@8&!#5E-2
M3T]48&`@=&\Z.@H*("`@.F5X=#I54T523D%-14!C=G,N:&]R9&4N;W)G.B]R
M97!O<VET;W)Y"@IR97!L86-I;F<@8&!54T523D%-16!@('=I=&@@>6]U<B!C
M=G,@=7-E<FYA;64N"@I4:&4@8V]M;6ET=&5R<R<@<F5P;W-I=&]R>2!D;V5S
M(&YO="!U<V4@<'-E<G9E<BX@(%EO=2!W:6QL(&YE960@=&\@:&%V92!S<V@*
M:6YS=&%L;&5D(&]N('EO=7(@<WES=&5M+"!A;F0@:&%V92!A<G)A;F=E9"!W
M:71H(&]N92!O9B!T:&4@8V]R92!D979E;&]P97)S('1O"G!U="!Y;W5R(%-3
M2"!K97D@;VX@=&AE('-Y<W1E;2X@($EF('EO=2!H879E(&YO="!D;VYE('1H
M:7,L('1A;&L@=&\@;VYE(&]F('1H90IC;W)E(&1E=F5L;W!E<G,N"@I4;R!G
M970@8W9S('1O('5S92!S<V@L('EO=2!W:6QL(&YE960@=&\@<V5T('1H92!E
M;G9I<F]N;65N="!V87)I86)L90I@8$-64U]24TA@8"!T;R!@8'-S:&!@(&EN
M('EO=7(@<VAE;&PN"@I9;W4@9&\@;F]T(&YE960@=&\@9&\@8&!C=G,@;&]G
M:6Y@8#L@>6]U('=I;&P@8F4@<')O;7!T960@9F]R('1H92!P87-S<&AR87-E
M"F9O<B!Y;W5R(%-32"!K97D@=VAE;F5V97(@>6]U(&%C8V5S<R!T:&4@<F5P
M;W-I=&]R>2X*"EEO=2!M87D@86QS;R!W:7-H('1O('-E="!T:&4@96YV:7)O
M;FUE;G0@=F%R:6%B;&4@8&!%1$E43U)@8"!T;R!P;VEN="!T;R!Y;W5R"F9A
M=F]R:71E('1E>'0@961I=&]R+B!4:&ES('=A>2!W:&5N('EO=2!C;VUM:70@
M<V]F='=A<F4@8VAA;F=E<R!A;F0@:70@87-K<PIY;W4@=&\@96YT97(@82!C
M:&%N9V4@9&5S8W)I<'1I;VXL('EO=2!C86X@9&\@<V\@:6X@>6]U<B!F879O
M<FET92!E9&ET;W(N"@I4:&5N+"!F;W(@=V]R:R!O;B!D979E;&]P;65N=&%L
M+"!B;&5E9&EN9RUE9&=E('9E<G-I;VYS.@H*,2D@0VAE8VL@;W5T('1H92!C
M;V1E(&)Y('1Y<&EN9R!@8&-V<R!C;R!-3T153$5@8`HR*2!7;W)K(&]N('1H
M92!C;V1E(#QH86-K+"!H86-K+"!H86-K/@HS*2!#;VUM:70@86YY(&-H86YG
M97,@=VET:"!@8&-V<R!C;VUM:70@1DE,14Y!34538&`@:6X@=&AE(&1I<F5C
M=&]R>2!T:&4@9FEL97,*("`@87)E(&EN+@H*4V]M971I;65S+"!O=&AE<G,@
M=VEL;"!M86ME(&-H86YG97,@86YD('EO=2!W:6QL(&YE960@=&\@=7!D871E
M('EO=7(@=')E92!S;PIT:&4@8VAA;F=E<R!S:&]W('5P(&EN('EO=7(@;&]C
M86P@<V]U<F-E<RX@(%EO=2!D;R!T:&ES('=I=&@@=&AE(&!@8W9S"G5P9&%T
M96!@(&-O;6UA;F0@:6X@=&AE(&AO<F1E(&1I<F5C=&]R>2X@(%!L96%S92!B
M92!S=7)E('1O('5P9&%T92!Y;W5R('1R964*<F5G=6QA<FQY.R!M97)G:6YG
M(&-H86YG97,@:7,@8V]N<VED97)A8FQY(&UO<F4@=V]R:R!T:&%N(')U;FYI
M;F<@8&!C=G,*=7!D871E8&`N"@I4;R!W;W)K('=I=&@@86YY('1A9V=E9"!B
M<F%N8V@@*'1O('!A=&-H(&$@<W1A8FQE(')E;&5A<V4L(&9O<B!I;G-T86YC
M92DZ"@HQ*2!#:&5C:R!O=70@=&AE(&-O9&4@=VET:"!@8&-V<R!C;R`M<B!4
M04<@34]$54Q%8&`*,BD@5V]R:R!O;B!T:&4@8V]D92`\:&%C:RP@:&%C:RP@
M:&%C:SX*,RD@0V]M;6ET(&%N>2!C:&%N9V5S('=I=&@@8&!C=G,@8V]M;6ET
M($9)3$5.04U%4V!@(&EN('1H92!D:7)E8W1O<GD@=&AE(&9I;&5S"B`@(&%R
M92!I;BX*"DEF('-O;65B;V1Y(&5L<V4@86QS;R!M86ME<R!C:&%N9V5S('1O
M('1H92!L86)E;&5D('9E<G-I;VXL('EO=2!C86X@9V5T('1H96T*:6X@>6]U
M<B!L;V-A;"!S;W5R8V4@=')E92!W:71H('1H92!@8&-V<R!U<&1A=&5@8"!C
M;VUM86YD(&ES<W5E9"!I;B!T:&4@;6]D=6QE"F1I<F5C=&]R>2X*"DEF('EO
M=2!A<F4@9&]N92!W;W)K:6YG('=I=&@@=&AE(&QA8F5L960@<V]U<F-E(&)R
M86YC:"P@86YD('=O=6QD(&QI:V4@=&\@;6]V90IB86-K(&EN=&\@=&AE(&)L
M965D:6YG+65D9V4@9&5V96QO<&UE;G0@<V]U<F-E('1R964L('EO=2!C86X@
M:7-S=64@=&AE(&-O;6UA;F0*8&!C=G,@=7!D871E("U!8&`@=&\@=7!D871E
M(&5V97)Y=&AI;F<@=&\@=&AE(&-U<G)E;G0@8&!(14%$8&`@=F5R<VEO;BX*
M"BA792!U<V5D('1O(&1O8W5M96YT(&AO=R!T;R!M97)G92!C;V1E(&9R;VT@
M2$5!1"!I;G1O(&$@;&%B96QE9"!B<F%N8V@@:&5R92P*8G5T('-I;F-E(&ET
M('=A<R!H96%V:6QY('!E<'!E<F5D('=I=&@@(G1A;&L@=&\@8V]R92!D979E
M;&]P97)S(&9I<G-T(BP@:70G<PIB965N(&5L:61E9"!T;R!P<F5V96YT(&5R
M<F]R<R!O9B!E>'!E<FEM96YT871I;VXN("!)9B!Y;W4@=&AI;FL@>6]U(&YE
M960@=&\@9&\*=&AA="P@>6]U(&AA=F4@=&\@=&%L:R!T;R!C;W)E(&1E=F5L
M;W!E<G,@86YY:&]W("TM('1H97DG;&P@97AP;&%I;B!H;W<N*0H*"D]T:&5R
M($-64R!.;W1E<PHM+2TM+2TM+2TM+2TM+2T*"DEF('EO=2!D;R!E;F0@=7`@
M9V5T=&EN9R!A($-64R!A8V-O=6YT+"!H97)E(&%R92!S;VUE('1I<',@=&\@
M:&5L<"!K965P('1H:6YG<PIG;VEN9R!S;6]O=&AL>3H*"C$N(%-U8G-C<FEB
M92!T;R!T:&4@8W9S0&QI<W1S+FAO<F1E+F]R9R!A;F0@9&5V0&QI<W1S+FAO
M<F1E+F]R9R!M86EL:6YG(&QI<W1S+@H*,BX@0F4@<W5R92!T;R!M;V1I9GD@
M=&AE(&9I;&4@8&!D;V-S+T-(04Y'15-@8"!T;R!R969L96-T('1H92!C:&%N
M9V5S('1O('1H90H@("!C;V1E('EO=2!A<F4@8V]M;6ET=&EN9RX*"C,N($EF
M('EO=2=R92!P;&%N;FEN9R!O;B!D;VEN9R!A;GET:&EN9R!M86IO<BP@<&QE
M87-E(&QE="!P96]P;&4@:VYO=R!I;@H@("!A9'9A;F-E(&]N('1H92!D979`
M(&]R(&%P<&QI8V%T:6]N(&UA:6QI;F<@;&ES=',@87,@87!P<F]P<FEA=&4N
M"@H@("!$979E;&]P97)S(&YE960@=&\@8V]M;75N:6-A=&4@97AT96YS:79E
M;'D@:6X@;W)D97(@=&\@;6%K92!S=7)E(&5V97)Y;VYE"B`@(&MN;W=S('=H
M870G<R!G;VEN9R!O;BX@(%1H:7,@:7,@97AT<F5M96QY(&EM<&]R=&%N="!W
M:&5N('EO=2!W;W)K(&]N(&ME>0H@("!C;VUP;VYE;G1S+@H*-"X@57-E('1H
M92!"=6<@5')A8VMI;F<@4WES=&5M(&]N(&AT='`Z+R]B=6=S+FAO<F1E+F]R
M9RX@($%L;"!N97<@<W5B;6ES<VEO;G,*("`@87)E(&)E:6YG(&-C)V0@=&\@
M=&AE(&)U9W-`;&ES=',N:&]R9&4N;W)G(&UA:6QI;F<@;&ES="!S;R!T:&%T
M(&EF('=E(&%R96XG=`H@("!P87EI;F<@871T96YT:6]N+"!W92=L;"!A="!L
M96%S="!G970@;6%I;"!A8F]U="!I="X@(%5S:6YG('1H92!"=6=S"B`@(&1A
M=&%B87-E(&AE;'!S('5S(&ME97`@=')A8VL@;V8@:7-S=65S('=E(&%R92!H
M879I;F<@86YD('=H97)E('=E('-T86YD"B`@('=I=&@@=&AE('!R;V1U8W0N
M"@HU+B!296UE;6)E<B!T;R!A9'9A;F-E('1H92!L:6)R87)Y('9E<G-I;VX@
M=VAE;F5V97(@86YY=&AI;F<@;6%J;W(@:7,@8VAA;F=E9"X*````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O9&]C<R])3E-404Q,````````````````````
M````````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`V-3(S,@`Q,#4Q-30S
M,S<T,P`P,3<V-#8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M"B!);G-T86QL:6YG('1H92!(;W)D92`S+C$@1G)A;65W;W)K"CT]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*.DQA<W0@=7!D871E.B`@
M("1$871E.B`R,#`V+S`X+S$U(#`Y.C,P.C0S("0*.E)E=FES:6]N.B`@("`@
M("12979I<VEO;CH@,2XY,"XV+C$V("0*.D-O;G1A8W0Z("`@("`@(&AO<F1E
M0&QI<W1S+FAO<F1E+F]R9PH*+BX@8V]N=&5N=',Z.B!#;VYT96YT<PHN+B!S
M96-T:6]N+6YU;6)E<FEN9SHZ"@I4:&ES(&1O8W5M96YT(&-O;G1A:6YS(&EN
M<W1R=6-T:6]N<R!F;W(@:6YS=&%L;&EN9R!T:&4@2&]R9&4@1G)A;65W;W)K
M(&]N('EO=7(*<WES=&5M+@H*5&AE($AO<F1E($9R86UE=V]R:RP@8GD@:71S
M96QF+"!D;V5S(&YO="!P<F]V:61E(&%N>2!S:6=N:69I8V%N="!E;F0@=7-E
M<@IF=6YC=&EO;F%L:71Y.R!I="!P<F]V:61E<R!A(&)A<V4@9F]R(&]T:&5R
M(&%P<&QI8V%T:6]N<R!A;F0@=&]O;',@9F]R"F1E=F5L;W!E<G,N(%=H96X@
M>6]U(&AA=F4@:6YS=&%L;&5D($AO<F1E(&%S(&1E<V-R:6)E9"!B96QO=RP@
M>6]U('=I;&P*<')O8F%B;'D@=V%N="!T;R!I;G-T86QL('-O;64@;V8@=&AE
M(&%V86EL86)L92!(;W)D92!A<'!L:6-A=&EO;G,L('-U8V@@87,*24U07R`H
M82!W96)M86EL(&-L:65N="DL(&]R($MR;VYO;&ET:%\@*&$@8V%L96YD87(I
M+B!4:&5R92!I<R!A(&QI<W0@;V8@2&]R9&4*87!P;&EC871I;VYS(&%N9"!P
M<F]J96-T<R!A="!H='1P.B\O=W=W+FAO<F1E+F]R9R]P<F]J96-T<RYP:'`N
M"@I)9B!Y;W4@87)E(&EN=&5R97-T960@:6X@9&5V96QO<&EN9R!A<'!L:6-A
M=&EO;G,@9F]R($AO<F1E+"!T:&5R92!I<R!D979E;&]P97(*9&]C=6UE;G1A
M=&EO;B!A;F0@<F5F97)E;F-E<R!A=F%I;&%B;&4@870@:'1T<#HO+V1E=BYH
M;W)D92YO<F<O+"!A;F0@<V]M90IT=71O<FEA;',@86YD('!A<&5R<R!O;B!(
M;W)D92!A=F%I;&%B;&4@870@:'1T<#HO+W=W=RYH;W)D92YO<F<O<&%P97)S
M+RX*"D9O<B!I;F9O<FUA=&EO;B!O;B!T:&4@8V%P86)I;&ET:65S(&%N9"!F
M96%T=7)E<R!O9B!(;W)D92P@<V5E('1H92!F:6QE"E)%041-15\@:6X@=&AE
M('1O<"UL979E;"!D:7)E8W1O<GD@;V8@=&AE($AO<F1E(&1I<W1R:6)U=&EO
M;BX*"BXN(%])35`Z(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VEM<"\*+BX@7TMR
M;VYO;&ET:#H@:'1T<#HO+W=W=RYH;W)D92YO<F<O:W)O;F]L:71H+PH*"D]B
M=&%I;FEN9R!(;W)D90H]/3T]/3T]/3T]/3T]/3T*"E1H92!(;W)D92!&<F%M
M97=O<FL@8V%N(&)E(&]B=&%I;F5D(&9R;VT@=&AE($AO<F1E('=E8G-I=&4@
M86YD($944"!S97)V97(L(&%T"@H@("!H='1P.B\O=W=W+FAO<F1E+F]R9R]H
M;W)D92\*"B`@(&9T<#HO+V9T<"YH;W)D92YO<F<O<'5B+VAO<F1E+PH*3W(L
M(&)E='1E<B!Y970L('5S92!A(&UI<G)O<B!T:&%T(&ES(&-L;W-E<B!T;R!Y
M;W4N("!4:&4@;6ER<F]R(&QI<W0@8V%N(&)E"F9O=6YD(&%T.@H*("`@:'1T
M<#HO+W=W=RYH;W)D92YO<F<O;6ER<F]R<RYP:'`*"E1H92!&5%`@9&ER96-T
M;W)Y(&-O;G1A:6YS('1H92!(;W)D92!02%`@9FEL97,@=VAI8V@@8V%N(&)E
M('5N<&%C:V5D('5S:6YG"F!@=&%R8&`@86YD(&!@9W5N>FEP8&`@*'-E92!@
M26YS=&%L;&EN9R!(;W)D96!?+"!B96QO=RDN"@I";&5E9&EN9RUE9&=E(&1E
M=F5L;W!M96YT('9E<G-I;VYS(&]F($AO<F1E(&%N9"!I=',@87!P;&EC871I
M;VYS(&%R92!A=F%I;&%B;&4*=FEA($-64SL@<V5E('1H92!F:6QE(&!D;V-S
M+TA!0TM)3D=@7RP@;W(@=FES:70@=&AE('=E8G-I=&4*:'1T<#HO+W=W=RYH
M;W)D92YO<F<O<V]U<F-E+RP@9F]R(&EN9F]R;6%T:6]N(&]N(&%C8V5S<VEN
M9R!T:&4@2&]R9&4@0U93"G)E<&]S:71O<GDN"@I9;W4@=VEL;"!P<F]B86)L
M>2!A;'-O('=A;G0@;VYE(&]R(&UO<F4@2&]R9&4@87!P;&EC871I;VYS+"!S
M:6YC92!(;W)D90ID;V5S;B=T(&1O(&UU8V@@8GD@:71S96QF.R!A(&QI<W0@
M;V8@879A:6QA8FQE(&%P<&QI8V%T:6]N<RP@=VET:"!L:6YK<R!T;PID97-C
M<FEP=&EO;G,@86YD(&1O=VYL;V%D<RP@8V%N(&)E(&9O=6YD(&%T"@H@("!H
M='1P.B\O=W=W+FAO<F1E+F]R9R]P<F]J96-T<RYP:'`*"E=H:6QE('!R979I
M;W5S('9E<G-I;VYS(&]F($AO<F1E('=E<F4@;G5M8F5R960@=&\@8V]R<F5S
M<&]N9"!W:71H(&$@<&%R=&EC=6QA<@IV97)S:6]N(&]F('1H92!)35`@=V5B
M;6%I;"!A<'!L:6-A=&EO;BP@=&AA="!I<R!N;R!L;VYG97(@=')U92!A<R!O
M9B!(;W)D90IV97)S:6]N(#(N,"X@5&AE(&-U<G)E;G0@=F5R<VEO;B!O9B!(
M;W)D92!W:6QL('=O<FL@=VET:"!T:&4@8W5R<F5N="!V97)S:6]N"F]F($AO
M<F1E(&%P<&QI8V%T:6]N<RX@1F]R(&UO<F4@:6YF;W)M871I;VX@86)O=70@
M=VAI8V@@=F5R<VEO;G,@87)E"F-O;7!A=&EB;&4@<V5E(&AT='`Z+R]W=W<N
M:&]R9&4N;W)G+W-O=7)C92]V97)S:6]N<RYP:'`N"@H*475I8VL@26YS=&%L
M;`H]/3T]/3T]/3T]/3T]"@I4:&5S92!A<F4@=F5R>2!T97)S92!I;G-T<G5C
M=&EO;G,@:&]W('1O(&EN<W1A;&P@2&]R9&4@86YD(&ET<R!P<F5R97%U:7-I
M=&5S"F]N(&$@3$%-4"!S>71E;2X@(%1H97D@87)E(&%D9')E<W-E9"!T;R!E
M>'!E<FEE;F-E9"!A9&UI;FES=')A=&]R<R!W:&\@:VYO=PIE>&%C=&QY('=H
M870@=&AE>2!A<F4@9&]I;F<N("!&;W(@;6]R92!D971A:6QE9"!I;G-T<G5C
M=&EO;G,L('-T87)T(')E861I;F<*8F5L;W<@870@4')E<F5Q=6ES:71E<U\N
M"@HQ+B!#;VUP:6QI;F<@4$A0(&9O<B!!<&%C:&4Z.@H*("`@("!C9"!P:'`M
M>"YX+G@O"B`@("`@+B]C;VYF:6=U<F4@+2UW:71H+6%P>',]+W5S<B]S8FEN
M+V%P>',@7`H@("`@("`@("`@("`@("`@("TM=VET:"UG971T97AT("TM=VET
M:"UD;VT@+2UW:71H+6UC<GEP="!<"B`@("`@("`@("`@("`@("`@+2UW:71H
M+6EC;VYV("TM96YA8FQE+6UB<W1R:6YG/6%L;"`M+65N86)L92UM8G)E9V5X
M(%P*("`@("`@("`@("`@("`@("`M+7=I=&@M9V0@+2UW:71H+7!N9RUD:7(]
M+W5S<B`M+7=I=&@M:G!E9RUD:7(]+W5S<B!<"B`@("`@("`@("`@("`@("`@
M+2UW:71H+6UI;64M;6%G:6,]+W5S97(O<VAA<F4O;6ES8R]M86=I8RYM:6UE
M(%P*("`@("`@("`@("`@("`@("!;+2UW:71H+6UY<W%L?"TM=VET:"UP9W-Q
M;'PM+7=I=&@M;V-I.'PM+7=I=&@M;&1A<%T*("`@("!M86ME"B`@("`@;6%K
M92!I;G-T86QL"@HR+B!297-T87)T($%P86-H92X*"C,N($EN<W1A;&P@4$5!
M4B!P86-K86=E<SHZ"@H@("`@('!E87(@:6YS=&%L;"`M;R!,;V<@36%I;"!-
M86EL7TUI;64@1$(@1&%T92!&:6QE"B`@("`@<&5A<B`M9"!P<F5F97)R961?
M<W1A=&4]8F5T82!I;G-T86QL("UA(%-E<G9I8V5S7U=E871H97(*"C0N($5X
M=')A8W0@=&%R8F%L;#HZ"@H@("`@(&-D("]U<W(O;&]C86PO87!A8VAE+VAT
M9&]C<PH@("`@('1A<B!Z>'9F("]P871H+W1O+VAO<F1E+7@N>2YZ+G1A<BYG
M>@H@("`@(&UV(&AO<F1E+7@N>2YZ(&AO<F1E"@HU+B!#;VYF:6=U<F4@2&]R
M9&4Z.@H*("`@("!C9"!C;VYF:6<O"B`@("`@9F]R(&8@:6X@*BYD:7-T.R!D
M;R!C<"`D9B!@8F%S96YA;64@)&8@+F1I<W1@.R!D;VYE"@HV+B!#<F5A=&4@
M9&%T86)A<V4@=&%B;&5S.CH*"B`@("`@8V0@+BXO<V-R:7!T<R]S<6P*("`@
M("!V:2!C<F5A=&4N;7ES<6PN<W%L"B`@("`@;7ES<6P@+74@<F]O="`M<"`\
M(&-R96%T92YM>7-Q;"YS<6P*"C<N(%1E<W0@2&]R9&4Z.@H*("`@("!H='1P
M.B\O>6]U<BUS97)V97(O:&]R9&4O=&5S="YP:'`*"C@N($9I;FES:"!C;VYF
M:6=U<F%T:6]N.CH*"B`@("`@:'1T<#HO+WEO=7(M<V5R=F5R+VAO<F1E+PH*
M("`@1V\@=&\@061M:6YS=')A=&EO;B`]/B!3971U<"`]/B!(;W)D90H*"E!R
M97)E<75I<VET97,*/3T]/3T]/3T]/3T]/0H*5&AE(&9O;&QO=VEN9R!P<F5R
M97%U:7-I=&5S(&%R92`J*E)%455)4D5$*BH@9F]R($AO<F1E('1O(&9U;F-T
M:6]N('!R;W!E<FQY+@H*,2X@02!W96)S97)V97(@=&AA="!S=7!P;W)T<R!0
M2%`N"@H@("!(;W)D92!A;F0@:71S(&%P<&QI8V%T:6]N<R!A<F4@9&5V96QO
M<&5D('5N9&5R('1H92!!<&%C:&4@=V5B<V5R=F5R+"!W:&EC:`H@("!W92!R
M96-O;6UE;F0N($%P86-H92!I<R!A=F%I;&%B;&4@9G)O;0H*("`@("`@:'1T
M<#HO+VAT='!D+F%P86-H92YO<F<O"@H@("!(;W)D92!H87,@86QS;R!B965N
M(')E<&]R=&5D;'D@=7-E9"!S=6-C97-S9G5L;'D@=6YD97(@36EC<F]S;V9T
M($E)4RP@86UO;F<*("`@;W1H97)S+@H*,BX@4$A0(#0N,RXP(&]R(&%B;W9E
M+@H*("`@4$A0(&ES('1H92!I;G1E<G!R971E9"!L86YG=6%G92!I;B!W:&EC
M:"!(;W)D92!I<R!W<FET=&5N+@H@("!9;W4@8V%N(&]B=&%I;B!02%`@870*
M"B`@("`@(&AT='`Z+R]W=W<N<&AP+FYE="\*"B`@($9O;&QO=R!T:&4@:6YS
M=')U8W1I;VYS(&EN('1H92!02%`@<&%C:V%G92!T;R!B=6EL9"!02%`@9F]R
M('EO=7(@<WES=&5M+B!)9@H@("!Y;W4@=7-E($%P86-H92P@8F4@<W5R92!T
M;R!B=6EL9"!02%`@87,@82!L:6)R87)Y('=I=&@@;VYE(&]F('1H92!F;VQL
M;W=I;F<*("`@;W!T:6]N<SHZ"@H@("`@("`@+2UW:71H+6%P86-H90H@("`@
M("`@+2UW:71H+6%P>',*("`@("`@("TM=VET:"UA<'AS,@H*("`@;W!T:6]N
M<R!T;R!@8"XO8V]N9FEG=7)E8&`L(&%N9"!N;W0@87,@82!S=&%N9&%L;VYE
M(&5X96-U=&%B;&4N"@H@("!4:&4@9F]L;&]W:6YG(%!(4"!O<'1I;VYS(&%R
M92`J*E)%455)4D5$*BH@8GD@2&]R9&4@*&QI<W1E9"!W:71H('1H96ER(&]W
M;@H@("!P<F5R97%U:7-I=&5S(&%N9"!C;VYF:6=U<F4@;W!T:6]N<RDN($EN
M(&UA;GD@8V%S97,L('1H92!R97%U:7)E9"!L:6)R87)I97,*("`@86YD('1O
M;VQS(&-A;B!B92!O8G1A:6YE9"!A<R!P86-K86=E<R!F<F]M('EO=7(@;W!E
M<F%T:6YG('-Y<W1E;2!V96YD;W(N"@H@("!A+B!'971T97AT('-U<'!O<G0N
M(&!@+2UW:71H+6=E='1E>'1@8`H*("`@("`@1V5T=&5X="!I<R!T:&4@1TY5
M(%1R86YS;&%T:6]N(%!R;VIE8W0G<R!L;V-A;&EZ871I;VX@;&EB<F%R>2X*
M("`@("`@2&]R9&4@=7-E<R!G971T97AT('1O('!R;W9I9&4@;&]C86P@=')A
M;G-L871I;VYS(&]F('1E>'0@9&ES<&QA>65D(&)Y"B`@("`@(&%P<&QI8V%T
M:6]N<RX@26YF;W)M871I;VX@;VX@;V)T86EN:6YG('1H92!G971T97AT('!A
M8VMA9V4@:7,@879A:6QA8FQE"B`@("`@(&%T"@H@("`@("`@("!H='1P.B\O
M=W=W+F=N=2YO<F<O<V]F='=A<F4O9V5T=&5X="]G971T97AT+FAT;6P*"B`@
M("`@(%-E92!A;'-O(&YO=&4@8F5L;W<@;VX@8V]N9FEG=7)I;F<@5')A;G-L
M871I;VYS7RX*"B`@(&(N(%A-3"!A;F0@1$]-6$U,('-U<'!O<G0N(&!@+2UW
M:71H+61O;6!@"@H@("`@("!(;W)D92=S(&AE;'`@96YG:6YE(&%N9"!C;VUP
M;VYE;G0@<V5T=7`@<F5Q=6ER92!834P@<W5P<&]R="X@5VAI;&4@<V]M90H@
M("`@("!W96)S97)V97)S("AI;F-L=61I;F<@<F5C96YT($%P86-H92!V97)S
M:6]N<RD@:&%V92!834P@;&EB<F%R:65S"B`@("`@(&)U:6QT+6EN+"!O=&AE
M<G,@=VEL;"!R97%U:7)E('1H92!E>'!A="!834P@<&%R<V5R(&QI8G)A<FEE
M<RP@879A:6QA8FQE"B`@("`@(&9R;VT*"B`@("`@("`@:'1T<#HO+V5X<&%T
M+G-O=7)C969O<F=E+FYE="\*"B`@("`@("XN($EM<&]R=&%N=#HZ(%EO=2!M
M=7-T(&AA=F4@*BIB;W1H*BH@6$U,(&QI8G)A<FEE<R!I;G-T86QL960@9F]R
M($AO<F1E"B`@("`@("`@("`@("`@("`@("`@('1O('=O<FL@<')O<&5R;'DA
M"@H@("`@("!/;&1E<B!V97)S:6]N<R!O9B!02%`@86QS;R!R97%U:7)E(&!@
M+2UW:71H+7AM;&!@('1O(&5N86)L92!T:&4*("`@("`@4T%8(%A-3"!F=6YC
M=&EO;G,N(%=I=&@@<F5C96YT('9E<G-I;VYS(&]F(%!(4"P@=&AI<R!I<R!E
M;F%B;&5D"B`@("`@(&)Y(&1E9F%U;'0N"@H@("!4:&4@9F]L;&]W:6YG(%!(
M4"!O<'1I;VYS(&%R92`J*E)%0T]-345.1$5$*BH@=&\@96YA8FQE(&%D=F%N
M8V5D(&9E871U<F5S(&EN"B`@($AO<F1E.@H*("`@82X@02!P<F5F97)E;F-E
M<R!C;VYT86EN97(N"@H@("`@("!(;W)D92!A<'!L:6-A=&EO;G,@8V%N('-T
M;W)E('5S97(@<')E9F5R96YC97,@:6X@86X@4U%,(&1A=&%B87-E+"!A;@H@
M("`@("!,1$%0(&1I<F5C=&]R>2P@86X@24U34"!S97)V97(L(&$@2V]L86(@
M<V5R=F5R+"!O<B!I;B!02%`@<V5S<VEO;G,N"@H@("`@("!&;W(@4U%,(&1A
M=&%B87-E('!R969E<F5N8V5S('-T;W)A9V4L($AO<F1E(&ES('1H;W)O=6=H
M;'D@=&5S=&5D(&]N"B`@("`@($UY4U%,("A@8"TM=VET:"UM>7-Q;&!@*2!A
M;F0@4&]S=&=R95-13"`H8&`M+7=I=&@M<&=S<6Q@8"D@86YD(&AA<R!B965N
M"B`@("`@(')E<&]R=&5D('1O('=O<FL@=VET:"!/<F%C;&4@*&!@+2UW:71H
M+6]C:3A@8"D@86YD(%-13"!397)V97(*("`@("`@*&!@+2UW:71H+6US<W%L
M8&`I+B`@270@;6%Y(&%L<V\@=V]R:R!W:71H(&%N>2!O=&AE<B!D871A8F%S
M92!S=7!P;W)T960*("`@("`@8GD@4$5!4BP@8G5T('1H97D@87)E('5N=&5S
M=&5D+@H*("`@("`@4')E9F5R96YC97,@8V%N(&%L<V\@8F4@<W1O<F5D('9I
M82!,1$%0("A@8"TM=VET:"UL9&%P8&`I+"!+;VQA8@H@("`@("`H8&`M+7=I
M=&@M;&1A<&!@*2P@86YD($E-4U`N"@H@("`@("!!;'1E<FYA=&EV96QY+"!P
M<F5F97)E;F-E<R!C86X@8F4@<W1O<F5D(&EN(%!(4"!S97-S:6]N<RP@=VAI
M8V@*("`@("`@<F5Q=6ER97,@;F\@97AT97)N86P@<')O9W)A;7,@;W(@8V]N
M9FEG=7)E(&]P=&EO;G,L(&)U="!W:&EC:"!W:6QL(&YO=`H@("`@("!M86EN
M=&%I;B!P<F5F97)E;F-E<R!B971W965N('-E<W-I;VYS+@H*("`@("`@5VAI
M;&4@=&AE($Q$05`L(&1A=&%B87-E+"!+;VQA8BP@;W(@24U34"!S97)V97(@
M;F5E9"!N;W0@8F4@<G5N;FEN9R!O;@H@("`@("!T:&4@;6%C:&EN92!O;G1O
M('=H:6-H('EO=2!A<F4@:6YS=&%L;&EN9R!(;W)D92P@=&AE(&%P<')O<')I
M871E"B`@("`@(&-L:65N="!L:6)R87)I97,@=&\@86-C97-S('1H92!S97)V
M97(@;75S="!B92!A=F%I;&%B;&4@;&]C86QL>2X*"B`@("`@($EF(&$@<')E
M9F5R96YC92!C;VYT86EN97(@:7,@;F]T(&-O;F9I9W5R960L(&YO('!R969E
M<F5N8V4@;W!T:6]N<PH@("`@("!W:6QL(&)E(&-O;F9I9W5R86)L92!V:6$@
M2&]R9&4G<R!W96(@:6YT97)F86-E("T@=&AE(&1E9F%U;'0@=F%L=65S"B`@
M("`@('-T;W)E9"!I;B!E86-H(&%P<&QI8V%T:6]N<R!@8&-O;F9I9R]P<F5F
M<RYP:'!@8"!F:6QE('=I;&P@8F4@=7-E9"X*"B`@(&(N($UC<GEP="!S=7!P
M;W)T(&!@+2UW:71H+6UC<GEP=&!@"@H@("`@("!-8W)Y<'0@:7,@82!G96YE
M<F%L+7!U<G!O<V4@8W)Y<'1O9W)A<&AY(&QI8G)A<GD@=VAI8V@@:7,@8G)O
M861E<B!A;F0*("`@("`@<VEG;FEF:6-A;G1L>2!M;W)E(&5F9FEC:65N="`H
M1D%35$52(2D@=&AA;B!02%`G<R!O=VX@8W)Y<'1O9W)A<&AI8PH@("`@("!C
M;V1E+B!9;W4@8V%N(&]B=&%I;B!M8W)Y<'0@9G)O;0H*("`@("`@("`@:'1T
M<#HO+VUC<GEP="YS;W5R8V5F;W)G92YN970O"@H@("`@("!"=6EL9&EN9R!0
M2%`@=VET:&]U="!M8W)Y<'0@<W5P<&]R="!W:6QL(&YO="!S=&]P($AO<F1E
M(&9R;VT@=V]R:VEN9RP*("`@("`@8G5T('=I;&P@9F]R8V4@:70@=&\@=7-E
M('=E86ME<B`H86YD(&UU8V@@<VQO=V5R*2!E;F-R>7!T:6]N+@H*("`@8RX@
M551&+3@@<W5P<&]R="!@8"TM=VET:"UI8V]N=B`M+65N86)L92UM8G-T<FEN
M9SUA;&P@+2UE;F%B;&4M;6)R96=E>&!@"@H@("`@("!)9B!T:&5S92!E>'1E
M;G-I;VYS(&%R92!E;F%B;&5D+"!(;W)D92!C86X@<W5P<&]R="!M=6QT:6)Y
M=&4@8VAA<F%C=&5R"B`@("`@('-E=',@;&EK92!55$8M."`H;65A;FEN9R!T
M:&%T(&-O;G1E;G0@=VET:"!A;GD@8VAA<G-E="!C86X@8F4@=FEE=V5D"B`@
M("`@('=I=&@@86YY('1R86YS;&%T:6]N*2X*"B`@(&0N($=$('-U<'!O<G0@
M8&`M+7=I=&@M9V1@8`H*("`@("`@2&]R9&4@=VEL;"!U<V4@=&AE($=$(&5X
M=&5N<VEO;B!T;R!P97)F;W)M(&UA;FEP=6QA=&EO;G,@;VX@:6UA9V4@9&%T
M80H@("`@("!T:')O=6=H('1H92!(;W)D95]);6%G92!L:6)R87)Y+@H*("`@
M("`@268@>6]U('=A;G0@1T0@=&\@8F4@86)L92!T;R!W;W)K('=I=&@@4$Y'
M(&EM86=E<RP@>6]U('-H;W5L9"!U<V4@=&AE"B`@("`@(&!@+2UW:71H+7!N
M9RUD:7)@8"!O<'1I;VX@=&\@;6%K92!S=7)E(%!(4"!C86X@9FEN9"!T:&4@
M4$Y'(&QI8G)A<FEE<PH@("`@("!I="!N965D<R!T;R!C;VUP:6QE+@H*("`@
M("`@268@>6]U('=A;G0@1T0@=&\@8F4@86)L92!T;R!W;W)K('=I=&@@2E!%
M1R!I;6%G97,L('EO=2!S:&]U;&0@=7-E('1H90H@("`@("!@8"TM=VET:"UJ
M<&5G+61I<F!@(&]P=&EO;B!T;R!M86ME('-U<F4@4$A0(&-A;B!F:6YD('1H
M92!*4$5'(&QI8G)A<FEE<PH@("`@("!I="!N965D<R!T;R!C;VUP:6QE+@H*
M("`@("`@66]U(&-A;B!A;'-O('5S92!T:&4@26UA9V5-86=I8VM?('!A8VMA
M9V4@=&\@9&\@=&AE<V4@;6%N:7!U;&%T:6]N<PH@("`@("!I;G-T96%D+B`@
M4V5E('1H92!@8$EM86=E($UA;FEP=6QA=&EO;F!@('1A8B!O9B!T:&4@2&]R
M9&4@<V5T=7`@9F]R(&UO<F4*("`@("`@9&5T86EL<RX*"B`@("`@("XN(%])
M;6%G94UA9VEC:SH@:'1T<#HO+W=W=RYI;6%G96UA9VEC:RYO<F<*"B`@(&4N
M($U)344@36%G:6,@<W5P<&]R="!@8"TM=VET:"UM:6UE+6UA9VEC8&`*"B`@
M("`@($AO<F1E('=I;&P@=7-E('1H92!-24U%($UA9VEC(&5X=&5N<VEO;B!T
M;R!G=65S<R!T:&4@34E-12!T>7!E(&]F(&9I;&5S"B`@("`@(&)Y(&%N86QY
M>FEN9R!T:&5I<B!C;VYT96YT<RX*"B`@("`@("XN($YO=&4Z.B!4:&ES(&5X
M=&5N<VEO;B!I<R!R97!O<G1E9"!T;R!B92!D97!R96-A=&5D7R!I;B!F879O
M<B!O9B!T:&4*("`@("`@("`@("`@("`@(&9I;&5I;F9O(%!%0TP@97AT96YS
M:6]N("AS964@8F5L;W<I+B`@2&]W979E<BP@<V]M92!U<V5R<R!H879E"B`@
M("`@("`@("`@("`@("!R97!O<G1E9"!T:&%T('1H92!F:6QE:6YF;R!E>'1E
M;G-I;VX@=VEL;"!N;W0@8G5I;&0@8V]R<F5C=&QY"B`@("`@("`@("`@("`@
M("!O;B!T:&5I<B!S>7-T96TN($EF('-O+"!T:&5N('1H92!-24U%($UA9VEC
M(&5X=&5N<VEO;B!S:&]U;&0*("`@("`@("`@("`@("`@(&)E('5S960@:6YS
M=&5A9"X@4&EC:R!O;F4@;W(@=&AE(&]T:&5R("T@=&AE<F4@:7,@;F\@;F5E
M9"!T;PH@("`@("`@("`@("`@("`@8V]M<&EL92!B;W1H+@H*("`@("`@268@
M=7-I;F<@4$A0(#0N,RXP("T^(#0N,RXQ+"!Y;W4@<VAO=6QD('5S92!@8"TM
M96YA8FQE+6UI;64M;6%G:6-@8`H@("`@("!I;G-T96%D(&]F(&!@+2UW:71H
M+6UI;64M;6%G:6-@8"X*"B`@("`@("XN(%]D97!R96-A=&5D.B!H='1P.B\O
M=W=W+G!H<"YN970O;6EM95]M86=I8PH*("`@+BX@26UP;W)T86YT.CH@061D
M:71I;VYA;&QY+"!I;F1I=FED=6%L($AO<F1E(&%P<&QI8V%T:6]N<R!M87D@
M*BI215%525)%*BH*("`@("`@("`@("`@("`@("`@;W(@*BI214-/34U%3D0J
M*B!O=&AE<B!O<'1I;VYS('1O(&)E(&)U:6QT(&EN=&\@4$A0"B`@("`@("`@
M("`@("`@("`@(&%L<V\N(%!L96%S92!C:&5C:R!@8&1O8W,O24Y35$%,3&!@
M(&9O<B!A;&P@87!P;&EC871I;VYS('EO=0H@("`@("`@("`@("`@("`@("!W
M:7-H('1O('5S92!T;R!S964@:68@;W1H97(@4$A0(&]P=&EO;G,@87)E(&YE
M961E9"X*"C,N($%D9&ET:6]N86P@4$5!4B!-;V1U;&5S"@H@("!014%2(&ES
M('-H;W)T(&9O<B`B4$A0($5X=&5N<VEO;B!A;F0@07!P;&EC871I;VX@4F5P
M;W-I=&]R>2(N("!4:&4@9V]A;"!O9@H@("!014%2(&ES('1O('!R;W9I9&4@
M82!M96%N<R!O9B!D:7-T<FEB=71I;F<@<F5U<V%B;&4@8V]D92X*"B`@($9O
M<B!M;W)E(&EN9F]R;6%T:6]N+"!S964@:'1T<#HO+W!E87(N<&AP+FYE="\*
M"B`@("XN($EM<&]R=&%N=#HZ($UA:V4@<W5R92!Y;W4@87)E(')U;FYI;F<@
M82!S=7!P;W)T960@*&DN92X@;F5W(&5N;W5G:"D*("`@("`@("`@("`@("`@
M("`@=F5R<VEO;B!O9B!014%2.B!U<V4@=&AE('1E<W0@<V-R:7!T(&1E<V-R
M:6)E9"!B96QO=R!U;F1E<@H@("`@("`@("`@("`@("`@("`B8$-O;F9I9W5R
M:6YG($AO<F1E8%\B+B`@1&\@*BIN;W0J*B!U<V4@=&AE(%!%05(@=F5R<VEO
M;@H@("`@("`@("`@("`@("`@("!F<F]M(&9T<"YH;W)D92YO<F<N"@H@("!#
M:&5C:R!T:&%T('1H92!P871H('=H97)E('1H92!014%2('!A8VMA9V5S(&%R
M92!I;G-T86QL960@87)E('!A<G0@;V8@=&AE"B`@(&!@:6YC;'5D95]P871H
M8&`@<&%R86UE=&5R('1H870@4$A0('5S97,@=&\@9FEN9"!014%2('!A8VMA
M9V5S+@H*("`@4G5N('1H92!C;VUM86YD.CH*"B`@("`@<&5A<B!C;VYF:6<M
M<VAO=PH*("`@66]U('=I;&P@<V5E('-O;65T:&EN9R!L:6ME.CH*"B`@("`@
M4$5!4B!D:7)E8W1O<GD@("`@("`@("`@("`@("`@('!H<%]D:7(@("`@("`@
M("`O=7-R+W-H87)E+W!H<`H*("`@3F]W(&]P96X@=&AE('!H<"YI;FD@9FEL
M92!O9B!Y;W5R('-Y<W1E;2P@9F]R(&5X86UP;&4@8&`O971C+W!H<"YI;FE@
M8"P*("`@9FEN9"!T:&4@8&!I;F-L=61E7W!A=&A@8"!A;F0@;6%K92!S=7)E
M('1H870@8&`O=7-R+W-H87)E+W!H<&!@(&ES('!A<G0@;V8*("`@=&AE(&QI
M<W0N("!)9B!Y;W4@:&%D('1O(&-H86YG92!T:&%T('9A;'5E+"!R97-T87)T
M('1H92!W96(@<V5R=F5R(&%F=&5R"B`@('-A=FEN9R!@8'!H<"YI;FE@8"X*
M"B`@(%1H97-E(%!%05(@;6]D=6QE<R!A<F4@*BI215%525)%1"HJ('1O(&)E
M(&EN<W1A;&QE9"!F;W(@8V]M<&QE=&4@2&]R9&4*("`@9G5N8W1I;VYA;&ET
M>3H*"B`@(&$N($QO9PH@("!B+B!-86EL"B`@(&,N($UA:6Q?36EM90H*("`@
M("`@5&\@:6YS=&%L;"P@96YT97(@=&AE(&9O;&QO=VEN9R!A="!T:&4@8V]M
M;6%N9"!P<F]M<'0Z.@H*("`@("`@("!P96%R(&EN<W1A;&P@3&]G($UA:6P@
M36%I;%]-:6UE"@H@("!4:&5S92!014%2(&UO9'5L97,@87)E("HJ4D5#3TU-
M14Y$140J*B!T;R!B92!I;G-T86QL960Z"@H@("!A+B!$0B`H/CT@,2XV+C`I
M"@H@("`@("`J*E)%455)4D5$*BH@87,@<V]O;B!A<R!Y;W4@=V%N="!O<B!N
M965D('1O('-T;W)E(&%N>71H:6YG(&EN(&$@9&%T86)A<V4N"B`@("`@(%1O
M(&EN<W1A;&PL(&5N=&5R('1H92!F;VQL;W=I;F<@870@=&AE(&-O;6UA;F0@
M<')O;7!T.CH*"B`@("`@("`@<&5A<B!I;G-T86QL($1""@H@("`@("!4;R!U
M<&=R861E+"!E;G1E<B!T:&4@9F]L;&]W:6YG(&%T('1H92!C;VUM86YD('!R
M;VUP=#HZ"@H@("`@("`@('!E87(@=7!G<F%D92!$0@H*("`@8BX@1FEL90H*
M("`@("`@*BI215%525)%1"HJ(&]N;'D@:68@>6]U('=I<V@@=&\@:6UP;W)T
M($-35B!F:6QE<RX*("`@("`@5&\@:6YS=&%L;"P@96YT97(@=&AE(&9O;&QO
M=VEN9R!A="!T:&4@8V]M;6%N9"!P<F]M<'0Z.@H*("`@("`@("!P96%R(&EN
M<W1A;&P@1FEL90H*("`@8RX@1&%T90H*("`@("`@*BI215%525)%1"HJ(&]N
M;'D@:68@>6]U(&%R92!D96%L:6YG('=I=&@@8V%L96YD87(@9&%T82X*("`@
M("`@5&\@:6YS=&%L;"P@96YT97(@=&AE(&9O;&QO=VEN9R!A="!T:&4@8V]M
M;6%N9"!P<F]M<'0Z.@H*("`@("`@("!P96%R(&EN<W1A;&P@1&%T90H*("`@
M9"X@4V5R=FEC97-?5V5A=&AE<B`H/CT@,2XS+C$I"@H@("`@("`J*E)%455)
M4D5$*BH@;VYL>2!I9B!Y;W4@=VES:"!T;R!U<V4@=&AE('=E871H97(N8V]M
M(&)L;V-K(&]N"B`@("`@('1H92!P;W)T86P@<&%G92X*("`@("`@5&\@:6YS
M=&%L;"P@96YT97(@=&AE(&9O;&QO=VEN9R!A="!T:&4@8V]M;6%N9"!P<F]M
M<'0Z.@H*("`@("`@("!P96%R("UD('!R969E<G)E9%]S=&%T93UB971A(&EN
M<W1A;&P@+6$@4V5R=FEC97-?5V5A=&AE<@H*("`@("`@061D:71I;VYA;"!S
M=&5P<R!A<F4@<F5Q=6ER960@:68@>6]U('=A;G0@=7-E('1H92!-151!4B!W
M96%T:&5R(&)L;V-K(&]N"B`@("`@('1H92!P;W)T86P@<&%G92X@4V5E('1H
M92!F:6QE(&!@9&%T82]397)V:6-E<U]796%T:&5R+V)U:6QD365T87)$0BYP
M:'!@8`H@("`@("!I;B!Y;W5R(%!%05(@9&ER96-T;W)Y(&9O<B!D971A:6QS
M+@H*("`@5&AI<R!M971H;V0@;V8@:6YS=&%L;&EN9R!014%2(&UO9'5L97,@
M<F5Q=6ER97,@=&AA="!Y;W4@:&%V92!A(%!(4"!V97)S:6]N"B`@('1H870@
M:&%S(&)E96X@8V]M<&EL960@87,@82!S=&%T:6,@8FEN87)Y+B`@06QL('9E
M<G-I;VYS(&]F(%!(4"`T+C,N,"L*("`@8G5I;&0@8F]T:"!A(%-!4$D@;6]D
M=6QE("A!<&%C:&4L($-'22P@971C+BD@86YD(&$@8V]M;6%N9"UL:6YE("A#
M3$DI"B`@(&)I;F%R>2!A="!T:&4@<V%M92!T:6UE+B`@0VAE8VL@:68@>6]U
M(&AA=F4@82!P:'`@8FEN87)Y(&EN"B`@(&!@+W5S<B]L;V-A;"]B:6Y@8"`H
M8&`O=7-R+V)I;F!@(&EF(&EF('EO=2!I;G-T86QL960@9G)O;2!A;B!O<&5R
M871I;F<*("`@<WES=&5M('!A8VMA9V4I(&)E9F]R92!R96-O;7!I;&EN9RX*
M"B`@($EF('EO=2!R96-E:79E('1H92!E<G)O<B!@8$-O=6QD(&YO="!R96%D
M(&-M9"!A<F=S8&`@>6]U('-H;W5L9"!R=6X@=&AE('!E87(*("`@<V-R:7!T
M('1H:7,@=V%Y.CH*"B`@("`@<&AP("UD(')E9VES=&5R7V%R9V-?87)G=CTQ
M(%]014%27R!I;G-T86QL(%]-3T153$5?"@H@("!?4$5!4E\@:7,@=&AE(&-O
M;7!L971E('!A=&@@;V8@=&AE('!E87(@<V-R:7!T(&EN<W1A;&QE9"!B>2!0
M2%`@9'5R:6YG"B`@(&EN<W1A;&QA=&EO;B`H92YG+B!@8"]U<W(O;&]C86PO
M8FEN+W!E87)@8"DN("!-86ME('-U<F4@=&AE(&!@<&5A<F!@('-C<FEP=`H@
M("!A<'!E87)S(&EN('EO=7(@<&%T:"X@5&AE(&1E9F%U;'0@:6YS=&%L;&%T
M:6]N('!A=&@@9F]R('!E87(@:7,*("`@8&`O=7-R+VQO8V%L+V)I;B]P96%R
M8&`N"@H@("!?34]$54Q%7R!I<R!T:&4@4$5!4B!M;V1U;&4L(&QI<W1E9"!A
M8F]V92P@=VAI8V@@>6]U('=I<V@@=&\@:6YS=&%L;"X*"B`@($9O<B!M;W)E
M(&1E=&%I;&5D(&1I<F5C=&EO;G,@;VX@:6YS=&%L;&EN9R!014%2(&UO9'5L
M97,L('-E92!T:&4@4$5!4@H@("!D;V-U;65N=&%T:6]N(&%T(&AT='`Z+R]P
M96%R+G!H<"YN970O;6%N=6%L+PH*-"X@061D:71I;VYA;"!014-,($UO9'5L
M97,*"B`@(%!%0TP@:7,@<VAO<G0@9F]R(")02%`@17AT96YS:6]N($-O;6UU
M;FET>2!,:6)R87)Y(BX@(%1H92!G;V%L(&]F(%!%0TP@:7,*("`@=&\@<')O
M=FED92!A(&UE86YS(&]F(&5A<VEL>2!D:7-T<FEB=71I;F<@4$A0(&5X=&5N
M<VEO;G,N"@H@("!&;W(@;6]R92!I;F9O<FUA=&EO;BP@<V5E(&AT='`Z+R]P
M96-L+G!H<"YN970O"@H@("!014-,(&ES('1H92`B<VES=&5R(B!O9B!014%2
M(&%N9"!U<V5S('1H92!S86UE('!A8VMA9VEN9R!A;F0@9&ES=')I8G5T:6]N
M"B`@('-Y<W1E;2!A<R!014%2+"!S;R!T:&4@8V]N9FEG=7)A=&EO;B]S971U
M<"!I<R!E<W-E;G1I86QL>2!I9&5N=&EC86P@=&\@=&AE"B`@(%!%05(@:6YS
M=')U8W1I;VYS(&%B;W9E+@H*("`@5VAE;B!Y;W4@:6YS=&%L;"!A(%!%0TP@
M97AT96YS:6]N+"!Y;W4@:&%V92!T;R!A9&0@:70@=&\@>6]U<B!@8'!H<"YI
M;FE@8`H@("!S;R!I="!G971S(&QO861E9"X@($%D9"!T:&4@9F]L;&]W:6YG
M(&QI;F4@=&\@>6]U<B!@8'!H<"YI;FE@8"!F:6QE('1O(&QO860*("`@=&AE
M(&5X=&5N<VEO;B`H=&AE(&5X=&5N<VEO;B!S:&]U;&0@8F4@:6YS=&%L;&5D
M(&EN('1H92!D:7)E8W1O<GD@<W!E8VEF:65D"B`@(&)Y('1H92!@8&5X=&5N
M<VEO;E]D:7)@8"!O<'1I;VX@:6X@8&!P:'`N:6YI8&`I.CH*"B`@("`@97AT
M96YS:6]N/69I;&5I;F9O+G-O"@H@("!/<B!O;B!7:6YD;W=S.CH*"B`@("`@
M97AT96YS:6]N/69I;&5I;F9O+F1L;`H*("`@069T97(@=&AA="P@<F5S=&%R
M="!Y;W5R('=E8G-E<G9E<BX*"B`@(%1H97-E(%!%0TP@;6]D=6QE<R!A<F4@
M*BI214-/34U%3D1%1"HJ('1O(&)E(&EN<W1A;&QE9#H*"B`@(&$N(&9I;&5I
M;F9O"@H@("`@("!!;&QO=W,@2&]R9&4@;6]D=6QE<R!T;R!G=65S<R!T:&4@
M34E-12!T>7!E(&]F(&9I;&5S(&)Y(&%N86QY>FEN9PH@("`@("!T:&5I<B!C
M;VYT96YT<RX*"B`@("`@($EF(&YO="!E;F%B;&5D+"!(;W)D92!W:6QL('5S
M92!I=',@;W=N(%!(4"!C;V1E('1O('!E<F9O<FT@34E-12!M86=I8PH@("`@
M("!L;V]K=7!S+B`@2&]W979E<BP@=&AI<R!L;V]K=7`@:7,@<VQO=V5R+"!L
M97-S(&%C8W5R871E+"!A;F0@9&5T96-T<PH@("`@("!F97=E<B!-24U%('1Y
M<&5S('1H86X@=&AE(%!%0TP@97AT96YS:6]N('=I;&PN"@H@("`@("!4;R!I
M;G-T86QL+"!E;G1E<B!T:&4@9F]L;&]W:6YG(&%T('1H92!C;VUM86YD('!R
M;VUP=#HZ"@H@("`@("`@('!E87(@:6YS=&%L;"!F:6QE:6YF;PH*("`@5&AE
M<V4@4$5#3"!M;V1U;&5S(&%R92`J*E)%0T]-345.1$5$*BH@=&\@8F4@:6YS
M=&%L;&5D(&EF('EO=2!N965D"B`@(&%D=F%N8V5D(&9U;F-T:6]N86QI='DZ
M"@H@("!A+B!M96UC86-H90H*("`@("`@268@=7-I;F<@=&AE(&UE;6-A8VAE
M9"!397-S:6]N2&%N9&QE<BP@=&AE(&UE;6-A8VAE(%!%0TP@97AT96YS:6]N
M(&UU<W0*("`@("`@8F4@:6YS=&%L;&5D+@H*("`@("`@5&\@:6YS=&%L;"P@
M96YT97(@=&AE(&9O;&QO=VEN9R!A="!T:&4@8V]M;6%N9"!P<F]M<'0Z.@H*
M("`@("`@("!P96%R(&EN<W1A;&P@;65M8V%C:&4*"B`@($9O<B!A9&1I=&EO
M;F%L(&AE;'`@;VX@=7-I;F<@=&AE('!E87(@8V]M;6%N9"UL:6YE('!R;V=R
M86T@=&\@:6YS=&%L;"!014-,"B`@(&5X=&5N<VEO;G,L('-E92!T:&4@4$5!
M4B!I;G-T86QL871I;VX@<V5C=&EO;B!A8F]V92X*"@I4:&4@9F]L;&]W:6YG
M(&YO;BU02%`@<')E<F5Q=6ES:71E<R!A<F4@*BI214-/34U%3D1%1"HJ+"!O
M<B!A<F4@*BI215%525)%1"HJ"FEF('EO=2!U<V4@82!S<&5C:69I8R!(;W)D
M92!A<'!L:6-A=&EO;B`H87,@;F]T960@:6X@6V)R86-K971S72DZ"@HQ+B!3
M96YD;6%I;"!O<B!E<75I=F%L96YT+@H*("`@2&]R9&4@=7-E<R!S96YD;6%I
M;"P@;W(@82!P<F]G<F%M('1H870@:6UP;&5M96YT<R!T:&4@8&!S96YD;6%I
M;"@X*6!@($%020H@("`H87,@:6YC;'5D960@=VET:"!P;W-T9FEX+"!Q;6%I
M;"P@86YD(&5X:6TL(&%M;VYG(&]T:&5R<RDN($EF('EO=7(@<WES=&5M"B`@
M(&1O97,@;F]T(&%L<F5A9'D@:&%V92!A(&9U;&P@;6%I;"!T<F%N<W!O<G0@
M=VET:"!A('-E;F1M86EL(&EN=&5R9F%C92P@>6]U"B`@(&-A;B!C;VYF:6=U
M<F4@2&]R9&4@=&\@<W!E86L@9&ER96-T;'D@=VET:"!A(')E;6]T92!33510
M('-E<G9E<BP@8G5T('1H:7,*("`@;6%Y(&EN8W5R(&$@<&5R9F]R;6%N8V4@
M<&5N86QT>2X*"@I);G-T86QL:6YG($AO<F1E"CT]/3T]/3T]/3T]/3T]/3T*
M"DAO<F1E(&ES('=R:71T96X@:6X@4$A0+"!A;F0@;75S="!B92!I;G-T86QL
M960@:6X@82!W96(M86-C97-S:6)L92!D:7)E8W1O<GDN"E1H92!P<F5C:7-E
M(&QO8V%T:6]N(&]F('1H:7,@9&ER96-T;W)Y('=I;&P@9&EF9F5R(&9R;VT@
M<WES=&5M('1O('-Y<W1E;2X@268*>6]U(&AA=F4@;F\@:61E82!W:&5R92!Y
M;W4@<VAO=6QD(&)E(&EN<W1A;&QI;F<@2&]R9&4L(&EN<W1A;&P@:70@9&ER
M96-T;'D*=6YD97(@=&AE(')O;W0@;V8@>6]U<B!W96)S97)V97(G<R!D;V-U
M;65N="!T<F5E+@H*"DEN<W1A;&QI;F<@9G)O;2!296QE87-E(%1A<F)A;&QS
M"GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^"@I3:6YC92!(;W)D
M92!I<R!W<FET=&5N(&EN(%!(4"P@=&AE<F4@:7,@;F\@8V]M<&EL871I;VX@
M;F5C97-S87)Y.R!S:6UP;'D*97AP86YD('1H92!D:7-T<FEB=71I;VX@=VAE
M<F4@>6]U('=A;G0@:70@=&\@<F5S:61E(&%N9"!R96YA;64@=&AE(')O;W0*
M9&ER96-T;W)Y(&]F('1H92!D:7-T<FEB=71I;VX@=&\@=VAA=&5V97(@>6]U
M('=I<V@@=&\@87!P96%R(&EN('1H90I54DPN(%!L96%S92!N;W1E('1H870@
M=&AE(&1E9F%U;'0@8V]N9FEG=7)A=&EO;B!E>'!E8W1S($AO<F1E('1O(&)E
M(&EN<W1A;&QE9`II;B!T:&4@9&ER96-T;W)Y(&!@+VAO<F1E8&`@=&AO=6=H
M+B!&;W(@97AA;7!L92P@=VET:"!T:&4@07!A8VAE('=E8G-E<G9E<B=S"F1E
M9F%U;'0@9&]C=6UE;G0@<F]O="!O9B!@8"]U<W(O;&]C86PO87!A8VAE+VAT
M9&]C<V!@+"!Y;W4@=V]U;&0@='EP93HZ"@H@("!C9"`O=7-R+VQO8V%L+V%P
M86-H92]H=&1O8W,*("`@=&%R('IX=F8@+W!A=&@O=&\O:&]R9&4M>"YY+GHN
M=&%R+F=Z"B`@(&UV(&AO<F1E+7@N>2YZ(&AO<F1E"@I9;W4@=V]U;&0@=&AE
M;B!F:6YD($AO<F1E(&%T('1H92!54DPZ.@H*("`@:'1T<#HO+WEO=7(M<V5R
M=F5R+VAO<F1E+PH*4VMI<"!T:&4@;F5X="!P87)A9W)A<&@@:68@>6]U(&EN
M<W1A;&QE9"!(;W)D92!F<F]M(&$@<F5L96%S92!T87)B86QL+@H*"DEN<W1A
M;&QI;F<@9G)O;2!#5E,@;W(@4VYA<&AO=',*?GY^?GY^?GY^?GY^?GY^?GY^
M?GY^?GY^?GY^?GY^?@H*070@=&AI<R!P;VEN="P@=&AE($AO<F1E(&9R86UE
M=V]R:R!M;V1U;&5S(&YE960@=&\@8F4@8VAE8VME9"!O=70@9G)O;2!#5E,@
M86YD"FEN<W1A;&QE9"X@5&AI<R!M=7-T(&)E(&1O;F4@87,@<F]O="`H;W(@
M86YO=&AE<B!U<V5R('=I=&@@<W5F9FEC:65N=`IA9&UI;FES=')A=&]R('!R
M:79I;&5D9V5S*3HZ"@H@("!C9"!H;W)D90H@("!C=G,@8V\@9G)A;65W;W)K
M"B`@(&-D(&9R86UE=V]R:PH@("!P:'`@+7$@:6YS=&%L;"UP86-K86=E<RYP
M:'`*"D9O<B!7:6YD;W=S('-Y<W1E;7,@+2!U<V4@=&AE(&!@:6YS=&%L;"UP
M86-K86=E<RYB871@8"!F:6QE(&EN<W1E860N"D9O<B!$96)I86X@<WES=&5M
M<R`M('1H92!C;VUM86YD+6QI;F4@4$A0(&EN=&5R<')E=&5R(&UI9VAT(&)E
M(&-A;&QE9"!@8'!H<#1@8`II;G-T96%D(&]F(&!@<&AP8&`N"@H*0V]N9FEG
M=7)I;F<@2&]R9&4*/3T]/3T]/3T]/3T]/3T]/3T*"C$N($-O;F9I9W5R:6YG
M('1H92!W96(@<V5R=F5R"@H@("!(;W)D92!R97%U:7)E<R!T:&4@9F]L;&]W
M:6YG('=E8G-E<G9E<B!S971T:6YG<RX@17AA;7!L97,@<VAO=VX@87)E(&9O
M<@H@("!!<&%C:&4[(&]T:&5R('=E8G-E<G9E<G,G(&-O;F9I9W5R871I;VYS
M('=I;&P@9&EF9F5R+@H*("`@82X@4$A0(&EN=&5R<')E=&%T:6]N(&9O<B!F
M:6QE<R!M871C:&EN9R!@8"HN<&AP8&`Z.@H*("`@("`@("`@061D5'EP92!A
M<'!L:6-A=&EO;B]X+6AT='!D+7!H<"`N<&AP"@H@("`@("`N+B!.;W1E.CH@
M5&AE(&%B;W9E(&EN<W1R=6-T:6]N<R!M87D@;F]T('=O<FL@:68@>6]U(&AA
M=F4@<W!E8VEF:65D(%!(4`H@("`@("`@("`@("`@("`@87,@86X@;W5T<'5T
M(&9I;'1E<B!W:71H(&!@4V5T3W5T<'5T1FEL=&5R8&`@9&ER96-T:79E(&EN
M"B`@("`@("`@("`@("`@("!!<&%C:&4@,BYX('9E<G-I;VYS+B`@26X@<&%R
M=&EC=6QA<BP@4F5D($AA="`X+C`@86YD(&%B;W9E"B`@("`@("`@("`@("`@
M("!!<&%C:&4@,BYX(%)035,@:&%V92!T:&4@;W5T<'5T(&9I;'1E<B!S970L
M(&%N9"`J*DU54U0@3D]4*BH*("`@("`@("`@("`@("`@(&AA=F4@=&AE(&%B
M;W9E(&!@061D5'EP96!@(&1I<F5C=&EV92!A9&1E9"X*"B`@(&(N(&!@:6YD
M97@N<&AP8&`@87,@86X@:6YD97@@9FEL92`H8G)O=6=H="!U<"!W:&5N(&$@
M=7-E<B!R97%U97-T<R!A(%523"!F;W(*("`@("`@82!D:7)E8W1O<GDI.CH*
M"B`@("`@("`@($1I<F5C=&]R>4EN9&5X(&EN9&5X+G!H<`H*,BX@0W)E871I
M;F<@9&%T86)A<V5S"@H@("!4:&4@<W!E8VEF:6,@<W1E<',@=&\@8W)E871E
M(&$@<')E9F5R96YC97,@<W1O<F%G92!C;VYT86EN97(@9&5P96YD(&]N"B`@
M('=H:6-H(&1A=&%B87-E('EO=2=V92!C:&]S96X@=&\@=7-E+@H*("`@1FER
M<W0L(&QO;VL@:6X@8&!S8W)I<'1S+W-Q;"]@8"!T;R!S964@:68@82!@8&-R
M96%T92Y@8"!S8W)I<'0@86QR96%D>0H@("!E>&ES=',@9F]R('EO=7(@9&%T
M86)A<V4N("!)9B!S;RP@>6]U('-H;W5L9"!B92!A8FQE('1O('-I;7!L>2!E
M>&5C=71E('1H870*("`@<V-R:7!T(&%S('-U<&5R=7-E<B!I;B!Y;W5R(&1A
M=&%B87-E+B`@0V]N<W5L="!T:&4@8&!S8W)I<'1S+W-Q;"]214%$345@8`H@
M("!F:6QE(&9O<B!M;W)E(&EN9F]R;6%T:6]N+@H*("`@0F4@<W5R92!T;R!C
M:&%N9V4@=&AE(&1E9F%U;'0@<&%S<W=O<F0L(&!@:&]R9&5@8"P@=&\@<V]M
M971H:6YG(&5L<V4@8F5F;W)E"B`@(&-R96%T:6YG('1H92!T86)L97,A("A2
M96UE;6)E<B!T;R!U<V4@=&AI<R!P87-S=V]R9"!W:&5N('EO=2!C;VYF:6=U
M<F4*("`@2&]R9&4@:6X@=&AE(&YE>'0@<W1E<"XI"@H@("!)9B!S=6-H(&$@
M<V-R:7!T(&1O97,@;F]T(&5X:7-T+"!Y;W4G;&P@;F5E9"!T;R!B=6EL9"!Y
M;W5R(&]W;BP@=7-I;F<@=&AE"B`@(&9I;&5S(&!@:&]R9&5?=7-E<G,N<W%L
M8&`L(&!@:&]R9&5?<')E9G,N<W%L8&`L(&%N9"!@8&AO<F1E7V1A=&%T<F5E
M+G-Q;&!@"B`@(&%S(&$@<W1A<G1I;F<@<&]I;G0N("!)9B!Y;W4@;F5E9"!A
M<W-I<W1A;F-E(&EN(&-R96%T:6YG(&1A=&%B87-E<R!F;W(@80H@("!D871A
M8F%S92!F;W(@=VAI8V@@;F\@8&!C<F5A=&4N8&`@<V-R:7!T(&5X:7-T<RP@
M>6]U(&UA>2!W:7-H('1O(&QE="!U<PH@("!K;F]W(&]N('1H92!@2&]R9&4@
M;6%I;&EN9R!L:7-T8%\N"@H@("!)9B!Y;W4@87)E(&=O:6YG('1O('5S92!D
M871A8F%S92!B87-E9"!S97-S:6]N<RP@8W)E871E(&$@=&%B;&4@=7-I;F<@
M=&AE"B`@(&9I;&5S(&!@<V-R:7!T<R]S<6PO:&]R9&5?<V5S<VEO;FAA;F1L
M97(J+G-Q;&!@(&%S(&$@<W1A<G1I;F<@<&]I;G0N"@H@("`N+B!?8$AO<F1E
M(&UA:6QI;F<@;&ES=&`Z(&AO<F1E0&QI<W1S+FAO<F1E+F]R9PH*,RX@0V]N
M9FEG=7)I;F<@2&]R9&4*"B`@(%1O(&-O;F9I9W5R92!(;W)D92P@8VAA;F=E
M('1O('1H92!@8&-O;F9I9R]@8"!D:7)E8W1O<GD@;V8@=&AE(&EN<W1A;&QE
M9`H@("!D:7-T<FEB=71I;VXL(&%N9"!M86ME(&-O<&EE<R!O9B!A;&P@;V8@
M=&AE(&-O;F9I9W5R871I;VX@8&`N9&ES=&!@(&9I;&5S"B`@('=I=&AO=70@
M=&AE(&!@+F1I<W1@8"!S=69F:7@Z.@H*("`@("`@8V0@8V]N9FEG+PH@("`@
M("!F;W(@9B!I;B`J+F1I<W0[(&1O(&-P("1F(&!B87-E;F%M92`D9B`N9&ES
M=&`[(&1O;F4*"B`@($]R(&EF('EO=2!A<F4@:6YS=&%L;&EN9R!(;W)D92!A
M;B!A(%=I;F1O=W,@<WES=&5M.CH*"B`@("`@(&-D(&-O;F9I9PH@("`@("!C
M;W!Y("HN9&ES="`J+@H*("`@+BX@3F]T93HZ(%EO=2!O;FQY(&YE960@=&AE
M(&!@:&]O:W,N<&AP8&`@9FEL92!I9B!Y;W4@=V%N="!T;R!C<F5A=&4@8W5S
M=&]M"B`@("`@("`@("`@("!H;V]K<R!F;W(@<V]M92!O9B!(;W)D92=S(&9E
M871U<F5S(&%N9"!D969A=6QT('9A;'5E<RX@0F5S:61E"B`@("`@("`@("`@
M("!T:&%T+"!T:&ES(&9I;&4@;VYL>2!C;VYT86EN<R!E>&%M<&QE<R!T:&%T
M('EO=2!S:&]U;&0@;F]T('5S92!A<PH@("`@("`@("`@("`@=&AE>2!A<F4N
M($EF('EO=2!D;VXG="!N965D(&AO;VMS(&ET)W,@82!G;V]D(&ED96$@=&\@
M<F5M;W9E('1H:7,*("`@("`@("`@("`@(&9I;&4@;F]W.CH*"B`@("`@("`@
M("`@("`@("`@("!R;2!H;V]K<RYP:'`*"B`@($1O8W5M96YT871I;VX@;VX@
M=&AE(&9O<FUA="!O9B!T:&]S92!F:6QE<R!C86X@8F4@9F]U;F0@:6X@96%C
M:"!F:6QE+@H*("`@+BX@5V%R;FEN9SHZ($%L;"!C;VYF:6=U<F%T:6]N(&9I
M;&5S(&EN($AO<F1E(&%R92!02%`@<V-R:7!T<R!T:&%T(&%R90H@("`@("`@
M("`@("`@("`@97AE8W5T960@8GD@=&AE('=E8B!S97)V97(N($EF('EO=2!M
M86ME(&%N(&5R<F]R(&EN(&]N92!O9@H@("`@("`@("`@("`@("`@=&AE<V4@
M9FEL97,L($AO<F1E(&UI9VAT('-T;W`@=V]R:VEN9RX@5&AU<R!I="!I<R!A
M;'=A>7,@80H@("`@("`@("`@("`@("`@9V]O9"!I9&5A('1O('1E<W0@=&AE
M(&-O;F9I9W5R871I;VX@9FEL97,@869T97(@>6]U(&5D:71E9`H@("`@("`@
M("`@("`@("`@=&AE;2X@268@>6]U('=A;G0@=&\@=&5S="!M:6UE7V1R:79E
M<G,N<&AP(&9O<B!E>&%M<&QE(')U;CHZ"@H@("`@("`@("`@("`@("`@("`@
M<&AP("UL(&UI;65?9')I=F5R<RYP:'`*"C0N(%1E<W1I;F<@2&]R9&4*"B`@
M($]N8V4@>6]U(&AA=F4@8V]N9FEG=7)E9"!Y;W5R('=E8G-E<G9E<BP@4$A0
M+"!A;F0@2&]R9&4L(&)R:6YG('5P('1H90H@("!I;F-L=61E9"!T97-T('!A
M9V4@:6X@>6]U<B!796(@8G)O=W-E<B!T;R!E;G-U<F4@=&AA="!A;&P@;F5C
M97-S87)Y"B`@('!R97)E<75I<VET97,@:&%V92!B965N(&UE="X@268@>6]U
M(&EN<W1A;&QE9"!(;W)D92!A<R!D97-C<FEB960@86)O=F4L('1H90H@("!5
M4DP@=&\@=&AE('1E<W0@<&%G92!W;W5L9"!B93HZ"@H@("`@("!H='1P.B\O
M>6]U<BUS97)V97(O:&]R9&4O=&5S="YP:'`*"B`@($-H96-K('1H870@>6]U
M<B!02%`@86YD(%!%05(@=F5R<VEO;G,@87)E(&%C8V5P=&%B;'D@<F5C96YT
M+"!T:&%T(&%L;`H@("!R97%U:7)E9"!M;V1U;&4@8V%P86)I;&ET:65S(&%R
M92!P<F5S96YT+"!A;F0@=&AA="!@8&UA9VEC7W%U;W1E<U]R=6YT:6UE8&`*
M("`@:7,@<V5T('1O(&!@3V9F8&`N(%1H96X@;F]T92!T:&4@8&!397-S:6]N
M(&-O=6YT97(Z(#%@8"!L:6YE('5N9&5R(&!@4$A0"B`@(%-E<W-I;VYS8&`L
M(&%N9"!R96QO860@=&AE('!A9V4N(%1H92!S97-S:6]N(&-O=6YT97(@<VAO
M=6QD(&EN8W)E;65N="X*"B`@($EF('EO=2!G970@82!W87)N:6YG(&QI:V4@
M8&!&86EL960@;W!E;FEN9R`G+W!A=&@O=&\O=&5S="YP:'`G(&9O<@H@("!I
M;F-L=7-I;VY@8"P@;6%K92!S=7)E('1H870@=&AE('=E8B!S97)V97(@:&%S
M('1H92!P97)M:7-S:6]N('1O(')E860@=&AE"B`@(&!@=&5S="YP:'!@8"!F
M:6QE+@H*-2X@0V]M<&QE=&EN9R!#;VYF:6=U<F%T:6]N"@H@("!9;W4@8V%N
M(&YO=R!A8V-E<W,@2&]R9&4@=VET:&]U="!A('!A<W-W;W)D+"!A;F0@>6]U
M('=I;&P@8F4@;&]G9V5D(&EN(&%S"B`@(&%N(&%D;6EN:7-T<F%T;W(N(%EO
M=2!S:&]U;&0@9FER<W0@8V]N9FEG=7)E(&$@<F5A;"!A=71H96YT:6-A=&EO
M;B!B86-K96YD+@H@("!#;&EC:R!O;B!@8%-E='5P8&`@:6X@=&AE(&!@061M
M:6YI<W1R871I;VY@8"!M96YU(&%N9"!C;VYF:6=U<F4*("`@2&]R9&4N("!3
M=&%R="!I;B!T:&4@8&!!=71H96YT:6-A=&EO;F!@('1A8BX*"B`@($AE<F4@
M:7,@86X@97AA;7!L92!F;W(@8V]N9FEG=7)I;F<@875T:&5N=&EC871I;VX@
M86=A:6YS="!A(')E;6]T92!)34%0"B`@('-E<G9E<BX@(%-I;6EL87(@<W1E
M<',@87!P;'D@9F]R(&%U=&AE;G1I8V%T:6YG(&%G86EN<W0@82!D871A8F%S
M92P@86X@3$1!4`H@("!S97)V97(L(&5T8RX*"B`@(&$N($EN('1H92!@8%=H
M:6-H('5S97)S('-H;W5L9"!B92!T<F5A=&5D(&%S(&%D;6EN:7-T<F%T;W)S
M8&`@9FEE;&0@96YT97(@80H@("`@("!C;VUM82!S97!A<F%T960@;&ES="!O
M9B!U<V5R(&YA;65S(&]F('EO=7(@8VAO;W-I;F<N(%1H:7,@=VEL;"!C;VYT
M<F]L"B`@("`@('=H;R!I<R!A;&QO=V5D('1O(&UA:V4@8V]N9FEG=7)A=&EO
M;B!C:&%N9V5S+"!S964@<&%S<W=O<F1S+"!P;W1E;G1I86QL>0H@("`@("!A
M9&0@=7-E<G,L(&5T8RX*"B`@(&(N($EN('1H92!@8%=H870@8F%C:V5N9"!S
M:&]U;&0@=V4@=7-E(&9O<B!A=71H96YT:6-A=&EN9R!U<V5R<R!T;R!(;W)D
M96!@"B`@("`@('!U;&QD;W=N(&UE;G4@<V5L96-T(&!@24U!4"!A=71H96YT
M:6-A=&EO;F!@+B!4:&4@<&%G92!W:6QL(')E;&]A9"!A;F0*("`@("`@>6]U
M('=I;&P@:&%V92!S<&5C:69I8R!O<'1I;VYS(&9O<B!)34%0(&%U=&AE;G1I
M8V%T:6]N+@H*("`@8RX@26X@=&AE(&!@0V]N9FEG=7)A=&EO;B!T>7!E8&`@
M<'5L;&1O=VX@;65N=2!S96QE8W0@8&!397!A<F%T92!V86QU97-@8"X*("`@
M("`@5&AE('!A9V4@=VEL;"!R96QO860@=VET:"!A9&1I=&EO;F%L(&]P=&EO
M;G,N($9I;&P@:6X@=&AE(')E;6%I;FEN9PH@("`@("!T:')E92!F:65L9',@
M87!P<F]P<FEA=&5L>3H*"B`@("`@("T@25`@;F%M92]N=6UB97(@;V8@=&AE
M($E-05`@<V5R=F5R"B`@("`@("T@1F]R(&$@<V5C=7)E(&-O;FYE8W1I;VXL
M('-E;&5C="!P;W)T(#DY,RX*("`@("`@+2!396QE8W0@=&AE('!R;W1O8V]L
M.R!F;W(@82!S96-U<F4@8V]N;F5C=&EO;B!E:71H97(@8&!I;6%P+W-S;&!@
M(&]R"B`@("`@("`@8&!I;6%P+W-S;"]N;W9A;&ED871E+6-E<G1@8"`H9F]R
M('-E;&8M<VEG;F5D(&-E<G1I9FEC871E<RDN"@H@("!#;VYT:6YU92!T;R!C
M;VYF:6=U<F4@2&]R9&4@=&AR;W5G:"!A;&P@=&AE('1A8G,@;V8@=&AE('-E
M='5P(&EN=&5R9F%C92!A;F0*("`@8VQI8VL@;VX@8&!'96YE<F%T92!(;W)D
M92!#;VYF:6=U<F%T:6]N8&`N($EM<&]R=&%N="!I=&5M<R!T:&%T('EO=0H@
M("!P<F]B86)L>2!W86YT('1O(&-O;F9I9W5R92!A<F4@=&AE(&!@4')E9F5R
M96YC92!3>7-T96U@8"!T:&%T(&QE=',@=7-E<G,*("`@<V%V92!T:&5I<B!P
M97)S;VYA;"!O<'1I;VYS+"!A;F0@=&AE(&!@1&%T851R964@4WES=&5M8&`@
M=&AA="!I<R!R97%U:7)E9`H@("!F;W(@<V]M92!A<'!L:6-A=&EO;G,@=&\@
M=V]R:R!A="!A;&PN"@H@("!#;VYF:6=U<F%T:6]N(&]F(&%P<&QI8V%T:6]N
M<R!I;B!@8')E9VES=')Y+G!H<&!@(&ES(&1O8W5M96YT960@:6X@=&AE"B`@
M(&!@24Y35$%,3&!@(&9I;&4@;V8@96%C:"!A<'!L:6-A=&EO;BX@($UO<W0@
M87!P;&EC871I;VYS(')E<75I<F4@>6]U('1O"B`@(&-O;F9I9W5R92!T:&5M
M('=I=&@@82`B2&]R9&4@861M:6YI<W1R871O<B(@86-C;W5N="X@($$@2&]R
M9&4@861M:6YI<W1R871O<@H@("!A8V-O=6YT(&ES(&%N>2!N;W)M86P@2&]R
M9&4@86-C;W5N="!T:&%T(&AA<R!B965N(&%D9&5D('1O('1H90H@("!A9&UI
M;FES=')A=&]R(&QI<W0@:6X@=&AE(&!@075T:&5N=&EC871I;VY@8"!T86(@
M;V8@=&AE($AO<F1E('-E='5P+@H*("`@5&AE(&]T:&5R(&9I;&5S(&EN('1H
M870@9&ER96-T;W)Y(&YE960@;VYL>2!B92!M;V1I9FEE9"!I9B!Y;W4@=VES
M:"!T;PH@("!C=7-T;VUI>F4@2&]R9&4G<R!A<'!E87)A;F-E(&]R(&)E:&%V
M:6]U<B`M+2!T:&4@9&5F875L=',@=VEL;"!W;W)K(&%T(&UO<W0*("`@<VET
M97,N"@HV+B!396-U<FEN9R!(;W)D90H*("`@82X@4&%S<W=O<F1S"@H@("`@
M("!3;VUE(&]F($AO<F1E)W,@8V]N9FEG=7)A=&EO;B!F:6QE<R!C;VYT86EN
M('!A<W-W;W)D<R!W:&EC:"!L;V-A;"!U<V5R<PH@("`@("!C;W5L9"!U<V4@
M=&\@86-C97-S('EO=7(@9&%T86)A<V4N("!)="!I<R!R96-O;6UE;F1E9"!T
M;R!E;G-U<F4@=&AA="!A=`H@("`@("!L96%S="!T:&4@2&]R9&4@8V]N9FEG
M=7)A=&EO;B!F:6QE<R`H:6X@8&!C;VYF:6<O8&`I(&%R92!N;W0@<F5A9&%B
M;&4@=&\*("`@("`@<WES=&5M('5S97)S+B`@5&AE<F4@87)E(&!@+FAT86-C
M97-S8&`@9FEL97,@<F5S=')I8W1I;F<@86-C97-S('1O"B`@("`@(&1I<F5C
M=&]R:65S('1H870@9&\@;F]T(&YE960@=&\@8F4@86-C97-S960@9&ER96-T
M;'D[(&)E9F]R92!R96QY:6YG(&]N"B`@("`@('1H;W-E+"!E;G-U<F4@=&AA
M="!Y;W5R('=E8G-E<G9E<B!S=7!P;W)T<R!@8"YH=&%C8V5S<V!@(&%N9"!I
M<PH@("`@("!C;VYF:6=U<F5D('1O('5S92!T:&5M+"!A;F0@=&AA="!T:&4@
M9FEL97,@:6X@=&AO<V4@9&ER96-T;W)I97,@87)E(&EN"B`@("`@(&9A8W0@
M:6YA8V-E<W-I8FQE('9I82!T:&4@8G)O=W-E<BX*"B`@("`@($%N(&%D9&ET
M:6]N86P@87!P<F]A8V@@:7,@=&\@;6%K92!(;W)D92=S(&-O;F9I9W5R871I
M;VX@9FEL97,@;W=N960@8GD*("`@("`@=&AE('5S97(@8&!R;V]T8&`@86YD
M(&)Y(&$@9W)O=7`@=VAI8V@@;VYL>2!T:&4@=V5B<V5R=F5R('5S97(@8F5L
M;VYG<PH@("`@("!T;RP@86YD('1H96X@;6%K:6YG('1H96T@<F5A9&%B;&4@
M;VYL>2!T;R!O=VYE<B!A;F0@9W)O=7`N("!&;W(@97AA;7!L92P*("`@("`@
M:68@>6]U<B!W96)S97)V97(@<G5N<R!A<R!@8'=W=RYW=W=@8"P@9&\@87,@
M9F]L;&]W<SHZ"@H@("`@("`@("!C:&]W;B!R;V]T+G=W=R!C;VYF:6<O*@H@
M("`@("`@("!C:&UO9"`P-#0P(&-O;F9I9R\J"@H@("!B+B!397-S:6]N<PH*
M("`@("`@4V5S<VEO;B!D871A("TM(&EN8VQU9&EN9R!H87-H960@=F5R<VEO
M;G,@;V8@>6]U<B!U<V5R<R<@<&%S<W=O<F1S+"!I;@H@("`@("!S;VUE(&%P
M<&QI8V%T:6]N<R`M+2!M87D@;F]T(&)E('-T;W)E9"!A<R!S96-U<F5L>2!A
M<R!N96-E<W-A<GDN"@H@("`@("!)9B!Y;W4@87)E('5S:6YG(&9I;&4M8F%S
M960@4$A0('-E<W-I;VYS("AW:&EC:"!A<F4@=&AE(&1E9F%U;'0I+"!B90H@
M("`@("!S=7)E('1H870@<V5S<VEO;B!F:6QE<R!A<F4@;F]T(&)E:6YG('=R
M:71T96X@:6YT;R!@8"]T;7!@8"!W:71H"B`@("`@('!E<FUI<W-I;VYS('1H
M870@86QL;W<@;W1H97(@=7-E<G,@=&\@<F5A9"!T:&5M+B!)9&5A;&QY+"!C
M:&%N9V4@=&AE"B`@("`@(&!@<V5S<VEO;BYS879E7W!A=&A@8"!S971T:6YG
M(&EN(&!@<&AP+FEN:6!@('1O(&$@9&ER96-T;W)Y(&]N;'D*("`@("`@<F5A
M9&%B;&4@86YD('=R:71E86)L92!B>2!Y;W5R('=E8G-E<G9E<BX*"B`@("`@
M($%D9&ET:6]N86QL>2P@>6]U(&-A;B!C:&%N9V4@=&AE('-E<W-I;VX@:&%N
M9&QE<B!O9B!02%`@=&\@=7-E(&%N>0H@("`@("!S=&]R86=E(&)A8VME;F0@
M<F5Q=65S=&5D("AE+F<N(%-13"!D871A8F%S92D@=FEA('1H92!@8$-U<W1O
M;2!397-S:6]N"B`@("`@($AA;F1L97)@8"!T86(@:6X@=&AE($AO<F1E('-E
M='5P+@H*("`@1F]R(&UO<F4@:6YF;W)M871I;VX@86)O=70@<V5C=7)I;F<@
M>6]U<B!W96)S97)V97(L(%!(4"!A;F0@2&]R9&4L('-E92!T:&4*("`@8&1O
M8W,O4T5#55))5%E@7R!F:6QE+@H*-RX@16YT97)I;F<@=&AE('-U<G9E>0H*
M("`@268@>6]U(&QI:V4L(&=O('1O(&AT='`Z+R]W=W<N:&]R9&4N;W)G+W-U
M<G9E>2\@86YD(&5N=&5R('1H92!D971A:6QS(&]F"B`@('EO=7(@<WES=&5M
M+@H*"D-O;F9I9W5R:6YG($%P<&QI8V%T:6]N<PH]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T*"D$@;&ES="!O9B!A=F%I;&%B;&4@2&]R9&4@87!P;&EC871I
M;VYS(&-A;B!B92!F;W5N9"!A=`H*("`@:'1T<#HO+W=W=RYH;W)D92YO<F<O
M<')O:F5C=',N<&AP"@I);G-T<G5C=&EO;G,@;VX@8V]N9FEG=7)I;F<@2&]R
M9&4@87!P;&EC871I;VYS(&-A;B!B92!F;W5N9"!I;B!T:&4@8&!)3E-404Q,
M8&`*9FEL92!I;B!T:&4@87!P;&EC871I;VXG<R!@8&1O8W,O8&`@9&ER96-T
M;W)Y+@H*"E1E;7!O<F%R>2!&:6QE<PH]/3T]/3T]/3T]/3T]/3T*"E9A<FEO
M=7,@2&]R9&4@87!P;&EC871I;VYS('=I;&P@9V5N97)A=&4@=&5M<&]R87)Y
M(&9I;&5S(&EN(%!(4"=S('1E;7!O<F%R>0ID:7)E8W1O<GD@*'-E92!T:&4@
M8&!'96YE<F%L8&`@=&%B(&EN('1H92!(;W)D92!S971U<"DN("!&;W(@=F%R
M:6]U<R!R96%S;VYS+`IS;VUE(&]F('1H97-E(&9I;&5S(&UA>2!N;W0@8F4@
M<F5M;W9E9"!W:&5N('1H92!U<V5R)W,@<V5S<VEO;B!E;F1S+B!4;PIR96-L
M86EM('1H:7,@9&ES:R!S<&%C92P@:70@;6%Y(&)E(&YE8V5S<V%R>2!T;R!P
M97)I;V1I8V%L;'D@9&5L971E('1H97-E(&]L9`IT96UP;W)A<GD@9FEL97,N
M"@I!;B!E>&%M<&QE(&-R;VXM8F%S960@<V]L=71I;VX@8V%N(&)E(&9O=6YD
M(&%T(&!@<V-R:7!T<R]T96UP+6-L96%N=7`N8W)O;F!@+@I!;F]T:&5R('!O
M<W-I8FQE('-O;'5T:6]N(&ES('1O('5S92!2960@2&%T)W,@8&!T;7!W871C
M:&!@('5T:6QI='D@;W(@86YY=&AI;F<*<VEM:6QA<B!T;R!R96UO=F4@;VQD
M(&9I;&5S("AS964@:'1T<#HO+W=W=RYR961H870N8V]M+RDN"@H*5')A;G-L
M871I;VYS"CT]/3T]/3T]/3T]/0H*3F]T92!F;W(@:6YT97)N871I;VYA;"!U
M<V5R<SH@2&]R9&4@=7-E<R!'3E4@9V5T=&5X="!T;R!P<F]V:61E(&QO8V%L
M"G1R86YS;&%T:6]N<R!O9B!T97AT(&1I<W!L87EE9"!B>2!A<'!L:6-A=&EO
M;G,[('1H92!T<F%N<VQA=&EO;G,@87)E(&9O=6YD(&EN"G1H92!P;R\@9&ER
M96-T;W)Y+B`@268@82!T<F%N<VQA=&EO;B!I<R!N;W0@>65T(&%V86EL86)L
M92!F;W(@>6]U<B!L;V-A;&4@*&%N9`IY;W4@=VES:"!T;R!C<F5A=&4@;VYE
M*2P@<V5E('1H92!@8&AO<F1E+W!O+U)%041-16!@(&9I;&4L(&]R(&EF('EO
M=2=R92!H879I;F<*=')O=6)L92!U<VEN9R!A('!R;W9I9&5D('1R86YS;&%T
M:6]N+"!P;&5A<V4@<V5E('1H90I@:&]R9&4O9&]C<R]44D%.4TQ!5$E/3E-@
M7R!F:6QE(&9O<B!I;G-T<G5C=&EO;G,N"@H*3V)T86EN:6YG(%-U<'!O<G0*
M/3T]/3T]/3T]/3T]/3T]/3T*"DEF('EO=2!E;F-O=6YT97(@<')O8FQE;7,@
M=VET:"!(;W)D92P@:&5L<"!I<R!A=F%I;&%B;&4A"@I4:&4@2&]R9&4@1G)E
M<75E;G1L>2!!<VME9"!1=65S=&EO;G,@3&ES="`H1D%1*2P@879A:6QA8FQE
M(&]N('1H92!796(@870*"B`@:'1T<#HO+W=W=RYH;W)D92YO<F<O9F%Q+PH*
M5&AE($AO<F1E(%!R;VIE8W0@<G5N<R!A(&YU;6)E<B!O9B!M86EL:6YG(&QI
M<W1S+"!F;W(@:6YD:79I9'5A;"!A<'!L:6-A=&EO;G,*86YD(&9O<B!I<W-U
M97,@<F5L871I;F<@=&\@=&AE('!R;VIE8W0@87,@82!W:&]L92X@26YF;W)M
M871I;VXL(&%R8VAI=F5S+"!A;F0*<W5B<V-R:7!T:6]N(&EN9F]R;6%T:6]N
M(&-A;B!B92!F;W5N9"!A=`H*("!H='1P.B\O=W=W+FAO<F1E+F]R9R]M86EL
M+PH*1FEN86QL>2P@2&]R9&4@9&5V96QO<&5R<RP@8V]N=')I8G5T;W)S(&%N
M9"!U<V5R<R!A;'-O(&UA:V4@;V-C87-I;VYA;`IA<'!E87)A;F-E<R!O;B!)
M4D,L(&]N('1H92!C:&%N;F5L("-H;W)D92!O;B!T:&4@9G)E96YO9&4@3F5T
M=V]R:PHH:7)C+F9R965N;V1E+FYE="DN"@I0;&5A<V4@:V5E<"!I;B!M:6YD
M('1H870@2&]R9&4@:7,@9G)E92!S;V9T=V%R92!W<FET=&5N(&)Y('9O;'5N
M=&5E<G,N"D9O<B!I;F9O<FUA=&EO;B!O;B!R96%S;VYA8FQE('-U<'!O<G0@
M97AP96-T871I;VYS+"!P;&5A<V4@<F5A9`H*("!H='1P.B\O=W=W+FAO<F1E
M+F]R9R]S=7!P;W)T+G!H<`H*5&AA;FMS(&9O<B!U<VEN9R!(;W)D92$*"E1H
M92!(;W)D92!496%M"@H*+BX@7U)%041-13H@/V8]4D5!1$U%+FAT;6P*+BX@
M7V1O8W,O2$%#2TE.1SH@/V8]2$%#2TE.1RYH=&UL"BXN(%]D;V-S+U-%0U52
M2519.B`_9CU314-54DE462YH=&UL"BXN(%]@:&]R9&4O9&]C<R]44D%.4TQ!
M5$E/3E-@.B`_9CU44D%.4TQ!5$E/3E,N:'1M;`H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]D;V-S+U!%4D9/4DU!3D-%````````````````````````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$U,3,R`#$P-3$U-#,S-S0S`#`R,#(W
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B!(;W)D92!097)F;W)M86YC92!'
M=6ED90H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@HZ3&%S="!U<&1A=&4Z
M("`@)$1A=&4Z(#(P,#8O,#4O,S$@,3DZ,30Z,30@)`HZ4F5V:7-I;VXZ("`@
M("`@)%)E=FES:6]N.B`Q+CDN,3`N,3,@)`HZ0V]N=&%C=#H@("`@("`@:&]R
M9&5`;&ES=',N:&]R9&4N;W)G"@HN+B!C;VYT96YT<SHZ($-O;G1E;G1S"@H*
M4V]M92!T:7!S(&]N('!E<F9O<FUA;F-E('1U;FEN9R!S>7-T96US(&9O<B!(
M;W)D92X@(%1H:7,@9&]E<R!N;W0@8V]V97(*:&%R9'=A<F4@='5N:6YG(&]R
M(&5V96X@;&]W(&QE=F5L('-Y<W1E;2`H;F5T=V]R:RP@9FEL97-Y<W1E;2P@
M971C*2!T=6YI;F<N"@I$;VXG="!A<'!L>2!T:&4@9F]L;&]W:6YG('1U;FEN
M9R!H:6YT<R!B;&EN9&QY+B`@5&5S="!Y;W5R(&%P<&QI8V%T:6]N<R!B969O
M<F4*86YD(&%F=&5R('1H92!C:&%N9V5S('5N9&5R('1H92!C;VYD:71I;VYS
M('1H870@87)E(&EM<&]R=&%N="!F;W(@>6]U+B`@1F]R"G-O;64@<&5O<&QE
M(&ET)W,@;6]R92!I;7!O<G1A;G0@=&\@;6%K92!T:&5M(&%S(&9A<W0@87,@
M<&]S<VEB;&4@9F]R(&$@<VUA;&P*=7-E<B!B87-E+"!O=&AE<G,@<F5Q=6ER
M92!T:&4@87!P;&EC871I;VYS('1O('-C86QE('=E;&P@=6YD97(@82!H:6=H
M(&QO860N"E-O;64@;V8@=&AE<V4@:&EN=',@;6EG:'0@979E;B!M86ME('1H
M92!A<'!L:6-A=&EO;G,@<VQO=V5R('5N9&5R(&-E<G1A:6X*8V]N9&ET:6]N
M<R!O<B!U<VEN9R!A(&-E<G1A:6X@:&%R9'=A<F4N"@H*3&EN=7@@5'5N:6YG
M"CT]/3T]/3T]/3T]/0H**B!296-O;7!I;&4@4E!-4R!F;W(@>6]U<B!A<F-H
M:71E8W1U<F4@*&4N9RX@:34X-BP@:38X-BP@871H;&]N+"!E=&,I+@H@(%1H
M:7,@87!P;&EE<R!M;W-T('1O('EO=7(@07!A8VAE+"!02%`L($E-05`L(&%N
M9"!03U`S('!A8VMA9V5S+@H*"D%P86-H92]02%`@='5N:6YG"CT]/3T]/3T]
M/3T]/3T]/3T]"@HJ($-O;G-I9&5R(&$@4$A0(&%C8V5L97)A=&]R('!R;V=R
M86TN("!3964@9F]R(&5X86UP;&4@8%1H92!:96YD(%!E<F9O<FUA;F-E"B`@
M4W5I=&5@7RP@5&AE(&!I;VY#=6)E(%!(4"!!8V-E;&5R871O<F!?+"!@5'5R
M8VL@34U#86-H92!F;W(@4$A08%\L(&]R"B`@94%C8V5L97)A=&]R7RX@(%1H
M97-E(&%C8V5L97)A=&]R<R!S<&5E9"!U<"!A8V-E<W,@8GD@8V%C:&EN9R!T
M:&4@8V]M<&EL960*("!02%`@8V]D92P@96QI;6EN871I;F<@=&AE(&YE960@
M=&\@<F5C;VUP:6QE('1H92!C;V1E(&9O<B!E=F5R>2!S:6YG;&4@<&%G90H@
M(&QO860N("`J*E1H:7,@:7,@<')O8F%B;'D@=&AE(&5A<VEE<W0@=V%Y('1O
M(&EM<')O=F4@=&AE('!E<F9O<FUA;F-E(&]F"B`@2&]R9&4J*BX@($EF('5S
M:6YG(%1U<F-K($U-0V%C:&4L("HJ4$Q%05-%*BH@<F5A9"!@5'5R8VL@34U#
M86-H90H@(%1R;W5B;&5S:&]O=&EN9V!?+@H**B!#;VUP:6QE(%!(4"!W:71H
M('1H92!@8"TM96YA8FQE+6EN;&EN92UO<'1I;6EZ871I;VY@8"!O<'1I;VX@
M=&\@9V5N97)A=&4@=&AE"B`@9F%S=&5S="!P;W-S:6)L92!02%`@97AE8W5T
M86)L92X*"BH@57-E(&]F('1H92!M8W)Y<'0@4$A0(&5X=&5N<VEO;B!S:&]U
M;&0@<VEG;FEF:6-A;G1L>2!I;F-R96%S92!P97)F;W)M86YC90H@('=H:6QE
M(&%L<V\@:6YC<F5A<VEN9R!S96-U<FET>2X*"BH@16YA8FQE(%!(4"!O=71P
M=70@8V]M<')E<W-I;VX@*&5I=&AE<B!I;B!@8'!H<"YI;FE@8"!O<@H@(&!@
M:&]R9&4O8V]N9FEG+V-O;F8N<&AP8&`I+@H**B!$:7-A8FQE('1H92!M96UO
M<GD@;&EM:70@:6X@8&!P:'`N:6YI8&`N"@HJ($ME97`@=&AE(&EN8VQU9&4@
M<&%T:"!D969I;F5D(&EN(&!@<&AP+FEN:6!@(&%S('-H;W)T(&%S('!O<W-I
M8FQE+"!W:71H('1H90H@(&UO<W0@9G)E<75E;G1L>2!U<V5D(&QI8G)A<GD@
M<&%T:',@9FER<W0N("!9;W4@9&]N)W0@;F5E9"!T;R!I;F-L=61E('1H90H@
M(&QO8V%L(&1I<F5C=&]R>2!@8"Y@8"!B96-A=7-E($AO<F1E(&%L=V%Y<R!U
M<V5S(&9U;&P@<&%T:',@:6YS=&5A9"!O9@H@(')E;&%T:79E('!A=&AS+@H*
M*B!5<V4@86X@;W!T:6UI>F5D(&!@<&AP+FEN:6!@+"!S=&%R="!F<F]M(&!@
M<&AP+FEN:2UR96-O;6UE;F1E9&!@(&]F('EO=7(@4$A0"B`@9'-I=')I8G5T
M:6]N+@H**B!$;VXG="!R=6X@4$A0('-E<W-I;VX@9V%R8F%G92!C;VQL96-T
M:6]N('1O;R!O9G1E;B!I9B!U<VEN9R!A('-L;W<@<W1O<F%G90H@(&UE9&EU
M;2`H;&EK92!344PI+B`H4V5E(&!@<V5S<VEO;BYG8U]P<F]B86)I;&ET>6!@
M(&EN(&!@<&AP+FEN:6!@*0H**B!)9B!Y;W4@:&%V92!A(&QA<F=E(&YU;6)E
M<B!O9B!S97-S:6]N<RP@8V]N<VED97(@<W1O<FEN9R!T:&5M(&EN(&AA<VAE
M9`H@(&1I<F5C=&]R>2!L979E;',N("A3964@8&!S97-S:6]N+G-A=F5?<&%T
M:&!@(&%T(&AT='`Z+R]W=W<N<&AP+FYE="]S97-S:6]N*0H**B!#;VYS:61E
M<B!U<VEN9R!A(&9A<W1E<B!S=&]R86=E(&UE9&EU;2!F;W(@<V5S<VEO;G,L
M('-U8V@@87,@82!T;7!F<R!O<@H@(&]T:&5R(&UE;6]R>2!B87-E9"!F:6QE
M('-Y<W1E;2X@($EF('EO=2!A<F4@<W5R92!Y;W5R(&%P86-H92!S971U<"!I
M<R!R;V-K"B`@<V]L:60@86YD('EO=2!D;VXG="!R97-T87)T(&ET('1H97)E
M(&ES(&$@;6T@<V5S<VEO;B!D<FEV97(N("!(;W=E=F5R+"!B90H@(&%W87)E
M('1H870@8V5R=&%I;B!(;W)D92!A<'!L:6-A=&EO;G,@*&QI:V4@24U0*2!M
M86ME(&AE879Y('5S92!O9B!C86-H:6YG"B`@9&%T82!I;B!S97-S:6]N<R!S
M;R!M96UO<GD@8F%S960@<V]L=71I;VYS(&UA>2!B92!E>&AA=7-T960@<75I
M8VML>2P*("!P87)T:6-U;&%R;'D@:68@=&AE<F4@=VEL;"!B92!M;W)E('1H
M86X@82!S:6YG;&4@=7-E<BX*"BH@3VYL>2!L;V%D(&%S(&UA;GD@07!A8VAE
M(&%N9"!02%`@97AT96YS:6]N<R!A<R!N965D960@*'1O(')E9'5C92!M96UO
M<GD*("!U<V%G92DN"@HJ(%5S92!S=&%T:6-A;&QY(&-O;7!I;&5D($%P86-H
M92!M;V1U;&5S+"!I;F-L=61I;F<@=&AE(%!(4"!M;V1U;&4N"@HJ(%5S92!C
M;VUP:6QE<B!O<'1I;6EZ871I;VYS("@M+7!R969E<BUN;VXM<&EC+"`M3S,L
M("UM87)C:"`M;6-P=2P@+6US<V4L"B`@+6UM;7@L("UM9G!M871H/7-S92P@
M971C+BD*"BH@268@=7-I;F<@4U-,('=I=&@@82!L87)G92!S:71E+"!C;VYS
M:61E<B!A(&AA<F1W87)E(%-33"!A8V-E;&5R871O<BX*"BH@57-E('-H87)E
M9"!M96UO<GD@9F]R('1H92!!<&%C:&4@4U-,(&-A8VAE(&EF('!O<W-I8FQE
M+@H**B!4;R!I;7!R;W9E(&-A8VAI;F<@;V8@<W1A=&EC(&-O;G1E;G0@:68@
M86-C97-S:6YG($%P86-H92!34TP@=VET:"!);G1E<FYE=`H@($5X<&QO<F5R
M+"!T<GD@<V5T=&EN9R!L;VYG97(@97AP:7)A=&EO;B!P97)I;V1S.CH*"B`@
M("!%>'!I<F5S06-T:79E($]N"B`@("!%>'!I<F5S0GE4>7!E(&EM86=E+W!N
M9R`B;F]W('!L=7,@,2!M;VYT:"(*("`@($5X<&ER97-">51Y<&4@:6UA9V4O
M9VEF(")N;W<@<&QU<R`Q(&UO;G1H(@H@("`@17AP:7)E<T)Y5'EP92!T97AT
M+VIA=F%S8W)I<'0@(FYO=R!P;'5S(#$@;6]N=&@B"B`@("!%>'!I<F5S0GE4
M>7!E(&%P<&QI8V%T:6]N+W@M:F%V87-C<FEP="`B;F]W('!L=7,@,2!M;VYT
M:"(*("`@($5X<&ER97-">51Y<&4@=&5X="]C<W,@(FYO=R!P;'5S(#$@;6]N
M=&@B"@H@("XN($YO=&4Z.B!9;W4@;75S="!C;VUP:6QE('1H92!@8&UO9%]E
M>'!I<F5S8&`@97AT96YS:6]N(&EN=&\@07!A8VAE(&EN"B`@("`@("`@("`@
M(&]R9&5R('1O('5S92!T:&5S92!D:7)E8W1I=F5S+@H*("`N+B!787)N:6YG
M.CH@5&AI<R!M:6=H="!C875S92!P<F]B;&5M<R!I9B!Y;W4@=7!G<F%D92!(
M;W)D92!A;F0@=&AE('5S97)S)PH@("`@("`@("`@("`@("!B<F]W<V5R<R!S
M=&EL;"!U<V4@=&AE(&]L9"!F:6QE('9E<G-I;VYS+@H**B!$:7-A8FQE($1.
M4R!L;V]K=7!S(&EN('EO=7(@07!A8VAE(&QO9V=I;F<L(&]R('5S92!A(&-A
M8VAI;F<@1$Y3('-E<G9E<B!O;@H@('1H92!W96(@<V5R=F5R(&AO<W0N"@HJ
M($5N86)L92!!<&%C:&4@:V5E<&%L:79E<RX*"BXN(%]@5&AE(%IE;F0@4&5R
M9F]R;6%N8V4@4W5I=&5@.B!H='1P.B\O=W=W+GIE;F0N8V]M+VAO<F1E+G!H
M<`HN+B!?8&EO;D-U8F4@4$A0($%C8V5L97)A=&]R8#H@:'1T<#HO+W=W=RYP
M:'`M86-C96QE<F%T;W(N8V\N=6L*+BX@7V!4=7)C:R!-34-A8VAE(&9O<B!0
M2%!@.B!H='1P.B\O='5R8VLM;6UC86-H92YS;W5R8V5F;W)G92YN970*+BX@
M7V5!8V-E;&5R871O<CH@:'1T<#HO+V5A8V-E;&5R871O<BYN970*+BX@7V!4
M=7)C:R!-34-A8VAE(%1R;W5B;&5S:&]O=&EN9V`Z(&AT='`Z+R]W:6MI+FAO
M<F1E+F]R9R]4=7)C:TU-0V%C:&54<F]U8FQE<VAO;W1I;F<*"@I396YD:6YG
M($UA:6P*/3T]/3T]/3T]/3T]"@HJ($=E;F5R86QL>2!U<VEN9R!A(&QO8V%L
M('-E;F1M86EL(&-O;6UA;F0@=&\@<V5N9"!M86EL('=I;&P@<F5S=6QT(&EN
M(&)E='1E<@H@('!E9F]R;6%N8V4@=&AA;B!U<VEN9R!A(%--5%`@8V]N;F5C
M=&EO;BX*"BH@4V]M92!-5$$@<V5R=F5R<R!M87D@8F4@9F%S=&5R(&]R(&UO
M<F4@969F:6-I96YT('1H86X@;W1H97)S+B`@0V]N<VED97(*("!S=VET8VAI
M;F<@=&\@82!F87-T97(@9F]R;6%T(&EF(&YE961E9"X*"@I)34%0('1U;FEN
M9PH]/3T]/3T]/3T]/0H**B!#;VYS:61E<B!A;B!)34%0('!R;WAY(&9O<B!M
M;W)E('!E<G-I<W1E;G0@8V]N;F5C=&EO;G,N("!3;VUE($E-05`@<')O>&EE
M<PH@(&%R92!U<"UI;6%P<')O>'E?(&%N9"!097)D:71I;VY?+B`@5&\@;6%K
M92!S96YS92P@=&AE('!R;WAY"B`@<VAO=6QD(&)E(&EN<W1A;&QE9"!O;B!T
M:&4@<V5R=F5R(')U;FYI;F<@2&]R9&4L(&%N9"!T:&ES('-E<G9E<B!N965D
M<PH@(&5N;W5G:"!#4%4@<&]W97(@=&\@:&%N9&QE('1H92!A9&1I=&EO;F%L
M(&QO860N"@HJ(%-O;64@24U!4"!S97)V97)S("AO<B!)34%0(&UA:6QB;W@@
M<W1O<F4@9F]R;6%T<RD@<&5R9F]R;2!B971T97(@=&AA;@H@(&]T:&5R<RX@
M($-O;G-I9&5R('-W:71C:&EN9R!T;R!A(&9A<W1E<B!F;W)M870@:68@;F5E
M9&5D+@H**B!&;VQL;W<@=&AE($E-05`@<V5R=F5R<R<@<&5R9F]R;6%N8V4@
M:&EN=',Z"@H@("T@0WER=7,Z(&AT='`Z+R]A<V<N=V5B+F-M=2YE9'4O8WER
M=7,O9&]W;FQO860O:6UA<&0O:6YS=&%L;"UP97)F+FAT;6P*"BXN(%]U<"UI
M;6%P<')O>'DZ(&AT='`Z+R]W=W<N:6UA<'!R;WAY+F]R9R\*+BX@7U!E<F1I
M=&EO;CH@:'1T<#HO+W=W=RYV97)G96YE="YN970O;&EN=7@O<&5R9&ET:6]N
M+PH*"E!O<W1G<F5S<6P@='5N:6YG"CT]/3T]/3T]/3T]/3T]/3T]"@HJ($1O
M(&$@=F%C=75M(&-O;6UA;F0@<&5R:6]D:6-A;&QY('1O('1U;F4@>6]U<B!D
M871A8F%S90H**B!);F-R96%S92!@8'-H87)E9%]B=69F97)S8&`@86YD(&!@
M<V]R=%]M96U@8"!M96UO<GD@<V5T=&EN9W,N"@HJ($EF('=E8B!S97)V97(@
M86YD(&1A=&%B87-E(&ES(&]N('1H92!S86UE('5N:7@@:&]S="P@=7-E('5N
M:7@@<V]C:V5T<PH@(&EN<W1E860@;V8@;F5T=V]R:R!C;VYN96-T:6]N<R!F
M;W(@9&%T86)A<V4@86-C97-S+@H*"DUY4U%,('1U;FEN9PH]/3T]/3T]/3T]
M/3T*"BH@268@=V5B('-E<G9E<B!A;F0@9&%T86)A<V4@:7,@;VX@=&AE('-A
M;64@=6YI>"!H;W-T+"!U<V4@=6YI>"!S;V-K971S"B`@:6YS=&5A9"!O9B!N
M971W;W)K(&-O;FYE8W1I;VYS(&9O<B!D871A8F%S92!A8V-E<W,N"@HJ($5N
M86)L92!M>7-Q;"!Q=65R>2!C86-H92!I9B!Y;W4@:&%V92!S=69F:6-I96YT
M(%)!32X@($5D:70@>6]U<B!@8&UY+F-N9F!@"B`@9FEL92!A;F0@861D('1H
M92!F;VQL;W=I;F<@=&\@=&AE(&!@6VUY<W%L9%U@8"!S96-T:6]N("AC:&%N
M9V4@=&AE(&UE;6]R>0H@('-I>F4@=&\@;65E="!Y;W5R(&YE961S*3HZ"@H@
M("`@<V5T+79A<FEA8FQE(#T@<75E<GE?8V%C:&5?<VEZ93TQ,CA-"@H*2&]R
M9&4@='5N:6YG"CT]/3T]/3T]/3T]/0H**B!9;W4@8V%N(&-O;F9I9W5R92!(
M;W)D92!T;R!S97)V92!A;&P@:6UA9V5S(&%N9"!S='EL92!S:&5E=',@9G)O
M;2!A"B`@9&EF9F5R96YT('-E<G9E<BX@5&AI<R!C;W5L9"!B92!A('9E<GD@
M;&EG:'1W96EG:'0@<V5R=F5R('=I=&AO=70@86QL('1H90H@(&]V97)H96%D
M(&9O<B!P<F]C97-S:6YG(%!(4"!F:6QE<RP@;&EK92!L:6=H='1P9"X@66]U
M(&YE960@=&\@<V5T('1H90H@(&!@=&AE;65S=7)I8&`@<&%R86UE=&5R(&EN
M(&!@8V]N9FEG+W)E9VES=')Y+G!H<&!@(&9O<B!A;&P@87!P;&EC871I;VYS
M(&%N9`H@(&-O<'D@86QL(&!@=&AE;65S8&`@9&ER96-T;W)I97,@:6X@=&AE
M('-A;64@9&ER96-T;W)Y(&QA>6]U="!T;R!T:&4@;W1H97(*("!S97)V97(N
M"@HN+B!?;&EG:'1T<&0Z(&AT='`Z+R]W=W<N;&EG:'1T<&0N;F5T+PH*"D%P
M<&QI8V%T:6]N('1U;FEN9PH]/3T]/3T]/3T]/3T]/3T]/3T*"BH@4V]M92!A
M<'!L:6-A=&EO;G,@8V]N=&%I;B!A9'9A;F-E9"!F96%T=7)E<R!T:&%T(&UI
M9VAT(&AA=F4@82!C97)T86EN(&EM<&%C=`H@(&]N('1H92!P97)F;W)M86YC
M92X@(%1H97-E(&9E871U<F5S(&-A;B!U<W5A;&QY(&)E('1U<FYE9"!O9F8@
M:6X@=&AE"B`@87!P;&EC871I;VXG<R!C;VYF:6=U<F%T:6]N(&%N9"!A<F4@
M97AP;&EC:71L>2!D97-C<FEB960@87,@8F5I;F<@80H@('!E<F9O<FUA;F-E
M(&AI="!I;B!T:&4@8V]N9FEG=7)A=&EO;B!W96(@9G)O;G1E;F0N"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]D;V-S+U)%
M041-10``````````````````````````````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`V-S,R`#$P-3$U-#,S-S0S`#`Q-S0W-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!7:&%T(&ES($AO<F1E/PH]
M/3T]/3T]/3T]/3T]/0H*.DQA<W0@=7!D871E.B`@("1$871E.B`R,#`U+S$P
M+S$X(#$Q.C,S.C,U("0*.E)E=FES:6]N.B`@("`@("12979I<VEO;CH@,BXQ
M,RXQ,"XQ("0*.D-O;G1A8W0Z("`@("`@(&AO<F1E0&QI<W1S+FAO<F1E+F]R
M9PH*+BX@8V]N=&5N=',Z.B!#;VYT96YT<PHN+B!S96-T:6]N+6YU;6)E<FEN
M9SHZ"@I4:&4@2&]R9&4@4')O:F5C="!I<R!A(&=R;W5P(&]F(&1E=F5L;W!E
M<G,@=VAO('=R:71E(%=E8B!A<'!L:6-A=&EO;G,@=7-I;F<*=&AE($AO<F1E
M($%P<&QI8V%T:6]N($9R86UE=V]R:RP@:71S96QF(&$@<')O9'5C="!O9B!T
M:&4@4')O:F5C="X*"E1H92!(;W)D92!!<'!L:6-A=&EO;B!&<F%M97=O<FL@
M:7,@=W)I='1E;B!I;B!02%`L(&%N9"!P<F]V:61E<R!T:&4@8V]M;6]N"G1O
M;VQS(&$@5V5B(&%P<&QI8V%T:6]N(')E<75I<F5S.B!C;&%S<V5S(&9O<B!D
M96%L:6YG('=I=&@@<')E9F5R96YC97,L"F-O;7!R97-S:6]N+"!B<F]W<V5R
M(&1E=&5C=&EO;BP@8V]N;F5C=&EO;B!T<F%C:VEN9RP@34E-12P@86YD(&UO
M<F4N"@I4:&4@2&]R9&4@1G)A;65W;W)K+"!B>2!I='-E;&8L(&1O97,@;F]T
M('!R;W9I9&4@86YY('-I9VYI9FEC86YT(&5N9"!U<V5R"F9U;F-T:6]N86QI
M='D[(&ET('!R;W9I9&5S(&$@8F%S92!F;W(@;W1H97(@87!P;&EC871I;VYS
M(&%N9"!T;V]L<R!F;W(*9&5V96QO<&5R<RX@66]U('=I;&P@<')O8F%B;'D@
M=V%N="!T;R!I;G-T86QL('-O;64@;V8@=&AE(&%V86EL86)L92!(;W)D90IA
M<'!L:6-A=&EO;G,L('-U8V@@87,@24U0("AA('=E8FUA:6P@8VQI96YT*2P@
M;W(@2W)O;F]L:71H("AA(&-A;&5N9&%R*2X@5&AE<F4*:7,@82!L:7-T(&]F
M($AO<F1E(&%P<&QI8V%T:6]N<R!A;F0@<')O:F5C=',@870*:'1T<#HO+W=W
M=RYH;W)D92YO<F<O<')O:F5C=',N<&AP+@H*5&AI<R!S;V9T=V%R92!I<R!/
M4TD@0V5R=&EF:65D($]P96X@4V]U<F-E(%-O9G1W87)E+B`@3U-)($-E<G1I
M9FEE9"!I<R!A"F-E<G1I9FEC871I;VX@;6%R:R!O9B!T:&4@8$]P96X@4V]U
M<F-E($EN:71I871I=F5@7RX*"BXN(%]@3W!E;B!3;W5R8V4@26YI=&EA=&EV
M96`Z(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O"@H*3V)T86EN:6YG($AO
M<F1E"BTM+2TM+2TM+2TM+2TM+0H*1G5R=&AE<B!I;F9O<FUA=&EO;B!O;B!(
M;W)D92!A;F0@=&AE(&QA=&5S="!V97)S:6]N(&-A;B!B92!O8G1A:6YE9"!A
M=`H*("!H='1P.B\O=W=W+FAO<F1E+F]R9R]H;W)D92\*"DEN9F]R;6%T:6]N
M(&]N(&%P<&QI8V%T:6]N<R!T:&%T('5S92!T:&4@2&]R9&4@9G)A;65W;W)K
M(&-A;B!B92!F;W5N9"!A=`H*("!H='1P.B\O=W=W+FAO<F1E+F]R9R]P<F]J
M96-T<RYP:'`*"@I$;V-U;65N=&%T:6]N"BTM+2TM+2TM+2TM+2T*"E1H92!F
M;VQL;W=I;F<@9&]C=6UE;G1A=&EO;B!I<R!A=F%I;&%B;&4@:6X@=&AE($AO
M<F1E(&1I<W1R:6)U=&EO;CH*"CI214%$345?.B`@("`@("`@("`@("`@("`@
M("!4:&ES(&9I;&4*.D-/4%E)3D=?.B`@("`@("`@("`@("`@("`@($-O<'ER
M:6=H="!A;F0@;&EC96YS92!I;F9O<FUA=&EO;@HZ8&1O8W,O0TA!3D=%4V!?
M.B`@("`@("`@("`@0VAA;F=E<R!B>2!R96QE87-E"CI@9&]C<R]#3T1)3D=?
M4U1!3D1!4D138%\Z("!#;V1I;F<@<W1A;F1A<F1S(&9O<B!(;W)D92!P<F]J
M96-T<PHZ8&1O8W,O0T].5%))0E5424Y'8%\Z("`@("`@2&]W('1O(&-O;G1R
M:6)U=&4@=&\@2&]R9&4*.F!D;V-S+T-2141)5%-@7SH@("`@("`@("`@(%!R
M;VIE8W0@9&5V96QO<&5R<PHZ8&1O8W,O2$%#2TE.1V!?.B`@("`@("`@("`@
M2&]W('1O(&=E="!(;W)D92!V:6$@0U93"CI@9&]C<R])3E-404Q,8%\Z("`@
M("`@("`@("!);G-T86QL871I;VX@:6YS=')U8W1I;VYS(&%N9"!N;W1E<PHZ
M8&1O8W,O4$521D]234%.0T5@7SH@("`@("`@4&5R9F]R;6%N8V4@9W5I9&4*
M.F!D;V-S+U)%3$5!4T5@7SH@("`@("`@("`@(%)E;&5A<V4@<')O8V5S<R!N
M;W1E<PHZ8&1O8W,O4T5#55))5%E@7SH@("`@("`@("`@4V5C=7)I='D@;F]T
M97,*.F!D;V-S+U1/1$]@7SH@("`@("`@("`@("`@($1E=F5L;W!M96YT(%1/
M1$\@;&ES=`HZ8&1O8W,O55!'4D%$24Y'8%\Z("`@("`@("`@4&]I;G1E<G,@
M;VX@=7!G<F%D:6YG(&9R;VT@<')E=FEO=7,@2&]R9&4@=F5R<VEO;G,*"@I)
M;G-T86QL871I;VX*+2TM+2TM+2TM+2TM"@I);G-T<G5C=&EO;G,@9F]R(&EN
M<W1A;&QI;F<@2&]R9&4@8V%N(&)E(&9O=6YD(&EN('1H92!F:6QE($E.4U1!
M3$Q?(&EN('1H90I@8&1O8W,O8&`@9&ER96-T;W)Y(&]F('1H92!(;W)D92!D
M:7-T<FEB=71I;VXN"@H*07-S:7-T86YC90HM+2TM+2TM+2TM"@I)9B!Y;W4@
M96YC;W5N=&5R('!R;V)L96US('=I=&@@2&]R9&4L(&AE;'`@:7,@879A:6QA
M8FQE(2`*"E1H92!(;W)D92!&<F5Q=65N=&QY($%S:V5D(%%U97-T:6]N<R!,
M:7-T("A&05$I+"!A=F%I;&%B;&4@;VX@=&AE(%=E8B!A=`H@"B`@:'1T<#HO
M+W=W=RYH;W)D92YO<F<O9F%Q+PH*5&AE($AO<F1E(%!R;VIE8W0@<G5N<R!A
M(&YU;6)E<B!O9B!M86EL:6YG(&QI<W1S+"!F;W(@:6YD:79I9'5A;"!A<'!L
M:6-A=&EO;G,*86YD(&9O<B!I<W-U97,@<F5L871I;F<@=&\@=&AE('!R;VIE
M8W0@87,@82!W:&]L92X@($EN9F]R;6%T:6]N+"!A<F-H:79E<RP@86YD"G-U
M8G-C<FEP=&EO;B!I;F9O<FUA=&EO;B!C86X@8F4@9F]U;F0@870*"B`@:'1T
M<#HO+W=W=RYH;W)D92YO<F<O;6%I;"\*"DQA<W1L>2P@2&]R9&4@9&5V96QO
M<&5R<RP@8V]N=')I8G5T;W)S(&%N9"!U<V5R<R!A;'-O(&UA:V4@;V-C87-I
M;VYA;`IA<'!E87)A;F-E<R!O;B!)4D,L(&]N('1H92!C:&%N;F5L("-H;W)D
M92!O;B!T:&4@9G)E96YO9&4@3F5T=V]R:PHH:7)C+F9R965N;V1E+FYE="DN
M"@H*3&EC96YS:6YG"BTM+2TM+2TM+0H*1F]R(&QI8V5N<VEN9R!A;F0@8V]P
M>7)I9VAT(&EN9F]R;6%T:6]N+"!P;&5A<V4@<V5E('1H92!F:6QE($-/4%E)
M3D=?(&EN('1H90I(;W)D92!D:7-T<FEB=71I;VXN"@I4:&%N:W,L"@I4:&4@
M2&]R9&4@=&5A;0H*"BXN(%]214%$344Z(#]F/5)%041-12YH=&UL"BXN(%]#
M3U!924Y'.B!H='1P.B\O=W=W+FAO<F1E+F]R9R]L:6-E;G-E<R]L9W!L+G!H
M<`HN+B!?9&]C<R]#2$%.1T53.B`_9CU#2$%.1T53+FAT;6P*+BX@7V1O8W,O
M0T]$24Y'7U-404Y$05)$4SH@/V8]0T]$24Y'7U-404Y$05)$4RYH=&UL"BXN
M(%]D;V-S+T-/3E1224)55$E.1SH@/V8]0T].5%))0E5424Y'+FAT;6P*+BX@
M7V1O8W,O0U)%1$E44SH@/V8]0U)%1$E44RYH=&UL"BXN(%]D;V-S+TA!0TM)
M3D<Z(#]F/4A!0TM)3D<N:'1M;`HN+B!?24Y35$%,3#H*+BX@7V1O8W,O24Y3
M5$%,3#H@/V8]24Y35$%,3"YH=&UL"BXN(%]D;V-S+U!%4D9/4DU!3D-%.B`_
M9CU015)&3U)-04Y#12YH=&UL"BXN(%]D;V-S+U)%3$5!4T4Z(#]F/5)%3$5!
M4T4N:'1M;`HN+B!?9&]C<R]314-54DE463H@/V8]4T5#55))5%DN:'1M;`HN
M+B!?9&]C<R]43T1/.B`_9CU43T1/+FAT;6P*+BX@7V1O8W,O55!'4D%$24Y'
M.B`_9CU54$=2041)3D<N:'1M;`H`````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O9&]C<R]3
M14-54DE460``````````````````````````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`R-#0T-@`Q,#4Q-30S,S<T,P`P,C`P,3$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/0H@2&]R9&4@4V5C=7)I='D@3F]T97,*/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/0H*.DQA<W0@=7!D871E.B`@("1$871E.B`R,#`T+S`Y+S(V(#(S
M.C,S.C`W("0*.E)E=FES:6]N.B`@("`@("12979I<VEO;CH@,2XY("0*.D-O
M;G1A8W0Z("`@("`@(&AO<F1E0&QI<W1S+FAO<F1E+F]R9PH*+BX@8V]N=&5N
M=',Z.B!#;VYT96YT<PHN+B!S96-T:6]N+6YU;6)E<FEN9SHZ"@H*5&5M<&]R
M87)Y(&9I;&5S"CT]/3T]/3T]/3T]/3T]/0H*2&]R9&4@87!P;&EC871I;VYS
M(&UA:V4@97AT96YS:79E('5S92!O9B!T96UP;W)A<GD@9FEL97,N("!);B!O
M<F1E<B!T;R!M86ME"G-U<F4@=&AE<V4@9FEL97,@87)E('-E8W5R92P@>6]U
M('-H;W5L9"!M86ME('-U<F4@>6]U<B!I;G-T86QL871I;VX@;65E=',@=&AE
M"F9O;&QO=VEN9R!C<FET97)I82X*"E-I=&5S(&UA>2!G86EN(&EN8W)E87-E
M9"!S96-U<FET>2!B>2!D969I;FEN9R!A('1E;7!O<F%R>2!D:7)E8W1O<GD@
M:6X@=&AE"DAO<F1E(&-O;F9I9W5R871I;VX@=VAI8V@@:7,@=W)I=&%B;&4@
M8GD@=&AE('=E8B!S97)V97(L(&)U="!N;W0@=W)I=&%B;&4@8GD*;W1H97(@
M=7-E<G,N("!3:6YC92!T:&4@=&5M<&]R87)Y(&9I;&5S(&UA>2!C;VYT86EN
M('-E;G-I=&EV92!I;F9O<FUA=&EO;B!I=`II<R!B97-T('1O(&%L<V\@;6%K
M92!T:&5S92!F:6QE('5N<F5A9&%B;&4@8GD@;W1H97(@=7-E<G,N("!4:&%T
M(&ES+"!T:&5Y(&-A;@IB92!M861E(')E861A8FQE(&%N9"!W<FET86)L92!O
M;FQY(&)Y('1H92!W96(@<V5R=F5R('5S97(N"@H*4$A0(%-E<W-I;VYS"CT]
M/3T]/3T]/3T]/0H*1F]R('1H92!M;W-T('-E8W5R:71Y+"!Y;W4@<VAO=6QD
M(&5N86)L92!02%`@<V5S<VEO;B!C;V]K:65S(&)Y(&5N86)L:6YG('1H90IP
M:'`@<V5T=&EN9R!@8'-E<W-I;VXN=7-E7V-O;VMI97-@8"X@(%=H96X@9&]I
M;F<@<V\L(&)E('-U<F4@=&\@<V5T(&%N"F%P<')O<')I871E(&!@<V5S<VEO
M;BYC;V]K:65?<&%T:&!@(&%N9"!@8'-E<W-I;VXN8V]O:VEE7V1O;6%I;F!@
M(&%L<V\@=&\*<V5C=7)E('EO=7(@8V]O:VEE<RX*"DEF(%!(4"!S97-S:6]N
M<R!A<F4@<V5T('1O('5S92!T:&4@8&!F:6QE<V!@('-A=F5?:&%N9&QE<BP@
M=&AE;B!T:&5S92!F:6QE<PIS:&]U;&0@8F4@<V5C=7)E9"!P<F]P97)L>2X@
M(%-I=&5S(&-A;B!I;F-R96%S92!S96-U<FET>2!B>2!S971T:6YG('1H92!P
M:'`*<V5T=&EN9R!@8'-E<W-I;VXN<V%V95]P871H8&`@=&\@82!D:7)E8W1O
M<GD@=&AA="!I<R!O;FQY(')E861A8FQE(&%N9`IW<FET86)L92!B>2!T:&4@
M=V5B('-E<G9E<B!P<F]C97-S+@H*4VET97,@=VET:"!A(&QA<F=E('5S97(@
M8F%S92!S:&]U;&0@8V]N<VED97(@<V5T=&EN9R!T:&4*8&!S97-S:6]N+F5N
M=')O<'E?9FEL96!@(&%N9"!@8'-E<W-I;VXN96YT<F]P>5]L96YG=&A@8"!T
M;R!A<'!R;W!R:6%T92!V86QU97,N"@I(;W)D92!W:6QL(&5N8W)Y<'0@=&AE
M('5S97(@8W)E9&5N=&EA;',@8F5F;W)E('-T;W)I;F<@=&AE;2!I;B!T:&4@
M<V5S<VEO;BX*2&]W979E<BP@=&AI<R!E;F-R>7!T:6]N(&-A;B!B92!I;7!R
M;W9E9"!I9B!Y;W4@:&%V92!A;F0@96YA8FQE('1H92!P:'`*97AT96YS:6]N
M(")M8W)Y<'0B('=H:6-H(&%L;&]W<R!F;W(@<W1R;VYG97(@96YC<GEP=&EO
M;B!T:&%N(&ES(&]T:&5R=VES90IP<F]V:61E9"!B>2!(;W)D92X*"@I$969A
M=6QT(&1A=&%B87-E('!A<W-W;W)D<PH]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/0H*5&AE($AO<F1E(&1O8W5M96YT871I;VX@86YD('-A;7!L92!D871A
M8F%S92!C<F5A=&EO;B!S8W)I<'1S(&-R96%T92!A(&1E9F%U;'0*=7-E<B!A
M;F0@<&%S<W=O<F0@9F]R(&%C8V5S<VEN9R!T:&4@:&]R9&4@9&%T86)A<V4N
M("!5<VEN9R!T:&ES('!A<W-W;W)D(&EN(&$*<')O9'5C=&EO;B!E;G9I<F]N
M;65N="!I<R!A('-E8W5R:71Y(&AO;&4L('-I;F-E(&%N(&%T=&%C:V5R('=I
M;&P@96%S:6QY(&=U97-S"FET+@H*270@:7,@=F5R>2!I;7!O<G1A;G0@=&AA
M="!S:71E<R!C:&%N9V4@870@;&5A<W0@=&AE('!A<W-W;W)D('1O('-O;65T
M:&EN9PIS96-U<F4N"@H*4')E=F5N="!C;VYF:6=U<F%T:6]N(&9I;&4@<F5A
M9&EN9R!A;F0@=W)I=&EN9R`*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/0H*5&AE(&-O;F9I9W5R871I;VX@9FEL97,@
M;6%Y(&-O;G1A:6X@<V5N<VET:79E(&1A=&$@*'-U8V@@87,@9&%T86)A<V4*
M<&%S<W=O<F1S*2!T:&%T('-H;W5L9"!N;W0@8F4@<F5A9"!O<B!W<FET=&5N
M(&)Y(&QO8V%L('-Y<W1E;2!U<V5R<R!O<B!R96UO=&4*=V5B('5S97)S+@H*
M268@>6]U('5S92!A(%5N:7@@<WES=&5M+"!O;F4@=V%Y('1O(&UA:V4@=&AE
M(&-O;F9I9W5R871I;VX@9FEL97,@86YD"F1I<F5C=&]R:65S(&%C8V5S<VEB
M;&4@;VYL>2!T;R!T:&4@=V5B('-E<G9E<B!I<R!A<R!F;VQL;W=S+B`@2&5R
M92!W92!A<W-U;64*=&AA="!T:&4@=V5B('-E<G9E<B!R=6YS(&%S('1H92!U
M<V5R(&!@87!A8VAE8&`@86YD('1H92!F:6QE<R!A<F4@;&]C871E9"!I;@I@
M8"]H;VUE+VAT='!D+VAT;6Q@8"`M+2!S=6)S=&ET=71E('1H92!C;W)R96-T
M('5S97(@;W(@9FEL92!P871H(&EF(&YE961E9#HZ"@HD(&-H;W=N("U2(&%P
M86-H92`O:&]M92]H='1P9"]H=&UL+VAO<F1E+V-O;F9I9PHD(&-H;W=N("U2
M(&%P86-H92`O:&]M92]H='1P9"]H=&UL+VAO<F1E+RHO8V]N9FEG"B0@8VAM
M;V0@+5(@9V\M<G=X("]H;VUE+VAT='!D+VAT;6PO:&]R9&4O8V]N9FEG"B0@
M8VAM;V0@+5(@9V\M<G=X("]H;VUE+VAT='!D+VAT;6PO:&]R9&4O*B]C;VYF
M:6<*"D9O<B!C;VUP;&5T96QY(&9A<V-I<W0@<&5R;6ES<VEO;G,L('EO=2!C
M86X@;6%K92!T:&4@96YT:7)E($AO<F1E('1R964*:6YA8V-E<W-I8FQE(&)Y
M(&%N>6]N92!E>&-E<'0@=&AE('=E8B!S97)V97(@=7-E<B`H86YD(')O;W0I
M.CH*"B0@8VAO=VX@+5(@87!A8VAE("]H;VUE+VAT='!D+VAT;6PO:&]R9&4*
M)"!C:&UO9"`M4B!G;RUR=W@@("]H;VUE+VAT='!D+VAT;6PO:&]R9&4*)"!C
M:&UO9"`M4B!A+7<@("`O:&]M92]H='1P9"]H=&UL+VAO<F1E+PH*3F]T92!T
M:&%T('1H92!L87-T(&QI;F4@;6%K97,@86QL(&9I;&5S('5N=W)I=&%B;&4@
M8GD@86YY('5S97(@*&]N;'D@<F]O="!C86X*;W9E<G)I9&4@=&AI<RDN("!4
M:&ES(&UA:V5S('1H92!S:71E('-E8W5R92P@8G5T(&UA>2!M86ME(&ET(&UO
M<F4@9&EF9FEC=6QT('1O"F%D;6EN:7-T<F%T92X@($EN('!A<G1I8W5L87(L
M(&ET('=I;&P@9&5F96%T('1H92!(;W)D92!A9&UI;FES=')A=&EV90IC;VYF
M:6=U<F%T:6]N(&EN=&5R9F%C92P@9F]R8VEN9R!Y;W4@=&\@=7!D871E('1H
M92!(;W)D92!C;VYF:6=U<F%T:6]N(&9I;&5S"FUA;G5A;&QY("AA<R!P97(@
M=&AE($E.4U1!3$Q?(&EN<W1R=6-T:6]N<RDN"@I4:&4@86)O=F4@=VEL;"!N
M;W0@<V5C=7)E('1H92!F:6QE<R!I9B!O=&AE<B!U<V5R)W,@;VX@=&AE('-A
M;64@;6%C:&EN92!C86X*<G5N('-C<FEP=',@87,@=&AE(&%P86-H92!U<V5R
M+B`@268@>6]U(&YE960@=&\@<')O=&5C="!A9V%I;G-T('1H:7,@>6]U"G-H
M;W5L9"!M86ME(&]T:&5R('5S97(G<R!S8W)I<'1S(')U;B!U;F1E<B!T:&5I
M<B!O=VX@86-C;W5N="!W:71H('-O;64*9F%C:6QI='D@<W5C:"!A<R!A<&%C
M:&4G<R!S=65X96,@;6]D=6QE+B`@66]U(&YE960@=&\@=V%T8V@@;W5T(&YO
M="!O;FQY(&9O<@IC9VD@<V-R:7!T<RP@8G5T(&%L<V\@9F]R(&]T:&5R(&UO
M9'5L97,@;&EK92!M;V1?<&AP+"!M;V1?<&5R;"P@;6]D7W!Y=&AO;BP*971C
M+B!T:&%T(&UA>2!B92!I;B!U<V4@;VX@>6]U<B!S97)V97(N"@HN+B!?24Y3
M5$%,3#H@/V8]24Y35$%,3"YH=&UL"@H*4F5S=')I8W1I;F<@=&5S="YP:'`@
M9FEL97,*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"E1H92!@8'1E<W0N
M<&AP8&`@9FEL97,@<')O=FED92!A('=E86QT:"!O9B!I;F9O<FUA=&EO;B!T
M:&%T(&-A;B!B92!U<V5D"F%G86EN<W0@=&AE('-I=&4@8GD@871T86-K97)S
M+B`@3VYE('EO=2!H879E(&-O;F9I<FUE9"!T:&%T(&5V97)Y=&AI;F<@:7,*
M=V]R:VEN9RP@>6]U('-H;W5L9"!D:7-A8FQE(&%C8V5S<R!T;R!T:&4@=&5S
M="YP:'`@9FEL97,N("!9;W4@8V%N(&1O('1H:7,@=FEA"G1H92!W96(@<V5R
M=F5R+"!O<B!V:6$@<WES=&5M(&9I;&4@<&5R;6ES<VEO;G,N("!/;B!A('5N
M:7@@<WES=&5M+"!Y;W4@;6EG:'0*:7-S=64@82!C;VUM86YD('-U8V@@87,Z
M.@H*)"!C:&UO9"!A+7)W>"`O:&]M92]H='1P9"]H=&UL+VAO<F1E+W1E<W0N
M<&AP"B0@8VAM;V0@82UR=W@@+VAO;64O:'1T<&0O:'1M;"]H;W)D92\J+W1E
M<W0N<&AP"@H*4')E=F5N=&EN9R!!<&%C:&4@9G)O;2!S97)V:6YG(&-O;F9I
M9W5R871I;VX@86YD('-O=7)C92!F:6QE<PH]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*
M5&AE($AO<F1E(&-O;F9I9W5R871I;VX@9FEL97,@;6%Y(&-O;G1A:6X@<V5N
M<VET:79E(&1A=&$@*'-U8V@@87,@9&%T86)A<V4*<&%S<W=O<F1S*2!T:&%T
M('-H;W5L9"!N;W0@8F4@<V5R=F5D(&)Y('1H92!W96(@<V5R=F5R+B!/=&AE
M<B!D:7)E8W1O<FEE<PIC;VYT86EN(%!(4"!S;W5R8V4@8V]D92!T:&%T(&ES
M;B=T(&EN=&5N9&5D(&9O<B!V:65W:6YG(&)Y(&5N9"UU<V5R<RX@5&AE"DAO
M<F1E(&=R;W5P(&AA<R!P<F]V:61E9"!@8"YH=&%C8V5S<V!@(&9I;&5S(&EN
M('9A<FEO=7,@9&ER96-T;W)I97,@=&\@:&5L<`IP<F]T96-T('1H97-E(&9I
M;&5S+B`@2&]W979E<BP@=&AA="!D97!E;F1S(&]N('EO=7(@=V5B('-E<G9E
M<B!H;VYO<FEN9PI@8"YH=&%C97-S8&`@9FEL97,@*'=H:6-H(&ES(&$@<&5R
M9F]R;6%N8V4@:&ET+"!A;F0@;6%Y(&YO="!B92!A=F%I;&%B;&4@:6X*86QL
M('=E8B!S97)V97)S*2X*"D%N($%P86-H92!S:71E(&-A;B!A;'-O('!R979E
M;G0@=&AE('=E8B!S97)V97(@9G)O;2!S97)V:6YG('1H97-E"F9I;&5S(&)Y
M(&%D9&EN9R!S96-T:6]N<R!T;R!@8&AT='!D+F-O;F9@8"!S=6-H(&%S('1H
M92!F;VQL;W=I;F<Z.@H*("`@/$1I<F5C=&]R>2`B+VAO;64O:'1T<&0O:'1M
M;"]H;W)D92]C;VYF:6<B/@H@("`@("`@;W)D97(@9&5N>2QA;&QO=PH@("`@
M("`@9&5N>2!F<F]M(&%L;`H@("`\+T1I<F5C=&]R>3X*("`@/$1I<F5C=&]R
M>2`B+VAO;64O:'1T<&0O:'1M;"]H;W)D92]L:6(B/@H@("`@("`@;W)D97(@
M9&5N>2QA;&QO=PH@("`@("`@9&5N>2!F<F]M(&%L;`H@("`\+T1I<F5C=&]R
M>3X*("`@/$1I<F5C=&]R>2`B+VAO;64O:'1T<&0O:'1M;"]H;W)D92]L;V-A
M;&4B/@H@("`@("`@;W)D97(@9&5N>2QA;&QO=PH@("`@("`@9&5N>2!F<F]M
M(&%L;`H@("`\+T1I<F5C=&]R>3X*("`@/$1I<F5C=&]R>2`B+VAO;64O:'1T
M<&0O:'1M;"]H;W)D92]P;R(^"B`@("`@("!O<F1E<B!D96YY+&%L;&]W"B`@
M("`@("!D96YY(&9R;VT@86QL"B`@(#PO1&ER96-T;W)Y/@H@("`\1&ER96-T
M;W)Y("(O:&]M92]H='1P9"]H=&UL+VAO<F1E+W-C<FEP=',B/@H@("`@("`@
M;W)D97(@9&5N>2QA;&QO=PH@("`@("`@9&5N>2!F<F]M(&%L;`H@("`\+T1I
M<F5C=&]R>3X*("`@/$1I<F5C=&]R>2`B+VAO;64O:'1T<&0O:'1M;"]H;W)D
M92]T96UP;&%T97,B/@H@("`@("`@;W)D97(@9&5N>2QA;&QO=PH@("`@("`@
M9&5N>2!F<F]M(&%L;`H@("`\+T1I<F5C=&]R>3X*"E)E<&5A="!T:&ES('!A
M='1E<FX@9F]R(&5A8V@@2&]R9&4@87!P;&EC871I;VXN("!&;W(@97AA;7!L
M92P@9F]R($E-4"!Y;W4*=V]U;&0@=&AE;B!A9&0Z.@H*("`@/$1I<F5C=&]R
M>2`B+VAO;64O:'1T<&0O:'1M;"]H;W)D92]I;7`O8V]N9FEG(CX*("`@("`@
M(&]R9&5R(&1E;GDL86QL;W<*("`@("`@(&1E;GD@9G)O;2!A;&P*("`@/"]$
M:7)E8W1O<GD^"B`@(#Q$:7)E8W1O<GD@(B]H;VUE+VAT='!D+VAT;6PO:&]R
M9&4O:6UP+VQI8B(^"B`@("`@("!O<F1E<B!D96YY+&%L;&]W"B`@("`@("!D
M96YY(&9R;VT@86QL"B`@(#PO1&ER96-T;W)Y/@H@("`\1&ER96-T;W)Y("(O
M:&]M92]H='1P9"]H=&UL+VAO<F1E+VEM<"]L;V-A;&4B/@H@("`@("`@;W)D
M97(@9&5N>2QA;&QO=PH@("`@("`@9&5N>2!F<F]M(&%L;`H@("`\+T1I<F5C
M=&]R>3X*("`@/$1I<F5C=&]R>2`B+VAO;64O:'1T<&0O:'1M;"]H;W)D92]I
M;7`O<&\B/@H@("`@("`@;W)D97(@9&5N>2QA;&QO=PH@("`@("`@9&5N>2!F
M<F]M(&%L;`H@("`\+T1I<F5C=&]R>3X*("`@/$1I<F5C=&]R>2`B+VAO;64O
M:'1T<&0O:'1M;"]H;W)D92]I;7`O<V-R:7!T<R(^"B`@("`@("!O<F1E<B!D
M96YY+&%L;&]W"B`@("`@("!D96YY(&9R;VT@86QL"B`@(#PO1&ER96-T;W)Y
M/@H@("`\1&ER96-T;W)Y("(O:&]M92]H='1P9"]H=&UL+VAO<F1E+VEM<"]T
M96UP;&%T97,B/@H@("`@("`@;W)D97(@9&5N>2QA;&QO=PH@("`@("`@9&5N
M>2!F<F]M(&%L;`H@("`\+T1I<F5C=&]R>3X*"@I3971U<"!S8W)I<'1S"CT]
M/3T]/3T]/3T]/3T*"E1H97)E(&%R92!V87)I;W5S('-C<FEP=',@=7-E('1O
M('-E='5P(&]R(&-O;F9I9W5R92!(;W)D92X@($EF('EO=2!A;&QO=R!O=&AE
M<@IU<V5R<R!O;B!T:&4@=V5B('-E<G9E<B!M86-H:6YE+"!Y;W4@<VAO=6QD
M('!R;W1E8W0@=&AE<V4@9FEL97,@9G)O;2!B96EN9PIA8V-E<W-E9"!B>2!T
M:&5M+B`@3VX@82!U;FEX('-Y<W1E;2P@>6]U(&UI9VAT(')E<W1R:6-T('1H
M97-E(&9I;&5S('1O(')O;W0*86-C97-S(&)Y('5S:6YG('1H92!F;VQL;W=I
M;F<@='EP92!O9B!C;VUM86YD<SHZ"@HD(&-H;W=N("U2(')O;W0@+VAO;64O
M:'1T<&0O:'1M;"]H;W)D92]S8W)I<'1S"B0@8VAO=VX@+5(@<F]O="`O:&]M
M92]H='1P9"]H=&UL+VAO<F1E+RHO<V-R:7!T<PHD(&-H;6]D("U2(&=O+7)W
M>"`O:&]M92]H='1P9"]H=&UL+VAO<F1E+W-C<FEP=',*)"!C:&UO9"`M4B!G
M;RUR=W@@+VAO;64O:'1T<&0O:'1M;"]H;W)D92\J+W-C<FEP=',*"@I5<VEN
M9R!A(&-H<F]O="!W96(@<V5R=F5R('-E='5P"CT]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T*"E5N:7@@=7-E<G,@;6%Y('=A;G0@=&\@8V]N<VED
M97(@=7-I;F<@82!C:')O;W0@96YV:7)O;FUE;G0@9F]R('1H96ER('=E8@IS
M97)V97(N("!(;W<@=&\@9&\@=&AI<R!I<R!B97EO;F0@=&AE('-C;W!E(&]F
M('1H:7,@9&]C=6UE;G0L(&)U="!S=69F:6-I96YT"FEN9F]R;6%T:6]N(&5X
M:7-T<R!O;B!T:&4@=V]R;&0@=VED92!W96(@86YD+V]R(&EN('EO=7(@<V5R
M=F5R(&1O8W5M96YT871I;VX*=&\@8V]M<&QE=&4@=&AI<R!T87-K+@H*"DAI
M9&EN9R!02%`@:6YF;R!F<F]M('1H92!U<V5R"CT]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]"@I9;W4@<VAO=6QD(&-O;G-I9&5R('-E='1I;F<@=&AE
M(&9O;&QO=VEN9R!02%`@=F%R:6%B;&5S(&EN('EO=7(@8&!P:'`N:6YI8&`*
M9FEL92!T;R!P<F5V96YT(&EN9F]R;6%T:6]N(&QE86L@=&\@=&AE('5S97(L
M(&]R(&=L;V)A;"!I;G-E<G1I;VX@8GD@=&AE"G5S97(Z.@H*("`@97AP;W-E
M7W!H<"`]($]F9@H@("!D:7-P;&%Y7V5R<F]R<R`]($]F9@H@("!L;V=?97)R
M;W)S(#T@3VX*("`@<F5G:7-T97)?9VQO8F%L<R`]($]F9@H*66]U('-H;W5L
M9"!A;'-O('-E="!U<"!E<G)O<B!L;V=G:6YG("AU<VEN9R!T:&4@4$A0(&!@
M97)R;W)?;&]G8&`@=F%R:6%B;&4I"G1O(&QO9R!T;R!A(&9I;&4L('-Y<VQO
M9RP@;W(@;W1H97(@;&]G(&1E<W1I;F%T:6]N+@H*"E5S:6YG(&$@<V5C=7)E
M('=E8B!S97)V97(*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*2&]R9&4@
M9&5P96YD<R!O;B!P87-S:6YG('-E;G-I=&EV92!I;F9O<FUA=&EO;B`H<W5C
M:"!A<R!P87-S=V]R9',@86YD('-E<W-I;VX*:6YF;W)M871I;VXI(&)E='=E
M96X@=&AE('=E8B!S97)V97(@86YD('1H92!W96(@8VQI96YT+B`@57-I;F<@
M82!S96-U<F4**%-33"UE;F%B;&5D*2!W96(@<V5R=F5R('=I;&P@:&5L<"!P
M<F]T96-T('1H:7,@:6YF;W)M871I;VX@87,@:70@=')A=F5R<VEN9PIT:&4@
M;F5T=V]R:RX*"@I5<VEN9R!A('-E8W5R92!03U`S+TE-05`@<V5R=F5R"CT]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"DEF('EO=2!A<F4@=7-I
M;F<@82!03U`S+TE-05`@<V5R=F5R('=I=&@@2&]R9&4@*&4N9RX@9F]R(&%U
M=&AE;G1I8V%T:6]N(&]R(&9O<@I)35`I('1H96X@2&]R9&4@:7,@<&%S<VEN
M9R!T:&4@=7-E<B=S(&QO9VEN(&-R961E;G1I86QS(&)E='=E96X@=&AE('=E
M8B!S97)V97(*86YD('1H92!M86EL('-E<G9E<BX*"DEF('EO=7(@=V5B('-E
M<G9E<B!A;F0@24U!4"!S97)V97(@87)E(&]N('1H92!S86UE(&AO<W0L('EO
M=2!C86X@:6YC<F5A<V4*<V5C=7)I='D@8GD@9F]R8VEN9R!A;&P@=')A9F9I
M8R!O=F5R('1H92!L;V]P8F%C:R!O<B!L;V-A;&AO<W0@:6YT97)F86-E('-O
M"G1H870@:70@:7,@;F]T(&5X<&]S960@=&\@>6]U<B!N971W;W)K+@H*26X@
M8V%S97,@=VAE<F4@=&AA="!I<R!N;W0@<&]S<VEB;&4L('=E(')E8V]M;65N
M9"!U<VEN9R!A('-E8W5R92!M86EL"F-O;FYE8W1I;VX@<W5C:"!A<R!)34%0
M+5-33"!O<B!03U`S+5-33"!T;R!E;G-U<F4@=&AA="!P87-S=V]R9',@<F5M
M86EN('-A9F4N"@H*3$1!4"!396-U<FET>0H]/3T]/3T]/3T]/3T]"@I,1$%0
M('-E8W5R:71Y(&ES('-I;6EL87(@=&\@=&AE(&%B;W9E(%!/4#,O24U!4"!S
M97)V97(@<V5C=7)I='D@:7-S=64N("!)9B!Y;W4*87)E('5S:6YG($Q$05`L
M('EO=2!S:&]U;&0@;6%K92!S=7)E('1H870@>6]U(&%R92!N;W0@97AP;W-I
M;F<@;&1A<"!P87-S=V]R9',*;W(@86YY('-E;G-I=&EV92!D871A(&EN('EO
M=7(@3$1!4"!D871A8F%S92X*"@I$871A8F%S92!S;V-K970@<V5C=7)I='D*
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@I)9B!Y;W5R(&1A=&%B87-E("AE
M+F<N($UY4U%,(&]R(%!O<W1G<F5344PI(&ES(&]N('1H92!S86UE(&AO<W0@
M87,@>6]U<B!W96(*<V5R=F5R+"!Y;W4@;6%Y('5S92!U;FEX('-O8VME=',@
M<F%T:&5R('1H86X@=&-P(&-O;FYE8W1I;VYS('1O(&AE;'`@:6UP<F]V90IY
M;W5R('-E8W5R:71Y("AA;F0@<&5R9F]R;6%N8V4I+B`@268@:70@9&]E<VXG
M="!S=7!P;W)T('5N:7@@<V]C:V5T<RP@>6]U(&-A;@IA8VAI979E('-O;64@
M8F5T=&5R('-E8W5R:71Y(&)Y(')E<W1R:6-T:6YG('1H92!T8W`@<W5P<&]R
M="!T;R!T:&4@;&]O<&)A8VL@;W(*;&]C86QH;W-T(&EN=&5R9F%C92X*"DEF
M('1H92!D871A8F%S92!K965P<R!I=',@<V]C:V5T(&9I;&4@*&4N9RX@8&!M
M>7-Q;"YS;V-K8&`I(&EN(&$@9&ER96-T;W)Y"FQI:V4@8&`O=&UP8&`@;W(@
M8&`O=F%R+W1M<&!@+"!Y;W4@<VAO=6QD('-E="!P97)M:7-S:6]N<R!C87)E
M9G5L;'D@=&\@96YS=7)E"G1H870@;&]C86P@=7-E<G,@*&EF('EO=2!H879E
M(&%N>2D@8V%N)W0@9&5L971E('1H92!S;V-K970N("!4:&4@=6YI>"`B<W1I
M8VMY(@IB:70@<VAO=6QD(&%L<F5A9'D@8F4@<V5N="!O;B!T:&4@=&5M<&]R
M87)Y(&1I<F5C=&]R>2!I='-E;&8L(&)U="!Y;W4@86QS;PIN965D('1O(&UA
M:V4@<W5R92!T:&4@<V]C:V5T(&ET<V5L9B!I<VXG="!W<FET86)L92!B>2`B
M;W1H97(B(&]R('5S97)S(&-A;@ID96QE=&4@:70N"@I9;W4@;6EG:'0@8V]N
M<VED97(@;6]V:6YG('1H92!S;V-K970@9FEL92!T;R!A;F]T:&5R(&QO8V%T
M:6]N('-U8V@@87,*8&`O=F%R+W)U;F!@(&]R('1H92!T;W`M;&5V96P@9&ER
M96-T;W)Y(&]F('EO=7(@9&%T86)A<V4@<')O9W)A;2`H92YG+@I@8"]V87(O
M;&EB+VUY<W%L8&`@;W(@8&`O=F%R+VQI8B]P9W-Q;&!@*2X*"@I396YD;6%I
M;"!O<B!33510(&-O;G-I9&5R871I;VYS"CT]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T*"DEN('-O;64@8V%S97,L('EO=2!C86X@:6YC<F5A<V4@
M<V5C=7)I='D@8GD@<V5N9&EN9R!M86EL('9I82!T:&4@;&]C86P*8V]M;6%N
M9"UL:6YE('-E;F1M86EL('!R;V=R86T@;VX@>6]U<B!W96(@<V5R=F5R+"!R
M871H97(@=&AA;B!U<VEN9R!33510+@I(;W=E=F5R+"!T:&5R92!M87D@8F4@
M<F5A<V]N<R!T;R!U<V4@4TU44"!I;G-T96%D+"!S=6-H(&%S(&EF('EO=7(@
M<VUT<"!S97)V97(*9&]E<R!S<&%M(&]R('9I<G5S(&-H96-K:6YG('=H:6-H
M('=O=6QD(&)E('-K:7!P960@=7-I;F<@=&AE(&QO8V%L('-E;F1M86EL"G!R
M;V=R86TN"@H*061D:71I;VYA;"!.;W1E<PH]/3T]/3T]/3T]/3T]/3T]"@I4
M:&ES(&ES(&)Y(&9A<B!N;W0@82!C;VUP;&5T92!S96-U<FET>2!(3U=43RX@
M5&AI<R!I<R!J=7-T(&$@8V]M<&EL960@;&ES="!O9@IW:&%T('!E;W!L92!H
M879E(&-O;G1R:6)U=&5D('-O(&9A<BX@268@>6]U(&AA=F4@=&EP<RP@:61E
M87,L('-U9V=E<W1I;VYS(&]R"F%N>71H:6YG(&5L<V4@=&AA="!Y;W4@=&AI
M;FL@8V]U;&0@:&5L<"!O=&AE<G,@:6X@<V5C=7)I;F<@=&AE:7(@2&]R9&4*
M:6YS=&%L;&%T:6]N+"!P;&5A<V4@;&5T('5S(&MN;W<N"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]D;V-S+U1/1$\`````````````````````````````````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-S(Q`#$P-3$U-#,S-S0S`#`Q-S,P
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@2&]R9&4@1&5V96QO<&UE
M;G0@5$]$3R!,:7-T"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@HZ
M3&%S="!U<&1A=&4Z("`@)$1A=&4Z(#(P,#0O,3(O,3@@,3DZ-3<Z,S(@)`HZ
M4F5V:7-I;VXZ("`@("`@)%)E=FES:6]N.B`Q+C(W("0*.D-O;G1A8W0Z("`@
M("`@(&AO<F1E0&QI<W1S+FAO<F1E+F]R9PH*26X@;F\@<&%R=&EC=6QA<B!O
M<F1E<CH*"BT@*$]P=&EO;F%L;'DI($)U;F1L92!014%2('!A8VMA9V5S('=I
M=&@@=&AE('1A<F)A;&QS+B!':79E;B!A('!A8VMA9V4@;&ES="P*("!M86ME
M+7)E;&5A<V4N<&AP('-H;W5L9"!G970@=&AE('!A8VMA9V5S(&%N9"!U;G!A
M8VL@=&AE;2!I;G1O(&QI8B\@=VAE<F4@=V4*("!I;G-T86QL(&]U<B!O=VX@
M<&%C:V%G97,@86YY=V%Y+B!4;V=E=&AE<B!W:71H('!E87(N:&]R9&4N;W)G
M('1H:7,@<VAO=6QD"B`@;&5A9"!T;R`B;&ET92(@=&%R8F%L;',@;VYL>2!C
M;VYT86EN:6YG(&%P<&QI8V%T:6]N(&-O9&4@86YD(")F=6QL(B!T87)B86QL
M<PH@('1H870@9&]N)W0@;F5E9"!A;GD@97AT97)N86P@9&5P96YC96YC:65S
M(&%N>6UO<F4N"@HM(")B<F]W<V4B(&1R:79E<B!F;W(@5D93('1H870@=7-E
M<R!(;W)D92=S(&)R;W=S92!!4$DN"@HM($-A8VAE('1H92!296=I<W1R>2!O
M8FIE8W0@<V\@=&AA="!F:6QE(&]V97)H96%D(&]F(')E861I;F<@:6X@96YT
M<FEE<R!F<F]M(&$*("!D:7)E8W1O<GD@*')E9VES=')Y+F0I(&ES(&UI=&EG
M871E9"X*"BT@26UP;&5M96YT(&%D;6EN+V1E;&5T955S97(@;65T:&]D<R!I
M;B!A<'!L:6-A=&EO;G,G($%027,@=&\@9&5L971E('5S97(*("!S<&5C:69I
M8R!D871A+@H*+2!!9&0@82`O<V5R=FEC97,O9W)O=7!S+R!S96-T:6]N+B!)
M;F-L=61E('!U8FQI8R!G<F]U<"!H;VUE<&%G97,L(&EN8VQU9&EN9PH@(&%N
M>2!I;F9O<FUA=&EO;B!M87)K960@<'5B;&EC(&9O<B!T:&4@9W)O=7`@*&QE
M="!T:&4@;65M8F5R<R!L:7-T(&)E(&UA<FME9`H@('!U8FQI8R]G<F]U<"!O
M;FQY+V%D;6EN(&]N;'DI+"!A9&0@9W)O=7`@861M:6YI<W1R871O<G,@*&IU
M<W0@82!F;&%G(&9O<@H@('5S97)S*2P@861D('1H92!A8FEL:71Y('1O('-H
M;W<@86QL(&-A;&5N9&%R<R]O=&AE<B!S:&%R97,@=&AA="!A(&=R;W5P(&AA
M<PH@('!E<FUI<W-I;VYS('1O+"!A;&QO=R!C<F5A=&EN9R!A(&YE=R!C86QE
M;F1A<B]P;VQL+V5T8RX@9F]R(&$@9W)O=7`N"@HM($%D9"!T:&4@86)I;&ET
M>2!T;R!B<F5A:R!O=70@1&%T851R964@9W)O=7!?=6ED<R!I;G1O('1H96ER
M(&]W;B!T86)L97,@*&]N90H@('1A8FQE('!E<B!G<F]U<"DN"@HM(%5S92!T
M:&4@9G)E961E<VMT;W`@<VAA<F5D+6UI;64M:6YF;U\@6$U,(&9I;&4@=&\@
M8G5I;&0@;W5R($U)345?36%G:6,@;6%G:6,*("!D871A(&9I;&5S+@H*+2!!
M9&0@<W5P<&]R="!F;W(@=&AE(%-232!A<'!L:6-A=&EO;B!S97)V97(@*&AT
M='`Z+R]W=W<N=FPM<W)M+FYE="\I+@H*+2!!9&0@54D@<W5P<&]R="!F;W(@
M;6]R92!C;VYF:6=U<F%T:6]N(&9I;&5S+@H*+2!3:6YC92!#;VYT96YT+41I
M<W!O<VET:6]N("A21D,@,C$X,RD@:7,@;F]T(&$@35535"!I;7!L96UE;G0L
M(&%L;&]W"B`@:6YD:79I9'5A;"!-24U%(%9I97=E<G,@=&\@86QL;W<@97AP
M;&EC:70@;W9E<G)I9&4@*&DN92X@=&\@875T;R!I;FQI;F4@"B`@9&ES<&QA
M>2!A('!A<G0@:6YS=&5A9"!O9B!R96YD97)I;F<@87,@86X@871T86-H;65N
M="`M('5S969U;"!F;W(@4R]-24U%"B`@96YC<GEP=&5D('!A<G1S+"!F;W(@
M97AA;7!L92DN"@HM(%-H;W<@<VAA<F5D('!R969E<F5N8V5S(&]N(&%L;"!P
M<F5F<R!S=6UM87)Y('-C<F5E;G,@=&\@;6%K92!I=`H@(&5A<VEE<B!F;W(@
M=7-E<B!T;R!F:6YD(&=L;V)A;"!P<F5F97)E;F-E<RX*"@HN+B!?<VAA<F5D
M+6UI;64M:6YF;SH@:'1T<#HO+W=W=RYF<F5E9&5S:W1O<"YO<F<O4V]F='=A
M<F4O<VAA<F5D+6UI;64M:6YF;PH`````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O9&]C<R]44D%.4TQ!5$E/3E,`````````````````````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`Q,C4W,0`Q,#4Q-30S,S<T,P`P,C`T-3<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/0H@2&]R9&4@5')A;G-L871I;VX@1W5I9&4*
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*.DQA<W0@=7!D871E.B`@("1$
M871E.B`R,#`U+S$P+S$X(#$Q.C,S.C,X("0*.E)E=FES:6]N.B`@("`@("12
M979I<VEO;CH@,2XX+C$P+C(@)`HZ075T:&]R.B`@("`@("`@2F]R:7,@0G)A
M86MM86X@/&IB<F%A:VUA;D!Y86AO;RYC;VT^"CI!=71H;W(Z("`@("`@("!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*.D%U=&AO<CH@("`@
M("`@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"CI#;VYT86-T.B`@
M("`@("!H;W)D94!L:7-T<RYH;W)D92YO<F<*"BXN(&-O;G1E;G1S.CH@0V]N
M=&5N=',*"@I'3E4@9V5T=&5X="P@4$A0(&%N9"!(;W)D90H]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/0H*2&]R9&4@=7-E<R!'3E4@9V5T=&5X="!F;W(@
M:6YT97)N871I;VYA;&EZ871I;VX@*&DQ.&XI(&%N9"!L;V-A;&EZ871I;VX*
M*&PQ,&XI+B`@5&AE(&UA;G5A;"!A="!H='1P.B\O=W=W+F=N=2YO<F<O;6%N
M=6%L+V=E='1E>'0O:6YD97@N:'1M;"!I<R!B:6%S960*86=A:6YS="!#(&%N
M9"!U<VEN9R!%;6%C<RX@(%1H:7,@:7,@;6]R92!F;W(@2&]R9&4N"@I4:&5R
M92!I<R!A(&=O;V0@97AP;&%N871I;VX@9F]R(%!(4"!A;F0@9V5T=&5X="!A
M=#H*:'1T<#HO+W=W=RYF87%T<RYC;VTO:VYO=VQE9&=E+6)A<V4O=FEE=RYP
M:'1M;"]A:60O,CDU,R]F:60O-#(R"@I096]P;&4@<V5E;2!T;R!L:6ME(&QE
M87)N:6YG(&9R;VT@97AA;7!L97,@8F5T=&5R+"!S;R!)(&AA=F4@=7-E9"!D
M=71C:`HH;FQ?3DPI(&%S(&%N(&5X86UP;&4@979E<GEW:&5R92X*"E1H97)E
M(&ES(&$@8V]M;6%N9"!L:6YE('1O;VP@=W)I='1E;B!I;B!02%`@9F]R(&-R
M96%T:6YG(&%N9"!M86YA9VEN9PIT<F%N<VQA=&EO;G,@:6X@=&AE(&!@:&]R
M9&4O<&\O8&`@9&ER96-T;W)Y+B`@57-A9V4@:6YS=')U8W1I;VYS(&-A;B!B
M92!F;W5N9`II;B!@8&AO<F1E+W!O+U)%041-16!@(&%S('=E;&P@87,@:6YS
M=')U8W1I;VYS(&]N(&AO=R!T;R!S=&%R="!A;F0@;6%I;G1A:6X*=')A;G-L
M871I;VYS+@H*"E1R86YS;&%T:6]N<R!D;VXG="!W;W)K"CT]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]"@I)9B!A;&P@;W(@<V]M92!T<F%N<VQA=&EO;G,@9&]N
M)W0@=V]R:R!O;B!Y;W5R('-Y<W1E;2P@<&QE87-E(&9O;&QO=R!T:&4@<W1E
M<',*9&5S8W)I8F5D(&)E;&]W+B`@268@>6]U('=A;G0@=&\@87-K(&9O<B!H
M96QP(&5I=&AE<B!O;B!T:&4@8&DQ.&X@;6%I;&EN9PIL:7-T8%\@;W(@;VX@
M8$AO<F1E)W,@8G5G('-Y<W1E;6!?+"!P;&5A<V4@97AP;&%I;B!W:&EC:"!S
M=&5P<R!Y;W4@=')I960@86YD"G=H:6-H(&9A:6QE9"X*"EEO=2!M:6=H="!A
M;'-O(&9I;F0@<V]M92!M;W)E(&EN9F]R;6%T:6]N(&EN('1H92!&05%?+@H*
M4&QE87-E(&YO=&4@=&AA="!$=71C:"`H;FQ?3DPI(&ES(&]N;'D@=7-E9"!A
M<R!A;B!E>&%M<&QE(&AE<F4N("!)9B!Y;W4@:&%V90IP<F]B;&5M<R!W:71H
M(&$@8V5R=&%I;B!T<F%N<VQA=&EO;B!U<V4@=&AI<R!T<F%N<VQA=&EO;B=S
M(&QA;F=U86=E(&-O9&4*:6YS=&5A9"X*"C$N($ES('1H:7,@;&]C86QE("AN
M;%].3"D@:6YS=&%L;&5D(&%T(&%L;#\*"B`@(&!@;&]C86QE("UA8&`@<VAO
M=6QD(&QI<W0@86QL(&QO8V%L97,@:6YS=&%L;&5D(&]N('EO=7(@<WES=&5M
M+@H*("`@3VX@1&5B:6%N(&YO="!A;&P@;&]C86QE<R!M87D@8F4@96YA8FQE
M9"!B>2!D969A=6QT+B`@161I=`H@("!@8"]E=&,O;&]C86QE+F=E;F!@(&%N
M9"!R=6X@8&!L;V-A;&4M9V5N8&`@:68@>6]U(&-H86YG960@=&AE(&QI<W0@
M;V8*("`@96YA8FQE9"!L;V-A;&5S+@H*,BX@1&\@>6]U(&AA=F4@86YY("YM
M;R!F:6QE<S\*"B`@(%5S=6%L;'D@:6X@8&`O=7-R+W-H87)E+VQO8V%L92]@
M8`H@("!E+F<N(&!@+W5S<B]S:&%R92]L;V-A;&4O;FPO3$-?34534T%'15,O
M=&%R+FUO8&`*"C,N($1O97,@9V5T=&5X="!E=F5N('=O<FL_"@H@("!'970@
M82!S=')I;F<@=&\@=')A;G-L871E.CH*"B`@("`@("0@<W1R:6YG<R`O8FEN
M+W1A<B!\(&=R97`@365M;W)Y"B`@("`@($UE;6]R>2!E>&AA=7-T960*("`@
M("`@)"`H3$%.1SUN;%].3#L@3$%.1U5!1T4];FQ?3DP[($Q#7TU%4U-!1T53
M/6YL7TY,.R!G971T97AT('1A<B`B365M;W)Y(&5X:&%U<W1E9"(@*0H@("`@
M("!'96AE=6=E;B!U:71G97!U=`H*-"X@1&]E<R!T:&4@;&]C86P@2&]R9&4@
M9FEL92!W;W)K/PH*("`@07-S=6UI;F<@=&AA="!Y;W4@:&%V92!P=70@=&AE
M('1R86YS;&%T960@2&]R9&4@9FEL92!I;@H@("!@8"]D871A+W=W=R]H;W)D
M92]L;V-A;&4O;FQ?3DPO3$-?34534T%'15,O:&]R9&4N;6]@8#HZ"@H@("`@
M("`D(&5X<&]R="!415A41$]-04E.1$E2/2]D871A+W=W=R]H;W)D92]L;V-A
M;&4*("`@("`@)"`H3$%.1SUN;%].3#L@3$%.1U5!1T4];FQ?3DP[($Q#7TU%
M4U-!1T53/6YL7TY,.R!G971T97AT(&AO<F1E(")-97-S86=E(B`I"B`@("`@
M($)E<FEC:'0*"B`@($-R96%T92!A(&9I;&4@:6X@=&AE(&AO<F1E(&1I<F5C
M=&]R>2P@;&%N9W1E<W0N<&AP.CH*"B`@("`@(#P_<&AP"@H@("`@("!S971L
M;V-A;&4H3$-?34534T%'15,L("=N;%].3"<I.PH@("`@("!P=71E;G8H)TQ!
M3D<];FQ?3DPG*3L*("`@("`@<'5T96YV*"=,04Y'54%'13UN;%].3"<I.PH@
M("`@("`O+R!U<V4@=&AE('1A<B!T97-T+@H@("`@("!E8VAO(&1G971T97AT
M*"=T87(G+"`G365M;W)Y(&5X:&%U<W1E9"<I.PH@("`@("!E8VAO("<\8G(@
M+SXG.PH*("`@("`@+R\@4W!E8VEF>2!L;V-A=&EO;B!O9B!T<F%N<VQA=&EO
M;B!T86)L97,*("`@("`@8FEN9'1E>'1D;VUA:6XH)VAO<F1E)RP@)RXO;&]C
M86QE)RD["@H@("`@("`O+R!#:&]O<V4@9&]M86EN"B`@("`@('1E>'1D;VUA
M:6XH)VAO<F1E)RD["@H@("`@("`O+R!0<FEN="!T:&4@86QR96%D>2!T97-T
M960@;65S<V%G90H@("`@("!E8VAO(%\H(DUE<W-A9V4B*3L*("`@("`@96-H
M;R`G/&)R("\^)SL*"B`@("`@("\O('1H:7,@<VAO=6QD('!R:6YT('1H92!S
M86UE+@H@("`@("!E8VAO(&1G971T97AT*"=H;W)D92<L("=-97-S86=E)RD[
M"@H@("`@("`_/@H*("`@3W5T<'5T('=E8B!B<F]W<V5R.CH*"B`@("`@($=E
M:&5U9V5N('5I=&=E<'5T"B`@("`@($)E<FEC:'0*("`@("`@0F5R:6-H=`H*
M"BXN(%]@:3$X;B!M86EL:6YG(&QI<W1@.B!H='1P.B\O:&]R9&4N;W)G+VUA
M:6PO"BXN(%]@2&]R9&4G<R!B=6<@<WES=&5M8#H@:'1T<#HO+V)U9W,N:&]R
M9&4N;W)G"BXN(%]&05$Z(&AT='`Z+R]H;W)D92YO<F<O9F%Q+PH*"E-O;&%R
M:7,*/3T]/3T]/0H*4VEN8V4@=&AE("YM;R!F:6QE<R!A<F4@8FEN87)Y+"!T
M:&5Y(&%R92!P;&%T9F]R;2!S<&5C:69I8RX@(%EO=2!H879E('1O(')E<G5N
M"FUA:V4@:6X@86QL('!O(&1I<F5C=&]R:65S+@H*3VX@4V]L87)I<R`W+"!Y
M;W4@9&]N)W0@:&%V92!T:&4@8&!087)T:6%L($QO8V%L97,@*%-53E=P;&]C
M*6!@(&%N9`I@8%-U<'!L96UE;G1A<GD@4&%R=&EA;"!,;V-A;&5S("A354Y7
M<&QO8S$I8&`@<&%C:V%G97,@:6YS=&%L;&5D(&EF('EO=2!G970Z.@H*("`@
M)"!,04Y'/6YL7TY,"B`@(&-O=6QD;B=T('-E="!L;V-A;&4@8V]R<F5C=&QY
M"@I/;B!3;VQA<FES(#@L('EO=2!M=7-T(&EN<W1A;&P@=&AE(&QO8V%L('!A
M8VMA9V5S(')E<75I<F5D(&9O<B!T:&4@;&]C86QE<R!Y;W4*9&5S:7)E("AF
M;W(@97AA;7!L92P@>6]U(&UA>2!N965D('1O(&EN<W1A;&P@8&!354Y7=V5U
M;W-@8"!F;W(@5V5S=&5R;@I%=7)O<&5A;B!L;V-A;&5S(&]R(&!@4U5.5VUE
M86]S8&`@9F]R($UI9&1L92!%87-T97)N(&QO8V%L97,I+B`@5&AE('!A8VMA
M9V5S"F%R92!L;V-A=&5D(&]N(%-O9G1W87)E($1I<VL@,2!O9B`R(&EN('1H
M92!D:7)E8W1O<GDZ"F!@<V]L7SA?,3`P,5]S<&%R8R]S,"]3;VQA<FES7S@O
M4')O9'5C=&!@"@I4:&ES(&ES('=H870@:70@<VAO=6QD('-A>3H*"E-O;&%R
M:7,@-SHZ"@H@("`D('!K9VEN9F\@?"!G<F5P('!L;V,*("`@<WES=&5M("`@
M("`@4U5.5W!L;V,@("`@("`@4&%R=&EA;"!,;V-A;&5S"B`@('-Y<W1E;2`@
M("`@(%-53E=P;&]C,2`@("`@(%-U<'!L96UE;G1A<GD@4&%R=&EA;"!,;V-A
M;&5S"@I3;VQA<FES(#@Z.@H*("`@)"!P:V=I;F9O('P@9W)E<"!E=6\*("`@
M<WES=&5M("`@("`@4U5.5V-E=6]S("`@("`@0V5N=')A;"!%=7)O<&4@3U,@
M4W5P<&]R=`H@("!S>7-T96T@("`@("!354Y78V5U;W@@("`@("!#96YT<F%L
M($5U<F]P92`V-"UB:70@3U,@4W5P<&]R=`H@("!S>7-T96T@("`@("!354Y7
M965U;W,@("`@("!%87-T97)N($5U<F]P92!/4R!3=7!P;W)T"B`@('-Y<W1E
M;2`@("`@(%-53E=E975O>"`@("`@($5A<W1E<FX@175R;W!E(#8T+6)I="!/
M4R!3=7!P;W)T"B`@('-Y<W1E;2`@("`@(%-53E=N975O<R`@("`@($YO<G1H
M97)N($5U<F]P92!/4R!3=7!P;W)T"B`@('-Y<W1E;2`@("`@(%-53E=N975O
M>"`@("`@($YO<G1H97)N($5U<F]P92`V-"UB:70@3U,@4W5P<&]R=`H@("!S
M>7-T96T@("`@("!354Y7<V5U;W,@("`@("!3;W5T:&5R;B!%=7)O<&4@3U,@
M4W5P<&]R=`H@("!S>7-T96T@("`@("!354Y7<V5U;W@@("`@("!3;W5T:&5R
M;B!%=7)O<&4@-C0M8FET($]3(%-U<'!O<G0*("`@<WES=&5M("`@("`@4U5.
M5W=E=6]S("`@("`@5V5S=&5R;B!%=7)O<&4@3U,@4W5P<&]R=`H@("!S>7-T
M96T@("`@("!354Y7=V5U;W@@("`@("!797-T97)N($5U<F]P92`V-"UB:70@
M3U,@4W5P<&]R=`H*5&AE('-T=69F(&ES(&EN<W1A;&QE9"!I;B!@8"]U<W(O
M;&EB+VQO8V%L96!@.CH*"B`@("0@;',@+W5S<B]L:6(O;&]C86QE+VYL"B`@
M($Q#7T-/3$Q!5$4@("!,0U]#5%E012`@("`@3$-?34534T%'15,@($Q#7TU/
M3D5405)9("!,0U].54U%4DE#("`@3$-?5$E-12`@("`@(&YL+G-O+C$*"DET
M('=A<R!R97!O<G1E9"!T:&%T('1H92!(5%10('-E<G9E<B!H87,@=&\@8F4@
M;&EN:V5D('1O('1H92!S86UE(&QI8FEN=&PN<V\*9FEL92!A<R!02%`@;VX@
M4V]L87)I<RX@($%L<V\L(&ET(&UA>2!B92!R97%U:7)E9"!T:&%T(&QI8FEN
M=&PN<V\@8F4@;&]A9&5D"F)E9F]R92!L:6)C(&ES(&QO861E9"X@($EF('EO
M=2!A<F4@:&%V:6YG(&-O;F9L:6-T<RP@>6]U(&UA>2!B92!A8FQE('1O(')E
M<VED90IT:&5M(&)Y('-T87)T:6YG(&%P86-H92!W:71H(&]N92!O9B!T:&4@
M9F]L;&]W:6YG(&-O;6UA;F1S.CH*"B`@("0@3$1?4%)%3$]!1#UL:6)I;G1L
M+G-O(&%P86-H96-T;"!S=&%R=`H*"D9R965"4T0*/3T]/3T]/0H*5&\@96YA
M8FQE(%541BTX('-U<'!O<G0@:6X@2&]R9&4L('EO=2!A;'-O(&YE960@551&
M+3@@<W5P<&]R="!I;@I&<F5E0E-$+B`@5&AI<R!I<R!N;W0@:6YS=&%L;&5D
M(&)Y(&1E9F%U;'0L('EO=2!N965D('1O(&EN<W1A;&P@=&AE"F!@=71F.&QO
M8V%L92UW:71H;W5T+7-W:61T:"TP-#`S,3E@8"!P86-K86=E(&]R('!O<G0N
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O9&]C<R]54$=2041)3D<`````
M````````````````````````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,#,P
M-0`Q,#4Q-30S,S<T,P`P,C`P-#<`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/3T]/3T]/3T]/3T]/3T]/3T*(%5P9W)A9&EN
M9R!(;W)D90H]/3T]/3T]/3T]/3T]/3T]/0H*.DQA<W0@=7!D871E.B`@("1$
M871E.B`R,#`V+S`V+S(Y(#$V.C(Y.C`R("0*.E)E=FES:6]N.B`@("`@("12
M979I<VEO;CH@,2XT+C0N,3$@)`HZ0V]N=&%C=#H@("`@("`@:&]R9&5`;&ES
M=',N:&]R9&4N;W)G"@H*5&AE<V4@87)E(&EN<W1R=6-T:6]N<R!T;R!U<&=R
M861E(&9R;VT@96%R;&EE<B!(;W)D92!V97)S:6]N<RX@4&QE87-E(&)A8VMU
M<`IY;W5R(&5X:7-T:6YG(&1A=&$@8F5F;W)E(')U;FYI;F<@86YY(&]F('1H
M92!S=&5P<R!D97-C<FEB960@8F5L;W<N(%EO=2!C86XG=`IU<V4@=&AE('5P
M9&%T960@9&%T82!W:71H('EO=7(@;VQD($AO<F1E('9E<G-I;VX@86YY;6]R
M92X*"D%F=&5R('5P9&%T:6YG('1O(&$@;F5W97(@2&]R9&4@=F5R<VEO;BP@
M;W(@82!N97=E<B!V97)S:6]N(&]F("HJ86YY*BH@2&]R9&4*87!P;&EC871I
M;VXL('EO=2`J*F%L=V%Y<RHJ(&YE960@=&\@=7!D871E("HJ86QL*BH@8V]N
M9FEG=7)A=&EO;B!F:6QE<RX*"@I5<&=R861I;F<@2&]R9&4@9G)O;2`S+C$N
M,2!T;R`S+C$N,@H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/0H*"E-E<W-I;VX@0V]N9FEG=7)A=&EO;@HM+2TM+2TM+2TM+2TM+2TM+2TM
M+2T*"D$@;F5W(&-O;F9I9W5R871I;VX@<V5T=&EN9R!H87,@8F5E;B!A9&1E
M9"!T;R!D:7-A8FQE($=%5"UB87-E9`IS97-S:6]N<RX@($EF('1H:7,@<V5T
M=&EN9R!I<R!E;F%B;&5D+"!S97-S:6]N($E$<R!W:6QL(&]N;'D@8F4@<W1O
M<F5D"FEN('-E<W-I;VX@8V]O:VEE<RP@<F5Q=6ER:6YG('1H92!U<V5R<R!T
M;R!E;F%B;&4@8V]O:VEE<R!I;B!T:&5I<@IB<F]W<V5R(&%N9"!T:&4@8V]O
M:VEE('-E='1I;F=S(&EN($AO<F1E)W,@8V]N9FEG=7)A=&EO;B!T;R!B92!C
M;W)R96-T+@H*57-I;F<@<V5S<VEO;B!C;V]K:65S(&ES(&UU8V@@<V%F97(@
M<VEN8V4@;F\@<V5S<VEO;B!I;F9O<FUA=&EO;B!C86X*8F4@<W1O<F5D(&EN
M(&%N>2!W96(@<V5R=F5R(&]R('!R;WAY(&QO9R!F:6QE<RP@<F5F97)R97(@
M:&5A9&5R<RP*8G)O=W-E<B!C86-H97,L(&]R(&)R;W=S97(@8F]O:VUA<FMS
M+@H*+BX@5V%R;FEN9SHZ(%1H:7,@<V5T=&EN9R!I;B!E;F%B;&5D(&)Y(&1E
M9F%U;'0N"@H*061D:71I;VYA;"!);F1E>&5S(&9O<B!T:&4@4')E9F5R96YC
M92!486)L90HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM"@I/<'1I;VYA;&QY(&5X96-U=&4@=&AE('!R;W9I9&5D(%-13"!S
M8W)I<'0@,C`P-BTP-BTR.5]H;W)D95]P<F5F<U]I;F1E>&5S+G-Q;`IT;R!C
M<F5A=&4@='=O(&%D9&ET:6]N86P@:6YD97AE<R!I;B!T:&4@<')E9F5R96YC
M92!T86)L92P@92YG+CHZ"@H@("!M>7-Q;"`M+75S97(]<F]O="`M+7!A<W-W
M;W)D/3Q->5-13"UR;V]T+7!A<W-W;W)D/B`\9&(@;F%M93X@/"!S8W)I<'1S
M+W5P9W)A9&5S+S(P,#8M,#8M,CE?:&]R9&5?<')E9G-?:6YD97AE<RYS<6P*
M"E1H:7,@:6YC<F5A<V5S(&1A=&%B87-E('!E<F9O<FUA;F-E(&9O<B!S;VUE
M(&1A=&%B87-E('-Y<W1E;7,L(&4N9RX@4&]S=&=R95-13`II9B!Y;W4@:&%V
M92!L87)G92!P<F5F97)E;F-E('1A8FQE<RX*"@I5<&=R861I;F<@2&]R9&4@
M9G)O;2`S+C$@=&\@,RXQ+C$*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]"@H*37E344P@4V5S<VEO;B!(86YD;&5R"BTM+2TM+2TM+2TM+2TM
M+2TM+2TM+0H*5&AE(&UY<W%L('-E<W-I;VX@:&%N9&QE<B!H87,@8F5E;B!I
M;7!R;W9E9"!T;R!C;W)R96-T;'D@;&]C:R!C;VYC=7)R96YT"F%C8V5S<V5S
M('1O('1H92!S86UE('-E<W-I;VXN(%EO=2!N965D('1O('-E="!I;B!T:&4@
M2&]R9&4@8V]N9FEG=7)A=&EO;B!I9@IY;W4@=V%N="!T;R!U<V4@<F]W+6QE
M=F5L(&QO8VMI;F<@86YD('1R86YS86-T:6]N<R!O<B!T86)L92UL979E;`IL
M;V-K:6YG+B!2;W<M;&5V96P@;&]C:VEN9R!A;F0@=')A;G-A8W1I;VYS(&%R
M92!O;FQY('-U<'!O<G1E9"!B>2!S;VUE('1A8FQE"F5N9VEN97,@;&EK92!)
M;FYO1$(L(&%N9"!I<R!R96-O;6UE;F1E9"!F;W(@<V5S<VEO;B!T86)L97,N
M(%1H92!D969A=6QT('1A8FQE"G1Y<&4@9F]R($UY4U%,(&ES($UY25-!32!T
M:&]U9V@L('1H870@;VYL>2!S=7!P;W)T<R!T86)L92UL979E;"!L;V-K:6YG
M+B!)9@IY;W4@=7-E9"!T:&4@4U%,('-C<FEP=',@9G)O;2!(;W)D92`S+C$@
M;W(@96%R;&EE<B!T;R!C<F5A=&4@=&AE('-E<W-I;VX*=&%B;&4L('1H:7,@
M:7,@<')O8F%B;'D@=&AE(&-U<G)E;G0@96YG:6YE(&]F('EO=2!S97-S:6]N
M('1A8FQE+B!)9B!Y;W4@=V%N=`IT;R!C:&%N9V4@=&AE('1A8FQE('1Y<&4@
M=&\@26YN;T1"+"!E>&5C=71E('1H92!F;VQL;W=I;F<@4U%,('-T871E;65N
M=#HZ"@H@("!!3%1%4B!404),12!H;W)D95]S97-S:6]N:&%N9&QE<B!%3D=)
M3D4@/2!);FYO1$(*"@H*57!G<F%D:6YG($AO<F1E(&9R;VT@,RXP+G@@=&\@
M,RXQ+G@*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"@I3
M44P@0F%C:V5N9',*+2TM+2TM+2TM+2TM"@I!(&9E=R!N97<@=&%B;&5S(&AA
M=F4@8F5E;B!A9&1E9"!T;R!(;W)D92X*"D5X96-U=&4@;VYE(&]F('1H92!P
M<F]V:61E9"!344P@<V-R:7!T<R!T;R!U<&1A=&4@>6]U<B!D871A('1O('1H
M92!N97<@2&]R9&4*=F5R<VEO;BP@92YG+CHZ"@H@("!M>7-Q;"`M+75S97(]
M<F]O="`M+7!A<W-W;W)D/3Q->5-13"UR;V]T+7!A<W-W;W)D/B`\9&(@;F%M
M93X@/"!S8W)I<'1S+W5P9W)A9&5S+S,N,%]T;U\S+C$N;7ES<6PN<W%L"@H*
M1W)O=7!S"BTM+2TM+0H*5&AE($AO<F1E7T=R;W5P($%022!U<V5S(&=R;W5P
M($E$<R!I;G-T96%D(&]F(&=R;W5P(&YA;65S('1O(&%V;VED(&%M8FEG=6ET
M>2X*0F4@<W5R92!T;R!U<&1A=&4@86YY(&-U<W1O;2!C;V1E('1H870@=7-E
M<R!(;W)D95]'<F]U<"X*"@I(:7-T;W)Y"BTM+2TM+2T*"E1H92!(;W)D95](
M:7-T;W)Y('-T;W)A9V4@:&%S(&)E96X@;6]V960@;W5T('1O(&$@<V5P87)A
M=&4@9&%T86)A<V4@=&%B;&4@=&\*9')A<W1I8V%L;'D@:6UP<F]V92!P97)F
M;W)M86YC92X*"BXN(%=A<FYI;F<Z.B!-:6=R871I;VX@;V8@=&AE($AO<F1E
M7TAI<W1O<GD@9&%T82!M87D@=&%K92!A('9E<GD@;&]N9R!T:6UE+`H@("`@
M("`@("`@("`@<&]S<VEB;'D@9&%Y<RP@9&5P96YD:6YG(&]N('1H92!N=6UB
M97(@;V8@96YT<FEE<RX@($)E('-U<F4@=&\*("`@("`@("`@("`@(&5X96-U
M=&4@=&AI<R!S8W)I<'0@9G)O;2!A(&QO8V%T:6]N('=H97)E(&ET('=I;&P@
M;F]T(&)E('1I;65D"B`@("`@("`@("`@("!O=70@8GD@9FER97=A;&P@;W(@
M=&5R;6EN86P@=&EM96]U=',N"@I%>&5C=71E('1H92!P<F]V:61E9"!02%`@
M<V-R:7!T('1O(&UI9W)A=&4@>6]U<B!H:7-T;W)I97,@=&\@=&AE(&YE=R!T
M86)L93HZ"@H@("!P:'`@<V-R:7!T<R]U<&=R861E<R]M;W9E7VAI<W1O<GE?
M;W5T7V]F7V1A=&%T<F5E+G!H<`H*"@I5<&=R861I;F<@2&]R9&4@9G)O;2`R
M+G@@=&\@,RXP+G@*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M"@H*0V]N9FEG=7)A=&EO;B!F:6QE<PHM+2TM+2TM+2TM+2TM+2TM+2TM"@I4
M:&4@8V]N9FEG=7)A=&EO;B!F:6QE<R!H879E(&)E96X@8VAA;F=E9"!T;R!8
M34P@9F]R;6%T+B`@5&\@9V5N97)A=&4@82!V86QI9`IC;VYF:6=U<F%T:6]N
M(&9I;&4@9G)O;2!T:&4@6$U,(&9I;&4L(&9O;&QO=R!T:&4@8V]N9FEG=7)A
M=&EO;B!I;G-T<G5C=&EO;G,*:6X@=&AE(&%P<&QI8V%T:6]N<R<@8&!D;V-S
M+TE.4U1!3$Q@8"!F:6QE+@H*"E!R969E<F5N8V5S"BTM+2TM+2TM+2TM"@I4
M:&4@8&!L87-T7VQO9VEN8&`@86YD(&!@9&%T95]F;W)M871@8"!P<F5F97)E
M;F-E<R!H879E(&-H86YG960@=&AE:7(@9F]R;6%T"F%N9"]O<B!S8V]P92X@
M($IU<W0@<F5M;W9E(&%L;"!@8&QA<W1?;&]G:6Y@8"!A;F0@8&!D871E7V9O
M<FUA=&!@('!R969E<F5N8V5S"F9R;VT@=&AE('!R969E<F5N8V5S(&)A8VME
M;F0N"@H*4U%,($)A8VME;F1S"BTM+2TM+2TM+2TM+0H*02!F97<@;F5W('1A
M8FQE<R!H879E(&)E96X@861D960@=&\@2&]R9&4N"@I%>&5C=71E('1H92!P
M<F]V:61E9"!344P@<V-R:7!T('1O('5P9&%T92!Y;W5R(&1A=&$@=&\@=&AE
M(&YE=R!(;W)D92!V97)S:6]N.CH*"B`@(&UY<W%L("TM=7-E<CUR;V]T("TM
M<&%S<W=O<F0]/$UY4U%,+7)O;W0M<&%S<W=O<F0^(#QD8B!N86UE/B`\('-C
M<FEP=',O=7!G<F%D97,O,BXR7W1O7S,N,"YM>7-Q;"YS<6P*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]I;F1E>"YP:'``````````````````````````
M````````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W,3<U`#$P-3$U-#,S
M-S0T`#`Q-S4Q,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]I;F1E>"YP:'`L
M=B`R+C$P-2XT+C@@,C`P-B\P-R\R.2`Q-CHT.3HQ.2!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:&%R;&5S($HN($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!0
M87)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F
M:6YE*"=!551(7TA!3D1,15(G+"!T<G5E*3L*0&1E9FEN92@G2$]21$5?0D%3
M12<L(&1I<FYA;64H7U]&24Q%7U\I*3L*)&AO<F1E7V-O;F9I9W5R960@/2`H
M0&9I;&5?97AI<W1S*$A/4D1%7T)!4T4@+B`G+V-O;F9I9R]C;VYF+G!H<"<I
M("8F"B`@("`@("`@("`@("`@("`@("`@($!F:6QE7V5X:7-T<RA(3U)$15]"
M05-%("X@)R]C;VYF:6<O;6EM95]D<FEV97)S+G!H<"<I("8F"B`@("`@("`@
M("`@("`@("`@("`@($!F:6QE7V5X:7-T<RA(3U)$15]"05-%("X@)R]C;VYF
M:6<O;FQS+G!H<"<I("8F"B`@("`@("`@("`@("`@("`@("`@($!F:6QE7V5X
M:7-T<RA(3U)$15]"05-%("X@)R]C;VYF:6<O<')E9G,N<&AP)RD@)B8*("`@
M("`@("`@("`@("`@("`@("`@0&9I;&5?97AI<W1S*$A/4D1%7T)!4T4@+B`G
M+V-O;F9I9R]R96=I<W1R>2YP:'`G*2D["@II9B`H(21H;W)D95]C;VYF:6=U
M<F5D*2!["B`@("!R97%U:7)E($A/4D1%7T)!4T4@+B`G+VQI8B]497-T+G!H
M<"<["B`@("!(;W)D95]497-T.CIC;VYF:6=&:6QE<TUI<W-I;F<H)TAO<F1E
M)RP@2$]21$5?0D%312P@)W!R969S+G!H<"<L"B`@("`@("`@87)R87DH)V-O
M;F8N<&AP)R`]/B`G5&AI<R!I<R!T:&4@;6%I;B!(;W)D92!C;VYF:6=U<F%T
M:6]N(&9I;&4N($ET(&-O;G1A:6YS('!A=&AS(&%N9"!B87-I8R!I=&5M<R!T
M:&%T(&%P<&QY('1O('1H92!C;W)E(&9R86UE=V]R:R!A;F0@86QL($AO<F1E
M(&%P<&QI8V%T:6]N<RXG+`H@("`@("`@("`@("`@("=M:6UE7V1R:79E<G,N
M<&AP)R`]/B`G5&AI<R!F:6QE(&-O;G1R;VQS('1H92!G;&]B86P@<V5T(&]F
M($U)344@9')I=F5R<R!F;W(@=&AE($AO<F1E(&9R86UE=V]R:RP@86QL;W=I
M;F<@87!P;&EC871I;VYS('1O(&UA:V4@=7-E(&]F('!R;V=R86US('-U8V@@
M87,@96YS8W)I<'0@;W(@;7-W;W)D=FEE=R!T;R!R96YD97(@8V]N=&5N="!I
M;G1O($A434P@9F]R('9I97=I;F<@:6X@82!B<F]W<V5R+B<L"B`@("`@("`@
M("`@("`@)VYL<RYP:'`G(#T^("=4:&ES(&9I;&4@<')O=FED97,@;&]C86QI
M<V%T:6]N('-U<'!O<G0@9F]R('1H92!(;W)D92!F<F%M97=O<FLN)RP*("`@
M("`@("`@("`@("`G<F5G:7-T<GDN<&AP)R`]/B`G5&AE(')E9VES=')Y(&ES
M(&AO=R!(;W)D92!A<'!L:6-A=&EO;G,@9FEN9"!O=70@:&]W('1O('1A;&L@
M=&\@96%C:"!O=&AE<BX@66]U('-H;W5L9"!L:7-T(&%N>2!I;G-T86QL960@
M2&]R9&4@87!P;&EC871I;VYS('1H870@>6]U(&AA=F4@:&5R92XG*2D["GT*
M"G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PH*
M:68@*"1B<F]W<V5R+3YI<TUO8FEL92@I*2!["B`@("!R97%U:7)E($A/4D1%
M7T)!4T4@+B`G+W-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP)SL*("`@(&5X
M:70["GT*"B1M86EN7W!A9V4@/2!5=&EL.CIG971&;W)M1&%T82@G=7)L)RD[
M"@HO+R!"<F5A:R!U<"!T:&4@<F5Q=65S=&5D(%523"!I;B`D;6%I;E]P86=E
M(&%N9"!R=6X@<V]M92!S86YI='D@8VAE8VMS"B\O(&]N(&ET('1O('!R979E
M;G0@<&AI<VAI;F<@86YD(%A34R!A='1A8VMS+B!)9B!A;GD@;V8@=&AE(&-H
M96-K<PHO+R!F86EL+"`D;6%I;E]P86=E('=I;&P@8F4@<V5T('1O(&YU;&PN
M"FEF("@A96UP='DH)&UA:6Y?<&%G92DI('L*("`@("\O($UU=&4@97)R;W)S
M(&EN(&-A<V4@;V8@=6YP87)S96%B;&4@55),<PH@("`@)')E<2`]($!P87)S
M95]U<FPH)&UA:6Y?<&%G92D["@H@("`@+R\@5V4@87-S=6UE('1H870@86YY
M('9A;&ED(')E9&ER96-T(%523"!W:6QL(&)E(&EN('1H92!S86UE"B`@("`O
M+R!C;V]K:64@9&]M86EN+B!4:&ES(&AE;'!S('!R979E;G0@<F]G=64@;V9F
M+7-I=&4@2&]R9&4@:6YS=&%L;',*("`@("\O(&9R;VT@;6EM:6-K:6YG('1H
M92!R96%L('-E<G9E<BX*("`@(&EF("AI<W-E="@D<F5Q6R=H;W-T)UTI*2![
M"B`@("`@("`@)'%C;V]K:65D;VT@/2!P<F5G7W%U;W1E*"1C;VYF6R=C;V]K
M:64G75LG9&]M86EN)UTI.PH@("`@("`@(&EF("@A<')E9U]M871C:"@G+R<@
M+B`D<6-O;VMI961O;2`N("<D+R<L("1R97%;)VAO<W0G72DI('L*("`@("`@
M("`@("`@)&UA:6Y?<&%G92`](&YU;&P["B`@("`@("`@?0H@("`@?0H*("`@
M("\O(%!R;W1O8V]L('=H:71E;&ES=#H@268@=&AE(%523"!I<R!F=6QL>2!Q
M=6%L:69I960L(&UA:V4@<W5R92!I=`H@("`@+R\@:7,@96ET:&5R(&AT='`@
M;W(@:'1T<',N"B`@("`D86QL;W=E9%]P<F]T;V-O;',@/2!A<G)A>2@G:'1T
M<"<L("=H='1P<R<I.PH@("`@:68@*&5M<'1Y*"1R97%;)W-C:&5M92==*2!\
M?`H@("`@("`@("%I;E]A<G)A>2@D<F5Q6R=S8VAE;64G72P@)&%L;&]W961?
M<')O=&]C;VQS*2D@>PH@("`@("`@("1M86EN7W!A9V4@/2!N=6QL.PH@("`@
M?0I]"@II9B`H(21M86EN7W!A9V4I('L*("`@("1I;FET:6%L7V%P<"`]("1P
M<F5F<RT^9V5T5F%L=64H)VEN:71I86Q?87!P;&EC871I;VXG*3L*("`@(&EF
M("@A96UP='DH)&EN:71I86Q?87!P*2`F)B`D<F5G:7-T<GDM/FAA<U!E<FUI
M<W-I;VXH)&EN:71I86Q?87!P*2D@>PH@("`@("`@("1M86EN7W!A9V4@/2!(
M;W)D93HZ=7)L*"1R96=I<W1R>2T^9V5T26YI=&EA;%!A9V4H)&EN:71I86Q?
M87!P*2P@=')U92D["B`@("!](&5L<V5I9B`H:7-S970H)')E9VES=')Y+3YA
M<'!L:6-A=&EO;G-;)VAO<F1E)UU;)VEN:71I86Q?<&%G92==*2D@>PH@("`@
M("`@("1M86EN7W!A9V4@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH)')E9VES
M=')Y+3YA<'!L:6-A=&EO;G-;)VAO<F1E)UU;)VEN:71I86Q?<&%G92==+"!T
M<G5E*3L*("`@('T@96QS96EF("A!=71H.CIG971!=71H*"DI('L*("`@("`@
M("`D;6%I;E]P86=E(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=S97)V:6-E
M<R]P;W)T86PO)RP@=')U92D["B`@("!](&5L<V4@>PH@("`@("`@("1M86EN
M7W!A9V4@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH)VQO9VEN+G!H<"<L('1R
M=64I.PH@("`@?0I]"@II9B`H(55T:6PZ.F=E=$9O<FU$871A*"=F<F%M97-E
M=%]L;V%D960G*2`F)@H@("`@*"1C;VYF6R=M96YU)UU;)V%L=V%Y<R==('Q\
M"B`@("`@*$%U=&@Z.F=E=$%U=&@H*2`F)B`D<')E9G,M/F=E=%9A;'5E*"=S
M:&]W7W-I9&5B87(G*2DI*2!["B`@("!I9B`H)&)R;W=S97(M/FAA<U%U:7)K
M*"=S8W)O;&QB87)?:6Y?=V%Y)RDI('L*("`@("`@("`D<V-R;VQL8F%R(#T@
M)WEE<R<["B`@("!](&5L<V4@>PH@("`@("`@("1S8W)O;&QB87(@/2`G875T
M;R<["B`@("!]"B`@("!R97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O:6YD
M97@O9G)A;65S7VEN9&5X+FEN8R<["GT@96QS92!["B`@("!H96%D97(H)TQO
M8V%T:6]N.B`G("X@)&UA:6Y?<&%G92D["GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]J<R\`````````
M````````````````````````````````````````````````````````````
M`````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-3$U-#,S-S0T`#`Q-C(W,@`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VIS+V%D9$5V96YT+G!H<```````````````````````````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(V-#(`,3`U,34T,S,W-#0`,#(P-30Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"\J
M*@H@*B!'96YE<FEC(&9U;F-T:6]N('1O(&%D9"!A;B!E=F5N="!H86YD;&5R
M('1O(&%N>2!$3TT@96QE;65N="X*("H*("H@)$AO<F1E.B!H;W)D92]J<R]A
M9&1%=F5N="YP:'`L=B`Q+C$N,BXR(#(P,#8O,#$O,#$@,C$Z,CDZ,#(@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"B\J*@H@
M*B!!9&1S('1H92!G:79E;B!E=F5N="!T;R!A;B!E;&5M96YT+B!)9B!T:&4@
M96QE;65N="!A;')E861Y(&AA<PH@*B!H86YD;&5R<R!F;W(@=&AE(&5V96YT
M+"!T:&4@;F5W(&5V96YT(&ES(&%P<&5N9&5D+@H@*@H@*B!`<&%R86T@;V)J
M96-T(&5L96UE;G0@("!4:&4@96QE;65N="!T;R!A9&0@=&AE(&5V96YT('1O
M+@H@*B!`<&%R86T@<W1R:6YG(&5V96YT("`@("!4:&4@;F%M92!O9B!T:&4@
M979E;G0N"B`J($!P87)A;2!S=')I;F=\9G5N8W1I;VX@9G5N8W1I;VX@(%1H
M92!J879A<V-R:7!T('1O(&5X96-U=&4N"B`J+PIF=6YC=&EO;B!A9&1%=F5N
M="AE;&5M96YT+"!E=F5N="P@8V]D92D*>PH@("`@:68@*"%E;&5M96YT*2![
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\O($%S<VEG;B!N
M97<@86YO;GEM;W5S(&9U;F-T:6]N(&EF('=E)W)E('!A<W-E9"!A(&IS('-T
M<FEN9PH@("`@+R\@:6YS=&5A9"!O9B!A(&9U;F-T:6]N(')E9F5R96YC92X*
M("`@(&EF("AT>7!E;V8@8V]D92`]/2`G<W1R:6YG)RD@>PH@("`@("`@(&-O
M9&4@/2!N97<@1G5N8W1I;VXH8V]D92D["B`@("!]"@H@("`@:68@*&5L96UE
M;G0N861D179E;G1,:7-T96YE<BD@>PH@("`@("`@(&5L96UE;G0N861D179E
M;G1,:7-T96YE<BAE=F5N="YR97!L86-E*"]O;B\L("<G*2P@8V]D92P@9F%L
M<V4I.PH@("`@?2!E;'-E(&EF("AE;&5M96YT+F%T=&%C:$5V96YT*2!["B`@
M("`@("`@96QE;65N="YA='1A8VA%=F5N="AE=F5N="P@8V]D92D["B`@("!]
M(&5L<V4@:68@*&5L96UE;G0N;VYL;V%D("$](&YU;&PI('L*("`@("`@("!E
M=F%L*"=V87(@3VQD179E;G0@/2!E;&5M96YT+B<@*R!E=F5N="D["B`@("`@
M("`@;F5W0V]D92`]($9U;F-T:6]N*&4I"B`@("`@("`@>PH@("`@("`@("`@
M("!O;&1%=F5N="AE*3L*("`@("`@("`@("`@8V]D92@I.PH@("`@("`@('T[
M"B`@("`@("`@979A;"@G96QE;65N="XG("L@979E;G0@*R`G(#T@;F5W0V]D
M92<I.PH@("`@?2!E;'-E('L*("`@("`@("!E=F%L*"=E;&5M96YT+B<@*R!E
M=F5N="`K("<@/2!C;V1E)RD["B`@("!]"@H@("`@<F5T=7)N('1R=64["GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O86QP:&%);6%G94QO
M861E<BYP:'``````````````````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,C<W-P`Q,#4Q-30S,S<T-``P,C(Q-S<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R
M9&4O:G,O86QP:&%);6%G94QO861E<BYP:'`L=B`Q+C(N."XT(#(P,#8O,#$O
M,#$@,C$Z,CDZ,#(@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P
M,#8@0VAA<FQE<R!*+B!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H
M7U]&24Q%7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N
M("<O;&EB+V-O<F4N<&AP)SL*"B1R96=I<W1R>2`]("9296=I<W1R>3HZ<VEN
M9VQE=&]N*$A/4D1%7U-%4U-)3TY?3D].12D["@HO*B!4:&ES('-H;W5L9"!B
M92!C86-H960N("HO"B1M;V1?9VUT(#T@9VUD871E*"=$+"!D($T@62!(.FDZ
M<R<L(&9I;&5M=&EM92A?7T9)3$5?7RDI("X@)R!'350G.PIH96%D97(H)TQA
M<W0M36]D:69I960Z("<@+B`D;6]D7V=M="D["FAE861E<B@G0V%C:&4M0V]N
M=')O;#H@<'5B;&EC+"!M87@M86=E/3@V-#`P)RD["FAE861E<B@G0V]N=&5N
M="U4>7!E.B!T97AT+W@M8V]M<&]N96YT)RD["@H_/@H\<'5B;&EC.F-O;7!O
M;F5N=#X*/'!U8FQI8SIA='1A8V@@979E;G0](F]N<')O<&5R='EC:&%N9V4B
M(&9O<CTB96QE;65N="(@;VY%=F5N=#TB<')O<&5R='E#:&%N9V5D*"DB("\^
M"CQS8W)I<'0^"@IV87(@=')A;G-P87)E;G1);6%G92`]("(\/W!H<"!E8VAO
M("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RD@/SXO8FQA;FLN9VEF
M(CL*"G!N9TAA8VLH*3L*"F9U;F-T:6]N('!R;W!E<G1Y0VAA;F=E9"@I"GL*
M("`@(&EF("AE=F5N="YP<F]P97)T>4YA;64@/3T@(G-R8R(I('L*("`@("`@
M("!P;F=(86-K*"D["B`@("!]"GT*"F9U;F-T:6]N('!N9TAA8VLH*0I["B`@
M("!V87(@=R`](&5L96UE;G0N=VED=&@["B`@("!V87(@:"`](&5L96UE;G0N
M:&5I9VAT.PH@("`@=F%R('-R8R`](&5L96UE;G0N<W)C.PH@("`@:68@*'-R
M8RYI;F1E>$]F*'1R86YS<&%R96YT26UA9V4I("$]("TQ*2!["B`@("`@("`@
M+R\@06QR96%D>2!F:7AE9"X*("`@("`@("!R971U<FX["B`@("!]"@H@("`@
M:68@*'-R8RYI;F1E>$]F*")P;F<B*2`]/2`M,2D@>PH@("`@("`@(&5L96UE
M;G0N<G5N=&EM95-T>6QE+F9I;'1E<B`]("(B.PH@("`@("`@(')E='5R;CL*
M("`@('T*"B`@("!E;&5M96YT+G-R8R`]('1R86YS<&%R96YT26UA9V4["B`@
M("!E;&5M96YT+G=I9'1H(#T@=SL*("`@(&5L96UE;G0N:&5I9VAT(#T@:#L*
M("`@(&5L96UE;G0N<G5N=&EM95-T>6QE+F9I;'1E<B`](")P<F]G:60Z1%A)
M;6%G951R86YS9F]R;2Y-:6-R;W-O9G0N06QP:&%);6%G94QO861E<BAS<F,]
M)R(@*R!S<F,@*R`B)RQS:7II;F=-971H;V0])W-C86QE)RDB.PI]"@H\+W-C
M<FEP=#X*/"]P=6)L:6,Z8V]M<&]N96YT/@H`+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]J<R]E;G1E<E]K97E?=')A<"YJ<P``````````````````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#`W`#$P-3$U-#,S-S0T`#`R,38T
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````O
M*BH*("H@2F%V87-C<FEP="!T;R!T<F%P(&9O<B!T:&4@96YT97(@:V5Y+@H@
M*@H@*B`D2&]R9&4Z(&AO<F1E+VIS+V5N=&5R7VME>5]T<F%P+FIS+'8@,2XR
M+C$P+C,@,C`P-B\P-2\P-2`Q-3HS,SHS-"!C:'5C:R!%>'`@)`H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("HO"F9U;F-T:6]N(&5N=&5R7VME>5]T<F%P*&5V96YT*0I["B`@
M("!V87(@:V5Y.PH@("`@:68@*&5V96YT+FME>4-O9&4I('L*("`@("`@("!K
M97D@/2!E=F5N="YK97E#;V1E.PH@("`@?2!E;'-E(&EF("AE=F5N="YW:&EC
M:"D@>PH@("`@("`@(&ME>2`](&5V96YT+G=H:6-H.PH@("`@?2!E;'-E('L*
M("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@<F5T=7)N("AK97D@
M/3T@,3`@?'P@:V5Y(#T](#$S*3L*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]J<R]F;W)M7V%S<VEG;BYJ<P``````````````````
M`````````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T,3,P`#$P-3$U-#,S-S0T
M`#`R,3$S-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````O*BH*("H@2&]R9&4@1F]R;2!!<W-I9VX@1FEE;&0@2F%V87-C<FEP
M="!#;&%S<PH@*@H@*B!0<F]V:61E<R!T:&4@:F%V87-C<FEP="!C;&%S<R!T
M;R!A8V-O;7!A;GD@=&AE($AO<F1E7T9O<FT@87-S:6=N(&9I96QD+@H@*@H@
M*B`D2&]R9&4Z(&AO<F1E+VIS+V9O<FU?87-S:6=N+FIS+'8@,2XR+C$P+C0@
M,C`P-B\P,R\R-"`P-3HQ-SHU.2!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P-"TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("HO"@I(;W)D95]&;W)M7T%S<VEG;B`](&YE=R!/8FIE
M8W0H*3L*"DAO<F1E7T9O<FU?07-S:6=N+F1E<V5L96-T2&5A9&5R<R`](&9U
M;F-T:6]N*&YA;64L('-I9&4I"GL*("`@(&EF("AS:61E*2!["B`@("`@("`@
M9&]C=6UE;G1;;F%M92`K("=?7W)I9VAT)UU;,%TN<V5L96-T960@/2!F86QS
M93L*("`@('T@96QS92!["B`@("`@("`@9&]C=6UE;G1;;F%M92`K("=?7VQE
M9G0G75LP72YS96QE8W1E9"`](&9A;'-E.PH@("`@?0I]"@I(;W)D95]&;W)M
M7T%S<VEG;BYM;W9E(#T@9G5N8W1I;VXH;F%M92P@9&ER96-T:6]N*0I["B`@
M("!V87(@;&5F="`](&1O8W5M96YT6VYA;64@*R`G7U]L969T)UT["B`@("!V
M87(@<FEG:'0@/2!D;V-U;65N=%MN86UE("L@)U]?<FEG:'0G73L*"B`@("!I
M9B`H9&ER96-T:6]N*2!["B`@("`@("`@=F%R(&9R;VT@/2!R:6=H=#L*("`@
M("`@("!V87(@=&\@/2!L969T.PH@("`@?2!E;'-E('L*("`@("`@("!V87(@
M9G)O;2`](&QE9G0["B`@("`@("`@=F%R('1O(#T@<FEG:'0["B`@("!]"@H@
M("`@9F]R("AV87(@:2`](#`[(&D@/"!F<F]M+FQE;F=T:#L@*RMI*2!["B`@
M("`@("`@:68@*&9R;VU;:5TN<V5L96-T960I('L*("`@("`@("`@("`@=&];
M=&\N;&5N9W1H72`](&YE=R!/<'1I;VXH9G)O;5MI72YT97AT+"!F<F]M6VE=
M+G9A;'5E*3L*("`@("`@("`@("`@=&];=&\N;&5N9W1H("T@,5TN;VYD8FQC
M;&EC:R`](&9U;F-T:6]N*"D*("`@("`@("`@("`@>PH@("`@("`@("`@("`@
M("`@2&]R9&5?1F]R;5]!<W-I9VXN;6]V92AN86UE+"`Q("T@9&ER96-T:6]N
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!F<F]M6VE=(#T@;G5L;#L*
M("`@("`@("`@("`@+2UI.PH@("`@("`@('T*("`@('T*"B`@("!T:&ES+G-E
M=$9I96QD*&YA;64I.PI]"@I(;W)D95]&;W)M7T%S<VEG;BYS971&:65L9"`]
M(&9U;F-T:6]N*&YA;64I"GL*("`@('9A<B!L969T(#T@9&]C=6UE;G1;;F%M
M92`K("=?7VQE9G0G73L*("`@('9A<B!R:6=H="`](&1O8W5M96YT6VYA;64@
M*R`G7U]R:6=H="==.PH*("`@('9A<B!V86QU97,@/2`G)SL*("`@('9A<B!H
M:70@/2!F86QS93L*("`@(&9O<B`H=F%R(&D@/2`P.R!I(#P@;&5F="YO<'1I
M;VYS+FQE;F=T:#L@*RMI*2!["B`@("`@("`@:68@*&D@/3T@,"`F)B`A;&5F
M=%MI72YV86QU92D@>PH@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("!]
M"B`@("`@("`@=F%L=65S("L](&QE9G0N;W!T:6]N<UMI72YV86QU92`K("=<
M="<["B`@("`@("`@:&ET(#T@=')U93L*("`@('T*("`@(&EF("AH:70I('L*
M("`@("`@("!V86QU97,@/2!V86QU97,N<W5B<W1R:6YG*#`L('9A;'5E<RYL
M96YG=&@@+2`Q*3L*("`@('T*("`@('9A;'5E<R`K/2`G7'1<="<["B`@("!H
M:70@/2!F86QS93L*("`@(&9O<B`H=F%R(&D@/2`P.R!I(#P@<FEG:'0N;W!T
M:6]N<RYL96YG=&@[("LK:2D@>PH@("`@("`@(&EF("AI(#T](#`@)B8@(7)I
M9VAT6VE=+G9A;'5E*2!["B`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@
M('T*("`@("`@("!V86QU97,@*ST@<FEG:'0N;W!T:6]N<UMI72YV86QU92`K
M("=<="<["B`@("`@("`@:&ET(#T@=')U93L*("`@('T*("`@(&EF("AH:70I
M('L*("`@("`@("!V86QU97,@/2!V86QU97,N<W5B<W1R:6YG*#`L('9A;'5E
M<RYL96YG=&@@+2`Q*3L*("`@('T*("`@(&1O8W5M96YT6VYA;64@*R`G7U]V
M86QU97,G72YV86QU92`]('9A;'5E<SL*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]J<R]F;W)M7VAE;'!E<G,N:G,`
M````````````````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q-34T
M`#$P-3$U-#,S-S0T`#`R,3,R,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````O*BH*("H@2F%V87-C<FEP="!T;R!A9&0@979E
M;G1S('1O(&9O<FT@96QE;65N=',*("H*("H@)$AO<F1E.B!H;W)D92]J<R]F
M;W)M7VAE;'!E<G,N:G,L=B`Q+C,N-"XV(#(P,#8O,#,O,C0@,#4Z,3<Z-3D@
M8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!-871T($MY
M;F%S=&]N(#QM871T0&MY;G@N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@HO*BH*
M("H@061D<R!T:&4@9VEV96X@979E;G0@=&\@86X@96QE;65N="X@268@=&AE
M(&5L96UE;G0@86QR96%D>2!H87,*("H@<V-R:7!T(&9O<B!T:&4@979E;G0L
M('1H92!N97<@979E;G0@:7,@87!P96YD960N"B`J"B`J($!P87)A;2!O8FIE
M8W0@96QE;65N="`@(%1H92!E;&5M96YT('1O(&%D9"!T:&4@979E;G0@=&\N
M"B`J($!P87)A;2!S=')I;F<@979E;G0@("`@(%1H92!N86UE(&]F('1H92!E
M=F5N="X*("H@0'!A<F%M('-T<FEN9WQF=6YC=&EO;B!F=6YC=&EO;B`@5&AE
M(&IA=F%S8W)I<'0@=&\@97AE8W5T92X*("HO"F9U;F-T:6]N(&%D9$5V96YT
M*&5L96UE;G0L(&5V96YT+"!C;V1E*0I["B`@("!I9B`H(65L96UE;G0I('L*
M("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+R\@07-S:6=N(&YE
M=R!A;F]N>6UO=7,@9G5N8W1I;VX@:68@=V4G<F4@<&%S<V5D(&$@:G,@<W1R
M:6YG"B`@("`O+R!I;G-T96%D(&]F(&$@9G5N8W1I;VX@<F5F97)E;F-E+@H@
M("`@:68@*'1Y<&5O9B!C;V1E(#T]("=S=')I;F<G*2!["B`@("`@("`@8V]D
M92`](&YE=R!&=6YC=&EO;BAC;V1E*3L*("`@('T*"B`@("!I9B`H96QE;65N
M="YA9&1%=F5N=$QI<W1E;F5R*2!["B`@("`@("`@96QE;65N="YA9&1%=F5N
M=$QI<W1E;F5R*&5V96YT+G)E<&QA8V4H+V]N+RP@)R<I+"!C;V1E+"!F86QS
M92D["B`@("!](&5L<V4@:68@*&5L96UE;G0N871T86-H179E;G0I('L*("`@
M("`@("!E;&5M96YT+F%T=&%C:$5V96YT*&5V96YT+"!C;V1E*3L*("`@('T@
M96QS92!I9B`H96QE;65N="YO;FQO860@(3T@;G5L;"D@>PH@("`@("`@('9A
M<B!/;&1%=F5N="`](&5L96UE;G1;979E;G1=.PH@("`@("`@(&YE=T-O9&4@
M/2!&=6YC=&EO;BAE*0H@("`@("`@('L*("`@("`@("`@("`@;VQD179E;G0H
M92D["B`@("`@("`@("`@(&-O9&4H*3L*("`@("`@("!].PH@("`@("`@(&5L
M96UE;G1;979E;G1=(#T@;F5W0V]D93L*("`@('T@96QS92!["B`@("`@("`@
M96QE;65N=%ME=F5N=%T@/2!C;V1E.PH@("`@?0H*("`@(')E='5R;B!T<G5E
M.PI]"@HO*BH*("H@4F5T=7)N<R!G:79E;B!V86QU92!A<R!A(&YU;6)E<BP@
M;W(@>F5R;R!I9B!.84XN"B`J"B`J($!P87)A;2!M:7AE9"`@=F%L"B`J"B`J
M($!R971U<FX@;G5M8F5R"B`J+PIF=6YC=&EO;B!T;TYU;6)E<BAV86PI"GL*
M("`@(&EF("AI<TYA3BAV86PI*2!["B`@("`@("`@<F5T=7)N(#`["B`@("!]
M(&5L<V4@>PH@("`@("`@(')E='5R;B!.=6UB97(H=F%L*3L*("`@('T*?0H*
M+RHJ"B`J(%-E=',@=&AE(&5N86)L960@<W1A=&4@;V8@;VYE(&5L96UE;G0@
M8F%S960@;VX@=&AE('9A;'5E<R!O9B!A;F]T:&5R+@H@*@H@*B!486ME<R!F
M;W5R(&]R(&UO<F4@87)G=6UE;G1S+"!I;B!T:&4@9F]R;3H*("H@("!C:&5C
M:T5N86)L960H<V]U<F-E+"!T87)G970L('1R=64L('9A;'5E,2P@=F%L=64R
M+"!V86QU93,N+BXI"B`J"B`J($!P87)A;2!O8FIE8W0@("!4:&4@96QE;65N
M="!T;R!C:&5C:PH@*B!`<&%R86T@<W1R:6YG("`@5&AE(&5L96UE;G0@=&\@
M96YA8FQE+V1I<V%B;&4*("H@0'!A<F%M(&)O;VQE86X@(%=H971H97(@=&\@
M96YA8FQE(&]R(&1I<V%B;&4@=&AE('1A<F=E=`H@*B!`<&%R86T@;6EX960@
M("`@5&AE('9A;'5E('1O(&-H96-K(&%G86EN<W0*("HO"F9U;F-T:6]N(&-H
M96-K16YA8FQE9"@I"GL*("`@(&EF("AA<F=U;65N=',N;&5N9W1H(#X@,BD@
M>PH@("`@("`@(&]B:E-R8R`](&%R9W5M96YT<ULP73L*("`@("`@("!O8FI4
M87)G970@/2!O8FI3<F,N9F]R;2YE;&5M96YT<UMA<F=U;65N='-;,5U=.PH@
M("`@("`@(&5N86)L960@/2!A<F=U;65N='-;,ET["B`@("`@("`@=&]G9VQE
M(#T@9F%L<V4["B`@("`@("`@:68@*&]B:E1A<F=E="D@>PH@("`@("`@("`@
M("!S=VET8V@@*&]B:E-R8RYT>7!E+G1O3&]W97)#87-E*"DI('L*("`@("`@
M("`@("`@8V%S92`G<V5L96-T+6]N92<@.@H@("`@("`@("`@("`@("`@=F%L
M(#T@;V)J4W)C+F]P=&EO;G-;;V)J4W)C+G-E;&5C=&5D26YD97A=+G9A;'5E
M.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=S
M96QE8W0M;75L=&EP;&4G(#H*("`@("`@("`@("`@("`@('9A;"`](&YE=R!!
M<G)A>2@I.PH@("`@("`@("`@("`@("`@8V]U;G0@/2`P.PH@("`@("`@("`@
M("`@("`@9F]R("AV87(@:2`](#`[(&D@/"!O8FI3<F,N;&5N9W1H.R`K*VDI
M('L*("`@("`@("`@("`@("`@("`@("!I9B`H;V)J4W)C+F]P=&EO;G-;:5TN
M<V5L96-T960I('L*("`@("`@("`@("`@("`@("`@("`@("`@=F%L6V-O=6YT
M72`](&]B:E-R8RYO<'1I;VYS6VE=+G9A;'5E.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@8V%S92`G8VAE8VMB;W@G(#H*("`@("`@("`@("`@
M("`@(&EF("AO8FI3<F,N8VAE8VME9"D@>PH@("`@("`@("`@("`@("`@("`@
M('9A;"`](&]B:E-R8RYV86QU93L*("`@("`@("`@("`@("`@("`@("!T;V=G
M;&4@/2!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("!D969A=6QT(#H*("`@("`@("`@("`@("`@
M('9A;"`](&]B:E-R8RYV86QU93L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@9F]R("AV87(@:2`](#,[(&D@/"!A<F=U;65N=',N;&5N9W1H.R`K*VDI
M('L*("`@("`@("`@("`@("`@(&EF("AT>7!E;V8H=F%L*2`]/2`G;V)J96-T
M)R`F)B`H87)G=6UE;G1S6VE=(&EN('9A;"DI('L*("`@("`@("`@("`@("`@
M("`@("!T;V=G;&4@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@?2!E;'-E(&EF("AA<F=U;65N='-;:5T@/3T@
M=F%L*2!["B`@("`@("`@("`@("`@("`@("`@=&]G9VQE(#T@=')U93L*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@;V)J5&%R9V5T+F1I<V%B;&5D(#T@
M=&]G9VQE(#\@(65N86)L960@.B!E;F%B;&5D.PH@("`@("`@("`@("!I9B`H
M(6]B:E1A<F=E="YD:7-A8FQE9"D@>PH@("`@("`@("`@("`@("`@;V)J5&%R
M9V5T+F9O8W5S*"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"GT*
M"B\J*@H@*B!3971S('1H92!T87)G970@9FEE;&0@=&\@=&AE('-U;2!O9B!A
M(')A;F=E(&]F(&9I96QD<RX*("H*("H@5&%K97,@=&AR964@;W(@;6]R92!A
M<F=U;65N=',L(&EN('1H92!F;W)M.@H@*B`@("!S=6U&:65L9',H9F]R;2P@
M=&%R9V5T+"!F:65L9#$L(&9I96QD,BP@9FEE;&0S+BXN*0H@*@H@*B!`<&%R
M86T@;V)J96-T("!4:&4@9F]R;2!T;R!C:&5C:PH@*B!`<&%R86T@<W1R:6YG
M("!4:&4@;F%M92!O9B!T:&4@=&%R9V5T(&5L96UE;G0*("H@0'!A<F%M('-T
M<FEN9R`@3VYE(&]R(&UO<F4@9FEE;&0@;F%M97,@=&\@<W5M"B`J+PIF=6YC
M=&EO;B!S=6U&:65L9',H*0I["B`@("!I9B`H87)G=6UE;G1S+FQE;F=T:"`^
M(#(I('L*("`@("`@("!O8FI&<FT@/2!A<F=U;65N='-;,%T["B`@("`@("`@
M;V)J5&%R9V5T(#T@;V)J1G)M+F5L96UE;G1S6V%R9W5M96YT<ULQ75T["B`@
M("`@("`@<W5M(#T@,#L*("`@("`@("!I9B`H;V)J5&%R9V5T*2!["B`@("`@
M("`@("`@(&9O<B`H=F%R(&D@/2`R.R!I(#P@87)G=6UE;G1S+FQE;F=T:#L@
M*RMI*2!["B`@("`@("`@("`@("`@("!O8FI3<F,@/2!O8FI&<FTN96QE;65N
M='-;87)G=6UE;G1S6VE=73L*("`@("`@("`@("`@("`@(&EF("AO8FI3<F,I
M('L*("`@("`@("`@("`@("`@("`@("!S=VET8V@@*&]B:E-R8RYT>7!E+G1O
M3&]W97)#87-E*"DI('L*("`@("`@("`@("`@("`@("`@("!C87-E("=S96QE
M8W0M;VYE)SH*("`@("`@("`@("`@("`@("`@("`@("`@<W5M("L]('1O3G5M
M8F5R*&]B:E-R8RYO<'1I;VYS6V]B:E-R8RYS96QE8W1E9$EN9&5X72YV86QU
M92D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@("`@("`@("!C87-E("=S96QE8W0M;75L=&EP;&4G(#H*("`@("`@("`@
M("`@("`@("`@("`@("`@9F]R("AV87(@:B`](#`[(&H@/"!O8FI3<F,N;&5N
M9W1H.R`K*VHI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('-U;2`K
M/2!T;TYU;6)E<BAO8FI3<F,N;W!T:6]N<UMJ72YV86QU92D["B`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("`@("`@("`@(&-A<V4@)V-H96-K8F]X)R`Z"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("AO8FI3<F,N8VAE8VME9"D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<W5M("L]('1O3G5M8F5R*&]B
M:E-R8RYV86QU92D["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@("`@
M(&1E9F%U;'0@.@H@("`@("`@("`@("`@("`@("`@("`@("!S=6T@*ST@=&].
M=6UB97(H;V)J4W)C+G9A;'5E*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&]B
M:E1A<F=E="YV86QU92`]('-U;3L*("`@("`@("!]"B`@("!]"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O9F]R;5]S96-T
M:6]N<RYJ<P``````````````````````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,S4R-``Q,#4Q-30S,S<T-``P,C$U,#8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+RHJ"B`J($AO<F1E($9O<FT@4V5C
M=&EO;G,@2F%V87-C<FEP="!#;&%S<PH@*@H@*B!0<F]V:61E<R!T:&4@:F%V
M87-C<FEP="!C;&%S<R!F;W(@:&%N9&QI;F<@=&%B8F5D('-E8W1I;VYS(&EN
M($AO<F1E($9O<FUS+@H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO
M($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B`D
M2&]R9&4Z(&AO<F1E+VIS+V9O<FU?<V5C=&EO;G,N:G,L=B`Q+C$N,BXR(#(P
M,#8O,#0O,34@,C(Z,C,Z,S8@8VAU8VL@17AP("0*("H*("H@0&%U=&AO<B`@
M36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H@0'!A8VMA9V4@2&]R
M9&5?1F]R;0H@*B\*9G5N8W1I;VX@2&]R9&5?1F]R;5]396-T:6]N<RAI;G-T
M86YC94YA;64L(&]P96Y396-T:6]N*0I["B`@("`O*B!3970@=7`@=&AI<R!C
M;&%S<R!I;G-T86YC92!F;W(@9G5N8W1I;VX@8V%L;',@9G)O;2!T:&4@<&%G
M92X@*B\*("`@('1H:7,N7VEN<W1A;F-E3F%M92`](&EN<W1A;F-E3F%M93L*
M"B`@("`O*B!4:&4@8W5R<F5N=&QY('-H;W=E9"!S96-T:6]N+B`J+PH@("`@
M=F%R(%]O<&5N4V5C=&EO;CL*"B`@("!T:&ES+G1O9V=L92`](&9U;F-T:6]N
M*'-E8W1I;VY)9"D*("`@('L*("`@("`@("`O*B!'970@=&AE(&-U<G)E;G1L
M>2!O<&5N('-E8W1I;VX@;V)J96-T+B`J+PH@("`@("`@(&]P96Y396-T:6]N
M260@/2!T:&ES+E]G970H*3L*("`@("`@("!I9B`H9&]C=6UE;G0N9V5T16QE
M;65N=$)Y260H)U]S96-T:6]N7R<@*R!O<&5N4V5C=&EO;DED*2D@>PH@("`@
M("`@("`@("!D;V-U;65N="YG971%;&5M96YT0GE)9"@G7W-E8W1I;VY?)R`K
M(&]P96Y396-T:6]N260I+G-T>6QE+F1I<W!L87D@/2`G;F]N92<["B`@("`@
M("`@?0H@("`@("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=?=&%B7R<@
M*R!O<&5N4V5C=&EO;DED*2YC;&%S<TYA;64@/2!N=6QL.PH*("`@("`@("`O
M*B!'970@=&AE(&YE=VQY(&]P96YE9"!S96-T:6]N(&]B:F5C="X@*B\*("`@
M("`@("!I9B`H9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)U]S96-T:6]N7R<@
M*R!S96-T:6]N260I*2!["B`@("`@("`@("`@(&1O8W5M96YT+F=E=$5L96UE
M;G1">4ED*"=?<V5C=&EO;E\G("L@<V5C=&EO;DED*2YS='EL92YD:7-P;&%Y
M(#T@)V)L;V-K)SL*("`@("`@("!]"B`@("`@("`@9&]C=6UE;G0N9V5T16QE
M;65N=$)Y260H)U]T86)?)R`K('-E8W1I;VY)9"DN8VQA<W-.86UE(#T@)V%C
M=&EV951A8B<["@H@("`@("`@("\J(%-T;W)E('1H92!N97=L>2!O<&5N960@
M<V5C=&EO;BX@*B\*("`@("`@("!T:&ES+E]S970H<V5C=&EO;DED*3L*("`@
M('T*"B`@("!T:&ES+E]G970@/2!F=6YC=&EO;B@I"B`@("!["B`@("`@("`@
M<F5T=7)N('1H:7,N7V]P96Y396-T:6]N.PH@("`@?0H*("`@('1H:7,N7W-E
M="`](&9U;F-T:6]N*'-E8W1I;VY)9"D*("`@('L*("`@("`@("!V87(@9F]R
M;2`](&5V86PH)V1O8W5M96YT+B<@*R!T:&ES+E]I;G-T86YC94YA;64I.PH@
M("`@("`@(&EF("AF;W)M("$](&YU;&P@)B8*("`@("`@("`@("`@='EP96]F
M(&9O<FTN7U]F;W)M3W!E;E-E8W1I;VX@(3T@)W5N9&5F:6YE9"<I('L*("`@
M("`@("`@("`@9F]R;2Y?7V9O<FU/<&5N4V5C=&EO;BYV86QU92`](&5S8V%P
M92AS96-T:6]N260I.PH@("`@("`@('T*("`@("`@("!T:&ES+E]O<&5N4V5C
M=&EO;B`]('-E8W1I;VY)9#L*("`@('T*"B`@("!T:&ES+E]S970H;W!E;E-E
M8W1I;VXI.PI]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VIS+VAI9&5A8FQE+FIS````
M````````````````````````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(V
M,C<`,3`U,34T,S,W-#0`,#(P,S<T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"\J*@H@*B!*879A<V-R:7!T(&]B:F5C="!F
M;W(@:&ED:6YG("8@<VAO=VEN9R!$3TT@96QE;65N=',N"B`J"B`J("1(;W)D
M93H@:&]R9&4O:G,O:&ED96%B;&4N:G,L=B`Q+C(@,C`P-"\Q,"\Q.2`Q.3HP
M.#HU,R!C:'5C:R!%>'`@)`H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@HO*BH*("H@0V]N
M<W1R=6-T;W(@9F]R($AO<F1E($AI9&5A8FQE($1/32!E;&5M96YT<RX*("H*
M("H@0'!A<F%M(&ED("`@("`@("`@("`@5&AE($1/32!I9"!O9B!T:&4@96QE
M;65N="!W92!W86YT('1O('=O<FL@=VET:"X*("H@0'!A<F%M(&1I<W!L87E3
M='EL92`@5VAA="!D:7-P;&%Y('-T>6QE('-H;W=S('1H:7,@96QE;65N=#\@
M1&5F875L=',*("H@("`@("`@("`@("`@("`@("`@("`@=&\@)V)L;V-K)RX*
M("HO"F9U;F-T:6]N($AO<F1E7TAI9&5A8FQE*"D*>PH@("`@=&AI<RYI9"`]
M(&%R9W5M96YT<ULP73L*("`@('1H:7,N96QE;65N="`](&1O8W5M96YT+F=E
M=$5L96UE;G1">4ED*'1H:7,N:60I.PH*("`@(&EF("AA<F=U;65N=',N;&5N
M9W1H(#T](#(I('L*("`@("`@("!T:&ES+F1I<W!L87E3='EL92`](&%R9W5M
M96YT<ULQ73L*("`@('T*?3L*"DAO<F1E7TAI9&5A8FQE+G!R;W1O='EP92`]
M('L*"B`@("`O*BH*("`@("`J($ED(&]F('1H92!$3TT@96QE;65N="X*("`@
M("`J($!V87(@:60*("`@("`J+PH@("`@:60Z(&YU;&PL"@H@("`@+RHJ"B`@
M("`@*B!$3TT@96QE;65N="!R969E<F5N8V4N"B`@("`@*B!`=F%R(&5L96UE
M;G0*("`@("`J+PH@("`@96QE;65N=#H@;G5L;"P*"B`@("`O*BH*("`@("`J
M(%1H92!D:7-P;&%Y('-T>6QE('1O('5S92X@1&5F875L="!I<R`G8FQO8VLG
M+@H@("`@("H@0'9A<B!D:7-P;&%Y4W1Y;&4*("`@("`J+PH@("`@9&ES<&QA
M>5-T>6QE.B`G8FQO8VLG+`H*("`@('-H;W=N.B!F=6YC=&EO;B@I"B`@("![
M"B`@("`@("`@<F5T=7)N('1H:7,N96QE;65N="YS='EL92YD:7-P;&%Y("$]
M("=N;VYE)SL*("`@('TL"@H@("`@:&ED93H@9G5N8W1I;VXH*0H@("`@>PH@
M("`@("`@('1H:7,N96QE;65N="YS='EL92YD:7-P;&%Y(#T@)VYO;F4G.PH@
M("`@("`@(')E='5R;B!T:&ES.PH@("`@?2P*"B`@("!S:&]W.B!F=6YC=&EO
M;B@I"B`@("!["B`@("`@("`@=&AI<RYE;&5M96YT+G-T>6QE+F1I<W!L87D@
M/2!T:&ES+F1I<W!L87E3='EL93L*("`@("`@("!R971U<FX@=&AI<SL*("`@
M('TL"@H@("`@=&]G9VQE.B!F=6YC=&EO;B@I"B`@("!["B`@("`@("`@<F5T
M=7)N('1H:7,N<VAO=VXH*2`_('1H:7,N:&ED92@I(#H@=&AI<RYS:&]W*"D[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O:G,O:&]R9&4N:64N:G,`````````````````````````````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3(Q,``Q,#4Q-30S,S<T-``P,C`S,3<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+RHJ
M"B`J($=E;F5R86P@2&]R9&4@54D@969F96-T<R!J879A<V-R:7!T("T@9FEX
M97,@9F]R($E%('1H870@8V%N)W0*("H@96%S:6QY(&)E(&1O;F4@=VET:&]U
M="!B<F]W<V5R(&1E=&5C=&EO;BX*("H*("H@)$AO<F1E.B!H;W)D92]J<R]H
M;W)D92YI92YJ<RQV(#$N,2XR+C(@,C`P-B\P,2\R.2`Q,#HQ.#HR,"!C:'5C
M:R!%>'`@)`H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T
M"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I4;V]L5&EP<U]/<'1I;VY?5VEN
M9&]W961?0V]N=')O;',@/2`Q.PH*:68@*'1Y<&5O9B!!<G)A>2YP<F]T;W1Y
M<&4N<'5S:"`]/2`G=6YD969I;F5D)RD@>PH@("`@($%R<F%Y+G!R;W1O='EP
M92YP=7-H(#T@9G5N8W1I;VXH*2!["B`@("`@("`@('9A<B!L(#T@=&AI<RYL
M96YG=&@["B`@("`@("`@(&9O<B`H=F%R(&D@/2`P.R!I(#P@87)G=6UE;G1S
M+FQE;F=T:#L@:2LK*2!["B`@("`@("`@("`@("!T:&ES6VP@*R!I72`](&%R
M9W5M96YT<UMI73L*("`@("`@("`@?0H@("`@("`@("!R971U<FX@=&AI<RYL
M96YG=&@*("`@("!]"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O:G,O:&]R9&4N:G,`````````````````````````````
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-38S-@`Q,#4Q-30S,S<T-``P
M,3<W-#0`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+RHJ"B`J($=E;F5R86P@2&]R9&4@54D@969F96-T<R!J879A<V-R:7!T
M+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VIS+VAO<F1E+FIS+'8@,2XQ-"XR+C4@
M,C`P-B\P-2\R-2`Q.#HP-SHR-B!S;'5S87)Z($5X<"`D"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*B\*"G9A<B!4;V]L5&EP<R`]('L*("`@($-54E)%3E0Z(&YU;&PL"B`@
M("!424U%3U54.B!N=6QL+`H@("`@3$E.2SH@;G5L;"P*"B`@("!A='1A8VA"
M96AA=FEO<CH@9G5N8W1I;VXH*0H@("`@>PH@("`@("`@(&QI;FMS(#T@9&]C
M=6UE;G0N9V5T16QE;65N='-">51A9TYA;64H)V$G*3L*("`@("`@("!F;W(@
M*&D@/2`P.R!I(#P@;&EN:W,N;&5N9W1H.R!I*RLI('L*("`@("`@("`@("`@
M:68@*&QI;FMS6VE=+G1I=&QE*2!["B`@("`@("`@("`@("`@("!L:6YK<UMI
M72YS971!='1R:6)U=&4H)VYI8V5T:71L92<L(&QI;FMS6VE=+G1I=&QE*3L*
M("`@("`@("`@("`@("`@(&QI;FMS6VE=+G)E;6]V94%T=')I8G5T92@G=&ET
M;&4G*3L*"B`@("`@("`@("`@("`@("!A9&1%=F5N="AL:6YK<UMI72P@)VUO
M=7-E;W9E<B<L(%1O;VQ4:7!S+F]V97(I.PH@("`@("`@("`@("`@("`@861D
M179E;G0H;&EN:W-;:5TL("=M;W5S96]U="<L(%1O;VQ4:7!S+F]U="D["B`@
M("`@("`@("`@("`@("!A9&1%=F5N="AL:6YK<UMI72P@)V9O8W5S)RP@5&]O
M;%1I<',N;W9E<BD["B`@("`@("`@("`@("`@("!A9&1%=F5N="AL:6YK<UMI
M72P@)V)L=7(G+"!4;V]L5&EP<RYO=70I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@?2P*"B`@("!O=F5R.B!F=6YC=&EO;BAE*0H@("`@>PH@("`@
M("`@(&EF("AT>7!E;V8@5&]O;%1I<',@/3T@)W5N9&5F:6YE9"<I('L*("`@
M("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@:68@*%1O;VQ4
M:7!S+E1)345/550I('L*("`@("`@("`@("`@=VEN9&]W+F-L96%R5&EM96]U
M="A4;V]L5&EP<RY424U%3U54*3L*("`@("`@("!]"@H@("`@("`@(&EF("AW
M:6YD;W<N979E;G0@)B8@=VEN9&]W+F5V96YT+G-R8T5L96UE;G0I('L*("`@
M("`@("`@("`@5&]O;%1I<',N3$E.2R`]('=I;F1O=RYE=F5N="YS<F-%;&5M
M96YT.PH@("`@("`@('T@96QS92!I9B`H92`F)B!E+G1A<F=E="D@>PH@("`@
M("`@("`@("!4;V]L5&EP<RY,24Y+(#T@92YT87)G970["B`@("`@("`@?0H*
M("`@("`@("!4;V]L5&EP<RY424U%3U54(#T@=VEN9&]W+G-E=%1I;65O=70H
M)U1O;VQ4:7!S+G-H;W<H*2<L(#,P,"D*("`@('TL"@H@("`@;W5T.B!F=6YC
M=&EO;B@I"B`@("!["B`@("`@("`@:68@*'1Y<&5O9B!4;V]L5&EP<R`]/2`G
M=6YD969I;F5D)RD@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*
M("`@("`@("!I9B`H5&]O;%1I<',N5$E-14]55"D@>PH@("`@("`@("`@("!W
M:6YD;W<N8VQE87)4:6UE;W5T*%1O;VQ4:7!S+E1)345/550I.PH@("`@("`@
M('T*"B`@("`@("`@:68@*%1O;VQ4:7!S+D-54E)%3E0I('L*("`@("`@("`@
M("`@9&]C=6UE;G0N9V5T16QE;65N='-">51A9TYA;64H)V)O9'DG*5LP72YR
M96UO=F5#:&EL9"A4;V]L5&EP<RY#55)214Y4*3L*("`@("`@("`@("`@5&]O
M;%1I<',N0U524D5.5"`](&YU;&P["@H@("`@("`@("`@("!V87(@:69R86UE
M(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)VEF<F%M95]T="<I.PH@("`@
M("`@("`@("!I9B`H:69R86UE("$](&YU;&PI('L*("`@("`@("`@("`@("`@
M(&EF<F%M92YS='EL92YD:7-P;&%Y(#T@)VYO;F4G.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@?2P*"B`@("!S:&]W.B!F=6YC=&EO;B@I"B`@("![
M"B`@("`@("`@:68@*'1Y<&5O9B!4;V]L5&EP<R`]/2`G=6YD969I;F5D)R!\
M?"`A5&]O;%1I<',N3$E.2RD@>PH@("`@("`@("`@("!R971U<FX["B`@("`@
M("`@?0H*("`@("`@("!I9B`H5&]O;%1I<',N0U524D5.5"D@>PH@("`@("`@
M("`@("!4;V]L5&EP<RYO=70H*3L*("`@("`@("!]"@H@("`@("`@(&QI;FL@
M/2!4;V]L5&EP<RY,24Y+.PH@("`@("`@('=H:6QE("@A;&EN:RYG971!='1R
M:6)U=&4H)VYI8V5T:71L92<I("8F(&QI;FLN;F]D94YA;64N=&],;W=E<D-A
M<V4H*2`A/2`G8F]D>2<I('L*("`@("`@("`@("`@;&EN:R`](&QI;FLN<&%R
M96YT3F]D93L*("`@("`@("!]"B`@("`@("`@;FEC971I=&QE(#T@;&EN:RYG
M971!='1R:6)U=&4H)VYI8V5T:71L92<I.PH@("`@("`@(&EF("@A;FEC971I
M=&QE*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@
M(&0@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=D:78G*3L*("`@("`@("!D
M+F-L87-S3F%M92`]("=N:6-E=&ET;&4G.PH@("`@("`@(&0N:6YN97)(5$U,
M(#T@;FEC971I=&QE.PH*("`@("`@("!35$1?5TE$5$@@/2`Q,#`["B`@("`@
M("`@34%87U=)1%1((#T@-C`P.PH@("`@("`@(&EF("AW:6YD;W<N:6YN97)7
M:61T:"D@>PH@("`@("`@("`@("!-05A?5TE$5$@@/2!-871H+FUI;BA-05A?
M5TE$5$@L('=I;F1O=RYI;FYE<E=I9'1H("T@,C`I.PH@("`@("`@('T*("`@
M("`@("!I9B`H9&]C=6UE;G0N8F]D>2`F)B!D;V-U;65N="YB;V1Y+G-C<F]L
M;%=I9'1H*2!["B`@("`@("`@("`@($U!6%]724142"`]($UA=&@N;6EN*$U!
M6%]724142"P@9&]C=6UE;G0N8F]D>2YS8W)O;&Q7:61T:"`M(#(P*3L*("`@
M("`@("!]"@H@("`@("`@(&YI8V5T:71L95]L96YG=&@@/2`P.PH@("`@("`@
M(&QI;F5S(#T@;FEC971I=&QE+G)E<&QA8V4H+SQB<B`_7"\^+V<L(")<;B(I
M+G-P;&ET*")<;B(I.PH@("`@("`@(&9O<B`H:2`](#`[(&D@/"!L:6YE<RYL
M96YG=&@[(&DK*RD@>PH@("`@("`@("`@("!N:6-E=&ET;&5?;&5N9W1H(#T@
M36%T:"YM87@H;FEC971I=&QE7VQE;F=T:"P@;&EN97-;:5TN;&5N9W1H*3L*
M("`@("`@("!]"@H@("`@("`@(&A?<&EX96QS(#T@;FEC971I=&QE7VQE;F=T
M:"`J(#<["B`@("`@("`@=%]P:7AE;',@/2!N:6-E=&ET;&5?;&5N9W1H("H@
M,3`["@H@("`@("`@(&EF("AH7W!I>&5L<R`^(%-41%]724142"D@>PH@("`@
M("`@("`@("!W(#T@:%]P:7AE;',["B`@("`@("`@?2!E;'-E(&EF("A35$1?
M5TE$5$@@/B!T7W!I>&5L<RD@>PH@("`@("`@("`@("!W(#T@=%]P:7AE;',[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@=R`](%-41%]724142#L*
M("`@("`@("!]"@H@("`@("`@(&UP;W,@/2!F:6YD4&]S*&QI;FLI.PH@("`@
M("`@(&UX(#T@;7!O<ULP73L*("`@("`@("!M>2`](&UP;W-;,5T["@H@("`@
M("`@(&QE9G0@/2!M>"`K(#(P.PH@("`@("`@(&EF("AW:6YD;W<N:6YN97)7
M:61T:"`F)B`H*&QE9G0@*R!W*2`^('=I;F1O=RYI;FYE<E=I9'1H*2D@>PH@
M("`@("`@("`@("!L969T(#T@=VEN9&]W+FEN;F5R5VED=&@@+2!W("T@-#`[
M"B`@("`@("`@?0H@("`@("`@(&EF("AD;V-U;65N="YB;V1Y("8F(&1O8W5M
M96YT+F)O9'DN<V-R;VQL5VED=&@@)B8@*"AL969T("L@=RD@/B!D;V-U;65N
M="YB;V1Y+G-C<F]L;%=I9'1H*2D@>PH@("`@("`@("`@("!L969T(#T@9&]C
M=6UE;G0N8F]D>2YS8W)O;&Q7:61T:"`M('<@+2`R-3L*("`@("`@("!]"@H@
M("`@("`@(&0N:60@/2`G=&]O;%1I<"<["B`@("`@("`@9"YS='EL92YL969T
M(#T@36%T:"YM87@H;&5F="P@-2D@*R`G<'@G.PH@("`@("`@(&0N<W1Y;&4N
M=VED=&@@/2!-871H+FUI;BAW+"!-05A?5TE$5$@I("L@)W!X)SL*("`@("`@
M("!D+G-T>6QE+G1O<"`]("AM>2`K(#(P*2`K("=P>"<["B`@("`@("`@9"YS
M='EL92YD:7-P;&%Y(#T@(F)L;V-K(CL*"B`@("`@("`@=')Y('L*("`@("`@
M("`@("`@9&]C=6UE;G0N9V5T16QE;65N='-">51A9TYA;64H)V)O9'DG*5LP
M72YA<'!E;F1#:&EL9"AD*3L*("`@("`@("`@("`@5&]O;%1I<',N0U524D5.
M5"`](&0["@H@("`@("`@("`@("!I9B`H='EP96]F(%1O;VQ4:7!S7T]P=&EO
M;E]7:6YD;W=E9%]#;VYT<F]L<R`A/2`G=6YD969I;F5D)RD@>PH@("`@("`@
M("`@("`@("`@=F%R(&EF<F%M92`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED
M*"=I9G)A;65?='0G*3L*("`@("`@("`@("`@("`@(&EF("AI9G)A;64@/3T@
M;G5L;"D@>PH@("`@("`@("`@("`@("`@("`@(&EF<F%M92`](&1O8W5M96YT
M+F-R96%T945L96UE;G0H(CQI9G)A;64@<W)C/2=J879A<V-R:7!T.F9A;'-E
M.R<@;F%M93TG:69R86UE7W1T)R!I9#TG:69R86UE7W1T)R!S8W)O;&QI;F<]
M)VYO)R!F<F%M96)O<F1E<CTG,"<@<W1Y;&4])W!O<VET:6]N.F%B<V]L=71E
M.R!T;W`Z,'!X.R!L969T.C!P>#L@9&ES<&QA>3IN;VYE.R<^/"]I9G)A;64^
M(BD["B`@("`@("`@("`@("`@("`@("`@9&]C=6UE;G0N9V5T16QE;65N='-"
M>51A9TYA;64H)V)O9'DG*5LP72YA<'!E;F1#:&EL9"AI9G)A;64I.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:69R86UE+G-T>6QE+G=I
M9'1H(#T@9"YO9F9S9717:61T:#L*("`@("`@("`@("`@("`@(&EF<F%M92YS
M='EL92YH96EG:'0@/2!D+F]F9G-E=$AE:6=H=#L*("`@("`@("`@("`@("`@
M(&EF<F%M92YS='EL92YT;W`@/2!D+G-T>6QE+G1O<#L*("`@("`@("`@("`@
M("`@(&EF<F%M92YS='EL92YL969T(#T@9"YS='EL92YL969T.PH@("`@("`@
M("`@("`@("`@:69R86UE+G-T>6QE+G!O<VET:6]N(#T@(F%B<V]L=71E(CL*
M("`@("`@("`@("`@("`@(&EF<F%M92YS='EL92YD:7-P;&%Y(#T@(F)L;V-K
M(CL*("`@("`@("`@("`@("`@(&0N<W1Y;&4N>DEN9&5X(#T@,3`P.PH@("`@
M("`@("`@("`@("`@:69R86UE+G-T>6QE+GI);F1E>"`](#DY.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!C871C:"`H92D@>PH@("`@("`@('T*("`@('T*
M"GT["@HO*BH*("H@4F5T=7)N('1H92!;>"QY72!P;W-I=&EO;B!O9B!A;B!O
M8FIE8W0N"B`J+PIF=6YC=&EO;B!F:6YD4&]S*&]B:BD*>PH@("`@:68@*&]B
M:BYO9F9S971087)E;G0I('L*("`@("`@("!F;W(@*'!O<U@@/2`P+"!P;W-9
M(#T@,#L@;V)J+F]F9G-E=%!A<F5N=#L@;V)J(#T@;V)J+F]F9G-E=%!A<F5N
M="D@>PH@("`@("`@("`@("!P;W-8("L](&]B:BYO9F9S971,969T.PH@("`@
M("`@("`@("!P;W-9("L](&]B:BYO9F9S9714;W`["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B!;<&]S6"P@<&]S65T["B`@("!](&5L<V4@>PH@("`@("`@
M(')E='5R;B!;;V)J+G@L(&]B:BYY73L*("`@('T*?0H*+RHJ"B`J($%D9"!A
M;B!E=F5N="!L:7-T96YE<B!A<R!L;VYG(&%S('1H92!B<F]W<V5R('-U<'!O
M<G1S(&ET+B!$:69F97)E;G0*("H@8G)O=W-E<G,@<W1I;&P@:&%N9&QE('1H
M97-E(&5V96YT<R!S;&EG:'1L>2!D:69F97)E;G1L>3L@:6X*("H@<&%R=&EC
M=6QA<B!A=F]I9"!U<VEN9R`B=&AI<R(@:6X@979E;G0@9G5N8W1I;VYS+@H@
M*@H@*B!`875T:&]R(%-C;W1T($%N9')E=PH@*B!`875T:&]R($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B\*9G5N8W1I;VX@861D179E
M;G0H;V)J+"!E=E1Y<&4L(&9N*0I["B`@("!I9B`H;V)J+F%D9$5V96YT3&ES
M=&5N97(I('L*("`@("`@("!O8FHN861D179E;G1,:7-T96YE<BAE=E1Y<&4L
M(&9N+"!T<G5E*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T@96QS92!I
M9B`H;V)J+F%T=&%C:$5V96YT*2!["B`@("`@("`@=F%R('(@/2!O8FHN871T
M86-H179E;G0H)V]N)R`K(&5V5'EP92P@9FXI.PH@("`@("`@($5V96YT0V%C
M:&4N861D*&]B:BP@9794>7!E+"!F;BD["B`@("`@("`@<F5T=7)N('(["B`@
M("!](&5L<V4@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*?0H*=F%R
M($5V96YT0V%C:&4@/2!F=6YC=&EO;B@I"GL*("`@('9A<B!L:7-T179E;G1S
M(#T@6UT["@H@("`@<F5T=7)N('L*("`@("`@("!L:7-T179E;G1S.B!L:7-T
M179E;G1S+`H*("`@("`@("!A9&0Z(&9U;F-T:6]N*&YO9&4L('-%=F5N=$YA
M;64L(&9(86YD;&5R+"!B0V%P='5R92D*("`@("`@("!["B`@("`@("`@("`@
M(&QI<W1%=F5N=',N<'5S:"AA<F=U;65N=',I.PH@("`@("`@('TL"@H@("`@
M("`@(&9L=7-H.B!F=6YC=&EO;B@I"B`@("`@("`@>PH@("`@("`@("`@("!V
M87(@:2P@:71E;3L*("`@("`@("`@("`@9F]R("AI(#T@;&ES=$5V96YT<RYL
M96YG=&@@+2`Q.R!I(#X](#`[(&D@/2!I("T@,2D@>PH@("`@("`@("`@("`@
M("`@:71E;2`](&QI<W1%=F5N='-;:5T["@H@("`@("`@("`@("`@("`@:68@
M*&ET96U;,%TN<F5M;W9E179E;G1,:7-T96YE<BD@>PH@("`@("`@("`@("`@
M("`@("`@(&ET96U;,%TN<F5M;W9E179E;G1,:7-T96YE<BAI=&5M6S%=+"!I
M=&5M6S)=+"!I=&5M6S-=*3L*("`@("`@("`@("`@("`@('T["@H@("`@("`@
M("`@("`@("`@+RH@1G)O;2!T:&ES('!O:6YT(&]N('=E(&YE960@=&AE(&5V
M96YT(&YA;65S('1O(&)E"B`@("`@("`@("`@("`@("`@*B!P<F5F:7AE9"!W
M:71H("=O;B<N("HO"B`@("`@("`@("`@("`@("!I9B`H:71E;5LQ72YS=6)S
M=')I;F<H,"P@,BD@(3T@)V]N)RD@>PH@("`@("`@("`@("`@("`@("`@(&ET
M96U;,5T@/2`G;VXG("L@:71E;5LQ73L*("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("!I9B`H:71E;5LP72YD971A8VA%=F5N="D@>PH@("`@
M("`@("`@("`@("`@("`@(&ET96U;,%TN9&5T86-H179E;G0H:71E;5LQ72P@
M:71E;5LR72D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M:71E;5LP75MI=&5M6S%=72`](&YU;&P["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!].PI]*"D["@II9B`H9&]C=6UE;G0N8W)E871E16QE;65N="`F
M)B!D;V-U;65N="YG971%;&5M96YT<T)Y5&%G3F%M92D@>PH@("`@861D179E
M;G0H=VEN9&]W+"`G;&]A9"<L(%1O;VQ4:7!S+F%T=&%C:$)E:&%V:6]R*3L*
M("`@(&%D9$5V96YT*'=I;F1O=RP@)W5N;&]A9"<L(%1O;VQ4:7!S+F]U="D[
M"B`@("!A9&1%=F5N="AW:6YD;W<L("=U;FQO860G+"!%=F5N=$-A8VAE+F9L
M=7-H*3L*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O
M:'1T<&-L:65N="YJ<P``````````````````````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`Q,3`W-@`Q,#4Q-30S,S<T-``P,C$P,3,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+RHJ"B`J($IA=F%S
M8W)I<'0@;&EB<F%R>2!F;W(@=V]R:VEN9R!W:71H(%AM;$AT='!297%U97-T
M(&]B:F5C=',@86YD"B`J($AO<F1E+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VIS
M+VAT='!C;&EE;G0N:G,L=B`Q+C(N,3`N,R`R,#`U+S$P+S$X(#$Q.C,S.C,X
M(&IA;B!%>'`@)`H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@
M;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@HO+R!#;VYS=')U8W1O<B!F
M;W(@9V5N97)I8R!(5%10(&-L:65N="X*9G5N8W1I;VX@2%144$-L:65N="@I
M('M].PH*+R\@061D(&UE=&AO9',@86YD('!R;W!E<G1I97,@87,@87)R87DN
M"DA45%!#;&EE;G0N<')O=&]T>7!E(#T@>PH@("`@=7)L.B!N=6QL+`H*("`@
M("\O($EN<W1A;F-E(&]F(%A-3$AT='!297%U97-T+@H@("`@<F5Q=65S=#H@
M;G5L;"P*"B`@("`O+R!5<V5D('1O(&UA:V4@<W5R92!M=6QT:7!L92!C86QL
M<R!A<F4@;F]T('!L86-E9"!W:71H('1H92!S86UE"B`@("`O+R!C;&EE;G0@
M;V)J96-T('=H:6QE(&%N;W1H97(@:6X@<')O9W)E<W,N"B`@("!C86QL26Y0
M<F]G<F5S<SH@9F%L<V4L"@H@("`@+R\@5&AE('5S97(@9&5F:6YE9"!H86YD
M;&5R("T@<V5E($UY2&%N9&QE<B!B96QO=RX*("`@('5S97)H86YD;&5R.B!N
M=6QL+`H*("`@(&EN:70Z(&9U;F-T:6]N*'5R;"D*("`@('L*("`@("`@("!T
M:&ES+G5R;"`]('5R;#L*"B`@("`@("`@=')Y('L*("`@("`@("`@("`@+R\@
M36]Z:6QL82P@4V%F87)I+@H@("`@("`@("`@("!T:&ES+G)E<75E<W0@/2!N
M97<@6$U,2'1T<%)E<75E<W0H*3L*("`@("`@("!](&-A=&-H("AE*2!["B`@
M("`@("`@("`@("\O($E%+@H@("`@("`@("`@("!V87(@35-834Q?6$U,2%14
M4%]04D]'2413(#T@;F5W($%R<F%Y*`H@("`@("`@("`@("`@("`@(DU36$U,
M,BY834Q(5%10+C0N,"(L"B`@("`@("`@("`@("`@("`B35-834PR+EA-3$A4
M5%`N,RXP(BP*("`@("`@("`@("`@("`@(")-4UA-3#(N6$U,2%144"(L"B`@
M("`@("`@("`@("`@("`B36EC<F]S;V9T+EA-3$A45%`B"B`@("`@("`@("`@
M("`@("`I.PH@("`@("`@("`@("!V87(@<W5C8V5S<R`](&9A;'-E.PH@("`@
M("`@("`@("!F;W(@*'9A<B!I(#T@,#L@:2`\($U36$U,7UA-3$A45%!?4%)/
M1TE$4RYL96YG=&@@)B8@(7-U8V-E<W,[(&DK*RD@>PH@("`@("`@("`@("`@
M("`@=')Y('L*("`@("`@("`@("`@("`@("`@("!T:&ES+G)E<75E<W0@/2!N
M97<@06-T:79E6$]B:F5C="A-4UA-3%]834Q(5%107U!23T=)1%-;:5TI.PH@
M("`@("`@("`@("`@("`@("`@('-U8V-E<W,@/2!T<G5E.PH@("`@("`@("`@
M("`@("`@?2!C871C:"`H92D@>WT*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H(7-U8V-E<W,I('L*("`@("`@("`@("`@("`@('1H<F]W(")5;F%B
M;&4@=&\@8W)E871E(%A-3$AT='!297%U97-T+B(["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]+`H*("`@("\O($AA;F1L97(@87)G=6UE;G0@:7,@
M82!U<V5R(&1E9FEN960@;V)J96-T('1O(&)E(&-A;&QE9"X*("`@(&%S>6YC
M1T54.B!F=6YC=&EO;BAH86YD;&5R*0H@("`@>PH@("`@("`@("\O($1E9W)A
M9&4@;W(@<V]M92!S=6-H+@H@("`@("`@(&EF("@A=&AI<RYR97%U97-T*2![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!].PH*("`@("`@
M("`O+R!0<F5V96YT(&UU;'1I<&QE(&-A;&QS"B`@("`@("`@:68@*'1H:7,N
M8V%L;$EN4')O9W)E<W,I('L*("`@("`@("`@("`@=&AR;W<@(D-A;&P@:6X@
M<')O9W)E<W,B.PH@("`@("`@('T["@H@("`@("`@('1H:7,N8V%L;$EN4')O
M9W)E<W,@/2!T<G5E.PH*("`@("`@("!T:&ES+G5S97)H86YD;&5R(#T@:&%N
M9&QE<CL*"B`@("`@("`@+R\@3W!E;B!A;B!A<WEN8R!R97%U97-T("T@=&AI
M<F0@87)G=6UE;G0@;6%K97,@:70*("`@("`@("`O+R!A<WEN8VAR;VYO=7,N
M"B`@("`@("`@=&AI<RYR97%U97-T+F]P96XH)T=%5"<L('1H:7,N=7)L+"!T
M<G5E*3L*"B`@("`@("`@+R\@2&%V92!T;R!A<W-I9VX@(G1H:7,B('1O(&$@
M=F%R:6%B;&4N"B`@("`@("`@=F%R('-E;&8@/2!T:&ES.PH*("`@("`@("`O
M+R!!<W-I9VX@82!C;&]S=7)E('1O('1H92!O;G)E861Y<W1A=&5C:&%N9V4@
M8V%L;&)A8VLN"B`@("`@("`@=&AI<RYR97%U97-T+F]N<F5A9'ES=&%T96-H
M86YG92`](&9U;F-T:6]N*"D*("`@("`@("!["B`@("`@("`@("`@('-E;&8N
M<W1A=&5#:&%N9V5#86QL8F%C:RAS96QF*3L*("`@("`@("!]"@H@("`@("`@
M('1H:7,N<F5Q=65S="YS96YD*&YU;&PI.PH@("`@?2P*"B`@("!S=&%T94-H
M86YG94-A;&QB86-K.B!F=6YC=&EO;BAC;&EE;G0I"B`@("!["B`@("`@("`@
M<W=I=&-H("AC;&EE;G0N<F5Q=65S="YR96%D>5-T871E*2!["B`@("`@("`@
M("`@("\O(%)E<75E<W0@;F]T('EE="!M861E+@H@("`@("`@("`@("!C87-E
M(#$Z"B`@("`@("`@("`@('1R>2!["B`@("`@("`@("`@("`@("!C;&EE;G0N
M=7-E<FAA;F1L97(N;VY);FET*"D["B`@("`@("`@("`@('T@8V%T8V@@*&4I
M('L@+RH@2&%N9&QE<B!M971H;V0@;F]T(&1E9FEN960N("HO('T*("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("`O+R!#;VYT86-T(&5S=&%B;&ES
M:&5D('=I=&@@<V5R=F5R(&)U="!N;W1H:6YG(&1O=VYL;V%D960*("`@("`@
M("`@("`@+R\@>65T+@H@("`@("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@
M('1R>2!["B`@("`@("`@("`@("`@("!S=&%T=7,@/2!C;&EE;G0N<F5Q=65S
M="YS=&%T=7,["B`@("`@("`@("`@("`@("`O+R!#:&5C:R!F;W(@2%144"!S
M=&%T=7,@,C`P+@H@("`@("`@("`@("`@("`@:68@*'-T871U<R`A/2`R,#`I
M('L*("`@("`@("`@("`@("`@("`@("!C;&EE;G0N=7-E<FAA;F1L97(N;VY%
M<G)O<B@*("`@("`@("`@("`@("`@("`@("`@("`@<W1A='5S+`H@("`@("`@
M("`@("`@("`@("`@("`@("!C;&EE;G0N<F5Q=65S="YS=&%T=7-497AT"B`@
M("`@("`@("`@("`@("`@("`@("`@("D["@H@("`@("`@("`@("`@("`@("`@
M("\O($%B;W)T('1H92!R97%U97-T+@H@("`@("`@("`@("`@("`@("`@(&-L
M:65N="YR97%U97-T+F%B;W)T*"D["@H@("`@("`@("`@("`@("`@("`@("\O
M($-A;&P@;F\@;&]N9V5R(&EN('!R;V=R97-S+@H@("`@("`@("`@("`@("`@
M("`@(&-L:65N="YC86QL26Y0<F]G<F5S<R`](&9A;'-E.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!](&-A=&-H("AE*2!["B`@("`@("`@("`@
M("`@("`O*B!-4UA-3$A45%`@,RYX*R!D;V5S;B=T('!O<'5L871E('-T871U
M<R!U;G1I;`H@("`@("`@("`@("`@("`@("H@<F5A9'E3=&%T92`T+B`J+PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M+R\@0V%L;&5D(&UU;'1I<&QE('1I;65S('=H:6QE(&1O=VYL;V%D(&ES(&EN
M('!R;V=R97-S+@H@("`@("`@("`@("!C87-E(#,Z"B`@("`@("`@("`@("\O
M($YO=&EF>2!U<V5R(&AA;F1L97(@;V8@9&]W;FQO860@<')O9W)E<W,N"B`@
M("`@("`@("`@('1R>2!["B`@("`@("`@("`@("`@("`O+R!'970@=&AE('1O
M=&%L(&-O;G1E;G0@;&5N9W1H("AU<V5F=6P@=&\@=V]R:PH@("`@("`@("`@
M("`@("`@+R\@;W5T(&AO=R!M=6-H(&AA<R!B965N(&1O=VYL;V%D960I+@H@
M("`@("`@("`@("`@("`@=')Y('L*("`@("`@("`@("`@("`@("`@("!V87(@
M8V]N=&5N=$QE;F=T:"`]"B`@("`@("`@("`@("`@("`@("`@("`@(&-L:65N
M="YR97%U97-T+F=E=%)E<W!O;G-E2&5A9&5R*")#;VYT96YT+4QE;F=T:"(I
M.PH@("`@("`@("`@("`@("`@?2!C871C:"`H92D@>PH@("`@("`@("`@("`@
M("`@("`@('9A<B!C;VYT96YT3&5N9W1H(#T@3F%..PH@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@("`@("\O($-A;&P@=&AE('!R;V=R97-S(&AA
M;F1L97(@=VET:"!W:&%T('=E)W9E(&=O="X*("`@("`@("`@("`@("`@(&-L
M:65N="YU<V5R:&%N9&QE<BYO;E!R;V=R97-S*`H@("`@("`@("`@("`@("`@
M("`@(&-L:65N="YR97%U97-T+G)E<W!O;G-E5&5X="P*("`@("`@("`@("`@
M("`@("`@("!C;VYT96YT3&5N9W1H"B`@("`@("`@("`@("`@("`@("`@*3L*
M"B`@("`@("`@("`@('T@8V%T8V@@*&4I('L@+RH@2&%N9&QE<B!M971H;V0@
M;F]T(&1E9FEN960N("HO('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("`O+R!$;W=N;&]A9"!C;VUP;&5T92X*("`@("`@("`@("`@8V%S92`T
M.@H@("`@("`@("`@("!T<GD@>PH@("`@("`@("`@("`@("`@8VQI96YT+G5S
M97)H86YD;&5R+F]N3&]A9"AC;&EE;G0N<F5Q=65S="YR97-P;VYS951E>'0I
M.PH@("`@("`@("`@("!](&-A=&-H("AE*2!["B`@("`@("`@("`@("`@("`O
M*B!(86YD;&5R(&UE=&AO9"!N;W0@9&5F:6YE9"X@*B\*("`@("`@("`@("`@
M?2!F:6YA;&QY('L*("`@("`@("`@("`@("`@("\O($-A;&P@;F\@;&]N9V5R
M(&EN('!R;V=R97-S+@H@("`@("`@("`@("`@("`@8VQI96YT+F-A;&Q);E!R
M;V=R97-S(#T@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@?0H@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VIS+VEE17-C1W5A<F0N:G,`````````````````````````````````
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#,T-#$`,3`U,34T,S,W-#0`,#(P-C0U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"\J*@H@
M*B!*879A<V-R:7!T(&-O9&4@9F]R(&%T=&%C:&EN9R!A;B!O;FME>61O=VX@
M;&ES=&5N97(@=&\@=&5X=&%R96$@86YD"B`J('1E>'0@:6YP=70@96QE;65N
M=',@=&\@<')E=F5N="!L;W-S(&]F(&1A=&$@=VAE;B!T:&4@=7-E<B!H:71S
M('1H90H@*B!%4T,@:V5Y+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VIS+VEE17-C
M1W5A<F0N:G,L=B`Q+C$N,BXS(#(P,#4O,3`O,3@@,3$Z,S,Z,S@@:F%N($5X
M<"`D"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*("H@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*B\*"B\J(%1H:7,@8V]D92!I<R!O;FQY(')E
M;&5V86YT(&9O<B!)12X@5&AE<F5F;W)E('1R>2!N;W0@=&\@9&\@86YY=&AI
M;F<*("H@:68@=&AE('5S97(@:7-N)W0@=7-I;F<@244L(&5V96X@:68@=&AI
M<R!S8W)I<'0@:7,@:6YC;'5D960N(%1H:7,*("H@8VAE8VL@=VEL;"!C871C
M:"!S;VUE(&)R;W=S97)S('1H870@87)E(&YO="!)12!B=70@:61E;G1I9GD*
M("H@=&AE;7-E;'9E<R!A<R!)12X@2&]P969U;&QY(&EF('1H97D@<&%S<R!T
M:')O=6=H('1H97D@<W5P<&]R="!W:&%T"B`J($E%('-U<'!O<G1S+B`J+PII
M9B`H;F%V:6=A=&]R+F%P<%9E<G-I;VXN:6YD97A/9B@G35-)12<I("$]("TQ
M("8F(&1O8W5M96YT+F%L;"D@>PH@("`@+RH@5V4@9&\@979E<GET:&EN9R!O
M;FQO860@<V\@=&AA="!T:&4@96YT:7)E(&1O8W5M96YT(&ES('!R97-E;G0*
M("`@("`J(&)E9F]R92!W92!S=&%R="!S96%R8VAI;F<@:70N("HO"B`@("!W
M:6YD;W<N871T86-H179E;G0H)V]N;&]A9"<L(&=U87)D*3L*?0H*+RHJ"B`J
M($9I;F1S(&%L;"!T97AT(&EN<'5T<R`H:6YP=70@='EP93TB=&5X="(I(&%N
M9"!T97AT87)E82!T86=S+"!A;F0*("H@871T86-H97,@=&AE(&]N:V5Y9&]W
M;B!L:7-T96YE<B!T;R!T:&5M('1O(&%V;VED($530R!C;&5A<FEN9R!T:&4*
M("H@=&5X="X*("HO"F9U;F-T:6]N(&=U87)D*"D*>PH@("`@+RH@1FEN9',@
M86QL('1E>'1A<F5A<RX@*B\*("`@('9A<B!T97AT87)E87,@/2!D;V-U;65N
M="YA;&PN=&%G<R@G5$585$%214$G*3L*("`@(&9O<B`H=F%R(&D@/2`P.R!I
M(#P@=&5X=&%R96%S+FQE;F=T:#L@:2LK*2!["B`@("`@("`@=&5X=&%R96%S
M6VE=+F%T=&%C:$5V96YT*"=O;FME>61O=VXG+"!D:7-A8FQE17-C87!E*3L*
M("`@('T*"B`@("`O*B!&:6YD<R!?86QL7R`\:6YP=70^('1A9W,N("HO"B`@
M("!V87(@:6YP=71S(#T@9&]C=6UE;G0N86QL+G1A9W,H)TE.4%54)RD["B`@
M("!F;W(@*'9A<B!I(#T@,#L@:2`\(&EN<'5T<RYL96YG=&@[(&DK*RD@>PH@
M("`@("`@("\J($]N;'D@871T86-H('1O(#QI;G!U="!T>7!E/2)T97AT(CX@
M=&%G<RX@*B\*("`@("`@("!I9B`H:6YP=71S6VE=+G1Y<&4@/3T@)W1E>'0G
M*2!["B`@("`@("`@("`@(&EN<'5T<UMI72YA='1A8VA%=F5N="@G;VYK97ED
M;W=N)RP@9&ES86)L945S8V%P92D["B`@("`@("`@?0H@("`@?0I]"@HO*BH*
M("H@4F5T=7)N<R!F86QS92!I9B!T:&4@=7-E<B!H:70@=&AE($530R!K97DL
M('!R979E;G1I;F<@244@9G)O;0H@*B!B;&%N:VEN9R!T:&4@9FEE;&0N($]T
M:&5R=VES92!R971U<FYS('1R=64N"B`J"B`J(')E='5R;B!B;V]L96%N("!7
M:&5T:&5R(&]R(&YO="!T;R!A;&QO=R!T:&4@:V5Y(&5V96YT+@H@*B\*9G5N
M8W1I;VX@9&ES86)L945S8V%P92@I"GL*("`@(')E='5R;B!W:6YD;W<N979E
M;G0N:V5Y0V]D92`A/2`R-SL*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]J
M<R]I;6%G92YJ<P``````````````````````````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`S-#0R`#$P-3$U-#,S-S0T`#`Q-S<Q-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````O*BH*("H@2&]R
M9&4@26UA9V4@2F%V87-C<FEP=`H@*@H@*B!0<F]V:61E<R!T:&4@:F%V87-C
M<FEP="!T;R!H96QP(&1U<FEN9R!T:&4@=7!L;V%D:6YG(&]F(&EM86=E<R!I
M;B!(;W)D95]&;W)M+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VIS+VEM86=E+FIS
M+'8@,2XS+C0N,R`R,#`V+S`Q+S`Q(#(Q.C(Y.C`R(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L
M;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*
M("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"B\J*@H@*B!#:&%N9V5S('1H92!S
M<F,@;V8@86X@:6UA9V4@=&%R9V5T+"!O<'1I;VYA;&QY(&%T=&%C:&EN9R!A
M('1I;64@=F%L=64@=&\@=&AE"B`J(%523"!T;R!M86ME('-U<F4@=&AA="!T
M:&4@:6UA9V4@9&]E<R!U<&1A=&4@86YD(&YO="!U<V4@=&AE(&)R;W=S97(@
M8V%C:&4N"B`J"B`J($!P87)A;2!S=')I;F<@<W)C("`@("`@("`@("`@("!4
M:&4@<W)O=6-E('1O(&EN<V5R=&5D(&EN=&\@=&AE(&EM86=E(&5L96UE;G0N
M"B`J($!P87)A;2!S=')I;F<@=&%R9V5T("`@("`@("`@("!4:&4@=&%R9V5T
M(&5L96UE;G0N"B`J($!P87)A;2!O<'1I;VYA;"!B;V]L(&YO7V-A8VAE("!)
M9B!S970@=&\@=')U92!W:6QL(&%P<&5N9"!T:&4@=&EM92X*("H*("H@0')E
M='5R;B!B;V]L("!&86QS92!T;R!S=&]P('1H92!B<F]W<V5R(&QO861I;F<@
M86YY=&AI;F<N"B`J+PIF=6YC=&EO;B!S:&]W26UA9V4H<W)C+"!T87)G970L
M(&YO7V-A8VAE*0I["B`@("!V87(@:6UG(#T@9&]C=6UE;G0N9V5T16QE;65N
M=$)Y260H=&%R9V5T*3L*("`@(&EF("AT>7!E;V8@;F]?8V%C:&4@/3T@)W5N
M9&5F:6YE9"<I('L*("`@("`@("!V87(@;F]?8V%C:&4@/2!F86QS93L*("`@
M('T*"B`@("!I9B`H;F]?8V%C:&4I('L*("`@("`@("!V87(@;F]W(#T@;F5W
M($1A=&4H*3L*("`@("`@("!S<F,@/2!S<F,@*R`G)B<@*R!N;W<N9V5T5&EM
M92@I.PH@("`@?0H*("`@(&EM9RYS<F,@/2!S<F,["@H@("`@<F5T=7)N(&9A
M;'-E.PI]"@HO*BH*("H@061D<R!T;R!T:&4@9VEV96X@<V]U<F-E('1H92!H
M96EG:'0O=VED=&@@9FEE;&0@=F%L=65S(&9O<B!T:&4@9VEV96X@=&%R9V5T
M+@H@*@H@*B!`<&%R86T@<W1R:6YG('-R8R`@("`@("`@("`@5&AE('-R;W5C
M92!T;R!A<'!E;F0@=&\@=&AE(')E<VEZ92!P87)A;7,N"B`J($!P87)A;2!S
M=')I;F<@=&%R9V5T("`@("`@("!4:&4@=&%R9V5T(&5L96UE;G0N"B`J($!P
M87)A;2!O<'1I;VYA;"!B;V]L(')A=&EO("!)9B!S970@=&\@=')U92!W:6QL
M(&%P<&5N9"!F:7@@=&AE(')A=&EO+@H@*@H@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(&UO9&EF:65D('-O=7)C92!T;R!I;F-L=61E('1H92!R97-I>F4@9&%T
M82X*("HO"F9U;F-T:6]N(&=E=%)E<VEZ95-R8RAS<F,L('1A<F=E="P@<F%T
M:6\I"GL*("`@('9A<B!W:61T:"`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED
M*"=?=U\G("L@=&%R9V5T*2YV86QU93L*("`@('9A<B!H96EG:'0@/2!D;V-U
M;65N="YG971%;&5M96YT0GE)9"@G7VA?)R`K('1A<F=E="DN=F%L=64["B`@
M("!I9B`H='EP96]F(')A=&EO(#T]("=U;F1E9FEN960G*2!["B`@("`@("`@
M=F%R(')A=&EO(#T@,#L*("`@('T*"B`@("!S<F,@/2!S<F,@*R`G)B<@*R`G
M=CTG("L@=VED=&@@*R`G+B<@*R!H96EG:'0@*R`G+B<@*R!R871I;SL*"B`@
M("!R971U<FX@<W)C.PI]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O;W!E
M;E]C;VQO<G!I8VME<BYJ<P``````````````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-34U,``Q,#4Q-30S,S<T-``P,C(Q-S(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+RHJ"B`J($AO<F1E($-O
M;&]R<&EC:V5R($IA=F%38W)I<'0N"B`J"B`J(%!R;W9I9&5S('1H92!J879A
M<V-R:7!T('1O(&-R96%T92!A(&-O;&]R<&EC:V5R+@H@*@H@*B`D2&]R9&4Z
M(&AO<F1E+VIS+V]P96Y?8V]L;W)P:6-K97(N:G,L=B`Q+C(@,C`P-"\Q,"\Q
M.2`Q.3HP.#HU,R!C:'5C:R!%>'`@)`H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@IF=6YC
M=&EO;B!O<&5N0V]L;W)0:6-K97(H=&%R9V5T*0I["B`@("!V87(@;&%Y(#T@
M9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)V-O;&]R<&EC:V5R7R<@*R!T87)G
M970I.PH@("`@:68@*&QA>2YS='EL92YD:7-P;&%Y(#T]("=B;&]C:R<I('L*
M("`@("`@("!L87DN<W1Y;&4N9&ES<&QA>2`]("=N;VYE)SL*("`@("`@("!R
M971U<FX@9F%L<V4["B`@("!]"@H@("`@:68@*&QA>2YF:7)S=$-H:6QD*2![
M"B`@("`@("`@:68@*&QA>2YF:7)S=$-H:6QD+FYO9&54>7!E(#T](#$I('L*
M("`@("`@("`@("`@;&%Y+G-T>6QE+F1I<W!L87D@/2`G8FQO8VLG.PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("!L87DN<F5M;W9E0VAI;&0H;&%Y+F9I<G-T0VAI;&0I
M.PH@("`@("`@('T*("`@('T*"B`@("!V87(@=&%B;&4@/2!D;V-U;65N="YC
M<F5A=&5%;&5M96YT*"=T86)L92<I.PH@("`@=F%R('1B;V1Y(#T@9&]C=6UE
M;G0N8W)E871E16QE;65N="@G=&)O9'DG*3L*("`@('1A8FQE+F%P<&5N9$-H
M:6QD*'1B;V1Y*3L*("`@('1A8FQE+F-E;&Q3<&%C:6YG(#T@,#L*("`@('1A
M8FQE+F)O<F1E<B`](#`["B`@("!T86)L92YS='EL92YC=7)S;W(@/2`G8W)O
M<W-H86ER)SL*("`@('1A8FQE+F]N;6]U<V5O=70@/2!F=6YC=&EO;B@I('L*
M("`@("`@("!D;V-U;65N="YG971%;&5M96YT0GE)9"@G8V]L;W)D96UO7R<@
M*R!T87)G970I+G-T>6QE+F)A8VMG<F]U;F1#;VQO<B`](&1O8W5M96YT+F=E
M=$5L96UE;G1">4ED*'1A<F=E="DN=F%L=64["B`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@?0H*("`@("\O(%1H92!P86QE='1E"B`@("!R(#T@,#L@9R`]
M(#`[(&(@/2`P.PH@("`@9F]R("AB(#T@,#L@8B`\(#8[(&(K*RD@>PH@("`@
M("`@(')O=R`](&1O8W5M96YT+F-R96%T945L96UE;G0H)W1R)RD["B`@("`@
M("`@8V]L;W(@/2!M86ME0V]L;W(H8B`J(#4Q+"!B("H@-3$L(&(@*B`U,2D[
M"B`@("`@("`@8V5L;"`](&UA:V5#96QL*'1A<F=E="P@8V]L;W(I.PH@("`@
M("`@(')O=RYA<'!E;F1#:&EL9"AC96QL*3L*("`@("`@("!F;W(@*&<@/2`P
M.R!G(#P@-CL@9RLK*2!["B`@("`@("`@("`@(&9O<B`H<B`](#`[('(@/"`V
M.R!R*RLI('L*("`@("`@("`@("`@("`@(&EF("AR("$](&(@)B8@8B`A/2!G
M*2!["B`@("`@("`@("`@("`@("`@("`@8V]L;W(@/2!M86ME0V]L;W(H<B`J
M(#4Q+"!G("H@-3$L(&(@*B`U,2D["B`@("`@("`@("`@("`@("`@("`@8V5L
M;"`](&UA:V5#96QL*'1A<F=E="P@8V]L;W(I.PH@("`@("`@("`@("`@("`@
M("`@(')O=RYA<'!E;F1#:&EL9"AC96QL*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!T8F]D>2YA<'!E;F1#
M:&EL9"AR;W<I.PH@("`@?0H*("`@('1A8FQE+F%P<&5N9$-H:6QD*'1B;V1Y
M*3L*("`@(&QA>2YA<'!E;F1#:&EL9"AT86)L92D["B`@("!L87DN<W1Y;&4N
M9&ES<&QA>2`]("=B;&]C:R<["GT*"F9U;F-T:6]N(&UA:V5#96QL*'1A<F=E
M="P@8V]L;W(I"GL*("`@(&-E;&P@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT
M*"=T9"<I.PH@("`@8V5L;"YH96EG:'0@/2`S.PH@("`@8V5L;"YW:61T:"`]
M(#8["B`@("!C96QL+FED(#T@8V]L;W(["B`@("!C96QL+G-T>6QE+F)A8VMG
M<F]U;F1#;VQO<B`](&-O;&]R.PH@("`@8V5L;"YO;FUO=7-E;W9E<B`](&9U
M;F-T:6]N*"D@>PH@("`@("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=C
M;VQO<F1E;6]?)R`K('1A<F=E="DN<W1Y;&4N8F%C:V=R;W5N9$-O;&]R(#T@
M=&AI<RYS='EL92YB86-K9W)O=6YD0V]L;W(["B`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@?0H@("`@8V5L;"YO;F-L:6-K(#T@9G5N8W1I;VXH*2!["B`@
M("`@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)V-O;&]R9&5M;U\G("L@
M=&%R9V5T*2YS='EL92YB86-K9W)O=6YD0V]L;W(@/2!T:&ES+G-T>6QE+F)A
M8VMG<F]U;F1#;VQO<CL*("`@("`@("!D;V-U;65N="YG971%;&5M96YT0GE)
M9"AT87)G970I+G9A;'5E(#T@=&AI<RYI9#L*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@<F5T=7)N(&-E;&P["GT*"F9U;F-T:6]N(&UA:V5#
M;VQO<BAR+"!G+"!B*0I["B`@("!C;VQO<B`]("(C(CL*("`@(&-O;&]R("L]
M(&AE>"A-871H+F9L;V]R*'(@+R`Q-BDI.PH@("`@8V]L;W(@*ST@:&5X*'(@
M)2`Q-BD["B`@("!C;VQO<B`K/2!H97@H36%T:"YF;&]O<BAG("\@,38I*3L*
M("`@(&-O;&]R("L](&AE>"AG("4@,38I.PH@("`@8V]L;W(@*ST@:&5X*$UA
M=&@N9FQO;W(H8B`O(#$V*2D["B`@("!C;VQO<B`K/2!H97@H8B`E(#$V*3L*
M("`@(')E='5R;B!C;VQO<CL*?0H*9G5N8W1I;VX@:&5X*$1E8RD*>PH@("`@
M:68@*$1E8R`]/2`Q,"D@<F5T=7)N(")A(CL*("`@(&EF("A$96,@/3T@,3$I
M(')E='5R;B`B8B(["B`@("!I9B`H1&5C(#T](#$R*2!R971U<FX@(F,B.PH@
M("`@:68@*$1E8R`]/2`Q,RD@<F5T=7)N(")D(CL*("`@(&EF("A$96,@/3T@
M,30I(')E='5R;B`B92(["B`@("!I9B`H1&5C(#T](#$U*2!R971U<FX@(F8B
M.PH@("`@<F5T=7)N("(B("L@1&5C.PI]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]J<R]P;W!U<"YJ<P``````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-S4R`#$P
M-3$U-#,S-S0T`#`R,#`P,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````O*BH*("H@2&]R9&4@4&]P=7`@2F%V85-C<FEP="X*
M("H*("H@4')O=FED97,@=&AE(&IA=F%S8W)I<'0@=&\@;W!E;B!P;W!U<"!W
M:6YD;W=S+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VIS+W!O<'5P+FIS+'8@,2XR
M+C$P+C0@,C`P-B\P,B\Q,"`Q.#HQ-#HU-"!C:'5C:R!%>'`@)`H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("HO"F9U;F-T:6]N('!O<'5P*'5R;"P@=VED=&@L(&AE:6=H="D*
M>PH@("`@:68@*"%W:61T:"D@>PH@("`@("`@('=I9'1H(#T@-C`P.PH@("`@
M?0H@("`@:68@*"%H96EG:'0I('L*("`@("`@("!H96EG:'0@/2`U,#`["B`@
M("!]"@H@("`@=F%R(&YA;64@/2`H;F5W($1A=&4H*2DN9V5T5&EM92@I.PH@
M("`@=F%R('!A<F%M(#T@(G1O;VQB87(];F\L;&]C871I;VX];F\L<W1A='5S
M/7EE<RQS8W)O;&QB87)S/7EE<RQR97-I>F%B;&4]>65S+'=I9'1H/2(@*R!W
M:61T:"`K("(L:&5I9VAT/2(@*R!H96EG:'0@*R`B+&QE9G0],"QT;W`],"([
M"B`@("!V87(@=VEN(#T@=VEN9&]W+F]P96XH=7)L+"!N86UE+"!P87)A;2D[
M"B`@("!I9B`H(7=I;BD@>PH@("`@("`@(&%L97)T*")!('!O<'5P('=I;F1O
M=R!C;W5L9"!N;W0@8F4@;W!E;F5D+B!9;W5R(&)R;W=S97(@;6%Y(&)E(&)L
M;V-K:6YG('!O<'5P<R!F;W(@=&AI<R!A<'!L:6-A=&EO;BXB*3L*("`@('T@
M96QS92!["B`@("`@("`@:68@*'1Y<&5O9B!W:6XN;F%M92`]/2`G=6YD969I
M;F5D)RD@>PH@("`@("`@("`@("!W:6XN;F%M92`](&YA;64["B`@("`@("`@
M?0H@("`@("`@(&EF("AT>7!E;V8@=VEN+F]P96YE<B`]/2`G=6YD969I;F5D
M)RD@>PH@("`@("`@("`@("!W:6XN;W!E;F5R(#T@<V5L9CL*("`@("`@("!]
M"B`@("!]"@H@("`@<F5T=7)N('=I;CL*?0H`````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]J<R]S;W)T97(N:G,`````
M````````````````````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V
M-3,V`#$P-3$U-#,S-S0T`#`R,#$V,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````O*BH*("H@2&]R9&4@1F]R;2!3;W)T97(@
M1FEE;&0@2F%V87-C<FEP="!#;&%S<PH@*@H@*B!0<F]V:61E<R!T:&4@:F%V
M87-C<FEP="!C;&%S<R!T;R!A8V-O;7!A;GD@=&AE($AO<F1E7T9O<FT@<V]R
M=&5R"B`J(&9I96QD+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VIS+W-O<G1E<BYJ
M<RQV(#$N,BXQ,"XS(#(P,#8O,#$O,#$@,C$Z,CDZ,#(@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O
M8FQO+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"F9U;F-T:6]N($AO<F1E7T9O
M<FU?4V]R=&5R*&EN<W1A;F-E3F%M92P@=F%R3F%M92P@:&5A9&5R*0I["B`@
M("`O*B!3970@=7`@=&AI<R!C;&%S<R!I;G-T86YC92!F;W(@9G5N8W1I;VX@
M8V%L;',@9G)O;2!T:&4@<&%G92X@*B\*("`@('1H:7,N7VEN<W1A;F-E3F%M
M92`](&EN<W1A;F-E3F%M93L*"B`@("!T:&ES+E]V87).86UE(#T@=F%R3F%M
M93L*"B`@("`O*B!3;W)T97(@=F%R:6%B;&5S+B`J+PH@("`@=&AI<RY?:&5A
M9&5R(#T@)R<["B`@("!T:&ES+FUI;DQE;F=T:"`](#`["B`@("!I9B`H:&5A
M9&5R("$]("<G*2!["B`@("`@("`@=&AI<RY?:&5A9&5R(#T@:&5A9&5R.PH@
M("`@("`@('1H:7,N;6EN3&5N9W1H(#T@,3L*("`@('T*("`@('1H:7,N<V]R
M=&5R3&ES="`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*'1H:7,N7W9A<DYA
M;64@*R`G6VQI<W1=)RD["B`@("!T:&ES+G-O<G1E<D%R<F%Y(#T@9&]C=6UE
M;G0N9V5T16QE;65N=$)Y260H=&AI<RY?=F%R3F%M92`K("=;87)R87E=)RD[
M"@H@("`@=&AI<RYD97-E;&5C=$AE861E<B`](&9U;F-T:6]N*"D*("`@('L*
M("`@("`@("!I9B`H=&AI<RY?:&5A9&5R("$]("<G*2!["B`@("`@("`@("`@
M('1H:7,N<V]R=&5R3&ES=%LP72YS96QE8W1E9"`](&9A;'-E.PH@("`@("`@
M('T*("`@('T*"B`@("!T:&ES+G-E=$AI9&1E;B`](&9U;F-T:6]N*"D*("`@
M('L*("`@("`@("!V87(@=&UP07)R87D@/2!N97<@07)R87DH*3L*"B`@("`@
M("`@9F]R("AV87(@:2`]('1H:7,N;6EN3&5N9W1H.R!I(#P@=&AI<RYS;W)T
M97),:7-T+FQE;F=T:#L@:2LK*2!["B`@("`@("`@("`@(&EF("AT:&ES+G-O
M<G1E<DQI<W1;:5TN=F%L=64I('L*("`@("`@("`@("`@("`@('1M<$%R<F%Y
M6VD@+2!T:&ES+FUI;DQE;F=T:%T@/2!T:&ES+G-O<G1E<DQI<W1;:5TN=F%L
M=64["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@('1H:7,N<V]R
M=&5R07)R87DN=F%L=64@/2!T;7!!<G)A>2YJ;VEN*")<="(I.PH@("`@?0H*
M("`@('1H:7,N;6]V94-O;'5M;E5P(#T@9G5N8W1I;VXH*0H@("`@>PH@("`@
M("`@('9A<B!S96P@/2!T:&ES+G-O<G1E<DQI<W0N<V5L96-T961);F1E>#L*
M"B`@("`@("`@:68@*'-E;"`\/2!T:&ES+FUI;DQE;F=T:"!\?"!T:&ES+G-O
M<G1E<DQI<W0N;&5N9W1H(#P]('1H:7,N;6EN3&5N9W1H("L@,2D@<F5T=7)N
M.PH*("`@("`@("`O*B!$97-E;&5C="!E=F5R>71H:6YG(&)U="!T:&4@9FER
M<W0@<V5L96-T960@:71E;2X@*B\*("`@("`@("!T:&ES+G-O<G1E<DQI<W0N
M<V5L96-T961);F1E>"`]('-E;#L*("`@("`@("!V87(@=7`@/2!T:&ES+G-O
M<G1E<DQI<W1;<V5L72YV86QU93L*"B`@("`@("`@=&UP(#T@;F5W($%R<F%Y
M*"D["B`@("`@("`@9F]R("AI(#T@=&AI<RYM:6Y,96YG=&@[(&D@/"!T:&ES
M+G-O<G1E<DQI<W0N;&5N9W1H.R!I*RLI('L*("`@("`@("`@("`@=&UP6VD@
M+2!T:&ES+FUI;DQE;F=T:%T@/2!N97<@3W!T:6]N*'1H:7,N<V]R=&5R3&ES
M=%MI72YT97AT+"!T:&ES+G-O<G1E<DQI<W1;:5TN=F%L=64I"B`@("`@("`@
M?0H*("`@("`@("!F;W(@*&D@/2`P.R!I(#P@=&UP+FQE;F=T:#L@:2LK*2![
M"B`@("`@("`@("`@(&EF("AI("L@=&AI<RYM:6Y,96YG=&@@/3T@<V5L("T@
M,2D@>PH@("`@("`@("`@("`@("`@=&AI<RYS;W)T97),:7-T6VD@*R!T:&ES
M+FUI;DQE;F=T:%T@/2!T;7!;:2`K(#%=.PH@("`@("`@("`@("!](&5L<V4@
M:68@*&D@*R!T:&ES+FUI;DQE;F=T:"`]/2!S96PI('L*("`@("`@("`@("`@
M("`@('1H:7,N<V]R=&5R3&ES=%MI("L@=&AI<RYM:6Y,96YG=&A=(#T@=&UP
M6VD@+2`Q73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M('1H:7,N<V]R=&5R3&ES=%MI("L@=&AI<RYM:6Y,96YG=&A=(#T@=&UP6VE=
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!T:&ES+G-O<G1E
M<DQI<W0N<V5L96-T961);F1E>"`]('-E;"`M(#$["@H@("`@("`@('1H:7,N
M<V5T2&ED9&5N*"D["B`@("!]"@H@("`@=&AI<RYM;W9E0V]L=6UN1&]W;B`]
M(&9U;F-T:6]N*"D*("`@('L*("`@("`@("!V87(@<V5L(#T@=&AI<RYS;W)T
M97),:7-T+G-E;&5C=&5D26YD97@["@H@("`@("`@(&EF("AS96P@/3T@+3$@
M?'P@<V5L(#T]('1H:7,N<V]R=&5R3&ES="YL96YG=&@@+2`Q*2!R971U<FX[
M"@H@("`@("`@("\J($1E<V5L96-T(&5V97)Y=&AI;F<@8G5T('1H92!F:7)S
M="!S96QE8W1E9"!I=&5M+B`J+PH@("`@("`@('1H:7,N<V]R=&5R3&ES="YS
M96QE8W1E9$EN9&5X(#T@<V5L.PH@("`@("`@('9A<B!D;W=N(#T@=&AI<RYS
M;W)T97),:7-T6W-E;%TN=F%L=64["@H@("`@("`@('1M<"`](&YE=R!!<G)A
M>2@I.PH@("`@("`@(&9O<B`H:2`]('1H:7,N;6EN3&5N9W1H.R!I(#P@=&AI
M<RYS;W)T97),:7-T+FQE;F=T:#L@:2LK*2!["B`@("`@("`@("`@('1M<%MI
M("T@=&AI<RYM:6Y,96YG=&A=(#T@;F5W($]P=&EO;BAT:&ES+G-O<G1E<DQI
M<W1;:5TN=&5X="P@=&AI<RYS;W)T97),:7-T6VE=+G9A;'5E*0H@("`@("`@
M('T*"B`@("`@("`@9F]R("AI(#T@,#L@:2`\('1M<"YL96YG=&@[(&DK*RD@
M>PH@("`@("`@("`@("!I9B`H:2`K('1H:7,N;6EN3&5N9W1H(#T]('-E;"D@
M>PH@("`@("`@("`@("`@("`@=&AI<RYS;W)T97),:7-T6VD@*R!T:&ES+FUI
M;DQE;F=T:%T@/2!T;7!;:2`K(#%=.PH@("`@("`@("`@("!](&5L<V4@:68@
M*&D@*R!T:&ES+FUI;DQE;F=T:"`]/2!S96P@*R`Q*2!["B`@("`@("`@("`@
M("`@("!T:&ES+G-O<G1E<DQI<W1;:2`K('1H:7,N;6EN3&5N9W1H72`]('1M
M<%MI("T@,5T["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!T:&ES+G-O<G1E<DQI<W1;:2`K('1H:7,N;6EN3&5N9W1H72`]('1M<%MI
M73L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@=&AI<RYS;W)T
M97),:7-T+G-E;&5C=&5D26YD97@@/2!S96P@*R`Q.PH*("`@("`@("!T:&ES
M+G-E=$AI9&1E;B@I.PH@("`@?0I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O<W1R:7!E+FIS````
M````````````````````````````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-#$P,0`Q,#4Q-30S,S<T-``P,C`Q,S(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+RHJ"B`J($IA=F%S8W)I<'0@8V]D92!F
M;W(@9FEN9&EN9R!A;&P@=&%B;&5S('=I=&@@8VQA<W-N86UE(")S=')I<&5D
M(B!A;F0*("H@9'EN86UI8V%L;'D@<W1R:7!I;F<@=&AE:7(@<F]W(&-O;&]R
M<RX*("H*("H@)$AO<F1E.B!H;W)D92]J<R]S=')I<&4N:G,L=B`Q+C,N,BXR
M(#(P,#4O,3`O,3@@,3$Z,S,Z,S@@:F%N($5X<"`D"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*B\*"B\J(%=E(&1O(&5V97)Y=&AI;F<@;VYL;V%D('-O('1H870@=&AE(&5N
M=&ER92!D;V-U;65N="!I<R!P<F5S96YT"B`J(&)E9F]R92!W92!S=&%R="!S
M96%R8VAI;F<@:70@9F]R('1A8FQE<RX@*B\*:68@*'=I;F1O=RYA9&1%=F5N
M=$QI<W1E;F5R*2!["B`@("!W:6YD;W<N861D179E;G1,:7-T96YE<B@G;&]A
M9"<L(&9I;F13=')I<&5D5&%B;&5S+"!F86QS92D["GT@96QS92!I9B`H=VEN
M9&]W+F%T=&%C:$5V96YT*2!["B`@("!W:6YD;W<N871T86-H179E;G0H)V]N
M;&]A9"<L(&9I;F13=')I<&5D5&%B;&5S*3L*?2!E;'-E(&EF("AW:6YD;W<N
M;VYL;V%D("$](&YU;&PI('L*("`@('9A<B!O;&1/;DQO860@/2!W:6YD;W<N
M;VYL;V%D.PH@("`@=VEN9&]W+F]N;&]A9"`](&9U;F-T:6]N*&4I"B`@("![
M"B`@("`@("`@;VQD3VY,;V%D*&4I.PH@("`@("`@(&9I;F13=')I<&5D5&%B
M;&5S*"D["B`@("!].PI](&5L<V4@>PH@("`@=VEN9&]W+F]N;&]A9"`](&9I
M;F13=')I<&5D5&%B;&5S.PI]"@IF=6YC=&EO;B!F:6YD4W1R:7!E9%1A8FQE
M<R@I"GL*("`@(&EF("@A9&]C=6UE;G0N9V5T16QE;65N='-">51A9TYA;64I
M('L*("`@("`@("!R971U<FX["B`@("!]"B`@("!T86)L97,@/2!D;V-U;65N
M="YG971%;&5M96YT<T)Y5&%G3F%M92@G=&%B;&4G*3L*("`@(&9O<B`H:2`]
M(#`[(&D@/"!T86)L97,N;&5N9W1H.R!I*RLI('L*("`@("`@("!I9B`H=&%B
M;&5S6VE=+F-L87-S3F%M92YI;F1E>$]F*"=S=')I<&5D)RD@(3T@+3$I('L*
M("`@("`@("`@("`@<W1R:7!E*'1A8FQE<UMI72D["B`@("`@("`@?0H@("`@
M?0I]"@IF=6YC=&EO;B!S=')I<&4H=&%B;&4I"GL*("`@("\O(%1H92!F;&%G
M('=E)VQL('5S92!T;R!K965P('1R86-K(&]F('=H971H97(@=&AE(&-U<G)E
M;G0@<F]W(&ES"B`@("`O+R!O9&0@;W(@979E;BX*("`@('9A<B!E=F5N(#T@
M9F%L<V4["@H@("`@+R\@5&%B;&5S(&-A;B!H879E(&UO<F4@=&AA;B!O;F4@
M=&)O9'D@96QE;65N=#L@9V5T(&%L;"!C:&EL9`H@("`@+R\@=&)O9'D@=&%G
M<R!A;F0@:6YT97)A=&4@=&AR;W5G:"!T:&5M+@H@("`@=F%R('1B;V1I97,@
M/2!T86)L92YC:&EL9$YO9&5S.PH@("`@9F]R("AV87(@8R`](#`[(&,@/"!T
M8F]D:65S+FQE;F=T:#L@8RLK*2!["B`@("`@("`@:68@*'1B;V1I97-;8UTN
M=&%G3F%M92`]/2`G5$)/1%DG*2!["B`@("`@("`@("`@('9A<B!T<G,@/2!T
M8F]D:65S6V-=+F-H:6QD3F]D97,["B`@("`@("`@("`@(&9O<B`H=F%R(&D@
M/2`P.R!I(#P@=')S+FQE;F=T:#L@:2LK*2!["B`@("`@("`@("`@("`@("!I
M9B`H=')S6VE=+G1A9TYA;64@/3T@)U12)RD@>PH@("`@("`@("`@("`@("`@
M("`@('1R<UMI72YC;&%S<TYA;64@/2!T<G-;:5TN8VQA<W-.86UE+G)E<&QA
M8V4H+R`_<F]W179E;B`_+RP@)R<I+G)E<&QA8V4H+R`_<F]W3V1D(#\O+"`G
M)RD["B`@("`@("`@("`@("`@("`@("`@:68@*'1R<UMI72YC;&%S<TYA;64I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@=')S6VE=+F-L87-S3F%M92`K
M/2`G("<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@('1R<UMI72YC;&%S<TYA;64@*ST@979E;B`_("=R;W=%=F5N)R`Z("=R
M;W=/9&0G.PH*("`@("`@("`@("`@("`@("`@("`O+R!&;&EP(&9R;VT@;V1D
M('1O(&5V96XL(&]R('9I8V4M=F5R<V$N"B`@("`@("`@("`@("`@("`@("`@
M979E;B`]("%E=F5N.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@?0I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O
M=&%B;&5S+FIS````````````````````````````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`R,C8R-P`Q,#4Q-30S,S<T-``P,C`Q,3,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+RHJ"B`J($IA=F%S
M8W)I<'0@8V]D92!F;W(@9FEN9&EN9R!A;&P@=&%B;&5S('=I=&@@8VQA<W-N
M86UE(")S=')I<&5D(B!A;F0*("H@9'EN86UI8V%L;'D@<W1R:7!I;F<@=&AE
M:7(@<F]W(&-O;&]R<RP@86YD(&9I;F1I;F<@86QL('1A8FQE<R!W:71H"B`J
M(&-L87-S;F%M92`B<V]R=&%B;&4B(&%N9"!M86MI;F<@=&AE;2!D>6YA;6EC
M86QL>2!S;W)T86)L92X*("H*("H@)$AO<F1E.B!H;W)D92]J<R]T86)L97,N
M:G,L=B`Q+C0N,BXS(#(P,#4O,3(O,#$@,C(Z-3@Z,C8@8VAU8VL@17AP("0*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J+PH*+RH@5V4@9&\@979E<GET:&EN9R!O;FQO860@
M<V\@=&AA="!T:&4@96YT:7)E(&1O8W5M96YT(&ES('!R97-E;G0*("H@8F5F
M;W)E('=E('-T87)T('-E87)C:&EN9R!I="!F;W(@=&%B;&5S+B`J+PII9B`H
M=VEN9&]W+F%D9$5V96YT3&ES=&5N97(I('L*("`@('=I;F1O=RYA9&1%=F5N
M=$QI<W1E;F5R*"=L;V%D)RP@=&%B;&5?:6YI="P@9F%L<V4I.PI](&5L<V4@
M:68@*'=I;F1O=RYA='1A8VA%=F5N="D@>PH@("`@=VEN9&]W+F%T=&%C:$5V
M96YT*"=O;FQO860G+"!T86)L95]I;FET*3L*?2!E;'-E(&EF("AW:6YD;W<N
M;VYL;V%D("$](&YU;&PI('L*("`@('9A<B!O;&1?;VYL;V%D(#T@=VEN9&]W
M+F]N;&]A9#L*("`@('=I;F1O=RYO;FQO860@/2!F=6YC=&EO;BAE*0H@("`@
M>PH@("`@("`@(&]L9%]O;FQO860H92D["B`@("`@("`@=&%B;&5?:6YI="@I
M.PH@("`@?3L*?2!E;'-E('L*("`@('=I;F1O=RYO;FQO860@/2!T86)L95]I
M;FET.PI]"@IV87(@4T]25%]#3TQ534Y?24Y$15@["@IF=6YC=&EO;B!T86)L
M95]I;FET*"D*>PH@("`@:68@*"%D;V-U;65N="YG971%;&5M96YT<T)Y5&%G
M3F%M92D@>PH@("`@("`@(')E='5R;CL*("`@('T*("`@('1A8FQE<R`](&1O
M8W5M96YT+F=E=$5L96UE;G1S0GE486=.86UE*"=T86)L92<I.PH@("`@9F]R
M("AI(#T@,#L@:2`\('1A8FQE<RYL96YG=&@[(&DK*RD@>PH@("`@("`@(&EF
M("AH87-#;&%S<RAT86)L97-;:5TL("=S=')I<&5D)RDI('L*("`@("`@("`@
M("`@=&%B;&5?<W1R:7!E*'1A8FQE<UMI72D["B`@("`@("`@?0H@("`@("`@
M(&EF("AH87-#;&%S<RAT86)L97-;:5TL("=S;W)T86)L92<I("8F('1A8FQE
M<UMI72YI9"D@>PH@("`@("`@("`@("!T86)L95]M86ME4V]R=&%B;&4H=&%B
M;&5S6VE=*3L*("`@("`@("!]"B`@("!]"GT*"F9U;F-T:6]N('1A8FQE7W-T
M<FEP92AT86)L92D*>PH@("`@+R\@5&AE(&9L86<@=V4G;&P@=7-E('1O(&ME
M97`@=')A8VL@;V8@=VAE=&AE<B!T:&4@8W5R<F5N="!R;W<@:7,*("`@("\O
M(&]D9"!O<B!E=F5N+@H@("`@=F%R(&5V96X@/2!F86QS93L*"B`@("`O+R!4
M86)L97,@8V%N(&AA=F4@;6]R92!T:&%N(&]N92!T8F]D>2!E;&5M96YT.R!G
M970@86QL(&-H:6QD"B`@("`O+R!T8F]D>2!T86=S(&%N9"!I;G1E<F%T92!T
M:')O=6=H('1H96TN"B`@("!V87(@=&)O9&EE<R`]('1A8FQE+F-H:6QD3F]D
M97,["B`@("!F;W(@*'9A<B!C(#T@,#L@8R`\('1B;V1I97,N;&5N9W1H.R!C
M*RLI('L*("`@("`@("!I9B`H=&)O9&EE<UMC72YT86=.86UE("$]("=40D]$
M62<I('L*("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@?0H*("`@("`@
M("!V87(@=')S(#T@=&)O9&EE<UMC72YC:&EL9$YO9&5S.PH@("`@("`@(&9O
M<B`H=F%R(&D@/2`P.R!I(#P@=')S+FQE;F=T:#L@:2LK*2!["B`@("`@("`@
M("`@(&EF("AT<G-;:5TN=&%G3F%M92`]/2`G5%(G*2!["B`@("`@("`@("`@
M("`@("!R96UO=F5#;&%S<RAT<G-;:5TL("=R;W=%=F5N)RD["B`@("`@("`@
M("`@("`@("!R96UO=F5#;&%S<RAT<G-;:5TL("=R;W=/9&0G*3L*("`@("`@
M("`@("`@("`@(&%D9$-L87-S*'1R<UMI72P@979E;B`_("=R;W=%=F5N)R`Z
M("=R;W=/9&0G*3L*"B`@("`@("`@("`@("`@("`O+R!&;&EP(&9R;VT@;V1D
M('1O(&5V96XL(&]R('9I8V4M=F5R<V$N"B`@("`@("`@("`@("`@("!E=F5N
M(#T@(65V96X["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"GT*"F9U
M;F-T:6]N('1A8FQE7VUA:V53;W)T86)L92AT86)L92D*>PH@("`@:68@*'1A
M8FQE+G)O=W,@)B8@=&%B;&4N<F]W<RYL96YG=&@@/B`P*2!["B`@("`@("`@
M=F%R(&9I<G-T4F]W(#T@=&%B;&4N<F]W<ULP73L*("`@('T*("`@(&EF("@A
M9FER<W12;W<I('L*("`@("`@("!R971U<FX["B`@("!]"@H@("`@+R\@5V4@
M:&%V92!A(&9I<G-T(')O=SH@87-S=6UE(&ET)W,@=&AE(&AE861E<BP@86YD
M(&UA:V4@:71S"B`@("`O+R!C;VYT96YT<R!C;&EC:V%B;&4@;&EN:W,N"B`@
M("!F;W(@*'9A<B!I(#T@,#L@:2`\(&9I<G-T4F]W+F-E;&QS+FQE;F=T:#L@
M:2LK*2!["B`@("`@("`@=F%R(&-E;&P@/2!F:7)S=%)O=RYC96QL<UMI73L*
M("`@("`@("!I9B`H:&%S0VQA<W,H8V5L;"P@)VYO<V]R="<I*2!["B`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@('T*"B`@("`@("`@8V5L;"YC;VQU
M;6Y);F1E>"`](&D["B`@("`@("`@8V5L;"YS='EL92YC=7)S;W(@/2`G<&]I
M;G1E<B<["B`@("`@("`@8V5L;"YO;F-L:6-K(#T@9G5N8W1I;VXH92D*("`@
M("`@("!["B`@("`@("`@("`@('9A<B!E(#T@92!\?"!W:6YD;W<N979E;G0[
M"@H@("`@("`@("`@("!I9B`H92YT87)G970I('L*("`@("`@("`@("`@("`@
M(&EF("AE+G1A<F=E="YN;V1E5'EP92`]/2`S*2!["B`@("`@("`@("`@("`@
M("`@("`@92YT87)G970@/2!E+G1A<F=E="YP87)E;G1.;V1E.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@:68@*&4N<W)C16QE;65N
M="D@>PH@("`@("`@("`@("`@("`@92YT87)G970@/2!E+G-R8T5L96UE;G0[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&5L(#T@:&%S4&%R96YT*&4N
M=&%R9V5T+"`G02<L("=42"<I.PH@("`@("`@("`@("!I9B`H96P@)B8@(6AA
M<T-L87-S*&5L+"`G<V]R=&QI;FLG*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@('1A8FQE7W)E
M<V]R=%1A8FQE*&=E=%!A<F5N="AE+G1A<F=E="P@)U1()RDI.PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0I]"@IF=6YC=&EO
M;B!T86)L95]G971);FYE<E1E>'0H96PI"GL*("`@(&EF("AT>7!E;V8@96P@
M/3T@)W-T<FEN9R<I('L*("`@("`@("!R971U<FX@96P["B`@("!]"B`@("!I
M9B`H='EP96]F(&5L(#T]("=U;F1E9FEN960G*2!["B`@("`@("`@<F5T=7)N
M(&5L.PH@("`@?0H@("`@:68@*&5L+FEN;F5R5&5X="D@>PH@("`@("`@("\O
M($YO="!N965D960@8G5T(&ET(&ES(&9A<W1E<BX*("`@("`@("!R971U<FX@
M96PN:6YN97)497AT.PH@("`@?0H*("`@('9A<B!S='(@/2`B(CL*("`@('9A
M<B!C<R`](&5L+F-H:6QD3F]D97,["B`@("!V87(@;"`](&-S+FQE;F=T:#L*
M("`@(&9O<B`H=F%R(&D@/2`P.R!I(#P@;#L@:2LK*2!["B`@("`@("`@<W=I
M=&-H("AC<UMI72YN;V1E5'EP92D@>PH@("`@("`@(&-A<V4@,3H*("`@("`@
M("`@("`@+R\@14Q%345.5%].3T1%"B`@("`@("`@("`@('-T<B`K/2!T86)L
M95]G971);FYE<E1E>'0H8W-;:5TI.PH@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@8V%S92`S.@H@("`@("`@("`@("`O+R!415A47TY/1$4*("`@("`@
M("`@("`@<W1R("L](&-S6VE=+FYO9&5686QU93L*("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@?0H@("`@?0H*("`@(')E='5R;B!S='(["GT*"F9U;F-T
M:6]N('1A8FQE7W)E<V]R=%1A8FQE*'1H*0I["B`@("!T86)L92`](&=E=%!A
M<F5N="AT:"P@)U1!0DQ%)RD["B`@("!S;W)T0V]L=6UN(#T@=&@N8V]L=6UN
M26YD97@["B`@("!S;W)T1&]W;B`](#`["@H@("`@+R\@3&]O<"!T:')O=6=H
M(#QT:&5A9#X@=&\@9FEN9"!T:&4@8W5R<F5N="!S;W)T(&-O;'5M;B!A;F0*
M("`@("\O(&1I<F5C=&EO;BX*("`@('1H96%D<R`]('1A8FQE+G1(96%D+F=E
M=$5L96UE;G1S0GE486=.86UE*"=T:"<I.PH@("`@9F]R("AI(#T@,#L@:2`\
M('1H96%D<RYL96YG=&@[(&DK*RD@>PH@("`@("`@(&EF("AT:"`]/2!T:&5A
M9'-;:5TI('L*("`@("`@("`@("`@:68@*&AA<T-L87-S*'1H96%D<UMI72P@
M)W-O<G1U<"<I*2!["B`@("`@("`@("`@("`@("!R96UO=F5#;&%S<RAT:&5A
M9'-;:5TL("=S;W)T=7`G*3L*("`@("`@("`@("`@("`@(&%D9$-L87-S*'1H
M96%D<UMI72P@)W-O<G1D;W=N)RD["B`@("`@("`@("`@('T@96QS92!I9B`H
M:&%S0VQA<W,H=&AE861S6VE=+"`G<V]R=&1O=VXG*2D@>PH@("`@("`@("`@
M("`@("`@<F5M;W9E0VQA<W,H=&AE861S6VE=+"`G<V]R=&1O=VXG*3L*("`@
M("`@("`@("`@("`@(&%D9$-L87-S*'1H96%D<UMI72P@)W-O<G1U<"<I.PH@
M("`@("`@("`@("`@("`@<V]R=$1O=VX@/2`Q.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@861D0VQA<W,H=&AE861S6VE=+"`G<V]R
M=&1O=VXG*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E;6]V94-L87-S*'1H96%D<UMI72P@)W-O<G1U<"<I.PH@("`@
M("`@("`@("!R96UO=F5#;&%S<RAT:&5A9'-;:5TL("=S;W)T9&]W;B<I.PH@
M("`@("`@('T*("`@('T*"B`@("`O+R!7;W)K(&]U="!A('1Y<&4@9F]R('1H
M92!C;VQU;6X*("`@(&EF("AT86)L92YR;W=S+FQE;F=T:"`\/2`Q*2!["B`@
M("`@("`@<F5T=7)N.PH@("`@?0H*("`@('9A<B!I=&T@/2!T86)L95]G971)
M;FYE<E1E>'0H=&%B;&4N<F]W<ULQ72YC96QL<UMS;W)T0V]L=6UN72D["B`@
M("!S;W)T9FX@/2!T86)L95]S;W)T7V-A<V5I;G-E;G-I=&EV93L*("`@(&EF
M("AI=&TN;6%T8V@H+UY<9%QD6UPO+5U<9%QD6UPO+5U<9%QD7&1<9"0O*2D@
M>PH@("`@("`@('-O<G1F;B`]('1A8FQE7W-O<G1?9&%T93L*("`@('T*("`@
M(&EF("AI=&TN;6%T8V@H+UY<9%QD6UPO+5U<9%QD6UPO+5U<9%QD)"\I*2![
M"B`@("`@("`@<V]R=&9N(#T@=&%B;&5?<V]R=%]D871E.PH@("`@?0H@("`@
M:68@*&ET;2YM871C:"@O7ENC)%TO*2D@>PH@("`@("`@('-O<G1F;B`]('1A
M8FQE7W-O<G1?8W5R<F5N8WD["B`@("!]"B`@("!I9B`H:71M+FUA=&-H*"]>
M6UQD7"Y=*R0O*2D@>PH@("`@("`@('-O<G1F;B`]('1A8FQE7W-O<G1?;G5M
M97)I8SL*("`@('T*"B`@("!33U)47T-/3%5-3E])3D1%6"`]('-O<G1#;VQU
M;6X["@H@("`@+R\@1&]N)W0@;6EX('5P('-E<&5R871E('1B;V1I97,[('-O
M<G0@96%C:"!I;B!T=7)N+@H@("`@9F]R("AI(#T@,#L@:2`\('1A8FQE+G1"
M;V1I97,N;&5N9W1H.R!I*RLI('L*("`@("`@("!T<G,@/2!T86)L92YT0F]D
M:65S6VE=+F=E=$5L96UE;G1S0GE486=.86UE*"=T<B<I.PH@("`@("`@(&YE
M=U)O=W,@/2!N97<@07)R87DH*3L*("`@("`@("!F;W(@*&H@/2`P.R!J(#P@
M=')S+FQE;F=T:#L@:BLK*2!["B`@("`@("`@("`@(&YE=U)O=W-;:ET@/2!T
M<G-;:ET["B`@("`@("`@?0H*("`@("`@("!N97=2;W=S+G-O<G0H<V]R=&9N
M*3L*("`@("`@("!I9B`H<V]R=$1O=VXI('L*("`@("`@("`@("`@;F5W4F]W
M<RYR979E<G-E*"D["B`@("`@("`@?0H*("`@("`@("`O+R!792!A<'!E;F1#
M:&EL9"!R;W=S('1H870@86QR96%D>2!E>&ES="!T;R!T:&4@=&)O9'DL('-O
M(&ET"B`@("`@("`@+R\@;6]V97,@=&AE;2!R871H97(@=&AA;B!C<F5A=&EN
M9R!N97<@;VYE<RX@1&]N)W0@9&\*("`@("`@("`O+R!S;W)T8F]T=&]M(')O
M=W,N"B`@("`@("`@9F]R("AJ(#T@,#L@:B`\(&YE=U)O=W,N;&5N9W1H.R!J
M*RLI('L*("`@("`@("`@("`@:68@*"%H87-#;&%S<RAN97=2;W=S6VI=+"`G
M<V]R=&)O='1O;2<I*2!["B`@("`@("`@("`@("`@("!T86)L92YT0F]D:65S
M6VE=+F%P<&5N9$-H:6QD*&YE=U)O=W-;:ETI.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O+R!$;R!S;W)T8F]T=&]M(')O=W,@;VYL>2X*
M("`@("`@("!F;W(@*&H@/2`P.R!J(#P@;F5W4F]W<RYL96YG=&@[(&HK*RD@
M>PH@("`@("`@("`@("!I9B`H:&%S0VQA<W,H;F5W4F]W<UMJ72P@)W-O<G1B
M;W1T;VTG*2D@>PH@("`@("`@("`@("`@("`@=&%B;&4N=$)O9&EE<UMI72YA
M<'!E;F1#:&EL9"AN97=2;W=S6VI=*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("`O+R!)9B!W92!J=7-T(')E<V]R=&5D(&$@<W1R:7!E
M9"!T86)L92P@<F4M<W1R:7!E(&ET+@H@("`@:68@*&AA<T-L87-S*'1A8FQE
M+"`G<W1R:7!E9"<I*2!["B`@("`@("`@=&%B;&5?<W1R:7!E*'1A8FQE*3L*
M("`@('T*"B`@("`O+R!&:6YA;&QY+"!S964@:68@=V4@:&%V92!A(&-A;&QB
M86-K(&9U;F-T:6]N('1O('1R:6=G97(N"B`@("!I9B`H='EP96]F*'1A8FQE
M7W-O<G1#86QL8F%C:RD@/3T@)V9U;F-T:6]N)RD@>PH@("`@("`@('1A8FQE
M7W-O<G1#86QL8F%C:RAT86)L92YI9"P@=&@N:60L('-O<G1$;W=N*3L*("`@
M('T*?0H*9G5N8W1I;VX@9V5T4&%R96YT*&5L+"!P5&%G3F%M92D*>PH@("`@
M:68@*&5L(#T](&YU;&PI('L*("`@("`@("!R971U<FX@;G5L;#L*("`@('T@
M96QS92!I9B`H<%1A9TYA;64@/3T@;G5L;"D@>PH@("`@("`@(')E='5R;B!E
M;"YP87)E;G1.;V1E.PH@("`@?2!E;'-E(&EF("AE;"YN;V1E5'EP92`]/2`Q
M("8F(&5L+G1A9TYA;64N=&],;W=E<D-A<V4H*2`]/2!P5&%G3F%M92YT;TQO
M=V5R0V%S92@I*2!["B`@("`@("`@+R\@1V5C:V\@8G5G+"!S=7!P;W-E9"!T
M;R!B92!U<'!E<F-A<V4N"B`@("`@("`@<F5T=7)N(&5L.PH@("`@?2!E;'-E
M('L*("`@("`@("!R971U<FX@9V5T4&%R96YT*&5L+G!A<F5N=$YO9&4L('!4
M86=.86UE*3L*("`@('T*?0H*9G5N8W1I;VX@=&%B;&5?<V]R=%]D871E*&$L
M(&(I"GL*("`@("\O(%1W;R!D:6=I="!Y96%R<R!L97-S('1H86X@-3`@87)E
M('1R96%T960@87,@,C!86"P@9W)E871E<B!T:&%N"B`@("`O+R`U,"!A<F4@
M=')E871E9"!A<R`Q.5A8+@H@("`@86$@/2!T86)L95]G971);FYE<E1E>'0H
M82YC96QL<UM33U)47T-/3%5-3E])3D1%6%TI.PH@("`@8F(@/2!T86)L95]G
M971);FYE<E1E>'0H8BYC96QL<UM33U)47T-/3%5-3E])3D1%6%TI.PH@("`@
M:68@*&%A+FQE;F=T:"`]/2`Q,"D@>PH@("`@("`@(&1T,2`](&%A+G-U8G-T
M<B@V+"`T*2`K(&%A+G-U8G-T<B@S+"`R*2`K(&%A+G-U8G-T<B@P+"`R*3L*
M("`@('T@96QS92!["B`@("`@("`@>7(@/2!A82YS=6)S='(H-BP@,BD["B`@
M("`@("`@:68@*'!A<G-E26YT*'ER*2`\(#4P*2!["B`@("`@("`@("`@('ER
M(#T@)S(P)R`K('ER.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('ER
M(#T@)S$Y)R`K('ER.PH@("`@("`@('T*("`@("`@("!D=#$@/2!Y<BMA82YS
M=6)S='(H,RP@,BD@*R!A82YS=6)S='(H,"P@,BD["B`@("!]"B`@("!I9B`H
M8F(N;&5N9W1H(#T](#$P*2!["B`@("`@("`@9'0R(#T@8F(N<W5B<W1R*#8L
M(#0I("L@8F(N<W5B<W1R*#,L(#(I("L@8F(N<W5B<W1R*#`L(#(I.PH@("`@
M?2!E;'-E('L*("`@("`@("!Y<B`](&)B+G-U8G-T<B@V+"`R*3L*("`@("`@
M("!I9B`H<&%R<V5);G0H>7(I(#P@-3`I('L*("`@("`@("`@("`@>7(@/2`G
M,C`G("L@>7(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@>7(@/2`G
M,3DG("L@>7(["B`@("`@("`@?0H@("`@("`@(&1T,B`]('ER("L@8F(N<W5B
M<W1R*#,L(#(I("L@8F(N<W5B<W1R*#`L(#(I.PH@("`@?0H@("`@:68@*&1T
M,2`]/2!D=#(I('L*("`@("`@("!R971U<FX@,#L*("`@('T@96QS92!I9B`H
M9'0Q(#P@9'0R*2!["B`@("`@("`@<F5T=7)N("TQ.PH@("`@?0H@("`@<F5T
M=7)N(#$["GT*"F9U;F-T:6]N('1A8FQE7W-O<G1?8W5R<F5N8WDH82P@8BD*
M>PH@("`@86$@/2!T86)L95]G971);FYE<E1E>'0H82YC96QL<UM33U)47T-/
M3%5-3E])3D1%6%TI+G)E<&QA8V4H+UM>,"TY+ETO9RP@)R<I.PH@("`@8F(@
M/2!T86)L95]G971);FYE<E1E>'0H8BYC96QL<UM33U)47T-/3%5-3E])3D1%
M6%TI+G)E<&QA8V4H+UM>,"TY+ETO9RP@)R<I.PH@("`@<F5T=7)N('!A<G-E
M1FQO870H86$I("T@<&%R<V5&;&]A="AB8BD["GT*"F9U;F-T:6]N('1A8FQE
M7W-O<G1?;G5M97)I8RAA+"!B*0I["B`@("!A82`]('!A<G-E1FQO870H=&%B
M;&5?9V5T26YN97)497AT*&$N8V5L;'-;4T]25%]#3TQ534Y?24Y$15A=*2D[
M"B`@("!I9B`H:7-.84XH86$I*2!["B`@("`@("`@86$@/2`P.PH@("`@?0H@
M("`@8F(@/2!P87)S949L;V%T*'1A8FQE7V=E=$EN;F5R5&5X="AB+F-E;&QS
M6U-/4E1?0T],54U.7TE.1$5872DI.PH@("`@:68@*&ES3F%.*&)B*2D@>PH@
M("`@("`@(&)B(#T@,#L*("`@('T*("`@(')E='5R;B!A82`M(&)B.PI]"@IF
M=6YC=&EO;B!T86)L95]S;W)T7V-A<V5I;G-E;G-I=&EV92AA+"!B*0I["B`@
M("!A82`]('1A8FQE7V=E=$EN;F5R5&5X="AA+F-E;&QS6U-/4E1?0T],54U.
M7TE.1$5872DN=&],;W=E<D-A<V4H*3L*("`@(&)B(#T@=&%B;&5?9V5T26YN
M97)497AT*&(N8V5L;'-;4T]25%]#3TQ534Y?24Y$15A=*2YT;TQO=V5R0V%S
M92@I.PH@("`@:68@*&%A(#T](&)B*2!["B`@("`@("`@<F5T=7)N(#`["B`@
M("!](&5L<V4@:68@*&%A(#P@8F(I('L*("`@("`@("!R971U<FX@+3$["B`@
M("!]"B`@("!R971U<FX@,3L*?0H*9G5N8W1I;VX@=&%B;&5?<V]R=%]D969A
M=6QT*&$L8BD*>PH@("`@86$@/2!T86)L95]G971);FYE<E1E>'0H82YC96QL
M<UM33U)47T-/3%5-3E])3D1%6%TI.PH@("`@8F(@/2!T86)L95]G971);FYE
M<E1E>'0H8BYC96QL<UM33U)47T-/3%5-3E])3D1%6%TI.PH@("`@:68@*&%A
M(#T](&)B*2!["B`@("`@("`@<F5T=7)N(#`["B`@("!](&5L<V4@:68@*&%A
M(#P@8F(I('L*("`@("`@("!R971U<FX@+3$["B`@("!]"B`@("!R971U<FX@
M,3L*?0H*+RHJ"B`J($1/32!U=&EL:71Y(&9U;F-T:6]N<RX*("HO"F9U;F-T
M:6]N(&AA<U!A<F5N="AE;"P@=&%G3F%M92P@=&%G4W1O<"D*>PH@("`@:68@
M*&5L+G1A9TYA;64@/3T@=&%G3F%M92D@>PH@("`@("`@(')E='5R;B!E;#L*
M("`@('T@96QS92!I9B`H=&%G4W1O<"`A/2!N=6QL("8F(&5L+G1A9TYA;64@
M/3T@=&%G4W1O<"D@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T@96QS
M92!["B`@("`@("`@<F5T=7)N(&AA<U!A<F5N="AG971087)E;G0H96PI+"!T
M86=.86UE+"!T86=3=&]P*3L*("`@('T*?0H*9G5N8W1I;VX@861D0VQA<W,H
M96PL(&-L87-S3F%M92D*>PH@("`@96PN8VQA<W-.86UE("L](&5L+F-L87-S
M3F%M92`_("<@)R`K(&-L87-S3F%M92`Z(&-L87-S3F%M93L*?0H*9G5N8W1I
M;VX@<F5M;W9E0VQA<W,H96PL(&-L87-S3F%M92D*>PH@("`@96PN8VQA<W-.
M86UE(#T@96PN8VQA<W-.86UE+G)E<&QA8V4H;F5W(%)E9T5X<"@G(#\G("L@
M8VQA<W-.86UE("L@)R`_)RDL("<G*3L*?0H*9G5N8W1I;VX@:&%S0VQA<W,H
M96PL(&-L87-S3F%M92D*>PH@("`@<F5T=7)N("AE;"YC;&%S<TYA;64N:6YD
M97A/9BAC;&%S<TYA;64I("$]("TQ*3L*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VIS+W1O;VQT:7`N:G,`````````````
M````````````````````````````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0R-S0`,3`U
M,34T,S,W-#0`,#(P,S,Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"\J*@H@*B!(;W)D92!4;V]L=&EP($IA=F%S8W)I<'0*
M("H*("H@4')O=FED97,@=&AE(&IA=F%S8W)I<'0@=&\@9&ES<&QA>2!T;V]L
M=&EP<RX*("H*("H@)$AO<F1E.B!H;W)D92]J<R]T;V]L=&EP+FIS+'8@,2XR
M+C$P+C(@,C`P-2\P-2\P,2`Q-CHU,SHS,"!C:'5C:R!%>'`@)`H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J+PH*=F%R(&%C=&EV951I;65O=70["@II9B`H='EP96]F(&1O
M8W5M96YT+F-A<'1U<F5%=F5N=',@(3T@)W5N9&5F:6YE9"<I('L*("`@(&1O
M8W5M96YT+F-A<'1U<F5%=F5N=',H179E;G0N34]54T5-3U9%*3L*("`@(&1O
M8W5M96YT+F]N;6]U<V5M;W9E(#T@;6]U<V50;W,["B`@("!V87(@;F5T6"P@
M;F5T63L*?0H*9G5N8W1I;VX@<&]S6"@I"GL*("`@('1E;7!8(#T@9&]C=6UE
M;G0N8F]D>2YS8W)O;&Q,969T("L@979E;G0N8VQI96YT6#L*("`@(&EF("AT
M96UP6"`\(#`I('L*("`@("`@("!T96UP6"`](#`["B`@("!]"B`@("!R971U
M<FX@=&5M<%@["GT*"F9U;F-T:6]N('!O<UDH*0I["B`@("!T96UP62`](&1O
M8W5M96YT+F)O9'DN<V-R;VQL5&]P("L@979E;G0N8VQI96YT63L*("`@(&EF
M("AT96UP62`\(#`I('L*("`@("`@("!T96UP62`](#`["B`@("!]"B`@("!R
M971U<FX@=&5M<%D["GT*"F9U;F-T:6]N(&UO=7-E4&]S*&4I"GL*("`@(&YE
M=%@@/2!E+G!A9V58.PH@("`@;F5T62`](&4N<&%G95D["GT*"F9U;F-T:6]N
M('1O;VQT:7!3:&]W*'!8+"!P62P@<W)C*0I["B`@("!I9B`H<%@@/"`Q*2![
M"B`@("`@("`@<%@@/2`Q.PH@("`@?0H@("`@:68@*'!9(#P@,2D@>PH@("`@
M("`@('!9(#T@,3L*("`@('T*("`@(&EF("AD;V-U;65N="YG971%;&5M96YT
M0GE)9"D@>PH@("`@("`@('1T(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H
M)W1O;VQT:7`G*3L*("`@("`@("!T="YS='EL92YL969T(#T@<%@@*R`G<'@G
M.PH@("`@("`@('1T+G-T>6QE+G1O<"`]('!9("L@)W!X)SL*("`@("`@("!T
M="YS='EL92YV:7-I8FEL:71Y(#T@)W9I<VEB;&4G.PH@("`@("`@('1T+FEN
M;F5R2%1-3"`]('-R8SL*("`@('T@96QS92!["B`@("`@("`@9&]C=6UE;G0N
M86QL+G1O;VQT:7`N<W1Y;&4N;&5F="`]('!8("L@)W!X)SL*("`@("`@("!D
M;V-U;65N="YA;&PN=&]O;'1I<"YS='EL92YT;W`@/2!P62`K("=P>"<["B`@
M("`@("`@9&]C=6UE;G0N86QL+G1O;VQT:7`N<W1Y;&4N=FES:6)I;&ET>2`]
M("=V:7-I8FQE)SL*("`@("`@("!D;V-U;65N="YA;&PN=&]O;'1I<"YI;FYE
M<DA434P@/2!S<F,["B`@("!]"GT*"F9U;F-T:6]N('1O;VQT:7!#;&]S92@I
M"GL*("`@(&EF("AD;V-U;65N="YG971%;&5M96YT0GE)9"D@>PH@("`@("`@
M('1T(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)W1O;VQT:7`G*3L*("`@
M("`@("!T="YS='EL92YV:7-I8FEL:71Y(#T@)VAI9&1E;B<["B`@("`@("`@
M='0N:6YN97)(5$U,(#T@)R<["B`@("!](&5L<V4@>PH@("`@("`@(&1O8W5M
M96YT+F%L;"YT;V]L=&EP+G-T>6QE+G9I<VEB:6QI='D@/2`G:&ED9&5N)SL*
M("`@("`@("!D;V-U;65N="YA;&PN=&]O;'1I<"YI;FYE<DA434P@/2`G)SL*
M("`@('T*("`@(&-L96%R5&EM96]U="AA8W1I=F54:6UE;W5T*3L*("`@('=I
M;F1O=RYS=&%T=7,@/2`G)SL*?0H*9G5N8W1I;VX@=&]O;'1I<$QI;FLH=&]O
M;'1E>'0L('-T871U<VQI;F4I"GL*("`@('1E>'0@/2`G/&1I=B!C;&%S<STB
M=&]O;'1I<"(^)R`K('1O;VQT97AT("L@)SPO9&EV/B<["B`@("!I9B`H='EP
M96]F(&1O8W5M96YT+F-A<'1U<F5%=F5N=',@(3T@)W5N9&5F:6YE9"<I('L*
M("`@("`@("!X<&]S(#T@;F5T6#L*("`@("`@("!Y<&]S(#T@;F5T63L*("`@
M('T@96QS92!["B`@("`@("`@>'!O<R`]('!O<U@H*3L*("`@("`@("!Y<&]S
M(#T@<&]S62@I.PH@("`@?0H@("`@86-T:79E5&EM96]U="`]('-E=%1I;65O
M=70H)W1O;VQT:7!3:&]W*'AP;W,@+2`Q,3`L('EP;W,@*R`Q-2P@=&5X="D[
M)RP@,S`P*3L*("`@('=I;F1O=RYS=&%T=7,@/2!S=&%T=7-L:6YE.PI]"@ID
M;V-U;65N="YW<FET92@G/&1I=B!I9#TB=&]O;'1I<"(@<W1Y;&4](G!O<VET
M:6]N.F%B<V]L=71E.R!V:7-I8FEL:71Y.FAI9&1E;CLB/CPO9&EV/B<I.PH`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B\`````````
M````````````````````````````````````````````````````````````
M````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`U,34T,S,W-3,`,#$V-#(T`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+RYH=&%C8V5S<P``````````````````````````````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`Q-@`Q,#4Q-30S,S<U,@`P,C`R,38`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````1&5N
M>2!F<F]M(&%L;`H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]A
M<&DN<&AP````````````````````````````````````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P-3(W-S4`,3`U,34T,S,W-3,`,#$W-S(V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!(
M;W)D92!E>'1E<FYA;"!!4$D@:6YT97)F86-E+@H@*@H@*B!4:&ES(&9I;&4@
M9&5F:6YE<R!(;W)D92=S(&5X=&5R;F%L($%022!I;G1E<F9A8V4N($]T:&5R
M"B`J(&%P<&QI8V%T:6]N<R!C86X@:6YT97)A8W0@=VET:"!(;W)D92!T:')O
M=6=H('1H:7,@05!)+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VQI8B]A<&DN<&AP
M+'8@,2XT,RXR+C4@,C`P-B\P-2\P-"`Q,SHR-SHR."!J86X@17AP("0*("H*
M("H@0'!A8VMA9V4@2&]R9&4*("HO"@HO*B!#;VUP;&5X('1Y<&5S+B`J+PHD
M7W1Y<&5S(#T@87)R87DH"B`@("`G>W5R;CIH;W)D97US=')I;F=!<G)A>2<@
M/3X@87)R87DH87)R87DH)VET96TG(#T^("=S=')I;F<G*2DL"B`@("`G:&%S
M:$ET96TG(#T^(&%R<F%Y*"=K97DG(#T^("=S=')I;F<G+"`G=F%L=64G(#T^
M("=S=')I;F<G*2P*("`@("=H87-H)R`]/B!A<G)A>2AA<G)A>2@G:71E;2<@
M/3X@)WMU<FXZ:&]R9&5]:&%S:$ET96TG*2DL"B`@("`G:&%S:$AA<VA)=&5M
M)R`]/B!A<G)A>2@G:V5Y)R`]/B`G<W1R:6YG)RP@)W9A;'5E)R`]/B`G>W5R
M;CIH;W)D97UH87-H)RDL"B`@("`G:&%S:$AA<V@G(#T^(&%R<F%Y*&%R<F%Y
M*"=I=&5M)R`]/B`G>W5R;CIH;W)D97UH87-H2&%S:$ET96TG*2DI.PH*+RH@
M3&ES=&EN9W,N("HO"B1?<V5R=FEC97-;)W!E<FUS)UT@/2!A<G)A>2@*("`@
M("=A<F=S)R`]/B!A<G)A>2@I+`H@("`@)W1Y<&4G(#T^("=[=7)N.FAO<F1E
M?7-T<FEN9T%R<F%Y)RD["@HD7W-E<G9I8V5S6R=A9&UI;E]L:7-T)UT@/2!A
M<G)A>2AT<G5E*3L*"B1?<V5R=FEC97-;)VQI<W1!<'!S)UT@/2!A<G)A>2@*
M("`@("=A<F=S)R`]/B!A<G)A>2@G9FEL=&5R)R`]/B`G>W5R;CIH;W)D97US
M=')I;F=!<G)A>2<I+`H@("`@)W1Y<&4G(#T^("=[=7)N.FAO<F1E?7-T<FEN
M9T%R<F%Y)PHI.PH*)%]S97)V:6-E<ULG;&ES=$%027,G72`](&%R<F%Y*`H@
M("`@)V%R9W,G(#T^(&%R<F%Y*"DL"B`@("`G='EP92<@/3X@)WMU<FXZ:&]R
M9&5]<W1R:6YG07)R87DG"BD["@HO*B!";&]C:W,N("HO"B1?<V5R=FEC97-;
M)V)L;V-K5&ET;&4G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=A
M<'`G(#T^("=S=')I;F<G+"`G;F%M92<@/3X@)W-T<FEN9R<L("=P87)A;7,G
M(#T^("=[=7)N.FAO<F1E?6AA<V@G*2P*("`@("=T>7!E)R`]/B`G<W1R:6YG
M)PHI.PH*)%]S97)V:6-E<ULG8FQO8VM#;VYT96YT)UT@/2!A<G)A>2@*("`@
M("=A<F=S)R`]/B!A<G)A>2@G87!P)R`]/B`G<W1R:6YG)RP@)VYA;64G(#T^
M("=S=')I;F<G+"`G<&%R86US)R`]/B`G>W5R;CIH;W)D97UH87-H)RDL"B`@
M("`G='EP92<@/3X@)W-T<FEN9R<**3L*"B1?<V5R=FEC97-;)V)L;V-K<R==
M(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH*2P*("`@("=T>7!E)R`]
M/B`G>W5R;CIH;W)D97UH87-H)PHI.PH*+RH@57-E<B!D871A+B`J+PHD7W-E
M<G9I8V5S6R=G9710<F5F97)E;F-E)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]
M/B!A<G)A>2@G87!P)R`]/B`G<W1R:6YG)RP@)W!R968G(#T^("=S=')I;F<G
M*2P*("`@("=T>7!E)R`]/B`G<W1R:6YG)PHI.PH*)%]S97)V:6-E<ULG<V5T
M4')E9F5R96YC92==(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH)V%P
M<"<@/3X@)W-T<FEN9R<L("=P<F5F)R`]/B`G<W1R:6YG)RP@)W9A;'5E)R`]
M/B`G<W1R:6YG)RDL"B`@("`G='EP92<@/3X@)V)O;VQE86XG"BD["@HD7W-E
M<G9I8V5S6R=R96UO=F55<V5R1&%T82==(#T@87)R87DH"B`@("`G87)G<R<@
M/3X@87)R87DH)W5S97(G(#T^("=S=')I;F<G*2P*("`@("=T>7!E)R`]/B`G
M8F]O;&5A;B<**3L*"B\J($=R;W5P<RX@*B\*)%]S97)V:6-E<ULG861D1W)O
M=7`G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=N86UE)R`]/B`G
M<W1R:6YG)RP@)W!A<F5N="<@/3X@)W-T<FEN9R<I+`H@("`@)W1Y<&4G(#T^
M("=B;V]L96%N)PHI.PH*)%]S97)V:6-E<ULG<F5M;W9E1W)O=7`G72`](&%R
M<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=N86UE)R`]/B`G<W1R:6YG)RDL
M"B`@("`G='EP92<@/3X@)V)O;VQE86XG"BD["@HO+R1?<V5R=FEC97-;)V=E
M=$=R;W5P<R==.R`_/S\*"B1?<V5R=FEC97-;)V%D9%5S97)4;T=R;W5P)UT@
M/2!A<G)A>2@*("`@("=A<F=S)R`]/B!A<G)A>2@G;F%M92<@/3X@)W-T<FEN
M9R<L("=U<V5R)R`]/B`G<W1R:6YG)RDL"B`@("`G='EP92<@/3X@)V)O;VQE
M86XG"BD["@HD7W-E<G9I8V5S6R=A9&15<V5R<U1O1W)O=7`G72`](&%R<F%Y
M*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=N86UE)R`]/B`G<W1R:6YG)RP@)W5S
M97)S)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A>2<I+`H@("`@)W1Y<&4G
M(#T^("=B;V]L96%N)PHI.PH*)%]S97)V:6-E<ULG<F5M;W9E57-E<D9R;VU'
M<F]U<"==(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH)VYA;64G(#T^
M("=S=')I;F<G+"`G=7-E<B<@/3X@)W-T<FEN9R<I+`H@("`@)W1Y<&4G(#T^
M("=B;V]L96%N)PHI.PH*)%]S97)V:6-E<ULG<F5M;W9E57-E<G-&<F]M1W)O
M=7`G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=N86UE)R`]/B`G
M<W1R:6YG)RP@)W5S97)S)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A>2<I
M+`H@("`@)W1Y<&4G(#T^("=B;V]L96%N)PHI.PH*)%]S97)V:6-E<ULG;&ES
M=%5S97)S3V9'<F]U<"==(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH
M)VYA;64G(#T^("=S=')I;F<G*2P*("`@("=T>7!E)R`]/B`G>W5R;CIH;W)D
M97US=')I;F=!<G)A>2<**3L*"B\J(%-H87)E<RX@*B\*)%]S97)V:6-E<ULG
M861D4VAA<F4G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=S:&%R
M95)O;W0G(#T^("=S=')I;F<G+"`G<VAA<F5.86UE)R`]/B`G<W1R:6YG)RP@
M)W-H87)E5&ET;&4G(#T^("=S=')I;F<G+"`G=7-E<DYA;64G(#T^("=S=')I
M;F<G*2P*("`@("=T>7!E)R`]/B`G8F]O;&5A;B<**3L*"B1?<V5R=FEC97-;
M)W)E;6]V95-H87)E)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]/B!A<G)A>2@G
M<VAA<F52;V]T)R`]/B`G<W1R:6YG)RP@)W-H87)E3F%M92<@/3X@)W-T<FEN
M9R<I+`H@("`@)W1Y<&4G(#T^("=B;V]L96%N)PHI.PH*)%]S97)V:6-E<ULG
M;&ES=%-H87)E<T]F3W=N97(G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R
M<F%Y*"=S:&%R95)O;W0G(#T^("=S=')I;F<G+"`G=7-E<DYA;64G(#T^("=S
M=')I;F<G*2P*("`@("=T>7!E)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A
M>2<**3L*"B1?<V5R=FEC97-;)V%D9%5S97)097)M:7-S:6]N<R==(#T@87)R
M87DH"B`@("`G87)G<R<@/3X@87)R87DH)W-H87)E4F]O="<@/3X@)W-T<FEN
M9R<L("=S:&%R94YA;64G(#T^("=S=')I;F<G+"`G=7-E<DYA;64G(#T^("=S
M=')I;F<G+"`G<&5R;6ES<VEO;G,G(#T^("=[=7)N.FAO<F1E?7-T<FEN9T%R
M<F%Y)RDL"B`@("`G='EP92<@/3X@)V)O;VQE86XG"BD["@HD7W-E<G9I8V5S
M6R=A9&1'<F]U<%!E<FUI<W-I;VYS)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]
M/B!A<G)A>2@G<VAA<F52;V]T)R`]/B`G<W1R:6YG)RP@)W-H87)E3F%M92<@
M/3X@)W-T<FEN9R<L("=G<F]U<$YA;64G(#T^("=S=')I;F<G+"`G<&5R;6ES
M<VEO;G,G(#T^("=[=7)N.FAO<F1E?7-T<FEN9T%R<F%Y)RDL"B`@("`G='EP
M92<@/3X@)V)O;VQE86XG"BD["@HD7W-E<G9I8V5S6R=S9715<V5R4&5R;6ES
M<VEO;G,G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=S:&%R95)O
M;W0G(#T^("=S=')I;F<G+"`G<VAA<F5.86UE)R`]/B`G<W1R:6YG)RP@)W5S
M97).86UE)R`]/B`G<W1R:6YG)RP@)W!E<FUI<W-I;VYS)R`]/B`G>W5R;CIH
M;W)D97US=')I;F=!<G)A>2<I+`H@("`@)W1Y<&4G(#T^("=B;V]L96%N)PHI
M.PH*)%]S97)V:6-E<ULG<V5T1W)O=7!097)M:7-S:6]N<R==(#T@87)R87DH
M"B`@("`G87)G<R<@/3X@87)R87DH)W-H87)E4F]O="<@/3X@)W-T<FEN9R<L
M("=S:&%R94YA;64G(#T^("=S=')I;F<G+"`G9W)O=7!.86UE)R`]/B`G<W1R
M:6YG)RP@)W!E<FUI<W-I;VYS)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A
M>2<I+`H@("`@)W1Y<&4G(#T^("=B;V]L96%N)PHI.PH*)%]S97)V:6-E<ULG
M<F5M;W9E57-E<E!E<FUI<W-I;VYS)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]
M/B!A<G)A>2@G<VAA<F52;V]T)R`]/B`G<W1R:6YG)RP@)W-H87)E3F%M92<@
M/3X@)W-T<FEN9R<L("=U<V5R3F%M92<@/3X@)W-T<FEN9R<I+`H@("`@)W1Y
M<&4G(#T^("=B;V]L96%N)PHI.PH*)%]S97)V:6-E<ULG<F5M;W9E1W)O=7!0
M97)M:7-S:6]N<R==(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH)W-H
M87)E4F]O="<@/3X@)W-T<FEN9R<L("=S:&%R94YA;64G(#T^("=S=')I;F<G
M+"`G9W)O=7!.86UE)R`]/B`G<W1R:6YG)RDL"B`@("`G='EP92<@/3X@)V)O
M;VQE86XG"BD["@HD7W-E<G9I8V5S6R=L:7-T57-E<E!E<FUI<W-I;VYS)UT@
M/2!A<G)A>2@*("`@("=A<F=S)R`]/B!A<G)A>2@G<VAA<F52;V]T)R`]/B`G
M<W1R:6YG)RP@)W-H87)E3F%M92<@/3X@)W-T<FEN9R<L("=U<V5R3F%M92<@
M/3X@)W-T<FEN9R<I+`H@("`@)W1Y<&4G(#T^("=[=7)N.FAO<F1E?7-T<FEN
M9T%R<F%Y)PHI.PH*)%]S97)V:6-E<ULG;&ES=$=R;W5P4&5R;6ES<VEO;G,G
M72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=S:&%R95)O;W0G(#T^
M("=S=')I;F<G+"`G<VAA<F5.86UE)R`]/B`G<W1R:6YG)RP@)V=R;W5P3F%M
M92<@/3X@)W-T<FEN9R<I+`H@("`@)W1Y<&4G(#T^("=[=7)N.FAO<F1E?7-T
M<FEN9T%R<F%Y)PHI.PH*)%]S97)V:6-E<ULG;&ES=%5S97)S3V93:&%R92==
M(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH)W-H87)E4F]O="<@/3X@
M)W-T<FEN9R<L("=S:&%R94YA;64G(#T^("=S=')I;F<G+"`G<&5R;6ES<VEO
M;G,G(#T^("=[=7)N.FAO<F1E?7-T<FEN9T%R<F%Y)RDL"B`@("`G='EP92<@
M/3X@)WMU<FXZ:&]R9&5]<W1R:6YG07)R87DG"BD["@HD7W-E<G9I8V5S6R=L
M:7-T1W)O=7!S3V93:&%R92==(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R
M87DH)W-H87)E4F]O="<@/3X@)W-T<FEN9R<L("=S:&%R94YA;64G(#T^("=S
M=')I;F<G+"`G<&5R;6ES<VEO;G,G(#T^("=[=7)N.FAO<F1E?7-T<FEN9T%R
M<F%Y)RDL"B`@("`G='EP92<@/3X@)WMU<FXZ:&]R9&5]<W1R:6YG07)R87DG
M"BD["@H*+RH@3&ES=&EN9W,N("HO"F9U;F-T:6]N(%]H;W)D95]P97)M<R@I
M"GL*("`@("1P97)M<R`](&%R<F%Y*"D["@H@("`@)'!E<FUS6R=T<F5E)UU;
M)VAO<F1E)UU;)VUA>%]B;&]C:W,G72`](&9A;'-E.PH@("`@)'!E<FUS6R=T
M:71L92==6R=H;W)D93IM87A?8FQO8VMS)UT@/2!?*")-87AI;75M($YU;6)E
M<B!O9B!0;W)T86P@0FQO8VMS(BD["B`@("`D<&5R;7-;)W1Y<&4G75LG:&]R
M9&4Z;6%X7V)L;V-K<R==(#T@)VEN="<["@H@("`@<F5T=7)N("1P97)M<SL*
M?0H*9G5N8W1I;VX@7VAO<F1E7V%D;6EN7VQI<W0H*0I["B`@("!R971U<FX@
M87)R87DH)V-O;F9I9W5R871I;VXG(#T^(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("`G;&EN:R<@/3X@)R5A<'!L:6-A=&EO;B4O861M:6XO<V5T=7`O
M)RP*("`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(E]3971U<"(I
M+`H@("`@("`@("`@("`@("`@("`@("`G:6-O;B<@/3X@)V-O;F9I9RYP;F<G
M*2P*("`@("`@("`@("`@("`@("`G=7-E<G,G(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@("`G;&EN:R<@/3X@)R5A<'!L:6-A=&EO;B4O861M:6XO
M=7-E<BYP:'`G+`H@("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@7R@B
M7U5S97)S(BDL"B`@("`@("`@("`@("`@("`@("`@("=I8V]N)R`]/B`G=7-E
M<BYP;F<G*2P*("`@("`@("`@("`@("`@("`G9W)O=7!S)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@("`@("`@("`@)VQI;FLG(#T^("<E87!P;&EC871I;VXE
M+V%D;6EN+V=R;W5P<RYP:'`G+`H@("`@("`@("`@("`@("`@("`@("`G;F%M
M92<@/3X@7R@B7T=R;W5P<R(I+`H@("`@("`@("`@("`@("`@("`@("`G:6-O
M;B<@/3X@)V=R;W5P+G!N9R<I+`H@("`@("`@("`@("`@("`@("=P97)M<R<@
M/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("=L:6YK)R`]/B`G)6%P
M<&QI8V%T:6]N)2]A9&UI;B]P97)M<R]I;F1E>"YP:'`G+`H@("`@("`@("`@
M("`@("`@("`@("`G;F%M92<@/3X@7R@B7U!E<FUI<W-I;VYS(BDL"B`@("`@
M("`@("`@("`@("`@("`@("=I8V]N)R`]/B`G<&5R;7,N<&YG)RDL"B`@("`@
M("`@("`@("`@("`@)V1A=&%T<F5E)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`@)VQI;FLG(#T^("<E87!P;&EC871I;VXE+V%D;6EN+V1A=&%T
M<F5E+G!H<"<L"B`@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B!?*")?
M1&%T851R964B*2P*("`@("`@("`@("`@("`@("`@("`@)VEC;VXG(#T^("=D
M871A=')E92YP;F<G*2P*("`@("`@("`@("`@("`@("`G<V5S<VEO;G,G(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`G;&EN:R<@/3X@)R5A<'!L
M:6-A=&EO;B4O861M:6XO<V5S<VEO;G,N<&AP)RP*("`@("`@("`@("`@("`@
M("`@("`@)VYA;64G(#T^(%\H(E-E<W-I;VYS(BDL"B`@("`@("`@("`@("`@
M("`@("`@("=I8V]N)R`]/B`G=7-E<BYP;F<G*2P*("`@("`@("`@("`@("`@
M("`G<&AP<VAE;&PG(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`G
M;&EN:R<@/3X@)R5A<'!L:6-A=&EO;B4O861M:6XO<&AP<VAE;&PN<&AP)RP*
M("`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(E!?2%`@4VAE;&PB
M*2P*("`@("`@("`@("`@("`@("`@("`@)VEC;VXG(#T^("=M:6UE+W!H<"YP
M;F<G*2P*("`@("`@("`@("`@("`@("`G<W%L<VAE;&PG(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`G;&EN:R<@/3X@)R5A<'!L:6-A=&EO;B4O
M861M:6XO<W%L<VAE;&PN<&AP)RP*("`@("`@("`@("`@("`@("`@("`@)VYA
M;64G(#T^(%\H(E-?44P@4VAE;&PB*2P*("`@("`@("`@("`@("`@("`@("`@
M)VEC;VXG(#T^("=S<6PN<&YG)RDL"B`@("`@("`@("`@("`@("`@)V-M9'-H
M96QL)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@)VQI;FLG(#T^
M("<E87!P;&EC871I;VXE+V%D;6EN+V-M9'-H96QL+G!H<"<L"B`@("`@("`@
M("`@("`@("`@("`@("=N86UE)R`]/B!?*")?0TQ)(BDL"B`@("`@("`@("`@
M("`@("`@("`@("=I8V]N)R`]/B`G<VAE;&PN<&YG)RDL"B`@("`@("`@("`@
M("`@("`@*3L*?0H*9G5N8W1I;VX@7VAO<F1E7VQI<W1!<'!S*"1F:6QT97(@
M/2!N=6QL*0I["B`@("!R971U<FX@)$=,3T)!3%-;)W)E9VES=')Y)UTM/FQI
M<W1!<'!S*"1F:6QT97(I.PI]"@IF=6YC=&EO;B!?:&]R9&5?;&ES=$%027,H
M*0I["B`@("!R971U<FX@)$=,3T)!3%-;)W)E9VES=')Y)UTM/FQI<W1!4$ES
M*"D["GT*"B\J($)L;V-K<RX@*B\*9G5N8W1I;VX@)E]H;W)D95]B;&]C:R@D
M87!P+"`D;F%M92P@)'!A<F%M<R`](&%R<F%Y*"DI"GL*("`@(&=L;V)A;"`D
M<F5G:7-T<GD["@H@("`@<F5Q=6ER95]O;F-E("=(;W)D92]";&]C:RYP:'`G
M.PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]";&]C:R]#;VQL96-T:6]N+G!H
M<"<["@H@("`@)')E<W5L="`]("1R96=I<W1R>2T^<'5S:$%P<"@D87!P*3L*
M("`@(&EF("@A:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@)')E<W5L="`]($AO<F1E7T)L;V-K7T-O;&QE8W1I;VXZ.F=E=$)L;V-K
M*"1A<'`L("1N86UE+"`D<&%R86US*3L*("`@("`@("`D<F5G:7-T<GDM/G!O
M<$%P<"@D87!P*3L*("`@('T*("`@(')E='5R;B`D<F5S=6QT.PI]"@IF=6YC
M=&EO;B!?:&]R9&5?8FQO8VM4:71L92@D87!P+"`D;F%M92P@)'!A<F%M<R`]
M(&%R<F%Y*"DI"GL*("`@("1B;&]C:R`]("9?:&]R9&5?8FQO8VLH)&%P<"P@
M)&YA;64L("1P87)A;7,I.PH@("`@:68@*&ES7V$H)&)L;V-K+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@<F5T=7)N("1B;&]C:RT^9V5T365S<V%G92@I
M.PH@("`@?0H@("`@<F5T=7)N("1B;&]C:RT^9V5T5&ET;&4H*3L*?0H*9G5N
M8W1I;VX@7VAO<F1E7V)L;V-K0V]N=&5N="@D87!P+"`D;F%M92P@)'!A<F%M
M<R`](&%R<F%Y*"DI"GL*("`@("1B;&]C:R`]("9?:&]R9&5?8FQO8VLH)&%P
M<"P@)&YA;64L("1P87)A;7,I.PH@("`@:68@*&ES7V$H)&)L;V-K+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N("1B;&]C:RT^9V5T365S<V%G
M92@I.PH@("`@?0H@("`@<F5T=7)N("1B;&]C:RT^9V5T0V]N=&5N="@I.PI]
M"@IF=6YC=&EO;B!?:&]R9&5?8FQO8VMS*"D*>PH@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<"<["B`@("`D8V]L;&5C=&EO
M;B`]("9(;W)D95]";&]C:U]#;VQL96-T:6]N.CIS:6YG;&5T;VXH*3L*("`@
M(&EF("AI<U]A*"1C;VQL96-T:6]N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@<F5T=7)N("1C;VQL96-T:6]N.PH@("`@?2!E;'-E('L*("`@("`@("!R
M971U<FX@)&-O;&QE8W1I;VXM/F=E=$)L;V-K<TQI<W0H*3L*("`@('T*?0H*
M+RH@57-E<B!D871A+B`J+PIF=6YC=&EO;B!?:&]R9&5?9V5T4')E9F5R96YC
M92@D87!P+"`D<')E9BD*>PH@("`@)$=,3T)!3%-;)W)E9VES=')Y)UTM/FQO
M8610<F5F<R@D87!P*3L*("`@(')E='5R;B`D1TQ/0D%,4ULG<')E9G,G72T^
M9V5T5F%L=64H)'!R968I.PI]"@IF=6YC=&EO;B!?:&]R9&5?<V5T4')E9F5R
M96YC92@D87!P+"`D<')E9BP@)'9A;'5E*0I["B`@("`D1TQ/0D%,4ULG<F5G
M:7-T<GDG72T^;&]A9%!R969S*"1A<'`I.PH@("`@<F5T=7)N("1'3$]"04Q3
M6R=P<F5F<R==+3YS971686QU92@D<')E9BP@)'9A;'5E*3L*?0H*9G5N8W1I
M;VX@7VAO<F1E7W)E;6]V955S97)$871A*"1U<V5R*0I["B`@("!G;&]B86P@
M)&-O;F8["@H@("`@<F5Q=6ER95]O;F-E("=(;W)D92]0<F5F<RYP:'`G.PH@
M("`@)'!R969S(#T@)E!R969S.CIS:6YG;&5T;VXH)&-O;F9;)W!R969S)UU;
M)V1R:79E<B==+"!N=6QL+"`D=7-E<BD["B`@("!I9B`H:7-?82@D<F5S=6QT
M(#T@)'!R969S+3YC;&5A<B@I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("!]"GT*"B\J($=R;W5P<RX@*B\*"B\J*@H@
M*B!!9&1S(&$@9W)O=7`@=&\@=&AE(&=R;W5P<R!S>7-T96TN"B`J"B`J($!P
M87)A;2!S=')I;F<@)&YA;64@("`@5&AE(&=R;W5P)W,@;F%M92X*("H@0'!A
M<F%M('-T<FEN9R`D<&%R96YT("!4:&4@9W)O=7`G<R!P87)E;G0G<R!N86UE
M+@H@*B\*9G5N8W1I;VX@7VAO<F1E7V%D9$=R;W5P*"1N86UE+"`D<&%R96YT
M(#T@;G5L;"D*>PH@("`@:68@*&5M<'1Y*"1P87)E;G0I*2!["B`@("`@("`@
M)'!A<F5N="`]($1!5$%44D5%7U)/3U0["B`@("!]"@H@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92]'<F]U<"YP:'`G.PH@("`@)&=R;W5P<R`]("9'<F]U<#HZ
M<VEN9VQE=&]N*"D["@H@("`@:68@*&ES7V$H)&=R;W5P(#T@)B1G<F]U<',M
M/FYE=T=R;W5P*"1N86UE+"`D<&%R96YT*2P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@(')E='5R;B`D9W)O=7`["B`@("!]"@H@("`@<F5T=7)N("1G<F]U
M<',M/F%D9$=R;W5P*"1G<F]U<"D["GT*"B\J*@H@*B!296UO=F5S(&$@9W)O
M=7`@9G)O;2!T:&4@9W)O=7!S('-Y<W1E;2X*("H*("H@0'!A<F%M('-T<FEN
M9R`D;F%M92`@5&AE(&=R;W5P)W,@;F%M92X*("HO"F9U;F-T:6]N(%]H;W)D
M95]R96UO=F5'<F]U<"@D;F%M92D*>PH@("`@<F5Q=6ER95]O;F-E("=(;W)D
M92]'<F]U<"YP:'`G.PH@("`@)&=R;W5P<R`]("9'<F]U<#HZ<VEN9VQE=&]N
M*"D["@H@("`@:68@*&ES7V$H)&=R;W5P(#T@)B1G<F]U<',M/F=E=$=R;W5P
M*"1N86UE*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R;B`D9W)O
M=7`["B`@("!]"@H@("`@<F5T=7)N("1G<F]U<',M/G)E;6]V94=R;W5P*"1G
M<F]U<"P@=')U92D["GT*"B\J*@H@*B!!9&1S(&$@=7-E<B!T;R!A(&=R;W5P
M+@H@*@H@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@9W)O=7`G<R!N86UE
M+@H@*B!`<&%R86T@<W1R:6YG("1U<V5R("!4:&4@=7-E<B!T;R!A9&0N"B`J
M+PIF=6YC=&EO;B!?:&]R9&5?861D57-E<E1O1W)O=7`H)&YA;64L("1U<V5R
M*0I["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T=R;W5P+G!H<"<["B`@("`D
M9W)O=7!S(#T@)D=R;W5P.CIS:6YG;&5T;VXH*3L*"B`@("!I9B`H:7-?82@D
M9W)O=7`@/2`F)&=R;W5P<RT^9V5T1W)O=7`H)&YA;64I+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@<F5T=7)N("1G<F]U<#L*("`@('T*"B`@("!R971U
M<FX@)&=R;W5P+3YA9&15<V5R*"1U<V5R*3L*?0H*+RHJ"B`J($%D9',@;75L
M=&EP;&4@=7-E<G,@=&\@82!G<F]U<"X*("H*("H@0'!A<F%M('-T<FEN9R`D
M;F%M92`@5&AE(&=R;W5P)W,@;F%M92X*("H@0'!A<F%M(&%R<F%Y("1U<V5R
M<R`@5&AE('5S97)S('1O(&%D9"X*("HO"F9U;F-T:6]N(%]H;W)D95]A9&15
M<V5R<U1O1W)O=7`H)&YA;64L("1U<V5R<RD*>PH@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92]'<F]U<"YP:'`G.PH@("`@)&=R;W5P<R`]("9'<F]U<#HZ<VEN
M9VQE=&]N*"D["@H@("`@:68@*&ES7V$H)&=R;W5P(#T@)B1G<F]U<',M/F=E
M=$=R;W5P*"1N86UE*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R
M;B`D9W)O=7`["B`@("!]"@H@("`@9F]R96%C:"`H)'5S97)S(&%S("1U<V5R
M*2!["B`@("`@("`@)&=R;W5P+3YA9&15<V5R*"1U<V5R+"!F86QS92D["B`@
M("!]"@H@("`@<F5T=7)N("1G<F]U<"T^<V%V92@I.PI]"@HO*BH*("H@4F5M
M;W9E<R!A('5S97(@9G)O;2!A(&=R;W5P+@H@*@H@*B!`<&%R86T@<W1R:6YG
M("1N86UE("!4:&4@9W)O=7`G<R!N86UE+@H@*B!`<&%R86T@<W1R:6YG("1U
M<V5R("!4:&4@=7-E<B!T;R!A9&0N"B`J+PIF=6YC=&EO;B!?:&]R9&5?<F5M
M;W9E57-E<D9R;VU'<F]U<"@D;F%M92P@)'5S97(I"GL*("`@(')E<75I<F5?
M;VYC92`G2&]R9&4O1W)O=7`N<&AP)SL*("`@("1G<F]U<',@/2`F1W)O=7`Z
M.G-I;F=L971O;B@I.PH*("`@(&EF("AI<U]A*"1G<F]U<"`]("8D9W)O=7!S
M+3YG971'<F]U<"@D;F%M92DL("=014%27T5R<F]R)RDI('L*("`@("`@("!R
M971U<FX@)&=R;W5P.PH@("`@?0H*("`@(')E='5R;B`D9W)O=7`M/G)E;6]V
M955S97(H)'5S97(I.PI]"@HO*BH*("H@4F5M;W9E<R!M=6QT:7!L92!U<V5R
M<R!F<F]M(&$@9W)O=7`N"B`J"B`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H
M92!G<F]U<"=S(&YA;64N"B`J($!P87)A;2!A<G)A>2`D=7-E<G,@(%1H92!U
M<V5R<R!T;R!A9&0N"B`J+PIF=6YC=&EO;B!?:&]R9&5?<F5M;W9E57-E<G-&
M<F]M1W)O=7`H)&YA;64L("1U<V5R<RD*>PH@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92]'<F]U<"YP:'`G.PH@("`@)&=R;W5P<R`]("9'<F]U<#HZ<VEN9VQE
M=&]N*"D["@H@("`@:68@*&ES7V$H)&=R;W5P(#T@)B1G<F]U<',M/F=E=$=R
M;W5P*"1N86UE*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R;B`D
M9W)O=7`["B`@("!]"@H@("`@9F]R96%C:"`H)'5S97)S(&%S("1U<V5R*2![
M"B`@("`@("`@)&=R;W5P+3YR96UO=F55<V5R*"1U<V5R+"!F86QS92D["B`@
M("!]"@H@("`@<F5T=7)N("1G<F]U<"T^<V%V92@I.PI]"@HO*BH*("H@4F5T
M=7)N<R!A(&QI<W0@;V8@=7-E<G,@=&AA="!A<F4@<&%R="!O9B!T:&ES(&=R
M;W5P("AA;F0@;VYL>2!T:&ES(&=R;W5P*0H@*@H@*B!`<F5T=7)N(&%R<F%Y
M("!4:&4@=7-E<B!L:7-T+@H@*B\*9G5N8W1I;VX@7VAO<F1E7VQI<W15<V5R
M<T]F1W)O=7`H)&YA;64I"GL*("`@(')E<75I<F5?;VYC92`G2&]R9&4O1W)O
M=7`N<&AP)SL*("`@("1G<F]U<',@/2`F1W)O=7`Z.G-I;F=L971O;B@I.PH*
M("`@(&EF("AI<U]A*"1G<F]U<"`]("8D9W)O=7!S+3YG971'<F]U<"@D;F%M
M92DL("=014%27T5R<F]R)RDI('L*("`@("`@("!R971U<FX@)&=R;W5P.PH@
M("`@?0H*("`@(')E='5R;B`D9W)O=7`M/FQI<W15<V5R<R@I.PI]"@HO*B!3
M:&%R97,N("HO"@HO*BH*("H@061D<R!A('-H87)E('1O('1H92!S:&%R97,@
M<WES=&5M+@H@*@H@*B!`<&%R86T@<W1R:6YG("1S:&%R95)O;W0@("!4:&4@
M;F%M92!O9B!T:&4@<VAA<F4@<F]O="P@92YG+B!T:&4*("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87!P;&EC871I;VX@=&AA="!T:&4@<VAA<F4@
M8F5L;VYG<R!T;RX*("H@0'!A<F%M('-T<FEN9R`D<VAA<F5.86UE("`@5&AE
M('-H87)E)W,@;F%M92X*("H@0'!A<F%M('-T<FEN9R`D<VAA<F54:71L92`@
M5&AE('-H87)E)W,@:'5M86X@<F5A9&%B;&4@=&ET;&4N"B`J($!P87)A;2!S
M=')I;F<@)'5S97).86UE("`@(%1H92!S:&%R92=S(&]W;F5R+@H@*B\*9G5N
M8W1I;VX@7VAO<F1E7V%D9%-H87)E*"1S:&%R95)O;W0L("1S:&%R94YA;64L
M("1S:&%R951I=&QE+"`D=7-E<DYA;64I"GL*("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O4VAA<F4N<&AP)SL*("`@("1S:&%R97,@/2`F2&]R9&5?4VAA<F4Z
M.G-I;F=L971O;B@D<VAA<F52;V]T*3L*"B`@("!I9B`H:7-?82@D<VAA<F4@
M/2`F)'-H87)E<RT^;F5W4VAA<F4H)'-H87)E3F%M92DL("=014%27T5R<F]R
M)RDI('L*("`@("`@("!R971U<FX@)'-H87)E.PH@("`@?0H@("`@)'-H87)E
M+3YS970H)V]W;F5R)RP@)'5S97).86UE*3L*("`@("1S:&%R92T^<V5T*"=N
M86UE)RP@)'-H87)E5&ET;&4I.PH*("`@(')E='5R;B`D<VAA<F5S+3YA9&13
M:&%R92@D<VAA<F4I.PI]"@HO*BH*("H@4F5M;W9E<R!A('-H87)E(&9R;VT@
M=&AE('-H87)E<R!S>7-T96T@<&5R;6%N96YT;'DN"B`J"B`J($!P87)A;2!S
M=')I;F<@)'-H87)E4F]O="`@5&AE(&YA;64@;V8@=&AE('-H87)E(')O;W0L
M(&4N9RX@=&AE"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@87!P;&EC
M871I;VX@=&AA="!T:&4@<VAA<F4@8F5L;VYG<R!T;RX*("H@0'!A<F%M('-T
M<FEN9R`D<VAA<F5.86UE("!4:&4@<VAA<F4G<R!N86UE+@H@*B\*9G5N8W1I
M;VX@7VAO<F1E7W)E;6]V95-H87)E*"1S:&%R95)O;W0L("1S:&%R94YA;64I
M"GL*("`@(')E<75I<F5?;VYC92`G2&]R9&4O4VAA<F4N<&AP)SL*("`@("1S
M:&%R97,@/2`F2&]R9&5?4VAA<F4Z.G-I;F=L971O;B@D<VAA<F52;V]T*3L*
M"B`@("!I9B`H:7-?82@D<VAA<F4@/2`F)'-H87)E<RT^9V5T4VAA<F4H)'-H
M87)E3F%M92DL("=014%27T5R<F]R)RDI('L*("`@("`@("!R971U<FX@)'-H
M87)E.PH@("`@?0H*("`@(')E='5R;B`D<VAA<F5S+3YR96UO=F53:&%R92@D
M<VAA<F4I.PI]"@HO*BH*("H@4F5T=7)N<R!A;B!A<G)A>2!O9B!A;&P@<VAA
M<F5S('1H870@)'5S97).86UE(&ES('1H92!O=VYE<B!O9BX*("H*("H@0'!A
M<F%M('-T<FEN9R`D<VAA<F52;V]T("!4:&4@;F%M92!O9B!T:&4@<VAA<F4@
M<F]O="P@92YG+B!T:&4*("H@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<'!L:6-A=&EO;B!T:&%T('1H92!S:&%R92!B96QO;F=S('1O+@H@*B!`<&%R
M86T@<W1R:6YG("1U<V5R3F%M92`@(%1H92!S:&%R92=S(&]W;F5R+@H@*@H@
M*B!`<F5T=7)N(&%R<F%Y("!4:&4@;&ES="!O9B!S:&%R97,N"B`J+PIF=6YC
M=&EO;B!?:&]R9&5?;&ES=%-H87)E<T]F3W=N97(H)'-H87)E4F]O="P@)'5S
M97).86UE*0I["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-H87)E+G!H<"<[
M"B`@("`D<VAA<F5S(#T@)DAO<F1E7U-H87)E.CIS:6YG;&5T;VXH)'-H87)E
M4F]O="D["@H@("`@)'-H87)E7VQI<W0@/2`F)'-H87)E<RT^;&ES=%-H87)E
M<R@D=7-E<DYA;64L(%!%4DU37U-(3U<L("1U<V5R3F%M92D["B`@("`D;7ES
M:&%R97,@/2!A<G)A>2@I.PH@("`@9F]R96%C:"`H)'-H87)E7VQI<W0@87,@
M)'-H87)E*2!["B`@("`@("`@)&UY<VAA<F5S6UT@/2`D<VAA<F4M/F=E=$YA
M;64H*3L*("`@('T*"B`@("!R971U<FX@)&UY<VAA<F5S.PI]"@HO*BH*("H@
M1VEV97,@82!U<V5R(&-E<G1A:6X@<')I=FEL96=E<R!F;W(@82!S:&%R92X*
M("H*("H@0'!A<F%M('-T<FEN9R`D<VAA<F52;V]T("`@5&AE(&YA;64@;V8@
M=&AE('-H87)E(')O;W0L(&4N9RX@=&AE"B`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%P<&QI8V%T:6]N('1H870@=&AE('-H87)E(&)E;&]N9W,@
M=&\N"B`J($!P87)A;2!S=')I;F<@)'-H87)E3F%M92`@(%1H92!S:&%R92=S
M(&YA;64N"B`J($!P87)A;2!S=')I;F<@)'5S97).86UE("`@(%1H92!U<V5R
M)W,@;F%M92X*("H@0'!A<F%M(&%R<F%Y("1P97)M:7-S:6]N<R`@02!L:7-T
M(&]F('!E<FUI<W-I;VYS("AS:&]W+"!R96%D+"!E9&ET+"!D96QE=&4I+@H@
M*B\*9G5N8W1I;VX@7VAO<F1E7V%D9%5S97)097)M:7-S:6]N<R@D<VAA<F52
M;V]T+"`D<VAA<F5.86UE+"`D=7-E<DYA;64L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!E<FUI<W-I;VYS*0I["B`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+U-H87)E+G!H<"<["B`@("`D<VAA<F5S(#T@)DAO<F1E
M7U-H87)E.CIS:6YG;&5T;VXH)'-H87)E4F]O="D["@H@("`@:68@*&ES7V$H
M)'-H87)E(#T@)B1S:&%R97,M/F=E=%-H87)E*"1S:&%R94YA;64I+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N("1S:&%R93L*("`@('T*"B`@
M("`D<&5R;2`]("8D<VAA<F4M/F=E=%!E<FUI<W-I;VXH*3L*("`@(&9O<F5A
M8V@@*"1P97)M:7-S:6]N<R!A<R`D<&5R;6ES<VEO;BD@>PH@("`@("`@("1P
M97)M:7-S:6]N(#T@4W1R:6YG.CIU<'!E<B@D<&5R;6ES<VEO;BD["B`@("`@
M("`@:68@*&1E9FEN960H)U!%4DU37R<@+B`D<&5R;6ES<VEO;BDI('L*("`@
M("`@("`@("`@)'!E<FTM/F%D9%5S97)097)M:7-S:6]N*"1U<V5R3F%M92P@
M8V]N<W1A;G0H)U!%4DU37R<@+B`D<&5R;6ES<VEO;BDL(&9A;'-E*3L*("`@
M("`@("!]"B`@("!]"B`@("!R971U<FX@)'-H87)E+3YS971097)M:7-S:6]N
M*"1P97)M*3L*?0H*+RHJ"B`J($=I=F5S(&$@9W)O=7`@8V5R=&%I;B!P<FEV
M:6QE9V5S(&9O<B!A('-H87)E+@H@*@H@*B!`<&%R86T@<W1R:6YG("1S:&%R
M95)O;W0@("!4:&4@;F%M92!O9B!T:&4@<VAA<F4@<F]O="P@92YG+B!T:&4*
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@87!P;&EC871I;VX@=&AA
M="!T:&4@<VAA<F4@8F5L;VYG<R!T;RX*("H@0'!A<F%M('-T<FEN9R`D<VAA
M<F5.86UE("`@5&AE('-H87)E)W,@;F%M92X*("H@0'!A<F%M('-T<FEN9R`D
M9W)O=7!.86UE("`@5&AE(&=R;W5P)W,@;F%M92X*("H@0'!A<F%M(&%R<F%Y
M("1P97)M:7-S:6]N<R`@02!L:7-T(&]F('!E<FUI<W-I;VYS("AS:&]W+"!R
M96%D+"!E9&ET+"!D96QE=&4I+@H@*B\*9G5N8W1I;VX@7VAO<F1E7V%D9$=R
M;W5P4&5R;6ES<VEO;G,H)'-H87)E4F]O="P@)'-H87)E3F%M92P@)&=R;W5P
M3F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!E
M<FUI<W-I;VYS*0I["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-H87)E+G!H
M<"<["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T=R;W5P+G!H<"<["B`@("`D
M<VAA<F5S(#T@)DAO<F1E7U-H87)E.CIS:6YG;&5T;VXH)'-H87)E4F]O="D[
M"B`@("`D9W)O=7!S(#T@)D=R;W5P.CIS:6YG;&5T;VXH*3L*"B`@("!I9B`H
M:7-?82@D<VAA<F4@/2`F)'-H87)E<RT^9V5T4VAA<F4H)'-H87)E3F%M92DL
M("=014%27T5R<F]R)RDI('L*("`@("`@("!R971U<FX@)'-H87)E.PH@("`@
M?0H@("`@:68@*&ES7V$H)&=R;W5P260@/2`D9W)O=7!S+3YG971'<F]U<$ED
M*"1G<F]U<$YA;64I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N
M("1G<F]U<$ED.PH@("`@?0H*("`@("1P97)M(#T@)B1S:&%R92T^9V5T4&5R
M;6ES<VEO;B@I.PH@("`@9F]R96%C:"`H)'!E<FUI<W-I;VYS(&%S("1P97)M
M:7-S:6]N*2!["B`@("`@("`@)'!E<FUI<W-I;VX@/2!3=')I;F<Z.G5P<&5R
M*"1P97)M:7-S:6]N*3L*("`@("`@("!I9B`H9&5F:6YE9"@G4$5235-?)R`N
M("1P97)M:7-S:6]N*2D@>PH@("`@("`@("`@("`D<&5R;2T^861D1W)O=7!0
M97)M:7-S:6]N*"1G<F]U<$ED+"!C;VYS=&%N="@G4$5235-?)R`N("1P97)M
M:7-S:6]N*2P@9F%L<V4I.PH@("`@("`@('T*("`@('T*("`@(')E='5R;B`D
M<VAA<F4M/G-E=%!E<FUI<W-I;VXH)'!E<FTI.PI]"@IF=6YC=&EO;B!?:&]R
M9&5?<V5T57-E<E!E<FUI<W-I;VYS*"1S:&%R95)O;W0L("1S:&%R94YA;64L
M("1U<V5R3F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<&5R;6ES<VEO;G,I"GL*?0H*9G5N8W1I;VX@7VAO<F1E7W-E=$=R;W5P
M4&5R;6ES<VEO;G,H)'-H87)E4F]O="P@)'-H87)E3F%M92P@)&=R;W5P3F%M
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!E<FUI
M<W-I;VYS*0I["GT*"B\J*@H@*B!296UO=F5S(&$@=7-E<B!F<F]M(&$@<VAA
M<F4N"B`J"B`J($!P87)A;2!S=')I;F<@)'-H87)E4F]O="`@(%1H92!N86UE
M(&]F('1H92!S:&%R92!R;V]T+"!E+F<N('1H90H@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!A<'!L:6-A=&EO;B!T:&%T('1H92!S:&%R92!B96QO
M;F=S('1O+@H@*B!`<&%R86T@<W1R:6YG("1S:&%R94YA;64@("!4:&4@<VAA
M<F4G<R!N86UE+@H@*B!`<&%R86T@<W1R:6YG("1U<V5R3F%M92`@("!4:&4@
M=7-E<B=S(&YA;64N"B`J+PIF=6YC=&EO;B!?:&]R9&5?<F5M;W9E57-E<E!E
M<FUI<W-I;VYS*"1S:&%R95)O;W0L("1S:&%R94YA;64L("1U<V5R3F%M92D*
M>PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]3:&%R92YP:'`G.PH@("`@)'-H
M87)E<R`]("9(;W)D95]3:&%R93HZ<VEN9VQE=&]N*"1S:&%R95)O;W0I.PH*
M("`@(&EF("AI<U]A*"1S:&%R92`]("8D<VAA<F5S+3YG9713:&%R92@D<VAA
M<F5.86UE*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R;B`D<VAA
M<F4["B`@("!]"@H@("`@<F5T=7)N("1S:&%R92T^<F5M;W9E57-E<B@D=7-E
M<DYA;64I.PI]"@HO*BH*("H@4F5M;W9E<R!A(&=R;W5P(&9R;VT@82!S:&%R
M92X*("H*("H@0'!A<F%M('-T<FEN9R`D<VAA<F52;V]T("`@5&AE(&YA;64@
M;V8@=&AE('-H87)E(')O;W0L(&4N9RX@=&AE"B`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%P<&QI8V%T:6]N('1H870@=&AE('-H87)E(&)E;&]N
M9W,@=&\N"B`J($!P87)A;2!S=')I;F<@)'-H87)E3F%M92`@(%1H92!S:&%R
M92=S(&YA;64N"B`J($!P87)A;2!S=')I;F<@)&=R;W5P3F%M92`@(%1H92!G
M<F]U<"=S(&YA;64N"B`J+PIF=6YC=&EO;B!?:&]R9&5?<F5M;W9E1W)O=7!0
M97)M:7-S:6]N<R@D<VAA<F52;V]T+"`D<VAA<F5.86UE+"`D9W)O=7!.86UE
M*0I["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-H87)E+G!H<"<["B`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+T=R;W5P+G!H<"<["B`@("`D<VAA<F5S(#T@
M)DAO<F1E7U-H87)E.CIS:6YG;&5T;VXH)'-H87)E4F]O="D["B`@("`D9W)O
M=7!S(#T@)D=R;W5P.CIS:6YG;&5T;VXH*3L*"B`@("!I9B`H:7-?82@D<VAA
M<F4@/2`F)'-H87)E<RT^9V5T4VAA<F4H)'-H87)E3F%M92DL("=014%27T5R
M<F]R)RDI('L*("`@("`@("!R971U<FX@)'-H87)E.PH@("`@?0H@("`@:68@
M*&ES7V$H)&=R;W5P260@/2`D9W)O=7!S+3YG971'<F]U<$ED*"1G<F]U<$YA
M;64I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N("1G<F]U<$ED
M.PH@("`@?0H*("`@(')E='5R;B`D<VAA<F4M/G)E;6]V94=R;W5P*"1G<F]U
M<$ED*3L*?0H*+RHJ"B`J(%)E='5R;G,@86X@87)R87D@;V8@86QL('5S97(@
M<&5R;6ES<VEO;G,@;VX@82!S:&%R92X*("H*("H@0'!A<F%M('-T<FEN9R`D
M<VAA<F52;V]T("`@5&AE(&YA;64@;V8@=&AE('-H87)E(')O;W0L(&4N9RX@
M=&AE"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%P<&QI8V%T:6]N
M('1H870@=&AE('-H87)E(&)E;&]N9W,@=&\N"B`J($!P87)A;2!S=')I;F<@
M)'-H87)E3F%M92`@(%1H92!S:&%R92=S(&YA;64N"B`J($!P87)A;2!S=')I
M;F<@)'5S97).86UE("`@(%1H92!U<V5R)W,@;F%M92X*("H*("H@0')E='5R
M;B!A<G)A>2`@06QL('5S97(@<&5R;6ES<VEO;G,@9F]R('1H:7,@<VAA<F4N
M"B`J+PIF=6YC=&EO;B!?:&]R9&5?;&ES=%5S97)097)M:7-S:6]N<R@D<VAA
M<F52;V]T+"`D<VAA<F5.86UE+"`D=7-E<DYA;64I"GL*("`@("1P97)M7VUA
M<"`](&%R<F%Y*%!%4DU37U-(3U<@/3X@)W-H;W<G+`H@("`@("`@("`@("`@
M("`@("`@("`@4$5235-?4D5!1"`]/B`G<F5A9"<L"B`@("`@("`@("`@("`@
M("`@("`@("!015)-4U]%1$E4(#T^("=E9&ET)RP*("`@("`@("`@("`@("`@
M("`@("`@(%!%4DU37T1%3$5412`]/B`G9&5L971E)RD["@H@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]3:&%R92YP:'`G.PH@("`@)'-H87)E<R`]("9(;W)D
M95]3:&%R93HZ<VEN9VQE=&]N*"1S:&%R95)O;W0I.PH*("`@(&EF("AI<U]A
M*"1S:&%R92`]("8D<VAA<F5S+3YG9713:&%R92@D<VAA<F5.86UE*2P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R;B`D<VAA<F4["B`@("!]"@H@
M("`@)'!E<FT@/2`F)'-H87)E+3YG971097)M:7-S:6]N*"D["B`@("`D<&5R
M;6ES<VEO;G,@/2`D<&5R;2T^9V5T57-E<E!E<FUI<W-I;VYS*"D["B`@("!I
M9B`H96UP='DH)'!E<FUI<W-I;VYS6R1U<V5R3F%M95TI*2!["B`@("`@("`@
M<F5T=7)N(&%R<F%Y*"D["B`@("!]"@H@("`@)'5S97)?<&5R;6ES<VEO;G,@
M/2!A<G)A>2@I.PH@("`@9F]R96%C:"`H87)R87E?:V5Y<RA097)M<SHZ:6YT
M96=E<E1O07)R87DH)'!E<FUI<W-I;VYS6R1U<V5R3F%M95TI*2!A<R`D<&5R
M;6ES<VEO;BD@>PH@("`@("`@("1U<V5R7W!E<FUI<W-I;VYS6UT@/2`D<&5R
M;5]M87!;)'!E<FUI<W-I;VY=.PH@("`@?0H*("`@(')E='5R;B`D=7-E<E]P
M97)M:7-S:6]N<SL*?0H*+RHJ"B`J(%)E='5R;G,@86X@87)R87D@;V8@86QL
M(&=R;W5P('!E<FUI<W-I;VYS(&]N(&$@<VAA<F4N"B`J"B`J($!P87)A;2!S
M=')I;F<@)'-H87)E4F]O="`@(%1H92!N86UE(&]F('1H92!S:&%R92!R;V]T
M+"!E+F<N('1H90H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<'!L
M:6-A=&EO;B!T:&%T('1H92!S:&%R92!B96QO;F=S('1O+@H@*B!`<&%R86T@
M<W1R:6YG("1S:&%R94YA;64@("!4:&4@<VAA<F4G<R!N86UE+@H@*B!`<&%R
M86T@<W1R:6YG("1G<F]U<$YA;64@("!4:&4@9W)O=7`G<R!N86UE+@H@*@H@
M*B!`<F5T=7)N(&%R<F%Y("!!;&P@9W)O=7`@<&5R;6ES<VEO;G,@9F]R('1H
M:7,@<VAA<F4N"B`J+PIF=6YC=&EO;B!?:&]R9&5?;&ES=$=R;W5P4&5R;6ES
M<VEO;G,H)'-H87)E4F]O="P@)'-H87)E3F%M92P@)&=R;W5P3F%M92D*>PH@
M("`@)'!E<FU?;6%P(#T@87)R87DH4$5235-?4TA/5R`]/B`G<VAO=R<L"B`@
M("`@("`@("`@("`@("`@("`@("!015)-4U]214%$(#T^("=R96%D)RP*("`@
M("`@("`@("`@("`@("`@("`@(%!%4DU37T5$250@/3X@)V5D:70G+`H@("`@
M("`@("`@("`@("`@("`@("`@4$5235-?1$5,151%(#T^("=D96QE=&4G*3L*
M"B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-H87)E+G!H<"<["B`@("`D<VAA
M<F5S(#T@)DAO<F1E7U-H87)E.CIS:6YG;&5T;VXH)'-H87)E4F]O="D["@H@
M("`@:68@*&ES7V$H)'-H87)E(#T@)B1S:&%R97,M/F=E=%-H87)E*"1S:&%R
M94YA;64I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N("1S:&%R
M93L*("`@('T*"B`@("`D<&5R;2`]("8D<VAA<F4M/F=E=%!E<FUI<W-I;VXH
M*3L*("`@("1P97)M:7-S:6]N<R`]("1P97)M+3YG971'<F]U<%!E<FUI<W-I
M;VYS*"D["B`@("!I9B`H96UP='DH)'!E<FUI<W-I;VYS6R1G<F]U<$YA;65=
M*2D@>PH@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@?0H*("`@("1G<F]U
M<%]P97)M:7-S:6]N<R`](&%R<F%Y*"D["B`@("!F;W)E86-H("AA<G)A>5]K
M97ES*%!E<FUS.CII;G1E9V5R5&]!<G)A>2@D<&5R;6ES<VEO;G-;)&=R;W5P
M3F%M95TI*2!A<R`D<&5R;6ES<VEO;BD@>PH@("`@("`@("1G<F]U<%]P97)M
M:7-S:6]N<UM=(#T@)'!E<FU?;6%P6R1P97)M:7-S:6]N73L*("`@('T*"B`@
M("!R971U<FX@)&=R;W5P7W!E<FUI<W-I;VYS.PI]"@HO*BH*("H@4F5T=7)N
M<R!A(&QI<W0@;V8@=7-E<G,@=VAI8V@@:&%V92!H879E(&-E<G1A:6X@<&5R
M;6ES<VEO;G,@;VX@82!S:&%R92X*("H*("H@0'!A<F%M('-T<FEN9R`D<VAA
M<F52;V]T("`@5&AE(&YA;64@;V8@=&AE('-H87)E(')O;W0L(&4N9RX@=&AE
M"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%P<&QI8V%T:6]N('1H
M870@=&AE('-H87)E(&)E;&]N9W,@=&\N"B`J($!P87)A;2!S=')I;F<@)'-H
M87)E3F%M92`@(%1H92!S:&%R92=S(&YA;64N"B`J($!P87)A;2!A<G)A>2`D
M<&5R;6ES<VEO;G,@($$@;&ES="!O9B!P97)M:7-S:6]N<R`H<VAO=RP@<F5A
M9"P@961I="P@9&5L971E*2X*("H*("H@0')E='5R;B!A<G)A>2`@3&ES="!O
M9B!U<V5R<R!W:71H('1H92!S<&5C:69I960@<&5R;6ES<VEO;G,N"B`J+PIF
M=6YC=&EO;B!?:&]R9&5?;&ES=%5S97)S3V93:&%R92@D<VAA<F52;V]T+"`D
M<VAA<F5.86UE+"`D<&5R;6ES<VEO;G,I"GL*("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O4VAA<F4N<&AP)SL*("`@("1S:&%R97,@/2`F2&]R9&5?4VAA<F4Z
M.G-I;F=L971O;B@D<VAA<F52;V]T*3L*"B`@("!I9B`H:7-?82@D<VAA<F4@
M/2`F)'-H87)E<RT^9V5T4VAA<F4H)'-H87)E3F%M92DL("=014%27T5R<F]R
M)RDI('L*("`@("`@("!R971U<FX@)'-H87)E.PH@("`@?0H*("`@("1P97)M
M(#T@,#L*("`@(&9O<F5A8V@@*"1P97)M:7-S:6]N<R!A<R`D<&5R;6ES<VEO
M;BD@>PH@("`@("`@("1P97)M:7-S:6]N(#T@4W1R:6YG.CIU<'!E<B@D<&5R
M;6ES<VEO;BD["B`@("`@("`@:68@*&1E9FEN960H)U!%4DU37R<@+B`D<&5R
M;6ES<VEO;BDI('L*("`@("`@("`@("`@)'!E<FT@)CT@8V]N<W1A;G0H)U!%
M4DU37R<@+B`D<&5R;6ES<VEO;BD["B`@("`@("`@?0H@("`@?0H*("`@(')E
M='5R;B`D<VAA<F4M/FQI<W15<V5R<R@D<&5R;2D["GT*"B\J*@H@*B!2971U
M<FYS(&$@;&ES="!O9B!G<F]U<',@=VAI8V@@:&%V92!H879E(&-E<G1A:6X@
M<&5R;6ES<VEO;G,@;VX@82!S:&%R92X*("H*("H@0'!A<F%M('-T<FEN9R`D
M<VAA<F52;V]T("`@5&AE(&YA;64@;V8@=&AE('-H87)E(')O;W0L(&4N9RX@
M=&AE"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%P<&QI8V%T:6]N
M('1H870@=&AE('-H87)E(&)E;&]N9W,@=&\N"B`J($!P87)A;2!S=')I;F<@
M)'-H87)E3F%M92`@(%1H92!S:&%R92=S(&YA;64N"B`J($!P87)A;2!A<G)A
M>2`D<&5R;6ES<VEO;G,@($$@;&ES="!O9B!P97)M:7-S:6]N<R`H<VAO=RP@
M<F5A9"P@961I="P@9&5L971E*2X*("H*("H@0')E='5R;B!A<G)A>2`@3&ES
M="!O9B!G<F]U<',@=VET:"!T:&4@<W!E8VEF:65D('!E<FUI<W-I;VYS+@H@
M*B\*9G5N8W1I;VX@7VAO<F1E7VQI<W1'<F]U<'-/9E-H87)E*"1S:&%R95)O
M;W0L("1S:&%R94YA;64L("1P97)M:7-S:6]N<RD*>PH@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92]3:&%R92YP:'`G.PH@("`@)'-H87)E<R`]("9(;W)D95]3
M:&%R93HZ<VEN9VQE=&]N*"1S:&%R95)O;W0I.PH*("`@(&EF("AI<U]A*"1S
M:&%R92`]("8D<VAA<F5S+3YG9713:&%R92@D<VAA<F5.86UE*2P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@(')E='5R;B`D<VAA<F4["B`@("!]"@H@("`@
M)'!E<FT@/2`P.PH@("`@9F]R96%C:"`H)'!E<FUI<W-I;VYS(&%S("1P97)M
M:7-S:6]N*2!["B`@("`@("`@)'!E<FUI<W-I;VX@/2!3=')I;F<Z.G5P<&5R
M*"1P97)M:7-S:6]N*3L*("`@("`@("!I9B`H9&5F:6YE9"@G4$5235-?)R`N
M("1P97)M:7-S:6]N*2D@>PH@("`@("`@("`@("`D<&5R;2`F/2!C;VYS=&%N
M="@G4$5235-?)R`N("1P97)M:7-S:6]N*3L*("`@("`@("!]"B`@("!]"@H@
M("`@<F5T=7)N("1S:&%R92T^;&ES=$=R;W5P<R@D<&5R;2D["GT*````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O8F%S92YP:'``````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-#8T`#$P
M-3$U-#,S-S4R`#`R,#`U-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@2&]R9&4@8F%S92!I;F-L=7-I
M;VX@9FEL92X*("H*("H@5&AI<R!F:6QE(&)R:6YG<R!I;B!A;&P@;V8@=&AE
M(&1E<&5N9&5N8VEE<R!T:&%T($AO<F1E"B`J(&9R86UE=V]R:RUL979E;"!S
M8W)I<'1S('=I;&P@;F5E9"P@86YD('-E=',@=7`@;V)J96-T<R!T:&%T(&%L
M;`H@*B!S8W)I<'1S('5S92X*("H*("H@3F]T93H@5&AI<R!B87-E(&9I;&4@
M9&]E<R!?;F]T7R!C:&5C:R!A=71H96YT:6-A=&EO;BP@<V\@87,@=&\*("H@
M879O:60@86X@:6YF:6YI=&4@;&]O<"!O;B!T:&4@2&]R9&4@;&]G:6X@<&%G
M92X@66]U)VQL(&YE960@=&\@9&\*("H@:70@>6]U<G-E;&8@:6X@9G)A;65W
M;W)K+6QE=F5L('!A9V5S+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VQI8B]B87-E
M+G!H<"QV(#$N-#`N,3`N,R`R,#`V+S`Q+S`Q(#(Q.C(Y.C`U(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@HO+R!#:&5C:R!F
M;W(@82!P<FEO<B!D969I;FET:6]N(&]F($A/4D1%7T)!4T4@*'!E<FAA<',@
M8GD@86X*+R\@875T;U]P<F5P96YD7V9I;&4@9&5F:6YI=&EO;B!F;W(@<VET
M92!C=7-T;VUI>F%T:6]N*2X*:68@*"%D969I;F5D*"=(3U)$15]"05-%)RDI
M('L*("`@($!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?
M*2`N("<O+BXG*3L*?0H*+R\@3&]A9"!T:&4@2&]R9&4@1G)A;65W;W)K(&-O
M<F4L(&%N9"!S970@=7`@:6YC;'5S:6]N('!A=&AS+@IR97%U:7)E7V]N8V4@
M2$]21$5?0D%312`N("<O;&EB+V-O<F4N<&AP)SL*"B\O(%)E9VES=')Y+@HD
M<V5S<VEO;E]C;VYT<F]L(#T@571I;#HZ;F]N26YP=71687(H)W-E<W-I;VY?
M8V]N=')O;"<I.PII9B`H)'-E<W-I;VY?8V]N=')O;"`]/2`G;F]N92<I('L*
M("`@("1R96=I<W1R>2`]("9296=I<W1R>3HZ<VEN9VQE=&]N*$A/4D1%7U-%
M4U-)3TY?3D].12D["GT@96QS96EF("@D<V5S<VEO;E]C;VYT<F]L(#T]("=R
M96%D;VYL>2<I('L*("`@("1R96=I<W1R>2`]("9296=I<W1R>3HZ<VEN9VQE
M=&]N*$A/4D1%7U-%4U-)3TY?4D5!1$].3%DI.PI](&5L<V4@>PH@("`@)')E
M9VES=')Y(#T@)E)E9VES=')Y.CIS:6YG;&5T;VXH*3L*?0II9B`H:7-?82@H
M)'!U<VAE9"`]("1R96=I<W1R>2T^<'5S:$%P<"@G:&]R9&4G+"`A9&5F:6YE
M9"@G05542%](04Y$3$52)RDI*2P@)U!%05)?17)R;W(G*2D@>PH@("`@:68@
M*"1P=7-H960M/F=E=$-O9&4H*2`]/2`G<&5R;6ES<VEO;E]D96YI960G*2![
M"B`@("`@("`@2&]R9&4Z.F%U=&AE;G1I8V%T:6]N1F%I;'5R95)E9&ER96-T
M*"D["B`@("!]"B`@("!(;W)D93HZ9F%T86PH)'!U<VAE9"P@7U]&24Q%7U\L
M(%]?3$E.15]?+"!F86QS92D["GT*)&-O;F8@/2`F)$=,3T)!3%-;)V-O;F8G
M73L*0&1E9FEN92@G2$]21$5?5$5-4$Q!5$53)RP@)')E9VES=')Y+3YG970H
M)W1E;7!L871E<R<I*3L*"B\O($YO=&EF:6-A=&EO;B!3>7-T96TN"B1N;W1I
M9FEC871I;VX@/2`F3F]T:69I8V%T:6]N.CIS:6YG;&5T;VXH*3L*)&YO=&EF
M:6-A=&EO;BT^871T86-H*"=S=&%T=7,G*3L*"B\J(%-E="!U<"!T:&4@;65N
M=2X@*B\*<F5Q=6ER95]O;F-E("=(;W)D92]-96YU+G!H<"<["B1M96YU(#T@
M)FYE=R!-96YU*"D["@HO+R!#;VUP<F5S<R!O=71P=70*2&]R9&4Z.F-O;7!R
M97-S3W5T<'5T*"D["@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+T)L;V-K+P``````````````````````
M````````````````````````````````````````````````````````````
M```P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,S<T-@`P,3<T-C``(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O0FQO8VLO
M86-C;W5N="YP:'``````````````````````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#0S-S$U`#$P-3$U-#,S-S0U`#`R,38S-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`H*)&)L;V-K7VYA;64@
M/2!?*")!8V-O=6YT($EN9F]R;6%T:6]N(BD["@HO*BH*("H@)$AO<F1E.B!H
M;W)D92]L:6(O0FQO8VLO86-C;W5N="YP:'`L=B`Q+C<N,BXT(#(P,#8O,#,O
M,3`@,3<Z,C@Z-#0@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`Q+3(P
M,#8@17)I8R!2;W-T971T97(@/&5R:6,N<F]S=&5T=&5R0'!H>7-I8W,N=71E
M>&%S+F5D=3X*("H@0V]P>7)I9VAT(#(P,#4M,C`P-B!*86X@4V-H;F5I9&5R
M(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0'-I;F-E("`@
M2&]R9&4@,RXQ"B`J($!P86-K86=E($AO<F1E7T)L;V-K"B`J+PIC;&%S<R!(
M;W)D95]";&]C:U](;W)D95]A8V-O=6YT(&5X=&5N9',@2&]R9&5?0FQO8VL@
M>PH*("`@('9A<B`D7V%P<"`]("=H;W)D92<["@H@("`@+RHJ"B`@("`@*B!4
M:&4@=&ET;&4@=&\@9V\@:6X@=&AI<R!B;&]C:RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@(%1H92!T:71L92!T97AT+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?=&ET;&4H*0H@("`@>PH@("`@("`@(')E='5R;B!?*")->2!!
M8V-O=6YT($EN9F]R;6%T:6]N(BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4
M:&4@8V]N=&5N="!T;R!G;R!I;B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("`@5&AE(&-O;G1E;G0*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V-O;G1E;G0H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T
M<GDL("1C;VYF.PH*("`@("`@("!S=VET8V@@*"1C;VYF6R=A8V-O=6YT<R==
M6R=D<FEV97(G72D@>PH@("`@("`@(&-A<V4@)VYU;&PG.@H@("`@("`@("`@
M("`D;7ED<FEV97(@/2`F;F5W($%C8V]U;G1S7T1R:79E<B@I.PH@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("!C87-E("=L;V-A;&AO<W0G.@H@("`@("`@
M(&-A<V4@)VQD87`G.@H@("`@("`@("`@("`D8VQA<W,@/2`G06-C;W5N='-?
M1')I=F5R7R<@+B`D8V]N9ELG86-C;W5N=',G75LG9')I=F5R)UT["B`@("`@
M("`@("`@("1M>61R:79E<B`]("9N97<@)&-L87-S*"1C;VYF6R=A8V-O=6YT
M<R==6R=P87)A;7,G72D["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("!]"@H@("`@
M("`@("\O($-H96-K(&9O<B!P87-S=V]R9"!S=&%T=7,N"B`@("`@("`@:68@
M*&ES7V$H)'-T871U<R`]("1M>61R:79E<BT^8VAE8VM087-S=V]R9%-T871U
M<R@I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1S=&%T=7,@/2`D
M<W1A='5S+3YG971-97-S86=E*"D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M:7-?82@D=7-E<FYA;64@/2`D;7ED<FEV97(M/F=E=%5S97)N86UE*"DL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1U<V5R;F%M92T^
M9V5T365S<V%G92@I.PH@("`@("`@('T*("`@("`@("`D=&%B;&4@/2!A<G)A
M>2A?*"),;V=I;B(I(#T^("1U<V5R;F%M92D["B`@("`@("`@:68@*&ES7V$H
M)&9U;&QN86UE(#T@)&UY9')I=F5R+3YG971&=6QL;F%M92@I+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D9G5L;&YA;64M/F=E=$UE
M<W-A9V4H*3L*("`@("`@("!](&5L<V5I9B`H)&9U;&QN86UE*2!["B`@("`@
M("`@("`@("1T86)L95M?*")&=6QL($YA;64B*5T@/2`D9G5L;&YA;64["B`@
M("`@("`@?0H@("`@("`@(&EF("AI<U]A*"1H;VUE(#T@)&UY9')I=F5R+3YG
M971(;VUE*"DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1H;VUE+3YG971-97-S86=E*"D["B`@("`@("`@?2!E;'-E:68@*"1H;VUE
M*2!["B`@("`@("`@("`@("1T86)L95M?*")(;VUE($1I<F5C=&]R>2(I72`]
M("1H;VUE.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?82@D<VAE;&P@/2`D
M;7ED<FEV97(M/F=E=%-H96QL*"DL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1S:&5L;"T^9V5T365S<V%G92@I.PH@("`@("`@('T@
M96QS96EF("@D<VAE;&PI('L*("`@("`@("`@("`@)'1A8FQE6U\H(D1E9F%U
M;'0@4VAE;&PB*5T@/2`D<VAE;&P["B`@("`@("`@?0H@("`@("`@(&EF("AI
M<U]A*"1Q=6]T82`]("1M>61R:79E<BT^9V5T475O=&$H*2P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'%U;W1A+3YG971-97-S86=E
M*"D["B`@("`@("`@?2!E;'-E:68@*"1Q=6]T82D@>PH@("`@("`@("`@("`D
M=&%B;&5;7R@B475O=&$B*5T@/2!S<')I;G1F*%\H(B4N,F9-0B!U<V5D(&]F
M("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'%U;W1A6R=U<V5D)UT@+R`H(#$P
M,C0@*B`Q,#(T+C`I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1Q=6]T85LG;&EM:70G72`O("@@,3`R-"`J(#$P,C0N,"DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*"1Q
M=6]T85LG=7-E9"==("H@,3`P+C`I("\@)'%U;W1A6R=L:6UI="==*3L*("`@
M("`@("!]"B`@("`@("`@:68@*&ES7V$H)&QA<W1C:&%N9V4@/2`D;7ED<FEV
M97(M/F=E=%!A<W-W;W)D0VAA;F=E*"DL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1L87-T8VAA;F=E+3YG971-97-S86=E*"D["B`@
M("`@("`@?2!E;'-E:68@*"1L87-T8VAA;F=E*2!["B`@("`@("`@("`@("1T
M86)L95M?*"),87-T(%!A<W-W;W)D($-H86YG92(I72`]("1L87-T8VAA;F=E
M.PH@("`@("`@('T*"B`@("`@("`@)&]U='!U="`]("<\=&%B;&4@8VQA<W,]
M(FET96TB('=I9'1H/2(Q,#`E(B!C96QL<W!A8VEN9STB,2(^)SL*"B`@("`@
M("`@:68@*"%E;7!T>2@D<W1A='5S*2D@>PH@("`@("`@("`@("`D;W5T<'5T
M("X]("<\='(^/'1D(&-O;'-P86X](C(B/CQP(&-L87-S/2)N;W1I8V4B/B<@
M+@H@("`@("`@("`@("`@("`@2&]R9&4Z.FEM9R@G86QE<G1S+W=A<FYI;F<N
M<&YG)RP@7R@B5V%R;FEN9R(I*2`N"B`@("`@("`@("`@("`@("`G)FYB<W`[
M)FYB<W`[)R`N("1S=&%T=7,@+B`G/"]P/CPO=&0^/"]T<CXG.PH@("`@("`@
M('T*"B`@("`@("`@9F]R96%C:"`H)'1A8FQE(&%S("1K97D@/3X@)'9A;'5E
M*2!["B`@("`@("`@("`@("1O=71P=70@+CT@(CQT<B!C;&%S<SU<(G1E>'1<
M(CX\=&0^)&ME>3PO=&0^/'1D/B1V86QU93PO=&0^/"]T<CY<;B(["B`@("`@
M("`@?0H@("`@("`@("1O=71P=70@+CT@(CPO=&%B;&4^7&XB.PH*("`@("`@
M("!I9B`H)')E9VES=')Y+3YG970H)W-T871U<R<L("=F;W)W87)D<R<I("$]
M("=I;F%C=&EV92<@)B8*("`@("`@("`@("`@)')E9VES=')Y+3YH87--971H
M;V0H)W-U;6UA<GDG+"`G9F]R=V%R9',G*2D@>PH@("`@("`@("`@("`D<W5M
M;6%R>2`]("1R96=I<W1R>2T^8V%L;$)Y4&%C:V%G92@G9F]R=V%R9',G+"`G
M<W5M;6%R>2<I.PH@("`@("`@("`@("!I9B`H(6ES7V$H)'-U;6UA<GDL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1O=71P=70@+CT@)SQB
M<B`O/B<@+B`D<W5M;6%R>2`N(")<;B(["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@:68@*"1R96=I<W1R>2T^9V5T*"=S=&%T=7,G+"`G=F%C
M871I;VXG*2`A/2`G:6YA8W1I=F4G("8F"B`@("`@("`@("`@("1R96=I<W1R
M>2T^:&%S365T:&]D*"=S=6UM87)Y)RP@)W9A8V%T:6]N)RDI('L*("`@("`@
M("`@("`@)'-U;6UA<GD@/2`D<F5G:7-T<GDM/F-A;&Q">5!A8VMA9V4H)W9A
M8V%T:6]N)RP@)W-U;6UA<GDG*3L*("`@("`@("`@("`@:68@*"%I<U]A*"1S
M=6UM87)Y+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D;W5T
M<'5T("X]("<\8G(@+SXG("X@)'-U;6UA<GD@+B`B7&XB.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&]U='!U=#L*("`@('T*
M"GT*"B\J*@H@*B!!8V-O=6YT<U]$<FEV97(Z.B!D969I;F5S(&%N($%022!F
M;W(@9V5T=&EN9R]D:7-P;&%Y:6YG(&%C8V]U;G0@:6YF;W)M871I;VX*("H@
M9F]R(&$@=7-E<B!F;W(@=&AE(&%C8V]U;G1S(&UO9'5L92X*("H*("H@0V]P
M>7)I9VAT(#(P,#$M,C`P-B!%<FEC(%)O<W1E='1E<B`\97)I8RYR;W-T971T
M97)`<&AY<VEC<RYU=&5X87,N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@17)I8R!2;W-T971T97(@/&5R:6,N<F]S=&5T=&5R0'!H>7-I8W,N
M=71E>&%S+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXQ"B`J($!P86-K86=E
M($AO<F1E7T)L;V-K"B`J+PIC;&%S<R!!8V-O=6YT<U]$<FEV97(@>PH*("`@
M("\J*@H@("`@("H@17)R;W(@<W1R:6YG(')E='5R;F5D('1O('5S97(@:68@
M86X@97)R;W(@;V-C=7)S+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D97)R7W-T<CL*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE('5S97)N86UE+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@;&]W97)C87-E9"!U<V5R;F%M92X*("`@("`J"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%5S97)N86UE*"D*("`@('L*("`@("`@("`D875T:"`]
M(&5X<&QO9&4H)T`G+"!!=71H.CIG971!=71H*"DI.PH@("`@("`@(')E='5R
M;B!3=')I;F<Z.FQO=V5R*"1A=71H6S!=*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE('5S97(@<F5A;&TN"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!U<V5R(')E86QM+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971296%L;2@I"B`@("!["B`@("`@("`@)&%U=&@@/2!E>'!L;V1E
M*"=`)RP@075T:#HZ9V5T075T:"@I*3L*("`@("`@("!R971U<FX@:7-S970H
M)&%U=&A;,5TI(#\@)&%U=&A;,5T@.B`G)SL*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE('5S97(G<R!Q=6]T82!I9B!A=F%I;&%B;&4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@02!Q=6]T82!A<G)A>2P@96QE
M;65N=',@87)E('5S960@8GET97,@86YD(&QI;6ET(&)Y=&5S(&]N"B`@("`@
M*B`@("`@("`@("`@("`@("!S=6-C97-S+"!F86QS92!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G9711=6]T82@I"B`@("!["B`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@=7-E<B=S(&9U;&P@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!4:&4@=7-E<B=S(&9U;&P@;F%M92`H<W1R:6YG*2P@;W(@9F%L<V4@
M*&5R<F]R*2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1G5L;&YA;64H*0H@
M("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE('5S97(G<R!H;VUE("AL;V=I;BD@9&ER96-T;W)Y
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!U<V5R)W,@9&ER
M96-T;W)Y("AS=')I;F<I+"!O<B!F86QS92`H97)R;W(I+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971(;VUE*"D*("`@('L*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!U<V5R)W,@
M9&5F875L="!S:&5L;"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M:&4@=7-E<B=S('-H96QL("AS=')I;F<I+"!O<B!F86QS92`H97)R;W(I+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G9713:&5L;"@I"B`@("!["B`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@9&%T92!O9B!T:&4@=7-E<B=S(&QA<W0@<&%S<W=O<F0@8VAA;F=E+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@($1A=&4@<W1R:6YG("AS=')I
M;F<I(&]R(&9A;'-E("AE<G)O<BDN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%!A<W-W;W)D0VAA;F=E*"D*("`@('L*("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!S=&%T=7,@;V8@
M=&AE(&-U<G)E;G0@<&%S<W=O<F0N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@02!S=')I;F<@=VET:"!A('=A<FYI;F<@;65S<V%G92!I9B!T:&4@
M<&%S<W=O<F0@:7,@86)O=70*("`@("`J("`@("`@("`@("`@("`@('1O(&5X
M<&ER92P@4$5!4E]%<G)O<B!O;B!E<G)O<B!A;F0@9F%L<V4@;W1H97)W:7-E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!C:&5C:U!A<W-W;W)D4W1A='5S*"D*
M("`@('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@I]"@HO*BH*("H@
M26UP;&5M96YT<R!T:&4@06-C;W5N=',@05!)(&9O<B!S97)V97)S('=I=&@@
M=6YI>"!A8V-O=6YT<R!O;B!T:&4@;&]C86QH;W-T"B`J(&UA8VAI;F4@*'-A
M;64@;6%C:&EN92!A<R!T:&4@=V5B('-E<G9E<BDN("!3:&]U;&0@=V]R:R!F
M;W(@;&]C86P@=6YI>`H@*B!A8V-O=6YT<RP@;FES+VYI<RL@86-C;W5N=',L
M(&]R(&%N>2!004T@;W)I96YT960@86-C;W5N=',@=&AA="!A<'!E87(@87,*
M("H@;&]C86P@86-C;W5N=',@;VX@=&AE(&QO8V%L(&UA8VAI;F4N("!4:&4@
M97AC97!T:6]N(&ES('1H92!Q=6]T82!S=7!P;W)T+@H@*B!3964@=&AA="!R
M;W5T:6YE(&9O<B!A9&1I=&EO;F%L(&-O;6UE;G1S+@H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,BTR,#`V($5R:6,@2F]N(%)O<W1E='1E<B`\97)I8RYR;W-T971T
M97)`<&AY<VEC<RYU=&5X87,N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@17)I8R!2;W-T971T97(@/&5R:6,N<F]S='1T97)`<&AY<VEC<RYU
M=&5X87,N961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C$*("H@0'!A8VMA9V4@
M2&]R9&5?0FQO8VL*("HO"F-L87-S($%C8V]U;G1S7T1R:79E<E]L;V-A;&AO
M<W0@97AT96YD<R!!8V-O=6YT<U]$<FEV97(@>PH*("`@("\J*@H@("`@("H@
M2&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D<&%R86US(#T@
M87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!(87-H(&-O;G1A:6YI;F<@
M8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!
M8V-O=6YT<U]$<FEV97)?;&]C86QH;W-T*"1P87)A;7,@/2!A<G)A>2@I*0H@
M("`@>PH@("`@("`@("1T:&ES+3YP87)A;7,@/2`D<&%R86US.PH@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/G!A<F%M<ULG<75O=&%?<&%T:"==*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^<&%R86US6R=Q=6]T85]P871H)UT@/2`G<75O
M=&$G.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YP87)A
M;7-;)V=R97!?<&%T:"==*2D@>PH@("`@("`@("`@("`D=&AI<RT^<&%R86US
M6R=G<F5P7W!A=&@G72`]("=G<F5P)SL*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!U<V5R(&%C8V]U;G0@9G)O;2!T:&4@
M<&]S:7@@:6YF;W)M871I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>2`@02!H87-H('=I=&@@8V]M<&QE=&4@86-C;W5N="!D971A:6QS+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?9V5T06-C;W5N="@I"B`@("!["B`@("`@("`@
M<W1A=&EC("1I;F9O<FUA=&EO;CL*"B`@("`@("`@:68@*"%I<W-E="@D:6YF
M;W)M871I;VXI*2!["B`@("`@("`@("`@("\O('1H:7,@=V]N)W0@=V]R:R!I
M9B!W92!D;VXG="!H879E('!O<VEX(&5X=&5N<VEO;G,*("`@("`@("`@("`@
M:68@*"%5=&EL.CIE>'1E;G-I;VY%>&ES=',H)W!O<VEX)RDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E!/4TE8(&5X
M=&5N<VEO;B!I<R!M:7-S:6YG(BDI.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D=7-E<B`](%-T<FEN9SHZ;&]W97(H)'1H:7,M/F=E=%5S97)N86UE
M*"DI.PH@("`@("`@("`@("`D:6YF;W)M871I;VX@/2!P;W-I>%]G971P=VYA
M;2@D=7-E<BD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN9F]R;6%T
M:6]N.PH@("`@?0H*("`@("\J*@H@("`@("H@26UP;&5M96YT('1H92!1=6]T
M82!!4$D@9F]R($E-05`@<V5R=F5R<R!W:71H(&$@=6YI>"!Q=6]T82!C;VUM
M86YD+@H@("`@("H@5&AI<R!M87D@<F5Q=6ER92!A(&UO9&EF:65D(")Q=6]T
M82(@8V]M;6%N9"!T:&%T(&%L;&]W<R!T:&4@:'1T<&0*("`@("`J('-E<G9E
M<B!A8V-O=6YT('1O(&=E="!Q=6]T87,@9F]R(&]T:&5R('5S97)S+BXN("!)
M="!R97%U:7)E<R!T:&%T('EO=7(*("`@("`J('=E8B!S97)V97(@86YD('5S
M97(@<V5R=F5R(&)E('1H92!S86UE('-E<G9E<B!O<B!A="!L96%S="!H879E
M('-H87)E9`H@("`@("H@875T:&5N=&EC871I;VX@86YD(&9I;&4@<V5R=F5R
M<R`H92YG+B!V:6$@3DE3+TY&4RDN("!!;F0@;&%S="P@:70@*&%S"B`@("`@
M*B!W<FET=&5N*2!R97%U:7)E<R!T:&4@<&]S:7@@<&AP(&5X=&5N<VEO;G,N
M"B`@("`@*@H@("`@("H@268@>6]U<B!Q=6]T82!C;VUM86YD('=R87!S('1H
M92!O=71P=70@;VYT;R!T=V\@;&EN97,L('1H96X@=&AI<R!M;V1U;&4*("`@
M("`J('=I;&P@;VYL>2!W;W)K(&EF('EO=2!H879E(&$@9W)E<"!W:&EC:"!S
M=7!P;W)T<R!T:&4@+4$@<W=I=&-H+"!A;F0@>6]U"B`@("`@*B!A<'!E;F0@
M86X@+4$Q('-W:71C:"!T;R!Y;W5R(&=R97!?<&%T:"`H92YG+B`G+V)I;B]G
M<F5P("U!,2<I+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!Q
M=6]T82!H87-H("AB>71E<R!U<V5D+"!L:6UI="D@;W(@9F%L<V4@9F]R(&5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9711=6]T82@I"B`@("!["B`@
M("`@("`@)&EN9F]R;6%T:6]N(#T@)'1H:7,M/E]G971!8V-O=6YT*"D["B`@
M("`@("`@:68@*&ES7V$H)&EN9F]R;6%T:6]N+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D:6YF;W)M871I;VX["B`@("`@("`@?0H*
M("`@("`@("`D:&]M961I<B`]("1I;F9O<FUA=&EO;ELG9&ER)UT["@H@("`@
M("`@("\O($EF('=E('=A;G0@;6]U;G0@<&]I;G0@=')A;G-L871I;VYS+"!T
M:&5N('1R86YS;&%T92!T:&4@;&]G:6X@9&ER"B`@("`@("`@+R\@;F%M92!T
M;R!A(&UO=6YT('!O:6YT+B`@268@;F]T+"!T:&5N('-I;7!L>2!P87)S92!O
M=70@=&AE(&1E=FEC90H@("`@("`@("\O(&YA;64@9G)O;2!T:&4@;&]G:6X@
M9&ER96-T;W)Y+"!A;F0@=7-E('1H870@:6YS=&5A9"X*("`@("`@("!I9B`H
M)'1H:7,M/G!A<F%M<ULG=')A;G-L871E36]U;G10;VEN="==("8F"B`@("`@
M("`@("`@(&9I;&5?97AI<W1S*"1T:&ES+3YP87)A;7-;)W1R86YS;&%T:6]N
M5&%B;&4G72DI"B`@("`@("`@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)T9I;&4O1G-T86(N<&AP)SL*("`@("`@("`@("`@)'-Y<U1A8B`]($9I;&5?
M1G-T86(Z.G-I;F=L971O;B@D=&AI<RT^<&%R86US6R=T<F%N<VQA=&EO;E1A
M8FQE)UTI.PH@("`@("`@("`@("!D;R!["B`@("`@("`@("`@("`@("1E;G1R
M>2`]("8D<WES5&%B+3YG971%;G1R>49O<E!A=&@H)&AO;65D:7(I.PH@("`@
M("`@("`@("`@("`D:&]M961I<B`](&1I<FYA;64H)&AO;65D:7(I.PH@("`@
M("`@("`@("`@("!I9B`H)&AO;65D:7(@/3T@)RXG('Q\(&5M<'1Y*"1H;VUE
M9&ER*2D@>PH@("`@("`@("`@("`@("`@("`@)&AO;65D:7(@/2`G+R<["B`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!W:&EL92`H:7-?82@D96YT
M<GDL("=014%27T5R<F]R)RDI.PH@("`@("`@("`@("`D;6]U;G10;VEN="`]
M("1E;G1R>2T^9&5V:6-E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M)&AO;65D:7(@/2!E>'!L;V1E*"<O)RP@)&AO;65D:7(I.PH@("`@("`@("`@
M("1M;W5N=%!O:6YT(#T@)R\G("X@)&AO;65D:7);,5T["B`@("`@("`@?0H*
M("`@("`@("`D8VUD;&EN92`]('-P<FEN=&8H)R5S("UU("5S(#(^)C$@?"`E
M<R`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YP87)A
M;7-;)W%U;W1A7W!A=&@G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/F=E=%5S97).86UE*"DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YP87)A;7-;)V=R97!?<&%T:"==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D;6]U;G10;VEN="D["B`@("`@("`@)&IU;FL@/2!E
M>&5C*"1C;61L:6YE+"`D<75O=&%?9&%T82P@)')E='5R;E]C;V1E*3L*("`@
M("`@("!I9B`H)')E='5R;E]C;V1E(#T](#`@)B8@(65M<'1Y*"1Q=6]T85]D
M871A6S!=*2D@>PH@("`@("`@("`@("\O($EN(&-A<V4@;V8@<75O=&$@;W5T
M<'5T('=R87!P:6YG(&]N('1W;R!L:6YE<RP@=V4@8V]N8V%T('1H90H@("`@
M("`@("`@("\O('-E8V]N9"!L:6YE(&]F(')E<W5L=',L(&EF(&%N>2P@:&5R
M92X*("`@("`@("`@("!I9B`H(65M<'1Y*"1Q=6]T85]D871A6S%=*2D@>PH@
M("`@("`@("`@("`@("`D<75O=&%?9&%T85LP72`N/2`D<75O=&%?9&%T85LQ
M73L*("`@("`@("`@("!]"B`@("`@("`@("`@+R\@3F]W('!A<G-E(&]U="!T
M:&4@<75O=&$@:6YF;R!A;F0@<F5T=7)N(&ET+@H@("`@("`@("`@("1Q=6]T
M82`]('!R96=?<W!L:70H)R]<<RLO)RP@=')I;2@D<75O=&%?9&%T85LP72DI
M.PH@("`@("`@("`@(')E='5R;B!A<G)A>2@G=7-E9"<@/3X@)'%U;W1A6S%=
M("H@,3`R-"P@)VQI;6ET)R`]/B`D<75O=&%;,ET@*B`Q,#(T*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@=7-E<B=S(&9U;&P@;F%M92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!4:&4@=7-E<B=S(&9U;&P@;F%M92`H<W1R:6YG
M*2P@;W(@9F%L<V4@*&5R<F]R*2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M1G5L;&YA;64H*0H@("`@>PH@("`@("`@("1I;F9O<FUA=&EO;B`]("1T:&ES
M+3Y?9V5T06-C;W5N="@I.PH@("`@("`@(&EF("AI<U]A*"1I;F9O<FUA=&EO
M;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&EN9F]R
M;6%T:6]N.PH@("`@("`@('T*("`@("`@("`D9V5C;W-?87)R87D@/2!E>'!L
M;V1E*"<L)RP@)&EN9F]R;6%T:6]N6R=G96-O<R==*3L*("`@("`@("!R971U
M<FX@)&=E8V]S7V%R<F%Y6S!=.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@=7-E<B=S(&AO;64@*&QO9VEN*2!D:7)E8W1O<GDN"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE('5S97(G<R!D:7)E8W1O<GD@
M*'-T<FEN9RDL(&]R(&9A;'-E("AE<G)O<BDN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$AO;64H*0H@("`@>PH@("`@("`@("1I;F9O<FUA=&EO;B`]("1T
M:&ES+3Y?9V5T06-C;W5N="@I.PH@("`@("`@(&EF("AI<U]A*"1I;F9O<FUA
M=&EO;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&EN
M9F]R;6%T:6]N.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&EN9F]R;6%T
M:6]N6R=D:7(G73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M('5S97(G<R!D969A=6QT('-H96QL+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1H92!U<V5R)W,@<VAE;&P@*'-T<FEN9RDL(&]R(&9A;'-E("AE
M<G)O<BDN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-H96QL*"D*("`@('L*
M("`@("`@("`D:6YF;W)M871I;VX@/2`D=&AI<RT^7V=E=$%C8V]U;G0H*3L*
M("`@("`@("!I9B`H:7-?82@D:6YF;W)M871I;VXL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1I;F9O<FUA=&EO;CL*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1I;F9O<FUA=&EO;ELG<VAE;&PG73L*("`@('T*
M"GT*"B\J*@H@*B!4:&4@;&1A<"!C;&%S<R!A='1E;7!T<R!T;R!R971U<FX@
M=7-E<B!I;F9O<FUA=&EO;B!S=&]R960@:6X@86X@;&1A<`H@*B!D:7)E8W1O
M<GD@<V5R=FEC92X*("H*("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!%<FEC(%)O
M<W1E='1E<B`\97)I8RYR;W-T971T97)`<&AY<VEC<RYU=&5X87,N961U/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@17)I8R!*;VX@4F]S=&5T=&5R
M(#QE<FEC+G)O<W1E='1E<D!P:'ES:6-S+G5T97AA<RYE9'4^"B`J($!S:6YC
M92`@($AO<F1E(#,N,0H@*B!`<&%C:V%G92!(;W)D95]";&]C:PH@*B\*8VQA
M<W,@06-C;W5N='-?1')I=F5R7VQD87`@97AT96YD<R!!8V-O=6YT<U]$<FEV
M97(@>PH*("`@("\J*@H@("`@("H@4&]I;G1E<B!T;R!T:&4@;&1A<"!C;VYN
M96-T:6]N+@H@("`@("H*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@
M("`@=F%R("1?9',["@H@("`@+RHJ"B`@("`@*B!(87-H(&-O;G1A:6YI;F<@
M8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?<&%R86US.PH*("`@("\J*@H@("`@("H@
M0V]N<W1R=6-T<R!A(&YE=R!!8V-O=6YT<U]$<FEV97)?;&1A<"!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C
M;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@06-C;W5N='-?1')I=F5R7VQD87`H)'!A<F%M<R`](&%R<F%Y
M*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2!A<G)A>5]M97)G
M92@*("`@("`@("`@("`@87)R87DH)VAO<W0G(#T^("=L;V-A;&AO<W0G+`H@
M("`@("`@("`@("`@("`@("`G<&]R="<@/3X@,S@Y+`H@("`@("`@("`@("`@
M("`@("`G8F%S961N)R`]/B`G)RP*("`@("`@("`@("`@("`@("`@)V%T='(G
M(#T^("=U:60G+`H@("`@("`@("`@("`@("`@("`G=F5R<VEO;B<@/3X@)S,G
M*2P*("`@("`@("`@("`@)'!A<F%M<RD["B`@("!]"@H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@=7-E<B!A8V-O=6YT(&9R;VT@=&AE(&QD87`@<V]U
M<F-E+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($$@:&%S:"!W:71H
M(&-O;7!L971E(&%C8V]U;G0@9&5T86EL<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V=E=$%C8V]U;G0H*0H@("`@>PH@("`@("`@('-T871I8R`D:6YF;W)M
M871I;VX["@H@("`@("`@(&EF("@A:7-S970H)&EN9F]R;6%T:6]N*2D@>PH@
M("`@("`@("`@("`D=7-E<FYA;64@(#T@)'1H:7,M/F=E=%5S97)N86UE*"D[
M"@H@("`@("`@("`@("`O+R!C;VYN96-T('1O('1H92!L9&%P('-E<G9E<@H@
M("`@("`@("`@("`D=&AI<RT^7V1S(#T@;&1A<%]C;VYN96-T*"1T:&ES+3Y?
M<&%R86US6R=H;W-T)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!O<G0G72D["B`@("`@("`@("`@
M(&EF("@A)'1H:7,M/E]D<RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T(&-O;FYE8W0@=&\@3$1!4"!S
M97)V97(N(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7W!A<F%M<ULG=F5R<VEO;B==*2D@>PH@("`@("`@("`@("`@
M("`@:68@*"%L9&%P7W-E=%]O<'1I;VXH)'1H:7,M/E]D<RP@3$1!4%]/4%1?
M4%)/5$]#3TQ?5D524TE/3BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=V97)S:6]N)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G4V5T
M($Q$05`@<')O=&]C;VP@=F5R<VEO;B!T;R`E9"!F86EL960Z(%LE9%T@)7,G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)W9E<G-I;VXG72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&QD87!?97)R;F\H)&-O
M;FXI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@;&1A<%]E<G)O<B@D8V]N;BDI+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+R\@8FEN9"!A<R!A;F]N>6UO=7,*("`@("`@("`@("`@)')E<W5L="`]
M($!L9&%P7V)I;F0H)'1H:7,M/E]D<RD["B`@("`@("`@("`@(&EF("@A)')E
M<W5L="D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(BDI.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O+R!'970@=&AE(&9U;&QN86UE"B`@
M("`@("`@("`@("1S96%R8VA297-U;'0@/2!L9&%P7W-E87)C:"@D=&AI<RT^
M7V1S+"`D=&AI<RT^7W!A<F%M<ULG8F%S961N)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG871T
M<B==("X@)STG("X@)'5S97)N86UE*3L*("`@("`@("`@("`@)&EN9F]R;6%T
M:6]N(#T@;&1A<%]G971?96YT<FEE<R@D=&AI<RT^7V1S+"`D<V5A<F-H4F5S
M=6QT*3L*"B`@("`@("`@("`@("\O(&1I<V-O;FYE8W0@9G)O;2!T:&4@;&1A
M<"!S97)V97(*("`@("`@("`@("`@0&QD87!?8VQO<V4H)'1H:7,M/E]D<RD[
M"@H@("`@("`@("`@("!I9B`H)&EN9F]R;6%T:6]N6R=C;W5N="==(#T](#`I
M('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(E5S97(@86-C;W5N="!N;W0@9F]U;F0B*2D["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D:6YF;W)M871I;VX["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!U<V5R)W,@9G5L;"!N86UE+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!U<V5R)W,@9G5L;"!N
M86UE("AS=')I;F<I+"!O<B!F86QS92`H97)R;W(I+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971&=6QL;F%M92@I"B`@("!["B`@("`@("`@)&EN9F]R;6%T
M:6]N(#T@)'1H:7,M/E]G971!8V-O=6YT*"D["B`@("`@("`@:68@*&ES7V$H
M)&EN9F]R;6%T:6]N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D:6YF;W)M871I;VX["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S
M970H)&EN9F]R;6%T:6]N6S!=6R=C;CML86YG+65S)UU;,%TI("8F"B`@("`@
M("`@("`@("1I;F9O<FUA=&EO;ELP75LG8VX[;&%N9RUE<R==6S!=("$]("<G
M*2!["B`@("`@("`@("`@("1N86UE(#T@)&EN9F]R;6%T:6]N6S!=6R=C;CML
M86YG+65S)UU;,%T["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&YA
M;64@/2`D:6YF;W)M871I;VY;,%U;)V-N)UU;,%T["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@*&5M<'1Y*"1N86UE*2`_(&9A;'-E(#H@)&YA;64I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=7-E<B=S(&AO;64@
M*&QO9VEN*2!D:7)E8W1O<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5&AE('5S97(G<R!D:7)E8W1O<GD@*'-T<FEN9RDL(&]R(&9A;'-E("AE
M<G)O<BDN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$AO;64H*0H@("`@>PH@
M("`@("`@("1I;F9O<FUA=&EO;B`]("1T:&ES+3Y?9V5T06-C;W5N="@I.PH@
M("`@("`@(&EF("AI<U]A*"1I;F9O<FUA=&EO;BP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&EN9F]R;6%T:6]N.PH@("`@("`@('T*
M("`@("`@("`D:&]M961I<B`]("1I;F9O<FUA=&EO;ELP75LG:&]M961I<F5C
M=&]R>2==6S!=.PH@("`@("`@(')E='5R;B`H96UP='DH)&AO;65D:7(I(#\@
M9F%L<V4@.B`D:&]M961I<BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!U<V5R)W,@9&5F875L="!S:&5L;"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4:&4@=7-E<B=S('-H96QL("AS=')I;F<I+"!O<B!F
M86QS92`H97)R;W(I+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9713:&5L;"@I
M"B`@("!["B`@("`@("`@)&EN9F]R;6%T:6]N(#T@)'1H:7,M/E]G971!8V-O
M=6YT*"D["B`@("`@("`@:68@*&ES7V$H)&EN9F]R;6%T:6]N+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D:6YF;W)M871I;VX["B`@
M("`@("`@?0H@("`@("`@("1S:&5L;"`]("1I;F9O<FUA=&EO;ELP75LG;&]G
M:6YS:&5L;"==6S!=.PH@("`@("`@(')E='5R;B`H96UP='DH)'-H96QL*2`_
M(&9A;'-E(#H@)'-H96QL*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE(&1A=&4@;V8@=&AE('5S97(G<R!L87-T('!A<W-W;W)D(&-H86YG
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!$871E('-T<FEN9R`H
M<W1R:6YG*2!O<B!F86QS92`H97)R;W(I+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971087-S=V]R9$-H86YG92@I"B`@("!["B`@("`@("`@)&EN9F]R;6%T
M:6]N(#T@)'1H:7,M/E]G971!8V-O=6YT*"D["B`@("`@("`@:68@*&ES7V$H
M)&EN9F]R;6%T:6]N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D:6YF;W)M871I;VX["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S
M970H)&EN9F]R;6%T:6]N6S!=6R=S:&%D;W=L87-T8VAA;F=E)UU;,%TI*2![
M"B`@("`@("`@("`@("1L87-T8VAA;F=E(#T@<W1R9G1I;64H)R5X)RP@)&EN
M9F]R;6%T:6]N6S!=6R=S:&%D;W=L87-T8VAA;F=E)UU;,%T@*B`X-C0P,"D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@*&5M<'1Y*"1L87-T8VAA;F=E
M*2`_(&9A;'-E(#H@)&QA<W1C:&%N9V4I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@<W1A='5S(&]F('1H92!C=7)R96YT('!A<W-W;W)D
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($$@<W1R:6YG('=I=&@@
M82!W87)N:6YG(&UE<W-A9V4@:68@=&AE('!A<W-W;W)D(&ES(&%B;W5T"B`@
M("`@*B`@("`@("`@("`@("`@("!T;R!E>'!I<F4L(%!%05)?17)R;W(@;VX@
M97)R;W(@86YD(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@8VAE8VM087-S=V]R9%-T871U<R@I"B`@("!["B`@("`@("`@)&EN9F]R
M;6%T:6]N(#T@)'1H:7,M/E]G971!8V-O=6YT*"D["B`@("`@("`@:68@*&ES
M7V$H)&EN9F]R;6%T:6]N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D:6YF;W)M871I;VX["B`@("`@("`@?0H*("`@("`@("!I9B`H
M:7-S970H)&EN9F]R;6%T:6]N6S!=6R=S:&%D;W=M87@G75LP72D@)B8*("`@
M("`@("`@("`@:7-S970H)&EN9F]R;6%T:6]N6S!=6R=S:&%D;W=L87-T8VAA
M;F=E)UU;,%TI("8F"B`@("`@("`@("`@(&ES<V5T*"1I;F9O<FUA=&EO;ELP
M75LG<VAA9&]W=V%R;FEN9R==6S!=*2D@>PH@("`@("`@("`@("`D=&]D87D@
M/2!F;&]O<BAT:6UE*"D@+R`X-C0P,"D["B`@("`@("`@("`@("1W87)N9&%Y
M(#T@)&EN9F]R;6%T:6]N6S!=6R=S:&%D;W=L87-T8VAA;F=E)UU;,%T@*PH@
M("`@("`@("`@("`@("`@("`@("`@("1I;F9O<FUA=&EO;ELP75LG<VAA9&]W
M;6%X)UU;,%T@+2`D:6YF;W)M871I;VY;,%U;)W-H861O=W=A<FYI;F<G75LP
M73L*("`@("`@("`@("`@)'1O97AP:7)E(#T@)&EN9F]R;6%T:6]N6S!=6R=S
M:&%D;W=L87-T8VAA;F=E)UU;,%T@*R`D:6YF;W)M871I;VY;,%U;)W-H861O
M=VUA>"==6S!=("T@)'1O9&%Y.PH*("`@("`@("`@("`@:68@*"1T;V1A>2`^
M/2`D=V%R;F1A>2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N('-P<FEN=&8H
M7R@B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N(BDL("1T
M;V5X<&ER92D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]";&]C:R]C
M;VQO<BYP:'``````````````````````````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#$V-C4`,3`U,34T,S,W-#8`,#(Q,S$W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@HO+R!4:&ES(&)L;V-K
M(&ES(&%N(&5X86UP;&4@86YD('!R;V)A8FQY(&YO="!U<V5F=6P@=&\@=7-E
M<G,N"B\O("1B;&]C:U]N86UE(#T@7R@B0V]L;W(B*3L*"B\J*@H@*B`D2&]R
M9&4Z(&AO<F1E+VQI8B]";&]C:R]C;VQO<BYP:'`L=B`Q+C$R(#(P,#0O,#8O
M,#$@,3`Z,#4Z,S$@:F%N($5X<"`D"B`J"B`J($!P86-K86=E($AO<F1E7T)L
M;V-K"B`J+PIC;&%S<R!(;W)D95]";&]C:U](;W)D95]C;VQO<B!E>'1E;F1S
M($AO<F1E7T)L;V-K('L*"B`@("!V87(@)%]A<'`@/2`G:&]R9&4G.PH*("`@
M(&9U;F-T:6]N(%]P87)A;7,H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A
M>2@G='EP92<@/3X@)W1E>'0G+`H@("`@("`@("`@("`@("`@("`@("`G;F%M
M92<@/3X@7R@B0V]L;W(B*2P*("`@("`@("`@("`@("`@("`@("`@)V1E9F%U
M;'0G(#T^("<C9F8P,#`P)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@
M=&ET;&4@=&\@9V\@:6X@=&AI<R!B;&]C:RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@(%1H92!T:71L92!T97AT+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?=&ET;&4H*0H@("`@>PH@("`@("`@(')E='5R;B!?*")#;VQO<B(I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AE(&-O;G1E;G0@=&\@9V\@:6X@
M=&AI<R!B;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H
M92!C;VYT96YT"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYT96YT*"D*("`@
M('L*("`@("`@("`D:'1M;"`@/2`G/'1A8FQE('=I9'1H/2(Q,#`B(&AE:6=H
M=#TB,3`P(B!B9V-O;&]R/2(E<R(^)SL*("`@("`@("`D:'1M;"`N/2`G/'1R
M/CQT9#XF;F)S<#L\+W1D/CPO='(^)SL*("`@("`@("`D:'1M;"`N/2`G/"]T
M86)L93XG.PH*("`@("`@("!R971U<FX@<W!R:6YT9B@D:'1M;"P@)'1H:7,M
M/E]P87)A;7-;)V-O;&]R)UTI.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]"
M;&]C:R]F;W)T=6YE+G!H<```````````````````````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,3$Q,3<`,3`U,34T,S,W-#4`,#(Q-C4S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"@HD8FQO8VM?
M;F%M92`](%\H(E)A;F1O;2!&;W)T=6YE(BD["@HO*BH*("H@)$AO<F1E.B!H
M;W)D92]L:6(O0FQO8VLO9F]R='5N92YP:'`L=B`Q+C$T+C$P+C(@,C`P-2\Q
M,"\Q."`Q,3HS,SHS.2!J86X@17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&5?
M0FQO8VL*("HO"F-L87-S($AO<F1E7T)L;V-K7TAO<F1E7V9O<G1U;F4@97AT
M96YD<R!(;W)D95]";&]C:R!["@H@("`@=F%R("1?87!P(#T@)VAO<F1E)SL*
M"B`@("`O*BH*("`@("`J(%1H92!T:71L92!T;R!G;R!I;B!T:&ES(&)L;V-K
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@5&AE('1I=&QE('1E
M>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T:71L92@I"B`@("!["B`@("`@
M("`@<F5T=7)N(%\H(D9O<G1U;F4B*3L*("`@('T*"B`@("!F=6YC=&EO;B!?
M<&%R86US*"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@
M("1D97-C<FEP=&EO;G,@/2!A<G)A>2@G87)T)R`]/B!?*")!<G0B*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%S8VEI+6%R="<@/3X@7R@B
M07-C:6D@07)T(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=B
M;V9H+65X8W5S97,G(#T^(%\H(D)/1D@@17AC=7-E<R(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G8V]M<'5T97)S)R`]/B!?*")#;VUP=71E
M<G,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-O;VMI92<@
M/3X@7R@B0V]O:VEE(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=D969I;FET:6]N<R<@/3X@7R@B1&5F:6YI=&EO;G,B*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V1R=6=S)R`]/B!?*")$<G5G<R(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G961U8V%T:6]N)R`]/B!?
M*")%9'5C871I;VXB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V5T:&YI8R<@/3X@7R@B171H;FEC(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=F;V]D)R`]/B!?*")&;V]D(BDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=F;W)T=6YE<R<@/3X@7R@B1F]R='5N97,B*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9O<G1U;F5S,B<@/3X@
M7R@B1F]R='5N97,@,B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G9V]E9&5L)R`]/B!?*")';V5D96PB*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VAU;6]R:7-T<R<@/3X@7R@B2'5M;W)I<W1S(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=K97)N96QN97=B:65S)R`]
M/B!?*")+97)N96P@3F5W8FEE<R(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G:VED<R<@/3X@7R@B2VED<R(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G;&%W)R`]/B!?*"),87<B*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VQI;65R:6-K)R`]/B!?*"),:6UE<FEC:R(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;&EN=7AC;V]K:64G
M(#T^(%\H(DQI;G5X($-O;VMI92(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G;&ET97)A='5R92<@/3X@7R@B3&ET97)A='5R92(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G;&]V92<@/3X@7R@B3&]V92(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;6%G:6,G(#T^(%\H
M(DUA9VEC(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M961I
M8VEN92<@/3X@7R@B365D:6-I;F4B*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VUI<V-E;&QA;F5O=7,G(#T^(%\H(DUI<V-E;&QA;F5O=7,B
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYE=W,G(#T^(%\H
M(DYE=W,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V]S9F]R
M='5N92<@/3X@7R@B3W!E<F%T:6YG(%-Y<W1E;2(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<&5O<&QE)R`]/B!?*")096]P;&4B*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!E=',G(#T^(%\H(E!E=',B
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!L871I='5D97,G
M(#T^(%\H(E!L871I='5D97,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W!O;&ET:6-S)R`]/B!?*")0;VQI=&EC<R(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<FED9&QE<R<@/3X@7R@B4FED9&QE<R(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<V-I96YC92<@/3X@
M7R@B4V-I96YC92(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<V]N9W,M<&]E;7,G(#T^(%\H(E-O;F=S("8@4&]E;7,B*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W-P;W)T<R<@/3X@7R@B4W!O<G1S(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S=&%R=')E:R<@/3X@
M7R@B4W1A<B!4<F5K(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=T<F%N<VQA=&4M;64G(#T^(%\H(E1R86YS;&%T:6]N<R(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G=VES9&]M)R`]/B!?*")7:7-D;VTB
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W=O<FLG(#T^(%\H
M(E=O<FLB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)WII<'!Y
M)R`]/B!?*")::7!P>2(I*3L*"B`@("`@("`@)'9A;'5E<R`](&YU;&P["B`@
M("`@("`@:68@*&ES<V5T*"1C;VYF6R=F;W)T=6YE)UU;)V5X96-?<&%T:"==
M*2`F)@H@("`@("`@("`@("!I<U]E>&5C=71A8FQE*"1C;VYF6R=F;W)T=6YE
M)UU;)V5X96-?<&%T:"==*2D@>PH@("`@("`@("`@("!E>&5C*"1C;VYF6R=F
M;W)T=6YE)UU;)V5X96-?<&%T:"==("X@)R`M9B`R/B8Q)RP@)&]U='!U="P@
M)'-T871U<RD["B`@("`@("`@("`@(&EF("@A)'-T871U<RD@>PH@("`@("`@
M("`@("`@("`@9F]R("@D:2`](#$[("1I(#P@8V]U;G0H)&]U='!U="D[("1I
M*RLI('L*("`@("`@("`@("`@("`@("`@("`D9F]R='5N92`]('-U8G-T<B@D
M;W5T<'5T6R1I72P@<W1R<G!O<R@D;W5T<'5T6R1I72P@)R`G*2`K(#$I.PH@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5S8W)I<'1I;VYS6R1F
M;W)T=6YE72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E<ULD
M9F]R='5N95T@/2`D9&5S8W)I<'1I;VYS6R1F;W)T=6YE73L*("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M=F%L=65S6R1F;W)T=6YE72`]("1F;W)T=6YE.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!I9B`H:7-?;G5L;"@D=F%L=65S*2D@>PH@("`@("`@("`@
M("`D=F%L=65S(#T@)&1E<V-R:7!T:6]N<SL*("`@("`@("!]"B`@("`@("`@
M87-O<G0H)'9A;'5E<RD["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y7VUE<F=E
M*&%R<F%Y*"<G(#T^(%\H(D%L;"(I*2P@)'9A;'5E<RD["@H@("`@("`@(')E
M='5R;B!A<G)A>2@*("`@("`@("`@("`@)V]F9F5N9"<@/3X@87)R87DH"B`@
M("`@("`@("`@("`@("`G='EP92<@/3X@)V5N=6TG+`H@("`@("`@("`@("`@
M("`@)VYA;64G(#T^(%\H(D]F9F5N<V4@9FEL=&5R(BDL"B`@("`@("`@("`@
M("`@("`G9&5F875L="<@/3X@)R<L"B`@("`@("`@("`@("`@("`G=F%L=65S
M)R`]/B!A<G)A>2@G)R`]/B!?*").;R!O9F9E;G-I=F4@9F]R='5N97,B*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R`M;R<@/3X@7R@B
M3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)R`M82<@/3X@7R@B0F]T:"(I*2DL"B`@("`@("`@
M("`@("=F;W)T=6YE)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("=T>7!E
M)R`]/B`G;75L=&EE;G5M)RP*("`@("`@("`@("`@("`@("=N86UE)R`]/B!?
M*")&;W)T=6YE('1Y<&4B*2P*("`@("`@("`@("`@("`@("=D969A=6QT)R`]
M/B!A<G)A>2@G)RDL"B`@("`@("`@("`@("`@("`G=F%L=65S)R`]/B`D=F%L
M=65S*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@8V]N=&5N="!T;R!G
M;R!I;B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("`@5&AE(&-O;G1E;G0*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;G1E;G0H
M*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@:68@*&ES
M<V5T*"1C;VYF6R=F;W)T=6YE)UU;)V5X96-?<&%T:"==*2`F)@H@("`@("`@
M("`@("!I<U]E>&5C=71A8FQE*"1C;VYF6R=F;W)T=6YE)UU;)V5X96-?<&%T
M:"==*2D@>PH@("`@("`@("`@("`D8VUD3&EN92`]("1C;VYF6R=F;W)T=6YE
M)UU;)V5X96-?<&%T:"==.PH@("`@("`@("`@("`D8VUD3&EN92`N/2`D=&AI
M<RT^7W!A<F%M<ULG;V9F96YD)UT["B`@("`@("`@("`@("1C;61,:6YE("X]
M("<@)R`N(&EM<&QO9&4H)R`G+"`D=&AI<RT^7W!A<F%M<ULG9F]R='5N92==
M*3L*("`@("`@("`@("`@<F5T=7)N(&YL,F)R*&AT;6QS<&5C:6%L8VAA<G,H
M<VAE;&Q?97AE8R@D8VUD3&EN92DI*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O0FQO8VLO9V]O9VQE+G!H<```````````````````````````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`S-C$S`#$P-3$U-#,S-S0U`#`R,30T-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M)&)L;V-K7VYA;64@/2!?*")';V]G;&4@4V5A<F-H(BD["@HO*BH*("H@)$AO
M<F1E.B!H;W)D92]L:6(O0FQO8VLO9V]O9VQE+G!H<"QV(#$N,3`N,3`N,2`R
M,#`U+S$P+S$X(#$Q.C,S.C,Y(&IA;B!%>'`@)`H@*@H@*B!`<&%C:V%G92!(
M;W)D95]";&]C:PH@*B\*8VQA<W,@2&]R9&5?0FQO8VM?2&]R9&5?9V]O9VQE
M(&5X=&5N9',@2&]R9&5?0FQO8VL@>PH*("`@('9A<B`D7V%P<"`]("=H;W)D
M92<["@H@("`@+RHJ"B`@("`@*B!4:&4@=&ET;&4@=&\@9V\@:6X@=&AI<R!B
M;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H92!T:71L
M92!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=&ET;&4H*0H@("`@>PH@
M("`@("`@(')E='5R;B!?*")';V]G;&4@4V5A<F-H(BD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!4:&4@8V]N=&5N="!T;R!G;R!I;B!T:&ES(&)L;V-K+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@5&AE(&-O;G1E;G0*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V-O;G1E;G0H*0H@("`@>PH@("`@("`@("1H
M=&UL("`]("<\9F]R;2!N86UE/2)G;V]G;&4B(&]N<W5B;6ET/2)O<&5N7V=O
M;V=L95]W:6XH*3L@<F5T=7)N(&9A;'-E.R(^)SL*("`@("`@("`D:'1M;"`N
M/2`G/'1A8FQE('=I9'1H/2(Q,#`E(B!H96EG:'0](C$P,"4B/B<["B`@("`@
M("`@)&AT;6P@+CT@)SQT<CX\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP
M="(@<W)C/2(G("X@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O
M="<L("=H;W)D92<I("X@)R]S97)V:6-E<R]J879A<V-R:7!T+G!H<#]F:6QE
M/6]P96Y?9V]O9VQE7W=I;BYJ<R9A;7`[87!P/6AO<F1E(CX\+W-C<FEP=#XG
M.PH@("`@("`@("1H=&UL("X]("<\=&0^)R`N($AO<F1E.CII;6<H)V=O;V=L
M92YP;F<G+"`G1V]O9VQE)RD@+B`G/"]T9#X\+W1R/B<["B`@("`@("`@)&AT
M;6P@+CT@)SQT<CX\=&0^/&EN<'5T(&UA>$QE;F=T:#TB,C4V(B!S:7IE/2(T
M,"(@;F%M93TB<2(@=VED=&@](C$P,"4B("\^/"]T9#X\+W1R/B<["B`@("`@
M("`@)&AT;6P@+CT@)SQT<CX\=&0^/'1A8FQE('=I9'1H/2(Q,#`E(CX\='(^
M/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)R861I;R(@;F%M93TB
M87)E82(@=F%L=64](G=E8B(@=VED=&@](C(P)2(@8VAE8VME9#TB8VAE8VME
M9"(@+SXG("X@7R@B5V5B(BD@+B`G/"]T9#XG.PH@("`@("`@("1H=&UL("X]
M("<\=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4](G)A9&EO(B!N86UE
M/2)A<F5A(B!V86QU93TB:6UA9V5S(B!W:61T:#TB,C`E(B`O/B<@+B!?*"))
M;6%G97,B*2`N("<\+W1D/B<["B`@("`@("`@)&AT;6P@+CT@)SQT9"!A;&EG
M;CTB8V5N=&5R(CX\:6YP=70@='EP93TB<F%D:6\B(&YA;64](F%R96$B('9A
M;'5E/2)G<F]U<',B('=I9'1H/2(R,"4B("\^)R`N(%\H(D=R;W5P<R(I("X@
M)SPO=&0^)SL*("`@("`@("`D:'1M;"`N/2`G/'1D(&%L:6=N/2)C96YT97(B
M/CQI;G!U="!T>7!E/2)R861I;R(@;F%M93TB87)E82(@=F%L=64](F1I<F5C
M=&]R>2(@=VED=&@](C(P)2(@+SXG("X@7R@B1&ER96-T;W)Y(BD@+B`G/"]T
M9#XG.PH@("`@("`@("1H=&UL("X]("<\=&0@86QI9VX](F-E;G1E<B(^/&EN
M<'5T('1Y<&4](G)A9&EO(B!N86UE/2)A<F5A(B!V86QU93TB;F5W<R(@=VED
M=&@](C(P)2(@+SXG("X@7R@B3F5W<R(I("X@)SPO=&0^/"]T<CX\+W1A8FQE
M/CPO=&0^/"]T<CXG.PH@("`@("`@("1H=&UL("X]("<\='(^/'1D/CQI;G!U
M="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB('9A;'5E/2(G("X@7R@B
M1V]O9VQE(%-E87)C:"(I("X@)R(@+SX\+W1D/CPO='(^)SL*("`@("`@("`D
M:'1M;"`N/2`G/"]T86)L93XG.PH@("`@("`@("1H=&UL("X]("<\+V9O<FT^
M)SL*("`@("`@("!R971U<FX@)&AT;6P["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+T)L;V-K+VEF<F%M92YP:'``````````````````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-#$Q,``Q,#4Q-30S,S<T-@`P,C$T,S``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"B1B;&]C
M:U]N86UE(#T@7R@B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(I.PH*+RHJ
M"B`J("1(;W)D93H@:&]R9&4O;&EB+T)L;V-K+VEF<F%M92YP:'`L=B`Q+C$X
M+C@N-"`R,#`V+S`R+S(Q(#$P.C4S.C0U(&IA;B!%>'`@)`H@*@H@*B!`<&%C
M:V%G92!(;W)D95]";&]C:PH@*B\*8VQA<W,@2&]R9&5?0FQO8VM?2&]R9&5?
M:69R86UE(&5X=&5N9',@2&]R9&5?0FQO8VL@>PH*("`@('9A<B`D7V%P<"`]
M("=H;W)D92<["@H@("`@9G5N8W1I;VX@7W!A<F%M<R@I"B`@("!["B`@("`@
M("`@<F5T=7)N(&%R<F%Y*"=I9G)A;64G(#T^(&%R<F%Y*"=T>7!E)R`]/B`G
M=&5X="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=N86UE)R`]/B!?*")54DPB*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("<G*2P*("`@("`@("`@("`@
M("`@("`@("`@)W1I=&QE)R`@/3X@87)R87DH)W1Y<&4G(#T^("=T97AT)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYA;64G
M(#T^(%\H(E1I=&QE(BDI+`H@("`@("`@("`@("`@("`@("`@("`G:&5I9VAT
M)R`]/B!A<G)A>2@G='EP92<@/3X@)VEN="<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B!?*")(96EG:'0B*2DI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AE('1I=&QE('1O(&=O(&EN('1H
M:7,@8FQO8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@("!4:&4@
M=&ET;&4@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@7W1I=&QE*"D*("`@
M('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`D=&ET;&4@
M/2!I<W-E="@D=&AI<RT^7W!A<F%M<ULG=&ET;&4G72D*("`@("`@("`@("`@
M/R`D=&AI<RT^7W!A<F%M<ULG=&ET;&4G70H@("`@("`@("`@("`Z("1T:&ES
M+3Y?<&%R86US6R=I9G)A;64G73L*"B`@("`@("`@)&AT;6P@/2!(;W)D93HZ
M;&EN:R@D=&AI<RT^7W!A<F%M<ULG:69R86UE)UTI("X@)'1I=&QE("X*("`@
M("`@("`@("`@)SPO83X@.CH@/'-M86QL/B<@+@H@("`@("`@("`@("!(;W)D
M93HZ;&EN:R@D=&AI<RT^7W!A<F%M<ULG:69R86UE)UTL("<G+"`G)RP@)U]B
M;&%N:R<I("X*("`@("`@("`@("`@2&]R9&4Z.FEM9R@G=V5B<VET92YP;F<G
M+"!?*")/<&5N(&EN(&$@;F5W('=I;F1O=R(I*2`N("<@)R`N"B`@("`@("`@
M("`@(%\H(D]P96X@:6X@82!N97<@=VEN9&]W(BD@+B`G/"]A/CPO<VUA;&P^
M)SL*"B`@("`@("`@<F5T=7)N("1H=&UL.PH@("`@?0H*("`@("\J*@H@("`@
M("H@5&AE(&-O;G1E;G0@=&\@9V\@:6X@=&AI<R!B;&]C:RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H92!C;VYT96YT"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]C;VYT96YT*"D*("`@('L*("`@("`@("!G;&]B86P@)&)R
M;W=S97(["@H@("`@("`@(&EF("@A)&)R;W=S97(M/FAA<T9E871U<F4H)VEF
M<F%M97,G*2D@>PH@("`@("`@("`@("!R971U<FX@7R@B66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(I.PH@("`@("`@('T*
M"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=H96EG:'0G72DI
M('L*("`@("`@("`@("`@:68@*"1B<F]W<V5R+3YI<T)R;W=S97(H)VUS:64G
M*2!\?"`D8G)O=W-E<BT^:7-"<F]W<V5R*"=K;VYQ=65R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@)&AE:6=H="`]("<G.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)&AE:6=H="`]("<@:&5I9VAT/2(Q,#`E(B<[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M:&5I9VAT(#T@)R!H96EG:'0](B<@+B!H=&UL<W!E8VEA;&-H87)S*"1T:&ES
M+3Y?<&%R86US6R=H96EG:'0G72D@+B`G(B<["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`G/&EF<F%M92!S<F,](B<@+B!H=&UL<W!E8VEA;&-H87)S*"1T
M:&ES+3Y?<&%R86US6R=I9G)A;64G72D@+B`G(B!W:61T:#TB,3`P)2(G("X@
M)&AE:6=H="`N("<@;6%R9VEN:&5I9VAT/2(P(B!S8W)O;&QI;F<](F%U=&\B
M(&9R86UE8F]R9&5R/2(P(CX\+VEF<F%M93XG.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+T)L;V-K+VUE=&%R+G!H<```````````````````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T-S$S-P`Q,#4Q-30S,S<T-@`P,C$S
M,34`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"B1B;&]C:U]N86UE(#T@7R@B365T87(@5V5A=&AE<B(I.PH*+RHJ
M"B`J(%1H92!(;W)D95]";&]C:U]M971A<B!C;&%S<R!P<F]V:61E<R!A;B!A
M<'!L970@9F]R('1H92!P;W)T86P*("H@<V-R965N('1O(&1I<W!L87D@3454
M05(@=V5A=&AE<B!D871A(&9O<B!A('-P96-I9FEE9"!L;V-A=&EO;@H@*B`H
M8W5R<F5N=&QY(&%I<G!O<G1S*2X*("H*("H@)$AO<F1E.B!H;W)D92]L:6(O
M0FQO8VLO;65T87(N<&AP+'8@,2XR,BXQ,"XV(#(P,#8O,#8O,C,@,3DZ,S$Z
M,C@@:F%N($5X<"`D"B`J"B`J($!P86-K86=E($AO<F1E7T)L;V-K"B`J+PIC
M;&%S<R!(;W)D95]";&]C:U](;W)D95]M971A<B!E>'1E;F1S($AO<F1E7T)L
M;V-K('L*"B`@("!V87(@)%]A<'`@/2`G:&]R9&4G.PH*("`@("\J*@H@("`@
M("H@5&AE('1I=&QE('1O(&=O(&EN('1H:7,@8FQO8VLN"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@("!4:&4@=&ET;&4@=&5X="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7W1I=&QE*"D*("`@('L*("`@("`@("!R971U<FX@7R@B
M0W5R<F5N="!796%T:&5R(BD["B`@("!]"@H@("`@9G5N8W1I;VX@7W!A<F%M
M<R@I"B`@("!["B`@("`@("`@:68@*"%`:6YC;'5D95]O;F-E("=397)V:6-E
M<R]796%T:&5R+G!H<"<I('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)U1H92!M971A<B!B;&]C:R!W:6QL(&YO="!W;W)K('=I=&AO=70@4V5R
M=FEC97-?5V5A=&AE<B!F<F]M(%!%05(N(%)U;B!P96%R(&EN<W1A;&P@4V5R
M=FEC97-?5V5A=&AE<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@
M("`@(')E='5R;B!A<G)A>2@*("`@("`@("`@("`@("`@("=E<G)O<B<@/3X@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=E<G)O<B<L
M"B`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(D5R<F]R(BDL"B`@
M("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^(%\H(DUE=&%R(&)L;V-K
M(&YO="!A=F%I;&%B;&4N(BD*("`@("`@("`@("`@("`@("D*("`@("`@("`@
M("`@*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!G;&]B86P@)&-O
M;F8["@H@("`@("`@("`@("`O+R!'970@;&]C871I;VYS(&9R;VT@=&AE(&1A
M=&%B87-E+@H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)T1"+G!H<"<["B`@
M("`@("`@("`@("1D8B`]("9$0CHZ8V]N;F5C="@D8V]N9ELG<W%L)UTI.PH@
M("`@("`@("`@("!I9B`H:7-?82@D9&(L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D9&(["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("\O(%-E="!$0B!P;W)T86)I;&ET>2!O<'1I;VYS+@H@("`@("`@
M("`@("!S=VET8V@@*"1D8BT^<&AP='EP92D@>PH@("`@("`@("`@("!C87-E
M("=M<W-Q;"<Z"B`@("`@("`@("`@("`@("`D9&(M/G-E=$]P=&EO;B@G<&]R
M=&%B:6QI='DG+"!$0E]03U)404))3$E465],3U=%4D-!4T4@?"!$0E]03U)4
M04))3$E465]%4E)/4E,@?"!$0E]03U)404))3$E465]25%))32D["B`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@("`@("1D8BT^<V5T3W!T:6]N*"=P;W)T86)I;&ET>2<L($1"7U!/
M4E1!0DE,25197TQ/5T520T%312!\($1"7U!/4E1!0DE,25197T524D]24RD[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1R97-U;'0@/2`D9&(M/G%U
M97)Y*"=314Q%0U0@:6-A;RP@;F%M92P@8V]U;G1R>2!&4D]-(&UE=&%R06ER
M<&]R=',@3U)$15(@0ED@8V]U;G1R>2<I.PH@("`@("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&QO
M8V%T:6]N<R`](&%R<F%Y*"D["B`@("`@("`@("`@('=H:6QE("@D<F]W(#T@
M)')E<W5L="T^9F5T8VA2;W<H1$)?1D540TA-3T1%7T%34T]#*2D@>PH@("`@
M("`@("`@("`@("`@)&QO8V%T:6]N<ULD<F]W6R=C;W5N=')Y)UU=6R1R;W=;
M)VEC86\G75T@/2`D<F]W6R=N86UE)UT["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(')E='5R;B!A<G)A>2@*("`@("`@("`@("`@("`@("=L;V-A=&EO
M;B<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=M
M;&5N=6TG+`H@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B!?*"),;V-A
M=&EO;B(I+`H@("`@("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B`G2U-&
M0B<L"B`@("`@("`@("`@("`@("`@("`@)W9A;'5E<R<@/3X@)&QO8V%T:6]N
M<RP*("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`G=6YI=',G
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=T>7!E)R`]/B`G96YU
M;2<L"B`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(E5N:71S(BDL
M"B`@("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("=S)RP*("`@("`@
M("`@("`@("`@("`@("`G=F%L=65S)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`@("`@)W,G(#T^(%\H(E-T86YD87)D(BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("=M)R`]/B!?*")-971R:6,B*0H@("`@("`@("`@("`@
M("`@("`@("D*("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`G
M:VYO=',G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=T>7!E)R`]
M/B`G8VAE8VMB;W@G+`H@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B!?
M*")7:6YD('-P965D(&EN(&MN;W1S(BDL"B`@("`@("`@("`@("`@("`@("`@
M)V1E9F%U;'0G(#T^(#`*("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@
M("`@("`G=&%F)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G='EP
M92<@/3X@)V-H96-K8F]X)RP*("`@("`@("`@("`@("`@("`@("`G;F%M92<@
M/3X@7R@B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(I+`H@("`@("`@("`@("`@
M("`@("`@("=D969A=6QT)R`]/B`P"B`@("`@("`@("`@("`@("`I"B`@("`@
M("`@("`@("D["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]R;W<H
M)&QA8F5L+"`D8V]N=&5N="D*("`@('L*("`@("`@("!R971U<FX@)SQB<B`O
M/CQS=')O;F<^)R`N("1L86)E;"`N("<Z/"]S=')O;F<^("<@+B`D8V]N=&5N
M=#L*("`@('T*"B`@("!F=6YC=&EO;B!?<V%M95)O=R@D;&%B96PL("1C;VYT
M96YT*0H@("`@>PH@("`@("`@(')E='5R;B`G(#QS=')O;F<^)R`N("1L86)E
M;"`N("<Z/"]S=')O;F<^("<@+B`D8V]N=&5N=#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%1H92!C;VYT96YT('1O(&=O(&EN('1H:7,@8FQO8VLN"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@("!4:&4@8V]N=&5N=`H@("`@("HO
M"B`@("!F=6YC=&EO;B!?8V]N=&5N="@I"B`@("!["B`@("`@("`@:68@*"%`
M:6YC;'5D95]O;F-E("=397)V:6-E<R]796%T:&5R+G!H<"<I('L*("`@("`@
M("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U1H92!M971A<B!B;&]C:R!W:6QL
M(&YO="!W;W)K('=I=&AO=70@4V5R=FEC97-?5V5A=&AE<B!F<F]M(%!%05(N
M(%)U;B!P96%R(&EN<W1A;&P@4V5R=FEC97-?5V5A=&AE<BXG+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%
M05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!?*")-971A<B!B;&]C
M:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R
M('1H92!A9&UI;FES=')A=&]R+B(I.PH@("`@("`@('T*"B`@("`@("`@9VQO
M8F%L("1C;VYF.PH@("`@("`@('-T871I8R`D;65T87),;V-S.PH*("`@("`@
M("!I9B`H(6ES<V5T*"1C;VYF6R=S<6PG72DI('L*("`@("`@("`@("`@<F5T
M=7)N(%\H(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI
M<R!B;&]C:RXB*3L*("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D=&AI
M<RT^7W!A<F%M<ULG;&]C871I;VXG72DI('L*("`@("`@("`@("`@<F5T=7)N
M(%\H(DYO(&QO8V%T:6]N(&ES('-E="XB*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@A:7-?87)R87DH)&UE=&%R3&]C<RDI('L*("`@("`@("`@("`@)&UE
M=&%R3&]C<R`]("1T:&ES+3YG971087)A;7,H*3L*("`@("`@("!]"@H@("`@
M("`@(')E<75I<F5?;VYC92`G4V5R=FEC97,O5V5A=&AE<BYP:'`G.PH@("`@
M("`@("1M971A<B`]("9397)V:6-E<U]796%T:&5R.CIS97)V:6-E*"=-151!
M4B<L(&%R<F%Y*"=D96)U9R<@/3X@,"DI.PH@("`@("`@("1M971A<BT^<V5T
M365T87)$0B@D8V]N9ELG<W%L)UTI.PH@("`@("`@("1M971A<BT^<V5T56YI
M='-&;W)M870H)'1H:7,M/E]P87)A;7-;)W5N:71S)UTI.PH@("`@("`@("1M
M971A<BT^<V5T1&%T951I;65&;W)M870H)TT@:BP@62<L("=(.FDG*3L*("`@
M("`@("`D;65T87(M/G-E=$UE=&%R4V]U<F-E*"=H='1P)RD["@H@("`@("`@
M("1U;FET<R`]("1M971A<BT^9V5T56YI='-&;W)M870H)'1H:7,M/E]P87)A
M;7-;)W5N:71S)UTI.PH@("`@("`@("1W96%T:&5R(#T@)&UE=&%R+3YG9717
M96%T:&5R*"1T:&ES+3Y?<&%R86US6R=L;V-A=&EO;B==*3L*"B`@("`@("`@
M)&AT;6P@/2`G/'1A8FQE('=I9'1H/2(Q,#`E(B!C96QL<W!A8VEN9STB,"(^
M)R`N"B`@("`@("`@("`@("<\='(^/'1D(&-L87-S/2)C;VYT<F]L(CX\<W1R
M;VYG/B<@+@H@("`@("`@("`@("!S<')I;G1F*"<E<RP@)7,@*"5S*2<L"B`@
M("`@("`@("`@("`@("`@("`@)&UE=&%R3&]C<ULG;&]C871I;VXG75LG=F%L
M=65S)UU;)'1H:7,M/E]P87)A;7-;)U]?;&]C871I;VXG75U;)'1H:7,M/E]P
M87)A;7-;)VQO8V%T:6]N)UU=+`H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=?7VQO8V%T:6]N)UTL"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)VQO8V%T:6]N)UTI("X*("`@("`@("`@("`@)SPO
M<W1R;VYG/CPO=&0^/"]T<CX\+W1A8FQE/CQS=')O;F<^)R`N(%\H(DQA<W0@
M57!D871E9#HB*2`N("<\+W-T<F]N9SX@)R`N"B`@("`@("`@("`@("1W96%T
M:&5R6R=U<&1A=&4G72`N("<\8G(@+SX\8G(@+SXG.PH*("`@("`@("`O+R!7
M:6YD+@H@("`@("`@(&EF("AI<W-E="@D=V5A=&AE<ELG=VEN9"==*2D@>PH@
M("`@("`@("`@("`D:'1M;"`N/2`G/'-T<F]N9SXG("X@7R@B5VEN9#HB*2`N
M("<\+W-T<F]N9SX@)SL*("`@("`@("`@("`@:68@*"1W96%T:&5R6R=W:6YD
M1&ER96-T:6]N)UT@/3T@)U9A<FEA8FQE)RD@>PH@("`@("`@("`@("`@("`@
M:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG:VYO=',G72DI('L*("`@("`@
M("`@("`@("`@("`@("`D:'1M;"`N/2!S<')I;G1F*%\H(B5S(&%T("5S("5S
M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R6R=W:6YD1&ER
M96-T:6]N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@(')O=6YD*"1M971A
M<BT^8V]N=F5R=%-P965D*"1W96%T:&5R6R=W:6YD)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=6YI='-;)W=I;F0G72P@)VMT)RDI+`H@("`@
M("`@("`@("`@("`@("`@("`@("`G:W0G*3L*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@<W!R:6YT9BA?
M*"(E<R!A="`E<R`E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`D=V5A
M=&AE<ELG=VEN9$1I<F5C=&EO;B==+`H@("`@("`@("`@("`@("`@("`@("`@
M("!R;W5N9"@D=V5A=&AE<ELG=VEN9"==*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@)'5N:71S6R=W:6YD)UTI.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!](&5L<V5I9B`H*"1W96%T:&5R6R=W:6YD1&5G<F5E<R==(#T]
M("<P,#`G*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("`H)'=E871H97);
M)W=I;F0G72`]/2`G,"<I*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2!S
M<')I;G1F*%\H(F-A;&TB*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D:'1M;"`N/2!S<')I;G1F*%\H(F9R;VT@=&AE("5S("@E
M<RD@870@)7,@)7,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'=E871H97);)W=I;F1$:7)E8W1I;VXG72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'=E871H97);)W=I;F1$96=R965S)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&5M<'1Y*"1T:&ES+3Y?
M<&%R86US6R=K;F]T<R==*2`_"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(')O=6YD*"1W96%T:&5R6R=W:6YD)UTI(#H*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<F]U;F0H)&UE=&%R+3YC;VYV97)T4W!E
M960H)'=E871H97);)W=I;F0G72P@)'5N:71S6R=W:6YD)UTL("=K="<I*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@96UP='DH)'1H:7,M
M/E]P87)A;7-;)VMN;W1S)UTI(#\*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'5N:71S6R=W:6YD)UT@.@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G:W0G*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("!I9B`H:7-S970H)'=E871H97);)W=I;F1'=7-T)UTI*2!["B`@
M("`@("`@("`@(&EF("@D=V5A=&AE<ELG=VEN9$=U<W0G72D@>PH@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG:VYO=',G72DI
M('L*("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2!S<')I;G1F*%\H(BP@
M9W5S=&EN9R`E<R`E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("!R;W5N
M9"@D;65T87(M/F-O;G9E<G13<&5E9"@D=V5A=&AE<ELG=VEN9$=U<W0G72P*
M("`@("`@("`@("`@("`@("`@("`@("`@)'5N:71S6R=W:6YD)UTL("=K="<I
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@)VMT)RD["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1H=&UL("X]('-P
M<FEN=&8H7R@B+"!G=7-T:6YG("5S("5S(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@(')O=6YD*"1W96%T:&5R6R=W:6YD1W5S="==*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@)'5N:71S6R=W:6YD)UTI.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E
M="@D=V5A=&AE<ELG=VEN9%9A<FEA8FEL:71Y)UTI*2!["B`@("`@("`@("`@
M(&EF("@D=V5A=&AE<ELG=VEN9%9A<FEA8FEL:71Y)UU;)V9R;VTG72D@>PH@
M("`@("`@("`@("`@("`@)&AT;6P@+CT@<W!R:6YT9BA?*"(L('9A<FEA8FQE
M(&9R;VT@)7,@=&\@)7,B*2P*("`@("`@("`@("`@("`@("`@("`D=V5A=&AE
M<ELG=VEN9%9A<FEA8FEL:71Y)UU;)V9R;VTG72P*("`@("`@("`@("`@("`@
M("`@("`D=V5A=&AE<ELG=VEN9%9A<FEA8FEL:71Y)UU;)W1O)UTI.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!6:7-I8FEL:71Y+@H@
M("`@("`@(&EF("AI<W-E="@D=V5A=&AE<ELG=FES:6)I;&ET>2==*2D@>PH@
M("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W-A;652;W<H7R@B5FES:6)I
M;&ET>2(I+"`D=V5A=&AE<ELG=FES:6)I;&ET>2==("X@)R`G("X@)'5N:71S
M6R=V:7,G72D["B`@("`@("`@?0H*("`@("`@("`O+R!496UP97)A='5R92]$
M97=0;VEN="X*("`@("`@("!I9B`H:7-S970H)'=E871H97);)W1E;7!E<F%T
M=7)E)UTI*2!["B`@("`@("`@("`@("1H=&UL("X]("1T:&ES+3Y?<F]W*%\H
M(E1E;7!E<F%T=7)E(BDL(')O=6YD*"1W96%T:&5R6R=T96UP97)A='5R92==
M*2`N("<F9&5G.R<@+B!3=')I;F<Z.G5P<&5R*"1U;FET<ULG=&5M<"==*2D[
M"B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D=V5A=&AE<ELG9&5W4&]I
M;G0G72DI('L*("`@("`@("`@("`@)&AT;6P@+CT@)'1H:7,M/E]S86UE4F]W
M*%\H(D1E=R!0;VEN="(I+"!R;W5N9"@D=V5A=&AE<ELG9&5W4&]I;G0G72D@
M+B`G)F1E9SLG("X@4W1R:6YG.CIU<'!E<B@D=6YI='-;)W1E;7`G72DI.PH@
M("`@("`@('T*("`@("`@("!I9B`H:7-S970H)'=E871H97);)V9E;'1496UP
M97)A='5R92==*2D@>PH@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W-A
M;652;W<H7R@B1F5E;',@3&EK92(I+"!R;W5N9"@D=V5A=&AE<ELG9F5L=%1E
M;7!E<F%T=7)E)UTI("X@)R9D96<[)R`N(%-T<FEN9SHZ=7!P97(H)'5N:71S
M6R=T96UP)UTI*3L*("`@("`@("!]"@H@("`@("`@("\O(%!R97-S=7)E+@H@
M("`@("`@(&EF("AI<W-E="@D=V5A=&AE<ELG<')E<W-U<F4G72DI('L*("`@
M("`@("`@("`@)&AT;6P@+CT@)'1H:7,M/E]R;W<H7R@B4')E<W-U<F4B*2P@
M)'=E871H97);)W!R97-S=7)E)UT@+B`G("<@+B`D=6YI='-;)W!R97,G72D[
M"B`@("`@("`@?0H*("`@("`@("`O+R!(=6UI9&ET>2X*("`@("`@("!I9B`H
M:7-S970H)'=E871H97);)VAU;6ED:71Y)UTI*2!["B`@("`@("`@("`@("1H
M=&UL("X]("1T:&ES+3Y?<V%M95)O=RA?*")(=6UI9&ET>2(I+"!R;W5N9"@D
M=V5A=&AE<ELG:'5M:61I='DG72D@+B`G)2<I.PH@("`@("`@('T*"B`@("`@
M("`@+R\@0VQO=61S+@H@("`@("`@(&EF("AI<W-E="@D=V5A=&AE<ELG8VQO
M=61S)UTI*2!["B`@("`@("`@("`@("1C;&]U9',@/2`G)SL*("`@("`@("`@
M("`@9F]R96%C:"`H)'=E871H97);)V-L;W5D<R==(&%S("1C;&]U9"D@>PH@
M("`@("`@("`@("`@("`@)&-L;W5D<R`N/2`G/&)R("\^)SL*("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D8VQO=61;)VAE:6=H="==*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1C;&]U9',@+CT@<W!R:6YT9BA?*"(E<R!A="`E<R`E
M<R(I+"`D8VQO=61;)V%M;W5N="==+"`D8VQO=61;)VAE:6=H="==+"`D=6YI
M='-;)VAE:6=H="==*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)&-L;W5D<R`N/2`D8VQO=61;)V%M;W5N="==.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1H
M=&UL("X]("1T:&ES+3Y?<F]W*%\H(D-L;W5D<R(I+"`D8VQO=61S*3L*("`@
M("`@("!]"@H@("`@("`@("\O($-O;F1I=&EO;G,N"B`@("`@("`@:68@*&ES
M<V5T*"1W96%T:&5R6R=C;VYD:71I;VXG72DI('L*("`@("`@("`@("`@)&AT
M;6P@+CT@)'1H:7,M/E]R;W<H7R@B0V]N9&ET:6]N<R(I+"`D=V5A=&AE<ELG
M8V]N9&ET:6]N)UTI.PH@("`@("`@('T*"B`@("`@("`@+R\@4F5M87)K<RX*
M("`@("`@("!I9B`H:7-S970H)'=E871H97);)W)E;6%R:R==*2D@>PH@("`@
M("`@("`@("`D<F5M87)K<R`]("<G.PH@("`@("`@("`@("`D;W1H97(@/2`G
M)SL*("`@("`@("`@("`@9F]R96%C:"`H)'=E871H97);)W)E;6%R:R==(&%S
M("1R96UA<FL@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("!S=VET8V@@
M*"1R96UA<FLI('L*("`@("`@("`@("`@("`@(&-A<V4@)W-E87!R97-S=7)E
M)SH*("`@("`@("`@("`@("`@("`@("`D<F5M87)K<R`N/2`G/&)R("\^)R`N
M(%\H(E!R97-S=7)E(&%T('-E82!L979E;#H@(BD@+B`D=F%L=64@+B`G("<@
M+B`D=6YI='-;)W!R97,G73L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@("`@("!C87-E("=P<F5C:7!I=&%T:6]N)SH*("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("@D=F%L=64@87,@)'!R96-I<"D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-?;G5M97)I8R@D<')E8VEP
M6R=A;6]U;G0G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R
M96UA<FMS("X]("<\8G(@+SXG("X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!S<')I;G1F*%\H(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@
M:&]U<BAS*3H@(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<')E8VEP6R=H;W5R<R==*2`N"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'!R96-I<%LG86UO=6YT)UT@+B`G("<@+B`D=6YI
M='-;)W)A:6XG73L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R96UA<FMS("X]("<\8G(@
M+SXG("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S<')I;G1F
M*%\H(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<')E8VEP
M6R=H;W5R<R==*2`N("1P<F5C:7!;)V%M;W5N="==.PH@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)W-N;W=D
M97!T:"<Z"B`@("`@("`@("`@("`@("`@("`@)')E;6%R:W,@+CT@)SQB<B`O
M/B<@+B!?*")3;F]W(&1E<'1H.B`B*2`N("1V86QU92`N("<@)R`N("1U;FET
M<ULG<F%I;B==.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@("`@(&-A<V4@)W-N;W=E<75I=B<Z"B`@("`@("`@("`@("`@("`@
M("`@)')E;6%R:W,@+CT@)SQB<B`O/B<@+B!?*")3;F]W(&5Q=6EV86QE;G0@
M:6X@=V%T97(Z("(I("X@)'9A;'5E("X@)R`G("X@)'5N:71S6R=R86EN)UT[
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@
M8V%S92`G<W5N9'5R871I;VXG.@H@("`@("`@("`@("`@("`@("`@("1R96UA
M<FMS("X]("<\8G(@+SXG("X@<W!R:6YT9BA?*"(E<R!M:6YU=&5S(BDL("1V
M86QU92D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("`@("`@8V%S92`G,6AT96UP)SH*("`@("`@("`@("`@("`@("`@("`D<F5M
M87)K<R`N/2`G/&)R("\^)R`N(%\H(E1E;7`@9F]R(&QA<W0@:&]U<CH@(BD@
M+B!R;W5N9"@D=F%L=64I("X@)R9D96<[)R`N(%-T<FEN9SHZ=7!P97(H)'5N
M:71S6R=T96UP)UTI.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@("`@(&-A<V4@)S%H9&5W)SH*("`@("`@("`@("`@("`@("`@
M("`D<F5M87)K<R`N/2`G/&)R("\^)R`N(%\H(D1E=R!0;VEN="!F;W(@;&%S
M="!H;W5R.B`B*2`N(')O=6YD*"1V86QU92D@+B`G)F1E9SLG("X@4W1R:6YG
M.CIU<'!E<B@D=6YI='-;)W1E;7`G72D["B`@("`@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G-FAM87AT96UP)SH*("`@
M("`@("`@("`@("`@("`@("`D<F5M87)K<R`N/2`G/&)R("\^)R`N(%\H(DUA
M>"!T96UP(&QA<W0@-B!H;W5R<SH@(BD@+B!R;W5N9"@D=F%L=64I("X@)R9D
M96<[)R`N(%-T<FEN9SHZ=7!P97(H)'5N:71S6R=T96UP)UTI.PH@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)S9H
M;6EN=&5M<"<Z"B`@("`@("`@("`@("`@("`@("`@)')E;6%R:W,@+CT@)SQB
M<B`O/B<@+B!?*")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(I("X@<F]U;F0H
M)'9A;'5E*2`N("<F9&5G.R<@+B!3=')I;F<Z.G5P<&5R*"1U;FET<ULG=&5M
M<"==*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M("`@("!C87-E("<R-&AM87AT96UP)SH*("`@("`@("`@("`@("`@("`@("`D
M<F5M87)K<R`N/2`G/&)R("\^)R`N(%\H(DUA>"!T96UP(&QA<W0@,C0@:&]U
M<G,Z("(I("X@<F]U;F0H)'9A;'5E*2`N("<F9&5G.R<@+B!3=')I;F<Z.G5P
M<&5R*"1U;FET<ULG=&5M<"==*3L*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@("`@("!C87-E("<R-&AM:6YT96UP)SH*("`@("`@
M("`@("`@("`@("`@("`D<F5M87)K<R`N/2`G/&)R("\^)R`N(%\H(DUI;B!T
M96UP(&QA<W0@,C0@:&]U<G,Z("(I("X@<F]U;F0H)'9A;'5E*2`N("<F9&5G
M.R<@+B!3=')I;F<Z.G5P<&5R*"1U;FET<ULG=&5M<"==*3L*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=S96YS
M;W)S)SH*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D=F%L=64@87,@
M)'-E;G-O<BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<F5M87)K<R`N
M/2`G/&)R("\^)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!?*")3
M96YS;W(Z("(I("X@)'-E;G-O<CL*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@9&5F
M875L=#H*("`@("`@("`@("`@("`@("`@("`D;W1H97(@+CT@)SQB<B`O/B<@
M+B`D=F%L=64["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1H=&UL("X]
M("1T:&ES+3Y?<F]W*%\H(E)E;6%R:W,B*2P@)')E;6%R:W,@+B`D;W1H97(I
M.PH@("`@("`@('T*"B`@("`@("`@+R\@5$%&"B`@("`@("`@:68@*"%E;7!T
M>2@D=&AI<RT^7W!A<F%M<ULG=&%F)UTI*2!["B`@("`@("`@("`@("1T868@
M/2`D;65T87(M/F=E=$9O<F5C87-T*"1T:&ES+3Y?<&%R86US6R=L;V-A=&EO
M;B==*3L*("`@("`@("`@("`@:68@*"%I<U]A*"1T868L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@("1F;W)E8V%S="`]("<\=&%B;&4@=VED
M=&@](C$P,"4B(&-E;&QS<&%C:6YG/2(P(CXG.PH@("`@("`@("`@("`@("`@
M)&9O<F5C87-T("X]("<\='(^/'1D(&-L87-S/2)C;VYT<F]L(B!C;VQS<&%N
M/2(R(CX\8V5N=&5R/CQS=')O;F<^)R`N(%\H(D9O<F5C87-T("A4048I(BD@
M+B`G/"]S=')O;F<^/"]T9#X\+W1R/CPO=&%B;&4^)SL*("`@("`@("`@("`@
M("`@("1F;W)E8V%S="`N/2`G/'-T<F]N9SY686QI9#H@/"]S=')O;F<^)R`N
M("1T869;)W9A;&ED1G)O;2==("X@)R`M("<@+B`D=&%F6R=V86QI9%1O)UT@
M+B`G/&)R("\^/&)R("\^)SL*("`@("`@("`@("`@("`@("1I=&5M(#T@,#L*
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T869;)W1I;64G72!A<R`D=&EM
M92`]/B`D96YT<GDI('L*("`@("`@("`@("`@("`@("`@("`D:71E;2LK.PH@
M("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G/'1A8FQE('=I9'1H
M/2(Q,#`E(B!C96QL<W!A8VEN9STB,"(^)SL*("`@("`@("`@("`@("`@("`@
M("`D9F]R96-A<W0@+CT@)SQT<B!C;&%S<STB:71E;2<@+B`H)&ET96T@)2`R
M*2`N("<B/B<["B`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<\
M=&0@86QI9VX](F-E;G1E<B(@=VED=&@](C4P(CXG("X@)'1I;64@+B`G/"]T
M9#X\=&0^/'-T<F]N9SY7:6YD.CPO<W1R;VYG/B`G.PH@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D96YT<GE;)W=I;F0G72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"1E;G1R>5LG=VEN9$1I<F5C=&EO;B==(#T]
M("=687)I86)L92<I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@A96UP='DH)'1H:7,M/E]P87)A;7-;)VMN;W1S)UTI*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]('-P<FEN=&8H
M7R@B)7,@870@)7,@)7,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@<W1R=&]L;W=E<B@D96YT<GE;)W=I;F1$:7)E8W1I;VXG72DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')O=6YD*"1M
M971A<BT^8V]N=F5R=%-P965D*"1E;G1R>5LG=VEN9"==+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'5N:71S6R=W:6YD)UTL
M("=K="<I*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VMT)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2!S
M<')I;G1F*%\H(B5S(&%T("5S("5S(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1E;G1R>5LG=VEN9$1I<F5C=&EO;B==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R;W5N9"@D96YT<GE;
M)W=I;F0G72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1U;FET<ULG=VEN9"==*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"@D96YT<GE;
M)W=I;F1$96=R965S)UT@/3T@)S`P,"<I("8F"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("@D96YT<GE;)W=I;F0G72`]/2`G,"<I*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@<W!R
M:6YT9BA?*")C86QM(BDI.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]
M('-P<FEN=&8H7R@B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D96YT
M<GE;)W=I;F1$:7)E8W1I;VXG72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&5N=')Y6R=W:6YD1&5G<F5E<R==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!E
M;7!T>2@D=&AI<RT^7W!A<F%M<ULG:VYO=',G72D@/PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R;W5N9"@D96YT<GE;
M)W=I;F0G72D@.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!R;W5N9"@D;65T87(M/F-O;G9E<G13<&5E9"@D96YT<GE;
M)W=I;F0G72P@)'5N:71S6R=W:6YD)UTL("=K="<I*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@96UP='DH)'1H:7,M
M/E]P87)A;7-;)VMN;W1S)UTI(#\*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'5N:71S6R=W:6YD)UT@.@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:W0G*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("`@("`D9F]R96-A<W0@+CT@)SQB<B`O/B<["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D96YT<GE;)W1E
M;7!E<F%T=7)E3&]W)UTI('Q\(&ES<V5T*"1E;G1R>5LG=&5M<&5R871U<F5(
M:6=H)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N
M/2`G/'-T<F]N9SY496UP97)A='5R93PO<W1R;VYG/B<["B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D96YT<GE;)W1E;7!E<F%T=7)E3&]W
M)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@
M+CT@)SQS=')O;F<^($QO=SH\+W-T<F]N9SXG.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&9O<F5C87-T("X]("1E;G1R>5LG=&5M<&5R871U<F5,
M;W<G73L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&5N=')Y6R=T96UP97)A='5R94AI9V@G
M72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N
M/2`G/'-T<F]N9SX@2&EG:#H\+W-T<F]N9SXG.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&9O<F5C87-T("X]("1E;G1R>5LG=&5M<&5R871U<F5(
M:6=H)UT["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`@("`@)&9O<F5C87-T("X]("<\8G(@+SXG.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&5N
M=')Y6R=W:6YD<VAE87(G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&9O<F5C87-T("X]("<\<W1R;VYG/E=I;F1S:&5A<CH\+W-T<F]N9SXG.PH@
M("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@<W!R:6YT9BA?
M*")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(BDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D96YT<GE;)W=I;F1S:&5A<D1I
M<F5C=&EO;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&5N=')Y6R=W:6YD<VAE87)$96=R965S)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D96YT<GE;)W=I;F1S:&5A
M<DAE:6=H="==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'5N:71S6R=H96EG:'0G72D["B`@("`@("`@("`@("`@("`@("`@
M("`@("1F;W)E8V%S="`N/2`G/&)R("\^)SL*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1E;G1R>5LG=FES
M:6)I;&ET>2==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A
M<W0@+CT@)SQS=')O;F<^5FES:6)I;&ET>3H\+W-T<F]N9SX@)SL*("`@("`@
M("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]('-T<G1O;&]W97(H)&5N
M=')Y6R=V:7-1=6%L:69I97(G72D@+B`G("<@+B`D96YT<GE;)W9I<VEB:6QI
M='DG72`N("<@)R`N("1U;FET<ULG=FES)UT["B`@("`@("`@("`@("`@("`@
M("`@("`@("1F;W)E8V%S="`N/2`G/&)R("\^)SL*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1E;G1R>5LG
M8V]N9&ET:6]N)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E
M8V%S="`N/2`G/'-T<F]N9SY#;VYD:71I;VYS.CPO<W1R;VYG/B`G.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@)&5N=')Y6R=C;VYD
M:71I;VXG73L*("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]
M("<\8G(@+SXG.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`D9F]R96-A<W0@+CT@)SQS=')O;F<^0VQO=61S.CPO<W1R;VYG
M/B`G.PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1E;G1R>5LG8VQO
M=61S)UT@87,@)&-L;W5D<RD@>PH@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)&-L;W5D<ULG='EP92==*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&9O<F5C87-T("X]("<@)R`N("1C;&]U9'-;)W1Y<&4G
M73L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("`@("`D9F]R96-A<W0@+CT@)R`G("X@)&-L;W5D<ULG86UO=6YT)UT[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D8VQO=61S6R=H
M96EG:'0G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E
M8V%S="`N/2`G(&%T("<@+B`D8VQO=61S6R=H96EG:'0G72`N("<@)R`N("1U
M;FET<ULG:&5I9VAT)UT["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@
M)R`G.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G/"]T
M9#X\+W1R/B<["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1E;G1R
M>5LG9FUC)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1I=&5M*RL[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1E;G1R>5LG9FUC
M)UT@87,@)&9M8T5N=')Y*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9F]R96-A<W0@+CT@)SQT<B!C;&%S<STB:71E;2<@+B`H)&ET96T@)2`R
M*2`N("<B/B<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A
M<W0@+CT@)SQT9"!A;&EG;CTB8V5N=&5R(B!W:61T:#TB-3`B/B<["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@)RH@)R`N("1F
M;6-%;G1R>5LG9G)O;2==("X@)SQB<B`O/B`M("<@+B`D9FUC16YT<GE;)W1O
M)UT@+B`G/"]T9#XG.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O
M<F5C87-T("X]("<\=&0^)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1F;W)E8V%S="`N/2`G/'-T<F]N9SY4>7!E.B`\+W-T<F]N9SXG("X@)&9M
M8T5N=')Y6R=T>7!E)UT["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)&9M8T5N=')Y6R=P<F]B86)I;&ET>2==*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G(#QS=')O
M;F<^(%!R;V(Z(#PO<W1R;VYG/B<@+B`D9FUC16YT<GE;)W!R;V)A8FEL:71Y
M)UT@+B`G)2<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&9M8T5N=')Y6R=C
M;VYD:71I;VXG72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9F]R96-A<W0@+CT@)R`\<W1R;VYG/B!#;VYD:71I;VYS.B`\+W-T<F]N
M9SXG("X@)&9M8T5N=')Y6R=C;VYD:71I;VXG73L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D9FUC16YT<GE;)V-L;W5D<R==*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G(#QS=')O;F<^0VQO
M=61S.CPO<W1R;VYG/B<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)&9M8T5N=')Y6R=C;&]U9',G72!A<R`D9FUC0VQO=61S
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D9FUC0VQO=61S6R=T>7!E)UTI*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@)R`G("X@)&9M
M8T-L;W5D<ULG='EP92==.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D9FUC0VQO=61S6R=H96EG:'0G72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G
M("<@+B`D9FUC0VQO=61S6R=A;6]U;G0G73L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G("<@+B`D9FUC
M0VQO=61S6R=H96EG:'0G73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G("<@+B`D=6YI='-;)VAE:6=H
M="==.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&9O<F5C87-T("X]("<@)R`N("1F;6-#;&]U9'-;)V%M;W5N="==.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1F;6-%;G1R>5LG=FES475A;&EF:65R)UTI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<@/'-T<F]N9SY6:7-I
M8FEL:71Y.CPO<W1R;VYG/B`G.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1F;W)E8V%S="`N/2!S=')T;VQO=V5R*"1F;6-%;G1R>5LG=FES
M475A;&EF:65R)UTI("X@)R`G.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1F;W)E8V%S="`N/2`D9FUC16YT<GE;)W9I<VEB:6QI='DG72`N
M("<@)R`N("1U;FET<ULG=FES)UT["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@
M+CT@)SPO=&0^/"]T<CXG.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1F;W)E8V%S="`N/2`G/"]T86)L93XG.PH*("`@("`@("`@
M("`@("`@("1H=&UL("X]("1F;W)E8V%S=#L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1H=&UL.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]";&]C:R]M;V]N
M+G!H<```````````````````````````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,3<P,C4`,3`U,34T,S,W-#4`,#(Q,30U`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@HD8FQO8VM?;F%M92`](%\H
M(DUO;VX@4&AA<V5S(BD["@HO*BH*("H@)$AO<F1E.B!H;W)D92]L:6(O0FQO
M8VLO;6]O;BYP:'`L=B`Q+C$V+C$P+C0@,C`P-2\Q,"\Q."`Q,3HS,SHS.2!J
M86X@17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&5?0FQO8VL*("HO"F-L87-S
M($AO<F1E7T)L;V-K7TAO<F1E7VUO;VX@97AT96YD<R!(;W)D95]";&]C:R![
M"@H@("`@=F%R("1?87!P(#T@)VAO<F1E)SL*"B`@("!F=6YC=&EO;B!?=&ET
M;&4H*0H@("`@>PH@("`@("`@(')E='5R;B!?*")-;V]N(%!H87-E<R(I.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]P87)A;7,H*0H@("`@>PH@("`@("`@(')E
M='5R;B!A<G)A>2@*("`@("`@("`@("`@)W!H87-E)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@("`@("=N86UE)R`]/B!?*")7:&EC:"!P:&%S97,B*2P*("`@
M("`@("`@("`@("`@("=T>7!E)R`]/B`G96YU;2<L"B`@("`@("`@("`@("`@
M("`G9&5F875L="<@/3X@)V-U<G)E;G0G+`H@("`@("`@("`@("`@("`@)W9A
M;'5E<R<@/3X@87)R87DH)V-U<G)E;G0G(#T^(%\H(D-U<G)E;G0@-"!0:&%S
M97,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N97AT
M)R`]/B!?*").97AT(#0@4&AA<V5S(BDI*2P*("`@("`@("`@("`@)VAE;6ES
M<&AE<F4G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H
M(DAE;6ES<&AE<F4B*2P*("`@("`@("`@("`@("`@("=T>7!E)R`]/B`G96YU
M;2<L"B`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@)VYO<G1H97)N)RP*
M("`@("`@("`@("`@("`@("=V86QU97,G(#T^(&%R<F%Y*"=N;W)T:&5R;B<@
M/3X@7R@B3F]R=&AE<FX@2&5M:7-P:&5R92(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W-O=71H97)N)R`]/B!?*")3;W5T:&5R;B!(
M96UI<W!H97)E(BDI*2P*("`@("`@("`@("`@*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!?8V]N=&5N="@I"B`@("!["B`@("`@("`@)'!H87-E<R`]("1T:&ES
M+3Y?8V%L8W5L871E36]O;E!H87-E<RAD871E*"=9)RDI.PH@("`@("`@("1N
M;W<@/2!T:6UE*"D["@H@("`@("`@("1L87-T3F5W(#T@,#L*("`@("`@("`D
M;&%S=$YE=U-T86UP(#T@,#L*("`@("`@("`D;V9F<V5T(#T@,#L*("`@("`@
M("!F;W)E86-H("@D<&AA<V5S(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@
M("`@("!I9B`H)&ME>2`\("1N;W<@)B8@)&ME>2`^("1L87-T3F5W4W1A;7`@
M)B8@)'9A;"`]/2!?*").97<@36]O;B(I*2!["B`@("`@("`@("`@("`@("`D
M;&%S=$YE=R`]("1O9F9S970["B`@("`@("`@("`@("`@("`D;&%S=$YE=U-T
M86UP(#T@)&ME>3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;V9F<V5T
M*RL["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P87)A
M;7-;)W!H87-E)UTI("8F("1T:&ES+3Y?<&%R86US6R=P:&%S92==(#T]("=N
M97AT)RD@>PH@("`@("`@("`@("`D9&%T97,@/2!A<G)A>5]S;&EC92AA<G)A
M>5]K97ES*"1P:&%S97,I+"`D;&%S=$YE=R`K(#0L(#0I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1D871E<R`](&%R<F%Y7W-L:6-E*&%R<F%Y
M7VME>7,H)'!H87-E<RDL("1L87-T3F5W+"`T*3L*("`@("`@("!]"@H@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W!A<F%M<ULG:&5M:7-P:&5R92==*2`F
M)B`D=&AI<RT^7W!A<F%M<ULG:&5M:7-P:&5R92==(#T]("=N;W)T:&5R;B<I
M('L*("`@("`@("`@("`@)&QO8V%T:6]N(#T@7R@B3F]R=&AE<FX@2&5M:7-P
M:&5R92(I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1L;V-A=&EO
M;B`](%\H(E-O=71H97)N($AE;6ES<&AE<F4B*3L*("`@("`@("!]"@H@("`@
M("`@("1H=&UL(#T@)SQT86)L92!W:61T:#TB,3`P)2(@:&5I9VAT/2(Q,#`E
M(B!C96QL<W!A8VEN9STB,"(^)R`N"B`@("`@("`@("`@("<\='(^/'1D(&-O
M;'-P86X](C0B(&-L87-S/2)C;VYT<F]L(CX\<W1R;VYG/B<@+B`D;&]C871I
M;VX@+B`G/"]S=')O;F<^/"]T9#X\+W1R/B<@+@H@("`@("`@("`@("`G/'1R
M(&AE:6=H=#TB,3`P)2(^/'1D('=I9'1H/2(R-24B(&%L:6=N/2)C96YT97(B
M/B<@+@H@("`@("`@("`@("!(;W)D93HZ:6UG*"=B;&]C:R]M;V]N+VYE=VUO
M;VXN<&YG)RP@7R@B3F5W($UO;VXB*2D@+@H@("`@("`@("`@("`G/&)R("\^
M)R`N('-T<F9T:6UE*"<E9"`E8B<L("1D871E<ULP72D@+@H@("`@("`@("`@
M("`G/"]T9#XG.PH*("`@("`@("`D:'1M;"`N/2`G/'1D('=I9'1H/2(R-24B
M(&%L:6=N/2)C96YT97(B/B<["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M<&%R86US6R=H96UI<W!H97)E)UTI("8F("1T:&ES+3Y?<&%R86US6R=H96UI
M<W!H97)E)UT@/3T@)VYO<G1H97)N)RD@>PH@("`@("`@("`@("`D:'1M;"`N
M/2!(;W)D93HZ:6UG*"=B;&]C:R]M;V]N+VQA<W1Q=6%R=&5R+G!N9R<L(%\H
M(D9I<G-T(%%U87)T97(B*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&AT;6P@+CT@2&]R9&4Z.FEM9R@G8FQO8VLO;6]O;B]F:7)S='%U87)T
M97(N<&YG)RP@7R@B1FER<W0@475A<G1E<B(I*3L*("`@("`@("!]"B`@("`@
M("`@)&AT;6P@+CT@)SQB<B`O/B<@+B!S=')F=&EM92@G)60@)6(G+"`D9&%T
M97-;,5TI("X@)SPO=&0^)SL*"B`@("`@("`@)&AT;6P@+CT@)SQT9"!W:61T
M:#TB,C4E(B!A;&EG;CTB8V5N=&5R(CXG("X*("`@("`@("`@("`@2&]R9&4Z
M.FEM9R@G8FQO8VLO;6]O;B]F=6QL;6]O;BYP;F<G+"!?*")&=6QL($UO;VXB
M*2D@+@H@("`@("`@("`@("`G/&)R("\^)R`N('-T<F9T:6UE*"<E9"`E8B<L
M("1D871E<ULR72D@+B`G/"]T9#XG.PH*("`@("`@("`D:'1M;"`N/2`G/'1D
M('=I9'1H/2(R-24B(&%L:6=N/2)C96YT97(B/B<["B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?<&%R86US6R=H96UI<W!H97)E)UTI("8F("1T:&ES+3Y?
M<&%R86US6R=H96UI<W!H97)E)UT@/3T@)VYO<G1H97)N)RD@>PH@("`@("`@
M("`@("`D:'1M;"`N/2!(;W)D93HZ:6UG*"=B;&]C:R]M;V]N+V9I<G-T<75A
M<G1E<BYP;F<G+"!?*"),87-T(%%U87)T97(B*2D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&AT;6P@+CT@2&]R9&4Z.FEM9R@G8FQO8VLO;6]O
M;B]L87-T<75A<G1E<BYP;F<G+"!?*"),87-T(%%U87)T97(B*2D["B`@("`@
M("`@?0H@("`@("`@("1H=&UL("X]("<\8G(@+SXG("X@<W1R9G1I;64H)R5D
M("5B)RP@)&1A=&5S6S-=*2`N("<\+W1D/CPO='(^/"]T86)L93XG.PH*("`@
M("`@("!R971U<FX@)&AT;6P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&%N(&%R<F%Y('=I=&@@86QL('1H92!P:&%S97,@;V8@=&AE(&UO;VX@
M9F]R(&$@=VAO;&4*("`@("`J('EE87(N"B`@("`@*@H@("`@("H@0F%S960@
M;VX@8V]D92!F<F]M"B`@("`@*B!H='1P.B\O=W=W+GIE;F0N8V]M+V-O9&5X
M+G!H<#]I9#TX,S`F<VEN9VQE/3$@8GD@07)E(%!E9&5R<V5N+@H@("`@("H*
M("`@("`J($-O;G9E<G1E9"!F<F]M($)A<VEC(&)Y(%)O9V5R(%<N(%-I;FYO
M="P@4VMY("8@5&5L97-C;W!E+"!-87)C:"`Q.3@U+@H@("`@("H@0V]N=F5R
M=&5D(&9R;VT@:F%V87-C<FEP="!B>2!!<F4@4&5D97)S96X@,C`P,@H@("`@
M("H@2F%V87-C<FEP="!F;W5N9"!A="!H='1P.B\O=W=W+G-T96QL869A;F4N
M8V]M+VUO;VY?<&AA<V4O;6]O;E]P:&%S92YH=&T*("`@("`J"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`@("1Y96%R("`@5&AE(&9O=7(@9&EG:70@>65A<B!T
M;R!R971U<FX@=&AE(&UO;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("!P:&%S97,@9F]R+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M("`@5&AE(&UO;VX@<&AA<V5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V%L
M8W5L871E36]O;E!H87-E<R@D62D*("`@('L*("`@("`@("`D4C$@/2`S+C$T
M,34Y,C8U("\@,3@P.PH@("`@("`@("15("`](&9A;'-E.PH@("`@("`@("1+
M,"`](&EN='9A;"@H)%D@+2`Q.3`P*2`J(#$R+C,V.#4I.PH@("`@("`@("14
M("`]("@D62`M(#$X.3DN-2D@+R`Q,#`["B`@("`@("`@)%0R(#T@)%0@*B`D
M5#L*("`@("`@("`D5#,@/2`D5"`J("14("H@)%0["B`@("`@("`@)$HP(#T@
M,C0Q-3`R,"`K(#(Y("H@)$LP.PH@("`@("`@("1&,"`](#`N,#`P,3$W."`J
M("14,B`M(#`N,#`P,#`P,34U("H@)%0S.PH@("`@("`@("1&,"`K/2`H,"XW
M-3DS,R`K(#`N-3,P-3@X-C@J)$LP*3L*("`@("`@("`D1C`@+3T@*#`N,#`P
M.#,W("H@)%0@*R`P+C`P,#,S-2`J("14,BD["B`@("`@("`@)$TP("`]("1+
M,"`J(#`N,#@P.#0X,C$Q,S,["B`@("`@("`@)$TP("`](#,V,"`J("@D33`@
M+2!I;G1V86PH)$TP*2D@*R`S-3DN,C(T,CL*("`@("`@("`D33`@+3T@,"XP
M,#`P,S,S("H@)%0R.PH@("`@("`@("1-,"`M/2`P+C`P,#`P,S0W("H@)%0S
M.PH@("`@("`@("1-,2`@/2`D2S`@*B`P+C`W,3<Q,S8V,3(X.PH@("`@("`@
M("1-,2`@/2`S-C`@*B`H)$TQ("T@:6YT=F%L*"1-,2DI("L@,S`V+C`R-3,[
M"B`@("`@("`@)$TQ("L](#`N,#$P-S,P-B`J("14,CL*("`@("`@("`D33$@
M*ST@,"XP,#`P,3(S-B`J("14,SL*("`@("`@("`D0C$@(#T@)$LP("H@,"XP
M.#4Q.34X-3$R.#L*("`@("`@("`D0C$@(#T@,S8P("H@*"1",2`M(&EN='9A
M;"@D0C$I*2`K(#(Q+C(Y-C0["B`@("`@("`@)$(Q("T](#`N,#`Q-C4R."`J
M("14,CL*("`@("`@("`D0C$@+3T@,"XP,#`P,#(S.2`J("14,SL*("`@("`@
M("!F;W(@*"1+.2`](#`[("1+.2`\/2`R.#L@)$LY(#T@)$LY("L@,"XU*2![
M"B`@("`@("`@("`@("1*(#T@)$HP("L@,30@*B`D2SD["B`@("`@("`@("`@
M("1&(#T@)$8P("L@,"XW-C4R.30@*B`D2SD["B`@("`@("`@("`@("1+(#T@
M)$LY("\@,CL*("`@("`@("`@("`@)$TU(#T@*"1-,"`K("1+("H@,CDN,3`U
M,S4V,#@I("H@)%(Q.PH@("`@("`@("`@("`D338@/2`H)$TQ("L@)$L@*B`S
M.#4N.#$V.3$X,#8I("H@)%(Q.PH@("`@("`@("`@("`D0C8@/2`H)$(Q("L@
M)$L@*B`S.3`N-C<P-3`V-#8I("H@)%(Q.PH@("`@("`@("`@("`D1B`M/2`P
M+C0P-C@@*B!S:6XH)$TV*3L*("`@("`@("`@("`@)$8@*ST@*#`N,3<S-"`M
M(#`N,#`P,SDS("H@)%0I("H@<VEN*"1--2D["B`@("`@("`@("`@("1&("L]
M(#`N,#$V,2`J('-I;B@R("H@)$TV*3L*("`@("`@("`@("`@)$8@*ST@,"XP
M,3`T("H@<VEN*#(@*B`D0C8I.PH@("`@("`@("`@("`D1B`M/2`P+C`P-S0@
M*B!S:6XH)$TU("T@)$TV*3L*("`@("`@("`@("`@)$8@+3T@,"XP,#4Q("H@
M<VEN*"1--2`K("1--BD["B`@("`@("`@("`@("1&("L](#`N,#`R,2`J('-I
M;B@R("H@)$TU*3L*("`@("`@("`@("`@)$8@*ST@,"XP,#$P("H@<VEN*#(@
M*B`D0C8@+2`D338I.PH*("`@("`@("`@("`@+RH@061D(#$O,B!M:6YU=&4@
M9F]R('!R;W!E<B!R;W5N9&EN9R!T;R!M:6YU=&5S('!E<B!3:WD@)@H@("`@
M("`@("`@("`@*B!496P@87)T:6-L92X@*B\*("`@("`@("`@("`@)$8@*ST@
M,"XU("\@,30T,#L*("`@("`@("`@("`@)$H@*ST@:6YT=F%L*"1&*3L*("`@
M("`@("`@("`@)$8@+3T@:6YT=F%L*"1&*3L*"B`@("`@("`@("`@("\J($-O
M;G9E<G0@9G)O;2!*1"!T;R!#86QE;F1A<B!$871E+B`J+PH@("`@("`@("`@
M("`D:G5L:6%N(#T@)$H@*R!R;W5N9"@D1BD["B`@("`@("`@("`@("1P87)T
M<R`@/2!E>'!L;V1E*"<O)RP@)'1H:7,M/E]J9'1O9W)E9V]R:6%N*"1J=6QI
M86XI*3L*("`@("`@("`@("`@)'-T86UP("`](&=M;6MT:6UE*#`L(#`L(#`L
M("1P87)T<ULP72P@)'!A<G1S6S%=+"`D<&%R='-;,ETI.PH*("`@("`@("`@
M("`@+RH@:&%L9B!++B`J+PH@("`@("`@("`@("!I9B`H*"1+.2`M(&9L;V]R
M*"1+.2DI(#X@,"D@>PH@("`@("`@("`@("`@("`@:68@*"15*2!["B`@("`@
M("`@("`@("`@("`@("`@+RH@3F5W(&AA;&8N("HO"B`@("`@("`@("`@("`@
M("`@("`@)'!H87-E<ULD<W1A;7!=(#T@7R@B1FER<W0@2&%L9B(I.PH@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O*B!&
M=6QL(&AA;&8N("HO"B`@("`@("`@("`@("`@("`@("`@)'!H87-E<ULD<W1A
M;7!=(#T@7R@B3&%S="!(86QF(BD["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O*B!F=6QL($LN("HO
M"B`@("`@("`@("`@("`@("!I9B`H(215*2!["B`@("`@("`@("`@("`@("`@
M("`@)'!H87-E<ULD<W1A;7!=(#T@7R@B3F5W($UO;VXB*3L*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'!H87-E<ULD
M<W1A;7!=(#T@7R@B1G5L;"!-;V]N(BD["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D52`]("$D53L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1P:&%S97,["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#:&5C:W,@:68@=&AE(&ID=&]G<F5G;W)I86X@9G5N8W1I;VX@97AI
M<W1S+"!A;F0@:68@;F]T"B`@("`@*B!C86QC=6QA=&5S('1H92!G<F5G;W)I
M86X@9&%T92!M86YU86QL>2X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("1J
M=6QI86X@5&AE(&IU;&EA;B!D871E"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@;2]D+UD*("`@("`J+PH@("`@9G5N8W1I;VX@7VID=&]G<F5G;W)I
M86XH)&IU;&EA;BD*("`@('L*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S
M*"=J9'1O9W)E9V]R:6%N)RDI('L*("`@("`@("`@("`@<F5T=7)N(&ID=&]G
M<F5G;W)I86XH)&IU;&EA;BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@+R\@1G)O;2!H='1P.B\O<&AP+FYE="]M86YU86PO96XO9G5N8W1I;VXN
M:F1T;V=R96=O<FEA;BYP:'`*("`@("`@("`@("`@)&IU;&EA;B`]("1J=6QI
M86X@+2`Q-S(Q,3$Y.PH@("`@("`@("`@("`D8V%L8S$@/2`T("H@)&IU;&EA
M;B`M(#$["B`@("`@("`@("`@("1Y96%R(#T@9FQO;W(H)&-A;&,Q("\@,30V
M,#DW*3L*("`@("`@("`@("`@)&IU;&EA;B`](&9L;V]R*"1C86QC,2`M(#$T
M-C`Y-R`J("1Y96%R*3L*("`@("`@("`@("`@)&1A>2`](&9L;V]R*"1J=6QI
M86X@+R`T*3L*("`@("`@("`@("`@)&-A;&,R(#T@-"`J("1D87D@*R`S.PH@
M("`@("`@("`@("`D:G5L:6%N(#T@9FQO;W(H)&-A;&,R("\@,30V,2D["B`@
M("`@("`@("`@("1D87D@/2`D8V%L8S(@+2`Q-#8Q("H@)&IU;&EA;CL*("`@
M("`@("`@("`@)&1A>2`](&9L;V]R*"@D9&%Y("L@-"D@+R`T*3L*("`@("`@
M("`@("`@)&-A;&,S(#T@-2`J("1D87D@+2`S.PH@("`@("`@("`@("`D;6]N
M=&@@/2!F;&]O<B@D8V%L8S,@+R`Q-3,I.PH@("`@("`@("`@("`D9&%Y(#T@
M)&-A;&,S("T@,34S("H@)&UO;G1H.PH@("`@("`@("`@("`D9&%Y(#T@9FQO
M;W(H*"1D87D@*R`U*2`O(#4I.PH@("`@("`@("`@("`D>65A<B`](#$P,"`J
M("1Y96%R("L@)&IU;&EA;CL*"B`@("`@("`@("`@(&EF("@D;6]N=&@@/"`Q
M,"D@>PH@("`@("`@("`@("`@("`@)&UO;G1H(#T@)&UO;G1H("L@,SL*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1M;VYT:"`]("1M
M;VYT:"`M(#D["B`@("`@("`@("`@("`@("`D>65A<B`]("1Y96%R("L@,3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@(B1M;VYT:"\D9&%Y
M+R1Y96%R(CL*("`@("`@("!]"B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O0FQO8VLO<W5N<FES92YP:'``````````````````````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q-C4U`#$P-3$U-#,S-S0U`#`R,38W,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`H*)&)L;V-K7VYA;64@/2!?*")3=6YR:7-E+U-U;G-E="(I.PH*+RHJ"B`J
M("1(;W)D93H@:&]R9&4O;&EB+T)L;V-K+W-U;G)I<V4N<&AP+'8@,2XQ-"XQ
M,"XS(#(P,#4O,3`O,3@@,3$Z,S,Z,SD@:F%N($5X<"`D"B`J"B`J($!P86-K
M86=E($AO<F1E7T)L;V-K"B`J+PIC;&%S<R!(;W)D95]";&]C:U](;W)D95]S
M=6YR:7-E(&5X=&5N9',@2&]R9&5?0FQO8VL@>PH*("`@('9A<B`D7V%P<"`]
M("=H;W)D92<["@H@("`@9G5N8W1I;VX@7W1I=&QE*"D*("`@('L*("`@("`@
M("!R971U<FX@7R@B4W5N<FES92]3=6YS970B*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!?<&%R86US*"D*("`@('L*("`@("`@("`D<&%R86US(#T@87)R87DH
M)VQO8V%T:6]N)R`]/B!A<G)A>2@G='EP92<@/3X@)VUL96YU;2<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYA;64G
M(#T^(%\H(DQO8V%T:6]N(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("<U,2XU,3<Z+3`N,3$W
M)RDI.PH*("`@("`@("!G;&]B86P@)&-O;W)D:6YA=&5S.PH@("`@("`@(&EF
M("@A:7-?87)R87DH)&-O;W)D:6YA=&5S*2D@>PH@("`@("`@("`@("!`:6YC
M;'5D92`G2&]R9&4O3DQ3+V-O;W)D:6YA=&5S+G!H<"<["B`@("`@("`@("`@
M(&EF("@A:7-?87)R87DH)&-O;W)D:6YA=&5S*2D@>PH@("`@("`@("`@("`@
M("`@)&-O;W)D:6YA=&5S(#T@87)R87DH*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("`D<&%R86US6R=L;V-A=&EO;B==6R=V86QU97,G72`]
M("1C;V]R9&EN871E<SL*"B`@("`@("`@<F5T=7)N("1P87)A;7,["B`@("!]
M"@H@("`@9G5N8W1I;VX@7V-O;G1E;G0H*0H@("`@>PH@("`@("`@(&EF("AE
M;7!T>2@D=&AI<RT^7W!A<F%M<ULG;&]C871I;VXG72DI('L*("`@("`@("`@
M("`@<F5T=7)N(%\H(DYO(&QO8V%T:6]N(&ES('-E="XB*3L*("`@("`@("!]
M"@H@("`@("`@("\O(%-E="!T:&4@=&EM97IO;F4@=F%R:6%B;&4L(&EF(&%V
M86EL86)L92X*("`@("`@("!.3%,Z.G-E=%1I;65:;VYE*"D["@H@("`@("`@
M(&QI<W0H)&QA="P@)&QO;F<I(#T@97AP;&]D92@G.B<L("1T:&ES+3Y?<&%R
M86US6R=L;V-A=&EO;B==*3L*("`@("`@("`D<FES92`]("1T:&ES+3Y?8V%L
M8W5L871E4W5N<V5T*'1I;64H*2P@)&QA="P@)&QO;F<L(&9A;'-E+"!F;&]O
M<BAD871E*"=:)RD@+R`S-C`P*2D["B`@("`@("`@)'-E="`]("1T:&ES+3Y?
M8V%L8W5L871E4W5N<V5T*'1I;64H*2P@)&QA="P@)&QO;F<L('1R=64L(&9L
M;V]R*&1A=&4H)UHG*2`O(#,V,#`I*3L*"B`@("`@("`@)&QO8V%T:6]N(#T@
M)R<["B`@("`@("`@9VQO8F%L("1C;V]R9&EN871E<SL*("`@("`@("!I9B`H
M(6ES7V%R<F%Y*"1C;V]R9&EN871E<RDI('L*("`@("`@("`@("`@<F5Q=6ER
M92`G2&]R9&4O3DQ3+V-O;W)D:6YA=&5S+G!H<"<["B`@("`@("`@?0H@("`@
M("`@(&9O<F5A8V@@*"1C;V]R9&EN871E<R!A<R`D8V]U;G1R>2D@>PH@("`@
M("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@D=&AI<RT^7W!A<F%M<ULG
M;&]C871I;VXG72P@)&-O=6YT<GDI*2!["B`@("`@("`@("`@("`@("`D;&]C
M871I;VX@/2`D8V]U;G1R>5LD=&AI<RT^7W!A<F%M<ULG;&]C871I;VXG75T[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("<\=&%B;&4@=VED=&@](C$P,"4B(&AE:6=H
M=#TB,3`P)2(@8V5L;'-P86-I;F<](C`B/CQT<CXG("X*("`@("`@("`@("`@
M)SQT9"!C;VQS<&%N/2(R(B!C;&%S<STB8V]N=')O;"(^/'-T<F]N9SXG("X@
M)&QO8V%T:6]N("X@)SPO<W1R;VYG/CPO=&0^/"]T<CX\='(@:&5I9VAT/2(Q
M,#`E(CXG("X*("`@("`@("`@("`@)SQT9"!W:61T:#TB-3`E(B!A;&EG;CTB
M8V5N=&5R(CXG("X*("`@("`@("`@("`@2&]R9&4Z.FEM9R@G8FQO8VLO<W5N
M<FES92]S=6YR:7-E+G!N9R<L(%\H(E-U;B!2:7-E(BDI("X*("`@("`@("`@
M("`@)SQB<B`O/B<@+B`D<FES92`N("<\+W1D/B<@+@H@("`@("`@("`@("`G
M/'1D('=I9'1H/2(U,"4B(&%L:6=N/2)C96YT97(B/B<@+@H@("`@("`@("`@
M("!(;W)D93HZ:6UG*"=B;&]C:R]S=6YR:7-E+W-U;G-E="YP;F<G+"!?*")3
M=6X@4V5T(BDI("X*("`@("`@("`@("`@)SQB<B`O/B<@+B`D<V5T("X@)SPO
M=&0^)R`N("<\+W1R/CPO=&%B;&4^)SL*("`@('T*"B`@("`O*BH*("`@("`J
M(&AT='`Z+R]W=W<N>F5N9"YC;VTO8V]D97@N<&AP/VED/3$S-29S:6YG;&4]
M,0H@("`@("HO"B`@("!F=6YC=&EO;B!?8V%L8W5L871E4W5N<V5T*"1D871E
M+"`D;&%T:71U9&4L("1L;VYG:71U9&4L("1S=6YS970@/2!T<G5E+"`D=&EM
M97IO;F4I"B`@("!["B`@("`@("`@)'ED87D@/2!D871E*"=Z)RP@)&1A=&4I
M.PH@("`@("`@("1M;VX@/2!D871E*"=N)RP@)&1A=&4I.PH@("`@("`@("1M
M9&%Y(#T@9&%T92@G:B<L("1D871E*3L*("`@("`@("`D>65A<B`](&1A=&4H
M)UDG+"`D9&%T92D["@H@("`@("`@(&EF("@D=&EM97IO;F4@/3T@)S$S)RD@
M>PH@("`@("`@("`@("`D=&EM97IO;F4@/2`G+3$Q)SL*("`@("`@("`@("`@
M)&UD87DK*SL*("`@("`@("`@("`@)'ED87DK*SL*("`@("`@("!]"@H@("`@
M("`@("1!(#T@,2XU-S`X.PH@("`@("`@("1"(#T@,RXQ-#$U.3L*("`@("`@
M("`D0R`](#0N-S$R,SD["B`@("`@("`@)$0@/2`V+C(X,S$Y.PH@("`@("`@
M("1%(#T@,"XP,3<T-3,S("H@)&QA=&ET=61E.PH@("`@("`@("1&(#T@,"XP
M,3<T-3,S("H@)&QO;F=I='5D93L*("`@("`@("`D1R`](#`N,C8Q-SDY("`J
M("1T:6UE>F]N93L*"B`@("`@("`@+R\@1F]R(&%S=')O;F]M:6-A;"!T=VEL
M:6=H="P@=7-E(%(@/2`M+C,P.3`Q-PH@("`@("`@("\O($9O<B!N875T:6-A
M;"!T=VEL:6=H="P@=7-E(%(@/2`M+C(P-SDQ,@H@("`@("`@("\O($9O<B!C
M:79I;"!T=VEL:6=H="P@=7-E(%(@/2`M+C$P-#4R.`H@("`@("`@("\O($9O
M<B!S=6YR:7-E(&]R('-U;G-E="P@=7-E(%(@/2`M+C`Q-#4T,SD*("`@("`@
M("`D4B`]("TN,#$T-30S.3L*"B`@("`@("`@:68@*"1S=6YS970I('L*("`@
M("`@("`@("`@)$H@/2`D0SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D2B`]("1!.PH@("`@("`@('T*"B`@("`@("`@)$L@/2`D>61A>2`K("@H
M)$H@+2`D1BD@+R`D1"D["B`@("`@("`@)$P@/2`H)$L@*B`N,#$W,C`R*2`M
M("XP-3<T,#,Y.R`@("`@("`@("`@("`@+R\@4V]L87(@365A;B!!;F]M;VQY
M"B`@("`@("`@)$T@/2`D3"`K("XP,S,T-#`U("H@<VEN*"1,*3L@("`@("`@
M("`@("`@("`@+R\@4V]L87(@5')U92!,;VYG:71U9&4*("`@("`@("`D32`K
M/2`T+CDS,C@Y("L@*#,N-#DP-C9%+3`T*2`J('-I;B@R("H@)$PI.R`O+R!1
M=6%D<F%N="!$971E<FUI;F%T:6]N"B`@("`@("`@=VAI;&4@*"1-(#P@,"D@
M>PH@("`@("`@("`@("`D32`]("@D32`K("1$*3L*("`@("`@("!]"B`@("`@
M("`@=VAI;&4@*"1-(#X]("1$*2!["B`@("`@("`@("`@("1-(#T@*"1-("T@
M)$0I.PH@("`@("`@('T*"B`@("`@("`@:68@*"@D32`O("1!*2`M(&EN='9A
M;"@D32`O("1!*2`]/2`P*2!["B`@("`@("`@("`@("1-("L](#0N.#0X,31%
M+3`V.PH@("`@("`@('T*"B`@("`@("`@)%`@/2!S:6XH)$TI("\@8V]S*"1-
M*3L@("`@("`@("`@("`@("`@("`@+R\@4V]L87(@4FEG:'0@07-C96YS:6]N
M"B`@("`@("`@)%`@/2!A=&%N,B@N.3$W-#8@*B`D4"P@,2D["@H@("`@("`@
M("\O(%%U861R86YT($%D:G5S=&UE;G0*("`@("`@("!I9B`H)$T@/B`D0RD@
M>PH@("`@("`@("`@("`D4"`K/2`D1#L*("`@("`@("!](&5L<V5I9B`H)$T@
M/B`D02D@>PH@("`@("`@("`@("`D4"`K/2`D0CL*("`@("`@("!]"@H@("`@
M("`@("11(#T@+C,Y-S@R("H@<VEN*"1-*3L@("`@("`@("`@("`O+R!3;VQA
M<B!$96-L:6YA=&EO;@H@("`@("`@("11(#T@)%$@+R!S<7)T*"TD42`J("11
M("L@,2D[("`@("`O+R!4:&ES(&ES(&AO=R!T:&4@;W)I9VEN86P@875T:&]R
M('=R;W1E(&ET(0H@("`@("`@("11(#T@871A;C(H)%$L(#$I.PH*("`@("`@
M("`D4R`]("12("T@*'-I;B@D42D@*B!S:6XH)$4I*3L*("`@("`@("`D4R`]
M("13("\@*&-O<R@D42D@*B!C;W,H)$4I*3L*"B`@("`@("`@:68@*&%B<R@D
M4RD@/B`Q*2!["B`@("`@("`@("`@(')E='5R;B`G;F]N92<[("`@("`@("`@
M("`@("`@("\O($YU;&P@<&AE;F]M96YO;@H@("`@("`@('T*"B`@("`@("`@
M)%,@/2`D4R`O('-Q<G0H+213("H@)%,@*R`Q*3L*("`@("`@("`D4R`]("1!
M("T@871A;C(H)%,L(#$I.PH*("`@("`@("!I9B`H(21S=6YS970I('L*("`@
M("`@("`@("`@)%,@/2`D1"`M("13(#L*("`@("`@("!]"@H@("`@("`@("14
M(#T@)%,@*R`D4"`M(#`N,#$W,C`R."`J("1+("T@,2XW,S,V-#L@+R\@3&]C
M86P@87!P87)E;G0@=&EM90H@("`@("`@("15(#T@)%0@+2`D1CL@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@56YI=F5R<V%L('1I;65R"B`@("`@
M("`@)%8@/2`D52`K("1'.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!786QL(&-L;V-K('1I;64*"B`@("`@("`@+R\@475A9')A;G0@1&5T97)M
M:6YA=&EO;@H@("`@("`@('=H:6QE("@D5B`\(#`I('L*("`@("`@("`@("`@
M)%8@/2`H)%8@*R`D1"D["B`@("`@("`@?0H@("`@("`@('=H:6QE("@D5B`^
M/2`D1"D@>PH@("`@("`@("`@("`D5B`]("@D5B`M("1$*3L*("`@("`@("!]
M"B`@("`@("`@)%8@/2`D5B`J(#,N.#$Y-S(["@H@("`@("`@("1H;W5R(#T@
M:6YT=F%L*"16*3L*("`@("`@("`D5B`@("T]("1H;W5R.PH@("`@("`@("1M
M:6X@(#T@:6YT=F%L*"16("H@-C`I.PH@("`@("`@("16("`@+3T@)&UI;B`O
M(#8P.PH@("`@("`@("1S96,@(#T@:6YT=F%L*"16("H@,S8P,"D["@H@("`@
M("`@(')E='5R;B!S=')F=&EM92@G)5@G+"!M:W1I;64H)&AO=7(L("1M:6XL
M("1S96,L("1M;VXL("1M9&%Y+"`D>65A<BDI.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+T)L;V-K+W1I;64N<&AP````````````````````
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S`T-P`Q,#4Q-30S,S<T-0`P
M,C$Q,S(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*"B1B;&]C:U]N86UE(#T@7R@B0W5R<F5N="!4:6UE(BD["@HO
M*BH*("H@)$AO<F1E.B!H;W)D92]L:6(O0FQO8VLO=&EM92YP:'`L=B`Q+C$V
M(#(P,#0O,3$O,C,@,34Z,3<Z-3,@8VAU8VL@17AP("0*("H*("H@0'!A8VMA
M9V4@2&]R9&5?0FQO8VL*("HO"F-L87-S($AO<F1E7T)L;V-K7TAO<F1E7W1I
M;64@97AT96YD<R!(;W)D95]";&]C:R!["@H@("`@=F%R("1?87!P(#T@)VAO
M<F1E)SL*"B`@("!F=6YC=&EO;B!?<&%R86US*"D*("`@('L*("`@("`@("!R
M971U<FX@)'!A<F%M<R`](&%R<F%Y*"=T:6UE)R`]/B!A<G)A>2@G='EP92<@
M/3X@)V5N=6TG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=N86UE)R`]/B!?*")4:6UE(&9O<FUA="(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D
M969A=6QT)R`]/B`G,C0M:&]U<B<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W9A;'5E<R<@/3X@87)R87DH)S(T
M+6AO=7(G(#T^(%\H(C(T($AO=7(@1F]R;6%T(BDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)S$R+6AO=7(G(#T^(%\H(C$R($AO=7(@1F]R;6%T(BDI*2D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@=&ET;&4@=&\@9V\@:6X@=&AI<R!B
M;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H92!T:71L
M92!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=&ET;&4H*0H@("`@>PH@
M("`@("`@(')E='5R;B!?*")#=7)R96YT(%1I;64B*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%1H92!C;VYT96YT('1O(&=O(&EN('1H:7,@8FQO8VLN"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@("!4:&4@8V]N=&5N=`H@("`@
M("HO"B`@("!F=6YC=&EO;B!?8V]N=&5N="@I"B`@("!["B`@("`@("`@:68@
M*&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=T:6UE)UTI*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=T:6UE)UT@/2`G,C0M:&]U<B<["B`@("`@("`@
M?0H*("`@("`@("`O+R!3970@=&AE('1I;65Z;VYE('9A<FEA8FQE+"!I9B!A
M=F%I;&%B;&4N"B`@("`@("`@3DQ3.CIS9714:6UE6F]N92@I.PH*("`@("`@
M("`D:'1M;"`]("<\=&%B;&4@=VED=&@](C$P,"4B(&AE:6=H=#TB,3`P)2(^
M/'1R/CQT9"!S='EL93TB9F]N="UF86UI;'DZ=F5R9&%N83MF;VYT+7-I>F4Z
M,3AP>#LB(&%L:6=N/2)C96YT97(B('9A;&EG;CTB;6ED9&QE(CXG.PH@("`@
M("`@("1H=&UL("X]('-T<F9T:6UE*"<E02P@)4(@)60L("59("<I.PH@("`@
M("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG=&EM92==(#T]("<R-"UH;W5R)RD@
M>PH@("`@("`@("`@("`D:'1M;"`N/2!S=')F=&EM92@G)4@Z)4TG*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:'1M;"`N/2!S=')F=&EM92@G
M)4DZ)4T@)7`G*3L*("`@("`@("!]"B`@("`@("`@)&AT;6P@+CT@)SPO=&0^
M/"]T<CX\+W1A8FQE/B<["@H@("`@("`@(')E='5R;B`D:'1M;#L*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<```````````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#,V-30`,3`U,34T,S,W-#4`,#(S,#4Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@HO*B!$:7-A8FQE(&)L;V-K(&EF(&YO="!C;VYF:6=U<F5D+B`J+PII
M9B`H(65M<'1Y*"1'3$]"04Q36R=C;VYF)UU;)W=E871H97)D;W1C;VTG75LG
M<&%R=&YE<E]I9"==*2`F)@H@("`@(65M<'1Y*"1'3$]"04Q36R=C;VYF)UU;
M)W=E871H97)D;W1C;VTG75LG;&EC96YS95]K97DG72DI('L*("`@("1B;&]C
M:U]N86UE(#T@7R@B=V5A=&AE<BYC;VTB*3L*?0H*+RHJ"B`J(%1H92!(;W)D
M95]";&]C:U]W96%T:&5R9&]T8V]M(&-L87-S('!R;W9I9&5S(&%N(&%P<&QE
M="!F;W(@=&AE"B`J('!O<G1A;"!S8W)E96X@=&\@9&ES<&QA>2!W96%T:&5R
M(&%N9"!F;W)E8V%S="!D871A(&9R;VT@=V5A=&AE<BYC;VT*("H@9F]R(&$@
M<W!E8VEF:65D(&QO8V%T:6]N+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VQI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<"QV(#$N,S<N-"XQ,R`R,#`U+S$R+S`U
M(#`S.C0Q.C`P(&-H=6-K($5X<"`D"B`J"B`J($!P86-K86=E($AO<F1E7T)L
M;V-K"B`J+PIC;&%S<R!(;W)D95]";&]C:U](;W)D95]W96%T:&5R9&]T8V]M
M(&5X=&5N9',@2&]R9&5?0FQO8VL@>PH*("`@('9A<B`D7V%P<"`]("=H;W)D
M92<["@H@("`@+RHJ"B`@("`@*B!4:&4@=&ET;&4@=&\@9V\@:6X@=&AI<R!B
M;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H92!T:71L
M92!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=&ET;&4H*0H@("`@>PH@
M("`@("`@(')E='5R;B!?*")796%T:&5R($9O<F5C87-T(BD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!4:&4@<&%R86UE=&5R<R!T;R!G;R!W:71H('1H:7,@
M8FQO8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@
M8V]N=&%I;FEN9R!T:&4@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W!A<F%M<R@I"B`@("!["B`@("`@("`@:68@*"$H0&EN8VQU9&5?;VYC
M92`G4V5R=FEC97,O5V5A=&AE<BYP:'`G*2!\?`H@("`@("`@("`@("`A*$!I
M;F-L=61E7V]N8V4@)T-A8VAE+G!H<"<I('Q\"B`@("`@("`@("`@("$H0&EN
M8VQU9&5?;VYC92`G6$U,+U-E<FEA;&EZ97(N<&AP)RD@?'P*("`@("`@("`@
M("`@(6EN:5]G970H)V%L;&]W7W5R;%]F;W!E;B<I*2!["B`@("`@("`@("`@
M($AO<F1E.CIL;V=-97-S86=E*"=4:&4@=V5A=&AE<BYC;VT@8FQO8VL@=VEL
M;"!N;W0@=V]R:R!W:71H;W5T(%!%05)<)W,@4V5R=FEC97-?5V5A=&AE<BP@
M0V%C:&4L(&%N9"!834Q?(%-E<FEA;&EZ97(@<&%C:V%G97,L(&%N9"!A;&QO
M=U]U<FQ?9F]P96X@96YA8FQE9"X@4G5N(&!P96%R(&EN<W1A;&P@4V5R=FEC
M97-?5V5A=&AE<B!#86-H92!834Q?4V5R:6%L:7IE<K0@86YD(&5N<W5R92!T
M:&%T(&%L;&]W7W5R;%]F;W!E;B!I<R!E;F%B;&5D(&EN('!H<"YI;FDN)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("`D<&%R86US(#T@87)R
M87DH"B`@("`@("`@("`@("`@("`G97)R;W(G(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@("=T>7!E)R`]/B`G97)R;W(G+`H@("`@("`@("`@("`@
M("`@("`@("=N86UE)R`]/B!?*")%<G)O<B(I+`H@("`@("`@("`@("`@("`@
M("`@("=D969A=6QT)R`]/B!?*")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@
M;F]T(&%V86EL86)L92XB*0H@("`@("`@("`@("`@("`@*0H@("`@("`@("`@
M("`I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P87)A;7,@/2!A
M<G)A>2@*("`@("`@("`@("`@("`@("=L;V-A=&EO;B<@/3X@87)R87DH"B`@
M("`@("`@("`@("`@("`@("`@+R\@)W1Y<&4G(#T^("=W96%T:&5R9&]T8V]M
M)RP*("`@("`@("`@("`@("`@("`@("`G='EP92<@/3X@)W1E>'0G+`H@("`@
M("`@("`@("`@("`@("`@("=N86UE)R`]/B!?*"),;V-A=&EO;B(I+`H@("`@
M("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B`G0F]S=&]N+"!-02<*("`@
M("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`G=6YI=',G(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`@("`@("`@("=T>7!E)R`]/B`G96YU;2<L"B`@
M("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(E5N:71S(BDL"B`@("`@
M("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("=S=&%N9&%R9"<L"B`@("`@
M("`@("`@("`@("`@("`@)S`G(#T^("=N;VYE)RP*("`@("`@("`@("`@("`@
M("`@("`G=F%L=65S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@
M("`@)W-T86YD87)D)R`]/B!?*")3=&%N9&%R9"(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`G;65T<FEC)R`]/B!?*")-971R:6,B*0H@("`@("`@("`@
M("`@("`@("`@("D*("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@
M("`G9&%Y<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)W1Y<&4G
M(#T^("=E;G5M)RP*("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@7R@B
M1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S
M="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N=6UB97(@
M:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(I+`H@("`@("`@
M("`@("`@("`@("`@("=D969A=6QT)R`]/B`G,R<L"B`@("`@("`@("`@("`@
M("`@("`@)W9A;'5E<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M("`@("<Q)R`]/B`G,2<L"B`@("`@("`@("`@("`@("`@("`@("`@("<R)R`]
M/B`G,B<L"B`@("`@("`@("`@("`@("`@("`@("`@("<S)R`]/B`G,R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("<T)R`]/B`G-"<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("<U)R`]/B`G-2<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("<V)R`]/B`G-B<L"B`@("`@("`@("`@("`@("`@("`@("`@("<W)R`]
M/B`G-R<L"B`@("`@("`@("`@("`@("`@("`@("`@("<X)R`]/B`G."<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("<Y)R`]/B`G.2<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("<Q,"<@/3X@)S$P)PH@("`@("`@("`@("`@("`@("`@
M("D*("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`G9&5T86EL
M961&;W)E8V%S="<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)W1Y
M<&4G(#T^("=C:&5C:V)O>"<L"B`@("`@("`@("`@("`@("`@("`@)VYA;64G
M(#T^(%\H(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B*2P*("`@("`@("`@
M("`@("`@("`@("`G9&5F875L="<@/3X@,`H@("`@("`@("`@("`@("`@*0H@
M("`@("`@("`@("`I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P87)A
M;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@8V]N=&5N="!T;R!G;R!I
M;B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@
M5&AE(&-O;G1E;G0*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;G1E;G0H*0H@
M("`@>PH@("`@("`@(&EF("@A*$!I;F-L=61E7V]N8V4@)U-E<G9I8V5S+U=E
M871H97(N<&AP)RD@?'P*("`@("`@("`@("`@(2A`:6YC;'5D95]O;F-E("=#
M86-H92YP:'`G*2!\?`H@("`@("`@("`@("`A:6YI7V=E="@G86QL;W=?=7)L
M7V9O<&5N)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U1H
M92!W96%T:&5R+F-O;2!B;&]C:R!W:6QL(&YO="!W;W)K('=I=&AO=70@=&AE
M(%!%05)397)V:6-E<U]796%T:&5R(&%N9"!#86-H92!P86-K86=E<RP@86YD
M(&%L;&]W7W5R;%]F;W!E;B!E;F%B;&5D+B!2=6X@<&5A<B!I;G-T86QL(%-E
M<G9I8V5S7U=E871H97(@0V%C:&4L(&%N9"!E;G-U<F4@=&AA="!A;&QO=U]U
M<FQ?9F]P96Y?=W)A<'!E<G,@:7,@96YA8FQE9"!I;B!P:'`N:6YI+B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(%\H(E1H92!W
M96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(I.PH@("`@("`@
M('T*"B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("!I9B`H96UP='DH
M)'1H:7,M/E]P87)A;7-;)VQO8V%T:6]N)UTI*2!["B`@("`@("`@("`@(')E
M='5R;B!?*").;R!L;V-A=&EO;B!I<R!S970N(BD["B`@("`@("`@?0H*("`@
M("`@("`D=V5A=&AE<D1O=$-O;2`]("9397)V:6-E<U]796%T:&5R.CIS97)V
M:6-E*"=796%T:&5R1&]T0V]M)RD["B`@("`@("`@)'=E871H97)$;W1#;VTM
M/G-E=$%C8V]U;G1$871A*`H@("`@("`@("`@("`H:7-S970H)&-O;F9;)W=E
M871H97)D;W1C;VTG75LG<&%R=&YE<E]I9"==*2`_("1C;VYF6R=W96%T:&5R
M9&]T8V]M)UU;)W!A<G1N97)?:60G72`Z("<G*2P*("`@("`@("`@("`@*&ES
M<V5T*"1C;VYF6R=W96%T:&5R9&]T8V]M)UU;)VQI8V5N<V5?:V5Y)UTI(#\@
M)&-O;F9;)W=E871H97)D;W1C;VTG75LG;&EC96YS95]K97DG72`Z("<G*2D[
M"@H@("`@("`@("1C86-H941I<B`]($AO<F1E.CIG971496UP1&ER*"D["B`@
M("`@("`@:68@*"$D8V%C:&5$:7(I('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I
M;&%B;&4@9F]R(&-A8VAE+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D=V5A=&AE<D1O=$-O;2T^<V5T0V%C:&4H
M)V9I;&4G+"!A<G)A>2@G8V%C:&5?9&ER)R`]/B`H)&-A8VAE1&ER("X@)R\G
M*2DI.PH@("`@("`@('T*("`@("`@("`D=V5A=&AE<D1O=$-O;2T^<V5T1&%T
M951I;65&;W)M870H)VTN9"Y9)RP@)T@Z:2<I.PH@("`@("`@("1W96%T:&5R
M1&]T0V]M+3YS9715;FET<T9O<FUA="@D=&AI<RT^7W!A<F%M<ULG=6YI=',G
M72D["B`@("`@("`@)'5N:71S(#T@)'=E871H97)$;W1#;VTM/F=E=%5N:71S
M1F]R;6%T*"D["@H@("`@("`@("\O($EF('1H92!U<V5R(&5N=&5R960@82!Z
M:7`@8V]D92!F;W(@=&AE(&QO8V%T:6]N+"!N;R!N965D('1O"B`@("`@("`@
M+R\@<V5A<F-H("AW96%T:&5R+F-O;2!A8V-E<'1S('II<"!C;V1E<R!A<R!L
M;V-A=&EO;B!)1',I+@H@("`@("`@("\O(%1H92!L;V-A=&EO;B!)1"!S:&]U
M;&0@86QR96%D>2!H879E(&)E96X@=F%L:61A=&5D(&EN"B`@("`@("`@+R\@
M9V5T4&%R86US+@H@("`@("`@("1S96%R8V@@/2`H<')E9U]M871C:"@G+UQB
M*#\Z7%QD>S5]*"U<7&1[-7TI/RE\*#\Z6T$M6EU[-'U<7&1[-'TI7&(O)RP*
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VQO8V%T:6]N)UTL("1M871C
M:&5S*2`_"B`@("`@("`@("`@("1M871C:&5S6S!=(#H*("`@("`@("`@("`@
M)'=E871H97)$;W1#;VTM/G-E87)C:$QO8V%T:6]N*"1T:&ES+3Y?<&%R86US
M6R=L;V-A=&EO;B==*2D["B`@("`@("`@:68@*&ES7V$H)'-E87)C:"P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!S=VET8V@@*"1S96%R8V@M/F=E
M=$-O9&4H*2D@>PH@("`@("`@("`@("!C87-E(%-%4E9)0T537U=%051(15)?
M15)23U)?4T525DE#15].3U1?1D]53D0Z"B`@("`@("`@("`@("`@("!R971U
M<FX@7R@B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(I
M.PH@("`@("`@("`@("!C87-E(%-%4E9)0T537U=%051(15)?15)23U)?54Y+
M3D]73E],3T-!5$E/3CH*("`@("`@("`@("`@("`@(')E='5R;B!?*")5;FMN
M;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(I.PH@("`@("`@("`@("!C87-E(%-%
M4E9)0T537U=%051(15)?15)23U)?5U)/3D=?4T525D527T1!5$$Z"B`@("`@
M("`@("`@("`@("!R971U<FX@7R@B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T
M(&%V86EL86)L92XB*3L*("`@("`@("`@("`@8V%S92!315)624-%4U]714%4
M2$527T524D]27T-!0TA%7TE.251?1D%)3$5$.@H@("`@("`@("`@("`@("`@
M<F5T=7)N(%\H(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(BD["B`@
M("`@("`@("`@(&-A<V4@4T525DE#15-?5T5!5$A%4E]%4E)/4E]$0E].3U1?
M0T].3D5#5$5$.@H@("`@("`@("`@("`@("`@<F5T=7)N(%\H(DUE=&%R1$(@
M:7,@;F]T(&-O;FYE8W1E9"XB*3L*("`@("`@("`@("`@8V%S92!315)624-%
M4U]714%42$527T524D]27U5.2TY/5TY?15)23U(Z"B`@("`@("`@("`@("`@
M("!R971U<FX@7R@B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB*3L*
M("`@("`@("`@("`@8V%S92!315)624-%4U]714%42$527T524D]27TY/7TQ/
M0T%424]..@H@("`@("`@("`@("`@("`@<F5T=7)N(%\H(DYO(&QO8V%T:6]N
M('!R;W9I9&5D+B(I.PH@("`@("`@("`@("!C87-E(%-%4E9)0T537U=%051(
M15)?15)23U)?24Y604Q)1%],3T-!5$E/3CH*("`@("`@("`@("`@("`@(')E
M='5R;B!?*"));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(I.PH@("`@("`@
M("`@("!C87-E(%-%4E9)0T537U=%051(15)?15)23U)?24Y604Q)1%]005)4
M3D527TE$.@H@("`@("`@("`@("`@("`@<F5T=7)N(%\H(DEN=F%L:60@<&%R
M=&YE<B!I9"XB*3L*("`@("`@("`@("`@8V%S92!315)624-%4U]714%42$52
M7T524D]27TE.5D%,241?4%)/1%5#5%]#3T1%.@H@("`@("`@("`@("`@("`@
M<F5T=7)N(%\H(DEN=F%L:60@<')O9'5C="!C;V1E+B(I.PH@("`@("`@("`@
M("!C87-E(%-%4E9)0T537U=%051(15)?15)23U)?24Y604Q)1%],24-%3E-%
M7TM%63H*("`@("`@("`@("`@("`@(')E='5R;B!?*"));G9A;&ED(&QI8V5N
M<V4@:V5Y+B(I.PH@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@
M("`@<F5T=7)N("1S96%R8V@M/F=E=&UE<W-A9V4H*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@)&AT;6P@/2`G)SL*("`@("`@("!I9B`H
M:7-?87)R87DH)'-E87)C:"DI('L*("`@("`@("`@("`@+R\@4V5V97)A;"!L
M;V-A=&EO;G,@<F5T=7)N960@9'5E('1O(&EM<')E8VES92!L;V-A=&EO;@H@
M("`@("`@("`@("`O+R!P87)A;65T97(N"B`@("`@("`@("`@("1H=&UL(#T@
M7R@B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE
M=&5R.B`B*2`N"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG;&]C
M871I;VXG72`N"B`@("`@("`@("`@("`@("`G/&)R("\^/'5L/B<["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1S96%R8V@@87,@)&ED7W=E871H97(]/B1R96%L
M7VQO8V%T:6]N*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2`B/&QI/B1R
M96%L7VQO8V%T:6]N("@D:61?=V5A=&AE<BD\+VQI/EQN(CL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D:'1M;"`N/2`G/"]U;#XG.PH@("`@("`@("`@
M("!R971U<FX@)&AT;6P["B`@("`@("`@?0H*("`@("`@("`D;&]C871I;VX@
M/2`D=V5A=&AE<D1O=$-O;2T^9V5T3&]C871I;VXH)'-E87)C:"D["B`@("`@
M("`@:68@*&ES7V$H)&QO8V%T:6]N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D;&]C871I;VXM/F=E=&UE<W-A9V4H*3L*("`@("`@
M("!]"B`@("`@("`@)'=E871H97(@/2`D=V5A=&AE<D1O=$-O;2T^9V5T5V5A
M=&AE<B@D<V5A<F-H*3L*("`@("`@("!I9B`H:7-?82@D=V5A=&AE<BP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'=E871H97(M/F=E
M=&UE<W-A9V4H*3L*("`@("`@("!]"B`@("`@("`@)&9O<F5C87-T(#T@)'=E
M871H97)$;W1#;VTM/F=E=$9O<F5C87-T*"1S96%R8V@L("1T:&ES+3Y?<&%R
M86US6R=D87ES)UTI.PH@("`@("`@(&EF("AI<U]A*"1F;W)E8V%S="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&9O<F5C87-T+3YG
M971M97-S86=E*"D["B`@("`@("`@?0H*("`@("`@("`O+R!,;V-A=&EO;B!A
M;F0@;&]C86P@=&EM92X*("`@("`@("`D:'1M;"`N/2`G/&1I=B!C;&%S<STB
M8V]N=')O;"(^)R`N"B`@("`@("`@("`@("<\<W1R;VYG/B<@+B`D;&]C871I
M;VY;)VYA;64G72`N("<\+W-T<F]N9SX@)R`N(%\H(DQO8V%L('1I;64Z("(I
M("X@)&QO8V%T:6]N6R=T:6UE)UT@+@H@("`@("`@("`@("`G/"]D:78^)SL*
M"B`@("`@("`@+R\@4W5N<FES92]S=6YS970N"B`@("`@("`@)&AT;6P@+CT@
M)SQS=')O;F<^)R`N(%\H(E-U;G)I<V4Z("(I("X@)SPO<W1R;VYG/B<@+@H@
M("`@("`@("`@("!(;W)D93HZ:6UG*"=B;&]C:R]S=6YR:7-E+W-U;G)I<V4N
M<&YG)RP@7R@B4W5N<FES92(I*2`N"B`@("`@("`@("`@("1L;V-A=&EO;ELG
M<W5N<FES92==.PH@("`@("`@("1H=&UL("X]("<@/'-T<F]N9SXG("X@7R@B
M4W5N<V5T.B`B*2`N("<\+W-T<F]N9SXG("X*("`@("`@("`@("`@2&]R9&4Z
M.FEM9R@G8FQO8VLO<W5N<FES92]S=6YS970N<&YG)RP@7R@B4W5N<V5T(BDI
M("X*("`@("`@("`@("`@)&QO8V%T:6]N6R=S=6YS970G73L*"B`@("`@("`@
M+R\@5&5M<&5R871U<F4N"B`@("`@("`@)&AT;6P@+CT@)SQB<B`O/CQS=')O
M;F<^)R`N(%\H(E1E;7!E<F%T=7)E.B`B*2`N("<\+W-T<F]N9SXG("X*("`@
M("`@("`@("`@<F]U;F0H)'=E871H97);)W1E;7!E<F%T=7)E)UTI("X@)R9D
M96<[)R`N(%-T<FEN9SHZ=7!P97(H)'5N:71S6R=T96UP)UTI.PH*("`@("`@
M("`O+R!$97<@<&]I;G0N"B`@("`@("`@)&AT;6P@+CT@)R`\<W1R;VYG/B<@
M+B!?*")$97<@<&]I;G0Z("(I("X@)SPO<W1R;VYG/B<@+@H@("`@("`@("`@
M("!R;W5N9"@D=V5A=&AE<ELG9&5W4&]I;G0G72D@+B`G)F1E9SLG("X@4W1R
M:6YG.CIU<'!E<B@D=6YI='-;)W1E;7`G72D["@H@("`@("`@("\O($9E96QS
M(&QI:V4@=&5M<&5R871U<F4N"B`@("`@("`@)&AT;6P@+CT@)R`\<W1R;VYG
M/B<@+B!?*")&965L<R!L:6ME.B`B*2`N("<\+W-T<F]N9SXG("X*("`@("`@
M("`@("`@<F]U;F0H)'=E871H97);)V9E;'1496UP97)A='5R92==*2`N("<F
M9&5G.R<@+B!3=')I;F<Z.G5P<&5R*"1U;FET<ULG=&5M<"==*3L*"B`@("`@
M("`@+R\@4')E<W-U<F4@86YD('1R96YD+@H@("`@("`@("1H=&UL("X]("<\
M8G(@+SX\<W1R;VYG/B<@+B!?*")0<F5S<W5R93H@(BD@+B`G/"]S=')O;F<^
M)SL*("`@("`@("`D=')E;F0@/2`D=V5A=&AE<ELG<')E<W-U<F54<F5N9"==
M.PH@("`@("`@("1H=&UL("X]('-P<FEN=&8H7R@B)60@)7,@86YD("5S(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("!R;W5N9"@D=V5A=&AE<ELG<')E
M<W-U<F4G72DL("1U;FET<ULG<')E<R==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@7R@D=')E;F0I*3L*"B`@("`@("`@+R\@5VEN9"X*("`@("`@("`D
M:'1M;"`N/2`G/&)R("\^/'-T<F]N9SXG("X@7R@B5VEN9#H@(BD@+B`G/"]S
M=')O;F<^)SL*("`@("`@("!I9B`H)'=E871H97);)W=I;F1$:7)E8W1I;VXG
M72`]/2`G5D%2)RD@>PH@("`@("`@("`@("`D:'1M;"`N/2!?*")687)I86)L
M92(I.PH@("`@("`@('T@96QS96EF("@D=V5A=&AE<ELG=VEN9$1I<F5C=&EO
M;B==(#T]("=#04Q-)RD@>PH@("`@("`@("`@("`D:'1M;"`N/2!?*")#86QM
M(BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&AT;6P@+CT@7R@B
M1G)O;2!T:&4@(BD@+B`D=V5A=&AE<ELG=VEN9$1I<F5C=&EO;B==.PH@("`@
M("`@(&EF("AI<W-E="@D=V5A=&AE<ELG=VEN9$=U<W0G72D@)B8@)'=E871H
M97);)W=I;F1'=7-T)UT@/B`P*2!["B`@("`@("`@("`@("1H=&UL("X]("<L
M("<@+B!?*")G=7-T:6YG(BD@+B`G("<@+B`D=V5A=&AE<ELG=VEN9$=U<W0G
M72`N"B`@("`@("`@("`@("`@("`G("<@+B`D=6YI='-;)W=I;F0G73L*("`@
M("`@("!]"@H@("`@("`@("`@("`D:'1M;"`N/2`G("@G("X@)'=E871H97);
M)W=I;F1$96=R965S)UT@+B`G*2<["B`@("`@("`@?0H@("`@("`@("1H=&UL
M("X](%\H(B!A="`B*2`N(')O=6YD*"1W96%T:&5R6R=W:6YD)UTI("X@)R`G
M("X@)'5N:71S6R=W:6YD)UT["@H@("`@("`@("\O($AU;6ED:71Y+@H@("`@
M("`@("1H=&UL("X]("<\8G(@+SX\<W1R;VYG/B<@+B!?*")(=6UI9&ET>3H@
M(BD@+B`G/"]S=')O;F<^)R`N"B`@("`@("`@("`@("1W96%T:&5R6R=H=6UI
M9&ET>2==("X@)R4G.PH*("`@("`@("`O+R!6:7-I8FEL:71Y+@H@("`@("`@
M("1H=&UL("X]("<@/'-T<F]N9SXG("X@7R@B5FES:6)I;&ET>3H@(BD@+B`G
M/"]S=')O;F<^)R`N"B`@("`@("`@("`@("AI<U]N=6UE<FEC*"1W96%T:&5R
M6R=V:7-I8FEL:71Y)UTI"B`@("`@("`@("`@("`_(')O=6YD*"1W96%T:&5R
M6R=V:7-I8FEL:71Y)UTI("X@)R`G("X@)'5N:71S6R=V:7,G70H@("`@("`@
M("`@("`@.B`D=V5A=&AE<ELG=FES:6)I;&ET>2==*3L*"B`@("`@("`@+R\@
M558@:6YD97@N"B`@("`@("`@)&AT;6P@+CT@)R`\<W1R;VYG/B<@+B!?*")5
M+E8N(&EN9&5X.B`B*2`N("<\+W-T<F]N9SXG.PH@("`@("`@("1U=B`]("1W
M96%T:&5R6R=U=E1E>'0G73L*("`@("`@("`D:'1M;"`N/2`D=V5A=&AE<ELG
M=79);F1E>"==("X@)R`M("<@+B!?*"1U=BD["@H@("`@("`@("\O($-U<G)E
M;G0@8V]N9&ET:6]N+@H@("`@("`@("1C;VYD:71I;VX@/2!I;7!L;V1E*"<@
M+R`G+"!A<G)A>5]M87`H)U\G+"!E>'!L;V1E*"<@+R`G+"`D=V5A=&AE<ELG
M8V]N9&ET:6]N)UTI*2D["B`@("`@("`@)&AT;6P@+CT@)SQB<B`O/CQS=')O
M;F<^)R`N(%\H(D-U<G)E;G0@8V]N9&ET:6]N.B`B*2`N("<\+W-T<F]N9SXG
M("X*("`@("`@("`@("`@2&]R9&4Z.FEM9R@G8FQO8VLO=V5A=&AE<F1O=&-O
M;2\S,G@S,B\G("X*("`@("`@("`@("`@("`@("`@("`@("`H)'=E871H97);
M)V-O;F1I=&EO;DEC;VXG72`]/2`G+2<@/R`G;F$G(#H@)'=E871H97);)V-O
M;F1I=&EO;DEC;VXG72D@+B`G+G!N9R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@)&-O;F1I=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`G86QI9VX]
M(FUI9&1L92(G*3L*("`@("`@("`D:'1M;"`N/2`G("<@+B`D8V]N9&ET:6]N
M.PH*("`@("`@("`O+R!$;R!T:&4@9F]R96-A<W0@;F]W("AI9B!R97%U97-T
M960I+@H@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG9&%Y<R==(#X@,"D@
M>PH@("`@("`@("`@("`D:'1M;"`N/2`G/&1I=B!C;&%S<STB8V]N=')O;"(@
M<W1Y;&4](G1E>'0M86QI9VXZ8V5N=&5R(CX\<W1R;VYG/B<@+@H@("`@("`@
M("`@("`@("`@<W!R:6YT9BA?*"(E9"UD87D@9F]R96-A<W0B*2P@)'1H:7,M
M/E]P87)A;7-;)V1A>7,G72D@+@H@("`@("`@("`@("`@("`@)SPO<W1R;VYG
M/CPO9&EV/B<["@H@("`@("`@("`@("`D9G5T=7)E1&%Y<R`](#`["B`@("`@
M("`@("`@("1H=&UL("X]("<\=&%B;&4@=VED=&@](C$P,"4B(&-E;&QS<&%C
M:6YG/2(S(CXG.PH@("`@("`@("`@("`O+R!(96%D97)S+@H@("`@("`@("`@
M("`D:'1M;"`N/2`G/'1R/B<["B`@("`@("`@("`@("1H=&UL("X]("<\=&@^
M)R`N(%\H(D1A>2(I("X@)SPO=&@^/'1H/B9N8G-P.SPO=&@^/'1H/B<@+@H@
M("`@("`@("`@("`@("`@<W!R:6YT9BA?*")496UP97)A='5R93QB<B`O/B@E
M<TAI)7,O)7-,;R5S*2`F9&5G.R5S(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("<\<W!A;B!S='EL93TB8V]L;W(Z<F5D(CXG+"`G/"]S<&%N/B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("<\<W!A;B!S='EL93TB8V]L;W(Z8FQU
M92(^)RP@)SPO<W!A;CXG+`H@("`@("`@("`@("`@("`@("`@("`@("!3=')I
M;F<Z.G5P<&5R*"1U;FET<ULG=&5M<"==*2D@+@H@("`@("`@("`@("`@("`@
M)SPO=&@^/'1H/B<@+B!?*")#;VYD:71I;VXB*2`N("<\+W1H/B<@+@H@("`@
M("`@("`@("`@("`@)SQT:#XG("X@7R@B4')E8VEP:71A=&EO;CQB<B`O/F-H
M86YC92(I("X@)SPO=&@^)SL*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?<&%R86US6R=D971A:6QE9$9O<F5C87-T)UTI*2!["B`@("`@("`@("`@
M("`@("`D:'1M;"`N/2`G/'1H/B<@+B!?*")(=6UI9&ET>2(I("X@)SPO=&@^
M/'1H/B<@+B!?*")7:6YD(BD@+B`G/"]T:#XG.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1H=&UL("X]("<\+W1R/B<["@H@("`@("`@("`@("!F;W)E
M86-H("@D9F]R96-A<W1;)V1A>7,G72!A<R`D=VAI8V@@/3X@)&1A>2D@>PH@
M("`@("`@("`@("`@("`@)&AT;6P@+CT@)SQT<B!C;&%S<STB:71E;3`B/B<[
M"@H@("`@("`@("`@("`@("`@+R\@1&%Y(&YA;64N"B`@("`@("`@("`@("`@
M("`D:'1M;"`N/2`G/'1D(')O=W-P86X](C(B('-T>6QE/2)B;W)D97(Z,7!X
M('-O;&ED("-D9&0[('1E>'0M86QI9VXZ8V5N=&5R(CXG("X*("`@("`@("`@
M("`@("`@("`@("`@("`@)SQS=')O;F<^)SL*("`@("`@("`@("`@("`@(&EF
M("@D=VAI8V@@/3T@,"D@>PH@("`@("`@("`@("`@("`@("`@("1H=&UL("X]
M(%\H(E1O9&%Y(BD["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'=H:6-H
M(#T](#$I('L*("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2!?*")4;VUO
M<G)O=R(I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D:'1M;"`N/2!S=')F=&EM92@G)4$G+"!M:W1I;64H,"P@,"P@
M,"P@9&%T92@G;2<I+"!D871E*"=D)RD@*R`D9G5T=7)E1&%Y<RP@9&%T92@G
M62<I*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D:'1M
M;"`N/2`G/"]S=')O;F<^/&)R("\^)R`N"B`@("`@("`@("`@("`@("`@("`@
M<W1R9G1I;64H)R5B("5D)RP@;6MT:6UE*#`L(#`L(#`L(&1A=&4H)VTG*2P@
M9&%T92@G9"<I("L@)&9U='5R941A>7,L(&1A=&4H)UDG*2DI("X*("`@("`@
M("`@("`@("`@("`@("`G/"]T9#XG("X*("`@("`@("`@("`@("`@("`@("`G
M/'1D('-T>6QE/2)B;W)D97(Z,7!X('-O;&ED("-D9&0[('1E>'0M86QI9VXZ
M8V5N=&5R(CXG("X*("`@("`@("`@("`@("`@("`@("`G/'-P86X@<W1Y;&4]
M(F-O;&]R.F]R86YG92(^)R`N"B`@("`@("`@("`@("`@("`@("`@7R@B1&%Y
M(BD@+B`G/"]S<&%N/CPO=&0^)SL*"B`@("`@("`@("`@("`@("`O+R!4:&4@
M9&%Y('!O<G1I;VX@;V8@=&AE(&9O<F5C87-T(&ES(&YO(&QO;F=E<B!A=F%I
M;&%B;&4@869T97(@,CHP,"!P+FTN(&QO8V%L('1O9&%Y+@H@("`@("`@("`@
M("`@("`@:68@*"1W:&EC:"`]/2`P("8F("AS=')T;W1I;64H)&QO8V%T:6]N
M6R=T:6UE)UTI(#X]('-T<G1O=&EM92@G,30Z,#`G*2DI('L*("`@("`@("`@
M("`@("`@("`@("`O+R!"86QA;F-E('1H92!G<FED+@H@("`@("`@("`@("`@
M("`@("`@("1H=&UL("X]("<\=&0@8V]L<W!A;CTB)R`N"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`H*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=D971A
M:6QE9$9O<F5C87-T)UTI(#\@)S4G(#H@)S,G*2`N("<B)RD@+@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)R!S='EL93TB8F]R9&5R.C%P>"!S;VQI
M9"`C9&1D.R!T97AT+6%L:6=N.F-E;G1E<B(^)R`N"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G)FYB<W`[/&)R("\^)R`N(%\H(DEN9F]R;6%T:6]N
M(&YO(&QO;F=E<B!A=F%I;&%B;&4N(BD@+B`G/&)R("\^)FYB<W`[)R`N"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G/"]T9#XG.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O+R!&;W)E8V%S
M="!C;VYD:71I;VXN"B`@("`@("`@("`@("`@("`@("`@)&-O;F1I=&EO;B`]
M(&EM<&QO9&4H)R`O("<L(&%R<F%Y7VUA<"@G7R<L(&5X<&QO9&4H)R`O("<L
M("1D87E;)V1A>2==6R=C;VYD:71I;VXG72DI*3L*"B`@("`@("`@("`@("`@
M("`@("`@+R\@2&EG:"!T96UP97)A='5R92X*("`@("`@("`@("`@("`@("`@
M("`D:'1M;"`N/2`G/'1D('-T>6QE/2)B;W)D97(Z,7!X('-O;&ED("-D9&0[
M('1E>'0M86QI9VXZ8V5N=&5R(CXG("X*("`@("`@("`@("`@("`@("`@("`@
M("`@)SQS<&%N('-T>6QE/2)C;VQO<CIR960B/B<@+@H@("`@("`@("`@("`@
M("`@("`@("`@("!R;W5N9"@D9&%Y6R=T96UP97)A='5R94AI9V@G72D@+B`G
M/"]S<&%N/CPO=&0^)SL*"B`@("`@("`@("`@("`@("`@("`@+R\@0V]N9&ET
M:6]N+@H@("`@("`@("`@("`@("`@("`@("1H=&UL("X]("<\=&0@<W1Y;&4]
M(F)O<F1E<CHQ<'@@<V]L:60@(V1D9#L@=&5X="UA;&EG;CIC96YT97(B/B<@
M+@H@("`@("`@("`@("`@("`@("`@("`@("!(;W)D93HZ:6UG*"=B;&]C:R]W
M96%T:&5R9&]T8V]M+S(S>#(S+R<@+B`H)&1A>5LG9&%Y)UU;)V-O;F1I=&EO
M;DEC;VXG72`]/2`G+2<@/R`G;F$G(#H@)&1A>5LG9&%Y)UU;)V-O;F1I=&EO
M;DEC;VXG72D@+B`G+G!N9R<L("1C;VYD:71I;VXI("X*("`@("`@("`@("`@
M("`@("`@("`@("`@)SQB<B`O/B<@+B`D8V]N9&ET:6]N("X@)SPO=&0^)SL*
M"B`@("`@("`@("`@("`@("`@("`@+R\@4')E8VEP:71A=&EO;B!C:&%N8V4N
M"B`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@)SQT9"!S='EL93TB8F]R
M9&5R.C%P>"!S;VQI9"`C9&1D.R!T97AT+6%L:6=N.F-E;G1E<B(^)R`N"B`@
M("`@("`@("`@("`@("`@("`@("`@("1D87E;)V1A>2==6R=P<F5C:7!I=&%T
M:6]N)UT@+B`G)2<@+B`G/"]T9#XG.PH*("`@("`@("`@("`@("`@("`@("`O
M+R!)9B!A(&1E=&%I;&5D(&9O<F5C87-T('=A<R!R97%U97-T960L('-H;W<@
M:'5M:61I='D@86YD"B`@("`@("`@("`@("`@("`@("`@+R\@=VEN9',N"B`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=D
M971A:6QE9$9O<F5C87-T)UTI*2!["@H@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!(=6UI9&ET>2X*("`@("`@("`@("`@("`@("`@("`@("`@)&AT;6P@
M+CT@)SQT9"!S='EL93TB8F]R9&5R.C%P>"!S;VQI9"`C9&1D.R!T97AT+6%L
M:6=N.F-E;G1E<B(^)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9&%Y6R=D87DG75LG:'5M:61I='DG72`N("<E/"]T9#XG.PH*("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@5VEN9',N"B`@("`@("`@("`@("`@("`@("`@
M("`@("1H=&UL("X]("<\=&0@<W1Y;&4](F)O<F1E<CHQ<'@@<V]L:60@(V1D
M9"(^)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!?*")&<F]M('1H
M92`B*2`N("1D87E;)V1A>2==6R=W:6YD1&ER96-T:6]N)UT@+@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@7R@B(&%T("(I("X@)&1A>5LG9&%Y)UU;
M)W=I;F0G72`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G("<@+B`D
M=6YI='-;)W=I;F0G73L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1D87E;)V1A>2==6R=W:6YD1W5S="==*2`F)@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&1A>5LG9&%Y)UU;)W=I;F1'=7-T)UT@/B`P*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2!?*"(L(&=U
M<W1I;F<@(BD@+B`D9&%Y6R=D87DG75LG=VEN9$=U<W0G72`N"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)R`G("X@)'5N:71S6R=W:6YD)UT[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@("`@("1H=&UL("X]("<\+W1R/B<["B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@+R\@3FEG:'0@9F]R
M96-A<W0*("`@("`@("`@("`@("`@("1N:6=H="`](&EM<&QO9&4H)R`O("<L
M(&%R<F%Y7VUA<"@G7R<L(&5X<&QO9&4H)R`O("<L("1D87E;)VYI9VAT)UU;
M)V-O;F1I=&EO;B==*2DI.PH*("`@("`@("`@("`@("`@("\O(%-H861E(&ET
M(&9O<B!V:7-U86P@<V5P87)A=&EO;BX*("`@("`@("`@("`@("`@("1H=&UL
M("X]("<\='(@8VQA<W,](FET96TQ(CXG.PH*("`@("`@("`@("`@("`@("1H
M=&UL("X]("<\=&0@<W1Y;&4](F)O<F1E<CHQ<'@@<V]L:60@(V1D9#L@=&5X
M="UA;&EG;CIC96YT97(B/B<@+@H@("`@("`@("`@("`@("`@("`@(%\H(DYI
M9VAT(BD@+B`G/"]T9#XG.PH*("`@("`@("`@("`@("`@("\O($QO=R!T96UP
M97)A='5R92X*("`@("`@("`@("`@("`@("1H=&UL("X]("<\=&0@<W1Y;&4]
M(F)O<F1E<CHQ<'@@<V]L:60@(V1D9#L@=&5X="UA;&EG;CIC96YT97(B/B<@
M+@H@("`@("`@("`@("`@("`@("`@("<\<W!A;B!S='EL93TB8V]L;W(Z8FQU
M92(^)R`N"B`@("`@("`@("`@("`@("`@("`@<F]U;F0H)&1A>5LG=&5M<&5R
M871U<F5,;W<G72D@+B`G/"]S<&%N/CPO=&0^)SL*"B`@("`@("`@("`@("`@
M("`O+R!#;VYD:71I;VXN"B`@("`@("`@("`@("`@("`D:'1M;"`N/2`G/'1D
M('-T>6QE/2)B;W)D97(Z,7!X('-O;&ED("-D9&0[('1E>'0M86QI9VXZ8V5N
M=&5R(CXG("X*("`@("`@("`@("`@("`@("`@("!(;W)D93HZ:6UG*"=B;&]C
M:R]W96%T:&5R9&]T8V]M+S(S>#(S+R<@+B`H)&1A>5LG;FEG:'0G75LG8V]N
M9&ET:6]N26-O;B==(#T]("<M)R`_("=N82<@.B`D9&%Y6R=N:6=H="==6R=C
M;VYD:71I;VY)8V]N)UTI("X@)RYP;F<G+"`D;FEG:'0I("X*("`@("`@("`@
M("`@("`@("`@("`G/&)R("\^)R`N("1N:6=H="`N("<\+W1D/B<["@H@("`@
M("`@("`@("`@("`@+R\@4')E8VEP:71A=&EO;B!C:&%N8V4N"B`@("`@("`@
M("`@("`@("`D:'1M;"`N/2`G/'1D('-T>6QE/2)B;W)D97(Z,7!X('-O;&ED
M("-D9&0[('1E>'0M86QI9VXZ8V5N=&5R(CXG("X*("`@("`@("`@("`@("`@
M("`@("`D9&%Y6R=N:6=H="==6R=P<F5C:7!I=&%T:6]N)UT@+B`G)3PO=&0^
M)SL*"B`@("`@("`@("`@("`@("`O+R!)9B!A(&1E=&%I;&5D(&9O<F5C87-T
M('=A<R!R97%U97-T960L(&1I<W!L87D@:'5M:61I='D@86YD"B`@("`@("`@
M("`@("`@("`O+R!W:6YD<RX*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7W!A<F%M<ULG9&5T86EL961&;W)E8V%S="==*2D@>PH*("`@("`@
M("`@("`@("`@("`@("`O+R!(=6UI9&ET>2X*("`@("`@("`@("`@("`@("`@
M("`D:'1M;"`N/2`G/'1D('-T>6QE/2)B;W)D97(Z,7!X('-O;&ED("-D9&0[
M('1E>'0M86QI9VXZ8V5N=&5R(CXG("X*("`@("`@("`@("`@("`@("`@("`@
M("`@)&1A>5LG;FEG:'0G75LG:'5M:61I='DG72`N("<E/"]T9#XG.PH*("`@
M("`@("`@("`@("`@("`@("`O+R!7:6YD<RX*("`@("`@("`@("`@("`@("`@
M("`D:'1M;"`N/2`G/'1D('-T>6QE/2)B;W)D97(Z,7!X('-O;&ED("-D9&0B
M/B<@+@H@("`@("`@("`@("`@("`@("`@("`@("!?*")&<F]M('1H92`B*2`N
M("1D87E;)VYI9VAT)UU;)W=I;F1$:7)E8W1I;VXG72`N"B`@("`@("`@("`@
M("`@("`@("`@("`@(%\H(B!A="`B*2`N("1D87E;)VYI9VAT)UU;)W=I;F0G
M72`N"B`@("`@("`@("`@("`@("`@("`@("`@("<@)R`N("1U;FET<ULG=VEN
M9"==.PH@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&%Y6R=N:6=H
M="==6R=W:6YD1W5S="==*2`F)B`D9&%Y6R=N:6=H="==6R=W:6YD1W5S="==
M(#X@,"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2!?*"(L
M(&=U<W1I;F<@(BD@+B`D9&%Y6R=N:6=H="==6R=W:6YD1W5S="==("X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("<@)R`N("1U;FET<ULG=VEN9"==
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("`D:'1M;"`N/2`G/"]T<CXG.PH*("`@("`@("`@("`@
M("`@("\O(%!R97!A<F4@9F]R(&YE>'0@9&%Y+@H@("`@("`@("`@("`@("`@
M)&9U='5R941A>7,K*SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D:'1M
M;"`N/2`G/"]T86)L93XG.PH@("`@("`@('T*"B`@("`@("`@+R\@1&ES<&QA
M>2!A(&)A<B!A="!T:&4@8F]T=&]M(&]F('1H92!B;&]C:R!W:71H('1H92!R
M97%U:7)E9`H@("`@("`@("\O(&%T=')I8G5T:6]N('1O('=E871H97(N8V]M
M(&%N9"!T:&4@;&]G;RP@8F]T:"!L:6YK960@=&\*("`@("`@("`O+R!W96%T
M:&5R+F-O;2!W:71H('1H92!P87)T;F5R($E$+@H@("`@("`@(')E='5R;B`D
M:'1M;"`N("<\9&EV(&-L87-S/2)R:6=H=$%L:6=N(&QI;F5D4F]W(CXG("X*
M("`@("`@("`@("`@7R@B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(BD@+B`G
M("<@+@H@("`@("`@("`@("!(;W)D93HZ;&EN:RA(;W)D93HZ97AT97)N86Q5
M<FPH)VAT='`Z+R]W=W<N=V5A=&AE<BYC;VTO/W!R;V0]>&]A<"9A;7`[<&%R
M/2<@+@H@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1O=$-O;2T^
M7W!A<G1N97))1"DL"B`@("`@("`@("`@("`@("`@("`@("`@("=W96%T:&5R
M+F-O;2<L("<G+"`G7V)L86YK)RP@)R<L("=W96%T:&5R+F-O;2<I("X*("`@
M("`@("`@("`@)SQE;3YW96%T:&5R+F-O;3PO96T^)G)E9SL@)R`N"B`@("`@
M("`@("`@($AO<F1E.CII;6<H)V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O
M5%=#;&]G;U\S,G!X+G!N9R<L("=W96%T:&5R+F-O;2!L;V=O)RD@+@H@("`@
M("`@("`@("`G/"]A/CPO9&EV/B<["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'``````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C8U-``Q,#4Q-30S,S<T-0`P,C0V,34`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%!O<W-I8FQE('-T<FEN9W,@9G)O;2!W96%T:&5R+F-O;2P@
M:G5S="!T;R!H879E('1H96T@:6X@=&AE('-O=7)C92!F;W(*("H@;&]C86QI
M>F%T:6]N(')E87-O;G,N"B`J"B`J("1(;W)D93H@:&]R9&4O;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`L=B`Q+C$N,BXV(#(P,#8O,#4O
M,#,@,3<Z,#<Z,C<@:F%N($5X<"`D"B`J+PH*7R@B04T@0VQO=61S(BD["E\H
M(D%-($QI9VAT(%)A:6XB*3L*7R@B04T@3&EG:'0@4VYO=R(I.PI?*")!32!2
M86EN(BD["E\H(D%-(%-H;W=E<G,B*3L*7R@B04T@4VYO=R!3:&]W97)S(BD[
M"E\H(D-L96%R(BD["E\H(D-L96%R:6YG($QA=&4B*3L*7R@B0VQO=61S($5A
M<FQY(BD["E\H(D-L;W5D>2(I.PI?*")&86ER(BD["E\H(D9E=R!3:&]W97)S
M(BD["E\H(D9E=R!3;F]W(%-H;W=E<G,B*3L*7R@B1F]G(BD["E\H(D9R965Z
M:6YG($1R:7IZ;&4B*3L*7R@B2&%Z92(I.PI?*")(96%V>2!4+5-T;W)M(BD[
M"E\H(DES;VQA=&5D(%0M4W1O<FUS(BD["E\H(DQI9VAT($1R:7IZ;&4B*3L*
M7R@B3&EG:'0@4F%I;B(I.PI?*"),:6=H="!286EN($5A<FQY(BD["E\H(DQI
M9VAT(%)A:6X@3&%T92(I.PI?*"),:6=H="!286EN(%-H;W=E<B(I.PI?*"),
M:6=H="!286EN('=I=&@@5&AU;F1E<B(I.PI?*"),:6=H="!3;F]W(BD["E\H
M(DQI9VAT(%-N;W<@4VAO=V5R(BD["E\H(DUO<W1L>2!#;&5A<B(I.PI?*")-
M;W-T;'D@0VQO=61Y(BD["E\H(DUO<W1L>2!#;&]U9'D@86YD(%=I;F1Y(BD[
M"E\H(DUO<W1L>2!3=6YN>2(I.PI?*")087)T;'D@0VQO=61Y(BD["E\H(E!-
M($QI9VAT(%)A:6XB*3L*7R@B4$T@4F%I;B(I.PI?*")032!3:&]W97)S(BD[
M"E\H(E!-(%-N;W<B*3L*7R@B4$T@4VYO=R!3:&]W97)S(BD["E\H(E!-(%-U
M;B(I.PI?*")032!4+5-T;W)M<R(I.PI?*")286EN(BD["E\H(E)A:6X@16%R
M;'DB*3L*7R@B4F%I;B!,871E(BD["E\H(E)A:6X@4VAO=V5R(BD["E\H(E)A
M:6X@86YD(%-N;W<B*3L*7R@B4F%I;B!T;R!3;F]W(BD["E\H(E-C871T97)E
M9"!4+5-T;W)M<R(I.PI?*")3:&]W97)S(BD["E\H(E-H;W=E<G,@16%R;'DB
M*3L*7R@B4VAO=V5R<R!,871E(BD["E\H(E-H;W=E<G,@:6X@=&AE(%9I8VEN
M:71Y(BD["E\H(E-N;W<B*3L*7R@B4VYO=R!3:&]W97(B*3L*7R@B4VYO=R!3
M:&]W97)S(BD["E\H(E-N;W<@4VAO=V5R<R!%87)L>2(I.PI?*")3;F]W(%-H
M;W=E<G,@3&%T92(I.PI?*")3=6YN>2(I.PI?*")4+5-T;W)M(BD["E\H(E0M
M4W1O<FT@86YD(%=I;F1Y(BD["E\H(E0M4W1O<FUS(BD["E\H(E0M4W1O<FUS
M($5A<FQY(BD["E\H(E1H=6YD97(B*3L*7R@B5VEN9"(I.PI?*")7:6YD($5A
M<FQY(BD["E\H(DQO=R(I.PI?*")-;V1E<F%T92(I.PI?*")(:6=H(BD["E\H
M(E9E<GD@2&EG:"(I.PI?*")F86QL:6YG(BD["E\H(G-T96%D>2(I.PI?*")R
M:7-I;F<B*3L*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O8V]R92YP:'``````
M````````````````````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S
M,S(V`#$P-3$U-#,S-S4R`#`R,#`W,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@2&]R9&4@07!P;&EC
M871I;VX@1G)A;65W;W)K(&-O<F4@<V5R=FEC97,@9FEL92X*("H*("H@5&AI
M<R!F:6QE('-E=',@=7`@86YY(&YE8V5S<V%R>2!I;F-L=61E('!A=&@@=F%R
M:6%B;&5S(&%N9"!I;F-L=61E<PH@*B!T:&4@;6EN:6UU;2!R97%U:7)E9"!(
M;W)D92!L:6)R87)I97,N"B`J"B`J("1(;W)D93H@:&]R9&4O;&EB+V-O<F4N
M<&AP+'8@,2XR-BXV+C<@,C`P-B\P,2\P-R`Q-CHT,#HR."!C:'5C:R!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@HO*B!4=7)N(%!(
M4"!S='5F9B!O9F8@=&AA="!C86X@<F5A;&QY('-C<F5W('1H:6YG<R!U<"X@
M*B\*:6YI7W-E="@G;6%G:6-?<75O=&5S7W-Y8F%S92<L(#`I.PII;FE?<V5T
M*"=M86=I8U]Q=6]T97-?<G5N=&EM92<L(#`I.PH*+RH@56YS970@86QL('9A
M<FEA8FQE<R!P;W!U;&%T960@=&AR;W5G:"!R96=I<W1E<E]G;&]B86QS+B`J
M+PII9B`H:6YI7V=E="@G<F5G:7-T97)?9VQO8F%L<R<I*2!["B`@("!F;W)E
M86-H("AA<G)A>5]K97ES*"1?1T54*2!A<R`D:V5Y*2!["B`@("`@("`@=6YS
M970H)"1K97DI.PH@("`@?0H@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D7U!/
M4U0I(&%S("1K97DI('L*("`@("`@("!U;G-E="@D)&ME>2D["B`@("!]"B`@
M("!F;W)E86-H("AA<G)A>5]K97ES*"1?0T]/2TE%*2!A<R`D:V5Y*2!["B`@
M("`@("`@=6YS970H)"1K97DI.PH@("`@?0H@("`@9F]R96%C:"`H87)R87E?
M:V5Y<R@D7T5.5BD@87,@)&ME>2D@>PH@("`@("`@('5N<V5T*"0D:V5Y*3L*
M("`@('T*("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H)%]315)615(I(&%S("1K
M97DI('L*("`@("`@("!U;G-E="@D)&ME>2D["B`@("!]"GT*"B\J($EF('1H
M92!(;W)D92!&<F%M97=O<FL@<&%C:V%G97,@87)E(&YO="!I;G-T86QL960@
M:6X@4$A0)W,@9VQO8F%L"B`J(&EN8VQU9&5?<&%T:"P@>6]U(&UU<W0@861D
M(&%N(&EN:5]S970H*2!C86QL(&AE<F4@=&\@861D('1H96ER(&QO8V%T:6]N
M('1O"B`J('1H92!I;F-L=61E7W!A=&@N("HO"FEN:5]S970H)VEN8VQU9&5?
M<&%T:"<L(&1I<FYA;64H7U]&24Q%7U\I("X@4$%42%]315!!4D%43U(@+B!I
M;FE?9V5T*"=I;F-L=61E7W!A=&@G*2D["@HO*B!014%2(&)A<V4@8VQA<W,N
M("HO"FEN8VQU9&5?;VYC92`G4$5!4BYP:'`G.PH*+RH@2&]R9&4@8V]R92!C
M;&%S<V5S+B`J+PII;F-L=61E7V]N8V4@)TAO<F1E+G!H<"<["FEN8VQU9&5?
M;VYC92`G2&]R9&4O4F5G:7-T<GDN<&AP)SL*:6YC;'5D95]O;F-E("=(;W)D
M92]3=')I;F<N<&AP)SL*:6YC;'5D95]O;F-E("=(;W)D92].3%,N<&AP)SL*
M:6YC;'5D95]O;F-E("=(;W)D92].;W1I9FEC871I;VXN<&AP)SL*:6YC;'5D
M95]O;F-E("=(;W)D92]!=71H+G!H<"<["FEN8VQU9&5?;VYC92`G2&]R9&4O
M0G)O=W-E<BYP:'`G.PII;F-L=61E7V]N8V4@)TAO<F1E+U!E<FUS+G!H<"<[
M"@HO*B!"<F]W<V5R(&1E=&5C=&EO;B!O8FIE8W0N("HO"FEF("AC;&%S<U]E
M>&ES=',H)T)R;W=S97(G*2D@>PH@("`@)&)R;W=S97(@/2`F0G)O=W-E<CHZ
M<VEN9VQE=&]N*"D["GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+T9I;&4O````````````````
M````````````````````````````````````````````````````````````
M```````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#4Q-30S,S<T-0`P,3<S,#0`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M1FEL92]#4U8N<&AP````````````````````````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#0P,S0V`#$P-3$U-#,S-S0U`#`R,#0U-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`H*<F5Q=6ER
M95]O;F-E("=014%2+G!H<"<["G)E<75I<F5?;VYC92`G1FEL92YP:'`G.PH*
M+RHJ"B`J(%1H92!&:6QE7T-35B!P86-K86=E(&%L;&]W<R!R96%D:6YG(&%N
M9"!C<F5A=&EN9R!O9B!#4U8@9&%T82!A;F0@9FEL97,N"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`L=B`Q+C0N,BXW(#(P,#8O
M,#,O,S`@,3`Z,34Z,CD@<V5L<VMY($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`R+3(P,#,@5&]M87,@5F]N(%9E<V-H;&5R($-O>"`\8V]X0&ED96-N970N
M8V]M/@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($IA;B!38VAN96ED97(@/&IA
M;D!H;W)D92YO<F<^"B`J"B`J(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C
M="!T;R!V97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L('1H870@:7,*
M("H@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%
M3E-%+"!A;F0@:7,@879A:6QA8FQE(&%T('1H<F]U9V@*("H@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N
M='AT+B`@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!A(&-O<'D@;V8@=&AE
M(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O
M=6=H('1H90H@*B!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E
M('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@80H@*B!C
M;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`875T:&]R("!4;VUA<R!6;VX@5F5S
M8VAL97(@0V]X(#QC;WA`:61E8VYE="YC;VT^"B`J($!A=71H;W(@($IA;B!3
M8VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N
M,0H@*B!`<&%C:V%G92!&:6QE7T-35@H@*B\*8VQA<W,@1FEL95]#4U8@>PH*
M("`@("\J*@H@("`@("H@1&ES8V]V97)S('1H92!F;W)M870@;V8@82!#4U8@
M9FEL92`H=&AE(&YU;6)E<B!O9B!F:65L9',L('1H92!S97!A<F%T;W(L"B`@
M("`@*B!T:&4@<75O=&4@<W1R:6YG+"!A;F0@=&AE(&QI;F4@8G)E86LI+@H@
M("`@("H*("`@("`J(%=E(&-A;B=T('5S92!T:&4@875T;U]D971E8W1?;&EN
M95]E;F1I;F=S(%!(4"!S971T:6YG+"!B96-A=7-E(&ET)W,@;F]T"B`@("`@
M*B!S=7!P;W)T960@8GD@9F=E=',H*2!C;VYT<F%R>2!T;R!W:&%T('1H92!M
M86YU86P@<V%Y<RX*("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@5&AE($-35B!F:6QE(&YA;64*("`@("`J($!P
M87)A;2!A<G)A>2`@($5X=')A('-E<&%R871O<G,@=&AA="!S:&]U;&0@8F4@
M8VAE8VME9"!F;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE
M(&9O<FUA="!H87-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!D:7-C;W9E<D9O
M<FUA="@D9FEL92P@)&5X=')A4V5P<R`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@:68@*"$D9G`@/2!`9F]P96XH)&9I;&4L("=R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-O=6QD(&YO="!O<&5N(&9I
M;&4Z("<@+B`D9FEL92D["B`@("`@("`@?0H*("`@("`@("`D<V5P<R`](&%R
M<F%Y*")<="(L("<[)RP@)SHG+"`G+"<I.PH@("`@("`@("1S97!S(#T@87)R
M87E?;65R9V4H)'-E<',L("1E>'1R85-E<',I.PH@("`@("`@("1M871C:&5S
M(#T@87)R87DH*3L*("`@("`@("`D8W)L9B`](&YU;&P["B`@("`@("`@)&-O
M;F8@/2!A<G)A>2@I.PH*("`@("`@("`O*B!486ME('1H92!F:7)S="`Q,"!L
M:6YE<R!A;F0@<W1O<F4@=&AE(&YU;6)E<B!O9B!O8W5R<F5N8V5S(&9O<B!E
M86-H"B`@("`@("`@("H@<V5P87)A=&]R(&EN(&5A8V@@;&EN92X@*B\*("`@
M("`@("!F;W(@*"1I(#T@,#L@*"1I(#P@,3`I("8F("@D;&EN92`](&9G971S
M*"1F<"DI.RD@>PH@("`@("`@("`@("`O*B!$;R!W92!H879E($UA8R!L:6YE
M(&5N9&EN9W,_("HO"B`@("`@("`@("`@("1L:6YE<R`]('!R96=?<W!L:70H
M)R]<<B@_(5QN*2\G+"`D;&EN92P@,3`I.PH@("`@("`@("`@("`D:B`](#`[
M"B`@("`@("`@("`@("1C(#T@8V]U;G0H)&QI;F5S*3L*("`@("`@("`@("`@
M:68@*"1C(#X@,2D@>PH@("`@("`@("`@("`@("`@)&-R;&8@/2`B7'(B.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@('=H:6QE("@D:2`\(#$P("8F("1J
M(#P@)&,I('L*("`@("`@("`@("`@("`@("1L:6YE(#T@)&QI;F5S6R1J73L*
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&-R;&8I*2!["B`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H87)R87DH(EQR7&XB+"`B7&XB*2!A<R`D
M8RD@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H<W5B<W1R*"1L:6YE
M+"`M<W1R;&5N*"1C*2D@/3T@)&,I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1C<FQF(#T@)&,["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("1I*RL["B`@("`@("`@("`@("`@("`D:BLK.PH@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)'-E<',@87,@)'-E<"D@>PH@("`@("`@("`@("`@("`@("`@
M("1M871C:&5S6R1S97!=6R1I72`]('-U8G-T<E]C;W5N="@D;&EN92P@)'-E
M<"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@:68@*&ES<V5T*"1C<FQF*2D@>PH@("`@("`@("`@("`D8V]N
M9ELG8W)L9B==(#T@)&-R;&8["B`@("`@("`@?0H*("`@("`@("`O*B!'<F]U
M<"!T:&4@<F5S=6QT<R!B>2!A;6]U;G0@;V8@97%U86P@;V-U<G)E;F-E<RX@
M*B\*("`@("`@("`D9FEE;&1S(#T@87)R87DH*3L*("`@("`@("`D86UO=6YT
M(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D;6%T8VAE<R!A<R`D<V5P
M(#T^("1L:6YE<RD@>PH@("`@("`@("`@("`D=&EM97,@/2!A<G)A>2@I.PH@
M("`@("`@("`@("`D=&EM97-;,%T@/2`P.PH@("`@("`@("`@("!F;W)E86-H
M("@D;&EN97,@87,@)&YU;2D@>PH@("`@("`@("`@("`@("`@:68@*"1N=6T@
M/B`P*2!["B`@("`@("`@("`@("`@("`@("`@)'1I;65S6R1N=6U=(#T@*&ES
M<V5T*"1T:6UE<ULD;G5M72DI(#\@)'1I;65S6R1N=6U=("L@,2`Z(#$["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@87)S
M;W)T*"1T:6UE<RD["B`@("`@("`@("`@("1F:65L9'-;)'-E<%T@/2!K97DH
M)'1I;65S*3L*("`@("`@("`@("`@)&%M;W5N=%LD<V5P72`]("1T:6UE<UMK
M97DH)'1I;65S*5T["B`@("`@("`@?0H@("`@("`@(&%R<V]R="@D86UO=6YT
M*3L*("`@("`@("`D<V5P(#T@:V5Y*"1A;6]U;G0I.PH*("`@("`@("`D8V]N
M9ELG9FEE;&1S)UT@/2`D9FEE;&1S6R1S97!=("L@,3L*("`@("`@("`D8V]N
M9ELG<V5P)UT@("`@/2`D<V5P.PH*("`@("`@("`O*B!497-T(&EF('1H97)E
M(&%R92!F:65L9',@=VET:"!Q=6]T97,@87)R;W5N9"!I;B!T:&4@9FER<W0@
M-0H@("`@("`@("`J(&QI;F5S+B`J+PH@("`@("`@("1Q=6]T97,@/2`G(EPG
M)SL*("`@("`@("`D<75O=&4@(#T@)R<["B`@("`@("`@<F5W:6YD*"1F<"D[
M"B`@("`@("`@9F]R("@D:2`](#`[("@D:2`\(#4I("8F("@D;&EN92`](&9G
M971S*"1F<"DI.R`D:2LK*2!["B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H
M*")\)'-E<"A;)'%U;W1E<UTI+BHH6R1Q=6]T97-=*21S97!\52(L("1L:6YE
M+"`D;6%T8V@I*2!["B`@("`@("`@("`@("`@("!I9B`H)&UA=&-H6S%=(#T]
M("1M871C:%LR72D@>PH@("`@("`@("`@("`@("`@("`@("1Q=6]T92`]("1M
M871C:%LQ73L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H<')E9U]M
M871C:"@B?%XH6R1Q=6]T97-=*2XJ*%LD<75O=&5S72DD<V5P?"(L("1L:6YE
M+"`D;6%T8V@I('Q\"B`@("`@("`@("`@("`@("!P<F5G7VUA=&-H*")\*%LD
M<75O=&5S72DN*BA;)'%U;W1E<UTI)'-E<%QS)'Q5<R(L("1L:6YE+"`D;6%T
M8V@I*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@("!I9B`H)&UA=&-H
M6S%=(#T]("1M871C:%LR72D@>PH@("`@("`@("`@("`@("`@("`@("1Q=6]T
M92`]("1M871C:%LQ73L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("`D8V]N9ELG<75O=&4G72`]("1Q=6]T93L*"B`@("`@("`@9F-L;W-E*"1F
M<"D["@H@("`@("`@("\O(%A86"!7:&%T(&%B;W5T('1R>6EN9R!T;R!D:7-C
M;W9E<B!T:&4@(FAE861E<B(_"B`@("`@("`@<F5T=7)N("1C;VYF.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5A9',@82!R;W<@9G)O;2!A($-35B!F:6QE
M(&%N9"!R971U<FYS(&ET(&%S(&%N(&%R<F%Y+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&9I;&4@(%1H92!N86UE(&]F('1H92!#4U8@9FEL92X*
M("`@("`J($!P87)A;2!A<G)A>2`D8V]N9B`@(%1H92!C;VYF:6=U<F%T:6]N
M(&9O<B!T:&4@0U-6(&9I;&4N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>7QB;V]L96%N("!4:&4@0U-6(&1A=&$@;W(@9F%L<V4@:68@;F\@;6]R92!D
M871A(&%V86EL86)L92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9"@D9FEL
M92P@)B1C;VYF*0H@("`@>PH@("`@("`@("1F<"`]($9I;&5?0U-6.CIG9710
M;VEN=&5R*"1F:6QE+"`D8V]N9BP@1DE,15]-3T1%7U)%040I.PH@("`@("`@
M(&EF("AI<U]A*"1F<"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&9P.PH@("`@("`@('T*"B`@("`@("`@)&QI;F4@/2!F9V5T<R@D
M9G`I.PH@("`@("`@(&EF("@A)&QI;F4I('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@57-E(')E8611=6]T960H
M*2!I9B!W92!H879E($UA8R!L:6YE(&5N9&EN9W,N("HO"B`@("`@("`@:68@
M*'!R96=?;6%T8V@H)R]<<B@_(5QN*2\G+"`D;&EN92DI('L*("`@("`@("`@
M("`@9G-E96LH)&9P+"`M<W1R;&5N*"1L:6YE*2P@4T5%2U]#55(I.PH@("`@
M("`@("`@("!R971U<FX@1FEL95]#4U8Z.G)E8611=6]T960H)&9I;&4L("1C
M;VYF*3L*("`@("`@("!]"@H@("`@("`@($9I;&5?0U-6.CI?;&EN92A&:6QE
M7T-35CHZ7VQI;F4H*2`K(#$I.PH*("`@("`@("!I9B`H)&-O;F9;)V9I96QD
M<R==(#T](#$I('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"1L:6YE*3L*
M("`@("`@("!]"@H@("`@("`@("1F:65L9',@/2!E>'!L;V1E*"1C;VYF6R=S
M97`G72P@)&QI;F4I.PH@("`@("`@(&EF("@D8V]N9ELG<75O=&4G72D@>PH@
M("`@("`@("`@("`D;&%S="`]("8D9FEE;&1S6V-O=6YT*"1F:65L9',I("T@
M,5T["B`@("`@("`@("`@("\J($9A;&QB86-K('1O(')E860@=&AE(&QI;F4@
M=VET:"!R96%D475O=&5D*"D@=VAE;B!G=65S<R!T:&%T('1H90H@("`@("`@
M("`@("`@*B!S:6UP;&4@97AP;&]D92!W;VXG="!W;W)K(')I9VAT+B`J+PH@
M("`@("`@("`@("!I9B`H*'-U8G-T<B@D;&%S="P@+7-T<FQE;B@D8V]N9ELG
M8W)L9B==*2D@/3T@)&-O;F9;)V-R;&8G72`F)@H@("`@("`@("`@("`@("`@
M("1L87-T>S!](#T]("1C;VYF6R=Q=6]T92==("8F"B`@("`@("`@("`@("`@
M("`@)&QA<W1[<W1R;&5N*')T<FEM*"1L87-T*2D@+2`Q?2`A/2`D8V]N9ELG
M<75O=&4G72D@?'P*("`@("`@("`@("`@("`@("AC;W5N="@D9FEE;&1S*2`A
M/2`D8V]N9ELG9FEE;&1S)UTI"B`@("`@("`@("`@("`@("`@("`@+R\@6%A8
M('!E<FAA<',@=&AE<F4@:7,@82!S97!A<F%T;W(@:6YS:61E(&$@<75O=&5D
M(&9I96QD"B`@("`@("`@("`@("`@("`@("`@+R]P<F5G7VUA=&-H*")\>R1C
M;VYF6R=Q=6]T92==?2XJ>R1C;VYF6R=S97`G77TN*GLD8V]N9ELG<75O=&4G
M77U\52(L("1L:6YE*0H@("`@("`@("`@("`@("`@*0H@("`@("`@("`@("![
M"B`@("`@("`@("`@("`@("!F<V5E:R@D9G`L("US=')L96XH)&QI;F4I+"!3
M145+7T-54BD["B`@("`@("`@("`@("`@("!R971U<FX@1FEL95]#4U8Z.G)E
M8611=6]T960H)&9I;&4L("1C;VYF*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1L87-T(#T@<G1R:6TH)&QA<W0I.PH@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&9I96QD<R!A<R`D:R`]/B`D=BD@>PH@("`@
M("`@("`@("`@("`@("`@("1F:65L9'-;)&M=(#T@1FEL95]#4U8Z.G5N<75O
M=&4H)'8L("1C;VYF6R=Q=6]T92==+"`D8V]N9ELG8W)L9B==*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1F:65L9'-;8V]U;G0H)&9I96QD<RD@+3%=(#T@<G1R:6TH
M)&9I96QD<UMC;W5N="@D9FEE;&1S*2`M,5TI.PH@("`@("`@('T*"B`@("`@
M("`@:68@*&-O=6YT*"1F:65L9',I(#P@)&-O;F9;)V9I96QD<R==*2!["B`@
M("`@("`@("`@($9I;&5?0U-6.CIW87)N:6YG*'-P<FEN=&8H7R@B5W)O;F<@
M;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U
M;F0@)60N(BDL($9I;&5?0U-6.CI?;&EN92@I+"`D8V]N9ELG9FEE;&1S)UTL
M(&-O=6YT*"1F:65L9',I*2D["B`@("`@("`@("`@("1F:65L9',@/2!A<G)A
M>5]M97)G92@D9FEE;&1S+"!A<G)A>5]F:6QL*#`L("1C;VYF6R=F:65L9',G
M72`M(&-O=6YT*"1F:65L9',I+"`G)RDI.PH@("`@("`@('T@96QS96EF("AC
M;W5N="@D9FEE;&1S*2`^("1C;VYF6R=F:65L9',G72D@>PH@("`@("`@("`@
M("!&:6QE7T-35CHZ=V%R;FEN9RAS<')I;G1F*%\H(DUO<F4@9FEE;&1S(&9O
M=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(BDL($9I;&5?
M0U-6.CI?;&EN92@I+"`D8V]N9ELG9FEE;&1S)UTI*3L*("`@("`@("`@("`@
M87)R87E?<W!L:6-E*"1F:65L9',L("1C;VYF6R=F:65L9',G72D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&9I96QD<SL*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E861S(&$@<F]W(&9R;VT@82!#4U8@9FEL92!A;F0@<F5T=7)N
M<R!I="!A<R!A;B!A<G)A>2X*("`@("`J(%1H:7,@;65T:&]D(&ES(&%B;&4@
M=&\@<F5A9"!F:65L9',@=VET:"!M=6QT:6QI;F4@9&%T82!A;F0@;F]R;6%L
M:7IE<PH@("`@("H@;&EN96)R96%K<R!T;R!S:6YG;&4@;F5W;&EN92!C:&%R
M86-T97)S("@P>#!A*2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F
M:6QE("!4:&4@;F%M92!O9B!T:&4@0U-6(&9I;&4N"B`@("`@*B!`<&%R86T@
M87)R87D@)&-O;F8@("!4:&4@8V]N9FEG=7)A=&EO;B!F;W(@=&AE($-35B!F
M:6QE+@H@("`@("H*("`@("`J($!R971U<FX@87)R87E\8F]O;&5A;B`@5&AE
M($-35B!D871A(&]R(&9A;'-E(&EF(&YO(&UO<F4@9&%T82!A=F%I;&%B;&4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E8611=6]T960H)&9I;&4L("8D8V]N
M9BD*("`@('L*("`@("`@("`D9G`@/2!&:6QE7T-35CHZ9V5T4&]I;G1E<B@D
M9FEL92P@)&-O;F8L($9)3$5?34]$15]214%$*3L*("`@("`@("!I9B`H:7-?
M82@D9G`L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1F
M<#L*("`@("`@("!]"@H@("`@("`@("\J($$@8G5F9F5R('=I=&@@86QL(&-H
M87)A8W1E<G,@;V8@=&AE(&-U<G)E;G0@9FEE;&0@<F5A9"!S;R!F87(N("HO
M"B`@("`@("`@)&)U9F8@/2`G)SL*("`@("`@("`O*B!4:&4@8W5R<F5N="!C
M:&%R86-T97(N("HO"B`@("`@("`@)&,@/2!N=6QL.PH@("`@("`@("\J(%1H
M92!R96%D(&9I96QD<RX@*B\*("`@("`@("`D<F5T(#T@87)R87DH*3L*("`@
M("`@("`O*B!4:&4@;G5M8F5R(&]F('1H92!C=7)R96YT(&9I96QD+B`J+PH@
M("`@("`@("1I(#T@,3L*("`@("`@("`O*B!!<F4@=V4@:6YS:61E(&$@<75O
M=&5D(&9I96QD/R`J+PH@("`@("`@("1I;E]Q=6]T92`](&9A;'-E.PH*("`@
M("`@("!W:&EL92`H*"1C:"`](&9G971C*"1F<"DI("$]/2!F86QS92D@>PH@
M("`@("`@("`@("`O*B!0<F5V:6]U<R!C:&%R86-T97(N("HO"B`@("`@("`@
M("`@("1P<F5V(#T@)&,["B`@("`@("`@("`@("\J($-U<G)E;G0@8VAA<F%C
M=&5R+B`J+PH@("`@("`@("`@("`D8R`]("1C:#L*"B`@("`@("`@("`@("\J
M(%-I;7!L92!C:&%R86-T97(N("HO"B`@("`@("`@("`@(&EF("@D8R`A/2`D
M8V]N9ELG<75O=&4G72`F)@H@("`@("`@("`@("`@("`@)&,@(3T@)&-O;F9;
M)W-E<"==("8F"B`@("`@("`@("`@("`@("!S=')P;W,H)&-O;F9;)V-R;&8G
M72P@)&,I(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)&)U9F8@+CT@
M)&,["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@:68@*"1C;VYF6R=Q=6]T92==("8F("1C(#T]("1C;VYF
M6R=Q=6]T92==("8F"B`@("`@("`@("`@("`@("`H)'!R978@/3T@)&-O;F9;
M)W-E<"==('Q\"B`@("`@("`@("`@("`@("`@)'!R978@/3T@<W5B<W1R*"1C
M;VYF6R=C<FQF)UTL("TQ*2!\?`H@("`@("`@("`@("`@("`@("1P<F5V(#T]
M/2!N=6QL*2D*("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@+RH@475O
M=&4@8F5G:6XN("HO"B`@("`@("`@("`@("`@("`D:6Y?<75O=&4@/2!T<G5E
M.PH@("`@("`@("`@("!](&5L<V5I9B`H)&EN7W%U;W1E*2!["B`@("`@("`@
M("`@("`@("`O*B!1=6]T92!E;F0_("HO"B`@("`@("`@("`@("`@("!I9B`H
M)&,@/3T@)&-O;F9;)W-E<"==("8F("1P<F5V(#T]("1C;VYF6R=Q=6]T92==
M*2!["B`@("`@("`@("`@("`@("`@("`@)&EN7W%U;W1E(#T@9F%L<V4["B`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H)&,@/3T@<W5B<W1R*"1C;VYF6R=C
M<FQF)UTL("TQ*2D@>PH@("`@("`@("`@("`@("`@("`@("1S=6(@/2`H<W1R
M;&5N*"1C;VYF6R=C<FQF)UTI(#X@,2`F)@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!R978@/3T@<W5B<W1R*"1C;VYF6R=C<FQF)UTL("TR+"`Q
M*2D*("`@("`@("`@("`@("`@("`@("`@("`@/R`R"B`@("`@("`@("`@("`@
M("`@("`@("`@(#H@,3L*("`@("`@("`@("`@("`@("`@("!I9B`H*'-T<FQE
M;B@D8G5F9BD@/CT@)'-U8BD@)B8*("`@("`@("`@("`@("`@("`@("`@("`@
M*"1B=69F>W-T<FQE;B@D8G5F9BD@+2`D<W5B?2`]/2`D8V]N9ELG<75O=&4G
M72DI"B`@("`@("`@("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D:6Y?<75O=&4@/2!F86QS93L*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("!&:6QE7T-35CHZ7VQI
M;F4H1FEL95]#4U8Z.E]L:6YE*"D@*R`Q*3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("\J($5N9"!O9B!L:6YE(&]R(&5N9"!O9B!F:65L9"X@*B\*("`@("`@
M("`@("`@:68@*"$D:6Y?<75O=&4@)B8*("`@("`@("`@("`@("`@("@D8R`]
M/2`D8V]N9ELG<V5P)UT@?'P@)&,@/3T@<W5B<W1R*"1C;VYF6R=C<FQF)UTL
M("TQ*2DI('L*("`@("`@("`@("`@("`@("\J($UO<F4@9FEE;&1S('1H86X@
M97AP96-T960N("HO"B`@("`@("`@("`@("`@("!I9B`H)&,@/3T@)&-O;F9;
M)W-E<"==("8F"B`@("`@("`@("`@("`@("`@("`@*&-O=6YT*"1R970I("L@
M,2D@/3T@)&-O;F9;)V9I96QD<R==*2!["B`@("`@("`@("`@("`@("`@("`@
M=VAI;&4@*"1C("$]/2!F86QS92`F)B`D8R`A/2!S=6)S='(H)&-O;F9;)V-R
M;&8G72P@+3$I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1C(#T@9F=E
M=&,H)&9P*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@1FEL95]#4U8Z.G=A<FYI;F<H<W!R:6YT9BA?*")-;W)E(&9I96QD
M<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(I+"!&
M:6QE7T-35CHZ7VQI;F4H*2P@)&-O;F9;)V9I96QD<R==*2D["B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*"1P<F5V(#T]('-U8G-T
M<B@D8V]N9ELG8W)L9B==+"`M,BP@,2DI('L*("`@("`@("`@("`@("`@("`@
M("`D8G5F9B`]('-U8G-T<B@D8G5F9BP@,"P@+3$I.PH@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@("`@("\J($QE<W,@9FEE;&1S('1H86X@97AP
M96-T960N("HO"B`@("`@("`@("`@("`@("!I9B`H*"1C(#T]('-U8G-T<B@D
M8V]N9ELG8W)L9B==+"`M,2DI("8F"B`@("`@("`@("`@("`@("`@("`@*"1I
M("$]("1C;VYF6R=F:65L9',G72DI('L*("`@("`@("`@("`@("`@("`@("!I
M9B`H)&D@/3T@,2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`O*B!3:VEP
M(&5M<'1Y(&QI;F5S+B`J+PH@("`@("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)')E=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@1FEL95]#4U8Z.G=A<FYI;F<H<W!R:6YT9BA?*")7<F]N9R!N=6UB
M97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E
M9"XB*2P@1FEL95]#4U8Z.E]L:6YE*"DL("1C;VYF6R=F:65L9',G72P@)&DI
M*3L*"B`@("`@("`@("`@("`@("`@("`@)')E=%M=(#T@1FEL95]#4U8Z.G5N
M<75O=&4H)&)U9F8L("1C;VYF6R=Q=6]T92==+"`D8V]N9ELG8W)L9B==*3L*
M("`@("`@("`@("`@("`@("`@("`D<F5T(#T@87)R87E?;65R9V4H)')E="P@
M87)R87E?9FEL;"@P+"`D8V]N9ELG9FEE;&1S)UT@+2`D:2P@)R<I*3L*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)')E=#L*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`D<F5T6UT@/2!&:6QE7T-35CHZ=6YQ=6]T
M92@D8G5F9BP@)&-O;F9;)W%U;W1E)UTL("1C;VYF6R=C<FQF)UTI.PH@("`@
M("`@("`@("`@("`@:68@*&-O=6YT*"1R970I(#T]("1C;VYF6R=F:65L9',G
M72D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5T.PH@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1B=69F(#T@)R<["B`@("`@
M("`@("`@("`@("`D:2LK.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&)U9F8@+CT@)&,["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@9F5O9B@D9G`I(#\@9F%L<V4@.B`D<F5T.PH@
M("`@?0H*("`@("\J*@H@("`@("H@5W)I=&5S(&$@:&%S:"!I;G1O(&$@0U-6
M(&9I;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL92`@(%1H
M92!N86UE(&]F('1H92!#4U8@9FEL92X*("`@("`J($!P87)A;2!A<G)A>2`D
M9FEE;&1S("!4:&4@0U-6(&1A=&$N"B`@("`@*B!`<&%R86T@87)R87D@)&-O
M;F8@("`@5&AE(&-O;F9I9W5R871I;VX@9F]R('1H92!#4U8@9FEL92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@
M4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W
M<FET92@D9FEL92P@)&9I96QD<RP@)B1C;VYF*0H@("`@>PH@("`@("`@(&EF
M("AI<U]A*"1F<"`]($9I;&5?0U-6.CIG9710;VEN=&5R*"1F:6QE+"`D8V]N
M9BP@1DE,15]-3T1%7U=2251%*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&9P.PH@("`@("`@('T*"B`@("`@("`@:68@*&-O=6YT
M*"1F:65L9',I("$]("1C;VYF6R=F:65L9',G72D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E=R;VYG(&YU;6)E
M<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB*2P@)&-O;F9;
M)V9I96QD<R==+"!C;W5N="@D9FEE;&1S*2DI.PH@("`@("`@('T*"B`@("`@
M("`@)'=R:71E(#T@)R<["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U
M;G0H)&9I96QD<RD[("1I*RLI('L*("`@("`@("`@("`@:68@*"%I<U]N=6UE
M<FEC*"1F:65L9'-;)&E=*2`F)B`D8V]N9ELG<75O=&4G72D@>PH@("`@("`@
M("`@("`@("`@)'=R:71E("X]("1C;VYF6R=Q=6]T92==("X@)&9I96QD<ULD
M:5T@+B`D8V]N9ELG<75O=&4G73L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1W<FET92`N/2`D9FEE;&1S6R1I73L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H)&D@/"`H8V]U;G0H)&9I96QD<RD@+2`Q
M*2D@>PH@("`@("`@("`@("`@("`@)'=R:71E("X]("1C;VYF6R=S97`G73L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1W<FET92`N
M/2`D8V]N9ELG8W)L9B==.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!I9B`H(69W<FET92@D9G`L("1W<FET92DI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")#86YN;W0@=W)I
M=&4@=&\@9FEL92!<(B5S7"(B*2P@)&9I;&4I*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E
M<R!S=7)R;W5N9&EN9R!Q=6]T97,@9G)O;2!A('-T<FEN9R!A;F0@;F]R;6%L
M:7IE<R!L:6YE8G)E86MS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&9I96QD("!4:&4@<W1R:6YG('1O('5N<75O=&4N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1Q=6]T92`@5&AE('%U;W1E(&-H87)A8W1E<BX*("`@("`J($!P
M87)A;2!S=')I;F<@)&-R;&8@("!4:&4@;&EN96)R96%K(&-H87)A8W1E<BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('5N<75O=&5D(&1A
M=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N('5N<75O=&4H)&9I96QD+"`D<75O
M=&4L("1C<FQF*0H@("`@>PH@("`@("`@("\J(%-K:7`@96UP='D@9FEE;&1S
M("AF;W)M.B`[.RD@*B\*("`@("`@("!I9B`H(7-T<FQE;B@D9FEE;&0I*2![
M"B`@("`@("`@("`@(')E='5R;B`D9FEE;&0["B`@("`@("`@?0H@("`@("`@
M(&EF("@D<75O=&4@)B8@)&9I96QD>S!](#T]("1Q=6]T92`F)B`D9FEE;&1[
M<W1R;&5N*"1F:65L9"DM,7T@/3T@)'%U;W1E*2!["B`@("`@("`@("`@(')E
M='5R;B!S=')?<F5P;&%C92@D8W)L9BP@(EQN(BP@<W5B<W1R*"1F:65L9"P@
M,2P@+3$I*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1F:65L9#L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E=',@;W(@9V5T<R!T:&4@8W5R<F5N="!L
M:6YE(&)E:6YG('!A<G-E9"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D;&EN92`@268@<W!E8VEF:65D+"!T:&4@8W5R<F5N="!L:6YE+@H@("`@
M("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&-U<G)E;G0@;&EN92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7VQI;F4H)&QI;F4@/2!N=6QL*0H@("`@
M>PH@("`@("`@('-T871I8R`D8W5R<F5N=%]L:6YE(#T@,#L*"B`@("`@("`@
M:68@*"%I<U]N=6QL*"1L:6YE*2D@>PH@("`@("`@("`@("`D8W5R<F5N=%]L
M:6YE(#T@)&QI;F4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-U<G)E
M;G1?;&EN93L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@82!W87)N:6YG
M('1O(&]R(')E=')I979E<R!A;F0@<F5S971S('1H92!W87)N:6YG('-T86-K
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@($$@=V%R;FEN9R!S=')I
M;F<N("!)9B!N;W0@<W!E8VEF:65D+"!T:&4@97AI<W1I;F<*("`@("`J("`@
M("`@("`@("`@("`@('=A<FYI;F=S('=I;&P@8F4@<F5T=7)N960@:6YS=&5A
M9"!A;F0@=&AE('=A<FYI;F<@<W1A8VL*("`@("`J("`@("`@("`@("`@("`@
M(&=E=',@96UP=&EE9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!)
M9B!N;R!P87)A;65T97(@:&%S(&)E96X@<W!E8VEF:65D+"!T:&4@;&ES="!O
M9B!E>&ES=&EN9PH@("`@("H@("`@("`@("`@("`@("`@=V%R;FEN9W,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('=A<FYI;F<H)'=A<FYI;F<@/2!N=6QL*0H@
M("`@>PH@("`@("`@('-T871I8R`D=V%R;FEN9W,@/2!A<G)A>2@I.PH*("`@
M("`@("!I9B`H:7-?;G5L;"@D=V%R;FEN9RDI('L*("`@("`@("`@("`@)')E
M='5R;B`]("1W87)N:6YG<SL*("`@("`@("`@("`@)'=A<FYI;F=S(#T@87)R
M87DH*3L*("`@("`@("`@("`@<F5T=7)N("1R971U<FX["B`@("`@("`@?0H*
M("`@("`@("`D=V%R;FEN9W-;72`]("1W87)N:6YG.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!O<B!C<F5A=&5S('1H92!F:6QE(&1E<V-R:7!T
M;W(@87-S;V-I871E9"!W:71H(&$@9FEL92X*("`@("`J"B`@("`@*B!`<W1A
M=&EC"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL92`@5&AE(&YA
M;64@;V8@=&AE(&9I;&4*("`@("`J($!P87)A;2!A<G)A>2`D8V]N9B`@(%1H
M92!C;VYF:6=U<F%T:6]N"B`@("`@*B!`<&%R86T@<W1R:6YG("1M;V1E("!4
M:&4@;W!E;B!M;V1E+B!&24Q%7TU/1$5?4D5!1"!O<B!&24Q%7TU/1$5?5U))
M5$4N"B`@("`@*@H@("`@("H@0')E='5R;B!R97-O=7)C92`@5&AE(&9I;&4@
M<F5S;W5R8V4@;W(@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T4&]I;G1E<B@D9FEL92P@)B1C;VYF+"`D;6]D92`]($9)
M3$5?34]$15]214%$*0H@("`@>PH@("`@("`@('-T871I8R`D<F5S;W5R8V5S
M(#T@87)R87DH*3L*("`@("`@("!S=&%T:6,@)&-O;F9I9R`](&%R<F%Y*"D[
M"@H@("`@("`@("1S:6=N871U<F4@/2`D9FEL92`N('-E<FEA;&EZ92@D8V]N
M9BD["B`@("`@("`@:68@*&ES<V5T*"1R97-O=7)C97-;)'-I9VYA='5R95TI
M*2!["B`@("`@("`@("`@("1C;VYF(#T@)&-O;F9I9ULD<VEG;F%T=7)E73L*
M("`@("`@("`@("`@<F5T=7)N("1R97-O=7)C97-;)'-I9VYA='5R95T["B`@
M("`@("`@?0H@("`@("`@(&EF("AI<U]A*"1E<G)O<B`]($9I;&5?0U-6.CI?
M8VAE8VM#;VYF:6<H)&-O;F8I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H@("`@("`@("1C;VYF:6=;
M)'-I9VYA='5R95T@/2`D8V]N9CL*"B`@("`@("`@)&9P(#T@0&9O<&5N*"1F
M:6QE+"`D;6]D92D["B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D9G`I*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H
M7R@B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB*2P@)&9I;&4I*3L*("`@("`@
M("!]"B`@("`@("`@)')E<V]U<F-E<ULD<VEG;F%T=7)E72`]("1F<#L*("`@
M("`@("!&:6QE7T-35CHZ7VQI;F4H,"D["@H@("`@("`@(&EF("@D;6]D92`]
M/2!&24Q%7TU/1$5?4D5!1"`F)B`A96UP='DH)&-O;F9;)VAE861E<B==*2D@
M>PH@("`@("`@("`@("!I9B`H:7-?82@D:&5A9&5R(#T@1FEL95]#4U8Z.G)E
M860H)&9I;&4L("1C;VYF*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1H96%D97(["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D9G`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M:&5C:W,@=&AE(&-O;F9I9W5R871I;VX@9VEV96X@8GD@=&AE('5S97(N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1C;VYF("`@(%1H92!C;VYF:6=U
M<F%T:6]N(&%S<V]C(&%R<F%Y"B`@("`@*B!`<&%R86T@<W1R:6YG("1E<G)O
M<B`@5&AE(&5R<F]R('=I;&P@8F4@=W)I='1E;B!H97)E(&EF(&%N>0H@("`@
M("HO"B`@("!F=6YC=&EO;B!?8VAE8VM#;VYF:6<H)B1C;VYF*0H@("`@>PH@
M("`@("`@("\O(&-H96-K(&-O;F8*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1C
M;VYF*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G
M26YV86QI9"!C;VYF:6=U<F%T:6]N+B<I.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"%I<W-E="@D8V]N9ELG9FEE;&1S)UTI('Q\("%I<U]N=6UE<FEC*"1C
M;VYF6R=F:65L9',G72DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H7R@B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE
M<FEC+B(I*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D8V]N9ELG
M<V5P)UTI*2!["B`@("`@("`@("`@(&EF("AS=')L96XH)&-O;F9;)W-E<"==
M*2`A/2`Q*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BA?*")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R
M86-T97(N(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*"1C
M;VYF6R=F:65L9',G72`^(#$I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB*2D["B`@
M("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=Q=6]T92==*2D@
M>PH@("`@("`@("`@("!I9B`H<W1R;&5N*"1C;VYF6R=Q=6]T92==*2`A/2`Q
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R
M86-T97(N(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&-O;F9;)W%U;W1E)UT@/2`G)SL*("`@("`@("!]"@H@("`@
M("`@(&EF("@A:7-S970H)&-O;F9;)V-R;&8G72DI('L*("`@("`@("`@("`@
M)&-O;F9;)V-R;&8G72`](")<;B(["B`@("`@("`@?0H@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]&:6QE+U!$
M1B\`````````````````````````````````````````````````````````
M````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`U,34T,S,W-#4`,#$W-S$U`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+T9I;&4O4$1&+V9O;G1S+P``````````````````````````
M```````````````````````````````````````````````P,#`P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<T-0`P,C$P-#8`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O1FEL92]01$8O9F]N=',O8V]U
M<FEE<BYP:'``````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#$V`#$P
M-3$U-#,S-S0U`#`R,S(S,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@0'!A8VMA9V4@1FEL95]01$8*
M("HO"F9O<B`H)&D@/2`P.R`D:2`\/2`R-34[("1I*RLI('L*("`@("1F;VYT
M7W=I9'1H<ULG8V]U<FEE<B==6V-H<B@D:2E=(#T@-C`P.PI]"B1F;VYT7W=I
M9'1H<ULG8V]U<FEE<D(G72`]("1F;VYT7W=I9'1H<ULG8V]U<FEE<B==.PHD
M9F]N=%]W:61T:'-;)V-O=7)I97)))UT@/2`D9F]N=%]W:61T:'-;)V-O=7)I
M97(G73L*)&9O;G1?=VED=&AS6R=C;W5R:65R0DDG72`]("1F<&1F7W=I9'1H
M<ULG8V]U<FEE<B==.PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O;G1S+VAE;'9E=&EC82YP:'``
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C(P-P`Q,#4Q-30S,S<T-0`P
M,C,U,S``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J($!P86-K86=E($9I;&5?4$1&"B`J+PHD9F]N=%]W
M:61T:'-;)VAE;'9E=&EC82==(#T@87)R87DH"B`@("!C:'(H,"D]/C(W."QC
M:'(H,2D]/C(W."QC:'(H,BD]/C(W."QC:'(H,RD]/C(W."QC:'(H-"D]/C(W
M."QC:'(H-2D]/C(W."QC:'(H-BD]/C(W."QC:'(H-RD]/C(W."QC:'(H."D]
M/C(W."QC:'(H.2D]/C(W."QC:'(H,3`I/3XR-S@L8VAR*#$Q*3T^,C<X+&-H
M<B@Q,BD]/C(W."QC:'(H,3,I/3XR-S@L8VAR*#$T*3T^,C<X+&-H<B@Q-2D]
M/C(W."QC:'(H,38I/3XR-S@L8VAR*#$W*3T^,C<X+&-H<B@Q."D]/C(W."QC
M:'(H,3DI/3XR-S@L8VAR*#(P*3T^,C<X+&-H<B@R,2D]/C(W."P*("`@(&-H
M<B@R,BD]/C(W."QC:'(H,C,I/3XR-S@L8VAR*#(T*3T^,C<X+&-H<B@R-2D]
M/C(W."QC:'(H,C8I/3XR-S@L8VAR*#(W*3T^,C<X+&-H<B@R."D]/C(W."QC
M:'(H,CDI/3XR-S@L8VAR*#,P*3T^,C<X+&-H<B@S,2D]/C(W."PG("<]/C(W
M."PG(2<]/C(W."PG(B<]/C,U-2PG(R<]/C4U-BPG)"<]/C4U-BPG)2<]/C@X
M.2PG)B<]/C8V-RPG7"<G/3XQ.3$L)R@G/3XS,S,L)RDG/3XS,S,L)RHG/3XS
M.#DL)RLG/3XU.#0L"B`@("`G+"<]/C(W."PG+2<]/C,S,RPG+B<]/C(W."PG
M+R<]/C(W."PG,"<]/C4U-BPG,2<]/C4U-BPG,B<]/C4U-BPG,R<]/C4U-BPG
M-"<]/C4U-BPG-2<]/C4U-BPG-B<]/C4U-BPG-R<]/C4U-BPG."<]/C4U-BPG
M.2<]/C4U-BPG.B<]/C(W."PG.R<]/C(W."PG/"<]/C4X-"PG/2<]/C4X-"PG
M/B<]/C4X-"PG/R<]/C4U-BPG0"<]/C$P,34L)T$G/3XV-C<L"B`@("`G0B<]
M/C8V-RPG0R<]/C<R,BPG1"<]/C<R,BPG12<]/C8V-RPG1B<]/C8Q,2PG1R<]
M/C<W."PG2"<]/C<R,BPG22<]/C(W."PG2B<]/C4P,"PG2R<]/C8V-RPG3"<]
M/C4U-BPG32<]/C@S,RPG3B<]/C<R,BPG3R<]/C<W."PG4"<]/C8V-RPG42<]
M/C<W."PG4B<]/C<R,BPG4R<]/C8V-RPG5"<]/C8Q,2PG52<]/C<R,BPG5B<]
M/C8V-RPG5R<]/CDT-"P*("`@("=8)ST^-C8W+"=9)ST^-C8W+"=:)ST^-C$Q
M+"=;)ST^,C<X+"=<7"<]/C(W."PG72<]/C(W."PG7B<]/C0V.2PG7R<]/C4U
M-BPG8"<]/C,S,RPG82<]/C4U-BPG8B<]/C4U-BPG8R<]/C4P,"PG9"<]/C4U
M-BPG92<]/C4U-BPG9B<]/C(W."PG9R<]/C4U-BPG:"<]/C4U-BPG:2<]/C(R
M,BPG:B<]/C(R,BPG:R<]/C4P,"PG;"<]/C(R,BPG;2<]/C@S,RP*("`@("=N
M)ST^-34V+"=O)ST^-34V+"=P)ST^-34V+"=Q)ST^-34V+"=R)ST^,S,S+"=S
M)ST^-3`P+"=T)ST^,C<X+"=U)ST^-34V+"=V)ST^-3`P+"=W)ST^-S(R+"=X
M)ST^-3`P+"=Y)ST^-3`P+"=Z)ST^-3`P+"=[)ST^,S,T+"=\)ST^,C8P+"=]
M)ST^,S,T+"=^)ST^-3@T+&-H<B@Q,C<I/3XS-3`L8VAR*#$R."D]/C4U-BQC
M:'(H,3(Y*3T^,S4P+&-H<B@Q,S`I/3XR,C(L8VAR*#$S,2D]/C4U-BP*("`@
M(&-H<B@Q,S(I/3XS,S,L8VAR*#$S,RD]/C$P,#`L8VAR*#$S-"D]/C4U-BQC
M:'(H,3,U*3T^-34V+&-H<B@Q,S8I/3XS,S,L8VAR*#$S-RD]/C$P,#`L8VAR
M*#$S."D]/C8V-RQC:'(H,3,Y*3T^,S,S+&-H<B@Q-#`I/3XQ,#`P+&-H<B@Q
M-#$I/3XS-3`L8VAR*#$T,BD]/C8Q,2QC:'(H,30S*3T^,S4P+&-H<B@Q-#0I
M/3XS-3`L8VAR*#$T-2D]/C(R,BQC:'(H,30V*3T^,C(R+&-H<B@Q-#<I/3XS
M,S,L8VAR*#$T."D]/C,S,RQC:'(H,30Y*3T^,S4P+&-H<B@Q-3`I/3XU-38L
M8VAR*#$U,2D]/C$P,#`L8VAR*#$U,BD]/C,S,RQC:'(H,34S*3T^,3`P,"P*
M("`@(&-H<B@Q-30I/3XU,#`L8VAR*#$U-2D]/C,S,RQC:'(H,34V*3T^.30T
M+&-H<B@Q-3<I/3XS-3`L8VAR*#$U."D]/C4P,"QC:'(H,34Y*3T^-C8W+&-H
M<B@Q-C`I/3XR-S@L8VAR*#$V,2D]/C,S,RQC:'(H,38R*3T^-34V+&-H<B@Q
M-C,I/3XU-38L8VAR*#$V-"D]/C4U-BQC:'(H,38U*3T^-34V+&-H<B@Q-C8I
M/3XR-C`L8VAR*#$V-RD]/C4U-BQC:'(H,38X*3T^,S,S+&-H<B@Q-CDI/3XW
M,S<L8VAR*#$W,"D]/C,W,"QC:'(H,3<Q*3T^-34V+&-H<B@Q-S(I/3XU.#0L
M8VAR*#$W,RD]/C,S,RQC:'(H,3<T*3T^-S,W+&-H<B@Q-S4I/3XS,S,L"B`@
M("!C:'(H,3<V*3T^-#`P+&-H<B@Q-S<I/3XU.#0L8VAR*#$W."D]/C,S,RQC
M:'(H,3<Y*3T^,S,S+&-H<B@Q.#`I/3XS,S,L8VAR*#$X,2D]/C4U-BQC:'(H
M,3@R*3T^-3,W+&-H<B@Q.#,I/3XR-S@L8VAR*#$X-"D]/C,S,RQC:'(H,3@U
M*3T^,S,S+&-H<B@Q.#8I/3XS-C4L8VAR*#$X-RD]/C4U-BQC:'(H,3@X*3T^
M.#,T+&-H<B@Q.#DI/3XX,S0L8VAR*#$Y,"D]/C@S-"QC:'(H,3DQ*3T^-C$Q
M+&-H<B@Q.3(I/3XV-C<L8VAR*#$Y,RD]/C8V-RQC:'(H,3DT*3T^-C8W+&-H
M<B@Q.34I/3XV-C<L8VAR*#$Y-BD]/C8V-RQC:'(H,3DW*3T^-C8W+`H@("`@
M8VAR*#$Y."D]/C$P,#`L8VAR*#$Y.2D]/C<R,BQC:'(H,C`P*3T^-C8W+&-H
M<B@R,#$I/3XV-C<L8VAR*#(P,BD]/C8V-RQC:'(H,C`S*3T^-C8W+&-H<B@R
M,#0I/3XR-S@L8VAR*#(P-2D]/C(W."QC:'(H,C`V*3T^,C<X+&-H<B@R,#<I
M/3XR-S@L8VAR*#(P."D]/C<R,BQC:'(H,C`Y*3T^-S(R+&-H<B@R,3`I/3XW
M-S@L8VAR*#(Q,2D]/C<W."QC:'(H,C$R*3T^-S<X+&-H<B@R,3,I/3XW-S@L
M8VAR*#(Q-"D]/C<W."QC:'(H,C$U*3T^-3@T+&-H<B@R,38I/3XW-S@L8VAR
M*#(Q-RD]/C<R,BQC:'(H,C$X*3T^-S(R+&-H<B@R,3DI/3XW,C(L"B`@("!C
M:'(H,C(P*3T^-S(R+&-H<B@R,C$I/3XV-C<L8VAR*#(R,BD]/C8V-RQC:'(H
M,C(S*3T^-C$Q+&-H<B@R,C0I/3XU-38L8VAR*#(R-2D]/C4U-BQC:'(H,C(V
M*3T^-34V+&-H<B@R,C<I/3XU-38L8VAR*#(R."D]/C4U-BQC:'(H,C(Y*3T^
M-34V+&-H<B@R,S`I/3XX.#DL8VAR*#(S,2D]/C4P,"QC:'(H,C,R*3T^-34V
M+&-H<B@R,S,I/3XU-38L8VAR*#(S-"D]/C4U-BQC:'(H,C,U*3T^-34V+&-H
M<B@R,S8I/3XR-S@L8VAR*#(S-RD]/C(W."QC:'(H,C,X*3T^,C<X+&-H<B@R
M,SDI/3XR-S@L8VAR*#(T,"D]/C4U-BQC:'(H,C0Q*3T^-34V+`H@("`@8VAR
M*#(T,BD]/C4U-BQC:'(H,C0S*3T^-34V+&-H<B@R-#0I/3XU-38L8VAR*#(T
M-2D]/C4U-BQC:'(H,C0V*3T^-34V+&-H<B@R-#<I/3XU.#0L8VAR*#(T."D]
M/C8Q,2QC:'(H,C0Y*3T^-34V+&-H<B@R-3`I/3XU-38L8VAR*#(U,2D]/C4U
M-BQC:'(H,C4R*3T^-34V+&-H<B@R-3,I/3XU,#`L8VAR*#(U-"D]/C4U-BQC
M:'(H,C4U*3T^-3`P*3L*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT<R]H96QV971I8V%B+G!H
M<```````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8R,#<`,3`U,34T,S,W-#4`
M,#(S-C<R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!`<&%C:V%G92!&:6QE7U!$1@H@*B\*)&9O;G1?
M=VED=&AS6R=H96QV971I8V%")UT@/2!A<G)A>2@*("`@(&-H<B@P*3T^,C<X
M+&-H<B@Q*3T^,C<X+&-H<B@R*3T^,C<X+&-H<B@S*3T^,C<X+&-H<B@T*3T^
M,C<X+&-H<B@U*3T^,C<X+&-H<B@V*3T^,C<X+&-H<B@W*3T^,C<X+&-H<B@X
M*3T^,C<X+&-H<B@Y*3T^,C<X+&-H<B@Q,"D]/C(W."QC:'(H,3$I/3XR-S@L
M8VAR*#$R*3T^,C<X+&-H<B@Q,RD]/C(W."QC:'(H,30I/3XR-S@L8VAR*#$U
M*3T^,C<X+&-H<B@Q-BD]/C(W."QC:'(H,3<I/3XR-S@L8VAR*#$X*3T^,C<X
M+&-H<B@Q.2D]/C(W."QC:'(H,C`I/3XR-S@L8VAR*#(Q*3T^,C<X+`H@("`@
M8VAR*#(R*3T^,C<X+&-H<B@R,RD]/C(W."QC:'(H,C0I/3XR-S@L8VAR*#(U
M*3T^,C<X+&-H<B@R-BD]/C(W."QC:'(H,C<I/3XR-S@L8VAR*#(X*3T^,C<X
M+&-H<B@R.2D]/C(W."QC:'(H,S`I/3XR-S@L8VAR*#,Q*3T^,C<X+"<@)ST^
M,C<X+"<A)ST^,S,S+"<B)ST^-#<T+"<C)ST^-34V+"<D)ST^-34V+"<E)ST^
M.#@Y+"<F)ST^-S(R+"=<)R<]/C(S."PG*"<]/C,S,RPG*2<]/C,S,RPG*B<]
M/C,X.2PG*R<]/C4X-"P*("`@("<L)ST^,C<X+"<M)ST^,S,S+"<N)ST^,C<X
M+"<O)ST^,C<X+"<P)ST^-34V+"<Q)ST^-34V+"<R)ST^-34V+"<S)ST^-34V
M+"<T)ST^-34V+"<U)ST^-34V+"<V)ST^-34V+"<W)ST^-34V+"<X)ST^-34V
M+"<Y)ST^-34V+"<Z)ST^,S,S+"<[)ST^,S,S+"<\)ST^-3@T+"<])ST^-3@T
M+"<^)ST^-3@T+"<_)ST^-C$Q+"=`)ST^.3<U+"=!)ST^-S(R+`H@("`@)T(G
M/3XW,C(L)T,G/3XW,C(L)T0G/3XW,C(L)T4G/3XV-C<L)T8G/3XV,3$L)T<G
M/3XW-S@L)T@G/3XW,C(L)TDG/3XR-S@L)THG/3XU-38L)TLG/3XW,C(L)TPG
M/3XV,3$L)TTG/3XX,S,L)TXG/3XW,C(L)T\G/3XW-S@L)U`G/3XV-C<L)U$G
M/3XW-S@L)U(G/3XW,C(L)U,G/3XV-C<L)U0G/3XV,3$L)U4G/3XW,C(L)U8G
M/3XV-C<L)U<G/3XY-#0L"B`@("`G6"<]/C8V-RPG62<]/C8V-RPG6B<]/C8Q
M,2PG6R<]/C,S,RPG7%PG/3XR-S@L)UTG/3XS,S,L)UXG/3XU.#0L)U\G/3XU
M-38L)V`G/3XS,S,L)V$G/3XU-38L)V(G/3XV,3$L)V,G/3XU-38L)V0G/3XV
M,3$L)V4G/3XU-38L)V8G/3XS,S,L)V<G/3XV,3$L)V@G/3XV,3$L)VDG/3XR
M-S@L)VHG/3XR-S@L)VLG/3XU-38L)VPG/3XR-S@L)VTG/3XX.#DL"B`@("`G
M;B<]/C8Q,2PG;R<]/C8Q,2PG<"<]/C8Q,2PG<2<]/C8Q,2PG<B<]/C,X.2PG
M<R<]/C4U-BPG="<]/C,S,RPG=2<]/C8Q,2PG=B<]/C4U-BPG=R<]/C<W."PG
M>"<]/C4U-BPG>2<]/C4U-BPG>B<]/C4P,"PG>R<]/C,X.2PG?"<]/C(X,"PG
M?2<]/C,X.2PG?B<]/C4X-"QC:'(H,3(W*3T^,S4P+&-H<B@Q,C@I/3XU-38L
M8VAR*#$R.2D]/C,U,"QC:'(H,3,P*3T^,C<X+&-H<B@Q,S$I/3XU-38L"B`@
M("!C:'(H,3,R*3T^-3`P+&-H<B@Q,S,I/3XQ,#`P+&-H<B@Q,S0I/3XU-38L
M8VAR*#$S-2D]/C4U-BQC:'(H,3,V*3T^,S,S+&-H<B@Q,S<I/3XQ,#`P+&-H
M<B@Q,S@I/3XV-C<L8VAR*#$S.2D]/C,S,RQC:'(H,30P*3T^,3`P,"QC:'(H
M,30Q*3T^,S4P+&-H<B@Q-#(I/3XV,3$L8VAR*#$T,RD]/C,U,"QC:'(H,30T
M*3T^,S4P+&-H<B@Q-#4I/3XR-S@L8VAR*#$T-BD]/C(W."QC:'(H,30W*3T^
M-3`P+&-H<B@Q-#@I/3XU,#`L8VAR*#$T.2D]/C,U,"QC:'(H,34P*3T^-34V
M+&-H<B@Q-3$I/3XQ,#`P+&-H<B@Q-3(I/3XS,S,L8VAR*#$U,RD]/C$P,#`L
M"B`@("!C:'(H,34T*3T^-34V+&-H<B@Q-34I/3XS,S,L8VAR*#$U-BD]/CDT
M-"QC:'(H,34W*3T^,S4P+&-H<B@Q-3@I/3XU,#`L8VAR*#$U.2D]/C8V-RQC
M:'(H,38P*3T^,C<X+&-H<B@Q-C$I/3XS,S,L8VAR*#$V,BD]/C4U-BQC:'(H
M,38S*3T^-34V+&-H<B@Q-C0I/3XU-38L8VAR*#$V-2D]/C4U-BQC:'(H,38V
M*3T^,C@P+&-H<B@Q-C<I/3XU-38L8VAR*#$V."D]/C,S,RQC:'(H,38Y*3T^
M-S,W+&-H<B@Q-S`I/3XS-S`L8VAR*#$W,2D]/C4U-BQC:'(H,3<R*3T^-3@T
M+&-H<B@Q-S,I/3XS,S,L8VAR*#$W-"D]/C<S-RQC:'(H,3<U*3T^,S,S+`H@
M("`@8VAR*#$W-BD]/C0P,"QC:'(H,3<W*3T^-3@T+&-H<B@Q-S@I/3XS,S,L
M8VAR*#$W.2D]/C,S,RQC:'(H,3@P*3T^,S,S+&-H<B@Q.#$I/3XV,3$L8VAR
M*#$X,BD]/C4U-BQC:'(H,3@S*3T^,C<X+&-H<B@Q.#0I/3XS,S,L8VAR*#$X
M-2D]/C,S,RQC:'(H,3@V*3T^,S8U+&-H<B@Q.#<I/3XU-38L8VAR*#$X."D]
M/C@S-"QC:'(H,3@Y*3T^.#,T+&-H<B@Q.3`I/3XX,S0L8VAR*#$Y,2D]/C8Q
M,2QC:'(H,3DR*3T^-S(R+&-H<B@Q.3,I/3XW,C(L8VAR*#$Y-"D]/C<R,BQC
M:'(H,3DU*3T^-S(R+&-H<B@Q.38I/3XW,C(L8VAR*#$Y-RD]/C<R,BP*("`@
M(&-H<B@Q.3@I/3XQ,#`P+&-H<B@Q.3DI/3XW,C(L8VAR*#(P,"D]/C8V-RQC
M:'(H,C`Q*3T^-C8W+&-H<B@R,#(I/3XV-C<L8VAR*#(P,RD]/C8V-RQC:'(H
M,C`T*3T^,C<X+&-H<B@R,#4I/3XR-S@L8VAR*#(P-BD]/C(W."QC:'(H,C`W
M*3T^,C<X+&-H<B@R,#@I/3XW,C(L8VAR*#(P.2D]/C<R,BQC:'(H,C$P*3T^
M-S<X+&-H<B@R,3$I/3XW-S@L8VAR*#(Q,BD]/C<W."QC:'(H,C$S*3T^-S<X
M+&-H<B@R,30I/3XW-S@L8VAR*#(Q-2D]/C4X-"QC:'(H,C$V*3T^-S<X+&-H
M<B@R,3<I/3XW,C(L8VAR*#(Q."D]/C<R,BQC:'(H,C$Y*3T^-S(R+`H@("`@
M8VAR*#(R,"D]/C<R,BQC:'(H,C(Q*3T^-C8W+&-H<B@R,C(I/3XV-C<L8VAR
M*#(R,RD]/C8Q,2QC:'(H,C(T*3T^-34V+&-H<B@R,C4I/3XU-38L8VAR*#(R
M-BD]/C4U-BQC:'(H,C(W*3T^-34V+&-H<B@R,C@I/3XU-38L8VAR*#(R.2D]
M/C4U-BQC:'(H,C,P*3T^.#@Y+&-H<B@R,S$I/3XU-38L8VAR*#(S,BD]/C4U
M-BQC:'(H,C,S*3T^-34V+&-H<B@R,S0I/3XU-38L8VAR*#(S-2D]/C4U-BQC
M:'(H,C,V*3T^,C<X+&-H<B@R,S<I/3XR-S@L8VAR*#(S."D]/C(W."QC:'(H
M,C,Y*3T^,C<X+&-H<B@R-#`I/3XV,3$L8VAR*#(T,2D]/C8Q,2P*("`@(&-H
M<B@R-#(I/3XV,3$L8VAR*#(T,RD]/C8Q,2QC:'(H,C0T*3T^-C$Q+&-H<B@R
M-#4I/3XV,3$L8VAR*#(T-BD]/C8Q,2QC:'(H,C0W*3T^-3@T+&-H<B@R-#@I
M/3XV,3$L8VAR*#(T.2D]/C8Q,2QC:'(H,C4P*3T^-C$Q+&-H<B@R-3$I/3XV
M,3$L8VAR*#(U,BD]/C8Q,2QC:'(H,C4S*3T^-34V+&-H<B@R-30I/3XV,3$L
M8VAR*#(U-2D]/C4U-BD["@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O1FEL92]01$8O9F]N=',O:&5L=F5T:6-A8FDN
M<&AP`````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V,C$P`#$P-3$U-#,S-S0U
M`#`R-#`S-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@0'!A8VMA9V4@1FEL95]01$8*("HO"B1F;VYT
M7W=I9'1H<ULG:&5L=F5T:6-A0DDG72`](&%R<F%Y*`H@("`@8VAR*#`I/3XR
M-S@L8VAR*#$I/3XR-S@L8VAR*#(I/3XR-S@L8VAR*#,I/3XR-S@L8VAR*#0I
M/3XR-S@L8VAR*#4I/3XR-S@L8VAR*#8I/3XR-S@L8VAR*#<I/3XR-S@L8VAR
M*#@I/3XR-S@L8VAR*#DI/3XR-S@L8VAR*#$P*3T^,C<X+&-H<B@Q,2D]/C(W
M."QC:'(H,3(I/3XR-S@L8VAR*#$S*3T^,C<X+&-H<B@Q-"D]/C(W."QC:'(H
M,34I/3XR-S@L8VAR*#$V*3T^,C<X+&-H<B@Q-RD]/C(W."QC:'(H,3@I/3XR
M-S@L8VAR*#$Y*3T^,C<X+&-H<B@R,"D]/C(W."QC:'(H,C$I/3XR-S@L"B`@
M("!C:'(H,C(I/3XR-S@L8VAR*#(S*3T^,C<X+&-H<B@R-"D]/C(W."QC:'(H
M,C4I/3XR-S@L8VAR*#(V*3T^,C<X+&-H<B@R-RD]/C(W."QC:'(H,C@I/3XR
M-S@L8VAR*#(Y*3T^,C<X+&-H<B@S,"D]/C(W."QC:'(H,S$I/3XR-S@L)R`G
M/3XR-S@L)R$G/3XS,S,L)R(G/3XT-S0L)R,G/3XU-38L)R0G/3XU-38L)R4G
M/3XX.#DL)R8G/3XW,C(L)UPG)ST^,C,X+"<H)ST^,S,S+"<I)ST^,S,S+"<J
M)ST^,S@Y+"<K)ST^-3@T+`H@("`@)RPG/3XR-S@L)RTG/3XS,S,L)RXG/3XR
M-S@L)R\G/3XR-S@L)S`G/3XU-38L)S$G/3XU-38L)S(G/3XU-38L)S,G/3XU
M-38L)S0G/3XU-38L)S4G/3XU-38L)S8G/3XU-38L)S<G/3XU-38L)S@G/3XU
M-38L)SDG/3XU-38L)SHG/3XS,S,L)SLG/3XS,S,L)SPG/3XU.#0L)STG/3XU
M.#0L)SXG/3XU.#0L)S\G/3XV,3$L)T`G/3XY-S4L)T$G/3XW,C(L"B`@("`G
M0B<]/C<R,BPG0R<]/C<R,BPG1"<]/C<R,BPG12<]/C8V-RPG1B<]/C8Q,2PG
M1R<]/C<W."PG2"<]/C<R,BPG22<]/C(W."PG2B<]/C4U-BPG2R<]/C<R,BPG
M3"<]/C8Q,2PG32<]/C@S,RPG3B<]/C<R,BPG3R<]/C<W."PG4"<]/C8V-RPG
M42<]/C<W."PG4B<]/C<R,BPG4R<]/C8V-RPG5"<]/C8Q,2PG52<]/C<R,BPG
M5B<]/C8V-RPG5R<]/CDT-"P*("`@("=8)ST^-C8W+"=9)ST^-C8W+"=:)ST^
M-C$Q+"=;)ST^,S,S+"=<7"<]/C(W."PG72<]/C,S,RPG7B<]/C4X-"PG7R<]
M/C4U-BPG8"<]/C,S,RPG82<]/C4U-BPG8B<]/C8Q,2PG8R<]/C4U-BPG9"<]
M/C8Q,2PG92<]/C4U-BPG9B<]/C,S,RPG9R<]/C8Q,2PG:"<]/C8Q,2PG:2<]
M/C(W."PG:B<]/C(W."PG:R<]/C4U-BPG;"<]/C(W."PG;2<]/C@X.2P*("`@
M("=N)ST^-C$Q+"=O)ST^-C$Q+"=P)ST^-C$Q+"=Q)ST^-C$Q+"=R)ST^,S@Y
M+"=S)ST^-34V+"=T)ST^,S,S+"=U)ST^-C$Q+"=V)ST^-34V+"=W)ST^-S<X
M+"=X)ST^-34V+"=Y)ST^-34V+"=Z)ST^-3`P+"=[)ST^,S@Y+"=\)ST^,C@P
M+"=])ST^,S@Y+"=^)ST^-3@T+&-H<B@Q,C<I/3XS-3`L8VAR*#$R."D]/C4U
M-BQC:'(H,3(Y*3T^,S4P+&-H<B@Q,S`I/3XR-S@L8VAR*#$S,2D]/C4U-BP*
M("`@(&-H<B@Q,S(I/3XU,#`L8VAR*#$S,RD]/C$P,#`L8VAR*#$S-"D]/C4U
M-BQC:'(H,3,U*3T^-34V+&-H<B@Q,S8I/3XS,S,L8VAR*#$S-RD]/C$P,#`L
M8VAR*#$S."D]/C8V-RQC:'(H,3,Y*3T^,S,S+&-H<B@Q-#`I/3XQ,#`P+&-H
M<B@Q-#$I/3XS-3`L8VAR*#$T,BD]/C8Q,2QC:'(H,30S*3T^,S4P+&-H<B@Q
M-#0I/3XS-3`L8VAR*#$T-2D]/C(W."QC:'(H,30V*3T^,C<X+&-H<B@Q-#<I
M/3XU,#`L8VAR*#$T."D]/C4P,"QC:'(H,30Y*3T^,S4P+&-H<B@Q-3`I/3XU
M-38L8VAR*#$U,2D]/C$P,#`L8VAR*#$U,BD]/C,S,RQC:'(H,34S*3T^,3`P
M,"P*("`@(&-H<B@Q-30I/3XU-38L8VAR*#$U-2D]/C,S,RQC:'(H,34V*3T^
M.30T+&-H<B@Q-3<I/3XS-3`L8VAR*#$U."D]/C4P,"QC:'(H,34Y*3T^-C8W
M+&-H<B@Q-C`I/3XR-S@L8VAR*#$V,2D]/C,S,RQC:'(H,38R*3T^-34V+&-H
M<B@Q-C,I/3XU-38L8VAR*#$V-"D]/C4U-BQC:'(H,38U*3T^-34V+&-H<B@Q
M-C8I/3XR.#`L8VAR*#$V-RD]/C4U-BQC:'(H,38X*3T^,S,S+&-H<B@Q-CDI
M/3XW,S<L8VAR*#$W,"D]/C,W,"QC:'(H,3<Q*3T^-34V+&-H<B@Q-S(I/3XU
M.#0L8VAR*#$W,RD]/C,S,RQC:'(H,3<T*3T^-S,W+&-H<B@Q-S4I/3XS,S,L
M"B`@("!C:'(H,3<V*3T^-#`P+&-H<B@Q-S<I/3XU.#0L8VAR*#$W."D]/C,S
M,RQC:'(H,3<Y*3T^,S,S+&-H<B@Q.#`I/3XS,S,L8VAR*#$X,2D]/C8Q,2QC
M:'(H,3@R*3T^-34V+&-H<B@Q.#,I/3XR-S@L8VAR*#$X-"D]/C,S,RQC:'(H
M,3@U*3T^,S,S+&-H<B@Q.#8I/3XS-C4L8VAR*#$X-RD]/C4U-BQC:'(H,3@X
M*3T^.#,T+&-H<B@Q.#DI/3XX,S0L8VAR*#$Y,"D]/C@S-"QC:'(H,3DQ*3T^
M-C$Q+&-H<B@Q.3(I/3XW,C(L8VAR*#$Y,RD]/C<R,BQC:'(H,3DT*3T^-S(R
M+&-H<B@Q.34I/3XW,C(L8VAR*#$Y-BD]/C<R,BQC:'(H,3DW*3T^-S(R+`H@
M("`@8VAR*#$Y."D]/C$P,#`L8VAR*#$Y.2D]/C<R,BQC:'(H,C`P*3T^-C8W
M+&-H<B@R,#$I/3XV-C<L8VAR*#(P,BD]/C8V-RQC:'(H,C`S*3T^-C8W+&-H
M<B@R,#0I/3XR-S@L8VAR*#(P-2D]/C(W."QC:'(H,C`V*3T^,C<X+&-H<B@R
M,#<I/3XR-S@L8VAR*#(P."D]/C<R,BQC:'(H,C`Y*3T^-S(R+&-H<B@R,3`I
M/3XW-S@L8VAR*#(Q,2D]/C<W."QC:'(H,C$R*3T^-S<X+&-H<B@R,3,I/3XW
M-S@L8VAR*#(Q-"D]/C<W."QC:'(H,C$U*3T^-3@T+&-H<B@R,38I/3XW-S@L
M8VAR*#(Q-RD]/C<R,BQC:'(H,C$X*3T^-S(R+&-H<B@R,3DI/3XW,C(L"B`@
M("!C:'(H,C(P*3T^-S(R+&-H<B@R,C$I/3XV-C<L8VAR*#(R,BD]/C8V-RQC
M:'(H,C(S*3T^-C$Q+&-H<B@R,C0I/3XU-38L8VAR*#(R-2D]/C4U-BQC:'(H
M,C(V*3T^-34V+&-H<B@R,C<I/3XU-38L8VAR*#(R."D]/C4U-BQC:'(H,C(Y
M*3T^-34V+&-H<B@R,S`I/3XX.#DL8VAR*#(S,2D]/C4U-BQC:'(H,C,R*3T^
M-34V+&-H<B@R,S,I/3XU-38L8VAR*#(S-"D]/C4U-BQC:'(H,C,U*3T^-34V
M+&-H<B@R,S8I/3XR-S@L8VAR*#(S-RD]/C(W."QC:'(H,C,X*3T^,C<X+&-H
M<B@R,SDI/3XR-S@L8VAR*#(T,"D]/C8Q,2QC:'(H,C0Q*3T^-C$Q+`H@("`@
M8VAR*#(T,BD]/C8Q,2QC:'(H,C0S*3T^-C$Q+&-H<B@R-#0I/3XV,3$L8VAR
M*#(T-2D]/C8Q,2QC:'(H,C0V*3T^-C$Q+&-H<B@R-#<I/3XU.#0L8VAR*#(T
M."D]/C8Q,2QC:'(H,C0Y*3T^-C$Q+&-H<B@R-3`I/3XV,3$L8VAR*#(U,2D]
M/C8Q,2QC:'(H,C4R*3T^-C$Q+&-H<B@R-3,I/3XU-38L8VAR*#(U-"D]/C8Q
M,2QC:'(H,C4U*3T^-34V*3L*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O;G1S+VAE;'9E=&EC86DN
M<&AP```````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C(Q,``Q,#4Q-30S,S<T
M-0`P,C,V-S,`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J($!P86-K86=E($9I;&5?4$1&"B`J+PHD9F]N
M=%]W:61T:'-;)VAE;'9E=&EC84DG72`](&%R<F%Y*`H@("`@8VAR*#`I/3XR
M-S@L8VAR*#$I/3XR-S@L8VAR*#(I/3XR-S@L8VAR*#,I/3XR-S@L8VAR*#0I
M/3XR-S@L8VAR*#4I/3XR-S@L8VAR*#8I/3XR-S@L8VAR*#<I/3XR-S@L8VAR
M*#@I/3XR-S@L8VAR*#DI/3XR-S@L8VAR*#$P*3T^,C<X+&-H<B@Q,2D]/C(W
M."QC:'(H,3(I/3XR-S@L8VAR*#$S*3T^,C<X+&-H<B@Q-"D]/C(W."QC:'(H
M,34I/3XR-S@L8VAR*#$V*3T^,C<X+&-H<B@Q-RD]/C(W."QC:'(H,3@I/3XR
M-S@L8VAR*#$Y*3T^,C<X+&-H<B@R,"D]/C(W."QC:'(H,C$I/3XR-S@L"B`@
M("!C:'(H,C(I/3XR-S@L8VAR*#(S*3T^,C<X+&-H<B@R-"D]/C(W."QC:'(H
M,C4I/3XR-S@L8VAR*#(V*3T^,C<X+&-H<B@R-RD]/C(W."QC:'(H,C@I/3XR
M-S@L8VAR*#(Y*3T^,C<X+&-H<B@S,"D]/C(W."QC:'(H,S$I/3XR-S@L)R`G
M/3XR-S@L)R$G/3XR-S@L)R(G/3XS-34L)R,G/3XU-38L)R0G/3XU-38L)R4G
M/3XX.#DL)R8G/3XV-C<L)UPG)ST^,3DQ+"<H)ST^,S,S+"<I)ST^,S,S+"<J
M)ST^,S@Y+"<K)ST^-3@T+`H@("`@)RPG/3XR-S@L)RTG/3XS,S,L)RXG/3XR
M-S@L)R\G/3XR-S@L)S`G/3XU-38L)S$G/3XU-38L)S(G/3XU-38L)S,G/3XU
M-38L)S0G/3XU-38L)S4G/3XU-38L)S8G/3XU-38L)S<G/3XU-38L)S@G/3XU
M-38L)SDG/3XU-38L)SHG/3XR-S@L)SLG/3XR-S@L)SPG/3XU.#0L)STG/3XU
M.#0L)SXG/3XU.#0L)S\G/3XU-38L)T`G/3XQ,#$U+"=!)ST^-C8W+`H@("`@
M)T(G/3XV-C<L)T,G/3XW,C(L)T0G/3XW,C(L)T4G/3XV-C<L)T8G/3XV,3$L
M)T<G/3XW-S@L)T@G/3XW,C(L)TDG/3XR-S@L)THG/3XU,#`L)TLG/3XV-C<L
M)TPG/3XU-38L)TTG/3XX,S,L)TXG/3XW,C(L)T\G/3XW-S@L)U`G/3XV-C<L
M)U$G/3XW-S@L)U(G/3XW,C(L)U,G/3XV-C<L)U0G/3XV,3$L)U4G/3XW,C(L
M)U8G/3XV-C<L)U<G/3XY-#0L"B`@("`G6"<]/C8V-RPG62<]/C8V-RPG6B<]
M/C8Q,2PG6R<]/C(W."PG7%PG/3XR-S@L)UTG/3XR-S@L)UXG/3XT-CDL)U\G
M/3XU-38L)V`G/3XS,S,L)V$G/3XU-38L)V(G/3XU-38L)V,G/3XU,#`L)V0G
M/3XU-38L)V4G/3XU-38L)V8G/3XR-S@L)V<G/3XU-38L)V@G/3XU-38L)VDG
M/3XR,C(L)VHG/3XR,C(L)VLG/3XU,#`L)VPG/3XR,C(L)VTG/3XX,S,L"B`@
M("`G;B<]/C4U-BPG;R<]/C4U-BPG<"<]/C4U-BPG<2<]/C4U-BPG<B<]/C,S
M,RPG<R<]/C4P,"PG="<]/C(W."PG=2<]/C4U-BPG=B<]/C4P,"PG=R<]/C<R
M,BPG>"<]/C4P,"PG>2<]/C4P,"PG>B<]/C4P,"PG>R<]/C,S-"PG?"<]/C(V
M,"PG?2<]/C,S-"PG?B<]/C4X-"QC:'(H,3(W*3T^,S4P+&-H<B@Q,C@I/3XU
M-38L8VAR*#$R.2D]/C,U,"QC:'(H,3,P*3T^,C(R+&-H<B@Q,S$I/3XU-38L
M"B`@("!C:'(H,3,R*3T^,S,S+&-H<B@Q,S,I/3XQ,#`P+&-H<B@Q,S0I/3XU
M-38L8VAR*#$S-2D]/C4U-BQC:'(H,3,V*3T^,S,S+&-H<B@Q,S<I/3XQ,#`P
M+&-H<B@Q,S@I/3XV-C<L8VAR*#$S.2D]/C,S,RQC:'(H,30P*3T^,3`P,"QC
M:'(H,30Q*3T^,S4P+&-H<B@Q-#(I/3XV,3$L8VAR*#$T,RD]/C,U,"QC:'(H
M,30T*3T^,S4P+&-H<B@Q-#4I/3XR,C(L8VAR*#$T-BD]/C(R,BQC:'(H,30W
M*3T^,S,S+&-H<B@Q-#@I/3XS,S,L8VAR*#$T.2D]/C,U,"QC:'(H,34P*3T^
M-34V+&-H<B@Q-3$I/3XQ,#`P+&-H<B@Q-3(I/3XS,S,L8VAR*#$U,RD]/C$P
M,#`L"B`@("!C:'(H,34T*3T^-3`P+&-H<B@Q-34I/3XS,S,L8VAR*#$U-BD]
M/CDT-"QC:'(H,34W*3T^,S4P+&-H<B@Q-3@I/3XU,#`L8VAR*#$U.2D]/C8V
M-RQC:'(H,38P*3T^,C<X+&-H<B@Q-C$I/3XS,S,L8VAR*#$V,BD]/C4U-BQC
M:'(H,38S*3T^-34V+&-H<B@Q-C0I/3XU-38L8VAR*#$V-2D]/C4U-BQC:'(H
M,38V*3T^,C8P+&-H<B@Q-C<I/3XU-38L8VAR*#$V."D]/C,S,RQC:'(H,38Y
M*3T^-S,W+&-H<B@Q-S`I/3XS-S`L8VAR*#$W,2D]/C4U-BQC:'(H,3<R*3T^
M-3@T+&-H<B@Q-S,I/3XS,S,L8VAR*#$W-"D]/C<S-RQC:'(H,3<U*3T^,S,S
M+`H@("`@8VAR*#$W-BD]/C0P,"QC:'(H,3<W*3T^-3@T+&-H<B@Q-S@I/3XS
M,S,L8VAR*#$W.2D]/C,S,RQC:'(H,3@P*3T^,S,S+&-H<B@Q.#$I/3XU-38L
M8VAR*#$X,BD]/C4S-RQC:'(H,3@S*3T^,C<X+&-H<B@Q.#0I/3XS,S,L8VAR
M*#$X-2D]/C,S,RQC:'(H,3@V*3T^,S8U+&-H<B@Q.#<I/3XU-38L8VAR*#$X
M."D]/C@S-"QC:'(H,3@Y*3T^.#,T+&-H<B@Q.3`I/3XX,S0L8VAR*#$Y,2D]
M/C8Q,2QC:'(H,3DR*3T^-C8W+&-H<B@Q.3,I/3XV-C<L8VAR*#$Y-"D]/C8V
M-RQC:'(H,3DU*3T^-C8W+&-H<B@Q.38I/3XV-C<L8VAR*#$Y-RD]/C8V-RP*
M("`@(&-H<B@Q.3@I/3XQ,#`P+&-H<B@Q.3DI/3XW,C(L8VAR*#(P,"D]/C8V
M-RQC:'(H,C`Q*3T^-C8W+&-H<B@R,#(I/3XV-C<L8VAR*#(P,RD]/C8V-RQC
M:'(H,C`T*3T^,C<X+&-H<B@R,#4I/3XR-S@L8VAR*#(P-BD]/C(W."QC:'(H
M,C`W*3T^,C<X+&-H<B@R,#@I/3XW,C(L8VAR*#(P.2D]/C<R,BQC:'(H,C$P
M*3T^-S<X+&-H<B@R,3$I/3XW-S@L8VAR*#(Q,BD]/C<W."QC:'(H,C$S*3T^
M-S<X+&-H<B@R,30I/3XW-S@L8VAR*#(Q-2D]/C4X-"QC:'(H,C$V*3T^-S<X
M+&-H<B@R,3<I/3XW,C(L8VAR*#(Q."D]/C<R,BQC:'(H,C$Y*3T^-S(R+`H@
M("`@8VAR*#(R,"D]/C<R,BQC:'(H,C(Q*3T^-C8W+&-H<B@R,C(I/3XV-C<L
M8VAR*#(R,RD]/C8Q,2QC:'(H,C(T*3T^-34V+&-H<B@R,C4I/3XU-38L8VAR
M*#(R-BD]/C4U-BQC:'(H,C(W*3T^-34V+&-H<B@R,C@I/3XU-38L8VAR*#(R
M.2D]/C4U-BQC:'(H,C,P*3T^.#@Y+&-H<B@R,S$I/3XU,#`L8VAR*#(S,BD]
M/C4U-BQC:'(H,C,S*3T^-34V+&-H<B@R,S0I/3XU-38L8VAR*#(S-2D]/C4U
M-BQC:'(H,C,V*3T^,C<X+&-H<B@R,S<I/3XR-S@L8VAR*#(S."D]/C(W."QC
M:'(H,C,Y*3T^,C<X+&-H<B@R-#`I/3XU-38L8VAR*#(T,2D]/C4U-BP*("`@
M(&-H<B@R-#(I/3XU-38L8VAR*#(T,RD]/C4U-BQC:'(H,C0T*3T^-34V+&-H
M<B@R-#4I/3XU-38L8VAR*#(T-BD]/C4U-BQC:'(H,C0W*3T^-3@T+&-H<B@R
M-#@I/3XV,3$L8VAR*#(T.2D]/C4U-BQC:'(H,C4P*3T^-34V+&-H<B@R-3$I
M/3XU-38L8VAR*#(U,BD]/C4U-BQC:'(H,C4S*3T^-3`P+&-H<B@R-30I/3XU
M-38L8VAR*#(U-2D]/C4P,"D["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT<R]S>6UB;VPN<&AP
M````````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8P-S,`,3`U,34T,S,W
M-#4`,#(S,#<R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!`<&%C:V%G92!&:6QE7U!$1@H@*B\*)&9O
M;G1?=VED=&AS6R=S>6UB;VPG72`](&%R<F%Y*`H@("`@8VAR*#`I/3XR-3`L
M8VAR*#$I/3XR-3`L8VAR*#(I/3XR-3`L8VAR*#,I/3XR-3`L8VAR*#0I/3XR
M-3`L8VAR*#4I/3XR-3`L8VAR*#8I/3XR-3`L8VAR*#<I/3XR-3`L8VAR*#@I
M/3XR-3`L8VAR*#DI/3XR-3`L8VAR*#$P*3T^,C4P+&-H<B@Q,2D]/C(U,"QC
M:'(H,3(I/3XR-3`L8VAR*#$S*3T^,C4P+&-H<B@Q-"D]/C(U,"QC:'(H,34I
M/3XR-3`L8VAR*#$V*3T^,C4P+&-H<B@Q-RD]/C(U,"QC:'(H,3@I/3XR-3`L
M8VAR*#$Y*3T^,C4P+&-H<B@R,"D]/C(U,"QC:'(H,C$I/3XR-3`L"B`@("!C
M:'(H,C(I/3XR-3`L8VAR*#(S*3T^,C4P+&-H<B@R-"D]/C(U,"QC:'(H,C4I
M/3XR-3`L8VAR*#(V*3T^,C4P+&-H<B@R-RD]/C(U,"QC:'(H,C@I/3XR-3`L
M8VAR*#(Y*3T^,C4P+&-H<B@S,"D]/C(U,"QC:'(H,S$I/3XR-3`L)R`G/3XR
M-3`L)R$G/3XS,S,L)R(G/3XW,3,L)R,G/3XU,#`L)R0G/3XU-#DL)R4G/3XX
M,S,L)R8G/3XW-S@L)UPG)ST^-#,Y+"<H)ST^,S,S+"<I)ST^,S,S+"<J)ST^
M-3`P+"<K)ST^-30Y+`H@("`@)RPG/3XR-3`L)RTG/3XU-#DL)RXG/3XR-3`L
M)R\G/3XR-S@L)S`G/3XU,#`L)S$G/3XU,#`L)S(G/3XU,#`L)S,G/3XU,#`L
M)S0G/3XU,#`L)S4G/3XU,#`L)S8G/3XU,#`L)S<G/3XU,#`L)S@G/3XU,#`L
M)SDG/3XU,#`L)SHG/3XR-S@L)SLG/3XR-S@L)SPG/3XU-#DL)STG/3XU-#DL
M)SXG/3XU-#DL)S\G/3XT-#0L)T`G/3XU-#DL)T$G/3XW,C(L"B`@("`G0B<]
M/C8V-RPG0R<]/C<R,BPG1"<]/C8Q,BPG12<]/C8Q,2PG1B<]/C<V,RPG1R<]
M/C8P,RPG2"<]/C<R,BPG22<]/C,S,RPG2B<]/C8S,2PG2R<]/C<R,BPG3"<]
M/C8X-BPG32<]/C@X.2PG3B<]/C<R,BPG3R<]/C<R,BPG4"<]/C<V."PG42<]
M/C<T,2PG4B<]/C4U-BPG4R<]/C4Y,BPG5"<]/C8Q,2PG52<]/C8Y,"PG5B<]
M/C0S.2PG5R<]/C<V."P*("`@("=8)ST^-C0U+"=9)ST^-SDU+"=:)ST^-C$Q
M+"=;)ST^,S,S+"=<7"<]/C@V,RPG72<]/C,S,RPG7B<]/C8U."PG7R<]/C4P
M,"PG8"<]/C4P,"PG82<]/C8S,2PG8B<]/C4T.2PG8R<]/C4T.2PG9"<]/C0Y
M-"PG92<]/C0S.2PG9B<]/C4R,2PG9R<]/C0Q,2PG:"<]/C8P,RPG:2<]/C,R
M.2PG:B<]/C8P,RPG:R<]/C4T.2PG;"<]/C4T.2PG;2<]/C4W-BP*("`@("=N
M)ST^-3(Q+"=O)ST^-30Y+"=P)ST^-30Y+"=Q)ST^-3(Q+"=R)ST^-30Y+"=S
M)ST^-C`S+"=T)ST^-#,Y+"=U)ST^-3<V+"=V)ST^-S$S+"=W)ST^-C@V+"=X
M)ST^-#DS+"=Y)ST^-C@V+"=Z)ST^-#DT+"=[)ST^-#@P+"=\)ST^,C`P+"=]
M)ST^-#@P+"=^)ST^-30Y+&-H<B@Q,C<I/3XP+&-H<B@Q,C@I/3XP+&-H<B@Q
M,CDI/3XP+&-H<B@Q,S`I/3XP+&-H<B@Q,S$I/3XP+`H@("`@8VAR*#$S,BD]
M/C`L8VAR*#$S,RD]/C`L8VAR*#$S-"D]/C`L8VAR*#$S-2D]/C`L8VAR*#$S
M-BD]/C`L8VAR*#$S-RD]/C`L8VAR*#$S."D]/C`L8VAR*#$S.2D]/C`L8VAR
M*#$T,"D]/C`L8VAR*#$T,2D]/C`L8VAR*#$T,BD]/C`L8VAR*#$T,RD]/C`L
M8VAR*#$T-"D]/C`L8VAR*#$T-2D]/C`L8VAR*#$T-BD]/C`L8VAR*#$T-RD]
M/C`L8VAR*#$T."D]/C`L8VAR*#$T.2D]/C`L8VAR*#$U,"D]/C`L8VAR*#$U
M,2D]/C`L8VAR*#$U,BD]/C`L8VAR*#$U,RD]/C`L"B`@("!C:'(H,34T*3T^
M,"QC:'(H,34U*3T^,"QC:'(H,34V*3T^,"QC:'(H,34W*3T^,"QC:'(H,34X
M*3T^,"QC:'(H,34Y*3T^,"QC:'(H,38P*3T^-S4P+&-H<B@Q-C$I/3XV,C`L
M8VAR*#$V,BD]/C(T-RQC:'(H,38S*3T^-30Y+&-H<B@Q-C0I/3XQ-C<L8VAR
M*#$V-2D]/C<Q,RQC:'(H,38V*3T^-3`P+&-H<B@Q-C<I/3XW-3,L8VAR*#$V
M."D]/C<U,RQC:'(H,38Y*3T^-S4S+&-H<B@Q-S`I/3XW-3,L8VAR*#$W,2D]
M/C$P-#(L8VAR*#$W,BD]/CDX-RQC:'(H,3<S*3T^-C`S+&-H<B@Q-S0I/3XY
M.#<L8VAR*#$W-2D]/C8P,RP*("`@(&-H<B@Q-S8I/3XT,#`L8VAR*#$W-RD]
M/C4T.2QC:'(H,3<X*3T^-#$Q+&-H<B@Q-SDI/3XU-#DL8VAR*#$X,"D]/C4T
M.2QC:'(H,3@Q*3T^-S$S+&-H<B@Q.#(I/3XT.30L8VAR*#$X,RD]/C0V,"QC
M:'(H,3@T*3T^-30Y+&-H<B@Q.#4I/3XU-#DL8VAR*#$X-BD]/C4T.2QC:'(H
M,3@W*3T^-30Y+&-H<B@Q.#@I/3XQ,#`P+&-H<B@Q.#DI/3XV,#,L8VAR*#$Y
M,"D]/C$P,#`L8VAR*#$Y,2D]/C8U."QC:'(H,3DR*3T^.#(S+&-H<B@Q.3,I
M/3XV.#8L8VAR*#$Y-"D]/C<Y-2QC:'(H,3DU*3T^.3@W+&-H<B@Q.38I/3XW
M-C@L8VAR*#$Y-RD]/C<V."P*("`@(&-H<B@Q.3@I/3XX,C,L8VAR*#$Y.2D]
M/C<V."QC:'(H,C`P*3T^-S8X+&-H<B@R,#$I/3XW,3,L8VAR*#(P,BD]/C<Q
M,RQC:'(H,C`S*3T^-S$S+&-H<B@R,#0I/3XW,3,L8VAR*#(P-2D]/C<Q,RQC
M:'(H,C`V*3T^-S$S+&-H<B@R,#<I/3XW,3,L8VAR*#(P."D]/C<V."QC:'(H
M,C`Y*3T^-S$S+&-H<B@R,3`I/3XW.3`L8VAR*#(Q,2D]/C<Y,"QC:'(H,C$R
M*3T^.#DP+&-H<B@R,3,I/3XX,C,L8VAR*#(Q-"D]/C4T.2QC:'(H,C$U*3T^
M,C4P+&-H<B@R,38I/3XW,3,L8VAR*#(Q-RD]/C8P,RQC:'(H,C$X*3T^-C`S
M+&-H<B@R,3DI/3XQ,#0R+`H@("`@8VAR*#(R,"D]/CDX-RQC:'(H,C(Q*3T^
M-C`S+&-H<B@R,C(I/3XY.#<L8VAR*#(R,RD]/C8P,RQC:'(H,C(T*3T^-#DT
M+&-H<B@R,C4I/3XS,CDL8VAR*#(R-BD]/C<Y,"QC:'(H,C(W*3T^-SDP+&-H
M<B@R,C@I/3XW.#8L8VAR*#(R.2D]/C<Q,RQC:'(H,C,P*3T^,S@T+&-H<B@R
M,S$I/3XS.#0L8VAR*#(S,BD]/C,X-"QC:'(H,C,S*3T^,S@T+&-H<B@R,S0I
M/3XS.#0L8VAR*#(S-2D]/C,X-"QC:'(H,C,V*3T^-#DT+&-H<B@R,S<I/3XT
M.30L8VAR*#(S."D]/C0Y-"QC:'(H,C,Y*3T^-#DT+&-H<B@R-#`I/3XP+&-H
M<B@R-#$I/3XS,CDL"B`@("!C:'(H,C0R*3T^,C<T+&-H<B@R-#,I/3XV.#8L
M8VAR*#(T-"D]/C8X-BQC:'(H,C0U*3T^-C@V+&-H<B@R-#8I/3XS.#0L8VAR
M*#(T-RD]/C,X-"QC:'(H,C0X*3T^,S@T+&-H<B@R-#DI/3XS.#0L8VAR*#(U
M,"D]/C,X-"QC:'(H,C4Q*3T^,S@T+&-H<B@R-3(I/3XT.30L8VAR*#(U,RD]
M/C0Y-"QC:'(H,C4T*3T^-#DT+&-H<B@R-34I/3XP*3L*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O1FEL92]01$8O9F]N=',O=&EM97,N<&AP
M````````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V,3<W`#$P-3$U-#,S
M-S0U`#`R,C<Q,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@0'!A8VMA9V4@1FEL95]01$8*("HO"B1F
M;VYT7W=I9'1H<ULG=&EM97,G72`](&%R<F%Y*`H@("`@8VAR*#`I/3XR-3`L
M8VAR*#$I/3XR-3`L8VAR*#(I/3XR-3`L8VAR*#,I/3XR-3`L8VAR*#0I/3XR
M-3`L8VAR*#4I/3XR-3`L8VAR*#8I/3XR-3`L8VAR*#<I/3XR-3`L8VAR*#@I
M/3XR-3`L8VAR*#DI/3XR-3`L8VAR*#$P*3T^,C4P+&-H<B@Q,2D]/C(U,"QC
M:'(H,3(I/3XR-3`L8VAR*#$S*3T^,C4P+&-H<B@Q-"D]/C(U,"QC:'(H,34I
M/3XR-3`L8VAR*#$V*3T^,C4P+&-H<B@Q-RD]/C(U,"QC:'(H,3@I/3XR-3`L
M8VAR*#$Y*3T^,C4P+&-H<B@R,"D]/C(U,"QC:'(H,C$I/3XR-3`L"B`@("!C
M:'(H,C(I/3XR-3`L8VAR*#(S*3T^,C4P+&-H<B@R-"D]/C(U,"QC:'(H,C4I
M/3XR-3`L8VAR*#(V*3T^,C4P+&-H<B@R-RD]/C(U,"QC:'(H,C@I/3XR-3`L
M8VAR*#(Y*3T^,C4P+&-H<B@S,"D]/C(U,"QC:'(H,S$I/3XR-3`L)R`G/3XR
M-3`L)R$G/3XS,S,L)R(G/3XT,#@L)R,G/3XU,#`L)R0G/3XU,#`L)R4G/3XX
M,S,L)R8G/3XW-S@L)UPG)ST^,3@P+"<H)ST^,S,S+"<I)ST^,S,S+"<J)ST^
M-3`P+"<K)ST^-38T+`H@("`@)RPG/3XR-3`L)RTG/3XS,S,L)RXG/3XR-3`L
M)R\G/3XR-S@L)S`G/3XU,#`L)S$G/3XU,#`L)S(G/3XU,#`L)S,G/3XU,#`L
M)S0G/3XU,#`L)S4G/3XU,#`L)S8G/3XU,#`L)S<G/3XU,#`L)S@G/3XU,#`L
M)SDG/3XU,#`L)SHG/3XR-S@L)SLG/3XR-S@L)SPG/3XU-C0L)STG/3XU-C0L
M)SXG/3XU-C0L)S\G/3XT-#0L)T`G/3XY,C$L)T$G/3XW,C(L"B`@("`G0B<]
M/C8V-RPG0R<]/C8V-RPG1"<]/C<R,BPG12<]/C8Q,2PG1B<]/C4U-BPG1R<]
M/C<R,BPG2"<]/C<R,BPG22<]/C,S,RPG2B<]/C,X.2PG2R<]/C<R,BPG3"<]
M/C8Q,2PG32<]/C@X.2PG3B<]/C<R,BPG3R<]/C<R,BPG4"<]/C4U-BPG42<]
M/C<R,BPG4B<]/C8V-RPG4R<]/C4U-BPG5"<]/C8Q,2PG52<]/C<R,BPG5B<]
M/C<R,BPG5R<]/CDT-"P*("`@("=8)ST^-S(R+"=9)ST^-S(R+"=:)ST^-C$Q
M+"=;)ST^,S,S+"=<7"<]/C(W."PG72<]/C,S,RPG7B<]/C0V.2PG7R<]/C4P
M,"PG8"<]/C,S,RPG82<]/C0T-"PG8B<]/C4P,"PG8R<]/C0T-"PG9"<]/C4P
M,"PG92<]/C0T-"PG9B<]/C,S,RPG9R<]/C4P,"PG:"<]/C4P,"PG:2<]/C(W
M."PG:B<]/C(W."PG:R<]/C4P,"PG;"<]/C(W."PG;2<]/C<W."P*("`@("=N
M)ST^-3`P+"=O)ST^-3`P+"=P)ST^-3`P+"=Q)ST^-3`P+"=R)ST^,S,S+"=S
M)ST^,S@Y+"=T)ST^,C<X+"=U)ST^-3`P+"=V)ST^-3`P+"=W)ST^-S(R+"=X
M)ST^-3`P+"=Y)ST^-3`P+"=Z)ST^-#0T+"=[)ST^-#@P+"=\)ST^,C`P+"=]
M)ST^-#@P+"=^)ST^-30Q+&-H<B@Q,C<I/3XS-3`L8VAR*#$R."D]/C4P,"QC
M:'(H,3(Y*3T^,S4P+&-H<B@Q,S`I/3XS,S,L8VAR*#$S,2D]/C4P,"P*("`@
M(&-H<B@Q,S(I/3XT-#0L8VAR*#$S,RD]/C$P,#`L8VAR*#$S-"D]/C4P,"QC
M:'(H,3,U*3T^-3`P+&-H<B@Q,S8I/3XS,S,L8VAR*#$S-RD]/C$P,#`L8VAR
M*#$S."D]/C4U-BQC:'(H,3,Y*3T^,S,S+&-H<B@Q-#`I/3XX.#DL8VAR*#$T
M,2D]/C,U,"QC:'(H,30R*3T^-C$Q+&-H<B@Q-#,I/3XS-3`L8VAR*#$T-"D]
M/C,U,"QC:'(H,30U*3T^,S,S+&-H<B@Q-#8I/3XS,S,L8VAR*#$T-RD]/C0T
M-"QC:'(H,30X*3T^-#0T+&-H<B@Q-#DI/3XS-3`L8VAR*#$U,"D]/C4P,"QC
M:'(H,34Q*3T^,3`P,"QC:'(H,34R*3T^,S,S+&-H<B@Q-3,I/3XY.#`L"B`@
M("!C:'(H,34T*3T^,S@Y+&-H<B@Q-34I/3XS,S,L8VAR*#$U-BD]/C<R,BQC
M:'(H,34W*3T^,S4P+&-H<B@Q-3@I/3XT-#0L8VAR*#$U.2D]/C<R,BQC:'(H
M,38P*3T^,C4P+&-H<B@Q-C$I/3XS,S,L8VAR*#$V,BD]/C4P,"QC:'(H,38S
M*3T^-3`P+&-H<B@Q-C0I/3XU,#`L8VAR*#$V-2D]/C4P,"QC:'(H,38V*3T^
M,C`P+&-H<B@Q-C<I/3XU,#`L8VAR*#$V."D]/C,S,RQC:'(H,38Y*3T^-S8P
M+&-H<B@Q-S`I/3XR-S8L8VAR*#$W,2D]/C4P,"QC:'(H,3<R*3T^-38T+&-H
M<B@Q-S,I/3XS,S,L8VAR*#$W-"D]/C<V,"QC:'(H,3<U*3T^,S,S+`H@("`@
M8VAR*#$W-BD]/C0P,"QC:'(H,3<W*3T^-38T+&-H<B@Q-S@I/3XS,#`L8VAR
M*#$W.2D]/C,P,"QC:'(H,3@P*3T^,S,S+&-H<B@Q.#$I/3XU,#`L8VAR*#$X
M,BD]/C0U,RQC:'(H,3@S*3T^,C4P+&-H<B@Q.#0I/3XS,S,L8VAR*#$X-2D]
M/C,P,"QC:'(H,3@V*3T^,S$P+&-H<B@Q.#<I/3XU,#`L8VAR*#$X."D]/C<U
M,"QC:'(H,3@Y*3T^-S4P+&-H<B@Q.3`I/3XW-3`L8VAR*#$Y,2D]/C0T-"QC
M:'(H,3DR*3T^-S(R+&-H<B@Q.3,I/3XW,C(L8VAR*#$Y-"D]/C<R,BQC:'(H
M,3DU*3T^-S(R+&-H<B@Q.38I/3XW,C(L8VAR*#$Y-RD]/C<R,BP*("`@(&-H
M<B@Q.3@I/3XX.#DL8VAR*#$Y.2D]/C8V-RQC:'(H,C`P*3T^-C$Q+&-H<B@R
M,#$I/3XV,3$L8VAR*#(P,BD]/C8Q,2QC:'(H,C`S*3T^-C$Q+&-H<B@R,#0I
M/3XS,S,L8VAR*#(P-2D]/C,S,RQC:'(H,C`V*3T^,S,S+&-H<B@R,#<I/3XS
M,S,L8VAR*#(P."D]/C<R,BQC:'(H,C`Y*3T^-S(R+&-H<B@R,3`I/3XW,C(L
M8VAR*#(Q,2D]/C<R,BQC:'(H,C$R*3T^-S(R+&-H<B@R,3,I/3XW,C(L8VAR
M*#(Q-"D]/C<R,BQC:'(H,C$U*3T^-38T+&-H<B@R,38I/3XW,C(L8VAR*#(Q
M-RD]/C<R,BQC:'(H,C$X*3T^-S(R+&-H<B@R,3DI/3XW,C(L"B`@("!C:'(H
M,C(P*3T^-S(R+&-H<B@R,C$I/3XW,C(L8VAR*#(R,BD]/C4U-BQC:'(H,C(S
M*3T^-3`P+&-H<B@R,C0I/3XT-#0L8VAR*#(R-2D]/C0T-"QC:'(H,C(V*3T^
M-#0T+&-H<B@R,C<I/3XT-#0L8VAR*#(R."D]/C0T-"QC:'(H,C(Y*3T^-#0T
M+&-H<B@R,S`I/3XV-C<L8VAR*#(S,2D]/C0T-"QC:'(H,C,R*3T^-#0T+&-H
M<B@R,S,I/3XT-#0L8VAR*#(S-"D]/C0T-"QC:'(H,C,U*3T^-#0T+&-H<B@R
M,S8I/3XR-S@L8VAR*#(S-RD]/C(W."QC:'(H,C,X*3T^,C<X+&-H<B@R,SDI
M/3XR-S@L8VAR*#(T,"D]/C4P,"QC:'(H,C0Q*3T^-3`P+`H@("`@8VAR*#(T
M,BD]/C4P,"QC:'(H,C0S*3T^-3`P+&-H<B@R-#0I/3XU,#`L8VAR*#(T-2D]
M/C4P,"QC:'(H,C0V*3T^-3`P+&-H<B@R-#<I/3XU-C0L8VAR*#(T."D]/C4P
M,"QC:'(H,C0Y*3T^-3`P+&-H<B@R-3`I/3XU,#`L8VAR*#(U,2D]/C4P,"QC
M:'(H,C4R*3T^-3`P+&-H<B@R-3,I/3XU,#`L8VAR*#(U-"D]/C4P,"QC:'(H
M,C4U*3T^-3`P*3L*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O;G1S+W1I;65S8BYP
M:'``````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C(P-0`Q,#4Q-30S
M,S<T-0`P,C,P-#4`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J($!P86-K86=E($9I;&5?4$1&"B`J+PHD
M9F]N=%]W:61T:'-;)W1I;65S0B==(#T@87)R87DH"B`@("!C:'(H,"D]/C(U
M,"QC:'(H,2D]/C(U,"QC:'(H,BD]/C(U,"QC:'(H,RD]/C(U,"QC:'(H-"D]
M/C(U,"QC:'(H-2D]/C(U,"QC:'(H-BD]/C(U,"QC:'(H-RD]/C(U,"QC:'(H
M."D]/C(U,"QC:'(H.2D]/C(U,"QC:'(H,3`I/3XR-3`L8VAR*#$Q*3T^,C4P
M+&-H<B@Q,BD]/C(U,"QC:'(H,3,I/3XR-3`L8VAR*#$T*3T^,C4P+&-H<B@Q
M-2D]/C(U,"QC:'(H,38I/3XR-3`L8VAR*#$W*3T^,C4P+&-H<B@Q."D]/C(U
M,"QC:'(H,3DI/3XR-3`L8VAR*#(P*3T^,C4P+&-H<B@R,2D]/C(U,"P*("`@
M(&-H<B@R,BD]/C(U,"QC:'(H,C,I/3XR-3`L8VAR*#(T*3T^,C4P+&-H<B@R
M-2D]/C(U,"QC:'(H,C8I/3XR-3`L8VAR*#(W*3T^,C4P+&-H<B@R."D]/C(U
M,"QC:'(H,CDI/3XR-3`L8VAR*#,P*3T^,C4P+&-H<B@S,2D]/C(U,"PG("<]
M/C(U,"PG(2<]/C,S,RPG(B<]/C4U-2PG(R<]/C4P,"PG)"<]/C4P,"PG)2<]
M/C$P,#`L)R8G/3XX,S,L)UPG)ST^,C<X+"<H)ST^,S,S+"<I)ST^,S,S+"<J
M)ST^-3`P+"<K)ST^-3<P+`H@("`@)RPG/3XR-3`L)RTG/3XS,S,L)RXG/3XR
M-3`L)R\G/3XR-S@L)S`G/3XU,#`L)S$G/3XU,#`L)S(G/3XU,#`L)S,G/3XU
M,#`L)S0G/3XU,#`L)S4G/3XU,#`L)S8G/3XU,#`L)S<G/3XU,#`L)S@G/3XU
M,#`L)SDG/3XU,#`L)SHG/3XS,S,L)SLG/3XS,S,L)SPG/3XU-S`L)STG/3XU
M-S`L)SXG/3XU-S`L)S\G/3XU,#`L)T`G/3XY,S`L)T$G/3XW,C(L"B`@("`G
M0B<]/C8V-RPG0R<]/C<R,BPG1"<]/C<R,BPG12<]/C8V-RPG1B<]/C8Q,2PG
M1R<]/C<W."PG2"<]/C<W."PG22<]/C,X.2PG2B<]/C4P,"PG2R<]/C<W."PG
M3"<]/C8V-RPG32<]/CDT-"PG3B<]/C<R,BPG3R<]/C<W."PG4"<]/C8Q,2PG
M42<]/C<W."PG4B<]/C<R,BPG4R<]/C4U-BPG5"<]/C8V-RPG52<]/C<R,BPG
M5B<]/C<R,BPG5R<]/C$P,#`L"B`@("`G6"<]/C<R,BPG62<]/C<R,BPG6B<]
M/C8V-RPG6R<]/C,S,RPG7%PG/3XR-S@L)UTG/3XS,S,L)UXG/3XU.#$L)U\G
M/3XU,#`L)V`G/3XS,S,L)V$G/3XU,#`L)V(G/3XU-38L)V,G/3XT-#0L)V0G
M/3XU-38L)V4G/3XT-#0L)V8G/3XS,S,L)V<G/3XU,#`L)V@G/3XU-38L)VDG
M/3XR-S@L)VHG/3XS,S,L)VLG/3XU-38L)VPG/3XR-S@L)VTG/3XX,S,L"B`@
M("`G;B<]/C4U-BPG;R<]/C4P,"PG<"<]/C4U-BPG<2<]/C4U-BPG<B<]/C0T
M-"PG<R<]/C,X.2PG="<]/C,S,RPG=2<]/C4U-BPG=B<]/C4P,"PG=R<]/C<R
M,BPG>"<]/C4P,"PG>2<]/C4P,"PG>B<]/C0T-"PG>R<]/C,Y-"PG?"<]/C(R
M,"PG?2<]/C,Y-"PG?B<]/C4R,"QC:'(H,3(W*3T^,S4P+&-H<B@Q,C@I/3XU
M,#`L8VAR*#$R.2D]/C,U,"QC:'(H,3,P*3T^,S,S+&-H<B@Q,S$I/3XU,#`L
M"B`@("!C:'(H,3,R*3T^-3`P+&-H<B@Q,S,I/3XQ,#`P+&-H<B@Q,S0I/3XU
M,#`L8VAR*#$S-2D]/C4P,"QC:'(H,3,V*3T^,S,S+&-H<B@Q,S<I/3XQ,#`P
M+&-H<B@Q,S@I/3XU-38L8VAR*#$S.2D]/C,S,RQC:'(H,30P*3T^,3`P,"QC
M:'(H,30Q*3T^,S4P+&-H<B@Q-#(I/3XV-C<L8VAR*#$T,RD]/C,U,"QC:'(H
M,30T*3T^,S4P+&-H<B@Q-#4I/3XS,S,L8VAR*#$T-BD]/C,S,RQC:'(H,30W
M*3T^-3`P+&-H<B@Q-#@I/3XU,#`L8VAR*#$T.2D]/C,U,"QC:'(H,34P*3T^
M-3`P+&-H<B@Q-3$I/3XQ,#`P+&-H<B@Q-3(I/3XS,S,L8VAR*#$U,RD]/C$P
M,#`L"B`@("!C:'(H,34T*3T^,S@Y+&-H<B@Q-34I/3XS,S,L8VAR*#$U-BD]
M/C<R,BQC:'(H,34W*3T^,S4P+&-H<B@Q-3@I/3XT-#0L8VAR*#$U.2D]/C<R
M,BQC:'(H,38P*3T^,C4P+&-H<B@Q-C$I/3XS,S,L8VAR*#$V,BD]/C4P,"QC
M:'(H,38S*3T^-3`P+&-H<B@Q-C0I/3XU,#`L8VAR*#$V-2D]/C4P,"QC:'(H
M,38V*3T^,C(P+&-H<B@Q-C<I/3XU,#`L8VAR*#$V."D]/C,S,RQC:'(H,38Y
M*3T^-S0W+&-H<B@Q-S`I/3XS,#`L8VAR*#$W,2D]/C4P,"QC:'(H,3<R*3T^
M-3<P+&-H<B@Q-S,I/3XS,S,L8VAR*#$W-"D]/C<T-RQC:'(H,3<U*3T^,S,S
M+`H@("`@8VAR*#$W-BD]/C0P,"QC:'(H,3<W*3T^-3<P+&-H<B@Q-S@I/3XS
M,#`L8VAR*#$W.2D]/C,P,"QC:'(H,3@P*3T^,S,S+&-H<B@Q.#$I/3XU-38L
M8VAR*#$X,BD]/C4T,"QC:'(H,3@S*3T^,C4P+&-H<B@Q.#0I/3XS,S,L8VAR
M*#$X-2D]/C,P,"QC:'(H,3@V*3T^,S,P+&-H<B@Q.#<I/3XU,#`L8VAR*#$X
M."D]/C<U,"QC:'(H,3@Y*3T^-S4P+&-H<B@Q.3`I/3XW-3`L8VAR*#$Y,2D]
M/C4P,"QC:'(H,3DR*3T^-S(R+&-H<B@Q.3,I/3XW,C(L8VAR*#$Y-"D]/C<R
M,BQC:'(H,3DU*3T^-S(R+&-H<B@Q.38I/3XW,C(L8VAR*#$Y-RD]/C<R,BP*
M("`@(&-H<B@Q.3@I/3XQ,#`P+&-H<B@Q.3DI/3XW,C(L8VAR*#(P,"D]/C8V
M-RQC:'(H,C`Q*3T^-C8W+&-H<B@R,#(I/3XV-C<L8VAR*#(P,RD]/C8V-RQC
M:'(H,C`T*3T^,S@Y+&-H<B@R,#4I/3XS.#DL8VAR*#(P-BD]/C,X.2QC:'(H
M,C`W*3T^,S@Y+&-H<B@R,#@I/3XW,C(L8VAR*#(P.2D]/C<R,BQC:'(H,C$P
M*3T^-S<X+&-H<B@R,3$I/3XW-S@L8VAR*#(Q,BD]/C<W."QC:'(H,C$S*3T^
M-S<X+&-H<B@R,30I/3XW-S@L8VAR*#(Q-2D]/C4W,"QC:'(H,C$V*3T^-S<X
M+&-H<B@R,3<I/3XW,C(L8VAR*#(Q."D]/C<R,BQC:'(H,C$Y*3T^-S(R+`H@
M("`@8VAR*#(R,"D]/C<R,BQC:'(H,C(Q*3T^-S(R+&-H<B@R,C(I/3XV,3$L
M8VAR*#(R,RD]/C4U-BQC:'(H,C(T*3T^-3`P+&-H<B@R,C4I/3XU,#`L8VAR
M*#(R-BD]/C4P,"QC:'(H,C(W*3T^-3`P+&-H<B@R,C@I/3XU,#`L8VAR*#(R
M.2D]/C4P,"QC:'(H,C,P*3T^-S(R+&-H<B@R,S$I/3XT-#0L8VAR*#(S,BD]
M/C0T-"QC:'(H,C,S*3T^-#0T+&-H<B@R,S0I/3XT-#0L8VAR*#(S-2D]/C0T
M-"QC:'(H,C,V*3T^,C<X+&-H<B@R,S<I/3XR-S@L8VAR*#(S."D]/C(W."QC
M:'(H,C,Y*3T^,C<X+&-H<B@R-#`I/3XU,#`L8VAR*#(T,2D]/C4U-BP*("`@
M(&-H<B@R-#(I/3XU,#`L8VAR*#(T,RD]/C4P,"QC:'(H,C0T*3T^-3`P+&-H
M<B@R-#4I/3XU,#`L8VAR*#(T-BD]/C4P,"QC:'(H,C0W*3T^-3<P+&-H<B@R
M-#@I/3XU,#`L8VAR*#(T.2D]/C4U-BQC:'(H,C4P*3T^-34V+&-H<B@R-3$I
M/3XU-38L8VAR*#(U,BD]/C4U-BQC:'(H,C4S*3T^-3`P+&-H<B@R-30I/3XU
M-38L8VAR*#(U-2D]/C4P,"D["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT<R]T:6UE<V)I
M+G!H<```````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8R,#(`,3`U,34T
M,S,W-#4`,#(S,C$S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!`<&%C:V%G92!&:6QE7U!$1@H@*B\*
M)&9O;G1?=VED=&AS6R=T:6UE<T)))UT@/2!A<G)A>2@*("`@(&-H<B@P*3T^
M,C4P+&-H<B@Q*3T^,C4P+&-H<B@R*3T^,C4P+&-H<B@S*3T^,C4P+&-H<B@T
M*3T^,C4P+&-H<B@U*3T^,C4P+&-H<B@V*3T^,C4P+&-H<B@W*3T^,C4P+&-H
M<B@X*3T^,C4P+&-H<B@Y*3T^,C4P+&-H<B@Q,"D]/C(U,"QC:'(H,3$I/3XR
M-3`L8VAR*#$R*3T^,C4P+&-H<B@Q,RD]/C(U,"QC:'(H,30I/3XR-3`L8VAR
M*#$U*3T^,C4P+&-H<B@Q-BD]/C(U,"QC:'(H,3<I/3XR-3`L8VAR*#$X*3T^
M,C4P+&-H<B@Q.2D]/C(U,"QC:'(H,C`I/3XR-3`L8VAR*#(Q*3T^,C4P+`H@
M("`@8VAR*#(R*3T^,C4P+&-H<B@R,RD]/C(U,"QC:'(H,C0I/3XR-3`L8VAR
M*#(U*3T^,C4P+&-H<B@R-BD]/C(U,"QC:'(H,C<I/3XR-3`L8VAR*#(X*3T^
M,C4P+&-H<B@R.2D]/C(U,"QC:'(H,S`I/3XR-3`L8VAR*#,Q*3T^,C4P+"<@
M)ST^,C4P+"<A)ST^,S@Y+"<B)ST^-34U+"<C)ST^-3`P+"<D)ST^-3`P+"<E
M)ST^.#,S+"<F)ST^-S<X+"=<)R<]/C(W."PG*"<]/C,S,RPG*2<]/C,S,RPG
M*B<]/C4P,"PG*R<]/C4W,"P*("`@("<L)ST^,C4P+"<M)ST^,S,S+"<N)ST^
M,C4P+"<O)ST^,C<X+"<P)ST^-3`P+"<Q)ST^-3`P+"<R)ST^-3`P+"<S)ST^
M-3`P+"<T)ST^-3`P+"<U)ST^-3`P+"<V)ST^-3`P+"<W)ST^-3`P+"<X)ST^
M-3`P+"<Y)ST^-3`P+"<Z)ST^,S,S+"<[)ST^,S,S+"<\)ST^-3<P+"<])ST^
M-3<P+"<^)ST^-3<P+"<_)ST^-3`P+"=`)ST^.#,R+"=!)ST^-C8W+`H@("`@
M)T(G/3XV-C<L)T,G/3XV-C<L)T0G/3XW,C(L)T4G/3XV-C<L)T8G/3XV-C<L
M)T<G/3XW,C(L)T@G/3XW-S@L)TDG/3XS.#DL)THG/3XU,#`L)TLG/3XV-C<L
M)TPG/3XV,3$L)TTG/3XX.#DL)TXG/3XW,C(L)T\G/3XW,C(L)U`G/3XV,3$L
M)U$G/3XW,C(L)U(G/3XV-C<L)U,G/3XU-38L)U0G/3XV,3$L)U4G/3XW,C(L
M)U8G/3XV-C<L)U<G/3XX.#DL"B`@("`G6"<]/C8V-RPG62<]/C8Q,2PG6B<]
M/C8Q,2PG6R<]/C,S,RPG7%PG/3XR-S@L)UTG/3XS,S,L)UXG/3XU-S`L)U\G
M/3XU,#`L)V`G/3XS,S,L)V$G/3XU,#`L)V(G/3XU,#`L)V,G/3XT-#0L)V0G
M/3XU,#`L)V4G/3XT-#0L)V8G/3XS,S,L)V<G/3XU,#`L)V@G/3XU-38L)VDG
M/3XR-S@L)VHG/3XR-S@L)VLG/3XU,#`L)VPG/3XR-S@L)VTG/3XW-S@L"B`@
M("`G;B<]/C4U-BPG;R<]/C4P,"PG<"<]/C4P,"PG<2<]/C4P,"PG<B<]/C,X
M.2PG<R<]/C,X.2PG="<]/C(W."PG=2<]/C4U-BPG=B<]/C0T-"PG=R<]/C8V
M-RPG>"<]/C4P,"PG>2<]/C0T-"PG>B<]/C,X.2PG>R<]/C,T."PG?"<]/C(R
M,"PG?2<]/C,T."PG?B<]/C4W,"QC:'(H,3(W*3T^,S4P+&-H<B@Q,C@I/3XU
M,#`L8VAR*#$R.2D]/C,U,"QC:'(H,3,P*3T^,S,S+&-H<B@Q,S$I/3XU,#`L
M"B`@("!C:'(H,3,R*3T^-3`P+&-H<B@Q,S,I/3XQ,#`P+&-H<B@Q,S0I/3XU
M,#`L8VAR*#$S-2D]/C4P,"QC:'(H,3,V*3T^,S,S+&-H<B@Q,S<I/3XQ,#`P
M+&-H<B@Q,S@I/3XU-38L8VAR*#$S.2D]/C,S,RQC:'(H,30P*3T^.30T+&-H
M<B@Q-#$I/3XS-3`L8VAR*#$T,BD]/C8Q,2QC:'(H,30S*3T^,S4P+&-H<B@Q
M-#0I/3XS-3`L8VAR*#$T-2D]/C,S,RQC:'(H,30V*3T^,S,S+&-H<B@Q-#<I
M/3XU,#`L8VAR*#$T."D]/C4P,"QC:'(H,30Y*3T^,S4P+&-H<B@Q-3`I/3XU
M,#`L8VAR*#$U,2D]/C$P,#`L8VAR*#$U,BD]/C,S,RQC:'(H,34S*3T^,3`P
M,"P*("`@(&-H<B@Q-30I/3XS.#DL8VAR*#$U-2D]/C,S,RQC:'(H,34V*3T^
M-S(R+&-H<B@Q-3<I/3XS-3`L8VAR*#$U."D]/C,X.2QC:'(H,34Y*3T^-C$Q
M+&-H<B@Q-C`I/3XR-3`L8VAR*#$V,2D]/C,X.2QC:'(H,38R*3T^-3`P+&-H
M<B@Q-C,I/3XU,#`L8VAR*#$V-"D]/C4P,"QC:'(H,38U*3T^-3`P+&-H<B@Q
M-C8I/3XR,C`L8VAR*#$V-RD]/C4P,"QC:'(H,38X*3T^,S,S+&-H<B@Q-CDI
M/3XW-#<L8VAR*#$W,"D]/C(V-BQC:'(H,3<Q*3T^-3`P+&-H<B@Q-S(I/3XV
M,#8L8VAR*#$W,RD]/C,S,RQC:'(H,3<T*3T^-S0W+&-H<B@Q-S4I/3XS,S,L
M"B`@("!C:'(H,3<V*3T^-#`P+&-H<B@Q-S<I/3XU-S`L8VAR*#$W."D]/C,P
M,"QC:'(H,3<Y*3T^,S`P+&-H<B@Q.#`I/3XS,S,L8VAR*#$X,2D]/C4W-BQC
M:'(H,3@R*3T^-3`P+&-H<B@Q.#,I/3XR-3`L8VAR*#$X-"D]/C,S,RQC:'(H
M,3@U*3T^,S`P+&-H<B@Q.#8I/3XS,#`L8VAR*#$X-RD]/C4P,"QC:'(H,3@X
M*3T^-S4P+&-H<B@Q.#DI/3XW-3`L8VAR*#$Y,"D]/C<U,"QC:'(H,3DQ*3T^
M-3`P+&-H<B@Q.3(I/3XV-C<L8VAR*#$Y,RD]/C8V-RQC:'(H,3DT*3T^-C8W
M+&-H<B@Q.34I/3XV-C<L8VAR*#$Y-BD]/C8V-RQC:'(H,3DW*3T^-C8W+`H@
M("`@8VAR*#$Y."D]/CDT-"QC:'(H,3DY*3T^-C8W+&-H<B@R,#`I/3XV-C<L
M8VAR*#(P,2D]/C8V-RQC:'(H,C`R*3T^-C8W+&-H<B@R,#,I/3XV-C<L8VAR
M*#(P-"D]/C,X.2QC:'(H,C`U*3T^,S@Y+&-H<B@R,#8I/3XS.#DL8VAR*#(P
M-RD]/C,X.2QC:'(H,C`X*3T^-S(R+&-H<B@R,#DI/3XW,C(L8VAR*#(Q,"D]
M/C<R,BQC:'(H,C$Q*3T^-S(R+&-H<B@R,3(I/3XW,C(L8VAR*#(Q,RD]/C<R
M,BQC:'(H,C$T*3T^-S(R+&-H<B@R,34I/3XU-S`L8VAR*#(Q-BD]/C<R,BQC
M:'(H,C$W*3T^-S(R+&-H<B@R,3@I/3XW,C(L8VAR*#(Q.2D]/C<R,BP*("`@
M(&-H<B@R,C`I/3XW,C(L8VAR*#(R,2D]/C8Q,2QC:'(H,C(R*3T^-C$Q+&-H
M<B@R,C,I/3XU,#`L8VAR*#(R-"D]/C4P,"QC:'(H,C(U*3T^-3`P+&-H<B@R
M,C8I/3XU,#`L8VAR*#(R-RD]/C4P,"QC:'(H,C(X*3T^-3`P+&-H<B@R,CDI
M/3XU,#`L8VAR*#(S,"D]/C<R,BQC:'(H,C,Q*3T^-#0T+&-H<B@R,S(I/3XT
M-#0L8VAR*#(S,RD]/C0T-"QC:'(H,C,T*3T^-#0T+&-H<B@R,S4I/3XT-#0L
M8VAR*#(S-BD]/C(W."QC:'(H,C,W*3T^,C<X+&-H<B@R,S@I/3XR-S@L8VAR
M*#(S.2D]/C(W."QC:'(H,C0P*3T^-3`P+&-H<B@R-#$I/3XU-38L"B`@("!C
M:'(H,C0R*3T^-3`P+&-H<B@R-#,I/3XU,#`L8VAR*#(T-"D]/C4P,"QC:'(H
M,C0U*3T^-3`P+&-H<B@R-#8I/3XU,#`L8VAR*#(T-RD]/C4W,"QC:'(H,C0X
M*3T^-3`P+&-H<B@R-#DI/3XU-38L8VAR*#(U,"D]/C4U-BQC:'(H,C4Q*3T^
M-34V+&-H<B@R-3(I/3XU-38L8VAR*#(U,RD]/C0T-"QC:'(H,C4T*3T^-3`P
M+&-H<B@R-34I/3XT-#0I.PH`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O1FEL92]01$8O9F]N=',O=&EM97-I
M+G!H<```````````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V,3<V`#$P-3$U
M-#,S-S0U`#`R,S`V,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@0'!A8VMA9V4@1FEL95]01$8*("HO
M"B1F;VYT7W=I9'1H<ULG=&EM97-))UT@/2!A<G)A>2@*("`@(&-H<B@P*3T^
M,C4P+&-H<B@Q*3T^,C4P+&-H<B@R*3T^,C4P+&-H<B@S*3T^,C4P+&-H<B@T
M*3T^,C4P+&-H<B@U*3T^,C4P+&-H<B@V*3T^,C4P+&-H<B@W*3T^,C4P+&-H
M<B@X*3T^,C4P+&-H<B@Y*3T^,C4P+&-H<B@Q,"D]/C(U,"QC:'(H,3$I/3XR
M-3`L8VAR*#$R*3T^,C4P+&-H<B@Q,RD]/C(U,"QC:'(H,30I/3XR-3`L8VAR
M*#$U*3T^,C4P+&-H<B@Q-BD]/C(U,"QC:'(H,3<I/3XR-3`L8VAR*#$X*3T^
M,C4P+&-H<B@Q.2D]/C(U,"QC:'(H,C`I/3XR-3`L8VAR*#(Q*3T^,C4P+`H@
M("`@8VAR*#(R*3T^,C4P+&-H<B@R,RD]/C(U,"QC:'(H,C0I/3XR-3`L8VAR
M*#(U*3T^,C4P+&-H<B@R-BD]/C(U,"QC:'(H,C<I/3XR-3`L8VAR*#(X*3T^
M,C4P+&-H<B@R.2D]/C(U,"QC:'(H,S`I/3XR-3`L8VAR*#,Q*3T^,C4P+"<@
M)ST^,C4P+"<A)ST^,S,S+"<B)ST^-#(P+"<C)ST^-3`P+"<D)ST^-3`P+"<E
M)ST^.#,S+"<F)ST^-S<X+"=<)R<]/C(Q-"PG*"<]/C,S,RPG*2<]/C,S,RPG
M*B<]/C4P,"PG*R<]/C8W-2P*("`@("<L)ST^,C4P+"<M)ST^,S,S+"<N)ST^
M,C4P+"<O)ST^,C<X+"<P)ST^-3`P+"<Q)ST^-3`P+"<R)ST^-3`P+"<S)ST^
M-3`P+"<T)ST^-3`P+"<U)ST^-3`P+"<V)ST^-3`P+"<W)ST^-3`P+"<X)ST^
M-3`P+"<Y)ST^-3`P+"<Z)ST^,S,S+"<[)ST^,S,S+"<\)ST^-C<U+"<])ST^
M-C<U+"<^)ST^-C<U+"<_)ST^-3`P+"=`)ST^.3(P+"=!)ST^-C$Q+`H@("`@
M)T(G/3XV,3$L)T,G/3XV-C<L)T0G/3XW,C(L)T4G/3XV,3$L)T8G/3XV,3$L
M)T<G/3XW,C(L)T@G/3XW,C(L)TDG/3XS,S,L)THG/3XT-#0L)TLG/3XV-C<L
M)TPG/3XU-38L)TTG/3XX,S,L)TXG/3XV-C<L)T\G/3XW,C(L)U`G/3XV,3$L
M)U$G/3XW,C(L)U(G/3XV,3$L)U,G/3XU,#`L)U0G/3XU-38L)U4G/3XW,C(L
M)U8G/3XV,3$L)U<G/3XX,S,L"B`@("`G6"<]/C8Q,2PG62<]/C4U-BPG6B<]
M/C4U-BPG6R<]/C,X.2PG7%PG/3XR-S@L)UTG/3XS.#DL)UXG/3XT,C(L)U\G
M/3XU,#`L)V`G/3XS,S,L)V$G/3XU,#`L)V(G/3XU,#`L)V,G/3XT-#0L)V0G
M/3XU,#`L)V4G/3XT-#0L)V8G/3XR-S@L)V<G/3XU,#`L)V@G/3XU,#`L)VDG
M/3XR-S@L)VHG/3XR-S@L)VLG/3XT-#0L)VPG/3XR-S@L)VTG/3XW,C(L"B`@
M("`G;B<]/C4P,"PG;R<]/C4P,"PG<"<]/C4P,"PG<2<]/C4P,"PG<B<]/C,X
M.2PG<R<]/C,X.2PG="<]/C(W."PG=2<]/C4P,"PG=B<]/C0T-"PG=R<]/C8V
M-RPG>"<]/C0T-"PG>2<]/C0T-"PG>B<]/C,X.2PG>R<]/C0P,"PG?"<]/C(W
M-2PG?2<]/C0P,"PG?B<]/C4T,2QC:'(H,3(W*3T^,S4P+&-H<B@Q,C@I/3XU
M,#`L8VAR*#$R.2D]/C,U,"QC:'(H,3,P*3T^,S,S+&-H<B@Q,S$I/3XU,#`L
M"B`@("!C:'(H,3,R*3T^-34V+&-H<B@Q,S,I/3XX.#DL8VAR*#$S-"D]/C4P
M,"QC:'(H,3,U*3T^-3`P+&-H<B@Q,S8I/3XS,S,L8VAR*#$S-RD]/C$P,#`L
M8VAR*#$S."D]/C4P,"QC:'(H,3,Y*3T^,S,S+&-H<B@Q-#`I/3XY-#0L8VAR
M*#$T,2D]/C,U,"QC:'(H,30R*3T^-34V+&-H<B@Q-#,I/3XS-3`L8VAR*#$T
M-"D]/C,U,"QC:'(H,30U*3T^,S,S+&-H<B@Q-#8I/3XS,S,L8VAR*#$T-RD]
M/C4U-BQC:'(H,30X*3T^-34V+&-H<B@Q-#DI/3XS-3`L8VAR*#$U,"D]/C4P
M,"QC:'(H,34Q*3T^.#@Y+&-H<B@Q-3(I/3XS,S,L8VAR*#$U,RD]/CDX,"P*
M("`@(&-H<B@Q-30I/3XS.#DL8VAR*#$U-2D]/C,S,RQC:'(H,34V*3T^-C8W
M+&-H<B@Q-3<I/3XS-3`L8VAR*#$U."D]/C,X.2QC:'(H,34Y*3T^-34V+&-H
M<B@Q-C`I/3XR-3`L8VAR*#$V,2D]/C,X.2QC:'(H,38R*3T^-3`P+&-H<B@Q
M-C,I/3XU,#`L8VAR*#$V-"D]/C4P,"QC:'(H,38U*3T^-3`P+&-H<B@Q-C8I
M/3XR-S4L8VAR*#$V-RD]/C4P,"QC:'(H,38X*3T^,S,S+&-H<B@Q-CDI/3XW
M-C`L8VAR*#$W,"D]/C(W-BQC:'(H,3<Q*3T^-3`P+&-H<B@Q-S(I/3XV-S4L
M8VAR*#$W,RD]/C,S,RQC:'(H,3<T*3T^-S8P+&-H<B@Q-S4I/3XS,S,L"B`@
M("!C:'(H,3<V*3T^-#`P+&-H<B@Q-S<I/3XV-S4L8VAR*#$W."D]/C,P,"QC
M:'(H,3<Y*3T^,S`P+&-H<B@Q.#`I/3XS,S,L8VAR*#$X,2D]/C4P,"QC:'(H
M,3@R*3T^-3(S+&-H<B@Q.#,I/3XR-3`L8VAR*#$X-"D]/C,S,RQC:'(H,3@U
M*3T^,S`P+&-H<B@Q.#8I/3XS,3`L8VAR*#$X-RD]/C4P,"QC:'(H,3@X*3T^
M-S4P+&-H<B@Q.#DI/3XW-3`L8VAR*#$Y,"D]/C<U,"QC:'(H,3DQ*3T^-3`P
M+&-H<B@Q.3(I/3XV,3$L8VAR*#$Y,RD]/C8Q,2QC:'(H,3DT*3T^-C$Q+&-H
M<B@Q.34I/3XV,3$L8VAR*#$Y-BD]/C8Q,2QC:'(H,3DW*3T^-C$Q+`H@("`@
M8VAR*#$Y."D]/C@X.2QC:'(H,3DY*3T^-C8W+&-H<B@R,#`I/3XV,3$L8VAR
M*#(P,2D]/C8Q,2QC:'(H,C`R*3T^-C$Q+&-H<B@R,#,I/3XV,3$L8VAR*#(P
M-"D]/C,S,RQC:'(H,C`U*3T^,S,S+&-H<B@R,#8I/3XS,S,L8VAR*#(P-RD]
M/C,S,RQC:'(H,C`X*3T^-S(R+&-H<B@R,#DI/3XV-C<L8VAR*#(Q,"D]/C<R
M,BQC:'(H,C$Q*3T^-S(R+&-H<B@R,3(I/3XW,C(L8VAR*#(Q,RD]/C<R,BQC
M:'(H,C$T*3T^-S(R+&-H<B@R,34I/3XV-S4L8VAR*#(Q-BD]/C<R,BQC:'(H
M,C$W*3T^-S(R+&-H<B@R,3@I/3XW,C(L8VAR*#(Q.2D]/C<R,BP*("`@(&-H
M<B@R,C`I/3XW,C(L8VAR*#(R,2D]/C4U-BQC:'(H,C(R*3T^-C$Q+&-H<B@R
M,C,I/3XU,#`L8VAR*#(R-"D]/C4P,"QC:'(H,C(U*3T^-3`P+&-H<B@R,C8I
M/3XU,#`L8VAR*#(R-RD]/C4P,"QC:'(H,C(X*3T^-3`P+&-H<B@R,CDI/3XU
M,#`L8VAR*#(S,"D]/C8V-RQC:'(H,C,Q*3T^-#0T+&-H<B@R,S(I/3XT-#0L
M8VAR*#(S,RD]/C0T-"QC:'(H,C,T*3T^-#0T+&-H<B@R,S4I/3XT-#0L8VAR
M*#(S-BD]/C(W."QC:'(H,C,W*3T^,C<X+&-H<B@R,S@I/3XR-S@L8VAR*#(S
M.2D]/C(W."QC:'(H,C0P*3T^-3`P+&-H<B@R-#$I/3XU,#`L"B`@("!C:'(H
M,C0R*3T^-3`P+&-H<B@R-#,I/3XU,#`L8VAR*#(T-"D]/C4P,"QC:'(H,C0U
M*3T^-3`P+&-H<B@R-#8I/3XU,#`L8VAR*#(T-RD]/C8W-2QC:'(H,C0X*3T^
M-3`P+&-H<B@R-#DI/3XU,#`L8VAR*#(U,"D]/C4P,"QC:'(H,C4Q*3T^-3`P
M+&-H<B@R-3(I/3XU,#`L8VAR*#(U,RD]/C0T-"QC:'(H,C4T*3T^-3`P+&-H
M<B@R-34I/3XT-#0I.PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O;G1S+WIA<&9D
M:6YG8F%T<RYP:'``````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C`S,``Q,#4Q
M-30S,S<T-0`P,C0R,S(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J($!P86-K86=E($9I;&5?4$1&"B`J
M+PHD9F]N=%]W:61T:'-;)WIA<&9D:6YG8F%T<R==(#T@87)R87DH"B`@("!C
M:'(H,"D]/C`L8VAR*#$I/3XP+&-H<B@R*3T^,"QC:'(H,RD]/C`L8VAR*#0I
M/3XP+&-H<B@U*3T^,"QC:'(H-BD]/C`L8VAR*#<I/3XP+&-H<B@X*3T^,"QC
M:'(H.2D]/C`L8VAR*#$P*3T^,"QC:'(H,3$I/3XP+&-H<B@Q,BD]/C`L8VAR
M*#$S*3T^,"QC:'(H,30I/3XP+&-H<B@Q-2D]/C`L8VAR*#$V*3T^,"QC:'(H
M,3<I/3XP+&-H<B@Q."D]/C`L8VAR*#$Y*3T^,"QC:'(H,C`I/3XP+&-H<B@R
M,2D]/C`L"B`@("!C:'(H,C(I/3XP+&-H<B@R,RD]/C`L8VAR*#(T*3T^,"QC
M:'(H,C4I/3XP+&-H<B@R-BD]/C`L8VAR*#(W*3T^,"QC:'(H,C@I/3XP+&-H
M<B@R.2D]/C`L8VAR*#,P*3T^,"QC:'(H,S$I/3XP+"<@)ST^,C<X+"<A)ST^
M.3<T+"<B)ST^.38Q+"<C)ST^.3<T+"<D)ST^.3@P+"<E)ST^-S$Y+"<F)ST^
M-S@Y+"=<)R<]/C<Y,"PG*"<]/C<Y,2PG*2<]/C8Y,"PG*B<]/CDV,"PG*R<]
M/CDS.2P*("`@("<L)ST^-30Y+"<M)ST^.#4U+"<N)ST^.3$Q+"<O)ST^.3,S
M+"<P)ST^.3$Q+"<Q)ST^.30U+"<R)ST^.3<T+"<S)ST^-S4U+"<T)ST^.#0V
M+"<U)ST^-S8R+"<V)ST^-S8Q+"<W)ST^-3<Q+"<X)ST^-C<W+"<Y)ST^-S8S
M+"<Z)ST^-S8P+"<[)ST^-S4Y+"<\)ST^-S4T+"<])ST^-#DT+"<^)ST^-34R
M+"<_)ST^-3,W+"=`)ST^-3<W+"=!)ST^-CDR+`H@("`@)T(G/3XW.#8L)T,G
M/3XW.#@L)T0G/3XW.#@L)T4G/3XW.3`L)T8G/3XW.3,L)T<G/3XW.30L)T@G
M/3XX,38L)TDG/3XX,C,L)THG/3XW.#DL)TLG/3XX-#$L)TPG/3XX,C,L)TTG
M/3XX,S,L)TXG/3XX,38L)T\G/3XX,S$L)U`G/3XY,C,L)U$G/3XW-#0L)U(G
M/3XW,C,L)U,G/3XW-#DL)U0G/3XW.3`L)U4G/3XW.3(L)U8G/3XV.34L)U<G
M/3XW-S8L"B`@("`G6"<]/C<V."PG62<]/C<Y,BPG6B<]/C<U.2PG6R<]/C<P
M-RPG7%PG/3XW,#@L)UTG/3XV.#(L)UXG/3XW,#$L)U\G/3XX,C8L)V`G/3XX
M,34L)V$G/3XW.#DL)V(G/3XW.#DL)V,G/3XW,#<L)V0G/3XV.#<L)V4G/3XV
M.38L)V8G/3XV.#DL)V<G/3XW.#8L)V@G/3XW.#<L)VDG/3XW,3,L)VHG/3XW
M.3$L)VLG/3XW.#4L)VPG/3XW.3$L)VTG/3XX-S,L"B`@("`G;B<]/C<V,2PG
M;R<]/C<V,BPG<"<]/C<V,BPG<2<]/C<U.2PG<B<]/C<U.2PG<R<]/C@Y,BPG
M="<]/C@Y,BPG=2<]/C<X."PG=B<]/C<X-"PG=R<]/C0S."PG>"<]/C$S."PG
M>2<]/C(W-RPG>B<]/C0Q-2PG>R<]/C,Y,BPG?"<]/C,Y,BPG?2<]/C8V."PG
M?B<]/C8V."QC:'(H,3(W*3T^,"QC:'(H,3(X*3T^,SDP+&-H<B@Q,CDI/3XS
M.3`L8VAR*#$S,"D]/C,Q-RQC:'(H,3,Q*3T^,S$W+`H@("`@8VAR*#$S,BD]
M/C(W-BQC:'(H,3,S*3T^,C<V+&-H<B@Q,S0I/3XU,#DL8VAR*#$S-2D]/C4P
M.2QC:'(H,3,V*3T^-#$P+&-H<B@Q,S<I/3XT,3`L8VAR*#$S."D]/C(S-"QC
M:'(H,3,Y*3T^,C,T+&-H<B@Q-#`I/3XS,S0L8VAR*#$T,2D]/C,S-"QC:'(H
M,30R*3T^,"QC:'(H,30S*3T^,"QC:'(H,30T*3T^,"QC:'(H,30U*3T^,"QC
M:'(H,30V*3T^,"QC:'(H,30W*3T^,"QC:'(H,30X*3T^,"QC:'(H,30Y*3T^
M,"QC:'(H,34P*3T^,"QC:'(H,34Q*3T^,"QC:'(H,34R*3T^,"QC:'(H,34S
M*3T^,"P*("`@(&-H<B@Q-30I/3XP+&-H<B@Q-34I/3XP+&-H<B@Q-38I/3XP
M+&-H<B@Q-3<I/3XP+&-H<B@Q-3@I/3XP+&-H<B@Q-3DI/3XP+&-H<B@Q-C`I
M/3XP+&-H<B@Q-C$I/3XW,S(L8VAR*#$V,BD]/C4T-"QC:'(H,38S*3T^-30T
M+&-H<B@Q-C0I/3XY,3`L8VAR*#$V-2D]/C8V-RQC:'(H,38V*3T^-S8P+&-H
M<B@Q-C<I/3XW-C`L8VAR*#$V."D]/C<W-BQC:'(H,38Y*3T^-3DU+&-H<B@Q
M-S`I/3XV.30L8VAR*#$W,2D]/C8R-BQC:'(H,3<R*3T^-S@X+&-H<B@Q-S,I
M/3XW.#@L8VAR*#$W-"D]/C<X."QC:'(H,3<U*3T^-S@X+`H@("`@8VAR*#$W
M-BD]/C<X."QC:'(H,3<W*3T^-S@X+&-H<B@Q-S@I/3XW.#@L8VAR*#$W.2D]
M/C<X."QC:'(H,3@P*3T^-S@X+&-H<B@Q.#$I/3XW.#@L8VAR*#$X,BD]/C<X
M."QC:'(H,3@S*3T^-S@X+&-H<B@Q.#0I/3XW.#@L8VAR*#$X-2D]/C<X."QC
M:'(H,3@V*3T^-S@X+&-H<B@Q.#<I/3XW.#@L8VAR*#$X."D]/C<X."QC:'(H
M,3@Y*3T^-S@X+&-H<B@Q.3`I/3XW.#@L8VAR*#$Y,2D]/C<X."QC:'(H,3DR
M*3T^-S@X+&-H<B@Q.3,I/3XW.#@L8VAR*#$Y-"D]/C<X."QC:'(H,3DU*3T^
M-S@X+&-H<B@Q.38I/3XW.#@L8VAR*#$Y-RD]/C<X."P*("`@(&-H<B@Q.3@I
M/3XW.#@L8VAR*#$Y.2D]/C<X."QC:'(H,C`P*3T^-S@X+&-H<B@R,#$I/3XW
M.#@L8VAR*#(P,BD]/C<X."QC:'(H,C`S*3T^-S@X+&-H<B@R,#0I/3XW.#@L
M8VAR*#(P-2D]/C<X."QC:'(H,C`V*3T^-S@X+&-H<B@R,#<I/3XW.#@L8VAR
M*#(P."D]/C<X."QC:'(H,C`Y*3T^-S@X+&-H<B@R,3`I/3XW.#@L8VAR*#(Q
M,2D]/C<X."QC:'(H,C$R*3T^.#DT+&-H<B@R,3,I/3XX,S@L8VAR*#(Q-"D]
M/C$P,38L8VAR*#(Q-2D]/C0U."QC:'(H,C$V*3T^-S0X+&-H<B@R,3<I/3XY
M,C0L8VAR*#(Q."D]/C<T."QC:'(H,C$Y*3T^.3$X+`H@("`@8VAR*#(R,"D]
M/CDR-RQC:'(H,C(Q*3T^.3(X+&-H<B@R,C(I/3XY,C@L8VAR*#(R,RD]/C@S
M-"QC:'(H,C(T*3T^.#<S+&-H<B@R,C4I/3XX,C@L8VAR*#(R-BD]/CDR-"QC
M:'(H,C(W*3T^.3(T+&-H<B@R,C@I/3XY,3<L8VAR*#(R.2D]/CDS,"QC:'(H
M,C,P*3T^.3,Q+&-H<B@R,S$I/3XT-C,L8VAR*#(S,BD]/C@X,RQC:'(H,C,S
M*3T^.#,V+&-H<B@R,S0I/3XX,S8L8VAR*#(S-2D]/C@V-RQC:'(H,C,V*3T^
M.#8W+&-H<B@R,S<I/3XV.38L8VAR*#(S."D]/C8Y-BQC:'(H,C,Y*3T^.#<T
M+&-H<B@R-#`I/3XP+&-H<B@R-#$I/3XX-S0L"B`@("!C:'(H,C0R*3T^-S8P
M+&-H<B@R-#,I/3XY-#8L8VAR*#(T-"D]/C<W,2QC:'(H,C0U*3T^.#8U+&-H
M<B@R-#8I/3XW-S$L8VAR*#(T-RD]/C@X."QC:'(H,C0X*3T^.38W+&-H<B@R
M-#DI/3XX.#@L8VAR*#(U,"D]/C@S,2QC:'(H,C4Q*3T^.#<S+&-H<B@R-3(I
M/3XY,C<L8VAR*#(U,RD]/CDW,"QC:'(H,C4T*3T^.3$X+&-H<B@R-34I/3XP
M*3L*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]&:6QE+U!$1BYP:'``````````
M````````````````````````````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`R-S(P,C<`,3`U
M,34T,S,W-#4`,#(P-#0P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B!&:6QE7U!$1CHZ"B`J"B`J(%1H
M92!&:6QE7U!$1CHZ(&-L87-S('!R;W9I9&5S(&$@4$A0+6]N;'D@:6UP;&5M
M96YT871I;VX@;V8@82!01$8@;&EB<F%R>2X*("H@3F\@97AT97)N86P@;&EB
M<R!O<B!02%`@97AT96YS:6]N<R!A<F4@<F5Q=6ER960N"B`J"B`J($)A<V5D
M(&]N('1H92!&4$1&(&-L87-S(&)Y($]L:79I97(@4&QA=&AE>2`H:'1T<#HO
M+W=W=RYF<&1F+F]R9RDN"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@3VQI
M=FEE<B!0;&%T:&5Y(#QO;&EV:65R0&9P9&8N;W)G/@H@*B!#;W!Y<FEG:'0@
M,C`P,RTR,#`V($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]&:6QE7U!$1B]01$8N
M<&AP+'8@,2XQ."XQ,"XQ,B`R,#`V+S`Q+S`Q(#(Q.C(X.C$U(&IA;B!%>'`@
M)`H@*@H@*B!`875T:&]R("!/;&EV:65R(%!L871H97D@/&]L:79I97)`9G!D
M9BYO<F<^"B`J($!A=71H;W(@($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC
M;VT^"B`J($!P86-K86=E($9I;&5?4$1&"B`J+PIC;&%S<R!&:6QE7U!$1B![
M"@H@("`@+RHJ"B`@("`@*B!#=7)R96YT('!A9V4@;G5M8F5R+@H@("`@("H*
M("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]P86=E(#T@
M,#L*"B`@("`O*BH*("`@("`J($-U<G)E;G0@;V)J96-T(&YU;6)E<BX*("`@
M("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?;B`]
M(#(["@H@("`@+RHJ"B`@("`@*B!!<G)A>2!O9B!O8FIE8W0@;V9F<V5T<RX*
M("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V]F
M9G-E=',@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0G5F9F5R(&AO;&1I
M;F<@:6XM;65M;W)Y(%!$1BX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)%]B=69F97(@/2`G)SL*"B`@("`O*BH*("`@("`J
M($%R<F%Y(&-O;G1A:6YI;F<@=&AE('!A9V5S+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%G97,@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@0W5R<F5N="!D;V-U;65N="!S=&%T92X*("`@("`J
M("`@,"`M(&EN:71I86P@<W1A=&4*("`@("`J("`@,2`M(&1O8W5M96YT(&]P
M96YE9`H@("`@("H@("`R("T@<&%G92!O<&5N960*("`@("`J("`@,R`M(&1O
M8W5M96YT(&-L;W-E9`H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@
M("HO"B`@("!V87(@)%]S=&%T92`](#`["@H@("`@+RHJ"B`@("`@*B!&;&%G
M(&EN9&EC871I;F<@:68@4$1&(&9I;&4@:7,@=&\@8F4@8V]M<')E<W-E9"!O
M<B!N;W0N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@
M('9A<B`D7V-O;7!R97-S.PH*("`@("\J*@H@("`@("H@5&AE(&1E9F%U;'0@
M<&%G92!O<FEE;G1A=&EO;BX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)%]D969A=6QT7V]R:65N=&%T:6]N.PH*("`@("\J
M*@H@("`@("H@5&AE(&-U<G)E;G0@<&%G92!O<FEE;G1A=&EO;BX*("`@("`J
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]C=7)R96YT
M7V]R:65N=&%T:6]N.PH*("`@("\J*@H@("`@("H@07)R87D@:6YD:6-A=&EN
M9R!O<FEE;G1A=&EO;B!C:&%N9V5S+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?;W)I96YT871I;VY?8VAA;F=E<R`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#=7)R96YT('=I9'1H(&]F('!A9V4@
M9F]R;6%T(&EN('!O:6YT<RX*("`@("`J"B`@("`@*B!`=F%R(&9L;V%T"B`@
M("`@*B\*("`@('9A<B`D9G=0=#L*"B`@("`O*BH*("`@("`J($-U<G)E;G0@
M:&5I9VAT(&]F('!A9V4@9F]R;6%T(&EN('!O:6YT<RX*("`@("`J"B`@("`@
M*B!`=F%R(&9L;V%T"B`@("`@*B\*("`@('9A<B`D9FA0=#L*"B`@("`O*BH*
M("`@("`J($-U<G)E;G0@=VED=&@@;V8@<&%G92!F;W)M870@:6X@=7-E<B!U
M;FET<RX*("`@("`J"B`@("`@*B!`=F%R(&9L;V%T"B`@("`@*B\*("`@('9A
M<B`D9G<["@H@("`@+RHJ"B`@("`@*B!#=7)R96YT(&AE:6=H="!O9B!P86=E
M(&9O<FUA="!I;B!U<V5R('5N:71S+@H@("`@("H*("`@("`J($!V87(@9FQO
M870*("`@("`J+PH@("`@=F%R("1F:#L*"B`@("`O*BH*("`@("`J($-U<G)E
M;G0@=VED=&@@;V8@<&%G92!I;B!P;VEN=',N"B`@("`@*@H@("`@("H@0'9A
M<B!F;&]A=`H@("`@("HO"B`@("!V87(@)'=0=#L*"B`@("`O*BH*("`@("`J
M($-U<G)E;G0@:&5I9VAT(&]F('!A9V4@:6X@<&]I;G1S+@H@("`@("H*("`@
M("`J($!V87(@9FQO870*("`@("`J+PH@("`@=F%R("1H4'0["@H@("`@+RHJ
M"B`@("`@*B!#=7)R96YT('=I9'1H(&]F('!A9V4@:6X@=7-E<B!U;FET<PH@
M("`@("H*("`@("`J($!V87(@9FQO870*("`@("`J+PH@("`@=F%R("1W.PH*
M("`@("\J*@H@("`@("H@0W5R<F5N="!H96EG:'0@;V8@<&%G92!I;B!U<V5R
M('5N:71S"B`@("`@*@H@("`@("H@0'9A<B!F;&]A=`H@("`@("HO"B`@("!V
M87(@)&@["@H@("`@+RHJ"B`@("`@*B!38V%L92!F86-T;W(@*&YU;6)E<B!O
M9B!P;VEN=',@:6X@=7-E<B!U;FET<RDN"B`@("`@*@H@("`@("H@0'9A<B!F
M;&]A=`H@("`@("HO"B`@("!V87(@)%]S8V%L93L*"B`@("`O*BH*("`@("`J
M($QE9G0@<&%G92!M87)G:6X@<VEZ92X*("`@("`J"B`@("`@*B!`=F%R(&9L
M;V%T"B`@("`@*B\*("`@('9A<B`D7VQE9G1?;6%R9VEN.PH*("`@("\J*@H@
M("`@("H@5&]P('!A9V4@;6%R9VEN('-I>F4N"B`@("`@*@H@("`@("H@0'9A
M<B!F;&]A=`H@("`@("HO"B`@("!V87(@)%]T;W!?;6%R9VEN.PH*("`@("\J
M*@H@("`@("H@4FEG:'0@<&%G92!M87)G:6X@<VEZ92X*("`@("`J"B`@("`@
M*B!`=F%R(&9L;V%T"B`@("`@*B\*("`@('9A<B`D7W)I9VAT7VUA<F=I;CL*
M"B`@("`O*BH*("`@("`J($)R96%K('!A9V4@;6%R9VEN('-I>F4L('1H92!B
M;W1T;VT@;6%R9VEN('=H:6-H('1R:6=G97)S(&$@<&%G92!B<F5A:RX*("`@
M("`J"B`@("`@*B!`=F%R(&9L;V%T"B`@("`@*B\*("`@('9A<B`D7V)R96%K
M7VUA<F=I;CL*"B`@("`O*BH*("`@("`J($-E;&P@;6%R9VEN('-I>F4N"B`@
M("`@*@H@("`@("H@0'9A<B!F;&]A=`H@("`@("HO"B`@("!V87(@)%]C96QL
M7VUA<F=I;CL*"B`@("`O*BH*("`@("`J(%1H92!C=7)R96YT(&AO<FEZ;VYT
M86P@<&]S:71I;VX@9F]R(&-E;&P@<&]S:71I;VYI;F<N"B`@("`@*B!686QU
M92!I<R!S970@:6X@=7-E<B!U;FET<R!A;F0@:7,@8V%L8W5L871E9"!F<F]M
M('1H92!T;W`@;&5F="!C;W)N97(*("`@("`J(&%S(&]R:6=I;BX*("`@("`J
M"B`@("`@*B!`=F%R(&9L;V%T"B`@("`@*B\*("`@('9A<B`D>#L*"B`@("`O
M*BH*("`@("`J(%1H92!C=7)R96YT('9E<G1I8V%L('!O<VET:6]N(&9O<B!C
M96QL('!O<VET:6]N:6YG+@H@("`@("H@5F%L=64@:7,@<V5T(&EN('5S97(@
M=6YI=',@86YD(&ES(&-A;&-U;&%T960@9G)O;2!T:&4@=&]P(&QE9G0@8V]R
M;F5R"B`@("`@*B!A<R!O<FEG:6XN"B`@("`@*@H@("`@("H@0'9A<B!F;&]A
M=`H@("`@("HO"B`@("!V87(@)'D["@H@("`@+RHJ"B`@("`@*B!4:&4@:&5I
M9VAT(&]F('1H92!L87-T(&-E;&P@<')I;G1E9"X*("`@("`J"B`@("`@*B!`
M=F%R(&9L;V%T"B`@("`@*B\*("`@('9A<B`D7VQA<W1?:&5I9VAT.PH*("`@
M("\J*@H@("`@("H@3&EN92!W:61T:"!I;B!U<V5R('5N:71S+@H@("`@("H*
M("`@("`J($!V87(@9FQO870*("`@("`J+PH@("`@=F%R("1?;&EN95]W:61T
M:#L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F('-T86YD87)D(&9O;G0@
M;F%M97,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)%]C;W)E7V9O;G1S(#T@87)R87DH)V-O=7)I97(G("`@("`@/3X@)T-O
M=7)I97(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C;W5R:65R
M0B<@("`@(#T^("=#;W5R:65R+4)O;&0G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=C;W5R:65R22<@("`@(#T^("=#;W5R:65R+4]B;&EQ=64G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C;W5R:65R0DDG("`@
M(#T^("=#;W5R:65R+4)O;&1/8FQI<75E)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G:&5L=F5T:6-A)R`@("`]/B`G2&5L=F5T:6-A)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G:&5L=F5T:6-A0B<@("`]/B`G
M2&5L=F5T:6-A+4)O;&0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=H96QV971I8V%))R`@(#T^("=(96QV971I8V$M3V)L:7%U92<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)VAE;'9E=&EC84)))R`@/3X@)TAE
M;'9E=&EC82U";VQD3V)L:7%U92<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W1I;65S)R`@("`@("`@/3X@)U1I;65S+5)O;6%N)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G=&EM97-")R`@("`@("`]/B`G5&EM
M97,M0F]L9"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1I;65S
M22<@("`@("`@/3X@)U1I;65S+4ET86QI8R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W1I;65S0DDG("`@("`@/3X@)U1I;65S+4)O;&1)=&%L
M:6,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S>6UB;VPG("`@
M("`@(#T^("=3>6UB;VPG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=Z87!F9&EN9V)A=',G(#T^("=:87!F1&EN9V)A=',G*3L*"B`@("`O*BH*
M("`@("`J($%N(&%R<F%Y(&]F('5S960@9F]N=',N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]F;VYT<R`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!F;VYT(&9I;&5S+@H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?9F]N=%]F
M:6QE<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!E
M;F-O9&EN9R!D:69F97)E;F-E<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D7V1I9F9S(#T@87)R87DH*3L*"B`@("`O*BH*
M("`@("`J($%N(&%R<F%Y(&]F('5S960@:6UA9V5S+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?:6UA9V5S(#T@87)R87DH
M*3L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F(&QI;FMS(&EN('!A9V5S
M+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M<&%G95]L:6YK<SL*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F(&EN=&5R
M;F%L(&QI;FMS+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1?;&EN:W,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0W5R
M<F5N="!F;VYT(&9A;6EL>2X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)%]F;VYT7V9A;6EL>2`]("<G.PH*("`@("\J*@H@
M("`@("H@0W5R<F5N="!F;VYT('-T>6QE+@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V9O;G1?<W1Y;&4@/2`G)SL*"B`@
M("`O*BH*("`@("`J(%5N9&5R;&EN:6YG(&9L86<N"B`@("`@*@H@("`@("H@
M0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7W5N9&5R;&EN92`](&9A
M;'-E.PH*("`@("\J*@H@("`@("H@06X@87)R87D@8V]N=&%I;FEN9R!C=7)R
M96YT(&9O;G0@:6YF;RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7V-U<G)E;G1?9F]N=#L*"B`@("`O*BH*("`@("`J($-U
M<G)E;G0@9F]N="!S:7IE(&EN('!O:6YT<RX*("`@("`J"B`@("`@*B!`=F%R
M(&9L;V%T"B`@("`@*B\*("`@('9A<B`D7V9O;G1?<VEZ95]P="`](#$R.PH*
M("`@("\J*@H@("`@("H@0W5R<F5N="!F;VYT('-I>F4@:6X@=7-E<B!U;FET
M<RX*("`@("`J"B`@("`@*B!`=F%R(&9L;V%T"B`@("`@*B\*("`@('9A<B`D
M7V9O;G1?<VEZ93L*"B`@("`O*BH*("`@("`J($-O;6UA;F1S(&9O<B!F:6QL
M:6YG(&-O;&]R+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7V9I;&Q?8V]L;W(@/2`G,"!G)SL*"B`@("`O*BH*("`@("`J
M($-O;6UA;F1S(&9O<B!D<F%W:6YG(&-O;&]R+@H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V1R87=?8V]L;W(@/2`G,"!'
M)SL*"B`@("`O*BH*("`@("`J(%=O<F0@<W!A8VEN9RX*("`@("`J"B`@("`@
M*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?=V]R9%]S<&%C:6YG
M(#T@,#L*"B`@("`O*BH*("`@("`J($%U=&]M871I8R!P86=E(&)R96%K:6YG
M+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@
M)%]A=71O7W!A9V5?8G)E86L["@H@("`@+RHJ"B`@("`@*B!4:')E<VAO;&0@
M=7-E9"!T;R!T<FEG9V5R('!A9V4@8G)E86MS+@H@("`@("H*("`@("`J($!V
M87(@9FQO870*("`@("`J+PH@("`@=F%R("1?<&%G95]B<F5A:U]T<FEG9V5R
M.PH*("`@("\J*@H@("`@("H@1FQA9R!S970@=VAE;B!P<F]C97-S:6YG(&9O
M;W1E<BX*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@
M=F%R("1?:6Y?9F]O=&5R(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!:;V]M
M(&1I<W!L87D@;6]D92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)%]Z;V]M7VUO9&4["@H@("`@+RHJ"B`@("`@*B!,87EO
M=70@9&ES<&QA>2!M;V1E+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7VQA>6]U=%]M;V1E.PH*("`@("\J*@H@("`@("H@
M06X@87)R87D@8V]N=&%I;FEN9R!T:&4@9&]C=6UE;G0@:6YF;RP@8V]N<VES
M=&EN9R!O9CH*("`@("`J("`@+2!T:71L90H@("`@("H@("`M('-U8FIE8W0*
M("`@("`J("`@+2!A=71H;W(*("`@("`J("`@+2!K97EW;W)D<PH@("`@("H@
M("`M(&-R96%T;W(*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D7VEN9F\@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@06QI
M87,@9F]R('1O=&%L(&YU;6)E<B!O9B!P86=E<RX*("`@("`J"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]A;&EA<U]N8E]P86=E<R`]
M("=[;F)])SL*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A
M(&-O;G)E=&4@4$1&(&EN<W1A;F-E+B!)="!A;&QO=W,@=&\@<V5T('5P('1H
M92!P86=E"B`@("`@*B!F;W)M870L('1H92!O<FEE;G1A=&EO;B!A;F0@=&AE
M('5N:71S(&]F(&UE87-U<F5M96YT('5S960@:6X@86QL('1H90H@("`@("H@
M;65T:&]D<R`H97AC97!T(&9O<B!T:&4@9F]N="!S:7IE<RDN"B`@("`@*@H@
M("`@("H@17AA;7!L93H\<')E/@H@("`@("H@)'!D9B`]("9&:6QE7U!$1CHZ
M9F%C=&]R>2AA<G)A>2@G;W)I96YT871I;VXG(#T^("=0)RP*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5N:70G(#T^("=M;2<L
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F;W)M
M870G(#T^("=!-"<I*3L\+W!R93X*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R`@02!H87-H('=I=&@@<&%R86UE=&5R<R!F;W(@=&AE(&-R
M96%T960@4$1&(&]B:F5C="X*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!0;W-S:6)L92!P87)A;65T97)S(&%R93H*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!O<FEE;G1A=&EO;B`M($1E9F%U;'0@<&%G92!O<FEE;G1A
M=&EO;BX@4&]S<VEB;&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!V
M86QU97,@87)E("AC87-E(&EN<V5N<VET:79E*3H*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`\<')E/@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@+2!0(&]R(%!O<G1R86ET("AD969A=6QT*0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@+2!,(&]R($QA;F1S8V%P90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(#PO<')E/@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@('5N:70@+2!5<V5R(&UE87-U<F4@=6YI=',N(%!O<W-I8FQE
M('9A;'5E<R!V86QU97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!A
M<F4Z"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@/'!R93X*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("T@<'0Z('!O:6YT"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`M(&UM.B!M:6QL:6UE=&5R("AD969A
M=6QT*0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2!C;3H@8V5N
M=&EM971E<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2!I;CH@
M:6YC:`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(#PO<')E/@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@($$@<&]I;G0@97%U86QS(#$O-S(@
M;V8@:6YC:"P@=&AA="!I<R!T;R!S87D@86)O=70*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`P+C,U(&UM("AA;B!I;F-H(&)E:6YG(#(N-30@8VTI
M+B!4:&ES(&ES(&$@=F5R>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M(&-O;6UO;B!U;FET(&EN('1Y<&]G<F%P:'D[(&9O;G0@<VEZ97,@87)E"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@97AP<F5S<V5D(&EN('1H870@
M=6YI="X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!F;W)M870@+2!4
M:&4@9F]R;6%T('5S960@9F]R('!A9V5S+B!)="!C86X@8F4*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!E:71H97(@;VYE(&]F('1H92!F;VQL;W=I
M;F<@=F%L=65S("AC87-E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M:6YS96YS:71I=F4I.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(#QP
M<F4^"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M($$S"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`M($$T("AD969A=6QT*0H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@+2!!-0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@+2!,971T97(*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("T@3&5G86P*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`\+W!R93X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!O<B!A
M(&-U<W1O;2!F;W)M870@:6X@=&AE(&9O<FT@;V8@82!T=V\M96QE;65N=`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y(&-O;G1A:6YI;F<@
M=&AE('=I9'1H(&%N9"!T:&4@:&5I9VAT"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@*&5X<')E<W-E9"!I;B!T:&4@=6YI="!G:79E;B!B>2!T:&4@
M=6YI=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E<BDN
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;&%S<R`@5&AE(&-O;F-R971E(&-L
M87-S(&YA;64@=&\@<F5T=7)N(&%N(&EN<W1A;F-E(&]F+@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@($1E9F%U;'1S('1O($9I;&5?4$1&+@H@("`@
M("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D<&%R86US(#T@87)R87DH*2P@
M)&-L87-S(#T@)T9I;&5?4$1&)RD*("`@('L*("`@("`@("`O*B!#:&5C:R!F
M;W(@4$A0(&QO8V%L92UR96QA=&5D(&)U9RX@*B\*("`@("`@("!I9B`H,2XQ
M(#T](#$I('L*("`@("`@("`@("`@<F5T=7)N($9I;&5?4$1&.CIR86ES945R
M<F]R*"=$;R!N;W0@86QT97(@=&AE(&QO8V%L92!B969O<F4@:6YC;'5D:6YG
M('1H92!C;&%S<R!F:6QE+B<I.PH@("`@("`@('T*"B`@("`@("`@+RH@1&5F
M875L="!P87)A;65T97)S+B`J+PH@("`@("`@("1D969A=6QT<R`](&%R<F%Y
M*"=O<FEE;G1A=&EO;B<@/3X@)U`G+"`G=6YI="<@/3X@)VUM)RP@)V9O<FUA
M="<@/3X@)T$T)RD["@H@("`@("`@("\J($)A8VMW87)D(&-O;7!A=&EB:6QI
M='D@=VET:"!O;&0@;65T:&]D('-I9VYA='5R92X@*B\*("`@("`@("`O*B!3
M:&]U;&0@8F4@<F5M;W9E9"!A(&9E=R!V97)S:6]N<R!L871E<BX@*B\*("`@
M("`@("!I9B`H(6ES7V%R<F%Y*"1P87)A;7,I*2!["B`@("`@("`@("`@("1C
M;&%S<R`]("=&:6QE7U!$1B<["B`@("`@("`@("`@("1P87)A;7,@/2`D9&5F
M875L=',["B`@("`@("`@("`@("1N86UE<R`](&%R<F%Y7VME>7,H)&1E9F%U
M;'1S*3L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@9G5N8U]N=6U?
M87)G<R@I.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D<&%R86US6R1N86UE
M<ULD:5U=(#T@9G5N8U]G971?87)G*"1I*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1P87)A;7,@/2!A<G)A>5]M97)G
M92@D9&5F875L=',L("1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@+RH@
M0W)E871E('1H92!01$8@;V)J96-T+B`J+PH@("`@("`@("1P9&8@/2`F;F5W
M("1C;&%S<R@I.PH*("`@("`@("`O*B!38V%L92!F86-T;W(N("HO"B`@("`@
M("`@:68@*"1P87)A;7-;)W5N:70G72`]/2`G<'0G*2!["B`@("`@("`@("`@
M("1P9&8M/E]S8V%L92`](#$["B`@("`@("`@?2!E;'-E:68@*"1P87)A;7-;
M)W5N:70G72`]/2`G;6TG*2!["B`@("`@("`@("`@("1P9&8M/E]S8V%L92`]
M(#<R("\@,C4N-#L*("`@("`@("!](&5L<V5I9B`H)'!A<F%M<ULG=6YI="==
M(#T]("=C;2<I('L*("`@("`@("`@("`@)'!D9BT^7W-C86QE(#T@-S(@+R`R
M+C4T.PH@("`@("`@('T@96QS96EF("@D<&%R86US6R=U;FET)UT@/3T@)VEN
M)RD@>PH@("`@("`@("`@("`D<&1F+3Y?<V-A;&4@/2`W,CL*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@1FEL95]01$8Z.G)A:7-E17)R
M;W(H<W!R:6YT9B@G26YC;W)R96-T('5N:71S.B`E<R<L("1P87)A;7-;)W5N
M:70G72DI.PH@("`@("`@('T*("`@("`@("`O*B!086=E(&9O<FUA="X@*B\*
M("`@("`@("!I9B`H:7-?<W1R:6YG*"1P87)A;7-;)V9O<FUA="==*2D@>PH@
M("`@("`@("`@("`D<&%R86US6R=F;W)M870G72`]('-T<G1O;&]W97(H)'!A
M<F%M<ULG9F]R;6%T)UTI.PH@("`@("`@("`@("!I9B`H)'!A<F%M<ULG9F]R
M;6%T)UT@/3T@)V$S)RD@>PH@("`@("`@("`@("`@("`@)'!A<F%M<ULG9F]R
M;6%T)UT@/2!A<G)A>2@X-#$N.#DL(#$Q.3`N-34I.PH@("`@("`@("`@("!]
M(&5L<V5I9B`H)'!A<F%M<ULG9F]R;6%T)UT@/3T@)V$T)RD@>PH@("`@("`@
M("`@("`@("`@)'!A<F%M<ULG9F]R;6%T)UT@/2!A<G)A>2@U.34N,C@L(#@T
M,2XX.2D["B`@("`@("`@("`@('T@96QS96EF("@D<&%R86US6R=F;W)M870G
M72`]/2`G834G*2!["B`@("`@("`@("`@("`@("`D<&%R86US6R=F;W)M870G
M72`](&%R<F%Y*#0R,"XY-"P@-3DU+C(X*3L*("`@("`@("`@("`@?2!E;'-E
M:68@*"1P87)A;7-;)V9O<FUA="==(#T]("=L971T97(G*2!["B`@("`@("`@
M("`@("`@("`D<&%R86US6R=F;W)M870G72`](&%R<F%Y*#8Q,BP@-SDR*3L*
M("`@("`@("`@("`@?2!E;'-E:68@*"1P87)A;7-;)V9O<FUA="==(#T]("=L
M96=A;"<I('L*("`@("`@("`@("`@("`@("1P87)A;7-;)V9O<FUA="==(#T@
M87)R87DH-C$R+"`Q,#`X*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@(')E='5R;B!&:6QE7U!$1CHZ<F%I<V5%<G)O<BAS<')I;G1F
M*"=5;FMN;W=N('!A9V4@9F]R;6%T.B`E<R<L("1P87)A;7-;)V9O<FUA="==
M*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'!D9BT^9G=0="`]("1P
M87)A;7-;)V9O<FUA="==6S!=.PH@("`@("`@("`@("`D<&1F+3YF:%!T(#T@
M)'!A<F%M<ULG9F]R;6%T)UU;,5T["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'!D9BT^9G=0="`]("1P87)A;7-;)V9O<FUA="==6S!=("H@)'!D
M9BT^7W-C86QE.PH@("`@("`@("`@("`D<&1F+3YF:%!T(#T@)'!A<F%M<ULG
M9F]R;6%T)UU;,5T@*B`D<&1F+3Y?<V-A;&4["B`@("`@("`@?0H@("`@("`@
M("1P9&8M/F9W(#T@)'!D9BT^9G=0="`O("1P9&8M/E]S8V%L93L*("`@("`@
M("`D<&1F+3YF:"`]("1P9&8M/F9H4'0@+R`D<&1F+3Y?<V-A;&4["@H@("`@
M("`@("\J(%!A9V4@;W)I96YT871I;VXN("HO"B`@("`@("`@)'!A<F%M<ULG
M;W)I96YT871I;VXG72`]('-T<G1O;&]W97(H)'!A<F%M<ULG;W)I96YT871I
M;VXG72D["B`@("`@("`@:68@*"1P87)A;7-;)V]R:65N=&%T:6]N)UT@/3T@
M)W`G('Q\("1P87)A;7-;)V]R:65N=&%T:6]N)UT@/3T@)W!O<G1R86ET)RD@
M>PH@("`@("`@("`@("`D<&1F+3Y?9&5F875L=%]O<FEE;G1A=&EO;B`]("=0
M)SL*("`@("`@("`@("`@)'!D9BT^=U!T(#T@)'!D9BT^9G=0=#L*("`@("`@
M("`@("`@)'!D9BT^:%!T(#T@)'!D9BT^9FA0=#L*("`@("`@("!](&5L<V5I
M9B`H)'!A<F%M<ULG;W)I96YT871I;VXG72`]/2`G;"<@?'P@)'!A<F%M<ULG
M;W)I96YT871I;VXG72`]/2`G;&%N9'-C87!E)RD@>PH@("`@("`@("`@("`D
M<&1F+3Y?9&5F875L=%]O<FEE;G1A=&EO;B`]("=,)SL*("`@("`@("`@("`@
M)'!D9BT^=U!T(#T@)'!D9BT^9FA0=#L*("`@("`@("`@("`@)'!D9BT^:%!T
M(#T@)'!D9BT^9G=0=#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@1FEL95]01$8Z.G)A:7-E17)R;W(H<W!R:6YT9B@G26YC;W)R96-T
M(&]R:65N=&%T:6]N.B`E<R<L("1P87)A;7-;)V]R:65N=&%T:6]N)UTI*3L*
M("`@("`@("!]"B`@("`@("`@)'!D9BT^7V-U<G)E;G1?;W)I96YT871I;VX@
M/2`D<&1F+3Y?9&5F875L=%]O<FEE;G1A=&EO;CL*("`@("`@("`D<&1F+3YW
M(#T@)'!D9BT^=U!T("\@)'!D9BT^7W-C86QE.PH@("`@("`@("1P9&8M/F@@
M/2`D<&1F+3YH4'0@+R`D<&1F+3Y?<V-A;&4["@H@("`@("`@("\J(%!A9V4@
M;6%R9VEN<R`H,2!C;2D@*B\*("`@("`@("`D;6%R9VEN(#T@,C@N,S4@+R`D
M<&1F+3Y?<V-A;&4["B`@("`@("`@)'!D9BT^<V5T36%R9VEN<R@D;6%R9VEN
M+"`D;6%R9VEN*3L*"B`@("`@("`@+RH@26YT97)I;W(@8V5L;"!M87)G:6X@
M*#$@;6TI("HO"B`@("`@("`@)'!D9BT^7V-E;&Q?;6%R9VEN(#T@)&UA<F=I
M;B`O(#$P.PH*("`@("`@("`O*B!,:6YE('=I9'1H("@P+C(@;6TI("HO"B`@
M("`@("`@)'!D9BT^7VQI;F5?=VED=&@@/2`N-38W("\@)'!D9BT^7W-C86QE
M.PH*("`@("`@("`O*B!!=71O;6%T:6,@<&%G92!B<F5A:R`J+PH@("`@("`@
M("1P9&8M/G-E=$%U=&]086=E0G)E86LH=')U92P@,B`J("1M87)G:6XI.PH*
M("`@("`@("`O*B!&=6QL('=I9'1H(&1I<W!L87D@;6]D92`J+PH@("`@("`@
M("1P9&8M/G-E=$1I<W!L87E-;V1E*"=F=6QL=VED=&@G*3L*"B`@("`@("`@
M+RH@0V]M<')E<W-I;VX@*B\*("`@("`@("`D<&1F+3YS971#;VUP<F5S<VEO
M;BAT<G5E*3L*"B`@("`@("`@<F5T=7)N("1P9&8["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS(&$@4$5!4E]%<G)O<B!O8FIE8W0N(%=R87!S(&%R
M;W5N9"!014%2.CIR86ES945R<F]R*"D@=&\*("`@("`J(&%V;VED(&AA=FEN
M9R!T;R!I;F-L=61E(%!%05(N<&AP('5N;&5S<R!A;B!E<G)O<B!O8V-U<G,N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1E<G)O<B`@5&AE(&5R<F]R
M(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@4$5!4E]%
M<G)O<@H@("`@("HO"B`@("!F=6YC=&EO;B!R86ES945R<F]R*"1E<G)O<BD*
M("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D97)R;W(I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1&5F:6YE<R!T:&4@;&5F="P@=&]P(&%N9"!R:6=H="!M
M87)G:6YS+B!">2!D969A=6QT+"!T:&5Y(&5Q=6%L"B`@("`@*B`Q(&-M+B`@
M0V%L;"!T:&ES(&UE=&AO9"!T;R!C:&%N9V4@=&AE;2X*("`@("`J"B`@("`@
M*B!`<&%R86T@9FQO870@)&QE9G0@("!,969T(&UA<F=I;BX*("`@("`J($!P
M87)A;2!F;&]A="`D=&]P("`@(%1O<"!M87)G:6XN"B`@("`@*B!`<&%R86T@
M9FQO870@)')I9VAT("!2:6=H="!M87)G:6XN($EF(&YO="!S<&5C:69I960@
M9&5F875L="!T;R!T:&4@=F%L=64*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@(&]F('1H92!L969T(&]N92X*("`@("`J"B`@("`@*B!`<V5E($9I;&5?
M4$1&.CIS971!=71O4&%G94)R96%K"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS
M971,969T36%R9VEN"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS9712:6=H=$UA
M<F=I;@H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T5&]P36%R9VEN"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=$UA<F=I;G,H)&QE9G0L("1T;W`L("1R:6=H
M="`](&YU;&PI"B`@("!["B`@("`@("`@+RH@4V5T(&QE9G0@86YD('1O<"!M
M87)G:6YS+B`J+PH@("`@("`@("1T:&ES+3Y?;&5F=%]M87)G:6X@(#T@)&QE
M9G0["B`@("`@("`@)'1H:7,M/E]T;W!?;6%R9VEN("`@/2`D=&]P.PH@("`@
M("`@("\J($EF(&YO(')I9VAT(&UA<F=I;B!S970@9&5F875L="!T;R!S86UE
M(&%S(&QE9G0N("HO"B`@("`@("`@)'1H:7,M/E]R:6=H=%]M87)G:6X@/2`H
M:7-?;G5L;"@D<FEG:'0I(#\@)&QE9G0@.B`D<FEG:'0I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1&5F:6YE<R!T:&4@;&5F="!M87)G:6XN(%1H92!M971H
M;V0@8V%N(&)E(&-A;&QE9"!B969O<F4@8W)E871I;F<@=&AE"B`@("`@*B!F
M:7)S="!P86=E+@H@("`@("H@268@=&AE(&-U<G)E;G0@86)S8VES<V$@9V5T
M<R!O=70@;V8@<&%G92P@:70@:7,@8G)O=6=H="!B86-K('1O('1H90H@("`@
M("H@;6%R9VEN+@H@("`@("H*("`@("`J($!P87)A;2!F;&]A="`D;6%R9VEN
M("`@5&AE(&UA<F=I;BX*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS
M971!=71O4&%G94)R96%K"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS971-87)G
M:6YS"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS9712:6=H=$UA<F=I;@H@("`@
M("H@0'-E92!&:6QE7U!$1CHZ<V5T5&]P36%R9VEN"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E=$QE9G1-87)G:6XH)&UA<F=I;BD*("`@('L*("`@("`@("`D
M=&AI<RT^7VQE9G1?;6%R9VEN(#T@)&UA<F=I;CL*("`@("`@("`O*B!)9B!T
M:&5R92!I<R!A(&-U<G)E;G0@<&%G92!A;F0@=&AE(&-U<G)E;G0@6"!P;W-I
M=&EO;B!I<R!L97-S('1H86X*("`@("`@("`@*B!M87)G:6X@<V5T('1H92!8
M('!O<VET:6]N('1O('1H92!M87)G:6X@=F%L=64N("HO"B`@("`@("`@:68@
M*"1T:&ES+3Y?<&%G92`^(#`@)B8@)'1H:7,M/G@@/"`D;6%R9VEN*2!["B`@
M("`@("`@("`@("1T:&ES+3YX(#T@)&UA<F=I;CL*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$969I;F5S('1H92!T;W`@;6%R9VEN+B!4:&4@
M;65T:&]D(&-A;B!B92!C86QL960@8F5F;W)E(&-R96%T:6YG('1H90H@("`@
M("H@9FER<W0@<&%G92X*("`@("`J"B`@("`@*B!`<&%R86T@9FQO870@)&UA
M<F=I;B`@5&AE(&UA<F=I;BX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T5&]P
M36%R9VEN*"1M87)G:6XI"B`@("!["B`@("`@("`@)'1H:7,M/E]T;W!?;6%R
M9VEN(#T@)&UA<F=I;CL*("`@('T*"B`@("`O*BH*("`@("`J($1E9FEN97,@
M=&AE(')I9VAT(&UA<F=I;BX@5&AE(&UE=&AO9"!C86X@8F4@8V%L;&5D(&)E
M9F]R92!C<F5A=&EN9R!T:&4*("`@("`J(&9I<G-T('!A9V4N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&9L;V%T("1M87)G:6X@(%1H92!M87)G:6XN"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=%)I9VAT36%R9VEN*"1M87)G:6XI"B`@("![
M"B`@("`@("`@)'1H:7,M/E]R:6=H=%]M87)G:6X@/2`D;6%R9VEN.PH@("`@
M?0H*("`@("\J*@H@("`@("H@16YA8FQE<R!O<B!D:7-A8FQE<R!T:&4@875T
M;VUA=&EC('!A9V4@8G)E86MI;F<@;6]D92X@5VAE;B!E;F%B;&EN9RP*("`@
M("`J('1H92!S96-O;F0@<&%R86UE=&5R(&ES('1H92!D:7-T86YC92!F<F]M
M('1H92!B;W1T;VT@;V8@=&AE('!A9V4@=&AA=`H@("`@("H@9&5F:6YE<R!T
M:&4@=')I9V=E<FEN9R!L:6UI="X@0GD@9&5F875L="P@=&AE(&UO9&4@:7,@
M;VX@86YD('1H92!M87)G:6X*("`@("`J(&ES(#(@8VTN"B`@("`@*@H@("`@
M("H@0'!A<F%M(&)O;VQE86X@875T;R`@($)O;VQE86X@:6YD:6-A=&EN9R!I
M9B!M;V1E('-H;W5L9"!B92!O;B!O<B!O9F8N"B`@("`@*B!`<&%R86T@9FQO
M870@)&UA<F=I;B`@1&ES=&%N8V4@9G)O;2!T:&4@8F]T=&]M(&]F('1H92!P
M86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971!=71O4&%G94)R96%K*"1A
M=71O+"`D;6%R9VEN(#T@,"D*("`@('L*("`@("`@("`D=&AI<RT^7V%U=&]?
M<&%G95]B<F5A:R`@("`]("1A=71O.PH@("`@("`@("1T:&ES+3Y?8G)E86M?
M;6%R9VEN("`@("`@(#T@)&UA<F=I;CL*("`@("`@("`D=&AI<RT^7W!A9V5?
M8G)E86M?=')I9V=E<B`]("1T:&ES+3YH("T@)&UA<F=I;CL*("`@('T*"B`@
M("`O*BH*("`@("`J($1E9FEN97,@=&AE('=A>2!T:&4@9&]C=6UE;G0@:7,@
M=&\@8F4@9&ES<&QA>65D(&)Y('1H92!V:65W97(N(%1H92!Z;V]M"B`@("`@
M*B!L979E;"!C86X@8F4@<V5T.B!P86=E<R!C86X@8F4@9&ES<&QA>65D(&5N
M=&ER96QY(&]N('-C<F5E;BP@;V-C=7!Y('1H90H@("`@("H@9G5L;"!W:61T
M:"!O9B!T:&4@=VEN9&]W+"!U<V4@<F5A;"!S:7IE+"!B92!S8V%L960@8GD@
M82!S<&5C:69I8PH@("`@("H@>F]O;6EN9R!F86-T;W(@;W(@=7-E('9I97=E
M<B!D969A=6QT("AC;VYF:6=U<F5D(&EN('1H92!0<F5F97)E;F-E<PH@("`@
M("H@;65N=2!O9B!!8W)O8F%T*2X@5&AE('!A9V4@;&%Y;W5T(&-A;B!B92!S
M<&5C:69I960@=&]O.B!S:6YG;&4@870@;VYC92P*("`@("`J(&-O;G1I;G5O
M=7,@9&ES<&QA>2P@='=O(&-O;'5M;G,@;W(@=FEE=V5R(&1E9F%U;'0N"B`@
M("`@*B!">2!D969A=6QT+"!D;V-U;65N=',@=7-E('1H92!F=6QL('=I9'1H
M(&UO9&4@=VET:"!C;VYT:6YU;W5S(&1I<W!L87DN"B`@("`@*@H@("`@("H@
M0'!A<F%M(&UI>&5D("1Z;V]M("`@("`@("`@("`@(%1H92!Z;V]M('1O('5S
M92X@270@8V%N(&)E(&]N92!O9B!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!F;VQL;W=I;F<@<W1R:6YG('9A;'5E<SH*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("T@9G5L;'!A
M9V4Z(&5N=&ER92!P86=E(&]N('-C<F5E;@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+2!F=6QL=VED=&@Z(&UA>&EM=6T@=VED
M=&@@;V8@=VEN9&]W"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`M(')E86PZ('5S97,@<F5A;"!S:7IE("@Q,#`E('IO;VTI"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`M(&1E9F%U
M;'0Z('5S97,@=FEE=V5R(&1E9F%U;'0@;6]D90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&]R(&$@;G5M8F5R(&EN9&EC871I;F<@
M=&AE('IO;VUI;F<@9F%C=&]R+@H@("`@("H@0'!A<F%M('-T<FEN9R!L87EO
M=70@(%1H92!P86=E(&QA>6]U="X@4&]S<VEB;&4@=F%L=65S(&%R93H*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@<VEN9VQE.B!O;F4@<&%G
M92!A="!O;F-E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M(&-O
M;G1I;G5O=7,Z('!A9V5S(&EN(&-O;G1I;G5O=7-L>0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@+2!T=V\Z('1W;R!P86=E<R!O;B!T=V\@8V]L
M=6UN<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2!D969A=6QT
M.B!U<V5S('9I97=E<B!D969A=6QT(&UO9&4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@($1E9F%U;'0@=F%L=64@:7,@8V]N=&EN=6]U<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T1&ES<&QA>4UO9&4H)'IO;VTL("1L87EO
M=70@/2`G8V]N=&EN=6]U<R<I"B`@("!["B`@("`@("`@)'IO;VT@/2!S=')T
M;VQO=V5R*"1Z;V]M*3L*("`@("`@("!I9B`H)'IO;VT@/3T@)V9U;&QP86=E
M)R!\?"`D>F]O;2`]/2`G9G5L;'=I9'1H)R!\?"`D>F]O;2`]/2`G<F5A;"<*
M("`@("`@("`@("`@?'P@)'IO;VT@/3T@)V1E9F%U;'0G('Q\("%I<U]S=')I
M;F<H)'IO;VTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?>F]O;5]M;V1E(#T@
M)'IO;VT["B`@("`@("`@?2!E;'-E:68@*"1Z;V]M(#T]("=Z;V]M)RD@>PH@
M("`@("`@("`@("`D=&AI<RT^7WIO;VU?;6]D92`]("1L87EO=70["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*'-P<FEN=&8H)TEN8V]R<F5C="!Z;V]M(&1I<W!L87D@;6]D93H@)7,G
M+"`D>F]O;2DI.PH@("`@("`@('T*"B`@("`@("`@)&QA>6]U="`]('-T<G1O
M;&]W97(H)&QA>6]U="D["B`@("`@("`@:68@*"1L87EO=70@/3T@)W-I;F=L
M92<@?'P@)&QA>6]U="`]/2`G8V]N=&EN=6]U<R<@?'P@)&QA>6]U="`]/2`G
M='=O)PH@("`@("`@("`@("!\?"`D;&%Y;W5T(#T]("=D969A=6QT)RD@>PH@
M("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%]M;V1E(#T@)&QA>6]U=#L*("`@
M("`@("!](&5L<V5I9B`H)'IO;VT@(3T@)WIO;VTG*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAS<')I;G1F*"=);F-O<G)E8W0@
M;&%Y;W5T(&1I<W!L87D@;6]D93H@)7,G+"`D;&%Y;W5T*2D["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@06-T:79A=&5S(&]R(&1E86-T:79A
M=&5S('!A9V4@8V]M<')E<W-I;VXN(%=H96X@86-T:79A=&5D+"!T:&4@:6YT
M97)N86P*("`@("`J(')E<')E<V5N=&%T:6]N(&]F(&5A8V@@<&%G92!I<R!C
M;VUP<F5S<V5D+"!W:&EC:"!L96%D<R!T;R!A(&-O;7!R97-S:6]N"B`@("`@
M*B!R871I;R!O9B!A8F]U="`R(&9O<B!T:&4@<F5S=6QT:6YG(&1O8W5M96YT
M+@H@("`@("H@0V]M<')E<W-I;VX@:7,@;VX@8GD@9&5F875L="X*("`@("`J
M($YO=&4Z('1H92!:;&EB(&5X=&5N<VEO;B!I<R!R97%U:7)E9"!F;W(@=&AI
M<R!F96%T=7)E+B!)9B!N;W0@<')E<V5N="P*("`@("`J(&-O;7!R97-S:6]N
M('=I;&P@8F4@='5R;F5D(&]F9BX*("`@("`J"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D8V]M<')E<W,@($)O;VQE86X@:6YD:6-A=&EN9R!I9B!C;VUP<F5S
M<VEO;B!M=7-T(&)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&5N86)L960@;W(@;F]T+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971#;VUP
M<F5S<VEO;B@D8V]M<')E<W,I"B`@("!["B`@("`@("`@+RH@268@;F\@9WIC
M;VUP<F5S<R!F=6YC=&EO;B!I<R!A=F%I;&%B;&4@=&AE;B!D969A=6QT('1O
M(&9A;'-E+B`J+PH@("`@("`@("1T:&ES+3Y?8V]M<')E<W,@/2`H9G5N8W1I
M;VY?97AI<W1S*"=G>F-O;7!R97-S)RD@/R`D8V]M<')E<W,@.B!F86QS92D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&EN9F\@=&\@82!D;V-U
M;65N="X@4&]S<VEB;&4@:6YF;R!S971T:6YG<R!A<F4Z"B`@("`@*B`@("T@
M=&ET;&4*("`@("`J("`@+2!S=6)J96-T"B`@("`@*B`@("T@875T:&]R"B`@
M("`@*B`@("T@:V5Y=V]R9',*("`@("`J("`@+2!C<F5A=&]R"B`@("`@*@H@
M("`@("H@0'!A<F%M(&UI>&5D("1I;F9O("`@($EF('!A<W-E9"!A<R!A;B!A
M<G)A>2!T:&5N('1H92!C;VUP;&5T92!H87-H"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@8V]N=&%I;FEN9R!T:&4@:6YF;R!T;R!B92!I;G-E<G1E
M9"!I;G1O('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&1O8W5M
M96YT+B!/=&AE<G=I<V4@=&AE(&YA;64@;V8@<V5T=&EN9R!T;R!B92!S970N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU92`@5&AE('9A;'5E(&]F('1H
M92!S971T:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971);F9O*"1I;F9O
M+"`D=F%L=64@/2`G)RD*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)&EN
M9F\I*2!["B`@("`@("`@("`@("1T:&ES+3Y?:6YF;R`]("1I;F9O.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?:6YF;ULD:6YF;UT@
M/2`D=F%L=64["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5F
M:6YE<R!A;B!A;&EA<R!F;W(@=&AE('1O=&%L(&YU;6)E<B!O9B!P86=E<RX@
M270@=VEL;"!B92!S=6)S=&ET=71E9`H@("`@("H@87,@=&AE(&1O8W5M96YT
M(&ES(&-L;W-E9"X*("`@("`J"B`@("`@*B!%>&%M<&QE.@H@("`@("H@8VQA
M<W,@37E?1FEL95]01$8@97AT96YD<R!&:6QE7U!$1B!["B`@("`@*B`@("`@
M9G5N8W1I;VX@9F]O=&5R*"D*("`@("`J("`@("!["B`@("`@*B`@("`@("`@
M("\O($=O('1O(#$N-2!C;2!F<F]M(&)O='1O;0H@("`@("H@("`@("`@("`D
M=&AI<RT^<V5T62@M,34I.PH@("`@("H@("`@("`@("`O+R!396QE8W0@07)I
M86P@:71A;&EC(#@*("`@("`J("`@("`@("`@)'1H:7,M/G-E=$9O;G0H)T%R
M:6%L)RP@)TDG+"`X*3L*("`@("`J("`@("`@("`@+R\@4')I;G0@8W5R<F5N
M="!A;F0@=&]T86P@<&%G92!N=6UB97)S"B`@("`@*B`@("`@("`@("1T:&ES
M+3YC96QL*#`L(#$P+"`G4&%G92`G("X@)'1H:7,M/F=E=%!A9V5.;R@I("X@
M)R][;F)])RP@,"P*("`@("`J("`@("`@("`@("`@("`@("`@("`@,"P@)T,G
M*3L*("`@("`J("`@("!]"B`@("`@*B!]"B`@("`@*B`D<&1F(#T@)DUY7T9I
M;&5?4$1&.CIF86-T;W)Y*"D["B`@("`@*B`D<&1F+3YA;&EA<TYB4&%G97,H
M*3L*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A;&EA<R`@5&AE(&%L
M:6%S+B!$969A=6QT('9A;'5E.B![;F)]+@H@("`@("H*("`@("`J($!S964@
M1FEL95]01$8Z.F=E=%!A9V5.;PH@("`@("H@0'-E92!&:6QE7U!$1CHZ9F]O
M=&5R"B`@("`@*B\*("`@(&9U;F-T:6]N(&%L:6%S3F)086=E<R@D86QI87,@
M/2`G>VYB?2<I"B`@("!["B`@("`@("`@)'1H:7,M/E]A;&EA<U]N8E]P86=E
M<R`]("1A;&EA<SL*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@;65T:&]D
M(&)E9VEN<R!T:&4@9V5N97)A=&EO;B!O9B!T:&4@4$1&(&1O8W5M96YT.R!I
M="!M=7-T(&)E"B`@("`@*B!C86QL960@8F5F;W)E(&%N>2!O=71P=70@8V]M
M;6%N9',N($YO('!A9V4@:7,@8W)E871E9"!B>2!T:&ES(&UE=&AO9"P*("`@
M("`J('1H97)E9F]R92!I="!I<R!N96-E<W-A<GD@=&\@8V%L;"!&:6QE7U!$
M1CHZ861D4&%G92X*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIA9&10
M86=E"B`@("`@*B!`<V5E($9I;&5?4$1&.CIC;&]S90H@("`@("HO"B`@("!F
M=6YC=&EO;B!O<&5N*"D*("`@('L*("`@("`@("`D=&AI<RT^7V)E9VEN1&]C
M*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!497)M:6YA=&5S('1H92!01$8@
M9&]C=6UE;G0N($ET(&ES(&YO="!N96-E<W-A<GD@=&\@8V%L;"!T:&ES(&UE
M=&AO9`H@("`@("H@97AP;&EC:71L>2!B96-A=7-E($9I;&5?4$1&.CIO=71P
M=70@9&]E<R!I="!A=71O;6%T:6-A;&QY+@H@("`@("H@268@=&AE(&1O8W5M
M96YT(&-O;G1A:6YS(&YO('!A9V4L($9I;&5?4$1&.CIA9&1086=E(&ES(&-A
M;&QE9"!T;R!P<F5V96YT"B`@("`@*B!F<F]M(&=E='1I;F<@86X@:6YV86QI
M9"!D;V-U;65N="X*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIO<&5N
M"B`@("`@*B!`<V5E($9I;&5?4$1&.CIO=71P=70*("`@("`J+PH@("`@9G5N
M8W1I;VX@8VQO<V4H*0H@("`@>PH@("`@("`@("\J(%1E<FUI;F%T92!D;V-U
M;65N="`J+PH@("`@("`@(&EF("@D=&AI<RT^7W!A9V4@/3T@,"D@>PH@("`@
M("`@("`@("`D=&AI<RT^861D4&%G92@I.PH@("`@("`@('T*("`@("`@("`O
M*B!086=E(&9O;W1E<B`J+PH@("`@("`@("1T:&ES+3Y?:6Y?9F]O=&5R(#T@
M=')U93L*("`@("`@("`D=&AI<RT^9F]O=&5R*"D["B`@("`@("`@)'1H:7,M
M/E]I;E]F;V]T97(@/2!F86QS93L*("`@("`@("`O*B!#;&]S92!P86=E("HO
M"B`@("`@("`@)'1H:7,M/E]E;F1086=E*"D["B`@("`@("`@+RH@0VQO<V4@
M9&]C=6UE;G0@*B\*("`@("`@("`D=&AI<RT^7V5N9$1O8R@I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@061D<R!A(&YE=R!P86=E('1O('1H92!D;V-U;65N
M="X@268@82!P86=E(&ES(&%L<F5A9'D@<')E<V5N="P@=&AE"B`@("`@*B!&
M:6QE7U!$1CHZ9F]O=&5R(&UE=&AO9"!I<R!C86QL960@9FER<W0@=&\@;W5T
M<'5T('1H92!F;V]T97(N(%1H96X@=&AE"B`@("`@*B!P86=E(&ES(&%D9&5D
M+"!T:&4@8W5R<F5N="!P;W-I=&EO;B!S970@=&\@=&AE('1O<"UL969T(&-O
M<FYE<B!A8V-O<F1I;F<*("`@("`J('1O('1H92!L969T(&%N9"!T;W`@;6%R
M9VEN<RP@86YD($9I;&5?4$1&.CIH96%D97(@:7,@8V%L;&5D('1O(&1I<W!L
M87D*("`@("`J('1H92!H96%D97(N"B`@("`@*B!4:&4@9F]N="!W:&EC:"!W
M87,@<V5T(&)E9F]R92!C86QL:6YG(&ES(&%U=&]M871I8V%L;'D@<F5S=&]R
M960N(%1H97)E"B`@("`@*B!I<R!N;R!N965D('1O(&-A;&P@1FEL95]01$8Z
M.G-E=$9O;G0@86=A:6X@:68@>6]U('=A;G0@=&\@8V]N=&EN=64@=VET:`H@
M("`@("H@=&AE('-A;64@9F]N="X@5&AE('-A;64@:7,@=')U92!F;W(@8V]L
M;W)S(&%N9"!L:6YE('=I9'1H+@H@("`@("H@5&AE(&]R:6=I;B!O9B!T:&4@
M8V]O<F1I;F%T92!S>7-T96T@:7,@870@=&AE('1O<"UL969T(&-O<FYE<B!A
M;F0*("`@("`J(&EN8W)E87-I;F<@;W)D:6YA=&5S(&=O(&1O=VYW87)D<RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O<FEE;G1A=&EO;B`@4&%G
M92!O<FEE;G1A=&EO;BX@4&]S<VEB;&4@=F%L=65S"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)E("AC87-E(&EN<V5N<VET:79E*3H*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("T@4"!O<B!0
M;W)T<F%I=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+2!,(&]R($QA;F1S8V%P90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%1H92!D969A=6QT('9A;'5E(&ES('1H92!O;F4@<&%S<V5D('1O
M('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G-T
M<G5C=&]R+@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.E!$1@H@("`@
M("H@0'-E92!&:6QE7U!$1CHZ:&5A9&5R"B`@("`@*B!`<V5E($9I;&5?4$1&
M.CIF;V]T97(*("`@("`J($!S964@1FEL95]01$8Z.G-E=$UA<F=I;G,*("`@
M("`J+PH@("`@9G5N8W1I;VX@861D4&%G92@D;W)I96YT871I;VX@/2`G)RD*
M("`@('L*("`@("`@("`O*B!&;W(@9V]O9"!M96%S=7)E(&UA:V4@<W5R92!T
M:&ES(&ES(&-A;&QE9"X@*B\*("`@("`@("`D=&AI<RT^7V)E9VEN1&]C*"D[
M"@H@("`@("`@("\J(%-A=F4@<W1Y;&4@<V5T=&EN9W,@<V\@=&AA="!T:&5Y
M(&%R92!N;W0@;W9E<G)I9&1E;B!B>0H@("`@("`@("`J(&AE861E<B@I+B`J
M+PH@("`@("`@("1L=R`]("1T:&ES+3Y?;&EN95]W:61T:#L*("`@("`@("`D
M9&,@/2`D=&AI<RT^7V1R87=?8V]L;W(["B`@("`@("`@)&9C(#T@)'1H:7,M
M/E]F:6QL7V-O;&]R.PH@("`@("`@(&EF("@D=&AI<RT^7W!A9V4@/B`P*2![
M"B`@("`@("`@("`@("\J(%!A9V4@9F]O=&5R+B`J+PH@("`@("`@("`@("`D
M=&AI<RT^7VEN7V9O;W1E<B`]('1R=64["B`@("`@("`@("`@("1T:&ES+3YF
M;V]T97(H*3L*("`@("`@("`@("`@)'1H:7,M/E]I;E]F;V]T97(@/2!F86QS
M93L*("`@("`@("`@("`@+RH@0VQO<V4@<&%G92X@*B\*("`@("`@("`@("`@
M)'1H:7,M/E]E;F1086=E*"D["B`@("`@("`@?0H@("`@("`@("\J(%-T87)T
M(&YE=R!P86=E+B`J+PH@("`@("`@("1T:&ES+3Y?8F5G:6Y086=E*"1O<FEE
M;G1A=&EO;BD["B`@("`@("`@+RH@4V5T(&QI;F4@8V%P('-T>6QE('1O('-Q
M=6%R92X@*B\*("`@("`@("`D=&AI<RT^7V]U="@G,B!*)RD["B`@("`@("`@
M+RH@4V5T(&QI;F4@=VED=&@N("HO"B`@("`@("`@)'1H:7,M/E]L:6YE7W=I
M9'1H(#T@)&QW.PH@("`@("`@("1T:&ES+3Y?;W5T*'-P<FEN=&8H)R4N,F8@
M=R<L("1L=R`J("1T:&ES+3Y?<V-A;&4I*3L*("`@("`@("`O*B!3970@9F]N
M="!F;W(@=&AE(&)E9VEN;FEN9R!O9B!T:&4@<&%G92X@*B\*("`@("`@("!I
M9B`H)'1H:7,M/E]F;VYT7V9A;6EL>2D@>PH@("`@("`@("`@("`D=&AI<RT^
M<V5T1F]N="@D=&AI<RT^7V9O;G1?9F%M:6QY+"`D<W1Y;&4L("1T:&ES+3Y?
M9F]N=%]S:7IE7W!T*3L*("`@("`@("`@("`@)&9O;G1?9F%M:6QY(#T@)'1H
M:7,M/E]F;VYT7V9A;6EL>3L*("`@("`@("`@("`@)&9O;G1?<W1Y;&4@/2`D
M=&AI<RT^7V9O;G1?<W1Y;&4@+B`H)'1H:7,M/E]U;F1E<FQI;F4@/R`G52<@
M.B`G)RD["B`@("`@("`@("`@("1F;VYT7W-I>F4@(#T@)'1H:7,M/E]F;VYT
M7W-I>F5?<'0["B`@("`@("`@?0H@("`@("`@("\J(%-E="!C;VQO<G,N("HO
M"B`@("`@("`@)'1H:7,M/E]F:6QL7V-O;&]R(#T@)&9C.PH@("`@("`@("\J
M($-H96-K(&EF(&9I;&P@8V]L;W(@:&%S(&)E96X@<V5T(&)E9F]R92!T:&ES
M('!A9V4N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?9FEL;%]C;VQO<B`A/2`G
M,"!G)RD@>PH@("`@("`@("`@("`D=&AI<RT^7V]U="@D=&AI<RT^7V9I;&Q?
M8V]L;W(I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7V1R87=?8V]L;W(@
M/2`D9&,["B`@("`@("`@+RH@0VAE8VL@:68@9')A=R!C;VQO<B!H87,@8F5E
M;B!S970@8F5F;W)E('1H:7,@<&%G92X@*B\*("`@("`@("!I9B`H)'1H:7,M
M/E]D<F%W7V-O;&]R("$]("<P($<G*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M;W5T*"1T:&ES+3Y?9')A=U]C;VQO<BD["B`@("`@("`@?0H@("`@("`@("\J
M(%!A9V4@:&5A9&5R+B`J+PH@("`@("`@("1T:&ES+3YH96%D97(H*3L*("`@
M("`@("`O*B!297-T;W)E(&QI;F4@=VED=&@N("HO"B`@("`@("`@:68@*"1T
M:&ES+3Y?;&EN95]W:61T:"`A/2`D;'<I('L*("`@("`@("`@("`@)'1H:7,M
M/E]L:6YE7W=I9'1H(#T@)&QW.PH@("`@("`@("`@("`D=&AI<RT^7V]U="AS
M<')I;G1F*"<E+C)F('<G+"`D;'<@*B`D=&AI<RT^7W-C86QE*2D["B`@("`@
M("`@?0H@("`@("`@("\J($UA:V4@<W5R92!T:&4@9F]N="!I<R!S970@9F]R
M('1H:7,@<&%G92!A<R!I="!W87,@8F5F;W)E('1H90H@("`@("`@("`J(&AE
M861E<BX@*B\*("`@("`@("!I9B`H)&9O;G1?9F%M:6QY*2!["B`@("`@("`@
M("`@("1T:&ES+3YS971&;VYT*"1F;VYT7V9A;6EL>2P@)&9O;G1?<W1Y;&4L
M("1F;VYT7W-I>F4L('1R=64I.PH@("`@("`@('T*("`@("`@("`O*B!297-T
M;W)E(&-O;&]R<RX@*B\*("`@("`@("!I9B`H)'1H:7,M/E]D<F%W7V-O;&]R
M("$]("1D8RD@>PH@("`@("`@("`@("`D=&AI<RT^7V1R87=?8V]L;W(@/2`D
M9&,["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"1D8RD["B`@("`@("`@?0H@
M("`@("`@(&EF("@D=&AI<RT^7V9I;&Q?8V]L;W(@(3T@)&9C*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?9FEL;%]C;VQO<B`]("1F8SL*("`@("`@("`@("`@
M)'1H:7,M/E]O=70H)&9C*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!4:&ES(&UE=&AO9"!I<R!U<V5D('1O(')E;F1E<B!T:&4@<&%G92!H
M96%D97(N($ET(&ES(&%U=&]M871I8V%L;'D*("`@("`J(&-A;&QE9"!B>2!&
M:6QE7U!$1CHZ861D4&%G92!A;F0@<VAO=6QD(&YO="!B92!C86QL960@9&ER
M96-T;'D@8GD@=&AE"B`@("`@*B!A<'!L:6-A=&EO;BX@5&AE(&EM<&QE;65N
M=&%T:6]N(&EN($9I;&5?4$1&.CH@:7,@96UP='DL('-O('EO=2!H879E('1O
M"B`@("`@*B!S=6)C;&%S<R!I="!A;F0@;W9E<G)I9&4@=&AE(&UE=&AO9"!I
M9B!Y;W4@=V%N="!A('-P96-I9FEC('!R;V-E<W-I;F<N"B`@("`@*@H@("`@
M("H@17AA;7!L93H*("`@("`J"B`@("`@*B!C;&%S<R!->5]&:6QE7U!$1B!E
M>'1E;F1S($9I;&5?4$1&('L*("`@("`J("`@("!F=6YC=&EO;B!H96%D97(H
M*0H@("`@("H@("`@('L*("`@("`J("`@("`@("`@+R\@4V5L96-T($%R:6%L
M(&)O;&0@,34*("`@("`J("`@("`@("`@)'1H:7,M/G-E=$9O;G0H)T%R:6%L
M)RP@)T(G+"`Q-2D["B`@("`@*B`@("`@("`@("\O($UO=F4@=&\@=&AE(')I
M9VAT"B`@("`@*B`@("`@("`@("1T:&ES+3YC96QL*#@P*3L*("`@("`J("`@
M("`@("`@+R\@1G)A;65D('1I=&QE"B`@("`@*B`@("`@("`@("1T:&ES+3YC
M96QL*#,P+"`Q,"P@)U1I=&QE)RP@,2P@,"P@)T,G*3L*("`@("`J("`@("`@
M("`@+R\@3&EN92!B<F5A:PH@("`@("H@("`@("`@("`D=&AI<RT^;F5W3&EN
M92@R,"D["B`@("`@*B`@("`@?0H@("`@("H@?0H@("`@("H*("`@("`J($!S
M964@1FEL95]01$8Z.F9O;W1E<@H@("`@("HO"B`@("!F=6YC=&EO;B!H96%D
M97(H*0H@("`@>PH@("`@("`@("\J(%1O(&)E(&EM<&QE;65N=&5D(&EN('EO
M=7(@;W=N(&EN:&5R:71E9"!C;&%S<RX@*B\*("`@('T*"B`@("`O*BH*("`@
M("`J(%1H:7,@;65T:&]D(&ES('5S960@=&\@<F5N9&5R('1H92!P86=E(&9O
M;W1E<BX@270@:7,@875T;VUA=&EC86QL>0H@("`@("H@8V%L;&5D(&)Y($9I
M;&5?4$1&.CIA9&1086=E(&%N9"!&:6QE7U!$1CHZ8VQO<V4@86YD('-H;W5L
M9"!N;W0@8F4@8V%L;&5D"B`@("`@*B!D:7)E8W1L>2!B>2!T:&4@87!P;&EC
M871I;VXN(%1H92!I;7!L96UE;G1A=&EO;B!I;B!&:6QE7U!$1CHZ(&ES(&5M
M<'1Y+`H@("`@("H@<V\@>6]U(&AA=F4@=&\@<W5B8VQA<W,@:70@86YD(&]V
M97)R:61E('1H92!M971H;V0@:68@>6]U('=A;G0@82!S<&5C:69I8PH@("`@
M("H@<')O8V5S<VEN9RX*("`@("`J"B`@("`@*B!%>&%M<&QE.@H@("`@("H*
M("`@("`J(&-L87-S($UY7T9I;&5?4$1&(&5X=&5N9',@1FEL95]01$8@>PH@
M("`@("H@("`@9G5N8W1I;VX@9F]O=&5R*"D*("`@("`J("`@('L*("`@("`J
M("`@("`@("`O+R!';R!T;R`Q+C4@8VT@9G)O;2!B;W1T;VT*("`@("`J("`@
M("`@("`D=&AI<RT^<V5T62@M,34I.PH@("`@("H@("`@("`@("\O(%-E;&5C
M="!!<FEA;"!I=&%L:6,@.`H@("`@("H@("`@("`@("1T:&ES+3YS971&;VYT
M*"=!<FEA;"<L("=))RP@."D["B`@("`@*B`@("`@("`@+R\@4')I;G0@8V5N
M=&5R960@<&%G92!N=6UB97(*("`@("`J("`@("`@("`D=&AI<RT^8V5L;"@P
M+"`Q,"P@)U!A9V4@)R`N("1T:&ES+3YG971086=E3F\H*2P@,"P@,"P@)T,G
M*3L*("`@("`J("`@('T*("`@("`J('T*("`@("`J"B`@("`@*B!`<V5E($9I
M;&5?4$1&.CIH96%D97(*("`@("`J+PH@("`@9G5N8W1I;VX@9F]O=&5R*"D*
M("`@('L*("`@("`@("`O*B!4;R!B92!I;7!L96UE;G1E9"!I;B!Y;W5R(&]W
M;B!I;FAE<FET960@8VQA<W,N("HO"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!C=7)R96YT('!A9V4@;G5M8F5R+@H@("`@("H*("`@("`J
M($!R971U<FX@:6YT96=E<@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z
M.F%L:6%S3F)086=E<PH@("`@("HO"B`@("!F=6YC=&EO;B!G971086=E3F\H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W!A9V4["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!3971S('1H92!F:6QL(&-O;&]R+B!3<&5C:69I97,@
M=&AE(&-O;&]R(&9O<B!B;W1H(&9I;&QE9"!A<F5A<R!A;F0*("`@("`J('1E
M>'0N($1E<&5N9&EN9R!O;B!T:&4@8V]L;W)S<&%C92!C86QL960L('1H92!N
M=6UB97(@;V8@8V]L;W(@8V]M<&]N96YT"B`@("`@*B!P87)A;65T97)S(')E
M<75I<F5D(&-A;B!B92!E:71H97(@,2P@,R!O<B`T+B!4:&4@;65T:&]D(&-A
M;B!B92!C86QL960*("`@("`J(&)E9F]R92!T:&4@9FER<W0@<&%G92!I<R!C
M<F5A=&5D(&%N9"!T:&4@8V]L;W(@:7,@<F5T86EN960@9G)O;2!P86=E('1O
M"B`@("`@*B!P86=E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-S
M("!);F1I8V%T97,@=&AE(&-O;&]R<W!A8V4@=VAI8V@@8V%N(&)E(&5I=&AE
M<B`G<F=B)RP*("`@("`J("`@("`@("`@("`@("`@("`@("`G8VUY:R<@;W(@
M)V=R87DG+B!$969A=6QT<R!T;R`G<F=B)RX*("`@("`J($!P87)A;2!F;&]A
M="`D8S$@("!&:7)S="!C;VQO<B!C;VUP;VYE;G0L(&9L;V%T:6YG('!O:6YT
M('9A;'5E(&)E='=E96X@,`H@("`@("H@("`@("`@("`@("`@("`@("`@(&%N
M9"`Q+B!297%U:7)E9"!F;W(@9W)A>2P@<F=B(&%N9"!C;7EK+@H@("`@("H@
M0'!A<F%M(&9L;V%T("1C,B`@(%-E8V]N9"!C;VQO<B!C;VUP;VYE;G0L(&9L
M;V%T:6YG('!O:6YT('9A;'5E(&)E='=E96X*("`@("`J("`@("`@("`@("`@
M("`@("`@("`P(&%N9"`Q+B!297%U:7)E9"!F;W(@<F=B(&%N9"!C;7EK+@H@
M("`@("H@0'!A<F%M(&9L;V%T("1C,R`@(%1H:7)D(&-O;&]R(&-O;7!O;F5N
M="P@9FQO871I;F<@<&]I;G0@=F%L=64@8F5T=V5E;@H@("`@("H@("`@("`@
M("`@("`@("`@("`@(#`@86YD(#$N(%)E<75I<F5D(&9O<B!R9V(@86YD(&-M
M>6LN"B`@("`@*B!`<&%R86T@9FQO870@)&,T("`@1F]U<G1H(&-O;&]R(&-O
M;7!O;F5N="P@9FQO871I;F<@<&]I;G0@=F%L=64@8F5T=V5E;@H@("`@("H@
M("`@("`@("`@("`@("`@("`@(#`@86YD(#$N(%)E<75I<F5D(&9O<B!C;7EK
M+@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.G-E=$1R87=#;VQO<@H@
M("`@("H@0'-E92!&:6QE7U!$1CHZ<F5C=`H@("`@("H@0'-E92!&:6QE7U!$
M1CHZ8V5L;`H@("`@("H@0'-E92!&:6QE7U!$1CHZ;75L=&E#96QL"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=$9I;&Q#;VQO<B@D8W,@/2`G<F=B)RP@)&,Q
M+"`D8S(@/2`P+"`D8S,@/2`P+"`D8S0@/2`P*0H@("`@>PH@("`@("`@("1C
M<R`]('-T<G1O;&]W97(H)&-S*3L*("`@("`@("!I9B`H)&-S(#T]("=R9V(G
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?9FEL;%]C;VQO<B`]('-P<FEN=&8H
M)R4N,V8@)2XS9B`E+C-F(')G)RP@)&,Q+"`D8S(L("1C,RD["B`@("`@("`@
M?2!E;'-E:68@*"1C<R`]/2`G8VUY:R<I('L*("`@("`@("`@("`@)'1H:7,M
M/E]F:6QL7V-O;&]R(#T@<W!R:6YT9B@G)2XS9B`E+C-F("4N,V8@)2XS9B!K
M)RP@)&,Q+"`D8S(L("1C,RP@)&,T*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&AI<RT^7V9I;&Q?8V]L;W(@/2!S<')I;G1F*"<E+C-F(&<G
M+"`D8S$I.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/E]P86=E(#X@
M,"D@>PH@("`@("`@("`@("`D=&AI<RT^7V]U="@D=&AI<RT^7V9I;&Q?8V]L
M;W(I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE
M(&1R87<@8V]L;W(L('5S960@=VAE;B!D<F%W:6YG(&QI;F5S+B!$97!E;F1I
M;F<@;VX@=&AE"B`@("`@*B!C;VQO<G-P86-E(&-A;&QE9"P@=&AE(&YU;6)E
M<B!O9B!C;VQO<B!C;VUP;VYE;G0@<&%R86UE=&5R<R!R97%U:7)E9`H@("`@
M("H@8V%N(&)E(&5I=&AE<B`Q+"`S(&]R(#0N(%1H92!M971H;V0@8V%N(&)E
M(&-A;&QE9"!B969O<F4@=&AE(&9I<G-T('!A9V4*("`@("`J(&ES(&-R96%T
M960@86YD('1H92!C;VQO<B!I<R!R971A:6YE9"!F<F]M('!A9V4@=&\@<&%G
M92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C<R`@26YD:6-A=&5S
M('1H92!C;VQO<G-P86-E('=H:6-H(&-A;B!B92!E:71H97(@)W)G8B<L"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@)V-M>6LG(&]R("=G<F%Y)RX@1&5F
M875L=',@=&\@)W)G8B<N"B`@("`@*B!`<&%R86T@9FQO870@)&,Q("`@1FER
M<W0@8V]L;W(@8V]M<&]N96YT+"!F;&]A=&EN9R!P;VEN="!V86QU92!B971W
M965N(#`*("`@("`J("`@("`@("`@("`@("`@("`@("!A;F0@,2X@4F5Q=6ER
M960@9F]R(&=R87DL(')G8B!A;F0@8VUY:RX*("`@("`J($!P87)A;2!F;&]A
M="`D8S(@("!396-O;F0@8V]L;W(@8V]M<&]N96YT+"!F;&]A=&EN9R!P;VEN
M="!V86QU92!B971W965N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@,"!A
M;F0@,2X@4F5Q=6ER960@9F]R(')G8B!A;F0@8VUY:RX*("`@("`J($!P87)A
M;2!F;&]A="`D8S,@("!4:&ER9"!C;VQO<B!C;VUP;VYE;G0L(&9L;V%T:6YG
M('!O:6YT('9A;'5E(&)E='=E96X@,`H@("`@("H@("`@("`@("`@("`@("`@
M("`@(&%N9"`Q+B!297%U:7)E9"!F;W(@<F=B(&%N9"!C;7EK+@H@("`@("H@
M0'!A<F%M(&9L;V%T("1C-"`@($9O=7)T:"!C;VQO<B!C;VUP;VYE;G0L(&9L
M;V%T:6YG('!O:6YT('9A;'5E(&)E='=E96X*("`@("`J("`@("`@("`@("`@
M("`@("`@("`P(&%N9"`Q+B!297%U:7)E9"!F;W(@8VUY:RX*("`@("`J"B`@
M("`@*B!`<V5E($9I;&5?4$1&.CIS971&:6QL0V]L;W(*("`@("`J($!S964@
M1FEL95]01$8Z.FQI;F4*("`@("`J($!S964@1FEL95]01$8Z.G)E8W0*("`@
M("`J($!S964@1FEL95]01$8Z.F-E;&P*("`@("`J($!S964@1FEL95]01$8Z
M.FUU;'1I0V5L;`H@("`@("HO"B`@("!F=6YC=&EO;B!S971$<F%W0V]L;W(H
M)&-S(#T@)W)G8B<L("1C,2P@)&,R(#T@,"P@)&,S(#T@,"P@)&,T(#T@,"D*
M("`@('L*("`@("`@("`D8W,@/2!S=')T;VQO=V5R*"1C<RD["B`@("`@("`@
M:68@*"1C<R`]/2`G<F=B)RD@>PH@("`@("`@("`@("`D=&AI<RT^7V1R87=?
M8V]L;W(@/2!S<')I;G1F*"<E+C-F("4N,V8@)2XS9B!21R<L("1C,2P@)&,R
M+"`D8S,I.PH@("`@("`@('T@96QS96EF("@D8W,@/3T@)V-M>6LG*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?9')A=U]C;VQO<B`]('-P<FEN=&8H)R4N,V8@
M)2XS9B`E+C-F("4N,V8@2R<L("1C,2P@)&,R+"`D8S,L("1C-"D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]D<F%W7V-O;&]R(#T@
M<W!R:6YT9B@G)2XS9B!')RP@)&,Q*3L*("`@("`@("!]"B`@("`@("`@:68@
M*"1T:&ES+3Y?<&%G92`^(#`I('L*("`@("`@("`@("`@)'1H:7,M/E]O=70H
M)'1H:7,M/E]D<F%W7V-O;&]R*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!L96YG=&@@;V8@82!T97AT('-T<FEN9RX@
M02!F;VYT(&UU<W0@8F4@<V5L96-T960N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@=VAO<V4@;&5N9W1H(&ES('1O(&)E
M(&-O;7!U=&5D+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'!T("`@0F]O;&5A
M;B!T;R!I;F1I8V%T92!I9B!T:&4@=VED=&@@<VAO=6QD(&)E(')E='5R;F5D
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!I;B!P;VEN=',@;W(@=7-E
M<B!U;FET<RX@1&5F875L="!I<R`G9F%L<V4G+@H@("`@("H*("`@("`J($!R
M971U<FX@9FQO870*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4W1R:6YG5VED
M=&@H)'1E>'0L("1P="`](&9A;'-E*0H@("`@>PH@("`@("`@("1T97AT(#T@
M*'-T<FEN9RDD=&5X=#L*("`@("`@("`D=VED=&@@/2`P.PH@("`@("`@("1L
M96YG=&@@/2!S=')L96XH)'1E>'0I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\("1L96YG=&@[("1I*RLI('L*("`@("`@("`@("`@)'=I9'1H("L]("1T
M:&ES+3Y?8W5R<F5N=%]F;VYT6R=C=R==6R1T97AT>R1I?5T["B`@("`@("`@
M?0H*("`@("`@("`O*B!!9&IU<W0@9F]R('=O<F0@<W!A8VEN9RX@*B\*("`@
M("`@("`D=VED=&@@*ST@)'1H:7,M/E]W;W)D7W-P86-I;F<@*B!S=6)S=')?
M8V]U;G0H)'1E>'0L("<@)RD@*B`D=&AI<RT^7V-U<G)E;G1?9F]N=%LG8W<G
M75LG("==.PH*("`@("`@("!I9B`H)'!T*2!["B`@("`@("`@("`@(')E='5R
M;B`D=VED=&@@*B`D=&AI<RT^7V9O;G1?<VEZ95]P="`O(#$P,#`["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1W:61T:"`J("1T:&ES
M+3Y?9F]N=%]S:7IE("\@,3`P,#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$969I;F5S('1H92!L:6YE('=I9'1H+B!">2!D969A=6QT+"!T
M:&4@=F%L=64@97%U86QS(#`N,B!M;2X@5&AE(&UE=&AO9`H@("`@("H@8V%N
M(&)E(&-A;&QE9"!B969O<F4@=&AE(&9I<G-T('!A9V4@:7,@8W)E871E9"!A
M;F0@=&AE('9A;'5E(&ES"B`@("`@*B!R971A:6YE9"!F<F]M('!A9V4@=&\@
M<&%G92X*("`@("`J"B`@("`@*B!`<&%R86T@9FQO870@)'=I9'1H("!4:&4@
M=VED=&@N"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ;&EN90H@("`@
M("H@0'-E92!&:6QE7U!$1CHZ<F5C=`H@("`@("H@0'-E92!&:6QE7U!$1CHZ
M8V5L;`H@("`@("H@0'-E92!&:6QE7U!$1CHZ;75L=&E#96QL"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-E=$QI;F57:61T:"@D=VED=&@I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]L:6YE7W=I9'1H(#T@)'=I9'1H.PH@("`@("`@(&EF("@D
M=&AI<RT^7W!A9V4@/B`P*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*'-P
M<FEN=&8H)R4N,F8@=R<L("1W:61T:"`J("1T:&ES+3Y?<V-A;&4I*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W<R!A(&QI;F4@8F5T
M=V5E;B!T=V\@<&]I;G1S+@H@("`@("H*("`@("`J($!P87)A;2!F;&]A="`D
M>#$@($%B<V-I<W-A(&]F(&9I<G-T('!O:6YT+@H@("`@("H@0'!A<F%M(&9L
M;V%T("1Y,2`@3W)D:6YA=&4@;V8@9FER<W0@<&]I;G0N"B`@("`@*B!`<&%R
M86T@9FQO870@)'@R("!!8G-C:7-S82!O9B!S96-O;F0@<&]I;G0N"B`@("`@
M*B!`<&%R86T@9FQO870@)'DR("!/<F1I;F%T92!O9B!S96-O;F0@<&]I;G0N
M"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T3&EN95=I9'1H"B`@
M("`@*B!`<V5E($9I;&5?4$1&.CIS971$<F%W0V]L;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&QI;F4H)'@Q+"`D>3$L("1X,BP@)'DR*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?;W5T*'-P<FEN=&8H)R4N,F8@)2XR9B!M("4N,F8@)2XR
M9B!L(%,G+"`D>#$@*B`D=&AI<RT^7W-C86QE+"`H)'1H:7,M/F@@+2`D>3$I
M("H@)'1H:7,M/E]S8V%L92P@)'@R("H@)'1H:7,M/E]S8V%L92P@*"1T:&ES
M+3YH("T@)'DR*2`J("1T:&ES+3Y?<V-A;&4I*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($]U='!U=',@82!R96-T86YG;&4N($ET(&-A;B!B92!D<F%W;B`H
M8F]R9&5R(&]N;'DI+"!F:6QL960@*'=I=&@@;F\*("`@("`J(&)O<F1E<BD@
M;W(@8F]T:"X*("`@("`J"B`@("`@*B!`<&%R86T@9FQO870@)'@@("`@("`@
M06)S8VES<V$@;V8@=7!P97(M;&5F="!C;W)N97(N"B`@("`@*B!`<&%R86T@
M9FQO870@)'D@("`@("`@3W)D:6YA=&4@;V8@=7!P97(M;&5F="!C;W)N97(N
M"B`@("`@*B!`<&%R86T@9FQO870@)'=I9'1H("`@5VED=&@N"B`@("`@*B!`
M<&%R86T@9FQO870@)&AE:6=H="`@2&5I9VAT+@H@("`@("H@0'!A<F%M(&9L
M;V%T("1S='EL92`@(%-T>6QE(&]F(')E;F1E<FEN9RX@4&]S<VEB;&4@=F%L
M=65S(&%R93H*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@1"!O
M<B!E;7!T>2!S=')I;F<Z(&1R87<@*&1E9F%U;'0I"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`M($8Z(&9I;&P*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("T@1$8@;W(@1D0Z(&1R87<@86YD(&9I;&P*("`@("`J
M"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS971,:6YE5VED=&@*("`@("`J($!S
M964@1FEL95]01$8Z.G-E=$1R87=#;VQO<@H@("`@("H@0'-E92!&:6QE7U!$
M1CHZ<V5T1FEL;$-O;&]R"B`@("`@*B\*("`@(&9U;F-T:6]N(')E8W0H)'@L
M("1Y+"`D=VED=&@L("1H96EG:'0L("1S='EL92`]("<G*0H@("`@>PH@("`@
M("`@("1S='EL92`]('-T<G1O=7!P97(H)'-T>6QE*3L*("`@("`@("!I9B`H
M)'-T>6QE(#T]("=&)RD@>PH@("`@("`@("`@("`D;W`@/2`G9B<["B`@("`@
M("`@?2!E;'-E:68@*"1S='EL92`]/2`G1D0G('Q\("1S='EL92`]/2`G1$8G
M*2!["B`@("`@("`@("`@("1O<"`]("=")SL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D;W`@/2`G4R<["B`@("`@("`@?0H*("`@("`@("`D>"`@
M("`@(#T@)'1H:7,M/E]T;U!T*"1X*3L*("`@("`@("`D>2`@("`@(#T@)'1H
M:7,M/E]T;U!T*"1Y*3L*("`@("`@("`D=VED=&@@(#T@)'1H:7,M/E]T;U!T
M*"1W:61T:"D["B`@("`@("`@)&AE:6=H="`]("1T:&ES+3Y?=&]0="@D:&5I
M9VAT*3L*"B`@("`@("`@)'1H:7,M/E]O=70H<W!R:6YT9B@G)2XR9B`E+C)F
M("4N,F8@)2XR9B!R92`E<R<L("1X+"`D=&AI<RT^:%!T("T@)'DL("1W:61T
M:"P@+21H96EG:'0L("1O<"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@3W5T
M<'5T<R!A(&-I<F-L92X@270@8V%N(&)E(&1R87=N("AB;W)D97(@;VYL>2DL
M(&9I;&QE9"`H=VET:"!N;PH@("`@("H@8F]R9&5R*2!O<B!B;W1H+@H@("`@
M("H*("`@("`J($!P87)A;2!F;&]A="`D>"`@("`@("!!8G-C:7-S82!O9B!T
M:&4@8V5N=&5R(&]F('1H92!C:7)C;&4N"B`@("`@*B!`<&%R86T@9FQO870@
M)'D@("`@("`@3W)D:6YA=&4@;V8@=&AE(&-E;G1E<B!O9B!T:&4@8VER8VQE
M+@H@("`@("H@0'!A<F%M(&9L;V%T("1R("`@("`@($-I<F-L92!R861I=7,N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1S='EL92`@4W1Y;&4@;V8@<F5N9&5R
M:6YG+B!0;W-S:6)L92!V86QU97,@87)E.@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@+2!$(&]R(&5M<'1Y('-T<FEN9SH@9')A=R`H9&5F875L
M="D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@1CH@9FEL;`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2!$1B!O<B!&1#H@9')A
M=R!A;F0@9FEL;`H@("`@("HO"B`@("!F=6YC=&EO;B!C:7)C;&4H)'@L("1Y
M+"`D<BP@)'-T>6QE(#T@)R<I"B`@("!["B`@("`@("`@)'-T>6QE(#T@<W1R
M=&]L;W=E<B@D<W1Y;&4I.PH@("`@("`@(&EF("@D<W1Y;&4@/3T@)V8G*2![
M"B`@("`@("`@("`@("1O<"`]("=F)SL@("`@("`O+R!3='EL92!I<R!F:6QL
M(&]N;'DN"B`@("`@("`@?2!E;'-E:68@*"1S='EL92`]/2`G9F0G('Q\("1S
M='EL92`]/2`G9&8G*2!["B`@("`@("`@("`@("1O<"`]("=")SL@("`@("`O
M+R!3='EL92!I<R!F:6QL(&%N9"!S=')O:V4N"B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&]P(#T@)U,G.R`@("`@("\O(%-T>6QE(&ES('-T<F]K
M92!O;FQY+@H@("`@("`@('T*"B`@("`@("`@)'@@/2`D=&AI<RT^7W1O4'0H
M)'@I.PH@("`@("`@("1Y(#T@)'1H:7,M/E]T;U!T*"1Y*3L*("`@("`@("`D
M<B`]("1T:&ES+3Y?=&]0="@D<BD["@H@("`@("`@("\J($EN=F5R="!T:&4@
M>2!S8V%L92X@*B\*("`@("`@("`D>2`]("1T:&ES+3YH4'0@+2`D>3L*("`@
M("`@("`O*B!,96YG=&@@;V8@=&AE($)E>FEE<B!C;VYT<F]L+B`J+PH@("`@
M("`@("1B(#T@)'(@*B`P+C4U,CL*"B`@("`@("`@+RH@36]V92!F<F]M('1H
M92!G:79E;B!O<FEG:6X@86YD('-E="!T:&4@8W5R<F5N="!P;VEN=`H@("`@
M("`@("`J('1O('1H92!S=&%R="!O9B!T:&4@9FER<W0@0F5Z:65R(&-U<G9E
M+B`J+PH@("`@("`@("1C(#T@<W!R:6YT9B@G)2XR9B`E+C)F(&TG+"`D>"`M
M("1R+"`D>2D["B`@("`@("`@)'@@/2`D>"`M("1R.PH@("`@("`@("\J($9I
M<G-T(&-I<F-L92!Q=6%R=&5R+B`J+PH@("`@("`@("1C("X]('-P<FEN=&8H
M)R`E+C)F("4N,F8@)2XR9B`E+C)F("4N,F8@)2XR9B!C)RP*("`@("`@("`@
M("`@("`@("`@("`@("1X+"`D>2`K("1B+"`@("`@("`@("`@+R\@1FER<W0@
M8V]N=')O;"!P;VEN="X*("`@("`@("`@("`@("`@("`@("`@("1X("L@)'(@
M+2`D8BP@)'D@*R`D<BP@+R\@4V5C;VYD(&-O;G1R;VP@<&]I;G0N"B`@("`@
M("`@("`@("`@("`@("`@("`D>"`K("1R+"`D>2`K("1R*3L@("`@("\O($9I
M;F%L('!O:6YT+@H@("`@("`@("\J(%-E="!X+WD@=&\@=&AE(&9I;F%L('!O
M:6YT+B`J+PH@("`@("`@("1X(#T@)'@@*R`D<CL*("`@("`@("`D>2`]("1Y
M("L@)'(["B`@("`@("`@+RH@4V5C;VYD(&-I<F-L92!Q=6%R=&5R+B`J+PH@
M("`@("`@("1C("X]('-P<FEN=&8H)R`E+C)F("4N,F8@)2XR9B`E+C)F("4N
M,F8@)2XR9B!C)RP*("`@("`@("`@("`@("`@("`@("`@("1X("L@)&(L("1Y
M+`H@("`@("`@("`@("`@("`@("`@("`@)'@@*R`D<BP@)'D@+2`D<B`K("1B
M+`H@("`@("`@("`@("`@("`@("`@("`@)'@@*R`D<BP@)'D@+2`D<BD["B`@
M("`@("`@+RH@4V5T('@O>2!T;R!T:&4@9FEN86P@<&]I;G0N("HO"B`@("`@
M("`@)'@@/2`D>"`K("1R.PH@("`@("`@("1Y(#T@)'D@+2`D<CL*("`@("`@
M("`O*B!4:&ER9"!C:7)C;&4@<75A<G1E<BX@*B\*("`@("`@("`D8R`N/2!S
M<')I;G1F*"<@)2XR9B`E+C)F("4N,F8@)2XR9B`E+C)F("4N,F8@8R<L"B`@
M("`@("`@("`@("`@("`@("`@("`D>"P@)'D@+2`D8BP*("`@("`@("`@("`@
M("`@("`@("`@("1X("T@)'(@*R`D8BP@)'D@+2`D<BP*("`@("`@("`@("`@
M("`@("`@("`@("1X("T@)'(L("1Y("T@)'(I.PH@("`@("`@("\J(%-E="!X
M+WD@=&\@=&AE(&9I;F%L('!O:6YT+B`J+PH@("`@("`@("1X(#T@)'@@+2`D
M<CL*("`@("`@("`D>2`]("1Y("T@)'(["B`@("`@("`@+RH@1F]U<G1H(&-I
M<F-L92!Q=6%R=&5R+B`J+PH@("`@("`@("1C("X]('-P<FEN=&8H)R`E+C)F
M("4N,F8@)2XR9B`E+C)F("4N,F8@)2XR9B!C("5S)RP*("`@("`@("`@("`@
M("`@("`@("`@("1X("T@)&(L("1Y+`H@("`@("`@("`@("`@("`@("`@("`@
M)'@@+2`D<BP@)'D@*R`D<B`M("1B+`H@("`@("`@("`@("`@("`@("`@("`@
M)'@@+2`D<BP@)'D@*R`D<BP*("`@("`@("`@("`@("`@("`@("`@("1O<"D[
M"B`@("`@("`@+RH@3W5T<'5T('1H92!W:&]L92!S=')I;F<N("HO"B`@("`@
M("`@)'1H:7,M/E]O=70H)&,I.PH@("`@?0H*("`@("\J*@H@("`@("H@26UP
M;W)T<R!A(%1R=654>7!E(&]R(%1Y<&4Q(&9O;G0@86YD(&UA:V5S(&ET(&%V
M86EL86)L92X@270@:7,*("`@("`J(&YE8V5S<V%R>2!T;R!G96YE<F%T92!A
M(&9O;G0@9&5F:6YI=&EO;B!F:6QE(&9I<G-T('=I=&@@=&AE"B`@("`@*B!M
M86ME9F]N="YP:'`@=71I;&ET>2X*("`@("`J(%1H92!L;V-A=&EO;B!O9B!T
M:&4@9&5F:6YI=&EO;B!F:6QE("AA;F0@=&AE(&9O;G0@9FEL92!I='-E;&8@
M=VAE;@H@("`@("H@96UB961D:6YG*2!M=7-T(&)E(&9O=6YD(&%T('1H92!F
M=6QL('!A=&@@;F%M92!I;F-L=61E9"X*("`@("`J"B`@("`@*B!%>&%M<&QE
M.@H@("`@("H@)'!D9BT^861D1F]N="@G0V]M:6,G+"`G22<I.PH@("`@("H@
M:7,@97%U:79A;&5N="!T;SH*("`@("`J("1P9&8M/F%D9$9O;G0H)T-O;6EC
M)RP@)TDG+"`G8V]M:6-I+G!H<"<I.PH@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&9A;6EL>2`@1F]N="!F86UI;'DN(%1H92!N86UE(&-A;B!B92!C
M:&]S96X@87)B:71R87)I;'DN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@($EF(&ET(&ES(&$@<W1A;F1A<F0@9F%M:6QY(&YA;64L(&ET('=I;&P*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@;W9E<G)I9&4@=&AE(&-O
M<G)E<W!O;F1I;F<@9F]N="X*("`@("`J($!P87)A;2!S=')I;F<@)'-T>6QE
M("`@1F]N="!S='EL92X@4&]S<VEB;&4@=F%L=65S(&%R92`H8V%S90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("!I;G-E;G-I=&EV92DZ"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@+2!E;7!T>2!S=')I;F<Z(')E
M9W5L87(@*&1E9F%U;'0I"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@+2!".B!B;VQD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M+2!).B!I=&%L:6,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`M
M($))(&]R($E".B!B;VQD(&ET86QI8PH@("`@("H@0'!A<F%M('-T<FEN9R`D
M9FEL92`@("!4:&4@9F]N="!D969I;FET:6]N(&9I;&4N($)Y(&1E9F%U;'0L
M('1H92!N86UE(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&)U
M:6QT(&9R;VT@=&AE(&9A;6EL>2!A;F0@<W1Y;&4L(&EN(&QO=V5R(&-A<V4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@=VET:"!N;R!S<&%C92X*
M("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS971&;VYT"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%D9$9O;G0H)&9A;6EL>2P@)'-T>6QE(#T@)R<L("1F
M:6QE(#T@)R<I"B`@("!["B`@("`@("`@)&9A;6EL>2`]('-T<G1O;&]W97(H
M)&9A;6EL>2D["B`@("`@("`@:68@*"1F86UI;'D@/3T@)V%R:6%L)RD@>PH@
M("`@("`@("`@("`D9F%M:6QY(#T@)VAE;'9E=&EC82<["B`@("`@("`@?0H*
M("`@("`@("`D<W1Y;&4@/2!S=')T;W5P<&5R*"1S='EL92D["B`@("`@("`@
M:68@*"1S='EL92`]/2`G24(G*2!["B`@("`@("`@("`@("1S='EL92`]("="
M22<["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V9O;G1S
M6R1F86UI;'D@+B`D<W1Y;&5=*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H<W!R:6YT9B@G1F]N="!A;')E861Y(&%D9&5D.B`E
M<R`E<R<L("1F86UI;'DL("1S='EL92DI.PH@("`@("`@('T*("`@("`@("!I
M9B`H)&9I;&4@/3T@)R<I('L*("`@("`@("`@("`@)&9I;&4@/2!S=')?<F5P
M;&%C92@G("<L("<G+"`D9F%M:6QY*2`N('-T<G1O;&]W97(H)'-T>6QE*2`N
M("<N<&AP)SL*("`@("`@("!]"B`@("`@("`@:6YC;'5D92@D9FEL92D["B`@
M("`@("`@:68@*"%I<W-E="@D;F%M92DI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"=#;W5L9"!N;W0@:6YC;'5D92!F;VYT(&1E
M9FEN:71I;VX@9FEL92XG*3L*("`@("`@("!]"B`@("`@("`@)&D@/2!C;W5N
M="@D=&AI<RT^7V9O;G1S*2`K(#$["B`@("`@("`@)'1H:7,M/E]F;VYT<ULD
M9F%M:6QY("X@)'-T>6QE72`](&%R<F%Y*"=I)R`]/B`D:2P@)W1Y<&4G(#T^
M("1T>7!E+"`G;F%M92<@/3X@)&YA;64L("=D97-C)R`]/B`D9&5S8RP@)W5P
M)R`]/B`D=7`L("=U="<@/3X@)'5T+"`G8W<G(#T^("1C=RP@)V5N8R<@/3X@
M)&5N8RP@)V9I;&4G(#T^("1F:6QE*3L*("`@("`@("!I9B`H)&1I9F8I('L*
M("`@("`@("`@("`@+RH@4V5A<F-H(&5X:7-T:6YG(&5N8V]D:6YG<RX@*B\*
M("`@("`@("`@("`@)&0@/2`P.PH@("`@("`@("`@("`D;F(@/2!C;W5N="@D
M=&AI<RT^7V1I9F9S*3L*("`@("`@("`@("`@9F]R("@D:2`](#$[("1I(#P]
M("1N8CL@)&DK*RD@>PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?9&EF
M9G-;)&E=(#T]("1D:69F*2!["B`@("`@("`@("`@("`@("`@("`@)&0@/2`D
M:3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&0@/3T@,"D@>PH@
M("`@("`@("`@("`@("`@)&0@/2`D;F(@*R`Q.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]D:69F<ULD9%T@/2`D9&EF9CL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D=&AI<RT^7V9O;G1S6R1F86UI;'DN)'-T>6QE75LG9&EF9B==
M(#T@)&0["B`@("`@("`@?0H@("`@("`@(&EF("@D9FEL92D@>PH@("`@("`@
M("`@("!I9B`H)'1Y<&4@/3T@)U1R=654>7!E)RD@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]F;VYT7V9I;&5S6R1F:6QE72`](&%R<F%Y*"=L96YG=&@Q
M)R`]/B`D;W)I9VEN86QS:7IE*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9F]N=%]F:6QE<ULD9FEL95T@/2!A<G)A
M>2@G;&5N9W1H,2<@/3X@)'-I>F4Q+"`G;&5N9W1H,B<@/3X@)'-I>F4R*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E=',@=&AE(&9O;G0@=7-E9"!T;R!P<FEN="!C:&%R86-T97(@<W1R:6YG
M<RX@270@:7,@;6%N9&%T;W)Y('1O(&-A;&P*("`@("`J('1H:7,@;65T:&]D
M(&%T(&QE87-T(&]N8V4@8F5F;W)E('!R:6YT:6YG('1E>'0@;W(@=&AE(')E
M<W5L=&EN9PH@("`@("H@9&]C=6UE;G0@=V]U;&0@;F]T(&)E('9A;&ED+B!4
M:&4@9F]N="!C86X@8F4@96ET:&5R(&$@<W1A;F1A<F0@;VYE(&]R(&$*("`@
M("`J(&9O;G0@861D960@=FEA('1H92!&:6QE7U!$1CHZ861D1F]N="!M971H
M;V0N(%-T86YD87)D(&9O;G1S('5S92!7:6YD;W=S"B`@("`@*B!E;F-O9&EN
M9R!C<#$R-3(@*%=E<W1E<FX@175R;W!E*2X*("`@("`J(%1H92!M971H;V0@
M8V%N(&)E(&-A;&QE9"!B969O<F4@=&AE(&9I<G-T('!A9V4@:7,@8W)E871E
M9"!A;F0@=&AE(&9O;G0*("`@("`J(&ES(')E=&%I;F5D(&9R;VT@<&%G92!T
M;R!P86=E+@H@("`@("H@268@>6]U(&IU<W0@=VES:"!T;R!C:&%N9V4@=&AE
M(&-U<G)E;G0@9F]N="!S:7IE+"!I="!I<R!S:6UP;&5R('1O(&-A;&P*("`@
M("`J($9I;&5?4$1&.CIS971&;VYT4VEZ92X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1F86UI;'D@($9A;6EL>2!F;VYT+B!)="!C86X@8F4@96ET
M:&5R(&$@;F%M92!D969I;F5D(&)Y"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@($9I;&5?4$1&.CIA9&1&;VYT(&]R(&]N92!O9B!T:&4@<W1A;F1A
M<F0@9F%M:6QI97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@*&-A
M<V4@:6YS96YS:71I=F4I.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("T@0V]U<FEE<B`H9FEX960M=VED=&@I"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@+2!(96QV971I8V$@;W(@07)I86P@*'-A;G,@<V5R
M:68I"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@+2!4:6UE<R`H
M<V5R:68I"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@+2!3>6UB
M;VP@*'-Y;6)O;&EC*0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("T@6F%P9D1I;F=B871S("AS>6UB;VQI8RD*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@270@:7,@86QS;R!P;W-S:6)L92!T;R!P87-S(&%N(&5M
M<'1Y('-T<FEN9RX@26X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M=&AA="!C87-E+"!T:&4@8W5R<F5N="!F86UI;'D@:7,@<F5T86EN960N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1S='EL92`@($9O;G0@<W1Y;&4N(%!O<W-I
M8FQE('9A;'5E<R!A<F4@*&-A<V4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@:6YS96YS:71I=F4I.@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("T@96UP='D@<W1R:6YG.B!R96=U;&%R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@+2!".B!B;VQD"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@+2!).B!I=&%L:6,*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`M(%4Z('5N9&5R;&EN90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("!O<B!A;GD@8V]M8FEN871I;VXN(%1H92!D969A=6QT
M('9A;'5E(&ES(')E9W5L87(N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@($)O;&0@86YD(&ET86QI8R!S='EL97,@9&\@;F]T(&%P<&QY('1O(%-Y
M;6)O;"!A;F0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@6F%P9D1I
M;F=B871S+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'-I>F4@("!&;VYT('-I
M>F4@:6X@<&]I;G1S+B!4:&4@9&5F875L="!V86QU92!I<R!T:&4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@8W5R<F5N="!S:7IE+B!)9B!N;R!S
M:7IE(&AA<R!B965N('-P96-I9FEE9"!S:6YC90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("!T:&4@8F5G:6YN:6YG(&]F('1H92!D;V-U;65N="P@
M=&AE('9A;'5E('1A:V5N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M(&ES(#$R+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&9O<F-E("!&;W)C92!T
M:&4@<V5T=&EN9R!O9B!T:&4@9F]N="X@16%C:"!N97<@<&%G92!W:6QL"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@(')E<75I<F4@82!N97<@8V%L
M;"!T;R!&:6QE7U!$1CHZ<V5T1F]N="!A;F0*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@<V5T=&EN9W,@=&AI<R!T;R!T<G5E('=I;&P@;6%K92!S
M=7)E('1H870@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&-H
M96-K<R!F;W(@<V%M92!F;VYT(&-A;&QS('=I;&P@8F4@<VMI<'!E9"X*("`@
M("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIA9&1&;VYT"B`@("`@*B!`<V5E
M($9I;&5?4$1&.CIS971&;VYT4VEZ90H@("`@("H@0'-E92!&:6QE7U!$1CHZ
M8V5L;`H@("`@("H@0'-E92!&:6QE7U!$1CHZ;75L=&E#96QL"B`@("`@*B!`
M<V5E($9I;&5?4$1&.CI7<FET90H@("`@("HO"B`@("!F=6YC=&EO;B!S971&
M;VYT*"1F86UI;'DL("1S='EL92`]("<G+"`D<VEZ92`](&YU;&PL("1F;W)C
M92`](&9A;'-E*0H@("`@>PH@("`@("`@("1F86UI;'D@/2!S=')T;VQO=V5R
M*"1F86UI;'DI.PH@("`@("`@(&EF("@D9F%M:6QY(#T]("=A<FEA;"<I('L*
M("`@("`@("`@("`@+RH@57-E(&AE;'9E=&EC82!I;G-T96%D(&]F(&%R:6%L
M+B`J+PH@("`@("`@("`@("`D9F%M:6QY(#T@)VAE;'9E=&EC82<["B`@("`@
M("`@?2!E;'-E:68@*"1F86UI;'D@/3T@)W-Y;6)O;"<@?'P@)&9A;6EL>2`]
M/2`G>F%P9F1I;F=B871S)RD@>PH@("`@("`@("`@("`O*B!4:&5S92!T=V\@
M9F]N=',@9&\@;F]T(&AA=F4@<W1Y;&5S(&%V86EL86)L92X@*B\*("`@("`@
M("`@("`@)'-T>6QE(#T@)R<["B`@("`@("`@?0H*("`@("`@("`D<W1Y;&4@
M/2!S=')T;W5P<&5R*"1S='EL92D["@H@("`@("`@("\J(%5N9&5R;&EN92!I
M<R!H86YD;&5D('-E<&%R871E;'DL(&EF('-P96-I9FEE9"!I;B!T:&4@<W1Y
M;&4@=F%R"B`@("`@("`@("H@<F5M;W9E(&ET(&9R;VT@=&AE('-T>6QE(&%N
M9"!S970@=&AE('5N9&5R;&EN92!F;&%G+B`J+PH@("`@("`@(&EF("AS=')P
M;W,H)'-T>6QE+"`G52<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`D=&AI
M<RT^7W5N9&5R;&EN92`]('1R=64["B`@("`@("`@("`@("1S='EL92`]('-T
M<E]R97!L86-E*"=5)RP@)R<L("1S='EL92D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'1H:7,M/E]U;F1E<FQI;F4@/2!F86QS93L*("`@("`@
M("!]"@H@("`@("`@(&EF("@D<W1Y;&4@/3T@)TE")RD@>PH@("`@("`@("`@
M("`D<W1Y;&4@/2`G0DDG.PH@("`@("`@('T*"B`@("`@("`@+RH@268@;F\@
M<VEZ92!S<&5C:69I960L('5S92!C=7)R96YT('-I>F4N("HO"B`@("`@("`@
M:68@*&ES7VYU;&PH)'-I>F4I*2!["B`@("`@("`@("`@("1S:7IE(#T@)'1H
M:7,M/E]F;VYT7W-I>F5?<'0["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!F
M;VYT(')E<75E<W1E9"!I<R!A;')E861Y('1H92!C=7)R96YT(&9O;G0@86YD
M(&YO(&9O<F-E('-E='1I;F<*("`@("`@("`@*B!O9B!T:&4@9F]N="!I<R!R
M97%U97-T960@*&5G+B!W:&5N(&%D9&EN9R!A(&YE=R!P86=E*2!D;VXG="!B
M;W1H97(*("`@("`@("`@*B!W:71H('1H92!R97-T(&]F('1H92!F=6YC=&EO
M;B!A;F0@<VEM<&QY(')E='5R;BX@*B\*("`@("`@("!I9B`H)'1H:7,M/E]F
M;VYT7V9A;6EL>2`]/2`D9F%M:6QY("8F("1T:&ES+3Y?9F]N=%]S='EL92`]
M/2`D<W1Y;&4@)B8*("`@("`@("`@("`@)'1H:7,M/E]F;VYT7W-I>F5?<'0@
M/3T@)'-I>F4@)B8@(21F;W)C92D@>PH@("`@("`@("`@("!R971U<FX["B`@
M("`@("`@?0H*("`@("`@("`O*B!3970@=&AE(&9O;G0@:V5Y+B`J+PH@("`@
M("`@("1F;VYT:V5Y(#T@)&9A;6EL>2`N("1S='EL93L*"B`@("`@("`@+RH@
M5&5S="!I9B!A;')E861Y(&-A8VAE9"X@*B\*("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?9F]N='-;)&9O;G1K97E=*2D@>PH@("`@("`@("`@("`O*B!'
M970@=&AE(&-H87)A8W1E<B!W:61T:"!D969I;FET:6]N(&9I;&4N("HO"B`@
M("`@("`@("`@("1F;VYT7W=I9'1H<R`]("9&:6QE7U!$1CHZ7V=E=$9O;G1&
M:6QE*"1F;VYT:V5Y*3L*("`@("`@("`@("`@:68@*&ES7V$H)&9O;G1?=VED
M=&AS+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)&9O;G1?=VED=&AS.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D:2`]
M(&-O=6YT*"1T:&ES+3Y?9F]N=',I("L@,3L*("`@("`@("`@("`@)'1H:7,M
M/E]F;VYT<ULD9F]N=&ME>5T@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=I
M)R`@("`]/B`D:2P*("`@("`@("`@("`@("`@("=T>7!E)R`]/B`G8V]R92<L
M"B`@("`@("`@("`@("`@("`G;F%M92<@/3X@)'1H:7,M/E]C;W)E7V9O;G1S
M6R1F;VYT:V5Y72P*("`@("`@("`@("`@("`@("=U<"<@("`]/B`M,3`P+`H@
M("`@("`@("`@("`@("`@)W5T)R`@(#T^(#4P+`H@("`@("`@("`@("`@("`@
M)V-W)R`@(#T^("1F;VYT7W=I9'1H<ULD9F]N=&ME>5TI.PH@("`@("`@('T*
M"B`@("`@("`@+RH@4W1O<F4@9F]N="!I;F9O<FUA=&EO;B!A<R!C=7)R96YT
M(&9O;G0N("HO"B`@("`@("`@)'1H:7,M/E]F;VYT7V9A;6EL>2`@/2`D9F%M
M:6QY.PH@("`@("`@("1T:&ES+3Y?9F]N=%]S='EL92`@(#T@)'-T>6QE.PH@
M("`@("`@("1T:&ES+3Y?9F]N=%]S:7IE7W!T(#T@)'-I>F4["B`@("`@("`@
M)'1H:7,M/E]F;VYT7W-I>F4@("`@/2`D<VEZ92`O("1T:&ES+3Y?<V-A;&4[
M"B`@("`@("`@)'1H:7,M/E]C=7)R96YT7V9O;G0@/2`F)'1H:7,M/E]F;VYT
M<ULD9F]N=&ME>5T["@H@("`@("`@("\J($]U='!U="!F;VYT(&EN9F]R;6%T
M:6]N(&EF(&%T(&QE87-T(&]N92!P86=E(&AA<R!B965N(&1E9FEN960N("HO
M"B`@("`@("`@:68@*"1T:&ES+3Y?<&%G92`^(#`I('L*("`@("`@("`@("`@
M)'1H:7,M/E]O=70H<W!R:6YT9B@G0E0@+T8E9"`E+C)F(%1F($54)RP@)'1H
M:7,M/E]C=7)R96YT7V9O;G1;)VDG72P@)'1H:7,M/E]F;VYT7W-I>F5?<'0I
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$969I;F5S('1H
M92!S:7IE(&]F('1H92!C=7)R96YT(&9O;G0N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&9L;V%T("1S:7IE("!4:&4@<VEZ92`H:6X@<&]I;G1S*2X*("`@("`J
M"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS971&;VYT"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E=$9O;G13:7IE*"1S:7IE*0H@("`@>PH@("`@("`@("\J($EF
M('1H92!F;VYT('-I>F4@:7,@86QR96%D>2!T:&4@8W5R<F5N="!F;VYT('-I
M>F4L(&IU<W0@<F5T=7)N+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7V9O;G1?
M<VEZ95]P="`]/2`D<VEZ92D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@
M("`@?0H@("`@("`@("\J(%-E="!T:&4@8W5R<F5N="!F;VYT('-I>F4L(&)O
M=&@@:6X@<&]I;G1S(&%N9"!S8V%L960@=&\@=7-E<@H@("`@("`@("`J('5N
M:71S+B`J+PH@("`@("`@("1T:&ES+3Y?9F]N=%]S:7IE7W!T(#T@)'-I>F4[
M"B`@("`@("`@)'1H:7,M/E]F;VYT7W-I>F4@/2`D<VEZ92`O("1T:&ES+3Y?
M<V-A;&4["@H@("`@("`@("\J($]U='!U="!F;VYT(&EN9F]R;6%T:6]N(&EF
M(&%T(&QE87-T(&]N92!P86=E(&AA<R!B965N(&1E9FEN960N("HO"B`@("`@
M("`@:68@*"1T:&ES+3Y?<&%G92`^(#`I('L*("`@("`@("`@("`@)'1H:7,M
M/E]O=70H<W!R:6YT9B@G0E0@+T8E9"`E+C)F(%1F($54)RP@)'1H:7,M/E]C
M=7)R96YT7V9O;G1;)VDG72P@)'1H:7,M/E]F;VYT7W-I>F5?<'0I*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@;F5W(&EN
M=&5R;F%L(&QI;FL@86YD(')E='5R;G,@:71S(&ED96YT:69I97(N($%N(&EN
M=&5R;F%L"B`@("`@*B!L:6YK(&ES(&$@8VQI8VMA8FQE(&%R96$@=VAI8V@@
M9&ER96-T<R!T;R!A;F]T:&5R('!L86-E('=I=&AI;B!T:&4*("`@("`J(&1O
M8W5M96YT+@H@("`@("H@5&AE(&ED96YT:69I97(@8V%N('1H96X@8F4@<&%S
M<V5D('1O($9I;&5?4$1&.CIC96QL+"!&:6QE7U!$1CHZ=W)I=&4L"B`@("`@
M*B!&:6QE7U!$1CHZ:6UA9V4@;W(@1FEL95]01$8Z.FQI;FLN(%1H92!D97-T
M:6YA=&EO;B!I<R!D969I;F5D('=I=&@*("`@("`J($9I;&5?4$1&.CIS971,
M:6YK+@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.F-E;&P*("`@("`J
M($!S964@1FEL95]01$8Z.E=R:71E"B`@("`@*B!`<V5E($9I;&5?4$1&.CII
M;6%G90H@("`@("H@0'-E92!&:6QE7U!$1CHZ3&EN:PH@("`@("H@0'-E92!&
M:6QE7U!$1CHZ4V5T3&EN:PH@("`@("HO"B`@("!F=6YC=&EO;B!A9&1,:6YK
M*"D*("`@('L*("`@("`@("`D;B`](&-O=6YT*"1T:&ES+3Y?;&EN:W,I("L@
M,3L*("`@("`@("`D=&AI<RT^7VQI;FMS6R1N72`](&%R<F%Y*#`L(#`I.PH@
M("`@("`@(')E='5R;B`D;CL*("`@('T*"B`@("`O*BH*("`@("`J($1E9FEN
M97,@=&AE('!A9V4@86YD('!O<VET:6]N(&$@;&EN:R!P;VEN=',@=&\N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&QI;FL@(%1H92!L:6YK(&ED
M96YT:69I97(@<F5T=7)N960@8GD@1FEL95]01$8Z.F%D9$QI;FLN"B`@("`@
M*B!`<&%R86T@9FQO870@)'D@("`@("`@3W)D:6YA=&4@;V8@=&%R9V5T('!O
M<VET:6]N.R`M,2!I;F1I8V%T97,@=&AE"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@8W5R<F5N="!P;W-I=&EO;BX@5&AE(&1E9F%U;'0@=F%L=64@
M:7,@,"`H=&]P(&]F"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<&%G
M92DN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<&%G92`@3G5M8F5R(&]F('1A
M<F=E="!P86=E.R`M,2!I;F1I8V%T97,@=&AE(&-U<G)E;G0*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!P86=E+B!4:&ES(&ES('1H92!D969A=6QT
M('9A;'5E+@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.F%D9$QI;FL*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5T3&EN:R@D;&EN:RP@)'D@/2`P+"`D
M<&%G92`]("TQ*0H@("`@>PH@("`@("`@(&EF("@D>2`]/2`M,2D@>PH@("`@
M("`@("`@("`D>2`]("1T:&ES+3YY.PH@("`@("`@('T*("`@("`@("!I9B`H
M)'!A9V4@/3T@+3$I('L*("`@("`@("`@("`@)'!A9V4@/2`D=&AI<RT^7W!A
M9V4["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?;&EN:W-;)&QI;FM=(#T@
M87)R87DH)'!A9V4L("1Y*3L*("`@('T*"B`@("`O*BH*("`@("`J(%!U=',@
M82!L:6YK(&]N(&$@<F5C=&%N9W5L87(@87)E82!O9B!T:&4@<&%G92X@5&5X
M="!O<B!I;6%G92!L:6YK<R!A<F4*("`@("`J(&=E;F5R86QL>2!P=70@=FEA
M($9I;&5?4$1&.CIC96QL+"!&:6QE7U!$1CHZ5W)I=&4@;W(@1FEL95]01$8Z
M.FEM86=E+`H@("`@("H@8G5T('1H:7,@;65T:&]D(&-A;B!B92!U<V5F=6P@
M9F]R(&EN<W1A;F-E('1O(&1E9FEN92!A(&-L:6-K86)L92!A<F5A"B`@("`@
M*B!I;G-I9&4@86X@:6UA9V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&9L;V%T
M("1X("`@("`@($%B<V-I<W-A(&]F('1H92!U<'!E<BUL969T(&-O<FYE<B!O
M9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&9L;V%T("1Y("`@("`@
M($]R9&EN871E(&]F('1H92!U<'!E<BUL969T(&-O<FYE<B!O9B!T:&4@<F5C
M=&%N9VQE+@H@("`@("H@0'!A<F%M(&9L;V%T("1W:61T:"`@(%=I9'1H(&]F
M('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@9FQO870@)&AE:6=H="`@
M2&5I9VAT(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@;6EX960@
M)&QI;FL@("`@55),(&]R(&ED96YT:69I97(@<F5T=7)N960@8GD@1FEL95]0
M1$8Z.F%D9$QI;FLN"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ861D
M3&EN:PH@("`@("H@0'-E92!&:6QE7U!$1CHZ8V5L;`H@("`@("H@0'-E92!&
M:6QE7U!$1CHZ5W)I=&4*("`@("`J($!S964@1FEL95]01$8Z.FEM86=E"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&QI;FLH)'@L("1Y+"`D=VED=&@L("1H96EG
M:'0L("1L:6YK*0H@("`@>PH@("`@("`@("\J(%-E="!U<"!T:&4@8V]O<F1I
M;F%T97,@=VET:"!C;W)R96-T('-C86QI;F<@:6X@<'0N("HO"B`@("`@("`@
M)'@@("`@("`]("1T:&ES+3Y?=&]0="@D>"D["B`@("`@("`@)'D@("`@("`]
M("1T:&ES+3YH4'0@+2`D=&AI<RT^7W1O4'0H)'DI.PH@("`@("`@("1W:61T
M:"`@/2`D=&AI<RT^7W1O4'0H)'=I9'1H*3L*("`@("`@("`D:&5I9VAT(#T@
M)'1H:7,M/E]T;U!T*"1H96EG:'0I.PH*("`@("`@("`O*B!3879E(&QI;FL@
M=&\@<&%G92!L:6YK<R!A<G)A>2X@*B\*("`@("`@("`D=&AI<RT^7VQI;FLH
M)'@L("1Y+"`D=VED=&@L("1H96EG:'0L("1L:6YK*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%!R:6YT<R!A(&-H87)A8W1E<B!S=')I;F<N(%1H92!O<FEG
M:6X@:7,@;VX@=&AE(&QE9G0@;V8@=&AE(&9I<G-T"B`@("`@*B!C:&%R86-T
M97(L(&]N('1H92!B87-E;&EN92X@5&AI<R!M971H;V0@86QL;W=S('1O('!L
M86-E(&$@<W1R:6YG"B`@("`@*B!P<F5C:7-E;'D@;VX@=&AE('!A9V4L(&)U
M="!I="!I<R!U<W5A;&QY(&5A<VEE<B!T;R!U<V4@1FEL95]01$8Z.F-E;&PL
M"B`@("`@*B!&:6QE7U!$1CHZ;75L=&E#96QL(&]R($9I;&5?4$1&.CI7<FET
M92!W:&EC:"!A<F4@=&AE('-T86YD87)D(&UE=&AO9',@=&\*("`@("`J('!R
M:6YT('1E>'0N"B`@("`@*@H@("`@("H@0'!A<F%M(&9L;V%T("1X("`@("`@
M06)S8VES<V$@;V8@=&AE(&]R:6=I;BX*("`@("`J($!P87)A;2!F;&]A="`D
M>2`@("`@($]R9&EN871E(&]F('1H92!O<FEG:6XN"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1T97AT("!3=')I;F<@=&\@<')I;G0N"B`@("`@*@H@("`@("H@
M0'-E92!&:6QE7U!$1CHZ<V5T1F]N=`H@("`@("H@0'-E92!&:6QE7U!$1CHZ
M8V5L;`H@("`@("H@0'-E92!&:6QE7U!$1CHZ;75L=&E#96QL"B`@("`@*B!`
M<V5E($9I;&5?4$1&.CI7<FET90H@("`@("HO"B`@("!F=6YC=&EO;B!T97AT
M*"1X+"`D>2P@)'1E>'0I"B`@("!["B`@("`@("`@+RH@4V-A;&4@8V]O<F1I
M;F%T97,@:6YT;R!P;VEN=',@86YD('-E="!C;W)R96-T(%D@<&]S:71I;VXN
M("HO"B`@("`@("`@)'@@/2`D=&AI<RT^7W1O4'0H)'@I.PH@("`@("`@("1Y
M(#T@)'1H:7,M/FA0="`M("1T:&ES+3Y?=&]0="@D>2D["@H@("`@("`@("\J
M($5S8V%P92!A;GD@<&]T96YT:6%L;'D@:&%R;69U;"!C:&%R86-T97)S+B`J
M+PH@("`@("`@("1T97AT(#T@)'1H:7,M/E]E<V-A<&4H)'1E>'0I.PH*("`@
M("`@("`D;W5T(#T@<W!R:6YT9B@G0E0@)2XR9B`E+C)F(%1D("@E<RD@5&H@
M150G+"`D>"P@)'DL("1T97AT*3L*("`@("`@("!I9B`H)'1H:7,M/E]U;F1E
M<FQI;F4@)B8@)'1E>'0@(3T@)R<I('L*("`@("`@("`@("`@)&]U="`N/2`G
M("<@+B`D=&AI<RT^7V1O56YD97)L:6YE*"1X+"`D>2P@)'1E>'0I.PH@("`@
M("`@('T*("`@("`@("`D=&AI<RT^7V]U="@D;W5T*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%=H96YE=F5R(&$@<&%G92!B<F5A:R!C;VYD:71I;VX@:7,@
M;65T+"!T:&4@;65T:&]D(&ES(&-A;&QE9"P@86YD('1H90H@("`@("H@8G)E
M86L@:7,@:7-S=65D(&]R(&YO="!D97!E;F1I;F<@;VX@=&AE(')E='5R;F5D
M('9A;'5E+B!4:&4@9&5F875L=`H@("`@("H@:6UP;&5M96YT871I;VX@<F5T
M=7)N<R!A('9A;'5E(&%C8V]R9&EN9R!T;R!T:&4@;6]D92!S96QE8W1E9"!B
M>0H@("`@("H@1FEL95]01$8Z<V5T075T;U!A9V5"<F5A:RX*("`@("`J(%1H
M:7,@;65T:&]D(&ES(&-A;&QE9"!A=71O;6%T:6-A;&QY(&%N9"!S:&]U;&0@
M;F]T(&)E(&-A;&QE9"!D:7)E8W1L>0H@("`@("H@8GD@=&AE(&%P<&QI8V%T
M:6]N+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;@H@("`@("H*("`@
M("`J($!S964@1FEL95]01$8Z.G-E=$%U=&]086=E0G)E86LN"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%C8V5P=%!A9V5"<F5A:R@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?875T;U]P86=E7V)R96%K.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4')I;G1S(&$@8V5L;"`H<F5C=&%N9W5L87(@87)E82D@=VET
M:"!O<'1I;VYA;"!B;W)D97)S+"!B86-K9W)O=6YD"B`@("`@*B!C;VQO<B!A
M;F0@8VAA<F%C=&5R('-T<FEN9RX@5&AE('5P<&5R+6QE9G0@8V]R;F5R(&]F
M('1H92!C96QL"B`@("`@*B!C;W)R97-P;VYD<R!T;R!T:&4@8W5R<F5N="!P
M;W-I=&EO;BX@5&AE('1E>'0@8V%N(&)E(&%L:6=N960@;W(*("`@("`J(&-E
M;G1E<F5D+B!!9G1E<B!T:&4@8V%L;"P@=&AE(&-U<G)E;G0@<&]S:71I;VX@
M;6]V97,@=&\@=&AE(')I9VAT(&]R('1O"B`@("`@*B!T:&4@;F5X="!L:6YE
M+B!)="!I<R!P;W-S:6)L92!T;R!P=70@82!L:6YK(&]N('1H92!T97AT+@H@
M("`@("H@268@875T;VUA=&EC('!A9V4@8G)E86MI;F<@:7,@96YA8FQE9"!A
M;F0@=&AE(&-E;&P@9V]E<R!B97EO;F0@=&AE"B`@("`@*B!L:6UI="P@82!P
M86=E(&)R96%K(&ES(&1O;F4@8F5F;W)E(&]U='!U='1I;F<N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&9L;V%T("1W:61T:"`@($-E;&P@=VED=&@N($EF(#`L
M('1H92!C96QL(&5X=&5N9',@=7`@=&\@=&AE(')I9VAT"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@;6%R9VEN+@H@("`@("H@0'!A<F%M(&9L;V%T
M("1H96EG:'0@($-E;&P@:&5I9VAT+B!$969A=6QT('9A;'5E.B`P+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=&5X="`@(%-T<FEN9R!T;R!P<FEN="X@1&5F
M875L="!V86QU93H@96UP='DN"B`@("`@*B!`<&%R86T@;6EX960@)&)O<F1E
M<B`@26YD:6-A=&5S(&EF(&)O<F1E<G,@;75S="!B92!D<F%W;B!A<F]U;F0@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@8V5L;"X@5&AE('9A
M;'5E(&-A;B!B92!E:71H97(@82!N=6UB97(Z"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`M(#`Z(&YO(&)O<F1E<B`H9&5F875L="D*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("T@,3H@9G)A;64*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!O<B!A('-T<FEN9R!C;VYT86EN:6YG('-O
M;64@;W(@86QL(&]F('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M(&9O;&QO=VEN9R!C:&%R86-T97)S("AI;B!A;GD@;W)D97(I.@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@+2!,.B!L969T"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`M(%0Z('1O<`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@+2!2.B!R:6=H=`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@+2!".B!B;W1T;VT*("`@("`J($!P87)A;2!I;G1E9V5R
M("1L;B`@("!);F1I8V%T97,@=VAE<F4@=&AE(&-U<G)E;G0@<&]S:71I;VX@
M<VAO=6QD(&=O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@869T97(@
M=&AE(&-A;&PN(%!O<W-I8FQE('9A;'5E<R!A<F4Z"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`M(#`Z('1O('1H92!R:6=H="`H9&5F875L="D*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@,3H@=&\@=&AE(&)E
M9VEN;FEN9R!O9B!T:&4@;F5X="!L:6YE"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`M(#(Z(&)E;&]W"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@4'5T=&EN9R`Q(&ES(&5Q=6EV86QE;G0@=&\@<'5T=&EN9R`P(&%N
M9"!C86QL:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@1FEL95]0
M1$8Z.FYE=TQI;F4@:G5S="!A9G1E<BX*("`@("`J($!P87)A;2!S=')I;F<@
M)&%L:6=N("!!;&QO=W,@=&\@8V5N=&5R(&]R(&%L:6=N('1H92!T97AT+B!0
M;W-S:6)L90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('9A;'5E<R!A
M<F4Z"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M($P@;W(@96UP
M='D@<W1R:6YG.B!L969T("AD969A=6QT*0H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@+2!#.B!C96YT97(*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("T@4CH@<FEG:'0*("`@("`J($!P87)A;2!I;G1E9V5R("1F
M:6QL("!);F1I8V%T97,@:68@=&AE(&-E;&P@9FEL;"!T>7!E+B!0;W-S:6)L
M92!V86QU97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!A<F4Z"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M(#`Z('1R86YS<&%R96YT
M("AD969A=6QT*0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2`Q
M.B!P86EN=&5D"B`@("`@*B!`<&%R86T@<W1R:6YG("1L:6YK("`@55),(&]R
M(&ED96YT:69I97(@<F5T=7)N960@8GD*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!&:6QE7U!$1CIA9&1,:6YK+@H@("`@("H*("`@
M("`J($!S964@1FEL95]01$8Z.G-E=$9O;G0*("`@("`J($!S964@1FEL95]0
M1$8Z.G-E=$1R87=#;VQO<@H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T1FEL
M;$-O;&]R"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS971,:6YE5VED=&@*("`@
M("`J($!S964@1FEL95]01$8Z.F%D9$QI;FL*("`@("`J($!S964@1FEL95]0
M1$8Z.FYE=TQI;F4*("`@("`J($!S964@1FEL95]01$8Z.FUU;'1I0V5L;`H@
M("`@("H@0'-E92!&:6QE7U!$1CHZ5W)I=&4*("`@("`J($!S964@1FEL95]0
M1$8Z.G-E=$%U=&]086=E0G)E86L*("`@("`J+PH@("`@9G5N8W1I;VX@8V5L
M;"@D=VED=&@L("1H96EG:'0@/2`P+"`D=&5X="`]("<G+"`D8F]R9&5R(#T@
M,"P@)&QN(#T@,"P@)&%L:6=N(#T@)R<L("1F:6QL(#T@,"P@)&QI;FL@/2`G
M)RD*("`@('L*("`@("`@("`D:R`]("1T:&ES+3Y?<V-A;&4["B`@("`@("`@
M:68@*"1T:&ES+3YY("L@)&AE:6=H="`^("1T:&ES+3Y?<&%G95]B<F5A:U]T
M<FEG9V5R("8F("$D=&AI<RT^7VEN7V9O;W1E<B`F)B`D=&AI<RT^06-C97!T
M4&%G94)R96%K*"DI('L*("`@("`@("`@("`@)'@@/2`D=&AI<RT^>#L*("`@
M("`@("`@("`@)'=S(#T@)'1H:7,M/E]W;W)D7W-P86-I;F<["B`@("`@("`@
M("`@(&EF("@D=W,@/B`P*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W=O
M<F1?<W!A8VEN9R`](#`["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G
M,"!4=R<I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3YA9&10
M86=E*"1T:&ES+3Y?8W5R<F5N=%]O<FEE;G1A=&EO;BD["B`@("`@("`@("`@
M("1T:&ES+3YX(#T@)'@["B`@("`@("`@("`@(&EF("@D=W,@/B`P*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7W=O<F1?<W!A8VEN9R`]("1W<SL*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;W5T*'-P<FEN=&8H)R4N,V8@5'<G+"`D
M=W,@*B`D:RDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF
M("@D=VED=&@@/3T@,"D@>PH@("`@("`@("`@("`D=VED=&@@/2`D=&AI<RT^
M=R`M("1T:&ES+3Y?<FEG:'1?;6%R9VEN("T@)'1H:7,M/G@["B`@("`@("`@
M?0H@("`@("`@("1S(#T@)R<["B`@("`@("`@:68@*"1F:6QL(#T](#$@?'P@
M)&)O<F1E<B`]/2`Q*2!["B`@("`@("`@("`@(&EF("@D9FEL;"`]/2`Q*2![
M"B`@("`@("`@("`@("`@("`D;W`@/2`H)&)O<F1E<B`]/2`Q*2`_("=")R`Z
M("=F)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1O
M<"`]("=3)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<R`]('-P<FEN
M=&8H)R4N,F8@)2XR9B`E+C)F("4N,F8@<F4@)7,@)RP@)'1H:7,M/G@@*B`D
M:RP@*"1T:&ES+3YH("T@)'1H:7,M/GDI("H@)&LL("1W:61T:"`J("1K+"`M
M)&AE:6=H="`J("1K+"`D;W`I.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?
M<W1R:6YG*"1B;W)D97(I*2!["B`@("`@("`@("`@(&EF("AS=')P;W,H)&)O
M<F1E<BP@)TPG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1S("X]
M('-P<FEN=&8H)R4N,F8@)2XR9B!M("4N,F8@)2XR9B!L(%,@)RP@)'1H:7,M
M/G@@*B`D:RP@*"1T:&ES+3YH("T@)'1H:7,M/GDI("H@)&LL("1T:&ES+3YX
M("H@)&LL("@D=&AI<RT^:"`M("@D=&AI<RT^>2`K("1H96EG:'0I*2`J("1K
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H<W1R<&]S*"1B;W)D
M97(L("=4)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D<R`N/2!S
M<')I;G1F*"<E+C)F("4N,F8@;2`E+C)F("4N,F8@;"!3("<L("1T:&ES+3YX
M("H@)&LL("@D=&AI<RT^:"`M("1T:&ES+3YY*2`J("1K+"`H)'1H:7,M/G@@
M*R`D=VED=&@I("H@)&LL("@D=&AI<RT^:"`M("1T:&ES+3YY*2`J("1K*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H<W1R<&]S*"1B;W)D97(L
M("=2)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D<R`N/2!S<')I
M;G1F*"<E+C)F("4N,F8@;2`E+C)F("4N,F8@;"!3("<L("@D=&AI<RT^>"`K
M("1W:61T:"D@*B`D:RP@*"1T:&ES+3YH("T@)'1H:7,M/GDI("H@)&LL("@D
M=&AI<RT^>"`K("1W:61T:"D@*B`D:RP@*"1T:&ES+3YH("T@*"1T:&ES+3YY
M("L@)&AE:6=H="DI("H@)&LI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("AS=')P;W,H)&)O<F1E<BP@)T(G*2`A/3T@9F%L<V4I('L*("`@("`@
M("`@("`@("`@("1S("X]('-P<FEN=&8H)R4N,F8@)2XR9B!M("4N,F8@)2XR
M9B!L(%,@)RP@)'1H:7,M/G@@*B`D:RP@*"1T:&ES+3YH("T@*"1T:&ES+3YY
M("L@)&AE:6=H="DI("H@)&LL("@D=&AI<RT^>"`K("1W:61T:"D@*B`D:RP@
M*"1T:&ES+3YH("T@*"1T:&ES+3YY("L@)&AE:6=H="DI("H@)&LI.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D=&5X="`A/2`G)RD@
M>PH@("`@("`@("`@("!I9B`H)&%L:6=N(#T]("=2)RD@>PH@("`@("`@("`@
M("`@("`@)&1X(#T@)'=I9'1H("T@)'1H:7,M/E]C96QL7VUA<F=I;B`M("1T
M:&ES+3YG9713=')I;F=7:61T:"@D=&5X="D["B`@("`@("`@("`@('T@96QS
M96EF("@D86QI9VX@/3T@)T,G*2!["B`@("`@("`@("`@("`@("`D9'@@/2`H
M)'=I9'1H("T@)'1H:7,M/F=E=%-T<FEN9U=I9'1H*"1T97AT*2D@+R`R.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&1X(#T@)'1H
M:7,M/E]C96QL7VUA<F=I;CL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M=&5X="`]('-T<E]R97!L86-E*"<I)RP@)UQ<*2<L('-T<E]R97!L86-E*"<H
M)RP@)UQ<*"<L('-T<E]R97!L86-E*"=<7"<L("=<7%Q<)RP@)'1E>'0I*2D[
M"B`@("`@("`@("`@("1T97-T,B`]("@H+C4@*B`D:&5I9VAT*2`K("@N,R`J
M("1T:&ES+3Y?9F]N=%]S:7IE*2D["B`@("`@("`@("`@("1T97-T,2`]("1T
M:&ES+3YF:%!T("T@*"@D=&AI<RT^>2`K("1T97-T,BD@*B`D:RD["B`@("`@
M("`@("`@("1S("X]('-P<FEN=&8H)T)4("4N,F8@)2XR9B!49"`H)7,I(%1J
M($54)RP@*"1T:&ES+3YX("L@)&1X*2`J("1K+"`H)'1H:7,M/F@@+2`H)'1H
M:7,M/GD@*R`N-2`J("1H96EG:'0@*R`N,R`J("1T:&ES+3Y?9F]N=%]S:7IE
M*2D@*B`D:RP@)'1E>'0I.PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]U;F1E
M<FQI;F4I('L*("`@("`@("`@("`@("`@("1S("X]("<@)R`N("1T:&ES+3Y?
M9&]5;F1E<FQI;F4H)'1H:7,M/G@@*R`D9'@L("1T:&ES+3YY("L@+C4@*B`D
M:&5I9VAT("L@+C,@*B`D=&AI<RT^7V9O;G1?<VEZ92P@)'1E>'0I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&EF("@D;&EN:RD@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/FQI;FLH)'1H:7,M/G@@*R`D9'@L("1T:&ES+3YY("L@
M+C4@*B`D:&5I9VAT+2XU("H@)'1H:7,M/E]F;VYT7W-I>F4L("1T:&ES+3YG
M9713=')I;F=7:61T:"@D=&5X="DL("1T:&ES+3Y?9F]N=%]S:7IE+"`D;&EN
M:RD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"1S*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"1S*3L*("`@("`@("!]"B`@("`@
M("`@)'1H:7,M/E]L87-T7VAE:6=H="`]("1H96EG:'0["B`@("`@("`@:68@
M*"1L;B`^(#`I('L*("`@("`@("`@("`@+RH@1V\@=&\@;F5X="!L:6YE+B`J
M+PH@("`@("`@("`@("`D=&AI<RT^>2`K/2`D:&5I9VAT.PH@("`@("`@("`@
M("!I9B`H)&QN(#T](#$I('L*("`@("`@("`@("`@("`@("1T:&ES+3YX(#T@
M)'1H:7,M/E]L969T7VUA<F=I;CL*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1T:&ES+3YX("L]("1W:61T:#L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&UE=&AO9"!A;&QO=W,@
M<')I;G1I;F<@=&5X="!W:71H(&QI;F4@8G)E86MS+B!4:&5Y(&-A;B!B90H@
M("`@("H@875T;VUA=&EC("AA<R!S;V]N(&%S('1H92!T97AT(')E86-H97,@
M=&AE(')I9VAT(&)O<F1E<B!O9B!T:&4@8V5L;"D@;W(*("`@("`J(&5X<&QI
M8VET("AV:6$@=&AE(%QN(&-H87)A8W1E<BDN($%S(&UA;GD@8V5L;',@87,@
M;F5C97-S87)Y(&%R92!O=71P=70L"B`@("`@*B!O;F4@8F5L;W<@=&AE(&]T
M:&5R+@H@("`@("H@5&5X="!C86X@8F4@86QI9VYE9"P@8V5N=&5R960@;W(@
M:G5S=&EF:65D+B!4:&4@8V5L;"!B;&]C:R!C86X@8F4*("`@("`J(&9R86UE
M9"!A;F0@=&AE(&)A8VMG<F]U;F0@<&%I;G1E9"X*("`@("`J"B`@("`@*B!`
M<&%R86T@9FQO870@)'=I9'1H("`@5VED=&@@;V8@8V5L;',N($EF(#`L('1H
M97D@97AT96YD('5P('1O('1H92!R:6=H=`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(&UA<F=I;B!O9B!T:&4@<&%G92X*("`@("`J($!P87)A;2!F
M;&]A="`D:&5I9VAT("!(96EG:'0@;V8@8V5L;',N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1T97AT("`@4W1R:6YG('1O('!R:6YT+@H@("`@("H@0'!A<F%M
M(&UI>&5D("1B;W)D97(@($EN9&EC871E<R!I9B!B;W)D97)S(&UU<W0@8F4@
M9')A=VX@87)O=6YD('1H92!C96QL"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@8FQO8VLN(%1H92!V86QU92!C86X@8F4@96ET:&5R(&$@;G5M8F5R
M.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2`P.B!N;R!B;W)D
M97(@*&1E9F%U;'0I"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M
M(#$Z(&9R86UE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@;W(@82!S
M=')I;F<@8V]N=&%I;FEN9R!S;VUE(&]R(&%L;"!O9B!T:&4*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!F;VQL;W=I;F<@8VAA<F%C=&5R<R`H:6X@
M86YY(&]R9&5R*3H*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`M
M($PZ(&QE9G0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`M(%0Z
M('1O<`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("T@4CH@<FEG
M:'0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`M($(Z(&)O='1O
M;0H@("`@("H@0'!A<F%M('-T<FEN9R`D86QI9VX@(%-E=',@=&AE('1E>'0@
M86QI9VYM96YT+B!0;W-S:6)L92!V86QU97,@87)E.@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@+2!,.B!L969T(&%L:6=N;65N=`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@+2!#.B!C96YT97(*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("T@4CH@<FEG:'0@86QI9VYM96YT"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M($HZ(&IU<W1I9FEC871I
M;VX@*&1E9F%U;'0@=F%L=64I"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9FEL
M;"`@26YD:6-A=&5S(&EF('1H92!C96QL(&)A8VMG<F]U;F0@;75S=#H*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@,#H@=')A;G-P87)E;G0@
M*&1E9F%U;'0I"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M(#$Z
M('!A:6YT960*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS971&;VYT
M"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS971$<F%W0V]L;W(*("`@("`J($!S
M964@1FEL95]01$8Z.G-E=$9I;&Q#;VQO<@H@("`@("H@0'-E92!&:6QE7U!$
M1CHZ<V5T3&EN95=I9'1H"B`@("`@*B!`<V5E($9I;&5?4$1&.CIC96QL"B`@
M("`@*B!`<V5E($9I;&5?4$1&.CIW<FET90H@("`@("H@0'-E92!&:6QE7U!$
M1CHZ<V5T075T;U!A9V5"<F5A:PH@("`@("HO"B`@("!F=6YC=&EO;B!M=6QT
M:4-E;&PH)'=I9'1H+"`D:&5I9VAT+"`D=&5X="P@)&)O<F1E<B`](#`L("1A
M;&EG;B`]("=*)RP@)&9I;&P@/2`P*0H@("`@>PH@("`@("`@("1C=R`]("8D
M=&AI<RT^7V-U<G)E;G1?9F]N=%LG8W<G73L*("`@("`@("!I9B`H)'=I9'1H
M(#T](#`I('L*("`@("`@("`@("`@)'=I9'1H(#T@)'1H:7,M/G<@+2`D=&AI
M<RT^7W)I9VAT7VUA<F=I;B`M("1T:&ES+3YX.PH@("`@("`@('T*("`@("`@
M("`D=VUA>"`]("@D=VED=&@M,B`J("1T:&ES+3Y?8V5L;%]M87)G:6XI("H@
M,3`P,"`O("1T:&ES+3Y?9F]N=%]S:7IE.PH@("`@("`@("1S(#T@<W1R7W)E
M<&QA8V4H(EQR(BP@)R<L("1T97AT*3L*("`@("`@("`D;F(@/2!S=')L96XH
M)',I.PH@("`@("`@(&EF("@D;F(@/B`P("8F("1S6R1N8BTQ72`]/2`B7&XB
M*2!["B`@("`@("`@("`@("1N8BTM.PH@("`@("`@('T*("`@("`@("`D8B`]
M(#`["B`@("`@("`@:68@*"1B;W)D97(I('L*("`@("`@("`@("`@:68@*"1B
M;W)D97(@/3T@,2D@>PH@("`@("`@("`@("`@("`@)&)O<F1E<B`]("=,5%)"
M)SL*("`@("`@("`@("`@("`@("1B(#T@)TQ25"<["B`@("`@("`@("`@("`@
M("`D8C(@/2`G3%(G.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)&(R(#T@)R<["B`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1B
M;W)D97(L("=,)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@
M)&(R("X]("=,)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&EF("AS=')P;W,H)&)O<F1E<BP@)U(G*2`A/3T@9F%L<V4I('L*("`@("`@
M("`@("`@("`@("`@("`D8C(@+CT@)U(G.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)&(@/2`H<W1R<&]S*"1B;W)D97(L("=4)RD@(3T]
M(&9A;'-E*2`_("1B,B`N("=4)R`Z("1B,CL*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("`D<V5P(#T@+3$["B`@("`@("`@)&D@("`](#`["B`@
M("`@("`@)&H@("`](#`["B`@("`@("`@)&P@("`](#`["B`@("`@("`@)&YS
M("`](#`["B`@("`@("`@)&YL("`](#$["B`@("`@("`@=VAI;&4@*"1I(#P@
M)&YB*2!["B`@("`@("`@("`@("\J($=E="!N97AT(&-H87)A8W1E<BX@*B\*
M("`@("`@("`@("`@)&,@/2`D<ULD:5T["B`@("`@("`@("`@(&EF("@D8R`]
M/2`B7&XB*2!["B`@("`@("`@("`@("`@("`O*B!%>'!L:6-I="!L:6YE(&)R
M96%K+B`J+PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?=V]R9%]S<&%C
M:6YG(#X@,"D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=V]R9%]S
M<&%C:6YG(#T@,#L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G
M,"!4=R<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1H
M:7,M/F-E;&PH)'=I9'1H+"`D:&5I9VAT+"!S=6)S='(H)',L("1J+"`D:2TD
M:BDL("1B+"`R+"`D86QI9VXL("1F:6QL*3L*("`@("`@("`@("`@("`@("1I
M*RL["B`@("`@("`@("`@("`@("`D<V5P(#T@+3$["B`@("`@("`@("`@("`@
M("`D:B`]("1I.PH@("`@("`@("`@("`@("`@)&P@/2`P.PH@("`@("`@("`@
M("`@("`@)&YS(#T@,#L*("`@("`@("`@("`@("`@("1N;"LK.PH@("`@("`@
M("`@("`@("`@:68@*"1B;W)D97(@)B8@)&YL(#T](#(I('L*("`@("`@("`@
M("`@("`@("`@("`D8B`]("1B,CL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("@D8R`]/2`G("<I('L*("`@("`@("`@("`@("`@("1S97`@/2`D:3L*
M("`@("`@("`@("`@("`@("1L<R`]("1L.PH@("`@("`@("`@("`@("`@)&YS
M*RL["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&P@*ST@)&-W6R1C73L*
M("`@("`@("`@("`@:68@*"1L(#X@)'=M87@I('L*("`@("`@("`@("`@("`@
M("\J($%U=&]M871I8R!L:6YE(&)R96%K+B`J+PH@("`@("`@("`@("`@("`@
M:68@*"1S97`@/3T@+3$I('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&D@
M/3T@)&HI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&DK*SL*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES
M+3Y?=V]R9%]S<&%C:6YG(#X@,"D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W=O<F1?<W!A8VEN9R`](#`["B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;W5T*"<P(%1W)RD["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC96QL*"1W:61T:"P@
M)&AE:6=H="P@<W5B<W1R*"1S+"`D:BP@)&D@+2`D:BDL("1B+"`R+"`D86QI
M9VXL("1F:6QL*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@:68@*"1A;&EG;B`]/2`G2B<I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]W;W)D7W-P86-I;F<@/2`H)&YS/C$I(#\@
M*"1W;6%X("T@)&QS*2\Q,#`P("H@)'1H:7,M/E]F;VYT7W-I>F4@+R`H)&YS
M("T@,2D@.B`P.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V]U
M="AS<')I;G1F*"<E+C-F(%1W)RP@)'1H:7,M/E]W;W)D7W-P86-I;F<@*B`D
M=&AI<RT^7W-C86QE*2D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YC96QL*"1W:61T:"P@)&AE:6=H="P@<W5B
M<W1R*"1S+"`D:BP@)'-E<"`M("1J*2P@)&(L(#(L("1A;&EG;BP@)&9I;&PI
M.PH@("`@("`@("`@("`@("`@("`@("1I(#T@)'-E<"`K(#$["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`D<V5P(#T@+3$["B`@("`@("`@
M("`@("`@("`D:B`]("1I.PH@("`@("`@("`@("`@("`@)&P@/2`P.PH@("`@
M("`@("`@("`@("`@)&YS(#T@,#L*("`@("`@("`@("`@("`@("1N;"LK.PH@
M("`@("`@("`@("`@("`@:68@*"1B;W)D97(@)B8@)&YL(#T](#(I('L*("`@
M("`@("`@("`@("`@("`@("`D8B`]("1B,CL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1I*RL["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@+RH@3&%S="!C:'5N:RX@
M*B\*("`@("`@("!I9B`H)'1H:7,M/E]W;W)D7W-P86-I;F<@/B`P*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?=V]R9%]S<&%C:6YG(#T@,#L*("`@("`@("`@
M("`@)'1H:7,M/E]O=70H)S`@5'<G*3L*("`@("`@("!]"B`@("`@("`@:68@
M*"1B;W)D97(@)B8@<W1R<&]S*"1B;W)D97(L("=")RD@(3T](&9A;'-E*2![
M"B`@("`@("`@("`@("1B("X]("=")SL*("`@("`@("!]"B`@("`@("`@)'1H
M:7,M/F-E;&PH)'=I9'1H+"`D:&5I9VAT+"!S=6)S='(H)',L("1J+"`D:2DL
M("1B+"`R+"`D86QI9VXL("1F:6QL*3L*("`@("`@("`D=&AI<RT^>"`]("1T
M:&ES+3Y?;&5F=%]M87)G:6X["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES
M(&UE=&AO9"!P<FEN=',@=&5X="!F<F]M('1H92!C=7)R96YT('!O<VET:6]N
M+B!7:&5N('1H92!R:6=H=`H@("`@("H@;6%R9VEN(&ES(')E86-H960@*&]R
M('1H92!<;B!C:&%R86-T97(@:7,@;65T*2!A(&QI;F4@8G)E86L@;V-C=7)S
M(&%N9`H@("`@("H@=&5X="!C;VYT:6YU97,@9G)O;2!T:&4@;&5F="!M87)G
M:6XN(%5P;VX@;65T:&]D(&5X:70L('1H92!C=7)R96YT"B`@("`@*B!P;W-I
M=&EO;B!I<R!L969T(&IU<W0@870@=&AE(&5N9"!O9B!T:&4@=&5X="X*("`@
M("`J($ET(&ES('!O<W-I8FQE('1O('!U="!A(&QI;FL@;VX@=&AE('1E>'0N
M"B`@("`@*@H@("`@("H@17AA;7!L93H*("`@("`J("\O0F5G:6X@=VET:"!R
M96=U;&%R(&9O;G0*("`@("`J("1P9&8M/G-E=$9O;G0H)T%R:6%L)RPG)RPQ
M-"D["B`@("`@*B`D<&1F+3YW<FET92@U+"=6:7-I="`G*3L*("`@("`J("\O
M5&AE;B!P=70@82!B;'5E('5N9&5R;&EN960@;&EN:PH@("`@("H@)'!D9BT^
M<V5T5&5X=$-O;&]R*#`L,"PR-34I.PH@("`@("H@)'!D9BT^<V5T1F]N="@G
M)RPG52<I.PH@("`@("H@)'!D9BT^=W)I=&4H-2PG=W=W+F9P9&8N;W)G)RPG
M:'1T<#HO+W=W=RYF<&1F+F]R9R<I.PH@("`@("H*("`@("`J($!P87)A;2!F
M;&]A="`D:&5I9VAT("!,:6YE(&AE:6=H="X*("`@("`J($!P87)A;2!S=')I
M;F<@)'1E>'0@("!3=')I;F<@=&\@<')I;G0N"B`@("`@*B!`<&%R86T@;6EX
M960@)&QI;FL@("`@55),(&]R(&ED96YT:69I97(@<F5T=7)N960@8GD@061D
M3&EN:R@I+@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.G-E=$9O;G0*
M("`@("`J($!S964@1FEL95]01$8Z.F%D9$QI;FL*("`@("`J($!S964@1FEL
M95]01$8Z.FUU;'1I0V5L;`H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T075T
M;U!A9V5"<F5A:PH@("`@("HO"B`@("!F=6YC=&EO;B!W<FET92@D:&5I9VAT
M+"`D=&5X="P@)&QI;FL@/2`G)RD*("`@('L*("`@("`@("`D8W<@/2`F)'1H
M:7,M/E]C=7)R96YT7V9O;G1;)V-W)UT["B`@("`@("`@)'=I9'1H(#T@)'1H
M:7,M/G<@+2`D=&AI<RT^7W)I9VAT7VUA<F=I;B`M("1T:&ES+3YX.PH@("`@
M("`@("1W;6%X(#T@*"1W:61T:"`M(#(@*B`D=&AI<RT^7V-E;&Q?;6%R9VEN
M*2`J(#$P,#`@+R`D=&AI<RT^7V9O;G1?<VEZ93L*("`@("`@("`D<R`]('-T
M<E]R97!L86-E*")<<B(L("<G+"`D=&5X="D["B`@("`@("`@)&YB(#T@<W1R
M;&5N*"1S*3L*("`@("`@("`D<V5P(#T@+3$["B`@("`@("`@)&D@/2`P.PH@
M("`@("`@("1J(#T@,#L*("`@("`@("`D;"`](#`["B`@("`@("`@)&YL(#T@
M,3L*("`@("`@("!W:&EL92`H)&D@/"`D;F(I('L*("`@("`@("`@("`@+RH@
M1V5T(&YE>'0@8VAA<F%C=&5R+B`J+PH@("`@("`@("`@("`D8R`]("1S>R1I
M?3L*("`@("`@("`@("`@:68@*"1C(#T](")<;B(I('L*("`@("`@("`@("`@
M("`@("\J($5X<&QI8VET(&QI;F4@8G)E86LN("HO"B`@("`@("`@("`@("`@
M("`D=&AI<RT^8V5L;"@D=VED=&@L("1H96EG:'0L('-U8G-T<B@D<RP@)&HL
M("1I("T@)&HI+"`P+"`R+"`G)RP@,"P@)&QI;FLI.PH@("`@("`@("`@("`@
M("`@)&DK*SL*("`@("`@("`@("`@("`@("1S97`@/2`M,3L*("`@("`@("`@
M("`@("`@("1J(#T@)&D["B`@("`@("`@("`@("`@("`D;"`](#`["B`@("`@
M("`@("`@("`@("!I9B`H)&YL(#T](#$I('L*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^>"`]("1T:&ES+3Y?;&5F=%]M87)G:6X["B`@("`@("`@("`@
M("`@("`@("`@)'=I9'1H(#T@)'1H:7,M/G<@+2`D=&AI<RT^7W)I9VAT7VUA
M<F=I;B`M("1T:&ES+3YX.PH@("`@("`@("`@("`@("`@("`@("1W;6%X(#T@
M*"1W:61T:"`M(#(@*B`D=&AI<RT^7V-E;&Q?;6%R9VEN*2`J(#$P,#`@+R`D
M=&AI<RT^7V9O;G1?<VEZ93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1N;"LK.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@:68@*"1C(#T]("<@)RD@>PH@("`@("`@
M("`@("`@("`@)'-E<"`]("1I.PH@("`@("`@("`@("`@("`@)&QS(#T@)&P[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&P@*ST@)&-W6R1C73L*("`@
M("`@("`@("`@:68@*"1L(#X@)'=M87@I('L*("`@("`@("`@("`@("`@("\J
M($%U=&]M871I8R!L:6YE(&)R96%K+B`J+PH@("`@("`@("`@("`@("`@:68@
M*"1S97`@/3T@+3$I('L*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M
M/G@@/B`D=&AI<RT^7VQE9G1?;6%R9VEN*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("\J($UO=F4@=&\@;F5X="!L:6YE+B`J+PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^>"`]("1T:&ES+3Y?;&5F=%]M87)G:6X["B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YY("L]("1H96EG:'0["B`@
M("`@("`@("`@("`@("`@("`@("`@("1W:61T:"`]("1T:&ES+3YW("T@)'1H
M:7,M/E]R:6=H=%]M87)G:6X@+2`D=&AI<RT^>#L*("`@("`@("`@("`@("`@
M("`@("`@("`@)'=M87@@/2`H)'=I9'1H("T@,B`J("1T:&ES+3Y?8V5L;%]M
M87)G:6XI("H@,3`P,"`O("1T:&ES+3Y?9F]N=%]S:7IE.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D:2LK.PH@("`@("`@("`@("`@("`@("`@("`@("`D
M;FPK*SL*("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF("@D:2`]
M/2`D:BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V5L
M;"@D=VED=&@L("1H96EG:'0L('-U8G-T<B@D<RP@)&HL("1I("T@)&HI+"`P
M+"`R+"`G)RP@,"P@)&QI;FLI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V5L;"@D=VED=&@L("1H96EG
M:'0L('-U8G-T<B@D<RP@)&HL("1S97`@+2`D:BDL(#`L(#(L("<G+"`P+"`D
M;&EN:RD["B`@("`@("`@("`@("`@("`@("`@)&D@/2`D<V5P("L@,3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1S97`@/2`M,3L*("`@
M("`@("`@("`@("`@("1J(#T@)&D["B`@("`@("`@("`@("`@("`D;"`](#`[
M"B`@("`@("`@("`@("`@("!I9B`H)&YL(#T](#$I('L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^>"`]("1T:&ES+3Y?;&5F=%]M87)G:6X["B`@("`@
M("`@("`@("`@("`@("`@)'=I9'1H(#T@)'1H:7,M/G<@+2`D=&AI<RT^7W)I
M9VAT7VUA<F=I;B`M("1T:&ES+3YX.PH@("`@("`@("`@("`@("`@("`@("1W
M;6%X(#T@*"1W:61T:"`M(#(@*B`D=&AI<RT^7V-E;&Q?;6%R9VEN*2`J(#$P
M,#`@+R`D=&AI<RT^7V9O;G1?<VEZ93L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1N;"LK.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<V4*("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@?0H@("`@("`@
M("\J($QA<W0@8VAU;FLN("HO"B`@("`@("`@:68@*"1I("$]("1J*2!["B`@
M("`@("`@("`@("1T:&ES+3YC96QL*"1L("\@,3`P,"`J("1T:&ES+3Y?9F]N
M=%]S:7IE+"`D:&5I9VAT+"!S=6)S='(H)',L("1J+"`D:2DL(#`L(#`L("<G
M+"`P+"`D;&EN:RD["B`@("`@("`@?0H@("`@?0H*("`@("`O*BH*("`@("`J
M('=R:71E(%)O=&%T960@5&5X="X*("`@("`J"B`@("`@*B!7<FET92!T97AT
M(&%T(&%N(&%N9VQE+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1X
M("`@("`@("`@6"!C;V]R9&EN871E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)'D@("`@("`@("!9(&-O;W)D:6YA=&4N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T97AT("`@("`@(%1E>'0@=&\@=W)I=&4N"B`@("`@*B!`<&%R86T@9FQO
M870@)'1E>'1?86YG;&4@($%N9VQE('1O(')O=&%T92`H16<N(#DP(#T@8F]T
M=&]M('1O('1O<"DN"B`@("`@*B!`<&%R86T@9FQO870@)&9O;G1?86YG;&4@
M(%)O=&%T92!C:&%R86-T97)S(&%S('=E;&P@87,@=&5X="X*("`@("`J"B`@
M("`@*B!`<V5E($9I;&5?4$1&.CIS971&;VYT"B`@("`@*B\*("`@("!F=6YC
M=&EO;B!W<FET95)O=&%T960H)'@L("1Y+"`D=&5X="P@)'1E>'1?86YG;&4L
M("1F;VYT7V%N9VQE(#T@,"D*("`@("!["B`@("`@("`@("\J($5S8V%P92!T
M97AT+B`J+PH@("`@("`@("`D=&5X="`]("1T:&ES+3Y?97-C87!E*"1T97AT
M*3L*"B`@("`@("`@("1F;VYT7V%N9VQE("L](#DP("L@)'1E>'1?86YG;&4[
M"B`@("`@("`@("1T97AT7V%N9VQE("H]($U?4$D@+R`Q.#`["B`@("`@("`@
M("1F;VYT7V%N9VQE("H]($U?4$D@+R`Q.#`["@H@("`@("`@("`D=&5X=%]D
M>"`](&-O<R@D=&5X=%]A;F=L92D["B`@("`@("`@("1T97AT7V1Y(#T@<VEN
M*"1T97AT7V%N9VQE*3L*("`@("`@("`@)&9O;G1?9'@@/2!C;W,H)&9O;G1?
M86YG;&4I.PH@("`@("`@("`D9F]N=%]D>2`]('-I;B@D9F]N=%]A;F=L92D[
M"@H@("`@("`@("`D<ST@<W!R:6YT9B@G0E0@)2XR9B`E+C)F("4N,F8@)2XR
M9B`E+C)F("4N,F8@5&T@*"5S*2!4:B!%5"<L"B`@("`@("`@("`@("`@("`@
M("`@("1T97AT7V1X+"`D=&5X=%]D>2P@)&9O;G1?9'@L("1F;VYT7V1Y+`H@
M("`@("`@("`@("`@("`@("`@("`D>"`J("1T:&ES+3Y?<V-A;&4L("@D=&AI
M<RT^:"TD>2D@*B`D=&AI<RT^7W-C86QE+"`D=&5X="D["@H@("`@("`@("!I
M9B`H("1T:&ES+3Y?9')A=U]C;VQO<BD@>PH@("`@("`@("`@("`@)',])W$@
M)R`N("1T:&ES+3Y?9')A=U]C;VQO<B`N("<@)R`N("1S("X@)R!1)SL*("`@
M("`@("`@?0H@("`@("`@("`D=&AI<RT^7V]U="@D<RD["B`@("`@?0H*("`@
M("\J*@H@("`@("H@4')I;G1S(&%N(&EM86=E(&EN('1H92!P86=E+B!4:&4@
M=7!P97(M;&5F="!C;W)N97(@86YD(&%T(&QE87-T(&]N92!O9@H@("`@("H@
M=&AE(&1I;65N<VEO;G,@;75S="!B92!S<&5C:69I960[('1H92!H96EG:'0@
M;W(@=&AE('=I9'1H(&-A;B!B90H@("`@("H@8V%L8W5L871E9"!A=71O;6%T
M:6-A;&QY(&EN(&]R9&5R('1O(&ME97`@=&AE(&EM86=E('!R;W!O<G1I;VYS
M+@H@("`@("H@4W5P<&]R=&5D(&9O<FUA=',@87)E($I014<@86YD(%!.1RX*
M("`@("`J"B`@("`@*B!&;W(@2E!%1RP@86QL(&9L879O<G,@87)E(&%L;&]W
M960Z"B`@("`@*B`@("T@9W)A>2!S8V%L97,*("`@("`J("`@+2!T<G5E(&-O
M;&]R<R`H,C0@8FET<RD*("`@("`J("`@+2!#35E+("@S,B!B:71S*0H@("`@
M("H*("`@("`J($9O<B!03D<L(&%R92!A;&QO=V5D.@H@("`@("H@("`M(&=R
M87D@<V-A;&5S(&]N(&%T(&UO<W0@."!B:71S("@R-38@;&5V96QS*0H@("`@
M("H@("`M(&EN9&5X960@8V]L;W)S"B`@("`@*B`@("T@=')U92!C;VQO<G,@
M*#(T(&)I=',I"B`@("`@*B!B=70@87)E(&YO="!S=7!P;W)T960Z"B`@("`@
M*B`@("T@26YT97)L86-I;F<*("`@("`J("`@+2!!;'!H82!C:&%N;F5L"B`@
M("`@*@H@("`@("H@268@82!T<F%N<W!A<F5N="!C;VQO<B!I<R!D969I;F5D
M+"!I="!W:6QL(&)E('1A:V5N(&EN=&\@86-C;W5N="`H8G5T"B`@("`@*B!W
M:6QL(&)E(&]N;'D@:6YT97)P<F5T960@8GD@06-R;V)A="`T(&%N9"!A8F]V
M92DN"B`@("`@*B!4:&4@9F]R;6%T(&-A;B!B92!S<&5C:69I960@97AP;&EC
M:71L>2!O<B!I;F9E<G)E9"!F<F]M('1H92!F:6QE"B`@("`@*B!E>'1E;G-I
M;VXN"B`@("`@*B!)="!I<R!P;W-S:6)L92!T;R!P=70@82!L:6YK(&]N('1H
M92!I;6%G92X*("`@("`J"B`@("`@*B!296UA<FLZ(&EF(&%N(&EM86=E(&ES
M('5S960@<V5V97)A;"!T:6UE<RP@;VYL>2!O;F4@8V]P>2!W:6QL(&)E"B`@
M("`@*B!E;6)E9&1E9"!I;B!T:&4@9FEL92X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1F:6QE("`@3F%M92!O9B!T:&4@9FEL92!C;VYT86EN:6YG
M('1H92!I;6%G92X*("`@("`J($!P87)A;2!F;&]A="`D>"`@("`@("!!8G-C
M:7-S82!O9B!T:&4@=7!P97(M;&5F="!C;W)N97(N"B`@("`@*B!`<&%R86T@
M9FQO870@)'D@("`@("`@3W)D:6YA=&4@;V8@=&AE('5P<&5R+6QE9G0@8V]R
M;F5R+@H@("`@("H@0'!A<F%M(&9L;V%T("1W:61T:"`@(%=I9'1H(&]F('1H
M92!I;6%G92!I;B!T:&4@<&%G92X@268@97%U86P@=&\@>F5R;RP*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!I="!I<R!A=71O;6%T:6-A;&QY(&-A
M;&-U;&%T960@=&\@:V5E<"!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!O<FEG:6YA;"!P<F]P;W)T:6]N<RX*("`@("`J($!P87)A;2!F;&]A
M="`D:&5I9VAT("!(96EG:'0@;V8@=&AE(&EM86=E(&EN('1H92!P86=E+B!)
M9B!N;W0@<W!E8VEF:65D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M;W(@97%U86P@=&\@>F5R;RP@:70@:7,@875T;VUA=&EC86QL>2!C86QC=6QA
M=&5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@=&\@:V5E<"!T:&4@
M;W)I9VEN86P@<')O<&]R=&EO;G,N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M>7!E("`@26UA9V4@9F]R;6%T+B!0;W-S:6)L92!V86QU97,@87)E("AC87-E
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:6YS96YS:71I=F4I(#H@
M2E!'+"!*4$5'+"!03D<N($EF(&YO="!S<&5C:69I960L"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@=&AE('1Y<&4@:7,@:6YF97)R960@9G)O;2!T
M:&4@9FEL92!E>'1E;G-I;VXN"B`@("`@*B!`<&%R86T@;6EX960@)&QI;FL@
M("`@55),(&]R(&ED96YT:69I97(@<F5T=7)N960@8GD@1FEL95]01$8Z.F%D
M9$QI;FLN"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ861D3&EN:PH@
M("`@("HO"B`@("!F=6YC=&EO;B!I;6%G92@D9FEL92P@)'@L("1Y+"`D=VED
M=&@@/2`P+"`D:&5I9VAT(#T@,"P@)'1Y<&4@/2`G)RP@)&QI;FL@/2`G)RD*
M("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?:6UA9V5S6R1F:6QE
M72DI('L*("`@("`@("`@("`@+RH@1FER<W0@=7-E(&]F(&EM86=E+"!G970@
M<V]M92!F:6QE(&EN9F\N("HO"B`@("`@("`@("`@(&EF("@D='EP92`]/2`G
M)RD@>PH@("`@("`@("`@("`@("`@)'!O<R`]('-T<G)P;W,H)&9I;&4L("<N
M)RD["B`@("`@("`@("`@("`@("!I9B`H)'!O<R`]/3T@9F%L<V4I('L*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H<W!R
M:6YT9B@G26UA9V4@9FEL92!H87,@;F\@97AT96YS:6]N(&%N9"!N;R!T>7!E
M('=A<R!S<&5C:69I960Z("5S)RP@)&9I;&4I*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1T>7!E(#T@<W5B<W1R*"1F:6QE+"`D<&]S
M("L@,2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1Y<&4@/2!S=')T
M;VQO=V5R*"1T>7!E*3L*("`@("`@("`@("`@)&UQ<B`](&=E=%]M86=I8U]Q
M=6]T97-?<G5N=&EM92@I.PH@("`@("`@("`@("!S971?;6%G:6-?<75O=&5S
M7W)U;G1I;64H,"D["B`@("`@("`@("`@(&EF("@D='EP92`]/2`G:G!G)R!\
M?"`D='EP92`]/2`G:G!E9R<I('L*("`@("`@("`@("`@("`@("1I;F9O(#T@
M)'1H:7,M/E]P87)S94I01R@D9FEL92D["B`@("`@("`@("`@('T@96QS96EF
M("@D='EP92`]/2`G<&YG)RD@>PH@("`@("`@("`@("`@("`@)&EN9F\@/2`D
M=&AI<RT^7W!A<G-E4$Y'*"1F:6QE*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAS<')I
M;G1F*"=5;G-U<'!O<G1E9"!I;6%G92!F:6QE('1Y<&4Z("5S)RP@)'1Y<&4I
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!S971?;6%G:6-?<75O=&5S
M7W)U;G1I;64H)&UQ<BD["B`@("`@("`@("`@("1I;F9O6R=I)UT@/2!C;W5N
M="@D=&AI<RT^7VEM86=E<RD@*R`Q.PH@("`@("`@("`@("`D=&AI<RT^7VEM
M86=E<ULD9FEL95T@/2`D:6YF;SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D:6YF;R`]("1T:&ES+3Y?:6UA9V5S6R1F:6QE73L*("`@("`@("!]
M"@H@("`@("`@("\J($UA:V4@<W5R92!A;&P@=F%R<R!A<F4@8V]N=F5R=&5D
M('1O('!T('-C86QE+B`J+PH@("`@("`@("1X("`@("`@/2`D=&AI<RT^7W1O
M4'0H)'@I.PH@("`@("`@("1Y("`@("`@/2`D=&AI<RT^7W1O4'0H)'DI.PH@
M("`@("`@("1W:61T:"`@/2`D=&AI<RT^7W1O4'0H)'=I9'1H*3L*("`@("`@
M("`D:&5I9VAT(#T@)'1H:7,M/E]T;U!T*"1H96EG:'0I.PH*("`@("`@("`O
M*B!)9B!N;W0@<W!E8VEF:65D(&1O(&%U=&]M871I8R!W:61T:"!A;F0@:&5I
M9VAT(&-A;&-U;&%T:6]N<RX@*B\*("`@("`@("!I9B`H96UP='DH)'=I9'1H
M*2`F)B!E;7!T>2@D:&5I9VAT*2D@>PH@("`@("`@("`@("`D=VED=&@@/2`D
M:6YF;ULG=R==.PH@("`@("`@("`@("`D:&5I9VAT(#T@)&EN9F];)V@G73L*
M("`@("`@("!](&5L<V5I9B`H96UP='DH)'=I9'1H*2D@>PH@("`@("`@("`@
M("`D=VED=&@@/2`D:&5I9VAT("H@)&EN9F];)W<G72`O("1I;F9O6R=H)UT[
M"B`@("`@("`@?2!E;'-E:68@*&5M<'1Y*"1H96EG:'0I*2!["B`@("`@("`@
M("`@("1H96EG:'0@/2`D=VED=&@@*B`D:6YF;ULG:"==("\@)&EN9F];)W<G
M73L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?;W5T*'-P<FEN=&8H)W$@
M)2XR9B`P(#`@)2XR9B`E+C)F("4N,F8@8VT@+TDE9"!$;R!1)RP@)'=I9'1H
M+"`D:&5I9VAT+"`D>"P@)'1H:7,M/FA0="`M("@D>2`K("1H96EG:'0I+"`D
M:6YF;ULG:2==*2D["@H@("`@("`@("\J(%-E="!A;GD@;&EN:R!I9B!R97%U
M97-T960N("HO"B`@("`@("`@:68@*"1L:6YK*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?;&EN:R@D>"P@)'DL("1W:61T:"P@)&AE:6=H="P@)&QI;FLI.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%!E<F9O<FUS(&$@;&EN
M92!B<F5A:RX@5&AE(&-U<G)E;G0@86)S8VES<V$@9V]E<R!B86-K('1O('1H
M92!L969T"B`@("`@*B!M87)G:6X@86YD('1H92!O<F1I;F%T92!I;F-R96%S
M97,@8GD@=&AE(&%M;W5N="!P87-S960@:6X@<&%R86UE=&5R+@H@("`@("H*
M("`@("`J($!P87)A;2!F;&]A="`D:&5I9VAT("!4:&4@:&5I9VAT(&]F('1H
M92!B<F5A:RX@0GD@9&5F875L="P@=&AE('9A;'5E"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@97%U86QS('1H92!H96EG:'0@;V8@=&AE(&QA<W0@
M<')I;G1E9"!C96QL+@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.F-E
M;&P*("`@("`J+PH@("`@9G5N8W1I;VX@;F5W3&EN92@D:&5I9VAT(#T@)R<I
M"B`@("!["B`@("`@("`@)'1H:7,M/G@@/2`D=&AI<RT^7VQE9G1?;6%R9VEN
M.PH@("`@("`@(&EF("AI<U]S=')I;F<H)&AE:6=H="DI('L*("`@("`@("`@
M("`@)'1H:7,M/GD@*ST@)'1H:7,M/E]L87-T7VAE:6=H=#L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^>2`K/2`D:&5I9VAT.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&%B<V-I
M<W-A(&]F('1H92!C=7)R96YT('!O<VET:6]N(&EN('5S97(@=6YI=',N"B`@
M("`@*@H@("`@("H@0')E='5R;B!F;&]A=`H@("`@("H*("`@("`J($!S964@
M1FEL95]01$8Z.G-E=%@*("`@("`J($!S964@1FEL95]01$8Z.F=E=%D*("`@
M("`J($!S964@1FEL95]01$8Z.G-E=%D*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T6"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YX.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1&5F:6YE<R!T:&4@86)S8VES<V$@;V8@=&AE(&-U
M<G)E;G0@<&]S:71I;VXN($EF('1H92!P87-S960@=F%L=64@:7,*("`@("`J
M(&YE9V%T:79E+"!I="!I<R!R96QA=&EV92!T;R!T:&4@<FEG:'0@;V8@=&AE
M('!A9V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&9L;V%T("1X("!4:&4@=F%L
M=64@;V8@=&AE(&%B<V-I<W-A+@H@("`@("H*("`@("`J($!S964@1FEL95]0
M1$8Z.F=E=%@*("`@("`J($!S964@1FEL95]01$8Z.F=E=%D*("`@("`J($!S
M964@1FEL95]01$8Z.G-E=%D*("`@("`J($!S964@1FEL95]01$8Z.G-E=%A9
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%@H)'@I"B`@("!["B`@("`@("`@
M:68@*"1X(#X](#`I('L*("`@("`@("`@("`@+RH@06)S;VQU=&4@=F%L=64N
M("HO"B`@("`@("`@("`@("1T:&ES+3YX(#T@)'@["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@+RH@3F5G871I=F4L('-O(')E;&%T:79E('1O(')I
M9VAT(&5D9V4@;V8@=&AE('!A9V4N("HO"B`@("`@("`@("`@("1T:&ES+3YX
M(#T@)'1H:7,M/G<@*R`D>#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!O<F1I;F%T92!O9B!T:&4@8W5R<F5N="!P;W-I
M=&EO;B!I;B!U<V5R('5N:71S+@H@("`@("H*("`@("`J($!R971U<FX@9FQO
M870*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS9719"B`@("`@*B!`
M<V5E($9I;&5?4$1&.CIG9718"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS9718
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%DH*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^>3L*("`@('T*"B`@("`O*BH*("`@("`J($1E9FEN97,@
M=&AE(&]R9&EN871E(&]F('1H92!C=7)R96YT('!O<VET:6]N+B!)9B!T:&4@
M<&%S<V5D('9A;'5E(&ES"B`@("`@*B!N96=A=&EV92P@:70@:7,@<F5L871I
M=F4@=&\@=&AE(&)O='1O;2!O9B!T:&4@<&%G92X*("`@("`J"B`@("`@*B!`
M<&%R86T@9FQO870@)'D@(%1H92!V86QU92!O9B!T:&4@;W)D:6YA=&4N"B`@
M("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ9V5T6`H@("`@("H@0'-E92!&
M:6QE7U!$1CHZ9V5T60H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T60H@("`@
M("H@0'-E92!&:6QE7U!$1CHZ<V5T6%D*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T62@D>2D*("`@('L*("`@("`@("!I9B`H)'D@/CT@,"D@>PH@("`@("`@
M("`@("`D=&AI<RT^>2`]("1Y.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1T:&ES+3YY(#T@)'1H:7,M/F@@*R`D>3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$969I;F5S('1H92!A8G-C:7-S82!A;F0@;W)D
M:6YA=&4@;V8@=&AE(&-U<G)E;G0@<&]S:71I;VXN($EF('1H90H@("`@("H@
M<&%S<V5D('9A;'5E<R!A<F4@;F5G871I=F4L('1H97D@87)E(')E;&%T:79E
M(')E<W!E8W1I=F5L>2!T;R!T:&4@<FEG:'0*("`@("`J(&%N9"!B;W1T;VT@
M;V8@=&AE('!A9V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&9L;V%T("1X("!4
M:&4@=F%L=64@;V8@=&AE(&%B<V-I<W-A+@H@("`@("H@0'!A<F%M(&9L;V%T
M("1Y("!4:&4@=F%L=64@;V8@=&AE(&]R9&EN871E+@H@("`@("H*("`@("`J
M($!S964@1FEL95]01$8Z.G-E=%@*("`@("`J($!S964@1FEL95]01$8Z.G-E
M=%D*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T6%DH)'@L("1Y*0H@("`@>PH@
M("`@("`@("1T:&ES+3YS9719*"1Y*3L*("`@("`@("`D=&AI<RT^<V5T6"@D
M>"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!R87<@4$1&
M(&9I;&4N"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ;W5T<'5T"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$]U='!U="@I"B`@("!["B`@("`@("`@
M+RH@0VAE8VL@=VAE=&AE<B!F:6QE(&AA<R!B965N(&-L;W-E9"X@*B\*("`@
M("`@("!I9B`H)'1H:7,M/E]S=&%T92`\(#,I('L*("`@("`@("`@("`@)'1H
M:7,M/F-L;W-E*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M
M/E]B=69F97(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC=&EO;B!T;R!O
M=71P=70@=&AE(&)U9F9E<F5D(&1A=&$@=&\@=&AE(&)R;W=S97(N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL96YA;64@(%1H92!F:6QE;F%M
M92!F;W(@=&AE(&]U='!U="!F:6QE+@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)&EN;&EN92`@(%1R=64@:68@:6YL:6YE+"!F86QS92!I9B!A='1A8VAM96YT
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!O=71P=70H)&9I;&5N86UE(#T@)W5N
M:VYO=VXN<&1F)RP@)&EN;&EN92`](&9A;'-E*0H@("`@>PH@("`@("`@("\J
M($-H96-K('=H971H97(@9FEL92!H87,@8F5E;B!C;&]S960N("HO"B`@("`@
M("`@:68@*"1T:&ES+3Y?<W1A=&4@/"`S*2!["B`@("`@("`@("`@("1T:&ES
M+3YC;&]S92@I.PH@("`@("`@('T*"B`@("`@("`@+RH@268@2%144%]$;W=N
M;&]A9"!I<R!N;W0@879A:6QA8FQE(')E='5R;B!014%27T5R<F]R+B`J+PH@
M("`@("`@(&EF("@A0&EN8VQU9&5?;VYC92`G2%144"]$;W=N;&]A9"YP:'`G
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G36ES
M<VEN9R!014%2('!A8VMA9V4@2%144%]$;W=N;&]A9"XG*3L*("`@("`@("!]
M"@H@("`@("`@("\J($-H96-K(&EF(&AE861E<G,@:&%V92!B965N('-E;G0N
M("HO"B`@("`@("`@:68@*&AE861E<G-?<V5N="@I*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G56YA8FQE('1O('-E;F0@4$1&
M(&9I;&4L('-O;64@9&%T82!H87,@86QR96%D>2!B965N(&]U='!U="!T;R!B
M<F]W<V5R+B<I.PH@("`@("`@('T*"B`@("`@("`@+RH@4&%R86US(&9O<B!T
M:&4@;W5T<'5T+B`J+PH@("`@("`@("1D:7-P;W-I=&EO;B`]("@A)&EN;&EN
M92D@/R!(5%107T1/5TY,3T%$7T%45$%#2$U%3E0@.B!(5%107T1/5TY,3T%$
M7TE.3$E.13L*("`@("`@("`D<&%R86US(#T@87)R87DH)V1A=&$G("`@("`@
M("`@("`@("`@/3X@)'1H:7,M/E]B=69F97(L"B`@("`@("`@("`@("`@("`@
M("`@("`@("=C;VYT96YT='EP92<@("`@("`@(#T^("=A<'!L:6-A=&EO;B]P
M9&8G+`H@("`@("`@("`@("`@("`@("`@("`@("`G8V]N=&5N=&1I<W!O<VET
M:6]N)R`]/B!A<G)A>2@D9&ES<&]S:71I;VXL("1F:6QE;F%M92DI.PH@("`@
M("`@("\J($]U='!U="!T:&4@9FEL92X@*B\*("`@("`@("!R971U<FX@2%14
M4%]$;W=N;&]A9#HZ<W1A=&EC4V5N9"@D<&%R86US*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($9U;F-T:6]N('1O('-A=F4@=&AE(%!$1B!F:6QE('-O;65W
M:&5R92!L;V-A;"!T;R!T:&4@<V5R=F5R+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&9I;&5N86UE("!4:&4@9FEL96YA;64@9F]R('1H92!O=71P
M=70@9FEL92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V%V92@D9FEL96YA;64@
M/2`G=6YK;F]W;BYP9&8G*0H@("`@>PH@("`@("`@("\J($-H96-K('=H971H
M97(@9FEL92!H87,@8F5E;B!C;&]S960N("HO"B`@("`@("`@:68@*"1T:&ES
M+3Y?<W1A=&4@/"`S*2!["B`@("`@("`@("`@("1T:&ES+3YC;&]S92@I.PH@
M("`@("`@('T*"B`@("`@("`@)&8@/2!F;W!E;B@D9FEL96YA;64L("=W8B<I
M.PH@("`@("`@(&EF("@A)&8I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*'-P<FEN=&8H)U5N86)L92!T;R!S879E(%!$1B!F:6QE
M.B`E<R<L("1F:6QE;F%M92DI.PH@("`@("`@('T*("`@("`@("!F=W)I=&4H
M)&8L("1T:&ES+3Y?8G5F9F5R+"!S=')L96XH)'1H:7,M/E]B=69F97(I*3L*
M("`@("`@("!F8VQO<V4H)&8I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]T;U!T
M*"1V86PI"B`@("!["B`@("`@("`@<F5T=7)N("1V86P@*B`D=&AI<RT^7W-C
M86QE.PH@("`@?0H*("`@(&9U;F-T:6]N("9?9V5T1F]N=$9I;&4H)&9O;G1K
M97DL("1P871H(#T@)R<I"B`@("!["B`@("`@("`@<W1A=&EC("1F;VYT7W=I
M9'1H<SL*"B`@("`@("`@:68@*"%I<W-E="@D9F]N=%]W:61T:'-;)&9O;G1K
M97E=*2D@>PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1P871H*2D@>PH@("`@
M("`@("`@("`@("`@)&9I;&4@/2`D<&%T:"`N('-T<G1O;&]W97(H)&9O;G1K
M97DI("X@)RYP:'`G.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)&9I;&4@/2`G1FEL92]01$8O9F]N=',O)R`N('-T<G1O;&]W97(H
M)&9O;G1K97DI("X@)RYP:'`G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M($!R97%U:7)E("1F:6QE.PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1F;VYT
M7W=I9'1H<ULD9F]N=&ME>5TI*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H<W!R:6YT9B@G0V]U;&0@;F]T(&EN8VQU9&4@
M9F]N="!M971R:6,@9FEL93H@)7,G+"`D9FEL92DI.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&9O;G1?=VED=&AS.PH@("`@
M?0H*("`@(&9U;F-T:6]N(%]L:6YK*"1X+"`D>2P@)'=I9'1H+"`D:&5I9VAT
M+"`D;&EN:RD*("`@('L*("`@("`@("`O*B!3879E(&QI;FL@=&\@<&%G92!L
M:6YK<R!A<G)A>2X@*B\*("`@("`@("`D=&AI<RT^7W!A9V5?;&EN:W-;)'1H
M:7,M/E]P86=E75M=(#T@87)R87DH)'@L("1Y+"`D=VED=&@L("1H96EG:'0L
M("1L:6YK*3L*("`@('T*"B`@("!F=6YC=&EO;B!?8F5G:6Y$;V,H*0H@("`@
M>PH@("`@("`@("\J(%-T87)T(&1O8W5M96YT+"!B=70@;VYL>2!I9B!N;W0@
M>65T('-T87)T960N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?<W1A=&4@/"`Q
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?<W1A=&4@/2`Q.PH@("`@("`@("`@
M("`D=&AI<RT^7V]U="@G)5!$1BTQ+C,G*3L*("`@("`@("!]"B`@("!]"@H@
M("`@9G5N8W1I;VX@7W!U=%!A9V5S*"D*("`@('L*("`@("`@("`D;F(@/2`D
M=&AI<RT^7W!A9V4["B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7V%L:6%S
M7VYB7W!A9V5S*2D@>PH@("`@("`@("`@("`O*B!297!L86-E(&YU;6)E<B!O
M9B!P86=E<RX@*B\*("`@("`@("`@("`@9F]R("@D;B`](#$[("1N(#P]("1N
M8CL@)&XK*RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P86=E<ULD;ET@
M/2!S=')?<F5P;&%C92@D=&AI<RT^7V%L:6%S7VYB7W!A9V5S+"`D;F(L("1T
M:&ES+3Y?<&%G97-;)&Y=*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("!I9B`H)'1H:7,M/E]D969A=6QT7V]R:65N=&%T:6]N(#T]("=0)RD@
M>PH@("`@("`@("`@("`D=U!T(#T@)'1H:7,M/F9W4'0["B`@("`@("`@("`@
M("1H4'0@/2`D=&AI<RT^9FA0=#L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=U!T(#T@)'1H:7,M/F9H4'0["B`@("`@("`@("`@("1H4'0@/2`D
M=&AI<RT^9G=0=#L*("`@("`@("!]"B`@("`@("`@)&9I;'1E<B`]("@D=&AI
M<RT^7V-O;7!R97-S*2`_("<O1FEL=&5R("]&;&%T941E8V]D92`G(#H@)R<[
M"B`@("`@("`@9F]R("@D;B`](#$[("1N(#P]("1N8CL@)&XK*RD@>PH@("`@
M("`@("`@("`O*B!086=E("HO"B`@("`@("`@("`@("1T:&ES+3Y?;F5W;V)J
M*"D["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<\/"]4>7!E("]086=E)RD[
M"B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O4&%R96YT(#$@,"!2)RD["B`@
M("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V]R:65N=&%T:6]N7V-H86YG
M97-;)&Y=*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=70H<W!R:6YT
M9B@G+TUE9&EA0F]X(%LP(#`@)2XR9B`E+C)F72<L("1H4'0L("1W4'0I*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V]U="@G+U)E<V]U
M<F-E<R`R(#`@4B<I.PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P
M86=E7VQI;FMS6R1N72DI('L*("`@("`@("`@("`@("`@("\J($QI;FMS("HO
M"B`@("`@("`@("`@("`@("`D86YN;W1S(#T@)R]!;FYO=',@6R<["B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!A9V5?;&EN:W-;)&Y=(&%S
M("1P;"D@>PH@("`@("`@("`@("`@("`@("`@("1R96-T(#T@<W!R:6YT9B@G
M)2XR9B`E+C)F("4N,F8@)2XR9B<L("1P;%LP72P@)'!L6S%=+"`D<&Q;,%T@
M*R`D<&Q;,ETL("1P;%LQ72`M("1P;%LS72D["B`@("`@("`@("`@("`@("`@
M("`@)&%N;F]T<R`N/2`G/#PO5'EP92`O06YN;W0@+U-U8G1Y<&4@+TQI;FL@
M+U)E8W0@6R<@+B`D<F5C="`N("==("]";W)D97(@6S`@,"`P72`G.PH@("`@
M("`@("`@("`@("`@("`@(&EF("AI<U]S=')I;F<H)'!L6S1=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D86YN;W1S("X]("<O02`\/"]3("]54DD@
M+U5222`G("X@)'1H:7,M/E]T97AT4W1R:6YG*"1P;%LT72D@+B`G/CX^/B<[
M"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&P@/2`D=&AI<RT^7VQI;FMS6R1P;%LT75T["B`@("`@("`@
M("`@("`@("`@("`@("`@("1H96EG:'0@/2!I<W-E="@D=&AI<RT^7V]R:65N
M=&%T:6]N7V-H86YG97-;)&Q;,%U=*2`_("1W4'0@.B`D:%!T.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D86YN;W1S("X]('-P<FEN=&8H)R]$97-T(%LE
M9"`P(%(@+UA96B`P("4N,F8@;G5L;%T^/B<L(#$@*R`R("H@)&Q;,%TL("1H
M96EG:'0@+2`D;%LQ72`J("1T:&ES+3Y?<V-A;&4I.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?;W5T*"1A;FYO=',N)UTG*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D=&AI<RT^7V]U="@G+T-O;G1E;G1S("<@+B`H)'1H:7,M/E]N("L@
M,2D@+B`G(#`@4CX^)RD["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"=E;F1O
M8FHG*3L*("`@("`@("`@("`@+RH@4&%G92!C;VYT96YT("HO"B`@("`@("`@
M("`@("1P(#T@*"1T:&ES+3Y?8V]M<')E<W,I(#\@9WIC;VUP<F5S<R@D=&AI
M<RT^7W!A9V5S6R1N72D@.B`D=&AI<RT^7W!A9V5S6R1N73L*("`@("`@("`@
M("`@)'1H:7,M/E]N97=O8FHH*3L*("`@("`@("`@("`@)'1H:7,M/E]O=70H
M)SP\)R`N("1F:6QT97(@+B`G+TQE;F=T:"`G("X@<W1R;&5N*"1P*2`N("<^
M/B<I.PH@("`@("`@("`@("`D=&AI<RT^7W!U=%-T<F5A;2@D<"D["B`@("`@
M("`@("`@("1T:&ES+3Y?;W5T*"=E;F1O8FHG*3L*("`@("`@("!]"B`@("`@
M("`@+RH@4&%G97,@<F]O="`J+PH@("`@("`@("1T:&ES+3Y?;V9F<V5T<ULQ
M72`]('-T<FQE;B@D=&AI<RT^7V)U9F9E<BD["B`@("`@("`@)'1H:7,M/E]O
M=70H)S$@,"!O8FHG*3L*("`@("`@("`D=&AI<RT^7V]U="@G/#PO5'EP92`O
M4&%G97,G*3L*("`@("`@("`D:VED<R`]("<O2VED<R!;)SL*("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"`D;F([("1I*RLI('L*("`@("`@("`@("`@)&MI
M9',@+CT@*#,@*R`R("H@)&DI("X@)R`P(%(@)SL*("`@("`@("!]"B`@("`@
M("`@)'1H:7,M/E]O=70H)&MI9',@+B`G72<I.PH@("`@("`@("1T:&ES+3Y?
M;W5T*"<O0V]U;G0@)R`N("1N8BD["B`@("`@("`@)'1H:7,M/E]O=70H<W!R
M:6YT9B@G+TUE9&EA0F]X(%LP(#`@)2XR9B`E+C)F72<L("1W4'0L("1H4'0I
M*3L*("`@("`@("`D=&AI<RT^7V]U="@G/CXG*3L*("`@("`@("`D=&AI<RT^
M7V]U="@G96YD;V)J)RD["B`@("!]"@H@("`@9G5N8W1I;VX@7W!U=$9O;G1S
M*"D*("`@('L*("`@("`@("`D;F8@/2`D=&AI<RT^7VX["B`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/E]D:69F<R!A<R`D9&EF9BD@>PH@("`@("`@("`@("`O
M*B!%;F-O9&EN9W,@*B\*("`@("`@("`@("`@)'1H:7,M/E]N97=O8FHH*3L*
M("`@("`@("`@("`@)'1H:7,M/E]O=70H)SP\+U1Y<&4@+T5N8V]D:6YG("]"
M87-E16YC;V1I;F<@+U=I;D%N<VE%;F-O9&EN9R`O1&EF9F5R96YC97,@6R<@
M+B`D9&EF9B`N("==/CXG*3L*("`@("`@("`@("`@)'1H:7,M/E]O=70H)V5N
M9&]B:B<I.PH@("`@("`@('T*("`@("`@("`D;7%R(#T@9V5T7VUA9VEC7W%U
M;W1E<U]R=6YT:6UE*"D["B`@("`@("`@<V5T7VUA9VEC7W%U;W1E<U]R=6YT
M:6UE*#`I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?9F]N=%]F:6QE<R!A
M<R`D9FEL92`]/B`D:6YF;RD@>PH@("`@("`@("`@("`O*B!&;VYT(&9I;&4@
M96UB961D:6YG+B`J+PH@("`@("`@("`@("`D=&AI<RT^7VYE=V]B:B@I.PH@
M("`@("`@("`@("`D=&AI<RT^7V9O;G1?9FEL97-;)&9I;&5=6R=N)UT@/2`D
M=&AI<RT^7VX["B`@("`@("`@("`@("1S:7IE(#T@9FEL97-I>F4H)&9I;&4I
M.PH@("`@("`@("`@("!I9B`H(21S:7IE*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T9O;G0@9FEL92!N;W0@9F]U;F0N
M)RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]O=70H)SP\
M+TQE;F=T:"`G("X@)'-I>F4I.PH@("`@("`@("`@("!I9B`H<W5B<W1R*"1F
M:6QE+"`M,BD@/3T@)RYZ)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O
M=70H)R]&:6QT97(@+T9L871E1&5C;V1E)RD["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)'1H:7,M/E]O=70H)R],96YG=&@Q("<@+B`D:6YF;ULG;&5N
M9W1H,2==*3L*("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=L96YG=&@R
M)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G+TQE;F=T:#(@
M)R`N("1I;F9O6R=L96YG=&@R)UT@+B`G("],96YG=&@S(#`G*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V]U="@G/CXG*3L*("`@("`@
M("`@("`@)&8@/2!F;W!E;B@D9FEL92P@)W)B)RD["B`@("`@("`@("`@("1T
M:&ES+3Y?<'5T4W1R96%M*&9R96%D*"1F+"`D<VEZ92DI.PH@("`@("`@("`@
M("!F8VQO<V4H)&8I.PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G96YD;V)J
M)RD["B`@("`@("`@?0H@("`@("`@('-E=%]M86=I8U]Q=6]T97-?<G5N=&EM
M92@D;7%R*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V9O;G1S(&%S("1K
M(#T^("1F;VYT*2!["B`@("`@("`@("`@("\J($9O;G0@;V)J96-T<R`J+PH@
M("`@("`@("`@("`D=&AI<RT^7VYE=V]B:B@I.PH@("`@("`@("`@("`D=&AI
M<RT^7V9O;G1S6R1K75LG;B==(#T@)'1H:7,M/E]N.PH@("`@("`@("`@("`D
M;F%M92`]("1F;VYT6R=N86UE)UT["B`@("`@("`@("`@("1T:&ES+3Y?;W5T
M*"<\/"]4>7!E("]&;VYT)RD["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O
M0F%S949O;G0@+R<@+B`D;F%M92D["B`@("`@("`@("`@(&EF("@D9F]N=%LG
M='EP92==(#T]("=C;W)E)RD@>PH@("`@("`@("`@("`@("`@+RH@4W1A;F1A
M<F0@9F]N="X@*B\*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O4W5B
M='EP92`O5'EP93$G*3L*("`@("`@("`@("`@("`@(&EF("@D;F%M92`A/2`G
M4WEM8F]L)R`F)B`D;F%M92`A/2`G6F%P9D1I;F=B871S)RD@>PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O16YC;V1I;F<@+U=I;D%N<VE%
M;F-O9&EN9R<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@+RH@061D:71I;VYA;"!F;VYT+B`J+PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]3=6)T>7!E("\G("X@)&9O
M;G1;)W1Y<&4G72D["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G+T9I
M<G-T0VAA<B`S,B<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=70H)R],
M87-T0VAA<B`R-34G*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O
M5VED=&AS("<@+B`H)'1H:7,M/E]N("L@,2D@+B`G(#`@4B<I.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]O=70H)R]&;VYT1&5S8W)I<'1O<B`G("X@*"1T
M:&ES+3Y?;B`K(#(I("X@)R`P(%(G*3L*("`@("`@("`@("`@("`@(&EF("@D
M9F]N=%LG96YC)UTI('L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)&9O;G1;)V1I9F8G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]O=70H)R]%;F-O9&EN9R`G("X@*"1N9B`K("1F;VYT6R=D:69F)UTI
M+B<@,"!2)RD["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]%;F-O9&EN9R`O5VEN
M06YS:45N8V]D:6YG)RD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?
M;W5T*"<^/B<I.PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G96YD;V)J)RD[
M"B`@("`@("`@("`@(&EF("@D9F]N=%LG='EP92==("$]("=C;W)E)RD@>PH@
M("`@("`@("`@("`@("`@+RH@5VED=&AS+B`J+PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]N97=O8FHH*3L*("`@("`@("`@("`@("`@("1C=R`]("8D9F]N
M=%LG8W<G73L*("`@("`@("`@("`@("`@("1S(#T@)ULG.PH@("`@("`@("`@
M("`@("`@9F]R("@D:2`](#,R.R`D:2`\/2`R-34[("1I*RLI('L*("`@("`@
M("`@("`@("`@("`@("`D<R`N/2`D8W=;8VAR*"1I*5T@+B`G("<["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@D<R`N
M("==)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G96YD;V)J)RD[
M"B`@("`@("`@("`@("`@("`O*B!$97-C<FEP=&]R+B`J+PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]N97=O8FHH*3L*("`@("`@("`@("`@("`@("1S(#T@
M)SP\+U1Y<&4@+T9O;G1$97-C<FEP=&]R("]&;VYT3F%M92`O)R`N("1N86UE
M.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&9O;G1;)V1E<V,G72!A<R`D
M:R`]/B`D=BD@>PH@("`@("`@("`@("`@("`@("`@("1S("X]("<@+R<@+B`D
M:R`N("<@)R`N("1V.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)&9I;&4@/2`D9F]N=%LG9FEL92==.PH@("`@("`@("`@("`@("`@:68@
M*"1F:6QE*2!["B`@("`@("`@("`@("`@("`@("`@)',@+CT@)R`O1F]N=$9I
M;&4G("X@*"1F;VYT6R=T>7!E)UT@/3T@)U1Y<&4Q)R`_("<G(#H@)S(G*2`N
M("<@)R`N("1T:&ES+3Y?9F]N=%]F:6QE<ULD9FEL95U;)VXG72`N("<@,"!2
M)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M;W5T*"1S("X@)SX^)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G
M96YD;V)J)RD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@
M9G5N8W1I;VX@7W!U=$EM86=E<R@I"B`@("!["B`@("`@("`@)&9I;'1E<B`]
M("@D=&AI<RT^7V-O;7!R97-S*2`_("<O1FEL=&5R("]&;&%T941E8V]D92`G
M(#H@)R<["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]I;6%G97,@87,@)&9I
M;&4@/3X@)&EN9F\I('L*("`@("`@("`@("`@)'1H:7,M/E]N97=O8FHH*3L*
M("`@("`@("`@("`@)'1H:7,M/E]I;6%G97-;)&9I;&5=6R=N)UT@/2`D=&AI
M<RT^7VX["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<\/"]4>7!E("]83V)J
M96-T)RD["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O4W5B='EP92`O26UA
M9V4G*3L*("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]7:61T:"`G("X@)&EN
M9F];)W<G72D["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O2&5I9VAT("<@
M+B`D:6YF;ULG:"==*3L*("`@("`@("`@("`@:68@*"1I;F9O6R=C<R==(#T]
M("=);F1E>&5D)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]#
M;VQO<E-P86-E(%LO26YD97AE9"`O1&5V:6-E4D="("<@+B`H<W1R;&5N*"1I
M;F9O6R=P86PG72DO,R`M(#$I("X@)R`G("X@*"1T:&ES+3Y?;B`K(#$I+B<@
M,"!272<I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]O=70H)R]#;VQO<E-P86-E("\G("X@)&EN9F];)V-S)UTI.PH@
M("`@("`@("`@("`@("`@:68@*"1I;F9O6R=C<R==(#T]("=$979I8V5#35E+
M)RD@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O1&5C;V1E
M(%LQ(#`@,2`P(#$@,"`Q(#!=)RD["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]":71S4&5R0V]M
M<&]N96YT("<@+B`D:6YF;ULG8G!C)UTI.PH@("`@("`@("`@("`D=&AI<RT^
M7V]U="@G+T9I;'1E<B`O)R`N("1I;F9O6R=F)UTI.PH@("`@("`@("`@("!I
M9B`H:7-S970H)&EN9F];)W!A<FUS)UTI*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V]U="@D:6YF;ULG<&%R;7,G72D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=T<FYS)UTI("8F(&ES7V%R<F%Y
M*"1I;F9O6R=T<FYS)UTI*2!["B`@("`@("`@("`@("`@("`D=')N<R`]("<G
M.PH@("`@("`@("`@("`@("`@)&E?;6%X(#T@8V]U;G0H)&EN9F];)W1R;G,G
M72D["B`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D:5]M87@[
M("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`D=')N<R`N/2`D:6YF;ULG
M=')N<R==6R1I72`N("<@)R`N("1I;F9O6R=T<FYS)UU;)&E=+B<@)SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O
M36%S:R!;)R`N("1T<FYS("X@)UTG*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D=&AI<RT^7V]U="@G+TQE;F=T:"`G("X@<W1R;&5N*"1I;F9O6R=D
M871A)UTI("X@)SX^)RD["B`@("`@("`@("`@("1T:&ES+3Y?<'5T4W1R96%M
M*"1I;F9O6R=D871A)UTI.PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G96YD
M;V)J)RD["@H@("`@("`@("`@("`O*B!086QE='1E+B`J+PH@("`@("`@("`@
M("!I9B`H)&EN9F];)V-S)UT@/3T@)TEN9&5X960G*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7VYE=V]B:B@I.PH@("`@("`@("`@("`@("`@)'!A;"`]
M("@D=&AI<RT^7V-O;7!R97-S*2`_(&=Z8V]M<')E<W,H)&EN9F];)W!A;"==
M*2`Z("1I;F9O6R=P86PG73L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T
M*"<\/"<@+B`D9FEL=&5R("X@)R],96YG=&@@)R`N('-T<FQE;B@D<&%L*2`N
M("<^/B<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P=713=')E86TH)'!A
M;"D["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G96YD;V)J)RD["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@7W!U
M=%)E<V]U<F-E<R@I"B`@("!["B`@("`@("`@)'1H:7,M/E]P=71&;VYT<R@I
M.PH@("`@("`@("1T:&ES+3Y?<'5T26UA9V5S*"D["B`@("`@("`@+RH@4F5S
M;W5R8V4@9&EC=&EO;F%R>2`J+PH@("`@("`@("1T:&ES+3Y?;V9F<V5T<ULR
M72`]('-T<FQE;B@D=&AI<RT^7V)U9F9E<BD["B`@("`@("`@)'1H:7,M/E]O
M=70H)S(@,"!O8FHG*3L*("`@("`@("`D=&AI<RT^7V]U="@G/#PO4')O8U-E
M="!;+U!$1B`O5&5X="`O26UA9V5"("]);6%G94,@+TEM86=E25TG*3L*("`@
M("`@("`D=&AI<RT^7V]U="@G+T9O;G0@/#PG*3L*("`@("`@("!F;W)E86-H
M("@D=&AI<RT^7V9O;G1S(&%S("1F;VYT*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?;W5T*"<O1B<@+B`D9F]N=%LG:2==("X@)R`G("X@)&9O;G1;)VXG72`N
M("<@,"!2)RD["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?;W5T*"<^/B<I
M.PH@("`@("`@(&EF("AC;W5N="@D=&AI<RT^7VEM86=E<RDI('L*("`@("`@
M("`@("`@)'1H:7,M/E]O=70H)R]83V)J96-T(#P\)RD["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?:6UA9V5S(&%S("1I;6%G92D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]O=70H)R]))R`N("1I;6%G95LG:2==("X@)R`G
M("X@)&EM86=E6R=N)UT@+B`G(#`@4B<I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1T:&ES+3Y?;W5T*"<^/B<I.PH@("`@("`@('T*("`@("`@("`D
M=&AI<RT^7V]U="@G/CXG*3L*("`@("`@("`D=&AI<RT^7V]U="@G96YD;V)J
M)RD["B`@("!]"@H@("`@9G5N8W1I;VX@7W!U=$EN9F\H*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?;W5T*"<O4')O9'5C97(@)R`N("1T:&ES+3Y?=&5X=%-T
M<FEN9R@G2&]R9&4@4$1&)RDI.PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M
M/E]I;F9O6R=T:71L92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G
M+U1I=&QE("<@+B`D=&AI<RT^7W1E>'13=')I;F<H)'1H:7,M/E]I;F9O6R=T
M:71L92==*2D["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)'1H:7,M
M/E]I;F9O6R=S=6)J96-T)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T
M*"<O4W5B:F5C="`G("X@)'1H:7,M/E]T97AT4W1R:6YG*"1T:&ES+3Y?:6YF
M;ULG<W5B:F5C="==*2D["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH
M)'1H:7,M/E]I;F9O6R=A=71H;W(G72DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]O=70H)R]!=71H;W(@)R`N("1T:&ES+3Y?=&5X=%-T<FEN9R@D=&AI<RT^
M7VEN9F];)V%U=&AO<B==*2D["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP
M='DH)'1H:7,M/FME>7=O<F1S*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V]U
M="@G+TME>7=O<F1S("<@+B`D=&AI<RT^7W1E>'13=')I;F<H)'1H:7,M/FME
M>7=O<F1S*2D["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)'1H:7,M
M/F-R96%T;W(I*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O0W)E871O
M<B`G("X@)'1H:7,M/E]T97AT4W1R:6YG*"1T:&ES+3YC<F5A=&]R*2D["B`@
M("`@("`@?0H@("`@("`@("1T:&ES+3Y?;W5T*"<O0W)E871I;VY$871E("<@
M+B`D=&AI<RT^7W1E>'13=')I;F<H)T0Z)R`N(&1A=&4H)UEM9$AI<R<I*2D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@7W!U=$-A=&%L;V<H*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?;W5T*"<O5'EP92`O0V%T86QO9R<I.PH@("`@("`@("1T
M:&ES+3Y?;W5T*"<O4&%G97,@,2`P(%(G*3L*("`@("`@("!I9B`H)'1H:7,M
M/E]Z;V]M7VUO9&4@/3T@)V9U;&QP86=E)RD@>PH@("`@("`@("`@("`D=&AI
M<RT^7V]U="@G+T]P96Y!8W1I;VX@6S,@,"!2("]&:71=)RD["B`@("`@("`@
M?2!E;'-E:68@*"1T:&ES+3Y?>F]O;5]M;V1E(#T]("=F=6QL=VED=&@G*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O3W!E;D%C=&EO;B!;,R`P(%(@
M+T9I=$@@;G5L;%TG*3L*("`@("`@("!](&5L<V5I9B`H)'1H:7,M/E]Z;V]M
M7VUO9&4@/3T@)W)E86PG*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O
M3W!E;D%C=&EO;B!;,R`P(%(@+UA96B!N=6QL(&YU;&P@,5TG*3L*("`@("`@
M("!](&5L<V5I9B`H(6ES7W-T<FEN9R@D=&AI<RT^7WIO;VU?;6]D92DI('L*
M("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]/<&5N06-T:6]N(%LS(#`@4B`O
M6%E:(&YU;&P@;G5L;"`G("X@*"1T:&ES+3Y?>F]O;5]M;V1E("\@,3`P*2XG
M72<I.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/E]L87EO=71?;6]D
M92`]/2`G<VEN9VQE)RD@>PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G+U!A
M9V5,87EO=70@+U-I;F=L95!A9V4G*3L*("`@("`@("!](&5L<V5I9B`H)'1H
M:7,M/E]L87EO=71?;6]D92`]/2`G8V]N=&EN=6]U<R<I('L*("`@("`@("`@
M("`@)'1H:7,M/E]O=70H)R]086=E3&%Y;W5T("]/;F5#;VQU;6XG*3L*("`@
M("`@("!](&5L<V5I9B`H)'1H:7,M/E]L87EO=71?;6]D92`]/2`G='=O)RD@
M>PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G+U!A9V5,87EO=70@+U1W;T-O
M;'5M;DQE9G0G*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@7W!U
M=%1R86EL97(H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;W5T*"<O4VEZ92`G
M("X@*"1T:&ES+3Y?;B`K(#$I*3L*("`@("`@("`D=&AI<RT^7V]U="@G+U)O
M;W0@)R`N("1T:&ES+3Y?;B`N("<@,"!2)RD["B`@("`@("`@)'1H:7,M/E]O
M=70H)R]);F9O("<@+B`H)'1H:7,M/E]N("T@,2D@+B`G(#`@4B<I.PH@("`@
M?0H*("`@(&9U;F-T:6]N(%]E;F1$;V,H*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?<'5T4&%G97,H*3L*("`@("`@("`D=&AI<RT^7W!U=%)E<V]U<F-E<R@I
M.PH@("`@("`@("\J($EN9F\@*B\*("`@("`@("`D=&AI<RT^7VYE=V]B:B@I
M.PH@("`@("`@("1T:&ES+3Y?;W5T*"<\/"<I.PH@("`@("`@("1T:&ES+3Y?
M<'5T26YF;R@I.PH@("`@("`@("1T:&ES+3Y?;W5T*"<^/B<I.PH@("`@("`@
M("1T:&ES+3Y?;W5T*"=E;F1O8FHG*3L*("`@("`@("`O*B!#871A;&]G("HO
M"B`@("`@("`@)'1H:7,M/E]N97=O8FHH*3L*("`@("`@("`D=&AI<RT^7V]U
M="@G/#PG*3L*("`@("`@("`D=&AI<RT^7W!U=$-A=&%L;V<H*3L*("`@("`@
M("`D=&AI<RT^7V]U="@G/CXG*3L*("`@("`@("`D=&AI<RT^7V]U="@G96YD
M;V)J)RD["B`@("`@("`@+RH@0W)O<W,M<F5F("HO"B`@("`@("`@)&\@/2!S
M=')L96XH)'1H:7,M/E]B=69F97(I.PH@("`@("`@("1T:&ES+3Y?;W5T*"=X
M<F5F)RD["B`@("`@("`@)'1H:7,M/E]O=70H)S`@)R`N("@D=&AI<RT^7VX@
M*R`Q*2D["B`@("`@("`@)'1H:7,M/E]O=70H)S`P,#`P,#`P,#`@-C4U,S4@
M9B`G*3L*("`@("`@("!F;W(@*"1I(#T@,3L@)&D@/#T@)'1H:7,M/E]N.R`D
M:2LK*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*'-P<FEN=&8H)R4P,3!D
M(#`P,#`P(&X@)RP@)'1H:7,M/E]O9F9S971S6R1I72DI.PH@("`@("`@('T*
M("`@("`@("`O*B!4<F%I;&5R("HO"B`@("`@("`@)'1H:7,M/E]O=70H)W1R
M86EL97(G*3L*("`@("`@("`D=&AI<RT^7V]U="@G/#PG*3L*("`@("`@("`D
M=&AI<RT^7W!U=%1R86EL97(H*3L*("`@("`@("`D=&AI<RT^7V]U="@G/CXG
M*3L*("`@("`@("`D=&AI<RT^7V]U="@G<W1A<G1X<F5F)RD["B`@("`@("`@
M)'1H:7,M/E]O=70H)&\I.PH@("`@("`@("1T:&ES+3Y?;W5T*"<E)45/1B<I
M.PH@("`@("`@("1T:&ES+3Y?<W1A=&4@/2`S.PH@("`@?0H*("`@(&9U;F-T
M:6]N(%]B96=I;E!A9V4H)&]R:65N=&%T:6]N*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?<&%G92LK.PH@("`@("`@("1T:&ES+3Y?<&%G97-;)'1H:7,M/E]P
M86=E72`]("<G.PH@("`@("`@("1T:&ES+3Y?<W1A=&4@/2`R.PH@("`@("`@
M("1T:&ES+3YX(#T@)'1H:7,M/E]L969T7VUA<F=I;CL*("`@("`@("`D=&AI
M<RT^>2`]("1T:&ES+3Y?=&]P7VUA<F=I;CL*("`@("`@("`D=&AI<RT^7VQA
M<W1?:&5I9VAT(#T@,#L*("`@("`@("`O*B!086=E(&]R:65N=&%T:6]N("HO
M"B`@("`@("`@:68@*"$D;W)I96YT871I;VXI('L*("`@("`@("`@("`@)&]R
M:65N=&%T:6]N(#T@)'1H:7,M/E]D969A=6QT7V]R:65N=&%T:6]N.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1O<FEE;G1A=&EO;B`]('-T<G1O
M=7!P97(H)&]R:65N=&%T:6]N>S!]*3L*("`@("`@("`@("`@:68@*"1O<FEE
M;G1A=&EO;B`A/2`D=&AI<RT^7V1E9F%U;'1?;W)I96YT871I;VXI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;W)I96YT871I;VY?8VAA;F=E<ULD=&AI
M<RT^7W!A9V5=(#T@=')U93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("!I9B`H)&]R:65N=&%T:6]N("$]("1T:&ES+3Y?8W5R<F5N=%]O<FEE
M;G1A=&EO;BD@>PH@("`@("`@("`@("`O*B!#:&%N9V4@;W)I96YT871I;VX@
M*B\*("`@("`@("`@("`@:68@*"1O<FEE;G1A=&EO;B`]/2`G4"<I('L*("`@
M("`@("`@("`@("`@("1T:&ES+3YW4'0@/2`D=&AI<RT^9G=0=#L*("`@("`@
M("`@("`@("`@("1T:&ES+3YH4'0@/2`D=&AI<RT^9FA0=#L*("`@("`@("`@
M("`@("`@("1T:&ES+3YW("`@/2`D=&AI<RT^9G<["B`@("`@("`@("`@("`@
M("`D=&AI<RT^:"`@(#T@)'1H:7,M/F9H.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/G=0="`]("1T:&ES+3YF:%!T.PH@
M("`@("`@("`@("`@("`@)'1H:7,M/FA0="`]("1T:&ES+3YF=U!T.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/G<@("`]("1T:&ES+3YF:#L*("`@("`@("`@
M("`@("`@("1T:&ES+3YH("`@/2`D=&AI<RT^9G<["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)'1H:7,M/E]P86=E7V)R96%K7W1R:6=G97(@/2`D=&AI
M<RT^:"`M("1T:&ES+3Y?8G)E86M?;6%R9VEN.PH@("`@("`@("`@("`D=&AI
M<RT^7V-U<G)E;G1?;W)I96YT871I;VX@/2`D;W)I96YT871I;VX["B`@("`@
M("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]E;F1086=E*"D*("`@('L*("`@
M("`@("`O*B!%;F0@;V8@<&%G92!C;VYT96YT<R`J+PH@("`@("`@("1T:&ES
M+3Y?<W1A=&4@/2`Q.PH@("`@?0H*("`@(&9U;F-T:6]N(%]N97=O8FHH*0H@
M("`@>PH@("`@("`@("\J($)E9VEN(&$@;F5W(&]B:F5C="`J+PH@("`@("`@
M("1T:&ES+3Y?;BLK.PH@("`@("`@("1T:&ES+3Y?;V9F<V5T<ULD=&AI<RT^
M7VY=(#T@<W1R;&5N*"1T:&ES+3Y?8G5F9F5R*3L*("`@("`@("`D=&AI<RT^
M7V]U="@D=&AI<RT^7VX@+B`G(#`@;V)J)RD["B`@("!]"@H@("`@9G5N8W1I
M;VX@7V1O56YD97)L:6YE*"1X+"`D>2P@)'1E>'0I"B`@("!["B`@("`@("`@
M+RH@4V5T('1H92!R96-T86YG;&4@=VED=&@@86-C;W)D:6YG('1O('1E>'0@
M=VED=&@N("HO"B`@("`@("`@)'=I9'1H("`]("1T:&ES+3YG9713=')I;F=7
M:61T:"@D=&5X="P@=')U92D["@H@("`@("`@("\J(%-E="!R96-T86YG;&4@
M<&]S:71I;VX@86YD(&AE:6=H="P@=7-I;F<@=6YD97)L:6YE('!O<VET:6]N
M(&%N9`H@("`@("`@("`J('1H:6-K;F5S<R!S971T:6YG<R!S8V%L960@8GD@
M=&AE(&9O;G0@<VEZ92X@*B\*("`@("`@("`D>2`]("1Y("L@*"1T:&ES+3Y?
M8W5R<F5N=%]F;VYT6R=U<"==("H@)'1H:7,M/E]F;VYT7W-I>F5?<'0@+R`Q
M,#`P*3L*("`@("`@("`D:&5I9VAT(#T@+21T:&ES+3Y?8W5R<F5N=%]F;VYT
M6R=U="==("H@)'1H:7,M/E]F;VYT7W-I>F5?<'0@+R`Q,#`P.PH*("`@("`@
M("!R971U<FX@<W!R:6YT9B@G)2XR9B`E+C)F("4N,F8@)2XR9B!R92!F)RP@
M)'@L("1Y+"`D=VED=&@L("1H96EG:'0I.PH@("`@?0H*("`@(&9U;F-T:6]N
M(%]P87)S94I01R@D9FEL92D*("`@('L*("`@("`@("`O*B!%>'1R86-T(&EN
M9F\@9G)O;2!A($I014<@9FEL92X@*B\*("`@("`@("`D:6UG(#T@0&=E=&EM
M86=E<VEZ92@D9FEL92D["B`@("`@("`@:68@*"$D:6UG*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAS<')I;G1F*"=-:7-S:6YG
M(&]R(&EN8V]R<F5C="!I;6%G92!F:6QE.B`E<R<L("1F:6QE*2D["B`@("`@
M("`@?0H@("`@("`@(&EF("@D:6UG6S)=("$](#(I('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*'-P<FEN=&8H)TYO="!A($I014<@
M9FEL93H@)7,G+"`D9FEL92DI.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES
M<V5T*"1I;6=;)V-H86YN96QS)UTI('Q\("1I;6=;)V-H86YN96QS)UT@/3T@
M,RD@>PH@("`@("`@("`@("`D8V]L<W!A8V4@/2`G1&5V:6-E4D=")SL*("`@
M("`@("!](&5L<V5I9B`H)&EM9ULG8VAA;FYE;',G72`]/2`T*2!["B`@("`@
M("`@("`@("1C;VQS<&%C92`]("=$979I8V5#35E+)SL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D8V]L<W!A8V4@/2`G1&5V:6-E1W)A>2<["B`@
M("`@("`@?0H@("`@("`@("1B<&,@/2!I<W-E="@D:6UG6R=B:71S)UTI(#\@
M)&EM9ULG8FET<R==(#H@.#L*"B`@("`@("`@+RH@4F5A9"!W:&]L92!F:6QE
M+B`J+PH@("`@("`@("1F(#T@9F]P96XH)&9I;&4L("=R8B<I.PH@("`@("`@
M("1D871A(#T@9G)E860H)&8L(&9I;&5S:7IE*"1F:6QE*2D["B`@("`@("`@
M9F-L;W-E*"1F*3L*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"=W)R`]/B`D:6UG
M6S!=+"`G:"<@/3X@)&EM9ULQ72P@)V-S)R`]/B`D8V]L<W!A8V4L("=B<&,G
M(#T^("1B<&,L("=F)R`]/B`G1$-41&5C;V1E)RP@)V1A=&$G(#T^("1D871A
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<&%R<V503D<H)&9I;&4I"B`@("![
M"B`@("`@("`@+RH@17AT<F%C="!I;F9O(&9R;VT@82!03D<@9FEL92X@*B\*
M("`@("`@("`D9B`](&9O<&5N*"1F:6QE+"`G<F(G*3L*("`@("`@("!I9B`H
M(21F*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAS
M<')I;G1F*"=5;F%B;&4@=&\@;W!E;B!I;6%G92!F:6QE.B`E<R<L("1F:6QE
M*2D["B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C:R!S:6=N871U<F4N("HO
M"B`@("`@("`@:68@*&9R96%D*"1F+"`X*2`A/2!C:'(H,3,W*2`N("=03D<G
M("X@8VAR*#$S*2`N(&-H<B@Q,"D@+B!C:'(H,C8I("X@8VAR*#$P*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H<W!R:6YT9B@G
M3F]T(&$@4$Y'(&9I;&4Z("5S)RP@)&9I;&4I*3L*("`@("`@("!]"@H@("`@
M("`@("\J(%)E860@:&5A9&5R(&-H=6YK+B`J+PH@("`@("`@(&9R96%D*"1F
M+"`T*3L*("`@("`@("!I9B`H9G)E860H)&8L(#0I("$]("=)2$12)RD@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H<W!R:6YT9B@G
M26YC;W)R96-T(%!.1R!F:6QE.B`E<R<L("1F:6QE*2D["B`@("`@("`@?0H@
M("`@("`@("1W:61T:"`]("1T:&ES+3Y?9G)E861);G0H)&8I.PH@("`@("`@
M("1H96EG:'0@/2`D=&AI<RT^7V9R96%D26YT*"1F*3L*("`@("`@("`D8G!C
M(#T@;W)D*&9R96%D*"1F+"`Q*2D["B`@("`@("`@:68@*"1B<&,@/B`X*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAS<')I;G1F
M*"<Q-BUB:70@9&5P=&@@;F]T('-U<'!O<G1E9#H@)7,G+"`D9FEL92DI.PH@
M("`@("`@('T*("`@("`@("`D8W0@/2!O<F0H9G)E860H)&8L(#$I*3L*("`@
M("`@("!I9B`H)&-T(#T](#`I('L*("`@("`@("`@("`@)&-O;'-P86-E(#T@
M)T1E=FEC94=R87DG.PH@("`@("`@('T@96QS96EF("@D8W0@/3T@,BD@>PH@
M("`@("`@("`@("`D8V]L<W!A8V4@/2`G1&5V:6-E4D=")SL*("`@("`@("!]
M(&5L<V5I9B`H)&-T(#T](#,I('L*("`@("`@("`@("`@)&-O;'-P86-E(#T@
M)TEN9&5X960G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<BAS<')I;G1F*"=!;'!H82!C:&%N;F5L(&YO
M="!S=7!P;W)T960Z("5S)RP@)&9I;&4I*3L*("`@("`@("!]"B`@("`@("`@
M:68@*&]R9"AF<F5A9"@D9BP@,2DI("$](#`I('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*'-P<FEN=&8H)U5N:VYO=VX@8V]M<')E
M<W-I;VX@;65T:&]D.B`E<R<L("1F:6QE*2D["B`@("`@("`@?0H@("`@("`@
M(&EF("AO<F0H9G)E860H)&8L(#$I*2`A/2`P*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAS<')I;G1F*"=5;FMN;W=N(&9I;'1E
M<B!M971H;V0Z("5S)RP@)&9I;&4I*3L*("`@("`@("!]"B`@("`@("`@:68@
M*&]R9"AF<F5A9"@D9BP@,2DI("$](#`I('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*'-P<FEN=&8H)TEN=&5R;&%C:6YG(&YO="!S
M=7!P;W)T960Z("5S)RP@)&9I;&4I*3L*("`@("`@("!]"B`@("`@("`@9G)E
M860H)&8L(#0I.PH@("`@("`@("1P87)M<R`]("<O1&5C;V1E4&%R;7,@/#PO
M4')E9&EC=&]R(#$U("]#;VQO<G,@)R`N("@D8W0@/3T@,B`_(#,@.B`Q*2XG
M("]":71S4&5R0V]M<&]N96YT("<@+B`D8G!C("X@)R`O0V]L=6UN<R`G("X@
M)'=I9'1H+B<^/B<["B`@("`@("`@+RH@4V-A;B!C:'5N:W,@;&]O:VEN9R!F
M;W(@<&%L971T92P@=')A;G-P87)E;F-Y(&%N9"!I;6%G92!D871A+B`J+PH@
M("`@("`@("1P86P@/2`G)SL*("`@("`@("`D=')N<R`]("<G.PH@("`@("`@
M("1D871A(#T@)R<["B`@("`@("`@9&\@>PH@("`@("`@("`@("`D;B`]("1T
M:&ES+3Y?9G)E861);G0H)&8I.PH@("`@("`@("`@("`D='EP92`](&9R96%D
M*"1F+"`T*3L*("`@("`@("`@("`@:68@*"1T>7!E(#T]("=03%1%)RD@>PH@
M("`@("`@("`@("`@("`@+RH@4F5A9"!P86QE='1E("HO"B`@("`@("`@("`@
M("`@("`D<&%L(#T@9G)E860H)&8L("1N*3L*("`@("`@("`@("`@("`@(&9R
M96%D*"1F+"`T*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1T>7!E(#T]("=T
M4DY3)RD@>PH@("`@("`@("`@("`@("`@+RH@4F5A9"!T<F%N<W!A<F5N8WD@
M:6YF;R`J+PH@("`@("`@("`@("`@("`@)'0@/2!F<F5A9"@D9BP@)&XI.PH@
M("`@("`@("`@("`@("`@:68@*"1C="`]/2`P*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1R;G,@/2!A<G)A>2AO<F0H<W5B<W1R*"1T+"`Q+"`Q*2DI.PH@
M("`@("`@("`@("`@("`@?2!E;'-E:68@*"1C="`]/2`R*2!["B`@("`@("`@
M("`@("`@("`@("`@)'1R;G,@/2!A<G)A>2AO<F0H<W5B<W1R*"1T+"`Q+"`Q
M*2DL(&]R9"AS=6)S='(H)'0L(#,L(#$I*2P@;W)D*'-U8G-T<B@D="P@-2P@
M,2DI*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@)'!O<R`]('-T<G!O<R@D="P@8VAR*#`I*3L*("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-?:6YT*"1P;W,I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1T<FYS(#T@87)R87DH)'!O<RD["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@9G)E860H
M)&8L(#0I.PH@("`@("`@("`@("!](&5L<V5I9B`H)'1Y<&4@/3T@)TE$050G
M*2!["B`@("`@("`@("`@("`@("`O*B!296%D(&EM86=E(&1A=&$@8FQO8VL@
M*B\*("`@("`@("`@("`@("`@("1D871A("X](&9R96%D*"1F+"`D;BD["B`@
M("`@("`@("`@("`@("!F<F5A9"@D9BP@-"D["B`@("`@("`@("`@('T@96QS
M96EF("@D='EP92`]/2`G245.1"<I('L*("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@9G)E860H
M)&8L("1N("L@-"D["B`@("`@("`@("`@('T*("`@("`@("!]('=H:6QE("@D
M;BD["@H@("`@("`@(&EF("@D8V]L<W!A8V4@/3T@)TEN9&5X960G("8F(&5M
M<'1Y*"1P86PI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<BAS<')I;G1F*"=-:7-S:6YG('!A;&5T=&4@:6XZ("5S)RP@)&9I;&4I
M*3L*("`@("`@("!]"B`@("`@("`@9F-L;W-E*"1F*3L*"B`@("`@("`@<F5T
M=7)N(&%R<F%Y*"=W)R`]/B`D=VED=&@L("=H)R`]/B`D:&5I9VAT+"`G8W,G
M(#T^("1C;VQS<&%C92P@)V)P8R<@/3X@)&)P8RP@)V8G(#T^("=&;&%T941E
M8V]D92<L("=P87)M<R<@/3X@)'!A<FUS+"`G<&%L)R`]/B`D<&%L+"`G=')N
M<R<@/3X@)'1R;G,L("=D871A)R`]/B`D9&%T82D["B`@("!]"@H@("`@9G5N
M8W1I;VX@7V9R96%D26YT*"1F*0H@("`@>PH@("`@("`@("\J(%)E860@82`T
M+6)Y=&4@:6YT96=E<B!F<F]M(&9I;&4N("HO"B`@("`@("`@)&D@(#T@;W)D
M*&9R96%D*"1F+"`Q*2D@/#P@,C0["B`@("`@("`@)&D@*ST@;W)D*&9R96%D
M*"1F+"`Q*2D@/#P@,38["B`@("`@("`@)&D@*ST@;W)D*&9R96%D*"1F+"`Q
M*2D@/#P@.#L*("`@("`@("`D:2`K/2!O<F0H9G)E860H)&8L(#$I*3L*("`@
M("`@("!R971U<FX@)&D["B`@("!]"@H@("`@9G5N8W1I;VX@7W1E>'13=')I
M;F<H)',I"B`@("!["B`@("`@("`@+RH@1F]R;6%T(&$@=&5X="!S=')I;F<@
M*B\*("`@("`@("!R971U<FX@)R@G("X@)'1H:7,M/E]E<V-A<&4H)',I("X@
M)RDG.PH@("`@?0H*("`@(&9U;F-T:6]N(%]E<V-A<&4H)',I"B`@("!["B`@
M("`@("`@+RH@061D(%P@8F5F;W)E(%PL("@@86YD("D@*B\*("`@("`@("!R
M971U<FX@<W1R7W)E<&QA8V4H87)R87DH)RDG+"<H)RPG7%PG*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)UQ<*2<L)UQ<*"<L)UQ<7%PG
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@)',I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]P=713=')E86TH)',I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]O=70H)W-T<F5A;2<I.PH@("`@("`@("1T:&ES+3Y?;W5T*"1S*3L*("`@
M("`@("`D=&AI<RT^7V]U="@G96YD<W1R96%M)RD["B`@("!]"@H@("`@9G5N
M8W1I;VX@7V]U="@D<RD*("`@('L*("`@("`@("`O*B!!9&0@82!L:6YE('1O
M('1H92!D;V-U;65N="X@*B\*("`@("`@("!I9B`H)'1H:7,M/E]S=&%T92`]
M/2`R*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%G97-;)'1H:7,M/E]P86=E
M72`N/2`D<R`N(")<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1H:7,M/E]B=69F97(@+CT@)',@+B`B7&XB.PH@("`@("`@('T*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O````````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-3$U-#,S-S4R`#`Q-S0V-``@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]!<G)A>2YP:'``````````````````````````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,3<Q,C,`,3`U,34T,S,W-3(`,#(Q,C4W`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!4
M:&4@2&]R9&5?07)R87DZ.B!C;&%S<R!P<F]V:61E<R!V87)I;W5S(&UE=&AO
M9',@9F]R(&%R<F%Y(&UA;FEP=6QA=&EO;BX*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO571I;"]!<G)A>2YP:'`L=B`Q+C(V+C(N."`R,#`V+S`Q+S`Q(#(Q
M.C(X.C0Q(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI
M8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*
M("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B
M;&\N8V]M/@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($IA;B!38VAN96ED97(@
M/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-
M:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^
M"B`J($!A=71H;W(@($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J
M($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S
M:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]5=&EL"B`J+PIC
M;&%S<R!(;W)D95]!<G)A>2!["@H@("`@+RHJ"B`@("`@*B!0<F5P87)E(&$@
M;&ES="!O9B!A9&1R97-S97,@9F]R('-T;W)A9V4N"B`@("`@*B!.86UE;'DL
M('1R:6US(&%N9"!L;W=E<F-A<V5S(&%L;"!A9&1R97-S97,@86YD('1H96X@
M<V]R="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&%D9'(@(%1H92!L
M:7-T(&]F(&%D9')E<W-E<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!4:&4@;&ES="!O9B!A9&1R97-S97,L('!R97!A<F5D(&9O<B!S=&]R86=E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!P<F5P87)E061D<F5S<TQI<W0H)&%D
M9'(I"B`@("!["B`@("`@("`@+RH@4F5M;W9E(&%N>2!E>'1R82!S<&%C92!I
M;B!T:&4@861D<F5S<R!A;F0@;6%K92!I="!L;W=E<F-A<V4N("HO"B`@("`@
M("`@)&%D9'(@/2!A<G)A>5]M87`H)W1R:6TG+"`D861D<BD["B`@("`@("`@
M)&%D9'(@/2!A<G)A>5]M87`H87)R87DH)U-T<FEN9R<L("=L;W=E<B<I+"`D
M861D<BD["@H@("`@("`@("\J(%)E;6]V92!D=7!L:6-A=&4@96YT<FEE<RX@
M*B\*("`@("`@("`D861D<B`](&%R<F%Y7W5N:7%U92@D861D<BD["@H@("`@
M("`@("\J(%-O<G0@=&AE(&QI<W0N("HO"B`@("`@("`@=7-O<G0H)&%D9'(L
M(&%R<F%Y*"=(;W)D95]!<G)A>2<L("=S;W)T061D<F5S<TQI<W0G*2D["@H@
M("`@("`@(')E='5R;B`D861D<CL*("`@('T*"B`@("`O*BH*("`@("`J($9U
M;F-T:6]N('5S960@8GD@=7-O<G0H*2!T;R!S;W)T(&%N(&%D9')E<W,@;&ES
M="X*("`@("`J(&4N9RX@=7-O<G0H)&9O;RP@87)R87DH)TAO<F1E7T%R<F%Y
M)RP@)W-O<G1!9&1R97-S3&ES="<I*3L*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1A("!!9&1R97-S(",Q+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M8B`@061D<F5S<R`C,BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@
M("TQ+"`P+"!O<B`Q+@H@("`@("HO"B`@("!F=6YC=&EO;B!S;W)T061D<F5S
M<TQI<W0H)&$L("1B*0H@("`@>PH@("`@("`@("1A(#T@97AP;&]D92@G0"<L
M("1A*3L*("`@("`@("`D8B`](&5X<&QO9&4H)T`G+"`D8BD["@H@("`@("`@
M("\J($]N92!O9B!T:&4@861D<F5S<V5S(&1O97-N)W0@:&%V92!A(&AO<W0@
M;F%M92X@*B\*("`@("`@("!I9B`H96UP='DH)&%;,%TI*2!["B`@("`@("`@
M("`@(&%R<F%Y7W-H:69T*"1A*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M
M<'1Y*"1B6S!=*2D@>PH@("`@("`@("`@("!A<G)A>5]S:&EF="@D8BD["B`@
M("`@("`@?0H@("`@("`@(&EF("AC;W5N="@D82D@(3T@8V]U;G0H)&(I*2![
M"B`@("`@("`@("`@(')E='5R;B`H8V]U;G0H)&$I(#X@8V]U;G0H)&(I*3L*
M("`@("`@("!]"@H@("`@("`@("\J(%1H92!A9&1R97-S97,@:&%V92!D:69F
M97)E;G0@:&]S=&YA;64@;W(@;F]T(&AO<W1N86UE(&%N9`H@("`@("`@("`@
M(&1I9F9E<F5N="!M86EL8F]X(&YA;65S+B`J+PH@("`@("`@(&EF("@D85LH
M8V]U;G0H)&$I("T@,2E=("$]("1B6RAC;W5N="@D8BD@+2`Q*5TI('L*("`@
M("`@("`@("`@<F5T=7)N('-T<F-M<"@D85LH8V]U;G0H)&$I("T@,2E=+"`D
M8ELH8V]U;G0H)&(I("T@,2E=*3L*("`@("`@("!]"@H@("`@("`@("\J($-O
M;7!A<F4@;6%I;&)O>"!N86UE<RX@*B\*("`@("`@("!R971U<FX@<W1R8VUP
M*"1A6S!=+"`D8ELP72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3;W)T<R!A
M;B!A<G)A>2!O;B!A('-P96-I9FEE9"!K97DN($EF('1H92!K97D@9&]E<R!N
M;W0@97AI<W0L"B`@("`@*B!D969A=6QT<R!T;R!T:&4@9FER<W0@:V5Y(&]F
M('1H92!A<G)A>2X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)B1A<G)A
M>2`@("`@("!4:&4@87)R87D@=&\@8F4@<V]R=&5D+"!P87-S960@8GD@<F5F
M97)E;F-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("`@("`@("`@5&AE
M(&ME>2!B>2!W:&EC:"!T;R!S;W)T+B!)9B!N;W0@<W!E8VEF:65D"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&5N('1H92!F:7)S="!K
M97D@:7,@=7-E9"X*("`@("`J($!P87)A;2!I;G1E9V5R("1D:7)E8W1I;VX@
M(%-O<G0@9&ER96-T:6]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@,"`](&%S8V5N9&EN9R`H9&5F875L="D*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Q(#T@9&5S8V5N9&EN9PH@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&%S<V]C:6%T92`@2V5E<"!K97D@=F%L=64@87-S;V-I
M871I;VX_"B`@("`@*B\*("`@(&9U;F-T:6]N(&%R<F%Y4V]R="@F)&%R<F%Y
M+"`D:V5Y(#T@;G5L;"P@)&1I<F5C=&EO;B`](#`L("1A<W-O8VEA=&4@/2!T
M<G5E*0H@("`@>PH@("`@("`@("\J(%)E='5R;B!I9B!T:&4@87)R87D@:7,@
M96UP='DN("HO"B`@("`@("`@:68@*&5M<'1Y*"1A<G)A>2DI('L*("`@("`@
M("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@+RH@268@;F\@:V5Y
M('1O('-O<G0@8GD@:7,@<W!E8VEF:65D+"!U<V4@=&AE(&9I<G-T(&ME>2X@
M*B\*("`@("`@("!I9B`H:7-?;G5L;"@D:V5Y*2D@>PH@("`@("`@("`@("`D
M:V5Y<R`](&%R<F%Y7VME>7,H96%C:"@D87)R87DI*3L*("`@("`@("`@("`@
M)&ME>2`]("1K97ES6S!=.PH@("`@("`@('T*"B`@("`@("`@+RH@0W)E871E
M('1H92!F=6YC=&EO;B!T:&%T('=I;&P@8F4@=7-E9"!T;R!S;W)T('1H92!K
M97ES+B`J+PH@("`@("`@(&EF("@D9&ER96-T:6]N*2!["B`@("`@("`@("`@
M("1F=6YC=&EO;B`]('-P<FEN=&8H)W)E='5R;B!S=')C;VQL*%-T<FEN9SHZ
M;&]W97(H)&);7"<E,21S7"==+"!T<G5E*2P@4W1R:6YG.CIL;W=E<B@D85M<
M)R4Q)'-<)UTL('1R=64I*3LG+"`D:V5Y*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D9G5N8W1I;VX@/2!S<')I;G1F*"=R971U<FX@<W1R8V]L
M;"A3=')I;F<Z.FQO=V5R*"1A6UPG)3$D<UPG72P@=')U92DL(%-T<FEN9SHZ
M;&]W97(H)&);7"<E,21S7"==+"!T<G5E*2D[)RP@)&ME>2D["B`@("`@("`@
M?0H*("`@("`@("`O*B!#86QL('1H92!A<'!R;W!R:6%T92!S;W)T(&9U;F-T
M:6]N+B`J+PH@("`@("`@(&EF("@D87-S;V-I871E*2!["B`@("`@("`@("`@
M('5A<V]R="@D87)R87DL(&-R96%T95]F=6YC=&EO;B@G)&$L("1B)RP@)&9U
M;F-T:6]N*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@=7-O<G0H
M)&%R<F%Y+"!C<F5A=&5?9G5N8W1I;VXH)R1A+"`D8B<L("1F=6YC=&EO;BDI
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=I=F5N(&%N($A4
M34P@='EP92!A<G)A>2!F:65L9"`B97AA;7!L95MK97DQ75MK97DR75MK97DS
M72(@8G)E86MS('5P"B`@("`@*B!T:&4@:V5Y<R!S;R!T:&%T('1H97D@8V]U
M;&0@8F4@=7-E9"!T;R!R969E<F5N8V4@82!R96=U;&%R(%!(4"!A<G)A>2X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:65L9"`@5&AE(&9I96QD
M(&YA;64@=&\@8F4@97AA;6EN960N"B`@("`@*B!`<&%R86T@<W1R:6YG("8D
M8F%S92`@4V5T('1O('1H92!B87-E(&5L96UE;G0N"B`@("`@*B!`<&%R86T@
M87)R87D@)B1K97ES("`@4V5T('1O('1H92!L:7-T(&]F(&ME>7,N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V5S<RP@9F%L
M<V4@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%R<F%Y4&%R
M=',H)&9I96QD+"`F)&)A<V4L("8D:V5Y<RD*("`@('L*("`@("`@("!I9B`H
M<')E9U]M871C:"@G?"A;7EQ;72HI*"A<6UM>7%M<75TJ7%TI*RE\)RP@)&9I
M96QD+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@)&)A<V4@/2`D;6%T8VAE
M<ULQ73L*("`@("`@("`@("`@)&ME>7,@/2!E>'!L;V1E*"==6R<L("1M871C
M:&5S6S)=*3L*("`@("`@("`@("`@)&ME>7-;,%T@/2!S=6)S='(H)&ME>7-;
M,%TL(#$I.PH@("`@("`@("`@("`D:V5Y<UMC;W5N="@D:V5Y<RD@+2`Q72`]
M('-U8G-T<B@D:V5Y<UMC;W5N="@D:V5Y<RD@+2`Q72P@,"P@<W1R;&5N*"1K
M97ES6V-O=6YT*"1K97ES*2`M(#%=*2`M(#$I.PH@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@57-I;F<@
M86X@87)R87D@;V8@:V5Y<R!I=&%R871E('1H<F]U9V@@=&AE(&%R<F%Y(&9O
M;&QO=VEN9R!T:&4*("`@("`J(&ME>7,@=&\@9FEN9"!T:&4@9FEN86P@:V5Y
M('9A;'5E+B!)9B!A('9A;'5E(&ES('!A<W-E9"!T:&5N('-E=`H@("`@("H@
M=&AA="!V86QU92X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)B1A<G)A
M>2`@5&AE(&%R<F%Y('1O(&)E('5S960N"B`@("`@*B!`<&%R86T@87)R87D@
M)B1K97ES("`@5&AE(&ME>2!P871H('1O(&9O;&QO=R!A<R!A;B!A<G)A>2X*
M("`@("`J($!P87)A;2!A<G)A>2`D=F%L=64@("!)9B!S970@=&AE('1A<F=E
M="!E;&5M96YT('=I;&P@:&%V92!T:&ES('9A;'5E('-E=`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@('1O(&ET+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%1H92!F:6YA;"!V86QU92!O9B!T:&4@:V5Y('!A=&@N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$5L96UE;G0H)B1A<G)A>2P@)B1K97ES
M+"`D=F%L=64@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AC;W5N="@D:V5Y
M<RDI('L*("`@("`@("`@("`@)&ME>2`](&%R<F%Y7W-H:69T*"1K97ES*3L*
M("`@("`@("`@("`@:68@*&ES<V5T*"1A<G)A>5LD:V5Y72DI('L*("`@("`@
M("`@("`@("`@(')E='5R;B!(;W)D95]!<G)A>3HZ9V5T16QE;65N="@D87)R
M87E;)&ME>5TL("1K97ES+"`D=F%L=64I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"%I<U]N=6QL*"1V
M86QU92DI('L*("`@("`@("`@("`@("`@("1A<G)A>2`]("1V86QU93L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)&%R<F%Y.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!R96-T86YG;&4@
M;V8@82!T=V\M9&EM96YS:6]N86P@87)R87DN"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("8D87)R87D@("`@5&AE(&%R<F%Y('1O(&5X=')A8W0@=&AE
M(')E8W1A;F=L92!F<F]M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@
M("`@5&AE('-T87)T(')O=R!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&-O;"`@("`@5&AE('-T87)T(&-O;'5M;B!O9B!T:&4@
M<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&AE:6=H="`@5&AE
M(&AE:6=H="!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'=I9'1H("`@5&AE('=I9'1H(&]F('1H92!R96-T86YG;&4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&5X=')A8W1E9"!R96-T86YG
M;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971296-T86YG;&4H)B1A<G)A
M>2P@)')O=RP@)&-O;"P@)&AE:6=H="P@)'=I9'1H*0H@("`@>PH@("`@("`@
M("1R96,@/2!A<G)A>2@I.PH@("`@("`@(&9O<B`H)'D@/2`D<F]W.R`D>2`\
M("1R;W<@*R`D:&5I9VAT.R`D>2LK*2!["B`@("`@("`@("`@("1R96-;72`]
M(&%R<F%Y7W-L:6-E*"1A<G)A>5LD>5TL("1C;VPL("1W:61T:"D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D<F5C.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1VEV96X@86X@87)R87DL(')E='5R;G,@86X@87-S;V-I871I=F4@87)R
M87D@=VET:"!E86-H(&5L96UE;G0@:V5Y"B`@("`@*B!D97)I=F5D(&9R;VT@
M:71S('9A;'5E+@H@("`@("H@1F]R(&5X86UP;&4Z"B`@("`@*B`@(&%R<F%Y
M*#`@/3X@)V9O;R<L(#$@/3X@)V)A<B<I"B`@("`@*B!W;W5L9"!B96-O;64Z
M"B`@("`@*B`@(&%R<F%Y*"=F;V\G(#T^("=F;V\G+"`G8F%R)R`]/B`G8F%R
M)RD*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&%R<F%Y("!!;B!A<G)A
M>2!O9B!V86QU97,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@
M87)R87D@=VET:"!K97ES('1H92!S86UE(&%S('9A;'5E<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@=F%L=65S5&]+97ES*"1A<G)A>2D*("`@('L*("`@("`@
M("`D;6%P<&5D(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D87)R87D@
M87,@)'9A;'5E*2!["B`@("`@("`@("`@("1M87!P961;)'9A;'5E72`]("1V
M86QU93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1M87!P960["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&%N(&%R<F%Y(&)Y('5S:6YG(&]N
M92!A<G)A>2!F;W(@:V5Y<R!A;F0@86YO=&AE<B!F;W(*("`@("`J(&ET<R!V
M86QU97,N($]N;'D@97AI<W1S(&EN(%!(4#4L('-O('=E(&-A;&P@87)R87E?
M8V]M8FEN92!I9B!I=`H@("`@("H@97AI<W1S(&%N9"!O=&AE<G=I<V4@96UU
M;&%T92!I="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&ME>7,@("`@
M2V5Y(&%R<F%Y+@H@("`@("H@0'!A<F%M(&%R<F%Y("1V86QU97,@(%9A;'5E
M(&%R<F%Y+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($9A;'-E(&EF
M('1H97)E(&%R92!N;R!E;&5M96YT<RP@;W(@=&AE(&-O;6)I;F5D(&%R<F%Y
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VUB:6YE*"1K97ES+"`D=F%L=65S
M*0H@("`@>PH@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V%R<F%Y7V-O
M;6)I;F4G*2D@>PH@("`@("`@("`@("!R971U<FX@87)R87E?8V]M8FEN92@D
M:V5Y<RP@)'9A;'5E<RD["B`@("`@("`@?0H*("`@("`@("`D<VEZ92`](&-O
M=6YT*"1K97ES*3L*("`@("`@("!I9B`H*"1S:7IE("$](&-O=6YT*"1V86QU
M97,I*2!\?"`H)'-I>F4@/3T@,"DI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@9F]R("@D>"`](#`[("1X(#P@)'-I
M>F4[("1X*RLI('L*("`@("`@("`@("`@)&%R<F%Y6R1K97ES6R1X75T@/2`D
M=F%L=65S6R1X73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1A<G)A>3L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"\`````````````````````
M`````````````````````````````````````````````````````````#`P
M,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S4Q
M`#`R,#,V-``@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H
M+V%P<&QI8V%T:6]N+G!H<```````````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,30T-3``,3`U,34T,S,W-3$`,#(S-#`T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@075T:%]A
M<'!L:6-A=&EO;B!C;&%S<R!P<F]V:61E<R!A('=R87!P97(@87)O=6YD"B`J
M(&%P<&QI8V%T:6]N+7!R;W9I9&5D($AO<F1E(&%U=&AE;G1I8V%T:6]N('=H
M:6-H(&9I=',@:6YS:61E('1H90H@*B!(;W)D92!!=71H.CH@05!)+@H@*@H@
M*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@)V%P<"<@(%1H92!A
M<'!L:6-A=&EO;B!W:&EC:"!I<R!P<F]V:61I;F<@875T:&5N=&EC871I;VXN
M/"]P<F4^"B`J"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T%U=&@O075T:"]A
M<'!L:6-A=&EO;BYP:'`L=B`Q+C(W+C$P+C$R(#(P,#8O,#@O,30@,#(Z-#@Z
M-#@@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?075T
M:`H@*B\*8VQA<W,@075T:%]A<'!L:6-A=&EO;B!E>'1E;F1S($%U=&@@>PH*
M("`@("\J*@H@("`@("H@06X@87)R87D@;V8@8V%P86)I;&ET:65S+"!S;R!T
M:&%T('1H92!D<FEV97(@8V%N(')E<&]R="!W:&EC:`H@("`@("H@;W!E<F%T
M:6]N<R!I="!S=7!P;W)T<R!A;F0@=VAI8V@@:70@9&]E<VXG="X*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D8V%P86)I;&ET
M:65S(#T@87)R87DH)V%D9"<@("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G=7!D871E)R`@("`@("`@/3X@9F%L
M<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97-E='!A<W-W
M;W)D)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W)E;6]V92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G;&ES="<@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=T<F%N<W!A<F5N="<@("`]/B!F86QS
M92D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W($%P<&QI8V%T
M:6]N(&%U=&AE;G1I8V%T:6]N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO
M;B!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H7V%P<&QI
M8V%T:6]N*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?<V5T4&%R86US*"1P87)A;7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M475E<FEE<R!T:&4@8W5R<F5N="!!=71H(&]B:F5C="!T;R!F:6YD(&]U="!I
M9B!I="!S=7!P;W)T<R!T:&4@9VEV96X*("`@("`J(&-A<&%B:6QI='DN"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V%P86)I;&ET>2`@5&AE(&-A
M<&%B:6QI='D@=&\@=&5S="!F;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8V%P86)I;&ET>2!I<R!S=7!P
M;W)T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA<T-A<&%B:6QI='DH)&-A
M<&%B:6QI='DI"B`@("!["B`@("`@("`@<W1A=&EC("1L;V%D960@/2!A<G)A
M>2@I.PH*("`@("`@("`D;65T:&]D<R`](&%R<F%Y*"=L:7-T)R`]/B`G=7-E
M<DQI<W0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)V%D9"<@/3X@)V%D
M9%5S97(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)W5P9&%T92<@/3X@
M)W5P9&%T955S97(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)W)E;6]V
M92<@/3X@)W)E;6]V955S97(G*3L*"B`@("`@("`@:68@*&5M<'1Y*"1L;V%D
M961;)&-A<&%B:6QI='E=*2`F)B!I<W-E="@D;65T:&]D<ULD8V%P86)I;&ET
M>5TI*2!["B`@("`@("`@("`@("1T:&ES+3YC87!A8FEL:71I97-;)&-A<&%B
M:6QI='E=(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/FAA<TUE=&AO9"@D;65T
M:&]D<ULD8V%P86)I;&ET>5TL("1T:&ES+3Y?<&%R86US6R=A<'`G72D["B`@
M("`@("`@("`@("1L;V%D961;)&-A<&%B:6QI='E=(#T@=')U93L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`A96UP='DH)'1H:7,M/F-A<&%B:6QI=&EE
M<ULD8V%P86)I;&ET>5TI.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T(&-O
M;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H
M87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?<V5T4&%R86US*"1P87)A;7,I"B`@("!["B`@("`@
M("`@2&]R9&4Z.F%S<V5R=$1R:79E<D-O;F9I9R@D<&%R86US+"`G875T:"<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G87!P
M)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G875T:&5N
M=&EC871I;VX@87!P;&EC871I;VXG*3L*"B`@("`@("`@:68@*&5M<'1Y*"1'
M3$]"04Q36R=R96=I<W1R>2==+3YA<'!L:6-A=&EO;G-;)'!A<F%M<ULG87!P
M)UU=*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH)'!A<F%M<ULG87!P
M)UT@+B`G(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R
M>2XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1FEN9"!O=70@:68@82!S970@;V8@;&]G:6X@8W)E9&5N=&EA;',@87)E
M('9A;&ED+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@(%1H92!U<V5R260@
M=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@87)R87D@)&-R961E;G1I86QS("!4
M:&4@8W)E9&5N=&EA;',@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-R961E;G1I86QS(&%R92!V
M86QI9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V%U=&AE;G1I8V%T92@D=7-E
M<DED+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@:68@*"$D1TQ/0D%,
M4ULG<F5G:7-T<GDG72T^:&%S365T:&]D*"=A=71H96YT:6-A=&4G+"`D=&AI
M<RT^7W!A<F%M<ULG87!P)UTI*2!["B`@("`@("`@("`@($AO<F1E.CIF871A
M;"@D=&AI<RT^7W!A<F%M<ULG87!P)UT@+B`G(&1O97,@;F]T('!R;W9I9&4@
M86X@875T:&5N=&EC871E*"D@;65T:&]D+B<L(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG<F5G:7-T
M<GDG72T^8V%L;$)Y4&%C:V%G92@D=&AI<RT^7W!A<F%M<ULG87!P)UTL("=A
M=71H96YT:6-A=&4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G=7-E<DED)R`]/B`D=7-E<DED
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G8W)E9&5N=&EA;',G(#T^("1C<F5D96YT:6%L<RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W!A<F%M<R<@/3X@)'1H:7,M/E]P87)A;7,I*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@55))(&]F('1H92!L;V=I
M;B!S8W)E96X@9F]R('1H:7,@875T:&5N=&EC871I;VX@;65T:&]D+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&%P<"`@5&AE(&%P<&QI8V%T:6]N('1O('5S92X*("`@("`J
M($!P87)A;2!S=')I;F<@)'5R;"`@5&AE(%523"!T;R!R961I<F5C="!T;R!A
M9G1E<B!L;V=I;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(&QO9VEN('-C<F5E;B!54DDN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971,
M;V=I;E-C<F5E;B@D87!P(#T@)VAO<F1E)RP@)'5R;"`]("<G*0H@("`@>PH@
M("`@("`@(')E='5R;B!P87)E;G0Z.E]G971,;V=I;E-C<F5E;B@D=&AI<RT^
M7W!A<F%M<ULG87!P)UTL("1U<FPI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M3&ES="!A;&P@=7-E<G,@:6X@=&AE('-Y<W1E;2X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4:&4@87)R87D@;V8@=7-E<DED<RP@;W(@82!014%2
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!L:7-T57-E<G,H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^:&%S0V%P
M86)I;&ET>2@G;&ES="<I*2!["B`@("`@("`@("`@(')E='5R;B`D1TQ/0D%,
M4ULG<F5G:7-T<GDG72T^8V%L;$)Y4&%C:V%G92@D=&AI<RT^7W!A<F%M<ULG
M87!P)UTL("=U<V5R3&ES="<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=U;G-U<'!O<G1E9"<I.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!A('-E="!O9B!A
M=71H96YT:6-A=&EO;B!C<F5D96YT:6%L<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1U<V5R260@("`@("!4:&4@=7-E<DED('1O(&%D9"X*("`@
M("`J($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@(%1H92!C<F5D96YT:6%L
M<R!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O
M;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@861D57-E<B@D=7-E<DED+"`D8W)E9&5N
M=&EA;',I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YH87-#87!A8FEL:71Y
M*"=A9&0G*2D@>PH@("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;)W)E9VES
M=')Y)UTM/F-A;&Q">5!A8VMA9V4H)'1H:7,M/E]P87)A;7-;)V%P<"==+"`G
M861D57-E<B<L(&%R<F%Y*"1U<V5R260L("1C<F5D96YT:6%L<RDI.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"=U;G-U<'!O<G1E9"<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%5P9&%T92!A('-E="!O9B!A=71H96YT:6-A=&EO;B!C<F5D96YT
M:6%L<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;&1)1"`@("`@
M("!4:&4@;VQD('5S97))9"X*("`@("`J($!P87)A;2!S=')I;F<@)&YE=TE$
M("`@("`@(%1H92!N97<@=7-E<DED+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C
M<F5D96YT:6%L<R`@5&AE(&YE=R!C<F5D96YT:6%L<PH@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('5P
M9&%T955S97(H)&]L9$E$+"`D;F5W240L("1C<F5D96YT:6%L<RD*("`@('L*
M("`@("`@("!I9B`H)'1H:7,M/FAA<T-A<&%B:6QI='DH)W5P9&%T92<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^8V%L
M;$)Y4&%C:V%G92@D=&AI<RT^7W!A<F%M<ULG87!P)UTL("=U<&1A=&55<V5R
M)RP@87)R87DH)&]L9$E$+"`D;F5W240L("1C<F5D96YT:6%L<RDI.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"=U;G-U<'!O<G1E9"<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($1E;&5T92!A('-E="!O9B!A=71H96YT:6-A=&EO;B!C<F5D96YT
M:6%L<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@(%1H
M92!U<V5R260@=&\@9&5L971E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V955S97(H)'5S
M97))9"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/FAA<T-A<&%B:6QI='DH
M)W)E;6]V92<I*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D1TQ/0D%,4ULG
M<F5G:7-T<GDG72T^8V%L;$)Y4&%C:V%G92@D=&AI<RT^7W!A<F%M<ULG87!P
M)UTL("=R96UO=F55<V5R)RP@87)R87DH)'5S97))9"DI.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=U
M;G-U<'!O<G1E9"<I.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?82@D<F5S
M=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3YR96UO=F55
M<V5R1&%T82@D=7-E<DED*3L*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O075T:"]A=71O+G!H<```````````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`U,S,W`#$P-3$U-#,S-S4Q`#`R,C`U-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@5&AE($%U=&A?875T;R!C;&%S<R!T<F%N<W!A<F5N=&QY(&QO9W,@=7-E
M<G,@:6X@=&\@2&]R9&4@=7-I;F<@3TY%"B`J('5S97)N86UE+"!E:71H97(@
M9&5F:6YE9"!I;B!T:&4@8V]N9FEG(&]R(&1E9F%U;'1I;F<@=&\*("H@)VAO
M<F1E7W5S97(G+B!4:&ES(&ES(&]N;'D@9F]R('5S92!I;B!T97-T:6YG(&]R
M(&)E:&EN9"!A(&9I<F5W86QL.PH@*B!I="!S:&]U;&0@3D]4(&)E('5S960@
M;VX@82!P=6)L:6,L('!R;V1U8W1I;VX@;6%C:&EN92X*("H*("H@3W!T:6]N
M86P@<&%R86UE=&5R<SH\<')E/@H@*B`@("=U<V5R;F%M92<@("`@(%1H92!U
M<V5R;F%M92!T;R!A=71H96YT:6-A=&4@979E<GEO;F4@87,N"B`J("`@("`@
M("`@("`@("`@("`@1$5&055,5#H@)VAO<F1E7W5S97(G"B`J("`@)W!A<W-W
M;W)D)R`@("`@5&AE('!A<W-W;W)D('1O(')E8V]R9"!I;B!T:&4@=7-E<B=S
M(&-R961E;G1I86QS+@H@*B`@("`@("`@("`@("`@("`@($1%1D%53%0Z(&YO
M;F4*("H@("`G<F5Q=65S='5S97(G("!)9B!T<G5E+"!A;&QO=R!U<V5R;F%M
M92!T;R!B92!P87-S960@8GD@1T54+"!03U-4(&]R"B`J("`@("`@("`@("`@
M("`@("`@8V]O:VEE+CPO<')E/@H@*@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O875T;RYP:'`L=B`Q+C$R+C0N."`R,#`V+S`Q+S`Q(#(Q
M.C(X.C`W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J($!S:6YC92`@($AO<F1E(#(N,@H@*B!`<&%C:V%G92!(;W)D95]!
M=71H"B`J+PIC;&%S<R!!=71H7V%U=&\@97AT96YD<R!!=71H('L*"B`@("`O
M*BH*("`@("`J($%N(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T
M:&4@9')I=F5R(&-A;B!R97!O<G0@=VAI8V@*("`@("`J(&]P97)A=&EO;G,@
M:70@<W5P<&]R=',@86YD('=H:6-H(&ET(&1O97-N)W0N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&-A<&%B:6QI=&EE<R`]
M(&%R<F%Y*"=A9&0G("`@("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W5P9&%T92<@("`@("`@(#T^(&9A;'-E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5S971P87-S=V]R9"<@
M/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R96UO
M=F4G("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VQI<W0G("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=')A;G-P87)E;G0G("`@/3X@=')U92D["@H@
M("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W($%U=&]M871I8R!A=71H
M96YT:6-A=&EO;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG('!A<F%M971E<G,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N($%U=&A?875T;R@D<&%R86US(#T@87)R87DH*2D*
M("`@('L*("`@("`@("`D=&AI<RT^7W-E=%!A<F%M<R@D<&%R86US*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E="!P87)A;65T97)S(&9O<B!T:&4@075T
M:%]A=71O(&]B:F5C="X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@4&%R86UE=&5R
M<RX@3F]N92!C=7)R96YT;'D@<F5Q=6ER960["B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@)W5S97)N86UE)RP@)W!A<W-W;W)D)RP@86YD("=R97%U
M97-T=7-E<B<@87)E(&]P=&EO;F%L+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M<V5T4&%R86US*"1P87)A;7,I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D
M<&%R86US6R=U<V5R;F%M92==*2D@>PH@("`@("`@("`@("`D<&%R86US6R=U
M<V5R;F%M92==(#T@)VAO<F1E7W5S97(G.PH@("`@("`@('T*("`@("`@("`D
M=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!=71O;6%T:6,@875T:&5N=&EC871I;VXZ(%-E="!T:&4@=7-E<B!A;&QO
M=V5D($E0(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M5VAE=&AE<B!O<B!N;W0@=&AE(&-L:65N="!I<R!A;&QO=V5D+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!T<F%N<W!A<F5N="@I"B`@("!["B`@("`@("`@)'5S
M97)N86UE(#T@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG<F5Q=65S='5S97(G
M72D@)B8@:7-S970H)%]215%515-46R=U<V5R;F%M92==*2D@/PH@("`@("`@
M("`@("`D7U)%455%4U1;)W5S97)N86UE)UT@.@H@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG=7-E<FYA;64G73L*("`@("`@("`D=&AI<RT^<V5T075T
M:"@D=7-E<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W1R
M86YS<&%R96YT)R`]/B`Q+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=P87-S=V]R9"<@/3X@:7-S970H)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D
M)UTI(#\@)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UT@.B!N=6QL*2D["B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+V-O
M;7!O<VET92YP:'``````````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C$U
M-#,`,3`U,34T,S,W-3$`,#(S,3`T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!4:&4@075T:%]C;VUP
M;W-I=&4@8VQA<W,@<')O=FED97,@82!W<F%P<&5R(&%R;W5N9`H@*B!A<'!L
M:6-A=&EO;BUP<F]V:61E9"!(;W)D92!A=71H96YT:6-A=&EO;B!W:&EC:"!F
M:71S(&EN<VED92!T:&4*("H@2&]R9&4@075T:#HZ($%022X*("H*("H@4F5Q
M=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@($YO;F4N/"]P<F4^"B`J"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+T%U=&@O075T:"]C;VUP;W-I=&4N<&AP
M+'8@,2XR-BXQ,"XQ,"`R,#`V+S`X+S$T(#`R.C0X.C0X(&-H=6-K($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@
M2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T%U=&@*("HO"F-L87-S($%U
M=&A?8V]M<&]S:71E(&5X=&5N9',@075T:"!["@H@("`@+RHJ"B`@("`@*B!(
M87-H(&-O;G1A:6YI;F<@86YY(&EN<W1A;G1I871E9"!D<FEV97)S+@H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?9')I=F5R
M<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W
M($-O;7!O<VET92!A=71H96YT:6-A=&EO;B!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O
M;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@075T
M:%]C;VUP;W-I=&4H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M)'1H:7,M/E]S971087)A;7,H)'!A<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3970@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D
M<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E
M<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S971087)A;7,H)'!A<F%M<RD*
M("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P87)A;7,I*2!["B`@("`@
M("`@("`@($AO<F1E.CIF871A;"@G3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R($-O;7!O<VET92!A=71H96YT:6-A=&EO;BXG
M+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N('1H92!N86UE9"!P87)A;65T97(@9F]R('1H92!C=7)R96YT(&%U
M=&@@9')I=F5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A<F%M
M("!4:&4@<&%R86UE=&5R('1O(&9E=&-H+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@<&%R86UE=&5R)W,@=F%L=64N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%!A<F%M*"1P87)A;2D*("`@('L*("`@("`@("!I9B`H
M*"1L;V=I;E]D<FEV97(@/2!!=71H.CI?9V5T1')I=F5R0GE087)A;2@G;&]G
M:6YS8W)E96Y?<W=I=&-H)RP@)'1H:7,M/E]P87)A;7,I*2`F)@H@("`@("`@
M("`@("`D=&AI<RT^7VQO861$<FEV97(H)&QO9VEN7V1R:79E<BDI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9')I=F5R<ULD;&]G:6Y?9')I=F5R
M72T^9V5T4&%R86TH)'!A<F%M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEN9"!O=70@:68@82!S
M970@;V8@;&]G:6X@8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'5S97))9"`@("`@(%1H92!U<V5R260@=&\@8VAE8VLN"B`@("`@*B!`
M<&%R86T@87)R87D@)&-R961E;G1I86QS("!4:&4@8W)E9&5N=&EA;',@=&\@
M=7-E+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O
M<B!N;W0@=&AE(&-R961E;G1I86QS(&%R92!V86QI9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V%U=&AE;G1I8V%T92@D=7-E<DED+"`D8W)E9&5N=&EA;',I
M"B`@("!["B`@("`@("`@:68@*"@D875T:%]D<FEV97(@/2!!=71H.CI?9V5T
M1')I=F5R0GE087)A;2@G;&]G:6YS8W)E96Y?<W=I=&-H)RP@)'1H:7,M/E]P
M87)A;7,I*2`F)@H@("`@("`@("`@("`D=&AI<RT^7VQO861$<FEV97(H)&%U
M=&A?9')I=F5R*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D<FEV
M97)S6R1A=71H7V1R:79E<ETM/F%U=&AE;G1I8V%T92@D=7-E<DED+"`D8W)E
M9&5N=&EA;',I.PH@("`@("`@('T*"B`@("`@("`@:68@*"@D875T:%]D<FEV
M97(@/2!!=71H.CI?9V5T1')I=F5R0GE087)A;2@G=7-E<FYA;65?<W=I=&-H
M)RP@)'1H:7,M/E]P87)A;7,L(&%R<F%Y*"1U<V5R260I*2D@)B8*("`@("`@
M("`@("`@)'1H:7,M/E]L;V%D1')I=F5R*"1A=71H7V1R:79E<BDI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9')I=F5R<ULD875T:%]D<FEV97)=
M+3YH87-#87!A8FEL:71Y*"=T<F%N<W!A<F5N="<I.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?1D%)3$5$
M*3L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!1=65R>2!T:&4@8W5R<F5N="!!=71H(&]B:F5C="!T;R!F:6YD(&]U="!I
M9B!I="!S=7!P;W)T<R!T:&4@9VEV96X*("`@("`J(&-A<&%B:6QI='DN"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V%P86)I;&ET>2`@5&AE(&-A
M<&%B:6QI='D@=&\@=&5S="!F;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8V%P86)I;&ET>2!I<R!S=7!P
M;W)T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA<T-A<&%B:6QI='DH)&-A
M<&%B:6QI='DI"B`@("!["B`@("`@("`@<W=I=&-H("@D8V%P86)I;&ET>2D@
M>PH@("`@("`@(&-A<V4@)V%D9"<Z"B`@("`@("`@8V%S92`G=7!D871E)SH*
M("`@("`@("!C87-E("=R96UO=F4G.@H@("`@("`@(&-A<V4@)VQI<W0G.@H@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=A9&UI;E]D
M<FEV97(G72D@)B8*("`@("`@("`@("`@("`@("1T:&ES+3Y?;&]A9$1R:79E
M<B@D=&AI<RT^7W!A<F%M<ULG861M:6Y?9')I=F5R)UTI*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]D<FEV97)S6R1T:&ES+3Y?<&%R86US
M6R=A9&UI;E]D<FEV97(G75TM/FAA<T-A<&%B:6QI='DH)&-A<&%B:6QI='DI
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("!C87-E("=T<F%N<W!A<F5N="<Z"B`@("`@("`@("`@(&EF("@H)&QO
M9VEN7V1R:79E<B`]($%U=&@Z.E]G971$<FEV97)">5!A<F%M*"=L;V=I;G-C
M<F5E;E]S=VET8V@G+"`D=&AI<RT^7W!A<F%M<RDI("8F"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7VQO861$<FEV97(H)&QO9VEN7V1R:79E<BDI('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1R:79E<G-;)&QO9VEN7V1R
M:79E<ETM/FAA<T-A<&%B:6QI='DH)W1R86YS<&%R96YT)RD["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%U=&]M871I
M8R!A=71H96YT:6-A=&EO;CH@1FEN9"!O=70@:68@=&AE(&-L:65N="!M871C
M:&5S(&%N(&%L;&]W960@25`*("`@("`J(&)L;V-K+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-L:65N="!I
M<R!A;&QO=V5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!T<F%N<W!A<F5N="@I
M"B`@("!["B`@("`@("`@:68@*"@D;&]G:6Y?9')I=F5R(#T@075T:#HZ7V=E
M=$1R:79E<D)Y4&%R86TH)VQO9VEN<V-R965N7W-W:71C:"<L("1T:&ES+3Y?
M<&%R86US*2D@)B8*("`@("`@("`@("`@)'1H:7,M/E]L;V%D1')I=F5R*"1L
M;V=I;E]D<FEV97(I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1R
M:79E<G-;)&QO9VEN7V1R:79E<ETM/G1R86YS<&%R96YT*"D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@=&AE(%5222!O9B!T:&4@;&]G:6X@<V-R965N(&9O<B!T:&ES
M(&%U=&AE;G1I8V%T:6]N(&]B:F5C="X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@(%1H
M92!A<'!L:6-A=&EO;B!T;R!U<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1U
M<FP@(%1H92!54DP@=&\@<F5D:7)E8W0@=&\@869T97(@;&]G:6XN"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!L;V=I;B!S8W)E96X@55))
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T3&]G:6Y38W)E96XH)&%P<"`]
M("=H;W)D92<L("1U<FP@/2`G)RD*("`@('L*("`@("`@("!I9B`H*"1L;V=I
M;E]D<FEV97(@/2!!=71H.CI?9V5T1')I=F5R0GE087)A;2@G;&]G:6YS8W)E
M96Y?<W=I=&-H)RP@)'1H:7,M/E]P87)A;7,I*2`F)@H@("`@("`@("`@("`D
M=&AI<RT^7VQO861$<FEV97(H)&QO9VEN7V1R:79E<BDI('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?9')I=F5R<ULD;&]G:6Y?9')I=F5R72T^7V=E
M=$QO9VEN4V-R965N*"1A<'`L("1U<FPI.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B!P87)E;G0Z.E]G971,;V=I;E-C<F5E;B@D87!P
M+"`D=7)L*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@
M82!S970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA;',N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@("`@(%1H92!U<V5R260@
M=&\@861D+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D8W)E9&5N=&EA;',@(%1H
M92!C<F5D96YT:6%L<R!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@("`@("`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@861D57-E
M<B@D=7-E<DED+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@:68@*"%E
M;7!T>2@D=&AI<RT^7W!A<F%M<ULG861M:6Y?9')I=F5R)UTI("8F"B`@("`@
M("`@("`@("1T:&ES+3Y?;&]A9$1R:79E<B@D=&AI<RT^7W!A<F%M<ULG861M
M:6Y?9')I=F5R)UTI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1R
M:79E<G-;)'1H:7,M/E]P87)A;7-;)V%D;6EN7V1R:79E<B==72T^861D57-E
M<B@D=7-E<DED+"`D8W)E9&5N=&EA;',I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=5;G-U<'!O<G1E
M9"<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%5P9&%T92!A
M('-E="!O9B!A=71H96YT:6-A=&EO;B!C<F5D96YT:6%L<RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1O;&1)1"`@("`@("!4:&4@;VQD('5S97))
M9"X*("`@("`J($!P87)A;2!S=')I;F<@)&YE=TE$("`@("`@(%1H92!N97<@
M=7-E<DED+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@5&AE
M(&YE=R!C<F5D96YT:6%L<PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('5P9&%T955S97(H)&]L9$E$
M+"`D;F5W240L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("!I9B`H(65M
M<'1Y*"1T:&ES+3Y?<&%R86US6R=A9&UI;E]D<FEV97(G72D@)B8*("`@("`@
M("`@("`@)'1H:7,M/E]L;V%D1')I=F5R*"1T:&ES+3Y?<&%R86US6R=A9&UI
M;E]D<FEV97(G72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9')I
M=F5R<ULD=&AI<RT^7W!A<F%M<ULG861M:6Y?9')I=F5R)UU=+3YU<&1A=&55
M<V5R*"1O;&1)1"P@)&YE=TE$+"`D8W)E9&5N=&EA;',I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=5
M;G-U<'!O<G1E9"<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($1E;&5T92!A('-E="!O9B!A=71H96YT:6-A=&EO;B!C<F5D96YT:6%L<RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@(%1H92!U<V5R
M260@=&\@9&5L971E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R
M=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V955S97(H)'5S97))9"D*
M("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=A9&UI
M;E]D<FEV97(G72D@)B8*("`@("`@("`@("`@)'1H:7,M/E]L;V%D1')I=F5R
M*"1T:&ES+3Y?<&%R86US6R=A9&UI;E]D<FEV97(G72DI('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?9')I=F5R<ULD=&AI<RT^7W!A<F%M<ULG861M
M:6Y?9')I=F5R)UU=+3YR96UO=F55<V5R*"1U<V5R260I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=5
M;G-U<'!O<G1E9"<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($QI<W0@86QL('5S97)S(&EN('1H92!S>7-T96TN"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@5&AE(&%R<F%Y(&]F('5S97))9',L(&]R(&$@4$5!
M4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@;&ES=%5S97)S*"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES
M+3Y?<&%R86US6R=A9&UI;E]D<FEV97(G72D@)B8*("`@("`@("`@("`@)'1H
M:7,M/E]L;V%D1')I=F5R*"1T:&ES+3Y?<&%R86US6R=A9&UI;E]D<FEV97(G
M72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9')I=F5R<ULD=&AI
M<RT^7W!A<F%M<ULG861M:6Y?9')I=F5R)UU=+3YL:7-T57-E<G,H*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G56YS=7!P;W)T960G*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#:&5C:W,@:68@82!U<V5R260@97AI<W1S(&EN('1H92!S>7-T
M96TN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("!5<V5R
M($E$('1O(&-H96-K"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7
M:&5T:&5R(&]R(&YO="!T:&4@=7-E<DED(&%L<F5A9'D@97AI<W1S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!E>&ES=',H)'5S97))9"D*("`@('L*("`@("`@
M("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=A9&UI;E]D<FEV97(G72D@
M)B8*("`@("`@("`@("`@)'1H:7,M/E]L;V%D1')I=F5R*"1T:&ES+3Y?<&%R
M86US6R=A9&UI;E]D<FEV97(G72DI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?9')I=F5R<ULD=&AI<RT^7W!A<F%M<ULG861M:6Y?9')I=F5R)UU=
M+3YE>&ES=',H)'5S97))9"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U5N<W5P<&]R=&5D)RD["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@3&]A9',@;VYE(&]F('1H
M92!D<FEV97)S(&EN(&]U<B!C;VYF:6=U<F%T:6]N(&%R<F%Y+"!I9B!I="!I
M<VXG="!A;')E861Y"B`@("`@*B!L;V%D960N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9')I
M=F5R("!4:&4@;F%M92!O9B!T:&4@9')I=F5R('1O(&QO860N"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N(%1R=64@:68@9')I=F5R('-U8V-E<W-F
M=6QL>2!I;FET:6%L:7IE<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7VQO861$
M<FEV97(H)&1R:79E<BD*("`@('L*("`@("`@("!I9B`H96UP='DH)'1H:7,M
M/E]D<FEV97)S6R1D<FEV97)=*2D@>PH@("`@("`@("`@("`O+R!4:&ES(&ES
M(&$@8FET('-P96-I86QI>F5D(&9O<B!(;W)D93HZ9V5T1')I=F5R0V]N9FEG
M*"DL"B`@("`@("`@("`@("\O('-O(&QO8V%L:7IE(&ET(&AE<F4Z"B`@("`@
M("`@("`@(&=L;V)A;"`D8V]N9CL*("`@("`@("`@("`@:68@*"%E;7!T>2@D
M=&AI<RT^7W!A<F%M<ULG9')I=F5R<R==6R1D<FEV97)=6R=P87)A;7,G72DI
M('L*("`@("`@("`@("`@("`@("1P87)A;7,@/2`D=&AI<RT^7W!A<F%M<ULG
M9')I=F5R<R==6R1D<FEV97)=6R=P87)A;7,G73L*("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D8V]N9ELD=&AI<RT^7W!A<F%M<ULG9')I=F5R<R==6R1D
M<FEV97)=6R=D<FEV97(G75TI*2!["B`@("`@("`@("`@("`@("`@("`@)'!A
M<F%M<R`](&%R<F%Y7VUE<F=E*"1C;VYF6R1T:&ES+3Y?<&%R86US6R=D<FEV
M97)S)UU;)&1R:79E<EU;)V1R:79E<B==72P@)'!A<F%M<RD["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF("@A96UP='DH)&-O;F9;
M)&1R:79E<ETI*2!["B`@("`@("`@("`@("`@("`D<&%R86US(#T@)&-O;F9;
M)&1R:79E<ET["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D<&%R86US(#T@;G5L;#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M)'1H:7,M/E]D<FEV97)S6R1D<FEV97)=(#T@)D%U=&@Z.G-I;F=L971O;B@D
M=&AI<RT^7W!A<F%M<ULG9')I=F5R<R==6R1D<FEV97)=6R=D<FEV97(G72P@
M)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@:7-S970H)'1H
M:7,M/E]D<FEV97)S6R1D<FEV97)=*3L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T%U=&@O8W5S=&]M<W%L+G!H<```````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`R,S<V,``Q,#4Q-30S,S<U,0`P,C,Q,S<`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC
M92!D:7)N86UE*%]?1DE,15]?*2`N("<O<W%L+G!H<"<["@HO*BH*("H@5&AE
M($%U=&A?8W5S=&]M<W%L(&-L87-S('!R;W9I9&5S(&$@<W%L(&EM<&QE;65N
M=&%T:6]N(&]F('1H92!(;W)D90H@*B!A=71H96YT:6-A=&EO;B!S>7-T96T@
M=VET:"!T:&4@<&]S<VEB:6QI='D@=&\@<V5T(&-U<W1O;2UM861E('%U97)I
M97,N"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z/'!R93X*("H@("`G<&AP
M='EP92<@(%1H92!D871A8F%S92!T>7!E("AI92X@)W!G<W%L)RP@)VUY<W%L
M)RP@971C+BDN/"]P<F4^"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z("A#
M=7-T;VT@<75E<GDI/'!R93X*("H@4V]M92!S<&5C:6%L('1O:V5N<R!C86X@
M8F4@=7-E9"!I;B!T:&4@<W%L('%U97)Y+B!4:&5Y(&%R92!R97!L86-E9`H@
M*B!A="!T:&4@<75E<GD@<W1A9V4Z"B`J"B`J("`@+2`G7$PG('=I;&P@8F4@
M<F5P;&%C960@8GD@=&AE('5S97(G<R!L;V=I;@H@*B`@("T@)UQ0)R!W:6QL
M(&)E(')E<&QA8V5D(&)Y('1H92!U<V5R)W,@<&%S<W=O<F0N"B`J("`@+2`G
M7$\G('=I;&P@8F4@<F5P;&%C960@8GD@=&AE(&]L9"!U<V5R)W,@;&]G:6X@
M*')E<75I<F5D(&9O<B!U<&1A=&4I"B`J"B`J("`@16<Z(")314Q%0U0@*B!&
M4D]-('5S97)S(%=(15)%('5I9"`](%Q,"B`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@($%.1"!P87-S=V0@/2!<4`H@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!!3D0@8FEL;&EN9R`]("=P86ED)PH@*@H@*B`@("=Q=65R
M>5]A=71H)R`@("!!=71H96YT:6-A=&4@=&AE('5S97(N("`@("`@("=<3"<@
M)B`G7$XG"B`J("`@)W%U97)Y7V%D9"<@("`@($%D9"!U<V5R+B`@("`@("`@
M("`@("`@("`@("`@)UQ,)R`F("=<3B<*("H@("`G<75E<GE?=7!D871E)R`@
M57!D871E('5S97(N("`@("`@("`@("`@("`@("`G7$\G+"`G7$PG("8@)UQ.
M)PH@*B`@("=Q=65R>5]R97-E='!A<W-W;W)D)R`@4F5S970@<&%S<W=O<F0N
M("`@("`@("=<3"<L("8@)UQ0)PH@*B`@("=Q=65R>5]R96UO=F4G("!296UO
M=F4@=7-E<BX@("`@("`@("`@("`@("`@("=<3"<*("H@("`G<75E<GE?;&ES
M="<@("`@3&ES="!U<V5R+B`@("`@("`@("`@("`@("`@("`G7$PG/"]P<F4^
M"B`J"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G96YC<GEP
M=&EO;B<@("`@("`@5&AE(&5N8W)Y<'1I;VX@=&\@=7-E('1O('-T;W)E('1H
M92!P87-S=V]R9"!I;B!T:&4*("H@("`@("`@("`@("`@("`@("`@("`@=&%B
M;&4@*&4N9RX@<&QA:6XL(&-R>7!T+"!M9#4M:&5X+"!M9#4M8F%S938T+"!S
M;60U+`H@*B`@("`@("`@("`@("`@("`@("`@("!S:&$L('-S:&$I+@H@*B`@
M("`@("`@("`@("`@("`@("`@("!$149!54Q4.B`G;60U+6AE>"<*("H@("`G
M<VAO=U]E;F-R>7!T:6]N)R`@5VAE=&AE<B!O<B!N;W0@=&\@<')E<&5N9"!T
M:&4@96YC<GEP=&EO;B!I;B!T:&4*("H@("`@("`@("`@("`@("`@("`@("`@
M<&%S<W=O<F0@9FEE;&0N"B`J("`@("`@("`@("`@("`@("`@("`@($1%1D%5
M3%0Z("=F86QS92<\+W!R93X*("H*("H@4F5Q=6ER960@8GD@<V]M92!D871A
M8F%S92!I;7!L96UE;G1A=&EO;G,Z/'!R93X*("H@("`G:&]S='-P96,G("!4
M:&4@:&]S=&YA;64@;V8@=&AE(&1A=&%B87-E('-E<G9E<BX*("H@("`G<')O
M=&]C;VPG("!4:&4@8V]M;75N:6-A=&EO;B!P<F]T;V-O;"`H)W1C<"<L("=U
M;FEX)RP@971C+BDN"B`J("`@)V1A=&%B87-E)R`@5&AE(&YA;64@;V8@=&AE
M(&1A=&%B87-E+@H@*B`@("=U<V5R;F%M92<@(%1H92!U<V5R;F%M92!W:71H
M('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+@H@*B`@("=P87-S
M=V]R9"<@(%1H92!P87-S=V]R9"!A<W-O8VEA=&5D('=I=&@@)W5S97)N86UE
M)RX*("H@("`G;W!T:6]N<R<@("!!9&1I=&EO;F%L(&]P=&EO;G,@=&\@<&%S
M<R!T;R!T:&4@9&%T86)A<V4N"B`J("`@)W!O<G0G("`@("`@5&AE('!O<G0@
M;VX@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@)W1T
M>2<@("`@("`@5&AE(%1462!O;B!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D
M871A8F%S92X\+W!R93X*("H*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T
M:"]!=71H+V-U<W1O;7-Q;"YP:'`L=B`Q+C$V+C$P+C@@,C`P-2\Q,2\S,"`P
M,#HP,SHS.2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(@4F]N;FEE
M($=A<F-I82`\<F]N;FEE0&UK,BYN970^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!2;VYN:64@1V%R8VEA(#QR;VYN:65`;6LR+FYE=#X*("H@0&%U
M=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A
M=71H;W(@($IO96P@5F%N9&%L(#QJ=F%N9&%L0&EN9F]T96-K+G%C+F-A/@H@
M*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@
M*B\*8VQA<W,@075T:%]C=7-T;VUS<6P@97AT96YD<R!!=71H7W-Q;"!["@H@
M("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL:71I97,L('-O('1H
M870@=&AE(&1R:79E<B!C86X@<F5P;W)T('=H:6-H"B`@("`@*B!O<&5R871I
M;VYS(&ET('-U<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S;B=T+@H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1C87!A8FEL:71I
M97,@/2!A<G)A>2@G861D)R`@("`@("`@("`@/3X@=')U92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W5P9&%T92<@("`@("`@(#T^('1R=64L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97-E='!A<W-W;W)D
M)R`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5M
M;W9E)R`@("`@("`@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VQI<W0G("`@("`@("`@(#T^('1R=64L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=T<F%N<W!A<F5N="<@("`]/B!F86QS92D["@H@
M("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W(%-13"!A=71H96YT:6-A
M=&EO;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@075T:%]C=7-T;VUS<6PH)'!A<F%M<R`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R
M86US.PH*("`@("`@("!(;W)D93HZ87-S97)T1')I=F5R0V]N9FEG*"1P87)A
M;7,L("=A=71H)RP*("`@("`@("`@("`@87)R87DH)W%U97)Y7V%U=&@G*2P*
M("`@("`@("`@("`@)V%U=&AE;G1I8V%T:6]N(&-U<W1O;2!344PG*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($9I;F0@;W5T(&EF(&$@<V5T(&]F(&QO9VEN
M(&-R961E;G1I86QS(&%R92!V86QI9"X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@
M("`@("!4:&4@=7-E<DED('1O(&-H96-K+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1C<F5D96YT:6%L<R`@5&AE(&-R961E;G1I86QS('1O('5S92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H92!C
M<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A
M=71H96YT:6-A=&4H)'5S97))9"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@
M("`@("\J(%]C;VYN96-T*"D@=VEL;"!D:64@=VET:"!(;W)D93HZ9F%T86PH
M*2!U<&]N(&9A:6QU<F4N("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D[
M"@H@("`@("`@("\J($)U:6QD(&$@8W5S=&]M('%U97)Y+"!B87-E9"!O;B!T
M:&4@8V]N9FEG(&9I;&4N("HO"B`@("`@("`@)'%U97)Y(#T@)'1H:7,M/E]P
M87)A;7-;)W%U97)Y7V%U=&@G73L*("`@("`@("`D<75E<GD@/2!S=')?<F5P
M;&%C92@G7$PG+"`D=&AI<RT^7V1B+3YQ=6]T92@D=7-E<DED*2P@)'%U97)Y
M*3L*("`@("`@("`D<75E<GD@/2!S=')?<F5P;&%C92@G7%`G+"`D=&AI<RT^
M7V1B+3YQ=6]T92@D=&AI<RT^9V5T0W)Y<'1E9%!A<W-W;W)D*"1C<F5D96YT
M:6%L<ULG<&%S<W=O<F0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)V5N8W)Y<'1I;VXG72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=S:&]W7V5N8W)Y
M<'1I;VXG72DI+"`D<75E<GDI.PH*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/E]D8BT^<75E<GDH)'%U97)Y*3L*("`@("`@("!I9B`H(6ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D<F]W(#T@)')E<W5L
M="T^9F5T8VA2;W<H1$)?1T5434]$15]!4U-/0RD["B`@("`@("`@("`@("\J
M($EF('=E(&AA=F4@870@;&5A<W0@;VYE(')E='5R;F5D(')O=RP@=&AE;B!T
M:&4@=7-E<B!I<PH@("`@("`@("`@("`@*B!V86QI9"X@*B\*("`@("`@("`@
M("`@:68@*&ES7V%R<F%Y*"1R;W<I*2!["B`@("`@("`@("`@("`@("`D<F5S
M=6QT+3YF<F5E*"D["B`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R97-U;'0M/F9R
M964H*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%5
M5$A?4D5!4T].7T)!1$Q/1TE.*3L*("`@("`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7T9!24Q%1"D[
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!9&0@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E
M9&5N=&EA;',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED
M("`@("`@5&AE('5S97))9"!T;R!A9&0N"B`@("`@*B!`<&%R86T@87)R87D@
M)&-R961E;G1I86QS("!4:&4@8W)E9&5N=&EA;',@=&\@861D+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%
M05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%D9%5S97(H)'5S97))9"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`O*B!"=6EL9"!A(&-U
M<W1O;2!Q=65R>2P@8F%S960@;VX@=&AE(&-O;F9I9R!F:6QE+B`J+PH@("`@
M("`@("1Q=65R>2`]("1T:&ES+3Y?<&%R86US6R=Q=65R>5]A9&0G73L*("`@
M("`@("`D<75E<GD@/2!S=')?<F5P;&%C92@G7$PG+"`D=&AI<RT^7V1B+3YQ
M=6]T92@D=7-E<DED*2P@)'%U97)Y*3L*("`@("`@("`D<75E<GD@/2!S=')?
M<F5P;&%C92@G7%`G+"`D=&AI<RT^7V1B+3YQ=6]T92@D=&AI<RT^9V5T0W)Y
M<'1E9%!A<W-W;W)D*"1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("<G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V5N8W)Y<'1I
M;VXG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=S:&]W7V5N8W)Y<'1I;VXG72DI+"`D<75E<GDI.PH*("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y*3L*("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<&1A=&4@82!S970@
M;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;VQD240@("`@("`@5&AE(&]L9"!U<V5R260N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N97=)1"`@("`@("!4:&4@;F5W('5S97))
M9"X*("`@("`J($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@(%1H92!N97<@
M8W)E9&5N=&EA;',*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E
M(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!U<&1A=&55<V5R*"1O;&1)1"P@)&YE
M=TE$+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@+RH@7V-O;FYE8W0H
M*2!W:6QL(&1I92!W:71H($AO<F1E.CIF871A;"@I('5P;VX@9F%I;'5R92X@
M*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I
M;&0@82!C=7-T;VT@<75E<GDL(&)A<V5D(&]N('1H92!C;VYF:6<@9FEL92X@
M*B\*("`@("`@("`D<75E<GD@/2`D=&AI<RT^7W!A<F%M<ULG<75E<GE?=7!D
M871E)UT["B`@("`@("`@)'%U97)Y(#T@<W1R7W)E<&QA8V4H)UQ/)RP@)'1H
M:7,M/E]D8BT^<75O=&4H)&]L9$E$*2P@)'%U97)Y*3L*("`@("`@("`D<75E
M<GD@/2!S=')?<F5P;&%C92@G7$PG+"`D=&AI<RT^7V1B+3YQ=6]T92@D;F5W
M240I+"`D<75E<GDI.PH@("`@("`@("1Q=65R>2`]('-T<E]R97!L86-E*"=<
M4"<L("1T:&ES+3Y?9&(M/G%U;W1E*"1T:&ES+3YG971#<GEP=&5D4&%S<W=O
M<F0H)&-R961E;G1I86QS6R=P87-S=V]R9"==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG96YC<GEP=&EO;B==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)W-H;W=?96YC<GEP=&EO;B==*2DL("1Q=65R>2D["@H@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDI.PH@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E<V5T<R!A('5S97(G<R!P87-S=V]R
M9"X@57-E9"!F;W(@97AA;7!L92!W:&5N('1H92!U<V5R(&1O97,@;F]T"B`@
M("`@*B!R96UE;6)E<B!T:&4@97AI<W1I;F<@<&%S<W=O<F0N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<E]I9"`@5&AE('5S97(@:60@9F]R
M('=H:6-H('1O(')E<V5T('1H92!P87-S=V]R9"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4:&4@;F5W('!A<W-W;W)D(&]N('-U8V-E<W,@;W(@
M82!014%27T5R<F]R(&]B:F5C="!O;@H@("`@("H@("`@("`@("`@("`@("`@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5S971087-S=V]R9"@D
M=7-E<E]I9"D*("`@('L*("`@("`@("`O*B!?8V]N;F5C="@I('=I;&P@9&EE
M('=I=&@@2&]R9&4Z.F9A=&%L*"D@=7!O;B!F86EL=7)E+B`J+PH@("`@("`@
M("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`O*B!'970@82!N97<@<F%N
M9&]M('!A<W-W;W)D+B`J+PH@("`@("`@("1P87-S=V]R9"`]($%U=&@Z.F=E
M;E)A;F1O;5!A<W-W;W)D*"D["@H@("`@("`@("\J($)U:6QD('1H92!344P@
M<75E<GDN("HO"B`@("`@("`@)'%U97)Y(#T@)'1H:7,M/E]P87)A;7-;)W%U
M97)Y7W)E<V5T<&%S<W=O<F0G73L*("`@("`@("`D<75E<GD@/2!S=')?<F5P
M;&%C92@G7$PG+"`D=&AI<RT^7V1B+3YQ=6]T92@D=7-E<E]I9"DL("1Q=65R
M>2D["B`@("`@("`@)'%U97)Y(#T@<W1R7W)E<&QA8V4H)UQ0)RP@)'1H:7,M
M/E]D8BT^<75O=&4H)'1H:7,M/F=E=$-R>7!T961087-S=V]R9"@D<&%S<W=O
M<F0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=E;F-R>7!T:6]N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG<VAO=U]E;F-R>7!T:6]N)UTI*2P@)'%U
M97)Y*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q
M=65R>2D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D<&%S<W=O<F0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!$96QE=&4@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA;',N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("!4:&4@=7-E
M<DED('1O(&1E;&5T92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M("`@("`@(%-U8V-E<W,@;W(@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5M;W9E57-E<B@D=7-E<DED*0H@("`@>PH@("`@("`@("\J(%]C;VYN
M96-T*"D@=VEL;"!D:64@=VET:"!(;W)D93HZ9F%T86PH*2!U<&]N(&9A:6QU
M<F4N("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J
M($)U:6QD(&$@8W5S=&]M('%U97)Y+"!B87-E9"!O;B!T:&4@8V]N9FEG(&9I
M;&4N("HO"B`@("`@("`@)'%U97)Y(#T@)'1H:7,M/E]P87)A;7-;)W%U97)Y
M7W)E;6]V92==.PH@("`@("`@("1Q=65R>2`]('-T<E]R97!L86-E*"=<3"<L
M("1T:&ES+3Y?9&(M/G%U;W1E*"1U<V5R260I+"`D<75E<GDI.PH*("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y*3L*("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1T:&ES+3YR96UO=F55<V5R1&%T82@D=7-E<DED*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($QI<W0@86QL('5S97)S(&EN('1H92!S>7-T96TN"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&%R<F%Y(&]F('5S97))9',L
M(&]R(&9A;'-E(&]N(&9A:6QU<F4O=6YS=7!P;W)T960N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&QI<W15<V5R<R@I"B`@("!["B`@("`@("`@+RH@7V-O;FYE
M8W0H*2!W:6QL(&1I92!W:71H($AO<F1E.CIF871A;"@I('5P;VX@9F%I;'5R
M92X@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@
M0G5I;&0@82!C=7-T;VT@<75E<GDL(&)A<V5D(&]N('1H92!C;VYF:6<@9FEL
M92X@*B\*("`@("`@("`D<75E<GD@/2`D=&AI<RT^7W!A<F%M<ULG<75E<GE?
M;&ES="==.PH*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^9V5T06QL
M*"1Q=65R>2P@;G5L;"P@1$)?1D540TA-3T1%7T]21$52140I.PH@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`O*B!,;V]P
M('1H<F]U9V@@86YD(&)U:6QD(')E='5R;B!A<G)A>2X@*B\*("`@("`@("`D
M=7-E<G,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1R97-U;'0@87,@
M)&%R*2!["B`@("`@("`@("`@("1U<V5R<UM=(#T@)&%R6S!=.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1U<V5R<SL*("`@('T*"GT*````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U
M=&@O8WER<W%L+G!H<```````````````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`T,3(V-0`Q,#4Q-30S,S<U,0`P,C(T,C(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G
M2&]R9&4O075T:"]S<6PN<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92])34%0
M+T%D;6EN+G!H<"<["@HO*BH*("H@5&AE($%U=&A?8WER<W%L(&-L87-S('!R
M;W9I9&5S(&$@4U%,(&EM<&QE;65N=&%T:6]N(&]F('1H92!(;W)D90H@*B!A
M=71H96YT:6-A=&EO;B!S>7-T96T@9F]R('1H92!#>7)U<R!)34%0('-E<G9E
M<BX@36]S="!O9B!T:&4@9G5N8W1I;VYA;&ET>0H@*B!I<R!T:&4@<V%M92!A
M<R!F;W(@=&AE(%-13"!C;&%S<SL@;VYL>2!W:&%T(&ES(&1I9F9E<F5N="!O
M=F5R<FED97,@=&AE"B`J('!A<F5N="!C;&%S<R!I;7!L96UE;G1A=&EO;G,N
M"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z/'!R93X*("H@("`G8WER861M
M:6XG("!4:&4@=7-E<FYA;64@;V8@=&AE(&-Y<G5S(&%D;6EN:7-T<F%T;W(N
M"B`J("`@)V-Y<G!A<W,G("`@5&AE('!A<W-W;W)D(&9O<B!T:&4@8WER=7,@
M861M:6YI<W1R871O<BX*("H@("`G:6UA<%]D<VXG("!4:&4@9G5L;"!)34%0
M($133@H@*B`@("`@("`@("`@("`@("AI+F4N('ML;V-A;&AO<W0Z.3DS+VEM
M87`O<W-L+VYO=F%L:61A=&4M8V5R='TI+@H@*B`@("=P:'!T>7!E)R`@(%1H
M92!D871A8F%S92!T>7!E("AI92X@)W!G<W%L)RP@)VUY<W%L)RP@971C+BDN
M/"]P<F4^"B`J"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G
M9&]M86EN7V9I96QD)R`@("!)9B!S970@=&\@86YY=&AI;F<@;W1H97(@=&AA
M;B`G;F]N92<@=&AI<R!I<R!U<V5D(&%S"B`J("`@("`@("`@("`@("`@("`@
M("`@9FEE;&0@;F%M92!W:&5R92!D;VUA:6X@:7,@<W1O<F5D+@H@*B`@("`@
M("`@("`@("`@("`@("`@($1%1D%53%0Z("=D;VUA:6Y?;F%M92<*("H@("`G
M96YC<GEP=&EO;B<@("`@("!4:&4@96YC<GEP=&EO;B!T;R!U<V4@=&\@<W1O
M<F4@=&AE('!A<W-W;W)D(&EN('1H90H@*B`@("`@("`@("`@("`@("`@("`@
M('1A8FQE("AE+F<N('!L86EN+"!C<GEP="P@;60U+6AE>"P@;60U+6)A<V4V
M-"P@<VUD-2P*("H@("`@("`@("`@("`@("`@("`@("!S:&$L('-S:&$I+@H@
M*B`@("`@("`@("`@("`@("`@("`@($1%1D%53%0Z("=M9#4M:&5X)PH@*B`@
M("=F;VQD97)S)R`@("`@("`@($%N(&%R<F%Y(&]F(&9O;&1E<G,@=&\@8W)E
M871E('5N9&5R('5S97)N86UE+@H@*B`@("`@("`@("`@("`@("`@("`@($1%
M1D%53%0Z($Y/3D4*("H@("`G<&%S<W=O<F1?9FEE;&0G("!4:&4@;F%M92!O
M9B!T:&4@<&%S<W=O<F0@9FEE;&0@:6X@=&AE(&%U=&@@=&%B;&4N"B`J("`@
M("`@("`@("`@("`@("`@("`@1$5&055,5#H@)W!A<W-W;W)D)PH@*B`@("=Q
M=6]T82<@("`@("`@("`@(%1H92!Q=6]T82`H:6X@:VEL;V)Y=&5S*2!T;R!G
M<F%N="!O;B!T:&4@;6%I;&)O>"X*("H@("`@("`@("`@("`@("`@("`@("!$
M149!54Q4.B!.3TY%"B`J("`@)W1A8FQE)R`@("`@("`@("`@5&AE(&YA;64@
M;V8@=&AE(&%U=&@@=&%B;&4@:6X@)V1A=&%B87-E)RX*("H@("`@("`@("`@
M("`@("`@("`@("!$149!54Q4.B`G86-C;W5N='5S97(G"B`J("`@)W5N:7AH
M:65R)R`@("`@("`@5&AE('9A;'5E(&]F(&EM87!D+F-O;F8G<R!U;FEX:&EE
M<F%R8VAY<V5P('-E='1I;F<N"B`J("`@("`@("`@("`@("`@("`@("`@4V5T
M('1H:7,@=&\@=')U92!I9B!T:&4@=F%L=64@:7,@=')U92!I;B!I;6%P9"YC
M;VYF+@H@*B`@("=U<V5R;F%M95]F:65L9"<@(%1H92!N86UE(&]F('1H92!U
M<V5R;F%M92!F:65L9"!I;B!T:&4@875T:"!T86)L92X*("H@("`@("`@("`@
M("`@("`@("`@("!$149!54Q4.B`G=7-E<FYA;64G/"]P<F4^"B`J"B`J(%)E
M<75I<F5D(&)Y('-O;64@9&%T86)A<V4@:6UP;&5M96YT871I;VYS.CQP<F4^
M"B`J("`@)V1A=&%B87-E)R`@5&AE(&YA;64@;V8@=&AE(&1A=&%B87-E+@H@
M*B`@("=H;W-T<W!E8R<@(%1H92!H;W-T;F%M92!O9B!T:&4@9&%T86)A<V4@
M<V5R=F5R+@H@*B`@("=P<F]T;V-O;"<@(%1H92!C;VUM=6YI8V%T:6]N('!R
M;W1O8V]L("@G=&-P)RP@)W5N:7@G+"!E=&,N*2X*("H@("`G=7-E<FYA;64G
M("!4:&4@=7-E<FYA;64@=VET:"!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D
M871A8F%S92X*("H@("`G<&%S<W=O<F0G("!4:&4@<&%S<W=O<F0@87-S;V-I
M871E9"!W:71H("=U<V5R;F%M92<N"B`J("`@)V]P=&EO;G,G("`@061D:71I
M;VYA;"!O<'1I;VYS('1O('!A<W,@=&\@=&AE(&1A=&%B87-E+@H@*B`@("=P
M;W)T)R`@("`@(%1H92!P;W)T(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE
M(&1A=&%B87-E+@H@*B`@("=T='DG("`@("`@(%1H92!45%D@;VX@=VAI8V@@
M=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N/"]P<F4^"B`J"B`J"B`J(%1H
M92!T86)L92!S=')U8W1U<F4@9F]R('1H92!A=71H('-Y<W1E;2!I<R!A<R!F
M;VQL;W=S.@H@*@H@*B`\<')E/@H@*B!#4D5!5$4@5$%"3$4@86-C;W5N='5S
M97(@*`H@*B`@("`@=7-E<FYA;64@("`@5D%20TA!4B@R-34I($))3D%262!.
M3U0@3E5,3"!$149!54Q4("<G+`H@*B`@("`@<&%S<W=O<F0@("`@5D%20TA!
M4B@S,BD@0DE.05)9($Y/5"!.54Q,($1%1D%53%0@)R<L"B`J("`@("!P<F5F
M:7@@("`@("!605)#2$%2*#4P*2!.3U0@3E5,3"!$149!54Q4("<G+`H@*B`@
M("`@9&]M86EN7VYA;64@5D%20TA!4B@R-34I($Y/5"!.54Q,($1%1D%53%0@
M)R<L"B`J("`@("!53DE1544@2T59('5S97)N86UE("AU<V5R;F%M92D*("H@
M*3L*("H*("H@0U)%051%(%1!0DQ%(&%D;6EN=7-E<B`H"B`J("`@("!U<V5R
M;F%M92`@("!605)#2$%2*#4P*2!"24Y!4ED@3D]4($Y53$P@1$5&055,5"`G
M)RP*("H@("`@('!A<W-W;W)D("`@(%9!4D-(05(H-3`I($))3D%262!.3U0@
M3E5,3"!$149!54Q4("<G+`H@*B`@("`@='EP92`@("`@("`@24Y4*#$Q*2!.
M3U0@3E5,3"!$149!54Q4("<P)RP*("H@("`@(%-)1"`@("`@("`@(%9!4D-(
M05(H,C4U*2!.3U0@3E5,3"!$149!54Q4("<G+`H@*B`@("`@:&]M92`@("`@
M("`@5D%20TA!4B@R-34I($Y/5"!.54Q,($1%1D%53%0@)R<L"B`J("`@("!0
M4DE-05)9($M%62`H=7-E<FYA;64I"B`J("D["B`J"B`J($-214%412!404),
M12!A;&EA<R`H"B`J("`@("!A;&EA<R`@("`@("!605)#2$%2*#(U-2D@3D]4
M($Y53$P@1$5&055,5"`G)RP*("H@("`@(&1E<W0@("`@("`@($Q/3D=415A4
M+`H@*B`@("`@=7-E<FYA;64@("`@5D%20TA!4B@U,"D@3D]4($Y53$P@1$5&
M055,5"`G)RP*("H@("`@('-T871U<R`@("`@($E.5"@Q,2D@3D]4($Y53$P@
M1$5&055,5"`G,2<L"B`J("`@("!04DE-05)9($M%62`H86QI87,I"B`J("D[
M"B`J"B`J($-214%412!404),12!D;VUA:6X@*`H@*B`@("`@9&]M86EN7VYA
M;64@5D%20TA!4B@R-34I($Y/5"!.54Q,($1%1D%53%0@)R<L"B`J("`@("!P
M<F5F:7@@("`@("!605)#2$%2*#4P*2!.3U0@3E5,3"!$149!54Q4("<G+`H@
M*B`@("`@;6%X86-C;W5N=',@24Y4*#$Q*2!.3U0@3E5,3"!$149!54Q4("<R
M,"<L"B`J("`@("!Q=6]T82`@("`@("!)3E0H,3`I($Y/5"!.54Q,($1%1D%5
M3%0@)S(P,#`P)RP*("H@("`@('1R86YS<&]R="`@(%9!4D-(05(H,C4U*2!.
M3U0@3E5,3"!$149!54Q4("=C>7)U<R<L"B`J("`@("!F<F5E;F%M97,@("!%
M3E5-*"=915,G+"=.3R<I($Y/5"!.54Q,($1%1D%53%0@)TY/)RP*("H@("`@
M(&9R965A9&1R97-S($5.54TH)UE%4R<L)TY/)RD@3D]4($Y53$P@1$5&055,
M5"`G3D\G+`H@*B`@("`@4%))34%262!+15D@*&1O;6%I;E]N86UE*2P*("H@
M("`@(%5.25%512!+15D@<')E9FEX("AP<F5F:7@I"B`J("D["B`J"B`J($-2
M14%412!404),12!D;VUA:6YA9&UI;B`H"B`J("`@("!D;VUA:6Y?;F%M92!6
M05)#2$%2*#(U-2D@3D]4($Y53$P@1$5&055,5"`G)RP*("H@("`@(&%D;6EN
M=7-E<B`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"!$149!54Q4("<G"B`J("D[
M"B`J"B`J($-214%412!404),12!S96%R8V@@*`H@*B`@("`@<V5A<F-H7VED
M("`@5D%20TA!4B@R-34I($Y/5"!.54Q,($1%1D%53%0@)R<L"B`J("`@("!S
M96%R8VA?<W%L("!415A4($Y/5"!.54Q,+`H@*B`@("`@<&5R<&%G92`@("`@
M24Y4*#$Q*2!.3U0@3E5,3"!$149!54Q4("<P)RP*("H@("`@('1I;65S=&%M
M<"`@(%1)34535$%-4"@Q-"D@3D]4($Y53$PL"B`J("`@("!04DE-05)9($M%
M62`H<V5A<F-H7VED*2P*("H@("`@($M%62!S96%R8VA?:60@*'-E87)C:%]I
M9"D*("H@*3L*("H*("H@0U)%051%(%1!0DQ%('9I<G1U86P@*`H@*B`@("`@
M86QI87,@("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,($1%1D%53%0@)R<L
M"B`J("`@("!D97-T("`@("`@("!,3TY'5$585"P*("H@("`@('5S97)N86UE
M("`@(%9!4D-(05(H-3`I($Y/5"!.54Q,($1%1D%53%0@)R<L"B`J("`@("!S
M=&%T=7,@("`@("!)3E0H,3$I($Y/5"!.54Q,($1%1D%53%0@)S$G+`H@*B`@
M("`@2T59(&%L:6%S("AA;&EA<RD*("H@*3L*("H*("H@0U)%051%(%1!0DQ%
M(&QO9R`H"B`J("`@("!I9"`@("`@("`@("!)3E0H,3$I($Y/5"!.54Q,($%5
M5$]?24Y#4D5-14Y4+`H@*B`@("`@;7-G("`@("`@("`@5$585"!.3U0@3E5,
M3"P*("H@("`@('5S97(@("`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"!$
M149!54Q4("<G+`H@*B`@("`@:&]S="`@("`@("`@5D%20TA!4B@R-34I($Y/
M5"!.54Q,($1%1D%53%0@)R<L"B`J("`@("!T:6UE("`@("`@("!$051%5$E-
M12!.3U0@3E5,3"!$149!54Q4("<R,#`P+3`P+3`P(#`P.C`P.C`P)RP*("H@
M("`@('!I9"`@("`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"!$149!54Q4
M("<G+`H@*B`@("`@4%))34%262!+15D@*&ED*0H@*B`I.PH@*B`\+W!R93X*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`L
M=B`Q+C,S+C$P+C$T(#(P,#8O,#@O,30@,#(Z-#@Z-#@@8VAU8VL@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!);'EA(#QM86EL0&MR96PN;W)G
M/@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H
M;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!);'EA(#QM
M86EL0&MR96PN;W)G/@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`
M:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@
M2&]R9&5?075T:`H@*B\*8VQA<W,@075T:%]C>7)S<6P@97AT96YD<R!!=71H
M7W-Q;"!["@H@("`@+RHJ"B`@("`@*B!(86YD;&4@9F]R('1H92!C=7)R96YT
M($E-05`@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`=F%R(')E<V]U<F-E
M"B`@("`@*B\*("`@('9A<B`D7VEM87!3=')E86T["@H@("`@+RHJ"B`@("`@
M*B!(86YD;&4@9F]R(&%N($E-05!?061M:6X@;V)J96-T+@H@("`@("H*("`@
M("`J($!V87(@24U!4%]!9&UI;@H@("`@("HO"B`@("!V87(@)%]A9&UI;CL*
M"B`@("`O*BH*("`@("`J($AI97)A<F-H>2!S97!A<F%T;W(@=&\@=7-E("AE
M+F<N+"!I<R!I="!U<V5R+VUA:6QB;W@@;W(@=7-E<BYM86EL8F]X*0H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W-E<&%R
M871O<B`]("<N)SL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I
M;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N($%U=&A?8WER<W%L*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@
M("`@(&EF("@A571I;#HZ97AT96YS:6]N17AI<W1S*"=I;6%P)RDI('L*("`@
M("`@("`@("`@2&]R9&4Z.F9A=&%L*%\H(D%U=&A?8WER<W%L.B!297%U:7)E
M9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(BDL(%]?1DE,15]?+"!?7TQ)
M3D5?7RD["B`@("`@("`@?0H@("`@("`@('!A<F5N=#HZ075T:%]S<6PH)'!A
M<F%M<RD["@H@("`@("`@("1A9&UI;E]P87)A;7,@/2!A<G)A>2@G861M:6Y?
M=7-E<B<@/3X@)'!A<F%M<ULG8WER861M:6XG72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V%D;6EN7W!A<W-W;W)D)R`]/B`D<&%R86US6R=C
M>7)P87-S)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D<VXG
M(#T^("1P87)A;7-;)VEM87!?9'-N)UTI.PH@("`@("`@(&EF("@A96UP='DH
M)'1H:7,M/E]P87)A;7-;)W5N:7AH:65R)UTI*2!["B`@("`@("`@("`@("1A
M9&UI;E]P87)A;7-;)W5S97)H:65R87)C:'DG72`]("=U<V5R+R<["B`@("`@
M("`@?0H@("`@("`@("1T:&ES+3Y?861M:6X@/2`F;F5W($E-05!?061M:6XH
M)&%D;6EN7W!A<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@82!S
M970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@("`@(%1H92!U<V5R260@=&\@
M861D+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D8W)E9&5N=&EA;',@(%1H92!C
M<F5D96YT:6%L<R!T;R!A9&0N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@861D57-E<B@D=7-E<DED
M+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@)'1H:7,M/E]C;VYN96-T
M*"D["@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)V1O;6%I
M;E]F:65L9"==*2`F)@H@("`@("`@("`@("`H)'1H:7,M/E]P87)A;7-;)V1O
M;6%I;E]F:65L9"==("$]("=N;VYE)RDI('L*("`@("`@("`@("`@;&ES="@D
M;F%M92P@)&1O;6%I;BD@/2!E>'!L;V1E*"=`)RP@)'5S97))9"D["B`@("`@
M("`@("`@("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@("`@("`@
M("1Q=65R>2`]('-P<FEN=&8H)TE.4T525"!)3E1/("5S("@E<RP@)7,L("5S
M*2!604Q515,@*#\L(#\L(#\I)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;65?9FEE;&0G
M72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG9&]M86EN7V9I96QD)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D7V9I96QD)UTI.PH@("`@("`@
M("`@("`D=F%L=65S(#T@87)R87DH)&YA;64L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9&]M86EN+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/F=E=$-R>7!T961087-S=V]R9"@D8W)E9&5N=&EA;'-;)W!A
M<W-W;W)D)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("<G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG96YC<GEP=&EO;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<VAO
M=U]E;F-R>7!T:6]N)UTI*3L*"B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S
M86=E*"=344P@475E<GD@8GD@075T:%]C>7)S<6PZ.F%D9%5S97(H*3H@)R`N
M("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD[
M"@H@("`@("`@("`@("`D9&)R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D
M<75E<GDL("1V86QU97,I.PH@("`@("`@("`@("`D<75E<GD@/2`G24Y315)4
M($E.5$\@=FER='5A;"`H86QI87,L(&1E<W0L('5S97)N86UE+"!S=&%T=7,I
M(%9!3%5%4R`H/RP@/RP@/RP@,2DG.PH@("`@("`@("`@("`D=F%L=65S(#T@
M87)R87DH)'5S97))9"P@)&YA;64L("1N86UE*3L*"B`@("`@("`@("`@($AO
M<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@075T:%]C>7)S<6PZ.F%D
M9%5S97(H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U]$14)51RD["@H@("`@("`@("`@("`D9&)R97-U;'0R(#T@)'1H:7,M
M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*("`@("`@("`@("`@:68@
M*&ES7V$H)&1B<F5S=6QT,BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1D8G)E<W5L=#(["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D9&)R97-U;'0@/2!P87)E;G0Z.F%D
M9%5S97(H)'5S97))9"P@)&-R961E;G1I86QS*3L*("`@("`@("`@("`@)&YA
M;64@/2`D=7-E<DED.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?82@D9&)R
M97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1D
M8G)E<W5L=#L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?82@D<F5S=6QT
M(#T@)'1H:7,M/E]A9&UI;BT^861D36%I;&)O>"@D;F%M92DL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@0&%R<F%Y7W=A;&LH)'1H:7,M/E]P87)A
M;7-;)V9O;&1E<G,G72P*("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)'1H:7,L("=?8W)E871E4W5B1F]L9&5R<R<I+"`D;F%M92D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)TE-05`@
M;6%I;&)O>"!C<F5A=&EO;B!F;W(@)R`N("1N86UE("X@)R!F86EL960Z("<@
M+B`D<F5S=6QT+3YG971-97-S86=E*"DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?
M*"))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(I+"`D<F5S=6QT
M+3YG971-97-S86=E*"DI*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7W!A<F%M<ULG<75O=&$G72D@)B8@)'1H:7,M/E]P87)A;7-;
M)W%U;W1A)UT@/CT@,"D@>PH@("`@("`@("`@("!I9B`H(4!I;6%P7W-E=%]Q
M=6]T82@D=&AI<RT^7VEM87!3=')E86TL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=U<V5R)R`N("1T:&ES+3Y?<V5P87)A=&]R("X@)&YA
M;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=Q=6]T82==*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*"))34%0(&UA:6QB;W@@<75O=&$@
M8W)E871I;VX@9F%I;&5D.B`E<R(I+"!I;6%P7VQA<W1?97)R;W(H*2DI.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T92!A('-E="!O9B!A=71H96YT
M:6-A=&EO;B!C<F5D96YT:6%L<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1U<V5R260@(%1H92!U<V5R260@=&\@9&5L971E+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@("`@("`@4W5C8V5S<R!O<B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F55<V5R*"1U<V5R260I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@(&EF("@A
M96UP='DH)'1H:7,M/E]P87)A;7-;)V1O;6%I;E]F:65L9"==*2`F)@H@("`@
M("`@("`@("`H)'1H:7,M/E]P87)A;7-;)V1O;6%I;E]F:65L9"==("$]("=N
M;VYE)RDI('L*("`@("`@("`@("`@;&ES="@D;F%M92P@)&1O;6%I;BD@/2!E
M>'!L;V1E*"=`)RP@)'5S97))9"D["B`@("`@("`@("`@("\J($)U:6QD('1H
M92!344P@<75E<GDN("HO"B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN=&8H
M)T1%3$5412!&4D]-("5S(%=(15)%("5S(#T@/R!A;F0@)7,@/2`_)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG=7-E<FYA;65?9FEE;&0G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG9&]M86EN7V9I96QD)UTI.PH@("`@
M("`@("`@("`D=F%L=65S(#T@87)R87DH)&YA;64L("1D;VUA:6XI.PH*("`@
M("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!!=71H
M7V-Y<G-Q;#HZ<F5M;W9E57-E<B@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@
M7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@("`@("1D8G)E
M<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@
M("`@("`@("`@("1Q=65R>2`]("=$14Q%5$4@1E)/32!V:7)T=6%L(%=(15)%
M(&1E<W0@/2`_)SL*("`@("`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1N86UE
M*3L*"B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@
M8GD@075T:%]C>7)S<6PZ.G)E;6]V955S97(H*3H@)R`N("1Q=65R>2P@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("`@
M("`D9&)R97-U;'0R(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L
M=65S*3L*("`@("`@("`@("`@:68@*&ES7V$H)&1B<F5S=6QT,BP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1D8G)E<W5L=#([
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M9&)R97-U;'0@/2!P87)E;G0Z.G)E;6]V955S97(H)'5S97))9"D["B`@("`@
M("`@("`@("1N86UE(#T@)'5S97))9#L*("`@("`@("!]"@H@("`@("`@(&EF
M("AI<U]A*"1D8G)E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&1B<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@+RH@1&5L
M971E($E-05`@;6%I;&)O>"X@*B\*("`@("`@("`D:6UA<')E<W5L="`]("1T
M:&ES+3Y?861M:6XM/G)E;6]V94UA:6QB;W@H)&YA;64I.PH*("`@("`@("!I
M9B`H:7-?82@D:6UA<')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(DE-05`@
M;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(BDL("1I;6%P<F5S=6QT+3YG
M971-97-S86=E*"DI*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI
M<RT^<F5M;W9E57-E<D1A=&$H)'5S97))9"D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!='1E;7!T<R!T;R!O<&5N(&-O;FYE8W1I;VYS('1O('1H92!344P@
M86YD($E-05`@<V5R=F5R<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E
M<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I"B`@("!["B`@("`@("`@:68@*"$D
M=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@("`@("!P87)E;G0Z.E]C;VYN
M96-T*"D["@H@("`@("`@("`@("`O+R!297-E="!T:&4@)%]C;VYN96-T960@
M9FQA9SL@=V4@:&%V96XG="!Y970@<W5C8V5S<V9U;&QY(&]P96YE9`H@("`@
M("`@("`@("`O+R!E=F5R>71H:6YG+@H@("`@("`@("`@("`D=&AI<RT^7V-O
M;FYE8W1E9"`](&9A;'-E.PH*("`@("`@("`@("`@)'1H:7,M/E]I;6%P4W1R
M96%M(#T@0&EM87!?;W!E;B@D=&AI<RT^7W!A<F%M<ULG:6UA<%]D<VXG72P@
M)'1H:7,M/E]P87)A;7-;)V-Y<F%D;6EN)UTL("1T:&ES+3Y?<&%R86US6R=C
M>7)P87-S)UTL($]07TA!3$9/4$5.*3L*("`@("`@("`@("`@:68@*"$D=&AI
M<RT^7VEM87!3=')E86TI('L*("`@("`@("`@("`@("`@($AO<F1E.CIF871A
M;"AS<')I;G1F*%\H(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S
M(BDL(&EM87!?;&%S=%]E<G)O<B@I*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^
M7W!A<F%M<ULG=6YI>&AI97(G72DI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<V5P87)A=&]R(#T@)R\G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1T:&ES+3Y?8V]N;F5C=&5D(#T@=')U93L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1&ES8V]N;F5C
M="!F<F]M('1H92!344P@86YD($E-05`@<V5R=F5R<R!A;F0@8VQE86X@=7`@
M=&AE(&-O;FYE8W1I;VYS+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C
M97-S+"!F86QS92!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M9&ES8V]N;F5C="@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?8V]N;F5C
M=&5D*2!["B`@("`@("`@("`@('!A<F5N=#HZ7V1I<V-O;FYE8W0H*3L*("`@
M("`@("`@("`@0&EM87!?8VQO<V4H)'1H:7,M/E]I;6%P4W1R96%M*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0W)E871E<R!A;&P@;6%I;&)O>&5S('-U<'!L:65D(&EN(&-O;F9I
M9W5R871I;VX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU90H@("`@("H@0'!A<F%M('-T
M<FEN9R`D:V5Y("`@("`@56YU<V5D(&)Y('1H:7,@9')I=F5R"B`@("`@*B!`
M<&%R86T@<W1R:6YG('5S97).86UE"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C
M<F5A=&53=6)&;VQD97)S*"1V86QU92P@)&ME>2P@)'5S97).86UE*0H@("`@
M>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)V1O;6%I;E]F
M:65L9"==*2`F)@H@("`@("`@("`@("`H)'1H:7,M/E]P87)A;7-;)V1O;6%I
M;E]F:65L9"==("$]("=N;VYE)RDI('L*("`@("`@("`@("`@;&ES="@D=7-E
M<DYA;64I(#T@97AP;&]D92@G0"<L("1U<V5R3F%M92D["B`@("`@("`@?0H@
M("`@("`@("1T:&ES+3Y?861M:6XM/F%D9$UA:6QB;W@H)'5S97).86UE("X@
M)'1H:7,M/E]S97!A<F%T;W(@+B`D=F%L=64I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@3&ES="!A;&P@=7-E<G,@:6X@=&AE('-Y<W1E;2X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@87)R87D@;V8@=7-E<DED<RP@;W(@
M9F%L<V4@;VX@9F%I;'5R92]U;G-U<'!O<G1E9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@;&ES=%5S97)S*"D*("`@('L*("`@("`@("`O*B!?8V]N;F5C="@I
M('=I;&P@9&EE('=I=&@@2&]R9&4Z.F9A=&%L*"D@=7!O;B!F86EL=7)E+B`J
M+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("!I9B`H(65M
M<'1Y*"1T:&ES+3Y?<&%R86US6R=D;VUA:6Y?9FEE;&0G72D@)B8*("`@("`@
M("`@("`@*"1T:&ES+3Y?<&%R86US6R=D;VUA:6Y?9FEE;&0G72`A/2`G;F]N
M92<I*2!["B`@("`@("`@("`@("\J($)U:6QD('1H92!344P@<75E<GD@=VET
M:"!D;VUA:6XN("HO"B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)U-%
M3$5#5"`E<RP@)7,@1E)/32`E<R!/4D1%4B!"62`E<R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE7V9I
M96QD)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)V1O;6%I;E]F:65L9"==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M95]F:65L
M9"==*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!"=6EL9"!T
M:&4@4U%,('%U97)Y('=I=&AO=70@9&]M86EN+B`J+PH@("`@("`@("`@("`D
M<75E<GD@/2!S<')I;G1F*"=314Q%0U0@)7,@1E)/32`E<R!/4D1%4B!"62`E
M<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W5S97)N86UE7V9I96QD)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE7V9I96QD
M)UTI.PH@("`@("`@('T*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-1
M3"!1=65R>2!B>2!!=71H7V-Y<G-Q;#HZ;&ES=%5S97)S*"DZ("<@+B`D<75E
M<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^9V5T06QL*"1Q=65R>2P@;G5L
M;"P@1$)?1D540TA-3T1%7T]21$52140I.PH@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@?0H*("`@("`@("`O*B!,;V]P('1H<F]U9V@@86YD
M(&)U:6QD(')E='5R;B!A<G)A>2X@*B\*("`@("`@("`D=7-E<G,@/2!A<G)A
M>2@I.PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)V1O;6%I
M;E]F:65L9"==*2`F)@H@("`@("`@("`@("`H)'1H:7,M/E]P87)A;7-;)V1O
M;6%I;E]F:65L9"==("$]("=N;VYE)RDI('L*("`@("`@("`@("`@9F]R96%C
M:"`H)')E<W5L="!A<R`D87(I('L*("`@("`@("`@("`@("`@("1U<V5R<UM=
M(#T@)&%R6S!=("X@)T`G("X@)&%R6S%=.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@9F]R96%C:"`H)')E<W5L="!A<R`D
M87(I('L*("`@("`@("`@("`@("`@("1U<V5R<UM=(#T@)&%R6S!=.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'5S97)S.PH@
M("`@?0H*("`@("\J*@H@("`@("H@57!D871E(&$@<V5T(&]F(&%U=&AE;G1I
M8V%T:6]N(&-R961E;G1I86QS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&]L9$E$("`@("`@(%1H92!O;&0@=7-E<DED+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F5W240@("`@("`@5&AE(&YE=R!U<V5R260N"B`@("`@*B!`
M<&%R86T@87)R87D@)&-R961E;G1I86QS("!4:&4@;F5W(&-R961E;G1I86QS
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S
M(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@=7!D871E57-E<B@D;VQD240L("1N97=)1"P@)&-R961E
M;G1I86QS*0H@("`@>PH@("`@("`@("\J(%]C;VYN96-T*"D@=VEL;"!D:64@
M=VET:"!(;W)D93HZ9F%T86PH*2!U<&]N(&9A:6QU<F4N("HO"B`@("`@("`@
M)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M
M/E]P87)A;7-;)V1O;6%I;E]F:65L9"==*2`F)@H@("`@("`@("`@("`H)'1H
M:7,M/E]P87)A;7-;)V1O;6%I;E]F:65L9"==("$]("=N;VYE)RDI('L*("`@
M("`@("`@("`@;&ES="@D;F%M92P@)&1O;6%I;BD@/2!E>'!L;V1E*"=`)RP@
M)&]L9$E$*3L*("`@("`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2!W
M:71H(&1O;6%I;BX@*B\*("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G
M55!$051%("5S(%-%5"`E<R`](#\@5TA%4D4@)7,@/2`_(&%N9"`E<R`](#\G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=T86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=P87-S=V]R9%]F:65L9"==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M95]F:65L9"==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=D;VUA:6Y?9FEE;&0G72D["B`@("`@("`@("`@("1V86QU97,@/2!A<G)A
M>2@D=&AI<RT^9V5T0W)Y<'1E9%!A<W-W;W)D*"1C<F5D96YT:6%L<ULG<&%S
M<W=O<F0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=E;F-R>7!T:6]N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=S:&]W
M7V5N8W)Y<'1I;VXG72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;F%M92P@)&1O;6%I;BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`@("`@)'%U97)Y
M(#T@<W!R:6YT9B@G55!$051%("5S(%-%5"`E<R`](#\@5TA%4D4@)7,@/2`_
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG=&%B;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG<&%S<W=O<F1?9FEE;&0G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;65?9FEE;&0G
M72D["B`@("`@("`@("`@("1V86QU97,@/2!A<G)A>2@D=&AI<RT^9V5T0W)Y
M<'1E9%!A<W-W;W)D*"1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=E;F-R>7!T:6]N)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=S:&]W7V5N8W)Y<'1I;VXG72DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;VQD240I.PH@("`@("`@
M('T*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!!
M=71H7V-Y<G-Q;#HZ=7!D871E57-E<B@I.B`G("X@)'%U97)Y+"!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]!=71H+V-Y<G5S+G!H<```````````````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,S`P-S$`,3`U,34T,S,W-3$`,#(R,C0S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B!4:&4@075T:%]C>7)U<R!C;&%S<R!P<F]V:61E<R!H;W)D92!W:71H('1H
M92!A8FEL:71Y(&]F(&%D;6EN:7-T<F%T:6YG"B`J(&$@0WER=7,@;6%I;"!S
M97)V97(@875T:&5N=&EC871I;VYS(&%G86EN<W0@86YO=&AE<B!B86-K96YD
M('1H870@2&]R9&4*("H@8V%N('5P9&%T92`H96<@4U%,(&]R($Q$05`I+@H@
M*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@)V-Y<F%D;6EN
M)R`@(%1H92!U<V5R;F%M92!O9B!T:&4@8WER=7,@861M:6YI<W1R871O<@H@
M*B`@("=C>7)P87-S)R`@("!4:&4@<&%S<W=O<F0@9F]R('1H92!C>7)U<R!A
M9&UI;FES=')A=&]R"B`J("`@)VEM87!?9'-N)R`@(%1H92!F=6QL($E-05`@
M1%-.("AI+F4N"B`@("`@("`@("`@("`@("`@('ML;V-A;&AO<W0Z.3DS+VEM
M87`O<W-L+VYO=F%L:61A=&4M8V5R='TI"B`J("`@)V)A8VME;F0G("`@(%1H
M92!C;VUP;&5T92!H87-H(&9O<B!T:&4@075T:%\J(&1R:79E<B!T:&%T(&-Y
M<G5S"B`J("`@("`@("`@("`@("`@(&%U=&AE;G1I8V%T97,@86=A:6YS="`H
M96<@4U%,+"!,1$%0*2X*("H@("`G<V5P87)A=&]R)R`@2&EE<F%R8VAY('-E
M<&%R871O<B!T;R!U<V4@*&4N9RXL(&ES(&ET('5S97(O;6%I;&)O>"!O<@H@
M*B`@("`@("`@("`@("`@("!U<V5R+FUA:6QB;W@I/"]P<F4^"B`J"B`J($]P
M=&EO;F%L('9A;'5E<SH\<')E/@H@*B`@("=U;FEX:&EE<B<@("!4:&4@=F%L
M=64@;V8@:6UA<&0N8V]N9B=S('5N:7AH:65R87)C:'ES97`@<V5T=&EN9RX*
M("H@("`@("`@("`@("`@("`@4V5T('1H:7,@=&\@)W1R=64G(&EF('1H92!V
M86QU92!I<R!T<G5E(&EN(&EM87!D+F-O;F8*("H@("`G9F]L9&5R<R<@("`@
M06X@87)R87D@;V8@9F]L9&5R<R!T;R!C<F5A=&4@=6YD97(@=7-E<FYA;64N
M"B`J("`@("`@("`@("`@("`@($1O97-N)W0@8W)E871E('-U8F9O;&1E<G,@
M8GD@9&5F875L="X*("H@("`G<75O=&$G("`@("`@5&AE('%U;W1A("AI;B!K
M:6QO8GET97,I('1O(&=R86YT(&]N('1H92!M86EL8F]X+@H@*B`@("`@("`@
M("`@("`@("!$;V5S(&YO="!E<W1A8FQI<V@@<75O=&$@8GD@9&5F875L="X\
M+W!R93X*("H*("H@17AA;7!L92!5<V%G93H\<')E/@H@*B`@("1C;VYF6R=A
M=71H)UU;)V1R:79E<B==(#T@)V-O;7!O<VET92<["B`J("`@)&-O;F9;)V%U
M=&@G75LG<&%R86US)UU;)VQO9VEN<V-R965N7W-W:71C:"==(#T@)U]H;W)D
M95]S96QE8W1?;&]G:6YS8W)E96XG.PH@*B`@("1C;VYF6R=A=71H)UU;)W!A
M<F%M<R==6R=A9&UI;E]D<FEV97(G72`]("=C>7)U<R<["B`J("`@)&-O;F9;
M)V%U=&@G75LG<&%R86US)UU;)V1R:79E<G,G75LG:6UP)UT@/2!A<G)A>2@G
M9')I=F5R)R`]/B`G87!P;&EC871I;VXG+`H@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!A<F%M<R<@
M/3X@87)R87DH)V%P<"<@/3X@)VEM<"<I*3L*("H@("`D8V]N9ELG875T:"==
M6R=P87)A;7,G75LG9')I=F5R<R==6R=C>7)U<R==(#T@87)R87DH)V1R:79E
M<B<@/3X@)V-Y<G5S)RP*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!A<F%M<R<@/3X@87)R87DH
M)V-Y<F%D;6EN)R`]/B`G8WER=7,G+`H@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G8WER<&%S<R<@/3X@)W!A<W-W;W)D)RP*("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W-E<&%R871O<B<@/3X@)RXG+`H@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G:6UA<%]D<VXG(#T^("=[;6%I:RYE
M>&%M<&QE+F-O;2]I;6%P?2<I*3L*("H@("`D8V]N9ELG875T:"==6R=P87)A
M;7,G75LG9')I=F5R<R==6R=C>7)U<R==6R=P87)A;7,G75LG8F%C:V5N9"==
M(#T@87)R87DH)V1R:79E<B<@/3X@)W-Q;"<L"B`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=P87)A;7,G(#T^(&%R<F%Y*"=P:'!T>7!E)R`]
M/B`G;7ES<6PG+`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G:&]S='-P96,G(#T^("=D871A8F%S92YE>&%M
M<&QE+F-O;2<L"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=P<F]T;V-O;"<@/3X@)W1C<"<L"B`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U
M<V5R;F%M92<@/3X@)W5S97)N86UE)RP*("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!A<W-W;W)D)R`]/B`G
M<&%S<W=O<F0G+`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G9&%T86)A<V4G(#T^("=M86EL)RP*("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W1A8FQE)R`]/B`G86-C;W5N='5S97(G+`H@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G96YC<GEP=&EO;B<@
M/3X@)VUD-2UH97@G+`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G=7-E<FYA;65?9FEE;&0G(#T^("=U<V5R
M;F%M92<L"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=P87-S=V]R9%]F:65L9"<@/3X@)W!A<W-W;W)D)RDI
M.PH@*@H@*B`@(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?<V5L96-T
M7VQO9VEN<V-R965N)RDI('L*("H@("`@("`@9G5N8W1I;VX@7VAO<F1E7W-E
M;&5C=%]L;V=I;G-C<F5E;B@I('L*("H@("`@("`@("`@(')E='5R;B`G:6UP
M)SL*("H@("`@("`@?0H@*B`@('T\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<"QV(#$N,34N,3`N,30@,C`P-B\P
M."\Q-"`P,CHT.#HT."!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M,BTR,#`V($EL>6$@/&UA:6Q`:W)E;"YO<F<^"B`J($-O<'ER:6=H="`R,#`S
M+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($EL>6$@/&UA:6Q`:W)E;"YO
M<F<^"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA
M;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(
M;W)D95]!=71H"B`J+PIC;&%S<R!!=71H7V-Y<G5S(&5X=&5N9',@075T:"![
M"@H@("`@+RHJ"B`@("`@*B!(86YD;&4@9F]R('1H92!C=7)R96YT($E-05`@
M8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@
M*B\*("`@('9A<B`D7VEM87!3=')E86T["@H@("`@+RHJ"B`@("`@*B!&;&%G
M(&EN9&EC871I;F<@:68@=&AE($E-05`@8V]N;F5C=&EO;B!I<R!C;VYN96-T
M960N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A
M<B`D7V-O;FYE8W1E9#L*"B`@("`O*BH*("`@("`J(%!O:6YT97(@=&\@86YO
M=&AE<B!!=71H7R!B86-K96YD('1H870@0WER=7,@875T:&5N=&EC871E<R!A
M9V%I;G-T+@H@("`@("H*("`@("`J($!V87(@075T:`H@("`@("HO"B`@("`@
M=F%R("1?8F%C:V5N9#L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F(&-A
M<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A;B!R97!O<G0@=VAI
M8V@*("`@("`J(&]P97)A=&EO;G,@:70@<W5P<&]R=',@86YD('=H:6-H(&ET
M(&1O97-N)W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)&-A<&%B:6QI=&EE<R`](&%R<F%Y*"=A9&0G("`@("`@("`@("`]
M/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=7!D871E
M)R`@("`@("`@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W)E<V5T<&%S<W=O<F0G(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<F5M;W9E)R`@("`@("`@/3X@=')U92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)VQI<W0G("`@("`@("`@(#T^(&9A
M;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9W)O=7!S)R`@
M("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=T<F%N<W!A<F5N="<@("`]/B!F86QS92D["@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M
M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!!=71H7V-Y<G5S*"1P87)A;7,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*
M"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG<V5P87)A=&]R
M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=S97!A<F%T;W(G
M72`]("<N)SL*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7W!A<F%M<ULG=6YI>&AI97(G72D@)B8@)'1H:7,M/E]P87)A;7-;)W5N:7AH
M:65R)UT@/3T@=')U92D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M<V5P87)A=&]R)UT@/2`G+R<["B`@("`@("`@?0H*("`@("`@("!I9B`H(55T
M:6PZ.F5X=&5N<VEO;D5X:7-T<R@G:6UA<"<I*2!["B`@("`@("`@("`@($AO
M<F1E.CIF871A;"A?*")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@?0H*("`@("`@("`O+R!#<F5A=&4@8F%C:V5N9"!I;G-T86YC92X*("`@
M("`@("`D=&AI<RT^7V)A8VME;F0@/2`F075T:#HZ<VEN9VQE=&]N*"1T:&ES
M+3Y?<&%R86US6R=B86-K96YD)UU;)V1R:79E<B==+"`D=&AI<RT^7W!A<F%M
M<ULG8F%C:V5N9"==6R=P87)A;7,G72D["B`@("`@("`@:68@*&ES7V$H)'1H
M:7,M/E]B86-K96YD+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7V)A8VME;F0["B`@("`@("`@?0H*("`@("`@("`O+R!#
M:&5C:R!T:&4@8V%P86)I;&ET:65S(&]F('1H92!B86-K96YD+@H@("`@("`@
M(&EF("@A)'1H:7,M/E]B86-K96YD+3YH87-#87!A8FEL:71Y*"=A9&0G*2!\
M?`H@("`@("`@("`@("`A)'1H:7,M/E]B86-K96YD+3YH87-#87!A8FEL:71Y
M*"=U<&1A=&4G*2!\?`H@("`@("`@("`@("`A)'1H:7,M/E]B86-K96YD+3YH
M87-#87!A8FEL:71Y*"=R96UO=F4G*2D@>PH@("`@("`@("`@("!(;W)D93HZ
M9F%T86PH7R@B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E
M<75I<F5D(&-A<&%B:6QI=&5S+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@('T*"B`@("`@("`@)'1H:7,M/F-A<&%B:6QI=&EE<ULG;&ES="==
M(#T@)'1H:7,M/E]B86-K96YD+3YH87-#87!A8FEL:71Y*"=L:7-T)RD["B`@
M("`@("`@)'1H:7,M/F-A<&%B:6QI=&EE<ULG9W)O=7!S)UT@/2`D=&AI<RT^
M7V)A8VME;F0M/FAA<T-A<&%B:6QI='DH)V=R;W5P<R<I.PH@("`@("`@("1T
M:&ES+3YC87!A8FEL:71I97-;)W1R86YS<&%R96YT)UT@/2`D=&AI<RT^7V)A
M8VME;F0M/FAA<T-A<&%B:6QI='DH)W1R86YS<&%R96YT)RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!9&0@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E
M9&5N=&EA;',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED
M("`@("`@(%1H92!U<V5R260@=&\@861D+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("`D8W)E9&5N=&EA;',@(%1H92!C<F5D96YT:6%L<R!T;R!A9&0N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@
M4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@861D57-E<B@D=7-E<DED+"`D8W)E9&5N=&EA;',I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("1R97,@/2`D=&AI
M<RT^7V)A8VME;F0M/F%D9%5S97(H)'5S97))9"P@)&-R961E;G1I86QS*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*"B`@("`@("`@)&YA;64@
M/2!I;6%P7W5T9C=?96YC;V1E*"1U<V5R260I.PH@("`@("`@(&EF("A`:6UA
M<%]C<F5A=&5M86EL8F]X*"1T:&ES+3Y?:6UA<%-T<F5A;2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I;6%P7W5T9C=?96YC;V1E*"1T:&ES
M+3Y?<&%R86US6R=I;6%P7V1S;B==("X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G=7-E<B<@+B`D=&AI<RT^7W!A<F%M<ULG<V5P87)A=&]R
M)UT@+B`D;F%M92DI*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7W!A<F%M<ULG9F]L9&5R<R==*2`F)B!I<U]A<G)A>2@D=&AI<RT^7W!A<F%M
M<ULG9F]L9&5R<R==*2D@>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/E]P87)A;7-;)V9O;&1E<G,G72!A<R`D9F]L9&5R*2!["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]C<F5A=&53=6)&;VQD97(H)&YA;64L("1F
M;VQD97(I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)TE-
M05`@;6%I;&)O>"!C<F5A=&EO;B!F;W(@)R`N("1N86UE("X@)R!F86EL960@
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(DE-05`@;6%I;&)O>"!C<F5A=&EO
M;B!F86EL960Z("5S(BDL(&EM87!?;&%S=%]E<G)O<B@I*2D["B`@("`@("`@
M?0H*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P87)A;7-;)W%U;W1A)UTI
M("8F("1T:&ES+3Y?<&%R86US6R=Q=6]T82==(#X](#`I('L*("`@("`@("`@
M("`@:68@*"%`:6UA<%]S971?<75O=&$H)'1H:7,M/E]I;6%P4W1R96%M+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=7-E<B<@+B`D=&AI
M<RT^7W-E<&%R871O<B`N("1N86UE+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<75O=&$G72DI('L*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B
M24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B*2P@:6UA
M<%]L87-T7V5R<F]R*"DI*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE
M=&4@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA;',N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("!4:&4@=7-E<DED('1O
M(&1E;&5T92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@("`@("`@
M(%-U8V-E<W,@;W(@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M
M;W9E57-E<B@D=7-E<DED*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8V]N;F5C
M="@I.PH*("`@("`@("`D<F5S(#T@)'1H:7,M/E]B86-K96YD+3YR96UO=F55
M<V5R*"1U<V5R260I.PH@("`@("`@(&EF("AI<U]A*"1R97,L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H*
M("`@("`@("`O*B!3970@04-,(&9O<B!M86EL8F]X(&1E;&5T:6]N+B`J+PH@
M("`@("`@(&QI<W0H)&%D;6EN*2`](&5X<&QO9&4H)T`G+"`D=&AI<RT^7W!A
M<F%M<ULG8WER861M:6XG72D["B`@("`@("`@0&EM87!?<V5T86-L*"1T:&ES
M+3Y?:6UA<%-T<F5A;2P*("`@("`@("`@("`@("`@("`@("`@)W5S97(G("X@
M)'1H:7,M/E]P87)A;7-;)W-E<&%R871O<B==("X@)'5S97))9"P*("`@("`@
M("`@("`@("`@("`@("`@)&%D;6EN+"`G;')S=VEP8V1A)RD["@H@("`@("`@
M("\J($1E;&5T92!)34%0(&UA:6QB;W@N("HO"B`@("`@("`@)&EM87!R97-U
M;'0@/2!`:6UA<%]D96QE=&5M86EL8F]X*"1T:&ES+3Y?:6UA<%-T<F5A;2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)VEM87!?9'-N)UT@+@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G=7-E<B<@+B`D=&AI<RT^7W!A<F%M
M<ULG<V5P87)A=&]R)UT@+B`D=7-E<DED*3L*"B`@("`@("`@:68@*"$D:6UA
M<')E<W5L="D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BAS<')I;G1F*%\H(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S
M(BDL(&EM87!?;&%S=%]E<G)O<B@I*2D["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)'1H:7,M/G)E;6]V955S97)$871A*"1U<V5R260I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@071T96UP=',@=&\@;W!E;B!C;VYN96-T:6]N<R!T
M;R!T:&4@4U%,(&%N9"!)34%0('-E<G9E<G,N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U
M92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H*0H@("`@>PH@("`@
M("`@(&EF("@A)'1H:7,M/E]C;VYN96-T960I('L*"B`@("`@("`@("`@("1T
M:&ES+3Y?:6UA<%-T<F5A;2`]($!I;6%P7V]P96XH)'1H:7,M/E]P87)A;7-;
M)VEM87!?9'-N)UTL("1T:&ES+3Y?<&%R86US6R=C>7)A9&UI;B==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=C>7)P87-S)UTL($]07TA!3$9/4$5.*3L*"B`@("`@("`@
M("`@(&EF("@A)'1H:7,M/E]I;6%P4W1R96%M*2!["B`@("`@("`@("`@("`@
M("!(;W)D93HZ9F%T86PH<W!R:6YT9BA?*")#86XG="!C;VYN96-T('1O($E-
M05`@<V5R=F5R.B`E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:6UA<%]L87-T7V5R<F]R*"DI+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7V-O;FYE
M8W1E9"`]('1R=64["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("`O*BH*("`@("`J($1I<V-O;FYE8W0@9G)O;2!T:&4@24U!
M4"!S97)V97(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A
M;'-E(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D:7-C;VYN
M96-T*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]C;VYN96-T960I('L*
M("`@("`@("`@("`@0&EM87!?8VQO<V4H)'1H:7,M/E]I;6%P4W1R96%M*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0W)E871E<R!A(&UA:6QB;WAE<R!S=7!P;&EE9"!I;B!C;VYF
M:6=U<F%T:6]N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DYA;64@("!&;W(@=VAO;2!T
M:&4@9F]L9&5R('=I;&P@8F4@8W)E871E9`H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9F]L9&5R3F%M92!.86UE(&]F(&9O;&1E<B!T;R!C<F5A=&4*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V-R96%T95-U8D9O;&1E<B@D=7-E<DYA;64L("1F
M;VQD97).86UE*0H@("`@>PH@("`@("`@("!`:6UA<%]C<F5A=&5M86EL8F]X
M*"1T:&ES+3Y?:6UA<%-T<F5A;2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EM87!?=71F-U]E;F-O9&4H)'1H:7,M/E]P87)A;7-;)VEM87!?9'-N
M)UT@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5S97(G("X@)'1H
M:7,M/E]P87)A;7-;)W-E<&%R871O<B==("X@)'5S97).86UE("X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=S97!A<F%T;W(G72`N("1F;VQD97).86UE*2D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!,:7-T(&%L;"!U<V5R<R!I;B!T:&4@<WES=&5M+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1H92!A<G)A>2!O9B!U<V5R261S+"!O
M<B!F86QS92!O;B!F86EL=7)E+W5N<W5P<&]R=&5D+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!L:7-T57-E<G,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7V)A8VME;F0M/FQI<W15<V5R<R@I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@57!D871E(&$@<V5T(&]F(&%U=&AE;G1I8V%T:6]N(&-R961E;G1I86QS
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]L9$E$("`@("`@(%1H
M92!O;&0@=7-E<DED+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W240@("`@
M("`@5&AE(&YE=R!U<V5R260N"B`@("`@*B!`<&%R86T@87)R87D@)&-R961E
M;G1I86QS("!4:&4@;F5W(&-R961E;G1I86QS"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@=7!D871E
M57-E<B@D;VQD240L("1N97=)1"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7V)A8VME;F0M/G5P9&%T955S97(H)&]L9$E$
M+"`D;F5W240L("1C<F5D96YT:6%L<RD["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@=&AE(%5222!O9B!T:&4@;&]G:6X@<V-R965N(&9O<B!T:&ES
M(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@(%1H
M92!A<'!L:6-A=&EO;B!T;R!U<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1U
M<FP@(%1H92!54DP@=&\@<F5D:7)E8W0@=&\@869T97(@;&]G:6XN"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!L;V=I;B!S8W)E96X@55))
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T3&]G:6Y38W)E96XH)&%P<"`]
M("=H;W)D92<L("1U<FP@/2`G)RD*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]B86-K96YD+3Y?9V5T3&]G:6Y38W)E96XH)&%P<"P@)'5R;"D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@82!U<V5R260@97AI<W1S
M(&EN('1H92!S:7-T96TN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!7:&5T:&5R(&]R(&YO="!T:&4@=7-E<DED(&%L<F5A9'D@97AI<W1S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!E>&ES=',H)'5S97))9"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]B86-K96YD+3YE>&ES=',H)'5S97))9"D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!=71O;6%T:6,@875T:&5N=&EC871I
M;VXZ($9I;F0@;W5T(&EF('1H92!C;&EE;G0@;6%T8VAE<R!A;B!A;&QO=V5D
M($E0"B`@("`@*B!B;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@(%=H971H97(@;W(@;F]T('1H92!C;&EE;G0@:7,@86QL;W=E9"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@=')A;G-P87)E;G0H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7V)A8VME;F0M/G1R86YS<&%R96YT*"D["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M075T:"]F='`N<&AP````````````````````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`T,C$W`#$P-3$U-#,S-S4Q`#`R,38W,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@5&AE($%U
M=&A?9G1P(&-L87-S('!R;W9I9&5S(&%N($944"!I;7!L96UE;G1A=&EO;B!O
M9B!T:&4@2&]R9&4*("H@875T:&5N=&EC871I;VX@<WES=&5M+@H@*@H@*B!/
M<'1I;VYA;"!P87)A;65T97)S.CQP<F4^"B`J("`@)VAO<W1S<&5C)R`@5&AE
M(&AO<W1N86UE(&]R($E0(&%D9')E<W,@;V8@=&AE($944"!S97)V97(N"B`J
M("`@("`@("`@("`@("`@1$5&055,5#H@)VQO8V%L:&]S="<*("H@("`G<&]R
M="<@("`@("!4:&4@<V5R=F5R('!O<G0@=&\@8V]N;F5C="!T;RX*("H@("`@
M("`@("`@("`@("!$149!54Q4.B`R,3PO<')E/@H@*@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O9G1P+G!H<"QV(#$N,C,N,3(N."`R,#`V
M+S`Q+S`Q(#(Q.C(X.C`W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY
M.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#
M;W!Y<FEG:'0@,3DY.2TR,#`V($UA>"!+86QI:V$@/&UA>$!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@36%X($MA;&EK82`\;6%X
M0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E
M($AO<F1E7T%U=&@*("HO"F-L87-S($%U=&A?9G1P(&5X=&5N9',@075T:"![
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W($944"!A=71H96YT
M:6-A=&EO;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@075T:%]F='`H)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%5=&EL.CIE>'1E;G-I;VY%>&ES
M=',H)V9T<"<I*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"A?*")!=71H
M7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I
M;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N(BDL(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`D9&5F875L=%]P
M87)A;7,@/2!A<G)A>2@*("`@("`@("`@("`@)VAO<W1S<&5C)R`]/B`G;&]C
M86QH;W-T)RP*("`@("`@("`@("`@)W!O<G0G(#T^(#(Q"B`@("`@("`@*3L*
M("`@("`@("`D=&AI<RT^7W!A<F%M<R`](&%R<F%Y7VUE<F=E*"1D969A=6QT
M7W!A<F%M<RP@)'!A<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD
M(&]U="!I9B!A('-E="!O9B!L;V=I;B!C<F5D96YT:6%L<R!A<F4@=F%L:60N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=7-E<DED("`@("`@5&AE('5S97))9"!T;R!C:&5C
M:RX*("`@("`J($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@($%N(&%R<F%Y
M(&]F(&QO9VEN(&-R961E;G1I86QS+B!&;W(@1E10+`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&AI<R!M=7-T(&-O;G1A:6X@82!P87-S
M=V]R9"!E;G1R>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H
M971H97(@;W(@;F]T('1H92!C<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]A=71H96YT:6-A=&4H)'5S97))9"P@)&-R961E
M;G1I86QS*0H@("`@>PH@("`@("`@("1F='`@/2!`9G1P7V-O;FYE8W0H)'1H
M:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTL("1T:&ES+3Y?<&%R86US6R=P;W)T
M)UTI.PH*("`@("`@("!I9B`H)&9T<"`F)B!`9G1P7VQO9VEN*"1F='`L("1U
M<V5R260L("1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72DI('L*("`@("`@("`@
M("`@0&9T<%]Q=6ET*"1F='`I.PH@("`@("`@("`@("!R971U<FX@=')U93L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!`9G1P7W%U:70H)&9T<"D[
M"B`@("`@("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].
M7T)!1$Q/1TE.*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O075T:"]H='1P+G!H<```````````````````````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#$R,3`W`#$P-3$U-#,S-S4Q`#`R,C`U-0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@5&AE($%U=&A?:'1T<"!C;&%S<R!T<F%N<W!A<F5N=&QY(&QO9W,@
M=7-E<G,@:6X@=&\@2&]R9&4@=7-I;F<*("H@86QR96%D>2!P<F5S96YT($A4
M5%`@875T:&5N=&EC871I;VX@:&5A9&5R<RX*("H*("H@5&AE("=E;F-R>7!T
M:6]N)R!P87)A;65T97(@<W!E8VEF:65S('=H870@:VEN9"!O9B!P87-S=V]R
M9',@87)E(&EN"B`J('1H92`N:'1P87-S=V0@9FEL92X@5&AE('-U<'!O<G1E
M9"!O<'1I;VYS(&%R92`G8W)Y<'0M9&5S)R`H<W1A;F1A<F0*("H@8W)Y<'1E
M9"!H='!A<W-W9"!E;G1R:65S*2!A;F0@)V%P<FUD-2<N(%1H:7,@:6YF;W)M
M871I;VX@:7,@=7-E9"!I9@H@*B!Y;W4@=V%N="!T;R!D:7)E8W1L>2!A=71H
M96YT:6-A=&4@=7-E<G,@=VET:"!T:&ES(&1R:79E<BP@:6YS=&5A9`H@*B!O
M9B!R96QY:6YG(&]N('1R86YS<&%R96YT(&%U=&@N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<"QV(#$N,C$N,3`N.2`R,#`V
M+S`Q+S`Q(#(Q.C(X.C`W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY
M.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G
M92!(;W)D95]!=71H"B`J+PIC;&%S<R!!=71H7VAT='`@97AT96YD<R!!=71H
M('L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@
M<V\@=&AA="!T:&4@9')I=F5R(&-A;B!R97!O<G0@=VAI8V@*("`@("`J(&]P
M97)A=&EO;G,@:70@<W5P<&]R=',@86YD('=H:6-H(&ET(&1O97-N)W0N"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&-A<&%B
M:6QI=&EE<R`](&%R<F%Y*"=A9&0G("`@("`@("`@("`]/B!F86QS92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5P9&%T92<@("`@("`@(#T^
M(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5S971P
M87-S=V]R9"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=R96UO=F4G("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VQI<W0G("`@("`@("`@(#T^(&9A;'-E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=')A;G-P87)E;G0G("`@/3X@
M=')U92D["@H@("`@+RHJ"B`@("`@*B!!<G)A>2!O9B!U<V5R;F%M97,@86YD
M(&AA<VAE9"!P87-S=V]R9',N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]U<V5R<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@
M("`@*B!#;VYS=')U8W1S(&$@;F5W($A45%`@875T:&5N=&EC871I;VX@;V)J
M96-T+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA
M<V@@8V]N=&%I;FEN9R!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!!=71H7VAT='`H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH*("`@("`@("`O+R!$969A=6QT
M('1O($1%4R!P87-S=V]R9',N"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?
M<&%R86US6R=E;F-R>7!T:6]N)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=E;F-R>7!T:6]N)UT@/2`G8W)Y<'0M9&5S)SL*("`@("`@("!]
M"@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)VAT<&%S<W=D
M7V9I;&4G72DI('L*("`@("`@("`@("`@)'5S97)S(#T@0&9I;&4H)'1H:7,M
M/E]P87)A;7-;)VAT<&%S<W=D7V9I;&4G72D["B`@("`@("`@("`@(&EF("AI
M<U]A<G)A>2@D=7-E<G,I*2!["B`@("`@("`@("`@("`@("`O+R!%;F%B;&4@
M=&AE(&QI<W0@=7-E<G,@8V%P86)I;&ET>2X*("`@("`@("`@("`@("`@("1T
M:&ES+3YC87!A8FEL:71I97-;)VQI<W0G72`]('1R=64["@H@("`@("`@("`@
M("`@("`@+R\@4'5T('5S97)S(&EN=&\@86QP:&%B971I8V%L(&]R9&5R+@H@
M("`@("`@("`@("`@("`@<V]R="@D=7-E<G,I.PH*("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1U<V5R<R!A<R`D;&EN92D@>PH@("`@("`@("`@("`@("`@
M("`@(&QI<W0H)'5S97(L("1P87-S*2`](&5X<&QO9&4H)SHG+"`D;&EN92P@
M,BD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]U<V5R<UMT<FEM*"1U
M<V5R*5T@/2!T<FEM*"1P87-S*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($9I;F0@
M;W5T(&EF(&$@<V5T(&]F(&QO9VEN(&-R961E;G1I86QS(&%R92!V86QI9"X@
M3VYL>2!S=7!P;W)T<PH@("`@("H@:'1P87-S=V0@9FEL97,@=VET:"!$15,@
M<&%S<W=O<F1S(')I9VAT(&YO=RX*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@
M("`@5&AE('5S97))9"!T;R!C:&5C:RX*("`@("`J($!P87)A;2!A<G)A>2`@
M)&-R961E;G1I86QS("!!;B!A<G)A>2!O9B!L;V=I;B!C<F5D96YT:6%L<RX@
M1F]R($E-05`L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=&AI<R!M=7-T(&-O;G1A:6X@82!P87-S=V]R9"!E;G1R>2X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H92!C<F5D
M96YT:6%L<R!A<F4@=F%L:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A=71H
M96YT:6-A=&4H)'5S97))9"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@
M(&EF("AE;7!T>2@D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTI*2!["B`@("`@
M("`@("`@($AO<F1E.CIF871A;"A?*").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@2%144"!A=71H96YT:6-A=&EO;BXB*2P@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W5S97)S
M6R1U<V5R261=*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O
M<BA!551(7U)%05-/3E]"041,3T=)3BD["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"@H@("`@("`@("1H87-H(#T@)'1H:7,M/F=E=$-R
M>7!T961087-S=V]R9"@D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTL("1T:&ES
M+3Y?=7-E<G-;)'5S97))9%TL("1T:&ES+3Y?<&%R86US6R=E;F-R>7!T:6]N
M)UTL("%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG<VAO=U]E;F-R>7!T:6]N)UTI
M*3L*("`@("`@("!I9B`H)&AA<V@@/3T@)'1H:7,M/E]U<V5R<ULD=7-E<DED
M72D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/
M3E]"041,3T=)3BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(%5222!O9B!T
M:&4@;&]G:6X@<V-R965N(&9O<B!T:&ES(&%U=&AE;G1I8V%T:6]N(&]B:F5C
M="X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1A<'`@(%1H92!A<'!L:6-A=&EO;B!T;R!U<V4N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<FP@(%1H92!54DP@=&\@<F5D:7)E
M8W0@=&\@869T97(@;&]G:6XN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!L;V=I;B!S8W)E96X@55))+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?9V5T3&]G:6Y38W)E96XH)&%P<"`]("=H;W)D92<L("1U<FP@/2`G)RD*
M("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=L;V=I
M;E-C<F5E;B==*2D@>PH@("`@("`@("`@("!I9B`H)'5R;"D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N(%5T:6PZ.F%D9%!A<F%M971E<B@D=&AI<RT^7W!A
M<F%M<ULG;&]G:6Y38W)E96XG72P@)W5R;"<L("1U<FPI.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%R
M86US6R=L;V=I;E-C<F5E;B==.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N('!A<F5N=#HZ7V=E=$QO9VEN4V-R
M965N*"1A<'`L("1U<FPI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($QI<W0@86QL('5S97)S(&EN('1H92!S>7-T96TN"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5&AE(&%R<F%Y(&]F('5S97))9',L(&]R(&$@
M4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@;&ES=%5S97)S*"D*("`@('L*("`@("`@("!R971U<FX@87)R87E?
M:V5Y<R@D=&AI<RT^7W5S97)S*3L*("`@('T*"B`@("`O*BH*("`@("`J($%U
M=&]M871I8R!A=71H96YT:6-A=&EO;CH@1FEN9"!O=70@:68@=&AE(&-L:65N
M="!H87,@2%144`H@("`@("H@875T:&5N=&EC871I;VX@:6YF;R!P<F5S96YT
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N
M;W0@=&AE(&-L:65N="!I<R!A;&QO=V5D+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!T<F%N<W!A<F5N="@I"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D7U-%
M4E9%4ELG4$A07T%55$A?55-%4B==*2`F)@H@("`@("`@("`@("`A96UP='DH
M)%]315)615);)U!(4%]!551(7U!7)UTI*2!["B`@("`@("`@("`@("1T:&ES
M+3YS971!=71H*%5T:6PZ.F1I<W!E;$UA9VEC475O=&5S*"1?4T525D526R=0
M2%!?05542%]54T52)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G<&%S<W=O<F0G(#T^(%5T:6PZ.F1I<W!E;$UA9VEC475O=&5S*"1?
M4T525D526R=02%!?05542%]05R==*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W1R86YS<&%R96YT)R`]/B`Q*2D["B`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]S971!
M=71H17)R;W(H05542%]214%33TY?34534T%'12P@7R@B2%144"!!=71H96YT
M:6-A=&EO;B!N;W0@9F]U;F0N(BDI.PH@("`@("`@(')E='5R;B!F86QS93L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]I;6%P
M+G!H<```````````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$S,3$P
M`#$P-3$U-#,S-S4Q`#`R,C`Q-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@5&AE($%U=&A?:6UA<#HZ
M(&-L87-S('!R;W9I9&5S(&%N($E-05`@:6UP;&5M96YT871I;VX@;V8@=&AE
M($AO<F1E"B`J(&%U=&AE;G1I8V%T:6]N('-Y<W1E;2X*("H*("H@3W!T:6]N
M86P@<&%R86UE=&5R<SH\<')E/@H@*B`@)VAO<W1S<&5C)R`@("`@("`@5&AE
M(&AO<W1N86UE(&]R($E0(&%D9')E<W,@;V8@=&AE('-E<G9E<BX*("H@("`@
M("`@("`@("`@("`@("`@($1%1D%53%0Z("=L;V-A;&AO<W0G"B`J("`G<&]R
M="<@("`@("`@("`@("!4:&4@<V5R=F5R('!O<G0@=&\@=VAI8V@@=V4@=VEL
M;"!C;VYN96-T+@H@*B`@("`@("`@("`@("`@("`@("`@24U!4"!I<R!G96YE
M<F%L;'D@,30S+"!W:&EL92!)34%0+5-33"!I<R!G96YE<F%L;'D@.3DS+@H@
M*B`@("`@("`@("`@("`@("`@("`@1$5&055,5#H@,30S"B`J("`G<')O=&]C
M;VPG("`@("`@("!4:&4@8V]N;F5C=&EO;B!P<F]T;V-O;"`H92YG+B`G:6UA
M<"<L("=P;W`S)RP@)VYN='`G*2X*("H@("`@("`@("`@("`@("`@("`@(%!R
M;W1O8V]L(&ES(&]N92!O9B`G:6UA<"]N;W1L<R<@*&]R(&]N;'D@)VEM87`G
M(&EF('EO=0H@*B`@("`@("`@("`@("`@("`@("`@:&%V92!A(&,M8VQI96YT
M('9E<G-I;VX@,C`P,&,@;W(@;VQD97(I+"`G:6UA<"]S<VPG+`H@*B`@("`@
M("`@("`@("`@("`@("`@;W(@)VEM87`O<W-L+VYO=F%L:61A=&4M8V5R="<@
M*&9O<B!A('-E;&8M<VEG;F5D"B`J("`@("`@("`@("`@("`@("`@("!C97)T
M:69I8V%T92DN"B`J("`@("`@("`@("`@("`@("`@("!$149!54Q4.B`G:6UA
M<"<*("H@("=A9&UI;E]U<V5R)R`@("`@(%1H92!N86UE(&]F(&$@=7-E<B!W
M:71H(&%D;6EN('!R:79I;&5G97,N"B`J("`@("`@("`@("`@("`@("`@("!$
M149!54Q4.B!N=6QL"B`J("`G861M:6Y?<&%S<W=O<F0G("!4:&4@<&%S<W=O
M<F0@;V8@=&AE(&%D;6EN<W1R871O<BX*("H@("`@("`@("`@("`@("`@("`@
M($1%1D%53%0Z(&YU;&P*("H@("=U<V5R:&EE<F%R8VAY)R`@(%1H92!H:65R
M87)C:'D@=VAE<F4@=7-E<B!M86EL8F]X97,@87)E('-T;W)E9"X*("H@("`@
M("`@("`@("`@("`@("`@($1%1D%53%0Z("=U<V5R+B<*("H@("=D<VXG("`@
M("`@("`@("`@(%1H92!F=6QL($E-05`@8V]N;F5C=&EO;B!S=')I;F<N"B`J
M("`@("`@("`@("`@("`@("`@("!)9B!N;W0@<')E<V5N="P@=&AI<R!I<R!B
M=6EL="!F<F]M("=H;W-T<W!E8R<L("=P;W)T)PH@*B`@("`@("`@("`@("`@
M("`@("`@86YD("=P<F]T;V-O;"<@<&%R86UE=&5R<RX\+W!R93X*("H*("H*
M("H@268@<V5T=&EN9R!U<"!A<R!(;W)D92!A=71H(&AA;F1L97(@:6X@8V]N
M9BYP:'`L('1H:7,@:7,@82!S86UP;&4@96YT<GDZ/'!R93X*("H@("`D8V]N
M9ELG875T:"==6R=P87)A;7,G75LG:&]S='-P96,G72`]("=I;6%P+F5X86UP
M;&4N8V]M)SL*("H@("`D8V]N9ELG875T:"==6R=P87)A;7,G75LG<&]R="==
M(#T@,30S.PH@*B`@("1C;VYF6R=A=71H)UU;)W!A<F%M<R==6R=P<F]T;V-O
M;"==(#T@)VEM87`O;F]T;',O;F]V86QI9&%T92UC97)T)SL\+W!R93X*("H*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP+'8@
M,2XR."XQ,"XY(#(P,#8O,#4O,S$@,3DZ,SDZ-#@@<VQU<V%R>B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($=A=61E;GH@
M4W1E:6YL:6X@/&=A=61E;GHN<W1E:6YL:6Y`:60N=6YI8F4N8V@^"B`J($-O
M<'ER:6=H="`R,#`T+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!'875D96YZ(%-T96EN
M;&EN(#QG875D96YZ+G-T96EN;&EN0&ED+G5N:6)E+F-H/@H@*B!`875T:&]R
M("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(
M;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@075T
M:%]I;6%P(&5X=&5N9',@075T:"!["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U
M8W1S(&$@;F5W($E-05`@875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN
M9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M($%U=&A?:6UA<"@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I
M9B`H(55T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G:6UA<"<I*2!["B`@("`@("`@
M("`@($AO<F1E.CIF871A;"A?*")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@
M97AT96YS:6]N(&YO="!F;W5N9"XB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("!]"@H@("`@("`@("1D969A=6QT7W!A<F%M<R`](&%R<F%Y*`H@
M("`@("`@("`@("`G:&]S='-P96,G(#T^("=L;V-A;&AO<W0G+`H@("`@("`@
M("`@("`G<&]R="<@/3X@)S$T,R<L"B`@("`@("`@("`@("=P<F]T;V-O;"<@
M/3X@)VEM87`G+`H@("`@("`@("`@("`G=7-E<FAI97)A<F-H>2<@/3X@)W5S
M97(N)PH@("`@("`@("D["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2!A<G)A
M>5]M97)G92@D9&5F875L=%]P87)A;7,L("1P87)A;7,I.PH*("`@("`@("!I
M9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=A9&UI;E]U<V5R)UTI*2!["B`@
M("`@("`@("`@("1T:&ES+3YC87!A8FEL:71I97-;)V%D9"==(#T@=')U93L*
M("`@("`@("`@("`@)'1H:7,M/F-A<&%B:6QI=&EE<ULG<F5M;W9E)UT@/2!T
M<G5E.PH@("`@("`@("`@("`D=&AI<RT^8V%P86)I;&ET:65S6R=L:7-T)UT@
M/2!T<G5E.PH@("`@("`@('T*"B`@("`@("`@+RH@0W)E871E($133B!S=')I
M;F<N("HO"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG9'-N
M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=D<VXG72`]('-P
M<FEN=&8H)WLE<SHE9"\E<WTG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=P;W)T)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!R;W1O
M8V]L)UTI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($9I;F0@
M;W5T(&EF(&$@<V5T(&]F(&QO9VEN(&-R961E;G1I86QS(&%R92!V86QI9"X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1U<V5R260@("`@("!4:&4@=7-E<DED('1O(&-H96-K
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@06X@87)R87D@
M;V8@;&]G:6X@8W)E9&5N=&EA;',N($9O<B!)34%0+`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&AI<R!M=7-T(&-O;G1A:6X@82!P87-S
M=V]R9"!E;G1R>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H
M971H97(@;W(@;F]T('1H92!C<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]A=71H96YT:6-A=&4H)'5S97))9"P@)&-R961E
M;G1I86QS*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D8W)E9&5N=&EA;'-;
M)W!A<W-W;W)D)UTI*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"A?*").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB
M*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1I
M;6%P(#T@0&EM87!?;W!E;B@D=&AI<RT^7W!A<F%M<ULG9'-N)UTL("1U<V5R
M260L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1C<F5D96YT:6%L<ULG
M<&%S<W=O<F0G72P@3U!?2$%,1D]014XI.PH*("`@("`@("!I9B`H)&EM87`I
M('L*("`@("`@("`@("`@0&EM87!?8VQO<V4H)&EM87`I.PH@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]"041,3T=)3BD["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!9&0@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N
M=&EA;',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@
M("`@(%1H92!U<V5R260@=&\@861D+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D
M8W)E9&5N=&EA;',@(%1H92!C<F5D96YT:6%L<R!T;R!U<V4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!
M4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@861D57-E<B@D=7-E<DED+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@
M("`@<F5Q=6ER95]O;F-E("=(;W)D92])34%0+T%D;6EN+G!H<"<["B`@("`@
M("`@)&EM87`@/2`F;F5W($E-05!?061M:6XH)'1H:7,M/E]P87)A;7,I.PH@
M("`@("`@(')E='5R;B`D:6UA<"T^861D36%I;&)O>"A3=')I;F<Z.F-O;G9E
M<G1#:&%R<V5T*"1U<V5R260L($Y,4SHZ9V5T0VAA<G-E="@I+"`G=71F-RUI
M;6%P)RDI.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E(&$@<V5T(&]F
M(&%U=&AE;G1I8V%T:6]N(&-R961E;G1I86QS+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'5S97))9"`@5&AE('5S97))9"!T;R!D96QE=&4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R
M(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5M;W9E57-E<B@D=7-E<DED*0H@("`@>PH@("`@("`@(')E
M<75I<F5?;VYC92`G2&]R9&4O24U!4"]!9&UI;BYP:'`G.PH@("`@("`@("1I
M;6%P(#T@)FYE=R!)34%07T%D;6EN*"1T:&ES+3Y?<&%R86US*3L*("`@("`@
M("`D<F5S=6QT(#T@)&EM87`M/G)E;6]V94UA:6QB;W@H4W1R:6YG.CIC;VYV
M97)T0VAA<G-E="@D=7-E<DED+"!.3%,Z.F=E=$-H87)S970H*2P@)W5T9C<M
M:6UA<"<I*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)'1H:7,M/G)E;6]V955S97)$871A*"1U<V5R260I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@3&ES="!A;&P@=7-E<G,@:6X@=&AE
M('-Y<W1E;2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@87)R
M87D@;V8@=7-E<DED<RP@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T57-E<G,H*0H@("`@>PH@
M("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O24U!4"]!9&UI;BYP:'`G.PH@
M("`@("`@("1I;6%P(#T@)FYE=R!)34%07T%D;6EN*"1T:&ES+3Y?<&%R86US
M*3L*("`@("`@("!R971U<FX@)&EM87`M/FQI<W1-86EL8F]X97,H*3L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+VEM<W`N<&AP
M````````````````````````````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4T-38`,3`U
M,34T,S,W-3$`,#(R,#4W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B!4:&4@075T:%]I;7-P(&-L87-S
M('!R;W9I9&5S(&)A<VEC(&%U=&AE;G1I8V%T:6]N(&%G86EN<W0@86X@24U3
M4"!S97)V97(N"B`J(%1H:7,@=VEL;"!B92!M;W-T(&)E;FEF:6-I86P@:68@
M86QR96%D>2!U<VEN9R!A;B!)35-0(&)A<V5D('!R969E<F5N8V4*("H@<WES
M=&5M(&]R($E-4U`@8F%S960@861D<F5S<V)O;VL@<WES=&5M"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+T%U=&@O075T:"]I;7-P+G!H<"QV(#$N,BXQ,"XQ
M,"`R,#`V+S`Q+S`Q(#(Q.C(X.C`W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P-"TR,#`V($UI8VAA96P@4G5B:6YS:WD@/&UR=6)I;G-K0&AO<F1E
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4G5B
M:6YS:WD@/&UR=6)I;G-K0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@2&]R9&5?
M075T:`H@*B\*8VQA<W,@075T:%]I;7-P(&5X=&5N9',@075T:'L*"B`@("`O
M*BH*("`@("`J($%N(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T
M:&4@9')I=F5R(&-A;B!R97!O<G0@=VAI8V@*("`@("`J(&]P97)A=&EO;G,@
M:70@<W5P<&]R=',@86YD('=H:6-H(&ET(&1O97-N)W0N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&-A<&%B:6QI=&EE<R`]
M(&%R<F%Y*"=A9&0G("`@("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W5P9&%T92<@("`@("`@(#T^(&9A;'-E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5S971P87-S=V]R9"<@
M/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R96UO
M=F4G("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VQI<W0G("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=')A;G-P87)E;G0G("`@/3X@9F%L<V4I.PH@
M("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<B!F=6YC=&EO;BX@0W)E871E<R!N
M97<@075T:%]I;7-P(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R!!(&AA<V@@8V]N=&%I;FEN9R!P87)A;65T97)S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!!=71H7VEM<W`H)'!A<F%M<R`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@)'1H:7,M/E]S971087)A;7,H)'!A<F%M<RD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!0<FEV871E(&%U=&AE;G1I8V%T:6]N(&9U
M;F-T:6]N+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'5S97))1"!5<V5R;F%M92!F;W(@24U3
M4"!S97)V97(N"B`@("`@*B!`<&%R86T@87)R87D@)&-R961E;G1I86QS($AA
M<V@@8V]N=&%I;FEN9R`G<&%S<W=O<F0G(&5L96UE;G0N"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N(%1R=64@;VX@<W5C8V5S<R`O($9A;'-E(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A=71H96YT:6-A=&4H
M)'5S97))1"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@(')E<75I<F5?
M;VYC92`G3F5T+TE-4U`O075T:"YP:'`G.PH*("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG=7-E<FYA;64G72`]("1U<V5R240["B`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W!A<W-W;W)D)UT@/2`D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UT[
M"B`@("`@("`@)&EM<W`@/2`F3F5T7TE-4U!?075T:#HZ<VEN9VQE=&]N*"1T
M:&ES+3Y?<&%R86US6R=A=71H7VUE=&AO9"==*3L*"B`@("`@("`@:68@*&ES
M7V$H)&EM<W`L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1I;7-P.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]("1I;7-P+3YA
M=71H96YT:6-A=&4H)'1H:7,M/E]P87)A;7,L(&9A;'-E*3L*("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7T)!1$Q/1TE.*3L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($-H96-K<R!T:&4@<&%R86US(&%R<F%Y(&%N9"!S971S(&1E
M9F%U;'0@=F%L=65S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@2&%S:"!C;VYT86EN:6YG($E-
M4U`@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E=%!A<F%M
M<R@D<&%R86US*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%R86US6R=S97)V
M97(G72`]("1P87)A;7-;)W-E<G9E<B==.PH@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=P;W)T)UT@/2`D<&%R86US6R=P;W)T)UT["B`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)V%U=&A?;65T:&]D)UT@/2`D<&%R86US6R=A=71H7VUE=&AO
M9"==.PH*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG875T:%]M96-H86YI
M<VTG72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V%U=&A?;65C
M:&%N:7-M)UT@/2`D<&%R86US6R=A=71H7VUE8VAA;FES;2==.PH@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG<V]C:V5T)UT@/2`D<&%R86US6R=S;V-K
M970G73L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V-O;6UA;F0G72`]
M("1P87)A;7-;)V-O;6UA;F0G73L*("`@("`@("!]"B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+T%U=&@O:7!B87-I8RYP:'``````````````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C<R-@`Q,#4Q-30S,S<U,0`P,C(U,C(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%1H92!!=71H7VEP8F%S:6,@8VQA<W,@<')O=FED97,@86-C
M97-S(&-O;G1R;VP@8F%S960@;VX@0TE$4B!M87-K<PH@*B`H8VQI96YT($E0
M(&%D9')E<W-E<RDN($ET(&ES(&YO="!M96%N="!F;W(@=7-E<BUB87-E9"!S
M>7-T96US+"!B=70*("H@9F]R('1I;65S('=H96X@>6]U('=A;G0@82!B;&]C
M:R!O9B!)4',@=&\@8F4@86)L92!T;R!A8V-E<W,@82!S:71E+`H@*B!A;F0@
M=&AA="!A8V-E<W,@:7,@<VEM<&QY(&]N+V]F9B`M(&YO('!R969E<F5N8V5S
M+"!E=&,N($EF('EO=2!N965D"B`J(&UO<F4@<V]P:&ES=&EC871E9"!)4"UB
M87-E9"!A=71H96YT:6-A=&EO;BP@>6]U('-H;W5L9"!L;V]K(&%T('1H90H@
M*B!!=71H7VEP;6%P(&-L87-S('=H:6-H(&QE=',@>6]U(&UA<"!)4"!B;&]C
M:W,@=&\@<W!E8VEF:6,*("H@=7-E<FYA;65S+@H@*@H@*B!087)A;65T97)S
M.@H@*B`@("=B;&]C:W,G("`@("!!;B!A<G)A>2!O9B!#2412(&UA<VMS('=H
M:6-H(&%R92!A;&QO=V5D(&%C8V5S<RX*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO075T:"]!=71H+VEP8F%S:6,N<&AP+'8@,2XR,"XQ,"XW(#(P,#8O,#$O
M,#$@,C$Z,C@Z,#<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P
M,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO
M<F1E7T%U=&@*("HO"F-L87-S($%U=&A?:7!B87-I8R!E>'1E;F1S($%U=&@@
M>PH*("`@("\J*@H@("`@("H@06X@87)R87D@;V8@8V%P86)I;&ET:65S+"!S
M;R!T:&%T('1H92!D<FEV97(@8V%N(')E<&]R="!W:&EC:`H@("`@("H@;W!E
M<F%T:6]N<R!I="!S=7!P;W)T<R!A;F0@=VAI8V@@:70@9&]E<VXG="X*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D8V%P86)I
M;&ET:65S(#T@87)R87DH)V%D9"<@("`@("`@("`@(#T^(&9A;'-E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=7!D871E)R`@("`@("`@/3X@
M9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97-E='!A
M<W-W;W)D)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W)E;6]V92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G;&ES="<@("`@("`@("`@/3X@9F%L<V4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=T<F%N<W!A<F5N="<@("`]/B!T
M<G5E*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@0F%S:6,@
M25`@875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!P87)A;65T97)S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H7VEP8F%S:6,H)'!A<F%M<R`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]S971087)A;7,H)'!A
M<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@<&%R86UE=&5R<R!F
M;W(@=&AE($%U=&A?:7!B87-I8R!O8FIE8W0N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@(%-H;W5L9"!C;VYT86EN("=B;&]C:W,G+"!A;B!A<G)A>2!O9B!#2412
M(&UA<VMS+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5T4&%R86US*"1P87)A
M;7,I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1P87)A;7-;)V)L;V-K<R==
M*2D@>PH@("`@("`@("`@("`D<&%R86US6R=B;&]C:W,G72`](&%R<F%Y*"D[
M"B`@("`@("`@?2!E;'-E:68@*"%I<U]A<G)A>2@D<&%R86US6R=B;&]C:W,G
M72DI('L*("`@("`@("`@("`@)'!A<F%M<ULG8FQO8VMS)UT@/2!A<G)A>2@D
M<&%R86US6R=B;&]C:W,G72D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^
M7W!A<F%M<R`]("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!=71O
M;6%T:6,@875T:&5N=&EC871I;VXZ($9I;F0@;W5T(&EF('1H92!C;&EE;G0@
M;6%T8VAE<R!A;B!A;&QO=V5D($E0"B`@("`@*B!B;&]C:RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H92!C;&EE
M;G0@:7,@86QL;W=E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@=')A;G-P87)E
M;G0H*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)%]315)615);)U)%34]4
M15]!1$12)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R
M*$%55$A?4D5!4T].7TU%4U-!1T4L(%\H(DE0($%D9')E<W,@;F]T(&%V86EL
M86)L92XB*2D["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"@H@("`@("`@("1C;&EE;G0@/2`D7U-%4E9%4ELG4D5-3U1%7T%$1%(G73L*
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!A<F%M<ULG8FQO8VMS)UT@87,@
M)&-I9'(I('L*("`@("`@("`@("`@:68@*"1T:&ES+3Y?861D<F5S<U=I=&AI
M;D-)1%(H)&-L:65N="P@)&-I9'(I*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T075T:"@D8VED<BP@87)R87DH)W1R86YS<&%R96YT)R`]/B`Q*2D[
M"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]2
M14%33TY?34534T%'12P@7R@B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W
M960@0TE$4B!B;&]C:RXB*2D["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE(&EF(&%N($E0(&%D9')E<W,@
M:7,@=VET:&EN(&$@0TE$4B!B;&]C:RX*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A9&1R97-S
M("!4:&4@25`@861D<F5S<R!T;R!C:&5C:RX*("`@("`J($!P87)A;2!S=')I
M;F<@)&-I9'(@("`@(%1H92!B;&]C:R`H92YG+B`Q.3(N,38X+C`N,"\Q-BD@
M=&\@=&5S="!A9V%I;G-T+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&%D9')E<W,@;6%T8VAE<R!T:&4@;6%S
M:RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V%D9')E<W-7:71H:6Y#2412*"1A
M9&1R97-S+"`D8VED<BD*("`@('L*("`@("`@("`D861D<F5S<R`](&EP,FQO
M;F<H)&%D9')E<W,I.PH@("`@("`@(&QI<W0H)'%U860L("1B:71S*2`](&5X
M<&QO9&4H)R\G+"`D8VED<BD["B`@("`@("`@)&)I=',@/2!I;G1V86PH)&)I
M=',I.PH@("`@("`@("1Q=6%D(#T@:7`R;&]N9R@D<75A9"D["@H@("`@("`@
M(')E='5R;B`H*"1A9&1R97-S(#X^("@S,B`M("1B:71S*2D@/3T@*"1Q=6%D
M(#X^("@S,B`M("1B:71S*2DI.PH@("`@?0H*?0H`````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]!=71H+VEP;6%P+G!H<```````````````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(T-30`,3`U,34T,S,W-3$`,#(R,C$P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@IR97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+VEP8F%S
M:6,N<&AP)SL*"B\J*@H@*B!4:&4@075T:%]I<&UA<"!C;&%S<R!P<F]V:61E
M<R!A8V-E<W,@8V]N=')O;"!B87-E9"!O;B!#2412(&UA<VMS+@H@*@H@*B!0
M87)A;65T97)S.@H@*B`@($Y/3D4*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M075T:"]!=71H+VEP;6%P+G!H<"QV(#$N,30N,3`N-B`R,#`V+S`Q+S`Q(#(Q
M.C(X.C`W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]!
M=71H"B`J+PIC;&%S<R!!=71H7VEP;6%P(&5X=&5N9',@075T:%]I<&)A<VEC
M('L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@
M<V\@=&AA="!T:&4@9')I=F5R(&-A;B!R97!O<G0@=VAI8V@*("`@("`J(&]P
M97)A=&EO;G,@:70@<W5P<&]R=',@86YD('=H:6-H(&ET(&1O97-N)W0N"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&-A<&%B
M:6QI=&EE<R`](&%R<F%Y*"=A9&0G("`@("`@("`@("`]/B!F86QS92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5P9&%T92<@("`@("`@(#T^
M(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5S971P
M87-S=V]R9"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=R96UO=F4G("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VQI<W0G("`@("`@("`@(#T^(&9A;'-E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=')A;G-P87)E;G0G("`@/3X@
M=')U92D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W($E0+6UA
M<'!I;F<@875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!P87)A;65T
M97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H7VEP;6%P*"1P87)A;7,@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V5T4&%R86US*"1P
M87)A;7,I.PH@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O
M:V]L86(N<&AP````````````````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-S$P,P`Q,#4Q-30S,S<U,0`P,C(Q-C8`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R
M9&4O075T:"]I;6%P+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O2&ES=&]R
M>2YP:'`G.PH*+RHJ"B`J($MO;&%B(&EM<&QE;65N=&%T:6]N(&]F('1H92!(
M;W)D92!A=71H96YT:6-A=&EO;B!S>7-T96TN($1E<FEV97,@9G)O;2!T:&4*
M("H@075T:%]I;6%P($E-05`@875T:&5N=&EC871I;VX@;V)J96-T+"!A;F0@
M<VEM<&QY('!R;W9I9&5S('!A<F%M971E<G,@=&\@:70*("H@8F%S960@;VX@
M=&AE(&=L;V)A;"!+;VQA8B!C;VYF:6=U<F%T:6]N+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:V]L86(N<&AP+'8@,2XQ+C$P+C@@,C`P
M-B\P,R\P,R`R,SHP,#HR."!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P-"TR,#`V(%-T=6%R="!":6YG92`\<RYB:6YG94!C;V1E9G5S:6]N+F-O
M+GIA/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@4W1U87)T($)I;F=E
M(#QS+F)I;F=E0&-O9&5F=7-I;VXN8V\N>F$^"B`J($!S:6YC92`@($AO<F1E
M(#$N,PH@*B!`<&%C:V%G92!(;W)D95]!=71H"B`J+PIC;&%S<R!!=71H7VMO
M;&%B(&5X=&5N9',@075T:%]I;6%P('L*"B`@("`O*BH*("`@("`J($-O;G-T
M<G5C=',@82!N97<@2V]L86(@875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I
M;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N($%U=&A?:V]L86(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@)'!A<F%M<ULG:&]S='-P96,G72`]("1'3$]"04Q36R=C;VYF)UU;)VMO
M;&%B)UU;)VEM87`G75LG<V5R=F5R)UT["B`@("`@("`@)'!A<F%M<ULG<&]R
M="==(#T@)$=,3T)!3%-;)V-O;F8G75LG:V]L86(G75LG:6UA<"==6R=P;W)T
M)UT["B`@("`@("`@)'!A<F%M<ULG<')O=&]C;VPG72`]("=I;6%P+VYO=&QS
M+VYO=F%L:61A=&4M8V5R="<["@H@("`@("`@('!A<F5N=#HZ075T:%]I;6%P
M*"1P87)A;7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEN9"!O=70@:68@
M82!S970@;V8@;&]G:6X@8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'5S97))9"`@("`@(%1H92!U<V5R260@=&\@8VAE8VLN"B`@("`@
M*B!`<&%R86T@87)R87D@)&-R961E;G1I86QS("!!;B!A<G)A>2!O9B!L;V=I
M;B!C<F5D96YT:6%L<RX@1F]R($MO;&%B+`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=&AI<R!M=7-T(&-O;G1A:6X@82!P87-S=V]R9"!E
M;G1R>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@
M;W(@;F]T('1H92!C<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]A=71H96YT:6-A=&4H)'5S97))9"P@)&-R961E;G1I86QS
M*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@)&QO9VEN
M7V]K(#T@<&%R96YT.CI?875T:&5N=&EC871E*"1U<V5R260L("1C<F5D96YT
M:6%L<RD["@H@("`@("`@(&EF("@D8V]N9ELG875T:"==6R=P87)A;7,G75LG
M;&]G:6Y?8FQO8VLG72`A/2`Q*2!["B`@("`@("`@("`@("\O(%)E='5R;B!I
M9B!F96%T=7)E(&ES(&1I<V%B;&5D+@H@("`@("`@("`@("!R971U<FX@)&QO
M9VEN7V]K.PH@("`@("`@('T*"B`@("`@("`@)&AI<W1O<GD@/2`F2&]R9&5?
M2&ES=&]R>3HZ<VEN9VQE=&]N*"D["@H@("`@("`@("1H:7-T;W)Y7VED96YT
M:69I97(@/2`B)'5S97))9$!L;V=I;G,N:V]L86(B.PH@("`@("`@("1H:7-T
M;W)Y7VQO9R`]("1H:7-T;W)Y+3YG971(:7-T;W)Y*"1H:7-T;W)Y7VED96YT
M:69I97(I.PH@("`@("`@("1H:7-T;W)Y7VQI<W0@/2!A<G)A>2@I.PH*("`@
M("`@("`O+R!%>'1R86-T(&AI<W1O<GD@;&ES="!F<F]M(&QO9RX*("`@("`@
M("!I9B`H)&AI<W1O<GE?;&]G("8F("%I<U]A*"1H:7-T;W)Y7VQO9RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D9&%T82`]("1H:7-T;W)Y7VQO
M9RT^9V5T1&%T82@I.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1D871A*2D@
M>PH@("`@("`@("`@("`@("`@)&5N=')Y(#T@87)R87E?<VAI9G0H)&1A=&$I
M.PH@("`@("`@("`@("`@("`@)&AI<W1O<GE?;&ES="`]("1E;G1R>5LG:&ES
M=&]R>5]L:7-T)UT["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("\O($-A;&-U;&%T92!T:&4@=&EM92!R86YG92X*("`@("`@("`D<W1A<G1?
M=&EM92`]("AT:6UE*"D@+2`D8V]N9ELG875T:"==6R=P87)A;7,G75LG;&]G
M:6Y?8FQO8VM?=&EM92==("H@-C`I.PH*("`@("`@("`D;F5W7VAI<W1O<GE?
M;&ES="`](&%R<F%Y*"D["B`@("`@("`@)&-O=6YT(#T@,#L*"B`@("`@("`@
M+R\@0V]P>2!A;F0@8V]U;G0@86QL(')E;&5V86YT('1I;65S=&%M<',N"B`@
M("`@("`@9F]R96%C:"`H)&AI<W1O<GE?;&ES="!A<R`D96YT<GDI('L*("`@
M("`@("`@("`@)'1I;65S=&%M<"`]("1E;G1R>5L@)W1I;65S=&%M<"<@73L*
M"B`@("`@("`@("`@(&EF("@D=&EM97-T86UP(#X@)'-T87)T7W1I;64I('L*
M("`@("`@("`@("`@("`@("1N97=?:&ES=&]R>5]L:7-T6UT@/2`D96YT<GD[
M"B`@("`@("`@("`@("`@("`D8V]U;G0K*SL*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@)&UA>%]C;W5N="`]("1C;VYF6R=A=71H)UU;)W!A
M<F%M<R==6R=L;V=I;E]B;&]C:U]C;W5N="==.PH*("`@("`@("!I9B`H)&-O
M=6YT(#X@)&UA>%]C;W5N="!\?"`A)&QO9VEN7V]K*2!["B`@("`@("`@("`@
M("\O($%D9"!E;G1R>2!F;W(@8W5R<F5N="!F86EL960@;&]G:6XN"B`@("`@
M("`@("`@("1E;G1R>2`](&%R<F%Y*"D["B`@("`@("`@("`@("1E;G1R>5L@
M)W1I;65S=&%M<"<@72`]('1I;64H*3L*("`@("`@("`@("`@)&YE=U]H:7-T
M;W)Y7VQI<W1;72`]("1E;G1R>3L*"B`@("`@("`@("`@("\O(%=R:71E(&)A
M8VL@:&ES=&]R>2X*("`@("`@("`@("`@)&AI<W1O<GDM/FQO9R@D:&ES=&]R
M>5]I9&5N=&EF:65R+"!A<G)A>2@G86-T:6]N)R`]/B`G861D)RP@)W=H;R<@
M/3X@)'5S97))9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G:&ES=&]R>5]L:7-T)R`]/B`D;F5W7VAI
M<W1O<GE?;&ES="DL('1R=64I.PH*("`@("`@("`@("`@:68@*"1C;W5N="`^
M("1M87A?8V]U;G0I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T075T
M:$5R<F]R*$%55$A?4D5!4T].7TU%4U-!1T4L(%\H(E1O;R!M86YY(&EN=F%L
M:60@;&]G:6YS(&1U<FEN9R!T:&4@;&%S="!M:6YU=&5S+B(I*3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T075T
M:$5R<F]R*$%55$A?4D5!4T].7T)!1$Q/1TE.*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1L;V=I;E]O:SL*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'``````````````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P-3<R-P`Q,#4Q-30S,S<U,0`P,C$W-3,`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J(%1H92!!=71H7VMR8C4@8VQA<W,@<')O=FED97,@86X@:V5R8F5R
M;W,@:6UP;&5M96YT871I;VX@;V8@=&AE($AO<F1E"B`J(&%U=&AE;G1I8V%T
M:6]N('-Y<W1E;2X*("H*("H@5&AI<R!D<FEV97(@<F5Q=6ER97,@=&AE("=K
M<F(U)R!02%`@97AT96YS:6]N('1O(&)E(&QO861E9"X*("H@5&AE(&UO9'5L
M92!C86X@8F4@9&]W;FQO861E9"!H97)E.@H@*B`@(&AT='`Z+R]W=W<N:&]R
M9&4N;W)G+V1O=VYL;V%D+W!H<"]P:'!K<F(U+G1A<BYG>@H@*@H@*B!297%U
M:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@3F]N92X\+W!R93X*("H*("H@
M26YS=&5A9"P@2V5R8F5R;W,@;75S="!B92!C;W)R96-T;'D@8V]N9FEG=7)E
M9"!O;B!Y;W5R('-Y<W1E;2`H92YG+@H@*B`@("]E=&,O:W)B-2YC;VYF*2!F
M;W(@=&AI<R!C;&%S<R!T;R!W;W)K(&-O<G)E8W1L>2X*("H*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP+'8@,2XR,2XQ,"XX
M(#(P,#8O,#$O,#$@,C$Z,C@Z,#<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN
M8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC
M:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@
M*B!`<VEN8V4@("!(;W)D92`R+C(*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@
M*B\*8VQA<W,@075T:%]K<F(U(&5X=&5N9',@075T:"!["@H@("`@+RHJ"B`@
M("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL:71I97,L('-O('1H870@=&AE(&1R
M:79E<B!C86X@<F5P;W)T('=H:6-H"B`@("`@*B!O<&5R871I;VYS(&ET('-U
M<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S;B=T+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1C87!A8FEL:71I97,@/2!A<G)A
M>2@G861D)R`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=U<&1A=&4G("`@("`@("`]/B!F86QS92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W)E<V5T<&%S<W=O<F0G(#T^(&9A
M;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5M;W9E)R`@
M("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=L:7-T)R`@("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W1R86YS<&%R96YT)R`@(#T^(&9A;'-E*3L*"B`@("`O
M*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@2V5R8F5R;W,@875T:&5N=&EC
M871I;VX@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N($%U=&A?:W)B-2@D<&%R86US(#T@87)R
M87DH*2D*("`@('L*("`@("`@("!I9B`H(55T:6PZ.F5X=&5N<VEO;D5X:7-T
M<R@G:W)B-2<I*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"A?*")!=71H
M7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB*2P@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3Y?<&%R86US(#T@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J($9I
M;F0@;W5T(&EF(&$@<V5T(&]F(&QO9VEN(&-R961E;G1I86QS(&%R92!V86QI
M9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@("!4:&4@=7-E<DED('1O(&-H
M96-K+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@06X@87)R
M87D@;V8@;&]G:6X@8W)E9&5N=&EA;',N"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!&;W(@:V5R8F5R;W,L('1H:7,@;75S="!C;VYT86EN
M(&$@<&%S<W=O<F0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&5N=')Y+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE
M<B!O<B!N;W0@=&AE(&-R961E;G1I86QS(&%R92!V86QI9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V%U=&AE;G1I8V%T92@D=7-E<DED+"`D8W)E9&5N=&EA
M;',I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1C<F5D96YT:6%L<ULG<&%S
M<W=O<F0G72DI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%\H(DYO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB
M*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1R
M97-U;'0@/2!K<F(U7VQO9VEN*"1U<V5R260L("1C<F5D96YT:6%L<ULG<&%S
M<W=O<F0G72D["@H@("`@("`@(&EF("@D<F5S=6QT(#T]/2!+4D(U7T]+*2![
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(&EF("@D<F5S=6QT(#T]/2!+4D(U7T)!1%]005-35T]21"D@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]2
M14%33TY?34534T%'12P@7R@B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(I*3L*
M("`@("`@("`@("`@?2!E;'-E:68@*"1R97-U;'0@/3T]($M20C5?0D%$7U53
M15(I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%5
M5$A?4D5!4T].7TU%4U-!1T4L(%\H(D)A9"!K97)B97)O<R!U<V5R;F%M92XB
M*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]-15-304=%+"!?*")+97)B
M97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(BDI.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O075T
M:"]L9&%P+G!H<```````````````````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#0W,3$V`#$P-3$U-#,S-S4Q`#`R,C`R-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@5&AE($%U=&A?
M;&1A<"!C;&%S<R!P<F]V:61E<R!A;B!,1$%0(&EM<&QE;65N=&%T:6]N(&]F
M('1H92!(;W)D90H@*B!A=71H96YT:6-A=&EO;B!S>7-T96TN"B`J"B`J(%)E
M<75I<F5D('!A<F%M971E<G,Z/'!R93X*("H@("`G8F%S961N)R`@("`@("!4
M:&4@8F%S92!$3B!F;W(@=&AE($Q$05`@<V5R=F5R+@H@*B`@("=H;W-T<W!E
M8R<@("`@(%1H92!H;W-T;F%M92!O9B!T:&4@3$1!4"!S97)V97(N"B`J("`@
M)W5I9"<@("`@("`@("`@5&AE('5S97)N86UE('-E87)C:"!K97DN"B`J("`@
M)V9I;'1E<B<@("`@("`@5&AE($Q$05`@9F]R;6%T=&5D('-E87)C:"!F:6QT
M97(@=&\@<V5A<F-H(&9O<B!U<V5R<RX@5&AI<PH@*B`@("`@("`@("`@("`@
M("`@('-E='1I;F<@;W9E<G)I9&5S('1H92`G;V)J96-T8VQA<W,G(&UE=&AO
M9"!B96QO=RX*("H@("`G;V)J96-T8VQA<W,G("!4:&4@;V)J96-T8VQA<W,@
M9FEL=&5R('5S960@=&\@<V5A<F-H(&9O<B!U<V5R<RX@0V%N(&)E(&$*("H@
M("`@("`@("`@("`@("`@("!S:6YG;&4@;V)J96-T8VQA<W,@;W(@86X@87)R
M87DN/"]P<F4^"B`J"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@
M("`G8FEN9&1N)R`@("`@("!4:&4@1$X@=7-E9"!T;R!B:6YD('1O('1H92!,
M1$%0('-E<G9E<@H@*B`@("=P87-S=V]R9"<@("`@(%1H92!P87-S=V]R9"!U
M<V5D('1O(&)I;F0@=&\@=&AE($Q$05`@<V5R=F5R"B`J("`@)W9E<G-I;VXG
M("`@("`@5&AE('9E<G-I;VX@;V8@=&AE($Q$05`@<')O=&]C;VP@=&\@=7-E
M+@H@*B`@("`@("`@("`@("`@("`@($1%1D%53%0Z($Y/3D4@*'-Y<W1E;2!D
M969A=6QT('=I;&P@8F4@=7-E9"D\+W!R93X*("H*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP+'8@,2XT-RXQ,"XQ.2`R,#`V
M+S`X+S$T(#`R.C0X.C0X(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q
M.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^
M"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]!=71H
M"B`J+PIC;&%S<R!!=71H7VQD87`@97AT96YD<R!!=71H('L*"B`@("`O*BH*
M("`@("`J($%N(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@
M9')I=F5R(&-A;B!R97!O<G0@=VAI8V@*("`@("`J(&]P97)A=&EO;G,@:70@
M<W5P<&]R=',@86YD('=H:6-H(&ET(&1O97-N)W0N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&-A<&%B:6QI=&EE<R`](&%R
M<F%Y*"=A9&0G("`@("`@("`@("`]/B!T<G5E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G=7!D871E)R`@("`@("`@/3X@=')U92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W)E<V5T<&%S<W=O<F0G(#T^(&9A
M;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5M;W9E)R`@
M("`@("`@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VQI<W0G("`@("`@("`@(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=T<F%N<W!A<F5N="<@("`]/B!F86QS92D["@H@("`@+RHJ
M"B`@("`@*B!,1$%0(&-O;FYE8W1I;VX@:&%N9&QE"B`@("`@*@H@("`@("H@
M0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@)%]D<SL*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=',@82!N97<@3$1!4"!A=71H96YT:6-A=&EO;B!O
M8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@
M:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@075T:%]L9&%P*"1P87)A;7,@/2!A<G)A>2@I*0H@
M("`@>PH@("`@("`@(&EF("@A571I;#HZ97AT96YS:6]N17AI<W1S*"=L9&%P
M)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%\H(D%U=&A?;&1A<#H@
M4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(I+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]S9710
M87)A;7,H)'!A<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@8V]N
M9FEG=7)A=&EO;B!P87)A;65T97)S"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@
M:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W-E=%!A<F%M<R@D<&%R86US*0H@("`@>PH@("`@
M("`@("\J($5N<W5R92!W92=V92!B965N('!R;W9I9&5D('=I=&@@86QL(&]F
M('1H92!N96-E<W-A<GD@<&%R86UE=&5R<RX@*B\*("`@("`@("!(;W)D93HZ
M87-S97)T1')I=F5R0V]N9FEG*"1P87)A;7,L("=A=71H)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=H;W-T<W!E8R<L("=B
M87-E9&XG+"`G=6ED)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G875T:&5N=&EC871I;VX@3$1!4"<I.PH*("`@("`@("`D=&AI<RT^
M7W!A<F%M<R`]("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$;V5S
M(&%N(&QD87`@8V]N;F5C="!A;F0@8FEN9',@87,@=&AE(&=U97-T('5S97(@
M;W(@87,@=&AE(&]P=&EO;F%L(&1N+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O
M<B!&86QS92!B87-E9"!O;B!S=6-C97-S(&]F(&-O;FYE8W0@86YD(&)I;F0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN96-T*"D*("`@('L*("`@("`@
M("`O*B!#;VYN96-T('1O('1H92!,1$%0('-E<G9E<BX@*B\*("`@("`@("`D
M=&AI<RT^7V1S(#T@0&QD87!?8V]N;F5C="@D=&AI<RT^7W!A<F%M<ULG:&]S
M='-P96,G72D["B`@("`@("`@:68@*"$D=&AI<RT^7V1S*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D9A:6QE9"!T;R!C;VYN
M96-T('1O($Q$05`@<V5R=F5R+B(I*3L*("`@("`@("!]"@H@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7W!A<F%M<ULG=F5R<VEO;B==*2D@>PH@("`@("`@
M("`@("!I9B`H(6QD87!?<V5T7V]P=&EO;B@D=&AI<RT^7V1S+"!,1$%07T]0
M5%]04D]43T-/3%]615)324].+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=F5R<VEO;B==*2D@>PH@("`@("`@
M("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G4V5T($Q$05`@
M<')O=&]C;VP@=F5R<VEO;B!T;R`E9"!F86EL960Z(%LE9%T@)7,G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG=F5R<VEO;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!L9&%P7V5R<FYO*"1C;VYN*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;&1A<%]E<G)O<B@D
M8V]N;BDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P87)A;7-;
M)V)I;F1D;B==*2D@>PH@("`@("`@("`@("`D8FEN9"`]($!L9&%P7V)I;F0H
M)'1H:7,M/E]D<RP@)'1H:7,M/E]P87)A;7-;)V)I;F1D;B==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!A<W-W
M;W)D)UTI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1B:6YD(#T@
M0&QD87!?8FEN9"@D=&AI<RT^7V1S*3L*("`@("`@("!]"@H@("`@("`@(&EF
M("@A)&)I;F0I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(BDI.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!&:6YD('1H92!U<V5R(&1N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@
M("`@(%1H92!U<V5R260@=&\@9FEN9"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE('5S97)S(&9U;&P@1$X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V9I;F1$3B@D=7-E<DED*0H@("`@>PH@("`@("`@("\J(%-E87)C:"!F
M;W(@=&AE('5S97(G<R!F=6QL($1.+B`J+PH@("`@("`@("1S96%R8V@@/2!`
M;&1A<%]S96%R8V@H)'1H:7,M/E]D<RP@)'1H:7,M/E]P87)A;7-;)V)A<V5D
M;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W5I9"==("X@)STG("X@)'5S97))9"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"1T:&ES+3Y?<&%R86US6R=U:60G72DI
M.PH@("`@("`@(&EF("@A)'-E87)C:"D@>PH@("`@("`@("`@("!(;W)D93HZ
M;&]G365S<V%G92AL9&%P7V5R<F]R*"1T:&ES+3Y?9',I+"!?7T9)3$5?7RP@
M7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*%\H(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@
M<V5R=F5R+B(I*3L*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2!`;&1A
M<%]G971?96YT<FEE<R@D=&AI<RT^7V1S+"`D<V5A<F-H*3L*("`@("`@("!I
M9B`H:7-?87)R87DH)')E<W5L="D@)B8@*&-O=6YT*"1R97-U;'0I(#X@,2DI
M('L*("`@("`@("`@("`@)&1N(#T@)')E<W5L=%LP75LG9&XG73L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BA?*")%;7!T>2!R97-U;'0N(BDI.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1D;CL*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!F;W(@<VAA
M9&]W3&%S=$-H86YG92!A;F0@<VAA9&]W36EN+TUA>"!S=7!P;W)T(&%N9"!R
M971U<FYS('1H96ER"B`@("`@*B!V86QU97,N("!792!W:6QL(&%L<V\@8VAE
M8VL@9F]R('!W9$QA<W13970@:68@06-T:79E($1I<F5C=&]R>2!I<PH@("`@
M("H@<W5P<&]R="!I<R!R97%U97-T960N("!&;W(@=&AI<R!C:&5C:R!T;R!S
M=6-C965D('=E(&YE960@=&\@8F4@8F]U;F0*("`@("`J('1O('1H92!D:7)E
M8W1O<GD*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1D;B`@("`@5&AE(&1N(&]F('1H92!U<V5R
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@87)R87D@=VET:"!K97ES
M(&)E:6YG(")S:&%D;W=L87-T8VAA;F=E(BP@(G-H861O=VUI;B(*("`@("`J
M("`@("`@("`@("`@("`@(")S:&%D;W=M87@B+"`B<VAA9&]W=V%R;FEN9R(@
M86YD(&-O;G1A:6YI;F<@=&AE:7(*("`@("`J("`@("`@("`@("`@("`@(')E
M<W!E8W1I=F4@=F%L=65S(&]R(&9A;'-E(&9O<B!N;R!S=7!P;W)T+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?;&]O:W5P4VAA9&]W*"1D;BD*("`@('L*("`@
M("`@("`O*B!);FET('1H92!R971U<FX@87)R87DN("HO"B`@("`@("`@)&QO
M;VMU<'-H861O=R`](&%R<F%Y*"=S:&%D;W=L87-T8VAA;F=E)R`]/B!F86QS
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-H861O=VUI;B<@
M/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S:&%D
M;W=M87@G(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<VAA9&]W=V%R;FEN9R<@/3X@9F%L<V4I.PH*"B`@("`@("`@)')E<W5L
M="`]($!L9&%P7W)E860H)'1H:7,M/E]D<RP@)&1N+"`G;V)J96-T0VQA<W,]
M*B<I.PH*("`@("`@("!I9B`H)')E<W5L="D@>PH@("`@("`@("`@("`D:6YF
M;W)M871I;VX@/2!`;&1A<%]G971?96YT<FEE<R@D=&AI<RT^7V1S+"`D<F5S
M=6QT*3L*"B`@("`@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG860G72D@
M>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9O<FUA=&EO;ELP75LG
M<'=D;&%S='-E="==6S!=*2D@>PH@("`@("`@("`@("`@("`@("`@("\J($%C
M=&EV92!$:7)E8W1O<GD@:&%N9&QE<R!T:6UE<W1A;7!S(&$@8FET"B`@("`@
M("`@("`@("`@("`@("`@("H@9&EF9F5R96YT;'DN("!#;VYV97)T('1H92!T
M:6UE<W1A;7`@=&\@82!53DE8"B`@("`@("`@("`@("`@("`@("`@("H@=&EM
M97-T86UP+B`J+PH@("`@("`@("`@("`@("`@("`@("1L;V]K=7!S:&%D;W=;
M)W-H861O=VQA<W1C:&%N9V4G72`](&9L;V]R*"@H)&EN9F]R;6%T:6]N6S!=
M6R=P=V1L87-T<V5T)UU;,%T@+R`Q,#`P,#`P,"D@+2`Q,38T-#0P-C<X,RD@
M+R`X-C0P,"D@+2`Q.PH*("`@("`@("`@("`@("`@("`@("`O*B!087-S=V]R
M9"!E>'!I<GD@871T<FEB=71E<R!A<F4@:6X@82!P;VQI8WDN(%=E"B`@("`@
M("`@("`@("`@("`@("`@("H@8V%N;F]T(')E860@=&AE;2!S;R!U<V4@=&AE
M($AO<F1E(&-O;F9I9RX@*B\*("`@("`@("`@("`@("`@("`@("`D;&]O:W5P
M<VAA9&]W6R=S:&%D;W=W87)N:6YG)UT@/2`D=&AI<RT^7W!A<F%M<ULG=V%R
M;F%G92==.PH@("`@("`@("`@("`@("`@("`@("1L;V]K=7!S:&%D;W=;)W-H
M861O=VUI;B==("`@("`]("1T:&ES+3Y?<&%R86US6R=M:6YA9V4G73L*("`@
M("`@("`@("`@("`@("`@("`D;&]O:W5P<VAA9&]W6R=S:&%D;W=M87@G72`@
M("`@/2`D=&AI<RT^7W!A<F%M<ULG;6%X86=E)UT["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&EN9F]R;6%T:6]N6S!=6R=S:&%D;W=M87@G75LP72DI('L*("`@
M("`@("`@("`@("`@("`@("`D;&]O:W5P<VAA9&]W6R=S:&%D;W=M87@G72`]
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1I;F9O<FUA=&EO;ELP75LG<VAA9&]W;6%X)UU;,%T["B`@("`@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9O<FUA=&EO
M;ELP75LG<VAA9&]W;6EN)UU;,%TI*2!["B`@("`@("`@("`@("`@("`@("`@
M)&QO;VMU<'-H861O=ULG<VAA9&]W;6EN)UT@/0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;W)M871I;VY;,%U;
M)W-H861O=VUI;B==6S!=.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D:6YF;W)M871I;VY;,%U;)W-H861O=VQA<W1C
M:&%N9V4G75LP72DI('L*("`@("`@("`@("`@("`@("`@("`D;&]O:W5P<VAA
M9&]W6R=S:&%D;W=L87-T8VAA;F=E)UT@/0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1I;F9O<FUA=&EO;ELP75LG<VAA9&]W;&%S
M=&-H86YG92==6S!=.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D:6YF;W)M871I;VY;,%U;)W-H861O=W=A<FYI;F<G
M75LP72DI('L*("`@("`@("`@("`@("`@("`@("`D;&]O:W5P<VAA9&]W6R=S
M:&%D;W=W87)N:6YG)UT@/0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1I;F9O<FUA=&EO;ELP75LG<VAA9&]W=V%R;FEN9R==
M6S!=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&QO;VMU<'-H861O=SL*("`@('T*"B`@("`O
M*BH*("`@("`J($9I;F0@;W5T(&EF('1H92!G:79E;B!S970@;V8@;&]G:6X@
M8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@
M("`@("!4:&4@=7-E<DED('1O(&-H96-K+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("`D8W)E9&5N=&EA;',@($%N(&%R<F%Y(&]F(&QO9VEN(&-R961E;G1I86QS
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C
M97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V%U=&AE;G1I8V%T92@D=7-E<DED+"`D8W)E9&5N
M=&EA;',I"B`@("!["B`@("`@("`@+RH@0V]N;F5C="!T;R!T:&4@3$1!4"!S
M97)V97(N("HO"B`@("`@("`@)'-U8V-E<W,@/2`D=&AI<RT^7V-O;FYE8W0H
M*3L*("`@("`@("!I9B`H:7-?82@D<W5C8V5S<RP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/
M3E]-15-304=%+"`D<W5C8V5S<RT^9V5T365S<V%G92@I*3L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@4V5A<F-H
M(&9O<B!T:&4@=7-E<B=S(&9U;&P@1$XN("HO"B`@("`@("`@)&1N(#T@)'1H
M:7,M/E]F:6YD1$XH)'5S97))9"D["B`@("`@("`@:68@*&ES7V$H)&1N+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5T075T:$5R
M<F]R*$%55$A?4D5!4T].7TU%4U-!1T4L("1D;BT^9V5T365S<V%G92@I*3L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M+RH@071T96UP="!T;R!B:6YD('1O('1H92!,1$%0('-E<G9E<B!A<R!T:&4@
M=7-E<BX@*B\*("`@("`@("`D8FEN9"`]($!L9&%P7V)I;F0H)'1H:7,M/E]D
M<RP@)&1N+"`D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTI.PH@("`@("`@(&EF
M("@D8FEN9"`A/2!F86QS92D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]P
M87)A;7-;)W!A<W-W;W)D7V5X<&ER871I;VXG72`]/2`G>65S)RD@>PH*("`@
M("`@("`@("`@("`@("1S:&%D;W<@/2`D=&AI<RT^7VQO;VMU<%-H861O=R@D
M9&XI.PH*("`@("`@("`@("`@("`@(&EF("@D<VAA9&]W6R=S:&%D;W=M87@G
M72`F)B`D<VAA9&]W6R=S:&%D;W=L87-T8VAA;F=E)UT@)B8*("`@("`@("`@
M("`@("`@("`@("`D<VAA9&]W6R=S:&%D;W=W87)N:6YG)UTI('L*"B`@("`@
M("`@("`@("`@("`@("`@)'1O9&%Y(#T@9FQO;W(H=&EM92@I("\@.#8T,#`I
M.PH@("`@("`@("`@("`@("`@("`@("1W87)N9&%Y(#T@)'-H861O=ULG<VAA
M9&]W;&%S=&-H86YG92==("L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1S:&%D;W=;)W-H861O=VUA>"==("T@)'-H861O=ULG<VAA9&]W=V%R
M;FEN9R==.PH*("`@("`@("`@("`@("`@("`@("`D=&]E>'!I<F4@/2`D<VAA
M9&]W6R=S:&%D;W=L87-T8VAA;F=E)UT@*PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1S:&%D;W=;)W-H861O=VUA>"==("T@)'1O9&%Y.PH*
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1T;V1A>2`^/2`D=V%R;F1A>2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG;F]T:69I8V%T
M:6]N)UTM/G!U<V@H<W!R:6YT9BA?*"(E9"!D87ES('5N=&EL('EO=7(@<&%S
M<W=O<F0@97AP:7)E<RXB*2P@)'1O97AP:7)E*2PG:&]R9&4N=V%R;FEN9R<I
M.PH@("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@
M:68@*"1T;V5X<&ER92`](#`I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]A=71H0W)E9&5N=&EA;'-;)V-H86YG95)E<75E<W1E9"==(#T@
M=')U93L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M("`@(&EF("@D=&]E>'!I<F4@/"`P*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7T584$E2140I
M.PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!`;&1A<%]C;&]S92@D=&AI<RT^7V1S*3L*("`@
M("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@0&QD87!?8VQO<V4H)'1H:7,M/E]D<RD["B`@("`@("`@("`@("1T
M:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7T9!24Q%1"D["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!!9&0@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA
M;',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@("`@
M5&AE('5S97))9"!T;R!A9&0N"B`@("`@*B!`<&%R86T@87)R87D@)&-R961E
M;G1I86QS("!4:&4@8W)E9&5N=&EA;',@=&\@8F4@<V5T+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%D9%5S97(H)'5S97))9"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@
M(&EF("@D=&AI<RT^7W!A<F%M<ULG860G72D@>PH@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(D%U=&A?;&1A<#H@061D:6YG('5S97)S
M(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB*2P@7U]&
M24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("\J($-O;FYE
M8W0@=&\@=&AE($Q$05`@<V5R=F5R+B`J+PH@("`@("`@("1S=6-C97-S(#T@
M)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@(&=L;V)A;"`D8V]N9CL*("`@
M("`@("!I9B`H(65M<'1Y*"1C;VYF6R=H;V]K<R==6R=A=71H;&1A<"==*2D@
M>PH@("`@("`@("`@("!`:6YC;'5D92!(3U)$15]"05-%("X@)R]C;VYF:6<O
M:&]O:W,N<&AP)SL*("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G
M7VAO<F1E7VAO;VM?875T:&QD87`G*2D@>PH@("`@("`@("`@("`@("`@)&5N
M=')Y(#T@8V%L;%]U<V5R7V9U;F,H)U]H;W)D95]H;V]K7V%U=&AL9&%P)RP@
M)'5S97))9"P@)&-R961E;G1I86QS*3L*("`@("`@("`@("`@("`@("1D;B`]
M("1E;G1R>5LG9&XG73L*("`@("`@("`@("`@("`@("\J(')E;6]V92!T:&4@
M9&X@96YT<GD@9G)O;2!T:&4@87)R87DN("HO"B`@("`@("`@("`@("`@("!U
M;G-E="@D96YT<GE;)V1N)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@+RH@5')Y('1H:7,@<VEM<&QE(&1E9F%U;'0@
M86YD(&AO<&4@:70@=V]R:W,N("HO"B`@("`@("`@("`@("1D;B`]("1T:&ES
M+3Y?<&%R86US6R=U:60G72`N("<])R`N("1U<V5R260@+B`G+"<@+B`D=&AI
M<RT^7W!A<F%M<ULG8F%S961N)UT["B`@("`@("`@("`@("1E;G1R>5LG8VXG
M72`]("1U<V5R260["B`@("`@("`@("`@("1E;G1R>5LG<VXG72`]("1U<V5R
M260["B`@("`@("`@("`@("1E;G1R>5LD=&AI<RT^7W!A<F%M<ULG=6ED)UU=
M(#T@)'5S97))9#L*("`@("`@("`@("`@)&5N=')Y6R=O8FIE8W1C;&%S<R==
M(#T@87)R87E?;65R9V4H87)R87DH)W1O<"<I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG;F5W=7-E<E]O
M8FIE8W1C;&%S<R==*3L*("`@("`@("`@("`@)&5N=')Y6R=U<V5R4&%S<W=O
M<F0G72`]("1T:&ES+3YG971#<GEP=&5D4&%S<W=O<F0H)&-R961E;G1I86QS
M6R=P87-S=V]R9"==+"<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG96YC<GEP=&EO;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=')U92<I
M.PH*("`@("`@("`@("`@:68@*"1T:&ES+3Y?<&%R86US6R=P87-S=V]R9%]E
M>'!I<F%T:6]N)UT@/3T@)WEE<R<I('L*("`@("`@("`@("`@("`@("1E;G1R
M>5LG<VAA9&]W36EN)UT@/2`D=&AI<RT^7W!A<F%M<ULG;6EN86=E)UT["B`@
M("`@("`@("`@("`@("`D96YT<GE;)W-H861O=TUA>"==(#T@)'1H:7,M/E]P
M87)A;7-;)VUA>&%G92==.PH@("`@("`@("`@("`@("`@)&5N=')Y6R=S:&%D
M;W=787)N:6YG)UT@/2`D=&AI<RT^7W!A<F%M<ULG=V%R;F%G92==.PH@("`@
M("`@("`@("`@("`@)&5N=')Y6R=S:&%D;W=,87-T0VAA;F=E)UT@/2!F;&]O
M<BAT:6UE*"D@+R`X-C0P,"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@)'-U8V-E<W,@/2!`;&1A<%]A9&0H)'1H:7,M/E]D<RP@)&1N+"`D
M96YT<GDI.PH*("`@("`@("!I9B`H(21S=6-C97-S*2!["B`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")!=71H7VQD87`Z
M(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@(BDL("1U<V5R260I("X@0&QD87!?97)R;W(H)'1H:7,M/E]D
M<RDI.PH@("`@("`@('T*"B`@("`@("`@0&QD87!?8VQO<V4H)'1H:7,M/E]D
M<RD["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5M;W9E(&$@<V5T(&]F(&%U=&AE;G1I8V%T:6]N(&-R961E;G1I86QS
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@(%1H
M92!U<V5R260@=&\@861D+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V955S97(H)'5S97))
M9"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]P87)A;7-;)V%D)UTI('L*
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")!=71H7VQD
M87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV
M92!$:7)E8W1O<GDB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]
M"@H@("`@("`@("\J($-O;FYE8W0@=&\@=&AE($Q$05`@<V5R=F5R+B`J+PH@
M("`@("`@("1S=6-C97-S(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@
M:68@*&ES7V$H)'-U8V-E<W,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?34534T%'12P@
M)'-U8V-E<W,M/F=E=$UE<W-A9V4H*2D["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"@H@("`@("`@(&=L;V)A;"`D8V]N9CL*("`@("`@
M("!I9B`H(65M<'1Y*"1C;VYF6R=H;V]K<R==6R=A=71H;&1A<"==*2D@>PH@
M("`@("`@("`@("!`:6YC;'5D92!(3U)$15]"05-%("X@)R]C;VYF:6<O:&]O
M:W,N<&AP)SL*("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G7VAO
M<F1E7VAO;VM?875T:&QD87`G*2D@>PH@("`@("`@("`@("`@("`@)&5N=')Y
M(#T@8V%L;%]U<V5R7V9U;F,H)U]H;W)D95]H;V]K7V%U=&AL9&%P)RP@)'5S
M97))9"D["B`@("`@("`@("`@("`@("`D9&X@/2`D96YT<GE;)V1N)UT["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!3
M96%R8V@@9F]R('1H92!U<V5R)W,@9G5L;"!$3BX@*B\*("`@("`@("`@("`@
M)&1N(#T@)'1H:7,M/E]F:6YD1$XH)'5S97))9"D["B`@("`@("`@("`@(&EF
M("AI<U]A*"1D;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?34534T%'12P@)&1N
M+3YG971-97-S86=E*"DI.PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<W5C8V5S<R`]
M($!L9&%P7V1E;&5T92@D=&AI<RT^7V1S+"1D;BD["B`@("`@("`@:68@*"$D
M<W5C8V5S<RD@>PH@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*'-P<FEN=&8H7R@B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@
M)7,B*2P@)'5S97))9"DL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M?0H*("`@("`@("!`;&1A<%]C;&]S92@D=&AI<RT^7V1S*3L*"B`@("`@("`@
M<F5T=7)N("1T:&ES+3YR96UO=F55<V5R1&%T82@D=7-E<DED*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%5P9&%T92!A('-E="!O9B!A=71H96YT:6-A=&EO
M;B!C<F5D96YT:6%L<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O
M;&1)1"`@("`@("!4:&4@;VQD('5S97))9"X*("`@("`J($!P87)A;2!S=')I
M;F<@)&YE=TE$("`@("`@(%1H92!N97<@=7-E<DED+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1C<F5D96YT:6%L<R`@5&AE(&YE=R!C<F5D96YT:6%L<PH@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A
M(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('5P9&%T955S97(H)&]L9$E$+"`D;F5W240L("1C<F5D96YT:6%L
M<RD*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]P87)A;7-;)V%D)UTI('L*
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")!=71H7VQD
M87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV
M92!$:7)E8W1O<GDN(BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M?0H*("`@("`@("`O*B!#;VYN96-T('1O('1H92!,1$%0('-E<G9E<BX@*B\*
M("`@("`@("`D<W5C8V5S<R`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@
M(&EF("AI<U]A*"1S=6-C97-S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1S=6-C97-S+3YG971-97-S
M86=E*"DL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@
M("!G;&]B86P@)&-O;F8["B`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG:&]O
M:W,G75LG875T:&QD87`G72DI('L*("`@("`@("`@("`@0&EN8VQU9&4@2$]2
M1$5?0D%312`N("<O8V]N9FEG+VAO;VMS+G!H<"<["B`@("`@("`@("`@(&EF
M("AF=6YC=&EO;E]E>&ES=',H)U]H;W)D95]H;V]K7V%U=&AL9&%P)RDI('L*
M("`@("`@("`@("`@("`@("1E;G1R>2`](&-A;&Q?=7-E<E]F=6YC*"=?:&]R
M9&5?:&]O:U]A=71H;&1A<"<L("1O;&1)1"P@)&-R961E;G1I86QS*3L*("`@
M("`@("`@("`@("`@("1O;&1D;B`]("1E;G1R>5LG9&XG73L*("`@("`@("`@
M("`@("`@("1E;G1R>2`](&-A;&Q?=7-E<E]F=6YC*"=?:&]R9&5?:&]O:U]A
M=71H;&1A<"<L("1N97=)1"P@)&-R961E;G1I86QS*3L*("`@("`@("`@("`@
M("`@("1N97=D;B`]("1E;G1R>5LG9&XG73L*("`@("`@("`@("`@("`@('5N
M<V5T*"1E;G1R>5LG9&XG72D["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`O*B!396%R8V@@9F]R('1H92!U<V5R)W,@9G5L
M;"!$3BX@*B\*("`@("`@("`@("`@)&1N(#T@)'1H:7,M/E]F:6YD1$XH)&]L
M9$E$*3L*"B`@("`@("`@("`@(&EF("AI<U]A*"1D;BP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)'-U8V-E<W,M/F=E=$UE<W-A9V4H*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1O;&1D;B`]
M("1D;CL*("`@("`@("`@("`@("`@("1N97=D;B`]('!R96=?<F5P;&%C92@G
M+W5I9#TN*C\L+R<L)W5I9#TG+B1N97=)1"XG+"<L)&1N+#$I.PH@("`@("`@
M("`@("`@("`@)'-H861O=R`]("1T:&ES+3Y?;&]O:W5P4VAA9&]W*"1D;BD[
M"@H@("`@("`@("`@("`@("`@+RH@:68@<VAA9&]W;6EN(&AA<VXG="!Y970@
M97AP:7)E9"!O;FQY(&-H86YG92!W:&5N('=E(&%R90H@("`@("`@("`@("`@
M("`@("`@861M:6YI<W1R871O<B`J+PH@("`@("`@("`@("`@("`@:68@*"1S
M:&%D;W=;)W-H861O=VQA<W1C:&%N9V4G72`F)B`D<VAA9&]W6R=S:&%D;W=M
M:6XG72D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D<VAA9&]W6R=S:&%D
M;W=L87-T8VAA;F=E)UT@*R`D<VAA9&]W6R=S:&%D;W=M:6XG72`^("AT:6UE
M*"D@+R`X-C0P,"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S
M(&YO="!Y970@97AP:7)E9"(I*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@+RH@4V5T('1H92!L
M87-T8VAA;F=E(&9I96QD("HO"B`@("`@("`@("`@("`@("!I9B`H)'-H861O
M=ULG<VAA9&]W;&%S=&-H86YG92==*2!["B`@("`@("`@("`@("`@("`@("`@
M)&5N=')Y6R=S:&%D;W=L87-T8VAA;F=E)UT@/2`@9FQO;W(H=&EM92@I("\@
M.#8T,#`I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\J
M($5N8W)Y<'0@=&AE(&YE=R!P87-S=V]R9"`J+PH@("`@("`@("`@("`@("`@
M)&5N=')Y6R=U<V5R<&%S<W=O<F0G72`]("1T:&ES+3YG971#<GEP=&5D4&%S
M<W=O<F0H)&-R961E;G1I86QS6R=P87-S=V]R9"==+"<G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V5N8W)Y<'1I;VXG72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=T<G5E)RD["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(&EF("@D;VQD240@(3T@)&YE=TE$*2!["B`@("`@
M("`@("`@(&EF("A,1$%07T]05%]04D]43T-/3%]615)324].(#T](#,I('L*
M("`@("`@("`@("`@("`@(&QD87!?<F5N86UE*"1T:&ES+3Y?9',L("1O;&1D
M;BP@)&YE=V1N+"`D=&AI<RT^7W!A<F%M<ULG8F%S961N)UTL('1R=64I.PH*
M("`@("`@("`@("`@("`@("1S=6-C97-S(#T@;&1A<%]M;V1I9GDH)'1H:7,M
M/E]D<RP@)&YE=V1N+"`D96YT<GDI.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@+RH@1V5T('1H92!C;VUP;&5T92!O;&0@<F5C;W)D
M(&9I<G-T("HO"B`@("`@("`@("`@("`@("`D<W5C8V5S<R`]($!L9&%P7W)E
M860H)'1H:7,M/E]D<RP@)&]L9&1N+"`G;V)J96-T0VQA<W,]*B<I.PH*("`@
M("`@("`@("`@("`@(&EF("@D<W5C8V5S<RD@>PH@("`@("`@("`@("`@("`@
M("`@("1I;F9O<FUA=&EO;B`]($!L9&%P7V=E=%]E;G1R:65S*"1T:&ES+3Y?
M9',L("1S=6-C97-S*3L*"B`@("`@("`@("`@("`@("`@("`@+RH@4F5M;W9E
M('1H92!C;W5N="!E;&5M96YT<R!F<F]M('1H92!A<G)A>2`J+PH@("`@("`@
M("`@("`@("`@("`@("1C;W5N=&5R(#T@,#L*("`@("`@("`@("`@("`@("`@
M("`D;F5W<F5C;W)D(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("!W
M:&EL92`H:7-S970H)&EN9F]R;6%T:6]N6S!=6R1C;W5N=&5R72DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"1I;F9O<FUA=&EO;ELP75LD:6YF
M;W)M871I;VY;,%U;)&-O=6YT97)=75LG8V]U;G0G72`]/2`Q*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D;F5W<F5C;W)D6R1I;F9O<FUA=&EO
M;ELP75LD8V]U;G1E<EU=(#T@)&EN9F]R;6%T:6]N6S!=6R1I;F9O<FUA=&EO
M;ELP75LD8V]U;G1E<EU=6S!=.PH@("`@("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YE=W)E8V]R
M9%LD:6YF;W)M871I;VY;,%U;)&-O=6YT97)=72`]("1I;F9O<FUA=&EO;ELP
M75LD:6YF;W)M871I;VY;,%U;)&-O=6YT97)=73L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('5N<V5T*"1N97=R96-O<F1;)&EN9F]R;6%T:6]N6S!=
M6R1C;W5N=&5R75U;)V-O=6YT)UTI.PH@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1C;W5N=&5R*RL["B`@("`@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("`O*B!!9&IU
M<W0@=&AE(&-H86YG960@<&%R86UE=&5R<R`J+PH@("`@("`@("`@("`@("`@
M("`@('5N<V5T*"1N97=R96-O<F1;)V1N)UTI.PH@("`@("`@("`@("`@("`@
M("`@("1N97=R96-O<F1;)'1H:7,M/E]P87)A;7-;)W5I9"==72`]("1N97=)
M1#L*("`@("`@("`@("`@("`@("`@("`D;F5W<F5C;W)D6R=U<V5R<&%S<W=O
M<F0G72`]("1E;G1R>5LG=7-E<G!A<W-W;W)D)UT["B`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1E;G1R>5LG<VAA9&]W;&%S=&-H86YG92==*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D;F5W<F5C;W)D6R=S:&%D;W=L
M87-T8VAA;F=E)UT@/2`D96YT<GE;)W-H861O=VQA<W1C:&%N9V4G73L*("`@
M("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@("1S=6-C
M97-S(#T@;&1A<%]A9&0H)'1H:7,M/E]D<RPD;F5W9&XL)&YE=W)E8V]R9"D[
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1S=6-C97-S*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1S=6-C97-S(#T@0&QD87!?9&5L971E*"1T:&ES
M+3Y?9',L)&]L9&1N*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D<W5C8V5S<R`]($!L9&%P7VUO9&EF>2@D=&AI<RT^7V1S+"`D
M;VQD9&XL("1E;G1R>2D["B`@("`@("`@?0H*("`@("`@("!I9B`H(21S=6-C
M97-S*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P
M<FEN=&8H7R@B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B
M*2P@)&YE=TE$*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@
M("`@("`@($!L9&%P7V-L;W-E*"1T:&ES+3Y?9',I.PH*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($QI<W0@57-E<G,*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!,:7-T(&]F(%5S97)S"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&QI<W15<V5R<R@I"B`@("!["B`@("`@("`@+RH@
M0V]N;F5C="!T;R!T:&4@3$1!4"!S97)V97(N("HO"B`@("`@("`@)'-U8V-E
M<W,@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D<W5C
M8V5S<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@D<W5C8V5S<RT^9V5T365S<V%G92@I+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D
M=&AI<RT^7W!A<F%M<ULG9FEL=&5R)UTI*2!["B`@("`@("`@("`@("1F:6QT
M97(@/2`D=&AI<RT^7W!A<F%M<ULG9FEL=&5R)UT["B`@("`@("`@?2!E;'-E
M:68@*"%I<U]A<G)A>2@D=&AI<RT^7W!A<F%M<ULG;V)J96-T8VQA<W,G72DI
M('L*("`@("`@("`@("`@)&9I;'1E<B`]("=O8FIE8W1C;&%S<STG("X@)'1H
M:7,M/E]P87)A;7-;)V]B:F5C=&-L87-S)UT["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&9I;'1E<B`]("<G.PH@("`@("`@("`@("!F;W)E86-H
M("@D=&AI<RT^7W!A<F%M<ULG;V)J96-T8VQA<W,G72!A<R`D;V)J96-T8VQA
M<W,I('L*("`@("`@("`@("`@("`@("1F:6QT97(@/2`G*"8G("X@)&9I;'1E
M<CL*("`@("`@("`@("`@("`@("1F:6QT97(@+CT@)RAO8FIE8W1C;&%S<STG
M("X@)&]B:F5C=&-L87-S("X@)RDI)SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@)'-E87)C:"`]($!L9&%P7W-E87)C:"@D=&AI<RT^7V1S
M+"`D=&AI<RT^7W!A<F%M<ULG8F%S961N)UTL("1F:6QT97(L(&%R<F%Y*"1T
M:&ES+3Y?<&%R86US6R=U:60G72DI.PH@("`@("`@("1E;G1R:65S(#T@0&QD
M87!?9V5T7V5N=')I97,H)'1H:7,M/E]D<RP@)'-E87)C:"D["B`@("`@("`@
M)'5S97)L:7-T(#T@87)R87DH*3L*("`@("`@("`D=6ED(#T@4W1R:6YG.CIL
M;W=E<B@D=&AI<RT^7W!A<F%M<ULG=6ED)UTI.PH@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\("1E;G1R:65S6R=C;W5N="==.R`D:2LK*2!["B`@("`@("`@
M("`@("1U<V5R;&ES=%LD:5T@/2`D96YT<FEE<ULD:5U;)'5I9%U;,%T["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)'5S97)L:7-T.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O;&]G:6XN<&AP````````````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-38R-P`Q,#4Q-30S,S<U,0`P,C(R
M,3<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J(%1H92!!=71H7VQO9VEN.CH@8VQA<W,@<')O=FED97,@
M82!S>7-T96T@;&]G:6X@:6UP;&5M96YT871I;VX@;V8*("H@=&AE($AO<F1E
M(&%U=&AE;G1I8V%T:6]N('-Y<W1E;2X*("H@5&AI<R!!=71H(&1R:79E<B!I
M<R!U<V5F=6P@:68@>6]U(&AA=F4@82!S:&%D;W<@<&%S<W=O<F0@<WES=&5M
M"B`J('=H97)E('1H92!!=71H7W!A<W-W9"!D<FEV97(@9&]E<VXG="!W;W)K
M+@H@*@H@*B!/<'1I;VYA;"!P87)A;65T97)S.CQP<F4^"B`J("`@)VQO8V%T
M:6]N)R`@3&]C871I;VX@;V8@=&AE('-U(&)I;F%R>2X*("H@("`@("`@("`@
M("`@("!$149!54Q4.B`O8FEN+W-U/"]P<F4^"B`J"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+T%U=&@O075T:"]L;V=I;BYP:'`L=B`Q+C,N,3`N.2`R,#`V
M+S`Q+S`Q(#(Q.C(X.C`W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M-"TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N
M;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?
M075T:`H@*B\*8VQA<W,@075T:%]L;V=I;B!E>'1E;F1S($%U=&@@>PH*("`@
M("\J*@H@("`@("H@06X@87)R87D@;V8@8V%P86)I;&ET:65S+"!S;R!T:&%T
M('1H92!D<FEV97(@8V%N(')E<&]R="!W:&EC:`H@("`@("H@;W!E<F%T:6]N
M<R!I="!S=7!P;W)T<R!A;F0@=VAI8V@@:70@9&]E<VXG="X*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D8V%P86)I;&ET:65S
M(#T@87)R87DH)V%D9"<@("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G=7!D871E)R`@("`@("`@/3X@9F%L<V4L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97-E='!A<W-W;W)D
M)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E
M;6]V92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G;&ES="<@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=T<F%N<W!A<F5N="<@("`]/B!F86QS92D[
M"@H@("`@+RHJ"B`@("`@*B!S=2!B:6YA<GDN"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?;&]C871I;VX@/2`G+V)I;B]S
M=2<["@H@("`@+RHJ"B`@("`@*B!,:7-T(&]F('5S97)S('1H870@<VAO=6QD
M(&)E(&5X8VQU9&5D(&9R;VT@8F5I;F<@;&ES=&5D+VAA;F1L960*("`@("`J
M(&EN(&%N>2!W87D@8GD@=&AI<R!D<FEV97(N"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]E>&-L=61E(#T@87)R87DH)W)O
M;W0G+"`G9&%E;6]N)RP@)V)I;B<L("=S>7,G+"`G<WEN8R<L("=G86UE<R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@)VUA;B<L("=L<"<L("=M86EL
M)RP@)VYE=W,G+"`G=75C<"<L("=P<F]X>2<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W!O<W1G<F5S)RP@)W=W=RUD871A)RP@)V)A8VMU<"<L("=O
M<&5R871O<B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI<W0G+"`G
M:7)C)RP@)V=N871S)RP@)VYO8F]D>2<L("=I9&5N=&0G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("=S<VAD)RP@)V=D;2<L("=P;W-T9FEX)RP@)VUY
M<W%L)RP@)V-Y<G5S)RP@)V9T<"<I.PH*("`@("\J*@H@("`@("H@0V]N<W1R
M=6-T<R!A(&YE=R!,;V=I;B!A=71H96YT:6-A=&EO;B!O8FIE8W0N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN
M:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@075T:%]L;V=I;B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@
M("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("`@("`@:68@*"%E;7!T
M>2@D<&%R86US6R=L;V-A=&EO;B==*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7VQO8V%T:6]N(#T@)'!A<F%M<ULG;&]C871I;VXG73L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD(&]U="!I9B!A('-E="!O9B!L;V=I
M;B!C<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED
M("`@("`@5&AE('5S97))9"!T;R!C:&5C:RX*("`@("`J($!P87)A;2!A<G)A
M>2`D8W)E9&5N=&EA;',@($%N(&%R<F%Y(&]F(&QO9VEN(&-R961E;G1I86QS
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N
M;W0@=&AE(&-R961E;G1I86QS(&%R92!V86QI9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V%U=&AE;G1I8V%T92@D=7-E<DED+"`D8W)E9&5N=&EA;',I"B`@
M("!["B`@("`@("`@:68@*&5M<'1Y*"1C<F5D96YT:6%L<ULG<&%S<W=O<F0G
M72DI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%\H(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB*2P@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1P<F]C(#T@<&]P
M96XH)'1H:7,M/E]L;V-A=&EO;B`N("<@+6,@+V)I;B]T<G5E("<@+B`D=7-E
M<DED+"`G=R<I.PH@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)'!R;V,I*2![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@
M9G=R:71E*"1P<F]C+"`D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTI.PH*("`@
M("`@("!R971U<FX@<&-L;W-E*"1P<F]C*2`]/3T@,#L*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O075T:"]M8V%L+G!H<```````````````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`U-C`S`#$P-3$U-#,S-S4Q`#`R,C`Q-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@5&AE
M($%U=&A?;6-A;"!C;&%S<R!P<F]V:61E<R!A;B!-0T%,(&EM<&QE;65N=&%T
M:6]N(&]F('1H92!(;W)D90H@*B!A=71H96YT:6-A=&EO;B!S>7-T96TN"B`J
M"B`J($U#04P@2&]M92!086=E.B!H='1P.B\O;6-A;"YC:&5K+F-O;2\*("H*
M("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=C86QE;F1A<B<@
M(%1H92!-0T%,(&-A;&5N9&%R(&YA;64N/"]P<F4^"B`J"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<"QV(#$N,C<N,3`N.2`R
M,#`V+S`Q+S`Q(#(Q.C(X.C`W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C
M:V%G92!(;W)D95]!=71H"B`J+PIC;&%S<R!!=71H7VUC86P@97AT96YD<R!!
M=71H('L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F(&-A<&%B:6QI=&EE
M<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A;B!R97!O<G0@=VAI8V@*("`@("`J
M(&]P97)A=&EO;G,@:70@<W5P<&]R=',@86YD('=H:6-H(&ET(&1O97-N)W0N
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&-A
M<&%B:6QI=&EE<R`](&%R<F%Y*"=A9&0G("`@("`@("`@("`]/B!F86QS92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5P9&%T92<@("`@("`@
M(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5S
M971P87-S=V]R9"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=R96UO=F4G("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VQI<W0G("`@("`@("`@(#T^('1R=64L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T<F%N<W!A<F5N="<@("`]
M/B!F86QS92D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W($U#
M04P@875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N
M('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($%U=&A?;6-A;"@D
M<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H(55T:6PZ.F5X
M=&5N<VEO;D5X:7-T<R@G;6-A;"<I*2!["B`@("`@("`@("`@($AO<F1E.CIF
M871A;"A?*")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO
M="!F;W5N9"XB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@
M("`@("`@(&EF("AE;7!T>2@D<&%R86US6R=C86QE;F1A<B==*2D@>PH@("`@
M("`@("`@("!(;W)D93HZ9F%T86PH7R@B3F\@8V%L96YD87(@;F%M92!P<F]V
M:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB*2P@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<&%R86US(#T@
M)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J($9I;F0@;W5T(&EF(&$@
M<V5T(&]F(&QO9VEN(&-R961E;G1I86QS(&%R92!V86QI9"X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1U<V5R260@("`@("!4:&4@=7-E<DED('1O(&-H96-K+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@06X@87)R87D@;V8@;&]G:6X@
M8W)E9&5N=&EA;',N($9O<B!-0T%,+`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@=&AI<R!M=7-T(&-O;G1A:6X@82!P87-S=V]R9"!E;G1R
M>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@
M;F]T('1H92!C<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]A=71H96YT:6-A=&4H)'5S97))9"P@)&-R961E;G1I86QS*0H@
M("`@>PH@("`@("`@("1M8V%L(#T@0&UC86Q?;W!E;B@D=&AI<RT^7W!A<F%M
M<ULG8V%L96YD87(G72P@)'5S97))9"P@)&-R961E;G1I86QS6R=P87-S=V]R
M9"==*3L*"B`@("`@("`@:68@*"1M8V%L*2!["B`@("`@("`@("`@($!M8V%L
M7V-L;W-E*"1M8V%L*3L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@0&UC86Q?8VQO<V4H)&UC86PI.PH@
M("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]"
M041,3T=)3BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!,:7-T(&%L;"!U<V5R<R!I;B!T:&4@
M<WES=&5M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!A<G)A
M>2!O9B!U<V5R261S+"!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W15<V5R<R@I"B`@("!["B`@
M("`@("`@)&QI;F5S(#T@0&9I;&4H)R]E=&,O;7!A<W-W9"<I.PH@("`@("`@
M(&EF("@A)&QI;F5S('Q\("%I<U]A<G)A>2@D;&EN97,I*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=5;F%B;&4@=&\@;&ES="!U
M<V5R<RXG*3L*("`@("`@("!]"@H@("`@("`@("1U<V5R<R`](&%R<F%Y*"D[
M"B`@("`@("`@9F]R96%C:"`H)&QI;F5S(&%S("1L:6YE*2!["B`@("`@("`@
M("`@("1U<V5R<UM=(#T@<W5B<W1R*"1L:6YE+"`P+"!S=')P;W,H)&QI;F4L
M("<Z)RDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1U<V5R<SL*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+W!A;2YP:'``
M````````````````````````````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4S,C,`,3`U
M,34T,S,W-3$`,#(Q-C4U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B!4:&4@075T:%]P86TZ.B!C;&%S
M<R!P<F]V:61E<R!A(%!!32UB87-E9"!I;7!L96UE;G1A=&EO;B!O9B!T:&4@
M2&]R9&4*("H@875T:&5N=&EC871I;VX@<WES=&5M+@H@*@H@*B!004T@*%!L
M=6=G86)L92!!=71H96YT:6-A=&EO;B!-;V1U;&5S*2!I<R!A(&9L97AI8FQE
M(&UE8VAA;FES;2!F;W(*("H@875T:&5N=&EC871I;F<@=7-E<G,N("!)="!H
M87,@8F5C;VUE('1H92!S=&%N9&%R9"!A=71H96YT:6-A=&EO;B!S>7-T96T@
M9F]R"B`J($QI;G5X+"!3;VQA<FES(&%N9"!&<F5E0E-$+@H@*@H@*B!4:&ES
M(&EM<&QE;65N=&%T:6]N(')E<75I<F5S($-H860@0W5N;FEN9VAA;2=S('!A
M;5]A=71H(&5X=&5N<VEO;CH*("H*("H@("`@("!H='1P.B\O=W=W+FUA=&@N
M;VAI;RUS=&%T92YE9'4O?F-C=6YN:6YG+W!A;5]A=71H+PH@*@H@*B!/<'1I
M;VYA;"!P87)A;65T97)S.CQP<F4^"B`J("`@)W-E<G9I8V4G("!4:&4@;F%M
M92!O9B!T:&4@4$%-('-E<G9I8V4@=&\@=7-E('=H96X@875T:&5N=&EC871I
M;F<N"B`J("`@("`@("`@("`@("!$149!54Q4.B!P:'`\+W!R93X*("H*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`L=B`Q+C,N
M,3`N,3$@,C`P-B\P,2\P,2`R,3HR.#HP-R!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#0M,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N(%!A<FES92`\:F]N0&AO
M<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO
M<F1E7T%U=&@*("HO"F-L87-S($%U=&A?<&%M(&5X=&5N9',@075T:"!["@H@
M("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL:71I97,L('-O('1H
M870@=&AE(&1R:79E<B!C86X@<F5P;W)T('=H:6-H"B`@("`@*B!O<&5R871I
M;VYS(&ET('-U<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S;B=T+@H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1C87!A8FEL:71I
M97,@/2!A<G)A>2@G861D)R`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=U<&1A=&4G("`@("`@("`]/B!F86QS
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E<V5T<&%S<W=O
M<F0G(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<F5M;W9E)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=L:7-T)R`@("`@("`@("`]/B!F86QS92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W1R86YS<&%R96YT)R`@(#T^(&9A;'-E
M*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@4$%-(&%U=&AE
M;G1I8V%T:6]N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T
M97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H7W!A;2@D<&%R86US(#T@
M87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A
M;7,["B`@("`@("`@:68@*"%E;7!T>2@D<&%R86US6R=S97)V:6-E)UTI*2![
M"B`@("`@("`@("`@(&EN:5]S970H)W!A;5]A=71H+G-E<G9I8V5N86UE)RP@
M)'!A<F%M<ULG<V5R=FEC92==*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A
M97AT96YS:6]N7VQO861E9"@G<&%M7V%U=&@G*2D@>PH@("`@("`@("`@("!D
M;"@G<&%M7V%U=&@N<V\G*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!&:6YD(&]U="!I9B!A('-E="!O9B!L;V=I;B!C<F5D96YT:6%L<R!A
M<F4@=F%L:60N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@("`@5&AE('5S97))
M9"!T;R!C:&5C:RX*("`@("`J($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@
M($%N(&%R<F%Y(&]F(&QO9VEN(&-R961E;G1I86QS+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-R961E;G1I
M86QS(&%R92!V86QI9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V%U=&AE;G1I
M8V%T92@D=7-E<DED+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@:68@
M*&5M<'1Y*"1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72DI('L*("`@("`@("`@
M("`@2&]R9&4Z.F9A=&%L*%\H(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,
M;V=I;B!A=71H96YT:6-A=&EO;BXB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("!]"@H@("`@("`@(&EF("@A97AT96YS:6]N7VQO861E9"@G<&%M
M7V%U=&@G*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH7R@B4$%-(&%U
M=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(BDL(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("!I9B`H(7!A;5]A=71H*"1U
M<V5R260L("1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72P@)B1E<G)O<BDI('L*
M("`@("`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?
M34534T%'12P@)&5R<F]R*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+T%U=&@O<&%S<W=D+G!H<```````````````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-C$Q,``Q,#4Q-30S,S<U,0`P,C(S-S4`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%1H92!!=71H7W!A<W-W9#HZ(&-L87-S('!R;W9I9&5S(&$@
M<&%S<W=D+69I;&4@:6UP;&5M96YT871I;VX@;V8*("H@=&AE($AO<F1E(&%U
M=&AE;G1I8V%T:6]N('-Y<W1E;2X*("H*("H@3W!T:6]N86P@<&%R86UE=&5R
M<SH\<')E/@H@*B`@("=F:6QE;F%M92<@(%1H92!P87-S=V0@9FEL92!T;R!U
M<V4N"B`J("`@("`@("`@("`@("`@1$5&055,5#H@+V5T8R]P87-S=V0*("H@
M("`G;&]C:R<@("`@("!3:&]U;&0@=V4@;&]C:R!T:&4@<&%S<W=D(&9I;&4_
M("AB;V]L96%N*0H@*B`@("`@("`@("`@("`@($1%1D%53%0Z(&9A;'-E/"]P
M<F4^"B`J"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T%U=&@O075T:"]P87-S
M=V0N<&AP+'8@,2XQ-BXQ,"XQ,2`R,#`V+S`X+S$T(#`R.C0X.C0X(&-H=6-K
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DW+3(P,#8@4F%S;75S($QE<F1O
M<F8@/')A<VUU<T!P:'`N;F5T/@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@4F%S;75S($QE<F1O<F8@/')A<VUU<T!P:'`N;F5T
M/@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7T%U
M=&@*("HO"F-L87-S($%U=&A?<&%S<W=D(&5X=&5N9',@075T:"!["@H@("`@
M+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL:71I97,L('-O('1H870@
M=&AE(&1R:79E<B!C86X@<F5P;W)T('=H:6-H"B`@("`@*B!O<&5R871I;VYS
M(&ET('-U<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S;B=T+@H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1C87!A8FEL:71I97,@
M/2!A<G)A>2@G861D)R`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=U<&1A=&4G("`@("`@("`]/B!F86QS92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E<V5T<&%S<W=O<F0G
M(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5M
M;W9E)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=L:7-T)R`@("`@("`@("`]/B!T<G5E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=')A;G-P87)E;G0G("`@/3X@9F%L<V4I.PH*
M("`@("\J*@H@("`@("H@4&%S<W=D(&9I;&4N"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?9FEL96YA;64@/2`G+V5T8R]P
M87-S=V0G.PH*("`@("\J*@H@("`@("H@2&%S:"!L:7-T(&]F('5S97)S+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?=7-E
M<G,["@H@("`@+RHJ"B`@("`@*B!&:6QE:&%N9&QE(&9O<B!L;V-K9FEL92X*
M("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?
M9G!L;V-K.PH*("`@("\J*@H@("`@("H@3&]C:VEN9R!S=&%T92X*("`@("`J
M"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?;&]C:V5D
M.PH*("`@("\J*@H@("`@("H@3&ES="!O9B!U<V5R<R!T:&%T('-H;W5L9"!B
M92!E>&-L=61E9"!F<F]M(&)E:6YG(&QI<W1E9"]H86YD;&5D"B`@("`@*B!I
M;B!A;GD@=V%Y(&)Y('1H:7,@9')I=F5R+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?97AC;'5D92`](&%R<F%Y*"=R;V]T
M)RP@)V1A96UO;B<L("=B:6XG+"`G<WES)RP@)W-Y;F,G+"`G9V%M97,G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("=M86XG+"`G;'`G+"`G;6%I;"<L
M("=N97=S)RP@)W5U8W`G+"`G<')O>'DG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("=P;W-T9W)E<R<L("=W=W<M9&%T82<L("=B86-K=7`G+"`G;W!E
M<F%T;W(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("=L:7-T)RP@)VER
M8R<L("=G;F%T<R<L("=N;V)O9'DG+"`G:61E;G1D)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<W-H9"<L("=G9&TG+"`G<&]S=&9I>"<L("=M>7-Q
M;"<L("=C>7)U<R<L("=F='`G*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=',@82!N97<@4&%S<W=D(&%U=&AE;G1I8V%T:6]N(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI
M;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!!=71H7W!A<W-W9"@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@
M("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("`@("`@:68@*"%E;7!T
M>2@D<&%R86US6R=F:6QE;F%M92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7V9I;&5N86UE(#T@)'!A<F%M<ULG9FEL96YA;64G73L*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3Y?9G!L;V-K(#T@9F]P96XH2&]R9&4Z.F=E=%1E;7!$
M:7(H*2`N("<O<&%S<W=D+FQO8VLG+"`G=R<I.PH@("`@("`@(&EF("@A96UP
M='DH)'!A<F%M<ULG;&]C:R==*2D@>PH@("`@("`@("`@("!F;&]C:R@D=&AI
M<RT^7V9P;&]C:RP@3$]#2U]%6"D["B`@("`@("`@("`@("1T:&ES+3Y?;&]C
M:V5D(#T@=')U93L*("`@("`@("!]"@H@("`@("`@("1F<"`](&9O<&5N*"1T
M:&ES+3Y?9FEL96YA;64L("=R)RD["B`@("`@("`@:68@*"$D9G`I('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-O=6QD;B=T(&]P
M96X@)R(@+B`D=&AI<RT^7V9I;&5N86UE("X@(B<N(BD["B`@("`@("`@?0H@
M("`@("`@('=H:6QE("@A9F5O9B@D9G`I*2!["B`@("`@("`@("`@("1L:6YE
M(#T@9F=E=',H)&9P+"`Q,C@I.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1L
M:6YE*2D@>PH@("`@("`@("`@("`@("`@;&ES="@D=7-E<BP@)'!A<W,L("1U
M:60L("1G:60L("1I;F9O+"`D:&]M92P@)'-H96QL*2`](&5X<&QO9&4H)SHG
M+"`D;&EN92D["B`@("`@("`@("`@("`@("!I9B`H<W1R;&5N*"1U<V5R*2`F
M)@H@("`@("`@("`@("`@("`@("`@("%I;E]A<G)A>2@D=7-E<BP@)'1H:7,M
M/E]E>&-L=61E*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=7-E
M<G-;)'5S97)=6R=P87-S=V]R9"==(#T@)'!A<W,["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]U<V5R<ULD=7-E<EU;)W5I9"==(#T@)'5I9#L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W5S97)S6R1U<V5R75LG9VED)UT@
M/2`D9VED.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=7-E<G-;)'5S
M97)=6R=I;F9O)UT@/2`D:6YF;SL*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W5S97)S6R1U<V5R75LG:&]M92==(#T@)&AO;64["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]U<V5R<ULD=7-E<EU;)W-H96QL)UT@/2`D<VAE
M;&P["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@9F-L;W-E*"1F<"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&
M:6YD(&]U="!I9B!A('-E="!O9B!L;V=I;B!C<F5D96YT:6%L<R!A<F4@=F%L
M:60N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@("`@5&AE('5S97))9"!T;R!C
M:&5C:RX*("`@("`J($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@($%N(&%R
M<F%Y(&]F(&QO9VEN(&-R961E;G1I86QS+B!&;W(@34-!3"P*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('1H:7,@;75S="!C;VYT86EN(&$@
M<&%S<W=O<F0@96YT<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!7:&5T:&5R(&]R(&YO="!T:&4@8W)E9&5N=&EA;',@87)E('9A;&ED+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?875T:&5N=&EC871E*"1U<V5R260L("1C
M<F5D96YT:6%L<RD*("`@('L*("`@("`@("!I9B`H96UP='DH)&-R961E;G1I
M86QS6R=P87-S=V]R9"==*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH
M7R@B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A
M=&EO;BXB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?=7-E<G-;)'5S97))9%TI*2!["B`@("`@
M("`@("`@(&EF("@D=&AI<RT^7W5S97)S6R1U<V5R261=6R=P87-S=V]R9"==
M(#T](&-R>7!T*"1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72P@<W5B<W1R*"1T
M:&ES+3Y?=7-E<G-;)'5S97))9%U;)W!A<W-W;W)D)UTL(#`L(#(I*2D@<F5T
M=7)N('1R=64["B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS93L*("`@
M('T*"B`@("`O*BH*("`@("`J($QI<W0@86QL('5S97)S(&EN('1H92!S>7-T
M96TN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&%R<F%Y(&]F
M('5S97))9',L(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=%5S97)S*"D*("`@('L*("`@("`@
M("!R971U<FX@87)R87E?:V5Y<R@D=&AI<RT^7W5S97)S*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($%D9',@82!U<V5R+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'5S97(@("`@($YE=R!U<V5R($E$+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<&%S<R`@("`@4&%S<W=O<F0@9F]R(&YE=R!U<V5R+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8W9S=7-E<B`@0U93('5S97(@:60@*&YE961E
M9"!F;W(@<'-E<G9E<B!P87-S=V0@9FEL97,I+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@4F5T=7)N<R!T<G5E(&]R(%!%05)?17)R;W(@:68@
M=&AE('5S97(@86QR96%D>0H@("`@("H@("`@("`@("`@("`@("`@("!E>&ES
M=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9%5S97(H)'5S97(L("1P87-S
M+"`D8W9S=7-E<B`]("<G*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]U<V5R<ULD=7-E<ETI("8F("1T:&ES+3Y?;&]C:V5D*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?=7-E<G-;)'5S97)=(#T@8W)Y<'0H)'!A<W,I.PH@
M("`@("`@("`@("`D=&AI<RT^7V-V<ULD=7-E<ET@/2`D8W9S=7-E<CL*("`@
M("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-O=6QD;B=T(&%D9"!U
M<V5R("<D=7-E<B<L(&)E8V%U<V4@=&AE('5S97(@86QR96%D>2!E>&ES=',N
M(BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@36]D:69I97,@
M82!U<V5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97(@("`@
M(%5S97(@240N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87-S("`@("!087-S
M=V]R9"!F;W(@;F5W('5S97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C=G-U
M<V5R("!#5E,@=7-E<B!I9"`H;F5E9&5D(&9O<B!P<V5R=F5R('!A<W-W9"!F
M:6QE<RDN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!2971U<FYS
M('1R=64@;W(@4$5!4E]%<G)O<B!I9B!T:&4@=7-E<B!D;V5S;B=T"B`@("`@
M*B`@("`@("`@("`@("`@("`@(&5X:7-T<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@;6]D57-E<B@D=7-E<BP@)'!A<W,L("1C=G-U<V5R(#T@)R<I"B`@("![
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?=7-E<G-;)'5S97)=*2`F)B`D
M=&AI<RT^7VQO8VME9"D@>PH@("`@("`@("`@("`D=&AI<RT^7W5S97)S6R1U
M<V5R72`](&-R>7!T*"1P87-S*3L*("`@("`@("`@("`@)'1H:7,M/E]C=G-;
M)'5S97)=(#T@)&-V<W5S97(["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*")#;W5L9&XG="!M;V1I9GD@=7-E<B`G)'5S97(G+"!B96-A=7-E
M('1H92!U<V5R(&1O97-N)W0@97AI<W0N(BD["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@1&5L971E<R!A('5S97(N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=7-E<B`@57-E<B!)1"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%)E='5R;G,@=')U92!O<B!014%27T5R<F]R(&EF
M('1H92!U<V5R(&1O97-N)W0@97AI<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&1E;%5S97(H)'5S97(I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?=7-E<G-;)'5S97)=*2`F)B`D=&AI<RT^7VQO8VME9"D@>PH@("`@("`@
M("`@("!U;G-E="@D=&AI<RT^7W5S97)S6R1U<V5R72D["B`@("`@("`@("`@
M('5N<V5T*"1T:&ES+3Y?8W9S6R1U<V5R72D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-O=6QD;B=T
M(&1E;&5T92!U<V5R("<D=7-E<B<L(&)E8V%U<V4@=&AE('5S97(@9&]E<VXG
M="!E>&ES="XB*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!7
M<FET97,@8VAA;F=E<R!T;R!P87-S=V0@9FEL92!A;F0@=6YL;V-K<R!I="X@
M(%1A:V5S(&YO(&%R9W5M96YT<R!A;F0*("`@("`J(&AA<R!N;R!D969I;F5D
M(')E='5R;B!V86QU92X*("`@("`J+PH@("`@9G5N8W1I;VX@8VQO<V4H*0H@
M("`@>PH@("`@("`@(&EF("@D=&AI<RT^7VQO8VME9"D@>PH@("`@("`@("`@
M("!F;W)E86-H("@D=&AI<RT^7W5S97)S(&%S("1U<V5R(#T^("1P87-S*2![
M"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]U<V5R<ULD=7-E<ETI('L*
M("`@("`@("`@("`@("`@("`@("!F<'5T<R@D=&AI<RT^7V9P;&]C:RP@(B1U
M<V5R.B1P87-S.B(@+B`D=&AI<RT^7W5S97)S6R1U<V5R72`N(")<;B(I.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!F
M<'5T<R@D=&AI<RT^7V9P;&]C:RP@(B1U<V5R.B1P87-S7&XB*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!R96YA;64H
M)'1H:7,M/E]L;V-K9FEL92P@)'1H:7,M/E]F:6QE;F%M92D["B`@("`@("`@
M("`@(&9L;V-K*"1T:&ES+3Y?9G!L;V-K+"!,3T-+7U5.*3L*("`@("`@("`@
M("`@)'1H:7,M/E]L;V-K960@/2!F86QS93L*("`@("`@("`@("`@9F-L;W-E
M*"1T:&ES+3Y?9G!L;V-K*3L*("`@("`@("!]"B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O075T:"]R861I=7,N<&AP````````````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$T-S$T`#$P-3$U-#,S-S4Q`#`R,C,W
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@5&AE($%U=&A?<F%D:75S(&-L87-S('!R;W9I9&5S(&$@
M4D%$2553(&EM<&QE;65N=&%T:6]N(&]F('1H92!(;W)D90H@*B!A=71H96YT
M:6-A=&EO;B!S>7-T96TN"B`J"B`J(%1H:7,@8VQA<W,@<F5Q=6ER97,@=&AE
M("=R861I=7,G(%!%0TP@97AT96YS:6]N+@H@*B!2041)55,@4$5#3"!E>'1E
M;G-I;VXZ(&AT='`Z+R]P96-L+G!H<"YN970O<&%C:V%G92]R861I=7,*("H*
M("H@3VX@*FYI>"UY(&UA8VAI;F5S+"!T:&ES(&5X=&5N<VEO;B!C86X@8F4@
M:6YS=&%L;&5D(&%S(&9O;&QO=W,Z/'!R93X*("H@("`B<&5A<B!I;G-T86QL
M(')A9&EU<R(\+W!R93X*("H*("H@5&AE;BP@961I="!Y;W5R('!H<"YI;FD@
M9FEL92!A;F0@;6%K92!S=7)E('1H92!F;VQL;W=I;F<@;&EN92!I<R!P<F5S
M96YT.CQP<F4^"B`J("`@1F]R(%=I;F1O=W,@;6%C:&EN97,Z("!E>'1E;G-I
M;VX]<&AP7W)A9&EU<RYD;&P*("H@("!&;W(@86QL(&]T:&5R<SH@("`@("`@
M(&5X=&5N<VEO;CUR861I=7,N<V\\+W!R93X*("H*("H@4F5Q=6ER960@<&%R
M86UE=&5R<SH\<')E/@H@*B`@("=H;W-T)R`@("!4:&4@4D%$2553(&AO<W0@
M=&\@=7-E("A)4"!A9&1R97-S(&]R(&9U;&QY('%U86QI9FEE9`H@*B`@("`@
M("`@("`@("!H;W-T;F%M92DN"B`J("`@)VUE=&AO9"<@(%1H92!2041)55,@
M;65T:&]D('1O('5S92!F;W(@=F%L:61A=&EN9R!T:&4@<F5Q=65S="X*("H@
M("`@("`@("`@("`@16ET:&5R.B`G4$%0)RP@)T-(05!?340U)RP@)TU30TA!
M4'8Q)RP@;W(@)TU30TA!4'8R)RX*("H@("`@("`@("`@("`@*BH@0U524D5.
M5$Q9+"!O;FQY("=005`G(&ES('-U<'!O<G1E9"X@*BH*("H@("`G<V5C<F5T
M)R`@5&AE(%)!1$E54R!S:&%R960@<V5C<F5T('-T<FEN9R!F;W(@=&AE(&AO
M<W0N(%1H90H@*B`@("`@("`@("`@("!2041)55,@<')O=&]C;VP@:6=N;W)E
M<R!A;&P@8G5T('1H92!L96%D:6YG(#$R."!B>71E<PH@*B`@("`@("`@("`@
M("!O9B!T:&4@<VAA<F5D('-E8W)E="X\+W!R93X*("H*("H@3W!T:6]N86P@
M<&%R86UE=&5R<SH\<')E/@H@*B`@("=N87,G("`@("`@5&AE(%)!1$E54R!.
M05,@:61E;G1I9FEE<B!T;R!U<V4N"B`J("`@("`@("`@("`@("!$149!54Q4
M.B!4:&4@=F%L=64@;V8@)%]315)615);)TA45%!?2$]35"==(&]R+"!I9B!N
M;W0*("H@("`@("`@("`@("`@("`@("`@("`@(&1E9FEN960L('1H96X@)VQO
M8V%L:&]S="<N"B`J("`@)W!O<G0G("`@("!4:&4@<&]R="!T;R!U<V4@;VX@
M=&AE(%)!1$E54R!S97)V97(N"B`J("`@("`@("`@("`@("!$149!54Q4.B!7
M:&%T979E<B!T:&4@;&]C86P@<WES=&5M(&ED96YT:69I97,@87,@=&AE"B`J
M("`@("`@("`@("`@("`@("`@("`@("`G<F%D:75S)R!51%`@<&]R=`H@*B`@
M("=R971R:65S)R`@5&AE(&UA>&EM=6T@;G5M8F5R(&]F(')E<&5A=&5D(')E
M<75E<W1S('1O(&UA:V4@8F5F;W)E"B`J("`@("`@("`@("`@("!G:79I;F<@
M=7`N"B`J("`@("`@("`@("`@("!$149!54Q4.B`S"B`J("`@)W-U9F9I>"<@
M("!4:&4@9&]M86EN(&YA;64@=&\@861D('1O('5N<75A;&EF:65D('5S97(@
M;F%M97,N"B`J("`@("`@("`@("`@("!$149!54Q4.B!.3TY%"B`J("`@)W1I
M;65O=70G("!4:&4@=&EM96]U="!F;W(@<F5C96EV:6YG(')E<&QI97,@9G)O
M;2!T:&4@<V5R=F5R("AI;@H@*B`@("`@("`@("`@("`@<V5C;VYD<RDN"B`J
M("`@("`@("`@("`@("!$149!54Q4.B`S('-E8V]N9',\+W!R93X*("H*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`L=B`Q
M+C(T+C@N."`R,#`V+S`Q+S`Q(#(Q.C(X.C`W(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B
M:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O
M+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E
M7T%U=&@*("HO"F-L87-S($%U=&A?<F%D:75S(&5X=&5N9',@075T:"!["@H@
M("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL:71I97,L('-O('1H
M870@=&AE(&1R:79E<B!C86X@<F5P;W)T('=H:6-H"B`@("`@*B!O<&5R871I
M;VYS(&ET('-U<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S;B=T+@H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1C87!A8FEL:71I
M97,@/2!A<G)A>2@G861D)R`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=U<&1A=&4G("`@("`@("`]/B!F86QS
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E<V5T<&%S<W=O
M<F0G(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<F5M;W9E)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=L:7-T)R`@("`@("`@("`]/B!F86QS92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W1R86YS<&%R96YT)R`@(#T^(&9A;'-E
M*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@4D%$2553(&%U
M=&AE;G1I8V%T:6]N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A
M;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H7W)A9&EU<R@D<&%R
M86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H(55T:6PZ.F5X=&5N
M<VEO;D5X:7-T<R@G<F%D:75S)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A
M=&%L*"=!=71H7W)A9&EU<R!R97%U:7)E<R!T:&4@<F%D:75S(%!%0TP@97AT
M96YS:6]N('1O(&)E(&QO861E9"XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]S971087)A;7,H)'!A<F%M<RD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@<&%R86UE=&5R<RX*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@5&AE('!A<F%M971E<B!H87-H+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?<V5T4&%R86US*"1P87)A;7,I"B`@("!["B`@("`@("`@
M+RH@02!2041)55,@:&]S="!I<R!R97%U:7)E9"X@*B\*("`@("`@("!I9B`H
M96UP='DH)'!A<F%M<ULG:&]S="==*2D@>PH@("`@("`@("`@("!(;W)D93HZ
M9F%T86PH)T%U=&A?<F%D:75S(')E<75I<F5S(&$@4D%$2553(&AO<W0@=&\@
M8V]N;F5C="!T;RXG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@02!2041)55,@<V5C<F5T('-T<FEN9R!I<R!R97%U:7)E
M9"X@*B\*("`@("`@("!I9B`H96UP='DH)'!A<F%M<ULG<V5C<F5T)UTI*2![
M"B`@("`@("`@("`@($AO<F1E.CIF871A;"@G075T:%]R861I=7,@<F5Q=6ER
M97,@82!2041)55,@<V5C<F5T('-T<FEN9RXG+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@('T*"B`@("`@("`@+RH@02!2041)55,@875T:&5N=&EC
M871I;VX@;65T:&]D(&ES(')E<75I<F5D+B`J+PH@("`@("`@(&EF("AE;7!T
M>2@D<&%R86US6R=M971H;V0G72DI('L*("`@("`@("`@("`@2&]R9&4Z.F9A
M=&%L*"=!=71H7W)A9&EU<R!R97%U:7)E<R!A(%)!1$E54R!A=71H96YT:6-A
M=&EO;B!M971H;V0N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]
M"@H@("`@("`@("\J(%)!1$E54R!.05,@261E;G1I9FEE<BX@*B\*("`@("`@
M("!I9B`H96UP='DH)'!A<F%M<ULG;F%S)UTI*2!["B`@("`@("`@("`@("1P
M87)A;7-;)VYA<R==(#T@:7-S970H)%]315)615);)TA45%!?2$]35"==*2`_
M("1?4T525D526R=(5%107TA/4U0G"ET@.B`G;&]C86QH;W-T)SL*("`@("`@
M("!]"@H@("`@("`@("\J(%-U9F9I>"!T;R!A9&0@=&\@=6YQ=6%L:69I960@
M=7-E<B!N86UE<RX@*B\*("`@("`@("!I9B`H96UP='DH)'!A<F%M<ULG<W5F
M9FEX)UTI*2!["B`@("`@("`@("`@("1P87)A;7-;)W-U9F9I>"==(#T@)R<[
M"B`@("`@("`@?0H*("`@("`@("`O*B!4:&4@4D%$2553('!O<G0@=&\@=7-E
M+B`J+PH@("`@("`@(&EF("AE;7!T>2@D<&%R86US6R=P;W)T)UTI*2!["B`@
M("`@("`@("`@("1P87)A;7-;)W!O<G0G72`](#`["B`@("`@("`@?0H*("`@
M("`@("`O*B!-87AI;75M(&YU;6)E<B!O9B!R971R:65S+B`J+PH@("`@("`@
M(&EF("AE;7!T>2@D<&%R86US6R=R971R:65S)UTI*2!["B`@("`@("`@("`@
M("1P87)A;7-;)W)E=')I97,G72`](#,["B`@("`@("`@?0H*("`@("`@("`O
M*B!2041)55,@=&EM96]U="X@*B\*("`@("`@("!I9B`H96UP='DH)'!A<F%M
M<ULG=&EM96]U="==*2D@>PH@("`@("`@("`@("`D<&%R86US6R=T:6UE;W5T
M)UT@/2`S.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D
M<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEN9"!O=70@:68@82!S
M970@;V8@;&]G:6X@8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'5S97)N86UE("`@(%1H92!U<V5R260@=&\@8VAE8VLN"B`@("`@*B!`
M<&%R86T@87)R87D@)&-R961E;G1I86QS("!!;B!A<G)A>2!O9B!L;V=I;B!C
M<F5D96YT:6%L<RX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($9O<B!R861I=7,L('1H:7,@;75S="!C;VYT86EN(&$@<&%S<W=O<F0*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&5N=')Y+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-R
M961E;G1I86QS(&%R92!V86QI9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V%U
M=&AE;G1I8V%T92@D=7-E<FYA;64L("1C<F5D96YT:6%L<RD*("`@('L*("`@
M("`@("`O*B!087-S=V]R9"!I<R!R97%U:7)E9"X@*B\*("`@("`@("!I9B`H
M(6ES<V5T*"1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72DI('L*("`@("`@("`@
M("`@2&]R9&4Z.F9A=&%L*%\H(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)
M55,@875T:&5N=&EC871I;VXN(BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("`@("`@?0H*("`@("`@("`D<F5S(#T@<F%D:75S7V%U=&A?;W!E;B@I.PH@
M("`@("`@(')A9&EU<U]A9&1?<V5R=F5R*"1R97,L("1T:&ES+3Y?<&%R86US
M6R=H;W-T)UTL("1T:&ES+3Y?<&%R86US6R=P;W)T)UTL("1T:&ES+3Y?<&%R
M86US6R=S96-R970G72P@)'1H:7,M/E]P87)A;7-;)W1I;65O=70G72P@)'1H
M:7,M/E]P87)A;7-;)W)E=')I97,G72D["B`@("`@("`@<F%D:75S7V-R96%T
M95]R97%U97-T*"1R97,L(%)!1$E54U]!0T-%4U-?4D5154535"D["B`@("`@
M("`@<F%D:75S7W!U=%]A='1R*"1R97,L(%)!1$E54U].05-?241%3E1)1DE%
M4BP@)'1H:7,M/E]P87)A;7-;)VYA<R==*3L*("`@("`@("!R861I=7-?<'5T
M7V%T='(H)')E<RP@4D%$25537TY!4U]03U)47U194$4L(%)!1$E54U]625)4
M54%,*3L*("`@("`@("!R861I=7-?<'5T7V%T='(H)')E<RP@4D%$25537U-%
M4E9)0T5?5%E012P@4D%$25537T9204U%1"D["B`@("`@("`@<F%D:75S7W!U
M=%]A='1R*"1R97,L(%)!1$E54U]&4D%-141?4%)/5$]#3TPL(%)!1$E54U]0
M4%`I.PH@("`@("`@(')A9&EU<U]P=71?871T<B@D<F5S+"!2041)55-?0T%,
M3$E.1U]35$%424].7TE$+"!I<W-E="@D7U-%4E9%4ELG4D5-3U1%7TA/4U0G
M72D@/R`D7U-%4E9%4ELG4D5-3U1%7TA/4U0G72`Z("<Q,C<N,"XP+C$G*3L*
M"B`@("`@("`@+RH@26YS97)T('5S97)N86UE+W!A<W-W;W)D(&EN=&\@<F5Q
M=65S="X@*B\*("`@("`@("!R861I=7-?<'5T7V%T='(H)')E<RP@4D%$2553
M7U5315)?3D%-12P@)'5S97)N86UE*3L*("`@("`@("!R861I=7-?<'5T7V%T
M='(H)')E<RP@4D%$25537U5315)?4$%34U=/4D0L("1C<F5D96YT:6%L<ULG
M<&%S<W=O<F0G72D["@H@("`@("`@("\J(%-E;F0@<F5Q=65S="X@*B\*("`@
M("`@("`D<W5C8V5S<R`](')A9&EU<U]S96YD7W)E<75E<W0H)')E<RD["@H@
M("`@("`@('-W:71C:"`H)'-U8V-E<W,I('L*("`@("`@("!C87-E(%)!1$E5
M4U]!0T-%4U-?04-#15!4.@H@("`@("`@("`@("!R971U<FX@=')U93L*"B`@
M("`@("`@8V%S92!2041)55-?04-#15-37U)%2D5#5#H*("`@("`@("`@("`@
M)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?34534T%'12P@7R@B
M075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB*2D[
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*"B`@("`@("`@9&5F875L=#H*
M("`@("`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?
M34534T%'12P@<F%D:75S7W-T<F5R<F]R*"1R97,I*3L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"GT*````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'``
M````````````````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C`Q,0`Q,#4Q
M-30S,S<U,0`P,C(P,S4`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J(%1H92!!=71H7W-A<VPZ.B!C;&%S
M<R!P<F]V:61E<R!A(%-!4TPM8F%S960@:6UP;&5M96YT871I;VX@;V8@=&AE
M($AO<F1E"B`J(&%U=&AE;G1I8V%T:6]N('-Y<W1E;2X*("H*("H@4T%33"!I
M<R!T:&4@4VEM<&QE($%U=&AE;G1I8V%T:6]N(&%N9"!396-U<FET>2!,87EE
M<B`H87,@9&5F:6YE9"!B>2!21D,*("H@,C(R,BDN($ET('!R;W9I9&5S(&$@
M<WES=&5M(&9O<B!A9&1I;F<@<&QU9V%B;&4@875T:&5N=&EC871I;F<@<W5P
M<&]R="!T;PH@*B!C;VYN96-T:6]N+6)A<V5D('!R;W1O8V]L<RX*("H*("H@
M5&AI<R!D<FEV97(@<F5L:65S(&]N('1H92!014-,('-A<VP@<&%C:V%G93H*
M("H*("H@("`@("!H='1P.B\O<&5C;"YP:'`N;F5T+W!A8VMA9V4O<V%S;`H@
M*@H@*B!/<'1I;VYA;"!P87)A;65T97)S.CQP<F4^"B`J("`@)V%P<"<@("`@
M("!4:&4@;F%M92!O9B!T:&4@875T:&5N=&EC871I;F<@87!P;&EC871I;VXN
M"B`J("`@("`@("`@("`@("!$149!54Q4.B!H;W)D90H@*B`@("=S97)V:6-E
M)R`@5&AE(&YA;64@;V8@=&AE(%-!4TP@<V5R=FEC92!T;R!U<V4@=VAE;B!A
M=71H96YT:6-A=&EN9RX*("H@("`@("`@("`@("`@($1%1D%53%0Z('!H<#PO
M<')E/@H@*@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S
M;"YP:'`L=B`Q+C0N,3`N.2`R,#`V+S`Q+S`Q(#(Q.C(X.C`W(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IO;B!087)I<V4@/&IO;D!H
M;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*86X@4&%R
M:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@
M0'!A8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@075T:%]S87-L(&5X=&5N
M9',@075T:"!["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL
M:71I97,L('-O('1H870@=&AE(&1R:79E<B!C86X@<F5P;W)T('=H:6-H"B`@
M("`@*B!O<&5R871I;VYS(&ET('-U<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S
M;B=T+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1C87!A8FEL:71I97,@/2!A<G)A>2@G861D)R`@("`@("`@("`@/3X@9F%L
M<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U<&1A=&4G("`@
M("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W)E<V5T<&%S<W=O<F0G(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<F5M;W9E)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=L:7-T)R`@("`@("`@("`]/B!F86QS
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1R86YS<&%R96YT
M)R`@(#T^(&9A;'-E*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N
M97<@4T%33"!A=71H96YT:6-A=&EO;B!O8FIE8W0N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE
M8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@075T:%]S
M87-L*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M<&%R86US(#T@)'!A<F%M<SL*"B`@("`@("`@:68@*"%E>'1E;G-I;VY?;&]A
M9&5D*"=S87-L)RDI('L*("`@("`@("`@("`@9&PH)W-A<VPN<V\G*3L*("`@
M("`@("!]"@H@("`@("`@("1A<'`@/2`H(65M<'1Y*"1P87)A;7-;)V%P<"==
M*2D@/R`D<&%R86US6R=A<'`G72`Z("=H;W)D92<["B`@("`@("`@<V%S;%]S
M97)V97)?:6YI="@D87!P*3L*("`@('T*"B`@("`O*BH*("`@("`J($9I;F0@
M;W5T(&EF(&$@<V5T(&]F(&QO9VEN(&-R961E;G1I86QS(&%R92!V86QI9"X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1U<V5R260@("`@("!4:&4@=7-E<DED('1O(&-H96-K
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@06X@87)R87D@
M;V8@;&]G:6X@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8W)E9&5N=&EA;',@87)E('9A
M;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!?875T:&5N=&EC871E*"1U<V5R
M260L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("!I9B`H96UP='DH)&-R
M961E;G1I86QS6R=P87-S=V]R9"==*2D@>PH@("`@("`@("`@("!(;W)D93HZ
M9F%T86PH7R@B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE
M;G1I8V%T:6]N+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"%E>'1E;G-I;VY?;&]A9&5D*"=S87-L)RDI('L*("`@
M("`@("`@("`@2&]R9&4Z.F9A=&%L*%\H(E-!4TP@875T:&5N=&EC871I;VX@
M:7,@;F]T(&%V86EL86)L92XB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M("`@("!]"@H@("`@("`@("1S97)V:6-E(#T@*"%E;7!T>2@D<&%R86US6R=S
M97)V:6-E)UTI*2`_("1P87)A;7-;)W-E<G9I8V4G72`Z("=P:'`G.PH@("`@
M("`@("1C;VYN(#T@<V%S;%]S97)V97)?;F5W*"1S97)V:6-E*3L*("`@("`@
M("!I9B`H(6ES7W)E<V]U<F-E*"1C;VYN*2D@>PH@("`@("`@("`@("!(;W)D
M93HZ9F%T86PH7R@B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T
M:6]N+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"%S87-L7V-H96-K<&%S<R@D8V]N;BP@)'5S97))9"P@)&-R961E
M;G1I86QS6R=P87-S=V]R9"==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-E
M=$%U=&A%<G)O<BA!551(7U)%05-/3E]-15-304=%+"!S87-L7V5R<F1E=&%I
M;"@D8V]N;BDI.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+U-I9VYU<"YP
M:'``````````````````````````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C(T,#``,3`U
M,34T,S,W-3$`,#(R,S0P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+T1A=&%4
M<F5E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O1F]R;2YP:'`G.PIR97%U
M:7)E7V]N8V4@)TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP)SL*"B\J*@H@*B!!
M=71H7U-I9VYU<#HZ(%1H:7,@8VQA<W,@<')O=FED97,@86X@:6YT97)F86-E
M('1O('-I9VX@=7`@;W(@:&%V90H@*B!N97<@=7-E<G,@<VEG;B!T:&5M<V5L
M=F5S('5P(&EN=&\@=&AE(&AO<F1E(&EN<W1A;&QA=&EO;BP@9&5P96YD:6YG
M"B`J(&]N(&AO=R!T:&4@861M:6X@:&%S(&-O;F9I9W5R960@2&]R9&4N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP+'8@
M,2XS."XR+C$Q(#(P,#8O,#@O,30@,#(Z-#@Z-#@@8VAU8VL@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B
M;&\N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36%R:V\@1&IU
M:VEC(#QM87)K;T!O8FQO+F-O;3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J
M($!P86-K86=E($AO<F1E7T%U=&@*("HO"F-L87-S($%U=&A?4VEG;G5P('L*
M"B`@("`O*BH*("`@("`J(%!O:6YT97(@=&\@82!$871A5')E92!I;G-T86YC
M92!T;R!M86YA9V4O<W1O<F4@<VEG;G5P<PH@("`@("H*("`@("`J($!V87(@
M1&%T851R964*("`@("`J+PH@("`@=F%R("1?9&%T871R964["@H@("`@9G5N
M8W1I;VX@075T:%]3:6=N=7`H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N
M9CL*"B`@("`@("`@:68@*&5M<'1Y*"1C;VYF6R=D871A=')E92==6R=D<FEV
M97(G72DI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%\H(EEO=2!M=7-T
M(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N
M(BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@("`@("1D
M<FEV97(@/2`D8V]N9ELG9&%T871R964G75LG9')I=F5R)UT["B`@("`@("`@
M)'1H:7,M/E]D871A=')E92`]("9$871A5')E93HZ<VEN9VQE=&]N*"1D<FEV
M97(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y7VUE<F=E*$AO<F1E.CIG971$<FEV97)#;VYF:6<H)V1A
M=&%T<F5E)RP@)&1R:79E<BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=G<F]U
M<"<@/3X@)VAO<F1E+G-I9VYU<"<I*2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E<F5N8V4@=&\@82!C;VYC<F5T
M92!!=71H7U-I9VYU<`H@("`@("H@:6YS=&%N8V4N($ET('=I;&P@;VYL>2!C
M<F5A=&4@82!N97<@:6YS=&%N8V4@:68@;F\@075T:%]3:6=N=7`*("`@("`J
M(&EN<W1A;F-E(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI
M<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R(#T@)D%U=&A?4VEG
M;G5P.CIS:6YG;&5T;VXH*0H@("`@("H*("`@("`J($!R971U<FX@075T:%]3
M:6=N=7`@(%1H92!C;VYC<F5T92!!=71H7U-I9VYU<"!R969E<F5N8V4L(&]R
M(&9A;'-E(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE
M=&]N*"D*("`@('L*("`@("`@("!S=&%T:6,@)'-I9VYU<#L*"B`@("`@("`@
M:68@*"%I<W-E="@D<VEG;G5P*2D@>PH@("`@("`@("`@("`D<VEG;G5P(#T@
M;F5W($%U=&A?4VEG;G5P*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)'-I9VYU<#L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@82!N97<@=7-E
M<B!T;R!T:&4@<WES=&5M(&%N9"!H86YD;&5S(&%N>2!E>'1R82!F:65L9',@
M=&AA="!M87D@:&%V90H@("`@("H@8F5E;B!C;VUP:6QE9"P@<F5L>6EN9R!O
M;B!T:&4@:&]O:W,N<&AP(&9I;&4N"B`@("`@*@H@("`@("H@0'!A<F%M<R!M
M:7AE9"`D:6YF;R`@4F5F97)E;F-E('1O(&%R<F%Y(&]F('!A<F%M971E<F5S
M('1O(&)E('!A<W-E9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@=&\@
M:&]O:PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%!%05)?17)R;W(@
M:68@86YY(&5R<F]R<RP@;W1H97)W:7-E('1R=64N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%D9%-I9VYU<"@F)&EN9F\I"B`@("!["B`@("`@("`@9VQO8F%L
M("1A=71H+"`D8V]N9CL*"B`@("`@("`@+R\@4&5R9F]R;2!A;GD@<')E<')O
M8V5S<VEN9R!I9B!R97%U97-T960N"B`@("`@("`@:68@*"1C;VYF6R=S:6=N
M=7`G75LG<')E<')O8V5S<R==*2!["B`@("`@("`@("`@("1I;F9O(#T@2&]R
M9&4Z.F-A;&Q(;V]K*"=?:&]R9&5?:&]O:U]S:6=N=7!?<')E<')O8V5S<R<L
M(&%R<F%Y*"1I;F9O*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1I;F9O+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&EN9F\[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($%T=&5M<'0@
M=&\@861D('1H92!U<V5R('1O('1H92!S>7-T96TN"B`@("`@("`@)'-U8V-E
M<W,@/2`D875T:"T^861D57-E<B@D:6YF;ULG=7-E<E]N86UE)UTL(&%R<F%Y
M*"=P87-S=V]R9"<@/3X@)&EN9F];)W!A<W-W;W)D)UTI*3L*("`@("`@("!I
M9B`H:7-?82@D<W5C8V5S<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'-U8V-E<W,["B`@("`@("`@?0H*("`@("`@("`O+R!!='1E
M;7!T('1O(&%D9"]U<&1A=&4@86YY(&5X=')A(&1A=&$@:&%N9&5D(&EN+@H@
M("`@("`@(&EF("@A96UP='DH)&EN9F];)V5X=')A)UTI*2!["B`@("`@("`@
M("`@("1A9&1E9"`](&9A;'-E.PH@("`@("`@("`@("`D861D960@/2!(;W)D
M93HZ8V%L;$AO;VLH)U]H;W)D95]H;V]K7W-I9VYU<%]A9&1E>'1R82<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@D:6YF
M;ULG=7-E<E]N86UE)UTL("1I;F9O6R=E>'1R82==*2D["B`@("`@("`@("`@
M(&EF("@A)&%D9&5D('Q\(&ES7V$H)&%D9&5D+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D861D960L(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?14U%4D<I.PH@("`@("`@("`@
M("`@("`@2&]R9&4Z.F9A=&%L*%\H(E5N86)L92!T;R!A9&0@97AT<F$@=7-E
M<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(BDL(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@475E=65S('1H92!U
M<V5R)W,@<W5B;6ET=&5D(')E9VES=')A=&EO;B!I;F9O(&9O<B!L871E<B!A
M9&UI;B!A<'!R;W9A;"X*("`@("`J"B`@("`@*B!`<&%R86US(&UI>&5D("1I
M;F9O("!2969E<F5N8V4@=&\@87)R87D@;V8@<&%R86UE=&5R97,@=&\@8F4@
M<&%S<V5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!T;R!H;V]K"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@4$5!4E]%<G)O<B!I9B!A;GD@
M97)R;W)S+"!O=&AE<G=I<V4@=')U92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M)G%U975E4VEG;G5P*"8D:6YF;RD*("`@('L*("`@("`@("!G;&]B86P@)&%U
M=&@L)&-O;F8["@H@("`@("`@("\O(%!E<F9O<FT@86YY('!R97!R;V-E<W-I
M;F<@:68@<F5Q=65S=&5D+@H@("`@("`@(&EF("@D8V]N9ELG<VEG;G5P)UU;
M)W!R97!R;V-E<W,G72D@>PH@("`@("`@("`@("`D:6YF;R`]($AO<F1E.CIC
M86QL2&]O:R@G7VAO<F1E7VAO;VM?<VEG;G5P7W!R97!R;V-E<W,G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@D:6YF;RDI
M.PH@("`@("`@("`@("!I9B`H:7-?82@D:6YF;RP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1I;F9O.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O+R!#:&5C:R!T;R!S964@:68@=&AE('5S
M97)N86UE(&%L<F5A9'D@97AI<W1S+@H@("`@("`@(&EF("@D875T:"T^97AI
M<W1S*"1I;F9O6R=U<V5R7VYA;64G72D@?'P*("`@("`@("`@("`@)'1H:7,M
M/E]D871A=')E92T^97AI<W1S*"1I;F9O6R=U<V5R7VYA;64G72DI('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5
M<V5R;F%M92!<(B5S7"(@86QR96%D>2!E>&ES=',N(BDL("1I;F9O6R=U<V5R
M7VYA;64G72DI.PH@("`@("`@('T*"B`@("`@("`@+R\@268@:70G<R!A('5N
M:7%U92!U<V5R;F%M92P@9V\@86AE860@86YD('%U975E('1H92!R97%U97-T
M+@H@("`@("`@("1S:6=N=7`@/2`D=&AI<RT^;F5W4VEG;G5P*"1I;F9O6R=U
M<V5R7VYA;64G72D["B`@("`@("`@:68@*"%E;7!T>2@D:6YF;ULG97AT<F$G
M72DI('L*("`@("`@("`@("`@)'-I9VYU<"T^9&%T82`](&%R<F%Y7VUE<F=E
M*"1I;F9O6R=E>'1R82==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)W!A<W-W;W)D)R`]/B`D:6YF;ULG<&%S<W=O
M<F0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=D871E4F5C96EV960G(#T^('1I;64H*2DI.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1S:6=N=7`M/F1A=&$@/2!A<G)A>2@G<&%S
M<W=O<F0G(#T^("1I;F9O6R=P87-S=V]R9"==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V1A=&5296-E:79E9"<@/3X@=&EM92@I*3L*
M("`@("`@("!]"@H@("`@("`@(&EF("@D8V]N9ELG<VEG;G5P)UU;)W%U975E
M)UTI('L*("`@("`@("`@("`@)')E<W5L="`]($AO<F1E.CIC86QL2&]O:R@G
M7VAO<F1E7VAO;VM?<VEG;G5P7W%U975E9"<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)&EN9F];)W5S97)?;F%M92==
M+"`D:6YF;RDI.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?9&%T871R964M/F%D9"@D<VEG;G5P*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($=E="!A('5S97(G<R!Q=65U960@<VEG;G5P(&EN9F]R;6%T:6]N+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97)N86UE("!4:&4@=7-E
M<FYA;64@=&\@<F5T<FEE=F4@=&AE('%U975E9"!I;F9O(&9O<BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N($1A=&%4<F5E3V)J96-T7U-I9VYU<"`@5&AE($1A
M=&%4<F5E3V)J96-T(&9O<B!T:&4@<F5Q=65S=&5D"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@<VEG;G5P+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G9711=65U9613:6=N=7`H)'5S97)N86UE*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7V1A=&%T<F5E+3YG971/8FIE8W0H)'5S97)N
M86UE+"`G1&%T851R965/8FIE8W1?4VEG;G5P)RD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'970@=&AE('%U975E9"!I;F9O<FUA=&EO;B!F;W(@86QL('!E
M;F1I;F<@<VEG;G5P<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!
M;B!A<G)A>2!O9B!$871A5')E94]B:F5C=%]3:6=N=7`@;V)J96-T<RP@;VYE
M(&9O<@H@("`@("H@("`@("`@("`@("`@("`@96%C:"!S:6=N=7`@:6X@=&AE
M('%U975E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9711=65U9613:6=N=7!S
M*"D*("`@('L*("`@("`@("`D<VEG;G5P<R`](&%R<F%Y*"D["B`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]D871A=')E92T^9V5T*$1!5$%44D5%7T9/4DU!
M5%]&3$%4+"!$051!5%)%15]23T]4+"!T<G5E*2!A<R`D=7-E<FYA;64I('L*
M("`@("`@("`@("`@:68@*"1U<V5R;F%M92`A/2!$051!5%)%15]23T]4*2![
M"B`@("`@("`@("`@("`@("`D<VEG;G5P<UM=(#T@)'1H:7,M/E]D871A=')E
M92T^9V5T3V)J96-T*"1U<V5R;F%M92D["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1S:6=N=7!S.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5M;W9E(&$@<75E=65D('-I9VYU<"X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1U<V5R;F%M92`@5&AE('5S97(@=&\@<F5M;W9E(&9R
M;VT@=&AE('-I9VYU<"!Q=65U92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M
M;W9E475E=65D4VEG;G5P*"1U<V5R;F%M92D*("`@('L*("`@("`@("`D=&AI
M<RT^7V1A=&%T<F5E+3YR96UO=F4H)'5S97)N86UE*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;B!A(&YE=R!S:6=N=7`@;V)J96-T+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!S:6=N=7!S)W,@;F%M
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N($1A=&%4<F5E3V)J96-T7U-I9VYU
M<"`@02!N97<@<VEG;G5P(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M)FYE=U-I9VYU<"@D;F%M92D*("`@('L*("`@("`@("!I9B`H96UP='DH)&YA
M;64I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=3
M:6=N=7`@;F%M97,@;75S="!B92!N;VXM96UP='DG*3L*("`@("`@("!]"B`@
M("`@("`@)'-I9VYU<"`]("9N97<@1&%T851R965/8FIE8W1?4VEG;G5P*"1N
M86UE*3L*("`@("`@("!R971U<FX@)'-I9VYU<#L*("`@('T*"GT*"B\J*@H@
M*B!%>'1E;G-I;VX@;V8@=&AE($1A=&%4<F5E3V)J96-T(&-L87-S(&9O<B!S
M=&]R:6YG(%-I9VYU<`H@*B!I;F9O<FUA=&EO;B!I;B!T:&4@1&%T851R964@
M9')I=F5R+B!)9B!Y;W4@=V%N="!T;R!S=&]R90H@*B!S<&5C:6%L:7IE9"!3
M:6=N=7`@:6YF;W)M871I;VXL('EO=2!S:&]U;&0@97AT96YD('1H:7,@8VQA
M<W,*("H@:6YS=&5A9"!O9B!E>'1E;F1I;F<@1&%T851R965/8FIE8W0@9&ER
M96-T;'DN"B`J"B`J($!A=71H;W(@($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L
M;RYC;VT^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D
M95]!=71H"B`J+PIC;&%S<R!$871A5')E94]B:F5C=%]3:6=N=7`@97AT96YD
M<R!$871A5')E94]B:F5C="!["@H@("`@+RHJ"B`@("`@*B!792!W86YT('1O
M('-E92!Q=65U960@<VEG;G5P<R!I;B!D97-C96YD:6YG(&]R9&5R(&]F(')E
M8V5I<'0N"B`@("`@*B!);G-E<G0@;F5W('-I9VYU<',@870@<&]S:71I;VX@
M,"!A;F0@<'5S:"!T:&4@<F5S="!D;W=N+@H@("`@("H*("`@("`J($!V87(@
M:6YT96=E<@H@("`@("HO"B`@("!V87(@)&]R9&5R(#T@,#L*"B`@("`O*BH*
M("`@("`J(%1H92!$871A5')E94]B:F5C=%]3:6=N=7`@8V]N<W1R=6-T;W(N
M($IU<W0@;6%K97,@<W5R92!T;R!C86QL"B`@("`@*B!T:&4@<&%R96YT(&-O
M;G-T<G5C=&]R('-O('1H870@=&AE('-I9VYU<"=S(&ES(&ES('-E=`H@("`@
M("H@<')O<&5R;'DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@
M(%1H92!I9"!O9B!T:&4@<VEG;G5P+@H@("`@("HO"B`@("!F=6YC=&EO;B!$
M871A5')E94]B:F5C=%]3:6=N=7`H)&ED*0H@("`@>PH@("`@("`@('!A<F5N
M=#HZ1&%T851R965/8FIE8W0H)&ED*3L*("`@("`@("!I9B`H:7-?;G5L;"@D
M=&AI<RT^9&%T82DI('L*("`@("`@("`@("`@)'1H:7,M/F1A=&$@/2!A<G)A
M>2@I.PH@("`@("`@('T*("`@('T*"GT*"B\J*@H@*B!(;W)D92!3:6=N=7`@
M1F]R;2P@97AT96YD:6YG(&]F($AO<F1E7T9O<FTZ.@H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UA<FMO($1J=6MI8R`\;6%R:V]`
M;V)L;RYC;VT^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(
M;W)D95]!=71H"B`J+PIC;&%S<R!(;W)D95-I9VYU<$9O<FT@97AT96YD<R!(
M;W)D95]&;W)M('L*"B`@("!V87(@)%]U<V5&;W)M5&]K96X@/2!T<G5E.PH*
M("`@(&9U;F-T:6]N($AO<F1E4VEG;G5P1F]R;2@F)'9A<G,I"B`@("!["B`@
M("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@<&%R96YT.CI(;W)D
M95]&;W)M*"1V87)S+"!S<')I;G1F*%\H(B5S(%-I9VX@57`B*2P@)')E9VES
M=')Y+3YG970H)VYA;64G*2DI.PH*("`@("`@("`D=&AI<RT^<V5T0G5T=&]N
M<RA?*")3:6=N('5P(BDL('1R=64I.PH*("`@("`@("`D=&AI<RT^861D2&ED
M9&5N*"<G+"`G=7)L)RP@)W1E>'0G+"!F86QS92D["B`@("`@("`@)'1H:7,M
M/F%D9%9A<FEA8FQE*%\H(D-H;V]S92!A('5S97)N86UE(BDL("=U<V5R7VYA
M;64G+"`G=&5X="<L('1R=64I.PH@("`@("`@("1T:&ES+3YA9&1687)I86)L
M92A?*")#:&]O<V4@82!P87-S=V]R9"(I+"`G<&%S<W=O<F0G+"`G<&%S<W=O
M<F1C;VYF:7)M)RP@=')U92P@9F%L<V4L(%\H(G1Y<&4@=&AE('!A<W-W;W)D
M('1W:6-E('1O(&-O;F9I<FTB*2D["@H@("`@("`@("\J(%5S92!H;V]K<R!G
M970@86YY(&5X=')A(&9I96QD<R!R97%U:7)E9"!I;B!S:6=N:6YG('5P+B`J
M+PH@("`@("`@("1E>'1R82`]($AO<F1E.CIC86QL2&]O:R@G7VAO<F1E7VAO
M;VM?<VEG;G5P7V=E=&5X=')A)RD["B`@("`@("`@:68@*"%I<U]A*"1E>'1R
M82P@)U!%05)?17)R;W(G*2`F)B`A96UP='DH)&5X=')A*2D@>PH@("`@("`@
M("`@("!F;W)E86-H("@D97AT<F$@87,@)&9I96QD7VYA;64@/3X@)&9I96QD
M*2!["B`@("`@("`@("`@("`@("`D<F5A9&]N;'D@/2!I<W-E="@D9FEE;&1;
M)W)E861O;FQY)UTI(#\@)&9I96QD6R=R96%D;VYL>2==(#H@;G5L;#L*("`@
M("`@("`@("`@("`@("1D97-C(#T@:7-S970H)&9I96QD6R=D97-C)UTI(#\@
M)&9I96QD6R=D97-C)UT@.B!N=6QL.PH@("`@("`@("`@("`@("`@)')E<75I
M<F5D(#T@:7-S970H)&9I96QD6R=R97%U:7)E9"==*2`_("1F:65L9%LG<F5Q
M=6ER960G72`Z(&9A;'-E.PH@("`@("`@("`@("`@("`@)&9I96QD7W!A<F%M
M<R`](&ES<V5T*"1F:65L9%LG<&%R86US)UTI(#\@)&9I96QD6R=P87)A;7,G
M72`Z(&%R<F%Y*"D["@H@("`@("`@("`@("`@("`@)'1H:7,M/F%D9%9A<FEA
M8FQE*"1F:65L9%LG;&%B96PG72P@)V5X=')A6R<@+B`D9FEE;&1?;F%M92`N
M("==)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEE
M;&1;)W1Y<&4G72P@)')E<75I<F5D+"`D<F5A9&]N;'DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&1E<V,L("1F:65L9%]P87)A;7,I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O075T:"]S;6(N<&AP````````````````````````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`W,3(V`#$P-3$U-#,S-S4Q`#`R,38V-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@5&AE($%U=&A?<VUB(&-L87-S('!R;W9I9&5S(&%N(%--0B!I;7!L
M96UE;G1A=&EO;B!O9B!T:&4@2&]R9&4*("H@875T:&5N=&EC871I;VX@<WES
M=&5M+@H@*@H@*B!4:&ES(&UO9'5L92!R97%U:7)E<R!T:&4@<VUB875T:"!E
M>'1E;G-I;VX@9F]R(%!(4#H*("H@("!H='1P.B\O=W=W+G1E:W)A="YC;VTO
M<VUB875T:"\*("H*("H@070@=&AE('1I;64@;V8@=&AI<R!W<FET:6YG+"!T
M:&4@97AT96YS:6]N+"!A;F0@=&AU<R!T:&ES(&UO9'5L92P@;VYL>0H@*B!S
M=7!P;W)T960@875T:&5N=&EC871I;VX@86=A:6YS="!A(&1O;6%I;BP@86YD
M('!D8R!A;F0@8F1C(&UU<W0@8F4@;F]N+6YU;&P*("H@86YD(&YO="!E<75A
M;"!T;R!E86-H(&]T:&5R+B!);B!O=&AE<B!W;W)D<RP@=&\@=7-E('1H:7,@
M;6]D=6QE('EO=2!M=7-T"B`J(&AA=F4@82!D;VUA:6X@=VET:"!A="!L96%S
M="!O;F4@4$1#(&%N9"!O;F4@0D1#+@H@*@H@*B!297%U:7)E9"!P87)A;65T
M97)S.CQP<F4^"B`J("`@)VAO<W1S<&5C)R`@25`L($1.4R!.86UE+"!O<B!.
M971":6]S($YA;64@;V8@=&AE(%--0B!S97)V97(@=&\*("H@("`@("`@("`@
M("`@("!A=71H96YT:6-A=&4@=VET:"X*("H@("`G9&]M86EN)R`@("!4:&4@
M9&]M86EN(&YA;64@=&\@875T:&5N=&EC871E('=I=&@N/"]P<F4^"B`J"B`J
M($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G9W)O=7`G("`@("!'
M<F]U<"!N86UE('1H870@=&AE('5S97(@;75S="!B92!A(&UE;6)E<B!O9BX@
M5VEL;"!B90H@*B`@("`@("`@("`@("`@(&EG;F]R960@:68@=&AE('9A;'5E
M('!A<W-E9"!I<R!A('IE<F\@;&5N9W1H('-T<FEN9RX\+W!R93X*("H*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`L=B`Q+C(P
M+C$P+C@@,C`P-B\P,2\P,2`R,3HR.#HP-R!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@
M*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UA<F-U<R!)+B!2>6%N(#QM87)C=7-`
M<FEB;V9L879I;BYN970^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*
M;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!`875T:&]R("!-87)C=7,@
M22X@4GEA;B`\;6%R8W5S0')I8F]F;&%V:6XN;F5T/@H@*B!`<VEN8V4@("!(
M;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@075T
M:%]S;6(@97AT96YD<R!!=71H('L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y
M(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A;B!R97!O
M<G0@=VAI8V@*("`@("`J(&]P97)A=&EO;G,@:70@<W5P<&]R=',@86YD('=H
M:6-H(&ET(&1O97-N)W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)&-A<&%B:6QI=&EE<R`](&%R<F%Y*"=A9&0G("`@("`@
M("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W5P9&%T92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<F5S971P87-S=V]R9"<@/3X@9F%L<V4L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=R96UO=F4G("`@("`@("`]/B!F86QS
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI<W0G("`@("`@
M("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=')A;G-P87)E;G0G("`@/3X@9F%L<V4I.PH*("`@("\J*@H@("`@("H@0V]N
M<W1R=6-T<R!A(&YE=R!334(@875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I
M;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N($%U=&A?<VUB*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@
M(&EF("@A571I;#HZ97AT96YS:6]N17AI<W1S*"=S;6)A=71H)RDI('L*("`@
M("`@("`@("`@2&]R9&4Z.F9A=&%L*%\H(D%U=&A?<VUB875T:#H@4F5Q=6ER
M960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(I+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@+RH@16YS=7)E('=E)W9E
M(&)E96X@<')O=FED960@=VET:"!A;&P@;V8@=&AE(&YE8V5S<V%R>2!P87)A
M;65T97)S+B`J+PH@("`@("`@($AO<F1E.CIA<W-E<G1$<FEV97)#;VYF:6<H
M)'!A<F%M<RP@)V%U=&@G+`H@("`@("`@("`@("!A<G)A>2@G:&]S='-P96,G
M+"`G9&]M86EN)RDL"B`@("`@("`@("`@("=A=71H96YT:6-A=&EO;B!386UB
M82<I.PH*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!&:6YD(&]U="!I9B!T:&4@9VEV96X@<V5T(&]F
M(&QO9VEN(&-R961E;G1I86QS(&%R92!V86QI9"X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U
M<V5R260@("`@("!4:&4@=7-E<DED('1O(&-H96-K+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1C<F5D96YT:6%L<R`@06X@87)R87D@;V8@;&]G:6X@8W)E9&5N
M=&EA;',N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N
M('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?875T:&5N=&EC871E*"1U<V5R260L("1C
M<F5D96YT:6%L<RD*("`@('L*("`@("`@("!I9B`H96UP='DH)&-R961E;G1I
M86QS6R=P87-S=V]R9"==*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH
M7R@B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO
M;BXB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@
M("\J($%U=&AE;G1I8V%T92X@*B\*("`@("`@("`D<G9A;"`]('9A;&ED871E
M*"1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V1O;6%I;B==+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@96UP='DH)'1H:7,M/E]P87)A;7-;)V=R;W5P)UTI
M(#\@)R<@.B`D=&AI<RT^7W!A<F%M<ULG9W)O=7`G72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("1U<V5R260L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTI.PH*("`@("`@("!I9B`H)')V
M86P@/3T](#`I('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@:68@*"1R=F%L(#T]/2`Q*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]-
M15-304=%+"!?*")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(I
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7TU%4U-!1T4L(&5R<C)S='(H
M*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]S<6PN<&AP````
M````````````````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0P-30T`#$P-3$U
M-#,S-S4Q`#`R,3<P,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@5&AE($%U=&A?<W%L(&-L87-S('!R
M;W9I9&5S(&$@4U%,(&EM<&QE;65N=&%T:6]N(&]F('1H92!(;W)D90H@*B!A
M=71H96YT:6-A=&EO;B!S>7-T96TN"B`J"B`J(%)E<75I<F5D('!A<F%M971E
M<G,Z/'!R93X*("H@("`G<&AP='EP92<@("`@("!4:&4@9&%T86)A<V4@='EP
M92`H:64N("=P9W-Q;"<L("=M>7-Q;"<L(&5T8RXI+CPO<')E/@H@*@H@*B!/
M<'1I;VYA;"!P87)A;65T97)S.CQP<F4^"B`J("`@)V5N8W)Y<'1I;VXG("`@
M("`@("`@("`@(%1H92!E;F-R>7!T:6]N('1O('5S92!T;R!S=&]R92!T:&4@
M<&%S<W=O<F0@:6X*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE
M('1A8FQE("AE+F<N('!L86EN+"!C<GEP="P@;60U+6AE>"P*("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@;60U+6)A<V4V-"P@<VUD-2P@<VAA+"!S
M<VAA+"!A<')M9#4I+@H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!$
M149!54Q4.B`G;60U+6AE>"<*("H@("`G<VAO=U]E;F-R>7!T:6]N)R`@("`@
M("`@5VAE=&AE<B!O<B!N;W0@=&\@<')E<&5N9"!T:&4@96YC<GEP=&EO;B!I
M;B!T:&4*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<&%S<W=O<F0@
M9FEE;&0N"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@($1%1D%53%0Z
M("=F86QS92<*("H@("`G<&%S<W=O<F1?9FEE;&0G("`@("`@("`@5&AE(&YA
M;64@;V8@=&AE('!A<W-W;W)D(&9I96QD(&EN('1H92!A=71H('1A8FQE+@H@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!$149!54Q4.B`G=7-E<E]P
M87-S)PH@*B`@("=T86)L92<@("`@("`@("`@("`@("`@("!4:&4@;F%M92!O
M9B!T:&4@4U%,('1A8FQE('1O('5S92!I;B`G9&%T86)A<V4G+@H@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!$149!54Q4.B`G:&]R9&5?=7-E<G,G
M"B`J("`@)W5S97)N86UE7V9I96QD)R`@("`@("`@(%1H92!N86UE(&]F('1H
M92!U<V5R;F%M92!F:65L9"!I;B!T:&4@875T:"!T86)L92X*("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@1$5&055,5#H@)W5S97)?=6ED)PH@*B`@
M("=S;V9T7V5X<&ER871I;VY?9FEE;&0G("!4:&4@;F%M92!O9B!T:&4@9FEE
M;&0@8V]N=&%I;FEN9R!A(&1A=&4@869T97(*("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@=VAI8V@@=&AE('-Y<W1E;2!W:6QL(')E<75E<W0@=&AE
M('5S97(@8VAA;F=E(&AI<PH@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!O<B!H97(@<&%S<W=O<F0N"B`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@($1%1D%53%0Z(&YO;F4*("H@("`G:&%R9%]E>'!I<F%T:6]N7V9I96QD
M)R`@5&AE(&YA;64@;V8@=&AE(&9I96QD(&-O;G1A:6YI;F<@82!D871E(&%F
M=&5R"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@('=H:6-H('1H92!A
M8V-O=6YT(&ES(&YO(&QO;F=E<B!V86QI9"!A;F0@=&AE('5S97(*("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=VEL;"!N;W0@8F4@86)L92!T;R!L
M;V<@:6X@870@86QL+@H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!$
M149!54Q4.B!N;VYE/"]P<F4^"B`J"B`J(%)E<75I<F5D(&)Y('-O;64@9&%T
M86)A<V4@:6UP;&5M96YT871I;VYS.CQP<F4^"B`J("`@)VAO<W1S<&5C)R`@
M("`@5&AE(&AO<W1N86UE(&]F('1H92!D871A8F%S92!S97)V97(N"B`J("`@
M)W!R;W1O8V]L)R`@("`@5&AE(&-O;6UU;FEC871I;VX@<')O=&]C;VP@*"=T
M8W`G+"`G=6YI>"<L(&5T8RXI+@H@*B`@("=D871A8F%S92<@("`@(%1H92!N
M86UE(&]F('1H92!D871A8F%S92X*("H@("`G=7-E<FYA;64G("`@("!4:&4@
M=7-E<FYA;64@=VET:"!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A8F%S
M92X*("H@("`G<&%S<W=O<F0G("`@("!4:&4@<&%S<W=O<F0@87-S;V-I871E
M9"!W:71H("=U<V5R;F%M92<N"B`J("`@)V]P=&EO;G,G("`@("`@061D:71I
M;VYA;"!O<'1I;VYS('1O('!A<W,@=&\@=&AE(&1A=&%B87-E+@H@*B`@("=P
M;W)T)R`@("`@("`@(%1H92!P;W)T(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@
M=&AE(&1A=&%B87-E+@H@*B`@("=T='DG("`@("`@("`@(%1H92!45%D@;VX@
M=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N/"]P<F4^"B`J"B`J
M(%1H92!T86)L92!S=')U8W1U<F4@9F]R('1H92!!=71H('-Y<W1E;2!I<R!I
M;@H@*B!S8W)I<'1S+W-Q;"]H;W)D95]U<V5R<RYS<6PN"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP+'8@,2XV.2XQ,"XQ.2`R
M,#`V+S`X+S$T(#`R.C0X.C0X(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P
M86-K86=E($AO<F1E7T%U=&@*("HO"F-L87-S($%U=&A?<W%L(&5X=&5N9',@
M075T:"!["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL:71I
M97,L('-O('1H870@=&AE(&1R:79E<B!C86X@<F5P;W)T('=H:6-H"B`@("`@
M*B!O<&5R871I;VYS(&ET('-U<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S;B=T
M+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1C
M87!A8FEL:71I97,@/2!A<G)A>2@G861D)R`@("`@("`@("`@/3X@=')U92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5P9&%T92<@("`@("`@
M(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97-E
M='!A<W-W;W)D)R`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G<F5M;W9E)R`@("`@("`@/3X@=')U92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VQI<W0G("`@("`@("`@(#T^('1R=64L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=T<F%N<W!A<F5N="<@("`]/B!F
M86QS92D["@H@("`@+RHJ"B`@("`@*B!(86YD;&4@9F]R('1H92!C=7)R96YT
M(&1A=&%B87-E(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!$0@H@
M("`@("HO"B`@("!V87(@)%]D8CL*"B`@("`O*BH*("`@("`J($)O;VQE86X@
M:6YD:6-A=&EN9R!W:&5T:&5R(&]R(&YO="!W92=R92!C;VYN96-T960@=&\@
M=&AE(%-13"!S97)V97(N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@
M("`@*B\*("`@('9A<B`D7V-O;FYE8W1E9"`](&9A;'-E.PH*("`@("\J*@H@
M("`@("H@0V]N<W1R=6-T<R!A(&YE=R!344P@875T:&5N=&EC871I;VX@;V)J
M96-T+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA
M<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*B\*
M("`@(&9U;F-T:6]N($%U=&A?<W%L*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*("`@('T*"B`@
M("`O*BH*("`@("`J($9I;F0@;W5T(&EF(&$@<V5T(&]F(&QO9VEN(&-R961E
M;G1I86QS(&%R92!V86QI9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@("!4
M:&4@=7-E<DED('1O(&-H96-K+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D
M96YT:6%L<R`@5&AE(&-R961E;G1I86QS('1O('5S92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H92!C<F5D96YT
M:6%L<R!A<F4@=F%L:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A=71H96YT
M:6-A=&4H)'5S97))9"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@("\J
M(%]C;VYN96-T*"D@=VEL;"!D:64@=VET:"!(;W)D93HZ9F%T86PH*2!U<&]N
M(&9A:6QU<F4N("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@
M("`@("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@("`@)'%U97)Y
M(#T@<W!R:6YT9B@G4T5,14-4("H@1E)/32`E<R!72$5212`E<R`](#\G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M=7-E<FYA;65?9FEE;&0G72D["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1U
M<V5R260I.PH*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y
M(&)Y($%U=&A?<W%L.CI?875T:&5N=&EC871E*"DZ("<@+B`D<75E<GDL(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7T9!
M24Q%1"D["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@
M("`@("`@("1R;W<@/2`D<F5S=6QT+3YF971C:%)O=RA$0E]'151-3T1%7T%3
M4T]#*3L*("`@("`@("!I9B`H:7-?87)R87DH)')O=RDI('L*("`@("`@("`@
M("`@)')E<W5L="T^9G)E92@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7T)!1$Q/1TE.
M*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"$D=&AI<RT^7V-O;7!A<F5087-S=V]R9',H)')O=ULD=&AI<RT^
M7W!A<F%M<ULG<&%S<W=O<F1?9FEE;&0G75TL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&-R961E;G1I86QS6R=P87-S=V]R9"==
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%
M05-/3E]"041,3T=)3BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@("1N;W<@/2!T:6UE*"D["B`@("`@("`@:68@*"%E
M;7!T>2@D=&AI<RT^7W!A<F%M<ULG:&%R9%]E>'!I<F%T:6]N7V9I96QD)UTI
M("8F"B`@("`@("`@("`@("%E;7!T>2@D<F]W6R1T:&ES+3Y?<&%R86US6R=H
M87)D7V5X<&ER871I;VY?9FEE;&0G75TI("8F"B`@("`@("`@("`@("@D;F]W
M(#X@)')O=ULD=&AI<RT^7W!A<F%M<ULG:&%R9%]E>'!I<F%T:6]N7V9I96QD
M)UU=*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(
M7U)%05-/3E]%6%!)4D5$*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG
M<V]F=%]E>'!I<F%T:6]N7V9I96QD)UTI("8F"B`@("`@("`@("`@("%E;7!T
M>2@D<F]W6R1T:&ES+3Y?<&%R86US6R=S;V9T7V5X<&ER871I;VY?9FEE;&0G
M75TI("8F"B`@("`@("`@("`@("@D;F]W(#X@)')O=ULD=&AI<RT^7W!A<F%M
M<ULG<V]F=%]E>'!I<F%T:6]N7V9I96QD)UU=*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7V%U=&A#<F5D96YT:6%L<ULG8VAA;F=E4F5Q=65S=&5D)UT@/2!T
M<G5E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!9&0@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E
M9&5N=&EA;',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED
M("`@("`@5&AE('5S97))9"!T;R!A9&0N"B`@("`@*B!`<&%R86T@87)R87D@
M)&-R961E;G1I86QS("!4:&4@8W)E9&5N=&EA;',@=&\@861D+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%
M05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%D9%5S97(H)'5S97))9"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`O*B!"=6EL9"!T:&4@
M4U%,('%U97)Y+B`J+PH@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)TE.4T52
M5"!)3E1/("5S("@E<RP@)7,I(%9!3%5%4R`H/RP@/RDG+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;65?
M9FEE;&0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=P87-S=V]R9%]F:65L9"==*3L*("`@("`@("`D=F%L=65S(#T@87)R
M87DH)'5S97))9"P*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E
M=$-R>7!T961087-S=V]R9"@D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V5N8W)Y<'1I;VXG72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG<VAO=U]E;F-R>7!T:6]N)UTI*3L*"B`@("`@
M("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!!=71H7W-Q;#HZ
M861D57-E<B@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%
M05)?3$]'7T1%0E5'*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M
M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@57!D871E(&$@<V5T(&]F(&%U=&AE;G1I8V%T:6]N
M(&-R961E;G1I86QS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]L
M9$E$("`@("`@("!4:&4@;VQD('5S97))9"X*("`@("`J($!P87)A;2!S=')I
M;F<@)&YE=TE$("`@("`@("!4:&4@;F5W('5S97))9"X*("`@("`J($!P87)A
M;2!A<G)A>2`@)&-R961E;G1I86QS("!4:&4@;F5W(&-R961E;G1I86QS"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R
M(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@=7!D871E57-E<B@D;VQD240L("1N97=)1"P@)&-R961E;G1I
M86QS*0H@("`@>PH@("`@("`@("\J(%]C;VYN96-T*"D@=VEL;"!D:64@=VET
M:"!(;W)D93HZ9F%T86PH*2!U<&]N(&9A:6QU<F4N("HO"B`@("`@("`@)'1H
M:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J($)U:6QD('1H92!344P@<75E
M<GDN("HO"B`@("`@("`@)'1U<&QE(#T@87)R87DH*3L*("`@("`@("`D='5P
M;&5;)'1H:7,M/E]P87)A;7-;)W5S97)N86UE7V9I96QD)UU=(#T@)&YE=TE$
M.PH@("`@("`@("1T=7!L95LD=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F1?9FEE
M;&0G75T@/0H@("`@("`@("`@("`D=&AI<RT^9V5T0W)Y<'1E9%!A<W-W;W)D
M*"1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG96YC<GEP=&EO;B==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=S:&]W7V5N8W)Y<'1I;VXG72D["@H@("`@("`@(&EF("AE
M;7!T>2@D=&AI<RT^7W!A<F%M<ULG<V]F=%]E>'!I<F%T:6]N7W=I;F1O=R==
M*2D@>PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=S
M;V9T7V5X<&ER871I;VY?9FEE;&0G72DI('L*("`@("`@("`@("`@("`@("1T
M=7!L95LD=&AI<RT^7W!A<F%M<ULG<V]F=%]E>'!I<F%T:6]N7V9I96QD)UU=
M(#T@;G5L;#L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1D871E(#T@=&EM92@I.PH@("`@("`@("`@("`D9&%T96$@/2!L
M;V-A;'1I;64H)&1A=&4L('1R=64I.PH@("`@("`@("`@("`D9&%T92`](&UK
M=&EM92@D9&%T96%;)W1M7VAO=7(G72P@)&1A=&5A6R=T;5]M:6XG72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&5A6R=T;5]S96,G72P@)&1A
M=&5A6R=T;5]M;VXG72`K(#$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D871E85LG=&U?;61A>2==("L@)'1H:7,M/E]P87)A;7-;)W-O9G1?97AP
M:7)A=&EO;E]W:6YD;W<G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&1A=&5A6R=T;5]Y96%R)UTI.PH*("`@("`@("`@("`@)'1U<&QE6R1T:&ES
M+3Y?<&%R86US6R=S;V9T7V5X<&ER871I;VY?9FEE;&0G75T@/2`D9&%T93L*
M"B`@("`@("`@("`@(&=L;V)A;"`D;F]T:69I8V%T:6]N.PH@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1N;W1I9FEC871I;VXI*2!["B`@("`@("`@("`@("`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*'-T<F9T:6UE*%\H(DYE=R!P87-S=V]R
M9"!W:6QL(&5X<&ER92!O;B`E>"XB*2P@)&1A=&4I+"`G:&]R9&4N;65S<V%G
M92<I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H96UP='DH)'1H
M:7,M/E]P87)A;7-;)VAA<F1?97AP:7)A=&EO;E]W:6YD;W<G72DI('L*("`@
M("`@("`@("`@("`@("1T=7!L95LD=&AI<RT^7W!A<F%M<ULG:&%R9%]E>'!I
M<F%T:6]N7V9I96QD)UU=(#T@;G5L;#L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1D871E82`](&QO8V%L=&EM92@D9&%T92P@=')U
M92D["B`@("`@("`@("`@("`@("`D9&%T92`](&UK=&EM92@D9&%T96%;)W1M
M7VAO=7(G72P@)&1A=&5A6R=T;5]M:6XG72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1D871E85LG=&U?<V5C)UTL("1D871E85LG=&U?;6]N
M)UT@*R`Q+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&5A
M6R=T;5]M9&%Y)UT@*R`D=&AI<RT^7W!A<F%M<ULG<V]F=%]E>'!I<F%T:6]N
M7W=I;F1O=R==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A
M=&5A6R=T;5]Y96%R)UTI.PH*("`@("`@("`@("`@("`@("1T=7!L95LD=&AI
M<RT^7W!A<F%M<ULG:&%R9%]E>'!I<F%T:6]N7V9I96QD)UU=(#T@)&1A=&4[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O4U%,+G!H<"<["B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G
M55!$051%("5S(%-%5"`E<R!72$5212`E<R`](#\G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("!(;W)D95]344PZ.G5P9&%T959A;'5E<R@D=&AI
M<RT^7V1B+"`D='5P;&4I+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)W5S97)N86UE7V9I96QD)UTI.PH@("`@("`@("1V86QU
M97,@/2!A<G)A>2@D;VQD240I.PH*("`@("`@("!(;W)D93HZ;&]G365S<V%G
M92@G4U%,(%%U97)Y(&)Y($%U=&A?<W%L.G5P9&%T955S97(H*3H@)R`N("1Q
M=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V
M86QU97,I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E<W5L="P@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5S970@82!U<V5R)W,@<&%S
M<W=O<F0N(%5S960@9F]R(&5X86UP;&4@=VAE;B!T:&4@=7-E<B!D;V5S(&YO
M=`H@("`@("H@<F5M96UB97(@=&AE(&5X:7-T:6YG('!A<W-W;W)D+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97)?:60@(%1H92!U<V5R(&ED
M(&9O<B!W:&EC:"!T;R!R97-E="!T:&4@<&%S<W=O<F0N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5&AE(&YE=R!P87-S=V]R9"!O;B!S=6-C97-S
M(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX*("`@("`J("`@("`@("`@("`@
M("`@(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E<V5T4&%S<W=O
M<F0H)'5S97)?:60I"B`@("!["B`@("`@("`@+RH@7V-O;FYE8W0H*2!W:6QL
M(&1I92!W:71H($AO<F1E.CIF871A;"@I('5P;VX@9F%I;'5R92X@*B\*("`@
M("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@1V5T(&$@;F5W
M(')A;F1O;2!P87-S=V]R9"X@*B\*("`@("`@("`D<&%S<W=O<F0@/2!!=71H
M.CIG96Y286YD;VU087-S=V]R9"@I.PH*("`@("`@("`O*B!"=6EL9"!T:&4@
M4U%,('%U97)Y+B`J+PH@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)U501$%4
M12`E<R!3150@)7,@/2`_(%=(15)%("5S(#T@/R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P87-S=V]R9%]F:65L
M9"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)W5S97)N86UE7V9I96QD)UTI.PH@("`@("`@("1V86QU97,@/2!A<G)A>2@D
M=&AI<RT^9V5T0W)Y<'1E9%!A<W-W;W)D*"1P87-S=V]R9"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG96YC<GEP=&EO;B==+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=S:&]W7V5N8W)Y<'1I;VXG72DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("1U<V5R7VED*3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)U-13"!1=65R>2!B>2!!=71H7W-Q;#HZ<F5S971087-S=V]R9"@I.B`G
M("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'
M*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R
M>2P@)'9A;'5E<RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D<&%S<W=O<F0["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$96QE=&4@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N
M=&EA;',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("!4
M:&4@=7-E<DED('1O(&1E;&5T92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@("`@("`@(%-U8V-E<W,@;W(@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5M;W9E57-E<B@D=7-E<DED*0H@("`@>PH@("`@("`@("\J
M(%]C;VYN96-T*"D@=VEL;"!D:64@=VET:"!(;W)D93HZ9F%T86PH*2!U<&]N
M(&9A:6QU<F4N("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@
M("`@("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@("`@)'%U97)Y
M(#T@<W!R:6YT9B@G1$5,151%($923TT@)7,@5TA%4D4@)7,@/2`_)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S
M97)N86UE7V9I96QD)UTI.PH@("`@("`@("1V86QU97,@/2!A<G)A>2@D=7-E
M<DED*3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B
M>2!!=71H7W-Q;#HZ<F5M;W9E57-E<B@I.B`G("X@)'%U97)Y+"!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D=&AI<RT^<F5M;W9E57-E<D1A=&$H)'5S97))9"D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!,:7-T(&%L;"!U<V5R<R!I;B!T:&4@<WES=&5M+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!A<G)A>2!O9B!U<V5R261S
M+"!O<B!F86QS92!O;B!F86EL=7)E+W5N<W5P<&]R=&5D+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!L:7-T57-E<G,H*0H@("`@>PH@("`@("`@("\J(%]C;VYN
M96-T*"D@=VEL;"!D:64@=VET:"!(;W)D93HZ9F%T86PH*2!U<&]N(&9A:6QU
M<F4N("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J
M($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@("`@)'%U97)Y(#T@<W!R
M:6YT9B@G4T5,14-4("5S($923TT@)7,G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE7V9I96QD)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72D[
M"@H@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@075T
M:%]S<6PZ.FQI<W15<V5R<R@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],
M24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?9&(M/F=E=$-O;"@D<75E<GDI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0VAE8VMS(&EF(&$@=7-E<DED(&5X:7-T<R!I;B!T:&4@<VES=&5M+@H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE
M('5S97))9"!A;')E861Y(&5X:7-T<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M97AI<W1S*"1U<V5R260I"B`@("!["B`@("`@("`@+RH@7V-O;FYE8W0H*2!W
M:6QL(&1I92!W:71H($AO<F1E.CIF871A;"@I('5P;VX@9F%I;'5R92X@*B\*
M("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I;&0@
M=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=3
M14Q%0U0@)7,@1E)/32`E<R!72$5212`E<R`](#\G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE7V9I96QD)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=U<V5R;F%M95]F:65L9"==*3L*("`@("`@("`D=F%L=65S(#T@87)R87DH
M)'5S97))9"D["@H@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E
M<GD@8GD@075T:%]S<6PZ.F5X:7-T<R@I.B`G("X@)'%U97)Y+"!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?9&(M/F=E=$]N92@D<75E<GDL("1V86QU97,I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0V]M<&%R92!A;B!E;F-R>7!T960@<&%S<W=O<F0@
M=&\@82!P;&%I;G1E>'0@<W1R:6YG('1O('-E92!I9@H@("`@("H@=&AE>2!M
M871C:"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1E;F-R>7!T960@(%1H92!C<GEP=&5D('!A
M<W-W;W)D('1O(&-O;7!A<F4@86=A:6YS="X*("`@("`J($!P87)A;2!S=')I
M;F<@)'!L86EN=&5X="`@5&AE('!L86EN=&5X="!P87-S=V]R9"!T;R!V97)I
M9GDN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF(&UA
M=&-H960L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V-O;7!A<F5087-S=V]R9',H)&5N8W)Y<'1E9"P@)'!L86EN=&5X="D*("`@
M('L*("`@("`@("!R971U<FX@)&5N8W)Y<'1E9"`]/2`D=&AI<RT^9V5T0W)Y
M<'1E9%!A<W-W;W)D*"1P;&%I;G1E>'0L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D96YC<GEP=&5D
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V5N8W)Y<'1I;VXG72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=S:&]W7V5N8W)Y<'1I;VXG72D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!O<&5N(&$@8V]N;F5C
M=&EO;B!T;R!T:&4@4U%,('-E<G9E<BX*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N
M('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I"B`@("!["B`@("`@("`@
M:68@*"1T:&ES+3Y?8V]N;F5C=&5D*2!["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T*"B`@("`@("`@2&]R9&4Z.F%S<V5R=$1R:79E<D-O
M;F9I9R@D=&AI<RT^7W!A<F%M<RP@)V%U=&@G+"!A<G)A>2@G<&AP='EP92<I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%U=&AE;G1I
M8V%T:6]N(%-13"<I.PH*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R
M86US6R=D871A8F%S92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG9&%T86)A<V4G72`]("<G.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?<&%R86US6R=U<V5R;F%M92==*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;64G72`]("<G.PH@("`@("`@('T*
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=P87-S=V]R9"==
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72`]
M("<G.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R
M86US6R=H;W-T<W!E8R==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG:&]S='-P96,G72`]("<G.PH@("`@("`@('T*("`@("`@("!I9B`H96UP
M='DH)'1H:7,M/E]P87)A;7-;)V5N8W)Y<'1I;VXG72DI('L*("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)V5N8W)Y<'1I;VXG72`]("=M9#4M:&5X)SL*
M("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG
M<VAO=U]E;F-R>7!T:6]N)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=S:&]W7V5N8W)Y<'1I;VXG72`](&9A;'-E.PH@("`@("`@('T*("`@
M("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==(#T@)VAO<F1E7W5S
M97)S)SL*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R
M86US6R=U<V5R;F%M95]F:65L9"==*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG=7-E<FYA;65?9FEE;&0G72`]("=U<V5R7W5I9"<["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S97)N
M86UE7V9I96QD)UT@/2!3=')I;F<Z.FQO=V5R*"1T:&ES+3Y?<&%R86US6R=U
M<V5R;F%M95]F:65L9"==*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y
M*"1T:&ES+3Y?<&%R86US6R=P87-S=V]R9%]F:65L9"==*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F1?9FEE;&0G72`]("=U<V5R
M7W!A<W,G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=P87-S=V]R9%]F:65L9"==(#T@4W1R:6YG.CIL;W=E<B@D=&AI
M<RT^7W!A<F%M<ULG<&%S<W=O<F1?9FEE;&0G72D["B`@("`@("`@?0H*("`@
M("`@("`O*B!#;VYN96-T('1O('1H92!344P@<V5R=F5R('5S:6YG('1H92!S
M=7!P;&EE9"!P87)A;65T97)S+B`J+PH@("`@("`@(&EN8VQU9&5?;VYC92`G
M1$(N<&AP)SL*("`@("`@("`D=&AI<RT^7V1B(#T@)D1".CIC;VYN96-T*"1T
M:&ES+3Y?<&%R86US+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)W!E<G-I<W1E;G0G(#T^("%E;7!T>2@D=&AI<RT^7W!A<F%M
M<ULG<&5R<VES=&5N="==*2DI.PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?
M9&(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L
M*%\H(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(BDL(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`O+R!3970@1$(@
M<&]R=&%B:6QI='D@;W!T:6]N<RX*("`@("`@("!S=VET8V@@*"1T:&ES+3Y?
M9&(M/G!H<'1Y<&4I('L*("`@("`@("!C87-E("=M<W-Q;"<Z"B`@("`@("`@
M("`@("1T:&ES+3Y?9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]0
M3U)404))3$E465],3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%4E)/4E,@
M?"!$0E]03U)404))3$E465]25%))32D["B`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("1T:&ES+3Y?9&(M/G-E=$]P
M=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)404))3$E465],3U=%4D-!4T4@
M?"!$0E]03U)404))3$E465]%4E)/4E,I.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/E]C;VYN96-T960@/2!T<G5E.PH@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+WEA:&]O+G!H<```````````
M````````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4P-C``,3`U,34T,S,W-3$`
M,#(R,C$U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!4:&4@075T:%]Y86AO;SHZ(&-L87-S(&-H96-K
M<R!L;V=I;B!C<F5D96YT:6%L<R!A9V%I;G-T(%EA:&]O(2!M86EL"B`J(&%C
M8V]U;G1S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]!=71H+T%U=&@O>6%H
M;V\N<&AP+'8@,2XQ,RXQ,BXW(#(P,#8O,#$O,#$@,C$Z,C@Z,#<@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!Y86AO;SHO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC
M92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]!=71H"B`J+PIC;&%S
M<R!!=71H7WEA:&]O(&5X=&5N9',@075T:"!["@H@("`@+RHJ"B`@("`@*B!`
M=F%R($A45%!?4F5Q=65S=`H@("`@("HO"B`@("!V87(@)%]H='1P.PH*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!986AO;R!A=71H96YT:6-A
M=&EO;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@($$@:&%S:"!C;VYT86EN:6YG('!A<F%M971E<G,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N($%U=&A?>6%H;V\H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1FEN9"!O=70@:68@82!S970@;V8@;&]G:6X@8W)E9&5N
M=&EA;',@87)E('9A;&ED+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@("!4
M:&4@=7-E<DED('1O(&-H96-K+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D8W)E
M9&5N=&EA;',@(%1H92!C<F5D96YT:6%L<R!T;R!U<V4N"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8W)E9&5N
M=&EA;',@87)E('9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!?875T:&5N
M=&EC871E*"1U<V5R260L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("!R
M97%U:7)E7V]N8V4@)TA45%`O4F5Q=65S="YP:'`G.PH*("`@("`@("`O+R!-
M86ME('-U<F4@=&AA="!W92!H879E(&$@8F%R92!U<V5R;F%M92`M('-T<FEP
M(&]F9B!A;GET:&EN9PH@("`@("`@("\O(&%F=&5R("AA;F0@:6YC;'5D:6YG
M*2!T:&4@9FER<W0@0"P@:68@=&AE<F4@:7,@;VYE+@H@("`@("`@("1P;W,@
M/2!S=')P;W,H)'5S97))9"P@)T`G*3L*("`@("`@("!I9B`H)'!O<R`A/3T@
M9F%L<V4I('L*("`@("`@("`@("`@)'5S97))9"`]('-U8G-T<B@D=7-E<DED
M+"`P+"`D<&]S*3L*("`@("`@("!]"@H@("`@("`@("1O<'1I;VYS6R=M971H
M;V0G72`]($A45%!?4D5154535%]-151(3T1?4$]35#L*("`@("`@("`D;W!T
M:6]N<ULG=&EM96]U="==(#T@-3L*("`@("`@("`D;W!T:6]N<ULG86QL;W=2
M961I<F5C=',G72`]('1R=64["@H@("`@("`@("1T:&ES+3Y?:'1T<"`]("9N
M97<@2%144%]297%U97-T*"=H='1P.B\O;&]G:6XN>6%H;V\N8V]M+V-O;F9I
M9R]L;V=I;B<L("1O<'1I;VYS*3L*("`@("`@("`D=&AI<RT^7VAT='`M/F%D
M9%!O<W1$871A*"=L;V=I;B<L("1U<V5R260I.PH@("`@("`@("1T:&ES+3Y?
M:'1T<"T^861D4&]S=$1A=&$H)W!A<W-W9"<L("1C<F5D96YT:6%L<ULG<&%S
M<W=O<F0G72D["@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VAT='`M/G-E
M;F1297%U97-T*"D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@)')E<W5L="T^9V5T
M365S<V%G92@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^7VAT='`M/F=E=%)E<W!O;G-E0F]D>2@I.PH@("`@("`@
M("`@("`D8V]O:VEE<R`]("1T:&ES+3Y?:'1T<"T^9V5T4F5S<&]N<V5#;V]K
M:65S*"D["B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D8V]O:VEE<RDI('L*
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1C;V]K:65S(&%S("1C;V]K:64I
M('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VAT='`M/F%D9$-O;VMI
M92@D8V]O:VEE6R=N86UE)UTL("1C;V]K:65;)W9A;'5E)UTI.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M+R!4:&ES(&ES(%]S=6-H7R!A(&AA8VLL(&)U="!I="!W;W)K<RX*("`@("`@
M("!I9B`H(7!R96=?;6%T8V@H)WQI;G9A;&ED('!A<W-W;W)D?&DG+"`D<F5S
M=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D<F5S=6QT+"!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@
M("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?0D%$3$]'24XI
M.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+T%U=&@N<&AP````````````````````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#$R-#$R,``Q,#4Q-30S,S<U,@`P,C$P-S8`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M(%1H92!P87)A;65T97(@;F%M92!F;W(@=&AE(&QO9V]U="!R96%S;VXN"B`J
M+PID969I;F4H)T%55$A?4D5!4T].7U!!4D%-)RP@)VQO9V]U=%]R96%S;VXG
M*3L*"B\J*@H@*B!4:&4@<&%R86UE=&5R(&YA;64@9F]R('1H92!L;V=O=70@
M;65S<V%G92!U<V5D('=I=&@@='EP90H@*B!!551(7U)%05-/3E]-15-304=%
M+@H@*B\*9&5F:6YE*"=!551(7U)%05-/3E]-4T=?4$%204TG+"`G;&]G;W5T
M7VUS9R<I.PH*+RHJ"B`J(%1H92`G8F%D;&]G:6XG(')E87-O;BX*("H*("H@
M5&AE(&9O;&QO=VEN9R`G<F5A<V]N<R<@9F]R('1H92!L;V=O=70@<V-R965N
M(&%R92!R96-O9VYI>F5D.@H@*B`\<')E/@H@*B`@("=B861L;V=I;B<@("`M
M+2`@0F%D('5S97)N86UE(&%N9"]O<B!P87-S=V]R9`H@*B`@("=B<F]W<V5R
M)R`@("`M+2`@02!B<F]W<V5R(&-H86YG92!W87,@9&5T96-T960*("H@("`G
M9F%I;&5D)R`@("`@+2T@($QO9VEN(&9A:6QE9`H@*B`@("=L;V=O=70G("`@
M("`M+2`@3&]G;W5T(&1U92!T;R!U<V5R(')E<75E<W0*("H@("`G;65S<V%G
M92<@("`@+2T@($QO9V]U="!W:71H(&-U<W1O;2!M97-S86=E(&EN($%55$A?
M4D5!4T].7TU31U]005)!30H@*B`@("=S97-S:6]N)R`@("`M+2`@3&]G;W5T
M(&1U92!T;R!S97-S:6]N(&5X<&ER871I;VX*("H@("`G<V5S<VEO;FEP)R`@
M+2T@($QO9V]U="!D=64@=&\@8VAA;F=E(&]F($E0(&%D9')E<W,@9'5R:6YG
M('-E<W-I;VX*("H@/"]P<F4^"B`J+PID969I;F4H)T%55$A?4D5!4T].7T)!
M1$Q/1TE.)RP@)V)A9&QO9VEN)RD["@HO*BH*("H@5&AE("=B<F]W<V5R)R!R
M96%S;VXN"B`J+PID969I;F4H)T%55$A?4D5!4T].7T)23U=315(G+"`G8G)O
M=W-E<B<I.PH*+RHJ"B`J(%1H92`G9F%I;&5D)R!R96%S;VXN"B`J+PID969I
M;F4H)T%55$A?4D5!4T].7T9!24Q%1"<L("=F86EL960G*3L*"B\J*@H@*B!4
M:&4@)V5X<&ER960G(')E87-O;BX*("HO"F1E9FEN92@G05542%]214%33TY?
M15A025)%1"<L("=E>'!I<F5D)RD["@HO*BH*("H@5&AE("=L;V=O=70G(')E
M87-O;BX*("HO"F1E9FEN92@G05542%]214%33TY?3$]'3U54)RP@)VQO9V]U
M="<I.PH*+RHJ"B`J(%1H92`G;65S<V%G92<@<F5A<V]N+@H@*B\*9&5F:6YE
M*"=!551(7U)%05-/3E]-15-304=%)RP@)VUE<W-A9V4G*3L*"B\J*@H@*B!4
M:&4@)W-E<W-I;VXG(')E87-O;BX*("HO"F1E9FEN92@G05542%]214%33TY?
M4T534TE/3B<L("=S97-S:6]N)RD["@HO*BH*("H@5&AE("=S97-S:6]N:7`G
M(')E87-O;BX*("HO"F1E9FEN92@G05542%]214%33TY?4T534TE/3DE0)RP@
M)W-E<W-I;VYI<"<I.PH*+RHJ"B`J(%1H92!!=71H.CH@8VQA<W,@<')O=FED
M97,@82!C;VUM;VX@86)S=')A8W1E9"!I;G1E<F9A8V4@:6YT;R!T:&4@=F%R
M:6]U<PH@*B!B86-K96YD<R!F;W(@=&AE($AO<F1E(&%U=&AE;G1I8V%T:6]N
M('-Y<W1E;2X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<"QV(#$N,30R+C$P+C(S(#(P,#8O,#@O,30@,#(Z-#@Z-#@@8VAU8VL@17AP
M("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@
M("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@
M075T:"!["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL:71I
M97,L('-O('1H870@=&AE(&1R:79E<B!C86X@<F5P;W)T('=H:6-H"B`@("`@
M*B!O<&5R871I;VYS(&ET('-U<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S;B=T
M+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1C
M87!A8FEL:71I97,@/2!A<G)A>2@G861D)R`@("`@("`@("`@/3X@9F%L<V4L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U<&1A=&4G("`@("`@
M("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E
M<V5T<&%S<W=O<F0G(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<F5M;W9E)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=L:7-T)R`@("`@("`@("`]/B!F86QS92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V=R;W5P<R<@("`@("`@
M(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=')A
M;G-P87)E;G0G("`@/3X@9F%L<V4I.PH*("`@("\J*@H@("`@("H@2&%S:"!C
M;VYT86EN:6YG('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@I.PH*("`@("\J
M*@H@("`@("H@5&AE(&-R961E;G1I86QS(&-U<G)E;G1L>2!B96EN9R!A=71H
M96YT:6-A=&5D+@H@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]A=71H
M0W)E9&5N=&EA;',@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@;F%M92!O9B!T:&4@8V]N8W)E=&4@075T:"!I;7!L96UE;G1A=&EO
M;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($%U=&@@:6UP
M;&5M96YT871I;VX@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1')I
M=F5R*"D*("`@('L*("`@("`@("!R971U<FX@<W1R7W)E<&QA8V4H)V%U=&A?
M)RP@)R<L('-T<G1O;&]W97(H9V5T7V-L87-S*"1T:&ES*2DI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1FEN9',@;W5T(&EF(&$@<V5T(&]F(&QO9VEN(&-R
M961E;G1I86QS(&%R92!V86QI9"P@86YD(&EF(')E<75E<W1E9"P*("`@("`J
M(&UA<FL@=&AE('5S97(@87,@;&]G9V5D(&EN(&EN('1H92!C=7)R96YT('-E
M<W-I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@
M("`@5&AE('5S97))9"!T;R!C:&5C:RX*("`@("`J($!P87)A;2!A<G)A>2`D
M8W)E9&5N=&EA;',@(%1H92!C<F5D96YT:6%L<R!T;R!C:&5C:RX*("`@("`J
M($!P87)A;2!B;V]L96%N("1L;V=I;B`@("`@(%=H971H97(@=&\@;&]G('1H
M92!U<V5R(&EN+B!)9B!F86QS92P@=V4G;&P*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&]N;'D@=&5S="!T:&4@8W)E9&5N=&EA;',@86YD
M('=O;B=T(&UO9&EF>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@=&AE(&-U<G)E;G0@<V5S<VEO;BX@1&5F875L=',@=&\@=')U92X*("`@
M("`J($!P87)A;2!S=')I;F<@)')E86QM("`@("`@(%1H92!A=71H96YT:6-A
M=&EO;B!R96%L;2!T;R!C:&5C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%=H971H97(@;W(@;F]T('1H92!C<F5D96YT:6%L<R!A<F4@=F%L
M:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%U=&AE;G1I8V%T92@D=7-E<DED
M+"`D8W)E9&5N=&EA;',L("1L;V=I;B`]('1R=64L("1R96%L;2`](&YU;&PI
M"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("`D875T:"`]
M(&9A;'-E.PH@("`@("`@("1U<V5R260@/2!T<FEM*"1U<V5R260I.PH*("`@
M("`@("!I9B`H(65M<'1Y*"1C;VYF6R=H;V]K<R==6R=P<F5A=71H96YT:6-A
M=&4G72DI('L*("`@("`@("`@("`@:6YC;'5D95]O;F-E($A/4D1%7T)!4T4@
M+B`G+V-O;F9I9R]H;V]K<RYP:'`G.PH@("`@("`@("`@("!I9B`H9G5N8W1I
M;VY?97AI<W1S*"=?:&]R9&5?:&]O:U]P<F5A=71H96YT:6-A=&4G*2D@>PH@
M("`@("`@("`@("`@("`@:68@*"%C86QL7W5S97)?9G5N8R@G7VAO<F1E7VAO
M;VM?<')E875T:&5N=&EC871E)RP@)'5S97))9"P@)&-R961E;G1I86QS+"`D
M<F5A;&TI*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?9V5T
M075T:$5R<F]R*"D@(3T@05542%]214%33TY?34534T%'12D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%
M05-/3E]&04E,140I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%-T;W)E('1H92!C
M<F5D96YT:6%L<R!B96EN9R!C:&5C:V5D('-O('1H870@<W5B8VQA<W-E<R!C
M86X@;6]D:69Y"B`@("`@("`@("H@=&AE;2!I9B!N96-E<W-A<GD@*&QI:V4@
M=')A;G-P87)E;G0@875T:"!D;V5S*2X@*B\*("`@("`@("`D=&AI<RT^7V%U
M=&A#<F5D96YT:6%L<R`](&%R<F%Y*`H@("`@("`@("`@("`G=7-E<DED)R`]
M/B`D=7-E<DED+`H@("`@("`@("`@("`G8W)E9&5N=&EA;',G(#T^("1C<F5D
M96YT:6%L<RP*("`@("`@("`@("`@)W)E86QM)R`]/B`D<F5A;&TL"B`@("`@
M("`@("`@("=C:&%N9V5297%U97-T960G(#T^(&9A;'-E"B`@("`@("`@*3L*
M"B`@("`@("`@:68@*"1A=71H96YT:6-A=&5D(#T@)'1H:7,M/E]A=71H96YT
M:6-A=&4H)'5S97))9"P@)&-R961E;G1I86QS*2D@>PH@("`@("`@("`@("!I
M9B`H:7-?82@D875T:&5N=&EC871E9"P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("@A96UP='DH)&-O;F9;)VAO;VMS)UU;)W!O<W1A=71H96YT
M:6-A=&4G72DI('L*("`@("`@("`@("`@("`@(&EN8VQU9&5?;VYC92!(3U)$
M15]"05-%("X@)R]C;VYF:6<O:&]O:W,N<&AP)SL*("`@("`@("`@("`@("`@
M(&EF("AF=6YC=&EO;E]E>&ES=',H)U]H;W)D95]H;V]K7W!O<W1A=71H96YT
M:6-A=&4G*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@A8V%L;%]U<V5R
M7V9U;F,H)U]H;W)D95]H;V]K7W!O<W1A=71H96YT:6-A=&4G+"`D=7-E<DED
M+"`D8W)E9&5N=&EA;',L("1R96%L;2DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"1T:&ES+3Y?9V5T075T:$5R<F]R*"D@(3T@05542%]214%3
M3TY?34534T%'12D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?1D%)3$5$*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&QO9VEN
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T075T:"@D=&AI<RT^7V%U
M=&A#<F5D96YT:6%L<ULG=7-E<DED)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V%U=&A#<F5D96YT:6%L<ULG8W)E9&5N=&EA
M;',G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M875T:$-R961E;G1I86QS6R=R96%L;2==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]A=71H0W)E9&5N=&EA;'-;)V-H86YG95)E
M<75E<W1E9"==*3L*("`@("`@("`@("`@("`@("1A=71H(#T@=')U93L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M
M/E]C:&5C:U-E<W-I;VY)4"@I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?4T534TE/3DE0*3L*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H(21T:&ES+3Y?8VAE8VM"<F]W<V5R4W1R:6YG*"DI('L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(
M7U)%05-/3E]"4D]74T52*3L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D875T
M:"`]('1R=64["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D875T:#L*("`@('T*"B`@("`O*BH*("`@("`J($9O<FUA=',@82!P
M87-S=V]R9"!U<VEN9R!T:&4@8W5R<F5N="!E;F-R>7!T:6]N+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'!L86EN=&5X="`@("`@(%1H92!P;&%I
M;G1E>'0@<&%S<W=O<F0@=&\@96YC<GEP="X*("`@("`J($!P87)A;2!S=')I
M;F<@)'-A;'0@("`@("`@("`@(%1H92!S86QT('1O('5S92!T;R!E;F-R>7!T
M('1H92!P87-S=V]R9"X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@($EF(&YO="!P<F5S96YT+"!A(&YE=R!S86QT('=I;&P@8F4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&=E;F5R871E9"X*
M("`@("`J($!P87)A;2!S=')I;F<@)&5N8W)Y<'1I;VX@("`@(%1H92!K:6YD
M(&]F('!A<W=O<F0@96YC<GEP=&EO;B!T;R!U<V4N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!$969A=6QT<R!T;R!M9#4M:&5X+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)'-H;W=?96YC<GEP="`@4V]M92!P87-S
M=V]R9"!S>7-T96US('!R97!E;F0@=&AE(&MI;F0@;V8*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&5N8W)Y<'1I;VX@=&\@=&AE(&-R
M>7!T960@<&%S<W=O<F0@*'M32$%]+`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@971C*2X@1&5F875L=',@=&\@9F%L<V4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!E;F-R>7!T960@<&%S<W=O
M<F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-R>7!T961087-S=V]R9"@D
M<&QA:6YT97AT+"`D<V%L="`]("<G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1E;F-R>7!T:6]N(#T@)VUD-2UH97@G+"`D<VAO=U]E;F-R
M>7!T(#T@9F%L<V4I"B`@("!["B`@("`@("`@+RH@1V5T('1H92!S86QT('1O
M('5S92X@*B\*("`@("`@("`D<V%L="`]($%U=&@Z.F=E=%-A;'0H)&5N8W)Y
M<'1I;VXL("1S86QT+"`D<&QA:6YT97AT*3L*"B`@("`@("`@+RH@16YC<GEP
M="!T:&4@<&%S<W=O<F0N("HO"B`@("`@("`@<W=I=&-H("@D96YC<GEP=&EO
M;BD@>PH@("`@("`@(&-A<V4@)W!L86EN)SH*("`@("`@("`@("`@<F5T=7)N
M("1P;&%I;G1E>'0["@H@("`@("`@(&-A<V4@)VUS860G.@H@("`@("`@("`@
M("!R971U<FX@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@G(B<@+B`D<&QA:6YT
M97AT("X@)R(G+"`G25-/+3@X-3DM,2<L("=55$8M,39,12<I.PH*("`@("`@
M("!C87-E("=S:&$G.@H@("`@("`@("`@("`D96YC<GEP=&5D(#T@8F%S938T
M7V5N8V]D92AM:&%S:"A-2$%32%]32$$Q+"`D<&QA:6YT97AT*2D["B`@("`@
M("`@("`@(')E='5R;B`H)'-H;W=?96YC<GEP="D@/R`G>U-(07TG("X@)&5N
M8W)Y<'1E9"`Z("1E;F-R>7!T960["@H@("`@("`@(&-A<V4@)V-R>7!T)SH*
M("`@("`@("!C87-E("=C<GEP="UD97,G.@H@("`@("`@(&-A<V4@)V-R>7!T
M+6UD-2<Z"B`@("`@("`@8V%S92`G8W)Y<'0M8FQO=V9I<V@G.@H@("`@("`@
M("`@("!R971U<FX@*"1S:&]W7V5N8W)Y<'0@/R`G>V-R>7!T?2<@.B`G)RD@
M+B!C<GEP="@D<&QA:6YT97AT+"`D<V%L="D["@H@("`@("`@(&-A<V4@)VUD
M-2UB87-E-C0G.@H@("`@("`@("`@("`D96YC<GEP=&5D(#T@8F%S938T7V5N
M8V]D92AM:&%S:"A-2$%32%]-1#4L("1P;&%I;G1E>'0I*3L*("`@("`@("`@
M("`@<F5T=7)N("@D<VAO=U]E;F-R>7!T*2`_("=[340U?2<@+B`D96YC<GEP
M=&5D(#H@)&5N8W)Y<'1E9#L*"B`@("`@("`@8V%S92`G<W-H82<Z"B`@("`@
M("`@("`@("1E;F-R>7!T960@/2!B87-E-C1?96YC;V1E*&UH87-H*$U(05-(
M7U-(03$L("1P;&%I;G1E>'0@+B`D<V%L="D@+B`D<V%L="D["B`@("`@("`@
M("`@(')E='5R;B`H)'-H;W=?96YC<GEP="D@/R`G>U-32$%])R`N("1E;F-R
M>7!T960@.B`D96YC<GEP=&5D.PH*("`@("`@("!C87-E("=S;60U)SH*("`@
M("`@("`@("`@)&5N8W)Y<'1E9"`](&)A<V4V-%]E;F-O9&4H;6AA<V@H34A!
M4TA?340U+"`D<&QA:6YT97AT("X@)'-A;'0I("X@)'-A;'0I.PH@("`@("`@
M("`@("!R971U<FX@*"1S:&]W7V5N8W)Y<'0I(#\@)WM3340U?2<@+B`D96YC
M<GEP=&5D(#H@)&5N8W)Y<'1E9#L*"B`@("`@("`@8V%S92`G87!R;60U)SH*
M("`@("`@("`@("`@)&QE;F=T:"`]('-T<FQE;B@D<&QA:6YT97AT*3L*("`@
M("`@("`@("`@)&-O;G1E>'0@/2`D<&QA:6YT97AT("X@)R1A<'(Q)"<@+B`D
M<V%L=#L*("`@("`@("`@("`@)&)I;F%R>2`]($%U=&@Z.E]B:6XH;60U*"1P
M;&%I;G1E>'0@+B`D<V%L="`N("1P;&%I;G1E>'0I*3L*"B`@("`@("`@("`@
M(&9O<B`H)&D@/2`D;&5N9W1H.R`D:2`^(#`[("1I("T](#$V*2!["B`@("`@
M("`@("`@("`@("`D8V]N=&5X="`N/2!S=6)S='(H)&)I;F%R>2P@,"P@*"1I
M(#X@,38@/R`Q-B`Z("1I*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M9F]R("@D:2`]("1L96YG=&@[("1I(#X@,#L@)&D@/CX](#$I('L*("`@("`@
M("`@("`@("`@("1C;VYT97AT("X]("@D:2`F(#$I(#\@8VAR*#`I(#H@)'!L
M86EN=&5X='LP?3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&)I;F%R
M>2`]($%U=&@Z.E]B:6XH;60U*"1C;VYT97AT*2D["@H@("`@("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"`Q,#`P.R`D:2LK*2!["B`@("`@("`@("`@("`@
M("`D;F5W(#T@*"1I("8@,2D@/R`D<&QA:6YT97AT(#H@<W5B<W1R*"1B:6YA
M<GDL(#`L,38I.PH@("`@("`@("`@("`@("`@:68@*"1I("4@,RD@>PH@("`@
M("`@("`@("`@("`@("`@("1N97<@+CT@)'-A;'0["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!I9B`H)&D@)2`W*2!["B`@("`@("`@("`@
M("`@("`@("`@)&YE=R`N/2`D<&QA:6YT97AT.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)&YE=R`N/2`H)&D@)B`Q*2`_('-U8G-T<B@D
M8FEN87)Y+"`P+"`Q-BD@.B`D<&QA:6YT97AT.PH@("`@("`@("`@("`@("`@
M)&)I;F%R>2`]($%U=&@Z.E]B:6XH;60U*"1N97<I*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@)'`@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W(@
M*"1I(#T@,#L@)&D@/"`U.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D:R`]
M("1I("L@-CL*("`@("`@("`@("`@("`@("1J(#T@)&D@*R`Q,CL*("`@("`@
M("`@("`@("`@(&EF("@D:B`]/2`Q-BD@>PH@("`@("`@("`@("`@("`@("`@
M("1J(#T@-3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1P
M6UT@/2!!=71H.CI?=&]!4%)-1#4H*&]R9"@D8FEN87)Y6R1I72D@/#P@,38I
M('P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*&]R
M9"@D8FEN87)Y6R1K72D@/#P@."D@?`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`H;W)D*"1B:6YA<GE;)&I=*2DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#4I.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!R971U<FX@)R1A<'(Q)"<@+B`D<V%L="`N("<D
M)R`N(&EM<&QO9&4H)R<L("1P*2`N($%U=&@Z.E]T;T%04DU$-2AO<F0H)&)I
M;F%R>5LQ,5TI+"`S*3L*"B`@("`@("`@8V%S92`G;60U+6AE>"<Z"B`@("`@
M("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N("@D<VAO=U]E;F-R>7!T
M*2`_("=[340U?2<@+B!M9#4H)'!L86EN=&5X="D@.B!M9#4H)'!L86EN=&5X
M="D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A
M('-A;'0@9F]R('1H92!A<'!R;W!R:6%T92!K:6YD(&]F('!A<W-W;W)D(&5N
M8W)Y<'1I;VXN"B`@("`@*B!/<'1I;VYA;&QY('1A:V5S(&$@<V5E9"!A;F0@
M82!P;&%I;G1E>'0@<&%S<W=O<F0L('1O(&5X=')A8W0@=&AE('-E960*("`@
M("`J(&]F(&%N(&5X:7-T:6YG('!A<W-W;W)D+"!O<B!F;W(@96YC<GEP=&EO
M;B!T>7!E<R!T:&%T('5S92!T:&4@<&QA:6YT97AT"B`@("`@*B!I;B!T:&4@
M9V5N97)A=&EO;B!O9B!T:&4@<V%L="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1E;F-R>7!T:6]N("!4:&4@:VEN9"!O9B!P87-W;W)D(&5N8W)Y
M<'1I;VX@=&\@=7-E+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@1&5F875L=',@=&\@;60U+6AE>"X*("`@("`J($!P87)A;2!S=')I;F<@
M)'-E960@("`@("`@(%1H92!S965D('1O(&=E="!T:&4@<V%L="!F<F]M("AP
M<F]B86)L>2!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!P
M<F5V:6]U<VQY(&=E;F5R871E9"!P87-S=V]R9"DN($1E9F%U;'1S('1O"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!G96YE<F%T:6YG(&$@
M;F5W('-E960N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P;&%I;G1E>'0@("!4
M:&4@<&QA:6YT97AT('!A<W-W;W)D('1H870@=V4G<F4@9V5N97)A=&EN9PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@82!S86QT(&9O<BX@
M1&5F875L=',@=&\@;F]N92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&=E;F5R871E9"!O<B!E>'1R86-T960@<V%L="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T4V%L="@D96YC<GEP=&EO;B`]("=M9#4M:&5X)RP@
M)'-E960@/2`G)RP@)'!L86EN=&5X="`]("<G*0H@("`@>PH@("`@("`@("\O
M($5N8W)Y<'0@=&AE('!A<W-W;W)D+@H@("`@("`@('-W:71C:"`H)&5N8W)Y
M<'1I;VXI('L*("`@("`@("!C87-E("=C<GEP="<Z"B`@("`@("`@8V%S92`G
M8W)Y<'0M9&5S)SH*("`@("`@("`@("`@:68@*"1S965D*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@<W5B<W1R*'!R96=?<F5P;&%C92@G?%Y[8W)Y<'1]
M?&DG+"`G)RP@)'-E960I+"`P+"`R*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@(')E='5R;B!S=6)S='(H;60U*&UT7W)A;F0H*2DL
M(#`L(#(I.PH@("`@("`@("`@("!]"@H@("`@("`@(&-A<V4@)V-R>7!T+6UD
M-2<Z"B`@("`@("`@("`@(&EF("@D<V5E9"D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N('-U8G-T<BAP<F5G7W)E<&QA8V4H)WQ>>V-R>7!T?7QI)RP@)R<L
M("1S965D*2P@,"P@,3(I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("<D,20G("X@<W5B<W1R*&UD-2AM=%]R86YD*"DI
M+"`P+"`X*2`N("<D)SL*("`@("`@("`@("`@?0H*("`@("`@("!C87-E("=C
M<GEP="UB;&]W9FES:"<Z"B`@("`@("`@("`@(&EF("@D<V5E9"D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N('-U8G-T<BAP<F5G7W)E<&QA8V4H)WQ>>V-R
M>7!T?7QI)RP@)R<L("1S965D*2P@,"P@,38I.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N("<D,B0G("X@<W5B<W1R*&UD
M-2AM=%]R86YD*"DI+"`P+"`Q,BD@+B`G)"<["B`@("`@("`@("`@('T*"B`@
M("`@("`@8V%S92`G<W-H82<Z"B`@("`@("`@("`@(&EF("@D<V5E9"D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N('-U8G-T<BAP<F5G7W)E<&QA8V4H)WQ>
M>U-32$%]?"<L("<G+"`D<V5E9"DL("TR,"D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!R971U<FX@;6AA<VA?:V5Y9V5N7W,R:RA-
M2$%32%]32$$Q+"`D<&QA:6YT97AT+"!S=6)S='(H<&%C:R@G:"HG+"!M9#4H
M;71?<F%N9"@I*2DL(#`L(#@I+"`T*3L*("`@("`@("`@("`@?0H*("`@("`@
M("!C87-E("=S;60U)SH*("`@("`@("`@("`@:68@*"1S965D*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@<W5B<W1R*'!R96=?<F5P;&%C92@G?%Y[4TU$
M-7U\)RP@)R<L("1S965D*2P@+3$V*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@(')E='5R;B!M:&%S:%]K97EG96Y?<S)K*$U(05-(
M7TU$-2P@)'!L86EN=&5X="P@<W5B<W1R*'!A8VLH)V@J)RP@;60U*&UT7W)A
M;F0H*2DI+"`P+"`X*2P@-"D["B`@("`@("`@("`@('T*"B`@("`@("`@8V%S
M92`G87!R;60U)SH*("`@("`@("`@("`@+RH@-C0@8VAA<F%C=&5R<R!T:&%T
M(&%R92!V86QI9"!F;W(@05!2340U('!A<W-W;W)D<RX@*B\*("`@("`@("`@
M("`@)$%04DU$-2`]("<N+S`Q,C,T-38W.#E!0D-$149'2$E*2TQ-3D]045)3
M5%565UA96F%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ)SL*"B`@("`@("`@
M("`@(&EF("@D<V5E9"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N('-U8G-T
M<BAP<F5G7W)E<&QA8V4H)R]>7"1A<'(Q7"0H+GLX?2DN*B\G+"`G7%PQ)RP@
M)'-E960I+"`P+"`X*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1S86QT(#T@)R<["B`@("`@("`@("`@("`@("!F;W(@*"1I(#T@
M,#L@)&D@/"`X.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@)'-A;'0@
M+CT@)$%04DU$-7MR86YD*#`L(#8S*7T["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!R971U<FX@)'-A;'0["B`@("`@("`@("`@('T*"B`@
M("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E<R!A(')A;F1O;2P@
M:&]P969U;&QY('!R;VYO=6YC96%B;&4L('!A<W-W;W)D+B!4:&ES(&-A;B!B
M92!U<V5D"B`@("`@*B!W:&5N(')E<V5T=&EN9R!A=71O;6%T:6-A;&QY(&$@
M=7-E<B=S('!A<W-W;W)D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M($$@<F%N9&]M('!A<W-W;W)D"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E;E)A
M;F1O;5!A<W-W;W)D*"D*("`@('L*("`@("`@("`D=F]W96QS("`@(#T@)V%E
M:6]U>2<["B`@("`@("`@)&-O;G-T86YT<R`]("=B8V1F9VAJ:VQM;G!Q<G-T
M=G=X>B<["B`@("`@("`@)&YU;6)E<G,@("`]("<P,3(S-#4V-S@Y)SL*"B`@
M("`@("`@+RH@06QT97)N871E(&-O;G-T86YT(&%N9"!V;W=E;"!R86YD;VT@
M8VAA<G,@=VET:"!T=V\@<F%N9&]M(&YU;6)E<G,*("`@("`@("`@*B!A="!T
M:&4@96YD+B!4:&ES('-H;W5L9"!P<F]D=6-E(&$@9F%I<FQY('!R;VYO=6YC
M96%B;&4@<&%S<W=O<F0N("HO"B`@("`@("`@)&-H87)S6S!=(#T@<W5B<W1R
M*"1C;VYS=&%N=',L(&UT7W)A;F0H,"P@<W1R;&5N*"1C;VYS=&%N=',I("T@
M,2DL(#$I.PH@("`@("`@("1C:&%R<ULQ72`]('-U8G-T<B@D=F]W96QS+"!M
M=%]R86YD*#`L('-T<FQE;B@D=F]W96QS*2`M(#$I+"`Q*3L*("`@("`@("`D
M8VAA<G-;,ET@/2!S=6)S='(H)&-O;G-T86YT<RP@;71?<F%N9"@P+"!S=')L
M96XH)&-O;G-T86YT<RD@+2`Q*2P@,2D["B`@("`@("`@)&-H87)S6S-=(#T@
M<W5B<W1R*"1V;W=E;',L(&UT7W)A;F0H,"P@<W1R;&5N*"1V;W=E;',I("T@
M,2DL(#$I.PH@("`@("`@("1C:&%R<ULT72`]('-U8G-T<B@D8V]N<W1A;G1S
M+"!M=%]R86YD*#`L('-T<FQE;B@D8V]N<W1A;G1S*2`M(#$I+"`Q*3L*("`@
M("`@("`D8VAA<G-;-5T@/2!S=6)S='(H)&YU;6)E<G,L(&UT7W)A;F0H,"P@
M<W1R;&5N*"1N=6UB97)S*2`M(#$I+"`Q*3L*("`@("`@("`D8VAA<G-;-ET@
M/2!S=6)S='(H)&YU;6)E<G,L(&UT7W)A;F0H,"P@<W1R;&5N*"1N=6UB97)S
M*2`M(#$I+"`Q*3L*"B`@("`@("`@<F5T=7)N(&EM<&QO9&4H)R<L("1C:&%R
M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@<V5T(&]F(&%U=&AE
M;G1I8V%T:6]N(&-R961E;G1I86QS+@H@("`@("H*("`@("`J($!A8G-T<F%C
M=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@(%1H
M92!U<V5R260@=&\@861D+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT
M:6%L<R`@5&AE(&-R961E;G1I86QS('1O('5S92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&15
M<V5R*"1U<V5R260L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G=6YS=7!P;W)T960G*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%5P9&%T97,@82!S970@;V8@875T:&5N=&EC871I;VX@
M8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;VQD240@("`@("`@(%1H92!O;&0@=7-E
M<DED+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W240@("`@("`@(%1H92!N
M97<@=7-E<DED+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@
M(%1H92!N97<@8W)E9&5N=&EA;',*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!U<&1A=&55<V5R*"1O
M;&1)1"P@)&YE=TE$+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)W5N<W5P<&]R=&5D)RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@<V5T(&]F(&%U=&AE;G1I8V%T:6]N
M(&-R961E;G1I86QS+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@5&AE('5S97))9"!T;R!D
M96QE=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S
M=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E57-E<B@D=7-E<DED*0H@("`@>PH@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=U;G-U<'!O<G1E9"<I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0V%L;',@86QL(&%P<&QI8V%T:6]N
M<R<@<F5M;W9E57-E<B!!4$D@;65T:&]D<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1U<V5R260@(%1H92!U<V5R260@=&\@9&5L971E+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A
M(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(')E;6]V955S97)$871A*"1U<V5R260I"B`@("!["B`@("`@("`@
M9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@9F]R96%C:"`H)')E9VES=')Y
M+3YL:7-T07!P<RAA<G)A>2@G;F]T;V]L8F%R)RP@)VAI9&1E;B<L("=A8W1I
M=F4G+"`G861M:6XG*2D@87,@)&%P<"D@>PH@("`@("`@("`@("!I9B`H)')E
M9VES=')Y+3YH87--971H;V0H)W)E;6]V955S97)$871A)RP@)&%P<"DI('L*
M("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D<F5G:7-T<GDM
M/F-A;&Q">5!A8VMA9V4H)&%P<"P@)W)E;6]V955S97)$871A)RP@87)R87DH
M)'5S97))9"DI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*
M"B`@("`O*BH*("`@("`J($QI<W1S(&%L;"!U<V5R<R!I;B!T:&4@<WES=&5M
M+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%1H92!A<G)A>2!O9B!U<V5R261S+"!O<B!A(%!%05)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI
M<W15<V5R<R@I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)W5N<W5P<&]R=&5D)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C
M:W,@:68@)'5S97))9"!E>&ES=',@:6X@=&AE('-Y<W1E;2X*("`@("`J"B`@
M("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U
M<V5R260@57-E<B!)1"!F;W(@=VAI8V@@=&\@8VAE8VL*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T("1U<V5R260@86QR
M96%D>2!E>&ES=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X:7-T<R@D=7-E
M<DED*0H@("`@>PH@("`@("`@(')E='5R;B!I;E]A<G)A>2@D=7-E<DED+"`D
M=&AI<RT^;&ES=%5S97)S*"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@075T
M;VUA=&EC(&%U=&AE;G1I8V%T:6]N.B!&:6YD<R!O=70@:68@=&AE(&-L:65N
M="!M871C:&5S(&%N(&%L;&]W960@25`*("`@("`J(&)L;V-K+@H@("`@("H*
M("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-L:65N="!I<R!A;&QO=V5D+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!T<F%N<W!A<F5N="@I"B`@("!["B`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS(&EF
M('1H97)E(&ES(&$@<V5S<VEO;B!W:71H('9A;&ED(&%U=&@@:6YF;W)M871I
M;VXN(&9O<B!T:&4*("`@("`J('-P96-I9FEE9"!U<V5R+B!)9B!T:&5R92!I
M<VXG="P@8G5T('1H92!C;VYF:6=U<F5D($%U=&@@9')I=F5R('-U<'!O<G1S
M"B`@("`@*B!T<F%N<W!A<F5N="!A=71H96YT:6-A=&EO;BP@=&AE;B!W92!T
M<GD@=&AA="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1R96%L;2`@
M5&AE(&%U=&AE;G1I8V%T:6]N(')E86QM('1O(&-H96-K+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE('5S97(@
M:7,@875T:&5N=&EC871E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-!=71H
M96YT:6-A=&5D*"1R96%L;2`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES
M<V5T*"1?4T534TE/3ELG7U]A=71H)UTI*2!["B`@("`@("`@("`@(&EF("@A
M96UP='DH)%]315-324].6R=?7V%U=&@G75LG875T:&5N=&EC871E9"==*2`F
M)@H@("`@("`@("`@("`@("`@(65M<'1Y*"1?4T534TE/3ELG7U]A=71H)UU;
M)W5S97))9"==*2`F)@H@("`@("`@("`@("`@("`@*"1?4T534TE/3ELG7U]A
M=71H)UU;)W)E86QM)UT@/3T@)')E86QM*2D@>PH@("`@("`@("`@("`@("`@
M:68@*"%!=71H.CI?8VAE8VM397-S:6]N25`H*2D@>PH@("`@("`@("`@("`@
M("`@("`@($%U=&@Z.E]S971!=71H17)R;W(H05542%]214%33TY?4T534TE/
M3DE0*3L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H(4%U=&@Z.E]C:&5C:T)R;W=S97)3=')I
M;F<H*2D@>PH@("`@("`@("`@("`@("`@("`@($%U=&@Z.E]S971!=71H17)R
M;W(H05542%]214%33TY?0E)/5U-%4BD["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@5')Y('1R86YS
M<&%R96YT(&%U=&AE;G1I8V%T:6]N(&YO=RX*("`@("`@("`D875T:"`]("9!
M=71H.CIS:6YG;&5T;VXH)$=,3T)!3%-;)V-O;F8G75LG875T:"==6R=D<FEV
M97(G72D["B`@("`@("`@:68@*"1A=71H+3YH87-#87!A8FEL:71Y*"=T<F%N
M<W!A<F5N="<I("8F"B`@("`@("`@("`@("1A=71H+3YT<F%N<W!A<F5N="@I
M*2!["B`@("`@("`@("`@(')E='5R;B!!=71H.CII<T%U=&AE;G1I8V%T960H
M)')E86QM*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-U<G)E;G1L>2!L;V=G
M960@:6X@=7-E<BP@:68@=&AE<F4@:7,@;VYE+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1H92!U<V5R260@;V8@=&AE(&-U<G)E;G0@=7-E<BP@
M;W(@9F%L<V4@:68@;F\@=7-E<B!I<PH@("`@("H@("`@("`@("`@("`@("`@
M;&]G9V5D(&EN+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!=71H*"D*("`@
M('L*("`@("`@("!I9B`H:7-S970H)%]315-324].6R=?7V%U=&@G72DI('L*
M("`@("`@("`@("`@:68@*"%E;7!T>2@D7U-%4U-)3TY;)U]?875T:"==6R=A
M=71H96YT:6-A=&5D)UTI("8F"B`@("`@("`@("`@("`@("`A96UP='DH)%]3
M15-324].6R=?7V%U=&@G75LG=7-E<DED)UTI*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)%]315-324].6R=?7V%U=&@G75LG=7-E<DED)UT["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!W:&5T:&5R('1H92!A=71H96YT
M:6-A=&EO;B!B86-K96YD(')E<75E<W1E9"!A('!A<W-W;W)D(&-H86YG92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@5VAE=&AE<B!T:&4@8F%C
M:V5N9"!R97%U97-T960@82!P87-S=V]R9"!C:&%N9V4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&ES4&%S<W=O<F1#:&%N9V5297%U97-T960H*0H@("`@>PH@
M("`@("`@(&EF("AI<W-E="@D7U-%4U-)3TY;)U]?875T:"==*2`F)@H@("`@
M("`@("`@("`A96UP='DH)%]315-324].6R=?7V%U=&@G75LG875T:&5N=&EC
M871E9"==*2`F)@H@("`@("`@("`@("`A96UP='DH)%]315-324].6R=?7V%U
M=&@G75LG8VAA;F=E4F5Q=65S=&5D)UTI*2!["B`@("`@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8W5R96YT;'D@;&]G9V5D
M+6EN('5S97(@=VET:&]U="!A;GD@9&]M86EN(&EN9F]R;6%T:6]N"B`@("`@
M*B`H92YG+BP@8F]B0&5X86UP;&4N8V]M('=O=6QD(&)E(')E='5R;F5D(&%S
M("=B;V(G*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@=7-E
M<B!)1"!O9B!T:&4@8W5R<F5N="!U<V5R+"!O<B!F86QS92!I9B!N;R!U<V5R
M"B`@("`@*B`@("`@("`@("`@("`@("!I<R!L;V=G960@:6XN"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$)A<F5!=71H*"D*("`@('L*("`@("`@("`D=7-E
M<B`]($%U=&@Z.F=E=$%U=&@H*3L*("`@("`@("!I9B`H)'5S97(I('L*("`@
M("`@("`@("`@)'!O<R`]('-T<G!O<R@D=7-E<BP@)T`G*3L*("`@("`@("`@
M("`@:68@*"1P;W,@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D=7-E
M<B`]('-U8G-T<B@D=7-E<BP@,"P@)'!O<RD["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D=7-E<CL*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE(&1O;6%I;B!O9B!C=7)R96YT;'D@;&]G9V5D
M+6EN('5S97(@*&4N9RXL(&)O8D!E>&%M<&QE+F-O;0H@("`@("H@=V]U;&0@
M8F4@<F5T=7)N960@87,@)V5X86UP;&4N8V]M)RDN"B`@("`@*@H@("`@("H@
M0'-I;F-E($AO<F1E(#,N,"XV"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5&AE(&1O;6%I;B!S=69F:7@@;V8@=&AE(&-U<G)E;G0@=7-E<BP@;W(@
M9F%L<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%U=&A$;VUA:6XH*0H@
M("`@>PH@("`@("`@(&EF("@D=7-E<B`]($%U=&@Z.F=E=$%U=&@H*2D@>PH@
M("`@("`@("`@("`D<&]S(#T@<W1R<&]S*"1U<V5R+"`G0"<I.PH@("`@("`@
M("`@("!I9B`H)'!O<R`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@(')E
M='5R;B!S=6)S='(H)'5S97(L("1P;W,@*R`Q*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@<F5Q=65S=&5D(&-R961E;G1I86P@9F]R
M('1H92!C=7)R96YT;'D@;&]G9V5D(&EN('5S97(L(&EF"B`@("`@*B!P<F5S
M96YT+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-R961E;G1I86P@
M(%1H92!C<F5D96YT:6%L('1O(')E=')I979E+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1H92!R97%U97-T960@8W)E9&5N=&EA;"P@;W(@9F%L
M<V4@:68@;F\@=7-E<B!I<PH@("`@("H@("`@("`@("`@("`@("`@;&]G9V5D
M(&EN+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#<F5D96YT:6%L*"1C<F5D
M96YT:6%L*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)%]315-324].6R=?
M7V%U=&@G72D@)B8*("`@("`@("`@("`@(65M<'1Y*"1?4T534TE/3ELG7U]A
M=71H)UU;)V%U=&AE;G1I8V%T960G72DI('L*("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]396-R970N<&AP)SL*("`@("`@("`@("`@)&-R961E
M;G1I86QS(#T@0'5N<V5R:6%L:7IE*%-E8W)E=#HZ<F5A9"A396-R970Z.F=E
M=$ME>2@G875T:"<I+"`D7U-%4U-)3TY;)U]?875T:"==6R=C<F5D96YT:6%L
M<R==*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1C<F5D96YT
M:6%L<RD@)B8*("`@("`@("`@("`@:7-S970H)&-R961E;G1I86QS6R1C<F5D
M96YT:6%L72DI('L*("`@("`@("`@("`@<F5T=7)N("1C<F5D96YT:6%L<ULD
M8W)E9&5N=&EA;%T["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E
M=',@=&AE(')E<75E<W1E9"!C<F5D96YT:6%L(&9O<B!T:&4@8W5R<F5N=&QY
M(&QO9V=E9"!I;B!U<V5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&-R961E;G1I86P@(%1H92!C<F5D96YT:6%L('1O('-E="X*("`@("`J($!P
M87)A;2!S=')I;F<@)'9A;'5E("`@("`@(%1H92!V86QU92!T;R!S970@=&AE
M(&-R961E;G1I86P@=&\N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$-R961E
M;G1I86PH)&-R961E;G1I86PL("1V86QU92D*("`@('L*("`@("`@("!I9B`H
M(65M<'1Y*"1?4T534TE/3ELG7U]A=71H)UTI("8F"B`@("`@("`@("`@("%E
M;7!T>2@D7U-%4U-)3TY;)U]?875T:"==6R=A=71H96YT:6-A=&5D)UTI*2![
M"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O4V5C<F5T+G!H<"<[
M"B`@("`@("`@("`@("1C<F5D96YT:6%L<R`]($!U;G-E<FEA;&EZ92A396-R
M970Z.G)E860H4V5C<F5T.CIG971+97DH)V%U=&@G*2P@)%]315-324].6R=?
M7V%U=&@G75LG8W)E9&5N=&EA;',G72DI.PH@("`@("`@("`@("!I9B`H:7-?
M87)R87DH)&-R961E;G1I86QS*2D@>PH@("`@("`@("`@("`@("`@)&-R961E
M;G1I86QS6R1C<F5D96YT:6%L72`]("1V86QU93L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1C<F5D96YT:6%L<R`](&%R<F%Y*"1C
M<F5D96YT:6%L(#T^("1V86QU92D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)%]315-324].6R=?7V%U=&@G75LG8W)E9&5N=&EA;',G72`](%-E8W)E
M=#HZ=W)I=&4H4V5C<F5T.CIG971+97DH)V%U=&@G*2P@<V5R:6%L:7IE*"1C
M<F5D96YT:6%L<RDI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E=',@82!V87)I86)L92!I;B!T:&4@<V5S<VEO;B!S87EI;F<@=&AA="!A
M=71H;W)I>F%T:6]N(&AA<R!S=6-C965D960L"B`@("`@*B!N;W1E('=H:6-H
M('5S97))9"!W87,@875T:&]R:7IE9"P@86YD(&YO=&4@=VAE;B!T:&4@;&]G
M:6X@=&]O:R!P;&%C92X*("`@("`J"B`@("`@*B!)9B!A('5S97(@;F%M92!H
M;V]K('=A<R!D969I;F5D(&EN('1H92!C;VYF:6=U<F%T:6]N+"!I="!G971S
M(&%P<&QI960*("`@("`J('1O('1H92!U<V5R260@870@=&AI<R!P;VEN="X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@("`@("`@
M("!4:&4@=7-E<DED('=H;R!H87,@8F5E;B!A=71H;W)I>F5D+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@("`@("`@5&AE(&-R961E;G1I
M86QS(&]F('1H92!U<V5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5A;&T@
M("`@("`@("`@("`@5&AE(&%U=&AE;G1I8V%T:6]N(')E86QM('1O('5S92X*
M("`@("`J($!P87)A;2!B;V]L96%N("1C:&%N9V5297%U97-T960@(%=H971H
M97(@=&\@<F5Q=65S="!T:&%T('1H92!U<V5R(&-H86YG90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE:7(@<&%S<W=O<F0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$%U=&@H)'5S97))9"P@)&-R961E
M;G1I86QS+"`D<F5A;&T@/2!N=6QL+"`D8VAA;F=E4F5Q=65S=&5D(#T@9F%L
M<V4I"B`@("!["B`@("`@("`@)'5S97))9"`]('1R:6TH)'5S97))9"D["B`@
M("`@("`@)'5S97))9"`]($%U=&@Z.F%D9$AO;VLH)'5S97))9"D["@H@("`@
M("`@("\J($EF('=E)W)E(&%L<F5A9'D@<V5T('=I=&@@=&AI<R!U<V5R260L
M(&1O;B=T(&-O;G1I;G5E+B`J+PH@("`@("`@(&EF("AI<W-E="@D7U-%4U-)
M3TY;)U]?875T:"==6R=U<V5R260G72D@)B8*("`@("`@("`@("`@)%]315-3
M24].6R=?7V%U=&@G75LG=7-E<DED)UT@/3T@)'5S97))9"D@>PH@("`@("`@
M("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`O*B!#;&5A<B!A;GD@
M97AI<W1I;F<@:6YF;RX@*B\*("`@("`@("`D=&AI<RT^8VQE87)!=71H*"1R
M96%L;2D["@H@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O4V5C<F5T+G!H
M<"<["B`@("`@("`@)&-R961E;G1I86QS(#T@4V5C<F5T.CIW<FET92A396-R
M970Z.F=E=$ME>2@G875T:"<I+"!S97)I86QI>F4H)&-R961E;G1I86QS*2D[
M"@H@("`@("`@(&EF("@A96UP='DH)')E86QM*2D@>PH@("`@("`@("`@("`D
M=7-E<DED("X]("=`)R`N("1R96%L;3L*("`@("`@("!]"@H@("`@("`@("1?
M4T534TE/3ELG7U]A=71H)UT@/2!A<G)A>2@*("`@("`@("`@("`@)V%U=&AE
M;G1I8V%T960G(#T^('1R=64L"B`@("`@("`@("`@("=U<V5R260G(#T^("1U
M<V5R260L"B`@("`@("`@("`@("=C<F5D96YT:6%L<R<@/3X@)&-R961E;G1I
M86QS+`H@("`@("`@("`@("`G<F5A;&TG(#T^("1R96%L;2P*("`@("`@("`@
M("`@)W1I;65S=&%M<"<@/3X@=&EM92@I+`H@("`@("`@("`@("`G<F5M;W1E
M7V%D9'(G(#T^(&ES<V5T*"1?4T525D526R=214U/5$5?041$4B==*2`_("1?
M4T525D526R=214U/5$5?041$4B==(#H@;G5L;"P*("`@("`@("`@("`@)V)R
M;W=S97(G(#T^("1'3$]"04Q36R=B<F]W<V5R)UTM/F=E=$%G96YT4W1R:6YG
M*"DL"B`@("`@("`@("`@("=C:&%N9V5297%U97-T960G(#T^("1C:&%N9V52
M97%U97-T960*("`@("`@("`I.PH*("`@("`@("`O*B!296QO860@<')E9F5R
M96YC97,@9F]R('1H92!N97<@=7-E<BX@*B\*("`@("`@("`D1TQ/0D%,4ULG
M<F5G:7-T<GDG72T^;&]A9%!R969S*"D["B`@("`@("`@3DQ3.CIS971,86YG
M*"1'3$]"04Q36R=P<F5F<R==+3YG971686QU92@G;&%N9W5A9V4G*2D["@H@
M("`@("`@("\J($9E=&-H('1H92!U<V5R)W,@;&%S="!L;V=I;B!T:6UE+B`J
M+PH@("`@("`@("1O;&1?;&]G:6X@/2!`=6YS97)I86QI>F4H)$=,3T)!3%-;
M)W!R969S)UTM/F=E=%9A;'5E*"=L87-T7VQO9VEN)RDI.PH*("`@("`@("`O
M*B!$:7-P;&%Y(&ET+"!I9B!W92!H879E(&$@;F]T:69I8V%T:6]N(&]B:F5C
M="!A;F0@=&AE"B`@("`@("`@("H@<VAO=U]L87-T7VQO9VEN('!R969E<F5N
M8V4@:7,@86-T:79E+B`J+PH@("`@("`@(&EF("AI<W-E="@D1TQ/0D%,4ULG
M;F]T:69I8V%T:6]N)UTI("8F("1'3$]"04Q36R=P<F5F<R==+3YG971686QU
M92@G<VAO=U]L87-T7VQO9VEN)RDI('L*("`@("`@("`@("`@:68@*&5M<'1Y
M*"1O;&1?;&]G:6Y;)W1I;64G72DI('L*("`@("`@("`@("`@("`@("1'3$]"
M04Q36R=N;W1I9FEC871I;VXG72T^<'5S:"A?*"),87-T(&QO9VEN.B!.979E
M<B(I+"`G:&]R9&4N;65S<V%G92<I.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1O;&1?;&]G:6Y;)VAO<W0G72DI
M('L*("`@("`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG;F]T:69I8V%T:6]N
M)UTM/G!U<V@H<W!R:6YT9BA?*"),87-T(&QO9VEN.B`E<R(I+"!S=')F=&EM
M92@G)6,G+"`D;VQD7VQO9VEN6R=T:6UE)UTI*2P@)VAO<F1E+FUE<W-A9V4G
M*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@)$=,3T)!3%-;)VYO=&EF:6-A=&EO;B==+3YP=7-H*'-P<FEN=&8H7R@B
M3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(I+"!S=')F=&EM92@G)6,G+"`D;VQD
M7VQO9VEN6R=T:6UE)UTI+"`D;VQD7VQO9VEN6R=H;W-T)UTI+"`G:&]R9&4N
M;65S<V%G92<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O+R!3970@=&AE('5S97(G<R!L87-T7VQO9VEN
M(&EN9F]R;6%T:6]N+@H@("`@("`@("1H;W-T(#T@96UP='DH)%]315)615);
M)TA45%!?6%]&3U)705)$141?1D]2)UTI"B`@("`@("`@("`@(#\@)%]315)6
M15);)U)%34]415]!1$12)UT*("`@("`@("`@("`@.B`D7U-%4E9%4ELG2%14
M4%]87T9/4E=!4D1%1%]&3U(G73L*("`@("`@("`D;&%S=%]L;V=I;B`](&%R
M<F%Y*"=T:6UE)R`]/B!T:6UE*"DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G:&]S="<@/3X@0&=E=&AO<W1B>6%D9'(H)&AO<W0I*3L*("`@("`@
M("`D1TQ/0D%,4ULG<')E9G,G72T^<V5T5F%L=64H)VQA<W1?;&]G:6XG+"!S
M97)I86QI>F4H)&QA<W1?;&]G:6XI*3L*"B`@("`@("`@:68@*"1C:&%N9V52
M97%U97-T960I('L*("`@("`@("`@("`@)$=,3T)!3%-;)VYO=&EF:6-A=&EO
M;B==+3YP=7-H*%\H(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:&]R
M9&4N;65S<V%G92<I.PH@("`@("`@("`@("!I9B`H)'1H:7,M/FAA<T-A<&%B
M:6QI='DH)W5P9&%T92<I*2!["B`@("`@("`@("`@("`@("`O*B!!(&)I="!O
M9B!A(&ML=61G92X@(%523"!I<R!S970@9G)O;2!T:&4@;&]G:6X@<V-R965N
M+"!B=70*("`@("`@("`@("`@("`@("`J('=E(&%R96XG="!C;VUP;&5T96QY
M(&-E<G1A:6X@=V4@9V]T(&AE<F4@9G)O;2!T:&4@;&]G:6X*("`@("`@("`@
M("`@("`@("`J('-C<F5E;BX@(%-O(&%N>2!S8W)E96X@=VAI8V@@8V%L;',@
M<V5T075T:"@I('=H:6-H(&AA<R!A"B`@("`@("`@("`@("`@("`@*B!U<FP@
M=VEL;"!E;F0@=7`@9V]I;F<@=&AE<F4N("!3:&]U;&0@8F4@3TLN("HO"B`@
M("`@("`@("`@("`@("`D=7)L7W!A<F%M(#T@571I;#HZ9V5T1F]R;41A=&$H
M)W5R;"<I.PH*("`@("`@("`@("`@("`@(&EF("@D=7)L7W!A<F%M*2!["B`@
M("`@("`@("`@("`@("`@("`@)'5R;"`]($AO<F1E.CIU<FPH571I;#HZ<F5M
M;W9E4&%R86UE=&5R*"1U<FQ?<&%R86TL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-E<W-I
M;VY?;F%M92@I*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!T<G5E*3L*("`@("`@("`@("`@("`@("`@("`D<F5T=7)N7W1O(#T@
M)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O="<L("=H;W)D92<I
M("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R]I;F1E>"YP
M:'`G.PH@("`@("`@("`@("`@("`@("`@("1R971U<FY?=&\@/2!5=&EL.CIA
M9&1087)A;65T97(H)')E='5R;E]T;RP@)W5R;"<L("1U<FPI.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<F5T=7)N
M7W1O(#T@2&]R9&4Z.G5R;"@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=W
M96)R;V]T)RP@)VAO<F1E)RD*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+B`G+VEN9&5X+G!H<"<I.PH@("`@("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@("`@("1U<FP@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH)W-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<"<I.PH@("`@("`@("`@("`@("`@
M)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<F5T=7)N7W1O
M)R`]/B`D<F5T=7)N7W1O*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@;G5L;"P@9F%L<V4I.PH*("`@("`@("`@("`@("`@
M(&AE861E<B@G3&]C871I;VXZ("<@+B`D=7)L*3L*("`@("`@("`@("`@("`@
M(&5X:70["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#;&5A<G,@86YY(&%U=&AE;G1I8V%T:6]N('1O:V5N<R!I;B!T
M:&4@8W5R<F5N="!S97-S:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)')E86QM("!4:&4@875T:&5N=&EC871I;VX@<F5A;&T@=&\@8VQE87(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L96%R075T:"@D<F5A;&T@/2!N=6QL
M*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)')E86QM*2`F)B!I<W-E="@D
M7U-%4U-)3TY;)U]?875T:"==6R1R96%L;5TI*2!["B`@("`@("`@("`@("1?
M4T534TE/3ELG7U]A=71H)UU;)')E86QM72`](&%R<F%Y*"D["B`@("`@("`@
M("`@("1?4T534TE/3ELG7U]A=71H)UU;)')E86QM75LG875T:&5N=&EC871E
M9"==(#T@9F%L<V4["B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1?4T534TE/
M3ELG7U]A=71H)UTI*2!["B`@("`@("`@("`@("1?4T534TE/3ELG7U]A=71H
M)UT@/2!A<G)A>2@I.PH@("`@("`@("`@("`D7U-%4U-)3TY;)U]?875T:"==
M6R=A=71H96YT:6-A=&5D)UT@/2!F86QS93L*("`@("`@("!]"@H@("`@("`@
M("\J(%)E;6]V92!T:&4@=7-E<B=S(&-A8VAE9"!P<F5F97)E;F-E<R!I9B!T
M:&5Y(&%R92!P<F5S96YT+B`J+PH@("`@("`@(&EF("AI<W-E="@D1TQ/0D%,
M4ULG<F5G:7-T<GDG72DI('L*("`@("`@("`@("`@)$=,3T)!3%-;)W)E9VES
M=')Y)UTM/G5N;&]A9%!R969S*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@27,@=&AE(&-U<G)E;G0@=7-E<B!A;B!A9&UI;FES=')A=&]R
M/PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!E<FUI<W-I;VX@($%L
M;&]W('5S97)S('=I=&@@=&AI<R!P97)M:7-S:6]N(&%D;6EN(&%C8V5S<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6X@=&AE(&-U<G)E
M;G0@8V]N=&5X="X*("`@("`J($!P87)A;2!I;G1E9V5R("1P97)M;&5V96P@
M(%1H92!L979E;"!O9B!P97)M:7-S:6]N<R!T;R!C:&5C:R!F;W(*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("A015)-4U]%1$E4+"!015)-
M4U]$14Q%5$4L(&5T8RDN($1E9F%U;'1S"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!T;R!015)-4U]%1$E4+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=7-E<B`@("`@("`@5&AE('5S97(@=&\@8VAE8VLN($1E9F%U;'1S
M('1O($%U=&@Z.F=E=$%U=&@H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%=H971H97(@;W(@;F]T('1H:7,@:7,@86X@861M:6X@=7-E<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@:7-!9&UI;B@D<&5R;6ES<VEO;B`](&YU
M;&PL("1P97)M;&5V96P@/2!N=6QL+"`D=7-E<B`](&YU;&PI"B`@("!["B`@
M("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("!I9B`H)'5S97(@/3T](&YU
M;&PI('L*("`@("`@("`@("`@)'5S97(@/2!!=71H.CIG971!=71H*"D["B`@
M("`@("`@?0H*("`@("`@("!I9B`H0&ES7V%R<F%Y*"1C;VYF6R=A=71H)UU;
M)V%D;6EN<R==*2D@>PH@("`@("`@("`@("!I9B`H)'5S97(@)B8@:6Y?87)R
M87DH)'5S97(L("1C;VYF6R=A=71H)UU;)V%D;6EN<R==*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(&EF("@A:7-?;G5L;"@D<&5R;6ES<VEO;BDI('L*("`@("`@
M("`@("`@:68@*&ES7VYU;&PH)'!E<FUL979E;"DI('L*("`@("`@("`@("`@
M("`@("1P97)M;&5V96P@/2!015)-4U]%1$E4.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG<&5R;7,G72T^:&%S4&5R;6ES
M<VEO;B@D<&5R;6ES<VEO;BP@)'5S97(L("1P97)M;&5V96PI.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@07!P;&EE<R!A(&AO;VL@9&5F:6YE9"!B>2!T:&4@9G5N8W1I;VX@7W5S
M97)N86UE7VAO;VM?9G)O;6)A8VME;F0H*2!T;PH@("`@("H@=&AE(&=I=F5N
M('5S97(@;F%M92!I9B!T:&ES(&9U;F-T:6]N(&5X:7-T<R!A;F0@=7-E<B!H
M;V]K<R!A<F4@96YA8FQE9"X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!S
M:&]U;&0@8F4@8V%L;&5D(&EF(&$@8F%C:V5N9"=S('5S97(@;F%M92!N965D
M<R!T;R!B90H@("`@("H@8V]N=F5R=&5D('1O(&$@*'5N:7%U92D@2&]R9&4@
M=7-E<B!N86UE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))
M9"`@5&AE(&]R:6=I;F%L('5S97(@;F%M92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE('5S97(@;F%M92!W:71H('1H92!H;V]K(&%P<&QI
M960@=&\@:70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$AO;VLH)'5S97))
M9"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@(&EF("@A
M96UP='DH)&-O;F9;)VAO;VMS)UU;)W5S97)N86UE)UTI*2!["B`@("`@("`@
M("`@(')E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]C;VYF:6<O:&]O:W,N
M<&AP)SL*("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G7W5S97)N
M86UE7VAO;VM?9G)O;6)A8VME;F0G*2D@>PH@("`@("`@("`@("`@("`@)'5S
M97))9"`](&-A;&Q?=7-E<E]F=6YC*"=?=7-E<FYA;65?:&]O:U]F<F]M8F%C
M:V5N9"<L("1U<V5R260I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)'5S97))9#L*("`@('T*"B`@("`O*BH*("`@("`J($%P
M<&QI97,@82!H;V]K(&1E9FEN960@8GD@=&AE(&9U;F-T:6]N(%]U<V5R;F%M
M95]H;V]K7W1O8F%C:V5N9"@I('1O"B`@("`@*B!T:&4@9VEV96X@=7-E<B!N
M86UE(&EF('1H:7,@9G5N8W1I;VX@97AI<W1S(&%N9"!U<V5R(&AO;VMS(&%R
M92!E;F%B;&5D+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D('-H;W5L9"!B
M92!C86QL960@:68@82!(;W)D92!U<V5R(&YA;64@;F5E9',@=&\@8F4@8V]N
M=F5R=&5D"B`@("`@*B!T;R!A(&)A8VME;F0G<R!U<V5R(&YA;64@;W(@9&ES
M<&QA>65D('1O('1H92!U<V5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'5S97))9"`@5&AE($AO<F1E('5S97(@;F%M92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE('5S97(@;F%M92!W:71H('1H92!H;V]K
M(&%P<&QI960@=&\@:70N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V94AO
M;VLH)'5S97))9"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@
M("`@(&EF("@A96UP='DH)&-O;F9;)VAO;VMS)UU;)W5S97)N86UE)UTI*2![
M"B`@("`@("`@("`@(')E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]C;VYF
M:6<O:&]O:W,N<&AP)SL*("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T
M<R@G7W5S97)N86UE7VAO;VM?=&]B86-K96YD)RDI('L*("`@("`@("`@("`@
M("`@("1U<V5R260@/2!C86QL7W5S97)?9G5N8R@G7W5S97)N86UE7VAO;VM?
M=&]B86-K96YD)RP@)'5S97))9"D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D=7-E<DED.PH@("`@?0H*("`@("\J*@H@("`@
M("H@475E<FEE<R!T:&4@8W5R<F5N="!!=71H(&]B:F5C="!T;R!F:6YD(&]U
M="!I9B!I="!S=7!P;W)T<R!T:&4@9VEV96X*("`@("`J(&-A<&%B:6QI='DN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V%P86)I;&ET>2`@5&AE
M(&-A<&%B:6QI='D@=&\@=&5S="!F;W(N"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8V%P86)I;&ET>2!I<R!S
M=7!P;W)T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA<T-A<&%B:6QI='DH
M)&-A<&%B:6QI='DI"B`@("!["B`@("`@("`@<F5T=7)N("%E;7!T>2@D=&AI
M<RT^8V%P86)I;&ET:65S6R1C87!A8FEL:71Y72D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!54DD@;V8@=&AE(&QO9VEN('-C<F5E;B!F
M;W(@=&AE(&-U<G)E;G0@875T:&5N=&EC871I;VX*("`@("`J(&UE=&AO9"X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@(%1H92!A<'!L:6-A
M=&EO;B!T;R!U<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<FP@(%1H92!5
M4DP@=&\@<F5D:7)E8W0@=&\@869T97(@;&]G:6XN"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!L;V=I;B!S8W)E96X@55))+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971,;V=I;E-C<F5E;B@D87!P(#T@)VAO<F1E)RP@
M)'5R;"`]("<G*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*("`@("`@
M("`D875T:"`]("9!=71H.CIS:6YG;&5T;VXH)&-O;F9;)V%U=&@G75LG9')I
M=F5R)UTI.PH@("`@("`@(')E='5R;B`D875T:"T^7V=E=$QO9VEN4V-R965N
M*"1A<'`L("1U<FPI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@;F%M960@<&%R86UE=&5R(&9O<B!T:&4@8W5R<F5N="!A=71H(&1R:79E
M<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87)A;2`@5&AE('!A
M<F%M971E<B!T;R!F971C:"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE('!A<F%M971E<B=S('9A;'5E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971087)A;2@D<&%R86TI"B`@("!["B`@("`@("`@<F5T=7)N(&ES<V5T
M*"1T:&ES+3Y?<&%R86US6R1P87)A;5TI(#\@)'1H:7,M/E]P87)A;7-;)'!A
M<F%M72`Z(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!N86UE(&]F('1H92!A=71H96YT:6-A=&EO;B!P<F]V:61E<BX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1D<FEV97(@(%5S960@8GD@<F5C=7)S
M:79E(&-A;&QS('=H96X@=6YT86YG;&EN9R!C;VUP;W-I=&4*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@875T:"X*("`@("`J($!P87)A;2!A<G)A
M>2`@)'!A<F%M<R`@57-E9"!B>2!R96-U<G-I=F4@8V%L;',@=VAE;B!U;G1A
M;F=L:6YG(&-O;7!O<VET90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("!A=71H+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;F%M
M92!O9B!T:&4@9')I=F5R(&-U<G)E;G1L>2!P<F]V:61I;F<*("`@("`J("`@
M("`@("`@("`@("`@("!A=71H96YT:6-A=&EO;BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4')O=FED97(H)&1R:79E<B`](&YU;&PL("1P87)A;7,@/2!N
M=6QL*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@:68@
M*&ES7VYU;&PH)&1R:79E<BDI('L*("`@("`@("`@("`@)&1R:79E<B`]("1C
M;VYF6R=A=71H)UU;)V1R:79E<B==.PH@("`@("`@('T*("`@("`@("!I9B`H
M:7-?;G5L;"@D<&%R86US*2D@>PH@("`@("`@("`@("`D<&%R86US(#T@2&]R
M9&4Z.F=E=$1R:79E<D-O;F9I9R@G875T:"<L"B`@("`@("`@("`@("`@("!I
M<U]A<G)A>2@D9')I=F5R*2`_("1D<FEV97);,5T@.B`D9')I=F5R*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("@D9')I=F5R(#T]("=A<'!L:6-A=&EO;B<I
M('L*("`@("`@("`@("`@<F5T=7)N(&ES<V5T*"1P87)A;7-;)V%P<"==*2`_
M("1P87)A;7-;)V%P<"==(#H@)V%P<&QI8V%T:6]N)SL*("`@("`@("!](&5L
M<V5I9B`H)&1R:79E<B`]/2`G8V]M<&]S:71E)RD@>PH@("`@("`@("`@("!I
M9B`H*"1L;V=I;E]D<FEV97(@/2!!=71H.CI?9V5T1')I=F5R0GE087)A;2@G
M;&]G:6YS8W)E96Y?<W=I=&-H)RP@)'!A<F%M<RDI("8F"B`@("`@("`@("`@
M("`@("`A96UP='DH)'!A<F%M<ULG9')I=F5R<R==6R1L;V=I;E]D<FEV97)=
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N($%U=&@Z.F=E=%!R;W9I9&5R
M*"1P87)A;7-;)V1R:79E<G,G75LD;&]G:6Y?9')I=F5R75LG9')I=F5R)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:7-S
M970H)'!A<F%M<ULG9')I=F5R<R==6R1L;V=I;E]D<FEV97)=6R=P87)A;7,G
M72D@/R`D<&%R86US6R=D<FEV97)S)UU;)&QO9VEN7V1R:79E<EU;)W!A<F%M
M<R==(#H@;G5L;"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N
M("=C;VUP;W-I=&4G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B`D9')I=F5R.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE(&QO9V]U="!R96%S;VXN"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@3VYE(&]F('1H92!L;V=O=70@<F5A<V]N<R`H<V5E('1H
M92!!551(7TQ/1T]55%\J"B`@("`@*B`@("`@("`@("`@("`@("!C;VYS=&%N
M=',@9F]R('1H92!V86QI9"!R96%S;VYS*2X@(%)E='5R;G,@;G5L;"!I9B!T
M:&5R90H@("`@("H@("`@("`@("`@("`@("`@:7,@;F\@;&]G;W5T(')E87-O
M;B!P<F5S96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971,;V=O=71296%S
M;VXH*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D1TQ/0D%,4ULG7U]A=71H
M97)R;W(G75LG='EP92==*2D@>PH@("`@("`@("`@("!R971U<FX@)$=,3T)!
M3%-;)U]?875T:&5R<F]R)UU;)W1Y<&4G73L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!R971U<FX@571I;#HZ9V5T1F]R;41A=&$H05542%]214%3
M3TY?4$%204TI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE('-T871U<R!S=')I;F<@=&\@=7-E(&9O<B!L;V=O=70@;65S
M<V%G97,N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!L;V=O
M=70@<F5A<V]N('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3&]G
M;W5T4F5A<V]N4W1R:6YG*"D*("`@('L*("`@("`@("!S=VET8V@@*$%U=&@Z
M.F=E=$QO9V]U=%)E87-O;B@I*2!["B`@("`@("`@8V%S92!!551(7U)%05-/
M3E]315-324]..@H@("`@("`@("`@("`D=&5X="`]('-P<FEN=&8H7R@B66]U
M<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN
M(BDL("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)VYA;64G*2D["B`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("!C87-E($%55$A?4D5!4T].7U-%4U-)
M3TY)4#H*("`@("`@("`@("`@)'1E>'0@/2!S<')I;G1F*%\H(EEO=7(@26YT
M97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG
M(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y
M+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB*2P@)$=,3T)!3%-;)W)E9VES=')Y
M)UTM/F=E="@G;F%M92<I*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@05542%]214%33TY?0E)/5U-%4CH*("`@("`@("`@("`@)'1E>'0@
M/2!S<')I;G1F*%\H(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA
M;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@
M5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I
M;BXB*2P@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G;F%M92<I*3L*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@05542%]214%33TY?3$]'
M3U54.@H@("`@("`@("`@("`D=&5X="`](%\H(EEO=2!H879E(&)E96X@;&]G
M9V5D(&]U="XB*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@
M05542%]214%33TY?1D%)3$5$.@H@("`@("`@("`@("`D=&5X="`](%\H(DQO
M9VEN(&9A:6QE9"XB*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@05542%]214%33TY?0D%$3$]'24XZ"B`@("`@("`@("`@("1T97AT(#T@
M7R@B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S
M=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB*3L*("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@(&-A<V4@05542%]214%33TY?15A025)%1#H*("`@
M("`@("`@("`@)'1E>'0@/2!?*")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(I
M.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!!551(7U)%05-/
M3E]-15-304=%.@H@("`@("`@("`@("!I9B`H:7-S970H)$=,3T)!3%-;)U]?
M875T:&5R<F]R)UU;)VUS9R==*2D@>PH@("`@("`@("`@("`@("`@)'1E>'0@
M/2`D1TQ/0D%,4ULG7U]A=71H97)R;W(G75LG;7-G)UT["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D=&5X="`](%5T:6PZ.F=E=$9O
M<FU$871A*$%55$A?4D5!4T].7TU31U]005)!32D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@
M("`@("1T97AT(#T@)R<["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1T97AT.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1V5N97)A=&5S('1H92!C;W)R96-T('!A<F%M971E<G,@=&\@<&%S<R!T;R!T
M:&4@9VEV96X@;&]G;W5T(%523"X*("`@("`J"B`@("`@*B!)9B!N;R!R96%S
M;VXO;7-G(&ES('!A<W-E9"!I;BP@=7-E('1H92!C=7)R96YT(&=L;V)A;"!A
M=71H96YT:6-A=&EO;@H@("`@("H@97)R;W(@;65S<V%G92X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1U<FP@("`@(%1H92!54DP@=&\@<F5D:7)E
M8W0@=&\N"B`@("`@*B!`<&%R86T@<W1R:6YG("1R96%S;VX@(%1H92!R96%S
M;VX@9F]R(&QO9V]U="X*("`@("`J($!P87)A;2!S=')I;F<@)&US9R`@("`@
M268@<F5A<V]N(&ES($%55$A?4D5!4T].7TU%4U-!1T4L('1H92!M97-S86=E
M('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&1I<W!L87D@=&\@
M=&AE('5S97(N"B`@("`@*B!`<F5T=7)N('-T<FEN9R!4:&4@9F]R;6%T=&5D
M(%523`H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1,;V=O=71087)A;65T97)S
M*"1U<FPL("1R96%S;VX@/2!N=6QL+"`D;7-G(#T@;G5L;"D*("`@('L*("`@
M("`@("!I9B`H:7-?;G5L;"@D<F5A<V]N*2D@>PH@("`@("`@("`@("`D<F5A
M<V]N(#T@075T:#HZ9V5T3&]G;W5T4F5A<V]N*"D["B`@("`@("`@?0H*("`@
M("`@("!I9B`H)')E87-O;BD@>PH@("`@("`@("`@("`D=7)L(#T@571I;#HZ
M861D4&%R86UE=&5R*"1U<FPL($%55$A?4D5!4T].7U!!4D%-+"`D<F5A<V]N
M+"!F86QS92D["B`@("`@("`@("`@(&EF("@D<F5A<V]N(#T]($%55$A?4D5!
M4T].7TU%4U-!1T4I('L*("`@("`@("`@("`@("`@(&EF("AI<U]N=6QL*"1M
M<V<I*2!["B`@("`@("`@("`@("`@("`@("`@)&US9R`]($%U=&@Z.F=E=$QO
M9V]U=%)E87-O;E-T<FEN9R@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"!!551(
M7U)%05-/3E]-4T=?4$%204TL("1M<V<L(&9A;'-E*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1U<FP["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!54DD@;V8@=&AE(&QO9VEN('-C<F5E
M;B!F;W(@=&AI<R!A=71H96YT:6-A=&EO;B!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D87!P("!4:&4@87!P;&EC871I;VX@=&\@=7-E+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=7)L("!4:&4@55),('1O(')E9&ER96-T('1O(&%F=&5R(&QO
M9VEN+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;&]G:6X@
M<V-R965N(%5222X*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$QO9VEN4V-R
M965N*"1A<'`@/2`G:&]R9&4G+"`D=7)L(#T@)R<I"B`@("!["B`@("`@("`@
M)&QO9VEN(#T@2&]R9&4Z.G5R;"@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T
M*"=W96)R;V]T)RP@)&%P<"D@+B`G+VQO9VEN+G!H<"<L('1R=64I.PH@("`@
M("`@(&EF("@A96UP='DH)'5R;"DI('L*("`@("`@("`@("`@)&QO9VEN(#T@
M571I;#HZ861D4&%R86UE=&5R*"1L;V=I;BP@)W5R;"<L("1U<FPI.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)&QO9VEN.PH@("`@?0H*("`@("\J*@H@
M("`@("H@075T:&5N=&EC871I;VX@<W1U8BX*("`@("`J"B`@("`@*B!`86)S
M=')A8W0*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@1F%L<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A
M=71H96YT:6-A=&4H*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(&5R<F]R(&UE<W-A9V4@9F]R
M(&%N(&EN=F%L:60@875T:&5N=&EC871I;VXN"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP
M92`@5&AE('1Y<&4@;V8@97)R;W(@*$%55$A?4D5!4T].(&-O;G-T86YT*2X*
M("`@("`J($!P87)A;2!S=')I;F<@)&US9R`@(%1H92!E<G)O<B!M97-S86=E
M+W)E87-O;B!F;W(@:6YV86QI9`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@875T:&5N=&EC871I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S971!
M=71H17)R;W(H)'1Y<&4L("1M<V<@/2!N=6QL*0H@("`@>PH@("`@("`@("1'
M3$]"04Q36R=?7V%U=&AE<G)O<B==(#T@87)R87DH*3L*("`@("`@("`D1TQ/
M0D%,4ULG7U]A=71H97)R;W(G75LG='EP92==(#T@)'1Y<&4["B`@("`@("`@
M)$=,3T)!3%-;)U]?875T:&5R<F]R)UU;)VUS9R==(#T@)&US9SL*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&5R<F]R('1Y<&4@9F]R(&%N
M(&EN=F%L:60@875T:&5N=&EC871I;VX@;W(@9F%L<V4@;VX@97)R;W(N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"!%<G)O<B!T>7!E(&]R(&9A;'-E(&]N(&5R<F]R"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]G971!=71H17)R;W(H*0H@("`@>PH@("`@("`@
M(&EF("AI<W-E="@D1TQ/0D%,4ULG7U]A=71H97)R;W(G75LG='EP92==*2D@
M>PH@("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;)U]?875T:&5R<F]R)UU;
M)W1Y<&4G73L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&%P<')O<')I871E(&%U
M=&AE;G1I8V%T:6]N(&1R:79E<BP@:68@86YY+"!S96QE8W1I;F<@8GD@=&AE
M"B`@("`@*B!S<&5C:69I960@<&%R86UE=&5R+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA
M;64@("`@("`@("`@5&AE('!A<F%M971E<B!N86UE+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@("`@("`@("!4:&4@<&%R86UE=&5R(&QI<W0N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1D<FEV97)P87)A;7,@($$@;&ES="!O9B!P
M87)A;65T97)S('1O('!A<W,@=&\@=&AE(&1R:79E<BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D(%)E='5R;B!V86QU92!O<B!C86QL960@=7-E<B!F
M=6YC(&]R(&YU;&P@:68@=6YA=F%I;&%B;&4*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V=E=$1R:79E<D)Y4&%R86TH)&YA;64L("1P87)A;7,L("1D<FEV97)P
M87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D<&%R
M86US6R1N86UE72D@)B8*("`@("`@("`@("`@9G5N8W1I;VY?97AI<W1S*"1P
M87)A;7-;)&YA;65=*2D@>PH@("`@("`@("`@("!R971U<FX@8V%L;%]U<V5R
M7V9U;F-?87)R87DH)'!A<F%M<ULD;F%M95TL("1D<FEV97)P87)A;7,I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!097)F;W)M<R!C:&5C:R!O;B!S97-S:6]N('1O('-E92!I9B!)
M4"!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H90H@("`@("H@;&%S="!A
M8V-E<W,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF($E0($%D9')E<W,@:7,@
M=&AE('-A;64@*&]R('1H92!C:&5C:R!I<PH@("`@("H@("`@("`@("`@("`@
M("`@("!D:7-A8FQE9"DL(&9A;'-E(&EF('1H92!A9&1R97-S(&AA<R!C:&%N
M9V5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8VAE8VM397-S:6]N25`H*0H@
M("`@>PH@("`@("`@(')E='5R;B`H96UP='DH)$=,3T)!3%-;)V-O;F8G75LG
M875T:"==6R=C:&5C:VEP)UTI('Q\"B`@("`@("`@("`@("`@("`H:7-S970H
M)%]315-324].6R=?7V%U=&@G75LG<F5M;W1E7V%D9'(G72D@)B8@)%]315-3
M24].6R=?7V%U=&@G75LG<F5M;W1E7V%D9'(G72`]/2`D7U-%4E9%4ELG4D5-
M3U1%7T%$1%(G72DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4&5R9F]R;7,@
M8VAE8VL@;VX@<V5S<VEO;B!T;R!S964@:68@8G)O=W-E<B!S=')I;F<@:&%S
M(&-H86YG960@<VEN8V4*("`@("`J('1H92!L87-T(&%C8V5S<RX*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%1R=64@:68@8G)O=W-E<B!S=')I;F<@:7,@=&AE('-A;64L
M(&9A;'-E(&EF('1H90H@("`@("H@("`@("`@("`@("`@("`@("!S=')I;F<@
M:&%S(&-H86YG960N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C:&5C:T)R;W=S
M97)3=')I;F<H*0H@("`@>PH@("`@("`@(')E='5R;B`H96UP='DH)$=,3T)!
M3%-;)V-O;F8G75LG875T:"==6R=C:&5C:V)R;W=S97(G72D@?'P*("`@("`@
M("`@("`@("`@("1?4T534TE/3ELG7U]A=71H)UU;)V)R;W=S97(G72`]/2`D
M1TQ/0D%,4ULG8G)O=W-E<B==+3YG971!9V5N=%-T<FEN9R@I*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($-O;G9E<G1S('1O(&%L;&]W960@-C0@8VAA<F%C
M=&5R<R!F;W(@05!2340U('!A<W-W;W)D<RX*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=F%L
M=64*("`@("`J($!P87)A;2!I;G1E9V5R("1C;W5N=`H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("`D=F%L=64@8V]N=F5R=&5D('1O('1H92`V-"!-
M1#4@8VAA<F%C=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W1O05!2340U
M*"1V86QU92P@)&-O=6YT*0H@("`@>PH@("`@("`@("\J(#8T(&-H87)A8W1E
M<G,@=&AA="!A<F4@=F%L:60@9F]R($%04DU$-2!P87-S=V]R9',N("HO"B`@
M("`@("`@)$%04DU$-2`]("<N+S`Q,C,T-38W.#E!0D-$149'2$E*2TQ-3D]0
M45)35%565UA96F%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ)SL*"B`@("`@
M("`@)&%P<FUD-2`]("<G.PH@("`@("`@("1C;W5N="`](&%B<R@D8V]U;G0I
M.PH@("`@("`@('=H:6QE("@M+21C;W5N="D@>PH@("`@("`@("`@("`D87!R
M;60U("X]("1!4%)-1#5;)'9A;'5E("8@,'@S9ET["B`@("`@("`@("`@("1V
M86QU92`^/CT@-CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1A<')M9#4[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T<R!H97AA9&5C:6UA;"!S
M=')I;F<@=&\@8FEN87)Y(&1A=&$N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:&5X("!(97@@
M9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@0FEN87)Y(&1A
M=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]B:6XH)&AE>"D*("`@('L*("`@
M("`@("`D8FEN(#T@)R<["B`@("`@("`@)&QE;F=T:"`]('-T<FQE;B@D:&5X
M*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D;&5N9W1H.R`D:2`K/2`R
M*2!["B`@("`@("`@("`@("1T;7`@/2!S<V-A;F8H<W5B<W1R*"1H97@L("1I
M+"`R*2P@)R5X)RD["B`@("`@("`@("`@("1B:6X@+CT@8VAR*&%R<F%Y7W-H
M:69T*"1T;7`I*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1B:6X["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC
M<F5T92!!=71H(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&UI>&5D("1D<FEV97(@(%1H92!T>7!E(&]F(&-O;F-R
M971E($%U=&@@<W5B8VQA<W,@=&\@<F5T=7)N+B!4:&ES"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@:7,@8F%S960@;VX@=&AE('-T;W)A9V4@9')I
M=F5R("@D9')I=F5R*2X@5&AE(&-O9&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!I<R!D>6YA;6EC86QL>2!I;F-L=61E9"X@268@)&1R:79E<B!I
M<R!A;B!A<G)A>2P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T:&5N
M('=E('=I;&P@;&]O:R!I;B`D9')I=F5R6S!=+VQI8B]!=71H+R!F;W(@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<W5B8VQA<W,@:6UP;&5M
M96YT871I;VX@;F%M960@)&1R:79E<ELQ72YP:'`N"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N
M86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE
M960N"B`@("`@*@H@("`@("H@0')E='5R;B!!=71H("!4:&4@;F5W;'D@8W)E
M871E9"!C;VYC<F5T92!!=71H(&EN<W1A;F-E+"!O<B!F86QS92!O;B!A;@H@
M("`@("H@("`@("`@("`@("`@("!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@)F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<R`](&YU;&PI"B`@("!["B`@
M("`@("`@:68@*&ES7V%R<F%Y*"1D<FEV97(I*2!["B`@("`@("`@("`@("1A
M<'`@/2`D9')I=F5R6S!=.PH@("`@("`@("`@("`D9')I=F5R(#T@)&1R:79E
M<ELQ73L*("`@("`@("!]"@H@("`@("`@("1D<FEV97(@/2!B87-E;F%M92@D
M9')I=F5R*3L*"B`@("`@("`@:68@*&5M<'1Y*"1D<FEV97(I('Q\("@D9')I
M=F5R(#T]("=N;VYE)RDI('L*("`@("`@("`@("`@)&%U=&@@/2`F;F5W($%U
M=&@H*3L*("`@("`@("`@("`@<F5T=7)N("1A=71H.PH@("`@("`@('T*"B`@
M("`@("`@:68@*&ES7VYU;&PH)'!A<F%M<RDI('L*("`@("`@("`@("`@)'!A
M<F%M<R`]($AO<F1E.CIG971$<FEV97)#;VYF:6<H)V%U=&@G+"`D9')I=F5R
M*3L*("`@("`@("!]"@H@("`@("`@(&EN:5]S970H)W1R86-K7V5R<F]R<R<L
M(#$I.PH@("`@("`@("1I;F-L=61E7V5R<F]R(#T@)R<["B`@("`@("`@:68@
M*"%E;7!T>2@D87!P*2D@>PH@("`@("`@("`@("!`:6YC;'5D95]O;F-E("1'
M3$]"04Q36R=R96=I<W1R>2==+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G
M+VQI8B]!=71H+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@($!I;F-L=61E7V]N8V4@)TAO<F1E+T%U=&@O)R`N
M("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E
M="@D<&AP7V5R<F]R;7-G*2D@>PH@("`@("`@("`@("`D:6YC;'5D95]E<G)O
M<B`]("1P:'!?97)R;W)M<V<["B`@("`@("`@?0H@("`@("`@(&EN:5]R97-T
M;W)E*"=T<F%C:U]E<G)O<G,G*3L*"B`@("`@("`@)&-L87-S(#T@)T%U=&A?
M)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I
M*2!["B`@("`@("`@("`@("1A=71H(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&%U=&@@/2!014%2.CIR
M86ES945R<F]R*"=!=71H($1R:79E<B`H)R`N("1C;&%S<R`N("<I(&YO="!F
M;W5N9"<@+B`H)&EN8VQU9&5?97)R;W(@/R`G.B`G("X@)&EN8VQU9&5?97)R
M;W(@.B`G)RD@+B`G+B<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1A
M=71H.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N
M(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@075T:"!I;G-T86YC92!B87-E
M9"!O;@H@("`@("H@)&1R:79E<BX@270@=VEL;"!O;FQY(&-R96%T92!A(&YE
M=R!I;G-T86YC92!I9B!N;R!!=71H(&EN<W1A;F-E('=I=&@*("`@("`J('1H
M92!S86UE('!A<F%M971E<G,@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@
M("`@*B!4:&ES('-H;W5L9"!B92!U<V5D(&EF(&UU;'1I<&QE(&%U=&AE;G1I
M8V%T:6]N('-O=7)C97,@*&%N9"P@=&AU<RP*("`@("`J(&UU;'1I<&QE($%U
M=&@@:6YS=&%N8V5S*2!A<F4@<F5Q=6ER960N"B`@("`@*@H@("`@("H@5&AI
M<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R(#T@)D%U=&@Z.G-I
M;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9')I=F5R
M("!4:&4@='EP92!O9B!C;VYC<F5T92!!=71H('-U8F-L87-S('1O(')E='5R
M;BX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@5&AI<R!I<R!B87-E
M9"!O;B!T:&4@<W1O<F%G92!D<FEV97(@*"1D<FEV97(I+@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("!4:&4@8V]D92!I<R!D>6YA;6EC86QL>2!I
M;F-L=61E9"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@02!H87-H
M(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T:6]N('!A<F%M
M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R
M971U<FX@075T:"`@5&AE(&-O;F-R971E($%U=&@@<F5F97)E;F-E+"!O<B!F
M86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L
M971O;B@D9')I=F5R+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("!S
M=&%T:6,@)&EN<W1A;F-E<R`](&%R<F%Y*"D["@H@("`@("`@(&EF("AI<U]N
M=6QL*"1P87)A;7,I*2!["B`@("`@("`@("`@("1P87)A;7,@/2!(;W)D93HZ
M9V5T1')I=F5R0V]N9FEG*"=A=71H)RP*("`@("`@("`@("`@("`@(&ES7V%R
M<F%Y*"1D<FEV97(I(#\@)&1R:79E<ELQ72`Z("1D<FEV97(I.PH@("`@("`@
M('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92AA<G)A>2@D9')I
M=F5R+"`D<&%R86US*2D["B`@("`@("`@:68@*&5M<'1Y*"1I;G-T86YC97-;
M)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA
M='5R95T@/2`F075T:#HZ9F%C=&]R>2@D9')I=F5R+"`D<&%R86US*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D:6YS=&%N8V5S6R1S:6=N871U<F5=
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]";&]C:R\`````````````
M````````````````````````````````````````````````````````````
M````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T
M,S,W-3$`,#(P-3$U`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T)L;V-K+T-O;&QE8W1I;VXN<&AP````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`S-C4U,0`Q,#4Q-30S,S<U,0`P,C,S,S,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC
M92`G2&]R9&4O0FQO8VLN<&AP)SL*"B\J*@H@*B!4:&4@2&]R9&5?0FQO8VM?
M0V]L;&5C=&EO;CHZ(&-L87-S('!R;W9I9&5S(&%N($%022!T;R!T:&4@8FQO
M8VMS"B`J("AA<'!L971S*2!F<F%M97=O<FLN"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP+'8@,2XS-BXT+C$W
M(#(P,#8O,#,O,#@@,3<Z-3,Z-3(@8VAU8VL@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#,M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL
M+F-O+FYZ/@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($IA;B!38VAN96ED97(@
M/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-
M:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`875T
M:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@
M("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?0FQO8VL*("HO"F-L87-S
M($AO<F1E7T)L;V-K7T-O;&QE8W1I;VX@>PH*("`@("\J*@H@("`@("H@5VAA
M="!K:6YD(&]F(&)L;V-K<R!A<F4@=V4@8V]L;&5C=&EN9S\@1&5F875L=',@
M=&\@86YY+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D7W1Y<&4@/2`G<&]R=&%L)SL*"B`@("`O*BH*("`@("`J($$@:&%S
M:"!S=&]R:6YG('1H92!I;F9O<FUA=&EO;B!A8F]U="!A;&P@879A:6QA8FQE
M(&)L;V-K<R!F<F]M"B`@("`@*B!A;&P@87!P;&EC871I;VYS+@H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?8FQO8VMS(#T@
M87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@(%1H92!K:6YD(&]F(&)L;V-K
M<R!T;R!L:7-T+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A<'!S("`@5&AE(&%P
M<&QI8V%T:6]N<R!W:&]S92!B;&]C:W,@=&\@;&ES="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@2&]R9&5?0FQO8VM?0V]L;&5C=&EO;B@D='EP92`](&YU;&PL
M("1A<'!S(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H(6ES7VYU;&PH
M)'1Y<&4I*2!["B`@("`@("`@("`@("1T:&ES+3Y?='EP92`]("1T>7!E.PH@
M("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92@D87!P
M<RD["B`@("`@("`@:68@*&ES<V5T*"1?4T534TE/3ELG:&]R9&4G75LG8FQO
M8VMS)UU;)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@("1T:&ES+3Y?8FQO
M8VMS(#T@)B1?4T534TE/3ELG:&]R9&4G75LG8FQO8VMS)UU;)'-I9VYA='5R
M95T["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@(&=L
M;V)A;"`D<F5G:7-T<GD["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]"
M;&]C:RYP:'`G.PH*("`@("`@("!F;W)E86-H("@D<F5G:7-T<GDM/FQI<W1!
M<'!S*"D@87,@)&%P<"D@>PH@("`@("`@("`@("!I9B`H8V]U;G0H)&%P<',I
M("8F("%I;E]A<G)A>2@D87!P+"`D87!P<RDI('L*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0@/2`D<F5G:7-T<GDM/G!U<VA!<'`H)&%P<"DL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1B;&]C:V1I<B`]("1R96=I<W1R>2T^9V5T*"=F
M:6QE<F]O="<L("1A<'`I("X@)R]L:6(O0FQO8VLG.PH@("`@("`@("`@("`D
M9&@@/2!`;W!E;F1I<B@D8FQO8VMD:7(I.PH@("`@("`@("`@("!I9B`H:7-?
M<F5S;W5R8V4H)&1H*2D@>PH@("`@("`@("`@("`@("`@=VAI;&4@*"@D9FEL
M92`](')E861D:7(H)&1H*2D@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*'-U8G-T<B@D9FEL92P@+30I(#T]("<N<&AP)RD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D8FQO8VM?;F%M92`](&YU;&P["B`@("`@
M("`@("`@("`@("`@("`@("`@("1B;&]C:U]T>7!E(#T@;G5L;#L*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES7W)E861A8FQE*"1B;&]C:V1I<B`N
M("<O)R`N("1F:6QE*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:6YC;'5D95]O;F-E("1B;&]C:V1I<B`N("<O)R`N("1F:6QE.PH@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-?;G5L;"@D8FQO8VM?='EP92D@)B8@(6ES7VYU;&PH)'1H:7,M/E]T
M>7!E*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&)L;V-K7W1Y
M<&4@(3T@)'1H:7,M/E]T>7!E*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1B;&]C:U]N86UE*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]B;&]C:W-;
M)&%P<%U;<W5B<W1R*"1F:6QE+"`P+"`M-"E=6R=N86UE)UT@/2`D8FQO8VM?
M;F%M93L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&-L
M;W-E9&ER*"1D:"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E9VES
M=')Y+3YP;W!!<'`H)&%P<"D["B`@("`@("`@?0H*("`@("`@("!U:W-O<G0H
M)'1H:7,M/E]B;&]C:W,L"B`@("`@("`@("`@("`@(&-R96%T95]F=6YC=&EO
M;B@G)&$L("1B)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=G
M;&]B86P@)')E9VES=')Y.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!S=')C87-E8VUP*"1R96=I<W1R>2T^9V5T*")N86UE(BP@
M)&$I+"`D<F5G:7-T<GDM/F=E="@B;F%M92(L("1B*2D[)RD*("`@("`@("`@
M("`@("`@*3L*"B`@("`@("`@)%]315-324].6R=H;W)D92==6R=B;&]C:W,G
M75LD<VEG;F%T=7)E72`]("8D=&AI<RT^7V)L;V-K<SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@82!S:6YG;&4@:6YS=&%N8V4@;V8@=&AE($AO
M<F1E7T)L;V-K<R!C;&%S<RX*("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@5&AE(&MI;F0@;V8@8FQO
M8VMS('1O(&QI<W0N"B`@("`@*B!`<&%R86T@87)R87D@)&%P<',@("!4:&4@
M87!P;&EC871I;VYS('=H;W-E(&)L;V-K<R!T;R!L:7-T+@H@("`@("H*("`@
M("`J($!R971U<FX@2&]R9&5?0FQO8VM?0V]L;&5C=&EO;B`@5&AE($AO<F1E
M7T)L;V-K7T-O;&QE8W1I;VX@:6YS=&%N8V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9S:6YG;&5T;VXH)'1Y<&4@/2!N=6QL+"`D87!P<R`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC97,@/2!A<G)A>2@I.PH*
M("`@("`@("`D<VEG;F%T=7)E(#T@<V5R:6%L:7IE*&%R<F%Y*"1T>7!E+"`D
M87!P<RDI.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<ULD<VEG;F%T
M=7)E72DI('L*("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`]
M(&YE=R!(;W)D95]";&]C:U]#;VQL96-T:6]N*"1T>7!E+"`D87!P<RD["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E
M73L*("`@('T*"B`@("!F=6YC=&EO;B`F9V5T0FQO8VLH)&%P<"P@)&YA;64L
M("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T
M<GD["@H@("`@("`@("1P871H(#T@)')E9VES=')Y+3YG970H)V9I;&5R;V]T
M)RP@)&%P<"D@+B`G+VQI8B]";&]C:R\G("X@)&YA;64@+B`G+G!H<"<["B`@
M("`@("`@)&-L87-S(#T@)TAO<F1E7T)L;V-K7R<@+B`D87!P("X@)U\G("X@
M)&YA;64["B`@("`@("`@:68@*&ES7W)E861A8FQE*"1P871H*2D@>PH@("`@
M("`@("`@("!I;F-L=61E7V]N8V4@)'!A=&@["B`@("`@("`@?0H@("`@("`@
M(&EF("@A8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)&5R
M<F]R(#T@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(B5S(&YO="!F;W5N
M9"XB*2P@)&-L87-S*2D["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@
M("`@("`@?0H*("`@("`@("`D8FQO8VL@/2`F;F5W("1C;&%S<R@D<&%R86US
M*3L*("`@("`@("!R971U<FX@)&)L;V-K.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A('!R971T>2!P<FEN=&5D(&QI<W0@;V8@86QL(&%V86EL
M86)L92!B;&]C:W,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!H
M87-H('=I=&@@8FQO8VL@241S(&%S(&ME>7,@86YD(&%P<&QI8V%T:6]N('!L
M=7,@8FQO8VL*("`@("`J("`@("`@("`@("`@("`@(&)L;V-K(&YA;65S(&%S
M('9A;'5E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0FQO8VMS3&ES="@I
M"B`@("!["B`@("`@("`@<W1A=&EC("1B;&]C:W,@/2!A<G)A>2@I.PH@("`@
M("`@(&EF("@A96UP='DH)&)L;V-K<RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1B;&]C:W,["B`@("`@("`@?0H*("`@("`@("!G;&]B86P@)')E9VES=')Y
M.PH*("`@("`@("`O*B!'970@879A:6QA8FQE(&)L;V-K<R!F<F]M(&%L;"!A
M<'!S+B`J+PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?8FQO8VMS(&%S("1A
M<'`@/3X@)&%P<%]B;&]C:W,I('L*("`@("`@("`@("`@9F]R96%C:"`H)&%P
M<%]B;&]C:W,@87,@)&)L;V-K7VED(#T^("1B;&]C:RD@>PH@("`@("`@("`@
M("`@("`@)&)L;V-K<ULD87!P("X@)SHG("X@)&)L;V-K7VED72`]("1R96=I
M<W1R>2T^9V5T*"=N86UE)RP@)&%P<"D@+B`G.B`G("X@)&)L;V-K6R=N86UE
M)UT["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M8FQO8VMS.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&QA>6]U
M="!H87-H('=I=&@@86QL(&9I>&5D(&)L;V-K<R!A<R!P97(@8V]N9FEG=7)A
M=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&AA<V@@<F5P
M<F5S96YT:6YG(&$@9&5F875L="!L87EO=70@=VET:"!A;&P@9FEX960*("`@
M("`J("`@("`@("`@("`@("`@(&)L;V-K<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T1FEX961";&]C:W,H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N
M9CL*"B`@("`@("`@)&QA>6]U="`](&%R<F%Y*"D["B`@("`@("`@:68@*&ES
M<V5T*"1C;VYF6R=P;W)T86PG75LG9FEX961?8FQO8VMS)UTI*2!["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1C;VYF6R=P;W)T86PG75LG9FEX961?8FQO8VMS
M)UT@87,@)&)L;V-K*2!["B`@("`@("`@("`@("`@("!L:7-T*"1A<'`L("1T
M>7!E*2`](&5X<&QO9&4H)SHG+"`D8FQO8VLL(#(I.PH@("`@("`@("`@("`@
M("`@)&QA>6]U=%M=(#T@87)R87DH87)R87DH)V%P<"<@/3X@)&%P<"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P87)A;7,G
M(#T^(&%R<F%Y*"=T>7!E)R`]/B`D='EP92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P87)A
M;7,G(#T^(&9A;'-E*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=H96EG:'0G(#T^(#$L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G=VED=&@G(#T^(#$I*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1L87EO=70["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<V5L96-T('=I9&=E="!W:71H
M(&%L;"!A=F%I;&%B;&4@8FQO8VMS+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&-U<E]A<'`@("`@5&AE(&)L;V-K(&9R;VT@=&AI<R!A<'!L:6-A
M=&EO;B!G971S('-E;&5C=&5D+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8W5R
M7V)L;V-K("!4:&4@8FQO8VL@=VET:"!T:&ES(&YA;64@9V5T<R!S96QE8W1E
M9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('-E;&5C="!T
M86<@=VET:"!A;&P@879A:6QA8FQE(&)L;V-K<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T0FQO8VMS5VED9V5T*"1C=7)?87!P(#T@;G5L;"P@)&-U<E]B
M;&]C:R`](&YU;&PL("1O;F-H86YG92`](&9A;'-E*0H@("`@>PH@("`@("`@
M(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@("1W:61G970@/2`G/'-E;&5C
M="!N86UE/2)A<'`B)SL*("`@("`@("!I9B`H)&]N8VAA;F=E*2!["B`@("`@
M("`@("`@("1W:61G970@+CT@)R!O;F-H86YG93TB9&]C=6UE;G0N8FQO8VMF
M;W)M+F%C=&EO;BYV86QU93U<)W-A=F4M<F5S=6UE7"<[9&]C=6UE;G0N8FQO
M8VMF;W)M+G-U8FUI="@I(B<["B`@("`@("`@?0H@("`@("`@("1W:61G970@
M+CT@(CY<;B(["B`@("`@("`@)&)L;V-K<U]L:7-T(#T@)'1H:7,M/F=E=$)L
M;V-K<TQI<W0H*3L*("`@("`@("!F;W)E86-H("@D8FQO8VMS7VQI<W0@87,@
M)&ED(#T^("1N86UE*2!["B`@("`@("`@("`@("1W:61G970@+CT@<W!R:6YT
M9B@B/&]P=&EO;B!V86QU93U<(B5S7"(E<SXE<SPO;W!T:6]N/EQN(BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:60L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*"1I9"`]/2`D8W5R7V%P<"`N
M("<Z)R`N("1C=7)?8FQO8VLI(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z
M("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE
M*3L*("`@("`@("!]"B`@("`@("`@)'=I9&=E="`N/2`B/"]S96QE8W0^7&XB
M.PH*("`@("`@("!R971U<FX@)'=I9&=E=#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE(&]P=&EO;B!T>7!E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971/<'1I;VY4>7!E*"1A<'`L("1B;&]C:RP@)'!A<F%M7VED*0H@
M("`@>PH@("`@("`@("1T:&ES+3YG971087)A;7,H)&%P<"P@)&)L;V-K*3L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]B;&]C:W-;)&%P<%U;)&)L;V-K75LG
M<&%R86US)UU;)'!A<F%M7VED75LG='EP92==.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!W:&5T:&5R('1H92!O<'1I;VX@:7,@<F5Q=6ER960@
M;W(@;F]T+B!$969A=6QT<R!T;R!T<G5E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971/<'1I;VY297%U:7)E9"@D87!P+"`D8FQO8VLL("1P87)A;5]I9"D*
M("`@('L*("`@("`@("`D=&AI<RT^9V5T4&%R86US*"1A<'`L("1B;&]C:RD[
M"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V)L;V-K<ULD87!P75LD8FQO
M8VM=6R=P87)A;7,G75LD<&%R86U?:61=6R=R97%U:7)E9"==*2D@>PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]B;&]C:W-;)&%P<%U;)&)L;V-K75LG<&%R
M86US)UU;)'!A<F%M7VED75LG<F5Q=6ER960G73L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!V86QU97,@9F]R(&%N(&]P
M=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$]P=&EO;E9A;'5E<R@D
M87!P+"`D8FQO8VLL("1P87)A;5]I9"D*("`@('L*("`@("`@("`D=&AI<RT^
M9V5T4&%R86US*"1A<'`L("1B;&]C:RD["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?8FQO8VMS6R1A<'!=6R1B;&]C:UU;)W!A<F%M<R==6R1P87)A;5]I9%U;
M)W9A;'5E<R==.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M=VED9V5T(&YE8V5S<V%R>2!T;R!C;VYF:6=U<F4@=&AI<R!B;&]C:RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T3W!T:6]N<U=I9&=E="@D87!P+"`D8FQO
M8VLL("1P87)A;5]I9"P@)'9A;"`](&YU;&PI"B`@("!["B`@("`@("`@)'=I
M9&=E="`]("<G.PH*("`@("`@("`D=&AI<RT^9V5T4&%R86US*"1A<'`L("1B
M;&]C:RD["B`@("`@("`@)'!A<F%M(#T@)'1H:7,M/E]B;&]C:W-;)&%P<%U;
M)&)L;V-K75LG<&%R86US)UU;)'!A<F%M7VED73L*("`@("`@("!I9B`H(6ES
M<V5T*"1P87)A;5LG9&5F875L="==*2D@>PH@("`@("`@("`@("`D<&%R86U;
M)V1E9F%U;'0G72`]("<G.PH@("`@("`@('T*"B`@("`@("`@<W=I=&-H("@D
M<&%R86U;)W1Y<&4G72D@>PH@("`@("`@(&-A<V4@)V)O;VQE86XG.@H@("`@
M("`@(&-A<V4@)V-H96-K8F]X)SH*("`@("`@("`@("`@)&-H96-K960@/2`A
M96UP='DH)'9A;%LD<&%R86U?:61=*2`_("<@8VAE8VME9#TB8VAE8VME9"(G
M(#H@)R<["B`@("`@("`@("`@("1W:61G970@/2!S<')I;G1F*"<\:6YP=70@
M='EP93TB8VAE8VMB;W@B(&YA;64](G!A<F%M<ULE<UTB)7,@+SXG+"`D<&%R
M86U?:60L("1C:&5C:V5D*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@)V5N=6TG.@H@("`@("`@("`@("`D=VED9V5T(#T@<W!R:6YT9B@G
M/'-E;&5C="!N86UE/2)P87)A;7-;)7-=(CXG+"`D<&%R86U?:60I.PH@("`@
M("`@("`@("!F;W)E86-H("@D<&%R86U;)W9A;'5E<R==(&%S("1K97D@/3X@
M)&YA;64I('L*("`@("`@("`@("`@("`@(&EF("A3=')I;F<Z.FQE;F=T:"@D
M;F%M92D@/B`S,"D@>PH@("`@("`@("`@("`@("`@("`@("1N86UE(#T@<W5B
M<W1R*"1N86UE+"`P+"`R-RD@+B`G+BXN)SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1W:61G970@+CT@<W!R:6YT9B@B/&]P=&EO;B!V
M86QU93U<(B5S7"(E<SXE<SPO;W!T:6]N/EQN(BP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!H=&UL<W!E8VEA;&-H87)S*"1K97DI+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("AI<W-E="@D=F%L
M6R1P87)A;5]I9%TI("8F("1V86Q;)'!A<F%M7VED72`]/2`D:V5Y*2`_("<@
M<V5L96-T960](G-E;&5C=&5D(B<@.B`G)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!H=&UL<W!E8VEA;&-H87)S*"1N86UE*2D["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1W:61G970@+CT@)SPO<V5L96-T
M/B<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=M=6QT:65N
M=6TG.@H@("`@("`@("`@("`D=VED9V5T(#T@<W!R:6YT9B@G/'-E;&5C="!M
M=6QT:7!L93TB;75L=&EP;&4B(&YA;64](G!A<F%M<ULE<UU;72(^)RP@)'!A
M<F%M7VED*3L*("`@("`@("`@("`@9F]R96%C:"`H)'!A<F%M6R=V86QU97,G
M72!A<R`D:V5Y(#T^("1N86UE*2!["B`@("`@("`@("`@("`@("!I9B`H4W1R
M:6YG.CIL96YG=&@H)&YA;64I(#X@,S`I('L*("`@("`@("`@("`@("`@("`@
M("`D;F%M92`]('-U8G-T<B@D;F%M92P@,"P@,C<I("X@)RXN+B<["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=VED9V5T("X]('-P<FEN
M=&8H(CQO<'1I;VX@=F%L=64]7"(E<UPB)7,^)7,\+V]P=&EO;CY<;B(L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:'1M;'-P96-I86QC
M:&%R<R@D:V5Y*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`H:7-S970H)'9A;%LD<&%R86U?:61=*2`F)B!I;E]A<G)A>2@D:V5Y+"`D
M=F%L6R1P87)A;5]I9%TI*2`_("<@<V5L96-T960](G-E;&5C=&5D(B<@.B`G
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!H=&UL<W!E
M8VEA;&-H87)S*"1N86UE*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1W:61G970@+CT@)SPO<V5L96-T/B<["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!C87-E("=M;&5N=6TG.@H@("`@("`@("`@("`O+R!-=6QT:2UL
M979E;"!E;G5M+@H@("`@("`@("`@("!I9B`H:7-?87)R87DH)'9A;"D@)B8@
M:7-S970H)'9A;%LG7U\G("X@)'!A<F%M7VED72DI('L*("`@("`@("`@("`@
M("`@("1F:7)S='9A;"`]("1V86Q;)U]?)R`N("1P87)A;5]I9%T["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&UP(#T@87)R87E?
M:V5Y<R@D<&%R86U;)W9A;'5E<R==*3L*("`@("`@("`@("`@("`@("1F:7)S
M='9A;"`](&-U<G)E;G0H)'1M<"D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)&)L;V-K=F%L=65S(#T@)'!A<F%M6R=V86QU97,G75LD9FER<W1V86Q=
M.PH@("`@("`@("`@("!A<V]R="@D8FQO8VMV86QU97,I.PH*("`@("`@("`@
M("`@)'=I9&=E="`]('-P<FEN=&8H)SQS96QE8W0@;F%M93TB<&%R86US6U]?
M)7-=(B!O;F-H86YG93TB9&]C=6UE;G0N8FQO8VMF;W)M+F%C=&EO;BYV86QU
M93U<)W-A=F4M<F5S=6UE7"<[9&]C=6UE;G0N8FQO8VMF;W)M+G-U8FUI="@I
M(CXG+"`D<&%R86U?:60I("X@(EQN(CL*("`@("`@("`@("`@9F]R96%C:"`H
M)'!A<F%M6R=V86QU97,G72!A<R`D:V5Y(#T^("1V86QU97,I('L*("`@("`@
M("`@("`@("`@("1N86UE(#T@4W1R:6YG.CIL96YG=&@H)&ME>2D@/B`S,"`_
M(%-T<FEN9SHZ<W5B<W1R*"1K97DL(#`L(#(W*2`N("<N+BXG(#H@)&ME>3L*
M("`@("`@("`@("`@("`@("1W:61G970@+CT@<W!R:6YT9B@B/&]P=&EO;B!V
M86QU93U<(B5S7"(E<SXE<SPO;W!T:6]N/EQN(BP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!H=&UL<W!E8VEA;&-H87)S*"1K97DI+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1K97D@/3T@)&9I
M<G-T=F%L(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&AT;6QS<&5C:6%L8VAA<G,H
M)&YA;64I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=VED9V5T("X]
M("(\+W-E;&5C=#X\8G(@+SY<;B(["@H@("`@("`@("`@("`D=VED9V5T("X]
M('-P<FEN=&8H(CQS96QE8W0@;F%M93U<(G!A<F%M<ULE<UU<(CY<;B(L("1P
M87)A;5]I9"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1B;&]C:W9A;'5E<R!A
M<R`D:V5Y(#T^("1N86UE*2!["B`@("`@("`@("`@("`@("`D;F%M92`]("A3
M=')I;F<Z.FQE;F=T:"@D;F%M92D@/B`S,"D@/R!3=')I;F<Z.G-U8G-T<B@D
M;F%M92P@,"P@,C<I("X@)RXN+B<@.B`D;F%M93L*("`@("`@("`@("`@("`@
M("1W:61G970@+CT@<W!R:6YT9B@B/&]P=&EO;B!V86QU93U<(B5S7"(E<SXE
M<SPO;W!T:6]N/EQN(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!H=&UL<W!E8VEA;&-H87)S*"1K97DI+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1V86Q;)'!A<F%M7VED72`]/2`D:V5Y(#\@
M)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&AT;6QS<&5C:6%L8VAA<G,H)&YA;64I*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D=VED9V5T("X]("(\+W-E;&5C
M=#X\8G(@+SY<;B(["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M("=C;VQO<B<Z"B`@("`@("`@("`@("1V86P@/2!I<W-E="@D8FQO8VLM/E]P
M87)A;7-;)'!A<F%M7VED72D@/R`D8FQO8VLM/E]P87)A;7-;)'!A<F%M7VED
M72`Z("<G.PH@("`@("`@("`@("`D=VED9V5T(#T@<W!R:6YT9B@G/&EN<'5T
M('-T>6QE/2)B86-K9W)O=6YD+6-O;&]R.B5S(B!T>7!E/2)T97AT(B!N86UE
M/2)P87)A;7-;)7-=(B!V86QU93TB)7,B("\^)RP@)'9A;"P@)'!A<F%M7VED
M+"`D=F%L*3L*("`@("`@("`@("`@)'5R;"`@/2`D<F5G:7-T<GDM/F=E="@G
M=V5B<F]O="<L("=H;W)D92<I.PH@("`@("`@("`@("`D=7)L("X](%5T:6PZ
M.F%D9%!A<F%M971E<B@G+W-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP
M:'`_=&%R9V5T/7!A<F%M<ULG("X@)'!A<F%M7VED("X@)UTG+"`G9F]R;2<L
M("=B;&]C:V9O<FTG*3L*("`@("`@("`@("`@)'=I9&=E="`N/2!S<')I;G1F
M*"<\82!H<F5F/2(E<R(@;VYC;&EC:STB=VEN9&]W+F]P96XH7"<E<UPG+"!<
M)V-O;&]R<&EC:V5R7"<L(%PG=&]O;&)A<CUN;RQL;V-A=&EO;CUN;RQS=&%T
M=7,];F\L<V-R;VQL8F%R<SUN;RQR97-I>F%B;&4];F\L=VED=&@],3(P+&AE
M:6=H=#TR-3`L;&5F=#TQ,#`L=&]P/3$P,%PG*3L@<F5T=7)N(&9A;'-E.R(@
M;VYM;W5S96]U=#TB=VEN9&]W+G-T871U<SU<)UPG.R(@;VYM;W5S96]V97(]
M(G=I;F1O=RYS=&%T=7,]7"<E<UPG.R!R971U<FX@=')U93LB(&-L87-S/2)W
M:61G970B('1A<F=E=#TB8V]L;W)P:6-K97(B/B<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=7)L+"`D=7)L+"!?*")#;VQO<B!0:6-K97(B
M*2D["B`@("`@("`@("`@("1W:61G970@+CT@2&]R9&4Z.FEM9R@G8V]L;W)P
M:6-K97(N<&YG)RP@7R@B0V]L;W(@4&EC:V5R(BDL("=H96EG:'0](C$V(B<L
M("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI.PH@("`@("`@("`@
M("`D=VED9V5T("X]("<\+V$^)SL*("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@(&-A<V4@)VEN="<Z"B`@("`@("`@8V%S92`G=&5X="<Z"B`@("`@("`@
M("`@("1W:61G970@/2!S<')I;G1F*"<\:6YP=70@='EP93TB=&5X="(@;F%M
M93TB<&%R86US6R5S72(@=F%L=64](B5S(B`O/B<L("1P87)A;5]I9"P@(6ES
M<V5T*"1V86Q;)'!A<F%M7VED72D@/R`D<&%R86U;)V1E9F%U;'0G72`Z("1V
M86Q;)'!A<F%M7VED72D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C
M87-E("=E<G)O<B<Z"B`@("`@("`@("`@("1W:61G970@/2`G/'-P86X@8VQA
M<W,](F9O<FTM97)R;W(B/B<@+B`D<&%R86U;)V1E9F%U;'0G72`N("<\+W-P
M86X^)SL*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)'=I9&=E=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE(&YA;64@;V8@=&AE('-P96-I9FEE9"!B;&]C:RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1A<'`@("`@06X@87!P;&EC871I;VX@;F%M92X*
M("`@("`J($!P87)A;2!S=')I;F<@)&)L;V-K("!!(&)L;V-K(&YA;64N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!N86UE(&]F('1H92!S
M<&5C:69I960@8FQO8VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$YA;64H
M)&%P<"P@)&)L;V-K*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]B;&]C:W-;)&%P<%U;)&)L;V-K72DI('L*("`@("`@("`@("`@<F5T=7)N
M('-P<FEN=&8H7R@B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<
M(B!N;W0@9F]U;F0N(BDL("1B;&]C:RP@)&%P<"D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D=&AI<RT^7V)L;V-K<ULD87!P75LD8FQO8VM=6R=N86UE
M)UT["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!P87)A;65T
M97(@;&ES="!O9B!T:&4@<W!E8VEF:65D(&)L;V-K+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&%P<"`@("!!;B!A<'!L:6-A=&EO;B!N86UE+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D8FQO8VL@($$@8FQO8VL@;F%M92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!W:71H(&%L;"!P
M87)A;71E<B!N86UE<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%R86US
M*"1A<'`L("1B;&]C:RD*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?8FQO8VMS6R1A<'!=6R1B;&]C:UU;)W!A<F%M<R==*2D@>PH@("`@("`@
M("`@("`D8FQO8VM/8B`]("8D=&AI<RT^9V5T0FQO8VLH)&%P<"P@)&)L;V-K
M*3L*("`@("`@("`@("`@:68@*&ES7V$H)&)L;V-K3V(L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D8FQO8VM/8CL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V)L;V-K<ULD87!P75LD8FQO
M8VM=6R=P87)A;7,G72`]("1B;&]C:T]B+3YG971087)A;7,H*3L*("`@("`@
M("!]"@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V)L;V-K<ULD87!P75LD
M8FQO8VM=6R=P87)A;7,G72D@)B8*("`@("`@("`@("`@:7-?87)R87DH)'1H
M:7,M/E]B;&]C:W-;)&%P<%U;)&)L;V-K75LG<&%R86US)UTI*2!["B`@("`@
M("`@("`@(')E='5R;B!A<G)A>5]K97ES*"1T:&ES+3Y?8FQO8VMS6R1A<'!=
M6R1B;&]C:UU;)W!A<F%M<R==*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@87)R87DH*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92`H8VQE87(@=&5X="D@;F%M92!O9B!T:&4@
M<W!E8VEF:65D('!A<F%M971E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1A<'`@("`@06X@87!P;&EC871I;VX@;F%M92X*("`@("`J($!P87)A
M;2!S=')I;F<@)&)L;V-K("!!(&)L;V-K(&YA;64N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P87)A;2`@02!P87)A;65T97(@;F%M92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(&YA;64@;V8@=&AE('-P96-I9FEE9"!P
M87)A;65T97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<F%M3F%M92@D
M87!P+"`D8FQO8VLL("1P87)A;2D*("`@('L*("`@("`@("`D=&AI<RT^9V5T
M4&%R86US*"1A<'`L("1B;&]C:RD["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M8FQO8VMS6R1A<'!=6R1B;&]C:UU;)W!A<F%M<R==6R1P87)A;5U;)VYA;64G
M73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&1E9F%U;'0@
M=F%L=64@;V8@=&AE('-P96-I9FEE9"!P87)A;65T97(N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D87!P("`@($%N(&%P<&QI8V%T:6]N(&YA;64N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1B;&]C:R`@02!B;&]C:R!N86UE+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<&%R86T@($$@<&%R86UE=&5R(&YA;64N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D969A=6QT('9A
M;'5E(&]F('1H92!S<&5C:69I960@<&%R86UE=&5R(&]R(&YU;&PN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$1E9F%U;'1686QU92@D87!P+"`D8FQO8VLL
M("1P87)A;2D*("`@('L*("`@("`@("`D=&AI<RT^9V5T4&%R86US*"1A<'`L
M("1B;&]C:RD["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8FQO8VMS6R1A
M<'!=6R1B;&]C:UU;)W!A<F%M<R==6R1P87)A;5U;)V1E9F%U;'0G72DI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8FQO8VMS6R1A<'!=6R1B;&]C
M:UU;)W!A<F%M<R==6R1P87)A;5U;)V1E9F%U;'0G73L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&EF('1H92!S<&5C:69I960@8FQO8VL@:7,@8W5S=&]M:7IE86)L92!B
M>2!T:&4@=7-E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@
M("`@06X@87!P;&EC871I;VX@;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@
M)&)L;V-K("!!(&)L;V-K(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!4<G5E(&ES('1H92!B;&]C:R!I<R!C=7-T;VUI>F5A8FQE+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!I<T5D:71A8FQE*"1A<'`L("1B;&]C:RD*
M("`@('L*("`@("`@("`D=&AI<RT^9V5T4&%R86US*"1A<'`L("1B;&]C:RD[
M"B`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES+3Y?8FQO8VMS6R1A<'!=6R1B
M;&]C:UU;)W!A<F%M<R==*2`F)@H@("`@("`@("`@("!C;W5N="@D=&AI<RT^
M7V)L;V-K<ULD87!P75LD8FQO8VM=6R=P87)A;7,G72D["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]";&]C:R],87EO=70O````````````````````````````````````
M````````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-3$`,#(Q-S<R`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<``````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$S,S(Q-P`Q,#4Q-30S,S<U,0`P
M,C0P-C0`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O07)R87DN<&AP)SL*"B\J
M*@H@*B!4:&4@2&]R9&5?0FQO8VM?3&%Y;W5T7TUA;F%G97(@8VQA<W,@86QL
M;W=S(&UA;FEP=6QA=&EO;B!O9@H@*B!(;W)D95]";&]C:R!L87EO=71S+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`L=B`Q+C0N,BXS(#(P,#8O,#,O,#@@,3<Z-30Z,#@@8VAU8VL@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6ME($-O8VAR86YE
M(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!#;W!Y<FEG:'0@,C`P,RTR
M,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH
M86QL+F-O+FYZ/@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R
M9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C(*("H@0'!A8VMA9V4@2&]R
M9&5?0FQO8VL*("HO"F-L87-S($AO<F1E7T)L;V-K7TQA>6]U=%]-86YA9V5R
M('L*"B`@("`O*BH*("`@("`J($]U<B!(;W)D95]";&]C:U]#;VQL96-T:6]N
M(&EN<W1A;F-E+@H@("`@("H*("`@("`J($!V87(@2&]R9&5?0FQO8VM?0V]L
M;&5C=&EO;@H@("`@("HO"B`@("!V87(@)%]C;VQL96-T:6]N.PH*("`@("\J
M*@H@("`@("H@5&AE(&-U<G)E;G0@8FQO8VL@;&%Y;W5T+@H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?;&%Y;W5T(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("`J($$@8V%C:&4@9F]R('1H92!B;&]C:R!O
M8FIE8W1S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1?8FQO8VMS(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!M
M87AI;75M(&YU;6)E<B!O9B!C;VQU;6YS+@H@("`@("H*("`@("`J($!V87(@
M:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]C;VQU;6YS(#T@,#L*"B`@("`O
M*BH*("`@("`J($AA<R!T:&4@;&%Y;W5T(&)E96X@=7!D871E9"!S:6YC92!I
M="!W87,@:6YS=&%N=&EA=&5D+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A
M;@H@("`@("HO"B`@("!V87(@)%]U<&1A=&5D(#T@9F%L<V4["@H@("`@+RHJ
M"B`@("`@*B!4:&4@8W5R<F5N="!B;&]C:R`H87)R87DZ(%MR;W<L(&-O;%TI
M+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M8W5R<F5N=$)L;V-K(#T@87)R87DH;G5L;"P@;G5L;"D["@H@("`@+RHJ"B`@
M("`@*B!4:&4@;F5W(')O=R!O9B!T:&4@;&%S="!C:&%N9V5D(&)L;V-K+@H@
M("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]C
M:&%N9V5D7W)O=R`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!4:&4@;F5W(&-O
M;'5M;B!O9B!T:&4@;&%S="!C:&%N9V5D(&)L;V-K+@H@("`@("H*("`@("`J
M($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]C:&%N9V5D7V-O;"`]
M(&YU;&P["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@
M("`@*B!`<&%R86T@2&]R9&5?0FQO8VM?0V]L;&5C=&EO;B`F)&-O;&QE8W1I
M;VX*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&$*("`@("`J+PH@("`@9G5N
M8W1I;VX@2&]R9&5?0FQO8VM?3&%Y;W5T7TUA;F%G97(H)B1C;VQL96-T:6]N
M+"`D9&%T82`]("<G*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8V]L;&5C=&EO
M;B`]("8D8V]L;&5C=&EO;CL*("`@("`@("`D=&AI<RT^=6YS97)I86QI>F4H
M)&1A=&$I.PH*("`@("`@("`O+R!&:6QL('1H92!?8V]V97)E9"!C86-H97,@
M86YD(&5M<'1Y(')O=W,N"B`@("`@("`@)')O=W,@/2!C;W5N="@D=&AI<RT^
M7VQA>6]U="D["B`@("`@("`@)&5M<'1Y(#T@87)R87DH*3L*("`@("`@("!F
M;W(@*"1R;W<@/2`P.R`D<F]W(#P@)')O=W,[("1R;W<K*RD@>PH@("`@("`@
M("`@("`D8V]L<R`](&-O=6YT*"1T:&ES+3Y?;&%Y;W5T6R1R;W==*3L*("`@
M("`@("`@("`@:68@*"%I<W-E="@D96UP='E;)')O=UTI*2!["B`@("`@("`@
M("`@("`@("`D96UP='E;)')O=UT@/2!T<G5E.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&9O<B`H)&-O;"`](#`[("1C;VP@/"`D8V]L<SL@)&-O;"LK
M*2!["B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;&%Y;W5T
M6R1R;W==6R1C;VQ=*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M8FQO8VMS6R1R;W==6R1C;VQ=(#T@4$5!4CHZ<F%I<V5%<G)O<BA?*").;R!B
M;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(I+"`G:&]R
M9&4N97)R;W(G*3L*("`@("`@("`@("`@("`@('T@96QS96EF("AI<U]A<G)A
M>2@D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L72DI('L*("`@("`@("`@("`@
M("`@("`@("`D9FEE;&0@/2`D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L73L*
M"B`@("`@("`@("`@("`@("`@("`@)&5M<'1Y6R1R;W==(#T@9F%L<V4["B`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1F:65L9%LG=VED=&@G72DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`](#$[("1I(#P@
M)&9I96QD6R=W:61T:"==.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L("L@)&E=(#T@)V-O
M=F5R960G.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9FEE
M;&1;)VAE:6=H="==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1F:65L9%LG=VED=&@G72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1F:65L9%LG=VED=&@G72`](#$["B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`]
M(#$[("1I(#P@)&9I96QD6R=H96EG:'0G73L@)&DK*RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=R`K("1I75LD
M8V]L72`]("=C;W9E<F5D)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&9O<B`H)&H@/2`Q.R`D:B`\("1F:65L9%LG=VED=&@G73L@)&HK*RD@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T
M6R1R;W<@*R`D:5U;)&-O;"`K("1J72`]("=C;W9E<F5D)SL*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1E;7!T>5LD<F]W("L@)&E=(#T@9F%L<V4["B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O(%-T<FEP(&5M
M<'1Y(&)L;V-K<R!F<F]M('1H92!E;F0@;V8@=&AE(')O=W,N"B`@("`@("`@
M("`@(&9O<B`H)&-O;"`]("1C;VQS("T@,3L@)&-O;"`^/2`P.R`D8V]L+2TI
M('L*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]L87EO=71;
M)')O=UU;)&-O;%TI('Q\"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L
M87EO=71;)')O=UU;)&-O;%T@/3T@)V5M<'1Y)RD@>PH@("`@("`@("`@("`@
M("`@("`@('5N<V5T*"1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=*3L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1T:&ES+3Y?8V]L=6UN<R`](&UA>"@D=&AI<RT^7V-O;'5M;G,L(&-O
M=6YT*"1T:&ES+3Y?;&%Y;W5T6R1R;W==*2D["B`@("`@("`@?0H*("`@("`@
M("`O+R!&:6QL(&%L;"!R;W=S('5P('1O('1H92!S86UE(&QE;F=T:"X*("`@
M("`@("`D;&%Y;W5T(#T@87)R87DH*3L*("`@("`@("!F;W(@*"1R;W<@/2`P
M.R`D<F]W(#P@)')O=W,[("1R;W<K*RD@>PH@("`@("`@("`@("`D8V]L<R`]
M(&-O=6YT*"1T:&ES+3Y?;&%Y;W5T6R1R;W==*3L*("`@("`@("`@("`@:68@
M*"1C;VQS(#P@)'1H:7,M/E]C;VQU;6YS*2!["B`@("`@("`@("`@("`@("!F
M;W(@*"1C;VP@/2`D8V]L<SL@)&-O;"`\("1T:&ES+3Y?8V]L=6UN<SL@)&-O
M;"LK*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O
M=UU;)&-O;%T@/2`G96UP='DG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1L87EO=71;72`]("1T:&ES+3Y?;&%Y;W5T
M6R1R;W==.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]L87EO=70@/2`D
M;&%Y;W5T.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5R:6%L:7IE(&%N9"!R
M971U<FX@=&AE(&-U<G)E;G0@8FQO8VL@;&%Y;W5T+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!S97)I86QI>F4H*0H@("`@>PH@("`@("`@(')E='5R;B!S97)I
M86QI>F4H)'1H:7,M/E]L87EO=70I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5S971S('1H92!C=7)R96YT(&QA>6]U="!T;R!T:&4@=F%L=64@<W1O<F5D
M(&EN('1H92!P<F5F97)E;F-E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@=6YS
M97)I86QI>F4H)&1A=&$I"B`@("!["B`@("`@("`@)'1H:7,M/E]L87EO=70@
M/2!`=6YS97)I86QI>F4H)&1A=&$I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!A('-I;F=L92!I;G-T86YC92!O9B!T:&4@2&]R9&5?0FQO8VM?
M3&%Y;W5T7TUA;F%G97(@8VQA<W,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;F%M90H@("`@("H@0'!A<F%M($AO<F1E7T)L;V-K7T-O;&QE8W1I
M;VX@)B1C;VQL96-T:6]N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A"B`@
M("`@*@H@("`@("H@0'-T871I8PH@("`@("H*("`@("`J($!R971U<FX@2&]R
M9&5?0FQO8VM?3&%Y;W5T7TUA;F%G97(@(%1H92!(;W)D95]";&]C:U],87EO
M=71?36%N86=E<B!I;G-T86YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I
M;F=L971O;B@D;F%M92P@)B1C;VQL96-T:6]N+"`D9&%T82`]("<G*0H@("`@
M>PH@("`@("`@('-T871I8R`D:6YS=&%N8V5S(#T@87)R87DH*3L*("`@("`@
M("!I9B`H(6ES<V5T*"1I;G-T86YC97-;)&YA;65=*2D@>PH@("`@("`@("`@
M("`D:6YS=&%N8V5S6R1N86UE72`](&YE=R!(;W)D95]";&]C:U],87EO=71?
M36%N86=E<B@D8V]L;&5C=&EO;BP@)&1A=&$I.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)&EN<W1A;F-E<ULD;F%M95T["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!0<F]C97-S(&$@;6]D:69I8V%T:6]N('1O('1H92!C=7)R96YT(&QA
M>6]U="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9R`D86-T:6]N"B`@("`@
M*B!`=F%R(&EN=&5G97(@)')O=PH@("`@("H@0'9A<B!I;G1E9V5R("1C;VP*
M("`@("`J+PH@("`@9G5N8W1I;VX@:&%N9&QE*"1A8W1I;VXL("1R;W<L("1C
M;VPI"B`@("!["B`@("`@("`@<W=I=&-H("@D86-T:6]N*2!["B`@("`@("`@
M8V%S92`G;6]V955P)SH*("`@("`@("!C87-E("=M;W9E1&]W;B<Z"B`@("`@
M("`@8V%S92`G;6]V94QE9G0G.@H@("`@("`@(&-A<V4@)VUO=F52:6=H="<Z
M"B`@("`@("`@8V%S92`G97AP86YD57`G.@H@("`@("`@(&-A<V4@)V5X<&%N
M9$1O=VXG.@H@("`@("`@(&-A<V4@)V5X<&%N9$QE9G0G.@H@("`@("`@(&-A
M<V4@)V5X<&%N9%)I9VAT)SH*("`@("`@("!C87-E("=S:')I;FM,969T)SH*
M("`@("`@("!C87-E("=S:')I;FM2:6=H="<Z"B`@("`@("`@8V%S92`G<VAR
M:6YK57`G.@H@("`@("`@(&-A<V4@)W-H<FEN:T1O=VXG.@H@("`@("`@(&-A
M<V4@)W)E;6]V94)L;V-K)SH*("`@("`@("`@("`@)')E<W5L="`](&-A;&Q?
M=7-E<E]F=6YC*&%R<F%Y*"8D=&AI<RP@)&%C=&EO;BDL("1R;W<L("1C;VPI
M.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG;F]T:69I8V%T:6]N)UTM
M/G!U<V@H)')E<W5L="D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7W5P9&%T960@/2!T<G5E.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`O+R!3879E('1H92!C:&%N
M9V5S(&UA9&4@=&\@82!B;&]C:RX*("`@("`@("!C87-E("=S879E)SH*("`@
M("`@("`O+R!3879E('1H92!C:&%N9V5S(&UA9&4@=&\@82!B;&]C:R!A;F0@
M8V]N=&EN=64@961I=&EN9RX*("`@("`@("!C87-E("=S879E+7)E<W5M92<Z
M"B`@("`@("`@("`@("\O($=E="!R97%U97-T960@8FQO8VL@='EP92X*("`@
M("`@("`@("`@;&ES="@D;F5W87!P+"`D;F5W='EP92D@/2!E>'!L;V1E*"<Z
M)RP@571I;#HZ9V5T1F]R;41A=&$H)V%P<"<I*3L*"B`@("`@("`@("`@("\O
M($ES('1H:7,@82!N97<@8FQO8VL_"B`@("`@("`@("`@("1N97<@/2!F86QS
M93L*("`@("`@("`@("`@:68@*"1T:&ES+3YI<T5M<'1Y*"1R;W<L("1C;VPI
M('Q\"B`@("`@("`@("`@("`@("`A)'1H:7,M/G)O=T5X:7-T<R@D<F]W*2!\
M?`H@("`@("`@("`@("`@("`@(21T:&ES+3YC;VQ%>&ES=',H)&-O;"DI('L*
M("`@("`@("`@("`@("`@("\O($-H96-K('!E<FUI<W-I;VYS+@H@("`@("`@
M("`@("`@("`@:68@*$AO<F1E.CIH87-097)M:7-S:6]N*"=M87A?8FQO8VMS
M)RD@(3T]('1R=64@)B8*("`@("`@("`@("`@("`@("`@("!(;W)D93HZ:&%S
M4&5R;6ES<VEO;B@G;6%X7V)L;V-K<R<I(#P]("1T:&ES+3YC;W5N="@I*2![
M"B`@("`@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!`:'1M;'-P96-I86QC
M:&%R<RAS<')I;G1F*%\H(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E
M(&UO<F4@=&AA;B`E9"!B;&]C:W,N(BDL($AO<F1E.CIH87-097)M:7-S:6]N
M*"=M87A?8FQO8VMS)RDI+"!%3E1?0T]-4$%4+"!.3%,Z.F=E=$-H87)S970H
M*2D["B`@("`@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG:&]O
M:W,G75LG<&5R;7-D96YI960G72DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&UE<W-A9V4@/2!(;W)D93HZ8V%L;$AO;VLH)U]P97)M<U]H;V]K7V1E
M;FEE9"<L(&%R<F%Y*"=H;W)D93IM87A?8FQO8VMS)RDL("=H;W)D92<L("1M
M97-S86=E*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@)$=,3T)!3%-;)VYO=&EF:6-A=&EO;B==+3YP=7-H*"1M97-S86=E
M+"`G:&]R9&4N97)R;W(G+"!A<G)A>2@G8V]N=&5N="YR87<G*2D["B`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`@("`@)&YE=R`]('1R=64["B`@("`@("`@("`@("`@("`O+R!-
M86ME('-U<F4@=&AE<F4@:7,@<V]M97=H97)E('1O('!U="!I="X*("`@("`@
M("`@("`@("`@("1T:&ES+3YA9&1";&]C:R@D<F]W+"`D8V]L*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@+R\@3W(@86X@97AI<W1I;F<@;VYE/PH@
M("`@("`@("`@("`D97AI<W1S(#T@9F%L<V4["B`@("`@("`@("`@("1C:&%N
M9V5D(#T@9F%L<V4["B`@("`@("`@("`@(&EF("@A)&YE=RD@>PH@("`@("`@
M("`@("`@("`@+R\@1V5T('1A<F=E="!B;&]C:R!I;F9O+@H@("`@("`@("`@
M("`@("`@)&EN9F\@/2`D=&AI<RT^9V5T0FQO8VM);F9O*"1R;W<L("1C;VPI
M.PH@("`@("`@("`@("`@("`@)&5X:7-T<R`]("1T:&ES+3YI<T)L;V-K*"1R
M;W<L("1C;VPI.PH@("`@("`@("`@("`@("`@+R\@2&%S(&$@9&EF9F5R96YT
M(&)L;V-K(&)E96X@<V5L96-T960_"B`@("`@("`@("`@("`@("!I9B`H)&5X
M:7-T<R`F)@H@("`@("`@("`@("`@("`@("`@("@D:6YF;ULG87!P)UT@(3T@
M)&YE=V%P<"!\?`H@("`@("`@("`@("`@("`@("`@("`D:6YF;ULG8FQO8VLG
M72`A/2`D;F5W='EP92DI('L*("`@("`@("`@("`@("`@("`@("`D8VAA;F=E
M9"`]('1R=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@(&EF("@D;F5W('Q\("1C:&%N9V5D*2!["B`@("`@("`@("`@
M("`@("`O+R!#:&%N9V4@87!P(&]R('1Y<&4N"B`@("`@("`@("`@("`@("`D
M:6YF;R`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`D:6YF;ULG87!P)UT@
M/2`D;F5W87!P.PH@("`@("`@("`@("`@("`@)&EN9F];)V)L;V-K)UT@/2`D
M;F5W='EP93L*("`@("`@("`@("`@("`@("1P87)A;7,@/2`D=&AI<RT^7V-O
M;&QE8W1I;VXM/F=E=%!A<F%M<R@D;F5W87!P+"`D;F5W='EP92D["B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D<&%R86US(&%S("1N97=P87)A;2D@>PH@
M("`@("`@("`@("`@("`@("`@("1I;F9O6R=P87)A;7,G75LD;F5W<&%R86U=
M(#T@)'1H:7,M/E]C;VQL96-T:6]N+3YG971$969A=6QT5F%L=64H)&YE=V%P
M<"P@)&YE=W1Y<&4L("1N97=P87)A;2D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T0FQO8VM);F9O*"1R;W<L("1C;VPL
M("1I;F9O*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1E>&ES=',I('L*("`@
M("`@("`@("`@("`@("\O($-H86YG92!V86QU97,N"B`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5T0FQO8VM);F9O*"1R;W<L("1C;VPL(&%R<F%Y*"=P87)A
M;7,G(#T^(%5T:6PZ.F=E=$9O<FU$871A*"=P87)A;7,G+"!A<G)A>2@I*2DI
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?=7!D871E9"`]
M('1R=64["B`@("`@("`@("`@(&EF("@D86-T:6]N(#T]("=S879E)RD@>PH@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*"B`@("`@("`@
M+R\@36%K92!A(&)L;V-K('1H92!C=7)R96YT(&)L;V-K(&9O<B!E9&ET:6YG
M+@H@("`@("`@(&-A<V4@)V5D:70G.@H@("`@("`@("`@("`D=&AI<RT^7V-U
M<G)E;G1";&]C:R`](&%R<F%Y*"1R;W<L("1C;VPI.PH@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!(87,@=&AE
M(&QA>6]U="!B965N(&-H86YG960@<VEN8V4@:70@=V%S(&EN<W1A;G1I871E
M9#\*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X*("`@("`J+PH@("`@
M9G5N8W1I;VX@=7!D871E9"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?=7!D871E9#L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@8W5R
M<F5N="!B;&]C:R!R;W<@86YD(&-O;'5M;BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y(%MR;W<L(&-O;%T*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M0W5R<F5N=$)L;V-K*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]C
M=7)R96YT0FQO8VL["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!(;W)D95]";&]C:R!A="!T:&4@<W!E8VEF:65D('!O<VET:6]N+@H@("`@
M("H*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O=RX*
M("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M;BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7T)L;V-K("!4:&4@8FQO8VL@
M9G)O;2!T:&%T('!O<VET:6]N(&]R(&$@4$5!4E]%<G)O<@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@:68@<V]M971H:6YG('=E;G0@=W)O;F<N"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9G971";&]C:R@D<F]W+"`D8V]L*0H@("`@
M>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]B;&]C:W-;)')O=UU;)&-O
M;%TI*2!["B`@("`@("`@("`@("1F:65L9"`]("1T:&ES+3Y?;&%Y;W5T6R1R
M;W==6R1C;VQ=.PH@("`@("`@("`@("`D=&AI<RT^7V)L;V-K<ULD<F]W75LD
M8V]L72`]"B`@("`@("`@("`@("`@("`F2&]R9&5?0FQO8VM?0V]L;&5C=&EO
M;CHZ9V5T0FQO8VLH)&9I96QD6R=A<'`G72P@)&9I96QD6R=P87)A;7,G75LG
M='EP92==+"`D9FEE;&1;)W!A<F%M<R==6R=P87)A;7,G72D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]B;&]C:W-;)')O=UU;)&-O;%T[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C;V]R9&EN871E
M<R!O9B!T:&4@8FQO8VL@8V]V97)I;F<@=&AE('-P96-I9FEE9`H@("`@("H@
M9FEE;&0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L
M87EO=70@<F]W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO
M=70@8V]L=6UN+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!T
M;W`M;&5F="!R;W<M8V]L=6UN+6-O;W)D:6YA=&4@;V8@=&AE(&)L;V-K"B`@
M("`@*B`@("`@("`@("`@("`@("!C;W9E<FEN9R!T:&4@<W!E8VEF:65D(&9I
M96QD(&]R(&YU;&P@:68@=&AE(&9I96QD"B`@("`@*B`@("`@("`@("`@("`@
M("!I<R!E;7!T>2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0FQO8VM!="@D
M<F]W+"`D8V]L*0H@("`@>PH@("`@("`@("\J(%1R:79I86P@8V%S97,@9FER
M<W0N("HO"B`@("`@("`@:68@*"1T:&ES+3YI<T5M<'1Y*"1R;W<L("1C;VPI
M*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T@96QS96EF
M("@A)'1H:7,M/FES0V]V97)E9"@D<F]W+"`D8V]L*2D@>PH@("`@("`@("`@
M("!R971U<FX@87)R87DH)')O=RP@)&-O;"D["B`@("`@("`@?0H*("`@("`@
M("`O*B!4:&ES(&ES(&$@8V]V97)E9"!F:65L9"X@*B\*("`@("`@("!F;W(@
M*"1T97-T(#T@)')O=R`M(#$[("1T97-T(#X](#`[("1T97-T+2TI('L*("`@
M("`@("`@("`@:68@*"$D=&AI<RT^:7-#;W9E<F5D*"1T97-T+"`D8V]L*2`F
M)@H@("`@("`@("`@("`@("`@(21T:&ES+3YI<T5M<'1Y*"1T97-T+"`D8V]L
M*2`F)@H@("`@("`@("`@("`@("`@)'1E<W0@*R`D=&AI<RT^9V5T2&5I9VAT
M*"1T97-T+"`D8V]L*2`M(#$@/3T@)')O=RD@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(&%R<F%Y*"1T97-T+"`D8V]L*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("!F;W(@*"1T97-T(#T@)&-O;"`M(#$[("1T97-T(#X]
M(#`[("1T97-T+2TI('L*("`@("`@("`@("`@:68@*"$D=&AI<RT^:7-#;W9E
M<F5D*"1R;W<L("1T97-T*2`F)@H@("`@("`@("`@("`@("`@(21T:&ES+3YI
M<T5M<'1Y*"1T97-T+"`D8V]L*2`F)@H@("`@("`@("`@("`@("`@)'1E<W0@
M*R`D=&AI<RT^9V5T5VED=&@H)')O=RP@)'1E<W0I("T@,2`]/2`D8V]L*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@87)R87DH)')O=RP@)'1E<W0I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!A(&AA<V@@=VET:"!S;VUE('5S969U;"!I;F9O<FUA=&EO;B!A
M8F]U="!T:&4@<W!E8VEF:65D"B`@("`@*B!B;&]C:RX*("`@("`J"B`@("`@
M*B!2971U<FYE9"!H87-H('9A;'5E<SH*("`@("`J("=A<'`G.B!A<'!L:6-A
M=&EO;B!N86UE"B`@("`@*B`G8FQO8VLG.B!B;&]C:R!N86UE"B`@("`@*B`G
M<&%R86US)SH@<&%R86UE=&5R(&AA<V@*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@5&AE(&EN9F]R;6%T:6]N(&AA<V@N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$)L;V-K26YF;R@D<F]W+"`D8V]L*0H@("`@>PH@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%TI('Q\
M"B`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=(#T]("=E
M;7!T>2<I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M7R@B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB
M*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M87)R87DH)V%P<"<@/3X@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%U;)V%P
M<"==+`H@("`@("`@("`@("`@("`@("`@("`G8FQO8VLG(#T^("1T:&ES+3Y?
M;&%Y;W5T6R1R;W==6R1C;VQ=6R=P87)A;7,G75LG='EP92==+`H@("`@("`@
M("`@("`@("`@("`@("`G<&%R86US)R`]/B`D=&AI<RT^7VQA>6]U=%LD<F]W
M75LD8V]L75LG<&%R86US)UU;)W!A<F%M<R==*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E=',@82!B871C:"!O9B!I;F9O<FUA=&EO;B!A8F]U="!T:&4@
M<W!E8VEF:65D(&)L;V-K+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R
M("1R;W<@($$@;&%Y;W5T(')O=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1C
M;VP@($$@;&%Y;W5T(&-O;'5M;BX*("`@("`J($!P87)A;2!A<G)A>2`D:6YF
M;R`@($$@:&%S:"!W:71H(&EN9F]R;6%T:6]N('9A;'5E<RX*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@(%!O<W-I8FQE(&5L96UE;G1S(&%R93H*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("=A<'`G.B!A<'!L:6-A=&EO;B!N
M86UE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`G8FQO8VLG.B!B;&]C
M:R!N86UE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`G<&%R86US)SH@
M<&%R86UE=&5R(&AA<V@*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T0FQO8VM)
M;F9O*"1R;W<L("1C;VPL("1I;F9O(#T@87)R87DH*2D*("`@('L*("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=*2D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;R!B;&]C
M:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(I+"`G:&]R9&4N
M97)R;W(G*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D:6YF;ULG
M87!P)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C
M;VQ=6R=A<'`G72`]("1I;F9O6R=A<'`G73L*("`@("`@("!]"B`@("`@("`@
M:68@*&ES<V5T*"1I;F9O6R=B;&]C:R==*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7VQA>6]U=%LD<F]W75LD8V]L75LG<&%R86US)UU;)W1Y<&4G72`]("1I
M;F9O6R=B;&]C:R==.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)&EN
M9F];)W!A<F%M<R==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD
M<F]W75LD8V]L75LG<&%R86US)UU;)W!A<F%M<R==(#T@)&EN9F];)W!A<F%M
M<R==.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]C:&%N9V5D7W)O=R`]
M("1R;W<["B`@("`@("`@)'1H:7,M/E]C:&%N9V5D7V-O;"`]("1C;VP["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!N=6UB97(@;V8@8FQO
M8VMS(&EN('1H92!C=7)R96YT(&QA>6]U="X*("`@("`J"B`@("`@*B!`<VEN
M8V4@2&]R9&4@,RXQ"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4
M:&4@;G5M8F5R(&]F(&)L;V-K<RX*("`@("`J+PH@("`@9G5N8W1I;VX@8V]U
M;G0H*0H@("`@>PH@("`@("`@("1R;W=S(#T@)'1H:7,M/G)O=W,H*3L*("`@
M("`@("`D8V]U;G0@/2`P.PH*("`@("`@("!F;W(@*"1R;W<@/2`P.R`D<F]W
M(#P@)')O=W,[("1R;W<K*RD@>PH@("`@("`@("`@("`D8V]L<R`]("1T:&ES
M+3YC;VQU;6YS*"1R;W<I.PH@("`@("`@("`@("!F;W(@*"1C;VP@/2`P.R`D
M8V]L(#P@)&-O;',[("1C;VPK*RD@>PH@("`@("`@("`@("`@("`@:68@*"$D
M=&AI<RT^:7-%;7!T>2@D<F]W+"`D8V]L*2`F)@H@("`@("`@("`@("`@("`@
M("`@("$D=&AI<RT^:7-#;W9E<F5D*"1R;W<L("1C;VPI*2!["B`@("`@("`@
M("`@("`@("`@("`@)&-O=6YT*RL["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D8V]U;G0["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!N=6UB97(@;V8@<F]W
M<R!I;B!T:&4@8W5R<F5N="!L87EO=70N"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G1E9V5R("!4:&4@;G5M8F5R(&]F(')O=W,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(')O=W,H*0H@("`@>PH@("`@("`@(')E='5R;B!C;W5N="@D=&AI
M<RT^7VQA>6]U="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!N=6UB97(@;V8@8V]L=6UN<R!I;B!T:&4@<W!E8VEF:65D(')O=R!O9B!T
M:&4*("`@("`J(&-U<G)E;G0@;&%Y;W5T+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1R;W<@(%1H92!R;W<@=&\@<F5T=7)N('1H92!N=6UB97(@
M;V8@8V]L=6UN<R!F<F]M+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E
M<B`@5&AE(&YU;6)E<B!O9B!C;VQU;6YS+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!C;VQU;6YS*"1R;W<I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7VQA>6]U=%LD<F]W72DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H<W!R:6YT9BA?*")4:&4@<W!E8VEF:65D(')O=R`H)60I
M(&1O97,@;F]T(&5X:7-T+B(I+"`D<F]W*2P@)VAO<F1E+F5R<F]R)RD["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B!C;W5N="@D=&AI<RT^7VQA>6]U=%LD
M<F]W72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@=&\@<V5E(&EF
M(&$@9VEV96X@;&]C871I;VX@:68@8F5I;F<@=7-E9"!B>2!A(&)L;V-K"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L87EO=70@<F]W
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO=70@8V]L=6UN
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@
M;&]C871I;VX@:7,@96UP='D*("`@("`J("`@("`@("`@("`@("`@("`@1F%L
M<V4@:7,@=&AE(&QO8V%T:6]N(&ES(&)E:6YG('5S960N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&ES16UP='DH)')O=RP@)&-O;"D*("`@('L*("`@("`@("!R
M971U<FX@(6ES<V5T*"1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=*2!\?"`D
M=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L72`]/2`G96UP='DG.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!I9B!T:&4@9FEE;&0@870@=&AE('-P
M96-I9FEE9"!P;W-I=&EO;B!I<R!C;W9E<F5D(&)Y"B`@("`@*B!A;F]T:&5R
M(&)L;V-K+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@($$@
M;&%Y;W5T(')O=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y
M;W5T(&-O;'5M;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R
M=64@:68@=&AE('-P96-I9FEE9"!F:65L9"!I<R!C;W9E<F5D+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!I<T-O=F5R960H)')O=RP@)&-O;"D*("`@('L*("`@
M("`@("!R971U<FX@:7-S970H)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%TI
M(#\@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%T@/3T@)V-O=F5R960G(#H@
M9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&EF('1H92!S
M<&5C:69I960@;&]C871I;VX@:7,@=&AE('1O<"!L969T(&9I96QD(&]F"B`@
M("`@*B!A(&)L;V-K+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1R
M;W<@($$@;&%Y;W5T(')O=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@
M($$@;&%Y;W5T(&-O;'5M;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@(%1R=64@:68@=&AE('-P96-I9FEE9"!P;W-I=&EO;B!I<R!A(&)L;V-K
M+"!F86QS92!I9@H@("`@("H@("`@("`@("`@("`@("`@("!T:&4@9FEE;&0@
M9&]E<VXG="!E>&ES="P@:7,@96UP='D@;W(@8V]V97)E9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@:7-";&]C:R@D<F]W+"`D8V]L*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^<F]W17AI<W1S*"1R;W<I("8F("1T:&ES+3YC;VQ%
M>&ES=',H)&-O;"D@)B8*("`@("`@("`@("`@(21T:&ES+3YI<T5M<'1Y*"1R
M;W<L("1C;VPI("8F("$D=&AI<RT^:7-#;W9E<F5D*"1R;W<L("1C;VPI.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!I9B!T:&4@<W!E8VEF:65D
M(&)L;V-K(&AA<R!B965N(&-H86YG960@;&%S="X*("`@("`J"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H:7,@8FQO8VL@:7,@=&AE
M(&QA<W0@;VYE('1H870@=V%S(&-H86YG960N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&ES0VAA;F=E9"@D<F]W+"`D8V]L*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7V-H86YG961?<F]W(#T]/2`D<F]W("8F("1T:&ES+3Y?8VAA
M;F=E9%]C;VP@/3T]("1C;VP["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&EF('1H92!S<&5C:69I960@8FQO8VL@;6%Y(&)E(')E;6]V960N"B`@
M("`@*@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y
M;W5T(')O=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T
M(&-O;'5M;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@
M:68@=&AI<R!B;&]C:R!M87D@8F4@<F5M;W9E9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@:7-296UO=F%B;&4H)')O=RP@)&-O;"D*("`@('L*("`@("`@("!G
M;&]B86P@)&-O;F8["@H@("`@("`@("1A<'`@/2`D=&AI<RT^7VQA>6]U=%LD
M<F]W75LD8V]L75LG87!P)UT["B`@("`@("`@)'1Y<&4@/2`D=&AI<RT^7VQA
M>6]U=%LD<F]W75LD8V]L75LG<&%R86US)UU;)W1Y<&4G73L*("`@("`@("`D
M8FQO8VL@/2`D87!P("X@)SHG("X@)'1Y<&4["@H@("`@("`@("\J($-H96-K
M(&EF('1H92!B;&]C:R!I<R!A(&9I>&5D(&)L;V-K+B`J+PH@("`@("`@(&EF
M("@A:6Y?87)R87DH)&)L;V-K+"`D8V]N9ELG<&]R=&%L)UU;)V9I>&5D7V)L
M;V-K<R==*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M"@H@("`@("`@("\J($-H96-K(&EF('=E(&AA=F4@<W1I;&P@86YO=&AE<B!B
M;&]C:R!O9B!T:&4@<V%M92!T>7!E+B`J+PH@("`@("`@("1F;W5N9"`](&9A
M;'-E.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?;&%Y;W5T(&%S("1C=7)?
M<F]W*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1C=7)?<F]W(&%S("1C=7)?
M8V]L*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&-U<E]C;VQ;)V%P
M<"==*2`F)@H@("`@("`@("`@("`@("`@("`@("1C=7)?8V]L6R=A<'`G72`]
M/2`D87!P("8F"B`@("`@("`@("`@("`@("`@("`@)&-U<E]C;VQ;)W!A<F%M
M<R==6R=T>7!E)UT@/3T@)'1Y<&4I('L*("`@("`@("`@("`@("`@("`@("!I
M9B`H)&9O=6YD*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1F;W5N9"`]('1R=64["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&%N(%523"!T<FEG9V5R:6YG(&%N(&%C=&EO;B!T;R!A(&)L
M;V-K"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D86-T:6]N("!!;B!A
M8W1I;VX@=&\@=')I9V=E<BX*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@
M($$@;&%Y;W5T(')O=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@($$@
M;&%Y;W5T(&-O;'5M;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M06X@55),('=I=&@@86QL(&YE8V5S<V%R>2!P87)A;65T97)S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971!8W1I;VY5<FPH)&%C=&EO;BP@)')O=RP@)&-O
M;"D*("`@('L*("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*$AO
M<F1E.CIS96QF57)L*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@G8V]L)R`]/B`D8V]L+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W)O=R<@/3X@)')O=RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A8W1I;VXG(#T^("1A
M8W1I;VXL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G;F]C86-H92<@/3X@8F%S95]C;VYV97)T*&UI8W)O=&EM92@I+"`Q,"P@
M,S8I*2D["B`@("`@("`@<F5T=7)N("1U<FP@+B`G(V)L;V-K)SL*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!C;VYT<F]L("AL:6YK960@87)R
M;W<I(&9O<B!A(&-E<G1A:6X@86-T:6]N(&]N('1H90H@("`@("H@<W!E8VEF
M:65D(&)L;V-K+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@
M($$@8V]N=')O;"!T>7!E(&EN('1H92!F;W)M"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`B;6]D:69I8V%T:6]N+V1I<F5C=&EO;B(N(%!O<W-I8FQE
M('9A;'5E<R!F;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&UO9&EF
M:6-A=&EO;CH@97AP86YD+"!S:')I;FLL(&UO=F4N(%!O<W-I8FQE('9A;'5E
M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@9F]R(&1I<F5C=&EO;CH@
M=7`L(&1O=VXL(&QE9G0L(')I9VAT+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)')O=R`@02!L87EO=70@<F]W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O
M;"`@02!L87EO=70@8V]L=6UN+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!!(&QI;FL@8V]N=&%I;FEN9R!A;B!A<G)O=R!R97!R97-E;G1I;F<@
M=&AE(')E<75E<W1E9`H@("`@("H@("`@("`@("`@("`@("`@(&-O;G1R;VPN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-O;G1R;VPH)'1Y<&4L("1R;W<L
M("1C;VPI"B`@("!["B`@("`@("`@)'1Y<&4@/2!E>'!L;V1E*"<O)RP@)'1Y
M<&4I.PH@("`@("`@("1A8W1I;VX@/2`D='EP95LP72`N('5C9FER<W0H)'1Y
M<&5;,5TI.PH@("`@("`@("1U<FP@/2`D=&AI<RT^9V5T06-T:6]N57)L*"1A
M8W1I;VXL("1R;W<L("1C;VPI.PH*("`@("`@("!S=VET8V@@*"1T>7!E6S!=
M*2!["B`@("`@("`@8V%S92`G97AP86YD)SH*("`@("`@("`@("`@)'1I=&QE
M(#T@7R@B17AP86YD(BD["B`@("`@("`@("`@("1I;6<@/2`G;&%R9V5?)R`N
M("1T>7!E6S%=.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G
M<VAR:6YK)SH*("`@("`@("`@("`@)'1I=&QE(#T@7R@B4VAR:6YK(BD["B`@
M("`@("`@("`@("1I;6<@/2`G;&%R9V5?)SL*"B`@("`@("`@("`@('-W:71C
M:"`H)'1Y<&5;,5TI('L*("`@("`@("`@("`@8V%S92`G=7`G.@H@("`@("`@
M("`@("`@("`@)&EM9R`N/2`G9&]W;B<["B`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@(&-A<V4@)V1O=VXG.@H@("`@("`@("`@("`@("`@
M)&EM9R`N/2`G=7`G.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("!C87-E("=L969T)SH*("`@("`@("`@("`@("`@("1I;6<@+CT@)W)I
M9VAT)SL*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S
M92`G<FEG:'0G.@H@("`@("`@("`@("`@("`@)&EM9R`N/2`G;&5F="<["B`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@8V%S92`G;6]V92<Z"B`@("`@("`@("`@('-W
M:71C:"`H)'1Y<&5;,5TI('L*("`@("`@("`@("`@8V%S92`G=7`G.@H@("`@
M("`@("`@("`@("`@)'1I=&QE(#T@7R@B36]V92!5<"(I.PH@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=D;W=N)SH*("`@("`@
M("`@("`@("`@("1T:71L92`](%\H(DUO=F4@1&]W;B(I.PH@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=L969T)SH*("`@("`@
M("`@("`@("`@("1T:71L92`](%\H(DUO=F4@3&5F="(I.PH@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=R:6=H="<Z"B`@("`@
M("`@("`@("`@("`D=&ET;&4@/2!?*")-;W9E(%)I9VAT(BD["B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&EM
M9R`]("1T>7!E6S%=.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!(;W)D93HZ;&EN:R@D=7)L+"`D=&ET;&4I("X*("`@
M("`@("`@("`@2&]R9&4Z.FEM9R@G8FQO8VLO)R`N("1I;6<@+B`G+G!N9R<L
M("1T:71L92P@)R<L("1'3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G941I
M<B@G:&]R9&4G*2D@+B`G/"]A/B<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M;V5S(&$@<F]W(&5X:7-T/PH@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R
M("1R;W<@(%1H92!R;W<@=&\@;&]O:R!F;W(*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@:68@=&AE(')O=R!E>&ES=',*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F]W17AI<W1S*"1R;W<I"B`@("!["B`@("`@("`@<F5T
M=7)N("1R;W<@/"!C;W5N="@D=&AI<RT^7VQA>6]U="D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$;V5S(&$@8V]L=6UN(&5X:7-T/PH@("`@("H*("`@("`J
M($!P87)A;2!I;G1E9V5R("1C;VP@(%1H92!C;VQU;6X@=&\@;&]O:R!F;W(*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE(&-O
M;'5M;B!E>&ES=',*("`@("`J+PH@("`@9G5N8W1I;VX@8V]L17AI<W1S*"1C
M;VPI"B`@("!["B`@("`@("`@<F5T=7)N("1C;VP@/"`D=&AI<RT^7V-O;'5M
M;G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE('=I9'1H(&]F('1H
M92!B;&]C:R!A="!A(&=I=F5N(&QO8V%T:6]N+@H@("`@("H@5&AI<R!R971U
M<FYS('1H92!W:61T:"!I9B!T:&5R92!I<R!A(&)L;V-K(&%T('1H:7,*("`@
M("`J(&QO8V%T:6]N+"!O=&AE<G=I<V4@<F5T=7)N<R`Q+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O=RX*("`@("`J
M($!P87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M;BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!N=6UB97(@;V8@8V]L=6UN
M<R!T:&ES(&)L;V-K('-P86YS"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%=I
M9'1H*"1R;W<L("1C;VPI"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D
M=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L72DI('L*("`@("`@("`@("`@<F5T
M=7)N(#$["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]L
M87EO=71;)')O=UU;)&-O;%U;)W=I9'1H)UTI*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=6R=W:61T:"==(#T@,3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=
M6R=W:61T:"==.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H92!H96EG
M:'0@;V8@=&AE(&)L;V-K(&%T(&$@9VEV96X@;&]C871I;VXN"B`@("`@*B!4
M:&ES(')E='5R;G,@=&AE(&AE:6=H="!I9B!T:&5R92!I<R!A(&)L;V-K(&%T
M('1H:7,*("`@("`J(&QO8V%T:6]N+"!O=&AE<G=I<V4@<F5T=7)N<R`Q+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O
M=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M
M;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!N=6UB97(@
M;V8@<F]W<R!T:&ES(&)L;V-K('-P86YS"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$AE:6=H="@D<F]W+"`D8V]L*0H@("`@>PH@("`@("`@(&EF("@A:7-?
M87)R87DH)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%TI*2!["B`@("`@("`@
M("`@(')E='5R;B`Q.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=6R=H96EG:'0G72DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%U;)VAE:6=H="==(#T@
M,3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;&%Y;W5T6R1R
M;W==6R1C;VQ=6R=H96EG:'0G73L*("`@('T*"B`@("`O*BH*("`@("`J($%D
M9',@86X@96UP='D@8FQO8VL@870@=&AE('-P96-I9FEE9"!P;W-I=&EO;BX*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U="!R
M;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C;VQU
M;6XN"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$)L;V-K*"1R;W<L("1C;VPI
M"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^<F]W17AI<W1S*"1R;W<I*2![
M"B`@("`@("`@("`@("1T:&ES+3YA9&12;W<H)')O=RD["B`@("`@("`@?0H@
M("`@("`@(&EF("@A)'1H:7,M/F-O;$5X:7-T<R@D8V]L*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^861D0V]L*"1C;VPI.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%T@/2!A<G)A>2@G87!P)R`]/B!N
M=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VAE:6=H="<@/3X@,2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=W:61T:"<@/3X@,2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P87)A;7,G(#T^(&%R<F%Y
M*"=T>7!E)R`]/B!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!A<F%M<R<@/3X@
M87)R87DH*2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A(&YE=R!R
M;W<@=&\@=&AE(&QA>6]U="X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D<F]W("!4:&4@;G5M8F5R(&]F('1H92!R;W<@=&\@861D"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%D9%)O=R@D<F]W*0H@("`@>PH@("`@("`@(&EF("@D
M=&AI<RT^7V-O;'5M;G,@/B`P*2!["B`@("`@("`@("`@("1T:&ES+3Y?;&%Y
M;W5T6R1R;W==(#T@87)R87E?9FEL;"@P+"`D=&AI<RT^7V-O;'5M;G,L("=E
M;7!T>2<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@
M82!N97<@8V]L=6UN('1O('1H92!L87EO=70N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&-O;"`@5&AE(&YU;6)E<B!O9B!T:&4@8V]L=6UN('1O
M(&%D9`H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1#;VPH)&-O;"D*("`@('L*
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7VQA>6]U="!A<R`D:60@/3X@)'9A
M;"D@>PH@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD:61=6R1C;VQ=(#T@
M)V5M<'1Y)SL*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]C;VQU;6YS*RL[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(&$@8FQO8VLN"B`@("`@
M*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L87EO=70@<F]W+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO=70@8V]L=6UN+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5";&]C:R@D<F]W+"`D8V]L*0H@
M("`@>PH@("`@("`@("1W:61T:"`]("1T:&ES+3YG9717:61T:"@D<F]W+"`D
M8V]L*3L*("`@("`@("`D:&5I9VAT(#T@)'1H:7,M/F=E=$AE:6=H="@D<F]W
M+"`D8V]L*3L*("`@("`@("!F;W(@*"1I(#T@)&AE:6=H="`M(#$[("1I(#X]
M(#`[("1I+2TI('L*("`@("`@("`@("`@9F]R("@D:B`]("1W:61T:"`M(#$[
M("1J(#X](#`[("1J+2TI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y
M;W5T6R1R;W<@*R`D:5U;)&-O;"`K("1J72`]("=E;7!T>2<["B`@("`@("`@
M("`@("`@("!I9B`H(21T:&ES+3YC;VQ%>&ES=',H)&-O;"`K("1J("L@,2DI
M('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<F5M;W9E0V]L269%;7!T
M>2@D8V]L("L@)&HI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("@A)'1H:7,M/G)O=T5X:7-T<R@D<F]W("L@)&D@
M*R`Q*2`F)B`D=&AI<RT^<F]W17AI<W1S*"1R;W<@*R`D:2DI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3YR96UO=F52;W=)9D5M<'1Y*"1R;W<@*R`D:2D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?8VAA
M;F=E9%]R;W<@/2`D<F]W.PH@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]C;VP@
M/2`D8V]L.PH*("`@("`@("!I9B`H(21T:&ES+3YR;W=%>&ES=',H)')O=RDI
M('L*("`@("`@("`@("`@)')O=RTM.PH@("`@("`@("`@("!W:&EL92`H)')O
M=R`^/2`P("8F("1T:&ES+3YR96UO=F52;W=)9D5M<'1Y*"1R;W<I*2!["B`@
M("`@("`@("`@("`@("`D<F]W+2T["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@:68@*"$D=&AI<RT^8V]L17AI<W1S*"1C;VPI*2!["B`@("`@
M("`@("`@("1C;VPM+3L*("`@("`@("`@("`@=VAI;&4@*"1C;VP@/CT@,"`F
M)B`D=&AI<RT^<F5M;W9E0V]L269%;7!T>2@D8V]L*2D@>PH@("`@("`@("`@
M("`@("`@)&-O;"TM.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@4F5M;W9E<R!A(')O=R!I9B!I="=S(&5M<'1Y+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@(%1H92!N=6UB97(@
M;V8@=&AE(')O=R!T;R!T;R!C:&5C:PH@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;B`@5')U92!I9B!T:&4@<F]W(&ES(&YO=R!R96UO=F5D+@H@("`@
M("H@("`@("`@("`@("`@("`@("!&86QS92!I9B!T:&4@<F]W('-T:6QL(&5X
M:7-T<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E4F]W269%;7!T>2@D
M<F]W*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/G)O=T5X:7-T<R@D<F]W
M*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@
M("`@("1R;W=S(#T@8V]U;G0H)'1H:7,M/E]L87EO=71;)')O=UTI.PH@("`@
M("`@(&9O<B`H)&D@/2`P.R`D:2`\("1R;W=S.R`D:2LK*2!["B`@("`@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7VQA>6]U=%LD<F]W75LD:5TI("8F("1T
M:&ES+3Y?;&%Y;W5T6R1R;W==6R1I72`A/2`G96UP='DG*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@=6YS970H)'1H:7,M/E]L87EO=71;)')O=UTI.PH*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@
M82!C;VQU;6X@:68@:70G<R!E;7!T>2X*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D8V]L("!4:&4@;G5M8F5R(&]F('1H92!C;VQU;6X@=&\@=&\@
M8VAE8VL*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@
M=&AE(&-O;'5M;B!I<R!N;W<@<F5M;W9E9"X*("`@("`J("`@("`@("`@("`@
M("`@("`@1F%L<V4@:68@=&AE(&-O;'5M;B!S=&EL;"!E>&ES=',N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(')E;6]V94-O;$EF16UP='DH)&-O;"D*("`@('L*
M("`@("`@("!I9B`H(21T:&ES+3YC;VQ%>&ES=',H)&-O;"DI('L*("`@("`@
M("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`D8V]L<R`]
M(&-O=6YT*"1T:&ES+3Y?;&%Y;W5T*3L*("`@("`@("!F;W(@*"1I(#T@,#L@
M)&D@/"`D8V]L<SL@)&DK*RD@>PH@("`@("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]L87EO=71;)&E=6R1C;VQ=*2`F)B`D=&AI<RT^7VQA>6]U=%LD:5U;
M)&-O;%T@(3T@)V5M<'1Y)RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"`D8V]L<SL@)&DK*RD@>PH@("`@("`@("`@("!U;G-E="@D
M=&AI<RT^7VQA>6]U=%LD:5U;)&-O;%TI.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!-;W9E<R!A(&)L
M;V-K(&]N92!R;W<@=7`N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)')O=R`@02!L87EO=70@<F]W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O
M;"`@02!L87EO=70@8V]L=6UN+@H@("`@("HO"B`@("!F=6YC=&EO;B!M;W9E
M57`H)')O=RP@)&-O;"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/G)O=T5X
M:7-T<R@D<F]W("T@,2DI('L*("`@("`@("`@("`@)'=I9'1H(#T@)'1H:7,M
M/F=E=%=I9'1H*"1R;W<L("1C;VPI.PH@("`@("`@("`@("`O+R!3964@:68@
M=&AE<F4G<R!R;V]M('1O(&UO=F4@:6YT;PH@("`@("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"`D=VED=&@[("1I*RLI('L*("`@("`@("`@("`@("`@(&EF
M("@A)'1H:7,M/FES16UP='DH)')O=R`M(#$L("1C;VP@*R`D:2DI('L*("`@
M("`@("`@("`@("`@("`@("`D:6Y?=V%Y(#T@)'1H:7,M/F=E=$)L;V-K070H
M)')O=R`M(#$L("1C;VP@*R`D:2D["B`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<U]N=6QL*"1I;E]W87DI("8F"B`@("`@("`@("`@("`@("`@("`@("`@
M("1I;E]W87E;,5T@/3T@)&-O;"`F)@H@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^9V5T5VED=&@H)&EN7W=A>5LP72P@)&EN7W=A>5LQ72D@/3T@
M)'=I9'1H*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\O(%=E(&YE960@
M=&\@<W=A<"!T:&4@8FQO8VMS+@H@("`@("`@("`@("`@("`@("`@("`@("`D
M<F5C,2`]($AO<F1E7T%R<F%Y.CIG971296-T86YG;&4H)'1H:7,M/E]L87EO
M=70L("1R;W<L("1C;VPL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9V5T2&5I9VAT
M*"1R;W<L("1C;VPI+"`D=&AI<RT^9V5T5VED=&@H)')O=RP@)&-O;"DI.PH@
M("`@("`@("`@("`@("`@("`@("`@("`D<F5C,B`]($AO<F1E7T%R<F%Y.CIG
M971296-T86YG;&4H)'1H:7,M/E]L87EO=70L("1I;E]W87E;,%TL("1I;E]W
M87E;,5TL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9V5T2&5I9VAT*"1I;E]W87E;
M,%TL("1I;E]W87E;,5TI+"`D=&AI<RT^9V5T5VED=&@H)&EN7W=A>5LP72P@
M)&EN7W=A>5LQ72DI.PH@("`@("`@("`@("`@("`@("`@("`@("!F;W(@*"1J
M(#T@,#L@)&H@/"!C;W5N="@D<F5C,2D[("1J*RLI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&9O<B`H)&L@/2`P.R`D:R`\(&-O=6YT*"1R96,Q
M6R1J72D[("1K*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7VQA>6]U=%LD:6Y?=V%Y6S!=("L@)&I=6R1I;E]W87E;,5T@
M*R`D:UT@/2`D<F5C,5LD:EU;)&M=.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@("`@(&9O<B`H)&H@/2`P.R`D:B`\(&-O=6YT*"1R96,R*3L@
M)&HK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R("@D:R`]
M(#`[("1K(#P@8V]U;G0H)')E8S);)&I=*3L@)&LK*RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1I;E]W87E;
M,%T@*R!C;W5N="@D<F5C,2D@*R`D:EU;)&EN7W=A>5LQ72`K("1K72`]("1R
M96,R6R1J75LD:UT["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]C:&%N9V5D7W)O=R`]("1I;E]W87E;,%T["B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]C;VP@/2`D:6Y?=V%Y
M6S%=.PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("\O($YO=VAE<F4@
M=&\@9V\N"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H7R@B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I
M(&]U="!O9B!T:&4@=V%Y(&9I<G-T(BDL("=H;W)D92YW87)N:6YG)RD["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1L
M87-T<F]W(#T@)')O=R`K("1T:&ES+3YG971(96EG:'0H)')O=RP@)&-O;"D@
M+2`Q.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D=VED=&@[("1I
M*RLI('L*("`@("`@("`@("`@("`@("1P<F5V(#T@)'1H:7,M/E]L87EO=71;
M)')O=UU;)&-O;"`K("1I73L*("`@("`@("`@("`@("`@("\O($UO=F4@=&]P
M(&5D9V4*("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W<@+2`Q
M75LD8V]L("L@)&E=(#T@)'!R978["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7VQA>6]U=%LD<F]W75LD8V]L("L@)&E=(#T@)V-O=F5R960G.PH@("`@("`@
M("`@("`@("`@+R\@36]V92!B;W1T;VT@961G90H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]L87EO=71;)&QA<W1R;W==6R1C;VP@*R`D:5T@/2`G96UP='DG
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(21T:&ES+3YR;W=%
M>&ES=',H)&QA<W1R;W<@*R`Q*2D@>PH@("`@("`@("`@("`@("`@+R\@5V%S
M(&]N('1H92!B;W1T;VT@<F]W"B`@("`@("`@("`@("`@("`D=&AI<RT^<F5M
M;W9E4F]W269%;7!T>2@D;&%S=')O=RD["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]R;W<@/2`D<F]W("T@,3L*
M("`@("`@("`D=&AI<RT^7V-H86YG961?8V]L(#T@)&-O;#L*("`@('T*"B`@
M("`O*BH*("`@("`J($UO=F5S(&$@8FQO8VL@;VYE(')O=R!D;W=N+@H@("`@
M("H*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O=RX*
M("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M;BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@;6]V941O=VXH)')O=RP@)&-O;"D*("`@
M('L*("`@("`@("`D=VED=&@@/2`D=&AI<RT^9V5T5VED=&@H)')O=RP@)&-O
M;"D["B`@("`@("`@)&QA<W1R;W<@/2`D<F]W("L@)'1H:7,M/F=E=$AE:6=H
M="@D<F]W+"`D8V]L*3L*("`@("`@("!I9B`H)'1H:7,M/G)O=T5X:7-T<R@D
M;&%S=')O=RDI('L*("`@("`@("`@("`@+R\@4V5E(&EF('1H97)E)W,@<F]O
M;2!T;R!M;W9E(&EN=&\*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M)'=I9'1H.R`D:2LK*2!["B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YI
M<T5M<'1Y*"1L87-T<F]W+"`D8V]L("L@)&DI*2!["B`@("`@("`@("`@("`@
M("`@("`@)&EN7W=A>2`]("1T:&ES+3YG971";&]C:T%T*"1L87-T<F]W+"`D
M8V]L("L@)&DI.PH@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?;G5L;"@D
M:6Y?=V%Y*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("`D:6Y?=V%Y6S%=
M(#T]("1C;VP@)B8*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E
M=%=I9'1H*"1I;E]W87E;,%TL("1I;E]W87E;,5TI(#T]("1W:61T:"D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!792!N965D('1O('-W87`@=&AE
M(&)L;V-K<RX*("`@("`@("`@("`@("`@("`@("`@("`@)')E8S$@/2!(;W)D
M95]!<G)A>3HZ9V5T4F5C=&%N9VQE*"1T:&ES+3Y?;&%Y;W5T+"`D<F]W+"`D
M8V]L+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E=$AE:6=H="@D<F]W+"`D8V]L
M*2P@)'1H:7,M/F=E=%=I9'1H*"1R;W<L("1C;VPI*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@)')E8S(@/2!(;W)D95]!<G)A>3HZ9V5T4F5C=&%N9VQE
M*"1T:&ES+3Y?;&%Y;W5T+"`D:6Y?=V%Y6S!=+"`D:6Y?=V%Y6S%=+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/F=E=$AE:6=H="@D:6Y?=V%Y6S!=+"`D:6Y?=V%Y
M6S%=*2P@)'1H:7,M/F=E=%=I9'1H*"1I;E]W87E;,%TL("1I;E]W87E;,5TI
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@9F]R("@D:B`](#`[("1J(#P@
M8V]U;G0H)')E8S(I.R`D:BLK*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!F;W(@*"1K(#T@,#L@)&L@/"!C;W5N="@D<F5C,ELD:ETI.R`D:RLK
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L
M87EO=71;)')O=R`K("1J75LD8V]L("L@)&M=(#T@)')E8S);)&I=6R1K73L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!F;W(@*"1J(#T@
M,#L@)&H@/"!C;W5N="@D<F5C,2D[("1J*RLI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&9O<B`H)&L@/2`P.R`D:R`\(&-O=6YT*"1R96,Q6R1J
M72D[("1K*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7VQA>6]U=%LD<F]W("L@8V]U;G0H)')E8S(I("L@)&I=6R1C;VP@
M*R`D:UT@/2`D<F5C,5LD:EU;)&M=.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]R;W<@/2`D:6Y?=V%Y6S!=
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-H86YG961?8V]L
M(#T@)&EN7W=A>5LQ73L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`O
M+R!.;R!W:&5R92!T;R!G;PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*%\H(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN
M9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(I+"`G:&]R9&4N=V%R
M;FEN9R<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@36%K92!R;V]M('1O(&UO=F4@
M:6YT;PH@("`@("`@("`@("`D=&AI<RT^861D4F]W*"1L87-T<F]W*3L*("`@
M("`@("!]"@H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1W:61T:#L@)&DK
M*RD@>PH@("`@("`@("`@("`D<')E=B`]("1T:&ES+3Y?;&%Y;W5T6R1R;W==
M6R1C;VP@*R`D:5T["B`@("`@("`@("`@("\O($UO=F4@8F]T=&]M(&5D9V4*
M("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)&QA<W1R;W==6R1C;VP@*R`D
M:5T@/2`G8V]V97)E9"<["B`@("`@("`@("`@("\O($UO=F4@=&]P(&5D9V4*
M("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=R`K(#%=6R1C;VP@*R`D
M:5T@/2`D<')E=CL*("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=UU;
M)&-O;"`K("1I72`]("=E;7!T>2<["B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^7V-H86YG961?<F]W(#T@)')O=R`K(#$["B`@("`@("`@)'1H:7,M/E]C
M:&%N9V5D7V-O;"`]("1C;VP["B`@("!]"@H@("`@+RHJ"B`@("`@*B!-;W9E
M<R!A;&P@8FQO8VMS(&)E;&]W(&$@8V5R=&%I;B!R;W<@;VYE(')O=R!D;W=N
M+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y;W5T
M(')O=RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@
M86QL(')O=W,@8V]U;&0@8F4@;6]V960@9&]W;BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@;6]V941O=VY"96QO=R@D<F]W*0H@("`@>PH@("`@("`@("1M;W9E
M9"`](&%R<F%Y*"D["B`@("`@("`@9F]R("@D>2`](&-O=6YT*"1T:&ES+3Y?
M;&%Y;W5T*2`M(#$[("1Y(#X@)')O=SL@)'DM+2D@>PH@("`@("`@("`@("!F
M;W(@*"1X(#T@,#L@)'@@/"`D=&AI<RT^7V-O;'5M;G,[("1X*RLI('L*("`@
M("`@("`@("`@("`@("1B;&]C:R`]("1T:&ES+3YG971";&]C:T%T*"1Y+"`D
M>"D["B`@("`@("`@("`@("`@("!I9B`H96UP='DH)&)L;V-K*2D@>PH@("`@
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1M;W9E9%LD8FQO8VM;,5T@+B`G
M.B<@+B`D8FQO8VM;,%U=*2D@>PH@("`@("`@("`@("`@("`@("`@("1M;W9E
M9%LD8FQO8VM;,5T@+B`G.B<@+B`D8FQO8VM;,%U=(#T@=')U93L*("`@("`@
M("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/FUO=F5$;W=N*"1B;&]C
M:ULP72P@)&)L;V-K6S%=*3L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!-;W9E<R!A
M(&)L;V-K(&]N92!C;VQU;6X@;&5F="X*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&UO=F5,969T*"1R;W<L("1C;VPI"B`@("!["B`@("`@("`@:68@*"1T
M:&ES+3YC;VQ%>&ES=',H)&-O;"`M(#$I*2!["B`@("`@("`@("`@("1H96EG
M:'0@/2`D=&AI<RT^9V5T2&5I9VAT*"1R;W<L("1C;VPI.PH@("`@("`@("`@
M("`O+R!3964@:68@=&AE<F4G<R!R;V]M('1O(&UO=F4@:6YT;RX*("`@("`@
M("`@("`@9F]R("@D:2`](#`[("1I(#P@)&AE:6=H=#L@)&DK*RD@>PH@("`@
M("`@("`@("`@("`@:68@*"$D=&AI<RT^:7-%;7!T>2@D<F]W("L@)&DL("1C
M;VP@+2`Q*2D@>PH@("`@("`@("`@("`@("`@("`@("1I;E]W87D@/2`D=&AI
M<RT^9V5T0FQO8VM!="@D<F]W("L@)&DL("1C;VP@+2`Q*3L*("`@("`@("`@
M("`@("`@("`@("!I9B`H(6ES7VYU;&PH)&EN7W=A>2D@)B8*("`@("`@("`@
M("`@("`@("`@("`@("`@)&EN7W=A>5LP72`]/2`D<F]W("8F"B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YG971(96EG:'0H)&EN7W=A>5LP72P@
M)&EN7W=A>5LQ72D@/3T@)&AE:6=H="D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!792!N965D('1O('-W87`@=&AE(&)L;V-K<RX*("`@("`@("`@
M("`@("`@("`@("`@("`@)')E8S$@/2!(;W)D95]!<G)A>3HZ9V5T4F5C=&%N
M9VQE*"1T:&ES+3Y?;&%Y;W5T+"`D<F]W+"`D8V]L+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/F=E=$AE:6=H="@D<F]W+"`D8V]L*2P@)'1H:7,M/F=E=%=I9'1H
M*"1R;W<L("1C;VPI*3L*("`@("`@("`@("`@("`@("`@("`@("`@)')E8S(@
M/2!(;W)D95]!<G)A>3HZ9V5T4F5C=&%N9VQE*"1T:&ES+3Y?;&%Y;W5T+"`D
M:6Y?=V%Y6S!=+"`D:6Y?=V%Y6S%=+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E
M=$AE:6=H="@D:6Y?=V%Y6S!=+"`D:6Y?=V%Y6S%=*2P@)'1H:7,M/F=E=%=I
M9'1H*"1I;E]W87E;,%TL("1I;E]W87E;,5TI*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@9F]R("@D:B`](#`[("1J(#P@8V]U;G0H)')E8S$I.R`D:BLK
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W(@*"1K(#T@,#L@
M)&L@/"!C;W5N="@D<F5C,5LD:ETI.R`D:RLK*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)&EN7W=A>5LP72`K
M("1J75LD:6Y?=V%Y6S%=("L@)&M=(#T@)')E8S%;)&I=6R1K73L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!F;W(@*"1J(#T@,#L@)&H@
M/"!C;W5N="@D<F5C,BD[("1J*RLI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&9O<B`H)&L@/2`P.R`D:R`\(&-O=6YT*"1R96,R6R1J72D[("1K
M*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7VQA>6]U=%LD:6Y?=V%Y6S!=("L@)&I=6R1I;E]W87E;,5T@*R!C;W5N="@D
M<F5C,5LD:ETI("L@)&M=(#T@)')E8S);)&I=6R1K73L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-H86YG961?<F]W(#T@
M)&EN7W=A>5LP73L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C
M:&%N9V5D7V-O;"`]("1I;E]W87E;,5T["B`@("`@("`@("`@("`@("`@("`@
M("`@(')E='5R;CL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@+R\@3F\@=VAE<F4@=&\@9V\*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")3:')I;FL@;W(@;6]V92!N
M96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B*2P@
M)VAO<F1E+G=A<FYI;F<G*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)&QA<W1C;VP@/2`D8V]L("L@)'1H:7,M/F=E
M=%=I9'1H*"1R;W<L("1C;VPI("T@,3L*("`@("`@("`@("`@9F]R("@D:2`]
M(#`[("1I(#P@)&AE:6=H=#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)'!R
M978@/2`D=&AI<RT^7VQA>6]U=%LD<F]W("L@)&E=6R1C;VQ=.PH@("`@("`@
M("`@("`@("`@+R\@36]V92!L969T(&AA;F0@961G90H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]L87EO=71;)')O=R`K("1I75LD8V]L("T@,5T@/2`D<')E
M=CL*("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W<@*R`D:5U;
M)&-O;%T@/2`G8V]V97)E9"<["B`@("`@("`@("`@("`@("`O+R!-;W9E(')I
M9VAT(&AA;F0@961G90H@("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;
M)')O=R`K("1I75LD;&%S=&-O;%T@/2`G96UP='DG.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!I9B`H(21T:&ES+3YC;VQ%>&ES=',H)&QA<W1C;VP@
M*R`Q*2D@>PH@("`@("`@("`@("`@("`@+R\@5V%S(&]N('1H92!R:6=H="UM
M;W-T(&-O;'5M;@H@("`@("`@("`@("`@("`@)'1H:7,M/G)E;6]V94-O;$EF
M16UP='DH)&QA<W1C;VPI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M=&AI<RT^7V-H86YG961?<F]W(#T@)')O=SL*("`@("`@("`@("`@)'1H:7,M
M/E]C:&%N9V5D7V-O;"`]("1C;VP@+2`Q.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($UO=F5S(&$@8FQO8VL@;VYE(&-O;'5M;B!R:6=H="X*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U="!R
M;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C;VQU
M;6XN"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO=F52:6=H="@D<F]W+"`D8V]L
M*0H@("`@>PH@("`@("`@("1H96EG:'0@/2`D=&AI<RT^9V5T2&5I9VAT*"1R
M;W<L("1C;VPI.PH@("`@("`@("1L87-T8V]L(#T@)&-O;"`K("1T:&ES+3YG
M9717:61T:"@D<F]W+"`D8V]L*3L*("`@("`@("!I9B`H)'1H:7,M/F-O;$5X
M:7-T<R@D;&%S=&-O;"DI('L*("`@("`@("`@("`@+R\@4V5E(&EF('1H97)E
M)W,@<F]O;2!T;R!M;W9E(&EN=&\N"B`@("`@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\("1H96EG:'0[("1I*RLI('L*("`@("`@("`@("`@("`@(&EF("@A
M)'1H:7,M/FES16UP='DH)')O=R`K("1I+"`D;&%S=&-O;"DI('L*("`@("`@
M("`@("`@("`@("`@("`D:6Y?=V%Y(#T@)'1H:7,M/F=E=$)L;V-K070H)')O
M=R`K("1I+"`D;&%S=&-O;"D["B`@("`@("`@("`@("`@("`@("`@:68@*"%I
M<U]N=6QL*"1I;E]W87DI("8F"B`@("`@("`@("`@("`@("`@("`@("`@("1I
M;E]W87E;,%T@/3T@)')O=R`F)@H@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^9V5T2&5I9VAT*"1I;E]W87E;,%TL("1I;E]W87E;,5TI(#T]("1H
M96EG:'0I('L*("`@("`@("`@("`@("`@("`@("`@("`@+R\@5V4@;F5E9"!T
M;R!S=V%P('1H92!B;&]C:W,N"B`@("`@("`@("`@("`@("`@("`@("`@("1R
M96,Q(#T@2&]R9&5?07)R87DZ.F=E=%)E8W1A;F=L92@D=&AI<RT^7VQA>6]U
M="P@)')O=RP@)&-O;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YG971(96EG:'0H
M)')O=RP@)&-O;"DL("1T:&ES+3YG9717:61T:"@D<F]W+"`D8V]L*2D["B`@
M("`@("`@("`@("`@("`@("`@("`@("1R96,R(#T@2&]R9&5?07)R87DZ.F=E
M=%)E8W1A;F=L92@D=&AI<RT^7VQA>6]U="P@)&EN7W=A>5LP72P@)&EN7W=A
M>5LQ72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YG971(96EG:'0H)&EN7W=A>5LP
M72P@)&EN7W=A>5LQ72DL("1T:&ES+3YG9717:61T:"@D:6Y?=V%Y6S!=+"`D
M:6Y?=V%Y6S%=*2D["B`@("`@("`@("`@("`@("`@("`@("`@(&9O<B`H)&H@
M/2`P.R`D:B`\(&-O=6YT*"1R96,R*3L@)&HK*RD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@9F]R("@D:R`](#`[("1K(#P@8V]U;G0H)')E8S);
M)&I=*3L@)&LK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;&%Y;W5T6R1R;W<@*R`D:EU;)&-O;"`K("1K72`]("1R96,R
M6R1J75LD:UT["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@
M9F]R("@D:B`](#`[("1J(#P@8V]U;G0H)')E8S$I.R`D:BLK*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!F;W(@*"1K(#T@,#L@)&L@/"!C;W5N
M="@D<F5C,5LD:ETI.R`D:RLK*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=R`K("1J75LD8V]L("L@8V]U
M;G0H)')E8S);)&I=*2`K("1K72`]("1R96,Q6R1J75LD:UT["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C:&%N9V5D7W)O
M=R`]("1I;E]W87E;,%T["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?8VAA;F=E9%]C;VP@/2`D:6Y?=V%Y6S%=.PH@("`@("`@("`@("`@("`@
M("`@("`@("!R971U<FX["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("\O($YO('=H97)E('1O(&=O"B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B4VAR:6YK(&]R(&UO
M=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T
M(BDL("=H;W)D92YW87)N:6YG)RD["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!-86ME
M(')O;VT@=&\@;6]V92!I;G1O+@H@("`@("`@("`@("`D=&AI<RT^861D0V]L
M*"1L87-T8V]L*3L*("`@("`@("!]"@H@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\("1H96EG:'0[("1I*RLI('L*("`@("`@("`@("`@)'!R978@/2`D=&AI
M<RT^7VQA>6]U=%LD<F]W("L@)&E=6R1C;VQ=.PH@("`@("`@("`@("`O+R!-
M;W9E(')I9VAT(&AA;F0@961G90H@("`@("`@("`@("`D=&AI<RT^7VQA>6]U
M=%LD<F]W("L@)&E=6R1L87-T8V]L72`]("=C;W9E<F5D)SL*("`@("`@("`@
M("`@+R\@36]V92!L969T(&AA;F0@961G90H@("`@("`@("`@("`D=&AI<RT^
M7VQA>6]U=%LD<F]W("L@)&E=6R1C;VP@*R`Q72`]("1P<F5V.PH@("`@("`@
M("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W("L@)&E=6R1C;VQ=(#T@)V5M<'1Y
M)SL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]R;W<@/2`D
M<F]W.PH@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]C;VP@/2`D8V]L("L@,3L*
M("`@('T*"B`@("`O*BH*("`@("`J($UO=F5S(&%L;"!B;&]C:W,@869T97(@
M82!C97)T86EN(&-O;'5M;B!O;F4@8V]L=6UN(')I9VAT+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M;BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@86QL(&-O;'5M
M;G,@8V]U;&0@8F4@;6]V960@<FEG:'0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&UO=F52:6=H=$%F=&5R*"1C;VPI"B`@("!["B`@("`@("`@)&UO=F5D(#T@
M87)R87DH*3L*("`@("`@("!F;W(@*"1X(#T@)'1H:7,M/E]C;VQU;6YS("T@
M,3L@)'@@/B`D8V]L.R`D>"TM*2!["B`@("`@("`@("`@(&9O<B`H)'D@/2`P
M.R`D>2`\(&-O=6YT*"1T:&ES+3Y?;&%Y;W5T*3L@)'DK*RD@>PH@("`@("`@
M("`@("`@("`@)&)L;V-K(#T@)'1H:7,M/F=E=$)L;V-K070H)'DL("1X*3L*
M("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D8FQO8VLI*2!["B`@("`@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!I9B`H96UP='DH)&UO=F5D6R1B;&]C:ULQ72`N("<Z)R`N
M("1B;&]C:ULP75TI*2!["B`@("`@("`@("`@("`@("`@("`@)&UO=F5D6R1B
M;&]C:ULQ72`N("<Z)R`N("1B;&]C:ULP75T@/2!T<G5E.PH@("`@("`@("`@
M("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^;6]V95)I9VAT*"1B;&]C:ULP
M72P@)&)L;V-K6S%=*3L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!-86ME<R!A(&)L
M;V-K(&]N92!R;W<@=&%L;&5R(&)Y(&UO=FEN9R!T:&4@=&]P('5P+@H@("`@
M("H*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O=RX*
M("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M;BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@97AP86YD57`H)')O=RP@)&-O;"D*("`@
M('L*("`@("`@("!I9B`H)'1H:7,M/G)O=T5X:7-T<R@D<F]W("T@,2DI('L*
M("`@("`@("`@("`@)'=I9'1H(#T@)'1H:7,M/F=E=%=I9'1H*"1R;W<L("1C
M;VPI.PH@("`@("`@("`@("`O+R!3964@:68@=&AE<F4G<R!R;V]M('1O(&5X
M<&%N9"!I;G1O"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1W:61T
M:#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^:7-%;7!T
M>2@D<F]W("T@,2P@)&-O;"`K("1I*2D@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("@A)'1H:7,M/FUO=F5$;W=N0F5L;W<H)')O=R`M(#$I*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@
M=&AE('=A>2!F:7)S="(I+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1R
M;W<K*SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M("1W:61T:#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO
M=71;)')O=R`M(#%=6R1C;VP@*R`D:5T@/2`D=&AI<RT^7VQA>6]U=%LD<F]W
M75LD8V]L("L@)&E=.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;
M)')O=UU;)&-O;"`K("1I72`]("=C;W9E<F5D)SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W("T@,5U;)&-O;%U;)VAE
M:6=H="==(#T@)'1H:7,M/F=E=$AE:6=H="@D<F]W("T@,2P@)&-O;"D@*R`Q
M.PH*("`@("`@("`@("`@)'1H:7,M/E]C:&%N9V5D7W)O=R`]("1R;W<@+2`Q
M.PH@("`@("`@("`@("`D=&AI<RT^7V-H86YG961?8V]L(#T@)&-O;#L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!-86ME<R!A(&)L;V-K(&]N
M92!R;W<@=&%L;&5R(&)Y(&UO=FEN9R!T:&4@8F]T=&]M(&1O=VXN"B`@("`@
M*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L87EO=70@<F]W+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO=70@8V]L=6UN+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!E>'!A;F1$;W=N*"1R;W<L("1C;VPI"B`@
M("!["B`@("`@("`@)'=I9'1H(#T@)'1H:7,M/F=E=%=I9'1H*"1R;W<L("1C
M;VPI.PH@("`@("`@("1L87-T<F]W(#T@)')O=R`K("1T:&ES+3YG971(96EG
M:'0H)')O=RP@)&-O;"D@+2`Q.PH@("`@("`@(&EF("@A)'1H:7,M/G)O=T5X
M:7-T<R@D;&%S=')O=R`K(#$I*2!["B`@("`@("`@("`@("\O($%D9"!A(&YE
M=R!R;W<N"B`@("`@("`@("`@("1T:&ES+3YA9&12;W<H)&QA<W1R;W<@*R`Q
M*3L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)'=I9'1H.R`D:2LK
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD;&%S=')O=R`K
M(#%=6R1C;VP@*R`D:5T@/2`G8V]V97)E9"<["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%U;)VAE:6=H="==
M(#T@)'1H:7,M/F=E=$AE:6=H="@D<F]W+"`D8V]L*2`K(#$["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@+R\@4V5E(&EF('1H97)E)W,@<F]O;2!T
M;R!E>'!A;F0@:6YT;PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D
M=VED=&@[("1I*RLI('L*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/FES
M16UP='DH)&QA<W1R;W<@*R`Q+"`D8V]L("L@)&DI*2!["B`@("`@("`@("`@
M("`@("`@("`@:68@*"$D=&AI<RT^;6]V941O=VY"96QO=R@D;&%S=')O=RDI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H7R@B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I
M(&]U="!O9B!T:&4@=V%Y(&9I<G-T(BDL("=H;W)D92YW87)N:6YG)RD["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D=VED=&@[
M("1I*RLI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1L87-T
M<F]W("L@,5U;)&-O;"`K("1I72`]("=C;W9E<F5D)SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L75LG:&5I
M9VAT)UT@/2`D=&AI<RT^9V5T2&5I9VAT*"1R;W<L("1C;VPI("L@,3L*("`@
M("`@("!]"@H@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]R;W<@/2`D<F]W.PH@
M("`@("`@("1T:&ES+3Y?8VAA;F=E9%]C;VP@/2`D8V]L.PH@("`@?0H*("`@
M("\J*@H@("`@("H@36%K97,@82!B;&]C:R!O;F4@8V]L=6UN('=I9&5R(&)Y
M(&UO=FEN9R!T:&4@;&5F="!S:61E(&]U="X*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&5X<&%N9$QE9G0H)')O=RP@)&-O;"D*("`@('L*("`@("`@("!I
M9B`H)'1H:7,M/F-O;$5X:7-T<R@D8V]L("T@,2DI('L*("`@("`@("`@("`@
M)&AE:6=H="`]("1T:&ES+3YG971(96EG:'0H)')O=RP@)&-O;"D["B`@("`@
M("`@("`@("\O(%-E92!I9B!T:&5R92=S(')O;VT@=&\@97AP86YD(&EN=&\*
M("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&AE:6=H=#L@)&DK*RD@
M>PH@("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^:7-%;7!T>2@D<F]W("L@
M)&DL("1C;VP@+2`Q*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@A)'1H
M:7,M/FUO=F52:6=H=$%F=&5R*"1C;VP@+2`Q*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")3:')I;FL@
M;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@
M9FER<W0B*2P@)VAO<F1E+G=A<FYI;F<G*3L*("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D8V]L*RL["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D:&5I9VAT
M.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W
M("L@)&E=6R1C;VP@+2`Q72`]("1T:&ES+3Y?;&%Y;W5T6R1R;W<@*R`D:5U;
M)&-O;%T["B`@("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W("L@
M)&E=6R1C;VQ=(#T@)V-O=F5R960G.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VP@+2`Q75LG=VED=&@G72`]
M("1T:&ES+3YG9717:61T:"@D<F]W+"`D8V]L("T@,2D@*R`Q.PH*("`@("`@
M("`@("`@)'1H:7,M/E]C:&%N9V5D7W)O=R`]("1R;W<["B`@("`@("`@("`@
M("1T:&ES+3Y?8VAA;F=E9%]C;VP@/2`D8V]L("T@,3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!-86ME<R!A(&)L;V-K(&]N92!C;VQU;6X@
M=VED97(@8GD@;6]V:6YG('1H92!R:6=H="!S:61E(&]U="X*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&5X<&%N9%)I9VAT*"1R;W<L("1C;VPI"B`@("![
M"B`@("`@("`@)&AE:6=H="`]("1T:&ES+3YG971(96EG:'0H)')O=RP@)&-O
M;"D["B`@("`@("`@)&QA<W1C;VP@/2`D8V]L("L@)'1H:7,M/F=E=%=I9'1H
M*"1R;W<L("1C;VPI("T@,3L*("`@("`@("!I9B`H)'1H:7,M/F-O;$5X:7-T
M<R@D;&%S=&-O;"`K(#$I*2!["B`@("`@("`@("`@("\O(%-E92!I9B!T:&5R
M92=S(')O;VT@=&\@97AP86YD(&EN=&\*("`@("`@("`@("`@9F]R("@D:2`]
M(#`[("1I(#P@)&AE:6=H=#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@:68@
M*"$D=&AI<RT^:7-%;7!T>2@D<F]W("L@)&DL("1L87-T8V]L("L@,2DI('L*
M("`@("`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YM;W9E4FEG:'1!9G1E
M<B@D;&%S=&-O;"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R
M:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(BDL("=H;W)D92YW
M87)N:6YG)RD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!F;W(@*"1I(#T@,#L@
M)&D@/"`D:&5I9VAT.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7VQA>6]U=%LD<F]W("L@)&E=6R1L87-T8V]L("L@,5T@/2`G8V]V97)E9"<[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O
M=UU;)&-O;%U;)W=I9'1H)UT@/2`D=&AI<RT^9V5T5VED=&@H)')O=RP@)&-O
M;"D@*R`Q.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O($%D9"!N
M97<@8V]L=6UN"B`@("`@("`@("`@("1T:&ES+3YA9&1#;VPH)&QA<W1C;VP@
M*R`Q*3L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&AE:6=H=#L@
M)&DK*RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=R`K
M("1I75LD;&%S=&-O;"`K(#%=(#T@)V-O=F5R960G.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=6R=W:61T
M:"==(#T@)'1H:7,M/F=E=%=I9'1H*"1R;W<L("1C;VPI("L@,3L*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]R;W<@/2`D<F]W.PH@("`@
M("`@("1T:&ES+3Y?8VAA;F=E9%]C;VP@/2`D8V]L.PH@("`@?0H*("`@("\J
M*@H@("`@("H@36%K97,@82!B;&]C:R!O;F4@<F]W(&QO=V5R(&)Y(&UO=FEN
M9R!T:&4@=&]P(&1O=VXN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)')O=R`@02!L87EO=70@<F]W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O
M;"`@02!L87EO=70@8V]L=6UN+@H@("`@("HO"B`@("!F=6YC=&EO;B!S:')I
M;FM5<"@D<F]W+"`D8V]L*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^9V5T
M2&5I9VAT*"1R;W<L("1C;VPI(#X@,2D@>PH@("`@("`@("`@("`D=VED=&@@
M/2`D=&AI<RT^9V5T5VED=&@H)')O=RP@)&-O;"D["B`@("`@("`@("`@(&9O
M<B`H)&D@/2`P.R`D:2`\("1W:61T:#L@)&DK*RD@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]L87EO=71;)')O=R`K(#%=6R1C;VP@*R`D:5T@/2`D=&AI
M<RT^7VQA>6]U=%LD<F]W75LD8V]L("L@)&E=.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;"`K("1I72`]("=E;7!T>2<["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=R`K
M(#%=6R1C;VQ=6R=H96EG:'0G72`]("1T:&ES+3YG971(96EG:'0H)')O=R`K
M(#$L("1C;VPI("T@,3L*"B`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]R
M;W<@/2`D<F]W("L@,3L*("`@("`@("`@("`@)'1H:7,M/E]C:&%N9V5D7V-O
M;"`]("1C;VP["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@36%K
M97,@82!B;&]C:R!O;F4@<F]W(&QO=V5R(&)Y(&UO=FEN9R!T:&4@8F]T=&]M
M('5P+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y
M;W5T(')O=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T
M(&-O;'5M;BX*("`@("`J+PH@("`@9G5N8W1I;VX@<VAR:6YK1&]W;B@D<F]W
M+"`D8V]L*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^9V5T2&5I9VAT*"1R
M;W<L("1C;VPI(#X@,2D@>PH@("`@("`@("`@("`D;&%S=')O=R`]("1R;W<@
M*R`D=&AI<RT^9V5T2&5I9VAT*"1R;W<L("1C;VPI("T@,3L*("`@("`@("`@
M("`@)'=I9'1H(#T@)'1H:7,M/F=E=%=I9'1H*"1R;W<L("1C;VPI.PH@("`@
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D=VED=&@[("1I*RLI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1L87-T<F]W75LD8V]L("L@
M)&E=(#T@)V5M<'1Y)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI
M<RT^7VQA>6]U=%LD<F]W75LD8V]L75LG:&5I9VAT)UT@/2`D=&AI<RT^9V5T
M2&5I9VAT*"1R;W<L("1C;VPI("T@,3L*("`@("`@("`@("`@:68@*"$D=&AI
M<RT^<F]W17AI<W1S*"1L87-T<F]W("L@,2DI('L*("`@("`@("`@("`@("`@
M("\O(%=A<R!O;B!T:&4@8F]T=&]M(')O=PH@("`@("`@("`@("`@("`@)'1H
M:7,M/G)E;6]V95)O=TEF16UP='DH)&QA<W1R;W<I.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`D=&AI<RT^7V-H86YG961?<F]W(#T@)')O=SL*("`@
M("`@("`@("`@)'1H:7,M/E]C:&%N9V5D7V-O;"`]("1C;VP["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@36%K97,@82!B;&]C:R!O;F4@8V]L
M=6UN(&YA<G)O=V5R(&)Y(&UO=FEN9R!T:&4@;&5F="!S:61E(&EN+@H@("`@
M("H*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O=RX*
M("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M;BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@<VAR:6YK3&5F="@D<F]W+"`D8V]L*0H@
M("`@>PH@("`@("`@(&EF("@D=&AI<RT^9V5T5VED=&@H)')O=RP@)&-O;"D@
M/B`Q*2!["B`@("`@("`@("`@("1H96EG:'0@/2`D=&AI<RT^9V5T2&5I9VAT
M*"1R;W<L("1C;VPI.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D
M:&5I9VAT.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U
M=%LD<F]W("L@)&E=6R1C;VP@*R`Q72`]("1T:&ES+3Y?;&%Y;W5T6R1R;W<@
M*R`D:5U;)&-O;%T["B`@("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD
M<F]W("L@)&E=6R1C;VQ=(#T@)V5M<'1Y)SL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L("L@,5U;)W=I9'1H
M)UT@/2`D=&AI<RT^9V5T5VED=&@H)')O=RP@)&-O;"`K(#$I("T@,3L*"B`@
M("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]R;W<@/2`D<F]W.PH@("`@("`@
M("`@("`D=&AI<RT^7V-H86YG961?8V]L(#T@)&-O;"`K(#$["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@36%K97,@82!B;&]C:R!O;F4@8V]L
M=6UN(&YA<G)O=V5R(&)Y(&UO=FEN9R!T:&4@<FEG:'0@<VED92!I;BX*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U="!R;W<N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-H<FEN:U)I9VAT*"1R;W<L("1C;VPI
M"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YG9717:61T:"@D<F]W+"`D8V]L
M*2`^(#$I('L*("`@("`@("`@("`@)&QA<W1C;VP@/2`D8V]L("L@)'1H:7,M
M/F=E=%=I9'1H*"1R;W<L("1C;VPI("T@,3L*("`@("`@("`@("`@)&AE:6=H
M="`]("1T:&ES+3YG971(96EG:'0H)')O=RP@)&-O;"D["B`@("`@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\("1H96EG:'0[("1I*RLI('L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W<@*R`D:5U;)&QA<W1C;VQ=(#T@
M)V5M<'1Y)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7VQA
M>6]U=%LD<F]W75LD8V]L75LG=VED=&@G72`]("1T:&ES+3YG9717:61T:"@D
M<F]W+"`D8V]L*2`M(#$["B`@("`@("`@("`@("1T:&ES+3YR96UO=F5#;VQ)
M9D5M<'1Y*"1L87-T8V]L*3L*"B`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E
M9%]R;W<@/2`D<F]W.PH@("`@("`@("`@("`D=&AI<RT^7V-H86YG961?8V]L
M(#T@)&-O;#L*("`@("`@("!]"B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]6:65W
M+G!H<```````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,#4S,@`Q,#4Q-30S
M,S<U,0`P,C,T,38`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O0G)O=W-E<BYP
M:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP
M)SL*"B\J*@H@*B!4:&4@2&]R9&5?0FQO8VM?3&%Y;W5T7U9I97<@8VQA<W,@
M<F5P<F5S96YT<R!T:&4@=7-E<B!D969I;F5D('!O<G1A;"!L87EO=70N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]6:65W
M+G!H<"QV(#$N-"XR+C,@,C`P-B\P-B\R,R`P-#HS-3HR,2!C:'5C:R!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI:V4@0V]C:')A;F4@/&UI
M:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@
M2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN
M8V\N;GH^"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO
M<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,@H@*B!`<&%C:V%G92!(;W)D95]"
M;&]C:PH@*B\*8VQA<W,@2&]R9&5?0FQO8VM?3&%Y;W5T7U9I97<@>PH*("`@
M("\J*@H@("`@("H@5&AE(&-U<G)E;G0@8FQO8VL@;&%Y;W5T+@H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?;&%Y;W5T(#T@
M87)R87DH*3L*"B`@("`O*BH*("`@("`J($%L;"!A<'!L:6-A=&EO;G,@=7-E
M9"!I;B!T:&ES(&QA>6]U="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D7V%P<&QI8V%T:6]N<R`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*B!#4U,@;&EN:R!T86=S('!U;&QE9"!O=70@;V8@8FQO8VL@
M8V]N=&5N="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D7VQI;FM486=S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=&]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]";&]C:U],
M87EO=71?5FEE=R@D;&%Y;W5T(#T@)R<I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]L87EO=70@/2!`=6YS97)I86QI>F4H)&QA>6]U="D["B`@("`@("`@:68@
M*"$D=&AI<RT^7VQA>6]U="D@>PH@("`@("`@("`@("`D=&AI<RT^7VQA>6]U
M="`](&%R<F%Y*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4F5N9&5R('1H92!C=7)R96YT(&QA>6]U="!A<R!(5$U,+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG($A434P@;&%Y;W5T+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!T;TAT;6PH*0H@("`@>PH@("`@("`@("1B<F]W<V5R(#T@)D)R
M;W=S97(Z.G-I;F=L971O;B@I.PH@("`@("`@("1T<&Q$:7(@/2`D1TQ/0D%,
M4ULG<F5G:7-T<GDG72T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*3L*("`@
M("`@("`D:6YT97)V86P@/2`D1TQ/0D%,4ULG<')E9G,G72T^9V5T5F%L=64H
M)W-U;6UA<GE?<F5F<F5S:%]T:6UE)RD["@H@("`@("`@("1H=&UL(#T@)SQT
M86)L92!C;&%S<STB;F]P861D:6YG(B!C96QL<W!A8VEN9STB-B(@=VED=&@]
M(C$P,"4B/B<["@H@("`@("`@("1C;W9E<F5D(#T@87)R87DH*3L*("`@("`@
M("!F;W)E86-H("@D=&AI<RT^7VQA>6]U="!A<R`D<F]W7VYU;2`]/B`D<F]W
M*2!["B`@("`@("`@("`@("1W:61T:"`](&9L;V]R*#$P,"`O(&-O=6YT*"1R
M;W<I*3L*("`@("`@("`@("`@)&AT;6P@+CT@)SQT<CXG.PH@("`@("`@("`@
M("!F;W)E86-H("@D<F]W(&%S("1C;VQ?;G5M(#T^("1I=&5M*2!["B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&-O=F5R961;)')O=U]N=6U=*2`F)B!I
M<W-E="@D8V]V97)E9%LD<F]W7VYU;5U;)&-O;%]N=6U=*2D@>PH@("`@("`@
M("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1I=&5M*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?87!P;&EC871I;VYS6R1I=&5M6R=A<'`G75T@
M/2`D:71E;5LG87!P)UT["B`@("`@("`@("`@("`@("`@("`@)&)L;V-K(#T@
M)DAO<F1E7T)L;V-K7T-O;&QE8W1I;VXZ.F=E=$)L;V-K*"1I=&5M6R=A<'`G
M72P@)&ET96U;)W!A<F%M<R==6R=T>7!E)UTL("1I=&5M6R=P87)A;7,G75LG
M<&%R86US)UTI.PH@("`@("`@("`@("`@("`@("`@("1R;W=S<&%N(#T@)&ET
M96U;)VAE:6=H="==.PH@("`@("`@("`@("`@("`@("`@("1C;VQS<&%N(#T@
M)&ET96U;)W=I9'1H)UT["B`@("`@("`@("`@("`@("`@("`@)'=I9'1H("H]
M("1C;VQS<&%N.PH@("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\("1I=&5M6R=H96EG:'0G73L@)&DK*RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1C;W9E<F5D6R1R;W=?;G5M("L@)&E=*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O=F5R961;)')O=U]N
M=6T@*R`D:5T@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<B`H)&H@/2`P.R`D:B`\("1I
M=&5M6R=W:61T:"==.R`D:BLK*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D8V]V97)E9%LD<F]W7VYU;2`K("1I75LD8V]L7VYU;2`K("1J72`]
M('1R=64["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*&ES7V$H)&)L;V-K
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1H
M96%D97(@/2!?*")%<G)O<B(I.PH@("`@("`@("`@("`@("`@("`@("`@("`D
M8V]N=&5N="`]("1B;&]C:RT^9V5T365S<V%G92@I.PH@("`@("`@("`@("`@
M("`@("`@("`@("!O8E]S=&%R="@I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!I;F-L=61E("1T<&Q$:7(@+B`G+W!O<G1A;"]B;&]C:RYI;F,G.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2!O8E]G971?8VQE86XH*3L*
M("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-?82@D8FQO8VLL("=(
M;W)D95]";&]C:R<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1H96%D
M97(@/2`D8FQO8VLM/F=E=%1I=&QE*"D["B`@("`@("`@("`@("`@("`@("`@
M("`@("1C;VYT96YT(#T@)&)L;V-K+3YG971#;VYT96YT*"D["B`@("`@("`@
M("`@("`@("`@("`@("`@(&]B7W-T87)T*"D["B`@("`@("`@("`@("`@("`@
M("`@("`@(&EN8VQU9&4@)'1P;$1I<B`N("<O<&]R=&%L+V)L;V-K+FEN8R<[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1H=&UL("X](&]B7V=E=%]C;&5A
M;B@I.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1H=&UL("X]("<\=&0@=VED=&@](B<@+B`D=VED=&@@
M+B`G)2(^)FYB<W`[/"]T9#XG.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&AT
M;6P@+CT@)SQT9"!W:61T:#TB)R`N("1W:61T:"`N("<E(CXF;F)S<#L\+W1D
M/B<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)&AT;6P@+CT@)SPO='(^)SL*("`@("`@("!]"B`@("`@("`@)&AT;6P@
M+CT@)SPO=&%B;&4^)SL*"B`@("`@("`@+R\@4W1R:7`@86YY($-34R`\;&EN
M:SX@=&%G<R!O=70@;V8@=&AE(')E='5R;F5D(&-O;G1E;G0@<V\*("`@("`@
M("`O+R!T:&5Y(&-A;B!B92!H86YD;&5D('-E<&5R871E;'DN"B`@("`@("`@
M:68@*'!R96=?;6%T8VA?86QL*"<O/&QI;FL@+BH_<F5L/2)S='EL97-H965T
M(BXJ/UPO/B\G+"`D:'1M;"P@)&QI;FMS*2D@>PH@("`@("`@("`@("`D:'1M
M;"`]('-T<E]R97!L86-E*"1L:6YK<ULP72P@)R<L("1H=&UL*3L*("`@("`@
M("`@("`@)'1H:7,M/E]L:6YK5&%G<R`]("1L:6YK<ULP73L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D:'1M;#L*("`@('T*"B`@("`O*BH*("`@("`J
M($=E="!A;GD@;&EN:R!T86=S(&9O=6YD(&EN('1H92!V:65W+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971,:6YK5&%G<R@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?;&EN:U1A9W,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FX@82!L:7-T(&]F(&%L;"!T:&4@87!P;&EC871I;VYS('5S960@8GD@
M8FQO8VMS(&EN('1H:7,@;&%Y;W5T+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@3&ES="!O9B!A<'!L:6-A=&EO;G,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$%P<&QI8V%T:6]N<R@I"B`@("!["B`@("`@("`@<F5T=7)N(&%R
M<F%Y7VME>7,H)'1H:7,M/E]A<'!L:6-A=&EO;G,I.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O0FQO8VLO54DN<&AP````````````````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-S8W`#$P-3$U-#,S-S4Q`#`R,34V
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@0VQA<W,@9F]R('-E='1I;F<@=7`@2&]R9&4@0FQO8VMS
M('5S:6YG('1H92!(;W)D95]&;W)M.CH@8VQA<W-E<RX*("H*("H@0V]P>7)I
M9VAT(#(P,#0M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO54DN<&AP+'8@,2XX+C$P+C4@,C`P-B\P,2\P,B`Q-SHT-CHS-2!J86X@
M17AP("0*("H*("H@0&%U=&AO<B`@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO
M+F-O;3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E
M7T)L;V-K"B`J+PIC;&%S<R!(;W)D95]";&]C:U]522!["@H@("`@=F%R("1?
M8FQO8VMS(#T@87)R87DH*3L*("`@('9A<B`D7V9O<FT@/2!N=6QL.PH@("`@
M=F%R("1?=F%R<R`](&YU;&P["@H@("`@9G5N8W1I;VX@2&]R9&5?0FQO8VM?
M54DH*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O0FQO8VLN
M<&AP)SL*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T)L;V-K+T-O;&QE
M8W1I;VXN<&AP)SL*("`@("`@("`D=&AI<RT^7V)L;V-K<R`]("9(;W)D95]"
M;&]C:U]#;VQL96-T:6]N.CIS:6YG;&5T;VXH*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!S971&;W)M*"8D9F]R;2D*("`@('L*("`@("`@("`D=&AI<RT^7V9O
M<FT@/2`F)&9O<FT["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T5F%R<R@F)'9A
M<G,I"B`@("!["B`@("`@("`@)'1H:7,M/E]V87)S(#T@)B1V87)S.PH@("`@
M?0H*("`@(&9U;F-T:6]N('-E='5P161I=$9O<FTH)&9I96QD(#T@)V)L;V-K
M)RD*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7W9A<G,I*2![
M"B`@("`@("`@("`@("\J($YO(&5X:7-T:6YG('9A<G,@<V5T+"!G970@=&AE
M;2!N;W<N("HO"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O5F%R
M:6%B;&5S+G!H<"<["B`@("`@("`@("`@("1T:&ES+3Y?=F%R<R`]("9687)I
M86)L97,Z.F=E=$1E9F%U;'1687)I86)L97,H*3L*("`@("`@("!]"@H@("`@
M("`@(&EF("@A:7-?82@D=&AI<RT^7V9O<FTL("=(;W)D95]&;W)M)RDI('L*
M("`@("`@("`@("`@+RH@3F\@97AI<W1I;F<@=F%L:60@9F]R;2!O8FIE8W0@
M<V5T('-O('-E="!U<"!A(&YE=R!O;F4N("HO"B`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G2&]R9&4O1F]R;2YP:'`G.PH@("`@("`@("`@("`D=&AI<RT^
M7V9O<FT@/2`F2&]R9&5?1F]R;3HZ<VEN9VQE=&]N*"<G+"`D=&AI<RT^7W9A
M<G,L(%\H(D5D:70@0FQO8VLB*2D["B`@("`@("`@?0H*("`@("`@("`O*B!'
M970@=&AE(&-U<G)E;G0@=F%L=64@;V8@=&AE(&)L;V-K('-E;&5C=&EO;BX@
M*B\*("`@("`@("`D=F%L=64@/2`D=&AI<RT^7W9A<G,M/F=E="@D9FEE;&0I
M.PH*("`@("`@("`O*B!&:65L9"!T;R!S96QE8W0@87!P<RX@*B\*("`@("`@
M("`D87!P<R`]("1T:&ES+3Y?8FQO8VMS+3YG971";&]C:W-,:7-T*"D["B`@
M("`@("`@)'8@/2`F)'1H:7,M/E]F;W)M+3YA9&1687)I86)L92A?*")!<'!L
M:6-A=&EO;B(I+"`D9FEE;&0@+B`G6V%P<%TG+"`G96YU;2<L('1R=64L(&9A
M;'-E+"!N=6QL+"!A<G)A>2@D87!P<RDI.PH@("`@("`@("1V+3YS971/<'1I
M;VXH)W1R86-K8VAA;F=E)RP@=')U92D["@H@("`@("`@(&EF("AE;7!T>2@D
M=F%L=65;)V%P<"==*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@
M?0H*("`@("`@("`O*B!)9B!A(&)L;V-K(&AA<R!B965N('-E;&5C=&5D+"!O
M=71P=70@86YY(&]P=&EO;G,@:6YP=70N("HO"B`@("`@("`@;&ES="@D87!P
M+"`D8FQO8VLI(#T@97AP;&]D92@G.B<L("1V86QU95LG87!P)UTI.PH*("`@
M("`@("`O*B!'970@=&AE(&]P=&EO;G,@9F]R('1H92!R97%U97-T960@8FQO
M8VLN("HO"B`@("`@("`@)&]P=&EO;G,@/2`D=&AI<RT^7V)L;V-K<RT^9V5T
M4&%R86US*"1A<'`L("1B;&]C:RD["@H@("`@("`@("\J($=O('1H<F]U9V@@
M=&AE(&]P=&EO;G,@9F]R('1H:7,@8FQO8VL@86YD('-E="!U<"!A;GD@<F5Q
M=6ER960*("`@("`@("`@*B!E>'1R82!I;G!U="X@*B\*("`@("`@("!F;W)E
M86-H("@D;W!T:6]N<R!A<R`D;W!T:6]N*2!["B`@("`@("`@("`@("1N86UE
M(#T@)'1H:7,M/E]B;&]C:W,M/F=E=%!A<F%M3F%M92@D87!P+"`D8FQO8VLL
M("1O<'1I;VXI.PH@("`@("`@("`@("`D='EP92`]("1T:&ES+3Y?8FQO8VMS
M+3YG971/<'1I;VY4>7!E*"1A<'`L("1B;&]C:RP@)&]P=&EO;BD["B`@("`@
M("`@("`@("1R97%U:7)E9"`]("1T:&ES+3Y?8FQO8VMS+3YG971/<'1I;VY2
M97%U:7)E9"@D87!P+"`D8FQO8VLL("1O<'1I;VXI.PH@("`@("`@("`@("`D
M=F%L=65S(#T@)'1H:7,M/E]B;&]C:W,M/F=E=$]P=&EO;E9A;'5E<R@D87!P
M+"`D8FQO8VLL("1O<'1I;VXI.PH@("`@("`@("`@("`O*B!43T1/.B!T:&4@
M<V5T=&EN9R`G<W1R:6YG)R!S:&]U;&0@8F4@8VAA;F=E9"!I;B!A;&P@8FQO
M8VMS"B`@("`@("`@("`@("`J('1O("=T97AT)R!S;R!T:&%T(&ET(&-O;F9O
M<FUS('=I=&@@2&]R9&5?1F]R;2!S>6YT87@N("HO"B`@("`@("`@("`@(&EF
M("@D='EP92`]/2`G<W1R:6YG)RD@>PH@("`@("`@("`@("`@("`@)'1Y<&4@
M/2`G=&5X="<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'!A<F%M<R`]
M(&%R<F%Y*"D["B`@("`@("`@("`@(&EF("@D='EP92`]/2`G96YU;2<@?'P@
M)'1Y<&4@/3T@)VUL96YU;2<I('L*("`@("`@("`@("`@("`@("1P87)A;7,@
M/2!A<G)A>2@D=F%L=65S+"!T<G5E*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE*"1N86UE+"`D9FEE;&0@
M+B`G6V]P=&EO;G-=6R<@+B`D;W!T:6]N("X@)UTG+"`D='EP92P@)')E<75I
M<F5D+"!F86QS92P@;G5L;"P@)'!A<F%M<RD["B`@("`@("`@?0H@("`@?0H*
M?0H````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]";&]C:RYP:'``````````````````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,3(W,C<`,3`U,34T,S,W-3(`,#(Q,C0P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@
M86)S=')A8W0@2&]R9&5?0FQO8VLZ.B!C;&%S<R!R97!R97-E;G1S(&$@<VEN
M9VQE(&)L;V-K('=I=&AI;@H@*B!T:&4@0FQO8VMS(&9R86UE=V]R:RX*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLN<&AP+'8@,2XS,RXQ
M,"XU(#(P,#8O,#$O,#$@,C$Z,C@Z,#@@:F%N($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`R,#`S+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L
M;"YC;RYN>CX*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*86X@4V-H;F5I9&5R
M(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0&%U
M=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E
M("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T)L;V-K"B`J+PIC;&%S
M<R!(;W)D95]";&]C:R!["@H@("`@+RHJ"B`@("`@*B!";&]C:R!S<&5C:69I
M8R!P87)A;65T97)S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?<&%R86US(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M($%P<&QI8V%T:6]N('1H870@=&AI<R!B;&]C:R!O<FEG:6YA=&5D(&9R;VTN
M"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?
M87!P.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y?&)O;VQE86X@)'!A<F%M<R`@06YY('!A<F%M971E
M<G,@=&AE(&)L;V-K(&YE961S+B!)9B!F86QS92P*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('1H92!D969A=6QT('!A<F%M971E<B!W
M:6QL(&)E('5S960N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7T)L;V-K
M*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@D<&%R86US
M(#T]/2!F86QS92D@>PH@("`@("`@("`@("`D<&%R86US(#T@)'1H:7,M/F=E
M=%!A<F%M<R@I.PH@("`@("`@("`@("!F;W)E86-H("@D<&%R86US(&%S("1N
M86UE(#T^("1P87)A;2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)&YA;65=(#T@)'!A<F%M6R=D969A=6QT)UT["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<R`]
M("1P87)A;7,["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@87!P;&EC871I;VX@=&AA="!T:&ES(&)L;V-K(&)E;&]N9W,@
M=&\N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!A<'!L:6-A
M=&EO;B!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!<'`H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V%P<#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@86YY('-E='1A8FQE('!A<F%M971E<G,@9F]R('1H
M:7,@8FQO8VLN(%1H:7,@:7,@80H@("`@("H@<W1A=&EC(&UE=&AO9"X@270@
M9&]E<R`J;F]T*B!R969E<F5N8V4@)'1H:7,M/E]P87)A;7,[('1H870@:7,*
M("`@("`J(&9O<B!R=6YT:6UE('!A<F%M971E<G,@*'1H92!C:&]I8V5S(&UA
M9&4@9G)O;2!T:&5S92!O<'1I;VYS*2X*("`@("`J"B`@("`@*B!`<W1A=&EC
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&)L;V-K)W,@8V]N
M9FEG=7)A8FQE('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%!A<F%M<R@I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@
M("`@("`@+RH@4W=I=&-H(&%P<&QI8V%T:6]N(&-O;G1E>'1S+"!I9B!N96-E
M<W-A<GDN(%)E='5R;B!A;B!E<G)O<@H@("`@("`@("`J(&EM;65D:6%T96QY
M(&EF('!U<VA!<'`H*2!F86EL<RX@*B\*("`@("`@("`D87!P7W!U<VAE9"`]
M("1R96=I<W1R>2T^<'5S:$%P<"@D=&AI<RT^7V%P<"D["B`@("`@("`@:68@
M*&ES7V$H)&%P<%]P=7-H960L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1A<'!?<'5S:&5D+3YG971-97-S86=E*"D["B`@("`@("`@
M?0H*("`@("`@("`D<&%R86US(#T@)'1H:7,M/E]P87)A;7,H*3L*"B`@("`@
M("`@+RH@268@=V4@8VAA;F=E9"!A<'!L:6-A=&EO;B!C;VYT97AT(&EN('1H
M92!C;W5R<V4@;V8@=&AI<PH@("`@("`@("`J(&-A;&PL('5N9&\@=&AA="!C
M:&%N9V4@;F]W+B`J+PH@("`@("`@(&EF("@D87!P7W!U<VAE9"`]/3T@=')U
M92D@>PH@("`@("`@("`@("`D<F5G:7-T<GDM/G!O<$%P<"@I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!T97AT('1O(&=O(&EN('1H92!T:71L92!O9B!T
M:&ES(&)L;V-K+@H@("`@("H*("`@("`J(%1H:7,@9G5N8W1I;VX@:&%N9&QE
M<R!T:&4@8VAA;F=I;F<@;V8@8W5R<F5N="!A<'!L:6-A=&EO;B!A<PH@("`@
M("H@;F5E9&5D('-O(&-O9&4@:7,@97AE8W5T960@:6X@=&AE('-C;W!E(&]F
M('1H92!A<'!L:6-A=&EO;B!T:&4*("`@("`J(&)L;V-K(&]R:6=I;F%T960@
M9G)O;2X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&)L;V-K
M)W,@=&ET;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1I=&QE*"D*("`@
M('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`O*B!3=VET
M8V@@87!P;&EC871I;VX@8V]N=&5X=',L(&EF(&YE8V5S<V%R>2X@4F5T=7)N
M(&%N(&5R<F]R"B`@("`@("`@("H@:6UM961I871E;'D@:68@<'5S:$%P<"@I
M(&9A:6QS+B`J+PH@("`@("`@("1A<'!?<'5S:&5D(#T@)')E9VES=')Y+3YP
M=7-H07!P*"1T:&ES+3Y?87!P*3L*("`@("`@("!I9B`H:7-?82@D87!P7W!U
M<VAE9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&%P
M<%]P=7-H960M/F=E=$UE<W-A9V4H*3L*("`@("`@("!]"@H@("`@("`@("1T
M:71L92`]("1T:&ES+3Y?=&ET;&4H*3L*"B`@("`@("`@+RH@268@=V4@8VAA
M;F=E9"!A<'!L:6-A=&EO;B!C;VYT97AT(&EN('1H92!C;W5R<V4@;V8@=&AI
M<PH@("`@("`@("`J(&-A;&PL('5N9&\@=&AA="!C:&%N9V4@;F]W+B`J+PH@
M("`@("`@(&EF("@D87!P7W!U<VAE9"`]/3T@=')U92D@>PH@("`@("`@("`@
M("`D<F5G:7-T<GDM/G!O<$%P<"@I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1T:71L93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M(&-O;G1E;G0@9F]R('1H:7,@8FQO8VLN"B`@("`@*@H@("`@("H@5&AI<R!F
M=6YC=&EO;B!H86YD;&5S('1H92!C:&%N9VEN9R!O9B!C=7)R96YT(&%P<&QI
M8V%T:6]N(&%S"B`@("`@*B!N965D960@<V\@8V]D92!I<R!E>&5C=71E9"!I
M;B!T:&4@<V-O<&4@;V8@=&AE(&%P<&QI8V%T:6]N('1H90H@("`@("H@8FQO
M8VL@;W)I9VEN871E9"!F<F]M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@8FQO8VLG<R!C;VYT96YT+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971#;VYT96YT*"D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y
M.PH*("`@("`@("`O*B!3=VET8V@@87!P;&EC871I;VX@8V]N=&5X=',L(&EF
M(&YE8V5S<V%R>2X@4F5T=7)N(&%N(&5R<F]R"B`@("`@("`@("H@:6UM961I
M871E;'D@:68@<'5S:$%P<"@I(&9A:6QS+B`J+PH@("`@("`@("1A<'!?<'5S
M:&5D(#T@)')E9VES=')Y+3YP=7-H07!P*"1T:&ES+3Y?87!P*3L*("`@("`@
M("!I9B`H:7-?82@D87!P7W!U<VAE9"P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&%P<%]P=7-H960M/F=E=$UE<W-A9V4H*3L*("`@
M("`@("!]"@H@("`@("`@("1C;VYT96YT(#T@)'1H:7,M/E]C;VYT96YT*"D[
M"@H@("`@("`@("\J($EF('=E(&-H86YG960@87!P;&EC871I;VX@8V]N=&5X
M="!I;B!T:&4@8V]U<G-E(&]F('1H:7,*("`@("`@("`@*B!C86QL+"!U;F1O
M('1H870@8VAA;F=E(&YO=RX@*B\*("`@("`@("!I9B`H)&%P<%]P=7-H960@
M/3T]('1R=64I('L*("`@("`@("`@("`@)')E9VES=')Y+3YP;W!!<'`H*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D8V]N=&5N=#L*("`@('T*"B`@
M("!F=6YC=&EO;B!B=6EL9%1R964H)B1T<F5E+"`D:6YD96YT(#T@,"P@)'!A
M<F5N="`](&YU;&PI"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*
M"B`@("`@("`@+RH@4W=I=&-H(&%P<&QI8V%T:6]N(&-O;G1E>'1S+"!I9B!N
M96-E<W-A<GDN(%)E='5R;B!A;B!E<G)O<@H@("`@("`@("`J(&EM;65D:6%T
M96QY(&EF('!U<VA!<'`H*2!F86EL<RX@*B\*("`@("`@("`D87!P7W!U<VAE
M9"`]("1R96=I<W1R>2T^<'5S:$%P<"@D=&AI<RT^7V%P<"D["B`@("`@("`@
M:68@*&ES7V$H)&%P<%]P=7-H960L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1A<'!?<'5S:&5D+3YG971-97-S86=E*"D["B`@("`@
M("`@?0H*("`@("`@("`D=&AI<RT^7V)U:6QD5')E92@D=')E92P@)&EN9&5N
M="P@)'!A<F5N="D["@H@("`@("`@("\J($EF('=E(&-H86YG960@87!P;&EC
M871I;VX@8V]N=&5X="!I;B!T:&4@8V]U<G-E(&]F('1H:7,*("`@("`@("`@
M*B!C86QL+"!U;F1O('1H870@8VAA;F=E(&YO=RX@*B\*("`@("`@("!I9B`H
M)&%P<%]P=7-H960@/3T]('1R=64I('L*("`@("`@("`@("`@)')E9VES=')Y
M+3YP;W!!<'`H*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!T:71L92!T;R!G;R!I;B!T:&ES(&)L;V-K+@H@("`@("H*
M("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@8FQO8VL@=&ET;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T:71L
M92@I"B`@("!["B`@("`@("`@<F5T=7)N("<G.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@<&%R86UE=&5R<R!N965D960@8GD@8FQO8VLN
M"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@5&AE(&)L;V-K)W,@<&%R86UE=&5R<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W!A<F%M<R@I"B`@("!["B`@("`@("`@<F5T=7)N(&%R<F%Y
M*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H:7,@8FQO8VLG
M<R!C;VYT96YT+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@8FQO8VLG<R!C;VYT96YT+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?8V]N=&5N="@I"B`@("!["B`@("`@("`@<F5T
M=7)N("<G.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&ES(&)L
M;V-K)W,@8V]N=&5N="X*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&)L;V-K)W,@8V]N=&5N="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V)U:6QD5')E92@F)'1R964L("1I;F1E
M;G0@/2`P+"`D<&%R96YT(#T@;G5L;"D*("`@('L*("`@('T*"GT*````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]"<F]W<V5R+P``````````````
M````````````````````````````````````````````````````````````
M,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W
M-3``,#(Q,3`U`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T)R
M;W=S97(O:6UO9&4N<&AP````````````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`S,3`W,@`Q,#4Q-30S,S<U,``P,C(W,38`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!"<F]W
M<V5R7VEM;V1E.CH@8VQA<W,@97AT96YD<R!T:&4@0G)O=W-E<B!!4$D@8GD@
M<')O=FED:6YG"B`J('-P96-I9FEC(&EN9F]R;6%T:6]N(&%B;W5T($EM;V1E
M(&AA;F1S971S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]"<F]W<V5R+T)R
M;W=S97(O:6UO9&4N<&AP+'8@,2XW+C$R+C4@,C`P-B\P,2\P,2`R,3HR.#HP
M.2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#`M,C`P-B!-:6MA(%1U
M=7!O;&$*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@
M("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?0G)O=W-E<@H@*B\*8VQA
M<W,@0G)O=W-E<E]I;6]D92!["@H@("`@+RHJ"B`@("`@*B!$979I8V4@9&%T
M82X@1G)O;2!H='1P.B\O=W=W+FYT=&1O8V]M;RYC;RYJ<"]I+W1A9R]S-2YH
M=&UL(S5?,0H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1?9&%T82`](&%R<F%Y*`H@("`@("`@("=$,C`Y:2<@/3X@87)R87DH
M"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Y-BP@)VEM86=E:&5I9VAT
M)R`]/B`Y,"P*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@."P@)W1E>'1H
M96EG:'0G(#T^(#<L"B`@("`@("`@("`@("=C;VQO<B<@/3X@,C4V+`H@("`@
M("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@
M("`I+`H@("`@("`@("=&,C`Y:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I
M;6%G97=I9'1H)R`]/B`Y-BP@)VEM86=E:&5I9VAT)R`]/B`Y,2P*("`@("`@
M("`@("`@)W1E>'1W:61T:"<@/3X@."P@)W1E>'1H96EG:'0G(#T^(#<L"B`@
M("`@("`@("`@("=C;VQO<B<@/3X@,C4V+`H@("`@("`@("`@("`G:6UA9V5F
M;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@("=.
M,C`Y:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Q
M,#@L("=I;6%G96AE:6=H="<@/3X@.#(L"B`@("`@("`@("`@("=T97AT=VED
M=&@G(#T^(#DL("=T97AT:&5I9VAT)R`]/B`V+`H@("`@("`@("`@("`G8V]L
M;W(G(#T^("=G<F5Y)RP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@
M87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G4#(P.6DG(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@.38L("=I;6%G96AE
M:6=H="<@/3X@.#<L"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#@L("=T
M97AT:&5I9VAT)R`]/B`V+`H@("`@("`@("`@("`G8V]L;W(G(#T^("=G<F5Y
M)RP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I
M"B`@("`@("`@*2P*("`@("`@("`G4#(P.6ES)R`]/B!A<G)A>2@*("`@("`@
M("`@("`@)VEM86=E=VED=&@G(#T^(#DV+"`G:6UA9V5H96EG:'0G(#T^(#@W
M+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H="<@
M/3X@-BP*("`@("`@("`@("`@)V-O;&]R)R`]/B`R-38L"B`@("`@("`@("`@
M("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@
M("`@("`@)U(R,#EI)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED
M=&@G(#T^(#DV+"`G:6UA9V5H96EG:'0G(#T^(#<R+`H@("`@("`@("`@("`G
M=&5X='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H="<@/3X@-BP*("`@("`@("`@
M("`@)V-O;&]R)R`]/B`G9W)E>2<L"B`@("`@("`@("`@("=I;6%G969O<FUA
M=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@)T52,C`Y
M:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Q,C`L
M("=I;6%G96AE:6=H="<@/3X@-S(L"B`@("`@("`@("`@("=T97AT=VED=&@G
M(#T^(#$P+"`G=&5X=&AE:6=H="<@/3X@-BP*("`@("`@("`@("`@)V-O;&]R
M)R`]/B`G9W)E>2<L"B`@("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R
M<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@)TM/,C`Y:2<@/3X@87)R
M87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Y-BP@)VEM86=E:&5I
M9VAT)R`]/B`Y-BP*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@."P@)W1E
M>'1H96EG:'0G(#T^(#@L"B`@("`@("`@("`@("=C;VQO<B<@/3X@,C4V+`H@
M("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@
M("`@("`I+`H@("`@("`@("=$,C$P:2<@/3X@87)R87DH"B`@("`@("`@("`@
M("=I;6%G97=I9'1H)R`]/B`Y-BP@)VEM86=E:&5I9VAT)R`]/B`Y,2P*("`@
M("`@("`@("`@)W1E>'1W:61T:"<@/3X@."P@)W1E>'1H96EG:'0G(#T^(#<L
M"B`@("`@("`@("`@("=C;VQO<B<@/3X@,C4V+`H@("`@("`@("`@("`G:6UA
M9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@
M("=&,C$P:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]
M/B`Y-BP@)VEM86=E:&5I9VAT)R`]/B`Q,3,L"B`@("`@("`@("`@("=T97AT
M=VED=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]/B`X+`H@("`@("`@("`@("`G
M8V]L;W(G(#T^(#(U-BP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@
M87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G3C(Q,&DG(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@,3$X+"`G:6UA9V5H
M96EG:'0G(#T^(#$Q,RP*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@,3`L
M("=T97AT:&5I9VAT)R`]/B`X+`H@("`@("`@("`@("`G8V]L;W(G(#T^(#(U
M-BP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I
M"B`@("`@("`@*2P*("`@("`@("`G4#(Q,&DG(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`G:6UA9V5W:61T:"<@/3X@.38L("=I;6%G96AE:6=H="<@/3X@.3$L
M"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]
M/B`V+`H@("`@("`@("`@("`G8V]L;W(G(#T^(#(U-BP*("`@("`@("`@("`@
M)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@
M("`@("`G2T\R,3!I)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED
M=&@G(#T^(#DV+"`G:6UA9V5H96EG:'0G(#T^(#DV+`H@("`@("`@("`@("`G
M=&5X='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H="<@/3X@."P*("`@("`@("`@
M("`@)V-O;&]R)R`]/B`R-38L"B`@("`@("`@("`@("=I;6%G969O<FUA=',G
M(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@)U-/,C$P:2<@
M/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Q,C`L("=I
M;6%G96AE:6=H="<@/3X@,3$S+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]
M/B`X+"`G=&5X=&AE:6=H="<@/3X@-RP*("`@("`@("`@("`@)V-O;&]R)R`]
M/B`R-38L"B`@("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G
M:68G*0H@("`@("`@("DL"B`@("`@("`@)T0U,#%I)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@)VEM86=E=VED=&@G(#T^(#DV+"`G:6UA9V5H96EG:'0G(#T^
M(#<R+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H
M="<@/3X@-BP*("`@("`@("`@("`@)V-O;&]R)R`]/B`G8FQA8VLG+`H@("`@
M("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@
M("`I+`H@("`@("`@("=&-3`Q:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I
M;6%G97=I9'1H)R`]/B`Q,3(L("=I;6%G96AE:6=H="<@/3X@.#0L"B`@("`@
M("`@("`@("=T97AT=VED=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]/B`V+`H@
M("`@("`@("`@("`G8V]L;W(G(#T^("=B;&%C:R<L"B`@("`@("`@("`@("=I
M;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@
M("`@)TXU,#%I)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G
M(#T^(#$Q."P@)VEM86=E:&5I9VAT)R`]/B`Q,C@L"B`@("`@("`@("`@("=T
M97AT=VED=&@G(#T^(#$P+"`G=&5X=&AE:6=H="<@/3XQ,"P*("`@("`@("`@
M("`@)V-O;&]R)R`]/B`G8FQA8VLG+`H@("`@("`@("`@("`G:6UA9V5F;W)M
M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@("=0-3`Q
M:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Y-BP@
M)VEM86=E:&5I9VAT)R`]/B`Q,C`L"B`@("`@("`@("`@("=T97AT=VED=&@G
M(#T^(#@L("=T97AT:&5I9VAT)R`]/B`X+`H@("`@("`@("`@("`G8V]L;W(G
M(#T^("=B;&%C:R<L"B`@("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R
M<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@)T0U,#)I)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#DV+"`G:6UA9V5H96EG
M:'0G(#T^(#DP+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`X+"`G=&5X
M=&AE:6=H="<@/3X@-RP*("`@("`@("`@("`@)V-O;&]R)R`]/B`R-38L"B`@
M("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@
M("`@("DL"B`@("`@("`@)T8U,#)I)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M)VEM86=E=VED=&@G(#T^(#DV+"`G:6UA9V5H96EG:'0G(#T^(#DQ+`H@("`@
M("`@("`@("`G=&5X='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H="<@/3X@-RP*
M("`@("`@("`@("`@)V-O;&]R)R`]/B`R-38L"B`@("`@("`@("`@("=I;6%G
M969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@
M)T8U,#)I="<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]
M/B`Y-BP@)VEM86=E:&5I9VAT)R`]/B`Y,2P*("`@("`@("`@("`@)W1E>'1W
M:61T:"<@/3X@."P@)W1E>'1H96EG:'0G(#T^(#<L"B`@("`@("`@("`@("=C
M;VQO<B<@/3X@,C4V+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A
M<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@("=.-3`R:2<@/3X@87)R
M87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Q,3@L("=I;6%G96AE
M:6=H="<@/3X@,3(X+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`Q,"P@
M)W1E>'1H96EG:'0G(#T^(#$P+`H@("`@("`@("`@("`G8V]L;W(G(#T^("=G
M<F5Y)RP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I
M9B<I"B`@("`@("`@*2P*("`@("`@("`G3C4P,FET)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@)VEM86=E=VED=&@G(#T^(#$Q."P@)VEM86=E:&5I9VAT)R`]
M/B`Q,C@L"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#$P+"`G=&5X=&AE
M:6=H="<@/3X@,3`L"B`@("`@("`@("`@("=C;VQO<B<@/3X@,C4V+`H@("`@
M("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@
M("`I+`H@("`@("`@("=0-3`R:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I
M;6%G97=I9'1H)R`]/B`Y-BP@)VEM86=E:&5I9VAT:"<@/3X@,3$W+`H@("`@
M("`@("`@("`G=&5X='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H="<@/3X@."P*
M("`@("`@("`@("`@)V-O;&]R)R`]/B`G9W)E>2<L"B`@("`@("`@("`@("=I
M;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@
M("`@)TY--3`R:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H
M)R`]/B`Q,3$L("=I;6%G96AE:6=H="<@/3X@-S<L"B`@("`@("`@("`@("=T
M97AT=VED=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]/B`V+`H@("`@("`@("`@
M("`G8V]L;W(G(#T^("=B;&%C:R<L"B`@("`@("`@("`@("=I;6%G969O<FUA
M=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@)U-/-3`R
M:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Q,C`L
M("=I;6%G96AE:6=H="<@/3X@,3(P+`H@("`@("`@("`@("`G=&5X='=I9'1H
M)R`]/B`X+"`G=&5X=&AE:6=H="<@/3X@."P*("`@("`@("`@("`@)V-O;&]R
M)R`]/B`G9W)E>2<L"B`@("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R
M<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@)U-/-3`R:7=M)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#$R,"P@)VEM86=E
M:&5I9VAT)R`]/B`Q,3,L"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#@L
M("=T97AT:&5I9VAT)R`]/B`W+`H@("`@("`@("`@("`G8V]L;W(G(#T^(#(U
M-BP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I
M"B`@("`@("`@*2P*("`@("`@("`G1C4P,VDG(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`G:6UA9V5W:61T:"<@/3X@,3(P+"`G:6UA9V5H96EG:'0G(#T^(#$S
M,"P*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@,3`L("=T97AT:&5I9VAT
M)R`]/B`Q,"P*("`@("`@("`@("`@)V-O;&]R)R`]/B`R-38L"B`@("`@("`@
M("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL
M"B`@("`@("`@)T8U,#-I4R<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G
M97=I9'1H)R`]/B`Q,C`L("=I;6%G96AE:6=H="<@/3X@,3,P+`H@("`@("`@
M("`@("`G=&5X='=I9'1H)R`]/B`Q,BP@)W1E>'1H96EG:'0G(#T^(#$R+`H@
M("`@("`@("`@("`G8V]L;W(G(#T^(#0P.38L"B`@("`@("`@("`@("=I;6%G
M969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@
M)U`U,#-I)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^
M(#$R,"P@)VEM86=E:&5I9VAT)R`]/B`Q,S`L"B`@("`@("`@("`@("=T97AT
M=VED=&@G(#T^(#$R+"`G=&5X=&AE:6=H="<@/3X@,3`L"B`@("`@("`@("`@
M("=C;VQO<B<@/3X@,C4V+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]
M/B!A<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@("=0-3`S:5,G(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@,3(P+"`G:6UA
M9V5H96EG:'0G(#T^(#$S,"P*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@
M,3(L("=T97AT:&5I9VAT)R`]/B`Q,"P*("`@("`@("`@("`@)V-O;&]R)R`]
M/B`R-38L"B`@("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G
M:68G*0H@("`@("`@("DL"B`@("`@("`@)U-/-3`S:2<@/3X@87)R87DH"B`@
M("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Q,C`L("=I;6%G96AE:6=H="<@
M/3X@,3$S+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`X+C4L("=T97AT
M:&5I9VAT)R`]/B`W+`H@("`@("`@("`@("`G8V]L;W(G(#T^(#8U-3,V+`H@
M("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@
M("`@("`I+`H@("`@("`@("=$-3`S:2<@/3X@87)R87DH"B`@("`@("`@("`@
M("=I;6%G97=I9'1H)R`]/B`Q,S(L("=I;6%G96AE:6=H="<@/3X@,3(V+`H@
M("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H="<@/3X@
M-RP*("`@("`@("`@("`@)V-O;&]R)R`]/B`T,#DV+`H@("`@("`@("`@("`G
M:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@
M("`@("=.-3`S:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H
M)R`]/B`Q,3@L("=I;6%G96AE:6=H="<@/3X@,3(X+`H@("`@("`@("`@("`G
M=&5X='=I9'1H)R`]/B`Q,"P@)W1E>'1H96EG:'0G(#T^(#$P+`H@("`@("`@
M("`@("`G8V]L;W(G(#T^(#0P.38L"B`@("`@("`@("`@("=I;6%G969O<FUA
M=',G(#T^(&%R<F%Y*"=G:68G+"`G:G!G)RD*("`@("`@("`I+`H@("`@("`@
M("=.-3`S:5,G(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@
M/3X@,3$X+"`G:6UA9V5H96EG:'0G(#T^(#$R."P*("`@("`@("`@("`@)W1E
M>'1W:61T:"<@/3X@,3`L("=T97AT:&5I9VAT)R`]/B`Q,"P*("`@("`@("`@
M("`@)V-O;&]R)R`]/B`T,#DV+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S
M)R`]/B!A<G)A>2@G9VEF)RP@)VIP9R<I"B`@("`@("`@*2P*("`@("`@("`G
M3C8Y,6DG(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@
M.38L("=I;6%G96AE:6=H="<@/3X@-S(L"B`@("`@("`@("`@("=T97AT=VED
M=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]/B`V+`H@("`@("`@("`@("`G8V]L
M;W(G(#T^("=G<F5Y)RP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@
M87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G4T@X,C%I)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#DV+"`G:6UA9V5H
M96EG:'0G(#T^(#<X+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`X+"`G
M=&5X=&AE:6=H="<@/3X@-BP*("`@("`@("`@("`@)V-O;&]R)R`]/B`R-38L
M"B`@("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@
M("`@("`@("DL"B`@("`@("`@)TXX,C%I)R`]/B!A<G)A>2@*("`@("`@("`@
M("`@)VEM86=E=VED=&@G(#T^(#$Q."P@)VEM86=E:&5I9VAT)R`]/B`Q,C@L
M"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#$P+"`G=&5X=&AE:6=H="<@
M/3X@,3`L"B`@("`@("`@("`@("=C;VQO<B<@/3X@)V=R97DG+`H@("`@("`@
M("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@("`I
M+`H@("`@("`@("=0.#(Q:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G
M97=I9'1H)R`]/B`Q,3@L("=I;6%G96AE:6=H="<@/3X@,3(X+`H@("`@("`@
M("`@("`G=&5X='=I9'1H)R`]/B`Q,"P@)W1E>'1H96EG:'0G(#T^(#$P+`H@
M("`@("`@("`@("`G8V]L;W(G(#T^("=G<F5Y)RP*("`@("`@("`@("`@)VEM
M86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@
M("`G<V%F92<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]
M/B`Y-"P@)VEM86=E:&5I9VAT)R`]/B`W,BP*("`@("`@("`@("`@)W1E>'1W
M:61T:"<@/3X@."P@)W1E>'1H96EG:'0G(#T^(#8L"B`@("`@("`@("`@("=C
M;VQO<B<@/3X@)V)L86-K)RP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@
M/3X@87)R87DH)V=I9B<I"B`@("`@("`@*0H@("`@*3L*"B`@("!V87(@)%]M
M86YU9F%C='5R97)L:7-T(#T@87)R87DH"B`@("`@("`@)T0G(#T^("=-:71S
M=6)I<VAI)RP*("`@("`@("`G4"<@/3X@)U!A;F%S;VYI8R`H36%T<W5S:&ET
M82DG+`H@("`@("`@("=.32<@/3X@)TYO:VEA)RP*("`@("`@("`G4T\G(#T^
M("=3;VYY)RP*("`@("`@("`G1B<@/3X@)T9U:FET<W4G+`H@("`@("`@("=.
M)R`]/B`G3F5C)RP*("`@("`@("`G4T@G(#T^("=3:&%R<"<L"B`@("`@("`@
M)T52)R`]/B`G17)I8W-S;VXG+`H@("`@("`@("=2)R`]/B`G2F%P86X@4F%D
M:6\G+`H@("`@("`@("=+3R<@/3X@)TMO:W5S86D@*$AI=&%C:&DI)PH@("`@
M*3L*"B`@("!V87(@)%]E>'1R82`](&%R<F%Y*`H@("`@("`@("=T)R`]/B`G
M5')A;G-P;W)T(&QA>65R)RP*("`@("`@("`G92<@/3X@)T5N9VQI<V@@;&%N
M9W5A9V4G+`H@("`@("`@("=S)R`]/B`G4V5C;VYD('9E<G-I;VXG"B`@("`I
M.PH*("`@('9A<B`D7W5S97)?86=E;G0["B`@("!V87(@)%]M;V1E;#L*("`@
M('9A<B`D7VUA;G5F86-T=7)E<CL*("`@('9A<B`D7VAT='!V97)S:6]N.PH@
M("`@=F%R("1?8V%C:&4@/2`U.PH*("`@("\J*@H@("`@("H@1&]E<R!N;W0@
M:&%N9&QE(&)O9W5S('5S97)?86=E;G1S(&]R(&UO<W0@;V8@=&AE(&]T:&5R
M(&5R<F]R"B`@("`@*B!S:71U871I;VX@<')O<&5R;'D@>65T+@H@("`@("H*
M("`@("`J($5X86UP;&4@=7-A9V4Z"B`@("`@*B`@("1U82`]("9N97<@0G)O
M=W-E<E]I;6]D92@D7U-%4E9%<ELG2%144%]54T527T%'14Y4)UTI.PH@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&EN<'5T("!4:&4@=7-E<B!A9V5N
M="!T;R!M871C:"X*("`@("`J+PH@("`@9G5N8W1I;VX@0G)O=W-E<E]I;6]D
M92@D:6YP=70I"B`@("!["B`@("`@("`@)%]E<G)O<B`](#`["B`@("`@("`@
M)'1E;7`@/2!E>'!L;V1E*"<O)RP@)&EN<'5T*3L*"B`@("`@("`@)'1H:7,M
M/E]U<V5R7V%G96YT(#T@)&EN<'5T.PH@("`@("`@("1T:&ES+3Y?:'1T<'9E
M<G-I;VX@/2`D=&5M<%LQ73L*("`@("`@("`D=&AI<RT^7VUO9&5L(#T@)'1E
M;7!;,ET["B`@("`@("`@:68@*"1T96UP6S-=*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?8V%C:&4@/2!S=6)S='(H)'1E;7!;,UTL(#$I.PH@("`@("`@('T*
M"B`@("`@("`@<')E9U]M871C:"@G+RA>6V$M>D$M6ETK*2A;,"TY72MI*2@N
M*BE<+S\H+BHI+R<L("1T:&ES+3Y?;6]D96PL("1M871C:&5S*3L*"B`@("`@
M("`@+R\@0%1/1$\Z($9I>"!S:71U871I;VX@;V8@=6YK;F]W;B!M86YU9F%C
M='5R97(N($EM<&QE;65N=`H@("`@("`@("\O(&5X=')A:6YF;R!P<F]P97)L
M>2X*("`@("`@("`D=&AI<RT^7VUA;G5F86-T=7)E<B`]("1T:&ES+3Y?;6%N
M=69A8W1U<F5R;&ES=%LD;6%T8VAE<ULQ75T["B`@("`@("`@)'1H:7,M/E]E
M>'1R82`]("1M871C:&5S6S-=.PH*("`@("`@("!I9B`H(2@D=&AI<RT^7V1A
M=&%;)'1H:7,M/E]M;V1E;%TI*2!["B`@("`@("`@("`@("1?97)R;W(@/2!0
M14%2.CIR86ES945R<F]R*"=5;FMN;W=N(%5S97(@06=E;G0G*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>&%M<&QE('5S86=E.@H@("`@
M("H@("1I;6%G961I;2`@("`]("1U82T^9V5T26UA9V5$:6UE;G-I;VYS*"D[
M"B`@("`@*B`@)&EM86=E=VED=&@@(#T@)&EM86=E9&EM6S!=.PH@("`@("H@
M("1I;6%G96AE:6=H="`]("1I;6%G961I;5LQ73L*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!4:&4@;6%X:6UU;2!I;6%G97=I9'1H(&%N9"!I;6%G
M96AE:6=H="!T:&%T"B`@("`@*B`@("`@("`@("`@("`@("!F:70@;VX@=&AE
M(&AA;F1S970@<V-R965N('=I=&AO=70@<V-R;VQL:6YG+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971);6%G941I;65N<VEO;G,H*0H@("`@>PH@("`@("`@
M("1D871A(#T@)'1H:7,M/E]D871A6R1T:&ES+3Y?;6]D96Q=.PH@("`@("`@
M(')E='5R;B!A<G)A>2@D9&%T85LG:6UA9V5W:61T:"==+"`D9&%T85LG:6UA
M9V5H96EG:'0G72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>&%M<&QE('5S
M86=E.@H@("`@("H@("1T97AT9&EM("`@(#T@)'5A+3YG971497AT1&EM96YS
M:6]N<R@I.PH@("`@("H@("1T97AT=VED=&@@(#T@)'1E>'1D:6U;,%T["B`@
M("`@*B`@)'1E>'1H96EG:'0@/2`D=&5X=&1I;5LQ73L*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!4:&4@36%X:6UU;2!T97AT=VED=&@@86YD('1E
M>'1H96EG:'0@=&AA=`H@("`@("H@("`@("`@("`@("`@("`@9FET(&]N('1H
M92!H86YD<V5T('-C<F5E;B!W:71H;W5T('-C<F]L;&EN9RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T5&5X=$1I;65N<VEO;G,H*0H@("`@>PH@("`@("`@
M(')E='5R;B!A<G)A>2@D=&AI<RT^7V1A=&%;)'1H:7,M/E]M;V1E;%U;)W1E
M>'1W:61T:"==+`H@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1A=&%;
M)'1H:7,M/E]M;V1E;%U;)W1E>'1H96EG:'0G72D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!A;6]U;G0@;V8@:&%N9'-E
M="!C86-H92!I;B!K:6QO8GET97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$-A8VAE*"D*("`@('L*("`@("`@("!R971U<FX@*&EN="DD=&AI<RT^7V-A
M8VAE.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$UA;G5F86-T=7)E<B@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;6%N=69A8W1U<F5R.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&=E=$5X=')A*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]E>'1R83L*("`@('T*"B`@("!F=6YC=&EO;B!G971);6%G
M949O<FUA=',H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1A=&%;
M)'1H:7,M/E]M;V1E;%U;)VEM86=E9F]R;6%T<R==.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!7:&EC:"!C;VQO<B!M;V1E;"!T
M:&4@:&%N9'-E="!S=7!P;W)T<RX*("`@("`J("`@5F%L=65S(&AA=F4@=&AE
M(&9O;&QO=VEN9R!M96%N:6YG.@H@("`@("H@("`@(#`@+3X@8FQA8VL@86YD
M('=H:71E"B`@("`@*B`@("`@,2`M/B`T('1O;F4@9W)E>7-C86QE"B`@("`@
M*B`@("`@,B`M/B`R-38@8V]L;W(*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M0V]L;W(H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1A=&%;)'1H
M:7,M/E]M;V1E;%U;)V-O;&]R)UT["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M2%144%9E<G-I;VXH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VAT
M='!V97)S:6]N.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES0V]L;W(H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1A=&%;)'1H:7,M/E]M;V1E;%U;
M)V-O;&]R)UT@/3T@,C4V.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES1W)E>5-C
M86QE*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]D871A6R1T:&ES
M+3Y?;6]D96Q=6R=C;VQO<B==(#T]("=G<F5Y)SL*("`@('T*"B`@("!F=6YC
M=&EO;B!I<T)L86-K06YD5VAI=&4H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7V1A=&%;)'1H:7,M/E]M;V1E;%U;)V-O;&]R)UT@/3T@)V)L86-K
M)SL*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+T)R;W=S97(N<&AP````````````````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#$Q,#8P-@`Q,#4Q-30S,S<U,@`P,C$V,C0`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"G)E<75I
M<F5?;VYC92`G2&]R9&4O4W1R:6YG+G!H<"<["@HO*BH*("H@5&AE($)R;W=S
M97(Z.B!C;&%S<R!P<F]V:61E<R!C87!A8FEL:71Y(&EN9F]R;6%T:6]N(&9O
M<B!T:&4@8W5R<F5N=`H@*B!W96(@8VQI96YT+@H@*@H@*B!"<F]W<V5R(&ED
M96YT:69I8V%T:6]N(&ES('!E<F9O<FUE9"!B>2!E>&%M:6YI;F<@=&AE($A4
M5%!?55-%4E]!1T5.5`H@*B!E;G9I<F]N;65N="!V87)I86)L92!P<F]V:61E
M9"!B>2!T:&4@=V5B('-E<G9E<BX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M0G)O=W-E<B]"<F]W<V5R+G!H<"QV(#$N,34S+C(N-#<@,C`P-B\P-R\Q-R`P
M.3HU,CHP,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT
M(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!H;W)D92YO
M<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]"
M<F]W<V5R"B`J+PIC;&%S<R!"<F]W<V5R('L*"B`@("`O*BH*("`@("`J($UA
M:F]R('9E<G-I;VX@;G5M8F5R+@H@("`@("H*("`@("`J($!V87(@:6YT96=E
M<@H@("`@("HO"B`@("!V87(@)%]M86IO<E9E<G-I;VX@/2`P.PH*("`@("\J
M*@H@("`@("H@36EN;W(@=F5R<VEO;B!N=6UB97(N"B`@("`@*@H@("`@("H@
M0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7VUI;F]R5F5R<VEO;B`]
M(#`["@H@("`@+RHJ"B`@("`@*B!"<F]W<V5R(&YA;64N"B`@("`@*@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8G)O=W-E<B`]("<G
M.PH*("`@("\J*@H@("`@("H@1G5L;"!U<V5R(&%G96YT('-T<FEN9RX*("`@
M("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]A9V5N
M="`]("<G.PH*("`@("\J*@H@("`@("H@3&]W97(M8V%S92!U<V5R(&%G96YT
M('-T<FEN9RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]L;W=E<D%G96YT(#T@)R<["@H@("`@+RHJ"B`@("`@*B!(5%10
M7T%#0T505"!S=')I;F<*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)%]A8V-E<'0@/2`G)SL*"B`@("`O*BH*("`@("`J(%!L
M871F;W)M('1H92!B<F]W<V5R(&ES(')U;FYI;F<@;VXN"B`@("`@*@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<&QA=&9O<FT@/2`G
M)SL*"B`@("`O*BH*("`@("`J($MN;W=N(')O8F]T<RX*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W)O8F]T<R`](&%R<F%Y
M*`H@("`@("`@("\J(%1H92!M;W-T(&-O;6UO;B!O;F5S+B`J+PH@("`@("`@
M("=';V]G;&5B;W0G+`H@("`@("`@("=M<VYB;W0G+`H@("`@("`@("=3;'5R
M<"<L"B`@("`@("`@)UEA:&]O)RP*("`@("`@("`O*B!4:&4@<F5S="!A;'!H
M86)E=&EC86QL>2X@*B\*("`@("`@("`G87!P:64G+`H@("`@("`@("=!<F%C
M:&YO:61E82<L"B`@("`@("`@)T%R8VAI=&5X=%-P:61E<B<L"B`@("`@("`@
M)T%S:R!*965V97,G+`H@("`@("`@("="+6PM:2UT+7HM0F]T)RP*("`@("`@
M("`G0F%I9'5S<&ED97(G+`H@("`@("`@("="96-O;65";W0G+`H@("`@("`@
M("=C9F5T8V@G+`H@("`@("`@("=#;VYV97)A0W)A=VQE<B<L"B`@("`@("`@
M)T5X=')A8W1O<E!R;R<L"B`@("`@("`@)T9!4U0M5V5B0W)A=VQE<B<L"B`@
M("`@("`@)T9$4T4@<F]B;W0G+`H@("`@("`@("=F:61O)RP*("`@("`@("`G
M9FEN9&QI;FMS)RP*("`@("`@("`G1G)A;F-I<R<L"B`@("`@("`@)V=E8VMO
M8F]T)RP*("`@("`@("`G1VEG86)O="<L"B`@("`@("`@)T=I<F%F86)O="<L
M"B`@("`@("`@)V=R=6(M8VQI96YT)RP*("`@("`@("`G1W5L;&EV97(G+`H@
M("`@("`@("=(5%1R86-K)RP*("`@("`@("`G:6%?87)C:&EV97(G+`H@("`@
M("`@("=I0T-R87=L97(G+`H@("`@("`@("=);F9O4V5E:R<L"B`@("`@("`@
M)VMI;FIA8F]T)RP*("`@("`@("`G2TE4+49I<F5B86QL)RP*("`@("`@("`G
M;&%R8FEN)RP*("`@("`@("`G3$5)02<L"B`@("`@("`@)VQM<W!I9&5R)RP*
M("`@("`@("`G;'=P+71R:79I86PG+`H@("`@("`@("=,>6-O<U]3<&ED97(G
M+`H@("`@("`@("=-961I87!A<G1N97)S+4=O;V=L92<L"B`@("`@("`@)TUU
M<V-A=$9E<G)E="<L"B`@("`@("`@)TYA=F5R0F]T)RP*("`@("`@("`G3VUN
M:45X<&QO<F5R7T)O="<L"B`@("`@("`@)W!O;'EB;W0G+`H@("`@("`@("=0
M;VUP;W,G+`H@("`@("`@("=2=69U<T)O="<L"B`@("`@("`@)U-C;V]T97(G
M+`H@("`@("`@("=3965K8F]T)RP*("`@("`@("`G<W!R;V]S92<L"B`@("`@
M("`@)U1E;VUA)RP*("`@("`@("`G5&AE4W5";W0G+`H@("`@("`@("=4=7)N
M:71I;D)O="<L"B`@("`@("`@)U5L=')A<V5E:R<L"B`@("`@("`@)U9I;VQA
M0F]T)RP*("`@("`@("`G=F]Y86=E<B<L"B`@("`@("`@)W=E8F)A;F1I="<L
M"B`@("`@("`@)W=W=RYA;&UA9&5N+FEB;2YC;VTO8W,O8W)A=VQE<B<L"B`@
M("`@("`@)WEA8WDG+`H@("`@("`@("=:>4)O<F<G+`H@("`@*3L*"B`@("`O
M*BH*("`@("`J($ES('1H:7,@82!M;V)I;&4@8G)O=W-E<C\*("`@("`J"B`@
M("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?;6]B:6QE(#T@
M9F%L<V4["@H@("`@+RHJ"B`@("`@*B!&96%T=7)E<RX*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V9E871U<F5S(#T@87)R
M87DH"B`@("`@("`@)VAT;6PG("`@("`@(#T^('1R=64L"B`@("`@("`@)VAD
M;6PG("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=W;6PG("`@("`@("`]/B!F
M86QS92P*("`@("`@("`G:6UA9V5S)R`@("`@/3X@=')U92P*("`@("`@("`G
M:69R86UE<R<@("`@/3X@9F%L<V4L"B`@("`@("`@)V9R86UE<R<@("`@(#T^
M('1R=64L"B`@("`@("`@)W1A8FQE<R<@("`@(#T^('1R=64L"B`@("`@("`@
M)VIA=F$G("`@("`@(#T^('1R=64L"B`@("`@("`@)VIA=F%S8W)I<'0G(#T^
M('1R=64L"B`@("`@("`@)V1O;2<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@
M("=U=&8G("`@("`@("`]/B!F86QS92P*("`@("`@("`G<G1E)R`@("`@("`@
M/3X@9F%L<V4L"B`@("`@("`@)VAO;65P86=E)R`@(#T^(&9A;'-E+`H@("`@
M("`@("=A8V-E<W-K97DG("`]/B!F86QS92P*("`@("`@("`G;W!T9W)O=7`G
M("`@/3X@9F%L<V4L"B`@("`@("`@)WAM;&AT='!R97$G(#T^(&9A;'-E+`H@
M("`@("`@("=C:71E)R`@("`@("`]/B!F86QS92P*("`@("D["@H@("`@+RHJ
M"B`@("`@*B!1=6ER:W,*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7W%U:7)K<R`](&%R<F%Y*`H@("`@("`@("=A=F]I9%]P
M;W!U<%]W:6YD;W=S)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@)V)R96%K
M7V1I<W!O<VET:6]N7VAE861E<B<@("`]/B!F86QS92P*("`@("`@("`G8G)E
M86M?9&ES<&]S:71I;VY?9FEL96YA;64G(#T^(&9A;'-E+`H@("`@("`@("=B
M<F]K96Y?;75L=&EP87)T7V9O<FTG("`@("`@/3X@9F%L<V4L"B`@("`@("`@
M)V)U9V=Y7V-O;7!R97-S:6]N)R`@("`@("`@("`]/B!F86QS92P*("`@("`@
M("`G8V%C:&5?<V%M95]U<FPG("`@("`@("`@("`@(#T^(&9A;'-E+`H@("`@
M("`@("=C86-H95]S<VQ?9&]W;FQO861S)R`@("`@("`@/3X@9F%L<V4L"B`@
M("`@("`@)V1O=6)L95]L:6YE8G)E86M?=&5X=&%R96$G("`]/B!F86QS92P*
M("`@("`@("`G96UP='E?9FEL95]I;G!U=%]V86QU92<@("`@(#T^(&9A;'-E
M+`H@("`@("`@("=M=7-T7V-A8VAE7V9O<FUS)R`@("`@("`@("`@/3X@9F%L
M<V4L"B`@("`@("`@)VYO7V9I;&5N86UE7W-P86-E<R<@("`@("`@("`]/B!F
M86QS92P*("`@("`@("`G;F]?:&ED9&5N7V]V97)F;&]W7W1A8FQE<R<@(#T^
M(&9A;'-E+`H@("`@("`@("=O=U]G=6E?,2XS)R`@("`@("`@("`@("`@("`@
M/3X@9F%L<V4L"B`@("`@("`@)W!N9U]T<F%N<W!A<F5N8WDG("`@("`@("`@
M("`]/B!F86QS92P*("`@("`@("`G<V-R;VQL8F%R7VEN7W=A>2<@("`@("`@
M("`@(#T^(&9A;'-E+`H@("`@("`@("=S8W)O;&Q?=&1S)R`@("`@("`@("`@
M("`@("`@/3X@9F%L<V4L"B`@("`@("`@)W=I;F1O=V5D7V-O;G1R;VQS)R`@
M("`@("`@("`]/B!F86QS92P*("`@("D["@H@("`@+RHJ"B`@("`@*B!,:7-T
M(&]F('9I97=A8FQE(&EM86=E($U)344@<W5B='EP97,N"B`@("`@*B!4:&ES
M(&QI<W0@;V8@=FEE=V%B;&4@:6UA9V5S('=O<FMS(&9O<B!)12!A;F0@3F5T
M<V-A<&4O36]Z:6QL82X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7VEM86=E<R`](&%R<F%Y*"=J<&5G)RP@)V=I9B<L("=P
M;F<G+"`G<&IP96<G+"`G>"UP;F<G+"`G8FUP)RD["@H@("`@+RHJ"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&$@<F5F97)E;F-E('1O('1H92!G;&]B86P@
M0G)O=W-E<B!O8FIE8W0L(&]N;'D@8W)E871I;F<@:70*("`@("`J(&EF(&ET
M(&1O97-N)W0@86QR96%D>2!E>&ES="X*("`@("`J"B`@("`@*B!4:&ES(&UE
M=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z/'!R93X*("`@("`J("`@)&)R;W=S
M97(@/2`F0G)O=W-E<CHZ<VEN9VQE=&]N*%LD=7-E<D%G96YT6RP@)&%C8V5P
M=%U=*3L\+W!R93X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R
M06=E;G0@(%1H92!B<F]W<V5R('-T<FEN9R!T;R!P87)S92X*("`@("`J($!P
M87)A;2!S=')I;F<@)&%C8V5P="`@("`@5&AE($A45%!?04-#15!4('-E='1I
M;F=S('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N($)R;W=S97(@(%1H
M92!"<F]W<V5R(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L
M971O;B@D=7-E<D%G96YT(#T@;G5L;"P@)&%C8V5P="`](&YU;&PI"B`@("![
M"B`@("`@("`@<W1A=&EC("1I;G-T86YC97,["@H@("`@("`@(&EF("@A:7-S
M970H)&EN<W1A;F-E<RDI('L*("`@("`@("`@("`@)&EN<W1A;F-E<R`](&%R
M<F%Y*"D["B`@("`@("`@?0H*("`@("`@("`D<VEG;F%T=7)E(#T@<V5R:6%L
M:7IE*&%R<F%Y*"1U<V5R06=E;G0L("1A8V-E<'0I*3L*("`@("`@("!I9B`H
M96UP='DH)&EN<W1A;F-E<ULD<VEG;F%T=7)E72DI('L*("`@("`@("`@("`@
M)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`](&YE=R!"<F]W<V5R*"1U<V5R06=E
M;G0L("1A8V-E<'0I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T
M86YC97-;)'-I9VYA='5R95T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A
M=&4@82!B<F]W<V5R(&EN<W1A;F-E("A#;VYS=')U8W1O<BDN"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<D%G96YT("!4:&4@8G)O=W-E<B!S
M=')I;F<@=&\@<&%R<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1A8V-E<'0@
M("`@(%1H92!(5%107T%#0T505"!S971T:6YG<R!T;R!U<V4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N($)R;W=S97(H)'5S97)!9V5N="`](&YU;&PL("1A8V-E
M<'0@/2!N=6QL*0H@("`@>PH@("`@("`@("1T:&ES+3YM871C:"@D=7-E<D%G
M96YT+"`D86-C97!T*3L*("`@('T*"B`@("`O*BH*("`@("`J(%!A<G-E<R!T
M:&4@=7-E<B!A9V5N="!S=')I;F<@86YD(&EN:71I=&EA;&EZ97,@=&AE(&]B
M:F5C="!W:71H"B`@("`@*B!A;&P@=&AE(&MN;W=N(&9E871U<F5S(&%N9"!Q
M=6ER:W,@9F]R('1H92!G:79E;B!B<F]W<V5R+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'5S97)!9V5N="`@5&AE(&)R;W=S97(@<W1R:6YG('1O
M('!A<G-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D86-C97!T("`@("!4:&4@
M2%144%]!0T-%4%0@<V5T=&EN9W,@=&\@=7-E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!M871C:"@D=7-E<D%G96YT(#T@;G5L;"P@)&%C8V5P="`](&YU;&PI
M"B`@("!["B`@("`@("`@+R\@4V5T(&]U<B!A9V5N="!S=')I;F<N"B`@("`@
M("`@:68@*&ES7VYU;&PH)'5S97)!9V5N="DI('L*("`@("`@("`@("`@:68@
M*&ES<V5T*"1?4T525D526R=(5%107U5315)?04=%3E0G72DI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?86=E;G0@/2!T<FEM*"1?4T525D526R=(5%10
M7U5315)?04=%3E0G72D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=&AI<RT^7V%G96YT(#T@)'5S97)!9V5N=#L*("`@
M("`@("!]"B`@("`@("`@)'1H:7,M/E]L;W=E<D%G96YT(#T@4W1R:6YG.CIL
M;W=E<B@D=&AI<RT^7V%G96YT*3L*"B`@("`@("`@+R\@4V5T(&]U<B!A8V-E
M<'0@<W1R:6YG+@H@("`@("`@(&EF("AI<U]N=6QL*"1A8V-E<'0I*2!["B`@
M("`@("`@("`@(&EF("AI<W-E="@D7U-%4E9%4ELG2%144%]!0T-%4%0G72DI
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?86-C97!T(#T@4W1R:6YG.CIL
M;W=E<BAT<FEM*"1?4T525D526R=(5%107T%#0T505"==*2D["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V%C
M8V5P="`](%-T<FEN9SHZ;&]W97(H)&%C8V5P="D["B`@("`@("`@?0H*("`@
M("`@("`O+R!#:&5C:R!F;W(@551&('-U<'!O<G0N"B`@("`@("`@:68@*&ES
M<V5T*"1?4T525D526R=(5%107T%#0T505%]#2$%24T54)UTI*2!["B`@("`@
M("`@("`@("1T:&ES+3YS971&96%T=7)E*"=U=&8G+"!S=')P;W,H4W1R:6YG
M.CIL;W=E<B@D7U-%4E9%4ELG2%144%]!0T-%4%1?0TA!4E-%5"==*2P@)W5T
M9B<I("$]/2!F86QS92D["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y
M*"1T:&ES+3Y?86=E;G0I*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5T4&QA
M=&9O<FTH*3L*"B`@("`@("`@("`@(&EF("AS=')P;W,H)'1H:7,M/E]L;W=E
M<D%G96YT+"`G;6]B:6QE97AP;&]R97(G*2`A/3T@9F%L<V4@?'P*("`@("`@
M("`@("`@("`@('-T<G!O<R@D=&AI<RT^7VQO=V5R06=E;G0L("=O<&5N=V%V
M92<I("$]/2!F86QS92!\?`H@("`@("`@("`@("`@("`@<W1R<&]S*"1T:&ES
M+3Y?;&]W97)!9V5N="P@)V]P97)A(&UI;FDG*2`A/3T@9F%L<V4@?'P*("`@
M("`@("`@("`@("`@('-T<G!O<R@D=&AI<RT^7VQO=V5R06=E;G0L("=O<&5R
M86UI;FDG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS
M971&96%T=7)E*"=F<F%M97,G+"!F86QS92D["B`@("`@("`@("`@("`@("`D
M=&AI<RT^<V5T1F5A='5R92@G:F%V87-C<FEP="<L(&9A;'-E*3L*("`@("`@
M("`@("`@("`@("1T:&ES+3YS9711=6ER:R@G879O:61?<&]P=7!?=VEN9&]W
M<R<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]M;V)I;&4@/2!T<G5E.PH@
M("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G?$]P97)A6R\@72A;
M,"TY+ETK*7PG+"`D=&AI<RT^7V%G96YT+"`D=F5R<VEO;BDI('L*("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=O<&5R82<I.PH@
M("`@("`@("`@("`@("`@("`@("`@;&ES="@D=&AI<RT^7VUA:F]R5F5R<VEO
M;BP@)'1H:7,M/E]M:6YO<E9E<G-I;VXI(#T@97AP;&]D92@G+B<L("1V97)S
M:6]N6S%=*3L*("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T
M=7)E*"=J879A<V-R:7!T)RP@=')U92D["B`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5T475I<FLH)VYO7V9I;&5N86UE7W-P86-E<R<I.PH*("`@
M("`@("`@("`@("`@(&EF("@D=&AI<RT^7VUA:F]R5F5R<VEO;B`^/2`W*2![
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)V1O;2<I
M.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=I9G)A
M;65S)RD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H
M)V%C8V5S<VME>2<I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&
M96%T=7)E*"=O<'1G<F]U<"<I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YS9711=6ER:R@G9&]U8FQE7VQI;F5B<F5A:U]T97AT87)E82<I.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V5I9B`H<W1R<&]S*"1T
M:&ES+3Y?;&]W97)!9V5N="P@)V5L86EN92\G*2`A/3T@9F%L<V4@?'P*("`@
M("`@("`@("`@("`@("`@("`@('-T<G!O<R@D=&AI<RT^7VQO=V5R06=E;G0L
M("=P86QM<V]U<F-E)RD@(3T](&9A;'-E('Q\"B`@("`@("`@("`@("`@("`@
M("`@("!S=')P;W,H)'1H:7,M/E]L;W=E<D%G96YT+"`G9&EG:71A;"!P871H
M<R<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$)R
M;W=S97(H)W!A;&TG*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T
M=7)E*"=I;6%G97,G+"!F86QS92D["B`@("`@("`@("`@("`@("`D=&AI<RT^
M<V5T1F5A='5R92@G9G)A;65S)RP@9F%L<V4I.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/G-E=$9E871U<F4H)VIA=F%S8W)I<'0G+"!F86QS92D["B`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)V%V;VED7W!O<'5P7W=I;F1O
M=W,G*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;6]B:6QE(#T@=')U93L*
M("`@("`@("`@("`@?2!E;'-E:68@*"AP<F5G7VUA=&-H*"=\35-)12`H6S`M
M.2Y=*RE\)RP@)'1H:7,M/E]A9V5N="P@)'9E<G-I;VXI*2!\?`H@("`@("`@
M("`@("`@("`@("`@("`@*'!R96=?;6%T8V@H)WQ);G1E<FYE="!%>'!L;W)E
M<B\H6S`M.2Y=*RE\)RP@)'1H:7,M/E]A9V5N="P@)'9E<G-I;VXI*2D@>PH*
M("`@("`@("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=M<VEE)RD["B`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)V-A8VAE7W-S;%]D;W=N
M;&]A9',G*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS9711=6ER:R@G8V%C
M:&5?<V%M95]U<FPG*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS9711=6ER
M:R@G8G)E86M?9&ES<&]S:71I;VY?9FEL96YA;64G*3L*"B`@("`@("`@("`@
M("`@("!I9B`H<W1R<&]S*"1V97)S:6]N6S%=+"`G+B<I("$]/2!F86QS92D@
M>PH@("`@("`@("`@("`@("`@("`@(&QI<W0H)'1H:7,M/E]M86IO<E9E<G-I
M;VXL("1T:&ES+3Y?;6EN;W)697)S:6]N*2`](&5X<&QO9&4H)RXG+"`D=F5R
M<VEO;ELQ72D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?;6%J;W)697)S:6]N(#T@)'9E<G-I;VY;,5T[
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]M:6YO<E9E<G-I;VX@/2`P
M.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\J($E%("@\
M(#<I(&]N(%=I;F1O=W,@9&]E<R!N;W0@<W5P<&]R="!A;'!H82!T<F%N<W!A
M<F5N8WD@:6X*("`@("`@("`@("`@("`@("`J(%!.1R!I;6%G97,N("HO"B`@
M("`@("`@("`@("`@("!I9B`H*"1T:&ES+3Y?;6%J;W)697)S:6]N(#P@-RD@
M)B8*("`@("`@("`@("`@("`@("`@("!P<F5G7VUA=&-H*"<O=VEN9&]W<R]I
M)RP@)'1H:7,M/E]A9V5N="DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T475I<FLH)W!N9U]T<F%N<W!A<F5N8WDG*3L*("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("`O*B!)12`V("AP<F4M4U`Q*2!A;F0@
M-2XU("AP<F4M4U`Q*2!H879E(&)U9V=Y(&-O;7!R97-S:6]N+@H@("`@("`@
M("`@("`@("`@("H@5&AE('9E<G-I;VYS(&%F9F5C=&5D(&%R92!A<R!F;VQL
M;W=S.@H@("`@("`@("`@("`@("`@("H@-BXP,"XR-#8R+C`P,#`@($EN=&5R
M;F5T($5X<&QO<F5R(#8@4'5B;&EC(%!R979I97<@*$)E=&$I"B`@("`@("`@
M("`@("`@("`@*B`V+C`P+C(T-SDN,#`P-B`@26YT97)N970@17AP;&]R97(@
M-B!0=6)L:6,@4')E=FEE=R`H0F5T82D*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@4F5F<F5S:`H@("`@("`@("`@("`@("`@("H@-BXP
M,"XR-C`P+C`P,#`@($EN=&5R;F5T($5X<&QO<F5R(#8@*%=I;F1O=W,@6%`I
M"B`@("`@("`@("`@("`@("`@*B`U+C4P+C,X,C4N,3,P,"`@26YT97)N970@
M17AP;&]R97(@-2XU($1E=F5L;W!E<B!0<F5V:65W("A"971A*0H@("`@("`@
M("`@("`@("`@("H@-2XU,"XT,#,P+C(T,#`@($EN=&5R;F5T($5X<&QO<F5R
M(#4N-2`F($EN=&5R;F5T(%1O;VQS($)E=&$*("`@("`@("`@("`@("`@("`J
M(#4N-3`N-#$S-"XP,3`P("!);G1E<FYE="!%>'!L;W)E<B`U+C4@9F]R(%=I
M;F1O=W,@364@*#0N.3`N,S`P,"D*("`@("`@("`@("`@("`@("`J(#4N-3`N
M-#$S-"XP-C`P("!);G1E<FYE="!%>'!L;W)E<B`U+C4*("`@("`@("`@("`@
M("`@("`J(#4N-3`N-#,P."XR.3`P("!);G1E<FYE="!%>'!L;W)E<B`U+C4@
M061V86YC960@4V5C=7)I='D@4')I=F%C>2!"971A"B`@("`@("`@("`@("`@
M("`@*@H@("`@("`@("`@("`@("`@("H@4V5E.@H@("`@("`@("`@("`@("`@
M("H@/3T]/0H@("`@("`@("`@("`@("`@("H@:'1T<#HO+W-U<'!O<G0N;6EC
M<F]S;V9T+F-O;2]K8B\Q-C0U,SD["B`@("`@("`@("`@("`@("`@*B!H='1P
M.B\O<W5P<&]R="YM:6-R;W-O9G0N8V]M+V1E9F%U;'0N87-P>#]S8VED/6MB
M.V5N+75S.U$S,3(T.38I"B`@("`@("`@("`@("`@("`@*B!H='1P.B\O<W5P
M<&]R="YM:6-R;W-O9G0N8V]M+V1E9F%U;'0N87-P>#]S8VED/6MB.V5N+75S
M.U$S,3,W,3(*("`@("`@("`@("`@("`@("`J+PH@("`@("`@("`@("`@("`@
M)&EE7W9E<G,@/2`D=&AI<RT^9V5T245697)S:6]N*"D["B`@("`@("`@("`@
M("`@("`D8G5G9WE?;&ES="`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@
M("<V+#`P+#(T-C(L,#`P,"<L("<V+#`P+#(T-SDL,#`P-B<L("<V+#`P+#(V
M,#`L,#`P,"<L"B`@("`@("`@("`@("`@("`@("`@)S4L-3`L,S@R-2PQ,S`P
M)RP@)S4L-3`L-#`S,"PR-#`P)RP@)S4L-3`L-#$S-"PP,3`P)RP*("`@("`@
M("`@("`@("`@("`@("`G-2PU,"PT,3,T+#`V,#`G+"`G-2PU,"PT,S`X+#(Y
M,#`G"B`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@("`@("`@:68@*"%I
M<U]N=6QL*"1I95]V97)S*2`F)B!I;E]A<G)A>2@D:65?=F5R<RP@)&)U9V=Y
M7VQI<W0I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%%U:7)K
M*"=B=6=G>5]C;VUP<F5S<VEO;B<I.PH@("`@("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@("`@("\J(%-O;64@2&%N9&AE;&1S(&AA=F4@=&AE:7(@<V-R
M965N(')E<V]L=71I;VX@:6X@=&AE"B`@("`@("`@("`@("`@("`@*B!U<V5R
M(&%G96YT('-T<FEN9RP@=VAI8V@@=V4@8V%N('5S92!T;R!L;V]K(&9O<@H@
M("`@("`@("`@("`@("`@("H@;6]B:6QE(&%G96YT<RX@*B\*("`@("`@("`@
M("`@("`@(&EF("AP<F5G7VUA=&-H*"<O.R`H,3(P>#$V,'PR-#!X,C@P?#(T
M,'@S,C!\,S(P>#,R,"E<*2\G+"`D=&AI<RT^7V%G96YT*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;6]B:6QE(#T@=')U93L*("`@("`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("`@("!S=VET8V@@*"1T:&ES+3Y?;6%J
M;W)697)S:6]N*2!["B`@("`@("`@("`@("`@("!C87-E(#<Z"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VIA=F%S8W)I<'0G+"`Q
M+C0I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=D
M;VTG*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G
M:69R86UE<R<I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T
M=7)E*"=U=&8G*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A
M='5R92@G<G1E)RD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E
M871U<F4H)VAO;65P86=E)RD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G-E=$9E871U<F4H)V%C8V5S<VME>2<I.PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YS971&96%T=7)E*"=O<'1G<F]U<"<I.PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YS971&96%T=7)E*"=X;6QH='1P<F5Q)RD["B`@("`@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`V
M.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=J879A
M<V-R:7!T)RP@,2XT*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T
M1F5A='5R92@G9&]M)RD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E
M=$9E871U<F4H)VEF<F%M97,G*3L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T1F5A='5R92@G=71F)RD["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G-E=$9E871U<F4H)W)T92<I.PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YS971&96%T=7)E*"=H;VUE<&%G92<I.PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YS971&96%T=7)E*"=A8V-E<W-K97DG*3L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G;W!T9W)O=7`G*3L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G>&UL:'1T<')E
M<2<I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS9711=6ER:R@G<V-R
M;VQL8F%R7VEN7W=A>2<I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS
M9711=6ER:R@G8G)O:V5N7VUU;'1I<&%R=%]F;W)M)RD["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E=%%U:7)K*"=W:6YD;W=E9%]C;VYT<F]L<R<I
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@
M(&-A<V4@-3H*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F=E=%!L
M871F;W)M*"D@/3T@)VUA8R<I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/G-E=$9E871U<F4H)VIA=F%S8W)I<'0G+"`Q+C(I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G;W!T9W)O=7`G
M*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!-4TE%(#4@9F]R(%=I;F1O=W,N"B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=J879A<V-R:7!T)RP@
M,2XT*3L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U
M<F4H)V1O;2<I.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T
M1F5A='5R92@G>&UL:'1T<')E<2<I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H)'1H:7,M/E]M:6YO<E9E<G-I;VX@/CT@-2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)W)T92<I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%%U:7)K*"=W
M:6YD;W=E9%]C;VYT<F]L<R<I.PH@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YS971&96%T=7)E*"=I9G)A;65S)RD["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G-E=$9E871U<F4H)W5T9B<I.PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YS971&96%T=7)E*"=H;VUE<&%G92<I.PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=A8V-E<W-K97DG*3L*("`@
M("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]M:6YO<E9E<G-I;VX@/3T@
M-2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH
M)V)R96%K7V1I<W!O<VET:6]N7VAE861E<B<I.PH@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^<V5T475I<FLH)V)R;VME;E]M=6QT:7!A<G1?9F]R
M;2<I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E(#0Z"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VIA=F%S8W)I<'0G+"`Q+C(I
M.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=A8V-E
M<W-K97DG*3L*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]M:6YO
M<E9E<G-I;VX@/B`P*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YS971&96%T=7)E*"=U=&8G*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S
M92`S.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=J
M879A<V-R:7!T)RP@,2XQ*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M<V5T475I<FLH)V%V;VED7W!O<'5P7W=I;F1O=W,G*3L*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?2!E;'-E:68@*'!R96=?;6%T8V@H)WQ!3E1&<F5S8V\O*%LP+3E=*RE\)RP@
M)'1H:7,M/E]A9V5N="P@)'9E<G-I;VXI*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^<V5T0G)O=W-E<B@G9G)E<V-O)RD["B`@("`@("`@("`@("`@("`D
M=&AI<RT^<V5T1F5A='5R92@G:F%V87-C<FEP="<L(#$N,2D["B`@("`@("`@
M("`@("`@("`D=&AI<RT^<V5T475I<FLH)V%V;VED7W!O<'5P7W=I;F1O=W,G
M*3L*("`@("`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D=&AI<RT^7VQO=V5R
M06=E;G0L("=A=F%N=&=O)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5T0G)O=W-E<B@G879A;G1G;R<I.PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]M;V)I;&4@/2!T<G5E.PH@("`@("`@("`@("!](&5L<V5I
M9B`H<')E9U]M871C:"@G?$MO;G%U97)O<B\H6S`M.5TK*7PG+"`D=&AI<RT^
M7V%G96YT+"`D=F5R<VEO;BD@?'P*("`@("`@("`@("`@("`@("`@("`@('!R
M96=?;6%T8V@H)WQ3869A<FDO*%LP+3E=*RE<+C\H6S`M.5TK*3]\)RP@)'1H
M:7,M/E]A9V5N="P@)'9E<G-I;VXI*2!["B`@("`@("`@("`@("`@("`O+R!+
M;VYQ=65R;W(@86YD($%P<&QE)W,@4V%F87)I(&)O=&@@=7-E('1H92!+2%1-
M3`H@("`@("`@("`@("`@("`@+R\@<F5N9&5R:6YG(&5N9VEN92X*("`@("`@
M("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=K;VYQ=65R;W(G*3L*("`@
M("`@("`@("`@("`@("1T:&ES+3YS9711=6ER:R@G96UP='E?9FEL95]I;G!U
M=%]V86QU92<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%%U:7)K*"=N
M;U]H:61D96Y?;W9E<F9L;W=?=&%B;&5S)RD["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7VUA:F]R5F5R<VEO;B`]("1V97)S:6]N6S%=.PH@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1V97)S:6]N6S)=*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;6EN;W)697)S:6]N(#T@)'9E<G-I;VY;,ET["B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D
M=&AI<RT^7V%G96YT+"`G4V%F87)I)RD@(3T](&9A;'-E("8F"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]M86IO<E9E<G-I;VX@/CT@-C`I('L*("`@
M("`@("`@("`@("`@("`@("`O+R!3869A<FDN"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G-E=$9E871U<F4H)W5T9B<I.PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YS971&96%T=7)E*"=J879A<V-R:7!T)RP@,2XT*3L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G9&]M)RD["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VEF<F%M97,G
M*3L*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]M86IO<E9E<G-I
M;VX@/B`Q,C4@?'P*("`@("`@("`@("`@("`@("`@("`@("`@*"1T:&ES+3Y?
M;6%J;W)697)S:6]N(#T](#$R-2`F)@H@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]M:6YO<E9E<G-I;VX@/CT@,2DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)V%C8V5S<VME>2<I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G>&UL
M:'1T<')E<2<I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@+R\@2V]N<75E<F]R
M+@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=J879A
M<V-R:7!T)RP@,2XQ*3L*("`@("`@("`@("`@("`@("`@("!S=VET8V@@*"1T
M:&ES+3Y?;6%J;W)697)S:6]N*2!["B`@("`@("`@("`@("`@("`@("`@8V%S
M92`S.@H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R
M92@G9&]M)RD["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&
M96%T=7)E*"=I9G)A;65S)RD["B`@("`@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)WQ-;WII;&QA+RA;
M,"TY+ETK*7PG+"`D=&AI<RT^7V%G96YT+"`D=F5R<VEO;BDI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=M;WII;&QA)RD["B`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)VUU<W1?8V%C:&5?9F]R;7,G
M*3L*"B`@("`@("`@("`@("`@("!L:7-T*"1T:&ES+3Y?;6%J;W)697)S:6]N
M+"`D=&AI<RT^7VUI;F]R5F5R<VEO;BD@/2!E>'!L;V1E*"<N)RP@)'9E<G-I
M;VY;,5TI.PH@("`@("`@("`@("`@("`@<W=I=&-H("@D=&AI<RT^7VUA:F]R
M5F5R<VEO;BD@>PH@("`@("`@("`@("`@("`@8V%S92`U.@H@("`@("`@("`@
M("`@("`@("`@(&EF("@D=&AI<RT^9V5T4&QA=&9O<FTH*2`]/2`G=VEN)RD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)V)R
M96%K7V1I<W!O<VET:6]N7V9I;&5N86UE)RD["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=J
M879A<V-R:7!T)RP@,2XT*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M<V5T1F5A='5R92@G9&]M)RD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G-E=$9E871U<F4H)V%C8V5S<VME>2<I.PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YS971&96%T=7)E*"=O<'1G<F]U<"<I.PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YS971&96%T=7)E*"=X;6QH='1P<F5Q)RD["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)V-I=&4G*3L*("`@
M("`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G?')V.B@N*BE<*7PG
M+"`D=&AI<RT^7V%G96YT+"`D<F5V:7-I;VXI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@D<F5V:7-I;VY;,5T@/CT@,2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VEF<F%M97,G
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H)')E=FES:6]N6S%=(#X](#$N,RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)W)T92<I.PH@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@
M(&-A<V4@-#H*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R
M92@G:F%V87-C<FEP="<L(#$N,RD["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G-E=%%U:7)K*"=B=6=G>5]C;VUP<F5S<VEO;B<I.PH@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@,SH*("`@
M("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G-E=$9E871U<F4H)VIA=F%S8W)I<'0G+"`Q*3L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^<V5T475I<FLH)V)U9V=Y7V-O;7!R97-S:6]N)RD[
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"=\3'EN>"\H6S`M
M.5TK*7PG+"`D=&AI<RT^7V%G96YT+"`D=F5R<VEO;BDI('L*("`@("`@("`@
M("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=L>6YX)RD["B`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T1F5A='5R92@G:6UA9V5S)RP@9F%L<V4I.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)V9R86UE<R<L(&9A;'-E
M*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=J879A<V-R
M:7!T)RP@9F%L<V4I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%%U:7)K
M*"=A=F]I9%]P;W!U<%]W:6YD;W=S)RD["B`@("`@("`@("`@('T@96QS96EF
M("AP<F5G7VUA=&-H*"=\3&EN:W,@7"@H6S`M.5TK*7PG+"`D=&AI<RT^7V%G
M96YT+"`D=F5R<VEO;BDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YS971"
M<F]W<V5R*"=L:6YK<R<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E
M871U<F4H)VEM86=E<R<L(&9A;'-E*3L*("`@("`@("`@("`@("`@("1T:&ES
M+3YS971&96%T=7)E*"=F<F%M97,G+"!F86QS92D["B`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5T1F5A='5R92@G:F%V87-C<FEP="<L(&9A;'-E*3L*("`@
M("`@("`@("`@("`@("1T:&ES+3YS9711=6ER:R@G879O:61?<&]P=7!?=VEN
M9&]W<R<I.PH@("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G?$AO
M=$IA=F$O*%LP+3E=*RE\)RP@)'1H:7,M/E]A9V5N="P@)'9E<G-I;VXI*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T0G)O=W-E<B@G:&]T:F%V82<I
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VIA=F%S8W)I
M<'0G+"!F86QS92D["B`@("`@("`@("`@('T@96QS96EF("AS=')P;W,H)'1H
M:7,M/E]A9V5N="P@)U50+R<I("$]/2!F86QS92!\?`H@("`@("`@("`@("`@
M("`@("`@("`@<W1R<&]S*"1T:&ES+3Y?86=E;G0L("=54"Y")RD@(3T](&9A
M;'-E('Q\"B`@("`@("`@("`@("`@("`@("`@("!S=')P;W,H)'1H:7,M/E]A
M9V5N="P@)U50+DPG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1T
M:&ES+3YS971"<F]W<V5R*"=U<"<I.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/G-E=$9E871U<F4H)VAT;6PG+"!F86QS92D["B`@("`@("`@("`@("`@("`D
M=&AI<RT^<V5T1F5A='5R92@G:F%V87-C<FEP="<L(&9A;'-E*3L*("`@("`@
M("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=H9&UL)RD["B`@("`@("`@
M("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G=VUL)RD["@H@("`@("`@("`@
M("`@("`@:68@*'-T<G!O<R@D=&AI<RT^7V%G96YT+"`G1U5))RD@(3T](&9A
M;'-E("8F"B`@("`@("`@("`@("`@("`@("`@<W1R<&]S*"1T:&ES+3Y?86=E
M;G0L("=54"Y,:6YK)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@
M("`@+RH@5&AE(&1E=FEC92!A8V-E<'1S($]P96YW879E($=522!E>'1E;G-I
M;VYS(&9O<@H@("`@("`@("`@("`@("`@("`@("`J(%=-3"`Q+C,N($YO;BU5
M4"Y,:6YK(&=A=&5W87ES('-O;65T:6UE<R!H879E"B`@("`@("`@("`@("`@
M("`@("`@("H@<')O8FQE;7,L('-O(&5X8VQU9&4@=&AE;2X@*B\*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)V]W7V=U:5\Q+C,G*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3Y?;6]B
M:6QE(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D=&AI
M<RT^7V%G96YT+"`G6&EI;F\O)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T0G)O=W-E<B@G>&EI;F\G*3L*("`@("`@("`@("`@
M("`@("1T:&ES+3YS971&96%T=7)E*"=H9&UL)RD["B`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5T1F5A='5R92@G=VUL)RD["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7VUO8FEL92`]('1R=64["B`@("`@("`@("`@('T@96QS96EF("AS
M=')P;W,H)'1H:7,M/E]A9V5N="P@)U!A;&US8V%P92\G*2`A/3T@9F%L<V4I
M('L*("`@("`@("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=P86QM<V-A
M<&4G*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=J879A
M<V-R:7!T)RP@9F%L<V4I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E
M871U<F4H)VAD;6PG*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T
M=7)E*"=W;6PG*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;6]B:6QE(#T@
M=')U93L*("`@("`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D=&AI<RT^7V%G
M96YT+"`G3F]K:6$G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1T
M:&ES+3YS971"<F]W<V5R*"=N;VMI82<I.PH@("`@("`@("`@("`@("`@)'1H
M:7,M/G-E=$9E871U<F4H)VAT;6PG+"!F86QS92D["B`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5T1F5A='5R92@G=VUL)RD["B`@("`@("`@("`@("`@("`D
M=&AI<RT^<V5T1F5A='5R92@G>&AT;6PG*3L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?;6]B:6QE(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E:68@*'-T
M<G!O<R@D=&AI<RT^7V%G96YT+"`G17)I8W-S;VXG*2`A/3T@9F%L<V4I('L*
M("`@("`@("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=E<FEC<W-O;B<I
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VAT;6PG+"!F
M86QS92D["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G=VUL
M)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^7VUO8FEL92`]('1R=64["B`@
M("`@("`@("`@('T@96QS96EF("AS=')P;W,H)'1H:7,M/E]L;W=E<D%G96YT
M+"`G=V%P)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M<V5T0G)O=W-E<B@G=V%P)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T
M1F5A='5R92@G:'1M;"<L(&9A;'-E*3L*("`@("`@("`@("`@("`@("1T:&ES
M+3YS971&96%T=7)E*"=J879A<V-R:7!T)RP@9F%L<V4I.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VAD;6PG*3L*("`@("`@("`@("`@
M("`@("1T:&ES+3YS971&96%T=7)E*"=W;6PG*3L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;6]B:6QE(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E:68@
M*'-T<G!O<R@D=&AI<RT^7VQO=V5R06=E;G0L("=D;V-O;6\G*2`A/3T@9F%L
M<V4@?'P*("`@("`@("`@("`@("`@("`@("`@('-T<G!O<R@D=&AI<RT^7VQO
M=V5R06=E;G0L("=P;W)T86QM;6TG*2`A/3T@9F%L<V4I('L*("`@("`@("`@
M("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=I;6]D92<I.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VEM86=E<R<L(&9A;'-E*3L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;6]B:6QE(#T@=')U93L*("`@("`@("!]
M(&5L<V5I9B`H<W1R<&]S*"1T:&ES+3Y?86=E;G0L("=";&%C:T)E<G)Y)RD@
M(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T0G)O=W-E
M<B@G8FQA8VMB97)R>2<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E
M871U<F4H)VAT;6PG+"!F86QS92D["B`@("`@("`@("`@("`@("`D=&AI<RT^
M<V5T1F5A='5R92@G:F%V87-C<FEP="<L(&9A;'-E*3L*("`@("`@("`@("`@
M("`@("1T:&ES+3YS971&96%T=7)E*"=H9&UL)RD["B`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5T1F5A='5R92@G=VUL)RD["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7VUO8FEL92`]('1R=64["B`@("`@("`@("`@('T@96QS96EF("AS
M=')P;W,H)'1H:7,M/E]A9V5N="P@)TU/5"TG*2`A/3T@9F%L<V4I('L*("`@
M("`@("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=M;W1O<F]L82<I.PH@
M("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VAT;6PG+"!F86QS
M92D["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:F%V87-C
M<FEP="<L(&9A;'-E*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T
M=7)E*"=H9&UL)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R
M92@G=VUL)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^7VUO8FEL92`]('1R
M=64["B`@("`@("`@("`@('T@96QS96EF("AS=')P;W,H)'1H:7,M/E]L;W=E
M<D%G96YT+"`G:BTG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1T
M:&ES+3YS971"<F]W<V5R*"=M;6PG*3L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;6]B:6QE(#T@=')U93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($UA=&-H('1H92!P;&%T9F]R;2!O9B!T:&4@
M8G)O=W-E<BX*("`@("`J"B`@("`@*B!4:&ES(&ES(&$@<')E='1Y('-I;7!L
M:7-T:6,@:6UP;&5M96YT871I;VXL(&)U="!I="=S(&EN=&5N9&5D"B`@("`@
M*B!T;R!L970@=7,@=&5L;"!W:&%T(&QI;F4@8G)E86MS('1O('-E;F0L('-O
M(&ET)W,@9V]O9"!E;F]U9V@*("`@("`J(&9O<B!I=',@<'5R<&]S92X*("`@
M("`J"B`@("`@*B!`<VEN8V4@2&]R9&4@,BXR"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]S9710;&%T9F]R;2@I"B`@("!["B`@("`@("`@:68@*'-T<G!O<R@D
M=&AI<RT^7VQO=V5R06=E;G0L("=W:6YD)RD@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?<&QA=&9O<FT@/2`G=VEN)SL*("`@("`@("!](&5L
M<V5I9B`H<W1R<&]S*"1T:&ES+3Y?;&]W97)!9V5N="P@)VUA8R<I("$]/2!F
M86QS92D@>PH@("`@("`@("`@("`D=&AI<RT^7W!L871F;W)M(#T@)VUA8R<[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]P;&%T9F]R
M;2`]("=U;FEX)SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FX@=&AE(&-U<G)E;G1L>2!M871C:&5D('!L871F;W)M+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=7-E<B=S('!L871F;W)M+@H@
M("`@("H*("`@("`J($!S:6YC92!(;W)D92`R+C(*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4&QA=&9O<FTH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7W!L871F;W)M.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@
M8W5R<F5N="!B<F]W<V5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&)R;W=S97(@(%1H92!B<F]W<V5R('1O('-E="!A<R!C=7)R96YT+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S971"<F]W<V5R*"1B<F]W<V5R*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?8G)O=W-E<B`]("1B<F]W<V5R.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1&5T97)M:6YE(&EF('1H92!G:79E;B!B<F]W<V5R(&ES
M('1H92!S86UE(&%S('1H92!C=7)R96YT+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&)R;W=S97(@(%1H92!B<F]W<V5R('1O(&-H96-K+@H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@27,@=&AE(&=I=F5N(&)R;W=S
M97(@=&AE('-A;64@87,@=&AE(&-U<G)E;G0_"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&ES0G)O=W-E<B@D8G)O=W-E<BD*("`@('L*("`@("`@("!R971U<FX@
M*"1T:&ES+3Y?8G)O=W-E<B`]/3T@)&)R;W=S97(I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1&\@=V4@8V]N<VED97(@=&AE(&-U<G)E;G0@8G)O=W-E<B!T
M;R!B92!A(&UO8FEL92!D979I8V4_"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!4<G5E(&EF('=E(&1O+"!F86QS92!I9B!W92!D;VXG="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@:7--;V)I;&4H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7VUO8FEL93L*("`@('T*"B`@("`O*BH*("`@("`J($1E
M=&5R;6EN97,@:68@=&AE(&)R;W=S97(@:7,@82!R;V)O="!O<B!N;W0N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF(&)R;W=S97(@
M:7,@82!K;F]W;B!R;V)O="X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-2;V)O
M="@I"B`@("!["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]R;V)O=',@87,@
M)')O8F]T*2!["B`@("`@("`@("`@(&EF("AS=')P;W,H)'1H:7,M/E]A9V5N
M="P@)')O8F]T*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E('1H92!C
M=7)R96YT(&)R;W=S97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!C=7)R96YT(&)R;W=S97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$)R;W=S97(H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V)R;W=S
M97(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V92!T:&4@8W5R<F5N
M="!B<F]W<V5R)W,@;6%J;W(@=F5R<VEO;BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN=&5G97(@(%1H92!C=7)R96YT(&)R;W=S97(G<R!M86IO<B!V97)S
M:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971-86IO<B@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?;6%J;W)697)S:6]N.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T<FEE=F4@=&AE(&-U<G)E;G0@8G)O=W-E<B=S(&UI
M;F]R('9E<G-I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4
M:&4@8W5R<F5N="!B<F]W<V5R)W,@;6EN;W(@=F5R<VEO;BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T36EN;W(H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7VUI;F]R5F5R<VEO;CL*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M=')I979E('1H92!C=7)R96YT(&)R;W=S97(G<R!V97)S:6]N+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8W5R<F5N="!B<F]W<V5R)W,@
M=F5R<VEO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5F5R<VEO;B@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;6%J;W)697)S:6]N("X@)RXG
M("X@)'1H:7,M/E]M:6YO<E9E<G-I;VX["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@=&AE(&9U;&P@8G)O=W-E<B!A9V5N="!S=')I;F<N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!B<F]W<V5R(&%G96YT('-T
M<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T06=E;G13=')I;F<H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V%G96YT.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T('5N:7%U92!B96AA=FEO<B!F;W(@=&AE(&-U<G)E
M;G0@8G)O=W-E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1Q=6ER
M:R`@5&AE(&)E:&%V:6]R('1O('-E="X*("`@("`J($!P87)A;2!S=')I;F<@
M)'9A;'5E("!3<&5C:6%L(&)E:&%V:6]R('!A<F%M971E<BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5T475I<FLH)'%U:7)K+"`D=F%L=64@/2!T<G5E*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?<75I<FMS6R1Q=6ER:UT@/2`D=F%L=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:R!U;FEQ=64@8F5H879I;W(@
M9F]R('1H92!C=7)R96YT(&)R;W=S97(N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<75I<FL@(%1H92!B96AA=FEO<B!T;R!C:&5C:RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@($1O97,@=&AE(&)R;W=S97(@:&%V
M92!T:&4@8F5H879I;W(@<V5T/PH@("`@("HO"B`@("!F=6YC=&EO;B!H87-1
M=6ER:R@D<75I<FLI"B`@("!["B`@("`@("`@<F5T=7)N("%E;7!T>2@D=&AI
M<RT^7W%U:7)K<ULD<75I<FM=*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M=')I979E('5N:7%U92!B96AA=FEO<B!F;W(@=&AE(&-U<G)E;G0@8G)O=W-E
M<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1Q=6ER:R`@5&AE(&)E
M:&%V:6]R('1O(')E=')I979E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@=F%L=64@9F]R('1H92!R97%U97-T960@8F5H879I;W(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%%U:7)K*"1Q=6ER:RD*("`@('L*("`@
M("`@("!R971U<FX@:7-S970H)'1H:7,M/E]Q=6ER:W-;)'%U:7)K72D*("`@
M("`@("`@("`@("`@/R`D=&AI<RT^7W%U:7)K<ULD<75I<FM="B`@("`@("`@
M("`@("`@(#H@;G5L;#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!C87!A
M8FEL:71I97,@9F]R('1H92!C=7)R96YT(&)R;W=S97(N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9F5A='5R92`@5&AE(&-A<&%B:6QI='D@=&\@
M<V5T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%L=64@("`@4W!E8VEA;"!C
M87!A8FEL:71Y('!A<F%M971E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M1F5A='5R92@D9F5A='5R92P@)'9A;'5E(#T@=')U92D*("`@('L*("`@("`@
M("`D=&AI<RT^7V9E871U<F5S6R1F96%T=7)E72`]("1V86QU93L*("`@('T*
M"B`@("`O*BH*("`@("`J($-H96-K('1H92!C=7)R96YT(&)R;W=S97(@8V%P
M86)I;&ET:65S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9E871U
M<F4@(%1H92!C87!A8FEL:71Y('1O(&-H96-K+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@1&]E<R!T:&4@8G)O=W-E<B!H879E('1H92!C87!A
M8FEL:71Y('-E=#\*("`@("`J+PH@("`@9G5N8W1I;VX@:&%S1F5A='5R92@D
M9F5A='5R92D*("`@('L*("`@("`@("!R971U<FX@(65M<'1Y*"1T:&ES+3Y?
M9F5A='5R97-;)&9E871U<F5=*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M=')I979E('1H92!C=7)R96YT(&)R;W=S97(@8V%P86)I;&ET>2X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1F96%T=7)E("!4:&4@8V%P86)I;&ET
M>2!T;R!R971R:65V92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE('9A;'5E(&]F('1H92!R97%U97-T960@8V%P86)I;&ET>2X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T1F5A='5R92@D9F5A='5R92D*("`@('L*("`@
M("`@("!R971U<FX@:7-S970H)'1H:7,M/E]F96%T=7)E<ULD9F5A='5R95TI
M"B`@("`@("`@("`@("`@(#\@)'1H:7,M/E]F96%T=7)E<ULD9F5A='5R95T*
M("`@("`@("`@("`@("`@.B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1&5T97)M:6YE(&EF('=E(&%R92!U<VEN9R!A('-E8W5R92`H4U-,*2!C;VYN
M96-T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I
M9B!U<VEN9R!34TPL(&9A;'-E(&EF(&YO="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@=7-I;F=34TQ#;VYN96-T:6]N*"D*("`@('L*("`@("`@("!R971U<FX@
M*"AI<W-E="@D7U-%4E9%4ELG2%144%,G72D@)B8*("`@("`@("`@("`@("`@
M("`H)%]315)615);)TA45%!3)UT@/3T@)V]N)RDI('Q\"B`@("`@("`@("`@
M("`@("!G971E;G8H)U-33%]04D]43T-/3%]615)324].)RDI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<V5R=F5R('!R;W1O8V]L(&EN
M('5S92!O;B!T:&4@8W5R<F5N="!S97)V97(N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!(5%10('-E<G9E<B!P<F]T;V-O;"!V97)S:6]N
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971(5%104')O=&]C;VPH*0H@("`@
M>PH@("`@("`@(&EF("AI<W-E="@D7U-%4E9%4ELG4T525D527U!23U1/0T],
M)UTI*2!["B`@("`@("`@("`@(&EF("@H)'!O<R`]('-T<G)P;W,H)%]315)6
M15);)U-%4E9%4E]04D]43T-/3"==+"`G+R<I*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N('-U8G-T<B@D7U-%4E9%4ELG4T525D527U!23U1/0T],)UTL
M("1P;W,@*R`Q*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F4@
M:68@9FEL97,@8V%N(&)E('5P;&]A9&5D('1O('1H92!S>7-T96TN"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!)9B!U<&QO861S(&%L;&]W960L
M(')E='5R;G,@=&AE(&UA>&EM=6T@<VEZ92!O9B!T:&4*("`@("`J("`@("`@
M("`@("`@("`@("`@=7!L;V%D(&EN(&)Y=&5S+B`@4F5T=7)N<R`P(&EF('5P
M;&]A9',@87)E(&YO=`H@("`@("H@("`@("`@("`@("`@("`@("!A;&QO=V5D
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!A;&QO=T9I;&55<&QO861S*"D*("`@
M('L*("`@("`@("!I9B`H:6YI7V=E="@G9FEL95]U<&QO861S)RDI('L*("`@
M("`@("`@("`@:68@*"@D9&ER(#T@:6YI7V=E="@G=7!L;V%D7W1M<%]D:7(G
M*2D@)B8*("`@("`@("`@("`@("`@("%I<U]W<FET86)L92@D9&ER*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&9I;&5S:7IE(#T@:6YI7V=E="@G=7!L;V%D7VUA>%]F:6QE<VEZ
M92<I.PH@("`@("`@("`@("!S=VET8V@@*'-T<G1O;&]W97(H<W5B<W1R*"1F
M:6QE<VEZ92P@+3$L(#$I*2D@>PH@("`@("`@("`@("!C87-E("=K)SH*("`@
M("`@("`@("`@("`@("1F:6QE<VEZ92`](&EN='9A;"AF;&]A='9A;"@D9FEL
M97-I>F4I("H@,3`R-"D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@(&-A<V4@)VTG.@H@("`@("`@("`@("`@("`@)&9I;&5S:7IE(#T@
M:6YT=F%L*&9L;V%T=F%L*"1F:6QE<VEZ92D@*B`Q,#(T("H@,3`R-"D["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@
M("`@("`@("`@("`@("`D9FEL97-I>F4@/2!I;G1V86PH)&9I;&5S:7IE*3L*
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1P;W-T<VEZ92`](&EN:5]G970H)W!O<W1?;6%X7W-I>F4G*3L*("`@
M("`@("`@("`@<W=I=&-H("AS=')T;VQO=V5R*'-U8G-T<B@D<&]S='-I>F4L
M("TQ+"`Q*2DI('L*("`@("`@("`@("`@8V%S92`G:R<Z"B`@("`@("`@("`@
M("`@("`D<&]S='-I>F4@/2!I;G1V86PH9FQO871V86PH)'!O<W1S:7IE*2`J
M(#$P,C0I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E("=M)SH*("`@("`@("`@("`@("`@("1P;W-T<VEZ92`](&EN='9A;"AF
M;&]A='9A;"@D<&]S='-I>F4I("H@,3`R-"`J(#$P,C0I.PH@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@
M("`@("`@)'!O<W1S:7IE(#T@:6YT=F%L*"1P;W-T<VEZ92D["B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U
M<FX@;6EN*"1F:6QE<VEZ92P@)'!O<W1S:7IE*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@,#L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$971E<FUI;F5S(&EF('1H92!F:6QE('=A<R!U<&QO861E
M9"!O<B!N;W0N("!)9B!N;W0L('=I;&P@<F5T=7)N('1H90H@("`@("H@87!P
M<F]P<FEA=&4@97)R;W(@;65S<V%G92X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1F:65L9"`@5&AE(&YA;64@;V8@=&AE(&9I96QD(&-O;G1A:6YI
M;F<@=&AE('5P;&]A9&5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("!4:&4@9FEL92!D
M97-C<FEP=&EO;B!S=')I;F<@=&\@=7-E(&EN('1H92!E<G)O<@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@(&UE<W-A9V4N("!$969A=6QT.B`G9FEL
M92<N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C
M97-S+"!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!W87-&:6QE57!L;V%D960H)&9I96QD+"`D;F%M92`](&YU;&PI"B`@("![
M"B`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+G!H<"<["@H@("`@("`@(&EF
M("AI<U]N=6QL*"1N86UE*2D@>PH@("`@("`@("`@("`D;F%M92`](%\H(F9I
M;&4B*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A*"1U<&QO8613:7IE(#T@
M0G)O=W-E<CHZ86QL;W=&:6QE57!L;V%D<R@I*2D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")&:6QE('5P;&]A9',@;F]T('-U
M<'!O<G1E9"XB*2D["B`@("`@("`@?0H*("`@("`@("`O*B!'970@86YY(&EN
M9&5X(&]N('1H92!F:65L9"!N86UE+B`J+PH@("`@("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O07)R87DN<&AP)SL*("`@("`@("`D:6YD97@@/2!(;W)D95]!
M<G)A>3HZ9V5T07)R87E087)T<R@D9FEE;&0L("1B87-E+"`D:V5Y<RD["@H@
M("`@("`@(&EF("@D:6YD97@I('L*("`@("`@("`@("`@+RH@26YD97@@<')E
M<V5N="P@9F5T8V@@=&AE(&5R<F]R('9A<B!T;R!C:&5C:RX@*B\*("`@("`@
M("`@("`@)&ME>7-?<&%T:"`](&%R<F%Y7VUE<F=E*&%R<F%Y*"1B87-E+"`G
M97)R;W(G*2P@)&ME>7,I.PH@("`@("`@("`@("`D97)R;W(@/2!(;W)D95]!
M<G)A>3HZ9V5T16QE;65N="@D7T9)3$53+"`D:V5Y<U]P871H*3L*"B`@("`@
M("`@("`@("\J($EN9&5X('!R97-E;G0L(&9E=&-H('1H92!T;7!?;F%M92!V
M87(@=&\@8VAE8VLN("HO"B`@("`@("`@("`@("1K97ES7W!A=&@@/2!A<G)A
M>5]M97)G92AA<G)A>2@D8F%S92P@)W1M<%]N86UE)RDL("1K97ES*3L*("`@
M("`@("`@("`@)'1M<%]N86UE(#T@2&]R9&5?07)R87DZ.F=E=$5L96UE;G0H
M)%]&24Q%4RP@)&ME>7-?<&%T:"D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@+RH@3F\@:6YD97@L('-I;7!L92!S970@=7`@;V8@=F%R<R!T;R!C
M:&5C:RX@*B\*("`@("`@("`@("`@:68@*"%I<W-E="@D7T9)3$536R1F:65L
M9%TI*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BA?*").;R!F:6QE('5P;&]A9&5D(BDL(%503$]!1%]%4E)?3D]?1DE,12D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&5R<F]R(#T@)%]&24Q%4ULD
M9FEE;&1=6R=E<G)O<B==.PH@("`@("`@("`@("`D=&UP7VYA;64@/2`D7T9)
M3$536R1F:65L9%U;)W1M<%]N86UE)UT["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(6ES<V5T*"1?1DE,15,I('Q\("@D97)R;W(@/3T@55!,3T%$7T524E].
M3U]&24Q%*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BAS<')I;G1F*%\H(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB*2P@)&YA;64I+"!54$Q/
M041?15)27TY/7T9)3$4I.PH@("`@("`@('T@96QS96EF("@H)&5R<F]R(#T]
M(%503$]!1%]%4E)?3TLI("8F(&ES7W5P;&]A9&5D7V9I;&4H)'1M<%]N86UE
M*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L<V5I
M9B`H*"1E<G)O<B`]/2!54$Q/041?15)27TE.25]325I%*2!\?`H@("`@("`@
M("`@("`@("`@("`H)&5R<F]R(#T](%503$]!1%]%4E)?1D]235]325I%*2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F
M*%\H(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S
M:7IE("@E9"!B>71E<RDN(BDL("1N86UE+"`D=7!L;V%D4VEZ92DL("1E<G)O
M<BD["B`@("`@("`@?2!E;'-E:68@*"1E<G)O<B`]/2!54$Q/041?15)27U!!
M4E1)04PI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M<W!R:6YT9BA?*")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(I
M+"`D;F%M92DL("1E<G)O<BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@:&5A9&5R<R!F;W(@82!B<F]W<V5R(&1O=VYL
M;V%D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&5N86UE("!4
M:&4@9FEL96YA;64@;V8@=&AE(&1O=VYL;V%D+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8U1Y<&4@("`@(%1H92!C;VYT96YT+71Y<&4@9&5S8W)I<'1I;VX@
M;V8@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D:6YL:6YE("`@
M5')U92!I9B!I;FQI;F4L(&9A;'-E(&EF(&%T=&%C:&UE;G0N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1C3&5N9W1H("`@5&AE(&-O;G1E;G0M;&5N9W1H(&]F
M('1H:7,@9FEL92X*("`@("`J"B`@("`@*B!`<VEN8V4@2&]R9&4@,BXR"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&1O=VYL;V%D2&5A9&5R<R@D9FEL96YA;64@
M/2`G=6YK;F]W;B<L("1C5'EP92`](&YU;&PL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&EN;&EN92`](&9A;'-E+"`D8TQE;F=T:"`](&YU;&PI
M"B`@("!["B`@("`@("`@+RH@4F5M;W9E(&QI;F5B<F5A:W,@9G)O;2!F:6QE
M(&YA;65S+B`J+PH@("`@("`@("1F:6QE;F%M92`]('-T<E]R97!L86-E*&%R
M<F%Y*")<<EQN(BP@(EQR(BP@(EQN(BDL("<@)RP@)&9I;&5N86UE*3L*"B`@
M("`@("`@+RH@4V]M92!B<F]W<V5R<R!D;VXG="!L:6ME('-P86-E<R!I;B!T
M:&4@9FEL96YA;64N("HO"B`@("`@("`@:68@*"1T:&ES+3YH87-1=6ER:R@G
M;F]?9FEL96YA;65?<W!A8V5S)RDI('L*("`@("`@("`@("`@)&9I;&5N86UE
M(#T@<W1R='(H)&9I;&5N86UE+"`G("<L("=?)RD["B`@("`@("`@?0H*("`@
M("`@("`O*B!-4TE%(&1O97-N)W0@;&EK92!M=6QT:7!L92!P97)I;V1S(&EN
M('1H92!F:6QE(&YA;64N($-O;G9E<G0*("`@("`@("`@("!A;&P@<&5R:6]D
M<R`H97AC97!T('1H92!L87-T(&]N92D@=&\@=6YD97)S8V]R97,N("HO"B`@
M("`@("`@:68@*"1T:&ES+3YI<T)R;W=S97(H)VUS:64G*2D@>PH@("`@("`@
M("`@("!I9B`H*"1P;W,@/2!S=')R<&]S*"1F:6QE;F%M92P@)RXG*2DI('L*
M("`@("`@("`@("`@("`@("1F:6QE;F%M92`]('-T<G1R*'-U8G-T<B@D9FEL
M96YA;64L(#`L("1P;W,I+"`G+B<L("=?)RD@+B!S=6)S='(H)&9I;&5N86UE
M+"`D<&]S*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@
M0V]N=&5N="U4>7!E+T-O;G1E;G0M1&ES<&]S:71I;VX@2&5A9&5R+B`J+PH@
M("`@("`@(&EF("@D:6YL:6YE*2!["B`@("`@("`@("`@(&EF("@A:7-?;G5L
M;"@D8U1Y<&4I*2!["B`@("`@("`@("`@("`@("!H96%D97(H)T-O;G1E;G0M
M5'EP93H@)R`N('1R:6TH)&-4>7!E*2D["B`@("`@("`@("`@('T@96QS96EF
M("@D=&AI<RT^:7-"<F]W<V5R*"=M<VEE)RDI('L*("`@("`@("`@("`@("`@
M(&AE861E<B@G0V]N=&5N="U4>7!E.B!A<'!L:6-A=&EO;B]X+6US9&]W;FQO
M860G*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&AE
M861E<B@G0V]N=&5N="U4>7!E.B!A<'!L:6-A=&EO;B]O8W1E="US=')E86TG
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!H96%D97(H)T-O;G1E;G0M
M1&ES<&]S:71I;VXZ(&EN;&EN93L@9FEL96YA;64](B<@+B`D9FEL96YA;64@
M+B`G(B<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@D=&AI
M<RT^:7-"<F]W<V5R*"=M<VEE)RDI('L*("`@("`@("`@("`@("`@(&AE861E
M<B@G0V]N=&5N="U4>7!E.B!A<'!L:6-A=&EO;B]X+6US9&]W;FQO860G*3L*
M("`@("`@("`@("`@?2!E;'-E:68@*"%I<U]N=6QL*"1C5'EP92DI('L*("`@
M("`@("`@("`@("`@(&AE861E<B@G0V]N=&5N="U4>7!E.B`G("X@=')I;2@D
M8U1Y<&4I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M(&AE861E<B@G0V]N=&5N="U4>7!E.B!A<'!L:6-A=&EO;B]O8W1E="US=')E
M86TG*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1T:&ES+3YH
M87-1=6ER:R@G8G)E86M?9&ES<&]S:71I;VY?:&5A9&5R)RDI('L*("`@("`@
M("`@("`@("`@(&AE861E<B@G0V]N=&5N="U$:7-P;W-I=&EO;CH@9FEL96YA
M;64](B<@+B`D9FEL96YA;64@+B`G(B<I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@:&5A9&5R*"=#;VYT96YT+41I<W!O<VET:6]N
M.B!A='1A8VAM96YT.R!F:6QE;F%M93TB)R`N("1F:6QE;F%M92`N("<B)RD[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($-O;G1E;G0M
M3&5N9W1H($AE861E<BX@*B\*("`@("`@("!I9B`H(6ES7VYU;&PH)&-,96YG
M=&@I*2!["B`@("`@("`@("`@(&AE861E<B@G0V]N=&5N="U,96YG=&@Z("<@
M+B`D8TQE;F=T:"D["B`@("`@("`@?0H*("`@("`@("`O*B!/=F5R=W)I=&4@
M4')A9VUA.B!A;F0@;W1H97(@8V%C:&EN9R!H96%D97)S(&9O<B!)12X@*B\*
M("`@("`@("!I9B`H)'1H:7,M/FAA<U%U:7)K*"=C86-H95]S<VQ?9&]W;FQO
M861S)RDI('L*("`@("`@("`@("`@:&5A9&5R*"=%>'!I<F5S.B`P)RD["B`@
M("`@("`@("`@(&AE861E<B@G0V%C:&4M0V]N=')O;#H@;75S="UR979A;&ED
M871E)RD["B`@("`@("`@("`@(&AE861E<B@G4')A9VUA.B!P=6)L:6,G*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S(&EF
M(&$@8G)O=W-E<B!C86X@9&ES<&QA>2!A(&=I=F5N($U)344@='EP92X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M:6UE='EP92`@5&AE($U)344@
M='EP92!T;R!C:&5C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@:68@=&AE(&)R;W=S97(@8V%N(&1I<W!L87D@=&AE($U)344@='EP
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-6:65W86)L92@D;6EM971Y<&4I
M"B`@("!["B`@("`@("`@)&UI;65T>7!E(#T@4W1R:6YG.CIL;W=E<B@D;6EM
M971Y<&4I.PH@("`@("`@(&QI<W0H)'1Y<&4L("1S=6)T>7!E*2`](&5X<&QO
M9&4H)R\G+"`D;6EM971Y<&4I.PH*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES
M+3Y?86-C97!T*2D@>PH@("`@("`@("`@("`D=VEL9&-A<F1?;6%T8V@@/2!F
M86QS93L*"B`@("`@("`@("`@(&EF("AS=')P;W,H)'1H:7,M/E]A8V-E<'0L
M("1M:6UE='EP92D@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*'-T<G!O
M<R@D=&AI<RT^7V%C8V5P="P@)RHO*B<I("$]/2!F86QS92D@>PH@("`@("`@
M("`@("`@("`@)'=I;&1C87)D7VUA=&-H(#T@=')U93L*("`@("`@("`@("`@
M("`@(&EF("@D='EP92`A/2`G:6UA9V4G*2!["B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("\J(&EM86=E+VIP96<@86YD(&EM86=E+W!J<&5G
M("IA<'!E87(J('1O(&)E('1H92!S86UE"B`@("`@("`@("`@("`J(&5N=&ET
M>2P@8G5T($UO>FEL;&$@9&]E<VXG="!S965M('1O('=A;G0@=&\@86-C97!T
M('1H90H@("`@("`@("`@("`@*B!L871T97(N("!&;W(@;W5R('!U<G!O<V5S
M+"!W92!W:6QL('1R96%T('1H96T@=&AE"B`@("`@("`@("`@("`J('-A;64N
M("HO"B`@("`@("`@("`@(&EF("@D=&AI<RT^:7-"<F]W<V5R*"=M;WII;&QA
M)RD@)B8*("`@("`@("`@("`@("`@("@D;6EM971Y<&4@/3T@)VEM86=E+W!J
M<&5G)RD@)B8*("`@("`@("`@("`@("`@("AS=')P;W,H)'1H:7,M/E]A8V-E
M<'0L("=I;6%G92]J<&5G)RD@(3T](&9A;'-E*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF
M("@A)'=I;&1C87)D7VUA=&-H*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A
M)'1H:7,M/FAA<T9E871U<F4H)VEM86=E<R<I('Q\("@D='EP92`A/2`G:6UA
M9V4G*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@:6Y?87)R87DH)'-U8G1Y<&4L("1T:&ES+3Y?:6UA
M9V5S*3L*("`@('T*"B`@("`O*BH*("`@("`J($5S8V%P92!C:&%R86-T97)S
M(&EN(&IA=F%S8W)I<'0@8V]D92!I9B!T:&4@8G)O=W-E<B!R97%U:7)E<R!I
M="X*("`@("`J("4R,RP@)3(V+"!A;F0@)3)"("AF;W(@<V]M92!B<F]W<V5R
M<RD@86YD("4R-R!N965D('1O(&)E(&5S8V%P960@;W(*("`@("`J(&5L<V4@
M:F%V87-C<FEP="!W:6QL(&EN=&5R<')E="!I="!A<R!A('-I;F=L92!Q=6]T
M92P@<&]U;F0@<VEG;BP@;W(*("`@("`J(&%M<&5R<V%N9"!A;F0@<F5F=7-E
M('1O('=O<FLN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]D92`@
M5&AE($I3(&-O9&4@=&\@97-C87!E+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@97-C87!E9"!C;V1E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!E<V-A<&5*4T-O9&4H)&-O9&4I"B`@("!["B`@("`@("`@)&9R;VT@/2`D
M=&\@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H)'1H:7,M/FES0G)O=W-E<B@G
M;7-I92<I('Q\"B`@("`@("`@("`@("@D=&AI<RT^:7-"<F]W<V5R*"=M;WII
M;&QA)RD@)B8@*"1T:&ES+3YG971-86IO<B@I(#X](#4I*2!\?`H@("`@("`@
M("`@("`D=&AI<RT^:7-"<F]W<V5R*"=K;VYQ=65R;W(G*2D@>PH@("`@("`@
M("`@("`D9G)O;2`](&%R<F%Y*"<E,C,G+"`G)3(V)RP@)R4R0B<I.PH@("`@
M("`@("`@("`D=&\@/2!A<G)A>2AU<FQE;F-O9&4H)R4R,R<I+"!U<FQE;F-O
M9&4H)R4R-B<I+"!U<FQE;F-O9&4H)R4R0B<I*3L*("`@("`@("!]"B`@("`@
M("`@)&9R;VU;72`]("<E,C<G.PH@("`@("`@("1T;UM=(#T@)UPE,C<G.PH*
M("`@("`@("!R971U<FX@<W1R7W)E<&QA8V4H)&9R;VTL("1T;RP@)&-O9&4I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!)12!V97)S:6]N(&EN
M('1H92!S97-S:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'9E
M<B`@5&AE($E%(%9E<G-I;VX@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S971)159E<G-I;VXH)'9E<BD*("`@('L*("`@("`@("`D7U-%4U-)3TY;
M)U]?8G)O=W-E<B==(#T@87)R87DH"B`@("`@("`@("`@("=I95]V97)S:6]N
M)R`]/B`D=F5R"B`@("`@("`@*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!T:&4@244@=F5R<VEO;B!S=&]R960@:6X@=&AE('-E<W-I;VXL(&EF
M(&%V86EL86)L92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@
M244@5F5R<VEO;B!S=')I;F<@;W(@;G5L;"!I9B!N;R!S=')I;F<@:7,@<W1O
M<F5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971)159E<G-I;VXH*0H@("`@
M>PH@("`@("`@(')E='5R;B!I<W-E="@D7U-%4U-)3TY;)U]?8G)O=W-E<B==
M6R=I95]V97)S:6]N)UTI(#\@)%]315-324].6R=?7V)R;W=S97(G75LG:65?
M=F5R<VEO;B==(#H@;G5L;#L*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]#86-H92\`````````````````````````````````````````````
M````````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-3$`,#(P-#8V`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-A8VAE+V9I;&4N<&AP````````````
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-#$U-P`Q,#4Q-30S,S<U,0`P
M,C(Q,C8`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]#86-H95]F:6QE.CH@8VQA<W,@
M<')O=FED97,@82!F:6QE<WES=&5M(&EM<&QE;65N=&%T:6]N(&]F('1H90H@
M*B!(;W)D92!C86-H:6YG('-Y<W1E;2X*("H*("H@3W!T:6]N86P@<&%R86UE
M=&5R<SH\<')E/@H@*B`@("=D:7(G("`@("!4:&4@9&ER96-T;W)Y('1O('-T
M;W)E('1H92!C86-H92!F:6QE<R!I;BX*("H@("`G<')E9FEX)R`@5&AE(&9I
M;&5N86UE('!R969I>"!T;R!U<V4@9F]R('1H92!C86-H92!F:6QE<RX\+W!R
M93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO0V%C:&4O0V%C:&4O9FEL92YP
M:'`L=B`Q+C(X+C$P+CD@,C`P-B\P,2\P,2`R,3HR.#HQ,"!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!!;FEL($UA9&AA=F%P961D>2`\
M86YI;$!R96-O:6PN;W)G/@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R
M9SX*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]#
M86-H90H@*B\*8VQA<W,@2&]R9&5?0V%C:&5?9FEL92!E>'1E;F1S($AO<F1E
M7T-A8VAE('L*"B`@("`O*BH*("`@("`J(%1H92!L;V-A=&EO;B!O9B!T:&4@
M=&5M<"!D:7)E8W1O<GDN"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1?9&ER.PH*("`@("\J*@H@("`@("H@5&AE(&9I;&5N
M86UE('!R969I>"!F;W(@8V%C:&4@9FEL97,N"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<')E9FEX(#T@)V-A8VAE7R<[
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W0@82!N97<@2&]R9&5?0V%C:&5?
M9FEL92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@(%!A<F%M971E<B!A<G)A>2X*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R
M9&5?0V%C:&5?9FEL92@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@
M("!I9B`H(65M<'1Y*"1P87)A;7-;)V1I<B==*2`F)B!`:7-?9&ER*"1P87)A
M;7-;)V1I<B==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V1I<B`]("1P87)A
M;7-;)V1I<B==.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G2&]R9&4O571I;"YP:'`G.PH@("`@("`@("`@("`D=&AI<RT^
M7V1I<B`](%5T:6PZ.F=E=%1E;7!$:7(H*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("AI<W-E="@D<&%R86US6R=P<F5F:7@G72DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]P<F5F:7@@/2`D<&%R86US6R=P<F5F:7@G73L*("`@("`@("!]
M"@H@("`@("`@('!A<F5N=#HZ2&]R9&5?0V%C:&4H)'!A<F%M<RD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971R:65V92!C86-H960@
M9&%T82!F<F]M('1H92!F:6QE<WES=&5M(&%N9"!R971U<FX@:70@=&\*("`@
M("`J('1H92!C86QL97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@
M)&ME>2`@("`@("!#86-H92!K97D@=&\@9F5T8V@N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D;&EF971I;64@($QI9F5T:6UE(&]F('1H92!D871A(&EN('-E
M8V]N9',N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@0V%C:&5D(&1A
M=&$L(&]R(&9A;'-E(&EF(&YO;F4@=V%S(&9O=6YD+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G970H)&ME>2P@)&QI9F5T:6UE(#T@,2D*("`@('L*("`@("`@
M("!I9B`H)'1H:7,M/F5X:7-T<R@D:V5Y+"`D;&EF971I;64I*2!["B`@("`@
M("`@("`@("1F:6QE;F%M92`]("1T:&ES+3Y?:V5Y5&]&:6QE*"1K97DI.PH@
M("`@("`@("`@("`D<VEZ92`](&9I;&5S:7IE*"1F:6QE;F%M92D["B`@("`@
M("`@("`@(&EF("@A)'-I>F4I('L*("`@("`@("`@("`@("`@(')E='5R;B`G
M)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D9&%T82`](&9I;&5?9V5T
M7V-O;G1E;G1S*"1F:6QE;F%M92D["B`@("`@("`@("`@(&EF("@D9&%T82`A
M/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@(')E='5R;B`D9&%T83L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@3F]T:&EN9R!C86-H
M960L(')E='5R;B!F86EL=7)E+B`J+PH@("`@("`@(')E='5R;B!F86QS93L*
M("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O('-T;W)E(&1A=&$@
M=&\@=&AE(&9I;&5S>7-T96TN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D:V5Y("`@0V%C:&4@:V5Y+@H@("`@("H@0'!A<F%M(&UI>&5D("`D9&%T
M82`@1&%T82!T;R!S=&]R92!I;B!T:&4@8V%C:&4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E="@D:V5Y+"`D9&%T82D*
M("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U5T:6PN<&AP)SL*
M("`@("`@("`D9FEL96YA;64@/2`D=&AI<RT^7VME>51O1FEL92@D:V5Y*3L*
M("`@("`@("`D=&UP7V9I;&4@/2!5=&EL.CIG971496UP1FEL92@G2&]R9&5#
M86-H92<L('1R=64L("1T:&ES+3Y?9&ER*3L*"B`@("`@("`@:68@*"1F9"`]
M(&9O<&5N*"1T;7!?9FEL92P@)W<G*2D@>PH@("`@("`@("`@("!I9B`H9G=R
M:71E*"1F9"P@)&1A=&$I(#P@<W1R;&5N*"1D871A*2D@>PH@("`@("`@("`@
M("`@("`@9F-L;W-E*"1F9"D["B`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!F8VQO
M<V4H)&9D*3L*("`@("`@("`@("`@("`@($!R96YA;64H)'1M<%]F:6QE+"`D
M9FEL96YA;64I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@071T96UP=',@=&\@9&ER96-T;'D@;W5T<'5T(&-A8VAE
M9"!D871A(&9R;VT@=&AE(&9I;&5S>7-T96TN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`@)&ME>2`@("`@("!#86-H92!K97D@=&\@;W5T<'5T+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&QI9F5T:6UE("!,:69E=&EM92!O9B!T
M:&4@9&%T82!I;B!S96-O;F1S+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@($-A8VAE9"!D871A+"!O<B!F86QS92!I9B!N;VYE('=A<R!F;W5N9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@;W5T<'5T*"1K97DL("1L:69E=&EM92`]
M(#$I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YE>&ES=',H)&ME>2P@)&QI
M9F5T:6UE*2D@>PH@("`@("`@("`@("`D9FEL96YA;64@/2`D=&AI<RT^7VME
M>51O1FEL92@D:V5Y*3L*("`@("`@("`@("`@)&9D(#T@0&9O<&5N*"1F:6QE
M;F%M92P@)W(G*3L*("`@("`@("`@("`@:68@*"1F9"D@>PH@("`@("`@("`@
M("`@("`@9G!A<W-T:')U*"1F9"D["B`@("`@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@3F]T
M:&EN9R!C86-H960L(')E='5R;B!F86EL=7)E+B`J+PH@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!I9B!A(&=I
M=F5N(&ME>2!E>&ES=',@:6X@=&AE(&-A8VAE+"!V86QI9"!F;W(@=&AE(&=I
M=F5N"B`@("`@*B!L:69E=&EM92X@268@:70@97AI<W1S(&)U="!I<R!E>'!I
M<F5D+"!D96QE=&4@=&AE(&9I;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`@)&ME>2`@("`@("!#86-H92!K97D@=&\@8VAE8VLN"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D;&EF971I;64@($QI9F5T:6UE(&]F('1H92!K97D@
M:6X@<V5C;VYD<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@($5X
M:7-T86YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@97AI<W1S*"1K97DL("1L
M:69E=&EM92`](#$I"B`@("!["B`@("`@("`@)&9I;&5N86UE(#T@)'1H:7,M
M/E]K97E4;T9I;&4H)&ME>2D["@H@("`@("`@("\J($ME>2!E>&ES=',@:6X@
M=&AE(&-A8VAE("HO"B`@("`@("`@:68@*&9I;&5?97AI<W1S*"1F:6QE;F%M
M92DI('L*("`@("`@("`@("`@+RH@,"!M96%N<R!N;R!E>'!I<F4N("HO"B`@
M("`@("`@("`@(&EF("@D;&EF971I;64@/3T@,"D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J
M($EF('1H92!F:6QE('=A<R!B965N(&-R96%T960@869T97(@=&AE('-U<'!L
M:65D('9A;'5E+`H@("`@("`@("`@("`@*B!T:&4@9&%T82!I<R!V86QI9"`H
M9G)E<V@I+B`J+PH@("`@("`@("`@("!I9B`H=&EM92@I("T@)&QI9F5T:6UE
M(#P](&9I;&5M=&EM92@D9FEL96YA;64I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@($!U;FQI;FLH)&9I;&5N86UE*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@17AP:7)E(&%N>2!E>&ES=&EN9R!D871A(&9O<B!T:&4@9VEV96X@:V5Y
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@0V%C:&4@:V5Y
M('1O(&5X<&ER92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%-U
M8V-E<W,@;W(@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@97AP:7)E
M*"1K97DI"B`@("!["B`@("`@("`@)&9I;&5N86UE(#T@)'1H:7,M/E]K97E4
M;T9I;&4H)&ME>2D["B`@("`@("`@<F5T=7)N($!U;FQI;FLH)&9I;&5N86UE
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($UA<"!A(&-A8VAE(&ME>2!T;R!A
M('5N:7%U92!F:6QE;F%M92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1K97D@($-A8VAE(&ME
M>2X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@1G5L;'D@<75A;&EF
M:65D(&9I;&5N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!?:V5Y5&]&:6QE
M*"1K97DI"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&ER("X@)R\G
M("X@)'1H:7,M/E]P<F5F:7@@+B!M9#4H)&ME>2D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$;R!A;GD@9V%R8F%G92!C;VQL96-T:6]N(&YE961E9"!F;W(@
M=&AE(&1R:79E<BX*("`@("`J"B`@("`@*B!`<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1S96-S("!4:&4@;6EN:6UU;2!A;6]U;G0@
M;V8@=&EM92`H:6X@<V5C;VYD<RD@<F5Q=6ER960*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!B969O<F4@82!C86-H92!I=&5M(&ES(')E;6]V960N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D;T=#*"1S96-S*0H@("`@>PH@("`@
M("`@("1F:6QE;F%M92`]("1T:&ES+3Y?9&ER("X@)R]H;W)D95]C86-H95]G
M8R<["B`@("`@("`@)&=C7W1I;64@/2!T:6UE*"D@+2`D<V5C<SL*("`@("`@
M("!I9B`H9FEL95]E>&ES=',H)&9I;&5N86UE*2D@>PH@("`@("`@("`@("`D
M;VQD7W1I;64@/2!F:6QE7V=E=%]C;VYT96YT<R@D9FEL96YA;64I.PH@("`@
M("`@("`@("!I9B`H*"1O;&1?=&EM92`A/3T@9F%L<V4I("8F"B`@("`@("`@
M("`@("`@("`H)&=C7W1I;64@/B`D;VQD7W1I;64I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("1D(#T@9&ER*"1T:&ES+3Y?9&ER*3L*("`@("`@("!W:&EL92`H*"1E;G1R
M>2`]("1D+3YR96%D*"DI("$]/2!F86QS92D@>PH@("`@("`@("`@("!I9B`H
M<W1R<&]S*"1E;G1R>2P@)'1H:7,M/E]P<F5F:7@I(#T]/2`P*2!["B`@("`@
M("`@("`@("`@("`D;71I;64@/2!F:6QE;71I;64H)'1H:7,M/E]D:7(@+B`G
M+R<@+B`D96YT<GDI.PH@("`@("`@("`@("`@("`@:68@*"1G8U]T:6UE(#X@
M)&UT:6UE*2!["B`@("`@("`@("`@("`@("`@("`@0'5N;&EN:R@D=&AI<RT^
M7V1I<B`N("<O)R`N("1E;G1R>2D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("`@("`@)&0M/F-L;W-E*"D["B`*("`@
M("`@("`D9G`@/2!F;W!E;B@D9FEL96YA;64L("=W)RD["B`@("`@("`@9G=R
M:71E*"1F<"P@=&EM92@I*3L*("`@("`@("!F8VQO<V4H)&9P*3L*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]#86-H92]Z<',T
M+G!H<```````````````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0T-S(`
M,3`U,34T,S,W-3$`,#(R,3`V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?0V%C:&5?
M>G!S-#HZ(&-L87-S('!R;W9I9&5S(&$@6F5N9"!097)F;W)M86YC92!3=6ET
M90H@*B`H=F5R<VEO;B`T+C`K*2!I;7!L96UE;G1A=&EO;B!O9B!T:&4@2&]R
M9&4@8V%C:&EN9R!S>7-T96TN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T-A
M8VAE+T-A8VAE+WIP<S0N<&AP+'8@,2XQ+C$P+C0@,C`P-B\P,2\P,2`R,3HR
M.#HQ,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?0V%C
M:&4*("HO"F-L87-S($AO<F1E7T-A8VAE7WIP<S0@97AT96YD<R!(;W)D95]#
M86-H92!["@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971R:65V92!A
M('!I96-E(&]F(&-A8VAE9"!D871A(&%N9"!R971U<FX@:70@=&\@=&AE(&-A
M;&QE<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D:V5Y("`@("`@
M($-A8VAE(&ME>2!T;R!F971C:"X*("`@("`J($!P87)A;2!I;G1E9V5R("1L
M:69E=&EM92`@3&EF971I;64@;V8@=&AE(&ME>2!I;B!S96-O;F1S+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@($-A8VAE9"!D871A+"!O<B!F86QS
M92!I9B!N;VYE('=A<R!F;W5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M*"1K97DL("1L:69E=&EM92`](#$I"B`@("!["B`@("`@("`@<F5T=7)N(&]U
M='!U=%]C86-H95]G970H)&ME>2P@)&QI9F5T:6UE*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($%T=&5M<'1S('1O('-T;W)E(&%N(&]B:F5C="!T;R!T:&4@
M8V%C:&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("`@0V%C
M:&4@:V5Y("AI9&5N=&EF:65R*2X*("`@("`J($!P87)A;2!M:7AE9"`@)&1A
M=&$@($1A=&$@=&\@<W1O<F4@:6X@=&AE(&-A8VAE+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S970H)&ME>2P@)&1A=&$I
M"B`@("!["B`@("`@("`@;W5T<'5T7V-A8VAE7W!U="@D:V5Y+"`D9&%T82D[
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!
M='1E;7!T<R!T;R!D:7)E8W1L>2!O=71P=70@8V%C:&5D(&1A=&$N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&ME>2`@("`@("!#86-H92!K97D@
M=&\@;W5T<'5T+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&QI9F5T:6UE("!,
M:69E=&EM92!O9B!T:&4@:V5Y(&EN('-E8V]N9',N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@0V%C:&5D(&1A=&$L(&]R(&9A;'-E(&EF(&YO;F4@
M=V%S(&9O=6YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!O=71P=70H)&ME>2P@
M)&QI9F5T:6UE(#T@,2D*("`@('L*("`@("`@("!E8VAO("1T:&ES+3YF971C
M:"@D:V5Y+"`D;&EF971I;64I.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE
M8VMS(&EF(&$@9VEV96X@:V5Y(&5X:7-T<R!I;B!T:&4@8V%C:&4L('9A;&ED
M(&9O<B!T:&4@9VEV96X@;&EF971I;64N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@)&ME>2`@("`@("!#86-H92!K97D@=&\@8VAE8VLN"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D;&EF971I;64@($QI9F5T:6UE(&]F('1H92!K
M97D@:6X@<V5C;VYD<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M($5X:7-T86YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@97AI<W1S*"1K97DL
M("1L:69E=&EM92`](#$I"B`@("!["B`@("`@("`@)&5X:7-T<R`](&]U='!U
M=%]C86-H95]E>&ES=',H)&ME>2P@)&QI9F5T:6UE*3L*("`@("`@("!O=71P
M=71?8V%C:&5?<W1O<"@I.PH@("`@("`@(')E='5R;B`D97AI<W1S.PH@("`@
M?0H*("`@("\J*@H@("`@("H@17AP:7)E(&%N>2!E>&ES=&EN9R!D871A(&9O
M<B!T:&4@9VEV96X@:V5Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&ME>2`@0V%C:&4@:V5Y('1O(&5X<&ER92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%-U8V-E<W,@;W(@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@97AP:7)E*"1K97DI"B`@("!["B`@("`@("`@<F5T=7)N(&]U
M='!U=%]C86-H95]R96UO=F5?:V5Y*"1K97DI.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]#86-H92YP:'``````````````````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,30P,3$`,3`U,34T,S,W-3(`,#(Q,3<U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@
M2&]R9&5?0V%C:&4Z.B!C;&%S<R!P<F]V:61E<R!A(&-O;6UO;B!A8G-T<F%C
M=&5D(&EN=&5R9F%C92!I;G1O"B`J('1H92!V87)I;W5S(&-A8VAI;F<@8F%C
M:V5N9',N("!)="!A;'-O('!R;W9I9&5S(&9U;F-T:6]N<R!F;W(*("H@8VAE
M8VMI;F<@:6XL(')E=')I979I;F<L(&%N9"!F;'5S:&EN9R!A(&-A8VAE+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#86-H92]#86-H92YP:'`L=B`Q+C,Q
M+C$P+C$Q(#(P,#8O,#$O,#$@,C$Z,C@Z,3`@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`Q.3DY+3(P,#8@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C
M;VEL+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U
M8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!A
M=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`
M<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?0V%C:&4*("HO
M"F-L87-S($AO<F1E7T-A8VAE('L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M="!A(&YE=R!(;W)D95]#86-H92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1P87)A;7,@(%!A<F%M971E<B!A<G)A>2X*("`@("`J+PH@
M("`@9G5N8W1I;VX@2&]R9&5?0V%C:&4H)'!A<F%M<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@+RH@3VYL>2!D;R!G87)B86=E(&-O;&QE8W1I;VX@:68@
M87-K960@9F]R+"!A;F0@=&AE;B!O;FQY(#$E(&]F('1H90H@("`@("`@("`J
M('1I;64@=V4@8W)E871E(&%N(&]B:F5C="X@*B\*("`@("`@("!I9B`H(65M
M<'1Y*"1P87)A;7-;)V=C)UTI("8F"B`@("`@("`@("`@("AR86YD*#`L(#DY
M*2`]/2`P*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V1O1T,H)'!A<F%M<ULG
M9V,G72D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@071T96UP
M=',@=&\@<F5T<FEE=F4@82!C86-H960@;V)J96-T(&%N9"!R971U<FX@:70@
M=&\@=&AE"B`@("`@*B!C86QL97(N"B`@("`@*@H@("`@("H@0&%B<W1R86-T
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&ME>2`@("`@("!/8FIE
M8W0@240@=&\@<75E<GDN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;&EF971I
M;64@($QI9F5T:6UE(&]F('1H92!O8FIE8W0@:6X@<V5C;VYD<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!#86-H960@9&%T82P@;W(@9F%L<V4@
M:68@;F]N92!W87,@9F]U;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E="@D
M:V5Y+"`D;&EF971I;64@/2`Q*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS
M93L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O('-T;W)E(&%N
M(&]B:F5C="!I;B!T:&4@8V%C:&4N"B`@("`@*@H@("`@("H@0&%B<W1R86-T
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("`@3V)J96-T($E$
M('5S960@87,@=&AE(&-A8VAI;F<@:V5Y+@H@("`@("H@0'!A<F%M(&UI>&5D
M("`D9&%T82`@1&%T82!T;R!S=&]R92!I;B!T:&4@8V%C:&4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E="@D:V5Y+"`D
M9&%T82D*("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J($%T=&5M<'1S('1O(&1I<F5C=&QY(&]U='!U="!A(&-A8VAE
M9"!O8FIE8W0N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)&ME>2`@("`@("!/8FIE8W0@240@=&\@<75E
M<GDN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;&EF971I;64@($QI9F5T:6UE
M(&]F('1H92!O8FIE8W0@:6X@<V5C;VYD<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!#86-H960@9&%T82P@;W(@9F%L<V4@:68@;F]N92!W87,@
M9F]U;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&]U='!U="@D:V5Y+"`D;&EF
M971I;64@/2`Q*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*
M"B`@("`O*BH*("`@("`J($-H96-K<R!I9B!A(&=I=F5N(&ME>2!E>&ES=',@
M:6X@=&AE(&-A8VAE+"!V86QI9"!F;W(@=&AE(&=I=F5N"B`@("`@*B!L:69E
M=&EM92X*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D:V5Y("`@("`@($-A8VAE(&ME>2!T;R!C:&5C:RX*
M("`@("`J($!P87)A;2!I;G1E9V5R("1L:69E=&EM92`@3&EF971I;64@;V8@
M=&AE(&ME>2!I;B!S96-O;F1S+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@17AI<W1A;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>&ES=',H
M)&ME>2P@)&QI9F5T:6UE(#T@,2D*("`@('L*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'!I<F4@86YY(&5X:7-T:6YG
M(&1A=&$@9F]R('1H92!G:79E;B!K97DN"B`@("`@*@H@("`@("H@0&%B<W1R
M86-T"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("!#86-H92!K
M97D@=&\@97AP:7)E+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M4W5C8V5S<R!O<B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>'!I
M<F4H)&ME>2D*("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J($1O(&%N>2!G87)B86=E(&-O;&QE8W1I;VX@;F5E9&5D
M(&9O<B!T:&4@9')I=F5R+@H@("`@("H*("`@("`J($!P<FEV871E"B`@("`@
M*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'-E8W,@(%1H92!M:6YI;75M(&%M;W5N="!O9B!T:6UE("AI;B!S96-O
M;F1S*2!R97%U:7)E9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&)E
M9F]R92!A(&-A8VAE(&ET96T@:7,@<F5M;W9E9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V1O1T,H)'-E8W,I"B`@("!["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!(;W)D95]#86-H92!I
M;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@("`@("H*("`@("`J($!P87)A
M;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!(;W)D95]#
M86-H92!S=6)C;&%S<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;BX@268@)&1R:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL
M(&QO;VL*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!I;B`D9')I=F5R
M6S!=+VQI8B]#86-H92\@9F]R('1H92!S=6)C;&%S<PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@(&EM<&QE;65N=&%T:6]N(&YA;65D("1D<FEV97);
M,5TN<&AP+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C
M;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@8V]N9FEG=7)A=&EO;B!O<B!C;VYN96-T:6]N('!A<F%M971E
M<G,@82!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&UI
M9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]#86-H92`@
M5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@2&]R9&5?0V%C:&4@:6YS=&%N
M8V4L(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!F86QS92!O;B!E
M<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)&1R:79E<BP@
M)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1D<FEV97(I*2!["B`@("`@("`@("`@("1A<'`@/2`D9')I=F5R6S!=.PH@
M("`@("`@("`@("`D9')I=F5R(#T@)&1R:79E<ELQ73L*("`@("`@("!]"@H@
M("`@("`@("1D<FEV97(@/2!B87-E;F%M92@D9')I=F5R*3L*("`@("`@("!I
M9B`H96UP='DH)&1R:79E<BD@?'P@)&1R:79E<B`]/2`G;F]N92<I('L*("`@
M("`@("`@("`@)&-A8VAE(#T@)FYE=R!(;W)D95]#86-H92@D<&%R86US*3L*
M("`@("`@("`@("`@<F5T=7)N("1C86-H93L*("`@("`@("!]"@H@("`@("`@
M(&EF("@A96UP='DH)&%P<"DI('L*("`@("`@("`@("`@:6YC;'5D95]O;F-E
M("1A<'`@+B`G+VQI8B]#86-H92\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@
M("`@("!](&5L<V5I9B`H0&9I;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I
M("X@)R]#86-H92\G("X@)&1R:79E<B`N("<N<&AP)RDI('L*("`@("`@("`@
M("`@:6YC;'5D95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]#86-H92\G
M("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!`:6YC;'5D95]O;F-E("=(;W)D92]#86-H92\G("X@)&1R:79E<B`N
M("<N<&AP)SL*("`@("`@("!]"@H@("`@("`@("1C;&%S<R`]("=(;W)D95]#
M86-H95\G("X@)&1R:79E<CL*("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C
M;&%S<RDI('L*("`@("`@("`@("`@)&-A8VAE(#T@)FYE=R`D8VQA<W,H)'!A
M<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-A8VAE(#T@
M4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@9&5F:6YI=&EO;B!O9B`G("X@)&-L
M87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&-A8VAE.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@
M<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@2&]R9&5?0V%C:&4*
M("`@("`J(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(N($ET('=I;&P@;VYL
M>2!C<F5A=&4@82!N97<@:6YS=&%N8V4*("`@("`J(&EF(&YO($AO<F1E7T-A
M8VAE(&EN<W1A;F-E('=I=&@@=&AE('-A;64@<&%R86UE=&5R<R!C=7)R96YT
M;'D*("`@("`J(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES('-H;W5L9"!B
M92!U<V5D(&EF(&UU;'1I<&QE(&-A8VAE(&)A8VME;F1S("AA;F0L('1H=7,L
M"B`@("`@*B!M=6QT:7!L92!(;W)D95]#86-H92!I;G-T86YC97,I(&%R92!R
M97%U:7)E9"X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN
M=F]K960@87,Z"B`@("`@*B`D=F%R(#T@)DAO<F1E7T-A8VAE.CIS:6YG;&5T
M;VXH*0H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@
M='EP92!O9B!C;VYC<F5T92!(;W)D95]#86-H92!S=6)C;&%S<R!T;PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@(')E='5R;BX@268@)&1R:79E<B!I
M<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL(&QO;VL*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!I;B`D9')I=F5R6S!=+VQI8B]#86-H92\@9F]R('1H
M92!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EM<&QE
M;65N=&%T:6]N(&YA;65D("1D<FEV97);,5TN<&AP+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO
M;F%L(&-O;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!C;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N
M965D+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?0V%C:&4@(%1H92!C
M;VYC<F5T92!(;W)D95]#86-H92!R969E<F5N8V4L(&]R(&9A;'-E(&]N"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("!E<G)O<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@)G-I;F=L971O;B@D9')I=F5R+"`D<&%R86US(#T@87)R87DH
M*2D*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<R`](&%R<F%Y*"D[
M"@H@("`@("`@("1S:6=N871U<F4@/2!S97)I86QI>F4H87)R87DH)&1R:79E
M<BP@)'!A<F%M<RDI.PH@("`@("`@(&EF("AE;7!T>2@D:6YS=&%N8V5S6R1S
M:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U
M<F5=(#T@)DAO<F1E7T-A8VAE.CIF86-T;W)Y*"1D<FEV97(L("1P87)A;7,I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA
M='5R95T["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O0VEP:&5R+P``````````````````````````````
M`````````````````````````````````````````````#`P,#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S4P`#`R,#8W-``@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]#:7!H97(O0FQO8VM-
M;V1E+P``````````````````````````````````````````````````````
M````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U
M,34T,S,W-3``,#(R-3,S`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T-I<&AE<B]";&]C:TUO9&4O8V)C+G!H<```````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-#<P,P`Q,#4Q-30S,S<U,``P,C,W-S<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M92!(;W)D95]#:7!H97)?0FQO8VM-;V1E7V-B8SHZ(%1H:7,@8VQA<W,@:6UP
M;&5M96YT<R!T:&4*("H@2&]R9&5?0VEP:&5R7T)L;V-K36]D92!U<VEN9R!T
M:&4@0VEP:&5R($)L;V-K($-H86EN:6YG(&UE=&AO9"!O9@H@*B!E;F-R>7!T
M:6YG(&)L;V-K<R!O9B!D871A+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#
M:7!H97(O0VEP:&5R+T)L;V-K36]D92]C8F,N<&AP+'8@,2XW+C$R+C4@,C`P
M-B\P,2\P,2`R,3HR.#HQ,2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#(M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\
M;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@2&]R9&4@,BXR
M"B`J($!P86-K86=E($AO<F1E7T-I<&AE<@H@*B\*8VQA<W,@2&]R9&5?0VEP
M:&5R7T)L;V-K36]D95]C8F,@97AT96YD<R!(;W)D95]#:7!H97)?0FQO8VM-
M;V1E('L*"B`@("`O*BH*("`@("`J($5N8W)Y<'0@82!S=')I;F<N"B`@("`@
M*@H@("`@("H@0'!A<F%M($AO<F1E7T-I<&AE<B`D8VEP:&5R("!#:7!H97(@
M86QG;W)I=&AM('1O('5S92!F;W(*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@96YC<GEP=&EO;BX*("`@("`J($!P87)A;2!S=')I;F<@
M)'!L86EN=&5X="`@("`@5&AE(&1A=&$@=&\@96YC<GEP="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N("!4:&4@96YC<GEP=&5D(&1A=&$N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&5N8W)Y<'0H)B1C:7!H97(L("1P;&%I;G1E>'0I"B`@("![
M"B`@("`@("`@)&5N8W)Y<'1E9"`]("<G.PH*("`@("`@("`D8FQO8VMS:7IE
M(#T@)&-I<&AE<BT^9V5T0FQO8VM3:7IE*"D["B`@("`@("`@)'!R979I;W5S
M0VEP:&5R(#T@)'1H:7,M/E]I=CL*"B`@("`@("`@)&I-87@@/2!S=')L96XH
M)'!L86EN=&5X="D["B`@("`@("`@9F]R("@D:B`](#`[("1J(#P@)&I-87@[
M("1J("L]("1B;&]C:W-I>F4I('L*("`@("`@("`@("`@)'!L86EN(#T@<W5B
M<W1R*"1P;&%I;G1E>'0L("1J+"`D8FQO8VMS:7IE*3L*"B`@("`@("`@("`@
M(&EF("AS=')L96XH)'!L86EN*2`\("1B;&]C:W-I>F4I('L*("`@("`@("`@
M("`@("`@("\O('!A9"!T:&4@8FQO8VL@=VET:"!<,"=S(&EF(&ET)W,@;F]T
M(&QO;F<@96YO=6=H"B`@("`@("`@("`@("`@("`D<&QA:6X@/2!S=')?<&%D
M*"1P;&%I;BP@."P@(EPP(BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1P;&%I;B`]("1P;&%I;B!>("1P<F5V:6]U<T-I<&AE<CL*("`@("`@("`@
M("`@)'!R979I;W5S0VEP:&5R(#T@)&-I<&AE<BT^96YC<GEP=$)L;V-K*"1P
M;&%I;BD["B`@("`@("`@("`@("1E;F-R>7!T960@+CT@)'!R979I;W5S0VEP
M:&5R.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1E;F-R>7!T960["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!$96-R>7!T(&$@<W1R:6YG+@H@("`@("H*
M("`@("`J($!P87)A;2!(;W)D95]#:7!H97(@)&-I<&AE<B`@0VEP:&5R(&%L
M9V]R:71H;2!T;R!U<V4@9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&1E8W)Y<'1I;VXN"B`@("`@*B!`<&%R86T@<W1R:6YG("1C
M:7!H97)T97AT("`@(%1H92!D871A('1O(&1E8W)Y<'0N"B`@("`@*@H@("`@
M("H@0')E='5R;B`@5&AE(&1E8W)Y<'1E9"!D871A+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!D96-R>7!T*"8D8VEP:&5R+"`D8VEP:&5R=&5X="D*("`@('L*
M("`@("`@("`D9&5C<GEP=&5D(#T@)R<["@H@("`@("`@("1B;&]C:W-I>F4@
M/2`D8VEP:&5R+3YG971";&]C:U-I>F4H*3L*("`@("`@("`D<')E=FEO=7-#
M:7!H97(@/2`D=&AI<RT^7VEV.PH*("`@("`@("`D:DUA>"`]('-T<FQE;B@D
M8VEP:&5R=&5X="D["B`@("`@("`@9F]R("@D:B`](#`[("1J(#P@)&I-87@[
M("1J("L]("1B;&]C:W-I>F4I('L*("`@("`@("`@("`@)'!L86EN(#T@<W5B
M<W1R*"1C:7!H97)T97AT+"`D:BP@)&)L;V-K<VEZ92D["B`@("`@("`@("`@
M("1D96-R>7!T960@+CT@)&-I<&AE<BT^9&5C<GEP=$)L;V-K*"1P;&%I;BD@
M7B`D<')E=FEO=7-#:7!H97(["B`@("`@("`@("`@("1P<F5V:6]U<T-I<&AE
M<B`]("1P;&%I;CL*("`@("`@("!]"@H@("`@("`@("\O(%)E;6]V92!T<F%I
M;&EN9R!<,"=S('5S960@=&\@<&%D('1H92!L87-T(&)L;V-K+@H@("`@("`@
M('=H:6QE("AS=6)S='(H)&1E8W)Y<'1E9"P@+3$L(#$I(#T](")<,"(I('L*
M("`@("`@("`@("`@)&1E8W)Y<'1E9"`]('-U8G-T<B@D9&5C<GEP=&5D+"`P
M+"`M,2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&1E8W)Y<'1E9#L*
M("`@('T*"GT*````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+T-I<&AE<B]";&]C:TUO9&4O8V9B-C0N<&AP````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#8V-``Q,#4Q-30S,S<U,``P,C0Q-C(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%1H92!(;W)D95]#:7!H97)?0FQO8VM-;V1E7V-F8C8T.CH@
M5&AI<R!C;&%S<R!I;7!L96UE;G1S('1H90H@*B!(;W)D95]#:7!H97)?0FQO
M8VM-;V1E('5S:6YG(&$@-C0@8FET(&-I<&AE<B!F965D8F%C:RX*("H*("H@
M5&AI<R!C86X@8F4@=7-E9"!T;R!E;F-R>7!T(&%N>2!L96YG=&@@<W1R:6YG
M(&%N9"!T:&4@96YC<GEP=&5D"B`J('9E<G-I;VX@=VEL;"!B92!T:&4@<V%M
M92!L96YG=&@N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T-I<&AE<B]#:7!H
M97(O0FQO8VM-;V1E+V-F8C8T+G!H<"QV(#$N-RXQ,BXU(#(P,#8O,#$O,#$@
M,C$Z,C@Z,3$@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@
M36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A
M9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#(N,@H@*B!`<&%C
M:V%G92!(;W)D95]#:7!H97(*("HO"F-L87-S($AO<F1E7T-I<&AE<E]";&]C
M:TUO9&5?8V9B-C0@97AT96YD<R!(;W)D95]#:7!H97)?0FQO8VM-;V1E('L*
M"B`@("`O*BH*("`@("`J($5N8W)Y<'0@82!S=')I;F<N"B`@("`@*@H@("`@
M("H@0'!A<F%M($AO<F1E7T-I<&AE<B`D8VEP:&5R("!#:7!H97(@86QG;W)I
M=&AM('1O('5S92!F;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@96YC<GEP=&EO;BX*("`@("`J($!P87)A;2!S=')I;F<@)'!L86EN
M=&5X="`@("`@5&AE(&1A=&$@=&\@96YC<GEP="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N("!4:&4@96YC<GEP=&5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&5N8W)Y<'0H)B1C:7!H97(L("1P;&%I;G1E>'0I"B`@("!["B`@("`@
M("`@)&5N8W)Y<'1E9"`]("<G.PH*("`@("`@("`D;B`](#`["B`@("`@("`@
M)&I-87@@/2!S=')L96XH)'!L86EN=&5X="D["B`@("`@("`@9F]R("@D:B`]
M(#`[("1J(#P@)&I-87@[("1J*RLI('L*("`@("`@("`@("`@:68@*"1N(#T]
M(#`I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?:78@/2`D8VEP:&5R+3YE
M;F-R>7!T0FQO8VLH)'1H:7,M/E]I=BD["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1C(#T@)'!L86EN=&5X=%LD:ET@7B`D=&AI<RT^7VEV6R1N73L*
M("`@("`@("`@("`@)'1H:7,M/E]I=B`]('-U8G-T<B@D=&AI<RT^7VEV+"`P
M+"`D;BD@+B`D8R`N('-U8G-T<B@D=&AI<RT^7VEV+"`D;B`K(#$I.PH@("`@
M("`@("`@("`D96YC<GEP=&5D("X]("1C.PH*("`@("`@("`@("`@)&X@/2`H
M*RLD;BD@)B`P>#`W.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1E;F-R
M>7!T960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96-R>7!T(&$@<W1R:6YG
M+@H@("`@("H*("`@("`J($!P87)A;2!(;W)D95]#:7!H97(@)&-I<&AE<B`@
M0VEP:&5R(&%L9V]R:71H;2!T;R!U<V4@9F]R"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&1E8W)Y<'1I;VXN"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1C:7!H97)T97AT("`@(%1H92!D871A('1O(&1E8W)Y<'0N"B`@
M("`@*@H@("`@("H@0')E='5R;B`@5&AE(&1E8W)Y<'1E9"!D871A+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!D96-R>7!T*"8D8VEP:&5R+"`D8VEP:&5R=&5X
M="D*("`@('L*("`@("`@("`D9&5C<GEP=&5D(#T@)R<["@H@("`@("`@("1N
M(#T@,#L*("`@("`@("`D:DUA>"`]('-T<FQE;B@D8VEP:&5R=&5X="D["B`@
M("`@("`@9F]R("@D:B`](#`[("1J(#P@)&I-87@[("1J*RLI('L*("`@("`@
M("`@("`@:68@*"1N(#T](#`I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M:78@/2`D8VEP:&5R+3YE;F-R>7!T0FQO8VLH)'1H:7,M/E]I=BD["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1C(#T@)&-I<&AE<G1E>'1;)&I=(%X@
M)'1H:7,M/E]I=ELD;ET["B`@("`@("`@("`@("1T:&ES+3Y?:78@/2!S=6)S
M='(H)'1H:7,M/E]I=BP@,"P@)&XI("X@<W5B<W1R*"1C:7!H97)T97AT+"`D
M:BP@,2D@+B!S=6)S='(H)'1H:7,M/E]I=BP@)&X@*R`Q*3L*("`@("`@("`@
M("`@)&1E8W)Y<'1E9"`N/2`D8SL*"B`@("`@("`@("`@("1N(#T@*"LK)&XI
M("8@,'@P-SL*("`@("`@("!]"@H@("`@("`@("\O(%)E;6]V92!T<F%I;&EN
M9R!<,"=S('5S960@=&\@<&%D('1H92!L87-T(&)L;V-K+@H@("`@("`@('=H
M:6QE("AS=6)S='(H)&1E8W)Y<'1E9"P@+3$L(#$I(#T](")<,"(I('L*("`@
M("`@("`@("`@)&1E8W)Y<'1E9"`]('-U8G-T<B@D9&5C<GEP=&5D+"`P+"`M
M,2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&1E8W)Y<'1E9#L*("`@
M('T*"GT*````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-I<&AE<B]";&]C:TUO9&4O
M96-B+G!H<```````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#,S-@`Q,#4Q-30S
M,S<U,``P,C0P,#,`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]#:7!H97)?0FQO8VM-
M;V1E7V5C8CHZ(%1H:7,@8VQA<W,@:6UP;&5M96YT<R!T:&4*("H@2&]R9&5?
M0VEP:&5R7T)L;V-K36]D92!U<VEN9R!T:&4@16QE8W1R;VYI8R!#;V1E($)O
M;VL@;65T:&]D(&]F"B`J(&5N8W)Y<'1I;F<@8FQO8VMS(&]F(&1A=&$N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+T-I<&AE<B]#:7!H97(O0FQO8VM-;V1E
M+V5C8BYP:'`L=B`Q+C<N,3(N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C$Q(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI:V4@0V]C:')A;F4@
M/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ
M/@H@*B!`<VEN8V4@("!(;W)D92`R+C(*("H@0'!A8VMA9V4@2&]R9&5?0VEP
M:&5R"B`J+PIC;&%S<R!(;W)D95]#:7!H97)?0FQO8VM-;V1E7V5C8B!E>'1E
M;F1S($AO<F1E7T-I<&AE<E]";&]C:TUO9&4@>PH*("`@("\J*@H@("`@("H@
M16YC<GEP="!A('-T<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@2&]R9&5?
M0VEP:&5R("1C:7!H97(@($-I<&AE<B!A;&=O<FET:&T@=&\@=7-E(&9O<@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!E;F-R>7!T:6]N
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&QA:6YT97AT("`@("!4:&4@9&%T
M82!T;R!E;F-R>7!T+@H@("`@("H*("`@("`J($!R971U<FX@(%1H92!E;F-R
M>7!T960@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@96YC<GEP="@F)&-I
M<&AE<BP@)'!L86EN=&5X="D*("`@('L*("`@("`@("`D96YC<GEP=&5D(#T@
M)R<["B`@("`@("`@)&)L;V-K<VEZ92`]("1C:7!H97(M/F=E=$)L;V-K4VEZ
M92@I.PH*("`@("`@("`D:DUA>"`]('-T<FQE;B@D<&QA:6YT97AT*3L*("`@
M("`@("!F;W(@*"1J(#T@,#L@)&H@/"`D:DUA>#L@)&H@*ST@)&)L;V-K<VEZ
M92D@>PH@("`@("`@("`@("`D<&QA:6X@/2!S=6)S='(H)'!L86EN=&5X="P@
M)&HL("1B;&]C:W-I>F4I.PH*("`@("`@("`@("`@:68@*'-T<FQE;B@D<&QA
M:6XI(#P@)&)L;V-K<VEZ92D@>PH@("`@("`@("`@("`@("`@+R\@<&%D('1H
M92!B;&]C:R!W:71H(%PP)W,@:68@:70G<R!N;W0@;&]N9R!E;F]U9V@*("`@
M("`@("`@("`@("`@("1P;&%I;B`]('-T<E]P860H)'!L86EN+"`X+"`B7#`B
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&5N8W)Y<'1E9"`N/2`D
M8VEP:&5R+3YE;F-R>7!T0FQO8VLH)'!L86EN*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D96YC<GEP=&5D.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1&5C<GEP="!A('-T<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@2&]R9&5?
M0VEP:&5R("1C:7!H97(@($-I<&AE<B!A;&=O<FET:&T@=&\@=7-E(&9O<@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D96-R>7!T:6]N
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VEP:&5R=&5X="`@("!4:&4@9&%T
M82!T;R!D96-R>7!T+@H@("`@("H*("`@("`J($!R971U<FX@(%1H92!D96-R
M>7!T960@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C<GEP="@F)&-I
M<&AE<BP@)&-I<&AE<G1E>'0I"B`@("!["B`@("`@("`@)&1E8W)Y<'1E9"`]
M("<G.PH@("`@("`@("1B;&]C:W-I>F4@/2`D8VEP:&5R+3YG971";&]C:U-I
M>F4H*3L*"B`@("`@("`@)&I-87@@/2!S=')L96XH)&-I<&AE<G1E>'0I.PH@
M("`@("`@(&9O<B`H)&H@/2`P.R`D:B`\("1J36%X.R`D:B`K/2`D8FQO8VMS
M:7IE*2!["B`@("`@("`@("`@("1P;&%I;B`]('-U8G-T<B@D8VEP:&5R=&5X
M="P@)&HL("1B;&]C:W-I>F4I.PH@("`@("`@("`@("`D9&5C<GEP=&5D("X]
M("1C:7!H97(M/F1E8W)Y<'1";&]C:R@D<&QA:6XI.PH@("`@("`@('T*"B`@
M("`@("`@+R\@4F5M;W9E('1R86EL:6YG(%PP)W,@=7-E9"!T;R!P860@=&AE
M(&QA<W0@8FQO8VLN"B`@("`@("`@=VAI;&4@*'-U8G-T<B@D9&5C<GEP=&5D
M+"`M,2P@,2D@/3T@(EPP(BD@>PH@("`@("`@("`@("`D9&5C<GEP=&5D(#T@
M<W5B<W1R*"1D96-R>7!T960L(#`L("TQ*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D9&5C<GEP=&5D.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-I<&AE
M<B]";&]C:TUO9&4O;V9B-C0N<&AP````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-#`W-@`Q,#4Q-30S,S<U,``P,C0Q-S,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]#
M:7!H97)?0FQO8VM-;V1E7V]F8C8T.CH@5&AI<R!C;&%S<R!I;7!L96UE;G1S
M('1H90H@*B!(;W)D95]#:7!H97)?0FQO8VM-;V1E('5S:6YG(&$@-C0@8FET
M(&]U='!U="!F965D8F%C:RX*("H*("H@5&AI<R!C86X@=7-E9"!T;R!E;F-R
M>7!T(&%N>2!L96YG=&@@<W1R:6YG(&%N9"!T:&4@96YC<GEP=&5D('9E<G-I
M;VX*("H@=VEL;"!B92!T:&4@<V%M92!L96YG=&@N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+T-I<&AE<B]#:7!H97(O0FQO8VM-;V1E+V]F8C8T+G!H<"QV
M(#$N-RXQ,BXU(#(P,#8O,#$O,#$@,C$Z,C@Z,3$@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`R+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F
M=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI
M:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC
M92`@($AO<F1E(#(N,@H@*B!`<&%C:V%G92!(;W)D95]#:7!H97(*("HO"F-L
M87-S($AO<F1E7T-I<&AE<E]";&]C:TUO9&5?;V9B-C0@97AT96YD<R!(;W)D
M95]#:7!H97)?0FQO8VM-;V1E('L*"B`@("`O*BH*("`@("`J($5N8W)Y<'0@
M82!S=')I;F<N"B`@("`@*@H@("`@("H@0'!A<F%M($AO<F1E7T-I<&AE<B`D
M8VEP:&5R("!#:7!H97(@86QG;W)I=&AM('1O('5S92!F;W(*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@96YC<GEP=&EO;BX*("`@("`J
M($!P87)A;2!S=')I;F<@)'!L86EN=&5X="`@("`@5&AE(&1A=&$@=&\@96YC
M<GEP="X*("`@("`J"B`@("`@*B!`<F5T=7)N("!4:&4@96YC<GEP=&5D(&1A
M=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8W)Y<'0H)B1C:7!H97(L("1P
M;&%I;G1E>'0I"B`@("!["B`@("`@("`@)&5N8W)Y<'1E9"`]("<G.PH*("`@
M("`@("`D;B`](#`["B`@("`@("`@)&I-87@@/2!S=')L96XH)'!L86EN=&5X
M="D["B`@("`@("`@9F]R("@D:B`](#`[("1J(#P@)&I-87@[("1J*RLI('L*
M("`@("`@("`@("`@:68@*"1N(#T](#`I('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?:78@/2`D8VEP:&5R+3YE;F-R>7!T0FQO8VLH)'1H:7,M/E]I=BD[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1C(#T@)'!L86EN=&5X=%LD
M:ET@7B`D=&AI<RT^7VEV6R1N73L*("`@("`@("`@("`@)&5N8W)Y<'1E9"`N
M/2`D8SL*"B`@("`@("`@("`@("1N(#T@*"LK)&XI("8@,'@P-SL*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D96YC<GEP=&5D.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1&5C<GEP="!A('-T<FEN9RX*("`@("`J"B`@("`@*B!`<&%R
M86T@2&]R9&5?0VEP:&5R("1C:7!H97(@($-I<&AE<B!A;&=O<FET:&T@=&\@
M=7-E(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D
M96-R>7!T:6]N+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VEP:&5R=&5X="`@
M("!4:&4@9&%T82!T;R!D96-R>7!T+@H@("`@("H*("`@("`J($!R971U<FX@
M(%1H92!D96-R>7!T960@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C
M<GEP="@F)&-I<&AE<BP@)&-I<&AE<G1E>'0I"B`@("!["B`@("`@("`@)&1E
M8W)Y<'1E9"`]("<G.PH*("`@("`@("`D;B`](#`["B`@("`@("`@)&I-87@@
M/2!S=')L96XH)&-I<&AE<G1E>'0I.PH@("`@("`@(&9O<B`H)&H@/2`P.R`D
M:B`\("1J36%X.R`D:BLK*2!["B`@("`@("`@("`@(&EF("@D;B`]/2`P*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEV(#T@)&-I<&AE<BT^96YC<GEP
M=$)L;V-K*"1T:&ES+3Y?:78I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D8R`]("1C:7!H97)T97AT6R1J72!>("1T:&ES+3Y?:79;)&Y=.PH@("`@
M("`@("`@("`D9&5C<GEP=&5D("X]("1C.PH*("`@("`@("`@("`@)&X@/2`H
M*RLD;BD@)B`P>#`W.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1D96-R
M>7!T960["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+T-I<&AE<B]";&]C:TUO9&4N<&AP````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,S8R,@`Q,#4Q-30S,S<U,``P,C,R-#<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M(%1H92!(;W)D95]#:7!H97)?0FQO8VM-;V1E.CH@8VQA<W,@<')O=FED97,@
M82!C;VUM;VX@86)S=')A8W1E9`H@*B!I;G1E<F9A8V4@=&\@=F%R:6]U<R!B
M;&]C:R!M;V1E(&AA;F1L97)S(&9O<B!C:7!H97)S+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]#:7!H97(O0VEP:&5R+T)L;V-K36]D92YP:'`L=B`Q+C$T
M+C$R+CD@,C`P-B\P,2\P,2`R,3HR.#HQ,"!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#(M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH
M86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#
M;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@
M2&]R9&4@,BXR"B`J($!P86-K86=E($AO<F1E7T-I<&AE<@H@*B\*8VQA<W,@
M2&]R9&5?0VEP:&5R7T)L;V-K36]D92!["@H@("`@+RHJ"B`@("`@*B!4:&4@
M:6YI=&EA;&EZ871I;VX@=F5C=&]R+@H@("`@("H*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D7VEV(#T@(EPP7#!<,%PP7#!<,%PP7#`B
M.PH*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E
M=&4@2&]R9&5?0VEP:&5R7T)L;V-K36]D92!I;G-T86YC92!B87-E9"!O;@H@
M("`@("H@)&UO9&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6]D
M92`@(%1H92!T>7!E(&]F(&-O;F-R971E($AO<F1E7T-I<&AE<E]";&]C:TUO
M9&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!S=6)C;&%S<R!T;R!R
M971U<FXN"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O
M;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@<&%R86UE=&5R<R!A"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7T-I<&AE<E]";&]C:TUO9&4@(%1H
M92!N97=L>2!C<F5A=&5D(&-O;F-R971E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@($-I<&AE<D)L;V-K36]D92!I;G-T86YC92P@
M;W(@4$5!4E]%<G)O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O
M<GDH)&UO9&4L("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@("1M;V1E
M(#T@8F%S96YA;64H)&UO9&4I.PH@("`@("`@(&EF("A`9FEL95]E>&ES=',H
M9&ER;F%M92A?7T9)3$5?7RD@+B`G+T)L;V-K36]D92\G("X@)&UO9&4@+B`G
M+G!H<"<I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?
M1DE,15]?*2`N("<O0FQO8VM-;V1E+R<@+B`D;6]D92`N("<N<&AP)SL*("`@
M("`@("!]"@H@("`@("`@("1C;&%S<R`]("=(;W)D95]#:7!H97)?0FQO8VM-
M;V1E7R<@+B`D;6]D93L*("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S
M<RDI('L*("`@("`@("`@("`@)&)L;V-K;6]D92`]("9N97<@)&-L87-S*"1P
M87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1B;&]C:VUO
M9&4@/2!014%2.CIR86ES945R<F]R*"=#;&%S<R!D969I;FET:6]N(&]F("<@
M+B`D8VQA<W,@+B`G(&YO="!F;W5N9"XG*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D8FQO8VMM;V1E.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T
M('1H92!)5@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&EV("!4:&4@
M;F5W($E6+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971)5B@D:78I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]I=B`]("1I=CL*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]#:7!H97(O8FQO=V9I<V@N<&AP````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P-3<U,#0`,3`U,34T,S,W-3``,#(S,C,U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@
M0VEP:&5R7V)L;W=F:7-H.CH@8VQA<W,@:6UP;&5M96YT<R!T:&4@0VEP:&5R
M(&EN=&5R9F%C92!E;F-R>7!T:6]N(&1A=&$*("H@=7-I;F<@=&AE($)L;W=F
M:7-H(&%L9V]R:71H;2X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO0VEP:&5R
M+T-I<&AE<B]B;&]W9FES:"YP:'`L=B`Q+C$T+C$R+CD@,C`P-B\P,2\P,2`R
M,3HR.#HQ,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-
M:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F
M=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@2&]R9&4@,BXR"B`J($!P86-K
M86=E($AO<F1E7T-I<&AE<@H@*B\*8VQA<W,@2&]R9&5?0VEP:&5R7V)L;W=F
M:7-H(&5X=&5N9',@2&]R9&5?0VEP:&5R('L*"B`@("`O*BH*("`@("`J(%!I
M($%R<F%Y"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)'`@/2!A<G)A>2@*("`@("`@("`P>#(T,T8V03@X+"`P>#@U03,P.$0S
M+"`P>#$S,3DX03)%+"`P>#`S-S`W,S0T+`H@("`@("`@(#!X030P.3,X,C(L
M(#!X,CDY1C,Q1#`L(#!X,#@R149!.3@L(#!X14,T139#.#DL"B`@("`@("`@
M,'@T-3(X,C%%-BP@,'@S.$0P,3,W-RP@,'A"134T-C9#1BP@,'@S-$4Y,$,V
M0RP*("`@("`@("`P>$,P04,R.4(W+"`P>$,Y-T,U,$1$+"`P>#-&.#1$-4(U
M+"`P>$(U-#<P.3$W+`H@("`@("`@(#!X.3(Q-D0U1#DL(#!X.#DW.49",4(I
M.PH*("`@("\J*@H@("`@("H@4R!";W@@*',Q*0H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1S,2`](&%R<F%Y*`H@("`@("`@
M(#!X1#$S,3!"038L(#!X.3A$1D(U04,L(#!X,D9&1#<R1$(L(#!X1#`Q041&
M0C<L"B`@("`@("`@,'A".$4Q049%1"P@,'@V03(V-T4Y-BP@,'A"03=#.3`T
M-2P@,'A&,3)#-T8Y.2P*("`@("`@("`P>#(T03$Y.30W+"`P>$(S.3$V0T8W
M+"`P>#`X,#%&,D4R+"`P>#@U.$5&0S$V+`H@("`@("`@(#!X-C,V.3(P1#@L
M(#!X-S$U-S1%-CDL(#!X030U.$9%03,L(#!X1C0Y,S-$-T4L"B`@("`@("`@
M,'@P1#DU-S0X1BP@,'@W,CA%0C8U."P@,'@W,3A"0T0U."P@,'@X,C$U-$%%
M12P*("`@("`@("`P>#="-31!-#%$+"`P>$,R-4$U.4(U+"`P>#E#,S!$-3,Y
M+"`P>#)!1C(V,#$S+`H@("`@("`@(#!X0S5$,4(P,C,L(#!X,C@V,#@U1C`L
M(#!X0T$T,3<Y,3@L(#!X0CA$0C,X148L"B`@("`@("`@,'@X13<Y1$-","P@
M,'@V,#-!,3@P12P@,'@V0SE%,$4X0BP@,'A",#%%.$$S12P*("`@("`@("`P
M>$0W,34W-T,Q+"`P>$)$,S$T0C(W+"`P>#<X048R1D1!+"`P>#4U-C`U0S8P
M+`H@("`@("`@(#!X138U-3(U1C,L(#!X04$U-4%".30L(#!X-3<T.#DX-C(L
M(#!X-C-%.#$T-#`L"B`@("`@("`@,'@U-4-!,SDV02P@,'@R04%",3!"-BP@
M,'A"-$-#-4,S-"P@,'@Q,30Q13A#12P*("`@("`@("`P>$$Q-30X-D%&+"`P
M>#=#-S)%.3DS+"`P>$(S144Q-#$Q+"`P>#8S-D9"0S)!+`H@("`@("`@(#!X
M,D)!.4,U-40L(#!X-S0Q.#,Q1C8L(#!X0T4U0S-%,38L(#!X.4(X-SDS,44L
M"B`@("`@("`@,'A!1D0V0D$S,RP@,'@V0S(T0T8U0RP@,'@W03,R-3,X,2P@
M,'@R.#DU.#8W-RP*("`@("`@("`P>#-".$8T.#DX+"`P>#9"-$)".4%&+"`P
M>$,T0D9%.#%"+"`P>#8V,C@R,3DS+`H@("`@("`@(#!X-C%$.#`Y0T,L(#!X
M1D(R,4$Y.3$L(#!X-#@W0T%#-C`L(#!X-41%0S@P,S(L"B`@("`@("`@,'A%
M1C@T-40U1"P@,'A%.3@U-S5",2P@,'A$0S(V,C,P,BP@,'A%0C8U,4(X."P*
M("`@("`@("`P>#(S.#DS13@Q+"`P>$0S.39!0T,U+"`P>#!&-D0V1D8S+"`P
M>#@S1C0T,C,Y+`H@("`@("`@(#!X,D4P0C0T.#(L(#!X030X-#(P,#0L(#!X
M-CE#.$8P-$$L(#!X.44Q1CE"-44L"B`@("`@("`@,'@R,4,V-C@T,BP@,'A&
M-D4Y-D,Y02P@,'@V-S!#.4,V,2P@,'A!0D0S.#A&,"P*("`@("`@("`P>#9!
M-3%!,$0R+"`P>$0X-30R1C8X+"`P>#DV,$9!-S(X+"`P>$%"-3$S,T$S+`H@
M("`@("`@(#!X-D5%1C!"-D,L(#!X,3,W03-"130L(#!X0D$S0D8P-3`L(#!X
M-T5&0C)!.3@L"B`@("`@("`@,'A!,48Q-C4Q1"P@,'@S.4%&,#$W-BP@,'@V
M-D-!-3DS12P@,'@X,C0S,$4X."P*("`@("`@("`P>#A#144X-C$Y+"`P>#0U
M-D8Y1D(T+"`P>#=$.#1!-4,S+"`P>#-".$(U14)%+`H@("`@("`@(#!X13`V
M1C<U1#@L(#!X.#5#,3(P-S,L(#!X-#`Q030T.48L(#!X-39#,39!038L"B`@
M("`@("`@,'@T140S04$V,BP@,'@S-C-&-S<P-BP@,'@Q0D9%1$8W,BP@,'@T
M,CE",#(S1"P*("`@("`@("`P>#,W1#!$-S(T+"`P>$0P,$$Q,C0X+"`P>$1"
M,$9%040S+"`P>#0Y1C%#,#E"+`H@("`@("`@(#!X,#<U,S<R0SDL(#!X.#`Y
M.3%"-T(L(#!X,C5$-#<Y1#@L(#!X1C9%.$1%1C<L"B`@("`@("`@,'A%,T9%
M-3`Q02P@,'A"-C<Y-$,S0BP@,'@Y-S9#13!"1"P@,'@P-$,P,#9"02P*("`@
M("`@("`P>$,Q03DT1D(V+"`P>#0P.48V,$,T+"`P>#5%-4,Y14,R+"`P>#$Y
M-D$R-#8S+`H@("`@("`@(#!X-CA&0C9&048L(#!X,T4V0S4S0C4L(#!X,3,S
M.4(R14(L(#!X,T(U,D5#-D8L"B`@("`@("`@,'@V1$9#-3$Q1BP@,'@Y0C,P
M.34R0RP@,'A#0S@Q-#4T-"P@,'A!1C5%0D0P.2P*("`@("`@("`P>$)%13-$
M,#`T+"`P>$1%,S,T049$+"`P>#8V,$8R.#`W+"`P>#$Y,D4T0D(S+`H@("`@
M("`@(#!X0S!#0D$X-3<L(#!X-#5#.#<T,$8L(#!X1#(P0C5&,SDL(#!X0CE$
M,T9"1$(L"B`@("`@("`@,'@U-3<Y0S!"1"P@,'@Q038P,S(P02P@,'A$-D$Q
M,#!#-BP@,'@T,#)#-S(W.2P*("`@("`@("`P>#8W.48R-49%+"`P>$9",49!
M,T-#+"`P>#A%035%.48X+"`P>$1",S(R,D8X+`H@("`@("`@(#!X,T,W-3$V
M1$8L(#!X1D0V,39",34L(#!X,D8U,#%%0S@L(#!X040P-34R04(L"B`@("`@
M("`@,'@S,C-$0C5&02P@,'A&1#(S.#<V,"P@,'@U,S,Q-T(T."P@,'@S13`P
M1$8X,BP*("`@("`@("`P>#E%-4,U-T)"+"`P>$-!-D8X0T$P+"`P>#%!.#<U
M-C)%+"`P>$1&,3<V.41"+`H@("`@("`@(#!X1#4T,D$X1C8L(#!X,C@W149&
M0S,L(#!X04,V-S,R0S8L(#!X.$,T1C4U-S,L"B`@("`@("`@,'@V.35",C="
M,"P@,'A"0D-!-3A#."P@,'A%,49&03,U1"P@,'A".$8P,3%!,"P*("`@("`@
M("`P>#$P1D$S1#DX+"`P>$9$,C$X,T(X+"`P>#1!1D-"-39#+"`P>#)$1#%$
M,S5"+`H@("`@("`@(#!X.4$U,T4T-SDL(#!X0C9&.#0U-C4L(#!X1#(X130Y
M0D,L(#!X-$)&0CDW.3`L"B`@("`@("`@,'A%,41$1C)$02P@,'A!-$-"-T4S
M,RP@,'@V,D9",3,T,2P@,'A#144T0S9%."P*("`@("`@("`P>$5&,C!#041!
M+"`P>#,V-S<T0S`Q+"`P>$0P-T4Y149%+"`P>#)"1C$Q1D(T+`H@("`@("`@
M(#!X.35$0D1!-$0L(#!X044Y,#DQ.3@L(#!X14%!1#A%-S$L(#!X-D(Y,T0U
M03`L"B`@("`@("`@,'A$,#A%1#%$,"P@,'A!1D,W,C5%,"P@,'@X13-#-4(R
M1BP@,'@X13<U.31"-RP*("`@("`@("`P>#A&1C9%,D9"+"`P>$8R,3(R0C8T
M+"`P>#@X.#A".#$R+"`P>#DP,$1&,#%#+`H@("`@("`@(#!X-$9!1#5%03`L
M(#!X-C@X1D,S,4,L(#!X1#%#1D8Q.3$L(#!X0C-!.$,Q040L"B`@("`@("`@
M,'@R1C)&,C(Q."P@,'A"13!%,3<W-RP@,'A%03<U,D1&12P@,'@X0C`R,49!
M,2P*("`@("`@("`P>$4U03!#0S!&+"`P>$(U-D8W-$4X+"`P>#$X04-&,T0V
M+"`P>$-%.#E%,CDY+`H@("`@("`@(#!X0C1!.#1&13`L(#!X1D0Q,T4P0C<L
M(#!X-T-#-#-".#$L(#!X1#)!1$$X1#DL"B`@("`@("`@,'@Q-C5&03(V-BP@
M,'@X,#DU-S<P-2P@,'@Y,T-#-S,Q-"P@,'@R,3%!,30W-RP*("`@("`@("`P
M>$4V040R,#8U+"`P>#<W0C5&03@V+"`P>$,W-30T,D8U+"`P>$9".40S-4-&
M+`H@("`@("`@(#!X14)#1$%&,$,L(#!X-T(S13@Y03`L(#!X1#8T,3%"1#,L
M(#!X044Q13=%-#DL"B`@("`@("`@,'@P,#(U,$4R1"P@,'@R,#<Q0C,U12P@
M,'@R,C8X,#!"0BP@,'@U-T(X13!!1BP*("`@("`@("`P>#(T-C0S-CE"+"`P
M>$8P,#E".3%%+"`P>#4U-C,Y,3%$+"`P>#4Y1$9!-D%!+`H@("`@("`@(#!X
M-SA#,30S.#DL(#!X1#DU034S-T8L(#!X,C`W1#5"03(L(#!X,#)%-4(Y0S4L
M"B`@("`@("`@,'@X,S(V,#,W-BP@,'@V,CDU0T9!.2P@,'@Q,4,X,3DV."P@
M,'@T13<S-$$T,2P*("`@("`@("`P>$(S-#<R1$-!+"`P>#=",31!.31!+"`P
M>#%"-3$P,#4R+"`P>#E!-3,R.3$U+`H@("`@("`@(#!X1#8P1C4W,T8L(#!X
M0D,Y0D,V130L(#!X,D(V,$$T-S8L(#!X.#%%-C<T,#`L"B`@("`@("`@,'@P
M.$)!-D9"-2P@,'@U-S%"13DQ1BP@,'A&,CDV14,V0BP@,'@R03!$1#DQ-2P*
M("`@("`@("`P>$(V-C,V-3(Q+"`P>$4W0CE&.4(V+"`P>$9&,S0P-3)%+"`P
M>$,U.#4U-C8T+`H@("`@("`@(#!X-3-",#)$-40L(#!X03DY1CA&03$L(#!X
M,#A"030W.3DL(#!X-D4X-3`W-D$I.PH*("`@("\J*@H@("`@("H@4R!";W@@
M*',R*0H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1S,B`](&%R<F%Y*`H@("`@("`@(#!X-$(W03<P13DL(#!X0C5",S(Y-#0L
M(#!X1$(W-3`Y,D4L(#!X0S0Q.3(V,C,L"B`@("`@("`@,'A!1#9%039","P@
M,'@T.4$W1$8W1"P@,'@Y0T5%-C!"."P@,'@X1D5$0C(V-BP*("`@("`@("`P
M>$5#04$X0S<Q+"`P>#8Y.4$Q-T9&+"`P>#4V-C0U,C9#+"`P>$,R0C$Y144Q
M+`H@("`@("`@(#!X,3DS-C`R034L(#!X-S4P.31#,CDL(#!X03`U.3$S-#`L
M(#!X130Q.#-!,T4L"B`@("`@("`@,'@S1C4T.3@Y02P@,'@U0C0R.40V-2P@
M,'@V0CA&131$-BP@,'@Y.48W,T9$-BP*("`@("`@("`P>$$Q1#(Y0S`W+"`P
M>$5&13@S,$8U+"`P>#1$,D0S.$4V+"`P>$8P,C4U1$,Q+`H@("`@("`@(#!X
M-$-$1#(P.#8L(#!X.#0W,$5",C8L(#!X-C,X,D4Y0S8L(#!X,#(Q14-#-44L
M"B`@("`@("`@,'@P.38X-D(S1BP@,'@S14)!149#.2P@,'@S0SDW,3@Q-"P@
M,'@V0C9!-S!!,2P*("`@("`@("`P>#8X-T8S-3@T+"`P>#4R03!%,C@V+"`P
M>$(W.4,U,S`U+"`P>$%!-3`P-S,W+`H@("`@("`@(#!X,T4P-S@T,4,L(#!X
M-T9$14%%-4,L(#!X.$4W1#0T14,L(#!X-3<Q-D8R0C@L"B`@("`@("`@,'A"
M,#-!1$$S-RP@,'A&,#4P,$,P1"P@,'A&,#%#,48P-"P@,'@P,C`P0C-&1BP*
M("`@("`@("`P>$%%,$-&-3%!+"`P>#-#0C4W-$(R+"`P>#(U.#,W034X+"`P
M>$1#,#DR,4)$+`H@("`@("`@(#!X1#$Y,3$S1CDL(#!X-T-!.3)&1C8L(#!X
M.30S,C0W-S,L(#!X,C)&-30W,#$L"B`@("`@("`@,'@S044U134X,2P@,'@S
M-T,R1$%$0RP@,'A#.$(U-S8S-"P@,'@Y048S1$1!-RP*("`@("`@("`P>$$Y
M-#0V,30V+"`P>#!&1#`P,S!%+"`P>$5#0SA#-S-%+"`P>$$T-S4Q130Q+`H@
M("`@("`@(#!X13(S.$-$.3DL(#!X,T)%03!%,D8L(#!X,S(X,$)"03$L(#!X
M,3@S14(S,S$L"B`@("`@("`@,'@T134T.$(S."P@,'@T1C9$0CDP."P@,'@V
M1C0R,$0P,RP@,'A&-C!!,#1"1BP*("`@("`@("`P>#)#0C@Q,CDP+"`P>#(T
M.3<W0S<Y+"`P>#4V-SE",#<R+"`P>$)#048X.4%&+`H@("`@("`@(#!X1$4Y
M03<W,48L(#!X1#DY,S`X,3`L(#!X0C,X0D%%,3(L(#!X1$-#1C-&,D4L"B`@
M("`@("`@,'@U-3$R-S(Q1BP@,'@R139"-S$R-"P@,'@U,#%!1$1%-BP@,'@Y
M1C@T0T0X-RP*("`@("`@("`P>#=!-3@T-S$X+"`P>#<T,#A$03$W+"`P>$)#
M.48Y04)#+"`P>$4Y-$(W1#A#+`H@("`@("`@(#!X14,W045#,T$L(#!X1$(X
M-3%$1D$L(#!X-C,P.30S-C8L(#!X0S0V-$,S1#(L"B`@("`@("`@,'A%1C%#
M,3@T-RP@,'@S,C$U1#DP."P@,'A$1#0S,T(S-RP@,'@R-$,R0D$Q-BP*("`@
M("`@("`P>#$R03$T1#0S+"`P>#)!-C5#-#4Q+"`P>#4P.30P,#`R+"`P>#$S
M,T%%-$1$+`H@("`@("`@(#!X-S%$1D8X.44L(#!X,3`S,31%-34L(#!X.#%!
M0S<W1#8L(#!X-48Q,3$Y.4(L"B`@("`@("`@,'@P-#,U-39&,2P@,'A$-T$S
M0S<V0BP@,'@S0S$Q,3@S0BP@,'@U.3(T034P.2P*("`@("`@("`P>$8R.$9%
M-D5$+"`P>#DW1C%&0D9!+"`P>#E%0D%"1C)#+"`P>#%%,34S0S9%+`H@("`@
M("`@(#!X.#9%,S0U-S`L(#!X14%%.39&0C$L(#!X.#8P135%,$$L(#!X-4$S
M13)!0C,L"B`@("`@("`@,'@W-S%&13<Q0RP@,'@T13-$,#9&02P@,'@R.38U
M1$-".2P@,'@Y.44W,40P1BP*("`@("`@("`P>#@P,T4X.40V+"`P>#4R-C9#
M.#(U+"`P>#)%-$-#.3<X+"`P>#E#,3!",S9!+`H@("`@("`@(#!X0S8Q-3!%
M0D$L(#!X.31%,D5!-S@L(#!X035&0S-#-3,L(#!X,44P03)$1C0L"B`@("`@
M("`@,'A&,D8W-$5!-RP@,'@S-C%$,D(S1"P@,'@Q.3,Y,C8P1BP@,'@Q.4,R
M-SDV,"P*("`@("`@("`P>#4R,C-!-S`X+"`P>$8W,3,Q,D(V+"`P>$5"041&
M139%+"`P>$5!0S,Q1C8V+`H@("`@("`@(#!X13-"0S0U.34L(#!X038W0D,X
M.#,L(#!X0C$W1C,W1#$L(#!X,#$X0T9&,C@L"B`@("`@("`@,'A#,S,R1$1%
M1BP@,'A"139#-4%!-2P@,'@V-34X,C$X-2P@,'@V.$%".3@P,BP*("`@("`@
M("`P>$5%0T5!-3!&+"`P>$1",D8Y-3-"+"`P>#)!148W1$%$+"`P>#5"-D4R
M1C@T+`H@("`@("`@(#!X,34R,4(V,C@L(#!X,CDP-S8Q-S`L(#!X14-$1#0W
M-S4L(#!X-C$Y1C$U,3`L"B`@("`@("`@,'@Q,T-#03@S,"P@,'A%0C8Q0D0Y
M-BP@,'@P,S,T1D4Q12P@,'A!03`S-C-#1BP*("`@("`@("`P>$(U-S,U0SDP
M+"`P>#1#-S!!,C,Y+"`P>$0U.44Y13!"+"`P>$-"04%$13$T+`H@("`@("`@
M(#!X145#0S@V0D,L(#!X-C`V,C)#03<L(#!X.4-!0C5#04(L(#!X0C)&,S@T
M-D4L"B`@("`@("`@,'@V-#A",45!1BP@,'@Q.4)$1C!#02P@,'A!,#(S-CE"
M.2P@,'@V-35!0D(U,"P*("`@("`@("`P>#0P-C@U03,R+"`P>#-#,D%"-$(S
M+"`P>#,Q.45%.40U+"`P>$,P,C%".$8W+`H@("`@("`@(#!X.4(U-#!",3DL
M(#!X.#<U1D$P.3DL(#!X.35&-SDY-T4L(#!X-C(S1#=$03@L"B`@("`@("`@
M,'A&.#,W.#@Y02P@,'@Y-T4S,D0W-RP@,'@Q,45$.3,U1BP@,'@Q-C8X,3(X
M,2P*("`@("`@("`P>#!%,S4X.#(Y+"`P>$,W138Q1D0V+"`P>#DV1$5$1D$Q
M+"`P>#<X-3A"03DY+`H@("`@("`@(#!X-3=&-3@T034L(#!X,4(R,C<R-C,L
M(#!X.4(X,T,S1D8L(#!X,4%#,C0V.38L"B`@("`@("`@,'A#1$(S,$%%0BP@
M,'@U,S)%,S`U-"P@,'@X1D0Y-#A%-"P@,'@V1$)#,S$R."P*("`@("`@("`P
M>#4X14)&,D5&+"`P>#,T0S9&1D5!+"`P>$9%,CA%1#8Q+"`P>$5%-T,S0S<S
M+`H@("`@("`@(#!X-40T03$T1#DL(#!X13@V-$(W13,L(#!X-#(Q,#5$,30L
M(#!X,C`S13$S13`L"B`@("`@("`@,'@T-45%13)"-BP@,'A!,T%!04)%02P@
M,'A$0C9#-$8Q-2P@,'A&04-"-$9$,"P*("`@("`@("`P>$,W-#)&-#0R+"`P
M>$5&-D%"0D(U+"`P>#8U-$8S0C%$+"`P>#0Q0T0R,3`U+`H@("`@("`@(#!X
M1#@Q13<Y.44L(#!X.#8X-31$0S<L(#!X130T0C0W-D$L(#!X,T0X,38R-3`L
M"B`@("`@("`@,'A#1C8R03%&,BP@,'@U0CA$,C8T-BP@,'A&0S@X.#-!,"P@
M,'A#,4,W0C9!,RP*("`@("`@("`P>#=&,34R-$,S+"`P>#8Y0T(W-#DR+"`P
M>#0W.#0X03!"+"`P>#4V.3)",C@U+`H@("`@("`@(#!X,#DU0D)&,#`L(#!X
M040Q.30X.40L(#!X,30V,D(Q-S0L(#!X,C,X,C!%,#`L"B`@("`@("`@,'@U
M.#0R.$0R02P@,'@P0S4U1C5%02P@,'@Q1$%$1C0S12P@,'@R,S-&-S`V,2P*
M("`@("`@("`P>#,S-S)&,#DR+"`P>#A$.3,W130Q+"`P>$0V-49%0T8Q+"`P
M>#9#,C(S0D1"+`H@("`@("`@(#!X-T-$13,W-3DL(#!X0T)%13<T-C`L(#!X
M-#`X-48R03<L(#!X0T4W-S,R-D4L"B`@("`@("`@,'A!-C`W.#`X-"P@,'@Q
M.48X-3`Y12P@,'A%.$5&1#@U-2P@,'@V,40Y.3<S-2P*("`@("`@("`P>$$Y
M-CE!-T%!+"`P>$,U,$,P-D,R+"`P>#5!,#1!0D9#+"`P>#@P,$)#041#+`H@
M("`@("`@(#!X.44T-#=!,D4L(#!X0S,T-3,T.#0L(#!X1D1$-38W,#4L(#!X
M,$4Q13E%0SDL"B`@("`@("`@,'A$0C<S1$)$,RP@,'@Q,#4U.#A#1"P@,'@V
M-S5&1$$W.2P@,'A%,S8W-#,T,"P*("`@("`@("`P>$,U0S0S-#8U+"`P>#<Q
M,T4S.$0X+"`P>#-$,CA&.#E%+"`P>$8Q-D1&1C(P+`H@("`@("`@(#!X,34S
M13(Q13<L(#!X.$9",#-$-$$L(#!X139%,SE&,D(L(#!X1$(X,T%$1C<I.PH*
M("`@("\J*@H@("`@("H@4R!";W@@*',S*0H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1S,R`](&%R<F%Y*`H@("`@("`@(#!X
M13DS1#5!-C@L(#!X.30X,30P1C<L(#!X1C8T0S(V,4,L(#!X.30V.3(Y,S0L
M"B`@("`@("`@,'@T,3$U,C!&-RP@,'@W-C`R1#1&-RP@,'A"0T8T-D(R12P@
M,'A$-$$R,#`V."P*("`@("`@("`P>$0T,#@R-#<Q+"`P>#,S,C!&-#9!+"`P
M>#0S0C=$-$(W+"`P>#4P,#`V,4%&+`H@("`@("`@(#!X,44S.48V,D4L(#!X
M.3<R-#0U-#8L(#!X,30R,31&-S0L(#!X0D8X0C@X-#`L"B`@("`@("`@,'@T
M1#DU1D,Q1"P@,'@Y-D(U.3%!1BP@,'@W,$8T1$1$,RP@,'@V-D$P,D8T-2P*
M("`@("`@("`P>$)&0D,P.45#+"`P>#`S0D0Y-S@U+"`P>#=&04,V1$0P+"`P
M>#,Q0T(X-3`T+`H@("`@("`@(#!X.39%0C(W0C,L(#!X-35&1#,Y-#$L(#!X
M1$$R-30W138L(#!X04)#03!!.4$L"B`@("`@("`@,'@R.#4P-S@R-2P@,'@U
M,S`T,CE&-"P@,'@P03)#.#9$02P@,'A%.4(V-D1&0BP*("`@("`@("`P>#8X
M1$,Q-#8R+"`P>$0W-#@V.3`P+"`P>#8X,$5#,$$T+"`P>#(W03$X1$5%+`H@
M("`@("`@(#!X-$8S1D9%03(L(#!X13@X-T%$.$,L(#!X0C4X0T4P,#8L(#!X
M-T%&-$0V0C8L"B`@("`@("`@,'A!04-%,44W0RP@,'A$,S,W-49%0RP@,'A#
M13<X03,Y.2P@,'@T,#9",D$T,BP*("`@("`@("`P>#(P1D4Y13,U+"`P>$0Y
M1C,X-4(Y+"`P>$5%,SE$-T%"+"`P>#-",3(T13A"+`H@("`@("`@(#!X,41#
M.49!1C<L(#!X-$(V1#$X-38L(#!X,C9!,S8V,S$L(#!X14%%,SDW0C(L"B`@
M("`@("`@,'@S039%1D$W-"P@,'A$1#5"-#,S,BP@,'@V.#0Q13=&-RP@,'A#
M03<X,C!&0BP*("`@("`@("`P>$9",$%&-31%+"`P>$0X1D5",SDW+"`P>#0U
M-#`U-D%#+"`P>$)!-#@Y-3(W+`H@("`@("`@(#!X-34U,S-!,T$L(#!X,C`X
M,SA$.#<L(#!X1D4V0D$Y0C<L(#!X1#`Y-CDU-$(L"B`@("`@("`@,'@U-4$X
M-C="0RP@,'A!,3$U.4$U."P@,'A#0T$Y,CDV,RP@,'@Y.44Q1$(S,RP*("`@
M("`@("`P>$$V,D$T034V+"`P>#-&,S$R-48Y+"`P>#5%1C0W13%#+"`P>#DP
M,CDS,3=#+`H@("`@("`@(#!X1D1&.$4X,#(L(#!X,#0R-S)&-S`L(#!X.#!"
M0C$U-4,L(#!X,#4R.#)#13,L"B`@("`@("`@,'@Y-4,Q,34T."P@,'A%-$,V
M-D0R,BP@,'@T.$,Q,3,S1BP@,'A#-S!&.#9$0RP*("`@("`@("`P>#`W1CE#
M.45%+"`P>#0Q,#0Q1C!&+"`P>#0P-#<W.4$T+"`P>#5$.#@V13$W+`H@("`@
M("`@(#!X,S(U1C4Q14(L(#!X1#4Y0D,P1#$L(#!X1C)"0T,Q.$8L(#!X-#$Q
M,3,U-C0L"B`@("`@("`@,'@R-3="-S@S-"P@,'@V,#)!.4,V,"P@,'A$1D8X
M13A!,RP@,'@Q1C8S-D,Q0BP*("`@("`@("`P>#!%,3)"-$,R+"`P>#`R13$S
M,CE%+"`P>$%&-C8T1D0Q+"`P>$-!1#$X,3$U+`H@("`@("`@(#!X-D(R,SDU
M13`L(#!X,S,S13DR13$L(#!X,T(R-#!"-C(L(#!X145"14(Y,C(L"B`@("`@
M("`@,'@X-4(R03(P12P@,'A%-D)!,$0Y.2P@,'A$13<R,$,X0RP@,'@R1$$R
M1C<R."P*("`@("`@("`P>$0P,3(W.#0U+"`P>#DU0C<Y-$9$+"`P>#8T-T0P
M.#8R+"`P>$4W0T-&-48P+`H@("`@("`@(#!X-30T.4$S-D8L(#!X.#<W1#0X
M1D$L(#!X0S,Y1$9$,C<L(#!X1C,S13A$,44L"B`@("`@("`@,'@P030W-C,T
M,2P@,'@Y.3)%1D8W-"P@,'@S039&-D5!0BP@,'A&-$8X1D0S-RP*("`@("`@
M("`P>$$X,3)$0S8P+"`P>$$Q14)$1$8X+"`P>#DY,4)%,31#+"`P>$1"-D4V
M0C!$+`H@("`@("`@(#!X0S8W0C4U,3`L(#!X-D0V-S)#,S<L(#!X,C<V-40T
M,T(L(#!X1$-$,$4X,#0L"B`@("`@("`@,'A&,3(Y,$1#-RP@,'A#0S`P1D9!
M,RP@,'A"-3,Y,$8Y,BP@,'@V.3!&140P0BP*("`@("`@("`P>#8V-T(Y1D9"
M+"`P>$-%1$(W1#E#+"`P>$$P.3%#1C!"+"`P>$0Y,34U14$S+`H@("`@("`@
M(#!X0D(Q,S)&.#@L(#!X-3$U0D%$,C0L(#!X-T(Y-#<Y0D8L(#!X-S8S0D0V
M14(L"B`@("`@("`@,'@S-S,Y,D5",RP@,'A#0S$Q-3DW.2P@,'@X,#(V13(Y
M-RP@,'A&-#)%,S$R1"P*("`@("`@("`P>#8X-#)!1$$W+"`P>$,V-D$R0C-"
M+"`P>#$R-S4T0T-#+"`P>#<X,D5&,3%#+`H@("`@("`@(#!X-D$Q,C0R,S<L
M(#!X0C<Y,C4Q13<L(#!X,#9!,4)"138L(#!X-$)&0C8S-3`L"B`@("`@("`@
M,'@Q039",3`Q."P@,'@Q,4-!141&02P@,'@S1#(U0D1$."P@,'A%,D4Q0S-#
M.2P*("`@("`@("`P>#0T-#(Q-C4Y+"`P>#!!,3(Q,S@V+"`P>$0Y,$-%0S9%
M+"`P>$0U04)%03)!+`H@("`@("`@(#!X-C1!1C8W-$4L(#!X1$$X-D$X-48L
M(#!X0D5"1D4Y.#@L(#!X-C1%-$,S1D4L"B`@("`@("`@,'@Y1$)#.#`U-RP@
M,'A&,$8W0S`X-BP@,'@V,#<X-T)&."P@,'@V,#`S-C`T1"P*("`@("`@("`P
M>$0Q1D0X,S0V+"`P>$8V,S@Q1D(P+"`P>#<W-#5!13`T+"`P>$0W,S9&0T-#
M+`H@("`@("`@(#!X.#,T,C9",S,L(#!X1C`Q14%"-S$L(#!X0C`X,#0Q.#<L
M(#!X,T,P,#5%-48L"B`@("`@("`@,'@W-T$P-3="12P@,'A"1$4X044R-"P@
M,'@U-30V-#(Y.2P@,'A"1C4X,D4V,2P*("`@("`@("`P>#1%-3A&-#A&+"`P
M>$8R1$1&1$$R+"`P>$8T-S1%1C,X+"`P>#@W.#E"1$,R+`H@("`@("`@(#!X
M-3,V-D8Y0S,L(#!X0SA",SA%-S0L(#!X0C0W-48R-34L(#!X-#9&0T0Y0CDL
M"B`@("`@("`@,'@W045",C8V,2P@,'@X0C%$1$8X-"P@,'@X-#9!,$4W.2P@
M,'@Y,35&.35%,BP*("`@("`@("`P>#0V-D4U.3A%+"`P>#(P0C0U-S<P+"`P
M>#A#1#4U-3DQ+"`P>$,Y,#)$131#+`H@("`@("`@(#!X0CDP0D%#13$L(#!X
M0D(X,C`U1#`L(#!X,3%!.#8R-#@L(#!X-S4W-$$Y.44L"B`@("`@("`@,'A"
M-S=&,3E"-BP@,'A%,$$Y1$,P.2P@,'@V-C)$,#E!,2P@,'A#-#,R-#8S,RP*
M("`@("`@("`P>$4X-4$Q1C`R+"`P>#`Y1C!"13A#+"`P>#1!.3E!,#(U+"`P
M>#%$-D5&13$P+`H@("`@("`@(#!X,4%".3-$,40L(#!X,$)!-4$T1$8L(#!X
M03$X-D8R,$8L(#!X,C@V.$8Q-CDL"B`@("`@("`@,'A$0T(W1$$X,RP@,'@U
M-S,Y,#9&12P@,'A!,44R0T4Y0BP@,'@T1D-$-T8U,BP*("`@("`@("`P>#4P
M,3$U13`Q+"`P>$$W,#8X,T9!+"`P>$$P,#)"-4,T+"`P>#!$139$,#(W+`H@
M("`@("`@(#!X.4%&.#A#,C<L(#!X-S<S1C@V-#$L(#!X0S,V,#1#,#8L(#!X
M-C%!.#`V0C4L"B`@("`@("`@,'A&,#$W-T$R."P@,'A#,$8U.#9%,"P@,'@P
M,#8P-3A!02P@,'@S,$1#-T0V,BP*("`@("`@("`P>#$Q138Y140W+"`P>#(S
M,SA%038S+"`P>#4S0S)$1#DT+"`P>$,R0S(Q-C,T+`H@("`@("`@(#!X0D)#
M0D5%-38L(#!X.3!"0T(V1$4L(#!X14)&0S=$03$L(#!X0T4U.3%$-S8L"B`@
M("`@("`@,'@V1C`U130P.2P@,'@T0C=#,#$X."P@,'@S.3<R,$$S1"P@,'@W
M0SDR-T,R-"P*("`@("`@("`P>#@V13,W,C5&+"`P>#<R-$0Y1$(Y+"`P>#%!
M0S$U0D(T+"`P>$0S.45".$9#+`H@("`@("`@(#!X140U-#4U-S@L(#!X,#A&
M0T$U0C4L(#!X1#@S1#=#1#,L(#!X-$1!1#!&0S0L"B`@("`@("`@,'@Q134P
M148U12P@,'A",38Q139&."P@,'A!,C@U,31$.2P@,'@V0S4Q,3,S0RP*("`@
M("`@("`P>#9&1#5#-T4W+"`P>#4V13$T14,T+"`P>#,V,D%"1D-%+"`P>$1$
M0S9#.#,W+`H@("`@("`@(#!X1#<Y03,R,S0L(#!X.3(V,S@R,3(L(#!X-C<P
M149!.$4L(#!X-#`V,#`P13`I.PH*("`@("\J*@H@("`@("H@4R!";W@@*',T
M*0H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1S
M-"`](&%R<F%Y*`H@("`@("`@(#!X,T$S.4-%,S<L(#!X1#-&048U0T8L(#!X
M04)#,C<W,S<L(#!X-4%#-3)$,4(L"B`@("`@("`@,'@U0T(P-C<Y12P@,'@T
M1D$S,S<T,BP@,'A$,S@R,C<T,"P@,'@Y.4)#.4)"12P*("`@("`@("`P>$0U
M,3$X13E$+"`P>$)&,$8W,S$U+"`P>$0V,D0Q0S=%+"`P>$,W,#!#-#="+`H@
M("`@("`@(#!X0C<X0S%"-D(L(#!X,C%!,3DP-#4L(#!X0C(V14(Q0D4L(#!X
M-D$S-C9%0C0L"B`@("`@("`@,'@U-S0X04(R1BP@,'A"0SDT-D4W.2P@,'A#
M-D$S-S9$,BP@,'@V-30Y0S)#."P*("`@("`@("`P>#4S,$9&.$5%+"`P>#0V
M.$1$13=$+"`P>$0U-S,P03%$+"`P>#1#1#`T1$,V+`H@("`@("`@(#!X,CDS
M.4)"1$(L(#!X03E"030V-3`L(#!X04,Y-3(V13@L(#!X0D4U144S,#0L"B`@
M("`@("`@,'A!,49!1#5&,"P@,'@V03)$-3$Y02P@,'@V,T5&.$-%,BP@,'@Y
M03@V144R,BP*("`@("`@("`P>$,P.#E#,D(X+"`P>#0S,C0R148V+"`P>$$U
M,44P,T%!+"`P>#E#1C)$,$$T+`H@("`@("`@(#!X.#-#,#8Q0D$L(#!X.4)%
M.39!-$0L(#!X.$9%-3$U-3`L(#!X0D$V-#5"1#8L"B`@("`@("`@,'@R.#(V
M03)&.2P@,'A!-S-!,T%%,2P@,'@T0D$Y.34X-BP@,'A%1C4U-C)%.2P*("`@
M("`@("`P>$,W,D9%1D0S+"`P>$8W-3)&-T1!+"`P>#-&,#0V1C8Y+"`P>#<W
M1D$P034Y+`H@("`@("`@(#!X.#!%-$$Y,34L(#!X.#=",#@V,#$L(#!X.4(P
M.44V040L(#!X,T(S144U.3,L"B`@("`@("`@,'A%.3DP1D0U02P@,'@Y13,T
M1#<Y-RP@,'@R0T8P0C=$.2P@,'@P,C)".$(U,2P*("`@("`@("`P>#DV1#5!
M0S-!+"`P>#`Q-T1!-C=$+"`P>$0Q0T8S140V+"`P>#=#-T0R1#(X+`H@("`@
M("`@(#!X,48Y1C(U0T8L(#!X041&,D(X.4(L(#!X-4%$-D(T-S(L(#!X-4$X
M.$8U-$,L"B`@("`@("`@,'A%,#(Y04,W,2P@,'A%,#$Y035%-BP@,'@T-T(P
M04-&1"P@,'A%1#DS1D$Y0BP*("`@("`@("`P>$4X1#-#-#A$+"`P>#(X,T(U
M-T-#+"`P>$8X1#4V-C(Y+"`P>#<Y,3,R13(X+`H@("`@("`@(#!X-S@U1C`Q
M.3$L(#!X140W-38P-34L(#!X1C<Y-C!%-#0L(#!X13-$,S5%.$,L"B`@("`@
M("`@,'@Q-3`U-D1$-"P@,'@X.$8T-D1"02P@,'@P,T$Q-C$R-2P@,'@P-38T
M1C!"1"P*("`@("`@("`P>$,S14(Y13$U+"`P>#-#.3`U-T$R+"`P>#DW,C<Q
M045#+"`P>$$Y,T$P-S)!+`H@("`@("`@(#!X,4(S1C9$.4(L(#!X,44V,S(Q
M1C4L(#!X1C4Y0S8V1D(L(#!X,C9$0T8S,3DL"B`@("`@("`@,'@W-3,S1#DR
M."P@,'A",34U1D1&-2P@,'@P,S4V,S0X,BP@,'@X04)!,T-"0BP*("`@("`@
M("`P>#(X-3$W-S$Q+"`P>$,R,$%$.48X+"`P>$%"0T,U,38W+"`P>$-#040Y
M,C5&+`H@("`@("`@(#!X-$1%.#$W-3$L(#!X,S@S,$1#.$4L(#!X,S<Y1#4X
M-C(L(#!X.3,R,$8Y.3$L"B`@("`@("`@,'A%03=!.3!#,BP@,'A&0C-%-T)#
M12P@,'@U,3(Q0T4V-"P@,'@W-S1&0D4S,BP*("`@("`@("`P>$$X0C9%,S=%
M+"`P>$,S,CDS1#0V+"`P>#0X1$4U,S8Y+"`P>#8T,3-%-C@P+`H@("`@("`@
M(#!X03)!13`X,3`L(#!X1$0V1$(R,C0L(#!X-CDX-3)$1D0L(#!X,#DP-S(Q
M-C8L"B`@("`@("`@,'A",SE!-#8P02P@,'@V-#0U0S!$1"P@,'@U.#9#1$5#
M1BP@,'@Q0S(P0SA!12P*("`@("`@("`P>#5"0D5&-T1$+"`P>#%"-3@X1#0P
M+"`P>$-#1#(P,3=&+"`P>#9"0C1%,T)"+`H@("`@("`@(#!X1$1!,C9!-T4L
M(#!X,T$U.49&-#4L(#!X,T4S-3!!-#0L(#!X0D-"-$-$1#4L"B`@("`@("`@
M,'@W,D5!0T5!."P@,'A&038T.#1"0BP@,'@X1#8V,3)!12P@,'A"1C-#-D8T
M-RP*("`@("`@("`P>$0R.4)%-#8S+"`P>#4T,D8U1#E%+"`P>$%%0S(W-S%"
M+"`P>$8V-$4V,S<P+`H@("`@("`@(#!X-S0P13!$.$0L(#!X13<U0C$S-3<L
M(#!X1C@W,C$V-S$L(#!X048U,S=$-40L"B`@("`@("`@,'@T,#0P0T(P."P@
M,'@T14(T13)#0RP@,'@S-$0R-#8V02P@,'@P,3$U048X-"P*("`@("`@("`P
M>$4Q0C`P-#(X+"`P>#DU.3@S03%$+"`P>#`V0C@Y1D(T+"`P>$-%-D5!,#0X
M+`H@("`@("`@(#!X-D8S1C-".#(L(#!X,S4R,$%".#(L(#!X,#$Q03%$-$(L
M(#!X,C<W,C(W1C@L"B`@("`@("`@,'@V,3$U-C!",2P@,'A%-SDS,T9$0RP@
M,'A"0C-!-SDR0BP@,'@S-#0U,C5"1"P*("`@("`@("`P>$$P.#@S.44Q+"`P
M>#4Q0T4W.31"+"`P>#)&,S)#.4(W+"`P>$$P,49"04,Y+`H@("`@("`@(#!X
M13`Q0T,X-T4L(#!X0D-#-T0Q1C8L(#!X0T8P,3$Q0S,L(#!X03%%.$%!0S<L
M"B`@("`@("`@,'@Q03DP.#<T.2P@,'A$-#1&0D0Y02P@,'A$,$1!1$5#0BP@
M,'A$-3!!1$$S."P*("`@("`@("`P>#`S,SE#,S)!+"`P>$,V.3$S-C8W+"`P
M>#A$1CDS,3=#+"`P>$4P0C$R0C1&+`H@("`@("`@(#!X1C<Y134Y0C<L(#!X
M-#-&-4)",T$L(#!X1C)$-3$Y1D8L(#!X,C=$.30U.4,L"B`@("`@("`@,'A"
M1CDW,C(R0RP@,'@Q-44V1D,R02P@,'@P1CDQ1D,W,2P@,'@Y0CDT,34R-2P*
M("`@("`@("`P>$9!134Y,S8Q+"`P>$-%0C8Y0T5"+"`P>$,R03@V-#4Y+"`P
M>#$R0D%!.$0Q+`H@("`@("`@(#!X0C9#,3`W-44L(#!X13,P-39!,$,L(#!X
M,3!$,C4P-C4L(#!X0T(P,T$T-#(L"B`@("`@("`@,'A%,$5#-D4P12P@,'@Q
M-CDX1$(S0BP@,'@T0SDX03!"12P@,'@S,C<X13DV-"P*("`@("`@("`P>#E&
M,48Y-3,R+"`P>$4P1#,Y,D1&+"`P>$0S03`S-#)"+"`P>#@Y-S%&,C%%+`H@
M("`@("`@(#!X,4(P03<T-#$L(#!X-$)!,S,T.$,L(#!X0S5"13<Q,C`L(#!X
M0S,W-C,R1#@L"B`@("`@("`@,'A$1C,U.48X1"P@,'@Y0CDY,D8R12P@,'A%
M-C!"-D8T-RP@,'@P1D4S1C$Q1"P*("`@("`@("`P>$4U-$-$034T+"`P>#%%
M1$%$.#DQ+"`P>$-%-C(W.4-&+"`P>$-$,T4W139&+`H@("`@("`@(#!X,38Q
M.$(Q-C8L(#!X1D0R0S%$,#4L(#!X.#0X1D0R0S4L(#!X1C9&0C(R.3DL"B`@
M("`@("`@,'A&-3(S1C,U-RP@,'A!-C,R-S8R,RP@,'@Y,T$X,S4S,2P@,'@U
M-D-#0T0P,BP*("`@("`@("`P>$%#1C`X,38R+"`P>#5!-S5%0D(U+"`P>#9%
M,38S-CDW+"`P>#@X1#(W,T-#+`H@("`@("`@(#!X1$4Y-C8R.3(L(#!X.#%"
M.30Y1#`L(#!X-$,U,#DP,4(L(#!X-S%#-C4V,30L"B`@("`@("`@,'A%-D,V
M0S="1"P@,'@S,C=!,30P02P@,'@T-44Q1#`P-BP@,'A#,T8R-T(Y02P*("`@
M("`@("`P>$,Y04$U,T9$+"`P>#8R03@P1C`P+"`P>$)",C5"1D4R+"`P>#,U
M0D1$,D8V+`H@("`@("`@(#!X-S$Q,C8Y,#4L(#!X0C(P-#`R,C(L(#!X0C9#
M0D-&-T,L(#!X0T0W-CE#,D(L"B`@("`@("`@,'@U,S$Q,T5#,"P@,'@Q-C0P
M13-$,RP@,'@S.$%"0D0V,"P@,'@R-30W041&,"P*("`@("`@("`P>$)!,S@R
M,#E#+"`P>$8W-#9#13<V+"`P>#<W049!,4,U+"`P>#(P-S4V,#8P+`H@("`@
M("`@(#!X.#5#0D9%-$4L(#!X.$%%.#A$1#@L(#!X-T%!048Y0C`L(#!X-$-&
M.4%!-T4L"B`@("`@("`@,'@Q.30X0S(U0RP@,'@P,D9".$$X0RP@,'@P,4,S
M-D%%-"P@,'A$-D5"13%&.2P*("`@("`@("`P>#DP1#1&.#8Y+"`P>$$V-4-$
M14$P+"`P>#-&,#DR-3)$+"`P>$,R,#A%-CE&+`H@("`@("`@(#!X0C<T138Q
M,S(L(#!X0T4W-T4R-4(L(#!X-3<X1D1&13,L(#!X,T%#,S<R138I.PH*("`@
M("\J*@H@("`@("H@5&AE(&YU;6)E<B!O9B!R;W5N9',@=&\@9&\*("`@("`J
M"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?<F]U;F1S
M(#T@,38["@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&ME>2!T;R!B92!U<V5D
M(&9O<B!E;B]D96-R>7!T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&ME>2`@5&AE(&ME>2!T;R!U<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E=$ME>2@D:V5Y*0H@("`@>PH@("`@("`@("1K97D@/2`D=&AI<RT^7V9O
M<FUA=$ME>2@D:V5Y*3L*("`@("`@("`D:V5Y4&]S(#T@,#L*("`@("`@("`D
M:V5Y6&]R(#T@,#L*"B`@("`@("`@)&E-87@@/2!C;W5N="@D=&AI<RT^<"D[
M"B`@("`@("`@)&ME>4QE;B`](&-O=6YT*"1K97DI.PH@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\("1I36%X.R`D:2LK*2!["B`@("`@("`@("`@(&9O<B`H
M)'0@/2`P.R`D="`\(#0[("1T*RLI('L*("`@("`@("`@("`@("`@("1K97E8
M;W(@/2`H)&ME>5AO<B`\/"`X*2!\("@H)&ME>5LD:V5Y4&]S72D@)B`P>#!F
M9BD["B`@("`@("`@("`@("`@("!I9B`H*RLD:V5Y4&]S(#T]("1K97E,96XI
M('L*("`@("`@("`@("`@("`@("`@("`D:V5Y4&]S(#T@,#L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^<%LD
M:5T@/2`D=&AI<RT^<%LD:5T@7B`D:V5Y6&]R.PH@("`@("`@('T*"B`@("`@
M("`@)&5N8UIE<F\@/2!A<G)A>2@G3"<@/3X@,"P@)U(G(#T^(#`I.PH@("`@
M("`@(&9O<B`H)&D@/2`P.R`D:2`K(#$@/"`D:4UA>#L@)&D@*ST@,BD@>PH@
M("`@("`@("`@("`D96YC6F5R;R`]("1T:&ES+3Y?96YC<GEP=$)L;V-K*"1E
M;F-:97)O6R=,)UTL("1E;F-:97)O6R=2)UTI.PH@("`@("`@("`@("`D=&AI
M<RT^<%LD:5T@/2`D96YC6F5R;ULG3"==.PH@("`@("`@("`@("`D=&AI<RT^
M<%LD:2`K(#%=(#T@)&5N8UIE<F];)U(G73L*("`@("`@("!]"@H@("`@("`@
M("1I36%X(#T@8V]U;G0H)'1H:7,M/G,Q*3L*("`@("`@("!F;W(@*"1I(#T@
M,#L@)&D@/"`D:4UA>#L@)&D@*ST@,BD@>PH@("`@("`@("`@("`D96YC6F5R
M;R`]("1T:&ES+3Y?96YC<GEP=$)L;V-K*"1E;F-:97)O6R=,)UTL("1E;F-:
M97)O6R=2)UTI.PH@("`@("`@("`@("`D=&AI<RT^<S%;)&E=(#T@)&5N8UIE
M<F];)TPG73L*("`@("`@("`@("`@)'1H:7,M/G,Q6R1I("L@,5T@/2`D96YC
M6F5R;ULG4B==.PH@("`@("`@('T*"B`@("`@("`@)&E-87@@/2!C;W5N="@D
M=&AI<RT^<S(I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1I36%X.R`D
M:2`K/2`R*2!["B`@("`@("`@("`@("1E;F-:97)O(#T@)'1H:7,M/E]E;F-R
M>7!T0FQO8VLH)&5N8UIE<F];)TPG72P@)&5N8UIE<F];)U(G72D["B`@("`@
M("`@("`@("1T:&ES+3YS,ELD:5T@/2`D96YC6F5R;ULG3"==.PH@("`@("`@
M("`@("`D=&AI<RT^<S);)&D@*R`Q72`]("1E;F-:97)O6R=2)UT["B`@("`@
M("`@?0H*("`@("`@("`D:4UA>"`](&-O=6YT*"1T:&ES+3YS,RD["B`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@)&E-87@[("1I("L](#(I('L*("`@("`@
M("`@("`@)&5N8UIE<F\@/2`D=&AI<RT^7V5N8W)Y<'1";&]C:R@D96YC6F5R
M;ULG3"==+"`D96YC6F5R;ULG4B==*3L*("`@("`@("`@("`@)'1H:7,M/G,S
M6R1I72`]("1E;F-:97)O6R=,)UT["B`@("`@("`@("`@("1T:&ES+3YS,ULD
M:2`K(#%=(#T@)&5N8UIE<F];)U(G73L*("`@("`@("!]"@H@("`@("`@("1I
M36%X(#T@8V]U;G0H)'1H:7,M/G,T*3L*("`@("`@("!F;W(@*"1I(#T@,#L@
M)&D@/"`D:4UA>#L@)&D@*ST@,BD@>PH@("`@("`@("`@("`D96YC6F5R;R`]
M("1T:&ES+3Y?96YC<GEP=$)L;V-K*"1E;F-:97)O6R=,)UTL("1E;F-:97)O
M6R=2)UTI.PH@("`@("`@("`@("`D=&AI<RT^<S1;)&E=(#T@)&5N8UIE<F];
M)TPG73L*("`@("`@("`@("`@)'1H:7,M/G,T6R1I("L@,5T@/2`D96YC6F5R
M;ULG4B==.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!T:&4@<VEZ92!O9B!T:&4@8FQO8VMS('1H870@=&AI<R!C:7!H97(@;F5E
M9',N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@;G5M8F5R
M(&]F(&-H87)A8W1E<G,@<&5R(&)L;V-K+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971";&]C:U-I>F4H*0H@("`@>PH@("`@("`@(')E='5R;B`X.PH@("`@
M?0H*("`@("\J*@H@("`@("H@16YC<GEP="!A(&)L;V-K(&]F(&1A=&$N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8FQO8VL@("`@("!4:&4@9&%T
M82!T;R!E;F-R>7!T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("`@("`@
M("!4:&4@:V5Y('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&5N8W)Y<'1E9"!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&5N8W)Y<'1";&]C:R@D8FQO8VLL("1K97D@/2!N=6QL*0H@("`@>PH@("`@
M("`@(&EF("@A:7-?;G5L;"@D:V5Y*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M<V5T2V5Y*"1K97DI.PH@("`@("`@('T*"B`@("`@("`@;&ES="@D3"P@)%(I
M(#T@87)R87E?=F%L=65S*'5N<&%C:R@G3BHG+"`D8FQO8VLI*3L*("`@("`@
M("`D<&%R=',@/2`D=&AI<RT^7V5N8W)Y<'1";&]C:R@D3"P@)%(I.PH@("`@
M("`@(')E='5R;B!P86-K*"=.3B<L("1P87)T<ULG3"==+"`D<&%R='-;)U(G
M72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%;F-R>7!T(&QE9G0@86YD(')I
M9VAT(&AA;'9E<R!O9B!A(&)L;V-K(&]F(&1A=&$N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)$P@($QE9G0@:&%L9B!O9B!T:&4@9&%T82X*("`@("`J($!P87)A;2!I;G1E
M9V5R("12("!2:6=H="!H86QF(&]F('1H92!D871A+@H@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@($$@:&%S:"P@=VET:"!K97ES("=,)R!A;F0@)U(G
M+"!A;F0@=&AE(&5N8W)Y<'1E9"!D871A(&%S"B`@("`@*B`@("`@("`@("`@
M("`@("!T:&4@=F%L=65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?96YC<GEP
M=$)L;V-K*"1,+"`D4BD*("`@('L*("`@("`@("`D3"!>/2`D=&AI<RT^<%LP
M73L*("`@("`@("`D4B!>/2`H*"@D=&AI<RT^<S%;*"1,(#X^(#(T*2`F(#!X
M1D9=("L@)'1H:7,M/G,R6R@D3"`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M
M/G,S6R@D3"`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)$P@)B`P>#!F
M9ETI(%X@)'1H:7,M/G!;,5T["B`@("`@("`@)$P@7CT@*"@H)'1H:7,M/G,Q
M6R@D4B`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)%(@/CX@,38I("8@
M,'@P9F9=*2!>("1T:&ES+3YS,ULH)%(@/CX@."D@)B`P>#!F9ETI("L@)'1H
M:7,M/G,T6R12("8@,'@P9F9=*2!>("1T:&ES+3YP6S)=.PH@("`@("`@("12
M(%X]("@H*"1T:&ES+3YS,5LH)$P@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^
M<S);*"1,(#X^(#$V*2`F(#!X,&9F72D@7B`D=&AI<RT^<S-;*"1,(#X^(#@I
M("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD3"`F(#!X,&9F72D@7B`D=&AI<RT^
M<%LS73L*("`@("`@("`D3"!>/2`H*"@D=&AI<RT^<S%;*"12(#X^(#(T*2`F
M(#!X1D9=("L@)'1H:7,M/G,R6R@D4B`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H
M:7,M/G,S6R@D4B`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)%(@)B`P
M>#!F9ETI(%X@)'1H:7,M/G!;-%T["B`@("`@("`@)%(@7CT@*"@H)'1H:7,M
M/G,Q6R@D3"`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)$P@/CX@,38I
M("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)$P@/CX@."D@)B`P>#!F9ETI("L@
M)'1H:7,M/G,T6R1,("8@,'@P9F9=*2!>("1T:&ES+3YP6S5=.PH@("`@("`@
M("1,(%X]("@H*"1T:&ES+3YS,5LH)%(@/CX@,C0I("8@,'A&1ET@*R`D=&AI
M<RT^<S);*"12(#X^(#$V*2`F(#!X,&9F72D@7B`D=&AI<RT^<S-;*"12(#X^
M(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD4B`F(#!X,&9F72D@7B`D=&AI
M<RT^<%LV73L*("`@("`@("`D4B!>/2`H*"@D=&AI<RT^<S%;*"1,(#X^(#(T
M*2`F(#!X1D9=("L@)'1H:7,M/G,R6R@D3"`^/B`Q-BD@)B`P>#!F9ETI(%X@
M)'1H:7,M/G,S6R@D3"`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)$P@
M)B`P>#!F9ETI(%X@)'1H:7,M/G!;-UT["B`@("`@("`@)$P@7CT@*"@H)'1H
M:7,M/G,Q6R@D4B`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)%(@/CX@
M,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)%(@/CX@."D@)B`P>#!F9ETI
M("L@)'1H:7,M/G,T6R12("8@,'@P9F9=*2!>("1T:&ES+3YP6SA=.PH@("`@
M("`@("12(%X]("@H*"1T:&ES+3YS,5LH)$P@/CX@,C0I("8@,'A&1ET@*R`D
M=&AI<RT^<S);*"1,(#X^(#$V*2`F(#!X,&9F72D@7B`D=&AI<RT^<S-;*"1,
M(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD3"`F(#!X,&9F72D@7B`D
M=&AI<RT^<%LY73L*("`@("`@("`D3"!>/2`H*"@D=&AI<RT^<S%;*"12(#X^
M(#(T*2`F(#!X1D9=("L@)'1H:7,M/G,R6R@D4B`^/B`Q-BD@)B`P>#!F9ETI
M(%X@)'1H:7,M/G,S6R@D4B`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;
M)%(@)B`P>#!F9ETI(%X@)'1H:7,M/G!;,3!=.PH@("`@("`@("12(%X]("@H
M*"1T:&ES+3YS,5LH)$P@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"1,
M(#X^(#$V*2`F(#!X,&9F72D@7B`D=&AI<RT^<S-;*"1,(#X^(#@I("8@,'@P
M9F9=*2`K("1T:&ES+3YS-%LD3"`F(#!X,&9F72D@7B`D=&AI<RT^<%LQ,5T[
M"B`@("`@("`@)$P@7CT@*"@H)'1H:7,M/G,Q6R@D4B`^/B`R-"D@)B`P>$9&
M72`K("1T:&ES+3YS,ELH)%(@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS
M,ULH)%(@/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T6R12("8@,'@P9F9=
M*2!>("1T:&ES+3YP6S$R73L*("`@("`@("`D4B!>/2`H*"@D=&AI<RT^<S%;
M*"1,(#X^(#(T*2`F(#!X1D9=("L@)'1H:7,M/G,R6R@D3"`^/B`Q-BD@)B`P
M>#!F9ETI(%X@)'1H:7,M/G,S6R@D3"`^/B`X*2`F(#!X,&9F72D@*R`D=&AI
M<RT^<S1;)$P@)B`P>#!F9ETI(%X@)'1H:7,M/G!;,3-=.PH@("`@("`@("1,
M(%X]("@H*"1T:&ES+3YS,5LH)%(@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^
M<S);*"12(#X^(#$V*2`F(#!X,&9F72D@7B`D=&AI<RT^<S-;*"12(#X^(#@I
M("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD4B`F(#!X,&9F72D@7B`D=&AI<RT^
M<%LQ-%T["B`@("`@("`@)%(@7CT@*"@H)'1H:7,M/G,Q6R@D3"`^/B`R-"D@
M)B`P>$9&72`K("1T:&ES+3YS,ELH)$P@/CX@,38I("8@,'@P9F9=*2!>("1T
M:&ES+3YS,ULH)$P@/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T6R1,("8@
M,'@P9F9=*2!>("1T:&ES+3YP6S$U73L*("`@("`@("`D3"!>/2`H*"@D=&AI
M<RT^<S%;*"12(#X^(#(T*2`F(#!X1D9=("L@)'1H:7,M/G,R6R@D4B`^/B`Q
M-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D4B`^/B`X*2`F(#!X,&9F72D@
M*R`D=&AI<RT^<S1;)%(@)B`P>#!F9ETI(%X@)'1H:7,M/G!;,39=.PH@("`@
M("`@("12(%X]("1T:&ES+3YP6S$W73L*"B`@("`@("`@<F5T=7)N(&%R<F%Y
M*"=,)R`]/B`D4BP@)U(G(#T^("1,*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($1E8W)Y<'0@82!B;&]C:R!O9B!D871A+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&)L;V-K("!4:&4@9&%T82!T;R!D96-R>7!T+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D:V5Y("`@(%1H92!K97D@=&\@=7-E+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9&5C<GEP=&5D(&]U='!U="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9&5C<GEP=$)L;V-K*"1B;&]C:RP@)&ME
M>2`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"%I<U]N=6QL*"1K97DI*2![
M"B`@("`@("`@("`@("1T:&ES+3YS971+97DH)&ME>2D["B`@("`@("`@?0H*
M("`@("`@("!L:7-T*"1,+"`D4BD@/2!A<G)A>5]V86QU97,H=6YP86-K*"=.
M*B<L("1B;&]C:RDI.PH*("`@("`@("`D3"!>/2`D=&AI<RT^<%LQ-UT["B`@
M("`@("`@)%(@7CT@*"@H)'1H:7,M/G,Q6R@D3"`^/B`R-"D@)B`P>$9&72`K
M("1T:&ES+3YS,ELH)$P@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH
M)$P@/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T6R1,("8@,'@P9F9=*2!>
M("1T:&ES+3YP6S$V73L*("`@("`@("`D3"!>/2`H*"@D=&AI<RT^<S%;*"12
M(#X^(#(T*2`F(#!X1D9=("L@)'1H:7,M/G,R6R@D4B`^/B`Q-BD@)B`P>#!F
M9ETI(%X@)'1H:7,M/G,S6R@D4B`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^
M<S1;)%(@)B`P>#!F9ETI(%X@)'1H:7,M/G!;,35=.PH@("`@("`@("12(%X]
M("@H*"1T:&ES+3YS,5LH)$P@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);
M*"1,(#X^(#$V*2`F(#!X,&9F72D@7B`D=&AI<RT^<S-;*"1,(#X^(#@I("8@
M,'@P9F9=*2`K("1T:&ES+3YS-%LD3"`F(#!X,&9F72D@7B`D=&AI<RT^<%LQ
M-%T["B`@("`@("`@)$P@7CT@*"@H)'1H:7,M/G,Q6R@D4B`^/B`R-"D@)B`P
M>$9&72`K("1T:&ES+3YS,ELH)%(@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES
M+3YS,ULH)%(@/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T6R12("8@,'@P
M9F9=*2!>("1T:&ES+3YP6S$S73L*("`@("`@("`D4B!>/2`H*"@D=&AI<RT^
M<S%;*"1,(#X^(#(T*2`F(#!X1D9=("L@)'1H:7,M/G,R6R@D3"`^/B`Q-BD@
M)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D3"`^/B`X*2`F(#!X,&9F72D@*R`D
M=&AI<RT^<S1;)$P@)B`P>#!F9ETI(%X@)'1H:7,M/G!;,3)=.PH@("`@("`@
M("1,(%X]("@H*"1T:&ES+3YS,5LH)%(@/CX@,C0I("8@,'A&1ET@*R`D=&AI
M<RT^<S);*"12(#X^(#$V*2`F(#!X,&9F72D@7B`D=&AI<RT^<S-;*"12(#X^
M(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD4B`F(#!X,&9F72D@7B`D=&AI
M<RT^<%LQ,5T["B`@("`@("`@)%(@7CT@*"@H)'1H:7,M/G,Q6R@D3"`^/B`R
M-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)$P@/CX@,38I("8@,'@P9F9=*2!>
M("1T:&ES+3YS,ULH)$P@/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T6R1,
M("8@,'@P9F9=*2!>("1T:&ES+3YP6S$P73L*("`@("`@("`D3"!>/2`H*"@D
M=&AI<RT^<S%;*"12(#X^(#(T*2`F(#!X1D9=("L@)'1H:7,M/G,R6R@D4B`^
M/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D4B`^/B`X*2`F(#!X,&9F
M72D@*R`D=&AI<RT^<S1;)%(@)B`P>#!F9ETI(%X@)'1H:7,M/G!;.5T["B`@
M("`@("`@)%(@7CT@*"@H)'1H:7,M/G,Q6R@D3"`^/B`R-"D@)B`P>$9&72`K
M("1T:&ES+3YS,ELH)$P@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH
M)$P@/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T6R1,("8@,'@P9F9=*2!>
M("1T:&ES+3YP6SA=.PH@("`@("`@("1,(%X]("@H*"1T:&ES+3YS,5LH)%(@
M/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"12(#X^(#$V*2`F(#!X,&9F
M72D@7B`D=&AI<RT^<S-;*"12(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS
M-%LD4B`F(#!X,&9F72D@7B`D=&AI<RT^<%LW73L*("`@("`@("`D4B!>/2`H
M*"@D=&AI<RT^<S%;*"1,(#X^(#(T*2`F(#!X1D9=("L@)'1H:7,M/G,R6R@D
M3"`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D3"`^/B`X*2`F(#!X
M,&9F72D@*R`D=&AI<RT^<S1;)$P@)B`P>#!F9ETI(%X@)'1H:7,M/G!;-ET[
M"B`@("`@("`@)$P@7CT@*"@H)'1H:7,M/G,Q6R@D4B`^/B`R-"D@)B`P>$9&
M72`K("1T:&ES+3YS,ELH)%(@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS
M,ULH)%(@/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T6R12("8@,'@P9F9=
M*2!>("1T:&ES+3YP6S5=.PH@("`@("`@("12(%X]("@H*"1T:&ES+3YS,5LH
M)$P@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"1,(#X^(#$V*2`F(#!X
M,&9F72D@7B`D=&AI<RT^<S-;*"1,(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES
M+3YS-%LD3"`F(#!X,&9F72D@7B`D=&AI<RT^<%LT73L*("`@("`@("`D3"!>
M/2`H*"@D=&AI<RT^<S%;*"12(#X^(#(T*2`F(#!X1D9=("L@)'1H:7,M/G,R
M6R@D4B`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D4B`^/B`X*2`F
M(#!X,&9F72D@*R`D=&AI<RT^<S1;)%(@)B`P>#!F9ETI(%X@)'1H:7,M/G!;
M,UT["B`@("`@("`@)%(@7CT@*"@H)'1H:7,M/G,Q6R@D3"`^/B`R-"D@)B`P
M>$9&72`K("1T:&ES+3YS,ELH)$P@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES
M+3YS,ULH)$P@/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T6R1,("8@,'@P
M9F9=*2!>("1T:&ES+3YP6S)=.PH@("`@("`@("1,(%X]("@H*"1T:&ES+3YS
M,5LH)%(@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"12(#X^(#$V*2`F
M(#!X,&9F72D@7B`D=&AI<RT^<S-;*"12(#X^(#@I("8@,'@P9F9=*2`K("1T
M:&ES+3YS-%LD4B`F(#!X,&9F72D@7B`D=&AI<RT^<%LQ73L*"B`@("`@("`@
M)&1E8W)Y<'1E9"`]('!A8VLH(DY.(BP@)%(@7B`D=&AI<RT^<%LP72P@)$PI
M.PH@("`@("`@(')E='5R;B`D9&5C<GEP=&5D.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0V]N=F5R=',@82!T97AT(&ME>2!I;G1O(&%N(&%R<F%Y+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@2V5Y(&EN('1E>'0@9F]R
M;6%T+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!K97D@:6X@
M87)R87D@9F]R;6%T+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9F]R;6%T2V5Y
M*"1K97DI"B`@("!["B`@("`@("`@<F5T=7)N(&%R<F%Y7W9A;'5E<RAU;G!A
M8VLH)T,J)RP@)&ME>2DI.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-I<&AE<B]C87-T,3(X+G!H<```
M```````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$S,C4S-@`Q,#4Q-30S,S<U
M,``P,C(V,#0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J(%1H92!#:7!H97)?8V%S=#$R.#HZ(&-L87-S
M(&EM<&QE;65N=',@=&AE($-I<&AE<B!I;G1E<F9A8V4@96YC<GEP=&EO;B!D
M871A"B`J('5S:6YG('1H92!#05-4,3(X("AA:V$@0V%S=#4I(&%L9V]R:71H
M;2!A<R!D969I;F5D(&EN(%)&0S(Q-#0N"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+T-I<&AE<B]#:7!H97(O8V%S=#$R."YP:'`L=B`Q+C<N,3(N."`R,#`V
M+S`Q+S`Q(#(Q.C(X.C$P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M,BTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM
M:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`R+C(*
M("H@0'!A8VMA9V4@2&]R9&5?0VEP:&5R"B`J+PIC;&%S<R!(;W)D95]#:7!H
M97)?8V%S=#$R."!E>'1E;F1S($AO<F1E7T-I<&AE<B!["@H@("`@+RHJ"B`@
M("`@*B!3(&)O>"`H<S$I"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)',Q(#T@87)R87DH"B`@("`@("`@,'@S,&9B-#!D-"P@
M,'@Y9F$P9F8P8BP@,'@V8F5C8V0R9BP@,'@S9C(U.&,W82P@,'@Q93(Q,V8R
M9BP@,'@Y8S`P-&1D,RP@,'@V,#`S934T,"P@,'AC9CEF8SDT.2P*("`@("`@
M("`P>&)F9#1A9C(W+"`P>#@X8F)B9&(U+"`P>&4R,#,T,#DP+"`P>#DX9#`Y
M-C<U+"`P>#9E-C-A,&4P+"`P>#$U8S,V,60R+"`P>&,R93<V-C%D+"`P>#(R
M9#1F9CAE+`H@("`@("`@(#!X,C@V.#-B-F8L(#!X8S`W9F0P-3DL(#!X9F8R
M,S<Y8S@L(#!X-S<U9C4P93(L(#!X-#-C,S0P9#,L(#!X9&8R9C@V-38L(#!X
M.#@W8V$T,6$L(#!X83)D,F)D,F0L"B`@("`@("`@,'AA,6,Y93!D-BP@,'@S
M-#9C-#@Q.2P@,'@V,6(W-F0X-RP@,'@R,C4T,&8R9BP@,'@R86)E,S)E,2P@
M,'AA834T,38V8BP@,'@R,C4V.&4S82P@,'AA,F0S-#%D,"P*("`@("`@("`P
M>#8V9&(T,&,X+"`P>&$W.#0S.3)F+"`P>#`P-&1F9C)F+"`P>#)D8CED,F1E
M+"`P>#DW.30S9F%C+"`P>#1A.3=C,60X+"`P>#4R-S8T-&(W+"`P>&(U9C0S
M-V$W+`H@("`@("`@(#!X8C@R8V)A968L(#!X9#<U,60Q-3DL(#!X-F9F-V8P
M960L(#!X-6$P.3=A,68L(#!X.#(W8C8X9#`L(#!X.3!E8V8U,F4L(#!X,C)B
M,&,P-30L(#!X8F,X934Y,S4L"B`@("`@("`@,'@T8C9D,F8W9BP@,'@U,&)B
M-C1A,BP@,'AD,C8V-#DQ,"P@,'AB964U.#$R9"P@,'AB-S,S,C(Y,"P@,'AE
M.3-B,34Y9BP@,'AB-#AE930Q,2P@,'@T8F9F,S0U9"P*("`@("`@("`P>&9D
M-#5C,C0P+"`P>&%D,S$Y-S-F+"`P>&,T9C9D,#)E+"`P>#4U9F,X,38U+"`P
M>&0U8C%C86%D+"`P>&$Q86,R9&%E+"`P>&$R9#1B-S9D+"`P>&,Q.6(P8S4P
M+`H@("`@("`@(#!X.#@R,C0P9C(L(#!X,&,V931F,S@L(#!X831E-&)F9#<L
M(#!X-&8U8F$R-S(L(#!X-38T8S%D,F8L(#!X8S4Y8S4S,3DL(#!X8CDT.64S
M-30L(#!X8C`T-C8Y9F4L"B`@("`@("`@,'AB,6(V86(X82P@,'AC-S$S-3AD
M9"P@,'@V,S@U8S4T-2P@,'@Q,3!F.3,U9"P@,'@U-S4S.&%D-2P@,'@V83,Y
M,#0Y,RP@,'AE-C-D,S=E,"P@,'@R834T9C9B,RP*("`@("`@("`P>#-A-S@W
M9#5F+"`P>#8R-S9A,&(U+"`P>#$Y839F8V1F+"`P>#=A-#(R,#9A+"`P>#(Y
M9CED-&0U+"`P>&8V,6(Q.#DQ+"`P>&)B-S(R-S5E+"`P>&%A-3`X,38W+`H@
M("`@("`@(#!X,S@Y,#$P.3$L(#!X8S9B-3`U96(L(#!X.#1C-V-B.&,L(#!X
M,F%D-S5A,&8L(#!X.#<T83$T,C<L(#!X83)D,3DS-F(L(#!X,F%D,C@V868L
M(#!X86$U-F0R.3$L"B`@("`@("`@,'AD-S@Y-#,V,"P@,'@T,C5C-S4P9"P@
M,'@Y,V(S.64R-BP@,'@Q.#<Q.#1C.2P@,'@V8S`P8C,R9"P@,'@W,V4R8F(Q
M-"P@,'AA,&)E8F,S8RP@,'@U-#8R,S<W.2P*("`@("`@("`P>#8T-#4Y96%B
M+"`P>#-F,S(X8C@R+"`P>#<W,3AC9C@R+"`P>#4Y83)C96$V+"`P>#`T964P
M,#)E+"`P>#@Y9F4W.&4V+"`P>#-F86(P.34P+"`P>#,R-69F-F,R+`H@("`@
M("`@(#!X.#$S.#-F,#4L(#!X-CDV,V,U8S@L(#!X-S9C8C5A9#8L(#!X9#0Y
M.3<T8SDL(#!X8V$Q.#!D8V8L(#!X,S@P-S@R9#4L(#!X8S=F835C9C8L(#!X
M.&%C,S$U,3$L"B`@("`@("`@,'@S-64W.64Q,RP@,'@T-V1A.3%D,"P@,'AF
M-#!F.3`X-BP@,'AA-V4R-#$Y92P@,'@S,3,V-C(T,2P@,'@P-3%E9C0Y-2P@
M,'AA834W,V(P-"P@,'@T83@P-60X9"P*("`@("`@("`P>#4T.#,P,&0P+"`P
M>#`P,S(R83-C+"`P>&)F-C1C9&1F+"`P>&)A-3=A-CAE+"`P>#<U8S8S-S)B
M+"`P>#4P869D,S0Q+"`P>&$W8S$S,C<U+"`P>#DQ-6$P8F8U+`H@("`@("`@
M(#!X-F(U-&)F86(L(#!X,F(P8C$T,C8L(#!X86(T8V,Y9#<L(#!X-#0Y8V-D
M.#(L(#!X9C=F8F8R-C4L(#!X86(X-6,U9C,L(#!X,6(U-61B.30L(#!X86%D
M-&4S,C0L"B`@("`@("`@,'AC9F$T8F0S9BP@,'@R9&5A83-E,BP@,'@Y93(P
M-&0P,BP@,'AC.&)D,C5A8RP@,'AE861F-35B,RP@,'AD-6)D.64Y."P@,'AE
M,S$R,S%B,BP@,'@R860U860V8RP*("`@("`@("`P>#DU-#,R.61E+"`P>&%D
M8F4T-3(X+"`P>&0X-S$P9C8Y+"`P>&%A-3%C.3!F+"`P>&%A-S@V8F8V+"`P
M>#(R-3$S9C%E+"`P>&%A-3%A-SEB+"`P>#)A9#,T-&-C+`H@("`@("`@(#!X
M-V(U830Q9C`L(#!X9#,W8V9B860L(#!X,6(P-CDU,#4L(#!X-#%E8V4T.3$L
M(#!X8C1C,S,R938L(#!X,#,R,C8X9#0L(#!X8SDV,#!A8V,L(#!X8V4S.#=E
M-F0L"B`@("`@("`@,'AB9C9B8C$V8RP@,'@V83<P9F(W."P@,'@P9#`S9#EC
M.2P@,'AD-&1F,SED92P@,'AE,#$P-C-D82P@,'@T-S,V9C0V-"P@,'@U860S
M,CAD."P@,'AB,S0W8V,Y-BP*("`@("`@("`P>#<U8F(P9F,S+"`P>#DX-3$Q
M8F9B+"`P>#1F9F)C8S,U+"`P>&(U.&)C9C9A+"`P>&4Q,68P86)C+"`P>&)F
M8S5F931A+"`P>&$W,&%E8S$P+"`P>&%C,SDU-S!A+`H@("`@("`@(#!X,V8P
M-#0T,F8L(#!X-C$X.&(Q-3,L(#!X93`S.3=A,F4L(#!X-3<R-V-B-SDL(#!X
M.6-E8C0Q.&8L(#!X,6-A8V0V.&0L(#!X,F%D,S=C.38L(#!X,#$W-6-B.60L
M"B`@("`@("`@,'AC-CED9F8P.2P@,'AC-S5B-C5F,"P@,'AD.61B-#!D."P@
M,'AE8S!E-S<W.2P@,'@T-S0T96%D-"P@,'AB,3%C,S(W-"P@,'AD9#(T8V(Y
M92P@,'@W93%C-31B9"P*("`@("`@("`P>&8P,3$T-&8Y+"`P>&0R,C0P96(Q
M+"`P>#DV-S5B,V9D+"`P>&$S86,S-S4U+"`P>&0T-V,R-V%F+"`P>#4Q8S@U
M9C1D+"`P>#4V.3`W-3DV+"`P>&$U8F(Q-64V+`H@("`@("`@(#!X-3@P,S`T
M9C`L(#!X8V$P-#)C9C$L(#!X,#$Q83,W96$L(#!X.&1B9F%A9&(L(#!X,S5B
M83-E-&$L(#!X,S4R-F9F83`L(#!X8S,W8C1D,#DL(#!X8F,S,#9E9#DL"B`@
M("`@("`@,'@Y.&$U,C8V-BP@,'@U-C0X9C<R-2P@,'AF9C5E-38Y9"P@,'@P
M8V5D-C-D,"P@,'@W8S8S8C)C9BP@,'@W,#!B-#5E,2P@,'AD-65A-3!F,2P@
M,'@X-6$Y,C@W,BP*("`@("`@("`P>&%F,69B9&$W+"`P>&0T,C,T.#<P+"`P
M>&$W.#<P8F8S+"`P>#)D,V(T9#<Y+"`P>#0R93`T,3DX+"`P>#!C9#!E9&4W
M+"`P>#(V-#<P9&(X+"`P>&8X.#$X,31C+`H@("`@("`@(#!X-#<T9#9A9#<L
M(#!X-V,P8S5E-6,L(#!X9#$R,S$Y-3DL(#!X,S@Q8C<R.3@L(#!X9C5D,F8T
M9&(L(#!X86(X,S@V-3,L(#!X-F4R9C%E,C,L(#!X.#,W,3EC.64L"B`@("`@
M("`@,'AB9#DQ93`T-BP@,'@Y834V-#4V92P@,'AD8S,Y,C`P8RP@,'@R,&,X
M8S4W,2P@,'@Y-C)B9&$Q8RP@,'AE,64V.39F9BP@,'AB,30Q86(P."P@,'@W
M8V-A.#EB.2P*("`@("`@("`P>#%A-CEE-S@S+"`P>#`R8V,T.#0S+"`P>&$R
M9C=C-3<Y+"`P>#0R.65F-#=D+"`P>#0R-V(Q-CEC+"`P>#5A8SEF,#0Y+"`P
M>&1D.&8P9C`P+"`P>#5C.#$V-6)F*3L*"B`@("`O*BH*("`@("`J(%,@8F]X
M("AS,BD*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D<S(@/2!A<G)A>2@*("`@("`@("`P>#%F,C`Q,#DT+"`P>&5F,&)A-S5B
M+"`P>#8Y93-C9C=E+"`P>#,Y,V8T,S@P+"`P>&9E-C%C9C=A+"`P>&5E8S4R
M,#=A+"`P>#4U.#@Y8SDT+"`P>#<R9F,P-C4Q+`H@("`@("`@(#!X861A-V5F
M-SDL(#!X-&4Q9#<R,S4L(#!X9#4U838S8V4L(#!X9&4P-#,V8F$L(#!X.3EC
M-#,P968L(#!X-68P8S`W.30L(#!X,3AD8V1B-V0L(#!X83%D-F5F9C,L"B`@
M("`@("`@,'AA,&(U,F8W8BP@,'@U.64X,S8P-2P@,'AE93$U8C`Y-"P@,'AE
M.69F9#DP.2P@,'AD8S0T,#`X-BP@,'AE9CDT-#0U.2P@,'AB83@S8V-B,RP@
M,'AE,&,S8V1F8BP*("`@("`@("`P>&0Q9&$T,3@Q+"`P>#-B,#DR86(Q+"`P
M>&8Y.3=F,6,Q+"`P>&$U939C9C=B+"`P>#`Q-#(P9&1B+"`P>&4T93=E9C5B
M+"`P>#(U83%F9C0Q+"`P>&4Q.#!F.#`V+`H@("`@("`@(#!X,69C-#$P.#`L
M(#!X,3<Y8F5E-V$L(#!X9#,W86,V83DL(#!X9F4U.#,P830L(#!X.3AD93AB
M-V8L(#!X-S=E.#-F-&4L(#!X-SDY,CDR-CDL(#!X,C1F83EF-V(L"B`@("`@
M("`@,'AE,3$S8S@U8BP@,'AA8V,T,#`X,RP@,'AD-S4P,S4R-2P@,'AF-V5A
M-C$U9BP@,'@V,C$T,S$U-"P@,'@P9#4U-&(V,RP@,'@U9#8X,3$R,2P@,'AC
M.#8V8S,U.2P*("`@("`@("`P>#-D-C-C9C<S+"`P>&-E93(S-&,P+"`P>&0T
M9#@W93@W+"`P>#5C-C<R8C(Q+"`P>#`W,68V,3@Q+"`P>#,Y9C<V,C=F+"`P
M>#,V,64S,#@T+"`P>&4T96(U-S-B+`H@("`@("`@(#!X-C`R9C8T830L(#!X
M9#8S86-D.6,L(#!X,6)B8S0V,S4L(#!X.64X,3`S,F0L(#!X,C<P,68U,&,L
M(#!X.3DX-#=A8C0L(#!X83!E,V1F-SDL(#!X8F$V8V8S.&,L"B`@("`@("`@
M,'@Q,#@T,S`Y-"P@,'@R-3,W83DU92P@,'AF-#9F-F9F92P@,'AA,69F,V(Q
M9BP@,'@R,#AC9F(V82P@,'@X9C0U.&,W-"P@,'AD.64P83(R-RP@,'@T96,W
M,V$S-"P*("`@("`@("`P>&9C.#@T9C8Y+"`P>#-E-&1E.&1F+"`P>&5F,&4P
M,#@X+"`P>#,U-3DV-#AD+"`P>#AA-#4S.#AC+"`P>#%D.#`T,S8V+"`P>#<R
M,60Y8F9D+"`P>&$U.#8X-&)B+`H@("`@("`@(#!X93@R-38S,S,L(#!X.#0T
M93@R,3(L(#!X,3(X9#@P.3@L(#!X9F5D,S-F8C0L(#!X8V4R.#!A93$L(#!X
M,C=E,3EB834L(#!X9#5A-F,R-3(L(#!X930Y-S4T8F0L"B`@("`@("`@,'AC
M-60V-35D9"P@,'AE8C8V-S`V-"P@,'@W-S@T,&(T9"P@,'AA,6(V83@P,2P@
M,'@X-&1B,C9A.2P@,'AE,&(U-C<Q-"P@,'@R,68P-#-B-RP@,'AE-60P-3@V
M,"P*("`@("`@("`P>#4T9C`S,#@T+"`P>#`V-F9F-#<R+"`P>&$S,6%A,34S
M+"`P>&1A9&,T-S4U+"`P>&(U-C(U9&)F+"`P>#8X-38Q8F4V+"`P>#@S8V$V
M8CDT+"`P>#)D-F5D,C-B+`H@("`@("`@(#!X96-C9C`Q9&(L(#!X839D,V0P
M8F$L(#!X8C8X,#-D-6,L(#!X868W-V$W,#DL(#!X,S-B-&$S-&,L(#!X,SDW
M8F,X9#8L(#!X-65E,C)B.34L(#!X-68P934S,#0L"B`@("`@("`@,'@X,65D
M-F8V,2P@,'@R,&4W-#,V-"P@,'AB-#5E,3,W."P@,'AD93$X-C,Y8BP@,'@X
M.#%C83$R,BP@,'AB.38W,C9D,2P@,'@X,#0Y83=E."P@,'@R,F(W9&$W8BP*
M("`@("`@("`P>#5E-34R9#(U+"`P>#4R-S)D,C,W+"`P>#<Y9#(Y-3%C+"`P
M>&,V,&0X.31C+"`P>#0X.&-B-#`R+"`P>#%B831F935B+"`P>&$T8C`Y9C9B
M+"`P>#%C83@Q-6-F+`H@("`@("`@(#!X83(P8S,P,#4L(#!X.#@W,61F-C,L
M(#!X8CED93)F8V(L(#!X,&-C-F,Y93DL(#!X,&)E969F-3,L(#!X93,R,30U
M,3<L(#!X8C0U-#(X,S4L(#!X.68V,S(Y,V,L"B`@("`@("`@,'AE930Q93<R
M.2P@,'@V93%D,F0W8RP@,'@U,#`T-3(X-BP@,'@Q938V.#5F,RP@,'AF,S,T
M,#%C-BP@,'@S,&$R,F,Y-2P@,'@S,6$W,#@U,"P@,'@V,#DS,&8Q,RP*("`@
M("`@("`P>#<S9CDX-#$W+"`P>&$Q,C8Y.#4Y+"`P>&5C-C0U8S0T+"`P>#4R
M8S@W-V$Y+"`P>&-D9F8S,V$V+"`P>&$P,F(Q-S0Q+"`P>#=C8F%D.6$R+"`P
M>#(Q.#`P,S9F+`H@("`@("`@(#!X-3!D.3EC,#@L(#!X8V(S9C0X-C$L(#!X
M8S(V8F0W-C4L(#!X-C1A,V8V86(L(#!X.#`S-#(V-S8L(#!X,C5A-S5E-V(L
M(#!X931E-F0Q9F,L(#!X,C!C-S$P938L"B`@("`@("`@,'AC9&8P8C8X,"P@
M,'@Q-S@T-&0S8BP@,'@S,65E9C@T9"P@,'@W93`X,C1E-"P@,'@R8V-B-#EE
M8BP@,'@X-#9A,V)A92P@,'@X9F8W-S@X."P@,'AE935D-C!F-BP*("`@("`@
M("`P>#=A9C<U-C<S+"`P>#)F9&0U8V1B+"`P>&$Q,38S,6,Q+"`P>#,P9C8V
M9C0S+"`P>&(S9F%E8S4T+"`P>#$U-V9D-V9A+"`P>&5F.#4W.6-C+"`P>&0Q
M-3)D934X+`H@("`@("`@(#!X9&(R9F9D-64L(#!X.&8S,F-E,3DL(#!X,S`V
M868Y-V$L(#!X,#)F,#-E9C@L(#!X.3DS,3EA9#4L(#!X8S(T,F9A,&8L(#!X
M83=E,V5B8C`L(#!X8S8X930Y,#8L"B`@("`@("`@,'AB.&1A,C,P8RP@,'@X
M,#@R,S`R."P@,'AD8V1E9C-C."P@,'AD,S5F8C$W,2P@,'@P.#AA,6)C."P@
M,'AB96,P8S4V,"P@,'@V,6$S8SEE."P@,'AB8V$X9C4T9"P*("`@("`@("`P
M>&,W,F9E9F9A+"`P>#(R.#(R93DY+"`P>#@R8S4W,&(T+"`P>&0X9#DT93@Y
M+"`P>#AB,6,S-&)C+"`P>#,P,64Q-F4V+"`P>#(W,V)E.3<Y+"`P>&(P9F9E
M86$V+`H@("`@("`@(#!X-C%D.6(X8S8L(#!X,#!B,C0X-CDL(#!X8C=F9F-E
M,V8L(#!X,#AD8S(X,V(L(#!X-#-D868V-6$L(#!X9C=E,3DW.3@L(#!X-S8Q
M.6(W,F8L(#!X.&8Q8SEB830L"B`@("`@("`@,'AD8S@V,S=A,"P@,'@Q-F$W
M9#-B,2P@,'@Y9F,S.3-B-RP@,'AA-S$S-F5E8BP@,'AC-F)C8S8S92P@,'@Q
M834Q,S<T,BP@,'AE9C8X,CAB8RP@,'@U,C`S-C5D-BP*("`@("`@("`P>#)D
M-F$W-V%B+"`P>#,U,C=E9#1B+"`P>#@R,69D,C$V+"`P>#`Y-6,V93)E+"`P
M>&1B.3)F,F9B+"`P>#5E96$R.6-B+"`P>#$T-3@Y,F8U+"`P>#DQ-3@T9C=F
M+`H@("`@("`@(#!X-30X,S8Y-V(L(#!X,C8V-V$X8V,L(#!X.#4Q.38P-#@L
M(#!X.&,T8F%C96$L(#!X.#,S.#8P9#0L(#!X,&0R,V4P9CDL(#!X-F,S.#=E
M.&$L(#!X,&%E-F0R-#DL"B`@("`@("`@,'AB,C@T-C`P8RP@,'AD.#,U-S,Q
M9"P@,'AD8V(Q8S8T-RP@,'AA8S1C-39E82P@,'@S96)D.#%B,RP@,'@R,S!E
M86)B,"P@,'@V-#,X8F,X-RP@,'AF,&(U8C%F82P*("`@("`@("`P>#AF-65A
M,F(S+"`P>&9C,3@T-C0R+"`P>#!A,#,V8C=A+"`P>#1F8C`X.6)D+"`P>#8T
M.61A-3@Y+"`P>&$S-#4T,35E+"`P>#5C,#,X,S(S+"`P>#-E-60S8F(Y+`H@
M("`@("`@(#!X-#-D-SDU-S(L(#!X-V4V9&0P-V,L(#!X,#9D9F1F,64L(#!X
M-F,V8V,T968L(#!X-S$V,&$U,SDL(#!X-S-B9F)E-S`L(#!X.#,X-S<V,#4L
M(#!X-#4R,V5C9C$I.PH*("`@("\J*@H@("`@("H@4R!B;W@@*',S*0H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1S,R`](&%R
M<F%Y*`H@("`@("`@(#!X.&1E9F,R-#`L(#!X,C5F835D.68L(#!X96(Y,#-D
M8F8L(#!X93@Q,&,Y,#<L(#!X-#<V,#=F9F8L(#!X,S8Y9F4T-&(L(#!X.&,Q
M9F,V-#0L(#!X865C96-A.3`L"B`@("`@("`@,'AB96(Q9CEB9BP@,'AE969B
M8V%E82P@,'AE.&-F,3DU,"P@,'@U,61F,#=A92P@,'@Y,C!E.#@P-BP@,'AF
M,&%D,#4T."P@,'AE,3-C.&0X,RP@,'@Y,C<P,3!D-2P*("`@("`@("`P>#$Q
M,3`W9#EF+"`P>#`W-C0W9&(Y+"`P>&(R93-E-&0T+"`P>#-D-&8R.#5E+"`P
M>&(Y869A.#(P+"`P>&9A9&4X,F4P+"`P>&$P-C<R-CAB+"`P>#@R-S(W.3)E
M+`H@("`@("`@(#!X-34S9F(R8S`L(#!X-#@Y864R,F(L(#!X9#1E9CDW.30L
M(#!X,3(U93-F8F,L(#!X,C%F9F9C964L(#!X.#(U8C%B9F0L(#!X.3(U-6,U
M960L(#!X,3(U-V$R-#`L"B`@("`@("`@,'@T93%A.#,P,BP@,'AB864P-V9F
M9BP@,'@U,C@R-#9E-RP@,'@X934W,30P92P@,'@S,S<S9C=B9BP@,'@X8SEF
M.#$X."P@,'AA-F9C-&5E."P@,'AC.3@R8C5A-2P*("`@("`@("`P>&$X8S`Q
M9&(W+"`P>#4W.69C,C8T+"`P>#8W,#DT9C,Q+"`P>&8R8F0S9C5F+"`P>#0P
M9F9F-V,Q+"`P>#%F8C<X9&9C+"`P>#AE-F)D,F,Q+"`P>#0S-V)E-3EB+`H@
M("`@("`@(#!X.3EB,#-D8F8L(#!X8C5D8F,V-&(L(#!X-C,X9&,P938L(#!X
M-34X,3ED.3DL(#!X83$Y-V,X,6,L(#!X-&$P,3)D-F4L(#!X8S4X.#1A,C@L
M(#!X8V-C,S9F-S$L"B`@("`@("`@,'AB.#0S8S(Q,RP@,'@V8S`W-#-F,2P@
M,'@X,S`Y.#DS8RP@,'@P9F5D9&0U9BP@,'@R9C=F93@U,"P@,'AD-V,P-V8W
M92P@,'@P,C4P-V9B9BP@,'@U869B.6$P-"P*("`@("`@("`P>&$W-#=D,F0P
M+"`P>#$V-3$Q.3)E+"`P>&%F-S!B9C-E+"`P>#4X8S,Q,S@P+"`P>#5F.3@S
M,#)E+"`P>#<R-V-C,V,T+"`P>#!A,&9B-#`R+"`P>#!F-V9E9C@R+`H@("`@
M("`@(#!X.&,Y-F9D860L(#!X-60R8S)A864L(#!X.&5E.3EA-#DL(#!X-3!D
M83@X8C@L(#!X.#0R-V8T83`L(#!X,65A8S4W.3`L(#!X-SDV9F(T-#DL(#!X
M.#(U,F1C,34L"B`@("`@("`@,'AE9F)D-V0Y8BP@,'AA-C<R-3DW9"P@,'AA
M9&$X-#!D."P@,'@T-68U-#4P-"P@,'AF835D-S0P,RP@,'AE.#-E8S,P-2P@
M,'@T9CDQ-S4Q82P@,'@Y,C4V-CEC,BP*("`@("`@("`P>#(S969E.30Q+"`P
M>&$Y,#-F,3)E+"`P>#8P,C<P9&8R+"`P>#`R-S9E-&(V+"`P>#DT9F0V-3<T
M+"`P>#DR-SDX-6(R+"`P>#@R-S9D8F-B+"`P>#`R-S<X,3<V+`H@("`@("`@
M(#!X9CAA9CDQ.&0L(#!X-&4T.&8W.64L(#!X.&8V,39D9&8L(#!X93(Y9#@T
M,&4L(#!X.#0R9C=D.#,L(#!X,S0P8V4U8S@L(#!X.39B8F(V.#(L(#!X.3-B
M-&(Q-#@L"B`@("`@("`@,'AE9C,P,V-A8BP@,'@Y.#1F868R."P@,'@W-SEF
M868Y8BP@,'@Y,F1C-38P9"P@,'@R,C1D,64R,"P@,'@X-#,W86$X."P@,'@W
M9#(Y9&,Y-BP@,'@R-S4V9#-D8RP*("`@("`@("`P>#AB.3`W8V5E+"`P>&(U
M,69D,C0P+"`P>&4W8S`W8V4S+"`P>&4U-C9B-&$Q+"`P>&,S93DV,35E+"`P
M>#-C9C@R,#ED+"`P>#8P.31D,64S+"`P>&-D.6-A,S0Q+`H@("`@("`@(#!X
M-6,W-C0V,&4L(#!X,#!E83DX,V(L(#!X9#1D-C<X.#$L(#!X9F0T-S4W,F,L
M(#!X9C<V8V5D9#DL(#!X8F1A.#(R.6,L(#!X,3(W9&%D86$L(#!X-#,X83`W
M-&4L"B`@("`@("`@,'@Q9CDW8S`Y,"P@,'@P.#%B9&(X82P@,'@Y,V$P-V5B
M92P@,'AB.3,X8V$Q-2P@,'@Y-V(P,V-F9BP@,'@S9&,R8S!F."P@,'@X9#%A
M8C)E8RP@,'@V-#,X,&4U,2P*("`@("`@("`P>#8X8V,W8F9B+"`P>&0Y,&8R
M-S@X+"`P>#$R-#DP,3@Q+"`P>#5D935F9F0T+"`P>&1D-V5F.#9A+"`P>#<V
M83)E,C$T+"`P>&(Y830P,S8X+"`P>#DR-60Y-3AF+`H@("`@("`@(#!X-&(S
M.69F9F$L(#!X8F$S.6%E93DL(#!X831F9F0S,&(L(#!X9F%F-SDS,V(L(#!X
M-F0T.3@V,C,L(#!X,3DS8V)C9F$L(#!X,C<V,C<U-#4L(#!X.#(U8V8T-V$L
M"B`@("`@("`@,'@V,6)D.&)A,"P@,'AD,3%E-#)D,2P@,'AC96%D,#1F-"P@
M,'@Q,C=E83,Y,BP@,'@Q,#0R.&1B-RP@,'@X,C<R83DW,BP@,'@Y,C<P8S1A
M."P@,'@Q,C=D934P8BP*("`@("`@("`P>#(X-6)A,6,X+"`P>#-C-C)F-#1F
M+"`P>#,U8S!E86$U+"`P>&4X,#5D,C,Q+"`P>#0R.#DR.69B+"`P>&(T9F-D
M9C@R+"`P>#1F8C8V834S+"`P>#!E-V1C,35B+`H@("`@("`@(#!X,68P.#%F
M86(L(#!X,3`X-C$X864L(#!X9F-F9#`X-F0L(#!X9CEF9C(X.#DL(#!X-CDT
M8F-C,3$L(#!X,C,V835C864L(#!X,3)D96-A-&0L(#!X,F,S9CAC8S4L"B`@
M("`@("`@,'AD,F0P,F1F92P@,'AF.&5F-3@Y-BP@,'AE-&-F-3)D82P@,'@Y
M-3$U-6(V-RP@,'@T.31A-#@X8RP@,'AB.6(V83@P8RP@,'@U8SAF.#)B8RP@
M,'@X.60S-F(T-2P*("`@("`@("`P>#-A-C`Y-#,W+"`P>&5C,#!C.6$Y+"`P
M>#0T-S$U,C4S+"`P>#!A.#<T8C0Y+"`P>&0W-S-B8S0P+"`P>#=C,S0V-S%C
M+"`P>#`R-S$W968V+"`P>#1F96(U-3,V+`H@("`@("`@(#!X83)D,#)F9F8L
M(#!X9#)B9C8P8S0L(#!X9#0S9C`S8S`L(#!X-3!B-&5F-F0L(#!X,#<T-SAC
M9#$L(#!X,#`V93$X.#@L(#!X83)E-3-F-34L(#!X8CEE-F0T8F,L"B`@("`@
M("`@,'AA,C`T.#`Q-BP@,'@Y-S4W,S@S,RP@,'AD-S(P-V0V-RP@,'AD93!F
M.&8S9"P@,'@W,F8X-V(S,RP@,'AA8F-C-&8S,RP@,'@W-C@X8S4U9"P@,'@W
M8C`P839B,"P*("`@("`@("`P>#DT-V(P,#`Q+"`P>#4W,#`W-60R+"`P>&8Y
M8F(X.&8X+"`P>#@Y-#(P,3EE+"`P>#0R-C1A-69F+"`P>#@U-C,P,F4P+"`P
M>#<R9&)D.3)B+"`P>&5E.3<Q8C8Y+`H@("`@("`@(#!X-F5A,C)F9&4L(#!X
M-68P.&%E,F(L(#!X868W838Q-F0L(#!X935C.3@W-C<L(#!X8V8Q9F5B9#(L
M(#!X-C%E9F,X8S(L(#!X9C%A8S(U-S$L(#!X8V,X,C,Y8S(L"B`@("`@("`@
M,'@V-S(Q-&-B."P@,'AB,64U.#-D,2P@,'AB-V1C,V4V,BP@,'@W9C$P8F1C
M92P@,'AF.3!A-6,S."P@,'@P9F8P-#0S9"P@,'@V,#9E-F1C-BP@,'@V,#4T
M,V$T.2P*("`@("`@("`P>#4W,C=C,30X+"`P>#)B93DX83%D+"`P>#AA8C0Q
M-S,X+"`P>#(P93%B93(T+"`P>&%F.39D83!F+"`P>#8X-#4X-#(U+"`P>#DY
M.#,S8F4U+"`P>#8P,&0T-3=D+`H@("`@("`@(#!X,C@R9CDS-3`L(#!X.#,S
M-&(S-C(L(#!X9#DQ9#$Q,C`L(#!X,F(V9#AD83`L(#!X-C0R8C%E,S$L(#!X
M.6,S,#5A,#`L(#!X-3)B8V4V.#@L(#!X,6(P,S4X.&$L"B`@("`@("`@,'AF
M-V)A969D-2P@,'@T,30R960Y8RP@,'AA-#,Q-6,Q,2P@,'@X,S,R,V5C-2P@
M,'AD9F5F-#8S-BP@,'AA,3,S8S4P,2P@,'AE.60S-3,Q8RP@,'AE93,U,S<X
M,RD["@H@("`@+RHJ"B`@("`@*B!3(&)O>"`H<S0I"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)',T(#T@87)R87DH"B`@("`@
M("`@,'@Y9&(S,#0R,"P@,'@Q9F(V93ED92P@,'AA-V)E-V)E9BP@,'AD,C<S
M83(Y."P@,'@T831F-V)D8BP@,'@V-&%D.&,U-RP@,'@X-34Q,#0T,RP@,'AF
M83`R,&5D,2P*("`@("`@("`P>#=E,C@W869F+"`P>&4V,&9B-C8S+"`P>#`Y
M-68S-6$Q+"`P>#<Y96)F,3(P+"`P>&9D,#4Y9#0S+"`P>#8T.3=B-V(Q+"`P
M>&8S-C0Q9C8S+"`P>#(T,64T861F+`H@("`@("`@(#!X,C@Q-#=F-68L(#!X
M-&9A,F(X8V0L(#!X8SDT,S`P-#`L(#!X,&-C,S(R,C`L(#!X9F1D,S!B,S`L
M(#!X8S!A-3,W-&8L(#!X,60R9#`P9#DL(#!X,C0Q-#=B,34L"B`@("`@("`@
M,'AE931D,3$Q82P@,'@P9F-A-3$V-RP@,'@W,69F.3`T8RP@,'@R9#$Y-69F
M92P@,'@Q83`U-C0U9BP@,'@P8S$S9F5F92P@,'@P.#%B,#AC82P@,'@P-3$W
M,#$R,2P*("`@("`@("`P>#@P-3,P,3`P+"`P>&4X,V4U969E+"`P>&%C.6%F
M-&8X+"`P>#=F93<R-S`Q+"`P>&0R8CAE935F+"`P>#`V9&8T,C8Q+"`P>&)B
M.64Y8CAA+"`P>#<R.3-E83(U+`H@("`@("`@(#!X8V4X-&9F9&8L(#!X9C4W
M,3@X,#$L(#!X,V1D-C1B,#0L(#!X83(V9C(V,V(L(#!X-V5D-#@T,#`L(#!X
M-30W965B938L(#!X-#0V9#1C83`L(#!X-F-F,V0V9C4L"B`@("`@("`@,'@R
M-C0Y86)D9BP@,'AA96$P8S=F-2P@,'@S-C,S.&-C,2P@,'@U,#-F-V4Y,RP@
M,'AD,S<W,C`V,2P@,'@Q,6(V,SAE,2P@,'@W,C4P,&4P,RP@,'AF.#!E8C)B
M8BP*("`@("`@("`P>&%B93`U,#)E+"`P>&5C.&0W-V1E+"`P>#4W.3<Q93@Q
M+"`P>&4Q-&8V-S0V+"`P>&,Y,S,U-#`P+"`P>#8Y,C`S,3AF+"`P>#`X,61B
M8CDY+"`P>&9F8S,P-&$U+`H@("`@("`@(#!X-&0S-3$X,#4L(#!X-V8S9#5C
M93,L(#!X839C.#8V8S8L(#!X-60U8F-C83DL(#!X9&%E8S9F96$L(#!X.68Y
M,C9F.3$L(#!X.68T-C(R,F8L(#!X,SDY,30V-V0L"B`@("`@("`@,'AA-6)F
M-F0X92P@,'@Q,30S8S0T9BP@,'@T,SDU.#,P,BP@,'AD,#(Q-&5E8BP@,'@P
M,C(P.#-B."P@,'@S9F(V,3@P8RP@,'@Q.&8X.3,Q92P@,'@R.#$V-3AE-BP*
M("`@("`@("`P>#(V-#@V93-E+"`P>#AB9#<X83<P+"`P>#<T-S=E-&,Q+"`P
M>&(U,#9E,#=C+"`P>&8S,F0P83(U+"`P>#<Y,#DX8C`R+"`P>&4T96%B8C@Q
M+"`P>#(X,3(S8C(S+`H@("`@("`@(#!X-CED96%D,S@L(#!X,34W-&-A,38L
M(#!X9&8X-S%B-C(L(#!X,C$Q8S0P8C<L(#!X834Q83EE9CDL(#!X,#`Q-#,W
M-V(L(#!X,#0Q93AA8S@L(#!X,#DQ,30P,#,L"B`@("`@("`@,'AB9#4Y931D
M,BP@,'AE,V0Q-39D-2P@,'@T9F4X-S9D-2P@,'@R9CDQ83,T,"P@,'@U-3=B
M93AD92P@,'@P,&5A931A-RP@,'@P8V4U8S)E8RP@,'@T9&(T8F)A-BP*("`@
M("`@("`P>&4W-39B9&9F+"`P>&1D,S,V.6%C+"`P>&5C,3=B,#,U+"`P>#`V
M-3<R,S(W+"`P>#DY869C.&(P+"`P>#4V8SAC,SDQ+"`P>#9B-C4X,3%C+"`P
M>#5E,30V,3$Y+`H@("`@("`@(#!X-F4X-6-B-S4L(#!X8F4P-V,P,#(L(#!X
M8S(S,C4U-S<L(#!X.#DS9F8T96,L(#!X-6)B9F,Y,F0L(#!X9#!E8S-B,C4L
M(#!X8C<X,#%A8C<L(#!X.&0V9#-B,C0L"B`@("`@("`@,'@R,&,W-C-E9BP@
M,'AC,S8V835F8RP@,'@Y8S,X,C@X,"P@,'@P86-E,S(P-2P@,'AA86,Y-30X
M82P@,'AE8V$Q9#=C-RP@,'@P-#%A9F$S,BP@,'@Q9#$V-C(U82P*("`@("`@
M("`P>#8W,#$Y,#)C+"`P>#EB-S4W834T+"`P>#,Q9#0W-V8W+"`P>#DQ,C9B
M,#,Q+"`P>#,V8V,V9F1B+"`P>&,W,&(X8C0V+"`P>&0Y938V830X+"`P>#4V
M934U83<Y+`H@("`@("`@(#!X,#(V831C96(L(#!X-3(T,S=E9F8L(#!X,F8X
M9C<V8C0L(#!X,&1F.3@P834L(#!X.#8W-&-D93,L(#!X961D83`T96(L(#!X
M,3=A.6)E,#0L(#!X,F,Q.&8T9&8L"B`@("`@("`@,'AB-S<T-V8Y9"P@,'AA
M8C)A9C=B-"P@,'AE9F,S-&0R,"P@,'@R93`Y-F(W8RP@,'@Q-S0Q83(U-"P@
M,'AE-6(V83`S-2P@,'@R,3-D-#)F-BP@,'@R8S%C-V,R-BP*("`@("`@("`P
M>#8Q8S)F-3!F+"`P>#8U-3)D868Y+"`P>&0R8S(S,68X+"`P>#(U,3,P9C8Y
M+"`P>&0X,38W9F$R+"`P>#`T,3AF,F,X+"`P>#`P,6$Y-F$V+"`P>#!D,34R
M-F%B+`H@("`@("`@(#!X-C,S,35C,C$L(#!X-64P83<R96,L(#!X-#EB869E
M9F0L(#!X,3@W.3`X9#DL(#!X.&0P9&)D.#8L(#!X,S$Q,3<P83<L(#!X,V4Y
M8C8T,&,L(#!X8V,S93$P9#<L"B`@("`@("`@,'AD-6-A9#-B-BP@,'@P8V%E
M8S,X."P@,'AF-S,P,#%E,2P@,'@V8S<R.&%F9BP@,'@W,65A93)A,2P@,'@Q
M9CEA9C,V92P@,'AC9F-B9#$R9BP@,'AC,61E.#0Q-RP*("`@("`@("`P>&%C
M,#=B939B+"`P>&-B-#1A,60X+"`P>#AB.6(P9C4V+"`P>#`Q,SDX.&,S+"`P
M>&(Q8S4R9F-A+"`P>&(T8F4S,6-D+"`P>&0X-S@R.#`V+"`P>#$R83-A-&4R
M+`H@("`@("`@(#!X-F8W9&4U,S(L(#!X-3AF9#=E8C8L(#!X9#`Q964Y,#`L
M(#!X,C1A9&9F8S(L(#!X9C0Y.3!F8S4L(#!X.3<Q,6%A8S4L(#!X,#`Q9#=B
M.34L(#!X.#)E-64W9#(L"B`@("`@("`@,'@Q,#DX-S-F-BP@,'@P,#8Q,S`Y
M-BP@,'AC,S)D.34R,2P@,'AA9&$Q,C%F9BP@,'@R.3DP.#0Q-2P@,'@W9F)B
M.3<W9BP@,'AA9CEE8C-D8BP@,'@R.6,Y960R82P*("`@("`@("`P>#5C93)A
M-#8U+"`P>&$W,S!F,S)C+"`P>&0P86$S9F4X+"`P>#AA-6-C,#DQ+"`P>&0T
M.64R8V4W+"`P>#!C930U-&$Y+"`P>&0V,&%C9#@V+"`P>#`Q-68Q.3$Y+`H@
M("`@("`@(#!X-S<P-SDQ,#,L(#!X9&5A,#-A9C8L(#!X-SAA.#4V-64L(#!X
M9&5E,S4V9&8L(#!X,C%F,#5C8F4L(#!X.&(W-64S.#<L(#!X8C-C-3`V-3$L
M(#!X8CAA-6,S968L"B`@("`@("`@,'AD.&5E8C9D,BP@,'AE-3(S8F4W-RP@
M,'AC,C$U-#4R.2P@,'@R9C8Y969D9BP@,'AA9F4V-V%F8BP@,'AF-#<P8S1B
M,BP@,'AF,V4P96(U8BP@,'AD-F-C.3@W-BP*("`@("`@("`P>#,Y930T-C!C
M+"`P>#%F9&$X-3,X+"`P>#$Y.#<X,S)F+"`P>&-A,#`W,S8W+"`P>&$Y.3$T
M-&8X+"`P>#(Y-F(R.3EE+"`P>#0Y,F9C,CDU+"`P>#DR-C9B96%B+`H@("`@
M("`@(#!X8C4V-S9E-CDL(#!X.6)D,V1D9&$L(#!X9&8W93`U,F8L(#!X9&(R
M-3<P,6,L(#!X,6(U934Q964L(#!X9C8U,S(T938L(#!X-F%F8V4S-F,L(#!X
M,#,Q-F-C,#0L"B`@("`@("`@,'@X-C0T,C$S92P@,'AB-V1C-3ED,"P@,'@W
M.38U,CDQ9BP@,'AC8V0V9F0T,RP@,'@T,3@R,SDW.2P@,'@Y,S)B8V1F-BP@
M,'AB-C4W8S,T9"P@,'@T961F9#(X,BP*("`@("`@("`P>#=A934R.3!C+"`P
M>#-C8CDU,S9B+"`P>#@U,64R,&9E+"`P>#DX,S,U-3=E+"`P>#$S96-F,&(P
M+"`P>&0S9F9B,S<R+"`P>#-F.#5C-6,Q+"`P>#!A968W960R*3L*"B`@("`O
M*BH*("`@("`J(%,@8F]X("AS-2D*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D<S4@/2!A<G)A>2@*("`@("`@("`P>#=E8SDP
M8S`T+"`P>#)C-F4W-&(Y+"`P>#EB,&4V-F1F+"`P>&$V,S,W.3$Q+"`P>&(X
M-F$W9F9F+"`P>#%D9#,U.&8U+"`P>#0T9&0Y9#0T+"`P>#$W,S$Q-C=F+`H@
M("`@("`@(#!X,#AF8F8Q9F$L(#!X93=F-3$Q8V,L(#!X9#(P-3%B,#`L(#!X
M-S,U86)A,#`L(#!X,F%B-S(R9#@L(#!X,S@V,S@Q8V(L(#!X86-F-C(T,V$L
M(#!X-CEB969D-V$L"B`@("`@("`@,'AE-F$R93<W9BP@,'AF,&,W,C!C9"P@
M,'AC-#0Y-#@Q-BP@,'AC8V8U8S$X,"P@,'@S.#@U,38T,"P@,'@Q-6(P83@T
M."P@,'AE-CAB,3AC8BP@,'@T8V%A9&5F9BP*("`@("`@("`P>#5F-#@P83`Q
M+"`P>#`T,3)B,F%A+"`P>#(U.3@Q-&9C+"`P>#0Q9#!E9F4R+"`P>#1E-#!B
M-#AD+"`P>#(T.&5B-F9B+"`P>#AD8F$Q8V9E+"`P>#0Q83DY8C`R+`H@("`@
M("`@(#!X,6$U-3!A,#0L(#!X8F$X9C8U8V(L(#!X-S(U,68T93<L(#!X.35A
M-3$W,C4L(#!X8S$P-F5C9#<L(#!X.3=A-3DX,&$L(#!X8S4S.6(Y86$L(#!X
M-&0W.69E-F$L"B`@("`@("`@,'AF,F8S9C<V,RP@,'@V.&%F.#`T,"P@,'AE
M9#!C.64U-BP@,'@Q,6(T.34X8BP@,'AE,65B-6$X."P@,'@X-S`Y939B,"P@
M,'AD-V4P-S$U-BP@,'@T93(Y9F5A-RP*("`@("`@("`P>#8S-C9E-3)D+"`P
M>#`R9#%C,#`P+"`P>&,T86,X93`U+"`P>#DS-S=F-3<Q+"`P>#!C,#4S-S)A
M+"`P>#4W.#4S-68R+"`P>#(R-C%B93`R+"`P>&0V-#)A,&,Y+`H@("`@("`@
M(#!X9&8Q,V$R.#`L(#!X-S1B-35B9#(L(#!X-C@R,3DY8S`L(#!X9#0R,64U
M96,L(#!X-3-F8C-C93@L(#!X8SAA9&5D8C,L(#!X,CAA.#=F8SDL(#!X,V0Y
M-3DY.#$L"B`@("`@("`@,'@U8S%F9CDP,"P@,'AF93,X9#,Y.2P@,'@P8S1E
M9F8P8BP@,'@P-C(T,#=E82P@,'AA83)F-&9B,2P@,'@T9F(Y-CDW-BP@,'@Y
M,&,W.34P-2P@,'AB,&$X83<W-"P*("`@("`@("`P>&5F-35A,69F+"`P>&4U
M.6-A,F,R+"`P>&$V8C8R9#(W+"`P>&4V-F$T,C8S+"`P>&1F-C4P,#%F+"`P
M>#!E8S4P.38V+"`P>&1F9&0U-6)C+"`P>#(Y9&4P-C4U+`H@("`@("`@(#!X
M.3$Q93<S.6$L(#!X,3=A9C@Y-S4L(#!X,S)C-SDQ,6,L(#!X.#EF.#DT-C@L
M(#!X,&0P,64Y.#`L(#!X-3(T-S4U9C0L(#!X,#-B-C-C8SDL(#!X,&-C.#0T
M8C(L"B`@("`@("`@,'AB8V8S9C!A82P@,'@X-V%C,S9E.2P@,'AE-3-A-S0R
M-BP@,'@P,6(S9#@R8BP@,'@Q83EE-S0T.2P@,'@V-&5E,F0W92P@,'AC9&1B
M8C%D82P@,'@P,6,Y-#DQ,"P*("`@("`@("`P>&(X-CAB9C@P+"`P>#!D,C9F
M,V9D+"`P>#DS-#)E9&4W+"`P>#`T835C,C@T+"`P>#8S-C<S-V(V+"`P>#4P
M9C5B-C$V+"`P>&8R-#<V-F4S+"`P>#AE8V$S-F,Q+`H@("`@("`@(#!X,3,V
M93`U9&(L(#!X9F5F,3@S.3$L(#!X9F(X.#=A,S<L(#!X9#9E-V8W9#0L(#!X
M8S=F8C=D8SDL(#!X,S`V,V9C9&8L(#!X8C9F-3@Y9&4L(#!X96,R.30Q9&$L
M"B`@("`@("`@,'@R-F4T-C8Y-2P@,'AB-S4V-C0Q.2P@,'AF-C4T969C-2P@
M,'AD,#AD-3AB-RP@,'@T.#DR-30P,2P@,'AC,6)A8V(W9BP@,'AE-69F-34P
M9BP@,'AB-C`X,S`T.2P*("`@("`@("`P>#5B8C5D,&4X+"`P>#@W9#<R935A
M+"`P>&%B-F$V964Q+"`P>#(R,V$V-F-E+"`P>&,V,F)F,V-D+"`P>#EE,#@X
M-68Y+"`P>#8X8V(S930W+"`P>#`X-F,P,3!F+`H@("`@("`@(#!X83(Q9&4X
M,C`L(#!X9#$X8C8Y9&4L(#!X9C-F-C4W-S<L(#!X9F$P,F,S9C8L(#!X-#`W
M961A8S,L(#!X8V)B,V0U-3`L(#!X,3<Y,S`X-&0L(#!X8C!D-S!E8F$L"B`@
M("`@("`@,'@P86(S-SAD-2P@,'AD.34Q9F(P8RP@,'AD960W9&$U-BP@,'@T
M,3(T8F)E-"P@,'@Y-&-A,&(U-BP@,'@P9C4W-35D,2P@,'AE,&4Q934V92P@
M,'@V,3@T8C5B92P*("`@("`@("`P>#4X,&$R-#EF+"`P>#DT9C<T8F,P+"`P
M>&4S,C<X.#AE+"`P>#EF-V(U-38Q+"`P>&,S9&,P,C@P+"`P>#`U-C@W-S$U
M+"`P>#8T-F,V8F0W+"`P>#0T.3`T9&(S+`H@("`@("`@(#!X-C9B-&8P83,L
M(#!X8S!F,38T.&$L(#!X-CDW960U868L(#!X-#EE.3)F9C8L(#!X,S`Y93,W
M-&8L(#!X,F-B-C,U-F$L(#!X.#4X,#@U-S,L(#!X-#DY,68X-#`L"B`@("`@
M("`@,'@W-F8P864P,BP@,'@P.#-B93@T9"P@,'@R.#0R,6,Y82P@,'@T-#0X
M.30P-BP@,'@W,S9E-&-B."P@,'AC,3`Y,CDQ,"P@,'@X8F,Y-69C-BP@,'@W
M9#@V.6-F-"P*("`@("`@("`P>#$S-&8V,39F+"`P>#)E-S<Q,3AD+"`P>&(S
M,6(R8F4Q+"`P>&%A.3!B-#<R+"`P>#-C835D-S$W+"`P>#=D,38Q8F)A+"`P
M>#EC860Y,#$P+"`P>&%F-#8R8F$R+`H@("`@("`@(#!X.69E-#4Y9#(L(#!X
M-#5D,S0U-3DL(#!X9#EF,F1A,3,L(#!X9&)C-C4T.#<L(#!X9C-E-&8Y-&4L
M(#!X,3<V9#0X-F8L(#!X,#DW8S$S96$L(#!X-C,Q9&$U8S<L"B`@("`@("`@
M,'@T-#5F-S,X,BP@,'@Q-S4V.#-F-"P@,'AC9&,V-F$Y-RP@,'@W,&)E,#(X
M."P@,'AB,V-D8V8W,BP@,'@V935D9#)F,RP@,'@R,#DS-C`W.2P@,'@T-3EB
M.#!A-2P*("`@("`@("`P>&)E-C!E,F1B+"`P>&$Y8S(S,3`Q+"`P>&5B834S
M,35C+"`P>#(R-&4T,F8R+"`P>#%C-6,Q-3<R+"`P>&8V-S(Q8C)C+"`P>#%A
M9#)F9F8S+"`P>#AC,C4T,#1E+`H@("`@("`@(#!X,S(T960W,F8L(#!X-#`V
M-V(W9F0L(#!X,#4R,S$S.&4L(#!X-6-A,V)C-S@L(#!X9&,P9F0V-F4L(#!X
M-S4Y,C(R.#,L(#!X-S@T9#9B,3<L(#!X-3AE8F(Q-F4L"B`@("`@("`@,'@T
M-#`Y-&8X-2P@,'@S9C0X,60X-RP@,'AF8V9E864W8BP@,'@W-V(U9F8W-BP@
M,'@X8S(S,#)B9BP@,'AA868T-S4U-BP@,'@U9C0V8C`R82P@,'@R8C`Y,C@P
M,2P*("`@("`@("`P>#-D,SAF-68W+"`P>#!C83@Q9C,V+"`P>#4R868T83AA
M+"`P>#8V9#5E-V,P+"`P>&1F,V(P.#<T+"`P>#DU,#4U,3$P+"`P>#%B-6%D
M-V$X+"`P>&8V,65D-6%D+`H@("`@("`@(#!X-F-F-F4T-SDL(#!X,C`W-3@Q
M.#0L(#!X9#!C969A-C4L(#!X.#AF-V)E-3@L(#!X-&$P-#8X,C8L(#!X,&9F
M-F8X9C,L(#!X83`Y8S=F-S`L(#!X-3,T-F%B83`L"B`@("`@("`@,'@U8V4Y
M-F,R."P@,'AE,3<V961A,RP@,'@V8F%C,S`W9BP@,'@S-S8X,CED,BP@,'@X
M-3,V,&9A.2P@,'@Q-V4S9F4R82P@,'@R-&(W.3<V-RP@,'AF-6$Y-F(R,"P*
M("`@("`@("`P>&0V8V0R-3DU+"`P>#8X9F8Q96)F+"`P>#<U-34T-#)C+"`P
M>&8Q.68P-F)E+"`P>&8Y93`V-3EA+"`P>&5E8CDT.3%D+"`P>#,T,#$P-S$X
M+"`P>&)B,S!C86(X+`H@("`@("`@(#!X93@R,F9E,34L(#!X.#@U-S`Y.#,L
M(#!X-S4P938R-#DL(#!X9&$V,C=E-34L(#!X-64W-F9F83@L(#!X8C$U,S0U
M-#8L(#!X-F0T-V1E,#@L(#!X969E.64W9#0I.PH*("`@("\J*@H@("`@("H@
M4R!B;W@@*',V*0H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1S-B`](&%R<F%Y*`H@("`@("`@(#!X9C9F83AF.60L(#!X,F-A
M8S9C93$L(#!X-&-A,S0X-C<L(#!X93(S,S=F-V,L(#!X.35D8C`X93<L(#!X
M,#$V.#0S8C0L(#!X96-E9#5C8F,L(#!X,S(U-34S86,L"B`@("`@("`@,'AB
M9CEF,#DV,"P@,'AD9F$Q93)E9"P@,'@X,V8P-3<Y9"P@,'@V,V5D.#9B.2P@
M,'@Q86(V839B."P@,'AD935E8F4S.2P@,'AF,SAF9C<S,BP@,'@X.3@Y8C$S
M."P*("`@("`@("`P>#,S9C$T.38Q+"`P>&,P,3DS-V)D+"`P>&8U,#9C-F1A
M+"`P>&4T-C(U93=E+"`P>&$S,#AE83DY+"`P>#1E,C-E,S-C+"`P>#<Y8V)D
M-V-C+"`P>#0X83$T,S8W+`H@("`@("`@(#!X83,Q-#DV,3DL(#!X9F5C.31B
M9#4L(#!X83$Q-#$W-&$L(#!X96%A,#$X-C8L(#!X83`X-&1B,F0L(#!X,#EA
M.#0X-F8L(#!X83@X.#8Q-&$L(#!X,CDP,&%F.3@L"B`@("`@("`@,'@P,38V
M-3DY,2P@,'AE,3DY,C@V,RP@,'AC.&8S,&,V,"P@,'@R93<X968S8RP@,'AD
M,&0U,3DS,BP@,'AC9C!F96,Q-"P@,'AF-V-A,#=D,BP@,'AD,&$X,C`W,BP*
M("`@("`@("`P>&9D-#$Q.3=E+"`P>#DS,#5A-F(P+"`P>&4X-F)E,V1A+"`P
M>#<T8F5D,V-D+"`P>#,W,F1A-3-C+"`P>#1C-V8T-#0X+"`P>&1A8C5D-#0P
M+"`P>#9D8F$P96,S+`H@("`@("`@(#!X,#@S.3$Y83<L(#!X.69B865E9#DL
M(#!X-#ED8F-F8C`L(#!X-&4V-S!C-3,L(#!X-6,S9#EC,#$L(#!X-C1B9&(Y
M-#$L(#!X,F,P938S-F$L(#!X8F$W9&0Y8V0L"B`@("`@("`@,'AE839F-S,X
M."P@,'AE-S!B8S<V,BP@,'@S-68R.6%D8BP@,'@U8S1C9&0X9"P@,'AF,&0T
M.&0X8RP@,'AB.#@Q-3-E,BP@,'@P.&$Q.3@V-BP@,'@Q864R96%C."P*("`@
M("`@("`P>#(X-&-A9C@Y+"`P>&%A.3(X,C(S+"`P>#DS,S1B934S+"`P>#-B
M,V$R,6)F+"`P>#$V-#,T8F4S+"`P>#EA96$S.3`V+"`P>&5F93AC,S9E+"`P
M>&8X.3!C9&0Y+`H@("`@("`@(#!X.#`R,C9D864L(#!X8S,T,&$T83,L(#!X
M9&8W93EC,#DL(#!X838Y-&$X,#<L(#!X-6(W8S5E8V,L(#!X,C(Q9&(S838L
M(#!X.6$V.6$P,F8L(#!X-C@X,3AA-30L"B`@("`@("`@,'AC96(R,CDV9BP@
M,'@U,V,P.#0S82P@,'AF93@Y,S8U-2P@,'@R-6)F938X82P@,'AB-#8R.&%B
M8RP@,'AC9C(R,F5B9BP@,'@R-6%C-F8T."P@,'AA.6$Y.3,X-RP*("`@("`@
M("`P>#4S8F1D8C8U+"`P>&4W-F9F8F4W+"`P>&4Y-C=F9#<X+"`P>#!B83DS
M-38S+"`P>#AE,S0R8F,Q+"`P>&4X83$Q8F4Y+"`P>#0Y.#`W-#!D+"`P>&,X
M,#@W9&9C+`H@("`@("`@(#!X.&1E-&)F.3DL(#!X83$Q,3`Q83`L(#!X-V9D
M,S<Y-S4L(#!X9&$U83(V8S`L(#!X93@Q9CDY-&8L(#!X.34R.&-D.#DL(#!X
M9F0S,SEF960L(#!X8C@W.#,T8F8L"B`@("`@("`@,'@U9C`T-#4V9"P@,'@R
M,C(U.#8Y."P@,'AC.6,T8S@S8BP@,'@R9&,Q-39B92P@,'@T9C8R.&1A82P@
M,'@U-V8U-65C-2P@,'AE,C(R,&%B92P@,'AD,CDQ-F5B9BP*("`@("`@("`P
M>#1E8S<U8CDU+"`P>#(T9C)C,V,P+"`P>#0R9#$U9#DY+"`P>&-D,&0W9F$P
M+"`P>#=B-F4R-V9F+"`P>&$X9&,X868P+"`P>#<S-#5C,3`V+"`P>&8T,64R
M,S)F+`H@("`@("`@(#!X,S4Q-C(S.#8L(#!X939E83@Y,C8L(#!X,S,S,V(P
M.30L(#!X,34W96,V9C(L(#!X,S<R8C<T868L(#!X-CDR-3<S930L(#!X93EA
M.60X-#@L(#!X9C,Q-C`R.#DL"B`@("`@("`@,'@S838R968Q9"P@,'AA-S@W
M93(S."P@,'AF,V$U9C8W-BP@,'@W-#,V-#@U,RP@,'@R,#DU,3`V,RP@,'@T
M-3<V-CDX9"P@,'AB-F9A9#0P-RP@,'@U.3)A9CDU,"P*("`@("`@("`P>#,V
M9C<S-3(S+"`P>#1C9F(V93@W+"`P>#=D831C96,P+"`P>#9C,34R9&%A+"`P
M>&-B,#,Y-F$X+"`P>&,U,&1F935D+"`P>&9C9#<P-V%B+"`P>#`Y,C%C-#)F
M+`H@("`@("`@(#!X.#ED9F8P8F(L(#!X-69E,F)E-S@L(#!X-#0X9C1F,S,L
M(#!X-S4T-C$S8SDL(#!X,F(P-60P.&0L(#!X-#AB.60U.#4L(#!X9&,P-#DT
M-#$L(#!X8S@P.3AF.6(L"B`@("`@("`@,'@W9&5D93<X-BP@,'AC,SEA,S,W
M,RP@,'@T,C0Q,#`P-2P@,'@V83`Y,3<U,2P@,'@P968S8SAA-BP@,'@X.3`P
M-S)D-BP@,'@R.#(P-S8X,BP@,'AA.6$Y9C=B92P*("`@("`@("`P>&)F,S(V
M-SED+"`P>&0T-6(U8C<U+"`P>&(S-3-F9#`P+"`P>&-B8C!E,S4X+"`P>#@S
M,&8R,C!A+"`P>#%F.&9B,C$T+"`P>&0S-S)C9C`X+"`P>&-C,V,T83$S+`H@
M("`@("`@(#!X.&-F-C,Q-C8L(#!X,#8Q8S@W8F4L(#!X.#AC.3AF.#@L(#!X
M-C`V,F4S.3<L(#!X-#=C9CAE-V$L(#!X8C9C.#4R.#,L(#!X,V-C,F%C9F(L
M(#!X,V9C,#8Y-S8L"B`@("`@("`@,'@T93AF,#(U,BP@,'@V-&0X,S$T9"P@
M,'AD83,X-S!E,RP@,'@Q938V-30U.2P@,'AC,3`Y,#AF,"P@,'@U,3,P,C%A
M-2P@,'@V8S5B-CAB-RP@,'@X,C)F.&%A,"P*("`@("`@("`P>#,P,#=C9#-E
M+"`P>#<T-S$Y965F+"`P>&1C.#<R-C@Q+"`P>#`W,S,T,&0T+"`P>#=E-#,R
M9F0Y+"`P>#!C-65C,C0Q+"`P>#@X,#DR.#9C+"`P>&8U.3)D.#DQ+`H@("`@
M("`@(#!X,#AA.3,P9C8L(#!X.34W968S,#4L(#!X8C=F8F9F8F0L(#!X8S(V
M-F4Y-F8L(#!X-F9E-&%C.3@L(#!X8C$W,V5C8S`L(#!X8F,V,&(T,F$L(#!X
M.34S-#DX9&$L"B`@("`@("`@,'AF8F$Q864Q,BP@,'@R9#1B9#<S-BP@,'@P
M9C(U9F%A8BP@,'AA-&8S9F-E8BP@,'AE,CDV.3$R,RP@,'@R-3=F,&,S9"P@
M,'@Y,S0X868T.2P@,'@S-C$T,#!B8RP*("`@("`@("`P>&4X.#$V9C1A+"`P
M>#,X,31F,C`P+"`P>&$S9CDT,#0S+"`P>#EC-V$U-&,R+"`P>&)C-S`T9C4W
M+"`P>&1A-#%E-V8Y+"`P>&,R-6%D,S-A+"`P>#4T9C1A,#@T+`H@("`@("`@
M(#!X8C$W9C4U,#4L(#!X-3DS-3=C8F4L(#!X961B9#$U8S@L(#!X-V8Y-V,U
M86(L(#!X8F$U86,W8C4L(#!X8C9F-F1E868L(#!X,V$T-SEC,V$L(#!X-3,P
M,F1A,C4L"B`@("`@("`@,'@V-3-D-V4V82P@,'@U-#(V.&0T.2P@,'@U,6$T
M-S=E82P@,'@U,#$W9#4U8BP@,'AD-V0R-60X."P@,'@T-#$S-F,W-BP@,'@P
M-#`T83AC."P@,'AB.&4U83$R,2P*("`@("`@("`P>&(X,6$Y,CAA+"`P>#8P
M960U.#8Y+"`P>#DW8S4U8CDV+"`P>&5A96,Y.3%B+"`P>#(Y.3,U.3$S+"`P
M>#`Q9F1B-V8Q+"`P>#`X.&4X9&9A+"`P>#EA8C9F-F8U+`H@("`@("`@(#!X
M,V(T8V)F.68L(#!X-&$U9&4S86(L(#!X938P-3%D,S4L(#!X83!E,60X-34L
M(#!X9#,V8C1C9C$L(#!X9C4T-&5D96(L(#!X8C!E.3,U,C0L(#!X8F5B8CAF
M8F0L"B`@("`@("`@,'AA,F0W-C)C9BP@,'@T.6,Y,F8U-"P@,'@S.&(U9C,S
M,2P@,'@W,3(X830U-"P@,'@T.#,Y,CDP-2P@,'AA-C5B,61B."P@,'@X-3%C
M.3=B9"P@,'AD-C<U8V8R9BD["@H@("`@+RHJ"B`@("`@*B!3(&)O>"`H<S<I
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)',W
M(#T@87)R87DH"B`@("`@("`@,'@X-64P-#`Q.2P@,'@S,S)B9C4V-RP@,'@V
M-C)D8F9F9BP@,'AC9F,V-38Y,RP@,'@R83AD-V8V9BP@,'AA8CEB8SDQ,BP@
M,'AD938P,#AA,2P@,'@R,#(X9&$Q9BP*("`@("`@("`P>#`R,C=B8V4W+"`P
M>#1D-C0R.3$V+"`P>#$X9F%C,S`P+"`P>#4P9C$X8C@R+"`P>#)C8C)C8C$Q
M+"`P>&(R,S)E-S5C+"`P>#1B,S8Y-68R+"`P>&(R.#<P-V1E+`H@("`@("`@
M(#!X83`U9F)C9C8L(#!X8V0T,3@Q93DL(#!X93$U,#(Q,&,L(#!X93(T968Q
M8F0L(#!X8C$V.&,S.#$L(#!X9F1E-&4W.#DL(#!X-6,W.6(P9#@L(#!X,64X
M8F9D-#,L"B`@("`@("`@,'@T9#0Y-3`P,2P@,'@S.&)E-#,T,2P@,'@Y,3-C
M964Q9"P@,'@Y,F$W.6,S9BP@,'@P.#DW-C9B92P@,'AB865E861F-"P@,'@Q
M,C@V8F5C9BP@,'AB-F5A8V(Q.2P*("`@("`@("`P>#(V-C!C,C`P+"`P>#<U
M-C5B9&4T+"`P>#8T,C0Q9C=A+"`P>#@R-#AD8V$Y+"`P>&,S8C-A9#8V+"`P
M>#(X,3,V,#@V+"`P>#!B9#AD9F$X+"`P>#,U-F0Q8V8R+`H@("`@("`@(#!X
M,3`W-S@Y8F4L(#!X8C-B,F4Y8V4L(#!X,#4P,F%A.&8L(#!X,&)C,#,U,64L
M(#!X,38V8F8U,F$L(#!X96(Q,F9F.#(L(#!X93,T.#8Y,3$L(#!X9#,T9#<U
M,38L"B`@("`@("`@,'@T93=B,V%F9BP@,'@U9C0S-C<Q8BP@,'@Y8V8V93`S
M-RP@,'@T.3@Q86,X,RP@,'@S,S0R-C9C92P@,'@X8SDS-#%B-RP@,'AD,&0X
M-31C,"P@,'AC8C-A-F,X."P*("`@("`@("`P>#0W8F,R.#(Y+"`P>#0W,C5B
M83,W+"`P>&$V-F%D,C)B+"`P>#=A9#8Q9C%E+"`P>#!C-6-B869A+"`P>#0T
M,S=F,3`W+"`P>&(V93<Y.38R+"`P>#0R9#)D.#$V+`H@("`@("`@(#!X,&$Y
M-C$R.#@L(#!X93%A-6,P-F4L(#!X,3,W-#EE-C<L(#!X-S)F8S`X,6$L(#!X
M8C%D,3,Y9C<L(#!X9CDU.#,W-#4L(#!X8V8Q.61F-3@L(#!X8F5C,V8W-38L
M"B`@("`@("`@,'AC,#9E8F$S,"P@,'@P-S(Q,6(R-"P@,'@T-6,R.#@R.2P@
M,'AC.35E,S$W9BP@,'AB8SAE8S4Q,2P@,'@S.&)C-#9E.2P@,'AC-F4V9F$Q
M-"P@,'AB864X-3@T82P*("`@("`@("`P>&%D-&5B8S0V+"`P>#0V.&8U,#AB
M+"`P>#<X,CDT,S5F+"`P>&8Q,C0Q.#-B+"`P>#@R,61B83EF+"`P>&%F9C8P
M9F8T+"`P>&5A,F,T939D+"`P>#$V93,Y,C8T+`H@("`@("`@(#!X.3(U-#1A
M.&(L(#!X,#`Y8C1F8S,L(#!X86)A-CAC960L(#!X.6%C.39F-S@L(#!X,#9A
M-6(W.6$L(#!X8C(X-39E-F4L(#!X,6%E8S-C83DL(#!X8F4X,S@V.#@L"B`@
M("`@("`@,'@P93`X,#1E.2P@,'@U-68Q8F4U-BP@,'AE-V4U,S8S8BP@,'AB
M,V$Q9C(U9"P@,'AF-V1E8F(X-2P@,'@V,69E,#,S8RP@,'@Q-C<T-C(S,RP@
M,'@S8S`S-&,R."P*("`@("`@("`P>&1A-F0P8S<T+"`P>#<Y86%C-39C+"`P
M>#-C931E,6%D+"`P>#4Q9C!C.#`R+"`P>#DX9CAF,S5A+"`P>#$V,C9A-#EF
M+"`P>&5E9#@R8C(Y+"`P>#%D,S@R9F4S+`H@("`@("`@(#!X,&,T9F(Y.6$L
M(#!X8F(S,C4W-S@L(#!X,V5C-F0Y-V(L(#!X-F4W-V$V83DL(#!X8V(V-3AB
M-6,L(#!X9#0U,C,P8S<L(#!X,F)D,30P.&(L(#!X-C!C,#-E8C<L"B`@("`@
M("`@,'AB.3`V.&0W."P@,'AA,S,W-31F-"P@,'AF-#,P8S@W9"P@,'AC.&$W
M,3,P,BP@,'AB.39D.&,S,BP@,'AE8F0T93=B92P@,'AB93AB.60R9"P@,'@W
M.3<Y9F(P-BP*("`@("`@("`P>&4W,C(U,S`X+"`P>#AB-S5C9C<W+"`P>#$Q
M968X9&$T+"`P>&4P.#-C.#4X+"`P>#AD-F(W.#9F+"`P>#5A-C,Q-V$V+"`P
M>&9A-6-F-V$P+"`P>#5D9&$P,#,S+`H@("`@("`@(#!X9C(X96)F8C`L(#!X
M9C5B.6,S,3`L(#!X83!E86,R.#`L(#!X,#AB.3<V-V$L(#!X83-D.60R8C`L
M(#!X-SED,S0R,3<L(#!X,#(Q83<Q.&0L(#!X.6%C-C,S-F$L"B`@("`@("`@
M,'@R-S$Q9F0V,"P@,'@T,S@P-3!E,RP@,'@P-CDY,#AA."P@,'@S9#=F961C
M-"P@,'@X,C9D,F)E9BP@,'@T965B.#0W-BP@,'@T.#AD8V8R-2P@,'@S-F,Y
M9#4V-BP*("`@("`@("`P>#(X93<T930Q+"`P>&,R-C$P86-A+"`P>#-D-#EA
M.6-F+"`P>&)A93-B.61F+"`P>&(V-68X9&4V+"`P>#DR865A9C8T+"`P>#-A
M8S=D-64V+"`P>#EE83@P-3`Y+`H@("`@("`@(#!X9C(R8C`Q-V0L(#!X830Q
M-S-F-S`L(#!X9&0Q93$V8S,L(#!X,35E,&0W9CDL(#!X-3!B,6(X.#<L(#!X
M,F(Y9C1F9#4L(#!X-C(U86)A.#(L(#!X-F$P,3<Y-C(L"B`@("`@("`@,'@R
M96,P,6(Y8RP@,'@Q-30X.&%A.2P@,'AD-S$V93<T,"P@,'@T,#`U-6$R8RP@
M,'@Y,V0R.6$R,BP@,'AE,S)D8F8Y82P@,'@P-3@W-#5B.2P@,'@S-#4S9&,Q
M92P*("`@("`@("`P>&0V.3DR.39E+"`P>#0Y-F-F9C9F+"`P>#%C.68T.3@V
M+"`P>&1F93)E9#`W+"`P>&(X-S(T,F0Q+"`P>#$Y9&4W96%E+"`P>#`U,V4U
M-C%A+"`P>#$U860V9CAC+`H@("`@("`@(#!X-C8V,C9C,6,L(#!X-S$U-&,R
M-&,L(#!X96$P.#)B,F$L(#!X.3-E8C(Y,SDL(#!X,3=D8V(P9C`L(#!X-3AD
M-&8R864L(#!X.65A,CDT9F(L(#!X-3)C9C4V-&,L"B`@("`@("`@,'@Y.#@S
M9F4V-BP@,'@R96,T,#4X,2P@,'@W-C,Y-3-C,RP@,'@P,60V-CDR92P@,'AD
M,V$P8S$P."P@,'AA,64W,38P92P@,'AE-&8R9&9A-BP@,'@V.3-E9#(X-2P*
M("`@("`@("`P>#<T.3`T-CDX+"`P>#1C,F(P961D+"`P>#1F-S4W-C4V+"`P
M>#5D,SDS,S<X+"`P>&$Q,S(R,S1F+"`P>#-D,S(Q8S5D+"`P>&,S9C5E,3DT
M+"`P>#1B,C8Y,S`Q+`H@("`@("`@(#!X8S<Y9C`R,F8L(#!X,V,Y.3=E-V4L
M(#!X-64T9CDU,#0L(#!X,V9F869B8F0L(#!X-S9F-V%D,&4L(#!X,CDV-CDS
M9C0L(#!X,V0Q9F-E-F8L(#!X8S8Q930U8F4L"B`@("`@("`@,'AD,V(U86(S
M-"P@,'AF-S)B9CEB-RP@,'@Q8C`T,S1C,"P@,'@T93<R8C4V-RP@,'@U-3DR
M83,S9"P@,'AB-3(R.3,P,2P@,'AC9F0R83@W9BP@,'@V,&%E8C<V-RP*("`@
M("`@("`P>#$X,30S.#9B+"`P>#,P8F-C,S-D+"`P>#,X83!C,#=D+"`P>&9D
M,38P-F8R+"`P>&,S-C,U,3EB+"`P>#4X.61D,SDP+"`P>#4T-SEF.&4V+"`P
M>#%C8CAD-C0W+`H@("`@("`@(#!X.3=F9#8Q83DL(#!X96$W-S4Y9C0L(#!X
M,F0U-S4S.60L(#!X-38Y834X8V8L(#!X93@T938S860L(#!X-#8R93%B-S@L
M(#!X-C4X,&8X-V4L(#!X9C,X,3<Y,30L"B`@("`@("`@,'@Y,61A-35F-"P@
M,'@T,&$R,S!F,RP@,'AD,3DX.&8S-2P@,'AB-F4S,3AD,BP@,'@S9F9A-3!B
M8RP@,'@S9#0P9C`R,2P@,'AC,V,P8F1A92P@,'@T.34X8S(T8RP*("`@("`@
M("`P>#4Q.&8S-F(R+"`P>#@T8C%D,S<P+"`P>#!F961C93@S+"`P>#@W.&1D
M861A+"`P>&8R83(W.6,W+"`P>#DT93`Q8F4X+"`P>#DP-S$V9C1B+"`P>#DU
M-&(X86$S*3L*"B`@("`O*BH*("`@("`J(%,@8F]X("AS."D*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D<S@@/2!A<G)A>2@*
M("`@("`@("`P>&4R,38S,#!D+"`P>&)B9&1F9F9C+"`P>&$W96)D86)D+"`P
M>#,U-C0X,#DU+"`P>#<W.#EF.&(W+"`P>&4V8S$Q,C%B+"`P>#!E,C0Q-C`P
M+"`P>#`U,F-E.&(U+`H@("`@("`@(#!X,3%A.6-F8C`L(#!X934Y-3)F,3$L
M(#!X96-E-SDY,&$L(#!X.3,X-F0Q-S0L(#!X,F$T,CDS,6,L(#!X-S9E,S@Q
M,3$L(#!X8C$R9&5F,V$L(#!X,S=D9&1D9F,L"B`@("`@("`@,'AD93EA9&5B
M,2P@,'@P83!C8S,R8RP@,'AB93$Y-S`R.2P@,'@X-&$P,#DT,"P@,'AB8C(T
M,V$P9BP@,'AB-&0Q,S=C9BP@,'AB-#1E-SEF,"P@,'@P-#EE961F9"P*("`@
M("`@("`P>#!B,35A,35D+"`P>#0X,&0S,38X+"`P>#AB8F)D935A+"`P>#8V
M.61E9#0R+"`P>&,W96-E.#,Q+"`P>#-F.&8Y-64W+"`P>#<R9&8Q.3%B+"`P
M>#<U.#`S,S!D+`H@("`@("`@(#!X.30P-S0R-3$L(#!X-6,W9&-D9F$L(#!X
M86)B939D-C,L(#!X86$T,#(Q-C0L(#!X8C,P,60T,&$L(#!X,#)E-V0Q8V$L
M(#!X-3,U-S%D864L(#!X-V$S,3@R83(L"B`@("`@("`@,'@Q,F$X9&1E8RP@
M,'AF9&%A,S,U9"P@,'@Q-S9F-#-E."P@,'@W,69B-#9D-"P@,'@S.#$R.3`R
M,BP@,'AC93DT.6%D-"P@,'AB.#0W-CEA9"P@,'@Y-C5B9#@V,BP*("`@("`@
M("`P>#@R9C-D,#4U+"`P>#8V9F(Y-S8W+"`P>#$U8C@P8C1E+"`P>#%D-6(T
M-V$P+"`P>#1C9F1E,#9F+"`P>&,R.&5C-&(X+"`P>#4W93@W,C9E+"`P>#8T
M-V$W.&9C+`H@("`@("`@(#!X.3DX-C5D-#0L(#!X-C`X8F0U.3,L(#!X-F,R
M,#!E,#,L(#!X,SED8S5F9C8L(#!X-60P8C`P83,L(#!X864V,V%F9C(L(#!X
M-V4X8F0V,S(L(#!X-S`Q,#AC,&,L"B`@("`@("`@,'AB8F0S-3`T.2P@,'@R
M.3DX9&8P-"P@,'@Y.#!C9C0R82P@,'@Y8C9D9C0Y,2P@,'@Y93=E9&0U,RP@
M,'@P-CDQ.#4T."P@,'@U.&-B-V4P-RP@,'@S8C<T968R92P*("`@("`@("`P
M>#4R,F9F9F(Q+"`P>&0R-#<P.&-C+"`P>#%C-V4R-V-D+"`P>&$T96(R,35B
M+"`P>#-C9C%D,F4R+"`P>#$Y8C0W83,X+"`P>#0R-&8W-C$X+"`P>#,U.#4V
M,#,Y+`H@("`@("`@(#!X.60Q-V1E93<L(#!X,C=E8C,U938L(#!X8SEA9F8V
M-V(L(#!X,S9B868U8C@L(#!X,#EC-#8W8V0L(#!X8S$X.3$P8C$L(#!X93$Q
M9&)F-V(L(#!X,#9C9#%A9C@L"B`@("`@("`@,'@W,3<P8S8P."P@,'@R9#5E
M,S,U-"P@,'AD-&1E-#DU82P@,'@V-&,V9#`P-BP@,'AB8V,P8S8R8RP@,'@S
M9&0P,&1B,RP@,'@W,#AF.&8S-"P@,'@W-V0U,6(T,BP*("`@("`@("`P>#(V
M-&8V,C!F+"`P>#(T8CAD,F)F+"`P>#$U8S%B-SEE+"`P>#0V834R-38T+"`P
M>&8X9#=E-31E+"`P>#-E,S<X,38P+"`P>#<X.35C9&$U+"`P>#@U.6,Q-6$U
M+`H@("`@("`@(#!X938T-3DW.#@L(#!X8S,W8F,W-68L(#!X9&(P-V)A,&,L
M(#!X,#8W-F$S86(L(#!X-V8R,CEB,64L(#!X,S$X-#)E-V(L(#!X,C0R-3EF
M9#<L(#!X9CAB968T-S(L"B`@("`@("`@,'@X,S5F9F-B."P@,'@V9&8T8S%F
M,BP@,'@Y-F8U8C$Y-2P@,'AF9#!A9C!F8RP@,'AB,&9E,3,T8RP@,'AE,C4P
M-F0S9"P@,'@T9CEB,3)E82P@,'AF,C$U9C(R-2P*("`@("`@("`P>&$R,C,W
M,S9F+"`P>#EF8C1C-#(X+"`P>#(U9#`T.3<Y+"`P>#,T8S<Q,V8X+"`P>&,T
M-C$X,3@W+"`P>&5A-V$V93DX+"`P>#=C9#$V969C+"`P>#$T,S8X-S9C+`H@
M("`@("`@(#!X9C$U-#0Q,#<L(#!X8F5D965E,30L(#!X-39E.6%F,C<L(#!X
M83`T86$T-#$L(#!X,V-F-V,X.3DL(#!X.3)E8V)A938L(#!X9&0V-S`Q-F0L
M(#!X,34Q-C@R96(L"B`@("`@("`@,'AA.#0R965D9BP@,'AF9&)A-C!B-"P@
M,'AF,3DP-V(W-2P@,'@R,&4S,#,P9BP@,'@R-&0X8S(Y92P@,'AE,3,Y-C<S
M8BP@,'AE9F$V,V9B."P@,'@W,3@W,S`U-"P*("`@("`@("`P>&(V9C)C9C-B
M+"`P>#EF,S(V-#0R+"`P>&-B,35A-&-C+"`P>&(P,6$T-3`T+"`P>&8Q930W
M9#AD+"`P>#@T-&$Q8F4U+"`P>&)A93=D9F1C+"`P>#0R8V)D83<P+`H@("`@
M("`@(#!X8V0W9&%E,&$L(#!X-3=E.#5B-V$L(#!X9#4S9C5A9C8L(#!X,C!C
M9C1D.&,L(#!X8V5A-&0T,C@L(#!X-SED,3,P830L(#!X,S0X-F5B9F(L(#!X
M,S-D,V-D9&,L"B`@("`@("`@,'@W-S@U,V(U,RP@,'@S-V5F9F-B-2P@,'AC
M-3`V.#<W."P@,'AE-3@P8C-E-BP@,'@T938X8CAF-"P@,'AC-6,X8C,W92P@
M,'@P9#@P.65A,BP@,'@S.3AF96(W8RP*("`@("`@("`P>#$S,F$T9CDT+"`P
M>#0S8C<Y-3!E+"`P>#)F964W9#%C+"`P>#(R,S8Q,V)D+"`P>&1D,#9C86$R
M+"`P>#,W9&8Y,S)B+"`P>&,T,C0X,C@Y+"`P>&%C9C-E8F,S+`H@("`@("`@
M(#!X-3<Q-68V8C<L(#!X968S-#<X9&0L(#!X9C(V-S8Q-F8L(#!X8S$T.&-B
M930L(#!X.3`U,C@Q-64L(#!X-64T,3!F86(L(#!X8C0X83(T-C4L(#!X,F5D
M83=F830L"B`@("`@("`@,'AE.#=B-#!E-"P@,'AE.3AE83`X-"P@,'@U.#@Y
M93EE,2P@,'AE9F0S.3!F8RP@,'AD9#`W9#,U8BP@,'AD8C0X-38Y-"P@,'@S
M.&0W935B,BP@,'@U-S<R,#$P,2P*("`@("`@("`P>#<S,&5D96)C+"`P>#5B
M-C0S,3$S+"`P>#DT.3$W931F+"`P>#4P,V,R9F)A+"`P>#8T-F8Q,C@R+"`P
M>#<U,C-D,C1A+"`P>&4P-S<Y-CDU+"`P>&8Y8S$W83AF+`H@("`@("`@(#!X
M-V$U8C(Q,C$L(#!X9#$X-V(X.38L(#!X,CDR-C-A-&0L(#!X8F$U,3!C9&8L
M(#!X.#%F-#=C.68L(#!X860Q,38S960L(#!X96$W8C4Y-C4L(#!X,6$P,#<R
M-F4L"B`@("`@("`@,'@Q,30P,S`Y,BP@,'@P,&1A-F0W-RP@,'@T83!C9&0V
M,2P@,'AA9#%F-#8P,RP@,'@V,#5B9&9B,"P@,'@Y965D8S,V-"P@,'@R,F5B
M939A."P@,'AC964W9#(X82P*("`@("`@("`P>&$P93<S-F$P+"`P>#4U-C1A
M-F(Y+"`P>#$P.#4S,C`Y+"`P>&,W96(X9C,W+"`P>#)D93<P-6-A+"`P>#@Y
M-3$U-S!F+"`P>&1F,#DX,C)B+"`P>&)D-CDQ839C+`H@("`@("`@(#!X86$Q
M,F4T9C(L(#!X.#<T-3%C,&8L(#!X93!F-F$R-V$L(#!X,V%D830X,3DL(#!X
M-&-F,3<V-&8L(#!X,&0W-S%C,F(L(#!X-C=C9&(Q-38L(#!X,S4P9#@S.#0L
M"B`@("`@("`@,'@U.3,X9F$P9BP@,'@T,C,Y.65F,RP@,'@S-CDY-V(P-RP@
M,'@P93@T,#DS9"P@,'@T86$Y,V4V,2P@,'@X,S8P9#@W8BP@,'@Q9F$Y.&(P
M8RP@,'@Q,30Y,S@R8RP*("`@("`@("`P>&4Y-S8R-6$U+"`P>#`V,31D,6(W
M+"`P>#!E,C4R-#1B+"`P>#!C-S8X,S0W+"`P>#4X.64X9#@R+"`P>#!D,C`U
M.60Q+"`P>&$T-C9B8C%E+"`P>&8X9&$P83@R+`H@("`@("`@(#!X,#1F,3DQ
M,S`L(#!X8F$V931E8S`L(#!X.3DR-C4Q-C0L(#!X,65E-S(S,&0L(#!X-3!B
M,F%D.#`L(#!X96%E938X,#$L(#!X.&1B,F$R.#,L(#!X96$X8F8U.64I.PH*
M("`@("\J*@H@("`@("H@36%S:VEN9R!+97ES"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]+;2`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*B!2;W1A=&4@2V5Y<PH@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?2W(@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@5&AE(&YU;6)E<B!O9B!R;W5N9',@=&\@9&\*("`@("`J"B`@("`@
M*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?<F]U;F1S(#T@,38[
M"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&ME>2!T;R!B92!U<V5D(&9O<B!E
M;B]D96-R>7!T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ME
M>2`@5&AE(&ME>2!T;R!U<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$ME
M>2@D:V5Y*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D:V5Y*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7W)O=6YD<R`]("AS=')L96XH)&ME>2D@/"`Q
M,2D@/R`Q,B`Z(#$V.PH@("`@("`@("`@("`D:V5Y(#T@)'1H:7,M/E]F;W)M
M871+97DH)&ME>2D["B`@("`@("`@("`@("1K97E38VAE9'5L92`]("1T:&ES
M+3Y?:V5Y4V-H961U;&4H)&ME>2D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N('1H92!S:7IE(&]F('1H92!B;&]C:W,@=&AA="!T
M:&ES(&-I<&AE<B!N965D<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G
M97(@(%1H92!N=6UB97(@;V8@8VAA<F%C=&5R<R!P97(@8FQO8VLN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$)L;V-K4VEZ92@I"B`@("!["B`@("`@("`@
M<F5T=7)N(#@["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%;F-R>7!T(&$@8FQO
M8VL@;V8@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1B;&]C
M:R`@5&AE(&1A=&$@=&\@96YC<GEP="X*("`@("`J($!P87)A;2!S=')I;F<@
M)&ME>2`@("!4:&4@:V5Y('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE(&5N8W)Y<'1E9"!O=71P=70N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&5N8W)Y<'1";&]C:R@D8FQO8VLL("1K97D@/2!N=6QL*0H@("`@
M>PH@("`@("`@(&EF("@A:7-?;G5L;"@D:V5Y*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7W)O=6YD<R`]("AS=')L96XH)&ME>2D@/"`Q,2D@/R`Q,B`Z(#$V
M.PH@("`@("`@("`@("`D:V5Y(#T@)'1H:7,M/E]F;W)M871+97DH)&ME>2D[
M"B`@("`@("`@("`@("1K97E38VAE9'5L92`]("1T:&ES+3Y?:V5Y4V-H961U
M;&4H)&ME>2D["B`@("`@("`@?0H*("`@("`@("`D3"`]("1T:&ES+3Y?9F]R
M;6%T1&%T82AS=6)S='(H)&)L;V-K+"`P+"`T*2D["B`@("`@("`@)%(@/2`D
M=&AI<RT^7V9O<FUA=$1A=&$H<W5B<W1R*"1B;&]C:RP@-"P@-"DI.PH*("`@
M("`@("`D3"!>/2`D=&AI<RT^9C$H)%(L("1T:&ES+3Y?2VU;,5TL("`D=&AI
M<RT^7TMR6S%=*3L*("`@("`@("`D4B!>/2`D=&AI<RT^9C(H)$PL("1T:&ES
M+3Y?2VU;,ETL("`D=&AI<RT^7TMR6S)=*3L*("`@("`@("`D3"!>/2`D=&AI
M<RT^9C,H)%(L("1T:&ES+3Y?2VU;,UTL("`D=&AI<RT^7TMR6S-=*3L*("`@
M("`@("`D4B!>/2`D=&AI<RT^9C$H)$PL("1T:&ES+3Y?2VU;-%TL("`D=&AI
M<RT^7TMR6S1=*3L*("`@("`@("`D3"!>/2`D=&AI<RT^9C(H)%(L("1T:&ES
M+3Y?2VU;-5TL("`D=&AI<RT^7TMR6S5=*3L*("`@("`@("`D4B!>/2`D=&AI
M<RT^9C,H)$PL("1T:&ES+3Y?2VU;-ETL("`D=&AI<RT^7TMR6S9=*3L*("`@
M("`@("`D3"!>/2`D=&AI<RT^9C$H)%(L("1T:&ES+3Y?2VU;-UTL("`D=&AI
M<RT^7TMR6S==*3L*("`@("`@("`D4B!>/2`D=&AI<RT^9C(H)$PL("1T:&ES
M+3Y?2VU;.%TL("`D=&AI<RT^7TMR6SA=*3L*("`@("`@("`D3"!>/2`D=&AI
M<RT^9C,H)%(L("1T:&ES+3Y?2VU;.5TL("`D=&AI<RT^7TMR6SE=*3L*("`@
M("`@("`D4B!>/2`D=&AI<RT^9C$H)$PL("1T:&ES+3Y?2VU;,3!=+"`D=&AI
M<RT^7TMR6S$P72D["B`@("`@("`@)$P@7CT@)'1H:7,M/F8R*"12+"`D=&AI
M<RT^7TMM6S$Q72P@)'1H:7,M/E]+<ELQ,5TI.PH@("`@("`@("12(%X]("1T
M:&ES+3YF,R@D3"P@)'1H:7,M/E]+;5LQ,ETL("1T:&ES+3Y?2W);,3)=*3L*
M("`@("`@("!I9B`H)'1H:7,M/E]R;W5N9',@/B`Q,BD@>PH@("`@("`@("`@
M("`D3"!>/2`D=&AI<RT^9C$H)%(L("1T:&ES+3Y?2VU;,3-=+"`D=&AI<RT^
M7TMR6S$S72D["B`@("`@("`@("`@("12(%X]("1T:&ES+3YF,B@D3"P@)'1H
M:7,M/E]+;5LQ-%TL("1T:&ES+3Y?2W);,31=*3L*("`@("`@("`@("`@)$P@
M7CT@)'1H:7,M/F8S*"12+"`D=&AI<RT^7TMM6S$U72P@)'1H:7,M/E]+<ELQ
M-5TI.PH@("`@("`@("`@("`D4B!>/2`D=&AI<RT^9C$H)$PL("1T:&ES+3Y?
M2VU;,39=+"`D=&AI<RT^7TMR6S$V72D["B`@("`@("`@?0H*("`@("`@("`D
M96YC<GEP=&5D(#T@<&%C:R@B3B(L("12*2`N('!A8VLH(DXB+"`D3"D["@H@
M("`@("`@(')E='5R;B`D96YC<GEP=&5D.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1&5C<GEP="!A(&)L;V-K(&]F(&1A=&$N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D8FQO8VL@(%1H92!D871A('1O(&1E8W)Y<'0N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1K97D@("`@5&AE(&ME>2!T;R!U<V4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D96-R>7!T960@;W5T<'5T
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96-R>7!T0FQO8VLH)&)L;V-K+"`D
M:V5Y(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES7VYU;&PH)&ME>2DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]R;W5N9',@/2`H<W1R;&5N*"1K97DI
M(#P@,3$I(#\@,3(@.B`Q-CL*("`@("`@("`@("`@)&ME>2`]("1T:&ES+3Y?
M9F]R;6%T2V5Y*"1K97DI.PH@("`@("`@("`@("`D:V5Y4V-H961U;&4@/2`D
M=&AI<RT^7VME>5-C:&5D=6QE*"1K97DI.PH@("`@("`@('T*"B`@("`@("`@
M)%(@/2`D=&AI<RT^7V9O<FUA=$1A=&$H<W5B<W1R*"1B;&]C:RP@,"P@-"DI
M.PH@("`@("`@("1,(#T@)'1H:7,M/E]F;W)M871$871A*'-U8G-T<B@D8FQO
M8VLL(#0L(#0I*3L*"B`@("`@("`@:68@*"1T:&ES+3Y?<F]U;F1S(#X@,3(I
M('L*("`@("`@("`@("`@)%(@7CT@)'1H:7,M/F8Q*"1,+"`D=&AI<RT^7TMM
M6S$V72P@)'1H:7,M/E]+<ELQ-ETI.PH@("`@("`@("`@("`D3"!>/2`D=&AI
M<RT^9C,H)%(L("1T:&ES+3Y?2VU;,35=+"`D=&AI<RT^7TMR6S$U72D["B`@
M("`@("`@("`@("12(%X]("1T:&ES+3YF,B@D3"P@)'1H:7,M/E]+;5LQ-%TL
M("1T:&ES+3Y?2W);,31=*3L*("`@("`@("`@("`@)$P@7CT@)'1H:7,M/F8Q
M*"12+"`D=&AI<RT^7TMM6S$S72P@)'1H:7,M/E]+<ELQ,UTI.PH@("`@("`@
M('T*"B`@("`@("`@)%(@7CT@)'1H:7,M/F8S*"1,+"`D=&AI<RT^7TMM6S$R
M72P@)'1H:7,M/E]+<ELQ,ETI.PH@("`@("`@("1,(%X]("1T:&ES+3YF,B@D
M4BP@)'1H:7,M/E]+;5LQ,5TL("1T:&ES+3Y?2W);,3%=*3L*("`@("`@("`D
M4B!>/2`D=&AI<RT^9C$H)$PL("1T:&ES+3Y?2VU;,3!=+"`D=&AI<RT^7TMR
M6S$P72D["B`@("`@("`@)$P@7CT@)'1H:7,M/F8S*"12+"`D=&AI<RT^7TMM
M6SE=+"`@)'1H:7,M/E]+<ELY72D["B`@("`@("`@)%(@7CT@)'1H:7,M/F8R
M*"1,+"`D=&AI<RT^7TMM6SA=+"`@)'1H:7,M/E]+<ELX72D["B`@("`@("`@
M)$P@7CT@)'1H:7,M/F8Q*"12+"`D=&AI<RT^7TMM6S==+"`@)'1H:7,M/E]+
M<ELW72D["B`@("`@("`@)%(@7CT@)'1H:7,M/F8S*"1,+"`D=&AI<RT^7TMM
M6S9=+"`@)'1H:7,M/E]+<ELV72D["B`@("`@("`@)$P@7CT@)'1H:7,M/F8R
M*"12+"`D=&AI<RT^7TMM6S5=+"`@)'1H:7,M/E]+<ELU72D["B`@("`@("`@
M)%(@7CT@)'1H:7,M/F8Q*"1,+"`D=&AI<RT^7TMM6S1=+"`@)'1H:7,M/E]+
M<ELT72D["B`@("`@("`@)$P@7CT@)'1H:7,M/F8S*"12+"`D=&AI<RT^7TMM
M6S-=+"`@)'1H:7,M/E]+<ELS72D["B`@("`@("`@)%(@7CT@)'1H:7,M/F8R
M*"1,+"`D=&AI<RT^7TMM6S)=+"`@)'1H:7,M/E]+<ELR72D["B`@("`@("`@
M)$P@7CT@)'1H:7,M/F8Q*"12+"`D=&AI<RT^7TMM6S%=+"`@)'1H:7,M/E]+
M<ELQ72D["@H@("`@("`@("1D96-R>7!T960@/2!P86-K*").(BP@)$PI("X@
M<&%C:R@B3B(L("12*3L*"B`@("`@("`@<F5T=7)N("1D96-R>7!T960["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!F,2@I"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&8Q*"1D+"`D2VTL("1+<BD*("`@('L*("`@("`@("`D22`]("1+;2`K("1D
M.PH*("`@("`@("`O*B!.87-T>2!&:7@@87,*("`@("`@("`@*B`D22`\/"`D
M2W(@?"`D22`^/B`H,S(@+2`D2W(I"B`@("`@("`@("H@1&]E<VXG="!A;'=A
M>7,@9VEV92!T:&4@8V]R<F5C="!A;G-W97(*("`@("`@("`@*B\*("`@("`@
M("`D8FEN(#T@<W1R7W!A9"AD96-B:6XH)$DI+"`S,BP@)S`G+"!35%)?4$%$
M7TQ%1E0I.PH@("`@("`@("1)(#T@8FEN9&5C*'-U8G-T<B@D8FEN+"`D2W(I
M("X@<W5B<W1R*"1B:6XL(#`L("1+<BDI.PH*("`@("`@("`D9B`]("1T:&ES
M+3YS,5LH)$D@/CX@,C0I("8@,'A&1ET@7B`D=&AI<RT^<S);*"1)(#X^(#$V
M*2`F(#!X1D9=.PH@("`@("`@("1F(#T@)&8@+2`D=&AI<RT^<S-;*"1)(#X^
M(#@I("8@,'A&1ET["B`@("`@("`@)&8@/2`D9B`K("1T:&ES+3YS-%LD22`F
M(#!X1D9=.PH@("`@("`@(')E='5R;B`D9CL*("`@('T*"B`@("`O*BH*("`@
M("`J(&8R*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9C(H)&0L("1+;2P@)$MR
M*0H@("`@>PH@("`@("`@("1)(#T@)$MM(%X@)&0["@H@("`@("`@("\J($YA
M<W1Y($9I>"!A<PH@("`@("`@("`J("1)(#P\("1+<B!\("1)(#X^("@S,B`M
M("1+<BD*("`@("`@("`@*B!$;V5S;B=T(&%L=V%Y<R!G:79E('1H92!C;W)R
M96-T(&%N<W=E<@H@("`@("`@("`J+PH@("`@("`@("1B:6X@/2!S=')?<&%D
M*&1E8V)I;B@D22DL(#,R+"`G,"<L(%-44E]0041?3$5&5"D["B`@("`@("`@
M)$D@/2!B:6YD96,H<W5B<W1R*"1B:6XL("1+<BD@+B!S=6)S='(H)&)I;BP@
M,"P@)$MR*2D["@H@("`@("`@("1F(#T@)'1H:7,M/G,Q6R@D22`^/B`R-"D@
M)B`P>$9&72`M("1T:&ES+3YS,ELH)$D@/CX@,38I("8@,'A&1ET["B`@("`@
M("`@)&8@/2`D9B`K("1T:&ES+3YS,ULH)$D@/CX@."D@)B`P>$9&73L*("`@
M("`@("`D9B`]("1F(%X@)'1H:7,M/G,T6R1)("8@,'A&1ET["B`@("`@("`@
M<F5T=7)N("1F.PH@("`@?0H*("`@("\J*@H@("`@("H@9C,H*0H@("`@("HO
M"B`@("!F=6YC=&EO;B!F,R@D9"P@)$MM+"`D2W(I"B`@("!["B`@("`@("`@
M)$D@/2`P>$9&1D9&1D9&("8@*"1+;2`M("1D*3L*"B`@("`@("`@+RH@3F%S
M='D@1FEX(&%S"B`@("`@("`@("H@)$D@/#P@)$MR('P@)$D@/CX@*#,R("T@
M)$MR*0H@("`@("`@("`J($1O97-N)W0@86QW87ES(&=I=F4@=&AE(&-O<G)E
M8W0@86YS=V5R"B`@("`@("`@("HO"B`@("`@("`@)&)I;B`]('-T<E]P860H
M9&5C8FEN*"1)*2P@,S(L("<P)RP@4U127U!!1%],1494*3L*("`@("`@("`D
M22`](&)I;F1E8RAS=6)S='(H)&)I;BP@)$MR*2`N('-U8G-T<B@D8FEN+"`P
M+"`D2W(I*3L*"B`@("`@("`@)&8@/2`H)'1H:7,M/G,Q6R@D22`^/B`R-"D@
M)B`P>$9&72`K("1T:&ES+3YS,ELH)$D@/CX@,38I("8@,'A&1ETI.PH@("`@
M("`@("1F(#T@)&8@7B`D=&AI<RT^<S-;*"1)(#X^(#@I("8@,'A&1ET["B`@
M("`@("`@)&8@/2`P>$9&1D9&1D9&("8@*"1F("T@)'1H:7,M/G,T6R1)("8@
M,'A&1ETI.PH@("`@("`@(')E='5R;B`D9CL*("`@('T*"B`@("`O*BH*("`@
M("`J($-O;G9E<G0@82!S=')I;F<@:6YT;R!A(&%R<F%Y(&]F('1H92!O<F1I
M;F%T97,@;V8@:71S(&-H87)A8W1E<G,N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9&%T82`@1&%T82!T;R!C;VYV97)T+@H@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@(%1H92!C;VYV97)T960@9&%T82X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V9O<FUA=$1A=&$H)&1A=&$I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?8V]M8FEN930H=6YP86-K*"=#*B<L("1D871A*2P@
M,'@Q*3L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G1S(&$@=&5X="!K
M97D@:6YT;R!A;B!A<G)A>2!P861D960@=VET:"!<,"=S('1O(&$@;&5N9W1H
M(&]F(#$R.`H@("`@("H@8FET<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1K97D@(%1H92!K97D@=&\@9F]R;6%T+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@(%1H92!P861D960@:V5Y+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?9F]R;6%T2V5Y*"1K97DI"B`@("!["B`@("`@("`@)')E<R`](&%R
M<F%Y7W9A;'5E<RAU;G!A8VLH)T,J)RP@)&ME>2DI.PH@("`@("`@(&9O<B`H
M)&D@/2!C;W5N="@D<F5S*3L@)&D@/"`Q-CL@)&DK*RD@>PH@("`@("`@("`@
M("`D<F5S6R1I72`](#`["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E('1H92!C;VUP;&5T92!K
M97D@<VAE9'5L92X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&ME>2`@
M5&AE(&ME>2!T;R!U<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]K97E38VAE
M9'5L92@D:V5Y*0H@("`@>PH@("`@("`@("1X,'@Q>#)X,R`]("1T:&ES+3Y?
M8V]M8FEN930H)&ME>2P@,'@P*3L*("`@("`@("`D>#1X-7@V>#<@/2`D=&AI
M<RT^7V-O;6)I;F4T*"1K97DL(#!X-"D["B`@("`@("`@)'@X>#EX07A"(#T@
M)'1H:7,M/E]C;VUB:6YE-"@D:V5Y+"`P>#@I.PH@("`@("`@("1X0WA$>$5X
M1B`]("1T:&ES+3Y?8V]M8FEN930H)&ME>2P@,'A#*3L*"B`@("`@("`@)&(@
M/2`D=&AI<RT^7W-P;&ET*"1X,'@Q>#)X,RD[("1X,"`]("1B6S!=.R`D>#$@
M/2`D8ELQ73L@)'@R(#T@)&);,ET[("1X,R`]("1B6S-=.PH@("`@("`@("1B
M(#T@)'1H:7,M/E]S<&QI="@D>#1X-7@V>#<I.R`D>#0@/2`D8ELP73L@)'@U
M(#T@)&);,5T[("1X-B`]("1B6S)=.R`D>#<@/2`D8ELS73L*("`@("`@("`D
M8B`]("1T:&ES+3Y?<W!L:70H)'@X>#EX07A"*3L@)'@X(#T@)&);,%T[("1X
M.2`]("1B6S%=.R`D>$$@/2`D8ELR73L@)'A"(#T@)&);,UT["B`@("`@("`@
M)&(@/2`D=&AI<RT^7W-P;&ET*"1X0WA$>$5X1BD[("1X0R`]("1B6S!=.R`D
M>$0@/2`D8ELQ73L@)'A%(#T@)&);,ET[("1X1B`]("1B6S-=.PH*("`@("`@
M("`D>C!Z,7HR>C,@/2`D>#!X,7@R>#,@7B`D=&AI<RT^<S5;)'A$72!>("1T
M:&ES+3YS-ELD>$9=(%X@)'1H:7,M/G,W6R1X0UT@7B`D=&AI<RT^<SA;)'A%
M72!>("1T:&ES+3YS-ULD>#A=.PH@("`@("`@("1B(#T@)'1H:7,M/E]S<&QI
M="@D>C!Z,7HR>C,I.R`D>C`@/2`D8ELP73L@)'HQ(#T@)&);,5T[("1Z,B`]
M("1B6S)=.R`D>C,@/2`D8ELS73L*("`@("`@("`D>C1Z-7HV>C<@/2`D>#AX
M.7A!>$(@7B`D=&AI<RT^<S5;)'HP72!>("1T:&ES+3YS-ELD>C)=(%X@)'1H
M:7,M/G,W6R1Z,5T@7B`D=&AI<RT^<SA;)'HS72!>("1T:&ES+3YS.%LD>$%=
M.PH@("`@("`@("1B(#T@)'1H:7,M/E]S<&QI="@D>C1Z-7HV>C<I.R`D>C0@
M/2`D8ELP73L@)'HU(#T@)&);,5T[("1Z-B`]("1B6S)=.R`D>C<@/2`D8ELS
M73L*("`@("`@("`D>CAZ.7I!>D(@/2`D>$-X1'A%>$8@7B`D=&AI<RT^<S5;
M)'HW72!>("1T:&ES+3YS-ELD>C9=(%X@)'1H:7,M/G,W6R1Z-5T@7B`D=&AI
M<RT^<SA;)'HT72!>("1T:&ES+3YS-5LD>#E=.PH@("`@("`@("1B(#T@)'1H
M:7,M/E]S<&QI="@D>CAZ.7I!>D(I.R`D>C@@/2`D8ELP73L@)'HY(#T@)&);
M,5T[("1Z02`]("1B6S)=.R`D>D(@/2`D8ELS73L*("`@("`@("`D>D-Z1'I%
M>D8@/2`D>#1X-7@V>#<@7B`D=&AI<RT^<S5;)'I!72!>("1T:&ES+3YS-ELD
M>CE=(%X@)'1H:7,M/G,W6R1Z0ET@7B`D=&AI<RT^<SA;)'HX72!>("1T:&ES
M+3YS-ELD>$)=.PH@("`@("`@("1B(#T@)'1H:7,M/E]S<&QI="@D>D-Z1'I%
M>D8I.R`D>D,@/2`D8ELP73L@)'I$(#T@)&);,5T[("1Z12`]("1B6S)=.R`D
M>D8@/2`D8ELS73L*"B`@("`@("`@)'1H:7,M/E]+;5LQ72`]("1T:&ES+3YS
M-5LD>CA=(%X@)'1H:7,M/G,V6R1Z.5T@7B`D=&AI<RT^<S=;)'HW72!>("1T
M:&ES+3YS.%LD>C9=(%X@)'1H:7,M/G,U6R1Z,ET["B`@("`@("`@)'1H:7,M
M/E]+;5LR72`]("1T:&ES+3YS-5LD>D%=(%X@)'1H:7,M/G,V6R1Z0ET@7B`D
M=&AI<RT^<S=;)'HU72!>("1T:&ES+3YS.%LD>C1=(%X@)'1H:7,M/G,V6R1Z
M-ET["B`@("`@("`@)'1H:7,M/E]+;5LS72`]("1T:&ES+3YS-5LD>D-=(%X@
M)'1H:7,M/G,V6R1Z1%T@7B`D=&AI<RT^<S=;)'HS72!>("1T:&ES+3YS.%LD
M>C)=(%X@)'1H:7,M/G,W6R1Z.5T["B`@("`@("`@)'1H:7,M/E]+;5LT72`]
M("1T:&ES+3YS-5LD>D5=(%X@)'1H:7,M/G,V6R1Z1ET@7B`D=&AI<RT^<S=;
M)'HQ72!>("1T:&ES+3YS.%LD>C!=(%X@)'1H:7,M/G,X6R1Z0UT["@H@("`@
M("`@("1X,'@Q>#)X,R`]("1Z.'HY>D%Z0B!>("1T:&ES+3YS-5LD>C5=(%X@
M)'1H:7,M/G,V6R1Z-UT@7B`D=&AI<RT^<S=;)'HT72!>("1T:&ES+3YS.%LD
M>C9=(%X@)'1H:7,M/G,W6R1Z,%T["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P
M;&ET*"1X,'@Q>#)X,RD[("1X,"`]("1B6S!=.R`D>#$@/2`D8ELQ73L@)'@R
M(#T@)&);,ET[("1X,R`]("1B6S-=.PH@("`@("`@("1X-'@U>#9X-R`]("1Z
M,'HQ>C)Z,R!>("1T:&ES+3YS-5LD>#!=(%X@)'1H:7,M/G,V6R1X,ET@7B`D
M=&AI<RT^<S=;)'@Q72!>("1T:&ES+3YS.%LD>#-=(%X@)'1H:7,M/G,X6R1Z
M,ET["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1X-'@U>#9X-RD[("1X
M-"`]("1B6S!=.R`D>#4@/2`D8ELQ73L@)'@V(#T@)&);,ET[("1X-R`]("1B
M6S-=.PH@("`@("`@("1X.'@Y>$%X0B`]("1Z-'HU>C9Z-R!>("1T:&ES+3YS
M-5LD>#==(%X@)'1H:7,M/G,V6R1X-ET@7B`D=&AI<RT^<S=;)'@U72!>("1T
M:&ES+3YS.%LD>#1=(%X@)'1H:7,M/G,U6R1Z,5T["B`@("`@("`@)&(@/2`D
M=&AI<RT^7W-P;&ET*"1X.'@Y>$%X0BD[("1X."`]("1B6S!=.R`D>#D@/2`D
M8ELQ73L@)'A!(#T@)&);,ET[("1X0B`]("1B6S-=.PH@("`@("`@("1X0WA$
M>$5X1B`]("1Z0WI$>D5Z1B!>("1T:&ES+3YS-5LD>$%=(%X@)'1H:7,M/G,V
M6R1X.5T@7B`D=&AI<RT^<S=;)'A"72!>("1T:&ES+3YS.%LD>#A=(%X@)'1H
M:7,M/G,V6R1Z,UT["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1X0WA$
M>$5X1BD[("1X0R`]("1B6S!=.R`D>$0@/2`D8ELQ73L@)'A%(#T@)&);,ET[
M("1X1B`]("1B6S-=.PH*("`@("`@("`D=&AI<RT^7TMM6S5=("`]("1T:&ES
M+3YS-5LD>#-=(%X@)'1H:7,M/G,V6R1X,ET@7B`D=&AI<RT^<S=;)'A#72!>
M("1T:&ES+3YS.%LD>$1=(%X@)'1H:7,M/G,U6R1X.%T["B`@("`@("`@)'1H
M:7,M/E]+;5LV72`@/2`D=&AI<RT^<S5;)'@Q72!>("1T:&ES+3YS-ELD>#!=
M(%X@)'1H:7,M/G,W6R1X15T@7B`D=&AI<RT^<SA;)'A&72!>("1T:&ES+3YS
M-ELD>$1=.PH@("`@("`@("1T:&ES+3Y?2VU;-UT@(#T@)'1H:7,M/G,U6R1X
M-UT@7B`D=&AI<RT^<S9;)'@V72!>("1T:&ES+3YS-ULD>#A=(%X@)'1H:7,M
M/G,X6R1X.5T@7B`D=&AI<RT^<S=;)'@S73L*("`@("`@("`D=&AI<RT^7TMM
M6SA=("`]("1T:&ES+3YS-5LD>#5=(%X@)'1H:7,M/G,V6R1X-%T@7B`D=&AI
M<RT^<S=;)'A!72!>("1T:&ES+3YS.%LD>$)=(%X@)'1H:7,M/G,X6R1X-UT[
M"@H@("`@("`@("1Z,'HQ>C)Z,R`]("1X,'@Q>#)X,R!>("1T:&ES+3YS-5LD
M>$1=(%X@)'1H:7,M/G,V6R1X1ET@7B`D=&AI<RT^<S=;)'A#72!>("1T:&ES
M+3YS.%LD>$5=(%X@)'1H:7,M/G,W6R1X.%T["B`@("`@("`@)&(@/2`D=&AI
M<RT^7W-P;&ET*"1Z,'HQ>C)Z,RD[("1Z,"`]("1B6S!=.R`D>C$@/2`D8ELQ
M73L@)'HR(#T@)&);,ET[("1Z,R`]("1B6S-=.PH@("`@("`@("1Z-'HU>C9Z
M-R`]("1X.'@Y>$%X0B!>("1T:&ES+3YS-5LD>C!=(%X@)'1H:7,M/G,V6R1Z
M,ET@7B`D=&AI<RT^<S=;)'HQ72!>("1T:&ES+3YS.%LD>C-=(%X@)'1H:7,M
M/G,X6R1X05T["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1Z-'HU>C9Z
M-RD[("1Z-"`]("1B6S!=.R`D>C4@/2`D8ELQ73L@)'HV(#T@)&);,ET[("1Z
M-R`]("1B6S-=.PH@("`@("`@("1Z.'HY>D%Z0B`]("1X0WA$>$5X1B!>("1T
M:&ES+3YS-5LD>C==(%X@)'1H:7,M/G,V6R1Z-ET@7B`D=&AI<RT^<S=;)'HU
M72!>("1T:&ES+3YS.%LD>C1=(%X@)'1H:7,M/G,U6R1X.5T["B`@("`@("`@
M)&(@/2`D=&AI<RT^7W-P;&ET*"1Z.'HY>D%Z0BD[("1Z."`]("1B6S!=.R`D
M>CD@/2`D8ELQ73L@)'I!(#T@)&);,ET[("1Z0B`]("1B6S-=.PH@("`@("`@
M("1Z0WI$>D5Z1B`]("1X-'@U>#9X-R!>("1T:&ES+3YS-5LD>D%=(%X@)'1H
M:7,M/G,V6R1Z.5T@7B`D=&AI<RT^<S=;)'I"72!>("1T:&ES+3YS.%LD>CA=
M(%X@)'1H:7,M/G,V6R1X0ET["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET
M*"1Z0WI$>D5Z1BD[("1Z0R`]("1B6S!=.R`D>D0@/2`D8ELQ73L@)'I%(#T@
M)&);,ET[("1Z1B`]("1B6S-=.PH*("`@("`@("`D=&AI<RT^7TMM6SE=("`]
M("1T:&ES+3YS-5LD>C-=(%X@)'1H:7,M/G,V6R1Z,ET@7B`D=&AI<RT^<S=;
M)'I#72!>("1T:&ES+3YS.%LD>D1=(%X@)'1H:7,M/G,U6R1Z.5T["B`@("`@
M("`@)'1H:7,M/E]+;5LQ,%T@/2`D=&AI<RT^<S5;)'HQ72!>("1T:&ES+3YS
M-ELD>C!=(%X@)'1H:7,M/G,W6R1Z15T@7B`D=&AI<RT^<SA;)'I&72!>("1T
M:&ES+3YS-ELD>D-=.PH@("`@("`@("1T:&ES+3Y?2VU;,3%=(#T@)'1H:7,M
M/G,U6R1Z-UT@7B`D=&AI<RT^<S9;)'HV72!>("1T:&ES+3YS-ULD>CA=(%X@
M)'1H:7,M/G,X6R1Z.5T@7B`D=&AI<RT^<S=;)'HR73L*("`@("`@("`D=&AI
M<RT^7TMM6S$R72`]("1T:&ES+3YS-5LD>C5=(%X@)'1H:7,M/G,V6R1Z-%T@
M7B`D=&AI<RT^<S=;)'I!72!>("1T:&ES+3YS.%LD>D)=(%X@)'1H:7,M/G,X
M6R1Z-ET["@H@("`@("`@("1X,'@Q>#)X,R`]("1Z.'HY>D%Z0B!>("1T:&ES
M+3YS-5LD>C5=(%X@)'1H:7,M/G,V6R1Z-UT@7B`D=&AI<RT^<S=;)'HT72!>
M("1T:&ES+3YS.%LD>C9=(%X@)'1H:7,M/G,W6R1Z,%T["B`@("`@("`@)&(@
M/2`D=&AI<RT^7W-P;&ET*"1X,'@Q>#)X,RD[("1X,"`]("1B6S!=.R`D>#$@
M/2`D8ELQ73L@)'@R(#T@)&);,ET[("1X,R`]("1B6S-=.PH@("`@("`@("1X
M-'@U>#9X-R`]("1Z,'HQ>C)Z,R!>("1T:&ES+3YS-5LD>#!=(%X@)'1H:7,M
M/G,V6R1X,ET@7B`D=&AI<RT^<S=;)'@Q72!>("1T:&ES+3YS.%LD>#-=(%X@
M)'1H:7,M/G,X6R1Z,ET["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1X
M-'@U>#9X-RD[("1X-"`]("1B6S!=.R`D>#4@/2`D8ELQ73L@)'@V(#T@)&);
M,ET[("1X-R`]("1B6S-=.PH@("`@("`@("1X.'@Y>$%X0B`]("1Z-'HU>C9Z
M-R!>("1T:&ES+3YS-5LD>#==(%X@)'1H:7,M/G,V6R1X-ET@7B`D=&AI<RT^
M<S=;)'@U72!>("1T:&ES+3YS.%LD>#1=(%X@)'1H:7,M/G,U6R1Z,5T["B`@
M("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1X.'@Y>$%X0BD[("1X."`]("1B
M6S!=.R`D>#D@/2`D8ELQ73L@)'A!(#T@)&);,ET[("1X0B`]("1B6S-=.PH@
M("`@("`@("1X0WA$>$5X1B`]("1Z0WI$>D5Z1B!>("1T:&ES+3YS-5LD>$%=
M(%X@)'1H:7,M/G,V6R1X.5T@7B`D=&AI<RT^<S=;)'A"72!>("1T:&ES+3YS
M.%LD>#A=(%X@)'1H:7,M/G,V6R1Z,UT["B`@("`@("`@)&(@/2`D=&AI<RT^
M7W-P;&ET*"1X0WA$>$5X1BD[("1X0R`]("1B6S!=.R`D>$0@/2`D8ELQ73L@
M)'A%(#T@)&);,ET[("1X1B`]("1B6S-=.PH*("`@("`@("`D=&AI<RT^7TMM
M6S$S72`]("1T:&ES+3YS-5LD>#A=(%X@)'1H:7,M/G,V6R1X.5T@7B`D=&AI
M<RT^<S=;)'@W72!>("1T:&ES+3YS.%LD>#9=(%X@)'1H:7,M/G,U6R1X,UT[
M"B`@("`@("`@)'1H:7,M/E]+;5LQ-%T@/2`D=&AI<RT^<S5;)'A!72!>("1T
M:&ES+3YS-ELD>$)=(%X@)'1H:7,M/G,W6R1X-5T@7B`D=&AI<RT^<SA;)'@T
M72!>("1T:&ES+3YS-ELD>#==.PH@("`@("`@("1T:&ES+3Y?2VU;,35=(#T@
M)'1H:7,M/G,U6R1X0UT@7B`D=&AI<RT^<S9;)'A$72!>("1T:&ES+3YS-ULD
M>#-=(%X@)'1H:7,M/G,X6R1X,ET@7B`D=&AI<RT^<S=;)'@X73L*("`@("`@
M("`D=&AI<RT^7TMM6S$V72`]("1T:&ES+3YS-5LD>$5=(%X@)'1H:7,M/G,V
M6R1X1ET@7B`D=&AI<RT^<S=;)'@Q72!>("1T:&ES+3YS.%LD>#!=(%X@)'1H
M:7,M/G,X6R1X1%T["@H@("`@("`@("1Z,'HQ>C)Z,R`]("1X,'@Q>#)X,R!>
M("1T:&ES+3YS-5LD>$1=(%X@)'1H:7,M/G,V6R1X1ET@7B`D=&AI<RT^<S=;
M)'A#72!>("1T:&ES+3YS.%LD>$5=(%X@)'1H:7,M/G,W6R1X.%T["B`@("`@
M("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1Z,'HQ>C)Z,RD[("1Z,"`]("1B6S!=
M.R`D>C$@/2`D8ELQ73L@)'HR(#T@)&);,ET[("1Z,R`]("1B6S-=.PH@("`@
M("`@("1Z-'HU>C9Z-R`]("1X.'@Y>$%X0B!>("1T:&ES+3YS-5LD>C!=(%X@
M)'1H:7,M/G,V6R1Z,ET@7B`D=&AI<RT^<S=;)'HQ72!>("1T:&ES+3YS.%LD
M>C-=(%X@)'1H:7,M/G,X6R1X05T["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P
M;&ET*"1Z-'HU>C9Z-RD[("1Z-"`]("1B6S!=.R`D>C4@/2`D8ELQ73L@)'HV
M(#T@)&);,ET[("1Z-R`]("1B6S-=.PH@("`@("`@("1Z.'HY>D%Z0B`]("1X
M0WA$>$5X1B!>("1T:&ES+3YS-5LD>C==(%X@)'1H:7,M/G,V6R1Z-ET@7B`D
M=&AI<RT^<S=;)'HU72!>("1T:&ES+3YS.%LD>C1=(%X@)'1H:7,M/G,U6R1X
M.5T["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1Z.'HY>D%Z0BD[("1Z
M."`]("1B6S!=.R`D>CD@/2`D8ELQ73L@)'I!(#T@)&);,ET[("1Z0B`]("1B
M6S-=.PH@("`@("`@("1Z0WI$>D5Z1B`]("1X-'@U>#9X-R!>("1T:&ES+3YS
M-5LD>D%=(%X@)'1H:7,M/G,V6R1Z.5T@7B`D=&AI<RT^<S=;)'I"72!>("1T
M:&ES+3YS.%LD>CA=(%X@)'1H:7,M/G,V6R1X0ET["B`@("`@("`@)&(@/2`D
M=&AI<RT^7W-P;&ET*"1Z0WI$>D5Z1BD[("1Z0R`]("1B6S!=.R`D>D0@/2`D
M8ELQ73L@)'I%(#T@)&);,ET[("1Z1B`]("1B6S-=.PH*("`@("`@("`D=&AI
M<RT^7TMR6S%=("`](#!X,48@)B`H)'1H:7,M/G,U6R1Z.%T@7B`D=&AI<RT^
M<S9;)'HY72!>("1T:&ES+3YS-ULD>C==(%X@)'1H:7,M/G,X6R1Z-ET@7B`D
M=&AI<RT^<S5;)'HR72D["B`@("`@("`@)'1H:7,M/E]+<ELR72`@/2`P>#%&
M("8@*"1T:&ES+3YS-5LD>D%=(%X@)'1H:7,M/G,V6R1Z0ET@7B`D=&AI<RT^
M<S=;)'HU72!>("1T:&ES+3YS.%LD>C1=(%X@)'1H:7,M/G,V6R1Z-ETI.PH@
M("`@("`@("1T:&ES+3Y?2W);,UT@(#T@,'@Q1B`F("@D=&AI<RT^<S5;)'I#
M72!>("1T:&ES+3YS-ELD>D1=(%X@)'1H:7,M/G,W6R1Z,UT@7B`D=&AI<RT^
M<SA;)'HR72!>("1T:&ES+3YS-ULD>CE=*3L*("`@("`@("`D=&AI<RT^7TMR
M6S1=("`](#!X,48@)B`H)'1H:7,M/G,U6R1Z15T@7B`D=&AI<RT^<S9;)'I&
M72!>("1T:&ES+3YS-ULD>C%=(%X@)'1H:7,M/G,X6R1Z,%T@7B`D=&AI<RT^
M<SA;)'I#72D["@H@("`@("`@("1X,'@Q>#)X,R`]("1Z.'HY>D%Z0B!>("1T
M:&ES+3YS-5LD>C5=(%X@)'1H:7,M/G,V6R1Z-UT@7B`D=&AI<RT^<S=;)'HT
M72!>("1T:&ES+3YS.%LD>C9=(%X@)'1H:7,M/G,W6R1Z,%T["B`@("`@("`@
M)&(@/2`D=&AI<RT^7W-P;&ET*"1X,'@Q>#)X,RD[("1X,"`]("1B6S!=.R`D
M>#$@/2`D8ELQ73L@)'@R(#T@)&);,ET[("1X,R`]("1B6S-=.PH@("`@("`@
M("1X-'@U>#9X-R`]("1Z,'HQ>C)Z,R!>("1T:&ES+3YS-5LD>#!=(%X@)'1H
M:7,M/G,V6R1X,ET@7B`D=&AI<RT^<S=;)'@Q72!>("1T:&ES+3YS.%LD>#-=
M(%X@)'1H:7,M/G,X6R1Z,ET["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET
M*"1X-'@U>#9X-RD[("1X-"`]("1B6S!=.R`D>#4@/2`D8ELQ73L@)'@V(#T@
M)&);,ET[("1X-R`]("1B6S-=.PH@("`@("`@("1X.'@Y>$%X0B`]("1Z-'HU
M>C9Z-R!>("1T:&ES+3YS-5LD>#==(%X@)'1H:7,M/G,V6R1X-ET@7B`D=&AI
M<RT^<S=;)'@U72!>("1T:&ES+3YS.%LD>#1=(%X@)'1H:7,M/G,U6R1Z,5T[
M"B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1X.'@Y>$%X0BD[("1X."`]
M("1B6S!=.R`D>#D@/2`D8ELQ73L@)'A!(#T@)&);,ET[("1X0B`]("1B6S-=
M.PH@("`@("`@("1X0WA$>$5X1B`]("1Z0WI$>D5Z1B!>("1T:&ES+3YS-5LD
M>$%=(%X@)'1H:7,M/G,V6R1X.5T@7B`D=&AI<RT^<S=;)'A"72!>("1T:&ES
M+3YS.%LD>#A=(%X@)'1H:7,M/G,V6R1Z,UT["B`@("`@("`@)&(@/2`D=&AI
M<RT^7W-P;&ET*"1X0WA$>$5X1BD[("1X0R`]("1B6S!=.R`D>$0@/2`D8ELQ
M73L@)'A%(#T@)&);,ET[("1X1B`]("1B6S-=.PH*("`@("`@("`D=&AI<RT^
M7TMR6S5=("`](#!X,48@)B`H)'1H:7,M/G,U6R1X,UT@7B`D=&AI<RT^<S9;
M)'@R72!>("1T:&ES+3YS-ULD>$-=(%X@)'1H:7,M/G,X6R1X1%T@7B`D=&AI
M<RT^<S5;)'@X72D["B`@("`@("`@)'1H:7,M/E]+<ELV72`@/2`P>#%&("8@
M*"1T:&ES+3YS-5LD>#%=(%X@)'1H:7,M/G,V6R1X,%T@7B`D=&AI<RT^<S=;
M)'A%72!>("1T:&ES+3YS.%LD>$9=(%X@)'1H:7,M/G,V6R1X1%TI.PH@("`@
M("`@("1T:&ES+3Y?2W);-UT@(#T@,'@Q1B`F("@D=&AI<RT^<S5;)'@W72!>
M("1T:&ES+3YS-ELD>#9=(%X@)'1H:7,M/G,W6R1X.%T@7B`D=&AI<RT^<SA;
M)'@Y72!>("1T:&ES+3YS-ULD>#-=*3L*("`@("`@("`D=&AI<RT^7TMR6SA=
M("`](#!X,48@)B`H)'1H:7,M/G,U6R1X-5T@7B`D=&AI<RT^<S9;)'@T72!>
M("1T:&ES+3YS-ULD>$%=(%X@)'1H:7,M/G,X6R1X0ET@7B`D=&AI<RT^<SA;
M)'@W72D["@H@("`@("`@("1Z,'HQ>C)Z,R`]("1X,'@Q>#)X,R!>("1T:&ES
M+3YS-5LD>$1=(%X@)'1H:7,M/G,V6R1X1ET@7B`D=&AI<RT^<S=;)'A#72!>
M("1T:&ES+3YS.%LD>$5=(%X@)'1H:7,M/G,W6R1X.%T["B`@("`@("`@)&(@
M/2`D=&AI<RT^7W-P;&ET*"1Z,'HQ>C)Z,RD[("1Z,"`]("1B6S!=.R`D>C$@
M/2`D8ELQ73L@)'HR(#T@)&);,ET[("1Z,R`]("1B6S-=.PH@("`@("`@("1Z
M-'HU>C9Z-R`]("1X.'@Y>$%X0B!>("1T:&ES+3YS-5LD>C!=(%X@)'1H:7,M
M/G,V6R1Z,ET@7B`D=&AI<RT^<S=;)'HQ72!>("1T:&ES+3YS.%LD>C-=(%X@
M)'1H:7,M/G,X6R1X05T["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1Z
M-'HU>C9Z-RD[("1Z-"`]("1B6S!=.R`D>C4@/2`D8ELQ73L@)'HV(#T@)&);
M,ET[("1Z-R`]("1B6S-=.PH@("`@("`@("1Z.'HY>D%Z0B`]("1X0WA$>$5X
M1B!>("1T:&ES+3YS-5LD>C==(%X@)'1H:7,M/G,V6R1Z-ET@7B`D=&AI<RT^
M<S=;)'HU72!>("1T:&ES+3YS.%LD>C1=(%X@)'1H:7,M/G,U6R1X.5T["B`@
M("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1Z.'HY>D%Z0BD[("1Z."`]("1B
M6S!=.R`D>CD@/2`D8ELQ73L@)'I!(#T@)&);,ET[("1Z0B`]("1B6S-=.PH@
M("`@("`@("1Z0WI$>D5Z1B`]("1X-'@U>#9X-R!>("1T:&ES+3YS-5LD>D%=
M(%X@)'1H:7,M/G,V6R1Z.5T@7B`D=&AI<RT^<S=;)'I"72!>("1T:&ES+3YS
M.%LD>CA=(%X@)'1H:7,M/G,V6R1X0ET["B`@("`@("`@)&(@/2`D=&AI<RT^
M7W-P;&ET*"1Z0WI$>D5Z1BD[("1Z0R`]("1B6S!=.R`D>D0@/2`D8ELQ73L@
M)'I%(#T@)&);,ET[("1Z1B`]("1B6S-=.PH*("`@("`@("`D=&AI<RT^7TMR
M6SE=("`](#!X,48@)B`H)'1H:7,M/G,U6R1Z,UT@7B`D=&AI<RT^<S9;)'HR
M72!>("1T:&ES+3YS-ULD>D-=(%X@)'1H:7,M/G,X6R1Z1%T@7B`D=&AI<RT^
M<S5;)'HY72D["B`@("`@("`@)'1H:7,M/E]+<ELQ,%T@/2`P>#%&("8@*"1T
M:&ES+3YS-5LD>C%=(%X@)'1H:7,M/G,V6R1Z,%T@7B`D=&AI<RT^<S=;)'I%
M72!>("1T:&ES+3YS.%LD>D9=(%X@)'1H:7,M/G,V6R1Z0UTI.PH@("`@("`@
M("1T:&ES+3Y?2W);,3%=(#T@,'@Q1B`F("@D=&AI<RT^<S5;)'HW72!>("1T
M:&ES+3YS-ELD>C9=(%X@)'1H:7,M/G,W6R1Z.%T@7B`D=&AI<RT^<SA;)'HY
M72!>("1T:&ES+3YS-ULD>C)=*3L*("`@("`@("`D=&AI<RT^7TMR6S$R72`]
M(#!X,48@)B`H)'1H:7,M/G,U6R1Z-5T@7B`D=&AI<RT^<S9;)'HT72!>("1T
M:&ES+3YS-ULD>D%=(%X@)'1H:7,M/G,X6R1Z0ET@7B`D=&AI<RT^<SA;)'HV
M72D["@H@("`@("`@("1X,'@Q>#)X,R`]("1Z.'HY>D%Z0B!>("1T:&ES+3YS
M-5LD>C5=(%X@)'1H:7,M/G,V6R1Z-UT@7B`D=&AI<RT^<S=;)'HT72!>("1T
M:&ES+3YS.%LD>C9=(%X@)'1H:7,M/G,W6R1Z,%T["B`@("`@("`@)&(@/2`D
M=&AI<RT^7W-P;&ET*"1X,'@Q>#)X,RD[("1X,"`]("1B6S!=.R`D>#$@/2`D
M8ELQ73L@)'@R(#T@)&);,ET[("1X,R`]("1B6S-=.PH@("`@("`@("1X-'@U
M>#9X-R`]("1Z,'HQ>C)Z,R!>("1T:&ES+3YS-5LD>#!=(%X@)'1H:7,M/G,V
M6R1X,ET@7B`D=&AI<RT^<S=;)'@Q72!>("1T:&ES+3YS.%LD>#-=(%X@)'1H
M:7,M/G,X6R1Z,ET["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1X-'@U
M>#9X-RD[("1X-"`]("1B6S!=.R`D>#4@/2`D8ELQ73L@)'@V(#T@)&);,ET[
M("1X-R`]("1B6S-=.PH@("`@("`@("1X.'@Y>$%X0B`]("1Z-'HU>C9Z-R!>
M("1T:&ES+3YS-5LD>#==(%X@)'1H:7,M/G,V6R1X-ET@7B`D=&AI<RT^<S=;
M)'@U72!>("1T:&ES+3YS.%LD>#1=(%X@)'1H:7,M/G,U6R1Z,5T["B`@("`@
M("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1X.'@Y>$%X0BD[("1X."`]("1B6S!=
M.R`D>#D@/2`D8ELQ73L@)'A!(#T@)&);,ET[("1X0B`]("1B6S-=.PH@("`@
M("`@("1X0WA$>$5X1B`]("1Z0WI$>D5Z1B!>("1T:&ES+3YS-5LD>$%=(%X@
M)'1H:7,M/G,V6R1X.5T@7B`D=&AI<RT^<S=;)'A"72!>("1T:&ES+3YS.%LD
M>#A=(%X@)'1H:7,M/G,V6R1Z,UT["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P
M;&ET*"1X0WA$>$5X1BD[("1X0R`]("1B6S!=.R`D>$0@/2`D8ELQ73L@)'A%
M(#T@)&);,ET[("1X1B`]("1B6S-=.PH*("`@("`@("`D=&AI<RT^7TMR6S$S
M72`](#!X,48@)B`H)'1H:7,M/G,U6R1X.%T@7B`D=&AI<RT^<S9;)'@Y72!>
M("1T:&ES+3YS-ULD>#==(%X@)'1H:7,M/G,X6R1X-ET@7B`D=&AI<RT^<S5;
M)'@S72D["B`@("`@("`@)'1H:7,M/E]+<ELQ-%T@/2`P>#%&("8@*"1T:&ES
M+3YS-5LD>$%=(%X@)'1H:7,M/G,V6R1X0ET@7B`D=&AI<RT^<S=;)'@U72!>
M("1T:&ES+3YS.%LD>#1=(%X@)'1H:7,M/G,V6R1X-UTI.PH@("`@("`@("1T
M:&ES+3Y?2W);,35=(#T@,'@Q1B`F("@D=&AI<RT^<S5;)'A#72!>("1T:&ES
M+3YS-ELD>$1=(%X@)'1H:7,M/G,W6R1X,UT@7B`D=&AI<RT^<SA;)'@R72!>
M("1T:&ES+3YS-ULD>#A=*3L*("`@("`@("`D=&AI<RT^7TMR6S$V72`](#!X
M,48@)B`H)'1H:7,M/G,U6R1X15T@7B`D=&AI<RT^<S9;)'A&72!>("1T:&ES
M+3YS-ULD>#%=(%X@)'1H:7,M/G,X6R1X,%T@7B`D=&AI<RT^<SA;)'A$72D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!5;G!A8VL@=&AE(#,R(&)I="!V86QU
M92!I;G1O(&%N(&%R<F%Y(&]F(&9O=7(@."!B:70@=F%L=65S+@H@("`@("H*
M("`@("`J($!P87)A;2!I;G1E9V5R("1X("`S,B!B:70@=F%L=64N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@1F]U<B`X(&)I="!V86QU97,@35,@
M=&\@3%,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S<&QI="@D>"D*("`@('L*
M("`@("`@("!R971U<FX@87)R87DH*"1X(#X^(#(T*2`F(#!X1D8L("@D>"`^
M/B`Q-BD@)B`P>$9&+"`H)'@@/CX@."D@)B`P>$9&+"`D>"`F(#!X1D8I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4&%C:R!F;W5R(#@@8FET('9A;'5E<R!I
M;G1O(&]N92`S,B!B:70@=F%L=64N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1K97D@("`@("!!<G)A>2!O9B`X(&)I="!V86QU97,N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D<W1A<G0@(%-T87)T('!O<VET:6]N(&EN(&%R<F%Y
M('1O(&=E="`T('9A;'5E<R!F<F]M+@H@("`@("H*("`@("`J($!R971U<FX@
M:6YT96=E<B`@,S(@8FET('9A;'5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M8V]M8FEN930H)&ME>2P@)'-T87)T(#T@,"D*("`@('L*("`@("`@("`D<F5S
M("`](#`["B`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)'-T87)T+"`D
M:V5Y*2D@>PH@("`@("`@("`@("`D<F5S('P]("@D:V5Y6R1S=&%R=%TI(#P\
M(#(T.PH@("`@("`@('T*("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@D
M<W1A<G0@*R`Q+"`D:V5Y*2D@>PH@("`@("`@("`@("`D<F5S('P]("@D:V5Y
M6R1S=&%R="`K(#%=*2`\/"`Q-CL*("`@("`@("!]"B`@("`@("`@:68@*&%R
M<F%Y7VME>5]E>&ES=',H)'-T87)T("L@,BP@)&ME>2DI('L*("`@("`@("`@
M("`@)')E<R!\/2`H)&ME>5LD<W1A<G0@*R`R72D@/#P@.#L*("`@("`@("!]
M"B`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)'-T87)T("L@,RP@)&ME
M>2DI('L*("`@("`@("`@("`@)')E<R!\/2`H)&ME>5LD<W1A<G0@*R`S72D[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B](;W)D92]#:7!H97(O9&5S+G!H<```````````````````````
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,C<R,#(`,3`U,34T,S,W-3``,#(R,38S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!4:&4@0VEP:&5R7V1E<SHZ(&-L87-S(&EM<&QE;65N=',@=&AE
M($-I<&AE<B!I;G1E<F9A8V4@96YC<GEP=&EO;B!D871A"B`J('5S:6YG('1H
M92!$871A($5N8W)Y<'1I;VX@4W1A;F1A<F0@*$1%4RD@86QG;W)I=&AM(&%S
M(&1E9FEN92!I;B!&25!3-#8M,RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M0VEP:&5R+T-I<&AE<B]D97,N<&AP+'8@,2XT+C$R+C<@,C`P-B\P,2\P,2`R
M,3HR.#HQ,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-
M:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F
M=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K
M86=E($AO<F1E7T-I<&AE<@H@*B\*8VQA<W,@2&]R9&5?0VEP:&5R7V1E<R!E
M>'1E;F1S($AO<F1E7T-I<&AE<B!["@H@("`@+RHJ"B`@("`@*B!);FET:6%L
M(%!E<FUU=&%T:6]N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)&EP(#T@87)R87DH"B`@("`@("`@-3@L(#4P+"`T,BP@,S0L
M(#(V+"`Q."P@,3`L("`R+`H@("`@("`@(#8P+"`U,BP@-#0L(#,V+"`R."P@
M,C`L(#$R+"`@-"P*("`@("`@("`V,BP@-30L(#0V+"`S."P@,S`L(#(R+"`Q
M-"P@(#8L"B`@("`@("`@-C0L(#4V+"`T."P@-#`L(#,R+"`R-"P@,38L("`X
M+`H@("`@("`@(#4W+"`T.2P@-#$L(#,S+"`R-2P@,3<L("`Y+"`@,2P*("`@
M("`@("`U.2P@-3$L(#0S+"`S-2P@,C<L(#$Y+"`Q,2P@(#,L"B`@("`@("`@
M-C$L(#4S+"`T-2P@,S<L(#(Y+"`R,2P@,3,L("`U+`H@("`@("`@(#8S+"`U
M-2P@-#<L(#,Y+"`S,2P@,C,L(#$U+"`@-PH@("`@*3L*"B`@("`O*BH*("`@
M("`J($9I;F%L(%!E<FUU=&%T:6]N($E07BTQ"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&9P(#T@87)R87DH"B`@("`@("`@
M-#`L("`X+"`T."P@,38L(#4V+"`R-"P@-C0L(#,R+`H@("`@("`@(#,Y+"`@
M-RP@-#<L(#$U+"`U-2P@,C,L(#8S+"`S,2P*("`@("`@("`S."P@(#8L(#0V
M+"`Q-"P@-30L(#(R+"`V,BP@,S`L"B`@("`@("`@,S<L("`U+"`T-2P@,3,L
M(#4S+"`R,2P@-C$L(#(Y+`H@("`@("`@(#,V+"`@-"P@-#0L(#$R+"`U,BP@
M,C`L(#8P+"`R."P*("`@("`@("`S-2P@(#,L(#0S+"`Q,2P@-3$L(#$Y+"`U
M.2P@,C<L"B`@("`@("`@,S0L("`R+"`T,BP@,3`L(#4P+"`Q."P@-3@L(#(V
M+`H@("`@("`@(#,S+"`@,2P@-#$L("`Y+"`T.2P@,3<L(#4W+"`R-0H@("`@
M*3L*"B`@("`O*BH*("`@("`J($4@0FET(%-E;&5C=&EO;B!486)L90H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1E(#T@87)R
M87DH"B`@("`@("`@,S(L("`Q+"`@,BP@(#,L("`T+"`@-2P*("`@("`@("`@
M-"P@(#4L("`V+"`@-RP@(#@L("`Y+`H@("`@("`@("`X+"`@.2P@,3`L(#$Q
M+"`Q,BP@,3,L"B`@("`@("`@,3(L(#$S+"`Q-"P@,34L(#$V+"`Q-RP*("`@
M("`@("`Q-BP@,3<L(#$X+"`Q.2P@,C`L(#(Q+`H@("`@("`@(#(P+"`R,2P@
M,C(L(#(S+"`R-"P@,C4L"B`@("`@("`@,C0L(#(U+"`R-BP@,C<L(#(X+"`R
M.2P*("`@("`@("`R."P@,CDL(#,P+"`S,2P@,S(L("`Q"B`@("`I.PH*("`@
M("\J*@H@("`@("H@4R!B;WAE<PH@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1?<R`](&%R<F%Y*`H@("`@("`@("\J(%,Q("HO
M"B`@("`@("`@,2`]/B!A<G)A>2@*("`@("`@("`@("`Q-"P@(#0L(#$S+"`@
M,2P@(#(L(#$U+"`Q,2P@(#@L("`S+"`Q,"P@(#8L(#$R+"`@-2P@(#DL("`P
M+"`@-RP*("`@("`@("`@("`@,"P@,34L("`W+"`@-"P@,30L("`R+"`Q,RP@
M(#$L(#$P+"`@-BP@,3(L(#$Q+"`@.2P@(#4L("`S+"`@."P*("`@("`@("`@
M("`@-"P@(#$L(#$T+"`@."P@,3,L("`V+"`@,BP@,3$L(#$U+"`Q,BP@(#DL
M("`W+"`@,RP@,3`L("`U+"`@,"P*("`@("`@("`@("`Q-2P@,3(L("`X+"`@
M,BP@(#0L("`Y+"`@,2P@(#<L("`U+"`Q,2P@(#,L(#$T+"`Q,"P@(#`L("`V
M+"`Q,PH@("`@("`@("DL"@H@("`@("`@("\J(%,R("HO"B`@("`@("`@,B`]
M/B!A<G)A>2@*("`@("`@("`@("`Q-2P@(#$L("`X+"`Q-"P@(#8L(#$Q+"`@
M,RP@(#0L("`Y+"`@-RP@(#(L(#$S+"`Q,BP@(#`L("`U+"`Q,"P*("`@("`@
M("`@("`@,RP@,3,L("`T+"`@-RP@,34L("`R+"`@."P@,30L(#$R+"`@,"P@
M(#$L(#$P+"`@-BP@(#DL(#$Q+"`@-2P*("`@("`@("`@("`@,"P@,30L("`W
M+"`Q,2P@,3`L("`T+"`Q,RP@(#$L("`U+"`@."P@,3(L("`V+"`@.2P@(#,L
M("`R+"`Q-2P*("`@("`@("`@("`Q,RP@(#@L(#$P+"`@,2P@(#,L(#$U+"`@
M-"P@(#(L(#$Q+"`@-BP@(#<L(#$R+"`@,"P@(#4L(#$T+"`@.2P*("`@("`@
M("`I+`H*("`@("`@("`O*B!3,R`J+PH@("`@("`@(#,@/3X@87)R87DH"B`@
M("`@("`@("`@,3`L("`P+"`@.2P@,30L("`V+"`@,RP@,34L("`U+"`@,2P@
M,3,L(#$R+"`@-RP@,3$L("`T+"`@,BP@(#@L"B`@("`@("`@("`@,3,L("`W
M+"`@,"P@(#DL("`S+"`@-"P@(#8L(#$P+"`@,BP@(#@L("`U+"`Q-"P@,3(L
M(#$Q+"`Q-2P@(#$L"B`@("`@("`@("`@,3,L("`V+"`@-"P@(#DL("`X+"`Q
M-2P@(#,L("`P+"`Q,2P@(#$L("`R+"`Q,BP@(#4L(#$P+"`Q-"P@(#<L"B`@
M("`@("`@("`@(#$L(#$P+"`Q,RP@(#`L("`V+"`@.2P@(#@L("`W+"`@-"P@
M,34L(#$T+"`@,RP@,3$L("`U+"`@,BP@,3(L"B`@("`@("`@*2P*"B`@("`@
M("`@+RH@4S0@*B\*("`@("`@("`T(#T^(&%R<F%Y*`H@("`@("`@("`@("`W
M+"`Q,RP@,30L("`S+"`@,"P@(#8L("`Y+"`Q,"P@(#$L("`R+"`@."P@(#4L
M(#$Q+"`Q,BP@(#0L(#$U+`H@("`@("`@("`@(#$S+"`@."P@,3$L("`U+"`@
M-BP@,34L("`P+"`@,RP@(#0L("`W+"`@,BP@,3(L("`Q+"`Q,"P@,30L("`Y
M+`H@("`@("`@("`@(#$P+"`@-BP@(#DL("`P+"`Q,BP@,3$L("`W+"`Q,RP@
M,34L("`Q+"`@,RP@,30L("`U+"`@,BP@(#@L("`T+`H@("`@("`@("`@("`S
M+"`Q-2P@(#`L("`V+"`Q,"P@(#$L(#$S+"`@."P@(#DL("`T+"`@-2P@,3$L
M(#$R+"`@-RP@(#(L(#$T+`H@("`@("`@("DL"@H@("`@("`@("\J(%,U("HO
M"B`@("`@("`@-2`]/B!A<G)A>2@*("`@("`@("`@("`@,BP@,3(L("`T+"`@
M,2P@(#<L(#$P+"`Q,2P@(#8L("`X+"`@-2P@(#,L(#$U+"`Q,RP@(#`L(#$T
M+"`@.2P*("`@("`@("`@("`Q-"P@,3$L("`R+"`Q,BP@(#0L("`W+"`Q,RP@
M(#$L("`U+"`@,"P@,34L(#$P+"`@,RP@(#DL("`X+"`@-BP*("`@("`@("`@
M("`@-"P@(#(L("`Q+"`Q,2P@,3`L(#$S+"`@-RP@(#@L(#$U+"`@.2P@,3(L
M("`U+"`@-BP@(#,L("`P+"`Q-"P*("`@("`@("`@("`Q,2P@(#@L(#$R+"`@
M-RP@(#$L(#$T+"`@,BP@,3,L("`V+"`Q-2P@(#`L("`Y+"`Q,"P@(#0L("`U
M+"`@,RP*("`@("`@("`I+`H*("`@("`@("`O*B!3-B`J+PH@("`@("`@(#8@
M/3X@87)R87DH"B`@("`@("`@("`@,3(L("`Q+"`Q,"P@,34L("`Y+"`@,BP@
M(#8L("`X+"`@,"P@,3,L("`S+"`@-"P@,30L("`W+"`@-2P@,3$L"B`@("`@
M("`@("`@,3`L(#$U+"`@-"P@(#(L("`W+"`Q,BP@(#DL("`U+"`@-BP@(#$L
M(#$S+"`Q-"P@(#`L(#$Q+"`@,RP@(#@L"B`@("`@("`@("`@(#DL(#$T+"`Q
M-2P@(#4L("`R+"`@."P@,3(L("`S+"`@-RP@(#`L("`T+"`Q,"P@(#$L(#$S
M+"`Q,2P@(#8L"B`@("`@("`@("`@(#0L("`S+"`@,BP@,3(L("`Y+"`@-2P@
M,34L(#$P+"`Q,2P@,30L("`Q+"`@-RP@(#8L("`P+"`@."P@,3,L"B`@("`@
M("`@*2P*"B`@("`@("`@+RH@4S<@*B\*("`@("`@("`W(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`T+"`Q,2P@(#(L(#$T+"`Q-2P@(#`L("`X+"`Q,RP@(#,L
M(#$R+"`@.2P@(#<L("`U+"`Q,"P@(#8L("`Q+`H@("`@("`@("`@(#$S+"`@
M,"P@,3$L("`W+"`@-"P@(#DL("`Q+"`Q,"P@,30L("`S+"`@-2P@,3(L("`R
M+"`Q-2P@(#@L("`V+`H@("`@("`@("`@("`Q+"`@-"P@,3$L(#$S+"`Q,BP@
M(#,L("`W+"`Q-"P@,3`L(#$U+"`@-BP@(#@L("`P+"`@-2P@(#DL("`R+`H@
M("`@("`@("`@("`V+"`Q,2P@,3,L("`X+"`@,2P@(#0L(#$P+"`@-RP@(#DL
M("`U+"`@,"P@,34L(#$T+"`@,BP@(#,L(#$R+`H@("`@("`@("DL"@H@("`@
M("`@("\J(%,X("HO"B`@("`@("`@."`]/B!A<G)A>2@*("`@("`@("`@("`@
M,3,L("`R+"`@."P@(#0L("`V+"`Q-2P@,3$L("`Q+"`Q,"P@(#DL("`S+"`Q
M-"P@(#4L("`P+"`Q,BP@(#<L"B`@("`@("`@("`@("`Q+"`Q-2P@,3,L("`X
M+"`Q,"P@(#,L("`W+"`@-"P@,3(L("`U+"`@-BP@,3$L("`P+"`Q-"P@(#DL
M("`R+`H@("`@("`@("`@("`@-RP@,3$L("`T+"`@,2P@(#DL(#$R+"`Q-"P@
M(#(L("`P+"`@-BP@,3`L(#$S+"`Q-2P@(#,L("`U+"`@."P*("`@("`@("`@
M("`@(#(L("`Q+"`Q-"P@(#<L("`T+"`Q,"P@(#@L(#$S+"`Q-2P@,3(L("`Y
M+"`@,"P@(#,L("`U+"`@-BP@,3$*("`@("`@("`I"B`@("`I.PH*("`@("\J
M*@H@("`@("H@4')I;6ET:79E(&9U;F-T:6]N"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)'`@/2!A<G)A>2@*("`@("`@("`Q
M-BP@(#<L(#(P+"`R,2P*("`@("`@("`R.2P@,3(L(#(X+"`Q-RP*("`@("`@
M("`@,2P@,34L(#(S+"`R-BP*("`@("`@("`@-2P@,3@L(#,Q+"`Q,"P*("`@
M("`@("`@,BP@(#@L(#(T+"`Q-"P*("`@("`@("`S,BP@,C<L("`S+"`@.2P*
M("`@("`@("`Q.2P@,3,L(#,P+"`@-BP*("`@("`@("`R,BP@,3$L("`T+"`R
M-0H@("`@*3L*"B`@("`O*BH*("`@("`J(%!E<FUU=&5D($-H;VEC92!486)L
M90H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1P
M8S$@/2!A<G)A>2@*("`@("`@("`U-RP@-#DL(#0Q+"`S,RP@,C4L(#$W+"`@
M.2P*("`@("`@("`@,2P@-3@L(#4P+"`T,BP@,S0L(#(V+"`Q."P*("`@("`@
M("`Q,"P@(#(L(#4Y+"`U,2P@-#,L(#,U+"`R-RP*("`@("`@("`Q.2P@,3$L
M("`S+"`V,"P@-3(L(#0T+"`S-BP*"B`@("`@("`@-C,L(#4U+"`T-RP@,SDL
M(#,Q+"`R,RP@,34L"B`@("`@("`@(#<L(#8R+"`U-"P@-#8L(#,X+"`S,"P@
M,C(L"B`@("`@("`@,30L("`V+"`V,2P@-3,L(#0U+"`S-RP@,CDL"B`@("`@
M("`@,C$L(#$S+"`@-2P@,C@L(#(P+"`Q,BP@(#0*("`@("D["@H@("`@+RHJ
M"B`@("`@*B!.=6UB97(@;&5F="!R;W1A=&EO;G,@;V8@<&,Q"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)'-H:69T<R`](&%R
M<F%Y*`H@("`@("`@(#$L(#$L(#(L(#(L(#(L(#(L(#(L(#(L"B`@("`@("`@
M,2P@,BP@,BP@,BP@,BP@,BP@,BP@,0H@("`@*3L*"B`@("`O*BH*("`@("`J
M(%!E<FUU=&5D($-H;VEC92!486)L92`R"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)'!C,B`](&%R<F%Y*`H@("`@("`@(#$T
M+"`Q-RP@,3$L(#(T+"`@,2P@(#4L"B`@("`@("`@(#,L(#(X+"`Q-2P@(#8L
M(#(Q+"`Q,"P*("`@("`@("`R,RP@,3DL(#$R+"`@-"P@,C8L("`X+`H@("`@
M("`@(#$V+"`@-RP@,C<L(#(P+"`Q,RP@(#(L"B`@("`@("`@-#$L(#4R+"`S
M,2P@,S<L(#0W+"`U-2P*("`@("`@("`S,"P@-#`L(#4Q+"`T-2P@,S,L(#0X
M+`H@("`@("`@(#0T+"`T.2P@,SDL(#4V+"`S-"P@-3,L"B`@("`@("`@-#8L
M(#0R+"`U,"P@,S8L(#(Y+"`S,@H@("`@*3L*"B`@("`O*BH*("`@("`J($ME
M>2!38VAE9'5L90H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1?2W,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@4V5T('1H
M92!K97D@=&\@8F4@=7-E9"!F;W(@96XO9&5C<GEP=&EO;BX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1K97D@(%1H92!K97D@=&\@=7-E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S971+97DH)&ME>2D*("`@('L*("`@("`@("!I
M9B`H(6ES7VYU;&PH)&ME>2DI('L*("`@("`@("`@("`@)'1H:7,M/E]+<R`]
M("1T:&ES+3Y?:V5Y4V-H961U;&4H)&ME>2D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N('1H92!S:7IE(&]F('1H92!B;&]C:W,@
M=&AA="!T:&ES(&-I<&AE<B!N965D<RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN=&5G97(@(%1H92!N=6UB97(@;V8@8VAA<F%C=&5R<R!P97(@8FQO8VLN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$)L;V-K4VEZ92@I"B`@("!["B`@
M("`@("`@<F5T=7)N(#@["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%;F-R>7!T
M(&$@8FQO8VL@;V8@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1B;&]C:R`@5&AE(&1A=&$@=&\@96YC<GEP="X*("`@("`J($!P87)A;2!S
M=')I;F<@)&ME>2`@("!4:&4@:V5Y('1O('5S92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&5N8W)Y<'1E9"!O=71P=70N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&5N8W)Y<'1";&]C:R@D8FQO8VLL("1K97D@/2!N=6QL
M*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D:V5Y*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7TMS(#T@)'1H:7,M/E]K97E38VAE9'5L92@D:V5Y*3L*
M("`@("`@("!]"@H@("`@("`@("1B;&]C:R`]("1T:&ES+3Y?:6YI=&EA;%!E
M<FTH)&)L;V-K*3L*"B`@("`@("`@)$P@/2!S=6)S='(H)&)L;V-K+"`P+"`T
M*3L*("`@("`@("`D4B`]('-U8G-T<B@D8FQO8VLL(#0L(#0I.PH*("`@("`@
M("!F;W(@*"1I(#T@,3L@)&D@/#T@,38[("1I*RL@*2!["B`@("`@("`@("`@
M("127W!R978@/2`D4CL*("`@("`@("`@("`@)$Q?<')E=B`]("1,.PH*("`@
M("`@("`@("`@)$P@/2`D4CL*("`@("`@("`@("`@)%(@/2`D3%]P<F5V(%X@
M)'1H:7,M/E]F*"127W!R978L("1I*3L*("`@("`@("!]"@H@("`@("`@("1B
M;&]C:R`]("12("X@)$P["B`@("`@("`@)&)L;V-K(#T@)'1H:7,M/E]F:6YA
M;%!E<FTH)&)L;V-K*3L*"B`@("`@("`@<F5T=7)N("1B;&]C:SL*("`@('T*
M"B`@("`O*BH*("`@("`J($1E8W)Y<'0@82!B;&]C:R!O9B!D871A+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&)L;V-K("!4:&4@9&%T82!T;R!D
M96-R>7!T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("`@(%1H92!K97D@
M=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9&5C
M<GEP=&5D(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C<GEP=$)L
M;V-K*"1B;&]C:RP@)&ME>2`](&YU;&PI"B`@("!["B`@("`@("`@)&)L;V-K
M(#T@)'1H:7,M/E]I;FET:6%L4&5R;2@D8FQO8VLI.PH*("`@("`@("!I9B`H
M(6ES7VYU;&PH)&ME>2DI('L*("`@("`@("`@("`@)'1H:7,M/E]+<R`]("1T
M:&ES+3Y?:V5Y4V-H961U;&4H)&ME>2D["B`@("`@("`@?0H*("`@("`@("`D
M3"`]('-U8G-T<B@D8FQO8VLL(#`L(#0I.PH@("`@("`@("12(#T@<W5B<W1R
M*"1B;&]C:RP@-"P@-"D["@H@("`@("`@(&9O<B`H)&D@/2`Q-CL@)&D@/CT@
M,3L@)&DM+2`I('L*("`@("`@("`@("`@)%)?<')E=B`]("12.PH@("`@("`@
M("`@("`D3%]P<F5V(#T@)$P["@H@("`@("`@("`@("`D3"`]("127W!R978[
M"B`@("`@("`@("`@("12(#T@)$Q?<')E=B!>("1T:&ES+3Y?9B@D4E]P<F5V
M+"`D:2D["B`@("`@("`@?0H*("`@("`@("`D8FQO8VL@/2`D4B`N("1,.PH@
M("`@("`@("1B;&]C:R`]("1T:&ES+3Y?9FEN86Q097)M*"1B;&]C:RD["@H@
M("`@("`@(')E='5R;B`D8FQO8VL["B`@("!]"@H@("`@+RHJ"B`@("`@*B!0
M=70@86X@:6YP=70@<W1R:6YG('1H<F]U9V@@86X@:6YI=&EA;"!P97)M=71A
M=&EO;@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&EN<'5T("!);G!U
M="!S=')I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%!E<FUU
M=&%T960@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!?:6YI=&EA;%!E
M<FTH)&EN<'5T*0H@("`@>PH@("`@("`@("\O(%1/1$\Z(%-O;64@<W1Y;&EE
M(&)I='=I<V4@=&AI;F<@:6YS=&5A9"X*"B`@("`@("`@)&EN<'5T7V)I;B`]
M("<G.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(#@[("1I*RLI('L*("`@
M("`@("`@("`@)&EN<'5T7V)I;B`N/2!S=')?<&%D*&1E8V)I;BAO<F0H)&EN
M<'5T6R1I72DI+"`X+"`G,"<L(%-44E]0041?3$5&5"D["B`@("`@("`@?0H*
M("`@("`@("`D;W5T<'5T7V)I;B`]("<G.PH@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3YI<"!A<R`D;V9F<V5T*2!["B`@("`@("`@("`@("1O=71P=71?8FEN
M("X]("1I;G!U=%]B:6Y;)&]F9G-E="`M(#%=.PH@("`@("`@('T*"B`@("`@
M("`@)&]U='!U="`]("<G.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(#@[
M("1I*RLI('L*("`@("`@("`@("`@)&]U='!U="`N/2!C:'(H8FEN9&5C*'-U
M8G-T<B@D;W5T<'5T7V)I;BP@."`J("1I+"`X*2DI.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1O=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!0
M=70@86X@:6YP=70@<W1R:6YG('1H<F]U9V@@82!F:6YA;"!P97)M=71A=&EO
M;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I;G!U="`@26YP=70@
M<W1R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!097)M=71A
M=&5D('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V9I;F%L4&5R;2@D
M:6YP=70I"B`@("!["B`@("`@("`@+R\@5$]$3SH@4V]M92!S='EL:64@8FET
M=VES92!T:&EN9R!I;G-T96%D+@H@("`@("`@("1I;G!U=%]B:6X@/2`G)SL*
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`X.R`D:2LK*2!["B`@("`@("`@
M("`@("1I;G!U=%]B:6X@+CT@<W1R7W!A9"AD96-B:6XH;W)D*"1I;G!U=%LD
M:5TI*2P@."P@)S`G+"!35%)?4$%$7TQ%1E0I.PH@("`@("`@('T*"B`@("`@
M("`@)&]U='!U=%]B:6X@/2`G)SL*("`@("`@("!F;W)E86-H("@D=&AI<RT^
M9G`@87,@)&]F9G-E="D@>PH@("`@("`@("`@("`D;W5T<'5T7V)I;B`N/2`D
M:6YP=71?8FEN6R1O9F9S970@+2`Q73L*("`@("`@("!]"@H@("`@("`@("1O
M=71P=70@/2`G)SL*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`X.R`D:2LK
M*2!["B`@("`@("`@("`@("1O=71P=70@+CT@8VAR*&)I;F1E8RAS=6)S='(H
M)&]U='!U=%]B:6XL(#@@*B`D:2P@."DI*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D;W5T<'5T.PH@("`@?0H*"B`@("`O*BH*("`@("`J(&8H*2!4
M:&4@<&5R;75T871I;VX@9G5N8W1I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D:6YP=70@($EN<'5T('-T<FEN9RX*("`@("`J($!P87)A;2!I
M;G1E9V5R("1R;W5N9"`@5&AE(')O=6YD+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@;W5T<'5T('-T<FEN9RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V8H)&EN<'5T+"`D<F]U;F0I"B`@("!["B`@("`@("`@+R\@5$]$
M3SH@4V]M92!S='EL:64@8FET=VES92!T:&EN9R!I;G-T96%D+@H@("`@("`@
M("1K97D@/2`D=&AI<RT^7TMS6R1R;W5N9%T["@H@("`@("`@("1I;G!U=%]B
M:6X@/2`G)SL*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`T.R`D:2LK*2![
M"B`@("`@("`@("`@("1I;G!U=%]B:6X@+CT@<W1R7W!A9"AD96-B:6XH;W)D
M*"1I;G!U=%LD:5TI*2P@."P@)S`G+"!35%)?4$%$7TQ%1E0I.PH@("`@("`@
M('T*"B`@("`@("`@)&5X<&%N9&5D7V)I;B`]("<G.PH@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3YE(&%S("1O9F9S970I('L*("`@("`@("`@("`@)&5X<&%N
M9&5D7V)I;B`N/2`D:6YP=71?8FEN6R1O9F9S970@+2`Q73L*("`@("`@("!]
M"@H@("`@("`@("1E>'!A;F1E9"`](&%R<F%Y*"D["B`@("`@("`@9F]R("@D
M:2`](#`[("1I(#P@.#L@)&DK*RD@>PH@("`@("`@("`@("`D97AP86YD961;
M)&E=(#T@8FEN9&5C*"<P,"<@+B!S=6)S='(H)&5X<&%N9&5D7V)I;BP@)&D@
M*B`V+"`V*2D@7B`D:V5Y6R1I73L*("`@("`@("!]"@H@("`@("`@("1C;VUB
M:6YE9%]B:6X@/2`G)SL*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`X.R`D
M:2LK*2!["B`@("`@("`@("`@("1S7VEN9&5X(#T@*"@D97AP86YD961;)&E=
M("8@,'@R,"D@/CX@-"D@?"`H)&5X<&%N9&5D6R1I72`F(#!X,#$I.PH@("`@
M("`@("`@("`D<U]I;F1E>"`](#$V("H@)'-?:6YD97@@*R`H*"1E>'!A;F1E
M9%LD:5T@)B`P>#%%*2`^/B`Q*3L*("`@("`@("`@("`@)'9A;"`]("1T:&ES
M+3Y?<ULD:2`K(#%=6R1S7VEN9&5X73L*("`@("`@("`@("`@)&-O;6)I;F5D
M7V)I;B`N/2!S=')?<&%D*&1E8V)I;B@D=F%L*2P@-"P@)S`G+"!35%)?4$%$
M7TQ%1E0I.PH@("`@("`@('T*"B`@("`@("`@)&]U='!U=%]B:6X@/2`G)SL*
M("`@("`@("!F;W)E86-H("@D=&AI<RT^<"!A<R`D;V9F<V5T*2!["B`@("`@
M("`@("`@("1O=71P=71?8FEN("X]("1C;VUB:6YE9%]B:6Y;)&]F9G-E="`M
M(#%=.PH@("`@("`@('T*"B`@("`@("`@)&]U='!U="`]("<G.PH@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\(#0[("1I*RLI('L*("`@("`@("`@("`@)&]U
M='!U="`N/2!C:'(H8FEN9&5C*'-U8G-T<B@D;W5T<'5T7V)I;BP@)&D@*B`X
M+"`X*2DI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O=71P=70["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@=&AE(&-O;7!L971E(&ME>2!S
M:&5D=6QE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@5&AE
M(&ME>2!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2!+97D@
M<V-H961U;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]K97E38VAE9'5L92@D
M:V5Y*0H@("`@>PH@("`@("`@("1K97D@/2!S=')?<&%D*"1K97DL(#@L(")<
M,"(I.PH@("`@("`@("1K<R`](&%R<F%Y*"D["@H@("`@("`@("1K97E?8FEN
M(#T@)R<["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@.#L@)&DK*RD@>PH@
M("`@("`@("`@("`D:V5Y7V)I;B`N/2!S=')?<&%D*&1E8V)I;BAO<F0H)&ME
M>5LD:5TI*2P@."P@)S`G+"!35%)?4$%$7TQ%1E0I.PH@("`@("`@('T*"B`@
M("`@("`@)&,@/2`G)SL*("`@("`@("`D9"`]("<G.PH@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\(#(X.R`D:2LK*2!["B`@("`@("`@("`@("1C("X]("1K
M97E?8FEN6R1T:&ES+3YP8S%;)&E=("T@,5T["B`@("`@("`@("`@("1D("X]
M("1K97E?8FEN6R1T:&ES+3YP8S%;,C@@*R`D:5T@+2`Q73L*("`@("`@("!]
M"@H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(#$V.R`D:2LK*2!["B`@("`@
M("`@("`@("1C(#T@<W5B<W1R*"1C+"`D=&AI<RT^<VAI9G1S6R1I72D@+B!S
M=6)S='(H)&,L(#`L("1T:&ES+3YS:&EF='-;)&E=*3L*("`@("`@("`@("`@
M)&0@/2!S=6)S='(H)&0L("1T:&ES+3YS:&EF='-;)&E=*2`N('-U8G-T<B@D
M9"P@,"P@)'1H:7,M/G-H:69T<ULD:5TI.PH*("`@("`@("`@("`@)&-D(#T@
M)&,@+B`D9#L*"B`@("`@("`@("`@("1P97)M=71A=&5D7V)I;B`]("<G.PH@
M("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^<&,R(&%S("1O9F9S970I('L*
M("`@("`@("`@("`@("`@("1P97)M=71A=&5D7V)I;B`N/2`D8V1;)&]F9G-E
M="`M(#%=.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!F;W(@*"1J(#T@
M,#L@)&H@/"`X.R`D:BLK*2!["B`@("`@("`@("`@("`@("`D:W-;)&D@*R`Q
M75M=(#T@8FEN9&5C*"<P,"<@+B!S=6)S='(H)'!E<FUU=&%T961?8FEN+"`D
M:B`J(#8L(#8I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1K<SL*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-I<&AE<B]R8S(N
M<&AP````````````````````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-S`W-P`Q
M,#4Q-30S,S<U,``P,C(Q,#<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J(%1H92!#:7!H97)?<F,R.CH@
M8VQA<W,@:6UP;&5M96YT<R!T:&4@0VEP:&5R(&EN=&5R9F%C92!E;F-R>7!T
M:6]N(&1A=&$*("H@=7-I;F<@=&AE(%)#,B!A;&=O<FET:&T@87,@9&5S8W)I
M8F5D(&EN(%)&0S(R-C@N"B`J"B`J($)A<V5D(&]N('1H92!N;W1E<R!B>2!0
M971E<B!'=71M86YN(#QP9W5T,#%`8W,N875C:VQA;F0N86,N;GH^"B`J(&AT
M='`Z+R]W=W<N;6ER<F]R<RYW:7)E=&%P<&5D+FYE="]S96-U<FET>2]C<GEP
M=&]G<F%P:'DO"B`J("`@86QG;W)I=&AM<R]R8S(O8V]M;65N=',O9W5T;6%N
M+3DV,#(Q,0H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#:7!H97(O0VEP:&5R
M+W)C,BYP:'`L=B`Q+CDN,3(N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C$P(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI:V4@0V]C:')A;F4@
M/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ
M/@H@*B!`<VEN8V4@("!(;W)D92`R+C(*("H@0'!A8VMA9V4@2&]R9&5?0VEP
M:&5R"B`J+PIC;&%S<R!(;W)D95]#:7!H97)?<F,R(&5X=&5N9',@2&]R9&5?
M0VEP:&5R('L*"B`@("`O*BH*("`@("`J(%!E<FUU=&%T:6]N<R!A<G)A>0H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&5R
M;2`](&%R<F%Y*`H@("`@("`@(#!X1#DL(#!X-S@L(#!X1CDL(#!X0S0L(#!X
M,3DL(#!X1$0L(#!X0C4L(#!X140L"B`@("`@("`@,'@R."P@,'A%.2P@,'A&
M1"P@,'@W.2P@,'@T02P@,'A!,"P@,'A$."P@,'@Y1"P*("`@("`@("`P>$,V
M+"`P>#=%+"`P>#,W+"`P>#@S+"`P>#)"+"`P>#<V+"`P>#4S+"`P>#A%+`H@
M("`@("`@(#!X-C(L(#!X-$,L(#!X-C0L(#!X.#@L(#!X-#0L(#!X.$(L(#!X
M1D(L(#!X03(L"B`@("`@("`@,'@Q-RP@,'@Y02P@,'@U.2P@,'A&-2P@,'@X
M-RP@,'A",RP@,'@T1BP@,'@Q,RP*("`@("`@("`P>#8Q+"`P>#0U+"`P>#9$
M+"`P>#A$+"`P>#`Y+"`P>#@Q+"`P>#=$+"`P>#,R+`H@("`@("`@(#!X0D0L
M(#!X.$8L(#!X-#`L(#!X14(L(#!X.#8L(#!X0C<L(#!X-T(L(#!X,$(L"B`@
M("`@("`@,'A&,"P@,'@Y-2P@,'@R,2P@,'@R,BP@,'@U0RP@,'@V0BP@,'@T
M12P@,'@X,BP*("`@("`@("`P>#4T+"`P>$0V+"`P>#8U+"`P>#DS+"`P>$-%
M+"`P>#8P+"`P>$(R+"`P>#%#+`H@("`@("`@(#!X-S,L(#!X-38L(#!X0S`L
M(#!X,30L(#!X03<L(#!X.$,L(#!X1C$L(#!X1$,L"B`@("`@("`@,'@Q,BP@
M,'@W-2P@,'A#02P@,'@Q1BP@,'@S0BP@,'A"12P@,'A%-"P@,'A$,2P*("`@
M("`@("`P>#0R+"`P>#-$+"`P>$0T+"`P>#,P+"`P>$$S+"`P>#-#+"`P>$(V
M+"`P>#(V+`H@("`@("`@(#!X-D8L(#!X0D8L(#!X,$4L(#!X1$$L(#!X-#8L
M(#!X-CDL(#!X,#<L(#!X-3<L"B`@("`@("`@,'@R-RP@,'A&,BP@,'@Q1"P@
M,'@Y0BP@,'A"0RP@,'@Y-"P@,'@T,RP@,'@P,RP*("`@("`@("`P>$8X+"`P
M>#$Q+"`P>$,W+"`P>$8V+"`P>#DP+"`P>$5&+"`P>#-%+"`P>$4W+`H@("`@
M("`@(#!X,#8L(#!X0S,L(#!X1#4L(#!X,D8L(#!X0S@L(#!X-C8L(#!X,44L
M(#!X1#<L"B`@("`@("`@,'@P."P@,'A%."P@,'A%02P@,'A$12P@,'@X,"P@
M,'@U,BP@,'A%12P@,'A&-RP*("`@("`@("`P>#@T+"`P>$%!+"`P>#<R+"`P
M>$%#+"`P>#,U+"`P>#1$+"`P>#9!+"`P>#)!+`H@("`@("`@(#!X.38L(#!X
M,4$L(#!X1#(L(#!X-S$L(#!X-4$L(#!X,34L(#!X-#DL(#!X-S0L"B`@("`@
M("`@,'@T0BP@,'@Y1BP@,'A$,"P@,'@U12P@,'@P-"P@,'@Q."P@,'A!-"P@
M,'A%0RP*("`@("`@("`P>$,R+"`P>$4P+"`P>#0Q+"`P>#9%+"`P>#!&+"`P
M>#4Q+"`P>$-"+"`P>$-#+`H@("`@("`@(#!X,C0L(#!X.3$L(#!X048L(#!X
M-3`L(#!X03$L(#!X1C0L(#!X-S`L(#!X,SDL"B`@("`@("`@,'@Y.2P@,'@W
M0RP@,'@S02P@,'@X-2P@,'@R,RP@,'A"."P@,'A"-"P@,'@W02P*("`@("`@
M("`P>$9#+"`P>#`R+"`P>#,V+"`P>#5"+"`P>#(U+"`P>#4U+"`P>#DW+"`P
M>#,Q+`H@("`@("`@(#!X,D0L(#!X-40L(#!X1D$L(#!X.3@L(#!X13,L(#!X
M.$$L(#!X.3(L(#!X044L"B`@("`@("`@,'@P-2P@,'A$1BP@,'@R.2P@,'@Q
M,"P@,'@V-RP@,'@V0RP@,'A"02P@,'A#.2P*("`@("`@("`P>$0S+"`P>#`P
M+"`P>$4V+"`P>$-&+"`P>$4Q+"`P>#E%+"`P>$$X+"`P>#)#+`H@("`@("`@
M(#!X-C,L(#!X,38L(#!X,#$L(#!X,T8L(#!X-3@L(#!X13(L(#!X.#DL(#!X
M03DL"B`@("`@("`@,'@P1"P@,'@S."P@,'@S-"P@,'@Q0BP@,'A!0BP@,'@S
M,RP@,'A&1BP@,'A","P*("`@("`@("`P>$)"+"`P>#0X+"`P>#!#+"`P>#5&
M+"`P>$(Y+"`P>$(Q+"`P>$-$+"`P>#)%+`H@("`@("`@(#!X0S4L(#!X1C,L
M(#!X1$(L(#!X-#<L(#!X134L(#!X034L(#!X.4,L(#!X-S<L"B`@("`@("`@
M,'@P02P@,'A!-BP@,'@R,"P@,'@V."P@,'A&12P@,'@W1BP@,'A#,2P@,'A!
M1`H@("`@*3L*"B`@("`O*BH*("`@("`J($%R<F%Y('1O(&AO;&0@=&AE(&ME
M>2!S8VAE9'5L90H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1?:V5Y4V-H961U;&4@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H@4V5T('1H92!K97D@=&\@8F4@=7-E9"!F;W(@96XO9&5C<GEP=&EO;BX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1K97D@(%1H92!K97D@=&\@
M=7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971+97DH)&ME>2D*("`@('L*
M("`@("`@("`D:V5Y(#T@87)R87E?=F%L=65S*'5N<&%C:R@G0RHG+"`D:V5Y
M*2D["B`@("`@("`@)&)I=',@/2`Q,#(T.PH*("`@("`@("`O*B!%>'!A;F0@
M:6YP=70@:V5Y('1O(#$R."!B>71E<R`J+PH@("`@("`@("1L96X@/2!C;W5N
M="@D:V5Y*3L*("`@("`@("`D;&%S="`]("1K97E;)&QE;B`M(#%=.PH@("`@
M("`@(&9O<B`H)&D@/2`D;&5N.R`D:2`\(#$R.#L@)&DK*RD@>PH@("`@("`@
M("`@("`D;&%S="`]("1T:&ES+3Y?<&5R;5LH)&ME>5LD:2`M("1L96Y=("L@
M)&QA<W0I("8@,'A&1ET["B`@("`@("`@("`@("1K97E;)&E=(#T@)&QA<W0[
M"B`@("`@("`@?0H*("`@("`@("`O*B!0:&%S92`R("T@<F5D=6-E(&5F9F5C
M=&EV92!K97D@<VEZ92!T;R`B8FET<R(@*B\*("`@("`@("!I9B`H)&QE;B`A
M/2`X*2!["B`@("`@("`@("`@("1L96X@/2`D;&5N("H@.#L*("`@("`@("!]
M"B`@("`@("`@)&ME>5LQ,C@@+2`D;&5N72`]("1T:&ES+3Y?<&5R;5LD:V5Y
M6S$R."`M("1L96Y=("8@,'A&1ET["B`@("`@("`@9F]R("@D:2`](#$R-R`M
M("1L96X[("1I(#X](#`[("1I+2TI('L*("`@("`@("`@("`@)&ME>5LD:5T@
M/2`D=&AI<RT^7W!E<FU;)&ME>5LD:2`K("1L96Y=(%X@)&ME>5LD:2`K(#%=
M73L*("`@("`@("!]"@H@("`@("`@("\J(%!H87-E(#,@+2!C;VYV97)T('1O
M(#$V(&)I="!V86QU97,@*B\*("`@("`@("!F;W(@*"1I(#T@-C,[("1I(#X]
M(#`[("1I+2TI('L*("`@("`@("`@("`@)'1H:7,M/E]K97E38VAE9'5L95LD
M:5T@/2`H)&ME>5LD:2`J(#(@*R`Q72`\/"`X('P@)&ME>5LD:2`J(#)=*2`F
M(#!X1D9&1CL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FX@=&AE('-I>F4@;V8@=&AE(&)L;V-K<R!T:&%T('1H:7,@8VEP:&5R(&YE
M961S+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&YU;6)E
M<B!O9B!C:&%R86-T97)S('!E<B!B;&]C:RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T0FQO8VM3:7IE*"D*("`@('L*("`@("`@("!R971U<FX@.#L*("`@
M('T*"B`@("`O*BH*("`@("`J($5N8W)Y<'0@82!B;&]C:R!O9B!D871A+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&)L;V-K("!4:&4@9&%T82!T
M;R!E;F-R>7!T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("`@(%1H92!K
M97D@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M96YC<GEP=&5D(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@96YC<GEP
M=$)L;V-K*"1B;&]C:RP@)&ME>2`](&YU;&PI"B`@("!["B`@("`@("`@:68@
M*"%I<U]N=6QL*"1K97DI*2!["B`@("`@("`@("`@("1T:&ES+3YS971+97DH
M)&ME>2D["B`@("`@("`@?0H*("`@("`@("`D<&QA:6X@/2!U;G!A8VLH)W8J
M)RP@)&)L;V-K*3L*"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@,38[("1I
M*RLI('L*("`@("`@("`@("`@)'!L86EN6S%=("L]("@D<&QA:6Y;,ET@)B!^
M)'!L86EN6S1=*2`K("@D<&QA:6Y;,UT@)B`D<&QA:6Y;-%TI("L@)'1H:7,M
M/E]K97E38VAE9'5L95LT("H@)&D@*R`P73L*("`@("`@("`@("`@)&)I;B`]
M('-T<E]P860H9&5C8FEN*#!X1D9&1B`F("1P;&%I;ELQ72DL(#,R+"`G,"<L
M(%-44E]0041?3$5&5"D["B`@("`@("`@("`@("1P;&%I;ELQ72`](&)I;F1E
M8R@D8FEN("X@<W5B<W1R*"1B:6XL(#$V+"`Q*2D["@H@("`@("`@("`@("`D
M<&QA:6Y;,ET@*ST@*"1P;&%I;ELS72`F('XD<&QA:6Y;,5TI("L@*"1P;&%I
M;ELT72`F("1P;&%I;ELQ72D@*R`D=&AI<RT^7VME>5-C:&5D=6QE6S0@*B`D
M:2`K(#%=.PH@("`@("`@("`@("`D8FEN(#T@<W1R7W!A9"AD96-B:6XH,'A&
M1D9&("8@)'!L86EN6S)=*2P@,S(L("<P)RP@4U127U!!1%],1494*3L*("`@
M("`@("`@("`@)'!L86EN6S)=(#T@8FEN9&5C*"1B:6X@+B!S=6)S='(H)&)I
M;BP@,38L(#(I*3L*"B`@("`@("`@("`@("1P;&%I;ELS72`K/2`H)'!L86EN
M6S1=("8@?B1P;&%I;ELR72D@*R`H)'!L86EN6S%=("8@)'!L86EN6S)=*2`K
M("1T:&ES+3Y?:V5Y4V-H961U;&5;-"`J("1I("L@,ET["B`@("`@("`@("`@
M("1B:6X@/2!S=')?<&%D*&1E8V)I;B@P>$9&1D8@)B`D<&QA:6Y;,UTI+"`Q
M-BP@)S`G+"!35%)?4$%$7TQ%1E0I.PH@("`@("`@("`@("`D<&QA:6Y;,UT@
M/2!B:6YD96,H)&)I;B`N('-U8G-T<B@D8FEN+"`P+"`S*2D["@H@("`@("`@
M("`@("`D<&QA:6Y;-%T@*ST@*"1P;&%I;ELQ72`F('XD<&QA:6Y;,UTI("L@
M*"1P;&%I;ELR72`F("1P;&%I;ELS72D@*R`D=&AI<RT^7VME>5-C:&5D=6QE
M6S0@*B`D:2`K(#-=.PH@("`@("`@("`@("`D8FEN(#T@<W1R7W!A9"AD96-B
M:6XH,'A&1D9&("8@)'!L86EN6S1=*2P@,38L("<P)RP@4U127U!!1%],1494
M*3L*("`@("`@("`@("`@)'!L86EN6S1=(#T@8FEN9&5C*"1B:6X@+B!S=6)S
M='(H)&)I;BP@,"P@-2DI.PH*("`@("`@("`@("`@:68@*"1I(#T](#0@?'P@
M)&D@/3T@,3`I('L*("`@("`@("`@("`@("`@("1P;&%I;ELQ72`K/2`D=&AI
M<RT^7VME>5-C:&5D=6QE6R1P;&%I;ELT72`F(#!X,T9=.PH@("`@("`@("`@
M("`@("`@)'!L86EN6S)=("L]("1T:&ES+3Y?:V5Y4V-H961U;&5;)'!L86EN
M6S%=("8@,'@S1ET["B`@("`@("`@("`@("`@("`D<&QA:6Y;,UT@*ST@)'1H
M:7,M/E]K97E38VAE9'5L95LD<&QA:6Y;,ET@)B`P>#-&73L*("`@("`@("`@
M("`@("`@("1P;&%I;ELT72`K/2`D=&AI<RT^7VME>5-C:&5D=6QE6R1P;&%I
M;ELS72`F(#!X,T9=.PH@("`@("`@("`@("!]"@H@("`@("`@('T*"B`@("`@
M("`@)&5N8W)Y<'1E9"`]('!A8VLH(G8J(BP@)'!L86EN6S%=+"`D<&QA:6Y;
M,ETL("1P;&%I;ELS72P@)'!L86EN6S1=*3L*("`@("`@("!R971U<FX@)&5N
M8W)Y<'1E9#L*("`@('T*"B`@("`O*BH*("`@("`J($1E8W)Y<'0@82!B;&]C
M:R!O9B!D871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&)L;V-K
M("!4:&4@9&%T82!T;R!D96-R>7!T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M:V5Y("`@(%1H92!K97D@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@9&5C<GEP=&5D(&]U='!U="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9&5C<GEP=$)L;V-K*"1B;&]C:RP@)&ME>2`](&YU;&PI"B`@("![
M"B`@("`@("`@:68@*"%I<U]N=6QL*"1K97DI*2!["B`@("`@("`@("`@("1T
M:&ES+3YS971+97DH)&ME>2D["B`@("`@("`@?0H*("`@("`@("`D8VEP:&5R
M(#T@=6YP86-K*"=V*B<L("1B;&]C:RD["@H@("`@("`@(&9O<B`H)&D@/2`Q
M-3L@)&D@/CT@,#L@)&DM+2D@>PH@("`@("`@("`@("`D8FEN(#T@<W1R7W!A
M9"AD96-B:6XH,'A&1D9&("8@)&-I<&AE<ELT72DL(#$V+"`G,"<L(%-44E]0
M041?3$5&5"D["B`@("`@("`@("`@("1C:7!H97);-%T@/2!B:6YD96,H<W5B
M<W1R*"1B:6XL("TR,2P@,C$I("X@<W5B<W1R*"1B:6XL(#`L(#$Q*2D["B`@
M("`@("`@("`@("1C:7!H97);-%T@+3T@*"1C:7!H97);,5T@)B!^)&-I<&AE
M<ELS72D@*R`H)&-I<&AE<ELR72`F("1C:7!H97);,UTI("L@)'1H:7,M/E]K
M97E38VAE9'5L95LT("H@)&D@*R`S73L*"B`@("`@("`@("`@("1B:6X@/2!S
M=')?<&%D*&1E8V)I;B@P>$9&1D8@)B`D8VEP:&5R6S-=*2P@,38L("<P)RP@
M4U127U!!1%],1494*3L*("`@("`@("`@("`@)&-I<&AE<ELS72`](&)I;F1E
M8RAS=6)S='(H)&)I;BP@+3$Y+"`Q.2D@+B!S=6)S='(H)&)I;BP@,"P@,3,I
M*3L*("`@("`@("`@("`@)&-I<&AE<ELS72`M/2`H)&-I<&AE<ELT72`F('XD
M8VEP:&5R6S)=*2`K("@D8VEP:&5R6S%=("8@)&-I<&AE<ELR72D@*R`D=&AI
M<RT^7VME>5-C:&5D=6QE6S0@*B`D:2`K(#)=.PH*("`@("`@("`@("`@)&)I
M;B`]('-T<E]P860H9&5C8FEN*#!X1D9&1B`F("1C:7!H97);,ETI+"`Q-BP@
M)S`G+"!35%)?4$%$7TQ%1E0I.PH@("`@("`@("`@("`D8VEP:&5R6S)=(#T@
M8FEN9&5C*'-U8G-T<B@D8FEN+"`M,3@L(#$X*2`N('-U8G-T<B@D8FEN+"`P
M+"`Q-"DI.PH@("`@("`@("`@("`D8VEP:&5R6S)=("T]("@D8VEP:&5R6S-=
M("8@?B1C:7!H97);,5TI("L@*"1C:7!H97);-%T@)B`D8VEP:&5R6S%=*2`K
M("1T:&ES+3Y?:V5Y4V-H961U;&5;-"`J("1I("L@,5T["@H@("`@("`@("`@
M("`D8FEN(#T@<W1R7W!A9"AD96-B:6XH,'A&1D9&("8@)&-I<&AE<ELQ72DL
M(#$V+"`G,"<L(%-44E]0041?3$5&5"D["B`@("`@("`@("`@("1C:7!H97);
M,5T@/2!B:6YD96,H<W5B<W1R*"1B:6XL("TQ-RP@,3<I("X@<W5B<W1R*"1B
M:6XL(#`L(#$U*2D["B`@("`@("`@("`@("1C:7!H97);,5T@+3T@*"1C:7!H
M97);,ET@)B!^)&-I<&AE<ELT72D@*R`H)&-I<&AE<ELS72`F("1C:7!H97);
M-%TI("L@)'1H:7,M/E]K97E38VAE9'5L95LT("H@)&D@*R`P73L*"B`@("`@
M("`@("`@(&EF("@D:2`]/2`U('Q\("1I(#T](#$Q*2!["B`@("`@("`@("`@
M("`@("`D8VEP:&5R6S1=("T]("1T:&ES+3Y?:V5Y4V-H961U;&5;)&-I<&AE
M<ELS72`F(#!X,T9=.PH@("`@("`@("`@("`@("`@)&-I<&AE<ELS72`M/2`D
M=&AI<RT^7VME>5-C:&5D=6QE6R1C:7!H97);,ET@)B`P>#-&73L*("`@("`@
M("`@("`@("`@("1C:7!H97);,ET@+3T@)'1H:7,M/E]K97E38VAE9'5L95LD
M8VEP:&5R6S%=("8@,'@S1ET["B`@("`@("`@("`@("`@("`D8VEP:&5R6S%=
M("T]("1T:&ES+3Y?:V5Y4V-H961U;&5;)&-I<&AE<ELT72`F(#!X,T9=.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@<&%C:R@B
M=BHB+"`D8VEP:&5R6S%=+"`D8VEP:&5R6S)=+"`D8VEP:&5R6S-=+"`D8VEP
M:&5R6S1=*3L*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]#:7!H97(O<F,T+G!H<```````````````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#0T-#``,3`U,34T,S,W-3``,#(R,#<W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B!4:&4@0VEP:&5R7W)C-#HZ(&-L87-S(&EM<&QE;65N=',@=&AE($-I<&AE
M<B!I;G1E<F9A8V4@96YC<GEP=&EO;B!D871A"B`J('5S:6YG('1H92!20S0@
M96YC<GEP=&EO;B!A;&=O<G1H:6TN(%1H:7,@8VQA<W,@=7-E<R!T:&4@4$5!
M4B!#<GEP=%]20S0*("H@8VQA<W,@=&\@9&\@=&AE(&5N8W)Y<'1I;VXN"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+T-I<&AE<B]#:7!H97(O<F,T+G!H<"QV
M(#$N-"XQ,BXW(#(P,#8O,#$O,#$@,C$Z,C@Z,3`@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`R+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F
M=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI
M:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC
M92`@($AO<F1E(#(N,@H@*B!`<&%C:V%G92!(;W)D95]#:7!H97(*("HO"F-L
M87-S($AO<F1E7T-I<&AE<E]R8S0@97AT96YD<R!(;W)D95]#:7!H97(@>PH*
M("`@("\J*@H@("`@("H@4&]I;G1E<B!T;R!A(%!%05(@0W)Y<'1?<F,T(&]B
M:F5C=`H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1?8VEP:&5R(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=&]R"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7T-I<&AE<E]R8S0H)'!A
M<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=#<GEP
M="]28S0N<&AP)SL*("`@("`@("`D=&AI<RT^7V-I<&AE<B`]("9N97<@0W)Y
M<'1?4F,T*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&ME>2!T
M;R!B92!U<V5D(&9O<B!E;B]D96-R>7!T:6]N+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&ME>2`@5&AE(&ME>2!T;R!U<V4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-E=$ME>2@D:V5Y*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M8VEP:&5R+3YK97DH)&ME>2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FX@=&AE('-I>F4@;V8@=&AE(&)L;V-K<R!T:&%T('1H:7,@8VEP:&5R(&YE
M961S+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&YU;6)E
M<B!O9B!C:&%R86-T97)S('!E<B!B;&]C:RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T0FQO8VM3:7IE*"D*("`@('L*("`@("`@("!R971U<FX@.#L*("`@
M('T*"B`@("`O*BH*("`@("`J($5N8W)Y<'0@82!B;&]C:R!O9B!D871A+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&)L;V-K("!4:&4@9&%T82!T
M;R!E;F-R>7!T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("`@(%1H92!K
M97D@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M96YC<GEP=&5D(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@96YC<GEP
M=$)L;V-K*"1B;&]C:RP@)&ME>2`](&YU;&PI"B`@("!["B`@("`@("`@:68@
M*"%I<U]N=6QL*"1K97DI*2!["B`@("`@("`@("`@("1T:&ES+3YS971+97DH
M)&ME>2D["B`@("`@("`@?0H*("`@("`@("`O+R!-86ME(&$@8V]P>2!O9B!T
M:&4@8VEP:&5R(&%S(&ET(&1E<W1R;WES(&ET<V5L9B!D=7)I;F<@82!C<GEP
M=`H@("`@("`@("1C:7!H97(@/2`D=&AI<RT^7V-I<&AE<CL*("`@("`@("`D
M8VEP:&5R+3YC<GEP="@D8FQO8VLI.PH*("`@("`@("!R971U<FX@)&)L;V-K
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5C<GEP="!A(&)L;V-K(&]F(&1A
M=&$N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8FQO8VL@(%1H92!D
M871A('1O(&1E8W)Y<'0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1K97D@("`@
M5&AE(&ME>2!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!D96-R>7!T960@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!D
M96-R>7!T0FQO8VLH)&)L;V-K+"`D:V5Y(#T@;G5L;"D*("`@('L*("`@("`@
M("!I9B`H(6ES7VYU;&PH)&ME>2DI('L*("`@("`@("`@("`@)'1H:7,M/G-E
M=$ME>2@D:V5Y*3L*("`@("`@("!]"@H@("`@("`@("\O($UA:V4@82!C;W!Y
M(&]F('1H92!C:7!H97(@87,@:70@9&5S=')O>7,@:71S96QF(&1U<FEN9R!A
M"B`@("`@("`@+R\@8W)Y<'0N"B`@("`@("`@)&-I<&AE<B`]("1T:&ES+3Y?
M8VEP:&5R.PH@("`@("`@("1C:7!H97(M/F1E8W)Y<'0H)&)L;V-K*3L*"B`@
M("`@("`@<F5T=7)N("1B;&]C:SL*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]#:7!H97(N<&AP````````````````````
M````````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8P-#0`,3`U,34T,S,W-3(`,#(Q
M-#$S`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?0VEP:&5R.CH@8VQA<W,@<')O=FED
M97,@82!C;VUM;VX@86)S=')A8W1E9"!I;G1E<F9A8V4@=&\*("H@=F%R:6]U
M<R!#:7!H97)S(&9O<B!E;F-R>7!T:6]N(&]F(&%R8FET<F%R>2!L96YG=&@@
M<&EE8V5S(&]F(&1A=&$N"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EK
M92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T-I<&AE<B]#:7!H97(N<&AP
M+'8@,2XQ-BXQ,BXX(#(P,#8O,#$O,#$@,C$Z,C@Z,3`@:F%N($5X<"`D"B`J
M"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN
M8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#(N,@H@*B!`<&%C:V%G92!(;W)D
M95]#:7!H97(*("HO"F-L87-S($AO<F1E7T-I<&AE<B!["@H@("`@+RHJ"B`@
M("`@*B!4:&4@8FQO8VL@;6]D92!F;W(@=&AE(&-I<&AE<B!C:&%I;FEN9PH@
M("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V)L
M;V-K36]D92`]("=#0D,G.PH*("`@("\J*@H@("`@("H@5&AE(&EN:71I86QI
M>F%T:6]N('9E8W1O<@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D7VEV(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%-E="!T
M:&4@8FQO8VL@;6]D92!F;W(@8VEP:&5R(&-H86EN:6YG+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&)L;V-K36]D92`@5&AE(&YE=R!B;&]C:VUO
M9&4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$)L;V-K36]D92@D8FQO8VM-
M;V1E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8FQO8VM-;V1E(#T@)&)L;V-K
M36]D93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@258N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:78@(%1H92!N97<@258N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=$E6*"1I=BD*("`@('L*("`@("`@("`D=&AI
M<RT^7VEV(#T@)&EV.PH@("`@?0H*("`@("\J*@H@("`@("H@16YC<GEP="!A
M('-T<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P;&%I;G1E
M>'0@(%1H92!D871A('1O(&5N8W)Y<'0N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!E;F-R>7!T960@9&%T82X*("`@("`J+PH@("`@9G5N
M8W1I;VX@96YC<GEP="@D<&QA:6YT97AT*0H@("`@>PH@("`@("`@(')E<75I
M<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O0VEP:&5R+T)L;V-K36]D
M92YP:'`G.PH@("`@("`@("1B;&]C:TUO9&4@/2`F2&]R9&5?0VEP:&5R7T)L
M;V-K36]D93HZ9F%C=&]R>2@D=&AI<RT^7V)L;V-K36]D92D["B`@("`@("`@
M:68@*"%I<U]N=6QL*"1T:&ES+3Y?:78I*2!["B`@("`@("`@("`@("1B;&]C
M:TUO9&4M/G-E=$E6*"1T:&ES+3Y?:78I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1B;&]C:TUO9&4M/F5N8W)Y<'0H)'1H:7,L("1P;&%I;G1E>'0I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5C<GEP="!A('-T<FEN9RX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:7!H97)T97AT("!4:&4@9&%T
M82!T;R!D96-R>7!T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@9&5C<GEP=&5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E8W)Y
M<'0H)&-I<&AE<G1E>'0I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E(&1I
M<FYA;64H7U]&24Q%7U\I("X@)R]#:7!H97(O0FQO8VM-;V1E+G!H<"<["B`@
M("`@("`@)&)L;V-K36]D92`]("9(;W)D95]#:7!H97)?0FQO8VM-;V1E.CIF
M86-T;W)Y*"1T:&ES+3Y?8FQO8VM-;V1E*3L*("`@("`@("!I9B`H(6ES7VYU
M;&PH)'1H:7,M/E]I=BDI('L*("`@("`@("`@("`@)&)L;V-K36]D92T^<V5T
M258H)'1H:7,M/E]I=BD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&)L
M;V-K36]D92T^9&5C<GEP="@D=&AI<RP@)&-I<&AE<G1E>'0I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@
M2&]R9&5?0VEP:&5R(&EN<W1A;F-E+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&-I<&AE<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?0VEP
M:&5R('-U8F-L87-S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;BX*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@02!H87-H
M(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@<&%R86UE=&5R<R!A"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@('-U8F-L87-S(&UI9VAT(&YE960N
M"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]#:7!H97(@(%1H92!N97=L
M>2!C<F5A=&5D(&-O;F-R971E($AO<F1E7T-I<&AE<B!I;G-T86YC92P*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!O<B!014%27T5R<F]R(&]N(&5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D8VEP:&5R+"`D
M<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("`D9')I=F5R(#T@8F%S96YA
M;64H)&-I<&AE<BD["@H@("`@("`@(&EF("A`9FEL95]E>&ES=',H9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+T-I<&AE<B\G("X@)&-I<&AE<B`N("<N<&AP)RDI
M('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I
M("X@)R]#:7!H97(O)R`N("1C:7!H97(@+B`G+G!H<"<["B`@("`@("`@?0H*
M("`@("`@("`D8VQA<W,@/2`G2&]R9&5?0VEP:&5R7R<@+B`D8VEP:&5R.PH@
M("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@
M("`D8VEP:&5R(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&-I<&AE<B`](%!%05(Z.G)A:7-E17)R;W(H
M)T-L87-S(&1E9FEN:71I;VX@;V8@)R`N("1C;&%S<R`N("<@;F]T(&9O=6YD
M+B<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C:7!H97(["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O0TQ)+G!H<```````````````````````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(S-#(T`#$P-3$U-#,S-S4Q`#`R
M,#8Q,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@2&]R9&5?0TQ).CH@05!)(&9O<B!B87-I8R!C;VUM
M86YD+6QI;F4@9G5N8W1I;VYA;&ET>2]C:&5C:W,N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+T-,22]#3$DN<&AP+'8@,2XT,BXV+C$S(#(P,#8O,#4O,S$@
M,3(Z,S$Z,#`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H
M="`R,#`S+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`
M:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@
M2&]R9&5?0TQ)"B`J+PIC;&%S<R!(;W)D95]#3$D@>PH*("`@("\J*@H@("`@
M("H@07)E('=E(')U;FYI;F<@;VX@82!C;VYS;VQE/PH@("`@("H*("`@("`J
M($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]C;VYS;VQE.PH*("`@
M("\J*@H@("`@("H@5&AE(&YE=VQI;F4@<W1R:6YG('1O('5S92X*("`@("`J
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]N97=L:6YE
M.PH*("`@("\J*@H@("`@("H@5&AE(&EN9&5N="!S=')I;F<@=&\@=7-E+@H@
M("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VEN
M9&5N=#L*"B`@("`O*BH*("`@("`J(%1H92!S=')I;F<@=&\@;6%R:R!T:&4@
M8F5G:6YN:6YG(&]F(&)O;&0@=&5X="X*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]B;VQD7W-T87)T(#T@)R<["@H@("`@
M+RHJ"B`@("`@*B!4:&4@<W1R:6YG('1O(&UA<FL@=&AE(&5N9"!O9B!B;VQD
M('1E>'0N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?8F]L9%]E;F0@/2`G)SL*"B`@("`O*BH*("`@("`J(%1H92!S=')I
M;F=S('1O(&UA<FL@=&AE(&)E9VEN;FEN9R!O9B!C;VQO=7)E9"!T97AT+@H@
M("`@("HO"B`@("!V87(@)%]R961?<W1A<G0@("`@/2`G)SL*("`@('9A<B`D
M7V=R965N7W-T87)T("`]("<G.PH@("`@=F%R("1?>65L;&]W7W-T87)T(#T@
M)R<["B`@("!V87(@)%]B;'5E7W-T87)T("`@/2`G)SL*"B`@("`O*BH*("`@
M("`J(%1H92!S=')I;F=S('1O(&UA<FL@=&AE(&5N9"!O9B!C;VQO=7)E9"!T
M97AT+@H@("`@("HO"B`@("!V87(@)%]R961?96YD("`@("`@/2`G)SL*("`@
M('9A<B`D7V=R965N7V5N9"`@("`]("<G.PH@("`@=F%R("1?>65L;&]W7V5N
M9"`@(#T@)R<["B`@("!V87(@)%]B;'5E7V5N9"`@("`@/2`G)SL*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@82!S:6YG;&4@:6YS=&%N8V4@;V8@=&AE($AO
M<F1E7T-,22!C;&%S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O
M;B@I"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC93L*("`@("`@("!I
M9B`H(6ES<V5T*"1I;G-T86YC92DI('L*("`@("`@("`@("`@)&EN<W1A;F-E
M(#T@;F5W($AO<F1E7T-,22@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)&EN<W1A;F-E.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5T96-T('1H92!C
M=7)R96YT(&5N=FER;VYM96YT("AW96(@<V5R=F5R(&]R(&-O;G-O;&4I(&%N
M9"!S971S"B`@("`@*B!I;G1E<FYA;"!V86QU97,@86-C;W)D:6YG;'DN"B`@
M("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7T-,22@I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]C;VYS;VQE(#T@)'1H:7,M/G)U;FYI;F=&<F]M0TQ)*"D["@H@
M("`@("`@(&EF("@D=&AI<RT^7V-O;G-O;&4I('L*("`@("`@("`@("`@)'1H
M:7,M/E]N97=L:6YE(#T@(EQN(CL*("`@("`@("`@("`@)'1H:7,M/E]I;F1E
M;G0@(#T@)R`@("`G.PH*("`@("`@("`@("`@)'1E<FT@/2!G971E;G8H)U1%
M4DTG*3L*("`@("`@("`@("`@:68@*"1T97)M*2!["B`@("`@("`@("`@("`@
M("!I9B`H<')E9U]M871C:"@G+UXH>'1E<FU\=G0R,C!\;&EN=7@I+R<L("1T
M97)M*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8F]L9%]S=&%R
M="`@(#T@(EQX,6);,6TB.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<F5D7W-T87)T("`@(#T@(EQX,6);,#$[,S%M(CL*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V=R965N7W-T87)T("`](")<>#%B6S`Q.S,R;2(["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]Y96QL;W=?<W1A<G0@/2`B7'@Q
M8ELP,3LS,VTB.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8FQU95]S
M=&%R="`@(#T@(EQX,6);,#$[,S1M(CL*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V)O;&1?96YD(#T@)'1H:7,M/E]R961?96YD(#T@)'1H:7,M/E]G
M<F5E;E]E;F0@/2`D=&AI<RT^7WEE;&QO=U]E;F0@/2`D=&AI<RT^7V)L=65?
M96YD(#T@(EQX,6);,&TB.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*'!R
M96=?;6%T8V@H)R]>=G0Q,#`O)RP@)'1E<FTI*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]B;VQD7W-T87)T(#T@(EQX,6);,6TB.PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8F]L9%]E;F0@("`](")<>#%B6S!M(CL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1T:&ES+3Y?;F5W;&EN92`]("<\8G(@+SXG.PH@
M("`@("`@("`@("`D=&AI<RT^7VEN9&5N="`@/2!S=')?<F5P96%T*"<F;F)S
M<#LG+"`T*3L*"B`@("`@("`@("`@("1T:&ES+3Y?8F]L9%]S=&%R="`@(#T@
M)SQS=')O;F<^)SL*("`@("`@("`@("`@)'1H:7,M/E]B;VQD7V5N9"`@("`@
M/2`G/"]S=')O;F<^)SL*("`@("`@("`@("`@)'1H:7,M/E]R961?<W1A<G0@
M("`@/2`G/'-P86X@<W1Y;&4](F-O;&]R.G)E9"(^)SL*("`@("`@("`@("`@
M)'1H:7,M/E]G<F5E;E]S=&%R="`@/2`G/'-P86X@<W1Y;&4](F-O;&]R.F=R
M965N(CXG.PH@("`@("`@("`@("`D=&AI<RT^7WEE;&QO=U]S=&%R="`]("<\
M<W!A;B!S='EL93TB8V]L;W(Z>65L;&]W(CXG.PH@("`@("`@("`@("`D=&AI
M<RT^7V)L=65?<W1A<G0@("`]("<\<W!A;B!S='EL93TB8V]L;W(Z8FQU92(^
M)SL*("`@("`@("`@("`@)'1H:7,M/E]R961?96YD(#T@)'1H:7,M/E]G<F5E
M;E]E;F0@/2`D=&AI<RT^7WEE;&QO=U]E;F0@/2`D=&AI<RT^7V)L=65?96YD
M(#T@)SPO<W!A;CXG.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%!R:6YT<R`D=&5X="!O;B!A('-I;F=L92!L:6YE+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@("1T97AT("!4:&4@=&5X="!T;R!P<FEN="X*("`@
M("`J($!P87)A;2!B;V]L96%N("1P<F4@("!)9B!T<G5E('1H92!L:6YE8G)E
M86L@:7,@<')I;G1E9"!B969O<F4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!T:&4@=&5X="!I;G-T96%D(&]F(&%F=&5R(&ET+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!W<FET96QN*"1T97AT(#T@)R<L("1P<F4@/2!F86QS92D*
M("`@('L*("`@("`@("!I9B`H)'!R92D@>PH@("`@("`@("`@("!E8VAO("1T
M:&ES+3Y?;F5W;&EN92`N("1T97AT.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(&5C:&\@)'1E>'0@+B`D=&AI<RT^7VYE=VQI;F4["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@:6YD96YT960@
M<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H
M92!T97AT('1O(&EN9&5N="X*("`@("`J+PH@("`@9G5N8W1I;VX@:6YD96YT
M*"1T97AT*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VEN9&5N="`N
M("1T97AT.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&)O;&0@
M=F5R<VEO;B!O9B`D=&5X="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T97AT("!4:&4@=&5X="!T;R!B;VQD+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!B;VQD*"1T97AT*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V)O
M;&1?<W1A<G0@+B`D=&5X="`N("1T:&ES+3Y?8F]L9%]E;F0["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<F5D('9E<G-I;VX@;V8@)'1E>'0N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@
M=&\@<')I;G0@:6X@<F5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!R960H)'1E
M>'0I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F5D7W-T87)T("X@
M)'1E>'0@+B`D=&AI<RT^7W)E9%]E;F0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&$@9W)E96X@=F5R<VEO;B!O9B`D=&5X="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!T;R!P<FEN="!I
M;B!G<F5E;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9W)E96XH)'1E>'0I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9W)E96Y?<W1A<G0@+B`D=&5X
M="`N("1T:&ES+3Y?9W)E96Y?96YD.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!A(&)L=64@=F5R<VEO;B!O9B`D=&5X="X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!T;R!P<FEN="!I;B!B
M;'5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!B;'5E*"1T97AT*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7V)L=65?<W1A<G0@+B`D=&5X="`N("1T
M:&ES+3Y?8FQU95]E;F0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&$@>65L;&]W('9E<G-I;VX@;V8@)'1E>'0N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@=&\@<')I;G0@:6X@>65L;&]W
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!Y96QL;W<H)'1E>'0I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?>65L;&]W7W-T87)T("X@)'1E>'0@+B`D
M=&AI<RT^7WEE;&QO=U]E;F0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$:7-P
M;&%Y<R!A(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M979E;G0@(%1H92!M97-S86=E('-T<FEN9RX*("`@("`J($!P87)A;2!S=')I
M;F<@)'1Y<&4@("!4:&4@='EP92!O9B!M97-S86=E.B`G8VQI+F5R<F]R)RP@
M)V-L:2YW87)N:6YG)RP*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`G
M8VQI+G-U8V-E<W,G+"!O<B`G8VQI+FUE<W-A9V4G+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!M97-S86=E*"1M97-S86=E+"`D='EP92`]("=C;&DN;65S<V%G
M92<I"B`@("!["B`@("`@("`@)&UE<W-A9V4@/2!W;W)D=W)A<"@D;65S<V%G
M92P@-C@L(")<;B`@("`@("`@("`@(BP@=')U92D["@H@("`@("`@('-W:71C
M:"`H)'1Y<&4I('L*("`@("`@("!C87-E("=C;&DN97)R;W(G.@H@("`@("`@
M("`@("`D='EP95]M97-S86=E(#T@)'1H:7,M/G)E9"@G6R!%4E)/4B$@72`G
M*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)V-L:2YW87)N
M:6YG)SH*("`@("`@("`@("`@)'1Y<&5?;65S<V%G92`]("1T:&ES+3YY96QL
M;W<H)UL@(%=!4DX@(%T@)RD["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E("=C;&DN<W5C8V5S<R<Z"B`@("`@("`@("`@("1T>7!E7VUE<W-A
M9V4@/2`D=&AI<RT^9W)E96XH)UL@("!/2R`@(%T@)RD["B`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("!C87-E("=C;&DN;65S<V%G92<Z"B`@("`@("`@
M("`@("1T>7!E7VUE<W-A9V4@/2`D=&AI<RT^8FQU92@G6R`@24Y&3R`@72`G
M*3L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^=W)I=&5L;B@D='EP95]M97-S86=E("X@)&UE<W-A9V4I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1&ES<&QA>7,@82!F871A;"!E<G)O<B!M97-S86=E
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&5R<F]R("!4:&4@97)R
M;W(@=&5X="!T;R!D:7-P;&%Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!F871A
M;"@D97)R;W(I"B`@("!["B`@("`@("`@)'1H:7,M/G=R:71E;&XH)'1H:7,M
M/G)E9"@G/3T]/3T]/3T]/3T]/3T]/3T]/3TG*2D["B`@("`@("`@)'1H:7,M
M/G=R:71E;&XH*3L*("`@("`@("`D=&AI<RT^=W)I=&5L;B@D=&AI<RT^<F5D
M*%\H(D9A=&%L($5R<F]R.B(I*2D["B`@("`@("`@)'1H:7,M/G=R:71E;&XH
M)'1H:7,M/G)E9"@D97)R;W(I*3L*("`@("`@("`D=&AI<RT^=W)I=&5L;B@I
M.PH@("`@("`@("1T:&ES+3YW<FET96QN*"1T:&ES+3YR960H)ST]/3T]/3T]
M/3T]/3T]/3T]/3T])RDI.PH@("`@("`@(&5X:70["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!0<F]M<'1S(&9O<B!A('5S97(@<F5S<&]N<V4N"B`@("`@*@H@
M("`@("H@0'1O9&\@2&]R9&4@-#H@<W=I=&-H("1C:&]I8V5S(&%N9"`D9&5F
M875L=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!R;VUP="`@5&AE
M(&UE<W-A9V4@=&\@9&ES<&QA>2!W:&5N('!R;VUP=&EN9R!T:&4@=7-E<BX*
M("`@("`J($!P87)A;2!A<G)A>2`D8VAO:6-E<R`@5&AE(&-H;VEC97,@879A
M:6QA8FQE('1O('1H92!U<V5R(&]R(&YU;&P@9F]R(&$*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@=&5X="!I;G!U="X*("`@("`J($!P87)A;2!S
M=')I;F<@)&1E9F%U;'0@5&AE(&1E9F%U;'0@=F%L=64@:68@;F\@=F%L=64@
M<W!E8VEF:65D+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!U
M<V5R)W,@<F5S<&]N<V4@=&\@=&AE('!R;VUP="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<')O;7!T*"1P<F]M<'0L("1C:&]I8V5S(#T@;G5L;"P@)&1E9F%U
M;'0@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@D9&5F875L="`A/3T@;G5L
M;"D@>PH@("`@("`@("`@("`D<')O;7!T("X]("<@6R<@+B`D9&5F875L="`N
M("==)SL*("`@("`@("!]"@H@("`@("`@("\O($UA:6X@979E;G0@;&]O<"!T
M;R!C87!T=7)E('1O<"!L979E;"!C;VUM86YD+@H@("`@("`@('=H:6QE("AT
M<G5E*2!["B`@("`@("`@("`@("\O(%!R:6YT(&]U="!T:&4@<')O;7!T(&UE
M<W-A9V4N"B`@("`@("`@("`@("1T:&ES+3YW<FET96QN*"1P<F]M<'0@+B`G
M("<L("%I<U]A<G)A>2@D8VAO:6-E<RDI.PH@("`@("`@("`@("!I9B`H:7-?
M87)R87DH)&-H;VEC97,I("8F("%E;7!T>2@D8VAO:6-E<RDI('L*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1C:&]I8V5S(&%S("1K97D@/3X@)&-H;VEC
M92D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<FET96QN*"1T:&ES
M+3YI;F1E;G0H)R@G("X@)'1H:7,M/F)O;&0H)&ME>2D@+B`G*2`G("X@)&-H
M;VEC92DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1H
M:7,M/G=R:71E;&XH7R@B5'EP92!Y;W5R(&-H;VEC93H@(BDL('1R=64I.PH@
M("`@("`@("`@("`@("`@0&]B7V9L=7-H*"D["@H@("`@("`@("`@("`@("`@
M+R\@1V5T('1H92!U<V5R(&-H;VEC92X*("`@("`@("`@("`@("`@("1R97-P
M;VYS92`]('1R:6TH9F=E=',H4U1$24XI*3L*("`@("`@("`@("`@("`@(&EF
M("@D<F5S<&]N<V4@/3T]("<G("8F("1D969A=6QT("$]/2!N=6QL*2!["B`@
M("`@("`@("`@("`@("`@("`@)')E<W!O;G-E(#T@)&1E9F%U;'0["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&-H;VEC
M97-;)')E<W!O;G-E72DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)')E<W!O;G-E.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^=W)I=&5L;BAS<')I;G1F*%\H(EPB)7-<(B!I
M<R!N;W0@82!V86QI9"!C:&]I8V4N(BDL("1R97-P;VYS92DI.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)')E<W!O;G-E(#T@=')I;2AF9V5T<RA35$1)3BDI.PH@("`@("`@("`@
M("`@("`@:68@*"1R97-P;VYS92`]/3T@)R<@)B8@)&1E9F%U;'0@(3T](&YU
M;&PI('L*("`@("`@("`@("`@("`@("`@("`D<F5S<&]N<V4@/2`D9&5F875L
M=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(')E='5R;B`D
M<F5S<&]N<V4["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5A9',@979E<GET
M:&EN9R!T:&%T(&ES('-E;G0@=&AR;W5G:"!S=&%N9&%R9"!I;G!U="!A;F0@
M<F5T=7)N<R!I=`H@("`@("H@87,@82!S:6YG;&4@<W1R:6YG+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]N=&5N=',@;V8@=&AE('-T
M86YD87)D(&EN<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D4W1D:6XH
M*0H@("`@>PH@("`@("`@("1I;B`]("<G.PH@("`@("`@('=H:6QE("@A9F5O
M9BA35$1)3BDI('L*("`@("`@("`@("`@)&EN("X](&9G971S*%-41$E.+"`Q
M,#(T*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1I;CL*("`@('T*"B`@
M("`O*BH*("`@("`J($-,22!S8W)I<'1S('-H;W5L9&XG="!T:6UE;W5T+"!S
M;R!T<GD@=&\@<V5T('1H92!T:6UE(&QI;6ET('1O"B`@("`@*B!N;VYE+B!!
M;'-O(&EN:71I86QI>F4@82!F97<@=F%R:6%B;&5S(&EN("1?4T525D52('1H
M870@87)E;B=T('!R97-E;G0*("`@("`J(&9R;VT@=&AE($-,22X*("`@("`J
M"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN:70H*0H@
M("`@>PH@("`@("`@("\J(%)U;B!C;VYS=')U8W1O<B!N;W<@8F5C875S92!I
M="!R97%U:7)E<R`D7U-%4E9%4ELG4T525D527TY!344G72!T;PH@("`@("`@
M("`J(&)E(&5M<'1Y(&EF(&-A;&QE9"!W:71H(&$@0T=)(%-!4$DN("HO"B`@
M("`@("`@)&-L:2`]("9(;W)D95]#3$DZ.G-I;F=L971O;B@I.PH*("`@("`@
M("!`<V5T7W1I;65?;&EM:70H,"D["B`@("`@("`@;V)?:6UP;&EC:71?9FQU
M<V@H=')U92D["B`@("`@("`@:6YI7W-E="@G:'1M;%]E<G)O<G,G+"!F86QS
M92D["B`@("`@("`@)%]315)615);)TA45%!?2$]35"==(#T@)S$R-RXP+C`N
M,2<["B`@("`@("`@)%]315)615);)U-%4E9%4E].04U%)UT@/2`G,3(W+C`N
M,"XQ)SL*("`@("`@("`D7U-%4E9%4ELG4T525D527U!/4E0G72`]("<G.PH@
M("`@("`@("1?4T525D526R=214U/5$5?041$4B==(#T@)R<["B`@("`@("`@
M)%]315)615);)U!(4%]314Q&)UT@/2!I<W-E="@D87)G=BD@/R`D87)G=ELP
M72`Z("<G.PH@("`@("`@(&EF("@A9&5F:6YE9"@G4U1$24XG*2D@>PH@("`@
M("`@("`@("!D969I;F4H)U-41$E.)RP@9F]P96XH)W!H<#HO+W-T9&EN)RP@
M)W(G*2D["B`@("`@("`@?0H@("`@("`@(&EF("@A9&5F:6YE9"@G4U1$3U54
M)RDI('L*("`@("`@("`@("`@9&5F:6YE*"=35$1/550G+"!F;W!E;B@G<&AP
M.B\O<W1D;W5T)RP@)W(G*2D["B`@("`@("`@?0H@("`@("`@(&EF("@A9&5F
M:6YE9"@G4U1$15)2)RDI('L*("`@("`@("`@("`@9&5F:6YE*"=35$1%4E(G
M+"!F;W!E;B@G<&AP.B\O<W1D97)R)RP@)W(G*2D["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@36%K92!S=7)E('=E)W)E(&)E:6YG(&-A;&QE
M9"!F<F]M('1H92!C;VUM86YD(&QI;F4L(&%N9"!N;W0@=FEA"B`@("`@*B!T
M:&4@=V5B+@H@("`@("H*("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=V4@87)E+"!F86QS92!O=&AE<G=I
M<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')U;FYI;F=&<F]M0TQ)*"D*("`@
M('L*("`@("`@("`D<V%P:2`]('!H<%]S87!I7VYA;64H*3L*("`@("`@("!I
M9B`H)'-A<&D@/3T@)V-L:2<I('L*("`@("`@("`@("`@<F5T=7)N('1R=64[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1S87!I(#T]
M("=C9VDG("8F(&5M<'1Y*"1?4T525D526R=315)615)?3D%-12==*3L*("`@
M("`@("!]"B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O0V]M<')E<W,O````````````````````````
M`````````````````````````````````````````````````#`P,#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S4P`#`R,3(U
M-0`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]#;VUP<F5S<R]D
M8G@N<&AP````````````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C$P-S0`
M,3`U,34T,S,W-3``,#(R-30W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?0V]M<')E
M<W-?9&)X(&-L87-S(&%L;&]W<R!D8G@@9FEL97,@*&4N9RX@9G)O;2!/=71L
M;V]K($5X<')E<W,I"B`J('1O(&)E(')E860N"B`J"B`J(%1H:7,@8VQA<W,@
M:7,@8F%S960@;VX@8V]D92!B>3H*("H@06YT;VYY(%)A:6IE:V]V(#QD979`
M<W1R871E9VUA+F)G/@H@*B!H='1P.B\O=7)U9',N9V%T97=A>2YB9R]Z96]S
M+PH@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D
M8G@N<&AP+'8@,2XS+C$R+CD@,C`P-B\P,2\P,2`R,3HR.#HQ,2!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*86X@4V-H;F5I9&5R(#QJ
M86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N
M(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@
M,RXP"B`J($!P86-K86=E($AO<F1E7T-O;7!R97-S"B`J+PIC;&%S<R!(;W)D
M95]#;VUP<F5S<U]D8G@@97AT96YD<R!(;W)D95]#;VUP<F5S<R!["@H@("`@
M+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)%]M86EL<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@
M*B!43T1/"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)%]T;7`@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@1&5C;VUP<F5S
M<V5S(&$@1$)8(&9I;&4@86YD(&=E=',@:6YF;W)M871I;VX@9G)O;2!I="X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("!4:&4@9&)X(&9I
M;&4@9&%T82X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@<F5Q=65S=&5D(&1A=&$N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E8V]M<')E<W,H)B1D871A+"`D<&%R
M86US(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7VUA:6QS(#T@87)R
M87DH*3L*("`@("`@("`D=&AI<RT^7W1M<"`](&%R<F%Y*"D["B`@("`@("`@
M)'!O<VET:6]N(#T@,'A#-#L*("`@("`@("`D:&5A9&5R7VEN9F\@/2!U;G!A
M8VLH)TQP;W-I=&EO;B],1&%T84QE;F=T:"]N2&5A9&5R3&5N9W1H+VY&;&%G
M0V]U;G0G+"!S=6)S='(H)&1A=&$L("1P;W-I=&EO;BP@,3(I*3L*("`@("`@
M("`D<&]S:71I;VX@*ST@,3(["B`@("`@("`@+R\@1V\@=&\@=&AE(&9I<G-T
M('1A8FQE(&]F9F5S="!A;F0@<')O8V5S<R!I="X*("`@("`@("!I9B`H)&AE
M861E<E]I;F9O6R=P;W-I=&EO;B==(#X@,"D@>PH@("`@("`@("`@("`D<&]S
M:71I;VX@/2`P>#,P.PH@("`@("`@("`@("`D8G5F(#T@=6YP86-K*"=,<&]S
M:71I;VXG+"!S=6)S='(H)&1A=&$L("1P;W-I=&EO;BP@-"DI.PH@("`@("`@
M("`@("`D<&]S:71I;VX@/2`D8G5F6R=P;W-I=&EO;B==.PH@("`@("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/E]R96%D26YD97@H)&1A=&$L("1P;W-I=&EO
M;BD["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^7VUA:6QS
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&YU;&PM=&5R;6EN
M871E9"!S=')I;F<@9G)O;2!T:&4@<W!E8VEF:65D(&1A=&$N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`F)&)U9B`@5$]$3PH@("`@("H@0'!A<F%M(&EN=&5G97(@)'!O<R`@
M5$]$3PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!43T1/"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]R96%D4W1R:6YG*"8D8G5F+"`D<&]S*0H@("`@
M>PH@("`@("`@(&EF("@D;&5N(#T@<W1R<&]S*'-U8G-T<B@D8G5F+"`D<&]S
M*2P@8VAR*#`I*2D@>PH@("`@("`@("`@("!R971U<FX@<W5B<W1R*"1B=68L
M("1P;W,L("1L96XI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)R<["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`F)&1A=&$@
M("`@("!43T1/"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<&]S:71I;VX@(%1/
M1$\*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5$]$3PH@("`@("HO
M"B`@("!F=6YC=&EO;B!?<F5A9$UE<W-A9V4H)B1D871A+"`D<&]S:71I;VXI
M"B`@("!["B`@("`@("`@)&US9R`]("<G.PH@("`@("`@("1P87)T(#T@,#L*
M"B`@("`@("`@:68@*"1P;W-I=&EO;B`^(#`I('L*("`@("`@("`@("`@)$EN
M9&5X271E;7-#;W5N="`](&%R<F%Y7W!O<"AU;G!A8VLH)U,G+"!S=6)S='(H
M)&1A=&$L(#!X0S0L(#0I*2D["B`@("`@("`@("`@(&EF("@D26YD97A)=&5M
M<T-O=6YT(#X@,"D@>PH@("`@("`@("`@("`@("`@=VAI;&4@*"1P;W-I=&EO
M;B`\('-T<FQE;B@D9&%T82DI('L*("`@("`@("`@("`@("`@("`@("`D<&%R
M="LK.PH@("`@("`@("`@("`@("`@("`@("1S(#T@<W5B<W1R*"1D871A+"`D
M<&]S:71I;VXL(#4R."D["B`@("`@("`@("`@("`@("`@("`@:68@*'-T<FQE
M;B@D<RD@/3T@,"D@>PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&US
M9U]I=&5M(#T@=6YP86-K*"=,1FEL95!O<R],56YK;F]W;B],271E;5-I>F4O
M3$YE>'1)=&5M+V$U,3)#;VYT96YT)RP@)',I.PH@("`@("`@("`@("`@("`@
M("`@(&EF("@D;7-G7VET96U;)T9I;&50;W,G72`A/2`D<&]S:71I;VXI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B26YV86QI9"!F:6QE(&9O<FUA="(I*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'!O<VET:6]N("L](#4R.#L*
M("`@("`@("`@("`@("`@("`@("`D;7-G("X]('-U8G-T<B@D;7-G7VET96U;
M)T-O;G1E;G0G72P@,"P@)&US9U]I=&5M6R=)=&5M4VEZ92==*3L*("`@("`@
M("`@("`@("`@("`@("`D<&]S:71I;VX@/2`D;7-G7VET96U;)TYE>'1)=&5M
M)UT["B`@("`@("`@("`@("`@("`@("`@:68@*"1P;W-I=&EO;B`]/2`P*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1M<V<["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!43T1/"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`F)&1A=&$@("`@("!43T1/"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D<&]S:71I;VX@(%1/1$\*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!43T1/"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R
M96%D365S<V%G94EN9F\H)B1D871A+"`D<&]S:71I;VXI"B`@("!["B`@("`@
M("`@)&UE<W-A9V5?:6YF;R`](&%R<F%Y*"D["B`@("`@("`@)&US9U]H96%D
M97(@/2!U;G!A8VLH)TQP;W-I=&EO;B],1&%T84QE;F=T:"]32&5A9&5R3&5N
M9W1H+U-&;&%G0V]U;G0G+"!S=6)S='(H)&1A=&$L("1P;W-I=&EO;BP@,3(I
M*3L*("`@("`@("!I9B`H)&US9U]H96%D97);)W!O<VET:6]N)UT@(3T@)'!O
M<VET:6]N*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(DEN=F%L:60@9FEL92!F;W)M870B*2D["B`@("`@("`@?0H@("`@("`@
M("1P;W-I=&EO;B`K/2`Q,CL*("`@("`@("`D;65S<V%G95]I;F9O6R=(96%D
M97)0;W-I=&EO;B==(#T@)&US9U]H96%D97);)W!O<VET:6]N)UT["B`@("`@
M("`@)&9L86=S(#T@)&US9U]H96%D97);)T9L86=#;W5N="==("8@,'A&1CL*
M("`@("`@("`D1&%T85-I>F4@/2`D;7-G7VAE861E<ELG1&%T84QE;F=T:"==
M("T@)&9L86=S("H@-#L*("`@("`@("`D<VEZ92`](#0@*B`D9FQA9W,["B`@
M("`@("`@)$9L86=S0G5F9F5R(#T@<W5B<W1R*"1D871A+"`D<&]S:71I;VXL
M("1S:7IE*3L*("`@("`@("`D<&]S:71I;VX@*ST@)'-I>F4["B`@("`@("`@
M)'-I>F4@/2`D1&%T85-I>F4["B`@("`@("`@)$1A=&%"=69F97(@/2!S=6)S
M='(H)&1A=&$L("1P;W-I=&EO;BP@)'-I>F4I.PH@("`@("`@("1P;W-I=&EO
M;B`K/2`D<VEZ93L*("`@("`@("`D;65S<V%G95]I;F9O(#T@87)R87DH*3L*
M"B`@("`@("`@)&9L86=?87)R87D@/2!A<G)A>2@*("`@("`@("`@("`@,'@Q
M(#T^("=-<V=&;&%G<R<L"B`@("`@("`@("`@(#!X,B`]/B`G4V5N="<L"B`@
M("`@("`@("`@(#!X-"`]/B`G<&]S:71I;VXG+`H@("`@("`@("`@("`P>#<@
M/3X@)TUE<W-A9V5)1"<L"B`@("`@("`@("`@(#!X."`]/B`G4W5B:F5C="<L
M"B`@("`@("`@("`@(#!X.2`]/B`G1G)O;5]R97!L>2<L"B`@("`@("`@("`@
M(#!X02`]/B`G4F5F97)E;F-E<R<L"B`@("`@("`@("`@(#!X0B`]/B`G3F5W
M<V=R;W5P)RP*("`@("`@("`@("`@,'A$(#T^("=&<F]M)RP*("`@("`@("`@
M("`@,'A%(#T^("=297!L>5]4;R<L"B`@("`@("`@("`@(#!X,3(@/3X@)U)E
M8V5I=F5D)RP*("`@("`@("`@("`@,'@Q,R`]/B`G4F5C96EP="<L"B`@("`@
M("`@("`@(#!X,4$@/3X@)T%C8V]U;G0G+`H@("`@("`@("`@("`P>#%"(#T^
M("=!8V-O=6YT240G+`H@("`@("`@("`@("`P>#@P(#T^("=-<V<G+`H@("`@
M("`@("`@("`P>#@Q(#T^("=-<V=&;&%G<R<L"B`@("`@("`@("`@(#!X.#0@
M/3X@)W!O<VET:6]N)RP*("`@("`@("`@("`@,'@Y,2`]/B`G<VEZ92<L"B`@
M("`@("`@*3L*"B`@("`@("`@+RH@4')O8V5S<R!F;&%G<R`J+PH@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\("1F;&%G<SL@)&DK*RD@>PH@("`@("`@("`@
M("`D<&]S(#T@,#L*("`@("`@("`@("`@)&8@/2!A<G)A>5]P;W`H=6YP86-K
M*"=,)RP@<W5B<W1R*"1&;&%G<T)U9F9E<BP@)&D@*B`T+"`T*2DI.PH*("`@
M("`@("`@("`@)&UA<VL@/2`D9B`F(#!X1D8["B`@("`@("`@("`@('-W:71C
M:"`H)&UA<VLI('L*("`@("`@("`@("`@8V%S92`P>#$Z"B`@("`@("`@("`@
M("`@("`D<&]S(#T@)'!O<R`K("@D9B`^/B`X*3L*("`@("`@("`@("`@("`@
M("1M97-S86=E7VEN9F];)TUS9T9L86=S)UT@/2!A<G)A>5]P;W`H=6YP86-K
M*"=#)RP@<W5B<W1R*"1$871A0G5F9F5R+"`D<&]S*RLL(#$I*2D["B`@("`@
M("`@("`@("`@("`D;65S<V%G95]I;F9O6R=-<V=&;&%G<R==("L](&%R<F%Y
M7W!O<"AU;G!A8VLH)T,G+"!S=6)S='(H)$1A=&%"=69F97(L("1P;W,K*RP@
M,2DI*2`J(#(U-CL*("`@("`@("`@("`@("`@("1M97-S86=E7VEN9F];)TUS
M9T9L86=S)UT@*ST@87)R87E?<&]P*'5N<&%C:R@G0R<L('-U8G-T<B@D1&%T
M84)U9F9E<BP@)'!O<RP@,2DI*2`J(#8U-3,V.PH@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("!C87-E(#!X,CH*("`@("`@("`@("`@8V%S
M92`P>#0Z"B`@("`@("`@("`@("`@("`D<&]S("L](&%R<F%Y7W!O<"AU;G!A
M8VLH)TPG+"!S=6)S='(H)$9L86=S0G5F9F5R+"`D:2`J(#0L(#0I*2D@/CX@
M.#L*("`@("`@("`@("`@("`@("1M97-S86=E7VEN9F];)&9L86=?87)R87E;
M)&UA<VM=72`](&%R<F%Y7W!O<"AU;G!A8VLH)TPG+"!S=6)S='(H)$1A=&%"
M=69F97(L("1P;W,L(#0I*2D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@(&-A<V4@,'@W.@H@("`@("`@("`@("!C87-E(#!X.#H*("`@
M("`@("`@("`@8V%S92`P>#DZ"B`@("`@("`@("`@(&-A<V4@,'A!.@H@("`@
M("`@("`@("!C87-E(#!X0CH*("`@("`@("`@("`@8V%S92`P>$0Z"B`@("`@
M("`@("`@(&-A<V4@,'A%.@H@("`@("`@("`@("!C87-E(#!X,3,Z"B`@("`@
M("`@("`@(&-A<V4@,'@Q03H*("`@("`@("`@("`@("`@("1P;W,@*ST@87)R
M87E?<&]P*'5N<&%C:R@G3"<L('-U8G-T<B@D1FQA9W-"=69F97(L("1I("H@
M-"P@-"DI*2`^/B`X.PH@("`@("`@("`@("`@("`@)&UE<W-A9V5?:6YF;ULD
M9FQA9U]A<G)A>5LD;6%S:UU=(#T@)'1H:7,M/E]R96%D4W1R:6YG*"1$871A
M0G5F9F5R+"`D<&]S*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@8V%S92`P>#$R.@H@("`@("`@("`@("`@("`@)'!O<R`K/2!A<G)A
M>5]P;W`H=6YP86-K*"=,)RP@<W5B<W1R*"1&;&%G<T)U9F9E<BP@)&D@*B`T
M+"`T*2DI(#X^(#@["B`@("`@("`@("`@("`@("`D;65S<V%G95]I;F9O6R=2
M96-E:79E9"==(#T@87)R87E?<&]P*'5N<&%C:R@G3"<L('-U8G-T<B@D1&%T
M84)U9F9E<BP@)'!O<RP@-"DI*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@8V%S92`P>#%".@H@("`@("`@("`@("`@("`@)'!O<R`K
M/2!A<G)A>5]P;W`H=6YP86-K*"=,)RP@<W5B<W1R*"1&;&%G<T)U9F9E<BP@
M)&D@*B`T+"`T*2DI(#X^(#@["B`@("`@("`@("`@("`@("`D;65S<V%G95]I
M;F9O6R=!8V-O=6YT240G72`](&EN='9A;"@D=&AI<RT^7W)E8613=')I;F<H
M)$1A=&%"=69F97(L("1P;W,I*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@8V%S92`P>#@P.@H@("`@("`@("`@("!C87-E(#!X.#$Z
M"B`@("`@("`@("`@(&-A<V4@,'@X-#H*("`@("`@("`@("`@8V%S92`P>#DQ
M.@H@("`@("`@("`@("`@("`@)&UE<W-A9V5?:6YF;ULD9FQA9U]A<G)A>5LD
M;6%S:UU=(#T@87)R87E?<&]P*'5N<&%C:R@G3"<L('-U8G-T<B@D1FQA9W-"
M=69F97(L("1I("H@-"P@-"DI*2`^/B`X.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M;65S<V%G95]I;F9O.PH@("`@?0H*("`@("\J*@H@("`@("H@5$]$3PH@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)B1D871A("`@("`@5$]$3PH@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'!O<VET:6]N("!43T1/"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R96%D
M26YD97@H)B1D871A+"`D<&]S:71I;VXI"B`@("!["B`@("`@("`@)&EN9&5X
M7VAE861E<B`]('5N<&%C:R@G3$9I;&50;W,O3%5N:VYO=VXQ+TQ0<F5V26YD
M97@O3$YE>'1);F1E>"],0V]U;G0O3%5N:VYO=VXG+"!S=6)S='(H)&1A=&$L
M("1P;W-I=&EO;BP@,C0I*3L*("`@("`@("!I9B`H)&EN9&5X7VAE861E<ELG
M1FEL95!O<R==("$]("1P;W-I=&EO;BD@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*"));G9A;&ED(&9I;&4@9F]R;6%T(BDI.PH@
M("`@("`@('T*"B`@("`@("`@+R\@4'5S:"!I="!I;G1O(&QI<W0@;V8@<')O
M8V5S<V5D(&ET96US+@H@("`@("`@("1T:&ES+3Y?=&UP6R1P;W-I=&EO;ET@
M/2!T<G5E.PH@("`@("`@(&EF("@H)&EN9&5X7VAE861E<ELG3F5X=$EN9&5X
M)UT@/B`P*2`F)@H@("`@("`@("`@("!E;7!T>2@D=&AI<RT^7W1M<%LD:6YD
M97A?:&5A9&5R6R=.97AT26YD97@G75TI*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?<F5A9$EN9&5X*"1D871A+"`D:6YD97A?:&5A9&5R6R=.97AT26YD97@G
M72D["B`@("`@("`@?0H@("`@("`@(&EF("@H)&EN9&5X7VAE861E<ELG4')E
M=DEN9&5X)UT@/B`P*2`F)@H@("`@("`@("`@("!E;7!T>2@D=&AI<RT^7W1M
M<%LD:6YD97A?:&5A9&5R6R=0<F5V26YD97@G75TI*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?<F5A9$EN9&5X*"1D871A+"`D:6YD97A?:&5A9&5R6R=0<F5V
M26YD97@G72D["B`@("`@("`@?0H@("`@("`@("1P;W-I=&EO;B`K/2`R-#L*
M("`@("`@("`D:6-O=6YT(#T@)&EN9&5X7VAE861E<ELG0V]U;G0G72`^/B`X
M.PH@("`@("`@(&EF("@D:6-O=6YT(#X@,"D@>PH@("`@("`@("`@("`D8G5F
M(#T@<W5B<W1R*"1D871A+"`D<&]S:71I;VXL(#$R("H@)&EC;W5N="D["B`@
M("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1I8V]U;G0[("1I*RLI('L*
M("`@("`@("`@("`@("`@("1H9')?8G5F(#T@<W5B<W1R*"1B=68L("1I("H@
M,3(L(#$R*3L*("`@("`@("`@("`@("`@("1);F1E>$ET96T@/2!U;G!A8VLH
M)TQ(96%D97)0;W,O3$-H:6QD26YD97@O3%5N:VYO=VXG+"`D:&1R7V)U9BD[
M"B`@("`@("`@("`@("`@("!I9B`H)$EN9&5X271E;5LG2&5A9&5R4&]S)UT@
M/B`P*2!["B`@("`@("`@("`@("`@("`@("`@)&UA:6Q;)VEN9F\G72`]("1T
M:&ES+3Y?<F5A9$UE<W-A9V5);F9O*"1D871A+"`D26YD97A)=&5M6R=(96%D
M97)0;W,G72D["B`@("`@("`@("`@("`@("`@("`@)&UA:6Q;)V-O;G1E;G0G
M72`]("1T:&ES+3Y?<F5A9$UE<W-A9V4H)&1A=&$L("1M86EL6R=I;F9O)UU;
M)W!O<VET:6]N)UTI.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;6%I
M;'-;72`]("1M86EL.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@:68@*"@D26YD97A)=&5M6R=#:&EL9$EN9&5X)UT@/B`P*2`F)@H@("`@
M("`@("`@("`@("`@("`@(&5M<'1Y*"1T:&ES+3Y?=&UP6R1);F1E>$ET96U;
M)T-H:6QD26YD97@G75TI*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]R96%D26YD97@H)&9P+"`D26YD97A)=&5M6R=#:&EL9$EN9&5X)UTI.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-O
M;7!R97-S+V=Z:7`N<&AP````````````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P-30Q,P`Q,#4Q-30S,S<U,``P,C(W-#(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D
M95]#;VUP<F5S<U]G>FEP(&-L87-S(&%L;&]W<R!G>FEP(&9I;&5S('1O(&)E
M(')E860N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+V=Z:7`N<&AP+'8@,2XW+C$R+CD@,C`P-B\P-"\S,"`R,CHR.#HR.2!C
M:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@
M0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($-O<'ER:6=H
M="`R,#`S+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN
M8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC
M:&%E;"!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0&%U
M=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A
M9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?0V]M<')E<W,*("HO"F-L87-S($AO<F1E7T-O;7!R97-S7V=Z:7`@97AT
M96YD<R!(;W)D95]#;VUP<F5S<R!["@H@("`@+RHJ"B`@("`@*B!'>FEP(&9I
M;&4@9FQA9W,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]F;&%G<R`](&%R<F%Y*`H@("`@("`@("=&5$585"<@("`@(#T^
M("`P>#`Q+`H@("`@("`@("=&2$-20R<@("`@(#T^("`P>#`R+`H@("`@("`@
M("=&15A44D$G("`@(#T^("`P>#`T+`H@("`@("`@("=&3D%-12<@("`@(#T^
M("`P>#`X+`H@("`@("`@("=&0T]-345.5"<@(#T^("`P>#$P"B`@("`I.PH*
M("`@("\J*@H@("`@("H@1&5C;VUP<F5S<R!A(&=Z:7`@9FEL92!A;F0@9V5T
M(&EN9F]R;6%T:6]N(&9R;VT@:70N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`F)&1A=&$@(%1H92!T87(@9FEL92!D871A+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@(%1H92!P87)A;65T97(@87)R87D@*%5N=7-E9"DN
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!U;F-O;7!R97-S
M960@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C;VUP<F5S<R@F)&1A
M=&$L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("\J($EF(&=Z
M:7`@:7,@;F]T(&-O;7!I;&5D(&EN=&\@4$A0+"!R971U<FX@;F]W+B`J+PH@
M("`@("`@(&EF("@A571I;#HZ97AT96YS:6]N17AI<W1S*"=Z;&EB)RDI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B5&AI<R!S
M97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(BDI
M.PH@("`@("`@('T*"B`@("`@("`@+RH@1WII<'!E9"!&:6QE("T@9&5C;VUP
M<F5S<R!I="!F:7)S="X@*B\*("`@("`@("`D<&]S:71I;VX@/2`P.PH@("`@
M("`@("1I;F9O(#T@0'5N<&%C:R@G0T--+T-&3$<O5E1I;64O0UA&3"]#3U,G
M+"!S=6)S='(H)&1A=&$L("1P;W-I=&EO;B`K(#(I*3L*("`@("`@("!I9B`H
M(21I;F9O*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N(BDI.PH@("`@("`@('T*
M("`@("`@("`D<&]S:71I;VX@*ST@,3`["@H@("`@("`@(&EF("@D:6YF;ULG
M1DQ')UT@)B`D=&AI<RT^7V9L86=S6R=&15A44D$G72D@>PH@("`@("`@("`@
M("`D6$Q%3B`]('5N<&%C:R@G=DQE;F=T:"<L('-U8G-T<B@D9&%T82P@)'!O
M<VET:6]N("L@,"P@,BDI.PH@("`@("`@("`@("`D6$Q%3B`]("183$5.6R=,
M96YG=&@G73L*("`@("`@("`@("`@)'!O<VET:6]N("L]("183$5.("L@,CL*
M("`@("`@("!]"@H@("`@("`@(&EF("@D:6YF;ULG1DQ')UT@)B`D=&AI<RT^
M7V9L86=S6R=&3D%-12==*2!["B`@("`@("`@("`@("1F:6QE;F%M95!O<R`]
M('-T<G!O<R@D9&%T82P@(EQX,"(L("1P;W-I=&EO;BD["B`@("`@("`@("`@
M("1F:6QE;F%M92`]('-U8G-T<B@D9&%T82P@)'!O<VET:6]N+"`D9FEL96YA
M;650;W,@+2`D<&]S:71I;VXI.PH@("`@("`@("`@("`D<&]S:71I;VX@/2`D
M9FEL96YA;650;W,@*R`Q.PH@("`@("`@('T*"B`@("`@("`@:68@*"1I;F9O
M6R=&3$<G72`F("1T:&ES+3Y?9FQA9W-;)T9#3TU-14Y4)UTI('L*("`@("`@
M("`@("`@)&-O;6UE;G10;W,@/2!S=')P;W,H)&1A=&$L(")<>#`B+"`D<&]S
M:71I;VXI.PH@("`@("`@("`@("`D8V]M;65N="`]('-U8G-T<B@D9&%T82P@
M)'!O<VET:6]N+"`D8V]M;65N=%!O<R`M("1P;W-I=&EO;BD["B`@("`@("`@
M("`@("1P;W-I=&EO;B`]("1C;VUM96YT4&]S("L@,3L*("`@("`@("!]"@H@
M("`@("`@(&EF("@D:6YF;ULG1DQ')UT@)B`D=&AI<RT^7V9L86=S6R=&2$-2
M0R==*2!["B`@("`@("`@("`@("1H8W)C(#T@=6YP86-K*"=V0U)#)RP@<W5B
M<W1R*"1D871A+"`D<&]S:71I;VX@*R`P+"`R*2D["B`@("`@("`@("`@("1H
M8W)C(#T@)&AC<F-;)T-20R==.PH@("`@("`@("`@("`D<&]S:71I;VX@*ST@
M,CL*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2!`9WII;F9L871E*'-U
M8G-T<B@D9&%T82P@)'!O<VET:6]N+"!S=')L96XH)&1A=&$I("T@)'!O<VET
M:6]N*2D["B`@("`@("`@:68@*&5M<'1Y*"1R97-U;'0I*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!D96-O
M;7!R97-S(&1A=&$N(BDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O0V]M<')E<W,O=&%R+G!H<```
M````````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W-S4T`#$P-3$U-#,S
M-S4P`#`R,C4W,0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&AE($AO<F1E7T-O;7!R97-S7W1A<B!C
M;&%S<R!A;&QO=W,@=&%R(&9I;&5S('1O(&)E(')E860N"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`L=B`Q+C0N
M,3(N.2`R,#`V+S`T+S,P(#(R.C(X.C(Y(&-H=6-K($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E;"!#;V-H<F%N92`\;6EK94!G<F%F
M=&]N:&%L;"YC;RYN>CX*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6-H865L
M(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L($-O8VAR86YE(#QM:6ME
M0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A
M<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@
M($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]#;VUP<F5S<PH@*B\*8VQA
M<W,@2&]R9&5?0V]M<')E<W-?=&%R(&5X=&5N9',@2&]R9&5?0V]M<')E<W,@
M>PH*("`@("\J*@H@("`@("H@5&%R(&9I;&4@='EP97,N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]T>7!E<R`](&%R<F%Y
M*`H@("`@("`@(#!X,"`@(#T^("`G56YI>"!F:6QE)RP*("`@("`@("`P>#,P
M("`]/B`@)T9I;&4G+`H@("`@("`@(#!X,S$@(#T^("`G3&EN:R<L"B`@("`@
M("`@,'@S,B`@/3X@("=3>6UB;VQI8R!L:6YK)RP*("`@("`@("`P>#,S("`]
M/B`@)T-H87)A8W1E<B!S<&5C:6%L(&9I;&4G+`H@("`@("`@(#!X,S0@(#T^
M("`G0FQO8VL@<W!E8VEA;"!F:6QE)RP*("`@("`@("`P>#,U("`]/B`@)T1I
M<F5C=&]R>2<L"B`@("`@("`@,'@S-B`@/3X@("=&249/('-P96-I86P@9FEL
M92<L"B`@("`@("`@,'@S-R`@/3X@("=#;VYT:6=U;W5S(&9I;&4G"B`@("`I
M.PH*("`@("\J*@H@("`@("H@5&%R(&9I;&4@9FQA9W,N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]F;&%G<R`](&%R<F%Y
M*`H@("`@("`@("=&5$585"<@("`@(#T^("`P>#`Q+`H@("`@("`@("=&2$-2
M0R<@("`@(#T^("`P>#`R+`H@("`@("`@("=&15A44D$G("`@(#T^("`P>#`T
M+`H@("`@("`@("=&3D%-12<@("`@(#T^("`P>#`X+`H@("`@("`@("=&0T]-
M345.5"<@(#T^("`P>#$P"B`@("`I.PH*("`@("\J*@H@("`@("H@1&5C;VUP
M<F5S<R!A('1A<B!F:6QE(&%N9"!G970@:6YF;W)M871I;VX@9G)O;2!I="X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("8D9&%T82`@(%1H92!T87(@
M9FEL92!D871A+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%1H92!P
M87)A;65T97(@87)R87D@*%5N=7-E9"DN"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@5&AE(')E<75E<W1E9"!D871A(&]R(%!%05)?17)R;W(@;VX@
M97)R;W(N"B`@("`@*B`\<')E/@H@("`@("H@2T59.B!0;W-I=&EO;B!I;B!T
M:&4@87)R87D*("`@("`J(%9!3%5%4SH@)V%T='(G("`M+2`@1FEL92!A='1R
M:6)U=&5S"B`@("`@*B`@("`@("`@("=D871A)R`@+2T@(%)A=R!F:6QE(&-O
M;G1E;G1S"B`@("`@*B`@("`@("`@("=D871E)R`@+2T@($9I;&4@;6]D:69I
M8V%T:6]N('1I;64*("`@("`J("`@("`@("`@)VYA;64G("`M+2`@1FEL96YA
M;64*("`@("`J("`@("`@("`@)W-I>F4G("`M+2`@3W)I9VEN86P@9FEL92!S
M:7IE"B`@("`@*B`@("`@("`@("=T>7!E)R`@+2T@($9I;&4@='EP90H@("`@
M("H@/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E8V]M<')E<W,H)B1D
M871A+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D<&]S:71I
M;VX@/2`P.PH@("`@("`@("1R971U<FY?87)R87D@/2!A<G)A>2@I.PH*("`@
M("`@("!W:&EL92`H)'!O<VET:6]N(#P@<W1R;&5N*"1D871A*2D@>PH@("`@
M("`@("`@("`D:6YF;R`]($!U;G!A8VLH(F$Q,#!F:6QE;F%M92]A.&UO9&4O
M83AU:60O83AG:60O83$R<VEZ92]A,3)M=&EM92]A.&-H96-K<W5M+T-T>7!E
M9FQA9R]A,3`P;&EN:R]A-FUA9VEC+V$R=F5R<VEO;B]A,S)U;F%M92]A,S)G
M;F%M92]A.&1E=FUA:F]R+V$X9&5V;6EN;W(B+"!S=6)S='(H)&1A=&$L("1P
M;W-I=&EO;BDI.PH@("`@("`@("`@("!I9B`H(21I;F9O*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@
M9&5C;VUP<F5S<R!D871A+B(I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@)'!O<VET:6]N("L](#4Q,CL*("`@("`@("`@("`@)&-O;G1E;G1S(#T@
M<W5B<W1R*"1D871A+"`D<&]S:71I;VXL(&]C=&1E8R@D:6YF;ULG<VEZ92==
M*2D["B`@("`@("`@("`@("1P;W-I=&EO;B`K/2!C96EL*&]C=&1E8R@D:6YF
M;ULG<VEZ92==*2`O(#4Q,BD@*B`U,3(["@H@("`@("`@("`@("!I9B`H)&EN
M9F];)V9I;&5N86UE)UTI('L*("`@("`@("`@("`@("`@("1F:6QE(#T@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@)V%T='(G(#T^(&YU;&PL"B`@("`@
M("`@("`@("`@("`@("`@)V1A=&$G(#T^(&YU;&PL"B`@("`@("`@("`@("`@
M("`@("`@)V1A=&4G(#T^(&]C=&1E8R@D:6YF;ULG;71I;64G72DL"B`@("`@
M("`@("`@("`@("`@("`@)VYA;64G(#T^('1R:6TH)&EN9F];)V9I;&5N86UE
M)UTI+`H@("`@("`@("`@("`@("`@("`@("=S:7IE)R`]/B!O8W1D96,H)&EN
M9F];)W-I>F4G72DL"B`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^(&ES
M<V5T*"1T:&ES+3Y?='EP97-;)&EN9F];)W1Y<&5F;&%G)UU=*2`_("1T:&ES
M+3Y?='EP97-;)&EN9F];)W1Y<&5F;&%G)UU=(#H@;G5L;`H@("`@("`@("`@
M("`@("`@*3L*"B`@("`@("`@("`@("`@("!I9B`H*"1I;F9O6R=T>7!E9FQA
M9R==(#T](#`I('Q\"B`@("`@("`@("`@("`@("`@("`@*"1I;F9O6R=T>7!E
M9FQA9R==(#T](#!X,S`I('Q\"B`@("`@("`@("`@("`@("`@("`@*"1I;F9O
M6R=T>7!E9FQA9R==(#T](#!X,S4I*2!["B`@("`@("`@("`@("`@("`@("`@
M+RH@1FEL92!O<B!F;VQD97(N("HO"B`@("`@("`@("`@("`@("`@("`@)&9I
M;&5;)V1A=&$G72`]("1C;VYT96YT<SL*"B`@("`@("`@("`@("`@("`@("`@
M)&UO9&4@/2!H97AD96,H<W5B<W1R*"1I;F9O6R=M;V1E)UTL(#0L(#,I*3L*
M("`@("`@("`@("`@("`@("`@("`D9FEL95LG871T<B==(#T*("`@("`@("`@
M("`@("`@("`@("`@("`@*"@D:6YF;ULG='EP969L86<G72`]/2`P>#,U*2`_
M("=D)R`Z("<M)RD@+@H@("`@("`@("`@("`@("`@("`@("`@("`H*"1M;V1E
M("8@,'@T,#`I(#\@)W(G(#H@)RTG*2`N"B`@("`@("`@("`@("`@("`@("`@
M("`@("@H)&UO9&4@)B`P>#(P,"D@/R`G=R<@.B`G+2<I("X*("`@("`@("`@
M("`@("`@("`@("`@("`@*"@D;6]D92`F(#!X,3`P*2`_("=X)R`Z("<M)RD@
M+@H@("`@("`@("`@("`@("`@("`@("`@("`H*"1M;V1E("8@,'@P-#`I(#\@
M)W(G(#H@)RTG*2`N"B`@("`@("`@("`@("`@("`@("`@("`@("@H)&UO9&4@
M)B`P>#`R,"D@/R`G=R<@.B`G+2<I("X*("`@("`@("`@("`@("`@("`@("`@
M("`@*"@D;6]D92`F(#!X,#$P*2`_("=X)R`Z("<M)RD@+@H@("`@("`@("`@
M("`@("`@("`@("`@("`H*"1M;V1E("8@,'@P,#0I(#\@)W(G(#H@)RTG*2`N
M"B`@("`@("`@("`@("`@("`@("`@("`@("@H)&UO9&4@)B`P>#`P,BD@/R`G
M=R<@.B`G+2<I("X*("`@("`@("`@("`@("`@("`@("`@("`@*"@D;6]D92`F
M(#!X,#`Q*2`_("=X)R`Z("<M)RD["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("\J(%-O;64@;W1H97(@='EP92X@*B\*
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D<F5T=7)N7V%R
M<F%Y6UT@/2`D9FEL93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1R971U<FY?87)R87D["B`@("!]"@I]"@``````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M0V]M<')E<W,O=&YE9BYP:'``````````````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#(U,S(T`#$P-3$U-#,S-S4P`#`R,C<S,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`H*9&5F:6YE*"=43D5&
M7U-)1TY!5%5212<L("`@("`@,'@R,C-E.68W."D["F1E9FEN92@G5$Y%1E],
M5DQ?34534T%'12<L("`@(#!X,#$I.PID969I;F4H)U1.149?3%9,7T%45$%#
M2$U%3E0G+"`P>#`R*3L*"F1E9FEN92@G5$Y%1E]35%))3D<G+"`P>#`P,#$P
M,#`P*3L*9&5F:6YE*"=43D5&7T)95$4G+"`@(#!X,#`P-C`P,#`I.PID969I
M;F4H)U1.149?5T]21"<L("`@,'@P,#`W,#`P,"D["F1E9FEN92@G5$Y%1E]$
M5T]21"<L("`P>#`P,#@P,#`P*3L*"F1E9FEN92@G5$Y%1E]!4U5"2D5#5"<L
M("`@5$Y%1E]$5T]21"`@?"`P>#@P,#0I.PID969I;F4H)U1.149?04U#3$%3
M4R<L("`@(%1.149?5T]21"`@('P@,'@X,#`X*3L*9&5F:6YE*"=43D5&7T%4
M5$%#2$1!5$$G+"!43D5&7T)95$4@("!\(#!X.#`P9BD["F1E9FEN92@G5$Y%
M1E]!1DE,14Y!344G+"`@5$Y%1E]35%))3D<@?"`P>#@P,3`I.PID969I;F4H
M)U1.149?05)%3D1$051!)RP@(%1.149?0EE412`@('P@,'@Y,#`R*3L*9&5F
M:6YE*"=43D5&7T%-05!)05144E,G+"!43D5&7T)95$4@("!\(#!X.3`P-2D[
M"F1E9FEN92@G5$Y%1E]!5D524TE/3B<L("`@5$Y%1E]$5T]21"`@?"`P>#DP
M,#8I.PH*9&5F:6YE*"=43D5&7TU!4$E?3E5,3"<L("`@("`@("`@("`P>#`P
M,#$I.PID969I;F4H)U1.149?34%025]32$]25"<L("`@("`@("`@(#!X,#`P
M,BD["F1E9FEN92@G5$Y%1E]-05!)7TE.5"<L("`@("`@("`@("`@,'@P,#`S
M*3L*9&5F:6YE*"=43D5&7TU!4$E?1DQ/050G+"`@("`@("`@("`P>#`P,#0I
M.PID969I;F4H)U1.149?34%025]$3U5"3$4G+"`@("`@("`@(#!X,#`P-2D[
M"F1E9FEN92@G5$Y%1E]-05!)7T-54E)%3D-9)RP@("`@("`@,'@P,#`V*3L*
M9&5F:6YE*"=43D5&7TU!4$E?05!05$E-12<L("`@("`@("`P>#`P,#<I.PID
M969I;F4H)U1.149?34%025]%4E)/4B<L("`@("`@("`@(#!X,#`P82D["F1E
M9FEN92@G5$Y%1E]-05!)7T)/3TQ%04XG+"`@("`@("`@,'@P,#!B*3L*9&5F
M:6YE*"=43D5&7TU!4$E?3T)*14-4)RP@("`@("`@("`P>#`P,&0I.PID969I
M;F4H)U1.149?34%025])3E0X0EE412<L("`@("`@(#!X,#`Q-"D["F1E9FEN
M92@G5$Y%1E]-05!)7U-44DE.1R<L("`@("`@("`@,'@P,#%E*3L*9&5F:6YE
M*"=43D5&7TU!4$E?54Y)0T]$15]35%))3D<G+"`P>#`P,68I.PID969I;F4H
M)U1.149?34%025]365-424U%)RP@("`@("`@(#!X,#`T,"D["F1E9FEN92@G
M5$Y%1E]-05!)7T-,4TE$)RP@("`@("`@("`@,'@P,#0X*3L*9&5F:6YE*"=4
M3D5&7TU!4$E?0DE.05)9)RP@("`@("`@("`P>#`Q,#(I.PH*9&5F:6YE*"=4
M3D5&7TU!4$E?051404-(7TQ/3D=?1DE,14Y!344G+"`P>#,W,#<I.PID969I
M;F4H)U1.149?34%025]!5%1!0TA?34E-15]404<G+"`@("`@(#!X,S<P12D[
M"@ID969I;F4H)U1.149?34%025].04U%1%]465!%7TE$)RP@("`@(#!X,#`P
M,"D["F1E9FEN92@G5$Y%1E]-05!)7TY!345$7U194$5?4U1224Y')RP@,'@P
M,#`Q*3L*9&5F:6YE*"=43D5&7TU!4$E?359?1DQ!1R<L("`@("`@("`@("`P
M>#$P,#`I.PH*+RHJ"B`J(%1H92!(;W)D95]#;VUP<F5S<U]T;F5F(&-L87-S
M(&%L;&]W<R!-4RU43D5&(&1A=&$@=&\@8F4@9&ES<&QA>65D+@H@*@H@*B!4
M:&4@5$Y%1B!R96YD97)I;F<@:7,@8F%S960@;VX@8V]D92!B>3H*("H@("!'
M<F%H86T@3F]R8G5R>2`\9VYO<F)U<GE`8F]N9&-A<BYC;VT^"B`J($]R:6=I
M;F%L(&1E<VEG;B!B>3H*("H@("!4:&]M87,@0F]L;"`\=&)`8F]L;"YC:#XL
M($UA<FL@4VEM<'-O;B`\9&%M;F5D0'=O<FQD+G-T9"YC;VT^"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1N968N<&AP+'8@
M,2XV+C$R+CD@,C`P-B\P,2\P,2`R,3HR.#HQ,2!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#(M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N
M;W)G/@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@4VQU<V%R>B`\
M<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J
M($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O
M;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E
M($AO<F1E7T-O;7!R97-S"B`J+PIC;&%S<R!(;W)D95]#;VUP<F5S<U]T;F5F
M(&5X=&5N9',@2&]R9&5?0V]M<')E<W,@>PH*("`@("\J*@H@("`@("H@1&5C
M;VUP<F5S<R!T:&4@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1D871A("`@5&AE(&1A=&$@=&\@9&5C;VUP<F5S<RX*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("!!;B!A<G)A>2!O9B!A<F=U;65N=',@;F5E9&5D
M('1O(&1E8V]M<')E<W,@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@9&5C
M;VUP<F5S<V5D(&1A=&$N"B`@("`@*B`@("`@("`@("`@("`@("!2971U<FYS
M(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&1E8V]M<')E<W,H)&1A=&$L("1P87)A;7,@/2!A<G)A>2@I*0H@
M("`@>PH@("`@("`@("1O=70@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H)'1H
M:7,M/E]G971I*"1D871A+"`S,BD@/3T@5$Y%1E]324=.05154D4I('L*("`@
M("`@("`@("`@)'1H:7,M/E]G971I*"1D871A+"`Q-BD["@H@("`@("`@("`@
M("!W:&EL92`H<W1R;&5N*"1D871A*2`^(#`I('L*("`@("`@("`@("`@("`@
M('-W:71C:"`H)'1H:7,M/E]G971I*"1D871A+"`X*2D@>PH@("`@("`@("`@
M("`@("`@8V%S92!43D5&7TQ63%]-15-304=%.@H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9&5C;V1E365S<V%G92@D9&%T82D["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92!43D5&7TQ6
M3%]!5%1!0TA-14Y4.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&5C
M;V1E071T86-H;65N="@D9&%T82P@)&]U="D["B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>5]R979E<G-E*"1O=70I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)B1D871A
M("!4:&4@9&%T82!S=')I;F<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8FET
M<R`@2&]W(&UA;GD@8FET<R!T;R!R971R:65V92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(%1/1$\*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E='@H)B1D871A
M+"`D8FET<RD*("`@('L*("`@("`@("`D=F%L=64@/2!N=6QL.PH*("`@("`@
M("!I9B`H<W1R;&5N*"1D871A*2`^/2`D8FET<RD@>PH@("`@("`@("`@("`D
M=F%L=64@/2!S=6)S='(H)&1A=&$L(#`L("1B:71S*3L*("`@("`@("`@("`@
M)&1A=&$@/2!S=6)S=')?<F5P;&%C92@D9&%T82P@)R<L(#`L("1B:71S*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=F%L=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`F)&1A=&$@(%1H92!D871A
M('-T<FEN9RX*("`@("`J($!P87)A;2!I;G1E9V5R("1B:71S("!(;W<@;6%N
M>2!B:71S('1O(')E=')I979E+@H@("`@("H*("`@("`J($!R971U<FX@5$]$
M3PH@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T:2@F)&1A=&$L("1B:71S*0H@
M("`@>PH@("`@("`@("1B>71E<R`]("1B:71S("\@.#L*("`@("`@("`D=F%L
M=64@/2!N=6QL.PH*("`@("`@("!I9B`H<W1R;&5N*"1D871A*2`^/2`D8GET
M97,I('L*("`@("`@("`@("`@)'9A;'5E(#T@;W)D*"1D871A6S!=*3L*("`@
M("`@("`@("`@:68@*"1B>71E<R`^/2`R*2!["B`@("`@("`@("`@("`@("`D
M=F%L=64@*ST@*&]R9"@D9&%T85LQ72D@/#P@."D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*"1B>71E<R`^/2`T*2!["B`@("`@("`@("`@("`@
M("`D=F%L=64@*ST@*&]R9"@D9&%T85LR72D@/#P@,38I("L@*&]R9"@D9&%T
M85LS72D@/#P@,C0I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1D871A
M(#T@<W5B<W1R7W)E<&QA8V4H)&1A=&$L("<G+"`P+"`D8GET97,I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1V86QU93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%1/1$\*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("8D9&%T82`@("`@(%1H92!D871A
M('-T<FEN9RX*("`@("`J($!P87)A;2!S=')I;F<@)&%T=')I8G5T92`@5$]$
M3PH@("`@("HO"B`@("!F=6YC=&EO;B!?9&5C;V1E071T<FEB=71E*"8D9&%T
M82P@)&%T=')I8G5T92D*("`@('L*("`@("`@("`O*B!$871A+B`J+PH@("`@
M("`@("1T:&ES+3Y?9V5T>"@D9&%T82P@)'1H:7,M/E]G971I*"1D871A+"`S
M,BDI.PH*("`@("`@("`O*B!#:&5C:W-U;2X@*B\*("`@("`@("`D=&AI<RT^
M7V=E=&DH)&1A=&$L(#$V*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1/1$\*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1D871A("`@("`@("`@("`@(%1H92!D871A('-T<FEN
M9RX*("`@("`J($!P87)A;2!A<G)A>2`F)&%T=&%C:&UE;G1?9&%T82`@5$]$
M3PH@("`@("HO"B`@("!F=6YC=&EO;B!?97AT<F%C=$UA<&E!='1R:6)U=&5S
M*"1D871A+"`F)&%T=&%C:&UE;G1?9&%T82D*("`@('L*("`@("`@("`O*B!.
M=6UB97(@;V8@871T<FEB=71E<RX@*B\*("`@("`@("`D;G5M8F5R(#T@)'1H
M:7,M/E]G971I*"1D871A+"`S,BD["@H@("`@("`@('=H:6QE("@H<W1R;&5N
M*"1D871A*2`^(#`I("8F("1N=6UB97(M+2D@>PH@("`@("`@("`@("`D:&%V
M95]M=F%L(#T@9F%L<V4["B`@("`@("`@("`@("1N=6U?;79A;"`](#$["B`@
M("`@("`@("`@("1N86UE9%]I9"`]("1V86QU92`](&YU;&P["B`@("`@("`@
M("`@("1A='1R7W1Y<&4@/2`D=&AI<RT^7V=E=&DH)&1A=&$L(#$V*3L*("`@
M("`@("`@("`@)&%T=')?;F%M92`]("1T:&ES+3Y?9V5T:2@D9&%T82P@,38I
M.PH*("`@("`@("`@("`@:68@*"@D871T<E]T>7!E("8@5$Y%1E]-05!)7TU6
M7T9,04<I("$](#`I('L*("`@("`@("`@("`@("`@("1H879E7VUV86P@/2!T
M<G5E.PH@("`@("`@("`@("`@("`@)&%T=')?='EP92`]("1A='1R7W1Y<&4@
M)B!^5$Y%1E]-05!)7TU67T9,04<["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(&EF("@H)&%T=')?;F%M92`^/2`P>#@P,#`I("8F("@D871T<E]N86UE
M(#P@,'A&1D9%*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]G971X*"1D
M871A+"`Q-BD["B`@("`@("`@("`@("`@("`D;F%M961?='EP92`]("1T:&ES
M+3Y?9V5T:2@D9&%T82P@,S(I.PH*("`@("`@("`@("`@("`@('-W:71C:"`H
M)&YA;65D7W1Y<&4I('L*("`@("`@("`@("`@("`@(&-A<V4@5$Y%1E]-05!)
M7TY!345$7U194$5?240Z"B`@("`@("`@("`@("`@("`@("`@)&YA;65D7VED
M(#T@)'1H:7,M/E]G971I*"1D871A+"`S,BD["B`@("`@("`@("`@("`@("`@
M("`@)&%T=')?;F%M92`]("1N86UE9%]I9#L*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E(%1.149?34%025].04U%
M1%]465!%7U-44DE.1SH*("`@("`@("`@("`@("`@("`@("`D871T<E]N86UE
M(#T@,'@Y.3DY.PH@("`@("`@("`@("`@("`@("`@("1I9&QE;B`]("1T:&ES
M+3Y?9V5T:2@D9&%T82P@,S(I.PH@("`@("`@("`@("`@("`@("`@("1D871A
M;&5N(#T@)&ED;&5N("L@*"@T("T@*"1I9&QE;B`E(#0I*2`E(#0I.PH@("`@
M("`@("`@("`@("`@("`@("1N86UE9%]I9"`]('-U8G-T<B@D=&AI<RT^7V=E
M='@H)&1A=&$L("1D871A;&5N*2P@,"P@)&ED;&5N*3L*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@:68@*"1H879E7VUV86PI('L*("`@("`@("`@("`@
M("`@("1N=6U?;79A;"`]("1T:&ES+3Y?9V5T:2@D9&%T82P@,S(I.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!S=VET8V@@*"1A='1R7W1Y<&4I('L*
M("`@("`@("`@("`@8V%S92!43D5&7TU!4$E?4TA/4E0Z"B`@("`@("`@("`@
M("`@("`D=F%L=64@/2`D=&AI<RT^7V=E=&DH)&1A=&$L(#$V*3L*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92!43D5&7TU!4$E?
M24Y4.@H@("`@("`@("`@("!C87-E(%1.149?34%025]"3T],14%..@H@("`@
M("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&YU;5]M=F%L.R`D:2LK
M*2!["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@)'1H:7,M/E]G971I
M*"1D871A+"`S,BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@5$Y%1E]-05!)7T9,3T%4.@H@
M("`@("`@("`@("!C87-E(%1.149?34%025]%4E)/4CH*("`@("`@("`@("`@
M("`@("1V86QU92`]("1T:&ES+3Y?9V5T>"@D9&%T82P@-"D["B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@5$Y%1E]-05!)7T1/
M54),13H*("`@("`@("`@("`@8V%S92!43D5&7TU!4$E?05!05$E-13H*("`@
M("`@("`@("`@8V%S92!43D5&7TU!4$E?0U524D5.0UDZ"B`@("`@("`@("`@
M(&-A<V4@5$Y%1E]-05!)7TE.5#A"651%.@H@("`@("`@("`@("!C87-E(%1.
M149?34%025]365-424U%.@H@("`@("`@("`@("`@("`@)'9A;'5E(#T@)'1H
M:7,M/E]G971X*"1D871A+"`X*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@8V%S92!43D5&7TU!4$E?4U1224Y'.@H@("`@("`@("`@
M("!C87-E(%1.149?34%025]53DE#3T1%7U-44DE.1SH*("`@("`@("`@("`@
M8V%S92!43D5&7TU!4$E?0DE.05)9.@H@("`@("`@("`@("!C87-E(%1.149?
M34%025]/0DI%0U0Z"B`@("`@("`@("`@("`@("`D;G5M7W9A;',@/2`H)&AA
M=F5?;79A;"D@/R`D;G5M7VUV86P@.B`D=&AI<RT^7V=E=&DH)&1A=&$L(#,R
M*3L*("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1N=6U?=F%L
M<SL@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("1L96YG=&@@/2`D=&AI
M<RT^7V=E=&DH)&1A=&$L(#,R*3L*"B`@("`@("`@("`@("`@("`@("`@+RH@
M4&%D('1O(&YE>'0@-"!B>71E(&)O=6YD87)Y+B`J+PH@("`@("`@("`@("`@
M("`@("`@("1D871A;&5N(#T@)&QE;F=T:"`K("@H-"`M("@D;&5N9W1H("4@
M-"DI("4@-"D["@H@("`@("`@("`@("`@("`@("`@(&EF("@D871T<E]T>7!E
M(#T](%1.149?34%025]35%))3D<I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&QE;F=T:"`M/2`Q.PH@("`@("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("`@("`@+RH@4F5A9"!A;F0@=')U;F-A=&4@=&\@;&5N9W1H
M+B`J+PH@("`@("`@("`@("`@("`@("`@("1V86QU92`]('-U8G-T<B@D=&AI
M<RT^7V=E='@H)&1A=&$L("1D871A;&5N*2P@,"P@)&QE;F=T:"D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@+RH@4W1O<F4@86YY(&EN=&5R97-T:6YG(&%T
M=')I8G5T97,N("HO"B`@("`@("`@("`@('-W:71C:"`H)&%T=')?;F%M92D@
M>PH@("`@("`@("`@("!C87-E(%1.149?34%025]!5%1!0TA?3$].1U]&24Q%
M3D%-13H*("`@("`@("`@("`@("`@("\J(%5S960@:6X@<')E9F5R96YC92!T
M;R!!1DE,14Y!344@=F%L=64N("HO"B`@("`@("`@("`@("`@("`D871T86-H
M;65N=%]D871A6S!=6R=N86UE)UT@/2!P<F5G7W)E<&QA8V4H)R\N*EM<+UTH
M+BHI)"\G+"`G7#$G+"`D=F%L=64I.PH@("`@("`@("`@("`@("`@)&%T=&%C
M:&UE;G1?9&%T85LP75LG;F%M92==(#T@<W1R7W)E<&QA8V4H(EPP(BP@)R<L
M("1A='1A8VAM96YT7V1A=&%;,%U;)VYA;64G72D["B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@5$Y%1E]-05!)7T%45$%#2%]-
M24U%7U1!1SH*("`@("`@("`@("`@("`@("\J($ES('1H:7,@979E<B!S970L
M(&%N9"!W:&%T(&ES(&9O<FUA=#\@*B\*("`@("`@("`@("`@("`@("1A='1A
M8VAM96YT7V1A=&%;,%U;)W1Y<&4G72`]('!R96=?<F5P;&%C92@G+UXH+BHI
M7"\N*B\G+"`G7#$G+"`D=F%L=64I.PH@("`@("`@("`@("`@("`@)&%T=&%C
M:&UE;G1?9&%T85LP75LG<W5B='EP92==(#T@<')E9U]R97!L86-E*"<O+BI<
M+R@N*BDD+R<L("=<,2<L("1V86QU92D["B`@("`@("`@("`@("`@("`D871T
M86-H;65N=%]D871A6S!=6R=S=6)T>7!E)UT@/2!S=')?<F5P;&%C92@B7#`B
M+"`G)RP@)&%T=&%C:&UE;G1?9&%T85LP75LG<W5B='EP92==*3L*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)B1D871A("!4
M:&4@9&%T82!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D96-O9&5-
M97-S86=E*"8D9&%T82D*("`@('L*("`@("`@("`D=&AI<RT^7V1E8V]D94%T
M=')I8G5T92@D9&%T82P@)'1H:7,M/E]G971I*"1D871A+"`S,BDI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)B1D871A("`@
M("`@("`@("`@5&AE(&1A=&$@<W1R:6YG+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("8D871T86-H;65N=%]D871A("!43T1/"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]D96-O9&5!='1A8VAM96YT*"8D9&%T82P@)B1A='1A8VAM96YT7V1A=&$I
M"B`@("!["B`@("`@("`@)&%T=')I8G5T92`]("1T:&ES+3Y?9V5T:2@D9&%T
M82P@,S(I.PH*("`@("`@("!S=VET8V@@*"1A='1R:6)U=&4I('L*("`@("`@
M("!C87-E(%1.149?05)%3D1$051!.@H@("`@("`@("`@("`O*B!-87)K<R!S
M=&%R="!O9B!N97<@871T86-H;65N="X@*B\*("`@("`@("`@("`@)'1H:7,M
M/E]G971X*"1D871A+"`D=&AI<RT^7V=E=&DH)&1A=&$L(#,R*2D["@H@("`@
M("`@("`@("`O*B!#:&5C:W-U;2`J+PH@("`@("`@("`@("`D=&AI<RT^7V=E
M=&DH)&1A=&$L(#$V*3L*"B`@("`@("`@("`@("\J($%D9"!A(&YE=R!D969A
M=6QT(&1A=&$@8FQO8VL@=&\@:&]L9"!D971A:6QS(&]F('1H:7,*("`@("`@
M("`@("`@("`@871T86-H;65N="X@4F5V97)S92!O<F1E<B!I<R!E87-I97(@
M=&\@:&%N9&QE(&QA=&5R(2`J+PH@("`@("`@("`@("!A<G)A>5]U;G-H:69T
M*"1A='1A8VAM96YT7V1A=&$L(&%R<F%Y*"=T>7!E)R`@("`]/B`G87!P;&EC
M871I;VXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=S=6)T>7!E)R`]/B`G;V-T970M<W1R96%M)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G;F%M92<@("`@/3X@)W5N:VYO=VXG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S=')E86TG("`]/B`G
M)RDI.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!43D5&7T%&
M24Q%3D%-13H*("`@("`@("`@("`@+RH@4W1R:7`@<&%T:"X@*B\*("`@("`@
M("`@("`@)&%T=&%C:&UE;G1?9&%T85LP75LG;F%M92==(#T@<')E9U]R97!L
M86-E*"<O+BI;7"]=*"XJ*20O)RP@)UPQ)RP@)'1H:7,M/E]G971X*"1D871A
M+"`D=&AI<RT^7V=E=&DH)&1A=&$L(#,R*2DI.PH@("`@("`@("`@("`D871T
M86-H;65N=%]D871A6S!=6R=N86UE)UT@/2!S=')?<F5P;&%C92@B7#`B+"`G
M)RP@)&%T=&%C:&UE;G1?9&%T85LP75LG;F%M92==*3L*"B`@("`@("`@("`@
M("\J($-H96-K<W5M("HO"B`@("`@("`@("`@("1T:&ES+3Y?9V5T:2@D9&%T
M82P@,38I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!43D5&
M7T%45$%#2$1!5$$Z"B`@("`@("`@("`@("\J(%1H92!A='1A8VAM96YT(&ET
M<V5L9BX@*B\*("`@("`@("`@("`@)&QE;F=T:"`]("1T:&ES+3Y?9V5T:2@D
M9&%T82P@,S(I.PH@("`@("`@("`@("`D871T86-H;65N=%]D871A6S!=6R=S
M:7IE)UT@/2`D;&5N9W1H.PH@("`@("`@("`@("`D871T86-H;65N=%]D871A
M6S!=6R=S=')E86TG72`]("1T:&ES+3Y?9V5T>"@D9&%T82P@)&QE;F=T:"D[
M"@H@("`@("`@("`@("`O*B!#:&5C:W-U;2`J+PH@("`@("`@("`@("`D=&AI
M<RT^7V=E=&DH)&1A=&$L(#$V*3L*("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@(&-A<V4@5$Y%1E]!34%024%45%)3.@H@("`@("`@("`@("`D;&5N9W1H
M(#T@)'1H:7,M/E]G971I*"1D871A+"`S,BD["B`@("`@("`@("`@("1V86QU
M92`]("1T:&ES+3Y?9V5T>"@D9&%T82P@)&QE;F=T:"D["@H@("`@("`@("`@
M("`O*B!#:&5C:W-U;2`J+PH@("`@("`@("`@("`D=&AI<RT^7V=E=&DH)&1A
M=&$L(#$V*3L*("`@("`@("`@("`@)'1H:7,M/E]E>'1R86-T36%P:4%T=')I
M8G5T97,H)'9A;'5E+"`D871T86-H;65N=%]D871A*3L*("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("1T:&ES+3Y?
M9&5C;V1E071T<FEB=71E*"1D871A+"`D871T<FEB=71E*3L*("`@("`@("!]
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP
M:'``````````````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S-#<S,P`Q,#4Q
M-30S,S<U,``P,C(V,#(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"B\J*@H@*B!&;W(@9&5C;VUP<F5S<R@I+"!R
M971U<FX@82!L:7-T(&]F(&9I;&5S+VEN9F]R;6%T:6]N(&%B;W5T('1H92!Z
M:7!F:6QE+@H@*B\*9&5F:6YE*"=(3U)$15]#3TU04D534U]:25!?3$E35"<L
M(#$I.PH*+RHJ"B`J($9O<B!D96-O;7!R97-S*"DL(')E='5R;B!T:&4@9&%T
M82!F;W(@86X@:6YD:79I9'5A;"!F:6QE(&EN('1H92!Z:7!F:6QE+@H@*B\*
M9&5F:6YE*"=(3U)$15]#3TU04D534U]:25!?1$%402<L(#(I.PH*+RHJ"B`J
M(%1H92!(;W)D95]#;VUP<F5S<U]Z:7`@8VQA<W,@86QL;W=S(%I)4"!F:6QE
M<R!T;R!B92!C<F5A=&5D(&%N9`H@*B!R96%D+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP+'8@,2XQ,2XQ,BXQ
M-B`R,#`V+S`V+S(Y(#`X.C,T.C,P(&IA;B!%>'`@)`H@*@H@*B!4:&4@6DE0
M(&-O;7!R97-S:6]N(&-O9&4@:7,@<&%R=&EA;&QY(&)A<V5D(&]N(&-O9&4@
M9G)O;3H*("H@("!%<FEC($UU96QL97(@/&5R:6-`=&AE;65P87)K+F-O;3X*
M("H@("!H='1P.B\O=W=W+GIE;F0N8V]M+V-O9&5X+G!H<#]I9#TU,S4F<VEN
M9VQE/3$*("H*("H@("!$96EN<S$R-2`\=V5B;6%S=&5R0&%T;&%N="YR=3X*
M("H@("!H='1P.B\O=W=W+GIE;F0N8V]M+V-O9&5X+G!H<#]I9#TT-S`F<VEN
M9VQE/3$*("H*("H@5&AE(%I)4"!C;VUP<F5S<VEO;B!D871E(&-O9&4@:7,@
M<&%R=&EA;&QY(&)A<V5D(&]N(&-O9&4@9G)O;0H@*B`@(%!E=&5R($QI<W1I
M86L@/&UL861Y0'5S97)S+G-O=7)C969O<F=E+FYE=#X*("H*("H@0V]P>7)I
M9VAT(#(P,#`M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L($-O8VAR86YE(#QM
M:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V
M($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D
M=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!-:6-H865L($-O8VAR
M86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`875T:&]R("!-:6-H
M865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J
M($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]#;VUP<F5S
M<PH@*B\*8VQA<W,@2&]R9&5?0V]M<')E<W-?>FEP(&5X=&5N9',@2&]R9&5?
M0V]M<')E<W,@>PH*("`@("\J*@H@("`@("H@6DE0(&-O;7!R97-S:6]N(&UE
M=&AO9',N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)%]M971H;V1S(#T@87)R87DH"B`@("`@("`@,'@P(#T^("=.;VYE)RP*
M("`@("`@("`P>#$@/3X@)U-H<G5N:R<L"B`@("`@("`@,'@R(#T^("=3=7!E
M<B!&87-T)RP*("`@("`@("`P>#,@/3X@)T9A<W0G+`H@("`@("`@(#!X-"`]
M/B`G3F]R;6%L)RP*("`@("`@("`P>#4@/3X@)TUA>&EM=6TG+`H@("`@("`@
M(#!X-B`]/B`G26UP;&]D960G+`H@("`@("`@(#!X."`]/B`G1&5F;&%T960G
M"B`@("`I.PH*("`@("\J*@H@("`@("H@0F5G:6YN:6YG(&]F(&-E;G1R86P@
M9&ER96-T;W)Y(')E8V]R9"X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)%]C=')L1&ER2&5A9&5R(#T@(EQX-3!<>#1B7'@P
M,5QX,#(B.PH*("`@("\J*@H@("`@("H@16YD(&]F(&-E;G1R86P@9&ER96-T
M;W)Y(')E8V]R9"X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)%]C=')L1&ER16YD(#T@(EQX-3!<>#1B7'@P-5QX,#9<>#`P
M7'@P,%QX,#!<>#`P(CL*"B`@("`O*BH*("`@("`J($)E9VEN;FEN9R!O9B!F
M:6QE(&-O;G1E;G1S+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D7V9I;&5(96%D97(@/2`B7'@U,%QX-&)<>#`S7'@P-"([
M"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@82!:25`@8V]M<')E<W-E9"!F:6QE
M(&9R;VT@86X@87)R87D@;V8@9FEL92!D871A+@H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`D9&%T82`@("!4:&4@9&%T82!T;R!C;VUP<F5S<RX*("`@
M("`J(#QP<F4^"B`@("`@*B!297%U:7)E<R!A;B!A<G)A>2!O9B!A<G)A>7,@
M+2!E86-H('-U8F%R<F%Y('-H;W5L9"!C;VYT86EN('1H90H@("`@("H@9F]L
M;&]W:6YG(&9I96QD<SH*("`@("`J("=D871A)R`H<W1R:6YG*2`@("TM("!4
M:&4@9&%T82!T;R!C;VUP<F5S<RX*("`@("`J("=N86UE)R`H<W1R:6YG*2`@
M("TM("!4:&4@<&%T:&YA;64@=&\@=&AE(&9I;&4N"B`@("`@*B`G=&EM92<@
M*&EN=&5G97(I("`M+2`@6V]P=&EO;F%L72!4:&4@=&EM97-T86UP('1O('5S
M92!F;W(@=&AE(&9I;&4N"B`@("`@*B`\+W!R93X*("`@("`J($!P87)A;2!A
M<G)A>2`D<&%R86US("!4:&4@<&%R86UE=&5R(&%R<F%Y("A5;G5S960I+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@6DE0(&9I;&4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&-O;7!R97-S*"1D871A+"`D<&%R86US(#T@
M87)R87DH*2D*("`@('L*("`@("`@("`D8V]N=&5N=',@/2`D8W1R;&1I<B`]
M(&%R<F%Y*"D["@H@("`@("`@(&9O<F5A8V@@*"1D871A(&%S("1V86PI('L*
M("`@("`@("`@("`@)'1H:7,M/E]A9&14;UI)4$9I;&4H)'9A;"P@)&-O;G1E
M;G1S+"`D8W1R;&1I<BD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H
M:7,M/E]C<F5A=&5:25!&:6QE*"1C;VYT96YT<RP@)&-T<FQD:7(I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1&5C;VUP<F5S<R!A(%I)4"!F:6QE(&%N9"!G
M970@:6YF;W)M871I;VX@9G)O;2!I="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1D871A("`@5&AE('II<&9I;&4@9&%T82X*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("!4:&4@<&%R86UE=&5R(&%R<F%Y+@H@("`@("H@
M/'!R93X*("`@("`J(%1H92!F;VQL;W=I;F<@<&%R86UE=&5R<R!A<F4@4D51
M54E2140Z"B`@("`@*B`G86-T:6]N)R`H:6YT96=E<BD@(#T^("!4:&4@86-T
M:6]N('1O('1A:V4@;VX@=&AE(&1A=&$N("!%:71H97(*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@($A/4D1%7T-/35!215-37UI)4%],25-4(&]R
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!(3U)$15]#3TU04D53
M4U]:25!?1$%402X*("`@("`J"B`@("`@*B!4:&4@9F]L;&]W:6YG('!A<F%M
M971E<G,@87)E(%)%455)4D5$(&9O<B!(3U)$15]#3TU04D534U]:25!?1$%4
M02!A;'-O.@H@("`@("H@)VEN9F\G("AA<G)A>2D@("`]/B`@5&AE('II<&9I
M;&4@;&ES="X*("`@("`J("=K97DG("AI;G1E9V5R*2`@/3X@(%1H92!P;W-I
M=&EO;B!O9B!T:&4@9FEL92!I;B!T:&4@87)C:&EV92!L:7-T+@H@("`@("H@
M/"]P<F4^"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(')E<75E
M<W1E9"!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96-O;7!R97-S*"1D
M871A+"`D<&%R86US*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D<&%R86US
M6R=A8W1I;VXG72DI('L*("`@("`@("`@("`@:68@*"1P87)A;7-;)V%C=&EO
M;B==(#T]($A/4D1%7T-/35!215-37UI)4%],25-4*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]G971::7!);F9O*"1D871A*3L*("`@("`@
M("`@("`@?2!E;'-E:68@*"1P87)A;7-;)V%C=&EO;B==(#T]($A/4D1%7T-/
M35!215-37UI)4%]$051!*2!["B`@("`@("`@("`@("`@("`O+R!43T1/.B!#
M:&5C:R!F;W(@<&%R86UE=&5R<RX*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7V=E=%II<$1A=&$H)&1A=&$L("1P87)A;7-;)VEN9F\G72P@)'!A
M<F%M<ULG:V5Y)UTI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B26YC;W)R96-T(&%C
M=&EO;B!C;V1E(&=I=F5N+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M
M+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E
M="!T:&4@;&ES="!O9B!F:6QE<R]D871A(&9R;VT@=&AE('II<"!A<F-H:79E
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)B1D871A("!4:&4@>FEP9FEL92!D871A+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@($M%63H@4&]S:71I;VX@:6X@>FEP
M9FEL90H@("`@("H@("`@("`@("`@("`@("`@5D%,5453.B`G871T<B<@("`@
M+2T@($9I;&4@871T<FEB=71E<PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`G8W)C)R`@("`@+2T@($-20R!C:&5C:W-U;0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`G8W-I>F4G("`@+2T@($-O;7!R97-S960@9FEL
M92!S:7IE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("=D871E)R`@
M("`M+2`@1FEL92!M;V1I9FEC871I;VX@=&EM90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`G;F%M92<@("`@+2T@($9I;&5N86UE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("=M971H;V0G("`M+2`@0V]M<')E<W-I
M;VX@;65T:&]D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("=S:7IE
M)R`@("`M+2`@3W)I9VEN86P@9FEL92!S:7IE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("=T>7!E)R`@("`M+2`@1FEL92!T>7!E"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]G971::7!);F9O*"8D9&%T82D*("`@('L*("`@("`@
M("`D96YT<FEE<R`](&%R<F%Y*"D["@H@("`@("`@("\J($=E="!D971A:6QS
M(&9R;VT@0V5N=')A;"!D:7)E8W1O<GD@<W1R=6-T=7)E+B`J+PH@("`@("`@
M("1F:%-T87)T(#T@<W1R<&]S*"1D871A+"`D=&AI<RT^7V-T<FQ$:7)(96%D
M97(I.PH*("`@("`@("!D;R!["B`@("`@("`@("`@(&EF("AS=')L96XH)&1A
M=&$I(#P@)&9H4W1A<G0@*R`S,2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B26YV86QI9"!:25`@9&%T82(I*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D:6YF;R`]('5N<&%C:R@G=DUE=&AO
M9"]65&EM92]60U)#,S(O5D-O;7!R97-S960O5E5N8V]M<')E<W-E9"]V3&5N
M9W1H)RP@<W5B<W1R*"1D871A+"`D9FA3=&%R="`K(#$P+"`R,"DI.PH@("`@
M("`@("`@("`D;F%M92`]('-U8G-T<B@D9&%T82P@)&9H4W1A<G0@*R`T-BP@
M)&EN9F];)TQE;F=T:"==*3L*"B`@("`@("`@("`@("1E;G1R:65S6R1N86UE
M72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)V%T='(G(#T^(&YU;&PL"B`@
M("`@("`@("`@("`@("`G8W)C)R`]/B!S<')I;G1F*"(E,#AS(BP@9&5C:&5X
M*"1I;F9O6R=#4D,S,B==*2DL"B`@("`@("`@("`@("`@("`G8W-I>F4G(#T^
M("1I;F9O6R=#;VUP<F5S<V5D)UTL"B`@("`@("`@("`@("`@("`G9&%T92<@
M/3X@;G5L;"P*("`@("`@("`@("`@("`@("=?9&%T85-T87)T)R`]/B!N=6QL
M+`H@("`@("`@("`@("`@("`@)VYA;64G(#T^("1N86UE+`H@("`@("`@("`@
M("`@("`@)VUE=&AO9"<@/3X@)'1H:7,M/E]M971H;V1S6R1I;F9O6R=-971H
M;V0G75TL"B`@("`@("`@("`@("`@("`G7VUE=&AO9"<@/3X@)&EN9F];)TUE
M=&AO9"==+`H@("`@("`@("`@("`@("`@)W-I>F4G(#T^("1I;F9O6R=5;F-O
M;7!R97-S960G72P*("`@("`@("`@("`@("`@("=T>7!E)R`]/B!N=6QL"B`@
M("`@("`@("`@("D["@H@("`@("`@("`@("`D96YT<FEE<ULD;F%M95U;)V1A
M=&4G72`]"B`@("`@("`@("`@("`@("!M:W1I;64H*"@D:6YF;ULG5&EM92==
M(#X^(#$Q*2`F(#!X,68I+`H@("`@("`@("`@("`@("`@("`@("`@("@H)&EN
M9F];)U1I;64G72`^/B`U*2`F(#!X,V8I+`H@("`@("`@("`@("`@("`@("`@
M("`@("@H)&EN9F];)U1I;64G72`\/"`Q*2`F(#!X,V4I+`H@("`@("`@("`@
M("`@("`@("`@("`@("@H)&EN9F];)U1I;64G72`^/B`R,2D@)B`P>#`W*2P*
M("`@("`@("`@("`@("`@("`@("`@("`H*"1I;F9O6R=4:6UE)UT@/CX@,38I
M("8@,'@Q9BDL"B`@("`@("`@("`@("`@("`@("`@("`@*"@H)&EN9F];)U1I
M;64G72`^/B`R-2D@)B`P>#=F*2`K(#$Y.#`I*3L*"B`@("`@("`@("`@(&EF
M("AS=')L96XH)&1A=&$I(#P@)&9H4W1A<G0@*R`T,RD@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B26YV86QI9"!:25`@
M9&%T82(I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D:6YF;R`]('5N
M<&%C:R@G=DEN=&5R;F%L+U9%>'1E<FYA;"<L('-U8G-T<B@D9&%T82P@)&9H
M4W1A<G0@*R`S-BP@-BDI.PH*("`@("`@("`@("`@)&5N=')I97-;)&YA;65=
M6R=T>7!E)UT@/2`H)&EN9F];)TEN=&5R;F%L)UT@)B`P>#`Q*2`_("=T97AT
M)R`Z("=B:6YA<GDG.PH@("`@("`@("`@("`D96YT<FEE<ULD;F%M95U;)V%T
M='(G72`]"B`@("`@("`@("`@("`@("`H*"1I;F9O6R=%>'1E<FYA;"==("8@
M,'@Q,"D@/R`G1"<@.B`G+2<I("X*("`@("`@("`@("`@("`@("@H)&EN9F];
M)T5X=&5R;F%L)UT@)B`P>#(P*2`_("=!)R`Z("<M)RD@+@H@("`@("`@("`@
M("`@("`@*"@D:6YF;ULG17AT97)N86PG72`F(#!X,#,I(#\@)U,G(#H@)RTG
M*2`N"B`@("`@("`@("`@("`@("`H*"1I;F9O6R=%>'1E<FYA;"==("8@,'@P
M,BD@/R`G2"<@.B`G+2<I("X*("`@("`@("`@("`@("`@("@H)&EN9F];)T5X
M=&5R;F%L)UT@)B`P>#`Q*2`_("=2)R`Z("<M)RD["B`@("`@("`@?2!W:&EL
M92`H*"1F:%-T87)T(#T@<W1R<&]S*"1D871A+"`D=&AI<RT^7V-T<FQ$:7)(
M96%D97(L("1F:%-T87)T("L@-#8I*2`A/3T@9F%L<V4I.PH*("`@("`@("`O
M*B!'970@9&5T86EL<R!F<F]M(&QO8V%L(&9I;&4@:&5A9&5R+B`J+PH@("`@
M("`@("1F:%-T87)T(#T@<W1R<&]S*"1D871A+"`D=&AI<RT^7V9I;&5(96%D
M97(I.PH*("`@("`@("!D;R!["B`@("`@("`@("`@(&EF("AS=')L96XH)&1A
M=&$I(#P@)&9H4W1A<G0@*R`S-"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B26YV86QI9"!:25`@9&%T82(I*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D:6YF;R`]('5N<&%C:R@G=DUE=&AO
M9"]65&EM92]60U)#,S(O5D-O;7!R97-S960O5E5N8V]M<')E<W-E9"]V3&5N
M9W1H+W9%>'1R84QE;F=T:"<L('-U8G-T<B@D9&%T82P@)&9H4W1A<G0@*R`X
M+"`R-2DI.PH@("`@("`@("`@("`D;F%M92`]('-U8G-T<B@D9&%T82P@)&9H
M4W1A<G0@*R`S,"P@)&EN9F];)TQE;F=T:"==*3L*("`@("`@("`@("`@)&5N
M=')I97-;)&YA;65=6R=?9&%T85-T87)T)UT@/2`D9FA3=&%R="`K(#,P("L@
M)&EN9F];)TQE;F=T:"==("L@)&EN9F];)T5X=')A3&5N9W1H)UT["B`@("`@
M("`@?2!W:&EL92`H<W1R;&5N*"1D871A*2`^("1F:%-T87)T("L@,S`@*R`D
M:6YF;ULG3&5N9W1H)UT@)B8*("`@("`@("`@("`@("`@("`H)&9H4W1A<G0@
M/2!S=')P;W,H)&1A=&$L("1T:&ES+3Y?9FEL94AE861E<BP@)&9H4W1A<G0@
M*R`S,"`K("1I;F9O6R=,96YG=&@G72DI("$]/2!F86QS92D["@H@("`@("`@
M(')E='5R;B!A<G)A>5]V86QU97,H)&5N=')I97,I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@9&%T82!F;W(@82!S<&5C:69I8R!A<F-H
M:79E9"!F:6QE+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)B1D871A("!4:&4@>FEP(&%R8VAI
M=F4@8V]N=&5N=',N"B`@("`@*B!`<&%R86T@87)R87D@)B1I;F9O("`@5&AE
M(&EN9F]R;6%T:6]N(&%R<F%Y(&9R;VT@7V=E=%II<$EN9F\H*2X*("`@("`J
M($!P87)A;2!I;G1E9V5R("1K97D@("!4:&4@<&]S:71I;VX@;V8@=&AE(&9I
M;&4@:6X@=&AE(&%R8VAI=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!F:6QE(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971:
M:7!$871A*"8D9&%T82P@)B1I;F9O+"`D:V5Y*0H@("`@>PH@("`@("`@(&EF
M("@H)&EN9F];)&ME>5U;)U]M971H;V0G72`]/2`P>#@I("8F(%5T:6PZ.F5X
M=&5N<VEO;D5X:7-T<R@G>FQI8B<I*2!["B`@("`@("`@("`@("\J($EF('1H
M92!F:6QE(&AA<R!B965N(&1E9FQA=&5D+"!A;F0@>FQI8B!I<R!I;G-T86QL
M960L"B`@("`@("`@("`@("`@('1H96X@:6YF;&%T92!T:&4@9&%T82!A9V%I
M;BX@*B\*("`@("`@("`@("`@<F5T=7)N($!G>FEN9FQA=&4H<W5B<W1R*"1D
M871A+"`D:6YF;ULD:V5Y75LG7V1A=&%3=&%R="==+"`D:6YF;ULD:V5Y75LG
M8W-I>F4G72DI.PH@("`@("`@('T@96QS96EF("@D:6YF;ULD:V5Y75LG7VUE
M=&AO9"==(#T](#!X,"D@>PH@("`@("`@("`@("`O*B!&:6QE<R!T:&%T(&%R
M96XG="!C;VUP<F5S<V5D+B`J+PH@("`@("`@("`@("!R971U<FX@<W5B<W1R
M*"1D871A+"`D:6YF;ULD:V5Y75LG7V1A=&%3=&%R="==+"`D:6YF;ULD:V5Y
M75LG8W-I>F4G72D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)R<["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@=&\@<V5E(&EF('1H92!D871A
M(&ES(&$@=F%L:60@6DE0(&9I;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`F)&1A=&$@(%1H92!:25`@9FEL92!D871A+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!V86QI9"P@9F%L<V4@:68@:6YV
M86QI9"X*("`@("`J+PH@("`@9G5N8W1I;VX@8VAE8VM::7!$871A*"8D9&%T
M82D*("`@('L*("`@("`@("!I9B`H<W1R<&]S*"1D871A+"`D=&AI<RT^7V9I
M;&5(96%D97(I(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N('1R=64[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@82!5
M3DE8('1I;65S=&%M<"!T;R!A(#0M8GET92!$3U,@9&%T92!A;F0@=&EM92!F
M;W)M870*("`@("`J("AD871E(&EN(&AI9V@@,BUB>71E<RP@=&EM92!I;B!L
M;W<@,BUB>71E<R!A;&QO=VEN9R!M86=N:71U9&4*("`@("`J(&-O;7!A<FES
M;VXI+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1U;FEX=&EM92`@5&AE(&-U<G)E;G0@54Y)
M6"!T:6UE<W1A;7`N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4
M:&4@8W5R<F5N="!D871E(&EN(&$@-"UB>71E($1/4R!F;W)M870N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]U;FEX,D1/4U1I;64H)'5N:7AT:6UE(#T@;G5L
M;"D*("`@('L*("`@("`@("`D=&EM96%R<F%Y(#T@*&ES7VYU;&PH)'5N:7AT
M:6UE*2D@/R!G971D871E*"D@.B!G971D871E*"1U;FEX=&EM92D["@H@("`@
M("`@(&EF("@D=&EM96%R<F%Y6R=Y96%R)UT@/"`Q.3@P*2!["B`@("`@("`@
M("`@("1T:6UE87)R87E;)WEE87(G72`@("`](#$Y.#`["B`@("`@("`@("`@
M("1T:6UE87)R87E;)VUO;B==("`@("`](#$["B`@("`@("`@("`@("1T:6UE
M87)R87E;)VUD87DG72`@("`](#$["B`@("`@("`@("`@("1T:6UE87)R87E;
M)VAO=7)S)UT@("`](#`["B`@("`@("`@("`@("1T:6UE87)R87E;)VUI;G5T
M97,G72`](#`["B`@("`@("`@("`@("1T:6UE87)R87E;)W-E8V]N9',G72`]
M(#`["B`@("`@("`@?0H*("`@("`@("!R971U<FX@*"@D=&EM96%R<F%Y6R=Y
M96%R)UT@+2`Q.3@P*2`\/"`R-2D@?`H@("`@("`@("`@("`@("`@*"1T:6UE
M87)R87E;)VUO;B==(#P\(#(Q*2!\"B`@("`@("`@("`@("`@("`H)'1I;65A
M<G)A>5LG;61A>2==(#P\(#$V*2!\"B`@("`@("`@("`@("`@("`H)'1I;65A
M<G)A>5LG:&]U<G,G72`\/"`Q,2D@?`H@("`@("`@("`@("`@("`@*"1T:6UE
M87)R87E;)VUI;G5T97,G72`\/"`U*2!\"B`@("`@("`@("`@("`@("`H)'1I
M;65A<G)A>5LG<V5C;VYD<R==(#X^(#$I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@061D<R!A(")F:6QE(B!T;R!T:&4@6DE0(&%R8VAI=F4N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("8D9FEL92`@("`@(%-E92!(;W)D95]#;VUP<F5S<U]Z:7`Z.F-R96%T
M95II<$9I;&4H*2X*("`@("`J($!P87)A;2!A<G)A>2`F)&-O;G1E;G1S("!!
M;B!A<G)A>2!O9B!E>&ES=&EN9R!Z:7!P960@9FEL97,N"B`@("`@*B!`<&%R
M86T@87)R87D@)B1C=')L9&ER("`@06X@87)R87D@;V8@8V5N=')A;"!D:7)E
M8W1O<GD@:6YF;W)M871I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A9&14
M;UI)4$9I;&4H)B1F:6QE+"`F)&-O;G1E;G1S+"`F)&-T<FQD:7(I"B`@("![
M"B`@("`@("`@)&1A=&$@/2`F)&9I;&5;)V1A=&$G73L*("`@("`@("`D;F%M
M92`]('-T<E]R97!L86-E*"=<7"<L("<O)RP@)&9I;&5;)VYA;64G72D["@H@
M("`@("`@("\J(%-E92!I9B!T:6UE+V1A=&4@:6YF;W)M871I;VX@:&%S(&)E
M96X@<')O=FED960N("HO"B`@("`@("`@)&9T:6UE(#T@;G5L;#L*("`@("`@
M("!I9B`H:7-S970H)&9I;&5;)W1I;64G72DI('L*("`@("`@("`@("`@)&9T
M:6UE(#T@)&9I;&5;)W1I;64G73L*("`@("`@("!]"@H@("`@("`@("\J($=E
M="!T:&4@:&5X('1I;64N("HO"B`@("`@("`@)&1T:6UE("`@(#T@9&5C:&5X
M*"1T:&ES+3Y?=6YI>#)$;W-4:6UE*"1F=&EM92DI.PH@("`@("`@("1H97AD
M=&EM92`](&-H<BAH97AD96,H)&1T:6UE6S9=("X@)&1T:6UE6S==*2D@+@H@
M("`@("`@("`@("`@("`@("`@(&-H<BAH97AD96,H)&1T:6UE6S1=("X@)&1T
M:6UE6S5=*2D@+@H@("`@("`@("`@("`@("`@("`@(&-H<BAH97AD96,H)&1T
M:6UE6S)=("X@)&1T:6UE6S-=*2D@+@H@("`@("`@("`@("`@("`@("`@(&-H
M<BAH97AD96,H)&1T:6UE6S!=("X@)&1T:6UE6S%=*2D["@H@("`@("`@("1F
M<B`@/2`D=&AI<RT^7V9I;&5(96%D97([("`@+RH@0F5G:6X@8W)E871I;F<@
M=&AE(%I)4"!D871A+B`J+PH@("`@("`@("1F<B`N/2`B7'@Q-%QX,#`B.R`@
M("`@("`@("`@+RH@5F5R<VEO;B!N965D960@=&\@97AT<F%C="X@*B\*("`@
M("`@("`D9G(@+CT@(EQX,#!<>#`P(CL@("`@("`@("`@("\J($=E;F5R86P@
M<'5R<&]S92!B:70@9FQA9RX@*B\*("`@("`@("`D9G(@+CT@(EQX,#A<>#`P
M(CL@("`@("`@("`@("\J($-O;7!R97-S:6]N(&UE=&AO9"X@*B\*("`@("`@
M("`D9G(@+CT@)&AE>&1T:6UE.R`@("`@("`@("`@("\J($QA<W0@;6]D:69I
M8V%T:6]N('1I;64O9&%T92X@*B\*"B`@("`@("`@+RH@(DQO8V%L(&9I;&4@
M:&5A9&5R(B!S96=M96YT+B`J+PH@("`@("`@("1U;F-?;&5N(#T@<W1R;&5N
M*"1D871A*3L*("`@("`@("`D8W)C("`@("`](&-R8S,R*"1D871A*3L*("`@
M("`@("`D>F1A=&$@("`](&=Z8V]M<')E<W,H)&1A=&$I.PH@("`@("`@("1Z
M9&%T82`@(#T@<W5B<W1R*'-U8G-T<B@D>F1A=&$L(#`L('-T<FQE;B@D>F1A
M=&$I("T@-"DL(#(I.PH@("`@("`@("1C7VQE;B`@(#T@<W1R;&5N*"1Z9&%T
M82D["@H@("`@("`@("1F<B`N/2!P86-K*"=6)RP@)&-R8RD[("`@("`@("`@
M("`@+RH@0U)#(#,R(&EN9F]R;6%T:6]N+B`J+PH@("`@("`@("1F<B`N/2!P
M86-K*"=6)RP@)&-?;&5N*3L@("`@("`@("`@+RH@0V]M<')E<W-E9"!F:6QE
M<VEZ92X@*B\*("`@("`@("`D9G(@+CT@<&%C:R@G5B<L("1U;F-?;&5N*3L@
M("`@("`@("\J(%5N8V]M<')E<W-E9"!F:6QE<VEZ92X@*B\*("`@("`@("`D
M9G(@+CT@<&%C:R@G=B<L('-T<FQE;B@D;F%M92DI.R`@("\J($QE;F=T:"!O
M9B!F:6QE;F%M92X@*B\*("`@("`@("`D9G(@+CT@<&%C:R@G=B<L(#`I.R`@
M("`@("`@("`@("`@("\J($5X=')A(&9I96QD(&QE;F=T:"X@*B\*("`@("`@
M("`D9G(@+CT@)&YA;64[("`@("`@("`@("`@("`@("`@("`@("\J($9I;&4@
M;F%M92X@*B\*"B`@("`@("`@+RH@(D9I;&4@9&%T82(@<V5G;65N="X@*B\*
M("`@("`@("`D9G(@+CT@)'ID871A.PH*("`@("`@("`O*B`B1&%T82!D97-C
M<FEP=&]R(B!S96=M96YT("AO<'1I;VYA;"!B=70@;F5C97-S87)Y(&EF(&%R
M8VAI=F4@:7,*("`@("`@("`@("!N;W0@<V5R=F5D(&%S(&9I;&4I+B`J+PH@
M("`@("`@("1F<B`N/2!P86-K*"=6)RP@)&-R8RD["B`@("`@("`@)&9R("X]
M('!A8VLH)U8G+"`D8U]L96XI.PH@("`@("`@("1F<B`N/2!P86-K*"=6)RP@
M)'5N8U]L96XI.PH*("`@("`@("`O*B!!9&0@=&AI<R!E;G1R>2!T;R!A<G)A
M>2X@*B\*("`@("`@("`D;VQD7V]F9G-E="`]('-T<FQE;BAI;7!L;V1E*"<G
M+"`D8V]N=&5N=',I*3L*("`@("`@("`D8V]N=&5N='-;72`]("8D9G(["@H@
M("`@("`@("\J($%D9"!T;R!C96YT<F%L(&1I<F5C=&]R>2!R96-O<F0N("HO
M"B`@("`@("`@)&-D<F5C("`]("1T:&ES+3Y?8W1R;$1I<DAE861E<CL*("`@
M("`@("`D8V1R96,@+CT@(EQX,#!<>#`P(CL@("`@("`@("`@("`@("`@+RH@
M5F5R<VEO;B!M861E(&)Y+B`J+PH@("`@("`@("1C9')E8R`N/2`B7'@Q-%QX
M,#`B.R`@("`@("`@("`@("`@("`O*B!697)S:6]N(&YE961E9"!T;R!E>'1R
M86-T("HO"B`@("`@("`@)&-D<F5C("X](")<>#`P7'@P,"([("`@("`@("`@
M("`@("`@("\J($=E;F5R86P@<'5R<&]S92!B:70@9FQA9R`J+PH@("`@("`@
M("1C9')E8R`N/2`B7'@P.%QX,#`B.R`@("`@("`@("`@("`@("`O*B!#;VUP
M<F5S<VEO;B!M971H;V0@*B\*("`@("`@("`D8V1R96,@+CT@)&AE>&1T:6UE
M.R`@("`@("`@("`@("`@("`@+RH@3&%S="!M;V0@=&EM92]D871E+B`J+PH@
M("`@("`@("1C9')E8R`N/2!P86-K*"=6)RP@)&-R8RD[("`@("`@("`@("`O
M*B!#4D,@,S(@:6YF;W)M871I;VXN("HO"B`@("`@("`@)&-D<F5C("X]('!A
M8VLH)U8G+"`D8U]L96XI.R`@("`@("`@("\J($-O;7!R97-S960@9FEL97-I
M>F4N("HO"B`@("`@("`@)&-D<F5C("X]('!A8VLH)U8G+"`D=6YC7VQE;BD[
M("`@("`@("\J(%5N8V]M<')E<W-E9"!F:6QE<VEZ92X@*B\*("`@("`@("`D
M8V1R96,@+CT@<&%C:R@G=B<L('-T<FQE;B@D;F%M92DI.R`@+RH@3&5N9W1H
M(&]F(&9I;&5N86UE+B`J+PH@("`@("`@("1C9')E8R`N/2!P86-K*"=V)RP@
M,"D[("`@("`@("`@("`@("`O*B!%>'1R82!F:65L9"!L96YG=&@N("HO"B`@
M("`@("`@)&-D<F5C("X]('!A8VLH)W8G+"`P*3L@("`@("`@("`@("`@("\J
M($9I;&4@8V]M;65N="!L96YG=&@N("HO"B`@("`@("`@)&-D<F5C("X]('!A
M8VLH)W8G+"`P*3L@("`@("`@("`@("`@("\J($1I<VL@;G5M8F5R('-T87)T
M+B`J+PH@("`@("`@("1C9')E8R`N/2!P86-K*"=V)RP@,"D[("`@("`@("`@
M("`@("`O*B!);G1E<FYA;"!F:6QE(&%T=')I8G5T97,N("HO"B`@("`@("`@
M)&-D<F5C("X]('!A8VLH)U8G+"`S,BD[("`@("`@("`@("`@("\J($5X=&5R
M;F%L(&9I;&4@871T<FEB=71E<R`M"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=A<F-H:79E)R!B:70@<V5T+B`J
M+PH@("`@("`@("1C9')E8R`N/2!P86-K*"=6)RP@)&]L9%]O9F9S970I.R`@
M("`O*B!296QA=&EV92!O9F9S970@;V8@;&]C86P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:&5A9&5R+B`J+PH@
M("`@("`@("1C9')E8R`N/2`D;F%M93L@("`@("`@("`@("`@("`@("`@("`O
M*B!&:6QE(&YA;64N("HO"B`@("`@("`@+RH@3W!T:6]N86P@97AT<F$@9FEE
M;&0L(&9I;&4@8V]M;65N="!G;V5S(&AE<F4N("HO"@H@("`@("`@("\O(%-A
M=F4@=&\@8V5N=')A;"!D:7)E8W1O<GD@87)R87DN("HO"B`@("`@("`@)&-T
M<FQD:7);72`]("8D8V1R96,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A
M=&5S('1H92!:25`@9FEL92X*("`@("`J($]F9FEC:6%L(%I)4"!F:6QE(&9O
M<FUA=#H@:'1T<#HO+W=W=RYP:W=A<F4N8V]M+V%P<&YO=&4N='AT"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!:25`@9FEL92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V-R96%T95I)4$9I;&4H)B1C;VYT96YT<RP@)B1C=')L1&ER*0H@("`@>PH@
M("`@("`@("1D871A(#T@:6UP;&]D92@G)RP@)&-O;G1E;G1S*3L*("`@("`@
M("`D9&ER(#T@:6UP;&]D92@G)RP@)&-T<FQ$:7(I.PH*("`@("`@("!R971U
M<FX@)&1A=&$@+B`D9&ER("X@)'1H:7,M/E]C=')L1&ER16YD("X*("`@("`@
M("`@("`@+RH@5&]T86P@(R!O9B!E;G1R:65S(")O;B!T:&ES(&1I<VLB+B`J
M+PH@("`@("`@("`@("!P86-K*"=V)RP@8V]U;G0H)&-T<FQ$:7(I*2`N"B`@
M("`@("`@("`@("\J(%1O=&%L(",@;V8@96YT<FEE<R!O=F5R86QL+B`J+PH@
M("`@("`@("`@("!P86-K*"=V)RP@8V]U;G0H)&-T<FQ$:7(I*2`N"B`@("`@
M("`@("`@("\J(%-I>F4@;V8@8V5N=')A;"!D:7)E8W1O<GDN("HO"B`@("`@
M("`@("`@('!A8VLH)U8G+"!S=')L96XH)&1I<BDI("X*("`@("`@("`@("`@
M+RH@3V9F<V5T('1O('-T87)T(&]F(&-E;G1R86P@9&ER+B`J+PH@("`@("`@
M("`@("!P86-K*"=6)RP@<W1R;&5N*"1D871A*2D@+@H@("`@("`@("`@("`O
M*B!:25`@9FEL92!C;VUM96YT(&QE;F=T:"X@*B\*("`@("`@("`@("`@(EQX
M,#!<>#`P(CL*("`@('T*"GT*````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T-O;7!R97-S+G!H<```````````````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-S4R-P`Q,#4Q-30S,S<U,@`P,C(P,#,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!(
M;W)D95]#;VUP<F5S<SHZ(&-L87-S('!R;W9I9&5S(&%N($%022!F;W(@=F%R
M:6]U<R!C;VUP<F5S<VEO;@H@*B!T96-H;FEQ=65S('1H870@8V%N(&)E('5S
M960@8GD@2&]R9&4@87!P;&EC871I;VYS+@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<RYP:'`L=B`Q+C<N,3(N,3`@,C`P-B\P
M,2\P,2`R,3HR.#HQ,2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M
M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D
M;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L(%-L
M=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC
M92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]#;VUP<F5S<PH@*B\*
M8VQA<W,@2&]R9&5?0V]M<')E<W,@>PH*("`@("\J*@H@("`@("H@071T96UP
M=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@2&]R9&5?0V]M<')E<W,@:6YS=&%N
M8V4@8F%S960@;VX@)&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX
M960@)&1R:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?0V]M<')E
M<W,@<W5B8VQA<W,@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FXN($EF("1D<FEV97(@:7,@86X@87)R87DL('1H96X@=V4@=VEL;"!L
M;V]K"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:6X@)&1R:79E<ELP
M72]L:6(O0V]M<')E<W,O(&9O<B!T:&4@<W5B8VQA<W,*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D9')I=F5R
M6S%=+G!H<"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@
M8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R<R!A('-U8F-L
M87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]#
M;VUP<F5S<R`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@2&]R9&5?0V]M
M<')E<W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&EN<W1A;F-E
M+"!O<B!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M)F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@:68@*&ES7V%R<F%Y*"1D<FEV97(I*2!["B`@("`@("`@("`@(&QI
M<W0H)&%P<"P@)&1R:79E<BD@/2`D9')I=F5R.PH@("`@("`@('T*"B`@("`@
M("`@)&1R:79E<B`](&)A<V5N86UE*"1D<FEV97(I.PH*("`@("`@("!I9B`H
M(65M<'1Y*"1A<'`I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`D87!P
M("X@)R]L:6(O0V]M<')E<W,O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@
M("`@?2!E;'-E:68@*$!F:6QE7V5X:7-T<RAD:7)N86UE*%]?1DE,15]?*2`N
M("<O0V]M<')E<W,O)R`N("1D<FEV97(@+B`G+G!H<"<I*2!["B`@("`@("`@
M("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O0V]M<')E
M<W,O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@0&EN8VQU9&5?;VYC92`G2&]R9&4O0V]M<')E<W,O)R`N("1D
M<FEV97(@+B`G+G!H<"<["B`@("`@("`@?0H*("`@("`@("`D8VQA<W,@/2`G
M2&]R9&5?0V]M<')E<W-?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L87-S
M7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1C;VUP<F5S<R`]("9N
M97<@)&-L87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1C;VUP<F5S<R`](&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1C;VUP<F5S<SL*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S
M('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E($AO<F1E7T-O
M;7!R97-S(&EN<W1A;F-E"B`@("`@*B!B87-E9"!O;B`D9')I=F5R+B!)="!W
M:6QL(&]N;'D@8W)E871E(&$@;F5W(&EN<W1A;F-E(&EF(&YO"B`@("`@*B!(
M;W)D95]#;VUP<F5S<R!I;G-T86YC92!W:71H('1H92!S86UE('!A<F%M971E
M<G,@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO
M9"!M=7-T(&)E(&EN=F]K960@87,Z"B`@("`@*B`@("1V87(@/2`F2&]R9&5?
M0V]M<')E<W,Z.G-I;F=L971O;B@I.PH@("`@("H*("`@("`J($!P87)A;2!M
M:7AE9"`D9')I=F5R("!3964@2&]R9&5?0V]M<')E<W,Z.F9A8W1O<GDH*2X*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!3964@2&]R9&5?0V]M<')E
M<W,Z.F9A8W1O<GDH*2X*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7T-O
M;7!R97-S("!4:&4@8V]N8W)E=&4@2&]R9&5?0V]M<')E<W,@<F5F97)E;F-E
M+"!O<B!F86QS90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@;VX@
M86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)&1R
M:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<W1A=&EC
M("1I;G-T86YC97,@/2!A<G)A>2@I.PH*("`@("`@("`D<VEG;F%T=7)E(#T@
M;60U*'-E<FEA;&EZ92AA<G)A>2@D9')I=F5R+"`D<&%R86US*2DI.PH@("`@
M("`@(&EF("@A:7-S970H)&EN<W1A;F-E<ULD<VEG;F%T=7)E72DI('L*("`@
M("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`]("9(;W)D95]#;VUP
M<F5S<SHZ9F%C=&]R>2@D9')I=F5R+"`D<&%R86US*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1P87)A;7,@(%!A<F%M971E<B!A<G)A>2X*("`@("`J+PH@
M("`@9G5N8W1I;VX@2&]R9&5?0V]M<')E<W,H)'!A<F%M<R`](&%R<F%Y*"DI
M"B`@("!["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VUP<F5S<R!T:&4@9&%T
M82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("`@5&AE(&1A
M=&$@=&\@8V]M<')E<W,N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@
M06X@87)R87D@;V8@87)G=6UE;G1S(&YE961E9"!T;R!C;VUP<F5S<R!T:&4@
M9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@8V]M<')E
M<W-E9"!D871A+@H@("`@("H@("`@("`@("`@("`@("`@4F5T=7)N<R!014%2
M7T5R<F]R(&]B:F5C="!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M8V]M<')E<W,H)&1A=&$L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=5;G-U<'!O<G1E9"<I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1&5C;VUP<F5S<R!T:&4@9&%T82X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("`@5&AE(&1A=&$@=&\@
M9&5C;VUP<F5S<RX*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;B!A
M<G)A>2!O9B!A<F=U;65N=',@;F5E9&5D('1O(&1E8V]M<')E<W,@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@9&%T82X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!4:&4@9&5C;VUP<F5S<V5D(&1A=&$N"B`@("`@
M*B`@("`@("`@("`@("`@("!2971U<FYS(%!%05)?17)R;W(@;V)J96-T(&]N
M(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96-O;7!R97-S*"1D871A
M+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@G56YS=7!P;W)T960G*3L*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+T-O;F9I9RYP:'``````````````````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$T-S$Q,@`Q,#4Q-30S,S<U,@`P,C$T
M,3``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O1F]R;2YP:'`G.PH*+RHJ"B`J
M(%1H92!#;VYF:6<Z.B!P86-K86=E('!R;W9I9&5S(&$@9G)A;65W;W)K(&9O
M<B!M86YA9VEN9R!T:&4*("H@8V]N9FEG=7)A=&EO;B!O9B!(;W)D92!A<'!L
M:6-A=&EO;G,L('=R:71I;F<@8V]N9BYP:'`@9FEL97,@9G)O;0H@*B!C;VYF
M+GAM;"!S;W5R8V4@9FEL97,L(&=E;F5R871I;F<@=7-E<B!I;G1E<F9A8V5S
M+"!E=&,N"B`J"B`J(%1H92!(;W)D95]#;VYF:6=?3F]D92!$3TT@8VQA<W-E
M<R!A;F0@<W5B8VQA<W-E<PH@*B`H2&]R9&5?0V]N9FEG7T1O8W5M96YT+"!(
M;W)D95]#;VYF:6=?16QE;65N="D@87)E('-I;7!L>2!M87-S86=E9`H@*B!F
M<F]M(&-O9&4@=W)I='1E;B!B>2!T;R!E;75L871E(%!(4#0G<R!$3TU834P@
M97AT96YS:6]N('=I=&@@4$A0-2=S"B`J($1/32!S=7!P;W)T+B!/;FQY(&-H
M86YG97,@87)E(&YA;6EN9R!A;F0@<WEN=&%C=&EC('-U9V%R+TAO<F1E"B`J
M(&-O9&EN9R!S=&%N9&%R9',[(&%L;"!C<F5D:70@9V]E<R!T;R!!;&5X86YD
M<F4@86YD('1H92!C;V1E(&ES('5S960*("H@=VET:"!H:7,@<&5R;6ES<VEO
M;BX@2&ES(&]R:6=I;F%L(&-O9&4@8V%N(&)E(&9O=6YD(&%T.@H@*@H@*B`@
M(&AT='`Z+R]A;&5X86YD<F4N86QA<&5T:71E+FYE="]D;V,M86QE>"]D;VUX
M;6PM<&AP-"UP:'`U+PH@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]#;VYF:6<N<&AP+'8@,2XX,"XR+C(V(#(P,#8O,#8O,#$@,C,Z-#0Z
M,S(@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@
M*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*
M("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T9R86UE
M=V]R:PH@*B\*8VQA<W,@2&]R9&5?0V]N9FEG('L*"B`@("`O*BH*("`@("`J
M(%1H92!N86UE(&]F('1H92!C;VYF:6=U<F5D(&%P<&QI8V%T:6]N+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V%P<#L*
M"B`@("`O*BH*("`@("`J(%1H92!834P@=')E92!O9B!T:&4@8V]N9FEG=7)A
M=&EO;B!F:6QE('1R879E<G-E9"!T;R!A;@H@("`@("H@87-S;V-I871I=F4@
M87)R87DN"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)%]X;6Q#;VYF:6=4<F5E(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%1H
M92!C;VYT96YT(&]F('1H92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!F:6QE
M+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M7W!H<$-O;F9I9SL*"B`@("`O*BH*("`@("`J(%1H92!C;VYT96YT(&]F('1H
M92!O;&0@8V]N9FEG=7)A=&EO;B!F:6QE+@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V]L9$-O;F9I9SL*"B`@("`O*BH*
M("`@("`J(%1H92!M86YU86P@8V]N9FEG=7)A=&EO;B!I;B!F<F]N="!O9B!T
M:&4@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<')E0V]N9FEG.PH*("`@("\J
M*@H@("`@("H@5&AE(&UA;G5A;"!C;VYF:6=U<F%T:6]N(&%F=&5R('1H92!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;BX*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]P;W-T0V]N9FEG.PH*("`@("\J*@H@
M("`@("H@5&AE(&-U<G)E;G0@)&-O;F8@87)R87D@;V8@=&AE(&-O;F9I9W5R
M960@87!P;&EC871I;VXN"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)%]C=7)R96YT0V]N9FEG(#T@87)R87DH*3L*"B`@("`O
M*BH*("`@("`J(%1H92!#5E,@=F5R<VEO;B!T86<@;V8@=&AE(&-O;F8N>&UL
M(&9I;&4@=VAI8V@@=VEL;"!B92!C;W!I960@:6YT;R!T:&4*("`@("`J(&-O
M;F8N<&AP(&9I;&4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1?=F5R<VEO;E1A9R`]("<G.PH*("`@("\J*@H@("`@("H@
M5&AE(&QI;F4@;6%R:VEN9R!T:&4@8F5G:6X@;V8@=&AE(&=E;F5R871E9"!C
M;VYF:6=U<F%T:6]N+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D7V-O;F9I9T)E9VEN(#T@(B\J($-/3D9)1R!35$%25"X@
M1$\@3D]4($-(04Y'12!!3EE42$E.1R!)3B!/4B!!1E1%4B!42$E3($Q)3D4N
M("HO7&XB.PH*("`@("\J*@H@("`@("H@5&AE(&QI;F4@;6%R:VEN9R!T:&4@
M96YD(&]F('1H92!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]C;VYF:6=%;F0@
M/2`B+RH@0T].1DE'($5.1"X@1$\@3D]4($-(04Y'12!!3EE42$E.1R!)3B!/
M4B!"149/4D4@5$A)4R!,24Y%+B`J+UQN(CL*"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%P<"`@
M5&AE(&YA;64@;V8@=&AE(&%P<&QI8V%T:6]N('1O(&)E(&-O;F9I9W5R960N
M"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7T-O;F9I9R@D87!P*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?87!P(#T@)&%P<#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E861S('1H92!A<'!L:6-A=&EO;B=S(&-O;F8N>&UL(&9I;&4@
M86YD(&)U:6QD<R!A;B!A<W-O8VEA=&EV92!A<G)A>0H@("`@("H@9G)O;2!I
M=',@6$U,('1R964N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1C=7-T
M;VU?8V]N9B`@($%N>2!S971T:6YG<R!T:&%T('-H86QL(&)E(&EN8VQU9&5D
M(&EN('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&=E
M;F5R871E9"!C;VYF:6=U<F%T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@($%N(&%S<V]C:6%T:79E(&%R<F%Y(')E<')E<V5N=&EN9R!T:&4@
M8V]N9FEG=7)A=&EO;B!T<F5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D
M6$U,0V]N9FEG*"1C=7-T;VU?8V]N9B`](&YU;&PI"B`@("!["B`@("`@("`@
M:68@*&ES7VYU;&PH)'1H:7,M/E]X;6Q#;VYF:6=4<F5E*2!\?"`D8W5S=&]M
M7V-O;F8I('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]497AT
M+G!H<"<["@H@("`@("`@("`@("!G;&]B86P@)')E9VES=')Y.PH@("`@("`@
M("`@("`D<&%T:"`]("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1T:&ES
M+3Y?87!P*2`N("<O8V]N9FEG)SL*"B`@("`@("`@("`@(&EF("@D8W5S=&]M
M7V-O;F8I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=$-O;F9I
M9R`]("1C=7-T;VU?8V]N9CL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("\J($9E=&-H('1H92!C=7)R96YT(&-O;F8N<&AP(&-O;G1E
M;G1S+B`J+PH@("`@("`@("`@("`@("`@0&5V86PH)'1H:7,M/F=E=%!(4$-O
M;F9I9R@I*3L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D8V]N9BDI('L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G1#;VYF:6<@/2`D
M8V]N9CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@+RH@3&]A9"!T:&4@1$]-(&]B:F5C="X@*B\*("`@("`@("`@("`@
M)&1O8R`]($AO<F1E7T-O;F9I9U]$;V-U;65N=#HZ9F%C=&]R>2@D<&%T:"`N
M("<O8V]N9BYX;6PG*3L*"B`@("`@("`@("`@("\J($-H96-K(&EF('1H97)E
M(&ES(&$@0U93('9E<G-I;VX@=&%G(&%N9"!S=&]R92!I="X@*B\*("`@("`@
M("`@("`@)&YO9&4@/2`D9&]C+3YF:7)S=%]C:&EL9"@I.PH@("`@("`@("`@
M("!W:&EL92`H(65M<'1Y*"1N;V1E*2D@>PH@("`@("`@("`@("`@("`@:68@
M*"1N;V1E+3YT>7!E(#T](%A-3%]#3TU-14Y47TY/1$4I('L*("`@("`@("`@
M("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UPD+BH_8V]N9EPN>&UL+'8@
M+BH_("XJ7"0O)RP@)&YO9&4M/FYO9&5?=F%L=64H*2P@)&UA=&-H*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9E<G-I;VY486<@/2`D
M;6%T8VA;,%T@+B`B7&XB.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D;F]D92`]("1N;V1E+3YN97AT7W-I8FQI;F<H*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@4&%R<V4@=&AE(&-O;F9I
M9R!F:6QE+B`J+PH@("`@("`@("`@("`D=&AI<RT^7WAM;$-O;F9I9U1R964@
M/2!A<G)A>2@I.PH@("`@("`@("`@("`D<F]O="`]("1D;V,M/G)O;W0H*3L*
M("`@("`@("`@("`@:68@*"1R;V]T+3YH87-?8VAI;&1?;F]D97,H*2D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P87)S94QE=F5L*"1T:&ES+3Y?>&UL
M0V]N9FEG5')E92P@)')O;W0M/F-H:6QD7VYO9&5S*"DL("<G*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?>&UL
M0V]N9FEG5')E93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M(&9I;&4@8V]N=&5N="!O9B!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N(&9I
M;&4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!U;G!A<G-E
M9"!C;VYF:6=U<F%T:6]N(&9I;&4@8V]N=&5N="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4$A00V]N9FEG*"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L
M;"@D=&AI<RT^7V]L9$-O;F9I9RDI('L*("`@("`@("`@("`@9VQO8F%L("1R
M96=I<W1R>3L*("`@("`@("`@("`@)'!A=&@@/2`D<F5G:7-T<GDM/F=E="@G
M9FEL97)O;W0G+"`D=&AI<RT^7V%P<"D@+B`G+V-O;F9I9R<["B`@("`@("`@
M("`@(&EF("AF:6QE7V5X:7-T<R@D<&%T:"`N("<O8V]N9BYP:'`G*2D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]O;&1#;VYF:6<@/2!F:6QE7V=E=%]C
M;VYT96YT<R@D<&%T:"`N("<O8V]N9BYP:'`G*3L*("`@("`@("`@("`@("`@
M(&EF("@A96UP='DH)'1H:7,M/E]O;&1#;VYF:6<I*2!["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]O;&1#;VYF:6<@/2!P<F5G7W)E<&QA8V4H)R\\
M7#]P:'!<;C\O)RP@)R<L("1T:&ES+3Y?;VQD0V]N9FEG*3L*("`@("`@("`@
M("`@("`@("`@("`D<&]S(#T@<W1R<&]S*"1T:&ES+3Y?;VQD0V]N9FEG+"`D
M=&AI<RT^7V-O;F9I9T)E9VEN*3L*("`@("`@("`@("`@("`@("`@("!I9B`H
M)'!O<R`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P<F5#;VYF:6<@/2!S=6)S='(H)'1H:7,M/E]O;&1#;VYF:6<L(#`L
M("1P;W,I.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V]L9$-O
M;F9I9R`]('-U8G-T<B@D=&AI<RT^7V]L9$-O;F9I9RP@)'!O<RD["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1P;W,@/2!S
M=')P;W,H)'1H:7,M/E]O;&1#;VYF:6<L("1T:&ES+3Y?8V]N9FEG16YD*3L*
M("`@("`@("`@("`@("`@("`@("!I9B`H)'!O<R`A/3T@9F%L<V4I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P;W-T0V]N9FEG(#T@<W5B
M<W1R*"1T:&ES+3Y?;VQD0V]N9FEG+"`D<&]S("L@<W1R;&5N*"1T:&ES+3Y?
M8V]N9FEG16YD*2D["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M;VQD0V]N9FEG(#T@<W5B<W1R*"1T:&ES+3Y?;VQD0V]N9FEG+"`P+"`D<&]S
M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]L
M9$-O;F9I9R`]("<G.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`D=&AI<RT^7V]L9$-O;F9I9SL*("`@('T*"B`@("`O*BH*("`@
M("`J($=E;F5R871E<R!T:&4@8V]N=&5N="!O9B!T:&4@87!P;&EC871I;VXG
M<R!C;VYF:6=U<F%T:6]N(&9I;&4N"B`@("`@*@H@("`@("H@0'!A<F%M(%9A
M<FEA8FQE<R`D9F]R;79A<G,@(%1H92!P<F]C97-S960@8V]N9FEG=7)A=&EO
M;B!F;W)M(&1A=&$N"B`@("`@*B!`<&%R86T@87)R87D@)&-U<W1O;5]C;VYF
M("`@06YY('-E='1I;F=S('1H870@<VAA;&P@8F4@:6YC;'5D960@:6X@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!C;VYT96YT(&]F('1H92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!F
M:6QE+@H@("`@("HO"B`@("!F=6YC=&EO;B!G96YE<F%T95!(4$-O;F9I9R@D
M9F]R;79A<G,L("1C=7-T;VU?8V]N9B`](&YU;&PI"B`@("!["B`@("`@("`@
M)'1H:7,M/G)E861834Q#;VYF:6<H)&-U<W1O;5]C;VYF*3L*("`@("`@("`D
M=&AI<RT^9V5T4$A00V]N9FEG*"D["@H@("`@("`@("1T:&ES+3Y?<&AP0V]N
M9FEG(#T@(CP_<&AP7&XB.PH@("`@("`@("1T:&ES+3Y?<&AP0V]N9FEG("X]
M("1T:&ES+3Y?<')E0V]N9FEG.PH@("`@("`@("1T:&ES+3Y?<&AP0V]N9FEG
M("X]("1T:&ES+3Y?8V]N9FEG0F5G:6X["B`@("`@("`@:68@*"%E;7!T>2@D
M=&AI<RT^7W9E<G-I;VY486<I*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&AP
M0V]N9FEG("X]("<O+R`G("X@)'1H:7,M/E]V97)S:6]N5&%G.PH@("`@("`@
M('T*("`@("`@("`D=&AI<RT^7V=E;F5R871E4$A00V]N9FEG*"1T:&ES+3Y?
M>&UL0V]N9FEG5')E92P@)R<L("1F;W)M=F%R<RD["B`@("`@("`@)'1H:7,M
M/E]P:'!#;VYF:6<@+CT@)'1H:7,M/E]C;VYF:6=%;F0["B`@("`@("`@)'1H
M:7,M/E]P:'!#;VYF:6<@+CT@)'1H:7,M/E]P;W-T0V]N9FEG.PH*("`@("`@
M("!R971U<FX@)'1H:7,M/E]P:'!#;VYF:6<["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!'96YE<F%T97,@=&AE(&-O;F9I9W5R871I;VX@9FEL92!I=&5M<R!F
M;W(@82!P87)T(&]F('1H92!C;VYF:6=U<F%T:6]N"B`@("`@*B!T<F5E+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`D<V5C=&EO;B`@06X@87-S;V-I871I=F4@87)R87D@8V]N
M=&%I;FEN9R!T:&4@<&%R="!O9B!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@=')A=F5R<V5D(%A-3"!C;VYF:6=U<F%T:6]N('1R964@=&AA
M="!S:&]U;&0@8F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@<')O
M8V5S<V5D+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E9FEX("!!(&-O;F9I
M9W5R871I;VX@<')E9FEX(&1E=&5R;6EN:6YG('1H92!C=7)R96YT"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@('!O<VET:6]N(&EN<VED92!T:&4@
M8V]N9FEG=7)A=&EO;B!F:6QE+B!4:&ES"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@('!R969I>"!W:6QL(&)E('1R86YS;&%T960@=&\@:V5Y<R!O
M9B!T:&4@)&-O;F8*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87D@:6X@=&AE(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&9I;&4N"B`@("`@
M*B!`<&%R86T@5F%R:6%B;&5S("1F;W)M=F%R<R`@5&AE('!R;V-E<W-E9"!C
M;VYF:6=U<F%T:6]N(&9O<FT@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V=E;F5R871E4$A00V]N9FEG*"1S96-T:6]N+"`D<')E9FEX+"`D9F]R;79A
M<G,I"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D<V5C=&EO;BDI('L*
M("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C
M:"`H)'-E8W1I;VX@87,@)&YA;64@/3X@)&-O;F9I9VET96TI('L*("`@("`@
M("`@("`@)'!R969I>&5D;F%M92`](&5M<'1Y*"1P<F5F:7@I(#\@)&YA;64@
M.B`D<')E9FEX("X@)WPG("X@)&YA;64["B`@("`@("`@("`@("1C;VYF:6=N
M86UE(#T@<W1R7W)E<&QA8V4H)WPG+"`G7U\G+"`D<')E9FEX961N86UE*3L*
M("`@("`@("`@("`@)'%U;W1E(#T@(6ES<V5T*"1C;VYF:6=I=&5M6R=Q=6]T
M92==*2!\?"`D8V]N9FEG:71E;5LG<75O=&4G72`A/3T@9F%L<V4["B`@("`@
M("`@("`@(&EF("@D8V]N9FEG:71E;2`]/2`G<&QA8V5H;VQD97(G*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!H<$-O;F9I9R`N/2`G)&-O;F9;7"<G
M("X@<W1R7W)E<&QA8V4H)WPG+"`G7"==6UPG)RP@)'!R969I>"D@+B`B)UT@
M/2!A<G)A>2@I.UQN(CL*("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1C
M;VYF:6=I=&5M6R=S=VET8V@G72DI('L*("`@("`@("`@("`@("`@("1V86P@
M/2`D9F]R;79A<G,M/F=E=$5X:7-T<R@D8V]N9FEG;F%M92P@)'=A<W-E="D[
M"B`@("`@("`@("`@("`@("!I9B`H(21W87-S970I('L*("`@("`@("`@("`@
M("`@("`@("`D=F%L(#T@:7-S970H)&-O;F9I9VET96U;)V1E9F%U;'0G72D@
M/R`D8V]N9FEG:71E;5LG9&5F875L="==(#H@;G5L;#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D8V]N9FEG:71E;5LG
M<W=I=&-H)UU;)'9A;%TI*2!["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E
M(#T@)'9A;#L*("`@("`@("`@("`@("`@("`@("!I9B`H)'%U;W1E("8F("1V
M86QU92`A/2`G=')U92<@)B8@)'9A;'5E("$]("=F86QS92<I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@(B<B("X@)'9A;'5E("X@(B<B
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V=E;F5R871E4$A00V]N9FEG*"1C;VYF:6=I=&5M6R=S=VET8V@G
M75LD=F%L75LG9FEE;&1S)UTL("1P<F5F:7@L("1F;W)M=F%R<RD["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D8V]N
M9FEG:71E;5LG7W1Y<&4G72DI('L*("`@("`@("`@("`@("`@("1V86P@/2`D
M9F]R;79A<G,M/F=E=$5X:7-T<R@D8V]N9FEG;F%M92P@)'=A<W-E="D["B`@
M("`@("`@("`@("`@("!I9B`H(21W87-S970I('L*("`@("`@("`@("`@("`@
M("`@("`D=F%L(#T@:7-S970H)&-O;F9I9VET96U;)V1E9F%U;'0G72D@/R`D
M8V]N9FEG:71E;5LG9&5F875L="==(#H@;G5L;#L*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`D='EP92`]("1C;VYF:6=I=&5M6R=?='EP
M92==.PH@("`@("`@("`@("`@("`@<W=I=&-H("@D='EP92D@>PH@("`@("`@
M("`@("`@("`@8V%S92`G;75L=&EE;G5M)SH*("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-?87)R87DH)'9A;"DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&5N8W9A;',@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D=F%L(&%S("1V*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D96YC=F%L<UM=(#T@)'1H:7,M/E]Q=6]T92@D=BD["B`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@
M)&%R<F%Y=F%L(#T@(B<B("X@:6UP;&]D92@G7"<L(%PG)RP@)&5N8W9A;',I
M("X@(B<B.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&%R<F%Y=F%L
M(#T]("(G)R(I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A<G)A
M>79A;"`]("<G.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&%R<F%Y=F%L(#T@)R<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("1V86QU92`]("=A<G)A>2@G("X@)&%R<F%Y=F%L("X@
M)RDG.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M("`@(&-A<V4@)V)O;VQE86XG.@H@("`@("`@("`@("`@("`@("`@(&EF("AI
M<U]B;V]L*"1V86PI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU
M92`]("1V86P@/R`G=')U92<@.B`G9F%L<V4G.PH@("`@("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`]
M("@D=F%L(#T]("=O;B<I(#\@)W1R=64G(#H@)V9A;'-E)SL*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("`@("`@8V%S92`G<W1R:6YG;&ES="<Z"B`@("`@("`@("`@("`@
M("`@("`@)'9A;'5E<R`](&5X<&QO9&4H)RPG+"`D=F%L*3L*("`@("`@("`@
M("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1V86QU97,I*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1V86QU92`](")A<G)A>2@G(B`N("1T:&ES+3Y?
M<75O=&4H=')I;2@D=F%L=65S*2D@+B`B)RDB.PH@("`@("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1E;F-V86QS
M(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)'9A;'5E<R!A<R`D=BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&5N8W9A;'-;72`]("1T:&ES+3Y?<75O=&4H=')I;2@D=BDI.PH@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1A
M<G)A>79A;"`]("(G(B`N(&EM<&QO9&4H)UPG+"!<)R<L("1E;F-V86QS*2`N
M("(G(CL*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1A<G)A>79A;"`]
M/2`B)R<B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D87)R87EV
M86P@/2`G)SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@("`@("`D=F%L=64@/2`G87)R87DH)R`N("1A<G)A>79A;"`N
M("<I)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G:6YT)SH*("`@("`@
M("`@("`@("`@("`@("!I9B`H)'9A;"`A/3T@)R<I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'9A;'5E(#T@*&EN="DD=F%L.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("`@("!C87-E("=O8W1A;"<Z"B`@("`@("`@("`@("`@("`@("`@)'9A
M;'5E(#T@<W!R:6YT9B@G,"5O)RP@;V-T9&5C*"1V86PI*3L*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=H96%D
M97(G.@H@("`@("`@("`@("`@("`@8V%S92`G9&5S8W)I<'1I;VXG.@H@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&1E9F%U
M;'0Z"B`@("`@("`@("`@("`@("`@("`@:68@*"1V86P@(3T@)R<I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@)'9A;#L*("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"1Q=6]T92`F)B`D=F%L=64@(3T@)W1R=64G
M("8F("1V86QU92`A/2`G9F%L<V4G*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=F%L=64@/2`B)R(@+B`D=&AI<RT^7W%U;W1E*"1V86QU92D@
M+B`B)R(["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V=E;F5R871E4$A00V]N9FEG*"1C;VYF:6=I=&5M+"`D<')E
M9FEX961N86UE+"`D9F]R;79A<G,I.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!I9B`H:7-S970H)'9A;'5E*2D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P:'!#;VYF:6<@+CT@)R1C;VYF6UPG)R`N('-T<E]R97!L86-E*"=?
M7R<L("=<)UU;7"<G+"`D8V]N9FEG;F%M92D@+B`G7"==(#T@)R`N("1V86QU
M92`N("([7&XB.PH@("`@("`@("`@("!]"B`@("`@("`@("`@('5N<V5T*"1V
M86QU92D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4&%R<V5S
M(&]N92!L979E;"!O9B!T:&4@8V]N9FEG=7)A=&EO;B!834P@=')E92!I;G1O
M('1H92!A<W-O8VEA=&EV90H@("`@("H@87)R87D@8V]N=&%I;FEN9R!T:&4@
M=')A=F5R<V5D(&-O;F9I9W5R871I;VX@=')E92X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)B1C
M;VYF("`@("!4:&4@86QR96%D>2!E>&ES=&EN9R!A<G)A>2!W:&5R92!T:&4@
M<')O8V5S<V5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!834P@
M=')E92!P;W)T:6]N('-H;W5L9"!B92!A<'!E;F1E9"!T;RX*("`@("`J($!P
M87)A;2!A<G)A>2`D8VAI;&1R96X@($%N(&%R<F%Y(&-O;G1A:6YI;F<@=&AE
M(%A-3"!N;V1E<R!O9B!T:&4@;&5V96P*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@('1H870@<VAO=6QD(&)E('!A<G-E9"X*("`@("`J($!P87)A
M;2!S=')I;F<@)&-T>"`@("`@($$@<W1R:6YG(')E<')E<V5N=&EN9R!T:&4@
M8W5R<F5N="!P;W-I=&EO;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@*&-O;G1E>'0@<')E9FEX*2!I;G-I9&4@=&AE(&-O;F9I9W5R871I;VX@
M6$U,"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!F:6QE+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?<&%R<V5,979E;"@F)&-O;F8L("1C:&EL9')E
M;BP@)&-T>"D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U1E
M>'0O1FEL=&5R+G!H<"<["@H@("`@("`@(&9O<F5A8V@@*"1C:&EL9')E;B!A
M<R`D;F]D92D@>PH@("`@("`@("`@("!I9B`H)&YO9&4M/G1Y<&4@(3T@6$U,
M7T5,14U%3E1?3D]$12D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&YA;64@/2`D;F]D92T^9V5T7V%T
M=')I8G5T92@G;F%M92<I.PH@("`@("`@("`@("`D9&5S8R`](%1E>'1?1FEL
M=&5R.CIF:6QT97(H)&YO9&4M/F=E=%]A='1R:6)U=&4H)V1E<V,G*2P@)VQI
M;FMU<FQS)RP@87)R87DH)V-A;&QB86-K)R`]/B`G2&]R9&4Z.F5X=&5R;F%L
M57)L)RDI.PH@("`@("`@("`@("`D<F5Q=6ER960@/2`A*"1N;V1E+3YG971?
M871T<FEB=71E*"=R97%U:7)E9"<I(#T]("=F86QS92<I.PH@("`@("`@("`@
M("`D<75O=&4@/2`A*"1N;V1E+3YG971?871T<FEB=71E*"=Q=6]T92<I(#T]
M("=F86QS92<I.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1C='@I*2!["B`@
M("`@("`@("`@("`@("`D8W5R8W1X(#T@)&-T>"`N("=\)R`N("1N86UE.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&-U<F-T>"`]
M("1N86UE.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!S=VET8V@@*"1N
M;V1E+3YT86=N86UE*2!["B`@("`@("`@("`@(&-A<V4@)V-O;F9I9V1E<V-R
M:7!T:6]N)SH*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D;F%M92DI('L*
M("`@("`@("`@("`@("`@("`@("`D;F%M92`](&UD-2AM:6-R;W1I;64H*2D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D8V]N9ELD;F%M
M95T@/2!A<G)A>2@G7W1Y<&4G(#T^("=D97-C<FEP=&EO;B<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@5&5X=%]&
M:6QT97(Z.F9I;'1E<B@D=&AI<RT^7V1E9F%U;'0H)&-U<F-T>"P@)'1H:7,M
M/E]G971.;V1E3VYL>51E>'0H)&YO9&4I*2P@)VQI;FMU<FQS)RP@87)R87DH
M)V-A;&QB86-K)R`]/B`G2&]R9&4Z.F5X=&5R;F%L57)L)RDI*3L*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G8V]N9FEG:&5A
M9&5R)SH*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D;F%M92DI('L*("`@
M("`@("`@("`@("`@("`@("`D;F%M92`](&UD-2AM:6-R;W1I;64H*2D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D8V]N9ELD;F%M95T@
M/2!A<G)A>2@G7W1Y<&4G(#T^("=H96%D97(G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("1T:&ES+3Y?9&5F875L
M="@D8W5R8W1X+"`D=&AI<RT^7V=E=$YO9&5/;FQY5&5X="@D;F]D92DI*3L*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G8V]N
M9FEG<W=I=&-H)SH*("`@("`@("`@("`@("`@("1V86QU97,@/2`D=&AI<RT^
M7V=E=%-W:71C:%9A;'5E<R@D;F]D92P@)&-T>"D["B`@("`@("`@("`@("`@
M("!I9B`H)'%U;W1E*2!["B`@("`@("`@("`@("`@("`@("`@)&1E9F%U;'0@
M/2`D=&AI<RT^7V1E9F%U;'0H)&-U<F-T>"P@)'1H:7,M/E]G971.;V1E3VYL
M>51E>'0H)&YO9&4I*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)&1E9F%U;'0@/2`D=&AI<RT^7V1E9F%U;'1287<H
M)&-U<F-T>"P@)'1H:7,M/E]G971.;V1E3VYL>51E>'0H)&YO9&4I*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@D9&5F875L="`]
M/3T@)R<I('L*("`@("`@("`@("`@("`@("`@("`D9&5F875L="`](&ME>2@D
M=F%L=65S*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF
M("AI<U]B;V]L*"1D969A=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@("1D
M969A=6QT(#T@)&1E9F%U;'0@/R`G=')U92<@.B`G9F%L<V4G.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&-O;F9;)&YA;65=(#T@87)R
M87DH)V1E<V,G(#T^("1D97-C+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W-W:71C:"<@/3X@)'9A;'5E<RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B`D9&5F875L
M="D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@
M)V-O;F9I9V5N=6TG.@H@("`@("`@("`@("`@("`@)'9A;'5E<R`]("1T:&ES
M+3Y?9V5T16YU;59A;'5E<R@D;F]D92D["B`@("`@("`@("`@("`@("!I9B`H
M)'%U;W1E*2!["B`@("`@("`@("`@("`@("`@("`@)&1E9F%U;'0@/2`D=&AI
M<RT^7V1E9F%U;'0H)&-U<F-T>"P@)'1H:7,M/E]G971.;V1E3VYL>51E>'0H
M)&YO9&4I*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@)&1E9F%U;'0@/2`D=&AI<RT^7V1E9F%U;'1287<H)&-U<F-T
M>"P@)'1H:7,M/E]G971.;V1E3VYL>51E>'0H)&YO9&4I*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@D9&5F875L="`]/3T@)R<I
M('L*("`@("`@("`@("`@("`@("`@("`D9&5F875L="`](&ME>2@D=F%L=65S
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("AI<U]B
M;V]L*"1D969A=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@("1D969A=6QT
M(#T@)&1E9F%U;'0@/R`G=')U92<@.B`G9F%L<V4G.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)&-O;F9;)&YA;65=(#T@87)R87DH)U]T
M>7!E)R`]/B`G96YU;2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<F5Q=6ER960G(#T^("1R97%U:7)E9"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=Q=6]T92<@/3X@)'%U;W1E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9A;'5E<R<@
M/3X@)'9A;'5E<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=D97-C)R`]/B`D9&5S8RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=D969A=6QT)R`]/B`D9&5F875L="D["B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V-O;F9I9VQI<W0G
M.@H@("`@("`@("`@("`@("`@)&1E9F%U;'0@/2`D=&AI<RT^7V1E9F%U;'0H
M)&-U<F-T>"P@;G5L;"D["B`@("`@("`@("`@("`@("!I9B`H)&1E9F%U;'0@
M/3T](&YU;&PI('L*("`@("`@("`@("`@("`@("`@("`D9&5F875L="`]("1T
M:&ES+3Y?9V5T3F]D94]N;'E497AT*"1N;V1E*3L*("`@("`@("`@("`@("`@
M('T@96QS96EF("AI<U]A<G)A>2@D9&5F875L="DI('L*("`@("`@("`@("`@
M("`@("`@("`D9&5F875L="`](&EM<&QO9&4H)RP@)RP@)&1E9F%U;'0I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&-O;F9;)&YA;65=
M(#T@87)R87DH)U]T>7!E)R`]/B`G<W1R:6YG;&ES="<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5Q=6ER960G(#T^("1R97%U
M:7)E9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D
M97-C)R`]/B`D9&5S8RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=D969A=6QT)R`]/B`D9&5F875L="D["B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V-O;F9I9VUU;'1I96YU;2<Z
M"B`@("`@("`@("`@("`@("`D=F%L=65S(#T@)'1H:7,M/E]G971%;G5M5F%L
M=65S*"1N;V1E*3L*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O07)R87DN<&AP)SL*("`@("`@("`@("`@("`@("1C;VYF6R1N86UE72`]
M(&%R<F%Y*"=?='EP92<@/3X@)VUU;'1I96YU;2<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<F5Q=6ER960G(#T^("1R97%U:7)E
M9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V86QU
M97,G(#T^("1V86QU97,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G9&5S8R<@/3X@)&1E<V,L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@2&]R9&5?07)R87DZ.G9A
M;'5E<U1O2V5Y<R@D=&AI<RT^7V1E9F%U;'0H)&-U<F-T>"P@97AP;&]D92@G
M+"<L("1T:&ES+3Y?9V5T3F]D94]N;'E497AT*"1N;V1E*2DI*2D["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V-O;F9I9W!A
M<W-W;W)D)SH*("`@("`@("`@("`@("`@("1C;VYF6R1N86UE72`](&%R<F%Y
M*"=?='EP92<@/3X@)W!A<W-W;W)D)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=R97%U:7)E9"<@/3X@)')E<75I<F5D+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("1D
M97-C+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E
M9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D8W5R8W1X+"`D=&AI<RT^7V=E
M=$YO9&5/;FQY5&5X="@D;F]D92DI*3L*("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@8V%S92`G8V]N9FEG<W1R:6YG)SH*("`@("`@("`@
M("`@("`@("1C;VYF6R1N86UE72`](&%R<F%Y*"=?='EP92<@/3X@)W1E>'0G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E<75I
M<F5D)R`]/B`D<F5Q=6ER960L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G9&5S8R<@/3X@)&1E<V,L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@)'1H:7,M/E]D969A
M=6QT*"1C=7)C='@L("1T:&ES+3Y?9V5T3F]D94]N;'E497AT*"1N;V1E*2DI
M.PH@("`@("`@("`@("`@("`@:68@*"1C;VYF6R1N86UE75LG9&5F875L="==
M(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@("1C;VYF6R1N86UE
M75LG9&5F875L="==(#T@)V9A;'-E)SL*("`@("`@("`@("`@("`@('T@96QS
M96EF("@D8V]N9ELD;F%M95U;)V1E9F%U;'0G72`]/3T@=')U92D@>PH@("`@
M("`@("`@("`@("`@("`@("1C;VYF6R1N86UE75LG9&5F875L="==(#T@)W1R
M=64G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("!C87-E("=C;VYF:6=B;V]L96%N)SH*("`@("`@("`@
M("`@("`@("1D969A=6QT(#T@)'1H:7,M/E]G971.;V1E3VYL>51E>'0H)&YO
M9&4I.PH@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1D969A=6QT*2!\?"`D
M9&5F875L="`]/3T@)V9A;'-E)RD@>PH@("`@("`@("`@("`@("`@("`@("1D
M969A=6QT(#T@9F%L<V4["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("1D969A=6QT(#T@=')U93L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("1C;VYF6R1N86UE72`](&%R<F%Y*"=?
M='EP92<@/3X@)V)O;VQE86XG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W)E<75I<F5D)R`]/B`D<F5Q=6ER960L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)&1E<V,L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L
M="<@/3X@)'1H:7,M/E]D969A=6QT*"1C=7)C='@L("1D969A=6QT*2D["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V-O;F9I
M9VEN=&5G97(G.@H@("`@("`@("`@("`@("`@)'9A;'5E<R`]("1T:&ES+3Y?
M9V5T16YU;59A;'5E<R@D;F]D92D["B`@("`@("`@("`@("`@("`D8V]N9ELD
M;F%M95T@/2!A<G)A>2@G7W1Y<&4G(#T^("=I;G0G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W)E<75I<F5D)R`]/B`D<F5Q=6ER
M960L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=F%L
M=65S)R`]/B`D=F%L=65S+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V1E<V,G(#T^("1D97-C+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L
M="@D8W5R8W1X+"`D=&AI<RT^7V=E=$YO9&5/;FQY5&5X="@D;F]D92DI*3L*
M("`@("`@("`@("`@("`@(&EF("@D;F]D92T^9V5T7V%T=')I8G5T92@G;V-T
M86PG*2`]/2`G=')U92<@)B8*("`@("`@("`@("`@("`@("`@("`D8V]N9ELD
M;F%M95U;)V1E9F%U;'0G72`A/2`G)RD@>PH@("`@("`@("`@("`@("`@("`@
M("1C;VYF6R1N86UE75LG7W1Y<&4G72`]("=O8W1A;"<["B`@("`@("`@("`@
M("`@("`@("`@)&-O;F9;)&YA;65=6R=D969A=6QT)UT@/2!S<')I;G1F*"<P
M)6\G+"`D=&AI<RT^7V1E9F%U;'0H)&-U<F-T>"P@;V-T9&5C*"1T:&ES+3Y?
M9V5T3F]D94]N;'E497AT*"1N;V1E*2DI*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G8V]N
M9FEG<&AP)SH*("`@("`@("`@("`@("`@("1C;VYF6R1N86UE72`](&%R<F%Y
M*"=?='EP92<@/3X@)W!H<"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<F5Q=6ER960G(#T^("1R97%U:7)E9"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=Q=6]T92<@/3X@9F%L<V4L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@
M/3X@)&1E<V,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G9&5F875L="<@/3X@)'1H:7,M/E]D969A=6QT4F%W*"1C=7)C='@L("1T
M:&ES+3Y?9V5T3F]D94]N;'E497AT*"1N;V1E*2DI.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=C;VYF:6=S<6PG.@H@("`@
M("`@("`@("`@("`@)&-O;F9;)&YO9&4M/F=E=%]A='1R:6)U=&4H)W-W:71C
M:&YA;64G*5T@/2`D=&AI<RT^7V-O;F9I9U-13"@D8W1X+"`D;F]D92D["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V-O;F9I
M9W9F<R<Z"B`@("`@("`@("`@("`@("`D8V]N9ELD;F]D92T^9V5T7V%T=')I
M8G5T92@G<W=I=&-H;F%M92<I72`]("1T:&ES+3Y?8V]N9FEG5D93*"1C='@L
M("1N;V1E*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M8V%S92`G8V]N9FEG<V5C=&EO;B<Z"B`@("`@("`@("`@("`@("`D8V]N9ELD
M;F%M95T@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@)&-U<B`]("8D8V]N
M9ELD;F%M95T["B`@("`@("`@("`@("`@("!I9B`H)&YO9&4M/FAA<U]C:&EL
M9%]N;V1E<R@I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)S
M94QE=F5L*"1C=7(L("1N;V1E+3YC:&EL9%]N;V1E<R@I+"`D8W5R8W1X*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`G8V]N9FEG=&%B)SH*("`@("`@("`@("`@("`@("1K
M97D@/2!M9#4H;6EC<F]T:6UE*"DI.PH@("`@("`@("`@("`@("`@)&-O;F9;
M)&ME>5T@/2!A<G)A>2@G=&%B)R`]/B`D;F%M92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("1D97-C*3L*("`@("`@
M("`@("`@("`@(&EF("@D;F]D92T^:&%S7V-H:6QD7VYO9&5S*"DI('L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<G-E3&5V96PH)&-O;F8L("1N
M;V1E+3YC:&EL9%]N;V1E<R@I+"`D8W1X*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G8V]N
M9FEG<&QA8V5H;VQD97(G.@H@("`@("`@("`@("`@("`@)&-O;F9;;60U*&UI
M8W)O=&EM92@I*5T@/2`G<&QA8V5H;VQD97(G.PH@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@
M)&-O;F9;)&YA;65=(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("1C=7(@
M/2`F)&-O;F9;)&YA;65=.PH@("`@("`@("`@("`@("`@:68@*"1N;V1E+3YH
M87-?8VAI;&1?;F]D97,H*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R<V5,979E;"@D8W5R+"`D;F]D92T^8VAI;&1?;F]D97,H*2P@)&-U
M<F-T>"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE(&-O;F9I9W5R871I;VX@=')E92!F;W(@86X@4U%,
M(&)A8VME;F0@8V]N9FEG=7)A=&EO;B!T;PH@("`@("H@<F5P;&%C92!A(#QC
M;VYF:6=S<6P^('1A9RX*("`@("`J(%-U8FYO9&5S('=I;&P@8F4@<&%R<V5D
M(&%N9"!A9&1E9"!T;R!B;W1H('1H92!(;W)D92!D969A=6QT<R!A;F0@=&AE
M"B`@("`@*B!#=7-T;VT@8V]N9FEG=7)A=&EO;B!P87)T<RX*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1C='@@("`@("`@("!4:&4@8V]N=&5X="!O9B!T:&4@/&-O;F9I9W-Q
M;#X@=&%G+@H@("`@("H@0'!A<F%M($1O;4YO9&4@)&YO9&4@("`@("`@5&AE
M($1O;4YO9&4@<F5P<F5S96YT871I;VX@;V8@=&AE(#QC;VYF:6=S<6P^"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!T86<N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1S=VET8VAN86UE("!)9B!$;VU.;V1E(&ES(&YO="!S
M970L('1H92!V86QU92!O9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('1A9R=S('-W:71C:&YA;64@871T<FEB=71E+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@($%N(&%S<V]C:6%T:79E(&%R<F%Y('=I
M=&@@=&AE(%-13"!C;VYF:6=U<F%T:6]N('1R964N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]C;VYF:6=344PH)&-T>"P@)&YO9&4@/2!N=6QL+"`D<W=I=&-H
M;F%M92`]("=D<FEV97)C;VYF:6<G*0H@("`@>PH@("`@("`@("1P97)S:7-T
M96YT(#T@87)R87DH"B`@("`@("`@("`@("=?='EP92<@/3X@)V)O;VQE86XG
M+`H@("`@("`@("`@("`G<F5Q=6ER960G(#T^(&9A;'-E+`H@("`@("`@("`@
M("`G9&5S8R<@/3X@)U)E<75E<W0@<&5R<VES=&5N="!C;VYN96-T:6]N<S\G
M+`H@("`@("`@("`@("`G9&5F875L="<@/3X@)'1H:7,M/E]D969A=6QT*"1C
M='@@+B`G?'!E<G-I<W1E;G0G+"!F86QS92DI.PH@("`@("`@("1H;W-T<W!E
M8R`](&%R<F%Y*`H@("`@("`@("`@("`G7W1Y<&4G(#T^("=T97AT)RP*("`@
M("`@("`@("`@)W)E<75I<F5D)R`]/B!T<G5E+`H@("`@("`@("`@("`G9&5S
M8R<@/3X@)T1A=&%B87-E('-E<G9E<B]H;W-T)RP*("`@("`@("`@("`@)V1E
M9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D8W1X("X@)WQH;W-T<W!E8R<L
M("<G*2D["B`@("`@("`@)'5S97)N86UE(#T@87)R87DH"B`@("`@("`@("`@
M("=?='EP92<@/3X@)W1E>'0G+`H@("`@("`@("`@("`G<F5Q=6ER960G(#T^
M('1R=64L"B`@("`@("`@("`@("=D97-C)R`]/B`G57-E<FYA;64@=&\@8V]N
M;F5C="!T;R!T:&4@9&%T86)A<V4@87,G+`H@("`@("`@("`@("`G9&5F875L
M="<@/3X@)'1H:7,M/E]D969A=6QT*"1C='@@+B`G?'5S97)N86UE)RP@)R<I
M*3L*("`@("`@("`D<&%S<W=O<F0@/2!A<G)A>2@*("`@("`@("`@("`@)U]T
M>7!E)R`]/B`G=&5X="<L"B`@("`@("`@("`@("=R97%U:7)E9"<@/3X@9F%L
M<V4L"B`@("`@("`@("`@("=D97-C)R`]/B`G4&%S<W=O<F0@=&\@8V]N;F5C
M="!W:71H)RP*("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F
M875L="@D8W1X("X@)WQP87-S=V]R9"<L("<G*2D["B`@("`@("`@)&1A=&%B
M87-E(#T@87)R87DH"B`@("`@("`@("`@("=?='EP92<@/3X@)W1E>'0G+`H@
M("`@("`@("`@("`G<F5Q=6ER960G(#T^('1R=64L"B`@("`@("`@("`@("=D
M97-C)R`]/B`G1&%T86)A<V4@;F%M92!T;R!U<V4G+`H@("`@("`@("`@("`G
M9&5F875L="<@/3X@)'1H:7,M/E]D969A=6QT*"1C='@@+B`G?&1A=&%B87-E
M)RP@)R<I*3L*("`@("`@("`D<V]C:V5T(#T@87)R87DH"B`@("`@("`@("`@
M("=?='EP92<@/3X@)W1E>'0G+`H@("`@("`@("`@("`G<F5Q=6ER960G(#T^
M(&9A;'-E+`H@("`@("`@("`@("`G9&5S8R<@/3X@)TQO8V%T:6]N(&]F(%5.
M25@@<V]C:V5T)RP*("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?
M9&5F875L="@D8W1X("X@)WQS;V-K970G+"`G)RDI.PH@("`@("`@("1P;W)T
M(#T@87)R87DH"B`@("`@("`@("`@("=?='EP92<@/3X@)VEN="<L"B`@("`@
M("`@("`@("=R97%U:7)E9"<@/3X@9F%L<V4L"B`@("`@("`@("`@("=D97-C
M)R`]/B`G4&]R="!T:&4@1$(@:7,@<G5N;FEN9R!O;BP@:68@;F]N+7-T86YD
M87)D)RP*("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L
M="@D8W1X("X@)WQP;W)T)RP@;G5L;"DI.PH@("`@("`@("1P<F]T;V-O;"`]
M(&%R<F%Y*`H@("`@("`@("`@("`G9&5S8R<@/3X@)TAO=R!S:&]U;&0@=V4@
M8V]N;F5C="!T;R!T:&4@9&%T86)A<V4_)RP*("`@("`@("`@("`@)V1E9F%U
M;'0G(#T^("1T:&ES+3Y?9&5F875L="@D8W1X("X@)WQP<F]T;V-O;"<L("=U
M;FEX)RDL"B`@("`@("`@("`@("=S=VET8V@G(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`@("`@)W5N:7@G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@
M("=D97-C)R`]/B`G54Y)6"!3;V-K971S)RP*("`@("`@("`@("`@("`@("`@
M("`G9FEE;&1S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@
M)W-O8VME="<@/3X@)'-O8VME="DI+`H@("`@("`@("`@("`@("`@)W1C<"<@
M/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=40U`O
M25`G+`H@("`@("`@("`@("`@("`@("`@("=F:65L9',G(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`@("`G<&]R="<@/3X@)'!O<G0I*2DI.PH@
M("`@("`@("1M>7-Q;%]P<F]T;V-O;"`]("1P<F]T;V-O;#L*("`@("`@("`D
M;7ES<6Q?<')O=&]C;VQ;)W-W:71C:"==6R=T8W`G75LG9FEE;&1S)UU;)W!O
M<G0G75LG9&5F875L="==(#T@)'1H:7,M/E]D969A=6QT*"1C='@@+B`G?'!O
M<G0G+"`S,S`V*3L*("`@("`@("`D8VAA<G-E="`](&%R<F%Y*`H@("`@("`@
M("`@("`G7W1Y<&4G(#T^("=T97AT)RP*("`@("`@("`@("`@)W)E<75I<F5D
M)R`]/B!T<G5E+`H@("`@("`@("`@("`G9&5S8R<@/3X@)TEN=&5R;F%L;'D@
M=7-E9"!C:&%R<V5T)RP*("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES
M+3Y?9&5F875L="@D8W1X("X@)WQC:&%R<V5T)RP@)VES;RTX.#4Y+3$G*2D[
M"@H@("`@("`@("1O8VDX7V9I96QD<R`](&%R<F%Y*`H@("`@("`@("`@("`G
M<&5R<VES=&5N="<@/3X@)'!E<G-I<W1E;G0L"B`@("`@("`@("`@("=U<V5R
M;F%M92<@/3X@)'5S97)N86UE+`H@("`@("`@("`@("`G<&%S<W=O<F0G(#T^
M("1P87-S=V]R9"D["B`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G;V-I
M7V-O;FYE8W0G*2D@>PH@("`@("`@("`@("`D;V-I.%]F:65L9'-;)V1A=&%B
M87-E)UT@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=?='EP92<@/3X@)W1E
M>'0G+`H@("`@("`@("`@("`@("`@)W)E<75I<F5D)R`]/B!T<G5E+`H@("`@
M("`@("`@("`@("`@)V1E<V,G(#T^("=$871A8F%S92!N86UE(&]R($5A<WD@
M0V]N;F5C="!P87)A;65T97(G+`H@("`@("`@("`@("`@("`@)V1E9F%U;'0G
M(#T^("1T:&ES+3Y?9&5F875L="@D8W1X("X@)WQD871A8F%S92<L("=H;W)D
M92<I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;V-I.%]F:65L
M9'-;)VAO<W1S<&5C)UT@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=?='EP
M92<@/3X@)W1E>'0G+`H@("`@("`@("`@("`@("`@)W)E<75I<F5D)R`]/B!T
M<G5E+`H@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=$871A8F%S92!N86UE
M(&]R($5A<WD@0V]N;F5C="!P87)A;65T97(G+`H@("`@("`@("`@("`@("`@
M)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D8W1X("X@)WQH;W-T<W!E
M8R<L("=H;W)D92<I*3L*("`@("`@("!]"B`@("`@("`@)&]C:3A?9FEE;&1S
M6R=C:&%R<V5T)UT@/2`D8VAA<G-E=#L*"B`@("`@("`@)&-U<W1O;5]F:65L
M9',@/2!A<G)A>2@*("`@("`@("`@("`@)W)E<75I<F5D)R`]/B!T<G5E+`H@
M("`@("`@("`@("`G9&5S8R<@/3X@)U=H870@9&%T86)A<V4@8F%C:V5N9"!S
M:&]U;&0@=V4@=7-E/R<L"B`@("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI
M<RT^7V1E9F%U;'0H)&-T>"`N("=\<&AP='EP92<L("=F86QS92<I+`H@("`@
M("`@("`@("`G<W=I=&-H)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("=F
M86QS92<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^
M("=;3F]N95TG+`H@("`@("`@("`@("`@("`@("`@("=F:65L9',G(#T^(&%R
M<F%Y*"DI+`H@("`@("`@("`@("`@("`@)V1B87-E)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)V1"87-E)RP*("`@("`@("`@
M("`@("`@("`@("`G9FEE;&1S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`@("`@)V1A=&%B87-E)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=?='EP92<@/3X@)W1E>'0G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W)E<75I<F5D)R`]/B!T<G5E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=!8G-O;'5T92!P871H('1O
M('1H92!D871A8F%S92!F:6QE)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\9&%T
M86)A<V4G+"`G)RDI+`H@("`@("`@("`@("`@("`@("`@("`@("`G;6]D92<@
M/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G7W1Y<&4G
M(#T^("=E;G5M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D97-C
M)R`]/B`G5&AE(&UO9&4@=&\@;W!E;B!T:&4@9FEL92!W:71H)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=V86QU97,G(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#`@/3X@)U)E860@3VYL>2<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,B`]/B`G4F5A9"!7
M<FET92<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G
M(#T^("1T:&ES+3Y?9&5F875L="@D8W1X("X@)WQM;V1E)RP@,BDI+`H*("`@
M("`@("`@("`@("`@("`@("`@("`@)V-H87)S970G(#T^("1C:&%R<V5T*2DL
M"B`@("`@("`@("`@("`@("`G:6)A<V4G(#T^(&%R<F%Y*`H@("`@("`@("`@
M("`@("`@("`@("=D97-C)R`]/B`G1FER96)I<F0O26YT97)"87-E)RP*("`@
M("`@("`@("`@("`@("`@("`G9FEE;&1S)R`]/B!A<G)A>2@*("`@("`@("`@
M("`@("`@("`@("`@("`@)V1B<WEN=&%X)R`]/B!A<G)A>2@*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=?='EP92<@/3X@)V5N=6TG+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=4:&4@9&%T86)A<V4@
M<WEN=&%X('9A<FEA;G0@=&\@=7-E)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=R97%U:7)E9"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G=F%L=65S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G:6)A<V4G(#T^("=);G1E<D)A<V4G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F:7)E8FER9"<@/3X@)T9I
M<F5B:7)D)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L
M="<@/3X@)'1H:7,M/E]D969A=6QT*"1C='@@+B`G?&1B<WEN=&%X)RP@)V9I
M<F5B:7)D)RDI+`H@("`@("`@("`@("`@("`@("`@("`@("`G<&5R<VES=&5N
M="<@/3X@)'!E<G-I<W1E;G0L"B`@("`@("`@("`@("`@("`@("`@("`@("=H
M;W-T<W!E8R<@/3X@)&AO<W1S<&5C+`H@("`@("`@("`@("`@("`@("`@("`@
M("`G=7-E<FYA;64G(#T^("1U<V5R;F%M92P*("`@("`@("`@("`@("`@("`@
M("`@("`@)W!A<W-W;W)D)R`]/B`D<&%S<W=O<F0L"B`@("`@("`@("`@("`@
M("`@("`@("`@("=D871A8F%S92<@/3X@)&1A=&%B87-E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`G8G5F9F5R<R<@/3X@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G7W1Y<&4G(#T^("=I;G0G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=4:&4@;G5M8F5R(&]F(&1A
M=&%B87-E(&)U9F9E<G,@=&\@86QL;V-A=&4G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W)E<75I<F5D)R`]/B!F86QS92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H
M)&-T>"`N("=\8G5F9F5R<R<L(&YU;&PI*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@)V1I86QE8W0G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)U]T>7!E)R`]/B`G:6YT)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=D97-C)R`]/B`G5&AE(&1E9F%U;'0@4U%,(&1I86QE8W0@
M9F]R(&%N>2!S=&%T96UE;G0@97AE8W5T960@=VET:&EN(&$@8V]N;F5C=&EO
M;BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E<75I<F5D)R`]
M/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D969A=6QT
M)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\9&EA;&5C="<L(&YU;&PI
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@)W)O;&4G(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)U]T>7!E)R`]/B`G=&5X="<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)U)O;&4G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E<75I<F5D)R`]/B!F
M86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D969A=6QT)R`]
M/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\<F]L92<L(&YU;&PI*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@)V-H87)S970G(#T^("1C:&%R<V5T*2DL
M"B`@("`@("`@("`@("`@("`G9F)S<6PG(#T^(&%R<F%Y*`H@("`@("`@("`@
M("`@("`@("`@("=D97-C)R`]/B`G1G)O;G1B87-E)RP*("`@("`@("`@("`@
M("`@("`@("`G9FEE;&1S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@
M("`@("`@)W!E<G-I<W1E;G0G(#T^("1P97)S:7-T96YT+`H@("`@("`@("`@
M("`@("`@("`@("`@("`G:&]S='-P96,G(#T^("1H;W-T<W!E8RP*("`@("`@
M("`@("`@("`@("`@("`@("`@)W5S97)N86UE)R`]/B`D=7-E<FYA;64L"B`@
M("`@("`@("`@("`@("`@("`@("`@("=P87-S=V]R9"<@/3X@)'!A<W-W;W)D
M+`H@("`@("`@("`@("`@("`@("`@("`@("`G9&%T86)A<V4G(#T^("1D871A
M8F%S92P*("`@("`@("`@("`@("`@("`@("`@("`@)V-H87)S970G(#T^("1C
M:&%R<V5T*2DL"B`@("`@("`@("`@("`@("`G:69X)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)TEN9F]R;6EX)RP*("`@("`@
M("`@("`@("`@("`@("`G9FEE;&1S)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`@("`@)W!E<G-I<W1E;G0G(#T^("1P97)S:7-T96YT+`H@("`@
M("`@("`@("`@("`@("`@("`@("`G=7-E<FYA;64G(#T^("1U<V5R;F%M92P*
M("`@("`@("`@("`@("`@("`@("`@("`@)W!A<W-W;W)D)R`]/B`D<&%S<W=O
M<F0L"B`@("`@("`@("`@("`@("`@("`@("`@("=D871A8F%S92<@/3X@)&1A
M=&%B87-E+`H@("`@("`@("`@("`@("`@("`@("`@("`G8VAA<G-E="<@/3X@
M)&-H87)S970I*2P*("`@("`@("`@("`@("`@("=M<W%L)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)VU344PG+`H@("`@("`@
M("`@("`@("`@("`@("=F:65L9',G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("`@("`G<&5R<VES=&5N="<@/3X@)'!E<G-I<W1E;G0L"B`@("`@
M("`@("`@("`@("`@("`@("`@("=H;W-T<W!E8R<@/3X@)&AO<W1S<&5C+`H@
M("`@("`@("`@("`@("`@("`@("`@("`G=7-E<FYA;64G(#T^("1U<V5R;F%M
M92P*("`@("`@("`@("`@("`@("`@("`@("`@)W!A<W-W;W)D)R`]/B`D<&%S
M<W=O<F0L"B`@("`@("`@("`@("`@("`@("`@("`@("=P;W)T)R`]/B`D<&]R
M="P*("`@("`@("`@("`@("`@("`@("`@("`@)V1A=&%B87-E)R`]/B`D9&%T
M86)A<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("=C:&%R<V5T)R`]/B`D
M8VAA<G-E="DI+`H@("`@("`@("`@("`@("`@)VUS<W%L)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)TU3(%-13"!397)V97(G
M+`H@("`@("`@("`@("`@("`@("`@("=F:65L9',G(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@("`@("`G<&5R<VES=&5N="<@/3X@)'!E<G-I<W1E
M;G0L"B`@("`@("`@("`@("`@("`@("`@("`@("=H;W-T<W!E8R<@/3X@)&AO
M<W1S<&5C+`H@("`@("`@("`@("`@("`@("`@("`@("`G=7-E<FYA;64G(#T^
M("1U<V5R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@)W!A<W-W;W)D
M)R`]/B`D<&%S<W=O<F0L"B`@("`@("`@("`@("`@("`@("`@("`@("=P;W)T
M)R`]/B`D<&]R="P*("`@("`@("`@("`@("`@("`@("`@("`@)V1A=&%B87-E
M)R`]/B`D9&%T86)A<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("=C:&%R
M<V5T)R`]/B`D8VAA<G-E="DI+`H@("`@("`@("`@("`@("`@)VUY<W%L)R`]
M/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)TUY4U%,
M)RP*("`@("`@("`@("`@("`@("`@("`G9FEE;&1S)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@("`@("`@("`@("`@)W!E<G-I<W1E;G0G(#T^("1P97)S:7-T
M96YT+`H@("`@("`@("`@("`@("`@("`@("`@("`G:&]S='-P96,G(#T^("1H
M;W-T<W!E8RP*("`@("`@("`@("`@("`@("`@("`@("`@)W5S97)N86UE)R`]
M/B`D=7-E<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("=P87-S=V]R
M9"<@/3X@)'!A<W-W;W)D+`H@("`@("`@("`@("`@("`@("`@("`@("`G<')O
M=&]C;VPG(#T^("1M>7-Q;%]P<F]T;V-O;"P*("`@("`@("`@("`@("`@("`@
M("`@("`@)V1A=&%B87-E)R`]/B`D9&%T86)A<V4L"B`@("`@("`@("`@("`@
M("`@("`@("`@("=C:&%R<V5T)R`]/B`D8VAA<G-E="DI+`H@("`@("`@("`@
M("`@("`@)VUY<W%L:2<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M)V1E<V,G(#T^("=->5-13"`H;7ES<6QI*2<L"B`@("`@("`@("`@("`@("`@
M("`@)V9I96QD<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@
M("=P97)S:7-T96YT)R`]/B`D<&5R<VES=&5N="P*("`@("`@("`@("`@("`@
M("`@("`@("`@)VAO<W1S<&5C)R`]/B`D:&]S='-P96,L"B`@("`@("`@("`@
M("`@("`@("`@("`@("=U<V5R;F%M92<@/3X@)'5S97)N86UE+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G<&%S<W=O<F0G(#T^("1P87-S=V]R9"P*("`@
M("`@("`@("`@("`@("`@("`@("`@)W!O<G0G(#T^("1P;W)T+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G<V]C:V5T)R`]/B`D<V]C:V5T+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G9&%T86)A<V4G(#T^("1D871A8F%S92P*("`@
M("`@("`@("`@("`@("`@("`@("`@)V-H87)S970G(#T^("1C:&%R<V5T*2DL
M"B`@("`@("`@("`@("`@("`G;V-I."<@/3X@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@)V1E<V,G(#T^("=/<F%C;&4G+`H@("`@("`@("`@("`@("`@
M("`@("=F:65L9',G(#T^("1O8VDX7V9I96QD<RDL"B`@("`@("`@("`@("`@
M("`G;V1B8R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)V1E<V,G
M(#T^("=/1$)#)RP*("`@("`@("`@("`@("`@("`@("`G9FEE;&1S)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)W!E<G-I<W1E;G0G(#T^
M("1P97)S:7-T96YT+`H@("`@("`@("`@("`@("`@("`@("`@("`G=7-E<FYA
M;64G(#T^("1U<V5R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@)W!A
M<W-W;W)D)R`]/B`D<&%S<W=O<F0L"B`@("`@("`@("`@("`@("`@("`@("`@
M("=H;W-T<W!E8R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G7W1Y<&4G(#T^("=T97AT)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=D97-C)R`]/B`G1%-.)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\
M:&]S='-P96,G+"`G)RDI+`H@("`@("`@("`@("`@("`@("`@("`@("`G9&)S
M>6YT87@G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)U]T>7!E)R`]/B`G96YU;2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G9&5S8R<@/3X@)U1H92!D871A8F%S92!S>6YT87@@=F%R:6%N="!T;R!U
M<V4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E<75I<F5D)R`]
M/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V86QU97,G
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S
M<6PY,B<@/3X@)U-13#DR)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G86-C97-S)R`]/B`G06-C97-S)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G9&(R)R`]/B`G1$(R)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<V]L:60G(#T^("=3;VQI9"<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)VYA=FES:6]N)R`]/B`G3F%V:7-I
M;VXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M<W-Q;"<@
M/3X@)TU3(%-13"!397)V97(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=S>6)A<V4G(#T^("=3>6)A<V4G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=M>7-Q;"<@/3X@)TUY4U%,)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G;7ES<6QI)R`]/B`G37E344P@*&UY
M<W%L:2DG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@)'1H:7,M
M/E]D969A=6QT*"1C='@@+B`G?&1B<WEN=&%X)RP@)W-Q;#DR)RDI+`H@("`@
M("`@("`@("`@("`@("`@("`@("`G8W5R<V]R)R`]/B!A<G)A>2@*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=?='EP92<@/3X@)V5N=6TG+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=#=7)S;W(@='EP
M92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<75O=&4G(#T^(&9A
M;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E<75I<F5D)R`]
M/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V86QU97,G
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N
M=6QL)R`]/B`G3F]N92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)U-13%]#55)?1$5&055,5"<@/3X@)T1E9F%U;'0G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=344Q?0U527U5315]$4DE615(G(#T^
M("=5<V4@1')I=F5R)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G4U%,7T-54E]54T5?3T1"0R<@/3X@)U5S92!/1$)#)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G4U%,7T-54E]54T5?249?3D5%1$5$
M)R`]/B`G57-E($EF($YE961E9"<I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D8W1X("X@)WQC
M=7)S;W(G+"!N=6QL*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("=C:&%R
M<V5T)R`]/B`D8VAA<G-E="DI+`H@("`@("`@("`@("`@("`@)W!G<W%L)R`]
M/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)U!O<W1G
M<F5344PG+`H@("`@("`@("`@("`@("`@("`@("=F:65L9',G(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`@("`@("`@("`@("`G<&5R<VES=&5N="<@/3X@)'!E
M<G-I<W1E;G0L"B`@("`@("`@("`@("`@("`@("`@("`@("=H;W-T<W!E8R<@
M/3X@)&AO<W1S<&5C+`H@("`@("`@("`@("`@("`@("`@("`@("`G=7-E<FYA
M;64G(#T^("1U<V5R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@)W!A
M<W-W;W)D)R`]/B`D<&%S<W=O<F0L"B`@("`@("`@("`@("`@("`@("`@("`@
M("=P<F]T;V-O;"<@/3X@)'!R;W1O8V]L+`H@("`@("`@("`@("`@("`@("`@
M("`@("`G9&%T86)A<V4G(#T^("1D871A8F%S92P*("`@("`@("`@("`@("`@
M("`@("`@("`@)V-H87)S970G(#T^("1C:&%R<V5T*2DL"B`@("`@("`@("`@
M("`@("`G<W%L:71E)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G
M9&5S8R<@/3X@)U-13&ET92<L"B`@("`@("`@("`@("`@("`@("`@)V9I96QD
M<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=D871A8F%S
M92<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G7W1Y
M<&4G(#T^("=T97AT)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R
M97%U:7)E9"<@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=D97-C)R`]/B`G06)S;VQU=&4@<&%T:"!T;R!T:&4@9&%T86)A<V4@9FEL
M92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@
M)'1H:7,M/E]D969A=6QT*"1C='@@+B`G?&1A=&%B87-E)RP@)R<I*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@)VUO9&4G(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)U]T>7!E)R`]/B`G=&5X="<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)U1H92!M;V1E('1O
M(&]P96X@=&AE(&9I;&4@=VET:"<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G9&5F875L="<@/3X@)'1H:7,M/E]D969A=6QT*"1C='@@+B`G?&UO
M9&4G+"`G,#8T-"<I*2P*("`@("`@("`@("`@("`@("`@("`@("`@)V-H87)S
M970G(#T^("1C:&%R<V5T*2DL"B`@("`@("`@("`@("`@("`G<WEB87-E)R`]
M/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)U-Y8F%S
M92<L"B`@("`@("`@("`@("`@("`@("`@)V9I96QD<R<@/3X@87)R87DH"B`@
M("`@("`@("`@("`@("`@("`@("`@("=P97)S:7-T96YT)R`]/B`D<&5R<VES
M=&5N="P*("`@("`@("`@("`@("`@("`@("`@("`@)VAO<W1S<&5C)R`]/B`D
M:&]S='-P96,L"B`@("`@("`@("`@("`@("`@("`@("`@("=U<V5R;F%M92<@
M/3X@)'5S97)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`G<&%S<W=O
M<F0G(#T^("1P87-S=V]R9"P*("`@("`@("`@("`@("`@("`@("`@("`@)V1A
M=&%B87-E)R`]/B`D9&%T86)A<V4L"B`@("`@("`@("`@("`@("`@("`@("`@
M("=A<'!N86UE)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=?='EP92<@/3X@)W1E>'0G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V1E<V,G(#T^("=!<'!L:6-A=&EO;B!.86UE)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=R97%U:7)E9"<@/3X@9F%L<V4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@)'1H:7,M/E]D
M969A=6QT*"1C='@@+B`G?&%P<&YA;64G+"`G)RDI+`H@("`@("`@("`@("`@
M("`@("`@("`@("`G8VAA<G-E="<@/3X@)&-H87)S970I*2DI.PH*("`@("`@
M("!I9B`H:7-S970H)&YO9&4I("8F("1N;V1E+3YG971?871T<FEB=71E*"=B
M87-E8V]N9FEG)RD@/3T@)W1R=64G*2!["B`@("`@("`@("`@(')E='5R;B`D
M8W5S=&]M7V9I96QD<SL*("`@("`@("!]"@H@("`@("`@("1C;VYF:6<@/2!A
M<G)A>2@*("`@("`@("`@("`@)V1E<V,G(#T^("=$<FEV97(@8V]N9FEG=7)A
M=&EO;B<L"B`@("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U
M;'0H)&-T>"`N("=\)R`N("AI<W-E="@D;F]D92D@/R`D;F]D92T^9V5T7V%T
M=')I8G5T92@G<W=I=&-H;F%M92<I(#H@)'-W:71C:&YA;64I+"`G:&]R9&4G
M*2P*("`@("`@("`@("`@)W-W:71C:"<@/3X@87)R87DH"B`@("`@("`@("`@
M("`@("`G:&]R9&4G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=D
M97-C)R`]/B`G2&]R9&4@9&5F875L=',G+`H@("`@("`@("`@("`@("`@("`@
M("=F:65L9',G(#T^(&%R<F%Y*"DI+`H@("`@("`@("`@("`@("`@)V-U<W1O
M;2<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=#
M=7-T;VT@<&%R86UE=&5R<R<L"B`@("`@("`@("`@("`@("`@("`@)V9I96QD
M<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@(&UD-2AM:6-R
M;W1I;64H*2D@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G7W1Y<&4G(#T^("=D97-C<FEP=&EO;B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G9&5S8R<@/3X@)T%N>2!P87)A;65T97)S('1H870@=&AE
M('-T;W)A9V4@9')I=F5R(&YE961S+B<I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`G<&AP='EP92<@/3X@)&-U<W1O;5]F:65L9',I*2DI.PH*("`@("`@
M("!I9B`H:7-S970H)&YO9&4I("8F("1N;V1E+3YH87-?8VAI;&1?;F]D97,H
M*2D@>PH@("`@("`@("`@("`D8W5R(#T@87)R87DH*3L*("`@("`@("`@("`@
M)'1H:7,M/E]P87)S94QE=F5L*"1C=7(L("1N;V1E+3YC:&EL9%]N;V1E<R@I
M+"`D8W1X*3L*("`@("`@("`@("`@)&-O;F9I9ULG<W=I=&-H)UU;)VAO<F1E
M)UU;)V9I96QD<R==(#T@87)R87E?;65R9V4H)&-O;F9I9ULG<W=I=&-H)UU;
M)VAO<F1E)UU;)V9I96QD<R==+"`D8W5R*3L*("`@("`@("`@("`@)&-O;F9I
M9ULG<W=I=&-H)UU;)V-U<W1O;2==6R=F:65L9',G72`](&%R<F%Y7VUE<F=E
M*"1C;VYF:6=;)W-W:71C:"==6R=C=7-T;VTG75LG9FEE;&1S)UTL("1C=7(I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C;VYF:6<["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C;VYF:6=U<F%T:6]N('1R964@
M9F]R(&$@5D93(&)A8VME;F0@8V]N9FEG=7)A=&EO;B!T;PH@("`@("H@<F5P
M;&%C92!A(#QC;VYF:6=V9G,^('1A9RX*("`@("`J(%-U8FYO9&5S('=I;&P@
M8F4@<&%R<V5D(&%N9"!A9&1E9"!T;R!B;W1H('1H92!(;W)D92!D969A=6QT
M<R!A;F0@=&AE"B`@("`@*B!#=7-T;VT@8V]N9FEG=7)A=&EO;B!P87)T<RX*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1C='@@("`@5&AE(&-O;G1E>'0@;V8@=&AE(#QC;VYF
M:6=V9G,^('1A9RX*("`@("`J($!P87)A;2!$;VU.;V1E("1N;V1E("!4:&4@
M1&]M3F]D92!R97!R97-E;G1A=&EO;B!O9B!T:&4@/&-O;F9I9W9F<SX*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!T86<N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@06X@87-S;V-I871I=F4@87)R87D@=VET:"!T:&4@
M5D93(&-O;F9I9W5R871I;VX@=')E92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V-O;F9I9U9&4R@D8W1X+"`D;F]D92D*("`@('L*("`@("`@("`D<W%L(#T@
M)'1H:7,M/E]C;VYF:6=344PH)&-T>"`N("=\<&%R86US)RD["B`@("`@("`@
M)&-O;F9I9R`]"B`@("`@("`@("`@(&%R<F%Y*`H@("`@("`@("`@("`@("`@
M)V1E<V,G(#T^("=7:&%T(%9&4R!D<FEV97(@<VAO=6QD('=E('5S93\G+`H@
M("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D
M8W1X("X@)WPG("X@)&YO9&4M/F=E=%]A='1R:6)U=&4H)W-W:71C:&YA;64G
M*2P@)VAO<F1E)RDL"B`@("`@("`@("`@("`@("`G<W=I=&-H)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@("`@("`@("`G;F]N92<@/3X@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`G3F]N92<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("=F:65L9',G(#T^(&%R<F%Y*"DI+`H@("`@("`@
M("`@("`@("`@("`@("=H;W)D92<@/3X@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@("`@("=D97-C)R`]/B`G2&]R9&4@9&5F875L=',G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G9FEE;&1S)R`]/B!A<G)A>2@I*2P*("`@("`@
M("`@("`@("`@("`@("`G9FEL92<@/3X@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@("`@("=D97-C)R`]/B`G1FEL97,@;VX@=&AE(&QO8V%L('-Y<W1E
M;2<L"B`@("`@("`@("`@("`@("`@("`@("`@("=F:65L9',G(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!A<F%M<R<@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9F<W)O;W0G
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G7W1Y<&4G(#T^("=T97AT)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V1E<V,G(#T^("=7:&5R92!O;B!T:&4@<F5A;"!F:6QE
M<WES=&5M('-H;W5L9"!(;W)D92!U<V4@87,@<F]O="!O9B!T:&4@=FER='5A
M;"!F:6QE<WES=&5M/R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\
M<&%R86US?'9F<W)O;W0G+"`G+W1M<"<I*2DI*2P*("`@("`@("`@("`@("`@
M("`@("`G<W%L)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@
M)V1E<V,G(#T^("=344P@9&%T86)A<V4G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`G9FEE;&1S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=P87)A;7,G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=D<FEV97)C;VYF:6<G(#T^("1S<6PI*2DI*3L*"B`@
M("`@("`@)&-A<V5S(#T@)'1H:7,M/E]G9713=VET8VA686QU97,H)&YO9&4L
M("1C='@@+B`G?'!A<F%M<R<I.PH@("`@("`@(&9O<F5A8V@@*"1C87-E<R!A
M<R`D8V%S92`]/B`D9FEE;&1S*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D
M8V]N9FEG6R=S=VET8V@G75LD8V%S95TI*2!["B`@("`@("`@("`@("`@("`D
M8V]N9FEG6R=S=VET8V@G75LD8V%S95U;)V9I96QD<R==6R=P87)A;7,G72`]
M(&%R<F%Y7VUE<F=E*"1C;VYF:6=;)W-W:71C:"==6R1C87-E75LG9FEE;&1S
M)UU;)W!A<F%M<R==+"`D9FEE;&1S6R=F:65L9',G72D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D8V]N9FEG.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&-E<G1A:6X@=F%L=64@9G)O;2!T
M:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N(&%R<F%Y(&]R"B`@("`@*B!A(&1E
M9F%U;'0@=F%L=64L(&EF(&YO="!F;W5N9"X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C='@@
M("`@($$@<W1R:6YG(')E<')E<V5N=&EN9R!T:&4@:V5Y(&]F('1H90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("!C;VYF:6=U<F%T:6]N(&%R<F%Y
M('1O(')E='5R;BX*("`@("`J($!P87)A;2!M:7AE9"`D9&5F875L="`@5&AE
M(&1E9F%U;'0@=F%L=64@=&\@<F5T=7)N(&EF('1H92!K97D@=V%S;B=T"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&9O=6YD+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@($5I=&AE<B!T:&4@=F%L=64@;V8@=&AE(&-O
M;F9I9W5R871I;VX@87)R87DG<R!R97%U97-T960*("`@("`J("`@("`@("`@
M("`@("`@(&ME>2!O<B!T:&4@9&5F875L="!V86QU92!I9B!T:&4@:V5Y('=A
M<VXG="!F;W5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V1E9F%U;'0H)&-T
M>"P@)&1E9F%U;'0I"B`@("!["B`@("`@("`@)&-T>"`](&5X<&QO9&4H)WPG
M+"`D8W1X*3L*("`@("`@("`D<'1R(#T@)'1H:7,M/E]C=7)R96YT0V]N9FEG
M.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1C='@I.R`D:2LK
M*2!["B`@("`@("`@("`@(&EF("@A:7-S970H)'!T<ELD8W1X6R1I75TI*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)&1E9F%U;'0["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D<'1R(#T@)'!T<ELD8W1X6R1I
M75T["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*&ES7W-T
M<FEN9R@D<'1R*2D@>PH@("`@("`@("`@("!R971U<FX@4W1R:6YG.CIC;VYV
M97)T0VAA<G-E="@D<'1R+"`G:7-O+3@X-3DM,2<I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B`D<'1R.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!C97)T86EN('9A;'5E(&9R;VT@
M=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;B!F:6QE(&]R"B`@("`@*B!A(&1E
M9F%U;'0@=F%L=64L(&EF(&YO="!F;W5N9"X*("`@("`J($ET(&1O97,@3D]4
M(')E='5R;B!T:&4@86-T=6%L('9A;'5E+"!B=70@=&AE(%!(4"!E>'!R97-S
M:6]N(&%S('5S960*("`@("`J(&EN('1H92!C;VYF:6=U<F%T:6]N(&9I;&4N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8W1X("`@("!!('-T<FEN9R!R97!R97-E;G1I;F<@
M=&AE(&ME>2!O9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M8V]N9FEG=7)A=&EO;B!A<G)A>2!T;R!R971U<FXN"B`@("`@*B!`<&%R86T@
M;6EX960@)&1E9F%U;'0@(%1H92!D969A=6QT('9A;'5E('1O(')E='5R;B!I
M9B!T:&4@:V5Y('=A<VXG=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("!F;W5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!%:71H97(@
M=&AE('9A;'5E(&]F('1H92!C;VYF:6=U<F%T:6]N(&9I;&4G<R!R97%U97-T
M960*("`@("`J("`@("`@("`@("`@("`@(&ME>2!O<B!T:&4@9&5F875L="!V
M86QU92!I9B!T:&4@:V5Y('=A<VXG="!F;W5N9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V1E9F%U;'1287<H)&-T>"P@)&1E9F%U;'0I"B`@("!["B`@("`@
M("`@)&-T>"`](&5X<&QO9&4H)WPG+"`D8W1X*3L*("`@("`@("`D<&%T=&5R
M;B`]("<O7EPD8V]N9EQ;7"<G("X@:6UP;&]D92@B)UQ=7%LG(BP@)&-T>"D@
M+B`G7"=<72`]("@N*BD[)"]M)SL*("`@("`@("!I9B`H<')E9U]M871C:"@D
M<&%T=&5R;BP@)'1H:7,M/F=E=%!(4$-O;F9I9R@I+"`D;6%T8VAE<RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1M871C:&5S6S%=.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)&1E9F%U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!C;VYT96YT(&]F(&%L;"!T97AT(&YO9&4@8VAI;&1R96X@
M;V8@=&AE('-P96-I9FEE9"!N;V1E+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!$;VU.;V1E("1N;V1E("!!
M($1O;4YO9&4@;V)J96-T('=H;W-E('1E>'0@;F]D92!C:&EL9')E;B!T;R!R
M971U<FXN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C;VYC
M871E;F%T960@=F%L=65S(&]F(&%L;"!T97AT(&YO9&5S+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?9V5T3F]D94]N;'E497AT*"1N;V1E*0H@("`@>PH@("`@
M("`@("1T97AT(#T@)R<["B`@("`@("`@:68@*"$D;F]D92T^:&%S7V-H:6QD
M7VYO9&5S*"DI('L*("`@("`@("`@("`@<F5T=7)N("1N;V1E+3YG971?8V]N
M=&5N="@I.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D;F]D92T^8VAI
M;&1?;F]D97,H*2!A<R`D=&YO9&4I('L*("`@("`@("`@("`@:68@*"1T;F]D
M92T^='EP92`]/2!834Q?5$585%].3T1%*2!["B`@("`@("`@("`@("`@("`D
M=&5X="`N/2`D=&YO9&4M/F-O;G1E;G0["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<FEM*"1T97AT*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@86X@87-S;V-I871I=F4@87)R87D@8V]N=&%I
M;FEN9R!A;&P@<&]S<VEB;&4@=F%L=65S(&]F('1H90H@("`@("H@<W!E8VEF
M:65D(#QC;VYF:6=E;G5M/B!T86<N"B`@("`@*B!4:&4@:V5Y<R!C;VYT86EN
M('1H92!A8W1U86P@96YU;2!V86QU97,@=VAI;&4@=&AE('9A;'5E<R!C;VYT
M86EN('1H96ER"B`@("`@*B!C;W)R97-P;VYD:6YG(&1E<V-R:7!T:6]N<RX*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@1&]M3F]D92`D;F]D92`@5&AE($1O;4YO9&4@<F5P<F5S96YT871I
M;VX@;V8@=&AE(#QC;VYF:6=E;G5M/B!T86<*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!W:&]S92!V86QU97,@<VAO=6QD(&)E(')E='5R;F5D+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%S<V]C:6%T:79E(&%R
M<F%Y('=I=&@@86QL('!O<W-I8FQE(&5N=6T@=F%L=65S+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?9V5T16YU;59A;'5E<R@D;F]D92D*("`@('L*("`@("`@
M("`D=F%L=65S(#T@87)R87DH*3L*("`@("`@("!I9B`H(21N;V1E+3YH87-?
M8VAI;&1?;F]D97,H*2D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH*3L*
M("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H)&YO9&4M/F-H:6QD7VYO9&5S
M*"D@87,@)'9N;V1E*2!["B`@("`@("`@("`@(&EF("@D=FYO9&4M/G1Y<&4@
M/3T@6$U,7T5,14U%3E1?3D]$12`F)@H@("`@("`@("`@("`@("`@)'9N;V1E
M+3YT86=N86UE(#T]("=V86QU97,G*2!["B`@("`@("`@("`@("`@("!I9B`H
M(21V;F]D92T^:&%S7V-H:6QD7VYO9&5S*"DI('L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@87)R87DH*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1V;F]D92T^8VAI;&1?;F]D97,H*2!A<R`D
M=F%L=64I('L*("`@("`@("`@("`@("`@("`@("!I9B`H)'9A;'5E+3YT>7!E
M(#T](%A-3%]%3$5-14Y47TY/1$4I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"1V86QU92T^=&%G;F%M92`]/2`G8V]N9FEG<W!E8VEA;"<I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VAA
M;F1L95-P96-I86QS*"1V86QU92D["B`@("`@("`@("`@("`@("`@("`@("`@
M('T@96QS96EF("@D=F%L=64M/G1A9VYA;64@/3T@)W9A;'5E)RD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1E>'0@/2`D=F%L=64M/F=E=%]C
M;VYT96YT*"D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5S8R`]
M("1V86QU92T^9V5T7V%T=')I8G5T92@G9&5S8R<I.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D9&5S8RDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=F%L=65S6R1T97AT72`]("1D97-C
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=65S6R1T97AT72`]("1T
M97AT.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D=F%L=65S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A
M(&UU;'1I9&EM96YS:6]N86P@87-S;V-I871I=F4@87)R87D@<F5P<F5S96YT
M:6YG('1H92!S<&5C:69I960*("`@("`J(#QC;VYF:6=S=VET8V@^('1A9RX*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@1&]M3F]D92`F)&YO9&4@(%1H92!$;VU.;V1E(')E<')E<V5N=&%T
M:6]N(&]F('1H92`\8V]N9FEG<W=I=&-H/@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("!T86<@=&\@<')O8V5S<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!!;B!A<W-O8VEA=&EV92!A<G)A>2!R97!R97-E;G1I;F<@
M=&AE(&YO9&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G9713=VET8VA686QU
M97,H)B1N;V1E+"`D8W5R8W1X*0H@("`@>PH@("`@("`@(&EF("@A)&YO9&4M
M/FAA<U]C:&EL9%]N;V1E<R@I*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A
M>2@I.PH@("`@("`@('T*("`@("`@("`D=F%L=65S(#T@87)R87DH*3L*("`@
M("`@("!F;W)E86-H("@D;F]D92T^8VAI;&1?;F]D97,H*2!A<R`D8V%S92D@
M>PH@("`@("`@("`@("!I9B`H)&-A<V4M/G1Y<&4@/3T@6$U,7T5,14U%3E1?
M3D]$12D@>PH@("`@("`@("`@("`@("`@)&YA;64@/2`D8V%S92T^9V5T7V%T
M=')I8G5T92@G;F%M92<I.PH@("`@("`@("`@("`@("`@)'9A;'5E<ULD;F%M
M95T@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@)'9A;'5E<ULD;F%M95U;
M)V1E<V,G72`]("1C87-E+3YG971?871T<FEB=71E*"=D97-C)RD["B`@("`@
M("`@("`@("`@("`D=F%L=65S6R1N86UE75LG9FEE;&1S)UT@/2!A<G)A>2@I
M.PH@("`@("`@("`@("`@("`@:68@*"1C87-E+3YH87-?8VAI;&1?;F]D97,H
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5,979E;"@D
M=F%L=65S6R1N86UE75LG9FEE;&1S)UTL("1C87-E+3YC:&EL9%]N;V1E<R@I
M+"`D8W5R8W1X*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!R971U<FX@)'9A;'5E<SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@86X@87-S;V-I871I=F4@87)R87D@8V]N=&%I
M;FEN9R!T:&4@<&]S<VEB;&4@=F%L=65S(&]F(&$*("`@("`J(#QC;VYF:6=S
M<&5C:6%L/B!T86<@87,@=7-E9"!I;G-I9&4@;V8@96YU;2!C;VYF:6=U<F%T
M:6]N<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@1&]M3F]D92`D;F]D92`@5&AE($1O;4YO9&4@<F5P<F5S
M96YT871I;VX@;V8@=&AE(#QC;VYF:6=S<&5C:6%L/@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@('1A9RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!!;B!A<W-O8VEA=&EV92!A<G)A>2!W:71H('1H92!P;W-S:6)L92!V
M86QU97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]H86YD;&53<&5C:6%L<R@D
M;F]D92D*("`@('L*("`@("`@("!S=VET8V@@*"1N;V1E+3YG971?871T<FEB
M=71E*"=N86UE)RDI('L*("`@("`@("!C87-E("=L:7-T+6AO<F1E+6%P<',G
M.@H@("`@("`@("`@("!G;&]B86P@)')E9VES=')Y.PH@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+T%R<F%Y+G!H<"<["B`@("`@("`@("`@("1A
M<'!S(#T@2&]R9&5?07)R87DZ.G9A;'5E<U1O2V5Y<R@D<F5G:7-T<GDM/FQI
M<W1!<'!S*&%R<F%Y*"=H:61D96XG+"`G;F]T;V]L8F%R)RP@)V%C=&EV92<I
M*2D["B`@("`@("`@("`@(&%S;W)T*"1A<'!S*3L*("`@("`@("`@("`@<F5T
M=7)N("1A<'!S.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G
M;&ES="UH;W)D92UL86YG=6%G97,G.@H@("`@("`@("`@("!R971U<FX@87)R
M87E?;6%P*&-R96%T95]F=6YC=&EO;B@G)'9A;"<L("=R971U<FX@<')E9U]R
M97!L86-E*&%R<F%Y*"(O)B-X*%LP+3EA+69=>S1]*3LO:64B+"`B+R@F6UX[
M72L[*2]E(BDL(&%R<F%Y*")3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*'!A8VLH
M7")(*EPB+"!<(B0Q7"(I+"!<(G5C<RTR7"(L(%PB)R`N($Y,4SHZ9V5T0VAA
M<G-E="@I("X@)UPB*2(L(")3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*&AT;6Q?
M96YT:71Y7V1E8V]D92A<(B0Q7"(L($5.5%]#3TU0050L(%PB:7-O+3@X-3DM
M,5PB*2P@7")I<V\M.#@U.2TQ7"(L(%PB)R`N($Y,4SHZ9V5T0VAA<G-E="@I
M("X@)UPB*2(I+"`D=F%L*3LG*2P@)$=,3T)!3%-;)VYL<R==6R=L86YG=6%G
M97,G72D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=L:7-T
M+6)L;V-K<R<Z"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O0FQO
M8VLO0V]L;&5C=&EO;BYP:'`G.PH@("`@("`@("`@("`D8V]L;&5C=&EO;B`]
M("9(;W)D95]";&]C:U]#;VQL96-T:6]N.CIS:6YG;&5T;VXH)W!O<G1A;"<I
M.PH@("`@("`@("`@("!R971U<FX@)&-O;&QE8W1I;VXM/F=E=$)L;V-K<TQI
M<W0H*3L*"B`@("`@("`@8V%S92`G;&ES="UC;&EE;G0M9FEE;&1S)SH*("`@
M("`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*("`@("`@("`@("`@)&8@/2!A
M<G)A>2@I.PH@("`@("`@("`@("!I9B`H)')E9VES=')Y+3YH87--971H;V0H
M)V-L:65N=',O9V5T0VQI96YT4V]U<F-E)RDI('L*("`@("`@("`@("`@("`@
M("1A9&1R97-S8F]O:R`]("1R96=I<W1R>2T^8V%L;"@G8VQI96YT<R]G971#
M;&EE;G13;W5R8V4G*3L*("`@("`@("`@("`@("`@("1F:65L9',@/2`D<F5G
M:7-T<GDM/F-A;&PH)V-L:65N=',O9FEE;&1S)RP@87)R87DH)&%D9')E<W-B
M;V]K*2D["B`@("`@("`@("`@("`@("!I9B`H(6ES7V$H)&9I96QD<RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1F
M:65L9',@87,@)&9I96QD*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1F
M6R1F:65L9%LG;F%M92==72`]("1F:65L9%LG;&%B96PG73L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("`@("`@<F5T=7)N("1F.PH@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@<W!E8VEF:65D('-T<FEN9R!W:71H(&5S
M8V%P960@<VEN9VQE('%U;W1E<PH@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T<FEN9R`@02!S
M=')I;F<@=&\@97-C87!E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@<W!E8VEF:65D('-T<FEN9R!W:71H('-I;F=L92!Q=6]T97,@8F5I
M;F<@97-C87!E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7W%U;W1E*"1S=')I
M;F<I"B`@("!["B`@("`@("`@<F5T=7)N('-T<E]R97!L86-E*"(G(BP@(EPG
M(BP@)'-T<FEN9RD["B`@("!]"@I]"@HO*BH*("H@02!(;W)D95]&;W)M.CH@
M9F]R;2!T:&%T(&EM<&QE;65N=',@82!U<V5R(&EN=&5R9F%C92!F;W(@=&AE
M(&-O;F9I9PH@*B!S>7-T96TN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N
M8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*
M("H@0'!A8VMA9V4@2&]R9&5?1G)A;65W;W)K"B`J+PIC;&%S<R!#;VYF:6=&
M;W)M(&5X=&5N9',@2&]R9&5?1F]R;2!["@H@("`@+RHJ"B`@("`@*B!$;VXG
M="!U<V4@9F]R;2!T;VME;G,@9F]R('1H92!C;VYF:6=U<F%T:6]N(&9O<FT@
M+2!W:&EL90H@("`@("H@9V5N97)A=&EN9R!C;VYF:6=U<F%T:6]N(&EN9F\L
M('1H:6YG<R!L:6ME('1H92!4;VME;B!S>7-T96T*("`@("`J(&UI9VAT(&YO
M="!W;W)K(&-O<G)E8W1L>2X@5&AI<R!S879E<R!S;VUE(&AE861A8VAE<RX*
M("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?
M=7-E1F]R;51O:V5N(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!#;VYT86EN
M<R!T:&4@2&]R9&5?0V]N9FEG(&]B:F5C="!T:&%T('1H:7,@9F]R;2!R97!R
M97-E;G1S+@H@("`@("H*("`@("`J($!V87(@2&]R9&5?0V]N9FEG"B`@("`@
M*B\*("`@('9A<B`D7WAM;$-O;F9I9SL*"B`@("`O*BH*("`@("`J($-O;G1A
M:6YS('1H92!687)I86)L97,@;V)J96-T(&]F('1H:7,@9F]R;2X*("`@("`J
M"B`@("`@*B!`=F%R(%9A<FEA8FQE<PH@("`@("HO"B`@("!V87(@)%]V87)S
M.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@
M0'!A<F%M(%9A<FEA8FQE<R`F)'9A<G,@(%1H92!687)I86)L97,@;V)J96-T
M(&]F('1H:7,@9F]R;2X*("`@("`J($!P87)A;2!S=')I;F<@)&%P<"`@("`@
M("`@("`@("!4:&4@;F%M92!O9B!T:&4@87!P;&EC871I;VX@=&AA="!T:&ES
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N9FEG
M=7)A=&EO;B!F;W)M(&ES(&9O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@0V]N
M9FEG1F]R;2@F)'9A<G,L("1A<'`I"B`@("!["B`@("`@("`@<&%R96YT.CI(
M;W)D95]&;W)M*"1V87)S*3L*"B`@("`@("`@)'1H:7,M/E]X;6Q#;VYF:6<@
M/2`F;F5W($AO<F1E7T-O;F9I9R@D87!P*3L*("`@("`@("`D=&AI<RT^7W9A
M<G,@/2`F)'9A<G,["B`@("`@("`@)&-O;F9I9R`]("1T:&ES+3Y?>&UL0V]N
M9FEG+3YR96%D6$U,0V]N9FEG*"D["B`@("`@("`@)'1H:7,M/F%D9$AI9&1E
M;B@G)RP@)V%P<"<L("=T97AT)RP@=')U92D["B`@("`@("`@)'1H:7,M/E]B
M=6EL9%9A<FEA8FQE<R@D8V]N9FEG*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($)U:6QD<R!T:&4@9F]R;2!B87-E9"!O;B!T:&4@<W!E8VEF:65D(&QE=F5L
M(&]F('1H92!C;VYF:6=U<F%T:6]N('1R964N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1C;VYF
M:6<@("!4:&4@<&]R=&EO;B!O9B!T:&4@8V]N9FEG=7)A=&EO;B!T<F5E(&9O
M<B!T:&%T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@('1H92!F;W)M
M(&9I96QD<R!S:&]U;&0@8F4@8W)E871E9"X*("`@("`J($!P87)A;2!S=')I
M;F<@)'!R969I>"`@02!S=')I;F<@<F5P<F5S96YT:6YG('1H92!C=7)R96YT
M('!O<VET:6]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&EN<VED
M92!T:&4@8V]N9FEG=7)A=&EO;B!T<F5E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?8G5I;&1687)I86)L97,H)&-O;F9I9RP@)'!R969I>"`]("<G*0H@("`@
M>PH@("`@("`@(&EF("@A:7-?87)R87DH)&-O;F9I9RDI('L*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D8V]N9FEG
M(&%S("1N86UE(#T^("1C;VYF:6=I=&5M*2!["B`@("`@("`@("`@("1P<F5F
M:7AE9&YA;64@/2!E;7!T>2@D<')E9FEX*2`_("1N86UE(#H@)'!R969I>"`N
M("=\)R`N("1N86UE.PH@("`@("`@("`@("`D=F%R;F%M92`]('-T<E]R97!L
M86-E*"=\)RP@)U]?)RP@)'!R969I>&5D;F%M92D["B`@("`@("`@("`@("1D
M97-C<FEP=&EO;B`](&YU;&P["B`@("`@("`@("`@(&EF("@D8V]N9FEG:71E
M;2`]/2`G<&QA8V5H;VQD97(G*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1C;VYF:6=I=&5M6R=T
M86(G72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3YS971396-T:6]N*"1C
M;VYF:6=I=&5M6R=T86(G72P@)&-O;F9I9VET96U;)V1E<V,G72D["B`@("`@
M("`@("`@('T@96QS96EF("AI<W-E="@D8V]N9FEG:71E;5LG<W=I=&-H)UTI
M*2!["B`@("`@("`@("`@("`@("`D<V5L96-T960@/2`D=&AI<RT^7W9A<G,M
M/F=E=$5X:7-T<R@D=F%R;F%M92P@)'=A<W-E="D["B`@("`@("`@("`@("`@
M("`D=F%R7W!A<F%M<R`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`D<V5L
M96-T7V]P=&EO;B`]('1R=64["B`@("`@("`@("`@("`@("!I9B`H:7-?8F]O
M;"@D8V]N9FEG:71E;5LG9&5F875L="==*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1C;VYF:6=I=&5M6R=D969A=6QT)UT@/2`D8V]N9FEG:71E;5LG9&5F
M875L="==(#\@)W1R=64G(#H@)V9A;'-E)SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1C;VYF:6=I=&5M6R=S=VET8V@G
M72!A<R`D;W!T:6]N(#T^("1C87-E*2!["B`@("`@("`@("`@("`@("`@("`@
M)'9A<E]P87)A;7-;)&]P=&EO;ET@/2`D8V%S95LG9&5S8R==.PH@("`@("`@
M("`@("`@("`@("`@(&EF("@D;W!T:6]N(#T]("1C;VYF:6=I=&5M6R=D969A
M=6QT)UTI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'-E;&5C=%]O<'1I
M;VX@/2!F86QS93L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"$D=V%S
M<V5T*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<V5L96-T960@
M/2`D;W!T:6]N.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)'8@/2`F)'1H:7,M/F%D9%9A<FEA8FQE*"1C;VYF:6=I=&5M6R=D97-C
M)UTL("1V87)N86UE+"`G96YU;2<L('1R=64L(&9A;'-E+"!N=6QL+"!A<G)A
M>2@D=F%R7W!A<F%M<RP@)'-E;&5C=%]O<'1I;VXI*3L*("`@("`@("`@("`@
M("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=D969A=6QT)RP@)&-O;F9I9VET
M96TI*2!["B`@("`@("`@("`@("`@("`@("`@)'8M/G-E=$1E9F%U;'0H)&-O
M;F9I9VET96U;)V1E9F%U;'0G72D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D=E]A8W1I;VX@/2`F2&]R9&5?1F]R;5]!8W1I;VXZ.F9A
M8W1O<GDH)W)E;&]A9"<I.PH@("`@("`@("`@("`@("`@)'8M/G-E=$%C=&EO
M;B@D=E]A8W1I;VXI.PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1S96QE
M8W1E9"D@)B8@:7-S970H)&-O;F9I9VET96U;)W-W:71C:"==6R1S96QE8W1E
M9%TI*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]B=6EL9%9A<FEA
M8FQE<R@D8V]N9FEG:71E;5LG<W=I=&-H)UU;)'-E;&5C=&5D75LG9FEE;&1S
M)UTL("1P<F5F:7@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M(&5L<V5I9B`H:7-S970H)&-O;F9I9VET96U;)U]T>7!E)UTI*2!["B`@("`@
M("`@("`@("`@("`D<F5Q=6ER960@/2`H:7-S970H)&-O;F9I9VET96U;)W)E
M<75I<F5D)UTI*2`_("1C;VYF:6=I=&5M6R=R97%U:7)E9"==(#H@=')U93L*
M("`@("`@("`@("`@("`@("1T>7!E(#T@)&-O;F9I9VET96U;)U]T>7!E)UT[
M"B`@("`@("`@("`@("`@("`O+R!&25A-13H@;75L=&EE;G5M(&9I96QD<R!C
M86X@=V5L;"!B92!R97%U:7)E9"P@;65A;FEN9R!T:&%T"B`@("`@("`@("`@
M("`@("`O+R!Y;W4@;F5E9"!T;R!S96QE8W0@870@;&5A<W0@;VYE(&5N=')Y
M+B!#:&%N9VEN9R!T:&ES(&)E9F]R90H@("`@("`@("`@("`@("`@+R\@2&]R
M9&4@-"XP('=O=6QD(&)R96%K(&$@;&]T(&]F(&-O;F9I9W5R871I;VX@9FEL
M97,@=&AO=6=H+@H@("`@("`@("`@("`@("`@:68@*"1T>7!E(#T]("=M=6QT
M:65N=6TG('Q\("1T>7!E(#T]("=H96%D97(G('Q\"B`@("`@("`@("`@("`@
M("`@("`@)'1Y<&4@/3T@)V1E<V-R:7!T:6]N)RD@>PH@("`@("`@("`@("`@
M("`@("`@("1R97%U:7)E9"`](&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@:68@*"1T>7!E(#T]("=M=6QT:65N=6TG('Q\("1T
M>7!E(#T]("=E;G5M)RD@>PH@("`@("`@("`@("`@("`@("`@("1V87)?<&%R
M86US(#T@87)R87DH)&-O;F9I9VET96U;)W9A;'5E<R==*3L*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'9A<E]P87)A
M;7,@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@:68@*"1T>7!E(#T]("=P:'`G*2!["B`@("`@("`@("`@("`@("`@("`@
M)'1Y<&4@/2`G=&5X="<["B`@("`@("`@("`@("`@("`@("`@)&1E<V-R:7!T
M:6]N(#T@)T5N=&5R(&$@=F%L:60@4$A0(&5X<')E<W-I;VXN)SL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1V(#T@)B1T:&ES+3YA9&16
M87)I86)L92@D8V]N9FEG:71E;5LG9&5S8R==+"`D=F%R;F%M92P@)'1Y<&4L
M("1R97%U:7)E9"P@9F%L<V4L("1D97-C<FEP=&EO;BP@)'9A<E]P87)A;7,I
M.PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1C;VYF:6=I=&5M6R=D969A
M=6QT)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)'8M/G-E=$1E9F%U;'0H
M)&-O;F9I9VET96U;)V1E9F%U;'0G72D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V)U
M:6QD5F%R:6%B;&5S*"1C;VYF:6=I=&5M+"`D<')E9FEX961N86UE*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@('T*"GT*"F-L87-S($AO<F1E7T-O
M;F9I9U]$;V-U;65N="!E>'1E;F1S($AO<F1E7T-O;F9I9U].;V1E('L*"B`@
M("!F=6YC=&EO;B!F86-T;W)Y*"1F:6QE*0H@("`@>PH@("`@("`@(&EF("AF
M=6YC=&EO;E]E>&ES=',H)V1O;7AM;%]O<&5N7V9I;&4G*2D@>PH@("`@("`@
M("`@("!R971U<FX@9&]M>&UL7V]P96Y?9FEL92@D9FEL92D["B`@("`@("`@
M?2!E;'-E:68@*'9E<G-I;VY?8V]M<&%R92AP:'!V97)S:6]N*"DL("<U)RP@
M)SX])RDI('L*("`@("`@("`@("`@<F5T=7)N("1D;V,@/2!N97<@2&]R9&5?
M0V]N9FEG7T1O8W5M96YT*"1F:6QE*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!(;W)D93HZ9F%T86PH)T1/32!S=7!P;W)T(&YO="!P<F5S96YT
M+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@?0H*("`@
M(&9U;F-T:6]N($AO<F1E7T-O;F9I9U]$;V-U;65N="@D9FEL96YA;64I"B`@
M("!["B`@("`@("`@)'1H:7,M/FYO9&4@/2!N97<@1$]-1&]C=6UE;G0H*3L*
M("`@("`@("`D=&AI<RT^;F]D92T^;&]A9"@D9FEL96YA;64I.PH@("`@?0H*
M("`@(&9U;F-T:6]N(')O;W0H*0H@("`@>PH@("`@("`@(')E='5R;B`D<F]O
M="`](&YE=R!(;W)D95]#;VYF:6=?16QE;65N="@D=&AI<RT^;F]D92T^9&]C
M=6UE;G1%;&5M96YT*3L*("`@('T*"GT*"F-L87-S($AO<F1E7T-O;F9I9U].
M;V1E('L*"B`@("!V87(@)&YO9&4["@H@("`@9G5N8W1I;VX@2&]R9&5?0V]N
M9FEG7TYO9&4H)&%$;VU.;V1E*2![)'1H:7,M/FYO9&4])&%$;VU.;V1E.WT*
M"B`@("!F=6YC=&EO;B!?7V=E="@D;F%M92D*("`@('L*("`@("`@("!S=VET
M8V@@*"1N86UE*2!["B`@("`@("`@8V%S92`G='EP92<Z"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^;F]D92T^;F]D951Y<&4["@H@("`@("`@(&-A<V4@
M)W1A9VYA;64G.@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/FYO9&4M/G1A
M9TYA;64["@H@("`@("`@(&-A<V4@)V-O;G1E;G0G.@H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/FYO9&4M/G1E>'1#;VYT96YT.PH*("`@("`@("!D969A
M=6QT.@H@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@
M?0H*("`@(&9U;F-T:6]N(&-H:6QD7VYO9&5S*"D*("`@('L*("`@("`@("`D
M;F]D94QI<W0@/2`D=&AI<RT^;F]D92T^8VAI;&1.;V1E<SL*("`@("`@("`D
M;F]D95-E="`](&%R<F%Y*"D["B`@("`@("`@:68@*&ES<V5T*"1N;V1E3&ES
M="DI('L*("`@("`@("`@("`@)&D@/2`P.PH@("`@("`@("`@("!W:&EL92`H
M)&YO9&4@/2`D;F]D94QI<W0M/FET96TH)&DI*2!["B`@("`@("`@("`@("`@
M("`D;F]D95-E=%M=(#T@;F5W($AO<F1E7T-O;F9I9U]%;&5M96YT*"1N;V1E
M*3L*("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1N;V1E4V5T.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&9I<G-T7V-H:6QD*"D*("`@('L*("`@("`@("!R971U<FX@;F5W($AO
M<F1E7T-O;F9I9U]%;&5M96YT*"1T:&ES+3YN;V1E+3YF:7)S=$-H:6QD*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!G971?8V]N=&5N="@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3YN;V1E+3YT97AT0V]N=&5N=#L*("`@('T*"B`@
M("!F=6YC=&EO;B!H87-?8VAI;&1?;F]D97,H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^;F]D92T^:&%S0VAI;&1.;V1E<R@I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&YE>'1?<VEB;&EN9R@I"B`@("!["B`@("`@("`@<F5T=7)N
M(&YE=R!(;W)D95]#;VYF:6=?16QE;65N="@D=&AI<RT^;F]D92T^;F5X=%-I
M8FQI;F<I.PH@("`@?0H*("`@(&9U;F-T:6]N(&YO9&5?=F%L=64H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^;F]D92T^;F]D959A;'5E.PH@("`@
M?0H*?0H*8VQA<W,@2&]R9&5?0V]N9FEG7T5L96UE;G0@97AT96YD<R!(;W)D
M95]#;VYF:6=?3F]D92!["@H@("`@9G5N8W1I;VX@9V5T7V%T=')I8G5T92@D
M;F%M92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FYO9&4M/F=E=$%T
M=')I8G5T92@D;F%M92D["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T-R>7!T+P``````````````````````````````````````````````
M```````````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U,``P,C`U-C,`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<```````````````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,30V,C`V`#$P-3$U-#,S-S4P`#`R
M,C`W,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92]#<GEP="YP:'`G.PH*+RHJ
M"B`J($%R;6]R($AE861E<B!,:6YE<R`M($9R;VT@4D9#(#(T-#`*("H*("H@
M($%N($%R;6]R($AE861E<B!,:6YE(&-O;G-I<W1S(&]F('1H92!A<'!R;W!R
M:6%T92!H96%D97(@;&EN92!T97AT"B`J("!S=7)R;W5N9&5D(&)Y(&9I=F4@
M*#4I(&1A<VAE<R`H)RTG+"`P>#)$*2!O;B!E:71H97(@<VED92!O9B!T:&4@
M:&5A9&5R"B`J("!L:6YE('1E>'0N(%1H92!H96%D97(@;&EN92!T97AT(&ES
M(&-H;W-E;B!B87-E9"!U<&]N('1H92!T>7!E(&]F(&1A=&$@=&AA=`H@*B`@
M:7,@8F5I;F<@96YC;V1E9"!I;B!!<FUO<BP@86YD(&AO=R!I="!I<R!B96EN
M9R!E;F-O9&5D+B!(96%D97(@;&EN92!T97AT<PH@*B`@:6YC;'5D92!T:&4@
M9F]L;&]W:6YG('-T<FEN9W,Z"B`J"B`J("!!;&P@07)M;W(@2&5A9&5R($QI
M;F5S(&%R92!P<F5F:7AE9"!W:71H("=01U`G+@H@*@H@*B`@5&AE($%R;6]R
M(%1A:6P@3&EN92!I<R!C;VUP;W-E9"!I;B!T:&4@<V%M92!M86YN97(@87,@
M=&AE($%R;6]R($AE861E<@H@*B`@3&EN92P@97AC97!T('1H92!S=')I;F<@
M(D)%1TE.(B!I<R!R97!L86-E9"!B>2!T:&4@<W1R:6YG(")%3D0N(@H@*B\*
M"B\J*B!5<V5D(&9O<B!S:6=N960L(&5N8W)Y<'1E9"P@;W(@8V]M<')E<W-E
M9"!F:6QE<RX@*B\*9&5F:6YE*"=01U!?05)-3U)?34534T%'12<L(#$I.PH*
M+RHJ(%5S960@9F]R('-I9VYE9"!F:6QE<RX@*B\*9&5F:6YE*"=01U!?05)-
M3U)?4TE'3D5$7TU%4U-!1T4G+"`R*3L*"B\J*B!5<V5D(&9O<B!A<FUO<FEN
M9R!P=6)L:6,@:V5Y<RX@*B\*9&5F:6YE*"=01U!?05)-3U)?4%5"3$E#7TM%
M62<L(#,I.PH*+RHJ(%5S960@9F]R(&%R;6]R:6YG('!R:79A=&4@:V5Y<RX@
M*B\*9&5F:6YE*"=01U!?05)-3U)?4%))5D%415]+15DG+"`T*3L*"B\J*@H@
M*B!5<V5D(&9O<B!D971A8VAE9"!S:6=N871U<F5S+"!01U`O34E-12!S:6=N
M871U<F5S+"!A;F0@;F%T=7)E<R!F;VQL;W=I;F<*("H@8VQE87)S:6=N960@
M;65S<V%G97,N"B`J+PID969I;F4H)U!'4%]!4DU/4E]324=.05154D4G+"`U
M*3L*"B\J*B!296=U;&%R('1E>'0@8V]N=&%I;F5D(&EN(&%N(%!'4"!M97-S
M86=E+B`J+PID969I;F4H)U!'4%]!4DU/4E]415A4)RP@-BD["@H*+RHJ(%1H
M92!D969A=6QT('!U8FQI8R!01U`@:V5Y<V5R=F5R('1O('5S92X@*B\*9&5F
M:6YE*"=01U!?2T594T525D527U!50DQ)0R<L("=W=W=K97ES+G!G<"YN970G
M*3L*"B\J*@H@*B!4:&4@;G5M8F5R(&]F('1I;65S('1H92!K97ES97)V97(@
M<F5F=7-E<R!C;VYN96-T:6]N(&)E9F]R92!A;B!E<G)O<B!I<PH@*B!R971U
M<FYE9"X*("HO"F1E9FEN92@G4$=07TM%65-%4E9%4E]214954T4G+"`S*3L*
M"B\J*@H@*B!4:&4@;G5M8F5R(&]F('-E8V]N9',@=&AA="!02%`@=VEL;"!A
M='1E;7!T('1O(&-O;FYE8W0@=&\@=&AE(&ME>7-E<G9E<@H@*B!B969O<F4@
M:70@=VEL;"!S=&]P('!R;V-E<W-I;F<@=&AE(')E<75E<W0N"B`J+PID969I
M;F4H)U!'4%]+15E315)615)?5$E-14]55"<L(#$P*3L*"@HO*BH*("H@2&]R
M9&5?0W)Y<'1?<&=P.CH@<')O=FED97,@82!F<F%M97=O<FL@9F]R($AO<F1E
M(&%P<&QI8V%T:6]N<R!T;R!I;G1E<F%C=`H@*B!W:71H('1H92!'3E4@4')I
M=F%C>2!'=6%R9"!P<F]G<F%M("@B1VYU4$<B*2X@($=N=5!'(&EM<&QE;65N
M=',@=&AE($]P96Y01U`*("H@<W1A;F1A<F0@*%)&0R`R-#0P*2X*("H*("H@
M1VYU4$<@5V5B<VET93H@:'1T<#HO+W=W=RYG;G5P9RYO<F<O"B`J"B`J(%1H
M:7,@8VQA<W,@:&%S(&)E96X@9&5V96QO<&5D('=I=&@L(&%N9"!I<R!O;FQY
M(&=U87)A;G1E960@=&\@=V]R:R!W:71H+`H@*B!697)S:6]N(#$N,C$@;W(@
M86)O=F4@;V8@1VYU4$<N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`L=B`Q+C@U+C(N,34@,C`P-B\P-R\R,"`P.3HP,CHS
M."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L
M(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A
M<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#,N
M,`H@*B!`<&%C:V%G92!(;W)D95]#<GEP=`H@*B\*8VQA<W,@2&]R9&5?0W)Y
M<'1?<&=P(&5X=&5N9',@2&]R9&5?0W)Y<'0@>PH*("`@("\J*@H@("`@("H@
M4W1R:6YG<R!I;B!A<FUO<B!H96%D97(@;&EN97,@=7-E9"!T;R!D:7-T:6YG
M=6ES:"!B971W965N('1H92!D:69F97)E;G0*("`@("`J('1Y<&5S(&]F(%!'
M4"!D96-R>7!T:6]N+V5N8W)Y<'1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]A<FUO<B`](&%R<F%Y*`H@("`@("`@
M("=-15-304=%)R`@("`@("`@("`@(#T^("!01U!?05)-3U)?34534T%'12P*
M("`@("`@("`G4TE'3D5$($U%4U-!1T4G("`@("`]/B`@4$=07T%234]27U-)
M1TY%1%]-15-304=%+`H@("`@("`@("=054),24,@2T59($),3T-+)R`@(#T^
M("!01U!?05)-3U)?4%5"3$E#7TM%62P*("`@("`@("`G4%))5D%412!+15D@
M0DQ/0TLG("`]/B`@4$=07T%234]27U!2259!5$5?2T59+`H@("`@("`@("=3
M24=.05154D4G("`@("`@("`@(#T^("!01U!?05)-3U)?4TE'3D%455)%"B`@
M("`I.PH*("`@("\J*@H@("`@("H@5&AE(&QI<W0@;V8@4$=0(&AA<V@@86QG
M;W)I=&AM<R`H9G)O;2!21D,@,S$U-BDN"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]H87-H06QG(#T@87)R87DH"B`@("`@
M("`@,2`@/3X@("=P9W`M;60U)RP*("`@("`@("`R("`]/B`@)W!G<"US:&$Q
M)RP*("`@("`@("`S("`]/B`@)W!G<"UR:7!E;60Q-C`G+`H@("`@("`@(#4@
M(#T^("`G<&=P+6UD,B<L"B`@("`@("`@-B`@/3X@("=P9W`M=&EG97(Q.3(G
M+`H@("`@("`@(#<@(#T^("`G<&=P+6AA=F%L+34M,38P)RP*("`@("`@("`X
M("`]/B`@)W!G<"US:&$R-38G+`H@("`@("`@(#D@(#T^("`G<&=P+7-H83,X
M-"<L"B`@("`@("`@,3`@/3X@("=P9W`M<VAA-3$R)RP*("`@("D["@H@("`@
M+RHJ"B`@("`@*B!';G501R!P<F]G<F%M(&QO8V%T:6]N+V-O;6UO;B!O<'1I
M;VYS+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1?9VYU<&<["@H@("`@+RHJ"B`@("`@*B!&:6QE;F%M92!O9B!T:&4@=&5M
M<&]R87)Y('!U8FQI8R!K97ER:6YG+@H@("`@("H*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D7W!U8FQI8TME>7)I;F<["@H@("`@+RHJ
M"B`@("`@*B!&:6QE;F%M92!O9B!T:&4@=&5M<&]R87)Y('!R:79A=&4@:V5Y
M<FEN9RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)%]P<FEV871E2V5Y<FEN9SL*"B`@("`O*BH*("`@("`J(%1H92!E>&ES
M=&5N8V4@;V8@=&AI<R!P<F]P97)T>2!I;F1I8V%T97,@=&AA="!M=6QT:7!L
M92!R96-I<&EE;G0*("`@("`J(&5N8W)Y<'1I;VX@:7,@879A:6QA8FQE+@H@
M("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@("`J"B`@("`@*B!`
M9&5P<F5C871E9`H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO
M"B`@("!V87(@)&UU;'1I<&QE4F5C:7!I96YT16YC<GEP=&EO;B`]('1R=64[
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A<F%M<R`@4&%R86UE=&5R(&%R<F%Y(&-O;G1A:6YI
M;F<@=&AE('!A=&@@=&\@=&AE($=N=5!'"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@8FEN87)Y("AK97D@/2`G<')O9W)A;2<I(&%N9"!T;R!A('1E
M;7!O<F%R>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&1I<F5C=&]R
M>2X*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?0W)Y<'1?<&=P*"1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=&5M<&1I<B`]
M(%5T:6PZ.F-R96%T951E;7!$:7(H=')U92P@)'!A<F%M<ULG=&5M<"==*3L*
M"B`@("`@("`@:68@*&5M<'1Y*"1P87)A;7-;)W!R;V=R86TG72DI('L*("`@
M("`@("`@("`@2&]R9&4Z.F9A=&%L*%!%05(Z.G)A:7-E17)R;W(H7R@B5&AE
M(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T
M;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(BDI+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@('T*"B`@("`@("`@+RH@4W1O<F4@=&AE(&QO8V%T:6]N
M(&]F($=N=5!'(&%N9"!S970@8V]M;6]N(&]P=&EO;G,N("HO"B`@("`@("`@
M)'1H:7,M/E]G;G5P9R`](&%R<F%Y*`H@("`@("`@("`@("`D<&%R86US6R=P
M<F]G<F%M)UTL"B`@("`@("`@("`@("<M+6YO+71T>2<L"B`@("`@("`@("`@
M("<M+6YO+7-E8VUE;2UW87)N:6YG)RP*("`@("`@("`@("`@)RTM;F\M;W!T
M:6]N<R<L"B`@("`@("`@("`@("<M+6YO+61E9F%U;'0M:V5Y<FEN9R<L"B`@
M("`@("`@("`@("<M+7%U:65T)RP*("`@("`@("`@("`@)RTM>65S)RP*("`@
M("`@("`@("`@)RTM:&]M961I<B`G("X@)'1H:7,M/E]T96UP9&ER"B`@("`@
M("`@*3L*"B`@("`@("`@:68@*'-U8G-T<BA02%!?3U,L(#`L(#,I("$]("=7
M24XG*2!["B`@("`@("`@("`@(&%R<F%Y7W5N<VAI9G0H)'1H:7,M/E]G;G5P
M9RP@)TQ!3D<](#LG*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!'96YE<F%T97,@82!P97)S;VYA;"!0=6)L:6,O4')I=F%T92!K97EP86ER
M(&-O;6)I;F%T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)')E
M86QN86UE("`@(%1H92!N86UE('1O('5S92!F;W(@=&AE(&ME>2X*("`@("`J
M($!P87)A;2!S=')I;F<@)&5M86EL("`@("`@(%1H92!E;6%I;"!T;R!U<V4@
M9F]R('1H92!K97DN"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87-S<&AR87-E
M("!4:&4@<&%S<W!H<F%S92!T;R!U<V4@9F]R('1H92!K97DN"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1C;VUM96YT("`@("!4:&4@8V]M;65N="!T;R!U<V4@
M9F]R('1H92!K97DN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:V5Y;&5N9W1H
M("!4:&4@:V5Y;&5N9W1H('1O('5S92!F;W(@=&AE(&ME>2X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!C;VYS:7-T:6YG(&]F('1H
M92!P=6)L:6,@:V5Y(&%N9"!T:&4@<')I=F%T90H@("`@("H@("`@("`@("`@
M("`@("`@:V5Y+"!O<B!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("H@/'!R
M93X*("`@("`J(%)E='5R;B!A<G)A>3H*("`@("`J($ME>2`@("`@("`@("`@
M(%9A;'5E"B`@("`@*B`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H@("`@
M("H@)W!U8FQI8R<@("`]/B`@4'5B;&EC($ME>0H@("`@("H@)W!R:79A=&4G
M("`]/B`@4')I=F%T92!+97D*("`@("`J(#PO<')E/@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G96YE<F%T94ME>2@D<F5A;&YA;64L("1E;6%I;"P@)'!A<W-P
M:')A<V4L("1C;VUM96YT(#T@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`D:V5Y;&5N9W1H(#T@,3`R-"D*("`@('L*("`@("`@("`O*B!#:&5C:R!F
M;W(@<V5C=7)E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'-E8W5R95]C:&5C
M:R`]("1T:&ES+3YR97%U:7)E4V5C=7)E0V]N;F5C=&EO;B@I.PH@("`@("`@
M(&EF("AI<U]A*"1S96-U<F5?8VAE8VLL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1S96-U<F5?8VAE8VL["B`@("`@("`@?0H*("`@
M("`@("`O*B!#<F5A=&4@=&5M<"!F:6QE<R!T;R!H;VQD('1H92!G96YE<F%T
M960@:V5Y<RX@*B\*("`@("`@("`D<'5B7V9I;&4@/2`D=&AI<RT^7V-R96%T
M951E;7!&:6QE*"=H;W)D92UP9W`G*3L*("`@("`@("`D<V5C<F5T7V9I;&4@
M/2`D=&AI<RT^7V-R96%T951E;7!&:6QE*"=H;W)D92UP9W`G*3L*"B`@("`@
M("`@+RH@0W)E871E('1H92!C;VYF:6<@9FEL92!N96-E<W-A<GD@9F]R($=N
M=5!'('1O(')U;B!I;B!B871C:"!M;V1E+B`J+PH@("`@("`@("\J(%1/1$\Z
M(%-A;FET:7IE(&EN<'5T+"!-;W)E('5S97(@8W5S=&]M:7IA8FQE/R`J+PH@
M("`@("`@("1I;G!U="`](&%R<F%Y*"D["B`@("`@("`@)&EN<'5T6UT@/2`G
M)7!U8G)I;F<@)R`N("1P=6)?9FEL93L*("`@("`@("`D:6YP=71;72`]("<E
M<V5C<FEN9R`G("X@)'-E8W)E=%]F:6QE.PH@("`@("`@("1I;G!U=%M=(#T@
M)TME>2U4>7!E.B!$4T$G.PH@("`@("`@("1I;G!U=%M=(#T@)TME>2U,96YG
M=&@Z(#$P,C0G.PH@("`@("`@("1I;G!U=%M=(#T@)U-U8FME>2U4>7!E.B!%
M3$<M12<["B`@("`@("`@)&EN<'5T6UT@/2`G4W5B:V5Y+4QE;F=T:#H@)R`N
M("1K97EL96YG=&@["B`@("`@("`@)&EN<'5T6UT@/2`G3F%M92U296%L.B`G
M("X@)')E86QN86UE.PH@("`@("`@(&EF("@A96UP='DH)&-O;6UE;G0I*2![
M"B`@("`@("`@("`@("1I;G!U=%M=(#T@)TYA;64M0V]M;65N=#H@)R`N("1C
M;VUM96YT.PH@("`@("`@('T*("`@("`@("`D:6YP=71;72`]("=.86UE+45M
M86EL.B`G("X@)&5M86EL.PH@("`@("`@("1I;G!U=%M=(#T@)T5X<&ER92U$
M871E.B`P)SL*("`@("`@("`D:6YP=71;72`]("=087-S<&AR87-E.B`G("X@
M)'!A<W-P:')A<V4["B`@("`@("`@)&EN<'5T6UT@/2`G)6-O;6UI="<["@H@
M("`@("`@("\J(%)U;B!T:')O=6=H(&=P9R!B:6YA<GDN("HO"B`@("`@("`@
M)&-M9&QI;F4@/2!A<G)A>2@*("`@("`@("`@("`@)RTM9V5N+6ME>2<L"B`@
M("`@("`@("`@("<M+6)A=&-H)RP*("`@("`@("`@("`@)RTM87)M;W(G"B`@
M("`@("`@*3L*("`@("`@("`D=&AI<RT^7V-A;&Q'<&<H)&-M9&QI;F4L("=W
M)RP@)&EN<'5T*3L*"B`@("`@("`@+RH@1V5T('1H92!K97ES(&9R;VT@=&AE
M('1E;7`@9FEL97,N("HO"B`@("`@("`@)'!U8FQI8U]K97D@/2!F:6QE*"1P
M=6)?9FEL92D["B`@("`@("`@)'-E8W)E=%]K97D@/2!F:6QE*"1S96-R971?
M9FEL92D["@H@("`@("`@("\J($EF(&5I=&AE<B!K97D@:7,@96UP='DL('-O
M;65T:&EN9R!W96YT('=R;VYG+B`J+PH@("`@("`@(&EF("AE;7!T>2@D<'5B
M;&EC7VME>2D@?'P@96UP='DH)'-E8W)E=%]K97DI*2!["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E!U8FQI8R]0<FEV871E(&ME
M>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(BDL("=H;W)D92YE
M<G)O<B<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"=P=6)L
M:6,G(#T^("1P=6)L:6-?:V5Y+"`G<')I=F%T92<@/3X@)'-E8W)E=%]K97DI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!I;F9O<FUA=&EO;B!O
M;B!A(%!'4"!D871A(&)L;V-K+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'!G<&1A=&$@(%1H92!01U`@9&%T82!B;&]C:RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!W:71H(&EN9F]R;6%T:6]N(&]N
M('1H92!01U`@9&%T82!B;&]C:RX@268@86X*("`@("`J("`@("`@("`@("`@
M("`@(&5L96UE;G0@:7,@;F]T('!R97-E;G0@:6X@=&AE(&1A=&$@8FQO8VLL
M(&ET('=I;&P*("`@("`J("`@("`@("`@("`@("`@(&QI:V5W:7-E(&YO="!B
M92!S970@:6X@=&AE(&%R<F%Y+@H@("`@("H@/'!R93X*("`@("`J($%R<F%Y
M($9O<FUA=#H*("`@("`J("TM+2TM+2TM+2TM+2T*("`@("`J(%MP=6)L:6-?
M:V5Y72];<V5C<F5T7VME>5T@/3X@07)R87D*("`@("`J("`@*`H@("`@("H@
M("`@(%MC<F5A=&5D72`]/B!+97D@8W)E871I;VX@+2!53DE8('1I;65S=&%M
M<`H@("`@("H@("`@(%ME>'!I<F5S72`]/B!+97D@97AP:7)A=&EO;B`M(%5.
M25@@=&EM97-T86UP("@P(#T@;F5V97(@97AP:7)E<RD*("`@("`J("`@("!;
M<VEZ95T@("`@/3X@4VEZ92!O9B!T:&4@:V5Y(&EN(&)I=',*("`@("`J("`@
M*0H@("`@("H*("`@("`J(%MF:6YG97)P<FEN=%T@/3X@1FEN9V5R<')I;G0@
M;V8@=&AE(%!'4"!D871A("AI9B!A=F%I;&%B;&4I"B`@("`@*B`@("`@("`@
M("`@("`@("`@(#$V+6)I="!H97@@=F%L=64*("`@("`J"B`@("`@*B!;<VEG
M;F%T=7)E72`]/B!!<G)A>2`H"B`@("`@*B`@("`@6VED>VY]+R=?4TE'3D%4
M55)%)UT@/3X@07)R87D@*`H@("`@("H@("`@("`@("!;;F%M95T@("`@("`@
M(#T^($9U;&P@3F%M90H@("`@("H@("`@("`@("!;8V]M;65N=%T@("`@(#T^
M($-O;6UE;G0*("`@("`J("`@("`@("`@6V5M86EL72`@("`@("`]/B!%+6UA
M:6P@061D<F5S<PH@("`@("H@("`@("`@("!;9FEN9V5R<')I;G1=(#T^(#$V
M+6)I="!H97@@=F%L=64*("`@("`J("`@("`@("`@6V-R96%T961=("`@("`]
M/B!3:6=N871U<F4@8W)E871I;VX@+2!53DE8('1I;65S=&%M<`H@("`@("H@
M("`@("`@("!;;6EC86QG72`@("`@(#T^(%1H92!H87-H('5S960@=&\@8W)E
M871E('1H92!S:6=N871U<F4*("`@("`J("`@("`@("`@6W-I9U][:&5X?5T@
M("`]/B!!<G)A>2!;9&5T86EL<R!O9B!A('-I9R!V97)I9GEI;F<@=&AE($E$
M72`H"B`@("`@*B`@("`@("`@("`@("!;8W)E871E9%T@("`@(#T^(%-I9VYA
M='5R92!C<F5A=&EO;B`M(%5.25@@=&EM97-T86UP"B`@("`@*B`@("`@("`@
M("`@("!;9FEN9V5R<')I;G1=(#T^(#$V+6)I="!H97@@=F%L=64*("`@("`J
M("`@("`@("`@("`@(%MM:6-A;&==("`@("`@/3X@5&AE(&AA<V@@=7-E9"!T
M;R!C<F5A=&4@=&AE('-I9VYA='5R90H@("`@("H@("`@("`@("`I"B`@("`@
M*B`@("`@*0H@("`@("H@*0H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@("H@
M16%C:"!U<V5R($E$('=I;&P@8F4@<W1O<F5D(&EN('1H92!A<G)A>2`G<VEG
M;F%T=7)E)R!A;F0@:&%V92!D871A"B`@("`@*B!A<W-O8VEA=&5D('=I=&@@
M:70L(&EN8VQU9&EN9R!A;B!A<G)A>2!F;W(@:6YF;W)M871I;VX@;VX@96%C
M:`H@("`@("H@<VEG;F%T=7)E('1H870@:&%S('-I9VYE9"!T:&%T(%5)1"X@
M4VEG;F%T=7)E<R!N;W0@87-S;V-I871E9"!W:71H(&$*("`@("`J(%5)1"`H
M92YG+B!R979O8V%T:6]N('-I9VYA='5R97,@86YD('-U8B!K97ES*2!W:6QL
M(&)E('-T;W)E9"!U;F1E<B!T:&4*("`@("`J('-P96-I86P@:V5Y=V]R9"`G
M7U-)1TY!5%5212<N"B`@("`@*B\*("`@(&9U;F-T:6]N('!G<%!A8VME=$EN
M9F]R;6%T:6]N*"1P9W!D871A*0H@("`@>PH@("`@("`@("1D871A7V%R<F%Y
M(#T@87)R87DH*3L*("`@("`@("`D9FEN9V5R<')I;G0@/2`G)SL*("`@("`@
M("`D:&5A9&5R(#T@;G5L;#L*("`@("`@("`D:6YP=70@/2`D=&AI<RT^7V-R
M96%T951E;7!&:6QE*"=H;W)D92UP9W`G*3L*("`@("`@("`D<VEG7VED(#T@
M)'5I9%]I9'@@/2`P.PH*("`@("`@("`O*B!3=&]R92!M97-S86=E(&EN('1E
M;7!O<F%R>2!F:6QE+B`J+PH@("`@("`@("1F<"`](&9O<&5N*"1I;G!U="P@
M)W<K)RD["B`@("`@("`@9G!U=',H)&9P+"`D<&=P9&%T82D["B`@("`@("`@
M9F-L;W-E*"1F<"D["@H@("`@("`@("1C;61L:6YE(#T@87)R87DH"B`@("`@
M("`@("`@("<M+6QI<W0M<&%C:V5T<R<L"B`@("`@("`@("`@("1I;G!U=`H@
M("`@("`@("D["B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?8V%L;$=P9R@D
M8VUD;&EN92P@)W(G*3L*"B`@("`@("`@9F]R96%C:"`H97AP;&]D92@B7&XB
M+"`D<F5S=6QT+3YS=&1O=70I(&%S("1L:6YE*2!["B`@("`@("`@("`@("\J
M($AE861E<G,@87)E('!R969A8V5D('=I=&@@82`G.B<@87,@=&AE(&9I<G-T
M(&-H87)A8W1E<B!O;B!T:&4*("`@("`@("`@("`@("`@;&EN92X@*B\*("`@
M("`@("`@("`@:68@*'-T<G!O<R@D;&EN92P@)SHG*2`]/3T@,"D@>PH@("`@
M("`@("`@("`@("`@)&QO=V5R3&EN92`](%-T<FEN9SHZ;&]W97(H)&QI;F4I
M.PH*("`@("`@("`@("`@("`@("\J($EF('=E(&AA=F4@82!K97D@*')A=&AE
M<B!T:&%N(&$@<VEG;F%T=7)E(&)L;V-K*2P@9V5T('1H90H@("`@("`@("`@
M("`@("`@("`@:V5Y)W,@9FEN9V5R<')I;G0@*B\*("`@("`@("`@("`@("`@
M(&EF("AS=')P;W,H)&QO=V5R3&EN92P@)SIP=6)L:6,@:V5Y('!A8VME=#HG
M*2`A/3T@9F%L<V4@?'P*("`@("`@("`@("`@("`@("`@("!S=')P;W,H)&QO
M=V5R3&EN92P@)SIS96-R970@:V5Y('!A8VME=#HG*2`A/3T@9F%L<V4I('L*
M("`@("`@("`@("`@("`@("`@("`D8VUD;&EN92`](&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@("`@("`G+2UW:71H+6-O;&]N<R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("1I;G!U=`H@("`@("`@("`@("`@("`@("`@("D["B`@
M("`@("`@("`@("`@("`@("`@)&1A=&$@/2`D=&AI<RT^7V-A;&Q'<&<H)&-M
M9&QI;F4L("=R)RD["B`@("`@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T
M8V@H(B\H<V5C?'!U8BDZ+BHZ+BHZ+BHZ*%M!+48P+3E=>S$V?2DZ+R(L("1D
M871A+3YS=&1O=70L("1M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D9FEN9V5R<')I;G0@/2`D;6%T8VAE<ULR73L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M:68@*'-T<G!O<R@D;&]W97),:6YE+"`G.G!U8FQI8R!K97D@<&%C:V5T.B<I
M("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@("1H96%D97(@/2`G
M<'5B;&EC7VME>2<["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H<W1R<&]S
M*"1L;W=E<DQI;F4L("<Z<V5C<F5T(&ME>2!P86-K970Z)RD@(3T](&9A;'-E
M*2!["B`@("`@("`@("`@("`@("`@("`@)&AE861E<B`]("=S96-R971?:V5Y
M)SL*("`@("`@("`@("`@("`@('T@96QS96EF("AS=')P;W,H)&QO=V5R3&EN
M92P@)SIU<V5R(&ED('!A8VME=#HG*2`A/3T@9F%L<V4I('L*("`@("`@("`@
M("`@("`@("`@("`D=6ED7VED>"LK.PH@("`@("`@("`@("`@("`@("`@("1L
M:6YE(#T@<')E9U]R97!L86-E7V-A;&QB86-K*"<O7%Q<7'@H6S`M.6$M9EU[
M,GTI+R<L(&-R96%T95]F=6YC=&EO;B@G)&$G+"`G<F5T=7)N(&-H<BAH97AD
M96,H)&%;,5TI*3LG*2P@)&QI;F4I.PH@("`@("`@("`@("`@("`@("`@(&EF
M("AP<F5G7VUA=&-H*"(O7"(H6UY</%TK*5P\*%M>7#Y=*RE</EPB+R(L("1L
M:6YE+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&AE
M861E<B`]("=I9"<@+B`D=6ED7VED>#L*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*'!R96=?;6%T8V@H)R\H6UY<*%TK*5PH*"XK*5PI)"\G+"!T<FEM
M*"1M871C:&5S6S%=*2P@)&-O;6UE;G1?;6%T8VAE<RDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1D871A7V%R<F%Y6R=S:6=N871U<F4G75LD
M:&5A9&5R75LG;F%M92==(#T@=')I;2@D8V]M;65N=%]M871C:&5S6S%=*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D871A7V%R<F%Y6R=S:6=N
M871U<F4G75LD:&5A9&5R75LG8V]M;65N="==(#T@)&-O;6UE;G1?;6%T8VAE
M<ULR73L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1D871A7V%R<F%Y6R=S:6=N871U<F4G
M75LD:&5A9&5R75LG;F%M92==(#T@=')I;2@D;6%T8VAE<ULQ72D["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9&%T85]A<G)A>5LG<VEG;F%T=7)E
M)UU;)&AE861E<EU;)V-O;6UE;G0G72`]("<G.PH@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1D871A7V%R<F%Y
M6R=S:6=N871U<F4G75LD:&5A9&5R75LG96UA:6PG72`]("1M871C:&5S6S)=
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D9&%T85]A<G)A>5LG<VEG;F%T
M=7)E)UU;)&AE861E<EU;)V9I;F=E<G!R:6YT)UT@/2`D9FEN9V5R<')I;G0[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E
M:68@*'-T<G!O<R@D;&]W97),:6YE+"`G.G-I9VYA='5R92!P86-K970Z)RD@
M(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1H
M96%D97(I('Q\(&5M<'1Y*"1U:61?:61X*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D:&5A9&5R(#T@)U]324=.05154D4G.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@B
M+VME>6ED7',K*%LP+3E!+49=*RDO:2(L("1L:6YE+"`D;6%T8VAE<RDI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'-I9U]I9"`]("1M871C:&5S6S%=
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D9&%T85]A<G)A>5LG<VEG;F%T
M=7)E)UU;)&AE861E<EU;)W-I9U\G("X@)'-I9U]I9%U;)V9I;F=E<G!R:6YT
M)UT@/2`D;6%T8VAE<ULQ73L*("`@("`@("`@("`@("`@("`@("`@("`@)&1A
M=&%?87)R87E;)V9I;F=E<G!R:6YT)UT@/2`D;6%T8VAE<ULQ73L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("1H96%D97(@/2!N=6QL.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:68@
M*"@D:&5A9&5R(#T]("=S96-R971?:V5Y)RD@?'P@*"1H96%D97(@/3T@)W!U
M8FQI8U]K97DG*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA
M=&-H*"(O8W)E871E9%QS*RA<9"LI+%QS*V5X<&ER97-<<RLH7&0K*2]I(BP@
M)&QI;F4L("1M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M9&%T85]A<G)A>5LD:&5A9&5R75LG8W)E871E9"==(#T@)&UA=&-H97-;,5T[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1D871A7V%R<F%Y6R1H96%D97)=
M6R=E>'!I<F5S)UT@/2`D;6%T8VAE<ULR73L*("`@("`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H<')E9U]M871C:"@B+UQS*UMS<%UK97E<6S!<73I<<RM<
M6RA<9"LI+VDB+"`D;&EN92P@)&UA=&-H97,I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1D871A7V%R<F%Y6R1H96%D97)=6R=S:7IE)UT@/2`D;6%T
M8VAE<ULQ73L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H)&AE861E<BD@>PH@("`@("`@("`@("`@("`@("`@(&EF
M("AP<F5G7VUA=&-H*"(O=F5R<VEO;EQS*UQD*RQ<<RMC<F5A=&5D7',K*%QD
M*RDO:2(L("1L:6YE+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&1A=&%?87)R87E;)W-I9VYA='5R92==6R1H96%D97)=6R=S:6=?
M)R`N("1S:6=?:61=6R=C<F5A=&5D)UT@/2`D;6%T8VAE<ULQ73L*("`@("`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@B+V1I9V5S="!A
M;&=O7',K*%QD>S%]*2\B+"`D;&EN92P@)&UA=&-H97,I*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1M:6-A;&<@/2`D=&AI<RT^7VAA<VA!;&=;)&UA
M=&-H97-;,5U=.PH@("`@("`@("`@("`@("`@("`@("`@("`D9&%T85]A<G)A
M>5LG<VEG;F%T=7)E)UU;)&AE861E<EU;)W-I9U\G("X@)'-I9U]I9%U;)VUI
M8V%L9R==(#T@)&UI8V%L9SL*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"1H96%D97(@/3T@)U]324=.05154D4G*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O*B!,:6ME;'D@82!S:6=N871U<F4@8FQO8VLL(&YO="!A
M(&ME>2X@*B\*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D871A7V%R
M<F%Y6R=S:6=N871U<F4G75LG7U-)1TY!5%5212==6R=M:6-A;&<G72`]("1M
M:6-A;&<["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"1S:6=?:60@/3T@)&9I;F=E<G!R:6YT*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`O*B!396QF('-I9VYI;F<@<VEG
M;F%T=7)E("T@=V4@8V%N(&%S<W5M92!T:&4*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&UI8V%L9R!V86QU92!F<F]M('1H:7,@<VEG;F%T=7)E
M(&ES('1H870@9F]R"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T
M:&4@:V5Y("HO"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T85]A
M<G)A>5LG<VEG;F%T=7)E)UU;)U]324=.05154D4G75LG;6EC86QG)UT@/2`D
M;6EC86QG.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&%?87)R
M87E;)W-I9VYA='5R92==6R1H96%D97)=6R=M:6-A;&<G72`]("1M:6-A;&<[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("1F:6YG97)P<FEN="`F)B`D9&%T85]A<G)A>5LG9FEN9V5R
M<')I;G0G72`]("1F:6YG97)P<FEN=#L*"B`@("`@("`@<F5T=7)N("1D871A
M7V%R<F%Y.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!H=6UA;B!R
M96%D86)L92!I;F9O<FUA=&EO;B!O;B!A(%!'4"!K97DN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&=P9&%T82`@5&AE(%!'4"!D871A(&)L;V-K
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!486)U;&%R(&EN9F]R
M;6%T:6]N(&]N('1H92!01U`@:V5Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!P
M9W!0<F5T='E+97DH)'!G<&1A=&$I"B`@("!["B`@("`@("`@)&US9R`]("<G
M.PH@("`@("`@("1P86-K971?:6YF;R`]("1T:&ES+3YP9W!086-K971);F9O
M<FUA=&EO;B@D<&=P9&%T82D["@H@("`@("`@(&EF("@A96UP='DH)'!A8VME
M=%]I;F9O6R=S:6=N871U<F4G72DI('L*("`@("`@("`@("`@+RH@36%K:6YG
M('1H92!P<F]P97)T>2!N86UE<R!T:&4@<V%M92!W:61T:"!F;W(@86QL"B`@
M("`@("`@("`@("`J(&QO8V%L:7IA=&EO;G,@+BHO"B`@("`@("`@("`@("1L
M969T<F]W(#T@87)R87DH7R@B3F%M92(I+"!?*")+97D@5'EP92(I+"!?*")+
M97D@0W)E871I;VXB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?
M*")%>'!I<F%T:6]N($1A=&4B*2P@7R@B2V5Y($QE;F=T:"(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%\H(D-O;6UE;G0B*2P@7R@B12U-86EL
M(BDL(%\H(DAA<V@M06QG;W)I=&AM(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@7R@B2V5Y($9I;F=E<G!R:6YT(BDI.PH@("`@("`@("`@("`D
M;&5F='=I9'1H(#T@87)R87E?;6%P*"=S=')L96XG+"`D;&5F=')O=RD["B`@
M("`@("`@("`@("1M87AW:61T:"`@/2!M87@H)&QE9G1W:61T:"D@*R`R.PH@
M("`@("`@("`@("!A<G)A>5]W86QK*"1L969T<F]W+"!C<F5A=&5?9G5N8W1I
M;VXH)R8D<RP@)&LL("1M)RP@)R1S(#T@)',@+B`B.B(@+B!S=')?<F5P96%T
M*"(@(BP@)&T@+2!3=')I;F<Z.FQE;F=T:"@D<RDI.R<I+"`D;6%X=VED=&@I
M.PH*("`@("`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D<&%C:V5T7VEN
M9F];)W-I9VYA='5R92==*2!A<R`D=6ED7VED>"D@>PH@("`@("`@("`@("`@
M("`@:68@*"1U:61?:61X(#T]("=?4TE'3D%455)%)RD@8V]N=&EN=64["B`@
M("`@("`@("`@("`@("`D:V5Y7VEN9F\@/2`D=&AI<RT^<&=P4&%C:V5T4VEG
M;F%T=7)E0GE5:61);F1E>"@D<&=P9&%T82P@)'5I9%]I9'@I.PH@("`@("`@
M("`@("`@("`@)&US9R`N/2`D;&5F=')O=ULP72`N('-T<FEP8W-L87-H97,H
M)&ME>5]I;F9O6R=N86UE)UTI("X@(EQN(CL*("`@("`@("`@("`@("`@("1M
M<V<@+CT@)&QE9G1R;W=;,5T@+B`H*"1K97E?:6YF;ULG:V5Y7W1Y<&4G72`]
M/2`G<'5B;&EC7VME>2<I(#\@7R@B4'5B;&EC($ME>2(I(#H@7R@B4')I=F%T
M92!+97DB*2D@+B`B7&XB.PH@("`@("`@("`@("`@("`@)&US9R`N/2`D;&5F
M=')O=ULR72`N('-T<F9T:6UE*"(E1"(L("1K97E?:6YF;ULG:V5Y7V-R96%T
M960G72D@+B`B7&XB.PH@("`@("`@("`@("`@("`@)&US9R`N/2`D;&5F=')O
M=ULS72`N("AE;7!T>2@D:V5Y7VEN9F];)VME>5]E>'!I<F5S)UTI(#\@)ULG
M("X@7R@B3F5V97(B*2`N("==)R`Z('-T<F9T:6UE*"(E1"(L("1K97E?:6YF
M;ULG:V5Y7V5X<&ER97,G72DI("X@(EQN(CL*("`@("`@("`@("`@("`@("1M
M<V<@+CT@)&QE9G1R;W=;-%T@+B`D:V5Y7VEN9F];)VME>5]S:7IE)UT@+B`B
M($)Y=&5S7&XB.PH@("`@("`@("`@("`@("`@)&US9R`N/2`D;&5F=')O=ULU
M72`N("AE;7!T>2@D:V5Y7VEN9F];)V-O;6UE;G0G72D@/R`G6R<@+B!?*").
M;VYE(BD@+B`G72<@.B`D:V5Y7VEN9F];)V-O;6UE;G0G72D@+B`B7&XB.PH@
M("`@("`@("`@("`@("`@)&US9R`N/2`D;&5F=')O=ULV72`N("1K97E?:6YF
M;ULG96UA:6PG72`N(")<;B(["B`@("`@("`@("`@("`@("`D;7-G("X]("1L
M969T<F]W6S==("X@*&5M<'1Y*"1K97E?:6YF;ULG;6EC86QG)UTI(#\@)ULG
M("X@7R@B56YK;F]W;B(I("X@)UTG(#H@)&ME>5]I;F9O6R=M:6-A;&<G72D@
M+B`B7&XB.PH@("`@("`@("`@("`@("`@)&US9R`N/2`D;&5F=')O=ULX72`N
M("AE;7!T>2@D:V5Y7VEN9F];)V9I;F=E<G!R:6YT)UTI(#\@)ULG("X@7R@B
M56YK;F]W;B(I("X@)UTG(#H@)&ME>5]I;F9O6R=F:6YG97)P<FEN="==*2`N
M(")<;EQN(CL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1M<V<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&]N;'D@
M:6YF;W)M871I;VX@;VX@=&AE(&9I<G-T($E$('1H870@;6%T8VAE<R!T:&4@
M96UA:6P@861D<F5S<PH@("`@("H@:6YP=70N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<&=P9&%T82`@5&AE(%!'4"!D871A(&)L;V-K+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D96UA:6P@("`@06X@92UM86EL(&%D9')E<W,N
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@=VET:"!I
M;F9O<FUA=&EO;B!O;B!T:&4@4$=0(&1A=&$@8FQO8VLN($EF(&%N"B`@("`@
M*B`@("`@("`@("`@("`@("!E;&5M96YT(&ES(&YO="!P<F5S96YT(&EN('1H
M92!D871A(&)L;V-K+"!I="!W:6QL"B`@("`@*B`@("`@("`@("`@("`@("!L
M:6ME=VES92!N;W0@8F4@<V5T(&EN('1H92!A<G)A>2X*("`@("`J(#QP<F4^
M"B`@("`@*B!!<G)A>2!&:65L9',Z"B`@("`@*B`M+2TM+2TM+2TM+2TM"B`@
M("`@*B!K97E?8W)E871E9"`@/3X@($ME>2!C<F5A=&EO;B`M(%5.25@@=&EM
M97-T86UP"B`@("`@*B!K97E?97AP:7)E<R`@/3X@($ME>2!E>'!I<F%T:6]N
M("T@54Y)6"!T:6UE<W1A;7`@*#`@/2!N979E<B!E>'!I<F5S*0H@("`@("H@
M:V5Y7W-I>F4@("`@(#T^("!3:7IE(&]F('1H92!K97D@:6X@8FET<PH@("`@
M("H@:V5Y7W1Y<&4@("`@(#T^("!4:&4@:V5Y('1Y<&4@*'!U8FQI8U]K97D@
M;W(@<V5C<F5T7VME>2D*("`@("`J(&YA;64@("`@("`@("`]/B`@1G5L;"!.
M86UE"B`@("`@*B!C;VUM96YT("`@("`@/3X@($-O;6UE;G0*("`@("`J(&5M
M86EL("`@("`@("`]/B`@12UM86EL($%D9')E<W,*("`@("`J(&9I;F=E<G!R
M:6YT("`]/B`@,38M8FET(&AE>"!V86QU90H@("`@("H@8W)E871E9"`@("`@
M(#T^("!3:6=N871U<F4@8W)E871I;VX@+2!53DE8('1I;65S=&%M<`H@("`@
M("H@;6EC86QG("`@("`@(#T^("!4:&4@:&%S:"!U<V5D('1O(&-R96%T92!T
M:&4@<VEG;F%T=7)E"B`@("`@*B`\+W!R93X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<&=P4&%C:V5T4VEG;F%T=7)E*"1P9W!D871A+"`D96UA:6PI"B`@("![
M"B`@("`@("`@)&1A=&$@/2`D=&AI<RT^<&=P4&%C:V5T26YF;W)M871I;VXH
M)'!G<&1A=&$I.PH@("`@("`@("1K97E?='EP92`](&YU;&P["B`@("`@("`@
M)')E='5R;E]A<G)A>2`](&%R<F%Y*"D["@H@("`@("`@("\J($-H96-K('1H
M870@6W-I9VYA='5R95T@:V5Y(&5X:7-T<RX@*B\*("`@("`@("!I9B`H(6ES
M<V5T*"1D871A6R=S:6=N871U<F4G72DI('L*("`@("`@("`@("`@<F5T=7)N
M("1R971U<FY?87)R87D["B`@("`@("`@?0H*("`@("`@("`O*B!3=&]R92!T
M:&4@<VEG;F%T=7)E(&EN9F]R;6%T:6]N(&YO=RX@*B\*("`@("`@("!I9B`H
M*"1E;6%I;"`]/2`G7U-)1TY!5%5212<I("8F"B`@("`@("`@("`@(&ES<V5T
M*"1D871A6R=S:6=N871U<F4G75LG7U-)1TY!5%5212==*2D@>PH@("`@("`@
M("`@("!F;W)E86-H("@D9&%T85LG<VEG;F%T=7)E)UU;)&5M86EL72!A<R`D
M:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`@("`@)')E='5R;E]A<G)A
M>5LD:V5Y72`]("1V86QU93L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1U:61?:61X(#T@,3L*"B`@("`@("`@("`@('=H
M:6QE("AI<W-E="@D9&%T85LG<VEG;F%T=7)E)UU;)VED)R`N("1U:61?:61X
M72DI('L*("`@("`@("`@("`@("`@(&EF("@D9&%T85LG<VEG;F%T=7)E)UU;
M)VED)R`N("1U:61?:61X75LG96UA:6PG72`]/2`D96UA:6PI('L*("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("@D9&%T85LG<VEG;F%T=7)E)UU;)VED
M)R`N("1U:61?:61X72!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)')E='5R;E]A<G)A>5LD:V5Y72`]("1V86P["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'5I9%]I9'@K*SL*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<&=P4&%C:V5T4VEG;F%T=7)E*"1D871A+"`D<F5T=7)N7V%R<F%Y*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@:6YF;W)M871I;VX@;VX@
M82!01U`@<VEG;F%T=7)E(&5M8F5D9&5D(&EN(%!'4"!D871A+B`@4VEM:6QA
M<@H@("`@("H@=&\@<&=P4&%C:V5T4VEG;F%T=7)E*"DL(&)U="!R971U<FYS
M(&EN9F]R;6%T:6]N(&)Y('5N:7%U92!5<V5R($E$"B`@("`@*B!);F1E>"`H
M9F]R;6%T(&ED>VY]('=H97)E(&X@:7,@86X@:6YT96=E<B!O9B`Q(&]R(&=R
M96%T97(I+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!G<&1A=&$@
M("!3964@<&=P4&%C:V5T4VEG;F%T=7)E*"DN"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D=6ED7VED>"`@5&AE(%5)1"!I;F1E>"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!3964@<&=P4&%C:V5T4VEG;F%T=7)E*"DN"B`@("`@
M*B\*("`@(&9U;F-T:6]N('!G<%!A8VME=%-I9VYA='5R94)Y56ED26YD97@H
M)'!G<&1A=&$L("1U:61?:61X*0H@("`@>PH@("`@("`@("1D871A(#T@)'1H
M:7,M/G!G<%!A8VME=$EN9F]R;6%T:6]N*"1P9W!D871A*3L*("`@("`@("`D
M:V5Y7W1Y<&4@/2!N=6QL.PH@("`@("`@("1R971U<FY?87)R87D@/2!A<G)A
M>2@I.PH*("`@("`@("`O*B!396%R8V@@9F]R('1H92!5240@:6YD97@N("HO
M"B`@("`@("`@:68@*"%I<W-E="@D9&%T85LG<VEG;F%T=7)E)UTI('Q\"B`@
M("`@("`@("`@("%I<W-E="@D9&%T85LG<VEG;F%T=7)E)UU;)'5I9%]I9'A=
M*2D@>PH@("`@("`@("`@("!R971U<FX@)')E='5R;E]A<G)A>3L*("`@("`@
M("!]"@H@("`@("`@("\J(%-T;W)E('1H92!S:6=N871U<F4@:6YF;W)M871I
M;VX@;F]W+B`J+PH@("`@("`@(&9O<F5A8V@@*"1D871A6R=S:6=N871U<F4G
M75LD=6ED7VED>%T@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@
M)')E='5R;E]A<G)A>5LD:V5Y72`]("1V86QU93L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D=&AI<RT^7W!G<%!A8VME=%-I9VYA='5R92@D9&%T82P@
M)')E='5R;E]A<G)A>2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S('-O
M;64@9&%T82!T;R!T:&4@<&=P4&%C:V5T4VEG;F%T=7)E*B@I(&9U;F-T:6]N
M(&%R<F%Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D9&%T82`@("`@(%-E92!P9W!086-K9713
M:6=N871U<F4H*2X*("`@("`J($!P87)A;2!A<G)A>2`D<F5T87)R87D@(%1H
M92!R971U<FX@87)R87DN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M5&AE(')E='5R;B!A<G)A>2X*("`@("`J+PH@("`@9G5N8W1I;VX@7W!G<%!A
M8VME=%-I9VYA='5R92@D9&%T82P@)')E=&%R<F%Y*0H@("`@>PH@("`@("`@
M("\J($EF(&5M<'1Y+"!R971U<FX@;F]W+B`J+PH@("`@("`@(&EF("AE;7!T
M>2@D<F5T87)R87DI*2!["B`@("`@("`@("`@(')E='5R;B`D<F5T87)R87D[
M"B`@("`@("`@?0H*("`@("`@("`D:V5Y7W1Y<&4@/2!N=6QL.PH*("`@("`@
M("`O*B!3=&]R92!A;GD@<'5B;&EC+W!R:79A=&4@:V5Y(&EN9F]R;6%T:6]N
M+B`J+PH@("`@("`@(&EF("AI<W-E="@D9&%T85LG<'5B;&EC7VME>2==*2D@
M>PH@("`@("`@("`@("`D:V5Y7W1Y<&4@/2`G<'5B;&EC7VME>2<["B`@("`@
M("`@?2!E;'-E:68@*&ES<V5T*"1D871A6R=S96-R971?:V5Y)UTI*2!["B`@
M("`@("`@("`@("1K97E?='EP92`]("=S96-R971?:V5Y)SL*("`@("`@("!]
M"@H@("`@("`@(&EF("@D:V5Y7W1Y<&4I('L*("`@("`@("`@("`@)')E=&%R
M<F%Y6R=K97E?='EP92==(#T@)&ME>5]T>7!E.PH@("`@("`@("`@("!I9B`H
M:7-S970H)&1A=&%;)&ME>5]T>7!E75LG8W)E871E9"==*2D@>PH@("`@("`@
M("`@("`@("`@)')E=&%R<F%Y6R=K97E?8W)E871E9"==(#T@)&1A=&%;)&ME
M>5]T>7!E75LG8W)E871E9"==.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("AI<W-E="@D9&%T85LD:V5Y7W1Y<&5=6R=E>'!I<F5S)UTI*2!["B`@
M("`@("`@("`@("`@("`D<F5T87)R87E;)VME>5]E>'!I<F5S)UT@/2`D9&%T
M85LD:V5Y7W1Y<&5=6R=E>'!I<F5S)UT["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*&ES<V5T*"1D871A6R1K97E?='EP95U;)W-I>F4G72DI('L*
M("`@("`@("`@("`@("`@("1R971A<G)A>5LG:V5Y7W-I>F4G72`]("1D871A
M6R1K97E?='EP95U;)W-I>F4G73L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1R971A<G)A>3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE('-H;W)T(&9I;F=E<G!R:6YT("A+97D@240I(&]F
M('1H92!K97D@=7-E9"!T;R!S:6=N(&$@8FQO8VL*("`@("`J(&]F(%!'4"!D
M871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!0
M1U`@<VEG;F5D('1E>'0@8FQO8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!S:&]R="!F:6YG97)P<FEN="!O9B!T:&4@:V5Y('5S960@
M=&\@<VEG;B`D=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4VEG;F5R
M<T9I;F=E<G!R:6YT*"1T97AT*0H@("`@>PH@("`@("`@("1F:6YG97)P<FEN
M="`](&YU;&P["@H@("`@("`@("1I;G!U="`]("1T:&ES+3Y?8W)E871E5&5M
M<$9I;&4H)VAO<F1E+7!G<"<I.PH*("`@("`@("`D9G`@/2!F;W!E;B@D:6YP
M=70L("=W*R<I.PH@("`@("`@(&9P=71S*"1F<"P@)'1E>'0I.PH@("`@("`@
M(&9C;&]S92@D9G`I.PH*("`@("`@("`D8VUD;&EN92`](&%R<F%Y*`H@("`@
M("`@("`@("`G+2UV97)I9GDG+`H@("`@("`@("`@("`D:6YP=70L"B`@("`@
M("`@("`@("<R/B8Q)PH@("`@("`@("D["B`@("`@("`@)')E<W5L="`]("1T
M:&ES+3Y?8V%L;$=P9R@D8VUD;&EN92P@)W(G*3L*("`@("`@("!I9B`H<')E
M9U]M871C:"@G+V=P9SI<<U-I9VYA='5R95QS;6%D92XJ241<<RLH6T$M1C`M
M.5U[.'TI7',K+R<L("1R97-U;'0M/G-T9&]U="P@)&UA=&-H97,I*2!["B`@
M("`@("`@("`@("1F:6YG97)P<FEN="`]("1M871C:&5S6S%=.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1F:6YG97)P<FEN=#L*("`@('T*"B`@("`O
M*BH*("`@("`J(%9E<FEF>2!A('!A<W-P:')A<V4@9F]R(&$@9VEV96X@<'5B
M;&EC+W!R:79A=&4@:V5Y<&%I<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1P=6)L:6-?:V5Y("`@5&AE('5S97(G<R!01U`@<'5B;&EC(&ME>2X*
M("`@("`J($!P87)A;2!S=')I;F<@)'!R:79A=&5?:V5Y("!4:&4@=7-E<B=S
M(%!'4"!P<FEV871E(&ME>2X*("`@("`J($!P87)A;2!S=')I;F<@)'!A<W-P
M:')A<V4@("!4:&4@=7-E<B=S('!A<W-P:')A<V4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!2971U<FYS('1R=64@;VX@=F%L:60@<&%S<W!H
M<F%S92P@9F%L<V4@;VX@:6YV86QI9`H@("`@("H@("`@("`@("`@("`@("`@
M("!P87-S<&AR87-E+"!A;F0@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@=F5R:69Y4&%S<W!H<F%S92@D<'5B;&EC7VME>2P@
M)'!R:79A=&5?:V5Y+"`D<&%S<W!H<F%S92D*("`@('L*("`@("`@("`O*B!#
M:&5C:R!F;W(@<V5C=7)E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'-E8W5R
M95]C:&5C:R`]("1T:&ES+3YR97%U:7)E4V5C=7)E0V]N;F5C=&EO;B@I.PH@
M("`@("`@(&EF("AI<U]A*"1S96-U<F5?8VAE8VLL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1S96-U<F5?8VAE8VL["B`@("`@("`@
M?0H*("`@("`@("`O*B!%;F-R>7!T(&$@=&5S="!M97-S86=E+B`J+PH@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^96YC<GEP="@G5&5S="<L(&%R<F%Y*"=T
M>7!E)R`]/B`G;65S<V%G92<L("=P=6)K97DG(#T^("1P=6)L:6-?:V5Y*2D[
M"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O
M*B!4<GD@=&\@9&5C<GEP="!T:&4@;65S<V%G92X@*B\*("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/F1E8W)Y<'0H)')E<W5L="P@87)R87DH)W1Y<&4G(#T^
M("=M97-S86=E)RP@)W!U8FME>2<@/3X@)'!U8FQI8U]K97DL("=P<FEV:V5Y
M)R`]/B`D<')I=F%T95]K97DL("=P87-S<&AR87-E)R`]/B`D<&%S<W!H<F%S
M92DI.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!087)S97,@
M82!M97-S86=E(&EN=&\@=&5X="!A;F0@4$=0(&-O;7!O;F5N=',N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@=&\@<&%R
M<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@=VET
M:"!T:&4@<&%R<V5D('1E>'0L(')E='5R;F5D(&EN(&)L;V-K<R!O9@H@("`@
M("H@("`@("`@("`@("`@("`@=&5X="!C;W)R97-P;VYD:6YG('1O('1H96ER
M(&%C='5A;"!O<F1E<BX*("`@("`J(#QP<F4^"B`@("`@*B!2971U<FX@87)R
M87DZ"B`@("`@*B!+97D@("`@("`@("!686QU90H@("`@("H@+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H@("`@
M("H@)W1Y<&4G("`]/B`@5&AE('1Y<&4@;V8@9&%T82!C;VYT86EN960@:6X@
M8FQO8VLN"B`@("`@*B`@("`@("`@("`@("!686QI9"!T>7!E<R!A<F4@9&5F
M:6YE9"!A="!T:&4@=&]P(&]F('1H:7,@8VQA<W,*("`@("`J("`@("`@("`@
M("`@("AT:&4@4$=07T%234]27RH@8V]N<W1A;G1S*2X*("`@("`J("=D871A
M)R`@/3X@(%1H92!A8W1U86P@9&%T82!F;W(@96%C:"!S96-T:6]N+@H@("`@
M("H@/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T:6]N('!A<G-E4$=01&%T82@D
M=&5X="D*("`@('L*("`@("`@("`D9&%T82`](&%R<F%Y*"D["@H@("`@("`@
M("1B=69F97(@/2!E>'!L;V1E*")<;B(L("1T97AT*3L*"B`@("`@("`@+RH@
M4V5T("1T96UP7V%R<F%Y('1O(&)E(&]F('1Y<&4@4$=07T%234]27U1%6%0N
M("HO"B`@("`@("`@)'1E;7!?87)R87D@/2!A<G)A>2@I.PH@("`@("`@("1T
M96UP7V%R<F%Y6R=T>7!E)UT@/2!01U!?05)-3U)?5$585#L*"B`@("`@("`@
M9F]R96%C:"`H)&)U9F9E<B!A<R`D=F%L=64I('L*("`@("`@("`@("`@:68@
M*'!R96=?;6%T8V@H)R]>+2TM+2TH0D5'24Y\14Y$*2!01U`@*%M>+5TK*2TM
M+2TM7',J)"\G+"`D=F%L=64L("1M871C:&5S*2D@>PH@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1T96UP7V%R<F%Y6R=D871A)UTI*2!["B`@("`@("`@
M("`@("`@("`@("`@)&1A=&%;72`]("1T96UP7V%R<F%Y.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@=6YS970H)'1E;7!?87)R87DI.PH@
M("`@("`@("`@("`@("`@)'1E;7!?87)R87D@/2!A<G)A>2@I.PH*("`@("`@
M("`@("`@("`@(&EF("@D;6%T8VAE<ULQ72`]/3T@)T)%1TE.)RD@>PH@("`@
M("`@("`@("`@("`@("`@("1T96UP7V%R<F%Y6R=T>7!E)UT@/2`D=&AI<RT^
M7V%R;6]R6R1M871C:&5S6S)=73L*("`@("`@("`@("`@("`@("`@("`D=&5M
M<%]A<G)A>5LG9&%T82==6UT@/2`D=F%L=64["B`@("`@("`@("`@("`@("!]
M(&5L<V5I9B`H)&UA=&-H97-;,5T@/3T]("=%3D0G*2!["B`@("`@("`@("`@
M("`@("`@("`@)'1E;7!?87)R87E;)W1Y<&4G72`](%!'4%]!4DU/4E]415A4
M.PH@("`@("`@("`@("`@("`@("`@("1D871A6V-O=6YT*"1D871A*2`M(#%=
M6R=D871A)UU;72`]("1V86QU93L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T96UP7V%R<F%Y6R=D
M871A)UU;72`]("1V86QU93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@:68@*&ES<V5T*"1T96UP7V%R<F%Y6R=D871A)UTI*2!["B`@("`@
M("`@("`@("1D871A6UT@/2`D=&5M<%]A<G)A>3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@82!01U`@<'5B;&EC(&ME>2!F<F]M(&$@<'5B;&EC(&ME>7-E<G9E<BX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F<')I;G0@(%1H92!F:6YG
M97)P<FEN="!O9B!T:&4@4$=0(&ME>2X*("`@("`J($!P87)A;2!S=')I;F<@
M)'-E<G9E<B`@5&AE(&ME>7-E<G9E<B!T;R!U<V4N"B`@("`@*B!`<&%R86T@
M9FQO870@)'1I;65O=70@(%1H92!K97ES97)V97(@=&EM96]U="X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(%!'4"!P=6)L:6,@:V5Y+"!O
M<B!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9710=6)L:6-+97ES97)V97(H)&9P<FEN="P@)'-E<G9E<B`](%!'4%]+15E3
M15)615)?4%5"3$E#+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:6UE;W5T(#T@4$=07TM%65-%4E9%4E]424U%3U54*0H@("`@>PH@("`@
M("`@("\J($=E="!T:&4@."!C:&%R86-T97(@9FEN9V5R<')I;G0@<W1R:6YG
M+B`J+PH@("`@("`@(&EF("AS=')P;W,H)&9P<FEN="P@)S!X)RD@/3T](#`I
M('L*("`@("`@("`@("`@)&9P<FEN="`]('-U8G-T<B@D9G!R:6YT+"`R*3L*
M("`@("`@("!]"B`@("`@("`@:68@*'-T<FQE;B@D9G!R:6YT*2`^(#@I('L*
M("`@("`@("`@("`@)&9P<FEN="`]('-U8G-T<B@D9G!R:6YT+"`X*3L*("`@
M("`@("!]"B`@("`@("`@)&9P<FEN="`]("<P>"<@+B`D9G!R:6YT.PH*("`@
M("`@("`O*B!#;VYN96-T('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B`J+PH@
M("`@("`@("1C;60@/2`G1T54("]P:W,O;&]O:W5P/V]P/6=E="9E>&%C=#UO
M;B9S96%R8V@])R`N("1F<')I;G0@+B`G($A45%`O,2XP)SL*("`@("`@("`D
M;W5T<'5T(#T@)'1H:7,M/E]C;VYN96-T2V5Y<V5R=F5R*"1C;60L("1S97)V
M97(L("1T:6UE;W5T*3L*("`@("`@("!I9B`H:7-?82@D;W5T<'5T+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D;W5T<'5T.PH@("`@
M("`@('T*"B`@("`@("`@+RH@4W1R:7`@2%1-3"!486=S(&9R;VT@;W5T<'5T
M+B`J+PH@("`@("`@(&EF("@H)'-T87)T(#T@<W1R<W1R*"1O=71P=70L("<M
M+2TM+4)%1TE.)RDI*2!["B`@("`@("`@("`@("1L96YG=&@@/2!S=')P;W,H
M)'-T87)T+"`G+2TM+2U%3D0G*2`K(#,T.PH@("`@("`@("`@("!R971U<FX@
M<W5B<W1R*"1S=&%R="P@,"P@)&QE;F=T:"D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@
M;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB*2P@
M)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@4V5N9',@82!01U`@<'5B;&EC(&ME>2!T;R!A('!U8FQI8R!K97ES97)V
M97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<'5B:V5Y("!4:&4@
M4$=0('!U8FQI8R!K97D*("`@("`J($!P87)A;2!S=')I;F<@)'-E<G9E<B`@
M5&AE(&ME>7-E<G9E<B!T;R!U<V4N"B`@("`@*B!`<&%R86T@9FQO870@)'1I
M;65O=70@(%1H92!K97ES97)V97(@=&EM96]U="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(%!%05)?17)R;W(@(%!%05)?17)R;W(@;VX@97)R;W(O9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@<'5T4'5B;&EC2V5Y<V5R=F5R*"1P
M=6)K97DL("1S97)V97(@/2!01U!?2T594T525D527U!50DQ)0RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&EM96]U="`](%!'4%]+15E3
M15)615)?5$E-14]55"D*("`@('L*("`@("`@("`O*B!'970@=&AE(&9I;F=E
M<G!R:6YT(&]F('1H92!P=6)L:6,@:V5Y+B`J+PH@("`@("`@("1I;F9O(#T@
M)'1H:7,M/G!G<%!A8VME=$EN9F]R;6%T:6]N*"1P=6)K97DI.PH*("`@("`@
M("`O*B!3964@:68@=&AE('!U8FQI8R!K97D@86QR96%D>2!E>&ES=',@;VX@
M=&AE(&ME>7-E<G9E<BX@*B\*("`@("`@("!I9B`H(6ES7V$H)'1H:7,M/F=E
M=%!U8FQI8TME>7-E<G9E<B@D:6YF;ULG9FEN9V5R<')I;G0G72P@)'-E<G9E
M<BP@)'1I;65O=70I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*%\H(DME>2!A;')E861Y(&5X:7-T<R!O
M;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB*2P@)VAO<F1E+G=A<FYI;F<G*3L*
M("`@("`@("!]"@H@("`@("`@("\J($-O;FYE8W0@=&\@=&AE('!U8FQI8R!K
M97ES97)V97(N(%]C;VYN96-T2V5Y<V5R=F5R*"D@<F5T=7)N<R!A"B`@("`@
M("`@("`@4$5!4E]%<G)O<B!O8FIE8W0@;VX@97)R;W(@86YD('1H92!O=71P
M=70@=&5X="!O;B!S=6-C97-S+B`J+PH@("`@("`@("1P=6)K97D@/2`G:V5Y
M=&5X=#TG("X@=7)L96YC;V1E*')T<FEM*"1P=6)K97DI*3L*("`@("`@("`D
M8VUD(#T@87)R87DH"B`@("`@("`@("`@("=03U-4("]P:W,O861D($A45%`O
M,2XP)RP*("`@("`@("`@("`@)TAO<W0Z("<@+B`D<V5R=F5R("X@)SHQ,3,W
M,2<L"B`@("`@("`@("`@("=5<V5R+4%G96YT.B!(;W)D92!!<'!L:6-A=&EO
M;B!&<F%M97=O<FL@,RXQ)RP*("`@("`@("`@("`@)T-O;G1E;G0M5'EP93H@
M87!P;&EC871I;VXO>"UW=W<M9F]R;2UU<FQE;F-O9&5D)RP*("`@("`@("`@
M("`@)T-O;G1E;G0M3&5N9W1H.B`G("X@<W1R;&5N*"1P=6)K97DI+`H@("`@
M("`@("`@("`G0V]N;F5C=&EO;CH@8VQO<V4G+`H@("`@("`@("`@("`G)RP*
M("`@("`@("`@("`@)'!U8FME>0H@("`@("`@("D["B`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?8V]N;F5C=$ME>7-E<G9E<BAI;7!L;V1E*")<<EQN(BP@
M)&-M9"DL("1S97)V97(L("1T:6UE;W5T*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-O;FYE
M8W1S('1O(&$@<'5B;&EC(&ME>2!S97)V97(@=FEA($A+4"`H2&]R<F]W:71Z
M($ME>7-E<G9E<B!0<F]T;V-O;"DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]M;6%N9"`@
M5&AE(%!'4"!C;VUM86YD('1O(')U;BX*("`@("`J($!P87)A;2!S=')I;F<@
M)'-E<G9E<B`@(%1H92!K97ES97)V97(@=&\@=7-E+@H@("`@("H@0'!A<F%M
M(&9L;V%T("1T:6UE;W5T("`@5&AE('1I;65O=70@=F%L=64N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!T97AT(&9R;VT@<W1A;F1A<F0@
M;W5T<'5T(&]N('-U8V-E<W,L(&]R(%!%05)?17)R;W(*("`@("`J("`@("`@
M("`@("`@("`@("!O;B!E<G)O<B]F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?8V]N;F5C=$ME>7-E<G9E<B@D8V]M;6%N9"P@)'-E<G9E<BP@)'1I
M;65O=70I"B`@("!["B`@("`@("`@)&-O;FY2969U<V4@/2`P.PH@("`@("`@
M("1O=71P=70@/2`G)SL*"B`@("`@("`@+RH@071T96UP="!T;R!G970@=&AE
M(&ME>2!F<F]M('1H92!K97ES97)V97(N("HO"B`@("`@("`@9&\@>PH@("`@
M("`@("`@("`D8V]N;D5R<F]R(#T@9F%L<V4["B`@("`@("`@("`@("1E<G)N
M;R`]("1E<G)S='(@/2!N=6QL.PH*("`@("`@("`@("`@+RH@5&AE($A+4"!S
M97)V97(@:7,@;&]C871E9"!O;B!P;W)T(#$Q,S<Q+B`J+PH@("`@("`@("`@
M("`D9G`@/2!`9G-O8VMO<&5N*"1S97)V97(L("<Q,3,W,2<L("1E<G)N;RP@
M)&5R<G-T<BP@)'1I;65O=70I.PH@("`@("`@("`@("!I9B`H(21F<"D@>PH@
M("`@("`@("`@("`@("`@)&-O;FY%<G)O<B`]('1R=64["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("!F<'5T<R@D9G`L("1C;VUM86YD
M("X@(EQN7&XB*3L*("`@("`@("`@("`@("`@('=H:6QE("@A9F5O9B@D9G`I
M*2!["B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!F9V5T<R@D9G`L
M(#$P,C0I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@9F-L
M;W-E*"1F<"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D8V]N
M;D5R<F]R*2!["B`@("`@("`@("`@("`@("!I9B`H*RLD8V]N;E)E9G5S92`]
M/3T@4$=07TM%65-%4E9%4E]214954T4I('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H)&5R<FYO(#T](#`I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&]U='!U="`](%!%05(Z.G)A:7-E17)R;W(H7R@B0V]N;F5C=&EO;B!R969U
M<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(I+"`G:&]R9&4N97)R;W(G
M*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D;W5T<'5T(#T@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F
M*%\H(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BX@4F5A<V]N.B`E<R`H)7,I(BDL(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H
M)&5R<G-T<BP@3DQ3.CIG971%>'1E<FYA;$-H87)S970H*2DL("1E<G)N;RDL
M("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T@=VAI;&4@*"1C;VYN17)R;W(I.PH*("`@("`@
M("!R971U<FX@)&]U='!U=#L*("`@('T*"B`@("`O*BH*("`@("`J($5N8W)Y
M<'1S('1E>'0@=7-I;F<@4$=0+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'1E>'0@("!4:&4@=&5X="!T;R!B92!01U`@96YC<GEP=&5D+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%1H92!P87)A;65T97)S(&YE961E
M9"!F;W(@96YC<GEP=&EO;BX*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!3964@=&AE(&EN9&EV:61U86P@7V5N8W)Y<'0J*"D@9G5N8W1I;VYS(&9O
M<B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!P87)A;65T97(@
M<F5Q=6ER96UE;G1S+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@96YC<GEP=&5D(&UE<W-A9V4L(&]R(%!%05)?17)R;W(@;VX@97)R;W(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8W)Y<'0H)'1E>'0L("1P87)A;7,@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=T
M>7!E)UTI*2!["B`@("`@("`@("`@(&EF("@D<&%R86US6R=T>7!E)UT@/3T]
M("=M97-S86=E)RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M96YC<GEP=$UE<W-A9V4H)'1E>'0L("1P87)A;7,I.PH@("`@("`@("`@("!]
M(&5L<V5I9B`H)'!A<F%M<ULG='EP92==(#T]/2`G<VEG;F%T=7)E)RD@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?96YC<GEP=%-I9VYA='5R
M92@D=&5X="P@)'!A<F%M<RD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!$96-R>7!T<R!T97AT('5S:6YG(%!'4"X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@5&AE('1E>'0@
M=&\@8F4@4$=0(&1E8W)Y<'1E9"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("!4:&4@<&%R86UE=&5R<R!N965D960@9F]R(&1E8W)Y<'1I;VXN"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@4V5E('1H92!I;F1I=FED=6%L
M(%]D96-R>7!T*B@I(&9U;F-T:6]N<R!F;W(@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@<&%R86UE=&5R(')E<75I<F5M96YT<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&1E8W)Y<'1E9"!M97-S86=E
M+"!O<B!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!D96-R>7!T*"1T97AT+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@
M("`@("!I9B`H:7-S970H)'!A<F%M<ULG='EP92==*2D@>PH@("`@("`@("`@
M("!I9B`H)'!A<F%M<ULG='EP92==(#T]/2`G;65S<V%G92<I('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1E8W)Y<'1-97-S86=E*"1T97AT
M+"`D<&%R86US*3L*("`@("`@("`@("`@?2!E;'-E:68@*"@D<&%R86US6R=T
M>7!E)UT@/3T]("=S:6=N871U<F4G*2!\?`H@("`@("`@("`@("`@("`@("`@
M("`@*"1P87)A;7-;)W1Y<&4G72`]/3T@)V1E=&%C:&5D+7-I9VYA='5R92<I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D96-R>7!T4VEG
M;F%T=7)E*"1T97AT+"`D<&%R86US*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!T96UP;W)A<GD@
M9W!G(&ME>7)I;F<N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@5&AE('1Y<&4@;V8@
M:V5Y('1O(&%N86QY>F4N($5I=&AE<B`G<'5B;&EC)PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@*$1E9F%U;'0I(&]R("=P<FEV871E)PH@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!#;VUM86YD(&QI;F4@:V5Y<W1R:6YG
M(&]P=&EO;B!T;R!U<V4@=VET:"!G<&<@<')O9W)A;2X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V-R96%T94ME>7)I;F<H)'1Y<&4@/2`G<'5B;&EC)RD*("`@
M('L*("`@("`@("`D='EP92`](%-T<FEN9SHZ;&]W97(H)'1Y<&4I.PH*("`@
M("`@("!I9B`H)'1Y<&4@/3T]("=P=6)L:6,G*2!["B`@("`@("`@("`@(&EF
M("AE;7!T>2@D=&AI<RT^7W!U8FQI8TME>7)I;F<I*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!U8FQI8TME>7)I;F<@/2`D=&AI<RT^7V-R96%T951E
M;7!&:6QE*"=H;W)D92UP9W`G*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!R971U<FX@)RTM:V5Y<FEN9R`G("X@)'1H:7,M/E]P=6)L:6-+97ER:6YG
M.PH@("`@("`@('T@96QS96EF("@D='EP92`]/3T@)W!R:79A=&4G*2!["B`@
M("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!R:79A=&5+97ER:6YG*2D@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P<FEV871E2V5Y<FEN9R`]("1T
M:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7!G<"<I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(')E='5R;B`G+2US96-R970M:V5Y<FEN9R`G("X@
M)'1H:7,M/E]P<FEV871E2V5Y<FEN9SL*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!9&1S(%!'4"!K97ES('1O('1H92!K97ER:6YG+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A
M;2!M:7AE9"`D:V5Y<R`@($$@<VEN9VQE(&ME>2!O<B!A;B!A<G)A>2!O9B!K
M97DH<RD@=&\@861D('1O('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@:V5Y<FEN9RX*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@(%1H92!T
M>7!E(&]F(&ME>2AS*2!T;R!A9&0N($5I=&AE<B`G<'5B;&EC)PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@*$1E9F%U;'0I(&]R("=P<FEV871E)PH@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!#;VUM86YD(&QI;F4@:V5Y
M<W1R:6YG(&]P=&EO;B!T;R!U<V4@=VET:"!G<&<@<')O9W)A;2X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W!U=$EN2V5Y<FEN9R@D:V5Y<R`](&%R<F%Y*"DL
M("1T>7!E(#T@)W!U8FQI8R<I"B`@("!["B`@("`@("`@)'1Y<&4@/2!3=')I
M;F<Z.FQO=V5R*"1T>7!E*3L*"B`@("`@("`@:68@*"%I<U]A<G)A>2@D:V5Y
M<RDI('L*("`@("`@("`@("`@)&ME>7,@/2!A<G)A>2@D:V5Y<RD["B`@("`@
M("`@?0H*("`@("`@("`O*B!#<F5A=&4@=&AE(&ME>7)I;F=S(&EF('1H97D@
M9&]N)W0@86QR96%D>2!E>&ES="X@*B\*("`@("`@("`D:V5Y<FEN9R`]("1T
M:&ES+3Y?8W)E871E2V5Y<FEN9R@D='EP92D["@H@("`@("`@("\J(%-T;W)E
M('1H92!K97DH<RD@:6X@=&AE(&ME>7)I;F<N("HO"B`@("`@("`@)&-M9&QI
M;F4@/2!A<G)A>2@*("`@("`@("`@("`@)RTM86QL;W<M<V5C<F5T+6ME>2UI
M;7!O<G0G+`H@("`@("`@("`@("`G+2UF87-T+6EM<&]R="<L"B`@("`@("`@
M("`@("1K97ER:6YG"B`@("`@("`@*3L*("`@("`@("`D=&AI<RT^7V-A;&Q'
M<&<H)&-M9&QI;F4L("=W)RP@87)R87E?=F%L=65S*"1K97ES*2D["@H@("`@
M("`@(')E='5R;B`D:V5Y<FEN9SL*("`@('T*"B`@("`O*BH*("`@("`J($5N
M8W)Y<'1S(&$@;65S<V%G92!I;B!01U`@9F]R;6%T('5S:6YG(&$@<'5B;&EC
M(&ME>2X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@5&AE('1E>'0@=&\@8F4@96YC
M<GEP=&5D+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%1H92!P87)A
M;65T97)S(&YE961E9"!F;W(@96YC<GEP=&EO;BX*("`@("`J(#QP<F4^"B`@
M("`@*B!087)A;65T97)S.@H@("`@("H@/3T]/3T]/3T]/3T*("`@("`J("=T
M>7!E)R`@("`]/B`@)VUE<W-A9V4G("A215%525)%1"D*("`@("`J("=P=6)K
M97DG("`]/B`@4$=0('!U8FQI8R!K97DN("A/<'1I;VYA;"D@*$1%4%)%0T%4
M140I"B`@("`@*B`G96UA:6PG("`@/3X@($4M;6%I;"!A9&1R97-S(&]F(')E
M8VEP:65N="X@268@;F]T('!R97-E;G0L(&]R(&YO="!F;W5N9`H@("`@("H@
M("`@("`@("`@("`@("!I;B!T:&4@<'5B;&EC(&ME>2P@=&AE(&9I<G-T(&4M
M;6%I;"!A9&1R97-S(&9O=6YD(&EN('1H90H@("`@("H@("`@("`@("`@("`@
M("!K97D@=VEL;"!B92!U<V5D(&EN<W1E860N("A/<'1I;VYA;"D@*$1%4%)%
M0T%4140I"B`@("`@*B`G<F5C:7!S)R`@/3X@($%N(&%R<F%Y('=I=&@@=&AE
M(&4M;6%I;"!A9&1R97-S(&]F('1H92!R96-I<&EE;G0@87,*("`@("`J("`@
M("`@("`@("`@("`@=&AE(&ME>2!A;F0@=&AA="!P97)S;VXG<R!P=6)L:6,@
M:V5Y(&%S('1H92!V86QU92X*("`@("`J("`@("`@("`@("`@("`@*%)%455)
M4D5$*0H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!E;F-R>7!T960@;65S<V%G92P@;W(@4$5!4E]%<G)O<B!O;B!E
M<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@7V5N8W)Y<'1-97-S86=E*"1T
M97AT+"`D<&%R86US*0H@("`@>PH@("`@("`@("1E;6%I;"`](&YU;&P["@H@
M("`@("`@(&EF("@A:7-S970H)'!A<F%M<ULG<F5C:7!S)UTI*2!["B`@("`@
M("`@("`@("\J($-H96-K(&9O<B!R97%U:7)E9"!P87)A;65T97)S+B`J+PH@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1P87)A;7-;)W!U8FME>2==*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B02!P
M=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("\J($=E="!I;F9O<FUA=&EO;B!O;B!T:&4@:V5Y+B`J+PH@("`@("`@
M("`@("!I9B`H:7-S970H)'!A<F%M<ULG96UA:6PG72DI('L*("`@("`@("`@
M("`@("`@("1K97E?:6YF;R`]("1T:&ES+3YP9W!086-K9713:6=N871U<F4H
M)'!A<F%M<ULG<'5B:V5Y)UTL("1P87)A;7-;)V5M86EL)UTI.PH@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D:V5Y7VEN9F\I*2!["B`@("`@("`@("`@
M("`@("`@("`@)&5M86EL(#T@)&ME>5]I;F9O6R=E;6%I;"==.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!)9B!W
M92!H879E(&YO(&5M86EL(&%D9')E<W,@870@=&AI<R!P;VEN="P@=7-E('1H
M92!F:7)S="!E;6%I;`H@("`@("`@("`@("`@("!A9&1R97-S(&9O=6YD(&EN
M('1H92!P=6)L:6,@:V5Y+B`J+PH@("`@("`@("`@("!I9B`H96UP='DH)&5M
M86EL*2D@>PH@("`@("`@("`@("`@("`@)&ME>5]I;F9O(#T@)'1H:7,M/G!G
M<%!A8VME=$EN9F]R;6%T:6]N*"1P87)A;7-;)W!U8FME>2==*3L*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D:V5Y7VEN9F];)W-I9VYA='5R92==6R=I
M9#$G75LG96UA:6PG72DI('L*("`@("`@("`@("`@("`@("`@("`D96UA:6P@
M/2`D:V5Y7VEN9F];)W-I9VYA='5R92==6R=I9#$G75LG96UA:6PG73L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T(&1E=&5R;6EN92!T
M:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(BDL("=H;W)D92YE<G)O
M<B<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D<&%R86US6R=R96-I<',G72`](&%R<F%Y*"1E;6%I;"`]/B`D<&%R
M86US6R=P=6)K97DG72D["B`@("`@("`@?0H*("`@("`@("`O*B!3=&]R92!P
M=6)L:6,@:V5Y(&EN('1E;7!O<F%R>2!K97ER:6YG+B`J+PH@("`@("`@("1K
M97ER:6YG(#T@)'1H:7,M/E]P=71);DME>7)I;F<H87)R87E?=F%L=65S*"1P
M87)A;7-;)W)E8VEP<R==*2D["@H@("`@("`@("\J($5N8W)Y<'0@=&AE(&1O
M8W5M96YT+B`J+PH@("`@("`@("1C;61L:6YE(#T@87)R87DH"B`@("`@("`@
M("`@("<M+6%R;6]R)RP*("`@("`@("`@("`@)RTM8F%T8V@G+`H@("`@("`@
M("`@("`G+2UA;'=A>7,M=')U<W0G+`H@("`@("`@("`@("`D:V5Y<FEN9RP*
M("`@("`@("`@("`@)RTM96YC<GEP="<*("`@("`@("`I.PH@("`@("`@(&9O
M<F5A8V@@*&%R<F%Y7VME>7,H)'!A<F%M<ULG<F5C:7!S)UTI(&%S("1V86PI
M('L*("`@("`@("`@("`@)&-M9&QI;F5;72`]("<M+7)E8VEP:65N="`G("X@
M)'9A;#L*("`@("`@("!]"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?8V%L
M;$=P9R@D8VUD;&EN92P@)W<G+"`D=&5X="P@=')U92P@=')U92D["B`@("`@
M("`@:68@*&5M<'1Y*"1R97-U;'0M/F]U='!U="DI('L*("`@("`@("`@("`@
M)&5R<F]R(#T@<')E9U]R97!L86-E*"<O7&XN*B\G+"`G)RP@)')E<W5L="T^
M<W1D97)R*3L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M7R@B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z("(I("X@)&5R<F]R
M+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M<F5S=6QT+3YO=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3:6=N<R!A
M(&UE<W-A9V4@:6X@4$=0(&9O<FUA="!U<VEN9R!A('!R:79A=&4@:V5Y+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'1E>'0@("!4:&4@=&5X="!T;R!B92!S:6=N960N"B`@
M("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@5&AE('!A<F%M971E<G,@;F5E
M9&5D(&9O<B!S:6=N:6YG+@H@("`@("H@/'!R93X*("`@("`J(%!A<F%M971E
M<G,Z"B`@("`@*B`]/3T]/3T]/3T]/0H@("`@("H@)W1Y<&4G("`@("`@("`]
M/B`@)W-I9VYA='5R92<@*%)%455)4D5$*0H@("`@("H@)W!U8FME>2<@("`@
M("`]/B`@4$=0('!U8FQI8R!K97DN("A215%525)%1"D*("`@("`J("=P<FEV
M:V5Y)R`@("`@/3X@(%!'4"!P<FEV871E(&ME>2X@*%)%455)4D5$*0H@("`@
M("H@)W!A<W-P:')A<V4G("`]/B`@4&%S<W!H<F%S92!F;W(@4$=0($ME>2X@
M*%)%455)4D5$*0H@("`@("H@)W-I9W1Y<&4G("`@("`]/B`@1&5T97)M:6YE
M('1H92!S:6=N871U<F4@='EP92!T;R!U<V4N("A/<'1I;VYA;"D*("`@("`J
M("`@("`@("`@("`@("`@("`@("=C;&5A<G1E>'0G("`M+2`@36%K92!A(&-L
M96%R('1E>'0@<VEG;F%T=7)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`G
M9&5T86-H)R`@("`@+2T@($UA:V4@82!D971A8VAE9"!S:6=N871U<F4@*$1%
M1D%53%0I"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE('-I9VYE9"!M97-S86=E+"!O<B!014%27T5R<F]R(&]N(&5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!?96YC<GEP=%-I9VYA='5R92@D
M=&5X="P@)'!A<F%M<RD*("`@('L*("`@("`@("`O*B!#:&5C:R!F;W(@<V5C
M=7)E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'-E8W5R95]C:&5C:R`]("1T
M:&ES+3YR97%U:7)E4V5C=7)E0V]N;F5C=&EO;B@I.PH@("`@("`@(&EF("AI
M<U]A*"1S96-U<F5?8VAE8VLL("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1S96-U<F5?8VAE8VL["B`@("`@("`@?0H*("`@("`@("`O
M*B!#:&5C:R!F;W(@<F5Q=6ER960@<&%R86UE=&5R<RX@*B\*("`@("`@("!I
M9B`H(6ES<V5T*"1P87)A;7-;)W!U8FME>2==*2!\?`H@("`@("`@("`@("`A
M:7-S970H)'!A<F%M<ULG<')I=FME>2==*2!\?`H@("`@("`@("`@("`A:7-S
M970H)'!A<F%M<ULG<&%S<W!H<F%S92==*2D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")!('!U8FQI8R!01U`@:V5Y+"!P<FEV
M871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S
M:6=N(&$@;65S<V%G92XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?0H*
M("`@("`@("`O*B!#<F5A=&4@=&5M<"!F:6QE<R!F;W(@:6YP=70N("HO"B`@
M("`@("`@)&EN<'5T(#T@)'1H:7,M/E]C<F5A=&5496UP1FEL92@G:&]R9&4M
M<&=P)RD["@H@("`@("`@("\J($5N8W)Y<'1I;VX@<F5Q=6ER97,@8F]T:"!K
M97ER:6YG<RX@*B\*("`@("`@("`D<'5B7VME>7)I;F<@/2`D=&AI<RT^7W!U
M=$EN2V5Y<FEN9RAA<G)A>2@D<&%R86US6R=P=6)K97DG72DI.PH@("`@("`@
M("1S96-?:V5Y<FEN9R`]("1T:&ES+3Y?<'5T26Y+97ER:6YG*&%R<F%Y*"1P
M87)A;7-;)W!R:79K97DG72DL("=P<FEV871E)RD["@H@("`@("`@("\J(%-T
M;W)E(&UE<W-A9V4@:6X@=&5M<&]R87)Y(&9I;&4N("HO"B`@("`@("`@)&9P
M(#T@9F]P96XH)&EN<'5T+"`G=RLG*3L*("`@("`@("!F<'5T<R@D9G`L("1T
M97AT*3L*("`@("`@("!F8VQO<V4H)&9P*3L*"B`@("`@("`@+RH@1&5T97)M
M:6YE('1H92!S:6=N871U<F4@='EP92!T;R!U<V4N("HO"B`@("`@("`@)&-M
M9&QI;F4@/2!A<G)A>2@I.PH@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=S
M:6=T>7!E)UTI("8F"B`@("`@("`@("`@("1P87)A;7-;)W-I9W1Y<&4G72`]
M/2`G8VQE87)T97AT)RD@>PH@("`@("`@("`@("`D<VEG;E]T>7!E(#T@)RTM
M8VQE87)S:6=N)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<VEG
M;E]T>7!E(#T@)RTM9&5T86-H+7-I9VXG.PH@("`@("`@('T*"B`@("`@("`@
M+RH@061D:71I;VYA;"!'4$<@;W!T:6]N<RX@*B\*("`@("`@("`D8VUD;&EN
M92`K/2!A<G)A>2@*("`@("`@("`@("`@)RTM87)M;W(G+`H@("`@("`@("`@
M("`G+2UB871C:"<L"B`@("`@("`@("`@("<M+7!A<W-P:')A<V4M9F0@,"<L
M"B`@("`@("`@("`@("1S96-?:V5Y<FEN9RP*("`@("`@("`@("`@)'!U8E]K
M97ER:6YG+`H@("`@("`@("`@("`D<VEG;E]T>7!E+`H@("`@("`@("`@("`D
M:6YP=70*("`@("`@("`I.PH*("`@("`@("`O*B!3:6=N('1H92!D;V-U;65N
M="X@*B\*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C86QL1W!G*"1C;61L
M:6YE+"`G=R<L("1P87)A;7-;)W!A<W-P:')A<V4G72P@=')U92P@=')U92D[
M"B`@("`@("`@:68@*&5M<'1Y*"1R97-U;'0M/F]U='!U="DI('L*("`@("`@
M("`@("`@)&5R<F]R(#T@<')E9U]R97!L86-E*"<O7&XN*B\G+"`G)RP@)')E
M<W5L="T^<W1D97)R*3L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H7R@B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z("(I("X@)&5R
M<F]R+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@)')E<W5L="T^;W5T<'5T.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($1E8W)Y<'1S(&%N(%!'4"!E;F-R>7!T960@;65S
M<V%G92!U<VEN9R!A('!R:79A=&4O<'5B;&EC(&ME>7!A:7(@86YD(&$*("`@
M("`J('!A<W-H<')A<V4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@(%1H92!T97AT
M('1O(&)E(&1E8W)Y<'1E9"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M("!4:&4@<&%R86UE=&5R<R!N965D960@9F]R(&1E8W)Y<'1I;VXN"B`@("`@
M*B`\<')E/@H@("`@("H@4&%R86UE=&5R<SH*("`@("`J(#T]/3T]/3T]/3T]
M"B`@("`@*B`G='EP92<@("`@("`@(#T^("`G;65S<V%G92<@*%)%455)4D5$
M*0H@("`@("H@)W!U8FME>2<@("`@("`]/B`@4$=0('!U8FQI8R!K97DN("A2
M15%525)%1"D*("`@("`J("=P<FEV:V5Y)R`@("`@/3X@(%!'4"!P<FEV871E
M(&ME>2X@*%)%455)4D5$*0H@("`@("H@)W!A<W-P:')A<V4G("`]/B`@4&%S
M<W!H<F%S92!F;W(@4$=0($ME>2X@*%)%455)4D5$*0H@("`@("H@/"]P<F4^
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=&1#;&%S<R`@06X@;V)J96-T('=I
M=&@@=&AE(&9O;&QO=VEN9R!P<F]P97)T:65S+"!O<B!014%27T5R<F]R"B`@
M("`@*B`@("`@("`@("`@("`@("`@("!O;B!E<G)O<CH*("`@("`J(#QP<F4^
M"B`@("`@*B`G;65S<V%G92<@("`@("T@(%1H92!D96-R>7!T960@;65S<V%G
M92X*("`@("`J("=S:6=?<F5S=6QT)R`@+2`@5&AE(')E<W5L="!O9B!T:&4@
M<VEG;F%T=7)E('1E<W0N"B`@("`@*B`\+W!R93X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V1E8W)Y<'1-97-S86=E*"1T97AT+"`D<&%R86US*0H@("`@>PH@
M("`@("`@("\J($-H96-K(&9O<B!S96-U<F4@8V]N;F5C=&EO;BX@*B\*("`@
M("`@("`D<V5C=7)E7V-H96-K(#T@)'1H:7,M/G)E<75I<F5396-U<F5#;VYN
M96-T:6]N*"D["B`@("`@("`@:68@*&ES7V$H)'-E8W5R95]C:&5C:RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'-E8W5R95]C:&5C
M:SL*("`@("`@("!]"@H@("`@("`@("1G;V]D7W-I9U]F;&%G(#T@9F%L<V4[
M"@H@("`@("`@("\J($-H96-K(&9O<B!R97%U:7)E9"!P87)A;65T97)S+B`J
M+PH@("`@("`@(&EF("@A:7-S970H)'!A<F%M<ULG<'5B:V5Y)UTI('Q\"B`@
M("`@("`@("`@("%I<W-E="@D<&%R86US6R=P<FEV:V5Y)UTI('Q\"B`@("`@
M("`@("`@("%I<W-E="@D<&%R86US6R=P87-S<&AR87-E)UTI*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D$@<'5B;&EC(%!'
M4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+B(I+"`G:&]R9&4N97)R;W(G
M*3L*("`@("`@("!]"@H@("`@("`@("\J($-R96%T92!T96UP(&9I;&5S+B`J
M+PH@("`@("`@("1I;G!U="`]("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO
M<F1E+7!G<"<I.PH*("`@("`@("`O*B!$96-R>7!T:6]N(')E<75I<F5S(&)O
M=&@@:V5Y<FEN9W,N("HO"B`@("`@("`@)'!U8E]K97ER:6YG(#T@)'1H:7,M
M/E]P=71);DME>7)I;F<H87)R87DH)'!A<F%M<ULG<'5B:V5Y)UTI*3L*("`@
M("`@("`D<V5C7VME>7)I;F<@/2`D=&AI<RT^7W!U=$EN2V5Y<FEN9RAA<G)A
M>2@D<&%R86US6R=P<FEV:V5Y)UTI+"`G<')I=F%T92<I.PH*("`@("`@("`O
M*B!3=&]R92!M97-S86=E(&EN(&9I;&4N("HO"B`@("`@("`@)&9P(#T@9F]P
M96XH)&EN<'5T+"`G=RLG*3L*("`@("`@("!F<'5T<R@D9G`L("1T97AT*3L*
M("`@("`@("!F8VQO<V4H)&9P*3L*"B`@("`@("`@+RH@1&5C<GEP="!T:&4@
M9&]C=6UE;G0@;F]W+B`J+PH@("`@("`@("1C;61L:6YE(#T@87)R87DH"B`@
M("`@("`@("`@("<M+6%L=V%Y<RUT<G5S="<L"B`@("`@("`@("`@("<M+6%R
M;6]R)RP*("`@("`@("`@("`@)RTM8F%T8V@G+`H@("`@("`@("`@("`G+2UP
M87-S<&AR87-E+69D(#`G+`H@("`@("`@("`@("`D<V5C7VME>7)I;F<L"B`@
M("`@("`@("`@("1P=6)?:V5Y<FEN9RP*("`@("`@("`@("`@)RTM9&5C<GEP
M="<L"B`@("`@("`@("`@("1I;G!U=`H@("`@("`@("D["B`@("`@("`@)')E
M<W5L="`]("1T:&ES+3Y?8V%L;$=P9R@D8VUD;&EN92P@)W<G+"`D<&%R86US
M6R=P87-S<&AR87-E)UTL('1R=64L('1R=64I.PH@("`@("`@(&EF("AE;7!T
M>2@D<F5S=6QT+3YO=71P=70I*2!["B`@("`@("`@("`@("1E<G)O<B`]('!R
M96=?<F5P;&%C92@G+UQN+BHO)RP@)R<L("1R97-U;'0M/G-T9&5R<BD["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O=6QD(&YO
M="!D96-R>7!T(%!'4"!D871A.B`B*2`N("1E<G)O<BP@)VAO<F1E+F5R<F]R
M)RD["B`@("`@("`@?0H*("`@("`@("`O*B!#<F5A=&4@=&AE(')E='5R;B!O
M8FIE8W0N("HO"B`@("`@("`@)&]B(#T@)FYE=R!S=&1#;&%S<SL*("`@("`@
M("`D;V(M/FUE<W-A9V4@/2`D<F5S=6QT+3YO=71P=70["@H@("`@("`@("\J
M($-H96-K('1H92!01U`@<VEG;F%T=7)E+B`J+PH@("`@("`@("1S:6=?8VAE
M8VL@/2`D=&AI<RT^7V-H96-K4VEG;F%T=7)E4F5S=6QT*"1R97-U;'0M/G-T
M9&5R<BD["B`@("`@("`@:68@*&ES7V$H)'-I9U]C:&5C:RP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`D;V(M/G-I9U]R97-U;'0@/2`D<VEG7V-H
M96-K.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1O8BT^<VEG7W)E
M<W5L="`]("@D<VEG7V-H96-K*2`_("1R97-U;'0M/G-T9&5R<B`Z("<G.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O8CL*("`@('T*"B`@("`O*BH*
M("`@("`J($1E8W)Y<'1S(&%N(%!'4"!S:6=N960@;65S<V%G92!U<VEN9R!A
M('!U8FQI8R!K97DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@(%1H92!T97AT('1O
M(&)E('9E<FEF:65D+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%1H
M92!P87)A;65T97)S(&YE961E9"!F;W(@=F5R:69I8V%T:6]N+@H@("`@("H@
M/'!R93X*("`@("`J(%!A<F%M971E<G,Z"B`@("`@*B`]/3T]/3T]/3T]/0H@
M("`@("H@)W1Y<&4G("`@("`@(#T^("`G<VEG;F%T=7)E)R!O<B`G9&5T86-H
M960M<VEG;F%T=7)E)R`H4D5154E2140I"B`@("`@*B`G<'5B:V5Y)R`@("`@
M/3X@(%!'4"!P=6)L:6,@:V5Y+B`H4D5154E2140I"B`@("`@*B`G<VEG;F%T
M=7)E)R`@/3X@(%!'4"!S:6=N871U<F4@8FQO8VLN("A215%525)%1"!F;W(@
M9&5T86-H960@<VEG;F%T=7)E*0H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!V97)I9FEC871I;VX@;65S<V%G92!F
M<F]M(&=P9RX@268@;F\@<VEG;F%T=7)E+`H@("`@("H@("`@("`@("`@("`@
M("`@(')E='5R;G,@96UP='D@<W1R:6YG+"!A;F0@4$5!4E]%<G)O<B!O;B!E
M<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@7V1E8W)Y<'13:6=N871U<F4H
M)'1E>'0L("1P87)A;7,I"B`@("!["B`@("`@("`@+RH@0VAE8VL@9F]R(')E
M<75I<F5D('!A<F%M971E<G,N("HO"B`@("`@("`@:68@*"%I<W-E="@D<&%R
M86US6R=P=6)K97DG72DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H7R@B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@82!S:6=N960@;65S<V%G92XB*2P@)VAO<F1E+F5R<F]R)RD["B`@
M("`@("`@?0H@("`@("`@(&EF("@H)'!A<F%M<ULG='EP92==(#T]/2`G9&5T
M86-H960M<VEG;F%T=7)E)RD@)B8*("`@("`@("`@("`@(6ES<V5T*"1P87)A
M;7-;)W-I9VYA='5R92==*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BA?*")4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C
M:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(I
M+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!]"@H@("`@("`@("1G;V]D7W-I
M9U]F;&%G(#T@,#L*"B`@("`@("`@+RH@0W)E871E('1E;7`@9FEL97,@9F]R
M(&EN<'5T+B`J+PH@("`@("`@("1I;G!U="`]("1T:&ES+3Y?8W)E871E5&5M
M<$9I;&4H)VAO<F1E+7!G<"<I.PH*("`@("`@("`O*B!3=&]R92!P=6)L:6,@
M:V5Y(&EN('1E;7!O<F%R>2!K97ER:6YG+B`J+PH@("`@("`@("1K97ER:6YG
M(#T@)'1H:7,M/E]P=71);DME>7)I;F<H)'!A<F%M<ULG<'5B:V5Y)UTI.PH*
M("`@("`@("`O*B!3=&]R92!T:&4@;65S<V%G92!I;B!A('1E;7!O<F%R>2!F
M:6QE+B`J+PH@("`@("`@("1F<"`](&9O<&5N*"1I;G!U="P@)W<K)RD["B`@
M("`@("`@9G!U=',H)&9P+"`D=&5X="D["B`@("`@("`@9F-L;W-E*"1F<"D[
M"@H@("`@("`@("\J($]P=&EO;G,@9F]R('1H92!'4$<@8FEN87)Y+B`J+PH@
M("`@("`@("1C;61L:6YE(#T@87)R87DH"B`@("`@("`@("`@("<M+6%R;6]R
M)RP*("`@("`@("`@("`@)RTM86QW87ES+71R=7-T)RP*("`@("`@("`@("`@
M)RTM8F%T8V@G+`H@("`@("`@("`@("`G+2UC:&%R<V5T("<@+B!.3%,Z.F=E
M=$-H87)S970H*2P*("`@("`@("`@("`@)&ME>7)I;F<L"B`@("`@("`@("`@
M("<M+79E<FEF>2<*("`@("`@("`I.PH*("`@("`@("`O*B!%>'1R82!S='5F
M9B!T;R!D;R!I9B!W92!A<F4@=7-I;F<@82!D971A8VAE9"!S:6=N871U<F4N
M("HO"B`@("`@("`@:68@*"1P87)A;7-;)W1Y<&4G72`]/3T@)V1E=&%C:&5D
M+7-I9VYA='5R92<I('L*("`@("`@("`@("`@)'-I9V9I;&4@/2`D=&AI<RT^
M7V-R96%T951E;7!&:6QE*"=H;W)D92UP9W`G*3L*("`@("`@("`@("`@)&-M
M9&QI;F5;72`]("1S:6=F:6QE("X@)R`G("X@)&EN<'5T.PH*("`@("`@("`@
M("`@)&9P(#T@9F]P96XH)'-I9V9I;&4L("=W*R<I.PH@("`@("`@("`@("!F
M<'5T<R@D9G`L("1P87)A;7-;)W-I9VYA='5R92==*3L*("`@("`@("`@("`@
M9F-L;W-E*"1F<"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-M
M9&QI;F5;72`]("1I;G!U=#L*("`@("`@("!]"B`@("`@("`@)&-M9&QI;F5;
M72`]("<R/B8Q)SL*"B`@("`@("`@+RH@5F5R:69Y('1H92!S:6=N871U<F4N
M"B`@("`@("`@("`@5V4@;F5E9"!T;R!C871C:"!S=&%N9&%R9"!E<G)O<B!O
M=71P=70L('-I;F-E('1H:7,@:7,@=VAE<F4*("`@("`@("`@("!T:&4@<VEG
M;F%T=7)E(&EN9F]R;6%T:6]N(&ES('-E;G0N("HO"B`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?8V%L;$=P9R@D8VUD;&EN92P@)W(G*3L*("`@("`@("`D
M<VEG7W)E<W5L="`]("1T:&ES+3Y?8VAE8VM3:6=N871U<F5297-U;'0H)')E
M<W5L="T^<W1D;W5T*3L*("`@("`@("!I9B`H:7-?82@D<VEG7W)E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'-I9U]R97-U
M;'0["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("@D<VEG
M7W)E<W5L="D@/R`D<F5S=6QT+3YS=&1O=70@.B`G)SL*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@<VEG;F%T=7)E(')E<W5L="!F
M<F]M('1H92!';G501R!B:6YA<GDN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5S=6QT("!4
M:&4@<VEG;F%T=7)E(')E<W5L="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%1R=64@:68@<VEG;F%T=7)E(&ES(&=O;V0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]C:&5C:U-I9VYA='5R95)E<W5L="@D<F5S=6QT*0H@("`@
M>PH@("`@("`@("\J($=O;V0@<VEG;F%T=7)E.@H@("`@("`@("`J("`@9W!G
M.B!';V]D('-I9VYA='5R92!F<F]M(")B;&%H(&)L86@@8FQA:"`H0V]M;65N
M="DB"B`@("`@("`@("H@0F%D('-I9VYA='5R93H*("`@("`@("`@*B`@(&=P
M9SH@0D%$('-I9VYA='5R92!F<F]M(")B;&%H(&)L86@@8FQA:"`H0V]M;65N
M="DB("HO"B`@("`@("`@:68@*'-T<G!O<R@D<F5S=6QT+"`G9W!G.B!"040@
M<VEG;F%T=7)E)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"1R97-U;'0L("=H;W)D92YE<G)O<B<I.PH@("`@
M("`@('T@96QS96EF("AS=')P;W,H)')E<W5L="P@)V=P9SH@1V]O9"!S:6=N
M871U<F4G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N('1R=64[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-I9VYS(&$@34E-15]0
M87)T('5S:6YG(%!'4"X*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T
M("1M:6UE7W!A<G0@(%1H92!-24U%7U!A<G0@;V)J96-T('1O('-I9VXN"B`@
M("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@("`@("`@(%1H92!P87)A;65T
M97)S(')E<75I<F5D(&9O<B!S:6=N:6YG+@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!`<V5E(%]E;F-R>7!T4VEG;F%T=7)E*"DN"B`@
M("`@*@H@("`@("H@0')E='5R;B!-24U%7U!A<G0@($$@34E-15]087)T(&]B
M:F5C="!T:&%T(&ES('-I9VYE9"!A8V-O<F1I;F<@=&\@4D9#"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@,C`Q-2\S,34V+"!O<B!014%27T5R<F]R(&]N
M(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!S:6=N34E-15!A<G0H)&UI
M;65?<&%R="P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:6YC
M;'5D95]O;F-E("=(;W)D92]-24U%+U!A<G0N<&AP)SL*"B`@("`@("`@)'!A
M<F%M<R`](&%R<F%Y7VUE<F=E*"1P87)A;7,L(&%R<F%Y*"=T>7!E)R`]/B`G
M<VEG;F%T=7)E)RP@)W-I9W1Y<&4G(#T^("=D971A8V@G*2D["@H@("`@("`@
M("\J(%)&0R`R,#$U(%)E<75I<F5M96YT<R!F;W(@82!01U`@<VEG;F5D(&UE
M<W-A9V4Z"B`@("`@("`@("H@*R!#;VYT96YT+51Y<&4@<&%R86US("=M:6-A
M;&<G("8@)W!R;W1O8V]L)R!A<F4@4D5154E2140N"B`@("`@("`@("H@*R!4
M:&4@9&EG:71A;&QY('-I9VYE9"!M97-S86=E($U54U0@8F4@8V]N<W1R86EN
M960@=&\@-R!B:71S+@H@("`@("`@("`J("L@5&AE($U)344@:&5A9&5R<R!-
M55-4(&)E(&$@<&%R="!O9B!T:&4@<VEG;F5D(&1A=&$N("HO"@H@("`@("`@
M("1M:6UE7W!A<G0M/G-T<FEC=#=B:70H=')U92D["B`@("`@("`@)&US9U]S
M:6=N(#T@)'1H:7,M/F5N8W)Y<'0H)&UI;65?<&%R="T^=&]#86YO;FEC86Q3
M=')I;F<H*2P@)'!A<F%M<RD["B`@("`@("`@:68@*&ES7V$H)&US9U]S:6=N
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D;7-G7W-I
M9VX["B`@("`@("`@?0H*("`@("`@("`O*B!!9&0@=&AE(%!'4"!S:6=N871U
M<F4N("HO"B`@("`@("`@)'!G<%]S:6=N(#T@)FYE=R!-24U%7U!A<G0H)V%P
M<&QI8V%T:6]N+W!G<"US:6=N871U<F4G+"`D;7-G7W-I9VXL(&YU;&PL("=I
M;FQI;F4G*3L*("`@("`@("`D<&=P7W-I9VXM/G-E=$1E<V-R:7!T:6]N*%\H
M(E!'4"!$:6=I=&%L(%-I9VYA='5R92(I*3L*"B`@("`@("`@+RH@1V5T('1H
M92!A;&=O<FET:&EM(&EN9F]R;6%T:6]N(&9R;VT@=&AE('-I9VYA='5R92X@
M4VEN8V4@=V4@87)E"B`@("`@("`@("H@86YA;'EZ:6YG(&$@<VEG;F%T=7)E
M('!A8VME="P@=V4@;F5E9"!T;R!U<V4@=&AE('-P96-I86P@:V5Y=V]R9`H@
M("`@("`@("`J("=?4TE'3D%455)%)R`M('-E92!(;W)D95]#<GEP=%]P9W`N
M("HO"B`@("`@("`@)'-I9U]I;F9O(#T@)'1H:7,M/G!G<%!A8VME=%-I9VYA
M='5R92@D;7-G7W-I9VXL("=?4TE'3D%455)%)RD["@H@("`@("`@("\J(%-E
M='5P('1H92!M=6QT:7!A<G0@34E-12!087)T+B`J+PH@("`@("`@("1P87)T
M(#T@)FYE=R!-24U%7U!A<G0H)VUU;'1I<&%R="]S:6=N960G*3L*("`@("`@
M("`D<&%R="T^<V5T0V]N=&5N=',H)U1H:7,@;65S<V%G92!I<R!I;B!-24U%
M(&9O<FUA="!A;F0@:&%S(&)E96X@4$=0('-I9VYE9"XG("X@(EQN(BD["B`@
M("`@("`@)'!A<G0M/F%D9%!A<G0H)&UI;65?<&%R="D["B`@("`@("`@)'!A
M<G0M/F%D9%!A<G0H)'!G<%]S:6=N*3L*("`@("`@("`D<&%R="T^<V5T0V]N
M=&5N=%1Y<&5087)A;65T97(H)W!R;W1O8V]L)RP@)V%P<&QI8V%T:6]N+W!G
M<"US:6=N871U<F4G*3L*("`@("`@("`D<&%R="T^<V5T0V]N=&5N=%1Y<&50
M87)A;65T97(H)VUI8V%L9R<L("1S:6=?:6YF;ULG;6EC86QG)UTI.PH*("`@
M("`@("!R971U<FX@)'!A<G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%;F-R
M>7!T<R!A($U)345?4&%R="!U<VEN9R!01U`N"B`@("`@*@H@("`@("H@0'!A
M<F%M($U)345?4&%R="`D;6EM95]P87)T("!4:&4@34E-15]087)T(&]B:F5C
M="!T;R!E;F-R>7!T+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("`@
M("`@("!4:&4@<&%R86UE=&5R<R!R97%U:7)E9"!F;W(@96YC<GEP=&EO;BX*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($!S964@7V5N
M8W)Y<'1-97-S86=E*"DN"B`@("`@*@H@("`@("H@0')E='5R;B!-24U%7U!A
M<G0@($$@34E-15]087)T(&]B:F5C="!T:&%T(&ES(&5N8W)Y<'1E9"!A8V-O
M<F1I;F<@=&\@4D9#"B`@("`@*B`@("`@("`@("`@("`@("`@("`@,C`Q-2\S
M,34V+"!O<B!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!E;F-R>7!T34E-15!A<G0H)&UI;65?<&%R="P@)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@:6YC;'5D95]O;F-E("=(;W)D92]-24U%
M+U!A<G0N<&AP)SL*"B`@("`@("`@)'!A<F%M<R`](&%R<F%Y7VUE<F=E*"1P
M87)A;7,L(&%R<F%Y*"=T>7!E)R`]/B`G;65S<V%G92<I*3L*"B`@("`@("`@
M)'-I9VYE;F-?8F]D>2`]("1M:6UE7W!A<G0M/G1O0V%N;VYI8V%L4W1R:6YG
M*"D["B`@("`@("`@)&UE<W-A9V5?96YC<GEP="`]("1T:&ES+3YE;F-R>7!T
M*"1S:6=N96YC7V)O9'DL("1P87)A;7,I.PH@("`@("`@(&EF("AI<U]A*"1M
M97-S86=E7V5N8W)Y<'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1M97-S86=E7V5N8W)Y<'0["B`@("`@("`@?0H*("`@("`@("`O
M*B!3970@=7`@34E-12!3=')U8W1U<F4@86-C;W)D:6YG('1O(%)&0R`R,#$U
M+B`J+PH@("`@("`@("1P87)T(#T@)FYE=R!-24U%7U!A<G0H)VUU;'1I<&%R
M="]E;F-R>7!T960G*3L*("`@("`@("`D<&%R="T^<V5T0V]N=&5N=',H)U1H
M:7,@;65S<V%G92!I<R!I;B!-24U%(&9O<FUA="!A;F0@:&%S(&)E96X@4$=0
M(&5N8W)Y<'1E9"XG("X@(EQN(BD["B`@("`@("`@)'!A<G0M/F%D9%!A<G0H
M;F5W($U)345?4&%R="@G87!P;&EC871I;VXO<&=P+65N8W)Y<'1E9"<L(")6
M97)S:6]N.B`Q7&XB+"!N=6QL*2D["B`@("`@("`@)'!A<G0M/F%D9%!A<G0H
M;F5W($U)345?4&%R="@G87!P;&EC871I;VXO;V-T970M<W1R96%M)RP@)&UE
M<W-A9V5?96YC<GEP="P@;G5L;"P@)VEN;&EN92<I*3L*("`@("`@("`D<&%R
M="T^<V5T0V]N=&5N=%1Y<&5087)A;65T97(H)W!R;W1O8V]L)RP@)V%P<&QI
M8V%T:6]N+W!G<"UE;F-R>7!T960G*3L*("`@("`@("`D<&%R="T^<V5T1&5S
M8W)I<'1I;VXH7R@B4$=0($5N8W)Y<'1E9"!$871A(BDI.PH*("`@("`@("!R
M971U<FX@)'!A<G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3:6=N<R!A;F0@
M96YC<GEP=',@82!-24U%7U!A<G0@=7-I;F<@4$=0+@H@("`@("H*("`@("`J
M($!P87)A;2!-24U%7U!A<G0@)&UI;65?<&%R="`@(%1H92!-24U%7U!A<G0@
M;V)J96-T('1O('-I9VX@86YD(&5N8W)Y<'0N"B`@("`@*B!`<&%R86T@87)R
M87D@)'-I9VY?<&%R86US("`@("!4:&4@<&%R86UE=&5R<R!R97%U:7)E9"!F
M;W(@<VEG;FEN9RX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@($!S964@7V5N8W)Y<'13:6=N871U<F4H*2X*("`@("`J($!P87)A;2!A
M<G)A>2`D96YC<GEP=%]P87)A;7,@(%1H92!P87)A;65T97)S(')E<75I<F5D
M(&9O<B!E;F-R>7!T:6]N+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@0'-E92!?96YC<GEP=$UE<W-A9V4H*2X*("`@("`J"B`@("`@
M*B!`<F5T=7)N($U)345?4&%R="`@02!-24U%7U!A<G0@;V)J96-T('1H870@
M:7,@<VEG;F5D(&%N9"!E;F-R>7!T960*("`@("`J("`@("`@("`@("`@("`@
M("`@("!A8V-O<F1I;F<@=&\@4D9#(#(P,34O,S$U-BP@;W(@4$5!4E]%<G)O
M<B!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<VEG;D%N9$5N8W)Y
M<'1-24U%4&%R="@D;6EM95]P87)T+"`D<VEG;E]P87)A;7,@/2!A<G)A>2@I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D96YC<GEP
M=%]P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EN8VQU9&5?;VYC
M92`G2&]R9&4O34E-12]087)T+G!H<"<["@H@("`@("`@("\J(%)&0R`R,#$U
M(')E<75I<F5S('1H870@=&AE(&5N=&ER92!S:6=N960@;65S<V%G92!B92!E
M;F-R>7!T960N("!790H@("`@("`@("`J(&YE960@=&\@97AP;&EC:71L>2!C
M86QL('5S:6YG($AO<F1E7T-R>7!T7W!G<#HZ(&)E8V%U<V4@=V4@9&]N)W0*
M("`@("`@("`@*B!K;F]W('=H971H97(@82!S=6)C;&%S<R!H87,@97AT96YD
M960@=&AE<V4@;65T:&]D<RX@*B\*("`@("`@("`D<&%R="`]("1T:&ES+3YS
M:6=N34E-15!A<G0H)&UI;65?<&%R="P@)'-I9VY?<&%R86US*3L*("`@("`@
M("!I9B`H:7-?82@D<&%R="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'!A<G0["B`@("`@("`@?0H@("`@("`@("1P87)T(#T@)'1H
M:7,M/F5N8W)Y<'1-24U%4&%R="@D<&%R="P@)&5N8W)Y<'1?<&%R86US*3L*
M("`@("`@("!I9B`H:7-?82@D<&%R="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'!A<G0["B`@("`@("`@?0H@("`@("`@("1P87)T
M+3YS971#;VYT96YT<R@G5&AI<R!M97-S86=E(&ES(&EN($U)344@9F]R;6%T
M(&%N9"!H87,@8F5E;B!01U`@<VEG;F5D(&%N9"!E;F-R>7!T960N)R`N(")<
M;B(I.PH@("`@("`@("1P87)T+3YS971$97-C<FEP=&EO;BA?*")01U`@4VEG
M;F5D+T5N8W)Y<'1E9"!$871A(BDI.PH*("`@("`@("!R971U<FX@)'!A<G0[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T97,@82!-24U%7U!A<G0@
M;V)J96-T+"!I;B!A8V-O<F1A;F-E('=I=&@@4D9#(#(P,34O,S$U-BP@=&AA
M=`H@("`@("H@8V]N=&%I;G,@82!P=6)L:6,@:V5Y+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&ME>2`@5&AE('!U8FQI8R!K97DN"B`@("`@*@H@
M("`@("H@0')E='5R;B!-24U%7U!A<G0@($$@34E-15]087)T(&]B:F5C="!T
M:&%T(&-O;G1A:6YS('1H92!P=6)L:6,@:V5Y+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!P=6)L:6-+97E-24U%4&%R="@D:V5Y*0H@("`@>PH@("`@("`@(&EN
M8VQU9&5?;VYC92`G2&]R9&4O34E-12]087)T+G!H<"<["@H@("`@("`@("1P
M87)T(#T@)FYE=R!-24U%7U!A<G0H)V%P<&QI8V%T:6]N+W!G<"UK97ES)RP@
M)&ME>2P@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@("1P87)T+3YS971$
M97-C<FEP=&EO;BA?*")01U`@4'5B;&EC($ME>2(I*3L*"B`@("`@("`@<F5T
M=7)N("1P87)T.PH@("`@?0H*("`@("\J*@H@("`@("H@1G5N8W1I;VX@=&AA
M="!H86YD;&5S(&EN=&5R9F%C:6YG('=I=&@@=&AE($=N=5!'(&)I;F%R>2X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)&]P=&EO;G,@("!43T1/"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1M;V1E("`@("!43T1/"B`@("`@*B!`<&%R86T@87)R87D@)&EN<'5T
M("`@("!43T1/"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;W5T<'5T("!43T1/
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<W1D97)R("!43T1/"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=&1#;&%S<R`@5$]$3PH@("`@("HO"B`@("!F=6YC
M=&EO;B!?8V%L;$=P9R@D;W!T:6]N<RP@)&UO9&4L("1I;G!U="`](&%R<F%Y
M*"DL("1O=71P=70@/2!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("1S
M=&1E<G(@/2!F86QS92D*("`@('L*("`@("`@("`D8VUD;&EN92`](&%R<F%Y
M7VUE<F=E*"1T:&ES+3Y?9VYU<&<L("1O<'1I;VYS*3L*("`@("`@("`D9&%T
M82`]("9N97<@<W1D0VQA<W,["B`@("`@("`@)&1A=&$M/F]U='!U="`](&YU
M;&P["B`@("`@("`@)&1A=&$M/G-T9&5R<B`](&YU;&P["B`@("`@("`@)&1A
M=&$M/G-T9&]U="`](&YU;&P["@H@("`@("`@("\J($-R96%T92!T96UP(&9I
M;&5S(&9O<B!O=71P=70N("HO"B`@("`@("`@:68@*"1O=71P=70I('L*("`@
M("`@("`@("`@)&]U='!U=%]F:6QE(#T@)'1H:7,M/E]C<F5A=&5496UP1FEL
M92@G:&]R9&4M<&=P)RP@9F%L<V4I.PH@("`@("`@("`@("!A<G)A>5]U;G-H
M:69T*"1O<'1I;VYS+"`G+2UO=71P=70@)R`N("1O=71P=71?9FEL92D["@H@
M("`@("`@("`@("`O*B!$;R!W92!N965D('-T86YD87)D(&5R<F]R(&]U='!U
M=#\@*B\*("`@("`@("`@("`@:68@*"1S=&1E<G(I('L*("`@("`@("`@("`@
M("`@("1S=&1E<G)?9FEL92`]("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO
M<F1E+7!G<"<L(&9A;'-E*3L*("`@("`@("`@("`@("`@("1O<'1I;VYS6UT@
M/2`G,CX@)R`N("1S=&1E<G)?9FEL93L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@+RH@0G5I;&0@=&AE(&-O;6UA;F0@;&EN92!S=')I;F<@
M;F]W+B`J+PH@("`@("`@("1C;61L:6YE(#T@:6UP;&]D92@G("<L(&%R<F%Y
M7VUE<F=E*"1T:&ES+3Y?9VYU<&<L("1O<'1I;VYS*2D["@H@("`@("`@(&EF
M("@D;6]D92`]/2`G=R<I('L*("`@("`@("`@("`@)&9P(#T@<&]P96XH)&-M
M9&QI;F4L("=W)RD["B`@("`@("`@("`@("1W:6XS,B`]('-U8G-T<BA02%!?
M3U,L(#`L(#,I(#T]("=724XG.PH*("`@("`@("`@("`@:68@*"%I<U]A<G)A
M>2@D:6YP=70I*2!["B`@("`@("`@("`@("`@("`D:6YP=70@/2!A<G)A>2@D
M:6YP=70I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<F5A8V@@*"1I
M;G!U="!A<R`D;&EN92D@>PH@("`@("`@("`@("`@("`@:68@*"1W:6XS,B`F
M)B`H<W1R<&]S*"1L:6YE+"`B7'@P9%QX,&$B*2`A/3T@9F%L<V4I*2!["B`@
M("`@("`@("`@("`@("`@("`@)&-H=6YK<R`](&5X<&QO9&4H(EQX,&1<>#!A
M(BP@)&QI;F4I.PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1C:'5N
M:W,@87,@)&-H=6YK*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&9P=71S
M*"1F<"P@)&-H=6YK("X@(EQN(BD["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!F
M<'5T<R@D9G`L("1L:6YE("X@(EQN(BD["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H)&UO9&4@/3T@)W(G*2![
M"B`@("`@("`@("`@("1F<"`]('!O<&5N*"1C;61L:6YE+"`G<B<I.PH@("`@
M("`@("`@("!W:&EL92`H(69E;V8H)&9P*2D@>PH@("`@("`@("`@("`@("`@
M)&1A=&$M/G-T9&]U="`N/2!F9V5T<R@D9G`L(#$P,C0I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@('!C;&]S92@D9G`I.PH*("`@("`@("!I
M9B`H)&]U='!U="D@>PH@("`@("`@("`@("`D9&%T82T^;W5T<'5T(#T@9FEL
M95]G971?8V]N=&5N=',H)&]U='!U=%]F:6QE*3L*("`@("`@("`@("`@=6YL
M:6YK*"1O=71P=71?9FEL92D["B`@("`@("`@("`@(&EF("@D<W1D97)R*2![
M"B`@("`@("`@("`@("`@("`D9&%T82T^<W1D97)R(#T@9FEL95]G971?8V]N
M=&5N=',H)'-T9&5R<E]F:6QE*3L*("`@("`@("`@("`@("`@('5N;&EN:R@D
M<W1D97)R7V9I;&4I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&1A=&$["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<```````````````````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$T-#4R,0`Q
M,#4Q-30S,S<U,``P,C(T,34`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O0W)Y
M<'0N<&AP)SL*"B\J*@H@*B!(;W)D95]#<GEP=%]S;6EM93HZ('!R;W9I9&5S
M(&$@9G)A;65W;W)K(&9O<B!(;W)D92!A<'!L:6-A=&EO;G,@=&\*("H@:6YT
M97)A8W0@=VET:"!T:&4@3W!E;E-33"!L:6)R87)Y(&%N9"!I;7!L96UE;G0@
M4R]-24U%+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`L=B`Q+C0Y+C(N,3(@,C`P-B\P,B\P,R`Q-3HU,CHU-2!S;'5S
M87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EK92!#;V-H
M<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN
M8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D
M95]#<GEP=`H@*B\*8VQA<W,@2&]R9&5?0W)Y<'1?<VUI;64@97AT96YD<R!(
M;W)D95]#<GEP="!["@H@("`@+RHJ"B`@("`@*B!/8FIE8W0@261E;G1I9F5R
M<R!T;R!N86UE(&%R<F%Y+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1?;VED<R`](&%R<F%Y*`H@("`@("`@("<R+C4N-"XS
M)R`]/B`G0V]M;6]N3F%M92<L"B`@("`@("`@)S(N-2XT+C0G(#T^("=3=7)N
M86UE)RP*("`@("`@("`G,BXU+C0N-B<@/3X@)T-O=6YT<GDG+`H@("`@("`@
M("<R+C4N-"XW)R`]/B`G3&]C871I;VXG+`H@("`@("`@("<R+C4N-"XX)R`]
M/B`G4W1A=&5/<E!R;W9I;F-E)RP*("`@("`@("`G,BXU+C0N.2<@/3X@)U-T
M<F5E=$%D9')E<W,G+`H@("`@("`@("<R+C4N-"XQ,"<@/3X@)T]R9V%N:7-A
M=&EO;B<L"B`@("`@("`@)S(N-2XT+C$Q)R`]/B`G3W)G86YI<V%T:6]N86Q5
M;FET)RP*("`@("`@("`G,BXU+C0N,3(G(#T^("=4:71L92<L"B`@("`@("`@
M)S(N-2XT+C(P)R`]/B`G5&5L97!H;VYE3G5M8F5R)RP*("`@("`@("`G,BXU
M+C0N-#(G(#T^("=':79E;DYA;64G+`H*("`@("`@("`G,BXU+C(Y+C$T)R`]
M/B`G:60M8V4M<W5B:F5C=$ME>4ED96YT:69I97(G+`H*("`@("`@("`G,BXU
M+C(Y+C$T)R`]/B`G:60M8V4M<W5B:F5C=$ME>4ED96YT:69I97(G+`H@("`@
M("`@("<R+C4N,CDN,34G(#T^("=I9"UC92UK97E5<V%G92<L"B`@("`@("`@
M)S(N-2XR.2XQ-R<@/3X@)VED+6-E+7-U8FIE8W1!;'1.86UE)RP*("`@("`@
M("`G,BXU+C(Y+C$Y)R`]/B`G:60M8V4M8F%S:6-#;VYS=')A:6YT<R<L"B`@
M("`@("`@)S(N-2XR.2XS,2<@/3X@)VED+6-E+4-23$1I<W1R:6)U=&EO;E!O
M:6YT<R<L"B`@("`@("`@)S(N-2XR.2XS,B<@/3X@)VED+6-E+6-E<G1I9FEC
M871E4&]L:6-I97,G+`H@("`@("`@("<R+C4N,CDN,S4G(#T^("=I9"UC92UA
M=71H;W)I='E+97E)9&5N=&EF:65R)RP*("`@("`@("`G,BXU+C(Y+C,W)R`]
M/B`G:60M8V4M97AT2V5Y57-A9V4G+`H*("`@("`@("`G,2XR+C@T,"XQ,3,U
M-#DN,2XY+C$G(#T^("=%;6%I;"<L"B`@("`@("`@)S$N,BXX-#`N,3$S-30Y
M+C$N,2XQ)R`]/B`G4E-!16YC<GEP=&EO;B<L"B`@("`@("`@)S$N,BXX-#`N
M,3$S-30Y+C$N,2XR)R`]/B`G;60R5VET:%)3045N8W)Y<'1I;VXG+`H@("`@
M("`@("<Q+C(N.#0P+C$Q,S4T.2XQ+C$N-"<@/3X@)VUD-7=I=&A24T%%;F-R
M>7!T:6]N)RP*("`@("`@("`G,2XR+C@T,"XQ,3,U-#DN,2XQ+C4G(#T^("=3
M2$$M,5=I=&A24T%%;F-R>7!T:6]N)RP*("`@("`@("`G,2XR+C@T,"XQ,#`T
M,"XT+C,G(#T^("=I9"UD<V$M=VET:"US:&$M,2<L"@H@("`@("`@("<Q+C,N
M-BXQ+C4N-2XW+C,N,B<@/3X@)VED7VMP7V-L:65N=$%U=&@G+`H*("`@("`@
M("`G,BXQ-BXX-#`N,2XQ,3,W,S`N,2XQ)R`]/B`G;F5T<V-A<&4M8V5R="UT
M>7!E)RP*("`@("`@("`G,BXQ-BXX-#`N,2XQ,3,W,S`N,2XR)R`]/B`G;F5T
M<V-A<&4M8F%S92UU<FPG+`H@("`@("`@("<R+C$V+C@T,"XQ+C$Q,S<S,"XQ
M+C,G(#T^("=N971S8V%P92UR979O8V%T:6]N+75R;"<L"B`@("`@("`@)S(N
M,38N.#0P+C$N,3$S-S,P+C$N-"<@/3X@)VYE='-C87!E+6-A+7)E=F]C871I
M;VXM=7)L)RP*("`@("`@("`G,BXQ-BXX-#`N,2XQ,3,W,S`N,2XW)R`]/B`G
M;F5T<V-A<&4M8V5R="UR96YE=V%L+75R;"<L"B`@("`@("`@)S(N,38N.#0P
M+C$N,3$S-S,P+C$N."<@/3X@)VYE='-C87!E+6-A+7!O;&EC>2UU<FPG+`H@
M("`@("`@("<R+C$V+C@T,"XQ+C$Q,S<S,"XQ+C$R)R`]/B`G;F5T<V-A<&4M
M<W-L+7-E<G9E<BUN86UE)RP*("`@("`@("`G,BXQ-BXX-#`N,2XQ,3,W,S`N
M,2XQ,R<@/3X@)VYE='-C87!E+6-O;6UE;G0G+`H@("`@*3L*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`D<&%R86US("!087)A;65T97(@87)R87DN"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@)W1E;7`G(#T^($QO8V%T:6]N(&]F('1E;7!O<F%R>2!D
M:7)E8W1O<GDN"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7T-R>7!T7W-M
M:6UE*"1P87)A;7,I"B`@("!["B`@("`@("`@)'1H:7,M/E]T96UP9&ER(#T@
M)'!A<F%M<ULG=&5M<"==.PH@("`@?0H*("`@("\J*@H@("`@("H@5F5R:69Y
M(&$@<&%S<W!H<F%S92!F;W(@82!G:79E;B!P<FEV871E(&ME>2X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<FEV871E7VME>2`@5&AE('5S97(G
M<R!P<FEV871E(&ME>2X*("`@("`J($!P87)A;2!S=')I;F<@)'!A<W-P:')A
M<V4@("!4:&4@=7-E<B=S('!A<W-P:')A<V4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!2971U<FYS('1R=64@;VX@=F%L:60@<&%S<W!H<F%S
M92P@9F%L<V4@;VX@:6YV86QI9`H@("`@("H@("`@("`@("`@("`@("`@("!P
M87-S<&AR87-E+@H@("`@("H@("`@("`@("`@("`@("`@("!2971U<FYS(%!%
M05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N('9E<FEF
M>5!A<W-P:')A<V4H)'!R:79A=&5?:V5Y+"`D<&%S<W!H<F%S92D*("`@('L*
M("`@("`@("!I9B`H:7-?;G5L;"@D<&%S<W!H<F%S92DI('L*("`@("`@("`@
M("`@)')E<R`](&]P96YS<VQ?<&ME>5]G971?<')I=F%T92@D<')I=F%T95]K
M97DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R97,@/2!O<&5N
M<W-L7W!K97E?9V5T7W!R:79A=&4H)'!R:79A=&5?:V5Y+"`D<&%S<W!H<F%S
M92D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@:7-?<F5S;W5R8V4H)')E
M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%;F-R>7!T('1E>'0@=7-I;F<@
M4R]-24U%+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("!4
M:&4@=&5X="!T;R!B92!E;F-R>7!T960N"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@5&AE('!A<F%M971E<G,@;F5E9&5D(&9O<B!E;F-R>7!T:6]N
M+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(%-E92!T:&4@:6YD:79I
M9'5A;"!?96YC<GEP="HH*2!F=6YC=&EO;G,@9F]R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@=&AE('!A<F%M971E<B!R97%U:7)E;65N=',N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!E;F-R>7!T960@;65S
M<V%G92X*("`@("`J("`@("`@("`@("`@("`@("!2971U<FYS(%!%05)?17)R
M;W(@;V)J96-T(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!E;F-R
M>7!T*"1T97AT+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`O
M*B!#:&5C:R!F;W(@879A:6QA8FEL:71Y(&]F($]P96Y34TP@4$A0(&5X=&5N
M<VEO;BX@*B\*("`@("`@("`D;W!E;G-S;"`]("1T:&ES+3YC:&5C:T9O<D]P
M96Y34TPH*3L*("`@("`@("!I9B`H:7-?82@D;W!E;G-S;"P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&]P96YS<VP["B`@("`@("`@
M?0H*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG='EP92==*2D@>PH@("`@
M("`@("`@("!I9B`H)'!A<F%M<ULG='EP92==(#T]/2`G;65S<V%G92<I('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V5N8W)Y<'1-97-S86=E
M*"1T97AT+"`D<&%R86US*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1P87)A
M;7-;)W1Y<&4G72`]/3T@)W-I9VYA='5R92<I('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7V5N8W)Y<'13:6=N871U<F4H)'1E>'0L("1P87)A
M;7,I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@1&5C<GEP="!T97AT('9I82!3+TU)344N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=&5X="`@(%1H92!T97AT('1O(&)E('-M:6UE(&1E
M8W)Y<'1E9"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!4:&4@<&%R
M86UE=&5R<R!N965D960@9F]R(&1E8W)Y<'1I;VXN"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@4V5E('1H92!I;F1I=FED=6%L(%]D96-R>7!T*B@I
M(&9U;F-T:6]N<R!F;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T
M:&4@<&%R86UE=&5R(')E<75I<F5M96YT<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(&1E8W)Y<'1E9"!M97-S86=E+@H@("`@("H@("`@
M("`@("`@("`@("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O8FIE8W0@;VX@97)R
M;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E8W)Y<'0H)'1E>'0L("1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("\J($-H96-K(&9O<B!A=F%I
M;&%B:6QI='D@;V8@3W!E;E-33"!02%`@97AT96YS:6]N+B`J+PH@("`@("`@
M("1O<&5N<W-L(#T@)'1H:7,M/F-H96-K1F]R3W!E;E-33"@I.PH@("`@("`@
M(&EF("AI<U]A*"1O<&5N<W-L+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D;W!E;G-S;#L*("`@("`@("!]"@H@("`@("`@(&EF("AI
M<W-E="@D<&%R86US6R=T>7!E)UTI*2!["B`@("`@("`@("`@(&EF("@D<&%R
M86US6R=T>7!E)UT@/3T]("=M97-S86=E)RD@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?9&5C<GEP=$UE<W-A9V4H)'1E>'0L("1P87)A;7,I
M.PH@("`@("`@("`@("!](&5L<V5I9B`H*"1P87)A;7-;)W1Y<&4G72`]/3T@
M)W-I9VYA='5R92<I('Q\"B`@("`@("`@("`@("`@("`@("`@("`H)'!A<F%M
M<ULG='EP92==(#T]/2`G9&5T86-H960M<VEG;F%T=7)E)RDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1E8W)Y<'13:6=N871U<F4H)'1E
M>'0L("1P87)A;7,I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@5F5R:69Y(&$@<VEG;F%T=7)E('5S:6YG('9I82!3
M+TU)344N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE
M(&UU;'1I<&%R="]S:6=N960@9&%T82!T;R!B92!V97)I9FEE9"X*("`@("`J
M($!P87)A;2!M:7AE9"`D8V5R=',@($5I=&AE<B!A('-I;F=L92!O<B!A<G)A
M>2!O9B!R;V]T(&-E<G1I9FEC871E<RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T9$-L87-S("!/8FIE8W0@=VET:"!T:&4@9F]L;&]W:6YG(&5L96UE;G1S
M.@H@("`@("H@("`@("`@("`@("`@("`@("`@)W)E<W5L="<@+3X@4F5T=7)N
M<R!T<G5E(&]N('-U8V-E<W,["B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!014%27T5R<F]R(&]B:F5C="!O;B!E<G)O<BX*("`@("`J
M("`@("`@("`@("`@("`@("`@("=C97)T)R`M/B!4:&4@8V5R=&EF:6-A=&4@
M;V8@=&AE('-I9VYE<B!S=&]R960*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I;B!T:&4@;65S<V%G92`H:6X@4$5-(&9O<FUA="DN"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`G96UA:6PG("T^(%1H92!E;6%I;"!O
M9B!T:&4@<VEG;FEN9R!P97)S;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N('9E
M<FEF>2@D=&5X="P@)&-E<G1S*0H@("`@>PH@("`@("`@("\J($-H96-K(&9O
M<B!A=F%I;&%B:6QI='D@;V8@3W!E;E-33"!02%`@97AT96YS:6]N+B`J+PH@
M("`@("`@("1O<&5N<W-L(#T@)'1H:7,M/F-H96-K1F]R3W!E;E-33"@I.PH@
M("`@("`@(&EF("AI<U]A*"1O<&5N<W-L+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D;W!E;G-S;#L*("`@("`@("!]"@H@("`@("`@
M("\J($-R96%T92!T96UP(&9I;&5S(&9O<B!I;G!U="]O=71P=70N("HO"B`@
M("`@("`@)&EN<'5T(#T@)'1H:7,M/E]C<F5A=&5496UP1FEL92@G:&]R9&4M
M<VUI;64G*3L*("`@("`@("`D;W5T<'5T(#T@)'1H:7,M/E]C<F5A=&5496UP
M1FEL92@G:&]R9&4M<VUI;64G*3L*"B`@("`@("`@+RH@5W)I=&4@=&5X="!T
M;R!F:6QE("HO"B`@("`@("`@)&9P(#T@9F]P96XH)&EN<'5T+"`G=RLG*3L*
M("`@("`@("!F=W)I=&4H)&9P+"`D=&5X="D["B`@("`@("`@9F-L;W-E*"1F
M<"D["@H@("`@("`@("1R;V]T7V-E<G1S(#T@87)R87DH*3L*("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1C97)T<RDI('L*("`@("`@("`@("`@)&-E<G1S(#T@
M87)R87DH)&-E<G1S*3L*("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H)&-E
M<G1S(&%S("1F:6QE*2!["B`@("`@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D
M9FEL92DI('L*("`@("`@("`@("`@("`@("1R;V]T7V-E<G1S6UT@/2`D9FEL
M93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&]B(#T@)FYE
M=R!S=&1#;&%S<SL*"B`@("`@("`@:68@*"%E;7!T>2@D<F]O=%]C97)T<RDI
M('L*("`@("`@("`@("`@)')E<W5L="`](&]P96YS<VQ?<&MC<S=?=F5R:69Y
M*"1I;G!U="P@,"P@)&]U='!U="P@)')O;W1?8V5R=',I.PH@("`@("`@("`@
M("`O*B!-97-S86=E('9E<FEF:65D("HO"B`@("`@("`@("`@(&EF("@D<F5S
M=6QT(#T]/2!T<G5E*2!["B`@("`@("`@("`@("`@("`D;V(M/G)E<W5L="`]
M('1R=64["B`@("`@("`@("`@("`@("`D;V(M/F-E<G0@/2!F:6QE7V=E=%]C
M;VYT96YT<R@D;W5T<'5T*3L*("`@("`@("`@("`@("`@("1O8BT^96UA:6P@
M/2`D=&AI<RT^9V5T16UA:6Q&<F]M2V5Y*"1O8BT^8V5R="D["B`@("`@("`@
M("`@("`@("!R971U<FX@)&]B.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`O*B!4<GD@86=A:6X@=VET:&]U="!V97)F>6EN9R!T:&4@<VEG
M;F5R)W,@8V5R="`J+PH@("`@("`@("1R97-U;'0@/2!O<&5N<W-L7W!K8W,W
M7W9E<FEF>2@D:6YP=70L(%!+0U,W7TY/5D522499+"`D;W5T<'5T*3L*"B`@
M("`@("`@:68@*"@D<F5S=6QT(#T]/2!T<G5E*2!\?"`H)')E<W5L="`]/3T@
M+3$I*2!["B`@("`@("`@("`@("1O8BT^<F5S=6QT(#T@4$5!4CHZ<F%I<V5%
M<G)O<BA?*")-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE
M('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"XB
M*2P@)VAO<F1E+G=A<FYI;F<G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D;V(M/G)E<W5L="`](%!%05(Z.G)A:7-E17)R;W(H7R@B5F5R:69I
M8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A
M;7!E<F5D('=I=&@N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T*"B`@
M("`@("`@)&]B+3YC97)T(#T@9FEL95]G971?8V]N=&5N=',H)&]U='!U="D[
M"B`@("`@("`@)&]B+3YE;6%I;"`]("1T:&ES+3YG971%;6%I;$9R;VU+97DH
M)&]B+3YC97)T*3L*"B`@("`@("`@<F5T=7)N("1O8CL*("`@('T*"B`@("`O
M*BH*("`@("`J($5X=')A8W0@=&AE(&-O;G1E;G1S(&9R;VT@<VEG;F5D(%,O
M34E-12!D871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&$@
M("`@(%1H92!S:6=N960@4R]-24U%(&1A=&$N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1S<VQP871H("!4:&4@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GDN
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C;VYT96YT<R!E
M;6)E9&1E9"!I;B!T:&4@<VEG;F5D(&1A=&$N"B`@("`@*B`@("`@("`@("`@
M("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!E>'1R86-T4VEG;F5D0V]N=&5N=',H)&1A=&$L("1S<VQP
M871H*0H@("`@>PH@("`@("`@("1P:7!E<U]D97-C(#T@87)R87DH"B`@("`@
M("`@("`@(#`@/3X@87)R87DH)W!I<&4G+"`G<B<I+`H@("`@("`@("`@("`Q
M(#T^(&%R<F%Y*"=P:7!E)RP@)W<G*0H@("`@("`@("D["@H@("`@("`@("1F
M<"`]('!R;V-?;W!E;B@D<W-L<&%T:"`N("<@<VUI;64@+79E<FEF>2`M;F]V
M97)I9GD@+6YO8VAA:6XG+"`D<&EP97-?9&5S8RP@)'!I<&5S*3L*("`@("`@
M("!I9B`H(6ES7W)E<V]U<F-E*"1F<"DI('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T
M(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="XB*2P@)VAO
M<F1E+F5R<F]R)RD["B`@("`@("`@?0H*("`@("`@("`D;W5T<'5T(#T@)R<[
M"@H@("`@("`@("\J("1P:7!E<ULP72`]/B!W<FET96%B;&4@:&%N9&QE(&-O
M;FYE8W1E9"!T;R!C:&EL9"!S=&1I;@H@("`@("`@("`@("1P:7!E<ULQ72`]
M/B!R96%D86)L92!H86YD;&4@8V]N;F5C=&5D('1O(&-H:6QD('-T9&]U="`J
M+PH@("`@("`@(&9W<FET92@D<&EP97-;,%TL("1D871A*3L*("`@("`@("!F
M8VQO<V4H)'!I<&5S6S!=*3L*"B`@("`@("`@=VAI;&4@*"%F96]F*"1P:7!E
M<ULQ72DI('L*("`@("`@("`@("`@)&]U='!U="`N/2!F9V5T<R@D<&EP97-;
M,5TL(#$P,C0I.PH@("`@("`@('T*("`@("`@("!F8VQO<V4H)'!I<&5S6S%=
M*3L*("`@("`@("!P<F]C7V-L;W-E*"1F<"D["@H@("`@("`@(')E='5R;B`D
M;W5T<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@4VEG;B!A($U)345?4&%R
M="!U<VEN9R!3+TU)344N"B`@("`@*@H@("`@("H@0'!A<F%M($U)345?4&%R
M="`D;6EM95]P87)T("!4:&4@34E-15]087)T(&]B:F5C="!T;R!S:6=N+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("`@("`@("!4:&4@<&%R86UE
M=&5R<R!R97%U:7)E9"!F;W(@<VEG;FEN9RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N($U)345?4&%R="`@02!-24U%7U!A<G0@;V)J96-T('1H870@:7,@<VEG
M;F5D+@H@("`@("H@("`@("`@("`@("`@("`@("`@(%)E='5R;G,@4$5!4E]%
M<G)O<B!O8FIE8W0@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N('-I
M9VY-24U%4&%R="@D;6EM95]P87)T+"`D<&%R86US*0H@("`@>PH@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O34E-12]087)T+G!H<"<["B`@("`@("`@
M<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+U-T<G5C='5R92YP:'`G.PH*("`@
M("`@("`O*B!3:6=N('1H92!P87)T(&%S(&$@;65S<V%G92`J+PH@("`@("`@
M("1M97-S86=E(#T@)'1H:7,M/F5N8W)Y<'0H)&UI;65?<&%R="T^=&]#86YO
M;FEC86Q3=')I;F<H*2P@)'!A<F%M<RD["@H@("`@("`@("\J($)R96%K('1H
M92!R97-U;'0@:6YT;R!I=',@8V]M<&]N96YT<R`J+PH@("`@("`@("1M:6UE
M7VUE<W-A9V4@/2!-24U%7U-T<G5C='5R93HZ<&%R<V5497AT34E-14UE<W-A
M9V4H)&UE<W-A9V4I.PH*("`@("`@("`D<VUI;65?<VEG;B`]("1M:6UE7VUE
M<W-A9V4M/F=E=%!A<G0H,BD["B`@("`@("`@)'-M:6UE7W-I9VXM/G-E=$1E
M<V-R:7!T:6]N*%\H(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(I
M*3L*("`@("`@("`D<VUI;65?<VEG;BT^=')A;G-F97)$96-O9&5#;VYT96YT
M<R@I.PH@("`@("`@("1S;6EM95]S:6=N+3YS9714<F%N<V9E<D5N8V]D:6YG
M*"=B87-E-C0G*3L*"B`@("`@("`@)'-M:6UE7W!A<G0@/2`F;F5W($U)345?
M4&%R="@G;75L=&EP87)T+W-I9VYE9"<I.PH@("`@("`@("1S;6EM95]P87)T
M+3YS971#;VYT96YT<R@G5&AI<R!I<R!A(&-R>7!T;V=R87!H:6-A;&QY('-I
M9VYE9"!M97-S86=E(&EN($U)344@9F]R;6%T+B<@+B`B7&XB*3L*("`@("`@
M("`D<VUI;65?<&%R="T^861D4&%R="@D;6EM95]P87)T*3L*("`@("`@("`D
M<VUI;65?<&%R="T^861D4&%R="@D<VUI;65?<VEG;BD["B`@("`@("`@)'-M
M:6UE7W!A<G0M/G-E=$-O;G1E;G14>7!E4&%R86UE=&5R*"=P<F]T;V-O;"<L
M("=A<'!L:6-A=&EO;B]P:V-S-RUS:6=N871U<F4G*3L*("`@("`@("`D<VUI
M;65?<&%R="T^<V5T0V]N=&5N=%1Y<&5087)A;65T97(H)VUI8V%L9R<L("=S
M:&$Q)RD["@H@("`@("`@(')E='5R;B`D<VUI;65?<&%R=#L*("`@('T*"B`@
M("`O*BH*("`@("`J($5N8W)Y<'0@82!-24U%7U!A<G0@=7-I;F<@4R]-24U%
M+@H@("`@("H*("`@("`J($!P87)A;2!-24U%7U!A<G0@)&UI;65?<&%R="`@
M5&AE($U)345?4&%R="!O8FIE8W0@=&\@96YC<GEP="X*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("`@("`@("`@5&AE('!A<F%M971E<G,@<F5Q=6ER
M960@9F]R(&5N8W)Y<'1I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!-24U%
M7U!A<G0@($$@34E-15]087)T(&]B:F5C="!T:&%T(&ES(&5N8W)Y<'1E9"X*
M("`@("`J("`@("`@("`@("`@("`@("`@("!2971U<FYS(%!%05)?17)R;W(@
M;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8W)Y<'1-24U%4&%R
M="@D;6EM95]P87)T+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O4&%R="YP:'`G.PH@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O34E-12]3=')U8W1U<F4N<&AP)SL*"B`@
M("`@("`@+RH@4VEG;B!T:&4@<&%R="!A<R!A(&UE<W-A9V4@*B\*("`@("`@
M("`D;65S<V%G92`]("1T:&ES+3YE;F-R>7!T*"1M:6UE7W!A<G0M/G1O0V%N
M;VYI8V%L4W1R:6YG*"DL("1P87)A;7,I.PH@("`@("`@(&EF("AI<U]A*"1M
M97-S86=E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M;65S<V%G93L*("`@("`@("!]"@H@("`@("`@("\J($)R96%K('1H92!R97-U
M;'0@:6YT;R!I=',@8V]M<&]N96YT<R`J+PH@("`@("`@("1M:6UE7VUE<W-A
M9V4@/2!-24U%7U-T<G5C='5R93HZ<&%R<V5497AT34E-14UE<W-A9V4H)&UE
M<W-A9V4I.PH*("`@("`@("`D<VUI;65?<&%R="`]("1M:6UE7VUE<W-A9V4M
M/F=E=$)A<V5087)T*"D["B`@("`@("`@)'-M:6UE7W!A<G0M/G-E=$1E<V-R
M:7!T:6]N*%\H(E,O34E-12!%;F-R>7!T960@365S<V%G92(I*3L*("`@("`@
M("`D<VUI;65?<&%R="T^=')A;G-F97)$96-O9&5#;VYT96YT<R@I.PH@("`@
M("`@("1S;6EM95]P87)T+3YS9714<F%N<V9E<D5N8V]D:6YG*"=B87-E-C0G
M*3L*("`@("`@("`D<VUI;65?<&%R="T^<V5T1&ES<&]S:71I;VXH)VEN;&EN
M92<I.PH*("`@("`@("`O*B!">2!D969A=6QT+"!E;F-R>7!T*"D@<')O9'5C
M97,@82!M97-S86=E('=I=&@@='EP90H@("`@("`@("`J("=A<'!L:6-A=&EO
M;B]X+7!K8W,W+6UI;64G(&%N9"!N;R`G<VUI;64M='EP92<@<&%R86UE=&5R
M+B!097(*("`@("`@("`@*B!21D,@,C,Q,2P@=&AE(&UO<F4@8V]R<F5C="!-
M24U%('1Y<&4@:7,@)V%P<&QI8V%T:6]N+W!K8W,W+6UI;64G"B`@("`@("`@
M("H@86YD('1H92!S;6EM92UT>7!E('-H;W5L9"!B92`G96YV96QO<&5D+61A
M=&$G+B`J+PH@("`@("`@("1S;6EM95]P87)T+3YS9714>7!E*"=A<'!L:6-A
M=&EO;B]P:V-S-RUM:6UE)RD["B`@("`@("`@)'-M:6UE7W!A<G0M/G-E=$-O
M;G1E;G14>7!E4&%R86UE=&5R*"=S;6EM92UT>7!E)RP@)V5N=F5L;W!E9"UD
M871A)RD["@H@("`@("`@(')E='5R;B`D<VUI;65?<&%R=#L*("`@('T*"B`@
M("`O*BH*("`@("`J($5N8W)Y<'0@82!M97-S86=E(&EN(%,O34E-12!F;W)M
M870@=7-I;F<@82!P=6)L:6,@:V5Y+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("!4
M:&4@=&5X="!T;R!B92!E;F-R>7!T960N"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@5&AE('!A<F%M971E<G,@;F5E9&5D(&9O<B!E;F-R>7!T:6]N
M+@H@("`@("H@/'!R93X*("`@("`J(%!A<F%M971E<G,Z"B`@("`@*B`]/3T]
M/3T]/3T]/0H@("`@("H@)W1Y<&4G("`@(#T^("`G;65S<V%G92<@*%)%455)
M4D5$*0H@("`@("H@)W!U8FME>2<@(#T^("!P=6)L:6,@:V5Y+B`H4D5154E2
M140I"B`@("`@*B`G96UA:6PG("`@/3X@($4M;6%I;"!A9&1R97-S(&]F(')E
M8VEP:65N="X@268@;F]T('!R97-E;G0L(&]R(&YO="!F;W5N9`H@("`@("H@
M("`@("`@("`@("`@("!I;B!T:&4@<'5B;&EC(&ME>2P@=&AE(&9I<G-T(&4M
M;6%I;"!A9&1R97-S(&9O=6YD(&EN('1H90H@("`@("H@("`@("`@("`@("`@
M("!K97D@=VEL;"!B92!U<V5D(&EN<W1E860N("A/<'1I;VYA;"D*("`@("`J
M(#PO<')E/@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@96YC
M<GEP=&5D(&UE<W-A9V4N"B`@("`@*B`@("`@("`@("`@("`@("`@4F5T=7)N
M(%!%05)?17)R;W(@;V)J96-T(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?96YC<GEP=$UE<W-A9V4H)'1E>'0L("1P87)A;7,I"B`@("!["B`@
M("`@("`@)&5M86EL(#T@;G5L;#L*"B`@("`@("`@+RH@0VAE8VL@9F]R(')E
M<75I<F5D('!A<F%M971E<G,N("HO"B`@("`@("`@:68@*"%I<W-E="@D<&%R
M86US6R=P=6)K97DG72DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H7R@B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@
M("!]"@H@("`@("`@("\J($-R96%T92!T96UP(&9I;&5S(&9O<B!I;G!U="]O
M=71P=70N("HO"B`@("`@("`@)&EN<'5T(#T@)'1H:7,M/E]C<F5A=&5496UP
M1FEL92@G:&]R9&4M<VUI;64G*3L*("`@("`@("`D;W5T<'5T(#T@)'1H:7,M
M/E]C<F5A=&5496UP1FEL92@G:&]R9&4M<VUI;64G*3L*"B`@("`@("`@+RH@
M4W1O<F4@;65S<V%G92!I;B!F:6QE+B`J+PH@("`@("`@("1F<#$@/2!F;W!E
M;B@D:6YP=70L("=W*R<I.PH@("`@("`@(&9P=71S*"1F<#$L("1T97AT*3L*
M("`@("`@("!F8VQO<V4H)&9P,2D["@H@("`@("`@(&EF("AI<W-E="@D<&%R
M86US6R=E;6%I;"==*2D@>PH@("`@("`@("`@("`D96UA:6P@/2`D<&%R86US
M6R=E;6%I;"==.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1E;6%I
M;"`]("1T:&ES+3YG971%;6%I;$9R;VU+97DH)'!A<F%M<ULG<'5B:V5Y)UTI
M.PH@("`@("`@("`@("!I9B`H:7-?;G5L;"@D96UA:6PI*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@
M9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB*2P@
M)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("\J($5N8W)Y<'0@=&AE(&1O8W5M96YT+B`J+PH@("`@("`@(&EF("AO
M<&5N<W-L7W!K8W,W7V5N8W)Y<'0H)&EN<'5T+"`D;W5T<'5T+"`D<&%R86US
M6R=P=6)K97DG72P@87)R87DH)U1O)R`]/B`D96UA:6PI*2D@>PH@("`@("`@
M("`@("`D<F5S=6QT(#T@9FEL95]G971?8V]N=&5N=',H)&]U='!U="D["B`@
M("`@("`@("`@(&EF("@A96UP='DH)')E<W5L="DI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7V9I>$-O;G1E;G14>7!E*"1R97-U;'0L("=E
M;F-R>7!T)RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O=6QD(&YO="!3+TU)344@96YC
M<GEP="!M97-S86=E+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-I9VX@82!M97-S86=E(&EN(%,O34E-12!F;W)M870@=7-I
M;F<@82!P<FEV871E(&ME>2X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@5&AE('1E
M>'0@=&\@8F4@<VEG;F5D+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@
M(%1H92!P87)A;65T97)S(&YE961E9"!F;W(@<VEG;FEN9RX*("`@("`J(#QP
M<F4^"B`@("`@*B!087)A;65T97)S.@H@("`@("H@/3T]/3T]/3T]/3T*("`@
M("`J("=C97)T<R<@("`@("`@/3X@($%D9&ET:6]N86P@<VEG;FEN9R!C97)T
M<R`H3W!T:6]N86PI"B`@("`@*B`G<&%S<W!H<F%S92<@(#T^("!087-S<&AR
M87-E(&9O<B!K97D@*%)%455)4D5$*0H@("`@("H@)W!R:79K97DG("`@("`]
M/B`@4')I=F%T92!K97D@*%)%455)4D5$*0H@("`@("H@)W!U8FME>2<@("`@
M("`]/B`@4'5B;&EC(&ME>2`H4D5154E2140I"B`@("`@*B`G<VEG='EP92<@
M("`@(#T^("!$971E<FUI;F4@=&AE('-I9VYA='5R92!T>7!E('1O('5S92X@
M*$]P=&EO;F%L*0H@("`@("H@("`@("`@("`@("`@("`@("`@)V-L96%R=&5X
M="<@("TM("!-86ME(&$@8VQE87(@=&5X="!S:6=N871U<F4*("`@("`J("`@
M("`@("`@("`@("`@("`@("=D971A8V@G("`@("`M+2`@36%K92!A(&1E=&%C
M:&5D('-I9VYA='5R92`H1$5&055,5"D*("`@("`J("=T>7!E)R`@("`@("`@
M/3X@("=S:6=N871U<F4G("A215%525)%1"D*("`@("`J(#PO<')E/@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<VEG;F5D(&UE<W-A9V4N
M"B`@("`@*B`@("`@("`@("`@("`@("`@4F5T=7)N(%!%05)?17)R;W(@;V)J
M96-T(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!?96YC<GEP=%-I
M9VYA='5R92@D=&5X="P@)'!A<F%M<RD*("`@('L*("`@("`@("`O*B!#:&5C
M:R!F;W(@<V5C=7)E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'-E8W5R95]C
M:&5C:R`]("1T:&ES+3YR97%U:7)E4V5C=7)E0V]N;F5C=&EO;B@I.PH@("`@
M("`@(&EF("AI<U]A*"1S96-U<F5?8VAE8VLL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1S96-U<F5?8VAE8VL["B`@("`@("`@?0H*
M("`@("`@("`O*B!#:&5C:R!F;W(@<F5Q=6ER960@<&%R86UE=&5R<RX@*B\*
M("`@("`@("!I9B`H(6ES<V5T*"1P87)A;7-;)W!U8FME>2==*2!\?`H@("`@
M("`@("`@("`A:7-S970H)'!A<F%M<ULG<')I=FME>2==*2!\?`H@("`@("`@
M("`@("`A87)R87E?:V5Y7V5X:7-T<R@G<&%S<W!H<F%S92<L("1P87)A;7,I
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D$@
M<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+B(I+"`G
M:&]R9&4N97)R;W(G*3L*("`@("`@("!]"@H@("`@("`@("\J($-R96%T92!T
M96UP(&9I;&5S(&9O<B!I;G!U="]O=71P=70O8V5R=&EF:6-A=&5S+B`J+PH@
M("`@("`@("1I;G!U="`]("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E
M+7-M:6UE)RD["B`@("`@("`@)&]U='!U="`]("1T:&ES+3Y?8W)E871E5&5M
M<$9I;&4H)VAO<F1E+7-M:6UE)RD["B`@("`@("`@)&-E<G1S(#T@)'1H:7,M
M/E]C<F5A=&5496UP1FEL92@G:&]R9&4M<VUI;64G*3L*"B`@("`@("`@+RH@
M4W1O<F4@;65S<V%G92!I;B!T96UP;W)A<GD@9FEL92X@*B\*("`@("`@("`D
M9G`@/2!F;W!E;B@D:6YP=70L("=W*R<I.PH@("`@("`@(&9P=71S*"1F<"P@
M)'1E>'0I.PH@("`@("`@(&9C;&]S92@D9G`I.PH*("`@("`@("`O*B!3=&]R
M92!A9&1I=&EO;F%L(&-E<G1S(&EN('1E;7!O<F%R>2!F:6QE+B`J+PH@("`@
M("`@(&EF("@A96UP='DH)'!A<F%M<ULG8V5R=',G72DI('L*("`@("`@("`@
M("`@)&9P(#T@9F]P96XH)&-E<G1S+"`G=RLG*3L*("`@("`@("`@("`@9G!U
M=',H)&9P+"`D<&%R86US6R=C97)T<R==*3L*("`@("`@("`@("`@9F-L;W-E
M*"1F<"D["B`@("`@("`@?0H*("`@("`@("`O*B!$971E<FUI;F4@=&AE('-I
M9VYA='5R92!T>7!E('1O('5S92X@*B\*("`@("`@("!I9B`H:7-S970H)'!A
M<F%M<ULG<VEG='EP92==*2`F)B`H)'!A<F%M<ULG<VEG='EP92==(#T]("=C
M;&5A<G1E>'0G*2D@>PH@("`@("`@("`@("`D9FQA9W,@/2!02T-3-U]415A4
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F;&%G<R`](%!+0U,W
M7T1%5$%#2$5$.PH@("`@("`@('T*"B`@("`@("`@)'!R:79K97D@/2`H:7-?
M;G5L;"@D<&%R86US6R=P87-S<&AR87-E)UTI*2`_("1P87)A;7-;)W!R:79K
M97DG72`Z(&%R<F%Y*"1P87)A;7-;)W!R:79K97DG72P@)'!A<F%M<ULG<&%S
M<W!H<F%S92==*3L*"B`@("`@("`@:68@*&5M<'1Y*"1P87)A;7-;)V-E<G1S
M)UTI*2!["B`@("`@("`@("`@("1R97,@/2!O<&5N<W-L7W!K8W,W7W-I9VXH
M)&EN<'5T+"`D;W5T<'5T+"`D<&%R86US6R=P=6)K97DG72P@)'!R:79K97DL
M(&%R<F%Y*"DL("1F;&%G<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)')E<R`](&]P96YS<VQ?<&MC<S=?<VEG;B@D:6YP=70L("1O=71P=70L
M("1P87)A;7-;)W!U8FME>2==+"`D<')I=FME>2P@87)R87DH*2P@)&9L86=S
M+"`D8V5R=',I.PH@("`@("`@('T*"B`@("`@("`@:68@*"$D<F5S*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O=6QD(&YO
M="!3+TU)344@<VEG;B!M97-S86=E+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@
M("`@("!]"@H@("`@("`@("1D871A(#T@9FEL95]G971?8V]N=&5N=',H)&]U
M='!U="D["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9FEX0V]N=&5N=%1Y<&4H
M)&1A=&$L("=S:6=N871U<F4G*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E
M8W)Y<'0@86X@4R]-24U%(&5N8W)Y<'1E9"!M97-S86=E('5S:6YG(&$@<')I
M=F%T92]P=6)L:6,@:V5Y<&%I<@H@("`@("H@86YD(&$@<&%S<VAP<F%S92X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1T97AT("`@5&AE('1E>'0@=&\@8F4@9&5C<GEP=&5D
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%1H92!P87)A;65T97)S
M(&YE961E9"!F;W(@9&5C<GEP=&EO;BX*("`@("`J(#QP<F4^"B`@("`@*B!0
M87)A;65T97)S.@H@("`@("H@/3T]/3T]/3T]/3T*("`@("`J("=T>7!E)R`@
M("`@("`@/3X@("=M97-S86=E)R`H4D5154E2140I"B`@("`@*B`G<'5B:V5Y
M)R`@("`@(#T^("!P=6)L:6,@:V5Y+B`H4D5154E2140I"B`@("`@*B`G<')I
M=FME>2<@("`@(#T^("!P<FEV871E(&ME>2X@*%)%455)4D5$*0H@("`@("H@
M)W!A<W-P:')A<V4G("`]/B`@4&%S<W!H<F%S92!F;W(@2V5Y+B`H4D5154E2
M140I"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&1E8W)Y<'1E9"!M97-S86=E+@H@("`@("H@("`@("`@("`@("`@
M("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O8FIE8W0@;VX@97)R;W(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]D96-R>7!T365S<V%G92@D=&5X="P@)'!A<F%M
M<RD*("`@('L*("`@("`@("`O*B!#:&5C:R!F;W(@<V5C=7)E(&-O;FYE8W1I
M;VXN("HO"B`@("`@("`@)'-E8W5R95]C:&5C:R`]("1T:&ES+3YR97%U:7)E
M4V5C=7)E0V]N;F5C=&EO;B@I.PH@("`@("`@(&EF("AI<U]A*"1S96-U<F5?
M8VAE8VLL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1S
M96-U<F5?8VAE8VL["B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C:R!F;W(@
M<F5Q=6ER960@<&%R86UE=&5R<RX@*B\*("`@("`@("!I9B`H(6ES<V5T*"1P
M87)A;7-;)W!U8FME>2==*2!\?`H@("`@("`@("`@("`A:7-S970H)'!A<F%M
M<ULG<')I=FME>2==*2!\?`H@("`@("`@("`@("`A87)R87E?:V5Y7V5X:7-T
M<R@G<&%S<W!H<F%S92<L("1P87)A;7,I*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(D$@<'5B;&EC(%,O34E-12!K97DL('!R
M:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O(&1E8W)Y<'0@82!M97-S86=E+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@
M("`@("!]"@H@("`@("`@("\J($-R96%T92!T96UP(&9I;&5S(&9O<B!I;G!U
M="]O=71P=70N("HO"B`@("`@("`@)&EN<'5T(#T@)'1H:7,M/E]C<F5A=&54
M96UP1FEL92@G:&]R9&4M<VUI;64G*3L*("`@("`@("`D;W5T<'5T(#T@)'1H
M:7,M/E]C<F5A=&5496UP1FEL92@G:&]R9&4M<VUI;64G*3L*"B`@("`@("`@
M+RH@4W1O<F4@;65S<V%G92!I;B!F:6QE+B`J+PH@("`@("`@("1F<"`](&9O
M<&5N*"1I;G!U="P@)W<K)RD["B`@("`@("`@9G!U=',H)&9P+"!T<FEM*"1T
M97AT*2D["B`@("`@("`@9F-L;W-E*"1F<"D["@H@("`@("`@("1P<FEV:V5Y
M(#T@*&ES7VYU;&PH)'!A<F%M<ULG<&%S<W!H<F%S92==*2D@/R`D<&%R86US
M6R=P<FEV:V5Y)UT@.B!A<G)A>2@D<&%R86US6R=P<FEV:V5Y)UTL("1P87)A
M;7-;)W!A<W-P:')A<V4G72D["B`@("`@("`@:68@*&]P96YS<VQ?<&MC<S=?
M9&5C<GEP="@D:6YP=70L("1O=71P=70L("1P87)A;7-;)W!U8FME>2==+"`D
M<')I=FME>2DI('L*("`@("`@("`@("`@<F5T=7)N(&9I;&5?9V5T7V-O;G1E
M;G1S*"1O=71P=70I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N
M(BDL("=H;W)D92YE<G)O<B<I.PH@("`@?0H*("`@("\J*@H@("`@("H@4VEG
M;B!A;F0@16YC<GEP="!A($U)345?4&%R="!U<VEN9R!3+TU)344N"B`@("`@
M*@H@("`@("H@0'!A<F%M($U)345?4&%R="`D;6EM95]P87)T("`@5&AE($U)
M345?4&%R="!O8FIE8W0@=&\@<VEG;B!A;F0@96YC<GEP="X*("`@("`J($!P
M87)A;2!A<G)A>2`D<VEG;E]P87)A;7,@("`@(%1H92!P87)A;65T97)S(')E
M<75I<F5D(&9O<B!S:6=N:6YG+B!3964*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%]E;F-R>7!T4VEG;F%T=7)E*"DN"B`@("`@*B!`
M<&%R86T@87)R87D@)&5N8W)Y<'1?<&%R86US("!4:&4@<&%R86UE=&5R<R!R
M97%U:7)E9"!F;W(@96YC<GEP=&EO;BX*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%-E92!?96YC<GEP=$UE<W-A9V4H*2X*("`@("`J
M"B`@("`@*B!`<F5T=7)N($U)345?4&%R="`@02!-24U%7U!A<G0@;V)J96-T
M('1H870@:7,@<VEG;F5D(&%N9"!E;F-R>7!T960N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S:6=N06YD16YC<GEP=$U)345087)T*"1M:6UE
M7W!A<G0L("1S:6=N7W!A<F%M<R`](&%R<F%Y*"DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1E;F-R>7!T7W!A<F%M<R`](&%R<F%Y
M*"DI"B`@("!["B`@("`@("`@:6YC;'5D95]O;F-E("=(;W)D92]-24U%+U!A
M<G0N<&AP)SL*"B`@("`@("`@)'!A<G0@/2`D=&AI<RT^<VEG;DU)345087)T
M*"1M:6UE7W!A<G0L("1S:6=N7W!A<F%M<RD["B`@("`@("`@:68@*&ES7V$H
M)'!A<G0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1P
M87)T.PH@("`@("`@('T*("`@("`@("`D<&%R="`]("1T:&ES+3YE;F-R>7!T
M34E-15!A<G0H)'!A<G0L("1E;F-R>7!T7W!A<F%M<RD["B`@("`@("`@:68@
M*&ES7V$H)'!A<G0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1P87)T.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P87)T.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R="!A(%!%32!F;W)M870@8V5R
M=&EF:6-A=&4@=&\@<F5A9&%B;&4@2%1-3"!V97)S:6]N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8V5R="`@(%!%32!F;W)M870@8V5R=&EF:6-A
M=&4*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@2%1-3"!D971A:6QI
M;F<@=&AE(&-E<G1I9FEC871E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C97)T
M5&](5$U,*"1C97)T*0H@("`@>PH@("`@("`@("\J($-O;6UO;B!&:65L9',@
M*B\*("`@("`@("`D9FEE;&1N86UE<R`](&%R<F%Y*`H@("`@("`@("`@("`G
M16UA:6PG(#T^(%\H(D5M86EL($%D9')E<W,B*2P*("`@("`@("`@("`@)T-O
M;6UO;DYA;64G(#T^(%\H(D-O;6UO;B!.86UE(BDL"B`@("`@("`@("`@("=/
M<F=A;FES871I;VXG(#T^(%\H(D]R9V%N:7-A=&EO;B(I+`H@("`@("`@("`@
M("`G3W)G86YI<V%T:6]N86Q5;FET)R`]/B!?*")/<F=A;FES871I;VYA;"!5
M;FET(BDL"B`@("`@("`@("`@("=#;W5N=')Y)R`]/B!?*")#;W5N=')Y(BDL
M"B`@("`@("`@("`@("=3=&%T94]R4')O=FEN8V4G(#T^(%\H(E-T871E(&]R
M(%!R;W9I;F-E(BDL"B`@("`@("`@("`@("=,;V-A=&EO;B<@/3X@7R@B3&]C
M871I;VXB*2P*("`@("`@("`@("`@)U-T<F5E=$%D9')E<W,G(#T^(%\H(E-T
M<F5E="!!9&1R97-S(BDL"B`@("`@("`@("`@("=496QE<&AO;F5.=6UB97(G
M(#T^(%\H(E1E;&5P:&]N92!.=6UB97(B*2P*("`@("`@("`@("`@)U-U<FYA
M;64G(#T^(%\H(E-U<FYA;64B*2P*("`@("`@("`@("`@)T=I=F5N3F%M92<@
M/3X@7R@B1VEV96X@3F%M92(I"B`@("`@("`@*3L*"B`@("`@("`@+RH@3F5T
M<V-A<&4@17AT96YS:6]N<R`J+PH@("`@("`@("1F:65L9&YA;65S("L](&%R
M<F%Y*`H@("`@("`@("`@("`G;F5T<V-A<&4M8V5R="UT>7!E)R`]/B!?*").
M971S8V%P92!C97)T:69I8V%T92!T>7!E(BDL"B`@("`@("`@("`@("=N971S
M8V%P92UB87-E+75R;"<@/3X@7R@B3F5T<V-A<&4@0F%S92!54DPB*2P*("`@
M("`@("`@("`@)VYE='-C87!E+7)E=F]C871I;VXM=7)L)R`]/B!?*").971S
M8V%P92!2979O8V%T:6]N(%523"(I+`H@("`@("`@("`@("`G;F5T<V-A<&4M
M8V$M<F5V;V-A=&EO;BUU<FPG(#T^(%\H(DYE='-C87!E($-!(%)E=F]C871I
M;VX@55),(BDL"B`@("`@("`@("`@("=N971S8V%P92UC97)T+7)E;F5W86PM
M=7)L)R`]/B!?*").971S8V%P92!296YE=V%L(%523"(I+`H@("`@("`@("`@
M("`G;F5T<V-A<&4M8V$M<&]L:6-Y+75R;"<@/3X@7R@B3F5T<V-A<&4@0T$@
M<&]L:6-Y(%523"(I+`H@("`@("`@("`@("`G;F5T<V-A<&4M<W-L+7-E<G9E
M<BUN86UE)R`]/B!?*").971S8V%P92!34TP@<V5R=F5R(&YA;64B*2P*("`@
M("`@("`@("`@)VYE='-C87!E+6-O;6UE;G0G(#T^(%\H(DYE='-C87!E(&-E
M<G1I9FEC871E(&-O;6UE;G0B*0H@("`@("`@("D["@H@("`@("`@("\J(%@U
M.3!V,R!%>'1E;G-I;VYS("HO"B`@("`@("`@)&9I96QD;F%M97,@*ST@87)R
M87DH"B`@("`@("`@("`@("=I9"UC92UE>'1+97E5<V%G92<@/3X@7R@B6#4P
M.78S($5X=&5N9&5D($ME>2!5<V%G92(I+`H@("`@("`@("`@("`G:60M8V4M
M8F%S:6-#;VYS=')A:6YT<R<@/3X@7R@B6#4P.78S($)A<VEC($-O;G-T<F%I
M;G1S(BDL"B`@("`@("`@("`@("=I9"UC92US=6)J96-T06QT3F%M92<@/3X@
M7R@B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(I+`H@("`@("`@
M("`@("`G:60M8V4M<W5B:F5C=$ME>4ED96YT:69I97(G(#T^(%\H(E@U,#EV
M,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(BDL"B`@("`@("`@("`@("=I9"UC
M92UC97)T:69I8V%T95!O;&EC:65S)R`]/B!?*")#97)T:69I8V%T92!0;VQI
M8VEE<R(I+`H@("`@("`@("`@("`G:60M8V4M0U),1&ES=')I8G5T:6]N4&]I
M;G1S)R`]/B!?*")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(I+`H@("`@("`@
M("`@("`G:60M8V4M:V5Y57-A9V4G(#T^(%\H(DME>2!5<V%G92(I"B`@("`@
M("`@*3L*"B`@("`@("`@)&-E<G1?9&5T86EL<R`]("1T:&ES+3YP87)S94-E
M<G0H)&-E<G0I.PH@("`@("`@(&EF("@A:7-?87)R87DH)&-E<G1?9&5T86EL
M<RDI('L*("`@("`@("`@("`@<F5T=7)N("<\<')E(&-L87-S/2)F:7AE9"(^
M)R`N(%\H(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B
M*2`N("<\+W!R93XG.PH@("`@("`@('T*("`@("`@("`D8V5R=&EF:6-A=&4@
M/2`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==.PH*("`@("`@("`D=&5X
M="`]("<\<')E(&-L87-S/2)F:7AE9"(^)SL*"B`@("`@("`@+RH@4W5B:F5C
M="`H82]K+V$@0V5R=&EF:6-A=&4@3W=N97(I("HO"B`@("`@("`@:68@*&ES
M<V5T*"1C97)T:69I8V%T95LG<W5B:F5C="==*2D@>PH@("`@("`@("`@("`D
M=&5X="`N/2`B/'-T<F]N9SXB("X@7R@B0V5R=&EF:6-A=&4@3W=N97(B*2`N
M("(Z/"]S=')O;F<^7&XB.PH*("`@("`@("`@("`@9F]R96%C:"`H)&-E<G1I
M9FEC871E6R=S=6)J96-T)UT@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D9FEE;&1N86UE<ULD:V5Y72DI('L*("`@
M("`@("`@("`@("`@("`@("`D=&5X="`N/2!S<')I;G1F*"(F;F)S<#LF;F)S
M<#LE<SH@)7-<;B(L("1F:65L9&YA;65S6R1K97E=+"`D=F%L=64I.PH@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&5X
M="`N/2!S<')I;G1F*"(F;F)S<#LF;F)S<#LJ)7,Z("5S7&XB+"`D:V5Y+"`D
M=F%L=64I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1T97AT("X](")<;B(["B`@("`@("`@?0H*("`@("`@("`O*B!)
M<W-U97(@*B\*("`@("`@("!I9B`H:7-S970H)&-E<G1I9FEC871E6R=I<W-U
M97(G72DI('L*("`@("`@("`@("`@)'1E>'0@+CT@(CQS=')O;F<^(B`N(%\H
M(DES<W5E<B(I("X@(CH\+W-T<F]N9SY<;B(["@H@("`@("`@("`@("!F;W)E
M86-H("@D8V5R=&EF:6-A=&5;)VES<W5E<B==(&%S("1K97D@/3X@)'9A;'5E
M*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&9I96QD;F%M97-;)&ME
M>5TI*2!["B`@("`@("`@("`@("`@("`@("`@)'1E>'0@+CT@<W!R:6YT9B@B
M)FYB<W`[)FYB<W`[)7,Z("5S7&XB+"`D9FEE;&1N86UE<ULD:V5Y72P@)'9A
M;'5E*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@)'1E>'0@+CT@<W!R:6YT9B@B)FYB<W`[)FYB<W`[*B5S.B`E<UQN
M(BP@)&ME>2P@)'9A;'5E*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D=&5X="`N/2`B7&XB.PH@("`@("`@('T*"B`@
M("`@("`@+RH@1&%T97,@("HO"B`@("`@("`@)'1E>'0@+CT@(CQS=')O;F<^
M(B`N(%\H(E9A;&ED:71Y(BD@+B`B.CPO<W1R;VYG/EQN(CL*("`@("`@("`D
M=&5X="`N/2!S<')I;G1F*"(F;F)S<#LF;F)S<#LE<SH@)7-<;B(L(%\H(DYO
M="!"969O<F4B*2P@<W1R9G1I;64H(B5X("58(BP@)&-E<G1I9FEC871E6R=V
M86QI9&ET>2==6R=N;W1B969O<F4G72DI.PH@("`@("`@("1T97AT("X]('-P
M<FEN=&8H(B9N8G-P.R9N8G-P.R5S.B`E<UQN(BP@7R@B3F]T($%F=&5R(BDL
M('-T<F9T:6UE*"(E>"`E6"(L("1C97)T:69I8V%T95LG=F%L:61I='DG75LG
M;F]T869T97(G72DI.PH@("`@("`@("1T97AT("X](")<;B(["@H@("`@("`@
M("\J($-E<G1I9FEC871E($]W;F5R("T@4'5B;&EC($ME>2!);F9O("HO"B`@
M("`@("`@)'1E>'0@+CT@(CQS=')O;F<^(B`N(%\H(E!U8FQI8R!+97D@26YF
M;R(I("X@(CH\+W-T<F]N9SY<;B(["B`@("`@("`@)'1E>'0@+CT@<W!R:6YT
M9B@B)FYB<W`[)FYB<W`[)7,Z("5S7&XB+"!?*")0=6)L:6,@2V5Y($%L9V]R
M:71H;2(I+"`D8V5R=&EF:6-A=&5;)W-U8FIE8W10=6)L:6-+97E);F9O)UU;
M)V%L9V]R:71H;2==*3L*("`@("`@("!I9B`H)&-E<G1I9FEC871E6R=S=6)J
M96-T4'5B;&EC2V5Y26YF;R==6R=A;&=O<FET:&TG72`]/2`G<G-A16YC<GEP
M=&EO;B<I('L*("`@("`@("`@("`@:68@*%5T:6PZ.F5X=&5N<VEO;D5X:7-T
M<R@G8F-M871H)RDI('L*("`@("`@("`@("`@("`@("1M;V1U;'5S(#T@)&-E
M<G1I9FEC871E6R=S=6)J96-T4'5B;&EC2V5Y26YF;R==6R=S=6)J96-T4'5B
M;&EC2V5Y)UU;)VUO9'5L=7,G73L*("`@("`@("`@("`@("`@("1M;V1U;'5S
M7VAE>"`]("<G.PH@("`@("`@("`@("`@("`@=VAI;&4@*"1M;V1U;'5S("$]
M("<P)RD@>PH@("`@("`@("`@("`@("`@("`@("1M;V1U;'5S7VAE>"`](&1E
M8VAE>"AB8VUO9"@D;6]D=6QU<RP@)S$V)RDI("X@)&UO9'5L=7-?:&5X.PH@
M("`@("`@("`@("`@("`@("`@("1M;V1U;'5S(#T@8F-D:78H)&UO9'5L=7,L
M("<Q-B<L(#`I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@
M(&EF("@H<W1R;&5N*"1M;V1U;'5S7VAE>"D@/B`V-"D@)B8*("`@("`@("`@
M("`@("`@("`@("`H<W1R;&5N*"1M;V1U;'5S7VAE>"D@/"`Q,C@I*2!["B`@
M("`@("`@("`@("`@("`@("`@<W1R7W!A9"@D;6]D=6QU<U]H97@L(#$R."P@
M)S`G+"!35%)?4$%$7U))1TA4*3L*("`@("`@("`@("`@("`@('T@96QS96EF
M("@H<W1R;&5N*"1M;V1U;'5S7VAE>"D@/B`Q,C@I("8F"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@*'-T<FQE;B@D;6]D=6QU<U]H97@I(#P@,C4V*2D@
M>PH@("`@("`@("`@("`@("`@("`@('-T<E]P860H)&UO9'5L=7-?:&5X+"`R
M-38L("<P)RP@4U127U!!1%]224=(5"D["B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@)'1E>'0@+CT@(B9N8G-P.R9N8G-P.R(@+B!S<')I
M;G1F*%\H(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(BDL('-T<FQE;B@D;6]D
M=6QU<U]H97@I("H@-"D@+B`B.EQN(CL*"B`@("`@("`@("`@("`@("`D;6]D
M=6QU<U]S='(@/2`G)SL*("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\('-T<FQE;B@D;6]D=6QU<U]H97@I.R`D:2`K/2`R*2!["B`@("`@("`@
M("`@("`@("`@("`@:68@*"@D:2`E(#,R*2`]/2`P*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1M;V1U;'5S7W-T<B`N/2`B7&XF;F)S<#LF;F)S<#LF
M;F)S<#LF;F)S<#LF;F)S<#LF;F)S<#LB.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`D;6]D=6QU<U]S='(@+CT@<W5B<W1R
M*"1M;V1U;'5S7VAE>"P@)&DL(#(I("X@)SHG.PH@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@("1T97AT("X]('-P<FEN=&8H(B9N8G-P.R9N
M8G-P.R9N8G-P.R9N8G-P.R5S.B`E<UQN(BP@7R@B36]D=6QU<R(I+"`D;6]D
M=6QU<U]S='(I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&5X="`N
M/2!S<')I;G1F*"(F;F)S<#LF;F)S<#LF;F)S<#LF;F)S<#LE<SH@)7-<;B(L
M(%\H(D5X<&]N96YT(BDL("1C97)T:69I8V%T95LG<W5B:F5C=%!U8FQI8TME
M>4EN9F\G75LG<W5B:F5C=%!U8FQI8TME>2==6R=P=6)L:6-%>'!O;F5N="==
M*3L*("`@("`@("!]"B`@("`@("`@)'1E>'0@+CT@(EQN(CL*"B`@("`@("`@
M+RH@6#4P.78S(&5X=&5N<VEO;G,@*B\*("`@("`@("!I9B`H:7-S970H)&-E
M<G1I9FEC871E6R=E>'1E;G-I;VYS)UTI*2!["B`@("`@("`@("`@("1T97AT
M("X]("(\<W1R;VYG/B(@+B!?*")8-3`Y=C,@97AT96YS:6]N<R(I("X@(CH\
M+W-T<F]N9SY<;B(["@H@("`@("`@("`@("!F;W)E86-H("@D8V5R=&EF:6-A
M=&5;)V5X=&5N<VEO;G,G72!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@
M("`@("`@("`@:68@*&ES7V%R<F%Y*"1V86QU92DI('L*("`@("`@("`@("`@
M("`@("`@("`D=F%L=64@/2!?*")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M9FEE;&1N86UE<ULD:V5Y72DI('L*("`@("`@("`@("`@("`@("`@("`D=&5X
M="`N/2!S<')I;G1F*"(F;F)S<#LF;F)S<#LE<SI<;B9N8G-P.R9N8G-P.R9N
M8G-P.R9N8G-P.R5S7&XB+"`D9FEE;&1N86UE<ULD:V5Y72P@=V]R9'=R87`H
M)'9A;'5E+"`T,"P@(EQN)FYB<W`[)FYB<W`[)FYB<W`[)FYB<W`[(BDI.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D
M=&5X="`N/2!S<')I;G1F*"(F;F)S<#LF;F)S<#LE<SI<;B9N8G-P.R9N8G-P
M.R9N8G-P.R9N8G-P.R5S7&XB+"`D:V5Y+"!W;W)D=W)A<"@D=F%L=64L(#8P
M+"`B7&XF;F)S<#LF;F)S<#LF;F)S<#LF;F)S<#LB*2D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T97AT("X](")<
M;B(["B`@("`@("`@?0H*("`@("`@("`O*B!#97)T:69I8V%T92!$971A:6QS
M("HO"B`@("`@("`@)'1E>'0@+CT@(CQS=')O;F<^(B`N(%\H(D-E<G1I9FEC
M871E($1E=&%I;',B*2`N("(Z/"]S=')O;F<^7&XB.PH@("`@("`@("1T97AT
M("X]('-P<FEN=&8H(B9N8G-P.R9N8G-P.R5S.B`E9%QN(BP@7R@B5F5R<VEO
M;B(I+"`D8V5R=&EF:6-A=&5;)W9E<G-I;VXG72D["B`@("`@("`@)'1E>'0@
M+CT@<W!R:6YT9B@B)FYB<W`[)FYB<W`[)7,Z("5D7&XB+"!?*")397)I86P@
M3G5M8F5R(BDL("1C97)T:69I8V%T95LG<V5R:6%L3G5M8F5R)UTI.PH*("`@
M("`@("!F;W)E86-H("@D8V5R=%]D971A:6QS6R=F:6YG97)P<FEN=',G72!A
M<R`D:&%S:"`]/B`D9FEN9V5R<')I;G0I('L*("`@("`@("`@("`@)&QA8F5L
M(#T@<W!R:6YT9BA?*"(E<R!&:6YG97)P<FEN="(I+"!3=')I;F<Z.G5P<&5R
M*"1H87-H*2D["B`@("`@("`@("`@("1F:6YG97)P<FEN=%]S='(@/2`G)SL*
M("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<W1R;&5N*"1F:6YG97)P
M<FEN="D[("1I("L](#(I('L*("`@("`@("`@("`@("`@("1F:6YG97)P<FEN
M=%]S='(@+CT@<W5B<W1R*"1F:6YG97)P<FEN="P@)&DL(#(I("X@)SHG.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1T97AT("X]('-P<FEN=&8H(B9N
M8G-P.R9N8G-P.R5S.EQN)FYB<W`[)FYB<W`[)FYB<W`[)FYB<W`[)FYB<W`[
M)FYB<W`[)7-<;B(L("1L86)E;"P@)&9I;F=E<G!R:6YT7W-T<BD["B`@("`@
M("`@?0H@("`@("`@("1T97AT("X]('-P<FEN=&8H(B9N8G-P.R9N8G-P.R5S
M.B`E<UQN(BP@7R@B4VEG;F%T=7)E($%L9V]R:71H;2(I+"`D8V5R=%]D971A
M:6QS6R=S:6=N871U<F5!;&=O<FET:&TG72D["B`@("`@("`@)'1E>'0@+CT@
M<W!R:6YT9B@B)FYB<W`[)FYB<W`[)7,Z(BP@7R@B4VEG;F%T=7)E(BDI.PH*
M("`@("`@("`D<VEG7W-T<B`]("<G.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\('-T<FQE;B@D8V5R=%]D971A:6QS6R=S:6=N871U<F4G72D[("1I*RLI
M('L*("`@("`@("`@("`@:68@*"@D:2`E(#$V*2`]/2`P*2!["B`@("`@("`@
M("`@("`@("`D<VEG7W-T<B`N/2`B7&XF;F)S<#LF;F)S<#LF;F)S<#LF;F)S
M<#LF;F)S<#LF;F)S<#LB.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1S
M:6=?<W1R("X]('-P<FEN=&8H(B4P,G@Z(BP@;W)D*"1C97)T7V1E=&%I;'-;
M)W-I9VYA='5R92==6R1I72DI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1T97AT("X@)'-I9U]S='(@+B`B7&X\+W!R93XB.PH@("`@?0H*("`@("\J
M*@H@("`@("H@17AT<F%C="!T:&4@8V]N=&5N=',@;V8@82!014T@9F]R;6%T
M(&-E<G1I9FEC871E('1O(&%N(&%R<F%Y+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&-E<G0@(%!%32!F;W)M870@8V5R=&EF:6-A=&4*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!C;VYT86EN:6YG(&%L;"!E
M>'1R86-T86)L92!I;F9O<FUA=&EO;B!A8F]U=`H@("`@("H@("`@("`@("`@
M("`@("`@=&AE(&-E<G1I9FEC871E+@H@("`@("HO"B`@("!F=6YC=&EO;B!P
M87)S94-E<G0H)&-E<G0I"B`@("!["B`@("`@("`@)&-E<G1?<W!L:70@/2!P
M<F5G7W-P;&ET*"<O*"TM+2TM*"A"14=)3BE\*$5.1"DI($-%4E1)1DE#051%
M+2TM+2TI+R<L("1C97)T*3L*("`@("`@("!I9B`H(6ES<V5T*"1C97)T7W-P
M;&ET6S%=*2D@>PH@("`@("`@("`@("`D<F%W7V-E<G0@/2!B87-E-C1?9&5C
M;V1E*"1C97)T*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F%W
M7V-E<G0@/2!B87-E-C1?9&5C;V1E*"1C97)T7W-P;&ET6S%=*3L*("`@("`@
M("!]"@H@("`@("`@("1C97)T7V1A=&$@/2`D=&AI<RT^7W!A<G-E05-.*"1R
M87=?8V5R="D["B`@("`@("`@:68@*"%I<U]A<G)A>2@D8V5R=%]D871A*2!\
M?"`H)&-E<G1?9&%T85LP72`]/2`G54Y+3D]73B<I*2!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1C97)T7V1E=&%I
M;',@/2!A<G)A>2@I.PH@("`@("`@("1C97)T7V1E=&%I;'-;)V9I;F=E<G!R
M:6YT<R==6R=M9#4G72`](&UD-2@D<F%W7V-E<G0I.PH@("`@("`@(&EF("A5
M=&EL.CIE>'1E;G-I;VY%>&ES=',H)VUH87-H)RDI('L*("`@("`@("`@("`@
M)&-E<G1?9&5T86EL<ULG9FEN9V5R<')I;G1S)UU;)W-H83$G72`](&)I;C)H
M97@H;6AA<V@H34A!4TA?4TA!,2P@)')A=U]C97)T*2D["B`@("`@("`@?0H*
M("`@("`@("`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=E>'1E;G-I
M;VYS)UT@/2!A<G)A>2@I.PH@("`@("`@("1C97)T7V1E=&%I;'-;)V-E<G1I
M9FEC871E)UU;)W9E<G-I;VXG72`]("1C97)T7V1A=&%;,5U;,%U;,5U;,%U;
M,5T@*R`Q.PH@("`@("`@("1C97)T7V1E=&%I;'-;)V-E<G1I9FEC871E)UU;
M)W-E<FEA;$YU;6)E<B==(#T@)&-E<G1?9&%T85LQ75LP75LQ75LQ75LQ73L*
M("`@("`@("`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=S:6=N871U
M<F4G72`]("1C97)T7V1A=&%;,5U;,%U;,5U;,EU;,5U;,%U;,5T["B`@("`@
M("`@)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG:7-S=65R)UT@/2`D
M8V5R=%]D871A6S%=6S!=6S%=6S-=6S%=.PH@("`@("`@("1C97)T7V1E=&%I
M;'-;)V-E<G1I9FEC871E)UU;)W9A;&ED:71Y)UT@/2`D8V5R=%]D871A6S%=
M6S!=6S%=6S1=6S%=.PH@("`@("`@("1C97)T7V1E=&%I;'-;)V-E<G1I9FEC
M871E)UU;)W-U8FIE8W0G72`]($`D8V5R=%]D871A6S%=6S!=6S%=6S5=6S%=
M.PH@("`@("`@("1C97)T7V1E=&%I;'-;)V-E<G1I9FEC871E)UU;)W-U8FIE
M8W10=6)L:6-+97E);F9O)UT@/2`D8V5R=%]D871A6S%=6S!=6S%=6S9=6S%=
M.PH*("`@("`@("`D8V5R=%]D971A:6QS6R=S:6=N871U<F5!;&=O<FET:&TG
M72`]("1C97)T7V1A=&%;,5U;,5U;,5U;,%U;,5T["B`@("`@("`@)&-E<G1?
M9&5T86EL<ULG<VEG;F%T=7)E)UT@/2`D8V5R=%]D871A6S%=6S)=6S%=.PH*
M("`@("`@("`O+R!I<W-U97(*("`@("`@("`D:7-S=65R(#T@87)R87DH*3L*
M("`@("`@("!F;W)E86-H("@D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==
M6R=I<W-U97(G72!A<R`D=F%L=64I('L*("`@("`@("`@("`@)&ES<W5E<ELD
M=F%L=65;,5U;,5U;,%U;,5U=(#T@)'9A;'5E6S%=6S%=6S%=6S%=.PH@("`@
M("`@('T*("`@("`@("`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=I
M<W-U97(G72`]("1I<W-U97(["@H@("`@("`@("\O('-U8FIE8W0*("`@("`@
M("`D<W5B:F5C="`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&-E<G1?
M9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG<W5B:F5C="==(&%S("1V86QU92D@
M>PH@("`@("`@("`@("`D<W5B:F5C=%LD=F%L=65;,5U;,5U;,%U;,5U=(#T@
M)'9A;'5E6S%=6S%=6S%=6S%=.PH@("`@("`@('T*("`@("`@("`D8V5R=%]D
M971A:6QS6R=C97)T:69I8V%T92==6R=S=6)J96-T)UT@/2`D<W5B:F5C=#L*
M"B`@("`@("`@+R\@=F%L:61I='D*("`@("`@("`D=F%L<R`]("1C97)T7V1E
M=&%I;'-;)V-E<G1I9FEC871E)UU;)W9A;&ED:71Y)UT["B`@("`@("`@)&-E
M<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG=F%L:61I='DG72`](&%R<F%Y
M*"D["B`@("`@("`@)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG=F%L
M:61I='DG75LG;F]T8F5F;W)E)UT@/2`D=F%L<ULP75LQ73L*("`@("`@("`D
M8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=V86QI9&ET>2==6R=N;W1A
M9G1E<B==(#T@)'9A;'-;,5U;,5T["B`@("`@("`@9F]R96%C:"`H)&-E<G1?
M9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG=F%L:61I='DG72!A<R`D:V5Y(#T^
M("1V86PI('L*("`@("`@("`@("`@)'EE87(@/2!S=6)S='(H)'9A;"P@,"P@
M,BD["B`@("`@("`@("`@("1M;VYT:"`]('-U8G-T<B@D=F%L+"`R+"`R*3L*
M("`@("`@("`@("`@)&1A>2`]('-U8G-T<B@D=F%L+"`T+"`R*3L*("`@("`@
M("`@("`@)&AO=7(@/2!S=6)S='(H)'9A;"P@-BP@,BD["B`@("`@("`@("`@
M("1M:6YU=&4@/2!S=6)S='(H)'9A;"P@."P@,BD["B`@("`@("`@("`@(&EF
M("@H)'9A;%LQ,5T@/3T@)RTG*2!\?"`H)'9A;%LY72`]/2`G*R<I*2!["B`@
M("`@("`@("`@("`@("`O+R!H86YD;&4@=&EM92!Z;VYE(&]F9G-E="!H97)E
M"B`@("`@("`@("`@("`@("`D<V5C;VYD<R`](#`["B`@("`@("`@("`@('T@
M96QS96EF("A3=')I;F<Z.G5P<&5R*"1V86Q;,3%=*2`]/2`G6B<I('L*("`@
M("`@("`@("`@("`@("1S96-O;F1S(#T@,#L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1S96-O;F1S(#T@<W5B<W1R*"1V86PL(#$P
M+"`R*3L*("`@("`@("`@("`@("`@(&EF("@H)'9A;%LQ,5T@/3T@)RTG*2!\
M?"`H)'9A;%LY72`]/2`G*R<I*2!["B`@("`@("`@("`@("`@("`@("`@+R\@
M:&%N9&QE('1I;64@>F]N92!O9F9S970@:&5R90H@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1C97)T7V1E=&%I;'-;)V-E
M<G1I9FEC871E)UU;)W9A;&ED:71Y)UU;)&ME>5T@/2!M:W1I;64@*"1H;W5R
M+"`D;6EN=71E+"`D<V5C;VYD<RP@)&UO;G1H+"`D9&%Y+"`D>65A<BD["B`@
M("`@("`@?0H*("`@("`@("`O+R!3<&QI="!T:&4@4'5B;&EC($ME>2!I;G1O
M(&-O;7!O;F5N=',N"B`@("`@("`@)'-U8FIE8W10=6)L:6-+97E);F9O(#T@
M87)R87DH*3L*("`@("`@("`D<W5B:F5C=%!U8FQI8TME>4EN9F];)V%L9V]R
M:71H;2==(#T@)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG<W5B:F5C
M=%!U8FQI8TME>4EN9F\G75LP75LQ75LP75LQ73L*("`@("`@("!I9B`H)'-U
M8FIE8W10=6)L:6-+97E);F9O6R=A;&=O<FET:&TG72`]/2`G<G-A16YC<GEP
M=&EO;B<I('L*("`@("`@("`@("`@)'-U8FIE8W10=6)L:6-+97D@/2`D=&AI
M<RT^7W!A<G-E05-.*"1C97)T7V1E=&%I;'-;)V-E<G1I9FEC871E)UU;)W-U
M8FIE8W10=6)L:6-+97E);F9O)UU;,5U;,5TI.PH@("`@("`@("`@("`D<W5B
M:F5C=%!U8FQI8TME>4EN9F];)W-U8FIE8W10=6)L:6-+97DG75LG;6]D=6QU
M<R==(#T@)'-U8FIE8W10=6)L:6-+97E;,5U;,%U;,5T["B`@("`@("`@("`@
M("1S=6)J96-T4'5B;&EC2V5Y26YF;ULG<W5B:F5C=%!U8FQI8TME>2==6R=P
M=6)L:6-%>'!O;F5N="==(#T@)'-U8FIE8W10=6)L:6-+97E;,5U;,5U;,5T[
M"B`@("`@("`@?0H@("`@("`@("1C97)T7V1E=&%I;'-;)V-E<G1I9FEC871E
M)UU;)W-U8FIE8W10=6)L:6-+97E);F9O)UT@/2`D<W5B:F5C=%!U8FQI8TME
M>4EN9F\["@H@("`@("`@(&EF("AI<W-E="@D8V5R=%]D871A6S%=6S!=6S%=
M6S==*2`F)@H@("`@("`@("`@("!I<U]A<G)A>2@D8V5R=%]D871A6S%=6S!=
M6S%=6S==6S%=*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D8V5R=%]D871A
M6S%=6S!=6S%=6S==6S%=(&%S("1E>'0I('L*("`@("`@("`@("`@("`@("1O
M:60@/2`D97AT6S%=6S!=6S%=.PH@("`@("`@("`@("`@("`@)&-E<G1?9&5T
M86EL<ULG8V5R=&EF:6-A=&4G75LG97AT96YS:6]N<R==6R1O:61=(#T@)&5X
M=%LQ75LQ73L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&D@
M/2`Y.PH@("`@("`@('=H:6QE("AI<W-E="@D8V5R=%]D871A6S%=6S!=6S%=
M6R1I72DI('L*("`@("`@("`@("`@)&]I9"`]("1C97)T7V1A=&%;,5U;,%U;
M,5U;)&E=6S%=6S!=6S%=.PH@("`@("`@("`@("`D8V5R=%]D971A:6QS6R=C
M97)T:69I8V%T92==6R=E>'1E;G-I;VYS)UU;)&]I9%T@/2`D8V5R=%]D871A
M6S%=6S!=6S%=6R1I75LQ75LQ73L*("`@("`@("`@("`@)&DK*SL*("`@("`@
M("!]"@H@("`@("`@(&9O<F5A8V@@*"1C97)T7V1E=&%I;'-;)V-E<G1I9FEC
M871E)UU;)V5X=&5N<VEO;G,G72!A<R`D;VED(#T^("1V86PI('L*("`@("`@
M("`@("`@<W=I=&-H("@D;VED*2!["B`@("`@("`@("`@(&-A<V4@)VYE='-C
M87!E+6)A<V4M=7)L)SH*("`@("`@("`@("`@8V%S92`G;F5T<V-A<&4M<F5V
M;V-A=&EO;BUU<FPG.@H@("`@("`@("`@("!C87-E("=N971S8V%P92UC82UR
M979O8V%T:6]N+75R;"<Z"B`@("`@("`@("`@(&-A<V4@)VYE='-C87!E+6-E
M<G0M<F5N97=A;"UU<FPG.@H@("`@("`@("`@("!C87-E("=N971S8V%P92UC
M82UP;VQI8WDM=7)L)SH*("`@("`@("`@("`@8V%S92`G;F5T<V-A<&4M<W-L
M+7-E<G9E<BUN86UE)SH*("`@("`@("`@("`@8V%S92`G;F5T<V-A<&4M8V]M
M;65N="<Z"B`@("`@("`@("`@("`@("`D=F%L(#T@)'1H:7,M/E]P87)S94%3
M3B@D=F%L6S%=*3L*("`@("`@("`@("`@("`@("1C97)T7V1E=&%I;'-;)V-E
M<G1I9FEC871E)UU;)V5X=&5N<VEO;G,G75LD;VED72`]("1V86Q;,5T["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VED+6-E
M+7-U8FIE8W1!;'1.86UE)SH*("`@("`@("`@("`@("`@("1V86P@/2`D=&AI
M<RT^7W!A<G-E05-.*"1V86Q;,5TI.PH@("`@("`@("`@("`@("`@)&-E<G1?
M9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG97AT96YS:6]N<R==6R1O:61=(#T@
M)R<["B`@("`@("`@("`@("`@("!F;W)E86-H("@D=F%L6S%=(&%S("1N86UE
M*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D8V5R=%]D971A
M:6QS6R=C97)T:69I8V%T92==6R=E>'1E;G-I;VYS)UU;)&]I9%TI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1C97)T7V1E=&%I;'-;)V-E<G1I9FEC
M871E)UU;)V5X=&5N<VEO;G,G75LD;VED72`N/2`G+"`G.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D8V5R=%]D971A:6QS
M6R=C97)T:69I8V%T92==6R=E>'1E;G-I;VYS)UU;)&]I9%T@+CT@)&YA;65;
M,5T["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@(&-A<V4@)VYE='-C87!E+6-E<G0M='EP92<Z"B`@("`@
M("`@("`@("`@("`D=F%L(#T@)'1H:7,M/E]P87)S94%33B@D=F%L6S%=*3L*
M("`@("`@("`@("`@("`@("1V86P@/2!O<F0H)'9A;%LQ72D["B`@("`@("`@
M("`@("`@("`D;F5W5F%L(#T@)R<["@H@("`@("`@("`@("`@("`@:68@*"1V
M86P@)B`P>#@P*2!["B`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`N/2!E
M;7!T>2@D;F5W5F%L*2`_("=34TP@8VQI96YT)R`Z("<L(%-33"!C;&EE;G0G
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1V86P@
M)B`P>#0P*2!["B`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`N/2!E;7!T
M>2@D;F5W5F%L*2`_("=34TP@<V5R=F5R)R`Z("<L(%-33"!S97)V97(G.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1V86P@)B`P
M>#(P*2!["B`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`N/2!E;7!T>2@D
M;F5W5F%L*2`_("=3+TU)344G(#H@)RP@4R]-24U%)SL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&EF("@D=F%L("8@,'@Q,"D@>PH@("`@
M("`@("`@("`@("`@("`@("1N97=686P@+CT@96UP='DH)&YE=U9A;"D@/R`G
M3V)J96-T(%-I9VYI;F<G(#H@)RP@3V)J96-T(%-I9VYI;F<G.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1V86P@)B`P>#`T*2![
M"B`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`N/2!E;7!T>2@D;F5W5F%L
M*2`_("=34TP@0T$G(#H@)RP@4U-,($-!)SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&EF("@D=F%L("8@,'@P,BD@>PH@("`@("`@("`@
M("`@("`@("`@("1N97=686P@+CT@96UP='DH)&YE=U9A;"D@/R`G4R]-24U%
M($-!)R`Z("<L(%,O34E-12!#02<["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!I9B`H)'9A;"`F(#!X,#$I('L*("`@("`@("`@("`@("`@
M("`@("`D;F5W5F%L("X](&5M<'1Y*"1N97=686PI(#\@)T]B:F5C="!3:6=N
M:6YG($-!)R`Z("<L($]B:F5C="!3:6=N:6YG($-!)SL*("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("`D8V5R=%]D971A:6QS6R=C97)T:69I
M8V%T92==6R=E>'1E;G-I;VYS)UU;)&]I9%T@/2`D;F5W5F%L.PH@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=I9"UC92UE>'1+
M97E5<V%G92<Z"B`@("`@("`@("`@("`@("`D=F%L(#T@)'1H:7,M/E]P87)S
M94%33B@D=F%L6S%=*3L*("`@("`@("`@("`@("`@("1V86P@/2`D=F%L6S%=
M.PH*("`@("`@("`@("`@("`@("1N97=686P@/2`G)SL*("`@("`@("`@("`@
M("`@(&EF("@D=F%L6S!=6S%=("$]("=S97%U96YC92<I('L*("`@("`@("`@
M("`@("`@("`@("`D=F%L(#T@87)R87DH)'9A;"D["B`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1V86P@/2`D=F%L6S%=
M6S%=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)'9A;"!A<R`D=7-A9V4I('L*("`@("`@("`@("`@("`@("`@("!I9B`H
M)'5S86=E6S%=(#T]("=I9%]K<%]C;&EE;G1!=71H)RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D;F5W5F%L("X](&5M<'1Y*"1N97=686PI(#\@)U1,
M4R!796(@0VQI96YT($%U=&AE;G1I8V%T:6]N)R`Z("<L(%1,4R!796(@0VQI
M96YT($%U=&AE;G1I8V%T:6]N)SL*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;F5W5F%L("X](&5M<'1Y
M*"1N97=686PI(#\@)'5S86=E6S%=(#H@)RP@)R`N("1U<V%G95LQ73L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=E>'1E;G-I
M;VYS)UU;)&]I9%T@/2`D;F5W5F%L.PH@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("!C87-E("=I9"UC92US=6)J96-T2V5Y261E;G1I9FEE
M<B<Z"B`@("`@("`@("`@("`@("`D=F%L(#T@)'1H:7,M/E]P87)S94%33B@D
M=F%L6S%=*3L*("`@("`@("`@("`@("`@("1V86P@/2`D=F%L6S%=.PH*("`@
M("`@("`@("`@("`@("1N97=686P@/2`G)SL*"B`@("`@("`@("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"!S=')L96XH)'9A;"D[("1I*RLI('L*("`@("`@
M("`@("`@("`@("`@("`D;F5W5F%L("X]('-P<FEN=&8H(B4P,G@Z(BP@;W)D
M*"1V86Q;)&E=*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=E>'1E;G-I;VYS)UU;
M)&]I9%T@/2`D;F5W5F%L.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!C87-E("=I9"UC92UA=71H;W)I='E+97E)9&5N=&EF:65R)SH*
M("`@("`@("`@("`@("`@("1V86P@/2`D=&AI<RT^7W!A<G-E05-.*"1V86Q;
M,5TI.PH@("`@("`@("`@("`@("`@:68@*"1V86Q;,%T@/3T@)W-T<FEN9R<I
M('L*("`@("`@("`@("`@("`@("`@("`D=F%L(#T@)'9A;%LQ73L*"B`@("`@
M("`@("`@("`@("`@("`@)&YE=U9A;"`]("<G.PH@("`@("`@("`@("`@("`@
M("`@(&9O<B`H)&D@/2`P.R`D:2`\('-T<FQE;B@D=F%L*3L@)&DK*RD@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D;F5W5F%L("X]('-P<FEN=&8H(B4P
M,G@Z(BP@;W)D*"1V86Q;)&E=*2D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("1C97)T7V1E=&%I;'-;)V-E<G1I9FEC871E
M)UU;)V5X=&5N<VEO;G,G75LD;VED72`]("1N97=686P["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1C97)T7V1E=&%I
M;'-;)V-E<G1I9FEC871E)UU;)V5X=&5N<VEO;G,G75LD;VED72`](%\H(E5N
M<W5P<&]R=&5D($5X=&5N<VEO;B(I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=I9"UC92UB
M87-I8T-O;G-T<F%I;G1S)SH*("`@("`@("`@("`@8V%S92`G9&5F875L="<Z
M"B`@("`@("`@("`@("`@("`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==
M6R=E>'1E;G-I;VYS)UU;)&]I9%T@/2!?*")5;G-U<'!O<G1E9"!%>'1E;G-I
M;VXB*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&-E<G1?9&5T86EL<SL*("`@('T*
M"B`@("`O*BH*("`@("`J($%T=&5M<'0@=&\@<&%R<V4@05-.+C$@9F]R;6%T
M960@9&%T82X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("!!4TXN,2!F;W)M871E9"!D
M871A"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@07)R87D@8V]N=&%I
M;F5D('1H92!E>'1R86-T960@=F%L=65S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?<&%R<V5!4TXH)&1A=&$I"B`@("!["B`@("`@("`@)')E<W5L="`](&%R
M<F%Y*"D["@H@("`@("`@('=H:6QE("AS=')L96XH)&1A=&$I(#X@,2D@>PH@
M("`@("`@("`@("`D8VQA<W,@/2!O<F0H)&1A=&%;,%TI.PH@("`@("`@("`@
M("!S=VET8V@@*"1C;&%S<RD@>PH@("`@("`@("`@("!C87-E(#!X,S`Z"B`@
M("`@("`@("`@("`@("`O+R!397%U96YC90H@("`@("`@("`@("`@("`@)&QE
M;B`](&]R9"@D9&%T85LQ72D["B`@("`@("`@("`@("`@("`D8GET97,@/2`P
M.PH@("`@("`@("`@("`@("`@:68@*"1L96X@)B`P>#@P*2!["B`@("`@("`@
M("`@("`@("`@("`@)&)Y=&5S(#T@)&QE;B`F(#!X,&8["B`@("`@("`@("`@
M("`@("`@("`@)&QE;B`](#`["B`@("`@("`@("`@("`@("`@("`@9F]R("@D
M:2`](#`[("1I(#P@)&)Y=&5S.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1L96X@/2`H)&QE;B`\/"`X*2!\(&]R9"@D9&%T85LD:2`K(#)=
M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D<V5Q=65N8V5?9&%T82`]('-U8G-T<B@D9&%T82P@
M,B`K("1B>71E<RP@)&QE;BD["B`@("`@("`@("`@("`@("`D9&%T82`]('-U
M8G-T<B@D9&%T82P@,B`K("1B>71E<R`K("1L96XI.PH*("`@("`@("`@("`@
M("`@("1V86QU97,@/2`D=&AI<RT^7W!A<G-E05-.*"1S97%U96YC95]D871A
M*3L*("`@("`@("`@("`@("`@(&EF("@A:7-?87)R87DH)'9A;'5E<RD@?'P@
M:7-?<W1R:6YG*"1V86QU97-;,%TI*2!["B`@("`@("`@("`@("`@("`@("`@
M)'9A;'5E<R`](&%R<F%Y*"1V86QU97,I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)'-E<75E;F-E7W9A;'5E<R`](&%R<F%Y*"D["B`@
M("`@("`@("`@("`@("`D:2`](#`["B`@("`@("`@("`@("`@("!F;W)E86-H
M("@D=F%L=65S(&%S("1V86PI('L*("`@("`@("`@("`@("`@("`@("!I9B`H
M)'9A;%LP72`]/2`G97AT96YS:6]N)RD@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D<V5Q=65N8V5?=F%L=65S6R=E>'1E;G-I;VYS)UU;72`]("1V86P[
M"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)'-E<75E;F-E7W9A;'5E<ULD:2LK72`]("1V86P["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)')E<W5L=%M=(#T@87)R87DH)W-E<75E;F-E)RP@)'-E<75E;F-E
M7W9A;'5E<RD["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&-A<V4@,'@S,3H*("`@("`@("`@("`@("`@("\O(%-E="!O9@H@("`@("`@
M("`@("`@("`@)&QE;B`](&]R9"@D9&%T85LQ72D["B`@("`@("`@("`@("`@
M("`D8GET97,@/2`P.PH@("`@("`@("`@("`@("`@:68@*"1L96X@)B`P>#@P
M*2!["B`@("`@("`@("`@("`@("`@("`@)&)Y=&5S(#T@)&QE;B`F(#!X,&8[
M"B`@("`@("`@("`@("`@("`@("`@)&QE;B`](#`["B`@("`@("`@("`@("`@
M("`@("`@9F]R("@D:2`](#`[("1I(#P@)&)Y=&5S.R`D:2LK*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1L96X@/2`H)&QE;B`\/"`X*2!\(&]R9"@D
M9&%T85LD:2`K(#)=*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`D<V5Q=65N8V5?9&%T82`]('-U
M8G-T<B@D9&%T82P@,B`K("1B>71E<RP@)&QE;BD["B`@("`@("`@("`@("`@
M("`D9&%T82`]('-U8G-T<B@D9&%T82P@,B`K("1B>71E<R`K("1L96XI.PH@
M("`@("`@("`@("`@("`@)')E<W5L=%M=(#T@87)R87DH)W-E="<L("1T:&ES
M+3Y?<&%R<V5!4TXH)'-E<75E;F-E7V1A=&$I*3L*("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@8V%S92`P>#`Q.@H@("`@("`@("`@("`@
M("`@+R\@0F]O;&5A;B!T>7!E"B`@("`@("`@("`@("`@("`D8F]O;&5A;E]V
M86QU92`]("AO<F0H)&1A=&%;,ETI(#T](#!X9F8I.PH@("`@("`@("`@("`@
M("`@)&1A=&$@/2!S=6)S='(H)&1A=&$L(#,I.PH@("`@("`@("`@("`@("`@
M)')E<W5L=%M=(#T@87)R87DH)V)O;VQE86XG+"`D8F]O;&5A;E]V86QU92D[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@,'@P
M,CH*("`@("`@("`@("`@("`@("\O($EN=&5G97(@='EP90H@("`@("`@("`@
M("`@("`@)&QE;B`](&]R9"@D9&%T85LQ72D["B`@("`@("`@("`@("`@("`D
M8GET97,@/2`P.PH@("`@("`@("`@("`@("`@:68@*"1L96X@)B`P>#@P*2![
M"B`@("`@("`@("`@("`@("`@("`@)&)Y=&5S(#T@)&QE;B`F(#!X,&8["B`@
M("`@("`@("`@("`@("`@("`@)&QE;B`](#`["B`@("`@("`@("`@("`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@)&)Y=&5S.R`D:2LK*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1L96X@/2`H)&QE;B`\/"`X*2!\(&]R9"@D9&%T
M85LD:2`K(#)=*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`@("`@)&EN=&5G97)?9&%T82`]('-U8G-T
M<B@D9&%T82P@,B`K("1B>71E<RP@)&QE;BD["B`@("`@("`@("`@("`@("`D
M9&%T82`]('-U8G-T<B@D9&%T82P@,B`K("1B>71E<R`K("1L96XI.PH*("`@
M("`@("`@("`@("`@("1V86QU92`](#`["B`@("`@("`@("`@("`@("!I9B`H
M)&QE;B`\/2`T*2!["B`@("`@("`@("`@("`@("`@("`@+RH@365T:&]D('=O
M<FMS(&9I;F4@9F]R('-M86QL(&EN=&5G97)S("HO"B`@("`@("`@("`@("`@
M("`@("`@9F]R("@D:2`](#`[("1I(#P@<W1R;&5N*"1I;G1E9V5R7V1A=&$I
M.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`]("@D
M=F%L=64@/#P@."D@?"!O<F0H)&EN=&5G97)?9&%T85LD:5TI.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@+RH@365T:&]D('=O<FMS(&9O<B!A<F)I=')A<GD@
M;&5N9W1H(&EN=&5G97)S("HO"B`@("`@("`@("`@("`@("`@("`@:68@*%5T
M:6PZ.F5X=&5N<VEO;D5X:7-T<R@G8F-M871H)RDI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<W1R;&5N*"1I;G1E9V5R
M7V1A=&$I.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=F%L=64@/2!B8V%D9"AB8VUU;"@D=F%L=64L(#(U-BDL(&]R9"@D:6YT96=E
M<E]D871A6R1I72DI.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'9A;'5E(#T@+3$["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)')E<W5L=%M=(#T@87)R87DH
M)VEN=&5G97(H)R`N("1L96X@+B`G*2<L("1V86QU92D["B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@,'@P,SH*("`@("`@("`@
M("`@("`@("\O($)I='-T<FEN9R!T>7!E"B`@("`@("`@("`@("`@("`D;&5N
M(#T@;W)D*"1D871A6S%=*3L*("`@("`@("`@("`@("`@("1B>71E<R`](#`[
M"B`@("`@("`@("`@("`@("!I9B`H)&QE;B`F(#!X.#`I('L*("`@("`@("`@
M("`@("`@("`@("`D8GET97,@/2`D;&5N("8@,'@P9CL*("`@("`@("`@("`@
M("`@("`@("`D;&5N(#T@,#L*("`@("`@("`@("`@("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"`D8GET97,[("1I*RLI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&QE;B`]("@D;&5N(#P\(#@I('P@;W)D*"1D871A6R1I("L@,ETI
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1B:71S=')I;F=?9&%T82`]('-U8G-T<B@D9&%T82P@
M,R`K("1B>71E<RP@)&QE;BD["B`@("`@("`@("`@("`@("`D9&%T82`]('-U
M8G-T<B@D9&%T82P@,B`K("1B>71E<R`K("1L96XI.PH@("`@("`@("`@("`@
M("`@)')E<W5L=%M=(#T@87)R87DH)V)I="!S=')I;F<G+"`D8FET<W1R:6YG
M7V1A=&$I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E(#!X,#0Z"B`@("`@("`@("`@("`@("`O+R!/8W1E='-T<FEN9R!T>7!E
M"B`@("`@("`@("`@("`@("`D;&5N(#T@;W)D*"1D871A6S%=*3L*("`@("`@
M("`@("`@("`@("1B>71E<R`](#`["B`@("`@("`@("`@("`@("!I9B`H)&QE
M;B`F(#!X.#`I('L*("`@("`@("`@("`@("`@("`@("`D8GET97,@/2`D;&5N
M("8@,'@P9CL*("`@("`@("`@("`@("`@("`@("`D;&5N(#T@,#L*("`@("`@
M("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8GET97,[("1I*RLI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&QE;B`]("@D;&5N(#P\(#@I
M('P@;W)D*"1D871A6R1I("L@,ETI.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1O8W1E8W1S=')I
M;F=?9&%T82`]('-U8G-T<B@D9&%T82P@,B`K("1B>71E<RP@)&QE;BD["B`@
M("`@("`@("`@("`@("`D9&%T82`]('-U8G-T<B@D9&%T82P@,B`K("1B>71E
M<R`K("1L96XI.PH@("`@("`@("`@("`@("`@)')E<W5L=%M=(#T@87)R87DH
M)V]C=&5T('-T<FEN9R<L("1O8W1E8W1S=')I;F=?9&%T82D["B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@,'@P-3H*("`@("`@
M("`@("`@("`@("\O($YU;&P@='EP90H@("`@("`@("`@("`@("`@)&1A=&$@
M/2!S=6)S='(H)&1A=&$L(#(I.PH@("`@("`@("`@("`@("`@)')E<W5L=%M=
M(#T@87)R87DH)VYU;&PG+"!N=6QL*3L*("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@8V%S92`P>#`V.@H@("`@("`@("`@("`@("`@+R\@
M3V)J96-T(&ED96YT:69I97(@='EP90H@("`@("`@("`@("`@("`@)&QE;B`]
M(&]R9"@D9&%T85LQ72D["B`@("`@("`@("`@("`@("`D8GET97,@/2`P.PH@
M("`@("`@("`@("`@("`@:68@*"1L96X@)B`P>#@P*2!["B`@("`@("`@("`@
M("`@("`@("`@)&)Y=&5S(#T@)&QE;B`F(#!X,&8["B`@("`@("`@("`@("`@
M("`@("`@)&QE;B`](#`["B`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`]
M(#`[("1I(#P@)&)Y=&5S.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1L96X@/2`H)&QE;B`\/"`X*2!\(&]R9"@D9&%T85LD:2`K(#)=*3L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D;VED7V1A=&$@/2!S=6)S='(H)&1A=&$L(#(@*R`D8GET
M97,L("1L96XI.PH@("`@("`@("`@("`@("`@)&1A=&$@/2!S=6)S='(H)&1A
M=&$L(#(@*R`D8GET97,@*R`D;&5N*3L*"B`@("`@("`@("`@("`@("`O+R!5
M;G!A8VL@=&AE($])1`H@("`@("`@("`@("`@("`@)'!L86EN("`](&9L;V]R
M*&]R9"@D;VED7V1A=&%;,%TI("\@-#`I.PH@("`@("`@("`@("`@("`@)'!L
M86EN("X]("<N)R`N(&]R9"@D;VED7V1A=&%;,%TI("4@-#`["@H@("`@("`@
M("`@("`@("`@)'9A;'5E(#T@,#L*("`@("`@("`@("`@("`@("1I(#T@,3L*
M("`@("`@("`@("`@("`@('=H:6QE("@D:2`\('-T<FQE;B@D;VED7V1A=&$I
M*2!["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@)'9A;'5E(#P\(#<[
M"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@)'9A;'5E('P@*&]R9"@D
M;VED7V1A=&%;)&E=*2`F(#!X-V8I.PH*("`@("`@("`@("`@("`@("`@("!I
M9B`H(2AO<F0H)&]I9%]D871A6R1I72D@)B`P>#@P*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D<&QA:6X@+CT@)RXG("X@)'9A;'5E.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D=F%L=64@/2`P.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V]I9'-;
M)'!L86EN72DI('L*("`@("`@("`@("`@("`@("`@("`D<F5S=6QT6UT@/2!A
M<G)A>2@G;VED)RP@)'1H:7,M/E]O:61S6R1P;&%I;ETI.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<F5S=6QT6UT@
M/2!A<G)A>2@G;VED)RP@)'!L86EN*3L*("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@,'@Q,CH*
M("`@("`@("`@("`@8V%S92`P>#$S.@H@("`@("`@("`@("!C87-E(#!X,30Z
M"B`@("`@("`@("`@(&-A<V4@,'@Q-3H*("`@("`@("`@("`@8V%S92`P>#$V
M.@H@("`@("`@("`@("!C87-E(#!X.#$Z"B`@("`@("`@("`@(&-A<V4@,'@X
M,#H*("`@("`@("`@("`@("`@("\O($-H87)A8W1E<B!S=')I;F<@='EP90H@
M("`@("`@("`@("`@("`@)&QE;B`](&]R9"@D9&%T85LQ72D["B`@("`@("`@
M("`@("`@("`D8GET97,@/2`P.PH@("`@("`@("`@("`@("`@:68@*"1L96X@
M)B`P>#@P*2!["B`@("`@("`@("`@("`@("`@("`@)&)Y=&5S(#T@)&QE;B`F
M(#!X,&8["B`@("`@("`@("`@("`@("`@("`@)&QE;B`](#`["B`@("`@("`@
M("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&)Y=&5S.R`D:2LK*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1L96X@/2`H)&QE;B`\/"`X*2!\
M(&]R9"@D9&%T85LD:2`K(#)=*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<W1R:6YG7V1A=&$@
M/2!S=6)S='(H)&1A=&$L(#(@*R`D8GET97,L("1L96XI.PH@("`@("`@("`@
M("`@("`@)&1A=&$@/2!S=6)S='(H)&1A=&$L(#(@*R`D8GET97,@*R`D;&5N
M*3L*("`@("`@("`@("`@("`@("1R97-U;'1;72`](&%R<F%Y*"=S=')I;F<G
M+"`D<W1R:6YG7V1A=&$I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!C87-E(#!X,3<Z"B`@("`@("`@("`@("`@("`O+R!4:6UE('1Y
M<&5S"B`@("`@("`@("`@("`@("`D;&5N(#T@;W)D*"1D871A6S%=*3L*("`@
M("`@("`@("`@("`@("1B>71E<R`](#`["B`@("`@("`@("`@("`@("!I9B`H
M)&QE;B`F(#!X.#`I('L*("`@("`@("`@("`@("`@("`@("`D8GET97,@/2`D
M;&5N("8@,'@P9CL*("`@("`@("`@("`@("`@("`@("`D;&5N(#T@,#L*("`@
M("`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8GET97,[("1I
M*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&QE;B`]("@D;&5N(#P\
M(#@I('P@;W)D*"1D871A6R1I("L@,ETI.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T:6UE7V1A
M=&$@/2!S=6)S='(H)&1A=&$L(#(@*R`D8GET97,L("1L96XI.PH@("`@("`@
M("`@("`@("`@)&1A=&$@/2!S=6)S='(H)&1A=&$L(#(@*R`D8GET97,@*R`D
M;&5N*3L*("`@("`@("`@("`@("`@("1R97-U;'1;72`](&%R<F%Y*"=U=&-T
M:6UE)RP@)'1I;65?9&%T82D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@(&-A<V4@,'@X,CH*("`@("`@("`@("`@("`@("\O(%@U,#EV
M,R!E>'1E;G-I;VYS/PH@("`@("`@("`@("`@("`@)&QE;B`](&]R9"@D9&%T
M85LQ72D["B`@("`@("`@("`@("`@("`D8GET97,@/2`P.PH@("`@("`@("`@
M("`@("`@:68@*"1L96X@)B`P>#@P*2!["B`@("`@("`@("`@("`@("`@("`@
M)&)Y=&5S(#T@)&QE;B`F(#!X,&8["B`@("`@("`@("`@("`@("`@("`@)&QE
M;B`](#`["B`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M)&)Y=&5S.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1L96X@
M/2`H)&QE;B`\/"`X*2!\(&]R9"@D9&%T85LD:2`K(#)=*3L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D<V5Q=65N8V5?9&%T82`]('-U8G-T<B@D9&%T82P@,B`K("1B>71E<RP@
M)&QE;BD["B`@("`@("`@("`@("`@("`D9&%T82`]('-U8G-T<B@D9&%T82P@
M,B`K("1B>71E<R`K("1L96XI.PH@("`@("`@("`@("`@("`@)')E<W5L=%M=
M(#T@87)R87DH)V5X=&5N<VEO;B<L("=8-3`Y=C,@97AT96YS:6]N<R<I.PH@
M("`@("`@("`@("`@("`@)')E<W5L=%M=(#T@)'1H:7,M/E]P87)S94%33B@D
M<V5Q=65N8V5?9&%T82D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@(&-A<V4@,'AA,#H*("`@("`@("`@("`@8V%S92`P>&$S.@H@("`@
M("`@("`@("`@("`@+R\@17AT96YS:6]N<PH@("`@("`@("`@("`@("`@)&5X
M=&5N<VEO;E]D871A(#T@<W5B<W1R*"1D871A+"`P+"`R*3L*("`@("`@("`@
M("`@("`@("1D871A(#T@<W5B<W1R*"1D871A+"`R*3L*("`@("`@("`@("`@
M("`@("1R97-U;'1;72`](&%R<F%Y*"=E>'1E;G-I;VXG+"!D96-H97@H)&5X
M=&5N<VEO;E]D871A*2D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@(&-A<V4@,'AE-CH*("`@("`@("`@("`@("`@("1E>'1E;G-I;VY?
M9&%T82`]('-U8G-T<B@D9&%T82P@,"P@,2D["B`@("`@("`@("`@("`@("`D
M9&%T82`]('-U8G-T<B@D9&%T82P@,2D["B`@("`@("`@("`@("`@("`D<F5S
M=6QT6UT@/2!A<G)A>2@G97AT96YS:6]N)RP@9&5C:&5X*"1E>'1E;G-I;VY?
M9&%T82DI.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E(#!X83$Z"B`@("`@("`@("`@("`@("`D97AT96YS:6]N7V1A=&$@/2!S
M=6)S='(H)&1A=&$L(#`L(#$I.PH@("`@("`@("`@("`@("`@)&1A=&$@/2!S
M=6)S='(H)&1A=&$L(#8I.PH@("`@("`@("`@("`@("`@)')E<W5L=%M=(#T@
M87)R87DH)V5X=&5N<VEO;B<L(&1E8VAE>"@D97AT96YS:6]N7V1A=&$I*3L*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@9&5F875L=#H*
M("`@("`@("`@("`@("`@("\O(%5N:VYO=VX*("`@("`@("`@("`@("`@("1R
M97-U;'1;72`](&%R<F%Y*"=53DM.3U=.)RP@9&5C:&5X*"1D871A*2D["B`@
M("`@("`@("`@("`@("`D9&%T82`]("<G.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`H
M8V]U;G0H)')E<W5L="D@/B`Q*2`_("1R97-U;'0@.B!A<G)A>5]P;W`H)')E
M<W5L="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96-R>7!T(&%N(%,_34E-
M12!S:6=N960@;65S<V%G92!U<VEN9R!A('!U8FQI8R!K97DN"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=&5X="`@(%1H92!T97AT('1O(&)E('9E<FEF:65D+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1P87)A;7,@(%1H92!P87)A;65T97)S(&YE961E9"!F
M;W(@=F5R:69I8V%T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@=F5R:69I8V%T:6]N(&UE<W-A9V4N"B`@("`@*B`@("`@("`@("`@
M("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]B:F5C="!O;B!E<G)O<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V1E8W)Y<'13:6=N871U<F4H)'1E>'0L("1P
M87)A;7,I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)U]D96-R>7!T4VEG;F%T=7)E*"D@)R`N(%\H(FYO="!Y970@:6UP;&5M96YT
M960B*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:R!F;W(@=&AE('!R
M97-E;F-E(&]F('1H92!/<&5N4U-,(&5X=&5N<VEO;B!T;R!02%`N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!2971U<FYS('1R=64@:68@=&AE
M(&]P96YS<VP@97AT96YS:6]N(&ES(&%V86EL86)L92X*("`@("`J("`@("`@
M("`@("`@("`@("`@4F5T=7)N<R!A(%!%05)?17)R;W(@:68@;F]T+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!C:&5C:T9O<D]P96Y34TPH*0H@("`@>PH@("`@
M("`@(&EF("@A571I;#HZ97AT96YS:6]N17AI<W1S*"=O<&5N<W-L)RDI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B5&AE(&]P
M96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?
M<VUI;64Z.B!C;&%S<RXB*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@17AT<F%C="!T:&4@96UA:6P@861D<F5S<R!F<F]M(&$@<'5B;&EC
M(&ME>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1K97D@(%1H92!P
M=6)L:6,@:V5Y+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!2971U
M<FYS('1H92!E;6%I;"!A9&1R97-S+"!O<B!N=6QL(&EF(&YO;F4@:7,@9F]U
M;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$5M86EL1G)O;4ME>2@D:V5Y
M*0H@("`@>PH@("`@("`@("1K97E?:6YF;R`](&]P96YS<VQ?>#4P.5]P87)S
M92@D:V5Y*3L*("`@("`@("!I9B`H:7-?87)R87DH)&ME>5]I;F9O*2`F)B!I
M<W-E="@D:V5Y7VEN9F];)W-U8FIE8W0G72DI('L*("`@("`@("`@("`@:68@
M*&ES<V5T*"1K97E?:6YF;ULG<W5B:F5C="==6R=%;6%I;"==*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1K97E?:6YF;ULG<W5B:F5C="==6R=%;6%I
M;"==.PH@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)&ME>5]I;F9O6R=S
M=6)J96-T)UU;)V5M86EL061D<F5S<R==*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1K97E?:6YF;ULG<W5B:F5C="==6R=E;6%I;$%D9')E<W,G73L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&YU;&P[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T(&$@4$M#4R`Q,B!E;F-R
M>7!T960@8V5R=&EF:6-A=&4@<&%C:V%G92!I;G1O(&$@<')I=F%T92!K97DL
M"B`@("`@*B!P=6)L:6,@:V5Y+"!A;F0@86YY(&%D9&ET:6]N86P@:V5Y<RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@5&AE(%!+0U,@
M,3(@9&%T82X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!4:&4@<&%R
M86UE=&5R<R!N965D960@9F]R('!A<G-I;F<N"B`@("`@*B`\<')E/@H@("`@
M("H@4&%R86UE=&5R<SH*("`@("`J(#T]/3T]/3T]/3T]"B`@("`@*B`G<W-L
M<&%T:"<@/3X@5&AE('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y+B`H4D51
M54E2140I"B`@("`@*B`G<&%S<W=O<F0G(#T^(%1H92!P87-S=V]R9"!T;R!U
M<V4@=&\@9&5C<GEP="!T:&4@9&%T82X@*$]P=&EO;F%L*0H@("`@("H@)VYE
M=W!A<W-W;W)D)R`]/B!4:&4@<&%S<W=O<F0@=&\@=7-E('1O(&5N8W)Y<'0@
M=&AE('!R:79A=&4@:V5Y+@H@("`@("H@("`@("`@("`@("`@("`@("`H3W!T
M:6]N86PI"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M9$-L87-S("!!;B!O8FIE8W0N"B`@("`@*B`@("`@("`@("`@("`@("`@("`G
M<')I=F%T92<@+2`@5&AE('!R:79A=&4@:V5Y(&EN(%!%32!F;W)M870N"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`G<'5B;&EC)R`@+2`@5&AE('!U8FQI
M8R!K97D@:6X@4$5-(&9O<FUA="X*("`@("`J("`@("`@("`@("`@("`@("`@
M("=C97)T<R<@("`M("!!;B!A<G)A>2!O9B!A9&1I=&EO;F%L(&-E<G1S+@H@
M("`@("H@("`@("`@("`@("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N
M(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!P87)S95!+0U,Q,D1A=&$H
M)'!K8W,Q,BP@)'!A<F%M<RD*("`@('L*("`@("`@("`O*B!#:&5C:R!F;W(@
M879A:6QA8FEL:71Y(&]F($]P96Y34TP@4$A0(&5X=&5N<VEO;BX@*B\*("`@
M("`@("`D;W!E;G-S;"`]("1T:&ES+3YC:&5C:T9O<D]P96Y34TPH*3L*("`@
M("`@("!I9B`H:7-?82@D;W!E;G-S;"P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&]P96YS<VP["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(6ES<V5T*"1P87)A;7-;)W-S;'!A=&@G72DI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F\@<&%T:"!T;R!T:&4@3W!E
M;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N
M96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB*2P@)VAO<F1E
M+F5R<F]R)RD["B`@("`@("`@?0H@("`@("`@("1S<VQP871H(#T@97-C87!E
M<VAE;&QC;60H)'!A<F%M<ULG<W-L<&%T:"==*3L*"B`@("`@("`@+RH@0W)E
M871E('1E;7`@9FEL97,@9F]R(&EN<'5T+V]U='!U="X@*B\*("`@("`@("`D
M:6YP=70@/2`D=&AI<RT^7V-R96%T951E;7!&:6QE*"=H;W)D92US;6EM92<I
M.PH@("`@("`@("1O=71P=70@/2`D=&AI<RT^7V-R96%T951E;7!&:6QE*"=H
M;W)D92US;6EM92<I.PH*("`@("`@("`D;V(@/2`F;F5W('-T9$-L87-S.PH*
M("`@("`@("`O*B!7<FET92!T97AT('1O(&9I;&4@*B\*("`@("`@("`D9G`@
M/2!F;W!E;B@D:6YP=70L("=W*R<I.PH@("`@("`@(&9W<FET92@D9G`L("1P
M:V-S,3(I.PH@("`@("`@(&9C;&]S92@D9G`I.PH*("`@("`@("`O*B!%>'1R
M86-T('1H92!P<FEV871E(&ME>2!F<F]M('1H92!F:6QE(&9I<G-T+B`J+PH@
M("`@("`@("1C;61L:6YE(#T@)'-S;'!A=&@@+B`G('!K8W,Q,B`M:6X@)R`N
M("1I;G!U="`N("<@+6]U="`G("X@)&]U='!U="`N("<@+6YO8V5R=',G.PH@
M("`@("`@(&EF("AI<W-E="@D<&%R86US6R=P87-S=V]R9"==*2D@>PH@("`@
M("`@("`@("`D8VUD;&EN92`N/2`G("UP87-S:6X@<W1D:6XG.PH@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1P87)A;7-;)VYE=W!A<W-W;W)D)UTI*2!["B`@
M("`@("`@("`@("`@("`D8VUD;&EN92`N/2`G("UP87-S;W5T('-T9&EN)SL*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1C;61L:6YE
M("X]("<@+6YO9&5S)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D9F0@
M/2!P;W!E;B@D8VUD;&EN92P@)W<G*3L*("`@("`@("`@("`@9G=R:71E*"1F
M9"P@)'!A<F%M<ULG<&%S<W=O<F0G72`N(")<;B(I.PH@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1P87)A;7-;)VYE=W!A<W-W;W)D)UTI*2!["B`@("`@("`@
M("`@("`@("!F=W)I=&4H)&9D+"`D<&%R86US6R=N97=P87-S=V]R9"==("X@
M(EQN(BD["B`@("`@("`@("`@('T*("`@("`@("`@("`@<&-L;W-E*"1F9"D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-M9&QI;F4@+CT@)R`M
M;F]D97,G.PH@("`@("`@("`@("!E>&5C*"1C;61L:6YE*3L*("`@("`@("!]
M"B`@("`@("`@)&]B+3YP<FEV871E(#T@=')I;2AF:6QE7V=E=%]C;VYT96YT
M<R@D;W5T<'5T*2D["B`@("`@("`@:68@*&5M<'1Y*"1O8BT^<')I=F%T92DI
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B4&%S
M<W=O<F0@:6YC;W)R96-T(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@17AT<F%C="!T:&4@<'5B;&EC(&ME>2!N97AT+B`J+PH@
M("`@("`@("1C;61L:6YE(#T@)'-S;'!A=&@@+B`G('!K8W,Q,B`M:6X@)R`N
M("1I;G!U="`N("<@+6]U="`G("X@)&]U='!U="`N("<@+6YO:V5Y<R`M8VQC
M97)T<R<["B`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;)W!A<W-W;W)D)UTI
M*2!["B`@("`@("`@("`@("1C;61L:6YE("X]("<@+7!A<W-I;B!S=&1I;B<[
M"B`@("`@("`@("`@("1F9"`]('!O<&5N*"1C;61L:6YE+"`G=R<I.PH@("`@
M("`@("`@("!F=W)I=&4H)&9D+"`D<&%R86US6R=P87-S=V]R9"==("X@(EQN
M(BD["B`@("`@("`@("`@('!C;&]S92@D9F0I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(&5X96,H)&-M9&QI;F4I.PH@("`@("`@('T*("`@("`@
M("`D;V(M/G!U8FQI8R`]('1R:6TH9FEL95]G971?8V]N=&5N=',H)&]U='!U
M="DI.PH*("`@("`@("`O*B!%>'1R86-T('1H92!P=6)L:6,@:V5Y(&YE>'0N
M("HO"B`@("`@("`@)&-M9&QI;F4@/2`D<W-L<&%T:"`N("<@<&MC<S$R("UI
M;B`G("X@)&EN<'5T("X@)R`M;W5T("<@+B`D;W5T<'5T("X@)R`M;F]K97ES
M("UC86-E<G1S)SL*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG<&%S<W=O
M<F0G72DI('L*("`@("`@("`@("`@)&-M9&QI;F4@+CT@)R`M<&%S<VEN('-T
M9&EN)SL*("`@("`@("`@("`@)&9D(#T@<&]P96XH)&-M9&QI;F4L("=W)RD[
M"B`@("`@("`@("`@(&9W<FET92@D9F0L("1P87)A;7-;)W!A<W-W;W)D)UT@
M+B`B7&XB*3L*("`@("`@("`@("`@<&-L;W-E*"1F9"D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@97AE8R@D8VUD;&EN92D["B`@("`@("`@?0H@
M("`@("`@("1O8BT^8V5R=',@/2!T<FEM*&9I;&5?9V5T7V-O;G1E;G1S*"1O
M=71P=70I*3L*"B`@("`@("`@<F5T=7)N("1O8CL*("`@('T*"B`@("`O*BH*
M("`@("`J(%1H92!#;VYT96YT+51Y<&4@<&%R86UE=&5R<R!02%`G<R!O<&5N
M<W-L7W!K8W,W7RH@9G5N8W1I;VYS(')E='5R;B!A<F4*("`@("`J(&1E<')E
M8V%T960N("!&:7@@=&AE<V4@:&5A9&5R<R!T;R!T:&4@8V]R<F5C="!O;F5S
M("AS964@4D9#(#(S,3$I+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!02T-3
M-R!D871A+@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@27,@=&AI<R`G
M;65S<V%G92<@;W(@)W-I9VYA='5R92<@9&%T83\*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(%!+0U,W(&1A=&$@=VET:"!T:&4@8V]R<F5C
M="!#;VYT96YT+51Y<&4@<&%R86UE=&5R+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?9FEX0V]N=&5N=%1Y<&4H)'1E>'0L("1T>7!E*0H@("`@>PH@("`@("`@
M(&EF("@D='EP92`]/2`G;65S<V%G92<I('L*("`@("`@("`@("`@)&9R;VT@
M/2`G87!P;&EC871I;VXO>"UP:V-S-RUM:6UE)SL*("`@("`@("`@("`@)'1O
M(#T@)V%P<&QI8V%T:6]N+W!K8W,W+6UI;64G.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1F<F]M(#T@)V%P<&QI8V%T:6]N+W@M<&MC<S<M<VEG
M;F%T=7)E)SL*("`@("`@("`@("`@)'1O(#T@)V%P<&QI8V%T:6]N+W!K8W,W
M+7-I9VYA='5R92<["B`@("`@("`@?0H@("`@("`@(')E='5R;B!S=')?<F5P
M;&%C92@G0V]N=&5N="U4>7!E.B`G("X@)&9R;VTL("=#;VYT96YT+51Y<&4Z
M("<@+B`D=&\L("1T97AT*3L*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+T-R>7!T+G!H<```````````````````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`Q,C4W-P`Q,#4Q-30S,S<U,@`P,C$S,3(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J(%1H92!(;W)D95]#<GEP=#HZ(&-L87-S('!R;W9I9&5S(&%N($%0
M22!F;W(@=F%R:6]U<R!C<GEP=&]G<F%P:&EC"B`J('-Y<W1E;7,@=7-E9"!B
M>2!(;W)D92!A<'!L:6-A=&EO;G,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+G!H<"QV(#$N,C<N,3`N.2`R,#`V+S`Q+S`Q(#(Q.C(X
M.C$R(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA
M96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU
M<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@
M,RXP"B`J($!P86-K86=E($AO<F1E7T-R>7!T"B`J+PIC;&%S<R!(;W)D95]#
M<GEP="!["@H@("`@+RHJ"B`@("`@*B!4:&4@=&5M<&]R87)Y(&1I<F5C=&]R
M>2!T;R!U<V4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1?=&5M<&1I<CL*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O
M(')E='5R;B!A(&-O;F-R971E($AO<F1E7T-R>7!T(&EN<W1A;F-E(&)A<V5D
M(&]N("1D<FEV97(N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D<FEV
M97(@(%1H92!T>7!E(&]F(&-O;F-R971E($AO<F1E7T-R>7!T('-U8F-L87-S
M('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N+B!)9B`D
M9')I=F5R(&ES(&%N(&%R<F%Y+"!T:&5N('=E('=I;&P@;&]O:PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@(&EN("1D<FEV97);,%TO;&EB+T-R>7!T
M+R!F;W(@=&AE('-U8F-L87-S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@:6UP;&5M96YT871I;VX@;F%M960@)&1R:79E<ELQ72YP:'`N"B`@("`@
M*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY
M(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D
M+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?0W)Y<'0@(%1H92!N97=L
M>2!C<F5A=&5D(&-O;F-R971E($AO<F1E7T-R>7!T(&EN<W1A;F-E+"!O<@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@9F%L<V4@;VX@86X@97)R;W(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D<FEV97(L("1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D9')I
M=F5R*2D@>PH@("`@("`@("`@("!L:7-T*"1A<'`L("1D<FEV97(I(#T@)&1R
M:79E<CL*("`@("`@("!]"@H@("`@("`@("\J(%)E='5R;B!A(&)A<V4@2&]R
M9&5?0W)Y<'0@;V)J96-T(&EF(&YO(&1R:79E<B!I<R!S<&5C:69I960N("HO
M"B`@("`@("`@)&1R:79E<B`](&)A<V5N86UE*"1D<FEV97(I.PH@("`@("`@
M(&EF("AE;7!T>2@D9')I=F5R*2!\?"`H<W1R8VUP*"1D<FEV97(L("=N;VYE
M)RD@/3T@,"DI('L*("`@("`@("`@("`@)&-R>7!T(#T@)FYE=R!(;W)D95]#
M<GEP="@I.PH@("`@("`@("`@("!R971U<FX@)&-R>7!T.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"%E;7!T>2@D87!P*2D@>PH@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G9FEL97)O;W0G
M+"`D87!P*2`N("<O;&EB+T-R>7!T+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@
M("`@("`@('T@96QS96EF("A`9FEL95]E>&ES=',H9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+T-R>7!T+R<@+B`D9')I=F5R("X@)RYP:'`G*2D@>PH@("`@("`@
M("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+T-R>7!T
M+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@($!I;F-L=61E7V]N8V4@)TAO<F1E+T-R>7!T+R<@+B`D9')I=F5R
M("X@)RYP:'`G.PH@("`@("`@('T*("`@("`@("`D8VQA<W,@/2`G2&]R9&5?
M0W)Y<'1?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D
M8VQA<W,I*2!["B`@("`@("`@("`@("1C<GEP="`]("9N97<@)&-L87-S*"1P
M87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C<GEP="`]
M(%!%05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I;VX@;V8@)R`N("1C
M;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1C<GEP=#L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O
M(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E($AO<F1E7T-R>7!T
M(&EN<W1A;F-E"B`@("`@*B!B87-E9"!O;B`D9')I=F5R+B!)="!W:6QL(&]N
M;'D@8W)E871E(&$@;F5W(&EN<W1A;F-E(&EF(&YO"B`@("`@*B!(;W)D95]#
M<GEP="!I;G-T86YC92!W:71H('1H92!S86UE('!A<F%M971E<G,@8W5R<F5N
M=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES('-H;W5L9"!B92!U<V5D
M(&EF(&UU;'1I<&QE(&-R>7!T;R!B86-K96YD<R`H86YD+"!T:'5S+`H@("`@
M("H@;75L=&EP;&4@2&]R9&5?0W)Y<'0@:6YS=&%N8V5S*2!A<F4@<F5Q=6ER
M960N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D
M(&%S.B`D=F%R(#T@)DAO<F1E7T-R>7!T.CIS:6YG;&5T;VXH*0H@("`@("H*
M("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC
M<F5T92!(;W)D95]#<GEP="!S=6)C;&%S<R!T;PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;BX@268@)&1R:79E<B!I<R!A;B!A<G)A>2P@
M=&AE;B!W92!W:6QL(&QO;VL*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!I;B`D9')I=F5R6S!=+VQI8B]#<GEP="\@9F]R('1H92!S=6)C;&%S<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EM<&QE;65N=&%T:6]N(&YA
M;65D("1D<FEV97);,5TN<&AP+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R
M871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T
M:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*
M("`@("`J($!R971U<FX@2&]R9&5?0W)Y<'0@(%1H92!C;VYC<F5T92!(;W)D
M95]#<GEP="!R969E<F5N8V4L(&]R(&9A;'-E(&]N(&%N"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M)G-I;F=L971O;B@D9')I=F5R+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*
M("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<SL*"B`@("`@("`@:68@*"%I<W-E
M="@D:6YS=&%N8V5S*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S(#T@87)R
M87DH*3L*("`@("`@("!]"@H@("`@("`@("1S:6=N871U<F4@/2!S97)I86QI
M>F4H87)R87DH)&1R:79E<BP@)'!A<F%M<RDI.PH@("`@("`@(&EF("@A:7-S
M970H)&EN<W1A;F-E<ULD<VEG;F%T=7)E72DI('L*("`@("`@("`@("`@)&EN
M<W1A;F-E<ULD<VEG;F%T=7)E72`]("9(;W)D95]#<GEP=#HZ9F%C=&]R>2@D
M9')I=F5R+"`D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*("`@("\J*@H@("`@("H@
M3W5T<'5T<R!E<G)O<B!M97-S86=E(&EF('=E(&%R92!N;W0@=7-I;F<@82!S
M96-U<F4@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(%!%05)?
M17)R;W(@(%)E='5R;G,@82!014%27T5R<F]R(&]B:F5C="!I9B!T:&5R92!I
M<R!N;R!S96-U<F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@8V]N;F5C
M=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5Q=6ER95-E8W5R94-O;FYE
M8W1I;VXH*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8G)O=W-E<CL*"B`@("`@
M("`@:68@*"$D8G)O=W-E<BT^=7-I;F=34TQ#;VYN96-T:6]N*"DI('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B5&AE(&5N8W)Y
M<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO
M;BXB*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@16YC<GEP
M="!T:&4@<F5Q=65S=&5D(&1A=&$N"B`@("`@*B!4:&ES(&UE=&AO9"!S:&]U
M;&0@8F4@<')O=FED960@8GD@86QL(&-L87-S97,@=&AA="!E>'1E;F0@2&]R
M9&5?0W)Y<'0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T82`@
M(%1H92!D871A('1O(&5N8W)Y<'0N"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@06X@87)R87D@;V8@87)G=6UE;G1S(&YE961E9"!T;R!E;F-R>7!T
M('1H92!D871A+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!E
M;F-R>7!T960@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@96YC<GEP="@D
M9&%T82P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<F5T=7)N
M("1D871A.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5C<GEP="!T:&4@<F5Q
M=65S=&5D(&1A=&$N"B`@("`@*B!4:&ES(&UE=&AO9"!S:&]U;&0@8F4@<')O
M=FED960@8GD@86QL(&-L87-S97,@=&AA="!E>'1E;F0@2&]R9&5?0W)Y<'0N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T82`@(%1H92!D871A
M('1O(&1E8W)Y<'0N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06X@
M87)R87D@;V8@87)G=6UE;G1S(&YE961E9"!T;R!D96-R>7!T('1H92!D871A
M+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!D96-R>7!T960@
M9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C<GEP="@D9&%T82P@)'!A
M<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<F5T=7)N("1D871A.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0W)E871E(&$@=&5M<&]R87)Y(&9I;&4@
M=&AA="!W:6QL(&)E(&1E;&5T960@870@=&AE(&5N9"!O9B!T:&ES"B`@("`@
M*B!P<F]C97-S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@("1D97-C<FEP("!$97-C<FEP=&EO
M;B!S=')I;F<@=&\@=7-E(&EN(&9I;&5N86UE+@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)&1E;&5T92`@($1E;&5T92!T:&4@9FEL92!A=71O;6%T:6-A;&QY
M/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!&:6QE;F%M92!O9B!A
M('1E;7!O<F%R>2!F:6QE+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8W)E871E
M5&5M<$9I;&4H)&1E<V-R:7`@/2`G:&]R9&4M8W)Y<'0G+"`D9&5L971E(#T@
M=')U92D*("`@('L*("`@("`@("!R971U<FX@571I;#HZ9V5T5&5M<$9I;&4H
M)&1E<V-R:7`L("1D96QE=&4L("1T:&ES+3Y?=&5M<&1I<BP@=')U92D["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&$O````
M````````````````````````````````````````````````````````````
M```````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#4Q-30S,S<T-@`P,C`S-#``(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O1&%T82]C<W8N<&AP````````````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#(V-S0W`#$P-3$U-#,S-S0V`#`R,38V-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@2&]R9&5?1&%T82!I;7!L96UE;G1A=&EO;B!F;W(@8V]M;6$M<V5P87)A
M=&5D(&1A=&$@*$-35BDN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T1A=&$O
M1&%T82]C<W8N<&AP+'8@,2XS,"XQ,"XX(#(P,#8O,#$O,C@@,38Z,C$Z-3@@
M8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*86X@4V-H
M;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0&%U=&AO
M<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC
M92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]$871A"B`J+PIC;&%S
M<R!(;W)D95]$871A7V-S=B!E>'1E;F1S($AO<F1E7T1A=&$@>PH*("`@('9A
M<B`D7V5X=&5N<VEO;B`]("=C<W8G.PH@("`@=F%R("1?8V]N=&5N=%1Y<&4@
M/2`G=&5X="]C;VUM82US97!A<F%T960M=F%L=65S)SL*"B`@("`O*BH*("`@
M("`J(%1R:65S('1O(&1I<V-O=F5R('1H92!#4U8@9FEL92=S('!A<F%M971E
M<G,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL96YA;64@(%1H
M92!N86UE(&]F('1H92!F:6QE('1O(&EN=F5S=&EG871E+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@($%N(&%S<V]C:6%T:79E(&%R<F%Y('=I=&@@
M=&AE(&9O;&QO=VEN9R!P;W-S:6)L92!K97ES.@H@("`@("H@/'!R93X*("`@
M("`J("=S97`G.B`@("!4:&4@9FEE;&0@<V5P87)A=&]R"B`@("`@*B`G<75O
M=&4G.B`@5&AE('%U;W1I;F<@8VAA<F%C=&5R"B`@("`@*B`G9FEE;&1S)SH@
M5&AE(&YU;6)E<B!O9B!F:65L9',@*&-O;'5M;G,I"B`@("`@*B`\+W!R93X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9&ES8V]V97)&;W)M870H)&9I;&5N86UE
M*0H@("`@>PH@("`@("`@($!I;F-L=61E7V]N8V4H)T9I;&4O0U-6+G!H<"<I
M.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)T9I;&5?0U-6)RDI('L*("`@
M("`@("`@("`@<F5T=7)N($9I;&5?0U-6.CID:7-C;W9E<D9O<FUA="@D9FEL
M96YA;64I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!A
M<G)A>2@G<V5P)R`]/B`G+"<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($EM<&]R=',@86YD('!A<G-E<R!A($-35B!F:6QE+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&9I;&5N86UE("!4:&4@;F%M92!O9B!T
M:&4@9FEL92!T;R!P87)S92X*("`@("`J($!P87)A;2!B;V]L96%N("1H96%D
M97(@("!$;V5S('1H92!F:7)S="!L:6YE(&-O;G1A:6X@=&AE(&9I96QD+V-O
M;'5M;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&YA;65S/PH@
M("`@("H@0'!A<F%M('-T<FEN9R`D<V5P("`@("`@(%1H92!F:65L9"]C;VQU
M;6X@<V5P87)A=&]R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<75O=&4@("`@
M(%1H92!Q=6]T:6YG(&-H87)A8W1E<BX*("`@("`J($!P87)A;2!I;G1E9V5R
M("1F:65L9',@("!4:&4@;G5M8F5R(&]R(&9I96QD<R]C;VQU;6YS+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8VAA<G-E="`@(%1H92!F:6QE)W,@8VAA<G-E
M="X@0'-I;F-E($AO<F1E(#,N,2X*("`@("`J($!P87)A;2!S=')I;F<@)&-R
M;&8@("`@("!4:&4@9FEL92=S(&QI;F5F965D(&-H87)A8W1E<G,N($!S:6YC
M92!(;W)D92`S+C$N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!T
M=V\M9&EM96YS:6]N86P@87)R87D@;V8@86QL(&EM<&]R=&5D(&1A=&$@<F]W
M<RX@($EF"B`@("`@*B`@("`@("`@("`@("`@("`D:&5A9&5R('=A<R!T<G5E
M('1H92!R;W=S(&%R92!A<W-O8VEA=&EV92!A<G)A>7,@=VET:"!T:&4*("`@
M("`J("`@("`@("`@("`@("`@(&9I96QD+V-O;'5M;B!N86UE<R!A<R!T:&4@
M:V5Y<RX*("`@("`J+PH@("`@9G5N8W1I;VX@:6UP;W)T1FEL92@D9FEL96YA
M;64L("1H96%D97(@/2!F86QS92P@)'-E<"`]("<G+"`D<75O=&4@/2`G)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@)&9I96QD<R`](&YU;&PL("1I;7!O
M<G1?;6%P<&EN9R`](&%R<F%Y*"DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("1C:&%R<V5T(#T@;G5L;"P@)&-R;&8@/2!N=6QL*0H@("`@>PH@("`@("`@
M($!I;F-L=61E7V]N8V4H)T9I;&4O0U-6+G!H<"<I.PH*("`@("`@("`D9&%T
M82`](&%R<F%Y*"D["@H@("`@("`@("\J($9I;&5?0U-6(&ES('!R97-E;G0N
M("HO"B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@G1FEL95]#4U8G*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7W=A<FYI;F=S(#T@87)R87DH*3L*"B`@("`@
M("`@("`@("\J($9I;&5?0U-6(&ES(&$@8FET('!I8VMY(&%T('=H870@<&%R
M86UE=&5R(&ET(&5X<&5C=',N("HO"B`@("`@("`@("`@("1C;VYF(#T@87)R
M87DH*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D<75O=&4I*2!["B`@("`@
M("`@("`@("`@("`D8V]N9ELG<75O=&4G72`]("1Q=6]T93L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H96UP='DH)'-E<"DI('L*("`@("`@("`@
M("`@("`@("1C;VYF6R=S97`G72`]("<L)SL*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1C;VYF6R=S97`G72`]("1S97`["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@:68@*"1F:65L9',I('L*("`@("`@("`@
M("`@("`@("1C;VYF6R=F:65L9',G72`]("1F:65L9',["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@)&1A=&$["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@:68@*"%E;7!T>2@D8W)L9BDI('L*("`@
M("`@("`@("`@("`@("1C;VYF6R=C<FQF)UT@/2`D8W)L9CL*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@+RH@4W1R:7`@86YD(&ME97`@=&AE(&9I<G-T
M(&QI;F4@:68@:70@8V]N=&%I;G,@=&AE(&9I96QD"B`@("`@("`@("`@("`J
M(&YA;65S+B`J+PH@("`@("`@("`@("!I9B`H)&AE861E<BD@>PH@("`@("`@
M("`@("`@("`@)&AE860@/2!&:6QE7T-35CHZ<F5A9"@D9FEL96YA;64L("1C
M;VYF*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1H96%D+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1H96%D.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D
M8VAA<G-E="DI('L*("`@("`@("`@("`@("`@("`@("`D:&5A9"`](%-T<FEN
M9SHZ8V]N=F5R=$-H87)S970H)&AE860L("1C:&%R<V5T+"!.3%,Z.F=E=$-H
M87)S970H*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@('=H:6QE("@D;&EN92`]($9I;&5?0U-6.CIR96%D*"1F:6QE
M;F%M92P@)&-O;F8I*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D;&EN
M92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D;&EN93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF
M("@A96UP='DH)&-H87)S970I*2!["B`@("`@("`@("`@("`@("`@("`@)&QI
M;F4@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1L:6YE+"`D8VAA<G-E="P@
M3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D:&5A9"DI('L*("`@("`@("`@("`@("`@
M("`@("`D9&%T85M=(#T@)&QI;F4["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1N97=L:6YE(#T@87)R87DH*3L*("`@
M("`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D:&5A
M9"D[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1I;7!O<G1?;6%P<&EN9ULD:&5A9%LD:5U=*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&AE861;)&E=(#T@)&EM<&]R=%]M87!P:6YG6R1H
M96%D6R1I75T["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`@("`@)&-E;&P@/2`D;&EN95LD:5T["B`@("`@("`@("`@
M("`@("`@("`@("`@("1C96QL(#T@<')E9U]R97!L86-E*"(O7")<(B\B+"`B
M7"(B+"`D8V5L;"D["B`@("`@("`@("`@("`@("`@("`@("`@("1N97=L:6YE
M6R1H96%D6R1I75T@/2!E;7!T>2@D8V5L;"D@/R`G)R`Z("1C96QL.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D9&%T85M=
M(#T@)&YE=VQI;F4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("1F<"`]($9I;&5?0U-6.CIG9710;VEN=&5R*"1F:6QE
M;F%M92P@)&-O;F8I.PH@("`@("`@("`@("!I9B`H)&9P("8F("%I<U]A*"1F
M<"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5W:6YD*"1F
M<"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?=V%R;FEN
M9W,@/2!&:6QE7T-35CHZ=V%R;FEN9R@I.PH*("`@("`@("`O*B!&86QL(&)A
M8VL@=&\@9F=E=&-S=B@I+B`J+PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1F<"`](&9O<&5N*"1F:6QE;F%M92P@)W(G*3L*("`@("`@("`@("`@
M:68@*"$D9G`I('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+RH@4W1R:7`@86YD(&ME97`@=&AE
M(&9I<G-T(&QI;F4@:68@:70@8V]N=&%I;G,@=&AE(&9I96QD"B`@("`@("`@
M("`@("`@(&YA;65S+B`J+PH@("`@("`@("`@("!I9B`H)&AE861E<BD@>PH@
M("`@("`@("`@("`@("`@)&AE860@/2!F9V5T8W-V*"1F<"P@,3`R-"P@)'-E
M<"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%E;7!T>2@D8VAA
M<G-E="DI('L*("`@("`@("`@("`@("`@("1H96%D(#T@4W1R:6YG.CIC;VYV
M97)T0VAA<G-E="@D:&5A9"P@)&-H87)S970L($Y,4SHZ9V5T0VAA<G-E="@I
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!W:&EL92`H)&QI;F4@/2!F
M9V5T8W-V*"1F<"P@,3`R-"P@)'-E<"DI('L*("`@("`@("`@("`@("`@(&EF
M("@A96UP='DH)&-H87)S970I*2!["B`@("`@("`@("`@("`@("`@("`@)&QI
M;F4@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1L:6YE+"`D8VAA<G-E="P@
M3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D:&5A9"DI('L*("`@("`@("`@("`@("`@
M("`@("`D9&%T85M=(#T@)&QI;F4["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1N97=L:6YE(#T@87)R87DH*3L*("`@
M("`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D:&5A
M9"D[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1I;7!O<G1?;6%P<&EN9ULD:&5A9%LD:5U=*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&AE861;)&E=(#T@)&EM<&]R=%]M87!P:6YG6R1H
M96%D6R1I75T["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`@("`@)&-E;&P@/2`D;&EN95LD:5T["B`@("`@("`@("`@
M("`@("`@("`@("`@("1C96QL(#T@<')E9U]R97!L86-E*"(O7"(O(BP@(EPB
M7"(B+"`D8V5L;"D["B`@("`@("`@("`@("`@("`@("`@("`@("1N97=L:6YE
M6R1H96%D6R1I75T@/2!E;7!T>2@D8V5L;"D@/R`G)R`Z("1C96QL.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D9&%T85M=
M(#T@)&YE=VQI;F4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9',@82!#
M4U8@9FEL92!F<F]M(&$@9VEV96X@9&%T82!S=')U8W1U<F4@86YD(')E='5R
M;G,@:70@87,@80H@("`@("H@<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D9&%T82`@("`@($$@='=O+61I;65N<VEO;F%L(&%R<F%Y(&-O
M;G1A:6YI;F<@=&AE(&1A=&$@<V5T+@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)&AE861E<B`@268@=')U92P@=&AE(')O=W,@;V8@)&1A=&$@87)E(&%S<V]C
M:6%T:79E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>7,@
M=VET:"!F:65L9"!N86UE<R!A<R!T:&5I<B!K97ES+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@0U-6(&1A=&$N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&5X<&]R=$1A=&$H)&1A=&$L("1H96%D97(@/2!F86QS92P@)&5X
M<&]R=%]M87!P:6YG(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H(6ES
M7V%R<F%Y*"1D871A*2!\?"!C;W5N="@D9&%T82D@/3T@,"D@>PH@("`@("`@
M("`@("!R971U<FX@)R<["B`@("`@("`@?0H*("`@("`@("`D97AP;W)T(#T@
M)R<["B`@("`@("`@)&5O;"`](")<;B(["B`@("`@("`@)&AE860@/2!A<G)A
M>5]K97ES*&-U<G)E;G0H)&1A=&$I*3L*("`@("`@("!I9B`H)&AE861E<BD@
M>PH@("`@("`@("`@("!F;W)E86-H("@D:&5A9"!A<R`D:V5Y*2!["B`@("`@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1K97DI*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1E>'!O<G1?;6%P<&EN9ULD:V5Y72DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&ME>2`]("1E>'!O<G1?;6%P<&EN9ULD
M:V5Y73L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@)&5X<&]R="`N/2`G(B<@+B`D:V5Y("X@)R(G.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)&5X<&]R="`N/2`G+"<["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&5X<&]R="`]('-U8G-T<B@D97AP;W)T+"`P
M+"`M,2D@+B`D96]L.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)&1A
M=&$@87,@)')O=RD@>PH@("`@("`@("`@("!F;W)E86-H("@D:&5A9"!A<R`D
M:V5Y*2!["B`@("`@("`@("`@("`@("`D8V5L;"`]("1R;W=;)&ME>5T["B`@
M("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1C96QL*2!\?"`D8V5L;"`]/3T@
M,"D@>PH@("`@("`@("`@("`@("`@("`@("1E>'!O<G0@+CT@)R(G("X@)&-E
M;&P@+B`G(B<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M97AP;W)T("X]("<L)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D97AP
M;W)T(#T@<W5B<W1R*"1E>'!O<G0L(#`L("TQ*2`N("1E;VP["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&5X<&]R=#L*("`@('T*"B`@("`O*BH*("`@
M("`J($)U:6QD<R!A($-35B!F:6QE(&9R;VT@82!G:79E;B!D871A('-T<G5C
M='5R92!A;F0@=')I9V=E<G,@:71S"B`@("`@*B!D;W=N;&]A9"X@($ET($1/
M15,@3D]4(&5X:70@=&AE(&-U<G)E;G0@<V-R:7!T(&)U="!O;FQY(&]U='!U
M=',@=&AE"B`@("`@*B!C;W)R96-T(&AE861E<G,@86YD(&1A=&$N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL96YA;64@(%1H92!N86UE(&]F
M('1H92!F:6QE('1O(&)E(&1O=VYL;V%D960N"B`@("`@*B!`<&%R86T@87)R
M87D@)&1A=&$@("`@("`@02!T=V\M9&EM96YS:6]N86P@87)R87D@8V]N=&%I
M;FEN9R!T:&4@9&%T80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M('-E="X*("`@("`J($!P87)A;2!B;V]L96%N("1H96%D97(@("!)9B!T<G5E
M+"!T:&4@<F]W<R!O9B`D9&%T82!A<F4@87-S;V-I871I=F4*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>7,@=VET:"!F:65L9"!N86UE
M<R!A<R!T:&5I<B!K97ES+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>'!O<G1&
M:6QE*"1F:6QE;F%M92P@)&1A=&$L("1H96%D97(@/2!F86QS92P*("`@("`@
M("`@("`@("`@("`@("`@("`@)&5X<&]R=%]M87!P:6YG(#T@87)R87DH*2D*
M("`@('L*("`@("`@("`D97AP;W)T(#T@)'1H:7,M/F5X<&]R=$1A=&$H)&1A
M=&$L("1H96%D97(L("1E>'!O<G1?;6%P<&EN9RD["B`@("`@("`@)$=,3T)!
M3%-;)V)R;W=S97(G72T^9&]W;FQO861(96%D97)S*"1F:6QE;F%M92P@)V%P
M<&QI8V%T:6]N+V-S=B<L(&9A;'-E+"!S=')L96XH)&5X<&]R="DI.PH@("`@
M("`@(&5C:&\@)&5X<&]R=#L*("`@('T*"B`@("`O*BH*("`@("`J(%1A:V5S
M(&%L;"!N96-E<W-A<GD@86-T:6]N<R!F;W(@=&AE(&=I=F5N(&EM<&]R="!S
M=&5P+"!P87)A;65T97)S(&%N9`H@("`@("H@9F]R;2!V86QU97,@86YD(')E
M='5R;G,@=&AE(&YE>'0@;F5C97-S87)Y('-T97`N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&%C=&EO;B`@5&AE(&-U<G)E;G0@<W1E<"X@3VYE
M(&]F('1H92!)35!/4E1?*B!C;VYS=&%N=',N"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M("`@("!!;B!A<W-O8VEA=&EV92!A<G)A>2!C;VYT86EN:6YG
M(&YE961E9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE
M=&5R<R!F;W(@=&AE(&-U<G)E;G0@<W1E<"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!%:71H97(@=&AE(&YE>'0@<W1E<"!A<R!A;B!I;G1E9V5R
M(&-O;G-T86YT(&]R(&EM<&]R=&5D"B`@("`@*B`@("`@("`@("`@("`@("!D
M871A('-E="!A9G1E<B!T:&4@9FEN86P@<W1E<"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@;F5X=%-T97`H)&%C=&EO;BP@)'!A<F%M(#T@87)R87DH*2D*("`@
M('L*("`@("`@("!S=VET8V@@*"1A8W1I;VXI('L*("`@("`@("!C87-E($E-
M4$]25%]&24Q%.@H@("`@("`@("`@("`D;F5X=%]S=&5P(#T@<&%R96YT.CIN
M97AT4W1E<"@D86-T:6]N+"`D<&%R86TI.PH@("`@("`@("`@("!I9B`H:7-?
M82@D;F5X=%]S=&5P+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)&YE>'1?<W1E<#L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+RH@36]V92!U<&QO861E9"!F:6QE('-O('1H870@=V4@8V%N(')E860@
M:70@86=A:6X@:6X@=&AE(&YE>'0*("`@("`@("`@("`@("`@<W1E<"!A9G1E
M<B!T:&4@=7-E<B!G879E('-O;64@9F]R;6%T(&1E=&%I;',N("HO"B`@("`@
M("`@("`@("1F:6QE7VYA;64@/2!(;W)D93HZ9V5T5&5M<$9I;&4H)VEM<&]R
M="<L(&9A;'-E*3L*("`@("`@("`@("`@:68@*"%M;W9E7W5P;&]A9&5D7V9I
M;&4H)%]&24Q%4ULG:6UP;W)T7V9I;&4G75LG=&UP7VYA;64G72P@)&9I;&5?
M;F%M92DI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB
M*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)%]315-324].6R=I;7!O
M<G1?9&%T82==6R=F:6QE7VYA;64G72`]("1F:6QE7VYA;64["@H@("`@("`@
M("`@("`O*B!4<GD@=&\@9&ES8V]V97(@=&AE(&9I;&4@9F]R;6%T(&]U<G-E
M;'9E<RX@*B\*("`@("`@("`@("`@)&-O;F8@/2`D=&AI<RT^9&ES8V]V97)&
M;W)M870H)&9I;&5?;F%M92D["B`@("`@("`@("`@(&EF("@A)&-O;F8I('L*
M("`@("`@("`@("`@("`@("1C;VYF(#T@87)R87DH)W-E<"<@/3X@)RPG*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D7U-%4U-)3TY;)VEM<&]R=%]D
M871A)UT@/2!A<G)A>5]M97)G92@D7U-%4U-)3TY;)VEM<&]R=%]D871A)UTL
M("1C;VYF*3L*"B`@("`@("`@("`@("\J($-H96-K(&EF(&-H87)S970@=V%S
M('-P96-I9FEE9"X@*B\*("`@("`@("`@("`@)%]315-324].6R=I;7!O<G1?
M9&%T82==6R=C:&%R<V5T)UT@/2!5=&EL.CIG971&;W)M1&%T82@G8VAA<G-E
M="<I.PH*("`@("`@("`@("`@+RH@4F5A9"!T:&4@9FEL92=S(&9I<G-T('1W
M;R!L:6YE<R!T;R!S:&]W('1H96T@=&\@=&AE('5S97(N("HO"B`@("`@("`@
M("`@("1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9FER<W1?;&EN97,G72`]
M("<G.PH@("`@("`@("`@("`D9G`@/2!`9F]P96XH)&9I;&5?;F%M92P@)W(G
M*3L*("`@("`@("`@("`@:68@*"1F<"D@>PH@("`@("`@("`@("`@("`@)&QI
M;F5?;F\@/2`Q.PH@("`@("`@("`@("`@("`@=VAI;&4@*"1L:6YE7VYO(#P@
M,R`F)B`D;&EN92`](&9G971S*"1F<"DI('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG8VAA<G-E
M="==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;&EN92`](%-T<FEN
M9SHZ8V]N=F5R=$-H87)S970H)&QI;F4L("1?4T534TE/3ELG:6UP;W)T7V1A
M=&$G75LG8VAA<G-E="==+"!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1N97=L:6YE(#T@
M4W1R:6YG.CIL96YG=&@H)&QI;F4I(#X@,3`P(#\@(EQN(B`Z("<G.PH@("`@
M("`@("`@("`@("`@("`@("1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9FER
M<W1?;&EN97,G72`N/2!S=6)S='(H)&QI;F4L(#`L(#$P,"D@+B`D;F5W;&EN
M93L*("`@("`@("`@("`@("`@("`@("`D;&EN95]N;RLK.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B!)35!/
M4E1?0U-6.PH*("`@("`@("!C87-E($E-4$]25%]#4U8Z"B`@("`@("`@("`@
M("1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG:&5A9&5R)UT@/2!5=&EL.CIG
M971&;W)M1&%T82@G:&5A9&5R)RD["B`@("`@("`@("`@("1I;7!O<G1?;6%P
M<&EN9R`](&%R<F%Y*"D["B`@("`@("`@("`@(&EF("AI<W-E="@D<&%R86U;
M)VEM<&]R=%]M87!P:6YG)UTI*2!["B`@("`@("`@("`@("`@("`D:6UP;W)T
M7VUA<'!I;F<@/2`D<&%R86U;)VEM<&]R=%]M87!P:6YG)UT["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&EM<&]R=%]D871A(#T@)'1H:7,M/FEM<&]R
M=$9I;&4H)%]315-324].6R=I;7!O<G1?9&%T82==6R=F:6QE7VYA;64G72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)%]315-324].6R=I;7!O<G1?9&%T82==6R=H96%D97(G72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@571I;#HZ9V5T
M1F]R;41A=&$H)W-E<"<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!5=&EL.CIG971&;W)M1&%T82@G<75O=&4G*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M571I;#HZ9V5T1F]R;41A=&$H)V9I96QD<R<I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:6UP;W)T7VUA<'!I;F<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG8VAA<G-E="==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D7U-%4U-)
M3TY;)VEM<&]R=%]D871A)UU;)V-R;&8G72D["B`@("`@("`@("`@("1?4T53
M4TE/3ELG:6UP;W)T7V1A=&$G75LG9&%T82==(#T@)&EM<&]R=%]D871A.PH@
M("`@("`@("`@("!U;G-E="@D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)VUA
M<"==*3L*("`@("`@("`@("`@<F5T=7)N($E-4$]25%]-05!0140["@H@("`@
M("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B!P87)E;G0Z.FYE>'13
M=&5P*"1A8W1I;VXL("1P87)A;2D["B`@("`@("`@?0H@("`@?0H*?0H`````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O1&%T82]I8V%L96YD87(N<&AP````````````````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`Q,C`W`#$P-3$U-#,S-S0V`#`R,C<W,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M+RHJ(%=E(')E;'D@;VX@=&AE($AO<F1E7T1A=&%?:6UC.CH@86)S=')A8W0@
M8VQA<W,N("HO"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O
M:6UC+G!H<"<["@HO*BH*("H@5&AI<R!I<R!I0V%L96YD87(@*'9#86QE;F1A
M<BDN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T1A=&$O1&%T82]I8V%L96YD
M87(N<&AP+'8@,2XS,2XQ,"XS(#(P,#8O,#$O,#$@,C$Z,C@Z,3,@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO
M<B`@2V%R<W1E;B!&;W5R;6]N="`\9F]U<FUO;G1`:&]R9&4N;W)G/@H@*B!`
M<&%C:V%G92!(;W)D95]$871A"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B\*
M8VQA<W,@2&]R9&5?1&%T85]I8V%L96YD87(@97AT96YD<R!(;W)D95]$871A
M7VEM8R!["@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O1&%T82]I;6,N<&AP````````````````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-#(W`#$P-3$U-#,S-S0V`#`R,38S
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92]I0V%L96YD87(N<&AP)SL*"B\J
M*@H@*B!!8G-T<F%C="!I;7!L96UE;G1A=&EO;B!O9B!T:&4@2&]R9&5?1&%T
M83HZ($%022!F;W(@24U#(&1A=&$@+0H@*B!V0V%R9',@86YD(&E#86QE;F1A
M<B!D871A+"!E=&,N(%!R;W9I9&5S(&$@;G5M8F5R(&]F('5T:6QI='D*("H@
M;65T:&]D<R!T:&%T('9#87)D(&%N9"!I0V%L96YD87(@:6UP;&5M96YT871I
M;VX@8V%N('-H87)E(&%N9"!R96QY"B`J(&]N+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<"QV(#$N,S(N,3`N."`R,#`V+S`U
M+S`Y(#(S.C`V.C`Y(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY
M+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO
M<F<^"B`J($!P86-K86=E($AO<F1E7T1A=&$*("H@0'-I;F-E("`@2&]R9&4@
M,RXP"B`J+PIC;&%S<R!(;W)D95]$871A7VEM8R!E>'1E;F1S($AO<F1E7T1A
M=&$@>PH*("`@('9A<B`D7VE#86P@/2!F86QS93L*"B`@("!F=6YC=&EO;B!I
M;7!O<G1$871A*"1T97AT*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:4-A;"`]
M(&YE=R!(;W)D95]I0V%L96YD87(H*3L*("`@("`@("!I9B`H(21T:&ES+3Y?
M:4-A;"T^<&%R<V5V0V%L96YD87(H)'1E>'0I*2!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(I*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=&AI<RT^7VE#86PM/F=E=$-O;7!O;F5N=',H*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($)U:6QD<R!A;B!I0V%L96YD87(@9FEL
M92!F<F]M(&$@9VEV96X@9&%T82!S=')U8W1U<F4@86YD"B`@("`@*B!R971U
M<FYS(&ET(&%S(&$@<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`D9&%T82`@("`@06X@87)R87D@8V]N=&%I;FEN9R!(;W)D95]I0V%L96YD
M87)?=F5V96YT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&]B:F5C
M=',*("`@("`J($!P87)A;2!S=')I;F<@)&UE=&AO9"`@5&AE(&E4:7`@;65T
M:&]D('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(&E#86QE;F1A<B!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>'!O<G1$
M871A*"1D871A+"`D;65T:&]D(#T@)U)%455%4U0G*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?:4-A;"`](&YE=R!(;W)D95]I0V%L96YD87(H*3L*("`@("`@
M("`D=&AI<RT^7VE#86PM/G-E=$%T=')I8G5T92@G34542$]$)RP@)&UE=&AO
M9"D["@H@("`@("`@(&9O<F5A8V@@*"1D871A(&%S("1E=F5N="D@>PH@("`@
M("`@("`@("`D=&AI<RT^7VE#86PM/F%D9$-O;7!O;F5N="@D979E;G0I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?:4-A;"T^97AP;W)T
M=D-A;&5N9&%R*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9',@86X@
M:4-A;&5N9&%R(&9I;&4@9G)O;2!A(&=I=F5N(&1A=&$@<W1R=6-T=7)E(&%N
M9`H@("`@("H@=')I9V=E<G,@:71S(&1O=VYL;V%D+B`@270@1$]%4R!.3U0@
M97AI="!T:&4@8W5R<F5N="!S8W)I<'0@8G5T"B`@("`@*B!O;FQY(&]U='!U
M=',@=&AE(&-O<G)E8W0@:&5A9&5R<R!A;F0@9&%T82X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1F:6QE;F%M92`@(%1H92!N86UE(&]F('1H92!F
M:6QE('1O(&)E(&1O=VYL;V%D960N"B`@("`@*B!`<&%R86T@87)R87D@)&1A
M=&$@("`@("`@($%N(&%R<F%Y(&-O;G1A:6YI;F<@2&]R9&5?:4-A;&5N9&%R
M7W9E=F5N=',*("`@("`J+PH@("`@9G5N8W1I;VX@97AP;W)T1FEL92@D9FEL
M96YA;64L("1D871A*0H@("`@>PH@("`@("`@("1E>'!O<G0@/2`D=&AI<RT^
M97AP;W)T1&%T82@D9&%T82D["B`@("`@("`@)$=,3T)!3%-;)V)R;W=S97(G
M72T^9&]W;FQO861(96%D97)S*"1F:6QE;F%M92P@)W1E>'0O8V%L96YD87(G
M+"!F86QS92P@<W1R;&5N*"1E>'!O<G0I*3L*("`@("`@("!E8VAO("1E>'!O
M<G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!486ME<R!A;&P@;F5C97-S87)Y
M(&%C=&EO;G,@9F]R('1H92!G:79E;B!I;7!O<G0@<W1E<"P*("`@("`J('!A
M<F%M971E<G,@86YD(&9O<FT@=F%L=65S(&%N9"!R971U<FYS('1H92!N97AT
M(&YE8V5S<V%R>2!S=&5P+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R
M("1A8W1I;VX@(%1H92!C=7)R96YT('-T97`N($]N92!O9B!T:&4@24U03U)4
M7RH@8V]N<W1A;G1S+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;2`@("`@
M06X@87-S;V-I871I=F4@87)R87D@8V]N=&%I;FEN9R!N965D960*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E<G,@9F]R('1H92!C
M=7)R96YT('-T97`N"B`@("`@*B!`<F5T=7)N(&UI>&5D("!%:71H97(@=&AE
M(&YE>'0@<W1E<"!A<R!A;B!I;G1E9V5R(&-O;G-T86YT(&]R(&EM<&]R=&5D
M"B`@("`@*B`@("`@("`@("`@("`@("!D871A('-E="!A9G1E<B!T:&4@9FEN
M86P@<W1E<"X*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=%-T97`H)&%C=&EO
M;BP@)'!A<F%M(#T@87)R87DH*2D*("`@('L*("`@("`@("!S=VET8V@@*"1A
M8W1I;VXI('L*("`@("`@("!C87-E($E-4$]25%]&24Q%.@H@("`@("`@("`@
M("`D;F5X=%]S=&5P(#T@<&%R96YT.CIN97AT4W1E<"@D86-T:6]N+"`D<&%R
M86TI.PH@("`@("`@("`@("!I9B`H:7-?82@D;F5X=%]S=&5P+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&YE>'1?<W1E<#L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&EM<&]R=%]D871A(#T@)'1H
M:7,M/FEM<&]R=$9I;&4H)%]&24Q%4ULG:6UP;W)T7V9I;&4G75LG=&UP7VYA
M;64G72D["B`@("`@("`@("`@(&EF("AI<U]A*"1I;7!O<G1?9&%T82P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1I;7!O<G1?
M9&%T83L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?:4-A;"T^9V5T0V]M<&]N96YT<R@I.PH@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N('!A<F5N=#HZ
M;F5X=%-T97`H)&%C=&EO;BP@)'!A<F%M*3L*("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@?0H@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&$O;W5T;&]O:V-S=BYP:'``````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S0R,P`Q,#4Q-30S,S<T-@`P,C,R
M-C,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O1&%T82]C<W8N<&AP)SL*"B\J
M*@H@*B!(;W)D95]$871A(&EM<&QE;65N=&%T:6]N(&9O<B!/=71L;V]K(&-O
M;6UA+7-E<&%R871E9"!D871A("A#4U8I+@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]$871A+T1A=&$O;W5T;&]O:V-S=BYP:'`L=B`Q+C,N,3`N,R`R,#`U
M+S$P+S$X(#$Q.C`Q.C`T(&IA;B!%>'`@)`H@*@H@*B!`<&%C:V%G92!(;W)D
M95]$871A"B`J+PIC;&%S<R!(;W)D95]$871A7V]U=&QO;VMC<W8@97AT96YD
M<R!(;W)D95]$871A7V-S=B!["@H@("`@+RHJ"B`@("`@*B!"=6EL9',@82!#
M4U8@9FEL92!F<F]M(&$@9VEV96X@9&%T82!S=')U8W1U<F4@86YD(')E='5R
M;G,@:70@87,@80H@("`@("H@<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`@("1D871A("`@("`@($$@='=O+61I;65N<VEO;F%L(&%R<F%Y
M(&-O;G1A:6YI;F<@=&AE(&1A=&$*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('-E="X*("`@("`J($!P87)A;2!B;V]L96%N("1H96%D97(@
M("`@($EF('1R=64L('1H92!R;W=S(&]F("1D871A(&%R92!A<W-O8VEA=&EV
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87ES('=I
M=&@@9FEE;&0@;F%M97,@87,@=&AE:7(@:V5Y<RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE($-35B!D871A+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!E>'!O<G1$871A*"1D871A+"`D:&5A9&5R(#T@9F%L<V4L("1E>'!O
M<G1?;6%P<&EN9R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%I<U]A
M<G)A>2@D9&%T82D@?'P@8V]U;G0H)&1A=&$I(#T](#`I('L*("`@("`@("`@
M("`@<F5T=7)N("<G.PH@("`@("`@('T*"B`@("`@("`@)&5X<&]R="`]("<G
M.PH@("`@("`@("1E;VP@/2`B7')<;B(["B`@("`@("`@)&AE860@/2!A<G)A
M>5]K97ES*&-U<G)E;G0H)&1A=&$I*3L*("`@("`@("!I9B`H)&AE861E<BD@
M>PH@("`@("`@("`@("!F;W)E86-H("@D:&5A9"!A<R`D:V5Y*2!["B`@("`@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1K97DI*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1E>'!O<G1?;6%P<&EN9ULD:V5Y72DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&ME>2`]("1E>'!O<G1?;6%P<&EN9ULD
M:V5Y73L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@)&5X<&]R="`N/2`G(B<@+B`D:V5Y("X@)R(G.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)&5X<&]R="`N/2`G+"<["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&5X<&]R="`]('-U8G-T<B@D97AP;W)T+"`P
M+"`M,2D@+B`D96]L.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)&1A
M=&$@87,@)')O=RD@>PH@("`@("`@("`@("!F;W)E86-H("@D:&5A9"!A<R`D
M:V5Y*2!["B`@("`@("`@("`@("`@("`D8V5L;"`]("1R;W=;)&ME>5T["B`@
M("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1C96QL*2!\?"`D8V5L;"`]/3T@
M,"D@>PH@("`@("`@("`@("`@("`@("`@("1C96QL(#T@<')E9U]R97!L86-E
M*"(O7"(O(BP@(EPB7"(B+"`D8V5L;"D["B`@("`@("`@("`@("`@("`@("`@
M)&5X<&]R="`N/2`G(B<@+B`D8V5L;"`N("<B)SL*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1E>'!O<G0@+CT@)RPG.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1E>'!O<G0@/2!S=6)S='(H)&5X<&]R="P@,"P@
M+3$I("X@)&5O;#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D97AP;W)T
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B](;W)D92]$871A+W1S=BYP:'``````````````````````````
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,C$P,S,`,3`U,34T,S,W-#8`,#(Q-C8T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!(;W)D95]$871A(&EM<&QE;65N=&%T:6]N(&9O<B!T86(M<V5P
M87)A=&5D(&1A=&$@*%135BDN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T1A
M=&$O1&%T82]T<W8N<&AP+'8@,2XR,RXQ,"XQ,"`R,#`V+S`X+S`S(#`R.C4P
M.C0P('-E;'-K>2!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IA
M;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@
M*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`
M875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@
M0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7T1A=&$*("HO
M"F-L87-S($AO<F1E7T1A=&%?='-V(&5X=&5N9',@2&]R9&5?1&%T82!["@H@
M("`@=F%R("1?97AT96YS:6]N(#T@)W1S=B<["B`@("!V87(@)%]C;VYT96YT
M5'EP92`]("=T97AT+W1A8BUS97!A<F%T960M=F%L=65S)SL*"B`@("!F=6YC
M=&EO;B!I;7!O<G1$871A*"1C;VYT96YT<RP@)&AE861E<B`](&9A;'-E+"`D
M9&5L:6UI=&5R(#T@(EQT(BD*("`@('L*("`@("`@("`D8V]N=&5N=',@/2!E
M>'!L;V1E*")<;B(L("1C;VYT96YT<RD["B`@("`@("`@)&1A=&$@/2!A<G)A
M>2@I.PH@("`@("`@(&EF("@D:&5A9&5R*2!["B`@("`@("`@("`@("1H96%D
M(#T@97AP;&]D92@D9&5L:6UI=&5R+"!A<G)A>5]S:&EF="@D8V]N=&5N=',I
M*3L*("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H)&-O;G1E;G1S(&%S("1L
M:6YE*2!["B`@("`@("`@("`@(&EF("AT<FEM*"1L:6YE*2`]/2`G)RD@>PH@
M("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&QI;F4@/2!E>'!L;V1E*"1D96QI;6ET97(L("1L:6YE*3L*("`@
M("`@("`@("`@:68@*"%I<W-E="@D:&5A9"DI('L*("`@("`@("`@("`@("`@
M("1D871A6UT@/2`D;&EN93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1N97=L:6YE(#T@87)R87DH*3L*("`@("`@("`@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1H96%D*3L@)&DK*RD@>PH@("`@
M("`@("`@("`@("`@("`@("1N97=L:6YE6R1H96%D6R1I75T@/2!E;7!T>2@D
M;&EN95LD:5TI(#\@)R<@.B`D;&EN95LD:5T["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`D9&%T85M=(#T@)&YE=VQI;F4["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1D871A.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0G5I;&1S(&$@5%-6(&9I;&4@9G)O;2!A(&=I=F5N
M(&1A=&$@<W1R=6-T=7)E(&%N9"!R971U<FYS(&ET(&%S(&$*("`@("`J('-T
M<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&1A=&$@("`@("!!
M('1W;RUD:6UE;G-I;VYA;"!A<G)A>2!C;VYT86EN:6YG('1H92!D871A('-E
M="X*("`@("`J($!P87)A;2!B;V]L96%N("1H96%D97(@($EF('1R=64L('1H
M92!R;W=S(&]F("1D871A(&%R92!A<W-O8VEA=&EV90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87ES('=I=&@@9FEE;&0@;F%M97,@87,@
M=&AE:7(@:V5Y<RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(%135B!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>'!O<G1$871A*"1D
M871A+"`D:&5A9&5R(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"%I<U]A
M<G)A>2@D9&%T82D@?'P@8V]U;G0H)&1A=&$I(#T](#`I('L*("`@("`@("`@
M("`@<F5T=7)N("<G.PH@("`@("`@('T*("`@("`@("`D97AP;W)T(#T@)R<[
M"B`@("`@("`@)&AE860@/2!A<G)A>5]K97ES*&-U<G)E;G0H)&1A=&$I*3L*
M("`@("`@("!I9B`H)&AE861E<BD@>PH@("`@("`@("`@("`D97AP;W)T(#T@
M:6UP;&]D92@B7'0B+"`D:&5A9"D@+B`B7&XB.PH@("`@("`@('T*("`@("`@
M("!F;W)E86-H("@D9&%T82!A<R`D<F]W*2!["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1H96%D(&%S("1K97DI('L*("`@("`@("`@("`@("`@("1C96QL(#T@
M)')O=ULD:V5Y73L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&-E;&PI
M('Q\("1C96QL(#T]/2`P*2!["B`@("`@("`@("`@("`@("`@("`@)&5X<&]R
M="`N/2`D8V5L;#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("1E>'!O<G0@+CT@(EQT(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M97AP;W)T(#T@<W5B<W1R*"1E>'!O<G0L(#`L("TQ*2`N(")<;B(["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D97AP;W)T.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0G5I;&1S(&$@5%-6(&9I;&4@9G)O;2!A(&=I=F5N(&1A=&$@<W1R
M=6-T=7)E(&%N9"!T<FEG9V5R<R!I=',@9&]W;FQO860N"B`@("`@*B!)="!$
M3T53($Y/5"!E>&ET('1H92!C=7)R96YT('-C<FEP="!B=70@;VYL>2!O=71P
M=71S('1H92!C;W)R96-T(&AE861E<G,*("`@("`J(&%N9"!D871A+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&5N86UE("!4:&4@;F%M92!O
M9B!T:&4@9FEL92!T;R!B92!D;W=N;&]A9&5D+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1D871A("`@("`@($$@='=O+61I;65N<VEO;F%L(&%R<F%Y(&-O;G1A
M:6YI;F<@=&AE(&1A=&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("!S970N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D:&5A9&5R("`@268@=')U
M92P@=&AE(')O=W,@;V8@)&1A=&$@87)E(&%S<V]C:6%T:79E"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87ES('=I=&@@9FEE;&0@;F%M
M97,@87,@=&AE:7(@:V5Y<RX*("`@("`J+PH@("`@9G5N8W1I;VX@97AP;W)T
M1FEL92@D9FEL96YA;64L("1D871A+"`D:&5A9&5R(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@)&5X<&]R="`]("1T:&ES+3YE>'!O<G1$871A*"1D871A+"`D
M:&5A9&5R*3L*("`@("`@("`D1TQ/0D%,4ULG8G)O=W-E<B==+3YD;W=N;&]A
M9$AE861E<G,H)&9I;&5N86UE+"`G=&5X="]T86(M<V5P87)A=&5D+79A;'5E
M<R<L(&9A;'-E+"!S=')L96XH)&5X<&]R="DI.PH@("`@("`@(&5C:&\@)&5X
M<&]R=#L*("`@('T*"B`@("`O*BH*("`@("`J(%1A:V5S(&%L;"!N96-E<W-A
M<GD@86-T:6]N<R!F;W(@=&AE(&=I=F5N(&EM<&]R="!S=&5P+"!P87)A;65T
M97)S(&%N9`H@("`@("H@9F]R;2!V86QU97,@86YD(')E='5R;G,@=&AE(&YE
M>'0@;F5C97-S87)Y('-T97`N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&%C=&EO;B`@5&AE(&-U<G)E;G0@<W1E<"X@3VYE(&]F('1H92!)35!/
M4E1?*B!C;VYS=&%N=',N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M("`@
M("!!;B!A<W-O8VEA=&EV92!A<G)A>2!C;VYT86EN:6YG(&YE961E9`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R<R!F;W(@=&AE
M(&-U<G)E;G0@<W1E<"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!%
M:71H97(@=&AE(&YE>'0@<W1E<"!A<R!A;B!I;G1E9V5R(&-O;G-T86YT(&]R
M(&EM<&]R=&5D"B`@("`@*B`@("`@("`@("`@("`@("!D871A('-E="!A9G1E
M<B!T:&4@9FEN86P@<W1E<"X*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=%-T
M97`H)&%C=&EO;BP@)'!A<F%M(#T@87)R87DH*2D*("`@('L*("`@("`@("!S
M=VET8V@@*"1A8W1I;VXI('L*("`@("`@("!C87-E($E-4$]25%]&24Q%.@H@
M("`@("`@("`@("`D;F5X=%]S=&5P(#T@<&%R96YT.CIN97AT4W1E<"@D86-T
M:6]N+"`D<&%R86TI.PH@("`@("`@("`@("!I9B`H:7-?82@D;F5X=%]S=&5P
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&YE
M>'1?<W1E<#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1?4T53
M4TE/3ELG:6UP;W)T7V1A=&$G75LG9F]R;6%T)UT@/3T@)VUU;&)E<G)Y)R!\
M?`H@("`@("`@("`@("`@("`@)%]315-324].6R=I;7!O<G1?9&%T82==6R=F
M;W)M870G72`]/2`G<&EN92<I('L*("`@("`@("`@("`@("`@("1?4T534TE/
M3ELG:6UP;W)T7V1A=&$G75LG9&%T82==(#T@)'1H:7,M/FEM<&]R=$9I;&4H
M)%]&24Q%4ULG:6UP;W)T7V9I;&4G75LG=&UP7VYA;64G72D["B`@("`@("`@
M("`@("`@("`D9F]R;6%T(#T@)%]315-324].6R=I;7!O<G1?9&%T82==6R=F
M;W)M870G73L*("`@("`@("`@("`@("`@(&EF("@D9F]R;6%T(#T]("=M=6QB
M97)R>2<I('L*("`@("`@("`@("`@("`@("`@("`D87!P2V5Y<R`@/2!A<G)A
M>2@G86QI87,G+"`G;F%M92<L("=E;6%I;"<L("=C;VUP86YY)RP@)W=O<FM!
M9&1R97-S)RP@)W=O<FM0:&]N92<L("=H;VUE4&AO;F4G+"`G9F%X)RP@)VYO
M=&5S)RD["B`@("`@("`@("`@("`@("`@("`@)&1A=&%+97ES(#T@87)R87DH
M,"P@,2P@,BP@,RP@-"P@-2P@-BP@-RP@.2D["B`@("`@("`@("`@("`@("!]
M(&5L<V5I9B`H)&9O<FUA="`]/2`G<&EN92<I('L*("`@("`@("`@("`@("`@
M("`@("`D87!P2V5Y<R`](&%R<F%Y*"=A;&EA<R<L("=N86UE)RP@)V5M86EL
M)RP@)VYO=&5S)RD["B`@("`@("`@("`@("`@("`@("`@)&1A=&%+97ES(#T@
M87)R87DH,"P@,2P@,BP@-"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!F;W)E86-H("@D87!P2V5Y<R!A<R`D:V5Y(#T^("1A<'`I('L*
M("`@("`@("`@("`@("`@("`@("`D;6%P6R1D871A2V5Y<ULD:V5Y75T@/2`D
M87!P.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&1A=&$@
M/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)%]315-324].
M6R=I;7!O<G1?9&%T82==6R=D871A)UT@87,@)')O=RD@>PH@("`@("`@("`@
M("`@("`@("`@("1H87-H(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@
M("!I9B`H)&9O<FUA="`]/2`G;75L8F5R<GDG*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"(O7D=R<#HO(BP@)')O=ULP72DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@
M("1R;W=;,5T@/2!P<F5G7W)E<&QA8V4H)R]>*%M>+")=*RDL7',J*"XJ*20O
M)RP@)R0R("0Q)RP@)')O=ULQ72D["B`@("`@("`@("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1D871A2V5Y<R!A<R`D:V5Y*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@D:V5Y+"`D<F]W
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1H87-H6R1K
M97E=(#T@<W1R:7!S;&%S:&5S*'!R96=?<F5P;&%C92@G+UQ<7%QR+R<L(")<
M;B(L("1R;W=;)&ME>5TI*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@('T@96QS96EF("@D9F]R;6%T(#T]("=P:6YE)RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H8V]U;G0H)')O=RD@/"`S('Q\('!R96=?;6%T
M8V@H(B]>(T1%3$54140O(BP@)')O=ULP72D@?'P@<')E9U]M871C:"@B+ULH
M*5TO(BP@)')O=ULR72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@("`@("1R;W=;,5T@/2!P<F5G7W)E<&QA8V4H)R]>*%M>
M+")=*RDL7',J*"XJ*20O)RP@)R0R("0Q)RP@)')O=ULQ72D["B`@("`@("`@
M("`@("`@("`@("`@("`@("\J($%D9')E<W,@8V%N(&)E(&$@9G5L;"!21D,X
M,C(@861D<F5S<R`J+PH@("`@("`@("`@("`@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)TUA:6PO4D9#.#(R+G!H<"<["B`@("`@("`@("`@("`@("`@("`@
M("`@("1A9&1R7V%R<B`]($UA:6Q?4D9#.#(R.CIP87)S94%D9')E<W-,:7-T
M*"1R;W=;,ETI.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H96UP='DH
M)&%D9')?87)R6S!=+3YM86EL8F]X*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`@("`@)')O=ULR72`]("1A9&1R7V%R<ELP
M72T^;6%I;&)O>"`N("=`)R`N("1A9&1R7V%R<ELP72T^:&]S=#L*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1R;W=;,5TI("8F("%E;7!T
M>2@D861D<E]A<G);,%TM/G!E<G-O;F%L*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)')O=ULQ72`]("1A9&1R7V%R<ELP72T^<&5R<V]N86P[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)&1A=&%+97ES(&%S("1K97DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"1K97DL
M("1R;W<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&AA
M<VA;)&ME>5T@/2`D<F]W6R1K97E=.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1D871A6UT@/2`D:&%S
M:#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1?4T534TE/
M3ELG:6UP;W)T7V1A=&$G75LG9&%T82==(#T@)&1A=&$["B`@("`@("`@("`@
M("`@("`D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)VUA<"==(#T@)&UA<#L*
M("`@("`@("`@("`@("`@("1R970@/2`D=&AI<RT^;F5X=%-T97`H24U03U)4
M7T1!5$$L("1P87)A;2D["B`@("`@("`@("`@("`@("!R971U<FX@)')E=#L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@36]V92!U<&QO861E9"!F
M:6QE('-O('1H870@=V4@8V%N(')E860@:70@86=A:6X@:6X@=&AE(&YE>'0@
M<W1E<`H@("`@("`@("`@("`@("!A9G1E<B!T:&4@=7-E<B!G879E('-O;64@
M9F]R;6%T(&1E=&%I;',N("HO"B`@("`@("`@("`@("1U<&QO861E9"`]($)R
M;W=S97(Z.G=A<T9I;&55<&QO861E9"@G:6UP;W)T7V9I;&4G+"!?*")44U8@
M9FEL92(I*3L*("`@("`@("`@("`@:68@*&ES7V$H)'5P;&]A9&5D+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@D=7!L;V%D960M/F=E=$UE<W-A9V4H*2D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)&9I;&5?;F%M92`]($AO<F1E.CIG971496UP1FEL
M92@G:6UP;W)T)RP@9F%L<V4I.PH@("`@("`@("`@("!I9B`H(6UO=F5?=7!L
M;V%D961?9FEL92@D7T9)3$536R=I;7!O<G1?9FEL92==6R=T;7!?;F%M92==
M+"`D9FEL95]N86UE*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E
M('-A=F5D+B(I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D7U-%4U-)
M3TY;)VEM<&]R=%]D871A)UU;)V9I;&5?;F%M92==(#T@)&9I;&5?;F%M93L*
M"B`@("`@("`@("`@("\J(%)E860@=&AE(&9I;&4G<R!F:7)S="!T=V\@;&EN
M97,@=&\@<VAO=R!T:&5M('1O('1H92!U<V5R+B`J+PH@("`@("`@("`@("`D
M7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V9I<G-T7VQI;F5S)UT@/2`G)SL*
M("`@("`@("`@("`@)&9P(#T@0&9O<&5N*"1F:6QE7VYA;64L("=R)RD["B`@
M("`@("`@("`@(&EF("@D9G`I('L*("`@("`@("`@("`@("`@("1L:6YE7VYO
M(#T@,3L*("`@("`@("`@("`@("`@('=H:6QE("@D;&EN95]N;R`\(#,@)B8@
M)&QI;F4@/2!F9V5T<R@D9G`I*2!["B`@("`@("`@("`@("`@("`@("`@)&YE
M=VQI;F4@/2!3=')I;F<Z.FQE;F=T:"@D;&EN92D@/B`Q,#`@/R`B7&XB(#H@
M)R<["B`@("`@("`@("`@("`@("`@("`@)%]315-324].6R=I;7!O<G1?9&%T
M82==6R=F:7)S=%]L:6YE<R==("X]('-U8G-T<B@D;&EN92P@,"P@,3`P*2`N
M("1N97=L:6YE.PH@("`@("`@("`@("`@("`@("`@("1L:6YE7VYO*RL["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T
M=7)N($E-4$]25%]44U8["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C
M87-E($E-4$]25%]44U8Z"B`@("`@("`@("`@("1?4T534TE/3ELG:6UP;W)T
M7V1A=&$G75LG:&5A9&5R)UT@/2!5=&EL.CIG971&;W)M1&%T82@G:&5A9&5R
M)RD["B`@("`@("`@("`@("1I;7!O<G1?9&%T82`]("1T:&ES+3YI;7!O<G1&
M:6QE*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9FEL95]N86UE)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1?
M4T534TE/3ELG:6UP;W)T7V1A=&$G75LG:&5A9&5R)UTI.PH@("`@("`@("`@
M("`D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V1A=&$G72`]("1I;7!O<G1?
M9&%T83L*("`@("`@("`@("`@=6YS970H)%]315-324].6R=I;7!O<G1?9&%T
M82==6R=M87`G72D["B`@("`@("`@("`@(')E='5R;B!)35!/4E1?34%04$5$
M.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@<F5T=7)N('!A<F5N=#HZ;F5X=%-T97`H)&%C=&EO;BP@)'!A<F%M
M*3L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&$O=F-A<F0N<&AP````````````
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$T,P`Q,#4Q-30S,S<T-@`P
M,C(Q-3``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O
M:6UC+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O:4-A;&5N9&%R+G!H<"<[
M"@HO*BH*("H@26UP;&5M96YT('1H92!(;W)D95]$871A.CH@05!)(&9O<B!V
M0V%R9"!D871A+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]$871A+T1A=&$O
M=F-A<F0N<&AP+'8@,2XS,RXQ,"XW(#(P,#8O,#$O,#$@,C$Z,C@Z,3,@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F%N(%-C:&YE:61E
M<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO
M<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]$871A"B`J+PIC;&%S<R!(;W)D
M95]$871A7W9C87)D(&5X=&5N9',@2&]R9&5?1&%T85]I;6,@>PH*("`@("\J
M*@H@("`@("H@17AP;W)T<R!V8V%L96YD87(@9&%T82!A<R!A('-T<FEN9RX@
M56YL:6ME('9%=F5N="P@=D-A<F0@9&%T80H@("`@("H@:7,@;F]T(&5N8VQO
M<V5D(&EN($)%1TE.?$5.1#IV0V%L96YD87(N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1D871A("`@("!!;B!A<G)A>2!C;VYT86EN:6YG($AO<F1E
M7VE#86QE;F1A<E]V8V%R9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("!O8FIE8W1S+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65T:&]D("!4:&4@
M:51I<"!M971H;V0@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@:4-A;&5N9&%R(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&5X<&]R=$1A=&$H)&1A=&$L("1M971H;V0@/2`G4D5154535"<I"B`@("![
M"B`@("`@("`@)',@/2`G)SL*("`@("`@("!F;W)E86-H("@D9&%T82!A<R`D
M=F-A<F0I('L*("`@("`@("`@("`@)',N/2`D=F-A<F0M/F5X<&]R='9#86QE
M;F1A<B@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)',["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M1&%T82]V;F]T92YP:'``````````````````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R,S<R`#$P-3$U-#,S-S0V`#`R,C(Q,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E
M(&1I<FYA;64H7U]&24Q%7U\I("X@)R]I;6,N<&AP)SL*"B\J*@H@*B!);7!L
M96UE;G0@=&AE($AO<F1E7T1A=&$Z.B!!4$D@9F]R('9.;W1E(&1A=&$N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+T1A=&$O1&%T82]V;F]T92YP:'`L=B`Q
M+C@N,3`N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C$S(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,3DY.2TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO
M<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@
M2&]R9&5?1&%T80H@*B!`<VEN8V4@("!(;W)D92`S+C`*("HO"F-L87-S($AO
M<F1E7T1A=&%?=FYO=&4@97AT96YD<R!(;W)D95]$871A7VEM8R!["@H@("`@
M+RHJ"B`@("`@*B!%>'!O<G1S('9C86QE;F1A<B!D871A(&%S(&$@<W1R:6YG
M+B!5;FQI:V4@=D5V96YT+"!V3F]T92!D871A"B`@("`@*B!I<R!N;W0@96YC
M;&]S960@:6X@0D5'24Y\14Y$.G9#86QE;F1A<BX*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)&1A=&$@("`@($%N(&%R<F%Y(&-O;G1A:6YI;F<@2&]R
M9&5?:4-A;&5N9&%R7W9N;W1E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@(&]B:F5C=',N"B`@("`@*B!`<&%R86T@<W1R:6YG("1M971H;V0@(%1H
M92!I5&EP(&UE=&AO9"!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!I0V%L96YD87(@9&%T82X*("`@("`J+PH@("`@9G5N8W1I
M;VX@97AP;W)T1&%T82@D9&%T82P@)&UE=&AO9"`]("=215%515-4)RD*("`@
M('L*("`@("`@("!G;&]B86P@)'!R969S.PH*("`@("`@("`D=&AI<RT^7VE#
M86P@/2`F;F5W($AO<F1E7VE#86QE;F1A<B@I.PH*("`@("`@("`D=&AI<RT^
M7VE#86PM/G-E=$%T=')I8G5T92@G34542$]$)RP@)&UE=&AO9"D["B`@("`@
M("`@)',@/2`G)SL*("`@("`@("!F;W)E86-H("@D9&%T82!A<R`D979E;G0I
M('L*("`@("`@("`@("`@)',N/2`D979E;G0M/F5X<&]R='9#86QE;F1A<B@I
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@)',["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]$871A+W9T;V1O+G!H<```````````
M````````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$R,C$`,3`U,34T,S,W-#8`
M,#(R,C`P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@HO*BH@5V4@<F5L>2!O;B!T:&4@2&]R9&5?1&%T85]I;6,Z
M.B!A8G-T<F%C="!C;&%S<RX@*B\*<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&
M24Q%7U\I("X@)R]I;6,N<&AP)SL*"B\J*@H@*B!);7!L96UE;G0@=&AE($AO
M<F1E7T1A=&$Z.B!!4$D@9F]R('94;V1O(&1A=&$N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+T1A=&$O1&%T82]V=&]D;RYP:'`L=B`Q+C@N,3`N,R`R,#`V
M+S`Q+S`Q(#(Q.C(X.C$S(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY
M.2TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($-O<'ER
M:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U
M8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@2&]R9&5?1&%T80H@
M*B!`<VEN8V4@("!(;W)D92`S+C`*("HO"F-L87-S($AO<F1E7T1A=&%?=G1O
M9&\@97AT96YD<R!(;W)D95]$871A7VEM8R!["@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]$871A+G!H<```````````
M````````````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S0U-C$`,3`U,34T
M,S,W-3$`,#(Q,#4V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*"B\O
M($EM<&]R="!C;VYS=&%N=',*+RHJ($EM<&]R="!A;')E861Y(&UA<'!E9"!C
M<W8@9&%T82X@("`@("`@("HO(&1E9FEN92@G24U03U)47TU!4%!%1"<L(#$I
M.PHO*BH@36%P(&1A=&4@86YD('1I;64@96YT<FEE<R!O9B!C<W8@9&%T82X@
M*B\@9&5F:6YE*"=)35!/4E1?1$%4151)344G+"`R*3L*+RHJ($EM<&]R="!G
M96YE<FEC($-35B!D871A+B`@("`@("`@("`@("`@("HO(&1E9FEN92@G24U0
M3U)47T-35B<L(#,I.PHO*BH@26UP;W)T($U3($]U=&QO;VL@9&%T82X@("`@
M("`@("`@("`@("`@*B\@9&5F:6YE*"=)35!/4E1?3U543$]/2R<L(#0I.PHO
M*BH@26UP;W)T('9#86QE;F1A<B]I0V%L96YD87(@9&%T82X@("`@("`@*B\@
M9&5F:6YE*"=)35!/4E1?24-!3$5.1$%2)RP@-2D["B\J*B!);7!O<G0@=D-A
M<F1S+B`@("`@("`@("`@("`@("`@("`@("`@("`J+R!D969I;F4H)TE-4$]2
M5%]60T%21"<L(#8I.PHO*BH@26UP;W)T(&=E;F5R:6,@='-V(&1A=&$N("`@
M("`@("`@("`@("`@*B\@9&5F:6YE*"=)35!/4E1?5%-6)RP@-RD["B\J*B!)
M;7!O<G0@375L8F5R<GD@861D<F5S<R!B;V]K(&1A=&$@("`@("`J+R!D969I
M;F4H)TE-4$]25%]-54Q"15)262<L(#@I.PHO*BH@26UP;W)T(%!I;F4@861D
M<F5S<R!B;V]K(&1A=&$N("`@("`@("`@*B\@9&5F:6YE*"=)35!/4E1?4$E.
M12<L(#DI.PHO*BH@26UP;W)T(&9I;&4N("`@("`@("`@("`@("`@("`@("`@
M("`@("`@*B\@9&5F:6YE*"=)35!/4E1?1DE,12<L(#$Q*3L*+RHJ($EM<&]R
M="!D871A+B`@("`@("`@("`@("`@("`@("`@("`@("`@("HO(&1E9FEN92@G
M24U03U)47T1!5$$G+"`Q,BD["@HO+R!%>'!O<G0@8V]N<W1A;G1S"B\J*B!%
M>'!O<G0@9V5N97)I8R!#4U8@9&%T82X@*B\@9&5F:6YE*"=%6%!/4E1?0U-6
M)RP@,3`P*3L*+RHJ($5X<&]R="!I0V%L96YD87(@9&%T82X@("`J+R!D969I
M;F4H)T584$]25%])0T%,14Y$05(G+"`Q,#$I.PHO*BH@17AP;W)T('9#87)D
M<RX@("`@("`@("`@("HO(&1E9FEN92@G15A03U)47U9#05)$)RP@,3`R*3L*
M+RHJ($5X<&]R="!44U8@9&%T82X@("`@("`@("`J+R!D969I;F4H)T584$]2
M5%]44U8G+"`Q,#,I.PHO*BH@17AP;W)T($]U=&QO;VL@0U-6(&1A=&$N("HO
M(&1E9FEN92@G15A03U)47T]55$Q/3TM#4U8G+"`Q,#0I.PH*+RHJ"B`J($%B
M<W1R86-T(&-L87-S('1O(&AA;F1L92!D:69F97)E;G0@:VEN9',@;V8@1&%T
M82!F;W)M871S(&%N9"!T;PH@*B!H96QP(&1A=&$@97AC:&%N9V4@8F5T=V5E
M;B!(;W)D92!A<'!L:6-A=&EO;G,@86YD(&5X=&5R;F%L('-O=7)C97,N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`L=B`Q+C@P+C$P
M+C$R(#(P,#8O,#@O,#@@,3<Z,34Z,C(@:F%N($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`Q.3DY+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA
M;D!H;W)D92YO<F<^"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA
M9V4@2&]R9&5?1&%T80H@*B\*8VQA<W,@2&]R9&5?1&%T82!E>'1E;F1S(%!%
M05(@>PH*("`@('9A<B`D7V5X=&5N<VEO;CL*("`@('9A<B`D7V-O;G1E;G14
M>7!E(#T@)W1E>'0O<&QA:6XG.PH*("`@("\J*@H@("`@("H@02!L:7-T(&]F
M('=A<FYI;F=S(')A:7-E9"!D=7)I;F<@=&AE(&QA<W0@;W!E<F%T:6]N+@H@
M("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@("`J+PH@("`@=F%R
M("1?=V%R;FEN9W,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@4W1U8B!T
M;R!I;7!O<G0@<&%S<V5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EM
M<&]R=$1A=&$H*0H@("`@>PH@("`@?0H*("`@("\J*@H@("`@("H@4W1U8B!T
M;R!R971U<FX@97AP;W)T960@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@
M97AP;W)T1&%T82@I"B`@("!["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3='5B
M('1O(&EM<&]R="!A(&9I;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EM<&]R
M=$9I;&4H)&9I;&5N86UE+"`D:&5A9&5R(#T@9F%L<V4I"B`@("!["B`@("`@
M("`@)&1A=&$@/2!F:6QE7V=E=%]C;VYT96YT<R@D9FEL96YA;64I.PH@("`@
M("`@(')E='5R;B`D=&AI<RT^:6UP;W)T1&%T82@D9&%T82P@)&AE861E<BD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3='5B('1O(&5X<&]R="!D871A('1O
M(&$@9FEL92X*("`@("`J+PH@("`@9G5N8W1I;VX@97AP;W)T1FEL92@I"B`@
M("!["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4<FEE<R!T;R!D971E<FUI;F4@
M=&AE(&5X<&5C=&5D(&YE=VQI;F4@8VAA<F%C=&5R(&)A<V5D(&]N('1H90H@
M("`@("H@<&QA=&9O<FT@:6YF;W)M871I;VX@<&%S<V5D(&)Y('1H92!B<F]W
M<V5R)W,@86=E;G0@:&5A9&5R+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@9W5E<W-E9"!E>'!E8W1E9"!N97=L:6YE(&-H87)A8W1E<G,L
M(&5I=&AE<B!<;BP@7'(*("`@("`J("`@("`@("`@("`@("`@("!O<B!<<EQN
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971.97=L:6YE*"D*("`@('L*("`@
M("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T)R;W=S97(N<&AP)SL*("`@("`@
M("`D8G)O=W-E<B`]("9"<F]W<V5R.CIS:6YG;&5T;VXH*3L*"B`@("`@("`@
M<W=I=&-H("@D8G)O=W-E<BT^9V5T4&QA=&9O<FTH*2D@>PH@("`@("`@(&-A
M<V4@)W=I;B<Z"B`@("`@("`@("`@(')E='5R;B`B7')<;B(["@H@("`@("`@
M(&-A<V4@)VUA8R<Z"B`@("`@("`@("`@(')E='5R;B`B7'(B.PH*("`@("`@
M("!C87-E("=U;FEX)SH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!R
M971U<FX@(EQN(CL*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M1FEL96YA;64H)&)A<V5N86UE*0H@("`@>PH@("`@("`@(')E='5R;B`D8F%S
M96YA;64@+B`G+B<@+B`D=&AI<RT^7V5X=&5N<VEO;CL*("`@('T*"B`@("!F
M=6YC=&EO;B!G971#;VYT96YT5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?8V]N=&5N=%1Y<&4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&$@;&ES="!O9B!W87)N:6YG<R!T:&%T(&AA=F4@8F5E;B!R86ES
M960@9'5R:6YG('1H92!L87-T"B`@("`@*B!O<&5R871I;VXN"B`@("`@*@H@
M("`@("H@0'-I;F-E($AO<F1E(#,N,0H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@($$@*'!O<W-I8FQY(&5M<'1Y*2!L:7-T(&]F('=A<FYI;F=S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!W87)N:6YG<R@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?=V%R;FEN9W,["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!(;W)D95]$871A(&EN
M<W1A;F-E(&)A<V5D(&]N("1F;W)M870N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&UI>&5D("1F;W)M870@(%1H92!T>7!E(&]F(&-O;F-R971E($AO<F1E7T1A
M=&$@<W5B8VQA<W,@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FXN($EF("1F;W)M870@:7,@86X@87)R87DL('1H96X@=V4@=VEL;"!L
M;V]K"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:6X@)&9O<FUA=%LP
M72]L:6(O1&%T82\@9F]R('1H92!S=6)C;&%S<PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(&EM<&QE;65N=&%T:6]N(&YA;65D("1F;W)M871;,5TN
M<&AP+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?1&%T82`@5&AE(&YE
M=VQY(&-R96%T960@8V]N8W)E=&4@2&]R9&5?1&%T82!I;G-T86YC92P@;W(*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@9F%L<V4@;VX@86X@97)R;W(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1F;W)M870I"B`@("![
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1F;W)M870I*2!["B`@("`@("`@("`@
M("1A<'`@/2`D9F]R;6%T6S!=.PH@("`@("`@("`@("`D9F]R;6%T(#T@)&9O
M<FUA=%LQ73L*("`@("`@("!]"@H@("`@("`@("1F;W)M870@/2!B87-E;F%M
M92@D9F]R;6%T*3L*"B`@("`@("`@:68@*&5M<'1Y*"1F;W)M870I('Q\("AS
M=')C;7`H)&9O<FUA="P@)VYO;F4G*2`]/2`P*2D@>PH@("`@("`@("`@("`D
M9&%T82`])B!N97<@2&]R9&5?1&%T82@I.PH@("`@("`@("`@("!R971U<FX@
M)&1A=&$["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1A<'`I*2![
M"B`@("`@("`@("`@(')E<75I<F5?;VYC92`D1TQ/0D%,4ULG<F5G:7-T<GDG
M72T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]L:6(O1&%T82\G("X@)&9O
M<FUA="`N("<N<&AP)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+T1A=&$O)R`N("1F;W)M870@+B`G+G!H<"<[
M"B`@("`@("`@?0H@("`@("`@("1C;&%S<R`]("=(;W)D95]$871A7R<@+B`D
M9F]R;6%T.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@
M("`@("`@("`@("`D9&%T82`])B!N97<@)&-L87-S*"D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&1A=&$@/2!014%2.CIR86ES945R<F]R*"=#
M;&%S<R!D969I;FET:6]N(&]F("<@+B`D8VQA<W,@+B`G(&YO="!F;W5N9"XG
M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9&%T83L*("`@('T*"B`@
M("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC92!T
M;R!A(&-O;F-R971E($AO<F1E7T1A=&$@:6YS=&%N8V4*("`@("`J(&)A<V5D
M(&]N("1F;W)M870N($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N
M8V4@:68@;F\@2&]R9&5?1&%T80H@("`@("H@:6YS=&%N8V4@=VET:"!T:&4@
M<V%M92!P87)A;65T97)S(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@("`@
M("H@5&AI<R!S:&]U;&0@8F4@=7-E9"!I9B!M=6QT:7!L92!D871A('-O=7)C
M97,@*&%N9"P@=&AU<RP@;75L=&EP;&4*("`@("`J($AO<F1E7T1A=&$@:6YS
M=&%N8V5S*2!A<F4@<F5Q=6ER960N"B`@("`@*@H@("`@("H@5&AI<R!M971H
M;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R(#T@)DAO<F1E7T1A=&$Z.G-I
M;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T
M("!4:&4@='EP92!O9B!C;VYC<F5T92!(;W)D95]$871A('-U8F-L87-S('1O
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N($AO<F1E7T1A=&$@(%1H92!C;VYC<F5T92!(;W)D
M95]$871A(')E9F5R96YC92P@;W(@9F%L<V4@;VX@86X*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S
M:6YG;&5T;VXH)&9O<FUA="D*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A
M;F-E<SL*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97,I*2!["B`@("`@
M("`@("`@("1I;G-T86YC97,@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@
M("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92@D9F]R;6%T*3L*("`@("`@("!I
M9B`H(6ES<V5T*"1I;G-T86YC97-;)'-I9VYA='5R95TI*2!["B`@("`@("`@
M("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@/2`F2&]R9&5?1&%T83HZ9F%C
M=&]R>2@D9F]R;6%T*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YS
M=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*("`@("\J*@H@("`@("H@36%P
M<R!A(&1A=&4O=&EM92!S=')I;F<@=&\@86X@87-S;V-I871I=F4@87)R87DN
M"B`@("`@*@H@("`@("H@5&AE(&UE=&AO9"!S:6=N871U<F4@:&%S(&-H86YG
M960@:6X@2&]R9&4@,RXQ+C,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T92`@(%1H92!D
M871E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@($]N92!O9B`G9&%T
M92<L("=T:6UE)R!O<B`G9&%T971I;64G+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@(%1W;RUD:6UE;G-I;VYA;"!A<G)A>2!W:71H(&%D9&ET:6]N
M86P@:6YF;W)M871I;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!A
M8F]U="!T:&4@9F]R;6%T=&EN9RX@4&]S<VEB;&4@:V5Y<R!A<F4Z/'!R93X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!D96QI;6ET97(@+2T@5&AE
M(&-H87)A8W1E<B!T:&%T('-E<&5R871E<R!T:&4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9&EF9F5R96YT(&1A=&4O=&EM
M92!P87)T<RX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!F;W)M870@
M+2T@268@)V%M<&TG(&%N9"`D9&%T92!C;VYT86EN<R!A('1I;64@=V4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87-S=6UE('1H
M870@:70@:7,@:6X@04TO4$T@9F]R;6%T+@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(&]R9&5R("TM($EF("1T>7!E(&ES("=D871E=&EM92<@=&AE
M(&]R9&5R(&]F('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&1A>2!A;F0@=&EM92!P87)T<SH@+3$@*'1I;65S=&%M<"DL(#`*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`H9&%Y+W1I
M;64I+"`Q("AT:6UE+V1A>2DN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:V5Y
M("`@5&AE(&ME>2!T;R!U<V4@9F]R("1P87)A;7,N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!D871E(&]R('1I;64@:6X@25-/(&9O<FUA
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@;6%P1&%T92@D9&%T92P@)'1Y<&4L
M("1P87)A;7,L("1K97DI"B`@("!["B`@("`@("`@<W=I=&-H("@D='EP92D@
M>PH@("`@("`@(&-A<V4@)V1A=&4G.@H@("`@("`@(&-A<V4@)VUO;G1H9&%Y
M)SH*("`@("`@("!C87-E("=M;VYT:&1A>7EE87(G.@H@("`@("`@("`@("`D
M9&%T97,@/2!E>'!L;V1E*"1P87)A;7-;)V1E;&EM:71E<B==6R1K97E=+"`D
M9&%T92D["B`@("`@("`@("`@(&EF("AC;W5N="@D9&%T97,I("$](#,I('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D9&%T93L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D:6YD97@@/2!A<G)A>5]F;&EP*&5X<&QO9&4H)R\G+"`D
M<&%R86US6R=F;W)M870G75LD:V5Y72DI.PH@("`@("`@("`@("!R971U<FX@
M)&1A=&5S6R1I;F1E>%LG>65A<B==72`N("<M)R`N("1D871E<ULD:6YD97A;
M)VUO;G1H)UU=("X@)RTG("X@)&1A=&5S6R1I;F1E>%LG;61A>2==73L*"B`@
M("`@("`@8V%S92`G=&EM92<Z"B`@("`@("`@("`@("1D871E<R`](&5X<&QO
M9&4H)'!A<F%M<ULG9&5L:6UI=&5R)UU;)&ME>5TL("1D871E*3L*("`@("`@
M("`@("`@:68@*&-O=6YT*"1D871E<RD@/"`R('Q\(&-O=6YT*"1D871E<RD@
M/B`S*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&1A=&4["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*"1P87)A;7-;)V9O<FUA="==6R1K97E=
M(#T]("=A;7!M)RD@>PH@("`@("`@("`@("`@("`@:68@*'-T<G!O<RAS=')T
M;VQO=V5R*"1D871E<UMC;W5N="@D9&%T97,I+3%=*2P@)W!M)RD@(3T](&9A
M;'-E*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1D871E<ULP72`A/3T@
M)S$R)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9&%T97-;,%T@*ST@
M,3(["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E
M;'-E:68@*"1D871E<ULP72`]/2`G,3(G*2!["B`@("`@("`@("`@("`@("`@
M("`@)&1A=&5S6S!=(#T@)S`G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@)&1A=&5S6V-O=6YT*"1D871E<RD@+2`Q72`]('-P<FEN=&8H
M)R4P,F0G+"`D9&%T97-;8V]U;G0H)&1A=&5S*2TQ72D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@<F5T=7)N("1D871E<ULP72`N("<Z)R`N("1D871E
M<ULQ72`N("AC;W5N="@D9&%T97,I(#T](#,@/R`H)SHG("X@)&1A=&5S6S)=
M*2`Z("<Z,#`G*3L*"B`@("`@("`@8V%S92`G9&%T971I;64G.@H@("`@("`@
M("`@("!S=VET8V@@*"1P87)A;7-;)V]R9&5R)UU;)&ME>5TI('L*("`@("`@
M("`@("`@8V%S92`M,3H*("`@("`@("`@("`@("`@(')E='5R;B`H<W1R:6YG
M*2AI;G0I)&1A=&4@/3T@)&1A=&4*("`@("`@("`@("`@("`@("`@("`_(&1A
M=&4H)UDM;2UD($@Z:3IS)RP@)&1A=&4I"B`@("`@("`@("`@("`@("`@("`@
M.B`D9&%T93L*("`@("`@("`@("`@8V%S92`P.@H@("`@("`@("`@("`@("`@
M;&ES="@D9&%Y+"`D=&EM92D@/2!E>'!L;V1E*"<@)RP@)&1A=&4L(#(I.PH@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@,3H*("`@
M("`@("`@("`@("`@;&ES="@D=&EM92P@)&1A>2D@/2!E>'!L;V1E*"<@)RP@
M)&1A=&4L(#(I.PH@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D9&%T92`]("1T:&ES+3YM87!$871E*"1D87DL("=D
M871E)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G9&5L:6UI=&5R)R`]/B`D<&%R86US6R=D87E?9&5L:6UI=&5R)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9O<FUA
M="<@/3X@)'!A<F%M<ULG9&%Y7V9O<FUA="==*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D:V5Y*3L*("`@("`@("`@("`@)'1I;64@
M/2`D=&AI<RT^;6%P1&%T92@D=&EM92P@)W1I;64G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=D96QI;6ET97(G(#T^("1P
M87)A;7-;)W1I;65?9&5L:6UI=&5R)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V9O<FUA="<@/3X@)'!A<F%M<ULG=&EM
M95]F;W)M870G72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&ME>2D["B`@("`@("`@("`@(')E='5R;B`D9&%T92`N("<@)R`N("1T
M:6UE.PH*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!486ME<R!A
M;&P@;F5C97-S87)Y(&%C=&EO;G,@9F]R('1H92!G:79E;B!I;7!O<G0@<W1E
M<"P@<&%R86UE=&5R<R!A;F0*("`@("`J(&9O<FT@=F%L=65S(&%N9"!R971U
M<FYS('1H92!N97AT(&YE8V5S<V%R>2!S=&5P+@H@("`@("H*("`@("`J($!P
M87)A;2!I;G1E9V5R("1A8W1I;VX@(%1H92!C=7)R96YT('-T97`N($]N92!O
M9B!T:&4@24U03U)47RH@8V]N<W1A;G1S+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;2`@("`@06X@87-S;V-I871I=F4@87)R87D@8V]N=&%I;FEN9R!N
M965D960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E
M<G,@9F]R('1H92!C=7)R96YT('-T97`N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@16ET:&5R('1H92!N97AT('-T97`@87,@86X@:6YT96=E<B!C
M;VYS=&%N="!O<B!I;7!O<G1E9`H@("`@("H@("`@("`@("`@("`@("`@9&%T
M82!S970@869T97(@=&AE(&9I;F%L('-T97`N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&YE>'13=&5P*"1A8W1I;VXL("1P87)A;2`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@+RH@1FER<W0@<W1E<"X@*B\*("`@("`@("!I9B`H:7-?;G5L
M;"@D86-T:6]N*2D@>PH@("`@("`@("`@("`D7U-%4U-)3TY;)VEM<&]R=%]D
M871A)UT@/2!A<G)A>2@I.PH@("`@("`@("`@("!R971U<FX@24U03U)47T9)
M3$4["B`@("`@("`@?0H*("`@("`@("!S=VET8V@@*"1A8W1I;VXI('L*("`@
M("`@("!C87-E($E-4$]25%]&24Q%.@H@("`@("`@("`@("`O*B!386YI=&EZ
M92!U<&QO861E9"!F:6QE+B`J+PH@("`@("`@("`@("`D:6UP;W)T7V9O<FUA
M="`](%5T:6PZ.F=E=$9O<FU$871A*"=I;7!O<G1?9F]R;6%T)RD["B`@("`@
M("`@("`@("1C:&5C:U]U<&QO860@/2!"<F]W<V5R.CIW87-&:6QE57!L;V%D
M960H)VEM<&]R=%]F:6QE)RP@)'!A<F%M6R=F:6QE7W1Y<&5S)UU;)&EM<&]R
M=%]F;W)M871=*3L*("`@("`@("`@("`@:68@*&ES7V$H)&-H96-K7W5P;&]A
M9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1C
M:&5C:U]U<&QO860["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1?
M1DE,15-;)VEM<&]R=%]F:6QE)UU;)W-I>F4G72`\/2`P*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")4:&4@9FEL92!C
M;VYT86EN960@;F\@9&%T82XB*2D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)%]315-324].6R=I;7!O<G1?9&%T82==6R=F;W)M870G72`]("1I;7!O
M<G1?9F]R;6%T.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!)
M35!/4E1?34%04$5$.@H@("`@("`@("`@("`D9&%T84ME>7,@/2!5=&EL.CIG
M971&;W)M1&%T82@G9&%T84ME>7,G+"`G)RD["B`@("`@("`@("`@("1A<'!+
M97ES(#T@571I;#HZ9V5T1F]R;41A=&$H)V%P<$ME>7,G+"`G)RD["B`@("`@
M("`@("`@(&EF("AE;7!T>2@D9&%T84ME>7,I('Q\(&5M<'1Y*"1A<'!+97ES
M*2D@>PH@("`@("`@("`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B
M66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F
M:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RXB*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)')E9VES=')Y+3YG970H)VYA;64G*2DI.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1D871A2V5Y<R`](&5X<&QO9&4H(EQT(BP@)&1A=&%+97ES*3L*
M("`@("`@("`@("`@)&%P<$ME>7,@/2!E>'!L;V1E*")<="(L("1A<'!+97ES
M*3L*("`@("`@("`@("`@)&UA<"`](&%R<F%Y*"D["B`@("`@("`@("`@("1D
M871E<R`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1A<'!+97ES
M(&%S("1K97D@/3X@)&%P<"D@>PH@("`@("`@("`@("`@("`@)&UA<%LD9&%T
M84ME>7-;)&ME>5U=(#T@)&%P<#L*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D<&%R86U;)W1I;65?9FEE;&1S)UTI("8F"B`@("`@("`@("`@("`@("`@
M("`@:7-S970H)'!A<F%M6R=T:6UE7V9I96QD<R==6R1A<'!=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1D871E<ULD9&%T84ME>7-;)&ME>5U=6R=T>7!E
M)UT@/2`D<&%R86U;)W1I;65?9FEE;&1S)UU;)&%P<%T["B`@("`@("`@("`@
M("`@("`@("`@)&1A=&5S6R1D871A2V5Y<ULD:V5Y75U;)W9A;'5E<R==(#T@
M87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`D:2`](#`["B`@("`@("`@
M("`@("`@("`@("`@+RH@0G5I;&0@86X@97AA;7!L92!A<G)A>2!O9B!U<"!T
M;R`Q,"!D871E+W1I;64@9FEE;&1S+B`J+PH@("`@("`@("`@("`@("`@("`@
M('=H:6QE("@D:2`\(&-O=6YT*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG
M9&%T82==*2`F)B!C;W5N="@D9&%T97-;)&1A=&%+97ES6R1K97E=75LG=F%L
M=65S)UTI(#P@,3`I('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%E
M;7!T>2@D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V1A=&$G75LD:5U;)&1A
M=&%+97ES6R1K97E=72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D871E<ULD9&%T84ME>7-;)&ME>5U=6R=V86QU97,G75M=(#T@)%]315-3
M24].6R=I;7!O<G1?9&%T82==6R=D871A)UU;)&E=6R1D871A2V5Y<ULD:V5Y
M75T["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`@("`@)&DK*SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)%]315-324].
M6R=I;7!O<G1?9&%T82==6R=M87`G72`]("1M87`["B`@("`@("`@("`@(&EF
M("AC;W5N="@D9&%T97,I(#X@,"D@>PH@("`@("`@("`@("`@("`@)%]315-3
M24].6R=I;7!O<G1?9&%T82==6R=D871E<R==(#T@)&1A=&5S.PH@("`@("`@
M("`@("`@("`@<F5T=7)N($E-4$]25%]$051%5$E-13L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/FYE>'13=&5P*$E-4$]25%]$
M051!+"`D<&%R86TI.PH*("`@("`@("!C87-E($E-4$]25%]$051%5$E-13H*
M("`@("`@("!C87-E($E-4$]25%]$051!.@H@("`@("`@("`@("!I9B`H)&%C
M=&EO;B`]/2!)35!/4E1?1$%4151)344I('L*("`@("`@("`@("`@("`@("1P
M87)A;7,@/2!A<G)A>2@G9&5L:6UI=&5R)R`]/B!5=&EL.CIG971&;W)M1&%T
M82@G9&5L:6UI=&5R)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V9O<FUA="<@/3X@571I;#HZ9V5T1F]R;41A=&$H)V9O<FUA="<I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=O<F1E<B<@/3X@571I
M;#HZ9V5T1F]R;41A=&$H)V]R9&5R)RDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V1A>5]D96QI;6ET97(G(#T^(%5T:6PZ.F=E=$9O<FU$
M871A*"=D87E?9&5L:6UI=&5R)RDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V1A>5]F;W)M870G(#T^(%5T:6PZ.F=E=$9O<FU$871A*"=D
M87E?9F]R;6%T)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W1I;65?9&5L:6UI=&5R)R`]/B!5=&EL.CIG971&;W)M1&%T82@G=&EM95]D
M96QI;6ET97(G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=&EM95]F;W)M870G(#T^(%5T:6PZ.F=E=$9O<FU$871A*"=T:6UE7V9O<FUA
M="<I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1?
M4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9&%T82==*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B5&AE('5P;&]A9&5D
M(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(BDI.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("\J($)U:6QD('1H92!R97-U;'0@
M9&%T82!S970@87,@86X@87-S;V-I871I=F4@87)R87DN("HO"B`@("`@("`@
M("`@("1D871A(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R96%C:"`H)%]3
M15-324].6R=I;7!O<G1?9&%T82==6R=D871A)UT@87,@)')O=RD@>PH@("`@
M("`@("`@("`@("`@)&1A=&%?<F]W(#T@87)R87DH*3L*("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1R;W<@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G
M75LG;6%P)UU;)&ME>5TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1M
M87!P961?:V5Y(#T@)%]315-324].6R=I;7!O<G1?9&%T82==6R=M87`G75LD
M:V5Y73L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1A8W1I;VX@/3T@
M24U03U)47T1!5$5424U%("8F"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`A96UP='DH)'9A;"D@)B8*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&ES<V5T*"1P87)A;5LG=&EM95]F:65L9',G72D@)B8*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&ES<V5T*"1P87)A;5LG=&EM95]F:65L9',G75LD
M;6%P<&5D7VME>5TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=F%L(#T@)'1H:7,M/FUA<$1A=&4H)'9A;"P@)'!A<F%M6R=T:6UE7V9I96QD
M<R==6R1M87!P961?:V5Y72P@)'!A<F%M<RP@)&ME>2D["B`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&%?
M<F]W6R1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG;6%P)UU;)&ME>5U=(#T@
M)'9A;#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`D9&%T85M=(#T@)&1A=&%?<F]W.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(')E='5R;B`D9&%T83L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#;&5A;G,@=&AE('-E<W-I;VX@9&%T82!U
M<"!A;F0@<F5M;W9E<R!A;GD@=7!L;V%D960@86YD(&UO=F5D"B`@("`@*B!F
M:6QE<RX@268@82!F=6YC=&EO;B!C86QL960@(E]C;&5A;G5P*"DB(&5X:7-T
M<RP@=&AI<R!G971S"B`@("`@*B!C86QL960@=&]O+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@($EF(%]C;&5A;G5P*"D@=V%S(&-A;&QE9"P@=&AE
M(')E='5R;B!V86QU92!O9B!T:&ES(&-A;&PN"B`@("`@*B`@("`@("`@("`@
M("`@("!4:&ES('-H;W5L9"!B92!T:&4@=F%L=64@;V8@=&AE(&9I<G-T(&EM
M<&]R="!S=&5P+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;&5A;G5P*"D*("`@
M('L*("`@("`@("!I9B`H:7-S970H)%]315-324].6R=I;7!O<G1?9&%T82==
M6R=F:6QE7VYA;64G72DI('L*("`@("`@("`@("`@0'5N;&EN:R@D7U-%4U-)
M3TY;)VEM<&]R=%]D871A)UU;)V9I;&5?;F%M92==*3L*("`@("`@("!]"B`@
M("`@("`@)%]315-324].6R=I;7!O<G1?9&%T82==(#T@87)R87DH*3L*("`@
M("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=?8VQE86YU<"<I*2!["B`@("`@
M("`@("`@(')E='5R;B!?8VQE86YU<"@I.PH@("`@("`@('T*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]$
M871A5')E92\`````````````````````````````````````````````````
M````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`U,34T,S,W-3``,#(Q,34S`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+T1A=&%4<F5E+VYU;&PN<&AP````````````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`R-S,W-P`Q,#4Q-30S,S<U,``P,C(V-38`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%1H92!$871A5')E95]N=6QL.CH@8VQA<W,@<')O=FED97,@
M82!D=6UM>2!I;7!L96UE;G1A=&EO;B!O9B!T:&4*("H@1&%T851R964Z.B!!
M4$D[(&YO(&1A=&$@=VEL;"!L87-T(&)E>6]N9"!A('-I;F=L92!P86=E(')E
M<75E<W0N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4
M<F5E+VYU;&PN<&AP+'8@,2XQ-2XR+C0@,C`P-2\Q,"\Q."`Q,3HP,3HP-2!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DL(#(P,#`L(#(P,#$L(#(P
M,#(@4W1E<&AA;F4@2'5T:&5R(#QS:'5T:&5R0&)I9V9O;W0N8V]M/@H@*B!#
M;W!Y<FEG:'0@,C`P,2P@,C`P,B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@
M,RXP"B`J($!P86-K86=E($AO<F1E7T1A=&%4<F5E"B`J+PIC;&%S<R!$871A
M5')E95]N=6QL(&5X=&5N9',@1&%T851R964@>PH*("`@("\J*@H@("`@("H@
M0V%C:&4@;V8@871T<FEB=71E<R!F;W(@86YY(&]B:F5C=',@8W)E871E9"!D
M=7)I;F<@=&AI<R!P86=E(')E<75E<W0N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]A='1R:6)U=&5#86-H92`](&%R<F%Y
M*"D["@H@("`@+RHJ"B`@("`@*B!#86-H92!O9B!D871A(&9O<B!A;GD@;V)J
M96-T<R!C<F5A=&5D(&1U<FEN9R!T:&ES('!A9V4@<F5Q=65S="X*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V1A=&%#86-H
M92`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!,;V%D("AA('-U8G-E="!O
M9BD@=&AE(&1A=&%T<F5E(&EN=&\@=&AE("1?9&%T82!A<G)A>2X@4&%R="!O
M9B!T:&4*("`@("`J($1A=&%4<F5E($%022!T:&%T(&UU<W0@8F4@;W9E<G)I
M9&1E;B!B>2!S=6)C;&%S<V5S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@("1R;V]T("`@(%=H:6-H('!O<G1I;VX@;V8@=&AE('1R964@=&\@;&]A
M9"X@1&5F875L=',@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M(&%L;"!O9B!I="X*("`@("`J($!P87)A;2!B;V]L96%N("1R96QO860@(%)E
M+6QO860@86QR96%D>2!L;V%D960@=F%L=65S/PH@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@
M;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@9G5N8W1I;VX@7VQO860H)')O;W0@/2!N=6QL+"`D<F5L;V%D
M(#T@9F%L<V4I"B`@("!["B`@("!]"@H@("`@+RHJ"B`@("`@*B!,;V%D(&$@
M<W!E8VEF:6,@;V)J96-T(&ED96YT:69I960@8GD@:71S('5N:7%U92!)1"`H
M)&ED*2P@86YD"B`@("`@*B!I=',@<&%R96YT<RP@:6YT;R!T:&4@)%]D871A
M(&%R<F%Y+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1C:60@(%1H
M92!U;FEQ=64@240@;V8@=&AE(&]B:F5C="!T;R!L;V%D+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?
M17)R;W(@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7VQO861">4ED*"1C:60I"B`@("![
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!T<F5E('-O<G1E9"!B>2!T
M:&4@<W!E8VEF:65D(&%T=')I8G5T92!N86UE(&%N9"]O<B!K97DN"B`@("`@
M*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@("1R;V]T("`@("`@(%=H:6-H('!O<G1I;VX@;V8@=&AE('1R
M964@=&\@<V]R="X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($1E9F%U;'1S('1O(&%L;"!O9B!I="X*("`@("`J($!P87)A;2!B;V]L96%N
M("1L;V%D5')E92`@(%-O<G0@=&AE('1R964@<W1A<G1I;F<@870@)')O;W0L
M(&]R(&IU<W0@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!R97%U97-T960@;&5V96P@86YD(&1I<F5C="!P87)E;G1S/PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@1&5F875L=',@=&\@<VEN9VQE
M(&QE=F5L+@H@("`@("H@0'!A<F%M(&%R<F%Y("1S;W)T8GE?;F%M92`@071T
M<FEB=71E(&YA;64@=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1S;W)T8GE?:V5Y("`@071T<FEB=71E(&ME>2!T;R!U<V4@9F]R
M('-O<G1I;F<N"B`@("`@*B!`<&%R86T@87)R87D@)&1I<F5C=&EO;B`@("!3
M;W)T(&1I<F5C=&EO;CH*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@,"`M(&%S8V5N9&EN9PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`Q("T@9&5S8V5N9&EN9PH@("`@("HO"B`@("!F=6YC=&EO
M;B!G9713;W)T9614<F5E*"1R;V]T+"`D;&]A9%1R964@/2!F86QS92P@)'-O
M<G1B>5]N86UE(#T@;G5L;"P@)'-O<G1B>5]K97D@/2!N=6QL+"`D9&ER96-T
M:6]N(#T@,"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($%D9"!A;B!O8FIE8W0N(%!A<G0@;V8@=&AE($1A
M=&%4<F5E($%022!T:&%T(&UU<W0@8F4*("`@("`J(&]V97)R:61D96X@8GD@
M<W5B8VQA<W-E<RX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&9U;&QN
M86UE("!4:&4@;V)J96-T('1O(&%D9"`H<W1R:6YG(&]R($1A=&%4<F5E3V)J
M96-T*2X*("`@("`J+PH@("`@9G5N8W1I;VX@861D*"1O8FIE8W0I"B`@("![
M"B`@("`@("`@:68@*&ES7V$H)&]B:F5C="P@)T1A=&%4<F5E3V)J96-T)RDI
M('L*("`@("`@("`@("`@)&9U;&QN86UE(#T@)&]B:F5C="T^9V5T3F%M92@I
M.PH@("`@("`@("`@("`D;W)D97(@/2`D;V)J96-T+3YO<F1E<CL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D9G5L;&YA;64@/2`D;V)J96-T.PH@
M("`@("`@("`@("`D;W)D97(@/2!N=6QL.PH@("`@("`@('T*"B`@("`@("`@
M)&ED(#T@;60U*&UT7W)A;F0H*2D["B`@("`@("`@:68@*'-T<G!O<R@D9G5L
M;&YA;64L("<Z)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("1P87)T<R`]
M(&5X<&QO9&4H)SHG+"`D9G5L;&YA;64I.PH@("`@("`@("`@("`D;F%M92`]
M(&%R<F%Y7W!O<"@D<&%R=',I.PH@("`@("`@("`@("`D<&%R96YT(#T@:6UP
M;&]D92@G.B<L("1P87)T<RD["B`@("`@("`@("`@("1P:60@/2`D=&AI<RT^
M9V5T260H)'!A<F5N="D["B`@("`@("`@("`@(&EF("AI<U]A*"1P:60L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YA9&0H)'!A
M<F5N="D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D<&ED(#T@1$%40512145?4D]/5#L*("`@("`@("!]"@H@("`@("`@
M(&EF("AP87)E;G0Z.F5X:7-T<R@D9G5L;&YA;64I*2!["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*"=!;')E861Y(&5X:7-T<R<I.PH@
M("`@("`@('T*"B`@("`@("`@)&%D9&5D(#T@<&%R96YT.CI?861D*"1F=6QL
M;F%M92P@)&ED+"`D<&ED+"`D;W)D97(I.PH@("`@("`@(&EF("AI<U]A*"1A
M9&1E9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&%D
M9&5D.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/G5P9&%T941A
M=&$H)&]B:F5C="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&%N9V4@;W)D
M97(@;V8@=&AE(&-H:6QD<F5N(&]F(&%N(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1P87)E;G1S("!4:&4@<&%R96YT(&ED('-T<FEN
M9R!P871H+@H@("`@("H@0'!A<F%M(&UI>&5D("1O<F1E<B`@("`@02!S<&5C
M:69I8R!N97<@;W)D97(@<&]S:71I;VX@;W(@86X@87)R87D*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@(&-O;G1A:6YI;F<@=&AE(&YE=R!P;W-I
M=&EO;G,@9F]R('1H92!G:79E;@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!A<F5N=',@;V)J96-T+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&-I9"`@("`@268@<')O=FED960@:6YD:6-A=&5S(&EN<V5R=&EO;B!O9B!A
M(&YE=R!C:&EL9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@=&\@
M=&AE(&]B:F5C="P@86YD('=I;&P@8F4@=7-E9"!T;R!A=F]I9`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@:6YC<F5M96YT:6YG(&ET('=H96X@
M<VAI9G1I;F<@=7`@86QL(&]T:&5R"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!C:&EL9')E;B=S(&]R9&5R+B!)9B!N;W0@<')O=FED960@:6YD
M:6-A=&5S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!D96QE=&EO
M;BP@:&5N8V4@<VAI9G0@86QL(&]T:&5R('!O<VET:6]N<R!D;W=N"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!O;F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(')E;W)D97(H)'!A<F5N=',L("1O<F1E<B`](&YU;&PL("1C:60@
M/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D;W)D97(I("8F
M("%E;7!T>2@D;W)D97(I*2!["B`@("`@("`@("`@("\O($UU;'1I('5P9&%T
M92X*("`@("`@("`@("`@)'1H:7,M/E]R96]R9&5R*"1P:60L("1O<F1E<BD[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@17AP;&EC:71L>2!S
M970@=&AE(&]R9&5R(&9O<B!A(&1A=&%T<F5E(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D:60@("`@(%1H92!D871A=')E92!O8FIE
M8W0@:60@=&\@8VAA;F=E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&]R9&5R
M("!4:&4@;F5W(&]R9&5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971/<F1E
M<B@D:60L("1O<F1E<BD*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M;6]V97,@86X@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`@
M("1O8FIE8W0@(%1H92!O8FIE8W0@=&\@<F5M;W9E+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&9O<F-E("`@1F]R8V4@<F5M;W9A;"!O9B!E=F5R>2!C:&EL
M9"!O8FIE8W0_"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V92@D;V)J96-T
M+"`D9F]R8V4@/2!F86QS92D*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E;6]V92!O;F4@;W(@;6]R92!O8FIE8W1S(&)Y(&ED+B!4:&ES(&9U;F-T
M:6]N(&1O97,@*FYO="H@9&\*("`@("`J('1H92!V86QI9&%T:6]N+"!R96]R
M9&5R:6YG+"!E=&,N('1H870@<F5M;W9E*"D@9&]E<RX@268@>6]U"B`@("`@
M*B!N965D('1O(&-H96-K(&9O<B!C:&EL9')E;BP@<F4M9&\@;W)D97)I;F<L
M(&5T8RXL('1H96X@>6]U(&UU<W0*("`@("`J(')E;6]V92@I(&]B:F5C=',@
M;VYE+6)Y+6]N92X@5&AI<R!I<R!F;W(@8V]D92!T:&%T(&MN;W=S(&ET)W,*
M("`@("`J(&1E86QI;F<@=VET:"!S:6YG;&4@*&YO;BUP87)E;G1E9"D@;V)J
M96-T<R!A;F0@;F5E9',@=&\@9&5L971E"B`@("`@*B!A(&)A=&-H(&]F('1H
M96T@<75I8VML>2X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&ED<R`@
M5&AE(&]B:F5C=',@=&\@<F5M;W9E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M96UO=F5">4ED<R@D:61S*0H@("`@>PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5M;W9E(&]N92!O<B!M;W)E(&]B:F5C=',@8GD@;F%M92X@5&AI<R!F=6YC
M=&EO;B!D;V5S("IN;W0J(&1O"B`@("`@*B!T:&4@=F%L:61A=&EO;BP@<F5O
M<F1E<FEN9RP@971C+B!T:&%T(')E;6]V92@I(&1O97,N($EF('EO=0H@("`@
M("H@;F5E9"!T;R!C:&5C:R!F;W(@8VAI;&1R96XL(')E+61O(&]R9&5R:6YG
M+"!E=&,N+"!T:&5N('EO=2!M=7-T"B`@("`@*B!R96UO=F4H*2!O8FIE8W1S
M(&]N92UB>2UO;F4N(%1H:7,@:7,@9F]R(&-O9&4@=&AA="!K;F]W<R!I="=S
M"B`@("`@*B!D96%L:6YG('=I=&@@<VEN9VQE("AN;VXM<&%R96YT960I(&]B
M:F5C=',@86YD(&YE961S('1O(&1E;&5T90H@("`@("H@82!B871C:"!O9B!T
M:&5M('%U:6-K;'DN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1N86UE
M<R`@5&AE(&]B:F5C=',@=&\@<F5M;W9E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!R96UO=F5">4YA;65S*"1N86UE<RD*("`@('L*("`@('T*"B`@("`O*BH*
M("`@("`J($UO=F4@86X@;V)J96-T('1O(&$@;F5W('!A<F5N="X*("`@("`J
M"B`@("`@*B!`<&%R86T@;6EX960@("1O8FIE8W0@("`@(%1H92!O8FIE8W0@
M=&\@;6]V92X*("`@("`J($!P87)A;2!S=')I;F<@)&YE=W!A<F5N="`@5&AE
M(&YE=R!P87)E;G0@;V)J96-T+B!$969A=6QT<R!T;R!T:&4@<F]O="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@;6]V92@D;V)J96-T+"`D;F5W<&%R96YT(#T@
M;G5L;"D*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J($-H86YG92!A;B!O
M8FIE8W0G<R!N86UE+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`@)&]L
M9%]O8FIE8W0@("`@("`@5&AE(&]L9"!O8FIE8W0N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N97=?;V)J96-T7VYA;64@(%1H92!N97<@;V)J96-T(&YA;64N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F%M92@D;VQD7V]B:F5C="P@)&YE
M=U]O8FIE8W1?;F%M92D*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M=')I979E(&1A=&$@9F]R(&%N(&]B:F5C="!F<F]M('1H92!D871A=')E95]D
M871A(&9I96QD+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1C:60@
M(%1H92!O8FIE8W0@:60@=&\@9F5T8V@L(&]R(&%N(&%R<F%Y(&]F(&]B:F5C
M="!I9',N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1A=&$H)&-I9"D*("`@
M('L*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/E]D871A0V%C:&5;)&-I
M9%TI(#\*("`@("`@("`@("`@)'1H:7,M/E]D871A0V%C:&5;)&-I9%T@.@H@
M("`@("`@("`@("!A<G)A>2@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M<FEE=F4@9&%T82!F;W(@86X@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1C:60@(%1H92!O8FIE8W0@:60@=&\@9F5T8V@N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$%T=')I8G5T97,H)&-I9"D*("`@('L*("`@
M("`@("!I9B`H:7-?87)R87DH)&-I9"DI('L*("`@("`@("`@("`@)&1A=&$@
M/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D8VED(&%S("1I9"D@
M>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?871T<FEB=71E
M0V%C:&5;)&ED72DI('L*("`@("`@("`@("`@("`@("`@("`D9&%T85LD:61=
M(#T@)'1H:7,M/E]A='1R:6)U=&5#86-H95LD:61=.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!R971U<FX@)&1A=&$[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&ES<V5T*"1T
M:&ES+3Y?871T<FEB=71E0V%C:&5;)&-I9%TI(#\*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?871T<FEB=71E0V%C:&5;)&-I9%T@.@H@("`@("`@("`@("`@
M("`@87)R87DH*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!N=6UB97(@;V8@;V)J96-T<R!M871C:&EN9R!A('-E="!O
M9B!A='1R:6)U=&4*("`@("`J(&-R:71E<FEA+@H@("`@("H*("`@("`J($!S
M964@8G5I;&1!='1R:6)U=&51=65R>2@I"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("`@)&-R:71E<FEA("`@5&AE(&%R<F%Y(&]F(&-R:71E<FEA+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)'!A<F5N="`@("`@5&AE('!A<F5N="!N
M;V1E('1O('-T87)T('-E87)C:&EN9R!F<F]M+@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)&%L;$QE=F5L<R`@4F5T=7)N(&%L;"!L979E;',L(&]R(&IU<W0@
M=&AE(&1I<F5C=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8VAI;&1R96X@;V8@)'!A<F5N=#\@1&5F875L=',@=&\@86QL(&QE=F5L<RX*
M("`@("`J($!P87)A;2!S=')I;F<@("1R97-T<FEC="`@($]N;'D@<F5T=7)N
M(&%T=')I8G5T97,@=VET:"!T:&4@<V%M90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@871T<FEB=71E7VYA;64@;W(@871T<FEB=71E7VED
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;W5N=$)Y071T<FEB=71E<R@D8W)I
M=&5R:6$L("1P87)E;G0@/2!$051!5%)%15]23T]4+"`D86QL3&5V96QS(#T@
M=')U92P@)')E<W1R:6-T(#T@)VYA;64G*0H@("`@>PH@("`@("`@(&EF("@A
M8V]U;G0H)&-R:71E<FEA*2D@>PH@("`@("`@("`@("!R971U<FX@,#L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!C;W5N="@D=&AI<RT^7V%T=')I8G5T
M94-A8VAE*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!S970@
M;V8@;V)J96-T(&ED<R!B87-E9"!O;B!A('-E="!O9B!A='1R:6)U=&4@8W)I
M=&5R:6$N"B`@("`@*@H@("`@("H@0'-E92!B=6EL9$%T=')I8G5T95%U97)Y
M*"D*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@("`D8W)I=&5R:6$@("`@
M(%1H92!A<G)A>2!O9B!C<FET97)I82X*("`@("`J($!P87)A;2!S=')I;F<@
M("1P87)E;G0@("`@("`@5&AE('!A<F5N="!N;V1E('1O('-T87)T('-E87)C
M:&EN9R!F<F]M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%L;$QE=F5L<R`@
M("!2971U<FX@86QL(&QE=F5L<RP@;W(@:G5S="!T:&4@9&ER96-T"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-H:6QD<F5N(&]F("1P
M87)E;G0_($1E9F%U;'1S('1O(&%L;"!L979E;',N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("`D<F5S=')I8W0@("`@($]N;'D@<F5T=7)N(&%T=')I8G5T97,@
M=VET:"!T:&4@<V%M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A='1R:6)U=&5?;F%M92!O<B!A='1R:6)U=&5?:60N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D9G)O;2`@("`@("`@(%1H92!O8FIE8W0@=&\@<W1A
M<G0@=&\@9F5T8VAI;F<*("`@("`J($!P87)A;2!I;G1E9V5R("1C;W5N="`@
M("`@("`@5&AE(&YU;6)E<B!O9B!O8FIE8W1S('1O(&9E=&-H"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D<V]R=&)Y7VYA;64@($%T=')I8G5T92!N86UE('1O
M('5S92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A;2!S=')I;F<@("1S;W)T
M8GE?:V5Y("`@071T<FEB=71E(&ME>2!T;R!U<V4@9F]R('-O<G1I;F<N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D9&ER96-T:6]N("`@(%-O<G0@9&ER96-T
M:6]N.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#`@
M+2!A<V-E;F1I;F<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Q("T@9&5S8V5N9&EN9PH@("`@("HO"B`@("!F=6YC=&EO;B!G971"
M>4%T=')I8G5T97,H)&-R:71E<FEA+"`D<&%R96YT(#T@1$%40512145?4D]/
M5"P@)&%L;$QE=F5L<R`]('1R=64L("1R97-T<FEC="`]("=N86UE)RP@)&9R
M;VT@/2`P+"`D8V]U;G0@/2`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1S;W)T8GE?;F%M92`](&YU;&PL("1S;W)T8GE?:V5Y(#T@;G5L;"P@
M)&1I<F5C=&EO;B`](#`I"B`@("!["B`@("`@("`@:68@*"%C;W5N="@D8W)I
M=&5R:6$I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=N;R!C<FET97)I82<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R
M<F%Y7VME>7,H)'1H:7,M/E]A='1R:6)U=&5#86-H92D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!3;W)T<R!)1',@8GD@871T<FEB=71E('9A;'5E<RX@241S
M('=I=&AO=70@871T<FEB=71E<R!W:6QL(&)E"B`@("`@*B!A9&1E9"!T;R!T
M:&4@96YD(&]F('1H92!S;W)T960@;&ES="X*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)'5N;W)D97)E9%]I9',@($%R<F%Y(&]F(&ED<R!T;R!S;W)T
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1S;W)T8GE?;F%M92`@("!!='1R:6)U
M=&4@;F%M92!T;R!U<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@87)R
M87D@)'-O<G1B>5]K97D@("`@($%T=')I8G5T92!K97D@=&\@=7-E(&9O<B!S
M;W)T:6YG+@H@("`@("H@0'!A<F%M(&%R<F%Y("1D:7)E8W1I;VX@("`@("!3
M;W)T(&1I<F5C=&EO;CH*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`P("T@87-C96YD:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@,2`M(&1E<V-E;F1I;F<*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!3;W)T960@:61S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S;W)T0GE!='1R:6)U=&5S*"1U;F]R9&5R961?:61S+"`D<V]R=&)Y7VYA
M;64@/2!N=6QL+"`D<V]R=&)Y7VME>2`](&YU;&PL("1D:7)E8W1I;VX@/2`P
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=6YO<F1E<F5D7VED<SL*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!L:7-T(&]F(&%L;"!O9B!T:&4@
M879A:6QA8FQE('9A;'5E<R!O9B!T:&4@9VEV96X*("`@("`J(&%T=')I8G5T
M92!N86UE+VME>2!C;VUB:6YA=&EO;BX@16ET:&5R(&%T=')I8G5T95]N86UE
M(&]R"B`@("`@*B!A='1R:6)U=&5?:V5Y($U54U0@8F4@<W5P<&QI960L(&%N
M9"!B;W1H($U!62!B92!S=7!P;&EE9"X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1A='1R:6)U=&5?;F%M92`@5&AE(&YA;64@;V8@=&AE(&%T=')I
M8G5T92X*("`@("`J($!P87)A;2!S=')I;F<@)&%T=')I8G5T95]K97D@("!4
M:&4@:V5Y('9A;'5E(&]F('1H92!A='1R:6)U=&4N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P87)E;G0@("`@("`@("`@5&AE('!A<F5N="!N;V1E('1O('-T
M87)T('-E87)C:&EN9R!F<F]M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%L
M;$QE=F5L<R`@("`@(%)E='5R;B!A;&P@;&5V96QS+"!O<B!J=7-T('1H92!D
M:7)E8W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C
M:&EL9')E;B!O9B`D<&%R96YT/PH@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@($%N(&%R<F%Y(&]F(&%L;"!O9B!T:&4@879A:6QA8FQE('9A;'5E<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T071T<FEB=71E5F%L=65S*"1A='1R
M:6)U=&5?;F%M92`](&YU;&PL("1A='1R:6)U=&5?:V5Y(#T@;G5L;"P@)'!A
M<F5N="`]($1!5$%44D5%7U)/3U0L("1A;&Q,979E;',@/2!T<G5E*0H@("`@
M>PH@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@57!D871E('1H92!D871A(&EN(&%N(&]B:F5C="X@1&]E<R!N;W0@8VAA
M;F=E('1H92!O8FIE8W0G<PH@("`@("H@<&%R96YT(&]R(&YA;64L(&IU<W0@
M<V5R:6%L:7IE9"!D871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&]B:F5C="`@5&AE(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@=7!D
M871E1&%T82@D;V)J96-T*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D;V)J
M96-T+"`G1&%T851R965/8FIE8W0G*2D@>PH@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("!]"@H@("`@("`@("1C:60@/2`D=&AI<RT^9V5T260H
M)&]B:F5C="T^9V5T3F%M92@I*3L*("`@("`@("!I9B`H:7-?82@D8VED+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8VED.PH@("`@
M("`@('T*"B`@("`@("`@+R\@5V4@:&%N9&QE(&1A=&$@9&EF9F5R96YT;'D@
M:68@=V4@8V%N(&UA<"!I="!T;PH@("`@("`@("\O(&%T=')I8G5T97,N"B`@
M("`@("`@:68@*&UE=&AO9%]E>&ES=',H)&]B:F5C="P@)U]T;T%T=')I8G5T
M97,G*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V%T=')I8G5T94-A8VAE6R1C
M:61=(#T@)&]B:F5C="T^7W1O071T<FEB=71E<R@I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1T:&ES+3Y?9&%T84-A8VAE6R1C:61=(#T@)&]B
M:F5C="T^9V5T1&%T82@I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1&%T851R964O
M<W%L+G!H<```````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3<T,C8U
M`#$P-3$U-#,S-S4P`#`R,C4P,@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@5&AE($1A=&%4<F5E7W-Q
M;#HZ(&-L87-S('!R;W9I9&5S(&%N(%-13"!I;7!L96UE;G1A=&EO;B!O9B!T
M:&4@2&]R9&4*("H@1&%T851R964@<WES=&5M+@H@*@H@*B!297%U:7)E9"!P
M87)A;65T97)S.CQP<F4^"B`J("`@)W!H<'1Y<&4G("`@5&AE(&1A=&%B87-E
M('1Y<&4@*&EE+B`G<&=S<6PG+"`G;7ES<6PG+"!E=&,N*2X*("H@("`G8VAA
M<G-E="<@("!4:&4@8VAA<G-E="!U<V5D(&)Y('1H92!D871A8F%S92X\+W!R
M93X*("H*("H@3W!T:6]N86P@<&%R86UE=&5R<SH\<')E/@H@*B`@("=T86)L
M92<@("`@(%1H92!N86UE(&]F('1H92!D871A('1A8FQE(&EN("=D871A8F%S
M92<N"B`J("`@("`@("`@("`@("`@1$5&055,5#H@)VAO<F1E7V1A=&%T<F5E
M)SPO<')E/@H@*@H@*B!297%U:7)E9"!B>2!S;VUE(&1A=&%B87-E(&EM<&QE
M;65N=&%T:6]N<SH\<')E/@H@*B`@("=D871A8F%S92<@(%1H92!N86UE(&]F
M('1H92!D871A8F%S92X*("H@("`G=7-E<FYA;64G("!4:&4@=7-E<FYA;64@
M=VET:"!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A8F%S92X*("H@("`G
M<&%S<W=O<F0G("!4:&4@<&%S<W=O<F0@87-S;V-I871E9"!W:71H("=U<V5R
M;F%M92<N"B`J("`@)VAO<W1S<&5C)R`@5&AE(&AO<W1N86UE(&]F('1H92!D
M871A8F%S92!S97)V97(N"B`J("`@)W!R;W1O8V]L)R`@5&AE(&-O;6UU;FEC
M871I;VX@<')O=&]C;VP@*"=T8W`G+"`G=6YI>"<L(&5T8RXI+@H@*B`@("=O
M<'1I;VYS)R`@($%D9&ET:6]N86P@;W!T:6]N<R!T;R!P87-S('1O('1H92!D
M871A8F%S92X*("H@("`G<&]R="<@("`@("!4:&4@<&]R="!O;B!W:&EC:"!T
M;R!C;VYN96-T('1O('1H92!D871A8F%S92X*("H@("`G='1Y)R`@("`@("!4
M:&4@5%19(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+CPO
M<')E/@H@*@H@*B!4:&4@=&%B;&4@<W1R=6-T=7)E(&9O<B!T:&4@1&%T851R
M964@<WES=&5M(&ES(&EN"B`J('-C<FEP=',O<W%L+VAO<F1E7V1A=&%T<F5E
M+G-Q;"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO1&%T851R964O1&%T851R
M964O<W%L+G!H<"QV(#$N,34V+C(N,S`@,C`P-B\P-R\Q,R`P.3HP-#HR,"!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!3=&5P:&%N92!(
M=71H97(@/'-H=71H97)`8FEG9F]O="YC;VT^"B`J($-O<'ER:6=H="`R,#`Q
M+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O
M<'ER:6=H="`R,#`U+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9@H@*B!Y;W4@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E"B`J(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N
M8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!*86X@4V-H;F5I
M9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`875T:&]R("!3=&5P:&%N92!(=71H
M97(@/'-H=71H97)`8FEG9F]O="YC;VT^"B`J($!S:6YC92`@($AO<F1E(#(N
M,0H@*B!`<&%C:V%G92!(;W)D95]$871A5')E90H@*B\*8VQA<W,@1&%T851R
M965?<W%L(&5X=&5N9',@1&%T851R964@>PH*("`@("\J*@H@("`@("H@2&%N
M9&QE(&9O<B!T:&4@8W5R<F5N="!D871A8F%S92!C;VYN96-T:6]N+@H@("`@
M("H*("`@("`J($!V87(@1$(*("`@("`J+PH@("`@=F%R("1?9&(["@H@("`@
M+RHJ"B`@("`@*B!4:&4@;G5M8F5R(&]F(&-O<&EE<R!O9B!T:&4@:&]R9&5?
M9&%T871R965?871T<FEB=71E<R!T86)L90H@("`@("H@=&AA="!W92!N965D
M('1O(&IO:6X@;VX@:6X@=&AE(&-U<G)E;G0@<75E<GDN"B`@("`@*@H@("`@
M("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7W1A8FQE0V]U;G0@
M/2`Q.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!344P@1&%T
M851R964@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N($1A=&%4<F5E7W-Q;"@D<&%R86US*0H@
M("`@>PH@("`@("`@('!A<F5N=#HZ1&%T851R964H)'!A<F%M<RD["B`@("`@
M("`@)'1H:7,M/E]C;VYN96-T*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&$@;&ES="!O9B!A;&P@9W)O=7!S("AR;V]T(&YO9&5S*2!O9B!T
M:&4@9&%T82!T<F5E+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H
M92!T:&4@9W)O=7`@241S"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$=R;W5P
M<R@I"B`@("!["B`@("`@("`@)'%U97)Y(#T@)U-%3$5#5"!$25-424Y#5"!G
M<F]U<%]U:60@1E)/32`G("X@("1T:&ES+3Y?<&%R86US6R=T86)L92==.PH*
M("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($1A=&%4
M<F5E7W-Q;#HZ9V5T1W)O=7!S*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("!R971U<FX@)'1H
M:7,M/E]D8BT^9V5T0V]L*"1Q=65R>2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!,;V%D<R`H82!S=6)S970@;V8I('1H92!D871A=')E92!I;G1O('1H92`D
M7V1A=&$@87)R87DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)')O;W0@("`@("`@("!7:&EC
M:"!P;W)T:6]N(&]F('1H92!T<F5E('1O(&QO860N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@($1E9F%U;'1S('1O(&%L;"!O9B!I="X*
M("`@("`J($!P87)A;2!B;V]L96%N("1L;V%D5')E92`@("`@3&]A9"!A('1R
M964@<W1A<G1I;F<@870@)')O;W0L(&]R(&IU<W0@=&AE"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(')E<75E<W1E9"!L979E;"!A;F0@
M9&ER96-T('!A<F5N=',_"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@($1E9F%U;'1S('1O('-I;F=L92!L979E;"X*("`@("`J($!P87)A
M;2!B;V]L96%N("1R96QO860@("`@("`@4F4M;&]A9"!A;')E861Y(&QO861E
M9"!V86QU97,_"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V]R=&)Y7VYA;64@
M($%T=')I8G5T92!N86UE('1O('5S92!F;W(@<V]R=&EN9RX*("`@("`J($!P
M87)A;2!S=')I;F<@("1S;W)T8GE?:V5Y("`@071T<FEB=71E(&ME>2!T;R!U
M<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&ER96-T
M:6]N("`@(%-O<G0@9&ER96-T:6]N.@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`P("T@87-C96YD:6YG"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#$@+2!D97-C96YD:6YG"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%
M<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?;&]A9"@D
M<F]O="`]($1!5$%44D5%7U)/3U0L("1L;V%D5')E92`](&9A;'-E+"`D<F5L
M;V%D(#T@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`D<V]R=&)Y7VYA;64@
M/2!N=6QL+"`D<V]R=&)Y7VME>2`](&YU;&PL("1D:7)E8W1I;VX@/2`P*0H@
M("`@>PH@("`@("`@("\J($1O($Y/5"!U<V4@1&%T851R964Z.F5X:7-T<R@I
M(&AE<F4[('1H870@=V]U;&0@8V%U<V4@86X@:6YF:6YI=&4*("`@("`@("`@
M*B!L;V]P+B`J+PH@("`@("`@(&EF("@A)')E;&]A9"`F)@H@("`@("`@("`@
M("`H:6Y?87)R87DH)')O;W0L("1T:&ES+3Y?;F%M94UA<"D@?'P*("`@("`@
M("`@("`@("AC;W5N="@D=&AI<RT^7V1A=&$I("8F("1R;V]T(#T]($1!5$%4
M4D5%7U)/3U0I*2!\?`H@("`@("`@("`@("`H(6ES7VYU;&PH)'1H:7,M/E]S
M;W)T2&%S:"D@)B8*("`@("`@("`@("`@(&ES<V5T*"1T:&ES+3Y?9&%T85LD
M<F]O=%U;)W-O<G1E<B==6R1T:&ES+3Y?<V]R=$AA<VA=*2DI('L*("`@("`@
M("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`D<75E<GD@
M/2`D=&AI<RT^7V)U:6QD3&]A9%%U97)Y*"1R;V]T+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&QO8614<F5E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1$%40512145?0E5)
M3$1?4T5,14-4+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'-O<G1B>5]N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'-O<G1B>5]K97DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9&ER96-T:6]N*3L*("`@("`@("!I
M9B`H:7-?82@D<75E<GDL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1Q=65R>3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1Q
M=65R>2DI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*
M("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($1A=&%4
M<F5E7W-Q;#HZ7VQO860H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@)&1A=&$@/2`D=&AI<RT^
M7V1B+3YG971!;&PH)'%U97)Y*3L*("`@("`@("!I9B`H:7-?82@D9&%T82P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&1A=&$["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^<V5T*"1D871A+"`D=&AI
M<RT^7W!A<F%M<ULG8VAA<G-E="==*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($-O=6YT<R`H82!S=6)S970@;V8I('1H92!D871A=')E92!W:&EC:"!W;W5L
M9"!B92!L;V%D960@:6YT;R!T:&4@)%]D871A"B`@("`@*B!A<G)A>2!I9B!?
M;&]A9"@I(&ES(&-A;&QE9"!W:71H('1H92!S86UE('9A;'5E(&]F("1R;V]T
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)')O;W0@(%=H:6-H('!O<G1I;VX@;V8@=&AE('1R
M964@=&\@;&]A9"X@1&5F875L=',@=&\@86QL"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("!O9B!I="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G
M97(@($YU;6)E<B!O9B!O8FIE8W1S"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C
M;W5N="@D<F]O="`]($1!5$%44D5%7U)/3U0I"B`@("!["B`@("`@("`@)'%U
M97)Y(#T@)'1H:7,M/E]B=6EL9$QO8611=65R>2@D<F]O="P@=')U92P@1$%4
M0512145?0E5)3$1?0T]53E0I.PH@("`@("`@(&EF("AI<U]A*"1Q=65R>2P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'%U97)Y.PH@
M("`@("`@('T*("`@("`@("!I9B`H96UP='DH)'%U97)Y*2D@>PH@("`@("`@
M("`@("!R971U<FX@,#L*("`@("`@("!]"B`@("`@("`@2&]R9&4Z.FQO9TUE
M<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.E]C;W5N="@I.B`G
M("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'
M*3L*("`@("`@("!R971U<FX@*&EN="DD=&AI<RT^7V1B+3YG971/;F4H)'%U
M97)Y*3L*("`@('T*"B`@("`O*BH*("`@("`J($QO861S("AA('-U8G-E="!O
M9BD@=&AE(&1A=&%T<F5E(&EN=&\@=&AE("1?9&%T82!A<G)A>2X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("`D<F]O="`@("`@("`@(%=H:6-H('!O<G1I;VX@;V8@=&AE('1R
M964@=&\@;&]A9"X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@1&5F875L=',@=&\@86QL(&]F(&ET+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&QO8614<F5E("`@("!,;V%D(&$@=')E92!S=&%R=&EN9R!A="`D<F]O
M="P@;W(@:G5S="!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<F5Q=65S=&5D(&QE=F5L(&%N9"!D:7)E8W0@<&%R96YT<S\*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1&5F875L=',@=&\@
M<VEN9VQE(&QE=F5L+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&]P97)A=&EO
M;B`@("!4>7!E(&]F('%U97)Y('1O(&)U:6QD"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`D<V]R=&)Y7VYA;64@($%T=')I8G5T92!N86UE('1O('5S92!F;W(@
M<V]R=&EN9RX*("`@("`J($!P87)A;2!S=')I;F<@("1S;W)T8GE?:V5Y("`@
M071T<FEB=71E(&ME>2!T;R!U<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D9&ER96-T:6]N("`@(%-O<G0@9&ER96-T:6]N.@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`P("T@87-C96YD:6YG
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$@+2!D97-C
M96YD:6YG"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S
M=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?8G5I;&1,;V%D475E<GDH)')O;W0@/2!$051!5%)%15]2
M3T]4+"`D;&]A9%1R964@/2!F86QS92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D;W!E<F%T:6]N(#T@1$%40512145?0E5)3$1?4T5,14-4+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S;W)T8GE?;F%M92`](&YU
M;&PL("1S;W)T8GE?:V5Y(#T@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9&ER96-T:6]N(#T@,"D*("`@('L*("`@("`@("`D<V]R=&5D
M(#T@9F%L<V4["B`@("`@("`@)'=H97)E(#T@<W!R:6YT9B@G8RYG<F]U<%]U
M:60@/2`E<R`G+"`D=&AI<RT^7V1B+3YQ=6]T92@D=&AI<RT^7W!A<F%M<ULG
M9W)O=7`G72DI.PH*("`@("`@("!I9B`H(65M<'1Y*"1R;V]T*2`F)B`D<F]O
M="`A/2!$051!5%)%15]23T]4*2!["B`@("`@("`@("`@("1P87)E;G1?=VAE
M<F4@/2`D=&AI<RT^7V)U:6QD4&%R96YT261S*"1R;V]T+"`D;&]A9%1R964L
M("=C+B<I.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1P87)E;G1?=VAE<F4I
M("8F("%I<U]A*"1P87)E;G1?=VAE<F4L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@("1W:&5R92`]('-P<FEN=&8H)R5S($%.1"`H)7,I)RP@
M)'=H97)E+"`D<&%R96YT7W=H97)E*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!I9B`H(6ES7VYU;&PH)'-O<G1B>5]N86UE*2D@>PH@("`@
M("`@("`@("`D=VAE<F4@/2!S<')I;G1F*"<E<R!!3D0@82YA='1R:6)U=&5?
M;F%M92`]("5S("<L("1W:&5R92P@)'1H:7,M/E]D8BT^<75O=&4H)'-O<G1B
M>5]N86UE*2D["B`@("`@("`@("`@("1S;W)T960@/2!T<G5E.PH@("`@("`@
M('T*("`@("`@("!I9B`H(6ES7VYU;&PH)'-O<G1B>5]K97DI*2!["B`@("`@
M("`@("`@("1W:&5R92`]('-P<FEN=&8H)R5S($%.1"!A+F%T=')I8G5T95]K
M97D@/2`E<R`G+"`D=VAE<F4L("1T:&ES+3Y?9&(M/G%U;W1E*"1S;W)T8GE?
M:V5Y*2D["B`@("`@("`@("`@("1S;W)T960@/2!T<G5E.PH@("`@("`@('T*
M"B`@("`@("`@<W=I=&-H("@D;W!E<F%T:6]N*2!["B`@("`@("`@8V%S92!$
M051!5%)%15]"54E,1%]#3U5.5#H*("`@("`@("`@("`@)'=H870@/2`G0T]5
M3E0H*BDG.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*
M("`@("`@("`@("`@)'=H870@/2`G8RYD871A=')E95]I9"P@8RYD871A=')E
M95]N86UE+"!C+F1A=&%T<F5E7W!A<F5N=',L(&,N9&%T871R965?;W)D97(G
M.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@(&EF("@D
M<V]R=&5D*2!["B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)U-%3$5#
M5"`E<R!&4D]-("5S(&,@3$5&5"!*3TE.("5S(&$@3TX@*&,N9&%T871R965?
M:60@/2!A+F1A=&%T<F5E7VED($]2(&,N9&%T871R965?;F%M93TE<RD@)RX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G5TA%4D4@)7,@1U)/55`@
M0ED@8RYD871A=')E95]I9"P@8RYD871A=')E95]N86UE+"!C+F1A=&%T<F5E
M7W!A<F5N=',L(&,N9&%T871R965?;W)D97(@3U)$15(@0ED@82YA='1R:6)U
M=&5?=F%L=64@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W
M:&%T+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=T86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=T86)L95]A='1R:6)U=&5S)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D8BT^<75O=&4H)')O;W0I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W:&5R92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`H)&1I<F5C=&EO;B`]/2`Q*2`_("=$15-#
M)R`Z("=!4T,G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<75E
M<GD@/2!S<')I;G1F*"=314Q%0U0@)7,@1E)/32`E<R!C(%=(15)%("5S)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=VAA="P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=VAE<F4I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1Q=65R>3L*("`@('T*"B`@("`O*BH*("`@
M("`J($)U:6QD<R!P87)E;G0@240@<W1R:6YG(&9O<B!S96QE8W1I;F<@=')E
M97,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)')O;W0@("`@("!7:&EC:"!P;W)T:6]N(&]F
M('1H92!T<F5E('1O(&QO860N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;&]A
M9%1R964@($QO860@82!T<F5E('-T87)T:6YG(&%T("1R;V]T+"!O<B!J=7-T
M('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!R97%U97-T
M960@;&5V96P@86YD(&1I<F5C="!P87)E;G1S/PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("!$969A=6QT<R!T;R!S:6YG;&4@;&5V96PN"B`@
M("`@*B!`<&%R86T@<W1R:6YG("`D:F]I;E]N86UE(%1A8FQE(&IO:6X@;F%M
M90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!)9"!L:7-T+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?8G5I;&1087)E;G1)9',H)')O;W0L("1L;V%D
M5')E92`](&9A;'-E+"`D:F]I;E]N86UE(#T@)R<I"B`@("!["B`@("`@("`@
M:68@*'-T<G!O<R@D<F]O="P@)SHG*2`A/3T@9F%L<V4I('L*("`@("`@("`@
M("`@)'!A<G1S(#T@97AP;&]D92@G.B<L("1R;V]T*3L*("`@("`@("`@("`@
M)')O;W0@/2!A<G)A>5]P;W`H)'!A<G1S*3L*("`@("`@("!]"B`@("`@("`@
M)')O;W0@/2`H<W1R:6YG*21R;V]T.PH*("`@("`@("`D<75E<GD@/2`G4T5,
M14-4(&1A=&%T<F5E7VED+"!D871A=')E95]P87)E;G1S)R`N"B`@("`@("`@
M("`@("<@1E)/32`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@+@H@("`@
M("`@("`@("`G(%=(15)%(&1A=&%T<F5E7VYA;64@/2`_($%.1"!G<F]U<%]U
M:60@/2`_)R`N"B`@("`@("`@("`@("<@3U)$15(@0ED@9&%T871R965?:60G
M.PH@("`@("`@("1V86QU97,@/2!A<G)A>2@D<F]O="P*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V=R;W5P)UTI.PH*("`@("`@
M("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q
M;#HZ7V)U:6QD4&%R96YT261S*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("1R;V]T(#T@)'1H
M:7,M/E]D8BT^9V5T07-S;V,H)'%U97)Y+"!F86QS92P@)'9A;'5E<RD["B`@
M("`@("`@:68@*&ES7V$H)')O;W0L("=014%27T5R<F]R)RD@?'P@(6-O=6YT
M*"1R;V]T*2D@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H*
M("`@("`@("`D=VAE<F4@/2`G)SL*("`@("`@("`D9FER<W1?=&EM92`]('1R
M=64["B`@("`@("`@9F]R96%C:"`H)')O;W0@87,@)&]B:F5C=%]I9"`]/B`D
M;V)J96-T7W!A<F5N=',I('L*("`@("`@("`@("`@)'!S=')I;F<@/2`D;V)J
M96-T7W!A<F5N=',@+B`G.B<@+B`D;V)J96-T7VED("X@)R4G.PH@("`@("`@
M("`@("`D<'%U97)Y(#T@)R<["B`@("`@("`@("`@(&EF("@A96UP='DH)&]B
M:F5C=%]P87)E;G1S*2D@>PH@("`@("`@("`@("`@("`@)&ED<R`]('-U8G-T
M<B@D;V)J96-T7W!A<F5N=',L(#$I.PH@("`@("`@("`@("`@("`@)'!Q=65R
M>2`]("<@3U(@)R`N("1J;VEN7VYA;64@+B`G9&%T871R965?:60@24X@*"<@
M+B!S=')?<F5P;&%C92@G.B<L("<L("<L("1I9',I("X@)RDG.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("@D;&]A9%1R964I('L*("`@("`@("`@
M("`@("`@("1P<75E<GD@+CT@)R!/4B`G("X@)&IO:6Y?;F%M92`N("=D871A
M=')E95]P87)E;G1S(#T@)R`N("1T:&ES+3Y?9&(M/G%U;W1E*'-U8G-T<B@D
M<'-T<FEN9RP@,"P@+3(I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M:68@*"$D9FER<W1?=&EM92D@>PH@("`@("`@("`@("`@("`@)'=H97)E("X]
M("<@3U(@)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=VAE<F4@+CT@
M<W!R:6YT9B@D:F]I;E]N86UE("X@)V1A=&%T<F5E7W!A<F5N=',@3$E+12`E
M<R!/4B`G("X@)&IO:6Y?;F%M92`N("=D871A=')E95]I9"`]("5S)7,G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YQ=6]T
M92@D<'-T<FEN9RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1O
M8FIE8W1?:60L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<75E
M<GDI.PH*("`@("`@("`@("`@)&9I<G-T7W1I;64@/2!F86QS93L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D=VAE<F4["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!,;V%D<R!A('-E="!O9B!O8FIE8W1S(&ED96YT:69I960@8GD@=&AE
M:7(@=6YI<75E($E$<RP@86YD('1H96ER"B`@("`@*B!P87)E;G1S+"!I;G1O
M('1H92`D7V1A=&$@87)R87DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1C:61S("!4:&4@=6YI
M<75E($E$(&]F('1H92!O8FIE8W0@=&\@;&]A9"P@;W(@86X@87)R87D@;V8*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@;V)J96-T(&ED<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!0
M14%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]L
M;V%D0GE)9"@D8VED<RD*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@
M:&%V92!A;B!A<G)A>2X@*B\*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1C:61S
M*2D@>PH@("`@("`@("`@("`D8VED<R`](&%R<F%Y*"AI;G0I)&-I9',I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(&%R<F%Y7W=A;&LH)&-I9',L
M("=I;G1V86PG*3L*("`@("`@("!]"@H@("`@("`@("\J($)A:6P@;W5T(&YO
M=R!I9B!T:&5R92=S(&YO=&AI;F<@=&\@;&]A9"X@*B\*("`@("`@("!I9B`H
M(6-O=6YT*"1C:61S*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("!]"@H@("`@("`@("\J($1O;B=T(&QO860@86YY('1H870@87)E(&%L
M<F5A9'D@;&]A9&5D+B!!;'-O+"!M86ME('-U<F4@=&AA=`H@("`@("`@("`J
M(&5V97)Y=&AI;F<@:6X@=&AE("1I9',@87)R87D@=&AA="!W92!A<F4@8G5I
M;&1I;F<@:7,@86X@:6YT96=E<BX@*B\*("`@("`@("`D:61S(#T@87)R87DH
M*3L*("`@("`@("!F;W)E86-H("@D8VED<R!A<R`D8VED*2!["B`@("`@("`@
M("`@("\J($1O($Y/5"!U<V4@1&%T851R964Z.F5X:7-T<R@I(&AE<F4[('1H
M870@=V]U;&0@8V%U<V4@86X*("`@("`@("`@("`@("H@:6YF:6YI=&4@;&]O
M<"X@*B\*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V1A=&%;)&-I
M9%TI*2!["B`@("`@("`@("`@("`@("`D:61S6UT@/2`H:6YT*21C:60["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($EF('1H97)E(&%R
M92!N;VYE(&QE9G0@=&\@;&]A9"P@<F5T=7)N+B`J+PH@("`@("`@(&EF("@A
M8V]U;G0H)&ED<RDI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@
M("`@?0H*("`@("`@("`D:6X@/2!A<G)A>5]S96%R8V@H1$%40512145?4D]/
M5"P@)&ED<RD@/3T](&9A;'-E(#\@<W!R:6YT9B@G9&%T871R965?:60@24X@
M*"5S*2!!3D0@)RP@:6UP;&]D92@G+"`G+"`D:61S*2D@.B`G)SL*("`@("`@
M("`D<75E<GD@/2!S<')I;G1F*"=314Q%0U0@9&%T871R965?:60L(&1A=&%T
M<F5E7W!A<F5N=',@1E)/32`E<R<@+@H@("`@("`@("`@("`@("`@("`@("`@
M("`@)R!72$5212`E<V=R;W5P7W5I9"`]("5S)R`N"B`@("`@("`@("`@("`@
M("`@("`@("`@("`G($]21$52($)9(&1A=&%T<F5E7VED)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@)&EN+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]D8BT^<75O=&4H)'1H:7,M/E]P87)A;7-;)V=R;W5P
M)UTI*3L*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y
M($1A=&%4<F5E7W-Q;#HZ7VQO861">4ED*"DZ("<@+B`D<75E<GDL(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("1P87)E
M;G1S(#T@)'1H:7,M/E]D8BT^9V5T07-S;V,H)'%U97)Y*3L*("`@("`@("!I
M9B`H:7-?82@D<&%R96YT<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'!A<F5N=',["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T
M>2@D<&%R96YT<RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H7R@B3F]T(&9O=6YD+B(I+"!N=6QL+"!N=6QL+"!N=6QL+"`G1&%T
M851R964@:61S("<@+B!I;7!L;V1E*"<L("<L("1I9',I("X@)R!N;W0@9F]U
M;F0N)RD["B`@("`@("`@?0H*("`@("`@("`D:61S(#T@87)R87DH*3L*("`@
M("`@("!F;W)E86-H("@D<&%R96YT<R!A<R`D8VED(#T^("1P87)E;G0I('L*
M("`@("`@("`@("`@)&ED<ULH:6YT*21C:61=(#T@*&EN="DD8VED.PH*("`@
M("`@("`@("`@)'!I9',@/2!E>'!L;V1E*"<Z)RP@<W5B<W1R*"1P87)E;G0L
M(#$I*3L*("`@("`@("`@("`@9F]R96%C:"`H)'!I9',@87,@)'!I9"D@>PH@
M("`@("`@("`@("`@("`@)'!I9"`]("AI;G0I)'!I9#L*("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/E]D871A6R1P:61=*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1I9'-;)'!I9%T@/2`D<&ED.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!)9B`D
M:61S(&ES(&5M<'1Y+"!W92!H879E(&YO=&AI;F<@=&\@;&]A9"X@*B\*("`@
M("`@("!I9B`H(6-O=6YT*"1I9',I*2!["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T*"B`@("`@("`@)'%U97)Y(#T@)U-%3$5#5"!D871A
M=')E95]I9"P@9&%T871R965?;F%M92P@9&%T871R965?<&%R96YT<RP@9&%T
M871R965?;W)D97(G("X*("`@("`@("`@("`@("`@("`G($923TT@)R`N("1T
M:&ES+3Y?<&%R86US6R=T86)L92==("X*("`@("`@("`@("`@("`@("`G(%=(
M15)%(&1A=&%T<F5E7VED($E.("@_)R`N('-T<E]R97!E870H)RP@/R<L(&-O
M=6YT*"1I9',I("T@,2D@+B`G*2<@+@H@("`@("`@("`@("`@("`@("<@04Y$
M(&=R;W5P7W5I9"`](#\@3U)$15(@0ED@9&%T871R965?:60G.PH@("`@("`@
M("1V86QU97,@/2!A<G)A>5]M97)G92@D:61S+"!A<G)A>2@D=&AI<RT^7W!A
M<F%M<ULG9W)O=7`G72DI.PH*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G
M4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ7VQO861">4ED*"DZ("<@+B`D
M<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@
M("`@("`@("1D871A(#T@)'1H:7,M/E]D8BT^9V5T06QL*"1Q=65R>2P@)'9A
M;'5E<RD["B`@("`@("`@:68@*&ES7V$H)&1A=&$L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1D871A.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1T:&ES+3YS970H)&1A=&$L("1T:&ES+3Y?<&%R86US6R=C
M:&%R<V5T)UTI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('1R
M964@<V]R=&5D(&)Y('1H92!S<&5C:69I960@871T<FEB=71E(&YA;64@86YD
M+V]R(&ME>2X*("`@("`J"B`@("`@*B!`<VEN8V4@2&]R9&4@,RXQ"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F]O="`@("`@("`@(%=H:6-H('!O
M<G1I;VX@;V8@=&AE('1R964@=&\@<V]R="X*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!$969A=6QT<R!T;R!A;&P@;V8@:70N"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D;&]A9%1R964@("`@4V]R="!T:&4@=')E92!S
M=&%R=&EN9R!A="`D<F]O="P@;W(@:G5S="!T:&4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!R97%U97-T960@;&5V96P@86YD(&1I<F5C
M="!P87)E;G1S/PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($1E9F%U;'1S('1O('-I;F=L92!L979E;"X*("`@("`J($!P87)A;2!S=')I
M;F<@)'-O<G1B>5]N86UE("!!='1R:6)U=&4@;F%M92!T;R!U<V4@9F]R('-O
M<G1I;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG("1S;W)T8GE?:V5Y("`@071T
M<FEB=71E(&ME>2!T;R!U<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D9&ER96-T:6]N("`@4V]R="!D:7)E8W1I;VXZ"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@,"`M(&%S8V5N9&EN9PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$@+2!D97-C96YD:6YG
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-O<G1E9%1R964H)')O;W0L("1L
M;V%D5')E92`](&9A;'-E+"`D<V]R=&)Y7VYA;64@/2!N=6QL+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<V]R=&)Y7VME>2`](&YU;&PL("1D:7)E
M8W1I;VX@/2`P*0H@("`@>PH@("`@("`@("1Q=65R>2`]("1T:&ES+3Y?8G5I
M;&1,;V%D475E<GDH)')O;W0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D;&]A9%1R964L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!$051!5%)%15]"54E,1%]314Q%0U0L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<V]R=&)Y
M7VYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<V]R=&)Y7VME>2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1D:7)E8W1I;VXI.PH*("`@("`@("!R971U<FX@)'1H:7,M
M/E]D8BT^9V5T06QL*"1Q=65R>2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!
M9&1S(&%N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&]B
M:F5C="`@("`@("`@5&AE(&]B:F5C="!T;R!A9&0@*'-T<FEN9R!O<@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@($1A=&%4<F5E3V)J96-T
M*2X*("`@("`J($!P87)A;2!B;V]L96%N("1I9%]A<U]N86UE("!7:&5T:&5R
M('1H92!O8FIE8W0@240@:7,@=&\@8F4@=7-E9"!A<PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&]B:F5C="!N86UE+B`@57-E9"!I;B!S
M:71U871I;VYS('=H97)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=&AE<F4@:7,@;F\@879A:6QA8FQE('5N:7%U92!I;G!U="!F;W(*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!O8FIE8W0@;F%M
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@861D*"1O8FIE8W0L("1I9%]A<U]N
M86UE(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&%T=')I8G5T97,@/2!F86QS
M93L*("`@("`@("!I9B`H:7-?82@D;V)J96-T+"`G1&%T851R965/8FIE8W0G
M*2D@>PH@("`@("`@("`@("`D9G5L;&YA;64@/2`D;V)J96-T+3YG971.86UE
M*"D["B`@("`@("`@("`@("1O<F1E<B`]("1O8FIE8W0M/F]R9&5R.PH*("`@
M("`@("`@("`@+RH@5V4@:&%N9&QE(&1A=&$@9&EF9F5R96YT;'D@:68@=V4@
M8V%N(&UA<"!I="!T;R!T:&4*("`@("`@("`@("`@("H@:&]R9&5?9&%T871R
M965?871T<FEB=71E<R!T86)L92X@*B\*("`@("`@("`@("`@:68@*&UE=&AO
M9%]E>&ES=',H)&]B:F5C="P@)U]T;T%T=')I8G5T97,G*2D@>PH@("`@("`@
M("`@("`@("`@)&1A=&$@/2`G)SL*("`@("`@("`@("`@("`@("1S97(@/2!N
M=6QL.PH*("`@("`@("`@("`@("`@("\J(%-E="!A(&9L86<@9F]R(&QA=&5R
M('-O('1H870@=V4@:VYO=R!T;R!I;G-E<G0@=&AE"B`@("`@("`@("`@("`@
M("`@*B!A='1R:6)U=&4@<F]W<RX@*B\*("`@("`@("`@("`@("`@("1A='1R
M:6)U=&5S(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O4V5R:6%L:7IE+G!H<"<["B`@
M("`@("`@("`@("`@("`D<V5R(#T@4T5224%,25I%7U541C=?0D%324,["B`@
M("`@("`@("`@("`@("`D9&%T82`]($AO<F1E7U-E<FEA;&EZ93HZ<V5R:6%L
M:7IE*"1O8FIE8W0M/F=E=$1A=&$H*2P@)'-E<BP@3DQ3.CIG971#:&%R<V5T
M*"DI.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&9U;&QN86UE(#T@)&]B:F5C=#L*("`@("`@("`@("`@)&]R9&5R(#T@
M;G5L;#L*("`@("`@("`@("`@)&1A=&$@/2`G)SL*("`@("`@("`@("`@)'-E
M<B`](&YU;&P["B`@("`@("`@?0H*("`@("`@("`O*B!'970@=&AE(&YE>'0@
M=6YI<75E($E$+B`J+PH@("`@("`@("1I9"`]("1T:&ES+3Y?9&(M/FYE>'1)
M9"@D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72D["B`@("`@("`@:68@*&ES7V$H
M)&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-
M97-S86=E*"1I9"P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I
M.PH@("`@("`@("`@("!R971U<FX@)&ED.PH@("`@("`@('T*"B`@("`@("`@
M:68@*'-T<G!O<R@D9G5L;&YA;64L("<Z)RD@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@("1P87)T<R`](&5X<&QO9&4H)SHG+"`D9G5L;&YA;64I.PH@("`@
M("`@("`@("`D<&%R96YT<R`]("<G.PH@("`@("`@("`@("`D<'-T<FEN9R`]
M("<G.PH@("`@("`@("`@("!I9B`H)&ED7V%S7VYA;64I('L*("`@("`@("`@
M("`@("`@("\J(%)E<75E<W1E9"!U<V4@;V8@240@87,@;F%M92P@<V\@9&ES
M8V%R9"!C=7)R96YT(&YA;64N("HO"B`@("`@("`@("`@("`@("!A<G)A>5]P
M;W`H)'!A<G1S*3L*("`@("`@("`@("`@("`@("\J(%-E="!N86UE('1O($E$
M+B`J+PH@("`@("`@("`@("`@("`@)&YA;64@/2`D:60["B`@("`@("`@("`@
M("`@("`O*B!-;V1I9GD@9G5L;&YA;64@=&\@<F5F;&5C="!N97<@;F%M92X@
M*B\*("`@("`@("`@("`@("`@("1F=6QL;F%M92`](&EM<&QO9&4H)SHG+"`D
M<&%R=',I("X@)SHG("X@)&ED.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H
M)&]B:F5C="P@)T1A=&%4<F5E3V)J96-T)RDI('L*("`@("`@("`@("`@("`@
M("`@("`D;V)J96-T+3YS971.86UE*"1F=6QL;F%M92D["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1O8FIE8W0@/2`D
M9G5L;&YA;64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D;F%M92`](&%R<F%Y7W!O<"@D<&%R=',I
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<F5A8V@@*"1P87)T<R!A
M<R`D<&%R*2!["B`@("`@("`@("`@("`@("`D<'-T<FEN9R`N/2`H96UP='DH
M)'!S=')I;F<I(#\@)R<@.B`G.B<I("X@)'!A<CL*("`@("`@("`@("`@("`@
M("1P:60@/2`D=&AI<RT^9V5T260H)'!S=')I;F<I.PH@("`@("`@("`@("`@
M("`@:68@*&ES7V$H)'!I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@("`@("\J($%U=&\M8W)E871E('!A<F5N=',N("HO"B`@("`@("`@
M("`@("`@("`@("`@)'!I9"`]("1T:&ES+3YA9&0H)'!S=')I;F<I.PH@("`@
M("`@("`@("`@("`@("`@(&EF("AI<U]A*"1P:60L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1P:60["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)'!A<F5N=',@+CT@)SHG("X@)'!I9#L*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@D:61?87-?;F%M92D@
M>PH@("`@("`@("`@("`@("`@+RH@4F5Q=65S=&5D('5S92!O9B!)1"!A<R!N
M86UE+"!S970@9G5L;&YA;64@86YD(&YA;64@=&\@240N("HO"B`@("`@("`@
M("`@("`@("`D9G5L;&YA;64@/2`D:60["B`@("`@("`@("`@("`@("`D;F%M
M92`]("1I9#L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1O8FIE8W0L("=$
M871A5')E94]B:F5C="<I*2!["B`@("`@("`@("`@("`@("`@("`@)&]B:F5C
M="T^<V5T3F%M92@D9G5L;&YA;64I.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`D;V)J96-T(#T@)&9U;&QN86UE.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)&YA;64@/2`D9G5L;&YA;64["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)'!A<F5N=',@/2`G)SL*("`@("`@("`@("`@)'!I9"`]($1!
M5$%44D5%7U)/3U0["B`@("`@("`@?0H*("`@("`@("!I9B`H<&%R96YT.CIE
M>&ES=',H)&9U;&QN86UE*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BA?*")!;')E861Y(&5X:7-T<R(I*3L*("`@("`@("!]"@H@
M("`@("`@("1Q=65R>2`]("=)3E-%4E0@24Y43R`G("X@)'1H:7,M/E]P87)A
M;7-;)W1A8FQE)UT@+@H@("`@("`@("`@("`@("`@("<@*&1A=&%T<F5E7VED
M+"!G<F]U<%]U:60L(&1A=&%T<F5E7VYA;64L(&1A=&%T<F5E7V]R9&5R+"<@
M+@H@("`@("`@("`@("`@("`@("<@9&%T871R965?9&%T82P@=7-E<E]U:60L
M(&1A=&%T<F5E7W-E<FEA;&EZ960L)R`N"B`@("`@("`@("`@("`@("`@)R!D
M871A=')E95]P87)E;G1S*2<@+@H@("`@("`@("`@("`@("`@("<@5D%,5453
M("@_+"`_+"`_+"`_+"`_+"`_+"`_+"`_*2<["B`@("`@("`@)'9A;'5E<R`]
M(&%R<F%Y*"AI;G0I)&ED+`H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG9W)O=7`G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D;F%M92P@3DQ3.CIG971#:&%R<V5T
M*"DL("1T:&ES+3Y?<&%R86US6R=C:&%R<V5T)UTI+`H@("`@("`@("`@("`@
M("`@("`@("`@("!I<U]N=6QL*"1O<F1E<BD@/R!.54Q,(#H@*&EN="DD;W)D
M97(L"B`@("`@("`@("`@("`@("`@("`@("`@("1D871A+`H@("`@("`@("`@
M("`@("`@("`@("`@("`H<W1R:6YG*4%U=&@Z.F=E=$%U=&@H*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@*&EN="DD<V5R+`H@("`@("`@("`@("`@("`@
M("`@("`@("`D<&%R96YT<RD["@H@("`@("`@($AO<F1E.CIL;V=-97-S86=E
M*"=344P@475E<GD@8GD@1&%T851R965?<W%L.CIA9&0H*3H@)R`N("1Q=65R
M>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@
M("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E
M<RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D<F5S=6QT+"!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)')E;W)D97(@/2`D
M=&AI<RT^<F5O<F1E<B@D<&%R96YT<RP@)&]R9&5R+"`D:60I.PH@("`@("`@
M(&EF("AI<U]A*"1R96]R9&5R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*"1R96]R9&5R+"!?7T9)3$5?7RP@7U],
M24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B`D<F5O
M<F1E<CL*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2!P87)E;G0Z.E]A
M9&0H)&9U;&QN86UE+"`D:60L("1P:60L("1O<F1E<BD["B`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("\J($EF('=E('-U
M8V-E<V9U;&QY(&EN<V5R=&5D('1H92!O8FIE8W0@86YD(&ET('-U<'!O<G1S
M"B`@("`@("`@("H@8F5I;F<@;6%P<&5D('1O('1H92!A='1R:6)U=&5S('1A
M8FQE+"!D;R!T:&%T(&YO=SH@*B\*("`@("`@("!I9B`H(65M<'1Y*"1A='1R
M:6)U=&5S*2D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/G5P9&%T
M941A=&$H)&]B:F5C="D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&ED.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAA;F=E<R!T:&4@;W)D97(@
M;V8@=&AE(&-H:6QD<F5N(&]F(&%N(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1P87)E;G0@(%1H92!F=6QL(&ED('!A=&@@;V8@=&AE
M('!A<F5N="!O8FIE8W0N"B`@("`@*B!`<&%R86T@;6EX960@)&]R9&5R("`@
M($EF(&%N(&%R<F%Y(&ET('-P96-I9FEE<R!T:&4@;F5W('!O<VET:6]N<R!F
M;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@86QL(&-H:6QD(&]B
M:F5C=',N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@($EF(&%N(&EN
M=&5G97(@86YD("1C:60@:7,@<W!E8VEF:65D+"!T:&4@<&]S:71I;VX*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@=VAE<F4@=&AE(&-H:6QD('-P
M96-I9FEE9"!B>2`D8VED(&ES(&EN<V5R=&5D+B!)9@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`D8VED(&ES(&YO="!S<&5C:69I960L('1H92!P
M;W-I=&EO;B!G971S(&1E;&5T960L"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@(&-A=7-I;F<@=&AE(&9O;&QO=VEN9R!P;W-I=&EO;G,@=&\@<VAI
M9G0@=7`N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8VED("`@(%-E92`D;W)D
M97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;W)D97(H)'!A<F5N="P@)&]R
M9&5R(#T@;G5L;"P@)&-I9"`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"$D
M<&%R96YT('Q\(&ES7V$H)'!A<F5N="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`O+R!!8F]R="!I;6UE9&EA=&5L>2!I9B!T:&4@<&%R96YT('-T
M<FEN9R!I<R!E;7!T>3L@=V4*("`@("`@("`@("`@+R\@8V%N;F]T('-A9F5L
M>2!R96]R9&5R(&%L;"!T;W`M;&5V96P@96QE;65N=',N"B`@("`@("`@("`@
M(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("1P<75E<GD@/2`G)SL*("`@
M("`@("!I9B`H(6ES7V%R<F%Y*"1O<F1E<BD@)B8@(6ES7VYU;&PH)&]R9&5R
M*2D@>PH@("`@("`@("`@("`O*B!3:6YG;&4@=7!D871E("AA9&0O9&5L*2X@
M*B\*("`@("`@("`@("`@:68@*&ES7VYU;&PH)&-I9"DI('L*("`@("`@("`@
M("`@("`@("\J($YO(&]B:F5C="!I9"!G:79E;B!S;R!S:'5F9FQE(&1O=VXN
M("HO"B`@("`@("`@("`@("`@("`D9&ER96-T:6]N(#T@)RTG.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+RH@5V4@:&%V92!A;B!O
M8FIE8W0@:60@<V\@<VAU9F9L92!U<"X@*B\*("`@("`@("`@("`@("`@("1D
M:7)E8W1I;VX@/2`G*R<["@H@("`@("`@("`@("`@("`@+RH@3&5A=FEN9R!T
M:&4@;F5W;'D@:6YS97)T960@;V)J96-T(&%L;VYE+B`J+PH@("`@("`@("`@
M("`@("`@)'!Q=65R>2`]('-P<FEN=&8H)R!!3D0@9&%T871R965?:60@(3T@
M)7,G+"`H:6YT*21C:60I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1Q
M=65R>2`]('-P<FEN=&8H)U501$%412`E<R!3150@9&%T871R965?;W)D97(@
M/2!D871A=')E95]O<F1E<B`E<R`Q(%=(15)%(&=R;W5P7W5I9"`]("5S($%.
M1"!D871A=')E95]P87)E;G1S(#T@)7,@04Y$(&1A=&%T<F5E7V]R9&5R(#X]
M("5S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG=&%B;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9&ER96-T:6]N+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?9&(M/G%U;W1E*"1T:&ES+3Y?<&%R86US6R=G<F]U<"==*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YQ=6]T92@D<&%R
M96YT*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I<U]N=6QL*"1O
M<F1E<BD@/R`G3E5,3"<@.B`H:6YT*21O<F1E<BD@+B`D<'%U97)Y.PH*("`@
M("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A
M5')E95]S<6PZ.G)E;W)D97(H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDI.PH@("`@("`@('T@96QS96EF
M("AI<U]A<G)A>2@D;W)D97(I*2!["B`@("`@("`@("`@("\J($UU;'1I('5P
M9&%T92X@*B\*("`@("`@("`@("`@)'%U97)Y(#T@)U-%3$5#5"!#3U5.5"AD
M871A=')E95]I9"DG("X*("`@("`@("`@("`@("`@("`@("`@)R!&4D]-("<@
M+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@("`@("`@("`@("`@("`@
M("`@("<@5TA%4D4@9W)O=7!?=6ED(#T@/R!!3D0@9&%T871R965?<&%R96YT
M<R`](#\G("X*("`@("`@("`@("`@("`@("`@("`@)R!'4D]54"!"62!D871A
M=')E95]P87)E;G1S)SL*("`@("`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1T
M:&ES+3Y?<&%R86US6R=G<F]U<"==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!A<F5N="D["@H@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G
M92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ<F5O<F1E<B@I.B`G("X@
M)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*
M"B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YG971/;F4H)'%U
M97)Y+"`D=F%L=65S*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@("`@('T@96QS96EF("AC;W5N="@D;W)D97(I("$]("1R
M97-U;'0I('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P
M;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D
M+B(I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&]?:V5Y(#T@,#L*
M("`@("`@("`@("`@9F]R96%C:"`H)&]R9&5R(&%S("1O7V-I9"D@>PH@("`@
M("`@("`@("`@("`@)'%U97)Y(#T@)U501$%412`G("X@)'1H:7,M/E]P87)A
M;7-;)W1A8FQE)UT@+@H@("`@("`@("`@("`@("`@("`@("`@("`@)R!3150@
M9&%T871R965?;W)D97(@/2`_(%=(15)%(&1A=&%T<F5E7VED(#T@/R<["B`@
M("`@("`@("`@("`@("`D=F%L=65S(#T@87)R87DH)&]?:V5Y+"!I<U]N=6QL
M*"1O7V-I9"D@/R!.54Q,(#H@*&EN="DD;U]C:60I.PH*("`@("`@("`@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@1&%T851R965?
M<W%L.CIR96]R9&5R*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("`@("`@)')E<W5L="`]
M("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`@("`@)&]?:V5Y*RL["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1P:60@/2`D=&AI<RT^9V5T260H)'!A<F5N="D[
M"@H@("`@("`@("`@("`O*B!292UO<F1E<B!O=7(@8V%C:&4N("HO"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7W)E;W)D97(H)'!I9"P@)&]R9&5R*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'!L:6-I=&QY('-E
M="!T:&4@;W)D97(@9F]R(&$@9&%T871R964@;V)J96-T+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1I9"`@("`@5&AE(&1A=&%T<F5E(&]B:F5C
M="!I9"!T;R!C:&%N9V4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;W)D97(@
M(%1H92!N97<@;W)D97(N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$]R9&5R
M*"1I9"P@)&]R9&5R*0H@("`@>PH@("`@("`@("1Q=65R>2`]("=54$1!5$4@
M)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==("X*("`@("`@("`@("`@("`@
M("`G(%-%5"!D871A=')E95]O<F1E<B`](#\@5TA%4D4@9&%T871R965?:60@
M/2`_)SL*("`@("`@("`D=F%L=65S(#T@87)R87DH:7-?;G5L;"@D;W)D97(I
M(#\@3E5,3"`Z("AI;G0I)&]R9&5R+`H@("`@("`@("`@("`@("`@("`@("`@
M("`H:6YT*21I9"D["@H@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@
M475E<GD@8GD@1&%T851R965?<W%L.CIS971/<F1E<B@I.B`G("X@)'%U97)Y
M+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@86X@;V)J96-T+@H@("`@
M("H*("`@("`J($!P87)A;2!M:7AE9"`@("1O8FIE8W0@(%1H92!O8FIE8W0@
M=&\@<F5M;W9E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&9O<F-E("`@1F]R
M8V4@<F5M;W9A;"!O9B!E=F5R>2!C:&EL9"!O8FIE8W0_"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')E;6]V92@D;V)J96-T+"`D9F]R8V4@/2!F86QS92D*("`@
M('L*("`@("`@("`D:60@/2`D=&AI<RT^9V5T260H)&]B:F5C="D["B`@("`@
M("`@)&]R9&5R(#T@)'1H:7,M/F=E=$]R9&5R*"1O8FIE8W0I.PH*("`@("`@
M("`D<75E<GD@/2`G4T5,14-4(&1A=&%T<F5E7VED($923TT@)R`N("1T:&ES
M+3Y?<&%R86US6R=T86)L92==("X*("`@("`@("`@("`@("`@("`G(%=(15)%
M(&=R;W5P7W5I9"`](#\@04Y$(&1A=&%T<F5E7W!A<F5N=',@3$E+12`_)R`N
M"B`@("`@("`@("`@("`@("`@)R!/4D1%4B!"62!D871A=')E95]I9"<["B`@
M("`@("`@)'9A;'5E<R`](&%R<F%Y*"1T:&ES+3Y?<&%R86US6R=G<F]U<"==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`G)3HG("X@*&EN="DD:60@+B`G
M)RD["@H@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@
M1&%T851R965?<W%L.CIR96UO=F4H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L
M(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@)&-H:6QD<F5N
M(#T@)'1H:7,M/E]D8BT^9V5T06QL*"1Q=65R>2P@)'9A;'5E<RP@1$)?1D54
M0TA-3T1%7T%34T]#*3L*"B`@("`@("`@:68@*&-O=6YT*"1C:&EL9')E;BDI
M('L*("`@("`@("`@("`@:68@*"1F;W)C92D@>PH@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)&-H:6QD<F5N(&%S("1C:&EL9"D@>PH@("`@("`@("`@("`@
M("`@("`@("1C870@/2`D=&AI<RT^9V5T3F%M92@D8VAI;&1;)V1A=&%T<F5E
M7VED)UTI.PH@("`@("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M<F5M;W9E*"1C870L('1R=64I.PH@("`@("`@("`@("`@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?
M*")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB*2P@8V]U;G0H
M)&-H:6QD<F5N*2DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`O*B!296UO=F4@871T<FEB=71E<R!F;W(@=&AI<R!O8FIE8W0N("HO"B`@
M("`@("`@)'%U97)Y(#T@)T1%3$5412!&4D]-("<@+B`D=&AI<RT^7W!A<F%M
M<ULG=&%B;&5?871T<FEB=71E<R==("X*("`@("`@("`@("`@("`@("`G(%=(
M15)%(&1A=&%T<F5E7VED(#T@/R<["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y
M*"AI;G0I)&ED*3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1
M=65R>2!B>2!$871A5')E95]S<6PZ.G)E;6]V92@I.B`G("X@)'%U97)Y+"!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@
M)'%U97)Y(#T@)T1%3$5412!&4D]-("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G72`N"B`@("`@("`@("`@("`@("`@)R!72$5212!D871A=')E95]I9"`]
M(#\G.PH@("`@("`@("1V86QU97,@/2!A<G)A>2@H:6YT*21I9"D["@H@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@1&%T851R965?
M<W%L.CIR96UO=F4H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?
M+"!014%27TQ/1U]$14)51RD["B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?
M9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@:68@*&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("1P87)E;G1S(#T@)'1H:7,M
M/F=E=%!A<F5N=$ED4W1R:6YG*"1O8FIE8W0I.PH@("`@("`@(&EF("AI<U]A
M*"1P87)E;G1S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<&%R96YT<SL*("`@("`@("!]"@H@("`@("`@("1R96]R9&5R(#T@)'1H
M:7,M/G)E;W)D97(H)'!A<F5N=',L("1O<F1E<BD["B`@("`@("`@:68@*&ES
M7V$H)')E;W)D97(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1R96]R9&5R.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&ES7V$H
M<&%R96YT.CIR96UO=F4H)&]B:F5C="DL("=014%27T5R<F]R)RD@/R`D:60@
M.B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!O;F4@;W(@
M;6]R92!O8FIE8W1S(&)Y(&ED+@H@("`@("H*("`@("`J(%1H:7,@9G5N8W1I
M;VX@9&]E<R`J;F]T*B!D;R!T:&4@=F%L:61A=&EO;BP@<F5O<F1E<FEN9RP@
M971C+B!T:&%T"B`@("`@*B!R96UO=F4H*2!D;V5S+B!)9B!Y;W4@;F5E9"!T
M;R!C:&5C:R!F;W(@8VAI;&1R96XL(')E+61O(&]R9&5R:6YG+"!E=&,N+`H@
M("`@("H@=&AE;B!Y;W4@;75S="!R96UO=F4H*2!O8FIE8W1S(&]N92UB>2UO
M;F4N(%1H:7,@:7,@9F]R(&-O9&4@=&AA="!K;F]W<PH@("`@("H@:70G<R!D
M96%L:6YG('=I=&@@<VEN9VQE("AN;VXM<&%R96YT960I(&]B:F5C=',@86YD
M(&YE961S('1O(&1E;&5T92!A"B`@("`@*B!B871C:"!O9B!T:&5M('%U:6-K
M;'DN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1I9',@(%1H92!O8FIE
M8W1S('1O(')E;6]V92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E0GE)
M9',H)&ED<RD*("`@('L*("`@("`@("`O*B!386YI=&EZ92!I;G!U="X@*B\*
M("`@("`@("!I9B`H(6ES7V%R<F%Y*"1I9',I*2!["B`@("`@("`@("`@("1I
M9',@/2!A<G)A>2@H:6YT*21I9',I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(&%R<F%Y7W=A;&LH)&ED<RP@)VEN='9A;"<I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@4F5M;W9I;F<@>F5R;R!O8FIE8W1S(&%L=V%Y<R!S=6-C
M965D<RX@*B\*("`@("`@("!I9B`H(21I9',I('L*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`O*B!296UO=F4@871T<FEB
M=71E<R!F;W(@)&ED<RX@*B\*("`@("`@("`D<75E<GD@/2`G1$5,151%($92
M3TT@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L95]A='1R:6)U=&5S)UT@+@H@
M("`@("`@("`@("`@("`@("<@5TA%4D4@9&%T871R965?:60@24X@*#\G("X@
M<W1R7W)E<&5A="@G+"`_)RP@8V]U;G0H)&ED<RD@+2`Q*2`N("<I)SL*("`@
M("`@("`D=F%L=65S(#T@)&ED<SL*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.G)E;6]V94)Y261S*"DZ
M("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"
M54<I.PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E
M<GDL("1V86QU97,I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@?0H*("`@("`@("`D<75E<GD@/2`G1$5,151%($923TT@)R`N("1T:&ES
M+3Y?<&%R86US6R=T86)L92==("X*("`@("`@("`@("`@("`@("`G(%=(15)%
M(&1A=&%T<F5E7VED($E.("@_)R`N('-T<E]R97!E870H)RP@/R<L(&-O=6YT
M*"1I9',I("T@,2D@+B`G*2<["B`@("`@("`@)'9A;'5E<R`]("1I9',["@H@
M("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@1&%T851R
M965?<W%L.CIR96UO=F5">4ED<R@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@
M7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E;6]V97,@;VYE(&]R(&UO<F4@;V)J96-T<R!B>2!N86UE
M+@H@("`@("H*("`@("`J(%1H:7,@9G5N8W1I;VX@9&]E<R`J;F]T*B!D;R!T
M:&4@=F%L:61A=&EO;BP@<F5O<F1E<FEN9RP@971C+B!T:&%T"B`@("`@*B!R
M96UO=F4H*2!D;V5S+B!)9B!Y;W4@;F5E9"!T;R!C:&5C:R!F;W(@8VAI;&1R
M96XL(')E+61O(&]R9&5R:6YG+"!E=&,N+`H@("`@("H@=&AE;B!Y;W4@;75S
M="!R96UO=F4H*2!O8FIE8W1S(&]N92UB>2UO;F4N(%1H:7,@:7,@9F]R(&-O
M9&4@=&AA="!K;F]W<PH@("`@("H@:70G<R!D96%L:6YG('=I=&@@<VEN9VQE
M("AN;VXM<&%R96YT960I(&]B:F5C=',@86YD(&YE961S('1O(&1E;&5T92!A
M"B`@("`@*B!B871C:"!O9B!T:&5M('%U:6-K;'DN"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1N86UE<R`@5&AE(&]B:F5C=',@=&\@<F5M;W9E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5">4YA;65S*"1N86UE<RD*("`@
M('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1N86UE<RDI('L*("`@("`@("`@
M("`@)&YA;65S(#T@87)R87DH)&YA;65S*3L*("`@("`@("!]"@H@("`@("`@
M("\J(%)E;6]V:6YG('IE<F\@;V)J96-T<R!A;'=A>7,@<W5C8V5E9',N("HO
M"B`@("`@("`@:68@*"$D;F%M97,I('L*("`@("`@("`@("`@<F5T=7)N('1R
M=64["B`@("`@("`@?0H*("`@("`@("`D<75E<GD@/2`G4T5,14-4(&1A=&%T
M<F5E7VED($923TT@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==("X*("`@
M("`@("`@("`@("`@("`G(%=(15)%(&1A=&%T<F5E7VYA;64@24X@*#\G("X@
M<W1R7W)E<&5A="@G+"`_)RP@8V]U;G0H)&YA;65S*2`M(#$I("X@)RDG.PH@
M("`@("`@("1V86QU97,@/2`D;F%M97,["@H@("`@("`@($AO<F1E.CIL;V=-
M97-S86=E*"=344P@475E<GD@8GD@1&%T851R965?<W%L.CIR96UO=F5">4YA
M;65S*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?1$5"54<I.PH@("`@("`@("1I9',@/2`D=&AI<RT^7V1B+3YG971#;VPH
M)'%U97)Y+"`P+"`D=F%L=65S*3L*("`@("`@("!I9B`H:7-?82@D:61S+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D:61S.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3YR96UO=F5">4ED<R@D:61S
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($UO=F4@86X@;V)J96-T('1O(&$@
M;F5W('!A<F5N="X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@("1O8FIE
M8W0@("`@(%1H92!O8FIE8W0@=&\@;6]V92X*("`@("`J($!P87)A;2!S=')I
M;F<@)&YE=W!A<F5N="`@5&AE(&YE=R!P87)E;G0@;V)J96-T+B!$969A=6QT
M<R!T;R!T:&4@<F]O="X*("`@("`J+PH@("`@9G5N8W1I;VX@;6]V92@D;V)J
M96-T+"`D;F5W<&%R96YT(#T@;G5L;"D*("`@('L*("`@("`@("`D;VQD7W!A
M<F5N=%]P871H(#T@)'1H:7,M/F=E=%!A<F5N=$ED4W1R:6YG*"1O8FIE8W0I
M.PH@("`@("`@("1R97-U;'0@/2!P87)E;G0Z.FUO=F4H)&]B:F5C="P@)&YE
M=W!A<F5N="D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]
M"B`@("`@("`@)&ED(#T@)'1H:7,M/F=E=$ED*"1O8FIE8W0I.PH@("`@("`@
M("1N97=?<&%R96YT7W!A=&@@/2`D=&AI<RT^9V5T4&%R96YT2613=')I;F<H
M)&]B:F5C="D["@H@("`@("`@("\J($9E=&-H('1H92!O8FIE8W0@8F5I;F<@
M;6]V960@86YD(&%L;"!O9B!I=',@8VAI;&1R96XL('-I;F-E"B`@("`@("`@
M("H@=V4@86QS;R!N965D('1O('5P9&%T92!T:&5I<B!P87)E;G0@<&%T:',@
M=&\@879O:60@8W)E871I;F<*("`@("`@("`@*B!O<G!H86YS+B`J+PH@("`@
M("`@("1Q=65R>2`]("=314Q%0U0@9&%T871R965?:60L(&1A=&%T<F5E7W!A
M<F5N=',G("X*("`@("`@("`@("`@("`@("`G($923TT@)R`N("1T:&ES+3Y?
M<&%R86US6R=T86)L92==("X*("`@("`@("`@("`@("`@("`G(%=(15)%(&1A
M=&%T<F5E7W!A<F5N=',@/2`_($]2(&1A=&%T<F5E7W!A<F5N=',@3$E+12`_
M)R`N"B`@("`@("`@("`@("`@("`@)R!/4B!D871A=')E95]I9"`](#\G.PH@
M("`@("`@("1V86QU97,@/2!A<G)A>2@D;VQD7W!A<F5N=%]P871H("X@)SHG
M("X@)&ED+`H@("`@("`@("`@("`@("`@("`@("`@("`D;VQD7W!A<F5N=%]P
M871H("X@)SHG("X@)&ED("X@)SHE)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@*&EN="DD:60I.PH*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,
M(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ;6]V92@I.B`G("X@)'%U97)Y+"!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`D
M<F]W<V5T(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*
M("`@("`@("!I9B`H:7-?82@D<F]W<V5T+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F]W<V5T.PH@("`@("`@('T*"B`@("`@("`@
M+RH@57!D871E(&5A8V@@;V)J96-T+"!R97!L86-I;F<@=&AE(&]L9"!P87)E
M;G0@<&%T:"!W:71H('1H90H@("`@("`@("`J(&YE=R!O;F4N("HO"B`@("`@
M("`@=VAI;&4@*"1R;W<@/2`D<F]W<V5T+3YF971C:%)O=RA$0E]&151#2$U/
M1$5?05-33T,I*2!["B`@("`@("`@("`@(&EF("AI<U]A*"1R;W<L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F]W.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D;W%U97)Y(#T@)R<["B`@("`@("`@
M("`@(&EF("@D<F]W6R=D871A=')E95]I9"==(#T]("1I9"D@>PH@("`@("`@
M("`@("`@("`@)&]Q=65R>2`]("<L(&1A=&%T<F5E7V]R9&5R(#T@,"`G.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!$;R!S=')?<F5P;&%C92@I
M(&]N;'D@:68@=&AI<R!I<R!N;W0@82!F:7)S="!L979E;`H@("`@("`@("`@
M("`@*B!O8FIE8W0N("HO"B`@("`@("`@("`@(&EF("@A96UP='DH)')O=ULG
M9&%T871R965?<&%R96YT<R==*2D@>PH@("`@("`@("`@("`@("`@)'!P871H
M(#T@<W1R7W)E<&QA8V4H)&]L9%]P87)E;G1?<&%T:"P@)&YE=U]P87)E;G1?
M<&%T:"P@)')O=ULG9&%T871R965?<&%R96YT<R==*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1P<&%T:"`]("1N97=?<&%R96YT
M7W!A=&@["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'%U97)Y(#T@<W!R
M:6YT9B@G55!$051%("5S(%-%5"!D871A=')E95]P87)E;G1S(#T@)7,G("X@
M)&]Q=65R>2`N("<@5TA%4D4@9&%T871R965?:60@/2`E<R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D8BT^<75O
M=&4H)'!P871H*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`H:6YT
M*21R;W=;)V1A=&%T<F5E7VED)UTI.PH*("`@("`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.FUO=F4H*3H@
M)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)5
M1RD["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D
M<75E<GDI.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&]R9&5R(#T@)'1H:7,M
M/F=E=$]R9&5R*"1O8FIE8W0I.PH*("`@("`@("`O*B!3:'5F9FQE(&1O=VX@
M=&AE(&]L9"!O<F1E<B!P;W-I=&EO;G,N("HO"B`@("`@("`@)')E;W)D97(@
M/2`D=&AI<RT^<F5O<F1E<B@D;VQD7W!A<F5N=%]P871H+"`D;W)D97(I.PH*
M("`@("`@("`O*B!3:'5F9FQE('5P('1H92!N97<@;W)D97(@<&]S:71I;VYS
M+B`J+PH@("`@("`@("1R96]R9&5R(#T@)'1H:7,M/G)E;W)D97(H)&YE=U]P
M87)E;G1?<&%T:"P@,"P@)&ED*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#:&%N9V4@86X@;V)J96-T)W,@;F%M92X*
M("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@("1O;&1?;V)J96-T("`@("`@
M(%1H92!O;&0@;V)J96-T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W7V]B
M:F5C=%]N86UE("!4:&4@;F5W(&]B:F5C="!N86UE+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!R96YA;64H)&]L9%]O8FIE8W0L("1N97=?;V)J96-T7VYA;64I
M"B`@("!["B`@("`@("`@+RH@1&\@=&AE(&-A8VAE(')E;F%M:6YG(&9I<G-T
M("HO"B`@("`@("`@)')E<W5L="`]('!A<F5N=#HZ<F5N86UE*"1O;&1?;V)J
M96-T+"`D;F5W7V]B:F5C=%]N86UE*3L*("`@("`@("!I9B`H:7-?82@D<F5S
M=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@('T*"B`@("`@("`@+RH@1V5T('1H92!O8FIE8W0@:60@
M86YD('-E="!U<"!T:&4@<W%L('%U97)Y+B`J+PH@("`@("`@("1I9"`]("1T
M:&ES+3YG971)9"@D;VQD7V]B:F5C="D["B`@("`@("`@)'%U97)Y(#T@)U50
M1$%412`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@+@H@("`@("`@("`@
M("`@("`@("<@4T54(&1A=&%T<F5E7VYA;64@/2`_(%=(15)%(&1A=&%T<F5E
M7VED(#T@/R<["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*%-T<FEN9SHZ8V]N
M=F5R=$-H87)S970H)&YE=U]O8FIE8W1?;F%M92P@3DQ3.CIG971#:&%R<V5T
M*"DL("1T:&ES+3Y?<&%R86US6R=C:&%R<V5T)UTI+`H@("`@("`@("`@("`@
M("`@("`@("`@("`H:6YT*21I9"D["@H@("`@("`@($AO<F1E.CIL;V=-97-S
M86=E*"=344P@475E<GD@8GD@1&%T851R965?<W%L.CIR96YA;64H*3H@)R`N
M("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD[
M"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@
M)'9A;'5E<RD["@H@("`@("`@(')E='5R;B!I<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RD@/R`D<F5S=6QT(#H@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E=')I979E<R!D871A(&9O<B!A;B!O8FIE8W0@9G)O;2!T:&4@9&%T
M871R965?9&%T82!F:65L9"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D8VED("!4:&4@;V)J96-T(&ED('1O(&9E=&-H+"!O<B!A;B!A<G)A>2!O
M9B!O8FIE8W0@:61S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$871A*"1C
M:60I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]397)I86QI
M>F4N<&AP)SL*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1C:60I*2!["B`@("`@
M("`@("`@(&EF("@A8V]U;G0H)&-I9"DI('L*("`@("`@("`@("`@("`@(')E
M='5R;B!A<G)A>2@I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<75E
M<GD@/2!S<')I;G1F*"=314Q%0U0@9&%T871R965?:60L(&1A=&%T<F5E7V1A
M=&$L(&1A=&%T<F5E7W-E<FEA;&EZ960@1E)/32`E<R!72$5212!D871A=')E
M95]I9"!)3B`H)7,I)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I;7!L;V1E*"<L("<L("1C:60I*3L*"B`@("`@("`@("`@($AO
M<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@1&%T851R965?<W%L.CIG
M971$871A*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?1$5"54<I.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D
M8BT^9V5T07-S;V,H)'%U97)Y*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@2&]R9&4Z
M.FQO9TUE<W-A9V4H)')E<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U]%4E(I.PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1D871A(#T@87)R87DH*3L*("`@
M("`@("`@("`@9F]R96%C:"`H)')E<W5L="!A<R`D:60@/3X@)')O=RD@>PH@
M("`@("`@("`@("`@("`@)&1A=&%;)&ED72`]($AO<F1E7U-E<FEA;&EZ93HZ
M=6YS97)I86QI>F4H)')O=ULP72P@)')O=ULQ72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($Y,
M4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("`@("`@("`@("\J($-O;G9E<G0@
M;VQD(&1A=&$@=&\@=&AE(&YE=R!F;W)M870N("HO"B`@("`@("`@("`@("`@
M("!I9B`H)')O=ULQ72`]/2!315))04Q)6D5?0D%324,I('L*("`@("`@("`@
M("`@("`@("`@("`D9&%T85LD:61=(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E
M="@D9&%T85LD:61=+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@($Y,4SHZ9V5T0VAA<G-E="AT<G5E
M*2D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)&1A=&%;
M)&ED72`]("AI<U]N=6QL*"1D871A6R1I9%TI('Q\("%I<U]A<G)A>2@D9&%T
M85LD:61=*2D*("`@("`@("`@("`@("`@("`@("`_(&%R<F%Y*"D*("`@("`@
M("`@("`@("`@("`@("`Z("1D871A6R1I9%T["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@(')E='5R;B`D9&%T83L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D<75E<GD@/2`G4T5,14-4(&1A=&%T<F5E7V1A=&$L(&1A=&%T
M<F5E7W-E<FEA;&EZ960G("X*("`@("`@("`@("`@("`@("`@("`@)R!&4D]-
M("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@("`@("`@("`@("`@
M("`@("`@("<@5TA%4D4@9&%T871R965?:60@/2`_)SL*("`@("`@("`@("`@
M)'9A;'5E<R`](&%R<F%Y*"AI;G0I)&-I9"D["@H@("`@("`@("`@("!(;W)D
M93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ9V5T
M1&%T82@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T1%0E5'*3L*("`@("`@("`@("`@)')O=R`]("1T:&ES+3Y?9&(M/F=E
M=%)O=R@D<75E<GDL("1V86QU97,L($1"7T9%5$-(34]$15]!4U-/0RD["@H@
M("`@("`@("`@("`D9&%T82`]($AO<F1E7U-E<FEA;&EZ93HZ=6YS97)I86QI
M>F4H)')O=ULG9&%T871R965?9&%T82==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')O=ULG9&%T871R965?
M<V5R:6%L:7IE9"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@
M("`@("`O*B!#;VYV97)T(&]L9"!D871A('1O('1H92!N97<@9F]R;6%T+B`J
M+PH@("`@("`@("`@("!I9B`H)')O=ULG9&%T871R965?<V5R:6%L:7IE9"==
M(#T](%-%4DE!3$E:15]"05-)0RD@>PH@("`@("`@("`@("`@("`@)&1A=&$@
M/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1D871A+"!.3%,Z.F=E=$-H87)S
M970H=')U92DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`H
M:7-?;G5L;"@D9&%T82D@?'P@(6ES7V%R<F%Y*"1D871A*2D@/R!A<G)A>2@I
M(#H@)&1A=&$["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M<FEE=F5S(&1A=&$@9F]R(&%N(&]B:F5C="!F<F]M('1H92!H;W)D95]D871A
M=')E95]A='1R:6)U=&5S('1A8FQE+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R?&%R<F%Y("1C:60@(%1H92!O8FIE8W0@:60@=&\@9F5T8V@L(&]R
M(&%N(&%R<F%Y(&]F"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!O8FIE8W0@:61S+@H@("`@("H@0'!A<F%M(&%R<F%Y("1K97ES("`@("`@
M("`@5&AE(&%T=')I8G5T97,@:V5Y<R!T;R!F971C:"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!!(&AA<V@@;V8@871T<FEB=71E<RP@;W(@82!M
M=6QT:2UL979E;"!H87-H(&]F(&]B:F5C=`H@("`@("H@("`@("`@("`@("`@
M("`@:61S(#T^('1H96ER(&%T=')I8G5T97,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$%T=')I8G5T97,H)&-I9"P@)&ME>7,@/2!F86QS92D*("`@('L*
M("`@("`@("!I9B`H96UP='DH)&-I9"DI('L*("`@("`@("`@("`@<F5T=7)N
M(&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("!I9B`H)&ME>7,I('L*("`@
M("`@("`@("`@)&9I;'1E<B`]('-P<FEN=&8H)R!!3D0@871T<FEB=71E7VME
M>2!)3B`H7"<E<UPG*2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EM<&QO9&4H(B<L("<B+"`D:V5Y<RDI.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1F:6QT97(@/2`G)SL*("`@("`@("!]"@H@("`@("`@(&EF
M("AI<U]A<G)A>2@D8VED*2D@>PH@("`@("`@("`@("`D<75E<GD@/2!S<')I
M;G1F*"=314Q%0U0@9&%T871R965?:60L(&%T=')I8G5T95]N86UE($%3(&YA
M;64L(&%T=')I8G5T95]K97D@05,@(FME>2(L(&%T=')I8G5T95]V86QU92!!
M4R!V86QU92!&4D]-("5S(%=(15)%(&1A=&%T<F5E7VED($E.("@E<RDE<R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)W1A8FQE7V%T=')I8G5T97,G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I;7!L;V1E*"<L("<L("1C:60I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1F:6QT97(I.PH*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE
M<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.F=E=$%T=')I8G5T
M97,H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U]$14)51RD["B`@("`@("`@("`@("1R;W=S(#T@)'1H:7,M/E]D8BT^9V5T
M06QL*"1Q=65R>2P@1$)?1D540TA-3T1%7T%34T]#*3L*("`@("`@("`@("`@
M:68@*&ES7V$H)')O=W,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D<F]W<SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M)&1A=&$@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D<F]W<R!A
M<R`D<F]W*2!["B`@("`@("`@("`@("`@("!I9B`H96UP='DH)&1A=&%;)')O
M=ULG9&%T871R965?:60G75TI*2!["B`@("`@("`@("`@("`@("`@("`@)&1A
M=&%;)')O=ULG9&%T871R965?:60G75T@/2!A<G)A>2@I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@)&1A=&%;)')O=ULG9&%T871R965?
M:60G75U;72`](&%R<F%Y*"=N86UE)R`]/B`D<F]W6R=N86UE)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VME>2<@/3X@)')O=ULG:V5Y)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9A;'5E)R`]/B!3
M=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1R;W=;)W9A;'5E)UTL("1T:&ES+3Y?
M<&%R86US6R=C:&%R<V5T)UTL($Y,4SHZ9V5T0VAA<G-E="@I*2D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1D871A.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)U-%3$5#5"!A
M='1R:6)U=&5?;F%M92!!4R!N86UE+"!A='1R:6)U=&5?:V5Y($%3(")K97DB
M+"!A='1R:6)U=&5?=F%L=64@05,@=F%L=64@1E)/32`E<R!72$5212!D871A
M=')E95]I9"`]("5S)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=T86)L95]A='1R:6)U=&5S)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@*&EN="DD8VED+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1F:6QT97(I.PH*("`@("`@("`@("`@2&]R9&4Z
M.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.F=E=$%T
M=')I8G5T97,H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U]$14)51RD["B`@("`@("`@("`@("1R;W=S(#T@)'1H:7,M/E]D
M8BT^9V5T06QL*"1Q=65R>2P@1$)?1D540TA-3T1%7T%34T]#*3L*("`@("`@
M("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)')O=W,I.R`D:2LK*2![
M"B`@("`@("`@("`@("`@("`D<F]W<ULD:5U;)W9A;'5E)UT@/2!3=')I;F<Z
M.F-O;G9E<G1#:&%R<V5T*"1R;W=S6R1I75LG=F%L=64G72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(')E='5R;B`D<F]W<SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!N=6UB97(@;V8@;V)J96-T<R!M871C:&EN9R!A
M('-E="!O9B!A='1R:6)U=&4@8W)I=&5R:6$N"B`@("`@*@H@("`@("H@0'-E
M92!B=6EL9$%T=')I8G5T95%U97)Y*"D*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@("`D8W)I=&5R:6$@("!4:&4@87)R87D@;V8@8W)I=&5R:6$N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("`D<&%R96YT("`@("!4:&4@<&%R96YT(&YO
M9&4@=&\@<W1A<G0@<V5A<F-H:6YG(&9R;VTN"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D86QL3&5V96QS("!2971U<FX@86QL(&QE=F5L<RP@;W(@:G5S="!T
M:&4@9&ER96-T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C
M:&EL9')E;B!O9B`D<&%R96YT/R!$969A=6QT<R!T;R!A;&P@;&5V96QS+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)')E<W1R:6-T("`@3VYL>2!R971U<FX@
M871T<FEB=71E<R!W:71H('1H92!S86UE"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!A='1R:6)U=&5?;F%M92!O<B!A='1R:6)U=&5?:60N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O=6YT0GE!='1R:6)U=&5S*"1C<FET
M97)I82P@)'!A<F5N="`]($1!5$%44D5%7U)/3U0L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D86QL3&5V96QS(#T@=')U92P@)')E<W1R:6-T
M(#T@)VYA;64G*0H@("`@>PH@("`@("`@(&EF("@A8V]U;G0H)&-R:71E<FEA
M*2D@>PH@("`@("`@("`@("!R971U<FX@,#L*("`@("`@("!]"@H@("`@("`@
M("1A<2`]("1T:&ES+3YB=6EL9$%T=')I8G5T95%U97)Y*"1C<FET97)I82P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R
M96YT+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1A;&Q,979E;',L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)')E<W1R:6-T+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@($1!5$%44D5%7T)524Q$7T-/54Y4*3L*("`@("`@
M("!I9B`H:7-?82@D87$L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1A<3L*("`@("`@("!]"B`@("`@("`@;&ES="@D<75E<GDL("1V
M86QU97,I(#T@)&%Q.PH*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,
M(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ8V]U;G1">4%T=')I8G5T97,H*3H@
M)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)5
M1RD["@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E
M<GDL("1V86QU97,I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E
M<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@)')O
M=R`]("8D<F5S=6QT+3YF971C:%)O=R@I.PH@("`@("`@(&EF("AI<U]A*"1R
M;W<L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE
M<W-A9V4H)')O=RP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I
M.PH@("`@("`@("`@("!R971U<FX@)')O=SL*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D<F]W6S!=.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!A('-E="!O9B!O8FIE8W0@:61S(&)A<V5D(&]N(&$@<V5T(&]F(&%T=')I
M8G5T92!C<FET97)I82X*("`@("`J"B`@("`@*B!`<V5E(&)U:6QD071T<FEB
M=71E475E<GDH*0H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@("1C<FET
M97)I82`@("`@5&AE(&%R<F%Y(&]F(&-R:71E<FEA+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@)'!A<F5N="`@("`@("!4:&4@<&%R96YT(&YO9&4@=&\@<W1A
M<G0@<V5A<F-H:6YG(&9R;VTN"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D86QL
M3&5V96QS("`@(%)E='5R;B!A;&P@;&5V96QS+"!O<B!J=7-T('1H92!D:7)E
M8W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8VAI;&1R
M96X@;V8@)'!A<F5N=#\@1&5F875L=',@=&\@86QL(&QE=F5L<RX*("`@("`J
M($!P87)A;2!S=')I;F<@("1R97-T<FEC="`@("`@3VYL>2!R971U<FX@871T
M<FEB=71E<R!W:71H('1H92!S86UE"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%T=')I8G5T95]N86UE(&]R(&%T=')I8G5T95]I9"X*
M("`@("`J($!P87)A;2!I;G1E9V5R("1F<F]M("`@("`@("`@5&AE(&]B:F5C
M="!T;R!S=&%R="!T;R!F971C:&EN9PH@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&-O=6YT("`@("`@("!4:&4@;G5M8F5R(&]F(&]B:F5C=',@=&\@9F5T8V@*
M("`@("`J($!P87)A;2!S=')I;F<@("1S;W)T8GE?;F%M92`@071T<FEB=71E
M(&YA;64@=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@)'-O<G1B>5]K97D@("!!='1R:6)U=&4@:V5Y('1O('5S92!F;W(@<V]R
M=&EN9RX*("`@("`J($!P87)A;2!I;G1E9V5R("1D:7)E8W1I;VX@("`@4V]R
M="!D:7)E8W1I;VXZ"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@,"`M(&%S8V5N9&EN9PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#$@+2!D97-C96YD:6YG"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$)Y071T<FEB=71E<R@D8W)I=&5R:6$L("1P87)E;G0@/2!$051!
M5%)%15]23T]4+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A;&Q,
M979E;',@/2!T<G5E+"`D<F5S=')I8W0@/2`G;F%M92<L("1F<F]M(#T@,"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]U;G0@/2`P+"`D<V]R
M=&)Y7VYA;64@/2!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1S;W)T8GE?:V5Y(#T@;G5L;"P@)&1I<F5C=&EO;B`](#`I"B`@("!["B`@
M("`@("`@:68@*"%C;W5N="@D8W)I=&5R:6$I*2!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*"=N;R!C<FET97)I82<I.PH@("`@("`@
M('T*"B`@("`@("`@)&%Q(#T@)'1H:7,M/F)U:6QD071T<FEB=71E475E<GDH
M)&-R:71E<FEA+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P87)E;G0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&%L;$QE=F5L<RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<F5S=')I8W0L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@1$%40512145?0E5)3$1?4T5,
M14-4+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1S;W)T8GE?;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<V]R=&)Y7VME>2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9&ER96-T:6]N*3L*("`@("`@("!I9B`H
M:7-?82@D87$L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1A<3L*("`@("`@("!]"B`@("`@("`@;&ES="@D<75E<GDL("1V86QU97,I
M(#T@)&%Q.PH*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y
M(&)Y($1A=&%4<F5E7W-Q;#HZ9V5T0GE!='1R:6)U=&5S*"DZ("<@+B`D<75E
M<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@
M("`@("!I9B`H)&-O=6YT*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^7V1B+3YL:6UI=%%U97)Y*"1Q=65R>2P@)&9R;VTL("1C;W5N="P@)'9A
M;'5E<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')E<W5L="`]
M("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@
M?0H*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-U;'0L(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T
M=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@("`@("1R;W=S(#T@87)R87DH
M*3L*("`@("`@("!W:&EL92`H)')O=R`]("8D<F5S=6QT+3YF971C:%)O=R@I
M*2!["B`@("`@("`@("`@("1R;W=S6R1R;W=;,%U=(#T@4W1R:6YG.CIC;VYV
M97)T0VAA<G-E="@D<F]W6S%=+"`D=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==
M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F]W<SL*("`@('T*"B`@
M("`O*BH*("`@("`J(%-O<G1S($E$<R!B>2!A='1R:6)U=&4@=F%L=65S+B!)
M1',@=VET:&]U="!A='1R:6)U=&5S('=I;&P@8F4@861D960@=&\*("`@("`J
M('1H92!E;F0@;V8@=&AE('-O<G1E9"!L:7-T+@H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`D=6YO<F1E<F5D7VED<R`@07)R87D@;V8@:61S('1O('-O
M<G0N"B`@("`@*B!`<&%R86T@87)R87D@)'-O<G1B>5]N86UE("`@($%T=')I
M8G5T92!N86UE('1O('5S92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A;2!A
M<G)A>2`D<V]R=&)Y7VME>2`@("`@071T<FEB=71E(&ME>2!T;R!U<V4@9F]R
M('-O<G1I;F<N"B`@("`@*B!`<&%R86T@87)R87D@)&1I<F5C=&EO;B`@("`@
M(%-O<G0@9&ER96-T:6]N.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#`@+2!A<V-E;F1I;F<*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Q("T@9&5S8V5N9&EN9PH@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@(%-O<G1E9"!I9',N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-O<G1">4%T=')I8G5T97,H)'5N;W)D97)E9%]I9',L("1S;W)T8GE?
M;F%M92`](&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S
M;W)T8GE?:V5Y(#T@;G5L;"P@)&1I<F5C=&EO;B`](#`I"B`@("!["B`@("`@
M("`@+RH@4V5L96-T(&ED<R!O<F1E<F5D(&)Y(&%T=')I8G5T92!V86QU92X@
M*B\*("`@("`@("`D=VAE<F4@/2`G)SL*("`@("`@("!I9B`H(6ES7VYU;&PH
M)'-O<G1B>5]N86UE*2D@>PH@("`@("`@("`@("`D=VAE<F4@/2!S<')I;G1F
M*"<@04Y$(&%T=')I8G5T95]N86UE(#T@)7,@)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YQ=6]T92@D<V]R=&)Y7VYA;64I
M*3L*("`@("`@("!]"B`@("`@("`@:68@*"%I<U]N=6QL*"1S;W)T8GE?:V5Y
M*2D@>PH@("`@("`@("`@("`D=VAE<F4@/2!S<')I;G1F*"<E<R!!3D0@871T
M<FEB=71E7VME>2`]("5S("<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'=H97)E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?9&(M/G%U;W1E*"1S;W)T8GE?:V5Y*2D["B`@("`@("`@?0H*("`@("`@
M("`D<75E<GD@/2!S<')I;G1F*"=314Q%0U0@9&%T871R965?:60@1E)/32`E
M<R!72$5212!D871A=')E95]I9"!)3B`H)7,I("5S($]21$52($)9(&%T=')I
M8G5T95]V86QU92`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG=&%B;&5?871T<FEB=71E<R==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@:6UP;&]D92@G+"<L("1U;F]R9&5R961?:61S*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("1W:&5R92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("@D9&ER96-T:6]N(#T](#$I(#\@)T1%4T,G(#H@)T%30R<I
M.PH*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($1A
M=&%4<F5E7W-Q;#HZ<V]R=$)Y071T<FEB=71E<R@I.B`G("X@)'%U97)Y+"!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`D
M;W)D97)E9%]I9',@/2`D=&AI<RT^7V1B+3YG971#;VPH)'%U97)Y*3L*"B`@
M("`@("`@+RH@36%K92!S=7)E('1H870@<V]M92!I9',@9&ED;B=T(&=E="!L
M;W-T(&)E8V%U<V4@:&%S(&YO('-U8V@*("`@("`@("`@*B!A='1R:6)U=&4@
M;F%M92]K97DN($%P<&5N9"!T:&5M('1O('1H92!E;F0N("HO"B`@("`@("`@
M:68@*&-O=6YT*"1O<F1E<F5D7VED<RD@(3T@8V]U;G0H)'5N;W)D97)E9%]I
M9',I*2!["B`@("`@("`@("`@("1O<F1E<F5D7VED<R`](&%R<F%Y7W5N:7%U
M92AA<G)A>5]M97)G92@D;W)D97)E9%]I9',L("1U;F]R9&5R961?:61S*2D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&]R9&5R961?:61S.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&QI<W0@;V8@86QL(&]F('1H
M92!A=F%I;&%B;&4@=F%L=65S(&]F('1H92!G:79E;B!A='1R:6)U=&4*("`@
M("`J(&YA;64O:V5Y(&-O;6)I;F%T:6]N+B!%:71H97(@871T<FEB=71E7VYA
M;64@;W(@871T<FEB=71E7VME>2!-55-4(&)E"B`@("`@*B!S=7!P;&EE9"P@
M86YD(&)O=&@@34%9(&)E('-U<'!L:65D+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@("1A='1R:6)U=&5?;F%M92`@5&AE(&YA;64@;V8@=&AE(&%T
M=')I8G5T92X*("`@("`J($!P87)A;2!S=')I;F<@("1A='1R:6)U=&5?:V5Y
M("`@5&AE(&ME>2!V86QU92!O9B!T:&4@871T<FEB=71E+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`@)'!A<F5N="`@("`@("`@("!4:&4@<&%R96YT(&YO9&4@
M=&\@<W1A<G0@<V5A<F-H:6YG(&9R;VTN"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D86QL3&5V96QS("`@("`@(%)E='5R;B!A;&P@;&5V96QS+"!O<B!J=7-T
M('1H92!D:7)E8W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8VAI;&1R96X@;V8@)'!A<F5N=#\@1&5F875L=',@=&\@86QL"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&QE=F5L<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B!A;&P@
M;V8@=&AE(&%V86EL86)L92!V86QU97,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$%T=')I8G5T959A;'5E<R@D871T<FEB=71E7VYA;64@/2!N=6QL+"`D
M871T<FEB=71E7VME>2`](&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!A<F5N="`]($1!5$%44D5%7U)/3U0L("1A;&Q,979E;',@
M/2!T<G5E*0H@("`@>PH@("`@("`@("\O($)U:6QD('1H92!N86UE+VME>2!F
M:6QT97(N"B`@("`@("`@)'=H97)E(#T@)R<["B`@("`@("`@:68@*"%I<U]N
M=6QL*"1A='1R:6)U=&5?;F%M92DI('L*("`@("`@("`@("`@)'=H97)E("X]
M("=A+F%T=')I8G5T95]N86UE(#T@)R`N("1T:&ES+3Y?9&(M/G%U;W1E*"1A
M='1R:6)U=&5?;F%M92D["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-?;G5L
M;"@D871T<FEB=71E7VME>2DI('L*("`@("`@("`@("`@:68@*"1W:&5R92D@
M>PH@("`@("`@("`@("`@("`@)'=H97)E("X]("<@04Y$("<["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)'=H97)E("X]("=A+F%T=')I8G5T95]K97D@
M/2`G("X@)'1H:7,M/E]D8BT^<75O=&4H)&%T=')I8G5T95]K97DI.PH@("`@
M("`@('T*"B`@("`@("`@+R\@4F5T=7)N(&EF('=E(&AA=F4@;F\@8W)I=&5R
M:6$N"B`@("`@("`@:68@*"$D=VAE<F4I('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)VYO(&-R:71E<FEA)RD["B`@("`@("`@?0H*
M("`@("`@("`O+R!!9&0@9FEL=&5R:6YG(&)Y('!A<F5N="P@86YD(&9O<B!O
M;F4@;W(@86QL(&QE=F5L<RX*("`@("`@("`D;&5V96Q1=65R>2`]("<G.PH@
M("`@("`@(&EF("@D<&%R96YT("$]($1!5$%44D5%7U)/3U0I('L*("`@("`@
M("`@("`@)'!A<G1S(#T@97AP;&]D92@G.B<L("1P87)E;G0I.PH@("`@("`@
M("`@("`D<&%R96YT<R`]("<G.PH@("`@("`@("`@("`D<'-T<FEN9R`]("<G
M.PH@("`@("`@("`@("!F;W)E86-H("@D<&%R=',@87,@)'!A<G0I('L*("`@
M("`@("`@("`@("`@("1P<W1R:6YG("X]("AE;7!T>2@D<'-T<FEN9RD@/R`G
M)R`Z("<Z)RD@+B`D<&%R=#L*("`@("`@("`@("`@("`@("1P:60@/2`D=&AI
M<RT^9V5T260H)'!S=')I;F<I.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H
M)'!I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D<&ED.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)'!A<F5N=',@+CT@)SHG("X@)'!I9#L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@:68@*"1A;&Q,979E;',I('L*("`@("`@("`@("`@("`@("1L979E
M;%%U97)Y(#T@<W!R:6YT9B@G04Y$("AD871A=')E95]P87)E;G1S(#T@)7,@
M3U(@9&%T871R965?<&%R96YT<R!,24M%("5S*2<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D8BT^<75O=&4H)'!A
M<F5N=',I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?9&(M/G%U;W1E*"1P87)E;G1S("X@)SHE)RDI.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&QE=F5L475E<GD@/2!S
M<')I;G1F*"=!3D0@9&%T871R965?<&%R96YT<R`]("5S)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YQ=6]T
M92@D<&%R96YT<RDI.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@
M*"$D86QL3&5V96QS*2!["B`@("`@("`@("`@("1L979E;%%U97)Y(#T@(D%.
M1"!D871A=')E95]P87)E;G1S(#T@)R<B.PH@("`@("`@('T*"B`@("`@("`@
M+R\@0G5I;&0@=&AE($923TTO2D])3B!C;&%U<V5S+@H@("`@("`@("1J;VEN
M<R`]("=,1494($I/24X@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==("X*
M("`@("`@("`@("`@)R!C($].(&$N9&%T871R965?:60@/2!C+F1A=&%T<F5E
M7VED)SL*"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G4T5,14-4($1)4U1)
M3D-4(&$N871T<FEB=71E7W9A;'5E($923TT@)7,@82`E<R!72$5212!C+F=R
M;W5P7W5I9"`]("5S($%.1"`E<R`E<R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&5?871T<FEB=71E<R==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@)&IO:6YS+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]D8BT^<75O=&4H)'1H:7,M/E]P87)A;7-;)V=R
M;W5P)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'=H97)E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@)&QE=F5L475E<GDI.PH*("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ
M9V5T071T<FEB=71E5F%L=65S*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`D<F]W<R`]("1T
M:&ES+3Y?9&(M/F=E=$-O;"@D<75E<GDI.PH@("`@("`@(&EF("AI<U]A*"1R
M;W=S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-
M97-S86=E*"1R;W=S+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T52
M4BD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')O=W,["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!"=6EL9',@86X@871T<FEB=71E('%U97)Y+B!(97)E
M(&ES(&%N(&5X86UP;&4@)&-R:71E<FEA(&%R<F%Y.@H@("`@("H*("`@("`J
M(#QC;V1E/@H@("`@("H@)&-R:71E<FEA6R=/4B==(#T@87)R87DH"B`@("`@
M*B`@("`@87)R87DH)T%.1"<@/3X@87)R87DH"B`@("`@*B`@("`@("`@(&%R
M<F%Y*"=F:65L9"<@/3X@)VYA;64G+`H@("`@("H@("`@("`@("`@("`@("`G
M;W`G("`@(#T^("<])RP*("`@("`J("`@("`@("`@("`@("`@)W1E<W0G("`]
M/B`G9F]O)RDL"B`@("`@*B`@("`@("`@(&%R<F%Y*"=F:65L9"<@/3X@)VME
M>2<L"B`@("`@*B`@("`@("`@("`@("`@("=O<"<@("`@/3X@)STG+`H@("`@
M("H@("`@("`@("`@("`@("`G=&5S="<@(#T^("=A8F,G*2DI+`H@("`@("H@
M("`@("`@("!A<G)A>2@G04Y$)R`]/B!A<G)A>2@*("`@("`J("`@("`@("`@
M("`@(&%R<F%Y*"=F:65L9"<@/3X@)VYA;64G+`H@("`@("H@("`@("`@("`@
M("`@("`@("`@)V]P)R`@("`]/B`G/2<L"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`G=&5S="<@(#T^("=B87(G*2P*("`@("`J("`@("`@("`@("`@(&%R
M<F%Y*"=F:65L9"<@/3X@)VME>2<L"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`G;W`G("`@(#T^("<])RP*("`@("`J("`@("`@("`@("`@("`@("`@("=T
M97-T)R`@/3X@)WAY>B<I*2DI.PH@("`@("H@/"]C;V1E/@H@("`@("H*("`@
M("`J(%1H:7,@=V]U;&0@9F5T8V@@86QL(&]B:F5C="!I9',@=VAE<F4@871T
M<FEB=71E(&YA;64@:7,@(F9O;R(@04Y$(&ME>0H@("`@("H@:7,@(F%B8R(L
M($]2(")B87(B($%.1"`B>'EZ(BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@("`D8W)I=&5R:6$@("`@(%1H92!A<G)A>2!O9B!C<FET97)I82X*("`@
M("`J($!P87)A;2!S=')I;F<@("1P87)E;G0@("`@("`@5&AE('!A<F5N="!N
M;V1E('1O('-T87)T('-E87)C:&EN9R!F<F]M+@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)&%L;$QE=F5L<R`@("!2971U<FX@86QL(&QE=F5L<RP@;W(@:G5S
M="!T:&4@9&ER96-T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&-H:6QD<F5N(&]F("1P87)E;G0_($1E9F%U;'1S('1O(&%L;"!L979E
M;',N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<F5S=')I8W0@("`@($]N;'D@
M<F5T=7)N(&%T=')I8G5T97,@=VET:"!T:&4@<V%M90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A='1R:6)U=&5?;F%M92!O<B!A='1R
M:6)U=&5?:60N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;W!E<F%T:6]N("`@
M(%1Y<&4@;V8@<75E<GD@=&\@8G5I;&0*("`@("`J($!P87)A;2!S=')I;F<@
M("1S;W)T8GE?;F%M92`@071T<FEB=71E(&YA;64@=&\@=7-E(&9O<B!S;W)T
M:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-O<G1B>5]K97D@("!!='1R
M:6)U=&4@:V5Y('1O('5S92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A;2!I
M;G1E9V5R("1D:7)E8W1I;VX@("`@4V]R="!D:7)E8W1I;VXZ"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,"`M(&%S8V5N9&EN9PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$@+2!D97-C
M96YD:6YG"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@4U%,('%U
M97)Y(&%N9"!A(&QI<W0@;V8@=F%L=65S('-U:71A8FQE(&9O<B!B:6YD:6YG
M"B`@("`@*B`@("`@("`@("`@("`@("!A<R!A;B!A<G)A>2X*("`@("`J+PH@
M("`@9G5N8W1I;VX@8G5I;&1!='1R:6)U=&51=65R>2@D8W)I=&5R:6$L("1P
M87)E;G0@/2!$051!5%)%15]23T]4+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D86QL3&5V96QS(#T@=')U92P@)')E<W1R:6-T(#T@)VYA
M;64G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;W!E<F%T
M:6]N(#T@1$%40512145?0E5)3$1?4T5,14-4+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<V]R=&)Y7VYA;64@/2!N=6QL+"`D<V]R=&)Y
M7VME>2`](&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D:7)E8W1I;VX@/2`P*0H@("`@>PH@("`@("`@(&EF("@A8V]U;G0H)&-R
M:71E<FEA*2D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH)R<L(&%R<F%Y
M*"DI.PH@("`@("`@('T*"B`@("`@("`@+RH@0G5I;&0@=&AE('%U97)Y+B`J
M+PH@("`@("`@("1T:&ES+3Y?=&%B;&5#;W5N="`](#$["B`@("`@("`@)'%U
M97)Y(#T@)R<["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"D["B`@("`@("`@
M9F]R96%C:"`H)&-R:71E<FEA(&%S("1K97D@/3X@)'9A;',I('L*("`@("`@
M("`@("`@:68@*"1K97D@/3T@)T]2)R!\?"`D:V5Y(#T]("=!3D0G*2!["B`@
M("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1Q=65R>2DI('L*("`@("`@("`@
M("`@("`@("`@("`D<75E<GD@+CT@)R`G("X@)&ME>2`N("<@)SL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1B:6YD<R`]("1T:&ES+3Y?
M8G5I;&1!='1R:6)U=&51=65R>2@D:V5Y+"`D=F%L<RD["B`@("`@("`@("`@
M("`@("`D<75E<GD@+CT@)R@G("X@)&)I;F1S6S!=("X@)RDG.PH@("`@("`@
M("`@("`@("`@)'9A;'5E<R`K/2`D8FEN9'-;,5T["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("\O($%D9"!F:6QT97)I;F<@8GD@<&%R96YT
M+"!A;F0@9F]R(&]N92!O<B!A;&P@;&5V96QS+@H@("`@("`@("1L979E;%%U
M97)Y(#T@)R<["B`@("`@("`@)&QE=F5L5F%L=65S(#T@87)R87DH*3L*("`@
M("`@("!I9B`H)'!A<F5N="`A/2!$051!5%)%15]23T]4*2!["B`@("`@("`@
M("`@("1P87)T<R`](&5X<&QO9&4H)SHG+"`D<&%R96YT*3L*("`@("`@("`@
M("`@)'!A<F5N=',@/2`G)SL*("`@("`@("`@("`@)'!S=')I;F<@/2`G)SL*
M("`@("`@("`@("`@9F]R96%C:"`H)'!A<G1S(&%S("1P87)T*2!["B`@("`@
M("`@("`@("`@("`D<'-T<FEN9R`N/2`H96UP='DH)'!S=')I;F<I(#\@)R<@
M.B`G.B<I("X@)'!A<G0["B`@("`@("`@("`@("`@("`D<&ED(#T@)'1H:7,M
M/F=E=$ED*"1P<W1R:6YG*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1P
M:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)'!I9#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1P
M87)E;G1S("X]("<Z)R`N("1P:60["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(&EF("@D86QL3&5V96QS*2!["B`@("`@("`@("`@("`@("`D;&5V96Q1
M=65R>2`]("=!3D0@*&1A=&%T<F5E7W!A<F5N=',@/2`_($]2(&1A=&%T<F5E
M7W!A<F5N=',@3$E+12`_*2<["B`@("`@("`@("`@("`@("`D;&5V96Q686QU
M97,@/2!A<G)A>2@D<&%R96YT<RP@)'!A<F5N=',@+B`G.B4G*3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1L979E;%%U97)Y(#T@
M)T%.1"!D871A=')E95]P87)E;G1S(#T@/R<["B`@("`@("`@("`@("`@("`D
M;&5V96Q686QU97,@/2!A<G)A>2@D<&%R96YT<RD["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V5I9B`H(21A;&Q,979E;',I('L*("`@("`@("`@("`@
M)&QE=F5L475E<GD@/2`B04Y$(&1A=&%T<F5E7W!A<F5N=',@/2`G)R(["B`@
M("`@("`@?0H*("`@("`@("`O+R!"=6EL9"!T:&4@1E)/32]*3TE.(&-L875S
M97,N"B`@("`@("`@)&IO:6YS(#T@87)R87DH*3L*("`@("`@("`D<&%I<G,@
M/2!A<G)A>2@I.PH@("`@("`@(&9O<B`H)&D@/2`Q.R`D:2`\/2`D=&AI<RT^
M7W1A8FQE0V]U;G0[("1I*RLI('L*("`@("`@("`@("`@)&IO:6YS6UT@/2`G
M3$5&5"!*3TE.("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&5?871T<FEB=71E
M<R==("X*("`@("`@("`@("`@("`@("<@82<@+B`D:2`N("<@3TX@82<@+B`D
M:2`N("<N9&%T871R965?:60@/2!C+F1A=&%T<F5E7VED)SL*"B`@("`@("`@
M("`@(&EF("@D:2`A/2`Q*2!["B`@("`@("`@("`@("`@("!I9B`H)')E<W1R
M:6-T(#T]("=N86UE)RD@>PH@("`@("`@("`@("`@("`@("`@("1P86ER<UM=
M(#T@)T%.1"!A,2YA='1R:6)U=&5?;F%M92`](&$G("X@)&D@+B`G+F%T=')I
M8G5T95]N86UE)SL*("`@("`@("`@("`@("`@('T@96QS96EF("@D<F5S=')I
M8W0@/3T@)VED)RD@>PH@("`@("`@("`@("`@("`@("`@("1P86ER<UM=(#T@
M)T%.1"!A,2YD871A=')E95]I9"`](&$G("X@)&D@+B`G+F1A=&%T<F5E7VED
M)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+R\@3W9E<G)I9&4@<V]R=&EN9RX*("`@("`@("`D<V]R="`]
M(&%R<F%Y*"D["B`@("`@("`@:68@*"%I<U]N=6QL*"1S;W)T8GE?;F%M92D@
M?'P@(6ES7VYU;&PH)'-O<G1B>5]K97DI*2!["B`@("`@("`@("`@("1O<F1E
M<E]T86)L92`]("=A)R`N("1I.PH@("`@("`@("`@("`D:F]I;G-;72`]("=,
M1494($I/24X@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L95]A='1R:6)U=&5S
M)UT@+@H@("`@("`@("`@("`@("`@)R`G("X@)&]R9&5R7W1A8FQE("X@)R!/
M3B`G("X@)&]R9&5R7W1A8FQE("X*("`@("`@("`@("`@("`@("<N9&%T871R
M965?:60@/2!C+F1A=&%T<F5E7VED)SL*"B`@("`@("`@("`@(&EF("@A:7-?
M;G5L;"@D<V]R=&)Y7VYA;64I*2!["B`@("`@("`@("`@("`@("`D<&%I<G-;
M72`]('-P<FEN=&8H)T%.1"`E<RYA='1R:6)U=&5?;F%M92`](#\@)RP@)&]R
M9&5R7W1A8FQE*3L*("`@("`@("`@("`@("`@("1S;W)T6UT@/2`D<V]R=&)Y
M7VYA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%I<U]N=6QL
M*"1S;W)T8GE?:V5Y*2D@>PH@("`@("`@("`@("`@("`@)'!A:7)S6UT@/2!S
M<')I;G1F*"=!3D0@)7,N871T<FEB=71E7VME>2`](#\@)RP@)&]R9&5R7W1A
M8FQE*3L*("`@("`@("`@("`@("`@("1S;W)T6UT@/2`D<V]R=&)Y7VME>3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&]R9&5R(#T@<W!R:6YT9B@G
M)7,N871T<FEB=71E7W9A;'5E("5S)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D;W)D97)?=&%B;&4L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@*"1D:7)E8W1I;VX@/3T@,2D@/R`G1$530R<@.B`G05-#)RD["B`@
M("`@("`@("`@("1G<F]U<%]B>2`]("=C+F1A=&%T<F5E7VED+"!C+F1A=&%T
M<F5E7VYA;64L(&,N9&%T871R965?;W)D97(L("<@+@H@("`@("`@("`@("`@
M("`@)&]R9&5R7W1A8FQE("X@)RYA='1R:6)U=&5?=F%L=64G.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1O<F1E<B`]("=C+F1A=&%T<F5E7V]R
M9&5R+"!C+F1A=&%T<F5E7VYA;64L(&,N9&%T871R965?:60G.PH@("`@("`@
M("`@("`D9W)O=7!?8GD@/2`G8RYD871A=')E95]I9"P@8RYD871A=')E95]N
M86UE+"!C+F1A=&%T<F5E7V]R9&5R)SL*("`@("`@("!]"@H@("`@("`@("1J
M;VEN<R`](&EM<&QO9&4H)R`G+"`D:F]I;G,I.PH@("`@("`@("1P86ER<R`]
M(&EM<&QO9&4H)R`G+"`D<&%I<G,I.PH@("`@("`@("1T86EL(#T@<W!R:6YT
M9B@G1U)/55`@0ED@)7,@3U)$15(@0ED@)7,G+"`D9W)O=7!?8GDL("1O<F1E
M<BD["@H@("`@("`@('-W:71C:"`H)&]P97)A=&EO;BD@>PH@("`@("`@(&-A
M<V4@1$%40512145?0E5)3$1?0T]53E0Z"B`@("`@("`@("`@("1W:&%T(#T@
M)T-/54Y4*$1)4U1)3D-4(&,N9&%T871R965?:60I)SL*("`@("`@("`@("`@
M)'1A:6P@/2`G)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U
M;'0Z"B`@("`@("`@("`@("1W:&%T(#T@)V,N9&%T871R965?:60L(&,N9&%T
M871R965?;F%M92<["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N(&%R<F%Y*'-P<FEN=&8H)U-%3$5#5"`E<R!&4D]-("5S
M(&,@)7,@5TA%4D4@8RYG<F]U<%]U:60@/2`_($%.1"`E<R`E<R`E<R`E<R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=H870L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&IO:6YS+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1Q=65R>2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D;&5V96Q1=65R>2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<&%I<G,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1A:6PI+`H@("`@("`@("`@("`@("`@("`@("!A<G)A>5]M97)G92AA
M<G)A>2@D=&AI<RT^7W!A<F%M<ULG9W)O=7`G72DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1V86QU97,L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1L979E;%9A;'5E<RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'-O<G0I*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($)U:6QD<R!A('!I96-E(&]F(&%N(&%T=')I8G5T92!Q=65R>2X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1G;'5E("`@("!4:&4@9VQU92!T
M;R!J;VEN('1H92!C<FET97)I82`H3U(O04Y$*2X*("`@("`J($!P87)A;2!A
M<G)A>2`D8W)I=&5R:6$@(%1H92!A<G)A>2!O9B!C<FET97)I82X*("`@("`J
M($!P87)A;2!B;V]L96%N("1J;VEN("`@(%-H;W5L9"!W92!J;VEN(&]N(&$@
M8VQE86X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&AO<F1E7V1A
M=&%T<F5E7V%T=')I8G5T97,@=&%B;&4_($1E9F%U;'1S('1O"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!F86QS92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!!;B!344P@9G)A9VUE;G0@86YD(&$@;&ES="!O9B!V
M86QU97,@<W5I=&%B;&4@9F]R(&)I;F1I;F<*("`@("`J("`@("`@("`@("`@
M("`@(&%S(&%N(&%R<F%Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8G5I;&1!
M='1R:6)U=&51=65R>2@D9VQU92P@)&-R:71E<FEA+"`D:F]I;B`](&9A;'-E
M*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O4U%,+G!H<"<[
M"@H@("`@("`@("\O($EN:71I86QI>F4@=&AE(&-L875S92!T:&%T('=E)W)E
M(&)U:6QD:6YG+@H@("`@("`@("1C;&%U<V4@/2`G)SL*("`@("`@("`D=F%L
M=65S(#T@87)R87DH*3L*"B`@("`@("`@+R\@1V5T('1H92!T86)L92!A;&EA
M<R!T;R!U<V4@9F]R('1H:7,@<V5T(&]F(&-R:71E<FEA+@H@("`@("`@("1A
M;&EA<R`]("1T:&ES+3Y?9V5T06QI87,H)&IO:6XI.PH*("`@("`@("!F;W)E
M86-H("@D8W)I=&5R:6$@87,@)&ME>2`]/B`D=F%L<RD@>PH@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1C;&%U<V4I*2!["B`@("`@("`@("`@("`@("`D8VQA
M=7-E("X]("<@)R`N("1G;'5E("X@)R`G.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("@A96UP='DH)'9A;'-;)T]2)UTI('Q\("%E;7!T>2@D=F%L
M<ULG04Y$)UTI*2!["B`@("`@("`@("`@("`@("`D8FEN9',@/2`D=&AI<RT^
M7V)U:6QD071T<FEB=71E475E<GDH)&=L=64L("1V86QS*3L*("`@("`@("`@
M("`@("`@("1C;&%U<V4@+CT@)R@G("X@)&)I;F1S6S!=("X@)RDG.PH@("`@
M("`@("`@("`@("`@)'9A;'5E<R`](&%R<F%Y7VUE<F=E*"1V86QU97,L("1B
M:6YD<ULQ72D["B`@("`@("`@("`@('T@96QS96EF("@A96UP='DH)'9A;'-;
M)TI/24XG72DI('L*("`@("`@("`@("`@("`@("1B:6YD<R`]("1T:&ES+3Y?
M8G5I;&1!='1R:6)U=&51=65R>2@D9VQU92P@)'9A;'-;)TI/24XG72P@=')U
M92D["B`@("`@("`@("`@("`@("`D8VQA=7-E("X]("1B:6YD<ULP73L*("`@
M("`@("`@("`@("`@("1V86QU97,@/2!A<G)A>5]M97)G92@D=F%L=65S+"`D
M8FEN9'-;,5TI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1V86QS6R=F:65L9"==*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1B:6YD<R`]($AO<F1E7U-13#HZ8G5I;&1#;&%U<V4H)'1H:7,M
M/E]D8BP@)&%L:6%S("X@)RYA='1R:6)U=&5?)R`N("1V86QS6R=F:65L9"==
M+"`D=F%L<ULG;W`G72P@)'9A;'-;)W1E<W0G72P@=')U92D["B`@("`@("`@
M("`@("`@("`@("`@)&-L875S92`N/2`D8FEN9'-;,%T["B`@("`@("`@("`@
M("`@("`@("`@)'9A;'5E<R`](&%R<F%Y7VUE<F=E*"1V86QU97,L("1B:6YD
M<ULQ72D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1B:6YD<R`]("1T:&ES+3Y?8G5I;&1!='1R:6)U=&51=65R>2@D
M:V5Y+"`D=F%L<RD["B`@("`@("`@("`@("`@("`@("`@)&-L875S92`N/2`D
M8FEN9'-;,%T["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E<R`](&%R<F%Y
M7VUE<F=E*"1V86QU97,L("1B:6YD<ULQ72D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A
M>2@D8VQA=7-E+"`D=F%L=65S*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E
M="!A;B!A;&EA<R!T;R!H;W)D95]D871A=')E95]A='1R:6)U=&5S+"!I;F-R
M96UE;G1I;F<@:70@:68*("`@("`J(&YE8V5S<V%R>2X*("`@("`J"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D:6YC<F5M96YT("!);F-R96UE;G0@=&AE(&%L
M:6%S(&-O=6YT/R!$969A=6QT<R!T;R!N;RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V=E=$%L:6%S*"1I;F-R96UE;G0@/2!F86QS92D*("`@('L*("`@("`@
M("!S=&%T:6,@)'-E96X@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H)&EN8W)E
M;65N="`F)B`A96UP='DH)'-E96Y;)'1H:7,M/E]T86)L94-O=6YT72DI('L*
M("`@("`@("`@("`@)'1H:7,M/E]T86)L94-O=6YT*RL["B`@("`@("`@?0H*
M("`@("`@("`D<V5E;ELD=&AI<RT^7W1A8FQE0V]U;G1=(#T@=')U93L*("`@
M("`@("!R971U<FX@)V$G("X@)'1H:7,M/E]T86)L94-O=6YT.PH@("`@?0H*
M("`@("\J*@H@("`@("H@57!D871E('1H92!D871A(&EN(&%N(&]B:F5C="X@
M1&]E<R!N;W0@8VAA;F=E('1H92!O8FIE8W0G<PH@("`@("H@<&%R96YT(&]R
M(&YA;64L(&IU<W0@<V5R:6%L:7IE9"!D871A(&]R(&%T=')I8G5T97,N"B`@
M("`@*@H@("`@("H@0'!A<F%M($1A=&%4<F5E("1O8FIE8W0@($$@1&%T851R
M964@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!U<&1A=&5$871A*"1O
M8FIE8W0I"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1O8FIE8W0L("=$871A
M5')E94]B:F5C="<I*2!["B`@("`@("`@("`@("\J($YO=&AI;F<@=&\@9&\@
M9F]R(&YO;B!O8FIE8W1S+B`J+PH@("`@("`@("`@("!R971U<FX@=')U93L*
M("`@("`@("!]"@H@("`@("`@("\J($=E="!T:&4@;V)J96-T(&ED+B`J+PH@
M("`@("`@("1I9"`]("1T:&ES+3YG971)9"@D;V)J96-T+3YG971.86UE*"DI
M.PH@("`@("`@(&EF("AI<U]A*"1I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&ED.PH@("`@("`@('T*"B`@("`@("`@+RH@4V5E
M(&EF('=E(&-A;B!B<F5A:R!T:&4@;V)J96-T(&]U="!T;R!D871A=')E95]A
M='1R:6)U=&5S('1A8FQE+B`J+PH@("`@("`@(&EF("AM971H;V1?97AI<W1S
M*"1O8FIE8W0L("=?=&]!='1R:6)U=&5S)RDI('L*("`@("`@("`@("`@+RH@
M268@=V4@8V%N+"!C;&5A<B!O=70@=&AE(&1A=&%T<F5E7V1A=&$@9FEE;&0@
M=&\@;6%K92!S=7)E(&ET"B`@("`@("`@("`@("`J(&1O97-N)W0@9V5T('!I
M8VME9"!U<"!B>2!G971$871A*"DN($EN=&5N=&EO;F%L;'D@9&]N)W0@8VAE
M8VL*("`@("`@("`@("`@("H@9F]R(&5R<F]R<R!H97)E(&EN(&-A<V4@9&%T
M871R965?9&%T82!G;V5S(&%W87D@:6X@=&AE"B`@("`@("`@("`@("`J(&9U
M='5R92X@*B\*("`@("`@("`@("`@)'%U97)Y(#T@)U501$%412`G("X@)'1H
M:7,M/E]P87)A;7-;)W1A8FQE)UT@+@H@("`@("`@("`@("`@("`@("`@("`G
M(%-%5"!D871A=')E95]D871A(#T@/R!72$5212!D871A=')E95]I9"`](#\G
M.PH@("`@("`@("`@("`D=F%L=65S(#T@87)R87DH3E5,3"P@*&EN="DD:60I
M.PH*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B
M>2!$871A5')E95]S<6PZ.G5P9&%T941A=&$H*3H@)R`N("1Q=65R>2P@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@
M("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["@H@("`@("`@
M("`@("`O*B!3=&%R="!A('1R86YS86-T:6]N+B`J+PH@("`@("`@("`@("`D
M=&AI<RT^7V1B+3YA=71O0V]M;6ET*&9A;'-E*3L*"B`@("`@("`@("`@("\J
M($1E;&5T92!O;&0@871T<FEB=71E<RX@*B\*("`@("`@("`@("`@)'%U97)Y
M(#T@)T1%3$5412!&4D]-("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&5?871T
M<FEB=71E<R==("X*("`@("`@("`@("`@("`@("`@("`@)R!72$5212!D871A
M=')E95]I9"`](#\G.PH@("`@("`@("`@("`D=F%L=65S(#T@87)R87DH*&EN
M="DD:60I.PH*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1
M=65R>2!B>2!$871A5')E95]S<6PZ.G5P9&%T941A=&$H*3H@)R`N("1Q=65R
M>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V
M86QU97,I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YR;VQL8F%C
M:R@I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]D8BT^875T;T-O;6UI="AT
M<G5E*3L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`O*B!'970@=&AE(&YE=R!A='1R:6)U=&4@
M<V5T+"!A;F0@:6YS97)T(&5A8V@@:6YT;R!T:&4@1$(N($EF"B`@("`@("`@
M("`@("`J(&%N>71H:6YG(&9A:6QS(&EN(&AE<F4L(')O;&QB86-K('1H92!T
M<F%N<V%C=&EO;BP@<F5T=7)N('1H90H@("`@("`@("`@("`@*B!R96QE=F%N
M="!E<G)O<BP@86YD(&)A:6P@;W5T+B`J+PH@("`@("`@("`@("`D871T<FEB
M=71E<R`]("1O8FIE8W0M/E]T;T%T=')I8G5T97,H*3L*("`@("`@("`@("`@
M)'%U97)Y(#T@)TE.4T525"!)3E1/("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&5?871T<FEB=71E<R==("X*("`@("`@("`@("`@("`@("`@("`@)R`H9&%T
M871R965?:60L(&%T=')I8G5T95]N86UE+"!A='1R:6)U=&5?:V5Y+"!A='1R
M:6)U=&5?=F%L=64I)R`N"B`@("`@("`@("`@("`@("`@("`@("<@5D%,5453
M("@_+"`_+"`_+"`_*2<["B`@("`@("`@("`@("1S=&%T96UE;G0@/2`D=&AI
M<RT^7V1B+3YP<F5P87)E*"1Q=65R>2D["B`@("`@("`@("`@(&9O<F5A8V@@
M*"1A='1R:6)U=&5S(&%S("1A='1R*2!["B`@("`@("`@("`@("`@("`D=F%L
M=65S(#T@87)R87DH*&EN="DD:60L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&%T=');)VYA;64G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D871T<ELG:V5Y)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D871T<ELG=F%L
M=64G72P@3DQ3.CIG971#:&%R<V5T*"DL("1T:&ES+3Y?<&%R86US6R=C:&%R
M<V5T)UTI*3L*"B`@("`@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G
M4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ=7!D871E1&%T82@I.B`G("X@
M)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*
M"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^97AE8W5T
M92@D<W1A=&5M96YT+"`D=F%L=65S*3L*("`@("`@("`@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V1B+3YR;VQL8F%C:R@I.PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9&(M/F%U=&]#;VUM:70H=')U92D["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("\J($-O;6UI="!T:&4@=')A;G-A
M8W1I;VXL(&%N9"!T=7)N(&%U=&]C;VUM:70@8F%C:R!O;BX@*B\*("`@("`@
M("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/F-O;6UI="@I.PH@("`@("`@
M("`@("`D=&AI<RT^7V1B+3YA=71O0V]M;6ET*'1R=64I.PH*("`@("`@("`@
M("`@<F5T=7)N(&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2`_("1R97-U
M;'0@.B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J(%=R
M:71E('1O('1H92!D871A=')E95]D871A(&9I96QD+B`J+PH@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+U-E<FEA;&EZ92YP:'`G.PH@("`@("`@
M("`@("`D<V5R(#T@4T5224%,25I%7U541C=?0D%324,["B`@("`@("`@("`@
M("1D871A(#T@2&]R9&5?4V5R:6%L:7IE.CIS97)I86QI>F4H)&]B:F5C="T^
M9V5T1&%T82@I+"`D<V5R+"!.3%,Z.F=E=$-H87)S970H*2D["@H@("`@("`@
M("`@("`D<75E<GD@/2`G55!$051%("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G72`N"B`@("`@("`@("`@("`@("`@("`@("<@4T54(&1A=&%T<F5E7V1A
M=&$@/2`_+"!D871A=')E95]S97)I86QI>F5D(#T@/R<@+@H@("`@("`@("`@
M("`@("`@("`@("`G(%=(15)%(&1A=&%T<F5E7VED(#T@/R<["B`@("`@("`@
M("`@("1V86QU97,@/2!A<G)A>2@D9&%T82P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("AI;G0I)'-E<BP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("AI;G0I)&ED*3L*"B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E
M*"=344P@475E<GD@8GD@1&%T851R965?<W%L.CIU<&1A=&5$871A*"DZ("<@
M+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I
M.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U
M97)Y+"`D=F%L=65S*3L*"B`@("`@("`@("`@(')E='5R;B!I<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RD@/R`D<F5S=6QT(#H@=')U93L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!O<&5N(&$@8V]N
M;F5C=&EO;B!T;R!T:&4@4U%,('-E<G9E<BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN
M96-T*"D*("`@('L*("`@("`@("!(;W)D93HZ87-S97)T1')I=F5R0V]N9FEG
M*"1T:&ES+3Y?<&%R86US+"`G<W1O<F%G92<L"B`@("`@("`@("`@(&%R<F%Y
M*"=P:'!T>7!E)RP@)V-H87)S970G*2P*("`@("`@("`@("`@)T1A=&%4<F5E
M(%-13"<I.PH*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=D
M871A8F%S92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG9&%T
M86)A<V4G72`]("<G.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?<&%R86US6R=U<V5R;F%M92==*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG=7-E<FYA;64G72`]("<G.PH@("`@("`@('T*("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=P87-S=V]R9"==*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72`]("<G.PH@
M("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=H
M;W-T<W!E8R==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG:&]S
M='-P96,G72`]("<G.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?<&%R86US6R=T86)L92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG=&%B;&4G72`]("=H;W)D95]D871A=')E92<["B`@("`@("`@
M?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)W1A8FQE7V%T
M=')I8G5T97,G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A
M8FQE7V%T=')I8G5T97,G72`]("=H;W)D95]D871A=')E95]A='1R:6)U=&5S
M)SL*("`@("`@("!]"@H@("`@("`@("\J($-O;FYE8W0@=&\@=&AE(%-13"!S
M97)V97(@=7-I;F<@=&AE('-U<'!L:65D('!A<F%M971E<G,N("HO"B`@("`@
M("`@<F5Q=6ER95]O;F-E("=$0BYP:'`G.PH@("`@("`@("1T:&ES+3Y?9&(@
M/2`F1$(Z.F-O;FYE8W0H)'1H:7,M/E]P87)A;7,L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<&5R<VES=&5N="<@/3X@(65M
M<'1Y*"1T:&ES+3Y?<&%R86US6R=P97)S:7-T96YT)UTI*2D["B`@("`@("`@
M:68@*&ES7V$H)'1H:7,M/E]D8BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!(;W)D93HZ9F%T86PH)'1H:7,M/E]D8BP@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("!]"@H@("`@("`@("\O(%-E="!$0B!P;W)T86)I;&ET
M>2!O<'1I;VYS"B`@("`@("`@<W=I=&-H("@D=&AI<RT^7V1B+3YP:'!T>7!E
M*2!["B`@("`@("`@8V%S92`G;7-S<6PG.@H@("`@("`@("`@("`D=&AI<RT^
M7V1B+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?
M3$]715)#05-%('P@1$)?4$]25$%"24Q)5%E?15)23U)3('P@1$)?4$]25$%"
M24Q)5%E?4E1224TI.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!D969A
M=6QT.@H@("`@("`@("`@("`D=&AI<RT^7V1B+3YS971/<'1I;VXH)W!O<G1A
M8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?3$]715)#05-%('P@1$)?4$]25$%"
M24Q)5%E?15)23U)3*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O1&%T851R964N<&AP````````````````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,30S-30P`#$P-3$U-#,S-S4R`#`R,38W
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*+RHJ"B`J($QI<W0@979E<GD@;V)J96-T(&EN(&%N(&%R<F%Y+"!S
M:6UI;&%R('1O(%!%05(O:'1M;"]M96YU+G!H<"X*("HO"F1E9FEN92@G1$%4
M0512145?1D]234%47U12144G+"`Q*3L*"B\J*@H@*B!'970@82!F=6QL(&QI
M<W0@+2!A;B!A<G)A>2!O9B!K97ES+@H@*B\*9&5F:6YE*"=$051!5%)%15]&
M3U)-051?1DQ!5"<L(#(I.PH*+RHJ"B`J(%1H92!R;V]T(&5L96UE;G0@*'1O
M<"UL979E;"!P87)E;G0I(&]F(&5A8V@@1&%T851R964@9W)O=7`N"B`J+PID
M969I;F4H)T1!5$%44D5%7U)/3U0G+"`M,2D["@HO*BH*("H@0G5I;&0@82!N
M;W)M86P@<V5L96-T('%U97)Y+@H@*B\*9&5F:6YE*"=$051!5%)%15]"54E,
M1%]314Q%0U0G+"`P*3L*"B\J*@H@*B!"=6EL9"!A(&-O=6YT(&]N;'D@<75E
M<GDN"B`J+PID969I;F4H)T1!5$%44D5%7T)524Q$7T-/54Y4)RP@,2D["@HO
M*BH*("H@5&AE($1A=&%4<F5E.CH@8VQA<W,@<')O=FED97,@82!C;VUM;VX@
M86)S=')A8W1E9"!I;G1E<F9A8V4@:6YT;R!T:&4*("H@=F%R:6]U<R!B86-K
M96YD<R!F;W(@=&AE($AO<F1E($1A=&%4<F5E('-Y<W1E;2X*("H*("H@02!P
M:65C92!O9B!D871A(&ES(&IU<W0@82!T:71L92!T:&%T(&ES('-A=F5D(&EN
M('1H92!P86=E(&9O<B!T:&4@;G5L;`H@*B!D<FEV97(@;W(@8V%N(&)E('-A
M=F5D(&EN(&$@9&%T86)A<V4@=&\@8F4@86-C97-S960@9G)O;2!E=F5R>7=H
M97)E+B!%=F5R>0H@*B!S=&]R960@;V)J96-T(&UU<W0@:&%V92!A(&1I9F9E
M<F5N="!N86UE("AI;G-I9&4@96%C:"!G<F]U<&ED*2X*("H*("H@4F5Q=6ER
M960@=F%L=65S(&9O<B`D<&%R86US.CQP<F4^"B`J("`@)V=R;W5P)R`M+2!$
M969I;F4@96%C:"!G<F]U<"!O9B!O8FIE8W1S('=E('=A;G0@=&\@8G5I;&0N
M/"]P<F4^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4
M<F5E+G!H<"QV(#$N,34Q+C(N,3@@,C`P-B\P-R\Q,R`P.#HU.#HT-"!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P,R!3=&5P:&%N92!(=71H
M97(@/'-H=71H97)`8FEG9F]O="YC;VT^"B`J($-O<'ER:6=H="`R,#`Q+3(P
M,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!3=&5P:&%N92!(=71H97(@/'-H=71H97)`
M8FEG9F]O="YC;VT^"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`R+C$*("H@0'!A8VMA
M9V4@2&]R9&5?1&%T851R964*("HO"F-L87-S($1A=&%4<F5E('L*"B`@("`O
M*BH*("`@("`J($%R<F%Y(&]F(&%L;"!D871A.B!I;F1E>&5D(&)Y(&ED+B!4
M:&4@9F]R;6%T(&ES.B!A<G)A>2AI9"`]/@H@("`@("H@)VYA;64G(#T^(&YA
M;64L("=P87)E;G0G(#T^('!A<F5N="DN"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]D871A(#T@87)R87DH*3L*"B`@("`O
M*BH*("`@("`J($$@:&%S:"!T:&%T(&-A;B!B92!U<V5D('1O(&UA<"!A(&9U
M;&P@;V)J96-T(&YA;64*("`@("`J("AP87)E;G0Z8VAI;&0Z;V)J96-T*2!T
M;R!T:&%T(&]B:F5C="=S('5N:7%U92!)1"X*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7VYA;65-87`@/2!A<G)A>2@I.PH*
M("`@("`O*BH*("`@("`J($%C='5A;"!A='1R:6)U=&4@<V]R=&EN9R!H87-H
M+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M<V]R=$AA<V@@/2!N=6QL.PH*("`@("\J*@H@("`@("H@2&%S:"!C;VYT86EN
M:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"D["@H@
M("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET
M:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT
M(&YE960N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@5V4@86QW87ES
M(&YE960@)V=R;W5P)RP@82!S=')I;F<@=&AA="!D969I;F5S('1H90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@('!R969I>"!F;W(@96%C:"!S970@
M;V8@:&EE<F%R8VAI8V%L(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N($1A
M=&%4<F5E*"1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M<&%R86US(#T@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@82!P87)A;65T97(@;V8@=&AI<R!$871A5')E92!I;G-T86YC92X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87)A;2`@5&AE('!A<F%M971E
M<B!T;R!R971U<FXN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE
M('!A<F%M971E<B=S('9A;'5E(&]R(&YU;&P@:68@:70@9&]E<VXG="!E>&ES
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%R86TH)'!A<F%M*0H@("`@
M>PH@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7W!A<F%M<ULD<&%R86U=
M*2`_("1T:&ES+3Y?<&%R86US6R1P87)A;5T@.B!N=6QL.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5M;W9E<R!A;B!O8FIE8W0N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;V)J96-T("!4:&4@;V)J96-T('1O(')E;6]V92X*
M("`@("`J($!P87)A;2`D9F]R8V4@("`@("`@("`@1F]R8V4@<F5M;W9A;"!O
M9B!E=F5R>2!C:&EL9"!O8FIE8W0_"B`@("`@*B\*("`@(&9U;F-T:6]N(')E
M;6]V92@D;V)J96-T+"`D9F]R8V4@/2!F86QS92D*("`@('L*("`@("`@("!I
M9B`H:7-?82@D;V)J96-T+"`G1&%T851R965/8FIE8W0G*2D@>PH@("`@("`@
M("`@("`D;V)J96-T(#T@)&]B:F5C="T^9V5T3F%M92@I.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"$D=&AI<RT^97AI<W1S*"1O8FIE8W0I*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1O8FIE8W0@+B`G(&1O
M97,@;F]T(&5X:7-T)RD["B`@("`@("`@?0H*("`@("`@("`D8VAI;&1R96X@
M/2`D=&AI<RT^9V5T3G5M8F5R3V9#:&EL9')E;B@D;V)J96-T*3L*("`@("`@
M("!I9B`H)&-H:6QD<F5N*2!["B`@("`@("`@("`@("\J(%1/1$\Z(')E;6]V
M92!C:&EL9')E;B!I9B`D9F]R8V4@/3T@=')U92`J+PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-A;FYO="!R96UO
M=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(I+"!C;W5N="@D8VAI;&1R96XI*2D[
M"B`@("`@("`@?0H*("`@("`@("`D:60@/2`D=&AI<RT^9V5T260H)&]B:F5C
M="D["B`@("`@("`@)'!I9"`]("1T:&ES+3YG971087)E;G0H)&]B:F5C="D[
M"B`@("`@("`@)&]R9&5R(#T@)'1H:7,M/E]D871A6R1I9%U;)V]R9&5R)UT[
M"B`@("`@("`@=6YS970H)'1H:7,M/E]D871A6R1I9%TI.PH@("`@("`@('5N
M<V5T*"1T:&ES+3Y?;F%M94UA<%LD:61=*3L*"B`@("`@("`@+R\@4VAI9G0@
M9&]W;B!T:&4@;W)D97(@<&]S:71I;VYS+@H@("`@("`@("1T:&ES+3Y?<F5O
M<F1E<B@D<&ED+"`D;W)D97(I.PH*("`@("`@("!R971U<FX@)&ED.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!A;&P@1&%T851R964@;V)J96-T
M<R!O=VYE9"!B>2!A(&-E<G1A:6X@=7-E<BX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1U<V5R("!!('5S97(@;F%M92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5M;W9E57-E<D1A=&$H)'5S97(I"B`@("!["B`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)VYO="!S=7!P;W)T960G*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($UO=F4@86X@;V)J96-T('1O(&$@;F5W('!A<F5N
M="X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&]B:F5C="`@("`@(%1H
M92!O8FIE8W0@=&\@;6]V92X*("`@("`J($!P87)A;2!S=')I;F<@)&YE=W!A
M<F5N="`@5&AE(&YE=R!P87)E;G0@;V)J96-T+B!$969A=6QT<R!T;R!T:&4@
M<F]O="X*("`@("`J+PH@("`@9G5N8W1I;VX@;6]V92@D;V)J96-T+"`D;F5W
M<&%R96YT(#T@;G5L;"D*("`@('L*("`@("`@("`D8VED(#T@)'1H:7,M/F=E
M=$ED*"1O8FIE8W0I.PH@("`@("`@(&EF("AI<U]A*"1C:60L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M<W!R:6YT9B@G3V)J96-T('1O(&UO=F4@9&]E<R!N;W0@97AI<W0Z("5S)RP@
M)&-I9"T^9V5T365S<V%G92@I*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M(6ES7VYU;&PH)&YE=W!A<F5N="DI('L*("`@("`@("`@("`@)'!I9"`]("1T
M:&ES+3YG971)9"@D;F5W<&%R96YT*3L*("`@("`@("`@("`@:68@*&ES7V$H
M)'!I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9B@G3F5W('!A<F5N="!D;V5S(&YO
M="!E>&ES=#H@)7,G+"`D<&ED+3YG971-97-S86=E*"DI*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P:60@/2!$051!
M5%)%15]23T]4.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]D871A6R1C
M:61=6R=P87)E;G0G72`]("1P:60["@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0VAA;F=E(&%N(&]B:F5C="=S(&YA;64N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("`D;VQD7V]B:F5C="`@("`@
M("!4:&4@;VQD(&]B:F5C="X*("`@("`J($!P87)A;2!S=')I;F<@)&YE=U]O
M8FIE8W1?;F%M92`@5&AE(&YE=R!O8FIE8W0@;F%M92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5N86UE*"1O;&1?;V)J96-T+"`D;F5W7V]B:F5C=%]N86UE
M*0H@("`@>PH@("`@("`@("\J($-H96-K('=H971H97(@=&AE(&]B:F5C="!E
M>&ES=',@870@86QL("HO"B`@("`@("`@:68@*"$D=&AI<RT^97AI<W1S*"1O
M;&1?;V)J96-T*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@D;VQD7V]B:F5C="`N("<@9&]E<R!N;W0@97AI<W0G*3L*("`@("`@
M("!]"@H@("`@("`@("\J($-H96-K(&9O<B!D=7!L:6-A=&5S("T@9V5T('!A
M<F5N="!A;F0@8W)E871E(&YE=R!O8FIE8W0*("`@("`@("`@*B!N86UE("HO
M"B`@("`@("`@)'!A<F5N="`]("1T:&ES+3YG971.86UE*"1T:&ES+3YG9710
M87)E;G0H)&]L9%]O8FIE8W0I*3L*("`@("`@("!I9B`H)'1H:7,M/F5X:7-T
M<R@D<&%R96YT("X@)SHG("X@)&YE=U]O8FIE8W1?;F%M92DI('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T1U<&QI8V%T92!N86UE
M("<@+B`D;F5W7V]B:F5C=%]N86UE*3L*("`@("`@("!]"@H@("`@("`@("\J
M(%)E<&QA8V4@=&AE(&]L9"!N86UE('=I=&@@=&AE(&YE=R!O;F4@:6X@=&AE
M(&-A8VAE("HO"B`@("`@("`@)&]L9%]O8FIE8W1?:60@/2`D=&AI<RT^9V5T
M260H)&]L9%]O8FIE8W0I.PH@("`@("`@("1T:&ES+3Y?9&%T85LD;VQD7V]B
M:F5C=%]I9%U;)VYA;64G72`]("1N97=?;V)J96-T7VYA;64["@H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAA;F=E<R!T
M:&4@;W)D97(@;V8@=&AE(&-H:6QD<F5N(&]F(&%N(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87)E;G0@(%1H92!F=6QL(&ED('!A
M=&@@;V8@=&AE('!A<F5N="!O8FIE8W0N"B`@("`@*B!`<&%R86T@;6EX960@
M)&]R9&5R("`@($EF(&%N(&%R<F%Y(&ET('-P96-I9FEE<R!T:&4@;F5W('!O
M<VET:6]N<R!F;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@86QL
M(&-H:6QD(&]B:F5C=',N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M($EF(&%N(&EN=&5G97(@86YD("1C:60@:7,@<W!E8VEF:65D+"!T:&4@<&]S
M:71I;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@=VAE<F4@=&AE
M(&-H:6QD('-P96-I9FEE9"!B>2`D8VED(&ES(&EN<V5R=&5D+B!)9@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`D8VED(&ES(&YO="!S<&5C:69I
M960L('1H92!P;W-I=&EO;B!G971S(&1E;&5T960L"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@(&-A=7-I;F<@=&AE(&9O;&QO=VEN9R!P;W-I=&EO
M;G,@=&\@<VAI9G0@=7`N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8VED("`@
M(%-E92`D;W)D97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;W)D97(H)'!A
M<F5N=',L("1O<F1E<B`](&YU;&PL("1C:60@/2!N=6QL*0H@("`@>PH@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=N;W0@<W5P<&]R=&5D)RD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&%N9V4@;W)D97(@;V8@8VAI;&1R
M96X@;V8@86X@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'!I9"`@("`@5&AE('!A<F5N="!O8FIE8W0@:60@<W1R:6YG('!A=&@N"B`@
M("`@*B!`<&%R86T@;6EX960@)&]R9&5R("`@(%-P96-I9FEC(&YE=R!O<F1E
M<B!P;W-I=&EO;B!O<B!A;B!A<G)A>2!C;VYT86EN:6YG"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@('1H92!N97<@<&]S:71I;VYS(&9O<B!T:&4@
M9VEV96X@<&%R96YT+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-I9"`@("!)
M9B!P<F]V:61E9"!I;F1I8V%T97,@:6YS97)T:6]N(&]F(&$@;F5W(&-H:6QD
M('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@('1H92!P87)E;G0@
M=&\@879O:60@:6YC<F5M96YT:6YG(&ET('=H96X*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@<VAI9G1I;F<@=7`@86QL(&]T:&5R(&-H:6QD<F5N
M)W,@;W)D97(N($EF(&YO=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("!P<F]V:61E9"!I;F1I8V%T97,@9&5L971I;VXL('-O('-H:69T(&%L;"!O
M=&AE<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!P;W-I=&EO;G,@
M9&]W;B!O;F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R96]R9&5R*"1P:60L
M("1O<F1E<B`](&YU;&PL("1C:60@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF
M("@A:7-?87)R87DH)&]R9&5R*2`F)B`A:7-?;G5L;"@D;W)D97(I*2!["B`@
M("`@("`@("`@("\O(%-I;F=L92!U<&1A=&4@*&%D9"]D96PI+@H@("`@("`@
M("`@("!I9B`H:7-?;G5L;"@D8VED*2D@>PH@("`@("`@("`@("`@("`@+R\@
M3F\@:60@9VEV96X@<V\@<VAU9F9L92!D;W=N+@H@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]D871A(&%S("1C7VME>2`]/B`D8U]V86PI('L*
M("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]D871A6R1C7VME>5U;
M)W!A<F5N="==(#T]("1P:60*("`@("`@("`@("`@("`@("`@("`@("`@)B8@
M)'1H:7,M/E]D871A6R1C7VME>5U;)V]R9&5R)UT@/B`D;W)D97(I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D871A6R1C7VME>5U;)V]R
M9&5R)UTM+3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O+R!7
M92!H879E(&%N(&ED('-O('-H=69F;&4@=7`N"B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D=&AI<RT^7V1A=&$@87,@)&-?:V5Y(#T^("1C7W9A;"D@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("@D8U]K97D@(3T@)&-I9"`@)B8@)'1H
M:7,M/E]D871A6R1C7VME>5U;)W!A<F5N="==(#T]("1P:60*("`@("`@("`@
M("`@("`@("`@("`@("`@)B8@)'1H:7,M/E]D871A6R1C7VME>5U;)V]R9&5R
M)UT@/CT@)&]R9&5R*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?9&%T85LD8U]K97E=6R=O<F1E<B==*RL["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E:68@*&ES7V%R<F%Y*"1O<F1E<BD@)B8@8V]U;G0H)&]R9&5R*2D@
M>PH@("`@("`@("`@("`O+R!-=6QT:2!U<&1A=&4N"B`@("`@("`@("`@(&9O
M<F5A8V@@*"1O<F1E<B!A<R`D;W)D97)?<&]S:71I;VX@/3X@)&-I9"D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]D871A6R1C:61=6R=O<F1E<B==(#T@
M)&]R9&5R7W!O<VET:6]N.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@17AP;&EC:71L>2!S970@=&AE(&]R9&5R(&9O
M<B!A(&1A=&%T<F5E(&]B:F5C="X*("`@("`J"B`@("`@*B!`86)S=')A8W0*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:60@("`@(%1H92!D871A
M=')E92!O8FIE8W0@:60@=&\@8VAA;F=E+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&]R9&5R("!4:&4@;F5W(&]R9&5R+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S971/<F1E<B@D:60L("1O<F1E<BD*("`@('L*("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G;F]T('-U<'!O<G1E9"<I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1'EN86UI8V%L;'D@9&5T97)M:6YE<R!T:&4@;V)J96-T
M(&-L87-S+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D871T<FEB=71E
M<R`@5&AE('-E="!O9B!A='1R:6)U=&5S('1H870@8V]N=&%I;B!T:&4@8VQA
M<W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@:6YF;W)M871I
M;VXN($1E9F%U;'1S('1O($1A=&%4<F5E3V)J96-T+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?9&5F:6YE3V)J96-T0VQA<W,H)&%T=')I8G5T97,I"B`@("![
M"B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@)&-L87-S(#T@
M)T1A=&%4<F5E3V)J96-T)SL*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1A='1R
M:6)U=&5S*2D@>PH@("`@("`@("`@("!R971U<FX@)&-L87-S.PH@("`@("`@
M('T*"B`@("`@("`@9F]R96%C:"`H)&%T=')I8G5T97,@87,@)&%T='(I('L*
M("`@("`@("`@("`@:68@*"1A='1R6R=N86UE)UT@/3T@)T1A=&%4<F5E)RD@
M>PH@("`@("`@("`@("`@("`@:68@*"1A='1R6R=K97DG72`]/2`G;V)J96-T
M0VQA<W,G*2!["B`@("`@("`@("`@("`@("`@("`@)&-L87-S(#T@)&%T=');
M)W9A;'5E)UT["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("!](&5L<V5I9B`H)&%T=');)VME>2==(#T]("=O8FIE8W14>7!E
M)RD@>PH@("`@("`@("`@("`@("`@("`@("1R97-U;'0@/2!E>'!L;V1E*"<O
M)RP@)&%T=');)W9A;'5E)UTI.PH@("`@("`@("`@("`@("`@("`@("1C;&%S
M<R`]("1R96=I<W1R>2T^8V%L;$)Y4&%C:V%G92@D<F5S=6QT6S!=+"`G9&5F
M:6YE0VQA<W,G+"!A<G)A>2@G='EP92<@/3X@)')E<W5L=%LQ72DI.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-L87-S.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A($1A=&%4<F5E3V)J96-T
M("AO<B!S=6)C;&%S<RD@;V)J96-T(&]F('1H92!D871A(&EN('1H90H@("`@
M("H@;V)J96-T(&1E9FEN960@8GD@)&]B:F5C="X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1O8FIE8W0@(%1H92!O8FIE8W0@=&\@9F5T8V@Z("=P
M87)E;G0Z<W5B+7!A<F5N=#IN86UE)RX*("`@("`J($!P87)A;2!S=')I;F<@
M)&-L87-S("`@4W5B8VQA<W,@;V8@1&%T851R965/8FIE8W0@=&\@=7-E+B!$
M969A=6QT<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!$871A
M5')E94]B:F5C="X@3G5L;"!F;W)C97,@=&AE(&1R:79E<B!T;R!L;V]K"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&EN=&\@=&AE(&%T=')I8G5T
M97,@=&%B;&4@=&\@9&5T97)M:6YE('1H90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("!S=6)C;&%S<R!T;R!U<V4N($EF(&YO;F4@:7,@9F]U;F0@
M:70@=7-E<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!$871A5')E
M94]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$]B:F5C="@D;V)J
M96-T+"`D8VQA<W,@/2`G1&%T851R965/8FIE8W0G*0H@("`@>PH@("`@("`@
M(&EF("AE;7!T>2@D;V)J96-T*2D@>PH@("`@("`@("`@("`D97)R;W(@/2!0
M14%2.CIR86ES945R<F]R*"=.;R!O8FIE8W0@<F5Q=65S=&5D+B<I.PH@("`@
M("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/E]L;V%D*"1O8FIE8W0I.PH@("`@("`@(&EF("@A)'1H:7,M/F5X:7-T
M<R@D;V)J96-T*2D@>PH@("`@("`@("`@("`D97)R;W(@/2!014%2.CIR86ES
M945R<F]R*"1O8FIE8W0@+B`G(&YO="!F;W5N9"XG*3L*("`@("`@("`@("`@
M<F5T=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@("1U<V5?871T<FEB
M=71E<R`](&ES7VYU;&PH)&-L87-S*2!\?"!I<U]C86QL86)L92AA<G)A>2@D
M8VQA<W,L("=?9G)O;4%T=')I8G5T97,G*2D["B`@("`@("`@:68@*"1U<V5?
M871T<FEB=71E<RD@>PH@("`@("`@("`@("`D871T<FEB=71E<R`]("1T:&ES
M+3YG971!='1R:6)U=&5S*"1T:&ES+3YG971)9"@D;V)J96-T*2D["B`@("`@
M("`@("`@(&EF("AI<U]A*"1A='1R:6)U=&5S+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)&%T=')I8G5T97,["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(&EF("AI<U]N=6QL*"1C;&%S<RDI('L*("`@
M("`@("`@("`@("`@("1C;&%S<R`]("1T:&ES+3Y?9&5F:6YE3V)J96-T0VQA
M<W,H)&%T=')I8G5T97,I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!I9B`H(6-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@
M("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)&-L87-S("X@)R!N;W0@9F]U
M;F0N)RD["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H*
M("`@("`@("`D9&%T84]B(#T@)FYE=R`D8VQA<W,H)&]B:F5C="D["B`@("`@
M("`@)&1A=&%/8BT^<V5T1&%T851R964H)'1H:7,I.PH@("`@("`@("\J($EF
M('1H92!C;&%S<R!H87,@82!?9G)O;4%T=')I8G5T97,@;65T:&]D+"!L;V%D
M(&1A=&$@9G)O;0H@("`@("`@("`J('1H92!A='1R:6)U=&5S(&)A8VME;F0N
M("HO"B`@("`@("`@:68@*"1U<V5?871T<FEB=71E<RD@>PH@("`@("`@("`@
M("`D9&%T84]B+3Y?9G)O;4%T=')I8G5T97,H)&%T=')I8G5T97,I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("\J($]T:&5R=VES92!L;V%D(&ET
M(&9R;VT@=&AE(&]L9"!D871A('-T;W)A9V4@9FEE;&0N("HO"B`@("`@("`@
M("`@("1D871A3V(M/G-E=$1A=&$H)'1H:7,M/F=E=$1A=&$H)'1H:7,M/F=E
M=$ED*"1O8FIE8W0I*2D["B`@("`@("`@?0H*("`@("`@("`D9&%T84]B+3YS
M971/<F1E<B@D=&AI<RT^9V5T3W)D97(H)&]B:F5C="DI.PH@("`@("`@(')E
M='5R;B`D9&%T84]B.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A
M($1A=&%4<F5E3V)J96-T("AO<B!S=6)C;&%S<RD@;V)J96-T(&]F('1H92!D
M871A(&EN('1H90H@("`@("H@;V)J96-T('=I=&@@=&AE($E$("1I9"X*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:60@("`@06X@;V)J96-T(&ED
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VQA<W,@(%-U8F-L87-S(&]F($1A
M=&%4<F5E3V)J96-T('1O('5S92X@1&5F875L=',@=&\*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!$871A5')E94]B:F5C="X@3G5L;"!F;W)C97,@
M=&AE(&1R:79E<B!T;R!L;V]K"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@:6YT;R!T:&4@871T<FEB=71E<R!T86)L92!T;R!D971E<FUI;F4@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<W5B8VQA<W,@=&\@=7-E
M+B!)9B!N;VYE(&ES(&9O=6YD(&ET('5S97,*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!$871A5')E94]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@)F=E=$]B:F5C=$)Y260H)&ED+"`D8VQA<W,@/2`G1&%T851R965/8FIE
M8W0G*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D:60I*2!["B`@("`@("`@
M("`@("1O8FIE8W0@/2!014%2.CIR86ES945R<F]R*"=.;R!I9"!R97%U97-T
M960N)RD["B`@("`@("`@("`@(')E='5R;B`D;V)J96-T.PH@("`@("`@('T*
M"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?;&]A9$)Y260H)&ED*3L*("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)'5S
M95]A='1R:6)U=&5S(#T@:7-?;G5L;"@D8VQA<W,I('Q\(&ES7V-A;&QA8FQE
M*&%R<F%Y*"1C;&%S<RP@)U]F<F]M071T<FEB=71E<R<I*3L*("`@("`@("!I
M9B`H)'5S95]A='1R:6)U=&5S*2!["B`@("`@("`@("`@("1A='1R:6)U=&5S
M(#T@)'1H:7,M/F=E=$%T=')I8G5T97,H)&ED*3L*("`@("`@("`@("`@:68@
M*&ES7V$H)&%T=')I8G5T97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D871T<FEB=71E<SL*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@:68@*&ES7VYU;&PH)&-L87-S*2D@>PH@("`@("`@("`@("`@
M("`@)&-L87-S(#T@)'1H:7,M/E]D969I;F5/8FIE8W1#;&%S<R@D871T<FEB
M=71E<RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A
M8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@
M("`@?0H*("`@("`@("`D;F%M92`]("1T:&ES+3YG971.86UE*"1I9"D["B`@
M("`@("`@)&1A=&%/8B`]("9N97<@)&-L87-S*"1N86UE*3L*("`@("`@("`D
M9&%T84]B+3YS971$871A5')E92@D=&AI<RD["B`@("`@("`@+RH@268@=&AE
M(&-L87-S(&AA<R!A(%]F<F]M071T<FEB=71E<R!M971H;V0L(&QO860@9&%T
M82!F<F]M"B`@("`@("`@("H@=&AE(&%T=')I8G5T97,@8F%C:V5N9"X@*B\*
M("`@("`@("!I9B`H)'5S95]A='1R:6)U=&5S*2!["B`@("`@("`@("`@("1D
M871A3V(M/E]F<F]M071T<FEB=71E<R@D871T<FEB=71E<RD["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@+RH@3W1H97)W:7-E(&QO860@:70@9G)O
M;2!T:&4@;VQD(&1A=&$@<W1O<F%G92!F:65L9"X@*B\*("`@("`@("`@("`@
M)&1A=&%/8BT^<V5T1&%T82@D=&AI<RT^9V5T1&%T82@D:60I*3L*("`@("`@
M("!]"@H@("`@("`@("1D871A3V(M/G-E=$]R9&5R*"1T:&ES+3YG971/<F1E
M<B@D;F%M92DI.PH@("`@("`@(')E='5R;B`D9&%T84]B.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!A;B!A<G)A>2!O9B!$871A5')E94]B:F5C
M="`H;W(@<W5B8VQA<W,I(&]B:F5C=',*("`@("`J(&-O<G)E<W!O;F1I;F<@
M=&\@=&AE(&]B:F5C=',@:6X@)&ED<RP@=VET:"!T:&4@;V)J96-T"B`@("`@
M*B!N86UE<R!A<R!T:&4@:V5Y<R!O9B!T:&4@87)R87DN"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1I9',@("`@($%N(&%R<F%Y(&]F(&]B:F5C="!I
M9',N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;&%S<R`@4W5B8VQA<W,@;V8@
M1&%T851R965/8FIE8W0@=&\@=7-E+B!$969A=6QT<R!T;PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@($1A=&%4<F5E3V)J96-T+B!.=6QL(&9O<F-E
M<R!T:&4@9')I=F5R('1O(&QO;VL*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!I;G1O('1H92!A='1R:6)U=&5S('1A8FQE('1O(&1E=&5R;6EN92!T
M:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!S=6)C;&%S<R!T;R!U
M<V4N($EF(&YO;F4@:7,@9F]U;F0@:70@=7-E<PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@($1A=&%4<F5E3V)J96-T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B`F9V5T3V)J96-T<R@D:61S+"`D8VQA<W,@/2`G1&%T851R965/8FIE
M8W0G*0H@("`@>PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VQO861">4ED
M*"1I9',I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*
M("`@("`@("`D9&5F:6YE0VQA<W,@/2!I<U]N=6QL*"1C;&%S<RD["B`@("`@
M("`@)&%T=')I8G5T97,@/2!I<U]N=6QL*"1C;&%S<RD@?'P@:7-?8V%L;&%B
M;&4H87)R87DH)&-L87-S+"`G7V9R;VU!='1R:6)U=&5S)RDI.PH*("`@("`@
M("!I9B`H)&%T=')I8G5T97,I('L*("`@("`@("`@("`@)&1A=&$@/2`D=&AI
M<RT^9V5T071T<FEB=71E<R@D:61S*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D9&%T82`]("1T:&ES+3YG971$871A*"1I9',I.PH@("`@("`@
M('T*"B`@("`@("`@)&]B:F5C=',@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A
M8V@@*"1I9',@87,@)&ED*2!["B`@("`@("`@("`@("1N86UE(#T@)'1H:7,M
M/F=E=$YA;64H)&ED*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D;F%M92D@
M)B8@(65M<'1Y*"1D871A6R1I9%TI*2!["B`@("`@("`@("`@("`@("!I9B`H
M)&1E9FEN94-L87-S*2!["B`@("`@("`@("`@("`@("`@("`@)&-L87-S(#T@
M)'1H:7,M/E]D969I;F5/8FIE8W1#;&%S<R@D9&%T85LD:61=*3L*("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T
M<R@D8VQA<W,I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@)&]B:F5C='-;)&YA;65=(#T@
M)FYE=R`D8VQA<W,H)&YA;64I.PH@("`@("`@("`@("`@("`@)&]B:F5C='-;
M)&YA;65=+3YS971$871A5')E92@D=&AI<RD["B`@("`@("`@("`@("`@("!I
M9B`H)&%T=')I8G5T97,I('L*("`@("`@("`@("`@("`@("`@("`D;V)J96-T
M<ULD;F%M95TM/E]F<F]M071T<FEB=71E<R@D9&%T85LD:61=*3L*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&]B:F5C
M='-;)&YA;65=+3YS971$871A*"1D871A6R1I9%TI.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)&]B:F5C='-;)&YA;65=+3YS971/<F1E
M<B@D=&AI<RT^9V5T3W)D97(H)&YA;64I*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1O8FIE8W1S.PH@("`@?0H*("`@("\J
M*@H@("`@("H@17AP;W)T(&$@;&ES="!O9B!O8FIE8W1S+@H@("`@("H*("`@
M("`J($!P87)A;2!C;VYS=&%N="`D9F]R;6%T("`@("`@1F]R;6%T(&]F('1H
M92!E>'!O<G0*("`@("`J($!P87)A;2!S=')I;F<@("`D<W1A<G1L96%F("`@
M5&AE(&YA;64@;V8@=&AE(&QE868@9G)O;2!W:&EC:"!W92!S=&%R=`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@97AP;W)T('1R
M964N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`@)')E;&]A9"`@("`@(%)E+6QO
M860@=&AE(')E<75E<W1E9"!C:'5N:S\@1&5F875L=',@=&\*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9F%L<V4@*&]N;'D@=VAA="!I
M<R!C=7)R96YT;'D@;&]A9&5D*2X*("`@("`J($!P87)A;2!S=')I;F<@("`D
M<F]O=&YA;64@("`@5&AE(&QA8F5L('1O('5S92!F;W(@=&AE(')O;W0@96QE
M;65N="X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1&5F
M875L=',@=&\@1$%40512145?4D]/5"X*("`@("`J($!P87)A;2!I;G1E9V5R
M("`D;6%X9&5P=&@@("`@5&AE(&UA>&EM=6T@;G5M8F5R(&]F(&QE=F5L<R!T
M;R!R971U<FXN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($1E9F%U;'1S('1O($1!5$%44D5%7U)/3U0L('=H:6-H(&ES(&YO"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&QI;6ET+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@("1L;V%D5')E92`@("!,;V%D(&$@=')E92!S=&%R
M=&EN9R!A="`D<F]O="P@;W(@:G5S="!T:&4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<F5Q=65S=&5D(&QE=F5L(&%N9"!D:7)E8W0@
M<&%R96YT<S\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M1&5F875L=',@=&\@<VEN9VQE(&QE=F5L+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@("1S;W)T8GE?;F%M92!!='1R:6)U=&4@;F%M92!T;R!U<V4@9F]R('-O
M<G1I;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG("`@)'-O<G1B>5]K97D@($%T
M=')I8G5T92!K97D@=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@("1D:7)E8W1I;VX@("!3;W)T(&1I<F5C=&EO;CH*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#`@+2!A<V-E;F1I;F<*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$@+2!D97-C
M96YD:6YG"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE('1R964@
M<F5P<F5S96YT871I;VX@;V8@=&AE(&]B:F5C=',L(&]R(&$@4$5!4E]%<G)O
M<@H@("`@("H@("`@("`@("`@("`@("`@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T*"1F;W)M870L("1S=&%R=&QE868@/2!$051!5%)%
M15]23T]4+"`D<F5L;V%D(#T@9F%L<V4L"B`@("`@("`@("`@("`@("`@)')O
M;W1N86UE(#T@1$%40512145?4D]/5"P@)&UA>&1E<'1H(#T@+3$L("1L;V%D
M5')E92`](&9A;'-E+`H@("`@("`@("`@("`@("`@("1S;W)T8GE?;F%M92`]
M(&YU;&PL("1S;W)T8GE?:V5Y(#T@;G5L;"P@)&1I<F5C=&EO;B`](#`I"B`@
M("!["B`@("`@("`@+RH@4V5T('-O<G1I;F<@:&%S:"`J+PH@("`@("`@(&EF
M("@A:7-?;G5L;"@D<V]R=&)Y7VYA;64I('Q\("%I<U]N=6QL*"1S;W)T8GE?
M;F%M92DI('L*("`@("`@("`@("`@)'1H:7,M/E]S;W)T2&%S:"`]($1A=&%4
M<F5E.CIS;W)T2&%S:"@D<W1A<G1L96%F+"`D<V]R=&)Y7VYA;64L("1S;W)T
M8GE?:V5Y+"`D9&ER96-T:6]N*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3Y?;&]A9"@D<W1A<G1L96%F+"`D;&]A9%1R964L("1R96QO860L("1S;W)T
M8GE?;F%M92P@)'-O<G1B>5]K97DL("1D:7)E8W1I;VXI.PH@("`@("`@("1O
M=70@/2!A<G)A>2@I.PH*("`@("`@("!S=VET8V@@*"1F;W)M870I('L*("`@
M("`@("!C87-E($1!5$%44D5%7T9/4DU!5%]44D5%.@H@("`@("`@("`@("`D
M<W1A<G1I9"`]("1T:&ES+3YG971)9"@D<W1A<G1L96%F+"`D;6%X9&5P=&@I
M.PH@("`@("`@("`@("!I9B`H:7-?82@D<W1A<G1I9"P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1S=&%R=&ED.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?97AT<F%C=$%L;$QE=F5L5')E
M92@D;W5T+"`D<W1A<G1I9"P@)&UA>&1E<'1H*3L*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&-A<V4@1$%40512145?1D]234%47T9,050Z"B`@("`@
M("`@("`@("1S=&%R=&ED(#T@)'1H:7,M/F=E=$ED*"1S=&%R=&QE868I.PH@
M("`@("`@("`@("!I9B`H:7-?82@D<W1A<G1I9"P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1S=&%R=&ED.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1T:&ES+3Y?97AT<F%C=$%L;$QE=F5L3&ES="@D
M;W5T+"`D<W1A<G1I9"P@)&UA>&1E<'1H*3L*("`@("`@("`@("`@:68@*"%E
M;7!T>2@D;W5T6T1!5$%44D5%7U)/3U1=*2D@>PH@("`@("`@("`@("`@("`@
M)&]U=%M$051!5%)%15]23T]472`]("1R;V]T;F%M93L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TYO="!S=7!P;W)T960G
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?;G5L;"@D=&AI<RT^7W-O
M<G1(87-H*2D@>PH@("`@("`@("`@("`O*B!297-E="!S;W)T:6YG(&AA<V@N
M("HO"B`@("`@("`@("`@("1T:&ES+3Y?<V]R=$AA<V@@/2!N=6QL.PH@("`@
M("`@("`@("`O*B!2979E<G-E('-I;F-E('1H92!A='1R:6)U=&4@<V]R=&EN
M9R!C;VUB:6YE9"!W:71H('1R964@=7`M=V%R9`H@("`@("`@("`@("`@*B!S
M;W)T:6YG('!R;V1U8V5S(&$@<F5V97)S960@;V)J96-T(&]R9&5R+B`J+PH@
M("`@("`@("`@("`D;W5T(#T@87)R87E?<F5V97)S92@D;W5T+"!T<G5E*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;W5T.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0V]U;G1S(&]B:F5C=',N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<W1A<G1L96%F("!4:&4@;F%M92!O9B!T:&4@;&5A9B!F<F]M
M('=H:6-H('=E('-T87)T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&-O=6YT:6YG+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@
M5&AE(&YU;6)E<B!O9B!T:&4@;V)J96-T<R!B96QO=R`D<W1A<G1L96%F+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!C;W5N="@D<W1A<G1L96%F(#T@1$%40512
M145?4D]/5"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]C;W5N="@D
M<W1A<G1L96%F*3L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!A='1R
M:6)U=&4@<V]R="!H87-H"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N
M,0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1R;V]T("`@("`@("`@
M5&AE(&YA;64@;V8@=&AE(&QE868@9G)O;2!W:&EC:"!W92!S=&%R=`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@97AP;W)T('1R
M964N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V]R=&)Y7VYA;64@($%T=')I
M8G5T92!N86UE('1O('5S92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A;2!S
M=')I;F<@("1S;W)T8GE?:V5Y("`@071T<FEB=71E(&ME>2!T;R!U<V4@9F]R
M('-O<G1I;F<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&ER96-T:6]N("`@
M(%-O<G0@9&ER96-T:6]N.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`P("T@87-C96YD:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#$@+2!D97-C96YD:6YG"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@5&AE('-O<G0@:&%S:`H@("`@("HO"B`@("!F=6YC=&EO
M;B!S;W)T2&%S:"@D<F]O="P@)'-O<G1B>5]N86UE(#T@;G5L;"P@)'-O<G1B
M>5]K97D@/2!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@)&1I<F5C=&EO
M;B`](#`I"B`@("!["B`@("`@("`@<F5T=7)N('-P<FEN=&8H)R5S+25S+25S
M+25S)RP@)')O;W0L("1S;W)T8GE?;F%M92P@)'-O<G1B>5]K97DL("1D:7)E
M8W1I;VXI.PH@("`@?0H*("`@("\J*@H@("`@("H@17AP;W)T(&$@;&ES="!O
M9B!O8FIE8W1S(&IU<W0@;&EK92!G970H*2!A8F]V92P@8G5T('5S97,@86X*
M("`@("`J(&]B:F5C="!I9"!T;R!F971C:"!T:&4@;&ES="!O9B!O8FIE8W1S
M+@H@("`@("H*("`@("`J($!P87)A;2!C;VYS=&%N="`D9F]R;6%T("`@($9O
M<FUA="!O9B!T:&4@97AP;W)T+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-T
M87)T;&5A9B`@5&AE(&ED(&]F('1H92!L96%F(&9R;VT@=VAI8V@@=V4@<W1A
M<G0@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!E>'!O
M<G0@=')E92X*("`@("`J($!P87)A;2!B;V]L96%N("1R96QO860@("`@(%)E
M;&]A9"!T:&4@<F5Q=65S=&5D(&-H=6YK/R!$969A=6QT<R!T;PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9F%L<V4@*&]N;'D@=VAA="!I
M<R!C=7)R96YT;'D@;&]A9&5D*2X*("`@("`J($!P87)A;2!S=')I;F<@("1R
M;V]T;F%M92`@(%1H92!L86)E;"!T;R!U<V4@9F]R('1H92!R;V]T(&5L96UE
M;G0N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!$969A=6QT
M<R!T;R!$051!5%)%15]23T]4+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UA
M>&1E<'1H("`@5&AE(&UA>&EM=6T@;G5M8F5R(&]F(&QE=F5L<R!T;R!R971U
M<FX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@($1E9F%U;'1S
M('1O("TQ+"!W:&EC:"!I<R!N;R!L:6UI="X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4:&4@=')E92!R97!R97-E;G1A=&EO;B!O9B!T:&4@;V)J
M96-T<RP@;W(@82!014%27T5R<F]R"B`@("`@*B`@("`@("`@("`@("`@("!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971">4ED*"1F;W)M
M870L("1S=&%R=&QE868@/2!$051!5%)%15]23T]4+"`D<F5L;V%D(#T@9F%L
M<V4L"B`@("`@("`@("`@("`@("`@("`@("1R;V]T;F%M92`]($1!5$%44D5%
M7U)/3U0L("1M87AD97!T:"`]("TQ*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M;&]A9$)Y260H)'-T87)T;&5A9BD["B`@("`@("`@)&]U="`](&%R<F%Y*"D[
M"@H@("`@("`@('-W:71C:"`H)&9O<FUA="D@>PH@("`@("`@(&-A<V4@1$%4
M0512145?1D]234%47U12144Z"B`@("`@("`@("`@("1T:&ES+3Y?97AT<F%C
M=$%L;$QE=F5L5')E92@D;W5T+"`D<W1A<G1L96%F+"`D;6%X9&5P=&@I.PH@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!$051!5%)%15]&3U)-
M051?1DQ!5#H*("`@("`@("`@("`@)'1H:7,M/E]E>'1R86-T06QL3&5V96Q,
M:7-T*"1O=70L("1S=&%R=&QE868L("1M87AD97!T:"D["B`@("`@("`@("`@
M(&EF("@A96UP='DH)&]U=%M$051!5%)%15]23T]472DI('L*("`@("`@("`@
M("`@("`@("1O=71;1$%40512145?4D]/5%T@/2`D<F]O=&YA;64["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U;'0Z
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=.;W0@<W5P
M<&]R=&5D)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&]U=#L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!L:7-T(&]F(&%L;"!G<F]U
M<',@*')O;W0@;F]D97,I(&]F('1H92!D871A('1R964N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@5&AE('1H92!G<F]U<"!)1',*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T1W)O=7!S*"D*("`@('L*("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G;F]T('-U<'!O<G1E9"<I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T<FEE=F4@9&%T82!F;W(@86X@;V)J96-T(&9R;VT@
M=&AE(&1A=&%T<F5E7V1A=&$@9FEE;&0N"B`@("`@*@H@("`@("H@0&%B<W1R
M86-T"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-I9"`@5&AE(&]B
M:F5C="!I9"!T;R!F971C:"P@;W(@86X@87)R87D@;V8@;V)J96-T(&ED<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&%T82@D8VED*0H@("`@>PH@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=N;W0@<W5P<&]R=&5D)RD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!);7!O<G0@82!L:7-T(&]F(&]B:F5C
M=',N(%5S960@8GD@9')I=F5R<R!T;R!P;W!U;&%T92!T:&4@:6YT97)N86P*
M("`@("`J("1?9&%T82!A<G)A>2X*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@("`D9&%T82`@("`@5&AE(&1A=&$@=&\@:6UP;W)T+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`@)&-H87)S970@(%1H92!C:&%R<V5T('1O(&-O;G9E<G0@
M=&AE(&]B:F5C="!N86UE(&9R;VTN"B`@("`@*B\*("`@(&9U;F-T:6]N('-E
M="@D9&%T82P@)&-H87)S970@/2!N=6QL*0H@("`@>PH@("`@("`@("1C:61S
M(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D9&%T82!A<R`D:60@/3X@
M)&-A="D@>PH@("`@("`@("`@("!I9B`H(6ES7VYU;&PH)&-H87)S970I*2![
M"B`@("`@("`@("`@("`@("`D8V%T6S%=(#T@4W1R:6YG.CIC;VYV97)T0VAA
M<G-E="@D8V%T6S%=+"`D8VAA<G-E="D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&-I9'-;)&-A=%LP75T@/2`D8V%T6S%=.PH@("`@("`@("`@("`D
M8W!A<F5N='-;)&-A=%LP75T@/2`D8V%T6S)=.PH@("`@("`@("`@("`D8V]R
M9&5R<ULD8V%T6S!=72`]("1C871;,UT["B`@("`@("`@("`@("1S;W)D97)S
M6R1C871;,%U=(#T@)&ED.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H
M)&-I9',@87,@)&ED(#T^("1N86UE*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M9&%T85LD:61=6R=N86UE)UT@/2`D;F%M93L*("`@("`@("`@("`@)'1H:7,M
M/E]D871A6R1I9%U;)V]R9&5R)UT@/2`D8V]R9&5R<ULD:61=.PH@("`@("`@
M("`@("!I9B`H(6ES7VYU;&PH)'1H:7,M/E]S;W)T2&%S:"DI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?9&%T85LD:61=6R=S;W)T97(G75LD=&AI<RT^
M7W-O<G1(87-H72`]("1S;W)D97)S6R1I9%T["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*"%E;7!T>2@D8W!A<F5N='-;)&ED72DI('L*("`@("`@
M("`@("`@("`@("1P87)E;G1S(#T@97AP;&]D92@G.B<L('-U8G-T<B@D8W!A
M<F5N='-;)&ED72P@,2DI.PH@("`@("`@("`@("`@("`@)'!A<B`]("1P87)E
M;G1S6V-O=6YT*"1P87)E;G1S*2`M(#%=.PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]D871A6R1I9%U;)W!A<F5N="==(#T@)'!A<CL*"B`@("`@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?;F%M94UA<%LD<&%R72DI('L*("`@
M("`@("`@("`@("`@("`@("`O+R!)9B!W92=V92!A;')E861Y(&QO861E9"!T
M:&4@9&ER96-T('!A<F5N="!O9@H@("`@("`@("`@("`@("`@("`@("\O('1H
M:7,@;V)J96-T+"!U<V4@=&AA="!T;R!F:6YD('1H92!F=6QL(&YA;64N"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]N86UE36%P6R1I9%T@/2`D=&AI
M<RT^7VYA;65-87!;)'!A<ET@+B`G.B<@+B`D;F%M93L*("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@+R\@3W1H97)W:7-E
M+"!R=6X@=&AR;W5G:"!P87)E;G1S(&]N92!B>2!O;F4@=&\*("`@("`@("`@
M("`@("`@("`@("`O+R!B=6EL9"!I="!U<"X*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7VYA;65-87!;)&ED72`]("<G.PH@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1P87)E;G1S(&%S("1P87))1"D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1C:61S6R1P87))1%TI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VYA;65-87!;)&ED
M72`N/2`G.B<@+B`D8VED<ULD<&%R241=.PH@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?;F%M94UA<%LD:61=(#T@<W5B<W1R*"1T:&ES+3Y?;F%M
M94UA<%LD:61=+"`Q*2`N("<Z)R`N("1N86UE.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]D871A6R1I9%U;)W!A<F5N="==(#T@1$%40512145?4D]/5#L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?;F%M94UA<%LD:61=(#T@)&YA;64["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@17AT<F%C="!O;F4@;&5V96P@;V8@9&%T82!F
M;W(@82!P87)E;G0@;&5A9BP@<V]R=&5D(&9I<G-T(&)Y"B`@("`@*B!T:&5I
M<B!O<F1E<B!A;F0@=&AE;B!B>2!N86UE+B!4:&ES(&9U;F-T:6]N(&ES(&$@
M=V%Y('1O(&=E="!A"B`@("`@*B!C;VQL96-T:6]N(&]F("1L96%F)W,@8VAI
M;&1R96XN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&5A9B`@3F%M
M92!O9B!T:&4@<&%R96YT(&9R;VT@=VAI8V@@=&\@<W1A<G0N"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>0H@("`@("HO"B`@("!F=6YC=&EO;B!?97AT
M<F%C=$]N94QE=F5L*"1L96%F(#T@1$%40512145?4D]/5"D*("`@('L*("`@
M("`@("`D;W5T(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^
M7V1A=&$@87,@)&ED(#T^("1V86QS*2!["B`@("`@("`@("`@(&EF("@D=F%L
M<ULG<&%R96YT)UT@/3T@)&QE868I('L*("`@("`@("`@("`@("`@("1O=71;
M)&ED72`]("1V86QS.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!I9B`H:7-?;G5L;"@D=&AI<RT^7W-O<G1(87-H*2D@>PH@("`@("`@("`@
M("!U87-O<G0H)&]U="P@87)R87DH)'1H:7,L("=?8VUP)RDI.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@('5A<V]R="@D;W5T+"!A<G)A>2@D=&AI
M<RP@)U]C;7!3;W)T960G*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&]U=#L*("`@('T*"B`@("`O*BH*("`@("`J($5X=')A8W0@86QL(&QE=F5L
M<R!O9B!D871A+"!S=&%R=&EN9R!F<F]M(&$@9VEV96X@<&%R96YT"B`@("`@
M*B!L96%F(&EN('1H92!D871A=')E92X*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)&]U="`@("`@("`@(%1H:7,@:7,@86X@:71E<F%T:6YG(&9U;F-T
M:6]N+"!S;R`D;W5T(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@('!A<W-E9"!B>2!R969E<F5N8V4@=&\@8V]N=&%I;B!T:&4@<F5S=6QT
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'!A<F5N="`@("!4:&4@;F%M92!O
M9B!T:&4@<&%R96YT(&9R;VT@=VAI8V@@=&\@8F5G:6XN"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D;6%X9&5P=&@@($UA>"!O9B!L979E;',@;V8@9&5P=&@@
M=&\@8VAE8VLN"B`@("`@*@H@("`@("H@0&YO=&4@268@;F]T:&EN9R!I<R!R
M971U<FYE9"!T:&%T(&UE86YS('1H97)E(&ES(&YO(&-H:6QD+"!B=70*("`@
M("`J(&1O;B=T(&9O<F=E="!T;R!A9&0@=&AE('!A<F5N="!I9B!A;GD@<W5B
M<V5Q=65N="!O<&5R871I;VYS(&%R90H@("`@("H@<F5Q=6ER960A"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]E>'1R86-T06QL3&5V96Q4<F5E*"8D;W5T+"`D
M<&%R96YT(#T@1$%40512145?4D]/5"P@)&UA>&1E<'1H(#T@+3$I"B`@("![
M"B`@("`@("`@:68@*"1M87AD97!T:"`]/2`P*2!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1O=71;)'!A<F5N=%T@
M/2!T<G5E.PH*("`@("`@("`D:R`]("1T:&ES+3Y?97AT<F%C=$]N94QE=F5L
M*"1P87)E;G0I.PH@("`@("`@(&9O<F5A8V@@*"1K(&%S("1O8FIE8W0@/3X@
M)'8I('L*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D;W5T6R1P87)E;G1=
M*2D@>PH@("`@("`@("`@("`@("`@)&]U=%LD<&%R96YT72`](&%R<F%Y*"D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&]U=%LD<&%R96YT75LD;V)J
M96-T72`]('1R=64["B`@("`@("`@("`@("1T:&ES+3Y?97AT<F%C=$%L;$QE
M=F5L5')E92@D;W5T6R1P87)E;G1=+"`D;V)J96-T+"`D;6%X9&5P=&@@+2`Q
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'1R86-T(&%L
M;"!L979E;',@;V8@9&%T82P@<W1A<G1I;F<@9G)O;2!A;GD@<&%R96YT(&EN
M"B`@("`@*B!T:&4@=')E92X*("`@("`J"B`@("`@*B!2971U<FYE9"!A<G)A
M>2!F;W)M870Z(&%R<F%Y*'!A<F5N="`]/B!A<G)A>2AC:&EL9"`]/B!T<G5E
M*2D*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&]U="`@("`@("`@(%1H
M:7,@:7,@86X@:71E<F%T:6YG(&9U;F-T:6]N+"!S;R`D;W5T(&ES"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@('!A<W-E9"!B>2!R969E<F5N
M8V4@=&\@8V]N=&%I;B!T:&4@<F5S=6QT+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@)'!A<F5N="`@("!4:&4@;F%M92!O9B!T:&4@<&%R96YT(&9R;VT@=VAI
M8V@@=&\@8F5G:6XN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;6%X9&5P=&@@
M($UA>"!N=6UB97(@;V8@;&5V96QS(&]F(&1E<'1H('1O(&-H96-K+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?97AT<F%C=$%L;$QE=F5L3&ES="@F)&]U="P@
M)'!A<F5N="`]($1!5$%44D5%7U)/3U0L("1M87AD97!T:"`]("TQ*0H@("`@
M>PH@("`@("`@(&EF("@D;6%X9&5P=&@@/3T@,"D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O+R!4:&ES(&ES(')E
M9'5N9&%N="!M;W-T(&]F('1H92!T:6UE+"!S;R!M86ME('-U<F4@=V4@;F5E
M9"!T;PH@("`@("`@("\O(&1O(&ET+@H@("`@("`@(&EF("AE;7!T>2@D;W5T
M6R1P87)E;G1=*2D@>PH@("`@("`@("`@("`D;W5T6R1P87)E;G1=(#T@)'1H
M:7,M/F=E=$YA;64H)'!A<F5N="D["B`@("`@("`@?0H*("`@("`@("`D:R`]
M(&%R<F%Y7VME>7,H)'1H:7,M/E]E>'1R86-T3VYE3&5V96PH)'!A<F5N="DI
M.PH@("`@("`@(&9O<F5A8V@@*"1K(&%S("1O8FIE8W0I('L*("`@("`@("`@
M("`@)&]U=%LD;V)J96-T72`]("1T:&ES+3YG971.86UE*"1O8FIE8W0I.PH@
M("`@("`@("`@("`D=&AI<RT^7V5X=')A8W1!;&Q,979E;$QI<W0H)&]U="P@
M)&]B:F5C="P@)&UA>&1E<'1H("T@,2D["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!A(&-H:6QD)W,@9&ER96-T('!A<F5N="!)
M1"X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&-H:6QD("!%:71H97(@
M=&AE(&]B:F5C="P@86X@87)R87D@8V]N=&%I;FEN9R!T:&4*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@('!A=&@@96QE;65N=',L(&]R('1H92!O8FIE
M8W0@;F%M92!F;W(@=VAI8V@*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M('1O(&QO;VL@=7`@=&AE('!A<F5N="=S($E$+@H@("`@("H*("`@("`J($!R
M971U<FX@:6YT96=E<B`@5&AE('5N:7%U92!)1"!O9B!T:&4@<&%R96YT+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971087)E;G0H)&-H:6QD*0H@("`@>PH@
M("`@("`@(&EF("AI<U]A*"1C:&EL9"P@)T1A=&%4<F5E3V)J96-T)RDI('L*
M("`@("`@("`@("`@)&-H:6QD(#T@)&-H:6QD+3YG971.86UE*"D["B`@("`@
M("`@?0H@("`@("`@("1I9"`]("1T:&ES+3YG971)9"@D8VAI;&0I.PH@("`@
M("`@(&EF("AI<U]A*"1I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&ED.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?9&%T85LD:61=6R=P87)E;G0G73L*("`@('T*"B`@("`O*BH*("`@("`J
M($=E="!A("1C:&EL9"=S(&1I<F5C="!P87)E;G0@240N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&-H:6QD260@($=E="!T:&4@<&%R96YT(&]F
M('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@
M5&AE('5N:7%U92!)1"!O9B!T:&4@<&%R96YT+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971087)E;G1">4ED*"1C:&EL9$ED*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?;&]A9$)Y260H)&-H:6QD260I.PH@("`@("`@(')E='5R;B!I<W-E
M="@D=&AI<RT^7V1A=&%;)&-H:6QD261=*2`_"B`@("`@("`@("`@("1T:&ES
M+3Y?9&%T85LD8VAI;&1)9%U;)W!A<F5N="==(#H*("`@("`@("`@("`@4$5!
M4CHZ<F%I<V5%<G)O<B@D8VAI;&1)9"`N("<@;F]T(&9O=6YD)RD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F('!A<F5N=',@86QL('1H
M92!W87D@=7`@=&\@=&AE(')O;W0@;V)J96-T(&9O<@H@("`@("H@)&-H:6QD
M+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`@("1C:&EL9"`@(%1H92!N
M86UE(&]F('1H92!C:&EL9`H@("`@("H@0'!A<F%M(&)O;VQE86X@)&=E=&ED
M<R`@268@=')U92P@<F5T=7)N('!A<F5N="!)1',[(&]T:&5R=VES92P@<F5T
M=7)N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!N86UE<RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!;8VAI;&1=(%MP87)E;G1=(&EN
M(&$@=')E92!F;W)M870N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<F5N
M=',H)&-H:6QD+"`D9V5T:61S(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'!I
M9"`]("1T:&ES+3YG971087)E;G0H)&-H:6QD*3L*("`@("`@("!I9B`H:7-?
M82@D<&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=087)E;G1S(&YO="!F;W5N9#H@)R`N("1P:60M
M/F=E=$UE<W-A9V4H*2D["B`@("`@("`@?0H@("`@("`@("1P;F%M92`]("1T
M:&ES+3YG971.86UE*"1P:60I.PH@("`@("`@(&EF("@D9V5T:61S*2!["B`@
M("`@("`@("`@("1P87)E;G1S(#T@87)R87DH)'!I9"`]/B!T<G5E*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&%R96YT<R`](&%R<F%Y*"1P
M;F%M92`]/B!T<G5E*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D<&ED("$]
M($1!5$%44D5%7U)/3U0I('L*("`@("`@("`@("`@:68@*"1G971I9',I('L*
M("`@("`@("`@("`@("`@("1P87)E;G1S6R1P:61=(#T@)'1H:7,M/F=E=%!A
M<F5N=',H)'!N86UE+"`D9V5T:61S*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1P87)E;G1S6R1P;F%M95T@/2`D=&AI<RT^9V5T
M4&%R96YT<R@D<&YA;64L("1G971I9',I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'!A<F5N=',["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'970@82!L:7-T(&]F('!A<F5N=',@86QL('1H92!W87D@=7`@
M=&\@=&AE(')O;W0@;V)J96-T(&9O<@H@("`@("H@)&-H:6QD+@H@("`@("H*
M("`@("`J($!P87)A;2!I;G1E9V5R("1C:&EL9$ED("!4:&4@:60@;V8@=&AE
M(&-H:6QD+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)E;G1S("`@(%1H92!A
M<G)A>2P@87,@=V4@8G5I;&0@:70@=7`N"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@02!F;&%T(&QI<W0@;V8@86QL(&]F('1H92!P87)E;G1S(&]F
M("1C:&EL9"P*("`@("`J("`@("`@("`@("`@("`@(&AA<VAE9"!I;B`D:60@
M/3X@)&YA;64@9F]R;6%T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971087)E
M;G1,:7-T*"1C:&EL9$ED+"`D<&%R96YT<R`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@)'!I9"`]("1T:&ES+3YG971087)E;G1">4ED*"1C:&EL9$ED*3L*
M("`@("`@("!I9B`H:7-?82@D<&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=087)E;G1S(&YO="!F
M;W5N9#H@)R`N("1P:60M/F=E=$UE<W-A9V4H*2D["B`@("`@("`@?0H*("`@
M("`@("!I9B`H)'!I9"`A/2!$051!5%)%15]23T]4*2!["B`@("`@("`@("`@
M("1P87)E;G1S6R1P:61=(#T@)'1H:7,M/F=E=$YA;64H)'!I9"D["B`@("`@
M("`@("`@("1P87)E;G1S(#T@)'1H:7,M/F=E=%!A<F5N=$QI<W0H)'!I9"P@
M)'!A<F5N=',I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P87)E;G1S
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@<&%R96YT($E$('-T<FEN
M9R`H:60Z8VED(&9O<FUA="D@9F]R('1H92!S<&5C:69I960@;V)J96-T+@H@
M("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D;V)J96-T("!4:&4@;V)J96-T
M('1O(')E='5R;B!A('!A<F5N="!S=')I;F<@9F]R+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG?%!%05)?17)R;W(@(%1H92!)1"`B<&%T:"(@=&\@
M=&AE('!A<F5N="!O8FIE8W0@;W(*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T4&%R96YT2613=')I;F<H)&]B:F5C="D*("`@('L*("`@
M("`@("`D<'1R964@/2`D=&AI<RT^9V5T4&%R96YT<R@D;V)J96-T+"!T<G5E
M*3L*("`@("`@("!I9B`H:7-?82@D<'1R964L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1P=')E93L*("`@("`@("!]"@H@("`@("`@
M("1P:61S(#T@)R<["B`@("`@("`@=VAI;&4@*"AL:7-T*"1I9"P@)'!A<F5N
M="D@/2!E86-H*"1P=')E92DI("8F(&ES7V%R<F%Y*"1P87)E;G0I*2!["B`@
M("`@("`@("`@("1P:61S(#T@)SHG("X@)&ED("X@)'!I9',["B`@("`@("`@
M("`@("1P=')E92`]("1P87)E;G0["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'!I9',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&YU;6)E
M<B!O9B!C:&EL9')E;B!A;B!O8FIE8W0@:&%S+"!O;FQY(&-O=6YT:6YG(&EM
M;65D:6%T90H@("`@("H@8VAI;&1R96XL(&YO="!G<F%N9&-H:6QD<F5N+"!E
M=&,N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1P87)E;G0@($5I=&AE
M<B!T:&4@;V)J96-T(&]R('1H92!N86UE(&9O<B!W:&EC:"!T;R!C;W5N=`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@('1H92!C:&EL9')E;BP@9&5F
M875L=',@=&\@=&AE(')O;W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`H1$%40512145?4D]/5"DN"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E
M9V5R"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$YU;6)E<D]F0VAI;&1R96XH
M)'!A<F5N="`]($1!5$%44D5%7U)/3U0I"B`@("!["B`@("`@("`@:68@*&ES
M7V$H)'!A<F5N="P@)T1A=&%4<F5E3V)J96-T)RDI('L*("`@("`@("`@("`@
M)'!A<F5N="`]("1P87)E;G0M/F=E=$YA;64H*3L*("`@("`@("!]"B`@("`@
M("`@)'1H:7,M/E]L;V%D*"1P87)E;G0I.PH@("`@("`@("1O=70@/2`D=&AI
M<RT^7V5X=')A8W1/;F5,979E;"@D=&AI<RT^9V5T260H)'!A<F5N="DI.PH@
M("`@("`@(')E='5R;B!I<U]A<G)A>2@D;W5T*2`_(&-O=6YT*"1O=70I(#H@
M,#L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K(&EF(&%N(&]B:F5C="!E
M>&ES=',@;W(@;F]T+B!4:&4@<F]O="!E;&5M96YT($1!5$%44D5%7U)/3U0@
M86QW87ES(&5X:7-T<RX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&]B
M:F5C="`@5&AE(&YA;64@;V8@=&AE(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE(&]B:F5C="!E>&ES=',L(&9A
M;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@97AI<W1S*"1O
M8FIE8W0I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1O8FIE8W0I*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@:68@
M*&ES7V$H)&]B:F5C="P@)T1A=&%4<F5E3V)J96-T)RDI('L*("`@("`@("`@
M("`@)&]B:F5C="`]("1O8FIE8W0M/F=E=$YA;64H*3L*("`@("`@("!](&5L
M<V5I9B`H:7-?87)R87DH)&]B:F5C="DI('L*("`@("`@("`@("`@)&]B:F5C
M="`](&EM<&QO9&4H)SHG+"`D;V)J96-T*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@D;V)J96-T(#T]($1!5$%44D5%7U)/3U0I('L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`D:61-87`@/2!A<G)A
M>5]F;&EP*"1T:&ES+3Y?;F%M94UA<"D["B`@("`@("`@:68@*&ES<V5T*"1I
M9$UA<%LD;V)J96-T72DI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?0H*("`@("`@("`D=&AI<RT^7VQO860H)&]B:F5C="D["B`@("`@
M("`@)&ED36%P(#T@87)R87E?9FQI<"@D=&AI<RT^7VYA;65-87`I.PH@("`@
M("`@(')E='5R;B!I<W-E="@D:61-87!;)&]B:F5C=%TI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1V5T('1H92!N86UE(&]F(&%N(&]B:F5C="!F<F]M(&ET
M<R!I9"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:60@(%1H92!I
M9"!F;W(@=VAI8V@@=&\@;&]O:R!U<"!T:&4@;F%M92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9PH@("`@("HO"B`@("!F=6YC=&EO;B!G971.86UE
M*"1I9"D*("`@('L*("`@("`@("`O*B!)9B!N;R!I9"!O<B!I9B!I9"!I<R!A
M(%!%05(@97)R;W(L(')E='5R;B!N=6QL+B`J+PH@("`@("`@(&EF("AE;7!T
M>2@D:60I('Q\(&ES7V$H)&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*"B`@("`@("`@+RH@268@8VAE
M8VMI;F<@;F%M92!O9B!R;V]T+"!R971U<FX@1$%40512145?4D]/5"X@*B\*
M("`@("`@("!I9B`H)&ED(#T]($1!5$%44D5%7U)/3U0I('L*("`@("`@("`@
M("`@<F5T=7)N($1!5$%44D5%7U)/3U0["B`@("`@("`@?0H*("`@("`@("`O
M*B!)9B!F;W5N9"!I;B!T:&4@;F%M92!M87`L(')E='5R;B!T:&4@;F%M92X@
M*B\*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]N86UE36%P6R1I9%TI*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VYA;65-87!;)&ED73L*("`@
M("`@("!]"@H@("`@("`@("\J($YO="!F;W5N9"!I;B!N86UE(&UA<"P@=')Y
M(&QO861I;F<@=&AI<R!I9"!I;G1O('1H92!N86UE"B`@("`@("`@("H@;6%P
M+B`J+PH@("`@("`@("1T:&ES+3Y?;&]A9$)Y260H)&ED*3L*"B`@("`@("`@
M+RH@268@:60@;&]A9&5D(')E='5R;B!T:&4@;F%M92P@;W1H97)W:7-E(')E
M='5R;B!N=6QL+B`J+PH@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7VYA
M;65-87!;)&ED72D@/PH@("`@("`@("`@("`D=&AI<RT^7VYA;65-87!;)&ED
M72`Z"B`@("`@("`@("`@(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M970@=&AE(&ED(&]F(&%N(&]B:F5C="!F<F]M(&ET<R!N86UE+@H@("`@("H*
M("`@("`J($!P87)A;2!M:7AE9"`D;F%M92`@16ET:&5R('1H92!O8FIE8W0L
M(&%N(&%R<F%Y(&-O;G1A:6YI;F<@=&AE"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@('!A=&@@96QE;65N=',L(&]R('1H92!O8FIE8W0@;F%M92!F;W(@
M=VAI8V@*("`@("`J("`@("`@("`@("`@("`@("`@("`@=&\@;&]O:R!U<"!T
M:&4@:60N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T260H)&YA;64I"B`@("!["B`@("`@("`@+RH@0VAE
M8VL@:68@)&YA;64@:7,@;F]T(&$@<W1R:6YG+B`J+PH@("`@("`@(&EF("AI
M<U]A*"1N86UE+"`G1&%T851R965/8FIE8W0G*2D@>PH@("`@("`@("`@("`O
M*B!$871A5')E94]B:F5C="P@9V5T('1H92!S=')I;F<@;F%M92X@*B\*("`@
M("`@("`@("`@)&YA;64@/2`D;F%M92T^9V5T3F%M92@I.PH@("`@("`@('T@
M96QS96EF("AI<U]A<G)A>2@D;F%M92DI('L*("`@("`@("`@("`@+RH@4&%T
M:"!A<G)A>2P@:6UP;&]D92!T;R!G970@=&AE('-T<FEN9R!N86UE+B`J+PH@
M("`@("`@("`@("`D;F%M92`](&EM<&QO9&4H)SHG+"`D;F%M92D["B`@("`@
M("`@?0H*("`@("`@("`O*B!)9B!C:&5C:VEN9R!I9"!O9B!R;V]T+"!R971U
M<FX@1$%40512145?4D]/5"X@*B\*("`@("`@("!I9B`H)&YA;64@/3T@1$%4
M0512145?4D]/5"D@>PH@("`@("`@("`@("!R971U<FX@1$%40512145?4D]/
M5#L*("`@("`@("!]"@H@("`@("`@("\J($-H96-K(&EF('1H92!N86UE(&%C
M='5A;&QY(&5X:7-T<RP@:68@;F]T(')E='5R;B!A(%!%05(*("`@("`@("`@
M*B!E<G)O<BX@*B\*("`@("`@("!I9B`H(21T:&ES+3YE>&ES=',H)&YA;64I
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1N86UE
M("X@)R!D;V5S(&YO="!E>&ES="<I.PH@("`@("`@('T*"B`@("`@("`@+RH@
M1FQI<"!T:&4@;F%M92!M87`@=&\@;&]O:R!U<"!T:&4@:60@=7-I;F<@=&AE
M(&YA;64@87,@:V5Y+B`J+PH@("`@("`@("1I9$UA<"`](&%R<F%Y7V9L:7`H
M)'1H:7,M/E]N86UE36%P*3L*("`@("`@("!R971U<FX@)&ED36%P6R1N86UE
M73L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@;W)D97(@<&]S:71I
M;VX@;V8@86X@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D
M8VAI;&0@($5I=&AE<B!T:&4@;V)J96-T(&]R('1H92!N86UE+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1H92!O8FIE8W0G<R!O<F1E<B!P;W-I
M=&EO;B!O<B!A(%!%05(@97)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T3W)D97(H)&-H:6QD*0H@("`@>PH@("`@("`@(&EF("AI
M<U]A*"1C:&EL9"P@)T1A=&%4<F5E3V)J96-T)RDI('L*("`@("`@("`@("`@
M)&-H:6QD(#T@)&-H:6QD+3YG971.86UE*"D["B`@("`@("`@?0H@("`@("`@
M("1I9"`]("1T:&ES+3YG971)9"@D8VAI;&0I.PH@("`@("`@(&EF("AI<U]A
M*"1I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&ED
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES+3Y?9&%T
M85LD:61=6R=O<F1E<B==*2`_"B`@("`@("`@("`@("1T:&ES+3Y?9&%T85LD
M:61=6R=O<F1E<B==(#H*("`@("`@("`@("`@;G5L;#L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E<&QA8V4@86QL(&]C8W5R96YC97,@;V8@)SHG(&EN(&%N
M(&]B:F5C="!N86UE('=I=&@@)RXG+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@(%1H92!N86UE(&]F('1H92!O8FIE8W0N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!E;F-O9&5D(&YA;64N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&5N8V]D94YA;64H)&YA;64I"B`@("!["B`@("`@
M("`@<F5T=7)N('-T<E]R97!L86-E*"<Z)RP@)RXG+"`D;F%M92D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!'970@=&AE('-H;W)T(&YA;64@;V8@86X@;V)J
M96-T+"!R971U<FYS(&]N;'D@=&AE(&QA<W0@<&]R=&EO;B!O9B!T:&4*("`@
M("`J(&9U;&P@;F%M92X@1F]R(&1I<W!L87D@<'5R<&]S97,@;VYL>2X*("`@
M("`J"B`@("`@*B!`<W1A=&EC"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;F%M92`@5&AE(&YA;64@;V8@=&AE(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(&]B:F5C="=S('-H;W)T(&YA;64N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%-H;W)T3F%M92@D;F%M92D*("`@('L*
M("`@("`@("`O*B!)9B!T:&5R92!A<F4@<V5V97)A;"!C;VUP;VYE;G1S('1O
M('1H92!N86UE+"!E>'!L;V1E(&%N9"!G970@=&AE"B`@("`@("`@("H@;&%S
M="!O;F4L(&]T:&5R=VES92!J=7-T(')E='5R;B!T:&4@;F%M92X@*B\*("`@
M("`@("!I9B`H<W1R<&]S*"1N86UE+"`G.B<I("$]/2!F86QS92D@>PH@("`@
M("`@("`@("`D;F%M92`](&5X<&QO9&4H)SHG+"`D;F%M92D["B`@("`@("`@
M("`@("1N86UE(#T@87)R87E?<&]P*"1N86UE*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1N86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!A('1R964@<V]R=&5D(&)Y('1H92!S<&5C:69I960@871T<FEB=71E(&YA
M;64@86YD+V]R(&ME>2X*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J
M"B`@("`@*B!`<VEN8V4@2&]R9&4@,RXQ"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<F]O="`@("`@("`@(%=H:6-H('!O<G1I;VX@;V8@=&AE('1R
M964@=&\@<V]R="X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!$969A=6QT<R!T;R!A;&P@;V8@:70N"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D;&]A9%1R964@("`@4V]R="!T:&4@=')E92!S=&%R=&EN9R!A="`D<F]O
M="P@;W(@:G5S="!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!R97%U97-T960@;&5V96P@86YD(&1I<F5C="!P87)E;G1S/PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@($1E9F%U;'1S('1O('-I
M;F=L92!L979E;"X*("`@("`J($!P87)A;2!S=')I;F<@)'-O<G1B>5]N86UE
M("!!='1R:6)U=&4@;F%M92!T;R!U<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1S;W)T8GE?:V5Y("`@071T<FEB=71E(&ME>2!T;R!U
M<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&ER96-T
M:6]N("`@4V]R="!D:7)E8W1I;VXZ"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@,"`M(&%S8V5N9&EN9PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#$@+2!D97-C96YD:6YG"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%-O<G1E9%1R964H)')O;W0L("1L;V%D5')E92`](&9A;'-E
M+"`D<V]R=&)Y7VYA;64@/2!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<V]R=&)Y7VME>2`](&YU;&PL("1D:7)E8W1I;VX@/2`P*0H@("`@
M>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=N;W0@<W5P<&]R
M=&5D)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&%N(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@
M;6EX960@)&]B:F5C="`@("`@("`@5&AE(&]B:F5C="!T;R!A9&0@*'-T<FEN
M9R!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@($1A=&%4
M<F5E3V)J96-T*2X*("`@("`J($!P87)A;2!B;V]L96%N("1I9%]A<U]N86UE
M("!4<G5E(&]R(&9A;'-E('1O(&EN9&EC871E(&EF(&]B:F5C="!)1"!I<R!T
M;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)E('5S960@
M87,@;V)J96-T(&YA;64N(%5S960@:6X@<VET=6%T:6]N<PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('=H97)E('1H97)E(&ES(&YO(&%V
M86EL86)L92!U;FEQ=64@:6YP=70@9F]R"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@;V)J96-T(&YA;64N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%D9"@D;V)J96-T+"`D:61?87-?;F%M92`](&9A;'-E*0H@("`@>PH@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=N;W0@<W5P<&]R=&5D
M)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@86X@;V)J96-T+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@("`D;F%M92`@5&AE('-H;W)T(&]B
M:F5C="!N86UE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@("1I9"`@("!4:&4@
M;F5W(&]B:F5C="=S('5N:7%U92!)1"X*("`@("`J($!P87)A;2!I;G1E9V5R
M("`D<&ED("`@5&AE('5N:7%U92!)1"!O9B!T:&4@;V)J96-T)W,@<&%R96YT
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@("1O<F1E<B!4:&4@;W)D97)I;F<@
M9&%T82!F;W(@=&AE(&]B:F5C="X*("`@("`J"B`@("`@*B!`86-C97-S('!R
M;W1E8W1E9`H@("`@("HO"B`@("!F=6YC=&EO;B!?861D*"1N86UE+"`D:60L
M("1P:60L("1O<F1E<B`]("<G*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9&%T
M85LD:61=(#T@87)R87DH)VYA;64G(#T^("1N86UE+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W!A<F5N="<@/3X@)'!I9"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=O<F1E<B<@/3X@)&]R9&5R
M*3L*("`@("`@("`D=&AI<RT^7VYA;65-87!;)&ED72`]("1N86UE.PH*("`@
M("`@("`O*B!3:&EF="!A;&]N9R!T:&4@;W)D97(@<&]S:71I;VYS+B`J+PH@
M("`@("`@("1T:&ES+3Y?<F5O<F1E<B@D<&ED+"`D;W)D97(L("1I9"D["@H@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M<FEE=F4@9&%T82!F;W(@86X@;V)J96-T(&9R;VT@=&AE(&AO<F1E7V1A=&%T
M<F5E7V%T=')I8G5T97,*("`@("`J('1A8FQE+@H@("`@("H*("`@("`J($!A
M8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R('P@87)R87D@
M)&-I9"`@5&AE(&]B:F5C="!I9"!T;R!F971C:"P*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@;W(@86X@87)R87D@;V8@;V)J96-T(&ED
M<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&AA<V@@;V8@871T
M<FEB=71E<RP@;W(@82!M=6QT:2UL979E;"!H87-H"B`@("`@*B`@("`@("`@
M("`@("`@("!O9B!O8FIE8W0@:61S(#T^('1H96ER(&%T=')I8G5T97,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$%T=')I8G5T97,H)&-I9"D*("`@('L*
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G;F]T('-U<'!O<G1E
M9"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;G5M8F5R
M(&]F(&]B:F5C=',@;6%T8VAI;F<@82!S970@;V8@871T<FEB=71E(&-R:71E
M<FEA+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!S
M964@8G5I;&1!='1R:6)U=&51=65R>2@I"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("`@)&-R:71E<FEA("`@5&AE(&%R<F%Y(&]F(&-R:71E<FEA+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)'!A<F5N="`@("`@5&AE('!A<F5N="!N
M;V1E('1O('-T87)T('-E87)C:&EN9R!F<F]M+@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)&%L;$QE=F5L<R`@4F5T=7)N(&%L;"!L979E;',L(&]R(&IU<W0@
M=&AE(&1I<F5C=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8VAI;&1R96X@;V8@)'!A<F5N=#\@1&5F875L=',@=&\@86QL(&QE=F5L<RX*
M("`@("`J($!P87)A;2!S=')I;F<@("1R97-T<FEC="`@($]N;'D@<F5T=7)N
M(&%T=')I8G5T97,@=VET:"!T:&4@<V%M90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@871T<FEB=71E7VYA;64@;W(@871T<FEB=71E7VED
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;W5N=$)Y071T<FEB=71E<R@D8W)I
M=&5R:6$L("1P87)E;G0@/2!$051!5%)%15]23T]4+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&%L;$QE=F5L<R`]('1R=64L("1R97-T<FEC
M="`]("=N86UE)RD*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G;F]T('-U<'!O<G1E9"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!A('-E="!O9B!O8FIE8W0@:61S(&)A<V5D(&]N(&$@<V5T(&]F
M(&%T=')I8G5T92!C<FET97)I82X*("`@("`J"B`@("`@*B!`86)S=')A8W0*
M("`@("`J"B`@("`@*B!`<V5E(&)U:6QD071T<FEB=71E475E<GDH*0H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`@("1C<FET97)I82`@("`@5&AE(&%R
M<F%Y(&]F(&-R:71E<FEA+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'!A<F5N
M="`@("`@("!4:&4@<&%R96YT(&YO9&4@=&\@<W1A<G0@<V5A<F-H:6YG(&9R
M;VTN"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D86QL3&5V96QS("`@(%)E='5R
M;B!A;&P@;&5V96QS+"!O<B!J=7-T('1H92!D:7)E8W0*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8VAI;&1R96X@;V8@)'!A<F5N=#\@
M1&5F875L=',@=&\@86QL(&QE=F5L<RX*("`@("`J($!P87)A;2!S=')I;F<@
M("1R97-T<FEC="`@("`@3VYL>2!R971U<FX@871T<FEB=71E<R!W:71H('1H
M92!S86UE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%T
M=')I8G5T95]N86UE(&]R(&%T=')I8G5T95]I9"X*("`@("`J($!P87)A;2!I
M;G1E9V5R("1F<F]M("`@("`@("`@5&AE(&]B:F5C="!T;R!S=&%R="!T;R!F
M971C:&EN9PH@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O=6YT("`@("`@("!4
M:&4@;G5M8F5R(&]F(&]B:F5C=',@=&\@9F5T8V@*("`@("`J($!P87)A;2!S
M=')I;F<@("1S;W)T8GE?;F%M92`@071T<FEB=71E(&YA;64@=&\@=7-E(&9O
M<B!S;W)T:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-O<G1B>5]K97D@
M("!!='1R:6)U=&4@:V5Y('1O('5S92!F;W(@<V]R=&EN9RX*("`@("`J($!P
M87)A;2!I;G1E9V5R("1D:7)E8W1I;VX@("`@4V]R="!D:7)E8W1I;VXZ"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,"`M(&%S8V5N
M9&EN9PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$@
M+2!D97-C96YD:6YG"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$)Y071T<FEB
M=71E<R@D8W)I=&5R:6$L("1P87)E;G0@/2!$051!5%)%15]23T]4+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1A;&Q,979E;',@/2!T<G5E+"`D
M<F5S=')I8W0@/2`G;F%M92<L("1F<F]M(#T@,"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D8V]U;G0@/2`P+"`D<V]R=&)Y7VYA;64@/2!N=6QL
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S;W)T8GE?:V5Y(#T@
M;G5L;"P@)&1I<F5C=&EO;B`](#`I"B`@("!["B`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)VYO="!S=7!P;W)T960G*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-O<G1S($E$<R!B>2!A='1R:6)U=&4@=F%L=65S+B!)1',@
M=VET:&]U="!A='1R:6)U=&5S('=I;&P@8F4@861D960@=&\*("`@("`J('1H
M92!E;F0@;V8@=&AE('-O<G1E9"!L:7-T+@H@("`@("H*("`@("`J($!A8G-T
M<F%C=`H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D=6YO<F1E<F5D7VED
M<R`@07)R87D@;V8@:61S('1O('-O<G0N"B`@("`@*B!`<&%R86T@87)R87D@
M)'-O<G1B>5]N86UE("`@($%T=')I8G5T92!N86UE('1O('5S92!F;W(@<V]R
M=&EN9RX*("`@("`J($!P87)A;2!A<G)A>2`D<V]R=&)Y7VME>2`@("`@071T
M<FEB=71E(&ME>2!T;R!U<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@
M87)R87D@)&1I<F5C=&EO;B`@("`@(%-O<G0@9&ER96-T:6]N.@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#`@+2!A<V-E;F1I;F<*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Q("T@9&5S
M8V5N9&EN9PH@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%-O<G1E9"!I
M9',N"B`@("`@*B\*("`@(&9U;F-T:6]N('-O<G1">4%T=')I8G5T97,H)'5N
M;W)D97)E9%]I9',L("1S;W)T8GE?;F%M92`](&YU;&PL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1S;W)T8GE?:V5Y(#T@;G5L;"P@)&1I<F5C
M=&EO;B`](#`I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)VYO="!S=7!P;W)T960G*3L*("`@('T*"B`@("`O*BH*("`@("`J(%5P
M9&%T92!T:&4@9&%T82!I;B!A;B!O8FIE8W0N($1O97,@;F]T(&-H86YG92!T
M:&4@;V)J96-T)W,*("`@("`J('!A<F5N="!O<B!N86UE+"!J=7-T('-E<FEA
M;&EZ960@9&%T82!O<B!A='1R:6)U=&5S+@H@("`@("H*("`@("`J($!A8G-T
M<F%C=`H@("`@("H*("`@("`J($!P87)A;2!$871A5')E92`D;V)J96-T("!!
M($1A=&%4<F5E(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@=7!D871E
M1&%T82@D;V)J96-T*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*"=N;W0@<W5P<&]R=&5D)RD["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3;W)T('1W;R!O8FIE8W1S(&)Y('1H96ER(&]R9&5R(&9I96QD+"!A;F0@
M:68@=&AA="!I<R!T:&4@<V%M92P*("`@("`J(&%L<&AA8F5T:6-A;&QY("AC
M87-E(&EN<V5N<VET:79E*2!B>2!N86UE+@H@("`@("H*("`@("`J(%EO=2!N
M979E<B!C86QL('1H:7,@9G5N8W1I;VX[(&ET)W,@=7-E9"!I;B!U87-O<G0H
M*2!C86QL<RX@1&\*("`@("`J($Y/5"!U<V4@=7-O<G0H*3L@>6]U)VQL(&QO
M<V4@:V5Y(#T^('9A;'5E(&%S<V]C:6%T:6]N<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)&$@(%1H92!F:7)S="!O8FIE8W0*("`@("`J($!P87)A
M;2!A<G)A>2`D8B`@5&AE('-E8V]N9"!O8FIE8W0*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&EN=&5G97(@(#$@:68@)&$@<VAO=6QD(&)E(&9I<G-T+`H@("`@
M("H@("`@("`@("`@("`@("`@("TQ(&EF("1B('-H;W5L9"!B92!F:7)S="P*
M("`@("`J("`@("`@("`@("`@("`@("`@,"!I9B!T:&5Y(&%R92!E;G1I<F5L
M>2!E<75A;"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-M<"@D82P@)&(I"B`@
M("!["B`@("`@("`@:68@*"1A6R=O<F1E<B==(#X@)&);)V]R9&5R)UTI('L*
M("`@("`@("`@("`@<F5T=7)N(#$["B`@("`@("`@?2!E;'-E:68@*"1A6R=O
M<F1E<B==(#P@)&);)V]R9&5R)UTI('L*("`@("`@("`@("`@<F5T=7)N("TQ
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!S=')C87-E
M8VUP*"1A6R=N86UE)UTL("1B6R=N86UE)UTI.PH@("`@("`@('T*("`@('T*
M"B`@("`@+RHJ"B`@("`@*B!3;W)T<R!T=V\@;V)J96-T<R!B>2!T:&5I<B!S
M;W)T97(@:&%S:"!F:65L9"X*("`@("`J"B`@("`@*B!9;W4@;F5V97(@8V%L
M;"!T:&ES(&9U;F-T:6]N.R!I="=S('5S960@:6X@=6%S;W)T*"D@8V%L;',N
M($1O($Y/5"!U<V4*("`@("`J('5S;W)T*"D[('EO=2=L;"!L;W-E(&ME>2`]
M/B!V86QU92!A<W-O8VEA=&EO;G,N"B`@("`@*@H@("`@("H@0'-I;F-E($AO
M<F1E(#,N,0H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D82`@5&AE(&9I
M<G-T(&]B:F5C=`H@("`@("H@0'!A<F%M(&%R<F%Y("1B("!4:&4@<V5C;VYD
M(&]B:F5C=`H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@,2!I9B`D
M82!S:&]U;&0@8F4@9FER<W0L"B`@("`@*B`@("`@("`@("`@("`@("`@+3$@
M:68@)&(@<VAO=6QD(&)E(&9I<G-T+`H@("`@("H@("`@("`@("`@("`@("`@
M("`P(&EF('1H97D@87)E(&5N=&ER96QY(&5Q=6%L+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?8VUP4V]R=&5D*"1A+"`D8BD*("`@('L*("`@("`@("!I9B`H
M)&%;)W-O<G1E<B==6R1T:&ES+3Y?<V]R=$AA<VA=(#P@)&);)W-O<G1E<B==
M6R1T:&ES+3Y?<V]R=$AA<VA=*2!["B`@("`@("`@("`@(')E='5R;B`Q.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A
M(&-O;F-R971E($1A=&%4<F5E(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D<FEV97(@(%1H92!T>7!E
M(&]F(&-O;F-R971E($1A=&%4<F5E('-U8F-L87-S('1O(')E='5R;BX*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!4:&ES(&ES(&)A<V5D(&]N('1H
M92!S=&]R86=E(&1R:79E<B`H)&1R:79E<BDN(%1H90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@(&-O9&4@:7,@9'EN86UI8V%L;'D@:6YC;'5D960N
M($EF("1D<FEV97(@:7,@86X@87)R87DL"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@=&AE;B!W92!W:6QL(&QO;VL@:6X@)&1R:79E<ELP72]L:6(O
M1&%T851R964O(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('1H
M92!S=6)C;&%S<R!I;7!L96UE;G1A=&EO;B!N86UE9"`D9')I=F5R6S%=+G!H
M<"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I
M;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S(&$@
M<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!(97)E+"!W92!N965D("=G<F]U<"<@/2!A('-T<FEN9R!T:&%T(&1E
M9FEN97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T;W`M;&5V96P@
M9W)O=7!S(&]F(&]B:F5C=',N"B`@("`@*@H@("`@("H@0')E='5R;B!$871A
M5')E92`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@1&%T851R964@:6YS
M=&%N8V4L(&]R(&9A;'-E"B`@("`@*B`@("`@("`@("`@("`@("`@("!O;B!A
M;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)&1R:79E
M<BP@)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@)&1R:79E<B`](&)A
M<V5N86UE*"1D<FEV97(I.PH*("`@("`@("!I9B`H:7-?;G5L;"@D<&%R86US
M*2D@>PH@("`@("`@("`@("`D<&%R86US(#T@2&]R9&4Z.F=E=$1R:79E<D-O
M;F9I9R@G9&%T871R964G+"`D9')I=F5R*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("AE;7!T>2@D9')I=F5R*2D@>PH@("`@("`@("`@("`D9')I=F5R(#T@
M)VYU;&PG.PH@("`@("`@('T*"B`@("`@("`@:6YC;'5D95]O;F-E("=(;W)D
M92]$871A5')E92\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("`D8VQA
M<W,@/2`G1&%T851R965?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L87-S
M7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1D="`]("9N97<@)&-L
M87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1D
M="`](%!%05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I;VX@;V8@)R`N
M("1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*(`H@("`@("`@
M(')E='5R;B`D9'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T
M;R!R971U<FX@82!R969E<F5N8V4@=&\@82!C;VYC<F5T92!$871A5')E92!I
M;G-T86YC92!B87-E9"!O;@H@("`@("H@)&1R:79E<BX*("`@("`J"B`@("`@
M*B!)="!W:6QL(&]N;'D@8W)E871E(&$@;F5W(&EN<W1A;F-E(&EF(&YO($1A
M=&%4<F5E(&EN<W1A;F-E('=I=&@@=&AE('-A;64*("`@("`J('!A<F%M971E
M<G,@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES('-H;W5L
M9"!B92!U<V5D(&EF(&UU;'1I<&QE($1A=&%4<F5E('-O=7)C97,@*&%N9"P@
M=&AU<RP@;75L=&EP;&4*("`@("`J($1A=&%4<F5E(&EN<W1A;F-E<RD@87)E
M(')E<75I<F5D+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@
M:6YV;VME9"!A<SH@)'9A<B`]("9$871A5')E93HZ<VEN9VQE=&]N*"D["B`@
M("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D<FEV97(@(%1Y<&4@;V8@8V]N
M8W)E=&4@1&%T851R964@<W5B8VQA<W,@=&\@<F5T=7)N+`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(&)A<V5D(&]N('-T;W)A9V4@9')I=F5R("@D
M9')I=F5R*2X@5&AE(&-O9&4@:7,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!D>6YA;6EC86QL>2!I;F-L=61E9"X@268@)&1R:79E<B!I<R!A;B!A
M<G)A>2P@=&AE;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&QO;VL@
M:6X@)&1R:79E<ELP72]L:6(O1&%T851R964O(&9O<B!S=6)C;&%S<PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@(&EM<&QE;65N=&%T:6]N(&YA;65D
M("1D<FEV97);,5TN<&AP+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@
M($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I
M;VX@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T:6]N
M('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@
M("`J($!R971U<FX@1&%T851R964@(%1H92!C;VYC<F5T92!$871A5')E92!R
M969E<F5N8V4L(&]R(&9A;'-E(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(L("1P87)A;7,@/2!N=6QL*0H@
M("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N8V5S.PH@("`@("`@(&EF("@A
M:7-S970H)&EN<W1A;F-E<RDI('L*("`@("`@("`@("`@)&EN<W1A;F-E<R`]
M(&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?;G5L;"@D<&%R
M86US*2D@>PH@("`@("`@("`@("`D<&%R86US(#T@2&]R9&4Z.F=E=$1R:79E
M<D-O;F9I9R@G9&%T871R964G+"`D9')I=F5R*3L*("`@("`@("!]"@H@("`@
M("`@("1S:6=N871U<F4@/2!S97)I86QI>F4H87)R87DH)&1R:79E<BP@)'!A
M<F%M<RDI.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<ULD<VEG;F%T
M=7)E72DI('L*("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`]
M("9$871A5')E93HZ9F%C=&]R>2@D9')I=F5R+"`D<&%R86US*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@
M("`@?0H*?0H*+RHJ"B`J($-L87-S('1H870@8V%N(&)E(&5X=&5N9&5D('1O
M('-A=F4@87)B:71R87)Y(&EN9F]R;6%T:6]N(&%S('!A<G0@;V8@82!S=&]R
M960*("H@;V)J96-T+@H@*@H@*B!`875T:&]R("!3=&5P:&%N92!(=71H97(@
M/'-H=71H97)`8FEG9F]O="YC;VT^"B`J($!A=71H;W(@($-H=6-K($AA9V5N
M8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`R+C$*
M("H@0'!A8VMA9V4@2&]R9&5?1&%T851R964*("HO"F-L87-S($1A=&%4<F5E
M3V)J96-T('L*"B`@("`O*BH*("`@("`J(%1H:7,@;V)J96-T)W,@1&%T851R
M964@:6YS=&%N8V4N"B`@("`@*@H@("`@("H@0'9A<B!$871A5')E90H@("`@
M("HO"B`@("!V87(@)&1A=&%T<F5E.PH*("`@("\J*@H@("`@("H@2V5Y+79A
M;'5E(&AA<V@@=&AA="!W:6QL(&)E('-E<FEA;&EZ960N"B`@("`@*@H@("`@
M("H@0'-E92!G971$871A*"D*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1D871A(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!U
M;FEQ=64@;F%M92!O9B!T:&ES(&]B:F5C="X*("`@("`J(%1H97-E(&YA;65S
M(&AA=F4@=&AE('-A;64@<F5Q=6ER96UE;G1S(&%S(&]T:&5R(&]B:F5C="!N
M86UE<R`M('1H97D@;75S=`H@("`@("H@8F4@=6YI<75E+"!E=&,N"B`@("`@
M*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1N86UE.PH*
M("`@("\J*@H@("`@("H@268@=&AI<R!O8FIE8W0@:&%S(&]R9&5R:6YG(&1A
M=&$L('-T;W)E(&ET(&AE<F4N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R
M"B`@("`@*B\*("`@('9A<B`D;W)D97(@/2!N=6QL.PH*("`@("\J*@H@("`@
M("H@1&%T851R965/8FIE8W0@8V]N<W1R=6-T;W(N"B`@("`@*B!*=7-T('-E
M=',@=&AE("1N86UE('!A<F%M971E<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N86UE("!4:&4@;V)J96-T(&YA;64N"B`@("`@*B\*("`@(&9U
M;F-T:6]N($1A=&%4<F5E3V)J96-T*"1N86UE*0H@("`@>PH@("`@("`@("1T
M:&ES+3YS971.86UE*"1N86UE*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E
M=',@=&AE('M`;&EN:R!$871A5')E97T@:6YS=&%N8V4@=7-E9"!T;R!R971R
M:65V92!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@1&%T851R
M964@)&1A=&%T<F5E("!!('M`;&EN:R!$871A5')E97T@:6YS=&%N8V4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E=$1A=&%4<F5E*"8D9&%T871R964I"B`@
M("!["B`@("`@("`@)'1H:7,M/F1A=&%T<F5E(#T@)B1D871A=')E93L*("`@
M('T*"B`@("`O*BH*("`@("`J($=E=',@=&AE(&YA;64@;V8@=&AI<R!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@5&AE(&]B:F5C="!N
M86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971.86UE*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/FYA;64["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3971S('1H92!N86UE(&]F('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J
M($Y/5$4Z(%5S92!W:71H(&-A=71I;VXN(%1H:7,@;6%Y('1H<F]W(&]U="!O
M9B!S>6YC('1H92!C86-H960@9&%T871R964*("`@("`J('1A8FQE<R!I9B!N
M;W0@=7-E9"!P<F]P97)L>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("!4:&4@;F%M92!T;R!S970@=&AI<R!O8FIE8W0G<R!N86UE('1O
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971.86UE*"1N86UE*0H@("`@>PH@
M("`@("`@("1T:&ES+3YN86UE(#T@)&YA;64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!'971S('1H92!S:&]R="!N86UE(&]F('1H:7,@;V)J96-T+@H@("`@
M("H@1F]R(&1I<W!L87D@<'5R<&]S97,@;VYL>2X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&]B:F5C="=S('-H;W)T(&YA;64N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%-H;W)T3F%M92@I"B`@("!["B`@("`@("`@
M<F5T=7)N($1A=&%4<F5E.CIG9713:&]R=$YA;64H)'1H:7,M/FYA;64I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@240@;V8@=&AI<R!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!O8FIE8W0G
M<R!)1"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T260H*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^9&%T871R964M/F=E=$ED*"1T:&ES*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($=E=',@=&AE(&1A=&$@87)R87DN"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&EN=&5R;F%L(&1A=&$@87)R
M87DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1A=&$H*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E=',@=&AE(&1A=&$@87)R87DN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("!4:&4@9&%T82!A<G)A>2!T;R!S=&]R92!I;G1E<FYA;&QY+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S971$871A*"1D871A*0H@("`@>PH@("`@("`@
M("1T:&ES+3YD871A(#T@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M971S('1H92!O<F1E<B!O9B!T:&ES(&]B:F5C="!I;B!I=',@;V)J96-T(&-O
M;&QE8W1I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&]R9&5R
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$]R9&5R*"1O<F1E<BD*("`@('L*
M("`@("`@("`D=&AI<RT^;W)D97(@/2`D;W)D97(["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H:7,@;V)J96-T)W,@<&%R96YT+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&-L87-S("`@4W5B8VQA<W,@;V8@1&%T
M851R965/8FIE8W0@=&\@=7-E+B!$969A=6QT<R!T;PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("!$871A5')E94]B:F5C="X@3G5L;"!F;W)C97,@
M=&AE(&1R:79E<B!T;R!L;V]K"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@(&EN=&\@=&AE(&%T=')I8G5T97,@=&%B;&4@=&\@9&5T97)M:6YE('1H
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!S=6)C;&%S<R!T;R!U
M<V4N($EF(&YO;F4@:7,@9F]U;F0@:70@=7-E<PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("!$871A5')E94]B:F5C="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N($1A=&%4<F5E3V)J96-T("!4:&ES(&]B:F5C="=S('!A<F5N=`H@
M("`@("HO"B`@("!F=6YC=&EO;B`F9V5T4&%R96YT*"1C;&%S<R`]("=$871A
M5')E94]B:F5C="<I"B`@("!["B`@("`@("`@)&ED(#T@)'1H:7,M/F1A=&%T
M<F5E+3YG971087)E;G0H)'1H:7,I.PH@("`@("`@(&EF("AI<U]A*"1I9"P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&ED.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/F1A=&%T<F5E+3YG971/8FIE
M8W1">4ED*"1I9"P@)&-L87-S*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@82!C:&EL9"!O9B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE("`@("`@("`@5&AE(&-H:6QD)W,@;F%M92X*
M("`@("`J($!P87)A;2!B;V]L96%N("1A=71O8W)E871E("!)9B!T<G5E(&%N
M9"!N;R!C:&EL9"!W:71H('1H92!G:79E;B!N86UE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@97AI<W1S+"!O;F4@9V5T<R!C<F5A=&5D
M+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T0VAI;&0H)&YA;64L("1A=71O
M8W)E871E(#T@=')U92D*("`@('L*("`@("`@("`D;F%M92`]("1T:&ES+3YG
M9713:&]R=$YA;64H*2`N("<Z)R`N("1N86UE.PH*("`@("`@("`O*B!)9B!T
M:&4@8VAI;&0@<VAO=6QD;B=T(&=E="!C<F5A=&5D+"!W92!D;VXG="!C:&5C
M:R!F;W(@:71S"B`@("`@("`@("H@97AI<W1A;F-E('1O(')E='5R;B!T:&4@
M(FYO="!F;W5N9"(@97)R;W(@;V8*("`@("`@("`@*B!G971/8FIE8W0H*2X@
M*B\*("`@("`@("!I9B`H(21A=71O8W)E871E('Q\("1T:&ES+3YD871A=')E
M92T^97AI<W1S*"1N86UE*2D@>PH@("`@("`@("`@("`D8VAI;&0@/2`F)'1H
M:7,M/F1A=&%T<F5E+3YG971/8FIE8W0H)&YA;64I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1C:&EL9"`]("9N97<@1&%T851R965/8FIE8W0H
M)&YA;64I.PH@("`@("`@("`@("`D8VAI;&0M/G-E=$1A=&%4<F5E*"1T:&ES
M+3YD871A=')E92D["B`@("`@("`@("`@("1T:&ES+3YD871A=')E92T^861D
M*"1C:&EL9"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-H:6QD.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V%V97,@86YY(&-H86YG97,@=&\@=&AI
M<R!O8FIE8W0@=&\@=&AE(&)A8VME;F0@<&5R;6%N96YT;'DN($YE=R!O8FIE
M8W1S"B`@("`@*B!A<F4@861D960@:6YS=&5A9"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86Y\4$5!4E]%<G)O<B`@4$5!4E]%<G)O<B!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S879E*"D*("`@('L*("`@("`@
M("!I9B`H)'1H:7,M/F1A=&%T<F5E+3YE>&ES=',H)'1H:7,I*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^9&%T871R964M/G5P9&%T941A=&$H)'1H
M:7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^9&%T871R964M/F%D9"@D=&AI<RD["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@1&5L971E('1H:7,@;V)J96-T(&9R;VT@=&AE(&)A8VME
M;F0@<&5R;6%N96YT;'DN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M?%!%05)?17)R;W(@(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9&5L971E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/F1A=&%T<F5E+3YR96UO=F4H)'1H:7,I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T<R!O;F4@;V8@=&AE(&%T=')I8G5T97,@;V8@=&AE(&]B:F5C
M="P@;W(@;G5L;"!I9B!I="!I<VXG="!D969I;F5D+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&%T=')I8G5T92`@5&AE(&%T=')I8G5T92!T;R!G
M970N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE('9A;'5E(&]F
M('1H92!A='1R:6)U=&4L(&]R(&YU;&PN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E="@D871T<FEB=71E*0H@("`@>PH@("`@("`@(')E='5R;B!I<W-E="@D
M=&AI<RT^9&%T85LD871T<FEB=71E72D*("`@("`@("`@("`@/R`D=&AI<RT^
M9&%T85LD871T<FEB=71E70H@("`@("`@("`@("`Z(&YU;&P["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!3971S(&]N92!O9B!T:&4@871T<FEB=71E<R!O9B!T
M:&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%T=')I
M8G5T92`@5&AE(&%T=')I8G5T92!T;R!S970N"B`@("`@*B!`<&%R86T@;6EX
M960@)'9A;'5E("`@("`@(%1H92!V86QU92!F;W(@)&%T=')I8G5T92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T*"1A='1R:6)U=&4L("1V86QU92D*("`@
M('L*("`@("`@("`D=&AI<RT^9&%T85LD871T<FEB=71E72`]("1V86QU93L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&4N<&AP````````````````
M```````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S,S4S,P`Q,#4Q-30S,S<U
M,0`P,C$P-C``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"F1E9FEN92@G2$]21$5?1$%415]354Y$05DG+"`@("`P
M*3L*9&5F:6YE*"=(3U)$15]$051%7TU/3D1!62<L("`@(#$I.PID969I;F4H
M)TA/4D1%7T1!5$5?5%5%4T1!62<L("`@,BD["F1E9FEN92@G2$]21$5?1$%4
M15]7141.15-$05DG+"`S*3L*9&5F:6YE*"=(3U)$15]$051%7U1(55)31$%9
M)RP@(#0I.PID969I;F4H)TA/4D1%7T1!5$5?1E))1$%9)RP@("`@-2D["F1E
M9FEN92@G2$]21$5?1$%415]305154D1!62<L("`V*3L*"F1E9FEN92@G2$]2
M1$5?1$%415]-05-+7U-53D1!62<L("`@(#$I.PID969I;F4H)TA/4D1%7T1!
M5$5?34%32U]-3TY$05DG+"`@("`R*3L*9&5F:6YE*"=(3U)$15]$051%7TU!
M4TM?5%5%4T1!62<L("`@-"D["F1E9FEN92@G2$]21$5?1$%415]-05-+7U=%
M1$Y%4T1!62<L(#@I.PID969I;F4H)TA/4D1%7T1!5$5?34%32U]42%524T1!
M62<L(#$V*3L*9&5F:6YE*"=(3U)$15]$051%7TU!4TM?1E))1$%9)RP@("`S
M,BD["F1E9FEN92@G2$]21$5?1$%415]-05-+7U-!5%521$%9)RP@-C0I.PID
M969I;F4H)TA/4D1%7T1!5$5?34%32U]7145+1$%94R<L(#8R*3L*9&5F:6YE
M*"=(3U)$15]$051%7TU!4TM?5T5%2T5.1"<L("`V-2D["F1E9FEN92@G2$]2
M1$5?1$%415]-05-+7T%,3$1!65,G+"`Q,C<I.PH*9&5F:6YE*"=(3U)$15]$
M051%7TU!4TM?4T5#3TY$)RP@("`@,2D["F1E9FEN92@G2$]21$5?1$%415]-
M05-+7TU)3E5412<L("`@(#(I.PID969I;F4H)TA/4D1%7T1!5$5?34%32U](
M3U52)RP@("`@("`T*3L*9&5F:6YE*"=(3U)$15]$051%7TU!4TM?1$%9)RP@
M("`@("`@."D["F1E9FEN92@G2$]21$5?1$%415]-05-+7TU/3E1()RP@("`@
M,38I.PID969I;F4H)TA/4D1%7T1!5$5?34%32U]914%2)RP@("`@(#,R*3L*
M9&5F:6YE*"=(3U)$15]$051%7TU!4TM?04Q,4$%25%,G+"`V,RD["@HO*BH*
M("H@2&]R9&4@1&%T92!W<F%P<&5R+VQO9VEC(&-L87-S+"!I;F-L=61I;F<@
M<V]M92!C86QC=6QA=&EO;@H@*B!F=6YC=&EO;G,N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+T1A=&4O1&%T92YP:'`L=B`Q+C@N,3`N-R`R,#`V+S`U+S`T
M(#`S.C0R.C,R('-E;'-K>2!%>'`@)`H@*@H@*B!`<&%C:V%G92!(;W)D95]$
M871E"B`J+PIC;&%S<R!(;W)D95]$871E('L*"B`@("`O*BH*("`@("`J(%EE
M87(*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R
M("1Y96%R.PH*("`@("\J*@H@("`@("H@36]N=&@*("`@("`J"B`@("`@*B!`
M=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1M;VYT:#L*"B`@("`O*BH*
M("`@("`J($1A>0H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO
M"B`@("!V87(@)&UD87D["@H@("`@+RHJ"B`@("`@*B!(;W5R"B`@("`@*@H@
M("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D:&]U<B`](#`[
M"@H@("`@+RHJ"B`@("`@*B!-:6YU=&4*("`@("`J"B`@("`@*B!`=F%R(&EN
M=&5G97(*("`@("`J+PH@("`@=F%R("1M:6X@/2`P.PH*("`@("\J*@H@("`@
M("H@4V5C;VYD"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*
M("`@('9A<B`D<V5C(#T@,#L*"B`@("`O*BH*("`@("`J($)U:6QD(&$@;F5W
M(&1A=&4@;V)J96-T+B!)9B`D9&%T92!C;VYT86EN<R!D871E('!A<G1S+"!U
M<V4@=&AE;0H@("`@("H@=&\@:6YI=&EA;&EZ92!T:&4@;V)J96-T+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!(;W)D95]$871E*"1D871E(#T@;G5L;"D*("`@
M('L*("`@("`@("!I9B`H:7-?87)R87DH)&1A=&4I('Q\(&ES7V]B:F5C="@D
M9&%T92DI('L*("`@("`@("`@("`@9F]R96%C:"`H)&1A=&4@87,@)&ME>2`]
M/B`D=F%L*2!["B`@("`@("`@("`@("`@("!I9B`H:6Y?87)R87DH)&ME>2P@
M87)R87DH)WEE87(G+"`G;6]N=&@G+"`G;61A>2<L("=H;W5R)RP@)VUI;B<L
M("=S96,G*2DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^)&ME>2`]
M("AI;G0I)'9A;#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS96EF("@A:7-?;G5L;"@D9&%T92DI('L*("`@("`@("`@
M("`@+R\@36%T8V@@65E962U-32U$1"!(2#I-33I34R!A;F0@65E964U-1$1(
M2$U-4U,N"B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O*%QD>S1]*2T_
M*%QD>S)]*2T_*%QD>S)]*2`_*%QD>S)]*3H_*%QD>S)]*3H_*%QD>S)]*2\G
M+"`D9&%T92P@)'!A<G1S*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/GEE
M87(@/2`H:6YT*21P87)T<ULQ73L*("`@("`@("`@("`@("`@("1T:&ES+3YM
M;VYT:"`]("AI;G0I)'!A<G1S6S)=.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/FUD87D@/2`H:6YT*21P87)T<ULS73L*("`@("`@("`@("`@("`@("1T:&ES
M+3YH;W5R(#T@*&EN="DD<&%R='-;-%T["B`@("`@("`@("`@("`@("`D=&AI
M<RT^;6EN(#T@*&EN="DD<&%R='-;-5T["B`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5C(#T@*&EN="DD<&%R='-;-ET["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`O+R!4<GD@87,@82!T:6UE<W1A;7`N"B`@("`@
M("`@("`@("`@("`D<&%R=',@/2!`9V5T9&%T92@D9&%T92D["B`@("`@("`@
M("`@("`@("!I9B`H)'!A<G1S*2!["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/GEE87(@/2`D<&%R='-;)WEE87(G73L*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^;6]N=&@@/2`D<&%R='-;)VUO;B==.PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YM9&%Y(#T@)'!A<G1S6R=M9&%Y)UT["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/FAO=7(@/2`D<&%R='-;)VAO=7)S)UT["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/FUI;B`]("1P87)T<ULG;6EN=71E
M<R==.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS96,@/2`D<&%R='-;
M)W-E8V]N9',G73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@=6YI
M>"!T:6UE<W1A;7`@<F5P<F5S96YT871I;VX@;V8@=&AI<R!D871E+@H@("`@
M("H*("`@("`J($!R971U<FX@:6YT96=E<B`@02!U;FEX('1I;65S=&%M<"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@=&EM97-T86UP*"D*("`@('L*("`@("`@
M("!R971U<FX@0&UK=&EM92@D=&AI<RT^:&]U<BP@)'1H:7,M/FUI;BP@)'1H
M:7,M/G-E8RP@)'1H:7,M/FUO;G1H+"`D=&AI<RT^;61A>2P@)'1H:7,M/GEE
M87(I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!U;FEX('1I
M;65S=&%M<"!R97!R97-E;G1A=&EO;B!O9B!T:&ES(&1A=&4L(#$R.C`P86TN
M"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!!('5N:7@@=&EM97-T
M86UP+@H@("`@("HO"B`@("!F=6YC=&EO;B!D871E<W1A;7`H*0H@("`@>PH@
M("`@("`@(')E='5R;B!`;6MT:6UE*#`L(#`L(#`L("1T:&ES+3YM;VYT:"P@
M)'1H:7,M/FUD87DL("1T:&ES+3YY96%R*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@:7-,96%P665A<B@D
M>65A<BD*("`@('L*("`@("`@("!I9B`H<W1R;&5N*"1Y96%R*2`A/2`T('Q\
M('!R96=?;6%T8V@H)R]<1"\G+"`D>65A<BDI('L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("@H)'EE87(@
M)2`T(#T](#`@)B8@)'EE87(@)2`Q,#`@(3T@,"D@?'P@)'EE87(@)2`T,#`@
M/3T@,"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!D87D@
M;V8@=&AE('EE87(@*#$M,S8V*2!T:&%T(&-O<G)E<W!O;F1S('1O('1H90H@
M("`@("H@9FER<W0@9&%Y(&]F('1H92!G:79E;B!W965K+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1W965K("!4:&4@=V5E:R!O9B!T:&4@>65A
M<B!T;R!F:6YD('1H92!F:7)S="!D87D@;V8N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D>65A<B`@5&AE('EE87(@=&\@8V%L8W5L871E(&9O<BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!D87D@;V8@=&AE('EE87(@
M;V8@=&AE(&9I<G-T(&1A>2!O9B!T:&4@9VEV96X@=V5E:RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@9FER<W1$87E/9E=E96LH)'=E96LL("1Y96%R*0H@("`@
M>PH@("`@("`@("1J86XQ(#T@)FYE=R!(;W)D95]$871E*&%R<F%Y*"=Y96%R
M)R`]/B`D>65A<BP@)VUO;G1H)R`]/B`Q+"`G;61A>2<@/3X@,2DI.PH@("`@
M("`@("1S=&%R="`]("1J86XQ+3YD87E/9E=E96LH*3L*("`@("`@("!I9B`H
M)'-T87)T(#X@2$]21$5?1$%415]42%524T1!62D@>PH@("`@("`@("`@("`D
M<W1A<G0@+3T@-SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("@H)'=E96L@
M*B`W*2`M("@W("L@)'-T87)T*2D@*R`Q.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!D87ES26Y-;VYT:"@D
M;6]N=&@L("1Y96%R*0H@("`@>PH@("`@("`@(&EF("@D;6]N=&@@/3T@,BD@
M>PH@("`@("`@("`@("!I9B`H2&]R9&5?1&%T93HZ:7-,96%P665A<B@D>65A
M<BDI('L*("`@("`@("`@("`@("`@(')E='5R;B`R.3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B`R.#L*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS96EF("@D;6]N=&@@/3T@-"!\?"`D;6]N=&@@
M/3T@-B!\?"`D;6]N=&@@/3T@.2!\?"`D;6]N=&@@/3T@,3$I('L*("`@("`@
M("`@("`@<F5T=7)N(#,P.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E='5R;B`S,3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FX@=&AE(&1A>2!O9B!T:&4@=V5E:R`H,"`](%-U;F1A>2P@-B`](%-A
M='5R9&%Y*2!O9B!T:&ES"B`@("`@*B!O8FIE8W0G<R!D871E+@H@("`@("H*
M("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&1A>2!O9B!T:&4@=V5E:RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@9&%Y3V97965K*"D*("`@('L*("`@("`@
M("!I9B`H)'1H:7,M/FUO;G1H(#X@,BD@>PH@("`@("`@("`@("`D;6]N=&@@
M/2`D=&AI<RT^;6]N=&@@+2`R.PH@("`@("`@("`@("`D>65A<B`]("1T:&ES
M+3YY96%R.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1M;VYT:"`]
M("1T:&ES+3YM;VYT:"`K(#$P.PH@("`@("`@("`@("`D>65A<B`]("1T:&ES
M+3YY96%R("T@,3L*("`@("`@("!]"@H@("`@("`@("1D87D@/2`H9FQO;W(H
M*#$S("H@)&UO;G1H("T@,2D@+R`U*2`K"B`@("`@("`@("`@("`@("`D=&AI
M<RT^;61A>2`K("@D>65A<B`E(#$P,"D@*PH@("`@("`@("`@("`@("`@9FQO
M;W(H*"1Y96%R("4@,3`P*2`O(#0I("L*("`@("`@("`@("`@("`@(&9L;V]R
M*"@D>65A<B`O(#$P,"D@+R`T*2`M(#(@*@H@("`@("`@("`@("`@("`@9FQO
M;W(H)'EE87(@+R`Q,#`I("L@-S<I.PH*("`@("`@("!R971U<FX@*&EN="DH
M)&1A>2`M(#<@*B!F;&]O<B@D9&%Y("\@-RDI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@9&%Y(&YU;6)E<B!O9B!T:&4@>65A<B`H,"!T
M;R`S-C4O,S8V*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H
M92!D87D@;V8@=&AE('EE87(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1A>4]F
M665A<B@I"B`@("!["B`@("`@("`@)&UO;G1H5&]T86QS(#T@87)R87DH,"P@
M,S$L(#4Y+"`Y,"P@,3(P+"`Q-3$L(#$X,2P@,C$R+"`R-#,L(#(W,RP@,S`T
M+"`S,S0I.PH@("`@("`@("1D87E/9EEE87(@/2`D=&AI<RT^;61A>2`K("1M
M;VYT:%1O=&%L<ULD=&AI<RT^;6]N=&@@+2`Q73L*("`@("`@("!I9B`H2&]R
M9&5?1&%T93HZ:7-,96%P665A<B@D=&AI<RT^>65A<BD@)B8@)'1H:7,M/FUO
M;G1H(#X@,BD@>PH@("`@("`@("`@("`D9&%Y3V9996%R*RL["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&1A>4]F665A<CL*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=V5E:R!O9B!T:&4@>65A<BP@9FER<W0@36]N9&%Y
M(&ES(&9I<G-T(&1A>2!O9B!F:7)S=`H@("`@("H@=V5E:RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!W965K(&YU;6)E<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@=V5E:T]F665A<B@I"B`@("!["B`@("`@("`@<F5T
M=7)N(&1A=&4H)U<G+"`D=&AI<RT^=&EM97-T86UP*"DI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N('1H92!N=6UB97(@;V8@=V5E:W,@:6X@=&AE
M(&=I=F5N('EE87(@*#4R(&]R(#4S*2X*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D>65A<B`@5&AE('EE87(@=&\@8V]U;G0@=&AE(&YU;6)E<B!O
M9B!W965K<R!I;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@)&YU
M;5=E96MS("`@("`@5&AE(&YU;6)E<B!O9B!W965K<R!I;B`D>65A<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@=V5E:W-);EEE87(H)'EE87(I"B`@("!["B`@
M("`@("`@+R\@1FEN9"!T:&4@;&%S="!4:'5R<V1A>2!O9B!T:&4@>65A<BX*
M("`@("`@("`D9&%Y(#T@,S$["B`@("`@("`@=VAI;&4@*&1A=&4H)W<G+"!M
M:W1I;64H,"P@,"P@,"P@,3(L("1D87DL("1Y96%R*2D@(3T@2$]21$5?1$%4
M15]42%524T1!62D@>PH@("`@("`@("`@("`D9&%Y+2T["B`@("`@("`@?0H*
M("`@("`@("`D9&%T92`]("9N97<@2&]R9&5?1&%T92AA<G)A>2@G>65A<B<@
M/3X@)'EE87(L("=M;VYT:"<@/3X@,3(L("=M9&%Y)R`]/B`D9&%Y*2D["B`@
M("`@("`@<F5T=7)N("1D871E+3YW965K3V9996%R*"D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!3970@=&AE(&1A=&4@;V8@=&AI<R!O8FIE8W0@=&\@=&AE
M("1N=&@@=V5E:V1A>2!O9B`D=V5E:V1A>2X*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D=V5E:V1A>2`@5&AE(&1A>2!O9B!T:&4@=V5E:R`H,"`]
M(%-U;F1A>2P@971C*2X*("`@("`J($!P87)A;2!I;G1E9V5R("1N=&@@("`@
M("!4:&4@)&YT:"`D=V5E:V1A>2!T;R!S970@=&\@*&1E9F%U;'1S('1O(#$I
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971.=&A7965K9&%Y*"1W965K9&%Y
M+"`D;G1H(#T@,2D*("`@('L*("`@("`@("!I9B`H)'=E96MD87D@/"!(3U)$
M15]$051%7U-53D1!62!\?"`D=V5E:V1A>2`^($A/4D1%7T1!5$5?4T%455)$
M05DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/FUD87D@/2`Q.PH@("`@("`@("1F:7)S="`]("1T:&ES
M+3YD87E/9E=E96LH*3L*("`@("`@("!I9B`H)'=E96MD87D@/"`D9FER<W0I
M('L*("`@("`@("`@("`@)'1H:7,M/FUD87D@/2`X("L@)'=E96MD87D@+2`D
M9FER<W0["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/FUD
M87D@/2`D=V5E:V1A>2`M("1F:7)S="`K(#$["B`@("`@("`@?0H@("`@("`@
M("1T:&ES+3YM9&%Y("L](#<@*B`D;G1H("T@-SL*"B`@("`@("`@)'1H:7,M
M/F-O<G)E8W0H*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M9G5N8W1I;VX@9'5M<"@D<')E9FEX(#T@)R<I"B`@("!["B`@("`@("`@96-H
M;R`H)'!R969I>"`_("1P<F5F:7@@+B`G.B`G(#H@)R<I("X@)'1H:7,M/GEE
M87(@+B`G+2<@+B`D=&AI<RT^;6]N=&@@+B`G+2<@+B`D=&AI<RT^;61A>2`N
M("(\8G(@+SY<;B(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!)<R!T:&4@9&%T
M92!C=7)R96YT;'D@<F5P<F5S96YT960@8GD@=&AI<R!O8FIE8W0@82!V86QI
M9"!D871E/PH@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5F%L:61I
M='DL(&-O=6YT:6YG(&QE87`@>65A<G,L(&5T8RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@:7-686QI9"@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YY96%R
M(#P@,"!\?"`D=&AI<RT^>65A<B`^(#DY.3DI('L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("!R971U<FX@8VAE8VMD871E
M*"1T:&ES+3YM;VYT:"P@)'1H:7,M/FUD87DL("1T:&ES+3YY96%R*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($-O<G)E8W0@86YY(&]V97(M(&]R('5N9&5R
M9FQO=W,@:6X@86YY(&]F('1H92!D871E)W,@;65M8F5R<RX*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D;6%S:R`@5V4@;6%Y(&YO="!W86YT('1O
M(&-O<G)E8W0@<V]M92!O=F5R9FQO=W,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&-O<G)E8W0H)&UA<VL@/2!(3U)$15]$051%7TU!4TM?04Q,4$%25%,I"B`@
M("!["B`@("`@("`@:68@*"1M87-K("8@2$]21$5?1$%415]-05-+7U-%0T].
M1"D@>PH@("`@("`@("`@("!W:&EL92`H)'1H:7,M/G-E8R`\(#`I('L*("`@
M("`@("`@("`@("`@("1T:&ES+3YM:6XM+3L*("`@("`@("`@("`@("`@("1T
M:&ES+3YS96,@*ST@-C`["B`@("`@("`@("`@('T*("`@("`@("`@("`@=VAI
M;&4@*"1T:&ES+3YS96,@/B`U.2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/FUI;BLK.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E8R`M/2`V,#L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1M87-K("8@2$]2
M1$5?1$%415]-05-+7TU)3E5412D@>PH@("`@("`@("`@("!W:&EL92`H)'1H
M:7,M/FUI;B`\(#`I('L*("`@("`@("`@("`@("`@("1T:&ES+3YH;W5R+2T[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^;6EN("L](#8P.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@('=H:6QE("@D=&AI<RT^;6EN(#X@-3DI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3YH;W5R*RL["B`@("`@("`@("`@("`@("`D
M=&AI<RT^;6EN("T](#8P.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!I9B`H)&UA<VL@)B!(3U)$15]$051%7TU!4TM?2$]54BD@>PH@("`@
M("`@("`@("!W:&EL92`H)'1H:7,M/FAO=7(@/"`P*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^;61A>2TM.PH@("`@("`@("`@("`@("`@)'1H:7,M/FAO
M=7(@*ST@,C0["B`@("`@("`@("`@('T*("`@("`@("`@("`@=VAI;&4@*"1T
M:&ES+3YH;W5R(#X@,C,I('L*("`@("`@("`@("`@("`@("1T:&ES+3YM9&%Y
M*RL["B`@("`@("`@("`@("`@("`D=&AI<RT^:&]U<B`M/2`R-#L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1M87-K("8@2$]21$5?
M1$%415]-05-+7TU/3E1(*2!["B`@("`@("`@("`@('=H:6QE("@D=&AI<RT^
M;6]N=&@@/B`Q,BD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/GEE87(K*SL*
M("`@("`@("`@("`@("`@("1T:&ES+3YM;VYT:"`M/2`Q,CL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!W:&EL92`H)'1H:7,M/FUO;G1H(#P@,2D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/GEE87(M+3L*("`@("`@("`@("`@("`@
M("1T:&ES+3YM;VYT:"`K/2`Q,CL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@:68@*"1M87-K("8@2$]21$5?1$%415]-05-+7T1!62D@>PH@
M("`@("`@("`@("!W:&EL92`H)'1H:7,M/FUD87D@/B!(;W)D95]$871E.CID
M87ES26Y-;VYT:"@D=&AI<RT^;6]N=&@L("1T:&ES+3YY96%R*2D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/FUD87D@+3T@2&]R9&5?1&%T93HZ9&%Y<TEN
M36]N=&@H)'1H:7,M/FUO;G1H+"`D=&AI<RT^>65A<BD["B`@("`@("`@("`@
M("`@("`D=&AI<RT^;6]N=&@K*SL*("`@("`@("`@("`@("`@("1T:&ES+3YC
M;W)R96-T*$A/4D1%7T1!5$5?34%32U]-3TY42"D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@=VAI;&4@*"1T:&ES+3YM9&%Y(#P@,2D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/FUO;G1H+2T["B`@("`@("`@("`@("`@("`D=&AI
M<RT^8V]R<F5C="A(3U)$15]$051%7TU!4TM?34].5$@I.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/FUD87D@*ST@2&]R9&5?1&%T93HZ9&%Y<TEN36]N=&@H
M)'1H:7,M/FUO;G1H+"`D=&AI<RT^>65A<BD["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VUP87)E('1H:7,@9&%T
M92!T;R!A;F]T:&5R(&1A=&4@;V)J96-T('1O('-E92!W:&EC:"!O;F4@:7,*
M("`@("`J(&=R96%T97(@*&QA=&5R*2X@07-S=6UE<R!T:&%T('1H92!D871E
M<R!A<F4@:6X@=&AE('-A;64*("`@("`J('1I;65Z;VYE+@H@("`@("H*("`@
M("`J($!P87)A;2!M:7AE9"`D9&%T92`@5&AE(&1A=&4@=&\@8V]M<&%R92!T
M;RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(#T]("`P(&EF('1H
M92!D871E<R!A<F4@97%U86P*("`@("`J("`@("`@("`@("`@("`@("`@/CT@
M(#$@:68@=&AI<R!D871E(&ES(&=R96%T97(@*&QA=&5R*0H@("`@("H@("`@
M("`@("`@("`@("`@("`\/2`M,2!I9B!T:&4@;W1H97(@9&%T92!I<R!G<F5A
M=&5R("AL871E<BD*("`@("`J+PH@("`@9G5N8W1I;VX@8V]M<&%R941A=&4H
M)&1A=&4I"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1D871E+"`G2&]R9&5?
M1&%T92<I*2!["B`@("`@("`@("`@("1D871E(#T@)FYE=R!(;W)D95]$871E
M*"1D871E*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^>65A<B`A
M/2`D9&%T92T^>65A<BD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/GEE
M87(@+2`D9&%T92T^>65A<CL*("`@("`@("!](&5L<V5I9B`H)'1H:7,M/FUO
M;G1H("$]("1D871E+3YM;VYT:"D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/FUO;G1H("T@)&1A=&4M/FUO;G1H.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^;61A>2`M("1D871E+3YM9&%Y.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-O;7!A<F4@=&AI<R!T
M;R!A;F]T:&5R(&1A=&4@;V)J96-T(&)Y('1I;64L('1O('-E92!W:&EC:"!O
M;F4*("`@("`J(&ES(&=R96%T97(@*&QA=&5R*2X@07-S=6UE<R!T:&%T('1H
M92!D871E<R!A<F4@:6X@=&AE('-A;64*("`@("`J('1I;65Z;VYE+@H@("`@
M("H*("`@("`J($!P87)A;2!M:7AE9"`D9&%T92`@5&AE(&1A=&4@=&\@8V]M
M<&%R92!T;RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(#T]("`P
M(&EF('1H92!D871E<R!A<F4@97%U86P*("`@("`J("`@("`@("`@("`@("`@
M("`@/CT@(#$@:68@=&AI<R!D871E(&ES(&=R96%T97(@*&QA=&5R*0H@("`@
M("H@("`@("`@("`@("`@("`@("`\/2`M,2!I9B!T:&4@;W1H97(@9&%T92!I
M<R!G<F5A=&5R("AL871E<BD*("`@("`J+PH@("`@9G5N8W1I;VX@8V]M<&%R
M951I;64H)&1A=&4I"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1D871E+"`G
M2&]R9&5?1&%T92<I*2!["B`@("`@("`@("`@("1D871E(#T@)FYE=R!(;W)D
M95]$871E*"1D871E*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^
M:&]U<B`A/2`D9&%T92T^:&]U<BD@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/FAO=7(@+2`D9&%T92T^:&]U<CL*("`@("`@("!](&5L<V5I9B`H)'1H
M:7,M/FUI;B`A/2`D9&%T92T^;6EN*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^;6EN("T@)&1A=&4M/FUI;CL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G-E8R`M("1D871E+3YS96,["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0V]M<&%R92!T:&ES('1O(&%N
M;W1H97(@9&%T92!O8FIE8W0L(&EN8VQU9&EN9R!T:6UE<RP@=&\@<V5E"B`@
M("`@*B!W:&EC:"!O;F4@:7,@9W)E871E<B`H;&%T97(I+B!!<W-U;65S('1H
M870@=&AE(&1A=&5S(&%R92!I;B!T:&4*("`@("`J('-A;64@=&EM97IO;F4N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D871E("!4:&4@9&%T92!T
M;R!C;VUP87)E('1O+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@
M/3T@(#`@:68@=&AE(&1A=&5S(&%R92!E<75A;`H@("`@("H@("`@("`@("`@
M("`@("`@("`^/2`@,2!I9B!T:&ES(&1A=&4@:7,@9W)E871E<B`H;&%T97(I
M"B`@("`@*B`@("`@("`@("`@("`@("`@(#P]("TQ(&EF('1H92!O=&AE<B!D
M871E(&ES(&=R96%T97(@*&QA=&5R*0H@("`@("HO"B`@("!F=6YC=&EO;B!C
M;VUP87)E1&%T951I;64H)&1A=&4I"B`@("!["B`@("`@("`@:68@*"%I<U]A
M*"1D871E+"`G2&]R9&5?1&%T92<I*2!["B`@("`@("`@("`@("1D871E(#T@
M)FYE=R!(;W)D95]$871E*"1D871E*3L*("`@("`@("!]"@H@("`@("`@(&EF
M("@D9&EF9B`]("1T:&ES+3YC;VUP87)E1&%T92@D9&%T92DI('L*("`@("`@
M("`@("`@<F5T=7)N("1D:69F.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^8V]M<&%R951I;64H)&1A=&4I.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@=&EM92!O9F9S970@
M9F]R(&QO8V%L('1I;64@>F]N92X*("`@("`J"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D8V]L;VX@(%!L86-E(&$@8V]L;VX@8F5T=V5E;B!H;W5R<R!A;F0@
M;6EN=71E<S\*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&EM97IO
M;F4@;V9F<V5T(&%S(&$@<W1R:6YG(&EN('1H92!F;W)M870@*TA(.DU-+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!T>D]F9G-E="@D8V]L;VX@/2!T<G5E*0H@
M("`@>PH@("`@("`@("1S96-S(#T@9&%T92@G6B<L("1T:&ES+3YT:6UE<W1A
M;7`H*2D["@H@("`@("`@(&EF("@D<V5C<R`\(#`I('L*("`@("`@("`@("`@
M)'-I9VX@/2`G+2<["B`@("`@("`@("`@("1S96-S(#T@+21S96-S.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1S:6=N(#T@)RLG.PH@("`@("`@
M('T*("`@("`@("`D8V]L;VX@/2`D8V]L;VX@/R`G.B<@.B`G)SL*("`@("`@
M("`D;6EN<R`](&EN='9A;"@H)'-E8W,@*R`S,"D@+R`V,"D["B`@("`@("`@
M<F5T=7)N('-P<FEN=&8H)R5S)3`R9"5S)3`R9"<L"B`@("`@("`@("`@("`@
M("`@("`@("`@)'-I9VXL("1M:6YS("\@-C`L("1C;VQO;BP@)&UI;G,@)2`V
M,"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&;W)M870@=&EM92!I;B!)4T\M
M.#8P,2!F;W)M870N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($1A
M=&4@86YD('1I;64@:6X@25-/+3@V,#$@9F]R;6%T+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!I<V\X-C`Q1&%T951I;64H*0H@("`@>PH@("`@("`@("1T>F]F
M9B`]("1T:&ES+3YT>D]F9G-E="@I.PH@("`@("`@("1D871E(#T@)'1H:7,M
M/GEE87(@+B`G+2<@+B`D=&AI<RT^;6]N=&@@+B`G+2<@+B`D=&AI<RT^;61A
M>3L*("`@("`@("`D=&EM92`]("1T:&ES+3YH;W5R("X@)SHG("X@)'1H:7,M
M/FUI;B`N("<Z)R`N("1T:&ES+3YS96,["@H@("`@("`@(')E='5R;B`D9&%T
M92`N("=4)R`N("1T:6UE("X@)'1Z;V9F.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1F]R;6%T('1I;64@:6X@4D9#(#(X,C(@9F]R;6%T+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!$871E(&%N9"!T:6UE(&EN(%)&0R`R.#(R
M(&9O<FUA="X*("`@("`J+PH@("`@9G5N8W1I;VX@<F9C,C@R,D1A=&54:6UE
M*"D*("`@('L*("`@("`@("!R971U<FX@9&%T92@G1"P@:B!-(%D@2#II.G,@
M)RP@)'1H:7,M/G1I;65S=&%M<"@I*2`N("1T:&ES+3YT>D]F9G-E="AF86QS
M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&;W)M870@=&EM92!I;B!21D,@
M,S,S.2!F;W)M870N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($1A
M=&4@86YD('1I;64@:6X@4D9#(#,S,SD@9F]R;6%T+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!R9F,S,S,Y1&%T951I;64H*0H@("`@>PH@("`@("`@(')E='5R
M;B!D871E*"=9+6TM9%Q42#II)RP@)'1H:7,M/G1I;65S=&%M<"@I*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($9O<FUA="!T:6UE('1O('-T86YD87)D("=C
M=&EM92<@9F]R;6%T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!$
M871E(&%N9"!T:6UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!C5&EM92@D=&EM
M92`](&9A;'-E*0H@("`@>PH@("`@("`@(')E='5R;B!D871E*"=$($T@:B!(
M.FDZ<R!9)RP@)'1H:7,M/G1I;65S=&%M<"@I*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($9O<FUA="!D871E(&%N9"!T:6UE('5S:6YG('-T<F9T:6UE*"D@
M9F]R;6%T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!S=')F=&EM
M92@I(&9O<FUA='1E9"!D871E(&%N9"!T:6UE+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!S=')F=&EM92@D9F]R;6%T*0H@("`@>PH@("`@("`@(')E='5R;B!S
M=')F=&EM92@D9F]R;6%T+"`D=&AI<RT^=&EM97-T86UP*"DI.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]%9&ET;W(O````````````````````
M````````````````````````````````````````````````````````,#`P
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-3$`
M,#(P-S$Q`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T5D:71O
M<B]H=&UL87)E82YP:'``````````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-C8S,``Q,#4Q-30S,S<U,0`P,C,R,C0`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!%9&ET;W)?
M:'1M;&%R96$Z.B!C;&%S<R!P<F]V:61E<R!A;B!765-)5UE'(&5D:71O<B!F
M;W(@=7-E"B`J(&EN('1H92!(;W)D92!&<F%M97=O<FLN"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+T5D:71O<B]%9&ET;W(O:'1M;&%R96$N<&AP+'8@,2XR
M-"XT+C0@,C`P-B\P,2\P,2`R,3HR.#HQ-"!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#,M,C`P-B!.=6YO($QO=7)E:7)O(#QN=6YO0&-O+G-A<&\N
M<'0^"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($YU;F\@
M3&]U<F5I<F\@/&YU;F]`8V\N<V%P;RYP=#X*("H@0&%U=&AO<B`@2F%N(%-C
M:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP
M"B`J($!P86-K86=E($AO<F1E7T5D:71O<@H@*B\*8VQA<W,@2&]R9&5?161I
M=&]R7VAT;6QA<F5A(&5X=&5N9',@2&]R9&5?161I=&]R('L*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=&]R+B!);F-L=61E('1H92!N96-E<W-A<GD@:F%V
M87-C<FEP="!F:6QE<RX*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?161I
M=&]R7VAT;6QA<F5A*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@
M(&=L;V)A;"`D<F5G:7-T<GDL("1N;W1I9FEC871I;VXL("1P<F5F<SL*"B`@
M("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)VAT;6QA<F5A+FIS)RP@)VAO
M<F1E)RD["B`@("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)R]S97)V:6-E
M<R]E9&ET;W(O:'1M;&%R96$O:'1M;&%R96$N:G,G+"`G:&]R9&4G+"!T<G5E
M*3L*("`@("`@("`D<V-R:7!T(#T@2&]R9&4Z.G5R;"A5=&EL.CIA9&1087)A
M;65T97(H)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O
M<V5R=FEC97,O:F%V87-C<FEP="YP:'`G+"`G87!P)RP@)VAO<F1E)RDL('1R
M=64I.PH@("`@("`@("1J<R`]("=(5$U,07)E82YL;V%D4V-R:7!T*"(G("X@
M571I;#HZ861D4&%R86UE=&5R*"1S8W)I<'0L("=F:6QE)RP@("=H=&UL87)E
M85]L86YG+FIS)RP@9F%L<V4I("X@)R(I.R`G.PH*("`@("`@("`D<&QU9VEN
M<R`]("<G.PH@("`@("`@(&EF("@D<')E9G,M/F=E=%9A;'5E*"=T86)L96]P
M97)A=&EO;G,G*2D@>PH@("`@("`@("`@("`D:G,@+CT@)TA434Q!<F5A+FQO
M8610;'5G:6XH(E1A8FQE3W!E<F%T:6]N<R(I.R`G("X*("`@("`@("`@("`@
M("`@("`@("=(5$U,07)E82YL;V%D4V-R:7!T*"(G("X@571I;#HZ861D4&%R
M86UE=&5R*"1S8W)I<'0L("=F:6QE)RP@("=H=&UL87)E85]T86)L95]L86YG
M+FIS)RP@9F%L<V4I("X@)R(I.R`G.PH@("`@("`@("`@("`D<&QU9VEN<R`N
M/2`G961I=&]R+G)E9VES=&5R4&QU9VEN*%1A8FQE3W!E<F%T:6]N<RD[("<[
M"B`@("`@("`@?0H@("`@("`@(&EF("@D<')E9G,M/F=E=%9A;'5E*"=C;VYT
M97AT;65N=2<I*2!["B`@("`@("`@("`@("1J<R`N/2`G2%1-3$%R96$N;&]A
M9%!L=6=I;B@B0V]N=&5X=$UE;G4B*3L@)R`N"B`@("`@("`@("`@("`@("`@
M("`G2%1-3$%R96$N;&]A9%-C<FEP="@B)R`N(%5T:6PZ.F%D9%!A<F%M971E
M<B@D<V-R:7!T+"`G9FEL92<L("`G:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M)RP@9F%L<V4I("X@)R(I.R`G.PH@("`@("`@("`@("`D<&QU9VEN<R`N/2`G
M961I=&]R+G)E9VES=&5R4&QU9VEN*$-O;G1E>'1-96YU*3L@)SL*("`@("`@
M("!]"B`@("`@("`@:68@*"1P<F5F<RT^9V5T5F%L=64H)VQI<W1T>7!E)RDI
M('L*("`@("`@("`@("`@)&IS("X]("=(5$U,07)E82YL;V%D4&QU9VEN*"),
M:7-T5'EP92(I.R`G("X*("`@("`@("`@("`@("`@("`@("=(5$U,07)E82YL
M;V%D4V-R:7!T*"(G("X@571I;#HZ861D4&%R86UE=&5R*"1S8W)I<'0L("=F
M:6QE)RP@("=H=&UL87)E85]L:7-T='EP95]L86YG+FIS)RP@9F%L<V4I("X@
M)R(I.R`G.PH@("`@("`@("`@("`D<&QU9VEN<R`N/2`G961I=&]R+G)E9VES
M=&5R4&QU9VEN*$QI<W14>7!E*3L@)SL*("`@("`@("!]"B`@("`@("`@:68@
M*"1P<F5F<RT^9V5T5F%L=64H)V%N<V5L:6UA9V4G*2`F)B`D<F5G:7-T<GDM
M/FAA<TUE=&AO9"@G:6UA9V5S+VQI<W1'86QL97)I97,G*2D@>PH@("`@("`@
M("`@("`D:G,@+CT@)TA434Q!<F5A+FQO8610;'5G:6XH(D%N<V5L26UA9V4B
M*3L@)R`N"B`@("`@("`@("`@("`@("`@("`G2%1-3$%R96$N;&]A9%-C<FEP
M="@B)R`N(%5T:6PZ.F%D9%!A<F%M971E<B@D<V-R:7!T+"`G9FEL92<L("`G
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS)RP@9F%L<V4I("X@)R(I.R`G
M.PH@("`@("`@("`@("`D<&QU9VEN<R`N/2`G961I=&]R+G)E9VES=&5R4&QU
M9VEN*$%N<V5L26UA9V4I.R`G.PH@("`@("`@('T*"B`@("`@("`@)&IS("X]
M("=(5$U,07)E82YO;FQO860@/2!F=6YC=&EO;B@I('L@)R`N"B`@("`@("`@
M("`@("`@("=V87(@8V]N9FEG(#T@;F5W($A434Q!<F5A+D-O;F9I9R@I(#LG
M("X*("`@("`@("`@("`@("`@)V-O;F9I9RYD96)U9R`](&9A;'-E.R`G("X*
M("`@("`@("`@("`@("`@)V-O;F9I9RYH:61E4V]M94)U='1O;G,H(B!S:&]W
M:&5L<"`B*3L@)SL*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG8V]N9FEG
M)UTI*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1P87)A;7-;)V-O;F9I9R==
M(&%S("1C;VYF:6<@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("`D:G,@
M+CT@)V-O;F9I9RXG("X@)&-O;F9I9R`N("<@/2`B)R`N(&%D9'-L87-H97,H
M)'9A;'5E*2`N("<B.R<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(&EF("AI<W-E="@D<&%R86US6R=I9"==*2D@>PH@("`@("`@("`@("`D
M:G,@+CT@)W9A<B!T97AT87)E87,@/2!;9&]C=6UE;G0N9V5T16QE;65N=$)Y
M260H(B<@+B`D<&%R86US6R=I9"==("X@)R(I73L@)SL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D:G,@+CT@)W9A<B!T97AT87)E87,@/2!D;V-U
M;65N="YG971%;&5M96YT<T)Y5&%G3F%M92@B=&5X=&%R96$B*3L@)SL*("`@
M("`@("!]"B`@("`@("`@)&IS("X]("=F;W(@*'9A<B!I(#T@=&5X=&%R96%S
M+FQE;F=T:"`M(#$[(&D@/CT@,#L@:2TM*2![("<@+@H@("`@("`@("`@("`@
M("`G=F%R(&5D:71O<B`](&YE=R!(5$U,07)E82AT97AT87)E87-;:5TL(&-O
M;F9I9RD[("<@+@H@("`@("`@("`@("`@("`D<&QU9VEN<R`N"B`@("`@("`@
M("`@("`@("=E9&ET;W(N9V5N97)A=&4H*7U].R`G("X*("`@("`@("`@("`@
M("`@)TA434Q!<F5A+FEN:70H*3LG.PH*("`@("`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*"1J<RP@)VIA=F%S8W)I<'0G*3L*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]%9&ET
M;W(N<&AP````````````````````````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#<W,34`,3`U,34T,S,W-3$`,#(Q-#,T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!%9&ET;W(@0VQA
M<W,*("H*("H@5&AE($5D:71O<CHZ('!A8VMA9V4@<')O=FED97,@86X@<G1E
M(&5D:71O<B!F;W(@=&AE($AO<F1E"B`J($%P<&QI8V%T:6]N($9R86UE=V]R
M:RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO161I=&]R+T5D:71O<BYP:'`L
M=B`Q+C@N,3`N."`R,#`V+S`Q+S`Q(#(Q.C(X.C$T(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($YU;F\@3&]U<F5I<F\@/&YU;F]`8V\N
M<V%P;RYP=#X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($YU;F\@3&]U
M<F5I<F\@/&YU;F]`8V\N<V%P;RYP=#X*("H@0'-I;F-E("`@2&]R9&4@,RXP
M"B`J($!P86-K86=E($AO<F1E7T5D:71O<@H@*B\*8VQA<W,@2&]R9&5?161I
M=&]R('L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!(;W)D95]%9&ET;W(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@
M("!["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@
M82!C;VYC<F5T92!(;W)D95]%9&ET;W(@:6YS=&%N8V4@8F%S960@;VX@)&1R
M:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1R:79E<B`@5&AE
M('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?161I=&]R('-U8F-L87-S('1O"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N+B!)9B`D9')I=F5R
M(&ES(&%N(&%R<F%Y+"!T:&5N('=E('=I;&P@;&]O:PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@(&EN("1D<FEV97);,%TO;&EB+T1R:79E<B\@9F]R
M('1H92!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EM
M<&QE;65N=&%T:6]N(&YA;65D("1D<FEV97);,5TN<&AP+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I
M=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!C;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H
M="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?161I=&]R("!4
M:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T92!(;W)D95]%9&ET;W(@:6YS=&%N
M8V4L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@;W(@9F%L<V4@;VX@
M97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D<FEV97(L
M("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D
M9')I=F5R*2D@>PH@("`@("`@("`@("`D87!P(#T@)&1R:79E<ELP73L*("`@
M("`@("`@("`@)&1R:79E<B`]("1D<FEV97);,5T["B`@("`@("`@?0H*("`@
M("`@("`D9')I=F5R(#T@8F%S96YA;64H)&1R:79E<BD["B`@("`@("`@:68@
M*&5M<'1Y*"1D<FEV97(I('Q\("1D<FEV97(@/3T@)VYO;F4G*2!["B`@("`@
M("`@("`@("1E9&ET;W(@/2`F;F5W($AO<F1E7T5D:71O<B@D<&%R86US*3L*
M("`@("`@("`@("`@<F5T=7)N("1E9&ET;W(["B`@("`@("`@?0H*("`@("`@
M("!I9B`H:7-?;G5L;"@D<&%R86US*2`F)B!C;&%S<U]E>&ES=',H)TAO<F1E
M)RDI('L*("`@("`@("`@("`@)'!A<F%M<R`]($AO<F1E.CIG971$<FEV97)#
M;VYF:6<H)V5D:71O<B<L("1D<FEV97(I.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"%E;7!T>2@D87!P*2D@>PH@("`@("`@("`@("!G;&]B86P@)')E9VES
M=')Y.PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)')E9VES=')Y+3YG970H
M)V9I;&5R;V]T)RP@)&%P<"D@+B`G+VQI8B]%9&ET;W(O)R`N("1D<FEV97(@
M+B`G+G!H<"<["B`@("`@("`@?2!E;'-E:68@*$!F:6QE7V5X:7-T<RAD:7)N
M86UE*%]?1DE,15]?*2`N("<O161I=&]R+R<@+B`D9')I=F5R("X@)RYP:'`G
M*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+T5D:71O<B\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!`:6YC;'5D95]O;F-E("=(;W)D92]%9&ET
M;W(O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?0H*("`@("`@("`D
M8VQA<W,@/2`G2&]R9&5?161I=&]R7R<@+B`D9')I=F5R.PH@("`@("`@(&EF
M("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D961I=&]R
M(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&5D:71O<B`](%!%05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E
M9FEN:71I;VX@;V8@)R`N("1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1E9&ET;W(["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E<F5N8V4@=&\@82!C
M;VYC<F5T92!(;W)D95]%9&ET;W(*("`@("`J(&EN<W1A;F-E(&)A<V5D(&]N
M("1D<FEV97(N($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N8V4*
M("`@("`J(&EF(&YO($AO<F1E7T5D:71O<B!I;G-T86YC92!W:71H('1H92!S
M86UE('!A<F%M971E<G,@8W5R<F5N=&QY"B`@("`@*B!E>&ES=',N"B`@("`@
M*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E9"!I9B!M=6QT:7!L92!C86-H
M92!B86-K96YD<R`H86YD+"!T:'5S+`H@("`@("H@;75L=&EP;&4@2&]R9&5?
M161I=&]R(&EN<W1A;F-E<RD@87)E(')E<75I<F5D+@H@("`@("H*("`@("`J
M(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH*("`@("`J("1V87(@
M/2`F2&]R9&5?161I=&]R.CIS:6YG;&5T;VXH*0H@("`@("H*("`@("`J($!P
M87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!(;W)D
M95]%9&ET;W(@<W5B8VQA<W,@=&\*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!R971U<FXN($EF("1D<FEV97(@:7,@86X@87)R87DL('1H96X@=V4@
M=VEL;"!L;V]K"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:6X@)&1R
M:79E<ELP72]L:6(O161I=&]R+R!F;W(@=&AE('-U8F-L87-S"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@:6UP;&5M96YT871I;VX@;F%M960@)&1R
M:79E<ELQ72YP:'`N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H
M87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O
M<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&-O;FYE8W1I;VX@<&%R
M86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@
M0'-I;F-E($AO<F1E(#(N,@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?
M161I=&]R("!4:&4@8V]N8W)E=&4@2&]R9&5?161I=&]R(')E9F5R96YC92P@
M;W(@9F%L<V4@;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!E<G)O
M<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D9')I=F5R+"`D
M<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E
M<SL*"B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S*2D@>PH@("`@("`@
M("`@("`D:6YS=&%N8V5S(#T@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("AI<U]N=6QL*"1P87)A;7,I("8F(&-L87-S7V5X:7-T<R@G2&]R9&4G
M*2D@>PH@("`@("`@("`@("`D<&%R86US(#T@2&]R9&4Z.F=E=$1R:79E<D-O
M;F9I9R@G8V%C:&4G+"`D9')I=F5R*3L*("`@("`@("!]"@H@("`@("`@("1S
M:6=N871U<F4@/2!S97)I86QI>F4H87)R87DH)&1R:79E<BP@)'!A<F%M<RDI
M.PH@("`@("`@(&EF("@A87)R87E?:V5Y7V5X:7-T<R@D<VEG;F%T=7)E+"`D
M:6YS=&%N8V5S*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U
M<F5=(#T@)DAO<F1E7T5D:71O<CHZ9F%C=&]R>2@D9')I=F5R+"`D<&%R86US
M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YS=&%N8V5S6R1S:6=N
M871U<F5=.PH@("`@?0H*?0H`````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B](;W)D92]&;W)M+P``````````````````````````````````
M````````````````````````````````````````````,#`P,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-#<`,#(P,S<S`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T9O<FTO06-T:6]N+P``
M````````````````````````````````````````````````````````````
M```````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q
M-30S,S<T-P`P,C$V,3``(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O1F]R;2]!8W1I;VXO8V]N9&ET:6]N86Q?96YA8FQE+G!H<```````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`S-#$U`#$P-3$U-#,S-S0W`#`R-C$S-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@2&]R
M9&5?1F]R;5]!8W1I;VY?8V]N9&ET:6]N86Q?96YA8FQE(&ES(&$@2&]R9&5?
M1F]R;5]!8W1I;VX@=&AA=`H@*B!E;F%B;&5S(&]R(&1I<V%B;&5S(&%N(&5L
M96UE;G0@8F%S960@;VX@=&AE('9A;'5E(&]F(&%N;W1H97(@96QE;65N=`H@
M*@H@*B!&;W)M870@;V8@=&AE("1P87)A;7,@<&%S<V5D('1O('1H92!C;VYS
M=')U8W1O<CH*("H@/'!R93X*("H@("1P87)A;7,@/2!A<G)A>2@*("H@("`@
M("`G=&%R9V5T)R`@/3X@)UMN86UE(&]F(&5L96UE;G0@=&AI<R!I<R!C;VYD
M:71I;VYA;"!O;ETG+`H@*B`@("`@("=E;F%B;&5D)R`]/B`G=')U92<@?"`G
M9F%L<V4G+`H@*B`@("`@("=V86QU97,G("`]/B!A<G)A>2A;=&%R9V5T('9A
M;'5E<R!T;R!C:&5C:UTI"B`J("`I.PH@*B`\+W!R93X*("H*("H@4V\@)'!A
M<F%M<R`](&%R<F%Y*"=F;V\G+"`G=')U92<L(&%R<F%Y*#$L(#(I*2!W:6QL
M(&5N86)L92!T:&4@9FEE;&0@=&AI<PH@*B!A8W1I;VX@:7,@871T86-H960@
M=&\@:68@=&AE('9A;'5E(&]F("=F;V\G(&ES(#$@;W(@,BP@86YD(&1I<V%B
M;&4@:70*("H@;W1H97)W:7-E+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTO06-T:6]N+V-O;F1I=&EO;F%L7V5N86)L92YP:'`L=B`Q+C0N
M,3`N,R`R,#`V+S`Q+S`Q(#(Q.C(X.C$W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P,BTR,#`V($UA='0@2WEN87-T;VX@/&UA='1`:WEN>"YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-871T($MY;F%S=&]N(#QM
M871T0&MY;G@N;W)G/@H@*B!`<&%C:V%G92!(;W)D95]&;W)M"B`J+PIC;&%S
M<R!(;W)D95]&;W)M7T%C=&EO;E]C;VYD:71I;VYA;%]E;F%B;&4@97AT96YD
M<R!(;W)D95]&;W)M7T%C=&EO;B!["@H@("`@=F%R("1?=')I9V=E<B`](&%R
M<F%Y*"=O;FQO860G*3L*"B`@("!F=6YC=&EO;B!G971!8W1I;VY38W)I<'0H
M)B1F;W)M+"`D<F5N9&5R97(L("1V87)N86UE*0H@("`@>PH@("`@("`@($AO
M<F1E.CIA9&138W)I<'1&:6QE*"=F;W)M7VAE;'!E<G,N:G,G+"`G:&]R9&4G
M+"!T<G5E*3L*"B`@("`@("`@)&9O<FU?;F%M92`]("1F;W)M+3YG971.86UE
M*"D["B`@("`@("`@)'1A<F=E="`]("1T:&ES+3Y?<&%R86US6R=T87)G970G
M73L*("`@("`@("`D96YA8FQE9"`]("1T:&ES+3Y?<&%R86US6R=E;F%B;&5D
M)UT["B`@("`@("`@:68@*"%I<U]S=')I;F<H)&5N86)L960I*2!["B`@("`@
M("`@("`@("1E;F%B;&5D(#T@*"1E;F%B;&5D*2`_("=T<G5E)R`Z("=F86QS
M92<["B`@("`@("`@?0H@("`@("`@("1V86QS(#T@)'1H:7,M/E]P87)A;7-;
M)W9A;'5E<R==.PH@("`@("`@("1V86QS(#T@*&ES7V%R<F%Y*"1V86QS*2D@
M/R`D=F%L<R`Z(&%R<F%Y*"1V86QS*3L*("`@("`@("`D87)G<R`]("(G)'9A
M<FYA;64G+"`D96YA8FQE9"P@)R(@+B!I;7!L;V1E*"(G+"<B+"`D=F%L<RD@
M+B`B)R(["@H@("`@("`@(')E='5R;B`B:68@*&%D9$5V96YT*&1O8W5M96YT
M+B1F;W)M7VYA;64N)'1A<F=E="P@)V]N8VAA;F=E)RP@7")C:&5C:T5N86)L
M960H=&AI<RP@)&%R9W,I.UPB*2D@>R`B"B`@("`@("`@("`@("X@(B`@8VAE
M8VM%;F%B;&5D*&1O8W5M96YT+B1F;W)M7VYA;64N)'9A<FYA;64L("1A<F=S
M*3L@(@H@("`@("`@("`@("`N("=].R<["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T9O
M<FTO06-T:6]N+V-O;F1I=&EO;F%L7W-E='9A;'5E+G!H<```````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P-3`Q,``Q,#4Q-30S,S<T-P`P,C8U,S``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J($AO<F1E7T9O
M<FU?06-T:6]N7V-O;F1I=&EO;F%L7W-E='9A;'5E(&ES(&$@2&]R9&5?1F]R
M;5]!8W1I;VX@=&AA=`H@*B!S971S('1H92!V86QU92!O9B!O;F4@2&]R9&5?
M1F]R;2!V87)I86)L92!B87-E9"!O;B!T:&4@=F%L=64@;V8@=&AE"B`J('9A
M<FEA8FQE('1H92!A8W1I;VX@:7,@871T86-H960@=&\N"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+T9O<FTO1F]R;2]!8W1I;VXO8V]N9&ET:6]N86Q?<V5T
M=F%L=64N<&AP+'8@,2XQ.2XQ,"XU(#(P,#8O,#$O,#$@,C$Z,C@Z,3<@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'!A
M8VMA9V4@2&]R9&5?1F]R;0H@*B\*8VQA<W,@2&]R9&5?1F]R;5]!8W1I;VY?
M8V]N9&ET:6]N86Q?<V5T=F%L=64@97AT96YD<R!(;W)D95]&;W)M7T%C=&EO
M;B!["@H@("`@+RHJ"B`@("`@*B!7:&EC:"!*4R!E=F5N=',@<VAO=6QD('1R
M:6=G97(@=&AI<R!A8W1I;VX_"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]T<FEG9V5R(#T@87)R87DH)V]N8VAA;F=E)RP@
M)V]N;&]A9"<I.PH*("`@(&9U;F-T:6]N(&=E=$%C=&EO;E-C<FEP="@D9F]R
M;2P@)')E;F1E<F5R+"`D=F%R;F%M92D*("`@('L*("`@("`@("!R971U<FX@
M)VUA<"A<)R<@+B`D<F5N9&5R97(M/E]G96Y)1"@D=F%R;F%M92P@9F%L<V4I
M("X@(B<L("<B("X@)')E;F1E<F5R+3Y?9V5N240H)'1H:7,M/F=E=%1A<F=E
M="@I+"!F86QS92D@+B`G7"<I.R<["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T
M5F%L=65S*"8D=F%R<RP@)'-O=7)C959A;"P@)&%R<F%Y5F%L(#T@9F%L<V4I
M"B`@("!["B`@("`@("`@)&UA<"`]("1T:&ES+3Y?<&%R86US6R=M87`G73L*
M("`@("`@("`D=&%R9V5T(#T@)'1H:7,M/F=E=%1A<F=E="@I.PH*("`@("`@
M("!I9B`H)&%R<F%Y5F%L*2!["B`@("`@("`@("`@("1I(#T@,#L*("`@("`@
M("`@("`@:68@*&ES7V%R<F%Y*"1S;W5R8V5686PI*2!["B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D<V]U<F-E5F%L(&%S("1V86PI('L*("`@("`@("`@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1M87!;)'9A;%TI*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1V87)S+3YS970H)'1A<F=E="P@)&UA<%LD=F%L
M72P@)&DI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`D:2LK.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D;6%P6R1S
M;W5R8V5686Q=*2D@>PH@("`@("`@("`@("`@("`@)'9A<G,M/G-E="@D=&%R
M9V5T+"`D;6%P6R1S;W5R8V5686Q=*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("!F=6YC=&EO;B!P<FEN=$IA=F%38W)I<'0H*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?<')I;G1*879A4V-R:7!T4W1A<G0H*3L*("`@
M("`@("`D;6%P(#T@)'1H:7,M/E]P87)A;7-;)VUA<"==.PH_/@H*=F%R(%]M
M87`@/2!N97<@07)R87DH/#]P:'`*)&D@/2`P.PIF;W)E86-H("@D;6%P(&%S
M("1V86PI('L*("`@(&EF("@D:2`^(#`I('L*("`@("`@("!E8VAO("<L("<[
M"B`@("!]"B`@("!E8VAO("<B)R`N("1V86P@+B`G(B<["B`@("`D:2LK.PI]
M/SXI.PH*9G5N8W1I;VX@;6%P*'-O=7)C94ED+"!T87)G971)9"D*>PH@("`@
M=F%R(&YE=W9A;#L*("`@('9A<B!S;W5R8V4@/2!D;V-U;65N="YG971%;&5M
M96YT0GE)9"AS;W5R8V5)9"D["B`@("!V87(@96QE;65N="`](&1O8W5M96YT
M+F=E=$5L96UE;G1">4ED*'1A<F=E=$ED*3L*("`@(&EF("AE;&5M96YT*2![
M"B`@("`@("`@:68@*%]M87!;<V]U<F-E+G-E;&5C=&5D26YD97A=*2!["B`@
M("`@("`@("`@(&YE=W9A;"`](%]M87!;<V]U<F-E+G-E;&5C=&5D26YD97A=
M.PH@("`@("`@("`@("!R97!L86-E(#T@=')U93L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!N97=V86P@/2`G)SL*("`@("`@("`@("`@<F5P;&%C
M92`](&9A;'-E.PH@("`@("`@("`@("!F;W(@*&D@/2`P.R!I(#P@7VUA<"YL
M96YG=&@[(&DK*RD@>PH@("`@("`@("`@("`@("`@:68@*&5L96UE;G0N=F%L
M=64@/3T@7VUA<%MI72D@>PH@("`@("`@("`@("`@("`@("`@(')E<&QA8V4@
M/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H
M<F5P;&%C92D@>PH@("`@("`@("`@("!E;&5M96YT+G9A;'5E(#T@;F5W=F%L
M.PH@("`@("`@('T*("`@('T*?3P_<&AP"B`@("`@("`@)'1H:7,M/E]P<FEN
M=$IA=F%38W)I<'1%;F0H*3L*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1F]R;2]!8W1I;VXO<F5L;V%D
M+G!H<```````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-3<S`#$P-3$U-#,S
M-S0W`#`R,S4W-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@2&]R9&5?1F]R;5]!8W1I;VY?<F5L;V%D
M(&ES(&$@2&]R9&5?1F]R;2!!8W1I;VX@=&AA="!R96QO861S('1H90H@*B!F
M;W)M('=I=&@@=&AE(&-U<G)E;G0@*&YO="!T:&4@;W)I9VEN86PI('9A;'5E
M(&%F=&5R('1H92!F;W)M(&5L96UE;G0*("H@=&AA="!T:&4@86-T:6]N(&ES
M(&%T=&%C:&5D('1O(&ES(&UO9&EF:65D+@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTO06-T:6]N+W)E;&]A9"YP:'`L=B`Q+C<N,3`N-"`R
M,#`V+S`Q+S`Q(#(Q.C(X.C$W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P,RTR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R
M9&4N;W)G/@H@*B!`<&%C:V%G92!(;W)D95]&;W)M"B`J+PIC;&%S<R!(;W)D
M95]&;W)M7T%C=&EO;E]R96QO860@97AT96YD<R!(;W)D95]&;W)M7T%C=&EO
M;B!["@H@("`@=F%R("1?=')I9V=E<B`](&%R<F%Y*"=O;F-H86YG92<I.PH*
M("`@(&9U;F-T:6]N(&=E=$%C=&EO;E-C<FEP="@D9F]R;2P@)')E;F1E<F5R
M+"`D=F%R;F%M92D*("`@('L*("`@("`@("!R971U<FX@)VEF("AT:&ES+G9A
M;'5E*2![(&1O8W5M96YT+B<@+B`D9F]R;2T^9V5T3F%M92@I("X@)RYF;W)M
M;F%M92YV86QU93U<)UPG.R<@+@H@("`@("`@("`@("`G9&]C=6UE;G0N)R`N
M("1F;W)M+3YG971.86UE*"D@+B`G+G-U8FUI="@I('TG.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1F]R;2]!8W1I;VXO
M<W5B;6ET+G!H<```````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,S<W`#$P
M-3$U-#,S-S0W`#`R,S8S-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@2&]R9&5?1F]R;5]!8W1I;VY?
M<W5B;6ET(&ES(&$@2&]R9&5?1F]R;2!!8W1I;VX@=&AA="!S=6)M:71S('1H
M90H@*B!F;W)M(&%F=&5R('1H92!F;W)M(&5L96UE;G0@=&AA="!T:&4@86-T
M:6]N(&ES(&%T=&%C:&5D('1O(&ES"B`J(&UO9&EF:65D+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]&;W)M+T9O<FTO06-T:6]N+W-U8FUI="YP:'`L=B`Q
M+C$P+C$R+C0@,C`P-B\P,2\P,2`R,3HR.#HQ-R!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!(;W)D95]&
M;W)M"B`J+PIC;&%S<R!(;W)D95]&;W)M7T%C=&EO;E]S=6)M:70@97AT96YD
M<R!(;W)D95]&;W)M7T%C=&EO;B!["@H@("`@=F%R("1?=')I9V=E<B`](&%R
M<F%Y*"=O;F-H86YG92<I.PH*("`@(&9U;F-T:6]N(&=E=$%C=&EO;E-C<FEP
M="@D9F]R;2P@)')E;F1E<F5R+"`D=F%R;F%M92D*("`@('L*("`@("`@("!R
M971U<FX@)V1O8W5M96YT+B<@+B`D9F]R;2T^9V5T3F%M92@I("X@)RYS=6)M
M:70H*2<["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1F]R;2]!
M8W1I;VXO<W5M7V9I96QD<RYP:'``````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R
M-S8P`#$P-3$U-#,S-S0W`#`R-#0V,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@2&]R9&5?1F]R;5]!
M8W1I;VY?<W5M7V9I96QD<R!I<R!A($AO<F1E7T9O<FU?06-T:6]N('1H870@
M<V5T<R!T:&4@=&%R9V5T"B`J(&9I96QD('1O('1H92!S=6T@;V8@;VYE(&]R
M(&UO<F4@;W1H97(@;G5M97)I8R!F:65L9',N"B`J"B`J(%1H92!P87)A;7,@
M87)R87D@<VAO=6QD(&-O;G1A:6X@=&AE(&YA;65S(&]F('1H92!F:65L9',@
M=VAI8V@@=VEL;"!B90H@*B!S=6UM960N"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+T9O<FTO1F]R;2]!8W1I;VXO<W5M7V9I96QD<RYP:'`L=B`Q+C4N,3`N
M-"`R,#`V+S`Q+S`Q(#(Q.C(X.C$W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,BTR,#`V($UA='0@2WEN87-T;VX@/&UA='1`:WEN>"YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-871T($MY;F%S=&]N(#QM871T
M0&MY;G@N;W)G/@H@*B!`<&%C:V%G92!(;W)D95]&;W)M"B`J+PIC;&%S<R!(
M;W)D95]&;W)M7T%C=&EO;E]S=6U?9FEE;&1S(&5X=&5N9',@2&]R9&5?1F]R
M;5]!8W1I;VX@>PH*("`@('9A<B`D7W1R:6=G97(@/2!A<G)A>2@G;VYL;V%D
M)RD["@H@("`@9G5N8W1I;VX@9V5T06-T:6]N4V-R:7!T*"8D9F]R;2P@)')E
M;F1E<F5R+"`D=F%R;F%M92D*("`@('L*("`@("`@("!(;W)D93HZ861D4V-R
M:7!T1FEL92@G9F]R;5]H96QP97)S+FIS)RP@)VAO<F1E)RP@=')U92D["@H@
M("`@("`@("1F;W)M7VYA;64@/2`D9F]R;2T^9V5T3F%M92@I.PH@("`@("`@
M("1F:65L9',@/2`B)R(@+B!I;7!L;V1E*"(G+"<B+"`D=&AI<RT^7W!A<F%M
M<RD@+B`B)R(["B`@("`@("`@)&IS(#T@87)R87DH*3L*("`@("`@("`D:G-;
M72`]('-P<FEN=&8H)V1O8W5M96YT+F9O<FUS6UPG)7-<)UTN96QE;65N='-;
M7"<E<UPG72YD:7-A8FQE9"`]('1R=64[)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@)&9O<FU?;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@)'9A
M<FYA;64I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%R86US(&%S("1F
M:65L9"D@>PH@("`@("`@("`@("`D:G-;72`]('-P<FEN=&8H(F%D9$5V96YT
M*&1O8W5M96YT+F9O<FUS6R<E,5PD<R==+F5L96UE;G1S6R<E,EPD<R==+"!<
M(F]N8VAA;F=E7"(L(%PB<W5M1FEE;&1S*&1O8W5M96YT+F9O<FUS6R<E,5PD
M<R==+"`G)3-<)',G+"`E-%PD<RD[7"(I.R(L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9F]R;5]N86UE+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&9I96QD+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A
M<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEE;&1S*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!I;7!L;V1E*")<;B(L("1J<RD[
M"B`@("!]"@I]"@`````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]&;W)M+T%C=&EO;B]U<&1A=&5F:65L9"YP:'``
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,W,#$`,3`U,34T,S,W-#<`,#(T-C$P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!(;W)D95]&;W)M7T%C=&EO;E]U<&1A=&5F:65L9"!I<R!A
M($AO<F1E7T9O<FU?06-T:6]N('1H870@=7!D871E<PH@*B!T:&4@=F%L=64@
M;V8@;VYE($AO<F1E7T9O<FT@=F%R:6%B;&4@87,@=&AE('9A<FEA8FQE('1H
M92!A8W1I;VX@:7,*("H@871T86-H960@=&\@:7,@=7!D871E9"X*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO1F]R;2]&;W)M+T%C=&EO;B]U<&1A=&5F:65L
M9"YP:'`L=B`Q+C4N,3(N-"`R,#`V+S`Q+S`Q(#(Q.C(X.C$W(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!P86-K86=E
M($AO<F1E7T9O<FT*("HO"F-L87-S($AO<F1E7T9O<FU?06-T:6]N7W5P9&%T
M969I96QD(&5X=&5N9',@2&]R9&5?1F]R;5]!8W1I;VX@>PH*("`@('9A<B`D
M7W1R:6=G97(@/2!A<G)A>2@G;VYC:&%N9V4G+"`G;VYL;V%D)RP@)V]N:V5Y
M=7`G*3L*"B`@("!F=6YC=&EO;B!G971!8W1I;VY38W)I<'0H)B1F;W)M+"`F
M)')E;F1E<F5R+"`D=F%R;F%M92D*("`@('L*("`@("`@("!R971U<FX@)W5P
M9&%T949I96QD)R`N("1T:&ES+3YI9"@I("X@)R@I.R<["B`@("!]"@H@("`@
M9G5N8W1I;VX@<V5T5F%L=65S*"8D=F%R<RP@)'-O=7)C959A;"P@)&%R<F%Y
M5F%L(#T@9F%L<V4I"B`@("!["B`@("!]"@H@("`@9G5N8W1I;VX@<')I;G1*
M879A4V-R:7!T*"D*("`@('L*("`@("`@("`D=&AI<RT^7W!R:6YT2F%V85-C
M<FEP=%-T87)T*"D["B`@("`@("`@)'!I96-E<R`](&5X<&QO9&4H)R5S)RP@
M)'1H:7,M/E]P87)A;7-;)V9O<FUA="==*3L*("`@("`@("`D9FEE;&1S(#T@
M)'1H:7,M/E]P87)A;7-;)V9I96QD<R==.PH@("`@("`@("1V86Q?9FER<W0@
M/2`H<W5B<W1R*"1T:&ES+3Y?<&%R86US6R=F;W)M870G72P@,"P@,BD@/3T@
M)R5S)RD["B`@("`@("`@:68@*"1V86Q?9FER<W0I('L*("`@("`@("`@("`@
M87)R87E?<VAI9G0H)'!I96-E<RD["B`@("`@("`@?0H@("`@("`@(&EF("AS
M=6)S='(H)'1H:7,M/E]P87)A;7-;)V9O<FUA="==+"`M,BD@/3T@)R5S)RD@
M>PH@("`@("`@("`@("!A<G)A>5]P;W`H)'!I96-E<RD["B`@("`@("`@?0H*
M("`@("`@("`D87)G<R`](&%R<F%Y*"D["B`@("`@("`@:68@*"1V86Q?9FER
M<W0I('L*("`@("`@("`@("`@)&%R9W-;72`](")D;V-U;65N="YG971%;&5M
M96YT0GE)9"@G(B`N(&%R<F%Y7W-H:69T*"1F:65L9',I("X@(B<I+G9A;'5E
M(CL*("`@("`@("!]"B`@("`@("`@=VAI;&4@*&-O=6YT*"1P:65C97,I*2![
M"B`@("`@("`@("`@("1A<F=S6UT@/2`B)R(@+B!A<G)A>5]S:&EF="@D<&EE
M8V5S*2`N("(G(CL*("`@("`@("`@("`@)&%R9W-;72`](")D;V-U;65N="YG
M971%;&5M96YT0GE)9"@G(B`N(&%R<F%Y7W-H:69T*"1F:65L9',I("X@(B<I
M+G9A;'5E(CL*("`@("`@("!]"C\^"B\O(%5P9&%T97(@9F]R(#P_<&AP(&5C
M:&\@)'1H:7,M/F=E=%1A<F=E="@I(#\^+@IF=6YC=&EO;B!U<&1A=&5&:65L
M9#P_<&AP(&5C:&\@)'1H:7,M/FED*"D@/SXH*0I["B`@("!V87(@=&%R9V5T
M(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)SP_<&AP(&5C:&\@)'1H:7,M
M/F=E=%1A<F=E="@I(#\^)RD["B`@("!I9B`H=&%R9V5T*2!["B`@("`@("`@
M=&%R9V5T+G9A;'5E(#T@/#]P:'`@96-H;R!I;7!L;V1E*"<@*R`G+"!S=')?
M<F5P;&%C92@B7&XB+"`B7%QN(BP@)&%R9W,I*2`_/CL*("`@('T*?3P_<&AP
M"B`@("`@("`@)'1H:7,M/E]P<FEN=$IA=F%38W)I<'1%;F0H*3L*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O1F]R;2]!8W1I;VXN<&AP````````````````````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#$P-S`S`#$P-3$U-#,S-S0W`#`R,C,R,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@5&AE($AO<F1E7T9O<FU?06-T:6]N(&-L87-S('!R;W9I9&5S(&%N
M($%022!F;W(@861D:6YG(&%C=&EO;G,@=&\*("H@2&]R9&5?1F]R;2!V87)I
M86)L97,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T9O<FTO1F]R;2]!8W1I
M;VXN<&AP+'8@,2XQ.2XQ,"XV(#(P,#8O,#$O,#$@,C$Z,C@Z,3<@:F%N($5X
M<"`D"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@
M2&]R9&5?1F]R;0H@*B\*8VQA<W,@2&]R9&5?1F]R;5]!8W1I;VX@>PH*("`@
M('9A<B`D7VED.PH@("`@=F%R("1?<&%R86US.PH@("`@=F%R("1?=')I9V=E
M<B`](&YU;&P["@H@("`@9G5N8W1I;VX@2&]R9&5?1F]R;5]!8W1I;VXH)'!A
M<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D
M<&%R86US.PH@("`@("`@("1T:&ES+3Y?:60@/2!M9#4H;71?<F%N9"@I*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!G9714<FEG9V5R*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]T<FEG9V5R.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&ED*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]I9#L*("`@('T*
M"B`@("!F=6YC=&EO;B!G971!8W1I;VY38W)I<'0H)&9O<FTL("1R96YD97)E
M<BP@)'9A<FYA;64I"B`@("!["B`@("`@("`@<F5T=7)N("<G.PH@("`@?0H*
M("`@(&9U;F-T:6]N('!R:6YT2F%V85-C<FEP="@I"B`@("!["B`@("!]"@H@
M("`@9G5N8W1I;VX@7W!R:6YT2F%V85-C<FEP=%-T87)T*"D*("`@('L*("`@
M("`@("!E8VAO("<\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^/"$M
M+2<["B`@("!]"@H@("`@9G5N8W1I;VX@7W!R:6YT2F%V85-C<FEP=$5N9"@I
M"B`@("!["B`@("`@("`@96-H;R`G+R\@+2T^/"]S8W)I<'0^)SL*("`@('T*
M"B`@("!F=6YC=&EO;B!G971487)G970H*0H@("`@>PH@("`@("`@(')E='5R
M;B!I<W-E="@D=&AI<RT^7W!A<F%M<ULG=&%R9V5T)UTI(#\@)'1H:7,M/E]P
M87)A;7-;)W1A<F=E="==(#H@;G5L;#L*("`@('T*"B`@("!F=6YC=&EO;B!S
M971686QU97,H)B1V87)S+"`D<V]U<F-E5F%L+"`D:6YD97@@/2!N=6QL+"`D
M87)R87E686P@/2!F86QS92D*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J
M($%T=&5M<'1S('1O(')E='5R;B!A(&-O;F-R971E($AO<F1E7T9O<FU?06-T
M:6]N(&EN<W1A;F-E"B`@("`@*B!B87-E9"!O;B`D9F]R;2X*("`@("`J"B`@
M("`@*B!`<&%R86T@;6EX960@)&9O<FT@("`@5&AE('1Y<&4@;V8@8V]N8W)E
M=&4@2&]R9&5?1F]R;5]!8W1I;VX@<W5B8VQA<W,*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!T;R!R971U<FXN($EF("1F;W)M(&ES(&%N(&%R<F%Y
M+"!T:&5N('=E('=I;&P@;&]O:PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&EN("1F;W)M6S!=+VQI8B]&;W)M+T%C=&EO;B\@9F]R('1H92!S=6)C
M;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EM<&QE;65N=&%T
M:6]N(&YA;65D("1F;W)M6S%=+G!H<"X*("`@("`J($!P87)A;2!A<G)A>2`D
M<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF
M:6=U<F%T:6]N(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!F;W)M
M(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]&;W)M
M7T%C=&EO;B`@5&AE(&-O;F-R971E($AO<F1E7T9O<FU?06-T:6]N(')E9F5R
M96YC92P@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9A
M;'-E(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R
M>2@D86-T:6]N+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H
M:7-?87)R87DH)&%C=&EO;BDI('L*("`@("`@("`@("`@)&%P<"`]("1A8W1I
M;VY;,%T["B`@("`@("`@("`@("1A8W1I;VX@/2`D86-T:6]N6S%=.PH@("`@
M("`@('T*"B`@("`@("`@)&%C=&EO;B`](&)A<V5N86UE*"1A8W1I;VXI.PH@
M("`@("`@(&EF("AE;7!T>2@D86-T:6]N*2!\?"`H<W1R8VUP*"1A8W1I;VXL
M("=N;VYE)RD@/3T@,"DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)T-A;FYO="!I;G-T86YT:6%T92!A8G-T<F%C="!C;&%S<R!(
M;W)D95]&;W)M7T%C=&EO;BXG*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A
M96UP='DH)&%P<"DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("1'3$]"
M04Q36R=R96=I<W1R>2==+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G+VQI
M8B]&;W)M+T%C=&EO;B\G("X@)&%C=&EO;B`N("<N<&AP)SL*("`@("`@("!]
M(&5L<V5I9B`H0&9I;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I("X@)R]!
M8W1I;VXO)R`N("1A8W1I;VX@+B`G+G!H<"<I*2!["B`@("`@("`@("`@(')E
M<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O06-T:6]N+R<@+B`D
M86-T:6]N("X@)RYP:'`G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O1F]R;2]!8W1I;VXO)R`N("1A8W1I;VX@
M+B`G+G!H<"<["B`@("`@("`@?0H*("`@("`@("`D8VQA<W,@/2`G2&]R9&5?
M1F]R;5]!8W1I;VY?)R`N("1A8W1I;VX["B`@("`@("`@:68@*&-L87-S7V5X
M:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1I;G-T86YC92`]("9N97<@
M)&-L87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1I;G-T86YC92`](%!%05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I
M;VX@;V8@)R`N("1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1I;G-T86YC93L*("`@('T*"B`@("`O*BH*("`@
M("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R
M971E"B`@("`@*B!(;W)D95]&;W)M7T%C=&EO;B!I;G-T86YC92!B87-E9"!O
M;B`D86-T:6]N+B!)="!W:6QL(&]N;'D*("`@("`J(&-R96%T92!A(&YE=R!I
M;G-T86YC92!I9B!N;R!(;W)D95]&;W)M7T%C=&EO;B!I;G-T86YC92!W:71H
M"B`@("`@*B!T:&4@<V%M92!P87)A;65T97)S(&-U<G)E;G1L>2!E>&ES=',N
M"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E9"!I9B!M=6QT:7!L
M92!T>7!E<R!O9B!F;W)M(')E;F1E<F5R<R`H86YD+`H@("`@("H@=&AU<RP@
M;75L=&EP;&4@2&]R9&5?1F]R;5]!8W1I;VX@:6YS=&%N8V5S*2!A<F4@<F5Q
M=6ER960N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O
M:V5D(&%S.B`D=F%R(#T*("`@("`J("9(;W)D95]&;W)M7T%C=&EO;CHZ<VEN
M9VQE=&]N*"D*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&%C=&EO;B`@
M5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?1F]R;5]!8W1I;VX@<W5B8VQA
M<W,@=&\@<F5T=7)N+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(%1H
M92!C;V1E(&ES(&1Y;F%M:6-A;&QY(&EN8VQU9&5D+B!)9B`D86-T:6]N(&ES
M(&%N(&%R<F%Y+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('1H96X@
M=V4@=VEL;"!L;V]K(&EN("1A8W1I;VY;,%TO;&EB+T9O<FTO06-T:6]N+R!F
M;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T:&4@<W5B8VQA<W,@
M:6UP;&5M96YT871I;VX@;F%M960@)&%C=&EO;ELQ72YP:'`N"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D
M9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!A"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@9F]R;2!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U
M<FX@2&]R9&5?1F]R;5]!8W1I;VX@(%1H92!C;VYC<F5T92!(;W)D95]&;W)M
M7T%C=&EO;B!R969E<F5N8V4L(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@)G-I;F=L971O;B@D86-T:6]N+"`D<&%R86US(#T@;G5L;"D*("`@
M('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<SL*("`@("`@("!I9B`H(6ES
M<V5T*"1I;G-T86YC97,I*2!["B`@("`@("`@("`@("1I;G-T86YC97,@/2!A
M<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA
M;&EZ92AA<G)A>2@D86-T:6]N+"`D<&%R86US*2D["B`@("`@("`@:68@*"%I
M<W-E="@D:6YS=&%N8V5S6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D
M:6YS=&%N8V5S6R1S:6=N871U<F5=(#T@)DAO<F1E7T9O<FU?06-T:6]N.CIF
M86-T;W)Y*"1A8W1I;VXL("1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]&;W)M+U)E;F1E<F5R+G!H<```````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P-#0R,#0`,3`U,34T,S,W-#<`,#(R-C4V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@
M2&]R9&5?1F]R;5]296YD97)E<B!C;&%S<R!P<F]V:61E<R!(5$U,(&%N9"!O
M=&AE<B!R96YD97)I;F=S(&]F"B`J(&9O<FUS(&9O<B!T:&4@2&]R9&5?1F]R
M;3HZ('!A8VMA9V4N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T9O<FTO1F]R
M;2]296YD97)E<BYP:'`L=B`Q+C$X-2XT+C$U(#(P,#8O,#0O,34@,3@Z,#4Z
M,#0@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!2;V)E
M<G0@12X@0V]Y;&4@/')O8F5R=&5C;WEL94!H;W1M86EL+F-O;3X*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@(%)O8F5R="!%+B!#;WEL92`\<F]B97)T
M96-O>6QE0&AO=&UA:6PN8V]M/@H@*B!`<&%C:V%G92!(;W)D95]&;W)M"B`J
M+PIC;&%S<R!(;W)D95]&;W)M7U)E;F1E<F5R('L*"B`@("!V87(@)%]N86UE
M.PH@("`@=F%R("1?<F5Q=6ER961,96=E;F0@/2!F86QS93L*("`@('9A<B`D
M7W)E<75I<F5D36%R:V5R(#T@)RHG.PH@("`@=F%R("1?:&5L<$UA<FME<B`]
M("<_)SL*("`@('9A<B`D7V]N3&]A9$I3(#T@87)R87DH*3L*("`@('9A<B`D
M7W-H;W=(96%D97(@/2!T<G5E.PH@("`@=F%R("1?8V]L<R`](#(["B`@("!V
M87(@)%]V87)296YD97)E<B`](&YU;&P["B`@("!V87(@)%]F:7)S=$9I96QD
M(#T@;G5L;#L*("`@('9A<B`D7W-T<FEP9612;W=S(#T@=')U93L*"B`@("`O
M*BH*("`@("`J($1O97,@=&AE('1I=&QE(&]F('1H92!F;W)M(&-O;G1A:6X@
M2%1-3#\@268@<V\L('EO=2!A<F4@<F5S<&]N<VEB;&4@9F]R"B`@("`@*B!D
M;VEN9R!A;GD@;F5E9&5D(&5S8V%P:6YG+W-A;FET:7IA=&EO;B!Y;W5R<V5L
M9BX@3W1H97)W:7-E('1H92!T:71L90H@("`@("H@=VEL;"!B92!R=6X@=&AR
M;W5G:"!H=&UL<W!E8VEA;&-H87)S*"D@8F5F;W)E(&)E:6YG(&]U='!U="X*
M("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?
M96YC;V1E5&ET;&4@/2!T<G5E.PH*("`@("\J*@H@("`@("H@5VED=&@@;V8@
M=&AE(&%T=')I8G5T97,@8V]L=6UN+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?
M871T<D-O;'5M;E=I9'1H(#T@)S$U)2<["@H@("`@+RHJ"B`@("`@*B!#;VYS
M=')U8W0@82!N97<@2&]R9&5?1F]R;5]296YD97)E<CHZ+@H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("!4:&ES(&ES(&$@:&%S:"!O9B!R
M96YD97)E<BUS<&5C:69I8R!P87)A;65T97)S+@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(%!O<W-I8FQE(&ME>7,Z/&-O9&4^"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@)W9A<G)E;F1E<F5R7V1R:79E<B<Z('-P96-I
M9FEE<R!T:&4@9')I=F5R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@('!A<F%M971E<B!T;R!(;W)D95]525]687)296YD97)E<CHZ9F%C=&]R
M>2@I+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("=E;F-O9&5?=&ET
M;&4G.B!`<V5E("1?96YC;V1E5&ET;&4\+V-O9&4^"B`@("`@*B\*("`@(&9U
M;F-T:6]N($AO<F1E7T9O<FU?4F5N9&5R97(H)'!A<F%M<R`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*("`@("`@("!I9B`H
M:7-S970H)')E9VES=')Y*2`F)B!I<U]A*"1R96=I<W1R>2P@)U)E9VES=')Y
M)RDI('L*("`@("`@("`@("`@+RH@4F5G:7-T<GD@879A:6QA8FQE+"!S;R!U
M<V4@82!P<F5T='D@:6UA9V4N("HO"B`@("`@("`@("`@("1T:&ES+3Y?<F5Q
M=6ER961-87)K97(@/2!(;W)D93HZ:6UG*"=R97%U:7)E9"YP;F<G+"`G*B<L
M("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`O*B!.;R!R96=I<W1R>2!A=F%I;&%B
M;&4L('5S92!S;VUE=&AI;F<@<&QA:6XN("HO"B`@("`@("`@("`@("1T:&ES
M+3Y?<F5Q=6ER961-87)K97(@/2`G*B<["B`@("`@("`@?0H*("`@("`@("!I
M9B`H:7-S970H)'!A<F%M<ULG96YC;V1E7W1I=&QE)UTI*2!["B`@("`@("`@
M("`@("1T:&ES+3YE;F-O9&54:71L92@D<&%R86US6R=E;F-O9&5?=&ET;&4G
M72D["B`@("`@("`@?0H*("`@("`@("`D9')I=F5R(#T@)VAT;6PG.PH@("`@
M("`@(&EF("AI<W-E="@D<&%R86US6R=V87)R96YD97)E<E]D<FEV97(G72DI
M('L*("`@("`@("`@("`@)&1R:79E<B`]("1P87)A;7-;)W9A<G)E;F1E<F5R
M7V1R:79E<B==.PH@("`@("`@('T*("`@("`@("!R97%U:7)E7V]N8V4@)TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+G!H<"<["B`@("`@("`@)'1H:7,M/E]V87)2
M96YD97)E<B`]("9(;W)D95]525]687)296YD97)E<CHZ9F%C=&]R>2@D9')I
M=F5R+"`D<&%R86US*3L*("`@('T*"B`@("!F=6YC=&EO;B!S:&]W2&5A9&5R
M*"1B;V]L*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<VAO=TAE861E<B`]("1B
M;V]L.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!O<B!R971U<FYS('=H
M971H97(@=&AE(&9O<FT@=&ET;&4@<VAO=6QD(&)E(&5N8V]D960@=VET:`H@
M("`@("H@:'1M;'-P96-I86QC:&%R<R@I+@H@("`@("H*("`@("`J($!P87)A
M;2!B;V]L96%N("1E;F-O9&4@($EF('1R=64L('1H92!F;W)M('1I=&QE(&=E
M=',@96YC;V1E9"X@($EF(&9A;'-E"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!T:&4@=&ET;&4@8V%N(&-O;G1A:6X@2%1-3"P@8G5T('1H92!C
M;&%S<R!U<V5R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!I<R!R
M97-P;VYS:6)L92!T;R!E;F-O9&4@86YY('-P96-I86P@8VAA<F%C=&5R<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@=&AE(&9O
M<FT@=&ET;&4@<VAO=6QD(&)E(&5N8V]D960N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&5N8V]D951I=&QE*"1E;F-O9&4@/2!N=6QL*0H@("`@>PH@("`@("`@
M(&EF("@A:7-?;G5L;"@D96YC;V1E*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7V5N8V]D951I=&QE(#T@)&5N8V]D93L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?96YC;V1E5&ET;&4@/2`D96YC;V1E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4W!E8VEF>2!T:&4@=VED=&@@;V8@=&AE(&%T=')I8G5T
M92!C;VQU;6X@:6X@=&AE(')E;F1E<F5D(&9O<FTN"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=VED=&@@(%1H92!W:61T:"!O9B!T:&4@871T<FEB
M=71E(&-O;'5M;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T071T<D-O;'5M;E=I9'1H*"1W:61T:"D*("`@
M('L*("`@("`@("`D=&AI<RT^7V%T=')#;VQU;6Y7:61T:"`]("1W:61T:#L*
M("`@('T*"B`@("!F=6YC=&EO;B!O<&5N*"1A8W1I;VXL("1M971H;V0L("1N
M86UE+"`D96YC='EP92`](&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M/E]N
M86UE(#T@)&YA;64["B`@("`@("`@)&YA;64@/2!H=&UL<W!E8VEA;&-H87)S
M*"1N86UE*3L*("`@("`@("!E8VAO("(\9F]R;2!A8W1I;VX]7"(D86-T:6]N
M7"(@;65T:&]D/5PB)&UE=&AO9%PB(B`N("AE;7!T>2@D;F%M92D@/R`G)R`Z
M("(@;F%M93U<(B1N86UE7"(@:60]7"(D;F%M95PB(BD@+B`H:7-?;G5L;"@D
M96YC='EP92D@/R`G)R`Z("(@96YC='EP93U<(B1E;F-T>7!E7"(B*2`N("(^
M7&XB.PH@("`@("`@(%5T:6PZ.G!F;W)M26YP=70H*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!B96=I;D%C=&EV92@D;F%M92P@)&5X=')A(#T@;G5L;"D*("`@
M('L*("`@("`@("`D=&AI<RT^7W)E;F1E<D)E9VEN06-T:79E*"1N86UE+"`D
M97AT<F$I.PH@("`@?0H*("`@(&9U;F-T:6]N(&)E9VEN26YA8W1I=F4H)&YA
M;64L("1E>'1R82`](&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M/E]R96YD
M97)"96=I;DEN86-T:79E*"1N86UE+"`D97AT<F$I.PH@("`@?0H*("`@(&9U
M;F-T:6]N(%]R96YD97)396-T:6]N5&%B<R@F)&9O<FTI"B`@("!["B`@("`@
M("`@+RH@268@:F%V87-C<FEP="!I<R!N;W0@879A:6QA8FQE+"!D;R!N;W0@
M<F5N9&5R('1A8G,N("HO"B`@("`@("`@:68@*"$D1TQ/0D%,4ULG8G)O=W-E
M<B==+3YH87-&96%T=7)E*"=J879A<V-R:7!T)RDI('L*("`@("`@("`@("`@
M<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)&]P96Y?<V5C=&EO;B`]("1F
M;W)M+3YG971/<&5N4V5C=&EO;B@I.PH*("`@("`@("`O*B!!9&0@=&AE(&IA
M=F%S8W)I<'0@9F]R('1H92!T;V=G;&EN9R!T:&4@<V5C=&EO;G,N("HO"B`@
M("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)V9O<FU?<V5C=&EO;G,N:G,G
M+"`G:&]R9&4G+"!T<G5E*3L*("`@("`@("!E8VAO("<\<V-R:7!T('1Y<&4]
M(G1E>'0O:F%V87-C<FEP="(^)R`N(")<;B(["B`@("`@("`@<')I;G1F*"=V
M87(@<V5C=&EO;G-?)3$D<R`](&YE=R!(;W)D95]&;W)M7U-E8W1I;VYS*%PG
M)3$D<UPG+"!<)R4R)'-<)RD[)RP*("`@("`@("`@("`@("`@)&9O<FTM/F=E
M=$YA;64H*2P*("`@("`@("`@("`@("`@)&]P96Y?<V5C=&EO;BD["B`@("`@
M("`@96-H;R`B7&XB("X@)SPO<V-R:7!T/B<["@H@("`@("`@("\J($QO;W`@
M=&AR;W5G:"!T:&4@<V5C=&EO;G,@86YD('!R:6YT(&]U="!A('1A8B!F;W(@
M96%C:"X@*B\*("`@("`@("!E8VAO("(\9&EV(&-L87-S/5PB=&%B<V5T7"(^
M/'5L/EQN(CL*("`@("`@("!F;W)E86-H("@D9F]R;2T^7W-E8W1I;VYS(&%S
M("1S96-T:6]N(#T^("1V86PI('L*("`@("`@("`@("`@)&-L87-S(#T@*"1S
M96-T:6]N(#T]("1O<&5N7W-E8W1I;VXI(#\@)R!C;&%S<STB86-T:79E5&%B
M(B<@.B`G)SL*("`@("`@("`@("`@)&IS(#T@<W!R:6YT9B@G;VYC;&EC:STB
M<V5C=&EO;G-?)7,N=&]G9VQE*%PG)7-<)RD[(')E='5R;B!F86QS93LB)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R;2T^9V5T3F%M92@I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("1S96-T:6]N*3L*("`@("`@("`@
M("`@<')I;G1F*"<\;&DE<R!I9#TB)7,B/CQA(&AR968](B,B("5S/B5S)7,\
M+V$^(#PO;&D^)R`N(")<;B(L"B`@("`@("`@("`@("`@("`@("`D8VQA<W,L
M("=?=&%B7R<@+B`D<V5C=&EO;BP@)&IS+`H@("`@("`@("`@("`@("`@("`@
M)&9O<FTM/F=E=%-E8W1I;VY);6%G92@D<V5C=&EO;BDL"B`@("`@("`@("`@
M("`@("`@("`D9F]R;2T^9V5T4V5C=&EO;D1E<V,H)'-E8W1I;VXI*3L*("`@
M("`@("!]"B`@("`@("`@96-H;R`B/"]U;#X\+V1I=CX\8G(@8VQA<W,]7")C
M;&5A<EPB("\^7&XB.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)396-T
M:6]N0F5G:6XH)B1F;W)M+"`D<V5C=&EO;BD*("`@('L*("`@("`@("`O+R!3
M=')I<&4@86QT97)N871E(')O=W,@:68@=&AA="!O<'1I;VX@:7,@='5R;F5D
M(&]N+@H@("`@("`@(&EF("@D=&AI<RT^7W-T<FEP9612;W=S*2!["B`@("`@
M("`@("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"=S=')I<&4N:G,G+"`G:&]R
M9&4G+"!T<G5E*3L*("`@("`@("`@("`@)&-L87-S(#T@)R!C;&%S<STB<W1R
M:7!E9"(G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C;&%S<R`]
M("<G.PH@("`@("`@('T*"B`@("`@("`@)&]P96Y?<V5C=&EO;B`]("1F;W)M
M+3YG971/<&5N4V5C=&EO;B@I.PH@("`@("`@(&EF("AE;7!T>2@D;W!E;E]S
M96-T:6]N*2D@>PH@("`@("`@("`@("`D;W!E;E]S96-T:6]N(#T@)U]?8F%S
M92<["B`@("`@("`@?0H@("`@("`@('!R:6YT9B@G/&1I=B!I9#TB)7,B('-T
M>6QE/2)D:7-P;&%Y.B5S.R(^/'1A8FQE)7,@8V5L;'-P86-I;F<](C`B/B<L
M"B`@("`@("`@("`@("`@("=?<V5C=&EO;E\G("X@)'-E8W1I;VXL"B`@("`@
M("`@("`@("`@("@D;W!E;E]S96-T:6]N(#T]("1S96-T:6]N(#\@)V)L;V-K
M)R`Z("=N;VYE)RDL"B`@("`@("`@("`@("`@("1C;&%S<RD["B`@("!]"@H@
M("`@9G5N8W1I;VX@7W)E;F1E<E-E8W1I;VY%;F0H*0H@("`@>PH@("`@("`@
M(&5C:&\@)SPO=&%B;&4^/"]D:78^)SL*("`@('T*"B`@("!F=6YC=&EO;B!E
M;F0H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<F5N9&5R16YD*"D["B`@("!]
M"@H@("`@9G5N8W1I;VX@8VQO<V4H)&9O8W5S(#T@=')U92D*("`@('L*("`@
M("`@("!E8VAO("(\+V9O<FT^7&XB.PH@("`@("`@(&EF("@D9F]C=7,@)B8@
M(65M<'1Y*"1T:&ES+3Y?9FER<W1&:65L9"DI('L*("`@("`@("`@("`@96-H
M;R`G/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"G1R>2![
M"B`@("!D;V-U;65N="YG971%;&5M96YT0GE)9"@B)R`N("1T:&ES+3Y?9FER
M<W1&:65L9"`N("<B*2YF;V-U<R@I.PI](&-A=&-H*&4I('M]"B\O+2T^"CPO
M<V-R:7!T/@HG.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!L:7-T
M1F]R;59A<G,H)B1F;W)M*0H@("`@>PH@("`@("`@("1V87)I86)L97,@/2`F
M)&9O<FTM/F=E=%9A<FEA8FQE<RAT<G5E+"!T<G5E*3L*("`@("`@("`D=F%R
M<R`](&%R<F%Y*"D["B`@("`@("`@:68@*"1V87)I86)L97,I('L*("`@("`@
M("`@("`@9F]R96%C:"`H)'9A<FEA8FQE<R!A<R`D=F%R*2!["B`@("`@("`@
M("`@("`@("!I9B`H:7-?;V)J96-T*"1V87(I*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*"$D=F%R+3YI<U)E861O;FQY*"DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'9A<G-;)'9A<BT^9V5T5F%R3F%M92@I72`](#$["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`D=F%R<ULD=F%R72`](#$["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5Q
M=6ER95]O;F-E("=(;W)D92].3%,N<&AP)SL*("`@("`@("!E8VAO("<\:6YP
M=70@='EP93TB:&ED9&5N(B!N86UE/2)?9F]R;79A<G,B('9A;'5E/2(G("X@
M0&AT;6QS<&5C:6%L8VAA<G,H<V5R:6%L:7IE*"1V87)S*2P@14Y47U%53U1%
M4RP@3DQ3.CIG971#:&%R<V5T*"DI("X@)R(@+SXG.PH@("`@?0H*("`@(&9U
M;F-T:6]N(')E;F1E<D9O<FU!8W1I=F4H)B1F;W)M+"`F)'9A<G,I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]R96YD97)&;W)M*"1F;W)M+"`D=F%R<RP@=')U
M92D["B`@("!]"@H@("`@9G5N8W1I;VX@<F5N9&5R1F]R;4EN86-T:79E*"8D
M9F]R;2P@)B1V87)S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<F5N9&5R1F]R
M;2@D9F]R;2P@)'9A<G,L(&9A;'-E*3L*("`@('T*"B`@("!F=6YC=&EO;B!?
M<F5N9&5R1F]R;2@F)&9O<FTL("8D=F%R<RP@)&%C=&EV92D*("`@('L*("`@
M("`@("`O*B!)9B!H96QP(&ES('!R97-E;G0@,R!C;VQU;6YS(&%R92!N965D
M960N("HO"B`@("`@("`@)'1H:7,M/E]C;VQS(#T@)&9O<FTM/FAA<TAE;'`H
M*2`_(#,@.B`R.PH*("`@("`@("`D=F%R:6%B;&5S(#T@)B1F;W)M+3YG9716
M87)I86)L97,H9F%L<V4I.PH*("`@("`@("`O*B!#:&5C:R!F;W(@82!F;W)M
M('1O:V5N(&5R<F]R+B`J+PH@("`@("`@(&EF("@H)'1O:V5N17)R;W(@/2`D
M9F]R;2T^9V5T17)R;W(H)U]?9F]R;51O:V5N)RDI("$]/2!N=6QL*2!["B`@
M("`@("`@("`@('!R:6YT9B@G/'1R('9A;&EG;CTB=&]P(CX\=&0@8V]L<W!A
M;CTB)60B/CQS<&%N(&-L87-S/2)F;W)M+65R<F]R(CXE<SPO<W!A;CX\+W1D
M/CPO='(^)RP*("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]L<RP*("`@
M("`@("`@("`@("`@("`@("1T;VME;D5R<F]R*3L*("`@("`@("!]"@H@("`@
M("`@("1E<G)O<E]S96-T:6]N(#T@;G5L;#L*("`@("`@("!R97-E="@D=F%R
M:6%B;&5S*3L*("`@("`@("!I9B`H8V]U;G0H)'9A<FEA8FQE<RD@/B`Q('Q\
M(&ME>2@D=F%R:6%B;&5S*2`A/2`G7U]B87-E)RD@>PH@("`@("`@("`@("`D
M=&AI<RT^7W)E;F1E<E-E8W1I;VY486)S*"1F;W)M*3L*("`@("`@("!]"@H@
M("`@("`@(&9O<F5A8V@@*"1V87)I86)L97,@87,@)'-E8W1I;VY?:60@/3X@
M)'-E8W1I;VXI('L*("`@("`@("`@("`@)'1H:7,M/E]R96YD97)396-T:6]N
M0F5G:6XH)&9O<FTL("1S96-T:6]N7VED*3L*("`@("`@("`@("`@9F]R96%C
M:"`H)'-E8W1I;VX@87,@)'9A<BD@>PH@("`@("`@("`@("`@("`@)'1Y<&4@
M/2`D=F%R+3YG9714>7!E3F%M92@I.PH*("`@("`@("`@("`@("`@('-W:71C
M:"`H)'1Y<&4I('L*("`@("`@("`@("`@("`@(&-A<V4@)VAE861E<B<Z"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96YD97)(96%D97(H)'9A<BT^
M9V5T2'5M86Y.86UE*"DL("1F;W)M+3YG971%<G)O<B@D=F%R+3YG971687).
M86UE*"DI*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("`@("!C87-E("=D97-C<FEP=&EO;B<Z"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]R96YD97)$97-C<FEP=&EO;B@D=F%R+3YG971(=6UA;DYA
M;64H*2D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("`@("`@8V%S92`G<W!A8V5R)SH*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W)E;F1E<E-P86-E<B@I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@
M("`@)&ES26YP=70@/2`H)&%C=&EV92`F)B`A)'9A<BT^:7-296%D;VYL>2@I
M*3L*("`@("`@("`@("`@("`@("`@("`D9F]R;6%T(#T@)&ES26YP=70@/R`G
M26YP=70G(#H@)T1I<W!L87DG.PH@("`@("`@("`@("`@("`@("`@("1B96=I
M;B`](")?<F5N9&5R5F%R)'MF;W)M871]0F5G:6XB.PH@("`@("`@("`@("`@
M("`@("`@("1E;F0@/2`B7W)E;F1E<E9A<B1[9F]R;6%T?45N9"(["@H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3XD8F5G:6XH)&9O<FTL("1V87(L("1V
M87)S*3L*"B`@("`@("`@("`@("`@("`@("`@96-H;R`D=&AI<RT^7W9A<E)E
M;F1E<F5R+3YR96YD97(H)&9O<FTL("1V87(L("1V87)S+"`D:7-);G!U="D[
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/B1E;F0H)&9O<FTL("1V87(L
M("1V87)S*3L*"B`@("`@("`@("`@("`@("`@("`@+RH@4')I;G0@86YY(&IA
M=F%S8W)I<'0@:68@86-T:6]N<R!P<F5S96YT+B`J+PH@("`@("`@("`@("`@
M("`@("`@(&EF("@D=F%R+3YH87-!8W1I;VXH*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=F%R+3Y?86-T:6]N+3YP<FEN=$IA=F%38W)I<'0H*3L*
M("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@("\J
M($ME97`@9FER<W0@9FEE;&0N("HO"B`@("`@("`@("`@("`@("`@("`@:68@
M*"1A8W1I=F4@)B8@96UP='DH)'1H:7,M/E]F:7)S=$9I96QD*2`F)B`A)'9A
M<BT^:7-296%D;VYL>2@I("8F("$D=F%R+3YI<TAI9&1E;B@I*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9FER<W1&:65L9"`]("1V87(M
M/F=E=%9A<DYA;64H*3L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@("`@("\J($ME97`@<V5C=&EO;B!W:71H(&9I<G-T(&5R<F]R
M+B`J+PH@("`@("`@("`@("`@("`@("`@(&EF("AI<U]N=6QL*"1E<G)O<E]S
M96-T:6]N*2`F)B`D9F]R;2T^9V5T17)R;W(H)'9A<BDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&5R<F]R7W-E8W1I;VX@/2`D<V5C=&EO;E]I9#L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?<F5N9&5R4V5C=&EO;D5N
M9"@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<U]N=6QL*"1E<G)O<E]S
M96-T:6]N*2`F)B`D9F]R;2T^7W-E8W1I;VYS*2!["B`@("`@("`@("`@(&5C
M:&\@)SQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CXG("X*("`@("`@
M("`@("`@("`@(")<;B(@+B!S<')I;G1F*"=S96-T:6]N<U\E<RYT;V=G;&4H
M7"<E<UPG*3LG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O
M<FTM/F=E=$YA;64H*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1E<G)O<E]S96-T:6]N*2`N"B`@("`@("`@("`@("`@("`B7&X\+W-C<FEP
M=#XB.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!S=6)M:70H)'-U
M8FUI="`](&YU;&PL("1R97-E="`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF
M("AI<U]N=6QL*"1S=6)M:70I('Q\(&5M<'1Y*"1S=6)M:70I*2!["B`@("`@
M("`@("`@("1S=6)M:70@/2!?*")3=6)M:70B*3L*("`@("`@("!]"B`@("`@
M("`@:68@*"1R97-E="`]/3T@=')U92D@>PH@("`@("`@("`@("`D<F5S970@
M/2!?*")297-E="(I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7W)E;F1E
M<E-U8FUI="@D<W5B;6ET+"`D<F5S970I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@26UP;&5M96YT871I;VX@<W!E8VEF:6,@8F5G:6X@9G5N8W1I;VXN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]R96YD97)"96=I;D%C=&EV92@D;F%M92P@
M)&5X=')A*0H@("`@>PH@("`@("`@(&5C:&\@)SQD:78@8VQA<W,](F9O<FTB
M(&ED/2(G("X@:'1M;'-P96-I86QC:&%R<R@D=&AI<RT^7VYA;64I("X@)R(^
M)SL*("`@("`@("!I9B`H)'1H:7,M/E]S:&]W2&5A9&5R*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?<V5C=&EO;DAE861E<B@D;F%M92P@)&5X=')A*3L*("`@
M("`@("!]"B`@("`@("`@:68@*"1T:&ES+3Y?<F5Q=6ER961,96=E;F0I('L*
M("`@("`@("`@("`@96-H;R`G/'-P86X@8VQA<W,](F9O<FTM97)R;W(B/B<@
M+B`D=&AI<RT^7W)E<75I<F5D36%R:V5R("X@)SPO<W!A;CX@/2`G("X@7R@B
M4F5Q=6ER960@1FEE;&0B*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!);7!L96UE;G1A=&EO;B!S<&5C:69I8R!B96=I;B!F=6YC=&EO;BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@7W)E;F1E<D)E9VEN26YA8W1I=F4H)&YA
M;64L("1E>'1R82D*("`@('L*("`@("`@("!E8VAO("<\9&EV(&-L87-S/2)F
M;W)M(B!I9#TB)R`N(&AT;6QS<&5C:6%L8VAA<G,H)'1H:7,M/E]N86UE*2`N
M("<B/B<["B`@("`@("`@:68@*"1T:&ES+3Y?<VAO=TAE861E<BD@>PH@("`@
M("`@("`@("`D=&AI<RT^7W-E8W1I;VY(96%D97(H)&YA;64L("1E>'1R82D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@26UP;&5M96YT871I
M;VX@<W!E8VEF:6,@96YD(&9U;F-T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?<F5N9&5R16YD*"D*("`@('L*("`@("`@("!E8VAO("<\+V1I=CXG("X@
M)'1H:7,M/E]V87)296YD97)E<BT^<F5N9&5R16YD*"D["B`@("!]"@H@("`@
M9G5N8W1I;VX@7W)E;F1E<DAE861E<B@D:&5A9&5R+"`D97)R;W(@/2`G)RD*
M("`@('L*/SX\='(^/'1D(&-L87-S/2)C;VYT<F]L(B!W:61T:#TB,3`P)2(@
M8V]L<W!A;CTB/#]P:'`@96-H;R`D=&AI<RT^7V-O;',@/SXB('9A;&EG;CTB
M8F]T=&]M(CX\<W1R;VYG/CP_<&AP(&5C:&\@)&AE861E<B`_/CPO<W1R;VYG
M/CP_<&AP"B`@("`@("`@:68@*"%E;7!T>2@D97)R;W(I*2!["C\^/&)R("\^
M/'-P86X@8VQA<W,](F9O<FTM97)R;W(B/CP_<&AP(&5C:&\@)&5R<F]R(#\^
M/"]S<&%N/CP_<&AP"B`@("`@("`@?0H_/CPO=&0^/"]T<CX*/#]P:'`*("`@
M('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R1&5S8W)I<'1I;VXH)'1E>'0I"B`@
M("!["C\^/'1R/CQT9"!W:61T:#TB,3`P)2(@8V]L<W!A;CTB/#]P:'`@96-H
M;R`D=&AI<RT^7V-O;',@/SXB/CQP('-T>6QE/2)P861D:6YG.CAP>"(^/#]P
M:'`@96-H;R`D=&5X="`_/CPO<#X\+W1D/CPO='(^"CP_<&AP"B`@("!]"@H@
M("`@9G5N8W1I;VX@7W)E;F1E<E-P86-E<B@I"B`@("!["C\^/'1R/CQT9"!C
M;VQS<&%N/2(\/W!H<"!E8VAO("1T:&ES+3Y?8V]L<R`_/B(^)FYB<W`[/"]T
M9#X\+W1R/@H\/W!H<`H@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)3=6)M
M:70H)'-U8FUI="P@)')E<V5T*0H@("`@>PH_/CQD:78@8VQA<W,](F-O;G1R
M;VPB/@H@(#P_<&AP(&EF("@A:7-?87)R87DH)'-U8FUI="DI("1S=6)M:70@
M/2!A<G)A>2@D<W5B;6ET*3L@9F]R96%C:"`H)'-U8FUI="!A<R`D<W5B;6ET
M8G5T=&]N*3H@/SX*("`@(#QI;G!U="!C;&%S<STB8G5T=&]N(B!N86UE/2)S
M=6)M:71B=71T;VXB('1Y<&4](G-U8FUI="(@=F%L=64](CP_<&AP(&5C:&\@
M)'-U8FUI=&)U='1O;B`_/B(@+SX*("`\/W!H<"!E;F1F;W)E86-H.R`_/@H@
M(#P_<&AP(&EF("@A96UP='DH)')E<V5T*2DZ(#\^"B`@("`\:6YP=70@8VQA
M<W,](F)U='1O;B(@;F%M93TB<F5S971B=71T;VXB('1Y<&4](G)E<V5T(B!V
M86QU93TB/#]P:'`@96-H;R`D<F5S970@/SXB("\^"B`@/#]P:'`@96YD:68[
M(#\^"CPO9&EV/@H\/W!H<`H@("`@?0H*("`@("\O($EM<&QE;65N=&%T:6]N
M('-P96-I9FEC<R`M+2!I;G!U="!V87)I86)L97,N"B`@("!F=6YC=&EO;B!?
M<F5N9&5R5F%R26YP=71"96=I;B@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@
M("!["B`@("`@("`@)&UE<W-A9V4@/2`D9F]R;2T^9V5T17)R;W(H)'9A<BD[
M"B`@("`@("`@)&ES=F%L:60@/2!E;7!T>2@D;65S<V%G92D["B`@("`@("`@
M96-H;R`B/'1R('9A;&EG;CU<(G1O<%PB/EQN(CL*("`@("`@("!P<FEN=&8H
M)R`@/'1D)7,@86QI9VX](G)I9VAT(CXE<R5S)7,E<SPO=&0^)R`N(")<;B(L
M"B`@("`@("`@("`@("`@(&5M<'1Y*"1T:&ES+3Y?871T<D-O;'5M;E=I9'1H
M*2`_("<G(#H@)R!W:61T:#TB)R`N("1T:&ES+3Y?871T<D-O;'5M;E=I9'1H
M("X@)R(G+`H@("`@("`@("`@("`@("`D:7-V86QI9"`_("<G(#H@)SQS<&%N
M(&-L87-S/2)F;W)M+65R<F]R(CXG+`H@("`@("`@("`@("`@("`D=F%R+3YI
M<U)E<75I<F5D*"D@/R`G/'-P86X@8VQA<W,](F9O<FTM97)R;W(B/B<@+B`D
M=&AI<RT^7W)E<75I<F5D36%R:V5R("X@)SPO<W!A;CXF;F)S<#LG(#H@)R<L
M"B`@("`@("`@("`@("`@("1V87(M/F=E=$AU;6%N3F%M92@I+`H@("`@("`@
M("`@("`@("`D:7-V86QI9"`_("<G(#H@)SQB<B`O/B<@+B`D;65S<V%G92`N
M("<\+W-P86X^)RD["B`@("`@("`@<')I;G1F*"<@(#QT9"5S/B<L"B`@("`@
M("`@("`@("`@("@H(21V87(M/FAA<TAE;'`H*2`F)B`D9F]R;2T^:&%S2&5L
M<"@I*2`_("<@8V]L<W!A;CTB,B(G(#H@)R<I*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!?<F5N9&5R5F%R26YP=71%;F0H)B1F;W)M+"`F)'9A<BP@)B1V87)S
M*0H@("`@>PH@("`@("`@("\J($1I<W!L87D@86YY(&1E<V-R:7!T:6]N(&9O
M<B!T:&4@9FEE;&0N("HO"B`@("`@("`@:68@*"1V87(M/FAA<T1E<V-R:7!T
M:6]N*"DI('L*("`@("`@("`@("`@96-H;R`G/&)R("\^)R`N("1V87(M/F=E
M=$1E<V-R:7!T:6]N*"D["B`@("`@("`@?0H*("`@("`@("`O*B!$:7-P;&%Y
M(&%N>2!H96QP(&9O<B!T:&4@9FEE;&0N("HO"B`@("`@("`@:68@*"1V87(M
M/FAA<TAE;'`H*2D@>PH@("`@("`@("`@("!G;&]B86P@)')E9VES=')Y.PH@
M("`@("`@("`@("!I9B`H:7-S970H)')E9VES=')Y*2`F)B!I<U]A*"1R96=I
M<W1R>2P@)U)E9VES=')Y)RDI('L*("`@("`@("`@("`@("`@("1L:6YK(#T@
M2&5L<#HZ;&EN:R@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T07!P*"DL("1V
M87(M/F=E=$AE;'`H*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D;&EN:R`]("<\82!H<F5F/2(C(B!O;F-L:6-K/2)A;&5R="A<
M)R<@+B!A9&1S;&%S:&5S*$!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=$AE
M;'`H*2DI("X@)UPG*3MR971U<FX@9F%L<V4[(CXG("X@)'1H:7,M/E]H96QP
M36%R:V5R("X@)SPO83XG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5C
M:&\@(CPO=&0^7&X@(#QT9"!S='EL93U<(G1E>'0M86QI9VXZ<FEG:'1<(CXD
M;&EN:R9N8G-P.R(["B`@("`@("`@?0H*("`@("`@("!E8VAO("(\+W1D/EQN
M/"]T<CY<;B(["B`@("!]"@H@("`@+R\@26UP;&5M96YT871I;VX@<W!E8VEF
M:6-S("TM(&1I<W!L87D@=F%R:6%B;&5S+@H@("`@9G5N8W1I;VX@7W)E;F1E
M<E9A<D1I<W!L87E"96=I;B@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("![
M"B`@("`@("`@)&UE<W-A9V4@/2`D9F]R;2T^9V5T17)R;W(H)'9A<BD["B`@
M("`@("`@)&ES=F%L:60@/2!E;7!T>2@D;65S<V%G92D["B`@("`@("`@96-H
M;R`B/'1R('9A;&EG;CU<(G1O<%PB/EQN(CL*("`@("`@("!P<FEN=&8H)R`@
M/'1D)7,@86QI9VX](G)I9VAT(CXE<SQS=')O;F<^)7,\+W-T<F]N9SXE<SPO
M=&0^)R`N(")<;B(L"B`@("`@("`@("`@("`@(&5M<'1Y*"1T:&ES+3Y?871T
M<D-O;'5M;E=I9'1H*2`_("<G(#H@)R!W:61T:#TB)R`N("1T:&ES+3Y?871T
M<D-O;'5M;E=I9'1H("X@)R(G+`H@("`@("`@("`@("`@("`D:7-V86QI9"`_
M("<G(#H@)SQS<&%N(&-L87-S/2)F;W)M+65R<F]R(CXG+`H@("`@("`@("`@
M("`@("`D=F%R+3YG971(=6UA;DYA;64H*2P*("`@("`@("`@("`@("`@)&ES
M=F%L:60@/R`G)R`Z("<\8G(@+SXG("X@)&UE<W-A9V4@+B`G/"]S<&%N/B<I
M.PH@("`@("`@(&5C:&\@)R`@/'1D/B<["B`@("!]"@H@("`@9G5N8W1I;VX@
M7W)E;F1E<E9A<D1I<W!L87E%;F0H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@
M("`@>PH@("`@("`@(&5C:&\@(CPO=&0^7&X\+W1R/EQN(CL*("`@('T*"B`@
M("!F=6YC=&EO;B!?<V5C=&EO;DAE861E<B@D=&ET;&4L("1E>'1R82`]("<G
M*0H@("`@>PH@("`@("`@(&EF("AS=')L96XH)'1I=&QE*2D@>PH@("`@("`@
M("`@("!E8VAO("<\9&EV(&-L87-S/2)H96%D97(B/B<["B`@("`@("`@("`@
M(&EF("@A96UP='DH)&5X=')A*2D@>PH@("`@("`@("`@("`@("`@96-H;R`G
M/'-P86X@<W1Y;&4](F9L;V%T.G)I9VAT(CXG("X@)&5X=')A("X@)SPO<W!A
M;CXG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5C:&\@)'1H:7,M/E]E
M;F-O9&54:71L92`_(&AT;6QS<&5C:6%L8VAA<G,H)'1I=&QE*2`Z("1T:71L
M93L*("`@("`@("`@("`@96-H;R`G/"]D:78^)SL*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T
M92!(;W)D95]&;W)M7U)E;F1E<F5R(&EN<W1A;F-E(&)A<V5D(&]N"B`@("`@
M*B`D<F5N9&5R97(N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1R96YD
M97)E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?1F]R;5]296YD97)E
M<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<W5B8VQA<W,@=&\@
M<F5T=7)N+B!4:&4@8V]D92!I<R!D>6YA;6EC86QL>0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@:6YC;'5D960N($EF("1R96YD97)E<B!I<R!A
M;B!A<G)A>2P@=&AE;B!W92!W:6QL"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!L;V]K(&EN("1R96YD97)E<ELP72]L:6(O1F]R;2]296YD97)E
M<B\@9F]R('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<W5B
M8VQA<W,@:6UP;&5M96YT871I;VX@;F%M960@)')E;F1E<F5R6S%=+G!H<"X*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@($$@:&%S:"!C;VYT86EN
M:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@80H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@9F]R;2!M:6=H="!N965D+@H@("`@("H*
M("`@("`J($!R971U<FX@2&]R9&5?1F]R;5]296YD97)E<B`@5&AE(&-O;F-R
M971E($AO<F1E7T9O<FU?4F5N9&5R97(@<F5F97)E;F-E+`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!O<B!F86QS92!O;B!A;B!E<G)O
M<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)')E;F1E<F5R+"`D
M<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)')E
M;F1E<F5R*2D@>PH@("`@("`@("`@("`D87!P(#T@)')E;F1E<F5R6S!=.PH@
M("`@("`@("`@("`D<F5N9&5R97(@/2`D<F5N9&5R97);,5T["B`@("`@("`@
M?0H*("`@("`@("`O*B!2971U<FX@82!B87-E($AO<F1E7T9O<FU?4F5N9&5R
M97(@;V)J96-T(&EF(&YO(&1R:79E<B!I<PH@("`@("`@("`J('-P96-I9FEE
M9"X@*B\*("`@("`@("`D<F5N9&5R97(@/2!B87-E;F%M92@D<F5N9&5R97(I
M.PH@("`@("`@(&EF("AE;7!T>2@D<F5N9&5R97(I('Q\("AS=')C;7`H)')E
M;F1E<F5R+"`G;F]N92<I(#T](#`I*2!["B`@("`@("`@("`@("1F;W)M<F5N
M9&5R97(@/2`F;F5W($AO<F1E7T9O<FU?4F5N9&5R97(H)'!A<F%M<RD["B`@
M("`@("`@("`@(')E='5R;B`D9F]R;7)E;F1E<F5R.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"%E;7!T>2@D87!P*2D@>PH@("`@("`@("`@("!I;F-L=61E
M7V]N8V4@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G9FEL97)O;W0G+"`D
M87!P*2`N("<O;&EB+T9O<FTO4F5N9&5R97(O)R`N("1R96YD97)E<B`N("<N
M<&AP)SL*("`@("`@("!](&5L<V5I9B`H0&9I;&5?97AI<W1S*&1I<FYA;64H
M7U]&24Q%7U\I("X@)R]296YD97)E<B\G("X@)')E;F1E<F5R("X@)RYP:'`G
M*2D@>PH@("`@("`@("`@("!I;F-L=61E7V]N8V4@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+U)E;F1E<F5R+R<@+B`D<F5N9&5R97(@+B`G+G!H<"<["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@0&EN8VQU9&5?;VYC92`G2&]R9&4O
M1F]R;2]296YD97)E<B\G("X@)')E;F1E<F5R("X@)RYP:'`G.PH@("`@("`@
M('T*("`@("`@("`D8VQA<W,@/2`G2&]R9&5?1F]R;5]296YD97)E<E\G("X@
M)')E;F1E<F5R.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@
M>PH@("`@("`@("`@("`D9F]R;7)E;F1E<F5R(#T@)FYE=R`D8VQA<W,H)'!A
M<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&9O<FUR96YD
M97)E<B`](%!%05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I;VX@;V8@
M)R`N("1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1F;W)M<F5N9&5R97(["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E<F5N8V4@=&\@82!C;VYC<F5T
M92!(;W)D95]&;W)M7U)E;F1E<F5R"B`@("`@*B!I;G-T86YC92!B87-E9"!O
M;B`D<F5N9&5R97(N($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N
M8V4@:68@;F\*("`@("`J($AO<F1E7T9O<FU?4F5N9&5R97(@:6YS=&%N8V4@
M=VET:"!T:&4@<V%M92!P87)A;65T97)S(&-U<G)E;G1L>2!E>&ES=',N"B`@
M("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E9"!I9B!M=6QT:7!L92!T
M>7!E<R!O9B!F;W)M(')E;F1E<F5R<R`H86YD+`H@("`@("H@=&AU<RP@;75L
M=&EP;&4@2&]R9&5?1F]R;5]296YD97)E<B!I;G-T86YC97,I(&%R92!R97%U
M:7)E9"X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K
M960@87,Z("1V87(@/2`F2&]R9&5?1F]R;5]296YD97)E<CHZ<VEN9VQE=&]N
M*"D*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)')E;F1E<F5R("!4:&4@
M='EP92!O9B!C;VYC<F5T92!(;W)D95]&;W)M7U)E;F1E<F5R"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!S=6)C;&%S<R!T;R!R971U<FXN(%1H
M92!C;V1E(&ES(&1Y;F%M:6-A;&QY"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!I;F-L=61E9"X@268@)')E;F1E<F5R(&ES(&%N(&%R<F%Y+"!T
M:&5N('=E('=I;&P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&QO
M;VL@:6X@)')E;F1E<F5R6S!=+VQI8B]&;W)M+U)E;F1E<F5R+R!F;W(@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!S=6)C;&%S<R!I;7!L
M96UE;G1A=&EO;B!N86UE9"`D<F5N9&5R97);,5TN<&AP+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I
M=&EO;F%L(&-O;F9I9W5R871I;VX@80H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@(&9O<FT@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M($AO<F1E7T9O<FU?4F5N9&5R97(@(%1H92!C;VYC<F5T92!(;W)D95]&;W)M
M7U)E;F1E<F5R(')E9F5R96YC92P*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@;W(@9F%L<V4@;VX@86X@97)R;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9S:6YG;&5T;VXH)')E;F1E<F5R+"`D<&%R86US(#T@;G5L
M;"D*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<SL*("`@("`@("!I
M9B`H(6ES<V5T*"1I;G-T86YC97,I*2!["B`@("`@("`@("`@("1I;G-T86YC
M97,@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]
M('-E<FEA;&EZ92AA<G)A>2@D<F5N9&5R97(L("1P87)A;7,I*3L*("`@("`@
M("!I9B`H(6ES<V5T*"1I;G-T86YC97-;)'-I9VYA='5R95TI*2!["B`@("`@
M("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@/2`F2&]R9&5?1F]R;5]2
M96YD97)E<CHZ9F%C=&]R>2@D<F5N9&5R97(L("1P87)A;7,I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O1F]R;2]4>7!E+P``````````````````````
M`````````````````````````````````````````````````#`P,#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S0W`#`R,3,Q
M-``@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]&;W)M+U1Y<&4O
M=&%B;&5S970N<&AP````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(V,S(`
M,3`U,34T,S,W-#<`,#(S-C,S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+T9O
M<FTN<&AP)SL*"B\J*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]&;W)M+T9O<FTO
M5'EP92]T86)L97-E="YP:'`L=B`Q+C,N,BXQ(#(P,#4O,3`O,3@@,3$Z,#$Z
M,#@@:F%N($5X<"`D"B`J"B`J($!P86-K86=E($AO<F1E7T9O<FT*("H@0'-I
M;F-E("`@2&]R9&4@,RXQ"B`J+PIC;&%S<R!(;W)D95]&;W)M7U1Y<&5?=&%B
M;&5S970@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@('9A<B`D7W9A
M;'5E<SL*("`@('9A<B`D7VAE861E<CL*"B`@("!F=6YC=&EO;B!I;FET*"1V
M86QU97,L("1H96%D97(I"B`@("!["B`@("`@("`@)'1H:7,M/E]V86QU97,@
M/2`D=F%L=65S.PH@("`@("`@("1T:&ES+3Y?:&5A9&5R(#T@)&AE861E<CL*
M("`@('T*"B`@("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V
M86QU92P@)B1M97-S86=E*0H@("`@>PH@("`@("`@(&EF("AC;W5N="@D=&AI
M<RT^7W9A;'5E<RD@/3T@,"!\?"!C;W5N="@D=F%L=64I(#T](#`I('L*("`@
M("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H@("`@("`@(&9O<F5A
M8V@@*"1V86QU92!A<R`D:71E;2D@>PH@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?=F%L=65S6R1I=&5M72DI('L*("`@("`@("`@("`@("`@("1E
M<G)O<B`]('1R=64["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1E<G)O<BDI('L*
M("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`D
M;65S<V%G92`](%\H(DEN=F%L:60@9&%T82!S=6)M:71T960N(BD["B`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$AE861E
M<B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?:&5A9&5R.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&=E=%9A;'5E<R@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?=F%L=65S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@86)O=70H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@*("`@("`@
M("`@("`@)VYA;64G(#T^(%\H(E1A8FQE(%-E="(I+`H@("`@("`@("`@("`G
M<&%R86US)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("=V86QU97,G(#T^
M(&%R<F%Y*"=L86)E;"<@/3X@7R@B5F%L=65S(BDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=S=')I;F=L:7-T)RDL
M"B`@("`@("`@("`@("`@("`G:&5A9&5R)R`]/B!A<G)A>2@G;&%B96PG(#T^
M(%\H(DAE861E<G,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=T>7!E)R`@/3X@)W-T<FEN9VQI<W0G*2DL"B`@("`@("`@("`@("D[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+T9O<FTN<&AP````````````````````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#,R-#8U,@`Q,#4Q-30S,S<U,@`P,C$Q,30`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J($AO<F1E7T9O<FT@36%S=&5R($-L87-S+@H@*@H@*B!4:&4@2&]R
M9&5?1F]R;3HZ('!A8VMA9V4@<')O=FED97,@9F]R;2!R96YD97)I;F<L('9A
M;&ED871I;VXL(&%N9`H@*B!O=&AE<B!F=6YC=&EO;F%L:71Y(&9O<B!T:&4@
M2&]R9&4@07!P;&EC871I;VX@1G)A;65W;W)K+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP+'8@,2XS,#8N,BXT."`R,#`V+S`T+S(V
M(#$U.C4R.C(Y(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V
M(%)O8F5R="!%+B!#;WEL92`\<F]B97)T96-O>6QE0&AO=&UA:6PN8V]M/@H@
M*B!#;W!Y<FEG:'0@,C`P,2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@4F]B97)T
M($4N($-O>6QE(#QR;V)E<G1E8V]Y;&5`:&]T;6%I;"YC;VT^"B`J($!S:6YC
M92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]&;W)M"B`J+PIC;&%S
M<R!(;W)D95]&;W)M('L*"B`@("!V87(@)%]N86UE(#T@)R<["B`@("!V87(@
M)%]T:71L92`]("<G.PH@("`@=F%R("1?97AT<F$@/2`G)SL*("`@('9A<B`D
M7W9A<G,["B`@("!V87(@)%]S=6)M:70@/2!A<G)A>2@I.PH@("`@=F%R("1?
M<F5S970@/2!F86QS93L*("`@('9A<B`D7V5R<F]R<R`](&%R<F%Y*"D["B`@
M("!V87(@)%]S=6)M:71T960@/2!N=6QL.PH@("`@=F%R("1?<V5C=&EO;G,@
M/2!A<G)A>2@I.PH@("`@=F%R("1?;W!E;E]S96-T:6]N(#T@;G5L;#L*("`@
M('9A<B`D7V-U<G)E;G1396-T:6]N(#T@87)R87DH*3L*("`@('9A<B`D7W9A
M<FEA8FQE<R`](&%R<F%Y*"D["B`@("!V87(@)%]H:61D96Y687)I86)L97,@
M/2!A<G)A>2@I.PH@("`@=F%R("1?=7-E1F]R;51O:V5N(#T@=')U93L*("`@
M('9A<B`D7V%U=&]F:6QL960@/2!F86QS93L*("`@('9A<B`D7V5N8W1Y<&4@
M/2!N=6QL.PH@("`@=F%R("1?:&5L<"`](&9A;'-E.PH*("`@(&9U;F-T:6]N
M($AO<F1E7T9O<FTH)B1V87)S+"`D=&ET;&4@/2`G)RP@)&YA;64@/2!N=6QL
M*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1N86UE*2D@>PH@("`@("`@
M("`@("`D;F%M92`](%-T<FEN9SHZ;&]W97(H9V5T7V-L87-S*"1T:&ES*2D[
M"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W9A<G,@/2`F)'9A<G,["B`@
M("`@("`@)'1H:7,M/E]T:71L92`]("1T:71L93L*("`@("`@("`D=&AI<RT^
M7VYA;64@/2`D;F%M93L*("`@('T*"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N
M*"1F;W)M+"`F)'9A<G,L("1T:71L92`]("<G+"`D;F%M92`](&YU;&PI"B`@
M("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC97,["@H@("`@("`@("1S:6=N
M871U<F4@/2!S97)I86QI>F4H87)R87DH)&9O<FTL("1V87)S+"`D=&ET;&4L
M("1N86UE*2D["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1S:6=N
M871U<F5=*2D@>PH@("`@("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1F;W)M
M*2D@>PH@("`@("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`]
M("9N97<@)&9O<FTH)'9A<G,L("1T:71L92P@)&YA;64I.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T
M=7)E72`]("9N97<@2&]R9&5?1F]R;2@D=F%R<RP@)'1I=&QE+"`D;F%M92D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YS
M=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=%9A
M<G,H)B1V87)S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=F%R<R`]("8D=F%R
M<SL*("`@('T*"B`@("!F=6YC=&EO;B!G9714:71L92@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?=&ET;&4["B`@("!]"@H@("`@9G5N8W1I;VX@
M<V5T5&ET;&4H)'1I=&QE*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=&ET;&4@
M/2`D=&ET;&4["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T17AT<F$H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V5X=')A.PH@("`@?0H*("`@(&9U
M;F-T:6]N('-E=$5X=')A*"1E>'1R82D*("`@('L*("`@("`@("`D=&AI<RT^
M7V5X=')A(#T@)&5X=')A.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$YA;64H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VYA;64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!3971S(&]R(&=E=',@=VAE=&AE<B!T:&4@9F]R;2!S
M:&]U;&0@8F4@=F5R:69I960@8GD@=&]K96YS+@H@("`@("H@5&]K96YS(&%R
M92!U<V5D('1O('9E<FEF>2!T:&%T(&$@9F]R;2!I<R!O;FQY('-U8FUI='1E
M9"!O;F-E+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1T;VME;B`@
M268@<W!E8VEF:65D+"!S971S('=H971H97(@=&\@=7-E(&9O<FT@=&]K96YS
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!F;W)M
M('1O:V5N<R!A<F4@8F5I;F<@=7-E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M=7-E5&]K96XH)'1O:V5N(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES
M7VYU;&PH)'1O:V5N*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W5S949O<FU4
M;VME;B`]("1T;VME;CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?=7-E1F]R;51O:V5N.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H
M92!R96YD97)E<B!F;W(@=&AI<R!F;W)M+"!E:71H97(@82!C=7-T;VT@<F5N
M9&5R97(@;W(@=&AE"B`@("`@*B!S=&%N9&%R9"!O;F4N"B`@("`@*@H@("`@
M("H@5&\@=7-E(&$@8W5S=&]M(&9O<FT@<F5N9&5R97(L('EO=7(@9F]R;2!C
M;&%S<R!N965D<R!T;PH@("`@("H@;W9E<G)I9&4@=&AI<R!F=6YC=&EO;CH*
M("`@("`J(#QC;V1E/@H@("`@("H@9G5N8W1I;VX@)F=E=%)E;F1E<F5R*"D*
M("`@("`J('L*("`@("`J("`@("`D<B`]("9N97<@0W5S=&]M1F]R;5)E;F1E
M<F5R*"D["B`@("`@*B`@("`@<F5T=7)N("1R.PH@("`@("H@?0H@("`@("H@
M/"]C;V1E/@H@("`@("H*("`@("`J("XN+B!W:&5R92!#=7-T;VU&;W)M4F5N
M9&5R97(@:7,@=&AE(&-L87-S;F%M92!O9B!T:&4@8W5S=&]M"B`@("`@*B!R
M96YD97)E<B!C;&%S<RP@=VAI8V@@<VAO=6QD(&5X=&5N9"!(;W)D95]&;W)M
M7U)E;F1E<F5R+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M("!!(&AA<V@@;V8@<F5N9&5R97(M<W!E8VEF:6,@<&%R86UE=&5R<RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="!(;W)D95]&;W)M7U)E;F1E<F5R
M("!4:&4@9F]R;2!R96YD97)E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E
M=%)E;F1E<F5R*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(')E
M<75I<F5?;VYC92`G2&]R9&4O1F]R;2]296YD97)E<BYP:'`G.PH@("`@("`@
M("1R96YD97)E<B`]("9N97<@2&]R9&5?1F]R;5]296YD97)E<B@D<&%R86US
M*3L*("`@("`@("!R971U<FX@)')E;F1E<F5R.PH@("`@?0H*("`@(&9U;F-T
M:6]N("9G9714>7!E*"1T>7!E+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*
M("`@("`@("`D='EP95]C;&%S<R`]("=(;W)D95]&;W)M7U1Y<&5?)R`N("1T
M>7!E.PH@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"1T>7!E7V-L87-S*2D@
M>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*("`@("`@
M("`@("`@2&]R9&4Z.F9A=&%L*%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9B@G
M3F]N97AI<W1A;G0@8VQA<W,@(B5S(B!F;W(@9FEE;&0@='EP92`B)7,B)RP@
M)'1Y<&5?8VQA<W,L("1T>7!E*2DL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("`@("`@?0H@("`@("`@("1T>7!E7V]B(#T@)FYE=R`D='EP95]C;&%S<R@I
M.PH@("`@("`@(&-A;&Q?=7-E<E]F=6YC7V%R<F%Y*&%R<F%Y*"8D='EP95]O
M8BP@)VEN:70G*2P@)'!A<F%M<RD["B`@("`@("`@<F5T=7)N("1T>7!E7V]B
M.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=%-E8W1I;VXH)'-E8W1I;VX@/2`G
M)RP@)&1E<V,@/2`G)RP@)&EM86=E(#T@)R<L("1E>'!A;F1E9"`]('1R=64I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]C=7)R96YT4V5C=&EO;B`]("1S96-T
M:6]N.PH@("`@("`@(&EF("@A8V]U;G0H)'1H:7,M/E]S96-T:6]N<RD@)B8@
M(21T:&ES+3YG971/<&5N4V5C=&EO;B@I*2!["B`@("`@("`@("`@("1T:&ES
M+3YS971/<&5N4V5C=&EO;B@D<V5C=&EO;BD["B`@("`@("`@?0H@("`@("`@
M("1T:&ES+3Y?<V5C=&EO;G-;)'-E8W1I;VY=6R=D97-C)UT@/2`D9&5S8SL*
M("`@("`@("`D=&AI<RT^7W-E8W1I;VYS6R1S96-T:6]N75LG97AP86YD960G
M72`]("1E>'!A;F1E9#L*("`@("`@("`D=&AI<RT^7W-E8W1I;VYS6R1S96-T
M:6]N75LG:6UA9V4G72`]("1I;6%G93L*("`@('T*"B`@("!F=6YC=&EO;B!G
M971396-T:6]N1&5S8R@D<V5C=&EO;BD*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]S96-T:6]N<ULD<V5C=&EO;EU;)V1E<V,G73L*("`@('T*"B`@
M("!F=6YC=&EO;B!G971396-T:6]N26UA9V4H)'-E8W1I;VXI"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?<V5C=&EO;G-;)'-E8W1I;VY=6R=I;6%G
M92==.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=$]P96Y396-T:6]N*"1S96-T
M:6]N*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=F%R<RT^<V5T*"=?7V9O<FU/
M<&5N4V5C=&EO;B<L("1S96-T:6]N*3L*("`@('T*"B`@("!F=6YC=&EO;B!G
M971/<&5N4V5C=&EO;B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M=F%R<RT^9V5T*"=?7V9O<FU/<&5N4V5C=&EO;B<I.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&=E=%-E8W1I;VY%>'!A;F1E9%-T871E*"1S96-T:6]N+"`D8F]O
M;&5A;B`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@D8F]O;&5A;BD@>PH@
M("`@("`@("`@("`O*B!/;FQY('1H92!B;V]L96%N('9A;'5E(&ES(')E<75I
M<F5D+B`J+PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]S96-T:6]N<ULD
M<V5C=&EO;EU;)V5X<&%N9&5D)UT["B`@("`@("`@?0H*("`@("`@("`O*B!.
M965D('1O(')E='5R;B!T:&4@=F%L=65S(&9O<B!U<V4@:6X@<W1Y;&5S+B`J
M+PH@("`@("`@(&EF("@D=&AI<RT^7W-E8W1I;VYS6R1S96-T:6]N75LG97AP
M86YD960G72D@>PH@("`@("`@("`@("!R971U<FX@)V)L;V-K)SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)VYO;F4G.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%1/1$\*("`@("`J+PH@("`@9G5N
M8W1I;VX@)F%D9%9A<FEA8FQE*"1H=6UA;DYA;64L("1V87).86UE+"`D='EP
M92P@)')E<75I<F5D+`H@("`@("`@("`@("`@("`@("`@("`@("`@("1R96%D
M;VYL>2`](&9A;'-E+"`D9&5S8W)I<'1I;VX@/2!N=6QL+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^:6YS97)T5F%R:6%B;&5"969O<F4H;G5L;"P@
M)&AU;6%N3F%M92P@)'9A<DYA;64L("1T>7!E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<75I<F5D+"`D<F5A9&]N
M;'DL("1D97-C<FEP=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P87)A;7,I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@5$]$3PH@("`@("HO"B`@("!F=6YC=&EO;B`F:6YS97)T5F%R:6%B;&5"
M969O<F4H)&)E9F]R92P@)&AU;6%N3F%M92P@)'9A<DYA;64L("1T>7!E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97%U:7)E9"P@
M)')E861O;FQY(#T@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&1E<V-R:7!T:6]N(#T@;G5L;"P@)'!A<F%M<R`](&%R<F%Y
M*"DI"B`@("!["B`@("`@("`@)'1Y<&4@/2`F)'1H:7,M/F=E=%1Y<&4H)'1Y
M<&4L("1P87)A;7,I.PH@("`@("`@("1V87(@/2`F;F5W($AO<F1E7T9O<FU?
M5F%R:6%B;&4H)&AU;6%N3F%M92P@)'9A<DYA;64L("1T>7!E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<75I<F5D+"`D
M<F5A9&]N;'DL("1D97-C<FEP=&EO;BD["@H@("`@("`@("\J(%-E="!T:&4@
M9F]R;2!O8FIE8W0@<F5F97)E;F-E(&EN('1H92!V87(N("HO"B`@("`@("`@
M)'9A<BT^<V5T1F]R;4]B*"1T:&ES*3L*"B`@("`@("`@:68@*"1V87(M/F=E
M=%1Y<&5.86UE*"D@/3T@)V5N=6TG("8F"B`@("`@("`@("`@(&-O=6YT*"1V
M87(M/F=E=%9A;'5E<R@I*2`]/2`Q*2!["B`@("`@("`@("`@("1V86QS(#T@
M87)R87E?:V5Y<R@D=F%R+3YG971686QU97,H*2D["B`@("`@("`@("`@("1T
M:&ES+3Y?=F%R<RT^861D*"1V87(M/G9A<DYA;64L("1V86QS6S!=*3L*("`@
M("`@("`@("`@)'9A<BT^7V%U=&]F:6QL960@/2!T<G5E.PH@("`@("`@('T@
M96QS96EF("@D=F%R+3YG9714>7!E3F%M92@I(#T]("=F:6QE)R!\?`H@("`@
M("`@("`@("`@("`@("`D=F%R+3YG9714>7!E3F%M92@I(#T]("=I;6%G92<I
M('L*("`@("`@("`@("`@)'1H:7,M/E]E;F-T>7!E(#T@)VUU;'1I<&%R="]F
M;W)M+61A=&$G.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)'1H:7,M
M/E]C=7)R96YT4V5C=&EO;BDI('L*("`@("`@("`@("`@)'1H:7,M/E]C=7)R
M96YT4V5C=&EO;B`]("=?7V)A<V4G.PH@("`@("`@('T*"B`@("`@("`@:68@
M*&ES7VYU;&PH)&)E9F]R92DI('L*("`@("`@("`@("`@)'1H:7,M/E]V87)I
M86)L97-;)'1H:7,M/E]C=7)R96YT4V5C=&EO;EU;72`]("8D=F%R.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1N=6T@/2`P.PH@("`@("`@("`@
M("!W:&EL92`H:7-S970H)'1H:7,M/E]V87)I86)L97-;)'1H:7,M/E]C=7)R
M96YT4V5C=&EO;EU;)&YU;5TI("8F"B`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W9A<FEA8FQE<ULD=&AI<RT^7V-U<G)E;G1396-T:6]N75LD;G5M72T^
M9V5T5F%R3F%M92@I("$]("1B969O<F4I('L*("`@("`@("`@("`@("`@("1N
M=6TK*SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?=F%R:6%B;&5S6R1T:&ES+3Y?8W5R<F5N=%-E8W1I;VY=6R1N=6U=
M*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]V87)I86)L97-;)'1H:7,M
M/E]C=7)R96YT4V5C=&EO;EU;72`]("8D=F%R.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]V87)I86)L97-;)'1H:7,M
M/E]C=7)R96YT4V5C=&EO;ET@/2!A<G)A>5]M97)G92@*("`@("`@("`@("`@
M("`@("`@("!A<G)A>5]S;&EC92@D=&AI<RT^7W9A<FEA8FQE<ULD=&AI<RT^
M7V-U<G)E;G1396-T:6]N72P@,"P@)&YU;2DL"B`@("`@("`@("`@("`@("`@
M("`@87)R87DH)B1V87(I+`H@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W-L
M:6-E*"1T:&ES+3Y?=F%R:6%B;&5S6R1T:&ES+3Y?8W5R<F5N=%-E8W1I;VY=
M+"`D;G5M*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D=F%R.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!A('9A
M<FEA8FQE(&9R;VT@=&AE(&9O<FTN"B`@("`@*@H@("`@("H@07,@;VYL>2!V
M87)I86)L97,@8V%N(&)E('!A<W-E9"!B>2!R969E<F5N8V4L('EO=2!N965D
M('1O(&-A;&P@=&AI<PH@("`@("H@;65T:&]D('1H:7,@=V%Y(&EF('=A;G0@
M=&\@<&%S<R!A('9A<FEA8FQE(&YA;64Z"B`@("`@*B`\8V]D93X*("`@("`J
M("1F;W)M+3YR96UO=F5687)I86)L92@D=F%R(#T@)W9A<FYA;64G*3L*("`@
M("`J(#PO8V]D93X*("`@("`J"B`@("`@*B!`<&%R86T@2&]R9&5?1F]R;5]6
M87)I86)L97QS=')I;F<@)'9A<B`@16ET:&5R('1H92!V87)I86)L92=S(&YA
M;64@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!T:&4@=F%R:6%B;&4@=&\@<F5M;W9E(&9R;VT@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R
M;2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE
M('9A<FEA8FQE('=A<R!F;W5N9"`H86YD(&1E;&5T960I+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R96UO=F5687)I86)L92@F)'9A<BD*("`@('L*("`@("`@
M("!F;W)E86-H("AA<G)A>5]K97ES*"1T:&ES+3Y?=F%R:6%B;&5S*2!A<R`D
M<V5C=&EO;BD@>PH@("`@("`@("`@("!F;W)E86-H("AA<G)A>5]K97ES*"1T
M:&ES+3Y?=F%R:6%B;&5S6R1S96-T:6]N72D@87,@)&DI('L*("`@("`@("`@
M("`@("`@(&EF("@H:7-?82@D=F%R+"`G2&]R9&5?1F]R;5]687)I86)L92<I
M("8F("1T:&ES+3Y?=F%R:6%B;&5S6R1S96-T:6]N75LD:5T@/3T]("1V87(I
M('Q\"B`@("`@("`@("`@("`@("`@("`@*"1T:&ES+3Y?=F%R:6%B;&5S6R1S
M96-T:6]N75LD:5TM/F=E=%9A<DYA;64H*2`]/2`D=F%R*2D@>PH@("`@("`@
M("`@("`@("`@("`@("\O(%-L:6-E(&]U="!T:&4@=F%R:6%B;&4@=&\@8F4@
M<F5M;W9E9"X*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A<FEA8FQE
M<ULD=&AI<RT^7V-U<G)E;G1396-T:6]N72`](&%R<F%Y7VUE<F=E*`H@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>5]S;&EC92@D=&AI<RT^7W9A<FEA
M8FQE<ULD=&AI<RT^7V-U<G)E;G1396-T:6]N72P@,"P@)&DI+`H@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>5]S;&EC92@D=&AI<RT^7W9A<FEA8FQE
M<ULD=&AI<RT^7V-U<G)E;G1396-T:6]N72P@)&D@*R`Q*2D["@H@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9A9&1(:61D96XH)&AU;6%N3F%M92P@)'9A<DYA;64L("1T>7!E+"`D
M<F5Q=6ER960L"B`@("`@("`@("`@("`@("`@("`@("`@("1R96%D;VYL>2`]
M(&9A;'-E+"`D9&5S8W)I<'1I;VX@/2!N=6QL+`H@("`@("`@("`@("`@("`@
M("`@("`@("`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D='EP
M92`]("8D=&AI<RT^9V5T5'EP92@D='EP92P@)'!A<F%M<RD["B`@("`@("`@
M)'9A<B`]("9N97<@2&]R9&5?1F]R;5]687)I86)L92@D:'5M86Y.86UE+"`D
M=F%R3F%M92P@)'1Y<&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<F5Q=6ER960L("1R96%D;VYL>2P@)&1E<V-R:7!T:6]N
M*3L*("`@("`@("`D=F%R+3YH:61E*"D["B`@("`@("`@)'1H:7,M/E]H:61D
M96Y687)I86)L97-;72`]("8D=F%R.PH@("`@("`@(')E='5R;B`D=F%R.PH@
M("`@?0H*("`@(&9U;F-T:6]N("9G971687)I86)L97,H)&9L870@/2!T<G5E
M+"`D=VET:$AI9&1E;B`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@D9FQA
M="D@>PH@("`@("`@("`@("`D=F%R<R`](&%R<F%Y*"D["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?=F%R:6%B;&5S(&%S("1S96-T:6]N*2!["B`@
M("`@("`@("`@("`@("!F;W)E86-H("@D<V5C=&EO;B!A<R`D=F%R*2!["B`@
M("`@("`@("`@("`@("`@("`@)'9A<G-;72`]("1V87(["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1W:71H2&ED
M9&5N*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7VAI9&1E
M;E9A<FEA8FQE<R!A<R`D=F%R*2!["B`@("`@("`@("`@("`@("`@("`@)'9A
M<G-;72`]("1V87(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("`@("`@<F5T=7)N("1V87)S.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7W9A<FEA8FQE<SL*("`@("`@("!]
M"B`@("!]"@H@("`@9G5N8W1I;VX@<V5T0G5T=&]N<R@D<W5B;6ET+"`D<F5S
M970@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H)'-U8FUI="`]/3T@=')U
M92!\?"!I<U]N=6QL*"1S=6)M:70I('Q\(&5M<'1Y*"1S=6)M:70I*2!["B`@
M("`@("`@("`@("\J($1E9F%U;'0@=&\@)U-U8FUI="<N("HO"B`@("`@("`@
M("`@("1S=6)M:70@/2!A<G)A>2A?*")3=6)M:70B*2D["B`@("`@("`@?2!E
M;'-E:68@*"%I<U]A<G)A>2@D<W5B;6ET*2D@>PH@("`@("`@("`@("`O*B!$
M969A=6QT('1O(&%R<F%Y(&EF(&YO="!P87-S960N("HO"B`@("`@("`@("`@
M("1S=6)M:70@/2!A<G)A>2@D<W5B;6ET*3L*("`@("`@("!]"B`@("`@("`@
M+RH@3VYL>2!I9B`D<F5S970@:7,@<W1R:6-T;'D@=')U92!I;G-E<G0@9&5F
M875L="`G4F5S970G+B`J+PH@("`@("`@(&EF("@D<F5S970@/3T]('1R=64I
M('L*("`@("`@("`@("`@)')E<V5T(#T@7R@B4F5S970B*3L*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3Y?<W5B;6ET(#T@)'-U8FUI=#L*("`@("`@("`D
M=&AI<RT^7W)E<V5T(#T@)')E<V5T.PH@("`@?0H*("`@(&9U;F-T:6]N(&%P
M<&5N9$)U='1O;G,H)'-U8FUI="D*("`@('L*("`@("`@("!I9B`H(6ES7V%R
M<F%Y*"1S=6)M:70I*2!["B`@("`@("`@("`@("1S=6)M:70@/2!A<G)A>2@D
M<W5B;6ET*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<W5B;6ET(#T@
M87)R87E?;65R9V4H)'1H:7,M/E]S=6)M:70L("1S=6)M:70I.PH@("`@?0H*
M("`@(&9U;F-T:6]N('!R97-E<G9E5F%R0GE0;W-T*"8D=F%R<RP@)'9A<FYA
M;64L("1A;'1?=F%R;F%M92`]("<G*0H@("`@>PH@("`@("`@("1V86QU92`]
M("1V87)S+3YG971%>&ES=',H)'9A<FYA;64L("1W87-S970I.PH*("`@("`@
M("`O*B!)9B!A;B!A;'1E<FYA=&4@;F%M92!I<R!G:79E;B!U;F1E<B!W:&EC
M:"!T;R!P<F5S97)V92!U<V4@=&AA="X@*B\*("`@("`@("!I9B`H)&%L=%]V
M87)N86UE*2!["B`@("`@("`@("`@("1V87)N86UE(#T@)&%L=%]V87)N86UE
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"1W87-S970I('L*("`@("`@("`@
M("`@)'1H:7,M/E]P<F5S97)V959A<D)Y4&]S="@D=F%R;F%M92P@)'9A;'5E
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7W!R97-E<G9E5F%R0GE0;W-T
M*"1V87)N86UE+"`D=F%L=64I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1V86QU92DI('L*("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E(&%S("1I
M9"`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!R97-E<G9E
M5F%R0GE0;W-T*"1V87)N86UE("X@)ULG("X@)&ED("X@)UTG+"`D=F%L*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1V
M87)N86UE(#T@:'1M;'-P96-I86QC:&%R<R@D=F%R;F%M92D["B`@("`@("`@
M("`@("1V86QU92`](&AT;6QS<&5C:6%L8VAA<G,H)'9A;'5E*3L*("`@("`@
M("`@("`@<')I;G1F*"<\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2(E<R(@
M=F%L=64](B5S(B`O/B<@+B`B7&XB+`H@("`@("`@("`@("`@("`@("`@)'9A
M<FYA;64L"B`@("`@("`@("`@("`@("`@("`D=F%L=64I.PH@("`@("`@('T*
M("`@('T*"B`@("!F=6YC=&EO;B!O<&5N*"8D<F5N9&5R97(L("8D=F%R<RP@
M)&%C=&EO;BP@)&UE=&AO9"`]("=G970G+"`D96YC='EP92`](&YU;&PI"B`@
M("!["B`@("`@("`@:68@*&ES7VYU;&PH)&5N8W1Y<&4I("8F("%I<U]N=6QL
M*"1T:&ES+3Y?96YC='EP92DI('L*("`@("`@("`@("`@)&5N8W1Y<&4@/2`D
M=&AI<RT^7V5N8W1Y<&4["B`@("`@("`@?0H@("`@("`@("1R96YD97)E<BT^
M;W!E;B@D86-T:6]N+"`D;65T:&]D+"`D=&AI<RT^7VYA;64L("1E;F-T>7!E
M*3L*("`@("`@("`D<F5N9&5R97(M/FQI<W1&;W)M5F%R<R@D=&AI<RD["@H@
M("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]N86UE*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7W!R97-E<G9E5F%R0GE0;W-T*"=F;W)M;F%M92<L("1T:&ES
M+3Y?;F%M92D["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/E]U<V5&
M;W)M5&]K96XI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]4
M;VME;BYP:'`G.PH@("`@("`@("`@("`D=&AI<RT^7W!R97-E<G9E5F%R0GE0
M;W-T*"=?7V9O<FU4;VME;E\G("X@)'1H:7,M/E]N86UE+"!(;W)D95]4;VME
M;CHZ9V5N97)A=&5)9"@D=&AI<RT^7VYA;64I*3L*("`@("`@("!]"@H@("`@
M("`@("\J($QO;W`@=&AR;W5G:"!V87)S(&%N9"!C:&5C:R!F;W(@86YY('-P
M96-I86P@8V%S97,@=&\@<')E<V5R=F4N("HO"B`@("`@("`@)'9A<FEA8FQE
M<R`]("1T:&ES+3YG971687)I86)L97,H*3L*("`@("`@("!F;W)E86-H("@D
M=F%R:6%B;&5S(&%S("1V87(I('L*("`@("`@("`@("`@+RH@4')E<V5R=F4@
M=F%L=64@:68@8VAA;F=E(&AA<R!T;R!B92!T<F%C:V5D+B`J+PH@("`@("`@
M("`@("!I9B`H)'9A<BT^9V5T3W!T:6]N*"=T<F%C:V-H86YG92<I*2!["B`@
M("`@("`@("`@("`@("`D=F%R;F%M92`]("1V87(M/F=E=%9A<DYA;64H*3L*
M("`@("`@("`@("`@("`@("1T:&ES+3YP<F5S97)V959A<D)Y4&]S="@D=F%R
M<RP@)'9A<FYA;64L("=?7V]L9%\G("X@)'9A<FYA;64I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VAI9&1E
M;E9A<FEA8FQE<R!A<R`D=F%R*2!["B`@("`@("`@("`@("1T:&ES+3YP<F5S
M97)V959A<D)Y4&]S="@D=F%R<RP@)'9A<BT^9V5T5F%R3F%M92@I*3L*("`@
M("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@8VQO<V4H)B1R96YD97)E<BD*
M("`@('L*("`@("`@("`D<F5N9&5R97(M/F-L;W-E*"D["B`@("!]"@H@("`@
M9G5N8W1I;VX@<F5N9&5R06-T:79E*"8D<F5N9&5R97(L("8D=F%R<RP@)&%C
M=&EO;BP@)&UE=&AO9"`]("=G970G+"`D96YC='EP92`](&YU;&PL("1F;V-U
M<R`]('1R=64I"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)&5N8W1Y<&4I
M("8F("%I<U]N=6QL*"1T:&ES+3Y?96YC='EP92DI('L*("`@("`@("`@("`@
M)&5N8W1Y<&4@/2`D=&AI<RT^7V5N8W1Y<&4["B`@("`@("`@?0H@("`@("`@
M("1R96YD97)E<BT^;W!E;B@D86-T:6]N+"`D;65T:&]D+"`D=&AI<RT^9V5T
M3F%M92@I+"`D96YC='EP92D["B`@("`@("`@)')E;F1E<F5R+3YL:7-T1F]R
M;59A<G,H)'1H:7,I.PH*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?;F%M
M92DI('L*("`@("`@("`@("`@)'1H:7,M/E]P<F5S97)V959A<D)Y4&]S="@G
M9F]R;6YA;64G+"`D=&AI<RT^7VYA;64I.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"1T:&ES+3Y?=7-E1F]R;51O:V5N*2!["B`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G2&]R9&4O5&]K96XN<&AP)SL*("`@("`@("`@("`@)'1H:7,M
M/E]P<F5S97)V959A<D)Y4&]S="@G7U]F;W)M5&]K96Y?)R`N("1T:&ES+3Y?
M;F%M92P@2&]R9&5?5&]K96XZ.F=E;F5R871E260H)'1H:7,M/E]N86UE*2D[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]S96-T:6]N
M<RDI('L*("`@("`@("`@("`@)'1H:7,M/E]P<F5S97)V959A<D)Y4&]S="@G
M7U]F;W)M3W!E;E-E8W1I;VXG+"`D=&AI<RT^9V5T3W!E;E-E8W1I;VXH*2D[
M"B`@("`@("`@?0H*("`@("`@("`O*B!,;V]P('1H<F]U9V@@=F%R<R!A;F0@
M8VAE8VL@9F]R(&%N>2!S<&5C:6%L(&-A<V5S('1O"B`@("`@("`@("H@<')E
M<V5R=F4N("HO"B`@("`@("`@)'9A<FEA8FQE<R`]("1T:&ES+3YG971687)I
M86)L97,H*3L*("`@("`@("!F;W)E86-H("@D=F%R:6%B;&5S(&%S("1V87(I
M('L*("`@("`@("`@("`@+RH@4')E<V5R=F4@=F%L=64@:68@8VAA;F=E(&AA
M<R!T;R!B92!T<F%C:V5D+B`J+PH@("`@("`@("`@("!I9B`H)'9A<BT^9V5T
M3W!T:6]N*"=T<F%C:V-H86YG92<I*2!["B`@("`@("`@("`@("`@("`D=F%R
M;F%M92`]("1V87(M/F=E=%9A<DYA;64H*3L*("`@("`@("`@("`@("`@("1T
M:&ES+3YP<F5S97)V959A<D)Y4&]S="@D=F%R<RP@)'9A<FYA;64L("=?7V]L
M9%\G("X@)'9A<FYA;64I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!F;W)E86-H("@D=&AI<RT^7VAI9&1E;E9A<FEA8FQE<R!A<R`D=F%R
M*2!["B`@("`@("`@("`@("1T:&ES+3YP<F5S97)V959A<D)Y4&]S="@D=F%R
M<RP@)'9A<BT^9V5T5F%R3F%M92@I*3L*("`@("`@("!]"@H@("`@("`@("1R
M96YD97)E<BT^8F5G:6Y!8W1I=F4H)'1H:7,M/F=E=%1I=&QE*"DL("1T:&ES
M+3YG971%>'1R82@I*3L*("`@("`@("`D<F5N9&5R97(M/G)E;F1E<D9O<FU!
M8W1I=F4H)'1H:7,L("1V87)S*3L*("`@("`@("`D<F5N9&5R97(M/G-U8FUI
M="@D=&AI<RT^7W-U8FUI="P@)'1H:7,M/E]R97-E="D["B`@("`@("`@)')E
M;F1E<F5R+3YE;F0H*3L*("`@("`@("`D<F5N9&5R97(M/F-L;W-E*"1F;V-U
M<RD["B`@("!]"@H@("`@9G5N8W1I;VX@<F5N9&5R26YA8W1I=F4H)B1R96YD
M97)E<BP@)'9A<G,I"B`@("!["B`@("`@("`@)')E;F1E<F5R+3YB96=I;DEN
M86-T:79E*"1T:&ES+3YG9714:71L92@I+"`D=&AI<RT^9V5T17AT<F$H*2D[
M"B`@("`@("`@)')E;F1E<F5R+3YR96YD97)&;W)M26YA8W1I=F4H)'1H:7,L
M("1V87)S*3L*("`@("`@("`D<F5N9&5R97(M/F5N9"@I.PH@("`@?0H*("`@
M(&9U;F-T:6]N('!R97-E<G9E*"1V87)S*0H@("`@>PH@("`@("`@(&EF("@D
M=&AI<RT^7W5S949O<FU4;VME;BD@>PH@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)TAO<F1E+U1O:V5N+G!H<"<["B`@("`@("`@("`@("1T:&ES+3Y?<')E
M<V5R=F5687)">5!O<W0H)U]?9F]R;51O:V5N7R<@+B`D=&AI<RT^7VYA;64L
M($AO<F1E7U1O:V5N.CIG96YE<F%T94ED*"1T:&ES+3Y?;F%M92DI.PH@("`@
M("`@('T*"B`@("`@("`@)'9A<FEA8FQE<R`]("1T:&ES+3YG971687)I86)L
M97,H*3L*("`@("`@("!F;W)E86-H("@D=F%R:6%B;&5S(&%S("1V87(I('L*
M("`@("`@("`@("`@)'9A<FYA;64@/2`D=F%R+3YG971687).86UE*"D["@H@
M("`@("`@("`@("`O*B!3879E('9A;'5E(&]F(&EN9&EV:61U86P@8V]M<&]N
M96YT<RX@*B\*("`@("`@("`@("`@<W=I=&-H("@D=F%R+3YG9714>7!E3F%M
M92@I*2!["B`@("`@("`@("`@(&-A<V4@)W!A<W-W;W)D8V]N9FER;2<Z"B`@
M("`@("`@("`@(&-A<V4@)V5M86EL8V]N9FER;2<Z"B`@("`@("`@("`@("`@
M("`D=&AI<RT^<')E<V5R=F5687)">5!O<W0H)'9A<G,L("1V87)N86UE("X@
M)UMO<FEG:6YA;%TG*3L*("`@("`@("`@("`@("`@("1T:&ES+3YP<F5S97)V
M959A<D)Y4&]S="@D=F%R<RP@)'9A<FYA;64@+B`G6V-O;F9I<FU=)RD["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VUO;G1H
M>65A<B<Z"B`@("`@("`@("`@("`@("`D=&AI<RT^<')E<V5R=F5687)">5!O
M<W0H)'9A<G,L("1V87)N86UE("X@)UMM;VYT:%TG*3L*("`@("`@("`@("`@
M("`@("1T:&ES+3YP<F5S97)V959A<D)Y4&]S="@D=F%R<RP@)'9A<FYA;64@
M+B`G6WEE87)=)RD["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@)VUO;G1H9&%Y>65A<B<Z"B`@("`@("`@("`@("`@("`D=&AI
M<RT^<')E<V5R=F5687)">5!O<W0H)'9A<G,L("1V87)N86UE("X@)UMM;VYT
M:%TG*3L*("`@("`@("`@("`@("`@("1T:&ES+3YP<F5S97)V959A<D)Y4&]S
M="@D=F%R<RP@)'9A<FYA;64@+B`G6V1A>5TG*3L*("`@("`@("`@("`@("`@
M("1T:&ES+3YP<F5S97)V959A<D)Y4&]S="@D=F%R<RP@)'9A<FYA;64@+B`G
M6WEE87)=)RD["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@)'1H:7,M/G!R97-E<G9E5F%R0GE0;W-T*"1V87)S
M+"`D=F%R;F%M92D["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3Y?:&ED9&5N5F%R:6%B;&5S(&%S("1V87(I('L*("`@("`@("`@("`@)'1H
M:7,M/G!R97-E<G9E5F%R0GE0;W-T*"1V87)S+"`D=F%R+3YG971687).86UE
M*"DI.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!U;G-E=%9A<G,H
M)B1V87)S*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YG971687)I
M86)L97,H*2!A<R`D=F%R*2!["B`@("`@("`@("`@("1V87)S+3YR96UO=F4H
M)'9A<BT^9V5T5F%R3F%M92@I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$;V5S('1H92!A8W1I;VX@;V8@=F%L:61A=&EN9R!T:&4@9F]R
M;2P@8VAE8VMI;F<@:68@:70@<F5A;&QY(&AA<R!B965N"B`@("`@*B!S=6)M
M:71T960@8GD@8V%L;&EN9R!I<U-U8FUI='1E9"@I(&%N9"!I9B!T<G5E(&1O
M97,@86YY(&]N4W5B;6ET*"D*("`@("`J(&-A;&QS(&9O<B!V87(@='EP97,@
M:6X@=&AE(&9O<FTN(%1H92!?<W5B;6ET=&5D('9A<B!I<R!T:&5N(')E8VAE
M8VME9"X*("`@("`J"B`@("`@*B!`<&%R86T@2&]R9&5?5F%R:6%B;&5S("1V
M87)S"B`@("`@*B!`<&%R86T@8F]O;&5A;B`@("`@("`@("1C86Y!=71O9FEL
M;"`@0V%N('1H92!F;W)M(&)E('9A;&ED('=I=&AO=70*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B96EN9R!S=6)M:71T
M960_"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H
M92!F;W)M(&ES('9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!V86QI9&%T
M92@F)'9A<G,L("1C86Y!=71O1FEL;"`](&9A;'-E*0H@("`@>PH@("`@("`@
M("\J($=E="!S=6)M:71T960@<W1A='5S+B`J+PH@("`@("`@(&EF("@D=&AI
M<RT^:7-3=6)M:71T960H*2!\?"`D8V%N075T;T9I;&PI('L*("`@("`@("`@
M("`@+RH@1F]R;2!W87,@<W5B;6ET=&5D(&]R(&-A;B!A=71O9FEL;#L@8VAE
M8VL@9F]R(&%N>2!V87)I86)L90H@("`@("`@("`@("`@*B!T>7!E<R<@;VY3
M=6)M:70H*2X@*B\*("`@("`@("`@("`@)'1H:7,M/F]N4W5B;6ET*"1V87)S
M*3L*"B`@("`@("`@("`@("\J(%)E8VAE8VL@<W5B;6ET=&5D('-T871U<RX@
M*B\*("`@("`@("`@("`@:68@*"$D=&AI<RT^:7-3=6)M:71T960H*2`F)B`A
M)&-A;D%U=&]&:6QL*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O
M*B!&;W)M(&AA<R!N;W0@8F5E;B!S=6)M:71T960[(')E='5R;B!F86QS92X@
M*B\*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@)&UE<W-A9V4@/2`G)SL*("`@("`@("`D=&AI<RT^7V%U=&]F:6QL960@
M/2!T<G5E.PH*("`@("`@("!I9B`H)'1H:7,M/E]U<V5&;W)M5&]K96XI('L*
M("`@("`@("`@("`@9VQO8F%L("1C;VYF.PH@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+U1O:V5N+G!H<"<["B`@("`@("`@("`@(&EF("AI<W-E
M="@D8V]N9ELG=&]K96XG72DI('L*("`@("`@("`@("`@("`@("\J($EF('1H
M97)E(&ES(&$@8V]N9FEG=7)E9"!T;VME;B!S>7-T96TL('-E="!I="!U<"X@
M*B\*("`@("`@("`@("`@("`@("1T;VME;E-O=7)C92`]("9(;W)D95]4;VME
M;CHZ<VEN9VQE=&]N*"1C;VYF6R=T;VME;B==6R=D<FEV97(G72P@2&]R9&4Z
M.F=E=$1R:79E<D-O;F9I9R@G=&]K96XG+"`D8V]N9ELG=&]K96XG75LG9')I
M=F5R)UTI*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("\J($1E9F%U;'0@=&\@=&AE(&9I;&4@<WES=&5M(&EF(&YO(&-O;F9I9RX@
M*B\*("`@("`@("`@("`@("`@("1T;VME;E-O=7)C92`]("9(;W)D95]4;VME
M;CHZ<VEN9VQE=&]N*"=F:6QE)RD["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*"$D=&]K96Y3;W5R8V4M/G9E<FEF>2@D=F%R<RT^9V5T*"=?7V9O
M<FU4;VME;E\G("X@)'1H:7,M/E]N86UE*2DI('L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?97)R;W)S6R=?7V9O<FU4;VME;B==(#T@7R@B5&AI<R!F;W)M
M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D=&AI<RT^9V5T5F%R:6%B
M;&5S*"D@87,@)'9A<BD@>PH@("`@("`@("`@("`D=&AI<RT^7V%U=&]F:6QL
M960@/2`D=F%R+3Y?875T;V9I;&QE9"`F)B`D=&AI<RT^7V%U=&]F:6QL960[
M"B`@("`@("`@("`@(&EF("@A)'9A<BT^=F%L:61A=&4H)'9A<G,L("1M97-S
M86=E*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]E<G)O<G-;)'9A<BT^
M9V5T5F%R3F%M92@I72`]("1M97-S86=E.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!I9B`H)'1H:7,M/E]A=71O9FEL;&5D*2!["B`@("`@
M("`@("`@('5N<V5T*"1T:&ES+3Y?97)R;W)S6R=?7V9O<FU4;VME;B==*3L*
M("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?:&ED9&5N5F%R
M:6%B;&5S(&%S("1V87(I('L*("`@("`@("`@("`@:68@*"$D=F%R+3YV86QI
M9&%T92@D=F%R<RP@)&UE<W-A9V4I*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V5R<F]R<ULD=F%R+3YG971687).86UE*"E=(#T@)&UE<W-A9V4["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^
M:7-686QI9"@I.PH@("`@?0H*("`@(&9U;F-T:6]N(&-L96%R5F%L:61A=&EO
M;B@I"B`@("!["B`@("`@("`@)'1H:7,M/E]E<G)O<G,@/2!A<G)A>2@I.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&=E=$5R<F]R*"1V87(I"B`@("!["B`@("`@
M("`@:68@*&ES7V$H)'9A<BP@)TAO<F1E7T9O<FU?5F%R:6%B;&4G*2D@>PH@
M("`@("`@("`@("`D;F%M92`]("1V87(M/F=E=%9A<DYA;64H*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D;F%M92`]("1V87(["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7V5R<F]R<ULD;F%M95TI
M(#\@)'1H:7,M/E]E<G)O<G-;)&YA;65=(#H@;G5L;#L*("`@('T*"B`@("!F
M=6YC=&EO;B!S971%<G)O<B@D=F%R+"`D;65S<V%G92D*("`@('L*("`@("`@
M("!I9B`H:7-?82@D=F%R+"`G2&]R9&5?1F]R;5]687)I86)L92<I*2!["B`@
M("`@("`@("`@("1N86UE(#T@)'9A<BT^9V5T5F%R3F%M92@I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1N86UE(#T@)'9A<CL*("`@("`@("!]
M"B`@("`@("`@)'1H:7,M/E]E<G)O<G-;)&YA;65=(#T@)&UE<W-A9V4["B`@
M("!]"@H@("`@9G5N8W1I;VX@8VQE87)%<G)O<B@D=F%R*0H@("`@>PH@("`@
M("`@(&EF("AI<U]A*"1V87(L("=(;W)D95]&;W)M7U9A<FEA8FQE)RDI('L*
M("`@("`@("`@("`@)&YA;64@/2`D=F%R+3YG971687).86UE*"D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&YA;64@/2`D=F%R.PH@("`@("`@
M('T*("`@("`@("!U;G-E="@D=&AI<RT^7V5R<F]R<ULD;F%M95TI.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&ES5F%L:60H*0H@("`@>PH@("`@("`@(')E='5R
M;B`H)'1H:7,M/E]A=71O9FEL;&5D('Q\(&-O=6YT*"1T:&ES+3Y?97)R;W)S
M*2`]/2`P*3L*("`@('T*"B`@("!F=6YC=&EO;B!E>&5C=71E*"8D=F%R<RD*
M("`@('L*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G5V%R;FEN9SH@2&]R
M9&5?1F]R;3HZ97AE8W5T92@I(&-A;&QE9"P@<VAO=6QD(&)E(&]V97)R:61D
M96XG+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($9E=&-H('1H92!F:65L9"!V86QU97,@;V8@
M=&AE('-U8FUI='1E9"!F;W)M+@H@("`@("H*("`@("`J($!P87)A;2!687)I
M86)L97,@)'9A<G,@(%1H92!687)I86)L97,@;V)J96-T+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1I;F9O("`@("`@07)R87D@=&\@8F4@9FEL;&5D('=I=&@@
M=&AE('-U8FUI='1E9"!F:65L9`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@=F%L=65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971);F9O*"8D
M=F%R<RP@)B1I;F9O*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9V5T26YF;T9R
M;VU687)I86)L97,H)'1H:7,M/F=E=%9A<FEA8FQE<R@I+"`D=F%R<RP@)&EN
M9F\I.PH@("`@("`@("1T:&ES+3Y?9V5T26YF;T9R;VU687)I86)L97,H)'1H
M:7,M/E]H:61D96Y687)I86)L97,L("1V87)S+"`D:6YF;RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!&971C:"!T:&4@9FEE;&0@=F%L=65S(&9R;VT@82!G
M:79E;B!A<G)A>2!O9B!V87)I86)L97,N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("`D=F%R:6%B
M;&5S("!!;B!A<G)A>2!O9B!(;W)D95]&;W)M7U9A<FEA8FQE(&]B:F5C=',@
M=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@9F5T8V@@9G)O
M;2X*("`@("`J($!P87)A;2!O8FIE8W0@)'9A<G,@("`@("`@5&AE(%9A<FEA
M8FQE<R!O8FIE8W0N"B`@("`@*B!`<&%R86T@87)R87D@("1I;F9O("`@("`@
M(%1H92!A<G)A>2!T;R!B92!F:6QL960@=VET:"!T:&4@<W5B;6ET=&5D"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&9I96QD('9A;'5E<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$EN9F]&<F]M5F%R:6%B;&5S*"1V
M87)I86)L97,L("8D=F%R<RP@)B1I;F9O*0H@("`@>PH@("`@("`@(&9O<F5A
M8V@@*"1V87)I86)L97,@87,@)'9A<BD@>PH@("`@("`@("`@("!I9B`H)'9A
M<BT^:7-!<G)A>59A;"@I*2!["B`@("`@("`@("`@("`@("`D=F%R+3YG971)
M;F9O*"1V87)S+"`D=F%L=65S*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2@D=F%L=65S*2D@>PH@("`@("`@("`@("`@("`@("`@("1V87).86UE
M(#T@<W1R7W)E<&QA8V4H)UM=)RP@)R<L("1V87(M/F=E=%9A<DYA;64H*2D[
M"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E<R!A<R`D:2`]
M/B`D=F%L*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R1I75LD
M=F%R3F%M95T@/2`D=F%L.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@(')E<75I<F5?;VYC92`G2&]R9&4O07)R87DN<&AP)SL*("`@("`@("`@
M("`@("`@(&EF("A(;W)D95]!<G)A>3HZ9V5T07)R87E087)T<R@D=F%R+3YG
M971687).86UE*"DL("1B87-E+"`D:V5Y<RDI('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1I;F9O6R1B87-E72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&EN9F];)&)A<V5=(#T@87)R87DH*3L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'!O:6YT97(@/2`F
M)&EN9F];)&)A<V5=.PH@("`@("`@("`@("`@("`@("`@('=H:6QE("AC;W5N
M="@D:V5Y<RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&ME>2`](&%R
M<F%Y7W-H:69T*"1K97ES*3L*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D<&]I;G1E<ELD:V5Y72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P;VEN=&5R6R1K97E=(#T@87)R87DH*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`D<&]I
M;G1E<B`]("8D<&]I;G1E<ELD:V5Y73L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@)'9A<BT^9V5T26YF;R@D=F%R<RP@)'!O
M:6YT97(I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D=F%R+3YG971);F9O*"1V87)S+"`D:6YF;ULD=F%R+3YG9716
M87).86UE*"E=*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!H87-(96QP*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]H96QP.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1&5T97)M:6YE<R!I9B!T:&ES(&9O<FT@:&%S(&)E96X@<W5B;6ET
M=&5D(&]R(&YO="X@268@=&AE(&-L87-S"B`@("`@*B!V87(@7W-U8FUI='1E
M9"!I<R!N=6QL('1H96X@:70@=VEL;"!C:&5C:R!F;W(@=&AE('!R97-E;F-E
M(&]F"B`@("`@*B!T:&4@9F]R;6YA;64@:6X@=&AE(&9O<FT@=F%R:6%B;&5S
M+@H@("`@("H*("`@("`J($]T:&5R(&5V96YT<R!C86X@97AP;&EC:71L>2!S
M970@=&AE(%]S=6)M:71T960@=F%R:6%B;&4@=&\*("`@("`J(&9A;'-E('1O
M(&EN9&EC871E(&$@9F]R;2!S=6)M:70@8G5T(&YO="!F;W(@86-T=6%L('!O
M<W1I;F<@;V8*("`@("`J(&1A=&$@*&5G+B!O;D-H86YG92!E=F5N=',@=&\@
M=7!D871E('1H92!D:7-P;&%Y(&]F(&9I96QD<RDN"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!4<G5E(&]R(&9A;'-E(&EN9&EC871I;F<@:68@
M=&AE(&9O<FT@:&%S(&)E96X*("`@("`J("`@("`@("`@("`@("`@("`@<W5B
M;6ET=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<U-U8FUI='1E9"@I"B`@
M("!["B`@("`@("`@:68@*&ES7VYU;&PH)'1H:7,M/E]S=6)M:71T960I*2![
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^7W9A<G,M/F=E="@G9F]R;6YA;64G
M*2`]/2`D=&AI<RT^9V5T3F%M92@I*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7W-U8FUI='1E9"`]('1R=64["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7W-U8FUI='1E9"`](&9A;'-E.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]S
M=6)M:71T960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@=&AE
M<F4@:7,@86YY=&AI;F<@=&\@9&\@;VX@=&AE('-U8FUI<W-I;VX@;V8@=&AE
M(&9O<FT@8GD*("`@("`J(&QO;W!I;F<@=&AR;W5G:"!E86-H('9A<FEA8FQE
M)W,@;VY3=6)M:70H*2!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@
M2&]R9&5?5F%R:6%B;&5S("1V87)S"B`@("`@*B\*("`@(&9U;F-T:6]N(&]N
M4W5B;6ET*"8D=F%R<RD*("`@('L*("`@("`@("`O*B!,;V]P('1H<F]U9V@@
M86QL('9A<G,@86YD(&-H96-K(&EF('1H97)E)W,@86YY=&AI;F<@=&\@9&\@
M;VX*("`@("`@("`@*B!S=6)M:70N("HO"B`@("`@("`@)'9A<FEA8FQE<R`]
M("1T:&ES+3YG971687)I86)L97,H*3L*("`@("`@("!F;W)E86-H("@D=F%R
M:6%B;&5S(&%S("1V87(I('L*("`@("`@("`@("`@)'9A<BT^='EP92T^;VY3
M=6)M:70H)'9A<BP@)'9A<G,I.PH@("`@("`@("`@("`O*B!)9B!C:&%N9V5S
M('1O('9A<B!B96EN9R!T<F%C:V5D(&1O;B=T(')E9VES=&5R('1H92!F;W)M
M(&%S"B`@("`@("`@("`@("`J('-U8FUI='1E9"!I9B!O;&0@=F%L=64@86YD
M(&YE=R!V86QU92!D:69F97(N("HO"B`@("`@("`@("`@(&EF("@D=F%R+3YG
M971/<'1I;VXH)W1R86-K8VAA;F=E)RDI('L*("`@("`@("`@("`@("`@("1V
M87)N86UE(#T@)'9A<BT^9V5T5F%R3F%M92@I.PH@("`@("`@("`@("`@("`@
M:68@*"%I<U]N=6QL*"1V87)S+3YG970H)V9O<FUN86UE)RDI("8F"B`@("`@
M("`@("`@("`@("`@("`@)'9A<G,M/F=E="@D=F%R;F%M92D@(3T@)'9A<G,M
M/F=E="@G7U]O;&1?)R`N("1V87)N86UE*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<W5B;6ET=&5D(#T@9F%L<V4["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!%>'!L:6-I=&QY('-E=',@=&AE('-T871E(&]F('1H92!F;W)M('-U
M8FUI="X*("`@("`J"B`@("`@*B!!;B!E=F5N="!C86X@;W9E<G)I9&4@=&AE
M(&%U=&]M871I8R!D971E<FUI;F%T:6]N(&]F('1H92!S=6)M:70@<W1A=&4*
M("`@("`J(&EN('1H92!I<U-U8FUI='1E9"@I(&9U;F-T:6]N+@H@("`@("H*
M("`@("`J($!P87)A;2!B;V]L96%N("1S=&%T92`@5VAE=&AE<B!T;R!S970@
M=&AE('-T871E(&]F('1H92!F;W)M(&%S(&)E:6YG"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@('-U8FUI='1E9"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V5T4W5B;6ET=&5D*"1S=&%T92`]('1R=64I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]S=6)M:71T960@/2`D<W1A=&4["B`@("!]"@I]"@HO*BH*("H@
M2&]R9&5?1F]R;5]4>7!E($-L87-S"B`J"B`J($!A=71H;W(@(%)O8F5R="!%
M+B!#;WEL92`\<F]B97)T96-O>6QE0&AO=&UA:6PN8V]M/@H@*B!`<&%C:V%G
M92!(;W)D95]&;W)M"B`J+PIC;&%S<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@
M(&9U;F-T:6]N($AO<F1E7T9O<FU?5'EP92@I"B`@("!["B`@("!]"@H@("`@
M9G5N8W1I;VX@:6YI="@I"B`@("!["B`@("!]"@H@("`@9G5N8W1I;VX@;VY3
M=6)M:70H*0H@("`@>PH@("`@?0H*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V
M87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@
M)&UE<W-A9V4@/2`G/'-T<F]N9SY%<G)O<CH\+W-T<F]N9SX@2&]R9&5?1F]R
M;5]4>7!E.CII<U9A;&ED*"D@8V%L;&5D("T@<VAO=6QD(&)E(&]V97)R:61D
M96X\8G(@+SXG.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("!F
M=6YC=&EO;B!G9714>7!E3F%M92@I"B`@("!["B`@("`@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92]3=')I;F<N<&AP)SL*("`@("`@("!R971U<FX@<W1R7W)E
M<&QA8V4H)VAO<F1E7V9O<FU?='EP95\G+"`G)RP@4W1R:6YG.CIL;W=E<BAG
M971?8VQA<W,H)'1H:7,I*2D["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T5F%L
M=65S*"D*("`@('L*("`@("`@("!R971U<FX@;G5L;#L*("`@('T*"B`@("!F
M=6YC=&EO;B!G971);F9O*"8D=F%R<RP@)B1V87(L("8D:6YF;RD*("`@('L*
M("`@("`@("`D:6YF;R`]("1V87(M/F=E=%9A;'5E*"1V87)S*3L*("`@('T*
M"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]S<&%C97(@97AT96YD<R!(;W)D
M95]&;W)M7U1Y<&4@>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D
M=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U
M="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@
M("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*("`@("`@("`D86)O=71;
M)VYA;64G72`](%\H(E-P86-E<B(I.PH@("`@("`@(')E='5R;B`D86)O=70[
M"B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?=V5A=&AE<F1O=&-O
M;2!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@=F%R("1?<F5G97@[
M"B`@("!V87(@)%]S:7IE.PH@("`@=F%R("1?;6%X;&5N9W1H.PH*("`@("\J
M*@H@("`@("H@5&AE(&EN:71I86QI<V%T:6]N(&9U;F-T:6]N(&9O<B!T:&4@
M=&5X="!V87)I86)L92!T>7!E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)')E9V5X("`@("`@
M($%N>2!V86QI9"!02%`@4$-212!P871T97)N('-Y;G1A>"!T:&%T"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!N965D<R!T;R!B92!M871C
M:&5D(&9O<B!T:&4@9FEE;&0@=&\@8F4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&-O;G-I9&5R960@=F%L:60N($EF(&QE9G0@96UP='D@
M=F%L:61I='D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@('=I
M;&P@8F4@8VAE8VME9"!O;FQY(&9O<B!R97%U:7)E9"!F:65L9',*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('=H971H97(@=&AE>2!A<F4@
M96UP='D@;W(@;F]T+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@268@=7-I;F<@=&AI<R!R96=E>"!T97-T(&ET(&ES(&%D=FES86)L90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&\@96YT97(@82!D
M97-C<FEP=&EO;B!F;W(@=&AI<R!F:65L9"!T;PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=V%R;B!T:&4@=7-E<B!W:&%T(&ES(&5X<&5C
M=&5D+"!A<R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&=E;F5R871E9"!E<G)O<B!M97-S86=E(&ES('%U:71E(&=E;F5R:6,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%N9"!W:6QL(&YO="!G
M:79E(&%N>2!I;F1I8V%T:6]N('=H97)E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!T:&4@<F5G97@@9F%I;&5D+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'-I>F4@("`@("`@5&AE('-I>F4@;V8@=&AE(&EN<'5T(&9I
M96QD+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UA>&QE;F=T:"`@5&AE(&UA
M>"!N=6UB97(@;V8@8VAA<F%C=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M:6YI="@D<F5G97@@/2`G)RP@)'-I>F4@/2`T,"P@)&UA>&QE;F=T:"`](&YU
M;&PI"B`@("!["B`@("`@("`@)'1H:7,M/E]R96=E>"`@("`@/2`D<F5G97@[
M"B`@("`@("`@)'1H:7,M/E]S:7IE("`@("`@/2`D<VEZ93L*("`@("`@("`D
M=&AI<RT^7VUA>&QE;F=T:"`]("1M87AL96YG=&@["B`@("!]"@H@("`@9G5N
M8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G
M92D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?;6%X;&5N9W1H
M*2`F)B!3=')I;F<Z.FQE;F=T:"@D=F%L=64I(#X@)'1H:7,M/E]M87AL96YG
M=&@I('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!S<')I;G1F*%\H(E9A;'5E
M(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(I+"`D=&AI<RT^
M7VUA>&QE;F=T:"D["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@(')E<75I<F5?;VYC92`G4V5R=FEC97,O5V5A=&AE<BYP
M:'`G.PH@("`@("`@("1W96%T:&5R1&]T0V]M(#T@)E-E<G9I8V5S7U=E871H
M97(Z.G-E<G9I8V4H)U=E871H97)$;W1#;VTG*3L*("`@("`@("`D=V5A=&AE
M<D1O=$-O;2T^<V5T06-C;W5N=$1A=&$H)SQ087)T;F5R240^)RP@)SQ,:6-E
M;G-E2V5Y/B<I.PH@("`@("`@("1S96%R8V@@/2`D=V5A=&AE<D1O=$-O;2T^
M<V5A<F-H3&]C871I;VXH)'9A;'5E*3L*"B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1S96%R8V@I*2!["B`@("`@("`@("`@("1M97-S86=E(#T@7R@B5F%L:60@
M;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(I("X@:6UP;&]D92@G+"`G+"`D
M<V5A<F-H*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@
M96QS96EF("AI<U]A*"1S96%R8V@L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@)&UE<W-A9V4@/2`D<V5A<F-H+3YG971-97-S86=E*"D["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I
M;VX@9V5T4VEZ92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<VEZ
M93L*("`@('T*"B`@("!F=6YC=&EO;B!G971-87A,96YG=&@H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7VUA>&QE;F=T:#L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@
M/2!A<G)A>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B5V5A=&AE
M<BYC;VTB*3L*("`@("`@("`D86)O=71;)W!A<F%M<R==(#T@87)R87DH"B`@
M("`@("`@("`@("=R96=E>"<@("`@(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B
M4F5G97@B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y
M<&4G("`]/B`G=&5X="<I+`H@("`@("`@("`@("`G<VEZ92<@("`@("`]/B!A
M<G)A>2@G;&%B96PG(#T^(%\H(E-I>F4B*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G:6YT)RDL"B`@("`@("`@("`@
M("=M87AL96YG=&@G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B36%X:6UU;2!L
M96YG=&@B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y
M<&4G("`]/B`G:6YT)RDL"B`@("`@("`@*3L*("`@("`@("!R971U<FX@)&%B
M;W5T.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7VAE861E<B!E
M>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@9G5N8W1I;VX@:7-686QI
M9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A<G)A>2@I.PH@("`@
M("`@("1A8F]U=%LG;F%M92==(#T@7R@B2&5A9&5R(BD["B`@("`@("`@<F5T
M=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]D
M97-C<FEP=&EO;B!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@9G5N
M8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G
M92D*("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A
M<G)A>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B1&5S8W)I<'1I
M;VXB*3L*("`@("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*?0H*+RHJ"B`J
M(%-I;7!L>2!R96YD97)S(&ET<R!R87<@=F%L=64@:6X@8F]T:"!A8W1I=F4@
M86YD(&EN86-T:79E(')E;F1E<FEN9RX*("HO"F-L87-S($AO<F1E7T9O<FU?
M5'EP95]H=&UL(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!F=6YC
M=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E
M*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R
M<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")(5$U,(BD["B`@
M("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O
M<FU?5'EP95]N=6UB97(@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@
M('9A<B`D7V9R86-T:6]N.PH*("`@(&9U;F-T:6]N(&EN:70H)&9R86-T:6]N
M(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7V9R86-T:6]N(#T@)&9R
M86-T:6]N.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D
M=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@:68@*"1V
M87(M/FES4F5Q=6ER960H*2`F)B!E;7!T>2@D=F%L=64I("8F("@H<W1R:6YG
M*2AD;W5B;&4I)'9A;'5E("$]/2`D=F%L=64I*2!["B`@("`@("`@("`@("1M
M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB*3L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@96QS96EF("AE;7!T>2@D
M=F%L=64I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*
M"B`@("`@("`@+RH@268@;6%T8VAE9"P@=&AE;B!T:&ES(&ES(&$@8V]R<F5C
M="!N=6UE<FEC('9A;'5E+B`J+PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"1T
M:&ES+3Y?9V5T5F%L:61A=&EO;E!A='1E<FXH*2P@)'9A;'5E*2D@>PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1M97-S
M86=E(#T@7R@B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(I
M.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("!F=6YC=&EO;B!?
M9V5T5F%L:61A=&EO;E!A='1E<FXH*0H@("`@>PH@("`@("`@('-T871I8R`D
M<&%T=&5R;B`]("<G.PH@("`@("`@(&EF("@A96UP='DH)'!A='1E<FXI*2![
M"B`@("`@("`@("`@(')E='5R;B`D<&%T=&5R;CL*("`@("`@("!]"@H@("`@
M("`@("\J($=E="!C=7)R96YT(&QO8V%L92!I;F9O<FUA=&EO;BX@*B\*("`@
M("`@("`D;&EN9F\@/2!.3%,Z.F=E=$QO8V%L94EN9F\H*3L*"B`@("`@("`@
M+RH@0G5I;&0@=&AE('!A='1E<FXN("HO"B`@("`@("`@)'!A='1E<FX@/2`G
M*"TI/R<["@H@("`@("`@("\J($]N;'D@8VAE8VL@=&AO=7-A;F1S('-E<&%R
M871O<G,@:68@;&]C86QE(&AA<R!A;GDN("HO"B`@("`@("`@:68@*"%E;7!T
M>2@D;&EN9F];)VUO;E]T:&]U<V%N9'-?<V5P)UTI*2!["B`@("`@("`@("`@
M("\J(%)E9V5X('1O(&-H96-K(&9O<B!C;W)R96-T('1H;W5S86YD<R!S97!A
M<F%T;W)S("AI9B!A;GDI+B`J+PH@("`@("`@("`@("`D<&%T=&5R;B`N/2`G
M*"A<9"LI?"@H7&1[,"PS?3\I*%LG("X@)&QI;F9O6R=M;VY?=&AO=7-A;F1S
M7W-E<"==("X@)UU<9'LS?2DJ/RDI)SL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`O*B!.;R!L;V-A;&4@=&AO=7-A;F1S('-E<&%R871O<BP@8VAE
M8VL@9F]R(&]N;'D@9&EG:71S+B`J+PH@("`@("`@("`@("`D<&%T=&5R;B`N
M/2`G*%QD*RDG.PH@("`@("`@('T*("`@("`@("`O*B!)9B!N;R!D96-I;6%L
M('!O:6YT('-P96-I9FEE9"!D969A=6QT('1O(&1O="X@*B\*("`@("`@("!I
M9B`H96UP='DH)&QI;F9O6R=M;VY?9&5C:6UA;%]P;VEN="==*2D@>PH@("`@
M("`@("`@("`D;&EN9F];)VUO;E]D96-I;6%L7W!O:6YT)UT@/2`G+B<["B`@
M("`@("`@?0H@("`@("`@("\J(%)E9V5X('1O(&-H96-K(&9O<B!C;W)R96-T
M(&1E8VEM86QS("AI9B!A;GDI+B`J+PH@("`@("`@(&EF("AE;7!T>2@D=&AI
M<RT^7V9R86-T:6]N*2D@>PH@("`@("`@("`@("`D9G)A8W1I;VX@/2`G*B<[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&9R86-T:6]N(#T@)WLP
M+"<@+B`D=&AI<RT^7V9R86-T:6]N("X@)WTG.PH@("`@("`@('T*("`@("`@
M("`D<&%T=&5R;B`N/2`G*%LG("X@)&QI;F9O6R=M;VY?9&5C:6UA;%]P;VEN
M="==("X@)UTH7&0G("X@)&9R86-T:6]N("X@)RDI/R<["@H@("`@("`@("\J
M(%!U="!T;V=E=&AE<B!T:&4@=VAO;&4@<F5G97@@<&%T=&5R;BX@*B\*("`@
M("`@("`D<&%T=&5R;B`]("<O7B<@+B`D<&%T=&5R;B`N("<D+R<["@H@("`@
M("`@(')E='5R;B`D<&%T=&5R;CL*("`@('T*"B`@("!F=6YC=&EO;B!G971)
M;F9O*"8D=F%R<RP@)B1V87(L("8D:6YF;RD*("`@('L*("`@("`@("`D=F%L
M=64@/2`D=F%R<RT^9V5T*"1V87(M/F=E=%9A<DYA;64H*2D["B`@("`@("`@
M)&QI;F9O(#T@3DQ3.CIG971,;V-A;&5);F9O*"D["B`@("`@("`@)'9A;'5E
M(#T@<W1R7W)E<&QA8V4H)&QI;F9O6R=M;VY?=&AO=7-A;F1S7W-E<"==+"`G
M)RP@)'9A;'5E*3L*("`@("`@("`D:6YF;R`]('-T<E]R97!L86-E*"1L:6YF
M;ULG;6]N7V1E8VEM86Q?<&]I;G0G72P@)RXG+"`D=F%L=64I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A
M8F]U="`](&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*").
M=6UB97(B*3L*("`@("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*?0H*8VQA
M<W,@2&]R9&5?1F]R;5]4>7!E7VEN="!E>'1E;F1S($AO<F1E7T9O<FU?5'EP
M92!["@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L
M=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!I9B`H)'9A<BT^:7-297%U
M:7)E9"@I("8F(&5M<'1Y*"1V86QU92D@)B8@*"AS=')I;F<I*&EN="DD=F%L
M=64@(3T]("1V86QU92DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4
M:&ES(&9I96QD(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH)'9A;'5E*2!\
M?"!P<F5G7VUA=&-H*"<O7ELP+3E=*R0O)RP@)'9A;'5E*2D@>PH@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1M97-S86=E
M(#T@7R@B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(I
M.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A<G)A>2@I
M.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B26YT96=E<B(I.PH@("`@
M("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M
M7U1Y<&5?;V-T86P@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@(&9U
M;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A
M9V4I"B`@("!["B`@("`@("`@:68@*"1V87(M/FES4F5Q=6ER960H*2`F)B!E
M;7!T>2@D=F%L=64I("8F("@H<W1R:6YG*2AI;G0I)'9A;'5E("$]/2`D=F%L
M=64I*2!["B`@("`@("`@("`@("1M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I
M<R!R97%U:7)E9"XB*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1V86QU92D@?'P@<')E9U]M871C
M:"@G+UY;,"TW72LD+R<L("1V86QU92DI('L*("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@?0H*("`@("`@("`D;65S<V%G92`](%\H(E1H:7,@
M9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(BD["B`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@
M("`@)&%B;W5T6R=N86UE)UT@/2!?*")/8W1A;"(I.PH@("`@("`@(')E='5R
M;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?:6YT
M3&ES="!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@9G5N8W1I;VX@
M:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@
M('L*("`@("`@("!I9B`H96UP='DH)'9A;'5E*2`F)B`D=F%R+3YI<U)E<75I
M<F5D*"DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I96QD
M(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H*("`@("`@("!I9B`H96UP='DH)'9A;'5E*2!\?"!P<F5G7VUA
M=&-H*"<O7ELP+3D@+%TK)"\G+"`D=F%L=64I*2!["B`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)&UE<W-A9V4@/2!?*")4
M:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@
M;&ES="!O9B!I;G1E9V5R<R(I.PH@("`@("`@(')E='5R;B!F86QS93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y
M<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@
M("`D86)O=70@/2!A<G)A>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@
M7R@B26YT96=E<B!L:7-T(BD["B`@("`@("`@<F5T=7)N("1A8F]U=#L*("`@
M('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]T97AT(&5X=&5N9',@2&]R
M9&5?1F]R;5]4>7!E('L*"B`@("!V87(@)%]R96=E>#L*("`@('9A<B`D7W-I
M>F4["B`@("!V87(@)%]M87AL96YG=&@["@H@("`@+RHJ"B`@("`@*B!4:&4@
M:6YI=&EA;&ES871I;VX@9G5N8W1I;VX@9F]R('1H92!T97AT('9A<FEA8FQE
M('1Y<&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<F5G97@@("`@("`@06YY('9A;&ED(%!(
M4"!00U)%('!A='1E<FX@<WEN=&%X('1H870*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&YE961S('1O(&)E(&UA=&-H960@9F]R('1H92!F
M:65L9"!T;R!B90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8V]N<VED97)E9"!V86QI9"X@268@;&5F="!E;7!T>2!V86QI9&ET>0H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=VEL;"!B92!C:&5C:V5D
M(&]N;'D@9F]R(')E<75I<F5D(&9I96QD<PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=VAE=&AE<B!T:&5Y(&%R92!E;7!T>2!O<B!N;W0N
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!)9B!U<VEN9R!T
M:&ES(')E9V5X('1E<W0@:70@:7,@861V:7-A8FQE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!T;R!E;G1E<B!A(&1E<V-R:7!T:6]N(&9O
M<B!T:&ES(&9I96QD('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!W87)N('1H92!U<V5R('=H870@:7,@97AP96-T960L(&%S('1H90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@9V5N97)A=&5D(&5R
M<F]R(&UE<W-A9V4@:7,@<75I=&4@9V5N97)I8PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@86YD('=I;&P@;F]T(&=I=F4@86YY(&EN9&EC
M871I;VX@=VAE<F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('1H92!R96=E>"!F86EL960N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<VEZ
M92`@("`@("!4:&4@<VEZ92!O9B!T:&4@:6YP=70@9FEE;&0N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D;6%X;&5N9W1H("!4:&4@;6%X(&YU;6)E<B!O9B!C
M:&%R86-T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!I;FET*"1R96=E>"`]
M("<G+"`D<VEZ92`](#0P+"`D;6%X;&5N9W1H(#T@;G5L;"D*("`@('L*("`@
M("`@("`D=&AI<RT^7W)E9V5X("`@("`]("1R96=E>#L*("`@("`@("`D=&AI
M<RT^7W-I>F4@("`@("`]("1S:7IE.PH@("`@("`@("1T:&ES+3Y?;6%X;&5N
M9W1H(#T@)&UA>&QE;F=T:#L*("`@('T*"B`@("!F=6YC=&EO;B!I<U9A;&ED
M*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@>PH@("`@
M("`@("1V86QI9"`]('1R=64["@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M
M/E]M87AL96YG=&@I("8F(%-T<FEN9SHZ;&5N9W1H*"1V86QU92D@/B`D=&AI
M<RT^7VUA>&QE;F=T:"D@>PH@("`@("`@("`@("`D=F%L:60@/2!F86QS93L*
M("`@("`@("`@("`@)&UE<W-A9V4@/2!S<')I;G1F*%\H(E9A;'5E(&ES(&]V
M97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(I+"`D=&AI<RT^7VUA>&QE
M;F=T:"D["B`@("`@("`@?2!E;'-E:68@*"1V87(M/FES4F5Q=6ER960H*2`F
M)B!E;7!T>2@D=&AI<RT^7W)E9V5X*2D@>PH@("`@("`@("`@("`D=F%L:60@
M/2!S=')L96XH=')I;2@D=F%L=64I*2`^(#`["@H@("`@("`@("`@("!I9B`H
M(21V86QI9"D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES
M(&9I96QD(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E:68@*"%E;7!T>2@D=&AI<RT^7W)E9V5X*2D@>PH@("`@("`@("`@
M("`D=F%L:60@/2!P<F5G7VUA=&-H*"1T:&ES+3Y?<F5G97@L("1V86QU92D[
M"@H@("`@("`@("`@("!I9B`H(21V86QI9"D@>PH@("`@("`@("`@("`@("`@
M)&UE<W-A9V4@/2!?*")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E
M+B(I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)'9A;&ED.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%-I>F4H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7W-I>F4["B`@("!]"@H@("`@9G5N8W1I
M;VX@9V5T36%X3&5N9W1H*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/E]M87AL96YG=&@["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF
M;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U
M="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*("`@("`@("`D
M86)O=71;)VYA;64G72`](%\H(E1E>'0B*3L*("`@("`@("`D86)O=71;)W!A
M<F%M<R==(#T@87)R87DH"B`@("`@("`@("`@("=R96=E>"<@("`@(#T^(&%R
M<F%Y*"=L86)E;"<@/3X@7R@B4F5G97@B*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G=&5X="<I+`H@("`@("`@("`@
M("`G<VEZ92<@("`@("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E-I>F4B*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G
M:6YT)RDL"B`@("`@("`@("`@("=M87AL96YG=&@G(#T^(&%R<F%Y*"=L86)E
M;"<@/3X@7R@B36%X:6UU;2!L96YG=&@B*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G:6YT)RDL"B`@("`@("`@*3L*
M("`@("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?
M1F]R;5]4>7!E7W-T<FEN9VQI<W0@97AT96YD<R!(;W)D95]&;W)M7U1Y<&5?
M=&5X="!["@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L
M9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@
M("`@("`@)&%B;W5T(#T@87)R87DH*3L*("`@("`@("`D86)O=71;)VYA;64G
M72`](%\H(E-T<FEN9R!L:7-T(BD["B`@("`@("`@)&%B;W5T6R=P87)A;7,G
M72`](&%R<F%Y*`H@("`@("`@("`@("`G<F5G97@G("`@("`]/B!A<G)A>2@G
M;&%B96PG(#T^(%\H(E)E9V5X(BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=T>7!E)R`@/3X@)W1E>'0G*2P*("`@("`@("`@("`@)W-I
M>F4G("`@("`@/3X@87)R87DH)VQA8F5L)R`]/B!?*")3:7IE(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)VEN="<I
M+`H@("`@("`@("`@("`G;6%X;&5N9W1H)R`]/B!A<G)A>2@G;&%B96PG(#T^
M(%\H(DUA>&EM=6T@;&5N9W1H(BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=T>7!E)R`@/3X@)VEN="<I+`H@("`@("`@("D["B`@("`@
M("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?
M5'EP95]C96QL<&AO;F4@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@
M(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE
M<W-A9V4I"B`@("!["B`@("`@("`@)'9A;&ED(#T@=')U93L*"B`@("`@("`@
M:68@*"1V87(M/FES4F5Q=6ER960H*2D@>PH@("`@("`@("`@("`D=F%L:60@
M/2!S=')L96XH=')I;2@D=F%L=64I*2`^(#`["B`@("`@("`@("`@(&EF("@A
M)'9A;&ED*2!["B`@("`@("`@("`@("`@("`D;65S<V%G92`](%\H(E1H:7,@
M9FEE;&0@:7,@<F5Q=6ER960N(BD["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D=F%L:60@/2!P<F5G7VUA=&-H*"<O7EPK
M/UM<9"@I7"U<+R!=*B0O)RP@)'9A;'5E*3L*("`@("`@("`@("`@:68@*"$D
M=F%L:60I('L*("`@("`@("`@("`@("`@("1M97-S86=E(#T@7R@B66]U(&AA
M=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@
M;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N
M86P@9&EA;&EN9R!P<F5F:7@N(BD["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D=F%L:60["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH
M*3L*("`@("`@("`D86)O=71;)VYA;64G72`](%\H(D-E;&QP:&]N92(I.PH@
M("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&
M;W)M7U1Y<&5?:7!A9&1R97-S(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E7W1E
M>'0@>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@)'9A
M;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@)'9A;&ED(#T@=')U93L*
M"B`@("`@("`@:68@*'-T<FQE;BAT<FEM*"1V86QU92DI(#X@,"D@>PH@("`@
M("`@("`@("`D:7`@/2!E>'!L;V1E*"<N)RP@)'9A;'5E*3L*("`@("`@("`@
M("`@)'9A;&ED(#T@*&-O=6YT*"1I<"D@/3T@-"D["B`@("`@("`@("`@(&EF
M("@D=F%L:60I('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1I<"!A<R`D
M<&%R="D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?;G5M97)I8R@D
M<&%R="D@?'P*("`@("`@("`@("`@("`@("`@("`@("`@)'!A<G0@/B`R-34@
M?'P*("`@("`@("`@("`@("`@("`@("`@("`@)'!A<G0@/"`P*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1V86QI9"`](&9A;'-E.PH@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF
M("@A)'9A;&ED*2!["B`@("`@("`@("`@("`@("`D;65S<V%G92`](%\H(E!L
M96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(BD["B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V5I9B`H)'9A<BT^:7-297%U:7)E9"@I*2!["B`@
M("`@("`@("`@("1V86QI9"`](&9A;'-E.PH@("`@("`@("`@("`D;65S<V%G
M92`](%\H(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(BD["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'9A;&ED.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@G;F%M
M92<@/3X@7R@B25`@061D<F5S<R(I*3L*("`@('T*"GT*"F-L87-S($AO<F1E
M7T9O<FU?5'EP95]L;VYG5&5X="!E>'1E;F1S($AO<F1E7T9O<FU?5'EP95]T
M97AT('L*"B`@("!V87(@)%]R;W=S.PH@("`@=F%R("1?8V]L<SL*("`@('9A
M<B`D7VAE;'!E<B`](&%R<F%Y*"D["@H@("`@9G5N8W1I;VX@:6YI="@D<F]W
M<R`](#@L("1C;VQS(#T@.#`L("1H96QP97(@/2`G)RD*("`@('L*("`@("`@
M("`D=&AI<RT^7W)O=W,@/2`D<F]W<SL*("`@("`@("`D=&AI<RT^7V-O;',@
M/2`D8V]L<SL*("`@("`@("`D=&AI<RT^7VAE;'!E<B`]("1H96QP97(["B`@
M("!]"@H@("`@9G5N8W1I;VX@9V5T4F]W<R@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<F]W<SL*("`@('T*"B`@("!F=6YC=&EO;B!G971#;VQS
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]C;VQS.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&AA<TAE;'!E<B@D;W!T:6]N(#T@)R<I"B`@("!["B`@
M("`@("`@:68@*&5M<'1Y*"1O<'1I;VXI*2!["B`@("`@("`@("`@("\J($YO
M(&]P=&EO;B!S<&5C:69I960L(&-H96-K(&EF(&%N>2!H96QP97)S(&AA=F4@
M8F5E;@H@("`@("`@("`@("`@*B!A8W1I=F%T960N("HO"B`@("`@("`@("`@
M(')E='5R;B`A96UP='DH)'1H:7,M/E]H96QP97(I.PH@("`@("`@('T@96QS
M96EF("AE;7!T>2@D=&AI<RT^7VAE;'!E<BDI('L*("`@("`@("`@("`@+RH@
M3F\@:&5L<&5R<R!A8W1I=F%T960@870@86QL+"!R971U<FX@9F%L<V4N("HO
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`O*B!#:&5C:R!I9B!G:79E;B!H96QP97(@:&%S(&)E96X@
M86-T:79A=&5D+B`J+PH@("`@("`@("`@("!R971U<FX@:6Y?87)R87DH)&]P
M=&EO;BP@)'1H:7,M/E]H96QP97(I.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@
M/2!A<G)A>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B3&]N9R!T
M97AT(BD["B`@("`@("`@)&%B;W5T6R=P87)A;7,G72`](&%R<F%Y*`H@("`@
M("`@("`@("`G<F]W<R<@("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(DYU;6)E
M<B!O9B!R;W=S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T
M>7!E)R`@/3X@)VEN="<I+`H@("`@("`@("`@("`G8V]L<R<@("`]/B!A<G)A
M>2@G;&%B96PG(#T^(%\H(DYU;6)E<B!O9B!C;VQU;6YS(BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)VEN="<I+`H@("`@
M("`@("`@("`G:&5L<&5R)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(DAE;'!E
M<B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^
M("=B;V]L96%N)RD*("`@("`@("`I.PH@("`@("`@(')E='5R;B`D86)O=70[
M"B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?8V]U;G1E9%1E>'0@
M97AT96YD<R!(;W)D95]&;W)M7U1Y<&5?;&]N9U1E>'0@>PH*("`@('9A<B`D
M7V-H87)S.PH*("`@(&9U;F-T:6]N(&EN:70H)')O=W,@/2!N=6QL+"`D8V]L
M<R`](&YU;&PL("1C:&%R<R`](#$P,#`I"B`@("!["B`@("`@("`@<&%R96YT
M.CII;FET*"1R;W=S+"`D8V]L<RD["B`@("`@("`@)'1H:7,M/E]C:&%R<R`]
M("1C:&%R<SL*("`@('T*"B`@("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F
M)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@>PH@("`@("`@("1V86QI
M9"`]('1R=64["@H@("`@("`@(&EF("@D=F%R+3YI<U)E<75I<F5D*"DI('L*
M("`@("`@("`@("`@)&QE;F=T:"`](%-T<FEN9SHZ;&5N9W1H*'1R:6TH)'9A
M;'5E*2D["@H@("`@("`@("`@("!I9B`H)&QE;F=T:"`\/2`P*2!["B`@("`@
M("`@("`@("`@("`D=F%L:60@/2!F86QS93L*("`@("`@("`@("`@("`@("1M
M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB*3L*("`@("`@
M("`@("`@?2!E;'-E:68@*"1L96YG=&@@/B`D=&AI<RT^7V-H87)S*2!["B`@
M("`@("`@("`@("`@("`D=F%L:60@/2!F86QS93L*("`@("`@("`@("`@("`@
M("1M97-S86=E(#T@<W!R:6YT9BA?*")4:&5R92!A<F4@=&]O(&UA;GD@8VAA
M<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H
M87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB*2P@4W1R
M:6YG.CIL96YG=&@H=')I;2@D=F%L=64I*2P@)'1H:7,M/E]C:&%R<RD["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=F%L:60[
M"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T0VAA<G,H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7V-H87)S.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D[
M"B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")#;W5N=&5D('1E>'0B*3L*
M("`@("`@("`D86)O=71;)W!A<F%M<R==(#T@87)R87DH"B`@("`@("`@("`@
M("=R;W=S)R`@/3X@87)R87DH)VQA8F5L)R`]/B!?*").=6UB97(@;V8@<F]W
M<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@
M)VEN="<I+`H@("`@("`@("`@("`G8V]L<R<@(#T^(&%R<F%Y*"=L86)E;"<@
M/3X@7R@B3G5M8F5R(&]F(&-O;'5M;G,B*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G='EP92<@(#T^("=I;G0G*2P*("`@("`@("`@("`@)V-H
M87)S)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(DYU;6)E<B!O9B!C:&%R86-T
M97)S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]
M/B`G:6YT)RD*("`@("`@("`I.PH@("`@("`@(')E='5R;B`D86)O=70["B`@
M("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?861D<F5S<R!E>'1E;F1S
M($AO<F1E7T9O<FU?5'EP95]L;VYG5&5X="!["@H@("`@+RHJ"B`@("`@*B!2
M971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*
M("`@("`@("`D86)O=71;)VYA;64G72`](%\H(D%D9')E<W,B*3L*("`@("`@
M("`D86)O=71;)W!A<F%M<R==(#T@87)R87DH"B`@("`@("`@("`@("=R;W=S
M)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(DYU;6)E<B!O9B!R;W=S(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=I;G0G*2P*
M("`@("`@("`@("`@)V-O;',G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B3G5M
M8F5R(&]F(&-O;'5M;G,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=T>7!E)R`@/3X@)VEN="<I*3L*("`@("`@("!R971U<FX@)&%B;W5T.PH@
M("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7V9I;&4@97AT96YD<R!(
M;W)D95]&;W)M7U1Y<&4@>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L
M("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@:68@
M*"1V87(M/FES4F5Q=6ER960H*2D@>PH@("`@("`@("`@("`D=7!L;V%D960@
M/2!"<F]W<V5R.CIW87-&:6QE57!L;V%D960H)'9A<BT^9V5T5F%R3F%M92@I
M*3L*("`@("`@("`@("`@:68@*&ES7V$H)'5P;&]A9&5D+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("`D;65S<V%G92`]("1U<&QO861E9"T^
M9V5T365S<V%G92@I.PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("!F=6YC=&EO;B!G971);F9O*"8D=F%R<RP@)B1V87(L("8D
M:6YF;RD*("`@('L*("`@("`@("`D;F%M92`]("1V87(M/F=E=%9A<DYA;64H
M*3L*("`@("`@("`D=7!L;V%D960@/2!"<F]W<V5R.CIW87-&:6QE57!L;V%D
M960H)&YA;64I.PH@("`@("`@(&EF("@D=7!L;V%D960@/3T]('1R=64I('L*
M("`@("`@("`@("`@)&EN9F];)VYA;64G72`]("1?1DE,15-;)&YA;65=6R=N
M86UE)UT["B`@("`@("`@("`@("1I;F9O6R=T>7!E)UT@/2`D7T9)3$536R1N
M86UE75LG='EP92==.PH@("`@("`@("`@("`D:6YF;ULG=&UP7VYA;64G72`]
M("1?1DE,15-;)&YA;65=6R=T;7!?;F%M92==.PH@("`@("`@("`@("`D:6YF
M;ULG9FEL92==(#T@)%]&24Q%4ULD;F%M95U;)W1M<%]N86UE)UT["B`@("`@
M("`@("`@("1I;F9O6R=E<G)O<B==(#T@)%]&24Q%4ULD;F%M95U;)V5R<F]R
M)UT["B`@("`@("`@("`@("1I;F9O6R=S:7IE)UT@/2`D7T9)3$536R1N86UE
M75LG<VEZ92==.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%B;W5T*"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH)VYA;64G
M(#T^(%\H(D9I;&4@=7!L;V%D(BDI.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?
M1F]R;5]4>7!E7VEM86=E(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@
M("`O*BH*("`@("`J($AA<R!A(&9I;&4@8F5E;B!U<&QO861E9"!O;B!T:&ES
M(&9O<FT@<W5B;6ET/PH@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@
M("HO"B`@("!V87(@)%]U<&QO861E9"`](&YU;&P["@H@("`@+RHJ"B`@("`@
M*B!3:&]W('1H92!U<&QO860@8G5T=&]N/PH@("`@("H*("`@("`J($!V87(@
M8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]S:&]W7W5P;&]A9"`]('1R=64[
M"@H@("`@+RHJ"B`@("`@*B!3:&]W('1H92!O<'1I;VX@=&\@=7!L;V%D(&%L
M<V\@;W)I9VEN86P@;F]N+6UO9&EF:65D(&EM86=E/PH@("`@("H*("`@("`J
M($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]S:&]W7VME97!O<FEG
M/2!F86QS93L*"B`@("`O*BH*("`@("`J($AA<V@@8V]N=&%I;FEN9R!T:&4@
M<')E=FEO=7-L>2!U<&QO861E9"!I;6%G92!I;F9O+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?:6UG(#T@87)R87DH*3L*
M"B`@("!F=6YC=&EO;B!I;FET*"1S:&]W7W5P;&]A9"`]('1R=64L("1S:&]W
M7VME97!O<FEG(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M/E]S:&]W
M7W5P;&]A9"`@(#T@)'-H;W=?=7!L;V%D.PH@("`@("`@("1T:&ES+3Y?<VAO
M=U]K965P;W)I9R`]("1S:&]W7VME97!O<FEG.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&]N4W5B;6ET*"8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@+RH@
M1V5T('1H92!U<&QO860N("HO"B`@("`@("`@)'1H:7,M/E]G9715<&QO860H
M)'9A<G,L("1V87(I.PH*("`@("`@("`O*B!)9B!T:&ES('=A<R!D;VYE('1H
M<F]U9V@@=&AE('5P;&]A9"!B=71T;VX@;W9E<G)I9&4@=&AE('-U8FUI='1E
M9`H@("`@("`@("`J('9A;'5E(&]F('1H92!F;W)M+B`J+PH@("`@("`@(&EF
M("@D=F%R<RT^9V5T*"=?9&]?)R`N("1V87(M/F=E=%9A<DYA;64H*2DI('L*
M("`@("`@("`@("`@)'9A<BT^9F]R;2T^<V5T4W5B;6ET=&5D*&9A;'-E*3L*
M("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@
M)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("`D9FEE
M;&0@/2`D=F%R<RT^9V5T*"1V87(M/F=E=%9A<DYA;64H*2D["@H@("`@("`@
M("\J($=E="!T:&4@=7!L;V%D+B`J+PH@("`@("`@("1T:&ES+3Y?9V5T57!L
M;V%D*"1V87)S+"`D=F%R*3L*"B`@("`@("`@+RH@5&AE('5P;&]A9"!G96YE
M<F%T960@82!014%2($5R<F]R+B`J+PH@("`@("`@(&EF("AI<U]A*"1T:&ES
M+3Y?=7!L;V%D960L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@+RH@
M3F]T(')E<75I<F5D(&%N9"!N;R!I;6%G92!U<&QO860@871T96UP=&5D+B`J
M+PH@("`@("`@("`@("!I9B`H(21V87(M/FES4F5Q=6ER960H*2`F)B!E;7!T
M>2@D9FEE;&1;)VEM9R==*2`F)@H@("`@("`@("`@("`@("`@)'1H:7,M/E]U
M<&QO861E9"T^9V5T0V]D92@I(#T](#0I('L*("`@("`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H*"1T
M:&ES+3Y?=7!L;V%D960M/F=E=$-O9&4H*2`]/2!54$Q/041?15)27TY/7T9)
M3$4I("8F"B`@("`@("`@("`@("`@("!E;7!T>2@D9FEE;&1;)VEM9R==*2D@
M>PH@("`@("`@("`@("`@("`@+RH@3F]T:&EN9R!U<&QO861E9"!A;F0@;F\@
M;VQD97(@=7!L;V%D+B`J+PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!?
M*")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1F
M:65L9%LG:6UG)UTI*2!["B`@("`@("`@("`@("`@("`O*B!.;W1H:6YG('5P
M;&]A9&5D(&)U="!O;&1E<B!U<&QO860@<')E<V5N="X@*B\*("`@("`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@+RH@4V]M92!O=&AE<B!E<G)O<B!M97-S86=E+B`J+PH@
M("`@("`@("`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^7W5P;&]A9&5D+3YG
M971-97-S86=E*"D["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&=E=$EN9F\H)B1V87)S+"`F)'9A<BP@)B1I
M;F9O*0H@("`@>PH@("`@("`@("\J($=E="!T:&4@=7!L;V%D+B`J+PH@("`@
M("`@("1T:&ES+3Y?9V5T57!L;V%D*"1V87)S+"`D=F%R*3L*"B`@("`@("`@
M+RH@1V5T(&EM86=E('!A<F%M<R!S=&]R960@:6X@=&AE(&AI9&1E;B!F:65L
M9"X@*B\*("`@("`@("`D=F%L=64@/2`D=F%R+3YG971686QU92@D=F%R<RD[
M"B`@("`@("`@)&EN9F\@/2`D=&AI<RT^7VEM9SL*("`@("`@("!I9B`H96UP
M='DH)&EN9F];)V9I;&4G72DI('L*("`@("`@("`@("`@=6YS970H)&EN9F];
M)V9I;&4G72D["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"B`@("`@
M("`@:68@*"1T:&ES+3Y?<VAO=U]K965P;W)I9RD@>PH@("`@("`@("`@("`D
M:6YF;ULG:V5E<%]O<FEG)UT@/2`A96UP='DH)'9A;'5E6R=K965P7V]R:6<G
M72D["B`@("`@("`@?0H*("`@("`@("`O*B!3970@=&AE('5P;&]A9&5D('9A
M;'5E("AE:71H97(@=')U92!O<B!014%27T5R<F]R*2X@*B\*("`@("`@("`D
M:6YF;ULG=7!L;V%D960G72`]("8D=&AI<RT^7W5P;&]A9&5D.PH*("`@("`@
M("`O*B!)9B!A(&UO9&EF:65D(&9I;&4@97AI<W1S(&UO=F4@:70@;W9E<B!T
M:&4@;W)I9VEN86PN("HO"B`@("`@("`@:68@*"1T:&ES+3Y?<VAO=U]K965P
M;W)I9R`F)B`D:6YF;ULG:V5E<%]O<FEG)UTI('L*("`@("`@("`@("`@+RH@
M4F5Q=65S=&5D('1H92!S879I;F<@;V8@;W)I9VEN86P@9FEL92!A;'-O+B`J
M+PH@("`@("`@("`@("`D:6YF;ULG;W)I9U]F:6QE)UT@/2!(;W)D93HZ9V5T
M5&5M<$1I<B@I("X@)R\G("X@)&EN9F];)V9I;&4G73L*("`@("`@("`@("`@
M)&EN9F];)V9I;&4G72`]($AO<F1E.CIG971496UP1&ER*"D@+B`G+VUO9%\G
M("X@)&EN9F];)V9I;&4G73L*("`@("`@("`@("`@+RH@0VAE8VL@:68@82!M
M;V1I9FEE9"!F:6QE(&%C='5A;&QY(&5X:7-T<RX@*B\*("`@("`@("`@("`@
M:68@*"%F:6QE7V5X:7-T<R@D:6YF;ULG9FEL92==*2D@>PH@("`@("`@("`@
M("`@("`@)&EN9F];)V9I;&4G72`]("1I;F9O6R=O<FEG7V9I;&4G73L*("`@
M("`@("`@("`@("`@('5N<V5T*"1I;F9O6R=O<FEG7V9I;&4G72D["B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!3879I
M;F<@;V8@;W)I9VEN86P@;F]T(')E<75I<F5D+B`J+PH@("`@("`@("`@("`D
M;6]D7V9I;&4@/2!(;W)D93HZ9V5T5&5M<$1I<B@I("X@)R]M;V1?)R`N("1I
M;F9O6R=F:6QE)UT["B`@("`@("`@("`@("1I;F9O6R=F:6QE)UT@/2!(;W)D
M93HZ9V5T5&5M<$1I<B@I("X@)R\G("X@)&EN9F];)V9I;&4G73L*"B`@("`@
M("`@("`@(&EF("AF:6QE7V5X:7-T<R@D;6]D7V9I;&4I*2!["B`@("`@("`@
M("`@("`@("`O*B!5;FQI;FL@9FER<W0@*&AA<R!T;R!B92!D;VYE(&]N(%=I
M;F1O=W,@;6%C:&EN97,_*2`J+PH@("`@("`@("`@("`@("`@=6YL:6YK*"1I
M;F9O6R=F:6QE)UTI.PH@("`@("`@("`@("`@("`@<F5N86UE*"1M;V1?9FEL
M92P@)&EN9F];)V9I;&4G72D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!U<&QO860@86YD('-E=',@
M=7`@=&AE('5P;&]A9"!D871A(&%R<F%Y+B!%:71H97(*("`@("`J(&9E=&-H
M97,@86X@=7!L;V%D(&1O;F4@=VET:"!T:&ES('-U8FUI="!O<B!R971R:65S
M('-T;W)E9`H@("`@("H@=7!L;V%D(&EN9F\N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]G9715<&QO860H)B1V87)S+"`F)'9A<BD*("`@('L*("`@("`@("`O
M*B!$;VXG="!B;W1H97(@=VET:"!T:&ES(&9U;F-T:6]N(&EF(&%L<F5A9'D@
M8V%L;&5D(&%N9"!S970*("`@("`@("`@*B!U<"!V87)S+B`J+PH@("`@("`@
M(&EF("@A96UP='DH)'1H:7,M/E]I;6<I*2!["B`@("`@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@+RH@0VAE8VL@:68@9FEL92!H
M87,@8F5E;B!U<&QO861E9"X@*B\*("`@("`@("`D=F%R;F%M92`]("1V87(M
M/F=E=%9A<DYA;64H*3L*("`@("`@("`D=&AI<RT^7W5P;&]A9&5D(#T@0G)O
M=W-E<CHZ=V%S1FEL955P;&]A9&5D*"1V87)N86UE("X@)UMN97==)RD["@H@
M("`@("`@(&EF("@D=&AI<RT^7W5P;&]A9&5D(#T]/2!T<G5E*2!["B`@("`@
M("`@("`@("\J($$@9FEL92!H87,@8F5E;B!U<&QO861E9"!O;B!T:&ES('-U
M8FUI="X@4V%V92!T;R!T96UP(&1I<B!F;W(*("`@("`@("`@("`@("H@<')E
M=FEE=R!W;W)K+B`J+PH@("`@("`@("`@("`D=&AI<RT^7VEM9ULG='EP92==
M(#T@)'1H:7,M/F=E=%5P;&]A9&5D1FEL951Y<&4H)'9A<FYA;64@+B`G6VYE
M=UTG*3L*"B`@("`@("`@("`@("\J($=E="!T:&4@;W1H97(@<&%R=',@;V8@
M=&AE('5P;&]A9"X@*B\*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D
M92]!<G)A>2YP:'`G.PH@("`@("`@("`@("!(;W)D95]!<G)A>3HZ9V5T07)R
M87E087)T<R@D=F%R;F%M92`N("=;;F5W72<L("1B87-E+"`D:V5Y<RD["@H@
M("`@("`@("`@("`O*B!'970@=&AE('1E;7!O<F%R>2!F:6QE(&YA;64N("HO
M"B`@("`@("`@("`@("1K97ES7W!A=&@@/2!A<G)A>5]M97)G92AA<G)A>2@D
M8F%S92P@)W1M<%]N86UE)RDL("1K97ES*3L*("`@("`@("`@("`@)'1H:7,M
M/E]I;6=;)V9I;&4G72`]($AO<F1E7T%R<F%Y.CIG971%;&5M96YT*"1?1DE,
M15,L("1K97ES7W!A=&@I.PH*("`@("`@("`@("`@+RH@1V5T('1H92!A8W1U
M86P@9FEL92!N86UE+B`J+PH@("`@("`@("`@("`D:V5Y<U]P871H/2!A<G)A
M>5]M97)G92AA<G)A>2@D8F%S92P@)VYA;64G*2P@)&ME>7,I.PH@("`@("`@
M("`@("`D=&AI<RT^7VEM9ULG;F%M92==(#T@2&]R9&5?07)R87DZ.F=E=$5L
M96UE;G0H)%]&24Q%4RP@)&ME>7-?<&%T:"D["@H@("`@("`@("`@("`O*B!'
M970@=&AE(&9I;&4@<VEZ92X@*B\*("`@("`@("`@("`@)&ME>7-?<&%T:#T@
M87)R87E?;65R9V4H87)R87DH)&)A<V4L("=S:7IE)RDL("1K97ES*3L*("`@
M("`@("`@("`@)'1H:7,M/E]I;6=;)W-I>F4G72`]($AO<F1E7T%R<F%Y.CIG
M971%;&5M96YT*"1?1DE,15,L("1K97ES7W!A=&@I.PH*("`@("`@("`@("`@
M+RH@1V5T(&%N>2!E>&ES=&EN9R!V86QU97,@9F]R('1H92!I;6%G92!U<&QO
M860@9FEE;&0N("HO"B`@("`@("`@("`@("1U<&QO860@/2`D=F%R<RT^9V5T
M*"1V87(M/F=E=%9A<DYA;64H*2D["B`@("`@("`@("`@("1U<&QO861;)VEM
M9R==(#T@0'5N<V5R:6%L:7IE*"1U<&QO861;)VEM9R==*3L*"B`@("`@("`@
M("`@("\J($=E="!T:&4@=&5M<"!F:6QE(&EF(&%L<F5A9'D@;VYE('5P;&]A
M9&5D+"!O=&AE<G=I<V4@8W)E871E(&$*("`@("`@("`@("`@("H@;F5W('1E
M;7!O<F%R>2!F:6QE+B`J+PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1U<&QO
M861;)VEM9R==6R=F:6QE)UTI*2!["B`@("`@("`@("`@("`@("`D=&UP7V9I
M;&4@/2!(;W)D93HZ9V5T5&5M<$1I<B@I("X@)R\G("X@)'5P;&]A9%LG:6UG
M)UU;)V9I;&4G73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1T;7!?9FEL92`]($AO<F1E.CIG971496UP1FEL92@G2&]R9&4G+"!F
M86QS92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($UO=F4@=&AE
M(&)R;W=S97(@8W)E871E9"!T96UP(&9I;&4@=&\@=&AE(&YE=R!T96UP(&9I
M;&4N("HO"B`@("`@("`@("`@(&UO=F5?=7!L;V%D961?9FEL92@D=&AI<RT^
M7VEM9ULG9FEL92==+"`D=&UP7V9I;&4I.PH@("`@("`@("`@("`D=&AI<RT^
M7VEM9ULG9FEL92==(#T@8F%S96YA;64H)'1M<%]F:6QE*3L*"B`@("`@("`@
M("`@("\J(%-T;W)E('1H92!U<&QO861E9"!I;6%G92!F:6QE(&1A=&$@=&\@
M=&AE(&AI9&1E;B!F:65L9"X@*B\*("`@("`@("`@("`@)'5P;&]A9%LG:6UG
M)UT@/2!S97)I86QI>F4H)'1H:7,M/E]I;6<I.PH@("`@("`@("`@("`D=F%R
M<RT^<V5T*"1V87(M/F=E=%9A<DYA;64H*2P@)'5P;&]A9"D["B`@("`@("`@
M?2!E;'-E:68@*"1T:&ES+3Y?=7!L;V%D960I('L*("`@("`@("`@("`@+RH@
M1FEL92!H87,@;F]T(&)E96X@=7!L;V%D960N("HO"B`@("`@("`@("`@("1U
M<&QO860@/2`D=F%R<RT^9V5T*"1V87(M/F=E=%9A<DYA;64H*2D["B`@("`@
M("`@("`@(&EF("@D=&AI<RT^7W5P;&]A9&5D+3YG971#;V1E*"D@/3T@-"`F
M)B`A96UP='DH)'5P;&]A9%LG:6UG)UTI*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7VEM9R`]($!U;G-E<FEA;&EZ92@D=7!L;V%D6R=I;6<G72D["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M57!L;V%D961&:6QE5'EP92@D9FEE;&0I"B`@("!["B`@("`@("`@+RH@1V5T
M(&%N>2!I;F1E>"!O;B!T:&4@9FEE;&0@;F%M92X@*B\*("`@("`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+T%R<F%Y+G!H<"<["B`@("`@("`@)&EN9&5X(#T@
M2&]R9&5?07)R87DZ.F=E=$%R<F%Y4&%R=',H)&9I96QD+"`D8F%S92P@)&ME
M>7,I.PH*("`@("`@("!I9B`H)&EN9&5X*2!["B`@("`@("`@("`@("\J($EN
M9&5X('!R97-E;G0L(&9E=&-H('1H92!M:6UE('1Y<&4@=F%R('1O(&-H96-K
M+B`J+PH@("`@("`@("`@("`D:V5Y<U]P871H(#T@87)R87E?;65R9V4H87)R
M87DH)&)A<V4L("=T>7!E)RDL("1K97ES*3L*("`@("`@("`@("`@)'1Y<&4@
M/2!(;W)D95]!<G)A>3HZ9V5T16QE;65N="@D7T9)3$53+"`D:V5Y<U]P871H
M*3L*("`@("`@("`@("`@)&ME>7-?<&%T:#T@87)R87E?;65R9V4H87)R87DH
M)&)A<V4L("=T;7!?;F%M92<I+"`D:V5Y<RD["B`@("`@("`@("`@("1T;7!?
M;F%M92`]($AO<F1E7T%R<F%Y.CIG971%;&5M96YT*"1?1DE,15,L("1K97ES
M7W!A=&@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J($YO(&EN
M9&5X+"!S:6UP;&4@<V5T('5P(&]F('9A<G,@=&\@8VAE8VLN("HO"B`@("`@
M("`@("`@("1T>7!E(#T@)%]&24Q%4ULD9FEE;&1=6R=T>7!E)UT["B`@("`@
M("`@("`@("1T;7!?;F%M92`]("1?1DE,15-;)&9I96QD75LG=&UP7VYA;64G
M73L*("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D='EP92D@?'P@*"1T
M>7!E(#T]("=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG*2D@>PH@("`@("`@
M("`@("`O*B!4>7!E('=A<VXG="!S970@;VX@=7!L;V%D+"!T<GD@86YA;&ES
M:6YG('1H92!U<&QO860N("HO"B`@("`@("`@("`@(&=L;V)A;"`D8V]N9CL*
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+TUA9VEC+G!H
M<"<["B`@("`@("`@("`@(&EF("@A*"1T>7!E(#T@34E-15]-86=I8SHZ86YA
M;'EZ949I;&4H)'1M<%]N86UE+"!I<W-E="@D8V]N9ELG;6EM92==6R=M86=I
M8U]D8B==*2`_("1C;VYF6R=M:6UE)UU;)VUA9VEC7V1B)UT@.B!N=6QL*2DI
M('L*("`@("`@("`@("`@("`@(&EF("@D:6YD97@I('L*("`@("`@("`@("`@
M("`@("`@("`O*B!'970@=&AE(&YA;64@=F%L=64N("HO"B`@("`@("`@("`@
M("`@("`@("`@)&ME>7-?<&%T:"`](&%R<F%Y7VUE<F=E*&%R<F%Y*"1B87-E
M+"`G;F%M92<I+"`D:V5Y<RD["B`@("`@("`@("`@("`@("`@("`@)&YA;64@
M/2!(;W)D95]!<G)A>3HZ9V5T16QE;65N="@D7T9)3$53+"`D:V5Y<U]P871H
M*3L*"B`@("`@("`@("`@("`@("`@("`@+RH@5V]R:R!O=70@=&AE('1Y<&4@
M9G)O;2!T:&4@9FEL92!N86UE+B`J+PH@("`@("`@("`@("`@("`@("`@("1T
M>7!E(#T@34E-15]-86=I8SHZ9FEL96YA;654;TU)344H)&YA;64I.PH*("`@
M("`@("`@("`@("`@("`@("`O*B!3970@=&AE('1Y<&4N("HO"B`@("`@("`@
M("`@("`@("`@("`@)&ME>7-?<&%T:"`](&%R<F%Y7VUE<F=E*&%R<F%Y*"1B
M87-E+"`G='EP92<I+"`D:V5Y<RD["B`@("`@("`@("`@("`@("`@("`@2&]R
M9&5?07)R87DZ.F=E=$5L96UE;G0H)%]&24Q%4RP@)&ME>7-?<&%T:"P@)'1Y
M<&4I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`O*B!7;W)K(&]U="!T:&4@='EP92!F<F]M('1H92!F:6QE(&YA;64N
M("HO"B`@("`@("`@("`@("`@("`@("`@)'1Y<&4@/2!-24U%7TUA9VEC.CIF
M:6QE;F%M951O34E-12@D7T9)3$536R1F:65L9%U;)VYA;64G72D["@H@("`@
M("`@("`@("`@("`@("`@("\J(%-E="!T:&4@='EP92X@*B\*("`@("`@("`@
M("`@("`@("`@("`D7T9)3$536R1F:65L9%U;)W1Y<&4G72`]($U)345?36%G
M:6,Z.F9I;&5N86UE5&]-24U%*"1?1DE,15-;)&9I96QD75LG;F%M92==*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1T>7!E.PH@("`@?0H*("`@("\J*@H@("`@("H@3&]A
M9',@86YY(&5X:7-T:6YG(&EM86=E(&1A=&$@:6YT;R!T:&4@:6UA9V4@9FEE
M;&0N(%)E<75I<F5S('1H870@=&AE"B`@("`@*B!A<G)A>2`D:6UA9V4@<&%S
M<V5D('1O(&ET(&-O;G1A:6YS('1H92!S=')U8W1U<F4Z"B`@("`@*B`@("1I
M;6%G95LG;&]A9"==6R=F:6QE)UT@+2!T:&4@9FEL96YA;64@;V8@=&AE(&EM
M86=E.PH@("`@("H@("`D:6UA9V5;)VQO860G75LG9&%T82==("T@=&AE(')A
M=R!I;6%G92!D871A+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D:6UA9V4@(%1H92!I;6%G92!A
M<G)A>2X*("`@("`J+PH@("`@9G5N8W1I;VX@7VQO861);6%G941A=&$H)B1I
M;6%G92D*("`@('L*("`@("`@("`O*B!.;R!E>&ES=&EN9R!I;6%G92!D871A
M('1O(&QO860N("HO"B`@("`@("`@:68@*"%I<W-E="@D:6UA9V5;)VQO860G
M72DI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@
M+RH@4V%V92!T:&4@9&%T82!T;R!T:&4@=&5M<"!D:7(N("HO"B`@("`@("`@
M)'1M<%]F:6QE(#T@2&]R9&4Z.F=E=%1E;7!$:7(H*2`N("<O)R`N("1I;6%G
M95LG;&]A9"==6R=F:6QE)UT["B`@("`@("`@:68@*"1F9"`](&9O<&5N*"1T
M;7!?9FEL92P@)W<G*2D@>PH@("`@("`@("`@("!F=W)I=&4H)&9D+"`D:6UA
M9V5;)VQO860G75LG9&%T82==*3L*("`@("`@("`@("`@9F-L;W-E*"1F9"D[
M"B`@("`@("`@?0H*("`@("`@("`D:6UA9V5;)VEM9R==(#T@<V5R:6%L:7IE
M*&%R<F%Y*"=F:6QE)R`]/B`D:6UA9V5;)VQO860G75LG9FEL92==*2D["B`@
M("`@("`@=6YS970H)&EM86=E6R=L;V%D)UTI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R
M<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*"));6%G92!U<&QO
M860B*3L*("`@("`@("`D86)O=71;)W!A<F%M<R==(#T@87)R87DH"B`@("`@
M("`@("`@("=S:&]W7W5P;&]A9"<@("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H
M(E-H;W<@=7!L;V%D(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G='EP92<@(#T^("=B;V]L96%N)RDL"B`@("`@("`@("`@("=S
M:&]W7VME97!O<FEG)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E-H;W<@;W!T
M:6]N('1O(&ME97`@;W)I9VEN86PB*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)V)O;VQE86XG*2D["B`@("`@
M("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?
M5'EP95]B;V]L96%N(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!F
M=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S
M86=E*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&=E=$EN9F\H)B1V87)S+"`F)'9A<BP@)B1I;F9O*0H@("`@>PH@
M("`@("`@("1I;F9O(#T@4W1R:6YG.CIL;W=E<B@D=F%R<RT^9V5T*"1V87(M
M/F=E=%9A<DYA;64H*2DI(#T]("=O;B<["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH
M*3L*("`@("`@("`D86)O=71;)VYA;64G72`](%\H(E1R=64@;W(@9F%L<V4B
M*3L*("`@("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*?0H*8VQA<W,@2&]R
M9&5?1F]R;5]4>7!E7VQI;FL@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*
M("`@(&9U;F-T:6]N(&EN:70H)'9A;'5E<RD*("`@('L*("`@("`@("`D=&AI
M<RT^=F%L=65S(#T@)'9A;'5E<SL*("`@('T*"B`@("!F=6YC=&EO;B!I<U9A
M;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@>PH@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@86)O=70H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@*("`@("`@
M("`@("`@)VYA;64G(#T^(%\H(DQI;FLB*2P*("`@("`@("`@("`@)W!A<F%M
M<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`G=7)L)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@("`@("`@("`G;&%B96PG(#T^(%\H(DQI;FL@55),(BDL
M"B`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=T97AT)RDL"B`@("`@
M("`@("`@("`@("`G=&5X="<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@)VQA8F5L)R`]/B!?*"),:6YK('1E>'0B*2P*("`@("`@("`@("`@("`@
M("`@("`G='EP92<@/3X@)W1E>'0G*2P*("`@("`@("`@("`@("`@("=T87)G
M970G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=L86)E;"<@/3X@
M7R@B3&EN:R!T87)G970B*2P*("`@("`@("`@("`@("`@("`@("`G='EP92<@
M/3X@)W1E>'0G*2P*("`@("`@("`@("`@("`@("=O;F-L:6-K)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@("`@("`@("`G;&%B96PG(#T^(%\H(D]N8VQI8VL@
M979E;G0B*2P*("`@("`@("`@("`@("`@("`@("`G='EP92<@/3X@)W1E>'0G
M*2P*("`@("`@("`@("`@("`@("=T:71L92<@/3X@87)R87DH"B`@("`@("`@
M("`@("`@("`@("`@)VQA8F5L)R`]/B!?*"),:6YK('1I=&QE(&%T=')I8G5T
M92(I+`H@("`@("`@("`@("`@("`@("`@("=T>7!E)R`]/B`G=&5X="<I+`H@
M("`@("`@("`@("`@("`@)V%C8V5S<VME>2<@/3X@87)R87DH"B`@("`@("`@
M("`@("`@("`@("`@)VQA8F5L)R`]/B!?*"),:6YK(&%C8V5S<R!K97DB*2P*
M("`@("`@("`@("`@("`@("`@("`G='EP92<@/3X@)W1E>'0G*2DI.PH@("`@
M?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7V5M86EL(&5X=&5N9',@2&]R
M9&5?1F]R;5]4>7!E('L*"B`@("!V87(@)%]A;&QO=U]M=6QT:2`](&9A;'-E
M.PH@("`@=F%R("1?<W1R:7!?9&]M86EN(#T@9F%L<V4["B`@("!V87(@)%]L
M:6YK7V-O;7!O<V4@/2!F86QS93L*("`@('9A<B`D7VQI;FM?;F%M92`](&YU
M;&P["@H@("`@9G5N8W1I;VX@:6YI="@D86QL;W=?;75L=&D@/2!F86QS92P@
M)'-T<FEP7V1O;6%I;B`](&9A;'-E+`H@("`@("`@("`@("`@("`@("`D;&EN
M:U]C;VUP;W-E(#T@9F%L<V4L("1L:6YK7VYA;64@/2!N=6QL*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?86QL;W=?;75L=&D@/2`D86QL;W=?;75L=&D["B`@
M("`@("`@)'1H:7,M/E]S=')I<%]D;VUA:6X@/2`D<W1R:7!?9&]M86EN.PH@
M("`@("`@("1T:&ES+3Y?;&EN:U]C;VUP;W-E(#T@)&QI;FM?8V]M<&]S93L*
M("`@("`@("`D=&AI<RT^7VQI;FM?;F%M92`]("1L:6YK7VYA;64["B`@("!]
M"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L
M("8D;65S<V%G92D*("`@('L*("`@("`@("!I9B`H)'9A<BT^:7-297%U:7)E
M9"@I("8F(&5M<'1Y*"1V86QU92DI('L*("`@("`@("`@("`@)&UE<W-A9V4@
M/2!?*")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?2!E;'-E:68@*"%E;7!T>2@D=F%L=64I
M*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G36%I;"]21D,X,C(N<&AP
M)SL*("`@("`@("`@("`@)'!A<G-E<B`]("9N97<@36%I;%]21D,X,C(H*3L*
M("`@("`@("`@("`@)'!A<G-E9%]E;6%I;"`]("1P87)S97(M/G!A<G-E061D
M<F5S<TQI<W0H)'9A;'5E+"!F86QS92P@=')U92D["@H@("`@("`@("`@("!I
M9B`H:7-?82@D<&%R<V5D7V5M86EL+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("`D;65S<V%G92`]("1P87)S961?96UA:6PM/F=E=$UE<W-A
M9V4H*3L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H*"$D=&AI<RT^7V%L;&]W7VUU;'1I*2`F
M)B!C;W5N="@D<&%R<V5D7V5M86EL*2`^(#$I('L*("`@("`@("`@("`@("`@
M("1M97-S86=E(#T@7R@B3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D
M+B(I.PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&EF("AE;7!T>2@D<&%R<V5D7V5M86EL6S!=+3YM
M86EL8F]X*2D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")9;W4@
M9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(BD["B`@("`@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y
M*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")%;6%I;"(I.PH@("`@
M("`@("1A8F]U=%LG<&%R86US)UT@/2!A<G)A>2@*("`@("`@("`@("`@)V%L
M;&]W7VUU;'1I)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(D%L;&]W(&UU;'1I
M<&QE(&%D9')E<W-E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=T>7!E)R`@/3X@)V)O;VQE86XG*2P*("`@("`@("`@("`@)W-T
M<FEP7V1O;6%I;B<@/3X@87)R87DH)VQA8F5L)R`]/B!?*")3=')I<"!D;VUA
M:6X@9G)O;2!T:&4@861D<F5S<R(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G='EP92<@/3X@)V)O;VQE86XG*2P*("`@("`@("`@
M("`@)VQI;FM?8V]M<&]S92<@/3X@87)R87DH)VQA8F5L)R`]/B!?*"),:6YK
M('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D
M:7-P;&%Y:6YG(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=T>7!E)R`]/B`G8F]O;&5A;B<I+`H@("`@("`@("`@("`G;&EN:U]N
M86UE)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E1H92!N86UE('1O('5S92!W
M:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@/3X@)W1E>'0G*2D[
M"B`@("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E
M7T9O<FU?5'EP95]M871R:7@@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*
M("`@('9A<B`D7V-O;',["B`@("!V87(@)%]R;W=S.PH@("`@=F%R("1?;6%T
M<FEX.PH@("`@=F%R("1?;F5W7VEN<'5T.PH*("`@("\J*@H@("`@("H@26YI
M=&EA;&EZ97,@=&AE('9A<FEA8FQE+@H@("`@("H*("`@("`J($!E>&%M<&QE
M"B`@("`@*B!I;FET*&%R<F%Y*"=#;VQU;6X@02<L("=#;VQU;6X@0B<I+`H@
M("`@("H@("`@("!A<G)A>2@Q(#T^("=2;W<@3VYE)RP@,B`]/B`G4F]W(#(G
M+"`S(#T^("=2;W<@,R<I+`H@("`@("H@("`@("!A<G)A>2AA<G)A>2AT<G5E
M+"!T<G5E+"!F86QS92DL"B`@("`@*B`@("`@("`@("`@(&%R<F%Y*'1R=64L
M(&9A;'-E+"!T<G5E*2P*("`@("`J("`@("`@("`@("`@87)R87DH9F%S;&4L
M('1R=64L(&9A;'-E*2DL"B`@("`@*B`@("`@(&%R<F%Y*"=2;W<@-"<L("=2
M;W<@-2<I*3L*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&-O;',@("`@
M("`@("`@("`@("!!(&QI<W0@;V8@8V]L=6UN(&AE861E<G,N"B`@("`@*B!`
M<&%R86T@87)R87D@)')O=W,@("`@("`@("`@("`@("!!(&AA<V@@=VET:"!R
M;W<@241S(&%S('1H92!K97ES(&%N9"!R;W<*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&QA8F5L<R!A<R!T:&4@=F%L=65S+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1M871R:7@@("`@("`@("`@("`@02!T=V\@
M9&EM96YS:6]N86P@:&%S:"!W:71H('1H92!F:65L9`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@=F%L=65S+@H@("`@("H@0'!A
M<F%M(&)O;VQE86Y\87)R87D@)&YE=U]I;G!U="`@268@=')U92P@82!F<F5E
M('1E>'0@9FEE;&0@=&\@861D(&$@;F5W"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!R;W<@:7,@9&ES<&QA>65D(&]N('1H92!T
M;W`L(&$@<V5L96-T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!B;W@@:68@=&AI<R!P87)A;65T97(@:7,@82!V86QU92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@:6YI="@D8V]L<RP@)')O=W,@/2!A<G)A>2@I
M+"`D;6%T<FEX(#T@87)R87DH*2P@)&YE=U]I;G!U="`](&9A;'-E*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?8V]L<R`@("`@("`]("1C;VQS.PH@("`@("`@
M("1T:&ES+3Y?<F]W<R`@("`@("`]("1R;W=S.PH@("`@("`@("1T:&ES+3Y?
M;6%T<FEX("`@("`]("1M871R:7@["B`@("`@("`@)'1H:7,M/E]N97=?:6YP
M=70@(#T@)&YE=U]I;G!U=#L*("`@('T*"B`@("!F=6YC=&EO;B!I<U9A;&ED
M*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@>PH@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$-O;',H
M*2`@("`@>R!R971U<FX@)'1H:7,M/E]C;VQS.R!]"B`@("!F=6YC=&EO;B!G
M9712;W=S*"D@("`@('L@<F5T=7)N("1T:&ES+3Y?<F]W<SL@?0H@("`@9G5N
M8W1I;VX@9V5T36%T<FEX*"D@("![(')E='5R;B`D=&AI<RT^7VUA=')I>#L@
M?0H@("`@9G5N8W1I;VX@9V5T3F5W26YP=70H*2![(')E='5R;B`D=&AI<RT^
M7VYE=U]I;G!U=#L@?0H*("`@(&9U;F-T:6]N(&=E=$EN9F\H)B1V87)S+"`F
M)'9A<BP@)B1I;F9O*0H@("`@>PH@("`@("`@("1V86QU97,@/2`D=F%R<RT^
M9V5T*"1V87(M/F=E=%9A<DYA;64H*2D["B`@("`@("`@:68@*"%E;7!T>2@D
M=F%L=65S6R=N)UU;)W(G72D@)B8@:7-S970H)'9A;'5E<ULG;B==6R=V)UTI
M*2!["B`@("`@("`@("`@("1N97=?<F]W(#T@)'9A;'5E<ULG;B==6R=R)UT[
M"B`@("`@("`@("`@("1V86QU97-;)W(G75LD;F5W7W)O=UT@/2`D=F%L=65S
M6R=N)UU;)W8G73L*("`@("`@("`@("`@=6YS970H)'9A;'5E<ULG;B==*3L*
M("`@("`@("!]"@H@("`@("`@("1I;F9O(#T@*&ES<V5T*"1V86QU97-;)W(G
M72D@/R`D=F%L=65S6R=R)UT@.B!A<G)A>2@I*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*
M("`@("`@("`D86)O=71;)VYA;64G72`](%\H(D9I96QD(&UA=')I>"(I.PH@
M("`@("`@("1A8F]U=%LG<&%R86US)UT@/2!A<G)A>2@*("`@("`@("`@("`@
M)V-O;',G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B0V]L=6UN('1I=&QE<R(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G<W1R
M:6YG;&ES="<I*3L*("`@("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*?0H*
M8VQA<W,@2&]R9&5?1F]R;5]4>7!E7V5M86EL0V]N9FER;2!E>'1E;F1S($AO
M<F1E7T9O<FU?5'EP92!["@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@
M)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!I9B`H
M)'9A<BT^:7-297%U:7)E9"@I("8F(&5M<'1Y*"1V86QU95LG;W)I9VEN86PG
M72DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I96QD(&ES
M(')E<75I<F5D+B(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("!I9B`H)'9A;'5E6R=O<FEG:6YA;"==("$]("1V86QU
M95LG8V]N9FER;2==*2!["B`@("`@("`@("`@("1M97-S86=E(#T@7R@B16UA
M:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(BD["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)TUA:6PO4D9#.#(R+G!H<"<["B`@("`@("`@("`@("1P87)S97(@
M/2`F;F5W($UA:6Q?4D9#.#(R*"D["B`@("`@("`@("`@("1P87)S961?96UA
M:6P@/2`D<&%R<V5R+3YP87)S94%D9')E<W-,:7-T*"1V86QU95LG;W)I9VEN
M86PG72P@9F%L<V4L('1R=64I.PH*("`@("`@("`@("`@:68@*&-O=6YT*"1P
M87)S961?96UA:6PI(#X@,2D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@
M/2!?*")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(BD["B`@("`@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*&5M<'1Y*"1P87)S961?96UA:6Q;,%TM/FUA:6QB;W@I*2![
M"B`@("`@("`@("`@("`@("`D;65S<V%G92`](%\H(EEO=2!D:60@;F]T(&5N
M=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB*3L*("`@("`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@
M:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A
M8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*("`@("`@
M("`D86)O=71;)VYA;64G72`](%\H(D5M86EL('=I=&@@8V]N9FER;6%T:6]N
M(BD["B`@("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO
M<F1E7T9O<FU?5'EP95]P87-S=V]R9"!E>'1E;F1S($AO<F1E7T9O<FU?5'EP
M92!["@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L
M=64L("8D;65S<V%G92D*("`@('L*("`@("`@("`D=F%L:60@/2!T<G5E.PH*
M("`@("`@("!I9B`H)'9A<BT^:7-297%U:7)E9"@I*2!["B`@("`@("`@("`@
M("1V86QI9"`]('-T<FQE;BAT<FEM*"1V86QU92DI(#X@,#L*"B`@("`@("`@
M("`@(&EF("@A)'9A;&ED*2!["B`@("`@("`@("`@("`@("`D;65S<V%G92`]
M(%\H(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(BD["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=F%L:60["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T
M(#T@87)R87DH*3L*("`@("`@("`D86)O=71;)VYA;64G72`](%\H(E!A<W-W
M;W)D(BD["B`@("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S
M($AO<F1E7T9O<FU?5'EP95]P87-S=V]R9$-O;F9I<FT@97AT96YD<R!(;W)D
M95]&;W)M7U1Y<&4@>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D
M=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@:68@*"1V
M87(M/FES4F5Q=6ER960H*2`F)B!E;7!T>2@D=F%L=65;)V]R:6=I;F%L)UTI
M*2!["B`@("`@("`@("`@("1M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R
M97%U:7)E9"XB*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"1V86QU95LG;W)I9VEN86PG72`A/2`D=F%L=65;
M)V-O;F9I<FTG72D@>PH@("`@("`@("`@("`D;65S<V%G92`](%\H(E!A<W-W
M;W)D<R!M=7-T(&UA=&-H+B(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("!F
M=6YC=&EO;B!G971);F9O*"8D=F%R<RP@)B1V87(L("8D:6YF;RD*("`@('L*
M("`@("`@("`D=F%L=64@/2`D=F%R<RT^9V5T*"1V87(M/F=E=%9A<DYA;64H
M*2D["B`@("`@("`@)&EN9F\@/2`D=F%L=65;)V]R:6=I;F%L)UT["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@
M)&%B;W5T(#T@87)R87DH*3L*("`@("`@("`D86)O=71;)VYA;64G72`](%\H
M(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(BD["B`@("`@("`@<F5T=7)N
M("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]E;G5M
M(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!V87(@)%]V86QU97,[
M"B`@("!V87(@)%]P<F]M<'0["@H@("`@9G5N8W1I;VX@:6YI="@D=F%L=65S
M+"`D<')O;7!T(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7W9A;'5E
M<R`]("1V86QU97,["@H@("`@("`@(&EF("@D<')O;7!T(#T]/2!T<G5E*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?<')O;7!T(#T@7R@B+2T@<V5L96-T("TM
M(BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]P<F]M
M<'0@/2`D<')O;7!T.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!I
M<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@
M>PH@("`@("`@(&EF("@D=F%R+3YI<U)E<75I<F5D*"D@)B8@)'9A;'5E(#T]
M("<G("8F("%I<W-E="@D=&AI<RT^7W9A;'5E<ULD=F%L=65=*2D@>PH@("`@
M("`@("`@("`D;65S<V%G92`](%\H(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N
M(BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@(&EF("AC;W5N="@D=&AI<RT^7W9A;'5E<RD@/3T@,"!\?"!I<W-E="@D
M=&AI<RT^7W9A;'5E<ULD=F%L=65=*2!\?`H@("`@("`@("`@("`H)'1H:7,M
M/E]P<F]M<'0@)B8@96UP='DH)'9A;'5E*2DI('L*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`D;65S<V%G92`](%\H(DEN
M=F%L:60@9&%T82!S=6)M:71T960N(BD["B`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%9A;'5E<R@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?=F%L=65S.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&=E=%!R;VUP="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<')O
M;7!T.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@
M9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@
M>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N
M86UE)UT@/2!?*")$<F]P(&1O=VX@;&ES="(I.PH@("`@("`@("1A8F]U=%LG
M<&%R86US)UT@/2!A<G)A>2@*("`@("`@("`@("`@)W9A;'5E<R<@/3X@87)R
M87DH)VQA8F5L)R`]/B!?*")686QU97,@=&\@<V5L96-T(&9R;VTB*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G<W1R:6YG
M;&ES="<I+`H@("`@("`@("`@("`G<')O;7!T)R`]/B!A<G)A>2@G;&%B96PG
M(#T^(%\H(E!R;VUP="!T97AT(BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=T>7!E)R`@/3X@)W1E>'0G*2D["B`@("`@("`@<F5T=7)N("1A
M8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]M;&5N=6T@
M97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@('9A<B`D7W9A;'5E<SL*
M("`@('9A<B`D7W!R;VUP=',["@H@("`@9G5N8W1I;VX@:6YI="@F)'9A;'5E
M<RP@)'!R;VUP=',@/2!N=6QL*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=F%L
M=65S(#T@)B1V86QU97,["@H@("`@("`@(&EF("@D<')O;7!T<R`]/3T@=')U
M92D@>PH@("`@("`@("`@("`D=&AI<RT^7W!R;VUP=',@/2!A<G)A>2A?*"(M
M+2!S96QE8W0@+2TB*2P@7R@B+2T@<V5L96-T("TM(BDI.PH@("`@("`@('T@
M96QS96EF("@A:7-?87)R87DH)'!R;VUP=',I*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?<')O;7!T<R`](&%R<F%Y*"1P<F]M<'1S+"`D<')O;7!T<RD["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]P<F]M<'1S(#T@
M)'!R;VUP=',["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&]N4W5B
M;6ET*"8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A<FYA;64@/2`D
M=F%R+3YG971687).86UE*"D["B`@("`@("`@)'9A;'5E(#T@)'9A<G,M/F=E
M="@D=F%R;F%M92D["@H@("`@("`@(&EF("@D=F%L=65;)S$G72`A/2`D=F%L
M=65;)V]L9"==*2!["B`@("`@("`@("`@("1V87(M/F9O<FTM/G-E=%-U8FUI
M='1E9"AF86QS92D["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&ES
M5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("![
M"B`@("`@("`@:68@*"1V87(M/FES4F5Q=6ER960H*2`F)B`H96UP='DH)'9A
M;'5E6R<Q)UTI('Q\(&5M<'1Y*"1V86QU95LG,B==*2DI('L*("`@("`@("`@
M("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(I.PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(6-O=6YT*"1T:&ES+3Y?=F%L=65S*2!\?"!I<W-E="@D=&AI<RT^7W9A
M;'5E<ULD=F%L=65;)S$G75TI('Q\"B`@("`@("`@("`@("@A96UP='DH)'1H
M:7,M/E]P<F]M<'1S*2`F)B!E;7!T>2@D=F%L=65;)S$G72DI*2!["B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)&UE<W-A
M9V4@/2!?*"));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(I.PH@("`@("`@(')E
M='5R;B!F86QS93L*("`@('T*"B`@("!F=6YC=&EO;B!G971686QU97,H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W9A;'5E<SL*("`@('T*"B`@
M("!F=6YC=&EO;B!G9710<F]M<'1S*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]P<F]M<'1S.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$EN9F\H
M)B1V87)S+"`F)'9A<BP@)B1I;F9O*0H@("`@>PH@("`@("`@("1I;F9O(#T@
M)'9A<G,M/F=E="@D=F%R+3YG971687).86UE*"DI.PH@("`@("`@(')E='5R
M;B`D:6YF;ULG,B==.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&EN
M9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O
M=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@("`@
M)&%B;W5T6R=N86UE)UT@/2!?*")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES
M=',B*3L*("`@("`@("`D86)O=71;)W!A<F%M<R==(#T@87)R87DH"B`@("`@
M("`@("`@("=V86QU97,G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B5F%L=65S
M('1O('-E;&5C="!F<F]M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=T>7!E)R`@/3X@)W-T<FEN9VQI<W0G*2P*("`@("`@("`@("`@)W!R
M;VUP="<@/3X@87)R87DH)VQA8F5L)R`]/B!?*")0<F]M<'0@=&5X="(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=T97AT
M)RDI.PH@("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(
M;W)D95]&;W)M7U1Y<&5?;75L=&EE;G5M(&5X=&5N9',@2&]R9&5?1F]R;5]4
M>7!E7V5N=6T@>PH*("`@('9A<B`D<VEZ92`](#4["@H@("`@9G5N8W1I;VX@
M:6YI="@D=F%L=65S+"`D<VEZ92`](&YU;&PI"B`@("!["B`@("`@("`@:68@
M*"%I<U]N=6QL*"1S:7IE*2D@>PH@("`@("`@("`@("`D=&AI<RT^<VEZ92`]
M("AI;G0I)'-I>F4["B`@("`@("`@?0H*("`@("`@("!P87)E;G0Z.FEN:70H
M)'9A;'5E<RD["B`@("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@
M)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!I9B`H
M:7-?87)R87DH)'9A;'5E*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D=F%L
M=64@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^:7-6
M86QI9"@D=F%R+"`D=F%R<RP@)'9A;"P@)&UE<W-A9V4I*2!["B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M('T*"B`@("`@("`@:68@*&5M<'1Y*"1V86QU92D@)B8@*"AS=')I;F<I*&EN
M="DD=F%L=64@(3T]("1V86QU92DI('L*("`@("`@("`@("`@:68@*"1V87(M
M/FES4F5Q=6ER960H*2D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!?
M*")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(&EF("AC;W5N="@D=&AI<RT^7W9A;'5E<RD@/3T@,"!\?"!I<W-E
M="@D=&AI<RT^7W9A;'5E<ULD=F%L=65=*2D@>PH@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1M97-S86=E(#T@7R@B26YV
M86QI9"!D871A('-U8FUI='1E9"XB*3L*("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L
M9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@
M("`@("`@)&%B;W5T(#T@87)R87DH*3L*("`@("`@("`D86)O=71;)VYA;64G
M72`](%\H(DUU;'1I<&QE('-E;&5C=&EO;B(I.PH@("`@("`@("1A8F]U=%LG
M<&%R86US)UT@/2!A<G)A>2@*("`@("`@("`@("`@)W9A;'5E<R<@/3X@87)R
M87DH)VQA8F5L)R`]/B!?*")686QU97,B*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W1Y<&4G("`]/B`G<W1R:6YG;&ES="<I+`H@("`@("`@
M("`@("`G<VEZ92<@("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E-I>F4B*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G:6YT
M)RDI.PH@("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(
M;W)D95]&;W)M7U1Y<&5?<F%D:6\@97AT96YD<R!(;W)D95]&;W)M7U1Y<&5?
M96YU;2!["@H@("`@+RH@16YT:7)E;'D@:6UP;&5M96YT960@8GD@2&]R9&5?
M1F]R;5]4>7!E7V5N=6T[(&IU<W0@82!D:69F97)E;G0*("`@("`J('9I97<N
M("HO"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T
M>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@
M("`@)&%B;W5T(#T@87)R87DH*3L*("`@("`@("`D86)O=71;)VYA;64G72`]
M(%\H(E)A9&EO('-E;&5C=&EO;B(I.PH@("`@("`@("1A8F]U=%LG<&%R86US
M)UT@/2!A<G)A>2@*("`@("`@("`@("`@)W9A;'5E<R<@/3X@87)R87DH)VQA
M8F5L)R`]/B!?*")686QU97,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W1Y<&4G("`]/B`G<W1R:6YG;&ES="<I*3L*("`@("`@("!R971U
M<FX@)&%B;W5T.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7W-E
M="!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@=F%R("1?=F%L=65S
M.PH@("`@=F%R("1?8VAE8VM!;&P@/2!F86QS93L*"B`@("!F=6YC=&EO;B!I
M;FET*"8D=F%L=65S+"`D8VAE8VM!;&P@/2!F86QS92D*("`@('L*("`@("`@
M("`D=&AI<RT^7W9A;'5E<R`]("1V86QU97,["B`@("`@("`@)'1H:7,M/E]C
M:&5C:T%L;"`]("1C:&5C:T%L;#L*("`@('T*"B`@("!F=6YC=&EO;B!I<U9A
M;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@>PH@
M("`@("`@(&EF("AC;W5N="@D=&AI<RT^7W9A;'5E<RD@/3T@,"!\?"!C;W5N
M="@D=F%L=64I(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1V86QU92!A<R`D:71E;2D@>PH@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?=F%L=65S6R1I=&5M72DI
M('L*("`@("`@("`@("`@("`@("1E<G)O<B`]('1R=64["B`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I
M9B`H(6ES<V5T*"1E<G)O<BDI('L*("`@("`@("`@("`@<F5T=7)N('1R=64[
M"B`@("`@("`@?0H*("`@("`@("`D;65S<V%G92`](%\H(DEN=F%L:60@9&%T
M82!S=6)M:71T960N(BD["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&=E=%9A;'5E<R@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?=F%L=65S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@
M("`@)&%B;W5T6R=N86UE)UT@/2!?*")3970B*3L*("`@("`@("`D86)O=71;
M)W!A<F%M<R==(#T@87)R87DH"B`@("`@("`@("`@("=V86QU97,G(#T^(&%R
M<F%Y*"=L86)E;"<@/3X@7R@B5F%L=65S(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=T>7!E)R`@/3X@)W-T<FEN9VQI<W0G*2D["B`@("`@
M("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?
M5'EP95]D871E(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!V87(@
M)%]F;W)M870["@H@("`@9G5N8W1I;VX@:6YI="@D9F]R;6%T(#T@)R5A("5D
M("5")RD*("`@('L*("`@("`@("`D=&AI<RT^7V9O<FUA="`]("1F;W)M870[
M"B`@("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D
M=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("`D=F%L:60@/2!T<G5E
M.PH*("`@("`@("!I9B`H)'9A<BT^:7-297%U:7)E9"@I*2!["B`@("`@("`@
M("`@("1V86QI9"`]('-T<FQE;BAT<FEM*"1V86QU92DI(#X@,#L*"B`@("`@
M("`@("`@(&EF("@A)'9A;&ED*2!["B`@("`@("`@("`@("`@("`D;65S<V%G
M92`]('-P<FEN=&8H7R@B)7,@:7,@<F5Q=6ER960B*2P@)'9A<BT^9V5T2'5M
M86Y.86UE*"DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)'9A;&ED.PH@("`@?0H*("`@("\J*@H@("`@("H@0'-T871I8PH@
M("`@("HO"B`@("!F=6YC=&EO;B!G971!9V\H)'1I;65S=&%M<"D*("`@('L*
M("`@("`@("!R97%U:7)E7V]N8V4@)T1A=&4O0V%L8RYP:'`G.PH@("`@("`@
M("1D:69F9&%Y<R`]($1A=&5?0V%L8SHZ9&%T941I9F8H9&%T92@G:B<L("1T
M:6UE<W1A;7`I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@9&%T92@G;B<L("1T:6UE<W1A;7`I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@9&%T92@G62<L("1T:6UE<W1A;7`I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9&%T
M92@G:B<I+"!D871E*"=N)RDL(&1A=&4H)UDG*2D["@H@("`@("`@("\J($%N
M(&5R<F]R(&]C8W5R960N("HO"B`@("`@("`@:68@*"1D:69F9&%Y<R`]/2`M
M,2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D
M86=O(#T@)&1I9F9D87ES("H@1&%T95]#86QC.CIC;VUP87)E1&%T97,H9&%T
M92@G:B<L("1T:6UE<W1A;7`I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!D871E*"=N)RP@)'1I;65S=&%M
M<"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&1A=&4H)UDG+"`D=&EM97-T86UP*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9&%T92@G
M:B<I+"!D871E*"=N)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&1A=&4H)UDG*2D["B`@("`@("`@:68@
M*"1A9V\@/"`M,2D@>PH@("`@("`@("`@("!R971U<FX@<W!R:6YT9BA?*"(@
M*"5S(&1A>7,@86=O*2(I+"`D9&EF9F1A>7,I.PH@("`@("`@('T@96QS96EF
M("@D86=O(#T]("TQ*2!["B`@("`@("`@("`@(')E='5R;B!?*"(@*'EE<W1E
M<F1A>2DB*3L*("`@("`@("!](&5L<V5I9B`H)&%G;R`]/2`P*2!["B`@("`@
M("`@("`@(')E='5R;B!?*"(@*'1O9&%Y*2(I.PH@("`@("`@('T@96QS96EF
M("@D86=O(#T](#$I('L*("`@("`@("`@("`@<F5T=7)N(%\H(B`H=&]M;W)R
M;W<I(BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N('-P
M<FEN=&8H7R@B("AI;B`E<R!D87ES*2(I+"`D9&EF9F1A>7,I.PH@("`@("`@
M('T*("`@('T*"B`@("!F=6YC=&EO;B!G971&;W)M871T9614:6UE*"1T:6UE
M<W1A;7`L("1F;W)M870@/2!N=6QL+"`D<VAO=V%G;R`]('1R=64I"B`@("![
M"B`@("`@("`@:68@*&5M<'1Y*"1F;W)M870I*2!["B`@("`@("`@("`@("1F
M;W)M870@/2`D=&AI<RT^7V9O<FUA=#L*("`@("`@("!]"B`@("`@("`@:68@
M*"%E;7!T>2@D=&EM97-T86UP*2D@>PH@("`@("`@("`@("!R971U<FX@<W1R
M9G1I;64H)&9O<FUA="P@)'1I;65S=&%M<"D@+B`H)'-H;W=A9V\@/R!(;W)D
M95]&;W)M7U1Y<&5?9&%T93HZ9V5T06=O*"1T:6UE<W1A;7`I(#H@)R<I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F
M:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("![
M"B`@("`@("`@<F5T=7)N(&%R<F%Y*"=N86UE)R`]/B!?*")$871E(BDI.PH@
M("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7W1I;64@97AT96YD<R!(
M;W)D95]&;W)M7U1Y<&4@>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L
M("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@:68@
M*"1V87(M/FES4F5Q=6ER960H*2`F)B!E;7!T>2@D=F%L=64I("8F("@H<W1R
M:6YG*2AD;W5B;&4I)'9A;'5E("$]/2`D=F%L=64I*2!["B`@("`@("`@("`@
M("1M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB*3L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@
M*&5M<'1Y*"1V86QU92D@?'P@<')E9U]M871C:"@G+UY;,"TR73];,"TY73I;
M,"TU75LP+3E=)"\G+"`D=F%L=64I*2!["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T*"B`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(I
M.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH)VYA
M;64G(#T^(%\H(E1I;64B*2D["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M
M7U1Y<&5?:&]U<DUI;G5T95-E8V]N9"!E>'1E;F1S($AO<F1E7T9O<FU?5'EP
M92!["@H@("`@=F%R("1?<VAO=U]S96-O;F1S.PH*("`@(&9U;F-T:6]N(&EN
M:70H)'-H;W=?<V5C;VYD<R`](&9A;'-E*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?<VAO=U]S96-O;F1S(#T@)'-H;W=?<V5C;VYD<SL*("`@('T*"B`@("!F
M=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S
M86=E*0H@("`@>PH@("`@("`@("1T:6UE(#T@)'9A<G,M/F=E="@D=F%R+3YG
M971687).86UE*"DI.PH@("`@("`@(&EF("@A)'1H:7,M/E]S:&]W7W-E8V]N
M9',@)B8@(6ES<V5T*"1T:6UE6R=S96-O;F0G72DI('L*("`@("`@("`@("`@
M)'1I;65;)W-E8V]N9"==(#T@,#L*("`@("`@("!]"@H@("`@("`@(&EF("@A
M)'1H:7,M/F5M<'1Y5&EM94%R<F%Y*"1T:6UE*2`F)B`A)'1H:7,M/F-H96-K
M=&EM92@D=&EM95LG:&]U<B==+"`D=&EM95LG;6EN=71E)UTL("1T:6UE6R=S
M96-O;F0G72DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")0;&5A<V4@
M96YT97(@82!V86QI9"!T:6UE+B(I.PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?2!E;'-E:68@*"1T:&ES+3YE;7!T>51I;65!<G)A>2@D
M=&EM92D@)B8@)'9A<BT^:7-297%U:7)E9"@I*2!["B`@("`@("`@("`@("1M
M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB*3L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@8VAE8VMT:6UE*"1H;W5R+"`D
M;6EN=71E+"`D<V5C;VYD*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)&AO
M=7(I('Q\("1H;W5R(#T]("<G('Q\("@D:&]U<B`\(#`@?'P@)&AO=7(@/B`R
M,RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@
M("`@("!I9B`H(6ES<V5T*"1M:6YU=&4I('Q\("1M:6YU=&4@/3T@)R<@?'P@
M*"1M:6YU=&4@/"`P('Q\("1M:6YU=&4@/B`V,"DI('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1S
M96-O;F0I('Q\("1S96-O;F0@/3T]("<G('Q\("@D<V5C;VYD(#P@,"!\?"`D
M<V5C;VYD(#X@-C`I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N('1H92!T:6UE('-U<'!L:65D(&%S(&$@2&]R9&5?1&%T
M92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&EM95]I
M;B`@1&%T92!I;B!O;F4@;V8@=&AE('1H<F5E(&9O<FUA=',@<W5P<&]R=&5D
M(&)Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!(;W)D95]&;W)M
M(&%N9"!(;W)D95]$871E("A)4T\@9F]R;6%T"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!965E9+4U-+41$($A(.DU-.E-3+"!T:6UE<W1A;7`@
M65E964U-1$1(2$U-4U,@86YD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("!53DE8(&5P;V-H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N($1A=&4@
M(%1H92!T:6UE(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5&EM
M94]B*"1T:6UE7VEN*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O1&%T92YP:'`G.PH*("`@("`@("!I9B`H:7-?87)R87DH)'1I;65?:6XI
M*2!["B`@("`@("`@("`@(&EF("@A)'1H:7,M/F5M<'1Y5&EM94%R<F%Y*"1T
M:6UE7VEN*2D@>PH@("`@("`@("`@("`@("`@)'1I;65?:6X@/2!S<')I;G1F
M*"<Q.3<P+3`Q+3`Q("4P,F0Z)3`R9#HE,#)D)RP@)'1I;65?:6Y;)VAO=7(G
M72P@)'1I;65?:6Y;)VUI;G5T92==+"`D=&EM95]I;ELG<V5C;VYD)UTI.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@;F5W($AO
M<F1E7T1A=&4H)'1I;65?:6XI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N('1H92!T:6UE('-U<'!L:65D('-P;&ET('5P(&EN=&\@86X@87)R87DN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&EM95]I;B`@5&EM92!I
M;B!O;F4@;V8@=&AE('1H<F5E(&9O<FUA=',@<W5P<&]R=&5D(&)Y"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!(;W)D95]&;W)M(&%N9"!(;W)D
M95]$871E("A)4T\@9F]R;6%T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("!965E9+4U-+41$($A(.DU-.E-3+"!T:6UE<W1A;7`@65E964U-1$1(
M2$U-4U,@86YD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!53DE8
M(&5P;V-H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!W
M:71H('1H<F5E(&5L96UE;G1S("T@:&]U<BP@;6EN=71E(&%N9"!S96-O;F1S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714:6UE4&%R=',H)'1I;65?:6XI
M"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:6UE7VEN*2D@>PH@("`@
M("`@("`@("`O*B!4:&ES(&ES('!R;V)A8FQY(&$@9F%I;&5D(&ES5F%L:60@
M:6YP=70@<V\@:G5S="!R971U<FX@=&AE"B`@("`@("`@("`@("`J('!A<G1S
M(&%S('1H97D@87)E+B`J+PH@("`@("`@("`@("!R971U<FX@)'1I;65?:6X[
M"B`@("`@("`@?2!E;'-E:68@*&5M<'1Y*"1T:6UE7VEN*2D@>PH@("`@("`@
M("`@("`O*B!4:&ES(&ES(&IU<W0@86X@96UP='D@9FEE;&0@<V\@<F5T=7)N
M(&5M<'1Y('!A<G1S+B`J+PH@("`@("`@("`@("!R971U<FX@87)R87DH)VAO
M=7(G(#T^("<G+"`G;6EN=71E)R`]/B`G)RP@)W-E8V]N9"<@/3X@)R<I.PH@
M("`@("`@('T*("`@("`@("`D=&EM92`]("1T:&ES+3YG9714:6UE3V(H)'1I
M;65?:6XI.PH@("`@("`@(')E='5R;B!A<G)A>2@G:&]U<B<@/3X@)'1I;64M
M/FAO=7(L"B`@("`@("`@("`@("`@("`@("`@("=M:6YU=&4G(#T^("1T:6UE
M+3YM:6XL"B`@("`@("`@("`@("`@("`@("`@("=S96-O;F0G(#T^("1T:6UE
M+3YS96,I.PH@("`@?0H*("`@(&9U;F-T:6]N(&5M<'1Y5&EM94%R<F%Y*"1T
M:6UE*0H@("`@>PH@("`@("`@(')E='5R;B`H:7-?87)R87DH)'1I;64I("8F
M(&5M<'1Y*"1T:6UE6R=H;W5R)UTI("8F(&5M<'1Y*"1T:6UE6R=M:6YU=&4G
M72D@)B8@96UP='DH)'1I;65;)W-E8V]N9"==*2D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@<F5T=7)N(&%R
M<F%Y*"=N86UE)R`]/B!?*")4:6UE('-E;&5C=&EO;B(I*3L*("`@('T*"GT*
M"F-L87-S($AO<F1E7T9O<FU?5'EP95]M;VYT:%EE87(@97AT96YD<R!(;W)D
M95]&;W)M7U1Y<&4@>PH*("`@('9A<B`D7W-T87)T7WEE87(["B`@("!V87(@
M)%]E;F1?>65A<CL*"B`@("!F=6YC=&EO;B!I;FET*"1S=&%R=%]Y96%R(#T@
M;G5L;"P@)&5N9%]Y96%R(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H96UP
M='DH)'-T87)T7WEE87(I*2!["B`@("`@("`@("`@("1S=&%R=%]Y96%R(#T@
M,3DR,#L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1E;F1?>65A<BDI
M('L*("`@("`@("`@("`@)&5N9%]Y96%R(#T@9&%T92@G62<I.PH@("`@("`@
M('T*"B`@("`@("`@)'1H:7,M/E]S=&%R=%]Y96%R(#T@)'-T87)T7WEE87([
M"B`@("`@("`@)'1H:7,M/E]E;F1?>65A<B`]("1E;F1?>65A<CL*("`@('T*
M"B`@("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@
M)B1M97-S86=E*0H@("`@>PH@("`@("`@(&EF("@A)'9A<BT^:7-297%U:7)E
M9"@I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"$D=F%R<RT^9V5T*"1T:&ES+3YG971-;VYT:%9A<B@D=F%R
M*2D@?'P*("`@("`@("`@("`@(21V87)S+3YG970H)'1H:7,M/F=E=%EE87)6
M87(H)'9A<BDI*2!["B`@("`@("`@("`@("1M97-S86=E(#T@7R@B4&QE87-E
M(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB*3L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@9G5N8W1I;VX@9V5T36]N=&A687(H)'9A<BD*("`@('L*("`@
M("`@("!R971U<FX@)'9A<BT^9V5T5F%R3F%M92@I("X@)UMM;VYT:%TG.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&=E=%EE87)687(H)'9A<BD*("`@('L*("`@
M("`@("!R971U<FX@)'9A<BT^9V5T5F%R3F%M92@I("X@)UMY96%R72<["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T
M>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@
M("`@<F5T=7)N(&%R<F%Y*"=N86UE)R`]/B!?*")-;VYT:"!A;F0@>65A<B(I
M+`H@("`@("`@("`@("`@("`@("`@("`G<&%R86US)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@("`@("`@("`@("`@("=S=&%R=%]Y96%R)R`]/B!A<G)A>2@G
M;&%B96PG(#T^(%\H(E-T87)T('EE87(B*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=S=')I
M;F=L:7-T)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`G96YD7WEE87(G
M("`@/3X@87)R87DH)VQA8F5L)R`]/B!?*")%;F0@>65A<B(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E
M)R`@/3X@)W-T<FEN9VQI<W0G*2DI.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?
M1F]R;5]4>7!E7VUO;G1H1&%Y665A<B!E>'1E;F1S($AO<F1E7T9O<FU?5'EP
M92!["@H@("`@=F%R("1?<W1A<G1?>65A<CL*("`@('9A<B`D7V5N9%]Y96%R
M.PH@("`@=F%R("1?<&EC:V5R.PH@("`@=F%R("1?9F]R;6%T7VEN(#T@;G5L
M;#L*("`@('9A<B`D7V9O<FUA=%]O=70@/2`G)7@G.PH*("`@("\J*@H@("`@
M("H@4F5T=7)N('1H92!D871E('-U<'!L:65D(&%S(&$@2&]R9&5?1&%T92!O
M8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'-T87)T7WEE
M87(@(%1H92!F:7)S="!A=F%I;&%B;&4@>65A<B!F;W(@:6YP=70N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D96YD7WEE87(@("`@5&AE(&QA<W0@879A:6QA
M8FQE('EE87(@9F]R(&EN<'5T+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'!I
M8VME<B`@("`@($1O('=E('-H;W<@=&AE($1(5$U,(&-A;&5N9&%R/PH@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&9O<FUA=%]I;B`@(%1H92!F;W)M870@=&\@
M=7-E('=H96X@<V5N9&EN9R!T:&4@9&%T90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&9O<B!S=&]R86=E+B!$969A=6QT<R!T;R!5;FEX
M(&5P;V-H+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%-I
M;6EL87(@=&\@=&AE('-T<F9T:6UE*"D@9G5N8W1I;VXN"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D9F]R;6%T7V]U="`@5&AE(&9O<FUA="!T;R!U<V4@=VAE
M;B!D:7-P;&%Y:6YG('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&1A=&4N(%-I;6EL87(@=&\@=&AE('-T<F9T:6UE*"D@9G5N8W1I
M;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN:70H)'-T87)T7WEE87(@/2`G
M)RP@)&5N9%]Y96%R(#T@)R<L("1P:6-K97(@/2!T<G5E+`H@("`@("`@("`@
M("`@("`@("`D9F]R;6%T7VEN(#T@;G5L;"P@)&9O<FUA=%]O=70@/2`G)7@G
M*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D<W1A<G1?>65A<BDI('L*("`@
M("`@("`@("`@)'-T87)T7WEE87(@/2!D871E*"=9)RD["B`@("`@("`@?0H@
M("`@("`@(&EF("AE;7!T>2@D96YD7WEE87(I*2!["B`@("`@("`@("`@("1E
M;F1?>65A<B`](&1A=&4H)UDG*2`K(#$P.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/E]S=&%R=%]Y96%R(#T@)'-T87)T7WEE87(["B`@("`@("`@)'1H
M:7,M/E]E;F1?>65A<B`]("1E;F1?>65A<CL*("`@("`@("`D=&AI<RT^7W!I
M8VME<B`]("1P:6-K97(["B`@("`@("`@)'1H:7,M/E]F;W)M871?:6X@/2`D
M9F]R;6%T7VEN.PH@("`@("`@("1T:&ES+3Y?9F]R;6%T7V]U="`]("1F;W)M
M871?;W5T.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D
M=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@)&1A=&4@
M/2`D=F%R<RT^9V5T*"1V87(M/F=E=%9A<DYA;64H*2D["B`@("`@("`@)&5M
M<'1Y(#T@)'1H:7,M/F5M<'1Y1&%T94%R<F%Y*"1D871E*3L*"B`@("`@("`@
M:68@*"1E;7!T>2`]/2`Q("8F("1V87(M/FES4F5Q=6ER960H*2D@>PH@("`@
M("`@("`@("`D;65S<V%G92`](%\H(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N
M(BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!](&5L<V5I
M9B`H)&5M<'1Y(#T](#`@)B8@(6-H96-K9&%T92@D9&%T95LG;6]N=&@G72P@
M)&1A=&5;)V1A>2==+"`D9&%T95LG>65A<B==*2D@>PH@("`@("`@("`@("`D
M;65S<V%G92`](%\H(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K
M('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(BD["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!](&5L<V5I9B`H)&5M<'1Y(#T]
M("TQ*2!["B`@("`@("`@("`@("1M97-S86=E(#T@7R@B4V5L96-T(&%L;"!D
M871E(&-O;7!O;F5N=',N(BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&5M<'1Y1&%T94%R<F%Y*"1D871E*0H@("`@>PH@("`@("`@(&EF
M("@A:7-?87)R87DH)&1A=&4I*2!["B`@("`@("`@("`@(')E='5R;B!E;7!T
M>2@D9&%T92D["B`@("`@("`@?0H*("`@("`@("`D96UP='D@/2`P.PH@("`@
M("`@("\J($-H96-K(&5A8V@@9&%T92!A<G)A>2!C;VUP;VYE;G0N("HO"B`@
M("`@("`@9F]R96%C:"`H)&1A=&4@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@
M("`@("`@(&EF("AE;7!T>2@D=F%L*2D@>PH@("`@("`@("`@("`@("`@)&5M
M<'1Y*RL["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($-H
M96-K('-T871E(&]F(&5M<'1Y+B`J+PH@("`@("`@(&EF("@D96UP='D@/3T@
M,"D@>PH@("`@("`@("`@("`O*B!)9B!N;R!E;7!T>2!P87)T<R!R971U<FX@
M,"X@*B\*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@?2!E;'-E:68@
M*"1E;7!T>2`]/2`S*2!["B`@("`@("`@("`@("\J($EF(&%L;"!E;7!T>2!P
M87)T<R!R971U<FX@,2X@*B\*("`@("`@("`@("`@<F5T=7)N(#$["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@268@<V]M92!E;7!T>2!P87)T
M<R!R971U<FX@+3$N("HO"B`@("`@("`@("`@(')E='5R;B`M,3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&1A=&4@<W5P
M<&QI960@<W!L:70@=7`@:6YT;R!A;B!A<G)A>2X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1D871E7VEN("!$871E(&EN(&]N92!O9B!T:&4@=&AR
M964@9F]R;6%T<R!S=7!P;W)T960@8GD*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@($AO<F1E7T9O<FT@86YD($AO<F1E7T1A=&4@*$E33R!F;W)M
M870*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(%E965DM34TM1$0@
M2$@Z34TZ4U,L('1I;65S=&%M<"!965E934U$1$A(34U34PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@86YD(%5.25@@97!O8V@I('!L=7,@=&AE
M(&9O=7)T:"!965E9+4U-+41$+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@($%R<F%Y('=I=&@@=&AR964@96QE;65N=',@+2!Y96%R+"!M;VYT:"!A
M;F0@9&%Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$871E4&%R=',H)&1A
M=&5?:6XI"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1D871E7VEN*2D@
M>PH@("`@("`@("`@("`O*B!4:&ES(&ES('!R;V)A8FQY(&$@9F%I;&5D(&ES
M5F%L:60@:6YP=70@<V\@:G5S="!R971U<FX*("`@("`@("`@("`@("H@=&AE
M('!A<G1S(&%S('1H97D@87)E+B`J+PH@("`@("`@("`@("!R971U<FX@)&1A
M=&5?:6X["B`@("`@("`@?2!E;'-E:68@*&5M<'1Y*"1D871E7VEN*2D@>PH@
M("`@("`@("`@("`O*B!4:&ES(&ES(&IU<W0@86X@96UP='D@9FEE;&0@<V\@
M<F5T=7)N(&5M<'1Y('!A<G1S+B`J+PH@("`@("`@("`@("!R971U<FX@87)R
M87DH)WEE87(G(#T^("<G+"`G;6]N=&@G(#T^("<G+"`G9&%Y)R`]/B`G)RD[
M"B`@("`@("`@?0H*("`@("`@("`D9&%T92`]("1T:&ES+3YG971$871E3V(H
M)&1A=&5?:6XI.PH@("`@("`@(')E='5R;B!A<G)A>2@G>65A<B<@/3X@)&1A
M=&4M/GEE87(L"B`@("`@("`@("`@("`@("`@("`@("=M;VYT:"<@/3X@)&1A
M=&4M/FUO;G1H+`H@("`@("`@("`@("`@("`@("`@("`G9&%Y)R`]/B`D9&%T
M92T^;61A>2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&1A
M=&4@<W5P<&QI960@87,@82!(;W)D95]$871E(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1D871E7VEN("!$871E(&EN(&]N92!O9B!T
M:&4@=&AR964@9F]R;6%T<R!S=7!P;W)T960@8GD*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@($AO<F1E7T9O<FT@86YD($AO<F1E7T1A=&4@*$E3
M3R!F;W)M870*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(%E965DM
M34TM1$0@2$@Z34TZ4U,L('1I;65S=&%M<"!965E934U$1$A(34U34PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@86YD(%5.25@@97!O8V@I('!L
M=7,@=&AE(&9O=7)T:"!965E9+4U-+41$+@H@("`@("H*("`@("`J($!R971U
M<FX@1&%T92`@5&AE(&1A=&4@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971$871E3V(H)&1A=&5?:6XI"B`@("!["B`@("`@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92]$871E+G!H<"<["@H@("`@("`@(&EF("AI<U]A<G)A>2@D
M9&%T95]I;BDI('L*("`@("`@("`@("`@+RH@268@<&%S<V5D(&%N(&%R<F%Y
M(&-H86YG92!I="!T;R!T:&4@25-/(&9O<FUA="X@*B\*("`@("`@("`@("`@
M:68@*"1T:&ES+3YE;7!T>41A=&5!<G)A>2@D9&%T95]I;BD@/3T@,"D@>PH@
M("`@("`@("`@("`@("`@)&1A=&5?:6X@/2!S<')I;G1F*"<E,#1D+24P,F0M
M)3`R9"`P,#HP,#HP,"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1A=&5?:6Y;)WEE87(G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&%T95]I;ELG;6]N=&@G72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9&%T95]I;ELG9&%Y)UTI.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)R]>7&1[
M-'TM7&1[,GTM7&1[,GTD+R<L("1D871E7VEN*2D@>PH@("`@("`@("`@("`O
M*B!&:7@@=&AE(&1A=&4@:68@:70@:7,@=&AE('-H;W)T96YE9"!)4T\N("HO
M"B`@("`@("`@("`@("1D871E7VEN(#T@)&1A=&5?:6X@+B`G(#`P.C`P.C`P
M)SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!N97<@2&]R9&5?1&%T92@D
M9&%T95]I;BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&1A
M=&4@<W5P<&QI960@87,@82!(;W)D95]$871E(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1D871E("!%:71H97(@86X@86QR96%D>2!S
M970@=7`@2&]R9&5?1&%T92!O8FIE8W0@;W(@80H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@<W1R:6YG(&1A=&4@:6X@;VYE(&]F('1H92!T:')E92!F
M;W)M871S('-U<'!O<G1E9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M8GD@2&]R9&5?1F]R;2!A;F0@2&]R9&5?1&%T92`H25-/(&9O<FUA=`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@65E962U-32U$1"!(2#I-33I34RP@
M=&EM97-T86UP(%E965E-341$2$A-35-3(&%N9`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@54Y)6"!E<&]C:"D@<&QU<R!T:&4@9F]U<G1H(%E965DM
M34TM1$0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D871E
M(&9O<FUA='1E9"!A8V-O<F1I;F<@=&\@=&AE("1F;W)M871?;W5T"B`@("`@
M*B`@("`@("`@("`@("`@("`@<&%R86UE=&5R('=H96X@<V5T=&EN9R!U<"!T
M:&4@;6]N=&AD87EY96%R(&9I96QD+@H@("`@("HO"B`@("!F=6YC=&EO;B!F
M;W)M871$871E*"1D871E*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D9&%T
M92P@)T1A=&4G*2D@>PH@("`@("`@("`@("`D9&%T92`]("1T:&ES+3YG971$
M871E3V(H)&1A=&4I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1D871E
M+3YS=')F=&EM92@D=&AI<RT^7V9O<FUA=%]O=70I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@26YS97)T('1H92!D871E(&EN<'5T('1H<F]U9V@@=&AE(&9O
M<FT@:6YT;R`D:6YF;R!A<G)A>2P@:6X@=&AE(&9O<FUA=`H@("`@("H@<W!E
M8VEF:65D(&)Y('1H92`D9F]R;6%T7VEN('!A<F%M971E<B!W:&5N('-E='1I
M;F<@=7`@;6]N=&AD87EY96%R"B`@("`@*B!F:65L9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T26YF;R@F)'9A<G,L("8D=F%R+"`F)&EN9F\I"B`@("![
M"B`@("`@("`@)&EN9F\@/2`D=&AI<RT^7W9A;&ED871E06YD1F]R;6%T*"1V
M87(M/F=E=%9A;'5E*"1V87)S*2P@)'9A<BD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!686QI9&%T92]F;W)M870@82!D871E('-U8FUI<W-I;VXN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]V86QI9&%T94%N9$9O<FUA="@D=F%L=64L("8D
M=F%R*0H@("`@>PH@("`@("`@("\J($EF(&%N>2!C;VUP;VYE;G0@:7,@96UP
M='D@8V]N<VED97(@:70@82!B860@9&%T92!A;F0@<F5T=7)N('1H90H@("`@
M("`@("`J(&1E9F%U;'0N("HO"B`@("`@("`@:68@*"1T:&ES+3YE;7!T>41A
M=&5!<G)A>2@D=F%L=64I(#T](#$I('L*("`@("`@("`@("`@<F5T=7)N("1V
M87(M/F=E=$1E9F%U;'0H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D9&%T92`]("1T:&ES+3YG971$871E3V(H)'9A;'5E*3L*("`@("`@("`@
M("`@:68@*"1T:&ES+3Y?9F]R;6%T7VEN(#T]/2!N=6QL*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)&1A=&4M/G1I;65S=&%M<"@I.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1D871E+3YS=')F
M=&EM92@D=&AI<RT^7V9O<FUA=%]I;BD["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F
M:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("![
M"B`@("`@("`@<F5T=7)N(&%R<F%Y*"=N86UE)R`]/B!?*")$871E('-E;&5C
M=&EO;B(I+`H@("`@("`@("`@("`@("`@("`@("`G<&%R86US)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@("`@("`@("`@("`@("=S=&%R=%]Y96%R)R`]/B!A
M<G)A>2@G;&%B96PG(#T^(%\H(E-T87)T('EE87(B*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^
M("=I;G0G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("=E;F1?>65A<B<@
M("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(D5N9"!Y96%R(BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G
M("`]/B`G:6YT)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`G<&EC:V5R
M)R`@("`@/3X@87)R87DH)VQA8F5L)R`]/B!?*")3:&]W('!I8VME<B(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=T>7!E)R`@/3X@)V)O;VQE86XG*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("=F;W)M871?:6XG("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E-T;W)A
M9V4@9F]R;6%T(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G=&5X="<I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@)V9O<FUA=%]O=70G(#T^(&%R<F%Y*"=L86)E;"<@
M/3X@7R@B1&ES<&QA>2!F;W)M870B*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=T97AT)RDI
M*3L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]C;VQO<E!I8VME
M<B!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@9G5N8W1I;VX@:7-6
M86QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*
M("`@("`@("!I9B`H)'9A<BT^:7-297%U:7)E9"@I("8F(&5M<'1Y*"1V86QU
M92DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I96QD(&ES
M(')E<75I<F5D+B(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("!I9B`H96UP='DH)'9A;'5E*2!\?"!P<F5G7VUA=&-H
M*"<O7B,H6S`M.6$M>ETI>S9])"]I)RP@)'9A;'5E*2D@>PH@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1M97-S86=E(#T@
M7R@B5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H
M92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+B(I.PH@
M("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A<G)A>2@I.PH@
M("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B0V]L;W5R('-E;&5C=&EO;B(I
M.PH@("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D
M95]&;W)M7U1Y<&5?<V]R=&5R(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*
M"B`@("!V87(@)%]I;G-T86YC93L*("`@('9A<B`D7W9A;'5E<SL*("`@('9A
M<B`D7W-I>F4["B`@("!V87(@)%]H96%D97(["@H@("`@9G5N8W1I;VX@:6YI
M="@D=F%L=65S+"`D<VEZ92`](#@L("1H96%D97(@/2`G)RD*("`@('L*("`@
M("`@("!S=&%T:6,@)&AO<F1E7W-O<G1E<E]I;G-T86YC92`](#`["@H@("`@
M("`@("\J($=E="!T:&4@;F5X="!P<F]G<F5S<VEV92!I;G-T86YC92!C;W5N
M="!F;W(@=&AE(&AO<F1E"B`@("`@("`@("H@<V]R=&5R('-O('1H870@;75L
M=&EP;&4@<V]R=&5R<R!C86X@8F4@=7-E9"!O;B!O;F4@<&%G92X@*B\*("`@
M("`@("`D:&]R9&5?<V]R=&5R7VEN<W1A;F-E*RL["B`@("`@("`@)'1H:7,M
M/E]I;G-T86YC92`]("=H;W)D95]S;W)T97)?)R`N("1H;W)D95]S;W)T97)?
M:6YS=&%N8V4["B`@("`@("`@)'1H:7,M/E]V86QU97,@/2`D=F%L=65S.PH@
M("`@("`@("1T:&ES+3Y?<VEZ92`@(#T@)'-I>F4["B`@("`@("`@)'1H:7,M
M/E]H96%D97(@/2`D:&5A9&5R.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES5F%L
M:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T5F%L
M=65S*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]V86QU97,["B`@
M("!]"@H@("`@9G5N8W1I;VX@9V5T4VEZ92@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<VEZ93L*("`@('T*"B`@("!F=6YC=&EO;B!G971(96%D
M97(H*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]H96%D97(I
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VAE861E<CL*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("<G.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E
M=$]P=&EO;G,H)&ME>7,@/2!N=6QL*0H@("`@>PH@("`@("`@("1H=&UL(#T@
M)R<["B`@("`@("`@:68@*"1T:&ES+3Y?:&5A9&5R*2!["B`@("`@("`@("`@
M("1H=&UL("X]("<\;W!T:6]N('9A;'5E/2(B/B<@+B!H=&UL<W!E8VEA;&-H
M87)S*"1T:&ES+3Y?:&5A9&5R*2`N("<\+V]P=&EO;CXG.PH@("`@("`@('T*
M"B`@("`@("`@:68@*&5M<'1Y*"1K97ES*2D@>PH@("`@("`@("`@("`D:V5Y
M<R`](&%R<F%Y7VME>7,H)'1H:7,M/E]V86QU97,I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1K97ES(#T@97AP;&]D92@B7'0B+"`D:V5Y<ULG
M87)R87DG72D["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1K97ES(&%S
M("1S;%]K97DI('L*("`@("`@("`@("`@)&AT;6P@+CT@)SQO<'1I;VX@=F%L
M=64](B<@+B`D<VQ?:V5Y("X@)R(^)R`N(&AT;6QS<&5C:6%L8VAA<G,H)'1H
M:7,M/E]V86QU97-;)'-L7VME>5TI("X@)SPO;W!T:6]N/B<["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&AT;6P["B`@("!]"@H@("`@9G5N8W1I;VX@
M9V5T26YF;R@F)'9A<G,L("8D=F%R+"`F)&EN9F\I"B`@("!["B`@("`@("`@
M)'9A;'5E(#T@)'9A<G,M/F=E="@D=F%R+3YG971687).86UE*"DI.PH@("`@
M("`@("1I;F9O(#T@97AP;&]D92@B7'0B+"`D=F%L=65;)V%R<F%Y)UTI.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@
M='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@
M("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@
M/2!?*")3;W)T(&]R9&5R('-E;&5C=&EO;B(I.PH@("`@("`@("1A8F]U=%LG
M<&%R86US)UT@/2!A<G)A>2@*("`@("`@("`@("`@)W9A;'5E<R<@/3X@87)R
M87DH)VQA8F5L)R`]/B!?*")686QU97,B*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W1Y<&4G("`]/B`G<W1R:6YG;&ES="<I+`H@("`@("`@
M("`@("`G<VEZ92<@("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E-I>F4B*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G:6YT
M)RDL"B`@("`@("`@("`@("=H96%D97(G(#T^(&%R<F%Y*"=L86)E;"<@/3X@
M7R@B2&5A9&5R(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T
M>7!E)R`@/3X@)W1E>'0G*2D["B`@("`@("`@<F5T=7)N("1A8F]U=#L*("`@
M('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]S96QE8W1&:6QE<R!E>'1E
M;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@+RHJ"B`@("`@*B!4:&4@=&5X
M="!T;R!U<V4@:6X@=&AE(&QI;FLN"B`@("`@*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?;&EN:U]T97AT.PH*("`@("\J*@H@("`@
M("H@5&AE('-T>6QE('1O('5S92!F;W(@=&AE(&QI;FLN"B`@("`@*@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?;&EN:U]S='EL93L*
M"B`@("`O*BH*("`@("`J("!#<F5A=&4@=&AE(&QI;FL@=VET:"!A;B!I8V]N
M(&EN<W1E860@;V8@=&5X=#\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*
M("`@("`J+PH@("`@=F%R("1?:6-O;CL*"B`@("`O*BH*("`@("`J($-O;G1A
M:6YS(&=O;&QE;2!S96QE8W1F:6QE('-E;&5C=&EO;DE$"B`@("`@*@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<V5L96-T:60["@H@
M("`@9G5N8W1I;VX@:6YI="@D;&EN:U]T97AT(#T@;G5L;"P@)&QI;FM?<W1Y
M;&4@/2`G)RP@)&EC;VX@/2!F86QS92P*("`@("`@("`@("`@("`@("`@)'-E
M;&5C=&ED(#T@)R<I"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)&QI;FM?
M=&5X="DI('L*("`@("`@("`@("`@)&QI;FM?=&5X="`](%\H(E-E;&5C="!&
M:6QE<R(I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7VQI;FM?=&5X="`]
M("1L:6YK7W1E>'0["B`@("`@("`@)'1H:7,M/E]L:6YK7W-T>6QE(#T@)&QI
M;FM?<W1Y;&4["B`@("`@("`@)'1H:7,M/E]I8V]N(#T@)&EC;VX["B`@("`@
M("`@)'1H:7,M/E]S96QE8W1I9"`]("1S96QE8W1I9#L*("`@('T*"B`@("!F
M=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S
M86=E*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&=E=$EN9F\H)B1V87)S+"`F)'9A<BP@)B1I;F9O*0H@("`@>PH@
M("`@("`@("1V86QU92`]("1V87(M/F=E=%9A;'5E*"1V87)S*3L*("`@("`@
M("`D:6YF;R`]("1'3$]"04Q36R=R96=I<W1R>2==+3YC86QL*"=F:6QE<R]S
M96QE8W1L:7-T4F5S=6QT<R<L(&%R<F%Y*"1V86QU92D@*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R
M87DH*3L*("`@("`@("`D86)O=71;)VYA;64G72`](%\H(D9I;&4@<V5L96-T
M:6]N(BD["B`@("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S
M($AO<F1E7T9O<FU?5'EP95]A<W-I9VX@97AT96YD<R!(;W)D95]&;W)M7U1Y
M<&4@>PH*("`@('9A<B`D7VQE9G1686QU97,["B`@("!V87(@)%]R:6=H=%9A
M;'5E<SL*("`@('9A<B`D7VQE9G1(96%D97(["B`@("!V87(@)%]R:6=H=$AE
M861E<CL*("`@('9A<B`D7W-I>F4["B`@("!V87(@)%]W:61T:#L*"B`@("!F
M=6YC=&EO;B!I;FET*"1L969T5F%L=65S+"`D<FEG:'1686QU97,L("1L969T
M2&5A9&5R(#T@)R<L"B`@("`@("`@("`@("`@("`@("1R:6=H=$AE861E<B`]
M("<G+"`D<VEZ92`](#@L("1W:61T:"`]("<R,#!P>"<I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]L969T5F%L=65S(#T@)&QE9G1686QU97,["B`@("`@("`@
M)'1H:7,M/E]R:6=H=%9A;'5E<R`]("1R:6=H=%9A;'5E<SL*("`@("`@("`D
M=&AI<RT^7VQE9G1(96%D97(@/2`D;&5F=$AE861E<CL*("`@("`@("`D=&AI
M<RT^7W)I9VAT2&5A9&5R(#T@)')I9VAT2&5A9&5R.PH@("`@("`@("1T:&ES
M+3Y?<VEZ92`]("1S:7IE.PH@("`@("`@("1T:&ES+3Y?=VED=&@@/2`D=VED
M=&@["B`@("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S
M+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("!F=6YC=&EO;B!G971686QU97,H)'-I9&4I"B`@("![
M"B`@("`@("`@<F5T=7)N("1S:61E(#\@)'1H:7,M/E]R:6=H=%9A;'5E<R`Z
M("1T:&ES+3Y?;&5F=%9A;'5E<SL*("`@('T*"B`@("!F=6YC=&EO;B!S9716
M86QU97,H)'-I9&4L("1V86QU97,I"B`@("!["B`@("`@("`@:68@*"1S:61E
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?<FEG:'1686QU97,@/2`D=F%L=65S
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?;&5F=%9A
M;'5E<R`]("1V86QU97,["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N
M(&=E=$AE861E<B@D<VED92D*("`@('L*("`@("`@("!R971U<FX@)'-I9&4@
M/R`D=&AI<RT^7W)I9VAT2&5A9&5R(#H@)'1H:7,M/E]L969T2&5A9&5R.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&=E=%-I>F4H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7W-I>F4["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T5VED
M=&@H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W=I9'1H.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&=E=$]P=&EO;G,H)'-I9&4L("1F;W)M;F%M92D*
M("`@('L*("`@("`@("`D:'1M;"`]("<G.PH@("`@("`@("1H96%D97(@/2!F
M86QS93L*("`@("`@("!I9B`H)'-I9&4I('L*("`@("`@("`@("`@)'9A;'5E
M<R`]("1T:&ES+3Y?<FEG:'1686QU97,["B`@("`@("`@("`@(&EF("@A96UP
M='DH)'1H:7,M/E]R:6=H=$AE861E<BDI('L*("`@("`@("`@("`@("`@("1V
M86QU97,@/2!A<G)A>2@G)R`]/B`D=&AI<RT^7W)I9VAT2&5A9&5R*2`K("1V
M86QU97,["B`@("`@("`@("`@("`@("`D:&5A9&5R<R`]('1R=64["B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=F%L=65S
M(#T@)'1H:7,M/E]L969T5F%L=65S.PH@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1T:&ES+3Y?;&5F=$AE861E<BDI('L*("`@("`@("`@("`@("`@("1V86QU
M97,@/2!A<G)A>2@G)R`]/B`D=&AI<RT^7VQE9G1(96%D97(I("L@)'9A;'5E
M<SL*("`@("`@("`@("`@("`@("1H96%D97)S(#T@=')U93L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("!F;W)E86-H("@D=F%L=65S(&%S("1K
M97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`D:'1M;"`N/2`G/&]P=&EO;B!V
M86QU93TB)R`N("1K97D@+B`G(B<["B`@("`@("`@("`@(&EF("@D:&5A9&5R
M<RD@>PH@("`@("`@("`@("`@("`@)&AE861E<G,@/2!F86QS93L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1H=&UL("X]("<@;VYD
M8FQC;&EC:STB2&]R9&5?1F]R;5]!<W-I9VXN;6]V92A<)R<@+B`D9F]R;6YA
M;64@+@H@("`@("`@("`@("`@)UPG+"`G("X@*&EN="DD<VED92`N("<I.R(G
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1H=&UL("X]("<^)R`N("1V
M86P@+B`G/"]O<'1I;VX^)SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M:'1M;#L*("`@('T*"B`@("!F=6YC=&EO;B!G971);F9O*"8D=F%R<RP@)B1V
M87(L("8D:6YF;RD*("`@('L*("`@("`@("`D=F%L=64@/2`D=F%R<RT^9V5T
M*"1V87(M/F=E=%9A<DYA;64H*2`N("=?7W9A;'5E<R<I.PH@("`@("`@(&EF
M("AS=')P;W,H)'9A;'5E+"`B7'1<="(I(#T]/2!F86QS92D@>PH@("`@("`@
M("`@("`D;&5F="`]("1V86QU93L*("`@("`@("`@("`@)')I9VAT(#T@)R<[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@;&ES="@D;&5F="P@)')I
M9VAT*2`](&5X<&QO9&4H(EQT7'0B+"`D=F%L=64I.PH@("`@("`@('T*("`@
M("`@("!I9B`H96UP='DH)&QE9G0I*2!["B`@("`@("`@("`@("1I;F9O6R=L
M969T)UT@/2!A<G)A>2@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1I;F9O6R=L969T)UT@/2!E>'!L;V1E*")<="(L("1L969T*3L*("`@("`@
M("!]"B`@("`@("`@:68@*&5M<'1Y*"1R:6=H="DI('L*("`@("`@("`@("`@
M)&EN9F];)W)I9VAT)UT@/2!A<G)A>2@I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1I;F9O6R=R:6=H="==(#T@97AP;&]D92@B7'0B+"`D<FEG
M:'0I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!I
M;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%B
M;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A<G)A>2@I.PH@("`@("`@
M("1A8F]U=%LG;F%M92==(#T@7R@B07-S:6=N;65N="!C;VQU;6YS(BD["B`@
M("`@("`@)&%B;W5T6R=P87)A;7,G72`](&%R<F%Y*`H@("`@("`@("`@("`G
M;&5F=%9A;'5E<R<@/3X@87)R87DH)VQA8F5L)R`]/B!?*"),969T('9A;'5E
M<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G
M("`]/B`G<W1R:6YG;&ES="<I+`H@("`@("`@("`@("`G<FEG:'1686QU97,G
M(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B4FEG:'0@=F%L=65S(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G<W1R
M:6YG;&ES="<I+`H@("`@("`@("`@("`G;&5F=$AE861E<B<@/3X@87)R87DH
M)VQA8F5L)R`]/B!?*"),969T(&AE861E<B(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G='EP92<@(#T^("=T97AT)RDL"B`@("`@("`@("`@
M("=R:6=H=$AE861E<B<@/3X@87)R87DH)VQA8F5L)R`]/B!?*")2:6=H="!H
M96%D97(B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M='EP92<@(#T^("=T97AT)RDL"B`@("`@("`@("`@("=S:7IE)R`@(#T^(&%R
M<F%Y*"=L86)E;"<@/3X@7R@B4VEZ92(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G='EP92<@(#T^("=I;G0G*2P*("`@("`@("`@("`@)W=I
M9'1H)R`@(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B5VED=&@@:6X@0U-3('5N
M:71S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@
M(#T^("=T97AT)RDI.PH@("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]
M"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?8W)E9&ET8V%R9"!E>'1E;F1S($AO
M<F1E7T9O<FU?5'EP92!["@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@
M)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!I9B`H
M96UP='DH)'9A;'5E*2`F)B`D=F%R+3YI<U)E<75I<F5D*"DI('L*("`@("`@
M("`@("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(I
M.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("!I9B`H(65M<'1Y*"1V86QU92DI('L*("`@("`@("`@("`@+RH@9V5T0V%R
M9%1Y<&4H*2!W:6QL(&%L<V\@=F5R:69Y('1H92!C:&5C:W-U;2X@*B\*("`@
M("`@("`@("`@)'1Y<&4@/2`D=&AI<RT^9V5T0V%R9%1Y<&4H)'9A;'5E*3L*
M("`@("`@("`@("`@:68@*"1T>7!E(#T]/2!F86QS92!\?"`D='EP92`]/2`G
M=6YK;F]W;B<I('L*("`@("`@("`@("`@("`@("1M97-S86=E(#T@7R@B5&AI
M<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(BD[
M"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&=E=$-H96-K<W5M*"1C8VYU;2D*("`@('L*("`@("`@("`D;&5N
M(#T@<W1R;&5N*"1C8VYU;2D["B`@("`@("`@:68@*"%I<U]L;VYG*"1L96X@
M+R`R*2D@>PH@("`@("`@("`@("`D=V5I9VAT(#T@,CL*("`@("`@("`@("`@
M)&1I9VET(#T@)&-C;G5M6S!=.PH@("`@("`@('T@96QS96EF("AI<U]L;VYG
M*"1L96X@+R`R*2D@>PH@("`@("`@("`@("`D=V5I9VAT(#T@,3L*("`@("`@
M("`@("`@)&1I9VET(#T@)&-C;G5M6S!=("H@,CL*("`@("`@("!]"B`@("`@
M("`@:68@*"1D:6=I="`^(#DI('L*("`@("`@("`@("`@)&1I9VET(#T@)&1I
M9VET("T@.3L*("`@("`@("!]"B`@("`@("`@)&D@/2`Q.PH@("`@("`@("1C
M:&5C:W-U;2`]("1D:6=I=#L*("`@("`@("!W:&EL92`H)&D@/"`D;&5N*2![
M"B`@("`@("`@("`@(&EF("@D8V-N=6U;)&E=("$]("<@)RD@>PH@("`@("`@
M("`@("`@("`@)&1I9VET(#T@)&-C;G5M6R1I72`J("1W96EG:'0["B`@("`@
M("`@("`@("`@("`D=V5I9VAT(#T@*"1W96EG:'0@/3T@,2D@/R`R(#H@,3L*
M("`@("`@("`@("`@("`@(&EF("@D9&EG:70@/B`Y*2!["B`@("`@("`@("`@
M("`@("`@("`@)&1I9VET(#T@)&1I9VET("T@.3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1C:&5C:W-U;2`K/2`D9&EG:70["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)&DK*SL*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D8VAE8VMS=6T["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T0V%R
M9%1Y<&4H)&-C;G5M*0H@("`@>PH@("`@("`@("1S=6T@/2`D=&AI<RT^9V5T
M0VAE8VMS=6TH)&-C;G5M*3L*("`@("`@("`D;"`]('-T<FQE;B@D8V-N=6TI
M.PH*("`@("`@("`O+R!38W)E96X@8VAE8VMS=6TN"B`@("`@("`@:68@*"@D
M<W5M("4@,3`I("$](#`I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@+R\@0VAE8VL@9F]R(%9I<V$N"B`@("`@("`@
M:68@*"@H)&P@/3T@,38I('Q\("@D;"`]/2`Q,RDI("8F"B`@("`@("`@("`@
M("@D8V-N=6U;,%T@/3T@-"DI('L*("`@("`@("`@("`@<F5T=7)N("=V:7-A
M)SL*("`@("`@("!]"@H@("`@("`@("\O($-H96-K(&9O<B!-87-T97)#87)D
M+@H@("`@("`@(&EF("@H)&P@/3T@,38I("8F"B`@("`@("`@("`@("@D8V-N
M=6U;,%T@/3T@-2D@)B8*("`@("`@("`@("`@*"1C8VYU;5LQ72`^/2`Q*2`F
M)@H@("`@("`@("`@("`H)&-C;G5M6S%=(#P](#4I*2!["B`@("`@("`@("`@
M(')E='5R;B`G;6%S=&5R8V%R9"<["B`@("`@("`@?0H*("`@("`@("`O+R!#
M:&5C:R!F;W(@06UE>"X*("`@("`@("!I9B`H*"1L(#T](#$U*2`F)@H@("`@
M("`@("`@("`H)&-C;G5M6S!=(#T](#,I("8F"B`@("`@("`@("`@("@H)&-C
M;G5M6S%=(#T](#0I('Q\("@D8V-N=6U;,5T@/3T@-RDI*2!["B`@("`@("`@
M("`@(')E='5R;B`G86UE>"<["B`@("`@("`@?0H*("`@("`@("`O+R!#:&5C
M:R!F;W(@1&ES8V]V97(@*$YO=G5S*2X*("`@("`@("!I9B`H<W1R;&5N*"1C
M8VYU;2D@/3T@,38@)B8*("`@("`@("`@("`@<W5B<W1R*"1C8VYU;2P@,"P@
M-"D@/3T@)S8P,3$G*2!["B`@("`@("`@("`@(')E='5R;B`G9&ES8V]V97(G
M.PH@("`@("`@('T*"B`@("`@("`@+R\@268@=V4@9V]T('1H:7,@9F%R+"!T
M:&5N(&YO(&-A<F0@;6%T8VAE9"X*("`@("`@("!R971U<FX@)W5N:VYO=VXG
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE
M;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@
M("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE
M)UT@/2!?*")#<F5D:70@8V%R9"!N=6UB97(B*3L*("`@("`@("!R971U<FX@
M)&%B;W5T.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7V]B<F]W
M<V5R(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!F=6YC=&EO;B!I
M<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@
M>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D[
M"B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")296QA=&EO;G-H:7`@0G)O
M=W-E<B(I.PH@("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S
M<R!(;W)D95]&;W)M7U1Y<&5?9&)L;V]K=7`@97AT96YD<R!(;W)D95]&;W)M
M7U1Y<&5?96YU;2!["@H@("`@9G5N8W1I;VX@:6YI="@D9'-N+"`D<W%L+"`D
M<')O;7!T(#T@;G5L;"D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)T1"
M+G!H<"<["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"D["B`@("`@("`@)&1B
M(#T@)D1".CIC;VYN96-T*"1D<VXI.PH@("`@("`@(&EF("@A:7-?82@D9&(L
M("=014%27T5R<F]R)RDI('L*"B`@("`@("`@("`@("\O(%-E="!$0B!P;W)T
M86)I;&ET>2!O<'1I;VYS+@H@("`@("`@("`@("!S=VET8V@@*"1D8BT^<&AP
M='EP92D@>PH@("`@("`@("`@("!C87-E("=M<W-Q;"<Z"B`@("`@("`@("`@
M("`@("`D9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)404))
M3$E465],3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%4E)/4E,@?"!$0E]0
M3U)404))3$E465]25%))32D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@("1D8BT^<V5T3W!T
M:6]N*"=P;W)T86)I;&ET>2<L($1"7U!/4E1!0DE,25197TQ/5T520T%312!\
M($1"7U!/4E1!0DE,25197T524D]24RD["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1C;VP@/2`F)&1B+3YG971#;VPH)'-Q;"D["B`@("`@("`@("`@
M(&EF("@A:7-?82@D8V]L+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T%R<F%Y+G!H<"<["B`@("`@("`@
M("`@("`@("`D=F%L=65S(#T@2&]R9&5?07)R87DZ.F-O;6)I;F4H)&-O;"P@
M)&-O;"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<&%R96YT
M.CII;FET*"1V86QU97,L("1P<F]M<'0I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@*
M("`@("`@("`@("`@)VYA;64G(#T^(%\H(D1A=&%B87-E($QO;VMU<"(I+`H@
M("`@("`@("`@("`G<&%R86US)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@
M("=D<VXG(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B1%-.("AS964@:'1T<#HO
M+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI
M;G1R;RUD<VXN<&AP*2(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W1Y<&4G("`]/B`G=&5X="<I+`H@("`@("`@("`@("`@("`@)W-Q;"<@
M/3X@87)R87DH)VQA8F5L)R`]/B!?*")344P@<W1A=&5M96YT(&9O<B!V86QU
M92!L;V]K=7!S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M='EP92<@(#T^("=T97AT)RDL"B`@("`@("`@("`@("`@("`G<')O;7!T)R`]
M/B!A<G)A>2@G;&%B96PG(#T^(%\H(E!R;VUP="!T97AT(BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=T97AT)RDI
M"B`@("`@("`@("`@("D["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y
M<&5?9FEG;&5T(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!V87(@
M)%]T97AT.PH@("`@=F%R("1?9F]N=#L*"B`@("!F=6YC=&EO;B!I;FET*"1T
M97AT+"`D9F]N="D*("`@('L*("`@("`@("`D=&AI<RT^7W1E>'0@/2`D=&5X
M=#L*("`@("`@("`D=&AI<RT^7V9O;G0@/2`D9F]N=#L*("`@('T*"B`@("!F
M=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S
M86=E*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D=F%L=64I("8F("1V87(M
M/FES4F5Q=6ER960H*2D@>PH@("`@("`@("`@("`D;65S<V%G92`](%\H(E1H
M:7,@9FEE;&0@:7,@<F5Q=6ER960N(BD["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("A3=')I;F<Z.FQO=V5R*"1V
M86QU92D@(3T@4W1R:6YG.CIL;W=E<B@D=&AI<RT^7W1E>'0I*2!["B`@("`@
M("`@("`@("1M97-S86=E(#T@7R@B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED
M(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(I.PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!G971&;VYT*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]F;VYT.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&=E=%1E>'0H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W1E>'0[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L
M9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@
M("`@("`@<F5T=7)N(&%R<F%Y*`H@("`@("`@("`@("`G;F%M92<@/3X@7R@B
M1FEG;&5T($-!4%1#2$$B*2P*("`@("`@("`@("`@)W!A<F%M<R<@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`G=&5X="<@/3X@87)R87DH)VQA8F5L)R`]
M/B!?*")497AT(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W1Y<&4G("`]/B`G=&5X="<I+`H@("`@("`@("`@("`@("`@)V9O;G0G(#T^
M(&%R<F%Y*"=L86)E;"<@/3X@7R@B1FEG;&5T(&9O;G0B*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=T97AT)RDI"B`@
M("`@("`@("`@("D["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?
M:6YV86QI9"!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@=F%R("1M
M97-S86=E.PH*("`@(&9U;F-T:6]N(&EN:70H)&UE<W-A9V4I"B`@("!["B`@
M("`@("`@)'1H:7,M/FUE<W-A9V4@/2`D;65S<V%G93L*("`@('T*"B`@("!F
M=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S
M86=E*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"GT*"B\J
M*@H@*B!4:&ES(&-L87-S(')E<')E<V5N=',@82!S:6YG;&4@9F]R;2!V87)I
M86)L92!T:&%T(&UA>2!B92!R96YD97)E9"!A<R!O;F4@;W(*("H@;6]R92!F
M;W)M(&9I96QD<RX*("H*("H@0&%U=&AO<B`@4F]B97)T($4N($-O>6QE(#QR
M;V)E<G1E8V]Y;&5`:&]T;6%I;"YC;VT^"B`J($!P86-K86=E($AO<F1E7T9O
M<FT*("HO"F-L87-S($AO<F1E7T9O<FU?5F%R:6%B;&4@>PH*("`@("\J*@H@
M("`@("H@5&AE(&9O<FT@:6YS=&%N8V4@=&AI<R!V87)I86)L92!I<R!A<W-I
M9VYE9"!T;RX*("`@("`J"B`@("`@*B!`=F%R($AO<F1E7T9O<FT*("`@("`J
M+PH@("`@=F%R("1F;W)M.PH*("`@("\J*@H@("`@("H@02!S:&]R="!D97-C
M<FEP=&EO;B!O9B!T:&ES('9A<FEA8FQE)W,@<'5R<&]S92X*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&AU;6%N3F%M93L*
M"B`@("`O*BH*("`@("`J(%1H92!I;G1E<FYA;&QY('5S960@;F%M92X*("`@
M("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)'9A<DYA
M;64["@H@("`@+RHJ"B`@("`@*B!!('M`;&EN:R!(;W)D95]&;W)M7U1Y<&5]
M(&EN<W1A;F-E+@H@("`@("H*("`@("`J($!V87(@2&]R9&5?1F]R;5]4>7!E
M"B`@("`@*B\*("`@('9A<B`D='EP93L*"B`@("`O*BH*("`@("`J(%=H971H
M97(@=&AI<R!I<R!A(')E<75I<F5D('9A<FEA8FQE+@H@("`@("H*("`@("`J
M($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)')E<75I<F5D.PH*("`@
M("\J*@H@("`@("H@5VAE=&AE<B!T:&ES(&ES(&$@<F5A9&]N;'D@=F%R:6%B
M;&4N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A
M<B`D<F5A9&]N;'D["@H@("`@+RHJ"B`@("`@*B!!(&QO;F<@9&5S8W)I<'1I
M;VX@;V8@=&AE('9A<FEA8FQE)W,@<'5R<&]S92P@<W!E8VEA;"!I;G-T<G5C
M=&EO;G,L(&5T8RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)&1E<V-R:7!T:6]N.PH*("`@("\J*@H@("`@("H@5&AE('9A
M<FEA8FQE(&AE;'`@=&5X="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)&AE;'`["@H@("`@+RHJ"B`@("`@*B!7:&5T:&5R
M('1H:7,@:7,@86X@87)R87D@=F%R:6%B;&4N"B`@("`@*@H@("`@("H@0'9A
M<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V%R<F%Y5F%L.PH*("`@("\J
M*@H@("`@("H@5&AE(&1E9F%U;'0@=F%L=64N"B`@("`@*@H@("`@("H@0'9A
M<B!M:7AE9`H@("`@("HO"B`@("!V87(@)%]D969686QU92`](&YU;&P["@H@
M("`@+RHJ"B`@("`@*B!!('M`;&EN:R!(;W)D95]&;W)M7T%C=&EO;GT@:6YS
M=&%N8V4N"B`@("`@*@H@("`@("H@0'9A<B!(;W)D95]&;W)M7T%C=&EO;@H@
M("`@("HO"B`@("!V87(@)%]A8W1I;VX["@H@("`@+RHJ"B`@("`@*B!7:&5T
M:&5R('1H:7,@=F%R:6%B;&4@:7,@9&ES86)L960N"B`@("`@*@H@("`@("H@
M0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V1I<V%B;&5D(#T@9F%L
M<V4["@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@("`@("H@0'9A<B!B
M;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V%U=&]F:6QL960@/2!F86QS93L*
M"B`@("`O*BH*("`@("`J(%=H971H97(@=&AI<R!I<R!A(&AI9&1E;B!V87)I
M86)L92X*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@
M=F%R("1?:&ED9&5N(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!43T1/"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]O<'1I
M;VYS(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%9A<FEA8FQE(&-O;G-T
M<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&AU;6%N3F%M
M92`@("`@($$@<VAO<G0@9&5S8W)I<'1I;VX@;V8@=&AE('9A<FEA8FQE)W,*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('!U<G!O<V4N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1V87).86UE("`@("`@("!4:&4@:6YT
M97)N86QL>2!U<V5D(&YA;64N"B`@("`@*B!`<&%R86T@2&]R9&5?1F]R;5]4
M>7!E("1T>7!E("!!('M`;&EN:R!(;W)D95]&;W)M7U1Y<&5](&EN<W1A;F-E
M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)')E<75I<F5D("`@("`@5VAE=&AE
M<B!T:&ES(&ES(&$@<F5Q=6ER960@=F%R:6%B;&4N"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D<F5A9&]N;'D@("`@("!7:&5T:&5R('1H:7,@:7,@82!R96%D
M;VYL>2!V87)I86)L92X*("`@("`J($!P87)A;2!S=')I;F<@)&1E<V-R:7!T
M:6]N("`@($$@;&]N9R!D97-C<FEP=&EO;B!O9B!T:&4@=F%R:6%B;&4G<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<'5R<&]S92P@
M<W!E8VEA;"!I;G-T<G5C=&EO;G,L(&5T8RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@2&]R9&5?1F]R;5]687)I86)L92@D:'5M86Y.86UE+"`D=F%R3F%M92P@
M)B1T>7!E+"`D<F5Q=6ER960L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1R96%D;VYL>2`](&9A;'-E+"`D9&5S8W)I<'1I;VX@/2!N=6QL
M*0H@("`@>PH@("`@("`@("1T:&ES+3YH=6UA;DYA;64@("`]("1H=6UA;DYA
M;64["B`@("`@("`@)'1H:7,M/G9A<DYA;64@("`@(#T@)'9A<DYA;64["B`@
M("`@("`@)'1H:7,M/G1Y<&4@("`@("`@(#T@)B1T>7!E.PH@("`@("`@("1T
M:&ES+3YR97%U:7)E9"`@("`]("1R97%U:7)E9#L*("`@("`@("`D=&AI<RT^
M<F5A9&]N;'D@("`@/2`D<F5A9&]N;'D["B`@("`@("`@)'1H:7,M/F1E<V-R
M:7!T:6]N(#T@)&1E<V-R:7!T:6]N.PH@("`@("`@("1T:&ES+3Y?87)R87E6
M86P@("`]("AS=')P;W,H)'9A<DYA;64L("=;72<I("$]/2!F86QS92D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!<W-I9VX@=&AI<R!V87)I86)L92!T;R!T
M:&4@<W!E8VEF:65D(&9O<FTN"B`@("`@*@H@("`@("H@0'!A<F%M($AO<F1E
M7T9O<FT@)&9O<FT@(%1H92!F;W)M(&EN<W1A;F-E('1O(&%S<VEG;B!T:&ES
M('9A<FEA8FQE('1O+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971&;W)M3V(H
M)B1F;W)M*0H@("`@>PH@("`@("`@("1T:&ES+3YF;W)M(#T@)B1F;W)M.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!A(&1E9F%U;'0@=F%L=64@9F]R
M('1H:7,@=F%R:6%B;&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1V
M86QU92`@02!V87)I86)L92!V86QU92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T1&5F875L="@D=F%L=64I"B`@("!["B`@("`@("`@)'1H:7,M/E]D9696
M86QU92`]("1V86QU93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AI<R!V87)I86)L92=S(&1E9F%U;'0@=F%L=64N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@5&AI<R!V87)I86)L92=S(&1E9F%U;'0@=F%L=64N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1E9F%U;'0H*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7V1E9E9A;'5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@07-S:6=N<R!A;B!A8W1I;VX@=&\@=&AI<R!V87)I86)L92X*("`@
M("`J"B`@("`@*B!%>&%M<&QE.@H@("`@("H@/&-O9&4^"B`@("`@*B`D=B`]
M("8D9F]R;2T^861D5F%R:6%B;&4H)TUY(%9A<FEA8FQE)RP@)W9A<C$G+"`G
M=&5X="<L(&9A;'-E*3L*("`@("`J("1A8W1I;VX@/2`F2&]R9&5?1F]R;5]!
M8W1I;VXZ.F9A8W1O<GDH)W-U8FUI="<I.PH@("`@("H@)'8M/G-E=$%C=&EO
M;B@D86-T:6]N*3L*("`@("`J(#PO8V]D93X*("`@("`J"B`@("`@*B!`<&%R
M86T@2&]R9&5?1F]R;5]!8W1I;VX@)&%C=&EO;B`@02![0&QI;FL@2&]R9&5?
M1F]R;5]!8W1I;VY](&EN<W1A;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S
M971!8W1I;VXH)&%C=&EO;BD*("`@('L*("`@("`@("`D=&AI<RT^7V%C=&EO
M;B`]("1A8W1I;VX["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('=H
M971H97(@=&AI<R!V87)I86)L92!H87,@86X@871T86-H960@86-T:6]N+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&ES('9A
M<FEA8FQE(&AA<R!A;B!A='1A8VAE9"!A8W1I;VXN"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&AA<T%C=&EO;B@I"B`@("!["B`@("`@("`@<F5T=7)N("%I<U]N
M=6QL*"1T:&ES+3Y?86-T:6]N*3L*("`@('T*"B`@("`O*BH*("`@("`J($UA
M:V5S('1H:7,@82!H:61D96X@=F%R:6%B;&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&AI9&4H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:&ED9&5N(#T@=')U
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=VAE=&AE<B!T:&ES
M(&ES(&$@:&ED9&5N('9A<FEA8FQE+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;B`@5')U92!I9B!T:&ES(&$@:&ED9&5N('9A<FEA8FQE+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!I<TAI9&1E;B@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?:&ED9&5N.PH@("`@?0H*("`@("\J*@H@("`@("H@1&ES
M86)L97,@=&AI<R!V87)I86)L92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&ES
M86)L92@I"B`@("!["B`@("`@("`@)'1H:7,M/E]D:7-A8FQE9"`]('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('=H971H97(@=&AI<R!V
M87)I86)L92!I<R!D:7-A8FQE9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%1R=64@:68@=&AI<R!V87)I86)L92!I<R!D:7-A8FQE9"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@:7-$:7-A8FQE9"@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?9&ES86)L960["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@=&AE('-H;W)T(&1E<V-R:7!T:6]N(&]F('1H:7,@=F%R:6%B
M;&4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($$@<VAO<G0@9&5S
M8W)I<'1I;VX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T2'5M86Y.86UE*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FAU;6%N3F%M93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&EN=&5R;F%L;'D@=7-E9"!V
M87)I86)L92!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&ES('9A<FEA8FQE)W,@:6YT97)N86P@;F%M92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T5F%R3F%M92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3YV87).86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&ES
M('9A<FEA8FQE)W,@='EP92X*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E
M7T9O<FU?5'EP92`@5&AI<R!V87)I86)L92=S('M`;&EN:R!(;W)D95]&;W)M
M7U1Y<&5]"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@:6YS=&%N
M8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G9714>7!E*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/G1Y<&4["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!N86UE(&]F('1H:7,@=F%R:6%B;&4G<R!T>7!E+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&ES('9A<FEA8FQE)W,@
M('M`;&EN:R!(;W)D95]&;W)M7U1Y<&5](&YA;64N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%1Y<&5.86UE*"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/G1Y<&4M/F=E=%1Y<&5.86UE*"D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('=H971H97(@=&AI<R!I<R!A(')E<75I<F5D('9A<FEA8FQE
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&ES
M(&ES(&$@<F5Q=6ER960@=F%R:6%B;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&ES4F5Q=6ER960H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<F5Q
M=6ER960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('=H971H97(@
M=&AI<R!I<R!A(')E861O;FQY('9A<FEA8FQE+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&ES(&$@<F5A9&]N;'D@=F%R:6%B
M;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES4F5A9&]N;'DH*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^<F5A9&]N;'D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!P;W-S:6)L92!V86QU97,@;V8@=&AI<R!V
M87)I86)L92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@<&]S
M<VEB;&4@=F%L=65S(&]F('1H:7,@=F%R:6%B;&4@;W(@;G5L;"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T5F%L=65S*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/G1Y<&4M/F=E=%9A;'5E<R@I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!W:&5T:&5R('1H:7,@=F%R:6%B;&4@:&%S(&$@;&]N
M9R!D97-C<FEP=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@:68@=&AI<R!V87)I86)L92!H87,@82!L;VYG(&1E<V-R:7!T:6]N
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!H87-$97-C<FEP=&EO;B@I"B`@("![
M"B`@("`@("`@<F5T=7)N("%E;7!T>2@D=&AI<RT^9&5S8W)I<'1I;VXI.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&ES('9A<FEA8FQE)W,@
M;&]N9R!D97-C<FEP=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AI<R!V87)I86)L92=S(&QO;F<@9&5S8W)I<'1I;VXN"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$1E<V-R:7!T:6]N*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/F1E<V-R:7!T:6]N.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!W:&5T:&5R('1H:7,@:7,@86X@87)R87D@=F%R:6%B;&4N
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H:7,@
M86X@87)R87D@=F%R:6%B;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES07)R
M87E686PH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V%R<F%Y5F%L
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!W:&5T:&5R('1H:7,@
M=F%R:6%B;&4@:7,@=&\@=7!L;V%D(&$@9FEL92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=F%R:6%B;&4@:7,@=&\@=7!L;V%D
M(&$@9FEL92X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-5<&QO860H*0H@("`@
M>PH@("`@("`@(')E='5R;B`H)'1H:7,M/G1Y<&4M/F=E=%1Y<&5.86UE*"D@
M/3T@)V9I;&4G*3L*("`@('T*"B`@("`O*BH*("`@("`J($%S<VEG;G,@82!H
M96QP('1E>'0@=&\@=&AI<R!V87)I86)L92X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1H96QP("!4:&4@=F%R:6%B;&4@:&5L<"!T97AT+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S971(96QP*"1H96QP*0H@("`@>PH@("`@("`@
M("1T:&ES+3YF;W)M+3Y?:&5L<"`]('1R=64["B`@("`@("`@)'1H:7,M/FAE
M;'`@/2`D:&5L<#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=VAE
M=&AE<B!T:&ES('9A<FEA8FQE(&AA<R!S;VUE(&AE;'`@=&5X="!A<W-I9VYE
M9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AI
M<R!V87)I86)L92!H87,@82!H96QP('1E>'0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&AA<TAE;'`H*0H@("`@>PH@("`@("`@(')E='5R;B`A96UP='DH)'1H
M:7,M/FAE;'`I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M:&5L<"!T97AT(&]F('1H:7,@=F%R:6%B;&4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H:7,@=F%R:6%B;&4G<R!H96QP('1E>'0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$AE;'`H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^:&5L<#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@82!V
M87)I86)L92!O<'1I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;W!T:6]N("!4:&4@;W!T:6]N(&YA;64N"B`@("`@*B!`<&%R86T@;6EX960@
M)'9A;"`@("`@(%1H92!O<'1I;VXG<R!V86QU92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T3W!T:6]N*"1O<'1I;VXL("1V86PI"B`@("!["B`@("`@("`@
M)'1H:7,M/E]O<'1I;VYS6R1O<'1I;VY=(#T@)'9A;#L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@82!V87)I86)L92!O<'1I;VXG<R!V86QU92X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O<'1I;VX@(%1H92!O<'1I
M;VX@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("`@("`@("`@
M(%1H92!O<'1I;VXG<R!V86QU92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M3W!T:6]N*"1O<'1I;VXI"B`@("!["B`@("`@("`@<F5T=7)N(&ES<V5T*"1T
M:&ES+3Y?;W!T:6]N<ULD;W!T:6]N72D@/R`D=&AI<RT^7V]P=&EO;G-;)&]P
M=&EO;ET@.B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@4')O8V5S<V5S
M('1H92!S=6)M:71T960@=F%L=64@;V8@=&AI<R!V87)I86)L92!A8V-O<F1I
M;F<@=&\@=&AE(')U;&5S(&]F"B`@("`@*B!T:&4@=F%R:6%B;&4@='EP92X*
M("`@("`J"B`@("`@*B!`<&%R86T@5F%R:6%B;&5S("1V87)S("!4:&4@>T!L
M:6YK(%9A<FEA8FQE<WT@:6YS=&%N8V4@;V8@=&AE('-U8FUI='1E9`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@9F]R;2X*("`@("`J($!P87)A
M;2!M:7AE9"`D:6YF;R`@("`@($$@=F%R:6%B;&4@<&%S<V5D(&)Y(')E9F5R
M96YC92!T:&%T('=I;&P@8F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@(&%S<VEG;F5D('1H92!P<F]C97-S960@=F%L=64@;V8@=&AE('-U8FUI
M='1E9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@=F%R:6%B;&4@
M=F%L=64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1&5P96YD:6YG
M(&]N('1H92!V87)I86)L92!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971);F9O*"8D=F%R<RP@)B1I;F9O*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^='EP92T^9V5T26YF;R@D=F%R<RP@)'1H:7,L("1I;F9O*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=VAE=&AE<B!T:&ES('9A<FEA
M8FQE(&EF(&ET(&AA9"!T:&4@(G1R86-K8VAA;F=E(B!O<'1I;VX@<V5T"B`@
M("`@*B!H87,@86-T=6%L;'D@8F5E;B!C:&%N9V5D+@H@("`@("H*("`@("`J
M($!P87)A;2!687)I86)L97,@)'9A<G,@(%1H92![0&QI;FL@5F%R:6%B;&5S
M?2!I;G-T86YC92!O9B!T:&4@<W5B;6ET=&5D"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!F;W)M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@3G5L;"!I9B!T:&ES('9A<FEA8FQE(&1O97-N)W0@:&%V92!T:&4@
M(G1R86-K8VAA;F=E(@H@("`@("H@("`@("`@("`@("`@("`@("!O<'1I;VX@
M<V5T(&]R('1H92!F;W)M('=A<VXG="!S=6)M:71T960@>65T+B!!(&)O;VQE
M86X*("`@("`J("`@("`@("`@("`@("`@("`@:6YD:6-A=&EN9R!W:&5T:&5R
M('1H92!V87)I86)L92!W87,@8VAA;F=E9"!O=&AE<G=I<V4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('=A<T-H86YG960H)B1V87)S*0H@("`@>PH@("`@("`@
M(&EF("@A)'1H:7,M/F=E=$]P=&EO;B@G=')A8VMC:&%N9V4G*2D@>PH@("`@
M("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@("`@)&]L9"`]
M("1V87)S+3YG970H)U]?;VQD7R<@+B`D=&AI<RT^9V5T5F%R3F%M92@I*3L*
M("`@("`@("!I9B`H:7-?;G5L;"@D;VQD*2D@>PH@("`@("`@("`@("!R971U
M<FX@;G5L;#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1O;&0@(3T@)'9A
M<G,M/F=E="@D=&AI<RT^9V5T5F%R3F%M92@I*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%9A;&ED871E<R!T:&ES('9A<FEA8FQE+@H@("`@("H*("`@("`J
M($!P87)A;2!687)I86)L97,@)'9A<G,@(%1H92![0&QI;FL@5F%R:6%B;&5S
M?2!I;G-T86YC92!O9B!T:&4@<W5B;6ET=&5D"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!F;W)M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65S
M<V%G92`@02!V87)I86)L92!P87-S960@8GD@<F5F97)E;F-E('1H870@=VEL
M;"!B90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@87-S:6=N960@
M82!D97-C<FEP=&EV92!E<G)O<B!M97-S86=E(&EF"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("!V86QI9&%T:6]N(&9A:6QE9"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE('9A<FEA8FQE('9A
M;&ED871E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@=F%L:61A=&4H)B1V87)S
M+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?87)R87E6
M86PI('L*("`@("`@("`@("`@)'9A;',@/2`D=&AI<RT^9V5T5F%L=64H)'9A
M<G,I.PH@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1V86QS*2D@>PH@("`@
M("`@("`@("`@("`@:68@*"1T:&ES+3YR97%U:7)E9"D@>PH@("`@("`@("`@
M("`@("`@("`@("1M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U:7)E
M9"XB*3L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1V86QS(&%S("1I(#T^("1V86QU92D@>PH@("`@
M("`@("`@("`@("`@:68@*"1V86QU92`]/3T@;G5L;"`F)B`D=&AI<RT^<F5Q
M=6ER960I('L*("`@("`@("`@("`@("`@("`@("`D;65S<V%G92`](%\H(E1H
M:7,@9FEE;&0@:7,@<F5Q=6ER960N(BD["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H(21T:&ES+3YT>7!E+3YI<U9A;&ED*"1T:&ES
M+"`D=F%R<RP@)'9A;'5E+"`D;65S<V%G92DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1V86QU92`]("1T:&ES+3YG971686QU92@D=F%R
M<RD["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^='EP92T^:7-686QI9"@D
M=&AI<RP@)'9A<G,L("1V86QU92P@)&UE<W-A9V4I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!S=6)M:71T960@;W(@9&5F875L="!V86QU92!O9B!T:&ES('9A
M<FEA8FQE+@H@("`@("H@268@86X@86-T:6]N(&ES(&%T=&%C:&5D('1O('1H
M:7,@=F%R:6%B;&4L('1H92!V86QU92!W:6QL(&=E="!P87-S960@=&\*("`@
M("`J('1H92!A8W1I;VX@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!6
M87)I86)L97,@)'9A<G,@(%1H92![0&QI;FL@5F%R:6%B;&5S?2!I;G-T86YC
M92!O9B!T:&4@<W5B;6ET=&5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("!F;W)M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&EN9&5X("`@268@
M=&AE('9A<FEA8FQE(&ES(&%N(&%R<F%Y('9A<FEA8FQE+"!T:&ES"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!S<&5C:69I97,@=&AE(&%R<F%Y
M(&5L96UE;G0@=&\@<F5T=7)N+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1H92!V87)I86)L92!O<B!E;&5M96YT('9A;'5E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971686QU92@F)'9A<G,L("1I;F1E>"`](&YU;&PI"B`@
M("!["B`@("`@("`@:68@*"1T:&ES+3Y?87)R87E686PI('L*("`@("`@("`@
M("`@)&YA;64@/2!S=')?<F5P;&%C92@G6UTG+"`G)RP@)'1H:7,M/G9A<DYA
M;64I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1N86UE(#T@)'1H
M:7,M/G9A<DYA;64["B`@("`@("`@?0H@("`@("`@("1V86QU92`]("1V87)S
M+3YG971%>&ES=',H)&YA;64L("1W87-S970I.PH*("`@("`@("!I9B`H(21W
M87-S970I('L*("`@("`@("`@("`@)'9A;'5E(#T@)'1H:7,M/F=E=$1E9F%U
M;'0H*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^7V%R<F%Y5F%L
M("8F("%I<U]N=6QL*"1I;F1E>"DI('L*("`@("`@("`@("`@:68@*"$D=V%S
M<V5T("8F("%I<U]A<G)A>2@D=F%L=64I*2!["B`@("`@("`@("`@("`@("`D
M<F5T=7)N(#T@)'9A;'5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)')E='5R;B`](&ES<V5T*"1V86QU95LD:6YD97A=*2`_("1V
M86QU95LD:6YD97A=(#H@;G5L;#L*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1R971U<FX@/2`D=F%L=64["B`@("`@("`@
M?0H*("`@("`@("!I9B`H)'1H:7,M/FAA<T%C=&EO;B@I*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?86-T:6]N+3YS971686QU97,H)'9A<G,L("1R971U<FXL
M("1T:&ES+3Y?87)R87E686PI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1R971U<FX["B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O1W)A<&@O````````````````````````````````````````````
M`````````````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S0V`#`R,#4S,``@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]'<F%P:"]#:&%R="\`````````````
M````````````````````````````````````````````````````````,#`P
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-#8`
M,#(Q-3<Q`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T=R87!H
M+T-H87)T+W!I92YP:'``````````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q
M,#<Q-P`Q,#4Q-30S,S<T-@`P,C,P-C4`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%!I92!G<F%P:"!I
M;7!L96UE;G1A=&EO;B!F;W(@=&AE($AO<F1E7T=R87!H('!A8VMA9V4N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+T=R87!H+T=R87!H+T-H87)T+W!I92YP
M:'`L=B`Q+C$P+C$P+C0@,C`P-B\P,2\P,2`R,3HR.#HQ."!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(
M;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?1W)A<&@*("HO"F-L87-S($AO
M<F1E7T=R87!H7T-H87)T7W!I92!["@H@("`@=F%R("1G<F%P:#L*"B`@("!V
M87(@)%]D871A<V5T.PH@("`@=F%R("1?<&%D9&EN9R`](#(P.PH@("`@=F%R
M("1?;W5T;&EN92`]('1R=64["B`@("!V87(@)%]C;VQO<G,@/2!A<G)A>2@G
M=&%N)RP@)W!A;&5G;VQD96YR;V0G+"`G;VQI=F5D<F%B)RP@)V)L=64G+"`G
M<F5D)RP@)V=R965N)RP@)WEE;&QO=R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`G;W)A;F=E)RP@)V=R87DG+"`G<'5R<&QE)RD["B`@("`O*BH*("`@
M("`@(C(U-2PQ-3,L,"(L"B`@("`@("(P+#(P-"PQ-3,B+`H@("`@("`B,C`T
M+#(U-2PQ,#(B+`H@("`@("`B,C4U+#$P,BPQ,#(B+`H@("`@("`B,3`R+#(P
M-"PR-34B+`H@("`@("`B,C`T+#$U,RPR-34B+`H@("`@("`B,C4U+#`L,"(L
M"B`@("`@("(U,2PP+#(U-2(L"B`@("`@("(R-34L-3$L,34S(BP*("`@("`@
M(C(P-"PP+#(U-2(L"B`@("`@("(R-34L,C4U+#4Q(BP*("`@("`@(C4Q+#(U
M-2PU,2(L"B`@("`@("(R-34L,3`R+#`B*3L*("`@("HO"@H@("`@9G5N8W1I
M;VX@2&]R9&5?1W)A<&A?0VAA<G1?<&EE*"8D9W)A<&@L("1P87)A;7,I"B`@
M("!["B`@("`@("`@)'1H:7,M/F=R87!H(#T@)B1G<F%P:#L*"B`@("`@("`@
M9F]R96%C:"`H)'!A<F%M<R!A<R`D<&%R86T@/3X@)'9A;'5E*2!["B`@("`@
M("`@("`@("1K97D@/2`G7R<@+B`D<&%R86T["B`@("`@("`@("`@("1T:&ES
M+3XD:V5Y(#T@)'9A;'5E.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO
M;B!D<F%W*"D*("`@('L*("`@("`@("`D9&%T82`]("1T:&ES+3YG<F%P:"T^
M7V1A=&%;)WDG75LD=&AI<RT^7V1A=&%S971=.PH*("`@("`@("`O+R!);FET
M:6%L:7IE('-O;64@=F%R:6%B;&5S+@H@("`@("`@("1D:6%M971E<B`](&UI
M;B@D=&AI<RT^9W)A<&@M/E]G<F%P:%=I9'1H+"`D=&AI<RT^9W)A<&@M/E]G
M<F%P:$AE:6=H="D@+2`H)'1H:7,M/E]P861D:6YG("H@,BD["B`@("`@("`@
M)')A9&EU<R`]("1D:6%M971E<B`O(#(["B`@("`@("`@)&-O=6YT(#T@8V]U
M;G0H)&1A=&$I.PH@("`@("`@("1X8V5N=&5R(#T@)'1H:7,M/F=R87!H+3Y?
M9W)A<&A,969T("L@)'1H:7,M/E]P861D:6YG("L@*"1T:&ES+3YG<F%P:"T^
M7V=R87!H5VED=&@@+R`R*3L*("`@("`@("`D>6-E;G1E<B`]("1T:&ES+3YG
M<F%P:"T^7V=R87!H5&]P("L@)'1H:7,M/E]P861D:6YG("L@*"1T:&ES+3YG
M<F%P:"T^7V=R87!H2&5I9VAT("\@,BD["@H@("`@("`@("\O($-A;&-U;&%T
M92!T:&4@<W5M(&]F(&%L;"!S;&EC97,N"B`@("`@("`@)'-U;2`](#`["B`@
M("`@("`@9F]R96%C:"`H)&1A=&$@87,@)'@I('L*("`@("`@("`@("`@)'-U
M;2`K/2`D>#L*("`@("`@("!]"@H@("`@("`@("\O($-O;G9E<G0@96%C:"!S
M;&EC92!I;G1O('1H92!C;W)R97-P;VYD:6YG('!E<F-E;G1A9V4@;V8@80H@
M("`@("`@("\O(#,V,"UD96=R964@8VER8VQE+@H@("`@("`@("1D96=#;W5N
M="`](#`["B`@("`@("`@)'-L:6-E<R`](&%R<F%Y*"D["B`@("`@("`@)&1E
M9W)E97,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1D871A(&%S("1I
M(#T^("1Y*2!["B`@("`@("`@("`@(&EF("@H*"1Y("\@)'-U;2D@*B`S-C`I
M(#X@,"D@>PH@("`@("`@("`@("`@("`@)&1E9W)E97-;)&1E9T-O=6YT72`]
M("@D>2`O("1S=6TI("H@,S8P.PH@("`@("`@("`@("`@("`@)'-L:6-E<ULD
M9&5G0V]U;G1=(#T@)'D["B`@("`@("`@("`@("`@("`D;F%M97-;)&1E9T-O
M=6YT72`](&ES<V5T*"1T:&ES+3YG<F%P:"T^7V1A=&%;)W@G75LD:5TI(#\@
M)'1H:7,M/F=R87!H+3Y?9&%T85LG>"==6R1I72`Z("<G.PH@("`@("`@("`@
M("`@("`@)&1E9T-O=6YT*RL["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("\O($1R87<@=&AE(&)A<V5L:6YE+@H@("`@("`@(&EF("@D8V]U
M;G0@/B`Q*2!["B`@("`@("`@("`@("1L87-T7V%N9VQE(#T@,#L*("`@("`@
M("`@("`@)&-O=6YT(#T@8V]U;G0H)&1E9W)E97,I.PH@("`@("`@("`@("!F
M;W(@*"1Z(#T@,#L@)'H@/"`D8V]U;G0[("1Z*RLI('L*("`@("`@("`@("`@
M("`@("\O($-A;&-U;&%T92!A;F0@9')A=R!A<F-S(&-O<G)E<W!O;F1I;F<@
M=&\@96%C:`H@("`@("`@("`@("`@("`@+R\@<VQI8V4N"B`@("`@("`@("`@
M("`@("`D8WH@/2`D>B`E(&-O=6YT*"1T:&ES+3Y?8V]L;W)S*3L*("`@("`@
M("`@("`@("`@("1T:&ES+3YG<F%P:"T^:6UG+3YA<F,H)'AC96YT97(L("1Y
M8V5N=&5R+"`D<F%D:75S+"`D;&%S=%]A;F=L92P@*"1L87-T7V%N9VQE("L@
M)&1E9W)E97-;)'I=*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]O=71L:6YE(#\@)V)L86-K)R`Z("1T:&ES+3Y?
M8V]L;W)S6R1C>ETL("1T:&ES+3Y?8V]L;W)S6R1C>ETI.PH@("`@("`@("`@
M("`@("`@)&QA<W1?86YG;&4@/2`D;&%S=%]A;F=L92`K("1D96=R965S6R1Z
M73L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1T:&ES+3YG<F%P:"T^:6UG+3YC:7)C;&4H)'AC96YT97(L("1Y8V5N=&5R
M+"`D<F%D:75S+"`G8FQA8VLG+"`D=&AI<RT^7V-O;&]R<ULP72D["B`@("`@
M("`@?0H*("`@("`@("`O+R!#<F5A=&4@=&AE(&-O;&]R(&ME>2!A;F0@<VQI
M8V4@;&%B96QS+@H@("`@("`@("1Y0F%S92`]("1T:&ES+3YG<F%P:"T^7V=R
M87!H5&]P.PH@("`@("`@("1X0F%S92`](#4["B`@("`@("`@)&UA>"`]('-T
M<FQE;B@H<W1R:6YG*6UA>"@D9&%T82DI.PH@("`@("`@(&9O<B`H)'H@/2`P
M.R`D>B`\("1D96=#;W5N=#L@)'HK*RD@>PH@("`@("`@("`@("`D8WH@/2`D
M>B`E(&-O=6YT*"1T:&ES+3Y?8V]L;W)S*3L*("`@("`@("`@("`@)'!E<F-E
M;G0@/2`H)&1E9W)E97-;)'I=("\@,S8P*2`J(#$P,#L*("`@("`@("`@("`@
M)'!E<F-E;G0@/2!R;W5N9"@D<&5R8V5N="P@,BD["B`@("`@("`@("`@("1Y
M0F%S92`K/2`Q-3L*"B`@("`@("`@("`@("1T:&ES+3YG<F%P:"T^:6UG+3YR
M96-T86YG;&4H)'A"87-E+"`D>4)A<V4L(#$R+"`Q,BP@)V)L86-K)RP@)'1H
M:7,M/E]C;VQO<G-;)&-Z72D["B`@("`@("`@("`@(&EF("@D<VQI8V5S6R1Z
M72`^/2`Q,#`P("8F("1S;&EC97-;)'I=(#P@,3`P,#`P,"D@>PH@("`@("`@
M("`@("`@("`@)'-L:6-E<ULD>ET@/2`D<VQI8V5S6R1Z72`O(#$P,#`["B`@
M("`@("`@("`@("`@("`D<VQI8V5S6R1Z72`]("1S;&EC97-;)'I=("X@)VLG
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1R97!E870@/2`D;6%X("T@
M<W1R;&5N*"1S;&EC97-;)'I=*3L*("`@("`@("`@("`@:68@*"1R97!E870@
M/"`P*2!["B`@("`@("`@("`@("`@("`D<F5P96%T(#T@,#L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D<VQI8V5S6R1Z72`]('-T<E]R97!E870H)R`G
M+"`D<F5P96%T*2`N("1S;&EC97-;)'I=.PH*("`@("`@("`@("`@)'1H:7,M
M/F=R87!H+3YI;6<M/G1E>'0H)'-L:6-E<ULD>ETL("1X0F%S92`K(#(P+"`H
M)'E"87-E("L@,2DI.PH*("`@("`@("`@("`@)&QA8F5L(#T@)&YA;65S6R1Z
M72`N("<@*"<@+B`D<&5R8V5N="`N("<E*2<["B`@("`@("`@("`@(&EF("AS
M=')L96XH)&QA8F5L*2`^(#(P*2!["B`@("`@("`@("`@("`@("`D;&%B96QS
M(#T@97AP;&]D92@B7&XB+"!W;W)D=W)A<"@D;&%B96PL(#(P*2D["B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D;&%B96QS(&%S("1I(#T^("1L86)E;"D@
M>PH@("`@("`@("`@("`@("`@("`@(&EF("@D:2`^(#`I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)'E"87-E("L](#$U.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9W)A<&@M/FEM9RT^
M=&5X="@D;&%B96PL("1X0F%S92`K(#,U("L@*"1M87@@*B`T*2P@*"1Y0F%S
M92`K(#$I*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1T:&ES+3YG<F%P:"T^:6UG+3YT97AT*"1L
M86)E;"P@)'A"87-E("L@,S4@*R`H)&UA>"`J(#0I+"`H)'E"87-E("L@,2DI
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1W)A<&@O0VAA<G0O<&EE
M,V0N<&AP````````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S8W`#$P-3$U
M-#,S-S0V`#`R,S,Q-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@,T0@4&EE(&=R87!H(&EM<&QE;65N
M=&%T:6]N(&9O<B!T:&4@2&]R9&5?1W)A<&@@<&%C:V%G92X*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO1W)A<&@O1W)A<&@O0VAA<G0O<&EE,V0N<&AP+'8@
M,2XQ+C$P+C0@,C`P-B\P,2\P,2`R,3HR.#HQ."!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S
M+C`*("H@0'!A8VMA9V4@2&]R9&5?1W)A<&@*("HO"F-L87-S($AO<F1E7T=R
M87!H7T-H87)T7W!I93-D('L*"B`@("!V87(@)&=R87!H.PH*("`@('9A<B`D
M7V1A=&%S970["B`@("!V87(@)%]P861D:6YG(#T@,C`["B`@("!V87(@)%]O
M=71L:6YE(#T@=')U93L*("`@('9A<B`D7V-O;&]R<R`](&%R<F%Y*"=T86XG
M+"`G<&%L96=O;&1E;G)O9"<L("=O;&EV961R86(G+"`G8FQU92<L("=R960G
M+"`G9W)E96XG+"`G>65L;&]W)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("=O<F%N9V4G+"`G9W)A>2<L("=P=7)P;&4G*3L*("`@("\J*@H@("`@("`B
M,C4U+#$U,RPP(BP*("`@("`@(C`L,C`T+#$U,R(L"B`@("`@("(R,#0L,C4U
M+#$P,B(L"B`@("`@("(R-34L,3`R+#$P,B(L"B`@("`@("(Q,#(L,C`T+#(U
M-2(L"B`@("`@("(R,#0L,34S+#(U-2(L"B`@("`@("(R-34L,"PP(BP*("`@
M("`@(C4Q+#`L,C4U(BP*("`@("`@(C(U-2PU,2PQ-3,B+`H@("`@("`B,C`T
M+#`L,C4U(BP*("`@("`@(C(U-2PR-34L-3$B+`H@("`@("`B-3$L,C4U+#4Q
M(BP*("`@("`@(C(U-2PQ,#(L,"(I.PH@("`@*B\*"B`@("!F=6YC=&EO;B!(
M;W)D95]'<F%P:%]#:&%R=%]P:64S9"@F)&=R87!H+"`D<&%R86US*0H@("`@
M>PH@("`@("`@("1T:&ES+3YG<F%P:"`]("8D9W)A<&@["@H@("`@("`@(&9O
M<F5A8V@@*"1P87)A;7,@87,@)'!A<F%M(#T^("1V86QU92D@>PH@("`@("`@
M("`@("`D:V5Y(#T@)U\G("X@)'!A<F%M.PH@("`@("`@("`@("`D=&AI<RT^
M)&ME>2`]("1V86QU93L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@
M9')A=R@I"B`@("!["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]'<F%P:"]0;&]T+P``````````````````````````````````
M````````````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-#8`,#(Q-#0V`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T=R87!H+U!L;W0O8F%R+G!H<```
M```````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S`R,P`Q,#4Q-30S,S<T
M-@`P,C(W,C$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J($)A<B!G<F%P:"!I;7!L96UE;G1A=&EO;B!F
M;W(@=&AE($AO<F1E7T=R87!H('!A8VMA9V4N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+T=R87!H+T=R87!H+U!L;W0O8F%R+G!H<"QV(#$N-2XQ,BXT(#(P
M,#8O,#$O,#$@,C$Z,C@Z,3@@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K
M86=E($AO<F1E7T=R87!H"B`J+PIC;&%S<R!(;W)D95]'<F%P:%]0;&]T7V)A
M<B!["@H@("`@=F%R("1G<F%P:#L*"B`@("!V87(@)%]C;VQO<B`]("=B;'5E
M)SL*("`@('9A<B`D7V]U=&QI;F4@/2`G8FQA8VLG.PH@("`@=F%R("1?=VED
M=&@@/2`Q,#L*("`@('9A<B`D7V]F9G-E="`](#`["B`@("!V87(@)%]D871A
M<V5T.PH*("`@(&9U;F-T:6]N($AO<F1E7T=R87!H7U!L;W1?8F%R*"8D9W)A
M<&@L("1P87)A;7,I"B`@("!["B`@("`@("`@)'1H:7,M/F=R87!H(#T@)B1G
M<F%P:#L*"B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D<&%R86T@/3X@
M)'9A;'5E*2!["B`@("`@("`@("`@("1K97D@/2`G7R<@+B`D<&%R86T["B`@
M("`@("`@("`@("1T:&ES+3XD:V5Y(#T@)'9A;'5E.PH@("`@("`@('T*("`@
M('T*"B`@("!F=6YC=&EO;B!D<F%W*"1M:6Y9(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@)&1A=&$@/2`D=&AI<RT^9W)A<&@M/E]D871A6R=Y)UU;)'1H:7,M
M/E]D871A<V5T73L*"B`@("`@("`@)&)A<E=I9'1H(#T@)'1H:7,M/E]W:61T
M:#L*("`@("`@("`D8F%R3V9F<V5T(#T@)'1H:7,M/E]O9F9S970@*B`D8F%R
M5VED=&@["B`@("`@("`@)'4@/2`P.PH@("`@("`@("1V(#T@,#L*("`@("`@
M("`D8V]U;G0@/2!C;W5N="@D9&%T82D["B`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@)&-O=6YT.R`D:2LK*2!["B`@("`@("`@("`@("1X(#T@)&D["B`@
M("`@("`@("`@(&EF("@D;6EN62`]/3T@9F%L<V4@?'P@)&1A=&%;)&E=(#X]
M("1M:6Y9*2!["B`@("`@("`@("`@("`@("`D>2`]("1D871A6R1I73L*("`@
M("`@("`@("`@("`@("1T:&ES+3YG<F%P:"T^=')A;G-L871E*"1X+"`D>2D[
M"B`@("`@("`@("`@("`@("`D>"`]("1X("T@*"1B87)7:61T:"`O(#(I("L@
M)&)A<D]F9G-E=#L*("`@("`@("`@("`@("`@("1H96EG:'0@/2`D=&AI<RT^
M9W)A<&@M/E]G<F%P:$)O='1O;2`M("1Y.PH*("`@("`@("`@("`@("`@("1T
M:&ES+3YG<F%P:"T^:6UG+3YR96-T86YG;&4H)'@L("1Y+"`D8F%R5VED=&@L
M("1H96EG:'0L("1T:&ES+3Y?;W5T;&EN92P@)'1H:7,M/E]C;VQO<BD["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]'<F%P:"]0;&]T+V)A<F=R;W5P960N<&AP
M````````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(U-S(`,3`U,34T,S,W-#8`,#(T
M,S$W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+T=R87!H+U!L;W0O8F%R+G!H
M<"<["@HO*BH*("H@1W)O=7!E9"!B87(@9W)A<&@@:6UP;&5M96YT871I;VX@
M9F]R('1H92!(;W)D95]'<F%P:"!P86-K86=E+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]'<F%P:"]'<F%P:"]0;&]T+V)A<F=R;W5P960N<&AP+'8@,2XQ
M+C$P+C0@,C`P-B\P,2\P,2`R,3HR.#HQ."!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N
M8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*
M("H@0'!A8VMA9V4@2&]R9&5?1W)A<&@*("HO"F-L87-S($AO<F1E7T=R87!H
M7U!L;W1?8F%R9W)O=7!E9"!E>'1E;F1S($AO<F1E7T=R87!H7U!L;W1?8F%R
M('L*"B`@("!V87(@)%]S=&5P(#T@+C4["B`@("!V87(@)%]C;VQO<G,@/2!A
M<G)A>2@I.PH@("`@=F%R("1?9&%T87-E=',@/2!A<G)A>2@I.PH*("`@(&9U
M;F-T:6]N(&1R87<H*0H@("`@>PH@("`@("`@("\O($-A;&-U;&%T92!T:&4@
M<W1A<G1I;F<@;V9F<V5T(&9O<B!E86-H(&)A<BP@9G)O;2!W:&EC:"!W90H@
M("`@("`@("\O(&UO=F4@:70@;W9E<B!B>2`D=&AI<RT^7W-T97`N"B`@("`@
M("`@)&1A=&%S971S(#T@8V]U;G0H)'1H:7,M/E]D871A<V5T<RD["B`@("`@
M("`@)&=L;V)A;$]F9G-E="`]("1T:&ES+3Y?;V9F<V5T("T@*"@D=&AI<RT^
M7W-T97`@*B`H)&1A=&%S971S("T@,2DI("\@,BD["@H@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\("1D871A<V5T<SL@)&DK*RD@>PH@("`@("`@("`@("`O
M+R!#86QC=6QA=&4@=&AE(&]F9G-E="!O9B!T:&ES('-E="!O9B!B87)S+@H@
M("`@("`@("`@("`D=&AI<RT^7V]F9G-E="`]("1G;&]B86Q/9F9S970@*R`H
M)'1H:7,M/E]S=&5P("H@)&DI.PH*("`@("`@("`@("`@+R\@4V5T(&)A<B!P
M87)A;65T97)S('1H870@8VAA;F=E('!E<BUG<F]U<"X*("`@("`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?8V]L;W)S6R1I72DI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?8V]L;W(@/2`D=&AI<RT^7V-O;&]R<ULD:5T["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]D871A<V5T(#T@)'1H:7,M
M/E]D871A<V5T<ULD:5T["@H@("`@("`@("`@("`O+R!$<F%W('1H:7,@9&%T
M87-E="X*("`@("`@("`@("`@<&%R96YT.CID<F%W*"D["B`@("`@("`@?0H@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T=R
M87!H+U!L;W0O8F%R<W1A8VME9"YP:'``````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,38R-0`Q,#4Q-30S,S<T-@`P,C0R-C8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%-T86-K960@
M8F%R(&=R87!H(&EM<&QE;65N=&%T:6]N(&9O<B!T:&4@2&]R9&5?1W)A<&@@
M<&%C:V%G92X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO1W)A<&@O1W)A<&@O
M4&QO="]B87)S=&%C:V5D+G!H<"QV(#$N,2XQ,"XT(#(P,#8O,#$O,#$@,C$Z
M,C@Z,3@@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU
M8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T=R
M87!H"B`J+PIC;&%S<R!(;W)D95]'<F%P:%]0;&]T7V)A<G-T86-K960@>PH*
M("`@('9A<B`D9W)A<&@["@H@("`@=F%R("1?8V]L;W(@/2`G8FQU92<["B`@
M("!V87(@)%]O=71L:6YE(#T@)V)L86-K)SL*("`@('9A<B`D7W=I9'1H(#T@
M,3`["B`@("!V87(@)%]O9F9S970@/2`P.PH@("`@=F%R("1?9&%T87-E=#L*
M"B`@("!F=6YC=&EO;B!(;W)D95]'<F%P:%]0;&]T7V)A<G-T86-K960H)B1G
M<F%P:"P@)'!A<F%M<RD*("`@('L*("`@("`@("`D=&AI<RT^9W)A<&@@/2`F
M)&=R87!H.PH*("`@("`@("!F;W)E86-H("@D<&%R86US(&%S("1P87)A;2`]
M/B`D=F%L=64I('L*("`@("`@("`@("`@)&ME>2`]("=?)R`N("1P87)A;3L*
M("`@("`@("`@("`@)'1H:7,M/B1K97D@/2`D=F%L=64["B`@("`@("`@?0H@
M("`@?0H*("`@(&9U;F-T:6]N(&1R87<H*0H@("`@>PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T=R87!H+U!L;W0O;&EN92YP:'``````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,S(U-P`Q,#4Q-30S,S<T-@`P,C,Q,34`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J($QI
M;F4@9W)A<&@@:6UP;&5M96YT871I;VX@9F]R('1H92!(;W)D95]'<F%P:"!P
M86-K86=E+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]'<F%P:"]'<F%P:"]0
M;&]T+VQI;F4N<&AP+'8@,2XT+C$R+C0@,C`P-B\P,2\P,2`R,3HR.#HQ."!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`
M<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?1W)A<&@*("HO
M"F-L87-S($AO<F1E7T=R87!H7U!L;W1?;&EN92!["@H@("`@=F%R("1?9W)A
M<&@["B`@("!V87(@)%]C;VQO<B`]("=B;'5E)SL*("`@('9A<B`D7W=I9'1H
M(#T@,3L*("`@('9A<B`D7V1A=&%S970["@H@("`@9G5N8W1I;VX@2&]R9&5?
M1W)A<&A?4&QO=%]L:6YE*"8D9W)A<&@L("1P87)A;7,I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]G<F%P:"`]("8D9W)A<&@["@H@("`@("`@(&9O<F5A8V@@
M*"1P87)A;7,@87,@)'!A<F%M(#T^("1V86QU92D@>PH@("`@("`@("`@("`D
M:V5Y(#T@)U\G("X@)'!A<F%M.PH@("`@("`@("`@("`D=&AI<RT^)&ME>2`]
M("1V86QU93L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@9')A=R@D
M;6EN62`](&9A;'-E*0H@("`@>PH@("`@("`@("1D871A(#T@)'1H:7,M/E]G
M<F%P:"T^7V1A=&%;)WDG75LD=&AI<RT^7V1A=&%S971=.PH*("`@("`@("`D
M8V]U;G0@/2!C;W5N="@D9&%T82D["B`@("`@("`@)'9E<G1S(#T@87)R87DH
M*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8V]U;G0[("1I*RLI('L*
M("`@("`@("`@("`@)'@@/2`D:3L*("`@("`@("`@("`@:68@*"1M:6Y9("$]
M/2!F86QS92`F)B`D9&%T85LD:5T@/"`D;6EN62D@>PH@("`@("`@("`@("`@
M("`@:68@*&-O=6YT*"1V97)T<RD@/3T@,2D@>PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9W)A<&@M/FEM9RT^8VER8VQE*"1V97)T<ULP75LG>"==
M+"`D=F5R='-;,%U;)WDG72P@)'1H:7,M/E]W:61T:"P@)'1H:7,M/E]C;VQO
M<BP@)'1H:7,M/E]C;VQO<BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=R
M87!H+3YI;6<M/G!O;'EL:6YE*"1V97)T<RP@)'1H:7,M/E]C;VQO<BP@)'1H
M:7,M/E]W:61T:"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D=F5R=',@/2!A<G)A>2@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)'D@/2`D9&%T85LD:5T["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7V=R87!H+3YT<F%N<VQA=&4H)'@L("1Y*3L*
M("`@("`@("`@("`@("`@("1V97)T<UM=(#T@87)R87DH)W@G(#T^("1X+"`G
M>2<@/3X@)'DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D
M=&AI<RT^7V=R87!H+3YI;6<M/G!O;'EL:6YE*"1V97)T<RP@)'1H:7,M/E]C
M;VQO<BP@)'1H:7,M/E]W:61T:"D["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]'
M<F%P:"]0;&]T+W-C871T97(N<&AP````````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(T,C$`,3`U,34T,S,W-#8`,#(S-C(S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!38V%T=&5R
M('!L;W0@:6UP;&5M96YT871I;VX@9F]R('1H92!(;W)D95]'<F%P:"!P86-K
M86=E+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]'<F%P:"]'<F%P:"]0;&]T
M+W-C871T97(N<&AP+'8@,2XS+C$R+C0@,C`P-B\P,2\P,2`R,3HR.#HQ."!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`
M<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?1W)A<&@*("HO
M"F-L87-S($AO<F1E7T=R87!H7U!L;W1?<V-A='1E<B!["@H@("`@=F%R("1?
M9W)A<&@["B`@("!V87(@)%]C;VQO<B`]("=B;'5E)SL*("`@('9A<B`D7W-H
M87!E(#T@)W-Q=6%R92<["B`@("!V87(@)%]D871A<V5T.PH*("`@(&9U;F-T
M:6]N($AO<F1E7T=R87!H7U!L;W1?<V-A='1E<B@F)&=R87!H+"`D<&%R86US
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9W)A<&@@/2`F)&=R87!H.PH*("`@
M("`@("!F;W)E86-H("@D<&%R86US(&%S("1P87)A;2`]/B`D=F%L=64I('L*
M("`@("`@("`@("`@)&ME>2`]("=?)R`N("1P87)A;3L*("`@("`@("`@("`@
M)'1H:7,M/B1K97D@/2`D=F%L=64["B`@("`@("`@?0H@("`@?0H*("`@(&9U
M;F-T:6]N(&1R87<H)&UI;ED@/2!F86QS92D*("`@('L*("`@("`@("`D9&%T
M82`]("1T:&ES+3Y?9W)A<&@M/E]D871A6R=Y)UU;)'1H:7,M/E]D871A<V5T
M73L*"B`@("`@("`@)&-O=6YT(#T@8V]U;G0H)&1A=&$I.PH@("`@("`@("1V
M97)T<R`](&%R<F%Y*"D["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&-O
M=6YT.R`D:2LK*2!["B`@("`@("`@("`@("1X(#T@)&D["B`@("`@("`@("`@
M(&EF("@D;6EN62`]/3T@9F%L<V4@?'P@)&1A=&%;)&E=(#X]("1M:6Y9*2![
M"B`@("`@("`@("`@("`@("`D>2`]("1D871A6R1I73L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9W)A<&@M/G1R86YS;&%T92@D>"P@)'DI.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]G<F%P:"T^:6UG+3YB<G5S:"@D>"P@)'DL("1T
M:&ES+3Y?8V]L;W(L("1T:&ES+3Y?<VAA<&4I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+T=R87!H+G!H<```````````````````
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S-#,Q,``Q,#4Q-30S,S<U,@`P
M,C$R,S<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%1H92!(;W)D92!G<F%P:&EN9R!S=6ET92X*("H*
M("H@4')O=FED97,@82!S970@;V8@9W)A<&@@8F%C:V5N9',@86YD(&UE=&AO
M9',@9F]R(&-R96%T:6YG(&=R87!H<R!A<PH@*B!(5$U,('1A8FQE<RP@4U9'
M(&EM86=E<RP@971C+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]'<F%P:"]'
M<F%P:"YP:'`L=B`Q+C(W+C$P+C<@,C`P-B\P,2\P,2`R,3HR.#HQ."!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U
M8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN
M8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?1W)A<&@*("HO"F-L
M87-S($AO<F1E7T=R87!H('L*"B`@("`O*BH*("`@("`J(%1H92!(;W)D95])
M;6%G92!I;G-T86YC92!T:&%T('=E(&%R92!D<F%W:6YG('1H92!G<F%P:"!T
M;RX*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("H@0'9A
M<B!(;W)D95]);6%G90H@("`@("HO"B`@("!V87(@)&EM9SL*"B`@("!V87(@
M)%]G<F%P:',@/2!A<G)A>2@I.PH*("`@('9A<B`D7VAE:6=H=#L*("`@('9A
M<B`D7W=I9'1H.PH*("`@('9A<B`D7W1I=&QE(#T@)R<["@H@("`@=F%R("1?
M8F%C:V=R;W5N9"`]("=L:6=H=&=R87DG.PH@("`@=F%R("1?=&ET;&5&;VYT
M(#T@)W-A;G,M<V5R:68G.PH@("`@=F%R("1?;&%B96Q&;VYT(#T@)W-A;G,M
M<V5R:68G.PH@("`@=F%R("1?87AI<T9O;G0@/2`G;6]N;W-P86-E)SL*"B`@
M("!V87(@)%]P861D:6YG3&5F="`](#8P.PH@("`@=F%R("1?<&%D9&EN9T)O
M='1O;2`](#0P.PH@("`@=F%R("1?<&%D9&EN9U1O<"`](#,P.PH@("`@=F%R
M("1?<&%D9&EN9U)I9VAT(#T@,C`["@H@("`@=F%R("1?;V9F<V5T1W)I9%@@
M/2`P.PH*("`@('9A<B`D7VEM9U1Y<&4@/2`G9V0G.PH*("`@('9A<B`D7V1A
M=&$@/2!A<G)A>2@G>"<@/3X@87)R87DH*2P*("`@("`@("`@("`@("`@("`@
M("`@("`G>2<@/3X@87)R87DH*2D["@H@("`@=F%R("1?=&UP9&ER.PH*("`@
M('9A<B`D7W!L;W1S(#T@87)R87DH*3L*("`@('9A<B`D7V-H87)T<R`](&%R
M<F%Y*"D["@H@("`@9G5N8W1I;VX@2&]R9&5?1W)A<&@H)'!A<F%M<RD*("`@
M('L*("`@("`@("!I9B`H(65M<'1Y*"1P87)A;7-;)W1E;7`G72DI('L*("`@
M("`@("`@("`@)'1H:7,M/E]T;7!D:7(@/2`D<&%R86US6R=T96UP)UT["B`@
M("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1P87)A;7-;)W=I9'1H)UTI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?=VED=&@@/2`D<&%R86US6R=W:61T
M:"==.PH@("`@("`@("`@("`D=&AI<RT^7VAE:6=H="`]("1P87)A;7-;)VAE
M:6=H="==.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D<&%R86US
M6R=I;6=4>7!E)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?:6UG5'EP92`]
M("1P87)A;7-;)VEM9U1Y<&4G73L*("`@("`@("!]"B`@("!]"@H@("`@9G5N
M8W1I;VX@)F%D9%!L;W0H)'!L;W14>7!E+"`D<&QO=%!A<F%M<RD*("`@('L*
M("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]C:&%R=',I*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=-:7AI;F<@;V8@0VAA<G1S
M(&%N9"!0;&]T<R!I<R!N;W0@86QL;W=E9"XG*3L*("`@("`@("!]"@H@("`@
M("`@("1P;&]T5'EP92`](&)A<V5N86UE*"1P;&]T5'EP92D["B`@("`@("`@
M0&EN8VQU9&5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O1W)A<&@O4&QO
M="\G("X@)'!L;W14>7!E("X@)RYP:'`G.PH*("`@("`@("`D8VQA<W,@/2`G
M2&]R9&5?1W)A<&A?4&QO=%\G("X@)'!L;W14>7!E.PH@("`@("`@(&EF("AC
M;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D<&QO="`]("9N
M97<@)&-L87-S*"1T:&ES+"`D<&QO=%!A<F%M<RD["B`@("`@("`@("`@("1T
M:&ES+3Y?<&QO='-;72`]("8D<&QO=#L*("`@("`@("`@("`@<F5T=7)N("1P
M;&]T.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"=0;&]T('1Y<&4@;F]T(&9O=6YD)RD["B`@("`@("`@
M?0H@("`@?0H*("`@(&9U;F-T:6]N("9A9&1#:&%R="@D8VAA<G14>7!E+"`D
M8VAA<G1087)A;7,I"B`@("!["B`@("`@("`@:68@*&-O=6YT*"1T:&ES+3Y?
M<&QO=',I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=-:7AI;F<@;V8@0VAA<G1S(&%N9"!0;&]T<R!I<R!N;W0@86QL;W=E9"XG
M*3L*("`@("`@("!]"@H@("`@("`@("1C:&%R=%1Y<&4@/2!B87-E;F%M92@D
M8VAA<G14>7!E*3L*("`@("`@("!`:6YC;'5D95]O;F-E(&1I<FYA;64H7U]&
M24Q%7U\I("X@)R]'<F%P:"]#:&%R="\G("X@)&-H87)T5'EP92`N("<N<&AP
M)SL*"B`@("`@("`@)&-L87-S(#T@)TAO<F1E7T=R87!H7T-H87)T7R<@+B`D
M8VAA<G14>7!E.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@
M>PH@("`@("`@("`@("`D8VAA<G0@/2`F;F5W("1C;&%S<R@D=&AI<RP@)&-H
M87)T4&%R86US*3L*("`@("`@("`@("`@)'1H:7,M/E]C:&%R='-;72`]("8D
M8VAA<G0["B`@("`@("`@("`@(')E='5R;B`D8VAA<G0["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-H
M87)T('1Y<&4@;F]T(&9O=6YD)RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U
M;F-T:6]N(&%D9%A$871A*"1D871A*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M9&%T85LG>"==(#T@)&1A=&$["B`@("!]"@H@("`@9G5N8W1I;VX@861D641A
M=&$H)&1A=&$L("1N86UE(#T@)R<I"B`@("!["B`@("`@("`@:68@*&5M<'1Y
M*"1N86UE*2D@>PH@("`@("`@("`@("`D;F%M92`](&UD-2AS97)I86QI>F4H
M)&1A=&$I*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]D871A6R=Y)UU;
M)&YA;65=(#T@)&1A=&$["B`@("`@("`@<F5T=7)N("1N86UE.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&=E="@D<&%R86TI"B`@("!["B`@("`@("`@)&ME>2`]
M("=?)R`N("1P87)A;3L*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/B1K
M97DI(#\@)'1H:7,M/B1K97D@.B!N=6QL.PH@("`@?0H*("`@(&9U;F-T:6]N
M('-E="@D<&%R86TL("1V86QU92D*("`@('L*("`@("`@("`D:V5Y(#T@)U\G
M("X@)'!A<F%M.PH@("`@("`@("1T:&ES+3XD:V5Y(#T@)'9A;'5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@0V%C:&4@=&AE(&EM86=E(&%N9"!R971U<FX@
M82!L:6YK('1O('9I97<@:70@;W5T(&]F('1H92!C86-H92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9&ES<&QA>2@I"B`@("!["B`@("`@("`@9VQO8F%L("1C
M;VYF+"`D<F5G:7-T<GD["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]#
M86-H92YP:'`G.PH@("`@("`@("1C86-H92`]("9(;W)D95]#86-H93HZ<VEN
M9VQE=&]N*"1C;VYF6R=C86-H92==6R=D<FEV97(G72P@2&]R9&4Z.F=E=$1R
M:79E<D-O;F9I9R@G8V%C:&4G+"`D8V]N9ELG8V%C:&4G75LG9')I=F5R)UTI
M*3L*"B`@("`@("`@)'1H:7,M/FEN:71I86QI>F4H*3L*"B`@("`@("`@)&-I
M9"`](&UD-2AS97)I86QI>F4H)'1H:7,I*3L*("`@("`@("`D8V%C:&4M/G-E
M="@D8VED+"!S97)I86QI>F4H87)R87DH)V1A=&$G(#T^("1T:&ES+3YD<F%W
M*&9A;'-E*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V-T>7!E)R`]/B`D=&AI<RT^:6UG+3YG971#;VYT96YT5'EP92@I
M*2DI.PH*("`@("`@("`D=7)L(#T@2&]R9&4Z.G5R;"@D<F5G:7-T<GDM/F=E
M="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]S97)V:6-E<R]C86-H979I97<N
M<&AP)RD["B`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L
M+"`G8VED)RP@)&-I9"D["@H@("`@("`@(')E='5R;B`D=&AI<RT^:6UG+3YG
M971,:6YK*"1U<FPL("1T:&ES+3Y?=&ET;&4I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4')O8V5S<R!A;&P@;V8@=&AE(&1A=&$@<V5T<R!A;F0@<V5T(&=R
M87!H('!R;W!E<G1I97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN:71I86QI
M>F4H)&UI;ED@/2!F86QS92P@)'-T97!,86)E;'-9(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@+R\@3&]A9"!A($AO<F1E7TEM86=E(&-A;G9A<R!T;R!D<F%W
M(&]N+@H@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O26UA9V4N<&AP)SL*
M("`@("`@("`D=&AI<RT^:6UG(#T@)DAO<F1E7TEM86=E.CIF86-T;W)Y*"1T
M:&ES+3Y?:6UG5'EP92P@87)R87DH)VAE:6=H="<@/3X@)'1H:7,M/E]H96EG
M:'0L("=W:61T:"<@/3X@)'1H:7,M/E]W:61T:"P@)W1E;7`G(#T^("1T:&ES
M+3Y?=&UP9&ER*2D["@H@("`@("`@("\O(%1O=&%L(&EM86=E(&%N9"!G<F%P
M:"!A<F5A(&1I;65N<VEO;G,N"B`@("`@("`@)'=I9'1H(#T@)'1H:7,M/E]W
M:61T:"`M(#$["B`@("`@("`@)&AE:6=H="`]("1T:&ES+3Y?:&5I9VAT("T@
M,3L*"B`@("`@("`@)'1H:7,M/E]G<F%P:%1O<"`]("1T:&ES+3Y?<&%D9&EN
M9U1O<#L*("`@("`@("`D=&AI<RT^7V=R87!H0F]T=&]M(#T@)'1H:7,M/E]H
M96EG:'0@+2`Q("T@*"1T:&ES+3Y?<&%D9&EN9U1O<"`K("1T:&ES+3Y?<&%D
M9&EN9T)O='1O;2D["B`@("`@("`@)'1H:7,M/E]G<F%P:$QE9G0@/2`D=&AI
M<RT^7W!A9&1I;F=,969T.PH@("`@("`@("1T:&ES+3Y?9W)A<&A2:6=H="`]
M("1T:&ES+3Y?=VED=&@@+2`D=&AI<RT^7W!A9&1I;F=2:6=H="`M(#$["B`@
M("`@("`@)'1H:7,M/E]G<F%P:$AE:6=H="`]("1T:&ES+3Y?9W)A<&A";W1T
M;VT@+2`D=&AI<RT^7V=R87!H5&]P.PH@("`@("`@("1T:&ES+3Y?9W)A<&A7
M:61T:"`]("1T:&ES+3Y?9W)A<&A2:6=H="`M("1T:&ES+3Y?9W)A<&A,969T
M.PH*("`@("`@("`D=&AI<RT^7V=R:618(#T@;6EN*&-O=6YT*"1T:&ES+3Y?
M9&%T85LG>"==*2P@<F]U;F0H)'1H:7,M/E]G<F%P:%=I9'1H("\@-#`I*3L*
M("`@("`@("!I9B`H(21T:&ES+3Y?9W)I9%@I('L*("`@("`@("`@("`@<F5Q
M=6ER95]O;F-E("=014%2+G!H<"<["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"=.;R!D871A+B<I.PH@("`@("`@('T*"B`@("`@("`@
M+R\@1FEN9"!T:&4@<F%N9V4@;V8@86QL('D@=F%L=65S+@H@("`@("`@("1Y
M9&%T82`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/E]G<FED62`](#`["B`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/E]D871A6R=Y)UT@87,@)&1A=&$I('L*
M("`@("`@("`@("`@)'1H:7,M/E]G<FED62`](&UA>"@D=&AI<RT^7V=R:619
M+"!C;W5N="@D9&%T82DI.PH@("`@("`@("`@("`D>61A=&$@/2!A<G)A>5]M
M97)G92@D>61A=&$L("1D871A*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3Y?;6%X6"`](&-O=6YT*"1T:&ES+3Y?9&%T85LG>"==*3L*("`@("`@("!L
M:7-T*"1T:&ES+3Y?;6EN62P@)'1H:7,M/E]M87A9*2`]("1T:&ES+3Y?9FEN
M9%)A;F=E*"1Y9&%T82D["B`@("`@("`@:68@*"1M:6Y9("$]/2!F86QS92D@
M>PH@("`@("`@("`@("`D=&AI<RT^7VUI;ED@/2`D;6EN63L*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3Y?9&EF9ED@/2`D=&AI<RT^7VUA>%D@+2`D=&AI
M<RT^7VUI;ED["@H@("`@("`@("\O($-A;&-U;&%T92!T:&4@;G5M8F5R(&]F
M(%D@9W)I9&QI;F5S("AA;F0@=&AU<RP@;&%B96QS*2!T;PH@("`@("`@("\O
M('-H;W<N(%1R>2!T;R!M86ME('-U<F4@=V4@9&]N)W0@96YD('5P('=I=&@@
M=&]O(&1E;G-E(&$*("`@("`@("`O+R!G<FED+"!B=70@86QS;R!M86ME('-U
M<F4@=&AA="!W92!H879E(&$@9F5W(&=R:60@;&EN97,@=&\*("`@("`@("`O
M+R!B<F5A:R!U<"!S;6%L;"!D871A<V5T<RX*("`@("`@("!I9B`H)'-T97!,
M86)E;'-9(#T]/2!F86QS92D@>PH@("`@("`@("`@("`D=&AI<RT^7V=R:619
M(#T@;6%X*&UI;B@D=&AI<RT^7V=R:619+"!F;&]O<B@D=&AI<RT^7V=R87!H
M2&5I9VAT("\@,S`I*2P@9FQO;W(H)'1H:7,M/E]G<F%P:$AE:6=H="`O(#8P
M*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]G<FED
M62`](&9L;V]R*"@D=&AI<RT^7VUA>%D@+2`D=&AI<RT^7VUI;EDI("\@)'-T
M97!,86)E;'-9*3L*("`@("`@("!]"@H@("`@("`@(&EF("@H)'1H:7,M/E]M
M87A9("T@)'1H:7,M/E]M:6Y9*2`]/2`P*2!["B`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G4$5!4BYP:'`G.PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G3F\@<F%N9V4@=&\@9W)A<&@N($-H96-K(&1A=&$N)RD[
M"B`@("`@("`@?0H*("`@("`@("`O+R!&;W)M870@=&5X="!F;W(@;&%B96QI
M;F<@=&AE(%D@87AI<RX*("`@("`@("!I9B`H)'-T97!,86)E;'-9(#T]/2!F
M86QS92D@>PH@("`@("`@("`@("`D9&5L=&%,86)E;'-9(#T@*"1T:&ES+3Y?
M;6%X62`M("1T:&ES+3Y?;6EN62D@+R`H)'1H:7,M/E]G<FED62D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&1E;'1A3&%B96QS62`]("1S=&5P
M3&%B96QS63L*("`@("`@("!]"@H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M/2`D=&AI<RT^7V=R:619.R`D:2LK*2!["B`@("`@("`@("`@("1T97AT(#T@
M)'1H:7,M/E]M:6Y9("L@*"1D96QT84QA8F5L<UD@*B`D:2D["B`@("`@("`@
M("`@("1T:&ES+3Y?;&%B96QS65LD:5T@/2!N=6UB97)?9F]R;6%T*"1T97AT
M+"`R*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?;&%B
M96QS62DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+G!H<"<[
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=.;R!9(&%X
M:7,@9&%T82XG*3L*("`@("`@("!]"@H@("`@("`@("\O($-A;&-U;&%T92!T
M:&4@<W!A8VEN9R!F;W(@=&EC:W,@86YD(&=R:60@;&EN97,N"B`@("`@("`@
M)&1E;F]M:6YA=&]R(#T@)'1H:7,M/E]M87A8("T@,2`K("@R("H@)'1H:7,M
M/E]O9F9S971'<FED6"D["B`@("`@("`@:68@*"1D96YO;6EN871O<B`]/2`P
M*2!["B`@("`@("`@("`@("1D96YO;6EN871O<B`](#$["B`@("`@("`@?0H@
M("`@("`@("1T:&ES+3Y?9F%C=&]R6"`]("1T:&ES+3Y?9W)A<&A7:61T:"`O
M("1D96YO;6EN871O<CL*("`@("`@("`D=&AI<RT^7V9A8W1O<ED@/2`D=&AI
M<RT^7V=R87!H2&5I9VAT("\@)'1H:7,M/E]D:69F63L*"B`@("`@("`@)&1E
M;F]M:6YA=&]R(#T@)'1H:7,M/E]G<FED6"`M(#$@*R`R("H@)'1H:7,M/E]O
M9F9S971'<FED6#L*("`@("`@("!I9B`H)&1E;F]M:6YA=&]R(#T](#`I('L*
M("`@("`@("`@("`@)&1E;F]M:6YA=&]R(#T@,3L*("`@("`@("!]"B`@("`@
M("`@)'1H:7,M/E]D96QT851I8VMS6"`]("@D=&AI<RT^7V=R87!H5VED=&@@
M+R`D9&5N;VUI;F%T;W(I("\@)'1H:7,M/E]F86-T;W)8.PH@("`@("`@(&EF
M("@D<W1E<$QA8F5L<UD@/3T](&9A;'-E*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?9&5L=&%4:6-K<UD@/2`H)'1H:7,M/E]G<F%P:$AE:6=H="`O("1T:&ES
M+3Y?9W)I9%DI("\@)'1H:7,M/E]F86-T;W)9.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1T:&ES+3Y?9&5L=&%4:6-K<UD@/2`D<W1E<$QA8F5L
M<UD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("!F=6YC=&EO;B!D<F%W*"1D:7-P;&%Y(#T@=')U92P@)&UI;ED@/2!F86QS
M92P@)&1E;'1A3&%B96QS62`](&9A;'-E*0H@("`@>PH@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^:6YI=&EA;&EZ92@D;6EN62P@)&1E;'1A3&%B96QS62D[
M"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@
M("1P;&]T<R`](&-O=6YT*"1T:&ES+3Y?<&QO=',I.PH@("`@("`@("1C:&%R
M=',@/2!C;W5N="@D=&AI<RT^7V-H87)T<RD["@H@("`@("`@(&EF("@D<&QO
M=',I('L*("`@("`@("`@("`@)'1H:7,M/F1R87="86-K9W)O=6YD*"D["B`@
M("`@("`@("`@("1T:&ES+3YD<F%W5&ET;&4H*3L*("`@("`@("`@("`@)'1H
M:7,M/F1R87='<FED6"@I.PH@("`@("`@("`@("`D=&AI<RT^9')A=T=R:619
M*"D["B`@("`@("`@("`@("1T:&ES+3YD<F%W4&QO=$)O>"@I.PH@("`@("`@
M("`@("`D=&AI<RT^9')A=TQA8F5L<U@H*3L*("`@("`@("`@("`@)'1H:7,M
M/F1R87=,86)E;'-9*"D["@H@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@
M/"`D<&QO=',[("1I*RLI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&QO
M='-;)&E=+3YD<F%W*"1T:&ES+3Y?;6EN62D["B`@("`@("`@("`@('T*("`@
M("`@("!](&5L<V5I9B`H)&-H87)T<RD@>PH@("`@("`@("`@("`D=&AI<RT^
M9')A=U1I=&QE*"D["@H@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D
M8VAA<G1S.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-H87)T
M<ULD:5TM/F1R87<H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1D:7-P;&%Y(#\@)'1H:7,M/FEM9RT^9&ES<&QA>2@I(#H@
M)'1H:7,M/FEM9RT^<F%W*"D["B`@("!]"@H@("`@9G5N8W1I;VX@9')A=T)A
M8VMG<F]U;F0H*0H@("`@>PH@("`@("`@("1T:&ES+3YI;6<M/G)E8W1A;F=L
M92@P+"`P+"`D=&AI<RT^7W=I9'1H("T@,2P@)'1H:7,M/E]H96EG:'0@+2`Q
M+"`G8FQA8VLG+"`D=&AI<RT^7V)A8VMG<F]U;F0I.PH@("`@("`@("1T:&ES
M+3YI;6<M/G)E8W1A;F=L92@D=&AI<RT^7V=R87!H3&5F="P@)'1H:7,M/E]G
M<F%P:%1O<"P@)'1H:7,M/E]G<F%P:%=I9'1H+"`D=&AI<RT^7V=R87!H2&5I
M9VAT+"`G8FQA8VLG+"`G=VAI=&4G*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($1R87<@82!B;W@@87)O=6YD('1H92!P;&]T(&%R96$N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&1R87=0;&]T0F]X*"D*("`@('L*("`@("`@("`D=&AI<RT^
M:6UG+3YR96-T86YG;&4H)'1H:7,M/E]G<F%P:$QE9G0L("1T:&ES+3Y?9W)A
M<&A4;W`L("1T:&ES+3Y?9W)A<&A7:61T:"P@)'1H:7,M/E]G<F%P:$AE:6=H
M="P@)V)L86-K)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W<R!G<FED
M(&QI;F5S(&9R;VT@=&]P('1O(&)O='1O;2!O;B!T:&4@:6UA9V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&1R87='<FED6"@I"B`@("!["B`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@)'1H:7,M/E]G<FED6#L@)&DK*RD@>PH@("`@("`@
M("`@("`D>"`]("1T:&ES+3YT<F%N<VQA=&58*"1T:&ES+3Y?9&5L=&%4:6-K
M<U@@*B`D:2D["B`@("`@("`@("`@("1T:&ES+3YI;6<M/F1A<VAE9$QI;F4H
M)'@L("1T:&ES+3Y?9W)A<&A4;W`L("1X+"`D=&AI<RT^7V=R87!H0F]T=&]M
M+"`G9W)A>2<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1R
M87=S(&=R:60@;&EN97,@9G)O;2!L969T('1O(')I9VAT(&]N('1H92!I;6%G
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9')A=T=R:619*"D*("`@('L*("`@
M("`@("!F;W(@*"1I(#T@,#L@)&D@/#T@)'1H:7,M/E]G<FED63L@)&DK*RD@
M>PH@("`@("`@("`@("`D>2`]("1T:&ES+3YT<F%N<VQA=&59*"1T:&ES+3Y?
M;6EN62`K("1T:&ES+3Y?9&5L=&%4:6-K<UD@*B`D:2D["B`@("`@("`@("`@
M("1T:&ES+3YI;6<M/F1A<VAE9$QI;F4H)'1H:7,M/E]G<F%P:$QE9G0L("1Y
M+"`D=&AI<RT^7V=R87!H4FEG:'0L("1Y+"`G9W)A>2<I.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($1R87<@=&AE('1I=&QE+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!D<F%W5&ET;&4H*0H@("`@>PH@("`@("`@(&EF("@A
M96UP='DH)'1H:7,M/E]T:71L92DI('L*("`@("`@("`@("`@)'1H:7,M/FEM
M9RT^=&5X="@D=&AI<RT^7W1I=&QE+"`D=&AI<RT^7V=R87!H3&5F="`K("@D
M=&AI<RT^7V=R87!H5VED=&@@+R`R*2`M("@H<W1R;&5N*"1T:&ES+3Y?=&ET
M;&4I("\@,BD@*B`W*2P@)'1H:7,M/E]G<F%P:%1O<"`M(#(P+"`D=&AI<RT^
M7W1I=&QE1F]N="D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M1')A=W,@=&AE(&%X:7,@=&%G('1E>'0@;W5T<VED92!T:&4@<&QO='1I;F<@
M87)E82!O;B!T:&4@>`H@("`@("H@87AI<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9')A=TQA8F5L<U@H*0H@("`@>PH@("`@("`@("\O($1R87<@6"!A>&ES
M(&QA8F5L+@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]X;&%B96PI*2![
M"B`@("`@("`@("`@("1X(#T@)'1H:7,M/E]G<F%P:$QE9G0@*R`H)'1H:7,M
M/E]G<F%P:%=I9'1H("\@,BD@+2`H<W1R;&5N*"1T:&ES+3Y?>&QA8F5L*2`J
M(#,I.PH@("`@("`@("`@("`D>2`]("1T:&ES+3Y?9W)A<&A";W1T;VT@*R`U
M,#L*("`@("`@("`@("`@)'1H:7,M/FEM9RT^=&5X="@D=&AI<RT^7WAL86)E
M;"P@)'@L("1Y+"`D=&AI<RT^7VQA8F5L1F]N="D["B`@("`@("`@?0H*("`@
M("`@("`D;&%S=%@@/2`P.PH@("`@("`@("1M:6Y$:69F(#T@,C`["B`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/E]D871A6R=X)UT@87,@)&D@/3X@)'1E>'0I
M('L*("`@("`@("`@("`@)'@@/2`D=&AI<RT^=')A;G-L871E6"@D:2D["B`@
M("`@("`@("`@(&EF("@D>"`M("1L87-T6"`^/2`D;6EN1&EF9BD@>PH@("`@
M("`@("`@("`@("`@)&QA<W18(#T@)'@["B`@("`@("`@("`@("`@("`D=&AI
M<RT^:6UG+3YT97AT*"1T97AT+"`D>"`M(#4L("1T:&ES+3Y?9W)A<&A";W1T
M;VT@*R`H<W1R;&5N*"1T97AT*2`J(#<I+"`D=&AI<RT^7V%X:7-&;VYT+"`G
M8FQA8VLG+"`M.3`I.PH@("`@("`@("`@("`@("`@)'1H:7,M/FEM9RT^;&EN
M92@D>"P@)'1H:7,M/E]G<F%P:$)O='1O;2`K(#(L("1X+"`D=&AI<RT^7V=R
M87!H0F]T=&]M("T@,BD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$<F%W<R!T:&4@87AI<R!T86<@=&5X="!O=71S
M:61E('1H92!P;&]T=&EN9R!A<F5A(&]N('1H92!Y"B`@("`@*B!A>&ES+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!D<F%W3&%B96QS62@I"B`@("!["B`@("`@
M("`@+R\@1')A=R!9(&%X:7,@;&%B96PN"B`@("`@("`@:68@*"%E;7!T>2@D
M=&AI<RT^7WEL86)E;"DI('L*("`@("`@("`@("`@)'D@/2`D=&AI<RT^7V=R
M87!H5&]P("L@*"1T:&ES+3Y?9W)A<&A(96EG:'0@+R`R*2`K("@H<W1R;&5N
M*"1T:&ES+3Y?>6QA8F5L*2`O(#(I("H@-2D["B`@("`@("`@("`@("1T:&ES
M+3YI;6<M/G1E>'0H)'1H:7,M/E]Y;&%B96PL(#4L("1Y+"`D=&AI<RT^7VQA
M8F5L1F]N="P@)V)L86-K)RP@+3DP*3L*("`@("`@("!]"@H@("`@("`@(&9O
M<F5A8V@@*"1T:&ES+3Y?;&%B96QS62!A<R`D:2`]/B`D;&%B96PI('L*("`@
M("`@("`@("`@)'D@/2`D=&AI<RT^=')A;G-L871E62@D=&AI<RT^7VUI;ED@
M*R`D:2`J("1T:&ES+3Y?9&5L=&%4:6-K<UDI.PH@("`@("`@("`@("`D=&AI
M<RT^:6UG+3YT97AT*"1L86)E;"P@)'1H:7,M/E]G<F%P:$QE9G0@+2`H<W1R
M;&5N*"1L86)E;"D@*B`W*2P@)'D@+2`U+"`D=&AI<RT^7V%X:7-&;VYT*3L*
M("`@("`@("`@("`@)'1H:7,M/FEM9RT^;&EN92@D=&AI<RT^7V=R87!H3&5F
M="`M(#(L("1Y+"`D=&AI<RT^7V=R87!H3&5F="`K(#(L("1Y*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!486ME(&$@<&%I<B!O9B`H>"QY
M*2!G<F%P:"!C;V]R9&EN871E<R!A;F0@<F5T=7)N('1H90H@("`@("H@<V-R
M965N+7!I>&5L(&-O;W)D:6YA=&5S(&9O<B!T:&5M+@H@("`@("H*("`@("`J
M($!P87)A;2!F;&]A="`F)'@@("`@(%1H92!X('!O<VET:6]N(&EN('=O<FQD
M(&-O;W)D:6YA=&5S+@H@("`@("H@0'!A<F%M(&9L;V%T("8D>2`@("`@5&AE
M('D@<&]S:71I;VX@:6X@=V]R;&0@8V]O<F1I;F%T97,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('1R86YS;&%T92@F)'@L("8D>2D*("`@('L*("`@("`@("`D
M>"`]("1T:&ES+3YT<F%N<VQA=&58*"1X*3L*("`@("`@("`D>2`]("1T:&ES
M+3YT<F%N<VQA=&59*"1Y*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1R86YS
M;&%T92!T:&4@>"!C;V]R9&EN871E(&]F(&$@<&]I;G0@;VX@=&AE('!L;W0@
M=&\@<V-R965N"B`@("`@*B!C;V]R9&EN871E<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@9FQO870@)'@@(%1H92!X('=O<FQD("AP;&]T*2!C;V]R9&EN871E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!T<F%N<VQA=&58*"1X*0H@("`@>PH@
M("`@("`@(')E='5R;B`H*"1X("L@)'1H:7,M/E]O9F9S971'<FED6"D@*B`D
M=&AI<RT^7V9A8W1O<E@I("L@)'1H:7,M/E]G<F%P:$QE9G0["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!4<F%N<VQA=&4@=&AE('D@8V]O<F1I;F%T92!O9B!A
M('!O:6YT(&]N('1H92!P;&]T('1O('-C<F5E;@H@("`@("H@8V]O<F1I;F%T
M97,N"B`@("`@*@H@("`@("H@0'!A<F%M(&9L;V%T("1Y("!4:&4@>2!W;W)L
M9"`H<&QO="D@8V]O<F1I;F%T92X*("`@("`J+PH@("`@9G5N8W1I;VX@=')A
M;G-L871E62@D>2D*("`@('L*("`@("`@("!I9B`H)'DI('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?9W)A<&A";W1T;VT@+2`H*"1Y("T@)'1H:7,M
M/E]M:6Y9*2`J("1T:&ES+3Y?9F%C=&]R62D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9W)A<&A";W1T;VT["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1FEN9"!T:&4@;6EN:6UU;2!A
M;F0@;6%X:6UU;2!V86QU97,@9F]R(&$@<V5T(&]F(&1A=&$N"B`@("`@*@H@
M("`@("H@5&AE("1R97-O;'5T:6]N('9A<FEA8FQE(&ES('5S960@9F]R(')O
M=6YD:6YG(&UA>&EM=6T@86YD"B`@("`@*B!M:6YI;75M('9A;'5E<RX@268@
M;6%X:6UU;2!V86QU92!I<R`X-C0U('1H96XZ"B`@("`@*@H@("`@("H@268@
M)')E<V]L=71I;VX@:7,@,"P@=&AE;B!M87AI;75M('9A;'5E(&)E8V]M97,@
M.3`P,"X*("`@("`J($EF("1R97-O;'5T:6]N(&ES(#$L('1H96X@;6%X:6UU
M;2!V86QU92!B96-O;65S(#@W,#`N"B`@("`@*B!)9B`D<F5S;VQU=&EO;B!I
M<R`R+"!T:&5N(&UA>&EM=6T@=F%L=64@8F5C;VUE<R`X-C4P+@H@("`@("H@
M268@)')E<V]L=71I;VX@:7,@,RP@=&AE;B!M87AI;75M('9A;'5E(&)E8V]M
M97,@.#8T-2X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@("1D871A("`@
M("`@("`@5&AE($1A=&%S970@=&\@9FEN9"!T:&4@<F%N9V4@9F]R+@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&UI;B`@("`@("`@($UI;FEM=6T@=F%L=64@
M=&\@<W1A<G0@870N(%1H92!L;W=E<W0@;G5M8F5R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:6X@=&AE(&1A=&%S970@:7,@=7-E9"!I
M9B!I="=S(&QO=V5R+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UA>"`@("`@
M("`@($UA>&EM=6T@=F%L=64@=&\@<W1A<G0@870N(%1H92!H:6=H97-T"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;G5M8F5R(&EN('1H
M92!D871A<V5T(&ES('5S960@:68@:70G<PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&AI9VAE<BX*("`@("`J($!P87)A;2!I;G1E9V5R
M("1R97-O;'5T:6]N("!4:&4@<F5S;VQU=&EO;B!T;R!U<V4@9F]R('1H92!R
M86YG92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@;6EN:6UU
M;2!A;F0@;6%X:6UU;2!V86QU97,@9F]R('1H92!R86YG92X*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?9FEN9%)A;F=E
M*"1D871A+"`D;6EN(#T@,"P@)&UA>"`](#`L("1R97-O;'5T:6]N(#T@,"D*
M("`@('L*("`@("`@("!I9B`H(6-O=6YT*"1D871A*2D@>PH@("`@("`@("`@
M("!R971U<FX@87)R87DH)VUI;B<@/3X@,"P@)VUA>"<@/3X@,"D["B`@("`@
M("`@?0H*("`@("`@("`D9&%T85M=(#T@)&UA>#L*("`@("`@("`D9&%T85M=
M(#T@)&UI;CL*("`@("`@("`D;6%X(#T@;6%X*"1D871A*3L*("`@("`@("`D
M;6EN(#T@;6EN*"1D871A*3L*"B`@("`@("`@:68@*"1M87@@/3T@,"D@>PH@
M("`@("`@("`@("`D9F%C=&]R(#T@,3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!I9B`H)&UA>"`\(#`I('L*("`@("`@("`@("`@("`@("1F86-T
M;W(@/2`M<&]W*#$P+"`H9FQO;W(H;&]G,3`H86)S*"1M87@I*2D@*R`D<F5S
M;VQU=&EO;BDI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)&9A8W1O<B`]('!O=R@Q,"P@*&9L;V]R*&QO9S$P*&%B<R@D;6%X*2DI
M("T@)')E<V]L=71I;VXI*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@)&UA>"`]("1F86-T;W(@*B!`8V5I;"@D;6%X("\@)&9A8W1O<BD[
M"B`@("`@("`@)&UI;B`]("1F86-T;W(@*B!`9FQO;W(H)&UI;B`O("1F86-T
M;W(I.PH*("`@("`@("!R971U<FX@87)R87DH)&UI;BP@)&UA>"D["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T=R;W5P+P``
M````````````````````````````````````````````````````````````
M```````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#4Q-30S,S<T-@`P,C`U-C,`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O1W)O=7`O:&]O:W,N<&AP````````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`V-30T`#$P-3$U-#,S-S0V`#`R,C0S,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@5&AE($=R;W5P7VAO;VMS.CH@8VQA<W,@<')O=FED97,@=&AE($AO<F1E
M(&=R;W5P<R!S>7-T96T@=VET:"!T:&4*("H@861D:71I;VX@;V8@861D:6YG
M('-U<'!O<G0@9F]R(&AO;VL@9G5N8W1I;VYS('1O(&1E9FEN92!I9B!A('5S
M97(*("H@:7,@:6X@82!G<F]U<"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O:&]O:W,N<&AP+'8@,2XW+C(N,3`@,C`P-B\P,2\P,2`R
M,3HR.#HQ.2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*
M87-O;B!2=7-T(#QJ<G5S=$!R=7-T>7!A<G1S+F-O;3X*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($IA<V]N(%)U<W0@/&IR=7-T0')U<W1Y<&%R=',N
M8V]M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?
M1W)O=7`*("HO"F-L87-S($=R;W5P7VAO;VMS(&5X=&5N9',@1W)O=7`@>PH*
M("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N($=R;W5P7VAO;VMS*"D*("`@('L*("`@("`@("!P87)E;G0Z.D=R;W5P
M*"D["B`@("`@("`@<F5Q=6ER92`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T
M*"=F:6QE<F]O="<L("=H;W)D92<I("X@)R]C;VYF:6<O:&]O:W,N<&AP)SL*
M("`@('T*"B`@("`O*BH*("`@("`J($=E="!A(&QI<W0@;V8@979E<GD@9W)O
M=7`@=&AA="`D=7-E<B!I<R!I;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`D=7-E<B`@("`@("`@("!4:&4@=7-E<B!T;R!G970@9W)O=7!S(&9O
M<BX*("`@("`J($!P87)A;2!B;V]L96%N("1P87)E;G1'<F]U<',@($%L<V\@
M<F5T=7)N('1H92!P87)E;G1S(&]F(&%N>2!G<F]U<',_"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@;V8@86QL(&=R;W5P<R!T:&4@
M=7-E<B!I<R!I;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1W)O=7!-96UB
M97)S:&EP<R@D=7-E<BP@)'!A<F5N=$=R;W5P<R`](&9A;'-E*0H@("`@>PH@
M("`@("`@("1M96UB97)S:&EP<R`]('!A<F5N=#HZ9V5T1W)O=7!-96UB97)S
M:&EP<R@D=7-E<BP@)'!A<F5N=$=R;W5P<RD["B`@("`@("`@)&=R;W5P<R`]
M("1T:&ES+3YL:7-T1W)O=7!S*"D["B`@("`@("`@9F]R96%C:"`H)&=R;W5P
M<R!A<R`D9VED(#T^("1G<F]U<"D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M
M/FAA<TAO;VLH)&=R;W5P*2`F)@H@("`@("`@("`@("`@("`@8V%L;%]U<V5R
M7V9U;F,H)'1H:7,M/E]G971'<F]U<$AO;VM.86UE*"1G<F]U<"DL("1U<V5R
M*2D@>PH@("`@("`@("`@("`@("`@)&UE;6)E<G-H:7!S("L](&%R<F%Y*"1G
M:60@/3X@)&=R;W5P*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M)'!A<F5N=$=R;W5P<RD@>PH@("`@("`@("`@("`@("`@)'!A<F5N=',@/2`D
M=&AI<RT^9V5T1W)O=7!087)E;G1,:7-T*"1G:60I.PH@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)'!A<F5N=',@87,@)'!I9"`]/B`D<&%R96YT*2!["B`@
M("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YH87-(;V]K*"1P87)E;G0I
M("8F"B`@("`@("`@("`@("`@("`@("`@("`@(&-A;&Q?=7-E<E]F=6YC*"1T
M:&ES+3Y?9V5T1W)O=7!(;V]K3F%M92@D9W)O=7`I+"`D=7-E<BDI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&UE;6)E<G-H:7!S("L](&%R<F%Y*"1P
M:60@/3X@)'!A<F5N="D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&UE;6)E<G-H:7!S.PH@("`@?0H*("`@("\J*@H@("`@("H@4V%Y
M(&EF(&$@=7-E<B!I<R!A(&UE;6)E<B!O9B!A(&=R;W5P(&]R(&YO="X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=7-E<B`@("`@("!4:&4@;F%M
M92!O9B!T:&4@=7-E<BX*("`@("`J($!P87)A;2!I;G1E9V5R("1G:60@("`@
M("`@(%1H92!)1"!O9B!T:&4@9W)O=7`N"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D<W5B9W)O=7!S("!2971U<FX@=')U92!I9B!T:&4@=7-E<B!I<R!I;B!A
M;GD@<W5B9W)O=7!S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!O9B`D9W)O=7`L(&%L<V\N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N"B`@("`@*B\*("`@(&9U;F-T:6]N('5S97))<TEN1W)O=7`H)'5S97(L
M("1G:60L("1S=6)G<F]U<',@/2!T<G5E*0H@("`@>PH@("`@("`@("1G<F]U
M<"`]("1T:&ES+3YG971'<F]U<$YA;64H)&=I9"D["B`@("`@("`@:68@*"1T
M:&ES+3YH87-(;V]K*"1G<F]U<"DI('L*("`@("`@("`@("`@:68@*&-A;&Q?
M=7-E<E]F=6YC*"1T:&ES+3Y?9V5T1W)O=7!(;V]K3F%M92@D9W)O=7`I+"`D
M=7-E<BDI('L*("`@("`@("`@("`@("`@("1I;D=R;W5P(#T@=')U93L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1I;D=R;W5P(#T@
M9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D:6Y'<F]U<"`](&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"1I;D=R;W5P('Q\('!A<F5N=#HZ=7-E<DES26Y'<F]U<"@D=7-E<BP@)&=I
M9"P@)'-U8F=R;W5P<RDI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@:68@82!G
M<F]U<"!H87,@82!H;V]K(&%S<V]C:6%T960@=VET:"!I="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@9W)O=7`@;F%M92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE(&=R;W5P
M(&AA<R!A(&AO;VLL(&9A;'-E(&]T:&5R=VES90H@("`@("HO"B`@("!F=6YC
M=&EO;B!H87-(;V]K*"1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B!F=6YC
M=&EO;E]E>&ES=',H)'1H:7,M/E]G971'<F]U<$AO;VM.86UE*"1N86UE*2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!N86UE(&]F('1H
M92!H;V]K(&9U;F-T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&YA;64@(%1H92!G<F]U<"!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@9G5N8W1I;VX@;F%M92!F;W(@=&AE(&AO;VL@9F]R('1H
M:7,@9W)O=7`*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$=R;W5P2&]O:TYA
M;64H)&YA;64I"B`@("!["B`@("`@("`@<F5T=7)N("=?9W)O=7!?:&]O:U\G
M("X@<W1R7W)E<&QA8V4H)SHG+"`G7U\G+"`D;F%M92D["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP````````````````````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`V,S$U-0`Q,#4Q-30S,S<T-@`P,C(R,C8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J(%1H92!'<F]U<%]L9&%P(&-L87-S('!R;W9I9&5S(&%N($Q$05`@8F%C
M:V5N9"!F;W(@=&AE($AO<F1E(&=R;W5P<PH@*B!S>7-T96TN"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP+'8@,2XQ."XR
M+C(@,C`P-B\P,2\P,2`R,3HR.#HQ.2!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#4M,C`P-B!"96X@0VAA=F5T(#QB96Y`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0F5N($-H879E="`\8F5N0&AO<F1E
M+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXQ"B`J($!P86-K86=E($AO<F1E
M7T=R;W5P"B`J+PIC;&%S<R!'<F]U<%]L9&%P(&5X=&5N9',@1W)O=7`@>PH*
M("`@("\J*@H@("`@("H@3$1!4"!C;VYN96-T:6]N(&AA;F1L90H@("`@("HO
M"B`@("!V87(@)%]D<SL*"B`@("`O*BH*("`@("`J($QO8V%L(&-O<'D@;V8@
M=&AE(&=L;V)A;"`D8V]N9ELG9W)O=7`G75LG<&%R86US)UT@87)R87DN("!3
M:6UP;'D*("`@("`J(&9O<B!C;V1I;F<@8V]N=F5N:65N8V4N"B`@("`@*B\*
M("`@('9A<B`D7W!A<F%M<SL*"B`@("`O*BH*("`@("`J($=E;F5R871E9"!,
M1$%0(&9I;'1E<B!B87-E9"!O;B!T:&4@8V]N9FEG('!A<F%M971E<G,*("`@
M("`J+PH@("`@=F%R("1?9FEL=&5R.PH*("`@("\J*@H@("`@("H@0V]N<W1R
M=6-T;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N($=R;W5P7VQD87`H*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*("`@("`@("`D=&AI<RT^7W!A<F%M
M<R`]("1C;VYF6R=G<F]U<"==6R=P87)A;7,G73L*"B`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)V=I9"==(#T@<W1R=&]L;W=E<B@D=&AI<RT^7W!A<F%M<ULG
M9VED)UTI.PH@("`@("`@("1T:&ES+3Y?<&%R86US6R=M96UB97)U:60G72`]
M('-T<G1O;&]W97(H)'1H:7,M/E]P87)A;7-;)VUE;6)E<G5I9"==*3L*("`@
M("`@("!F;W)E86-H("@D=&AI<RT^7W!A<F%M<ULG;F5W9W)O=7!?;V)J96-T
M8VQA<W,G72!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)VYE=V=R;W5P7V]B:F5C=&-L87-S)UU;)&ME>5T@/2!S=')T
M;VQO=V5R*"1V86PI.PH@("`@("`@('T*"B`@("`@("`@+RH@1V5N97)A=&4@
M3$1!4"!S96%R8V@@9FEL=&5R+B`J+PH@("`@("`@(&EF("@A96UP='DH)'1H
M:7,M/E]P87)A;7-;)V9I;'1E<B==*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7V9I;'1E<B`]("1T:&ES+3Y?<&%R86US6R=F:6QT97(G73L*("`@("`@("!]
M(&5L<V5I9B`H(6ES7V%R<F%Y*"1T:&ES+3Y?<&%R86US6R=O8FIE8W1C;&%S
M<R==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V9I;'1E<B`]("=O8FIE8W1C
M;&%S<STG("X@)'1H:7,M/E]P87)A;7-;)V]B:F5C=&-L87-S)UT["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]F:6QT97(@/2`G)SL*
M("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P87)A;7-;)V]B:F5C=&-L
M87-S)UT@87,@)&]B:F5C=&-L87-S*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V9I;'1E<B`]("<H)B<@+B`D=&AI<RT^7V9I;'1E<CL*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9FEL=&5R("X]("<H;V)J96-T8VQA<W,])R`N("1O
M8FIE8W1C;&%S<R`N("<I*2<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3Y?9FEL=&5R(#T@<W1R=&]L;W=E<B@D=&AI<RT^7V9I
M;'1E<BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYN96-T<R!T;R!T:&4@
M3$1!4"!S97)V97(N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&]R($9A;'-E(&)A<V5D(&]N('-U8V-E<W,@;V8@8V]N;F5C="!A;F0@
M8FEN9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H*0H@("`@>PH@
M("`@("`@("\J($-O;FYE8W0@=&\@=&AE($Q$05`@<V5R=F5R+B`J+PH@("`@
M("`@("1T:&ES+3Y?9',@/2!`;&1A<%]C;VYN96-T*"1T:&ES+3Y?<&%R86US
M6R=H;W-T<W!E8R==*3L*("`@("`@("!I9B`H(21T:&ES+3Y?9',I('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B1F%I;&5D('1O
M(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(BDI.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"%L9&%P7W-E=%]O<'1I;VXH)'1H:7,M/E]D<RP@3$1!4%]/4%1?
M4%)/5$]#3TQ?5D524TE/3BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG=F5R<VEO;B==*2D@>PH@("`@("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92@*("`@("`@("`@("`@("`@('-P<FEN=&8H)U-E
M="!,1$%0('!R;W1O8V]L('9E<G-I;VX@=&\@)60@9F%I;&5D.B!;)61=("5S
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W9E
M<G-I;VXG72P*("`@("`@("`@("`@("`@("`@("`@("`@;&1A<%]E<G)N;R@D
M8V]N;BDL"B`@("`@("`@("`@("`@("`@("`@("`@(&QD87!?97)R;W(H)&-O
M;FXI+`H@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%
M7U\I*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A
M<F%M<ULG8FEN9&1N)UTI*2!["B`@("`@("`@("`@("1B:6YD(#T@0&QD87!?
M8FEN9"@D=&AI<RT^7V1S+"`D=&AI<RT^7W!A<F%M<ULG8FEN9&1N)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M<&%S<W=O<F0G72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&)I
M;F0@/2!`;&1A<%]B:6YD*"1T:&ES+3Y?9',I.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"$D8FEN9"D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB*2D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E8W5R<VEV96QY(&1E;&5T97,@)&1N+B`D=&AI<RT^7V1S
M($U54U0@86QR96%D>2!B92!C;VYN96-T960N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5')U92!I9B!D96QE=&4@=V%S('-U8V-E<W-F=6PL(%!%
M05)?17)R;W(@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<F5C
M=7)S:79E7V1E;&5T92@D9&XI"B`@("!["B`@("`@("`@)'-E87)C:"`]($!L
M9&%P7VQI<W0H)'1H:7,M/E]D<RP@)&1N+"`G;V)J96-T8VQA<W,]*B<L(&%R
M<F%Y*"<G*2D["B`@("`@("`@:68@*"$D<V5A<F-H*2!["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O=6QD(&YO="!R96%C:"!T
M:&4@3$1!4"!S97)V97(N(BDI.PH@("`@("`@('T*"B`@("`@("`@)&-H:6QD
M<F5N(#T@0&QD87!?9V5T7V5N=')I97,H)'1H:7,M/E]D<RP@)'-E87)C:"D[
M"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&-H:6QD<F5N6R=C;W5N="==
M.R`D:2LK*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7W)E8W5R
M<VEV95]D96QE=&4H)&-H:6QD<F5N6R1I75LG9&XG72D["B`@("`@("`@("`@
M(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H<W!R:6YT9BA?*")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M9&5L971E(&=R;W5P("5S(BDL("1T:&ES+3YG971.86UE*"1C:&EL9')E;ELD
M:5U;)V1N)UTI*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("1R97-U;'0@/2!`;&1A<%]D96QE=&4H)'1H:7,M/E]D<RP@)&1N*3L*("`@
M("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H<W!R:6YT9BA?*")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M9&5L971E(&=R;W5P("5S(BDL("1D;BDI.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!396%R8VAE
M<R!E>&ES=&EN9R!G<F]U<',@9F]R('1H92!H:6=H97-T(&=I9&YU;6)E<BP@
M86YD(')E='5R;G,*("`@("`J(&]N92!H:6=H97(N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]N97AT1VED*"D*("`@('L*("`@("`@("`O*B!#;VYN96-T('1O
M('1H92!,1$%0('-E<G9E<BX@*B\*("`@("`@("`D<W5C8V5S<R`]("1T:&ES
M+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1S=6-C97-S+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"1S=6-C97-S+3YG971-97-S86=E*"DI.PH@("`@("`@('T*"B`@("`@
M("`@)'-E87)C:"`]($!L9&%P7W-E87)C:"@D=&AI<RT^7V1S+"`D9&XL("1T
M:&ES+3Y?9FEL=&5R*3L*("`@("`@("!I9B`H(21S96%R8V@I('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T(')E
M86-H('1H92!,1$%0('-E<G9E<BXB*2D["B`@("`@("`@?0H*("`@("`@("!`
M;&1A<%]S;W)T*"1T:&ES+3Y?9',L("1S96%R8V@L("=G:61N=6UB97(G*3L*
M("`@("`@("`D<F5S=6QT(#T@0&QD87!?9V5T7V5N=')I97,H)'1H:7,M/E]D
M<RP@)'-E87)C:"D["B`@("`@("`@0&QD87!?8VQO<V4H)'1H:7,M/E]D<RD[
M"@H@("`@("`@(&EF("@A:7-?87)R87DH)')E<W5L="D@?'P@*&-O=6YT*"1R
M97-U;'0I(#P](#$I*2!["B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1R97-U;'1;)')E<W5L=%LG8V]U;G0G72`M
M(#%=6R=G:61N=6UB97(G75LP72`K(#$["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@82!N97<@9W)O=7`@;V)J96-T+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&YA;64@("`@5&AE(&=R;W5P)W,@;F%M92X*("`@("`J
M($!P87)A;2!S=')I;F<@)'!A<F5N="`@5&AE(&=R;W5P)W,@<&%R96YT)W,@
M;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N($Q$05!?1W)O=7`@($$@;F5W
M(&=R;W5P(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@)FYE=T=R;W5P
M*"1N86UE+"`D<&%R96YT(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H96UP
M='DH)&YA;64I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(BDI.PH@("`@
M("`@('T*"B`@("`@("`@9VQO8F%L("1C;VYF.PH@("`@("`@(&EF("@A96UP
M='DH)&-O;F9;)VAO;VMS)UU;)V=R;W5P;&1A<"==*2D@>PH@("`@("`@("`@
M("!`:6YC;'5D92!(3U)$15]"05-%("X@)R]C;VYF:6<O:&]O:W,N<&AP)SL*
M("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G7VAO<F1E7VAO;VM?
M9W)O=7!L9&%P)RDI('L*("`@("`@("`@("`@("`@("1E;G1R>2`](&-A;&Q?
M=7-E<E]F=6YC*"=?:&]R9&5?:&]O:U]G<F]U<&QD87`G+"`D;F%M92P@)'!A
M<F5N="D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`O+R!4<GD@=&AI<R!S:6UP;&4@9&5F875L="!A;F0@:&]P92!I="!W
M;W)K<RX*("`@("`@("`@("`@)&5N=')Y6R1T:&ES+3Y?<&%R86US6R=G:60G
M75T@/2`D;F%M93L*("`@("`@("`@("`@)&5N=')Y6R=O8FIE8W1C;&%S<R==
M(#T@)'1H:7,M/E]P87)A;7-;)VYE=V=R;W5P7V]B:F5C=&-L87-S)UT["B`@
M("`@("`@("`@("1E;G1R>5LG9VED;G5M8F5R)UT@/2`D=&AI<RT^7VYE>'1'
M:60H*3L*("`@("`@("!]"@H@("`@("`@("1G<F]U<"`]("9N97<@3$1!4%]'
M<F]U<"@D;F%M92P@)'!A<F5N="D["B`@("`@("`@)&=R;W5P+3Y?9G)O;4%T
M=')I8G5T97,H)&5N=')Y*3L*("`@("`@("`D9W)O=7`M/G-E=$=R;W5P3V(H
M)'1H:7,I.PH@("`@("`@(')E='5R;B`D9W)O=7`["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FX@86X@3$1!4%]'<F]U<"!O8FIE8W0@8V]R<F5S<&]N
M9&EN9R!T;R!T:&4@;F%M960@9W)O=7`L('=I=&@@=&AE"B`@("`@*B!U<V5R
M<R!A;F0@;W1H97(@9&%T82!R971R:65V960@87!P<F]P<FEA=&5L>2X*("`@
M("`J"B`@("`@*B!.3U1%.B!G971'<F]U<$)Y260H*2!S:&]U;&0@8F4@=7-E
M9"!W:&5R92!P;W-S:6)L92!I;G-T96%D(&]F"B`@("`@*B!G971'<F]U<"@I
M(&)E8V%U<V4@9W)O=7`@;F%M97,@87)E('!O=&5N=&EA;&QY(&YO;BUU;FEQ
M=64@=F%L=65S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@
M(%1H92!N86UE(&]F('1H92!G<F]U<"!T;R!R971R:65V92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N($Q$05!?1W)O=7`@(%1H92!R97%U97-T960@9W)O=7`N
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971'<F]U<"@D;F%M92D*("`@('L*
M("`@("`@("`D9&X@/2`D=&AI<RT^9V5T1W)O=7!)9"@D;F%M92D["B`@("`@
M("`@:68@*&ES7V$H)&1N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*"1D;BT^9V5T365S<V%G92@I*3L*
M("`@("`@("!]"B`@("`@("`@)&=R;W5P(#T@)B1T:&ES+3YG971'<F]U<$)Y
M260H)&1N*3L*("`@("`@("!R971U<FX@)&=R;W5P.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N(&%N($Q$05!?3V)J96-T(&]B:F5C="!C;W)R97-P
M;VYD:6YG('1O('1H92!G:79E;B!D;BP@=VET:"!T:&4*("`@("`J('5S97)S
M(&%N9"!O=&AE<B!D871A(')E=')I979E9"!A<'!R;W!R:6%T96QY+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&1N("!4:&4@9&X@;V8@=&AE(&=R
M;W5P('1O(')E=')I979E+@H@("`@("H*("`@("`J($!R971U<FX@3$1!4%]/
M8FIE8W0@(%1H92!R97%U97-T960@9W)O=7`N"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9G971'<F]U<$)Y260H)&1N*0H@("`@>PH@("`@("`@('-T871I8R`D
M8V%C:&4["@H@("`@("`@(&EF("@A:7-?87)R87DH)&-A8VAE*2D@>PH@("`@
M("`@("`@("`D8V%C:&4@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"%I<W-E="@D8V%C:&5;)&1N72DI('L*("`@("`@("`@("`@+RH@0V]N
M;F5C="!T;R!T:&4@3$1!4"!S97)V97(N("HO"B`@("`@("`@("`@("1S=6-C
M97-S(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@("`@(&EF("AI<U]A
M*"1S=6-C97-S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D<W5C8V5S<RT^9V5T365S<V%G92@I
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'-E87)C:"`]($!L9&%P
M7W-E87)C:"@D=&AI<RT^7V1S+"`D9&XL("1T:&ES+3Y?9FEL=&5R*3L*("`@
M("`@("`@("`@:68@*"$D<V5A<F-H*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$
M05`@<V5R=F5R+B(I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)')E
M<W5L="`]($!L9&%P7V=E=%]E;G1R:65S*"1T:&ES+3Y?9',L("1S96%R8V@I
M.PH@("`@("`@("`@("!`;&1A<%]C;&]S92@D=&AI<RT^7V1S*3L*("`@("`@
M("`@("`@:68@*"%I<U]A<G)A>2@D<F5S=6QT*2!\?"`H8V]U;G0H)')E<W5L
M="D@/#T@,2DI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(D5M<'1Y(')E<W5L="XB*2D["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1A='1R:6)U=&5S(#T@87)R87DH*3L*("`@("`@("`@("`@
M9F]R("@D:2`](#`[("1I(#P@)')E<W5L=%LP75LG8V]U;G0G73L@)&DK*RD@
M>PH@("`@("`@("`@("`@("`@:68@*"1R97-U;'1;,%U;)')E<W5L=%LP75LD
M:5U=6R=C;W5N="==(#X@,2D@>PH@("`@("`@("`@("`@("`@("`@("1A='1R
M:6)U=&5S6R1R97-U;'1;,%U;)&E=72`](&%R<F%Y*"D["B`@("`@("`@("`@
M("`@("`@("`@9F]R("@D:B`](#`[("1J(#P@)')E<W5L=%LP75LD<F5S=6QT
M6S!=6R1I75U;)V-O=6YT)UT[("1J*RLI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&%T=')I8G5T97-;)')E<W5L=%LP75LD:5U=6UT@/2`D<F5S=6QT
M6S!=6R1R97-U;'1;,%U;)&E=75LD:ET["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D871T<FEB=71E<ULD<F5S=6QT6S!=6R1I75T@/2`D<F5S=6QT6S!=6R1R
M97-U;'1;,%U;)&E=75LP73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D871T<FEB=71E<ULG9&XG72`]("1R97-U;'1;
M,%U;)V1N)UT["@H@("`@("`@("`@("`D9W)O=7`@/2!N97<@3$1!4%]'<F]U
M<"@D=&AI<RT^9V5T1W)O=7!.86UE*"1D;BDI.PH@("`@("`@("`@("`D9W)O
M=7`M/E]F<F]M071T<FEB=71E<R@D871T<FEB=71E<RD["B`@("`@("`@("`@
M("1G<F]U<"T^<V5T1W)O=7!/8B@D=&AI<RD["B`@("`@("`@("`@("1C86-H
M95LD9&Y=(#T@)&=R;W5P.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&-A
M8VAE6R1D;ET["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!G;&]B86QL
M>2!U;FEQ=64@240@9F]R(&$@9W)O=7`N("!4:&ES(')E86QL>2!J=7-T(')E
M='5R;G,@=&AE(&1N"B`@("`@*B!F;W(@=&AE(&=R;W5P+"!B=70@:7,@:6YC
M;'5D960@9F]R(&-O;7!A=&EB:6QI='D@=VET:"!T:&4@1W)O=7`@8VQA<W,N
M"B`@("`@*@H@("`@("H@0'!A<F%M($Q$05!?3V)J96-T("1G<F]U<"`@5&AE
M(&=R;W5P+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!A($=5240@
M<F5F97)R:6YG('1O("1G<F]U<"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M1U5)1"@D9W)O=7`I"B`@("!["B`@("`@("`@<F5T=7)N("1G<F]U<"T^9V5T
M*"=D;B<I.PH@("`@?0H*("`@("\J*@H@("`@("H@061D(&$@9W)O=7`@=&\@
M=&AE(&=R;W5P<R!S>7-T96TN("!4:&4@9W)O=7`@;75S="!F:7)S="!B92!C
M<F5A=&5D('=I=&@*("`@("`J($=R;W5P7VQD87`Z.FYE=T=R;W5P*"DL(&%N
M9"!H879E(&%N>2!I;FET:6%L('5S97)S(&%D9&5D('1O(&ET+"!B969O<F4*
M("`@("`J('1H:7,@9G5N8W1I;VX@:7,@8V%L;&5D+@H@("`@("H*("`@("`J
M($!P87)A;2!,1$%07T=R;W5P("1G<F]U<"`@5&AE(&YE=R!G<F]U<"!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!I9B!S=6-C
M97-S9G5L+"!014%27T5R<F]R(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@861D1W)O=7`H)&=R;W5P*0H@("`@>PH@("`@("`@(&EF("@A:7-?
M82@D9W)O=7`L("=$871A5')E94]B:F5C=%]'<F]U<"<I*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"='<F]U<',@;75S="!B92!$
M871A5')E94]B:F5C=%]'<F]U<"!O8FIE8W1S(&]R(&5X=&5N9"!T:&%T(&-L
M87-S+B<I.PH@("`@("`@('T*"B`@("`@("`@+RH@0V]N;F5C="!T;R!T:&4@
M3$1!4"!S97)V97(N("HO"B`@("`@("`@)'-U8V-E<W,@/2`D=&AI<RT^7V-O
M;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D<W5C8V5S<RP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D
M<W5C8V5S<RT^9V5T365S<V%G92@I*3L*("`@("`@("!]"@H@("`@("`@("1D
M;B`]("1G<F]U<"T^9V5T*"=D;B<I.PH*("`@("`@("`D96YT<GD@/2`D9W)O
M=7`M/E]T;T%T=')I8G5T97,H*3L*("`@("`@("`D<W5C8V5S<R`]($!L9&%P
M7V%D9"@D=&AI<RT^7V1S+"`D9&XL("1E;G1R>2D["@H@("`@("`@(&EF("@A
M)'-U8V-E<W,I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H<W!R:6YT9BA?*")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P
M("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B*2P@)&=R;W5P
M+3YG971.86UE*"DI("X@0&QD87!?97)R;W(H)'1H:7,M/E]D<RDI.PH@("`@
M("`@('T*"B`@("`@("`@0&QD87!?8VQO<V4H)'1H:7,M/E]D<RD["@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1O<F4@
M=7!D871E9"!D871A("T@=7-E<G,L(&5T8RX@+2!O9B!A(&=R;W5P('1O('1H
M92!B86-K96YD('-Y<W1E;2X*("`@("`J"B`@("`@*B!`<&%R86T@3$1!4%]/
M8FIE8W0@)&=R;W5P("!4:&4@9W)O=7`@=&\@=7!D871E"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S+"!014%27T5R<F]R
M(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@=7!D871E1W)O=7`H
M)&=R;W5P*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D9W)O=7`L("=$871A
M5')E94]B:F5C=%]'<F]U<"<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"='<F]U<',@;75S="!B92!$871A5')E94]B:F5C=%]'
M<F]U<"!O8FIE8W1S(&]R(&5X=&5N9"!T:&%T(&-L87-S+B<I.PH@("`@("`@
M('T*"B`@("`@("`@)&5N=')Y(#T@)&=R;W5P+3Y?=&]!='1R:6)U=&5S*"D[
M"@H@("`@("`@("\J($-O;FYE8W0@=&\@=&AE($Q$05`@<V5R=F5R+B`J+PH@
M("`@("`@("1S=6-C97-S(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@
M:68@*&ES7V$H)'-U8V-E<W,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)'-U8V-E<W,M/F=E=$UE<W-A
M9V4H*2D["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@0&QD87!?;6]D
M:69Y*"1T:&ES+3Y?9',L("1G<F]U<"T^9V5T260H*2P@)&5N=')Y*3L*("`@
M("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H<W!R:6YT9BA?*")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M=7!D871E(&=R;W5P("5S(BDL("1G<F]U<"T^9V5T3F%M92@I*2D["B`@("`@
M("`@?0H*("`@("`@("!`;&1A<%]C;&]S92@D=&AI<RT^7V1S*3L*"B`@("`@
M("`@+RH@3&]G('1H92!U<&1A=&4@;V8@=&AE(&=R;W5P('5S97)S(&]N('1H
M92!H:7-T;W)Y(&QO9RX@*B\*("`@("`@("`D:&ES=&]R>2`]("9(;W)D95](
M:7-T;W)Y.CIS:6YG;&5T;VXH*3L*("`@("`@("`D9W5I9"`]("1T:&ES+3YG
M971'54E$*"1G<F]U<"D["B`@("`@("`@9F]R96%C:"`H)&=R;W5P+3YG971!
M=61I=$QO9R@I(&%S("1U<V5R260@/3X@)&%C=&EO;BD@>PH@("`@("`@("`@
M("`D:&ES=&]R>2T^;&]G*"1G=6ED+"!A<G)A>2@G86-T:6]N)R`]/B`D86-T
M:6]N+"`G=7-E<B<@/3X@)'5S97))9"DL('1R=64I.PH@("`@("`@('T*("`@
M("`@("`D9W)O=7`M/F-L96%R075D:71,;V<H*3L*"B`@("`@("`@+RH@3&]G
M('1H92!G<F]U<"!M;V1I9FEC871I;VXN("HO"B`@("`@("`@)&AI<W1O<GDM
M/FQO9R@D9W5I9"P@87)R87DH)V%C=&EO;B<@/3X@)VUO9&EF>2<I+"!T<G5E
M*3L*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*("`@
M("`J($-H86YG92!T:&4@;F%M92!O9B!A(&=R;W5P+@H@("`@("H*("`@("`J
M($!P87)A;2!$871A5')E94]B:F5C=%]'<F]U<"`D9W)O=7`@(%1H92!G<F]U
M<"!T;R!R96YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=.86UE("`@
M("`@("`@("`@("!4:&4@9W)O=7`G<R!N97<@;F%M92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5N86UE1W)O=7`H)&=R;W5P+"`D;F5W3F%M92D*("`@('L*
M("`@("`@("!I9B`H(6ES7V$H)&=R;W5P+"`G1&%T851R965/8FIE8W1?1W)O
M=7`G*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G
M1W)O=7!S(&UU<W0@8F4@1&%T851R965/8FIE8W1?1W)O=7`@;V)J96-T<R!O
M<B!E>'1E;F0@=&AA="!C;&%S<RXG*3L*("`@("`@("!]"@H@("`@("`@("1G
M<F]U<"T^<V5T*"1T:&ES+3Y?<&%R86US6R=G:60G72P@)&YE=TYA;64I.PH@
M("`@("`@("1E;G1R>2`]("1G<F]U<"T^7W1O071T<FEB=71E<R@I.PH*("`@
M("`@("`O*B!#;VYN96-T('1O('1H92!,1$%0('-E<G9E<BX@*B\*("`@("`@
M("`D<W5C8V5S<R`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI
M<U]A*"1S=6-C97-S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*"1S=6-C97-S+3YG971-97-S86=E*"DI
M.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]($!L9&%P7VUO9&EF>2@D
M=&AI<RT^7V1S+"`D9W)O=7`M/F=E=$ED*"DL("1E;G1R>2D["B`@("`@("`@
M:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*'-P<FEN=&8H7R@B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T
M92!G<F]U<"`E<R(I+"`D9W)O=7`M/F=E=$YA;64H*2DI.PH@("`@("`@('T*
M"B`@("`@("`@0&QD87!?8VQO<V4H)'1H:7,M/E]D<RD["@H@("`@("`@("\J
M($AI<W1O<GD@3&]G('1H92!N86UE(&-H86YG92!O9B!T:&4@9W)O=7`N("HO
M"B`@("`@("`@)&AI<W1O<GD@/2`F2&]R9&5?2&ES=&]R>3HZ<VEN9VQE=&]N
M*"D["B`@("`@("`@)&AI<W1O<GDM/FQO9R@D9W)O=7`M/F=E="@G9&XG*2P@
M87)R87DH)V%C=&EO;B<@/3X@)W)E;F%M92<I+"!T<G5E*3L*("`@("`@("!R
M971U<FX@)')E<W5L=#L*"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F4@
M82!G<F]U<"!F<F]M('1H92!G<F]U<',@<WES=&5M('!E<FUA;F5N=&QY+@H@
M("`@("H*("`@("`J($!P87)A;2!,1$%07T=R;W5P("1G<F]U<"`@5&AE(&=R
M;W5P('1O(')E;6]V92X*("`@("`J($!P87)A;2!B;V]L96%N("1F;W)C92`@
M("`@4F5C=7)S:79E;'D@9&5L971E(&-H:6QD<F5N(&=R;W5P<R!I9B!T<G5E
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S
M<RP@4$5!4E]%<G)O<B!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E;6]V94=R;W5P*"1G<F]U<"P@)&9O<F-E(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@:68@*"%I<U]A*"1G<F]U<"P@)T1A=&%4<F5E3V)J96-T7T=R;W5P
M)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T=R
M;W5P<R!M=7-T(&)E($1A=&%4<F5E3V)J96-T7T=R;W5P(&]B:F5C=',@;W(@
M97AT96YD('1H870@8VQA<W,N)RD["B`@("`@("`@?0H*("`@("`@("`D9&X@
M/2`D9W)O=7`M/F=E=$ED*"D["@H@("`@("`@("\J($-O;FYE8W0@=&\@=&AE
M($Q$05`@<V5R=F5R+B`J+PH@("`@("`@("1S=6-C97-S(#T@)'1H:7,M/E]C
M;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)'-U8V-E<W,L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)'-U8V-E<W,M/F=E=$UE<W-A9V4H*2D["B`@("`@("`@?0H*("`@("`@("!I
M9B`H)&9O<F-E*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)E8W5R
M<VEV95]D96QE=&4H)&1N*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D<F5S=6QT(#T@0&QD87!?9&5L971E*"1T:&ES+3Y?9',L("1D;BD["B`@
M("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")'<F]U<%]L9&%P.B!5
M;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(BDL("1D;BDI.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F4@
M=&AE(&YA;64@;V8@82!G<F]U<"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1D;B`@5&AE(&1N(&]F('1H92!G<F]U<"!T;R!R971R:65V92!T:&4@
M;F%M92!F;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!G
M<F]U<"=S(&YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$=R;W5P3F%M
M92@D9&XI"B`@("!["B`@("`@("`@)')E<W5L="`](&QD87!?97AP;&]D95]D
M;B@D9&XL(#$I.PH@("`@("`@(')E='5R;B`D<F5S=6QT6S!=.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1&%T851R965/8FIE8W0@9G5L;"!N86UE<R!I;F-L
M=61E(')E9F5R96YC97,@=&\@<&%R96YT<RP@8G5T($Q$05`@9&]E<PH@("`@
M("H@;F]T(&AA=F4@=&AI<R!C;VYC97!T+B`@5&AI<R!F=6YC=&EO;B!S:6UP
M;'D@<F5T=7)N<R!T:&4@)&=R;W5P"B`@("`@*B!P87)A;65T97(@86YD(&ES
M(&EN8VQU9&5D(&9O<B!C;VUP871I8FEL:71Y('=I=&@@=&AE($=R;W5P(&-L
M87-S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&=R;W5P("!'<F]U
M<"!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`D9W)O=7`N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$=R;W5P4VAO<G1.86UE*"1G<F]U
M<"D*("`@('L*("`@("`@("!R971U<FX@)&=R;W5P.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T<FEE=F4@=&AE($E$(&]F('1H92!G:79E;B!G<F]U<"X*
M("`@("`J"B`@("`@*B!.3U1%.B!)9B!G:79E;B!A(&=R;W5P(&YA;64L('1H
M:7,@9G5N8W1I;VX@8V%N(&)E('5N<F5L:6%B;&4@:68@;6]R90H@("`@("H@
M=&AA;B!O;F4@9W)O=7`@97AI<W1S('=I=&@@=&AE('-A;64@;F%M92X*("`@
M("`J"B`@("`@*B!`<&%R86T@;6EX960@)&=R;W5P("`@3$1!4%]'<F]U<"!O
M8FIE8W0L(&]R(&$@9W)O=7`@;F%M92`H<W1R:6YG*0H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@9W)O=7`G<R!)1"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T1W)O=7!)9"@D9W)O=7`I"B`@("!["B`@("`@("`@:68@
M*&ES7V$H)&=R;W5P+"`G3$1!4%]'<F]U<"<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D9W)O=7`M/F=E="@G9&XG*3L*("`@("`@("!]"@H@("`@("`@('-T
M871I8R`D8V%C:&4["@H@("`@("`@(&EF("@A:7-?87)R87DH)&-A8VAE*2D@
M>PH@("`@("`@("`@("`D8V%C:&4@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"%I<W-E="@D8V%C:&5;)&=R;W5P72DI('L*("`@("`@("`@
M("`@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@("`@("1S96%R8V@@/2!`
M;&1A<%]S96%R8V@H)'1H:7,M/E]D<RP@)'1H:7,M/E]P87)A;7-;)V)A<V5D
M;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=G:60G72`N("<])R`N("1G<F]U<"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@D=&AI<RT^7W!A<F%M<ULG
M9VED)UTI*3L*("`@("`@("`@("`@:68@*"$D<V5A<F-H*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@
M<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(I*3L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@)')E<W5L="`]($!L9&%P7V=E=%]E;G1R:65S*"1T:&ES+3Y?
M9',L("1S96%R8V@I.PH@("`@("`@("`@("!`;&1A<%]C;&]S92@D=&AI<RT^
M7V1S*3L*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D<F5S=6QT*2!\?"`H
M8V]U;G0H)')E<W5L="D@/#T@,2DI('L*("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(D5M<'1Y(')E<W5L="XB*2D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)&-A8VAE6R1G<F]U<%T@/2`D<F5S=6QT
M6S!=6R=D;B==.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C86-H95LD
M9W)O=7!=.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VL@:68@82!G<F]U
M<"!E>&ES=',@:6X@=&AE('-Y<W1E;2X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1G<F]U<"`@5&AE(&=R;W5P(&YA;64@=&\@8VAE8VL@9F]R+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@9W)O
M=7`@97AI<W1S+"!&86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&5X:7-T<R@D9W)O=7`I"B`@("!["B`@("`@("`@<W1A=&EC("1C86-H
M93L*"B`@("`@("`@:68@*"%I<U]A<G)A>2@D8V%C:&4I*2!["B`@("`@("`@
M("`@("1C86-H92`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M(6ES<V5T*"1C86-H95LD9W)O=7!=*2D@>PH@("`@("`@("`@("`O*B!#;VYN
M96-T('1O('1H92!,1$%0('-E<G9E<BX@*B\*("`@("`@("`@("`@)'-U8V-E
M<W,@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("`@("`@:68@*&ES7V$H
M)'-U8V-E<W,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*"1S=6-C97-S+3YG971-97-S86=E*"DI
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<V5A<F-H(#T@0&QD87!?
M<V5A<F-H*"1T:&ES+3Y?9',L("1D;BP@)R@F)R`N("1T:&ES+3Y?9FEL=&5R
M("X@)R@G("X@)'1H:7,M/E]P87)A;7-;)V=I9"==("X@)STG("X@)&=R;W5P
M("X@)RDI)RD["B`@("`@("`@("`@(&EF("@A)'-E87)C:"D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T
M(')E86-H('1H92!,1$%0('-E<G9E<BXB*2D["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1R97-U;'0@/2!`;&1A<%]G971?96YT<FEE<R@D=&AI<RT^
M7V1S+"`D<V5A<F-H*3L*("`@("`@("`@("`@0&QD87!?8VQO<V4H)'1H:7,M
M/E]D<RD["B`@("`@("`@("`@("1C86-H95LD9W)O=7!=(#T@*&ES7V%R<F%Y
M*"1R97-U;'0I("8F("AC;W5N="@D<F5S=6QT(#X@,2DI*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D8V%C:&5;)&=R;W5P73L*("`@('T*"B`@("`O
M*BH*("`@("`J($=E="!A(&QI<W0@;V8@=&AE('!A<F5N=',@;V8@82!C:&EL
M9"!G<F]U<"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D;B`@5&AE
M(&1N(&]F('1H92!C:&EL9"!G<F]U<"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!4:&4@9&X@86YD(&YA;64@;V8@=&AE('!A<F5N="!G<F]U<"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1W)O=7!087)E;G1S*"1D;BD*("`@
M('L*("`@("`@("`D<&%R96YT(#T@)'1H:7,M/F=E=$=R;W5P4&%R96YT*"1D
M;BD["B`@("`@("`@<F5T=7)N(&%R<F%Y*"1P87)E;G0@/3X@)'1H:7,M/F=E
M=$=R;W5P3F%M92@D<&%R96YT*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M970@=&AE('!A<F5N="!O9B!T:&4@9VEV96X@9W)O=7`N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9&X@(%1H92!D;B!O9B!T:&4@8VAI;&0@9W)O
M=7`N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D;B!O9B!T
M:&4@<&%R96YT(&=R;W5P+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971'<F]U
M<%!A<F5N="@D9&XI"B`@("!["B`@("`@("`@)')E<W5L="`](&QD87!?97AP
M;&]D95]D;B@D9&XL(#`I.PH@("`@("`@('5N<V5T*"1R97-U;'1;)V-O=6YT
M)UTI.PH@("`@("`@('5N<V5T*"1R97-U;'1;,%TI.PH@("`@("`@("1P87)E
M;G1?9&X@/2!I;7!L;V1E*"<L)RP@)')E<W5L="D["@H@("`@("`@(&EF("@D
M<&%R96YT7V1N(#T]("1'3$]"04Q36R=C;VYF)UU;)V=R;W5P)UU;)W!A<F%M
M<R==6R=B87-E9&XG72D@>PH@("`@("`@("`@("!R971U<FX@1$%40512145?
M4D]/5#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'!A
M<F5N=%]D;CL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@
M82!L:7-T(&]F('!A<F5N=',@86QL('1H92!W87D@=7`@=&\@=&AE(')O;W0@
M;V)J96-T(&9O<B!T:&4@9VEV96X*("`@("`J(&=R;W5P+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&1N("!4:&4@9&X@;V8@=&AE(&=R;W5P+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@($$@9FQA="!L:7-T(&]F(&%L
M;"!O9B!T:&4@<&%R96YT<R!O9B!T:&4@9VEV96X@9W)O=7`L"B`@("`@*B`@
M("`@("`@("`@("`@("!H87-H960@:6X@)&1N(#T^("1N86UE(&9O<FUA="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1W)O=7!087)E;G1,:7-T*"1D;BD*
M("`@('L*("`@("`@("`D<F5S=6QT(#T@;&1A<%]E>'!L;V1E7V1N*"1D;BP@
M,"D["B`@("`@("`@)&YU;2`]("1R97-U;'1;)V-O=6YT)UT["@H@("`@("`@
M('5N<V5T*"1R97-U;'1;)V-O=6YT)UTI.PH@("`@("`@('5N<V5T*"1R97-U
M;'1;,%TI.PH*("`@("`@("`D8V]U;G0@/2`P.PH@("`@("`@("1P87)E;G1S
M(#T@87)R87DH*3L*("`@("`@("`D<&%R96YT7V1N(#T@:6UP;&]D92@G+"<L
M("1R97-U;'0I.PH@("`@("`@('=H:6QE("@D<&%R96YT7V1N("$]("1T:&ES
M+3Y?<&%R86US6R=B87-E9&XG72`F)B`D8V]U;G0K*R`A/2`D;G5M*2!["B`@
M("`@("`@("`@("1P87)E;G1S6R1P87)E;G1?9&Y=(#T@)'1H:7,M/F=E=$=R
M;W5P3F%M92@D<&%R96YT7V1N*3L*("`@("`@("`@("`@=6YS970H)')E<W5L
M=%LD8V]U;G1=*3L*("`@("`@("`@("`@)'!A<F5N=%]D;B`](&EM<&QO9&4H
M)RPG+"`D<F5S=6QT*3L*("`@("`@("!]"B`@("`@("`@)'!A<F5N='-;1$%4
M0512145?4D]/5%T@/2!$051!5%)%15]23T]4.PH*("`@("`@("!R971U<FX@
M)'!A<F5N=',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F
M(&5V97)Y(&=R;W5P+"!I;B!T:&4@9F]R;6%T(&1N(#T^(&=R;W5P;F%M92X*
M("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<F5F<F5S:"`@268@=')U
M92P@=&AE(&-A8VAE9"!V86QU92!I<R!I9VYO<F5D(&%N9"!T:&4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("!G<F]U<"!L:7-T(&ES(')E9G)E
M<VAE9"!F<F]M('1H92!G<F]U<"!B86-K96YD+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@(&1N(#T^(&=R;W5P;F%M92!H87-H+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!L:7-T1W)O=7!S*"1R969R97-H(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@<W1A=&EC("1G<F]U<',["@H@("`@("`@(&EF("@D<F5F<F5S
M:"!\?"!I<U]N=6QL*"1G<F]U<',I*2!["B`@("`@("`@("`@("\J($-O;FYE
M8W0@=&\@=&AE($Q$05`@<V5R=F5R+B`J+PH@("`@("`@("`@("`D<W5C8V5S
M<R`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@("`@("!I9B`H:7-?82@D
M<W5C8V5S<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)'-U8V-E<W,M/F=E=$UE<W-A9V4H*2D[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1S96%R8V@@/2!`;&1A<%]S
M96%R8V@H)'1H:7,M/E]D<RP@)'1H:7,M/E]P87)A;7-;)V)A<V5D;B==+"`D
M=&AI<RT^7V9I;'1E<BP@87)R87DH)'1H:7,M/E]P87)A;7-;)V=I9"==*2D[
M"B`@("`@("`@("`@(&EF("@A)'-E87)C:"D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T(')E86-H('1H
M92!,1$%0('-E<G9E<BXB*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M($!L9&%P7W-O<G0H)'1H:7,M/E]D<RP@)'-E87)C:"P@)'1H:7,M/E]P87)A
M;7-;)V=I9"==*3L*"B`@("`@("`@("`@("1R97-U;'0@/2!`;&1A<%]G971?
M96YT<FEE<R@D=&AI<RT^7V1S+"`D<V5A<F-H*3L*("`@("`@("`@("`@0&QD
M87!?8VQO<V4H)'1H:7,M/E]D<RD["B`@("`@("`@("`@(&EF("@A:7-?87)R
M87DH)')E<W5L="D@?'P@*&-O=6YT*"1R97-U;'0I(#P](#$I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@87)R87DH*3L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@)&=R;W5P<R`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\("1R97-U;'1;)V-O=6YT)UT[("1I*RLI('L*("`@("`@
M("`@("`@("`@("1G<F]U<'-;)')E<W5L=%LD:5U;)V1N)UU=(#T@)')E<W5L
M=%LD:5U;)'1H:7,M/E]P87)A;7-;)V=I9"==75LP73L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1G<F]U<',["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F(&5V97)Y('5S97(@=&AA="!I
M<R!P87)T(&]F('1H92!S<&5C:69I960@9W)O=7`@86YD(&%N>0H@("`@("H@
M;V8@:71S('-U8F=R;W5P<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1D;B`@5&AE(&1N(&]F('1H92!P87)E;G0@9W)O=7`N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@5&AE(&-O;7!L971E('5S97(@;&ES="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@;&ES=$%L;%5S97)S*"1D;BD*("`@('L*("`@
M("`@("!S=&%T:6,@)&-A8VAE.PH*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1C
M86-H92DI('L*("`@("`@("`@("`@)&-A8VAE(#T@87)R87DH*3L*("`@("`@
M("!]"@H@("`@("`@(&EF("@A:7-S970H)&-A8VAE6R1D;ETI*2!["B`@("`@
M("`@("`@("1S=6-C97-S(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@
M("`@(&EF("AI<U]A*"1S=6-C97-S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D<W5C8V5S<RT^
M9V5T365S<V%G92@I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'-E
M87)C:"`]($!L9&%P7W-E87)C:"@D=&AI<RT^7V1S+"`D=&AI<RT^9V5T1W)O
M=7!087)E;G0H)&1N*2P@)'1H:7,M/E]F:6QE<BD["B`@("`@("`@("`@(&EF
M("@A)'-E87)C:"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H7R@B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB
M*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1R97-U;'0@/2!`;&1A
M<%]G971?96YT<FEE<R@D=&AI<RT^7V1S+"`D<V5A<F-H*3L*("`@("`@("`@
M("`@0&QD87!?8VQO<V4H)'1H:7,M/E]D<RD["B`@("`@("`@("`@(&EF("@A
M:7-?87)R87DH)')E<W5L="D@?'P@*&-O=6YT*"1R97-U;'0I(#P](#$I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")%
M;7!T>2!R97-U;'0N(BDI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M=7-E<G,@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@
M/"`D<F5S=6QT6R=C;W5N="==.R`D:2LK*2!["B`@("`@("`@("`@("`@("!F
M;W(@*"1J(#T@,#L@)&H@/"`D<F5S=6QT6R1I75LD=&AI<RT^7W!A<F%M<ULG
M;65M8F5R=6ED)UU=6R=C;W5N="==.R`D:BLK*2!["B`@("`@("`@("`@("`@
M("`@("`@)'5S97)S6UT@/2`D<F5S=6QT6R1I75LD=&AI<RT^7W!A<F%M<ULG
M;65M8F5R=6ED)UU=6R1J73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)&-A8VAE6R1D;ET@/2!A<G)A>5]U;FEQ=64H
M)'5S97)S*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D8V%C:&5;)&1N
M73L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A(&QI<W0@;V8@979E<GD@
M9W)O=7`@=&AA="!T:&4@9VEV96X@=7-E<B!I<R!A(&UE;6)E<B!O9BX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=7-E<B`@("`@("`@("!4:&4@
M=7-E<B!T;R!G970@9W)O=7!S(&9O<BX*("`@("`J($!P87)A;2!B;V]L96%N
M("1P87)E;G1'<F]U<',@($%L<V\@<F5T=7)N('1H92!P87)E;G1S(&]F(&%N
M>2!G<F]U<',_"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R
M87D@;V8@86QL(&=R;W5P<R!T:&4@=7-E<B!I<R!I;BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T1W)O=7!-96UB97)S:&EP<R@D=7-E<BP@)'!A<F5N=$=R
M;W5P<R`](&9A;'-E*0H@("`@>PH@("`@("`@('-T871I8R`D8V%C:&4["@H@
M("`@("`@(&EF("AE;7!T>2@D8V%C:&5;)'5S97)=*2D@>PH@("`@("`@("`@
M("`O*B!#;VYN96-T('1O('1H92!,1$%0('-E<G9E<BX@*B\*("`@("`@("`@
M("`@)'-U8V-E<W,@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("`@("`@
M:68@*&ES7V$H)'-U8V-E<W,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1S=6-C97-S+3YG971-
M97-S86=E*"DI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<V5A<F-H
M(#T@0&QD87!?<V5A<F-H*"1T:&ES+3Y?9',L("1T:&ES+3Y?<&%R86US6R=B
M87-E9&XG72P@)R@G("X@)'1H:7,M/E]P87)A;7-;)VUE;6)E<G5I9"==("X@
M)STG("X@)'5S97(@+B`G*2<I.PH@("`@("`@("`@("!I9B`H(21S96%R8V@I
M('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(BDI.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D<F5S=6QT(#T@0&QD87!?9V5T7V5N=')I
M97,H)'1H:7,M/E]D<RP@)'-E87)C:"D["B`@("`@("`@("`@($!L9&%P7V-L
M;W-E*"1T:&ES+3Y?9',I.PH@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1R
M97-U;'0I('Q\("AC;W5N="@D<F5S=6QT*2`\/2`Q*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B16UP='D@<F5S=6QT
M+B(I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&=R;W5P<R`](&%R
M<F%Y*"D["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1R97-U;'1;
M)V-O=6YT)UT[("1I*RLI('L*("`@("`@("`@("`@("`@("1G<F]U<'-;)')E
M<W5L=%LD:5U;)V1N)UU=(#T@)')E<W5L=%LD:5U;)'1H:7,M/E]P87)A;7-;
M)V=I9"==75LP73L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&-A8VAE
M6R1U<V5R72`]("1G<F]U<',["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&-A8VAE6R1U<V5R73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE('1R964@9&5P=&@@;V8@=&AE(&=I=F5N(&=R;W5P+"!R96QA=&EV92!T
M;R!T:&4@8F%S92!D;BX*("`@("`J(#`@:7,@<F5T=7)N960@9F]R(&%N>2!O
M8FIE8W0@9&ER96-T;'D@8F5L;W<@=&AE(&)A<V4@9&XN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9&X@(%1H92!D;B!O9B!T:&4@;V)J96-T+@H@
M("`@("H*("`@("`J($!R971U<FX@:6YT96YG97(@(%1H92!T<F4@9&5P=&@@
M;V8@=&AE(&=R;W5P+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971,979E;"@D
M9&XI"B`@("!["B`@("`@("`@)&)A<V4@/2!`;&1A<%]E>'!L;V1E7V1N*"1T
M:&ES+3Y?<&%R86US6R=B87-E9&XG72P@,"D["B`@("`@("`@)&=R;W5P(#T@
M0&QD87!?97AP;&]D95]D;B@D9&XL(#`I.PH@("`@("`@(')E='5R;B`D9W)O
M=7!;)V-O=6YT)UT@+2`D8F%S95LG8V]U;G0G72`M(#$["B`@("!]"@I]"@HO
M*BH*("H@17AT96YS:6]N(&]F('1H92!$871A5')E94]B:F5C=%]'<F]U<"!C
M;&%S<R!F;W(@<W1O<FEN9R!G<F]U<"!I;F9O<FUA=&EO;@H@*B!I;B!A;B!,
M1$%0(&1I<F5C=&]R>2X*("H*("H@0&%U=&AO<B`@0F5N($-H879E="`\8F5N
M0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXQ"B`J($!P86-K86=E
M($AO<F1E7T=R;W5P"B`J+PIC;&%S<R!,1$%07T=R;W5P(&5X=&5N9',@1&%T
M851R965/8FIE8W1?1W)O=7`@>PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M;W(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("!4:&4@
M;F%M92!O9B!T:&ES(&=R;W5P+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%R
M96YT("!4:&4@9&X@;V8@=&AE('!A<F5N="!O9B!T:&ES(&=R;W5P+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!,1$%07T=R;W5P*"1N86UE+"`D<&%R96YT(#T@
M;G5L;"D*("`@('L*("`@("`@("!P87)E;G0Z.D1A=&%4<F5E3V)J96-T7T=R
M;W5P*"1N86UE*3L*("`@("`@("!I9B`H)'!A<F5N="D@>PH@("`@("`@("`@
M("`D=&AI<RT^9&%T85LG9&XG72`]('-T<G1O;&]W97(H)$=,3T)!3%-;)V-O
M;F8G75LG9W)O=7`G75LG<&%R86US)UU;)V=I9"==*2`N("<])R`N("1N86UE
M("X@)RPG("X@)'!A<F5N=#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D=&AI<RT^9&%T85LG9&XG72`]('-T<G1O;&]W97(H)$=,3T)!3%-;)V-O
M;F8G75LG9W)O=7`G75LG<&%R86US)UU;)V=I9"==*2`N("<])R`N("1N86UE
M("X*("`@("`@("`@("`@("`@("<L)R`N('-T<G1O;&]W97(H)$=,3T)!3%-;
M)V-O;F8G75LG9W)O=7`G75LG<&%R86US)UU;)V)A<V5D;B==*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F(&5V97)Y
M('5S97(@=&AA="!I<R!P87)T(&]F('1H:7,@9W)O=7`@*&%N9"!O;FQY"B`@
M("`@*B!T:&ES(&=R;W5P*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!4:&4@=7-E<B!L:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T57-E
M<G,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V=R;W5P3V(M/FQI
M<W15<V5R<R@D=&AI<RT^9&%T85LG9&XG72D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!'970@82!L:7-T(&]F(&5V97)Y('5S97(@=&AA="!I<R!A(&UE;6)E
M<B!O9B!T:&ES(&=R;W5P(&%N9"!A;GD@;V8*("`@("`J(&ET)W,@<W5B9W)O
M=7!S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!C;VUP;&5T
M92!U<V5R(&QI<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1!;&Q5<V5R
M<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9W)O=7!/8BT^;&ES
M=$%L;%5S97)S*"1T:&ES+3YD871A6R=D;B==*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%1A:V4@:6X@82!L:7-T(&]F(&%T=')I8G5T97,@9G)O;2!T:&4@
M8F%C:V5N9"!A;F0@;6%P(&ET('1O(&]U<@H@("`@("H@:6YT97)N86P@9&%T
M82!A<G)A>2X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&%T=')I8G5T
M97,@(%1H92!L:7-T(&]F(&%T=')I8G5T97,@9G)O;2!T:&4@8F%C:V5N9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V9R;VU!='1R:6)U=&5S*"1A='1R:6)U
M=&5S(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^9&%T85LG=7-E
M<G,G72`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&%T=')I8G5T97,@
M87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@:68@*"1K97D@/3T@
M<W1R=&]L;W=E<B@D1TQ/0D%,4ULG8V]N9B==6R=G<F]U<"==6R=P87)A;7,G
M75LG;65M8F5R=6ED)UTI*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?87)R
M87DH)'9A;'5E*2D@>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V
M86QU92!A<R`D=7-E<BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^9&%T85LG=7-E<G,G75LD=7-E<ET@/2`G,2<["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^9&%T85LG=7-E<G,G75LD=F%L=65=(#T@)S$G.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V5I9B`H)&ME>2`]
M/2`G;6%I;"<I('L*("`@("`@("`@("`@("`@("1T:&ES+3YD871A6R=E;6%I
M;"==(#T@)'9A;'5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/F1A=&%;)&ME>5T@/2`D=F%L=64["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!-87`@=&AI<R!O
M8FIE8W0G<R!A='1R:6)U=&5S(&9R;VT@=&AE(&1A=&$@87)R87D@:6YT;R!A
M(&9O<FUA="!T:&%T"B`@("`@*B!C86X@8F4@<W1O<F5D(&EN(&%N($Q$05`@
M96YT<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&5N=')Y
M(&%R<F%Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=&]!='1R:6)U=&5S*"D*
M("`@('L*("`@("`@("`D871T<FEB=71E<R`](&%R<F%Y*"D["B`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/F1A=&$@87,@)&ME>2`]/B`D=F%L=64I('L*("`@
M("`@("`@("`@:68@*"1K97D@/3T@)W5S97)S)RD@>PH@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)'9A;'5E(&%S("1U<V5R(#T^("1M96UB97)S:&EP*2![
M"B`@("`@("`@("`@("`@("`@("`@)&%T=')I8G5T97-;<W1R=&]L;W=E<B@D
M1TQ/0D%,4ULG8V]N9B==6R=G<F]U<"==6R=P87)A;7,G75LG;65M8F5R=6ED
M)UTI75M=(#T@)'5S97(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T@96QS96EF("@D:V5Y(#T]("=E;6%I;"<I('L*("`@("`@("`@("`@("`@
M("1A='1R:6)U=&5S6R=M86EL)UT@/2`A96UP='DH)'9A;'5E*2`_("1V86QU
M92`Z("<@)SL*("`@("`@("`@("`@?2!E;'-E:68@*"1K97D@(3T@)V1N)R`F
M)B`D:V5Y("$]('-T<G1O;&]W97(H)$=,3T)!3%-;)V-O;F8G75LG9W)O=7`G
M75LG<&%R86US)UU;)VUE;6)E<G5I9"==*2D@>PH@("`@("`@("`@("`@("`@
M)&%T=')I8G5T97-;)&ME>5T@/2`A96UP='DH)'9A;'5E*2`_("1V86QU92`Z
M("<@)SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1A='1R:6)U=&5S.PH@("`@?0H*?0``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]'<F]U<"YP:'``````````````````````````````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P-3`U,S0`,3`U,34T,S,W-3(`,#(Q,S`P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@IR
M97%U:7)E7V]N8V4@)TAO<F1E+T1A=&%4<F5E+G!H<"<["G)E<75I<F5?;VYC
M92`G2&]R9&4O2&ES=&]R>2YP:'`G.PH*+RHJ"B`J(%1H92!'<F]U<#HZ(&-L
M87-S('!R;W9I9&5S('1H92!(;W)D92!G<F]U<',@<WES=&5M+@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`L=B`Q+C8W+C(N,34@
M,C`P-B\P-R\Q-R`Q-#HT,#HQ.2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#$Y.3DM,C`P-B!3=&5P:&%N92!(=71H97(@/'-H=71H97)`8FEG9F]O="YC
M;VT^"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!3
M=&5P:&%N92!(=71H97(@/'-H=71H97)`8FEG9F]O="YC;VT^"B`J($!A=71H
M;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN
M8V4@("!(;W)D92`R+C$*("H@0'!A8VMA9V4@2&]R9&5?1W)O=7`*("HO"F-L
M87-S($=R;W5P('L*"B`@("`O*BH*("`@("`J(%!O:6YT97(@=&\@82!$871A
M5')E92!I;G-T86YC92!T;R!M86YA9V4@=&AE(&1I9F9E<F5N="!G<F]U<',N
M"B`@("`@*@H@("`@("H@0'9A<B!$871A5')E90H@("`@("HO"B`@("!V87(@
M)%]D871A=')E93L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@
M*B\*("`@(&9U;F-T:6]N($=R;W5P*"D*("`@('L*("`@("`@("!G;&]B86P@
M)&-O;F8["@H@("`@("`@(&EF("AE;7!T>2@D8V]N9ELG9&%T871R964G75LG
M9')I=F5R)UTI*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"@G66]U(&UU
M<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@1W)O=7!S
M+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`D
M9')I=F5R(#T@)&-O;F9;)V1A=&%T<F5E)UU;)V1R:79E<B==.PH@("`@("`@
M("1T:&ES+3Y?9&%T871R964@/2`F1&%T851R964Z.G-I;F=L971O;B@D9')I
M=F5R+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>5]M97)G92A(;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=D
M871A=')E92<L("1D<FEV97(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9W)O
M=7`G(#T^("=H;W)D92YG<F]U<',G*2DI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N(&$@;F5W(&=R;W5P(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE("`@(%1H92!G<F]U<"=S(&YA;64N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1P87)E;G0@(%1H92!G<F]U<"=S('!A<F5N="=S
M(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!$871A5')E94]B:F5C=%]'
M<F]U<"`@02!N97<@9W)O=7`@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO
M;B`F;F5W1W)O=7`H)&YA;64L("1P87)E;G0@/2!$051!5%)%15]23T]4*0H@
M("`@>PH@("`@("`@(&EF("AE;7!T>2@D;F%M92DI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B1W)O=7`@;F%M97,@;75S="!B
M92!N;VXM96UP='DB*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H)'!A<F5N
M="`A/2!$051!5%)%15]23T]4*2!["B`@("`@("`@("`@("1N86UE(#T@)'1H
M:7,M/F=E=$=R;W5P3F%M92@D<&%R96YT*2`N("<Z)R`N($1A=&%4<F5E.CIE
M;F-O9&5.86UE*"1N86UE*3L*("`@("`@("!]"@H@("`@("`@("1G<F]U<"`]
M("9N97<@1&%T851R965/8FIE8W1?1W)O=7`H)&YA;64I.PH@("`@("`@("1G
M<F]U<"T^<V5T1W)O=7!/8B@D=&AI<RD["B`@("`@("`@<F5T=7)N("1G<F]U
M<#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!A($1A=&%4<F5E3V)J
M96-T7T=R;W5P(&]B:F5C="!C;W)R97-P;VYD:6YG('1O('1H92!N86UE9`H@
M("`@("H@9W)O=7`L('=I=&@@=&AE('5S97)S(&%N9"!O=&AE<B!D871A(')E
M=')I979E9"!A<'!R;W!R:6%T96QY+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@5&AE(&YA;64@;V8@=&AE(&=R;W5P('1O(')E=')I979E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T1W)O=7`H)&YA;64I"B`@("![
M"B`@("`@("`@+RH@8V%C:&4@;V8@<')E=FEO=7,@<F5T<FEE=F5D(&=R;W5P
M<R`J+PH@("`@("`@('-T871I8R`D9W)O=7!#86-H93L*"B`@("`@("`@:68@
M*"%I<U]A<G)A>2@D9W)O=7!#86-H92DI('L*("`@("`@("`@("`@)&=R;W5P
M0V%C:&4@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<W-E
M="@D9W)O=7!#86-H95LD;F%M95TI*2!["B`@("`@("`@("`@("1G<F]U<$-A
M8VAE6R1N86UE72`]("1T:&ES+3Y?9&%T871R964M/F=E=$]B:F5C="@D;F%M
M92P@)T1A=&%4<F5E3V)J96-T7T=R;W5P)RD["B`@("`@("`@("`@(&EF("@A
M:7-?82@D9W)O=7!#86-H95LD;F%M95TL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@("1G<F]U<$-A8VAE6R1N86UE72T^<V5T1W)O=7!/8B@D
M=&AI<RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D9W)O=7!#86-H95LD;F%M95T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FX@82!$871A5')E94]B:F5C=%]'<F]U<"!O8FIE8W0@8V]R<F5S<&]N
M9&EN9R!T;R!T:&4@9VEV96X*("`@("`J('5N:7%U92!)1"P@=VET:"!T:&4@
M=7-E<G,@86YD(&]T:&5R(&1A=&$@<F5T<FEE=F5D"B`@("`@*B!A<'!R;W!R
M:6%T96QY+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1C:60@(%1H
M92!U;FEQ=64@240@;V8@=&AE(&=R;W5P('1O(')E=')I979E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B`F9V5T1W)O=7!">4ED*"1C:60I"B`@("!["B`@("`@
M("`@)&=R;W5P(#T@)'1H:7,M/E]D871A=')E92T^9V5T3V)J96-T0GE)9"@D
M8VED+"`G1&%T851R965/8FIE8W1?1W)O=7`G*3L*("`@("`@("!I9B`H(6ES
M7V$H)&=R;W5P+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1G<F]U
M<"T^<V5T1W)O=7!/8B@D=&AI<RD["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D9W)O=7`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!G;&]B86QL
M>2!U;FEQ=64@240@9F]R(&$@9W)O=7`N"B`@("`@*@H@("`@("H@0'!A<F%M
M($1A=&%4<F5E3V)J96-T7T=R;W5P("1G<F]U<"`@5&AE(&=R;W5P+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!!($=5240@<F5F97)R:6YG('1O
M("1G<F]U<"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1U5)1"@D9W)O=7`I
M"B`@("!["B`@("`@("`@<F5T=7)N("=H;W)D93IG<F]U<#HG("X@)'1H:7,M
M/F=E=$=R;W5P260H)&=R;W5P*3L*("`@('T*"B`@("`O*BH*("`@("`J($%D
M9"!A(&=R;W5P('1O('1H92!G<F]U<',@<WES=&5M+B!4:&4@9W)O=7`@;75S
M="!F:7)S="!B90H@("`@("H@8W)E871E9"!W:71H($=R;W5P.CIN97='<F]U
M<"@I+"!A;F0@:&%V92!A;GD@:6YI=&EA;"!U<V5R<PH@("`@("H@861D960@
M=&\@:70L(&)E9F]R92!T:&ES(&9U;F-T:6]N(&ES(&-A;&QE9"X*("`@("`J
M"B`@("`@*B!`<&%R86T@1&%T851R965/8FIE8W1?1W)O=7`@)&=R;W5P("!4
M:&4@;F5W(&=R;W5P(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@861D
M1W)O=7`H)&=R;W5P*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D9W)O=7`L
M("=$871A5')E94]B:F5C=%]'<F]U<"<I*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"='<F]U<',@;75S="!B92!$871A5')E94]B
M:F5C=%]'<F]U<"!O8FIE8W1S(&]R(&5X=&5N9"!T:&%T(&-L87-S+B<I.PH@
M("`@("`@('T*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D871A=')E92T^
M861D*"1G<F]U<"D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("!]"@H@("`@("`@("\J($QO9R!T:&4@861D:71I;VX@;V8@=&AE(&=R;W5P
M(&EN('1H92!H:7-T;W)Y(&QO9RX@*B\*("`@("`@("`D:&ES=&]R>2`]("9(
M;W)D95](:7-T;W)Y.CIS:6YG;&5T;VXH*3L*("`@("`@("`D;&]G(#T@)&AI
M<W1O<GDM/FQO9R@D=&AI<RT^9V5T1U5)1"@D9W)O=7`I+"!A<G)A>2@G86-T
M:6]N)R`]/B`G861D)RDL('1R=64I.PH@("`@("`@(&EF("AI<U]A*"1L;V<L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1L;V<["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-T;W)E('5P9&%T960@9&%T82`M('5S97)S+"!E=&,N("T@
M;V8@82!G<F]U<"!T;R!T:&4@8F%C:V5N9"!S>7-T96TN"B`@("`@*@H@("`@
M("H@0'!A<F%M($1A=&%4<F5E3V)J96-T7T=R;W5P("1G<F]U<"`@5&AE(&=R
M;W5P('1O('5P9&%T92X*("`@("`J+PH@("`@9G5N8W1I;VX@=7!D871E1W)O
M=7`H)&=R;W5P*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D9W)O=7`L("=$
M871A5')E94]B:F5C=%]'<F]U<"<I*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"='<F]U<',@;75S="!B92!$871A5')E94]B:F5C
M=%]'<F]U<"!O8FIE8W1S(&]R(&5X=&5N9"!T:&%T(&-L87-S+B<I.PH@("`@
M("`@('T*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D871A=')E92T^=7!D
M871E1&%T82@D9W)O=7`I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@?0H*("`@("`@("`O*B!,;V<@=&AE('5P9&%T92!O9B!T:&4@9W)O
M=7`@=7-E<G,@;VX@=&AE(&AI<W1O<GD@;&]G+B`J+PH@("`@("`@("1H:7-T
M;W)Y(#T@)DAO<F1E7TAI<W1O<GDZ.G-I;F=L971O;B@I.PH@("`@("`@("1G
M=6ED(#T@)'1H:7,M/F=E=$=5240H)&=R;W5P*3L*("`@("`@("!F;W)E86-H
M("@D9W)O=7`M/F=E=$%U9&ET3&]G*"D@87,@)'5S97))9"`]/B`D86-T:6]N
M*2!["B`@("`@("`@("`@("1H:7-T;W)Y+3YL;V<H)&=U:60L(&%R<F%Y*"=A
M8W1I;VXG(#T^("1A8W1I;VXL("=U<V5R)R`]/B`D=7-E<DED*2P@=')U92D[
M"B`@("`@("`@?0H@("`@("`@("1G<F]U<"T^8VQE87)!=61I=$QO9R@I.PH*
M("`@("`@("`O*B!,;V<@=&AE(&=R;W5P(&UO9&EF:6-A=&EO;BX@*B\*("`@
M("`@("`D:&ES=&]R>2T^;&]G*"1G=6ED+"!A<G)A>2@G86-T:6]N)R`]/B`G
M;6]D:69Y)RDL('1R=64I.PH@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M?0H*("`@("\J*@H@("`@("H@0VAA;F=E('1H92!N86UE(&]F(&$@9W)O=7`@
M=VET:&]U="!C:&%N9VEN9R!I=',@8V]N=&5N=',@;W(*("`@("`J('=H97)E
M(&ET(&ES(&EN('1H92!G<F]U<',@:&EE<F%R8VAY+@H@("`@("H*("`@("`J
M($!P87)A;2!$871A5')E94]B:F5C=%]'<F]U<"`D9W)O=7`@(%1H92!G<F]U
M<"!T;R!R96YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=.86UE("`@
M("`@("`@("`@("!4:&4@9W)O=7`G<R!N97<@;F%M92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5N86UE1W)O=7`H)&=R;W5P+"`D;F5W3F%M92D*("`@('L*
M("`@("`@("!I9B`H(6ES7V$H)&=R;W5P+"`G1&%T851R965/8FIE8W1?1W)O
M=7`G*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G
M1W)O=7!S(&UU<W0@8F4@1&%T851R965/8FIE8W1?1W)O=7`@;V)J96-T<R!O
M<B!E>'1E;F0@=&AA="!C;&%S<RXG*3L*("`@("`@("!]"B`@("`@("`@)')E
M<W5L="`]("1T:&ES+3Y?9&%T871R964M/G)E;F%M92@D9W)O=7`L("1N97=.
M86UE*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@
M("`@("`@+RH@2&ES=&]R>2!,;V<@=&AE(&YA;64@8VAA;F=E(&]F('1H92!G
M<F]U<"X@*B\*("`@("`@("`D:&ES=&]R>2`]("9(;W)D95](:7-T;W)Y.CIS
M:6YG;&5T;VXH*3L*("`@("`@("`D:&ES=&]R>2T^;&]G*"1T:&ES+3YG971'
M54E$*"1G<F]U<"DL(&%R<F%Y*"=A8W1I;VXG(#T^("=R96YA;64G*2P@=')U
M92D["B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!296UO=F4@82!G<F]U<"!F<F]M('1H92!G<F]U<',@<WES=&5M('!E
M<FUA;F5N=&QY+@H@("`@("H*("`@("`J($!P87)A;2!$871A5')E94]B:F5C
M=%]'<F]U<"`D9W)O=7`@(%1H92!G<F]U<"!T;R!R96UO=F4N"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D9F]R8V4@("`@("`@("`@("`@("!&;W)C92!T;R!R
M96UO=F4@979E<GD@8VAI;&0N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V
M94=R;W5P*"1G<F]U<"P@)&9O<F-E(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M:68@*"%I<U]A*"1G<F]U<"P@)T1A=&%4<F5E3V)J96-T7T=R;W5P)RDI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T=R;W5P<R!M
M=7-T(&)E($1A=&%4<F5E3V)J96-T7T=R;W5P(&]B:F5C=',@;W(@97AT96YD
M('1H870@8VQA<W,N)RD["B`@("`@("`@?0H*("`@("`@("`D:&ES=&]R>2`]
M("9(;W)D95](:7-T;W)Y.CIS:6YG;&5T;VXH*3L*("`@("`@("`D:&ES=&]R
M>2T^;&]G*"1T:&ES+3YG971'54E$*"1G<F]U<"DL(&%R<F%Y*"=A8W1I;VXG
M(#T^("=D96QE=&4G*2P@=')U92D["@H@("`@("`@(')E='5R;B`D=&AI<RT^
M7V1A=&%T<F5E+3YR96UO=F4H)&=R;W5P+"`D9F]R8V4I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T<FEE=F4@=&AE(&YA;64@;V8@82!G<F]U<"X*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9VED("!4:&4@:60@;V8@=&AE
M(&=R;W5P('1O(')E=')I979E('1H92!N86UE(&9O<BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(&=R;W5P)W,@;F%M92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T1W)O=7!.86UE*"1G:60I"B`@("!["B`@("`@("`@
M:68@*&ES7V$H)&=I9"P@)T1A=&%4<F5E3V)J96-T7T=R;W5P)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T871R964M/F=E=$YA;64H)&=I
M9"T^9V5T260H*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?9&%T871R964M/F=E=$YA;64H)&=I9"D["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@4W1R:7!S(&%L;"!P87)E;G0@<F5F
M97)E;F-E<R!O9F8@;V8@=&AE(&=I=F5N(&=R;W5P(&YA;64N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9W)O=7`@($YA;64@;V8@=&AE(&=R;W5P
M+@H@("`@("H*("`@("`J($!R971U<FX@5&AE(&YA;64@;V8@=&AE(&=R;W5P
M('=I=&AO=70@<&%R96YT<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1W)O
M=7!3:&]R=$YA;64H)&=R;W5P*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7V1A=&%T<F5E+3YG9713:&]R=$YA;64H)&=R;W5P*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E=')I979E('1H92!)1"!O9B!A(&=R;W5P+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&=R;W5P("!4:&4@9W)O=7`@=&\@
M<F5T<FEE=F4@=&AE($E$(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN
M=&5G97(@(%1H92!G<F]U<"=S($E$+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971'<F]U<$ED*"1G<F]U<"D*("`@('L*("`@("`@("!I9B`H:7-?82@D9W)O
M=7`L("=$871A5')E94]B:F5C=%]'<F]U<"<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7V1A=&%T<F5E+3YG971)9"@D9W)O=7`M/F=E=$YA;64H
M*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?9&%T871R964M/F=E=$ED*"1G<F]U<"D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@0VAE8VL@:68@82!G<F]U<"!E>&ES=',@:6X@=&AE
M('-Y<W1E;2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1G<F]U<"`@
M5&AE(&=R;W5P('1O(&-H96-K+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!I9B!T:&4@9W)O=7`@97AI<W1S+"!F86QS92!O=&AE<G=I
M<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X:7-T<R@D9W)O=7`I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T871R964M/F5X:7-T<R@D9W)O
M=7`I.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@;&ES="!O9B!T:&4@
M<&%R96YT<R!O9B!A(&-H:6QD(&=R;W5P+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1G:60@5&AE(&ED(&]F('1H92!C:&EL9"!G<F]U<"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$=R;W5P4&%R96YT<R@D9VED*0H@("`@>PH@("`@("`@("1N86UE(#T@
M)'1H:7,M/F=E=$=R;W5P3F%M92@D9VED*3L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]D871A=')E92T^9V5T4&%R96YT<R@D;F%M92D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FX@=&AE('-I;F=L92!P87)E;G0@;V8@=&AE(&=I
M=F5N(&=R;W5P+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1G:60@
M(%1H92!$871A5')E92!)1"!O9B!T:&4@8VAI;&0@9W)O=7`N"B`@("`@*@H@
M("`@("H@0')E='5R;B!T:&4@<&%R96YT(&]F('1H92!G:79E;B!G<F]U<"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1W)O=7!087)E;G0H)&=I9"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/E]D871A=')E92T^9V5T4&%R96YT
M0GE)9"@D9VED*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A(&QI<W0@
M;V8@<&%R96YT<R!A;&P@=&AE('=A>2!U<"!T;R!T:&4@<F]O="!O8FIE8W0@
M9F]R("1G<F]U<"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9VED
M("!4:&4@:60@;V8@=&AE(&=R;W5P+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@($$@9FQA="!L:7-T(&]F(&%L;"!O9B!T:&4@<&%R96YT<R!O9B`D
M9W)O=7`L"B`@("`@*B`@("`@("`@("`@("`@("!H87-H960@:6X@)&ED(#T^
M("1N86UE(&9O<FUA="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1W)O=7!0
M87)E;G1,:7-T*"1G:60I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M9&%T871R964M/F=E=%!A<F5N=$QI<W0H)&=I9"D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'970@82!L:7-T(&]F(&5V97)Y(&=R;W5P+"!I;B!T:&4@9F]R
M;6%T(&-I9"`]/B!G<F]U<&YA;64N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)')E9G)E<V@@($EF('1R=64L('1H92!C86-H960@=F%L=64@:7,@
M:6=N;W)E9"!A;F0@=&AE(&=R;W5P"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@;&ES="!I<R!R969R97-H960@9G)O;2!T:&4@9W)O=7`@8F%C
M:V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!#240@/3X@9W)O
M=7!N86UE(&AA<V@N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1'<F]U<',H
M)')E9G)E<V@@/2!F86QS92D*("`@('L*("`@("`@("!S=&%T:6,@)&=R;W5P
M<SL*"B`@("`@("`@:68@*"1R969R97-H('Q\(&ES7VYU;&PH)&=R;W5P<RDI
M('L*("`@("`@("`@("`@)&=R;W5P<R`]("1T:&ES+3Y?9&%T871R964M/F=E
M="A$051!5%)%15]&3U)-051?1DQ!5"P@1$%40512145?4D]/5"P@=')U92D[
M"B`@("`@("`@("`@('5N<V5T*"1G<F]U<'-;1$%40512145?4D]/5%TI.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1G<F]U<',["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'970@82!L:7-T(&]F(&5V97)Y('5S97(@=&AA="!I<R!A
M('!A<G0@;V8@=&AI<R!G<F]U<"!/3DQ9+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1G:60@(%1H92!)1"!O9B!T:&4@9W)O=7`N"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@5&AE('5S97(@;&ES="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@;&ES=%5S97)S*"1G:60I"B`@("!["B`@("`@("`@)&=R
M;W5P3V(@/2`F)'1H:7,M/F=E=$=R;W5P0GE)9"@D9VED*3L*("`@("`@("!I
M9B`H:7-?82@D9W)O=7!/8BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&=R;W5P3V(["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES
M<V5T*"1G<F]U<$]B+3YD871A6R=U<V5R<R==*2!\?`H@("`@("`@("`@("`A
M:7-?87)R87DH)&=R;W5P3V(M/F1A=&%;)W5S97)S)UTI*2!["B`@("`@("`@
M("`@(')E='5R;B!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M(&%R<F%Y7VME>7,H)&=R;W5P3V(M/F1A=&%;)W5S97)S)UTI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1V5T(&$@;&ES="!O9B!E=F5R>2!U<V5R('1H870@
M:7,@<&%R="!O9B!T:&4@<W!E8VEF:65D(&=R;W5P"B`@("`@*B!A;F0@86YY
M(&]F(&ET<R!S=6)G<F]U<',N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&=R;W5P("!4:&4@240@;V8@=&AE('!A<F5N="!G<F]U<"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@8V]M<&QE=&4@=7-E<B!L:7-T
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T06QL57-E<G,H)&=I9"D*("`@
M('L*("`@("`@("`O+R!'970@82!L:7-T(&]F(&5V97)Y(&=R;W5P('1H870@
M:7,@82!S=6(M9W)O=7`@;V8@)&=R;W5P+@H@("`@("`@("1G<F]U<',@/2`D
M=&AI<RT^7V1A=&%T<F5E+3YG970H1$%40512145?1D]234%47T9,050L("1T
M:&ES+3YG971'<F]U<$YA;64H)&=I9"DL('1R=64I.PH@("`@("`@(&EF("AI
M<U]A*"1G<F]U<',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1G<F]U<',["B`@("`@("`@?0H*("`@("`@("`D9W)O=7!S(#T@87)R
M87E?:V5Y<R@D9W)O=7!S*3L*("`@("`@("`D=7-E<G,@/2!A<G)A>2@I.PH@
M("`@("`@(&9O<F5A8V@@*"1G<F]U<',@87,@)&=R;W5P260I('L*("`@("`@
M("`@("`@)'5S97)S(#T@87)R87E?;65R9V4H)'5S97)S+"`D=&AI<RT^;&ES
M=%5S97)S*"1G<F]U<$ED*2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B!A
M<G)A>5]V86QU97,H87)R87E?9FQI<"AA<G)A>5]F;&EP*"1U<V5R<RDI*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($=E="!A(&QI<W0@;V8@979E<GD@9W)O
M=7`@=&AA="`D=7-E<B!I<R!I;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`D=7-E<B`@("`@("`@("!4:&4@=7-E<B!T;R!G970@9W)O=7!S(&9O
M<BX*("`@("`J($!P87)A;2!B;V]L96%N("1P87)E;G1'<F]U<',@($%L<V\@
M<F5T=7)N('1H92!P87)E;G1S(&]F(&%N>2!G<F]U<',_"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@;V8@86QL(&=R;W5P<R!T:&4@
M=7-E<B!I<R!I;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1W)O=7!-96UB
M97)S:&EP<R@D=7-E<BP@)'!A<F5N=$=R;W5P<R`](&9A;'-E*0H@("`@>PH@
M("`@("`@('-T871I8R`D8V%C:&4["@H@("`@("`@(&EF("AE;7!T>2@D8V%C
M:&5;)'5S97)=*2D@>PH@("`@("`@("`@("`D8W)I=&5R:6$@/2!A<G)A>2@*
M("`@("`@("`@("`@("`@("=!3D0G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=F:65L9"<@/3X@)VYA;64G+"`G;W`G(#T^("<])RP@
M)W1E<W0G(#T^("=U<V5R)RDL"B`@("`@("`@("`@("`@("`@("`@87)R87DH
M)V9I96QD)R`]/B`G:V5Y)RP@)V]P)R`]/B`G/2<L("=T97-T)R`]/B`D=7-E
M<BDI*3L*("`@("`@("`@("`@)&=R;W5P<R`]("1T:&ES+3Y?9&%T871R964M
M/F=E=$)Y071T<FEB=71E<R@D8W)I=&5R:6$I.PH*("`@("`@("`@("`@:68@
M*&ES7V$H)&=R;W5P<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@2&]R9&4Z.FQO9TUE<W-A9V4H)&=R;W5P<RP@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]%4E)/4BD["B`@("`@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D<&%R96YT
M1W)O=7!S*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D9W)O=7!S(&%S
M("1I9"`]/B`D9RD@>PH@("`@("`@("`@("`@("`@("`@("1P87)E;G1S(#T@
M)'1H:7,M/E]D871A=')E92T^9V5T4&%R96YT3&ES="@D:60I.PH@("`@("`@
M("`@("`@("`@("`@(&EF("AI<U]A*"1P87)E;G1S+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<&%R96YT<SL*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&=R
M;W5P<R`K/2`D<&%R96YT<SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)&-A8VAE6R1U<V5R72`]("1G<F]U<',["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&-A8VAE6R1U<V5R73L*("`@('T*
M"B`@("`O*BH*("`@("`J(%-A>2!I9B!A('5S97(@:7,@82!M96UB97(@;V8@
M82!G<F]U<"!O<B!N;W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=7-E<B`@("`@("`@5&AE(&YA;64@;V8@=&AE('5S97(N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D9VED("`@("`@("!4:&4@240@;V8@=&AE(&=R;W5P+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)'-U8F=R;W5P<R`@4F5T=7)N('1R=64@
M:68@=&AE('5S97(@:7,@:6X@86YY('-U8F=R;W5P<PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@;V8@9W)O=7`@=VET:"!)1"`D9VED+"!A
M;'-O+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;@H@("`@("HO"B`@
M("!F=6YC=&EO;B!U<V5R27-);D=R;W5P*"1U<V5R+"`D9VED+"`D<W5B9W)O
M=7!S(#T@=')U92D*("`@('L*("`@("`@("!I9B`H(21T:&ES+3YE>&ES=',H
M)'1H:7,M/F=E=$=R;W5P3F%M92@D9VED*2DI('L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T@96QS96EF("@D<W5B9W)O=7!S*2!["B`@
M("`@("`@("`@("1G<F]U<',@/2`D=&AI<RT^9V5T1W)O=7!-96UB97)S:&EP
M<R@D=7-E<BP@=')U92D["B`@("`@("`@("`@(&EF("AI<U]A*"1G<F]U<',L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@($AO<F1E.CIL;V=-
M97-S86=E*"1G<F]U<',L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?
M15)2*3L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@<F5T=7)N("%E;7!T>2@D9W)O=7!S6R1G:61=
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=7-E<G,@/2`D=&AI
M<RT^;&ES=%5S97)S*"1G:60I.PH@("`@("`@("`@("!I9B`H:7-?82@D=7-E
M<G,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@($AO<F1E.CIL
M;V=-97-S86=E*"1U<V5R<RP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U]%4E(I.PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(')E='5R;B!I;E]A<G)A>2@D=7-E<BP@)'5S
M97)S*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!$871A5')E92!L979E;"!O9B!T:&4@9VEV96X@9W)O=7`N(#`@:7,@
M<F5T=7)N960@9F]R"B`@("`@*B!A;F0@;V)J96-T(&1I<F5C=&QY(&)E;&]W
M($1!5$%44D5%7U)/3U0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&=I9"`@5&AE($1A=&%4<F5E($E$(&]F('1H92!G<F]U<"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(%1H92!$871A5')E92!L979E;"!O9B!T:&4@9W)O=7`N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$QE=F5L*"1G:60I"B`@("!["B`@
M("`@("`@)&YA;64@/2`D=&AI<RT^7V1A=&%T<F5E+3YG971.86UE*"1G:60I
M.PH@("`@("`@(')E='5R;B!S=6)S=')?8V]U;G0H)&YA;64L("<Z)RD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC
M<F5T92!'<F]U<"!I;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@("`@("H*
M("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC
M<F5T92!'<F]U<"!S=6)C;&%S<R!T;R!R971U<FXN"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N
M86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE
M960N"B`@("`@*@H@("`@("H@0')E='5R;B!'<F]U<"`@5&AE(&YE=VQY(&-R
M96%T960@8V]N8W)E=&4@1W)O=7`@:6YS=&%N8V4L(&]R(&$*("`@("`J("`@
M("`@("`@("`@("`@(%!%05)?17)R;W(@;V)J96-T(&]N(&%N(&5R<F]R+@H@
M("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D9')I=F5R(#T@)R<L("1P
M87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@("1D<FEV97(@/2!B87-E;F%M
M92@D9')I=F5R*3L*"B`@("`@("`@:68@*$!F:6QE7V5X:7-T<RAD:7)N86UE
M*%]?1DE,15]?*2`N("<O1W)O=7`O)R`N("1D<FEV97(@+B`G+G!H<"<I*2![
M"B`@("`@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N
M("<O1W)O=7`O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@0&EN8VQU9&5?;VYC92`G2&]R9&4O1W)O=7`O)R`N
M("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?0H@("`@("`@("1C;&%S<R`]
M("='<F]U<%\G("X@)&1R:79E<CL*("`@("`@("!I9B`H8VQA<W-?97AI<W1S
M*"1C;&%S<RDI('L*("`@("`@("`@("`@)&=R;W5P(#T@)FYE=R`D8VQA<W,H
M)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&=R;W5P
M(#T@4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@9&5F:6YI=&EO;B!O9B`G("X@
M)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&=R;W5P.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@
M=&\@<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@1W)O=7`@:6YS
M=&%N8V4N"B`@("`@*B!)="!W:6QL(&]N;'D@8W)E871E(&$@;F5W(&EN<W1A
M;F-E(&EF(&YO($=R;W5P(&EN<W1A;F-E"B`@("`@*B!C=7)R96YT;'D@97AI
M<W1S+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME
M9"!A<SH@)'9A<B`]("9'<F]U<#HZ<VEN9VQE=&]N*"D*("`@("`J"B`@("`@
M*B!`<F5T=7)N($=R;W5P("!4:&4@8V]N8W)E=&4@1W)O=7`@<F5F97)E;F-E
M+"!O<B!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M)G-I;F=L971O;B@I"B`@("!["B`@("`@("`@<W1A=&EC("1G<F]U<#L*"B`@
M("`@("`@:68@*"%I<W-E="@D9W)O=7`I*2!["B`@("`@("`@("`@(&=L;V)A
M;"`D8V]N9CL*"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O075T
M:"YP:'`G.PH@("`@("`@("`@("`D875T:"`]("9!=71H.CIS:6YG;&5T;VXH
M)&-O;F9;)V%U=&@G75LG9')I=F5R)UTI.PH@("`@("`@("`@("!I9B`H)&%U
M=&@M/FAA<T-A<&%B:6QI='DH)V=R;W5P<R<I*2!["B`@("`@("`@("`@("`@
M("`D9W)O=7`@/2`F1W)O=7`Z.F9A8W1O<GDH)&%U=&@M/F=E=$1R:79E<B@I
M+"`D875T:"D["B`@("`@("`@("`@('T@96QS96EF("@A96UP='DH)&-O;F9;
M)V=R;W5P)UU;)V1R:79E<B==*2`F)B`D8V]N9ELG9W)O=7`G75LG9')I=F5R
M)UT@(3T@)V1A=&%T<F5E)RD@>PH@("`@("`@("`@("`@("`@)&=R;W5P(#T@
M)D=R;W5P.CIF86-T;W)Y*"1C;VYF6R=G<F]U<"==6R=D<FEV97(G72D["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D9W)O=7`@/2!N
M97<@1W)O=7`H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1G<F]U<#L*("`@('T*"GT*"B\J*@H@*B!%>'1E;G-I;VX@;V8@
M=&AE($1A=&%4<F5E3V)J96-T(&-L87-S(&9O<B!S=&]R:6YG($=R;W5P(&EN
M9F]R;6%T:6]N"B`J(&EN('1H92!#871E9V]R:65S(&1R:79E<BX@268@>6]U
M('=A;G0@=&\@<W1O<F4@<W!E8VEA;&EZ960@1W)O=7`*("H@:6YF;W)M871I
M;VXL('EO=2!S:&]U;&0@97AT96YD('1H:7,@8VQA<W,@:6YS=&5A9"!O9B!E
M>'1E;F1I;F<*("H@1&%T851R965/8FIE8W0@9&ER96-T;'DN"B`J"B`J($!A
M=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`
M<VEN8V4@("!(;W)D92`R+C$*("H@0'!A8VMA9V4@2&]R9&5?1W)O=7`*("HO
M"F-L87-S($1A=&%4<F5E3V)J96-T7T=R;W5P(&5X=&5N9',@1&%T851R965/
M8FIE8W0@>PH*("`@("\J*@H@("`@("H@5&AE($=R;W5P(&]B:F5C="!W:&EC
M:"!T:&ES(&=R;W5P(&ES(&%S<V]C:6%T960@=VET:"`M(&YE961E9`H@("`@
M("H@9F]R('5P9&%T:6YG(&1A=&$@:6X@=&AE(&)A8VME;F0@=&\@;6%K92!C
M:&%N9V5S('-T:6-K+"!E=&,N"B`@("`@*@H@("`@("H@0'9A<B!'<F]U<`H@
M("`@("HO"B`@("!V87(@)%]G<F]U<$]B.PH*("`@("\J*@H@("`@("H@5&AI
M<R!V87)I86)L92!C86-H97,@=&AE('5S97)S(&%D9&5D(&]R(')E;6]V960@
M9G)O;2!T:&4@9W)O=7`*("`@("`J(&9O<B!(:7-T;W)Y(&QO9V=I;F<@;V8@
M=7-E<BUG<F]U<',@<F5L871I;VYS:&EP+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?875D:71,;V<@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@5&AE($1A=&%4<F5E3V)J96-T7T=R;W5P(&-O;G-T
M<G5C=&]R+B!*=7-T(&UA:V5S('-U<F4@=&\@8V%L;`H@("`@("H@=&AE('!A
M<F5N="!C;VYS=')U8W1O<B!S;R!T:&%T('1H92!G<F]U<"=S(&YA;64@:7,@
M<V5T"B`@("`@*B!P<F]P97)L>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1N86UE("!4:&4@;F%M92!O9B!T:&4@9W)O=7`N"B`@("`@*B\*("`@
M(&9U;F-T:6]N($1A=&%4<F5E3V)J96-T7T=R;W5P*"1N86UE*0H@("`@>PH@
M("`@("`@('!A<F5N=#HZ1&%T851R965/8FIE8W0H)&YA;64I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@07-S;V-I871E<R!A($=R;W5P(&]B:F5C="!W:71H
M('1H:7,@9W)O=7`N"B`@("`@*@H@("`@("H@0'!A<F%M($=R;W5P("1G<F]U
M<$]B("!4:&4@1W)O=7`@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!S
M971'<F]U<$]B*"8D9W)O=7!/8BD*("`@('L*("`@("`@("`D=&AI<RT^7V=R
M;W5P3V(@/2`F)&=R;W5P3V(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&971C
M:"!T:&4@240@;V8@=&AI<R!G<F]U<`H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG(%1H92!G<F]U<"=S($E$"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$ED*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]G<F]U<$]B+3YG
M971'<F]U<$ED*"1T:&ES*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-A=F4@
M86YY(&-H86YG97,@=&\@=&AI<R!O8FIE8W0@=&\@=&AE(&)A8VME;F0@<&5R
M;6%N96YT;'DN"B`@("`@*B\*("`@(&9U;F-T:6]N('-A=F4H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7V=R;W5P3V(M/G5P9&%T94=R;W5P*"1T
M:&ES*3L*"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@=7-E<B!T;R!T
M:&ES(&=R;W5P+"!A;F0@;6%K97,@<W5R92!T:&%T('1H92!B86-K96YD(&ES
M"B`@("`@*B!U<&1A=&5D(&%S('=E;&PN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=7-E<FYA;64@5&AE('5S97(@=&\@861D+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!A9&15<V5R*"1U<V5R;F%M92P@)'5P9&%T92`]('1R=64I
M"B`@("!["B`@("`@("`@)'1H:7,M/F1A=&%;)W5S97)S)UU;)'5S97)N86UE
M72`](#$["B`@("`@("`@)'1H:7,M/E]A=61I=$QO9ULD=7-E<FYA;65=(#T@
M)V%D9%5S97(G.PH@("`@("`@(&EF("@D=7!D871E("8F("1T:&ES+3Y?9W)O
M=7!/8BT^97AI<W1S*"1T:&ES+3YG971.86UE*"DI*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<V%V92@I.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E;6]V97,@82!U<V5R(&9R;VT@=&AI<R!G<F]U<"P@86YD
M(&UA:V5S('-U<F4@=&AA="!T:&4@8F%C:V5N9`H@("`@("H@:7,@=7!D871E
M9"!A<R!W96QL+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97)N
M86UE(%1H92!U<V5R('1O(')E;6]V92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F5M;W9E57-E<B@D=7-E<FYA;64L("1U<&1A=&4@/2!T<G5E*0H@("`@>PH@
M("`@("`@('5N<V5T*"1T:&ES+3YD871A6R=U<V5R<R==6R1U<V5R;F%M95TI
M.PH@("`@("`@("1T:&ES+3Y?875D:71,;V=;)'5S97)N86UE72`]("=D96QE
M=&55<V5R)SL*("`@("`@("!I9B`H)'5P9&%T92D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G-A=F4H*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'970@82!L:7-T(&]F(&5V97)Y('5S97(@=&AA="!I<R!A('!A
M<G0@;V8@=&AI<R!G<F]U<`H@("`@("H@*&%N9"!O;FQY('1H:7,@9W)O=7`I
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE('5S97(@;&ES=`H@
M("`@("HO"B`@("!F=6YC=&EO;B!L:7-T57-E<G,H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7V=R;W5P3V(M/FQI<W15<V5R<R@D=&AI<RT^9V5T
M260H*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F(&5V
M97)Y('5S97(@=&AA="!I<R!A('!A<G0@;V8@=&AI<R!G<F]U<"!A;F0*("`@
M("`J(&%N>2!O9B!I="=S('-U8F=R;W5P<PH@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@(%1H92!C;VUP;&5T92!U<V5R(&QI<W0*("`@("`J+PH@("`@
M9G5N8W1I;VX@;&ES=$%L;%5S97)S*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]G<F]U<$]B+3YL:7-T06QL57-E<G,H)'1H:7,M/F=E=$ED*"DI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&%L;"!T:&4@=7-E<G,@<F5C
M96YT;'D@861D960@;W(@<F5M;W9E9"!F<F]M('1H92!G<F]U<"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T075D:71,;V<H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7V%U9&ET3&]G.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0VQE87)S('1H92!A=61I="!L;V<N(%1O(&)E(&-A;&QE9"!A9G1E<B!G<F]U
M<"!U<&1A=&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L96%R075D:71,;V<H
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?875D:71,;V<@/2!A<G)A>2@I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@36%P('1H:7,@;V)J96-T)W,@871T<FEB
M=71E<R!F<F]M('1H92!D871A(&%R<F%Y(&EN=&\@82!F;W)M870*("`@("`J
M('1H870@=V4@8V%N('-T;W)E(&EN('1H92!A='1R:6)U=&5S('-T;W)A9V4@
M8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@871T
M<FEB=71E<R!A<G)A>2X*("`@("`J+PH@("`@9G5N8W1I;VX@7W1O071T<FEB
M=71E<R@I"B`@("!["B`@("`@("`@+R\@1&5F875L="!T;R!N;R!A='1R:6)U
M=&5S+@H@("`@("`@("1A='1R:6)U=&5S(#T@87)R87DH*3L*"B`@("`@("`@
M+R\@3&]O<"!T:')O=6=H(&%L;"!U<V5R<RP@:68@86YY+@H@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^9&%T85LG=7-E<G,G72D@)B8@:7-?87)R87DH)'1H
M:7,M/F1A=&%;)W5S97)S)UTI("8F(&-O=6YT*"1T:&ES+3YD871A6R=U<V5R
M<R==*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^9&%T85LG=7-E
M<G,G72!A<R`D=7-E<B`]/B`D86-T:79E*2!["B`@("`@("`@("`@("`@("`D
M871T<FEB=71E<UM=(#T@87)R87DH)VYA;64G(#T^("=U<V5R)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:V5Y)R`]/B`D=7-E
M<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=F%L
M=64G(#T^("1A8W1I=F4I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@("1A='1R:6)U=&5S6UT@/2!A<G)A>2@G;F%M92<@/3X@)V5M86EL)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VME>2<@/3X@)R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V86QU92<@/3X@)'1H:7,M
M/F=E="@G96UA:6PG*2D["@H@("`@("`@(')E='5R;B`D871T<FEB=71E<SL*
M("`@('T*"B`@("`O*BH*("`@("`J(%1A:V4@:6X@82!L:7-T(&]F(&%T=')I
M8G5T97,@9G)O;2!T:&4@8F%C:V5N9"!A;F0@;6%P(&ET('1O(&]U<@H@("`@
M("H@:6YT97)N86P@9&%T82!A<G)A>2X*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)&%T=')I8G5T97,@(%1H92!L:7-T(&]F(&%T=')I8G5T97,@9G)O
M;2!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@8F%C:V5N
M9"`H871T<FEB=71E(&YA;64L(&ME>2P@86YD('9A;'5E*2X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V9R;VU!='1R:6)U=&5S*"1A='1R:6)U=&5S*0H@("`@
M>PH@("`@("`@("\O($EN:71I86QI>F4@9&%T82!A<G)A>2X*("`@("`@("`D
M=&AI<RT^9&%T85LG=7-E<G,G72`](&%R<F%Y*"D["@H@("`@("`@(&9O<F5A
M8V@@*"1A='1R:6)U=&5S(&%S("1A='1R*2!["B`@("`@("`@("`@(&EF("@D
M871T<ELG;F%M92==(#T]("=U<V5R)RD@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/F1A=&%;)W5S97)S)UU;)&%T=');)VME>2==72`]("1A='1R6R=V86QU
M92==.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/F1A=&%;)&%T=');)VYA;64G75T@/2`D871T<ELG=F%L=64G73L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92](96QP+G!H<```````````````````````````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,S8U,3<`,3`U,34T,S,W-3$`,#(Q,3`P`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"@HO*BH*("H@
M4F%W(&AE;'`@:6X@=&AE('-T<FEN9RX*("HO"F1E9FEN92@G2$5,4%]33U52
M0T5?4D%7)RP@,"D["@HO*BH*("H@2&5L<"!T97AT(&ES(&EN(&$@9FEL92X*
M("HO"F1E9FEN92@G2$5,4%]33U520T5?1DE,12<L(#$I.PH*+RHJ"B`J(%1H
M92!(96QP.CH@8VQA<W,@<')O=FED97,@86X@:6YT97)F86-E('1O('1H92!O
M;FQI;F4@:&5L<"!S=6)S>7-T96TN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TAE;'`N<&AP+'8@,2XV."XX+C$X(#(P,#8O,#,O,#(@
M,#4Z,C<Z,S4@<VQU<V%R>B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR
M,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!`
M<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?1G)A;65W;W)K
M"B`J+PIC;&%S<R!(96QP('L*"B`@("`O*BH*("`@("`J($AA;F1L92!F;W(@
M=&AE(%A-3"!P87)S97(@;V)J96-T+@H@("`@("H*("`@("`J($!V87(@<F5S
M;W5R8V4*("`@("`J+PH@("`@=F%R("1?<&%R<V5R(#T@,#L*"B`@("`O*BH*
M("`@("`J(%-T<FEN9R!B=69F97(@=&\@:&]L9"!T:&4@6$U,(&AE;'`@<V]U
M<F-E+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D7V)U9F9E<B`]("<G.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&-O;G1A
M:6YI;F<@=&AE($E$(&]F('1H92!R97%U97-T960@:&5L<"!E;G1R>2X*("`@
M("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]R97%%
M;G1R>2`]("<G.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&-O;G1A:6YI;F<@
M=&AE($E$(&]F('1H92!C=7)R96YT(&AE;'`@96YT<GDN"B`@("`@*@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8W5R16YT<GD@/2`G
M)SL*"B`@("`O*BH*("`@("`J(%-T<FEN9R!C;VYT86EN:6YG('1H92!F;W)M
M871T960@;W5T<'5T+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D7V]U='!U="`]("<G.PH*("`@("\J*@H@("`@("H@0F]O
M;&5A;B!I;F1I8V%T:6YG('=H971H97(@=V4G<F4@:6YS:61E(&$@/&AE;'`^
M(&)L;V-K+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@
M("!V87(@)%]I;DAE;'`@/2!F86QS93L*"B`@("`O*BH*("`@("`J($)O;VQE
M86X@:6YD:6-A=&EN9R!W:&5T:&5R('=E)W)E(&EN<VED92!T:&4@<F5Q=65S
M=&5D(&)L;V-K+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO
M"B`@("!V87(@)%]I;D)L;V-K(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!"
M;V]L96%N(&EN9&EC871I;F<@=VAE=&AE<B!W92=R92!I;G-I9&4@82`\=&ET
M;&4^(&)L;V-K+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO
M"B`@("!V87(@)%]I;E1I=&QE(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!(
M87-H(&-O;G1A:6YI;F<@86X@:6YD97@@;V8@86QL(&]F('1H92!H96QP(&5N
M=')I97,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)%]E;G1R:65S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%-T<FEN
M9R!C;VYT86EN:6YG('1H92!C:&%R<V5T(&]F('1H92!834P@9&%T82!S;W5R
M8V4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?8VAA<G-E="`]("=I<V\M.#@U.2TQ)SL*"B`@("`O*BH*("`@("`J($AA
M<V@@;V8@=7-E<BUD969I;F5D(&9U;F-T:6]N(&AA;F1L97)S(&9O<B!T:&4@
M6$U,(&5L96UE;G1S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?:&%N9&QE<G,@/2!A<G)A>2@*("`@("`@("`G:&5L<"<@
M("`@(#T^("`G7VAE;'!(86YD;&5R)RP*("`@("`@("`G96YT<GDG("`@(#T^
M("`G7V5N=')Y2&%N9&QE<B<L"B`@("`@("`@)W1I=&QE)R`@("`]/B`@)U]T
M:71L94AA;F1L97(G+`H@("`@("`@("=H96%D:6YG)R`@/3X@("=?:&5A9&EN
M9TAA;F1L97(G+`H@("`@("`@("=P87)A)R`@("`@/3X@("=?<&%R84AA;F1L
M97(G+`H@("`@("`@("=R968G("`@("`@/3X@("=?<F5F2&%N9&QE<B<L"B`@
M("`@("`@)V5R968G("`@("`]/B`@)U]E<F5F2&%N9&QE<B<L"B`@("`@("`@
M)VAR968G("`@("`]/B`@)U]H<F5F2&%N9&QE<B<L"B`@("`@("`@)V(G("`@
M("`@("`]/B`@)U]B2&%N9&QE<B<L"B`@("`@("`@)VDG("`@("`@("`]/B`@
M)U]I2&%N9&QE<B<L"B`@("`@("`@)W!R92<@("`@("`]/B`@)U]P<F5(86YD
M;&5R)RP*("`@("`@("`G=&EP)R`@("`@(#T^("`G7W1I<$AA;F1L97(G+`H@
M("`@("`@("=W87)N)R`@("`@/3X@("=?=V%R;DAA;F1L97(G"B`@("`I.PH*
M("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D<V]U<F-E("!4:&4@<V]U<F-E(&]F('1H92!834P@:&5L
M<"!D871A+"!B87-E9"!O;B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@($A%3%!?4T]54D-%7RH@8V]N<W1A;G1S+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D87)G("`@("`@4V]U<F-E+61E<&5N9&5N="!A<F=U;65N="!F
M;W(@=&AI<R!(96QP"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!I
M;G-T86YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@2&5L<"@D<V]U<F-E+"`D
M87)G(#T@;G5L;"D*("`@('L*("`@("`@("!G;&]B86P@)&QA;F=U86=E+"`D
M;FQS.PH*("`@("`@("!I9B`H(55T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G>&UL
M)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%!%05(Z.G)A:7-E17)R
M;W(H)U1H92!834P@9G5N8W1I;VYS(&%R92!N;W0@879A:6QA8FQE+B!296)U
M:6QD(%!(4"!W:71H("TM=VET:"UX;6PN)RDL(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@9F%L<V4I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]C:&%R<V5T
M(#T@:7-S970H)&YL<ULG8VAA<G-E=',G75LD;&%N9W5A9V5=*2`_("1N;'-;
M)V-H87)S971S)UU;)&QA;F=U86=E72`Z("=)4T\M.#@U.2TQ)SL*"B`@("`@
M("`@+RH@4&]P=6QA=&4@)'1H:7,M/E]B=69F97(@8F%S960@;VX@)'-O=7)C
M92X@*B\*("`@("`@("!S=VET8V@@*"1S;W5R8V4I('L*("`@("`@("!C87-E
M($A%3%!?4T]54D-%7U)!5SH*("`@("`@("`@("`@)'1H:7,M/E]B=69F97(@
M/2`D87)G.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!(14Q0
M7U-/55)#15]&24Q%.@H@("`@("`@("`@("!I9B`H0&9I;&5?97AI<W1S*"1A
M<F=;,%TI("8F($!F:6QE<VEZ92@D87)G6S!=*2D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]B=69F97(@/2!F:6QE7V=E=%]C;VYT96YT<R@D87)G6S!=
M*3L*("`@("`@("`@("`@?2!E;'-E:68@*$!F:6QE7V5X:7-T<R@D87)G6S%=
M*2`F)B!`9FEL97-I>F4H)&%R9ULQ72DI('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?8G5F9F5R(#T@9FEL95]G971?8V]N=&5N=',H)&%R9ULQ72D["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V)U
M9F9E<B`]("<G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`D=&AI<RT^7V)U9F9E<B`]
M("<G.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'96YE<F%T97,@=&AE($A434P@;&EN:R!T:&%T('=I;&P@
M<&]P('5P(&$@:&5L<"!W:6YD;W<@9F]R('1H90H@("`@("H@<F5Q=65S=&5D
M('1O<&EC+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UO9'5L92`@
M5&AE(&YA;64@;V8@=&AE(&-U<G)E;G0@2&]R9&4@;6]D=6QE+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=&]P:6,@("!4:&4@:&5L<"!T;W!I8R!T;R!B92!D
M:7-P;&%Y960N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!(
M5$U,('1O(&-R96%T92!T:&4@:&5L<"!L:6YK+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!L:6YK*"1M;V1U;&4L("1T;W!I8RD*("`@('L*("`@("`@("!G;&]B
M86P@)&-O;F8L("1R96=I<W1R>2P@)&)R;W=S97(["@H@("`@("`@(&EF("@A
M2&]R9&4Z.G-H;W=397)V:6-E*"=H96QP)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("<F;F)S<#LG.PH@("`@("`@('T*"B`@("`@("`@:68@*"1B<F]W<V5R
M+3YH87-&96%T=7)E*"=J879A<V-R:7!T)RDI('L*("`@("`@("`@("`@2&]R
M9&4Z.F%D9%-C<FEP=$9I;&4H)W!O<'5P+FIS)RP@)VAO<F1E)RD["B`@("`@
M("`@?0H*("`@("`@("`D=7)L(#T@2&]R9&4Z.G5R;"@D<F5G:7-T<GDM/F=E
M="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]S97)V:6-E<R]H96QP+R<L('1R
M=64I.PH@("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@
M87)R87DH)VUO9'5L92<@/3X@)&UO9'5L92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T;W!I8R<@/3X@)'1O<&EC
M*2D["B`@("`@("`@)&AT;6P@/2!(;W)D93HZ;&EN:R@D=7)L+"!?*")(96QP
M(BDL("<G+"`G:&]R9&5H96QP=VEN)RP@)W!O<'5P*'1H:7,N:')E9BD[(')E
M='5R;B!F86QS93LG*3L*"B`@("`@("`@<F5T=7)N("1H=&UL("X@2&]R9&4Z
M.FEM9R@G:&5L<"YP;F<G+"!?*")(96QP(BDL("=W:61T:#TB,38B(&AE:6=H
M=#TB,38B)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D@+B`G
M/"]A/B<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&5A;G,@=7`@=&AE($AE
M;'`@8VQA<W,@<F5S;W5R8V5S+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@4F5T=7)N<R!T<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L96%N=7`H*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?8G5F9F5R(#T@)R<["B`@("`@("`@<F5T=7)N('AM;%]P
M87)S97)?9G)E92@D=&AI<RT^7W!A<G-E<BD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!,;V]K<R!U<"!T:&4@<F5Q=65S=&5D(&5N=')Y(&EN('1H92!834P@
M:&5L<"!B=69F97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D96YT
M<GD@(%-T<FEN9R!C;VYT86EN:6YG('1H92!E;G1R>2!)1"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@;&]O:W5P*"1E;G1R>2D*("`@('L*("`@("`@("`D=&AI
M<RT^7V]U='!U="`]("<G.PH@("`@("`@("1T:&ES+3Y?<F5Q16YT<GD@/2!3
M=')I;F<Z.G5P<&5R*"1E;G1R>2D["B`@("`@("`@:68@*"$D=&AI<RT^7W!A
M<G-E<BD@>PH@("`@("`@("`@("`D=&AI<RT^7VEN:70H*3L*("`@("`@("!]
M"B`@("`@("`@>&UL7W!A<G-E*"1T:&ES+3Y?<&%R<V5R+"`D=&AI<RT^7V)U
M9F9E<BP@=')U92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@
M:&%S:"!O9B!A;&P@;V8@=&AE('1O<&EC<R!I;B!T:&ES(&AE;'`@8G5F9F5R
M+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($AA<V@@;V8@86QL(&]F
M('1H92!T;W!I8W,@:6X@=&AI<R!B=69F97(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('1O<&EC<R@I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^7W!A<G-E
M<BD@>PH@("`@("`@("`@("`D=&AI<RT^7VEN:70H*3L*("`@("`@("!]"B`@
M("`@("`@>&UL7W!A<G-E*"1T:&ES+3Y?<&%R<V5R+"`D=&AI<RT^7V)U9F9E
M<BP@=')U92D["@H@("`@("`@(')E='5R;B`D=&AI<RT^7V5N=')I97,["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!$:7-P;&%Y('1H92!C;VYT96YT<R!O9B!T
M:&4@9F]R;6%T=&5D(&]U='!U="!B=69F97(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&1I<W!L87DH*0H@("`@>PH@("`@("`@(&5C:&\@)'1H:7,M/E]O=71P
M=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!);FET:6%L>F5S('1H92!834P@
M<&%R<V5R+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@4F5T=7)N<R!T<G5E(&]N('-U8V-E
M<W,L(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]I
M;FET*"D*("`@('L*("`@("`@("`O*B!#<F5A=&4@82!N97<@<&%R<V5R(&%N
M9"!S970@:71S(&1E9F%U;'0@<')O<&5R=&EE<RX@*B\*("`@("`@("`D=&AI
M<RT^7W!A<G-E<B`]('AM;%]P87)S97)?8W)E871E*"D["B`@("`@("`@>&UL
M7W-E=%]O8FIE8W0H)'1H:7,M/E]P87)S97(L("1T:&ES*3L*("`@("`@("!X
M;6Q?<&%R<V5R7W-E=%]O<'1I;VXH)'1H:7,M/E]P87)S97(L(%A-3%]/4%1)
M3TY?0T%315]&3TQ$24Y'+"!F86QS92D["B`@("`@("`@>&UL7W-E=%]E;&5M
M96YT7VAA;F1L97(H)'1H:7,M/E]P87)S97(L("=?<W1A<G1%;&5M96YT)RP@
M)U]E;F1%;&5M96YT)RD["B`@("`@("`@>&UL7W-E=%]C:&%R86-T97)?9&%T
M85]H86YD;&5R*"1T:&ES+3Y?<&%R<V5R+"`G7V1E9F%U;'1(86YD;&5R)RD[
M"@H@("`@("`@(')E='5R;B`H)'1H:7,M/E]P87)S97(@(3T@,"D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!5<V5R+61E9FEN960@9G5N8W1I;VX@8V%L;&)A
M8VL@9F]R('-T87)T(&5L96UE;G1S+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W0@)'!A<G-E<B`@
M2&%N9&QE('1O('1H92!P87)S97(@:6YS=&%N8V4N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N86UE("`@(%1H92!N86UE(&]F('1H:7,@6$U,(&5L96UE;G0N
M"B`@("`@*B!`<&%R86T@87)R87D@)&%T=')S("`@($QI<W0@;V8@=&AI<R!E
M;&5M96YT)W,@871T<FEB=71E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-T
M87)T16QE;65N="@D<&%R<V5R+"`D;F%M92P@)&%T=')S*0H@("`@>PH@("`@
M("`@("\J($-A;&P@=&AE(&%S<VEG;F5D(&AA;F1L97(@9F]R('1H:7,@96QE
M;65N="P@:68@;VYE(&ES"B`@("`@("`@("H@879A:6QA8FQE+B`J+PH@("`@
M("`@(&EF("AI;E]A<G)A>2@D;F%M92P@87)R87E?:V5Y<R@D=&AI<RT^7VAA
M;F1L97)S*2DI('L*("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F,H87)R87DH
M)B1T:&ES+"`D=&AI<RT^7VAA;F1L97)S6R1N86UE72DL('1R=64L("1A='1R
M<RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@57-E<BUD969I
M;F5D(&9U;F-T:6]N(&-A;&QB86-K(&9O<B!E;F0@96QE;65N=',N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M(&]B:F5C="`D<&%R<V5R("!(86YD;&4@=&\@=&AE('!A<G-E<B!I;G-T86YC
M92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@5&AE(&YA;64@;V8@
M=&AI<R!834P@96QE;65N="X*("`@("`J+PH@("`@9G5N8W1I;VX@7V5N9$5L
M96UE;G0H)'!A<G-E<BP@)&YA;64I"B`@("!["B`@("`@("`@+RH@0V%L;"!T
M:&4@87-S:6=N960@:&%N9&QE<B!F;W(@=&AI<R!E;&5M96YT+"!I9B!O;F4@
M:7,@879A:6QA8FQE+B`J+PH@("`@("`@(&EF("AI;E]A<G)A>2@D;F%M92P@
M87)R87E?:V5Y<R@D=&AI<RT^7VAA;F1L97)S*2DI('L*("`@("`@("`@("`@
M8V%L;%]U<V5R7V9U;F,H87)R87DH)B1T:&ES+"`D=&AI<RT^7VAA;F1L97)S
M6R1N86UE72DL(&9A;'-E*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!5<V5R+61E9FEN960@9G5N8W1I;VX@8V%L;&)A8VL@9F]R(&-H87)A
M8W1E<B!D871A+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!P87)A;2!O8FIE8W0@)'!A<G-E<B`@2&%N9&QE('1O('1H
M92!P87)S97(@:6YS=&%N8V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A
M("`@(%-T<FEN9R!O9B!C:&%R86-T97(@9&%T82X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V1E9F%U;'1(86YD;&5R*"1P87)S97(L("1D871A*0H@("`@>PH@
M("`@("`@("1D871A(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D9&%T82P@
M=F5R<VEO;E]C;VUP87)E*'IE;F1?=F5R<VEO;B@I+"`G,B<L("<\)RD@/R`D
M=&AI<RT^7V-H87)S970@.B`G551&+3@G*3L*("`@("`@("!I9B`H)'1H:7,M
M/E]I;E1I=&QE*2!["B`@("`@("`@("`@("1T:&ES+3Y?96YT<FEE<ULD=&AI
M<RT^7V-U<D5N=')Y72`N/2`D9&%T83L*("`@("`@("!]"B`@("`@("`@:68@
M*"1T:&ES+3Y?:6Y(96QP("8F("1T:&ES+3Y?:6Y";&]C:RD@>PH@("`@("`@
M("`@("`D=&AI<RT^7V]U='!U="`N/2!H=&UL<W!E8VEA;&-H87)S*"1D871A
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!834P@96QE;65N
M="!H86YD;&5R(&9O<B!T:&4@/&AE;'`^('1A9RX*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M<W1A<G1486<@($)O;VQE86X@:6YD:6-A=&EN9R!W:&5T:&5R('1H:7,@:6YS
M=&%N8V4@:7,@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!S
M=&%R="!T86<N"B`@("`@*B!`<&%R86T@87)R87D@)&%T=')S("`@("`@($%D
M9&ET:6]N86P@96QE;65N="!A='1R:6)U=&5S("A.;W0@=7-E9"DN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]H96QP2&%N9&QE<B@D<W1A<G1486<L("1A='1R
M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]I;DAE;'`@/2`D
M<W1A<G1486<@/R`@=')U92`Z(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@6$U,(&5L96UE;G0@:&%N9&QE<B!F;W(@=&AE(#QE;G1R>3X@=&%G+@H@
M("`@("H@071T<FEB=71E<SH@:60*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<W1A<G1486<@
M($)O;VQE86X@:6YD:6-A=&EN9R!W:&5T:&5R('1H:7,@:6YS=&%N8V4@:7,@
M80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!S=&%R="!T86<N
M"B`@("`@*B!`<&%R86T@87)R87D@)&%T=')S("`@("`@($%D9&ET:6]N86P@
M96QE;65N="!A='1R:6)U=&5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?96YT
M<GE(86YD;&5R*"1S=&%R=%1A9RP@)&%T=')S(#T@87)R87DH*2D*("`@('L*
M("`@("`@("!I9B`H(21S=&%R=%1A9RD@>PH@("`@("`@("`@("`D=&AI<RT^
M7VEN0FQO8VL@/2!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D:60@/2!3=')I;F<Z.G5P<&5R*"1A='1R<ULG:60G72D["B`@("`@("`@
M("`@("1T:&ES+3Y?8W5R16YT<GD@/2`D:60["B`@("`@("`@("`@("1T:&ES
M+3Y?96YT<FEE<ULD:61=(#T@)R<["B`@("`@("`@("`@("1T:&ES+3Y?:6Y"
M;&]C:R`]("@D:60@/3T@)'1H:7,M/E]R97%%;G1R>2D["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@6$U,(&5L96UE;G0@:&%N9&QE<B!F;W(@
M=&AE(#QT:71L93X@=&%G+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1S=&%R=%1A9R`@0F]O
M;&5A;B!I;F1I8V%T:6YG('=H971H97(@=&AI<R!I;G-T86YC92!I<R!A"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@('-T87)T('1A9RX*("`@
M("`J($!P87)A;2!A<G)A>2`D871T<G,@("`@("`@061D:71I;VYA;"!E;&5M
M96YT(&%T=')I8G5T97,@*$YO="!U<V5D*2X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W1I=&QE2&%N9&QE<B@D<W1A<G1486<L("1A='1R<R`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@)'1H:7,M/E]I;E1I=&QE(#T@)'-T87)T5&%G.PH@
M("`@("`@(&EF("@D=&AI<RT^7VEN2&5L<"`F)B`D=&AI<RT^7VEN0FQO8VLI
M('L*("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@)'-T87)T5&%G(#\@
M)SQH,3XG(#H@)SPO:#$^)SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!834P@96QE;65N="!H86YD;&5R(&9O<B!T:&4@/&AE861I;F<^('1A
M9RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D<W1A<G1486<@($)O;VQE86X@:6YD:6-A=&EN
M9R!W:&5T:&5R('1H:7,@:6YS=&%N8V4@:7,@80H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("!S=&%R="!T86<N"B`@("`@*B!`<&%R86T@(&%R
M<F%Y("1A='1R<R`@("`@($%D9&ET:6]N86P@96QE;65N="!A='1R:6)U=&5S
M("A.;W0@=7-E9"DN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]H96%D:6YG2&%N
M9&QE<B@D<W1A<G1486<L("1A='1R<R`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@:68@*"1T:&ES+3Y?:6Y(96QP("8F("1T:&ES+3Y?:6Y";&]C:RD@>PH@
M("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N/2`D<W1A<G1486<@/R`G/&@R
M/B<@.B`G/"]H,CXG.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%A-3"!E;&5M96YT(&AA;F1L97(@9F]R('1H92`\<&%R83X@=&%G+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A
M;2!B;V]L96%N("1S=&%R=%1A9R`@0F]O;&5A;B!I;F1I8V%T:6YG('=H971H
M97(@=&AI<R!I;G-T86YC92!I<R!A"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@('-T87)T('1A9RX*("`@("`J($!P87)A;2!A<G)A>2`D871T
M<G,@("`@("`@061D:71I;VYA;"!E;&5M96YT(&%T=')I8G5T97,@*$YO="!U
M<V5D*2X*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<F%(86YD;&5R*"1S=&%R
M=%1A9RP@)&%T=')S(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H)'1H
M:7,M/E]I;DAE;'`@)B8@)'1H:7,M/E]I;D)L;V-K*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?;W5T<'5T("X]("1S=&%R=%1A9R`_("<\<#XG(#H@)SPO<#XG
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%A-3"!E;&5M96YT
M(&AA;F1L97(@9F]R('1H92`\<F5F/B!T86<N"B`@("`@*B!297%U:7)E9"!A
M='1R:6)U=&5S.B!%3E1262P@34]$54Q%"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-T87)T
M5&%G("!";V]L96%N(&EN9&EC871I;F<@=VAE=&AE<B!T:&ES(&EN<W1A;F-E
M(&ES(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1A<G0@
M=&%G+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A='1R<R`@("`@("!!9&1I=&EO
M;F%L(&5L96UE;G0@871T<FEB=71E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M7W)E9DAA;F1L97(H)'-T87)T5&%G+"`D871T<G,@/2!A<G)A>2@I*0H@("`@
M>PH@("`@("`@(&EF("@D=&AI<RT^7VEN2&5L<"`F)B`D=&AI<RT^7VEN0FQO
M8VLI('L*("`@("`@("`@("`@:68@*"1S=&%R=%1A9R`F)B!I<W-E="@D871T
M<G-;)VUO9'5L92==*2`F)B!I<W-E="@D871T<G-;)V5N=')Y)UTI*2!["B`@
M("`@("`@("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*$AO<F1E
M.CIS96QF57)L*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*"=S:&]W)R`]/B`G96YT<GDG+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;6]D=6QE
M)R`]/B`D871T<G-;)VUO9'5L92==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=&]P:6,G("`]/B`D871T<G-;
M)V5N=')Y)UTI*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X]
M($AO<F1E.CIL:6YK*"1U<FPI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@)SPO83XG.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@6$U,(&5L
M96UE;G0@:&%N9&QE<B!F;W(@=&AE(#QE<F5F/B!T86<N"B`@("`@*B!297%U
M:7)E9"!E;&5M96YT<SH@55),"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-T87)T5&%G("!"
M;V]L96%N(&EN9&EC871I;F<@=VAE=&AE<B!T:&ES(&EN<W1A;F-E(&ES(&$*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1A<G0@=&%G+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1A='1R<R`@("`@("!!9&1I=&EO;F%L(&5L
M96UE;G0@871T<FEB=71E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V5R969(
M86YD;&5R*"1S=&%R=%1A9RP@)&%T=')S(#T@87)R87DH*2D*("`@('L*("`@
M("`@("!I9B`H)'1H:7,M/E]I;DAE;'`@)B8@)'1H:7,M/E]I;D)L;V-K*2![
M"B`@("`@("`@("`@(&EF("@D<W1A<G1486<I('L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;W5T<'5T("X]($AO<F1E.CIL:6YK*"1A='1R<ULG=7)L)UTL
M(&YU;&PL("<G+"`G7V)L86YK)RD["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N/2`G/"]A/B<["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!834P@
M96QE;65N="!H86YD;&5R(&9O<B!T:&4@/&AR968^('1A9RX*("`@("`J(%)E
M<75I<F5D(&5L96UE;G1S.B!U<FPL(&%P<"X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<W1A
M<G1486<@($)O;VQE86X@:6YD:6-A=&EN9R!W:&5T:&5R('1H:7,@:6YS=&%N
M8V4@:7,@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!S=&%R
M="!T86<N"B`@("`@*B!`<&%R86T@87)R87D@)&%T=')S("`@("`@($%D9&ET
M:6]N86P@96QE;65N="!A='1R:6)U=&5S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?:')E9DAA;F1L97(H)'-T87)T5&%G+"`D871T<G,@/2!A<G)A>2@I*0H@
M("`@>PH@("`@("`@(&EF("@D=&AI<RT^7VEN2&5L<"`F)B`D=&AI<RT^7VEN
M0FQO8VLI('L*("`@("`@("`@("`@:68@*"1S=&%R=%1A9RD@>PH@("`@("`@
M("`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*("`@("`@("`@("`@("`@("1U
M<FP@/2!(;W)D93HZ=7)L*"1R96=I<W1R>2T^9V5T*"=W96)R;V]T)RP@)&%T
M=')S6R=A<'`G72D@+B`G+R<@+B`D871T<G-;)W5R;"==*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;W5T<'5T("X]($AO<F1E.CIL:6YK*"1U<FPL(&YU
M;&PL("<G+"`G7V)L86YK)RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N/2`G/"]A/B<["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!834P@96QE
M;65N="!H86YD;&5R(&9O<B!T:&4@)FQT.V(F9W0[('1A9RX*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D<W1A<G1486<@($)O;VQE86X@:6YD:6-A=&EN9R!W:&5T:&5R('1H
M:7,@:6YS=&%N8V4@:7,@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("!S=&%R="!T86<N"B`@("`@*B!`<&%R86T@87)R87D@)&%T=')S("`@
M("`@($%D9&ET:6]N86P@96QE;65N="!A='1R:6)U=&5S("A.;W0@=7-E9"DN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]B2&%N9&QE<B@D<W1A<G1486<L("1A
M='1R<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?:6Y(
M96QP("8F("1T:&ES+3Y?:6Y";&]C:RD@>PH@("`@("`@("`@("`D=&AI<RT^
M7V]U='!U="`N/2`D<W1A<G1486<@/R`G/'-T<F]N9SXG(#H@)SPO<W1R;VYG
M/B<["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@6$U,(&5L96UE
M;G0@:&%N9&QE<B!F;W(@=&AE("9L=#MI)F=T.R!T86<N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)'-T87)T5&%G("!";V]L96%N(&EN9&EC871I;F<@=VAE=&AE<B!T:&ES
M(&EN<W1A;F-E(&ES(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<W1A<G0@=&%G+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A='1R<R`@("`@
M("!!9&1I=&EO;F%L(&5L96UE;G0@871T<FEB=71E<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@7VE(86YD;&5R*"1S=&%R=%1A9RP@)&%T=')S(#T@87)R87DH
M*2D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]I;DAE;'`@)B8@)'1H:7,M
M/E]I;D)L;V-K*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X]("1S
M=&%R=%1A9R`_("<\96T^)R`Z("<\+V5M/B<["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@6$U,(&5L96UE;G0@:&%N9&QE<B!F;W(@=&AE("9L
M=#MP<F4F9W0[('1A9RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<W1A<G1486<@($)O;VQE
M86X@:6YD:6-A=&EN9R!W:&5T:&5R('1H:7,@:6YS=&%N8V4@:7,@80H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("!S=&%R="!T86<N"B`@("`@
M*B!`<&%R86T@87)R87D@)&%T=')S("`@("`@($%D9&ET:6]N86P@96QE;65N
M="!A='1R:6)U=&5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<')E2&%N9&QE
M<B@D<W1A<G1486<L("1A='1R<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M:68@*"1T:&ES+3Y?:6Y(96QP("8F("1T:&ES+3Y?:6Y";&]C:RD@>PH@("`@
M("`@("`@("`D=&AI<RT^7V]U='!U="`N/2`D<W1A<G1486<@/R`G/'!R93XG
M(#H@)SPO<')E/B<["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M6$U,(&5L96UE;G0@:&%N9&QE<B!F;W(@=&AE(#QT:7`^('1A9RX*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D<W1A<G1486<@($)O;VQE86X@:6YD:6-A=&EN9R!W:&5T:&5R
M('1H:7,@:6YS=&%N8V4@:7,@80H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("!S=&%R="!T86<N"B`@("`@*B!`<&%R86T@87)R87D@)&%T=')S
M("`@("`@($%D9&ET:6]N86P@96QE;65N="!A='1R:6)U=&5S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?=&EP2&%N9&QE<B@D<W1A<G1486<L("1A='1R<R`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?:6Y(96QP("8F
M("1T:&ES+3Y?:6Y";&]C:RD@>PH@("`@("`@("`@("`D=&AI<RT^7V]U='!U
M="`N/2`D<W1A<G1486<@/R`G/&5M(&-L87-S/2)H96QP5&EP(CXG(#H@)SPO
M96T^)SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!834P@96QE
M;65N="!H86YD;&5R(&9O<B!T:&4@/'=A<FX^('1A9RX*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D<W1A<G1486<@($)O;VQE86X@:6YD:6-A=&EN9R!W:&5T:&5R('1H:7,@
M:6YS=&%N8V4@:7,@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("!S=&%R="!T86<N"B`@("`@*B!`<&%R86T@87)R87D@)&%T=')S("`@("`@
M($%D9&ET:6]N86P@96QE;65N="!A='1R:6)U=&5S+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?=V%R;DAA;F1L97(H)'-T87)T5&%G+"`D871T<G,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7VEN2&5L<"`F)B`D=&AI
M<RT^7VEN0FQO8VLI('L*("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@
M)'-T87)T5&%G(#\@)SQE;2!C;&%S<STB:&5L<%=A<FXB/B<@.B`G/"]E;3XG
M.PH@("`@("`@('T*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O2&ES=&]R>2YP:'``````````````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#(V-#(U`#$P-3$U-#,S-S4R`#`R,38T-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@5&AE($AI<W1O<GDZ.B!C;&%S<R!P<F]V:61E<R!A(&UE=&AO9"!O9B!T
M<F%C:VEN9R!C:&%N9V5S(&EN($AO<F1E"B`J(&]B:F5C=',L('-T;W)E9"!I
M;B!A(%-13"!T86)L92X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO2&ES=&]R
M>2](:7-T;W)Y+G!H<"QV(#$N,C@N,BXQ-"`R,#`V+S`U+S`S(#(Q.C0V.C$S
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M($!S:6YC92`@($AO<F1E(#(N,0H@*B!`<&%C:V%G92!(;W)D95](:7-T;W)Y
M"B`J+PIC;&%S<R!(;W)D95](:7-T;W)Y('L*"B`@("`O*BH*("`@("`J(%!O
M:6YT97(@=&\@82!$0B!I;G-T86YC92!T;R!M86YA9V4@=&AE(&AI<W1O<GDN
M"B`@("`@*@H@("`@("H@0'9A<B!$0@H@("`@("HO"B`@("!V87(@)%]D8CL*
M"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC
M92!T;R!A(&-O;F-R971E($AI<W1O<GD@:6YS=&%N8V4N"B`@("`@*B!)="!W
M:6QL(&]N;'D@8W)E871E(&$@;F5W(&EN<W1A;F-E(&EF(&YO($AI<W1O<GD@
M:6YS=&%N8V4*("`@("`J(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@("`@
M("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R(#T@)DAI
M<W1O<GDZ.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D
M95](:7-T;W)Y("!4:&4@8V]N8W)E=&4@2&ES=&]R>2!R969E<F5N8V4L(&]R
M(&9A;'-E(&]N(&%N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"D*("`@('L*
M("`@("`@("!S=&%T:6,@)&AI<W1O<GD["@H@("`@("`@(&EF("@A:7-S970H
M)&AI<W1O<GDI*2!["B`@("`@("`@("`@("1H:7-T;W)Y(#T@)FYE=R!(;W)D
M95](:7-T;W)Y*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&AI<W1O
M<GD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@2&]R9&5?2&ES=&]R>2@I"B`@("!["B`@("`@("`@
M9VQO8F%L("1C;VYF.PH*("`@("`@("!I9B`H96UP='DH)&-O;F9;)W-Q;"==
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V1B(#T@4$5!4CHZ<F%I<V5%<G)O
M<BA?*")4:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L960N(BDI.PH@("`@
M("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E("=$0BYP:'`G.PH@("`@("`@
M("1T:&ES+3Y?9&(@/2`F1$(Z.F-O;FYE8W0H)&-O;F9;)W-Q;"==*3L*"B`@
M("`@("`@+RH@4V5T($1"('!O<G1A8FEL:71Y(&]P=&EO;G,N("HO"B`@("`@
M("`@:68@*&ES7V$H)'1H:7,M/E]D8BP@)T1"7V-O;6UO;B<I*2!["B`@("`@
M("`@("`@('-W:71C:"`H)'1H:7,M/E]D8BT^<&AP='EP92D@>PH@("`@("`@
M("`@("!C87-E("=M<W-Q;"<Z"B`@("`@("`@("`@("`@("`D=&AI<RT^7V1B
M+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?3$]7
M15)#05-%('P@1$)?4$]25$%"24Q)5%E?15)23U)3('P@1$)?4$]25$%"24Q)
M5%E?4E1224TI.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YS971/<'1I
M;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?3$]715)#05-%('P@
M1$)?4$]25$%"24Q)5%E?15)23U)3*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($QO9W,@86X@979E;G0@=&\@86X@
M:71E;2=S(&AI<W1O<GD@;&]G+B!4:&4@:71E;2!M=7-T(&)E('5N:7%U96QY
M"B`@("`@*B!I9&5N=&EF:65D(&)Y("1G=6ED+B!!;GD@;W1H97(@9&5T86EL
M<R!A8F]U="!T:&4@979E;G0@87)E('!A<W-E9"!I;@H@("`@("H@)&%T=')I
M8G5T97,N(%-T86YD87)D('-U9V=E<W1E9"!A='1R:6)U=&5S(&%R93H*("`@
M("`J"B`@("`@*B`@("=W:&\G(#T^(%1H92!I9"!O9B!T:&4@=7-E<B!T:&%T
M('!E<F9O<FUE9"!T:&4@86-T:6]N("AW:6QL(&)E(&%D9&5D"B`@("`@*B`@
M("`@("`@("`@(&%U=&]M871I8V%L;'D@:68@;F]T('!R97-E;G0I+@H@("`@
M("H*("`@("`J("`@)W1S)R`]/B!4:6UE<W1A;7`@;V8@=&AE(&%C=&EO;B`H
M=&AI<R!W:6QL(&)E(&%D9&5D(&%U=&]M871I8V%L;'D@:68*("`@("`J("`@
M("`@("`@("!I="!I<R!N;W0@<')E<V5N="DN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9W5I9"`@("`@("`@("`@(%1H92!U;FEQ=64@:61E;G1I
M9FEE<B!O9B!T:&4@96YT<GD@=&\*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!A9&0@=&\N"B`@("`@*B!`<&%R86T@87)R87D@)&%T
M=')I8G5T97,@("`@("`@5&AE(&AA<V@@;V8@;F%M92`]/B!V86QU92!E;G1R
M:65S('1H870*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!D97-C<FEB92!T:&ES(&5V96YT+@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)')E<&QA8V5!8W1I;VX@($EF("1A='1R:6)U=&5S6R=A8W1I;VXG72!I<R!A
M;')E861Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<')E<V5N="!I;B!T:&4@:71E;2=S(&AI<W1O<GD@;&]G+`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('5P9&%T92!T:&%T(&5N=')Y
M(&EN<W1E860@;V8@8W)E871I;F<@80H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&YE=R!O;F4N"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N?%!%05)?17)R;W(@(%1R=64@;VX@<W5C8V5S<RP@4$5!4E]%
M<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L;V<H)&=U
M:60L("1A='1R:6)U=&5S(#T@87)R87DH*2P@)')E<&QA8V5!8W1I;VX@/2!F
M86QS92D*("`@('L*("`@("`@("!I9B`H:7-?82@D=&AI<RT^7V1B+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1B.PH@
M("`@("`@('T*"B`@("`@("`@)&AI<W1O<GD@/2`F)'1H:7,M/F=E=$AI<W1O
M<GDH)&=U:60I.PH@("`@("`@(&EF("@A)&AI<W1O<GD@?'P@:7-?82@D:&ES
M=&]R>2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&AI
M<W1O<GD["B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH)&%T=')I8G5T
M97-;)W=H;R==*2D@>PH@("`@("`@("`@("`D871T<FEB=71E<ULG=VAO)UT@
M/2!!=71H.CIG971!=71H*"D["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T
M>2@D871T<FEB=71E<ULG=',G72DI('L*("`@("`@("`@("`@)&%T=')I8G5T
M97-;)W1S)UT@/2!T:6UE*"D["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!W
M92!W86YT('1O(')E<&QA8V4@86X@96YT<GD@=VET:"!T:&4@<V%M92!A8W1I
M;VXL('1R>2!A;F0@9FEN9`H@("`@("`@("`J(&]N92X@5')A8VL@=VAE=&AE
M<B!O<B!N;W0@=V4@<W5C8V5E9"!I;B`D9&]N92P@<V\@=V4@:VYO=R!W:&5T
M:&5R"B`@("`@("`@("H@;W(@;F]T('1O(&%D9"!T:&4@96YT<GD@;&%T97(N
M("HO"B`@("`@("`@)&1O;F4@/2!F86QS93L*("`@("`@("!I9B`H)')E<&QA
M8V5!8W1I;VX@)B8@(65M<'1Y*"1A='1R:6)U=&5S6R=A8W1I;VXG72DI('L*
M("`@("`@("`@("`@)&-O=6YT(#T@8V]U;G0H)&AI<W1O<GDM/F1A=&$I.PH@
M("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8V]U;G0[("1I*RLI('L*
M("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&AI<W1O<GDM/F1A=&%;)&E=
M6R=A8W1I;VXG72D@)B8*("`@("`@("`@("`@("`@("`@("`D:&ES=&]R>2T^
M9&%T85LD:5U;)V%C=&EO;B==(#T]("1A='1R:6)U=&5S6R=A8W1I;VXG72D@
M>PH*("`@("`@("`@("`@("`@("`@("`D=F%L=65S(#T@87)R87DH)&%T=')I
M8G5T97-;)W1S)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1A='1R:6)U=&5S6R=W:&\G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:7-S970H)&%T=')I8G5T97-;)V1E<V,G72D@/R`D
M871T<FEB=71E<ULG9&5S8R==(#H@;G5L;"D["B`@("`@("`@("`@("`@("`@
M("`@=6YS970H)&%T=')I8G5T97-;)W1S)UTI.PH@("`@("`@("`@("`@("`@
M("`@('5N<V5T*"1A='1R:6)U=&5S6R=W:&\G72D["B`@("`@("`@("`@("`@
M("`@("`@=6YS970H)&%T=')I8G5T97-;)V1E<V,G72D["B`@("`@("`@("`@
M("`@("`@("`@=6YS970H)&%T=')I8G5T97-;)V%C=&EO;B==*3L*("`@("`@
M("`@("`@("`@("`@("!I9B`H)&%T=')I8G5T97,I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'9A;'5E<UM=(#T@<V5R:6%L:7IE*"1A='1R:6)U=&5S
M*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=F%L=65S6UT@/2!N=6QL.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`D=F%L=65S6UT@/2`D:&ES=&]R
M>2T^9&%T85LD:5U;)VED)UT["@H@("`@("`@("`@("`@("`@("`@("1R(#T@
M)'1H:7,M/E]D8BT^<75E<GDH)U501$%412!H;W)D95]H:7-T;W)I97,@4T54
M(&AI<W1O<GE?=',@/2`_+"<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("<@:&ES=&]R>5]W:&\@/2`_+"<@+@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("<@:&ES=&]R>5]D97-C(#T@
M/RPG("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M(&AI<W1O<GE?97AT<F$@/2`_(%=(15)%(&AI<W1O<GE?:60@/2`_)RP@)'9A
M;'5E<RD["B`@("`@("`@("`@("`@("`@("`@:68@*&ES7V$H)'(L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D
M9&]N92`]('1R=64["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("\J($EF('=E)W)E(&YO="!R97!L86-I;F<@8GD@86-T:6]N+"!O<B!I9B!W
M92!D:61N)W0@9FEN9"!A;B!E;G1R>2!T;PH@("`@("`@("`J(')E<&QA8V4L
M(&EN<V5R="!A(&YE=R!R;W<N("HO"B`@("`@("`@:68@*"$D9&]N92D@>PH@
M("`@("`@("`@("`D=F%L=65S(#T@87)R87DH)'1H:7,M/E]D8BT^;F5X=$ED
M*"=H;W)D95]H:7-T;W)I97,G*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1G=6ED+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%T=')I
M8G5T97-;)W1S)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D871T
M<FEB=71E<ULG=VAO)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M<W-E="@D871T<FEB=71E<ULG9&5S8R==*2`_("1A='1R:6)U=&5S6R=D97-C
M)UT@.B!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:7-S970H
M)&%T=')I8G5T97-;)V%C=&EO;B==*2`_("1A='1R:6)U=&5S6R=A8W1I;VXG
M72`Z(&YU;&PI.PH@("`@("`@("`@("!U;G-E="@D871T<FEB=71E<ULG=',G
M72D["B`@("`@("`@("`@('5N<V5T*"1A='1R:6)U=&5S6R=W:&\G72D["B`@
M("`@("`@("`@('5N<V5T*"1A='1R:6)U=&5S6R=D97-C)UTI.PH@("`@("`@
M("`@("!U;G-E="@D871T<FEB=71E<ULG86-T:6]N)UTI.PH@("`@("`@("`@
M("!I9B`H)&%T=')I8G5T97,I('L*("`@("`@("`@("`@("`@("1V86QU97-;
M72`]('-E<FEA;&EZ92@D871T<FEB=71E<RD["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D=F%L=65S6UT@/2!N=6QL.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D<B`]("1T:&ES+3Y?9&(M/G%U97)Y*"=)
M3E-%4E0@24Y43R!H;W)D95]H:7-T;W)I97,@*&AI<W1O<GE?:60L(&]B:F5C
M=%]U:60L(&AI<W1O<GE?=',L(&AI<W1O<GE?=VAO+"!H:7-T;W)Y7V1E<V,L
M(&AI<W1O<GE?86-T:6]N+"!H:7-T;W)Y7V5X=')A*2<@+@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G(%9!3%5%4R`H/RP@/RP@/RP@/RP@/RP@
M/RP@/RDG+"`D=F%L=65S*3L*("`@("`@("`@("`@:68@*&ES7V$H)'(L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<CL*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@2&ES=&]R>4]B:F5C="!C
M;W)R97-P;VYD:6YG('1O('1H92!N86UE9"!H:7-T;W)Y"B`@("`@*B!E;G1R
M>2P@=VET:"!T:&4@9&%T82!R971R:65V960@87!P<F]P<FEA=&5L>2X@)&%U
M=&]C<F5A=&4@:&%S"B`@("`@*B!N;R!A9F9E8W0N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9W5I9"`@("`@("`@(%1H92!N86UE(&]F('1H92!H
M:7-T;W)Y(&5N=')Y('1O(')E=')I979E+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&%U=&]C<F5A=&4@($1E<')E8V%T960N"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9G971(:7-T;W)Y*"1G=6ED+"`D875T;V-R96%T92`](&YU;&PI"B`@
M("!["B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]D8BP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`D9F%L<V4@/2!F86QS93L*("`@("`@("`@("`@
M<F5T=7)N("1F86QS93L*("`@("`@("!]"@H@("`@("`@("1R;W=S(#T@)'1H
M:7,M/E]D8BT^9V5T06QL*"=314Q%0U0@*B!&4D]-(&AO<F1E7VAI<W1O<FEE
M<R!72$5212!O8FIE8W1?=6ED(#T@/R<L(&%R<F%Y*"1G=6ED*2P@1$)?1D54
M0TA-3T1%7T%34T]#*3L*("`@("`@("`D:&ES=&]R>2`]("9N97<@2&ES=&]R
M>4]B:F5C="@D9W5I9"P@)')O=W,I.PH@("`@("`@(')E='5R;B`D:&ES=&]R
M>3L*("`@('T*"B`@("`O*BH*("`@("`J($9I;F1S(&AI<W1O<GD@;V)J96-T
M<R!B>2!T:6UE<W1A;7`L(&%N9"!O<'1I;VYA;&QY(&9I;'1E<B!O;B!O=&AE
M<@H@("`@("H@9FEE;&1S(&%S('=E;&PN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8VUP("`@("!4:&4@8V]M<&%R:7-O;B!O<&5R871O<B`H/"P@
M/BP@/#TL(#X]+"!O<B`]*2!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("!C:&5C:R!T:&4@=&EM97-T86UP<R!W:71H+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'1S("`@("!4:&4@=&EM97-T86UP('1O(&-O;7!A<F4@86=A
M:6YS="X*("`@("`J($!P87)A;2!A<G)A>2`D9FEL=&5R<R`@06X@87)R87D@
M;V8@861D:71I;VYA;"`H04Y$960I(&-R:71E<FEA+@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("!%86-H(&%R<F%Y('9A;'5E('-H;W5L9"!B92!A
M;B!A<G)A>2!W:71H(#,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M96YT<FEE<SH*("`@("`J(#QP<F4^"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`G;W`G("`@("T@=&AE(&]P97)A=&]R('1O(&-O;7!A<F4@=&AI
M<R!F:65L9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('=I=&@N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`G9FEE
M;&0G("T@=&AE(&AI<W1O<GD@9FEE;&0@8F5I;F<@8V]M<&%R960*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`H:2YE+B`G86-T
M:6]N)RDN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`G=F%L=64G
M("T@=&AE('9A;'5E('1O(&-H96-K(&9O<B`H:2YE+B`G861D)RDN"B`@("`@
M*B`\+W!R93X*("`@("`J($!P87)A;2!S=')I;F<@)'!A<F5N="`@5&AE('!A
M<F5N="!H:7-T;W)Y('1O('-T87)T('-E87)C:&EN9R!A="X@268@;F]N+65M
M<'1Y+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!W:6QL(&)E('-E
M87)C:&5D(&9O<B!W:71H(&$@3$E+12`G)'!A<F5N=#HE)R!C;&%U<V4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@;V8@:&ES=&]R
M>2!O8FIE8W0@:61S+"!O<B!A;B!E;7!T>2!A<G)A>2!I9@H@("`@("H@("`@
M("`@("`@("`@("`@;F]N92!M871C:&5D('1H92!C<FET97)I82X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T0GE4:6UE<W1A;7`H)&-M<"P@)'1S+"`D9FEL
M=&5R<R`](&%R<F%Y*"DL("1P87)E;G0@/2!N=6QL*0H@("`@>PH@("`@("`@
M(&EF("AI<U]A*"1T:&ES+3Y?9&(L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@0G5I
M;&0@=&AE('1I;65S=&%M<"!T97-T+B`J+PH@("`@("`@("1W:&5R92`](&%R
M<F%Y*")H:7-T;W)Y7W1S("1C;7`@)'1S(BD["@H@("`@("`@("\J($%D9"!A
M9&1I=&EO;F%L(&9I;'1E<G,L(&EF('1H97)E(&%R92!A;GDN("HO"B`@("`@
M("`@:68@*"1F:6QT97)S*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1F:6QT
M97)S(&%S("1F:6QT97(I('L*("`@("`@("`@("`@("`@("1W:&5R95M=(#T@
M)VAI<W1O<GE?)R`N("1F:6QT97);)V9I96QD)UT@+B`G("<@+B`D9FEL=&5R
M6R=O<"==("X@)R`G("X@)'1H:7,M/E]D8BT^<75O=&4H)&9I;'1E<ELG=F%L
M=64G72D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D
M<&%R96YT*2!["B`@("`@("`@("`@("1W:&5R95M=(#T@)V]B:F5C=%]U:60@
M3$E+12`G("X@)'1H:7,M/E]D8BT^<75O=&4H)'!A<F5N="`N("<Z)2<I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&(M/F=E=$%S<V]C
M*"=314Q%0U0@1$E35$E.0U0@;V)J96-T7W5I9"P@:&ES=&]R>5]I9"!&4D]-
M(&AO<F1E7VAI<W1O<FEE<R!72$5212`G("X@:6UP;&]D92@G($%.1"`G+"`D
M=VAE<F4I*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E=',@=&AE('1I;65S
M=&%M<"!O9B!T:&4@;6]S="!R96-E;G0@8VAA;F=E('1O("1G=6ED+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&=U:60@("`@5&AE(&YA;64@;V8@
M=&AE(&AI<W1O<GD@96YT<GD@=&\@<F5T<FEE=F4N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1A8W1I;VX@($%N(&%C=&EO;CH@)V%D9"<L("=M;V1I9GDG+"`G
M9&5L971E)RP@971C+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@
M5&AE('1I;65S=&%M<"P@;W(@,"!I9B!N;R!M871C:&EN9R!E;G1R>2!I<R!F
M;W5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T06-T:6]N5&EM97-T86UP
M*"1G=6ED+"`D86-T:6]N*0H@("`@>PH@("`@("`@("\J(%1H:7,@:6UP;&5M
M96YT871I;VX@<W1I;&P@=V]R:W,L(&)U="!W92!S:&]U;&0@8F4@86)L92!T
M;PH@("`@("`@("`J(&=E="!M=6-H(&9A<W1E<B!N;W<@=VET:"!A(%-%3$5#
M5"!-05@H:&ES=&]R>5]T<RD*("`@("`@("`@*B`N+BX@<75E<GDN("HO"B`@
M("`@("`@)&AI<W1O<GD@/2`F)'1H:7,M/F=E=$AI<W1O<GDH)&=U:60I.PH@
M("`@("`@(&EF("@A)&AI<W1O<GD@?'P@:7-?82@D:&ES=&]R>2P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@,#L*("`@("`@("!]"@H@
M("`@("`@("1L87-T(#T@,#L*("`@("`@("!I9B`H:7-?87)R87DH)&AI<W1O
M<GDM/F1A=&$I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1H:7-T;W)Y+3YD
M871A(&%S("1E;G1R>2D@>PH@("`@("`@("`@("`@("`@:68@*"1E;G1R>5LG
M86-T:6]N)UT@/3T@)&%C=&EO;B`F)B`D96YT<GE;)W1S)UT@/B`D;&%S="D@
M>PH@("`@("`@("`@("`@("`@("`@("1L87-T(#T@)&5N=')Y6R=T<R==.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&QA<W0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO
M=F4@;VYE(&]R(&UO<F4@:&ES=&]R>2!E;G1R:65S(&)Y(&YA;64N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1N86UE<R`@5&AE(&AI<W1O<GD@96YT
M<FEE<R!T;R!R96UO=F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V94)Y
M3F%M97,H)&YA;65S*0H@("`@>PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?
M9&(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@)&ED<R`](&%R<F%Y*"D["B`@("`@("`@
M9F]R96%C:"`H)&YA;65S(&%S("1N86UE*2!["B`@("`@("`@("`@("1I9'-;
M72`]("1T:&ES+3Y?9&(M/G%U;W1E*"1N86UE*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D=&AI<RT^7V1B+3YQ=65R>2@G1$5,151%($923TT@:&]R
M9&5?:&ES=&]R:65S(%=(15)%(&]B:F5C=%]U:60@24X@*"<@+B!I;7!L;V1E
M*"<L)RP@)&ED<RD@+B`G*2<I.PH@("`@?0H*?0H*+RHJ"B`J($-L87-S(&9O
M<B!P<F5S96YT:6YG($AI<W1O<GD@:6YF;W)M871I;VXN"B`J"B`J($!A=71H
M;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN
M8V4@("!(;W)D92`R+C$*("H@0'!A8VMA9V4@2&]R9&5?2&ES=&]R>0H@*B\*
M8VQA<W,@2&ES=&]R>4]B:F5C="!["@H@("`@=F%R("1U:60["B`@("!V87(@
M)&1A=&$@/2!A<G)A>2@I.PH*("`@(&9U;F-T:6]N($AI<W1O<GE/8FIE8W0H
M)'5I9"P@)&1A=&$@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3YU
M:60@/2`D=6ED.PH*("`@("`@("!I9B`H(21D871A('Q\(&ES7V$H)&1A=&$L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@
M('T*"B`@("`@("`@9F]R96%C:"`H)&1A=&$@87,@)')O=RD@>PH@("`@("`@
M("`@("`D:&ES=&]R>2`](&%R<F%Y*"=A8W1I;VXG(#T^("1R;W=;)VAI<W1O
M<GE?86-T:6]N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E
M<V,G(#T^("1R;W=;)VAI<W1O<GE?9&5S8R==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=W:&\G(#T^("1R;W=;)VAI<W1O<GE?=VAO)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VED)R`]/B`D<F]W6R=H:7-T
M;W)Y7VED)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1S)R`]
M/B`D<F]W6R=H:7-T;W)Y7W1S)UTI.PH@("`@("`@("`@("!I9B`H)')O=ULG
M:&ES=&]R>5]E>'1R82==*2!["B`@("`@("`@("`@("`@("`D97AT<F$@/2!`
M=6YS97)I86QI>F4H)')O=ULG:&ES=&]R>5]E>'1R82==*3L*("`@("`@("`@
M("`@("`@(&EF("@D97AT<F$I('L*("`@("`@("`@("`@("`@("`@("`D:&ES
M=&]R>2`](&%R<F%Y7VUE<F=E*"1H:7-T;W)Y+"`D97AT<F$I.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3YD
M871A6UT@/2`D:&ES=&]R>3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I
M;VX@9V5T1&%T82@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YD871A
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O:4-A;&5N9&%R+P``````````````````````````````
M`````````````````````````````````````````#`P,#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S4Q`#`R,3,T-0`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]I0V%L96YD87(O=F%L87)M
M+G!H<```````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$S-S4`,3`U,34T
M,S,W-3$`,#(S,S0V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!#;&%S<R!R97!R97-E;G1I;F<@=D%L
M87)M<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO:4-A;&5N9&%R+VE#86QE
M;F1A<B]V86QA<FTN<&AP+'8@,2XX+C$P+C0@,C`P-B\P,2\P,2`R,3HR.#HT
M-R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6ME($-O
M8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L
M;"YC;RYN>CX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO
M<F1E7VE#86QE;F1A<@H@*B\*8VQA<W,@2&]R9&5?:4-A;&5N9&%R7W9A;&%R
M;2!E>'1E;F1S($AO<F1E7VE#86QE;F1A<B!["@H@("`@9G5N8W1I;VX@9V5T
M5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=V06QA<FTG.PH@("`@?0H*
M("`@(&9U;F-T:6]N('!A<G-E=D-A;&5N9&%R*"1D871A*0H@("`@>PH@("`@
M("`@('!A<F5N=#HZ<&%R<V5V0V%L96YD87(H)&1A=&$L("=604Q!4DTG*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!E>'!O<G1V0V%L96YD87(H*0H@("`@>PH@
M("`@("`@(')E='5R;B!P87)E;G0Z.E]E>'!O<G1V1&%T82@G5D%,05)-)RD[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]I0V%L96YD87(O
M=F-A<F0N<&AP````````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<R-#(`
M,3`U,34T,S,W-3$`,#(S,38R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+VE#
M86QE;F1A<BYP:'`G.PH*+R\@5&AE(&9O;&QO=VEN9R!W97)E('-H86UE;&5S
M<VQY('EO:6YK960@9G)O;2!#;VYT86-T7U9C87)D7T)U:6QD"B\O(%!A<G0@
M;G5M8F5R<R!F;W(@3B!C;VUP;VYE;G1S+@ID969I;F4H)U9#05)$7TY?1D%-
M24Q9)RP@("`@(#`I.PID969I;F4H)U9#05)$7TY?1TE614XG+"`@("`@(#$I
M.PID969I;F4H)U9#05)$7TY?041$3"<L("`@("`@(#(I.PID969I;F4H)U9#
M05)$7TY?4%)%1DE8)RP@("`@(#,I.PID969I;F4H)U9#05)$7TY?4U5&1DE8
M)RP@("`@(#0I.PH*+R\@4&%R="!N=6UB97)S(&9O<B!!1%(@8V]M<&]N96YT
M<RX*9&5F:6YE*"=60T%21%]!1%)?4$]")RP@("`@("`P*3L*9&5F:6YE*"=6
M0T%21%]!1%)?15A414Y$)RP@("`Q*3L*9&5F:6YE*"=60T%21%]!1%)?4U12
M1454)RP@("`R*3L*9&5F:6YE*"=60T%21%]!1%)?3$]#04Q)5%DG+"`S*3L*
M9&5F:6YE*"=60T%21%]!1%)?4D5'24].)RP@("`T*3L*9&5F:6YE*"=60T%2
M1%]!1%)?4$]35$-/1$4G+"`U*3L*9&5F:6YE*"=60T%21%]!1%)?0T]53E12
M62<L("`V*3L*"B\O(%!A<G0@;G5M8F5R<R!F;W(@1T5/(&-O;7!O;F5N=',N
M"F1E9FEN92@G5D-!4D1?1T5/7TQ!5"<L("`@("`@,"D["F1E9FEN92@G5D-!
M4D1?1T5/7TQ/3B<L("`@("`@,2D["@HO*BH*("H@0VQA<W,@<F5P<F5S96YT
M:6YG('9#87)D(&5N=')I97,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+VE#
M86QE;F1A<B]I0V%L96YD87(O=F-A<F0N<&AP+'8@,2XS+C$P+C@@,C`P-B\P
M-2\P.2`R,SHP.#HR,B!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M,RTR,#`V($MA<G-T96X@1F]U<FUO;G0@*&MA<G-T96Y`:&]R9&4N;W)G*0H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2V%R<W1E;B!&;W5R;6]N="`\
M:V%R<W1E;D!H;W)D92YO<F<^"B`J($!P86-K86=E($AO<F1E7VE#86QE;F1A
M<@H@*B\*8VQA<W,@2&]R9&5?:4-A;&5N9&%R7W9C87)D(&5X=&5N9',@2&]R
M9&5?:4-A;&5N9&%R('L*"B`@("!F=6YC=&EO;B!(;W)D95]I0V%L96YD87)?
M=F-A<F0H)'9E<G-I;VX@/2`G,BXQ)RD*("`@('L*("`@("`@("!R971U<FX@
M<&%R96YT.CI(;W)D95]I0V%L96YD87(H)'9E<G-I;VXI.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G=F-A
M<F0G.PH@("`@?0H*("`@(&9U;F-T:6]N('!A<G-E=D-A;&5N9&%R*"1D871A
M*0H@("`@>PH@("`@("`@(')E='5R;B!P87)E;G0Z.G!A<G-E=D-A;&5N9&%R
M*"1D871A+"`G=F-A<F0G*3L*("`@('T*"B`@("`O*BH*("`@("`J(%5N;&EK
M92!V979E;G0@86YD('9T;V1O+"!A('9C87)D(&ES(&YO<FUA;&QY(&YO="!E
M;F-L;W-E9"!I;B!A;@H@("`@("H@:4-A;&5N9&%R(&-O;G1A:6YE<BX@*$)%
M1TE.+BY%3D0I"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X<&]R='9#86QE;F1A
M<B@I"B`@("!["B`@("`@("`@)')E<75I<F5D071T<FEB=71E<ULG0D]$62==
M(#T@)R<["B`@("`@("`@)')E<75I<F5D071T<FEB=71E<ULG5D524TE/3B==
M(#T@)S(N,2<["@H@("`@("`@(&9O<F5A8V@@*"1R97%U:7)E9$%T=')I8G5T
M97,@87,@)&YA;64@/3X@)&1E9F%U;'1?=F%L=64I('L*("`@("`@("`@("`@
M:68@*&ES7V$H)'1H:7,M/F=E=$%T=')I8G5T92@D;F%M92DL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H
M)&YA;64L("1D969A=6QT7W9A;'5E*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?97AP;W)T=D1A=&$H)U9#05)$
M)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C;VYT96YT
M<R!O9B!T:&4@(DXB('1A9R!A<R!A('!R:6YT86)L92!.86UE.@H@("`@("H@
M:2YE+B!C;VYV97)T<SH*("`@("`J"B`@("`@*B`@($XZ1'5C:SM$86=O8F5R
M=#M4.U!R;V9E<W-O<CM396XN"B`@("`@*B!T;PH@("`@("H@("`B4')O9F5S
M<V]R($1A9V]B97)T(%0@1'5C:R!396XB"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@($9U;&P@;F%M92!O9B!V8V%R9"`B3B(@=&%G"B`@("`@*B`@
M("`@("`@("`@("`@("`@;W(@;G5L;"!I9B!N;R!.('1A9RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@<')I;G1A8FQE3F%M92@I"B`@("!["B`@("`@("`@)&YA
M;65?<&%R=',@/2`D=&AI<RT^9V5T071T<FEB=71E5F%L=65S*"=.)RD["B`@
M("`@("`@:68@*&ES7V$H)&YA;65?<&%R=',L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(65M<'1Y*"1N86UE7W!A<G1S6U9#05)$7TY?4%)%1DE872DI('L*("`@
M("`@("`@("`@)&YA;65?87)R6UT@/2`D;F%M95]P87)T<UM60T%21%].7U!2
M149)6%T["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)&YA;65?<&%R
M='-;5D-!4D1?3E]'259%3ETI*2!["B`@("`@("`@("`@("1N86UE7V%R<EM=
M(#T@)&YA;65?<&%R='-;5D-!4D1?3E]'259%3ET["B`@("`@("`@?0H@("`@
M("`@(&EF("@A96UP='DH)&YA;65?<&%R='-;5D-!4D1?3E]!1$1,72DI('L*
M("`@("`@("`@("`@)&YA;65?87)R6UT@/2`D;F%M95]P87)T<UM60T%21%].
M7T%$1$Q=.PH@("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1N86UE7W!A
M<G1S6U9#05)$7TY?1D%-24Q972DI('L*("`@("`@("`@("`@)&YA;65?87)R
M6UT@/2`D;F%M95]P87)T<UM60T%21%].7T9!34E,65T["B`@("`@("`@?0H@
M("`@("`@(&EF("@A96UP='DH)&YA;65?<&%R='-;5D-!4D1?3E]3549&25A=
M*2D@>PH@("`@("`@("`@("`D;F%M95]A<G);72`]("1N86UE7W!A<G1S6U9#
M05)$7TY?4U5&1DE873L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!I;7!L
M;V1E*"<@)RP@)&YA;65?87)R*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-T
M871I8R!F=6YC=&EO;B!T;R!M86ME(&$@9VEV96X@96UA:6P@861D<F5S<R!R
M9F,X,C(@8V]M<&QI86YT+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&%D9')E<W,@($%N(&5M86EL(&%D9')E<W,N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!21D,X,C(M9F]R;6%T=&5D(&5M86EL(&%D9')E
M<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$)A<F5%;6%I;"@D861D<F5S
M<RD*("`@('L*("`@("`@("`O+R!%;7!T>2!V86QU97,@87)E('-T:6QL(&5M
M<'1Y+@H@("`@("`@(&EF("@A)&%D9')E<W,I('L*("`@("`@("`@("`@<F5T
M=7)N("1A9&1R97-S.PH@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E
M("=-86EL+U)&0S@R,BYP:'`G.PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O34E-12YP:'`G.PH*("`@("`@("!S=&%T:6,@)')F8S@R,CL*("`@("`@
M("!I9B`H:7-?;G5L;"@D<F9C.#(R*2D@>PH@("`@("`@("`@("`D<F9C.#(R
M(#T@;F5W($UA:6Q?4D9#.#(R*"D["B`@("`@("`@?0H*("`@("`@("`D<F9C
M.#(R+3YV86QI9&%T94UA:6QB;W@H)&%D9')E<W,I.PH@("`@("`@(')E='5R
M;B!-24U%.CIR9F,X,C)7<FET94%D9')E<W,H)&%D9')E<W,M/FUA:6QB;W@L
M("1A9&1R97-S+3YH;W-T*3L*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]I0V%L96YD87(O=F5V96YT+G!H<```````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,C`R-30`,3`U,34T,S,W-3$`,#(S,S<P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B!#;&%S<R!R97!R97-E;G1I;F<@=D5V96YT<RX*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO:4-A;&5N9&%R+VE#86QE;F1A<B]V979E;G0N<&AP+'8@,2XS
M,2XQ,"XX(#(P,#8O,#$O,#$@,C$Z,C@Z-#<@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`R,#`S+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N
M:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI:V4@
M0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@
M($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]I0V%L96YD87(*("HO"F-L
M87-S($AO<F1E7VE#86QE;F1A<E]V979E;G0@97AT96YD<R!(;W)D95]I0V%L
M96YD87(@>PH*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@
M(')E='5R;B`G=D5V96YT)SL*("`@('T*"B`@("!F=6YC=&EO;B!P87)S979#
M86QE;F1A<B@D9&%T82D*("`@('L*("`@("`@("!P87)E;G0Z.G!A<G-E=D-A
M;&5N9&%R*"1D871A+"`G5D5614Y4)RD["B`@("!]"@H@("`@9G5N8W1I;VX@
M97AP;W)T=D-A;&5N9&%R*"D*("`@('L*("`@("`@("`O+R!$969A=6QT('9A
M;'5E<RX*("`@("`@("`D<F5Q=6ER961!='1R:6)U=&5S(#T@87)R87DH*3L*
M("`@("`@("`D<F5Q=6ER961!='1R:6)U=&5S6R=$5%-404U0)UT@/2!T:6UE
M*"D["B`@("`@("`@)')E<75I<F5D071T<FEB=71E<ULG3U)'04Y)6D52)UT@
M/2`G56YK;F]W;B!/<F=A;FEZ97(G.PH@("`@("`@("1R97%U:7)E9$%T=')I
M8G5T97-;)U5)1"==(#T@)'1H:7,M/E]E>'!O<G1$871E5&EM92AT:6UE*"DI
M("X@)T`G("X@*&ES<V5T*"1?4T525D526R=315)615)?3D%-12==*2`_("1?
M4T525D526R=315)615)?3D%-12==(#H@)VQO8V%L:&]S="<I.PH*("`@("`@
M("`D;65T:&]D(#T@(65M<'1Y*"1T:&ES+3Y?8V]N=&%I;F5R*2`_"B`@("`@
M("`@("`@("1T:&ES+3Y?8V]N=&%I;F5R+3YG971!='1R:6)U=&4H)TU%5$A/
M1"<I(#H@)U!50DQ)4T@G.PH*("`@("`@("!S=VET8V@@*"1M971H;V0I('L*
M("`@("`@("!C87-E("=054),25-()SH*("`@("`@("`@("`@)')E<75I<F5D
M071T<FEB=71E<ULG1%135$%25"==(#T@=&EM92@I.PH@("`@("`@("`@("`D
M<F5Q=6ER961!='1R:6)U=&5S6R=354U-05)9)UT@/2`G)SL*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&-A<V4@)U)%455%4U0G.@H@("`@("`@("`@
M("`D<F5Q=6ER961!='1R:6)U=&5S6R=!5%1%3D1%12==(#T@)R<["B`@("`@
M("`@("`@("1R97%U:7)E9$%T=')I8G5T97-;)T144U1!4E0G72`]('1I;64H
M*3L*("`@("`@("`@("`@)')E<75I<F5D071T<FEB=71E<ULG4U5-34%262==
M(#T@)R<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=215!,
M62<Z"B`@("`@("`@("`@("1R97%U:7)E9$%T=')I8G5T97-;)T%45$5.1$5%
M)UT@/2`G)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)T%$
M1"<Z"B`@("`@("`@("`@("1R97%U:7)E9$%T=')I8G5T97-;)T144U1!4E0G
M72`]('1I;64H*3L*("`@("`@("`@("`@)')E<75I<F5D071T<FEB=71E<ULG
M4T51545.0T4G72`](#$["B`@("`@("`@("`@("1R97%U:7)E9$%T=')I8G5T
M97-;)U-534U!4EDG72`]("<G.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@8V%S92`G0T%.0T5,)SH*("`@("`@("`@("`@)')E<75I<F5D071T<FEB
M=71E<ULG051414Y$144G72`]("<G.PH@("`@("`@("`@("`D<F5Q=6ER961!
M='1R:6)U=&5S6R=315%514Y#12==(#T@,3L*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&-A<V4@)U)%1E)%4T@G.@H@("`@("`@("`@("`D<F5Q=6ER
M961!='1R:6)U=&5S6R=!5%1%3D1%12==(#T@)R<["B`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)')E<75I<F5D071T
M<FEB=71E<R!A<R`D;F%M92`]/B`D9&5F875L=%]V86QU92D@>PH@("`@("`@
M("`@("!I9B`H:7-?82@D=&AI<RT^9V5T071T<FEB=71E*"1N86UE*2P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$%T=')I
M8G5T92@D;F%M92P@)&1E9F%U;'1?=F%L=64I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@<&%R96YT.CI?97AP;W)T=D1A=&$H
M)U9%5D5.5"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@57!D871E('1H92!S
M=&%T=7,@;V8@86X@871T96YD964@;V8@86X@979E;G0N"B`@("`@*@H@("`@
M("H@0'!A<F%M("1E;6%I;"`@("!4:&4@96UA:6P@861D<F5S<R!O9B!T:&4@
M871T96YD964N"B`@("`@*B!`<&%R86T@)'-T871U<R`@(%1H92!P87)T:6-I
M<&%N="!S=&%T=7,@=&\@<V5T+@H@("`@("H@0'!A<F%M("1F=6QL;F%M92!4
M:&4@9G5L;"!N86UE(&]F('1H92!P87)T:6-I<&%N="!T;R!S970N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('5P9&%T94%T=&5N9&5E*"1E;6%I;"P@)'-T871U
M<RP@)&9U;&QN86UE(#T@)R<I"B`@("!["B`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/E]A='1R:6)U=&5S(&%S("1K97D@/3X@)&%T=')I8G5T92D@>PH@("`@
M("`@("`@("!I9B`H)&%T=')I8G5T95LG;F%M92==(#T]("=!5%1%3D1%12<@
M)B8@)&%T=')I8G5T95LG=F%L=64G72`]/2`G34%)3%1/.B<@+B`D96UA:6PI
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?871T<FEB=71E<ULD:V5Y75LG
M<&%R86US)UU;)U!!4E135$%4)UT@/2`D<W1A='5S.PH@("`@("`@("`@("`@
M("`@:68@*"%E;7!T>2@D9G5L;&YA;64I*2!["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]A='1R:6)U=&5S6R1K97E=6R=P87)A;7,G75LG0TXG72`]
M("1F=6QL;F%M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('5N<V5T*"1T:&ES+3Y?871T<FEB=71E<ULD:V5Y75LG<&%R86US)UU;)U)3
M5E`G72D["B`@("`@("`@("`@("`@("!R971U<FX["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"=005)44U1!5"<@
M/3X@)'-T871U<RD["B`@("`@("`@:68@*"%E;7!T>2@D9G5L;&YA;64I*2![
M"B`@("`@("`@("`@("1P87)A;7-;)T-.)UT@/2`D9G5L;&YA;64["B`@("`@
M("`@?0H@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)T%45$5.1$5%)RP@
M)TU!24Q43SHG("X@)&5M86EL+"`D<&%R86US*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;B!T:&4@;W)G86YI>F5R(&1I<W!L87D@;F%M92!O<B!E
M;6%I;"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&]R9V%N
M:7IE<B!N86UE('1O(&1I<W!L87D@9F]R('1H:7,@979E;G0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&]R9V%N:7IE<DYA;64H*0H@("`@>PH@("`@("`@("1O
M<F=A;FEZ97(@/2`D=&AI<RT^9V5T071T<FEB=71E*"=/4D=!3DE:15(G+"!T
M<G5E*3L*("`@("`@("!I9B`H:7-?82@D;W)G86YI>F5R+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*"B`@
M("`@("`@:68@*&ES<V5T*"1O<F=A;FEZ97);,%U;)T-.)UTI*2!["B`@("`@
M("`@("`@(')E='5R;B`D;W)G86YI>F5R6S!=6R=#3B==.PH@("`@("`@('T*
M"B`@("`@("`@)&]R9V%N:7IE<B`]('!A<G-E7W5R;"@D=&AI<RT^9V5T071T
M<FEB=71E*"=/4D=!3DE:15(G*2D["@H@("`@("`@(')E='5R;B`D;W)G86YI
M>F5R6R=P871H)UT["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<&1A=&4@=&AI
M<R!E=F5N="!W:71H(&1E=&%I;',@9G)O;2!A;F]T:&5R(&5V96YT+@H@("`@
M("H*("`@("`J($!P87)A;2!(;W)D95]I0V%L96YD87)?=D5V96YT("1V979E
M;G0@(%1H92!V179E;G0@=VET:"!L871E<W0@9&5T86EL<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@=7!D871E1G)O;79%=F5N="@D=F5V96YT*0H@("`@>PH@
M("`@("`@("1N97=!='1R:6)U=&5S(#T@)'9E=F5N="T^9V5T06QL071T<FEB
M=71E<R@I.PH@("`@("`@(&9O<F5A8V@@*"1N97=!='1R:6)U=&5S(&%S("1N
M97=!='1R:6)U=&4I('L*("`@("`@("`@("`@)&-U<G)E;G1686QU92`]("1T
M:&ES+3YG971!='1R:6)U=&4H)&YE=T%T=')I8G5T95LG;F%M92==*3L*("`@
M("`@("`@("`@:68@*&ES7V$H)&-U<G)E;G1686QU92P@)U!%05)?97)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@+R\@06QR96%D>2!E>&ES=',@<V\@:G5S
M="!A9&0@:70N"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E
M*"1N97=!='1R:6)U=&5;)VYA;64G72P@)&YE=T%T=')I8G5T95LG=F%L=64G
M72P@)&YE=T%T=')I8G5T95LG<&%R86US)UTI.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@+R\@06QR96%D>2!E>&ES=',@<V\@;&]C
M871E(&%N9"!M;V1I9GDN"B`@("`@("`@("`@("`@("`D9F]U;F0@/2!F86QS
M93L*"B`@("`@("`@("`@("`@("`O+R!4<GD@;6%T8VAI;F<@=&AE(&%T=')I
M8G1E(&YA;64@86YD('9A;'5E(&EN8V%S90H@("`@("`@("`@("`@("`@+R\@
M;VYL>2!T:&4@<&%R86US(&-H86YG960@*&5G(&%T=&5N9&5E('5P9&%T:6YG
M"B`@("`@("`@("`@("`@("`O+R!S=&%T=7,I+@H@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]A='1R:6)U=&5S(&%S("1I9"`]/B`D871T<BD@
M>PH@("`@("`@("`@("`@("`@("`@(&EF("@D871T<ELG;F%M92==(#T]("1N
M97=!='1R:6)U=&5;)VYA;64G72`F)@H@("`@("`@("`@("`@("`@("`@("`@
M("`D871T<ELG=F%L=64G72`]/2`D;F5W071T<FEB=71E6R=V86QU92==*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("\O(&UE<F=E('1H92!P87)A;7,*
M("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&YE=T%T=')I8G5T
M95LG<&%R86US)UT@87,@)'!A<F%M7VED(#T^("1P87)A;5]N86UE*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%T=')I8G5T97-;
M)&ED75LG<&%R86US)UU;)'!A<F%M7VED72`]("1P87)A;5]N86UE.PH@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@
M("1F;W5N9"`]('1R=64["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&EF("@A)&9O=6YD*2!["B`@("`@("`@("`@("`@("`@
M("`@+R\@16QS92!M871C:"!T:&4@9FER<W0@871T<FEB=71E('=I=&@@=&AE
M('-A;64*("`@("`@("`@("`@("`@("`@("`O+R!N86UE("AE9R!C:&%N9VEN
M9R!S=&%R="!T:6UE*2X*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M=&AI<RT^7V%T=')I8G5T97,@87,@)&ED(#T^("1A='1R*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@D871T<ELG;F%M92==(#T]("1N97=!='1R
M:6)U=&5;)VYA;64G72D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]A='1R:6)U=&5S6R1I9%U;)W9A;'5E)UT@/2`D;F5W071T<FEB
M=71E6R=V86QU92==.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M365R9V4@=&AE('!A<F%M<RX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1N97=!='1R:6)U=&5;)W!A<F%M<R==(&%S("1P87)A;5]I
M9"`]/B`D<&%R86U?;F%M92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?871T<FEB=71E<ULD:61=6R=P87)A;7,G75LD<&%R
M86U?:61=(#T@)'!A<F%M7VYA;64["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J(%5P9&%T92!J=7-T('1H92!A='1E;F1E<W,@
M;V8@979E;G0@=VET:"!D971A:6QS(&9R;VT@86YO=&AE<@H@("`@("H@979E
M;G0N"B`@("`@*@H@("`@("H@0'!A<F%M($AO<F1E7VE#86QE;F1A<E]V179E
M;G0@)'9E=F5N="`@5&AE('9%=F5N="!W:71H(&QA=&5S="!D971A:6QS"B`@
M("`@*B\*("`@(&9U;F-T:6]N('5P9&%T94%T=&5N9&5E<T9R;VUV179E;G0H
M)'9E=F5N="D*("`@('L*("`@("`@("`D;F5W071T<FEB=71E<R`]("1V979E
M;G0M/F=E=$%L;$%T=')I8G5T97,H*3L*("`@("`@("!F;W)E86-H("@D;F5W
M071T<FEB=71E<R!A<R`D;F5W071T<FEB=71E*2!["B`@("`@("`@("`@(&EF
M("@D;F5W071T<FEB=71E6R=N86UE)UT@(3T@)T%45$5.1$5%)RD@>PH@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)&-U<G)E;G1686QU92`]("1T:&ES+3YG971!='1R:6)U=&4H)&YE=T%T
M=')I8G5T95LG;F%M92==*3L*("`@("`@("`@("`@:68@*&ES7V$H)&-U<G)E
M;G1686QU92P@)U!%05)?97)R;W(G*2D@>PH@("`@("`@("`@("`@("`@+R\@
M06QR96%D>2!E>&ES=',@<V\@:G5S="!A9&0@:70N"B`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5T071T<FEB=71E*"1N97=!='1R:6)U=&5;)VYA;64G72P@
M)&YE=T%T=')I8G5T95LG=F%L=64G72P@)&YE=T%T=')I8G5T95LG<&%R86US
M)UTI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@
M06QR96%D>2!E>&ES=',@<V\@;&]C871E(&%N9"!M;V1I9GDN"B`@("`@("`@
M("`@("`@("`D9F]U;F0@/2!F86QS93L*("`@("`@("`@("`@("`@("\O(%1R
M>2!M871C:&EN9R!T:&4@871T<FEB=&4@;F%M92!A;F0@=F%L=64@:6YC87-E
M"B`@("`@("`@("`@("`@("`O+R!O;FQY('1H92!P87)A;7,@8VAA;F=E9"`H
M96<@871T96YD964@=7!D871I;F<*("`@("`@("`@("`@("`@("\O('-T871U
M<RDN"B`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7V%T=')I8G5T
M97,@87,@)&ED(#T^("1A='1R*2!["B`@("`@("`@("`@("`@("`@("`@:68@
M*"1A='1R6R=N86UE)UT@/3T@)&YE=T%T=')I8G5T95LG;F%M92==("8F"B`@
M("`@("`@("`@("`@("`@("`@("`@("1A='1R6R=V86QU92==(#T]("1N97=!
M='1R:6)U=&5;)W9A;'5E)UTI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M+R\@365R9V4@=&AE('!A<F%M<RX*("`@("`@("`@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)&YE=T%T=')I8G5T95LG<&%R86US)UT@87,@)'!A<F%M7VED
M(#T^("1P87)A;5]N86UE*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V%T=')I8G5T97-;)&ED75LG<&%R86US)UU;)'!A<F%M7VED
M72`]("1P87)A;5]N86UE.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@("`@("1F;W5N9"`]('1R=64["B`@("`@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H(21F;W5N
M9"D@>PH@("`@("`@("`@("`@("`@("`@("\O($5L<V4@;6%T8V@@=&AE(&9I
M<G-T(&%T=')I8G5T92!W:71H('1H92!S86UE"B`@("`@("`@("`@("`@("`@
M("`@+R\@;F%M92`H96<@8VAA;F=I;F<@<W1A<G0@=&EM92DN"B`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]A='1R:6)U=&5S(&%S("1I
M9"`]/B`D871T<BD@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&%T
M=');)VYA;64G72`]/2`D;F5W071T<FEB=71E6R=N86UE)UTI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?871T<FEB=71E<ULD:61=
M6R=V86QU92==(#T@)&YE=T%T=')I8G5T95LG=F%L=64G73L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O($UE<F=E('1H92!P87)A;7,N"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D;F5W071T<FEB=71E
M6R=P87)A;7,G72!A<R`D<&%R86U?:60@/3X@)'!A<F%M7VYA;64I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%T=')I8G5T
M97-;)&ED75LG<&%R86US)UU;)'!A<F%M7VED72`]("1P87)A;5]N86UE.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]I
M0V%L96YD87(O=F9R965B=7-Y+G!H<```````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,C,V-#$`,3`U,34T,S,W-3$`,#(T,#<V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!#;&%S<R!R
M97!R97-E;G1I;F<@=D9R965B=7-Y(&-O;7!O;F5N=',N"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+VE#86QE;F1A<B]I0V%L96YD87(O=F9R965B=7-Y+G!H
M<"QV(#$N,38N,3`N.2`R,#`V+S`R+S`V(#$W.C4S.C,Y(&UR=6)I;G-K($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EK92!#;V-H<F%N92`\
M;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^
M"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]I0V%L
M96YD87(*("HO"F-L87-S($AO<F1E7VE#86QE;F1A<E]V9G)E96)U<WD@97AT
M96YD<R!(;W)D95]I0V%L96YD87(@>PH*("`@('9A<B`D7V)U<WE097)I;V1S
M(#T@87)R87DH*3L*"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@
M("`@("!R971U<FX@)W9&<F5E8G5S>2<["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!087)S97,@82!S=')I;F<@8V]N=&%I;FEN9R!V1G)E96)U<WD@9&%T82X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("`@("!4:&4@9&%T
M82!T;R!P87)S92X*("`@("`J+PH@("`@9G5N8W1I;VX@<&%R<V5V0V%L96YD
M87(H)&1A=&$I"B`@("!["B`@("`@("`@<&%R96YT.CIP87)S979#86QE;F1A
M<B@D9&%T82P@)U9&4D5%0E5362<I.PH*("`@("`@("`O+R!$;R!S;VUE=&AI
M;F<@=VET:"!A;&P@=&AE(&)U<WD@<&5R:6]D<RX*("`@("`@("!F;W)E86-H
M("@D=&AI<RT^7V%T=')I8G5T97,@87,@)&ME>2`]/B`D871T<FEB=71E*2![
M"B`@("`@("`@("`@(&EF("@D871T<FEB=71E6R=N86UE)UT@/3T@)T92145"
M55-9)RD@>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&%T=')I8G5T95LG
M=F%L=65S)UT@87,@)'9A;'5E*2!["B`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1V86QU95LG9'5R871I;VXG72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^861D0G5S>5!E<FEO9"@G0E5362<L("1V86QU95LG
M<W1A<G0G72P@;G5L;"P@)'9A;'5E6R=D=7)A=&EO;B==*3L*("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YA9&1"=7-Y4&5R:6]D*"="55-9)RP@)'9A;'5E6R=S=&%R="==+"`D
M=F%L=65;)V5N9"==*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^7V%T=')I
M8G5T97-;)&ME>5TI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*
M("`@(&9U;F-T:6]N(&5X<&]R='9#86QE;F1A<B@I"B`@("!["B`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]B=7-Y4&5R:6]D<R!A<R`D<W1A<G0@/3X@)&5N
M9"D@>PH@("`@("`@("`@("`D<&5R:6]D<R`](&%R<F%Y*&%R<F%Y*"=S=&%R
M="<@/3X@)'-T87)T+"`G96YD)R`]/B`D96YD*2D["B`@("`@("`@("`@("1T
M:&ES+3YS971!='1R:6)U=&4H)T92145"55-9)RP@)'!E<FEO9',I.PH@("`@
M("`@('T*"B`@("`@("`@)')E<R`]('!A<F5N=#HZ7V5X<&]R='9$871A*"=6
M1E)%14)54UDG*3L*"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]A='1R:6)U
M=&5S(&%S("1K97D@/3X@)&%T=')I8G5T92D@>PH@("`@("`@("`@("!I9B`H
M)&%T=')I8G5T95LG;F%M92==(#T]("=&4D5%0E5362<I('L*("`@("`@("`@
M("`@("`@('5N<V5T*"1T:&ES+3Y?871T<FEB=71E<ULD:V5Y72D["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&1I<W!L87D@;F%M92!F;W(@
M=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($$@
M8VQE87(@=&5X="!N86UE(&9O<B!D:7-P;&%Y:6YG('1H:7,@;V)J96-T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971.86UE*"D*("`@('L*("`@("`@("`D
M;F%M92`]("<G.PH@("`@("`@("1M971H;V0@/2`A96UP='DH)'1H:7,M/E]C
M;VYT86EN97(I(#\*("`@("`@("`@("`@)'1H:7,M/E]C;VYT86EN97(M/F=E
M=$%T=')I8G5T92@G34542$]$)RD@.B`G4%5"3$E32"<["@H@("`@("`@(&EF
M("AI<U]A*"1M971H;V0L("=014%27T5R<F]R)RD@?'P@)&UE=&AO9"`]/2`G
M4%5"3$E32"<I('L*("`@("`@("`@("`@)&%T='(@/2`G3U)'04Y)6D52)SL*
M("`@("`@("!](&5L<V5I9B`H)&UE=&AO9"`]/2`G4D503%DG*2!["B`@("`@
M("`@("`@("1A='1R(#T@)T%45$5.1$5%)SL*("`@("`@("!]"@H@("`@("`@
M("1N86UE(#T@)'1H:7,M/F=E=$%T=')I8G5T92@D871T<BP@=')U92D["B`@
M("`@("`@:68@*&ES<V5T*"1N86UE6S!=6R=#3B==*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&YA;65;,%U;)T-.)UT["B`@("`@("`@?0H*("`@("`@("`D
M;F%M92`]("1T:&ES+3YG971!='1R:6)U=&4H)&%T='(I.PH@("`@("`@(&EF
M("AI<U]A*"1N86UE+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`G)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;F%M92`]
M('!A<G-E7W5R;"@D;F%M92D["B`@("`@("`@("`@(')E='5R;B`D;F%M95LG
M<&%T:"==.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE(&5M86EL(&%D9')E<W,@9F]R('1H:7,@;V)J96-T+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@96UA:6P@861D<F5S<R!O9B!T
M:&ES(&]B:F5C="=S(&]W;F5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971%
M;6%I;"@I"B`@("!["B`@("`@("`@)&YA;64@/2`G)SL*("`@("`@("`D;65T
M:&]D(#T@(65M<'1Y*"1T:&ES+3Y?8V]N=&%I;F5R*0H@("`@("`@("`@("`@
M("`@("`_("1T:&ES+3Y?8V]N=&%I;F5R+3YG971!='1R:6)U=&4H)TU%5$A/
M1"<I(#H@)U!50DQ)4T@G.PH*("`@("`@("!I9B`H:7-?82@D;65T:&]D+"`G
M4$5!4E]%<G)O<B<I('Q\("1M971H;V0@/3T@)U!50DQ)4T@G*2!["B`@("`@
M("`@("`@("1A='1R(#T@)T]21T%.25I%4B<["B`@("`@("`@?2!E;'-E:68@
M*"1M971H;V0@/3T@)U)%4$Q9)RD@>PH@("`@("`@("`@("`D871T<B`]("=!
M5%1%3D1%12<["B`@("`@("`@?0H*("`@("`@("`D;F%M92`]("1T:&ES+3YG
M971!='1R:6)U=&4H)&%T='(I.PH@("`@("`@(&EF("AI<U]A*"1N86UE+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D;F%M92`]('!A<G-E7W5R;"@D;F%M
M92D["B`@("`@("`@("`@(')E='5R;B`D;F%M95LG<&%T:"==.PH@("`@("`@
M('T*("`@('T*"B`@("!F=6YC=&EO;B!G971"=7-Y4&5R:6]D<R@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8G5S>5!E<FEO9',["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&%L;"!T:&4@9G)E92!P97)I;V1S(&]F
M('1I;64@:6X@82!G:79E;B!P97)I;V0N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'-T87)T4W1A;7`@(%1H92!S=&%R="!T:6UE<W1A;7`N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D96YD4W1A;7`@("`@5&AE(&5N9"!T:6UE
M<W1A;7`N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!H87-H('=I
M=&@@9G)E92!T:6UE('!E<FEO9',L('1H92!S=&%R="!T:6UE<R!A<R!T:&4*
M("`@("`J("`@("`@("`@("`@("`@(&ME>7,@86YD('1H92!E;F0@=&EM97,@
M87,@=&AE('9A;'5E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1G)E95!E
M<FEO9',H)'-T87)T4W1A;7`L("1E;F13=&%M<"D*("`@('L*("`@("`@("`D
M=&AI<RT^<VEM<&QI9GDH*3L*("`@("`@("`D<&5R:6]D<R`](&%R<F%Y*"D[
M"@H@("`@("`@("\O($-H96-K('1H870@=V4@:&%V92!D871A(&9O<B!S;VUE
M('!A<G0@;V8@=&AI<R!P97)I;V0N"B`@("`@("`@:68@*"1T:&ES+3YG971%
M;F0H*2`\("1S=&%R=%-T86UP('Q\("1T:&ES+3YG9713=&%R="@I(#X@)&5N
M9%-T86UP*2!["B`@("`@("`@("`@(')E='5R;B`D<&5R:6]D<SL*("`@("`@
M("!]"@H@("`@("`@("\O($QO8V%T92!T:&4@9FER<W0@=&EM92!I;B!T:&4@
M<F5Q=65S=&5D('!E<FEO9"!W92!H879E(&1A=&$@9F]R+@H@("`@("`@("1N
M97AT<W1A<G0@/2!M87@H)'-T87)T4W1A;7`L("1T:&ES+3YG9713=&%R="@I
M*3L*"B`@("`@("`@+R\@0VAE8VL@96%C:"!B=7-Y('!E<FEO9"!A;F0@861D
M(&9R964@<&5R:6]D<R!I;B!B971W965N+@H@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3Y?8G5S>5!E<FEO9',@87,@)'-T87)T(#T^("1E;F0I('L*("`@("`@
M("`@("`@:68@*"1S=&%R="`\/2`D96YD4W1A;7`@)B8@)&5N9"`^/2`D;F5X
M='-T87)T*2!["B`@("`@("`@("`@("`@("!I9B`H)&YE>'1S=&%R="`\/2`D
M<W1A<G0I('L*("`@("`@("`@("`@("`@("`@("`D<&5R:6]D<ULD;F5X='-T
M87)T72`](&UI;B@D<W1A<G0L("1E;F13=&%M<"D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D;F5X='-T87)T(#T@;6EN*"1E;F0L("1E
M;F13=&%M<"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O
M($EF('=E(&1I9&XG="!R96%D('1H92!E;F0@;V8@=&AE(')E<75E<W1E9"!P
M97)I;V0@8G5T('-T:6QL(&AA=F4*("`@("`@("`O+R!D871A('1H96X@;6%R
M:R!A<R!F<F5E('1O('1H92!E;F0@;V8@=&AE('!E<FEO9"!O<B!A=F%I;&%B
M;&4@9&%T82X*("`@("`@("!I9B`H)&YE>'1S=&%R="`\("1E;F13=&%M<"`F
M)B`D;F5X='-T87)T(#P@)'1H:7,M/F=E=$5N9"@I*2!["B`@("`@("`@("`@
M("1P97)I;V1S6R1N97AT<W1A<G1=(#T@;6EN*"1T:&ES+3YG971%;F0H*2P@
M)&5N9%-T86UP*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<&5R:6]D
M<SL*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@82!B=7-Y('!E<FEO9"!T
M;R!T:&4@:6YF;RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E
M("`@("`@(%1H92!T>7!E(&]F('1H92!P97)I;V0N($5I=&AE<B`G1E)%12<@
M;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@)T)54UDG.R!O
M;FQY("="55-9)R!S=7!P;W)T960@870@=&AE(&UO;65N="X*("`@("`J($!P
M87)A;2!I;G1E9V5R("1S=&%R="`@("`@5&AE('-T87)T('1I;65S=&%M<"!O
M9B!T:&4@<&5R:6]D+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&5N9"`@("`@
M("!4:&4@96YD('1I;65S=&%M<"!O9B!T:&4@<&5R:6]D+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&1U<F%T:6]N("!4:&4@9'5R871I;VX@;V8@=&AE('!E
M<FEO9"X@268@<W!E8VEF:65D+"!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&5N9"!P87)A;65T97(@=VEL;"!B92!I9VYO<F5D+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!A9&1"=7-Y4&5R:6]D*"1T>7!E+"`D<W1A
M<G0L("1E;F0@/2!N=6QL+"`D9'5R871I;VX@/2!N=6QL*0H@("`@>PH@("`@
M("`@(&EF("@D='EP92`]/2`G1E)%12<I('L*("`@("`@("`@("`@+R\@36%K
M92!S=7)E('1H:7,@<&5R:6]D(&ES(&YO="!M87)K960@87,@8G5S>2X*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+R\@
M0V%L8W5L871E('1H92!E;F0@=&EM92!I9B!D=7)A=&EO;B!W87,@<W!E8VEF
M:65D+@H@("`@("`@("1T96UP16YD(#T@:7-?;G5L;"@D9'5R871I;VXI(#\@
M)&5N9"`Z("1S=&%R="`K("1D=7)A=&EO;CL*"B`@("`@("`@+R\@36%K92!S
M=7)E('1H92!P97)I;V0@;&5N9W1H(&ES(&%L=V%Y<R!P;W-I=&EV92X*("`@
M("`@("`D96YD(#T@;6%X*"1S=&%R="P@)'1E;7!%;F0I.PH@("`@("`@("1S
M=&%R="`](&UI;B@D<W1A<G0L("1T96UP16YD*3L*"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?8G5S>5!E<FEO9'-;)'-T87)T72DI('L*("`@("`@("`@
M("`@+R\@06QR96%D>2!A('!E<FEO9"!S=&%R=&EN9R!A="!T:&ES('1I;64N
M($5X=&5N9"!T;R!T:&4@;&5N9W1H(&]F"B`@("`@("`@("`@("\O('1H92!L
M;VYG97-T(&]F('1H92!T=V\N"B`@("`@("`@("`@("1T:&ES+3Y?8G5S>5!E
M<FEO9'-;)'-T87)T72`](&UA>"@D96YD+"`D=&AI<RT^7V)U<WE097)I;V1S
M6R1S=&%R=%TI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O($%D
M9"!A(&YE=R!B=7-Y('!E<FEO9"X*("`@("`@("`@("`@)'1H:7,M/E]B=7-Y
M4&5R:6]D<ULD<W1A<G1=(#T@)&5N9#L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M=&EM97-T86UP(&]F('1H92!S=&%R="!O9B!T:&4@=&EM92!P97)I;V0@=&AI
M<R!F<F5E(&)U<WD*("`@("`J(&EN9F]R;6%T:6]N(&-O=F5R<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@($$@=&EM97-T86UP+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G9713=&%R="@I"B`@("!["B`@("`@("`@:68@*"%I
M<U]A*"1T:&ES+3YG971!='1R:6)U=&4H)T144U1!4E0G*2P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F=E=$%T=')I8G5T
M92@G1%135$%25"<I.PH@("`@("`@('T@96QS96EF("AC;W5N="@D=&AI<RT^
M7V)U<WE097)I;V1S*2D@>PH@("`@("`@("`@("!R971U<FX@;6EN*&%R<F%Y
M7VME>7,H)'1H:7,M/E]B=7-Y4&5R:6]D<RDI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!T:6UE<W1A;7`@;V8@=&AE(&5N
M9"!O9B!T:&4@=&EM92!P97)I;V0@=&AI<R!F<F5E(&)U<WD*("`@("`J(&EN
M9F]R;6%T:6]N(&-O=F5R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G
M97(@($$@=&EM97-T86UP+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971%;F0H
M*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D=&AI<RT^9V5T071T<FEB=71E
M*"=$5$5.1"<I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^9V5T071T<FEB=71E*"=$5$5.1"<I.PH@("`@("`@('T@96QS
M96EF("AC;W5N="@D=&AI<RT^7V)U<WE097)I;V1S*2D@>PH@("`@("`@("`@
M("!R971U<FX@;6%X*&%R<F%Y7W9A;'5E<R@D=&AI<RT^7V)U<WE097)I;V1S
M*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($UE<F=E<R!T:&4@
M8G5S>2!P97)I;V1S(&]F(&%N;W1H97(@2&]R9&5?:4-A;&5N9&%R7W9F<F5E
M8G5S>2!O8FIE8W0@:6YT;PH@("`@("H@=&AI<R!O;F4N"B`@("`@*@H@("`@
M("H@0'!A<F%M($AO<F1E7VE#86QE;F1A<E]V9G)E96)U<WD@)&9R965B=7-Y
M("!!(&9R965B=7-Y(&]B:F5C="X*("`@("`J($!P87)A;2!B;V]L96%N("1S
M:6UP;&EF>2`@("`@("`@("`@("`@("`@("`@268@=')U92P@<VEM<&QI9GDH
M*2!W:6QL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&-A;&QE9"!A9G1E<B!T:&4@;65R9V4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&UE<F=E*"1F<F5E8G5S>2P@)'-I;7!L:69Y(#T@=')U
M92D*("`@('L*("`@("`@("!I9B`H(6ES7V$H)&9R965B=7-Y+"`G2&]R9&5?
M:4-A;&5N9&%R7W9F<F5E8G5S>2<I*2!["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1F<F5E8G5S>2T^
M9V5T0G5S>5!E<FEO9',H*2!A<R`D<W1A<G0@/3X@)&5N9"D@>PH@("`@("`@
M("`@("`D=&AI<RT^861D0G5S>5!E<FEO9"@G0E5362<L("1S=&%R="P@)&5N
M9"D["B`@("`@("`@?0H*("`@("`@("`D=&AI<V%T='(@/2`D=&AI<RT^9V5T
M071T<FEB=71E*"=$5%-405)4)RD["B`@("`@("`@)'1H871A='1R(#T@)&9R
M965B=7-Y+3YG971!='1R:6)U=&4H)T144U1!4E0G*3L*("`@("`@("!I9B`H
M:7-?82@D=&AI<V%T='(L("=014%27T5R<F]R)RD@)B8@(6ES7V$H)'1H871A
M='1R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1T:&ES+3YS971!
M='1R:6)U=&4H)T144U1!4E0G+"`D=&AA=&%T='(I.PH@("`@("`@('T@96QS
M96EF("@A:7-?82@D=&AA=&%T='(L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@:68@*"1T:&%T871T<B`^("1T:&ES871T<BD@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$%T=')I8G5T92@G1%135$%25"<L("1T:&%T871T
M<BD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1T:&ES871T
M<B`]("1T:&ES+3YG971!='1R:6)U=&4H)T1414Y$)RD["B`@("`@("`@)'1H
M871A='1R(#T@)&9R965B=7-Y+3YG971!='1R:6)U=&4H)T1414Y$)RD["B`@
M("`@("`@:68@*&ES7V$H)'1H:7-A='1R+"`G4$5!4E]%<G)O<B<I("8F("%I
M<U]A*"1T:&%T871T<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^<V5T071T<FEB=71E*"=$5$5.1"<L("1T:&%T871T<BD["B`@("`@
M("`@?2!E;'-E:68@*"%I<U]A*"1T:&%T871T<BP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!I9B`H)'1H871A='1R(#P@)'1H:7-A='1R*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E*"=$5$5.1"<L("1T
M:&%T871T<BD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF
M("@D<VEM<&QI9GDI('L*("`@("`@("`@("`@)'1H:7,M/G-I;7!L:69Y*"D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E;6]V97,@86QL(&]V97)L87!S(&%N9"!S:6UP;&EF:65S
M('1H92!B=7-Y('!E<FEO9',@87)R87D@87,@;75C:"!A<PH@("`@("H@<&]S
M<VEB;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-I;7!L:69Y*"D*("`@('L*
M("`@("`@("`D8VAE8VME9"`](&%R<F%Y*"D["B`@("`@("`@)&-H96-K961%
M;7!T>2`]('1R=64["@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?8G5S>5!E
M<FEO9',@87,@)'-T87)T(#T^("1E;F0I('L*("`@("`@("`@("`@:68@*"1C
M:&5C:V5D16UP='DI('L*("`@("`@("`@("`@("`@("1C:&5C:V5D6R1S=&%R
M=%T@/2`D96YD.PH@("`@("`@("`@("`@("`@)&-H96-K961%;7!T>2`](&9A
M;'-E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&%D
M9&5D(#T@9F%L<V4["B`@("`@("`@("`@("`@("!F;W)E86-H("@D8VAE8VME
M9"!A<R`D=&5S=%-T87)T(#T^("1T97-T16YD*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*"1S=&%R="`]/2`D=&5S=%-T87)T*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1C:&5C:V5D6R1T97-T4W1A<G1=(#T@;6%X*"1T97-T
M16YD+"`D96YD*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&%D9&5D(#T@
M=')U93L*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&5N9"`\/2`D
M=&5S=$5N9"`F)B`D96YD(#X]("1T97-T4W1A<G0I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@=6YS970H)&-H96-K961;)'1E<W13=&%R=%TI.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D8VAE8VME9%MM:6XH)'1E<W13=&%R="P@
M)'-T87)T*5T@/2!M87@H)'1E<W1%;F0L("1E;F0I.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D861D960@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("!I9B`H)&%D9&5D*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@A)&%D9&5D
M*2!["B`@("`@("`@("`@("`@("`@("`@)&-H96-K961;)'-T87)T72`]("1E
M;F0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(&MS;W)T*"1C:&5C:V5D+"!33U)47TY5345224,I.PH@("`@
M("`@("1T:&ES+3Y?8G5S>5!E<FEO9',@/2`D8VAE8VME9#L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]I0V%L
M96YD87(O=FIO=7)N86PN<&AP````````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#$T,3$`,3`U,34T,S,W-3$`,#(S-S$S`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!#;&%S<R!R97!R
M97-E;G1I;F<@=DIO=7)N86QS+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]I
M0V%L96YD87(O:4-A;&5N9&%R+W9J;W5R;F%L+G!H<"QV(#$N."XQ,"XT(#(P
M,#8O,#$O,#$@,C$Z,C@Z-#<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`S+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN
M>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@
M/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#,N
M,`H@*B!`<&%C:V%G92!(;W)D95]I0V%L96YD87(*("HO"F-L87-S($AO<F1E
M7VE#86QE;F1A<E]V:F]U<FYA;"!E>'1E;F1S($AO<F1E7VE#86QE;F1A<B![
M"@H@("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N
M("=V2F]U<FYA;"<["B`@("!]"@H@("`@9G5N8W1I;VX@<&%R<V5V0V%L96YD
M87(H)&1A=&$I"B`@("!["B`@("`@("`@<&%R96YT.CIP87)S979#86QE;F1A
M<B@D9&%T82P@)U9*3U523D%,)RD["B`@("!]"@H@("`@9G5N8W1I;VX@97AP
M;W)T=D-A;&5N9&%R*"D*("`@('L*("`@("`@("!R971U<FX@<&%R96YT.CI?
M97AP;W)T=D1A=&$H)U9*3U523D%,)RD["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]I0V%L96YD87(O=FYO=&4N<&AP````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(T-C(`,3`U,34T,S,W-3$`,#(S,C$U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N
M8V4@)TAO<F1E+VE#86QE;F1A<BYP:'`G.PH*+RHJ"B`J($-L87-S(')E<')E
M<V5N=&EN9R!V3F]T97,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+VE#86QE
M;F1A<B]I0V%L96YD87(O=FYO=&4N<&AP+'8@,2XS+C$P+C4@,C`P-B\P,R\P
M,R`P.3HP-SHS,2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P
M-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2V%R<W1E;B!&;W5R;6]N="`\9F]U
M<FUO;G1`9VUX+F1E/@H@*B!`<&%C:V%G92!(;W)D95]I0V%L96YD87(*("HO
M"F-L87-S($AO<F1E7VE#86QE;F1A<E]V;F]T92!E>'1E;F1S($AO<F1E7VE#
M86QE;F1A<B!["@H@("`@9G5N8W1I;VX@2&]R9&5?:4-A;&5N9&%R7W9N;W1E
M*"1V97)S:6]N(#T@)S$N,2<I"B`@("!["B`@("`@("`@<F5T=7)N('!A<F5N
M=#HZ2&]R9&5?:4-A;&5N9&%R*"1V97)S:6]N*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)W9.;W1E)SL*
M("`@('T*"B`@("!F=6YC=&EO;B!P87)S979#86QE;F1A<B@D9&%T82D*("`@
M('L*("`@("`@("!R971U<FX@<&%R96YT.CIP87)S979#86QE;F1A<B@D9&%T
M82P@)U9.3U1%)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5;FQI:V4@=F5V
M96YT(&%N9"!V=&]D;RP@82!V;F]T92!I<R!N;W)M86QL>2!N;W0@96YC;&]S
M960@:6X@86X*("`@("`J(&E#86QE;F1A<B!C;VYT86EN97(N("A"14=)3BXN
M14Y$*0H@("`@("HO"B`@("!F=6YC=&EO;B!E>'!O<G1V0V%L96YD87(H*0H@
M("`@>PH@("`@("`@("1R97%U:7)E9$%T=')I8G5T97-;)T)/1%DG72`]("<G
M.PH@("`@("`@("1R97%U:7)E9$%T=')I8G5T97-;)U9%4E-)3TXG72`]("<Q
M+C$G.PH*("`@("`@("!F;W)E86-H("@D<F5Q=6ER961!='1R:6)U=&5S(&%S
M("1N86UE(#T^("1D969A=6QT7W9A;'5E*2!["B`@("`@("`@("`@(&EF("AI
M<U]A*"1T:&ES+3YG971A='1R:6)U=&4H)&YA;64I+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E*"1N86UE
M+"`D9&5F875L=%]V86QU92D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=&AI<RT^7V5X<&]R='9$871A*"=63D]412<I.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+VE#86QE;F1A<B]V=&EM97IO;F4N
M<&AP```````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C<Q-P`Q,#4Q-30S,S<U
M,0`P,C0Q,#4`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J($-L87-S(')E<')E<V5N=&EN9R!V5&EM97IO
M;F5S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]I0V%L96YD87(O:4-A;&5N
M9&%R+W9T:6UE>F]N92YP:'`L=B`Q+C@N,3`N-"`R,#`V+S`Q+S`Q(#(Q.C(X
M.C0W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI:V4@
M0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH
M86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@
M2&]R9&5?:4-A;&5N9&%R"B`J+PIC;&%S<R!(;W)D95]I0V%L96YD87)?=G1I
M;65Z;VYE(&5X=&5N9',@2&]R9&5?:4-A;&5N9&%R('L*"B`@("!F=6YC=&EO
M;B!G9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)W94:6UE6F]N92<[
M"B`@("!]"@H@("`@9G5N8W1I;VX@<&%R<V5V0V%L96YD87(H)&1A=&$I"B`@
M("!["B`@("`@("`@<&%R96YT.CIP87)S979#86QE;F1A<B@D9&%T82P@)U94
M24U%6D].12<I.PH@("`@?0H*("`@(&9U;F-T:6]N(&5X<&]R='9#86QE;F1A
M<B@I"B`@("!["B`@("`@("`@<F5T=7)N('!A<F5N=#HZ7V5X<&]R='9$871A
M*"=65$E-15I/3D4G*3L*("`@('T*"GT*"B\J*@H@*B!`<&%C:V%G92!(;W)D
M95]I0V%L96YD87(*("HO"F-L87-S($AO<F1E7VE#86QE;F1A<E]S=&%N9&%R
M9"!E>'1E;F1S($AO<F1E7VE#86QE;F1A<B!["@H@("`@9G5N8W1I;VX@9V5T
M5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=S=&%N9&%R9"<["B`@("!]
M"@H@("`@9G5N8W1I;VX@<&%R<V5V0V%L96YD87(H)&1A=&$I"B`@("!["B`@
M("`@("`@<&%R96YT.CIP87)S979#86QE;F1A<B@D9&%T82P@)U-404Y$05)$
M)RD["B`@("!]"@H@("`@9G5N8W1I;VX@97AP;W)T=D-A;&5N9&%R*"D*("`@
M('L*("`@("`@("!R971U<FX@<&%R96YT.CI?97AP;W)T=D1A=&$H)U-404Y$
M05)$)RD["B`@("!]"@I]"@HO*BH*("H@0'!A8VMA9V4@2&]R9&5?:4-A;&5N
M9&%R"B`J+PIC;&%S<R!(;W)D95]I0V%L96YD87)?9&%Y;&EG:'0@97AT96YD
M<R!(;W)D95]I0V%L96YD87(@>PH*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@
M("`@>PH@("`@("`@(')E='5R;B`G9&%Y;&EG:'0G.PH@("`@?0H*("`@(&9U
M;F-T:6]N('!A<G-E=D-A;&5N9&%R*"1D871A*0H@("`@>PH@("`@("`@('!A
M<F5N=#HZ<&%R<V5V0V%L96YD87(H)&1A=&$L("=$05E,24=(5"<I.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&5X<&]R='9#86QE;F1A<B@I"B`@("!["B`@("`@
M("`@<F5T=7)N('!A<F5N=#HZ7V5X<&]R='9$871A*"=$05E,24=(5"<I.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O:4-A;&5N9&%R+W9T;V1O+G!H<```````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`T-3(Q`#$P-3$U-#,S-S4Q`#`R,S(Q,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@0VQA
M<W,@<F5P<F5S96YT:6YG('94;V1O<RX*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO:4-A;&5N9&%R+VE#86QE;F1A<B]V=&]D;RYP:'`L=B`Q+C$S+C$P+C0@
M,C`P-B\P,2\P,2`R,3HR.#HT-R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#,M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O
M+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N
M92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@2&]R9&4@
M,RXP"B`J($!P86-K86=E($AO<F1E7VE#86QE;F1A<@H@*B\*8VQA<W,@2&]R
M9&5?:4-A;&5N9&%R7W9T;V1O(&5X=&5N9',@2&]R9&5?:4-A;&5N9&%R('L*
M"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@
M)W94;V1O)SL*("`@('T*"B`@("!F=6YC=&EO;B!P87)S979#86QE;F1A<B@D
M9&%T82D*("`@('L*("`@("`@("!P87)E;G0Z.G!A<G-E=D-A;&5N9&%R*"1D
M871A+"`G5E1/1$\G*3L*("`@('T*"B`@("!F=6YC=&EO;B!E>'!O<G1V0V%L
M96YD87(H*0H@("`@>PH@("`@("`@(')E='5R;B!P87)E;G0Z.E]E>'!O<G1V
M1&%T82@G5E1/1$\G*3L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G0@
M=&AI<R!T;V1O('1O(&%N(&%R<F%Y(&]F(&%T=')I8G5T97,N"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@07)R87D@8V]N=&%I;FEN9R!T:&4@9&5T
M86EL<R!O9B!T:&4@=&]D;R!I;B!A(&AA<V@*("`@("`J("`@("`@("`@("`@
M("`@(&%S('5S960@8GD@2&]R9&4@87!P;&EC871I;VYS+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!T;T%R<F%Y*"D*("`@('L*("`@("`@("`D=&]D;R`](&%R
M<F%Y*"D["@H@("`@("`@("1N86UE(#T@)'1H:7,M/F=E=$%T=')I8G5T92@G
M4U5-34%262<I.PH@("`@("`@(&EF("@A:7-?87)R87DH)&YA;64I("8F("%I
M<U]A*"1N86UE+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1T;V1O
M6R=N86UE)UT@/2`D;F%M93L*("`@("`@("!]"B`@("`@("`@)&1E<V,@/2`D
M=&AI<RT^9V5T071T<FEB=71E*"=$15-#4DE05$E/3B<I.PH@("`@("`@(&EF
M("@A:7-?87)R87DH)&1E<V,I("8F("%I<U]A*"1D97-C+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("1T;V1O6R=D97-C)UT@/2`D9&5S8SL*("`@
M("`@("!]"@H@("`@("`@("1P<FEO<FET>2`]("1T:&ES+3YG971!='1R:6)U
M=&4H)U!224]22519)RD["B`@("`@("`@:68@*"%I<U]A<G)A>2@D<')I;W)I
M='DI("8F("%I<U]A*"1P<FEO<FET>2P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`D=&]D;ULG<')I;W)I='DG72`]("1P<FEO<FET>3L*("`@("`@
M("!]"@H@("`@("`@("1D=64@/2`D=&AI<RT^9V5T071T<FEB=71E*"=$5%-4
M04U0)RD["B`@("`@("`@:68@*"%I<U]A<G)A>2@D9'5E*2`F)B`A:7-?82@D
M9'5E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1T;V1O6R=D=64G
M72`]("1D=64["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1O9&\["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&%T=')I8G5T97,@9F]R('1H
M:7,@=&]D;R!I=&5M(&9R;VT@86X@87)R87DN"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1T;V1O("!!<G)A>2!C;VYT86EN:6YG('1H92!D971A:6QS
M(&]F('1H92!T;V1O(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@('1H
M92!S86UE(&9O<FUA="!T:&%T('1O07)R87DH*2!E>'!O<G1S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!F<F]M07)R87DH)'1O9&\I"B`@("!["B`@("`@("`@
M:68@*&ES<V5T*"1T;V1O6R=N86UE)UTI*2!["B`@("`@("`@("`@("1T:&ES
M+3YS971!='1R:6)U=&4H)U-534U!4EDG+"`D=&]D;ULG;F%M92==*3L*("`@
M("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1T;V1O6R=D97-C)UTI*2!["B`@
M("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)T1%4T-225!424].)RP@
M)'1O9&];)V1E<V,G72D["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H
M)'1O9&];)W!R:6]R:71Y)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YS971!
M='1R:6)U=&4H)U!224]22519)RP@)'1O9&];)W!R:6]R:71Y)UTI.PH@("`@
M("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1T;V1O6R=D=64G72DI('L*("`@
M("`@("`@("`@)'1H:7,M/G-E=$%T=')I8G5T92@G1%135$%-4"<L("1T;V1O
M6R=D=64G72D["B`@("`@("`@?0H@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O:4-A;&5N9&%R+G!H<```````````````````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,3,P-3`T`#$P-3$U-#,S-S4R`#`R,C`V,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@0'!A8VMA9V4@2&]R9&5?:4-A;&5N9&%R"B`J+PH*+RHJ"B`J
M(%-T<FEN9R!P86-K86=E"B`J+PII;F-L=61E7V]N8V4@)TAO<F1E+U-T<FEN
M9RYP:'`G.PH*+RHJ"B`J($-L87-S(')E<')E<V5N=&EN9R!I0V%L96YD87(@
M9FEL97,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+VE#86QE;F1A<B]I0V%L
M96YD87(N<&AP+'8@,2XU-RXT+C,T(#(P,#8O,#@O,#4@,3,Z-#,Z-#<@:V%R
M<W1E;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI:V4@0V]C
M:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL
M+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?:4-A;&5N9&%R"B`J+PIC;&%S<R!(;W)D95]I0V%L96YD87(@>PH*("`@
M("\J*@H@("`@("H@5&AE('!A<F5N="`H8V]N=&%I;FEN9RD@:4-A;&5N9&%R
M(&]B:F5C="X*("`@("`J"B`@("`@*B!`=F%R($AO<F1E7VE#86QE;F1A<@H@
M("`@("HO"B`@("!V87(@)%]C;VYT86EN97(@/2!F86QS93L*"B`@("`O*BH*
M("`@("`J(%1H92!N86UE+W9A;'5E('!A:7)S(&]F(&%T=')I8G5T97,@9F]R
M('1H:7,@;V)J96-T("A5240L"B`@("`@*B!$5%-405)4+"!E=&,N*2X@5VAI
M8V@@87)E('!R97-E;G0@9&5P96YD<R!O;B!T:&4@;V)J96-T(&%N9"!O;@H@
M("`@("H@=VAA="!K:6YD(&]F(&-O;7!O;F5N="!I="!I<RX*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V%T=')I8G5T97,@
M/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@06YY(&-H:6QD<F5N("AC;VYT
M86EN960I(&E#86QE;F1A<B!C;VUP;VYE;G1S(&]F('1H:7,@;V)J96-T+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?8V]M
M<&]N96YT<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!!8V-O<F1I;F<@
M=&\@4D9#(#(T,C4L('=E('-H;W5L9"!A;'=A>7,@=7-E($-23$8M=&5R;6EN
M871E9"!L:6YE<RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)%]N97=L:6YE(#T@(EQR7&XB.PH*("`@("\J*@H@("`@("H@
M:4-A;&5N9&%R(&9O<FUA="!V97)S:6]N("AD:69F97)E;G0@8F5H879I;W(@
M9F]R(#$N,"!A;F0@,BXP"B`@("`@*B!E<W!E8VEA;&QY('=I=&@@<F5C=7)R
M:6YG(&5V96YT<RDN"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1?=F5R<VEO;CL*"B`@("!F=6YC=&EO;B!(;W)D95]I0V%L
M96YD87(H)'9E<G-I;VX@/2`G,BXP)RD*("`@('L*("`@("`@("`D=&AI<RT^
M7W9E<G-I;VX@/2`D=F5R<VEO;CL*("`@("`@("`D=&AI<RT^<V5T071T<FEB
M=71E*"=615)324].)RP@)'9E<G-I;VXI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N(&$@<F5F97)E;F-E('1O(&$@;F5W(&-O;7!O;F5N="X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`@("`@("`@("1T>7!E("`@("`@
M(%1H92!T>7!E(&]F(&-O;7!O;F5N="!T;R!R971U<FX*("`@("`J($!P87)A
M;2!(;W)D95]I0V%L96YD87(@)&-O;G1A:6YE<B`@02!C;VYT86EN97(@=&AA
M="!T:&ES(&-O;7!O;F5N=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!W:6QL(&)E(&%S<V]C:6%T960@=VET:"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@4F5F97)E;F-E('1O(&$@2&]R9&5?
M:4-A;&5N9&%R7RH@;V)J96-T(&%S('-P96-I9FEE9"X*("`@("`J"B`@("`@
M*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N("9N97=#;VUP;VYE;G0H
M)'1Y<&4L("8D8V]N=&%I;F5R*0H@("`@>PH@("`@("`@("1T>7!E(#T@4W1R
M:6YG.CIL;W=E<B@D='EP92D["B`@("`@("`@)&-L87-S(#T@)TAO<F1E7VE#
M86QE;F1A<E\G("X@)'1Y<&4["B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H
M)&-L87-S*2D@>PH@("`@("`@("`@("!I;F-L=61E7V]N8V4@)TAO<F1E+VE#
M86QE;F1A<B\G("X@)'1Y<&4@+B`G+G!H<"<["B`@("`@("`@?0H@("`@("`@
M(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D8V]M
M<&]N96YT(#T@;F5W("1C;&%S<R@I.PH@("`@("`@("`@("!I9B`H)&-O;G1A
M:6YE<B`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1C;VUP;VYE;G0M
M/E]C;VYT86EN97(@/2`F)&-O;G1A:6YE<CL*("`@("`@("`@("`@("`@("\O
M(%5S92!V97)S:6]N(&]F(&-O;G1A:6YE<BP@;F]T(&1E9F%U;'0@<V5T(&)Y
M(&-O;7!O;F5N=`H@("`@("`@("`@("`@("`@+R\@8V]N<W1R=6-T;W(N"B`@
M("`@("`@("`@("`@("`D8V]M<&]N96YT+3Y?=F5R<VEO;B`]("1C;VYT86EN
M97(M/E]V97)S:6]N.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@+R\@4VAO=6QD(')E='5R;B!A;B!D=6UM>2!X+75N:VYO
M=VX@='EP92!C;&%S<R!H97)E+@H@("`@("`@("`@("`D8V]M<&]N96YT(#T@
M9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-O;7!O;F5N=#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE('9A;'5E(&]F(&%N(&%T
M=')I8G5T92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@
M("!4:&4@;F%M92!O9B!T:&4@871T<FEB=71E+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=F%L=64@("`@5&AE('9A;'5E(&]F('1H92!A='1R:6)U=&4N"B`@
M("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@("!!<G)A>2!C;VYT86EN:6YG
M(&%N>2!A9&1I=&EO;B!P87)A;65T97)S(&9O<@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@=&AI<R!A='1R:6)U=&4N"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D87!P96YD("!4<G5E('1O(&%P<&5N9"!T:&4@871T<FEB=71E
M+"!&86QS92!T;R!R97!L86-E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("!T:&4@9FER<W0@;6%T8VAI;F<@871T<FEB=71E(&9O=6YD+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1V86QU97,@("`@07)R87D@<F5P<F5S96YT871I
M;VX@;V8@)'9A;'5E+B`@1F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("!C;VUM82]S96UI8V]L;VX@<V5P97)A=&5D(&QI<W1S(&]F('9A;'5E
M<RX@($EF"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!N;W0@<V5T
M('5S92`D=F%L=64@87,@<VEN9VQE(&%R<F%Y(&5L96UE;G0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-E=$%T=')I8G5T92@D;F%M92P@)'9A;'5E+"`D<&%R
M86US(#T@87)R87DH*2P@)&%P<&5N9"`]('1R=64L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'9A;'5E<R`](&9A;'-E*0H@("`@>PH@("`@("`@("\O
M($UA:V4@<W5R92!W92!U<&1A=&4@=&AE(&EN=&5R;F%L(&9O<FUA="!V97)S
M:6]N(&EF"B`@("`@("`@+R\@<V5T071T<FEB=71E*"=615)324].)RP@+BXN
M*2!I<R!C86QL960N"B`@("`@("`@:68@*"1N86UE(#T]("=615)324].)RD@
M>PH@("`@("`@("`@("`D=&AI<RT^7W9E<G-I;VX@/2`D=F%L=64["B`@("`@
M("`@("`@(&EF("@D=&AI<RT^7V-O;G1A:6YE<B`A/3T@9F%L<V4I('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8V]N=&%I;F5R+3Y?=F5R<VEO;B`]("1V
M86QU93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"$D
M=F%L=65S*2!["B`@("`@("`@("`@("1V86QU97,@/2!A<G)A>2@D=F%L=64I
M.PH@("`@("`@('T*("`@("`@("`D9F]U;F0@/2!F86QS93L*("`@("`@("!I
M9B`H(21A<'!E;F0I('L*("`@("`@("`@("`@)&ME>7,@/2!A<G)A>5]K97ES
M*"1T:&ES+3Y?871T<FEB=71E<RD["B`@("`@("`@("`@(&9O<F5A8V@@*"1K
M97ES(&%S("1K97DI('L*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7V%T
M=')I8G5T97-;)&ME>5U;)VYA;64G72`]/2!3=')I;F<Z.G5P<&5R*"1N86UE
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?871T<FEB=71E<ULD
M:V5Y75LG<&%R86US)UT@/2`D<&%R86US.PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?871T<FEB=71E<ULD:V5Y75LG=F%L=64G72`]("1V86QU93L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%T=')I8G5T97-;)&ME>5U;
M)W9A;'5E<R==(#T@)'9A;'5E<SL*("`@("`@("`@("`@("`@("`@("`D9F]U
M;F0@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I
M9B`H)&%P<&5N9"!\?"`A)&9O=6YD*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M871T<FEB=71E<UM=(#T@87)R87DH"B`@("`@("`@("`@("`@("`G;F%M92<@
M("`@("`]/B!3=')I;F<Z.G5P<&5R*"1N86UE*2P*("`@("`@("`@("`@("`@
M("=P87)A;7,G("`@(#T^("1P87)A;7,L"B`@("`@("`@("`@("`@("`G=F%L
M=64G("`@("`]/B`D=F%L=64L"B`@("`@("`@("`@("`@("`G=F%L=65S)R`@
M("`]/B`D=F%L=65S"B`@("`@("`@("`@("D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@4V5T<R!P87)A;65T97(H<RD@9F]R(&%N("AA;')E
M861Y(&5X:7-T:6YG*2!A='1R:6)U=&4N("!4:&4*("`@("`J('!A<F%M971E
M<B!S970@:7,@;65R9V5D(&EN=&\@=&AE(&5X:7-T:6YG('-E="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@5&AE(&YA;64@;V8@=&AE
M(&%T=')I8G5T92X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!<G)A
M>2!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L('!A<F%M971E<G,@9F]R"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@=&AI<R!A='1R:6)U=&4N"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@
M:68@;F\@871T<FEB=71E("1N86UE(&5X:7-T<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T4&%R86UE=&5R*"1N86UE+"`D<&%R86US(#T@87)R87DH*2D*
M("`@('L*("`@("`@("`D:V5Y<R`](&%R<F%Y7VME>7,H)'1H:7,M/E]A='1R
M:6)U=&5S*3L*("`@("`@("!F;W)E86-H("@D:V5Y<R!A<R`D:V5Y*2!["B`@
M("`@("`@("`@(&EF("@D=&AI<RT^7V%T=')I8G5T97-;)&ME>5U;)VYA;64G
M72`]/2`D;F%M92D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A='1R:6)U
M=&5S6R1K97E=6R=P87)A;7,G72`]"B`@("`@("`@("`@("`@("`@("`@87)R
M87E?;65R9V4H)'1H:7,M/E]A='1R:6)U=&5S6R1K97E=6R=P87)A;7,G72P@
M)'!A<F%M<RD["B`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1V5T('1H92!V86QU92!O9B!A;B!A='1R:6)U
M=&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@5&AE
M(&YA;64@;V8@=&AE(&%T=')I8G5T92X*("`@("`J($!P87)A;2!B;V]L96%N
M("1P87)A;7,@(%)E='5R;B!T:&4@<&%R86UE=&5R<R!F;W(@=&AI<R!A='1R
M:6)U=&4@:6YS=&5A9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M;V8@:71S('9A;'5E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@*&]B
M:F5C="D@(%!%05)?17)R;W(@:68@=&AE(&%T=')I8G5T92!D;V5S(&YO="!E
M>&ES="X*("`@("`J("`@("`@("`@("`@("`@*'-T<FEN9RD@(%1H92!V86QU
M92!O9B!T:&4@871T<FEB=71E+@H@("`@("H@("`@("`@("`@("`@("`H87)R
M87DI("`@5&AE('!A<F%M971E<G,@9F]R('1H92!A='1R:6)U=&4@;W(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@(&UU;'1I<&QE('9A;'5E<R!F
M;W(@86X@871T<FEB=71E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!='1R
M:6)U=&4H)&YA;64L("1P87)A;7,@/2!F86QS92D*("`@('L*("`@("`@("`D
M<F5S=6QT(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V%T
M=')I8G5T97,@87,@)&%T=')I8G5T92D@>PH@("`@("`@("`@("!I9B`H)&%T
M=')I8G5T95LG;F%M92==(#T]("1N86UE*2!["B`@("`@("`@("`@("`@("!I
M9B`H)'!A<F%M<RD@>PH@("`@("`@("`@("`@("`@("`@("1R97-U;'1;72`]
M("1A='1R:6)U=&5;)W!A<F%M<R==.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`D<F5S=6QT6UT@/2`D871T<FEB=71E
M6R=V86QU92==.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(&EF("@A8V]U;G0H)')E<W5L="DI('L*("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E("=014%2+G!H<"<["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*"=!='1R:6)U=&4@(B<@+B`D;F%M92`N
M("<B($YO="!&;W5N9"<I.PH@("`@("`@('T@:68@*&-O=6YT*"1R97-U;'0I
M(#T](#$@)B8@(21P87)A;7,I('L*("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'1;,%T["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1V5T<R!T
M:&4@=F%L=65S(&]F(&%N(&%T=')I8G5T92!A<R!A;B!A<G)A>2X@($UU;'1I
M<&QE('9A;'5E<PH@("`@("H@87)E('!O<W-I8FQE(&1U92!T;SH*("`@("`J
M"B`@("`@*B`@82D@;75L=&EP;&-E(&]C8W5R96YC97,@;V8@)VYA;64G"B`@
M("`@*B`@8BD@*'5N<V5C87!D*2!C;VUM82!S97!E<F%T960@;&ES=',N"B`@
M("`@*@H@("`@("H@4V\@9F]R(&$@=F-A<F0@;&EK92`B2T59.F$L8EQN2T59
M.F,B(&=E=$%T=')I8G5T97-686QU97,H)TM%62<I"B`@("`@*B!W:6QL(')E
M='5R;B!A<G)A>2@G82<L)V(G+"=C)RDN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@)&YA;64@("`@5&AE(&YA;64@;V8@=&AE(&%T=')I8G5T92X*
M("`@("`J($!R971U<FX@;6EX960@*&]B:F5C="D@(%!%05)?17)R;W(@:68@
M=&AE(&%T=')I8G5T92!D;V5S(&YO="!E>&ES="X*("`@("`J("`@("`@("`@
M("`@("`@*&%R<F%Y*2`@($UU;'1I<&QE('9A;'5E<R!F;W(@86X@871T<FEB
M=71E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!='1R:6)U=&5686QU97,H
M)&YA;64I"B`@("!["B`@("`@("`@)')E<W5L="`](&%R<F%Y*"D["B`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/E]A='1R:6)U=&5S(&%S("1A='1R:6)U=&4I
M('L*("`@("`@("`@("`@:68@*"1A='1R:6)U=&5;)VYA;64G72`]/2`D;F%M
M92D@>PH@("`@("`@("`@("`@("`@)')E<W5L="`](&%R<F%Y7VUE<F=E*"1A
M='1R:6)U=&5;)W9A;'5E<R==+"`D<F5S=6QT*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!I9B`H(6-O=6YT*"1R97-U;'0I*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=!='1R:6)U=&4@(B<@
M+B`D;F%M92`N("<B($YO="!&;W5N9"<I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE('9A;'5E(&]F(&%N(&%T=')I8G5T92P@;W(@82!S<&5C:69I960@9&5F
M875L="!V86QU90H@("`@("H@:68@=&AE(&%T=')I8G5T92!D;V5S(&YO="!E
M>&ES="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@(%1H
M92!N86UE(&]F('1H92!A='1R:6)U=&4N"B`@("`@*B!`<&%R86T@;6EX960@
M)&1E9F%U;'0@(%=H870@=&\@<F5T=7)N(&EF('1H92!A='1R:6)U=&4@<W!E
M8VEF:65D(&)Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("1N86UE
M(&1O97,@;F]T(&5X:7-T+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M*'-T<FEN9RD@5&AE('9A;'5E(&]F("1N86UE+@H@("`@("H@("`@("`@("`@
M("`@("`H;6EX960I("`D9&5F875L="!I9B`D;F%M92!D;V5S(&YO="!E>&ES
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T071T<FEB=71E1&5F875L="@D
M;F%M92P@)&1E9F%U;'0@/2`G)RD*("`@('L*("`@("`@("`D=F%L=64@/2`D
M=&AI<RT^9V5T071T<FEB=71E*"1N86UE*3L*("`@("`@("!R971U<FX@:7-?
M82@D=F%L=64L("=014%27T5R<F]R)RD@/R`D9&5F875L="`Z("1V86QU93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V92!A;&P@;V-C=7)E;F-E<R!O
M9B!A;B!A='1R:6)U=&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;F%M92`@5&AE(&YA;64@;V8@=&AE(&%T=')I8G5T92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5M;W9E071T<FEB=71E*"1N86UE*0H@("`@>PH@("`@("`@
M("1K97ES(#T@87)R87E?:V5Y<R@D=&AI<RT^7V%T=')I8G5T97,I.PH@("`@
M("`@(&9O<F5A8V@@*"1K97ES(&%S("1K97DI('L*("`@("`@("`@("`@:68@
M*"1T:&ES+3Y?871T<FEB=71E<ULD:V5Y75LG;F%M92==(#T]("1N86UE*2![
M"B`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^7V%T=')I8G5T97-;)&ME
M>5TI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T(&%T=')I8G5T97,@9F]R(&%L;"!T86=S(&]R(&9O<B!A(&=I
M=F5N('1A9RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T86<@(%)E
M='5R;B!A='1R:6)U=&5S(&9O<B!T:&ES('1A9RP@;W(@86QL(&%T=')I8G5T
M97,@:68*("`@("`J("`@("`@("`@("`@("`@("`@("`@;F]T(&=I=F5N+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y(&-O;G1A:6YI
M;F<@86QL('1H92!A='1R:6)U=&5S(&%N9"!T:&5I<B!T>7!E<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T06QL071T<FEB=71E<R@D=&%G(#T@9F%L<V4I
M"B`@("!["B`@("`@("`@:68@*"1T86<@/3T](&9A;'-E*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7V%T=')I8G5T97,["B`@("`@("`@?0H@("`@
M("`@("1R97-U;'0@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3Y?871T<FEB=71E<R!A<R`D871T<FEB=71E*2!["B`@("`@("`@("`@(&EF
M("@D871T<FEB=71E6R=N86UE)UT@/3T@)'1A9RD@>PH@("`@("`@("`@("`@
M("`@)')E<W5L=%M=(#T@)&%T=')I8G5T93L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*
M("`@("`J($%D9"!A('9#86QE;F1A<B!C;VUP;VYE;G0@*&5G('9%=F5N="P@
M=E1I;65Z;VYE+"!E=&,N*2X*("`@("`J"B`@("`@*B!`<&%R86T@2&]R9&5?
M:4-A;&5N9&%R("1C;VUP;VYE;G0@($-O;7!O;F5N="`H<W5B8VQA<W,I('1O
M(&%D9"X*("`@("`J+PH@("`@9G5N8W1I;VX@861D0V]M<&]N96YT*"1C;VUP
M;VYE;G0I"B`@("!["B`@("`@("`@:68@*&ES7V$H)&-O;7!O;F5N="P@)TAO
M<F1E7VE#86QE;F1A<B<I*2!["B`@("`@("`@("`@("1C;VUP;VYE;G0M/E]C
M;VYT86EN97(@/2`F)'1H:7,["B`@("`@("`@("`@("1T:&ES+3Y?8V]M<&]N
M96YT<UM=(#T@)B1C;VUP;VYE;G0["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T<FEE=F4@86QL('1H92!C;VUP;VYE;G1S+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@($%R<F%Y(&]F($AO<F1E7VE#86QE;F1A
M<B!O8FIE8W1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#;VUP;VYE;G1S
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]C;VUP;VYE;G1S.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@(')E
M='5R;B`G=F-A;&5N9&%R)SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!T:&4@8VQA<W-E<R`H96YT<GD@='EP97,I('=E(&AA=F4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@2&%S:"!W:71H(&-L87-S(&YA;65S($AO
M<F1E7VE#86QE;F1A<E]X>'@@87,@:V5Y<PH@("`@("H@("`@("`@("`@("`@
M("`@86YD(&YU;6)E<B!O9B!C;VUP;VYE;G1S(&]F('1H:7,@8VQA<W,@87,@
M=F%L=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-O;7!O;F5N=$-L87-S
M97,H*0H@("`@>PH@("`@("`@("1R(#T@87)R87DH*3L*("`@("`@("!F;W)E
M86-H("@D=&AI<RT^7V-O;7!O;F5N=',@87,@)&,I('L*("`@("`@("`@("`@
M)&-N(#T@<W1R=&]L;W=E<BAG971?8VQA<W,H)&,I*3L*("`@("`@("`@("`@
M:68@*&5M<'1Y*"1R6R1C;ETI*2!["B`@("`@("`@("`@("`@("`D<ELD8VY=
M(#T@,3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R
M6R1C;ETK*SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1R.PH@("`@?0H*("`@("\J*@H@("`@("H@3G5M8F5R(&]F(&-O;7!O
M;F5N=',@:6X@=&AI<R!C;VYT86EN97(N"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G1E9V5R("!.=6UB97(@;V8@8V]M<&]N96YT<R!I;B!T:&ES(&-O;G1A
M:6YE<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0V]M<&]N96YT0V]U;G0H
M*0H@("`@>PH@("`@("`@(')E='5R;B!C;W5N="@D=&AI<RT^7V-O;7!O;F5N
M=',I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F4@82!S<&5C:69I
M8R!C;VUP;VYE;G0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&ED
M>"`@5&AE(&EN9&5X(&]F('1H92!O8FIE8W0@=&\@<F5T<FEE=F4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@("`H8F]O;&5A;BD@1F%L<V4@:68@
M=&AE(&EN9&5X(&1O97,@;F]T(&5X:7-T+@H@("`@("H@("`@("`@("`@("`@
M("`@("`H2&]R9&5?:4-A;&5N9&%R7RHI(%1H92!R97%U97-T960@8V]M<&]N
M96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#;VUP;VYE;G0H)&ED>"D*
M("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C;VUP;VYE;G1S6R1I
M9'A=*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]C;VUP;VYE;G1S
M6R1I9'A=.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!,;V-A=&5S
M('1H92!F:7)S="!C:&EL9"!C;VUP;VYE;G0@;V8@=&AE('-P96-I9FEE9"!C
M;&%S<RP@86YD"B`@("`@*B!R971U<FYS(&$@<F5F97)E;F-E('1O('1H:7,@
M8V]M<&]N96YT+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@
M(%1H92!T>7!E(&]F(&-O;7!O;F5N="!T;R!F:6YD+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@*&)O;VQE86XI($9A;'-E(&EF(&YO('-U8F-O;7!O
M;F5N="!O9B!T:&4@<W!E8VEF:65D"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!C;&%S<R!E>&ES=',N"B`@("`@*B`@("`@("`@("`@("`@("A(
M;W)D95]I0V%L96YD87)?*BD@02!R969E<F5N8V4@=&\@=&AE(')E<75E<W1E
M9"!C;VUP;VYE;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F:6YD0V]M<&]N
M96YT*"1C:&EL9&-L87-S*0H@("`@>PH@("`@("`@("1C:&EL9&-L87-S(#T@
M)TAO<F1E7VE#86QE;F1A<E\G("X@4W1R:6YG.CIL;W=E<B@D8VAI;&1C;&%S
M<RD["B`@("`@("`@)&ME>7,@/2!A<G)A>5]K97ES*"1T:&ES+3Y?8V]M<&]N
M96YT<RD["B`@("`@("`@9F]R96%C:"`H)&ME>7,@87,@)&ME>2D@>PH@("`@
M("`@("`@("!I9B`H:7-?82@D=&AI<RT^7V-O;7!O;F5N='-;)&ME>5TL("1C
M:&EL9&-L87-S*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M8V]M<&]N96YT<ULD:V5Y73L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@0VQE
M87)S('1H92!I0V%L96YD87(@;V)J96-T("AR97-E=',@=&AE(&-O;7!O;F5N
M=',@86YD(&%T=')I8G5T97,*("`@("`J(&%R<F%Y<RDN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-L96%R*"D*("`@('L*("`@("`@("`D=&AI<RT^7V-O;7!O
M;F5N=',@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3Y?871T<FEB=71E<R`]
M(&%R<F%Y*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@96YT
M<GD@:7,@=F-A;&5N9&%R(#$N,"P@=F-A<F0@,BXQ(&]R('9N;W1E(#$N,2X*
M("`@("`J"B`@("`@*B!4:&5S92`G;VQD)R!F;W)M871S(&%R92!D969I;F5D
M(&)Y('=W=RYI;6,N;W)G+B!4:&4@)VYE=R<@*&YO;BUO;&0I"B`@("`@*B!F
M;W)M871S(&EC86QE;F1A<B`R+C`@86YD('9C87)D(#,N,"!A<F4@9&5F:6YE
M9"!I;B!R9F,R-#(V(&%N9"!R9F,R-#0U"B`@("`@*B!R97-P96-T:79E;'DN
M"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,2XR"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&ES3VQD1F]R;6%T*"D*("`@('L*("`@("`@("!I9B`H)'1H
M:7,M/E]C;VYT86EN97(@(3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7V-O;G1A:6YE<BT^:7-/;&1&;W)M870H*3L*("`@("`@("!]
M"B`@("`@("`@:68@*"1T:&ES+3YG9714>7!E*"D@/3T@)W9C87)D)RD@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]V97)S:6]N(#P@,R`_('1R=64@
M.B!F86QS93L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YG9714>7!E
M*"D@/3T@)W9.;W1E)RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]V
M97)S:6]N(#P@,B`_('1R=64@.B!F86QS93L*("`@("`@("!]"B`@("`@("`@
M:68@*"1T:&ES+3Y?=F5R<VEO;B`^/2`R*2!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!%>'!O<G0@87,@=D-A;&5N9&%R(&9O<FUA="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@97AP;W)T=D-A;&5N9&%R*"D*("`@('L*
M("`@("`@("`O+R!$969A=6QT('9A;'5E<RX*("`@("`@("`D<F5Q=6ER961!
M='1R:6)U=&5S6R=04D]$240G72`]("<M+R]4:&4@2&]R9&4@4')O:F5C="\O
M2&]R9&5?:4-A;&5N9&%R($QI8G)A<GDG("X@*&1E9FEN960H)TA/4D1%7U9%
M4E-)3TXG*2`_("<L($AO<F1E("<@+B!C;VYS=&%N="@G2$]21$5?5D524TE/
M3B<I(#H@)R<I("X@)R\O14XG.PH@("`@("`@("1R97%U:7)E9$%T=')I8G5T
M97-;)TU%5$A/1"==(#T@)U!50DQ)4T@G.PH*("`@("`@("!F;W)E86-H("@D
M<F5Q=6ER961!='1R:6)U=&5S(&%S("1N86UE(#T^("1D969A=6QT7W9A;'5E
M*2!["B`@("`@("`@("`@(&EF("AI<U]A*"1T:&ES+3YG971A='1R:6)U=&4H
M)&YA;64I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T071T<FEB=71E*"1N86UE+"`D9&5F875L=%]V86QU92D["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7V5X
M<&]R='9$871A*"=60T%,14Y$05(G*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($5X<&]R="!T:&ES(&5N=')Y(&%S(&$@:&%S:"!A<G)A>2!W:71H('1A9R!N
M86UE<R!A<R!K97ES+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1P
M87)A;7-);DME>7,*("`@("`J("`@("`@("`@("`@("`@($EF(&9A;'-E+"!T
M:&4@;W!E<F%T:6]N(&-A;B!B92!Q=6ET92!L;W-S>2!A<R!T:&4*("`@("`J
M("`@("`@("`@("`@("`@('!A<F%M971E<G,@87)E(&EG;F]R960@=VAE;B!B
M=6EL9&EN9R!T:&4@87)R87D@:V5Y<RX*("`@("`J("`@("`@("`@("`@("`@
M(%-O(&EF('EO=2!E>'!O<G0@82!V8V%R9"!W:71H"B`@("`@*B`@("`@("`@
M("`@("`@("!,04)%3#M465!%/5=/4DLZ9F]O"B`@("`@*B`@("`@("`@("`@
M("`@("!,04)%3#M465!%/4A/344Z8F%R"B`@("`@*B`@("`@("`@("`@("`@
M("!T:&4@<F5S=6QT:6YG(&AA<V@@8V]N=&%I;G,@;VYL>2!O;F4@;&%B96P@
M9FEE;&0A"B`@("`@*B`@("`@("`@("`@("`@("!)9B!S970@=&\@=')U92P@
M87)R87D@:V5Y<R!L;V]K(&QI:V4@)TQ!0D5,.U194$4]5T]22R<*("`@("`J
M($!R971U<FX@87)R87D@($$@:&%S:"!A<G)A>2!W:71H('1A9R!N86UE<R!A
M<R!K97ES+@H@("`@("HO"B`@("!F=6YC=&EO;B!T;TAA<V@H)'!A<F%M<TEN
M2V5Y<R`](&9A;'-E*0H@("`@>PH@("`@("`@("1H87-H(#T@87)R87DH*3L*
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7V%T=')I8G5T97,@87,@)&$I("![
M"B`@("`@("`@("`@("1K(#T@)&%;)VYA;64G73L*("`@("`@("`@("`@:68@
M*"1P87)A;7-);DME>7,@)B8@:7-?87)R87DH)&%;)W!A<F%M<R==*2D@>PH@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)&%;)W!A<F%M<R==(&%S("1P(#T^
M("1V*2!["B`@("`@("`@("`@("`@("`@("`@)&L@+CT@(CLD<#TD=B(["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&AA
M<VA;)&M=(#T@)&%;)W9A;'5E)UT["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&AA<V@["B`@("!]"@H@("`@+RHJ"B`@("`@*B!087)S97,@82!S=')I
M;F<@8V]N=&%I;FEN9R!V0V%L96YD87(@9&%T82X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1T97AT("`@("!4:&4@9&%T82!T;R!P87)S92X*("`@
M("`J($!P87)A;2!S=')I;F<@)&)A<V4@("`@(%1H92!T>7!E(&]F('1H92!B
M87-E(&]B:F5C="X*("`@("`J($!P87)A;2!S=')I;F<@)&-H87)S970@(%1H
M92!E;F-O9&EN9R!C:&%R<V5T(&9O<B`D=&5X="X@1&5F875L=',@=&\*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@('5T9BTX+@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&-L96%R("`@268@=')U92!C;&5A<G,@=&AE(&E#86P@
M;V)J96-T(&)E9F]R92!P87)S:6YG+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;B`@5')U92!O;B!S=6-C97-S9G5L(&EM<&]R="P@9F%L<V4@;W1H
M97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!P87)S979#86QE;F1A<B@D
M=&5X="P@)&)A<V4@/2`G5D-!3$5.1$%2)RP@)&-H87)S970@/2`G=71F+3@G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-L96%R(#T@=')U92D*
M("`@('L*("`@("`@("!I9B`H)&-L96%R*2!["B`@("`@("`@("`@("1T:&ES
M+3YC;&5A<B@I.PH@("`@("`@('T*("`@("`@("!I9B`H<')E9U]M871C:"@G
M+RA"14=)3CHG("X@)&)A<V4@+B`G7'(_7&X_*2A;7%=<=UTJ*2A%3D0Z)R`N
M("1B87-E("X@)UQR/UQN/RDO:2<L("1T97AT+"`D;6%T8VAE<RDI('L*("`@
M("`@("`@("`@)'9#86P@/2`D;6%T8VAE<ULR73L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`O+R!497AT(&ES;B=T(&5N8VQO<V5D(&EN($)%1TE.
M.E9#04Q%3D1!4@H@("`@("`@("`@("`O+R`N+B!%3D0Z5D-!3$5.1$%2+B!7
M92=L;"!T<GD@=&\@<&%R<V4@:70@86YY=V%Y+@H@("`@("`@("`@("`D=D-A
M;"`]("1T97AT.PH@("`@("`@('T*"B`@("`@("`@+R\@06QL('-U8F-O;7!O
M;F5N=',N"B`@("`@("`@)&UA=&-H97,@/2!N=6QL.PH@("`@("`@(&EF("AP
M<F5G7VUA=&-H7V%L;"@G+T)%1TE..BA;7%=<=UTJ*2A<<EQN?%QR?%QN*2A;
M7%=<=UTJ*45.1#I<,2A<<EQN?%QR?%QN*2]5:2<L("1V0V%L+"`D;6%T8VAE
M<RDI('L*("`@("`@("`@("`@9F]R96%C:"`H)&UA=&-H97-;,%T@87,@)&ME
M>2`]/B`D9&%T82D@>PH@("`@("`@("`@("`@("`@)'1Y<&4@/2!T<FEM*"1M
M871C:&5S6S%=6R1K97E=*3L*("`@("`@("`@("`@("`@("1C;VUP;VYE;G0@
M/2`F2&]R9&5?:4-A;&5N9&%R.CIN97=#;VUP;VYE;G0H)'1Y<&4L("1T:&ES
M*3L*("`@("`@("`@("`@("`@(&EF("@D8V]M<&]N96YT(#T]/2!F86QS92D@
M>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*")5;F%B;&4@=&\@8W)E871E(&]B:F5C="!F;W(@='EP92`D='EP92(I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&-O;7!O;F5N="T^
M<&%R<V5V0V%L96YD87(H)&1A=&$I.PH*("`@("`@("`@("`@("`@("1T:&ES
M+3YA9&1#;VUP;VYE;G0H)&-O;7!O;F5N="D["@H@("`@("`@("`@("`@("`@
M+R\@4F5M;W9E(&9R;VT@=&AE('9#86QE;F1A<B!D871A+@H@("`@("`@("`@
M("`@("`@)'9#86P@/2!S=')?<F5P;&%C92@D9&%T82P@)R<L("1V0V%L*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@56YF;VQD(&%N
M>2!F;VQD960@;&EN97,N"B`@("`@("`@)'9#86P@/2!P<F5G7W)E<&QA8V4H
M)R];7')<;ETK6R!<=%TO)RP@)R<L("1V0V%L*3L*"B`@("`@("`@+R\@56YF
M;VQD(")Q=6]T960@<')I;G1A8FQE(B!F;VQD960@;&EN97,@;&EK93H*("`@
M("`@("`O+R`@0D]$63M%3D-/1$E.1SU154]4140M4%))3E1!0DQ%.CT*("`@
M("`@("`O+R`@86YO=&AE<CTR,&QI;F4]"B`@("`@("`@+R\@(&QA<W0],C!L
M:6YE"B`@("`@("`@=VAI;&4@*'!R96=?;6%T8VA?86QL*"<O7BA;7CI=*SM<
M<RI%3D-/1$E.1SU154]4140M4%))3E1!0DQ%*"XJ/5QR/UQN*2LH+BI;7CU=
M*3]<<C]<;BDO;54G+"`D=D-A;"P@)&UA=&-H97,I*2!["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1M871C:&5S6S%=(&%S("1S*2!["B`@("`@("`@("`@("`@
M("`D<B`]('!R96=?<F5P;&%C92@G+SU<<C]<;B\G+"`G)RP@)',I.PH@("`@
M("`@("`@("`@("`@)'9#86P@/2!S=')?<F5P;&%C92@D<RP@)'(L("1V0V%L
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@4&%R<V4@
M=&AE(')E;6%I;FEN9R!A='1R:6)U=&5S+@H@("`@("`@(&EF("AP<F5G7VUA
M=&-H7V%L;"@G+R@N*BDZ*%M>7')<;ETJ*5M<<EQN72LO)RP@)'9#86PL("1M
M871C:&5S*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D;6%T8VAE<ULP72!A
M<R`D871T<FEB=71E*2!["B`@("`@("`@("`@("`@("!P<F5G7VUA=&-H*"<O
M*%M>.UXZ72HI*"@[6UXZ72HI/RDZ*%M>7')<;ETJ*5M<<EQN72HO)RP@)&%T
M=')I8G5T92P@)'!A<G1S*3L*("`@("`@("`@("`@("`@("1T86<@/2!3=')I
M;F<Z.G5P<&5R*"1P87)T<ULQ72D["B`@("`@("`@("`@("`@("`D=F%L=64@
M/2`D<&%R='-;-%T["B`@("`@("`@("`@("`@("`D<&%R86US(#T@87)R87DH
M*3L*"B`@("`@("`@("`@("`@("`O+R!087)S92!P87)A;65T97)S+@H@("`@
M("`@("`@("`@("`@:68@*"%E;7!T>2@D<&%R='-;,ETI*2!["B`@("`@("`@
M("`@("`@("`@("`@<')E9U]M871C:%]A;&PH)R\[*"A;7CL]72HI*#TH6UX[
M72HI*3\I+R<L("1P87)T<ULR72P@)'!A<F%M7W!A<G1S*3L*("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D<&%R86U?<&%R='-;,ET@87,@)&ME>2`]
M/B`D<&%R86U.86UE*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1P87)A
M;59A;'5E(#T@)'!A<F%M7W!A<G1S6S1=6R1K97E=.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D<&%R86US6U-T<FEN9SHZ=7!P97(H)'!A<F%M3F%M92E=
M(#T@)'!A<F%M5F%L=64["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\O($-H87)S970@86YD(&5N
M8V]D:6YG(&AA;F1L:6YG+@H@("`@("`@("`@("`@("`@:68@*"AI<W-E="@D
M<&%R86US6R=%3D-/1$E.1R==*0H@("`@("`@("`@("`@("`@("`@("`F)B!3
M=')I;F<Z.G5P<&5R*"1P87)A;7-;)T5.0T]$24Y')UTI(#T]("=154]4140M
M4%))3E1!0DQ%)RD*("`@("`@("`@("`@("`@("`@("!\?"!I<W-E="@D<&%R
M86US6R=154]4140M4%))3E1!0DQ%)UTI*2!["@H@("`@("`@("`@("`@("`@
M("`@("1V86QU92`]('%U;W1E9%]P<FEN=&%B;&5?9&5C;V1E*"1V86QU92D[
M"B`@("`@("`@("`@("`@("`@("`@+R\@475O=&5D('!R:6YT86)L92!I<R!N
M;W)M86QL>2!E;F-O9&5D(&%S('5T9BTX+@H@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D<&%R86US6R=#2$%24T54)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1V86QU92`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H
M)'9A;'5E+"`D<&%R86US6R=#2$%24T54)UTI.PH@("`@("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`]
M(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'9A;'5E+"`G=71F+3@G*3L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M:7-S970H)'!A<F%M<ULG0TA!4E-%5"==*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1V86QU92`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'9A;'5E+"`D
M<&%R86US6R=#2$%24T54)UTI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`O+R!!<R!P97(@4D9#(#(R-SDL(&%S<W5M
M92!55$8X(&EF('=E(&1O;B=T(&AA=F4@86X*("`@("`@("`@("`@("`@("`@
M("`O+R!E>'!L:6-I="!C:&%R<V5T('!A<F%M971E<BX*("`@("`@("`@("`@
M("`@("`@("`D=F%L=64@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1V86QU
M92P@)&-H87)S970I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@('-W:71C:"`H)'1A9RD@>PH@("`@("`@("`@("`@("`@+R\@1&%T92!F
M:65L9',N"B`@("`@("`@("`@("`@("!C87-E("=#3TU03$54140G.@H@("`@
M("`@("`@("`@("`@8V%S92`G0U)%051%1"<Z"B`@("`@("`@("`@("`@("!C
M87-E("=,05-4+4U/1$E&245$)SH*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T071T<FEB=71E*"1T86<L("1T:&ES+3Y?<&%R<V5$871E5&EM92@D
M=F%L=64I+"`D<&%R86US*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@("`@("!C87-E("="1$%9)SH*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T071T<FEB=71E*"1T86<L("1T:&ES+3Y?<&%R<V5$
M871E*"1V86QU92DL("1P87)A;7,I.PH@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)T1414Y$)SH*("`@("`@("`@
M("`@("`@(&-A<V4@)T144U1!4E0G.@H@("`@("`@("`@("`@("`@8V%S92`G
M1%135$%-4"<Z"B`@("`@("`@("`@("`@("!C87-E("=$544G.@H@("`@("`@
M("`@("`@("`@8V%S92`G04%,05)-)SH*("`@("`@("`@("`@("`@(&-A<V4@
M)U)%0U524D5.0T4M240G.@H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D<&%R86US6R=604Q512==*2`F)B`D<&%R86US6R=604Q512==(#T]("=$
M051%)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T071T
M<FEB=71E*"1T86<L("1T:&ES+3Y?<&%R<V5$871E*"1V86QU92DL("1P87)A
M;7,I.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)'1A9RP@)'1H:7,M
M/E]P87)S941A=&54:6UE*"1V86QU92DL("1P87)A;7,I.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@("`@("!C87-E("=44DE'1T52)SH*("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)'!A<F%M<ULG5D%,544G72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"1P87)A;7-;)U9!3%5%)UT@/3T@)T1!5$4M5$E-
M12<I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971!
M='1R:6)U=&4H)'1A9RP@)'1H:7,M/E]P87)S941A=&54:6UE*"1V86QU92DL
M("1P87)A;7,I.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$%T=')I8G5T
M92@D=&%G+"`D=&AI<RT^7W!A<G-E1'5R871I;VXH)'9A;'5E*2P@)'!A<F%M
M<RD["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M<V5T071T<FEB=71E*"1T86<L("1T:&ES+3Y?<&%R<V5$=7)A=&EO;B@D=F%L
M=64I+"`D<&%R86US*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@+R\@0V]M;6$@
M<V5P97)A=&5D(&1A=&5S+@H@("`@("`@("`@("`@("`@8V%S92`G15A$051%
M)SH*("`@("`@("`@("`@("`@(&-A<V4@)U)$051%)SH*("`@("`@("`@("`@
M("`@("`@("`D9&%T97,@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@
M('!R96=?;6%T8VA?86QL*"<O+"A;7BQ=*BDO)RP@)RPG("X@)'9A;'5E+"`D
M=F%L=65S*3L*"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E
M<ULQ72!A<R`D=F%L=64I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&1A
M=&5S6UT@/2`D=&AI<RT^7W!A<G-E1&%T92@D=F%L=64I.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T071T
M<FEB=71E*"1T86<L(&ES<V5T*"1D871E<ULP72D@/R`D9&%T97-;,%T@.B!N
M=6QL+"`D<&%R86US+"!T<G5E+"`D9&%T97,I.PH@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@("`@("\O($1U<F%T:6]N(&9I96QD
M<RX*("`@("`@("`@("`@("`@(&-A<V4@)T154D%424].)SH*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E*"1T86<L("1T:&ES+3Y?
M<&%R<V5$=7)A=&EO;B@D=F%L=64I+"`D<&%R86US*3L*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`O+R!097)I;V0@;V8@
M=&EM92!F:65L9',N"B`@("`@("`@("`@("`@("!C87-E("=&4D5%0E5362<Z
M"B`@("`@("`@("`@("`@("`@("`@)'!E<FEO9',@/2!A<G)A>2@I.PH@("`@
M("`@("`@("`@("`@("`@('!R96=?;6%T8VA?86QL*"<O+"A;7BQ=*BDO)RP@
M)RPG("X@)'9A;'5E+"`D=F%L=65S*3L*("`@("`@("`@("`@("`@("`@("!F
M;W)E86-H("@D=F%L=65S6S%=(&%S("1V86QU92D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D<&5R:6]D<UM=(#T@)'1H:7,M/E]P87)S95!E<FEO9"@D
M=F%L=64I.PH@("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$%T=')I8G5T92@D=&%G+"!I<W-E="@D<&5R:6]D
M<ULP72D@/R`D<&5R:6]D<ULP72`Z(&YU;&PL("1P87)A;7,L('1R=64L("1P
M97)I;V1S*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("`@("`O+R!55$,@;V9F<V5T(&9I96QD<RX*("`@("`@("`@("`@("`@
M(&-A<V4@)U1:3T9&4T541E)/32<Z"B`@("`@("`@("`@("`@("!C87-E("=4
M6D]&1E-%5%1/)SH*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T071T
M<FEB=71E*"1T86<L("1T:&ES+3Y?<&%R<V55=&-/9F9S970H)'9A;'5E*2P@
M)'!A<F%M<RD["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("`@("`@+R\@26YT96=E<B!F:65L9',N"B`@("`@("`@("`@("`@("!C
M87-E("=015)#14Y4+4-/35!,151%)SH*("`@("`@("`@("`@("`@(&-A<V4@
M)U!224]22519)SH*("`@("`@("`@("`@("`@(&-A<V4@)U)%4$5!5"<Z"B`@
M("`@("`@("`@("`@("!C87-E("=315%514Y#12<Z"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$%T=')I8G5T92@D=&%G+"!I;G1V86PH)'9A;'5E
M*2P@)'!A<F%M<RD["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("`@("`@+R\@1V5O(&9I96QD<RX*("`@("`@("`@("`@("`@(&-A
M<V4@)T=%3R<Z"B`@("`@("`@("`@("`@("`@("`@)&9L;V%T<R`](&5X<&QO
M9&4H)SLG+"`D=F%L=64I.PH@("`@("`@("`@("`@("`@("`@("1V86QU95LG
M;&%T:71U9&4G72`](&9L;V%T=F%L*"1F;&]A='-;,%TI.PH@("`@("`@("`@
M("`@("`@("`@("1V86QU95LG;&]N9VET=61E)UT@/2!F;&]A='9A;"@D9FQO
M871S6S%=*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T071T<FEB
M=71E*"1T86<L("1V86QU92P@)'!A<F%M<RD["B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("`@("`@+R\@4F5C=7)S:6]N(&9I96QD
M<RX*("`@("`@("`@("`@("`@(&-A<V4@)T584E5,12<Z"B`@("`@("`@("`@
M("`@("!C87-E("=24E5,12<Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G-E=$%T=')I8G5T92@D=&%G+"!T<FEM*"1V86QU92DL("1P87)A;7,I.PH@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@("\O
M($%$4BP@86YD($X@87)E(&QI<W1S('-E<&5R871E9"!B>2!U;F5S8V%P960*
M("`@("`@("`@("`@("`@("\O('-E;6EC;VQO;G,@=VET:"!A('-P96-I9FEC
M(&YU;6)E<B!O9B!S;&]T<RX*("`@("`@("`@("`@("`@(&-A<V4@)T%$4B<Z
M"B`@("`@("`@("`@("`@("!C87-E("=.)SH*("`@("`@("`@("`@("`@("`@
M("`D=F%L=64@/2!T<FEM*"1V86QU92D["B`@("`@("`@("`@("`@("`@("`@
M+R\@07,@;V8@<F9C(#(T,C8@,BXT+C(@<V5M:6-O;&]N+"!C;VUM82P@86YD
M"B`@("`@("`@("`@("`@("`@("`@+R\@8V]L;VX@;75S="!B92!E<V-A<&5D
M("AC;VUM82!I<R!U;F5S8V%P960@869T97(*("`@("`@("`@("`@("`@("`@
M("`O+R!S<&QI='1I;F<@8F5L;W<I+@H@("`@("`@("`@("`@("`@("`@("1V
M86QU92`]('-T<E]R97!L86-E*&%R<F%Y*"=<7&XG+"`G7%P[)RP@)UQ<.B<I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"1T:&ES+3Y?;F5W;&EN92P@)SLG+"`G.B<I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92D["@H@("`@("`@
M("`@("`@("`@("`@("\O(%-P;&ET(&)Y('5N97-C87!E9"!S96UI8V]L;VYS
M.@H@("`@("`@("`@("`@("`@("`@("1V86QU97,@/2!P<F5G7W-P;&ET*"<O
M*#\\(5Q<7%PI.R\G+"`D=F%L=64I.PH@("`@("`@("`@("`@("`@("`@("1V
M86QU92`]('-T<E]R97!L86-E*"=<7#LG+"`G.R<L("1V86QU92D["B`@("`@
M("`@("`@("`@("`@("`@)'9A;'5E<R`]('-T<E]R97!L86-E*"=<7#LG+"`G
M.R<L("1V86QU97,I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971!
M='1R:6)U=&4H)'1A9RP@=')I;2@D=F%L=64I+"`D<&%R86US+"!T<G5E+"`D
M=F%L=65S*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("`@("`O+R!/4D<@:7,@82!L:7-T('-E<&5R871E9"!B>2!U;F5S8V%P
M960@<V5M:6-O;&]N<R!B=70*("`@("`@("`@("`@("`@("\O('=I=&@@;F\@
M96UP='D@=F%L=65S+@H@("`@("`@("`@("`@("`@8V%S92`G3U)')SH*("`@
M("`@("`@("`@("`@("`@("`D=F%L=64@/2!T<FEM*"1V86QU92D["B`@("`@
M("`@("`@("`@("`@("`@+R\@07,@;V8@<F9C(#(T,C8@,BXT+C(@<V5M:6-O
M;&]N+"!C;VUM82P@86YD"B`@("`@("`@("`@("`@("`@("`@+R\@8V]L;VX@
M;75S="!B92!E<V-A<&5D("AC;VUM82!I<R!U;F5S8V%P960@869T97(*("`@
M("`@("`@("`@("`@("`@("`O+R!S<&QI='1I;F<@8F5L;W<I+@H@("`@("`@
M("`@("`@("`@("`@("1V86QU92`]('-T<E]R97!L86-E*&%R<F%Y*"=<7&XG
M+"`G7%P[)RP@)UQ<.B<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"1T:&ES+3Y?;F5W;&EN92P@)SLG+"`G.B<I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V
M86QU92D["@H@("`@("`@("`@("`@("`@("`@("\O(%-P;&ET(&)Y('5N97-C
M87!E9"!S96UI8V]L;VYS.@H@("`@("`@("`@("`@("`@("`@("1V86QU97,@
M/2!P<F5G7W-P;&ET*"<O*#\\(5Q<7%PI.R\G+"`D=F%L=64L("TQ+"!04D5'
M7U-03$E47TY/7T5-4%19*3L*("`@("`@("`@("`@("`@("`@("`D=F%L=64@
M/2!S=')?<F5P;&%C92@G7%P[)RP@)SLG+"`D=F%L=64I.PH@("`@("`@("`@
M("`@("`@("`@("1V86QU97,@/2!S=')?<F5P;&%C92@G7%P[)RP@)SLG+"`D
M=F%L=65S*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T071T<FEB
M=71E*"1T86<L('1R:6TH)'9A;'5E*2P@)'!A<F%M<RP@=')U92P@)'9A;'5E
M<RD["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@
M("`@+R\@4W1R:6YG(&9I96QD<RX*("`@("`@("`@("`@("`@(&1E9F%U;'0Z
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YI<T]L9$9O<FUA="@I
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\O('9C86QE;F1A<B`Q+C`@
M86YD('9C87)D(#(N,2!O;FQY(&5S8V%P92!S96UI8V]L;VYS"B`@("`@("`@
M("`@("`@("`@("`@("`@("\O(&%N9"!U<V4@=6YE<V-A<&5D('-E;6EC;VQO
M;G,@=&\@8W)E871E(&QI<W1S+@H@("`@("`@("`@("`@("`@("`@("`@("`D
M=F%L=64@/2!T<FEM*"1V86QU92D["B`@("`@("`@("`@("`@("`@("`@("`@
M("\O(%-P;&ET(&)Y('5N97-C87!E9"!S96UI8V]L;VYS.@H@("`@("`@("`@
M("`@("`@("`@("`@("`D=F%L=65S(#T@<')E9U]S<&QI="@G+R@_/"%<7%Q<
M*3LO)RP@)'9A;'5E*3L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E
M(#T@<W1R7W)E<&QA8V4H)UQ<.R<L("<[)RP@)'9A;'5E*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@)'9A;'5E<R`]('-T<E]R97!L86-E*"=<7#LG+"`G
M.R<L("1V86QU97,I.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M<V5T071T<FEB=71E*"1T86<L('1R:6TH)'9A;'5E*2P@)'!A<F%M<RP@=')U
M92P@)'9A;'5E<RD["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@=')I;2@D=F%L=64I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!!<R!O9B!R9F,@,C0R-B`R+C0N
M,B!S96UI8V]L;VXL(&-O;6UA+"!A;F0*("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@8V]L;VX@;75S="!B92!E<V-A<&5D("AC;VUM82!I<R!U;F5S8V%P
M960@869T97(*("`@("`@("`@("`@("`@("`@("`@("`@+R\@<W!L:71T:6YG
M(&)E;&]W*2X*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@<W1R
M7W)E<&QA8V4H87)R87DH)UQ<;B<L("=<7#LG+"`G7%PZ)RDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1T
M:&ES+3Y?;F5W;&EN92P@)SLG+"`G.B<I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64I.PH*("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@4W!L:70@8GD@=6YE<V-A<&5D(&-O;6UA<SH*
M("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E<R`]('!R96=?<W!L:70H
M)R\H/SPA7%Q<7"DL+R<L("1V86QU92D["B`@("`@("`@("`@("`@("`@("`@
M("`@("1V86QU92`]('-T<E]R97!L86-E*"=<7"PG+"`G+"<L("1V86QU92D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU97,@/2!S=')?<F5P;&%C
M92@G7%PL)RP@)RPG+"`D=F%L=65S*3L*"B`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YS971!='1R:6)U=&4H)'1A9RP@=')I;2@D=F%L=64I+"`D
M<&%R86US+"!T<G5E+"`D=F%L=65S*3L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@17AP;W)T('1H:7,@8V]M<&]N96YT
M(&EN('9#86P@9F]R;6%T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&)A<V4@(%1H92!T>7!E(&]F('1H92!B87-E(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@=D-A;"!F;W)M870@9&%T82X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V5X<&]R='9$871A*"1B87-E(#T@)U9#04Q%3D1!
M4B<I"B`@("!["B`@("`@("`@)')E<W5L="`]("="14=)3CHG("X@4W1R:6YG
M.CIU<'!E<B@D8F%S92D@+B`D=&AI<RT^7VYE=VQI;F4["@H@("`@("`@("\O
M(%9%4E-)3TX@:7,@;F]T(&%L;&]W960@9F]R(&5N=')I97,@96YC;&]S960@
M:6X@5D-!3$5.1$%2+TE#04Q%3D1!4BP*("`@("`@("`O+R!A<R!I="!I<R!P
M87)T(&]F('1H92!E;F-L;W-I;F<@5D-!3$5.1$%2+TE#04Q%3D1!4BX@4V5E
M(')F8S(T-#4*("`@("`@("!I9B`H)&)A<V4@(3T]("=6159%3E0G("8F("1B
M87-E("$]/2`G5E1/1$\G("8F("1B87-E("$]/2`G5D%,05)-)R`F)@H@("`@
M("`@("`@("`D8F%S92`A/3T@)U9*3U523D%,)R`F)B`D8F%S92`A/3T@)U9&
M4D5%0E5362<I('L*("`@("`@("`@("`@+R\@16YS=7)E('1H870@=F5R<VEO
M;B!I<R!T:&4@9FER<W0@871T<FEB=71E+@H@("`@("`@("`@("`D<F5S=6QT
M("X]("=615)324]..B<@+B`D=&AI<RT^7W9E<G-I;VX@+B`D=&AI<RT^7VYE
M=VQI;F4["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?871T
M<FEB=71E<R!A<R`D871T<FEB=71E*2!["B`@("`@("`@("`@("1N86UE(#T@
M)&%T=')I8G5T95LG;F%M92==.PH@("`@("`@("`@("!I9B`H)&YA;64@/3T@
M)U9%4E-)3TXG*2!["B`@("`@("`@("`@("`@("`O+R!!;')E861Y(&1O;F4N
M"B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@)'!A<F%M<U]S='(@/2`G)SL*("`@("`@("`@("`@)'!A<F%M
M<R`]("1A='1R:6)U=&5;)W!A<F%M<R==.PH@("`@("`@("`@("!I9B`H)'!A
M<F%M<RD@>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D
M<&%R86U?;F%M92`]/B`D<&%R86U?=F%L=64I('L*("`@("`@("`@("`@("`@
M("`@("`O+R!3:VEP($-(05)3150@9F]R(&E#86QE;F1A<B`R+C`@9&%T82P@
M;F]T"B`@("`@("`@("`@("`@("`@("`@+R\@86QL;W=E9"X*("`@("`@("`@
M("`@("`@("`@("!I9B`H)'!A<F%M7VYA;64@/3T@)T-(05)3150G("8F("$D
M=&AI<RT^:7-/;&1&;W)M870H*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!C;VYT:6YU93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@)'!A<F%M<U]S='(@+CT@(CLD<&%R86U?;F%M93TD<&%R86U?
M=F%L=64B.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D=F%L=64@/2`D871T<FEB=71E6R=V86QU92==.PH@("`@("`@
M("`@("!S=VET8V@@*"1N86UE*2!["B`@("`@("`@("`@("\O($1A=&4@9FEE
M;&1S+@H@("`@("`@("`@("!C87-E("=#3TU03$54140G.@H@("`@("`@("`@
M("!C87-E("=#4D5!5$5$)SH*("`@("`@("`@("`@8V%S92`G1$-214%4140G
M.@H@("`@("`@("`@("!C87-E("=,05-4+4U/1$E&245$)SH*("`@("`@("`@
M("`@("`@("1V86QU92`]("1T:&ES+3Y?97AP;W)T1&%T951I;64H)'9A;'5E
M*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G
M1%1%3D0G.@H@("`@("`@("`@("!C87-E("=$5%-405)4)SH*("`@("`@("`@
M("`@8V%S92`G1%135$%-4"<Z"B`@("`@("`@("`@(&-A<V4@)T1512<Z"B`@
M("`@("`@("`@(&-A<V4@)T%!3$%232<Z"B`@("`@("`@("`@(&-A<V4@)U)%
M0U524D5.0T4M240G.@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P87)A
M;7-;)U9!3%5%)UTI*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1P87)A
M;7-;)U9!3%5%)UT@/3T@)T1!5$4G*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1V86QU92`]("1T:&ES+3Y?97AP;W)T1&%T92@D=F%L=64I.PH@("`@
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1V86QU92`]("1T:&ES+3Y?97AP;W)T1&%T951I;64H)'9A;'5E*3L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1V86QU92`]("1T:&ES+3Y?97AP;W)T
M1&%T951I;64H)'9A;'5E*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@+R\@0V]M;6$@<V5P97)A=&5D
M(&1A=&5S+@H@("`@("`@("`@("!C87-E("=%6$1!5$4G.@H@("`@("`@("`@
M("!C87-E("=21$%412<Z"B`@("`@("`@("`@("`@("`D9&%T97,@/2!A<G)A
M>2@I.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E(&%S("1D871E
M*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;)U9!
M3%5%)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D<&%R86US
M6R=604Q512==(#T]("=$051%)RD@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1A=&5S6UT@/2`D=&AI<RT^7V5X<&]R=$1A=&4H)&1A=&4I.PH@
M("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'!A<F%M<ULG5D%,
M544G72`]/2`G4$5224]$)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&1A=&5S6UT@/2`D=&AI<RT^7V5X<&]R=%!E<FEO9"@D9&%T92D["B`@
M("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&%T97-;72`]("1T:&ES+3Y?97AP;W)T1&%T951I
M;64H)&1A=&4I.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&1A=&5S6UT@/2`D=&AI<RT^7V5X<&]R=$1A=&54:6UE*"1D871E*3L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D=F%L=64@/2!I;7!L;V1E*"<L)RP@)&1A=&5S*3L*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G5%))1T=%4B<Z
M"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG5D%,544G72DI
M('L*("`@("`@("`@("`@("`@("`@("!I9B`H)'!A<F%M<ULG5D%,544G72`]
M/2`G1$%412U424U%)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%L
M=64@/2`D=&AI<RT^7V5X<&]R=$1A=&54:6UE*"1V86QU92D["B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E:68@*"1P87)A;7-;)U9!3%5%)UT@/3T@)T15
M4D%424].)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2`D
M=&AI<RT^7V5X<&]R=$1U<F%T:6]N*"1V86QU92D["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D=F%L=64@/2`D=&AI<RT^7V5X<&]R=$1U<F%T:6]N*"1V86QU
M92D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@("\O($1U<F%T:6]N(&9I96QD<RX*("`@("`@("`@("`@
M8V%S92`G1%52051)3TXG.@H@("`@("`@("`@("`@("`@)'9A;'5E(#T@)'1H
M:7,M/E]E>'!O<G1$=7)A=&EO;B@D=F%L=64I.PH@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("`O+R!097)I;V0@;V8@=&EM92!F:65L9',N
M"B`@("`@("`@("`@(&-A<V4@)T92145"55-9)SH*("`@("`@("`@("`@("`@
M("1V86QU95]S='(@/2`G)SL*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V
M86QU92!A<R`D<&5R:6]D*2!["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E
M7W-T<B`N/2!E;7!T>2@D=F%L=65?<W1R*2`_("<G(#H@)RPG.PH@("`@("`@
M("`@("`@("`@("`@("1V86QU95]S='(@+CT@)'1H:7,M/E]E>'!O<G1097)I
M;V0H)'!E<FEO9"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D=F%L=64@/2`D=F%L=65?<W1R.PH@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("`O+R!55$,@;V9F<V5T(&9I96QD<RX*("`@("`@("`@
M("`@8V%S92`G5%I/1D93151&4D]-)SH*("`@("`@("`@("`@8V%S92`G5%I/
M1D9315143R<Z"B`@("`@("`@("`@("`@("`D=F%L=64@/2`D=&AI<RT^7V5X
M<&]R=%5T8T]F9G-E="@D=F%L=64I.PH@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("`O+R!);G1E9V5R(&9I96QD<RX*("`@("`@("`@("`@
M8V%S92`G4$520T5.5"U#3TU03$5412<Z"B`@("`@("`@("`@(&-A<V4@)U!2
M24]22519)SH*("`@("`@("`@("`@8V%S92`G4D5014%4)SH*("`@("`@("`@
M("`@8V%S92`G4T51545.0T4G.@H@("`@("`@("`@("`@("`@)'9A;'5E(#T@
M(B1V86QU92(["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M("\O($=E;R!F:65L9',N"B`@("`@("`@("`@(&-A<V4@)T=%3R<Z"B`@("`@
M("`@("`@("`@("`D=F%L=64@/2`D=F%L=65;)VQA=&ET=61E)UT@+B`G+"<@
M+B`D=F%L=65;)VQO;F=I='5D92==.PH@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("`O+R!296-U<G)E;F-E(&9I96QD<RX*("`@("`@("`@
M("`@8V%S92`G15A254Q%)SH*("`@("`@("`@("`@8V%S92`G4E)53$4G.@H@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`O+R!!='1E;F1A
M;F-E"B`@("`@("`@("`@(&-A<V4@)T%45$5.1$5%)SH*("`@("`@("`@("`@
M("`@("\O($MR;VYO;&ET:"!C<F5A=&5S(&%T=&5N9&5E(&9I96QD(&EN('9C
M86QE;F1A<C(N,"!F;W)M870N"B`@("`@("`@("`@("`@("`O+R!#;VYV97)T
M('1O('9C86QE;F1A<C$N,"!I9B!N96-E<W-A<GDN"B`@("`@("`@("`@("`@
M("`O+R!%>&%M<&QE(&]F(#$N,"!S='EL93H*("`@("`@("`@("`@("`@("\O
M($%45$5.1$5%.U)/3$4]3U=.15([4U1!5%53/4-/3D9)4DU%1#I*;VAN(%-M
M:71H(#QJ<VUI=&A`:&]S=#$N8V]M/@H@("`@("`@("`@("`@("`@:68@*"1T
M:&ES+3YI<T]L9$9O<FUA="@I*2!["B`@("`@("`@("`@("`@("`@("`@)'9A
M;'5E(#T@<')E9U]R97!L86-E*"<O34%)3%1/.B\G+"`G)RP@)'9A;'5E*3L*
M("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2`@)'9A;'5E("X@)R`\)R`N
M("1V86QU92`N("<^)SL*("`@("`@("`@("`@("`@("`@("`D<&%R86US7W-T
M<B`]('-T<E]R97!L86-E*"=005)44U1!5#TG+"`G4U1!5%53/2<L("1P87)A
M;7-?<W1R*3L*("`@("`@("`@("`@("`@("`@("`D<&%R86US7W-T<B`]('-T
M<E]R97!L86-E*"=35$%455,]3D5%1%,M04-424].)RP@)U-405154SU.145$
M4R!!0U1)3TXG+"`D<&%R86US7W-T<BD["B`@("`@("`@("`@("`@("`@("`@
M)'!A<F%M<U]S='(@/2!S=')?<F5P;&%C92@G4D],13U215$M4$%25$E#25!!
M3E0G+"`G15A014-4/5)%455)4D4G+"`D<&%R86US7W-T<BD["B`@("`@("`@
M("`@("`@("`@("`@)'!A<F%M<U]S='(@/2!S=')?<F5P;&%C92@G4D],13U/
M4%0M4$%25$E#25!!3E0G+"`G15A014-4/5)%455%4U0G+"`D<&%R86US7W-T
M<BD["B`@("`@("`@("`@("`@("`@("`@)'!A<F%M<U]S='(@/2!S=')?<F5P
M;&%C92@G4D],13U.3TXM4$%25$E#25!!3E0G+"`G15A014-4/49922<L("1P
M87)A;7-?<W1R*3L*("`@("`@("`@("`@("`@("`@("`D<&%R86US7W-T<B`]
M('-T<E]R97!L86-E*"=24U90/512544G+"`G4E-64#U915,G+"`D<&%R86US
M7W-T<BD["B`@("`@("`@("`@("`@("`@("`@)'!A<F%M<U]S='(@/2!S=')?
M<F5P;&%C92@G4E-64#U&04Q312<L("=24U90/4Y/)RP@)'!A<F%M<U]S='(I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M
M/FES3VQD1F]R;6%T*"DI('L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?
M87)R87DH)&%T=')I8G5T95LG=F%L=65S)UTI"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`F)B!C;W5N="@D871T<FEB=71E6R=V86QU97,G72D^,2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=65S(#T@)&%T=')I8G5T
M95LG=F%L=65S)UT["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D;F%M
M92`]/2`G3B<@?'P@)&YA;64@/3T@)T%$4B<I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1G;'5E(#T@)SLG.PH@("`@("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&=L
M=64@/2`G+"<["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`@("`@)'9A;'5E<R`@/2!S=')?<F5P;&%C92AA<G)A>2@G
M.R<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@G7%P[)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1V86QU97,I.PH@("`@("`@("`@("`@("`@
M("`@("`@("`D=F%L=64@/2!I;7!L;V1E*"1G;'5E+"`D=F%L=65S*3L*("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`O*B!V8V%R9"`R+C$@86YD('9C86QE;F1A<B`Q+C`@97-C87!E(&]N
M;'D*("`@("`@("`@("`@("`@("`@("`@("`@("H@<V5M:6-O;&]N<R`J+PH@
M("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2!S=')?<F5P;&%C92AA
M<G)A>2@G.R<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@G7%P[)RDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92D["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF("@D;F%M92`]/2`G
M4U1!5%53)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`O+R!V8V%L96YD
M87(@,2XP(&AA<R!35$%455,Z3D5%1%,@04-424].('=H:6QE(#(N,"!H87,*
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@4U1!5%53.DY%1413+4%#5$E/
M3BX*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@<W1R7W)E<&QA
M8V4H)TY%1413+4%#5$E/3B<L("=.145$4R!!0U1)3TXG+"`D=F%L=64I.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`O+R!4
M97AT(&-O;G1A:6YI;F<@;F5W;&EN97,@;W(@05-#24D@/CT@,3(W(&UU<W0@
M8F4@0D%3138T"B`@("`@("`@("`@("`@("`@("`@+R\@;W(@455/5$5$+5!2
M24Y404),12!E;F-O9&5D+B!#=7)R96YT;'D@=V4@=7-E"B`@("`@("`@("`@
M("`@("`@("`@+R\@455/5$5$+5!224Y404),12!A<R!D969A=6QT+@H@("`@
M("`@("`@("`@("`@("`@("\O($9)6$U%.B!D96%L('=I=&@@8F%S938T(&5N
M8V]D:6YG<R$*("`@("`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@B
M+UM>7'@R,"U<>#=&72\B+"`D=F%L=64I"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`F)B!E;7!T>2@D<&%R86US6R=%3D-/1$E.1R==*2D@('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<ULG14Y#3T1)3D<G72`]("=1
M54]4140M4%))3E1!0DQ%)SL*("`@("`@("`@("`@("`@("`@("`@("`@)'!A
M<F%M<U]S='(@+CT@)SM%3D-/1$E.1SU154]4140M4%))3E1!0DQ%)SL*("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@061D($-(05)3150@87,@=V5L;"X@
M070@;&5A<W0@=&AE('-Y;G1H97-I<R!C;&EE;G0*("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@9V5T<R!C;VYF=7-E9"!O=&AE<G=I<V4*("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1P87)A;7-;)T-(05)3150G72DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;7-;)T-!4E-%
M5"==(#T@3DQ3.CIG971#:&%R<V5T*"D["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&%R86US7W-T<B`N/2`G.T-(05)3150])R`N("1P87)A;7-;
M)T-!4E-%5"==.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)&%T=')I8G5T95LG=F%L=65S
M)UTI"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`F)B!C;W5N="@D871T
M<FEB=71E6R=V86QU97,G72D^,2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D=F%L=65S(#T@)&%T=')I8G5T95LG=F%L=65S)UT["B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@D;F%M92`]/2`G3B<@?'P@)&YA;64@/3T@)T%$
M4B<I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1G;'5E(#T@)SLG
M.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&=L=64@/2`G+"<["B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E<R`]
M('-T<E]R97!L86-E*&%R<F%Y*"<[)RP@)SHG+"`G+"<L("=-04E,5$]<7#HG
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)UQ<.R<L("=<7#HG+"`G7%PL)RP@)TU!24Q43SHG*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A
M;'5E<RD["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`](&EM<&QO
M9&4H)&=L=64L("1V86QU97,I.PH@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@("\O($%S(&]F(')F8R`R-#(V
M(#(N-"XR('-E;6EC;VQO;BP@8V]M;6$L(&%N9"!C;VQO;@H@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!M=7-T(&)E(&5S8V%P960N($5X8VQU9&4@34%)
M3%1/.B!T:&]U9V@N(%1H:7,@:7,@80H@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!H86-K(0H@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2!S
M=')?<F5P;&%C92AA<G)A>2@G.R<L("<Z)RP@)RPG+"`G34%)3%1/7%PZ)RDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"=<7#LG+"`G7%PZ)RP@)UQ<+"<L("=-04E,5$\Z)RDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V86QU
M92D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(&EF("@A96UP='DH)'!A<F%M<ULG14Y#3T1)3D<G72D@)B8*("`@("`@
M("`@("`@("`@("1P87)A;7-;)T5.0T]$24Y')UT@/3T@)U%53U1%1"U04DE.
M5$%"3$4G("8F('-T<FQE;BAT<FEM*"1V86QU92DI(#X@,"D@>PH@("`@("`@
M("`@("`@("`@+RH@<75O=&5D4')I;G1A8FQE16YC;V1E(&1O97,@;F]T(&5S
M8V%P92!#4DQ&<RP@8G5T('-T<F%N9V4*("`@("`@("`@("`@("`@("`J(&5N
M;W5G:"!S:6YG;&4@3$9S+B!S;R!C;VYV97)T(&5V97)Y=&AI;F<@=&\@3$8@
M;VYL>2!A;F0*("`@("`@("`@("`@("`@("`J(')E<&QA8V4@869T97)W87)D
M<RX@*B\*("`@("`@("`@("`@("`@("1V86QU92`]('-T<E]R97!L86-E*")<
M<B(L("<G+"`D=F%L=64I.PH@("`@("`@("`@("`@("`@)')E<W5L="`N/2`B
M)&YA;64D<&%R86US7W-T<CH](B`N("1T:&ES+3Y?;F5W;&EN90H@("`@("`@
M("`@("`@("`@("`@("X@<W1R7W)E<&QA8V4H)STP02<L("<],$0],$$G+"`D
M=&AI<RT^7W%U;W1E9%!R:6YT86)L945N8V]D92@D=F%L=64I*0H@("`@("`@
M("`@("`@("`@("`@("X@)'1H:7,M/E]N97=L:6YE.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)&%T=')?<W1R:6YG(#T@(B1N86UE
M)'!A<F%M<U]S='(Z)'9A;'5E(CL*("`@("`@("`@("`@("`@("1R97-U;'0@
M+CT@)'1H:7,M/E]F;VQD3&EN92@D871T<E]S=')I;F<I("X@)'1H:7,M/E]N
M97=L:6YE.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!F;W)E
M86-H("@D=&AI<RT^7V-O;7!O;F5N=',@87,@)&-O;7!O;F5N="D@>PH@("`@
M("`@("`@("`D<F5S=6QT("X]("1C;VUP;VYE;G0M/F5X<&]R='9#86QE;F1A
M<B@I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97-U;'0@+B`G14Y$
M.B<@+B`D8F%S92`N("1T:&ES+3Y?;F5W;&EN93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%!A<G-E(&$@551#($]F9G-E="!F:65L9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W!A<G-E571C3V9F<V5T*"1T97AT*0H@("`@>PH@("`@("`@
M("1O9F9S970@/2!A<G)A>2@I.PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O
M*%PK?"TI*%LP+3E=>S)]*2A;,"TY77LR?2DH6S`M.5U[,GTI/R\G+"`D=&5X
M="P@)'1I;65087)T<RDI('L*("`@("`@("`@("`@)&]F9G-E=%LG86AE860G
M72`@/2`H8F]O;"DH)'1I;65087)T<ULQ72`]/2`G*R<I.PH@("`@("`@("`@
M("`D;V9F<V5T6R=H;W5R)UT@("`](&EN='9A;"@D=&EM95!A<G1S6S)=*3L*
M("`@("`@("`@("`@)&]F9G-E=%LG;6EN=71E)UT@/2!I;G1V86PH)'1I;650
M87)T<ULS72D["B`@("`@("`@("`@(&EF("AI<W-E="@D=&EM95!A<G1S6S1=
M*2D@>PH@("`@("`@("`@("`@("`@)&]F9G-E=%LG<V5C;VYD)UT@/2!I;G1V
M86PH)'1I;65087)T<ULT72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M<F5T=7)N("1O9F9S970["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($5X<&]R="!A(%540R!/9F9S970@9FEE;&0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]E>'!O<G15=&-/9F9S970H)'9A;'5E*0H@("`@>PH@("`@("`@("1O
M9F9S970@/2`D=F%L=65;)V%H96%D)UT@/R`G*R<@.B`G+2<["B`@("`@("`@
M)&]F9G-E="`N/2!S<')I;G1F*"<E,#)D)3`R9"<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1V86QU95LG:&]U<B==+"`D=F%L=65;)VUI;G5T92==
M*3L*("`@("`@("!I9B`H:7-S970H)'9A;'5E6R=S96-O;F0G72DI('L*("`@
M("`@("`@("`@)&]F9G-E="`N/2!S<')I;G1F*"<E,#)D)RP@)'9A;'5E6R=S
M96-O;F0G72D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&]F9G-E=#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%!A<G-E(&$@5&EM92!097)I;V0@9FEE
M;&0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S95!E<FEO9"@D=&5X="D*
M("`@('L*("`@("`@("`D<&5R:6]D4&%R=',@/2!E>'!L;V1E*"<O)RP@)'1E
M>'0I.PH*("`@("`@("`D<W1A<G0@/2`D=&AI<RT^7W!A<G-E1&%T951I;64H
M)'!E<FEO9%!A<G1S6S!=*3L*"B`@("`@("`@:68@*"1D=7)A=&EO;B`]("1T
M:&ES+3Y?<&%R<V5$=7)A=&EO;B@D<&5R:6]D4&%R='-;,5TI*2!["B`@("`@
M("`@("`@(')E='5R;B!A<G)A>2@G<W1A<G0G(#T^("1S=&%R="P@)V1U<F%T
M:6]N)R`]/B`D9'5R871I;VXI.PH@("`@("`@('T@96QS96EF("@D96YD(#T@
M)'1H:7,M/E]P87)S941A=&54:6UE*"1P97)I;V1087)T<ULQ72DI('L*("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y*"=S=&%R="<@/3X@)'-T87)T+"`G96YD
M)R`]/B`D96YD*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!%
M>'!O<G0@82!4:6UE(%!E<FEO9"!F:65L9"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V5X<&]R=%!E<FEO9"@D=F%L=64I"B`@("!["B`@("`@("`@)'!E<FEO
M9"`]("1T:&ES+3Y?97AP;W)T1&%T951I;64H)'9A;'5E6R=S=&%R="==*3L*
M("`@("`@("`D<&5R:6]D("X]("<O)SL*("`@("`@("!I9B`H:7-S970H)'9A
M;'5E6R=D=7)A=&EO;B==*2D@>PH@("`@("`@("`@("`D<&5R:6]D("X]("1T
M:&ES+3Y?97AP;W)T1'5R871I;VXH)'9A;'5E6R=D=7)A=&EO;B==*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&5R:6]D("X]("1T:&ES+3Y?
M97AP;W)T1&%T951I;64H)'9A;'5E6R=E;F0G72D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D<&5R:6]D.PH@("`@?0H*("`@("\J*@H@("`@("H@4&%R
M<V5S(&$@1&%T951I;64@9FEE;&0@:6YT;R!A('5N:7@@=&EM97-T86UP+@H@
M("`@("H*("`@("`J($!T;V1O(%1H:7,@9G5N8W1I;VX@<VAO=6QD(&)E(&UO
M=F5D('1O($AO<F1E7T1A=&4@86YD(&UA9&4@<'5B;&EC+@H@("`@("H@0'-T
M871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5$871E5&EM92@D=&5X
M="D*("`@('L*("`@("`@("`D9&%T95!A<G1S(#T@97AP;&]D92@G5"<L("1T
M97AT*3L*("`@("`@("!I9B`H8V]U;G0H)&1A=&5087)T<RD@(3T@,B`F)B`A
M96UP='DH)'1E>'0I*2!["B`@("`@("`@("`@("\O($YO="!A(&1A=&5T:6UE
M(&9I96QD(&)U="!M87D@8F4@:G5S="!A(&1A=&4@9FEE;&0N"B`@("`@("`@
M("`@(&EF("@A)&1A=&4@/2!(;W)D95]I0V%L96YD87(Z.E]P87)S941A=&4H
M)'1E>'0I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&1A=&4["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@<F5T=7)N($!G;6UK=&EM92@P+"`P+"`P
M+"`D9&%T95LG;6]N=&@G72P@)&1A=&5;)VUD87DG72P@)&1A=&5;)WEE87(G
M72D["B`@("`@("`@?0H*("`@("`@("!I9B`H(21D871E(#T@2&]R9&5?:4-A
M;&5N9&%R.CI?<&%R<V5$871E*"1D871E4&%R='-;,%TI*2!["B`@("`@("`@
M("`@(')E='5R;B`D9&%T93L*("`@("`@("!]"B`@("`@("`@:68@*"$D=&EM
M92`]($AO<F1E7VE#86QE;F1A<CHZ7W!A<G-E5&EM92@D9&%T95!A<G1S6S%=
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'1I;64["B`@("`@("`@?0H*("`@
M("`@("!I9B`H)'1I;65;)WIO;F4G72`]/2`G551#)RD@>PH@("`@("`@("`@
M("!R971U<FX@0&=M;6MT:6UE*"1T:6UE6R=H;W5R)UTL("1T:6UE6R=M:6YU
M=&4G72P@)'1I;65;)W-E8V]N9"==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1D871E6R=M;VYT:"==+"`D9&%T95LG;61A>2==+"`D9&%T95LG
M>65A<B==*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M0&UK=&EM92@D=&EM95LG:&]U<B==+"`D=&EM95LG;6EN=71E)UTL("1T:6UE
M6R=S96-O;F0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&5;
M)VUO;G1H)UTL("1D871E6R=M9&%Y)UTL("1D871E6R=Y96%R)UTI.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($5X<&]R="!A($1A=&54:6UE
M(&9I96QD+@H@("`@("HO"B`@("!F=6YC=&EO;B!?97AP;W)T1&%T951I;64H
M)'9A;'5E*0H@("`@>PH@("`@("`@("1T96UP(#T@87)R87DH*3L*("`@("`@
M("!I9B`H(6ES7V]B:F5C="@D=F%L=64I("8F("%I<U]A<G)A>2@D=F%L=64I
M*2!["B`@("`@("`@("`@("1T>B`](&1A=&4H)T\G+"`D=F%L=64I.PH@("`@
M("`@("`@("`D5%I/9F9S970@/2`H,S8P,"`J('-U8G-T<B@D='HL(#`L(#,I
M*2`K("@V,"`J('-U8G-T<BAD871E*"=/)RP@)'9A;'5E*2P@,RP@,BDI.PH@
M("`@("`@("`@("`D=F%L=64@+3T@)%1:3V9F<V5T.PH*("`@("`@("`@("`@
M)'1E;7!;)WIO;F4G72`@(#T@)U540R<["B`@("`@("`@("`@("1T96UP6R=Y
M96%R)UT@("`](&1A=&4H)UDG+"`D=F%L=64I.PH@("`@("`@("`@("`D=&5M
M<%LG;6]N=&@G72`@/2!D871E*"=N)RP@)'9A;'5E*3L*("`@("`@("`@("`@
M)'1E;7!;)VUD87DG72`@(#T@9&%T92@G:B<L("1V86QU92D["B`@("`@("`@
M("`@("1T96UP6R=H;W5R)UT@("`](&1A=&4H)T<G+"`D=F%L=64I.PH@("`@
M("`@("`@("`D=&5M<%LG;6EN=71E)UT@/2!D871E*"=I)RP@)'9A;'5E*3L*
M("`@("`@("`@("`@)'1E;7!;)W-E8V]N9"==(#T@9&%T92@G<R<L("1V86QU
M92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&1A=&5/8B`](&YE
M=R!(;W)D95]$871E*"1V86QU92D["B`@("`@("`@("`@(')E='5R;B!(;W)D
M95]I0V%L96YD87(Z.E]E>'!O<G1$871E5&EM92@D9&%T94]B+3YT:6UE<W1A
M;7`H*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@2&]R9&5?:4-A;&5N
M9&%R.CI?97AP;W)T1&%T92@D=&5M<"D@+B`G5"<@+B!(;W)D95]I0V%L96YD
M87(Z.E]E>'!O<G14:6UE*"1T96UP*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%!A<G-E<R!A(%1I;64@9FEE;&0N"B`@("`@*@H@("`@("H@0'-T871I8PH@
M("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V54:6UE*"1T97AT*0H@("`@>PH@
M("`@("`@(&EF("AP<F5G7VUA=&-H*"<O*%LP+3E=>S)]*2A;,"TY77LR?2DH
M6S`M.5U[,GTI*%HI/R\G+"`D=&5X="P@)'1I;65087)T<RDI('L*("`@("`@
M("`@("`@)'1I;65;)VAO=7(G72`](&EN='9A;"@D=&EM95!A<G1S6S%=*3L*
M("`@("`@("`@("`@)'1I;65;)VUI;G5T92==(#T@:6YT=F%L*"1T:6UE4&%R
M='-;,ETI.PH@("`@("`@("`@("`D=&EM95LG<V5C;VYD)UT@/2!I;G1V86PH
M)'1I;65087)T<ULS72D["B`@("`@("`@("`@(&EF("AI<W-E="@D=&EM95!A
M<G1S6S1=*2D@>PH@("`@("`@("`@("`@("`@)'1I;65;)WIO;F4G72`]("=5
M5$,G.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1I
M;65;)WIO;F4G72`]("=,;V-A;"<["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@<F5T=7)N("1T:6UE.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!%>'!O<G1S(&$@5&EM92!F:65L9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V5X<&]R=%1I;64H)'9A;'5E*0H@("`@>PH@("`@("`@("1T:6UE(#T@<W!R
M:6YT9B@G)3`R9"4P,F0E,#)D)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M)'9A;'5E6R=H;W5R)UTL("1V86QU95LG;6EN=71E)UTL("1V86QU95LG<V5C
M;VYD)UTI.PH@("`@("`@(&EF("@D=F%L=65;)WIO;F4G72`]/2`G551#)RD@
M>PH@("`@("`@("`@("`D=&EM92`N/2`G6B<["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`D=&EM93L*("`@('T*"B`@("`O*BH*("`@("`J(%!A<G-E<R!A
M($1A=&4@9FEE;&0N"B`@("`@*@H@("`@("H@0'-T871I8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!?<&%R<V5$871E*"1T97AT*0H@("`@>PH@("`@("`@("1P
M87)T<R`](&5X<&QO9&4H)U0G+"`D=&5X="D["B`@("`@("`@:68@*&-O=6YT
M*"1P87)T<RD@/3T@,BD@>PH@("`@("`@("`@("`D=&5X="`]("1P87)T<ULP
M73L*("`@("`@("!]"@H@("`@("`@(&EF("@A<')E9U]M871C:"@G+UXH7&1[
M-'TI+3\H7&1[,GTI+3\H7&1[,GTI)"\G+"`D=&5X="P@)&UA=&-H*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@87)R87DH)WEE87(G(#T^("1M871C:%LQ72P*("`@("`@("`@("`@
M("`@("`@("`@)VUO;G1H)R`]/B`D;6%T8VA;,ETL"B`@("`@("`@("`@("`@
M("`@("`@("=M9&%Y)R`]/B`D;6%T8VA;,UTI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@17AP;W)T(&$@1&%T92!F:65L9"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V5X<&]R=$1A=&4H)'9A;'5E*0H@("`@>PH@("`@("`@(&EF("AI<U]O
M8FIE8W0H)'9A;'5E*2D@>PH@("`@("`@("`@("`D=F%L=64@/2!A<G)A>2@G
M>65A<B<@/3X@)'9A;'5E+3YY96%R+"`G;6]N=&@G(#T^("1V86QU92T^;6]N
M=&@L("=M9&%Y)R`]/B`D=F%L=64M/FUD87DI.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@<W!R:6YT9B@G)3`T9"4P,F0E,#)D)RP@)'9A;'5E6R=Y96%R
M)UTL("1V86QU95LG;6]N=&@G72P@)'9A;'5E6R=M9&%Y)UTI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4&%R<V4@82!$=7)A=&EO;B!686QU92!F:65L9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E1'5R871I;VXH)'1E>'0I"B`@
M("!["B`@("`@("`@:68@*'!R96=?;6%T8V@H)R\H6RM=/WQ;+5TI4"@H6S`M
M.5TK5RE\*%LP+3E=*T0I?"DH5"@H6S`M.5TK2"E\*%LP+3E=*TTI?"A;,"TY
M72M3*2DK*3\O)RP@=')I;2@D=&5X="DL("1D=7)V86QU92DI('L*("`@("`@
M("`@("`@+R\@5V5E:W,N"B`@("`@("`@("`@("1D=7)A=&EO;B`](#<@*B`X
M-C0P,"`J(&EN='9A;"@D9'5R=F%L=65;,UTI.PH*("`@("`@("`@("`@:68@
M*&-O=6YT*"1D=7)V86QU92D@/B`T*2!["B`@("`@("`@("`@("`@("`O+R!$
M87ES+@H@("`@("`@("`@("`@("`@)&1U<F%T:6]N("L](#@V-#`P("H@:6YT
M=F%L*"1D=7)V86QU95LT72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*&-O=6YT*"1D=7)V86QU92D@/B`U*2!["B`@("`@("`@("`@("`@("`O
M+R!(;W5R<RX*("`@("`@("`@("`@("`@("1D=7)A=&EO;B`K/2`S-C`P("H@
M:6YT=F%L*"1D=7)V86QU95LW72D["@H@("`@("`@("`@("`@("`@+R\@36EN
M<RX*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9'5R=F%L=65;.%TI*2![
M"B`@("`@("`@("`@("`@("`@("`@)&1U<F%T:6]N("L](#8P("H@:6YT=F%L
M*"1D=7)V86QU95LX72D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`@("`@+R\@4V5C<RX*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9'5R
M=F%L=65;.5TI*2!["B`@("`@("`@("`@("`@("`@("`@)&1U<F%T:6]N("L]
M(&EN='9A;"@D9'5R=F%L=65;.5TI.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O+R!3:6=N+@H@("`@("`@("`@("!I
M9B`H)&1U<G9A;'5E6S%=(#T]("(M(BD@>PH@("`@("`@("`@("`@("`@)&1U
M<F%T:6]N("H]("TQ.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!R971U
M<FX@)&1U<F%T:6]N.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!%
M>'!O<G0@82!D=7)A=&EO;B!V86QU92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V5X<&]R=$1U<F%T:6]N*"1V86QU92D*("`@('L*("`@("`@("`D9'5R871I
M;VX@/2`G)SL*("`@("`@("!I9B`H)'9A;'5E(#P@,"D@>PH@("`@("`@("`@
M("`D=F%L=64@*CT@+3$["B`@("`@("`@("`@("1D=7)A=&EO;B`N/2`G+2<[
M"B`@("`@("`@?0H@("`@("`@("1D=7)A=&EO;B`N/2`G4"<["@H@("`@("`@
M("1W965K<R`](&9L;V]R*"1V86QU92`O("@W("H@.#8T,#`I*3L*("`@("`@
M("`D=F%L=64@/2`D=F%L=64@)2`H-R`J(#@V-#`P*3L*("`@("`@("!I9B`H
M)'=E96MS*2!["B`@("`@("`@("`@("1D=7)A=&EO;B`N/2`D=V5E:W,@+B`G
M5R<["B`@("`@("`@?0H*("`@("`@("`D9&%Y<R`](&9L;V]R*"1V86QU92`O
M("@X-C0P,"DI.PH@("`@("`@("1V86QU92`]("1V86QU92`E("@X-C0P,"D[
M"B`@("`@("`@:68@*"1D87ES*2!["B`@("`@("`@("`@("1D=7)A=&EO;B`N
M/2`D9&%Y<R`N("=$)SL*("`@("`@("!]"@H@("`@("`@(&EF("@D=F%L=64I
M('L*("`@("`@("`@("`@)&1U<F%T:6]N("X]("=4)SL*"B`@("`@("`@("`@
M("1H;W5R<R`](&9L;V]R*"1V86QU92`O(#,V,#`I.PH@("`@("`@("`@("`D
M=F%L=64@/2`D=F%L=64@)2`S-C`P.PH@("`@("`@("`@("!I9B`H)&AO=7)S
M*2!["B`@("`@("`@("`@("`@("`D9'5R871I;VX@+CT@)&AO=7)S("X@)T@G
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D;6EN<R`](&9L;V]R*"1V
M86QU92`O(#8P*3L*("`@("`@("`@("`@)'9A;'5E(#T@)'9A;'5E("4@-C`[
M"B`@("`@("`@("`@(&EF("@D;6EN<RD@>PH@("`@("`@("`@("`@("`@)&1U
M<F%T:6]N("X]("1M:6YS("X@)TTG.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!I9B`H)'9A;'5E*2!["B`@("`@("`@("`@("`@("`D9'5R871I;VX@
M+CT@)'9A;'5E("X@)U,G.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&1U<F%T:6]N.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N('1H92!F;VQD960@=F5R<VEO;B!O9B!A(&QI;F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]F;VQD3&EN92@D;&EN92D*("`@('L*("`@("`@("`D
M;&EN92`]('!R96=?<F5P;&%C92@B+UQR7&Y\7&Y\7'(O(BP@)UQN)RP@)&QI
M;F4I.PH@("`@("`@(&EF("AS=')L96XH)&QI;F4I(#X@-S4I('L*("`@("`@
M("`@("`@)&9O;&1E9&QI;F4@/2`G)SL*("`@("`@("`@("`@=VAI;&4@*"%E
M;7!T>2@D;&EN92DI('L*("`@("`@("`@("`@("`@("1M87A,:6YE(#T@<W5B
M<W1R*"1L:6YE+"`P+"`W-2D["B`@("`@("`@("`@("`@("`D8W5T4&]I;G0@
M/2!M87@H-C`L(&UA>"AS=')R<&]S*"1M87A,:6YE+"`G.R<I+"!S=')R<&]S
M*"1M87A,:6YE+"`G.B<I*2`K(#$I.PH*("`@("`@("`@("`@("`@("1F;VQD
M961L:6YE("X]("AE;7!T>2@D9F]L9&5D;&EN92DI(#\*("`@("`@("`@("`@
M("`@("`@("!S=6)S='(H)&QI;F4L(#`L("1C=710;VEN="D@.@H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;F5W;&EN92`N("<@)R`N('-U8G-T<B@D
M;&EN92P@,"P@)&-U=%!O:6YT*3L*"B`@("`@("`@("`@("`@("`D;&EN92`]
M("AS=')L96XH)&QI;F4I(#P]("1C=710;VEN="D@/R`G)R`Z('-U8G-T<B@D
M;&EN92P@)&-U=%!O:6YT*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R
M971U<FX@)&9O;&1E9&QI;F4["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D
M;&EN93L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G0@86X@.&)I="!S
M=')I;F<@=&\@82!Q=6]T960M<')I;G1A8FQE('-T<FEN9R!A8V-O<F1I;F<*
M("`@("`J('1O(%)&0S(P-#4L('-E8W1I;VX@-BXW+@H@("`@("H*("`@("`J
M(%5S97,@:6UA<%\X8FET(&EF(&%V86EL86)L92X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1I;G!U="`@5&AE('-T<FEN9R!T;R!B92!E;F-O9&5D
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<75O=&5D+7!R
M:6YT86)L92!E;F-O9&5D('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M7W%U;W1E9%!R:6YT86)L945N8V]D92@D:6YP=70@/2`G)RD*("`@('L*("`@
M("`@("`O+R!)9B!I;6%P7SAB:70H*2!I<R!A=F%I;&%B;&4L('5S92!I="X*
M("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=I;6%P7SAB:70G*2D@>PH@
M("`@("`@("`@("!R971U<FX@:6UA<%\X8FET*"1I;G!U="D["B`@("`@("`@
M?0H*("`@("`@("`O+R!2871H97(@9'5M8B!R97!L86-M96YT.B!J=7-T(&5N
M8V]D92!E=F5R>71H:6YG+@H@("`@("`@("1H97@@/2!A<G)A>2@G,"<L("<Q
M)RP@)S(G+"`G,R<L("<T)RP@)S4G+"`G-B<L("<W)RP@)S@G+"`G.2<L"B`@
M("`@("`@("`@("`@("`@("`@("=!)RP@)T(G+"`G0R<L("=$)RP@)T4G+"`G
M1B<I.PH*("`@("`@("`D;W5T<'5T(#T@)R<["B`@("`@("`@)&QE;B`]('-T
M<FQE;B@D:6YP=70I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1L96X[
M("LK)&DI('L*("`@("`@("`@("`@)&,@/2!S=6)S='(H)&EN<'5T+"`D:2P@
M,2D["B`@("`@("`@("`@("1D96,@/2!O<F0H)&,I.PH@("`@("`@("`@("`D
M;W5T<'5T("X]("<])R`N("1H97A;9FQO;W(H)&1E8R`O(#$V*5T@+B`D:&5X
M6V9L;V]R*"1D96,@)2`Q-BE=.PH@("`@("`@("`@("!I9B`H*"1I("L@,2D@
M)2`R-2`]/2`P*2!["B`@("`@("`@("`@("`@("`D;W5T<'5T("X]("(]7')<
M;B(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1O
M=71P=70["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O261E;G1I='DN<&AP````````````````````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#,Q-S0S`#$P-3$U-#,S-S4R`#`R,3<W-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@5&AI<R!C;&%S<R!P<F]V:61E<R!A;B!I;G1E<F9A8V4@=&\@
M86QL(&ED96YT:71I97,@82!U<V5R(&UI9VAT(&AA=F4N($ET<PH@*B!M971H
M;V1S('1A:V4@8V%R92!O9B!A;GD@<VET92US<&5C:69I8R!R97-T<FEC=&EO
M;G,@8V]N9FEG=7)E9"!I;B!P<F5F<RYP:'`*("H@86YD(&-O;F8N<&AP+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]0<F5F<R])9&5N=&ET>2YP:'`L=B`Q
M+C$N,BXR(#(P,#8O,#8O,C@@,C`Z-3(Z-3,@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`R,#`Q+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@
M/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,RXU"B`J($!P
M86-K86=E($AO<F1E7TED96YT:71Y"B`J+PIC;&%S<R!)9&5N=&ET>2!["@H@
M("`@+RHJ"B`@("`@*B!!<G)A>2!C;VYT86EN:6YG(&%L;"!T:&4@=7-E<B=S
M(&ED96YT:71I97,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]I9&5N=&ET:65S(#T@87)R87DH*3L*"B`@("`O*BH*("`@
M("`J($$@<&]I;G1E<B!T;R!T:&4@=7-E<B=S('-T86YD87)D(&ED96YT:71Y
M+@H@("`@("H@5&AI<R!O;F4@:7,@=7-E9"!B>2!T:&4@;65T:&]D<R!R971U
M<FYI;F<@=F%L=65S(&EF(&YO(&]T:&5R(&]N92!I<PH@("`@("H@<W!E8VEF
M:65D+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V
M87(@)%]D969A=6QT(#T@,#L*"B`@("`O*BH*("`@("`J(%1H92!U<V5R('=H
M;W-E(&ED96YT:71I97,@=&AE<V4@87)E+@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W5S97(@/2!N=6QL.PH*("`@("\J
M*@H@("`@("H@07)R87D@8V]N=&%I;FEN9R!A;&P@;V8@=&AE('!R;W!E<G1I
M97,@:6X@=&AI<R!I9&5N=&ET>2X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D7W!R;W!E<G1I97,@/2!A<G)A>2@G:60G+"`G
M9G5L;&YA;64G+"`G9G)O;5]A9&1R)RD["@H@("`@+RHJ"B`@("`@*B!2969E
M<F5N8V4@=&\@=&AE('!R969S(&]B:F5C="!T:&%T('1H:7,@261E;G1I='D@
M<&]I;G1S('1O+@H@("`@("H*("`@("`J($!V87(@4')E9G,*("`@("`J+PH@
M("`@=F%R("1?<')E9G,["@H@("`@+RHJ"B`@("`@*B!296%D<R!A;&P@=&AE
M('5S97(G<R!I9&5N=&ET:65S(&9R;VT@=&AE('!R969S(&]B:F5C="!O<B!B
M=6EL9',@82!N97<*("`@("`J(&ED96YT:71Y(&9R;VT@=&AE('-T86YD87)D
M('9A;'5E<R!G:79E;B!I;B!P<F5F<RYP:'`N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=7-E<B`@268@<W!E8VEF:65D+"!W92!R96%D(&%N;W1H
M97(@=7-E<B=S(&ED96YT:71I97,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@(&EN<W1E860@;V8@=&AE(&-U<G)E;G0@=7-E<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@261E;G1I='DH)'5S97(@/2!N=6QL*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?=7-E<B`]("1U<V5R.PH@("`@("`@(&EF("@H:7-?;G5L;"@D
M=7-E<BD@?'P@)'5S97(@/3T@075T:#HZ9V5T075T:"@I*2`F)@H@("`@("`@
M("`@("!I<W-E="@D1TQ/0D%,4ULG<')E9G,G72DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]P<F5F<R`]("8D1TQ/0D%,4ULG<')E9G,G73L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7W!R969S(#T@)E!R969S.CIS
M:6YG;&5T;VXH)$=,3T)!3%-;)V-O;F8G75LG<')E9G,G75LG9')I=F5R)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T07!P*"DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=7-E<BP@)R<L
M(&YU;&PL(&9A;'-E*3L*("`@("`@("`@("`@)'1H:7,M/E]P<F5F<RT^<F5T
M<FEE=F4H*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A*"1T:&ES+3Y?:61E
M;G1I=&EE<R`]($!U;G-E<FEA;&EZ92@D=&AI<RT^7W!R969S+3YG971686QU
M92@G:61E;G1I=&EE<R<L(&9A;'-E*2DI*2!["B`@("`@("`@("`@("\J($-O
M;G9E<G0@:61E;G1I=&EE<R!F<F]M('1H92!O;&0@9F]R;6%T+B`J+PH@("`@
M("`@("`@("`D=&AI<RT^7VED96YT:71I97,@/2!U;G-E<FEA;&EZ92@D=&AI
M<RT^7W!R969S+3YG971686QU92@G:61E;G1I=&EE<R<I*3L*("`@("`@("!]
M(&5L<V5I9B`H:7-?87)R87DH)'1H:7,M/E]I9&5N=&ET:65S*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7VED96YT:71I97,@/2`D=&AI<RT^7W!R969S+3YC
M;VYV97)T1G)O;41R:79E<B@D=&AI<RT^7VED96YT:71I97,L($Y,4SHZ9V5T
M0VAA<G-E="@I*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YS971$969A
M=6QT*"1T:&ES+3Y?<')E9G,M/F=E=%9A;'5E*"=D969A=6QT7VED96YT:71Y
M)RDI.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A(&1E9F%U;'0@
M:61E;G1I='D@:68@;F]N92!E>&ES=',@>65T(&%N9"!S971S('1H92!P<F5F
M97)E;F-E<PH@("`@("H@=7`@:68@=&AE(&ED96YT:71I97,@87)E(&QO8VME
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@:6YI="@I"B`@("!["B`@("`@("`@
M:68@*"%I<U]A<G)A>2@D=&AI<RT^7VED96YT:71I97,I('Q\("AC;W5N="@D
M=&AI<RT^7VED96YT:71I97,I(#P](#`I*2!["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3Y?<')O<&5R=&EE<R!A<R`D:V5Y*2!["B`@("`@("`@("`@
M("`@("`D:61E;G1I='E;)&ME>5T@/2`D=&AI<RT^7W!R969S+3YG971686QU
M92@D:V5Y*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H96UP='DH
M)&ED96YT:71Y6R=I9"==*2D@>PH@("`@("`@("`@("`@("`@)&ED96YT:71Y
M6R=I9"==(#T@7R@B1&5F875L="!)9&5N=&ET>2(I.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`D=&AI<RT^7VED96YT:71I97,@/2!A<G)A>2@D:61E
M;G1I='DI.PH@("`@("`@("`@("`D=&AI<RT^=F5R:69Y*#`I.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"1T:&ES+3Y?<')E9G,M/FES3&]C:V5D*"=D969A
M=6QT7VED96YT:71Y)RDI('L*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M
M/E]P<F]P97)T:65S(&%S("1K97DI('L*("`@("`@("`@("`@("`@("1V86QU
M92`]("1T:&ES+3YG971686QU92@D:V5Y*3L*("`@("`@("`@("`@("`@(&EF
M("AI<U]A<G)A>2@D=F%L=64I*2!["B`@("`@("`@("`@("`@("`@("`@)'9A
M;'5E(#T@:6UP;&]D92@B7&XB+"`D=F%L=64I.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)'1H:7,M/E]P<F5F<RT^<V5T5F%L=64H)&ME
M>2P@)'9A;'5E*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<')E9G,M/G-E
M=$1I<G1Y*"1K97DL(&9A;'-E*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J(%-A=F5S(&%L;"!I9&5N=&ET:65S(&EN
M('1H92!P<F5F<R!B86-K96YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!S879E
M*"D*("`@('L*("`@("`@("`D:61E;G1I=&EE<R`]("1T:&ES+3Y?:61E;G1I
M=&EE<SL*("`@("`@("!I9B`H:7-?87)R87DH)&ED96YT:71I97,I*2!["B`@
M("`@("`@("`@("1I9&5N=&ET:65S(#T@)'1H:7,M/E]P<F5F<RT^8V]N=F5R
M=%1O1')I=F5R*"1I9&5N=&ET:65S+"!.3%,Z.F=E=$-H87)S970H*2D["B`@
M("`@("`@?0H*("`@("`@("`D=&AI<RT^7W!R969S+3YS971686QU92@G:61E
M;G1I=&EE<R<L('-E<FEA;&EZ92@D:61E;G1I=&EE<RDL(&9A;'-E*3L*("`@
M("`@("`D=&AI<RT^7W!R969S+3YS971686QU92@G9&5F875L=%]I9&5N=&ET
M>2<L("1T:&ES+3Y?9&5F875L="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!
M9&1S(&$@;F5W(&5M<'1Y(&ED96YT:71Y('1O('1H92!A<G)A>2!O9B!I9&5N
M=&ET:65S+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE('!O
M:6YT97(@=&\@=&AE(&-R96%T960@:61E;G1I='D*("`@("`J+PH@("`@9G5N
M8W1I;VX@861D*"D*("`@('L*("`@("`@("`D=&AI<RT^7VED96YT:71I97-;
M72`](&%R<F%Y*"D["B`@("`@("`@<F5T=7)N(&-O=6YT*"1T:&ES+3Y?:61E
M;G1I=&EE<RD@+2`Q.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!A
M;B!I9&5N=&ET>2!F<F]M('1H92!A<G)A>2!O9B!I9&5N=&ET:65S+@H@("`@
M("H*("`@("`J($!P87)A;2!I;G1E9V5R("1I9&5N=&ET>2`@5&AE('!O:6YT
M97(@=&\@=&AE(&ED96YT:71Y('1O(&)E(')E;6]V960*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!4:&4@<F5M;W9E9"!I9&5N=&ET>0H@("`@("HO
M"B`@("!F=6YC=&EO;B!D96QE=&4H)&ED96YT:71Y*0H@("`@>PH@("`@("`@
M("1D96QE=&5D(#T@87)R87E?<W!L:6-E*"1T:&ES+3Y?:61E;G1I=&EE<RP@
M)&ED96YT:71Y+"`Q*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VED96YT
M:71I97,@87,@)&ED(#T^("1N=6QL*2!["B`@("`@("`@("`@(&EF("@D=&AI
M<RT^<V5T1&5F875L="@D:60I*2!["B`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D=&AI<RT^<V%V92@I
M.PH@("`@("`@(')E='5R;B`D9&5L971E9#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@82!P;VEN=&5R('1O('1H92!C=7)R96YT(&1E9F%U;'0@
M:61E;G1I='DN"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@
M<&]I;G1E<B!T;R!T:&4@8W5R<F5N="!D969A=6QT(&ED96YT:71Y"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$1E9F%U;'0H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7V1E9F%U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M971S('1H92!C=7)R96YT(&1E9F%U;'0@:61E;G1I='DN"B`@("`@*B!)9B!T
M:&4@:61E;G1I='D@9&]E<VXG="!E>&ES="P@=&AE(&]L9"!D969A=6QT(&ED
M96YT:71Y('-T87ES('1H92!S86UE+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("1I9&5N=&ET>2`@5&AE('!O:6YT97(@=&\@=&AE(&YE=R!D969A
M=6QT(&ED96YT:71Y"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&9A:6QU<F4*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T1&5F875L="@D:61E;G1I='DI"B`@("!["B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?:61E;G1I=&EE<ULD:61E;G1I='E=*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7V1E9F%U;'0@/2`D:61E;G1I='D["B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS(&$@<')O<&5R='D@9G)O;2!O;F4@;V8@=&AE(&ED96YT
M:71I97,N($EF('1H:7,@=F%L=64@9&]E<VXG=`H@("`@("H@97AI<W0@;W(@
M:7,@;&]C:V5D+"!T:&4@<')O<&5R='D@:7,@<F5T<FEE=F5D(&9R;VT@=&AE
M('!R969S(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M:V5Y("`@("`@("!4:&4@<')O<&5R='D@=&\@<F5T<FEE=F4N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D:61E;G1I='D@(%1H92!I9&5N=&ET>2!T;R!R971R
M:65V92!T:&4@<')O<&5R='D@9G)O;2X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4:&4@=F%L=64@;V8@=&AE('!R;W!E<G1Y+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971686QU92@D:V5Y+"`D:61E;G1I='D@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&EF("@A:7-S970H)&ED96YT:71Y*2!\?"`A:7-S970H
M)'1H:7,M/E]I9&5N=&ET:65S6R1I9&5N=&ET>5TI*2!["B`@("`@("`@("`@
M("1I9&5N=&ET>2`]("1T:&ES+3Y?9&5F875L=#L*("`@("`@("!]"@H@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/E]I9&5N=&ET:65S6R1I9&5N=&ET>5U;
M)&ME>5TI('Q\("1T:&ES+3Y?<')E9G,M/FES3&]C:V5D*"1K97DI*2!["B`@
M("`@("`@("`@("1V86P@/2`D=&AI<RT^7W!R969S+3YG971686QU92@D:V5Y
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=F%L(#T@)'1H:7,M
M/E]I9&5N=&ET:65S6R1I9&5N=&ET>5U;)&ME>5T["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)'9A;#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@86X@87)R87D@=VET:"!T:&4@<W!E8VEF:65D('!R;W!E<G1Y(&9R;VT@
M86QL(&5X:7-T:6YG"B`@("`@*B!I9&5N=&ET:65S+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&ME>2`@5&AE('!R;W!E<G1Y('1O(')E=')I979E
M+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!A<G)A>2!W:71H
M('1H92!V86QU97,@9G)O;2!A;&P@:61E;G1I=&EE<PH@("`@("HO"B`@("!F
M=6YC=&EO;B!G971!;&PH)&ME>2D*("`@('L*("`@("`@("`D;&ES="`](&%R
M<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]I9&5N=&ET:65S(&%S
M("1I9&5N=&ET>2`]/B`D;G5L;"D@>PH@("`@("`@("`@("`D;&ES=%LD:61E
M;G1I='E=(#T@)'1H:7,M/F=E=%9A;'5E*"1K97DL("1I9&5N=&ET>2D["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D;&ES=#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E=',@82!P<F]P97)T>2!W:71H(&$@<W!E8VEF:65D('9A;'5E
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@("`@("`@5&AE
M('!R;W!E<G1Y('1O('-E=`H@("`@("H@0'!A<F%M(&UI>&5D("1V86P@("`@
M("`@("!4:&4@=F%L=64@=&\@=VAI8V@@=&AE('!R;W!E<G1Y('-H;W5L9"!B
M92!S970*("`@("`J($!P87)A;2!I;G1E9V5R("1I9&5N=&ET>2`@5&AE(&ED
M96YT:71Y('1O('-E="!T:&4@<')O<&5R='D@:6XN"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&9A
M:6QU<F4@*'!R;W!E<G1Y('=A<R!L;V-K960I"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-E=%9A;'5E*"1K97DL("1V86PL("1I9&5N=&ET>2`](&YU;&PI"B`@
M("!["B`@("`@("`@:68@*"%I<W-E="@D:61E;G1I='DI*2!["B`@("`@("`@
M("`@("1I9&5N=&ET>2`]("1T:&ES+3Y?9&5F875L=#L*("`@("`@("!]"@H@
M("`@("`@(&EF("@A)'1H:7,M/E]P<F5F<RT^:7-,;V-K960H)&ME>2DI('L*
M("`@("`@("`@("`@)'1H:7,M/E]I9&5N=&ET:65S6R1I9&5N=&ET>5U;)&ME
M>5T@/2`D=F%L.PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T<G5E(&EF(&%L;"!P<F]P
M97)T:65S(&%R92!L;V-K960@86YD('1H97)E9F]R92!N;W1H:6YG(&EN('1H
M90H@("`@("H@:61E;G1I=&EE<R!C86X@8F4@8VAA;F=E9"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@86QL('!R;W!E<G1I97,@
M87)E(&QO8VME9"P@9F%L<V4@;W1H97)W:7-E"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&ES3&]C:V5D*"D*("`@('L*("`@("`@("!F;W)E86-H("@D=&AI<RT^
M7W!R;W!E<G1I97,@87,@)&ME>2D@>PH@("`@("`@("`@("!I9B`H(21T:&ES
M+3Y?<')E9G,M/FES3&]C:V5D*"1K97DI*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M<G5E(&EF('1H92!G:79E;B!A9&1R97-S(&)E;&]N9W,@=&\@;VYE(&]F('1H
M92!I9&5N=&ET:65S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ME
M>2`@("!4:&4@:61E;G1I='D@:V5Y('1O('-E87)C:"X*("`@("`J($!P87)A
M;2!S=')I;F<@)'9A;'5E("!4:&4@=F%L=64@=&\@<V5A<F-H(&9O<B!I;B`D
M:V5Y+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T
M:&4@)'9A;'5E('=A<R!F;W5N9"!I;B`D:V5Y+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!H87-686QU92@D:V5Y+"`D=F%L=65!*0H@("`@>PH@("`@("`@("1L
M:7-T(#T@)'1H:7,M/F=E=$%L;"@D:V5Y*3L*("`@("`@("!F;W)E86-H("@D
M;&ES="!A<R`D=F%L=65"*2!["B`@("`@("`@("`@(&EF("AS=')P;W,H4W1R
M:6YG.CIL;W=E<B@D=F%L=65!*2P@4W1R:6YG.CIL;W=E<B@D=F%L=65"*2D@
M(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@9F%L<V4["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!697)I9FEE<R!A;F0@<V%N:71I>F5S(&%L
M;"!I9&5N=&ET>2!P<F]P97)T:65S+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("1I9&5N=&ET>2`@5&AE(&ED96YT:71Y('1O('9E<FEF>2X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQ\;V)J96-T("!4<G5E(&EF('1H92!P
M<F]P97)T:65S(&%R92!V86QI9"!O<B!A(%!%05)?17)R;W(*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@('=I=&@@86X@97)R;W(@9&5S8W)I<'1I;VX@
M;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!V97)I9GDH)&ED96YT
M:71Y(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1I9&5N=&ET
M>2DI('L*("`@("`@("`@("`@)&ED96YT:71Y(#T@)'1H:7,M/E]D969A=6QT
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"$D=&AI<RT^9V5T5F%L=64H)VED
M)RP@)&ED96YT:71Y*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T5F%L=64H
M)VED)RP@7R@B56YN86UE9"(I+"`D:61E;G1I='DI.PH@("`@("`@('T*"B`@
M("`@("`@+RH@4D9#(#(X,C(@6S,N,BXU72!D;V5S(&YO="!A;&QO=R!T:&4@
M)UPG(&-H87)A8W1E<B!T;R!B92!U<V5D(&EN('1H90H@("`@("`@("`J('!E
M<G-O;F%L('!O<G1I;VX@;V8@86X@92UM86EL('-T<FEN9RX@*B\*("`@("`@
M("!I9B`H<W1R<&]S*"1T:&ES+3YG971686QU92@G9G5L;&YA;64G+"`D:61E
M;G1I='DI+"`G7%PG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B66]U(&-A;FYO="!H879E('1H92`G7%PG
M(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB*2D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($=E
M;F5R871E<R!T:&4@9G)O;2!A9&1R97-S('1O('5S92!F;W(@=&AE(&1E9F%U
M;'0@:61E;G1I='DN"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&9U
M;&QN86UE("!);F-L=61E('1H92!F=6QL;F%M92!I;F9O<FUA=&EO;BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&1E9F%U;'0@9G)O;2!A
M9&1R97-S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$969A=6QT1G)O;4%D
M9')E<W,H)&9U;&QN86UE(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&9R;VU?
M861D<B`]("<G.PH*("`@("`@("!I9B`H)&9U;&QN86UE*2!["B`@("`@("`@
M("`@("1N86UE(#T@)'1H:7,M/F=E=%9A;'5E*"=F=6QL;F%M92<I.PH@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1N86UE*2D@>PH@("`@("`@("`@("`@("`@
M)&9R;VU?861D<B`]("1N86UE("X@)R`G.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`D861D<B`]("1T:&ES+3YG971686QU92@G9G)O;5]A
M9&1R)RD["B`@("`@("`@:68@*&5M<'1Y*"1A9&1R*2D@>PH@("`@("`@("`@
M("`D861D<B`]($%U=&@Z.F=E=$%U=&@H*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D9G)O;5]A9&1R("X@)SPG("X@)&%D9'(@+B`G/B<["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T
M92!)9&5N=&ET>2!I;G-T86YC92!B87-E9"!O;B`D='EP92X*("`@("`J"B`@
M("`@*B!`<&%R86T@;6EX960@)'1Y<&4@("!4:&4@='EP92!O9B!C;VYC<F5T
M92!)9&5N=&ET>2!S=6)C;&%S<R!T;R!R971U<FXN"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("!4:&ES(&ES(&)A<V5D(&]N('1H92!S=&]R86=E(&1R
M:79E<B`H)'1Y<&4I+B!4:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M(&-O9&4@:7,@9'EN86UI8V%L;'D@:6YC;'5D960N($EF("1T>7!E(&ES(&%N
M(&%R<F%Y+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@=&AE;B!W92!W
M:6QL(&QO;VL@:6X@)'1Y<&5;,%TO;&EB+TED96YT:71Y+R!F;W(*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@('1H92!S=6)C;&%S<R!I;7!L96UE;G1A
M=&EO;B!N86UE9"`D='EP95LQ72YP:'`N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1U<V5R("!)9B!S<&5C:69I960L('=E(')E860@86YO=&AE<B!U<V5R)W,@
M:61E;G1I=&EE<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@:6YS=&5A
M9"!O9B!T:&4@8W5R<F5N="!U<V5R+@H@("`@("H*("`@("`J($!R971U<FX@
M261E;G1I='D@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E($ED96YT:71Y
M(&EN<W1A;F-E+"!O<B!F86QS90H@("`@("H@("`@("`@("`@("`@("`@("`@
M;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1T
M>7!E(#T@)VYO;F4G+"`D=7-E<B`](&YU;&PI"B`@("!["B`@("`@("`@:68@
M*&ES7V%R<F%Y*"1T>7!E*2D@>PH@("`@("`@("`@("`D87!P(#T@)'1Y<&5;
M,%T["B`@("`@("`@("`@("1T>7!E(#T@)'1Y<&5;,5T["B`@("`@("`@?0H*
M("`@("`@("`O*B!2971U<FX@82!B87-E($ED96YT:71Y(&]B:F5C="!I9B!N
M;R!D<FEV97(@:7,@<W!E8VEF:65D+B`J+PH@("`@("`@("1T>7!E(#T@8F%S
M96YA;64H)'1Y<&4I.PH@("`@("`@(&EF("AE;7!T>2@D='EP92D@?'P@*'-T
M<F-M<"@D='EP92P@)VYO;F4G*2`]/2`P*2D@>PH@("`@("`@("`@("`D:6YS
M=&%N8V4@/2`F;F5W($ED96YT:71Y*"1U<V5R*3L*("`@("`@("`@("`@)&EN
M<W1A;F-E+3YI;FET*"D["B`@("`@("`@("`@(')E='5R;B`D:6YS=&%N8V4[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1A<'`I*2!["B`@("`@
M("`@("`@(')E<75I<F5?;VYC92`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T
M*"=F:6QE<F]O="<L("1A<'`I("X@)R]L:6(O261E;G1I='DO)R`N("1T>7!E
M("X@)RYP:'`G.PH@("`@("`@('T@96QS96EF("A`9FEL95]E>&ES=',H9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+TED96YT:71Y+R<@+B`D='EP92`N("<N<&AP
M)RDI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%
M7U\I("X@)R])9&5N=&ET>2\G("X@)'1Y<&4@+B`G+G!H<"<["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@0&EN8VQU9&5?;VYC92`G2&]R9&4O261E
M;G1I='DO)R`N("1T>7!E("X@)RYP:'`G.PH@("`@("`@('T*("`@("`@("`D
M8VQA<W,@/2`G261E;G1I='E?)R`N("1T>7!E.PH@("`@("`@(&EF("AC;&%S
M<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V4@/2`F
M;F5W("1C;&%S<R@D=7-E<BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I;VX@
M;V8@)R`N("1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*"B`@
M("`@("`@)&EN<W1A;F-E+3YI;FET*"D["B`@("`@("`@<F5T=7)N("1I;G-T
M86YC93L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R
M;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E($ED96YT:71Y(&EN<W1A;F-E
M(&)A<V5D(&]N"B`@("`@*B`D='EP92X@270@=VEL;"!O;FQY(&-R96%T92!A
M(&YE=R!I;G-T86YC92!I9B!N;R!)9&5N=&ET>2!I;G-T86YC92!W:71H"B`@
M("`@*B!T:&4@<V%M92!P87)A;65T97)S(&-U<G)E;G1L>2!E>&ES=',N"B`@
M("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E9"!I9B!M=6QT:7!L92!T
M>7!E<R!O9B!I9&5N=&ET:65S("AA;F0L('1H=7,L"B`@("`@*B!M=6QT:7!L
M92!)9&5N=&ET>2!I;G-T86YC97,I(&%R92!R97%U:7)E9"X*("`@("`J"B`@
M("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z("1V87(@/2`F
M261E;G1I='DZ.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A<F%M(&UI
M>&5D("1T>7!E("`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@261E;G1I='D@<W5B
M8VQA<W,@=&\@<F5T=7)N+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M5&AI<R!I<R!B87-E9"!O;B!T:&4@<W1O<F%G92!D<FEV97(@*"1T>7!E*2X@
M5&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!C;V1E(&ES(&1Y;F%M
M:6-A;&QY(&EN8VQU9&5D+B!)9B`D='EP92!I<R!A;B!A<G)A>2P*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@('1H96X@=V4@=VEL;"!L;V]K(&EN("1T
M>7!E6S!=+VQI8B])9&5N=&ET>2\@9F]R"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("!T:&4@<W5B8VQA<W,@:6UP;&5M96YT871I;VX@;F%M960@)'1Y
M<&5;,5TN<&AP+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@268@<W!E
M8VEF:65D+"!W92!R96%D(&%N;W1H97(@=7-E<B=S(&ED96YT:71I97,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@(&EN<W1E860@;V8@=&AE(&-U<G)E
M;G0@=7-E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N($ED96YT:71Y("!4:&4@
M8V]N8W)E=&4@261E;G1I='D@<F5F97)E;F-E+"!O<B!F86QS92!O;B!A;B!E
M<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D='EP92`]
M("=N;VYE)RP@)'5S97(@/2!N=6QL*0H@("`@>PH@("`@("`@('-T871I8R`D
M:6YS=&%N8V5S.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<RDI('L*
M("`@("`@("`@("`@)&EN<W1A;F-E<R`](&%R<F%Y*"D["B`@("`@("`@?0H*
M("`@("`@("`D<VEG;F%T=7)E(#T@<V5R:6%L:7IE*&%R<F%Y*"1T>7!E+"`D
M=7-E<BDI.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<ULD<VEG;F%T
M=7)E72DI('L*("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`]
M("9)9&5N=&ET>3HZ9F%C=&]R>2@D='EP92P@)'5S97(I.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@("!]
M"@I]"@``````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O26UA9V4O````````````````````
M`````````````````````````````````````````````````````````#`P
M,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S0V
M`#`R,#4Q,0`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]);6%G
M92]G9"YP:'``````````````````````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q
M,#<V-#8`,3`U,34T,S,W-#8`,#(Q-C,R`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+RXN+TEM86=E+G!H<"<["@HO*BH*("H@5&AI
M<R!C;&%S<R!I;7!L96UE;G1S('1H92!(;W)D95]);6%G93HZ($%022!F;W(@
M=&AE(%!(4"!'1`H@*B!E>'1E;G-I;VXN($ET(&UA:6YL>2!P<F]V:61E<R!S
M;VUE('5T:6QI='D@9G5N8W1I;VYS+"!S=6-H(&%S('1H90H@*B!A8FEL:71Y
M('1O(&UA:V4@<&EX96QS+"!F;W(@;F]W+@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]);6%G92]);6%G92]G9"YP:'`L=B`Q+C0X+C$P+C$T(#(P,#8O,#$O
M,#$@,C$Z,C@Z,C(@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P
M,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO
M<F1E7TEM86=E"B`J+PIC;&%S<R!(;W)D95]);6%G95]G9"!E>'1E;F1S($AO
M<F1E7TEM86=E('L*"B`@("`O*BH*("`@("`J($-A<&%B:6QI=&5S(&]F('1H
M:7,@9')I=F5R+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1?8V%P86)I;&ET:65S(#T@87)R87DH)W)E<VEZ92<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G8W)O<"<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<F]T871E)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=F;&EP)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=M:7)R;W(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V=R87ES8V%L92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G<V5P:6$G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)WEE;&QO=VEZ92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=V%T97)M87)K)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C
M86YV87,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`O*BH*
M("`@("`J(%=H870@:VEN9"!O9B!I;6%G97,@<VAO=6QD($=$(&=E;F5R871E
M/R!$969A=6QT<R!T;R`G<&YG)RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)%]T>7!E(#T@)W!N9R<["@H@("`@+RHJ"B`@
M("`@*B!'1"!);6%G92!R97-O=7)C92!F;W(@=&AE(&-U<G)E;G0@:6UA9V4@
M9&%T82X*("`@("`J"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@
M('9A<B`D7VEM.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&ED96YT:69I97(@
M;V8@=&AE(&-U<G)E;G0@:6UA9V4N($YE=R!I;6%G92!D871A('=I;&P@;F]T
M(&)E"B`@("`@*B!L;V%D960@:68@=&AE('-A;64@:60@:7,@86QR96%D>2!L
M;V%D960N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?:60@/2`G)SL*"B`@("!F=6YC=&EO;B!(;W)D95]);6%G95]G9"@D
M<&%R86US*0H@("`@>PH@("`@("`@('!A<F5N=#HZ2&]R9&5?26UA9V4H)'!A
M<F%M<RD["B`@("`@("`@:68@*"%E;7!T>2@D<&%R86US6R=T>7!E)UTI*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?='EP92`]("1P87)A;7-;)W1Y<&4G73L*
M("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)'!A<F%M<ULG=VED=&@G
M72DI('L*("`@("`@("`@("`@)'1H:7,M/E]I;2`]("8D=&AI<RT^7V-R96%T
M92@D=&AI<RT^7W=I9'1H+"`D=&AI<RT^7VAE:6=H="D["B`@("`@("`@("`@
M("1T:&ES+3Y?8V%L;"@G:6UA9V5&:6QL)RP@87)R87DH)'1H:7,M/E]I;2P@
M,"P@,"P@)'1H:7,M/F%L;&]C871E0V]L;W(H)'1H:7,M/E]B86-K9W)O=6YD
M*2DI.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!G971#;VYT96YT
M5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=I;6%G92\G("X@)'1H:7,M
M/E]T>7!E.PH@("`@?0H*("`@("\J*@H@("`@("H@1&ES<&QA>2!T:&4@8W5R
M<F5N="!I;6%G92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&ES<&QA>2@I"B`@
M("!["B`@("`@("`@)'1H:7,M/FAE861E<G,H*3L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]C86QL*"=I;6%G92<@+B`D=&AI<RT^7W1Y<&4L(&%R<F%Y*"1T
M:&ES+3Y?:6TI*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M(')A=R!D871A(&9O<B!T:&ES(&EM86=E+@H@("`@("H*("`@("`J($!P87)A
M;2!B;V]L96%N("1C;VYV97)T("!)9B!T<G5E+"!T:&4@:6UA9V4@9&%T82!W
M:6QL(&)E(')E='5R;F5D(&EN('1H90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@('1A<F=E="!F;W)M870L(&EN9&5P96YD96YT;'D@9G)O;2!A
M;GD@:6UA9V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!O<&5R
M871I;VYS+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F%W
M(&EM86=E(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')A=R@D8V]N=F5R
M="`](&9A;'-E*0H@("`@>PH@("`@("`@(')E='5R;B!5=&EL.CIB=69F97)/
M=71P=70H)VEM86=E)R`N("1T:&ES+3Y?='EP92P@)'1H:7,M/E]I;2D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!297-E="!T:&4@:6UA9V4@9&%T82X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F5S970H*0H@("`@>PH@("`@("`@('!A<F5N
M=#HZ<F5S970H*3L*("`@("`@("!I9B`H:7-?<F5S;W5R8V4H)'1H:7,M/E]I
M;2DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V%L;"@G:6UA9V5$
M97-T<F]Y)RP@87)R87DH)'1H:7,M/E]I;2DI.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@
M:&5I9VAT(&%N9"!W:61T:"!O9B!T:&4@8W5R<F5N="!I;6%G92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!H87-H('=I=&@@)W=I9'1H)R!C
M;VYT86EN:6YG('1H92!W:61T:"P*("`@("`J("`@("`@("`@("`@("`@("=H
M96EG:'0G(&-O;G1A:6YI;F<@=&AE(&AE:6=H="!O9B!T:&4@:6UA9V4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$1I;65N<VEO;G,H*0H@("`@>PH@("`@
M("`@(&EF("AI<U]A*"1T:&ES+3Y?:6TL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6T["B`@("`@("`@?2!E;'-E:68@
M*&ES7W)E<V]U<F-E*"1T:&ES+3Y?:6TI*2!["B`@("`@("`@("`@(')E='5R
M;B!A<G)A>2@G=VED=&@G(#T^("1T:&ES+3Y?8V%L;"@G:6UA9V536"<L(&%R
M<F%Y*"1T:&ES+3Y?:6TI*2P*("`@("`@("`@("`@("`@("`@("`@("`@("=H
M96EG:'0G(#T^("1T:&ES+3Y?8V%L;"@G:6UA9V5362<L(&%R<F%Y*"1T:&ES
M+3Y?:6TI*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M(&%R<F%Y*"=W:61T:"<@/3X@,"P@)VAE:6=H="<@/3X@,"D["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A(&-O;&]R('1H870@
M8V%N(&)E(&%C8V5S<V5D(&EN('1H:7,@;V)J96-T+B!7:&5N(&$*("`@("`J
M(&-O;&]R(&ES('-E="P@=&AE(&EN=&5G97(@<F5S;W5R8V4@;V8@:70@:7,@
M<F5T=7)N960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@
M5&AE(&YA;64@;V8@=&AE(&-O;&]R+@H@("`@("H*("`@("`J($!R971U<FX@
M:6YT96=E<B`@5&AE(')E<V]U<F-E(&]F('1H92!C;VQO<B!T:&%T(&-A;B!B
M92!P87-S960@=&\@1T0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%L;&]C871E
M0V]L;W(H)&YA;64I"B`@("!["B`@("`@("`@<W1A=&EC("1C;VQO<G,@/2!A
M<G)A>2@I.PH*("`@("`@("!I9B`H96UP='DH)&-O;&]R<ULD;F%M95TI*2![
M"B`@("`@("`@("`@(&QI<W0H)'(L("1G+"`D8BD@/2`D=&AI<RT^9V5T4D="
M*"1N86UE*3L*("`@("`@("`@("`@)&-O;&]R<ULD;F%M95T@/2`D=&AI<RT^
M7V-A;&PH)VEM86=E0V]L;W)!;&QO8V%T92<L(&%R<F%Y*"1T:&ES+3Y?:6TL
M("1R+"`D9RP@)&(I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D8V]L
M;W)S6R1N86UE73L*("`@('T*"B`@("!F=6YC=&EO;B!G971&;VYT*"1F;VYT
M*0H@("`@>PH@("`@("`@('-W:71C:"`H)&9O;G0I('L*("`@("`@("!C87-E
M("=T:6YY)SH*("`@("`@("`@("`@<F5T=7)N(#$["@H@("`@("`@(&-A<V4@
M)VUE9&EU;2<Z"B`@("`@("`@("`@(')E='5R;B`S.PH*("`@("`@("!C87-E
M("=L87)G92<Z"B`@("`@("`@("`@(')E='5R;B`T.PH*("`@("`@("!C87-E
M("=G:6%N="<Z"B`@("`@("`@("`@(')E='5R;B`U.PH*("`@("`@("!C87-E
M("=S;6%L;"<Z"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N
M(#(["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@3&]A9"!T:&4@
M:6UA9V4@9&%T82!F<F]M(&$@<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&ED("`@("`@("`@($%N(&%R8FET<F%R>2!I9"!F;W(@=&AE
M(&EM86=E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:6UA9V5?9&%T82`@5&AE
M(&1A=&$@=&\@=7-E(&9O<B!T:&4@:6UA9V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&QO8613=')I;F<H)&ED+"`D:6UA9V5?9&%T82D*("`@('L*("`@("`@
M("!I9B`H)&ED("$]("1T:&ES+3Y?:60I('L*("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?:6TI('L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0@
M/2`D=&AI<RT^<F5S970H*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?:6T@/2`F)'1H:7,M
M/E]C86QL*"=I;6%G94-R96%T949R;VU3=')I;F<G+"!A<G)A>2@D:6UA9V5?
M9&%T82DI.PH@("`@("`@("`@("`D=&AI<RT^7VED(#T@)&ED.PH@("`@("`@
M("`@("!I9B`H:7-?82@D=&AI<RT^7VEM+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($QO860@=&AE(&EM
M86=E(&1A=&$@9G)O;2!A(&9I;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9FEL96YA;64@(%1H92!F=6QL('!A=&@@86YD(&9I;&5N86UE('1O
M('1H92!F:6QE('1O(&QO860*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("!T:&4@:6UA9V4@9&%T82!F<F]M+B!4:&4@9FEL96YA;64@=VEL;"!A
M;'-O(&)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=7-E9"!F
M;W(@=&AE(&EM86=E(&ED+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%!%05(@17)R;W(@:68@9FEL92!D;V5S(&YO="!E>&ES="!O<B!C;W5L9"!N
M;W0@8F4@;&]A9&5D"B`@("`@*B`@("`@("`@("`@("`@("!O=&AE<G=I<V4@
M3E5,3"!I9B!S=6-C97-S9G5L(&]R(&%L<F5A9'D@;&]A9&5D+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!L;V%D1FEL92@D9FEL96YA;64I"B`@("!["B`@("`@
M("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3YR97-E="@I+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M('T*"B`@("`@("`@:68@*&ES7V$H)&EN9F\@/2`D=&AI<RT^7V-A;&PH)V=E
M=&EM86=E<VEZ92<L(&%R<F%Y*"1F:6QE;F%M92DI+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D:6YF;SL*("`@("`@("!]"@H@("`@
M("`@(&EF("AI<U]A<G)A>2@D:6YF;RDI('L*("`@("`@("`@("`@<W=I=&-H
M("@D:6YF;ULR72D@>PH@("`@("`@("`@("!C87-E(#$Z"B`@("`@("`@("`@
M("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=I;6%G96-R96%T969R;VUG:68G
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6T@/2`F)'1H:7,M
M/E]C86QL*"=I;6%G96-R96%T969R;VUG:68G+"!A<G)A>2@D9FEL96YA;64I
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEM
M(#T@)B1T:&ES+3Y?8V%L;"@G:6UA9V5C<F5A=&5F<F]M:G!E9R<L(&%R<F%Y
M*"1F:6QE;F%M92DI.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@(&-A<V4@,SH*("`@("`@("`@("`@("`@("1T:&ES+3Y?:6T@/2`F)'1H
M:7,M/E]C86QL*"=I;6%G96-R96%T969R;VUP;F<G+"!A<G)A>2@D9FEL96YA
M;64I*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E
M(#$U.@H@("`@("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G:6UA
M9V5C<F5A=&5F<F]M9W=B;7`G*2D@>PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?:6T@/2`F)'1H:7,M/E]C86QL*"=I;6%G96-R96%T969R;VUG=V)M
M<"<L(&%R<F%Y*"1F:6QE;F%M92DI.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@,38Z"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7VEM(#T@)B1T:&ES+3Y?8V%L;"@G:6UA9V5C
M<F5A=&5F<F]M>&)M)RP@87)R87DH)&9I;&5N86UE*2D["B`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M:68@*&ES7V$H)'1H:7,M/E]I;2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]I;3L*("`@("`@("!]"@H@("`@("`@(&EF
M("AI<U]R97-O=7)C92@D=&AI<RT^7VEM*2D@>PH@("`@("`@("`@("!R971U
M<FX["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@<&%R96YT.CIL;V%D
M1FEL92@D9FEL96YA;64I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^7VEM(#T@)B1T:&ES+3Y?
M8V%L;"@G:6UA9V5#<F5A=&5&<F]M4W1R:6YG)RP@87)R87DH)'1H:7,M/E]D
M871A*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!297-I>F4@=&AE(&-U<G)E
M;G0@:6UA9V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'=I9'1H
M("`@("`@5&AE(&YE=R!W:61T:"X*("`@("`J($!P87)A;2!I;G1E9V5R("1H
M96EG:'0@("`@(%1H92!N97<@:&5I9VAT+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)')A=&EO("`@("`@36%I;G1A:6X@;W)I9VEN86P@87-P96-T(')A=&EO
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R97-I>F4H)'=I9'1H+"`D:&5I9VAT
M+"`D<F%T:6\@/2!T<G5E*0H@("`@>PH@("`@("`@("\J($%B;W)T(&EF('=E
M)W)E(&%S:V5D('1O(&1I=FED92!B>2!Z97)O+"!O<B!T<G5N8V%T92!T:&4*
M("`@("`@("`@*B!I;6%G92!C;VUP;&5T96QY(&EN(&5I=&AE<B!D:7)E8W1I
M;VXN("HO"B`@("`@("`@:68@*"$D=VED=&@@?'P@(21H96EG:'0I('L*("`@
M("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@:68@*"1R871I
M;RD@>PH@("`@("`@("`@("!I9B`H)'=I9'1H("\@)&AE:6=H="`^("1T:&ES
M+3Y?8V%L;"@G:6UA9V536"<L(&%R<F%Y*"1T:&ES+3Y?:6TI*2`O("1T:&ES
M+3Y?8V%L;"@G:6UA9V5362<L(&%R<F%Y*"1T:&ES+3Y?:6TI*2D@>PH@("`@
M("`@("`@("`@("`@)'=I9'1H(#T@)&AE:6=H="`J("1T:&ES+3Y?8V%L;"@G
M:6UA9V536"<L(&%R<F%Y*"1T:&ES+3Y?:6TI*2`O("1T:&ES+3Y?8V%L;"@G
M:6UA9V5362<L(&%R<F%Y*"1T:&ES+3Y?:6TI*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1H96EG:'0@/2`D=VED=&@@*B`D=&AI
M<RT^7V-A;&PH)VEM86=E4UDG+"!A<G)A>2@D=&AI<RT^7VEM*2D@+R`D=&AI
M<RT^7V-A;&PH)VEM86=E4U@G+"!A<G)A>2@D=&AI<RT^7VEM*2D["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1I;2`]("1T:&ES+3Y?:6T[
M"B`@("`@("`@)'1H:7,M/E]I;2`]("8D=&AI<RT^7V-R96%T92@D=VED=&@L
M("1H96EG:'0I.PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?:6TL("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6T["B`@
M("`@("`@?0H@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A
M;&PH)VEM86=E1FEL;"<L(&%R<F%Y*"1T:&ES+3Y?:6TL(#`L(#`L("1T:&ES
M+3Y?8V%L;"@G:6UA9V5#;VQO<D%L;&]C871E)RP@87)R87DH)'1H:7,M/E]I
M;2P@,C4U+"`R-34L(#(U-2DI*2DL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@("`@(&EF("AI
M<U]A*"1T:&ES+3Y?8V%L;"@G:6UA9V5#;W!Y4F5S86UP;&5D)RP@87)R87DH
M)'1H:7,M/E]I;2P@)&EM+"`P+"`P+"`P+"`P+"`D=VED=&@L("1H96EG:'0L
M("1T:&ES+3Y?8V%L;"@G:6UA9V536"<L(&%R<F%Y*"1I;2DI+"`D=&AI<RT^
M7V-A;&PH)VEM86=E4UDG+"!A<G)A>2@D:6TI*2DI+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V-A;&PH)VEM86=E0V]P
M>5)E<VEZ960G+"!A<G)A>2@D=&AI<RT^7VEM+"`D:6TL(#`L(#`L(#`L(#`L
M("1W:61T:"P@)&AE:6=H="P@)'1H:7,M/E]C86QL*"=I;6%G95-8)RP@87)R
M87DH)&EM*2DL("1T:&ES+3Y?8V%L;"@G:6UA9V5362<L(&%R<F%Y*"1I;2DI
M*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0W)O<"!T:&4@
M8W5R<F5N="!I;6%G92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M>#$@(%1H92!T;W`@;&5F="!C;W)N97(@;V8@=&AE(&-R;W!P960@:6UA9V4N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>3$@(%1H92!T;W`@<FEG:'0@8V]R
M;F5R(&]F('1H92!C<F]P<&5D(&EM86=E+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'@R("!4:&4@8F]T=&]M(&QE9G0@8V]R;F5R(&]F('1H92!C<F]P<&5D
M(&EM86=E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'DR("!4:&4@8F]T=&]M
M(')I9VAT(&-O<FYE<B!O9B!T:&4@8W)O<'!E9"!I;6%G92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@8W)O<"@D>#$L("1Y,2P@)'@R+"`D>3(I"B`@("!["B`@
M("`@("`@)&EM(#T@)'1H:7,M/E]I;3L*("`@("`@("`D=&AI<RT^7VEM(#T@
M)B1T:&ES+3Y?8W)E871E*"1X,B`M("1X,2P@)'DR("T@)'DQ*3L*("`@("`@
M("!I9B`H:7-?82@D=&AI<RT^7VEM+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7VEM.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)'1H:7,M/E]C86QL*"=I;6%G94-O<'DG+"!A<G)A>2@D=&AI<RT^
M7VEM+"`D:6TL(#`L(#`L("1X,2P@)'DQ+"`D>#(@+2`D>#$L("1Y,B`M("1Y
M,2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F]T871E('1H92!C=7)R96YT
M(&EM86=E+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1A;F=L92`@
M("`@("!4:&4@86YG;&4@=&\@<F]T871E('1H92!I;6%G92!B>2P*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I;B!T:&4@8VQO8VMW:7-E
M(&1I<F5C=&EO;@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&)A8VMG<F]U;F0@
M(%1H92!B86-K9W)O=6YD(&-O;&]R('1O(&9I;&P@86YY('1R:6%N9VQE<PH@
M("`@("HO"B`@("!F=6YC=&EO;B!R;W1A=&4H)&%N9VQE+"`D8F%C:V=R;W5N
M9"`]("=W:&ET92<I"B`@("!["B`@("`@("`@:68@*"%F=6YC=&EO;E]E>&ES
M=',H)VEM86=E<F]T871E)RDI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@
M("`@('T*"B`@("`@("`@)&)A8VMG<F]U;F0@/2`D=&AI<RT^86QL;V-A=&5#
M;VQO<B@D8F%C:V=R;W5N9"D["B`@("`@("`@:68@*&ES7V$H)&)A8VMG<F]U
M;F0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1B86-K
M9W)O=6YD.PH@("`@("`@('T*"B`@("`@("`@<W=I=&-H("@D86YG;&4I('L*
M("`@("`@("!C87-E("<Y,"<Z"B`@("`@("`@("`@("1X(#T@)'1H:7,M/E]C
M86QL*"=I;6%G95-8)RP@87)R87DH)'1H:7,M/E]I;2DI.PH@("`@("`@("`@
M("`D>2`]("1T:&ES+3Y?8V%L;"@G:6UA9V5362<L(&%R<F%Y*"1T:&ES+3Y?
M:6TI*3L*("`@("`@("`@("`@)'AY;6%X(#T@;6%X*"1X+"`D>2D["@H@("`@
M("`@("`@("`D:6T@/2`F)'1H:7,M/E]C<F5A=&4H)'AY;6%X+"`D>'EM87@I
M.PH@("`@("`@("`@("!I9B`H:7-?82@D:6TL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D:6T["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA
M9V5#;W!Y)RP@87)R87DH)&EM+"`D=&AI<RT^7VEM+"`P+"`P+"`P+"`P+"`D
M>"P@)'DI*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&EM(#T@
M)B1T:&ES+3Y?8V%L;"@G:6UA9V52;W1A=&4G+"!A<G)A>2@D:6TL(#(W,"P@
M)&)A8VMG<F]U;F0I*3L*("`@("`@("`@("`@:68@*&ES7V$H)&EM+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&EM.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?:6T@/2`D:6T["B`@("`@
M("`@("`@("1I;2`]("8D=&AI<RT^7V-R96%T92@D>2P@)'@I.PH@("`@("`@
M("`@("!I9B`H:7-?82@D:6TL("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D:6T["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*"1X(#P@)'DI('L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E0V]P>2<L(&%R<F%Y*"1I;2P@)'1H
M:7,M/E]I;2P@,"P@,"P@,"P@,"P@)'AY;6%X+"`D>'EM87@I*2P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V5I9B`H)'@@
M/B`D>2D@>PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T
M:&ES+3Y?8V%L;"@G:6UA9V5#;W!Y)RP@87)R87DH)&EM+"`D=&AI<RT^7VEM
M+"`P+"`P+"`D>'EM87@@+2`D>2P@)'AY;6%X("T@)'@L("1X>6UA>"P@)'AY
M;6%X*2DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D=&AI<RT^7VEM(#T@)&EM.PH@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@)'1H:7,M/E]I
M;2`]("8D=&AI<RT^7V-A;&PH)VEM86=E4F]T871E)RP@87)R87DH)'1H:7,M
M/E]I;2P@,S8P("T@)&%N9VQE+"`D8F%C:V=R;W5N9"DI.PH@("`@("`@("`@
M("!I9B`H:7-?82@D=&AI<RT^7VEM+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!&;&EP('1H92!C=7)R96YT(&EM86=E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!F;&EP*"D*("`@('L*("`@("`@("`D>"`]("1T:&ES+3Y?8V%L;"@G
M:6UA9V536"<L(&%R<F%Y*"1T:&ES+3Y?:6TI*3L*("`@("`@("`D>2`]("1T
M:&ES+3Y?8V%L;"@G:6UA9V5362<L(&%R<F%Y*"1T:&ES+3Y?:6TI*3L*"B`@
M("`@("`@)&EM(#T@)B1T:&ES+3Y?8W)E871E*"1X+"`D>2D["B`@("`@("`@
M:68@*&ES7V$H)&EM+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D:6T["B`@("`@("`@?0H@("`@("`@(&9O<B`H)&-U<ED@/2`P.R`D
M8W5R62`\("1Y.R`D8W5R62LK*2!["B`@("`@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E0V]P>2<L(&%R<F%Y*"1I;2P@
M)'1H:7,M/E]I;2P@,"P@)'D@+2`H)&-U<ED@*R`Q*2P@,"P@)&-U<EDL("1X
M+"`Q*2DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D
M=&AI<RT^7VEM(#T@)&EM.PH@("`@?0H*("`@("\J*@H@("`@("H@36ER<F]R
M('1H92!C=7)R96YT(&EM86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!M:7)R
M;W(H*0H@("`@>PH@("`@("`@("1X(#T@)'1H:7,M/E]C86QL*"=I;6%G95-8
M)RP@87)R87DH)'1H:7,M/E]I;2DI.PH@("`@("`@("1Y(#T@)'1H:7,M/E]C
M86QL*"=I;6%G95-9)RP@87)R87DH)'1H:7,M/E]I;2DI.PH*("`@("`@("`D
M:6T@/2`F)'1H:7,M/E]C<F5A=&4H)'@L("1Y*3L*("`@("`@("!I9B`H:7-?
M82@D:6TL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I
M;3L*("`@("`@("!]"B`@("`@("`@9F]R("@D8W5R6"`](#`[("1C=7)8(#P@
M)'@[("1C=7)8*RLI('L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="`]
M("1T:&ES+3Y?8V%L;"@G:6UA9V5#;W!Y)RP@87)R87DH)&EM+"`D=&AI<RT^
M7VEM+"`D>"`M("@D8W5R6"`K(#$I+"`P+"`D8W5R6"P@,"P@,2P@)'DI*2P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?
M:6T@/2`D:6T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T('1H92!C
M=7)R96YT(&EM86=E('1O(&=R87ES8V%L92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9W)A>7-C86QE*"D*("`@('L*("`@("`@("`D<F%T95(@/2`N,C(Y.PH@
M("`@("`@("1R871E1R`]("XU.#<["B`@("`@("`@)')A=&5"(#T@+C$Q-#L*
M("`@("`@("`D=VAI=&5N97-S(#T@,SL*"B`@("`@("`@:68@*&9U;F-T:6]N
M7V5X:7-T<R@G:6UA9V5I<W1R=65C;VQO<B<I("8F("1T:&ES+3Y?8V%L;"@G
M:6UA9V5)<U1R=65#;VQO<B<L(&%R<F%Y*"1T:&ES+3Y?:6TI*2`]/3T@=')U
M92D@>PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C
M86QL*"=I;6%G951R=65#;VQO<E1O4&%L971T92<L(&%R<F%Y*"1T:&ES+3Y?
M:6TL('1R=64L(#(U-BDI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@)&-O;&]R<R`](&UI;B@R-38L("1T:&ES+3Y?8V%L;"@G:6UA
M9V5#;VQO<G-4;W1A;"<L(&%R<F%Y*"1T:&ES+3Y?:6TI*2D["B`@("`@("`@
M9F]R("@D>"`](#`[("1X(#P@)&-O;&]R<SL@)'@K*RD@>PH@("`@("`@("`@
M("`D<W)C(#T@)'1H:7,M/E]C86QL*"=I;6%G94-O;&]R<T9O<DEN9&5X)RP@
M87)R87DH)'1H:7,M/E]I;2P@)'@I*3L*("`@("`@("`@("`@:68@*&ES7V$H
M)'-R8RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1S<F,["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&YE=R`](&UI;B@R
M-34L(&%B<R@D<W)C6R=R960G72`J("1R871E4B`K("1S<F-;)V=R965N)UT@
M*B`D<F%T94<@*R`D<W)C6R=B;'5E)UT@*B`D<F%T94(I("L@)'=H:71E;F5S
M<RD["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A
M;&PH)VEM86=E0V]L;W)3970G+"!A<G)A>2@D=&AI<RT^7VEM+"`D>"P@)&YE
M=RP@)&YE=RP@)&YE=RDI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J(%-E<&EA(&9I;'1E<BX*("`@("`J"B`@
M("`@*B!"87-I8V%L;'D@='5R;G,@=&AE(&EM86=E('1O(&=R87ES8V%L92!A
M;F0@=&AE;B!A9&1S('-O;64*("`@("`J(&1E9FEN960@=&EN="!O;B!I="`H
M4B`K/2`S,"P@1R`K/2`T,RP@0B`K/2`M,C,I('-O(&ET('=I;&P*("`@("`J
M(&%P<&5A<B!T;R!B92!A('9E<GD@;VQD('!I8W1U<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-E<&EA*"D*("`@('L*("`@("`@("`D=&EN=%(@/2`X,#L*
M("`@("`@("`D=&EN=$<@/2`T,SL*("`@("`@("`D=&EN=$(@/2`M,C,["B`@
M("`@("`@)')A=&52(#T@+C(R.3L*("`@("`@("`D<F%T94<@/2`N-3@W.PH@
M("`@("`@("1R871E0B`]("XQ,30["B`@("`@("`@)'=H:71E;F5S<R`](#,[
M"@H@("`@("`@(&EF("@D=&AI<RT^7V-A;&PH)VEM86=E27-4<G5E0V]L;W(G
M+"!A<G)A>2@D=&AI<RT^7VEM*2D@/3T]('1R=64I('L*("`@("`@("`@("`@
M:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V54<G5E0V]L
M;W)4;U!A;&5T=&4G+"!A<G)A>2@D=&AI<RT^7VEM+"!T<G5E+"`R-38I*2P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1C;VQO<G,@
M/2!M87@H,C4V+"`D=&AI<RT^7V-A;&PH)VEM86=E0V]L;W)S5&]T86PG+"!A
M<G)A>2@D=&AI<RT^7VEM*2DI.PH@("`@("`@(&9O<B`H)'@@/2`P.R`D>"`\
M("1C;VQO<G,[("1X*RLI('L*("`@("`@("`@("`@)'-R8R`]("1T:&ES+3Y?
M8V%L;"@G:6UA9V5#;VQO<G-&;W));F1E>"<L(&%R<F%Y*"1T:&ES+3Y?:6TL
M("1X*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1S<F,L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<W)C.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1N97<@/2!M:6XH,C4U+"!A8G,H)'-R8ULG<F5D
M)UT@*B`D<F%T95(@*R`D<W)C6R=G<F5E;B==("H@)')A=&5'("L@)'-R8ULG
M8FQU92==("H@)')A=&5"*2`K("1W:&ET96YE<W,I.PH@("`@("`@("`@("`D
M<B`](&UI;B@R-34L("1N97<@*R`D=&EN=%(I.PH@("`@("`@("`@("`D9R`]
M(&UI;B@R-34L("1N97<@*R`D=&EN=$<I.PH@("`@("`@("`@("`D8B`](&UI
M;B@R-34L("1N97<@*R`D=&EN=$(I.PH@("`@("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G94-O;&]R4V5T)RP@87)R87DH
M)'1H:7,M/E]I;2P@)'@L("1R+"`D9RP@)&(I*2P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!996QL;W=I>F4@
M9FEL=&5R+@H@("`@("H*("`@("`J($%D9',@82!L87EE<B!O9B!Y96QL;W<@
M=&AA="!C86X@8F4@=')A;G-P87)E;G0@;W(@<V]L:60N($EF"B`@("`@*B`D
M:6YT96YS:71Y02!I<R`R-34@=&AE(&EM86=E('=I;&P@8F4@,"4@=')A;G-P
M87)E;G0@*'-O;&ED*2X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M:6YT96YS:71Y62`@2&]W('-T<F]N9R!S:&]U;&0@=&AE('EE;&QO=R`H<F5D
M(&%N9"!G<F5E;BD@8F4_("@P+3(U-2D*("`@("`J($!P87)A;2!I;G1E9V5R
M("1I;G1E;G-I='E"("!(;W<@=V5A:R!S:&]U;&0@=&AE(&)L=64@8F4_("@^
M/2`R+"!I;B!T:&4@<&]S:71I=F4@;&EM:70@:70@=VEL;"!B92!M86ME($),
M544@,"D*("`@("`J+PH@("`@9G5N8W1I;VX@>65L;&]W:7IE*"1I;G1E;G-I
M='E9(#T@-3`L("1I;G1E;G-I='E"(#T@,RD*("`@('L*("`@("`@("!I9B`H
M)'1H:7,M/E]C86QL*"=I;6%G94ES5')U94-O;&]R)RP@87)R87DH)'1H:7,M
M/E]I;2DI(#T]/2!T<G5E*2!["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E5')U94-O;&]R5&]086QE='1E)RP@
M87)R87DH)'1H:7,M/E]I;2P@=')U92P@,C4V*2DL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`D8V]L;W)S(#T@;6%X*#(U-BP@)'1H
M:7,M/E]C86QL*"=I;6%G94-O;&]R<U1O=&%L)RP@87)R87DH)'1H:7,M/E]I
M;2DI*3L*("`@("`@("!F;W(@*"1X(#T@,#L@)'@@/"`D8V]L;W)S.R`D>"LK
M*2!["B`@("`@("`@("`@("1S<F,@/2`D=&AI<RT^7V-A;&PH)VEM86=E0V]L
M;W)S1F]R26YD97@G+"!A<G)A>2@D=&AI<RT^7VEM+"`D>"DI.PH@("`@("`@
M("`@("!I9B`H:7-?82@D<W)C+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)'-R8SL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D<B`](&UI;B@D<W)C6R=R960G72`K("1I;G1E;G-I='E9+"`R-34I.PH@
M("`@("`@("`@("`D9R`](&UI;B@D<W)C6R=G<F5E;B==("L@)&EN=&5N<VET
M>5DL(#(U-2D["B`@("`@("`@("`@("1B(#T@;6%X*"@D<B`K("1G*2`O(&UA
M>"@D:6YT96YS:71Y0BP@,BDL(#`I.PH@("`@("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G94-O;&]R4V5T)RP@87)R87DH
M)'1H:7,M/E]I;2P@)'@L("1R+"`D9RP@)&(I*2P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@=V%T97)M87)K*"1T
M97AT+"`D:&%L:6=N(#T@)W)I9VAT)RP@)'9A;&EG;B`]("=B;W1T;VTG+"`D
M9F]N="`]("=S;6%L;"<I"B`@("!["B`@("`@("`@)&-O;&]R(#T@)'1H:7,M
M/E]C86QL*"=I;6%G94-O;&]R0VQO<V5S="<L(&%R<F%Y*"1T:&ES+3Y?:6TL
M(#(U-2P@,C4U+"`R-34I*3L*("`@("`@("!I9B`H:7-?82@D8V]L;W(L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VQO<CL*("`@
M("`@("!]"B`@("`@("`@)'-H861O=R`]("1T:&ES+3Y?8V%L;"@G:6UA9V5#
M;VQO<D-L;W-E<W0G+"!A<G)A>2@D=&AI<RT^7VEM+"`P+"`P+"`P*2D["B`@
M("`@("`@:68@*&ES7V$H)'-H861O=RP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'-H861O=SL*("`@("`@("!]"@H@("`@("`@("\O
M(%-H861O=R!O9F9S970@:6X@<&EX96QS+@H@("`@("`@("1D<F]P(#T@,3L*
M"B`@("`@("`@+R\@36%X:6UU;2!T97AT('=I9'1H+@H@("`@("`@("1M87AW
M:61T:"`](#(P,#L*"B`@("`@("`@+R\@06UO=6YT(&]F('-P86-E('1O(&QE
M879E(&)E='=E96X@=&AE('1E>'0@86YD('1H92!I;6%G90H@("`@("`@("\O
M(&)O<F1E<BX*("`@("`@("`D<&%D9&EN9R`](#$P.PH*("`@("`@("`D9B`]
M("1T:&ES+3YG971&;VYT*"1F;VYT*3L*("`@("`@("`D9F]N='=I9'1H(#T@
M)'1H:7,M/E]C86QL*"=I;6%G949O;G17:61T:"<L(&%R<F%Y*"1F*2D["B`@
M("`@("`@:68@*&ES7V$H)&9O;G1W:61T:"P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&9O;G1W:61T:#L*("`@("`@("!]"B`@("`@
M("`@)&9O;G1H96EG:'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E1F]N=$AE:6=H
M="<L(&%R<F%Y*"1F*2D["B`@("`@("`@:68@*&ES7V$H)&9O;G1H96EG:'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1F;VYT:&5I
M9VAT.PH@("`@("`@('T*"B`@("`@("`@+R\@4V\@=&AA="!S:&%D;W<@:7,@
M;F]T(&]F9B!T:&4@:6UA9V4@=VET:"!R:6=H="!A;&EG;B!A;F0*("`@("`@
M("`O+R!B;W1T;VT@=F%L:6=N+@H@("`@("`@("1M87)G:6X@/2!F;&]O<B@D
M<&%D9&EN9R`K("1D<F]P*2`O(#(["@H@("`@("`@(&EF("@D;6%X=VED=&@I
M('L*("`@("`@("`@("`@)&UA>&-H87)S<&5R;&EN92`](&9L;V]R*"@D;6%X
M=VED=&@@+2`H)&UA<F=I;B`J(#(I*2`O("1F;VYT=VED=&@I.PH@("`@("`@
M("`@("`D=&5X="`]('=O<F1W<F%P*"1T97AT+"`D;6%X8VAA<G-P97)L:6YE
M+"`B7&XB+"`Q*3L*("`@("`@("!]"@H@("`@("`@("\O(%-P;&ET("1T97AT
M(&EN=&\@:6YD:79I9'5A;"!L:6YE<RX*("`@("`@("`D;&EN97,@/2!E>'!L
M;V1E*")<;B(L("1T97AT*3L*"B`@("`@("`@<W=I=&-H("@D=F%L:6=N*2![
M"B`@("`@("`@8V%S92`G8V5N=&5R)SH*("`@("`@("`@("`@)'D@/2`H)'1H
M:7,M/E]C86QL*"=I;6%G95-9)RP@87)R87DH)'1H:7,M/E]I;2DI("T@*"1F
M;VYT:&5I9VAT("H@8V]U;G0H)&QI;F5S*2DI("\@,CL*("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@(&-A<V4@)V)O='1O;2<Z"B`@("`@("`@("`@("1Y
M(#T@)'1H:7,M/E]C86QL*"=I;6%G95-9)RP@87)R87DH)'1H:7,M/E]I;2DI
M("T@*"@D9F]N=&AE:6=H="`J(&-O=6YT*"1L:6YE<RDI("L@)&UA<F=I;BD[
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@("`@
M("`@("`D>2`]("1M87)G:6X["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M('T*"B`@("`@("`@<W=I=&-H("@D:&%L:6=N*2!["B`@("`@("`@8V%S92`G
M<FEG:'0G.@H@("`@("`@("`@("!F;W)E86-H("@D;&EN97,@87,@)&QI;F4I
M('L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^
M7V-A;&PH)VEM86=E4W1R:6YG)RP@87)R87DH)'1H:7,M/E]I;2P@)&8L("@D
M=&AI<RT^7V-A;&PH)VEM86=E4U@G+"!A<G)A>2@D=&AI<RT^7VEM*2D@+2`D
M9F]N='=I9'1H("H@<W1R;&5N*"1L:6YE*2D@+2`D;6%R9VEN("L@)&1R;W`L
M("@D>2`K("1D<F]P*2P@)&QI;F4L("1S:&%D;W<I*2P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?8V%L;"@G:6UA9V53=')I;F<G+"!A<G)A>2@D=&AI<RT^7VEM+"`D9BP@
M*"1T:&ES+3Y?8V%L;"@G:6UA9V536"<L(&%R<F%Y*"1T:&ES+3Y?:6TI*2`M
M("1F;VYT=VED=&@@*B!S=')L96XH)&QI;F4I*2`M("1M87)G:6XL("1Y+"`D
M;&EN92P@)&-O;&]R*2D["B`@("`@("`@("`@("`@("`D>2`K/2`D9F]N=&AE
M:6=H=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@8V%S92`G8V5N=&5R)SH*("`@("`@("`@("`@9F]R96%C:"`H)&QI;F5S
M(&%S("1L:6YE*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M(#T@)'1H:7,M/E]C86QL*"=I;6%G95-T<FEN9R<L(&%R<F%Y*"1T:&ES+3Y?
M:6TL("1F+"!F;&]O<B@H)'1H:7,M/E]C86QL*"=I;6%G95-8)RP@87)R87DH
M)'1H:7,M/E]I;2DI("T@)&9O;G1W:61T:"`J('-T<FQE;B@D;&EN92DI("\@
M,BD@*R`D9')O<"P@*"1Y("L@)&1R;W`I+"`D;&EN92P@)'-H861O=RDI+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G95-T<FEN9R<L(&%R<F%Y*"1T:&ES
M+3Y?:6TL("1F+"!F;&]O<B@H)'1H:7,M/E]C86QL*"=I;6%G95-8)RP@87)R
M87DH)'1H:7,M/E]I;2DI("T@)&9O;G1W:61T:"`J('-T<FQE;B@D;&EN92DI
M("\@,BDL("1Y+"`D;&EN92P@)&-O;&]R*2D["B`@("`@("`@("`@("`@("`D
M>2`K/2`D9F]N=&AE:6=H=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@9F]R96%C:"`H
M)&QI;F5S(&%S("1L:6YE*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G95-T<FEN9R<L(&%R<F%Y*"1T
M:&ES+3Y?:6TL("1F+"`D;6%R9VEN("L@)&1R;W`L("@D>2`K("1D<F]P*2P@
M)&QI;F4L("1S:&%D;W<I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V53
M=')I;F<G+"!A<G)A>2@D=&AI<RT^7VEM+"`D9BP@)&UA<F=I;BP@)'DL("1L
M:6YE+"`D8V]L;W(I*3L*("`@("`@("`@("`@("`@("1Y("L]("1F;VYT:&5I
M9VAT.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M('T*"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$<F%W<R!A('1E>'0@<W1R:6YG(&]N('1H92!I
M;6%G92!I;B!A('-P96-I9FEE9"!L;V-A=&EO;BP@=VET:`H@("`@("H@=&AE
M('-P96-I9FEE9"!S='EL92!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D=&5X="`@("`@("!4:&4@=&5X="!T;R!D<F%W+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)'@@("`@("`@("`@5&AE(&QE9G0@>"!C
M;V]R9&EN871E(&]F('1H92!S=&%R="!O9B!T:&4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('1E>'0@<W1R:6YG+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'D@("`@("`@("`@5&AE('1O<"!Y(&-O;W)D:6YA=&4@;V8@
M=&AE('-T87)T(&]F('1H92!T97AT"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!S=')I;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D9F]N
M="`@("`@("!4:&4@9F]N="!I9&5N=&EF:65R('EO=2!W86YT('1O('5S92!F
M;W(@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!T97AT
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&-O;&]R("`@("`@5&AE(&-O;&]R
M('1H870@>6]U('=A;G0@=&AE('1E>'0@9&ES<&QA>65D(&EN+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&1I<F5C=&EO;B`@06X@:6YT96=E<B!T:&%T('-P
M96-I9FEE<R!T:&4@;W)I96YT871I;VX@;V8*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('1H92!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!T97AT*"1S=')I;F<L("1X+"`D>2P@)&9O;G0@/2`G;6]N;W-P86-E)RP@
M)&-O;&]R(#T@)V)L86-K)RP@)&1I<F5C=&EO;B`](#`I"B`@("!["B`@("`@
M("`@)&,@/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D8V]L;W(I.PH@("`@("`@
M(&EF("AI<U]A*"1C+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D8SL*("`@("`@("!]"B`@("`@("`@)&8@/2`D=&AI<RT^9V5T1F]N
M="@D9F]N="D["B`@("`@("`@<W=I=&-H("@D9&ER96-T:6]N*2!["B`@("`@
M("`@8V%S92`M.3`Z"B`@("`@("`@8V%S92`R-S`Z"B`@("`@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E4W1R:6YG57`G+"!A<G)A>2@D
M=&AI<RT^7VEM+"`D9BP@)'@L("1Y+"`D<W1R:6YG+"`D8RDI.PH@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`P.@H@("`@("`@(&1E9F%U;'0Z
M"B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E4W1R
M:6YG)RP@87)R87DH)'1H:7,M/E]I;2P@)&8L("1X+"`D>2P@)'-T<FEN9RP@
M)&,I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1')A=R!A(&-I<F-L92X*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D>"`@("`@5&AE('@@8V\M;W)D:6YA=&4@;V8@
M=&AE(&-E;G1R92X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y("`@("!4:&4@
M>2!C;RUO<F1I;F%T92!O9B!T:&4@8V5N=')E+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)'(@("`@(%1H92!R861I=7,@;V8@=&AE(&-I<F-L92X*("`@("`J
M($!P87)A;2!S=')I;F<@)&-O;&]R("!4:&4@;&EN92!C;VQO<B!O9B!T:&4@
M8VER8VQE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL;"`@(%1H92!C;VQO
M<B!T;R!F:6QL('1H92!C:7)C;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-I
M<F-L92@D>"P@)'DL("1R+"`D8V]L;W(L("1F:6QL(#T@;G5L;"D*("`@('L*
M("`@("`@("`D8R`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"1C;VQO<BD["B`@
M("`@("`@:68@*&ES7V$H)&,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1C.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?;G5L;"@D
M9FEL;"DI('L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G
M:6UA9V5%;&QI<'-E)RP@87)R87DH)'1H:7,M/E]I;2P@)'@L("1Y+"`D<B`J
M(#(L("1R("H@,BP@)&,I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!I9B`H)&9I;&P@(3T]("1C;VQO<BD@>PH@("`@("`@("`@("`@("`@)&9I
M;&Q#;VQO<B`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"1F:6QL*3L*("`@("`@
M("`@("`@("`@(&EF("AI<U]A*"1F:6QL0V]L;W(L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)&9I;&Q#;VQO<CL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E1FEL;&5D16QL:7!S92<L(&%R<F%Y
M*"1T:&ES+3Y?:6TL("1X+"`D>2P@)'(@*B`R+"`D<B`J(#(L("1F:6QL0V]L
M;W(I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V5%;&QI<'-E)RP@87)R
M87DH)'1H:7,M/E]I;2P@)'@L("1Y+"`D<B`J(#(L("1R("H@,BP@)&,I*3L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^7V-A;&PH)VEM86=E1FEL;&5D16QL:7!S92<L(&%R<F%Y*"1T
M:&ES+3Y?:6TL("1X+"`D>2P@)'(@*B`R+"`D<B`J(#(L("1C*2D["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W(&$@<&]L>6=O
M;B!B87-E9"!O;B!A('-E="!O9B!V97)T:6-E<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)'9E<G1I8V5S("!!;B!A<G)A>2!O9B!X(&%N9"!Y(&QA
M8F5L960@87)R87ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`H
M96<N("1V97)T:6-E<ULP75LG>"==+"`D=F5R=&EC97-;,%U;)WDG72P@+BXN
M*2X*("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R("`@(%1H92!C;VQO<B!Y
M;W4@=V%N="!T;R!D<F%W('1H92!P;VQY9V]N('=I=&@N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1F:6QL("`@("!4:&4@8V]L;W(@=&\@9FEL;"!T:&4@<&]L
M>6=O;BX*("`@("`J+PH@("`@9G5N8W1I;VX@<&]L>6=O;B@D=F5R=',L("1C
M;VQO<BP@)&9I;&P@/2`G;F]N92<I"B`@("!["B`@("`@("`@)'9E<G1I8V5S
M(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D=F5R=',@87,@)'9E<G0I
M('L*("`@("`@("`@("`@)'9E<G1I8V5S6UT@/2`D=F5R=%LG>"==.PH@("`@
M("`@("`@("`D=F5R=&EC97-;72`]("1V97)T6R=Y)UT["B`@("`@("`@?0H*
M("`@("`@("!I9B`H)&9I;&P@(3T@)VYO;F4G*2!["B`@("`@("`@("`@("1F
M(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)&9I;&PI.PH@("`@("`@("`@("!I
M9B`H:7-?82@D9BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1F.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E1FEL;&5D4&]L>6=O;B<L
M(&%R<F%Y*"1T:&ES+3Y?:6TL("1V97)T:6-E<RP@8V]U;G0H)'9E<G1S*2P@
M)&8I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF
M("@D9FEL;"`]/2`G;F]N92<@?'P@)&9I;&P@(3T@)&-O;&]R*2!["B`@("`@
M("`@("`@("1C(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)&-O;&]R*3L*("`@
M("`@("`@("`@:68@*&ES7V$H)&,L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D8SL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G95!O;'EG
M;VXG+"!A<G)A>2@D=&AI<RT^7VEM+"`D=F5R=&EC97,L(&-O=6YT*"1V97)T
M<RDL("1C*2DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@1')A=R!A(')E8W1A;F=L92X*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D>"`@("`@("!4:&4@;&5F="!X+6-O;W)D:6YA
M=&4@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y
M("`@("`@(%1H92!T;W`@>2UC;V]R9&EN871E(&]F('1H92!R96-T86YG;&4N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=VED=&@@("!4:&4@=VED=&@@;V8@
M=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1H96EG:'0@
M(%1H92!H96EG:'0@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!S
M=')I;F<@)&-O;&]R("`@(%1H92!L:6YE(&-O;&]R(&]F('1H92!R96-T86YG
M;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QL("`@("!4:&4@8V]L;W(@
M=&\@9FEL;"!T:&4@<F5C=&%N9VQE('=I=&@N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')E8W1A;F=L92@D>"P@)'DL("1W:61T:"P@)&AE:6=H="P@)&-O;&]R
M(#T@)V)L86-K)RP@)&9I;&P@/2`G;F]N92<I"B`@("!["B`@("`@("`@:68@
M*"1F:6QL("$]("=N;VYE)RD@>PH@("`@("`@("`@("`D9B`]("1T:&ES+3YA
M;&QO8V%T94-O;&]R*"1F:6QL*3L*("`@("`@("`@("`@:68@*&ES7V$H)&8L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D9CL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@
M)'1H:7,M/E]C86QL*"=I;6%G949I;&QE9%)E8W1A;F=L92<L(&%R<F%Y*"1T
M:&ES+3Y?:6TL("1X+"`D>2P@)'@@*R`D=VED=&@L("1Y("L@)&AE:6=H="P@
M)&8I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF
M("@D9FEL;"`]/2`G;F]N92<@?'P@)&9I;&P@(3T@)&-O;&]R*2!["B`@("`@
M("`@("`@("1C(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)&-O;&]R*3L*("`@
M("`@("`@("`@:68@*&ES7V$H)&,L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D8SL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G95)E8W1A
M;F=L92<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1X+"`D>2P@)'@@*R`D=VED=&@L
M("1Y("L@)&AE:6=H="P@)&,I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W(&$@<F]U;F1E9"!R96-T
M86YG;&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@@("`@("`@
M5&AE(&QE9G0@>"UC;V]R9&EN871E(&]F('1H92!R96-T86YG;&4N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D>2`@("`@("!4:&4@=&]P('DM8V]O<F1I;F%T
M92!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'=I
M9'1H("`@5&AE('=I9'1H(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D:&5I9VAT("!4:&4@:&5I9VAT(&]F('1H92!R96-T86YG
M;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]U;F0@("!4:&4@=VED=&@@
M;V8@=&AE(&-O<FYE<B!R;W5N9&EN9RX*("`@("`J($!P87)A;2!S=')I;F<@
M)&-O;&]R("`@(%1H92!L:6YE(&-O;&]R(&]F('1H92!R96-T86YG;&4N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1F:6QL("`@("!4:&4@8V]L;W(@=&\@9FEL
M;"!T:&4@<F]U;F1E9"!R96-T86YG;&4@=VET:"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F]U;F1E9%)E8W1A;F=L92@D>"P@)'DL("1W:61T:"P@)&AE:6=H
M="P@)')O=6YD+"`D8V]L;W(@/2`G8FQA8VLG+"`D9FEL;"`]("=N;VYE)RD*
M("`@('L*("`@("`@("!I9B`H)')O=6YD(#P](#`I('L*("`@("`@("`@("`@
M+R\@3W!T:6UI>F4@;W5T(&%N>2!C86QL<R!W:71H(&YO(&-O<FYE<B!R;W5N
M9&EN9RX*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR96-T86YG;&4H)'@L
M("1Y+"`D=VED=&@L("1H96EG:'0L("1C;VQO<BP@)&9I;&PI.PH@("`@("`@
M('T*"B`@("`@("`@)&,@/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D8V]L;W(I
M.PH@("`@("`@(&EF("AI<U]A*"1C+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D8SL*("`@("`@("!]"@H@("`@("`@("\O(%-E="!C
M;W)N97(@<&]I;G1S('1O(&%V;VED(&QO=',@;V8@<F5D=6YD86YT(&UA=&@N
M"B`@("`@("`@)'@Q(#T@)'@@*R`D<F]U;F0["B`@("`@("`@)'DQ(#T@)'D@
M*R`D<F]U;F0["@H@("`@("`@("1X,B`]("1X("L@)'=I9'1H("T@)')O=6YD
M.PH@("`@("`@("1Y,B`]("1Y("L@)')O=6YD.PH*("`@("`@("`D>#,@/2`D
M>"`K("1W:61T:"`M("1R;W5N9#L*("`@("`@("`D>3,@/2`D>2`K("1H96EG
M:'0@+2`D<F]U;F0["@H@("`@("`@("1X-"`]("1X("L@)')O=6YD.PH@("`@
M("`@("1Y-"`]("1Y("L@)&AE:6=H="`M("1R;W5N9#L*"B`@("`@("`@)'(@
M/2`D<F]U;F0@*B`R.PH*("`@("`@("`O+R!#86QC=6QA=&4@=&AE('5P<&5R
M(&QE9G0@87)C+@H@("`@("`@("1P,2`]("1T:&ES+3Y?87)C4&]I;G1S*"1R
M;W5N9"P@,3@P+"`R,C4I.PH@("`@("`@("1P,B`]("1T:&ES+3Y?87)C4&]I
M;G1S*"1R;W5N9"P@,C(U+"`R-S`I.PH*("`@("`@("`O+R!#86QC=6QA=&4@
M=&AE('5P<&5R(')I9VAT(&%R8RX*("`@("`@("`D<#,@/2`D=&AI<RT^7V%R
M8U!O:6YT<R@D<F]U;F0L(#(W,"P@,S$U*3L*("`@("`@("`D<#0@/2`D=&AI
M<RT^7V%R8U!O:6YT<R@D<F]U;F0L(#,Q-2P@,S8P*3L*"B`@("`@("`@+R\@
M0V%L8W5L871E('1H92!L;W=E<B!R:6=H="!A<F,N"B`@("`@("`@)'`U(#T@
M)'1H:7,M/E]A<F-0;VEN=',H)')O=6YD+"`P+"`T-2D["B`@("`@("`@)'`V
M(#T@)'1H:7,M/E]A<F-0;VEN=',H)')O=6YD+"`T-2P@.3`I.PH*("`@("`@
M("`O+R!#86QC=6QA=&4@=&AE(&QO=V5R(&QE9G0@87)C+@H@("`@("`@("1P
M-R`]("1T:&ES+3Y?87)C4&]I;G1S*"1R;W5N9"P@.3`L(#$S-2D["B`@("`@
M("`@)'`X(#T@)'1H:7,M/E]A<F-0;VEN=',H)')O=6YD+"`Q,S4L(#$X,"D[
M"@H@("`@("`@("\O($1R87<@=&AE(&-O<FYE<G,@+2!U<'!E<B!L969T+"!U
M<'!E<B!R:6=H="P@;&]W97(@<FEG:'0L"B`@("`@("`@+R\@;&]W97(@;&5F
M="X*("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I
M;6%G94%R8R<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1X,2P@)'DQ+"`D<BP@)'(L
M(#$X,"P@,C<P+"`D8RDI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G94%R8R<L(&%R<F%Y*"1T:&ES
M+3Y?:6TL("1X,BP@)'DR+"`D<BP@)'(L(#(W,"P@,S8P+"`D8RDI+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@('T*("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL
M*"=I;6%G94%R8R<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1X,RP@)'DS+"`D<BP@
M)'(L(#`L(#DP+"`D8RDI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G94%R8R<L(&%R<F%Y*"1T:&ES
M+3Y?:6TL("1X-"P@)'DT+"`D<BP@)'(L(#DP+"`Q.#`L("1C*2DL("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@?0H*("`@("`@("`O+R!$<F%W('1H92!C;VYN96-T:6YG('-I9&5S("T@
M=&]P+"!R:6=H="P@8F]T=&]M+"!L969T+@H@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E3&EN92<L(&%R<F%Y*"1T:&ES
M+3Y?:6TL("1X,2`K("1P,ELG>#(G72P@)'DQ("L@)'`R6R=Y,B==+"`D>#(@
M*R`D<#-;)W@Q)UTL("1Y,B`K("1P,ULG>3$G72P@)&,I*2P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]
M"B`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA
M9V5,:6YE)RP@87)R87DH)'1H:7,M/E]I;2P@)'@R("L@)'`T6R=X,B==+"`D
M>3(@*R`D<#1;)WDR)UTL("1X,R`K("1P-5LG>#$G72P@)'DS("L@)'`U6R=Y
M,2==+"`D8RDI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M(#T@)'1H:7,M/E]C86QL*"=I;6%G94QI;F4G+"!A<G)A>2@D=&AI<RT^7VEM
M+"`D>#,@*R`D<#9;)W@R)UTL("1Y,R`K("1P-ELG>3(G72P@)'@T("L@)'`W
M6R=X,2==+"`D>30@*R`D<#=;)WDQ)UTL("1C*2DL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@
M("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E3&EN
M92<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1X-"`K("1P.%LG>#(G72P@)'DT("L@
M)'`X6R=Y,B==+"`D>#$@*R`D<#%;)W@Q)UTL("1Y,2`K("1P,5LG>3$G72P@
M)&,I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("!]"@H@("`@("`@(&EF("@D9FEL;"`A/2`G;F]N92<I
M('L*("`@("`@("`@("`@)&8@/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D9FEL
M;"D["B`@("`@("`@("`@(&EF("AI<U]A*"1F+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)&8["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA
M9V5&:6QL5&]";W)D97(G+"!A<G)A>2@D=&AI<RT^7VEM+"`D>"`K("@D=VED
M=&@@+R`R*2P@)'D@*R`H)&AE:6=H="`O(#(I+"`D8RP@)&8I*2P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M<F%W(&$@;&EN92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>#`@
M("`@5&AE('@@8V\M;W)D:6YA=&4@;V8@=&AE('-T87)T+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)'DP("`@(%1H92!Y(&-O+6]R9&EN871E(&]F('1H92!S
M=&%R="X*("`@("`J($!P87)A;2!I;G1E9V5R("1X,2`@("!4:&4@>"!C;RUO
M<F1I;F%T92!O9B!T:&4@96YD+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'DQ
M("`@(%1H92!Y(&-O+6]R9&EN871E(&]F('1H92!E;F0N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1C;VQO<B`@5&AE(&QI;F4@8V]L;W(N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1W:61T:"`@5&AE('=I9'1H(&]F('1H92!L:6YE+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!L:6YE*"1X,2P@)'DQ+"`D>#(L("1Y,BP@)&-O
M;&]R(#T@)V)L86-K)RP@)'=I9'1H(#T@,2D*("`@('L*("`@("`@("`D8R`]
M("1T:&ES+3YA;&QO8V%T94-O;&]R*"1C;VQO<BD["B`@("`@("`@:68@*&ES
M7V$H)&,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C
M.PH@("`@("`@('T*"B`@("`@("`@+R\@1&]N)W0@;F5E9"!T;R!D;R!A;GET
M:&EN9R!S<&5C:6%L(&9O<B!S:6YG;&4M=VED=&@@;&EN97,N"B`@("`@("`@
M:68@*"1W:61T:"`]/2`Q*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^7V-A;&PH)VEM86=E3&EN92<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1X,2P@
M)'DQ+"`D>#(L("1Y,BP@)&,I*3L*("`@("`@("!](&5L<V5I9B`H)'@Q(#T]
M("1X,BD@>PH@("`@("`@("`@("`O+R!&;W(@=F5R=&EC86P@;&EN97,L('=E
M(&-A;B!J=7-T(&1R87<@82!V97)T:6-A;`H@("`@("`@("`@("`O+R!R96-T
M86YG;&4N"B`@("`@("`@("`@("1L969T(#T@)'@Q("T@9FQO;W(H*"1W:61T
M:"`M(#$I("\@,BD["B`@("`@("`@("`@("1R:6=H="`]("1X,2`K(&9L;V]R
M*"1W:61T:"`O(#(I.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C
M86QL*"=I;6%G949I;&QE9%)E8W1A;F=L92<L(&%R<F%Y*"1T:&ES+3Y?:6TL
M("1L969T+"`D>3$L("1R:6=H="P@)'DR+"`D8RDI.PH@("`@("`@('T@96QS
M96EF("@D>3$@/3T@)'DR*2!["B`@("`@("`@("`@("\O($9O<B!H;W)I>F]N
M=&%L(&QI;F5S+"!W92!C86X@:G5S="!D<F%W(&$@:&]R:7IO;G1A;`H@("`@
M("`@("`@("`O+R!F:6QL960@<F5C=&%N9VQE+@H@("`@("`@("`@("`D=&]P
M(#T@)'DQ("T@9FQO;W(H)'=I9'1H("\@,BD["B`@("`@("`@("`@("1B;W1T
M;VT@/2`D>3$@*R!F;&]O<B@H)'=I9'1H("T@,2D@+R`R*3L*("`@("`@("`@
M("`@)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V5&:6QL961296-T86YG
M;&4G+"!A<G)A>2@D=&AI<RT^7VEM+"`D>#$L("1T;W`L("1X,BP@)&)O='1O
M;2P@)&,I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!!;F=L
M960@;&EN97,N"@H@("`@("`@("`@("`O+R!-86ME('-U<F4@=&AA="!T:&4@
M96YD('!O:6YT<R!O9B!T:&4@;&EN92!A<F4*("`@("`@("`@("`@+R\@<&5R
M<&5N9&EC=6QA<B!T;R!T:&4@;&EN92!I='-E;&8N"B`@("`@("`@("`@("1A
M(#T@871A;C(H)'DQ("T@)'DR+"`D>#(@+2`D>#$I.PH@("`@("`@("`@("`D
M9'@@/2`H<VEN*"1A*2`J("1W:61T:"`O(#(I.PH@("`@("`@("`@("`D9'D@
M/2`H8V]S*"1A*2`J("1W:61T:"`O(#(I.PH*("`@("`@("`@("`@)'9E<G1S
M(#T@87)R87DH)'@R("L@)&1X+"`D>3(@*R`D9'DL("1X,B`M("1D>"P@)'DR
M("T@)&1Y+"`D>#$@+2`D9'@L("1Y,2`M("1D>2P@)'@Q("L@)&1X+"`D>3$@
M*R`D9'DI.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I
M;6%G949I;&QE9%!O;'EG;VXG+"!A<G)A>2@D=&AI<RT^7VEM+"`D=F5R=',L
M(&-O=6YT*"1V97)T<RD@+R`R+"`D8RDI.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W(&$@
M9&%S:&5D(&QI;F4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@P
M("`@("`@("`@("!4:&4@>"!C;RUO<F1I;F%T92!O9B!T:&4@<W1A<G0N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D>3`@("`@("`@("`@(%1H92!Y(&-O+6]R
M9&EN871E(&]F('1H92!S=&%R="X*("`@("`J($!P87)A;2!I;G1E9V5R("1X
M,2`@("`@("`@("`@5&AE('@@8V\M;W)D:6YA=&4@;V8@=&AE(&5N9"X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1Y,2`@("`@("`@("`@5&AE('D@8V\M;W)D
M:6YA=&4@;V8@=&AE(&5N9"X*("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R
M("`@("`@("`@5&AE(&QI;F4@8V]L;W(N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1W:61T:"`@("`@("`@(%1H92!W:61T:"!O9B!T:&4@;&EN92X*("`@("`J
M($!P87)A;2!I;G1E9V5R("1D87-H7VQE;F=T:"`@5&AE(&QE;F=T:"!O9B!A
M(&1A<V@@;VX@=&AE(&1A<VAE9"!L:6YE"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D9&%S:%]S<&%C92`@(%1H92!L96YG=&@@;V8@82!S<&%C92!I;B!T:&4@
M9&%S:&5D(&QI;F4*("`@("`J+PH@("`@9G5N8W1I;VX@9&%S:&5D3&EN92@D
M>#`L("1Y,"P@)'@Q+"`D>3$L("1C;VQO<B`]("=B;&%C:R<L("1W:61T:"`]
M(#$L("1D87-H7VQE;F=T:"`](#(L("1D87-H7W-P86-E(#T@,BD*("`@('L*
M("`@("`@("`D8R`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"1C;VQO<BD["B`@
M("`@("`@:68@*&ES7V$H)&,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1C.PH@("`@("`@('T*("`@("`@("`D=R`]("1T:&ES+3YA
M;&QO8V%T94-O;&]R*"=W:&ET92<I.PH@("`@("`@(&EF("AI<U]A*"1W+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D=SL*("`@("`@
M("!]"@H@("`@("`@("\O(%-E="!U<"!T:&4@<W1Y;&4@87)R87D@86-C;W)D
M:6YG('1O('1H92`D9&%S:%\J('!A<F%M971E<G,N"B`@("`@("`@)'-T>6QE
M(#T@87)R87DH*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D9&%S:%]L
M96YG=&@[("1I*RLI('L*("`@("`@("`@("`@)'-T>6QE6UT@/2`D8SL*("`@
M("`@("!]"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&1A<VA?<W!A8V4[
M("1I*RLI('L*("`@("`@("`@("`@)'-T>6QE6UT@/2`D=SL*("`@("`@("!]
M"@H@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM
M86=E4V5T4W1Y;&4G+"!A<G)A>2@D=&AI<RT^7VEM+"`D<W1Y;&4I*2P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("!]"B`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L
M;"@G:6UA9V539714:&EC:VYE<W,G+"!A<G)A>2@D=&AI<RT^7VEM+"`D=VED
M=&@I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V%L;"@G
M:6UA9V5,:6YE)RP@87)R87DH)'1H:7,M/E]I;2P@)'@P+"`D>3`L("1X,2P@
M)'DQ+"!)34=?0T],3U)?4U193$5$*2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!$<F%W(&$@<&]L>6QI;F4@*&$@;F]N+6-L;W-E9"P@;F]N+69I;&QE9"!P
M;VQY9V]N*2!B87-E9"!O;B!A"B`@("`@*B!S970@;V8@=F5R=&EC97,N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1V97)T:6-E<R`@06X@87)R87D@
M;V8@>"!A;F0@>2!L86)E;&5D(&%R<F%Y<PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@*&5G+B`D=F5R=&EC97-;,%U;)W@G72P@)'9E<G1I8V5S
M6S!=6R=Y)UTL("XN+BDN"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VQO<B`@
M("!4:&4@8V]L;W(@>6]U('=A;G0@=&\@9')A=R!T:&4@;&EN92!W:71H+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=VED=&@@("`@5&AE('=I9'1H(&]F('1H
M92!L:6YE+@H@("`@("HO"B`@("!F=6YC=&EO;B!P;VQY;&EN92@D=F5R=',L
M("1C;VQO<BP@)'=I9'1H(#T@,2D*("`@('L*("`@("`@("`D9FER<W0@/2!T
M<G5E.PH@("`@("`@(&9O<F5A8V@@*"1V97)T<R!A<R`D=F5R="D@>PH@("`@
M("`@("`@("!I9B`H(21F:7)S="D@>PH@("`@("`@("`@("`@("`@:68@*&ES
M7V$H)')E<W5L="`]("1T:&ES+3YL:6YE*"1L87-T6"P@)&QA<W19+"`D=F5R
M=%LG>"==+"`D=F5R=%LG>2==+"`D8V]L;W(L("1W:61T:"DL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1F:7)S="`](&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1L87-T6"`]("1V97)T6R=X)UT["B`@("`@("`@("`@("1L87-T
M62`]("1V97)T6R=Y)UT["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@1')A=R!A;B!A<F,N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)'@@("`@("!4:&4@>"!C;RUO<F1I;F%T92!O9B!T:&4@8V5N=')E+@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)'D@("`@("!4:&4@>2!C;RUO<F1I;F%T92!O
M9B!T:&4@8V5N=')E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'(@("`@("!4
M:&4@<F%D:75S(&]F('1H92!A<F,N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M<W1A<G0@(%1H92!S=&%R="!A;F=L92!O9B!T:&4@87)C+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&5N9"`@("!4:&4@96YD(&%N9VQE(&]F('1H92!A<F,N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8V]L;W(@(%1H92!L:6YE(&-O;&]R
M(&]F('1H92!A<F,N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D9FEL;"`@(%1H
M92!F:6QL(&-O;&]R(&]F('1H92!A<F,@*&1E9F%U;'1S('1O(&YO;F4I+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!A<F,H)'@L("1Y+"`D<BP@)'-T87)T+"`D
M96YD+"`D8V]L;W(@/2`G8FQA8VLG+"`D9FEL;"`](&YU;&PI"B`@("!["B`@
M("`@("`@)&,@/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D8V]L;W(I.PH@("`@
M("`@(&EF("AI<U]A*"1C+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D8SL*("`@("`@("!]"B`@("`@("`@:68@*&ES7VYU;&PH)&9I
M;&PI*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM
M86=E07)C)RP@87)R87DH)'1H:7,M/E]I;2P@)'@L("1Y+"`D<B`J(#(L("1R
M("H@,BP@)'-T87)T+"`D96YD+"`D8RDI.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(&EF("@D9FEL;"`A/3T@)&-O;&]R*2!["B`@("`@("`@("`@
M("`@("`D9B`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"1F:6QL*3L*("`@("`@
M("`@("`@("`@(&EF("AI<U]A*"1F+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1F.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L
M;"@G:6UA9V5&:6QL961!<F,G+"!A<G)A>2@D=&AI<RT^7VEM+"`D>"P@)'DL
M("1R("H@,BP@)'(@*B`R+"`D<W1A<G0L("1E;F0L("1F+"!)34=?05)#7U!)
M12DI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G949I;&QE9$%R8R<L(&%R
M<F%Y*"1T:&ES+3Y?:6TL("1X+"`D>2P@)'(@*B`R+"`D<B`J(#(L("1S=&%R
M="P@)&5N9"P@)&,L($E-1U]!4D-?141'140@?"!)34=?05)#7TY/1DE,3"DI
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?8V%L;"@G:6UA9V5&:6QL961!<F,G+"!A<G)A>2@D=&AI
M<RT^7VEM+"`D>"P@)'DL("1R("H@,BP@)'(@*B`R+"`D<W1A<G0L("1E;F0L
M("1C+"!)34=?05)#7U!)12DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0W)E871E<R!A;B!I;6%G92!O9B!T:&4@9VEV96X@<VEZ92X*("`@("`J($EF
M('!O<W-I8FQE('1H92!F=6YC=&EO;B!R971U<FYS(&$@=')U92!C;VQO<B!I
M;6%G92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=VED=&@@("!4
M:&4@:6UA9V4@=VED=&@N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:&5I9VAT
M("!4:&4@:6UA9V4@:&5I9VAT+@H@("`@("H*("`@("`J($!R971U<FX@<F5S
M;W5R8V5\;V)J96-T(%!%05(@17)R;W(@(%1H92!I;6%G92!H86YD;&5R(&]R
M(&$@4$5!4E]%<G)O<B!O;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9?
M8W)E871E*"1W:61T:"P@)&AE:6=H="D*("`@('L*("`@("`@("`D<F5S=6QT
M(#T@)B1T:&ES+3Y?8V%L;"@G:6UA9V5#<F5A=&54<G5E0V]L;W(G+"!A<G)A
M>2@D=VED=&@L("1H96EG:'0I*3L*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E
M*"1R97-U;'0I*2!["B`@("`@("`@("`@("1R97-U;'0@/2`F)'1H:7,M/E]C
M86QL*"=I;6%G94-R96%T92<L(&%R<F%Y*"1W:61T:"P@)&AE:6=H="DI.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O
M*BH*("`@("`J(%=R87!S(&$@8V%L;"!T;R!A(&9U;F-T:6]N(&]F('1H92!G
M9"!E>'1E;G-I;VXN"B`@("`@*B!)9B!T:&4@8V%L;"!P<F]D=6-E<R!A;B!E
M<G)O<BP@82!014%27T5R<F]R(&ES(')E='5R;F5D+"!T:&4@9G5N8W1I;VX*
M("`@("`J(')E<W5L="!O=&AE<G=I<V4N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9G5N8W1I;VX@(%1H92!N86UE(&]F('1H92!F=6YC=&EO;B!T
M;R!W<F%P+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("`@($%N(&%R
M<F%Y('=I=&@@86QL('!A<F%M971E<G,@9F]R('1H870@9G5N8W1I;VXN"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@16ET:&5R('1H92!F=6YC=&EO
M;B!R97-U;'0@;W(@82!014%27T5R<F]R(&EF(&%N(&5R<F]R"B`@("`@*B`@
M("`@("`@("`@("`@("!O8V-U<F5D('=H96X@97AE8W5T:6YG('1H92!F=6YC
M=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@)E]C86QL*"1F=6YC=&EO;BP@
M)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@=6YS970H)'!H<%]E<G)O
M<FUS9RD["B`@("`@("`@)'1R86-K(#T@:6YI7W-E="@G=')A8VM?97)R;W)S
M)RP@,2D["B`@("`@("`@)')E<W5L="`]($!C86QL7W5S97)?9G5N8U]A<G)A
M>2@D9G5N8W1I;VXL("1P87)A;7,I.PH@("`@("`@(&EF("@D=')A8VL@(3T]
M(&9A;'-E*2!["B`@("`@("`@("`@(&EN:5]S970H)W1R86-K7V5R<F]R<R<L
M("1T<F%C:RD["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)'!H<%]E
M<G)O<FUS9RDI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+G!H
M<"<["B`@("`@("`@("`@("1R97-U;'0@/2!014%2.CIR86ES945R<F]R*"1F
M=6YC=&EO;B`N("<Z("<@+B`D<&AP7V5R<F]R;7-G*3L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+TEM86=E+VEM+G!H<```````````````
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S-S,T-@`Q,#4Q-30S,S<T-@`P
M,C$V-#0`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O26UA9V4N<&AP)SL*"B\J
M*@H@*B!4:&ES(&-L87-S(&EM<&QE;65N=',@=&AE($AO<F1E7TEM86=E.CH@
M05!)(&9O<B!);6%G94UA9VEC:RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M26UA9V4O26UA9V4O:6TN<&AP+'8@,2XS-"XQ,"XQ,2`R,#`V+S`Q+S`Q(#(Q
M.C(X.C(R(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@
M,C`P,RTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N
M;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U
M8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N
M92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@2&]R9&4@
M,RXP"B`J($!P86-K86=E($AO<F1E7TEM86=E"B`J+PIC;&%S<R!(;W)D95])
M;6%G95]I;2!E>'1E;F1S($AO<F1E7TEM86=E('L*"B`@("`O*BH*("`@("`J
M($-A<&%B:6QI=&5S(&]F('1H:7,@9')I=F5R+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?8V%P86)I;&ET:65S(#T@87)R
M87DH)W)E<VEZ92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M8W)O<"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F]T871E
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=G<F%Y<V-A;&4G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9L:7`G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUI<G)O<B<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<V5P:6$G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V-A;G9A<R<*("`@("`@("`@("`@("`@("`@
M("`@("`@("D["@H@("`@+RHJ"B`@("`@*B!7:&%T(&MI;F0@;V8@:6UA9V5S
M('-H;W5L9"!);6%G94UA9VEC:R!G96YE<F%T93\@1&5F875L=',@=&\@)W!N
M9R<N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?='EP92`]("=P;F<G.PH*("`@("\J*@H@("`@("H@3W!E<F%T:6]N<R!T
M;R!B92!P97)F;W)M960N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)%]O<&5R871I;VYS(#T@87)R87DH*3L*"B`@("`O*BH*
M("`@("`J($-U<G)E;G0@<W1R;VME(&-O;&]R.R!C86-H960@<V\@=V4@9&]N
M)W0@:7-S=64@;6]R92`M<W1R;VME(&-O;6UA;F1S"B`@("`@*B!T:&%N(&YE
M8V5S<V%R>2X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]S=')O:V5#;VQO<B`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!#
M=7)R96YT('-T<F]K92!W:61T:#L@8V%C:&5D('-O('=E(&1O;B=T(&ES<W5E
M(&UO<F4@+7-T<F]K97=I9'1H"B`@("`@*B!C;VUM86YD<R!T:&%N(&YE8V5S
M<V%R>2X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)%]S=')O:V57:61T:"`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!#=7)R
M96YT(&9I;&P@8V]L;W([(&-A8VAE9"!S;R!W92!D;VXG="!I<W-U92!M;W)E
M("UF:6QL(&-O;6UA;F1S('1H86X*("`@("`J(&YE8V5S<V%R>2X*("`@("`J
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]F:6QL0V]L
M;W(@/2!N=6QL.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N($AO<F1E7TEM86=E7VEM*"1P87)A;7,I"B`@("![
M"B`@("`@("`@<&%R96YT.CI(;W)D95]);6%G92@D<&%R86US*3L*"B`@("`@
M("`@:68@*"%E;7!T>2@D<&%R86US6R=T>7!E)UTI*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?='EP92`]("1P87)A;7-;)W1Y<&4G73L*("`@("`@("!]"@H@
M("`@("`@("\O($UA:V4@<W5R92!W92!S=&%R="!W:71H(&$@=VAI=&4@8F%C
M:V=R;W5N9"!T;R!B92!C;VYS:7-T96YT"B`@("`@("`@+R\@=VET:"!O=&AE
M<B!D<FEV97)S+@H@("`@("`@(&EF("@A96UP='DH)'!A<F%M<ULG8F%C:V=R
M;W5N9"==*2D@>PH@("`@("`@("`@("`D8F<@/2`D<&%R86US6R=B86-K9W)O
M=6YD)UT["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&)G(#T@)W=H
M:71E)SL*("`@("`@("!]"B`@("`@("`@)'1H:7,M/G)E8W1A;F=L92@P+"`P
M+"`D=&AI<RT^7W=I9'1H+"`D=&AI<RT^7VAE:6=H="P@)&)G+"`D8F<I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!C;VYT96YT('1Y<&4@
M9F]R('1H:7,@:6UA9V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!C;VYT96YT('1Y<&4@9F]R('1H:7,@:6UA9V4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$-O;G1E;G14>7!E*"D*("`@('L*("`@("`@("!R971U
M<FX@)VEM86=E+R<@+B`D=&AI<RT^7W1Y<&4["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!R87<@9&%T82!F;W(@=&AI<R!I;6%G92X*("`@
M("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8V]N=F5R="`@268@=')U92P@
M=&AE(&EM86=E(&1A=&$@=VEL;"!B92!R971U<FYE9"!I;B!T:&4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("!T87)G970@9F]R;6%T+"!I;F1E
M<&5N9&5N=&QY(&9R;VT@86YY(&EM86=E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@;W!E<F%T:6]N<RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE(')A=R!I;6%G92!D871A+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R87<H)&-O;G9E<G0@/2!F86QS92D*("`@('L*("`@("`@("!G;&]B
M86P@)&-O;F8["@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]D871A*2D@
M>PH@("`@("`@("`@("`O+R!)9B!T:&5R92!A<F4@;F\@;W!E<F%T:6]N<RP@
M86YD('=E(&%L<F5A9'D@:&%V92!D871A+`H@("`@("`@("`@("`O+R!D;VXG
M="!B;W1H97(@=W)I=&EN9R!O=70@9FEL97,L(&IU<W0@<F5T=7)N('1H92!C
M=7)R96YT"B`@("`@("`@("`@("\O(&1A=&$N"B`@("`@("`@("`@(&EF("@A
M)&-O;G9E<G0@)B8@(6-O=6YT*"1T:&ES+3Y?;W!E<F%T:6]N<RDI('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1A=&$["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1T;7!I;B`]("1T:&ES+3YT;T9I;&4H)'1H:7,M
M/E]D871A*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!#<F5A
M=&4@86X@96UP='D@4%!-(&9I;&4@=&\@;&]A9"X*("`@("`@("`@("`@)'1M
M<&EN(#T@571I;#HZ9V5T5&5M<$9I;&4H)VEM9R<L(&9A;'-E+"`D=&AI<RT^
M7W1M<&1I<BD["B`@("`@("`@("`@("1F<"`](&9O<&5N*"1T;7!I;BP@)W=B
M)RD["B`@("`@("`@("`@(&9W<FET92@D9G`L('-P<FEN=&8H(E`S7&XE9"`E
M9%QN,C4U7&X@(BP@)'1H:7,M/E]W:61T:"P@)'1H:7,M/E]H96EG:'0I*3L*
M("`@("`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@("`@?0H*("`@("`@("`D
M=&UP;W5T(#T@571I;#HZ9V5T5&5M<$9I;&4H)VEM9R<L(&9A;'-E+"`D=&AI
M<RT^7W1M<&1I<BD["@H@("`@("`@("1C;VUM86YD("`]("1C;VYF6R=I;6%G
M92==6R=C;VYV97)T)UT["B`@("`@("`@)&-O;6UA;F0@+CT@)R`G("X@:6UP
M;&]D92@G("<L("1T:&ES+3Y?;W!E<F%T:6]N<RD["B`@("`@("`@)&-O;6UA
M;F0@+CT@)R`B)R`N("1T;7!I;B`N("<B("MP<F]F:6QE("(J(B`G("X@)'1H
M:7,M/E]T>7!E("X@)SHB)R`N("1T;7!O=70@+B`G(B`R/B8Q)SL*"B`@("`@
M("`@97AE8R@D8V]M;6%N9"P@)&]U='!U="P@)')E='9A;"D["@H@("`@("`@
M("1T:&ES+3Y?9&%T82`](&9I;&5?9V5T7V-O;G1E;G1S*"1T;7!O=70I.PH*
M("`@("`@("!`=6YL:6YK*"1T;7!I;BD["B`@("`@("`@0'5N;&EN:R@D=&UP
M;W5T*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T83L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E<V5T('1H92!I;6%G92!D871A+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R97-E="@I"B`@("!["B`@("`@("`@<&%R96YT.CIR97-E
M="@I.PH@("`@("`@("1T:&ES+3Y?;W!E<F%T:6]N<R`](&%R<F%Y*"D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!297-I>F4@=&AE(&-U<G)E;G0@:6UA9V4N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'=I9'1H("`@5&AE(&YE
M=R!W:61T:"X*("`@("`J($!P87)A;2!I;G1E9V5R("1H96EG:'0@(%1H92!N
M97<@:&5I9VAT+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)')A=&EO("`@36%I
M;G1A:6X@;W)I9VEN86P@87-P96-T(')A=&EO+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R97-I>F4H)'=I9'1H+"`D:&5I9VAT+"`D<F%T:6\@/2!T<G5E*0H@
M("`@>PH@("`@("`@(&EF("@D<F%T:6\I('L*("`@("`@("`@("`@)'1H:7,M
M/E]O<&5R871I;VYS6UT@/2`B+7-I>F4@>R1W:61T:'UX>R1H96EG:'1]("UR
M97-I>F4@>R1W:61T:'UX>R1H96EG:'1](CL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D=&AI<RT^7V]P97)A=&EO;G-;72`]("(M<VEZ92![)'=I
M9'1H?7A[)&AE:6=H='T@+7)E<VEZ92![)'=I9'1H?7A[)&AE:6=H='TA(CL*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F]P('1H92!C=7)R
M96YT(&EM86=E+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1X,2`@
M5&AE('1O<"!L969T(&-O<FYE<B!O9B!T:&4@8W)O<'!E9"!I;6%G92X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1Y,2`@5&AE('1O<"!R:6=H="!C;W)N97(@
M;V8@=&AE(&-R;W!P960@:6UA9V4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M>#(@(%1H92!B;W1T;VT@;&5F="!C;W)N97(@;V8@=&AE(&-R;W!P960@:6UA
M9V4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>3(@(%1H92!B;W1T;VT@<FEG
M:'0@8V]R;F5R(&]F('1H92!C<F]P<&5D(&EM86=E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!C<F]P*"1X,2P@)'DQ+"`D>#(L("1Y,BD*("`@('L*("`@("`@
M("`D;&EN92`]("@D>#(@+2`D>#$I("X@)W@G("X@*"1Y,B`M("1Y,2D@+B`G
M*R<@+B`D>#$@+B`G*R<@+B`D>3(["B`@("`@("`@)'1H:7,M/E]O<&5R871I
M;VYS6UT@/2`G+6-R;W`@)R`N("1L:6YE.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F]T871E('1H92!C=7)R96YT(&EM86=E+@H@("`@("H*("`@("`J($!P
M87)A;2!I;G1E9V5R("1A;F=L92`@("`@("!4:&4@86YG;&4@=&\@<F]T871E
M('1H92!I;6%G92!B>2P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I;B!T:&4@8VQO8VMW:7-E(&1I<F5C=&EO;BX*("`@("`J($!P87)A
M;2!I;G1E9V5R("1B86-K9W)O=6YD("!4:&4@8F%C:V=R;W5N9"!C;VQO<B!T
M;R!F:6QL(&%N>2!T<FEA;F=L97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(')O
M=&%T92@D86YG;&4L("1B86-K9W)O=6YD(#T@)W=H:71E)RD*("`@('L*("`@
M("`@("`D=&AI<RT^7V]P97)A=&EO;G-;72`]("(M<F]T871E('LD86YG;&5]
M("UB86-K9W)O=6YD("1B86-K9W)O=6YD(CL*("`@('T*"B`@("`O*BH*("`@
M("`J($9L:7`@=&AE(&-U<G)E;G0@:6UA9V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&9L:7`H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;W!E<F%T:6]N<UM=
M(#T@)RUF;&EP)SL*("`@('T*"B`@("`O*BH*("`@("`J($UI<G)O<B!T:&4@
M8W5R<F5N="!I;6%G92X*("`@("`J+PH@("`@9G5N8W1I;VX@;6ER<F]R*"D*
M("`@('L*("`@("`@("`D=&AI<RT^7V]P97)A=&EO;G-;72`]("<M9FQO<"<[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T('1H92!C=7)R96YT(&EM
M86=E('1O(&=R87ES8V%L92X*("`@("`J+PH@("`@9G5N8W1I;VX@9W)A>7-C
M86QE*"D*("`@('L*("`@("`@("`D=&AI<RT^7V]P97)A=&EO;G-;72`]("<M
M8V]L;W)S<&%C92!'4D%9("UC;VQO<G,@,C4V)SL*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E<&EA(&9I;'1E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5P
M:6$H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;W!E<F%T:6]N<UM=(#T@)RUM
M;V1U;&%T92`Q,3`@+6-O;&]R<W!A8V4@1U)!62`M8V]L;W)S(#(U-B`M9V%M
M;6$@,2XR-2\Q+S`N-C8G.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=W,@
M82!T97AT('-T<FEN9R!O;B!T:&4@:6UA9V4@:6X@82!S<&5C:69I960@;&]C
M871I;VXL('=I=&@*("`@("`J('1H92!S<&5C:69I960@<W1Y;&4@:6YF;W)M
M871I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'1E>'0@("`@
M("`@5&AE('1E>'0@=&\@9')A=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1X
M("`@("`@("`@(%1H92!L969T('@@8V]O<F1I;F%T92!O9B!T:&4@<W1A<G0@
M;V8@=&AE('1E>'0@<W1R:6YG+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'D@
M("`@("`@("`@5&AE('1O<"!Y(&-O;W)D:6YA=&4@;V8@=&AE('-T87)T(&]F
M('1H92!T97AT('-T<FEN9RX*("`@("`J($!P87)A;2!S=')I;F<@("1F;VYT
M("`@("`@(%1H92!F;VYT(&ED96YT:69I97(@>6]U('=A;G0@=&\@=7-E(&9O
M<B!T:&4@=&5X="X*("`@("`J($!P87)A;2!S=')I;F<@("1C;VQO<B`@("`@
M(%1H92!C;VQO<B!T:&%T('EO=2!W86YT('1H92!T97AT(&1I<W!L87EE9"!I
M;BX*("`@("`J($!P87)A;2!I;G1E9V5R("1D:7)E8W1I;VX@($%N(&EN=&5G
M97(@=&AA="!S<&5C:69I97,@=&AE(&]R:65N=&%T:6]N(&]F('1H92!T97AT
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!T97AT*"1S=')I;F<L("1X+"`D>2P@
M)&9O;G0@/2`G7W-A;G,G+"`D8V]L;W(@/2`G8FQA8VLG+"`D9&ER96-T:6]N
M(#T@,"D*("`@('L*("`@("`@("`D=&AI<RT^<V5T4W1R;VME0V]L;W(H)&-O
M;&]R*3L*("`@("`@("`D=&AI<RT^<V5T4W1R;VME5VED=&@H,2D["@H@("`@
M("`@("1S=')I;F<@/2!A9&1S;&%S:&5S*"<B)R`N("1S=')I;F<@+B`G(B<I
M.PH@("`@("`@("1Y(#T@)'D@*R`Q,CL*("`@("`@("`D=&AI<RT^7V]P97)A
M=&EO;G-;72`]("(M9')A=R!<(G1E>'0@)'@L)'D@)'-T<FEN9UPB(CL*("`@
M('T*"B`@("`O*BH*("`@("`J($1R87<@82!C:7)C;&4N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)'@@("`@(%1H92!X(&-O;W)D:6YA=&4@;V8@
M=&AE(&-E;G1R92X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y("`@("!4:&4@
M>2!C;V]R9&EN871E(&]F('1H92!C96YT<F4N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D<B`@("`@5&AE(')A9&EU<R!O9B!T:&4@8VER8VQE+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8V]L;W(@(%1H92!L:6YE(&-O;&]R(&]F('1H92!C
M:7)C;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QL("`@5&AE(&-O;&]R
M('1O(&9I;&P@=&AE(&-I<F-L92X*("`@("`J+PH@("`@9G5N8W1I;VX@8VER
M8VQE*"1X+"`D>2P@)'(L("1C;VQO<BP@)&9I;&P@/2`G;F]N92<I"B`@("![
M"B`@("`@("`@)'1H:7,M/G-E=%-T<F]K94-O;&]R*"1C;VQO<BD["B`@("`@
M("`@)'1H:7,M/G-E=$9I;&Q#;VQO<B@D9FEL;"D["@H@("`@("`@("1X36%X
M(#T@)'@@*R`D<CL*("`@("`@("`D=&AI<RT^7V]P97)A=&EO;G-;72`]("(M
M9')A=R!<(F-I<F-L92`D>"PD>2`D>$UA>"PD>5PB(CL*("`@('T*"B`@("`O
M*BH*("`@("`J($1R87<@82!P;VQY9V]N(&)A<V5D(&]N(&$@<V5T(&]F('9E
M<G1I8V5S+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D=F5R=&EC97,@
M($%N(&%R<F%Y(&]F('@@86YD('D@;&%B96QE9"!A<G)A>7,*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("AE9RX@)'9E<G1I8V5S6S!=6R=X)UTL
M("1V97)T:6-E<ULP75LG>2==+"`N+BXI+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D8V]L;W(@("`@5&AE(&-O;&]R('EO=2!W86YT('1O(&1R87<@=&AE('!O
M;'EG;VX@=VET:"X*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&P@("`@(%1H
M92!C;VQO<B!T;R!F:6QL('1H92!P;VQY9V]N+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!P;VQY9V]N*"1V97)T<RP@)&-O;&]R+"`D9FEL;"`]("=N;VYE)RD*
M("`@('L*("`@("`@("`D=&AI<RT^<V5T4W1R;VME0V]L;W(H)&-O;&]R*3L*
M("`@("`@("`D=&AI<RT^<V5T1FEL;$-O;&]R*"1F:6QL*3L*"B`@("`@("`@
M)&-O;6UA;F0@/2`G)SL*("`@("`@("!F;W)E86-H("@D=F5R=',@87,@)'9E
M<G0I('L*("`@("`@("`@("`@)&-O;6UA;F0@+CT@<W!R:6YT9B@G("5D+"5D
M)RP@)'9E<G1;)W@G72P@)'9E<G1;)WDG72D["B`@("`@("`@?0H@("`@("`@
M("1T:&ES+3Y?;W!E<F%T:6]N<UM=(#T@(BUD<F%W(%PB<&]L>6=O;B`D8V]M
M;6%N9%PB(CL*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@82!R96-T86YG
M;&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@@("`@("`@5&AE
M(&QE9G0@>"UC;V]R9&EN871E(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D>2`@("`@("!4:&4@=&]P('DM8V]O<F1I;F%T92!O
M9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'=I9'1H
M("`@5&AE('=I9'1H(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D:&5I9VAT("!4:&4@:&5I9VAT(&]F('1H92!R96-T86YG;&4N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VQO<B`@("!4:&4@;&EN92!C;VQO
M<B!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL
M;"`@("`@5&AE(&-O;&]R('1O(&9I;&P@=&AE(')E8W1A;F=L92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5C=&%N9VQE*"1X+"`D>2P@)'=I9'1H+"`D:&5I
M9VAT+"`D8V]L;W(L("1F:6QL(#T@)VYO;F4G*0H@("`@>PH@("`@("`@("1T
M:&ES+3YS9713=')O:V5#;VQO<B@D8V]L;W(I.PH@("`@("`@("1T:&ES+3YS
M971&:6QL0V]L;W(H)&9I;&PI.PH*("`@("`@("`D>$UA>"`]("1X("L@)'=I
M9'1H.PH@("`@("`@("1Y36%X(#T@)'D@*R`D:&5I9VAT.PH@("`@("`@("1T
M:&ES+3Y?;W!E<F%T:6]N<UM=(#T@(BUD<F%W(%PB<F5C=&%N9VQE("1X+"1Y
M("1X36%X+"1Y36%X7"(B.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A
M(')O=6YD960@<F5C=&%N9VQE+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E
M9V5R("1X("`@("`@(%1H92!L969T('@M8V]O<F1I;F%T92!O9B!T:&4@<F5C
M=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'D@("`@("`@5&AE('1O
M<"!Y+6-O;W)D:6YA=&4@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A
M;2!I;G1E9V5R("1W:61T:"`@(%1H92!W:61T:"!O9B!T:&4@<F5C=&%N9VQE
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&AE:6=H="`@5&AE(&AE:6=H="!O
M9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=6YD
M("`@5&AE('=I9'1H(&]F('1H92!C;W)N97(@<F]U;F1I;F<N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D8V]L;W(@("!4:&4@;&EN92!C;VQO<B!O9B!T:&4@
M<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&9I;&P@("`@5&AE
M(&-O;&]R('1O(&9I;&P@=&AE(')O=6YD960@<F5C=&%N9VQE('=I=&@N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')O=6YD961296-T86YG;&4H)'@L("1Y+"`D
M=VED=&@L("1H96EG:'0L("1R;W5N9"P@)&-O;&]R+"`D9FEL;"D*("`@('L*
M("`@("`@("`D=&AI<RT^<V5T4W1R;VME0V]L;W(H)&-O;&]R*3L*("`@("`@
M("`D=&AI<RT^<V5T1FEL;$-O;&]R*"1F:6QL*3L*"B`@("`@("`@)'@Q(#T@
M)'@@*R`D=VED=&@["B`@("`@("`@)'DQ(#T@)'D@*R`D:&5I9VAT.PH@("`@
M("`@("1T:&ES+3Y?;W!E<F%T:6]N<UM=(#T@(BUD<F%W(%PB<F]U;F1296-T
M86YG;&4@)'@L)'D@)'@Q+"1Y,2P@)')O=6YD+"1R;W5N9%PB(CL*("`@('T*
M"B`@("`O*BH*("`@("`J($1R87<@82!L:6YE+@H@("`@("H*("`@("`J($!P
M87)A;2!I;G1E9V5R("1X,"`@("`@5&AE('@@8V]O<F1I;F%T92!O9B!T:&4@
M<W1A<G0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>3`@("`@(%1H92!Y(&-O
M;W)D:6YA=&4@;V8@=&AE('-T87)T+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)'@Q("`@("!4:&4@>"!C;V]R9&EN871E(&]F('1H92!E;F0N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D>3$@("`@(%1H92!Y(&-O;W)D:6YA=&4@;V8@=&AE
M(&5N9"X*("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R("`@5&AE(&QI;F4@
M8V]L;W(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1W:61T:"`@(%1H92!W:61T
M:"!O9B!T:&4@;&EN92X*("`@("`J+PH@("`@9G5N8W1I;VX@;&EN92@D>#`L
M("1Y,"P@)'@Q+"`D>3$L("1C;VQO<B`]("=B;&%C:R<L("1W:61T:"`](#$I
M"B`@("!["B`@("`@("`@)'1H:7,M/G-E=%-T<F]K94-O;&]R*"1C;VQO<BD[
M"B`@("`@("`@)'1H:7,M/G-E=%-T<F]K95=I9'1H*"1W:61T:"D["B`@("`@
M("`@)'1H:7,M/E]O<&5R871I;VYS6UT@/2`B+61R87<@7")L:6YE("1X,"PD
M>3`@)'@Q+"1Y,5PB(CL*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@82!D
M87-H960@;&EN92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>#`@
M("`@("`@("`@(%1H92!X(&-O+6]R9&EN871E(&]F('1H92!S=&%R="X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1Y,"`@("`@("`@("`@5&AE('D@8V\M;W)D
M:6YA=&4@;V8@=&AE('-T87)T+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@Q
M("`@("`@("`@("!4:&4@>"!C;RUO<F1I;F%T92!O9B!T:&4@96YD+@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)'DQ("`@("`@("`@("!4:&4@>2!C;RUO<F1I
M;F%T92!O9B!T:&4@96YD+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]L;W(@
M("`@("`@("!4:&4@;&EN92!C;VQO<BX*("`@("`J($!P87)A;2!S=')I;F<@
M)'=I9'1H("`@("`@("`@5&AE('=I9'1H(&]F('1H92!L:6YE+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&1A<VA?;&5N9W1H("!4:&4@;&5N9W1H(&]F(&$@
M9&%S:"!O;B!T:&4@9&%S:&5D(&QI;F4*("`@("`J($!P87)A;2!I;G1E9V5R
M("1D87-H7W-P86-E("`@5&AE(&QE;F=T:"!O9B!A('-P86-E(&EN('1H92!D
M87-H960@;&EN90H@("`@("HO"B`@("!F=6YC=&EO;B!D87-H961,:6YE*"1X
M,"P@)'DP+"`D>#$L("1Y,2P@)&-O;&]R(#T@)V)L86-K)RP@)'=I9'1H(#T@
M,2P@)&1A<VA?;&5N9W1H(#T@,BP@)&1A<VA?<W!A8V4@/2`R*0H@("`@>PH@
M("`@("`@("1T:&ES+3YS9713=')O:V5#;VQO<B@D8V]L;W(I.PH@("`@("`@
M("1T:&ES+3YS9713=')O:V57:61T:"@D=VED=&@I.PH@("`@("`@("1T:&ES
M+3Y?;W!E<F%T:6]N<UM=(#T@(BUD<F%W(%PB;&EN92`D>#`L)'DP("1X,2PD
M>3%<(B(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W(&$@<&]L>6QI;F4@
M*&$@;F]N+6-L;W-E9"P@;F]N+69I;&QE9"!P;VQY9V]N*2!B87-E9"!O;B!A
M"B`@("`@*B!S970@;V8@=F5R=&EC97,N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1V97)T:6-E<R`@06X@87)R87D@;V8@>"!A;F0@>2!L86)E;&5D
M(&%R<F%Y<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@*&5G+B`D
M=F5R=&EC97-;,%U;)W@G72P@)'9E<G1I8V5S6S!=6R=Y)UTL("XN+BDN"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C;VQO<B`@("!4:&4@8V]L;W(@>6]U('=A
M;G0@=&\@9')A=R!T:&4@;&EN92!W:71H+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=VED=&@@("`@5&AE('=I9'1H(&]F('1H92!L:6YE+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!P;VQY;&EN92@D=F5R=',L("1C;VQO<BP@)'=I9'1H(#T@
M,2D*("`@('L*("`@("`@("`D=&AI<RT^<V5T4W1R;VME0V]L;W(H)&-O;&]R
M*3L*("`@("`@("`D=&AI<RT^<V5T4W1R;VME5VED=&@H)'=I9'1H*3L*("`@
M("`@("`D=&AI<RT^<V5T1FEL;$-O;&]R*"=N;VYE)RD["@H@("`@("`@("1C
M;VUM86YD(#T@)R<["B`@("`@("`@9F]R96%C:"`H)'9E<G1S(&%S("1V97)T
M*2!["B`@("`@("`@("`@("1C;VUM86YD("X]('-P<FEN=&8H)R`E9"PE9"<L
M("1V97)T6R=X)UTL("1V97)T6R=Y)UTI.PH@("`@("`@('T*("`@("`@("`D
M=&AI<RT^7V]P97)A=&EO;G-;72`]("(M9')A=R!<(G!O;'EL:6YE("1C;VUM
M86YD7"(B.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A;B!A<F,N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@@("`@("!4:&4@>"!C;V]R
M9&EN871E(&]F('1H92!C96YT<F4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M>2`@("`@(%1H92!Y(&-O;W)D:6YA=&4@;V8@=&AE(&-E;G1R92X*("`@("`J
M($!P87)A;2!I;G1E9V5R("1R("`@("`@5&AE(')A9&EU<R!O9B!T:&4@87)C
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'-T87)T("!4:&4@<W1A<G0@86YG
M;&4@;V8@=&AE(&%R8RX*("`@("`J($!P87)A;2!I;G1E9V5R("1E;F0@("`@
M5&AE(&5N9"!A;F=L92!O9B!T:&4@87)C+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@)&-O;&]R("!4:&4@;&EN92!C;VQO<B!O9B!T:&4@87)C+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`@)&9I;&P@("!4:&4@9FEL;"!C;VQO<B!O9B!T:&4@
M87)C("AD969A=6QT<R!T;R!N;VYE*2X*("`@("`J+PH@("`@9G5N8W1I;VX@
M87)C*"1X+"`D>2P@)'(L("1S=&%R="P@)&5N9"P@)&-O;&]R(#T@)V)L86-K
M)RP@)&9I;&P@/2`G;F]N92<I"B`@("!["B`@("`@("`@)'1H:7,M/G-E=%-T
M<F]K94-O;&]R*"1C;VQO<BD["B`@("`@("`@)'1H:7,M/G-E=$9I;&Q#;VQO
M<B@D9FEL;"D["@H@("`@("`@("\O(%-P;&ET('5P(&%R8W,@9W)E871E<B!T
M:&%N(#$X,"!D96=R965S(&EN=&\@='=O('!I96-E<RX*("`@("`@("`D;6ED
M(#T@<F]U;F0H*"1S=&%R="`K("1E;F0I("\@,BD["B`@("`@("`@)'@@/2!R
M;W5N9"@D>"D["B`@("`@("`@)'D@/2!R;W5N9"@D>2D["B`@("`@("`@)'(@
M/2!R;W5N9"@D<BD["B`@("`@("`@:68@*"1M:60@/B`Y,"D@>PH@("`@("`@
M("`@("`D=&AI<RT^7V]P97)A=&EO;G-;72`]("(M9')A=R!<(F5L;&EP<V4@
M)'@L)'D@)'(L)'(@)'-T87)T+"1M:61<(B(["B`@("`@("`@("`@("1T:&ES
M+3Y?;W!E<F%T:6]N<UM=(#T@(BUD<F%W(%PB96QL:7!S92`D>"PD>2`D<BPD
M<B`D;6ED+"1E;F1<(B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1H:7,M/E]O<&5R871I;VYS6UT@/2`B+61R87<@7")E;&QI<'-E("1X+"1Y
M("1R+"1R("1S=&%R="PD96YD7"(B.PH@("`@("`@('T*"B`@("`@("`@+R\@
M268@9FEL;&5D+"!D<F%W('1H92!O=71L:6YE+@H@("`@("`@(&EF("@A96UP
M='DH)&9I;&PI*2!["B`@("`@("`@("`@(&QI<W0H)'@Q+"`D>3$I(#T@)'1H
M:7,M/E]C:7)C;&50;VEN="@D<W1A<G0L("1R("H@,BD["B`@("`@("`@("`@
M(&QI<W0H)'@R+"`D>3(I(#T@)'1H:7,M/E]C:7)C;&50;VEN="@D;6ED+"`D
M<B`J(#(I.PH@("`@("`@("`@("!L:7-T*"1X,RP@)'DS*2`]("1T:&ES+3Y?
M8VER8VQE4&]I;G0H)&5N9"P@)'(@*B`R*3L*"B`@("`@("`@("`@("\O(%1H
M:7,@<V5E;7,@=&\@<F5S=6QT(&EN('-L:6=H=&QY(&)E='1E<B!P;&%C96UE
M;G0@;V8*("`@("`@("`@("`@+R\@<&EE('-L:6-E<RX*("`@("`@("`@("`@
M)'@K*SL*("`@("`@("`@("`@)'DK*SL*"B`@("`@("`@("`@("1V97)T<R`]
M(&%R<F%Y*&%R<F%Y*"=X)R`]/B`D>"`K("1X,RP@)WDG(#T^("1Y("L@)'DS
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W@G(#T^("1X
M+"`G>2<@/3X@)'DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G>"<@/3X@)'@@*R`D>#$L("=Y)R`]/B`D>2`K("1Y,2DI.PH*("`@("`@
M("`@("`@:68@*"1M:60@/B`Y,"D@>PH@("`@("`@("`@("`@("`@)'9E<G1S
M,2`](&%R<F%Y*&%R<F%Y*"=X)R`]/B`D>"`K("1X,BP@)WDG(#T^("1Y("L@
M)'DR*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G
M>"<@/3X@)'@L("=Y)R`]/B`D>2DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH)W@G(#T^("1X("L@)'@Q+"`G>2<@/3X@)'D@*R`D
M>3$I*3L*("`@("`@("`@("`@("`@("1V97)T<S(@/2!A<G)A>2AA<G)A>2@G
M>"<@/3X@)'@@*R`D>#,L("=Y)R`]/B`D>2`K("1Y,RDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)W@G(#T^("1X+"`G>2<@/3X@
M)'DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=X
M)R`]/B`D>"`K("1X,BP@)WDG(#T^("1Y("L@)'DR*2D["@H@("`@("`@("`@
M("`@("`@)'1H:7,M/G!O;'EG;VXH)'9E<G1S,2P@)&9I;&PL("1F:6QL*3L*
M("`@("`@("`@("`@("`@("1T:&ES+3YP;VQY9V]N*"1V97)T<S(L("1F:6QL
M+"`D9FEL;"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^<&]L>6=O;B@D=F5R=',L("1F:6QL+"`D9FEL;"D["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3YP;VQY;&EN92@D=F5R=',L
M("1C;VQO<BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0VAA
M;F=E('1H92!C=7)R96YT('-T<F]K92!C;VQO<BX@5VEL;"!O;FQY(&%F9F5C
M="!T:&4@8V]M;6%N9`H@("`@("H@<W1R:6YG(&EF("1S=')O:V4@:7,@9&EF
M9F5R96YT(&9R;VT@=&AE('!R979I;W5S('-T<F]K92!C;VQO<@H@("`@("H@
M*'-T;W)E9"!I;B`D=&AI<RT^7W-T<F]K94-O;&]R*2X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J($!S964@)%]S=')O:V5#;VQO<@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R("!4:&4@;F5W('-T
M<F]K92!C;VQO<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T4W1R;VME0V]L
M;W(H)&-O;&]R*0H@("`@>PH@("`@("`@(&EF("@D8V]L;W(@(3T@)'1H:7,M
M/E]S=')O:V5#;VQO<BD@>PH@("`@("`@("`@("`D=&AI<RT^7V]P97)A=&EO
M;G-;72`]("(M<W1R;VME("1C;VQO<B(["B`@("`@("`@("`@("1T:&ES+3Y?
M<W1R;VME0V]L;W(@/2`D8V]L;W(["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@0VAA;F=E('1H92!C=7)R96YT('-T<F]K92!W:61T:"X@5VEL
M;"!O;FQY(&%F9F5C="!T:&4@8V]M;6%N9`H@("`@("H@<W1R:6YG(&EF("1W
M:61T:"!I<R!D:69F97)E;G0@9G)O;2!T:&4@<')E=FEO=7,@<W1R;VME('=I
M9'1H"B`@("`@*B`H<W1O<F5D(&EN("1T:&ES+3Y?<W1R;VME5VED=&@I+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'-E92`D7W-T
M<F]K90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'=I9'1H("!4:&4@
M;F5W('-T<F]K92!W:61T:"X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T4W1R
M;VME5VED=&@H)'=I9'1H*0H@("`@>PH@("`@("`@(&EF("@D=VED=&@@(3T@
M)'1H:7,M/E]S=')O:V57:61T:"D@>PH@("`@("`@("`@("`D=&AI<RT^7V]P
M97)A=&EO;G-;72`]("(M<W1R;VME=VED=&@@)'=I9'1H(CL*("`@("`@("`@
M("`@)'1H:7,M/E]S=')O:V57:61T:"`]("1W:61T:#L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#:&%N9V4@=&AE(&-U<G)E;G0@9FEL;"!C
M;VQO<BX@5VEL;"!O;FQY(&%F9F5C="!T:&4@8V]M;6%N9`H@("`@("H@<W1R
M:6YG(&EF("1C;VQO<B!I<R!D:69F97)E;G0@9G)O;2!T:&4@<')E=FEO=7,@
M9FEL;"!C;VQO<@H@("`@("H@*'-T;W)E9"!I;B`D=&AI<RT^7V9I;&Q#;VQO
M<BDN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<V5E
M("1?9FEL;`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R("!4
M:&4@;F5W(&9I;&P@8V]L;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$9I
M;&Q#;VQO<B@D8V]L;W(I"B`@("!["B`@("`@("`@:68@*"1C;VQO<B`A/2`D
M=&AI<RT^7V9I;&Q#;VQO<BD@>PH@("`@("`@("`@("`D=&AI<RT^7V]P97)A
M=&EO;G-;72`]("(M9FEL;"`D8V]L;W(B.PH@("`@("`@("`@("`D=&AI<RT^
M7V9I;&Q#;VQO<B`]("1C;VQO<CL*("`@("`@("!]"B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TEM
M86=E+W!N9RYP:'``````````````````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`Q-34S,@`Q,#4Q-30S,S<T-@`P,C(P,30`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92!D
M:7)N86UE*%]?1DE,15]?*2`N("<O+BXO26UA9V4N<&AP)SL*"B\J*@H@*B!4
M:&ES(&-L87-S(&EM<&QE;65N=',@=&AE($AO<F1E7TEM86=E.CH@05!)(&9O
M<B!03D<@:6UA9V5S+B!)=`H@*B!M86EN;'D@<')O=FED97,@<V]M92!U=&EL
M:71Y(&9U;F-T:6]N<RP@<W5C:"!A<R!T:&4@86)I;&ET>2!T;R!M86ME"B`J
M('!I>&5L<R!O<B!S;VQI9"!I;6%G97,@9F]R(&YO=RX*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO26UA9V4O26UA9V4O<&YG+G!H<"QV(#$N,3DN,3`N."`R
M,#`V+S`U+S,Q(#$W.C`V.C,V('-E;'-K>2!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,RTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN
M8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR
M86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D
M92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?26UA9V4*("HO"F-L87-S($AO<F1E
M7TEM86=E7W!N9R!E>'1E;F1S($AO<F1E7TEM86=E('L*"B`@("`O*BH*("`@
M("`J(%1H92!A<G)A>2!O9B!P:7AE;"!D871A+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?:6UG(#T@87)R87DH*3L*"B`@
M("`O*BH*("`@("`J($-O;&]R(&1E<'1H("AO;FQY(#@@86YD(#$V(&EM<&QE
M;65N=&5D*2X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@
M("`@=F%R("1?8V]L;W)$97!T:"`](#@["@H@("`@+RHJ"B`@("`@*B!#;VQO
M<B!T>7!E("AO;FQY(#(@*'1R=64@8V]L;W(I(&EM<&QE;65N=&5D*2X*("`@
M("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?8V]L
M;W)4>7!E(#T@,CL*"B`@("`O*BH*("`@("`J($-O;7!R97-S:6]N(&UE=&AO
M9"`H,"!I<R!T:&4@;VYL>2!C=7)R96YT('9A;&ED('9A;'5E*2X*("`@("`J
M"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?8V]M<')E
M<W-I;VY-971H;V0@/2`P.PH*("`@("\J*@H@("`@("H@1FEL=&5R(&UE=&AO
M9"`H,"!I<R!T:&4@;VYL>2!C=7)R96YT('9A;&ED('9A;'5E*2X*("`@("`J
M"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?9FEL=&5R
M365T:&]D(#T@,#L*"B`@("`O*BH*("`@("`J($EN=&5R;&%C92!M971H;V0@
M*&]N;'D@,"`H;F\@:6YT97)L86-E*2!I;7!L96UE;G1E9"DN"B`@("`@*@H@
M("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7VEN=&5R;&%C
M94UE=&AO9"`](#`["@H@("`@+RHJ"B`@("`@*B!03D<@:6UA9V4@8V]N<W1R
M=6-T;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TEM86=E7W!N9R@D
M<&%R86US*0H@("`@>PH@("`@("`@('!A<F5N=#HZ2&]R9&5?26UA9V4H)'!A
M<F%M<RD["@H@("`@("`@(&EF("@A96UP='DH)'!A<F%M<ULG=VED=&@G72DI
M('L*("`@("`@("`@("`@)'1H:7,M/G)E8W1A;F=L92@P+"`P+"`D<&%R86US
M6R=W:61T:"==+"`D<&%R86US6R=H96EG:'0G72P@)'1H:7,M/E]B86-K9W)O
M=6YD+"`D=&AI<RT^7V)A8VMG<F]U;F0I.PH@("`@("`@('T*("`@('T*"B`@
M("!F=6YC=&EO;B!G971#;VYT96YT5'EP92@I"B`@("!["B`@("`@("`@<F5T
M=7)N("=I;6%G92]P;F<G.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M('1H92!R87<@9&%T82!F;W(@=&AI<R!I;6%G92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(')A=R!I;6%G92!D871A+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R87<H*0H@("`@>PH@("`@("`@(')E='5R;@H@("`@("`@
M("`@("`D=&AI<RT^7VAE861E<B@I("X*("`@("`@("`@("`@)'1H:7,M/E])
M2$12*"D@+@H*("`@("`@("`@("`@+RH@4V%Y('=H870@8W)E871E9"!T:&4@
M:6UA9V4@9FEL92X@*B\*("`@("`@("`@("`@)'1H:7,M/E]T15AT*"=3;V9T
M=V%R92<L("=(;W)D92!&<F%M97=O<FL@26UA9V5?<&YG($-L87-S)RD@+@H*
M("`@("`@("`@("`@+RH@4V5T('1H92!L87-T(&UO9&EF:65D(&1A=&4O=&EM
M92X@*B\*("`@("`@("`@("`@)'1H:7,M/E]T24U%*"D@+@H*("`@("`@("`@
M("`@)'1H:7,M/E])1$%4*"D@+@H@("`@("`@("`@("`D=&AI<RT^7TE%3D0H
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E<V5T('1H92!I;6%G92!D871A
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R97-E="@I"B`@("!["B`@("`@("`@
M<&%R96YT.CIR97-E="@I.PH@("`@("`@("1T:&ES+3Y?:6UG(#T@87)R87DH
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@82!R96-T86YG;&4N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@@("`@("`@5&AE(&QE9G0@
M>"UC;V]R9&EN871E(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D>2`@("`@("!4:&4@=&]P('DM8V]O<F1I;F%T92!O9B!T:&4@
M<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'=I9'1H("`@5&AE
M('=I9'1H(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D:&5I9VAT("!4:&4@:&5I9VAT(&]F('1H92!R96-T86YG;&4N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1C;VQO<B`@("!4:&4@;&EN92!C;VQO<B!O9B!T
M:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL;"`@("`@
M5&AE(&-O;&]R('1O(&9I;&P@=&AE(')E8W1A;F=L92!W:71H+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!R96-T86YG;&4H)'@L("1Y+"`D=VED=&@L("1H96EG
M:'0L("1C;VQO<B`]("=B;&%C:R<L("1F:6QL(#T@)VYO;F4G*0H@("`@>PH@
M("`@("`@(&QI<W0H)'(L("1G+"`D8BD@/2`D=&AI<RT^9V5T4D="*"1C;VQO
M<BD["B`@("`@("`@:68@*"1F:6QL("$]("=N;VYE)RD@>PH@("`@("`@("`@
M("!L:7-T*"1F4BP@)&9'+"`D9D(I(#T@)'1H:7,M/F=E=%)'0B@D9FEL;"D[
M"B`@("`@("`@?0H*("`@("`@("`D>#(@/2`D>"`K("1W:61T:#L*("`@("`@
M("`D>3(@/2`D>2`K("1H96EG:'0["@H@("`@("`@(&9O<B`H)&@@/2`D>3L@
M)&@@/#T@)'DR.R`D:"LK*2!["B`@("`@("`@("`@(&9O<B`H)'<@/2`D>#L@
M)'<@/#T@)'@R.R`D=RLK*2!["B`@("`@("`@("`@("`@("`O+R!3964@:68@
M=V4G<F4@;VX@86X@961G92X*("`@("`@("`@("`@("`@(&EF("@D=R`]/2`D
M>"!\?"`D:"`]/2`D>2!\?"`D=R`]/2`D>#(@?'P@)&@@/3T@)'DR*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;6=;)&A=6R1W72`](&%R<F%Y
M*"=R)R`]/B`D<BP@)V<G(#T^("1G+"`G8B<@/3X@)&(I.PH@("`@("`@("`@
M("`@("`@?2!E;'-E:68@*"1F:6QL("$]("=N;VYE)RD@>PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?:6UG6R1H75LD=UT@/2!A<G)A>2@G<B<@/3X@
M)&92+"`G9R<@/3X@)&9'+"`G8B<@/3X@)&9"*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($-R96%T92!T:&4@4$Y'(&9I;&4@:&5A9&5R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?:&5A9&5R*"D*("`@('L*("`@("`@("!R971U<FX@<&%C:R@G
M0T-#0T-#0T,G+"`Q,S<L(#@P+"`W."P@-S$L(#$S+"`Q,"P@,C8L(#$P*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!);6%G92!(96%D97(@8FQO
M8VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(%])2$12*"D*("`@('L*("`@("`@
M("`D9&%T82`]('!A8VLH)V$T3DY#0T-#0R<L("=)2$12)RP@)'1H:7,M/E]W
M:61T:"P@)'1H:7,M/E]H96EG:'0L("1T:&ES+3Y?8V]L;W)$97!T:"P@)'1H
M:7,M/E]C;VQO<E1Y<&4L("1T:&ES+3Y?8V]M<')E<W-I;VY-971H;V0L("1T
M:&ES+3Y?9FEL=&5R365T:&]D+"`D=&AI<RT^7VEN=&5R;&%C94UE=&AO9"D[
M"B`@("`@("`@<F5T=7)N('!A8VLH)TYA)R`N('-T<FQE;B@D9&%T82D@+B`G
M3B<L('-T<FQE;B@D9&%T82D@+2`T+"`D9&%T82P@8W)C,S(H)&1A=&$I*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!)14Y$(&)L;V-K+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?245.1"@I"B`@("!["B`@("`@("`@)&1A=&$@
M/2`G245.1"<["B`@("`@("`@<F5T=7)N('!A8VLH)TYA)R`N('-T<FQE;B@D
M9&%T82D@+B`G3B<L('-T<FQE;B@D9&%T82D@+2`T+"`D9&%T82P@8W)C,S(H
M)&1A=&$I*3L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!);6%G92!$
M871A(&)L;V-K+@H@("`@("HO"B`@("!F=6YC=&EO;B!?241!5"@I"B`@("![
M"B`@("`@("`@)&1A=&$@/2`G)SL*("`@("`@("`D<')E=G-C86YL:6YE(#T@
M;G5L;#L*("`@("`@("`D9FEL=&5R(#T@,#L*("`@("`@("!F;W(@*"1I(#T@
M,#L@)&D@/"`D=&AI<RT^7VAE:6=H=#L@)&DK*RD@>PH@("`@("`@("`@("`D
M<V-A;FQI;F4@/2!A<G)A>2@I.PH@("`@("`@("`@("`D9&%T82`N/2!C:'(H
M)&9I;'1E<BD["B`@("`@("`@("`@(&9O<B`H)&H@/2`P.R`D:B`\("1T:&ES
M+3Y?=VED=&@[("1J*RLI('L*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^
M7V-O;&]R1&5P=&@@/3T@."D@>PH@("`@("`@("`@("`@("`@("`@("1S8V%N
M;&EN95LD:ET@/2!P86-K*"=#0T,G+"`D=&AI<RT^7VEM9ULD:5U;)&I=6R=R
M)UTL("1T:&ES+3Y?:6UG6R1I75LD:EU;)V<G72P@)'1H:7,M/E]I;6=;)&E=
M6R1J75LG8B==*3L*("`@("`@("`@("`@("`@('T@96QS96EF("@D=&AI<RT^
M7V-O;&]R1&5P=&@@/3T@,38I('L*("`@("`@("`@("`@("`@("`@("`D<V-A
M;FQI;F5;)&I=(#T@<&%C:R@G;FYN)RP@)'1H:7,M/E]I;6=;)&E=6R1J75LG
M<B==(#P\(#@L("1T:&ES+3Y?:6UG6R1I75LD:EU;)V<G72`\/"`X+"`D=&AI
M<RT^7VEM9ULD:5U;)&I=6R=B)UT@/#P@."D["B`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@:68@*"1F:6QT97(@/3T@,"D@>PH@("`@("`@
M("`@("`@("`@("`@("\J($YO($9I;'1E<BX@*B\*("`@("`@("`@("`@("`@
M("`@("`D9&%T82`N/2`D<V-A;FQI;F5;)&I=.PH@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*"1F:6QT97(@/3T@,BD@>PH@("`@("`@("`@("`@("`@("`@
M("\J(%5P($9I;'1E<BX@*B\*("`@("`@("`@("`@("`@("`@("`D<&EX96P@
M/2`D<V-A;FQI;F5;)&I=("T@)'!R979S8V%N;&EN95LD:ET["B`@("`@("`@
M("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V]L;W)$97!T:"`]/2`X*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1D871A("X]('!A8VLH)T-#0R<L("1P
M:7AE;"`^/B`Q-BP@*"1P:7AE;"`^/B`X*2`F(#!X1D8L("1P:7AE;"`F(#!X
M1D8I.PH@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D=&AI<RT^7V-O
M;&]R1&5P=&@@/3T@,38I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&1A
M=&$@+CT@<&%C:R@G;FYN)RP@*"1P:7AE;"`^/B`S,BDL("@D<&EX96P@/CX@
M,38I("8@,'A&1D9&+"`D<&EX96P@)B`P>$9&1D8I.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D<')E=G-C86YL:6YE(#T@)'-C86YL:6YE.PH@("`@("`@('T*
M("`@("`@("`D8V]M<')E<W-E9"`](&=Z9&5F;&%T92@D9&%T82P@.2D["@H@
M("`@("`@("1D871A(#T@)TE$050G("X@<&%C:R@G0T-A)R`N('-T<FQE;B@D
M8V]M<')E<W-E9"D@+B`G830G+"`P>#<X+"`P>#`Q+"`D8V]M<')E<W-E9"P@
M)'1H:7,M/E]!9&QE<C,R*"1D871A*2D["B`@("`@("`@<F5T=7)N('!A8VLH
M)TYA)R`N('-T<FQE;B@D9&%T82D@+B`G3B<L('-T<FQE;B@D9&%T82D@+2`T
M+"`D9&%T82P@8W)C,S(H)&1A=&$I*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($-R96%T92!T15AT(&)L;V-K+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=$58
M="@D:V5Y=V]R9"P@)'1E>'0I"B`@("!["B`@("`@("`@)&1A=&$@/2`G=$58
M="<@+B`D:V5Y=V]R9"`N(")<,"(@+B`D=&5X=#L*("`@("`@("!R971U<FX@
M<&%C:R@G3F$G("X@<W1R;&5N*"1D871A*2`N("=.)RP@<W1R;&5N*"1D871A
M*2`M(#0L("1D871A+"!C<F,S,B@D9&%T82DI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0W)E871E(&QA<W0@;6]D:69I960@=&EM92!B;&]C:RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W1)344H)&1A=&4@/2!N=6QL*0H@("`@>PH@("`@
M("`@(&EF("AI<U]N=6QL*"1D871E*2D@>PH@("`@("`@("`@("`D9&%T92`]
M('1I;64H*3L*("`@("`@("!]"@H@("`@("`@("1D871A(#T@)W1)344G("X@
M<&%C:R@G;D-#0T-#)RP@:6YT=F%L*&1A=&4H)UDG+"`D9&%T92DI+"!I;G1V
M86PH9&%T92@G;2<L("1D871E*2DL(&EN='9A;"AD871E*"=J)RP@)&1A=&4I
M*2P@:6YT=F%L*&1A=&4H)T<G+"`D9&%T92DI+"!I;G1V86PH9&%T92@G:2<L
M("1D871E*2DL(&EN='9A;"AD871E*"=S)RP@)&1A=&4I*2D["B`@("`@("`@
M<F5T=7)N('!A8VLH)TYA)R`N('-T<FQE;B@D9&%T82D@+B`G3B<L('-T<FQE
M;B@D9&%T82D@+2`T+"`D9&%T82P@8W)C,S(H)&1A=&$I*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($-A;&-U;&%T92!A;B!!9&QE<C,R(&-H96-K<W5M(&9O
M<B!A('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@7T%D;&5R,S(H)&EN
M<'5T*0H@("`@>PH@("`@("`@("1S,2`](#$["B`@("`@("`@)',R(#T@,#L*
M("`@("`@("`D:4UA>"`]('-T<FQE;B@D:6YP=70I.PH@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\("1I36%X.R`D:2LK*2!["B`@("`@("`@("`@("1S,2`]
M("@D<S$@*R!O<F0H)&EN<'5T6R1I72DI("4@,'A&1D8Q.PH@("`@("`@("`@
M("`D<S(@/2`H)',R("L@)',Q*2`E(#!X1D9&,3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N('!A8VLH)TXG+"`H*"1S,B`\/"`Q-BD@?"`D<S$I*3L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TEM86=E+W)G8BYP:'``````
M````````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T,C8W,0`Q,#4Q-30S
M,S<T-@`P,C(P,#8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J(%)'0B!C;VQO<B!N86UE<R]V86QU97,N
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TEM86=E+TEM86=E+W)G8BYP:'`L
M=B`Q+C(N,3(N,2`R,#`U+S$P+S$X(#$Q.C`Q.C$S(&IA;B!%>'`@)`H@*@H@
M*B!`<&%C:V%G92!(;W)D95]);6%G90H@*B\*)$=,3T)!3%-;)VAO<F1E7VEM
M86=E7W)G8E]C;VQO<G,G72`](&%R<F%Y*`H@("`@)V%Q=6$G(#T^(&%R<F%Y
M*#`L(#(U-2P@,C4U*2P@"0D*("`@("=L:6UE)R`]/B!A<G)A>2@P+"`R-34L
M(#`I+"`)"0H@("`@)W1E86PG(#T^(&%R<F%Y*#`L(#$R."P@,3(X*2P*("`@
M("=W:&ET97-M;VME)R`]/B!A<G)A>2@R-#4L(#(T-2P@,C0U*2P*("`@("=G
M86EN<V)O<F\G(#T^(&%R<F%Y*#(R,"P@,C(P+"`R,C`I+`H@("`@)V]L9&QA
M8V4G(#T^(&%R<F%Y*#(U,RP@,C0U+"`R,S`I+`H@("`@)VQI;F5N)R`]/B!A
M<G)A>2@R-3`L(#(T,"P@,C,P*2P*("`@("=A;G1I<75E=VAI=&4G(#T^(&%R
M<F%Y*#(U,"P@,C,U+"`R,34I+`H@("`@)W!A<&%Y87=H:7`G(#T^(&%R<F%Y
M*#(U-2P@,C,Y+"`R,3,I+`H@("`@)V)L86YC:&5D86QM;VYD)R`]/B!A<G)A
M>2@R-34L(#(S-2P@,C`U*2P*("`@("=B:7-Q=64G(#T^(&%R<F%Y*#(U-2P@
M,C(X+"`Q.38I+`H@("`@)W!E86-H<'5F9B<@/3X@87)R87DH,C4U+"`R,3@L
M(#$X-2DL"B`@("`G;F%V86IO=VAI=&4G(#T^(&%R<F%Y*#(U-2P@,C(R+"`Q
M-S,I+`H@("`@)VUO8V-A<VEN)R`]/B!A<G)A>2@R-34L(#(R."P@,3@Q*2P*
M("`@("=C;W)N<VEL:R<@/3X@87)R87DH,C4U+"`R-#@L(#(R,"DL"B`@("`G
M:79O<GDG(#T^(&%R<F%Y*#(U-2P@,C4U+"`R-#`I+`H@("`@)VQE;6]N8VAI
M9F9O;B<@/3X@87)R87DH,C4U+"`R-3`L(#(P-2DL"B`@("`G<V5A<VAE;&PG
M(#T^(&%R<F%Y*#(U-2P@,C0U+"`R,S@I+`H@("`@)VUI;G1C<F5A;2<@/3X@
M87)R87DH,C0U+"`R-34L(#(U,"DL"B`@("`G87IU<F4G(#T^(&%R<F%Y*#(T
M,"P@,C4U+"`R-34I+`H@("`@)V%L:6-E8FQU92<@/3X@87)R87DH,C0P+"`R
M-#@L(#(U-2DL"B`@("`G;&%V96YD97(G(#T^(&%R<F%Y*#(S,"P@,C,P+"`R
M-3`I+`H@("`@)VQA=F5N9&5R8FQU<V@G(#T^(&%R<F%Y*#(U-2P@,C0P+"`R
M-#4I+`H@("`@)VUI<W1Y<F]S92<@/3X@87)R87DH,C4U+"`R,C@L(#(R-2DL
M"B`@("`G=VAI=&4G(#T^(&%R<F%Y*#(U-2P@,C4U+"`R-34I+`H@("`@)V)L
M86-K)R`]/B!A<G)A>2@P+"`P+"`P*2P*("`@("=D87)K<VQA=&5G<F%Y)R`]
M/B!A<G)A>2@T-RP@-SDL(#<Y*2P*("`@("=D:6UG<F%Y)R`]/B!A<G)A>2@Q
M,#4L(#$P-2P@,3`U*2P*("`@("=S;&%T96=R87DG(#T^(&%R<F%Y*#$Q,BP@
M,3(X+"`Q-#0I+`H@("`@)VQI9VAT<VQA=&5G<F%Y)R`]/B!A<G)A>2@Q,3DL
M(#$S-BP@,34S*2P*("`@("=G<F%Y)R`]/B!A<G)A>2@Q.3`L(#$Y,"P@,3DP
M*2P*("`@("=L:6=H=&=R87DG(#T^(&%R<F%Y*#(Q,2P@,C$Q+"`R,3$I+`H@
M("`@)VUI9&YI9VAT8FQU92<@/3X@87)R87DH,C4L(#(U+"`Q,3(I+`H@("`@
M)VYA=GDG(#T^(&%R<F%Y*#`L(#`L(#$R."DL"B`@("`G8V]R;F9L;W=E<F)L
M=64G(#T^(&%R<F%Y*#$P,"P@,30Y+"`R,S<I+`H@("`@)V1A<FMS;&%T96)L
M=64G(#T^(&%R<F%Y*#<R+"`V,2P@,3,Y*2P*("`@("=S;&%T96)L=64G(#T^
M(&%R<F%Y*#$P-BP@.3`L(#(P-2DL"B`@("`G;65D:75M<VQA=&5B;'5E)R`]
M/B!A<G)A>2@Q,C,L(#$P-"P@,C,X*2P*("`@("=L:6=H='-L871E8FQU92<@
M/3X@87)R87DH,3,R+"`Q,3(L(#(U-2DL"B`@("`G;65D:75M8FQU92<@/3X@
M87)R87DH,"P@,"P@,C`U*2P*("`@("=R;WEA;&)L=64G(#T^(&%R<F%Y*#8U
M+"`Q,#4L(#(R-2DL"B`@("`G8FQU92<@/3X@87)R87DH,"P@,"P@,C4U*2P*
M("`@("=D;V1G97)B;'5E)R`]/B!A<G)A>2@S,"P@,30T+"`R-34I+`H@("`@
M)V1E97!S:WEB;'5E)R`]/B!A<G)A>2@P+"`Q.3$L(#(U-2DL"B`@("`G<VMY
M8FQU92<@/3X@87)R87DH,3,U+"`R,#8L(#(S-2DL"B`@("`G;&EG:'1S:WEB
M;'5E)R`]/B!A<G)A>2@Q,S4L(#(P-BP@,C4P*2P*("`@("=S=&5E;&)L=64G
M(#T^(&%R<F%Y*#<P+"`Q,S`L(#$X,"DL"B`@("`G;&EG:'1R960G(#T^(&%R
M<F%Y*#(Q,2P@,38W+"`Q-C@I+`H@("`@)VQI9VAT<W1E96QB;'5E)R`]/B!A
M<G)A>2@Q-S8L(#$Y-BP@,C(R*2P*("`@("=L:6=H=&)L=64G(#T^(&%R<F%Y
M*#$W,RP@,C$V+"`R,S`I+`H@("`@)W!O=V1E<F)L=64G(#T^(&%R<F%Y*#$W
M-BP@,C(T+"`R,S`I+`H@("`@)W!A;&5T=7)Q=6]I<V4G(#T^(&%R<F%Y*#$W
M-2P@,C,X+"`R,S@I+`H@("`@)V1A<FMT=7)Q=6]I<V4G(#T^(&%R<F%Y*#`L
M(#(P-BP@,C`Y*2P*("`@("=M961I=6UT=7)Q=6]I<V4G(#T^(&%R<F%Y*#<R
M+"`R,#DL(#(P-"DL"B`@("`G='5R<75O:7-E)R`]/B!A<G)A>2@V-"P@,C(T
M+"`R,#@I+`H@("`@)V-Y86XG(#T^(&%R<F%Y*#`L(#(U-2P@,C4U*2P*("`@
M("=L:6=H=&-Y86XG(#T^(&%R<F%Y*#(R-"P@,C4U+"`R-34I+`H@("`@)V-A
M9&5T8FQU92<@/3X@87)R87DH.34L(#$U."P@,38P*2P*("`@("=M961I=6UA
M<75A;6%R:6YE)R`]/B!A<G)A>2@Q,#(L(#(P-2P@,3<P*2P*("`@("=A<75A
M;6%R:6YE)R`]/B!A<G)A>2@Q,C<L(#(U-2P@,C$R*2P*("`@("=D87)K9W)E
M96XG(#T^(&%R<F%Y*#`L(#$P,"P@,"DL"B`@("`G9&%R:V]L:79E9W)E96XG
M(#T^(&%R<F%Y*#@U+"`Q,#<L(#0W*2P*("`@("=D87)K<V5A9W)E96XG(#T^
M(&%R<F%Y*#$T,RP@,3@X+"`Q-#,I+`H@("`@)W-E86=R965N)R`]/B!A<G)A
M>2@T-BP@,3,Y+"`X-RDL"B`@("`G;65D:75M<V5A9W)E96XG(#T^(&%R<F%Y
M*#8P+"`Q-SDL(#$Q,RDL"B`@("`G;&EG:'1S96%G<F5E;B<@/3X@87)R87DH
M,S(L(#$W."P@,3<P*2P*("`@("=P86QE9W)E96XG(#T^(&%R<F%Y*#$U,BP@
M,C4Q+"`Q-3(I+`H@("`@)W-P<FEN9V=R965N)R`]/B!A<G)A>2@P+"`R-34L
M(#$R-RDL"B`@("`G;&%W;F=R965N)R`]/B!A<G)A>2@Q,C0L(#(U,BP@,"DL
M"B`@("`G9W)E96XG(#T^(&%R<F%Y*#`L(#(U-2P@,"DL"B`@("`G8VAA<G1R
M975S92<@/3X@87)R87DH,3(W+"`R-34L(#`I+`H@("`@)VUE9&EU;7-P<FEN
M9V=R965N)R`]/B!A<G)A>2@P+"`R-3`L(#$U-"DL"B`@("`G9W)E96YY96QL
M;W<G(#T^(&%R<F%Y*#$W,RP@,C4U+"`T-RDL"B`@("`G;&EM96=R965N)R`]
M/B!A<G)A>2@U,"P@,C`U+"`U,"DL"B`@("`G>65L;&]W9W)E96XG(#T^(&%R
M<F%Y*#$U-"P@,C`U+"`U,"DL"B`@("`G9F]R97-T9W)E96XG(#T^(&%R<F%Y
M*#,T+"`Q,SDL(#,T*2P*("`@("=O;&EV961R86(G(#T^(&%R<F%Y*#$P-RP@
M,30R+"`S-2DL"B`@("`G9&%R:VMH86MI)R`]/B!A<G)A>2@Q.#DL(#$X,RP@
M,3`W*2P*("`@("=K:&%K:2<@/3X@87)R87DH,C0P+"`R,S`L(#$T,"DL"B`@
M("`G<&%L96=O;&1E;G)O9"<@/3X@87)R87DH,C,X+"`R,S(L(#$W,"DL"B`@
M("`G;&EG:'1G;VQD96YR;V1Y96QL;W<G(#T^(&%R<F%Y*#(U,"P@,C4P+"`R
M,3`I+`H@("`@)VQI9VAT>65L;&]W)R`]/B!A<G)A>2@R-34L(#(U-2P@,C`P
M*2P*("`@("=Y96QL;W<G(#T^(&%R<F%Y*#(U-2P@,C4U+"`P*2P*("`@("=G
M;VQD)R`]/B!A<G)A>2@R-34L(#(Q-2P@,"DL"B`@("`G;&EG:'1G;VQD96YR
M;V0G(#T^(&%R<F%Y*#(S."P@,C(Q+"`Q,S`I+`H@("`@)V=O;&1E;G)O9"<@
M/3X@87)R87DH,C$X+"`Q-C4L(#,R*2P*("`@("=D87)K9V]L9&5N<F]D)R`]
M/B!A<G)A>2@Q.#0L(#$S-"P@,3$I+`H@("`@)W)O<WEB<F]W;B<@/3X@87)R
M87DH,3@X+"`Q-#,L(#$T,RDL"B`@("`G:6YD:6%N<F5D)R`]/B!A<G)A>2@R
M,#4L(#DR+"`Y,BDL"B`@("`G<V%D9&QE8G)O=VXG(#T^(&%R<F%Y*#$S.2P@
M-CDL(#$Y*2P*("`@("=S:65N;F$G(#T^(&%R<F%Y*#$V,"P@.#(L(#0U*2P*
M("`@("=P97)U)R`]/B!A<G)A>2@R,#4L(#$S,RP@-C,I+`H@("`@)V)U<FQY
M=V]O9"<@/3X@87)R87DH,C(R+"`Q.#0L(#$S-2DL"B`@("`G8F5I9V4G(#T^
M(&%R<F%Y*#(T-2P@,C0U+"`R,C`I+`H@("`@)W=H96%T)R`]/B!A<G)A>2@R
M-#4L(#(R,BP@,3<Y*2P*("`@("=S86YD>6)R;W=N)R`]/B!A<G)A>2@R-#0L
M(#$V-"P@.38I+`H@("`@)W1A;B<@/3X@87)R87DH,C$P+"`Q.#`L(#$T,"DL
M"B`@("`G8VAO8V]L871E)R`]/B!A<G)A>2@R,3`L(#$P-2P@,S`I+`H@("`@
M)V9I<F5B<FEC:R<@/3X@87)R87DH,3<X+"`S-"P@,S0I+`H@("`@)V)R;W=N
M)R`]/B!A<G)A>2@Q-C4L(#0R+"`T,BDL"B`@("`G9&%R:W-A;&UO;B<@/3X@
M87)R87DH,C,S+"`Q-3`L(#$R,BDL"B`@("`G<V%L;6]N)R`]/B!A<G)A>2@R
M-3`L(#$R."P@,3$T*2P*("`@("=L:6=H='-A;&UO;B<@/3X@87)R87DH,C4U
M+"`Q-C`L(#$R,BDL"B`@("`G;W)A;F=E)R`]/B!A<G)A>2@R-34L(#$V-2P@
M,"DL"B`@("`G9&%R:V]R86YG92<@/3X@87)R87DH,C4U+"`Q-#`L(#`I+`H@
M("`@)V-O<F%L)R`]/B!A<G)A>2@R-34L(#$R-RP@.#`I+`H@("`@)VQI9VAT
M8V]R86PG(#T^(&%R<F%Y*#(T,"P@,3(X+"`Q,C@I+`H@("`@)W1O;6%T;R<@
M/3X@87)R87DH,C4U+"`Y.2P@-S$I+`H@("`@)V]R86YG97)E9"<@/3X@87)R
M87DH,C4U+"`V.2P@,"DL"B`@("`G<F5D)R`]/B!A<G)A>2@R-34L(#`L(#`I
M+`H@("`@)VAO='!I;FLG(#T^(&%R<F%Y*#(U-2P@,3`U+"`Q.#`I+`H@("`@
M)V1E97!P:6YK)R`]/B!A<G)A>2@R-34L(#(P+"`Q-#<I+`H@("`@)W!I;FLG
M(#T^(&%R<F%Y*#(U-2P@,3DR+"`R,#,I+`H@("`@)VQI9VAT<&EN:R<@/3X@
M87)R87DH,C4U+"`Q.#(L(#$Y,RDL"B`@("`G<&%L979I;VQE=')E9"<@/3X@
M87)R87DH,C$Y+"`Q,3(L(#$T-RDL"B`@("`G;6%R;V]N)R`]/B!A<G)A>2@Q
M-S8L(#0X+"`Y-BDL"B`@("`G;65D:75M=FEO;&5T<F5D)R`]/B!A<G)A>2@Q
M.3DL(#(Q+"`Q,S,I+`H@("`@)W9I;VQE=')E9"<@/3X@87)R87DH,C`X+"`S
M,BP@,30T*2P*("`@("=M86=E;G1A)R`]/B!A<G)A>2@R-34L(#`L(#(U-2DL
M"B`@("`G=FEO;&5T)R`]/B!A<G)A>2@R,S@L(#$S,"P@,C,X*2P*("`@("=P
M;'5M)R`]/B!A<G)A>2@R,C$L(#$V,"P@,C(Q*2P*("`@("=O<F-H:60G(#T^
M(&%R<F%Y*#(Q."P@,3$R+"`R,30I+`H@("`@)VUE9&EU;6]R8VAI9"<@/3X@
M87)R87DH,3@V+"`X-2P@,C$Q*2P*("`@("=D87)K;W)C:&ED)R`]/B!A<G)A
M>2@Q-3,L(#4P+"`R,#0I+`H@("`@)V1A<FMV:6]L970G(#T^(&%R<F%Y*#$T
M."P@,"P@,C$Q*2P*("`@("=B;'5E=FEO;&5T)R`]/B!A<G)A>2@Q,S@L(#0S
M+"`R,C8I+`H@("`@)W!U<G!L92<@/3X@87)R87DH,38P+"`S,BP@,C0P*2P*
M("`@("=M961I=6UP=7)P;&4G(#T^(&%R<F%Y*#$T-RP@,3$R+"`R,3DI+`H@
M("`@)W1H:7-T;&4G(#T^(&%R<F%Y*#(Q-BP@,3DQ+"`R,38I+`H@("`@)W-N
M;W<Q)R`]/B!A<G)A>2@R-34L(#(U,"P@,C4P*2P*("`@("=S;F]W,B<@/3X@
M87)R87DH,C,X+"`R,S,L(#(S,RDL"B`@("`G<VYO=S,G(#T^(&%R<F%Y*#(P
M-2P@,C`Q+"`R,#$I+`H@("`@)W-N;W<T)R`]/B!A<G)A>2@Q,SDL(#$S-RP@
M,3,W*2P*("`@("=S96%S:&5L;#$G(#T^(&%R<F%Y*#(U-2P@,C0U+"`R,S@I
M+`H@("`@)W-E87-H96QL,B<@/3X@87)R87DH,C,X+"`R,CDL(#(R,BDL"B`@
M("`G<V5A<VAE;&PS)R`]/B!A<G)A>2@R,#4L(#$Y-RP@,3DQ*2P*("`@("=S
M96%S:&5L;#0G(#T^(&%R<F%Y*#$S.2P@,3,T+"`Q,S`I+`H@("`@)T%N=&EQ
M=657:&ET93$G(#T^(&%R<F%Y*#(U-2P@,C,Y+"`R,3DI+`H@("`@)T%N=&EQ
M=657:&ET93(G(#T^(&%R<F%Y*#(S."P@,C(S+"`R,#0I+`H@("`@)T%N=&EQ
M=657:&ET93,G(#T^(&%R<F%Y*#(P-2P@,3DR+"`Q-S8I+`H@("`@)T%N=&EQ
M=657:&ET930G(#T^(&%R<F%Y*#$S.2P@,3,Q+"`Q,C`I+`H@("`@)V)I<W%U
M93$G(#T^(&%R<F%Y*#(U-2P@,C(X+"`Q.38I+`H@("`@)V)I<W%U93(G(#T^
M(&%R<F%Y*#(S."P@,C$S+"`Q.#,I+`H@("`@)V)I<W%U93,G(#T^(&%R<F%Y
M*#(P-2P@,3@S+"`Q-3@I+`H@("`@)V)I<W%U930G(#T^(&%R<F%Y*#$S.2P@
M,3(U+"`Q,#<I+`H@("`@)W!E86-H4'5F9C$G(#T^(&%R<F%Y*#(U-2P@,C$X
M+"`Q.#4I+`H@("`@)W!E86-H<'5F9C(G(#T^(&%R<F%Y*#(S."P@,C`S+"`Q
M-S,I+`H@("`@)W!E86-H<'5F9C,G(#T^(&%R<F%Y*#(P-2P@,3<U+"`Q-#DI
M+`H@("`@)W!E86-H<'5F9C0G(#T^(&%R<F%Y*#$S.2P@,3$Y+"`Q,#$I+`H@
M("`@)VYA=F%J;W=H:71E,2<@/3X@87)R87DH,C4U+"`R,C(L(#$W,RDL"B`@
M("`G;F%V86IO=VAI=&4R)R`]/B!A<G)A>2@R,S@L(#(P-RP@,38Q*2P*("`@
M("=N879A:F]W:&ET93,G(#T^(&%R<F%Y*#(P-2P@,3<Y+"`Q,SDI+`H@("`@
M)VYA=F%J;W=H:71E-"<@/3X@87)R87DH,3,Y+"`Q,C$L(#DT*2P*("`@("=L
M96UO;F-H:69F;VXQ)R`]/B!A<G)A>2@R-34L(#(U,"P@,C`U*2P*("`@("=L
M96UO;F-H:69F;VXR)R`]/B!A<G)A>2@R,S@L(#(S,RP@,3DQ*2P*("`@("=L
M96UO;F-H:69F;VXS)R`]/B!A<G)A>2@R,#4L(#(P,2P@,38U*2P*("`@("=L
M96UO;F-H:69F;VXT)R`]/B!A<G)A>2@Q,SDL(#$S-RP@,3$R*2P*("`@("=I
M=F]R>3$G(#T^(&%R<F%Y*#(U-2P@,C4U+"`R-#`I+`H@("`@)VEV;W)Y,B<@
M/3X@87)R87DH,C,X+"`R,S@L(#(R-"DL"B`@("`G:79O<GDS)R`]/B!A<G)A
M>2@R,#4L(#(P-2P@,3DS*2P*("`@("=I=F]R>30G(#T^(&%R<F%Y*#$S.2P@
M,3,Y+"`Q,S$I+`H@("`@)VAO;F5Y9&5W)R`]/B!A<G)A>2@Q.3,L(#(P-2P@
M,3DS*2P*("`@("=L879E;F1E<F)L=7-H,2<@/3X@87)R87DH,C4U+"`R-#`L
M(#(T-2DL"B`@("`G;&%V96YD97)B;'5S:#(G(#T^(&%R<F%Y*#(S."P@,C(T
M+"`R,CDI+`H@("`@)VQA=F5N9&5R8FQU<V@S)R`]/B!A<G)A>2@R,#4L(#$Y
M,RP@,3DW*2P*("`@("=L879E;F1E<F)L=7-H-"<@/3X@87)R87DH,3,Y+"`Q
M,S$L(#$S-"DL"B`@("`G;6ES='ER;W-E,2<@/3X@87)R87DH,C4U+"`R,C@L
M(#(R-2DL"B`@("`G;6ES='ER;W-E,B<@/3X@87)R87DH,C,X+"`R,3,L(#(Q
M,"DL"B`@("`G;6ES='ER;W-E,R<@/3X@87)R87DH,C`U+"`Q.#,L(#$X,2DL
M"B`@("`G;6ES='ER;W-E-"<@/3X@87)R87DH,3,Y+"`Q,C4L(#$R,RDL"B`@
M("`G87IU<F4Q)R`]/B!A<G)A>2@R-#`L(#(U-2P@,C4U*2P*("`@("=A>G5R
M93(G(#T^(&%R<F%Y*#(R-"P@,C,X+"`R,S@I+`H@("`@)V%Z=7)E,R<@/3X@
M87)R87DH,3DS+"`R,#4L(#(P-2DL"B`@("`G87IU<F4T)R`]/B!A<G)A>2@Q
M,S$L(#$S.2P@,3,Y*2P*("`@("=S;&%T96)L=64Q)R`]/B!A<G)A>2@Q,S$L
M(#$Q,2P@,C4U*2P*("`@("=S;&%T96)L=64R)R`]/B!A<G)A>2@Q,C(L(#$P
M,RP@,C,X*2P*("`@("=S;&%T96)L=64S)R`]/B!A<G)A>2@Q,#4L(#@Y+"`R
M,#4I+`H@("`@)W-L871E8FQU930G(#T^(&%R<F%Y*#<Q+"`V,"P@,3,Y*2P*
M("`@("=R;WEA;&)L=64Q)R`]/B!A<G)A>2@W,BP@,3$X+"`R-34I+`H@("`@
M)W)O>6%L8FQU93(G(#T^(&%R<F%Y*#8W+"`Q,3`L(#(S."DL"B`@("`G<F]Y
M86QB;'5E,R<@/3X@87)R87DH-3@L(#DU+"`R,#4I+`H@("`@)W)O>6%L8FQU
M930G(#T^(&%R<F%Y*#,Y+"`V-"P@,3,Y*2P*("`@("=D;V1G97)B;'5E,2<@
M/3X@87)R87DH,S`L(#$T-"P@,C4U*2P*("`@("=D;V1G97)B;'5E,B<@/3X@
M87)R87DH,C@L(#$S-"P@,C,X*2P*("`@("=D;V1G97)B;'5E,R<@/3X@87)R
M87DH,C0L(#$Q-BP@,C`U*2P*("`@("=D;V1G97)B;'5E-"<@/3X@87)R87DH
M,38L(#<X+"`Q,SDI+`H@("`@)W-T965L8FQU93$G(#T^(&%R<F%Y*#DY+"`Q
M.#0L(#(U-2DL"B`@("`G<W1E96QB;'5E,B<@/3X@87)R87DH.3(L(#$W,BP@
M,C,X*2P*("`@("=S=&5E;&)L=64S)R`]/B!A<G)A>2@W.2P@,30X+"`R,#4I
M+`H@("`@)W-T965L8FQU930G(#T^(&%R<F%Y*#4T+"`Q,#`L(#$S.2DL"B`@
M("`G9&5E<'-K>6)L=64Q)R`]/B!A<G)A>2@P+"`Q.3$L(#(U-2DL"B`@("`G
M9&5E<'-K>6)L=64R)R`]/B!A<G)A>2@P+"`Q-S@L(#(S."DL"B`@("`G9&5E
M<'-K>6)L=64S)R`]/B!A<G)A>2@P+"`Q-30L(#(P-2DL"B`@("`G9&5E<'-K
M>6)L=64T)R`]/B!A<G)A>2@P+"`Q,#0L(#$S.2DL"B`@("`G<VMY8FQU93$G
M(#T^(&%R<F%Y*#$S-2P@,C`V+"`R-34I+`H@("`@)W-K>6)L=64R)R`]/B!A
M<G)A>2@Q,C8L(#$Y,BP@,C,X*2P*("`@("=S:WEB;'5E,R<@/3X@87)R87DH
M,3`X+"`Q-C8L(#(P-2DL"B`@("`G<VMY8FQU930G(#T^(&%R<F%Y*#<T+"`Q
M,3(L(#$S.2DL"B`@("`G;&EG:'1S:WEB;'5E,2<@/3X@87)R87DH,3<V+"`R
M,C8L(#(U-2DL"B`@("`G;&EG:'1S:WEB;'5E,B<@/3X@87)R87DH,38T+"`R
M,3$L(#(S."DL"B`@("`G;&EG:'1S:WEB;'5E,R<@/3X@87)R87DH,30Q+"`Q
M.#(L(#(P-2DL"B`@("`G;&EG:'1S:WEB;'5E-"<@/3X@87)R87DH.38L(#$R
M,RP@,3,Y*2P*("`@("=S;&%T96=R87DQ)R`]/B!A<G)A>2@Q.3@L(#(R-BP@
M,C4U*2P*("`@("=S;&%T96=R87DR)R`]/B!A<G)A>2@Q.#4L(#(Q,2P@,C,X
M*2P*("`@("=S;&%T96=R87DS)R`]/B!A<G)A>2@Q-3DL(#$X,BP@,C`U*2P*
M("`@("=S;&%T96=R87DT)R`]/B!A<G)A>2@Q,#@L(#$R,RP@,3,Y*2P*("`@
M("=L:6=H='-T965L8FQU93$G(#T^(&%R<F%Y*#(P,BP@,C(U+"`R-34I+`H@
M("`@)VQI9VAT<W1E96QB;'5E,B<@/3X@87)R87DH,3@X+"`R,3`L(#(S."DL
M"B`@("`G;&EG:'1S=&5E;&)L=64S)R`]/B!A<G)A>2@Q-C(L(#$X,2P@,C`U
M*2P*("`@("=L:6=H='-T965L8FQU930G(#T^(&%R<F%Y*#$Q,"P@,3(S+"`Q
M,SDI+`H@("`@)VQI9VAT8FQU93$G(#T^(&%R<F%Y*#$Y,2P@,C,Y+"`R-34I
M+`H@("`@)VQI9VAT8FQU93(G(#T^(&%R<F%Y*#$W."P@,C(S+"`R,S@I+`H@
M("`@)VQI9VAT8FQU93,G(#T^(&%R<F%Y*#$U-"P@,3DR+"`R,#4I+`H@("`@
M)VQI9VAT8FQU930G(#T^(&%R<F%Y*#$P-"P@,3,Q+"`Q,SDI+`H@("`@)VQI
M9VAT8WEA;C$G(#T^(&%R<F%Y*#(R-"P@,C4U+"`R-34I+`H@("`@)VQI9VAT
M8WEA;C(G(#T^(&%R<F%Y*#(P.2P@,C,X+"`R,S@I+`H@("`@)VQI9VAT8WEA
M;C,G(#T^(&%R<F%Y*#$X,"P@,C`U+"`R,#4I+`H@("`@)VQI9VAT8WEA;C0G
M(#T^(&%R<F%Y*#$R,BP@,3,Y+"`Q,SDI+`H@("`@)W!A;&5T=7)Q=6]I<V4Q
M)R`]/B!A<G)A>2@Q.#<L(#(U-2P@,C4U*2P*("`@("=P86QE='5R<75O:7-E
M,B<@/3X@87)R87DH,3<T+"`R,S@L(#(S."DL"B`@("`G<&%L971U<G%U;VES
M93,G(#T^(&%R<F%Y*#$U,"P@,C`U+"`R,#4I+`H@("`@)W!A;&5T=7)Q=6]I
M<V4T)R`]/B!A<G)A>2@Q,#(L(#$S.2P@,3,Y*2P*("`@("=C861E=&)L=64Q
M)R`]/B!A<G)A>2@Q-3(L(#(T-2P@,C4U*2P*("`@("=C861E=&)L=64R)R`]
M/B!A<G)A>2@Q-#(L(#(R.2P@,C,X*2P*("`@("=C861E=&)L=64S)R`]/B!A
M<G)A>2@Q,C(L(#$Y-RP@,C`U*2P*("`@("=C861E=&)L=64T)R`]/B!A<G)A
M>2@X,RP@,3,T+"`Q,SDI+`H@("`@)W1U<G%U;VES93$G(#T^(&%R<F%Y*#`L
M(#(T-2P@,C4U*2P*("`@("=T=7)Q=6]I<V4R)R`]/B!A<G)A>2@P+"`R,CDL
M(#(S."DL"B`@("`G='5R<75O:7-E,R<@/3X@87)R87DH,"P@,3DW+"`R,#4I
M+`H@("`@)W1U<G%U;VES930G(#T^(&%R<F%Y*#`L(#$S-"P@,3,Y*2P*("`@
M("=C>6%N,2<@/3X@87)R87DH,"P@,C4U+"`R-34I+`H@("`@)V-Y86XR)R`]
M/B!A<G)A>2@P+"`R,S@L(#(S."DL"B`@("`G8WEA;C,G(#T^(&%R<F%Y*#`L
M(#(P-2P@,C`U*2P*("`@("=C>6%N-"<@/3X@87)R87DH,"P@,3,Y+"`Q,SDI
M+`H@("`@)V1A<FMS;&%T96=R87DQ)R`]/B!A<G)A>2@Q-3$L(#(U-2P@,C4U
M*2P*("`@("=D87)K<VQA=&5G<F%Y,B<@/3X@87)R87DH,30Q+"`R,S@L(#(S
M."DL"B`@("`G9&%R:W-L871E9W)A>3,G(#T^(&%R<F%Y*#$R,2P@,C`U+"`R
M,#4I+`H@("`@)V1A<FMS;&%T96=R87DT)R`]/B!A<G)A>2@X,BP@,3,Y+"`Q
M,SDI+`H@("`@)V%Q=6%M87)I;F4Q)R`]/B!A<G)A>2@Q,C<L(#(U-2P@,C$R
M*2P*("`@("=A<75A;6%R:6YE,B<@/3X@87)R87DH,3$X+"`R,S@L(#$Y."DL
M"B`@("`G87%U86UA<FEN93,G(#T^(&%R<F%Y*#$P,BP@,C`U+"`Q-S`I+`H@
M("`@)V%Q=6%M87)I;F4T)R`]/B!A<G)A>2@V.2P@,3,Y+"`Q,38I+`H@("`@
M)V1A<FMS96%G<F5E;C$G(#T^(&%R<F%Y*#$Y,RP@,C4U+"`Q.3,I+`H@("`@
M)V1A<FMS96%G<F5E;C(G(#T^(&%R<F%Y*#$X,"P@,C,X+"`Q.#`I+`H@("`@
M)V1A<FMS96%G<F5E;C,G(#T^(&%R<F%Y*#$U-2P@,C`U+"`Q-34I+`H@("`@
M)V1A<FMS96%G<F5E;C0G(#T^(&%R<F%Y*#$P-2P@,3,Y+"`Q,#4I+`H@("`@
M)W-E86=R965N,2<@/3X@87)R87DH.#0L(#(U-2P@,34Y*2P*("`@("=S96%G
M<F5E;C(G(#T^(&%R<F%Y*#<X+"`R,S@L(#$T."DL"B`@("`G<V5A9W)E96XS
M)R`]/B!A<G)A>2@V-RP@,C`U+"`Q,C@I+`H@("`@)W-E86=R965N-"<@/3X@
M87)R87DH-#8L(#$S.2P@.#<I+`H@("`@)W!A;&5G<F5E;C$G(#T^(&%R<F%Y
M*#$U-"P@,C4U+"`Q-30I+`H@("`@)W!A;&5G<F5E;C(G(#T^(&%R<F%Y*#$T
M-"P@,C,X+"`Q-#0I+`H@("`@)W!A;&5G<F5E;C,G(#T^(&%R<F%Y*#$R-"P@
M,C`U+"`Q,C0I+`H@("`@)W!A;&5G<F5E;C0G(#T^(&%R<F%Y*#@T+"`Q,SDL
M(#@T*2P*("`@("=S<')I;F=G<F5E;C$G(#T^(&%R<F%Y*#`L(#(U-2P@,3(W
M*2P*("`@("=S<')I;F=G<F5E;C(G(#T^(&%R<F%Y*#`L(#(S."P@,3$X*2P*
M("`@("=S<')I;F=G<F5E;C,G(#T^(&%R<F%Y*#`L(#(P-2P@,3`R*2P*("`@
M("=S<')I;F=G<F5E;C0G(#T^(&%R<F%Y*#`L(#$S.2P@-CDI+`H@("`@)V-H
M87)T<F5U<V4Q)R`]/B!A<G)A>2@Q,C<L(#(U-2P@,"DL"B`@("`G8VAA<G1R
M975S93(G(#T^(&%R<F%Y*#$Q."P@,C,X+"`P*2P*("`@("=C:&%R=')E=7-E
M,R<@/3X@87)R87DH,3`R+"`R,#4L(#`I+`H@("`@)V-H87)T<F5U<V4T)R`]
M/B!A<G)A>2@V.2P@,3,Y+"`P*2P*("`@("=O;&EV961R86(Q)R`]/B!A<G)A
M>2@Q.3(L(#(U-2P@-C(I+`H@("`@)V]L:79E9')A8C(G(#T^(&%R<F%Y*#$W
M.2P@,C,X+"`U."DL"B`@("`G;VQI=F5D<F%B,R<@/3X@87)R87DH,34T+"`R
M,#4L(#4P*2P*("`@("=O;&EV961R86(T)R`]/B!A<G)A>2@Q,#4L(#$S.2P@
M,S0I+`H@("`@)V1A<FMO;&EV96=R965N,2<@/3X@87)R87DH,C`R+"`R-34L
M(#$Q,BDL"B`@("`G9&%R:V]L:79E9W)E96XR)R`]/B!A<G)A>2@Q.#@L(#(S
M."P@,3`T*2P*("`@("=D87)K;VQI=F5G<F5E;C,G(#T^(&%R<F%Y*#$V,BP@
M,C`U+"`Y,"DL"B`@("`G9&%R:V]L:79E9W)E96XT)R`]/B!A<G)A>2@Q,3`L
M(#$S.2P@-C$I+`H@("`@)VMH86MI,2<@/3X@87)R87DH,C4U+"`R-#8L(#$T
M,RDL"B`@("`G:VAA:VDR)R`]/B!A<G)A>2@R,S@L(#(S,"P@,3,S*2P*("`@
M("=K:&%K:3,G(#T^(&%R<F%Y*#(P-2P@,3DX+"`Q,34I+`H@("`@)VMH86MI
M-"<@/3X@87)R87DH,3,Y+"`Q,S0L(#<X*2P*("`@("=L:6=H=&=O;&1E;G)O
M9#$G(#T^(&%R<F%Y*#(U-2P@,C,V+"`Q,SDI+`H@("`@)VQI9VAT9V]L9&5N
M<F]D,B<@/3X@87)R87DH,C,X+"`R,C`L(#$S,"DL"B`@("`G;&EG:'1G;VQD
M96YR;V0S)R`]/B!A<G)A>2@R,#4L(#$Y,"P@,3$R*2P*("`@("=L:6=H=&=O
M;&1E;G)O9#0G(#T^(&%R<F%Y*#$S.2P@,3(Y+"`W-BDL"B`@("`G>65L;&]W
M,2<@/3X@87)R87DH,C4U+"`R-34L(#`I+`H@("`@)WEE;&QO=S(G(#T^(&%R
M<F%Y*#(S."P@,C,X+"`P*2P*("`@("=Y96QL;W<S)R`]/B!A<G)A>2@R,#4L
M(#(P-2P@,"DL"B`@("`G>65L;&]W-"<@/3X@87)R87DH,3,Y+"`Q,SDL(#`I
M+`H@("`@)V=O;&0Q)R`]/B!A<G)A>2@R-34L(#(Q-2P@,"DL"B`@("`G9V]L
M9#(G(#T^(&%R<F%Y*#(S."P@,C`Q+"`P*2P*("`@("=G;VQD,R<@/3X@87)R
M87DH,C`U+"`Q-S,L(#`I+`H@("`@)V=O;&0T)R`]/B!A<G)A>2@Q,SDL(#$Q
M-RP@,"DL"B`@("`G9V]L9&5N<F]D,2<@/3X@87)R87DH,C4U+"`Q.3,L(#,W
M*2P*("`@("=G;VQD96YR;V0R)R`]/B!A<G)A>2@R,S@L(#$X,"P@,S0I+`H@
M("`@)V=O;&1E;G)O9#,G(#T^(&%R<F%Y*#(P-2P@,34U+"`R.2DL"B`@("`G
M9V]L9&5N<F]D-"<@/3X@87)R87DH,3,Y+"`Q,#4L(#(P*2P*("`@("=D87)K
M9V]L9&5N<F]D,2<@/3X@87)R87DH,C4U+"`Q.#4L(#$U*2P*("`@("=D87)K
M9V]L9&5N<F]D,B<@/3X@87)R87DH,C,X+"`Q-S,L(#$T*2P*("`@("=D87)K
M9V]L9&5N<F]D,R<@/3X@87)R87DH,C`U+"`Q-#DL(#$R*2P*("`@("=D87)K
M9V]L9&5N<F]D-"<@/3X@87)R87DH,3,Y+"`Q,#$L(#@I+`H@("`@)W)O<WEB
M<F]W;C$G(#T^(&%R<F%Y*#(U-2P@,3DS+"`Q.3,I+`H@("`@)W)O<WEB<F]W
M;C(G(#T^(&%R<F%Y*#(S."P@,3@P+"`Q.#`I+`H@("`@)W)O<WEB<F]W;C,G
M(#T^(&%R<F%Y*#(P-2P@,34U+"`Q-34I+`H@("`@)W)O<WEB<F]W;C0G(#T^
M(&%R<F%Y*#$S.2P@,3`U+"`Q,#4I+`H@("`@)VEN9&EA;G)E9#$G(#T^(&%R
M<F%Y*#(U-2P@,3`V+"`Q,#8I+`H@("`@)VEN9&EA;G)E9#(G(#T^(&%R<F%Y
M*#(S."P@.3DL(#DY*2P*("`@("=I;F1I86YR960S)R`]/B!A<G)A>2@R,#4L
M(#@U+"`X-2DL"B`@("`G:6YD:6%N<F5D-"<@/3X@87)R87DH,3,Y+"`U."P@
M-3@I+`H@("`@)W-I96YN83$G(#T^(&%R<F%Y*#(U-2P@,3,P+"`W,2DL"B`@
M("`G<VEE;FYA,B<@/3X@87)R87DH,C,X+"`Q,C$L(#8V*2P*("`@("=S:65N
M;F$S)R`]/B!A<G)A>2@R,#4L(#$P-"P@-3<I+`H@("`@)W-I96YN830G(#T^
M(&%R<F%Y*#$S.2P@-S$L(#,X*2P*("`@("=B=7)L>7=O;V0Q)R`]/B!A<G)A
M>2@R-34L(#(Q,2P@,34U*2P*("`@("=B=7)L>7=O;V0R)R`]/B!A<G)A>2@R
M,S@L(#$Y-RP@,30U*2P*("`@("=B=7)L>7=O;V0S)R`]/B!A<G)A>2@R,#4L
M(#$W,"P@,3(U*2P*("`@("=B=7)L>7=O;V0T)R`]/B!A<G)A>2@Q,SDL(#$Q
M-2P@.#4I+`H@("`@)W=H96%T,2<@/3X@87)R87DH,C4U+"`R,S$L(#$X-BDL
M"B`@("`G=VAE870R)R`]/B!A<G)A>2@R,S@L(#(Q-BP@,3<T*2P*("`@("=W
M:&5A=#,G(#T^(&%R<F%Y*#(P-2P@,3@V+"`Q-3`I+`H@("`@)W=H96%T-"<@
M/3X@87)R87DH,3,Y+"`Q,C8L(#$P,BDL"B`@("`G=&%N,2<@/3X@87)R87DH
M,C4U+"`Q-C4L(#<Y*2P*("`@("=T86XR)R`]/B!A<G)A>2@R,S@L(#$U-"P@
M-S,I+`H@("`@)W1A;C,G(#T^(&%R<F%Y*#(P-2P@,3,S+"`V,RDL"B`@("`G
M=&%N-"<@/3X@87)R87DH,3,Y+"`Y,"P@-#,I+`H@("`@)V-H;V-O;&%T93$G
M(#T^(&%R<F%Y*#(U-2P@,3(W+"`S-BDL"B`@("`G8VAO8V]L871E,B<@/3X@
M87)R87DH,C,X+"`Q,3@L(#,S*2P*("`@("=C:&]C;VQA=&4S)R`]/B!A<G)A
M>2@R,#4L(#$P,BP@,CDI+`H@("`@)V-H;V-O;&%T930G(#T^(&%R<F%Y*#$S
M.2P@-CDL(#$Y*2P*("`@("=F:7)E8G)I8VLQ)R`]/B!A<G)A>2@R-34L(#0X
M+"`T."DL"B`@("`G9FER96)R:6-K,B<@/3X@87)R87DH,C,X+"`T-"P@-#0I
M+`H@("`@)V9I<F5B<FEC:S,G(#T^(&%R<F%Y*#(P-2P@,S@L(#,X*2P*("`@
M("=F:7)E8G)I8VLT)R`]/B!A<G)A>2@Q,SDL(#(V+"`R-BDL"B`@("`G8G)O
M=VXQ)R`]/B!A<G)A>2@R-34L(#8T+"`V-"DL"B`@("`G8G)O=VXR)R`]/B!A
M<G)A>2@R,S@L(#4Y+"`U.2DL"B`@("`G8G)O=VXS)R`]/B!A<G)A>2@R,#4L
M(#4Q+"`U,2DL"B`@("`G8G)O=VXT)R`]/B!A<G)A>2@Q,SDL(#,U+"`S-2DL
M"B`@("`G<V%L;6]N,2<@/3X@87)R87DH,C4U+"`Q-#`L(#$P-2DL"B`@("`G
M<V%L;6]N,B<@/3X@87)R87DH,C,X+"`Q,S`L(#DX*2P*("`@("=S86QM;VXS
M)R`]/B!A<G)A>2@R,#4L(#$Q,BP@.#0I+`H@("`@)W-A;&UO;C0G(#T^(&%R
M<F%Y*#$S.2P@-S8L(#4W*2P*("`@("=L:6=H='-A;&UO;C$G(#T^(&%R<F%Y
M*#(U-2P@,38P+"`Q,C(I+`H@("`@)VQI9VAT<V%L;6]N,B<@/3X@87)R87DH
M,C,X+"`Q-#DL(#$Q-"DL"B`@("`G;&EG:'1S86QM;VXS)R`]/B!A<G)A>2@R
M,#4L(#$R.2P@.3@I+`H@("`@)VQI9VAT<V%L;6]N-"<@/3X@87)R87DH,3,Y
M+"`X-RP@-C8I+`H@("`@)V]R86YG93$G(#T^(&%R<F%Y*#(U-2P@,38U+"`P
M*2P*("`@("=O<F%N9V4R)R`]/B!A<G)A>2@R,S@L(#$U-"P@,"DL"B`@("`G
M;W)A;F=E,R<@/3X@87)R87DH,C`U+"`Q,S,L(#`I+`H@("`@)V]R86YG930G
M(#T^(&%R<F%Y*#$S.2P@.3`L(#`I+`H@("`@)V1A<FMO<F%N9V4Q)R`]/B!A
M<G)A>2@R-34L(#$R-RP@,"DL"B`@("`G9&%R:V]R86YG93(G(#T^(&%R<F%Y
M*#(S."P@,3$X+"`P*2P*("`@("=D87)K;W)A;F=E,R<@/3X@87)R87DH,C`U
M+"`Q,#(L(#`I+`H@("`@)V1A<FMO<F%N9V4T)R`]/B!A<G)A>2@Q,SDL(#8Y
M+"`P*2P*("`@("=C;W)A;#$G(#T^(&%R<F%Y*#(U-2P@,3$T+"`X-BDL"B`@
M("`G8V]R86PR)R`]/B!A<G)A>2@R,S@L(#$P-BP@.#`I+`H@("`@)V-O<F%L
M,R<@/3X@87)R87DH,C`U+"`Y,2P@-CDI+`H@("`@)V-O<F%L-"<@/3X@87)R
M87DH,3,Y+"`V,BP@-#<I+`H@("`@)W1O;6%T;S$G(#T^(&%R<F%Y*#(U-2P@
M.3DL(#<Q*2P*("`@("=T;VUA=&\R)R`]/B!A<G)A>2@R,S@L(#DR+"`V-BDL
M"B`@("`G=&]M871O,R<@/3X@87)R87DH,C`U+"`W.2P@-3<I+`H@("`@)W1O
M;6%T;S0G(#T^(&%R<F%Y*#$S.2P@-30L(#,X*2P*("`@("=O<F%N9V5R960Q
M)R`]/B!A<G)A>2@R-34L(#8Y+"`P*2P*("`@("=O<F%N9V5R960R)R`]/B!A
M<G)A>2@R,S@L(#8T+"`P*2P*("`@("=O<F%N9V5R960S)R`]/B!A<G)A>2@R
M,#4L(#4U+"`P*2P*("`@("=O<F%N9V5R960T)R`]/B!A<G)A>2@Q,SDL(#,W
M+"`P*2P*("`@("=D965P<&EN:S$G(#T^(&%R<F%Y*#(U-2P@,C`L(#$T-RDL
M"B`@("`G9&5E<'!I;FLR)R`]/B!A<G)A>2@R,S@L(#$X+"`Q,S<I+`H@("`@
M)V1E97!P:6YK,R<@/3X@87)R87DH,C`U+"`Q-BP@,3$X*2P*("`@("=D965P
M<&EN:S0G(#T^(&%R<F%Y*#$S.2P@,3`L(#@P*2P*("`@("=H;W1P:6YK,2<@
M/3X@87)R87DH,C4U+"`Q,3`L(#$X,"DL"B`@("`G:&]T<&EN:S(G(#T^(&%R
M<F%Y*#(S."P@,3`V+"`Q-C<I+`H@("`@)VAO='!I;FLS)R`]/B!A<G)A>2@R
M,#4L(#DV+"`Q-#0I+`H@("`@)VAO='!I;FLT)R`]/B!A<G)A>2@Q,SDL(#4X
M+"`Y."DL"B`@("`G<&EN:S$G(#T^(&%R<F%Y*#(U-2P@,3@Q+"`Q.3<I+`H@
M("`@)W!I;FLR)R`]/B!A<G)A>2@R,S@L(#$V.2P@,3@T*2P*("`@("=P:6YK
M,R<@/3X@87)R87DH,C`U+"`Q-#4L(#$U."DL"B`@("`G<&EN:S0G(#T^(&%R
M<F%Y*#$S.2P@.3DL(#$P."DL"B`@("`G;&EG:'1P:6YK,2<@/3X@87)R87DH
M,C4U+"`Q-S0L(#$X-2DL"B`@("`G;&EG:'1P:6YK,B<@/3X@87)R87DH,C,X
M+"`Q-C(L(#$W,RDL"B`@("`G;&EG:'1P:6YK,R<@/3X@87)R87DH,C`U+"`Q
M-#`L(#$T.2DL"B`@("`G;&EG:'1P:6YK-"<@/3X@87)R87DH,3,Y+"`Y-2P@
M,3`Q*2P*("`@("=P86QE=FEO;&5T<F5D,2<@/3X@87)R87DH,C4U+"`Q,S`L
M(#$W,2DL"B`@("`G<&%L979I;VQE=')E9#(G(#T^(&%R<F%Y*#(S."P@,3(Q
M+"`Q-3DI+`H@("`@)W!A;&5V:6]L971R960S)R`]/B!A<G)A>2@R,#4L(#$P
M-"P@,3,W*2P*("`@("=P86QE=FEO;&5T<F5D-"<@/3X@87)R87DH,3,Y+"`W
M,2P@.3,I+`H@("`@)VUA<F]O;C$G(#T^(&%R<F%Y*#(U-2P@-3(L(#$W.2DL
M"B`@("`G;6%R;V]N,B<@/3X@87)R87DH,C,X+"`T."P@,38W*2P*("`@("=M
M87)O;VXS)R`]/B!A<G)A>2@R,#4L(#0Q+"`Q-#0I+`H@("`@)VUA<F]O;C0G
M(#T^(&%R<F%Y*#$S.2P@,C@L(#DX*2P*("`@("=V:6]L971R960Q)R`]/B!A
M<G)A>2@R-34L(#8R+"`Q-3`I+`H@("`@)W9I;VQE=')E9#(G(#T^(&%R<F%Y
M*#(S."P@-3@L(#$T,"DL"B`@("`G=FEO;&5T<F5D,R<@/3X@87)R87DH,C`U
M+"`U,"P@,3(P*2P*("`@("=V:6]L971R960T)R`]/B!A<G)A>2@Q,SDL(#,T
M+"`X,BDL"B`@("`G;6%G96YT83$G(#T^(&%R<F%Y*#(U-2P@,"P@,C4U*2P*
M("`@("=M86=E;G1A,B<@/3X@87)R87DH,C,X+"`P+"`R,S@I+`H@("`@)VUA
M9V5N=&$S)R`]/B!A<G)A>2@R,#4L(#`L(#(P-2DL"B`@("`G;6%G96YT830G
M(#T^(&%R<F%Y*#$S.2P@,"P@,3,Y*2P*("`@("=M961I=6UR960G(#T^(&%R
M<F%Y*#$T,"P@,S0L(#,T*2P*("`@("=O<F-H:60Q)R`]/B!A<G)A>2@R-34L
M(#$S,2P@,C4P*2P*("`@("=O<F-H:60R)R`]/B!A<G)A>2@R,S@L(#$R,BP@
M,C,S*2P*("`@("=O<F-H:60S)R`]/B!A<G)A>2@R,#4L(#$P-2P@,C`Q*2P*
M("`@("=O<F-H:60T)R`]/B!A<G)A>2@Q,SDL(#<Q+"`Q,S<I+`H@("`@)W!L
M=6TQ)R`]/B!A<G)A>2@R-34L(#$X-RP@,C4U*2P*("`@("=P;'5M,B<@/3X@
M87)R87DH,C,X+"`Q-S0L(#(S."DL"B`@("`G<&QU;3,G(#T^(&%R<F%Y*#(P
M-2P@,34P+"`R,#4I+`H@("`@)W!L=6TT)R`]/B!A<G)A>2@Q,SDL(#$P,BP@
M,3,Y*2P*("`@("=M961I=6UO<F-H:60Q)R`]/B!A<G)A>2@R,C0L(#$P,BP@
M,C4U*2P*("`@("=M961I=6UO<F-H:60R)R`]/B!A<G)A>2@R,#DL(#DU+"`R
M,S@I+`H@("`@)VUE9&EU;6]R8VAI9#,G(#T^(&%R<F%Y*#$X,"P@.#(L(#(P
M-2DL"B`@("`G;65D:75M;W)C:&ED-"<@/3X@87)R87DH,3(R+"`U-2P@,3,Y
M*2P*("`@("=D87)K;W)C:&ED,2<@/3X@87)R87DH,3DQ+"`V,BP@,C4U*2P*
M("`@("=D87)K;W)C:&ED,B<@/3X@87)R87DH,3<X+"`U."P@,C,X*2P*("`@
M("=D87)K;W)C:&ED,R<@/3X@87)R87DH,34T+"`U,"P@,C`U*2P*("`@("=D
M87)K;W)C:&ED-"<@/3X@87)R87DH,3`T+"`S-"P@,3,Y*2P*("`@("=P=7)P
M;&4Q)R`]/B!A<G)A>2@Q-34L(#0X+"`R-34I+`H@("`@)W!U<G!L93(G(#T^
M(&%R<F%Y*#$T-2P@-#0L(#(S."DL"B`@("`G<'5R<&QE,R<@/3X@87)R87DH
M,3(U+"`S."P@,C`U*2P*("`@("=P=7)P;&4T)R`]/B!A<G)A>2@X-2P@,C8L
M(#$S.2DL"B`@("`G;65D:75M<'5R<&QE,2<@/3X@87)R87DH,3<Q+"`Q,S`L
M(#(U-2DL"B`@("`G;65D:75M<'5R<&QE,B<@/3X@87)R87DH,34Y+"`Q,C$L
M(#(S."DL"B`@("`G;65D:75M<'5R<&QE,R<@/3X@87)R87DH,3,W+"`Q,#0L
M(#(P-2DL"B`@("`G;65D:75M<'5R<&QE-"<@/3X@87)R87DH.3,L(#<Q+"`Q
M,SDI+`H@("`@)W1H:7-T;&4Q)R`]/B!A<G)A>2@R-34L(#(R-2P@,C4U*2P*
M("`@("=T:&ES=&QE,B<@/3X@87)R87DH,C,X+"`R,3`L(#(S."DL"B`@("`G
M=&AI<W1L93,G(#T^(&%R<F%Y*#(P-2P@,3@Q+"`R,#4I+`H@("`@)W1H:7-T
M;&4T)R`]/B!A<G)A>2@Q,SDL(#$R,RP@,3,Y*2P*("`@("=G<F%Y,2<@/3X@
M87)R87DH,3`L(#$P+"`Q,"DL"B`@("`G9W)A>3(G(#T^(&%R<F%Y*#0P+"`T
M,"P@,S`I+`H@("`@)V=R87DS)R`]/B!A<G)A>2@W,"P@-S`L(#<P*2P*("`@
M("=G<F%Y-"<@/3X@87)R87DH,3`P+"`Q,#`L(#$P,"DL"B`@("`G9W)A>34G
M(#T^(&%R<F%Y*#$S,"P@,3,P+"`Q,S`I+`H@("`@)V=R87DV)R`]/B!A<G)A
M>2@Q-C`L(#$V,"P@,38P*2P*("`@("=G<F%Y-R<@/3X@87)R87DH,3DP+"`Q
M.3`L(#$Y,"DL"B`@("`G9W)A>3@G(#T^(&%R<F%Y*#(Q,"P@,C$P+"`R,3`I
M+`H@("`@)V=R87DY)R`]/B!A<G)A>2@R-#`L(#(T,"P@,C0P*2P*("`@("=D
M87)K9W)A>2<@/3X@87)R87DH,3`P+"`Q,#`L(#$P,"DL"B`@("`G9&%R:V)L
M=64G(#T^(&%R<F%Y*#`L(#`L(#$S.2DL"B`@("`G9&%R:V-Y86XG(#T^(&%R
M<F%Y*#`L(#$S.2P@,3,Y*2P*("`@("=D87)K;6%G96YT82<@/3X@87)R87DH
M,3,Y+"`P+"`Q,SDI+`H@("`@)V1A<FMR960G(#T^(&%R<F%Y*#$S.2P@,"P@
M,"DL"B`@("`G<VEL=F5R)R`]/B!A<G)A>2@Q.3(L("`Q.3(L("`Q.3(I+`H@
M("`@)V5G9W!L86YT)R`]/B!A<G)A>2@Q-#0L(#$W-BP@,38X*2P*("`@("=L
M:6=H=&=R965N)R`]/B!A<G)A>2@Q-#0L(#(S."P@,30T*0HI.PH`````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+TEM86=E+W-V9RYP:'``````````````````````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`S,38P,0`Q,#4Q-30S,S<T-@`P,C(P,C(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*"G)E
M<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO26UA9V4N<&AP
M)SL*<F5Q=6ER95]O;F-E("=834PO4U9'+G!H<"<["@HO*BH*("H@5&AI<R!C
M;&%S<R!I;7!L96UE;G1S('1H92!(;W)D95]);6%G93HZ($%022!F;W(@4U9'
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]);6%G92]);6%G92]S=F<N<&AP
M+'8@,2XS,2XQ,"XV(#(P,#8O,#$O,#$@,C$Z,C@Z,C(@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R
M9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TEM86=E"B`J+PIC;&%S<R!(;W)D
M95]);6%G95]S=F<@97AT96YD<R!(;W)D95]);6%G92!["@H@("`@=F%R("1?
M<W9G.PH*("`@("\J*@H@("`@("H@0V%P86)I;&ET97,@;V8@=&AI<R!D<FEV
M97(N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)%]C87!A8FEL:71I97,@/2!A<G)A>2@G8V%N=F%S)RD["@H@("`@9G5N8W1I
M;VX@2&]R9&5?26UA9V5?<W9G*"1P87)A;7,I"B`@("!["B`@("`@("`@<&%R
M96YT.CI(;W)D95]);6%G92@D<&%R86US*3L*("`@("`@("`D=&AI<RT^7W-V
M9R`]("9N97<@6$U,7U-61U]$;V-U;65N="AA<G)A>2@G=VED=&@G(#T^("1T
M:&ES+3Y?=VED=&@L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VAE:6=H="<@/3X@)'1H:7,M/E]H96EG:'0I
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!G971#;VYT96YT5'EP92@I"B`@("![
M"B`@("`@("`@<F5T=7)N("=I;6%G92]S=F<K>&UL)SL*("`@('T*"B`@("!F
M=6YC=&EO;B!G971,:6YK*"1U<FPL("1T:71L92`]("<G*0H@("`@>PH@("`@
M?0H*("`@(&9U;F-T:6]N(&1I<W!L87DH*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?<W9G+3YP<FEN=$5L96UE;G0H*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;B!T:&4@<F%W(&1A=&$@9F]R('1H:7,@:6UA9V4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R87<@:6UA9V4@9&%T82X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F%W*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]S=F<M/F)U9F9E<D]B:F5C="@I.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&=E=$9O;G0H)&9O;G0I"B`@("!["B`@("`@("`@<F5T=7)N("1F;VYT
M.PH@("`@?0H*("`@(&9U;F-T:6]N(%]C<F5A=&53>6UB;VPH)',L("1I9"D*
M("`@('L*("`@("`@("`D<RT^<V5T4&%R86TH)VED)RP@)&ED*3L*("`@("`@
M("`D9&5F<R`]("9N97<@6$U,7U-61U]$969S*"D["B`@("`@("`@)&1E9G,M
M/F%D9$-H:6QD*"1S*3L*("`@("`@("`D=&AI<RT^7W-V9RT^861D0VAI;&0H
M)&1E9G,I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]C<F5A=&5$<F]P4VAA9&]W
M*"1I9"`]("=D<F]P4VAA9&]W)RD*("`@('L*("`@("`@("`D9&5F<R`]("9N
M97<@6$U,7U-61U]$969S*"D["B`@("`@("`@)&9I;'1E<B`]("9N97<@6$U,
M7U-61U]&:6QT97(H87)R87DH)VED)R`]/B`D:60I*3L*("`@("`@("`D9FEL
M=&5R+3YA9&10<FEM:71I=F4H)T=A=7-S:6%N0FQU<B<L(&%R<F%Y*"=I;B<@
M/3X@)U-O=7)C94%L<&AA)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=S=&1$979I871I;VXG(#T^(#(L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<F5S=6QT)R`]/B`G8FQU<B<I*3L*("`@("`@("`D9FEL=&5R
M+3YA9&10<FEM:71I=F4H)T]F9G-E="<L(&%R<F%Y*"=I;B<@/3X@)V)L=7(G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V1X)R`]/B`T+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V1Y)R`]/B`T+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E<W5L="<@/3X@)V]F9G-E
M=$)L=7(G*2D["B`@("`@("`@)&UE<F=E(#T@)FYE=R!834Q?4U9'7T9I;'1E
M<E!R:6UI=&EV92@G365R9V4G*3L*("`@("`@("`D;65R9V4M/F%D9$UE<F=E
M3F]D92@G;V9F<V5T0FQU<B<I.PH@("`@("`@("1M97)G92T^861D365R9V5.
M;V1E*"=3;W5R8V5'<F%P:&EC)RD["@H@("`@("`@("1F:6QT97(M/F%D9$-H
M:6QD*"1M97)G92D["B`@("`@("`@)&1E9G,M/F%D9$-H:6QD*"1F:6QT97(I
M.PH@("`@("`@("1T:&ES+3Y?<W9G+3YA9&1#:&EL9"@D9&5F<RD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$<F%W<R!A('1E>'0@<W1R:6YG(&]N('1H92!I
M;6%G92!I;B!A('-P96-I9FEE9"!L;V-A=&EO;BP@=VET:`H@("`@("H@=&AE
M('-P96-I9FEE9"!S='EL92!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D=&5X="`@("`@("!4:&4@=&5X="!T;R!D<F%W+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)'@@("`@("`@("`@5&AE(&QE9G0@>"!C
M;V]R9&EN871E(&]F('1H92!S=&%R="!O9B!T:&4@=&5X="!S=')I;F<N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D>2`@("`@("`@("!4:&4@=&]P('D@8V]O
M<F1I;F%T92!O9B!T:&4@<W1A<G0@;V8@=&AE('1E>'0@<W1R:6YG+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)&9O;G0@("`@("`@5&AE(&9O;G0@:61E;G1I
M9FEE<B!Y;W4@=V%N="!T;R!U<V4@9F]R('1H92!T97AT+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`@)&-O;&]R("`@("`@5&AE(&-O;&]R('1H870@>6]U('=A
M;G0@=&AE('1E>'0@9&ES<&QA>65D(&EN+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&1I<F5C=&EO;B`@06X@:6YT96=E<B!T:&%T('-P96-I9FEE<R!T:&4@
M;W)I96YT871I;VX@;V8@=&AE('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('1E>'0H)'-T<FEN9RP@)'@L("1Y+"`D9F]N="`]("=M;VYO<W!A8V4G+"`D
M8V]L;W(@/2`G8FQA8VLG+"`D9&ER96-T:6]N(#T@,"D*("`@('L*("`@("`@
M("`D:&5I9VAT(#T@,3(["B`@("`@("`@)'-T>6QE(#T@)V9O;G0M9F%M:6QY
M.B<@+B`D9F]N="`N("<[9F]N="UH96EG:'0Z)R`N("1H96EG:'0@+B`G<'@[
M9FEL;#HG("X@)'1H:7,M/F=E=$AE>$-O;&]R*"1C;VQO<BD@+B`G.W1E>'0M
M86YC:&]R.G-T87)T.R<["B`@("`@("`@)'1R86YS9F]R;2`]("=R;W1A=&4H
M)R`N("1D:7)E8W1I;VX@+B`G+"<@+B`D>"`N("<L)R`N("1Y("X@)RDG.PH@
M("`@("`@("1T:&ES+3Y?<W9G+3YA9&1#:&EL9"AN97<@6$U,7U-61U]497AT
M*&%R<F%Y*"=T97AT)R`]/B`D<W1R:6YG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=X)R`]/B`H:6YT
M*21X+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=Y)R`]/B`H:6YT*21Y("L@)&AE:6=H="P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G=')A;G-F;W)M)R`]/B`D=')A;G-F;W)M+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S='EL92<@
M/3X@)'-T>6QE*2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A(&-I
M<F-L92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@(%1H
M92!X(&-O;W)D:6YA=&4@;V8@=&AE(&-E;G1R92X*("`@("`J($!P87)A;2!I
M;G1E9V5R("1Y("`@("`@5&AE('D@8V]O<F1I;F%T92!O9B!T:&4@8V5N=')E
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'(@("`@("!4:&4@<F%D:75S(&]F
M('1H92!C:7)C;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8V]L;W(@(%1H
M92!L:6YE(&-O;&]R(&]F('1H92!C:7)C;&4N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`D9FEL;"`@(%1H92!C;VQO<B!T;R!F:6QL('1H92!C:7)C;&4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&-I<F-L92@D>"P@)'DL("1R+"`D8V]L;W(L
M("1F:6QL(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1F:6QL
M*2D@>PH@("`@("`@("`@("`D<W1Y;&4@/2`G9FEL;#HG("X@)'1H:7,M/F=E
M=$AE>$-O;&]R*"1F:6QL*2`N("<[("<["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'-T>6QE(#T@)V9I;&PZ;F]N93LG.PH@("`@("`@('T*("`@
M("`@("`D<W1Y;&4@+CT@)W-T<F]K93HG("X@)'1H:7,M/F=E=$AE>$-O;&]R
M*"1C;VQO<BD@+B`G.R!S=')O:V4M=VED=&@Z,2<["@H@("`@("`@("1T:&ES
M+3Y?<W9G+3YA9&1#:&EL9"AN97<@6$U,7U-61U]#:7)C;&4H87)R87DH)V-X
M)R`]/B`D>"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=C>2<@/3X@)'DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<B<@
M/3X@)'(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<W1Y;&4G(#T^("1S='EL92DI*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($1R87<@82!P;VQY9V]N(&)A<V5D(&]N(&$@<V5T
M(&]F('9E<G1I8V5S+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D=F5R
M=&EC97,@($%N(&%R<F%Y(&]F('@@86YD('D@;&%B96QE9"!A<G)A>7,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("AE9RX@)'9E<G1I8V5S6S!=
M6R=X)UTL("1V97)T:6-E<ULP75LG>2==+"`N+BXI+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8V]L;W(@("`@5&AE(&-O;&]R('EO=2!W86YT('1O(&1R87<@
M=&AE('!O;'EG;VX@=VET:"X*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&P@
M("`@(%1H92!C;VQO<B!T;R!F:6QL('1H92!P;VQY9V]N+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!P;VQY9V]N*"1V97)T<RP@)&-O;&]R+"`D9FEL;"`](&YU
M;&PI"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D9FEL;"DI('L*("`@("`@
M("`@("`@)'-T>6QE(#T@)V9I;&PZ)R`N("1T:&ES+3YG971(97A#;VQO<B@D
M9FEL;"D@+B`G.R`G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S
M='EL92`]("=F:6QL.FYO;F4[)SL*("`@("`@("!]"B`@("`@("`@)'-T>6QE
M("X]("=S=')O:V4Z)R`N("1T:&ES+3YG971(97A#;VQO<B@D8V]L;W(I("X@
M)SL@<W1R;VME+7=I9'1H.C$G.PH*("`@("`@("`D<&]I;G1S(#T@)R<["B`@
M("`@("`@9F]R96%C:"`H)'9E<G1S(&%S("1V*2!["B`@("`@("`@("`@("1P
M;VEN=',@+CT@)'9;)W@G72`N("<L)R`N("1V6R=Y)UT@+B`G("<["B`@("`@
M("`@?0H@("`@("`@("1P;VEN=',@/2!T<FEM*"1P;VEN=',I.PH*("`@("`@
M("`D=&AI<RT^7W-V9RT^861D0VAI;&0H;F5W(%A-3%]35D=?4&]L>6=O;BAA
M<G)A>2@G<&]I;G1S)R`]/B`D<&]I;G1S+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S='EL92<@
M/3X@)'-T>6QE*2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A(')E
M8W1A;F=L92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@
M("!4:&4@;&5F="!X+6-O;W)D:6YA=&4@;V8@=&AE(')E8W1A;F=L92X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1Y("`@("`@(%1H92!T;W`@>2UC;V]R9&EN
M871E(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M=VED=&@@("!4:&4@=VED=&@@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P
M87)A;2!I;G1E9V5R("1H96EG:'0@(%1H92!H96EG:'0@;V8@=&AE(')E8W1A
M;F=L92X*("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R("`@(%1H92!L:6YE
M(&-O;&]R(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1F:6QL("`@("!4:&4@8V]L;W(@=&\@9FEL;"!T:&4@<F5C=&%N9VQE+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!R96-T86YG;&4H)'@L("1Y+"`D=VED=&@L
M("1H96EG:'0L("1C;VQO<BP@)&9I;&P@/2!N=6QL*0H@("`@>PH@("`@("`@
M(&EF("@A96UP='DH)&9I;&PI*2!["B`@("`@("`@("`@("1S='EL92`]("=F
M:6QL.B<@+B`D=&AI<RT^9V5T2&5X0V]L;W(H)&9I;&PI("X@)SL@)SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<W1Y;&4@/2`G9FEL;#IN;VYE
M.R<["B`@("`@("`@?0H@("`@("`@("1S='EL92`N/2`G<W1R;VME.B<@+B`D
M=&AI<RT^9V5T2&5X0V]L;W(H)&-O;&]R*2`N("<[('-T<F]K92UW:61T:#HQ
M)SL*"B`@("`@("`@)'1H:7,M/E]S=F<M/F%D9$-H:6QD*&YE=R!834Q?4U9'
M7U)E8W0H87)R87DH)W@G(#T^("1X+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=Y)R`]/B`D>2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G=VED=&@G(#T^("1W:61T:"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:&5I9VAT)R`]/B`D
M:&5I9VAT+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=S='EL92<@/3X@)'-T>6QE*2DI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1')A=R!A(')E8W1A;F=L92X*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D>"`@("`@("!4:&4@;&5F="!X+6-O;W)D:6YA
M=&4@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y
M("`@("`@(%1H92!T;W`@>2UC;V]R9&EN871E(&]F('1H92!R96-T86YG;&4N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=VED=&@@("!4:&4@=VED=&@@;V8@
M=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1H96EG:'0@
M(%1H92!H96EG:'0@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I
M;G1E9V5R("1R;W5N9"`@(%1H92!W:61T:"!O9B!T:&4@8V]R;F5R(')O=6YD
M:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&-O;&]R("`@5&AE(&QI;F4@
M8V]L;W(@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!S=')I;F<@
M("1F:6QL("`@(%1H92!C;VQO<B!T;R!F:6QL('1H92!R96-T86YG;&4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')O=6YD961296-T86YG;&4H)'@L("1Y+"`D
M=VED=&@L("1H96EG:'0L("1R;W5N9"P@)&-O;&]R+"`D9FEL;"D*("`@('L*
M("`@("`@("!I9B`H(65M<'1Y*"1F:6QL*2D@>PH@("`@("`@("`@("`D<W1Y
M;&4@/2`G9FEL;#HG("X@)'1H:7,M/F=E=$AE>$-O;&]R*"1F:6QL*2`N("<[
M("<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-T>6QE(#T@)V9I
M;&PZ;F]N93LG.PH@("`@("`@('T*("`@("`@("`D<W1Y;&4@+CT@)W-T<F]K
M93HG("X@)'1H:7,M/F=E=$AE>$-O;&]R*"1C;VQO<BD@+B`G.R!S=')O:V4M
M=VED=&@Z,2<["@H@("`@("`@("1T:&ES+3Y?<W9G+3YA9&1#:&EL9"AN97<@
M6$U,7U-61U]296-T*&%R<F%Y*"=X)R`]/B`D>"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G>2<@/3X@
M)'DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W)X)R`]/B`D<F]U;F0L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)Y)R`]/B`D
M<F]U;F0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W=I9'1H)R`]/B`D=VED=&@L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAE
M:6=H="<@/3X@)&AE:6=H="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<W1Y;&4G(#T^("1S='EL92DI
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@82!L:6YE+@H@("`@("H*
M("`@("`J($!P87)A;2!I;G1E9V5R("1X,"`@("`@5&AE('@@8V]O<F1I;F%T
M92!O9B!T:&4@<W1A<G0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>3`@("`@
M(%1H92!Y(&-O;W)D:6YA=&4@;V8@=&AE('-T87)T+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'@Q("`@("!4:&4@>"!C;V]R9&EN871E(&]F('1H92!E;F0N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>3$@("`@(%1H92!Y(&-O;W)D:6YA
M=&4@;V8@=&AE(&5N9"X*("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R("`@
M5&AE(&QI;F4@8V]L;W(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1W:61T:"`@
M(%1H92!W:61T:"!O9B!T:&4@;&EN92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M;&EN92@D>#$L("1Y,2P@)'@R+"`D>3(L("1C;VQO<B`]("=B;&%C:R<L("1W
M:61T:"`](#$I"B`@("!["B`@("`@("`@)'-T>6QE(#T@)W-T<F]K93HG("X@
M)'1H:7,M/F=E=$AE>$-O;&]R*"1C;VQO<BD@+B`G.R!S=')O:V4M=VED=&@Z
M)R`N("AI;G0I)'=I9'1H.PH@("`@("`@("1T:&ES+3Y?<W9G+3YA9&1#:&EL
M9"AN97<@6$U,7U-61U],:6YE*&%R<F%Y*"=X,2<@/3X@)'@Q+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=Y,2<@/3X@)'DQ+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=X,B<@/3X@)'@R+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=Y
M,B<@/3X@)'DR+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=S='EL92<@/3X@)'-T>6QE*2DI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1')A=R!A(&1A<VAE9"!L:6YE+@H@("`@("H*
M("`@("`J($!P87)A;2!I;G1E9V5R("1X,"`@("`@("`@("`@5&AE('@@8V]O
M<F1I;F%T92!O9B!T:&4@<W1A<G0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M>3`@("`@("`@("`@(%1H92!Y(&-O;W)D:6YA=&4@;V8@=&AE('-T87)T+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)'@Q("`@("`@("`@("!4:&4@>"!C;V]R
M9&EN871E(&]F('1H92!E;F0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>3$@
M("`@("`@("`@(%1H92!Y(&-O;W)D:6YA=&4@;V8@=&AE(&5N9"X*("`@("`J
M($!P87)A;2!S=')I;F<@("1C;VQO<B`@("`@("`@5&AE(&QI;F4@8V]L;W(N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=VED=&@@("`@("`@(%1H92!W:61T
M:"!O9B!T:&4@;&EN92X*("`@("`J($!P87)A;2!I;G1E9V5R("1D87-H7VQE
M;F=T:"`@5&AE(&QE;F=T:"!O9B!A(&1A<V@@;VX@=&AE(&1A<VAE9"!L:6YE
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&%S:%]S<&%C92`@(%1H92!L96YG
M=&@@;V8@82!S<&%C92!I;B!T:&4@9&%S:&5D(&QI;F4*("`@("`J+PH@("`@
M9G5N8W1I;VX@9&%S:&5D3&EN92@D>#$L("1Y,2P@)'@R+"`D>3(L("1C;VQO
M<B`]("=B;&%C:R<L("1W:61T:"`](#$L("1D87-H7VQE;F=T:"`](#(L("1D
M87-H7W-P86-E(#T@,BD*("`@('L*("`@("`@("`D<W1Y;&4@/2`G<W1R;VME
M.B<@+B`D=&AI<RT^9V5T2&5X0V]L;W(H)&-O;&]R*2`N("<[('-T<F]K92UW
M:61T:#HG("X@*&EN="DD=VED=&@@+B`G.R!S=')O:V4M9&%S:&%R<F%Y.B<@
M+B`D9&%S:%]L96YG=&@@+B`G+"<@+B`D9&%S:%]S<&%C92`N("<[)SL*("`@
M("`@("`D=&AI<RT^7W-V9RT^861D0VAI;&0H;F5W(%A-3%]35D=?3&EN92AA
M<G)A>2@G>#$G(#T^("1X,2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G>3$G(#T^("1Y,2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G>#(G(#T^("1X,BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G>3(G(#T^("1Y,BP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<W1Y;&4G(#T^("1S='EL92DI*3L*("`@('T*"B`@("`O*BH*("`@("`J($1R
M87<@82!P;VQY;&EN92`H82!N;VXM8VQO<V5D+"!N;VXM9FEL;&5D('!O;'EG
M;VXI(&)A<V5D(&]N(&$*("`@("`J('-E="!O9B!V97)T:6-E<RX*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)'9E<G1I8V5S("!!;B!A<G)A>2!O9B!X
M(&%N9"!Y(&QA8F5L960@87)R87ES"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`H96<N("1V97)T:6-E<ULP75LG>"==+"`D=F5R=&EC97-;,%U;
M)WDG72P@+BXN*2X*("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R("`@(%1H
M92!C;VQO<B!Y;W4@=V%N="!T;R!D<F%W('1H92!L:6YE('=I=&@N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1W:61T:"`@("!4:&4@=VED=&@@;V8@=&AE(&QI
M;F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('!O;'EL:6YE*"1V97)T<RP@)&-O
M;&]R+"`D=VED=&@@/2`Q*0H@("`@>PH@("`@("`@("1S='EL92`]("=S=')O
M:V4Z)R`N("1T:&ES+3YG971(97A#;VQO<B@D8V]L;W(I("X@)SL@<W1R;VME
M+7=I9'1H.B<@+B`D=VED=&@@+B`G.V9I;&PZ;F]N93LG.PH*("`@("`@("`O
M+R!#86QC=6QA=&4@=&AE('!A=&@@96YT<GDN"B`@("`@("`@)'!A=&@@/2`G
M)SL*"B`@("`@("`@)&9I<G-T(#T@=')U93L*("`@("`@("!F;W)E86-H("@D
M=F5R=',@87,@)'9E<G0I('L*("`@("`@("`@("`@:68@*"1F:7)S="D@>PH@
M("`@("`@("`@("`@("`@)&9I<G-T(#T@9F%L<V4["B`@("`@("`@("`@("`@
M("`D<&%T:"`N/2`G32`G("X@)'9E<G1;)W@G72`N("<L)R`N("1V97)T6R=Y
M)UT["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<&%T
M:"`N/2`G($P@)R`N("1V97)T6R=X)UT@+B`G+"<@+B`D=F5R=%LG>2==.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W-V9RT^
M861D0VAI;&0H;F5W(%A-3%]35D=?4&%T:"AA<G)A>2@G9"<@/3X@)'!A=&@L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W-T>6QE)R`]/B`D<W1Y;&4I*2D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$<F%W(&%N(&%R8RX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D>"`@("`@(%1H92!X(&-O;W)D:6YA=&4@;V8@=&AE(&-E;G1R92X*
M("`@("`J($!P87)A;2!I;G1E9V5R("1Y("`@("`@5&AE('D@8V]O<F1I;F%T
M92!O9B!T:&4@8V5N=')E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'(@("`@
M("!4:&4@<F%D:75S(&]F('1H92!A<F,N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D<W1A<G0@(%1H92!S=&%R="!A;F=L92!O9B!T:&4@87)C+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&5N9"`@("!4:&4@96YD(&%N9VQE(&]F('1H92!A
M<F,N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8V]L;W(@(%1H92!L:6YE(&-O
M;&]R(&]F('1H92!A<F,N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D9FEL;"`@
M(%1H92!F:6QL(&-O;&]R(&]F('1H92!A<F,@*&1E9F%U;'1S('1O(&YO;F4I
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!A<F,H)'@L("1Y+"`D<BP@)'-T87)T
M+"`D96YD+"`D8V]L;W(@/2`G8FQA8VLG+"`D9FEL;"`](&YU;&PI"B`@("![
M"B`@("`@("`@:68@*"%E;7!T>2@D9FEL;"DI('L*("`@("`@("`@("`@)'-T
M>6QE(#T@)V9I;&PZ)R`N("1T:&ES+3YG971(97A#;VQO<B@D9FEL;"D@+B`G
M.R`G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S='EL92`]("=F
M:6QL.FYO;F4[)SL*("`@("`@("!]"B`@("`@("`@)'-T>6QE("X]("=S=')O
M:V4Z)R`N("1T:&ES+3YG971(97A#;VQO<B@D8V]L;W(I("X@)SL@<W1R;VME
M+7=I9'1H.C$G.PH*("`@("`@("`D;6ED(#T@<F]U;F0H*"1S=&%R="`K("1E
M;F0I("\@,BD["@H@("`@("`@("\O($-A;&-U;&%T92!T:&4@<&%T:"!E;G1R
M>2X*("`@("`@("`D<&%T:"`]("<G.PH*("`@("`@("`O+R!)9B!F:6QL960L
M(&1R87<@=&AE(&]U=&QI;F4N"B`@("`@("`@:68@*"%E;7!T>2@D9FEL;"DI
M('L*("`@("`@("`@("`@+R\@4W1A<G0@870@=&AE(&-E;G1E<B!O9B!T:&4@
M96QL:7!S92!T:&4@87)C(&ES(&]N+@H@("`@("`@("`@("`D<&%T:"`N/2`B
M32`D>"PD>2`B.PH*("`@("`@("`@("`@+R\@1')A=R!O=70@=&\@96QL:7!S
M92!E9&=E+@H@("`@("`@("`@("!L:7-T*"1A<F-8+"`D87)C62D@/2`D=&AI
M<RT^7V-I<F-L95!O:6YT*"1S=&%R="P@)'(@*B`R*3L*("`@("`@("`@("`@
M)'!A=&@@+CT@)TP@)R`N(')O=6YD*"1X("L@)&%R8U@I("X@)RPG("X*("`@
M("`@("`@("`@("`@(')O=6YD*"1Y("L@)&%R8UDI("X@)R`G.PH@("`@("`@
M('T*"B`@("`@("`@+R\@1')A=R!A<F-S+@H@("`@("`@(&QI<W0H)&%R8U@L
M("1A<F-9*2`]("1T:&ES+3Y?8VER8VQE4&]I;G0H)&UI9"P@)'(@*B`R*3L*
M("`@("`@("`D<&%T:"`N/2`B02`D<BPD<B`P(#`@,2`B("X*("`@("`@("`@
M("`@<F]U;F0H)'@@*R`D87)C6"D@+B`G+"<@+@H@("`@("`@("`@("!R;W5N
M9"@D>2`K("1A<F-9*2`N("<@)SL*"B`@("`@("`@;&ES="@D87)C6"P@)&%R
M8UDI(#T@)'1H:7,M/E]C:7)C;&50;VEN="@D96YD+"`D<B`J(#(I.PH@("`@
M("`@("1P871H("X](")!("1R+"1R(#`@,"`Q("(@+@H@("`@("`@("`@("!R
M;W5N9"@D>"`K("1A<F-8*2`N("<L)R`N"B`@("`@("`@("`@(')O=6YD*"1Y
M("L@)&%R8UDI("X@)R`G.PH*("`@("`@("`O+R!)9B!F:6QL960L(&-L;W-E
M('1H92!O=71L:6YE+@H@("`@("`@(&EF("@A96UP='DH)&9I;&PI*2!["B`@
M("`@("`@("`@("1P871H("X]("=:)SL*("`@("`@("!]"@H@("`@("`@("1P
M871H(#T@=')I;2@D<&%T:"D["@H@("`@("`@("1T:&ES+3Y?<W9G+3YA9&1#
M:&EL9"AN97<@6$U,7U-61U]0871H*&%R<F%Y*"=D)R`]/B`D<&%T:"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G<W1Y;&4G(#T^("1S='EL92DI*3L*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+TEM86=E+W-W9BYP:'``````````````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T-#<P-``Q,#4Q-30S,S<T-@`P,C(P
M,S(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO
M26UA9V4N<&AP)SL*"B\J*@H@*B!4:&ES(&-L87-S(&EM<&QE;65N=',@=&AE
M($AO<F1E7TEM86=E.CH@05!)(&9O<B!35T8L('5S:6YG('1H92!02%`*("H@
M36EN9R!E>'1E;G-I;VXN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TEM86=E
M+TEM86=E+W-W9BYP:'`L=B`Q+C(T+C$P+C8@,C`P-B\P,2\P,2`R,3HR.#HR
M,B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?26UA9V4*
M("HO"F-L87-S($AO<F1E7TEM86=E7W-W9B!E>'1E;F1S($AO<F1E7TEM86=E
M('L*"B`@("`O*BH*("`@("`J($-A<&%B:6QI=&5S(&]F('1H:7,@9')I=F5R
M+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M8V%P86)I;&ET:65S(#T@87)R87DH)V-A;G9A<R<I.PH*("`@("\J*@H@("`@
M("H@4U=&(')O;W0@;6]V:64N"B`@("`@*@H@("`@("H@0'9A<B!R97-O=7)C
M90H@("`@("HO"B`@("!V87(@)%]M;W9I93L*"B`@("!F=6YC=&EO;B!(;W)D
M95]);6%G95]S=V8H)'!A<F%M<RD*("`@('L*("`@("`@("!P87)E;G0Z.DAO
M<F1E7TEM86=E*"1P87)A;7,I.PH*("`@("`@("`D=&AI<RT^7VUO=FEE(#T@
M)FYE=R!35T9-;W9I92@I.PH@("`@("`@("1T:&ES+3Y?;6]V:64M/G-E=$1I
M;65N<VEO;B@D=&AI<RT^7W=I9'1H+"`D=&AI<RT^7VAE:6=H="D["@H@("`@
M("`@("\O($9)6$U%.B!H;VYO<B!T:&4@)V)A8VMG<F]U;F0G('!A<F%M971E
M<B!H97)E+@H@("`@("`@("1T:&ES+3Y?;6]V:64M/G-E=$)A8VMG<F]U;F0H
M,'AF9BP@,'AF9BP@,'AF9BD["B`@("`@("`@)'1H:7,M/E]M;W9I92T^<V5T
M4F%T92@S,"D["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T0V]N=&5N=%1Y<&4H
M*0H@("`@>PH@("`@("`@(')E='5R;B`G87!P;&EC871I;VXO>"US:&]C:W=A
M=F4M9FQA<V@G.PH@("`@?0H*("`@("\J*@H@("`@("H@1&ES<&QA>2!T:&4@
M;6]V:64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1I<W!L87DH*0H@("`@>PH@
M("`@("`@("1T:&ES+3YH96%D97)S*"D["B`@("`@("`@)'1H:7,M/E]M;W9I
M92T^;W5T<'5T*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE
M(')A=R!D871A(&9O<B!T:&ES(&EM86=E+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@<F%W(&EM86=E(&1A=&$N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(')A=R@I"B`@("!["B`@("`@("`@;V)?<W1A<G0H*3L*("`@("`@
M("`D=&AI<RT^7VUO=FEE+3YO=71P=70H*3L*("`@("`@("`D9&%T82`](&]B
M7V=E=%]C;VYT96YT<R@I.PH@("`@("`@(&]B7V5N9%]C;&5A;B@I.PH*("`@
M("`@("!R971U<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A
M=&5S(&$@8V]L;W(@=&AA="!C86X@8F4@86-C97-S960@:6X@=&AI<R!O8FIE
M8W0N(%=H96X@80H@("`@("H@8V]L;W(@:7,@<V5T+"!T:&4@<F=B82!V86QU
M97,@87)E(')E='5R;F5D(&EN(&%N(&%R<F%Y+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE(&]F('1H92!C;VQO<BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@<F5D+"!G<F5E;BP@8FQU
M92P@86QP:&$@=F%L=65S(&]F('1H92!C;VQO<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@86QL;V-A=&5#;VQO<B@D;F%M92D*("`@('L*("`@("`@("!L:7-T
M*"1R+"`D9RP@)&(I(#T@)'1H:7,M/F=E=%)'0B@D;F%M92D["B`@("`@("`@
M<F5T=7)N(&%R<F%Y*"=R960G(#T^("1R+`H@("`@("`@("`@("`@("`@("`@
M("`G9W)E96XG(#T^("1G+`H@("`@("`@("`@("`@("`@("`@("`G8FQU92<@
M/3X@)&(L"B`@("`@("`@("`@("`@("`@("`@("=A;'!H82<@/3X@,C4U*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!G971&;VYT*"1F;VYT*0H@("`@>PH@("`@
M("`@('-W:71C:"`H)&9O;G0I('L*("`@("`@("!C87-E("=S86YS+7-E<FEF
M)SH*("`@("`@("`@("`@<F5T=7)N("=?<V%N<R<["@H@("`@("`@(&-A<V4@
M)W-E<FEF)SH*("`@("`@("`@("`@<F5T=7)N("=?<V5R:68G.PH*("`@("`@
M("!C87-E("=M;VYO<W!A8V4G.@H@("`@("`@("`@("!R971U<FX@)U]T>7!E
M=W)I=&5R)SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N
M("1F;VYT.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1R87=S
M(&$@=&5X="!S=')I;F<@;VX@=&AE(&EM86=E(&EN(&$@<W!E8VEF:65D(&QO
M8V%T:6]N+"!W:71H"B`@("`@*B!T:&4@<W!E8VEF:65D('-T>6QE(&EN9F]R
M;6%T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1T97AT("`@
M("`@(%1H92!T97AT('1O(&1R87<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M>"`@("`@("`@("!4:&4@;&5F="!X(&-O;W)D:6YA=&4@;V8@=&AE('-T87)T
M(&]F('1H92!T97AT('-T<FEN9RX*("`@("`J($!P87)A;2!I;G1E9V5R("1Y
M("`@("`@("`@(%1H92!T;W`@>2!C;V]R9&EN871E(&]F('1H92!S=&%R="!O
M9B!T:&4@=&5X="!S=')I;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D9F]N
M="`@("`@("!4:&4@9F]N="!I9&5N=&EF:65R('EO=2!W86YT('1O('5S92!F
M;W(@=&AE('1E>'0N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8V]L;W(@("`@
M("!4:&4@8V]L;W(@=&AA="!Y;W4@=V%N="!T:&4@=&5X="!D:7-P;&%Y960@
M:6XN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&ER96-T:6]N("!!;B!I;G1E
M9V5R('1H870@<W!E8VEF:65S('1H92!O<FEE;G1A=&EO;B!O9B!T:&4@=&5X
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@=&5X="@D<W1R:6YG+"`D>"P@)'DL
M("1F;VYT(#T@)VUO;F]S<&%C92<L("1C;VQO<B`]("=B;&%C:R<L("1D:7)E
M8W1I;VX@/2`P*0H@("`@>PH@("`@("`@("1C;VQO<B`]("1T:&ES+3YA;&QO
M8V%T94-O;&]R*"1C;VQO<BD["@H@("`@("`@(&EF("AS=6)S='(H4$A07T]3
M+"`P+"`S*2`]/2`G5TE.)RD@>PH@("`@("`@("`@("`D=&5X="`]("9N97<@
M4U=&5&5X=$9I96QD*%-71E1%6%1&245,1%].3T5$250I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1T97AT(#T@)FYE=R!35T9497AT*"D["B`@
M("`@("`@?0H@("`@("`@("1T97AT+3YS971#;VQO<B@D8V]L;W);)W)E9"==
M+"`D8V]L;W);)V=R965N)UTL("1C;VQO<ELG8FQU92==+"`D8V]L;W);)V%L
M<&AA)UTI.PH@("`@("`@("1T97AT+3YA9&13=')I;F<H)'-T<FEN9RD["B`@
M("`@("`@)'1E>'0M/G-E=$9O;G0H;F5W(%-71D9O;G0H)'1H:7,M/F=E=$9O
M;G0H)&9O;G0I*2D["@H@("`@("`@("1T(#T@)'1H:7,M/E]M;W9I92T^861D
M*"1T97AT*3L*("`@("`@("`D="T^;6]V951O*"1X+"`D>2D["B`@("`@("`@
M)'0M/G)O=&%T92@D9&ER96-T:6]N*3L*"B`@("`@("`@<F5T=7)N("1T.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A(&-I<F-L92X*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@(%1H92!X(&-O+6]R9&EN871E
M(&]F('1H92!C96YT<F4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>2`@("`@
M(%1H92!Y(&-O+6]R9&EN871E(&]F('1H92!C96YT<F4N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D<B`@("`@(%1H92!R861I=7,@;V8@=&AE(&-I<F-L92X*
M("`@("`J($!P87)A;2!S=')I;F<@("1C;VQO<B`@5&AE(&QI;F4@8V]L;W(@
M;V8@=&AE(&-I<F-L92X*("`@("`J($!P87)A;2!S=')I;F<@("1F:6QL("`@
M5&AE(&-O;&]R('1O(&9I;&P@=&AE(&-I<F-L92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@8VER8VQE*"1X+"`D>2P@)'(L("1C;VQO<BP@)&9I;&P@/2`G;F]N
M92<I"B`@("!["B`@("`@("`@)',@/2`F;F5W(%-71E-H87!E*"D["B`@("`@
M("`@)&-O;&]R(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)&-O;&]R*3L*("`@
M("`@("`D<RT^<V5T3&EN92@Q+"`D8V]L;W);)W)E9"==+"`D8V]L;W);)V=R
M965N)UTL("1C;VQO<ELG8FQU92==+"`D8V]L;W);)V%L<&AA)UTI.PH*("`@
M("`@("!I9B`H)&9I;&P@(3T@)VYO;F4G*2!["B`@("`@("`@("`@("1F:6QL
M0V]L;W(@/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D9FEL;"D["B`@("`@("`@
M("`@("1F(#T@)',M/F%D9$9I;&PH)&9I;&Q#;VQO<ELG<F5D)UTL("1F:6QL
M0V]L;W);)V=R965N)UTL("1F:6QL0V]L;W);)V)L=64G72P@)&9I;&Q#;VQO
M<ELG86QP:&$G72D["B`@("`@("`@("`@("1S+3YS9712:6=H=$9I;&PH)&8I
M.PH@("`@("`@('T*"B`@("`@("`@)&$@/2`D<B`J(#`N-#$T,C$S-38R.R`O
M+R`]('1A;B@R,BXU(&1E9RD*("`@("`@("`D8B`]("1R("H@,"XW,#<Q,#8W
M.#$[("\O(#T@<W%R="@R*2\R(#T@<VEN*#0U(&1E9RD*"B`@("`@("`@)',M
M/FUO=F5096Y4;R@D>"`K("1R+"`D>2D["@H@("`@("`@("1S+3YD<F%W0W5R
M=F54;R@D>"`K("1R+"`D>2`M("1A+"`D>"`K("1B+"`D>2`M("1B*3L*("`@
M("`@("`D<RT^9')A=T-U<G9E5&\H)'@@*R`D82P@)'D@+2`D<BP@)'@L("1Y
M("T@)'(I.PH@("`@("`@("1S+3YD<F%W0W5R=F54;R@D>"`M("1A+"`D>2`M
M("1R+"`D>"`M("1B+"`D>2`M("1B*3L*("`@("`@("`D<RT^9')A=T-U<G9E
M5&\H)'@@+2`D<BP@)'D@+2`D82P@)'@@+2`D<BP@)'DI.PH@("`@("`@("1S
M+3YD<F%W0W5R=F54;R@D>"`M("1R+"`D>2`K("1A+"`D>"`M("1B+"`D>2`K
M("1B*3L*("`@("`@("`D<RT^9')A=T-U<G9E5&\H)'@@+2`D82P@)'D@*R`D
M<BP@)'@L("1Y("L@)'(I.PH@("`@("`@("1S+3YD<F%W0W5R=F54;R@D>"`K
M("1A+"`D>2`K("1R+"`D>"`K("1B+"`D>2`K("1B*3L*("`@("`@("`D<RT^
M9')A=T-U<G9E5&\H)'@@*R`D<BP@)'D@*R`D82P@)'@@*R`D<BP@)'DI.PH*
M("`@("`@("!R971U<FX@)'1H:7,M/E]M;W9I92T^861D*"1S*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($1R87<@82!P;VQY9V]N(&)A<V5D(&]N(&$@<V5T
M(&]F('9E<G1I8V5S+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D=F5R
M=&EC97,@($%N(&%R<F%Y(&]F('@@86YD('D@;&%B96QE9"!A<G)A>7,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("AE9RX@)'9E<G1I8V5S6S!=
M6R=X)UTL("1V97)T:6-E<ULP75LG>2==+"`N+BXI+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8V]L;W(@("`@5&AE(&-O;&]R('EO=2!W86YT('1O(&1R87<@
M=&AE('!O;'EG;VX@=VET:"X*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&P@
M("`@(%1H92!C;VQO<B!T;R!F:6QL('1H92!P;VQY9V]N+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!P;VQY9V]N*"1V97)T<RP@)&-O;&]R+"`D9FEL;"`]("=N
M;VYE)RD*("`@('L*("`@("`@("`D8V]L;W(@/2`D=&AI<RT^86QL;V-A=&5#
M;VQO<B@D8V]L;W(I.PH*("`@("`@("!I9B`H:7-?87)R87DH)&-O;&]R*2`F
M)B!I<U]A<G)A>2@D=F5R=',I("8F("AS:7IE;V8H)'9E<G1S*2`^(#(I*2![
M"B`@("`@("`@("`@("1S:&%P92`]("9N97<@4U=&4VAA<&4H*3L*("`@("`@
M("`@("`@)'-H87!E+3YS971,:6YE*#$L("1C;VQO<ELG<F5D)UTL("1C;VQO
M<ELG9W)E96XG72P@)&-O;&]R6R=B;'5E)UTL("1C;VQO<ELG86QP:&$G72D[
M"@H@("`@("`@("`@("!I9B`H)&9I;&P@(3T@)VYO;F4G*2!["B`@("`@("`@
M("`@("`@("`D9FEL;$-O;&]R(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)&9I
M;&PI.PH@("`@("`@("`@("`@("`@)&8@/2`D<VAA<&4M/F%D9$9I;&PH)&9I
M;&Q#;VQO<ELG<F5D)UTL("1F:6QL0V]L;W);)V=R965N)UTL("1F:6QL0V]L
M;W);)V)L=64G72P@)&9I;&Q#;VQO<ELG86QP:&$G72D["B`@("`@("`@("`@
M("`@("`D<VAA<&4M/G-E=%)I9VAT1FEL;"@D9BD["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("1F:7)S=%]D;VYE(#T@9F%L<V4["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1V97)T<R!A<R`D=F%L=64I('L*("`@("`@("`@("`@("`@
M(&EF("@A)&9I<G-T7V1O;F4I('L*("`@("`@("`@("`@("`@("`@("`D<VAA
M<&4M/FUO=F5096Y4;R@D=F%L=65;)W@G72P@)'9A;'5E6R=Y)UTI.PH@("`@
M("`@("`@("`@("`@("`@("1F:7)S=%]D;VYE(#T@=')U93L*("`@("`@("`@
M("`@("`@("`@("`D9FER<W1?>"`]("1V86QU95LG>"==.PH@("`@("`@("`@
M("`@("`@("`@("1F:7)S=%]Y(#T@)'9A;'5E6R=Y)UT["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D<VAA<&4M/F1R87=,:6YE5&\H)'9A
M;'5E6R=X)UTL("1V86QU95LG>2==*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D<VAA<&4M/F1R87=,:6YE5&\H)&9I<G-T7W@L("1F:7)S=%]Y*3L*
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VUO=FEE+3YA9&0H)'-H87!E
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!)9B!T:&4@8V]L
M;W(@:7,@86X@87)R87D@86YD('1H92!V97)T:6-E<R!I<R!A(&%N(&%R<F%Y
M"B`@("`@("`@("`@("\O(&]F(&UO<F4@=&AA;B`R('!O:6YT<RX*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($1R87<@82!R96-T86YG;&4N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'@@("`@("`@5&AE(&QE9G0@>"UC;V]R9&EN871E(&]F('1H
M92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>2`@("`@("!4
M:&4@=&]P('DM8V]O<F1I;F%T92!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)'=I9'1H("`@5&AE('=I9'1H(&]F('1H92!R96-T
M86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:&5I9VAT("!4:&4@:&5I
M9VAT(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D
M8V]L;W(@("!4:&4@;&EN92!C;VQO<B!O9B!T:&4@<F5C=&%N9VQE+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)&9I;&P@("`@5&AE(&-O;&]R('1O(&9I;&P@
M=&AE(')E8W1A;F=L92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5C=&%N9VQE
M*"1X+"`D>2P@)'=I9'1H+"`D:&5I9VAT+"`D8V]L;W(L("1F:6QL(#T@)VYO
M;F4G*0H@("`@>PH@("`@("`@("1V97)T<ULP72`](&%R<F%Y*"=X)R`]/B`D
M>"P@)WDG(#T^("1Y*3L*("`@("`@("`D=F5R='-;,5T@/2!A<G)A>2@G>"<@
M/3X@)'@@*R`D=VED=&@L("=Y)R`]/B`D>2D["B`@("`@("`@)'9E<G1S6S)=
M(#T@87)R87DH)W@G(#T^("1X("L@)'=I9'1H+"`G>2<@/3X@)'D@*R`D:&5I
M9VAT*3L*("`@("`@("`D=F5R='-;,UT@/2!A<G)A>2@G>"<@/3X@)'@L("=Y
M)R`]/B`D>2`K("1H96EG:'0I.PH*("`@("`@("!R971U<FX@)'1H:7,M/G!O
M;'EG;VXH)'9E<G1S+"`D8V]L;W(L("1F:6QL*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($1R87<@82!R96-T86YG;&4N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'@@("`@("`@5&AE(&QE9G0@>"UC;V]R9&EN871E(&]F('1H
M92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>2`@("`@("!4
M:&4@=&]P('DM8V]O<F1I;F%T92!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)'=I9'1H("`@5&AE('=I9'1H(&]F('1H92!R96-T
M86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:&5I9VAT("!4:&4@:&5I
M9VAT(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M<F]U;F0@("!4:&4@=VED=&@@;V8@=&AE(&-O<FYE<B!R;W5N9&EN9RX*("`@
M("`J($!P87)A;2!S=')I;F<@)&-O;&]R("`@(%1H92!L:6YE(&-O;&]R(&]F
M('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QL("`@
M("!4:&4@8V]L;W(@=&\@9FEL;"!T:&4@<F5C=&%N9VQE+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R;W5N9&5D4F5C=&%N9VQE*"1X+"`D>2P@)'=I9'1H+"`D
M:&5I9VAT+"`D<F]U;F0L("1C;VQO<B`]("=B;&%C:R<L("1F:6QL(#T@)VYO
M;F4G*0H@("`@>PH@("`@("`@(&EF("@D<F]U;F0@/#T@,"D@>PH@("`@("`@
M("`@("`O+R!/<'1I;6EZ92!O=70@86YY(&-A;&QS('=I=&@@;F\@8V]R;F5R
M(')O=6YD:6YG+@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)E8W1A;F=L
M92@D>"P@)'DL("1W:61T:"P@)&AE:6=H="P@)&-O;&]R+"`D9FEL;"D["B`@
M("`@("`@?0H*("`@("`@("`D<R`]("9N97<@4U=&4VAA<&4H*3L*("`@("`@
M("`D8V]L;W(@/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D8V]L;W(I.PH@("`@
M("`@("1S+3YS971,:6YE*#$L("1C;VQO<ELG<F5D)UTL("1C;VQO<ELG9W)E
M96XG72P@)&-O;&]R6R=B;'5E)UTL("1C;VQO<ELG86QP:&$G72D["@H@("`@
M("`@(&EF("@D9FEL;"`A/2`G;F]N92<I('L*("`@("`@("`@("`@)&9I;&Q#
M;VQO<B`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"1F:6QL*3L*("`@("`@("`@
M("`@)&8@/2`D<RT^861D1FEL;"@D9FEL;$-O;&]R6R=R960G72P@)&9I;&Q#
M;VQO<ELG9W)E96XG72P@)&9I;&Q#;VQO<ELG8FQU92==+"`D9FEL;$-O;&]R
M6R=A;'!H82==*3L*("`@("`@("`@("`@)',M/G-E=%)I9VAT1FEL;"@D9BD[
M"B`@("`@("`@?0H*("`@("`@("`O+R!3970@8V]R;F5R('!O:6YT<R!T;R!A
M=F]I9"!L;W1S(&]F(')E9'5N9&%N="!M871H+@H@("`@("`@("1X,2`]("1X
M("L@)')O=6YD.PH@("`@("`@("1Y,2`]("1Y("L@)')O=6YD.PH*("`@("`@
M("`D>#(@/2`D>"`K("1W:61T:"`M("1R;W5N9#L*("`@("`@("`D>3(@/2`D
M>2`K("1R;W5N9#L*"B`@("`@("`@)'@S(#T@)'@@*R`D=VED=&@@+2`D<F]U
M;F0["B`@("`@("`@)'DS(#T@)'D@*R`D:&5I9VAT("T@)')O=6YD.PH*("`@
M("`@("`D>#0@/2`D>"`K("1R;W5N9#L*("`@("`@("`D>30@/2`D>2`K("1H
M96EG:'0@+2`D<F]U;F0["@H@("`@("`@("\O(%-T87)T(&EN('1H92!U<'!E
M<B!L969T+@H@("`@("`@("1P,2`]("1T:&ES+3Y?87)C4&]I;G1S*"1R;W5N
M9"P@,3@P+"`R,C4I.PH@("`@("`@("1P,B`]("1T:&ES+3Y?87)C4&]I;G1S
M*"1R;W5N9"P@,C(U+"`R-S`I.PH*("`@("`@("`O+R!3=&%R="!A="!T:&4@
M;&]W97(@;&5F="!C;W)N97(@;V8@=&AE('1O<"!L969T(&-U<G9E+@H@("`@
M("`@("1S+3YM;W9E4&5N5&\H)'@Q("L@)'`Q6R=X,2==+"`D>3$@*R`D<#%;
M)WDQ)UTI.PH*("`@("`@("`O+R!$<F%W('1H92!U<'!E<B!L969T(&-O<FYE
M<BX*("`@("`@("`D<RT^9')A=T-U<G9E5&\H)'@Q("L@)'`Q6R=X,R==+"`D
M>3$@*R`D<#%;)WDS)UTL("1X,2`K("1P,5LG>#(G72P@)'DQ("L@)'`Q6R=Y
M,B==*3L*("`@("`@("`D<RT^9')A=T-U<G9E5&\H)'@Q("L@)'`R6R=X,R==
M+"`D>3$@*R`D<#);)WDS)UTL("1X,2`K("1P,ELG>#(G72P@)'DQ("L@)'`R
M6R=Y,B==*3L*"B`@("`@("`@+R\@0V%L8W5L871E('1H92!U<'!E<B!R:6=H
M="!P;VEN=',N"B`@("`@("`@)'`S(#T@)'1H:7,M/E]A<F-0;VEN=',H)')O
M=6YD+"`R-S`L(#,Q-2D["B`@("`@("`@)'`T(#T@)'1H:7,M/E]A<F-0;VEN
M=',H)')O=6YD+"`S,34L(#,V,"D["@H@("`@("`@("\O($-O;FYE8W0@=&AE
M('1O<"!L969T(&%N9"!R:6=H="!C=7)V97,N"B`@("`@("`@)',M/F1R87=,
M:6YE5&\H)'@R("L@)'`S6R=X,2==+"`D>3(@*R`D<#-;)WDQ)UTI.PH*("`@
M("`@("`O+R!$<F%W('1H92!U<'!E<B!R:6=H="!C;W)N97(N"B`@("`@("`@
M)',M/F1R87=#=7)V951O*"1X,B`K("1P,ULG>#,G72P@)'DR("L@)'`S6R=Y
M,R==+"`D>#(@*R`D<#-;)W@R)UTL("1Y,B`K("1P,ULG>3(G72D["B`@("`@
M("`@)',M/F1R87=#=7)V951O*"1X,B`K("1P-%LG>#,G72P@)'DR("L@)'`T
M6R=Y,R==+"`D>#(@*R`D<#1;)W@R)UTL("1Y,B`K("1P-%LG>3(G72D["@H@
M("`@("`@("\O($-A;&-U;&%T92!T:&4@;&]W97(@<FEG:'0@<&]I;G1S+@H@
M("`@("`@("1P-2`]("1T:&ES+3Y?87)C4&]I;G1S*"1R;W5N9"P@,"P@-#4I
M.PH@("`@("`@("1P-B`]("1T:&ES+3Y?87)C4&]I;G1S*"1R;W5N9"P@-#4L
M(#DP*3L*"B`@("`@("`@+R\@0V]N;F5C="!T:&4@=&]P(')I9VAT(&%N9"!L
M;W=E<B!R:6=H="!C=7)V97,N"B`@("`@("`@)',M/F1R87=,:6YE5&\H)'@S
M("L@)'`U6R=X,2==+"`D>3,@*R`D<#5;)WDQ)UTI.PH*("`@("`@("`O+R!$
M<F%W('1H92!L;W=E<B!R:6=H="!C;W)N97(N"B`@("`@("`@)',M/F1R87=#
M=7)V951O*"1X,R`K("1P-5LG>#,G72P@)'DS("L@)'`U6R=Y,R==+"`D>#,@
M*R`D<#5;)W@R)UTL("1Y,R`K("1P-5LG>3(G72D["B`@("`@("`@)',M/F1R
M87=#=7)V951O*"1X,R`K("1P-ELG>#,G72P@)'DS("L@)'`V6R=Y,R==+"`D
M>#,@*R`D<#9;)W@R)UTL("1Y,R`K("1P-ELG>3(G72D["@H@("`@("`@("\O
M($-A;&-U;&%T92!T:&4@;&]W97(@;&5F="!P;VEN=',N"B`@("`@("`@)'`W
M(#T@)'1H:7,M/E]A<F-0;VEN=',H)')O=6YD+"`Y,"P@,3,U*3L*("`@("`@
M("`D<#@@/2`D=&AI<RT^7V%R8U!O:6YT<R@D<F]U;F0L(#$S-2P@,3@P*3L*
M"B`@("`@("`@+R\@0V]N;F5C="!T:&4@8F]T=&]M(')I9VAT(&%N9"!B;W1T
M;VT@;&5F="!C=7)V97,N"B`@("`@("`@)',M/F1R87=,:6YE5&\H)'@T("L@
M)'`W6R=X,2==+"`D>30@*R`D<#=;)WDQ)UTI.PH*("`@("`@("`O+R!$<F%W
M('1H92!L;W=E<B!L969T(&-O<FYE<BX*("`@("`@("`D<RT^9')A=T-U<G9E
M5&\H)'@T("L@)'`W6R=X,R==+"`D>30@*R`D<#=;)WDS)UTL("1X-"`K("1P
M-ULG>#(G72P@)'DT("L@)'`W6R=Y,B==*3L*("`@("`@("`D<RT^9')A=T-U
M<G9E5&\H)'@T("L@)'`X6R=X,R==+"`D>30@*R`D<#A;)WDS)UTL("1X-"`K
M("1P.%LG>#(G72P@)'DT("L@)'`X6R=Y,B==*3L*"B`@("`@("`@+R\@0VQO
M<V4@=&AE('-H87!E+@H@("`@("`@("1S+3YD<F%W3&EN951O*"1X,2`K("1P
M,5LG>#$G72P@)'DQ("L@)'`Q6R=Y,2==*3L*"B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?;6]V:64M/F%D9"@D<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M<F%W(&$@;&EN92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>#`@
M("`@(%1H92!X(&-O+6]R9&EN871E(&]F('1H92!S=&%R="X*("`@("`J($!P
M87)A;2!I;G1E9V5R("1Y,"`@("`@5&AE('D@8V\M;W)D:6YA=&4@;V8@=&AE
M('-T87)T+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@Q("`@("!4:&4@>"!C
M;RUO<F1I;F%T92!O9B!T:&4@96YD+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)'DQ("`@("!4:&4@>2!C;RUO<F1I;F%T92!O9B!T:&4@96YD+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`@)&-O;&]R("!4:&4@;&EN92!C;VQO<BX*("`@("`J
M($!P87)A;2!S=')I;F<@("1W:61T:"`@5&AE('=I9'1H(&]F('1H92!L:6YE
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:6YE*"1X,2P@)'DQ+"`D>#(L("1Y
M,BP@)&-O;&]R(#T@)V)L86-K)RP@)'=I9'1H(#T@,2D*("`@('L*("`@("`@
M("`D8V]L;W(@/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D8V]L;W(I.PH*("`@
M("`@("!I9B`H:7-?87)R87DH)&-O;&]R*2D@>PH@("`@("`@("`@("`D<VAA
M<&4@/2`F;F5W(%-71E-H87!E*"D["B`@("`@("`@("`@("1S:&%P92T^<V5T
M3&EN92@D=VED=&@L("1C;VQO<ELG<F5D)UTL("1C;VQO<ELG9W)E96XG72P@
M)&-O;&]R6R=B;'5E)UTL("1C;VQO<ELG86QP:&$G72D["B`@("`@("`@("`@
M("1S:&%P92T^;6]V95!E;E1O*"1X,2P@)'DQ*3L*("`@("`@("`@("`@)'-H
M87!E+3YD<F%W3&EN951O*"1X,BP@)'DR*3L*"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7VUO=FEE+3YA9&0H)'-H87!E*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@1')A=R!A(&1A<VAE9"!L:6YE+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1X,"`@("`@("`@("`@5&AE('@@8V\M;W)D
M:6YA=&4@;V8@=&AE('-T87)T+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'DP
M("`@("`@("`@("!4:&4@>2!C;RUO<F1I;F%T92!O9B!T:&4@<W1A<G0N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D>#$@("`@("`@("`@(%1H92!X(&-O+6]R
M9&EN871E(&]F('1H92!E;F0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>3$@
M("`@("`@("`@(%1H92!Y(&-O+6]R9&EN871E(&]F('1H92!E;F0N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("`D8V]L;W(@("`@("`@(%1H92!L:6YE(&-O;&]R
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'=I9'1H("`@("`@("!4:&4@=VED
M=&@@;V8@=&AE(&QI;F4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&%S:%]L
M96YG=&@@(%1H92!L96YG=&@@;V8@82!D87-H(&]N('1H92!D87-H960@;&EN
M90H@("`@("H@0'!A<F%M(&EN=&5G97(@)&1A<VA?<W!A8V4@("!4:&4@;&5N
M9W1H(&]F(&$@<W!A8V4@:6X@=&AE(&1A<VAE9"!L:6YE"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&1A<VAE9$QI;F4H)'@P+"`D>3`L("1X,2P@)'DQ+"`D8V]L
M;W(@/2`G8FQA8VLG+"`D=VED=&@@/2`Q+"`D9&%S:%]L96YG=&@@/2`R+"`D
M9&%S:%]S<&%C92`](#(I"B`@("!["B`@("`@("`@+R\@1V5T('1H92!L96YG
M=&@@;V8@=&AE(&QI;F4@:6X@<&EX96QS+@H@("`@("`@("1L:6YE7VQE;F=T
M:"`](&UA>"AC96EL*'-Q<G0H<&]W*"@D>#$@+2`D>#`I+"`R*2`K('!O=R@H
M)'DQ("T@)'DP*2P@,BDI*2P@,BD["@H@("`@("`@("1C;W-4:&5T82`]("@D
M>#$@+2`D>#`I("\@)&QI;F5?;&5N9W1H.PH@("`@("`@("1S:6Y4:&5T82`]
M("@D>3$@+2`D>3`I("\@)&QI;F5?;&5N9W1H.PH@("`@("`@("1L87-T>"`]
M("1X,#L*("`@("`@("`D;&%S='D@/2`D>3`["@H@("`@("`@("\O($1R87<@
M=&AE(&1A<VAE9"!L:6YE+@H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1L
M:6YE7VQE;F=T:#L@)&D@*ST@*"1D87-H7VQE;F=T:"`K("1D87-H7W-P86-E
M*2D@>PH@("`@("`@("`@("`D>"`]("@D9&%S:%]L96YG=&@@*B`D8V]S5&AE
M=&$I("L@)&QA<W1X.PH@("`@("`@("`@("`D>2`]("@D9&%S:%]L96YG=&@@
M*B`D<VEN5&AE=&$I("L@)&QA<W1Y.PH*("`@("`@("`@("`@)'1H:7,M/FQI
M;F4H)&QA<W1X+"`D;&%S='DL("1X+"`D>2P@)&-O;&]R*3L*"B`@("`@("`@
M("`@("1L87-T>"`]("1X("L@*"1D87-H7W-P86-E("H@)&-O<U1H971A*3L*
M("`@("`@("`@("`@)&QA<W1Y(#T@)'D@*R`H)&1A<VA?<W!A8V4@*B`D<VEN
M5&AE=&$I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@
M82!P;VQY;&EN92`H82!N;VXM8VQO<V5D+"!N;VXM9FEL;&5D('!O;'EG;VXI
M(&)A<V5D(&]N(&$*("`@("`J('-E="!O9B!V97)T:6-E<RX*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@("`D=F5R=&EC97,@($%N(&%R<F%Y(&]F('@@
M86YD('D@;&%B96QE9"!A<G)A>7,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@*&5G+B`D=F5R=&EC97-;,%U;)W@G72P@)'9E<G1I8V5S6S!=
M6R=Y)UTL("XN+BDN"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8V]L;W(@("`@
M(%1H92!C;VQO<B!Y;W4@=V%N="!T;R!D<F%W('1H92!L:6YE('=I=&@N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("`D=VED=&@@("`@(%1H92!W:61T:"!O9B!T
M:&4@;&EN92X*("`@("`J+PH@("`@9G5N8W1I;VX@<&]L>6QI;F4H)'9E<G1S
M+"`D8V]L;W(L("1W:61T:"`](#$I"B`@("!["B`@("`@("`@)&-O;&]R(#T@
M)'1H:7,M/F%L;&]C871E0V]L;W(H)&-O;&]R*3L*"B`@("`@("`@)'-H87!E
M(#T@)FYE=R!35T93:&%P92@I.PH@("`@("`@("1S:&%P92T^<V5T3&EN92@D
M=VED=&@L("1C;VQO<ELG<F5D)UTL("1C;VQO<ELG9W)E96XG72P@)&-O;&]R
M6R=B;'5E)UTL("1C;VQO<ELG86QP:&$G72D["@H@("`@("`@("1F:7)S=%]D
M;VYE(#T@9F%L<V4["B`@("`@("`@9F]R96%C:"`H)'9E<G1S(&%S("1V86QU
M92D@>PH@("`@("`@("`@("!I9B`H(21F:7)S=%]D;VYE*2!["B`@("`@("`@
M("`@("`@("`D<VAA<&4M/FUO=F5096Y4;R@D=F%L=65;)W@G72P@)'9A;'5E
M6R=Y)UTI.PH@("`@("`@("`@("`@("`@)&9I<G-T7V1O;F4@/2!T<G5E.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1S:&%P92T^9')A=TQI;F54;R@D
M=F%L=65;)W@G72P@)'9A;'5E6R=Y)UTI.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?;6]V:64M/F%D9"@D<VAA<&4I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1')A=R!A;B!A<F,N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'@@("`@("!4:&4@>"!C;RUO<F1I;F%T92!O9B!T:&4@8V5N
M=')E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'D@("`@("!4:&4@>2!C;RUO
M<F1I;F%T92!O9B!T:&4@8V5N=')E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)'(@("`@("!4:&4@<F%D:75S(&]F('1H92!A<F,N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D<W1A<G0@(%1H92!S=&%R="!A;F=L92!O9B!T:&4@87)C+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&5N9"`@("!4:&4@96YD(&%N9VQE(&]F
M('1H92!A<F,N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VQO<B`@(%1H92!L
M:6YE(&-O;&]R(&]F('1H92!A<F,N"B`@("`@*B!`<&%R86T@<W1R:6YG("1F
M:6QL("`@(%1H92!F:6QL(&-O;&]R(&]F('1H92!A<F,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&%R8R@D>"P@)'DL("1R+"`D<W1A<G0L("1E;F0L("1C;VQO
M<B`]("=B;&%C:R<L("1F:6QL(#T@)VYO;F4G*0H@("`@>PH@("`@("`@("1S
M(#T@)FYE=R!35T93:&%P92@I.PH@("`@("`@("1C;VQO<B`]("1T:&ES+3YA
M;&QO8V%T94-O;&]R*"1C;VQO<BD["B`@("`@("`@)',M/G-E=$QI;F4H,2P@
M)&-O;&]R6R=R960G72P@)&-O;&]R6R=G<F5E;B==+"`D8V]L;W);)V)L=64G
M72P@)&-O;&]R6R=A;'!H82==*3L*"B`@("`@("`@:68@*"1F:6QL("$]("=N
M;VYE)RD@>PH@("`@("`@("`@("`D9FEL;$-O;&]R(#T@)'1H:7,M/F%L;&]C
M871E0V]L;W(H)&9I;&PI.PH@("`@("`@("`@("`D9B`]("1S+3YA9&1&:6QL
M*"1F:6QL0V]L;W);)W)E9"==+"`D9FEL;$-O;&]R6R=G<F5E;B==+"`D9FEL
M;$-O;&]R6R=B;'5E)UTL("1F:6QL0V]L;W);)V%L<&AA)UTI.PH@("`@("`@
M("`@("`D<RT^<V5T4FEG:'1&:6QL*"1F*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@D96YD("T@)'-T87)T(#P](#0U*2!["B`@("`@("`@("`@("1P=',@
M/2`D=&AI<RT^7V%R8U!O:6YT<R@D<BP@)'-T87)T+"`D96YD*3L*("`@("`@
M("`@("`@)',M/FUO=F5096Y4;R@D>"P@)'DI.PH@("`@("`@("`@("`D<RT^
M9')A=TQI;F54;R@D<'1S6R=X,2==("L@)'@L("1P='-;)WDQ)UT@*R`D>2D[
M"B`@("`@("`@("`@("1S+3YD<F%W0W5R=F54;R@D<'1S6R=X,R==("L@)'@L
M("1P='-;)WDS)UT@*R`D>2P@)'!T<ULG>#(G72`K("1X+"`D<'1S6R=Y,B==
M("L@)'DI.PH@("`@("`@("`@("`D<RT^9')A=TQI;F54;R@D>"P@)'DI.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S96-T:6]N<R`](&-E:6PH
M*"1E;F0@+2`D<W1A<G0I("\@-#4I.PH@("`@("`@("`@("!F;W(@*"1I(#T@
M,#L@)&D@/"`D<V5C=&EO;G,[("1I*RLI('L*("`@("`@("`@("`@("`@("1P
M=',@/2`D=&AI<RT^7V%R8U!O:6YT<R@D<BP@)'-T87)T("L@*"1I("H@-#4I
M+"`H)'-T87)T("L@*"@D:2`K(#$I("H@-#4I(#X@)&5N9"D*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`_("1E;F0*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("@D<W1A<G0@
M*R`H*"1I("L@,2D@*B`T-2DI*3L*"B`@("`@("`@("`@("`@("`O+R!)9B!W
M92!A<F4@;VX@=&AE(&9I<G-T('-E8W1I;VXL(&UO=F4@=&AE('!E;B!T;R!T
M:&4*("`@("`@("`@("`@("`@("\O(&-E;G1R92!A;F0@9')A=R!O=70@=&\@
M=&AE(&5D9V4N"B`@("`@("`@("`@("`@("!I9B`H)&D@/3T@,"`F)B`D9FEL
M;"`A/2`G;F]N92<I('L*("`@("`@("`@("`@("`@("`@("`D<RT^;6]V95!E
M;E1O*"1X+"`D>2D["B`@("`@("`@("`@("`@("`@("`@)',M/F1R87=,:6YE
M5&\H)'!T<ULG>#$G72`K("1X+"`D<'1S6R=Y,2==("L@)'DI.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<RT^;6]V
M95!E;E1O*"1P='-;)W@Q)UT@*R`D>"P@)'!T<ULG>3$G72`K("1Y*3L*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O+R!$<F%W('1H92!A
M<F,N"B`@("`@("`@("`@("`@("`D<RT^9')A=T-U<G9E5&\H)'!T<ULG>#,G
M72`K("1X+"`D<'1S6R=Y,R==("L@)'DL("1P='-;)W@R)UT@*R`D>"P@)'!T
M<ULG>3(G72`K("1Y*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@
M*"1F:6QL("$]("=N;VYE)RD@>PH@("`@("`@("`@("`@("`@+R\@1')A=R!A
M(&QI;F4@9G)O;2!T:&4@961G92!B86-K('1O('1H92!C96YT<F4@=&\@8VQO
M<V4*("`@("`@("`@("`@("`@("\O(&]F9B!T:&4@<V5G;65N="X*("`@("`@
M("`@("`@("`@("1S+3YD<F%W3&EN951O*"1X+"`D>2D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7VUO=FEE+3YA
M9&0H)',I.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A(')E8W1A;F=L
M92!F:6QL960@=VET:"!A(&=R861I96YT(&9R;VT@)&-O;&]R,2!T;PH@("`@
M("H@)&-O;&]R,BX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@
M("`@("!4:&4@;&5F="!X+6-O;W)D:6YA=&4@;V8@=&AE(')E8W1A;F=L92X*
M("`@("`J($!P87)A;2!I;G1E9V5R("1Y("`@("`@(%1H92!T;W`@>2UC;V]R
M9&EN871E(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D=VED=&@@("!4:&4@=VED=&@@;V8@=&AE(')E8W1A;F=L92X*("`@("`J
M($!P87)A;2!I;G1E9V5R("1H96EG:'0@(%1H92!H96EG:'0@;V8@=&AE(')E
M8W1A;F=L92X*("`@("`J($!P87)A;2!S=')I;F<@("1C;VQO<B`@(%1H92!O
M=71L:6YE(&-O;&]R(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("`D9FEL;#$@("!4:&4@;F%M92!O9B!T:&4@<W1A<G0@8V]L;W(@
M9F]R('1H92!G<F%D:65N="X*("`@("`J($!P87)A;2!S=')I;F<@("1F:6QL
M,B`@(%1H92!N86UE(&]F('1H92!E;F0@8V]L;W(@9F]R('1H92!G<F%D:65N
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@9W)A9&EE;G1296-T86YG;&4H)'@L
M("1Y+"`D=VED=&@L("1H96EG:'0L("1C;VQO<B`]("=B;&%C:R<L("1F:6QL
M,2`]("=B;&%C:R<L("1F:6QL,B`]("=W:&ET92<I"B`@("!["B`@("`@("`@
M)',@/2`F;F5W(%-71E-H87!E*"D["@H@("`@("`@(&EF("@D8V]L;W(@(3T@
M)VYO;F4G*2!["B`@("`@("`@("`@("1C;VQO<B`]("1T:&ES+3YA;&QO8V%T
M94-O;&]R*"1C;VQO<BD["B`@("`@("`@("`@("1S+3YS971,:6YE*#$L("1C
M;VQO<ELG<F5D)UTL("1C;VQO<ELG9W)E96XG72P@)&-O;&]R6R=B;'5E)UTL
M("1C;VQO<ELG86QP:&$G72D["B`@("`@("`@?0H*("`@("`@("`D9FEL;#$@
M/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D9FEL;#$I.PH@("`@("`@("1F:6QL
M,B`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"1F:6QL,BD["B`@("`@("`@)&=R
M861I96YT(#T@)FYE=R!35T9'<F%D:65N="@I.PH@("`@("`@("1G<F%D:65N
M="T^861D16YT<GDH,"XP+"`D9FEL;#%;)W)E9"==+"`D9FEL;#%;)V=R965N
M)UTL("1F:6QL,5LG8FQU92==+"`D9FEL;#%;)V%L<&AA)UTI.PH@("`@("`@
M("1G<F%D:65N="T^861D16YT<GDH,2XP+"`D9FEL;#);)W)E9"==+"`D9FEL
M;#);)V=R965N)UTL("1F:6QL,ELG8FQU92==+"`D9FEL;#);)V%L<&AA)UTI
M.PH*("`@("`@("`D9B`]("1S+3YA9&1&:6QL*"1G<F%D:65N="P@4U=&1DE,
M3%],24Y%05)?1U)!1$E%3E0I.PH@("`@("`@("1F+3YS8V%L951O*"1W:61T
M:"`O("1T:&ES+3Y?=VED=&@I.PH@("`@("`@("1F+3YM;W9E5&\H)'@L("1Y
M*3L*("`@("`@("`D<RT^<V5T4FEG:'1&:6QL*"1F*3L*"B`@("`@("`@)'9E
M<G1S6S!=(#T@87)R87DH)W@G(#T^("1X+"`G>2<@/3X@)'DI.PH@("`@("`@
M("1V97)T<ULQ72`](&%R<F%Y*"=X)R`]/B`D>"`K("1W:61T:"P@)WDG(#T^
M("1Y*3L*("`@("`@("`D=F5R='-;,ET@/2!A<G)A>2@G>"<@/3X@)'@@*R`D
M=VED=&@L("=Y)R`]/B`D>2`K("1H96EG:'0I.PH@("`@("`@("1V97)T<ULS
M72`](&%R<F%Y*"=X)R`]/B`D>"P@)WDG(#T^("1Y("L@)&AE:6=H="D["@H@
M("`@("`@("1F:7)S=%]D;VYE(#T@9F%L<V4["B`@("`@("`@9F]R96%C:"`H
M)'9E<G1S(&%S("1V97)T*2!["B`@("`@("`@("`@(&EF("@A)&9I<G-T7V1O
M;F4I('L*("`@("`@("`@("`@("`@("1S+3YM;W9E4&5N5&\H)'9E<G1;)W@G
M72P@)'9E<G1;)WDG72D["B`@("`@("`@("`@("`@("`D9FER<W1?9&]N92`]
M('1R=64["B`@("`@("`@("`@("`@("`D9FER<W1?>"`]("1V97)T6R=X)UT[
M"B`@("`@("`@("`@("`@("`D9FER<W1?>2`]("1V97)T6R=Y)UT["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)',M/F1R87=,:6YE5&\H)'9E<G1;)W@G
M72P@)'9E<G1;)WDG72D["B`@("`@("`@?0H@("`@("`@("1S+3YD<F%W3&EN
M951O*"1F:7)S=%]X+"`D9FER<W1?>2D["@H@("`@("`@(')E='5R;B`D=&AI
M<RT^7VUO=FEE+3YA9&0H)',I.PH@("`@?0H*?0H`````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]);6%G92YP:'``
M````````````````````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S4S-S0`
M,3`U,34T,S,W-3(`,#(Q,C,S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+U5T
M:6PN<&AP)SL*"B\J*@H@*B!4:&ES(&-L87-S(&1E9FEN97,@=&AE($AO<F1E
M7TEM86=E.CH@05!)+"!A;F0@86QS;R!P<F]V:61E<R!S;VUE"B`J('5T:6QI
M='D@9G5N8W1I;VYS+"!S=6-H(&%S(&=E;F5R871I;F<@:&EG:&QI9VAT<R!O
M9B!A(&-O;&]R+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]);6%G92]);6%G
M92YP:'`L=B`Q+C,Y+C$P+C$S(#(P,#8O,#$O,#$@,C$Z,C@Z,C(@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E
M("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TEM86=E"B`J+PIC;&%S
M<R!(;W)D95]);6%G92!["@H@("`@+RHJ"B`@("`@*B!#=7)R96YT(&-O;&]R
M+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M7W)G8B`]("=F9C`P,#`G.PH*("`@("\J*@H@("`@("H@0F%C:V=R;W5N9"!C
M;VQO<BX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)%]B86-K9W)O=6YD(#T@)W=H:71E)SL*"B`@("`O*BH*("`@("`J($]B
M<V5R=F5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D7V]B<V5R=F5R<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#
M87!A8FEL:71E<R!O9B!T:&ES(&1R:79E<BX*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V-A<&%B:6QI=&EE<R`](&%R<F%Y
M*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@8W5R<F5N="!I;6%G92!D871A+@H@
M("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V1A
M=&$@/2`G)SL*"B`@("`O*BH*("`@("`J(%1H92!C=7)R96YT(&EM86=E(&ED
M+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M7VED(#T@)R<["@H@("`@+RHJ"B`@("`@*B!4:&4@8W5R<F5N="!W:61T:"!O
M9B!T:&4@:6UA9V4@9&%T82X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*
M("`@("`J+PH@("`@=F%R("1?=VED=&@@/2`P.PH*("`@("\J*@H@("`@("H@
M5&AE(&-U<G)E;G0@:&5I9VAT(&]F('1H92!I;6%G92!D871A+@H@("`@("H*
M("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]H96EG:'0@
M/2`P.PH*("`@("\J*@H@("`@("H@02!D:7)E8W1O<GD@9F]R('1E;7!O<F%R
M>2!F:6QE<RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]T;7!D:7(["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1R9V(@(%1H92!B87-E(&-O
M;&]R(&9O<B!G96YE<F%T960@<&EX96QS+VEM86=E<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@2&]R9&5?26UA9V4H)'!A<F%M<RD*("`@('L*("`@("`@("`D
M=&AI<RT^7W1M<&1I<B`]("1P87)A;7-;)W1E;7`G73L*("`@("`@("!I9B`H
M:7-S970H)'!A<F%M<ULG=VED=&@G72DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]W:61T:"`]("1P87)A;7-;)W=I9'1H)UT["B`@("`@("`@?0H@("`@("`@
M(&EF("AI<W-E="@D<&%R86US6R=H96EG:'0G72DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]H96EG:'0@/2`D<&%R86US6R=H96EG:'0G73L*("`@("`@("!]
M"B`@("`@("`@:68@*"%E;7!T>2@D<&%R86US6R=R9V(G72DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]R9V(@/2`D<&%R86US6R=R9V(G73L*("`@("`@("!]
M"B`@("`@("`@)'1H:7,M/E]B86-K9W)O=6YD(#T@:7-S970H)'!A<F%M<ULG
M8F%C:V=R;W5N9"==*2`_("1P87)A;7-;)V)A8VMG<F]U;F0G72`Z("=W:&ET
M92<["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T0V%P86)I;&ET:65S*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/E]C87!A8FEL:71I97,["B`@("!]
M"@H@("`@9G5N8W1I;VX@:&%S0V%P86)I;&ET>2@D8V%P86)I;&ET>2D*("`@
M('L*("`@("`@("!R971U<FX@:6Y?87)R87DH)&-A<&%B:6QI='DL("1T:&ES
M+3Y?8V%P86)I;&ET:65S*3L*("`@('T*"B`@("!F=6YC=&EO;B!G971,:6YK
M*"1U<FPL("1T:71L92`]("<G*0H@("`@>PH@("`@("`@(')E='5R;B!(;W)D
M93HZ:6UG*"1U<FPL("1T:71L92P@)R<L("<G*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($=E;F5R871E(&EM86=E(&AE861E<G,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&AE861E<G,H*0H@("`@>PH@("`@("`@(&AE861E<B@G0V]N=&5N
M="UT>7!E.B`G("X@)'1H:7,M/F=E=$-O;G1E;G14>7!E*"DI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0V%L8W5L871E(&$@;&EG:'1E<B`H;W(@9&%R:V5R
M*2!V97)S:6]N(&]F(&$@8V]L;W(N"B`@("`@*@H@("`@("H@0'-T871I8PH@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R("`@06X@2%1-3"!C
M;VQO<BP@92YG+CH@(V9F9F9C8RX*("`@("`J($!P87)A;2!S=')I;F<@)&9A
M8W1O<B`@5$]$3PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!!(&UO
M9&EF:65D($A434P@8V]L;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO9&EF
M>4-O;&]R*"1C;VQO<BP@)&9A8W1O<B`](#!X,3$I"B`@("!["B`@("`@("`@
M)'(@/2!H97AD96,H<W5B<W1R*"1C;VQO<BP@,2P@,BDI("L@)&9A8W1O<CL*
M("`@("`@("`D9R`](&AE>&1E8RAS=6)S='(H)&-O;&]R+"`S+"`R*2D@*R`D
M9F%C=&]R.PH@("`@("`@("1B(#T@:&5X9&5C*'-U8G-T<B@D8V]L;W(L(#4L
M(#(I*2`K("1F86-T;W(["@H@("`@("`@("1R(#T@;6EN*&UA>"@D<BP@,"DL
M(#(U-2D["B`@("`@("`@)&<@/2!M:6XH;6%X*"1G+"`P*2P@,C4U*3L*("`@
M("`@("`D8B`](&UI;BAM87@H)&(L(#`I+"`R-34I.PH*("`@("`@("!R971U
M<FX@)R,G("X@<W1R7W!A9"AD96-H97@H)'(I+"`R+"`G,"<L(%-44E]0041?
M3$5&5"D@+B!S=')?<&%D*&1E8VAE>"@D9RDL(#(L("<P)RP@4U127U!!1%],
M1494*2`N('-T<E]P860H9&5C:&5X*"1B*2P@,BP@)S`G+"!35%)?4$%$7TQ%
M1E0I.PH@("`@?0H*("`@("\J*@H@("`@("H@0V%L8W5L871E(&$@;6]R92!I
M;G1E;G-E('9E<G-I;VX@;V8@82!C;VQO<BX*("`@("`J"B`@("`@*B!`<W1A
M=&EC"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]L;W(@("!!;B!(
M5$U,(&-O;&]R+"!E+F<N.B`C9F9F9F-C+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9F%C=&]R("!43T1/"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M($$@;6]R92!I;G1E;G-E($A434P@8V]L;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&UO<F5);G1E;G-E0V]L;W(H)&-O;&]R+"`D9F%C=&]R(#T@,'@Q,2D*
M("`@('L*("`@("`@("`D<B`](&AE>&1E8RAS=6)S='(H)&-O;&]R+"`Q+"`R
M*2D["B`@("`@("`@)&<@/2!H97AD96,H<W5B<W1R*"1C;VQO<BP@,RP@,BDI
M.PH@("`@("`@("1B(#T@:&5X9&5C*'-U8G-T<B@D8V]L;W(L(#4L(#(I*3L*
M"B`@("`@("`@:68@*"1R(#X]("1G("8F("1R(#X]("1B*2!["B`@("`@("`@
M("`@("1G(#T@)&<@+R`D<CL*("`@("`@("`@("`@)&(@/2`D8B`O("1R.PH*
M("`@("`@("`@("`@)'(@*ST@)&9A8W1O<CL*("`@("`@("`@("`@)&<@/2!F
M;&]O<B@D9R`J("1R*3L*("`@("`@("`@("`@)&(@/2!F;&]O<B@D8B`J("1R
M*3L*("`@("`@("!](&5L<V5I9B`H)&<@/CT@)'(@)B8@)&<@/CT@)&(I('L*
M("`@("`@("`@("`@)'(@/2`D<B`O("1G.PH@("`@("`@("`@("`D8B`]("1B
M("\@)&<["@H@("`@("`@("`@("`D9R`K/2`D9F%C=&]R.PH@("`@("`@("`@
M("`D<B`](&9L;V]R*"1R("H@)&<I.PH@("`@("`@("`@("`D8B`](&9L;V]R
M*"1B("H@)&<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R(#T@
M)'(@+R`D8CL*("`@("`@("`@("`@)&<@/2`D9R`O("1B.PH*("`@("`@("`@
M("`@)&(@*ST@)&9A8W1O<CL*("`@("`@("`@("`@)'(@/2!F;&]O<B@D<B`J
M("1B*3L*("`@("`@("`@("`@)&<@/2!F;&]O<B@D9R`J("1B*3L*("`@("`@
M("!]"@H@("`@("`@("1R(#T@;6EN*&UA>"@D<BP@,"DL(#(U-2D["B`@("`@
M("`@)&<@/2!M:6XH;6%X*"1G+"`P*2P@,C4U*3L*("`@("`@("`D8B`](&UI
M;BAM87@H)&(L(#`I+"`R-34I.PH*("`@("`@("!R971U<FX@)R,G("X@<W1R
M7W!A9"AD96-H97@H)'(I+"`R+"`G,"<L(%-44E]0041?3$5&5"D@+B!S=')?
M<&%D*&1E8VAE>"@D9RDL(#(L("<P)RP@4U127U!!1%],1494*2`N('-T<E]P
M860H9&5C:&5X*"1B*2P@,BP@)S`G+"!35%)?4$%$7TQ%1E0I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8G)I9VAT;F5S<R!O9B!A(&-O
M;&]R+@H@("`@("H*("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1C;VQO<B`@06X@2%1-3"!C;VQO<BP@92YG+CH@(V9F9F9C
M8RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!B<FEG:'1N
M97-S(&]N(&$@<V-A;&4@;V8@,"!T;R`R-34N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&)R:6=H=&YE<W,H)&-O;&]R*0H@("`@>PH@("`@("`@("1R(#T@:&5X
M9&5C*'-U8G-T<B@D8V]L;W(L(#$L(#(I*3L*("`@("`@("`D9R`](&AE>&1E
M8RAS=6)S='(H)&-O;&]R+"`S+"`R*2D["B`@("`@("`@)&(@/2!H97AD96,H
M<W5B<W1R*"1C;VQO<BP@-2P@,BDI.PH*("`@("`@("!R971U<FX@<F]U;F0H
M*"@D<B`J(#(Y.2D@*R`H)&<@*B`U.#<I("L@*"1B("H@,3$T*2D@+R`Q,#`P
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!G97121T(H)&-O;&]R;F%M92D*("`@
M('L*("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G
M+TEM86=E+W)G8BYP:'`G.PH@("`@("`@(')E='5R;B!I<W-E="@D1TQ/0D%,
M4ULG:&]R9&5?:6UA9V5?<F=B7V-O;&]R<R==6R1C;VQO<FYA;65=*2`_"B`@
M("`@("`@("`@("1'3$]"04Q36R=H;W)D95]I;6%G95]R9V)?8V]L;W)S)UU;
M)&-O;&]R;F%M95T@.@H@("`@("`@("`@("!A<G)A>2@P+"`P+"`P*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!G971(97A#;VQO<B@D8V]L;W)N86UE*0H@("`@
M>PH@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O
M26UA9V4O<F=B+G!H<"<["B`@("`@("`@:68@*&ES<V5T*"1'3$]"04Q36R=H
M;W)D95]I;6%G95]R9V)?8V]L;W)S)UU;)&-O;&]R;F%M95TI*2!["B`@("`@
M("`@("`@(&QI<W0H)'(L("1G+"`D8BD@/2`D1TQ/0D%,4ULG:&]R9&5?:6UA
M9V5?<F=B7V-O;&]R<R==6R1C;VQO<FYA;65=.PH@("`@("`@("`@("!R971U
M<FX@)R,G("X@<W1R7W!A9"AD96-H97@H;6EN*"1R+"`R-34I*2P@,BP@)S`G
M+"!35%)?4$%$7TQ%1E0I("X@<W1R7W!A9"AD96-H97@H;6EN*"1G+"`R-34I
M*2P@,BP@)S`G+"!35%)?4$%$7TQ%1E0I("X@<W1R7W!A9"AD96-H97@H;6EN
M*"1B+"`R-34I*2P@,BP@)S`G+"!35%)?4$%$7TQ%1E0I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B`G8FQA8VLG.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($1R87<@82!S:&%P960@<&]I;G0@870@
M=&AE('-P96-I9FEE9"`H>"QY*2!P;VEN="X@57-E9G5L(&9O<@H@("`@("H@
M<V-A='1E<B!D:6%G<F%M<RP@9&5B=6<@<&]I;G1S+"!E=&,N($1R87=S('-Q
M=6%R97,L(&-I<F-L97,L"B`@("`@*B!D:6%M;VYD<RP@86YD('1R:6%N9VQE
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@5&AE('@@
M8V]O<F1I;F%T92!O9B!T:&4@<&]I;G0@=&\@8G)U<V@N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D>2`@("`@5&AE('D@8V]O<F1I;F%T92!O9B!T:&4@<&]I
M;G0@=&\@8G)U<V@N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VQO<B`@5&AE
M(&-O;&]R('1O(&)R=7-H('1H92!P;VEN="!W:71H+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<VAA<&4@(%=H870@8G)U<V@@=&\@=7-E/R!$969A=6QT<R!T
M;R!A('-Q=6%R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8G)U<V@H)'@L("1Y
M+"`D8V]L;W(@/2`G8FQA8VLG+"`D<VAA<&4@/2`G<W%U87)E)RD*("`@('L*
M("`@("`@("!S=VET8V@@*"1S:&%P92D@>PH@("`@("`@(&-A<V4@)W1R:6%N
M9VQE)SH*("`@("`@("`@("`@)'9E<G1S6S!=(#T@87)R87DH)W@G(#T^("1X
M("L@,RP@)WDG(#T^("1Y("L@,RD["B`@("`@("`@("`@("1V97)T<ULQ72`]
M(&%R<F%Y*"=X)R`]/B`D>"P@)WDG(#T^("1Y("T@,RD["B`@("`@("`@("`@
M("1V97)T<ULR72`](&%R<F%Y*"=X)R`]/B`D>"`M(#,L("=Y)R`]/B`D>2`K
M(#,I.PH@("`@("`@("`@("`D=&AI<RT^<&]L>6=O;B@D=F5R=',L("1C;VQO
M<BP@)&-O;&]R*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@
M)V-I<F-L92<Z"B`@("`@("`@("`@("1T:&ES+3YC:7)C;&4H)'@L("1Y+"`S
M+"`D8V]L;W(L("1C;VQO<BD["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E("=D:6%M;VYD)SH*("`@("`@("`@("`@)'9E<G1S6S!=(#T@87)R
M87DH)W@G(#T^("1X("T@,RP@)WDG(#T^("1Y*3L*("`@("`@("`@("`@)'9E
M<G1S6S%=(#T@87)R87DH)W@G(#T^("1X+"`G>2<@/3X@)'D@*R`S*3L*("`@
M("`@("`@("`@)'9E<G1S6S)=(#T@87)R87DH)W@G(#T^("1X("L@,RP@)WDG
M(#T^("1Y*3L*("`@("`@("`@("`@)'9E<G1S6S-=(#T@87)R87DH)W@G(#T^
M("1X+"`G>2<@/3X@)'D@+2`S*3L*("`@("`@("`@("`@)'1H:7,M/G!O;'EG
M;VXH)'9E<G1S+"`D8V]L;W(L("1C;VQO<BD["B`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("!C87-E("=S<75A<F4G.@H@("`@("`@(&1E9F%U;'0Z"B`@
M("`@("`@("`@("1T:&ES+3YR96-T86YG;&4H)'@@+2`R+"`D>2`M(#(L(#0L
M(#0L("1C;VQO<BP@)&-O;&]R*3L*("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@061D(&%N(&]B<V5R=F5R('1O
M('1H:7,@:6UA9V4N(%1H92!O8G-E<G9E<B!W:6QL(&)E(&YO=&EF:65D"B`@
M("`@*B!W:&5N('1H92!I;6%G92=S(&-H86YG97,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%D9$]B<V5R=F5R*"1M971H;V0L("8D;V)J96-T*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?;V)S97)V97)S6UT@/2!A<G)A>2@D;65T:&]D+"`F
M)&]B:F5C="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!,970@;V)S97)V97)S
M(&MN;W<@=&AA="!S;VUE=&AI;F<@:&%P<&5N960@=V]R=&@@86-T:6YG(&]N
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!N;W1I9GE/8G-E<G9E<G,H*0H@("`@
M>PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1T:&ES+3Y?;V)S
M97)V97)S*3L@*RLD:2D@>PH@("`@("`@("`@("`D;V)J(#T@)B1T:&ES+3Y?
M;V)S97)V97)S6R1I75LQ73L*("`@("`@("`@("`@)&UE=&AO9"`]("1T:&ES
M+3Y?;V)S97)V97)S6R1I75LP73L*("`@("`@("`@("`@)&]B:BT^)&UE=&AO
M9"@D=&AI<RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5S
M970@=&AE(&EM86=E(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E<V5T
M*"D*("`@('L*("`@("`@("`D=&AI<RT^7V1A=&$@/2`G)SL*("`@("`@("`D
M=&AI<RT^7VED(#T@)R<["B`@("`@("`@)'1H:7,M/E]W:61T:"`](&YU;&P[
M"B`@("`@("`@)'1H:7,M/E]H96EG:'0@/2!N=6QL.PH@("`@("`@("1T:&ES
M+3Y?8F%C:V=R;W5N9"`]("=W:&ET92<["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!'970@=&AE(&AE:6=H="!A;F0@=VED=&@@;V8@=&AE(&-U<G)E;G0@:6UA
M9V4@9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!H87-H
M('=I=&@@)W=I9'1H)R!C;VYT86EN:6YG('1H92!W:61T:"P*("`@("`J("`@
M("`@("`@("`@("`@("=H96EG:'0G(&-O;G1A:6YI;F<@=&AE(&AE:6=H="!O
M9B!T:&4@:6UA9V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1I;65N<VEO
M;G,H*0H@("`@>PH@("`@("`@("1T;7`@/2`D=&AI<RT^=&]&:6QE*"D["B`@
M("`@("`@)&1E=&%I;',@/2!`9V5T:6UA9V5S:7IE*"1T;7`I.PH@("`@("`@
M('5N;&EN:R@D=&UP*3L*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"=W:61T:"<@
M/3X@)&1E=&%I;'-;,%TL"B`@("`@("`@("`@("`@("`@("`@("=H96EG:'0G
M(#T^("1D971A:6QS6S%=*3L*("`@('T*"B`@("`O*BH*("`@("`J($QO860@
M=&AE(&EM86=E(&1A=&$@9G)O;2!A('-T<FEN9RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1I9"`@("`@("`@("!!;B!A<F)I=')A<GD@:60@9F]R
M('1H92!I;6%G92X*("`@("`J($!P87)A;2!S=')I;F<@)&EM86=E7V1A=&$@
M(%1H92!D871A('1O('5S92!F;W(@=&AE(&EM86=E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!L;V%D4W1R:6YG*"1I9"P@)&EM86=E7V1A=&$I"B`@("!["B`@
M("`@("`@:68@*"1I9"`A/2`D=&AI<RT^7VED*2!["B`@("`@("`@("`@("1T
M:&ES+3YR97-E="@I.PH@("`@("`@("`@("`D=&AI<RT^7V1A=&$@/2`D:6UA
M9V5?9&%T83L*("`@("`@("`@("`@)'1H:7,M/E]I9"`]("1I9#L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!,;V%D('1H92!I;6%G92!D871A
M(&9R;VT@82!F:6QE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I
M;&5N86UE("!4:&4@9G5L;"!P871H(&%N9"!F:6QE;F%M92!T;R!T:&4@9FEL
M92!T;R!L;V%D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE
M(&EM86=E(&1A=&$@9G)O;2X@5&AE(&9I;&5N86UE('=I;&P@86QS;R!B90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('5S960@9F]R('1H92!I
M;6%G92!I9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!014%2($5R
M<F]R(&EF(&9I;&4@9&]E<R!N;W0@97AI<W0@;W(@8V]U;&0@;F]T(&)E(&QO
M861E9`H@("`@("H@("`@("`@("`@("`@("`@;W1H97)W:7-E($Y53$P@:68@
M<W5C8V5S<V9U;"!O<B!A;')E861Y(&QO861E9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@;&]A9$9I;&4H)&9I;&5N86UE*0H@("`@>PH@("`@("`@(&EF("@D
M9FEL96YA;64@(3T@)'1H:7,M/E]I9"D@>PH@("`@("`@("`@("`D=&AI<RT^
M<F5S970H*3L*("`@("`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D9FEL96YA
M;64I*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G5&AE(&EM86=E(&9I;&4@)R`N("1I;6%G92`N("<@9&]E<R!N;W0@97AI
M<W0N)RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1T:&ES+3Y?
M9&%T82`](&9I;&5?9V5T7V-O;G1E;G1S*"1F:6QE;F%M92DI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?:60@/2`D9FEL96YA;64["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G0V]U;&0@;F]T(&QO860@=&AE(&EM86=E(&9I;&4@)R`N("1I;6%G
M92D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I
M;VX@=&]&:6QE*"1D871A(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1M<"`]
M(%5T:6PZ.F=E=%1E;7!&:6QE*"=I;6<G+"!F86QS92P@)'1H:7,M/E]T;7!D
M:7(I.PH@("`@("`@("1F<"`]($!F;W!E;B@D=&UP+"`G=V(G*3L*("`@("`@
M("!F=W)I=&4H)&9P+"`D9&%T82`_("1D871A(#H@)'1H:7,M/G)A=R@I*3L*
M("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("!R971U<FX@)'1M<#L*("`@
M('T*"B`@("`O*BH*("`@("`J($1I<W!L87D@=&AE(&-U<G)E;G0@:6UA9V4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&1I<W!L87DH*0H@("`@>PH@("`@("`@
M("1T:&ES+3YH96%D97)S*"D["B`@("`@("`@96-H;R`D=&AI<RT^<F%W*"D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!R87<@9&%T82!F
M;W(@=&AI<R!I;6%G92X*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M8V]N=F5R="`@268@=')U92P@=&AE(&EM86=E(&1A=&$@=VEL;"!B92!R971U
M<FYE9"!I;B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T
M87)G970@9F]R;6%T+"!I;F1E<&5N9&5N=&QY(&9R;VT@86YY(&EM86=E"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@;W!E<F%T:6]N<RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')A=R!I;6%G92!D871A
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R87<H)&-O;G9E<G0@/2!F86QS92D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]D871A.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1V5T(&%N('@L>2!P86ER(&]N(&-I<F-L92P@87-S=6UI
M;F<@8V5N=&5R(&ES(#`L,"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@9&]U8FQE("1D96=R965S("`@(%1H
M92!D96=R965S(&]F(&%R8R!T;R!G970@=&AE('!O:6YT(&9O<BX*("`@("`J
M($!P87)A;2!I;G1E9V5R("1D:6%M971E<B`@5&AE(&1I86UE=&5R(&]F('1H
M92!C:7)C;&4N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@*'@@8V]O
M<F1I;F%T92P@>2!C;V]R9&EN871E*2!O9B!T:&4@<&]I;G0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]C:7)C;&50;VEN="@D9&5G<F5E<RP@)&1I86UE=&5R
M*0H@("`@>PH@("`@("`@("\O($%V;VED('!R;V)L96US('=I=&@@9&]U8FQE
M<RX*("`@("`@("`D9&5G<F5E<R`K/2`P+C`P,#$["@H@("`@("`@(')E='5R
M;B!A<G)A>2AC;W,H9&5G,G)A9"@D9&5G<F5E<RDI("H@*"1D:6%M971E<B`O
M(#(I+`H@("`@("`@("`@("`@("`@("`@("!S:6XH9&5G,G)A9"@D9&5G<F5E
M<RDI("H@*"1D:6%M971E<B`O(#(I*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($=E="!P;VEN="!C;V]R9&EN871E<R!A="!T:&4@;&EM:71S(&]F(&%N(&%R
M8RX@3VYL>2!V86QI9"!F;W(*("`@("`J(&%N9VQE<R`H)&5N9"`M("1S=&%R
M="D@/#T@-#4@9&5G<F5E<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<B`@("`@(%1H92!R
M861I=7,@;V8@=&AE(&%R8RX*("`@("`J($!P87)A;2!I;G1E9V5R("1S=&%R
M="`@5&AE('-T87)T:6YG(&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&5N9"`@("!4:&4@96YD:6YG(&%N9VQE+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@(%1H92!S=&%R="!P;VEN="P@96YD('!O:6YT+"!A;F0@86YC
M:&]R('!O:6YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?87)C4&]I;G1S*"1R
M+"`D<W1A<G0L("1E;F0I"B`@("!["B`@("`@("`@+R\@4W1A<G0@<&]I;G0N
M"B`@("`@("`@)'!T<ULG>#$G72`]("1R("H@8V]S*&1E9S)R860H)'-T87)T
M*2D["B`@("`@("`@)'!T<ULG>3$G72`]("1R("H@<VEN*&1E9S)R860H)'-T
M87)T*2D["@H@("`@("`@("\O($5N9"!P;VEN="X*("`@("`@("`D<'1S6R=X
M,B==(#T@)'(@*B!C;W,H9&5G,G)A9"@D96YD*2D["B`@("`@("`@)'!T<ULG
M>3(G72`]("1R("H@<VEN*&1E9S)R860H)&5N9"DI.PH*("`@("`@("`O+R!!
M;F-H;W(@<&]I;G0N"B`@("`@("`@)&$S(#T@*"1S=&%R="`K("1E;F0I("\@
M,CL*("`@("`@("`D<C,@/2`D<B`O(&-O<RAD96<R<F%D*"@D96YD("T@)'-T
M87)T*2`O(#(I*3L*("`@("`@("`D<'1S6R=X,R==(#T@)'(S("H@8V]S*&1E
M9S)R860H)&$S*2D["B`@("`@("`@)'!T<ULG>3,G72`]("1R,R`J('-I;BAD
M96<R<F%D*"1A,RDI.PH*("`@("`@("!R971U<FX@)'!T<SL*("`@('T*"B`@
M("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(&-O;F-R971E($AO
M<F1E7TEM86=E(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&UI>&5D("1D<FEV97(@(%1H92!T>7!E(&]F(&-O;F-R
M971E($AO<F1E7TEM86=E('-U8F-L87-S('1O"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N+B!4:&ES(&ES(&)A<V5D(&]N('1H92!S=&]R
M86=E(&1R:79E<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("@D9')I
M=F5R*2X@5&AE(&-O9&4@:7,@9'EN86UI8V%L;'D@:6YC;'5D960N($EF"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@)&1R:79E<B!I<R!A;B!A<G)A
M>2P@=&AE;B!W92!W:6QL(&QO;VL@:6X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`D9')I=F5R6S!=+VQI8B]);6%G92\@9F]R('1H92!S=6)C;&%S
M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EM<&QE;65N=&%T:6]N
M(&YA;65D("1D<FEV97);,5TN<&AP+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I
M9W5R871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C;VYN
M96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@
M("H*("`@("`J($!R971U<FX@2&]R9&5?26UA9V5\8F]O;&5A;B`@5&AE(&YE
M=VQY(&-R96%T960@8V]N8W)E=&4@2&]R9&5?26UA9V4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:6YS=&%N8V4L(&]R(&9A;'-E(&]N
M(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D9')I
M=F5R+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H:7-?
M87)R87DH)&1R:79E<BDI('L*("`@("`@("`@("`@;&ES="@D87!P+"`D9')I
M=F5R*2`]("1D<FEV97(["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y
M*"1A<'`I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`D1TQ/0D%,4ULG
M<F5G:7-T<GDG72T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]L:6(O26UA
M9V4O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?2!E;'-E:68@*$!F
M:6QE7V5X:7-T<RAD:7)N86UE*%]?1DE,15]?*2`N("<O26UA9V4O)R`N("1D
M<FEV97(@+B`G+G!H<"<I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92!D
M:7)N86UE*%]?1DE,15]?*2`N("<O26UA9V4O)R`N("1D<FEV97(@+B`G+G!H
M<"<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@0&EN8VQU9&5?;VYC
M92`G2&]R9&4O26UA9V4O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@
M?0H@("`@("`@("1C;&%S<R`]("=(;W)D95]);6%G95\G("X@)&1R:79E<CL*
M("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@
M("`@)&EM86=E(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&EM86=E(#T@4$5!4CHZ<F%I<V5%<G)O<B@G
M0VQA<W,@9&5F:6YI=&EO;B!O9B`G("X@)&-L87-S("X@)R!N;W0@9F]U;F0N
M)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EM86=E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@<F5F97)E;F-E
M('1O(&$@8V]N8W)E=&4@2&]R9&5?26UA9V4@:6YS=&%N8V4@8F%S960*("`@
M("`J(&]N("1D<FEV97(N($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS
M=&%N8V4@:68@;F\@2&]R9&5?26UA9V4*("`@("`J(&EN<W1A;F-E('=I=&@@
M=&AE('-A;64@<&%R86UE=&5R<R!C=7)R96YT;'D@97AI<W1S+@H@("`@("H*
M("`@("`J(%1H:7,@<VAO=6QD(&)E('5S960@:68@;75L=&EP;&4@='EP97,@
M;V8@:6UA9V4@<F5N9&5R97)S("AA;F0L('1H=7,L"B`@("`@*B!M=6QT:7!L
M92!(;W)D95]);6%G92!I;G-T86YC97,I(&%R92!R97%U:7)E9"X*("`@("`J
M"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z("1V87(@
M/2`F2&]R9&5?26UA9V4Z.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A
M<F%M(&UI>&5D("1D<FEV97(@(%1H92!T>7!E(&]F(&-O;F-R971E($AO<F1E
M7TEM86=E('-U8F-L87-S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N+B!4:&ES(&ES(&)A<V5D(&]N('1H92!S=&]R86=E(&1R:79E
M<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("@D9')I=F5R*2X@5&AE
M(&-O9&4@:7,@9'EN86UI8V%L;'D@:6YC;'5D960N($EF"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@)&1R:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W
M92!W:6QL(&QO;VL@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`D
M9')I=F5R6S!=+VQI8B]);6%G92\@9F]R('1H92!S=6)C;&%S<PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@(&EM<&QE;65N=&%T:6]N(&YA;65D("1D
M<FEV97);,5TN<&AP+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@
M:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@
M;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T:6]N('!A
M<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J
M($!R971U<FX@2&]R9&5?26UA9V5\8F]O;&5A;B`@5&AE(&-O;F-R971E($AO
M<F1E7TEM86=E(')E9F5R96YC92P@;W(*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@9F%L<V4@;VX@86X@97)R;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9S:6YG;&5T;VXH)&1R:79E<BP@)'!A<F%M<R`](&%R<F%Y
M*"DI"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC97,["B`@("`@("`@
M:68@*"%I<W-E="@D:6YS=&%N8V5S*2D@>PH@("`@("`@("`@("`D:6YS=&%N
M8V5S(#T@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@("1S:6=N871U<F4@
M/2!S97)I86QI>F4H87)R87DH)&1R:79E<BP@)'!A<F%M<RDI.PH@("`@("`@
M(&EF("@A:7-S970H)&EN<W1A;F-E<ULD<VEG;F%T=7)E72DI('L*("`@("`@
M("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`]("9(;W)D95]);6%G93HZ
M9F%C=&]R>2@D9')I=F5R+"`D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+TE-05`O````````````````````````
M```````````````````````````````````````````````````````P,#`P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<T-@`P
M,C`R,34`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O24U!4"]!
M0TPO````````````````````````````````````````````````````````
M`````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-3$U-#,S-S0V`#`R,#8Q-``@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<```````````````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P-#(T-C<`,3`U,34T,S,W-#8`,#(R-#,T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!#;VYT86EN<R!F=6YC=&EO;G,@<F5L871E9"!T;R!M86YA9VEN9R!!
M8V-E<W,@0V]N=')O;"!,:7-T<R!O;B!A;B!)34%0"B`J('-E<G9E<B!U<VEN
M9R!21D,@,C`X-BX*("H*("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@
M*B`@("=U<V5R;F%M92<@(%1H92!U<V5R;F%M92!F;W(@=&AE('-E<G9E<B!C
M;VYN96-T:6]N"B`J("`@)W!A<W-W;W)D)R`@5&AE('!A<W-W;W)D(&9O<B!T
M:&4@<V5R=F5R(&-O;FYE8W1I;VX*("H@("`G:&]S='-P96,G("!4:&4@:&]S
M=&YA;64@;W(@25`@861D<F5S<R!O9B!T:&4@<V5R=F5R+@H@*B`@("`@("`@
M("`@("`@($1%1D%53%0Z("=L;V-A;&AO<W0G"B`J("`@)W!O<G0G("`@("`@
M5&AE('-E<G9E<B!P;W)T('1O('=H:6-H('=E('=I;&P@8V]N;F5C="X*("H@
M("`@("`@("`@("`@("!)34%0(&ES(&=E;F5R86QL>2`Q-#,L('=H:6QE($E-
M05`M4U-,(&ES(&=E;F5R86QL>2`Y.3,N"B`J("`@("`@("`@("`@("`@1$5&
M055,5#H@,30S"B`J("`@)W!R;W1O8V]L)R`@5&AE(&-O;FYE8W1I;VX@<')O
M=&]C;VP@*&4N9RX@)VEM87`G+"`G<&]P,R<L("=N;G1P)RDN"B`J("`@("`@
M("`@("`@("`@4')O=&]C;VP@:7,@;VYE(&]F("=I;6%P+VYO=&QS)R`H;W(@
M;VYL>2`G:6UA<"<@:68@>6]U"B`J("`@("`@("`@("`@("`@:&%V92!A(&,M
M8VQI96YT('9E<G-I;VX@,C`P,&,@;W(@;VQD97(I+"`G:6UA<"]S<VPG+"!O
M<@H@*B`@("`@("`@("`@("`@("=I;6%P+W-S;"]N;W9A;&ED871E+6-E<G0G
M("AF;W(@82!S96QF+7-I9VYE9"!C97)T:69I8V%T92DN"B`J("`@("`@("`@
M("`@("`@1$5&055,5#H@)VEM87`G/"]P<F4^"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`L=B`Q+C8N."XQ,B`R
M,#`V+S`W+S(V(#$Y.C,T.C0U(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`S+3(P,#8@0VAR:7,@2&%S=&EE(#QI;7!`;V%K+7=O;V0N8V\N=6L^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:')I<R!(87-T:64@/&EM
M<$!O86LM=V]O9"YC;RYU:SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P
M86-K86=E($AO<F1E7TE-05`*("HO"F-L87-S($E-05!?04-,7W)F8S(P.#8@
M97AT96YD<R!)34%07T%#3"!["@H@("`@+RHJ"B`@("`@*B!)34%0(')E<V]U
M<F-E+@H@("`@("H*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@
M=F%R("1?:6UA<#L*"B`@("`O*BH*("`@("`J($QI<W0@;V8@<V5R=F5R)W,@
M8V%P86)I;&ET:65S+"!O=71P=70@;V8@0T%004))3$E462!C;VUM86YD+B!&
M;W)M871E9`H@("`@("H@87,@82!H87-H"B`@("`@*B`\8V]D93X*("`@("`J
M(&%R<F%Y*`H@("`@("H@("`@("IC87!A8FEL:71Y*B`]/B`Q"B`@("`@*B`I
M"B`@("`@*B`\+V-O9&4^"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)%]C87!S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("!!;GD@861D:71I;VYA;"!P87)A;65T97)S('1H:7,@9')I=F5R(&UA
M>2!N965D+@H@("`@("HO"B`@("!F=6YC=&EO;B!)34%07T%#3%]R9F,R,#@V
M*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%R
M86US(#T@87)R87E?;65R9V4H87)R87DH)VAO<W1S<&5C)R`]/B`G;&]C86QH
M;W-T)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=P;W)T)R`]/B`Q-#,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<')O=&]C;VPG(#T^("=I;6%P)RDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US*3L*"B`@
M("`@("`@)'1H:7,M/E]C87!S(#T@)'1H:7,M/E]G971#87!A8FEL:71Y*"D[
M"B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]C87!S+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?97)R;W(@/2`D=&AI<RT^7V-A<',[
M"B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@(&EF("AS
M=6)S='(H)'1H:7,M/E]P87)A;7-;)W!R;W1O8V]L)UTL(#`L(#0I("$]("=I
M;6%P)RD@>PH@("`@("`@("`@("`O*B!.;R!P;VEN="!I;B!G;VEN9R!A;GD@
M9G5R=&AE<B!I9B!I="=S(&YO="!A;B!)34%0('-E<G9E<BX@*B\*("`@("`@
M("`@("`@)'1H:7,M/E]E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H7R@B3VYL
M>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB*2D["B`@
M("`@("`@("`@("1T:&ES+3Y?<W5P<&]R=&5D(#T@9F%L<V4["B`@("`@("`@
M?2!E;'-E:68@*"%I<W-E="@D=&AI<RT^7V-A<'-;)V%C;"==*2D@>PH@("`@
M("`@("`@("`O*B!)9B!W92!C;W5L9&XG="!G970@=&AE('-E<G9E<B=S(&-A
M<&%B:6QI='DL('=E)VQL(&%S<W5M92!!0TP@:7,*("`@("`@("`@("`@("`@
M;F]T('-U<'!O<G1E9"!F;W(@;F]W+B`J+PH@("`@("`@("`@("`D=&AI<RT^
M7W-U<'!O<G1E9"`](&9A;'-E.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1T:&ES+3Y?<W5P<&]R=&5D(#T@=')U93L*("`@("`@("!]"@H@("`@
M("`@("1T:&ES+3Y?<')O=&5C=&5D(#T@87)R87DH)'1H:7,M/E]P87)A;7-;
M)W5S97)N86UE)UTI.PH*("`@("`@("`D=&AI<RT^7W)I9VAT<TQI<W0@/2!A
M<G)A>2@*("`@("`@("`@("`@("=L)R`]/B!?*"),:7-T("T@=7-E<B!C86X@
M<V5E('1H92!F;VQD97(B*2P*("`@("`@("`@("`@("=R)R`]/B!?*")296%D
M(&UE<W-A9V5S(BDL"B`@("`@("`@("`@("`G<R<@/3X@7R@B36%R:R!W:71H
M(%-E96XO56YS965N(&9L86=S(BDL"B`@("`@("`@("`@("`G=R<@/3X@7R@B
M36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E
M9"DB*2P*("`@("`@("`@("`@("=I)R`]/B!?*"));G-E<G0@;65S<V%G97,B
M*2P*("`@("`@("`@("`@("=P)R`]/B!?*")0;W-T('1O('1H:7,@9F]L9&5R
M("AN;W0@96YF;W)C960@8GD@24U!4"DB*2P*("`@("`@("`@("`@("=C)R`]
M/B!?*")#<F5A=&4@<W5B(&9O;&1E<G,B*2P*("`@("`@("`@("`@("=D)R`]
M/B!?*")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(BDL"B`@("`@("`@("`@
M("`G82<@/3X@7R@B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@
M;W1H97(@=7-E<G,B*0H@("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@
M7V-O;FYE8W0H*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/E]I;6%P*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?:6UA<"`]($!I;6%P7V]P96XH<W!R:6YT
M9B@G>R5S.B5D+R5S?2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=P;W)T)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<')O
M=&]C;VPG72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!A<W-W
M;W)D)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M3U!?2$%,1D]014XI.PH@("`@("`@("`@("!I9B`H(21T:&ES+3Y?:6UA<"D@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]I;6%P(#T@4$5!4CHZ<F%I<V5%
M<G)O<BAI;6%P7VQA<W1?97)R;W(H*2D["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("%I<U]A*"1T:&ES+3Y?:6UA<"P@)U!%05)?
M17)R;W(G*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE($%#3"!O
M;B!A;B!)34%0('-E<G9E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1F;VQD97(@("`@("!4:&4@9F]L9&5R(&]N('=H:6-H('1O(&5D:70@=&AE
M($%#3"X*("`@("`J($!P87)A;2!S=')I;F<@)'-H87)E7W5S97(@(%1H92!U
M<V5R('1O(&=R86YT(')I9VAT<R!T;RX*("`@("`J($!P87)A;2!A<G)A>2`D
M86-L("`@("`@("`@($%N(&%R<F%Y+"!T:&4@:V5Y<R!O9B!W:&EC:"!A<F4@
M=&AE(')I9VAT<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8F4@9W)A;G1E9"`H<V5E(%)&0R`R,#@V*2X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,L(%!%05)?17)R;W(@;VX@
M9F%I;'5R92!O<B!I9B!S97)V97(*("`@("`J("`@("`@("`@("`@("`@(&1O
M97-N)W0@<W5P<&]R="!!0TQS+@H@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A
M=&5!0TPH)&9O;&1E<BP@)'-H87)E7W5S97(L("1A8VPI"B`@("!["B`@("`@
M("`@:68@*"$D=&AI<RT^7V-O;FYE8W0H*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]I;6%P.PH@("`@("`@('T*"B`@("`@("`@)&%C;%]S='(@
M/2`G)SL*("`@("`@("!I9B`H(65M<'1Y*"1A8VPI*2!["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1A8VP@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@
M("`@("`D86-L7W-T<B`N/2`D:V5Y.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("`O*B!#86XG="!C86QL('1H:7,@87,@0&EM87!?<V5T86-L
M*"D@87,@<W5P<')E<W-I;F<@97)R;W)S(&QE861S('1O"B`@("`@("`@("`@
M:6UA<%]E<G)O<G,H*2!R971U<FYI;F<@;F]T:&EN9RX@*B\*("`@("`@("`D
M<F5S=6QT(#T@:6UA<%]S971A8VPH)'1H:7,M/E]I;6%P+"`D9F]L9&5R+"`D
M<VAA<F5?=7-E<BP@)&%C;%]S='(I.PH*("`@("`@("!I9B`H(21R97-U;'0I
M('L*("`@("`@("`@("`@)&5R<F]R<R`](&EM87!?97)R;W)S*"D["B`@("`@
M("`@("`@(&EF("AI<U]A<G)A>2@D97)R;W)S*2D@>PH@("`@("`@("`@("`@
M("`@)&5R<F]R7W-T<FEN9R`]("<G.PH@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&5R<F]R<R!A<R`D97)R*2!["B`@("`@("`@("`@("`@("`@("`@:68@
M*"1E<G(@/3T@)T%#3"!N;W0@879A:6QA8FQE(&]N('1H:7,@24U!4"!S97)V
M97(G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1E<G(@+CT@7R@B5&AI
M<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R
M<RXB*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@)&5R<F]R7W-T<FEN9R`N/2`D97)R.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)&5R<F]R
M7W-T<FEN9RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")#;W5L9&XG="!G:79E('5S97(@
M7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB
M)7-<(CH@)7,B*2P@)'-H87)E7W5S97(L("1F;VQD97(L("1A8VQ?<W1R*2D[
M"B`@("`@("`@?0H*("`@("`@("`O*B!)9B!02%`@-2!I<VXG="!A=F%I;&%B
M;&4@=V%I="!A(&)I="!T;R!E;G-U<F4@04-,('!R;W!A9V%T97,@:6X*("`@
M("`@("`@*B!#>7)U<R!-=7)D97(@8V]N9FEG=7)A=&EO;BX@*B\*("`@("`@
M("!I9B`H(69U;F-T:6]N7V5X:7-T<R@G:6UA<%]G971A8VPG*2D@>PH@("`@
M("`@("`@("!S;&5E<"@U*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@161I=',@86X@04-,(&]N
M(&%N($E-05`@<V5R=F5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&9O;&1E<B`@("`@(%1H92!F;VQD97(@;VX@=VAI8V@@=&\@961I="!T:&4@
M04-,+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<VAA<F5?=7-E<B`@5&AE('5S
M97(@=&\@9W)A;G0@<FEG:'1S('1O+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A
M8VP@("`@("`@("`@06X@87)R87DL('1H92!K97ES(&]F('=H:6-H(&%R92!T
M:&4@<FEG:'1S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!B92!G<F%N=&5D("AS964@4D9#(#(P.#8I+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@9F%I;'5R
M92!U;FQE<W,@<V5R=F5R(&1O97-N)W0*("`@("`J("`@("`@("`@("`@("`@
M('-U<'!O<G0@04-,<RP@<F5T=7)N<R`G;F]?<W5P<&]R="<*("`@("`J+PH@
M("`@9G5N8W1I;VX@961I=$%#3"@D9F]L9&5R+"`D<VAA<F5?=7-E<BP@)&%C
M;"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F-R96%T94%#3"@D9F]L
M9&5R+"`D<VAA<F5?=7-E<BP@)&%C;"D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!='1E;7!T<R!T;R!G970@=&AE(')E<W5L="!O9B!A($-!4$%"24Q)5%D@
M8V]M;6%N9"!T;R!T:&4@8W5R<F5N="!)34%0"B`@("`@*B!S97)V97(N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@06X@87)R87D@8V]N=&%I;FEN9R!T:&4@<V5R=F5R)W,@
M8V%P86)I;&ET:65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T0V%P86)I
M;&ET>2@I"B`@("!["B`@("`@("`@)&-A<&%B:6QI=&EE<R`](&YU;&P["B`@
M("`@("`@)'-E<G9E<B`]("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==.PH@
M("`@("`@("1S=6)?<')O=&\@/2!N=6QL.PH*("`@("`@("!I9B`H<')E9U]M
M871C:"@G?%Y;7B]=*R]S<VQ\)RP@)'1H:7,M/E]P87)A;7-;)W!R;W1O8V]L
M)UTI*2!["B`@("`@("`@("`@("1S97)V97(@/2`G<W-L.B\O)R`N("1S97)V
M97(["B`@("`@("`@?0H*("`@("`@("`D:6UA<"`](&9S;V-K;W!E;B@D<V5R
M=F5R+"`D=&AI<RT^7W!A<F%M<ULG<&]R="==+"`D97)R;F\L("1E<G)S='(L
M(#,P*3L*"B`@("`@("`@:68@*"$D:6UA<"D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R
M=F5R)W,@8V%P86)I;&ET:65S(BD@+B`G("T@)R`N("@D97)R;F\@/R!?*")#
M;VYN96-T:6]N(&9A:6QE9#H@(BD@+B`D97)R;F\@+B`G(#H@)R`N("1E<G)S
M='(@.B!?*")#;VYN96-T:6]N(&9A:6QE9"XB*2DI.PH@("`@("`@("`@("!R
M971U<FX@;G5L;#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S
M<&]N<V4@/2!F9V5T<R@D:6UA<"P@-#`Y-BD["B`@("`@("`@("`@(&EF("AP
M<F5G7VUA=&-H*"<O7EPJ7',K3TLO)RP@)')E<W!O;G-E*2D@>PH@("`@("`@
M("`@("`@("`@9G!U=',H)&EM87`L(")X($-!4$%"24Q)5%E<<EQN(BD["B`@
M("`@("`@("`@("`@("`D<F5S<&]N<V4@/2!T<FEM*&9G971S*"1I;6%P+"`Q
M,#(T*2D["B`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UY<*EQS
M*T-!4$%"24Q)5%DO)RP@)')E<W!O;G-E*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1R97-P;VYS95]A<G)A>2`](&5X<&QO9&4H)R`G+"`D<F5S<&]N<V4I
M.PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R97-P;VYS95]A<G)A
M>2!A<R`D=F%R*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AS=')P
M;W,H)'9A<BP@)STG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1V87(R(#T@97AP;&]D92@G/2<L("1V87(L(#(I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&-A<&%B:6QI=&EE<UM3=')I;F<Z
M.FQO=V5R*"1V87(R6S!=*5U;4W1R:6YG.CIL;W=E<B@D=F%R,ELQ72E=(#T@
M,3L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1C87!A8FEL:71I97-;4W1R:6YG.CIL;W=E
M<B@D=F%R*5T@/2`Q.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@9F-L;W-E("@D:6UA<"D["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T
M(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(I("X@)R`M("<@+B!?
M*")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B*2`N("=<
M)W@@0T%004))3$E465PG(#H@)R`N("1R97-P;VYS92D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!F
M8VQO<V4@*"1I;6%P*3L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A
M8FEL:71I97,B*2`N("<@+2`G("X@7R@B56YE>'!E8W1E9"!R97-P;VYS92!F
M<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B*2`N("1R97-P;VYS92D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@9F-L;W-E("@D:6UA<"D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&-A<&%B:6QI=&EE<SL*("`@('T*"B`@
M("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E=')I979E('1H92!E>&ES=&EN
M9R!!0TP@9F]R(&$@9F]L9&5R(&9R;VT@=&AE(&-U<G)E;G0*("`@("`J($E-
M05`@<V5R=F5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@9F]L9&5R
M("!4:&4@9F]L9&5R('1O(&=E="!T:&4@04-,(&9O<BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!!(&AA<V@@8V]N=&%I;FEN9R!I;F9O<FUA=&EO
M;B!O;B!T:&4@04-,+@H@("`@("H@/'!R93X*("`@("`J($%R<F%Y("@*("`@
M("`J("`@=7-E<B`]/B!!<G)A>2`H"B`@("`@*B`@("`@<FEG:'0@/3X@,0H@
M("`@("H@("`I"B`@("`@*B`I"B`@("`@*B`\+W!R93X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T04-,*"1F;VQD97(I"B`@("!["B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?8V%P<ULG875T:"==6R=D:6=E<W0M;60U)UTI*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7V=E=$%#3"@D9F]L9&5R+"`G9&EG
M97-T+6UD-2<I.PH@("`@("`@('T@96QS96EF("AI<W-E="@D=&AI<RT^7V-A
M<'-;)V%U=&@G75LG8W)A;2UM9#4G72DI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?9V5T04-,*"1F;VQD97(L("=C<F%M+6UD-2<I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V=E=$%#3"@D
M9F]L9&5R+"`G;&]G:6XG*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!='1E;7!T<R!T;R!R971R:65V92!T:&4@97AI<W1I;F<@04-,(&9O
M<B!A(&9O;&1E<B!F<F]M('1H92!C=7)R96YT"B`@("`@*B!)34%0('-E<G9E
M<BX*("`@("`J"B`@("`@*B!.0CH@:68@075T:%]305-,(&ES(&YO="!I;G-T
M86QL960@=&AI<R!F=6YC=&EO;B!W:6QL('-E;F0@=&AE('5S97)S"B`@("`@
M*B!P87-S=V]R9"!T;R!T:&4@24U!4"!S97)V97(@87,@<&QA:6X@=&5X="$A
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R!F;VQD97(@("`@5&AE(&9O;&1E<B!T;R!G970@=&AE
M($%#3"!F;W(N"B`@("`@*B!`<&%R86T@<W1R:6YG(&%U=&A-96-H("!4:&4@
M875T:&]R:7-A=&EO;B!M96-H86YI<VT@=&\@=7-E+B!/;F4@;V8*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@(&-R86TM;60U+"!D:6=E<W0M;60U
M(&]R(&QO9VEN+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($$@:&%S
M:"!C;VYT86EN:6YG(&EN9F]R;6%T:6]N(&]N('1H92!!0TP*("`@("`J(#QP
M<F4^"B`@("`@*B!!<G)A>2`H"B`@("`@*B`@('5S97(@/3X@07)R87D@*`H@
M("`@("H@("`@(')I9VAT(#T^(#$*("`@("`J("`@*0H@("`@("H@*0H@("`@
M("H@/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971!0TPH)&9O;&1E
M<BP@)&%U=&A-96-H*0H@("`@>PH@("`@("`@("\J($EF(&EM87!?9V5T86-L
M*"D@:7,@879A:6QA8FQE+"!U<V4@:70@*B\*("`@("`@("!I9B`H9G5N8W1I
M;VY?97AI<W1S*"=I;6%P7V=E=&%C;"<I*2!["B`@("`@("`@("`@(&EF("@A
M)'1H:7,M/E]C;VYN96-T*"DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7VEM87`["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1R97-U
M;'0@/2!`:6UA<%]G971A8VPH)'1H:7,M/E]I;6%P+"`D9F]L9&5R*3L*("`@
M("`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@("`@("`D97)R
M;W)S(#T@:6UA<%]E<G)O<G,H*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2@D97)R;W)S*2D@>PH@("`@("`@("`@("`@("`@("`@("1E<G)O<E]S
M=')I;F<@/2`G)SL*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D97)R
M;W)S(&%S("1E<G(I('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1E
M<G(@/3T@)T%#3"!N;W0@879A:6QA8FQE(&]N('1H:7,@24U!4"!S97)V97(G
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D97)R("X](%\H(E1H
M:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E
M<G,N(BD["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`@("`@)&5R<F]R7W-T<FEN9R`N/2`D97)R.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@D97)R;W)?<W1R:6YG*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN
M=&8H7R@B0V]U;&0@;F]T(')E=')I979E($%#3"(I*2D["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1R971U<FY!0TP@/2!A<G)A>2@I.PH@("`@("`@
M("`@("!F;W)E86-H("@D<F5S=6QT(&%S("1U<V5R(#T^("1R:6=H=',I('L*
M("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P+"`D:4UA>"`]('-T<FQE;B@D
M<FEG:'1S*3L@)&D@/"`D:4UA>#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@
M("`@("1R971U<FY!0TQ;)'5S97)=6R1R:6=H='-;)&E=72`](#$["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(')E='5R
M;B`D<F5T=7)N04-,.PH@("`@("`@('T*"B`@("`@("`@9VQO8F%L("1N;W1I
M9FEC871I;VX["@H@("`@("`@("1H879E7W-A<VP@/2!F86QS93L*("`@("`@
M("`D<F5T=7)N04-,(#T@87)R87DH*3L*("`@("`@("`D<V5R=F5R(#T@)'1H
M:7,M/E]P87)A;7-;)VAO<W1S<&5C)UT["B`@("`@("`@)'-U8E]P<F]T;R`]
M(&YU;&P["B`@("`@("`@)'1X:60@/2`P.PH*("`@("`@("`O*B!3:6QE;F-E
M('=A<FYI;F=S(&1U<FEN9R!C:&5C:R!I9B!!=71H7U-!4TP@;6]D=6QE(&ES
M(&EN<W1A;&QE9"X@*B\*("`@("`@("!I9B`H0&EN8VQU9&5?;VYC92`G075T
M:"]305-,+G!H<"<I('L*("`@("`@("`@("`@)&AA=F5?<V%S;"`]('1R=64[
M"B`@("`@("`@?0H*("`@("`@("`D<&%S<R`]("1T:&ES+3Y?<&%R86US6R=P
M87-S=V]R9"==.PH*("`@("`@("!I9B`H<')E9U]M871C:"@G?%Y;7B]=*R]S
M<VQ\)RP@)'1H:7,M/E]P87)A;7-;)W!R;W1O8V]L)UTI*2!["B`@("`@("`@
M("`@("1S97)V97(@/2`G<W-L.B\O)R`N("1S97)V97(["B`@("`@("`@?0H*
M("`@("`@("`O*B!1=6]T92!T:&4@9F]L9&5R('-T<FEN9R!I9B!I="!C;VYT
M86EN<R!N;VX@86QP:&$M;G5M97)I8PH@("`@("`@("`@(&-H87)A8W1E<G,N
M("HO"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R]<5R\G+"1F;VQD97(I*2![
M"B`@("`@("`@("`@("1F;VQD97(@/2`G(B<@+B`D9F]L9&5R("X@)R(G.PH@
M("`@("`@('T*"B`@("`@("`@)&EM87`@/2!F<V]C:V]P96XH)'-E<G9E<BP@
M)'1H:7,M/E]P87)A;7-;)W!O<G0G72P@)&5R<FYO+"`D97)R<W1R+"`S,"D[
M"@H@("`@("`@(&EF("@A)&EM87`I('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T(')E=')I979E($%#3"(I"B`@
M("`@("`@("`@("`@("`N("<@+2`G("X@*"1E<G)N;R`_(%\H(D-O;FYE8W1I
M;VX@9F%I;&5D.B`B*2`N("1E<G)N;RXG(#H@)R`N("1E<G)S='(@.B!?*")#
M;VYN96-T:6]N(&9A:6QE9"XB*2DI.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1R97-P;VYS92`](&9G971S*"1I;6%P+"`T,#DV*3L*("`@("`@
M("`@("`@:68@*'!R96=?;6%T8V@H)R]>7"I<<RM/2R\G+"`D<F5S<&]N<V4I
M*2!["@H@("`@("`@("`@("`@("`@+RH@;&]G:6X@=7-I;F<@=&AE('!R969E
M<G)E9"!M96-H86YI<VT@9&5F875L="!T;R!L;V=I;B!I9@H@("`@("`@("`@
M("`@("`@("`@075T:%]305-,(&ES(&YO="!I;G-T86QL960N("HO"B`@("`@
M("`@("`@("`@("!I9B`H)&AA=F5?<V%S;"`F)B`H)&%U=&A-96-H(#T]("=C
M<F%M+6UD-2<I*2!["B`@("`@("`@("`@("`@("`@("`@)&QO9VEN(#T@075T
M:%]305-,.CIF86-T;W)Y*"=C<F%M;60U)RD["@H@("`@("`@("`@("`@("`@
M("`@(&9P=71S*"1I;6%P+"`B)'1X:60@05542$5.5$E#051%($-204TM340U
M7')<;B(I.PH@("`@("`@("`@("`@("`@("`@("1C:&%L;&5N9V4@/2!E>'!L
M;V1E*"<@)RP@=')I;2AF9V5T<R@D:6UA<"P@,3`R-"DI*3L*"B`@("`@("`@
M("`@("`@("`@("`@)')E<W!O;G-E(#T@)&QO9VEN+3YG971297-P;VYS92@D
M7U-%4U-)3TY;)VEM<"==6R=U<V5R)UTL("1P87-S+"!B87-E-C1?9&5C;V1E
M*"1C:&%L;&5N9V5;,5TI*3L*("`@("`@("`@("`@("`@("`@("!F<'5T<R@D
M:6UA<"P@8F%S938T7V5N8V]D92@D<F5S<&]N<V4I("X@(EQR7&XB*3L*"B`@
M("`@("`@("`@("`@("!](&5L<V5I9B@D:&%V95]S87-L("8F("@D875T:$UE
M8V@@/3T@)V1I9V5S="UM9#4G*2D@>PH@("`@("`@("`@("`@("`@("`@("1L
M;V=I;B`]($%U=&A?4T%33#HZ9F%C=&]R>2@G9&EG97-T;60U)RD["@H@("`@
M("`@("`@("`@("`@("`@(&9P=71S*"1I;6%P+"`B)'1X:60@05542$5.5$E#
M051%($1)1T535"U-1#5<<EQN(BD["B`@("`@("`@("`@("`@("`@("`@)&-H
M86QL96YG92`](&5X<&QO9&4H)R`G+"!T<FEM*&9G971S*"1I;6%P+"`Q,#(T
M*2DI.PH*("`@("`@("`@("`@("`@("`@("`D<F5S<&]N<V4@/2`D;&]G:6XM
M/F=E=%)E<W!O;G-E*"1?4T534TE/3ELG:6UP)UU;)W5S97(G72P@)'!A<W,L
M(&)A<V4V-%]D96-O9&4H)&-H86QL96YG95LQ72DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("1?4T534TE/3ELG:6UP)UU;)W-E<G9E<B==+"`D7U-%4U-)
M3TY;)VEM<"==6R=B87-E7W!R;W1O8V]L)UTI.PH*("`@("`@("`@("`@("`@
M("`@("!F<'5T<R@D:6UA<"P@8F%S938T7V5N8V]D92@D<F5S<&]N<V4I("X@
M(EQR7&XB*3L*("`@("`@("`@("`@("`@("`@("`D<F5S<&]N<V4@/2!E>'!L
M;V1E*"<@)RP@=')I;2AF9V5T<R@D:6UA<"P@,3`R-"DI*3L*("`@("`@("`@
M("`@("`@("`@("`D<F5S<&]N<V4@/2!B87-E-C1?9&5C;V1E*"1R97-P;VYS
M95LQ72D["B`@("`@("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D<F5S<&]N
M<V4L("=R<W!A=71H/2<I(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("!F8VQO<V4H)&EM87`I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@<F5T<FEE
M=F4@04-,(BD*("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)R`M("<@
M+B!?*")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B*2`N
M("=$:6=E<W0M340U(')E<W!O;G-E)RP@)VAO<F1E+G=A<FYI;F<G*3L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@9G!U=',H
M)&EM87`L(")<<EQN(BD["@H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UQ7+R<L("1P87-S
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<&%S<R`](&%D9'-L87-H
M97,H)'!A<W,I.PH@("`@("`@("`@("`@("`@("`@("`@("`D<&%S<R`]("<B
M)R`N("1P87-S("X@)R(G.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!F<'5T<R@D:6UA<"P@(B1T>&ED($Q/1TE.("(@+B`D
M7U-%4U-)3TY;)VEM<"==6R=U<V5R)UT@+B`G("<@+B`D<&%S<R`N(")<<EQN
M(BD["@H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)')E<W!O
M;G-E(#T@=')I;2AF9V5T<R@D:6UA<"P@,3`R-"DI.PH@("`@("`@("`@("`@
M("`@:68@*'!R96=?;6%T8V@H(B]>)'1X:61<<T]++R(L("1R97-P;VYS92DI
M('L*("`@("`@("`@("`@("`@("`@("`D='AI9"LK.PH@("`@("`@("`@("`@
M("`@("`@(&9P=71S*"1I;6%P+"`B)'1X:60@1T5404-,("(@+B`D9F]L9&5R
M("X@(EQR7&XB*3L*("`@("`@("`@("`@("`@("`@("`D<F5S<&]N<V4@/2!T
M<FEM*&9G971S*"1I;6%P+"`T,#DV*2D["B`@("`@("`@("`@("`@("`@("`@
M:68@*'!R96=?;6%T8V@H)R]>7"I<<RM!0TQ<<RLH+BHI+VDG+"`D<F5S<&]N
M<V4L("1M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<F5S
M7V%R<B`]("1T:&ES+3Y?871O;6ES92@D;6%T8VAE<ULQ72D["B`@("`@("`@
M("`@("`@("`@("`@("`@("1R97-?9F]L9&5R(#T@87)R87E?<VAI9G0H)')E
M<U]A<G(I.PH@("`@("`@("`@("`@("`@("`@("`@("`D:7-?:V5Y(#T@,3L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&ME>2`](&YU;&P["B`@("`@("`@
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R97-?87)R(&%S("1V87(I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D:7-?:V5Y*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&ME>2`]("1V87(["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&ES7VME>2`](#`["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P97)M<R`]('!R96=?<W!L:70H)R\O
M)RP@)'9A<BP@+3$L(%!214=?4U!,251?3D]?14U05%DI.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1P97)M<R!A<R`D<%]K
M97D@/3X@)'!?=F%R*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1R971U<FY!0TQ;)&ME>5U;)'!?=F%R72`](#$["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1I<U]K97D@/2`Q.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@
M9F-L;W-E*"1I;6%P*3L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T(')E=')I979E($%#3"(I
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("<@+2`G("X@7R@B56YE
M>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(BD@+B`B)R1T>&ED
M($=%5$%#3"<@.B`B("XD<F5S<&]N<V4I.PH*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@(&9C;&]S92@D:6UA<"D["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T(')E=')I979E($%#3"(I
M"B`@("`@("`@("`@("`@("`@("`@("`@("X@)R`M("<@+B!?*")5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B*2`N("=L;V=I;B`Z("<@
M+B`D<F5S<&]N<V4I.PH*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@(&9C;&]S92@D:6UA<"D["B`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N
M;W0@<F5T<FEE=F4@04-,(BD*("`@("`@("`@("`@("`@("`@("`N("<@+2`G
M("X@7R@B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN
M96-T:6]N.B`B*2`N("1R97-P;VYS92D["@H@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&9C;&]S92@D:6UA<"D["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)')E='5R;D%#3#L*("`@('T*"B`@("`O*BH*("`@("`J($-A;B!A('5S
M97(@961I="!T:&4@04-,(&9O<B!T:&ES(&9O;&1E<C\*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1F;VQD97(@(%1H92!F;VQD97(@;F%M92X*("`@
M("`J($!P87)A;2!S=')I;F<@)'5S97(@("`@02!U<V5R(&YA;64N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF("1U<V5R(&AA<R!P
M97)M:7-S:6]N('1O(&5D:70@=&AE($%#3"!O;@H@("`@("H@("`@("`@("`@
M("`@("`@("`D9F]L9&5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!C86Y%9&ET
M*"1F;VQD97(L("1U<V5R*0H@("`@>PH@("`@("`@("\J(%=E(&-A;B=T(&5S
M=&%B;&ES:"!I9B!T:&4@=7-E<B!I<R!I;B!A(&=R;W5P('=I=&@@=&AE("=A
M)PH@("`@("`@("`@('!R:79I;&5G92P@<V\@:G5S="!R971U<FX@=')U92!A
M;F0@;&5A=F4@=&AE(&1E8VES:6]N('1O('1H90H@("`@("`@("`@('-E<G9E
M<B`J+PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0W)U9&5L>2!S<&QI="!A('-T<FEN9R!I;G1O("=A=&]M<R<N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D:6X@(%1H92!S=')I;F<@=&\@<W!L:70N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@;V8@)V%T;VUS)RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V%T;VUI<V4H)&EN*0H@("`@>PH@("`@("`@("1L
M96YG=&@@/2!S=')L96XH)&EN*3L*("`@("`@("`D<70@/2!F86QS93L*("`@
M("`@("`D:61X(#T@,#L*("`@("`@("`D;W5T(#T@87)R87DH*3L*"B`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@)&QE;F=T:#L@)&DK*RD@>PH@("`@("`@
M("`@("`D8VAA<B`]('-U8G-T<B@D:6XL("1I+"`Q*3L*("`@("`@("`@("`@
M:68@*"@D8VAA<B`]/2`G(B<I("8F("$D<70I('L*("`@("`@("`@("`@("`@
M("1Q="`]('1R=64["B`@("`@("`@("`@("`@("`D:61X*RL["B`@("`@("`@
M("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?2!E;'-E:68@*"@D8VAA
M<B`]/2`G("<I("8F("$D<70I('L*("`@("`@("`@("`@("`@("1I9'@K*SL*
M("`@("`@("`@("`@?2!E;'-E:68@*"@D8VAA<B`]/2`G(B<I("8F("1Q="D@
M>PH@("`@("`@("`@("`@("`@)'%T(#T@9F%L<V4["B`@("`@("`@("`@("`@
M("`D:61X*RL["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!I9B`H96UP='DH)&]U=%LD:61X72DI('L*("`@("`@("`@("`@("`@("`@
M("`D;W5T6R1I9'A=(#T@)&-H87(["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1O=71;)&ED>%T@+CT@)&-H87(["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D;W5T.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92])34%0+T%#
M3"]R9F,T,S$T+G!H<```````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0R
M,38`,3`U,34T,S,W-#8`,#(R-#$V`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP)SL*"B\J*@H@*B!#;VYT86EN<R!F=6YC
M=&EO;G,@<F5L871E9"!T;R!M86YA9VEN9R!!8V-E<W,@0V]N=')O;"!,:7-T
M<R!O;B!A;B!)34%0"B`J('-E<G9E<B!U<VEN9R!21D,@-#,Q-"X*("H*("H@
M4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=U<V5R;F%M92<@(%1H
M92!U<V5R;F%M92!F;W(@=&AE('-E<G9E<B!C;VYN96-T:6]N"B`J("`@)W!A
M<W-W;W)D)R`@5&AE('!A<W-W;W)D(&9O<B!T:&4@<V5R=F5R(&-O;FYE8W1I
M;VX*("H@("`G:&]S='-P96,G("!4:&4@:&]S=&YA;64@;W(@25`@861D<F5S
M<R!O9B!T:&4@<V5R=F5R+@H@*B`@("`@("`@("`@("`@($1%1D%53%0Z("=L
M;V-A;&AO<W0G"B`J("`@)W!O<G0G("`@("`@5&AE('-E<G9E<B!P;W)T('1O
M('=H:6-H('=E('=I;&P@8V]N;F5C="X*("H@("`@("`@("`@("`@("!)34%0
M(&ES(&=E;F5R86QL>2`Q-#,L('=H:6QE($E-05`M4U-,(&ES(&=E;F5R86QL
M>2`Y.3,N"B`J("`@("`@("`@("`@("`@1$5&055,5#H@,30S"B`J("`@)W!R
M;W1O8V]L)R`@5&AE(&-O;FYE8W1I;VX@<')O=&]C;VP@*&4N9RX@)VEM87`G
M+"`G<&]P,R<L("=N;G1P)RDN"B`J("`@("`@("`@("`@("`@4')O=&]C;VP@
M:7,@;VYE(&]F("=I;6%P+VYO=&QS)R`H;W(@;VYL>2`G:6UA<"<@:68@>6]U
M"B`J("`@("`@("`@("`@("`@:&%V92!A(&,M8VQI96YT('9E<G-I;VX@,C`P
M,&,@;W(@;VQD97(I+"`G:6UA<"]S<VPG+"!O<@H@*B`@("`@("`@("`@("`@
M("=I;6%P+W-S;"]N;W9A;&ED871E+6-E<G0G("AF;W(@82!S96QF+7-I9VYE
M9"!C97)T:69I8V%T92DN"B`J("`@("`@("`@("`@("`@1$5&055,5#H@)VEM
M87`G/"]P<F4^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C-#,Q-"YP:'`L=B`Q+C(N,BXQ(#(P,#8O,#(O,#8@,C,Z,C$Z,3D@
M<V5L<VMY($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`V($UA='0@4V5L<VMY
M(#QS96QS:WE`8V]L=6UB:6$N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@36%T="!396QS:WD@/'-E;'-K>4!C;VQU;6)I82YE9'4^"B`J($!S
M:6YC92`@($AO<F1E(#,N,0H@*B!`<&%C:V%G92!(;W)D95])34%0"B`J+PIC
M;&%S<R!)34%07T%#3%]R9F,T,S$T(&5X=&5N9',@24U!4%]!0TQ?<F9C,C`X
M-B!["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY(&%D9&ET:6]N86P@<&%R86UE
M=&5R<R!T:&ES(&1R:79E<B!M87D@;F5E9"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@24U!4%]!0TQ?<F9C-#,Q-"@D<&%R86US(#T@87)R87DH*2D*("`@('L*
M("`@("`@("!P87)E;G0Z.DE-05!?04-,7W)F8S(P.#8H)'!A<F%M<RD["@H@
M("`@("`@("1T:&ES+3Y?<FEG:'1S3&ES="`](&%R<F%Y*`H@("`@("`@("`@
M("`@)VPG(#T^(%\H(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(I
M+`H@("`@("`@("`@("`@)W(G(#T^(%\H(E)E860@;65S<V%G97,B*2P*("`@
M("`@("`@("`@("=S)R`]/B!?*")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA
M9W,B*2P*("`@("`@("`@("`@("=W)R`]/B!?*")-87)K('=I=&@@;W1H97(@
M9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(I+`H@("`@("`@("`@
M("`@)VDG(#T^(%\H(DEN<V5R="!M97-S86=E<R(I+`H@("`@("`@("`@("`@
M)W`G(#T^(%\H(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B
M>2!)34%0*2(I+`H@("`@("`@("`@("`@)VLG(#T^(%\H(D-R96%T92!S=6(@
M9F]L9&5R<R(I+`H@("`@("`@("`@("`@)W@G(#T^(%\H(D1E;&5T92!S=6(@
M9F]L9&5R<R(I+`H@("`@("`@("`@("`@)W0G(#T^(%\H(D1E;&5T92!M97-S
M86=E<R(I+`H@("`@("`@("`@("`@)V4G(#T^(%\H(E!U<F=E(&UE<W-A9V5S
M(BDL"B`@("`@("`@("`@("`G82<@/3X@7R@B061M:6YI<W1E<B`M('-E="!P
M97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B*0H@("`@("`@("D["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92])34%0+T%#3"YP:'``````````````````````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,3(W,34`,3`U,34T,S,W-#8`,#(Q,S,S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!#
M;VYT86EN<R!F=6YC=&EO;G,@<F5L871E9"!T;R!M86YA9VEN9PH@*B!!8V-E
M<W,@0V]N=')O;"!,:7-T<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"YP:'`L=B`Q+C(N,3(N,3`@,C`P-B\P,B\P,R`P,SHP-SHU
M-R!S96QS:WD@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!#:')I
M<R!(87-T:64@/&EM<$!O86LM=V]O9"YC;RYU:SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($-H<FES($AA<W1I92`\:6UP0&]A:RUW;V]D+F-O+G5K
M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?24U!
M4`H@*B\*8VQA<W,@24U!4%]!0TP@>PH*("`@("\J*@H@("`@("H@2&%S:"!C
M;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y
M*"D["@H@("`@+RHJ"B`@("`@*B!";V]L96%N(&EN9&EC871I;F<@:68@=&AE
M(&1R:79E<B!I<R!S=7!P;W)T960@8GD@=&AE('-E<G9E<@H@("`@("H*("`@
M("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]S=7!P;W)T960@
M/2!F86QS93L*"B`@("`O*BH*("`@("`J($%N>2!014%27T5R<F]R('1H870@
M;V-C=7)E9"!B=70@8V]U;&1N)W0@8F4@<F5T=7)N960@9&ER96-T;'DN"B`@
M("`@*@H@("`@("H@0'9A<B!014%27T5R<F]R"B`@("`@*B\*("`@('9A<B`D
M7V5R<F]R(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($AA<V@@8V]N=&%I;FEN
M9R!T:&4@;&ES="!O9B!P;W-S:6)L92!R:6=H=',@86YD(&$@:'5M86X*("`@
M("`J(')E861A8FQE(&1E<V-R:7!T:6]N(&]F(&5A8V@*("`@("`J"B`@("`@
M*B!!<G)A>2`H"B`@("`@*B`@("`@<FEG:'0M:60@/3X@<FEG:'0M9&5S8W)I
M<'1I;VX*("`@("`J("D*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7W)I9VAT<TQI<W0@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@07)R87D@8V]N=&%I;FEN9R!U<V5R(&YA;65S('1H870@8V%N;F]T
M(&AA=F4@=&AE:7(@86-C97-S"B`@("`@*B!R:6=H=',@8VAA;F=E9"X*("`@
M("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?<')O
M=&5C=&5D.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($AA<V@@8V]N=&%I;FEN9R!C
M;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($E-
M05!?04-,*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?<&%R86US(#T@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J($%T
M=&5M<'1S('1O(')E=')I979E('1H92!E>&ES=&EN9R!!0TP@9F]R(&$@9F]L
M9&5R(&9R;VT*("`@("`J('1H92!C=7)R96YT($E-05`@<V5R=F5R+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@9F]L9&5R("!4:&4@9F]L9&5R('1O
M(&=E="!T:&4@04-,(&9O<@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M($$@:&%S:"!C;VYT86EN:6YG(&EN9F]R;6%T:6]N(&]N('1H92!!0TP*("`@
M("`J("`@("`@("`@("`@("`@($%R<F%Y("@*("`@("`J("`@("`@("`@("`@
M("`@("`@("!U<V5R(#T^($%R<F%Y("@*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!R:6=H="`]/B`Q"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`I"B`@("`@*B`@("`@("`@("`@("`@("`I"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$%#3"@D9F]L9&5R*0H@("`@>PH@("`@
M("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@
M=&AE($%#3"!O;B!A;B!)34%0('-E<G9E<@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&9O;&1E<B`@5&AE(&9O;&1E<B!O;B!W:&EC:"!T;R!E9&ET
M('1H92!!0TP*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S:&%R95]U
M<V5R("!4:&4@=7-E<B!T;R!G<F%N="!R:6=H=',@=&\*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)&%C;"`@06X@87)R87DL('1H92!K97ES(&]F('=H
M:6-H(&%R92!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("!R:6=H=',@
M=&\@8F4@9W)A;G1E9"`H<V5E(%)&0R`R,#@V*0H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@9F%I;'5R
M92!U;FQE<W,*("`@("`J("`@("`@("`@("`@("`@('-E<G9E<B!D;V5S;B=T
M('-U<'!O<G0@04-,<RP@<F5T=7)N<R`G;F]?<W5P<&]R="<*("`@("`J+PH@
M("`@9G5N8W1I;VX@8W)E871E04-,*"1F;VQD97(L("1S:&%R95]U<V5R+"`D
M86-L*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O
M*BH*("`@("`J($5D:71S(&%N($%#3"!O;B!A;B!)34%0('-E<G9E<@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&9O;&1E<B`@5&AE(&9O;&1E<B!O
M;B!W:&EC:"!T;R!E9&ET('1H92!!0TP*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1S:&%R95]U<V5R("!4:&4@=7-E<B!T;R!G<F%N="!R:6=H=',@
M=&\*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&%C;"`@06X@87)R87DL
M('1H92!K97ES(&]F('=H:6-H(&%R92!T:&4*("`@("`J("`@("`@("`@("`@
M("`@("`@("!R:6=H=',@=&\@8F4@9W)A;G1E9"`H<V5E(%)&0R`R,#@V*0H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<RP@
M9F%L<V4@;VX@9F%I;'5R92!U;FQE<W,*("`@("`J("`@("`@("`@("`@("`@
M('-E<G9E<B!D;V5S;B=T('-U<'!O<G0@04-,<RP@<F5T=7)N<R`G;F]?<W5P
M<&]R="<*("`@("`J+PH@("`@9G5N8W1I;VX@961I=$%#3"@D9F]L9&5R+"`D
M<VAA<F5?=7-E<BP@)&%C;"D*("`@('L*("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#86X@82!U<V5R(&5D:70@=&AE($%#
M3"!F;W(@=&AI<R!F;VQD97(_(%)E='5R;G,@=')U92!I9B`D=7-E<@H@("`@
M("H@<&5R;6ES<VEO;B!T;R!E9&ET('1H92!!0TP@;VX@)&9O;&1E<@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&9O;&1E<B`@5&AE(&9O;&1E<B!N
M86UE"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@02!U<V5R
M(&YA;64*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@
M)'5S97(@:&%S("=A)R!R:6=H=`H@("`@("HO"B`@("!F=6YC=&EO;B!C86Y%
M9&ET*"1F;VQD97(L("1U<V5R*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%)I9VAT<R@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?<FEG:'1S3&ES=#L*("`@('T*"B`@("!F=6YC
M=&EO;B!G9710<F]T96-T960H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7W!R;W1E8W1E9#L*("`@('T*"B`@("!F=6YC=&EO;B!I<U-U<'!O<G1E
M9"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<W5P<&]R=&5D.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&=E=$5R<F]R*"D*("`@('L*("`@("`@("`D
M97)R;W(@/2`D=&AI<RT^7V5R<F]R.PH@("`@("`@("1T:&ES+3Y?97)R;W(@
M/2!N=6QL.PH@("`@("`@(')E='5R;B`D97)R;W(["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@86X@04-,(&EN<W1A;F-E(&)A
M<V5D(&]N("1D<FEV97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!!0TP@<W5B8VQA<W,@=&\@
M<F5T=7)N+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("!!(&AA<V@@
M8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&-O;FYE8W1I;VX@<&%R86UE
M=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@04-,(&EN
M<W1A;F-E+"!O<B!F86QS90H@("`@("H@("`@("`@("`@("`@("`@;VX@97)R
M;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D<FEV97(L("1P
M87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1D<FEV97(@/2!B87-E
M;F%M92@D9')I=F5R*3L*("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+T%#3"\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@
M("`D8VQA<W,@/2`G24U!4%]!0TQ?)R`N("1D<FEV97(["B`@("`@("`@:68@
M*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1A8VP@/2`F
M;F5W("1C;&%S<R@D<&%R86US*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D86-L(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&%C;#L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R
M;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E($%#3"!I;G-T86YC90H@("`@
M("H@8F%S960@;VX@)&1R:79E<BX@($ET('=I;&P@;VYL>2!C<F5A=&4@82!N
M97<@:6YS=&%N8V4@:68@;F\*("`@("`J($%#3"!I;G-T86YC92!W:71H('1H
M92!S86UE('!A<F%M971E<G,@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@
M("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z("1V87(@/2`F
M24U!4%]!0TPZ.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!!0TP@<W5B8VQA
M<W,@=&\@<F5T=7)N+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("!!
M(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N
M(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&-O;FYE8W1I;VX@
M<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5&AE(&-R96%T960@8V]N8W)E=&4@04-,(&EN
M<W1A;F-E+"!O<B!F86QS92!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@)G-I;F=L971O;B@D9')I=F5R+"`D<&%R86US(#T@87)R87DH*2D*("`@
M('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<SL*"B`@("`@("`@:68@*"%I
M<W-E="@D:6YS=&%N8V5S*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S(#T@
M87)R87DH*3L*("`@("`@("!]"@H@("`@("`@("1S:6=N871U<F4@/2!S97)I
M86QI>F4H87)R87DH)&1R:79E<BP@)'!A<F%M<RDI.PH@("`@("`@(&EF("@A
M:7-S970H)&EN<W1A;F-E<ULD<VEG;F%T=7)E72DI('L*("`@("`@("`@("`@
M)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`]("9)34%07T%#3#HZ9F%C=&]R>2@D
M9')I=F5R+"`D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*?0H`````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92])34%0+T%D;6EN+G!H<```
M````````````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3<P-3$`,3`U,34T
M,S,W-#8`,#(Q-S8R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!4:&4@24U!4%]!9&UI;CHZ(&-L87-S
M(&%L;&]W(&UA;F%G:6YG(&]F(&UA:6QB;WAE<R!O;B!)34%0('-E<G9E<G,N
M"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z/'!R93X*("H@("`G861M:6Y?
M=7-E<B<@("`@("!4:&4@;F%M92!O9B!A('5S97(@=VET:"!A9&UI;B!P<FEV
M:6QE9V5S+@H@*B`@("=A9&UI;E]P87-S=V]R9"<@(%1H92!P87-S=V]R9"!O
M9B!T:&4@861M:6YS=')A=&]R+CPO<')E/@H@*@H@*B!/<'1I;VYA;"!P87)A
M;65T97)S.CQP<F4^"B`J("`@)VAO<W1S<&5C)R`@("`@("!4:&4@:&]S=&YA
M;64@;W(@25`@861D<F5S<R!O9B!T:&4@<V5R=F5R+@H@*B`@("`@("`@("`@
M("`@("`@("`@1$5&055,5#H@)VQO8V%L:&]S="<*("H@("`G<&]R="<@("`@
M("`@("`@(%1H92!S97)V97(@<&]R="!T;R!W:&EC:"!W92!W:6QL(&-O;FYE
M8W0N"B`J("`@("`@("`@("`@("`@("`@("!)34%0(&ES(&=E;F5R86QL>2`Q
M-#,L('=H:6QE($E-05`M4U-,(&ES(&=E;F5R86QL>2`Y.3,N"B`J("`@("`@
M("`@("`@("`@("`@("!$149!54Q4.B`Q-#,*("H@("`G<')O=&]C;VPG("`@
M("`@(%1H92!C;VYN96-T:6]N('!R;W1O8V]L("AE+F<N("=I;6%P)RP@)W!O
M<#,G+"`G;FYT<"<I+@H@*B`@("`@("`@("`@("`@("`@("`@4')O=&]C;VP@
M:7,@;VYE(&]F("=I;6%P+VYO=&QS)R`H;W(@;VYL>2`G:6UA<"<@:68@>6]U
M"B`J("`@("`@("`@("`@("`@("`@("!H879E(&$@8RUC;&EE;G0@=F5R<VEO
M;B`R,#`P8R!O<B!O;&1E<BDL("=I;6%P+W-S;"<L"B`J("`@("`@("`@("`@
M("`@("`@("!O<B`G:6UA<"]S<VPO;F]V86QI9&%T92UC97)T)R`H9F]R(&$@
M<V5L9BUS:6=N960*("H@("`@("`@("`@("`@("`@("`@(&-E<G1I9FEC871E
M*2X*("H@("`@("`@("`@("`@("`@("`@($1%1D%53%0Z("=I;6%P)PH@*B`@
M("=U<V5R:&EE<F%R8VAY)R`@5&AE(&AI97)A<F-H>2!W:&5R92!U<V5R(&UA
M:6QB;WAE<R!A<F4@<W1O<F5D+@H@*B`@("`@("`@("`@("`@("`@("`@1$5&
M055,5#H@)W5S97(N)PH@*B`@("=D<VXG("`@("`@("`@("`@5&AE(&9U;&P@
M24U!4"!C;VYN96-T:6]N('-T<FEN9RX*("H@("`@("`@("`@("`@("`@("`@
M($EF(&YO="!P<F5S96YT+"!T:&ES(&ES(&)U:6QT(&9R;VT@)VAO<W1S<&5C
M)RP@)W!O<G0G"B`J("`@("`@("`@("`@("`@("`@("!A;F0@)W!R;W1O8V]L
M)R!P87)A;65T97)S+CPO<')E/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R])
M34%0+TE-05`O061M:6XN<&AP+'8@,2XU+C8N.2`R,#`V+S`U+S,Q(#$Y.C,Y
M.C0W('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!*
M86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@
M0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TE-05`*("HO
M"F-L87-S($E-05!?061M:6X@>PH*("`@("\J*@H@("`@("H@4&%R86UE=&5R
M(&AA<V@N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)%]P87)A;7,["@H@("`@+RHJ"B`@("`@*B!)34%0(')E<V]U<F-E+@H@
M("`@("H*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1?
M:6UA<#L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@=VET:"!A;&P@;F5C
M97-S87)Y('!A<F%M971E<G,*("`@("`J+PH@("`@9G5N8W1I;VX@24U!4%]!
M9&UI;B@D<&%R86US*0H@("`@>PH@("`@("`@("1D969A=6QT7W!A<F%M<R`]
M(&%R<F%Y*`H@("`@("`@("`@("`G:&]S='-P96,G(#T^("=L;V-A;&AO<W0G
M+`H@("`@("`@("`@("`G<&]R="<@/3X@)S$T,R<L"B`@("`@("`@("`@("=P
M<F]T;V-O;"<@/3X@)VEM87`G+`H@("`@("`@("`@("`G=7-E<FAI97)A<F-H
M>2<@/3X@)W5S97(N)PH@("`@("`@("D["B`@("`@("`@)'1H:7,M/E]P87)A
M;7,@/2!A<G)A>5]M97)G92@D9&5F875L=%]P87)A;7,L("1P87)A;7,I.PH*
M("`@("`@("`O*B!#<F5A=&4@1%-.('-T<FEN9RX@*B\*("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=D<VXG72DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)V1S;B==(#T@<W!R:6YT9B@G>R5S.B5D+R5S?2<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!O
M<G0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG<')O=&]C;VPG72D["B`@("`@("`@("`@
M("1T:&ES+3Y?<F5F(#T@)'1H:7,M/E]P87)A;7-;)V1S;B==.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7GLH6UXZ
M72LI.BA<9"LI7"\H6UY]72LI?2\G+"`D=&AI<RT^7W!A<F%M<ULG9'-N)UTL
M("1M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)VAO<W1S<&5C)UT@/2`D;6%T8VAE<ULQ73L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=P;W)T)UT@/2`D;6%T8VAE<ULR73L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=P<F]T;V-O;"==(#T@)&UA=&-H97-;
M,UT["B`@("`@("`@("`@("`@("`D=&AI<RT^7W)E9B`]('-P<FEN=&8H)WLE
M<SHE9"\E<WTG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P;W)T
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)W!R;W1O8V]L)UTI.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0V]N;F5C=',@=&\@=&AE($E-
M05`@<V5R=F5R('=I=&@@=&AE('!A<F%M971E<G,@<&%S<V5D('1O('1H90H@
M("`@("H@8V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!R97-O
M=7)C97QO8FIE8W0@($%N($E-05`@<F5S;W5R8V4@;W(@82!014%27T5R<F]R
M(&]N(&9A:6QU<F4*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H*0H@
M("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]I;6%P*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7VEM87`@/2!`:6UA<%]O<&5N*"1T:&ES+3Y?<F5F
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=A9&UI;E]U<V5R)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V%D;6EN7W!A<W-W
M;W)D)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M3U!?2$%,1D]014XI.PH@("`@("`@("`@("!I9B`H(21T:&ES+3Y?:6UA<"D@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]I;6%P(#T@4$5!4CHZ<F%I<V5%
M<G)O<BA?*")!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N
M(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D=&AI<RT^7VEM87`["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!9&1S(&$@;6%I;&)O>"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1M86EL8F]X("`@("`@5&AE(&UA:6QB;W@@;F%M92!T;R!A9&0N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R
M(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@861D36%I;&)O>"@D;6%I;&)O>"D*("`@('L*("`@("`@("!I
M9B`H:7-?82@D:6UA<"`]("1T:&ES+3Y?8V]N;F5C="@I+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D:6UA<#L*("`@("`@("!]"B`@
M("`@("`@:68@*"%`:6UA<%]C<F5A=&5M86EL8F]X*"1I;6%P+"`D=&AI<RT^
M7W)E9B`N("1T:&ES+3Y?<&%R86US6R=U<V5R:&EE<F%R8VAY)UT@+B`D;6%I
M;&)O>"DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M:6UA<%]L87-T7V5R<F]R*"DL("=H;W)D92YW87)N:6YG)RD["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]G<F%N=$%D;6EN4&5R;7,H)&UA
M:6QB;W@I.PH@("`@?0H*("`@("\J*@H@("`@("H@1W)A;G0@=&AE(&%D;6EN
M('5S97(@86QL(')I9VAT<R!O;B!T:&4@;6%I;&)O>"X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1M86EL8F]X("`@("`@('1H92!N86UE(&]F('1H92!M86EL8F]X(&]N('=H
M:6-H('=E('=I;&P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@9W)A;G0@=&AE('!E<FUI<W-I;VX*("`@("`J($!R971U<FX@;6EX960@
M5')U92!I9B!S=6-C97-S9G5L+"!O<B!014%27T5R<F]R(&]N(&9A:6QU<F4*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V=R86YT061M:6Y097)M<R@D;6%I;&)O
M>"D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+T%#3"YP:'`G.PH*("`@("`@("`D<&%R86US(#T@87)R87DH)W5S
M97)N86UE)R`]/B`D=&AI<RT^7W!A<F%M<ULG861M:6Y?=7-E<B==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`G<&%S<W=O<F0G(#T^("1T:&ES+3Y?<&%R
M86US6R=A9&UI;E]P87-S=V]R9"==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`G:&]S='-P96,G(#T^("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`G<&]R="<@/3X@)'1H:7,M/E]P87)A
M;7-;)W!O<G0G72P*("`@("`@("`@("`@("`@("`@("`@("`@)W!R;W1O8V]L
M)R`]/B`D=&AI<RT^7W!A<F%M<ULG<')O=&]C;VPG72D["B`@("`@("`@)&%C
M;"`]("9)34%07T%#3#HZ9F%C=&]R>2@G<F9C,C`X-B<L("1P87)A;7,I.PH@
M("`@("`@("1R97-U;'0@/2`D86-L+3YC<F5A=&5!0TPH)'1H:7,M/E]P87)A
M;7-;)W5S97)H:65R87)C:'DG72`N("1M86EL8F]X+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V%D;6EN7W5S
M97(G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=L)R`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W(G(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<R<@/3X@=')U92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=W)R`]/B!T<G5E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VDG(#T^('1R=64L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<"<@
M/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=C)R`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V0G(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G82<@/3X@=')U92DI.PH@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E<R!A(&UA:6QB;W@N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6%I;&)O>"`@5&AE(&UA:6QB
M;W@@=&\@9&5L971E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R
M=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V94UA:6QB;W@H)&UA:6QB
M;W@I"B`@("!["B`@("`@("`@:68@*&ES7V$H)&EM87`@/2`D=&AI<RT^7V-O
M;FYE8W0H*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&EM87`["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V=R86YT061M:6Y0
M97)M<R@D;6%I;&)O>"D["B`@("`@("`@:68@*"%`:6UA<%]D96QE=&5M86EL
M8F]X*"1I;6%P+"`D=&AI<RT^7W)E9B`N("1T:&ES+3Y?<&%R86US6R=U<V5R
M:&EE<F%R8VAY)UT@+B`D;6%I;&)O>"DI('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H:6UA<%]L87-T7V5R<F]R*"DL("=H;W)D92YW
M87)N:6YG)RD["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@3&ES="!A;&P@;6%I;&)O>&5S+@H@("`@("H*
M("`@("`J($YO=&4@=&AA="!T:&ES(&1O97,@;F]T('=O<FL@;VX@82!V:7)T
M=6%L+61O;6%I;B!E;F%B;&5D($-Y<G5S("AI="!W:6QL"B`@("`@*B!O;FQY
M(')E='5R;B!M86EL8F]X97,@:6X@=&AE(&1E9F%U;'0@9&]M86EN*2X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@87)R87D@;V8@;6%I;&)O
M>&5S+"!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&QI<W1-86EL8F]X97,H*0H@("`@>PH@("`@("`@
M(&EF("AI<U]A*"1I;6%P(#T@)'1H:7,M/E]C;VYN96-T*"DL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I;6%P.PH@("`@("`@('T*
M"B`@("`@("`@)&QI<W0@/2!`:6UA<%]L:7-T*"1I;6%P+"`D=&AI<RT^7W)E
M9BP@)'1H:7,M/E]P87)A;7-;)W5S97)H:65R87)C:'DG72`N("<E)RD["B`@
M("`@("`@:68@*"$D;&ES="D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH
M*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('!R96=?<F5P;&%C92@G+RXJ
M)R`N('!R96=?<75O=&4H)'1H:7,M/E]P87)A;7-;)W5S97)H:65R87)C:'DG
M72P@)R\G*2`N("<H+BHI+R<L("=<7#$G+"`D;&ES="D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#:&5C:R!W:&5T:&5R(&$@;6%I;&)O>"!E>&ES=',N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6%I;&)O>"`@(%1H92!M86EL
M8F]X('1O(&-H96-K+@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!I9B!M
M86EL8F]X(&5X:7-T<RP@9F%L<V4@:68@;F]T+"!O<B!A(%!%05)?17)R;W(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&UA:6QB;WA%>&ES=',H)&UA:6QB;W@I
M"B`@("!["B`@("`@("`@:68@*&ES7V$H)&EM87`@/2`D=&AI<RT^7V-O;FYE
M8W0H*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&EM
M87`["B`@("`@("`@?0H*("`@("`@("`D;&ES="`]($!I;6%P7VQI<W0H)&EM
M87`L("1T:&ES+3Y?<F5F+"`D=&AI<RT^7W!A<F%M<ULG=7-E<FAI97)A<F-H
M>2==("X@)&UA:6QB;W@I.PH@("`@("`@(&EF("@D;&ES="`]/3T@9F%L<V4I
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@8V]U;G0H)&QI<W0I(#X@,#L*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O24U!4"]#86-H92YP:'``````````````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#$R,34U`#$P-3$U-#,S-S0V`#`R,3<S-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@5&AE
M($E-05!?0V%C:&4Z.B!C;&%S<R!F86-I;&ET871E<R!I;B!C86-H:6YG(&]U
M='!U="!F<F]M('1H92!02%`@:6UA<`H@*B!E>'1E;G-I;VX@:6X@=&AE(&-U
M<G)E;G0@<V5S<VEO;BX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO24U!4"])
M34%0+T-A8VAE+G!H<"QV(#$N-"XQ,BXQ,2`R,#`V+S`T+S(X(#$U.C0S.C0P
M('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6-H
M865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]G
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S
M87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`S
M+C`*("H@0'!A8VMA9V4@2&]R9&5?24U!4`H@*B\*8VQA<W,@24U!4%]#86-H
M92!["@H@("`@+RHJ"B`@("`@*B!0;VEN=&5R('1O('1H92!S97-S:6]N(&-A
M8VAE+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1?8V%C:&4["@H@("`@+RHJ"B`@("`@*B!4:&4@8V%C:&5D(')E<W5L=',@
M;V8@:6UA<%]S=&%T=7,H*2!C86QL<RX*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7W-T871U<V-A8VAE(#T@87)R87DH*3L*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!R969E<F5N8V4@=&\@=&AE(&=L
M;V)A;"!)34%07T-A8VAE(&]B:F5C="P@;VYL>2!C<F5A=&EN9PH@("`@("H@
M:70@:68@:70@9&]E<VXG="!A;')E861Y(&5X:7-T+@H@("`@("H*("`@("`J
M(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH*("`@("`J("`@)&EM
M87!?8V%C:&4@/2`F24U!4%]#86-H93HZ<VEN9VQE=&]N*"D["B`@("`@*@H@
M("`@("H@0')E='5R;B!)34%07T-A8VAE("!4:&4@24U!4%]#86-H92!I;G-T
M86YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@I"B`@("![
M"B`@("`@("`@<W1A=&EC("1O8FIE8W0["@H@("`@("`@(&EF("@A:7-S970H
M)&]B:F5C="DI('L*("`@("`@("`@("`@)&]B:F5C="`](&YE=R!)34%07T-A
M8VAE*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&]B:F5C=#L*("`@
M('T*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*B\*("`@(&9U
M;F-T:6]N($E-05!?0V%C:&4H*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H
M)%]315-324].6R=I;6%P7V-A8VAE)UTI*2!["B`@("`@("`@("`@("1?4T53
M4TE/3ELG:6UA<%]C86-H92==(#T@87)R87DH*3L*("`@("`@("!]"B`@("`@
M("`@)'1H:7,M/E]C86-H92`]("8D7U-%4U-)3TY;)VEM87!?8V%C:&4G73L*
M("`@('T*"B`@("`O*BH*("`@("`J($=E="!D871A(&9R;VT@=&AE(&-A8VAE
M+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D:6UA<"`@(%1H92!)
M34%0(')E<V]U<F-E('-T<F5A;2X*("`@("`J($!P87)A;2!S=')I;F<@)&UA
M:6QB;W@@(%1H92!F=6QL("A[:&]S=&YA;65];6%I;&)O>"D@;6%I;&)O>"!N
M86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("`@("`@5&AE(&YA;64@
M;V8@82!S<&5C:69I8R!E;G1R>2!T;R!R971U<FXN"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D8VAE8VL@("!#:&5C:R!F;W(@=7!D871E9"!M86EL8F]X/PH@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!D871A(')E<75E<W1E
M9"P@;W(@9F%L<V4@:68@;F]T(&%V86EL86)L92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T0V%C:&4H)&EM87`L("1M86EL8F]X+"`D:V5Y(#T@;G5L;"P@
M)&-H96-K(#T@=')U92D*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]C86-H95LD;6%I;&)O>%TI*2!["B`@("`@("`@("`@(&EF("@A)&-H96-K
M('Q\("1T:&ES+3YC:&5C:T-A8VAE*"1I;6%P+"`D;6%I;&)O>"DI('L*("`@
M("`@("`@("`@("`@("1P='(@/2`F)'1H:7,M/E]C86-H95LD;6%I;&)O>%T[
M"B`@("`@("`@("`@("`@("!I9B`H(6ES7VYU;&PH)&ME>2DI('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)'!T<ELG9"==6R1K97E=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'!T<ELG9"==6R1K97E=
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1P=');)V0G73L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!)<R!T:&4@
M8V%C:&4@:6YF;W)M871I;VX@=7`M=&\M9&%T93\*("`@("`J"B`@("`@*B!`
M<&%R86T@<F5S;W5R8V4@)&EM87`@("!4:&4@24U!4"!R97-O=7)C92!S=')E
M86TN"B`@("`@*B!`<&%R86T@<W1R:6YG("1M86EL8F]X("!4:&4@9G5L;"`H
M>VAO<W1N86UE?6UA:6QB;W@I(&UA:6QB;W@@;F%M92X*("`@("`J($!P87)A
M;2!B;V]L96%N("1U<&1A=&4@(%-H;W5L9"!T:&4@8V%C:&4@240@<W1R:6YG
M(&)E('5P9&%T960_"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&EF(&-A8VAE(&EN9F]R;6%T:6]N('5P+71O+61A=&4L(&9A;'-E(&EF
M(&YO="X*("`@("`J+PH@("`@9G5N8W1I;VX@8VAE8VM#86-H92@D:6UA<"P@
M)&UA:6QB;W@L("1U<&1A=&4@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/E]C86-H95LD;6%I;&)O>%TI*2!["B`@("`@("`@("`@
M("1I9"`]("1T:&ES+3Y?9V5T0V%C:&5)1"@D:6UA<"P@)&UA:6QB;W@I.PH@
M("`@("`@("`@("!I9B`H)'1H:7,M/E]C86-H95LD;6%I;&)O>%U;)VLG72`]
M/2`D:60I('L*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M("`@("!](&5L<V5I9B`H)'5P9&%T92D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/G-T;W)E0V%C:&4H)&EM87`L("1M86EL8F]X*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T@96QS96EF("@D=7!D871E*2!["B`@("`@("`@("`@("1T
M:&ES+3YS=&]R94-A8VAE*"1I;6%P+"`D;6%I;&)O>"D["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%-T
M;W)E(&1A=&$@:6X@=&AE(&-A8VAE+@H@("`@("H*("`@("`J($!P87)A;2!R
M97-O=7)C92`D:6UA<"`@(%1H92!)34%0(')E<V]U<F-E('-T<F5A;2X*("`@
M("`J($!P87)A;2!S=')I;F<@)&UA:6QB;W@@(%1H92!F=6QL("A[:&]S=&YA
M;65];6%I;&)O>"D@;6%I;&)O>"!N86UE+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1V86QU97,@("`@5&AE(&1A=&$@=&\@861D('1O('1H92!C86-H92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<W1O<F5#86-H92@D:6UA<"P@)&UA:6QB;W@L
M("1V86QU97,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]C86-H95LD;6%I;&)O>%TI*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?8V%C:&5;)&UA:6QB;WA=(#T@87)R87DH)V0G(#T^(&%R<F%Y*"DI.PH@
M("`@("`@('T*("`@("`@("`D<'1R(#T@)B1T:&ES+3Y?8V%C:&5;)&UA:6QB
M;WA=.PH@("`@("`@("1P='(@/2!A<G)A>2@*("`@("`@("`@("`@)VLG(#T^
M("1T:&ES+3Y?9V5T0V%C:&5)1"@D:6UA<"P@)&UA:6QB;W@I+`H@("`@("`@
M("`@("`G9"<@/3X@87)R87E?;65R9V4H)'!T<ELG9"==+"`D=F%L=65S*0H@
M("`@("`@("D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N9"!C
M86-H97,@=&AE(')E<W5L=',@;V8@86X@:6UA<%]S=&%T=7,H*2!C86QL+@H@
M("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$N,@H@("`@("H*("`@("`J
M($!P87)A;2!R97-O=7)C92`D:6UA<"`@(%1H92!)34%0(')E<V]U<F-E('-T
M<FEN9RX*("`@("`J($!P87)A;2!S=')I;F<@)&UA:6QB;W@@(%1H92!F=6QL
M("A[:&]S=&YA;65];6%I;&)O>"D@;6%I;&)O>"!N86UE+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1D0VQA<W,@(%1H92!I;6%P7W-T871U<R@I(&]B:F5C
M="!O<B!T:&4@96UP='D@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9713=&%T=7,H)&EM87`L("1M86EL8F]X*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?9V5T0V%C:&5)1"@D:6UA<"P@)&UA:6QB;W@I.PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7W-T871U<V-A8VAE6R1M86EL8F]X73L*("`@('T*"B`@("`O
M*BH*("`@("`J($=E;F5R871E('1H92!U;FEQ=64@240@<W1R:6YG(&9O<B!T
M:&4@;6%I;&)O>"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)&EM87`@("!4:&4@24U!4"!R
M97-O=7)C92!S=')E86TN"B`@("`@*B!`<&%R86T@<W1R:6YG("1M86EL8F]X
M("!4:&4@9G5L;"`H>VAO<W1N86UE?6UA:6QB;W@I(&UA:6QB;W@@;F%M92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@02!U;FEQ=64@<W1R:6YG
M(&9O<B!T:&4@8W5R<F5N="!S=&%T92!O9B!T:&4@;6%I;&)O>"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V=E=$-A8VAE240H)&EM87`L("1M86EL8F]X*0H@
M("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]S=&%T=7-C86-H95LD
M;6%I;&)O>%TI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<W1A='5S8V%C:&5;
M)&UA:6QB;WA=(#T@0&EM87!?<W1A='5S*"1I;6%P+"`D;6%I;&)O>"P@4T%?
M04Q,*3L*("`@("`@("`@("`@:68@*"$D=&AI<RT^7W-T871U<V-A8VAE6R1M
M86EL8F]X72D@>PH@("`@("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H
M:6UA<%]L87-T7V5R<F]R*"DL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?3D]424-%*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I
M9B`H)'1H:7,M/E]S=&%T=7-C86-H95LD;6%I;&)O>%TI('L*("`@("`@("`@
M("`@)&]B(#T@)'1H:7,M/E]S=&%T=7-C86-H95LD;6%I;&)O>%T["B`@("`@
M("`@("`@(')E='5R;B!I;7!L;V1E*"=\)RP@87)R87DH)&]B+3YM97-S86=E
M<RP@)&]B+3YR96-E;G0L("1O8BT^=6YS965N+"`D;V(M/G5I9&YE>'0L("1O
M8BT^=6ED=F%L:61I='DI*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@)&UA:6QB;W@["B`@("`@("`@?0H@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O24U!4"]396%R8V@N<&AP````
M````````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0Q,S`Q`#$P-3$U-#,S
M-S0V`#`R,C$S,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&AE($E-05!?4V5A<F-H.CH@8VQA<W,@
M<&5R9F]R;7,@8V]M<&QE>"!S96%R8VAI;F<@;V8@86X@24U!4"!M86EL8F]X
M+@H@*@H@*B!#;&%S<V5S('1O(&AE;'`@=VET:"!C;VUP;&5X('-E87)C:&EN
M9R!O9B!A;B!)34%0(&UA:6QB;W@N("!4:&4@8G5I;'0M:6X*("H@4$A0('-E
M87)C:"@I(&9U;F-T:6]N(&]N;'D@86QL;W=S($E-05!V,B!S96%R8V@@<75E
M<FEE<R`H<V5E(%)&0R`Q,3<V*2X*("H@5&AI<R!L:6)R87)Y(&%L;&]W<R!M
M;W)E(&-O;7!L97@@<V5A<F-H97,@=&\@8F4@8W)E871E9"`H92YG+B!/4B!S
M96%R8VAE<RP*("H@<V5A<F-H:6YG('-P96-I9FEC(&AE861E<G,I+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R])34%0+TE-05`O4V5A<F-H+G!H<"QV(#$N
M,CDN,3`N,C4@,C`P-B\P-B\P-B`Q-3HT-#HR-R!S;'5S87)Z($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S
M87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,
M*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R
M861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO
M<F1E7TE-05`*("HO"F-L87-S($E-05!?4V5A<F-H('L*"B`@("`O*BH*("`@
M("`J(%1H92!H96%D97)S(&-A8VAE+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?:&5A9&5R<R`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*B!4:&4@<F5S=6QT<R!C86-H92X*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W)E<W5L="`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`@*B!4:&4@<&%R86UA=&5R(&QI<W0N"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A
M<G)A>2@I.PH*("`@("\J*@H@("`@("H@5&AE(&-H87)S970@;V8@=&AE('-E
M87)C:"!V86QU97,N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1?8VAA<G-E=#L*"B`@("`O*BH*("`@("`J($EN=&5R;F%L
M(&9L86<@=7-E9"!B>2!S96%R8VA-86EL8F]X*"DN"B`@("`@*@H@("`@("H@
M0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7W-E87)C:&9L86<@/2`P
M.PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(')E9F5R96YC92!T;R!T:&4@
M9VQO8F%L($E-05!?4V5A<F-H(&]B:F5C="P@;VYL>2!C<F5A=&EN9R!I=`H@
M("`@("H@:68@:70@9&]E<VXG="!A;')E861Y(&5X:7-T+@H@("`@("H*("`@
M("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH\8V]D93X*("`@
M("`J("`@)&EM87!?<V5A<F-H(#T@)DE-05!?4V5A<F-H.CIS:6YG;&5T;VXH
M*3L\+V-O9&4^"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@
M($%N>2!P87)A;65T97)S('1H92!C;VYS=')U8W1O<B!M87D@;F5E9"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N($E-05!?4V5A<F-H("!4:&4@24U!4%]396%R
M8V@@:6YS=&%N8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH
M)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<W1A=&EC("1O8FIE
M8W0["@H@("`@("`@(&EF("@A:7-S970H)&]B:F5C="DI('L*("`@("`@("`@
M("`@)&]B:F5C="`](&YE=R!)34%07U-E87)C:"@D<&%R86US*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D;V)J96-T.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG('1H92!F;VQL;W=I;F<@96YT
M<FEE<SH\<')E/@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("=P;W`S
M)R`]/B!B;V]L96%N("AU<VEN9R!03U`S(&-O;FYE8W1I;VX_*0H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("=C:&%R<V5T)R`]/B!S=')I;F<@*&-H
M87)S970@;V8@<V5A<F-H('9A;'5E<RD*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`G;F]?:6UA<%]S96%R8V@G(#T^('1R=64@:68@=&AE($E-05`@
M<V5R=F5R(&1O97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&YO="!S=7!P;W)T('1H92!C:&%R<V5T(&EN"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!T:&4@<V5A<F-H(&-O;6UA;F0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`\+W!R93X*("`@("`J+PH@("`@9G5N8W1I;VX@24U!4%]396%R8V@H
M)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]P87)A
M;7,@/2`D<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5A<F-H97,@
M;65S<V%G97,@8GD@04Q,(&AE861E<G,@*')A=&AE<B!T:&%N('1H92!L:6UI
M=&5D('-E="!P<F]V:61E9`H@("`@("H@8GD@:6UA<%]S96%R8V@H*2DN"B`@
M("`@*@H@("`@("H@0'!A<F%M($E-05!?4V5A<F-H7U%U97)Y("1Q=65R>2`@
M5&AE('-E87)C:"!Q=65R>2X*("`@("`J($!P87)A;2!R97-O=7)C92`D:6UA
M<"`@("`@("`@("`@($%N($E-05`@<F5S;W5R8V4@<W1R96%M+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;6)O>"`@("`@("`@("`@("`@5&AE(&YA;64@;V8@
M=&AE(&UA:6QB;W@@=&\@<V5A<F-H+B!&;W(*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%!/4#,L('1H:7,@<VAO=6QD(&)E(&5M
M<'1Y+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!L:7-T(&]F
M(&EN9&EC97,@=&AA="!M871C:"!T:&4@<V5A<F-H(')U;&5S(&EN('1H90H@
M("`@("H@("`@("`@("`@("`@("`@8W5R<F5N="!M86EL8F]X+@H@("`@("H@
M("`@("`@("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&5R<F]R+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!S96%R8VA-86EL8F]X*"1Q=65R>2P@)&EM
M87`L("1M8F]X*0H@("`@>PH@("`@("`@("\J($-H96-K(&9O<B!)34%0(&5X
M=&5N<VEO;BX@*B\*("`@("`@("!I9B`H(55T:6PZ.F5X=&5N<VEO;D5X:7-T
M<R@G:6UA<"<I*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"A014%2.CIR
M86ES945R<F]R*")4:&ES(&9U;F-T:6]N(')E<75I<F5S("=I;6%P)R!T;R!B
M92!B=6EL="!I;G1O(%!(4"XB*2P@7U]&24Q%7U\L(%]?3$E.15]?+"!F86QS
M92D["B`@("`@("`@?0H*("`@("`@("`O*B!/<&5N('1O('1H92!C;W)R96-T
M(&UA:6QB;W@N("HO"B`@("`@("`@:68@*"$D=&AI<RT^7W!A<F%M<ULG<&]P
M,R==*2!["B`@("`@("`@("`@(&EF("@A0&EM87!?<F5O<&5N*"1I;6%P+"`D
M;6)O>"P@3U!?4D5!1$].3%DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M87)R87DH*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@
M0VQE87(@=&AE('-E87)C:"!F;&%G+B`J+PH@("`@("`@("1T:&ES+3Y?<V5A
M<F-H9FQA9R`](#`["@H@("`@("`@(')E='5R;B`D=&AI<RT^7W-E87)C:$UA
M:6QB;W@H)'%U97)Y+"`D:6UA<"P@)&UB;W@I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4V5A<F-H97,@=&AE(&UA:6QB;W@@86YD('-O<G1S('1H92!R97-U
M;'1S+@H@("`@("H*("`@("`J($!P87)A;2!)34%07U-E87)C:%]1=65R>2`D
M<75E<GD@(%1H92!S96%R8V@@<75E<GDN"B`@("`@*B!`<&%R86T@<F5S;W5R
M8V4@)&EM87`@("`@("`@("`@("!!;B!)34%0(')E<V]U<F-E('-T<F5A;2X*
M("`@("`J($!P87)A;2!S=')I;F<@)&UB;W@@("`@("`@("`@("`@(%1H92!N
M86UE(&]F('1H92!M86EL8F]X('1O('-E87)C:"X*("`@("`J($!P87)A;2!I
M;G1E9V5R("1S;W)T8GD@("`@("`@("`@(%1H92!C<FET97)I82!T;R!S;W)T
M(&)Y("AS964*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EM87!?<V]R="@I*2X*("`@("`J($!P87)A;2!I;G1E9V5R("1S;W)T
M9&ER("`@("`@("`@(#$@9F]R(')E=F5R<V4@<V]R=&EN9RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@;&ES="!O9B!I;F1I8V5S('1H870@
M;6%T8V@@=&AE('-E87)C:"!R=6QE<R!I;B!T:&4*("`@("`J("`@("`@("`@
M("`@("`@(&-U<G)E;G0@;6%I;&)O>"!A;F0@<V]R=&5D+@H@("`@("H@("`@
M("`@("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S96%R8VA3;W)T36%I;&)O>"@D<75E<GDL("1I
M;6%P+"`D;6)O>"P@)'-O<G1B>2P@)'-O<G1D:7(@/2`P*0H@("`@>PH@("`@
M("`@("1I;F1I8V5S(#T@)'1H:7,M/G-E87)C:$UA:6QB;W@H)'%U97)Y+"`D
M:6UA<"P@)&UB;W@I.PH@("`@("`@(&EF("AI<U]A*"1I;F1I8V5S+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D:6YD:6-E<SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:6YD:6-E<U]S;W)T(#T@0&EM
M87!?<V]R="@D:6UA<"P@)'-O<G1B>2P@)'-O<G1D:7(L(%-%7U5)1"D["B`@
M("`@("`@("`@(')E='5R;B!A<G)A>5]V86QU97,H87)R87E?:6YT97)S96-T
M*"1I;F1I8V5S7W-O<G0L("1I;F1I8V5S*2D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@26YT97)N86P@=W)A<'!E<B!M971H;V0@=&\@:6UA
M<%]S96%R8V@@=&AA="!A;&QO=W,@8VAA<G-E="!A=V%R90H@("`@("H@<V5A
M<F-H97,@:68@879A:6QA8FQE+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?:6UA<%-E87)C:"@D:6UA<"P@
M)&-R:71E<FEA*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P
M87)A;7-;)V-H87)S970G72DI('L*("`@("`@("`@("`@:68@*&5M<'1Y*"1T
M:&ES+3Y?<&%R86US6R=N;U]I;6%P7V-H87)S970G72D@)B8*("`@("`@("`@
M("`@("`@('9E<G-I;VY?8V]M<&%R92AP:'!V97)S:6]N*"DL("<T+C,N,R<L
M("<^/2<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@0&EM87!?<V5A<F-H
M*"1I;6%P+"`D8W)I=&5R:6$L(%-%7U5)1"P@)'1H:7,M/E]P87)A;7-;)V-H
M87)S970G72D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D8W)I=&5R:6$@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1C<FET97)I
M82P@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72P@)U53+4%30TE))RD["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!`:6UA<%]S
M96%R8V@H)&EM87`L("1C<FET97)I82P@4T5?54E$*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($EN=&5R;F%L(&9U;F-T:6]N('1O('-E87)C:"!T:&4@;6%I
M;&)O>"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@9G5N8W1I;VX@7W-E87)C:$UA:6QB;W@H)'%U97)Y+"`D:6UA<"P@)&UB
M;W@I"B`@("!["B`@("`@("`@)&EN9&EC97,@/2!A<G)A>2@I.PH*("`@("`@
M("`D=&AI<RT^7W-E87)C:&9L86<@/2`P.PH*("`@("`@("`O*B!$;R!T:&4@
M<VEM<&QE('-E87)C:&5S('1H870@:6UA<%]S96%R8V@H*2!C86X@:&%N9&QE
M+B`J+PH@("`@("`@(&EF("@H)&]B(#T@)'%U97)Y+3YB=6EL9"@I*2D@>PH@
M("`@("`@("`@("!I9B`H)&]B+3YN;W0I('L*("`@("`@("`@("`@("`@(&EF
M("@A*"1I;F1I8V5S,2`]("1T:&ES+3Y?:6UA<%-E87)C:"@D:6UA<"P@)&]B
M+3YF;&%G<RDI*2!["B`@("`@("`@("`@("`@("`@("`@)&EN9&EC97,Q(#T@
M87)R87DH*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF
M("@A*"1I;F1I8V5S,B`]("1T:&ES+3Y?:6UA<%-E87)C:"@D:6UA<"P@)&]B
M+3YQ=65R>2DI*2!["B`@("`@("`@("`@("`@("`@("`@)&EN9&EC97,R(#T@
M87)R87DH*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1I
M;F1I8V5S(#T@87)R87E?9&EF9B@D:6YD:6-E<S$L("1I;F1I8V5S,BD["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I9B`H(2@D:6YD
M:6-E<R`]("1T:&ES+3Y?:6UA<%-E87)C:"@D:6UA<"P@)&]B+3YF=6QL<75E
M<GDI*2D@>PH@("`@("`@("`@("`@("`@("`@("1I;F1I8V5S(#T@87)R87DH
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+RH@4V5T('1H92!S96%R8V@@9FQA9RX@*B\*("`@("`@("`@("`@:68@
M*"1T:&ES+3Y?<V5A<F-H9FQA9R`]/2`P*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7W-E87)C:&9L86<@/2`Q.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("`O*B!0<F]C97-S(&5X=&5N9&5D('-E87)C:&5S+B`J+PH@
M("`@("`@(&EF("@H)&5X=&5N9&5D(#T@)'%U97)Y+3YE>'1E;F1E9%-E87)C
M:"@I*2D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]S96%R8VA0
M2%`H)&5X=&5N9&5D+"`D<75E<GDM/F9L86=S*"DL("1I;6%P+"`D;6)O>"D[
M"B`@("`@("`@("`@("\J(%-E="!T:&4@<V5A<F-H(&9L86<N("HO"B`@("`@
M("`@("`@(&EF("@D=&AI<RT^7W-E87)C:&9L86<@/3T@,"D@>PH@("`@("`@
M("`@("`@("`@)&EN9&EC97,@/2`D<F5S=6QT.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]S96%R8VAF;&%G(#T@,3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1I;F1I8V5S(#T@87)R87E?=F%L=65S*&%R<F%Y
M7VEN=&5R<V5C="@D:6YD:6-E<RP@)')E<W5L="DI.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O*B!0<F]C97-S('-I>F4@<V5A<F-H97,N
M("HO"B`@("`@("`@:68@*"@D<VEZ94]B(#T@)'%U97)Y+3YS:7IE4V5A<F-H
M*"DI*2!["B`@("`@("`@("`@("1O=F5R=FEE=R`]($!I;6%P7V9E=&-H7V]V
M97)V:65W*"1I;6%P+"!I;7!L;V1E*"<L)RP@)&EN9&EC97,I+"!&5%]5240I
M.PH@("`@("`@("`@("`D9G5N8R`](&-R96%T95]F=6YC=&EO;B@G)&$G+"`G
M<F5T=7)N("@D82`G("X@)'-I>F5/8BT^<VEZ96]P("X@)R`G("X@)'-I>F5/
M8BT^<VEZ92`N("<I.R<I.PH@("`@("`@("`@("`D<F5S=6QT(#T@87)R87DH
M*3L*("`@("`@("`@("`@9F]R96%C:"`H)&]V97)V:65W(&%S("1V86PI('L*
M("`@("`@("`@("`@("`@(&EF("@D9G5N8R@D=F%L+3YS:7IE*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1R97-U;'1;72`]("1V86PM/G5I9#L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)'1H
M:7,M/E]S96%R8VAF;&%G(#T](#`I('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<V5A<F-H9FQA9R`](#$["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)&EN9&EC97,@/2!A<G)A>5]V86QU97,H87)R87E?:6YT97)S96-T*"1I;F1I
M8V5S+"`D<F5S=6QT*2D["B`@("`@("`@?0H*("`@("`@("`O*B!0<F]C97-S
M($%.1"!S96%R8VAE<R!N;W<N("HO"B`@("`@("`@)&EN9&EC97,@/2`D=&AI
M<RT^7V1O06YD3W)396%R8V@H)'%U97)Y+3YA;F1396%R8V@H*2P@)&EM87`L
M("1M8F]X+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=A;F0G+"`D:6YD:6-E<RD["@H@("`@("`@("\J(%!R;V-E<W,@3U(@
M<V5A<F-H97,@;F]W+B`J+PH@("`@("`@("1I;F1I8V5S(#T@)'1H:7,M/E]D
M;T%N9$]R4V5A<F-H*"1Q=65R>2T^;W)396%R8V@H*2P@)&EM87`L("1M8F]X
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=O
M<B<L("1I;F1I8V5S*3L*"B`@("`@("`@<F5T=7)N("1I;F1I8V5S.PH@("`@
M?0H*("`@("\J*@H@("`@("H@26YT97)N86P@9G5N8W1I;VX@=&\@<V5A<F-H
M('1H92!M86EL8F]X+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!F=6YC=&EO;B!?9&]!;F1/<E-E87)C:"@D<75E<GDL("1I
M;6%P+"`D;6)O>"P@)&UO9&4L("1I;F1I8V5S+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&)A<V4@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H
M96UP='DH)'%U97)Y*2D@>PH@("`@("`@("`@("!R971U<FX@)&EN9&EC97,[
M"B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D<75E<GD@87,@)'9A;"D@
M>PH@("`@("`@("`@("!I9B`H:7-?82@D=F%L+"`G24U!4%]396%R8VA?475E
M<GDG*2D@>PH@("`@("`@("`@("`@("`@)'!R979S96%R8V@@/2`H96UP='DH
M)&EN9&EC97,I("8F("@D=&AI<RT^7W-E87)C:&9L86<@/3T@,"DI.PH@("`@
M("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?<V5A<F-H36%I;&)O>"@D
M=F%L+"`D:6UA<"P@)&UB;W@I.PH@("`@("`@("`@("`@("`@:68@*"1M;V1E
M(#T]("=A;F0G*2!["B`@("`@("`@("`@("`@("`@("`@+RH@268@=&AE(')E
M<W5L="!I<R!E;7!T>2!I;B!A;B!!3D0@<V5A<F-H+"!W92!K;F]W('1H870*
M("`@("`@("`@("`@("`@("`@("`@("!T:&4@96YT:7)E($%.1"!S96%R8V@@
M=VEL;"!B92!E;7!T>2!S;R!R971U<FX*("`@("`@("`@("`@("`@("`@("`@
M("!I;6UE9&EA=&5L>2X@*B\*("`@("`@("`@("`@("`@("`@("!I9B`H96UP
M='DH)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M(&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@("`@("`O*B!)9B!W92!H879E(')E86-H960@=&AI<R!P;VEN="P@86YD
M(&AA=F4@;F]T('!E<F9O<FUE9"!A"B`@("`@("`@("`@("`@("`@("`@("`@
M<V5A<F-H('EE="P@=V4@;75S="!U<V4@=&AE(')E<W5L=',@87,@=&AE(&EN
M9&EC97,*("`@("`@("`@("`@("`@("`@("`@("!L:7-T+B!7:71H;W5T('1H
M:7,@8VAE8VLL('1H92!I;F1I8V5S(&QI<W0@=VEL;"!A;'=A>7,*("`@("`@
M("`@("`@("`@("`@("`@("!B92!E;7!T>2!I9B!A;B!!3D0@<V5A<F-H(&ES
M('1H92!F:7)S="!S96%R8V@N("HO"B`@("`@("`@("`@("`@("`@("`@:68@
M*"1P<F5V<V5A<F-H*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1I;F1I
M8V5S(#T@)')E<W5L=#L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]S96%R8VAF;&%G(#T@,3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D:6YD:6-E<R`](&%R<F%Y7W9A
M;'5E<RAA<G)A>5]I;G1E<G-E8W0H)&EN9&EC97,L("1R97-U;'0I*3L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M(65M<'1Y*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("`@("`@)&EN9&EC
M97,@/2!A<G)A>5]U;FEQ=64H87)R87E?;65R9V4H)&EN9&EC97,L("1R97-U
M;'0I*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1I;F1I8V5S(#T@)'1H:7,M/E]D;T%N9$]R4V5A
M<F-H*"1V86PL("1I;6%P+"`D;6)O>"P@)&UO9&4L("1I;F1I8V5S*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;F1I8V5S
M.PH@("`@?0H*("`@("\J*@H@("`@("H@57-E<R!02%`@8F%S960@9G5N8W1I
M;VYS('1O('!E<F9O<FT@=&AE('-E87)C:"X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1D0VQA<W,@)&EM
M87!?<75E<GD@(%-E87)C:"!Q=65R>2X*("`@("`J($!P87)A;2!S=')I;F<@
M)&9L86=S("`@("`@("`@06YY(&%D9&ET:6]N86P@9FQA9W,N"B`@("`@*B!`
M<&%R86T@<F5S;W5R8V4@)&EM87`@("`@("`@($%N($E-05`@<F5S;W5R8V4@
M<W1R96%M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6)O>"`@("`@("`@("!4
M:&4@;F%M92!O9B!T:&4@<V5A<F-H(&UA:6QB;W@N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@5&AE(&QI<W0@;V8@:6YD:6-E<R!T:&%T(&UA=&-H
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5A<F-H4$A0*"1I;6%P7W%U97)Y
M+"`D9FQA9W,L("1I;6%P+"`D;6)O>"D*("`@('L*("`@("`@("`D:6YD:6-E
M<R`](&%R<F%Y*"D["@H@("`@("`@(&EF("AE;7!T>2@D9FQA9W,I*2!["B`@
M("`@("`@("`@("1F;&%G<R`]("=!3$PG.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG<&]P,R==*2D@>PH@("`@("`@
M("`@("`D;6)O>"`]("=03U`S)SL*("`@("`@("!]"@H@("`@("`@("1C86-H
M95]K97D@/2`D;6)O>"`N("=\)R`N("1F;&%G<SL*"B`@("`@("`@+RH@5V4@
M:&%V92!T;R!U<V4@<&%R<V5-24U%2&5A9&5R<R@I('1O(&=E="!E86-H(&AE
M861E<B!A;F0@<V5E(&EF(&%N>0H@("`@("`@("`J(&9I96QD(&UA=&-H97,N
M(%5S92!I;6%P7W-E87)C:"@I('1O(&=E="!T:&4@;&ES="!O9B!M97-S86=E
M(&EN9&EC97,*("`@("`@("`@*B!O<B!R971U<FX@96UP='D@;&ES="!I9B!N
M;R!S96%R8V@@<F5S=6QT<RX@*B\*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?<F5S=6QT6R1C86-H95]K97E=*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7W)E<W5L=%LD8V%C:&5?:V5Y72`]($!I;6%P7W-E87)C:"@D:6UA<"P@)&9L
M86=S+"!315]5240I.PH@("`@("`@('T*"B`@("`@("`@+RH@268@96UP='D@
M;65S<V%G92!L:7-T+"!R971U<FX@;F]W+B`J+PH@("`@("`@(&EF("AE;7!T
M>2@D=&AI<RT^7W)E<W5L=%LD8V%C:&5?:V5Y72DI('L*("`@("`@("`@("`@
M<F5T=7)N(&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("!I;F-L=61E7V]N
M8V4@)TAO<F1E+TU)344O4W1R=6-T=7)E+G!H<"<["@H@("`@("`@(&EF("@A
M:7-S970H)'1H:7,M/E]H96%D97)S6R1M8F]X72DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]H96%D97)S6R1M8F]X72`](&%R<F%Y*"D["B`@("`@("`@?0H*
M("`@("`@("`O*B!'970@=&AE(&AE861E<B]Q=65R>2!T;R!S96%R8V@@9F]R
M+B`J+PH@("`@("`@("1Q=65R>2`](')E<V5T*"1I;6%P7W%U97)Y+3YQ=65R
M>2D["B`@("`@("`@)&ME>2`]('-T<G1O;&]W97(H:V5Y*"1I;6%P7W%U97)Y
M+3YQ=65R>2DI.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W)E<W5L=%LD
M8V%C:&5?:V5Y72!A<R`D:6YD97@I('L*("`@("`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7VAE861E<G-;)&UB;WA=6R1I;F1E>%TI*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7VAE861E<G-;)&UB;WA=6R1I;F1E>%T@/2!-24U%
M7U-T<G5C='5R93HZ<&%R<V5-24U%2&5A9&5R<RA`:6UA<%]F971C:&AE861E
M<B@D:6UA<"P@)&EN9&5X+"!&5%]5240I+"!N=6QL+"!T<G5E*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D:"`]("8D=&AI<RT^7VAE861E<G-;)&UB
M;WA=6R1I;F1E>%T["@H@("`@("`@("`@("`O*B!792!N965D('1O(&1O(&$@
M8V%S92!I;G-E;G-I=&EV92!S96%R8V@@;VX@=&5X="!B96-A=7-E+"!F;W(*
M("`@("`@("`@("`@("H@97AA;7!L92P@92UM86EL(&%D9')E<W-E<R!M87D@
M;F]T(&)E(&-A=6=H="!C;W)R96-T;'D*("`@("`@("`@("`@("H@*&9I;'1E
M<FEN9R!F;W(@97AA;7!L94!E>&%M<&QE+F-O;2!W:6QL(&YO="!C871C:`H@
M("`@("`@("`@("`@*B!E>$%M<&QE0&5X86UP;&4N8V]M*2X@*B\*("`@("`@
M("`@("`@)&UA=&-H7W-U8V-E<W,@/2!F86QS93L*("`@("`@("`@("`@:68@
M*&ES<V5T*"1H6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@)&AD<E]A<G)A
M>2`]("AI<U]A<G)A>2@D:%LD:V5Y72DI(#\@)&A;)&ME>5T@.B!A<G)A>2@D
M:%LD:V5Y72D["B`@("`@("`@("`@("`@("!F;W)E86-H("@D:&1R7V%R<F%Y
M(&%S("1V86PI('L*("`@("`@("`@("`@("`@("`@("!I9B`H<W1R:7-T<B@D
M=F%L+"!S=')V86PH)'%U97)Y*2D@(3T](&9A;'-E*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1M871C:%]S=6-C97-S(#T@=')U93L*("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("@H)&EM87!?<75E<GDM/FYO="`F)B`A)&UA=&-H7W-U8V-E<W,I('Q\"B`@
M("`@("`@("`@("`@("`H(21I;6%P7W%U97)Y+3YN;W0@)B8@)&UA=&-H7W-U
M8V-E<W,I*2!["B`@("`@("`@("`@("`@("`D:6YD:6-E<UM=(#T@)&EN9&5X
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN
M9&EC97,["B`@("!]"@I]"@HO*BH*("H@5&AE($E-05!?4V5A<F-H7T]B:F5C
M=#HZ(&-L87-S(&ES('5S960@=&\@9F]R;75L871E('%U97)I97,@=&\@8F4@
M=7-E9"!W:71H"B`J('1H92!)34%07U-E87)C:#HZ(&-L87-S+@H@*@H@*B!`
M875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO
M<F%D;RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(
M;W)D95])34%0"B`J+PIC;&%S<R!)34%07U-E87)C:%]1=65R>2!["@H@("`@
M=F%R("1?86YD(#T@87)R87DH*3L*("`@('9A<B`D7V5X=&5N9&5D4V5A<F-H
M(#T@87)R87DH*3L*("`@('9A<B`D7V9L86=S(#T@87)R87DH*3L*("`@('9A
M<B`D7VYO="`](&9A;'-E.PH@("`@=F%R("1?;W(@/2!A<G)A>2@I.PH@("`@
M=F%R("1?<75E<GD@/2!N=6QL.PH@("`@=F%R("1?<VEZ92`](&YU;&P["B`@
M("!V87(@)%]S:7IE;W`@/2!N=6QL.PH*("`@(&9U;F-T:6]N($E-05!?4V5A
M<F-H7U%U97)Y*"D*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@86YY(&5X=&5N9&5D('-E87)C:&5S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!E>'1E;F1E9%-E87)C:"@I"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D
M=&AI<RT^7V5X=&5N9&5D4V5A<F-H*2D@>PH@("`@("`@("`@("`D<V5A<F-H
M(#T@)FYE=R!S=&1#;&%S<SL*("`@("`@("`@("`@)'-E87)C:"T^;F]T(#T@
M)'1H:7,M/E]N;W0["B`@("`@("`@("`@("1S96%R8V@M/G%U97)Y(#T@)'1H
M:7,M/E]E>'1E;F1E9%-E87)C:#L*("`@("`@("`@("`@<F5T=7)N("1S96%R
M8V@["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M<&%R86UE=&5R<R!F;W(@82!S:7IE('-E87)C:"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<VEZ95-E87)C:"@I"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH
M)'1H:7,M/E]S:7IE*2D@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@
M("`@("!]"B`@("`@("`@)&]B(#T@)FYE=R!S=&1#;&%S<SL*("`@("`@("`D
M;V(M/G-I>F4@/2`H9FQO870I)'1H:7,M/E]S:7IE.PH@("`@("`@("1O8BT^
M<VEZ96]P(#T@)'1H:7,M/E]S:7IE;W`["@H@("`@("`@(')E='5R;B`D;V([
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N>2!!3D0@<V5A<F-H
M97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%N9%-E87)C:"@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?86YD.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A;GD@3U(@<V5A<F-H97,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&]R4V5A<F-H*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]O
M<CL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&9L86=S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!F;&%G<R@I"B`@("!["B`@("`@("`@<F5T
M=7)N("@H96UP='DH)'1H:7,M/E]F;&%G<RDI(#\@)R<@.B!I;7!L;V1E*"<@
M)RP@)'1H:7,M/E]F;&%G<RDI.PH@("`@?0H*("`@("\J*@H@("`@("H@0G5I
M;&1S('1H92!)34%0('-E87)C:"!Q=65R>2X*("`@("`J+PH@("`@9G5N8W1I
M;VX@8G5I;&0H*0H@("`@>PH@("`@("`@("1S96%R8V@@/2`F;F5W('-T9$-L
M87-S.PH*("`@("`@("`D<V5A<F-H+3YN;W0@/2`D=&AI<RT^7VYO=#L*("`@
M("`@("`D<V5A<F-H+3YF;&%G<R`]("1T:&ES+3YF;&%G<R@I.PH*("`@("`@
M("!I9B`H96UP='DH)'1H:7,M/E]Q=65R>2DI('L*("`@("`@("`@("`@:68@
M*"%E;7!T>2@D=&AI<RT^7V]R*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("<G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1S96%R8V@M/G%U97)Y
M(#T@)T%,3"<["B`@("`@("`@("`@("1S96%R8V@M/FYO="`](&9A;'-E.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@D<V5A<F-H+3YN;W0@
M)B8@96UP='DH)'-E87)C:"T^9FQA9W,I*2!["B`@("`@("`@("`@("`@("`D
M<V5A<F-H+3YF;&%G<R`]("=!3$PG.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1S96%R8V@M/G%U97)Y(#T@)'1H:7,M/E]Q=65R>3L*("`@("`@("!]
M"B`@("`@("`@)'-E87)C:"T^9G5L;'%U97)Y(#T@*"%E;7!T>2@D<V5A<F-H
M+3YF;&%G<RD@/R`D<V5A<F-H+3YF;&%G<R`N("<@)R`Z("<G*2`N("1S96%R
M8V@M/G%U97)Y.PH*("`@("`@("!R971U<FX@)'-E87)C:#L*("`@('T*"B`@
M("`O*B!)34%0('-E87)C:"!M;V1I9FEE<G,N("HO"B`@("!F=6YC=&EO;B!?
M;6]D:69I97)S*"1O8BP@)&-M9"D*("`@('L*("`@("`@("!I9B`H:7-?82@D
M;V(L("=)34%07U-E87)C:%]1=65R>2<I*2!["B`@("`@("`@("`@("1O8B`]
M(&%R<F%Y*"1O8BD["B`@("`@("`@?0H@("`@("`@(&%R<F%Y7W!U<V@H)'1H
M:7,M/B1C;60L("1O8BD["B`@("!]"@H@("`@9G5N8W1I;VX@:6UA<$%N9"@D
M;V(I"B`@("!["B`@("`@("`@)'1H:7,M/E]M;V1I9FEE<G,H)&]B+"`G7V%N
M9"<I.PH@("`@?0H*("`@(&9U;F-T:6]N(&EM87!/<B@D;V(I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]M;V1I9FEE<G,H)&]B+"`G7V]R)RD["B`@("!]"@H@
M("`@+RH@24U!4"!396%R8V@@1FQA9W,N("HO"B`@("`O*B!4:&5R92!I<R!N
M;R!N965D('1O('-U<'!O<G0@=&AE($M%65=/4D0O54Y+15E73U)$('%U97)Y
M('-I;F-E('1H90H@("`@("`@:6YD:79I9'5A;"!K97EW;W)D<R!H879E(&ED
M96YT:6-A;"!F=6YC=&EO;F%L:71Y+B`J+PH@("`@9G5N8W1I;VX@7VEM87!&
M;&%G<R@D9FQA9RP@)&-M9"D*("`@('L*("`@("`@("`D8VUD(#T@*"1F;&%G
M*2`_("1C;60@.B`G54XG("X@)&-M9#L*("`@("`@("`D=&AI<RT^7V9L86=S
M6UT@/2`D8VUD.PH@("`@?0H*("`@(&9U;F-T:6]N(&%N<W=E<F5D*"1F;&%G
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:6UA<$9L86=S*"1F;&%G+"`G04Y3
M5T52140G*3L*("`@('T*"B`@("!F=6YC=&EO;B!D96QE=&5D*"1F;&%G*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?:6UA<$9L86=S*"1F;&%G+"`G1$5,151%
M1"<I.PH@("`@?0H*("`@(&9U;F-T:6]N(&9L86=G960H)&9L86<I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]I;6%P1FQA9W,H)&9L86<L("=&3$%'1T5$)RD[
M"B`@("!]"@H@("`@9G5N8W1I;VX@<V5E;B@D9FQA9RD*("`@('L*("`@("`@
M("`D=&AI<RT^7VEM87!&;&%G<R@D9FQA9RP@)U-%14XG*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!R96-E;G0H)&9L86<I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]I;6%P1FQA9W,H=')U92P@*"@D9FQA9RD@/R`G4D5#14Y4)R`Z("=/3$0G
M*2D["B`@("!]"@H@("`@9G5N8W1I;VX@:6UA<$YE=R@I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]I;6%P1FQA9W,H=')U92P@)TY%5R<I.PH@("`@?0H*("`@
M("\J($E-05`@2&5A9&5R(%-E87)C:"X@*B\*("`@(&9U;F-T:6]N(&AE861E
M<B@D:&5A9&5R+"`D<75E<GDL("1N;W0@/2!F86QS92D*("`@('L*("`@("`@
M("`D:&5A9&5R(#T@=6-F:7)S="AR=')I;2@D:&5A9&5R+"`G.B<I*3L*("`@
M("`@("`D<W1D2&1R<R`](&%R<F%Y*"=4;R<L("=#8R<L("=&<F]M)RP@)U-U
M8FIE8W0G*3L*("`@("`@("!I9B`H)'%U97)Y("$]("<G*2!["B`@("`@("`@
M("`@(&EF("AI;E]A<G)A>2@D:&5A9&5R+"`D<W1D2&1R<RDI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<75E<GD@/2!3=')I;F<Z.G5P<&5R*"1H96%D
M97(I("X@)R`B)R`N(&%D9'-L87-H97,H)'%U97)Y*2`N("<B)SL*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?97AT96YD
M961396%R8VA;)&AE861E<ET@/2`D<75E<GD["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)'1H:7,M/E]N;W0@/2`D;F]T.PH@("`@("`@('T*("`@('T*
M"B`@("`O*B!)34%0($1A=&4@4V5A<F-H+B`J+PH@("`@9G5N8W1I;VX@7VEM
M87!$871E*"1D87DL("1M;VYT:"P@)'EE87(L("1C;60I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]Q=65R>2`]("1C;60@+B`G("<@+B!D871E*")D+4TM>2(L
M(&UK=&EM92@P+"`P+"`P+"`D;6]N=&@L("1D87DL("1Y96%R*2D["B`@("!]
M"@H@("`@9G5N8W1I;VX@8F5F;W)E*"1D87DL("1M;VYT:"P@)'EE87(I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]I;6%P1&%T92@D9&%Y+"`D;6]N=&@L("1Y
M96%R+"`G0D5&3U)%)RD["B`@("!]"@H@("`@9G5N8W1I;VX@<VEN8V4H)&1A
M>2P@)&UO;G1H+"`D>65A<BD*("`@('L*("`@("`@("`D=&AI<RT^7VEM87!$
M871E*"1D87DL("1M;VYT:"P@)'EE87(L("=324Y#12<I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&]N*"1D87DL("1M;VYT:"P@)'EE87(I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]I;6%P1&%T92@D9&%Y+"`D;6]N=&@L("1Y96%R+"`G3TXG
M*3L*("`@('T*"B`@("`O*B!)34%0(%1E>'0@<V5A<F-H97,N("HO"B`@("!F
M=6YC=&EO;B!B;V1Y*"1Q=65R>2P@)&YO="`](&9A;'-E*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?<75E<GD@/2`G0D]$62`B)R`N("1Q=65R>2`N("<B)SL*
M("`@("`@("`D=&AI<RT^7VYO="`]("1N;W0["B`@("!]"@H@("`@9G5N8W1I
M;VX@=&5X="@D<75E<GDL("1N;W0@/2!F86QS92D*("`@('L*("`@("`@("`D
M=&AI<RT^7W%U97)Y(#T@)U1%6%0@(B<@+B`D<75E<GD@+B`G(B<["B`@("`@
M("`@)'1H:7,M/E]N;W0@/2`D;F]T.PH@("`@?0H*("`@("\J($E-05`@4VEZ
M92!S96%R8VAE<RX@*B\*("`@(&9U;F-T:6]N('-I>F4H)'-I>F4L("1O<&5R
M871O<BD*("`@('L*("`@("`@("`D=&AI<RT^7W-I>F4@/2`D<VEZ93L*("`@
M("`@("`D=&AI<RT^7W-I>F5O<"`]("1O<&5R871O<CL*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TE-05`O4V]R
M="YP:'``````````````````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S$P
M-0`Q,#4Q-30S,S<T-@`P,C$V-C``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J($E-05!?4V]R="!P<F]V
M:61E<R!F=6YC=&EO;G,@9F]R('-O<G1I;F<@;&ES=',@;V8@24U!4"!M86EL
M8F]X97,O9F]L9&5R<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO24U!4"])
M34%0+U-O<G0N<&AP+'8@,2XV+C@N,3,@,C`P-B\P,B\Q-2`Q.#HP-SHU,B!S
M;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@36EC:&%E
M;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R
M>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP
M"B`J($!P86-K86=E($AO<F1E7TE-05`*("HO"F-L87-S($E-05!?4V]R="![
M"@H@("`@+RHJ"B`@("`@*B!4:&4@9&5L:6UI=&5R(&-H87)A8W1E<B!T;R!U
M<V4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?9&5L:6UI=&5R.PH*("`@("\J*@H@("`@("H@4VAO=6QD('=E('-O<G0@
M=VET:"`G24Y"3U@G(&%T('1H92!F<F]N="!O9B!T:&4@;&ES=#\*("`@("`J
M"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?<V]R=&EN
M8F]X.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9&5L:6UI=&5R("!4:&4@9&5L:6UI=&5R('5S
M960@=&\@<V5P87)A=&4@;6%I;&)O>&5S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!)34%07U-O<G0H)&1E;&EM:71E<BD*("`@('L*("`@("`@("`D=&AI<RT^
M7V1E;&EM:71E<B`]("1D96QI;6ET97(["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3;W)T(&$@;&ES="!O9B!M86EL8F]X97,@*&)Y('9A;'5E*2X*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)B1M8F]X("`@(%1H92!L:7-T(&]F(&UA
M:6QB;WAE<R!T;R!S;W)T+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&EN8F]X
M("!7:&5N('-O<G1I;F<L(&%L=V%Y<R!P=70@)TE.0D]8)R!A="!T:&4@:&5A
M9"!O9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!T:&4@;&ES=#\*
M("`@("`J($!P87)A;2!B;V]L96%N("1I;F1E>"`@36%I;G1A:6X@:6YD97@@
M87-S;V-I871I;VX_"B`@("`@*B\*("`@(&9U;F-T:6]N('-O<G1-86EL8F]X
M97,H)B1M8F]X+"`D:6YB;W@@/2!T<G5E+"`D:6YD97@@/2!F86QS92D*("`@
M('L*("`@("`@("`D=&AI<RT^7W-O<G1I;F)O>"`]("1I;F)O>#L*("`@("`@
M("!I9B`H)&EN9&5X*2!["B`@("`@("`@("`@('5A<V]R="@D;6)O>"P@87)R
M87DH)B1T:&ES+"`G7VUB;WA?8VUP)RDI.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@('5S;W)T*"1M8F]X+"!A<G)A>2@F)'1H:7,L("=?;6)O>%]C
M;7`G*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4V]R="!A
M(&QI<W0@;V8@;6%I;&)O>&5S("AB>2!K97DI+@H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`F)&UB;W@@("`@5&AE(&QI<W0@;V8@;6%I;&)O>&5S('1O
M('-O<G0L('=I=&@@=&AE(&ME>7,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@8F5I;F<@=&AE(&UA:6QB;W@@;F%M97,N"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D:6YB;W@@(%=H96X@<V]R=&EN9RP@86QW87ES('!U="`G24Y"
M3U@G(&%T('1H92!H96%D(&]F"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@('1H92!L:7-T/PH@("`@("HO"B`@("!F=6YC=&EO;B!S;W)T36%I;&)O
M>&5S0GE+97DH)B1M8F]X+"`D:6YB;W@@/2!T<G5E*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?<V]R=&EN8F]X(#T@)&EN8F]X.PH@("`@("`@('5K<V]R="@D
M;6)O>"P@87)R87DH)B1T:&ES+"`G7VUB;WA?8VUP)RDI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@2&EE<F%R8VAI8V%L(&9O;&1E<B!S;W)T:6YG(&9U;F-T
M:6]N("AU<V5D('=I=&@@=7-O<G0H*2DN"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D82`@0V]M
M<&%R:7-O;B!I=&5M(#$N"B`@("`@*B!`<&%R86T@<W1R:6YG("1B("!#;VUP
M87)I<V]N(&ET96T@,BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@
M(%-E92!U<V]R="@I+@H@("`@("HO"B`@("!F=6YC=&EO;B!?;6)O>%]C;7`H
M)&$L("1B*0H@("`@>PH@("`@("`@("\J($%L=V%Y<R!R971U<FX@24Y"3U@@
M87,@(G-M86QL97(B+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W-O<G1I;F)O
M>"D@>PH@("`@("`@("`@("!I9B`H<W1R8V%S96-M<"@D82P@)TE.0D]8)RD@
M/3T@,"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("TQ.PH@("`@("`@("`@
M("!](&5L<V5I9B`H<W1R8V%S96-M<"@D8BP@)TE.0D]8)RD@/3T@,"D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(#$["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("1A7W!A<G1S(#T@97AP;&]D92@D=&AI<RT^7V1E;&EM
M:71E<BP@)&$I.PH@("`@("`@("1B7W!A<G1S(#T@97AP;&]D92@D=&AI<RT^
M7V1E;&EM:71E<BP@)&(I.PH*("`@("`@("`D85]C;W5N="`](&-O=6YT*"1A
M7W!A<G1S*3L*("`@("`@("`D8E]C;W5N="`](&-O=6YT*"1B7W!A<G1S*3L*
M"B`@("`@("`@)&E-87@@/2!M:6XH)&%?8V]U;G0L("1B7V-O=6YT*3L*"B`@
M("`@("`@9F]R("@D:2`](#`[("1I(#P@)&E-87@[("1I*RLI('L*("`@("`@
M("`@("`@:68@*"1A7W!A<G1S6R1I72`A/2`D8E]P87)T<ULD:5TI('L*("`@
M("`@("`@("`@("`@("\J($EF(&]N;'D@;VYE(&]F('1H92!F;VQD97)S(&ES
M('5N9&5R($E.0D]8+"!R971U<FX@:70@87,*("`@("`@("`@("`@("`@("`J
M(")S;6%L;&5R(BX@*B\*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7W-O
M<G1I;F)O>"`F)B`H)&D@/3T@,"DI('L*("`@("`@("`@("`@("`@("`@("`D
M85]B87-E(#T@*'-T<F-A<V5C;7`H)&%?<&%R='-;,%TL("=)3D)/6"<I(#T]
M(#`I.PH@("`@("`@("`@("`@("`@("`@("1B7V)A<V4@/2`H<W1R8V%S96-M
M<"@D8E]P87)T<ULP72P@)TE.0D]8)RD@/3T@,"D["B`@("`@("`@("`@("`@
M("`@("`@:68@*"1A7V)A<V4@)B8@(21B7V)A<V4I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("TQ.PH@("`@("`@("`@("`@("`@("`@('T@
M96QS96EF("@A)&%?8F%S92`F)B`D8E]B87-E*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`Q.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1C;7`@/2!S=')N871C
M87-E8VUP*"1A7W!A<G1S6R1I72P@)&)?<&%R='-;)&E=*3L*("`@("`@("`@
M("`@("`@(&EF("@D8VUP(#T](#`I('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@<W1R8VUP*"1A7W!A<G1S6R1I72P@)&)?<&%R='-;)&E=*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(')E='5R;B`D8VUP.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@*"1A7V-O
M=6YT("T@)&)?8V]U;G0I.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+TE-05`O5&AR96%D+G!H<```````````````````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`Q-30W-@`Q,#4Q-30S,S<T-@`P,C(Q-3(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J($E-05!?5&AR96%D('!R;W9I9&5S(&9U;F-T:6]N<R!F;W(@=V]R:VEN
M9R!W:71H(&EM87!?=&AR96%D*"D@;W5T<'5T+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R])34%0+TE-05`O5&AR96%D+G!H<"QV(#$N-"XQ,"XQ,R`R,#`V
M+S`Q+S`Q(#(Q.C(X.C(Q(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M-"TR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!C=7)E8V%N=&DN;W)G
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\
M<VQU<V%R>D!C=7)E8V%N=&DN;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*
M("H@0'!A8VMA9V4@2&]R9&5?24U!4`H@*B\*8VQA<W,@24U!4%]4:')E860@
M>PH*("`@("\J*@H@("`@("H@:6UA<%]T:')E860H*2!O=71P=70N"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]T:')E861A
M<G)A>3L*"B`@("`O*BH*("`@("`J($EN=&5R;F%L('1H<F5A9"!D871A('-T
M<G5C='5R92X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D7W1H<F5A9"`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!!<G)A
M>2!I;F1E>"!T;R!-97-S86=E(&EN9&5X(&QO;VMU<"!A<G)A>2X*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7VQO;VMU<"`]
M(&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)&]B("!/=71P=70@9G)O;2!I;6%P7W1H
M<F5A9"@I+@H@("`@("HO"B`@("!F=6YC=&EO;B!)34%07U1H<F5A9"@D;V(I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]T:')E861A<G)A>2`]("1O8CL*("`@
M("`@("`D=&AI<RT^7W!R;V-E<W-3=')U8W1U<F4H*3L*("`@('T*"B`@("\J
M*@H@("`@("H@1V5T<R!T:&4@:6YD96YT:6]N(&QE=F5L(&9O<B!A;B!)34%0
M(&UE<W-A9V4@:6YD97@N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&EN9&5X("!4:&4@24U!4"!M97-S86=E(&EN9&5X+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@(%)E='5R;G,@=&AE('1H<F5A9"!I;F1E;G0@;&5V
M96P@:68@)&EN9&5X(&9O=6YD+@H@("`@("H@("`@("`@("`@("`@("`@4F5T
M=7)N<R!F86QS92!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9714:')E861);F1E;G0H)&EN9&5X*0H@("`@>PH@("`@("`@("1K97D@/2`D
M=&AI<RT^7V=E=$ME>2@D:6YD97@I.PH@("`@("`@(&EF("@A:7-?;G5L;"@D
M:V5Y*2D@>PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]T:')E861;
M)&ME>5U;)VQE=F5L)UTI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]T:')E861;)&ME>5U;)VQE=F5L)UT["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'971S('1H92!B87-E('1H<F5A9"!I;F1E>"!F;W(@86X@24U!
M4"!M97-S86=E(&EN9&5X+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R
M("1I;F1E>"`@5&AE($E-05`@;65S<V%G92!I;F1E>"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!2971U<FYS('1H92!B87-E($E-05`@:6YD97@@
M:68@)&EN9&5X(&ES('!A<G0@;V8@80H@("`@("H@("`@("`@("`@("`@("`@
M=&AR96%D+@H@("`@("H@("`@("`@("`@("`@("`@4F5T=7)N<R!F86QS92!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714:')E861"87-E
M*"1I;F1E>"D*("`@('L*("`@("`@("`D:V5Y(#T@)'1H:7,M/E]G971+97DH
M)&EN9&5X*3L*("`@("`@("!I9B`H(6ES7VYU;&PH)&ME>2DI('L*("`@("`@
M("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W1H<F5A9%LD:V5Y75LG8F%S92==
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&AR96%D6R1K
M97E=6R=B87-E)UT["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($ES('1H:7,@
M:6YD97@@=&AE(&QA<W0@:6X@=&AE(&-U<G)E;G0@;&5V96P_"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&EN9&5X("!4:&4@24U!4"!M97-S86=E
M(&EN9&5X+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@4F5T=7)N
M<R!T<G5E(&EF("1I;F1E>"!I<R!T:&4@;&%S="!E;&5M96YT(&EN('1H90H@
M("`@("H@("`@("`@("`@("`@("`@("!C=7)R96YT('1H<F5A9"!L979E;"X*
M("`@("`J("`@("`@("`@("`@("`@("`@4F5T=7)N<R!F86QS92!I9B!N;W0L
M(&]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QA<W1);DQE
M=F5L*"1I;F1E>"D*("`@('L*("`@("`@("`D:V5Y(#T@)'1H:7,M/E]G971+
M97DH)&EN9&5X*3L*("`@("`@("!I9B`H(6ES7VYU;&PH)&ME>2DI('L*("`@
M("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W1H<F5A9%LD:V5Y75LG;&%S
M="==*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&AR96%D
M6R1K97E=6R=L87-T)UT["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($1O('1H
M92!M97-S86=E(&EN9&5X("T^(&%R<F%Y(&EN9&5X(&QO;VMU<"X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D:6YD97@@(%1H92!)34%0(&UE<W-A9V4@:6YD97@N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&%R<F%Y(&EN9&5X('9A;'5E
M(&]R(&YU;&P@:68@;F\@:6YD97@N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G
M971+97DH)&EN9&5X*0H@("`@>PH@("`@("`@(')E='5R;B`H:7-S970H)'1H
M:7,M/E]L;V]K=7!;)&EN9&5X72DI(#\@)'1H:7,M/E]L;V]K=7!;)&EN9&5X
M72`Z(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE('-O
M<G1E9"!L:7-T(&]F(&UE<W-A9V5S(&EN9&EC97,N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)&YE=R`@5')U92!F;W(@;F5W97-T(&9I<G-T+"!F
M86QS92!F;W(@;VQD97-T(&9I<G-T+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@(%1H92!S;W)T960@;&ES="!O9B!M97-S86=E<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@;65S<V%G94QI<W0H)&YE=RD*("`@('L*("`@("`@("!R
M971U<FX@*"1N97<I(#\@87)R87E?<F5V97)S92AA<G)A>5]K97ES*"1T:&ES
M+3Y?;&]O:W5P*2D@.B!A<G)A>5]K97ES*"1T:&ES+3Y?;&]O:W5P*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&QI<W0@;V8@;65S<V%G
M97,@:6X@=&AE(&-U<G)E;G0@=&AR96%D+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1I;F1E>"`@5&AE($E-05`@:6YD97@@;V8@=&AE(&-U<G)E
M;G0@;65S<V%G92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&QI
M<W0@;V8@24U!4"!M97-S86=E(&EN9&EC97,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=%1H<F5A9"@D:6YD97@I"B`@("!["B`@("`@("`@+RH@1FEN9"!T
M:&4@8F5G:6YN:6YG(&]F('1H92!T:')E860N("HO"B`@("`@("`@)&)E9VEN
M(#T@)'1H:7,M/F=E=%1H<F5A9$)A<V4H)&EN9&5X*3L*("`@("`@("`D:V5Y
M(#T@)'1H:7,M/E]G971+97DH)&)E9VEN*3L*("`@("`@("!I9B`H:7-?;G5L
M;"@D:V5Y*2!\?"!E;7!T>2@D8F5G:6XI*2!["B`@("`@("`@("`@(')E='5R
M;B!A<G)A>2@D:6YD97@I.PH@("`@("`@('T*"B`@("`@("`@+RH@5V]R:R!F
M;W)W87)D(&9R;VT@=&AE(&9I<G-T('1H<F5A9"!E;&5M96YT('1O(&9I;F0@
M=&AE(&5N9"!O9B!T:&4*("`@("`@("`@*B!T:')E860N("HO"B`@("`@("`@
M)'1H<F5A9%]L:7-T(#T@87)R87DH)'1H:7,M/E]T:')E861;)&ME>5U;)VEN
M9&5X)UTI.PH@("`@("`@('=H:6QE("@K*R1K97DI('L*("`@("`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^7W1H<F5A9%LD:V5Y72DI('L*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1C=7)R
M(#T@)'1H:7,M/E]T:')E861;)&ME>5T["B`@("`@("`@("`@(&EF("@D8W5R
M<ELG8F%S92==(#T]("1B96=I;BD@>PH@("`@("`@("`@("`@("`@)'1H<F5A
M9%]L:7-T6UT@/2`D=&AI<RT^7W1H<F5A9%LD:V5Y75LG:6YD97@G73L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H<F5A9%]L
M:7-T.PH@("`@?0H*("`@("\J*@H@("`@("H@4')O8V5S<R!T:&4@;W5T<'5T
M(&9R;VT@:6UA<%]T:')E860H*2!I;G1O(&%N(&EN=&5R;F%L(&1A=&$@<W1R
M=6-T=7)E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!F=6YC=&EO;B!?<')O8V5S<U-T<G5C='5R92@I"B`@("!["B`@("`@
M("`@)&-O;G1A:6YE<B`]("1C;VYT86EN97)?8F%S92`]("1L87-T7VEN9&5X
M(#T@)'1H<F5A9%]B87-E(#T@)'1H<F5A9%]B87-E7VED>"`]("!N=6QL.PH@
M("`@("`@("1I;F1I8V5S(#T@87)R87DH*3L*("`@("`@("`D:2`]("1L87-T
M7VD@/2`D;&5V96P@/2`P.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W1H
M<F5A9&%R<F%Y(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`D<&]S
M(#T@<W1R<&]S*"1K97DL("<N)RD["B`@("`@("`@("`@("1I;F1E>"`]('-U
M8G-T<B@D:V5Y+"`P+"`D<&]S*3L*("`@("`@("`@("`@)'1Y<&4@/2!S=6)S
M='(H)&ME>2P@)'!O<R`K(#$I.PH*("`@("`@("`@("`@<W=I=&-H("@D='EP
M92D@>PH@("`@("`@("`@("!C87-E("=N=6TG.@H@("`@("`@("`@("`@("`@
M:68@*"1V86P@/3T](#`I('L*("`@("`@("`@("`@("`@("`@("`D8V]N=&%I
M;F5R(#T@)&EN9&5X.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D:2LK.PH@("`@("`@("`@("`@("`@("`@(&EF("AI
M<U]N=6QL*"1C;VYT86EN97(I("8F(&5M<'1Y*"1L979E;"DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H<F5A9%]B87-E(#T@)'9A;#L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H<F5A9%]B87-E7VED>"`]("1I;F1E>#L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]L;V]K=7!;)'9A;%T@/2`D:6YD97@["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]T:')E861;)&EN9&5X72`](&%R<F%Y*"D["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]T:')E861;)&EN9&5X75LG:6YD97@G72`]
M("1V86P["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@(&-A<V4@)VYE>'0G.@H@("`@("`@("`@("`@("`@
M:68@*"%I<U]N=6QL*"1C;VYT86EN97(I("8F("@D8V]N=&%I;F5R(#T]/2`D
M:6YD97@I*2!["B`@("`@("`@("`@("`@("`@("`@)&-O;G1A:6YE<E]B87-E
M(#T@)'1H:7,M/E]T:')E861A<G)A>5LD=F%L("X@)RYN=6TG73L*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&DK*SL*
M("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7VYU;&PH)&-O;G1A:6YE<BDI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T:')E861;)&EN
M9&5X75LG8F%S92==(#T@)&-O;G1A:6YE<E]B87-E.PH@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?=&AR96%D6R1I;F1E>%U;)V)A<V4G72`]("@A96UP='DH)&QE=F5L*2!\
M?"`H)'9A;"`A/2`P*2D@/R`D=&AR96%D7V)A<V4@.B!N=6QL.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D;&5V96PK*SL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`G8G)A;F-H)SH*("`@("`@("`@("`@("`@(&EF("@D
M8V]N=&%I;F5R(#T]/2`D:6YD97@I('L*("`@("`@("`@("`@("`@("`@("`D
M8V]N=&%I;F5R(#T@)&-O;G1A:6YE<E]B87-E(#T@;G5L;#L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W1H<F5A9%LD;&%S=%]I;F1E>%U;)VQA<W0G
M72`]('1R=64["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?=&AR96%D6R1I;F1E>%U;)VQE=F5L)UT@/2`D
M;&5V96PM+3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W1H<F5A9%LD
M:6YD97A=6R=L87-T)UT@/2`A*"%I<U]N=6QL*"1C;VYT86EN97(I("8F(&5M
M<'1Y*"1L979E;"DI.PH@("`@("`@("`@("`@("`@("`@(&EF("@D:6YD97@@
M/3T]("1T:')E861?8F%S95]I9'@I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&EN9&5X(#T@;G5L;#L*("`@("`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H(65M<'1Y*"1L979E;"D@)B8*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(6ES7VYU;&PH)&QA<W1?:6YD97@I("8F"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&ES<V5T*"1T:&ES+3Y?=&AR96%D6R1L87-T7VEN
M9&5X72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T:')E
M861;)&QA<W1?:6YD97A=6R=L87-T)UT@/2`H)&QA<W1?:2`]/2`H)&D@+2`Q
M*2D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)&QA<W1?:6YD97@@/2`D:6YD97@["B`@("`@("`@
M("`@("`@("`D;&%S=%]I(#T@)&DK*SL*("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TE-05`O
M5')E92YP:'``````````````````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$V
M-30Q,P`Q,#4Q-30S,S<T-@`P,C$V,S<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RH@0V]N<W1A;G1S(&9O<B!M
M86EL8F]X16QT(&%T=')I8G5T97,N"B`J($%L;"!V97)S:6]N<R!O9B!C+6-L
M:65N="`H8RUC;&EE;G0O;6%I;"YH*2!D969I;F4@=&AE<V4@8V]N<W1A;G1S
M.@H@*B`@($Q!5%1?3D])3D9%4DE/4E,@*&QO;F<I(#!X,2`](#$*("H@("!,
M05147TY/4T5,14-4("AL;VYG*2`P>#(@/2`R"B`J("`@3$%45%]-05)+140@
M*&QO;F<I(#!X-"`](#0*("H@("!,05147U5.34%22T5$("AL;VYG*2`P>#@@
M/2`X"B`J"B`J($YE=V5R('9E<G-I;VYS(&]F(&,M8VQI96YT("AI;6%P+3(P
M,#(@86YD(&=R96%T97(I(&1E9FEN92!T:&5S92!C;VYS=&%N=',Z"B`J("`@
M3$%45%]2149%4E)!3"`H;&]N9RD@,'@Q,"`](#$V"B`J("`@3$%45%](05-#
M2$E,1%)%3B`H;&]N9RD@,'@R,"`](#,R"B`J("`@3$%45%](05-.3T-(24Q$
M4D5.("AL;VYG*2`P>#0P(#T@-C0*("H@+BXN8G5T('1H97-E(&-O;G-T86YT
M(&YA;65S(&1O(&YO="!A<'!E87(@:6X@4$A0('5N=&EL(%!(4"`T+C,N-2!A
M;F0@-2XP+@H@*B\*:68@*"%D969I;F5D*"=,05147TA!4T-(24Q$4D5.)RDI
M('L*("`@($!D969I;F4H)TQ!5%1?4D5&15)204PG+"`Q-BD["B`@("!`9&5F
M:6YE*"=,05147TA!4T-(24Q$4D5.)RP@,S(I.PH@("`@0&1E9FEN92@G3$%4
M5%](05-.3T-(24Q$4D5.)RP@-C0I.PI]"@HO*B!3=&%R="!A="`Q,C@@9F]R
M(&]U<B!L;V-A;"!B:71M87-K<R!T;R!A;&QO=R!F;W(@=&AE(&,M8VQI96YT
M($Q!5%1?*@H@("!C;VYS=&%N=',N("HO"F1E9FEN92@G24U!4%12145?14Q4
M7TA!4U]#2$E,1%)%3B<L(#$R."D[("\O($1%4%)%0T%4140*9&5F:6YE*"=)
M34%05%)%15]%3%1?25-?3U!%3B<L(#(U-BD["F1E9FEN92@G24U!4%12145?
M14Q47TE37U-50E-#4DE"140G+"`U,3(I.PID969I;F4H)TE-05!44D5%7T5,
M5%])4U]$25-#3U9%4D5$)RP@,3`R-"D["F1E9FEN92@G24U!4%12145?14Q4
M7TE37U!/3$Q%1"<L(#(P-#@I.PID969I;F4H)TE-05!44D5%7T5,5%].145$
M7U-/4E0G+"`T,#DV*3L*+R\@)S@Q.3(G(&ES('5S960@8GD@24U0(#0N>"!S
M;R!D;R!N;W0@=7-E(&ET(&AE<F4*9&5F:6YE*"=)34%05%)%15]%3%1?3D%-
M15-004-%)RP@,38S.#0I.PH*+RH@5&AE(&ES3W!E;B@I(&5X<&%N9&5D(&UO
M9&4@8V]N<W1A;G1S+B`J+PID969I;F4H)TE-05!44D5%7T]014Y?3D].12<L
M(#`I.PID969I;F4H)TE-05!44D5%7T]014Y?04Q,)RP@,2D["F1E9FEN92@G
M24U!4%12145?3U!%3E]54T52)RP@,BD["@HO*B!7:&EC:"!M;V1E(&]F($E-
M05`@86-C97-S(&%R92!W92!U<VEN9RX@*B\*9&5F:6YE*"=)34%05%)%15]-
M3T1%7TU!24PG+"`P*3L*9&5F:6YE*"=)34%05%)%15]-3T1%7TY%5U,G+"`Q
M*3L*"B\J(%1H92!I;FET86QI>F%T:6]N(&UO9&4@=&\@=7-E('=H96X@8W)E
M871I;F<@=&AE('1R964N("HO"F1E9FEN92@G24U!4%12145?24Y)5%]354(G
M+"`Q*3L*9&5F:6YE*"=)34%05%)%15])3DE47U5.4U5")RP@,BD["F1E9FEN
M92@G24U!4%12145?24Y)5%]&151#2$%,3"<L(#0I.PH*+RH@5&AE(&UA;FYE
M<B!T;R!W:&EC:"!T;R!T<F%V97)S92!T:&4@=')E92!W:&5N(&-A;&QI;F<@
M;F5X="@I+B`J+PID969I;F4H)TE-05!44D5%7TY%6%1?4TA/5T-,3U-%1"<L
M(#$I.PID969I;F4H)TE-05!44D5%7TY%6%1?4TA/5U-50B<L(#(I.PH*+RH@
M5&AE('-T<FEN9R!U<V5D('1O(&EN9&EC871E('1H92!B87-E(&]F('1H92!T
M<F5E+B`J+PID969I;F4H)TE-05!44D5%7T)!4T5?14Q4)RP@;G5L;"D["@HO
M*BH*("H@5&AE($E-05!?5')E92!C;&%S<R!P<F]V:61E<R!A('1R964@=FEE
M=R!O9B!T:&4@9F]L9&5R<R!S=7!P;W)T960@=VET:`H@*B!T:&4@4$A0(&EM
M87`@97AT96YS:6]N("A)34%0+U!/4#,O3DY44"!R97!O<VET;W)I97,I+B`@
M270@<')O=FED97,@86-C97-S"B`J(&9U;F-T:6]N<R!T;R!I=&5R871E('1H
M<F]U9V@@=&AI<R!T<F5E(&%N9"!Q=65R>2!I;F9O<FUA=&EO;B!A8F]U=`H@
M*B!I;F1I=FED=6%L(&UA:6QB;WAE<R]F;VQD97)S+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R])34%0+TE-05`O5')E92YP:'`L=B`Q+C0X+C(N-#,@,C`P
M-B\P-2\Q,B`Q-CHR.3HR.2!S;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`P+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J($-O<'ER:6=H="`R,#`P+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E
M+F]R9SX*("H@0V]P>7)I9VAT(#(P,#`M,C`P-B!!;FEL($UA9&AA=F%P961D
M>2`\879S;4!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EC
M:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&AO<F1E+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@
M0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%V<VU`:&]R9&4N;W)G/@H@
M*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`:&]R9&4N;W)G
M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?24U!
M4`H@*B\*8VQA<W,@24U!4%]4<F5E('L*"B`@("`O*BH*("`@("`J($%S<V]C
M:6%T:79E(&%R<F%Y(&-O;G1A:6YI;F<@=&AE(&UA:6QB;W@@=')E92X*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W1R964[
M"@H@("`@+RHJ"B`@("`@*B!,;V-A=&EO;B!O9B!C=7)R96YT(&5L96UE;G0@
M:6X@=&AE('1R964N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1?8W5R<G!A<F5N="`](&YU;&P["@H@("`@+RHJ"B`@("`@
M*B!,;V-A=&EO;B!O9B!C=7)R96YT(&5L96UE;G0@:6X@=&AE('1R964N"B`@
M("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7V-U
M<G)K97D@/2!N=6QL.PH*("`@("\J*@H@("`@("H@3&]C871I;VX@;V8@8W5R
M<F5N="!E;&5M96YT(&EN('1H92!T<F5E+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?8W5R<G-T86-K(#T@87)R87DH*3L*
M"B`@("`O*BH*("`@("`J(%-H;W<@=6YS=6)S8W)I8F5D(&UA:6QB;WAE<S\*
M("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?
M<VAO=W5N<W5B(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!087)E;G0@;&ES
M="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M7W!A<F5N="`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@8V%C:&5D
M(&QI<W0@;V8@;6%I;&)O>&5S('1O('!O;&PN"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P;VQL(#T@;G5L;#L*"B`@("`O
M*BH*("`@("`J(%1H92!C86-H960@;&ES="!O9B!E>'!A;F1E9"!F;VQD97)S
M+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M97AP86YD960@/2!N=6QL.PH*("`@("\J*@H@("`@("H@0V%C:&5D(&QI<W0@
M;V8@<W5B<V-R:6)E9"!M86EL8F]X97,N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]S=6)S8W)I8F5D(#T@;G5L;#L*"B`@
M("`O*BH*("`@("`J($-A8VAE9"!L:7-T(&]F('5N<W5B<V-R:6)E9"!M86EL
M8F]X97,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)%]U;G-U8G-C<FEB960@/2!N=6QL.PH*("`@("\J*@H@("`@("H@26YI
M="!M;V1E(&9L86<N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@
M*B\*("`@('9A<B`D7VEN:71M;V1E(#T@,#L*"B`@("`O*BH*("`@("`J(%1R
M964@8VAA;F=E9"!F;&%G+B`@4V5T('=H96X@<V]M971H:6YG(&EN('1H92!T
M<F5E(&AA<R!B965N(&%L=&5R960N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L
M96%N"B`@("`@*B\*("`@('9A<B`D7V-H86YG960@/2!F86QS93L*"B`@("`O
M*BH*("`@("`J($AA=F4@=V4@<VAO=VX@=6YS=6)S8W)I8F5D(&9O;&1E<G,@
M<')E=FEO=7-L>3\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J
M+PH@("`@=F%R("1?=6YS=6)V:65W(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@
M*B!4:&4@24U!4%]3;W)T(&]B:F5C="X*("`@("`J"B`@("`@*B!`=F%R($E-
M05!?4V]R=`H@("`@("HO"B`@("!V87(@)%]I;6%P7W-O<G0@/2!N=6QL.PH*
M("`@("\J*@H@("`@("H@26YS97)T(&%N(&5L96UE;G0@:6X@=&AE('1R964@
M=&AA="!D;V5S;B=T(&%P<&5A<B!O;B!T:&4@24U!4"!S97)V97(N"B`@("`@
M*B!)9B!S970L($E-05!?5')E93HZ('=I;&P@8V%L;"!?9V5T3F]N24U!4$5L
M="@I('1O(&]B=&%I;B!T:&4@96QE;65N=`H@("`@("H@=&\@861D('1O('1H
M92!T<F5E+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@
M("!V87(@)%]N;VYI;6%P96QT(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!4
M:&4@;F%M92!T;R!U<V4@=VAE;B!S=&]R:6YG('1H92!O8FIE8W0@:6X@=&AE
M('-E<W-I;VXN"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1?8V%C:&5N86UE.PH*("`@("\J*@H@("`@("H@5&AE(&%P<&QI
M8V%T:6]N('1H870@9V5N97)A=&5D('1H:7,@=')E92X*("`@("`J(%1(25,@
M4TA/54Q$($)%(%-%5"!)3B!%5D5262!354)#3$%34R!#3TY35%)50U1/4BX*
M("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]A
M<'`@/2!N=6QL.PH*("`@("\J*@H@("`@("H@5&AE('-E<G9E<B!S=')I;F<@
M9F]R('1H92!C=7)R96YT('-E<G9E<BX*("`@("`J(%1(25,@4TA/54Q$($)%
M(%-%5"!)3B!%5D5262!354)#3$%34R!#3TY35%)50U1/4BX*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]S97)V97(@/2`G
M)SL*"B`@("`O*BH*("`@("`J(%-H;W5L9"!W92!U<V4@)VUA:6PG(&UO9&4@
M;W(@)VYE=W,G(&UO9&4_"B`@("`@*B!42$E3(%-(3U5,1"!"12!3150@24X@
M159%4ED@4U5"0TQ!4U,@0T].4U1254-43U(N"B`@("`@*@H@("`@("H@0'9A
M<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7VUO9&4@/2!N=6QL.PH*("`@
M("\J*@H@("`@("H@5&AE(&QI<W0@;V8@;F%M97-P86-E<R!T;R!A9&0@=&\@
M=&AE('1R964N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]N86UE<W!A8V5S.PH@("`@+RHJ"B`@("`@*B!$;V5S('1H92!)
M34%0('-E<G9E<B!S=7!P;W)T('1H92!C:&EL9')E;B!E>'1E;G-I;VX_"B`@
M("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V-H
M:6QD<F5N<W5P<&]R="`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!5<V5D('1O
M(&1E=&5R;6EN92!T:&4@;&ES="!O9B!E;&5M96YT(&-H86YG97,N"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]E;'1D:69F
M(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A
M(')E9F5R96YC92!T;R!A(&-O;F-R971E($E-05!?5')E92!I;G-T86YC92X*
M("`@("`J"B`@("`@*B!)9B!A;B!)34%07U1R964@;V)J96-T(&ES(&-U<G)E
M;G1L>2!S=&]R960@:6X@=&AE(&QO8V%L('-E<W-I;VXL"B`@("`@*B!R96-R
M96%T92!T:&%T(&]B:F5C="X@($5L<V4L(&EF("1C<F5A=&4@:7,@=')U92P@
M=VEL;"!C<F5A=&4@82!N97<*("`@("`J(&EN<W1A;F-E+B`@16YS=7)E<R!T
M:&%T(&]N;'D@;VYE($E-05!?5')E92!I;G-T86YC92!I<R!A=F%I;&%B;&4*
M("`@("`J(&%T(&%N>2!T:6UE+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D
M(&UU<W0@8F4@:6YV;VME9"!A<SH\<')E/@H@("`@("H@("`D:6UA<%]T<F5E
M(#T@)DE-05!?5')E93HZ<VEN9VQE=&]N*"1A<'`L("1C;&%S<VYA;64L(%LD
M8W)E871E6RP@)'5N<W5B75TI.SPO<')E/@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&%P<"`@("`@("`@5&AE(&-U<G)E;G0@87!P;&EC871I;VX@
M;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)&-L87-S;F%M92`@5&AE(&-L
M87-S(&YA;64@=&\@=7-E('=H96X@:6YS=&%N=&EA=&EN9R!A(&YE=PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("!O8FIE8W0N"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D8W)E871E("`@($-R96%T92!A(&YE=R!)34%07U1R
M964@:68@:70@9&]E<VXG="!E>&ES="!I;@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("!T:&4@<V5S<VEO;C\*("`@("`J($!P87)A;2!I;G1E
M9V5R("1I;FET("`@("`@5&AE(&EN:71I86QI>F%T:6]N(&UO9&4@=&\@=7-E
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V%C:&5N86UE("!4:&4@;F%M92!T
M;R!U<V4@=VAE;B!S=&]R:6YG(&EN('1H92!S97-S:6]N+@H@("`@("H*("`@
M("`J($!R971U<FX@24U!4%]4<F5E("!4:&4@24U!4%]4<F5E(&]B:F5C="!O
M<B!N=6QL+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1A<'`L
M("1C;&%S<VYA;64L("1C<F5A=&4@/2!F86QS92P*("`@("`@("`@("`@("`@
M("`@("`@("`@)&EN:70@/2!)34%05%)%15])3DE47U-50BP@)&-A8VAE;F%M
M92`]("=I;6%P=')E92<I"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC
M92`](&%R<F%Y*"D["@H@("`@("`@(&EF("AI<W-E="@D:6YS=&%N8V5;)&%P
M<%TI*2!["B`@("`@("`@("`@(')E='5R;B`D:6YS=&%N8V5;)&%P<%T["B`@
M("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1?4T534TE/3ELD87!P75LD
M8V%C:&5N86UE72DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D
M92]397-S:6]N3V)J96-T<RYP:'`G.PH@("`@("`@("`@("`D8V%C:&5397-S
M(#T@)DAO<F1E7U-E<W-I;VY/8FIE8W1S.CIS:6YG;&5T;VXH*3L*("`@("`@
M("`@("`@)&EN<W1A;F-E6R1A<'!=(#T@)B1C86-H95-E<W,M/G%U97)Y*"1?
M4T534TE/3ELD87!P75LD8V%C:&5N86UE72D["B`@("`@("`@("`@(')E9VES
M=&5R7W-H=71D;W=N7V9U;F-T:6]N*&%R<F%Y*"8D:6YS=&%N8V5;)&%P<%TL
M("=?<W1O<F4G*2D["B`@("`@("`@?2!E;'-E:68@*"1C<F5A=&4I('L*("`@
M("`@("`@("`@)&EN<W1A;F-E6R1A<'!=(#T@)FYE=R`D8VQA<W-N86UE*"1I
M;FET+"`D8V%C:&5N86UE*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M:6YS=&%N8V5;)&%P<%T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U
M8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:6YI="`@("`@
M(%1H92!I;FET:6%L:7IA=&EO;B!M;V1E('1O('5S92X*("`@("`J($!P87)A
M;2!S=')I;F<@)&-A8VAE;F%M92`@5&AE(&YA;64@=&\@=7-E('=H96X@<W1O
M<FEN9R!I;B!T:&4@<V5S<VEO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@24U!
M4%]4<F5E*"1I;FET(#T@24U!4%12145?24Y)5%]354(L("1C86-H96YA;64@
M/2`G:6UA<'1R964G*0H@("`@>PH@("`@("`@(')E9VES=&5R7W-H=71D;W=N
M7V9U;F-T:6]N*&%R<F%Y*"8D=&AI<RP@)U]S=&]R92<I*3L*("`@("`@("`D
M=&AI<RT^7V-A8VAE;F%M92`]("1C86-H96YA;64["B`@("`@("`@)'1H:7,M
M/FEN:70H)&EN:70I.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1O<F4@82!S
M97)I86QI>F5D('9E<G-I;VX@;V8@;W5R<V5L9B!I;B!T:&4@8W5R<F5N="!S
M97-S:6]N+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!F=6YC=&EO;B!?<W1O<F4H*0H@("`@>PH@("`@("`@("\J(%=E(&]N
M;'D@;F5E9"!T;R!R97-T;W)E('1H92!O8FIE8W0@:68@=&AE('1R964@:&%S
M(&-H86YG960N("HO"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7V-H86YG
M960I*2!["B`@("`@("`@("`@("\J($1O;B=T('-T;W)E("1?97AP86YD960@
M86YD("1?<&]L;"`M('1H97-E('9A;'5E<R!A<F4@:&%N9&QE9`H@("`@("`@
M("`@("`@*B!B>2!T:&4@<W5B8VQA<W-E<RX*("`@("`@("`@("`@("H@1&]N
M)W0@<W1O<F4@)%]I;6%P7W-O<G0@;W(@)%]E;'1D:69F("T@=&AI<R!N965D
M<R!T;R!B90H@("`@("`@("`@("`@*B!R96=E;F5R871E9"!F;W(@96%C:"!R
M97%U97-T+@H@("`@("`@("`@("`@*B!$;VXG="!S=&]R92`D7V-U<G)K97DL
M("1?8W5R<G!A<F5N="P@86YD("1?8W5R<E-T86-K('-I;F-E('1H90H@("`@
M("`@("`@("`@*B!U<V5R($U54U0@8V%L;"!R97-E="@I(&)E9F]R92!C>6-L
M:6YG('1H<F]U9V@@=&AE('1R964N"B`@("`@("`@("`@("`J(%)E<V5T('1H
M92`D7V-H86YG960@9FQA9RX@*B\*("`@("`@("`@("`@)'1H:7,M/E]C=7)R
M:V5Y(#T@)'1H:7,M/E]C=7)R<&%R96YT(#T@)'1H:7,M/E]E;'1D:69F(#T@
M)'1H:7,M/E]E>'!A;F1E9"`]("1T:&ES+3Y?:6UA<%]S;W)T(#T@)'1H:7,M
M/E]P;VQL(#T@;G5L;#L*("`@("`@("`@("`@)'1H:7,M/E]C=7)R4W1A8VL@
M/2!A<G)A>2@I.PH@("`@("`@("`@("`D=&AI<RT^7V-H86YG960@/2!F86QS
M93L*"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O4V5S<VEO;D]B
M:F5C=',N<&AP)SL*("`@("`@("`@("`@)&-A8VAE4V5S<R`]("9(;W)D95]3
M97-S:6]N3V)J96-T<SHZ<VEN9VQE=&]N*"D["@H@("`@("`@("`@("`O*B!2
M975S92!O;&0@<V5S<VEO;B!)1"!I9B!P;W-S:6)L92X@*B\*("`@("`@("`@
M("`@:68@*&ES<V5T*"1?4T534TE/3ELD=&AI<RT^7V%P<%U;)'1H:7,M/E]C
M86-H96YA;65=*2D@>PH@("`@("`@("`@("`@("`@)&-A8VAE4V5S<RT^;W9E
M<G=R:71E*"1?4T534TE/3ELD=&AI<RT^7V%P<%U;)'1H:7,M/E]C86-H96YA
M;65=+"`D=&AI<RP@9F%L<V4I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D7U-%4U-)3TY;)'1H:7,M/E]A<'!=
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1?4T534TE/3ELD=&AI<RT^7V%P
M<%T@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)%]315-324].6R1T:&ES+3Y?87!P75LD=&AI<RT^7V-A8VAE;F%M95T@
M/2`D8V%C:&5397-S+3YS=&]R94]I9"@D=&AI<RP@9F%L<V4I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!A(&QI<W0@;V8@9F]L9&5R<R]M86EL8F]X97,@;6%T8VAI;F<@82!C97)T
M86EN('!A=&@N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE(&UA:6QB;W@@<&%T
M:"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&QI<W0@;V8@;6%I
M;&)O>%]O8FIE8W1S('=H;W-E(&YA;64@;6%T8VAE9"`D<&%T:"X*("`@("`J
M("`@("`@("`@("`@("`@(%1H92!S97)V97(@<W1R:6YG(&AA<R!B965N(')E
M;6]V960@9G)O;2!T:&4@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E
M=$QI<W0H)'!A=&@I"B`@("!["B`@("`@("`@)'5N:7%U92`](&%R<F%Y*"D[
M"@H@("`@("`@(&EF("@A)'1H:7,M/E]S:&]W=6YS=6(I('L*("`@("`@("`@
M("`@)'1H:7,M/E]I;FET4W5B<V-R:6)E9"@I.PH@("`@("`@('T*("`@("`@
M("`D;F5W8F]X97,@/2!`:6UA<%]G971M86EL8F]X97,H)'1H:7,M/E]G9713
M=')E86TH*2P@)'1H:7,M/E]S97)V97(L("1P871H*3L*("`@("`@("!I9B`H
M:7-?87)R87DH)&YE=V)O>&5S*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D
M;F5W8F]X97,@87,@)&)O>"D@>PH@("`@("`@("`@("`@("`@:68@*"1T:&ES
M+3Y?<VAO=W5N<W5B('Q\"B`@("`@("`@("`@("`@("`@("`@(6ES<V5T*"1T
M:&ES+3Y?<W5B<V-R:6)E9%LD8F]X+3YN86UE72DI('L*("`@("`@("`@("`@
M("`@("`@("`O*B!3=')I<"!O9F8@<V5R=F5R('-T<FEN9RX@*B\*("`@("`@
M("`@("`@("`@("`@("`D8F]X(#T@)'1H:7,M/E]R96UO=F5397)V97)3=')I
M;F<H)&)O>"D["B`@("`@("`@("`@("`@("`@("`@:68@*"1B;W@M/FYA;64@
M)B8@(6ES<V5T*"1U;FEQ=65;)&)O>"T^;F%M95TI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1U;FEQ=65;)&)O>"T^;F%M95T@/2`D8F]X.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1U;FEQ=64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!-86ME(&$@<VEN9VQE(&UA:6QB;W@@=')E92!E
M;&5M96YT+@H@("`@("H@06X@96QE;65N="!C;VYS:7-T<R!O9B!T:&4@9F]L
M;&]W:6YG(&ET96US("AW92!U<V4@<VEN9VQE(&QE='1E<G,@:&5R90H@("`@
M("H@=&\@<V%V92!I;B!S97-S:6]N('-T;W)A9V4@<W!A8V4I.@H@("`@("H@
M("`G82<@("TM("!!='1R:6)U=&5S"B`@("`@*B`@("=C)R`@+2T@($QE=F5L
M(&-O=6YT"B`@("`@*B`@("=L)R`@+2T@($QA8F5L"B`@("`@*B`@("=P)R`@
M+2T@(%!A<F5N="!N;V1E"B`@("`@*B`@("=V)R`@+2T@(%9A;'5E"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M(&]B:F5C="!S=&1#;&%S<R`D;V(@(%1H92!O8FIE8W0@<F5T=7)N960@8GD@
M:6UA<%]G971M86EL8F]X97,H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!3964@9F]R;6%T(&%B;W9E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M;6%K94UA:6QB;WA4<F5E16QT*"1O8BD*("`@('L*("`@("`@("`D96QT6R=A
M)UT@/2`D;V(M/F%T=')I8G5T97,["B`@("`@("`@)&5L=%LG8R==(#T@,#L*
M("`@("`@("`D96QT6R=P)UT@/2!)34%05%)%15]"05-%7T5,5#L*("`@("`@
M("`D96QT6R=V)UT@/2`D;V(M/FYA;64["@H@("`@("`@("\J(%-E="!S=6)S
M8W)I8F5D('9A;'5E<RX@36%K92!S=7)E($E.0D]8(&ES(&%L=V%Y<R!S=6)S
M8W)I8F5D"B`@("`@("`@("H@=&\@*&EF('=O<FMI;F<@=VET:"!M86EL*2!S
M;R!T:&5R92!I<R!A;'=A>7,@870@;&5A<W0@,0H@("`@("`@("`J('9I97=A
M8FQE(&5L96UE;G0N("HO"B`@("`@("`@:68@*"1E;'1;)W8G72`]/2`G24Y"
M3U@G*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5T4W5B<V-R:6)E9"@D96QT
M+"!T<G5E*3L*("`@("`@("!](&5L<V5I9B`H(21T:&ES+3YI<U-U8G-C<FEB
M960H)&5L="DI('L*("`@("`@("`@("`@)'1H:7,M/E]I;FET4W5B<V-R:6)E
M9"@I.PH@("`@("`@("`@("`D=&AI<RT^7W-E=%-U8G-C<FEB960H)&5L="P@
M:7-S970H)'1H:7,M/E]S=6)S8W)I8F5D6R1E;'1;)W8G75TI*3L*("`@("`@
M("!]"@H@("`@("`@("\J($-H96-K(&9O<B!P;VQL960@<W1A='5S+B`J+PH@
M("`@("`@(&EF("@A)'1H:7,M/FES4&]L;&5D*"1E;'0I*2!["B`@("`@("`@
M("`@("1T:&ES+3YG9710;VQL3&ES="@I.PH@("`@("`@("`@("`D=&AI<RT^
M7W-E=%!O;&QE9"@D96QT+"!I<W-E="@D=&AI<RT^7W!O;&Q;)&5L=%LG=B==
M72DI.PH@("`@("`@('T*"B`@("`@("`@+RH@0VAE8VL@9F]R(&]P96X@<W1A
M='5S+B`J+PH@("`@("`@("1T:&ES+3Y?<V5T3W!E;B@D96QT+"`D=&AI<RT^
M:7-/<&5N*"1E;'0I*3L*"B`@("`@("`@+RH@0V]M<'5T960@=F%L=65S+B`J
M+PH@("`@("`@("1N<U]I;F9O(#T@)'1H:7,M/E]G971.86UE<W!A8V4H)&5L
M=%LG=B==*3L*("`@("`@("`D=&UP(#T@97AP;&]D92@H:7-?;G5L;"@D;G-?
M:6YF;RDI(#\@)'1H:7,M/E]D96QI;6ET97(@.B`D;G-?:6YF;ULG9&5L:6UI
M=&5R)UTL("1E;'1;)W8G72D["B`@("`@("`@)&5L=%LG8R==(#T@8V]U;G0H
M)'1M<"D@+2`Q.PH@("`@("`@("1L86)E;"`]("1E;'1;)V,G73L*("`@("`@
M("!I9B`H(65M<'1Y*"1E;'1;)V,G72D@)B8*("`@("`@("`@("`@(7!R96=?
M;6%T8V@H(B]<>RXJ<&]P,RXJ7'TO(BP@)&]B+3YF=6QL4V5R=F5R4&%T:"DI
M('L*("`@("`@("`@("`@)&5L=%LG<"==(#T@:6UP;&]D92@H:7-?;G5L;"@D
M;G-?:6YF;RDI(#\@)'1H:7,M/E]D96QI;6ET97(@.B`D;G-?:6YF;ULG9&5L
M:6UI=&5R)UTL(&%R<F%Y7W-L:6-E*"1T;7`L(#`L("1E;'1;)V,G72DI.PH@
M("`@("`@("`@("`O*B!3=')I<"!P97)S;VYA;"!N86UE<W!A8V4N("HO"B`@
M("`@("`@("`@(&EF("@A:7-?;G5L;"@D;G-?:6YF;RD@)B8*("`@("`@("`@
M("`@("`@("%E;7!T>2@D;G-?:6YF;ULG;F%M92==*2`F)@H@("`@("`@("`@
M("`@("`@*"1N<U]I;F9O6R=T>7!E)UT@/3T@)W!E<G-O;F%L)RDI('L*("`@
M("`@("`@("`@("`@("1E;'1;)V,G72TM.PH@("`@("`@("`@("`@("`@:68@
M*'-T<G!O<R@D96QT6R=P)UTL("1N<U]I;F9O6R=D96QI;6ET97(G72D@/3T]
M(&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@)&5L=%LG<"==(#T@24U!
M4%12145?0D%315]%3%0["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H<W1R
M<&]S*"1E;'1;)W8G72P@)&YS7VEN9F];)VYA;64G72`N("=)3D)/6"<@+B`D
M;G-?:6YF;ULG9&5L:6UI=&5R)UTI(#T]/2`P*2!["B`@("`@("`@("`@("`@
M("`@("`@)&5L=%LG<"==(#T@)TE.0D]8)SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D96QT6R=L)UT@/2!3
M=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1T;7!;)&QA8F5L72P@)U541C<M24U!
M4"<I.PH*("`@("`@("!R971U<FX@)&5L=#L*("`@('T*"B`@("`O*BH*("`@
M("`J($EN:71A;&EZ92!T:&4@;&ES="!A="!T:&4@=&]P(&QE=F5L(&]F('1H
M92!H:65R87)C:'DN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&EN
M:70@(%1H92!I;FET:6%L:7IA=&EO;B!M;V1E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!I;FET*"1I;FET*0H@("`@>PH@("`@("`@("\J(%)E<V5T(&%L;"!C
M;&%S<R!V87)I86)L97,@=&\@=&AE(&1E9F%U;'1S+B`J+PH@("`@("`@("1T
M:&ES+3Y?8VAA;F=E9"`]('1R=64["B`@("`@("`@)'1H:7,M/E]C=7)R:V5Y
M(#T@;G5L;#L*("`@("`@("`D=&AI<RT^7V-U<G)P87)E;G0@/2!N=6QL.PH@
M("`@("`@("1T:&ES+3Y?8W5R<G-T86-K(#T@87)R87DH*3L*("`@("`@("`D
M=&AI<RT^7W1R964@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3Y?<&%R96YT
M(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^7W-H;W=U;G-U8B`]("1T:&ES
M+3Y?=6YS=6)V:65W(#T@*"1I;FET("8@24U!4%12145?24Y)5%]53E-50BD[
M"B`@("`@("`@)'1H:7,M/E]S=6)S8W)I8F5D(#T@;G5L;#L*("`@("`@("`D
M=&AI<RT^7W5N<W5B<V-R:6)E9"`](&YU;&P["@H@("`@("`@("\J(%-E="!I
M;FET:6%L:7IA=&EO;B!M;V1E+B`J+PH@("`@("`@("1T:&ES+3Y?:6YI=&UO
M9&4@/2`D:6YI=#L*"B`@("`@("`@+RH@1V5T('1H92!I;FET:6%L(&QI<W0@
M;V8@;6%I;&)O>&5S(&9R;VT@=&AE('-U8F-L87-S+B`J+PH@("`@("`@("1B
M;WAE<R`]("1T:&ES+3Y?:6YI="@I.PH*("`@("`@("`O*B!#<F5A=&4@82!P
M;&%C96AO;&1E<B!E;&5M96YT('1O('1H92!B87-E(&]F('1H92!T<F5E(&QI
M<W0@<V\@=V4@8V%N"B`@("`@("`@("H@:V5E<"!T<F%C:R!O9B!W:&5T:&5R
M('1H92!B87-E(&QE=F5L(&YE961S('1O(&)E('-O<G1E9"X@*B\*("`@("`@
M("`D=&AI<RT^7W1R965;24U!4%12145?0D%315]%3%1=(#T@87)R87DH)V$G
M(#T^($E-05!44D5%7T5,5%])4U]$25-#3U9%4D5$*3L*"B`@("`@("`@+RH@
M0VAE8VL@=&\@;6%K92!S=7)E(&%L;"!N86UE<W!A8V4@96QE;65N=',@87)E
M(&EN('1H92!T<F5E+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7VYA;65S<&%C
M97,I('L*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]N86UE<W!A8V5S
M(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`@("`@:68@*"1V86Q;
M)W1Y<&4G72`A/2`G<&5R<V]N86PG*2!["B`@("`@("`@("`@("`@("`@("`@
M)&YA;64@/2!S=6)S='(H)&ME>2P@,"P@+3$@*B!S=')L96XH)'9A;%LG9&5L
M:6UI=&5R)UTI*3L*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?=')E95LD=F%L6R=N86UE)UU=*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D;V(@/2`F;F5W('-T9$-L87-S.PH@("`@("`@("`@("`@("`@
M("`@("`@("`D;V(M/F1E;&EM:71E<B`]("1V86Q;)V1E;&EM:71E<B==.PH@
M("`@("`@("`@("`@("`@("`@("`@("`D;V(M/F%T=')I8G5T97,@/2!,0514
M7TY/4T5,14-4('P@24U!4%12145?14Q47TY!34534$%#13L*("`@("`@("`@
M("`@("`@("`@("`@("`@+RH@)&]B+3YF=6QL4V5R=F5R4&%T:"!I<R!N;W0@
M8V]M<&QE=&5L>2!S970@:&5R92X@*B\*("`@("`@("`@("`@("`@("`@("`@
M("`@)&]B+3YF=6QL4V5R=F5R4&%T:"`]("1O8BT^;F%M92`]("1N86UE.PH@
M("`@("`@("`@("`@("`@("`@("`@("`D96QT(#T@)'1H:7,M/E]M86ME36%I
M;&)O>%1R965%;'0H)&]B*3L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]I;G-E<G1%;'0H)&5L="D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`O*B!#<F5A=&4@=&AE(&QI<W0@*$E.0D]8(&%N9"!A;GD@;W1H97(@
M:&EE<F%R8VAI97,I+B`J+PH@("`@("`@("1T:&ES+3Y?861D3&5V96PH)&)O
M>&5S*3L*"B`@("`@("`@+RH@16YD(&EN:71I86QI>F%T:6]N(&UO9&4N("HO
M"B`@("`@("`@)'1H:7,M/E]I;FET;6]D92`](#`["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3=6)C;&%S<R!S<&5C:69I8R!I;FET:6%L:7IA=&EO;B!T87-K
M<RX*("`@("`J(%1(25,@34542$]$($U54U0@0D4@1$5&24Y%1"!)3B!!3$P@
M4U5"0TQ!4U-%4RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!4:&4@:6YI=&EA;"!L:7-T(&]F(&5L96UE;G1S('1O(&%D9"!T;R!T
M:&4@=')E92X*("`@("`J+PH@("`@9G5N8W1I;VX@7VEN:70H*0H@("`@>PH@
M("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M17AP86YD(&$@;6%I;"!F;VQD97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9F]L9&5R("`@("`@5&AE(&9O;&1E<B!N86UE('1O(&5X<&%N9"X*
M("`@("`J($!P87)A;2!B;V]L96%N("1E>'!A;F1A;&P@($5X<&%N9"!A;&P@
M9F]L9&5R<R!U;F1E<B!T:&ES(&]N93\*("`@("`J+PH@("`@9G5N8W1I;VX@
M97AP86YD*"1F;VQD97(L("1E>'!A;F1A;&P@/2!F86QS92D*("`@('L*("`@
M("`@("`D9F]L9&5R(#T@)'1H:7,M/E]C;VYV97)T3F%M92@D9F]L9&5R*3L*
M"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W1R965;)&9O;&1E<ETI*2![
M"B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3Y?8VAA;F=E9"`]('1R=64["@H@("`@("`@("\J($UE<F=E(&EN(&YE>'0@
M;&5V96P@;V8@:6YF;W)M871I;VXN("HO"B`@("`@("`@:68@*"1T:&ES+3YH
M87-#:&EL9')E;B@D=&AI<RT^7W1R965;)&9O;&1E<ETI*2!["B`@("`@("`@
M("`@(&EF("@A)'1H:7,M/FES1&ES8V]V97)E9"@D=&AI<RT^7W1R965;)&9O
M;&1E<ETI*2!["B`@("`@("`@("`@("`@("`D:6YF;R`]("1T:&ES+3Y?8VAI
M;&1R96Y);F9O*"1F;VQD97(I.PH@("`@("`@("`@("`@("`@:68@*"%E;7!T
M>2@D:6YF;RDI('L*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]I
M;FET;6]D92D@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H*"1T:&ES
M+3Y?:6YI=&UO9&4@)B!)34%05%)%15])3DE47T9%5$-(04Q,*2!\?`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FES3W!E;B@D=&AI<RT^
M7W1R965;)&9O;&1E<ETI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V%D9$QE=F5L*"1I;F9O*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?861D3&5V96PH)&EN9F\I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=$]P96XH)'1H:7,M/E]T
M<F5E6R1F;VQD97)=+"!T<G5E*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!I9B`H(2@D=&AI<RT^7VEN:71M;V1E("8@24U!4%12145?24Y)
M5%]&151#2$%,3"DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-E
M=$]P96XH)'1H:7,M/E]T<F5E6R1F;VQD97)=+"!T<G5E*3L*("`@("`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("`@("`O*B!%>'!A;F0@86QL(&-H:6QD
M<F5N(&)E;F5A=&@@=&AI<R!O;F4N("HO"B`@("`@("`@("`@("`@("!I9B`H
M)&5X<&%N9&%L;"`F)B`A96UP='DH)'1H:7,M/E]P87)E;G1;)&9O;&1E<ETI
M*2!["B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P87)E
M;G1;)&9O;&1E<ET@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^97AP86YD*"1T:&ES+3Y?=')E95LD=F%L75LG=B==+"!T<G5E
M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M;VQL87!S92!A(&UA:6P@9F]L9&5R+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&9O;&1E<B`@5&AE(&9O;&1E<B!N86UE('1O(&-O;&QA<'-E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!C;VQL87!S92@D9F]L9&5R*0H@("`@>PH@
M("`@("`@("1F;VQD97(@/2`D=&AI<RT^7V-O;G9E<G1.86UE*"1F;VQD97(I
M.PH*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?=')E95LD9F]L9&5R72DI
M('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/E]C:&%N9V5D(#T@=')U93L*"B`@("`@("`@+RH@4V5T('1H92!F;VQD
M97(@871T<FEB=71E<R!T;R!N;W0@97AP86YD960N("HO"B`@("`@("`@)'1H
M:7,M/E]S971/<&5N*"1T:&ES+3Y?=')E95LD9F]L9&5R72P@9F%L<V4I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@:6YT97)N86P@87)R87D@
M<&]I;G1E<B!T;R!T:&4@;F5X="!E;&5M96YT+"!A;F0@<F5T=7)N<R!T:&4*
M("`@("`J(&YE>'0@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E
M9V5R("1M87-K("!!(&UA<VL@=VET:"!T:&4@9F]L;&]W:6YG(&5L96UE;G1S
M.@H@("`@("H@/'!R93X*("`@("`J($E-05!44D5%7TY%6%1?4TA/5T-,3U-%
M1"`M($1O;B=T(&EG;F]R92!C;&]S960@96QE;65N=',N"B`@("`@*B!)34%0
M5%)%15].15A47U-(3U=354(@+2!/;FQY('-H;W<@<W5B<V-R:6)E9"!E;&5M
M96YT<RX*("`@("`J(#PO<')E/@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%)E='5R;G,@=&AE(&YE>'0@96QE;65N="!O<B!F86QS92!I9B!T:&4@
M96QE;65N="!D;V5S;B=T"B`@("`@*B`@("`@("`@("`@("`@("!E>&ES="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@;F5X="@D;6%S:R`](#`I"B`@("!["B`@
M("`@("`@:68@*&ES7VYU;&PH)'1H:7,M/E]C=7)R:V5Y*2`F)B!I<U]N=6QL
M*"1T:&ES+3Y?8W5R<G!A<F5N="DI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@)&-U<G(@/2`D=&AI<RT^8W5R<F5N
M="@I.PH*("`@("`@("`D;VQD7W-H;W=U;G-U8B`]("1T:&ES+3Y?<VAO=W5N
M<W5B.PH@("`@("`@(&EF("@D;6%S:R`F($E-05!44D5%7TY%6%1?4TA/5U-5
M0BD@>PH@("`@("`@("`@("`D=&AI<RT^7W-H;W=U;G-U8B`](&9A;'-E.PH@
M("`@("`@('T*("`@("`@(`H@("`@("`@(&EF("@D=&AI<RT^7V%C=&EV945L
M="@D8W5R<BD@)B8*("`@("`@("`@("`@*"@D;6%S:R`F($E-05!44D5%7TY%
M6%1?4TA/5T-,3U-%1"D@?'P@)'1H:7,M/FES3W!E;B@D8W5R<BDI("8F"B`@
M("`@("`@("`@("@D=&AI<RT^7V-U<G)P87)E;G0@(3T@)&-U<G);)W8G72DI
M('L*("`@("`@("`@("`@+RH@268@=&AE(&-U<G)E;G0@96QE;65N="!I<R!O
M<&5N+"!A;F0@8VAI;&1R96X@97AI<W0L(&UO=F4@:6YT;PH@("`@("`@("`@
M("`@*B!I="X@*B\*("`@("`@("`@("`@)'1H:7,M/E]C=7)R<W1A8VM;72`]
M(&%R<F%Y*"=K)R`]/B`D=&AI<RT^7V-U<G)K97DL("=P)R`]/B`D=&AI<RT^
M7V-U<G)P87)E;G0I.PH@("`@("`@("`@("`D=&AI<RT^7V-U<G)K97D@/2`P
M.PH@("`@("`@("`@("`D=&AI<RT^7V-U<G)P87)E;G0@/2`D8W5R<ELG=B==
M.PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]N965D4V]R="@D=&AI<RT^7W1R
M965;)&-U<G);)W8G75TI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W-O
M<G1,:7-T*"1T:&ES+3Y?<&%R96YT6R1C=7)R6R=V)UU=+"!I<U]N=6QL*"1C
M=7)R6R=V)UTI*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T3F5E9%-O
M<G0H)'1H:7,M/E]T<F5E6R1C=7)R6R=V)UU=+"!F86QS92D["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V-H86YG960@/2!T<G5E.PH@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@16QS92P@:6YC<F5M
M96YT('=I=&AI;B!T:&4@8W5R<F5N="!S=6)F;VQD97(N("HO"B`@("`@("`@
M("`@("1T:&ES+3Y?8W5R<FME>2LK.PH@("`@("`@('T*"B`@("`@("`@+RH@
M268@=&AE('!O:6YT97(@9&]E<VXG="!P;VEN="!T;R!A;B!E;&5M96YT+"!T
M<GD@=&\@;6]V92!B86-K('1O"B`@("`@("`@("`@=&AE('!R979I;W5S('-U
M8F9O;&1E<BX@($EF('1H97)E(&ES(&YO('!R979I;W5S('-U8F9O;&1E<BP*
M("`@("`@("`@("!R971U<FX@9F%L<V4N("HO"B`@("`@("`@)&-U<G(@/2`D
M=&AI<RT^8W5R<F5N="@I.PH@("`@("`@(&EF("@A)&-U<G(@)B8*("`@("`@
M("`@("`@*"1M87-K("8@24U!4%12145?3D585%]32$]70TQ/4T5$*2`F)@H@
M("`@("`@("`@("`A)'1H:7,M/FES1&ES8V]V97)E9"@D=&AI<RT^7W1R965;
M)'1H:7,M/E]C=7)R<&%R96YT72D@)B8*("`@("`@("`@("`@)'1H:7,M/FAA
M<T-H:6QD<F5N*"1T:&ES+3Y?=')E95LD=&AI<RT^7V-U<G)P87)E;G1=*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7V%D9$QE=F5L*"1T:&ES+3Y?8VAI;&1R
M96Y);F9O*"1T:&ES+3Y?=')E95LD=&AI<RT^7V-U<G)P87)E;G1=6R=V)UTI
M*3L*("`@("`@("`@("`@)&-U<G(@/2`D=&AI<RT^8W5R<F5N="@I.PH@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/E]S:&]W=6YS=6(@/2`D;VQD7W-H;W=U
M;G-U8CL*"B`@("`@("`@:68@*"$D8W5R<BD@>PH@("`@("`@("`@("!I9B`H
M96UP='DH)'1H:7,M/E]C=7)R<W1A8VLI*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V-U<G)K97D@/2!N=6QL.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]C=7)R<&%R96YT(#T@;G5L;#L*("`@("`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&1O
M('L*("`@("`@("`@("`@("`@("`@("`D;VQD(#T@87)R87E?<&]P*"1T:&ES
M+3Y?8W5R<G-T86-K*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-U
M<G)K97D@/2`D;VQD6R=K)UT@*R`Q.PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?8W5R<G!A<F5N="`]("1O;&1;)W`G73L*("`@("`@("`@("`@("`@
M('T@=VAI;&4@*"@H)&-U<G(@/2`D=&AI<RT^8W5R<F5N="@I*2`]/2!F86QS
M92D@)B8*("`@("`@("`@("`@("`@("`@("`@("`@(&-O=6YT*"1T:&ES+3Y?
M8W5R<G-T86-K*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(&EF("@A)'1H:7,M/E]A8W1I=F5%;'0H)&-U<G(I*2!["B`@("`@("`@("`@
M("\J(%-K:7`@=&AI<R!E;G1R>2!I9CH*("`@("`@("`@("`@("H@,2X@5V4@
M87)E(&YO="!S:&]W:6YG(&%L;"!E;&5M96YT<PH@("`@("`@("`@("`@*B`R
M+B!792!A<F4@;F]T('-U8G-C<FEB960@=&\@=&AI<R!E;&5M96YT"B`@("`@
M("`@("`@("`J(#,N($ET(&ES(&YO="!A(&-O;G1A:6YE<B`M3U(M+"!I9B!I
M="!I<R!A(&-O;G1A:6YE<BP@:68@=&AE<F4*("`@("`@("`@("`@("H@("`@
M87)E(&YO('9I97=A8FQE(&5L96UE;G1S('5N9&5R;F5A=&@@:70N"B`@("`@
M("`@("`@("`J(#0N(%1H:7,@:7,@86X@96UP='D@;F%M97-P86-E(&5L96UE
M;G0N("HO"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;F5X="@D;6%S:RD[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-U<G(["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!3970@:6YT97)N86P@<&]I;G1E<B!T;R!T:&4@:&5A9"!O
M9B!T:&4@=')E92X*("`@("`J(%1H:7,@35535"!B92!C86QL960@8F5F;W)E
M('EO=2!C86X@=')A=F5R<V4@=&AE('1R964@=VET:"!N97AT*"DN"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@4F5T=7)N<R!T:&4@96QE;65N="!A
M="!T:&4@:&5A9"!O9B!T:&4@=')E92!O<B!F86QS90H@("`@("H@("`@("`@
M("`@("`@("`@:68@=&AE(&5L96UE;G0@9&]E<VXG="!E>&ES="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5S970H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M8W5R<FME>2`](#`["B`@("`@("`@)'1H:7,M/E]C=7)R<&%R96YT(#T@24U!
M4%12145?0D%315]%3%0["B`@("`@("`@)'1H:7,M/E]C=7)R<W1A8VL@/2!A
M<G)A>2@I.PH*("`@("`@("!I9B`H)'1H:7,M/E]N965D4V]R="@D=&AI<RT^
M7W1R965;)'1H:7,M/E]C=7)R<&%R96YT72DI('L*("`@("`@("`@("`@)'1H
M:7,M/E]S;W)T3&ES="@D=&AI<RT^7W!A<F5N=%LD=&AI<RT^7V-U<G)P87)E
M;G1=+"!I<U]N=6QL*"1T:&ES+3Y?8W5R<G!A<F5N="DI.PH@("`@("`@("`@
M("`D=&AI<RT^7W-E=$YE9613;W)T*"1T:&ES+3Y?=')E95LD=&AI<RT^7V-U
M<G)P87)E;G1=+"!F86QS92D["B`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E
M9"`]('1R=64["B`@("`@("`@?0H*("`@("`@("`O*B!7:&5N(')E<V5T=&EN
M9R!I;B!N97=S(&UO9&4L('1H92!F:7)S="!E;&5M96YT(&UA>2!N;W0@8F4*
M("`@("`@("`@*B!V:65W86)L92`H=6YL:6ME(&UA:6P@;6]D92P@=VAE<F4@
M=&AE(&9I<G-T(&5L96UE;G0@:7,@24Y"3U@@86YD"B`@("`@("`@("H@:7,@
M86QW87ES('9I97=A8FQE*2X@(%1H97)E9F]R92P@=V4@;F5E9"!T;R!S96%R
M8V@@9F]R('1H92!F:7)S=`H@("`@("`@("`J('9I97=A8FQE(&ET96T@86YD
M('1H870@=VEL;"!B92!T:&4@8F%S92!O9B!T:&4@=FEE=V%B;&4@=')E92X@
M*B\*("`@("`@("!I9B`H)'1H:7,M/E]M;V1E(#T]($E-05!44D5%7TU/1$5?
M3D574RD@>PH@("`@("`@("`@("`D8W5R<B`]("1T:&ES+3YC=7)R96YT*"D[
M"B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]A8W1I=F5%;'0H)&-U<G(I*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^;F5X="@I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/F-U<G)E;G0H*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@8W5R<F5N="!T<F5E
M(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&-U
M<G)E;G0@=')E92!E;&5M96YT(&]R(&9A;'-E(&EF('1H97)E(&ES(&YO"B`@
M("`@*B`@("`@("`@("`@("`@("!E;&5M96YT+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!C=7)R96YT*"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?<&%R96YT6R1T:&ES+3Y?8W5R<G!A<F5N=%U;)'1H:7,M/E]C=7)R:V5Y
M72DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?861D06QI87-E<R@D=&AI<RT^7W1R965;
M)'1H:7,M/E]P87)E;G1;)'1H:7,M/E]C=7)R<&%R96YT75LD=&AI<RT^7V-U
M<G)K97E=72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S(&EF
M('1H97)E(&%R92!M;W)E(&5L96UE;G1S(&EN('1H92!C=7)R96YT('1R964@
M;&5V96PN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF
M('1H97)E(&%R92!M;W)E(&5L96UE;G1S+"!F86QS92!I9B!T:&ES(&ES('1H
M90H@("`@("H@("`@("`@("`@("`@("`@("!L87-T(&5L96UE;G0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('!E96LH*0H@("`@>PH@("`@("`@(&9O<B`H)&D@
M/2`H)'1H:7,M/E]C=7)R:V5Y("L@,2D[(#L@)&DK*RD@>PH@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R96YT6R1T:&ES+3Y?8W5R<G!A<F5N
M=%U;)&E=*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V%C=&EV945L="@D
M=&AI<RT^7V%D9$%L:6%S97,H)'1H:7,M/E]T<F5E6R1T:&ES+3Y?<&%R96YT
M6R1T:&ES+3Y?8W5R<G!A<F5N=%U;)&E=72DI*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($%D9',@86QI87-E<R!T;R!A('1R964@96QE;65N
M="!A;F0@<F5T=7)N<R!T:&4@<F5S=6QT:6YG(&%R<F%Y+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1E;'0@($$@=')E92!E;&5M96YT+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@($$@=')E92!E;&5M96YT('=I=&@@=&AE(&%L:6%S97,@861D
M960N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A9&1!;&EA<V5S*"1E;'0I"B`@
M("!["B`@("`@("`@)&5L=%LG;&%B96PG72`]("1E;'1;)VPG73L*("`@("`@
M("`D96QT6R=L979E;"==(#T@)&5L=%LG8R==.PH@("`@("`@("1E;'1;)W!A
M<F5N="==(#T@)&5L=%LG<"==.PH@("`@("`@("1E;'1;)W9A;'5E)UT@/2`D
M96QT6R=V)UT["@H@("`@("`@(')E='5R;B`D96QT.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@<F5Q=65S=&5D(&5L96UE;G0N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&YA;64@;V8@=&AE
M('1R964@96QE;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!2
M971U<FYS('1H92!R97%U97-T960@96QE;65N="!O<B!F86QS92!I9B!N;W0@
M9F]U;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E="@D;F%M92D*("`@('L*
M("`@("`@("`D;F%M92`]("1T:&ES+3Y?8V]N=F5R=$YA;64H)&YA;64I.PH*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]T<F5E6R1N86UE72DI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?861D06QI87-E<R@D=&AI<RT^7W1R
M965;)&YA;65=*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@26YS
M97)T(&$@9F]L9&5R+VUA:6QB;W@@:6YT;R!T:&4@=')E92X*("`@("`J"B`@
M("`@*B!`<&%R86T@;6EX960@)&ED("!4:&4@;F%M92!O9B!T:&4@9F]L9&5R
M("AO<B!A(&QI<W0@;V8@9F]L9&5R(&YA;65S*0H@("`@("H@("`@("`@("`@
M("`@("`@("`@=&\@861D("AM=7-T(&)E('!R97-E;G0@;VX@=&AE(&UA:6P@
M<V5R=F5R*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@
M;VX@<W5C8V5S<RP@9F%L<V4@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&EN<V5R="@D:60I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?;6]D
M92`]/2!)34%05%)%15]-3T1%7TY%5U,I('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1I9"DI
M('L*("`@("`@("`@("`@:68@*"$D=&AI<RT^7VYO;FEM87!E;'0I('L*("`@
M("`@("`@("`@("`@("\J(%=E('=A;G0@=&\@861D(&9R;VT@=&AE($)!4T4@
M;V8@=&AE('1R964@=7`@9F]R(&5F9FEC:65N8WD*("`@("`@("`@("`@("`@
M("`J('-A:V4N("HO"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-O<G1,:7-T
M*"1I9"D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D:60@/2!A<G)A>2@D:60I.PH@("`@("`@('T*"B`@("`@("`@)&%D
M9',@/2!A<G)A>2@I.PH*("`@("`@("!F;W)E86-H("@D:60@87,@)'9A;"D@
M>PH@("`@("`@("`@("`D;G-?:6YF;R`]("1T:&ES+3Y?9V5T3F%M97-P86-E
M*"1V86PI.PH@("`@("`@("`@("!I9B`H:7-?;G5L;"@D;G-?:6YF;RD@?'P@
M)'1H:7,M/E]N;VYI;6%P96QT*2!["B`@("`@("`@("`@("`@("`D861D<UM=
M(#T@)'9A;#L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("\J($)R96%K(&%P87)T('1H92!N86UE('9I82!T:&4@9&5L:6UI=&5R(&%N
M9"!G;R!S=&5P(&)Y('-T97`*("`@("`@("`@("`@("`@("`J('1H<F]U9V@@
M=&AE(&YA;64@=&\@;6%K92!S=7)E(&%L;"!S=6)F;VQD97)S(&5X:7-T(&EN
M('1H90H@("`@("`@("`@("`@("`@("H@=')E92X@*B\*("`@("`@("`@("`@
M("`@("1P87)T<R`](&5X<&QO9&4H)&YS7VEN9F];)V1E;&EM:71E<B==+"`D
M=F%L*3L*("`@("`@("`@("`@("`@("1P87)T<ULP72`]("1T:&ES+3Y?8V]N
M=F5R=$YA;64H)'!A<G1S6S!=*3L*("`@("`@("`@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\(&-O=6YT*"1P87)T<RD[("1I*RLI('L*("`@("`@("`@("`@
M("`@("`@("`D861D<UM=(#T@:6UP;&]D92@D;G-?:6YF;ULG9&5L:6UI=&5R
M)UTL(&%R<F%Y7W-L:6-E*"1P87)T<RP@,"P@)&D@*R`Q*2D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&9O
M<F5A8V@@*&%R<F%Y7W5N:7%U92@D861D<RD@87,@)&ED*2!["B`@("`@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W1R965;)&ED72DI('L*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M=&AI<RT^7V-H86YG960@/2!T<G5E.PH*("`@("`@("`@("`@:68@*"1T:&ES
M+3Y?;F]N:6UA<&5L="D@>PH@("`@("`@("`@("`@("`@)&5L="`]("1T:&ES
M+3Y?9V5T3F]N24U!4$5L="@D:60I.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)&]B(#T@)'1H:7,M/E]G971,:7-T*"1I9"D["B`@
M("`@("`@("`@("`@("`D96QT(#T@)'1H:7,M/E]M86ME36%I;&)O>%1R965%
M;'0H<F5S970H)&]B*2D["B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YI
M<U-U8G-C<FEB960H)&5L="DI('L*("`@("`@("`@("`@("`@("`@("`D=&UP
M(#T@0&EM87!?;'-U8B@D=&AI<RT^7V=E=%-T<F5A;2@I+"`D=&AI<RT^7W-E
M<G9E<BP@)&5L=%LG=B==*3L*("`@("`@("`@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1T;7`I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<V5T4W5B<V-R:6)E9"@D96QT+"!T<G5E*3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(&EF("@D=&AI<RT^7VEN<V5R=$5L="@D96QT*2D@>PH@("`@("`@("`@
M("`@("`@+RH@5V4@:VYO=R!T:&%T('1H92!P87)E;G0@9F]L9&5R(&AA<R!C
M:&EL9')E;BX@*B\*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7W1R965;)&5L=%LG<"==72DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W-E=$-H:6QD<F5N*"1T:&ES+3Y?=')E95LD96QT6R=P)UU=+"!T<G5E
M*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O*B!-86ME
M('-U<F4@=V4@87)E('-O<G1E9"!C;W)R96-T;'DN("HO"B`@("`@("`@("`@
M("`@("!I9B`H8V]U;G0H)'1H:7,M/E]P87)E;G1;)&5L=%LG<"==72D@/B`Q
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S971.965D4V]R="@D
M=&AI<RT^7W1R965;)&5L=%LG<"==72P@=')U92D["B`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@+RH@061D('1O('-U8G-C<FEB960O=6YS
M=6)S8W)I8F5D(&QI<W0N("HO"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M
M/FES4W5B<V-R:6)E9"@D96QT*2`F)@H@("`@("`@("`@("`@("`@("`@("%I
M<U]N=6QL*"1T:&ES+3Y?<W5B<V-R:6)E9"DI('L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W-U8G-C<FEB961;)&5L=%LG=B==72`](#$["B`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H(21T:&ES+3YI<U-U8G-C<FEB960H)&5L
M="D@)B8*("`@("`@("`@("`@("`@("`@("`@("`@("`A:7-?;G5L;"@D=&AI
M<RT^7W5N<W5B<V-R:6)E9"DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W5N<W5B<V-R:6)E9%LD96QT6R=V)UU=(#T@,3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!);G-E<G0@86X@96QE;65N
M="!I;G1O('1H92!T<F5E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D96QT("!4:&4@96QE;65N
M="!T;R!I;G-E<G0N(%1H92!K97D@:6X@=&AE('1R964@:7,@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@)W8G("AV86QU92D@96QE;65N="!O9B!T
M:&4@96QE;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R
M=64@:68@861D960@=&\@=&AE('1R964N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]I;G-E<G1%;'0H)&5L="D*("`@('L*("`@("`@("`O*B!$;VXG="!I;F-L
M=61E('1H92!P87)E;G0@9&ER96-T;W)I97,@=&AA="!55R!P87-S97,@8F%C
M:R!I;@H@("`@("`@("`@("4O)2!L:7-T<RX@*B\*("`@("`@("!I9B`H<W1R
M;&5N*"1E;'1;)VPG72D@)B8*("`@("`@("`@("`@*"%I<W-E="@D=&AI<RT^
M7W1R965;)&5L=%LG=B==72D@?'P*("`@("`@("`@("`@("1T:&ES+3YI<T-O
M;G1A:6YE<B@D=&AI<RT^7W1R965;)&5L=%LG=B==72DI("8F"B`@("`@("`@
M("`@("\J(%1/1$\Z(%)E;6]V92!D;W1F:6QE<R!F:6QT97(@:6X@;F5X="!M
M86IO<B!R96QE87-E+B`J+PH@("`@("`@("`@("`H)'1H:7,M/E]D;W1F:6QE
M<R!\?"`H)&5L=%LG;"==6S!=("$]("<N)RDI*2!["B`@("`@("`@("`@("\J
M(%-E="!T:&4@<&%R96YT(&%R<F%Y('1O('1H92!V86QU92!I;B`D96QT6R=P
M)UTN("HO"B`@("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A<F5N=%LD
M96QT6R=P)UU=*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)E;G1;
M)&5L=%LG<"==72`](&%R<F%Y*"D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'1H:7,M/E]P87)E;G1;)&5L=%LG<"==75M=(#T@)&5L=%LG=B==.PH@
M("`@("`@("`@("`D=&AI<RT^7W1R965;)&5L=%LG=B==72`]("1E;'0["B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$96QE=&4@86X@96QE;65N="!F<F]M('1H92!T<F5E+@H@("`@
M("H*("`@("`J($!P87)A;2!M:7AE9"`D:60@(%1H92!E;&5M96YT(&YA;64@
M;W(@86X@87)R87D@;V8@96QE;65N="!N86UE<RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%)E='5R;B!T<G5E(&]N('-U8V-E<W,L(&9A;'-E
M(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&4H)&ED*0H@
M("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D:60I*2!["B`@("`@("`@("`@
M("\J(%=E('=A;G0@=&\@9&5L971E(&9R;VT@=&AE(%1/4"!O9B!T:&4@=')E
M92!D;W=N('1O(&5N<W5R92!T:&%T"B`@("`@("`@("`@("`J('!A<F5N=',@
M:&%V92!A;B!A8V-U<F%T92!V:65W(&]F('=H870@8VAI;&1R96X@87)E(&QE
M9G0N("HO"B`@("`@("`@("`@("1T:&ES+3Y?<V]R=$QI<W0H)&ED*3L*("`@
M("`@("`@("`@)&ED(#T@87)R87E?<F5V97)S92@D:60I.PH*("`@("`@("`@
M("`@)'-U8V-E<W,@/2!T<G5E.PH@("`@("`@("`@("!F;W)E86-H("@D:60@
M87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@)&-U<G)S=6-C97-S(#T@)'1H
M:7,M/F1E;&5T92@D=F%L*3L*("`@("`@("`@("`@("`@(&EF("@A)&-U<G)S
M=6-C97-S*2!["B`@("`@("`@("`@("`@("`@("`@)'-U8V-E<W,@/2!F86QS
M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!R971U<FX@)'-U8V-E<W,["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&ED(#T@)'1H:7,M/E]C;VYV97)T3F%M92@D:60L('1R=64I.PH@("`@
M("`@('T*"B`@("`@("`@)&YS7VEN9F\@/2`D=&AI<RT^7V=E=$YA;65S<&%C
M92@D:60I.PH*("`@("`@("!I9B`H*"1I9"`]/2`G24Y"3U@G*2!\?`H@("`@
M("`@("`@("`A:7-S970H)'1H:7,M/E]T<F5E6R1I9%TI('Q\"B`@("`@("`@
M("`@("@D:60@/3T@)&YS7VEN9F];)VYA;64G72DI('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]C:&%N
M9V5D(#T@=')U93L*"B`@("`@("`@)&5L="`]("8D=&AI<RT^7W1R965;)&ED
M73L*"B`@("`@("`@+RH@1&\@;F]T(&1E;&5T92!F<F]M('1R964@:68@=&AE
M<F4@87)E(&-H:6QD(&5L96UE;G1S("T@:6YS=&5A9"P*("`@("`@("`@*B!C
M;VYV97)T('1O(&$@8V]N=&%I;F5R(&5L96UE;G0N("HO"B`@("`@("`@:68@
M*"1T:&ES+3YH87-#:&EL9')E;B@D96QT*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7W-E=$-O;G1A:6YE<B@D96QT+"!T<G5E*3L*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`D<&%R96YT(#T@)&5L=%LG
M<"==.PH*("`@("`@("`O*B!$96QE=&4@=&AE('1R964@96YT<FEE<RX@*B\*
M("`@("`@("!U;G-E="@D=&AI<RT^7W1R965;)&ED72D["B`@("`@("`@=6YS
M970H)'1H:7,M/E]S=6)S8W)I8F5D6R1I9%TI.PH@("`@("`@('5N<V5T*"1T
M:&ES+3Y?=6YS=6)S8W)I8F5D6R1I9%TI.PH*("`@("`@("`O*B!$96QE=&4@
M=&AE(&5N=')Y(&9R;VT@=&AE('!A<F5N="!T<F5E+B`J+PH@("`@("`@("1K
M97D@/2!A<G)A>5]S96%R8V@H)&ED+"`D=&AI<RT^7W!A<F5N=%LD<&%R96YT
M72D["B`@("`@("`@=6YS970H)'1H:7,M/E]P87)E;G1;)'!A<F5N=%U;)&ME
M>5TI.PH*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)E;G1;)'!A<F5N
M=%TI*2!["B`@("`@("`@("`@("\J(%1H:7,@9F]L9&5R(&ES(&YO=R!C;VUP
M;&5T96QY(&5M<'1Y("AN;R!C:&EL9')E;BDN("!)9B!T:&4*("`@("`@("`@
M("`@("H@9F]L9&5R(&ES(&$@8V]N=&%I;F5R(&]N;'DL('=E('-H;W5L9"!D
M96QE=&4@=&AE(&9O;&1E<B!F<F]M"B`@("`@("`@("`@("`J('1H92!T<F5E
M+B`J+PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^7W!A<F5N=%LD<&%R96YT
M72D["B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W1R965;)'!A<F5N
M=%TI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=$-H:6QD<F5N*"1T
M:&ES+3Y?=')E95LD<&%R96YT72P@;G5L;"D["B`@("`@("`@("`@("`@("!I
M9B`H)'1H:7,M/FES0V]N=&%I;F5R*"1T:&ES+3Y?=')E95LD<&%R96YT72D@
M)B8*("`@("`@("`@("`@("`@("`@("`A)'1H:7,M/FES3F%M97-P86-E*"1T
M:&ES+3Y?=')E95LD<&%R96YT72DI('L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^9&5L971E*"1P87)E;G0I.PH@("`@("`@("`@("`@("`@?2!E;'-E
M:68@*"$D=&AI<RT^:&%S0VAI;&1R96XH)'1H:7,M/E]T<F5E6R1P87)E;G1=
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5M;W9E17AP86YD
M961,:7-T*"1P87)E;G0I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<V5T0VAI;&1R96XH)'1H:7,M/E]T<F5E6R1P87)E;G1=+"!F86QS92D["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S971/<&5N*"1T:&ES+3Y?=')E
M95LD<&%R96YT72P@9F%L<V4I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@4F5B=6EL
M9"!T:&4@<&%R96YT('1R964N("HO"B`@("`@("`@("`@("1T:&ES+3Y?<&%R
M96YT6R1P87)E;G1=(#T@87)R87E?=F%L=65S*"1T:&ES+3Y?<&%R96YT6R1P
M87)E;G1=*3L*("`@("`@("!]"@H@("`@("`@("\J(%)E;6]V92!T:&4@;6%I
M;&)O>"!F<F]M('1H92!E>'!A;F1E9"!F;VQD97)S(&QI<W0N("HO"B`@("`@
M("`@)'1H:7,M/E]R96UO=F5%>'!A;F1E9$QI<W0H)&ED*3L*"B`@("`@("`@
M+RH@4F5M;W9E('1H92!M86EL8F]X(&9R;VT@=&AE(&YA=E]P;VQL(&QI<W0N
M("HO"B`@("`@("`@)'1H:7,M/G)E;6]V95!O;&Q,:7-T*"1I9"D["@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4W5B<V-R
M:6)E(&%N(&5L96UE;G0@=&\@=&AE('1R964N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&UI>&5D("1I9"`@5&AE(&5L96UE;G0@;F%M92!O<B!A;B!A<G)A>2!O
M9B!E;&5M96YT(&YA;65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!S=6)S8W)I
M8F4H)&ED*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)&ED*2D@>PH@
M("`@("`@("`@("`D:60@/2!A<G)A>2@D:60I.PH@("`@("`@('T*"B`@("`@
M("`@9F]R96%C:"`H)&ED(&%S("1V86PI('L*("`@("`@("`@("`@)'9A;"`]
M("1T:&ES+3Y?8V]N=F5R=$YA;64H)'9A;"D["B`@("`@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W1R965;)'9A;%TI*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V-H86YG960@/2!T<G5E.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]S9713=6)S8W)I8F5D*"1T:&ES+3Y?=')E95LD=F%L72P@=')U92D["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7W-E=$-O;G1A:6YE<B@D=&AI<RT^7W1R
M965;)'9A;%TL(&9A;'-E*3L*("`@("`@("`@("`@("`@(&EF("@A:7-?;G5L
M;"@D=&AI<RT^7W-U8G-C<FEB960I*2!["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]S=6)S8W)I8F5D6R1V86Q=(#T@,3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?=6YS=6)S8W)I8F5D
M6R1V86Q=*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1T:&ES+3YI;G-E<G0H)'9A;"D["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!5;G-U8G-C<FEB92!A;B!E;&5M96YT
M(&9R;VT@=&AE('1R964N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1I
M9"`@5&AE(&5L96UE;G0@;F%M92!O<B!A;B!A<G)A>2!O9B!E;&5M96YT(&YA
M;65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!U;G-U8G-C<FEB92@D:60I"B`@
M("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D:60I*2!["B`@("`@("`@("`@
M("1I9"`](&%R<F%Y*"1I9"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@+RH@5V4@=V%N="!T;R!D96QE=&4@9G)O;2!T:&4@5$]0(&]F('1H92!T
M<F5E(&1O=VX@=&\@96YS=7)E('1H870*("`@("`@("`@("`@("H@<&%R96YT
M<R!H879E(&%N(&%C8W5R871E('9I97<@;V8@=VAA="!C:&EL9')E;B!A<F4@
M;&5F="X@*B\*("`@("`@("`@("`@)'1H:7,M/E]S;W)T3&ES="@D:60I.PH@
M("`@("`@("`@("`D:60@/2!A<G)A>5]R979E<G-E*"1I9"D["B`@("`@("`@
M?0H*("`@("`@("!F;W)E86-H("@D:60@87,@)'9A;"D@>PH@("`@("`@("`@
M("`D=F%L(#T@)'1H:7,M/E]C;VYV97)T3F%M92@D=F%L*3L*"B`@("`@("`@
M("`@("\J($E.0D]8(&-A;B!N979E<B!B92!U;G-U8G-C<FEB960@=&\@*&EF
M(&EN(&UA:6P@;6]D92DN("HO"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7W1R965;)'9A;%TI("8F("@D=F%L("$]("=)3D)/6"<I*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7V-H86YG960@/2!T<G5E.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]U;G-U8G9I97<@/2!T<G5E.PH*("`@("`@("`@("`@
M("`@("1E;'0@/2`F)'1H:7,M/E]T<F5E6R1V86Q=.PH*("`@("`@("`@("`@
M("`@("\J($1O(&YO="!D96QE=&4@9G)O;2!T<F5E(&EF('1H97)E(&%R92!C
M:&EL9"!E;&5M96YT<R`M"B`@("`@("`@("`@("`@("`@*B!I;G-T96%D+"!C
M;VYV97)T('1O(&$@8V]N=&%I;F5R(&5L96UE;G0N("HO"B`@("`@("`@("`@
M("`@("!I9B`H(21T:&ES+3Y?<VAO=W5N<W5B("8F("1T:&ES+3YH87-#:&EL
M9')E;B@D96QT*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T
M0V]N=&%I;F5R*"1E;'0L('1R=64I.PH@("`@("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@("`@("\J(%-E="!A<R!U;G-U8G-C<FEB960L(&%D9"!T;R!U
M;G-U8G-C<FEB960@;&ES="P@86YD(')E;6]V90H@("`@("`@("`@("`@("`@
M("H@9G)O;2!S=6)S8W)I8F5D(&QI<W0N("HO"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7W-E=%-U8G-C<FEB960H)&5L="P@9F%L<V4I.PH@("`@("`@("`@
M("`@("`@:68@*"%I<U]N=6QL*"1T:&ES+3Y?=6YS=6)S8W)I8F5D*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=6YS=6)S8W)I8F5D6R1V86Q=
M(#T@,3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('5N<V5T
M*"1T:&ES+3Y?<W5B<V-R:6)E9%LD=F%L72D["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@86YO=&AE<B!L979E
M;"!O9B!H:65R87)C:'D@=&\@=&AE('1R964N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1L:7-T
M("!!(&QI<W0@;V8@<W1D0VQA<W,@;V)J96-T<R!I;B!T:&4@9F]R;6%T(')E
M='5R;F5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&9R;VT@:6UA<%]G
M971M86EL8F]X97,H*2X*("`@("`J+PH@("`@9G5N8W1I;VX@7V%D9$QE=F5L
M*"1L:7-T*0H@("`@>PH@("`@("`@("1E>'!A;F1A;&P@/2`H)'1H:7,M/E]I
M;FET;6]D92`F($E-05!44D5%7TE.251?1D540TA!3$PI.PH*("`@("`@("!F
M;W)E86-H("@D;&ES="!A<R`D=F%L*2!["B`@("`@("`@("`@("1E;'0@/2`D
M=&AI<RT^7VUA:V5-86EL8F]X5')E945L="@D=F%L*3L*"B`@("`@("`@("`@
M("1P87)E;G0@/2`D96QT6R=P)UT["B`@("`@("`@("`@("1T:&ES+3Y?:6YS
M97)T16QT*"1E;'0I.PH@("`@("`@("`@("`D=&AI<RT^7V-H86YG960@/2!T
M<G5E.PH*("`@("`@("`@("`@:68@*"1E>'!A;F1A;&P@?'P@)'1H:7,M/FES
M3W!E;B@D96QT*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F5X<&%N9"@D
M96QT6R=V)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M*B!3;W)T('1H92!L:7-T+B`J+PH@("`@("`@(&EF("@A96UP='DH)&QI<W0I
M("8F"B`@("`@("`@("`@("%E;7!T>2@D=&AI<RT^7W!A<F5N=%LD<&%R96YT
M72DI('L*("`@("`@("`@("`@)'1H:7,M/E]S971$:7-C;W9E<F5D*"1T:&ES
M+3Y?=')E95LD<&%R96YT72P@=')U92D["B`@("`@("`@("`@(&EF("AC;W5N
M="@D=&AI<RT^7W!A<F5N=%LD<&%R96YT72D@/B`Q*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W-E=$YE9613;W)T*"1T:&ES+3Y?=')E95LD<&%R96YT
M72P@=')U92D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!3970@86X@871T<FEB=71E(&9O<B!A;B!E;&5M96YT+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`F)&5L="`@("`@5&AE('1R964@96QE;65N="X*("`@("`J
M($!P87)A;2!I;G1E9V5R("1C;VYS="`@5&AE(&-O;G-T86YT('1O('-E="]R
M96UO=F4@9G)O;2!T:&4@8FET;6%S:RX*("`@("`J($!P87)A;2!B;V]L96%N
M("1B;V]L("`@4VAO=6QD('1H92!A='1R:6)U=&4@8F4@<V5T/PH@("`@("HO
M"B`@("!F=6YC=&EO;B!?<V5T071T<FEB=71E*"8D96QT+"`D8V]N<W0L("1B
M;V]L*0H@("`@>PH@("`@("`@(&EF("@D8F]O;"D@>PH@("`@("`@("`@("`D
M96QT6R=A)UT@?#T@)&-O;G-T.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1E;'1;)V$G72`F/2!^)&-O;G-T.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($1O97,@=&AE(&5L96UE;G0@:&%V92!A;GD@86-T:79E
M(&-H:6QD<F5N/PH@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D96QT("!!
M('1R964@96QE;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@:68@=&AE(&5L96UE;G0@:&%S(&%C=&EV92!C:&EL9')E;BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@:&%S0VAI;&1R96XH)&5L="D*("`@('L*("`@
M("`@("!S=&%T:6,@)&AA<T-H:6QD<F5N0V%C:&4@/2!A<G)A>2@I.PH*("`@
M("`@("`D:7-?;G,@/2`D=&AI<RT^:7-.86UE<W!A8V4H)&5L="D["@H@("`@
M("`@("\J($1O;B=T(&1O('1H92!F;VQL;W=I;F<@:68@=V4@87)E(&1E86QI
M;F<@=VET:"!A(&YA;65S<&%C90H@("`@("`@("`J(&-O;G1A:6YE<BX@*B\*
M("`@("`@("!I9B`H(21I<U]N<RD@>PH@("`@("`@("`@("`O*B!.;W0@86QL
M($E-05`@<V5R=F5R<R!S=7!P;W)T('1H92!(05-#2$E,1%)%3B!F;&%G("AL
M:6ME(%57(2D@<V\*("`@("`@("`@("`@("H@=V4@;F5E9"!T;R!S:VEP('1H
M:7,@8VAE8VL@:68@=&AE($E-05`@<V5R=F5R(&1O97-N)W0@<V5T"B`@("`@
M("`@("`@("`J(&5I=&AE<B!(05-#2$E,1%)%3B!O<B!(05-.3T-(24Q$4D5.
M+B`J+PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?8VAI;&1R96YS
M=7!P;W)T*2!\?`H@("`@("`@("`@("`@("`@*&ES7VYU;&PH)'1H:7,M/E]C
M:&EL9')E;G-U<'!O<G0I("8F"B`@("`@("`@("`@("`@("`@*"1E;'1;)V$G
M72`F($Q!5%1?2$%30TA)3$1214XI('Q\"B`@("`@("`@("`@("`@("`@*"1E
M;'1;)V$G72`F($Q!5%1?2$%33D]#2$E,1%)%3BDI*2!["B`@("`@("`@("`@
M("`@("`D<F5T(#T@*"1E;'1;)V$G72`F($Q!5%1?2$%30TA)3$1214XI.PH*
M("`@("`@("`@("`@("`@("\J($-(14-+.B!)9B!W92!A<F4@=FEE=VEN9R!A
M;&P@9F]L9&5R<RP@86YD('1H97)E(&ES(&$@9F]L9&5R"B`@("`@("`@("`@
M("`@("`@*B!L:7-T960@87,@97AP86YD960@8G5T(&ET(&1O97,@;F]T(&-O
M;G1A:6X@86YY(&-H:6QD<F5N+`H@("`@("`@("`@("`@("`@("H@=&AE;B!W
M92!S:&]U;&0@<F5M;W9E(&ET(&9R;VT@=&AE(&5X<&%N9&5D(&QI<W0@<VEN
M8V4@:70*("`@("`@("`@("`@("`@("`J(&1O97-N)W0@97AI<W0@86YY;6]R
M92X@*B\*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7W-H;W=U;G-U8B`F
M)B`A)')E="D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YI=$5X
M<&%N9&5D3&ES="@I.PH@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH
M)'1H:7,M/E]E>'!A;F1E9%LD96QT6R=V)UU=*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W)E;6]V945X<&%N9&5D3&ES="@D96QT6R=V
M)UTI.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=$]P96XH
M)'1H:7,M/E]T<F5E6R1E;'1;)W8G75TL(&9A;'-E*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M:68@*"$D<F5T*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\J($EF('=E
M(&%R92!V:65W:6YG(&%L;"!E;&5M96YT<R`H<W5B<V-R:6)E9"!A;F0@=6YS
M=6)S8W)I8F5D*0H@("`@("`@("`@("`@("`@("H@86YD('=E(')E86-H('1H
M:7,@<&]I;G0@=V4@:VYO=R!T:&%T('1H97)E(&UU<W0@8F4@=FEE=V%B;&4*
M("`@("`@("`@("`@("`@("`J(&-H:6QD<F5N('-O(')E='5R;B!T<G5E+B`J
M+PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?<VAO=W5N<W5B*2!["B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($-A8VAE
M(')E<W5L=',@9G)O;2!B96QO=R!S:6YC92P@;6]S="!L:6ME;'D@:68@=V4@
M9V5T('1H:7,@9F%R+`H@("`@("`@("`J('1H:7,@8V]D92!W:6QL(&)E(&%C
M8V5S<V5D('-E=F5R86P@=&EM97,@:6X@=&AE(&-U<G)E;G0@<F5Q=65S="X@
M*B\*("`@("`@("!I9B`H:7-S970H)&AA<T-H:6QD<F5N0V%C:&5;)&5L=%LG
M=B==72DI('L*("`@("`@("`@("`@<F5T=7)N("1H87-#:&EL9')E;D-A8VAE
M6R1E;'1;)W8G75T["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!W92!R96%C
M:"!T:&ES('!O:6YT+"!T:&5N('=E(&%R92!E:71H97(@:6X@<W5B<V-R:6)E
M+6]N;'D@;6]D90H@("`@("`@("`J(&]R('=E(&%R92!D96%L:6YG('=I=&@@
M82!N86UE<W!A8V4@8V]N=&%I;F5R+B!#:&5C:R!F;W(@=&AE"B`@("`@("`@
M("H@97AI<W1E;F-E(&]F(&%N>2!S=6)S8W)I8F5D(&UA:6QB;WAE<R!B96QO
M=R!T:&4@8W5R<F5N="!N;V1E+B`J+PH@("`@("`@("1T:&ES+3Y?:6YI=%-U
M8G-C<FEB960H*3L*("`@("`@("`D9F]L9&5R7VQI<W0@/2`D=&AI<RT^7W-U
M8G-C<FEB960["B`@("`@("`@:68@*"1T:&ES+3Y?<VAO=W5N<W5B*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?:6YI=%5N<W5B<V-R:6)E9"@I.PH@("`@("`@
M("`@("`D9F]L9&5R7VQI<W0@*ST@)'1H:7,M/E]U;G-U8G-C<FEB960["B`@
M("`@("`@?0H@("`@("`@("1N<U]I;F9O(#T@)'1H:7,M/E]G971.86UE<W!A
M8V4H)&5L=%LG=B==*3L*("`@("`@("!I9B`H(6ES7VYU;&PH)&YS7VEN9F\I
M*2!["B`@("`@("`@("`@("1S96%R8VA?<W1R(#T@)&5L=%LG=B==("X@)&YS
M7VEN9F];)V1E;&EM:71E<B==.PH@("`@("`@("`@("!I9B`H*"1E;'1;)W8G
M72`]/2`G24Y"3U@G*2`F)@H@("`@("`@("`@("`@("`@*"1N<U]I;F9O6R=N
M86UE)UT@/3T@*"=)3D)/6"<@+B`D;G-?:6YF;ULG9&5L:6UI=&5R)UTI*2D@
M>PH@("`@("`@("`@("`@("`@)'-E87)C:%]S='(@+CT@)&YS7VEN9F];)VYA
M;64G73L*("`@("`@("`@("`@?0H@("`@("`@("`@("!F;W)E86-H("AA<G)A
M>5]K97ES*"1F;VQD97)?;&ES="D@87,@)'9A;"D@>PH@("`@("`@("`@("`@
M("`@:68@*'-T<G!O<R@D=F%L+"`D<V5A<F-H7W-T<BD@/3T](#`I('L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7VAA<T-H:6QD<F5N0V%C:&5;)&5L
M=%LG=B==72`]('1R=64["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R
M=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("\J($1O(&]N92!F:6YA;"!C:&5C:R!I9B!T:&ES(&ES(&$@
M;F%M97-P86-E(&-O;G1A:6YE<B`M(&EF('=E(&=E=`H@("`@("`@("`J('1H
M:7,@9F%R+"!A;F0@87)E('9I97=I;F<@86QL(&9O;&1E<G,L('1H96X@=V4@
M:VYO=R!W92!H879E(&YO"B`@("`@("`@("H@8VAI;&1R96X@<V\@;6%K92!S
M=7)E('1H92!E;&5M96YT(&ES(&YO="!S970@=&\@97AP86YD960O;W!E;BX@
M*B\*("`@("`@("!I9B`H)&ES7VYS("8F("1T:&ES+3Y?<VAO=W5N<W5B*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?:6YI=$5X<&%N9&5D3&ES="@I.PH@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?97AP86YD961;)&5L=%LG=B==
M72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5M;W9E17AP86YD961,
M:7-T*"1E;'1;)W8G72D["B`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=$]P
M96XH)'1H:7,M/E]T<F5E6R1E;'1;)W8G75TL(&9A;'-E*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@)&AA<T-H:6QD<F5N0V%C:&5;)&5L
M=%LG=B==72`](&9A;'-E.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%-E="!T:&4@8VAI;&1R96X@871T<FEB=71E(&9O
M<B!A;B!E;&5M96YT+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`F)&5L="`@02!T<F5E(&5L96UE
M;G0N"B`@("`@*B!`<&%R86T@;6EX960@)&)O;VP@(%1H92!S971T:6YG+B!)
M9B!N=6QL+"!C;&5A<G,@=&AE(&9L86<N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]S971#:&EL9')E;B@F)&5L="P@)&)O;VPI"B`@("!["B`@("`@("`@:68@
M*&ES7VYU;&PH)&)O;VPI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5T071T
M<FEB=71E*"1E;'0L($Q!5%1?2$%30TA)3$1214XL(&9A;'-E*3L*("`@("`@
M("`@("`@)'1H:7,M/E]S971!='1R:6)U=&4H)&5L="P@3$%45%](05-.3T-(
M24Q$4D5.+"!F86QS92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1H:7,M/E]S971!='1R:6)U=&4H)&5L="P@3$%45%](05-#2$E,1%)%3BP@
M)&)O;VPI.PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%T=')I8G5T92@D96QT
M+"!,05147TA!4TY/0TA)3$1214XL("$D8F]O;"D["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@2&%S('1H92!T<F5E(&5L96UE;G0@8F5E;B!D
M:7-C;W9E<F5D/PH@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D96QT("!!
M('1R964@96QE;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@
M($YO;BUZ97)O(&EF('1H92!E;&5M96YT(&AA<R!B965N(&1I<V-O=F5R960N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES1&ES8V]V97)E9"@D96QT*0H@("`@
M>PH@("`@("`@(')E='5R;B`D96QT6R=A)UT@)B!)34%05%)%15]%3%1?25-?
M1$E30T]615)%1#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@9&ES
M8V]V97)E9"!A='1R:6)U=&4@9F]R(&%N(&5L96UE;G0N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("8D96QT("`@($$@=')E92!E;&5M96YT+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&)O;VP@(%1H92!S971T:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M<V5T1&ES8V]V97)E9"@F)&5L="P@)&)O;VPI"B`@("!["B`@("`@("`@)'1H
M:7,M/E]S971!='1R:6)U=&4H)&5L="P@24U!4%12145?14Q47TE37T1)4T-/
M5D52140L("1B;V]L*3L*("`@('T*"B`@("`O*BH*("`@("`J($ES('1H92!T
M<F5E(&5L96UE;G0@;W!E;C\*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)&5L="`@02!T<F5E(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G1E9V5R("!4<G5E(&EF('1H92!E;&5M96YT(&ES(&]P96XN"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&ES3W!E;B@D96QT*0H@("`@>PH@("`@("`@(&EF("@A
M)'1H:7,M/E]I;FET;6]D92D@>PH@("`@("`@("`@("!R971U<FX@*"@D96QT
M6R=A)UT@)B!)34%05%)%15]%3%1?25-?3U!%3BD@)B8@)'1H:7,M/FAA<T-H
M:6QD<F5N*"1E;'0I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!S
M=VET8V@@*"1T:&ES+3Y?9V5T26YI=$5X<&%N9&5D36]D92@I*2!["B`@("`@
M("`@("`@(&-A<V4@24U!4%12145?3U!%3E].3TY%.@H@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!C87-E($E-05!44D5%7T]014Y?04Q,.@H@("`@("`@("`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@(&-A<V4@24U!4%12145?3U!%3E]54T52.@H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]I;FET17AP86YD961,:7-T*"D["B`@("`@("`@("`@("`@
M("!R971U<FX@(65M<'1Y*"1T:&ES+3Y?97AP86YD961;)&5L=%LG=B==72D[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@;W!E;B!A='1R:6)U
M=&4@9F]R(&%N(&5L96UE;G0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D96QT("`@($$@=')E
M92!E;&5M96YT+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&)O;VP@(%1H92!S
M971T:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5T3W!E;B@F)&5L="P@
M)&)O;VPI"B`@("!["B`@("`@("`@)'1H:7,M/E]S971!='1R:6)U=&4H)&5L
M="P@24U!4%12145?14Q47TE37T]014XL("1B;V]L*3L*("`@("`@("!I9B`H
M(21T:&ES+3Y?:6YI=&UO9&4I('L*("`@("`@("`@("`@)'1H:7,M/E]I;FET
M17AP86YD961,:7-T*"D["B`@("`@("`@("`@(&EF("@D8F]O;"D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]A9&1%>'!A;F1E9$QI<W0H)&5L=%LG=B==
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<F5M;W9E17AP86YD961,:7-T*"1E;'1;)W8G72D["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!)<R!T:&ES(&5L
M96UE;G0@82!C;VYT86EN97(@;VYL>2P@;F]T(&$@;6%I;&)O>"`H;65A;FEN
M9R!Y;W4@8V%N"B`@("`@*B!N;W0@;W!E;B!I="D_"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1E;'0@($$@=')E92!E;&5M96YT+@H@("`@("H*("`@
M("`J($!R971U<FX@:6YT96=E<B`@5')U92!I9B!T:&4@96QE;65N="!I<R!A
M(&-O;G1A:6YE<BX*("`@("`J+PH@("`@9G5N8W1I;VX@:7-#;VYT86EN97(H
M)&5L="D*("`@('L*("`@("`@("!R971U<FX@*"@D96QT6R=A)UT@)B!,0514
M7TY/4T5,14-4*2!\?`H@("`@("`@("`@("`@("`@*"$D=&AI<RT^7W-H;W=U
M;G-U8B`F)@H@("`@("`@("`@("`@("`@("$D=&AI<RT^:7-3=6)S8W)I8F5D
M*"1E;'0I("8F"B`@("`@("`@("`@("`@("`@)'1H:7,M/FAA<T-H:6QD<F5N
M*"1E;'0I*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&5L96UE
M;G0@87,@82!C;VYT86EN97(_"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D96QT("`@($$@=')E
M92!E;&5M96YT+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&)O;VP@($ES('1H
M92!E;&5M96YT(&$@8V]N=&%I;F5R/PH@("`@("HO"B`@("!F=6YC=&EO;B!?
M<V5T0V]N=&%I;F5R*"8D96QT+"`D8F]O;"D*("`@('L*("`@("`@("`D=&AI
M<RT^7W-E=$%T=')I8G5T92@D96QT+"!,05147TY/4T5,14-4+"`D8F]O;"D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!)<R!T:&4@=7-E<B!S=6)S8W)I8F5D
M('1O('1H:7,@96QE;65N=#\*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)&5L="`@02!T<F5E(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G1E9V5R("!4<G5E(&EF('1H92!U<V5R(&ES('-U8G-C<FEB960@=&\@=&AE
M(&5L96UE;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES4W5B<V-R:6)E9"@D
M96QT*0H@("`@>PH@("`@("`@(')E='5R;B`D96QT6R=A)UT@)B!)34%05%)%
M15]%3%1?25-?4U5"4T-224)%1#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E
M="!T:&4@<W5B<V-R:7!T:6]N('-T871U<R!F;W(@86X@96QE;65N="X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)B1E;'0@("`@02!T<F5E(&5L96UE;G0N"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D8F]O;"`@27,@=&AE(&5L96UE;G0@<W5B<V-R:6)E9"!T
M;S\*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E=%-U8G-C<FEB960H)B1E;'0L
M("1B;V]L*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V5T071T<FEB=71E*"1E
M;'0L($E-05!44D5%7T5,5%])4U]354)30U))0D5$+"`D8F]O;"D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!)<R!T:&4@96QE;65N="!A(&YA;65S<&%C92!C
M;VYT86EN97(_"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1E;'0@($$@
M=')E92!E;&5M96YT+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@
M5')U92!I9B!T:&4@96QE;65N="!I<R!A(&YA;65S<&%C92!C;VYT86EN97(_
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES3F%M97-P86-E*"1E;'0I"B`@("![
M"B`@("`@("`@<F5T=7)N("1E;'1;)V$G72`F($E-05!44D5%7T5,5%].04U%
M4U!!0T4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F4@=&AE('-E<G9E
M<B!S=')I;F<@9G)O;2!T:&4@)VYA;64G('!A<F%M971E<BX*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@;V)J
M96-T('-T9$-L87-S("1O8B`@06X@;V)J96-T(')E='5R;F5D(&9R;VT*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I;6%P7V=E=&UA:6QB
M;WAE<R@I+@H@("`@("H*("`@("`J($!R971U<FX@<W1D0VQA<W,@(%1H92!O
M8FIE8W0@<F5T=7)N960@=VET:"!T:&4@<V5R=F5R('-T<FEN9R!S=')I<'!E
M9`H@("`@("H@("`@("`@("`@("`@("`@("`@9G)O;2!T:&4@)VYA;64G('!A
M<F%M971E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@7W)E;6]V95-E<G9E<E-T
M<FEN9R@D;V(I"B`@("!["B`@("`@("`@)&]B+3YF=6QL4V5R=F5R4&%T:"`]
M("1O8BT^;F%M93L*("`@("`@("`D;V(M/FYA;64@/2`D=&AI<RT^7V-O;G9E
M<G1.86UE*'-U8G-T<B@D;V(M/FYA;64L('-T<G!O<R@D;V(M/FYA;64L("=]
M)RD@*R`Q*2D["B`@("`@("`@<F5T=7)N("1O8CL*("`@('T*"B`@("`O*BH*
M("`@("`J($EN:71I86QI>F4@=&AE(&5X<&%N9&5D(&9O;&1E<B!L:7-T+@H@
M("`@("H@5$A)4R!-151(3T0@4TA/54Q$($)%($1%1DE.140@24X@04Q,(%-5
M0D-,05-315,N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]I;FET
M17AP86YD961,:7-T*"D*("`@('L*("`@("`@("`D=&AI<RT^7V5X<&%N9&5D
M(#T@87)R87DH*3L*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!A;B!E;&5M
M96YT('1O('1H92!E>'!A;F1E9"!L:7-T+@H@("`@("H@5$A)4R!-151(3T0@
M4TA/54Q$($)%($1%1DE.140@24X@04Q,(%-50D-,05-315,N"B`@("`@*@H@
M("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!E;&5M96YT
M(&YA;64@=&\@<F5M;W9E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?861D17AP
M86YD961,:7-T*"1I9"D*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M;6]V92!A;B!E;&5M96YT(&9R;VT@=&AE(&5X<&%N9&5D(&QI<W0N"B`@("`@
M*B!42$E3($U%5$A/1"!32$]53$0@0D4@1$5&24Y%1"!)3B!!3$P@4U5"0TQ!
M4U-%4RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I
M9"`@5&AE(&5L96UE;G0@;F%M92!T;R!R96UO=F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]R96UO=F5%>'!A;F1E9$QI<W0H)&ED*0H@("`@>PH@("`@?0H*
M("`@("\J*@H@("`@("H@26YI=&EA;&EZ92]G970@=&AE(&QI<W0@;V8@96QE
M;65N=',@=&\@<&]L;"X*("`@("`J(%1(25,@34542$]$(%-(3U5,1"!"12!$
M149)3D5$($E.($%,3"!354)#3$%34T53+@H@("`@("H*("`@("`J($!A8G-T
M<F%C=`H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!L:7-T(&]F
M(&5L96UE;G1S('1O('!O;&P@*&YA;64@:6X@:V5Y(&9I96QD*2X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T4&]L;$QI<W0H*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?<&]L;"`](&%R<F%Y*"D["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<&]L;#L*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!E;&5M96YT('1O('1H
M92!P;VQL(&QI<W0N"B`@("`@*B!42$E3($U%5$A/1"!32$]53$0@0D4@1$5&
M24Y%1"!)3B!!3$P@4U5"0TQ!4U-%4RX*("`@("`J"B`@("`@*B!`86)S=')A
M8W0*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&ED("!4:&4@96QE;65N
M="!N86UE(&]R(&$@;&ES="!O9B!E;&5M96YT(&YA;65S('1O(&%D9"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@861D4&]L;$QI<W0H)&ED*0H@("`@>PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5M;W9E(&5L96UE;G0@9G)O;2!T:&4@<&]L
M;"!L:7-T+@H@("`@("H@5$A)4R!-151(3T0@4TA/54Q$($)%($1%1DE.140@
M24X@04Q,(%-50D-,05-315,N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!F;VQD97(O;6%I
M;&)O>"!O<B!A(&QI<W0@;V8@9F]L9&5R<R]M86EL8F]X97,*("`@("`J("`@
M("`@("`@("`@("`@("`@("!T;R!R96UO=F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')E;6]V95!O;&Q,:7-T*"1I9"D*("`@('L*("`@('T*"B`@("`O*BH*
M("`@("`J($1O97,@=&AE('5S97(@=V%N="!T;R!P;VQL('1H:7,@;6%I;&)O
M>"!F;W(@;F5W+W5N<V5E;B!M97-S86=E<S\*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)&5L="`@02!T<F5E(&5L96UE;G0N"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G1E9V5R("!4<G5E(&EF('1H92!U<V5R('=A;G1S('1O('!O
M;&P@=&AE(&5L96UE;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES4&]L;&5D
M*"1E;'0I"B`@("!["B`@("`@("`@<F5T=7)N("1E;'1;)V$G72`F($E-05!4
M4D5%7T5,5%])4U]03TQ,140["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@
M=&AE('!O;&QE9"!A='1R:6)U=&4@9F]R(&%N(&5L96UE;G0N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("8D96QT("`@($$@=')E92!E;&5M96YT+@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)&)O;VP@(%1H92!S971T:6YG+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?<V5T4&]L;&5D*"8D96QT+"`D8F]O;"D*("`@('L*("`@("`@("`D=&AI
M<RT^7W-E=$%T=')I8G5T92@D96QT+"!)34%05%)%15]%3%1?25-?4$],3$5$
M+"`D8F]O;"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&;&%G('1H92!E;&5M
M96YT(&%S(&YE961I;F<@:71S(&-H:6QD<F5N('1O(&)E('-O<G1E9"X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)B1E;'0@("`@02!T<F5E(&5L96UE;G0N"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D8F]O;"`@5&AE('-E='1I;F<N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]S971.965D4V]R="@F)&5L="P@)&)O;VPI"B`@("!["B`@("`@
M("`@)'1H:7,M/E]S971!='1R:6)U=&4H)&5L="P@24U!4%12145?14Q47TY%
M141?4T]25"P@)&)O;VPI.PH@("`@?0H*("`@("\J*@H@("`@("H@1&]E<R!T
M:&ES(&5L96UE;G0G<R!C:&EL9')E;B!N965D('-O<G1I;F<_"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1E;'0@($$@=')E92!E;&5M96YT+@H@("`@
M("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5')U92!I9B!T:&4@8VAI;&1R
M96X@;F5E9"!T;R!B92!S;W)T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]N
M965D4V]R="@D96QT*0H@("`@>PH@("`@("`@(')E='5R;B`D96QT6R=A)UT@
M)B!)34%05%)%15]%3%1?3D5%1%]33U)4.PH@("`@?0H*("`@("\J*@H@("`@
M("H@26YI=&EA;&EZ92!T:&4@;&ES="!O9B!S=6)S8W)I8F5D(&UA:6QB;WAE
M<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M9G5N8W1I;VX@7VEN:713=6)S8W)I8F5D*"D*("`@('L*("`@("`@("!I9B`H
M:7-?;G5L;"@D=&AI<RT^7W-U8G-C<FEB960I*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?8VAA;F=E9"`]('1R=64["B`@("`@("`@("`@("1T:&ES+3Y?<W5B
M<V-R:6)E9"`](&%R<F%Y*"D["B`@("`@("`@("`@("1S=6)L:7-T(#T@87)R
M87DH*3L*"B`@("`@("`@("`@("\J($E.0D]8(&ES(&%L=V%Y<R!S=6)S8W)I
M8F5D('1O(&EF('=E(&%R92!I;B!M86EL(&UO9&4N("HO"B`@("`@("`@("`@
M(&EF("@D=&AI<RT^7VUO9&4@/3T@24U!4%12145?34]$15]-04E,*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7W-U8G-C<FEB961;)TE.0D]8)UT@/2`Q
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)'1H:7,M/E]N86UE
M<W!A8V5S*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7VYA
M;65S<&%C97,@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@("`@("1T;7`@
M/2!`:6UA<%]L<W5B*"1T:&ES+3Y?9V5T4W1R96%M*"DL("1T:&ES+3Y?<V5R
M=F5R+"`D=F%L6R=N86UE)UT@+B`G*B<I.PH@("`@("`@("`@("`@("`@("`@
M(&EF("@A96UP='DH)'1M<"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'-U8FQI<W0@/2!A<G)A>5]M97)G92@D<W5B;&ES="P@)'1M<"D["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'-U8FQI<W0@/2!`:6UA<%]L
M<W5B*"1T:&ES+3Y?9V5T4W1R96%M*"DL("1T:&ES+3Y?<V5R=F5R+"`D=&AI
M<RT^7W!R969I>"`N("<J)RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(&EF("@A96UP='DH)'-U8FQI<W0I*2!["B`@("`@("`@("`@("`@("!F;W)E
M86-H("@D<W5B;&ES="!A<R`D=F%L*2!["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]S=6)S8W)I8F5D6W-U8G-T<B@D=F%L+"!S=')P;W,H)'9A;"P@
M)WTG*2`K(#$I72`](#$["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!);FET:6%L:7IE
M('1H92!L:7-T(&]F('5N<W5B<V-R:6)E9"!M86EL8F]X97,N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]I
M;FET56YS=6)S8W)I8F5D*"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D
M=&AI<RT^7W5N<W5B<V-R:6)E9"DI('L*("`@("`@("`@("`@)'1H:7,M/E]C
M:&%N9V5D(#T@=')U93L*("`@("`@("`@("`@)'1H:7,M/E]I;FET4W5B<V-R
M:6)E9"@I.PH@("`@("`@("`@("`D=&AI<RT^7W5N<W5B<V-R:6)E9"`](&%R
M<F%Y*"D["B`@("`@("`@("`@("1A;&Q?;&ES="`](&%R<F%Y*"D["@H@("`@
M("`@("`@("`O*B!'970@;&ES="!O9B!A;&P@;6%I;&)O>&5S+B`J+PH@("`@
M("`@("`@("!I9B`H)'1H:7,M/E]N86UE<W!A8V5S*2!["B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D=&AI<RT^7VYA;65S<&%C97,@87,@)'9A;"D@>PH@
M("`@("`@("`@("`@("`@("`@("1T;7`@/2!`:6UA<%]L:7-T*"1T:&ES+3Y?
M9V5T4W1R96%M*"DL("1T:&ES+3Y?<V5R=F5R+"`D=F%L6R=N86UE)UT@+B`G
M*B<I.PH@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'1M<"DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&%L;%]L:7-T(#T@87)R87E?;65R
M9V4H)&%L;%]L:7-T+"`D=&UP*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D86QL7VQI<W0@/2!`:6UA<%]L:7-T*"1T:&ES+3Y?9V5T4W1R
M96%M*"DL("1T:&ES+3Y?<V5R=F5R+"`D=&AI<RT^7W!R969I>"`N("<J)RD[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@A96UP='DH)&%L;%]L
M:7-T*2D@>PH@("`@("`@("`@("`@("`@+RH@1FEN9"!A;&P@;6%I;&)O>&5S
M('1H870@87)E;B=T(&EN('1H92!S=6)S8W)I8F5D(&QI<W0N("HO"B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D86QL7VQI<W0@87,@)'9A;"D@>PH@("`@
M("`@("`@("`@("`@("`@("1V86P@/2!S=6)S='(H)'9A;"P@<W1R<&]S*"1V
M86PL("=])RD@*R`Q*3L*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?<W5B<V-R:6)E9%LD=F%L72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]U;G-U8G-C<FEB961;)'9A;%T@/2`Q.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-H;W5L9"!W
M92!E>'!A;F0@86QL(&5L96UE;G1S/PH@("`@("HO"B`@("!F=6YC=&EO;B!E
M>'!A;F1!;&PH*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%R
M96YT6VYU;&Q=(&%S("1V86PI('L*("`@("`@("`@("`@)'1H:7,M/F5X<&%N
M9"@D=F%L+"!T<G5E*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3:&]U;&0@=V4@8V]L;&%P<V4@86QL(&5L96UE;G1S/PH@("`@("HO"B`@
M("!F=6YC=&EO;B!C;VQL87!S94%L;"@I"B`@("!["B`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/E]T<F5E(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@
M("!I9B`H)&ME>2`A/2!)34%05%)%15]"05-%7T5,5"D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/F-O;&QA<'-E*"1V86Q;)W8G72D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("\J($-L96%R(&%L;"!E;G1R:65S(&9R
M;VT@=&AE(&5X<&%N9&5D(&QI<W0N("HO"B`@("`@("`@)'1H:7,M/E]I;FET
M17AP86YD961,:7-T*"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]E>'!A
M;F1E9"!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@)'1H:7,M/E]R
M96UO=F5%>'!A;F1E9$QI<W0H)&ME>2D["B`@("`@("`@?0H*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!T:&4@;&ES="!O9B!M86EL8F]X97,@:6X@
M=&AE(&YE>'0@;&5V96PN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!C=7)R96YT
M(&UA:6QB;W@N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!L:7-T
M(&]F(&UA:6QB;W@@;V)J96-T<R!O<B!T:&4@96UP='D@;&ES="X*("`@("`J
M("`@("`@("`@("`@("`@(%-E92!?9V5T3&ES="@I(&9O<B!F;W)M870N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]C:&EL9')E;DEN9F\H)&ED*0H@("`@>PH@
M("`@("`@("1I;F9O(#T@87)R87DH*3L*("`@("`@("`D;G-?:6YF;R`]("1T
M:&ES+3Y?9V5T3F%M97-P86-E*"1I9"D["@H@("`@("`@(&EF("AI<U]N=6QL
M*"1N<U]I;F9O*2D@>PH@("`@("`@("`@("!R971U<FX@)&EN9F\["B`@("`@
M("`@?0H*("`@("`@("!I9B`H*"1I9"`]/2`G24Y"3U@G*2`F)@H@("`@("`@
M("`@("`H)&YS7VEN9F];)VYA;64G72`]/2`H)TE.0D]8)R`N("1N<U]I;F9O
M6R=D96QI;6ET97(G72DI*2!["B`@("`@("`@("`@("1S96%R8V@@/2`D:60@
M+B`D;G-?:6YF;ULG9&5L:6UI=&5R)UT@+B`D;G-?:6YF;ULG;F%M92==.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S96%R8V@@/2`D:60@+B`D
M;G-?:6YF;ULG9&5L:6UI=&5R)UT["B`@("`@("`@?0H*("`@("`@("`D:6YF
M;R`]("1T:&ES+3Y?9V5T3&ES="@D<V5A<F-H("X@)R4G*3L*"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?=')E95LD:61=*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7W-E=$-H:6QD<F5N*"1T:&ES+3Y?=')E95LD:61=+"`A96UP='DH
M)&EN9F\I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YF;SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%-W:71C:"!S=6)S8W)I8F5D+W5N<W5B<V-R
M:6)E9"!V:65W:6YG+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1U
M;G-U8B`@4VAO=R!U;G-U8G-C<FEB960@96QE;65N=',_"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-H;W=5;G-U8G-C<FEB960H)'5N<W5B*0H@("`@>PH@("`@
M("`@(&EF("@D=6YS=6(@/3T]("1T:&ES+3Y?<VAO=W5N<W5B*2!["B`@("`@
M("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<VAO
M=W5N<W5B(#T@)'5N<W5B.PH@("`@("`@("1T:&ES+3Y?8VAA;F=E9"`]('1R
M=64["@H@("`@("`@("\J($EF('=E(&%R92!S=VET8VAI;F<@9G)O;2!U;G-U
M8G-C<FEB960@=&\@<W5B<V-R:6)E9"P@;F\@;F5E9`H@("`@("`@("`J('1O
M(&1O(&%N>71H:6YG("AW92!J=7-T(&EG;F]R92!U;G-U8G-C<FEB960@<W1U
M9F8I+B`J+PH@("`@("`@(&EF("@D=6YS=6(@/3T](&9A;'-E*2!["B`@("`@
M("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("\J($EF('=E(&%R
M92!S=VET8VAI;F<@9G)O;2!S=6)S8W)I8F5D('1O('5N<W5B<V-R:6)E9"P@
M=V4@;F5E9`H@("`@("`@("`J('1O(&%D9"!A;&P@=6YS=6)S8W)I8F5D(&5L
M96UE;G1S('1H870@;&EV92!I;B!C=7)R96YT;'D*("`@("`@("`@*B!D:7-C
M;W9E<F5D(&ET96US+B`J+PH@("`@("`@("1T:&ES+3Y?=6YS=6)V:65W(#T@
M=')U93L*("`@("`@("`D=&AI<RT^7VEN:715;G-U8G-C<FEB960H*3L*("`@
M("`@("!I9B`H96UP='DH)'1H:7,M/E]U;G-U8G-C<FEB960I*2!["B`@("`@
M("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?:6YI
M=&UO9&4@/2!)34%05%)%15])3DE47U5.4U5".PH@("`@("`@("1T:&ES+3YI
M;G-E<G0H87)R87E?:V5Y<R@D=&AI<RT^7W5N<W5B<V-R:6)E9"DI.PH@("`@
M("`@("1T:&ES+3Y?:6YI=&UO9&4@/2`P.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A(')E9F5R96YC92!T;R!A(&-U<G)E;G1L>2!O<&5N($E-
M05`@<W1R96%M+@H@("`@("H@5$A)4R!-151(3T0@35535"!"12!$149)3D5$
M($E.($%,3"!354)#3$%34T53+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R
M971U<FX@<F5S;W5R8V4@($%N($E-05`@<F5S;W5R8V4@<W1R96%M+@H@("`@
M("HO"B`@("!F=6YC=&EO;B`F7V=E=%-T<F5A;2@I"B`@("!["B`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@8W5R<F5N=&QY('-E;&5C=&5D(&EN:71I86QI>F%T:6]N(&5X<&%N9&5D
M(&UO9&4N"B`@("`@*B!42$E3($U%5$A/1"!32$]53$0@0D4@1$5&24Y%1"!)
M3B!!3$P@4U5"0TQ!4U-%4RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN=&5G97(@(%1H92!C=7)R96YT(&EN:71I86QI>F%T:6]N(&5X<&%N
M9&5D(&UO9&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971);FET17AP86YD
M961-;V1E*"D*("`@('L*("`@("`@("!R971U<FX@24U!4%12145?3U!%3E].
M3TY%.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&EN9F]R;6%T:6]N(&%B
M;W5T(&YE=R]U;G-E96XO=&]T86P@;65S<V%G97,@9F]R('1H92!G:79E;B!E
M;&5M96YT+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H
M92!E;&5M96YT(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M07)R87D@=VET:"!T:&4@9F]L;&]W:6YG(&9I96QD<SH*("`@("`J(#QP<F4^
M"B`@("`@*B`G;65S<V%G97,G("`M+2`@3G5M8F5R(&]F('1O=&%L(&UE<W-A
M9V5S+@H@("`@("H@)VYE=VUS9R<@("`@+2T@($YU;6)E<B!O9B!N97<@;65S
M<V%G97,N"B`@("`@*B`G=6YS965N)R`@("`M+2`@3G5M8F5R(&]F('5N<V5E
M;B!M97-S86=E<RX*("`@("`J(#PO<')E/@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971%;&5M96YT26YF;R@D;F%M92D*("`@('L*("`@("`@("`D<W1A='5S
M(#T@87)R87DH*3L*"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92])34%0
M+T-A8VAE+G!H<"<["B`@("`@("`@)&EM87!?8V%C:&4@/2`F24U!4%]#86-H
M93HZ<VEN9VQE=&]N*"D["B`@("`@("`@)'-T<R`]("1I;6%P7V-A8VAE+3YG
M9713=&%T=7,H)'1H:7,M/E]G9713=')E86TH*2P@)'1H:7,M/E]S97)V97(@
M+B`D;F%M92D["B`@("`@("`@:68@*"%E;7!T>2@D<W1S*2D@>PH@("`@("`@
M("`@("`D<W1A='5S6R=M97-S86=E<R==(#T@)'-T<RT^;65S<V%G97,["B`@
M("`@("`@("`@("1S=&%T=7-;)W5N<V5E;B==(#T@:7-S970H)'-T<RT^=6YS
M965N*2`_("1S=',M/G5N<V5E;B`Z(#`["B`@("`@("`@("`@("1S=&%T=7-;
M)VYE=VUS9R==(#T@:7-S970H)'-T<RT^<F5C96YT*2`_("1S=',M/G)E8V5N
M="`Z(#`["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'-T871U<SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%-O<G1S(&$@;&ES="!O9B!M86EL8F]X97,N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("8D;6)O>"`@(%1H92!L:7-T(&]F(&UA:6QB;WAE<R!T
M;R!S;W)T+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&)A<V4@($%R92!W92!S
M;W)T:6YG(&$@;&ES="!O9B!M86EL8F]X97,@:6X@=&AE(&)A<V4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!O9B!T:&4@=')E92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7W-O<G1,:7-T*"8D;6)O>"P@)&)A<V4@/2!F86QS92D*
M("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7VEM87!?<V]R="DI
M('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92])34%0+U-O<G0N
M<&AP)SL*("`@("`@("`@("`@)'1H:7,M/E]I;6%P7W-O<G0@/2`F;F5W($E-
M05!?4V]R="@D=&AI<RT^7V1E;&EM:71E<BD["B`@("`@("`@?0H*("`@("`@
M("!I9B`H)&)A<V4I('L*("`@("`@("`@("`@9F]R96%C:"`H)&UB;W@@87,@
M)'9A;"D@>PH@("`@("`@("`@("`@("`@)&)A<V5S;W)T6R1V86Q=(#T@*"1V
M86P@/3T@)TE.0D]8)RD@/R`G24Y"3U@G(#H@)'1H:7,M/E]T<F5E6R1V86Q=
M6R=L)UT["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]I;6%P
M7W-O<G0M/G-O<G1-86EL8F]X97,H)&)A<V5S;W)T+"`H)'1H:7,M/E]M;V1E
M(#T]($E-05!44D5%7TU/1$5?34%)3"DL('1R=64L('1R=64I.PH@("`@("`@
M("`@("`D;6)O>"`](&%R<F%Y7VME>7,H)&)A<V5S;W)T*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7VEM87!?<V]R="T^<V]R=$UA
M:6QB;WAE<R@D;6)O>"P@*"1T:&ES+3Y?;6]D92`]/2!)34%05%)%15]-3T1%
M7TU!24PI*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FX@82!.;VXM24U!4"!M86EL8F]X(&5L96UE;G0@9VEV96X@86X@96QE;65N
M="!I9&5N=&EF:65R+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&ED("!4:&4@96QE;65N="!I9&5N=&EF:65R+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@($$@;6%I;&)O>"!E;&5M96YT+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?9V5T3F]N24U!4$5L="@D:60I"B`@("!["B`@("`@
M("`@<F5T=7)N(&%R<F%Y*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!)<R!T
M:&4@9VEV96X@96QE;65N="!A;B`B86-T:79E(B!E;&5M96YT("AI+F4N(&%N
M(&5L96UE;G0@=&AA="!S:&]U;&0*("`@("`J(&)E('=O<FME9"!W:71H(&=I
M=F5N('1H92!C=7)R96YT('9I97=I;F<@<&%R86UE=&5R<RDN"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1E;'0@($$@=')E92!E;&5M96YT+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5')U92!I9B!I="!I<R!A;B!A8W1I=F4@96QE;65N="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V%C=&EV945L="@D96QT*0H@("`@>PH@
M("`@("`@(&EF("@D=&AI<RT^7W-H;W=U;G-U8B`F)@H@("`@("`@("`@("`D
M=&AI<RT^:7-.86UE<W!A8V4H)&5L="DI('L*("`@("`@("`@("`@<F5T=7)N
M("@D=&AI<RT^:&%S0VAI;&1R96XH)&5L="DI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B`H)'1H:7,M/E]S:&]W=6YS=6(@?'P*("`@
M("`@("`@("`@("`@("`@("`H)'1H:7,M/FES4W5B<V-R:6)E9"@D96QT*2`F
M)B`A)'1H:7,M/FES0V]N=&%I;F5R*"1E;'0I*2!\?`H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YH87-#:&EL9')E;B@D96QT*2D["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R="!A(&UA:6QB;W@@;F%M92!T
M;R!T:&4@8V]R<F5C="P@:6YT97)N86P@;F%M92`H:2YE+B!M86ME('-U<F4*
M("`@("`J($E.0D]8(&ES(&%L=V%Y<R!C87!I=&%L:7IE9"!F;W(@24U!4"!S
M97)V97)S*2X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@;6%I;&)O>"!N86UE
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]N=F5R=&5D
M(&YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYV97)T3F%M92@D;F%M
M92D*("`@('L*("`@("`@("!R971U<FX@*"@D=&AI<RT^7VUO9&4@/3T@24U!
M4%12145?34]$15]-04E,*2`F)B`H<W1R8V%S96-M<"@D;F%M92P@)TE.0D]8
M)RD@/3T@,"DI(#\@)TE.0D]8)R`Z("1N86UE.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T(&YA;65S<&%C92!I;F9O(&9O<B!A(&9U;&P@9F]L9&5R('!A
M=&@N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;6%I;&)O>"`@5&AE(&9O;&1E<B!P871H+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!N86UE<W!A8V4@:6YF
M;R!F;W(@=&AE(&9O;&1E<B!P871H(&]R(&YU;&P@:68@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("!P871H(&1O97-N)W0@97AI<W0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]G971.86UE<W!A8V4H)&UA:6QB;W@I"B`@("!["B`@("`@
M("`@<W1A=&EC("1N86UE<W!A8V5#86-H92`](&%R<F%Y*"D["@H@("`@("`@
M(&EF("AI<W-E="@D;F%M97-P86-E0V%C:&5;)&UA:6QB;WA=*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&YA;65S<&%C94-A8VAE6R1M86EL8F]X73L*("`@
M("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]N86UE<W!A8V5S
M*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7VYA;65S<&%C97,@
M87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("!I9B`H*"@D;6%I
M;&)O>"`N("1V86Q;)V1E;&EM:71E<B==*2`]/2`D:V5Y*2!\?`H@("`@("`@
M("`@("`@("`@("`@("@A96UP='DH)&ME>2D@)B8@*'-T<G!O<R@D;6%I;&)O
M>"P@)&ME>2D@/3T](#`I*2D@>PH@("`@("`@("`@("`@("`@("`@("1N86UE
M<W!A8V5#86-H95LD;6%I;&)O>%T@/2`D=F%L.PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D=F%L.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]N86UE<W!A8V5S
M6R<G72DI('L*("`@("`@("`@("`@("`@("1N86UE<W!A8V5#86-H95LD;6%I
M;&)O>%T@/2`D=&AI<RT^7VYA;65S<&%C97-;)R==.PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?;F%M97-P86-E<ULG)UT["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1N86UE<W!A8V5#86-H95LD;6%I;&)O>%T@/2!N
M=6QL.PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!I9B`H<W5B<W1R*"1T:&ES+3Y?<')E9FEX+"`M,2D@
M/3T@)'1H:7,M/E]D96QI;6ET97(I('L*("`@("`@("`@("`@("`@("1N86UE
M(#T@<W5B<W1R*"1T:&ES+3Y?<')E9FEX+"`P+"!S=')L96XH)'1H:7,M/E]P
M<F5F:7@I("T@,2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D;F%M92`]("1T:&ES+3Y?<')E9FEX.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1N86UE<W!A8V5#86-H95LD;6%I;&)O>%T@/2!A<G)A>2@G
M9&5L:6UI=&5R)R`]/B`D=&AI<RT^7V1E;&EM:71E<BP@)VYA;64G(#T^("1N
M86UE+"`G='EP92<@/3X@)W!E<G-O;F%L)RD["B`@("`@("`@("`@(')E='5R
M;B`D;F%M97-P86-E0V%C:&5;)&UA:6QB;WA=.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($1O97,@=&AE($E-05`@<V5R=F5R('-U<'!O<G0@
M=&AE("=#2$E,1%)%3B<@24U!4"!E>'1E;G-I;VX_"B`@("`@*@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)'-U<'!O<G0@(%1R=64@:68@=&AE($E-05`@<V5R
M=F5R('-U<'!O<G1S('1H92!#2$E,1%)%3@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@(&5X=&5N<VEO;BP@9F%L<V4@:68@:70@9&]E<VXG="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@24U!4&-H:6QD<F5N4W5P<&]R="@D<W5P
M<&]R="D*("`@('L*("`@("`@("`D=&AI<RT^7V-H:6QD<F5N<W5P<&]R="`]
M("AB;V]L*2`D<W5P<&]R=#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T
M:&4@<W1A<G0@<&]I;G0@9F]R(&1E=&5R;6EN:6YG(&5L96UE;G0@9&EF9F5R
M96YC97,@=FEA(&5L=$1I9F8H*2X*("`@("`J"B`@("`@*B!`<VEN8V4@2&]R
M9&4@,RXQ"B`@("`@*B\*("`@(&9U;F-T:6]N(&5L=$1I9F93=&%R="@I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]E;'1D:69F(#T@)'1H:7,M/E]T<F5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!L:7-T(&]F(&5L96UE
M;G1S('1H870@:&%V92!C:&%N9V5D('-I;F-E(&YO9&5$:69F4W1A<G0H*0H@
M("`@("H@=V%S(&QA<W0@8V%L;&5D+@H@("`@("H*("`@("`J($!S:6YC92!(
M;W)D92`S+C$*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A
M>2!W:71H('1H92!F;VQL;W=I;F<@:V5Y<SH*("`@("`J(#QP<F4^"B`@("`@
M*B`G82<@/3X@02!L:7-T(&]F(&5L96UE;G1S('1H870@:&%V92!B965N(&%D
M9&5D+@H@("`@("H@)V,G(#T^($$@;&ES="!O9B!E;&5M96YT<R!T:&%T(&AA
M=F4@8F5E;B!C:&%N9V5D+@H@("`@("H@)V0G(#T^($$@;&ES="!O9B!E;&5M
M96YT<R!T:&%T(&AA=F4@8F5E;B!D96QE=&5D+@H@("`@("H@/"]P<F4^"B`@
M("`@*B`@("`@("`@("`@("`@("!2971U<FYS(&9A;'-E(&EF(&YO(&-H86YG
M97,@:&%V92!O8V-U<G)E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@96QT1&EF
M9B@I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^7V-H86YG960@?'P@(21T
M:&ES+3Y?96QT9&EF9BD@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H*("`@("`@("`D861D960@/2`D8VAA;F=E9"`]("1D96QE=&5D
M(#T@87)R87DH*3L*"B`@("`@("`@+RH@1&5T97)M:6YE('1H92!D96QE=&5D
M(&ET96US+B`J+PH@("`@("`@("1D96QE=&5D(#T@87)R87E?=F%L=65S*&%R
M<F%Y7V1I9F8H87)R87E?:V5Y<R@D=&AI<RT^7V5L=&1I9F8I+"!A<G)A>5]K
M97ES*"1T:&ES+3Y?=')E92DI*3L*"B`@("`@("`@9F]R96%C:"`H)'1H:7,M
M/E]T<F5E(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?96QT9&EF9ELD:V5Y72DI('L*("`@("`@("`@("`@("`@
M("1A9&1E9%M=(#T@)&ME>3L*("`@("`@("`@("`@?2!E;'-E:68@*"1V86P@
M(3T@)'1H:7,M/E]E;'1D:69F6R1K97E=*2!["B`@("`@("`@("`@("`@("`D
M8VAA;F=E9%M=(#T@)&ME>3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@:68@*&5M<'1Y*"1A9&1E9"D@)B8@96UP='DH)&-H86YG960I("8F
M(&5M<'1Y*"1D96QE=&5D*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"=A
M)R`]/B`D861D960L("=C)R`]/B`D8VAA;F=E9"P@)V0G(#T^("1D96QE=&5D
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ*BH@1&5P<F5C871E9"!V87)I
M86)L97,O9G5N8W1I;VYS+B!4:&5S92!R96UA:6X@9F]R($)#(&]N;'DN("HJ
M*BHO"@H@("`@+RHJ"B`@("`@*B!4:&4@<')E9FEX('=I=&AO=70@82!T<F%I
M;&EN9R!D96QI;6ET97(N"B`@("`@*@H@("`@("H@0&1E<')E8V%T960@<VEN
M8V4@2&]R9&4@,RXQ"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)%]P<F5F:7AN;V1E;&EM(#T@)R<["@H@("`@+RHJ"B`@("`@*B!4:&4@
M<V5R=F5R('-T<FEN9R!U<V5D(&9O<B!T:&4@9&5L:6UI=&5R+@H@("`@("H@
M5$A)4R!32$]53$0@0D4@4T54($E.($5615)9(%-50D-,05-3($-/3E-44E5#
M5$]2+@H@("`@("H*("`@("`J($!D97!R96-A=&5D('-I;F-E($AO<F1E(#,N
M,0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?9&5L:6UI
M=&5R(#T@)R\G.PH*("`@("\J*@H@("`@("H@5VAE<F4@=V4@<W1A<G0@;&ES
M=&EN9R!F;VQD97)S+@H@("`@("H@5$A)4R!32$]53$0@0D4@4T54($E.($56
M15)9(%-50D-,05-3($-/3E-44E5#5$]2+@H@("`@("H*("`@("`J($!D97!R
M96-A=&5D('-I;F-E($AO<F1E(#,N,0H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1?<')E9FEX(#T@)R<["@H@("`@+RHJ"B`@("`@*B!4
M:&4@;&]C871I;VX@;V8@=&AE(&9I<G-T(&QE=F5L(&]F(&9O;&1E<G,@8F5L
M;W<@=&AE($E.0D]8+@H@("`@("H@5$A)4R!32$]53$0@0D4@4T54($E.($56
M15)9(%-50D-,05-3($-/3E-44E5#5$]2+@H@("`@("H*("`@("`J($!D97!R
M96-A=&5D('-I;F-E($AO<F1E(#,N,0H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1?;F%M97-P86-E(#T@)R<["@H@("`@+RHJ"B`@("`@
M*B!3:&]U;&0@9&]T9FEL97,@8F4@<VAO=VX_"B`@("`@*B!42$E3(%-(3U5,
M1"!"12!3150@24X@159%4ED@4U5"0TQ!4U,@0T].4U1254-43U(N"B`@("`@
M*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V1O=&9I
M;&5S(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!4:&4@97AI<W1E;F-E(&]F
M('1H:7,@9G5N8W1I;VX@:6X@24U!4%]4<F5E(&EN9&EC871E<R!T:&%T(&5X
M=&5N9&5D"B`@("`@*B!N86UE<W!A8V4@<W5P<&]R="!I<R!A=F%I;&%B;&4N
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!2971U<FYS('1R=64N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X=&5N9&5D3F%M97-P86-E4W5P<&]R
M="@I"B`@("!["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FX@=&AE('!R969I>"X*("`@("`J"B`@("`@*B!`9&5P
M<F5C871E9"!S:6YC92!(;W)D92`S+C$*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@<')E9FEX('=H97)E(&9O;&1E<G,@8F5G:6X@=&\@8F4@;&ES=&5D
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9710<F5F:7@H*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7W!R969I>#L*("`@('T*"B`@("`O*BH*("`@
M("`J($=E="!I;F9O<FUA=&EO;B!A8F]U="!A('-P96-I9FEC(&UA:6QB;W@N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`9&5P<F5C
M871E9"!S:6YC92!(;W)D92`S+C$*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1P871H("!4:&4@;6%I;&)O>"!T;R!Q=65R>2X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T9$-L87-S("!3964@:6UA<%]G971M86EL8F]X97,H*2X@
M(%1H92!S97)V97(@<W1R:6YG(&AA<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@86QR96%D>2!B965N(')E;6]V960@9G)O;2!T:&4@)VYA;64G('!A<F%M
M971E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$UA:6QB;W@H)'!A=&@I
M"B`@("!["B`@("`@("`@)&)O>"`]("1T:&ES+3Y?9V5T3&ES="@D<&%T:"D[
M"B`@("`@("`@:68@*&5M<'1Y*"1B;W@I*2!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M<F5S970H)&)O>"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M36%K92!S=7)E('1H97)E(&ES(&YO('1R86EL:6YG(&1E;&EM:71E<B!O;B!T
M:&4@96QE;65N="!N86UE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&YA;64@(%1H92!E;&5M96YT(&YA;64N"B`@("`@*B!`9&5P<F5C871E9"!S
M:6YC92!(;W)D92`S+C$*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(&5L96UE;G0@;F%M92!W:71H(&%N>2!T<F%I;&EN9R!D96QI;6ET97(@
M<W1R:7!P960*("`@("`J("`@("`@("`@("`@("`@("!O9F8N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&YO5')A:6QI;F=$96QI;6ET97(H)&YA;64I"B`@("![
M"B`@("`@("`@)&YS7VEN9F\@/2`D=&AI<RT^7V=E=$YA;65S<&%C92@D;F%M
M92D["B`@("`@("`@:68@*'-U8G-T<B@D;F%M92P@+3$I(#T]("1N<U]I;F9O
M6R=D96QI;6ET97(G72D@>PH@("`@("`@("`@("`D;F%M92`]('-U8G-T<B@D
M;F%M92P@,"P@<W1R;&5N*"1N86UE*2`M(#$I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1N86UE.PH@("`@?0H*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]+;VQA8BYP
M:'``````````````````````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q-C4T
M,#4`,3`U,34T,S,W-3(`,#(Q,C0P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"@HO*BH@5V4@<F5Q=6ER92!T:&4@
M8F%S92!(;W)D92!L:6)R87)Y+B`J+PIR97%U:7)E7V]N8V4@)TAO<F1E+G!H
M<"<["G)E<75I<F5?;VYC92`G2&]R9&4O4VAA<F4N<&AP)SL*"B\J*B!792!N
M965D('1H92!3=')I;F<@)B!.3%,@;&EB<F%R:65S(&9O<B!C:&%R86-T97(@
M<V5T(&-O;G9E<G-I;VYS+"!E=&,N("HO"G)E<75I<F5?;VYC92`G2&]R9&4O
M4W1R:6YG+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O3DQ3+G!H<"<["@HO
M*BH@5V4@;F5E9"!T:&4@2&]R9&4@34E-12!L:6)R87)Y('1O(&1E86P@=VET
M:"!-24U%(&UE<W-A9V5S+"!O8G9I;W5S;'D@.BTI+B`J+PIR97%U:7)E7V]N
M8V4@)TAO<F1E+TU)344N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-24U%
M+U!A<G0N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+TUE<W-A9V4N
M<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+TAE861E<G,N<&AP)SL*
M<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+U-T<G5C='5R92YP:'`G.PH*+RHJ
M"B`J(%1H92!(;W)D95]+;VQA8B!L:6)R87)Y(')E<75I<F5S('9E<G-I;VX@
M/CT@,2XP+C,@;V8@3F5T7TE-05`@*&DN92X@82!V97)S:6]N"B`J('1H870@
M:6YC;'5D97,@<W5P<&]R="!F;W(@=&AE($%.3D]4051%34]212!)34%0(&5X
M=&5N<VEO;BDN(%1H92!L871E<W0*("H@=F5R<VEO;B!O9B!.971?24U!4"!C
M86X@8F4@;V)T86EN960@9G)O;2!H='1P.B\O<&5A<BYP:'`N;F5T+V=E="].
M971?24U!4`H@*B\*<F5Q=6ER95]O;F-E("=.970O24U!4"YP:'`G.PH*+RHJ
M"B`J(%1H92!C:&%R86-T97(@<V5Q=65N8V4@=7-E9"!B>2!A("A+;VQA8BD@
M0WER=7,@24U!4"!S97)V97(@=&\@<V5P87)A=&4@;&EN97,*("H@=VET:&EN
M(&$@;65S<V%G92X*("HO"F1E9FEN92@G2T],04)?3D573$E.12<L(")<<EQN
M(BD["@HO*BH*("H@5&AE(&-H87)A8W1E<B!U<V5D('1O(&1E;&EM:70@<W5B
M9F]L9&5R<R!W:71H:6X@82`H2V]L86(I($-Y<G5S(&9O;&1E<@H@*B!H:65R
M87)C:'DN"B`J+PID969I;F4H)TM/3$%"7T9/3$1%4E]$14Q)32<L("<O)RD[
M"@HO*BH*("H@5&AE(')O;W0@;V8@=&AE($MO;&%B(&%N;F]T871I;VX@:&EE
M<F%R8VAY+"!U<V5D(&]N('1H92!V87)I;W5S($E-05`@9F]L9&5R"B`J('1H
M870@87)E('5S960@8GD@2V]L86(@8VQI96YT<RX*("HO"F1E9FEN92@G2T],
M04)?04Y.3U1?4D]/5"<L("<O=F5N9&]R+VMO;&%B+R<I.PH*+RHJ"B`J(%1H
M92!A;FYO=&%T:6]N+"!A<R!D969I;F5D(&)Y('1H92!+;VQA8B!F;W)M870@
M<W!E8RP@=&AA="!I<R!U<V5D('1O('-T;W)E"B`J(&EN9F]R;6%T:6]N(&%B
M;W5T('=H870@9W)O=7!W87)E(&9O<FUA="!T:&4@9F]L9&5R(&-O;G1A:6YS
M+@H@*B\*9&5F:6YE*"=+3TQ!0E]!3DY/5%]&3TQ$15)?5%E012<L($M/3$%"
M7T%.3D]47U)/3U0@+B`G9F]L9&5R+71Y<&4G*3L*"B\J*@H@*B!!($AO<F1E
M+7-P96-I9FEC(&%N;F]T871I;VX@=&AA="!S=&]R97,@=&AE(%5)1"!O9B!T
M:&4@2&]R9&4@<VAA<F4@=&AA=`H@*B!C;W)R97-P;VYD<R!T;R!T:&4@24U!
M4"!F;VQD97(N(%1H:7,@:7,@=7-E9"!I;B!T:&4@<WEN8VAR;VYI<V%T:6]N
M('!R;V-E<W,*("H@;V8@=&AE($E-05`@9F]L9&5R(&QI<W0@86YD('1H92!(
M;W)D92!S:&%R92!L:7-T+@H@*B\*9&5F:6YE*"=+3TQ!0E]!3DY/5%]32$%2
M15]5240G+"!+3TQ!0E]!3DY/5%]23T]4("X@)V@M<VAA<F4M=6ED)RD["@HO
M*BH*("H@5&AE(%@M(&AE861E<B!U<V5D('1O('-T;W)E(&$@8V]P>2!O9B!T
M:&4@2V]L86(@;V)J96-T('1Y<&4@<W1R:6YG(&9O<B!T:&4*("H@;V)J96-T
M('1Y<&4@=&AA="!I<R!C;VYT86EN960@=VET:&EN('1H92!E;6%I;"!M97-S
M86=E+@H@*B\*9&5F:6YE*"=+3TQ!0E](14%$15)?5%E012<L("=8+4MO;&%B
M+51Y<&4G*3L*"B\J*@H@*B!!;B!I;F1E>"!I;G1O('1H92`D7U-%4U-)3TX@
M87)R87D@=VAI8V@@:7,@=7-E9"!T;R!C86-H92!W:&%T(&%P<&QI8V%T:6]N
M"B`J('=A<R!L87-T('-Y;F-H<F]N:7-E9#L@=&AI<R!P<F5V96YT<R!U<R!F
M<F]M(&-O;G1I;G5O=7-L>2!R92US>6YC:')O;FES:6YG"B`J(&]N(&5V97)Y
M('!A9V4@;&]A9"!W:71H:6X@82!S:6YG;&4@87!P;&EC871I;VXN"B`J+PID
M969I;F4H)TM/3$%"7TQ!4U1?4UE.0TA%1%]!4%`G+"`G:V]L86)?;&%S=%]S
M>6YC:&5D7V%P<"<I.PH*+RHJ"B`J($%N(&EN9&5X(&EN=&\@=&AE("1?4T53
M4TE/3B!A<G)A>2!W:&EC:"!I<R!U<V5D('1O(&-A8VAE(&$@;6%P<&EN9R!O
M9B!S:&%R90H@*B!5241S('1O($E-05`@9F]L9&5R<SL@=&AI<R!I<R!U<V5D
M(&)Y('1H92!V87)I;W5S(&%P<&QI8V%T:6]N(&1R:79E<G,@=VAE;@H@*B!O
M<&5N:6YG(&$@<W!E8VEF:6,@<VAA<F4L(&EN(&]R9&5R('1O(&MN;W<@=VAA
M="!T:&4@8V]R<F5S<&]N9&EN9R!)34%0"B`J(&9O;&1E<B!T:&%T(&UU<W0@
M8F4@;W!E;F5D(&ES+@H@*B\*9&5F:6YE*"=+3TQ!0E]32$%215]-05`G+"`G
M:V]L86)?<VAA<F5?;6%P)RD["@HO*BH*("H@5&AE('!R969I>"!F;W(@86QL
M($MO;&%B(&=R;W5P=V%R92!O8FIE8W0@;6EM92!T>7!E('-T<FEN9W,N($5A
M8V@@;V)J96-T"B`J('1Y<&4@:&%S('1H:7,@<W1R:6YG(&EN(&-O;6UO;BP@
M=VET:"!A('-U9F9I>"!O9B!E+F<N("=N;W1E)RP@)V5V96YT)RP@971C+@H@
M*B!T;R!I;F1I8V%T92!W:&%T('1H92!S<&5C:69I8R!+;VQA8B!G<F]U<'=A
M<F4@9F]R;6%T(&ES+@H@*B\*9&5F:6YE*"=+3TQ!0E]-24U%7U194$5?4%)%
M1DE8)RP@)V%P<&QI8V%T:6]N+W@M=FYD+FMO;&%B+B<I.PH*+RHJ"B`J(%1H
M92!S=')I;F<@=7-E9"!T;R!I9&5N=&EF>2!T:&4@2&]R9&4O2V]L86(@:6YT
M96=R871I;VX@96YG:6YE(&EN('9A<FEO=7,*("H@<&QA8V5S("AE+F<N(&EN
M($MO;&%B(&]B:F5C=',@9V5N97)A=&5D(&)Y('1H92!L:6)R87)Y*2X*("HO
M"F1E9FEN92@G2T],04)?4%)/1%5#5%])1"<L("=H;W)D92]K;VQA8B\Q+C`G
M*3L*"B\J*@H@*B!4:&4@2&]R9&5?2V]L86(@;&EB<F%R>2!I<R!B;W1H(&%N
M(&]B:F5C="!U<V5D(&)Y(&%P<&QI8V%T:6]N(&1R:79E<G,@=&\*("H@8V]M
M;75N:6-A=&4@=VET:"!A($MO;&%B('-E<G9E<BP@87,@=V5L;"!A<R!A('5T
M:6QI='D@;&EB<F%R>2!P<F]V:61I;F<*("H@<V5V97)A;"!F=6YC=&EO;G,@
M=&\@:&5L<"!I;B!T:&4@24U!4"!F;VQD97(@/"T^($AO<F1E(%-H87)E('-Y
M;F-H<F]N:7-A=&EO;@H@*B!P<F]C97-S+@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`L=B`Q+C(V+C$P+C$V(#(P,#8O,#<O,3<@
M,#DZ,S`Z-3`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@
M2&]R9&4@4')O:F5C="`H:'1T<#HO+VAO<F1E+F]R9R\I"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!3='5A<G0@0FEN9V4@/&]M:6-R;VY`;6EG:'1Y
M+F-O+GIA/@H@*B!`<&%C:V%G92!(;W)D95]+;VQA8@H@*B\*8VQA<W,@2V]L
M86(@>PH*+R\@0VQA<W,@:6YT97)F86-E"@H@("`@+RHJ"B`@("`@*B!4:&4@
M8W5R<F5N="!A<'!L:6-A=&EO;B!T:&%T('1H:7,@2V]L86(@;V)J96-T(&EN
M<W1A;F-E(&ES(&-A=&5R:6YG('1O+@H@("`@("H*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D7V%P<#L*"B`@("`O*BH*("`@("`J($]U
M<B!.971?24U!4"!O8FIE8W0L('5S960@=&\@8V]M;75N:6-A=&4@=VET:"!T
M:&4@0WER=7,@<V5R=F5R+@H@("`@("H*("`@("`J($!V87(@3F5T7TE-05`*
M("`@("`J+PH@("`@=F%R("1?:6UA<"`](&YU;&P["@H@("`@+RHJ"B`@("`@
M*B!!(&-A8VAE9"!V97)S:6]N(&]F($MO;&%B.CIG971!<'!#;VYS=',H)'1H
M:7,M/E]A<'`I('1H870@:7,@=7-E9"!I;@H@("`@("H@<V5V97)A;"!O9B!T
M:&4@2V]L86(Z.B!F=6YC=&EO;G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]A<'!?8V]N<W1S.PH*("`@("\J*@H@("`@
M("H@02!S:&]R=&-U="!T;R`D=&AI<RT^7V%P<%]C;VYS='-;)VUI;65?='EP
M95]S=69F:7@G70H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7V]B:F5C=%]T>7!E.PH*("`@("\J*@H@("`@("H@5&AE(&9U
M;&P@;6EM92!T>7!E('-T<FEN9R!O9B!T:&4@8W5R<F5N="!+;VQA8B!O8FIE
M8W0@9F]R;6%T('=E)W)E"B`@("`@*B!D96%L:6YG('=I=&@N"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?;6EM95]T>7!E
M.PH*("`@("\J*@H@("`@("H@5&AE("AE;F-O9&5D*2!N86UE(&]F('1H92!)
M34%0(&9O;&1E<B!T:&%T(&-O<G)E<W!O;F1S('1O('1H92!C=7)R96YT"B`@
M("`@*B!S:&%R92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)%]F;VQD97(["@H@("`@+RHJ"B`@("`@*B!4:&4@34E-15]-
M97-S86=E(&]B:F5C="!T:&%T(&-O;G1A:6YS('1H92!C=7)R96YT;'D@;&]A
M9&5D(&UE<W-A9V4N(%1H:7,*("`@("`J(&ES('5S960@=VAE;B!U<&1A=&EN
M9R!A;B!O8FIE8W0L(&EN(&]R9&5R('1O('!R97-E<G9E(&5V97)Y=&AI;F<@
M96QS90H@("`@("H@=VET:&EN('1H92!M97-S86=E('1H870@=V4@9&]N)W0@
M:VYO=R!H;W<@=&\@:&%N9&QE+@H@("`@("H*("`@("`J($!V87(@34E-15]-
M97-S86=E"B`@("`@*B\*("`@('9A<B`D7VUE<W-A9V4["@H@("`@+RHJ"B`@
M("`@*B!!;B!A<G)A>2!C;VYT86EN:6YG("1?;65S<V%G92=S(&AE861E<G,N
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]H
M96%D97)S.PH*("`@("\J*@H@("`@("H@5&AE($U)344@:61E;G1I9FEE<B!O
M9B!T:&4@2V]L86(@9W)O=7!W87)E(&]B:F5C="!W:71H:6X@)'1H:7,M/E]M
M97-S86=E+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D7VUI;65?:60["@H@("`@+RHJ"B`@("`@*B!4:&4@*$MO;&%B*2!5
M240@;V8@)'1H:7,M/E]M97-S86=E+@H@("`@("H*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D7W5I9#L*"B`@("`O*BH*("`@("`J(%1H
M92!$;VU$;V-U;65N="!O8FIE8W0@=&AA="!C;VYT86EN<R!T:&4@6$U,($1/
M32!T<F5E(&]F('1H92!C=7)R96YT;'D*("`@("`J(&QO861E9"!G<F]U<'=A
M<F4@;V)J96-T+B!792!C86-H92!T:&ES(&AE<F4@=&\@96YS=7)E('!R97-E
M<G9A=&EO;B!O9@H@("`@("H@=6YK;F]W;B!F:65L9',@=VAE;B!R92US879I
M;F<@=&AE(&]B:F5C="X*("`@("`J"B`@("`@*B!`=F%R($1O;41O8W5M96YT
M"B`@("`@*B\*("`@('9A<B`D7WAM;#L*"B`@("`O*BH*("`@("`J(%1H92!)
M34%0(&UE<W-A9V4@;G5M8F5R(&]F("1T:&ES+3Y?;65S<V%G92X*("`@("`J
M"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?;7-G7VYO
M.PH*("`@(&9U;F-T:6]N(&=E=%5)1"@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?=6ED.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$UI;654>7!E
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]M:6UE7W1Y<&4["B`@
M("!]"@H@("`@9G5N8W1I;VX@2V]L86(H*0H@("`@>PH@("`@("`@(&=L;V)A
M;"`D<F5G:7-T<GD["@H@("`@("`@("1T:&ES+3Y?87!P(#T@)')E9VES=')Y
M+3YG971!<'`H*3L*("`@('T*"B`@("!F=6YC=&EO;B!O<&5N*"1S:&%R95]U
M:60I"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("!I9B`H
M(55T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G9&]M>&UL)RDI('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B2&]R9&4O2V]L86(Z(%1H
M92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(
M4"!E>'1E;G-I;VXB*2D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V%P
M<%]C;VYS=',@/2!+;VQA8CHZ9V5T07!P0V]N<W1S*"1T:&ES+3Y?87!P*3L*
M("`@("`@("!I9B`H:7-?82@D=&AI<RT^7V%P<%]C;VYS=',L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?87!P7V-O;G-T
M<SL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?;V)J96-T7W1Y<&4@/2`D
M=&AI<RT^7V%P<%]C;VYS='-;)VUI;65?='EP95]S=69F:7@G73L*("`@("`@
M("`D=&AI<RT^7VUI;65?='EP92`]($M/3$%"7TU)345?5%E015]04D5&25@@
M+B`D=&AI<RT^7V]B:F5C=%]T>7!E.PH*("`@("`@("`D8W5R<F5N=%]U<V5R
M(#T@075T:#HZ9V5T075T:"@I.PH@("`@("`@("1N9'@@/2!S=')P;W,H)&-U
M<G)E;G1?=7-E<BP@)T`G*3L*("`@("`@("`D=7-E<B`]("1N9'@@/3T](&9A
M;'-E(#\@)&-U<G)E;G1?=7-E<B`Z('-U8G-T<B@D8W5R<F5N=%]U<V5R+"`P
M+"`D;F1X*3L*("`@("`@("`D9&]M86EN(#T@<W1R<W1R*"1C=7)R96YT7W5S
M97(L("=`)RD["@H@("`@("`@("1S:&%R95]M87`@/2!+;VQA8CHZ9V5T4VAA
M<F5-87`H*3L*("`@("`@("!I9B`H96UP='DH)'-H87)E7VUA<%LD<VAA<F5?
M=6ED72DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M("`@("`@("`D9F]L9&5R(#T@)'-H87)E7VUA<%LD<VAA<F5?=6ED73L*"B`@
M("`@("`@+R\@5')A;G-L871E(')E;6]T92US>6YT87@@9F]L9&5R<R!T:&%T
M('=E(&]W;B!T;R!L;V-A;"US>6YT87@@<V\@=&AA=`H@("`@("`@("\O('=E
M(&-A;B!O<&5N('1H96T@<')O<&5R;'D*("`@("`@("!P<F5G7VUA=&-H*"([
M=7-E<B\H6UXO72LI+RA;7D!=*RDH0"XJ*3\[(BP@)&9O;&1E<BP@)&UA=&-H
M97,I.PH*("`@("`@("`D=7-E<E]D;VUA:6X@/2!I<W-E="@D;6%T8VAE<ULS
M72D@/R`D;6%T8VAE<ULS72`Z("1D;VUA:6X["B`@("`@("`@:68@*"1M871C
M:&5S6S%=(#T]("1U<V5R("8F("1U<V5R7V1O;6%I;B`]/2`D9&]M86EN*2![
M"B`@("`@("`@("`@("1F;VQD97(@/2`B24Y"3U@O)&UA=&-H97-;,ETB.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F;VQD97(@/2`B=7-E<B\D
M;6%T8VAE<ULQ72\D;6%T8VAE<ULR72(["B`@("`@("`@("`@(&EF("@D=7-E
M<E]D;VUA:6X@(3T@)&1O;6%I;BD@>PH@("`@("`@("`@("`@("`@)&9O;&1E
M<B`N/2`D=7-E<E]D;VUA:6X["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3Y?9F]L9&5R(#T@)&9O;&1E<CL*"B`@("`@("`@)'1H
M:7,M/E]I;6%P(#T@;F5W($YE=%])34%0*"1C;VYF6R=K;VQA8B==6R=I;6%P
M)UU;)W-E<G9E<B==+"`D8V]N9ELG:V]L86(G75LG:6UA<"==6R=P;W)T)UTI
M.PH*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;6%P+3YL;V=I;B@D8W5R
M<F5N=%]U<V5R+"!!=71H.CIG971#<F5D96YT:6%L*"=P87-S=V]R9"<I+"!F
M86QS92P@9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;6%P+3YS96QE8W1-
M86EL8F]X*"1T:&ES+3Y?9F]L9&5R*3L*("`@("`@("!I9B`H:7-?82@D<F5S
M=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@9G5N8W1I;VX@8VQO<V4H*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH
M)'1H:7,M/E]I;6%P*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VEM87`M/F1I
M<V-O;FYE8W0H*3L*("`@("`@("`@("`@)'1H:7,M/E]I;6%P(#T@;G5L;#L*
M("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@9FEN9$]B:F5C="@D=6ED
M*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7VEM87`I*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^7VEM87`M/G-E87)C:"@B4U5"2D5#5"!<(B1U:61<
M(B(I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@
M("`@("!I9B`H96UP='DH)')E<W5L="DI('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")(;W)D92]+;VQA8CH@3F\@
M;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B*2P@)'5I9"DI.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97-U;'1;,%T["B`@("!]"@H@
M("`@9G5N8W1I;VX@;&ES=$]B:F5C=',H*0H@("`@>PH@("`@("`@(&EF("AE
M;7!T>2@D=&AI<RT^7VEM87`I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7VEM87`M/G-E
M87)C:"@G2$5!1$52("(G("X@2T],04)?2$5!1$527U194$4@+B`G(B`B)R`N
M("1T:&ES+3Y?;6EM95]T>7!E("X@)R(G*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!F:6YD3V)J96-T<R@D8W)I=&5R:6$I"B`@("!["B`@("`@("`@:68@*&5M
M<'1Y*"1T:&ES+3Y?:6UA<"DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6UA<"T^<V5A
M<F-H*"1C<FET97)I82D["B`@("!]"@H@("`@9G5N8W1I;VX@;&ES=$]B:F5C
M='-);D9O;&1E<B@D9F]L9&5R*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N
M9CL*"B`@("`@("`@+R\@0V]N;F5C="!T;R!T:&4@24U!4"!S97)V97(*("`@
M("`@("`D:6UA<"`](&YE=R!.971?24U!4"@D8V]N9ELG:V]L86(G75LG:6UA
M<"==6R=S97)V97(G72P@)&-O;F9;)VMO;&%B)UU;)VEM87`G75LG<&]R="==
M*3L*"B`@("`@("`@+R\@3&]G:6X@=7-I;F<@=&AE(&-U<G)E;G0@2&]R9&4@
M8W)E9&5N=&EA;',*("`@("`@("`D<F5S=6QT(#T@)&EM87`M/FQO9VEN*$%U
M=&@Z.F=E=$%U=&@H*2P@075T:#HZ9V5T0W)E9&5N=&EA;"@G<&%S<W=O<F0G
M*2P@9F%L<V4L(&9A;'-E*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E
M*"=5;F%B;&4@=&\@875T:&5N=&EC871E('=I=&@@=&AE($MO;&%B($E-05`@
M<V5R=F5R)RP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@
M("`@("`@("`@("`D:6UA<"T^9&ES8V]N;F5C="@I.PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O+R!396QE8W0@;6%I
M;&)O>"!T;R!S96%R8V@@:6X*("`@("`@("`D<F5S=6QT(#T@)&EM87`M/G-E
M;&5C=$UA:6QB;W@H)&9O;&1E<BD["B`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D:6UA<"T^9&ES8V]N
M;F5C="@I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;6%P+3YS96%R8V@H)TA%041%
M4B`B)R`N($M/3$%"7TA%041%4E]465!%("X@)R(@(B<@+B`D=&AI<RT^7VUI
M;65?='EP92`N("<B)RD["B`@("`@("`@)&EM87`M/F1I<V-O;FYE8W0H*3L*
M"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+R\@5$]$3SH@
M=W)I=&4@82!F=6YC=&EO;B!T:&%T(&ES(&%B;&4@=&\@;&]O:R!T:')O=6=H
M(&%L;"!F;VQD97)S"B`@("`O+R!O9B!T:&4@='EP92!W92=R92!I;G1E<F5S
M=&5D(&EN+"!L;V]K:6YG(&9O<B!A;B!O8FIE8W0@=VET:"!A"B`@("`O+R!S
M<&5C:69I8R!5240N(%1H:7,@:7,@;F5E9&5D(&9O<B!T:&4@9V5T0GE'54E$
M*"D@9G5N8W1I;VYS(&EN"B`@("`O+R!T:&4@=F%R:6]U<R!A<'!L:6-A=&EO
M;B!D<FEV97)S+@H*("`@(&9U;F-T:6]N(&UO=F5/8FIE8W0H)'5I9"P@)&YE
M=U]S:&%R92D*("`@('L*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]I;6%P
M*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("`D;7-G7VYO(#T@)'1H:7,M/F9I;F1/8FIE8W0H)'5I9"D["B`@("`@
M("`@:68@*&ES7V$H)&US9U]N;RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&US9U]N;SL*("`@("`@("!]"@H@("`@("`@("1S:&%R
M95]M87`@/2!+;VQA8CHZ9V5T4VAA<F5-87`H*3L*("`@("`@("!I9B`H96UP
M='DH)'-H87)E7VUA<%LD;F5W7W-H87)E72DI('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")(;W)D92]+;VQA8CH@
M56YK;F]W;B!S:&%R92!<(B5S7"(B*2P@)&YE=U]S:&%R92DI.PH@("`@("`@
M('T*"B`@("`@("`@)&YE=U]F;VQD97(@/2`D<VAA<F5?;6%P6R1N97=?<VAA
M<F5=.PH*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;6%P+3YC;W!Y365S
M<V%G97,H)&YE=U]F;VQD97(L("1M<V=?;F\I.PH@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/E]I;6%P+3YD96QE=&5-97-S86=E<R@D;7-G7VYO*3L*("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?:6UA<"T^97AP=6YG92@I.PH@("`@?0H*("`@(&9U;F-T:6]N(')E;6]V
M94]B:F5C=',H)&]B:F5C=',L("1I<U]M<V=N;R`](&9A;'-E*0H@("`@>PH@
M("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7VEM87`I*2!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?87)R
M87DH)&]B:F5C=',I*2!["B`@("`@("`@("`@("1O8FIE8W1S(#T@87)R87DH
M)&]B:F5C=',I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1I<U]M<V=N;R`]
M/3T@9F%L<V4I('L*("`@("`@("`@("`@)&YE=U]O8FIE8W1S(#T@87)R87DH
M*3L*"B`@("`@("`@("`@(&9O<F5A8V@@*"1O8FIE8W1S(&%S("1O8FIE8W0I
M('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^9FEN9$]B:F5C
M="@D;V)J96-T*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D
M;F5W7V]B:F5C='-;72`]("1R97-U;'0["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1O8FIE8W1S(#T@)&YE=U]O8FIE8W1S.PH@("`@("`@('T*"B`@
M("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6UA<"T^9&5L971E365S<V%G97,H
M)&]B:F5C=',I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;6%P+3YE>'!U;F=E*"D[
M"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N(')E;6]V94%L;$]B
M:F5C=',H*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7VEM87`I
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^7VEM87`M/F1E;&5T94UE<W-A9V5S*"1T
M:&ES+3YL:7-T3V)J96-T<R@I*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M9G5N8W1I;VX@)FQO861/8FIE8W0H)'5I9"P@)&ES7VUS9VYO(#T@9F%L<V4I
M"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?:6UA<"DI('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"1I<U]M<V=N;R`]/3T@9F%L<V4I('L*("`@("`@("`@("`@)'5I9"`]("1T
M:&ES+3YF:6YD3V)J96-T*"1U:60I.PH@("`@("`@("`@("!I9B`H:7-?82@D
M=6ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)'5I9#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/E]H96%D97)S(#T@)'1H:7,M/E]I;6%P+3YG971087)S961(96%D97)S*"1U
M:60I.PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?:&5A9&5R<RP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("!]"@H@("`@("`@("1M97-S86=E7W1E>'0@/2`D=&AI<RT^7VEM87`M/F=E
M=$UE<W-A9V5S*"1U:60I.PH@("`@("`@(&EF("AI<U]A*"1M97-S86=E7W1E
M>'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1M97-S
M86=E7W1E>'0["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?87)R87DH)&UE
M<W-A9V5?=&5X="DI('L*("`@("`@("`@("`@)&UE<W-A9V5?=&5X="`](&%R
M<F%Y7W-H:69T*"1M97-S86=E7W1E>'0I.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/E]M<V=?;F\@/2`D=6ED.PH@("`@("`@("1T:&ES+3Y?;65S<V%G
M92`]("9-24U%7U-T<G5C='5R93HZ<&%R<V5497AT34E-14UE<W-A9V4H)&UE
M<W-A9V5?=&5X="D["@H@("`@("`@("1P87)T<R`]("1T:&ES+3Y?;65S<V%G
M92T^8V]N=&5N=%1Y<&5-87`H*3L*("`@("`@("!I9B`H*"1T:&ES+3Y?;6EM
M95]I9"`](&%R<F%Y7W-E87)C:"@D=&AI<RT^7VUI;65?='EP92P@)'!A<G1S
M*2D@(3T](&9A;'-E*2!["B`@("`@("`@("`@("1P87)T(#T@)'1H:7,M/E]M
M97-S86=E+3YG971087)T*"1T:&ES+3Y?;6EM95]I9"D["B`@("`@("`@("`@
M("1T97AT(#T@)'!A<G0M/G1R86YS9F5R1&5C;V1E*"D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R
M:6YT9BA?*")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U
M;F0@:6X@;65S<V%G92`E<R(I+"`D=&AI<RT^7VUI;65?='EP92P@)'5I9"DI
M.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]X;6P@/2!`9&]M>&UL7V]P
M96Y?;65M*"1T97AT+"!$3TU834Q?3$]!1%]005)324Y'('P*("`@("`@("`@
M("`@1$]-6$U,7TQ/041?0T]-4$Q%5$5?05144E,@?"!$3TU834Q?3$]!1%]3
M54)35$E4551%7T5.5$E42453('P*("`@("`@("`@("`@1$]-6$U,7TQ/041?
M1$].5%]+14507T),04Y+4RP@)&5R<F]R*3L*("`@("`@("!I9B`H(65M<'1Y
M*"1E<G)O<BDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H<W!R:6YT9BA?*")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T
M82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(BDL("1T:&ES+3Y?;V)J96-T
M7W1Y<&4L("1U:60I*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?=6ED
M(#T@)'1H:7,M/F=E=%9A;"@G=6ED)RD["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?>&UL+3YD;V-U;65N=%]E;&5M96YT*"D["B`@("!]"@H@("`@9G5N8W1I
M;VX@)FYE=T]B:F5C="@D=6ED*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D
M=&AI<RT^7VEM87`I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@("1T:&ES+3Y?;7-G7VYO(#T@+3$["@H@("`@("`@
M("1T:&ES+3Y?;65S<V%G92`](&YE=R!-24U%7TUE<W-A9V4H*3L*"B`@("`@
M("`@)&MO;&%B7W1E>'0@/2!S<')I;G1F*%\H(E1H:7,@:7,@82!+;VQA8B!'
M<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL
M(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO
M;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I
M;"!C;&EE;G1S('!L96%S92!V:7-I="`E<R(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G:'1T<#HO+W=W=RYK;VQA8BYO<F<O:V]L86(R+6-L
M:65N=',N:'1M;"<I.PH*("`@("`@("`D<&%R="`](&YE=R!-24U%7U!A<G0H
M)W1E>'0O<&QA:6XG+"!3=')I;F<Z.G=R87`H)&MO;&%B7W1E>'0L(#<V+"!+
M3TQ!0E].15=,24Y%+"!.3%,Z.F=E=$-H87)S970H*2DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@
M("`D<&%R="T^<V5T5')A;G-F97)%;F-O9&EN9R@G<75O=&5D+7!R:6YT86)L
M92<I.PH@("`@("`@("1T:&ES+3Y?;65S<V%G92T^861D4&%R="@D<&%R="D[
M"@H@("`@("`@("1P87)T(#T@;F5W($U)345?4&%R="@D=&AI<RT^7VUI;65?
M='EP92P@)R<L($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("`D<&%R="T^
M<V5T5')A;G-F97)%;F-O9&EN9R@G<75O=&5D+7!R:6YT86)L92<I.PH@("`@
M("`@("1T:&ES+3Y?;65S<V%G92T^861D4&%R="@D<&%R="D["@H@("`@("`@
M("1P87)T<R`]("1T:&ES+3Y?;65S<V%G92T^8V]N=&5N=%1Y<&5-87`H*3L*
M("`@("`@("!I9B`H*"1T:&ES+3Y?;6EM95]I9"`](&%R<F%Y7W-E87)C:"@D
M=&AI<RT^7VUI;65?='EP92P@)'!A<G1S*2D@/3T](&9A;'-E*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@
M<&%R="!O9B!T>7!E("5S(BDL("1T:&ES+3Y?;6EM95]T>7!E*2D["B`@("`@
M("`@?0H*("`@("`@("`D:&5A9&5R<R`](&YE=R!-24U%7TAE861E<G,H*3L*
M("`@("`@("`D:&5A9&5R<RT^861D2&5A9&5R*"=&<F]M)RP@075T:#HZ9V5T
M075T:"@I*3L*("`@("`@("`D:&5A9&5R<RT^861D2&5A9&5R*"=4;R<L($%U
M=&@Z.F=E=$%U=&@H*2D["B`@("`@("`@)&AE861E<G,M/F%D9$AE861E<B@G
M4W5B:F5C="<L("1U:60I.PH@("`@("`@("1H96%D97)S+3YA9&1(96%D97(H
M)U5S97(M06=E;G0G+"!+3TQ!0E]04D]$54-47TE$*3L*("`@("`@("`D:&5A
M9&5R<RT^861D2&5A9&5R*"=297!L>2U4;R<L("<G*3L*("`@("`@("`D:&5A
M9&5R<RT^861D2&5A9&5R*"=$871E)RP@9&%T92@G<B<I*3L*("`@("`@("`D
M:&5A9&5R<RT^861D2&5A9&5R*$M/3$%"7TA%041%4E]465!%+"`D=&AI<RT^
M7VUI;65?='EP92D["B`@("`@("`@)&AE861E<G,M/F%D9$U)345(96%D97)S
M*"1T:&ES+3Y?;65S<V%G92D["@H@("`@("`@("1T:&ES+3Y?:&5A9&5R<R`]
M("1H96%D97)S+3YT;T%R<F%Y*"D["@H@("`@("`@("1T:&ES+3Y?>&UL(#T@
M9&]M>&UL7V]P96Y?;65M*`H@("`@("`@("`@("`G/#]X;6P@=F5R<VEO;CTB
M,2XP(B!E;F-O9&EN9STB551&+3@B/SXG("X*("`@("`@("`@("`@)SPG("X@
M)'1H:7,M/E]O8FIE8W1?='EP92`N("<@=F5R<VEO;CTB,2XP(CXG("X*("`@
M("`@("`@("`@)SQU:60^)R`N("1U:60@+B`G/"]U:60^)R`N"B`@("`@("`@
M("`@("<\8F]D>3X\+V)O9'D^)R`N"B`@("`@("`@("`@("<\8V%T96=O<FEE
M<SX\+V-A=&5G;W)I97,^)R`N"B`@("`@("`@("`@("<\8W)E871I;VXM9&%T
M93XG("X@2V]L86(Z.F5N8V]D941A=&54:6UE*"D@+B`G/"]C<F5A=&EO;BUD
M871E/B<@+@H@("`@("`@("`@("`G/'-E;G-I=&EV:71Y/G!U8FQI8SPO<V5N
M<VET:79I='D^)R`N"B`@("`@("`@("`@("<\+R<@+B`D=&AI<RT^7V]B:F5C
M=%]T>7!E("X@)SXG+`H@("`@("`@("`@("!$3TU834Q?3$]!1%]005)324Y'
M('P@1$]-6$U,7TQ/041?0T]-4$Q%5$5?05144E,@?`H@("`@("`@("`@("!$
M3TU834Q?3$]!1%]354)35$E4551%7T5.5$E42453('P@1$]-6$U,7TQ/041?
M1$].5%]+14507T),04Y+4RP*("`@("`@("`@("`@)&5R<F]R"B`@("`@("`@
M*3L*("`@("`@("!I9B`H(65M<'1Y*"1E<G)O<BDI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")(;W)D92]+;VQA
M8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E
M<R(I+"`D=6ED*2D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W5I9"`]
M("1U:60["@H@("`@("`@(')E='5R;B`D=&AI<RT^7WAM;"T^9&]C=6UE;G1?
M96QE;65N="@I.PH@("`@?0H*("`@(&9U;F-T:6]N('-A=F5/8FIE8W0H*0H@
M("`@>PH@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7VEM87`I*2!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3YS971686PH)VQA<W0M;6]D:69I8V%T:6]N+61A=&4G+"!+;VQA8CHZ96YC
M;V1E1&%T951I;64H*2D["B`@("`@("`@)'1H:7,M/G-E=%9A;"@G<')O9'5C
M="UI9"<L($M/3$%"7U!23T150U1?240I.PH*("`@("`@("`D<&%R="`](&YE
M=R!-24U%7U!A<G0H)'1H:7,M/E]M:6UE7W1Y<&4L("1T:&ES+3Y?>&UL+3YD
M=6UP7VUE;2AT<G5E*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@("1P87)T+3YS9714<F%N<V9E
M<D5N8V]D:6YG*"=Q=6]T960M<')I;G1A8FQE)RD["B`@("`@("`@)'1H:7,M
M/E]M97-S86=E+3YA;'1E<E!A<G0H)'1H:7,M/E]M:6UE7VED+"`D<&%R="D[
M"@H@("`@("`@(&EF("@D=&AI<RT^7VUS9U]N;R`A/2`M,2D@>PH@("`@("`@
M("`@("`D=&AI<RT^<F5M;W9E3V)J96-T<R@D=&AI<RT^7VUS9U]N;RP@=')U
M92D["B`@("`@("`@?0H*("`@("`@("`D:&5A9&5R<R`](&YE=R!-24U%7TAE
M861E<G,H*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VAE861E<G,@87,@
M)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("1H96%D97)S+3YA9&1(96%D
M97(H)&ME>2P@)'9A;"D["B`@("`@("`@?0H*("`@("`@("`D;65S<V%G92`]
M($MO;&%B.CIK;VQA8DYE=VQI;F5S*"1H96%D97)S+3YT;U-T<FEN9R@I("X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;65S<V%G92T^=&]3=')I;F<H9F%L<V4I*3L*"B`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?:6UA<"T^87!P96YD365S<V%G92@D;65S<V%G92D["B`@
M("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3Y?;7-G7VYO(#T@)'1H:7,M/F9I;F1/8FIE8W0H)'1H:7,M/E]U:60I
M.PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?;7-G7VYO+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VUS9U]N;SL*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T
M:6]N("9G971#=7)R96YT3V)J96-T*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]X;6PM/F1O8W5M96YT7V5L96UE;G0H*3L*("`@('T*"B`@("!F
M=6YC=&EO;B`F9V5T16QE;2@D;F%M92P@)B1P87)E;G0I"B`@("!["B`@("`@
M("`@)&5L96UE;G1S(#T@)B1T:&ES+3YG971!;&Q%;&5M<R@D;F%M92P@)'!A
M<F5N="D["@H@("`@("`@(&EF("AE;7!T>2@D96QE;65N=',I*2!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D96QE;65N='-;,%T["B`@("!]"@H@("`@9G5N8W1I;VX@)F=E=$%L;$5L
M96US*"1N86UE+"`F)'!A<F5N="D*("`@('L*("`@("`@("!R971U<FX@)'!A
M<F5N="T^9V5T7V5L96UE;G1S7V)Y7W1A9VYA;64H)&YA;64I.PH@("`@?0H*
M("`@(&9U;F-T:6]N("9G9712;V]T16QE;2@D;F%M92D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/F=E=$5L96TH)&YA;64L("1T:&ES+3YG971#=7)R
M96YT3V)J96-T*"DI.PH@("`@?0H*("`@(&9U;F-T:6]N("9G971!;&Q2;V]T
M16QE;7,H)&YA;64I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YG971!
M;&Q%;&5M<R@D;F%M92P@)'1H:7,M/F=E=$-U<G)E;G1/8FIE8W0H*2D["B`@
M("!]"@H@("`@9G5N8W1I;VX@9&5L16QE;2@D;F%M92P@)B1P87)E;G0I"B`@
M("!["B`@("`@("`@)&5L96UE;G0@/2`F)'1H:7,M/F=E=$5L96TH)&YA;64L
M("1P87)E;G0I.PH@("`@("`@(&EF("@D96QE;65N="`]/3T@9F%L<V4I('L*
M("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1P87)E;G0M/G)E;6]V95]C:&EL9"@D96QE;65N="D["B`@("!]"@H@("`@
M9G5N8W1I;VX@9&5L06QL16QE;7,H)&YA;64L("8D<&%R96YT*0H@("`@>PH@
M("`@("`@("1E;&5M96YT<R`]("8D=&AI<RT^9V5T06QL16QE;7,H)&YA;64L
M("1P87)E;G0I.PH@("`@("`@(&9O<B`H)&D@/2`P+"`D:B`](&-O=6YT*"1E
M;&5M96YT<RD[("1I(#P@)&H[("1I*RLI('L*("`@("`@("`@("`@)'!A<F5N
M="T^<F5M;W9E7V-H:6QD*"1E;&5M96YT<ULD:5TI.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!D96Q!;&Q2
M;V]T16QE;7,H)&YA;64I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YD
M96Q!;&Q%;&5M<R@D;F%M92P@)'1H:7,M/F=E=$-U<G)E;G1/8FIE8W0H*2D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@9&5L4F]O=$5L96TH)B1E;&5M96YT*0H@
M("`@>PH@("`@("`@(&EF("@D96QE;65N="`]/3T@9F%L<V4I('L*("`@("`@
M("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)')O;W0@/2`F)'1H
M:7,M/F=E=$-U<G)E;G1/8FIE8W0H*3L*("`@("`@("!R971U<FX@)')O;W0M
M/G)E;6]V95]C:&EL9"@D96QE;65N="D["B`@("!]"@H@("`@9G5N8W1I;VX@
M9V5T16QE;59A;"@F)'!A<F5N="P@)&YA;64L("1D969A=6QT(#T@,"D*("`@
M('L*("`@("`@("!I9B`H)'!A<F5N="`]/3T@9F%L<V4I('L*("`@("`@("`@
M("`@<F5T=7)N("1D969A=6QT.PH@("`@("`@('T*"B`@("`@("`@)&5L96UE
M;G0@/2`F)'1H:7,M/F=E=$5L96TH)&YA;64L("1P87)E;G0I.PH@("`@("`@
M(&EF("@D96QE;65N="`]/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N
M("1D969A=6QT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1E;&5M96YT
M+3YG971?8V]N=&5N="@I.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$5L96U3
M='(H)B1P87)E;G0L("1N86UE+"`D9&5F875L="`]("<G*0H@("`@>PH@("`@
M("`@(&EF("@D<&%R96YT(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U
M<FX@)&1E9F%U;'0["B`@("`@("`@?0H*("`@("`@("`D96QE;65N="`]("8D
M=&AI<RT^9V5T16QE;2@D;F%M92P@)'!A<F5N="D["B`@("`@("`@:68@*"1E
M;&5M96YT(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@)&1E9F%U
M;'0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@4W1R:6YG.CIC;VYV97)T
M0VAA<G-E="@D96QE;65N="T^9V5T7V-O;G1E;G0H*2P@)W5T9BTX)RD["B`@
M("!]"@H@("`@9G5N8W1I;VX@9V5T5F%L*"1N86UE+"`D9&5F875L="`](#`I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YG971%;&5M5F%L*"1T:&ES
M+3YG971#=7)R96YT3V)J96-T*"DL("1N86UE+"`D9&5F875L="D["B`@("!]
M"@H@("`@9G5N8W1I;VX@9V5T4W1R*"1N86UE+"`D9&5F875L="`]("<G*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^9V5T16QE;5-T<B@D=&AI<RT^
M9V5T0W5R<F5N=$]B:F5C="@I+"`D;F%M92P@)&1E9F%U;'0I.PH@("`@?0H*
M("`@(&9U;F-T:6]N("9I;FET16QE;2@D;F%M92P@)B1P87)E;G0I"B`@("![
M"B`@("`@("`@:68@*"1P87)E;G0@/3T](&9A;'-E*2!["B`@("`@("`@("`@
M("1P87)E;G0@/2`D=&AI<RT^9V5T0W5R<F5N=$]B:F5C="@I.PH@("`@("`@
M('T*"B`@("`@("`@)&5L96UE;G0@/2`D=&AI<RT^9V5T16QE;2@D;F%M92P@
M)'!A<F5N="D["@H@("`@("`@(&EF("@D96QE;65N="`]/3T@9F%L<V4I('L*
M("`@("`@("`@("`@)&5L96UE;G0@/2`D<&%R96YT+3YA<'!E;F1?8VAI;&0H
M)'1H:7,M/E]X;6PM/F-R96%T95]E;&5M96YT*"1N86UE*2D["B`@("`@("`@
M?0H*("`@("`@("`D8VAI;&1R96X@/2`D96QE;65N="T^8VAI;&1?;F]D97,H
M*3L*("`@("`@("!F;W)E86-H("@D8VAI;&1R96X@87,@)&-H:6QD*2!["B`@
M("`@("`@("`@(&EF("@D8VAI;&0M/FYO9&5?='EP92@I(#T](%A-3%]415A4
M7TY/1$4I('L*("`@("`@("`@("`@("`@("1E;&5M96YT+3YR96UO=F5?8VAI
M;&0H)&-H:6QD*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1E;&5M96YT.PH@("`@?0H*("`@(&9U;F-T:6]N("9I;FET4F]O
M=$5L96TH)&YA;64I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YI;FET
M16QE;2@D;F%M92P@)'1H:7,M/F=E=$-U<G)E;G1/8FIE8W0H*2D["B`@("!]
M"@H@("`@9G5N8W1I;VX@)F%P<&5N9$5L96TH)&YA;64L("8D<&%R96YT*0H@
M("`@>PH@("`@("`@(')E='5R;B`D<&%R96YT+3YA<'!E;F1?8VAI;&0H)'1H
M:7,M/E]X;6PM/F-R96%T95]E;&5M96YT*"1N86UE*2D["B`@("!]"@H@("`@
M9G5N8W1I;VX@)F%P<&5N9%)O;W1%;&5M*"1N86UE*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^87!P96YD16QE;2@D;F%M92P@)'1H:7,M/F=E=$-U
M<G)E;G1/8FIE8W0H*2D["B`@("!]"@H@("`@9G5N8W1I;VX@)G-E=$5L96U6
M86PH)B1P87)E;G0L("1N86UE+"`D=F%L=64@/2`G)RD*("`@('L*("`@("`@
M("`D96QE;65N="`]("8D=&AI<RT^:6YI=$5L96TH)&YA;64L("1P87)E;G0I
M.PH@("`@("`@("1E;&5M96YT+3YS971?8V]N=&5N="@D=F%L=64I.PH*("`@
M("`@("!R971U<FX@)&5L96UE;G0["B`@("!]"@H@("`@9G5N8W1I;VX@)G-E
M=$5L96U3='(H)B1P87)E;G0L("1N86UE+"`D=F%L=64@/2`G)RD*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/G-E=$5L96U686PH)'!A<F5N="P@)&YA
M;64L(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'9A;'5E+"!.3%,Z.F=E=$-H
M87)S970H*2P@)W5T9BTX)RDI.PH@("`@?0H*("`@(&9U;F-T:6]N("9S9716
M86PH)&YA;64L("1V86QU92`]("<G*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^<V5T16QE;59A;"@D=&AI<RT^9V5T0W5R<F5N=$]B:F5C="@I+"`D
M;F%M92P@)'9A;'5E*3L*("`@('T*"B`@("!F=6YC=&EO;B`F<V5T4W1R*"1N
M86UE+"`D=F%L=64@/2`G)RD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/G-E=$5L96U3='(H)'1H:7,M/F=E=$-U<G)E;G1/8FIE8W0H*2P@)&YA;64L
M("1V86QU92D["B`@("!]"@HO+R!5=&EL:71Y(&QI8G)A<GD@:6YT97)F86-E
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<W1R:6YG(&-O;G1A:6YI;F<@
M=&AE(&-U<G)E;G0@551#(&1A=&4@:6X@=&AE(&9O<FUA=`H@("`@("H@<')E
M<V-R:6)E9"!B>2!T:&4@2V]L86(@1F]R;6%T(%-P96-I9FEC871I;VXN"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C=7)R96YT(%540R!D
M871E(&EN('1H92!F;W)M870@)UE965DM34TM1$0G+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!E;F-O9&5$871E*"1D871E(#T@9F%L<V4I"B`@("!["B`@("`@
M("`@:68@*"1D871E(#T]/2`P*2!["B`@("`@("`@("`@(')E='5R;B`P.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@<W1R9G1I;64H)R59+25M+25D)RP@
M)&1A=&4@/3T](&9A;'-E(#\@=&EM92@I(#H@)&1A=&4I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!A(%5.25@@=&EM97-T86UP(&-O<G)E<W!O
M;F1I;F<@=&AE(&=I=F5N(&1A=&4@<W1R:6YG('=H:6-H(&ES(&EN"B`@("`@
M*B!T:&4@9F]R;6%T('!R97-C<FEB960@8GD@=&AE($MO;&%B($9O<FUA="!3
M<&5C:69I8V%T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1A
M=&4@(%1H92!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@=&AE(&1A=&4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@=6YI>"!T:6UE<W1A
M;7`@8V]R<F5S<&]N9&EN9R!T;R`D9&%T92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9&5C;V1E1&%T92@D9&%T92D*("`@('L*("`@("`@("!I9B`H96UP='DH
M)&1A=&4I*2!["B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T*"B`@
M("`@("`@;&ES="@D>65A<BP@)&UO;G1H+"`D9&%Y*2`](&5X<&QO9&4H)RTG
M+"`D9&%T92D["B`@("`@("`@<F5T=7)N(&UK=&EM92@P+"`P+"`P+"`D;6]N
M=&@L("1D87DL("1Y96%R*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@82!S=')I;F<@8V]N=&%I;FEN9R!T:&4@8W5R<F5N="!55$,@9&%T92!A
M;F0@=&EM92!I;B!T:&4@9F]R;6%T"B`@("`@*B!P<F5S8W)I8F5D(&)Y('1H
M92!+;VQA8B!&;W)M870@4W!E8VEF:6-A=&EO;BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@("!4:&4@8W5R<F5N="!55$,@9&%T92!A;F0@=&EM
M92!I;B!T:&4@9F]R;6%T"B`@("`@*B`@("`@("`@("`@("`@("`@("`G65E9
M62U-32U$1%1H:#IM;3IS<UHG+"!W:&5R92!T:&4@5"!A;F0@6B!A<F4@;&ET
M97)A;`H@("`@("H@("`@("`@("`@("`@("`@("`@8VAA<F%C=&5R<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@96YC;V1E1&%T951I;64H)&1A=&5T:6UE(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@:68@*"1D871E=&EM92`]/3T@,"D@>PH@
M("`@("`@("`@("!R971U<FX@,#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M(&=M<W1R9G1I;64H)R59+25M+25D5"5(.B5-.B536B<L("1D871E=&EM92`]
M/3T@9F%L<V4@/R!T:6UE*"D@.B`D9&%T971I;64I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!A(%5.25@@=&EM97-T86UP(&-O<G)E<W!O;F1I
M;F<@=&AE(&=I=F5N(&1A=&4M=&EM92!S=')I;F<@=VAI8V@*("`@("`J(&ES
M(&EN('1H92!F;W)M870@<')E<V-R:6)E9"!B>2!T:&4@2V]L86(@1F]R;6%T
M(%-P96-I9FEC871I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9&%T971I;64@(%1H92!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@=&AE(&1A
M=&4@)B!T:6UE+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE
M('5N:7@@=&EM97-T86UP(&-O<G)E<W!O;F1I;F<@=&\@)&1A=&5T:6UE+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!D96-O9&5$871E5&EM92@D9&%T971I;64I
M"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1D871E=&EM92DI('L*("`@("`@
M("`@("`@<F5T=7)N(#`["B`@("`@("`@?0H*("`@("`@("!L:7-T*"1Y96%R
M+"`D;6]N=&@L("1D87DL("1H;W5R+"`D;6EN=71E+"`D<V5C;VYD*0H@("`@
M("`@("`@("`]('-S8V%N9B@D9&%T971I;64L("<E9"TE9"TE9%0E9#HE9#HE
M9%HG*3L*("`@("`@("!R971U<FX@9VUM:W1I;64H)&AO=7(L("1M:6YU=&4L
M("1S96-O;F0L("1M;VYT:"P@)&1A>2P@)'EE87(I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!A(%5.25@@=&EM97-T86UP(&-O<G)E<W!O;F1I
M;F<@=&AE(&=I=F5N(&1A=&4@;W(@9&%T92UT:6UE"B`@("`@*B!S=')I;F<@
M=VAI8V@@:7,@:6X@96ET:&5R(&9O<FUA="!P<F5S8W)I8F5D(&)Y('1H92!+
M;VQA8B!&;W)M870*("`@("`J(%-P96-I9FEC871I;VXN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9&%T92`@5&AE('-T<FEN9R!R97!R97-E;G1A
M=&EO;B!O9B!T:&4@9&%T92`H)B!T:6UE*2X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN=&5G97(@(%1H92!U;FEX('1I;65S=&%M<"!C;W)R97-P;VYD:6YG
M('1O("1D871E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96-O9&5$871E3W)$
M871E5&EM92@D9&%T92D*("`@('L*("`@("`@("!I9B`H96UP='DH)&1A=&4I
M*2!["B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("AS=')L96XH)&1A=&4I(#T](#$P(#\@2V]L86(Z.F1E8V]D941A
M=&4H)&1A=&4I(#H@2V]L86(Z.F1E8V]D941A=&54:6UE*"1D871E*2D["B`@
M("!]"@H@("`@9G5N8W1I;VX@9&5C;V1E1G5L;$1A>41A=&4H)&1A=&4I"B`@
M("!["B`@("`@("`@:68@*&5M<'1Y*"1D871E*2D@>PH@("`@("`@("`@("!R
M971U<FX@,#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`H<W1R;&5N*"1D
M871E*2`]/2`Q,"`_($MO;&%B.CID96-O9&5$871E*"1D871E*2LR-"HV,"HV
M,"`Z($MO;&%B.CID96-O9&5$871E5&EM92@D9&%T92DI.PH@("`@?0H*("`@
M(&9U;F-T:6]N('!E<F-E;G1A9V54;T)O;VQE86XH)'!E<F-E;G1A9V4I"B`@
M("!["B`@("`@("`@<F5T=7)N("1P97)C96YT86=E(#T](#$P,"`_("<Q)R`Z
M("<P)SL*("`@('T*"B`@("!F=6YC=&EO;B!B;V]L96%N5&]097)C96YT86=E
M*"1B;V]L96%N*0H@("`@>PH@("`@("`@(')E='5R;B`D8F]O;&5A;B`_("<Q
M,#`G(#H@)S`G.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@82!S
M=')I;F<@:6X@=&AE(&-U<G)E;G0@8VAA<F%C=&5R('-E="!T;R!A;B!)34%0
M(%541BTW('-T<FEN9RP*("`@("`J('-U:71A8FQE(&9O<B!U<V4@87,@=&AE
M(&YA;64@;V8@86X@24U!4"!F;VQD97(N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F%M92`@5&AE('1E>'0@:6X@=&AE(&-U<G)E;G0@8VAA<F%C
M=&5R('-E="!T;R!C;VYV97)T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("`@("1N86UE(&5N8V]D960@:6X@=&AE($E-05`@=F%R:6%T:6]N(&]F
M(%541BTW+@H@("`@("HO"B`@("!F=6YC=&EO;B!E;F-O9&5);6%P1F]L9&5R
M3F%M92@D;F%M92D*("`@('L*("`@("`@("!R971U<FX@4W1R:6YG.CIC;VYV
M97)T0VAA<G-E="@D;F%M92P@3DQ3.CIG971#:&%R<V5T*"DL("=55$8W+4E-
M05`G*3L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G1S(&$@<W1R:6YG
M(&EN('1H92!)34%0('9A<FEA=&EO;B!O9B!55$8M-R!I;G1O(&$@<W1R:6YG
M(&EN('1H90H@("`@("H@8W5R<F5N="!C:&%R86-T97(@<V5T+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!T97AT(&EN($E-05`@
M551&+3<@=&\@8V]N=F5R="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@("`D;F%M92!E;F-O9&5D(&EN('1H92!C=7)R96YT(&-H87)A8W1E<B!S
M970N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E8V]D94EM87!&;VQD97).86UE
M*"1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B!3=')I;F<Z.F-O;G9E<G1#
M:&%R<V5T*"1N86UE+"`G551&-RU)34%0)RD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#;VYV97)T<R!A;&P@;F5W;&EN97,@*&EN($1/4RP@34%#("8@54Y)
M6"!F;W)M870I(&EN('1H92!S<&5C:69I960@=&5X=`H@("`@("H@=&\@=6YI
M>"US='EL92`H3$8I(&9O<FUA="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T97AT("!4:&4@=&5X="!T;R!C;VYV97)T+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("`D=&5X="!W:71H(&%L;"!N97=L:6YE<R!R97!L
M86-E9"!B>2!,1BX*("`@("`J+PH@("`@9G5N8W1I;VX@=6YI>$YE=VQI;F5S
M*"1T97AT*0H@("`@>PH@("`@("`@(')E='5R;B!P<F5G7W)E<&QA8V4H(B]<
M<EQN?%QN?%QR+W,B+"`B7&XB+"`D=&5X="D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#;VYV97)T<R!A;&P@;F5W;&EN97,@*&EN($1/4RP@34%#("8@54Y)
M6"!F;W)M870I(&EN('1H92!S<&5C:69I960@=&5X=`H@("`@("H@=&\@2V]L
M86(@*$-Y<G5S*2!F;W)M870N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=&5X="`@5&AE('1E>'0@=&\@8V]N=F5R="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@)'1E>'0@=VET:"!A;&P@;F5W;&EN97,@<F5P;&%C
M960@8GD@2T],04)?3D573$E.12X*("`@("`J+PH@("`@9G5N8W1I;VX@:V]L
M86).97=L:6YE<R@D=&5X="D*("`@('L*("`@("`@("!R971U<FX@<')E9U]R
M97!L86-E*"(O7')<;GQ<;GQ<<B]S(BP@2T],04)?3D573$E.12P@)'1E>'0I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=6YF;VQD960@
M<F5P<F5S96YT871I;VX@;V8@=&AE(&=I=F5N('1E>'0N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@=&\@=6YF;VQD+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=6YF;VQD960@<F5P
M<F5S96YT871I;VX@;V8@)'1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N('5N
M9F]L9%1E>'0H)'1E>'0I"B`@("!["B`@("`@("`@<F5T=7)N('!R96=?<F5P
M;&%C92@B+UQR7&Y;(%QT72LO(BP@(B(L("1T97AT*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@86X@87)R87D@;V8@87!P;&EC871I;VXM<W!E
M8VEF:6,@8V]N<W1A;G1S+"!T:&%T(&%R92!U<V5D(&EN"B`@("`@*B!A(&=E
M;F5R:6,@;6%N;F5R('1H<F]U9VAO=70@=&AE(&QI8G)A<GDN"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D87!P("!4:&4@87!P;&EC871I;VX@=VAO
M<V4@8V]N<W1A;G1S('1O('%U97)Y+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@($%N(&%R<F%Y(&]F(&%P<&QI8V%T:6]N+7-P96-I9FEC(&-O;G-T
M86YT<R!I9B`D87!P(&ES(&$*("`@("`J("`@("`@("`@("`@("`@('-U<'!O
M<G1E9"!A<'!L:6-A=&EO;BP@;W(@82!014%27T5R<F]R(&]B:F5C="!I9B`D
M87!P(&ES"B`@("`@*B`@("`@("`@("`@("`@("!N;W0@<W5P<&]R=&5D+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971!<'!#;VYS=',H)&%P<"D*("`@('L*
M("`@("`@("!S=VET8V@@*"1A<'`I('L*("`@("`@("!C87-E("=M;F5M;R<Z
M"B`@("`@("`@("`@(')E='5R;B!A<G)A>2@*("`@("`@("`@("`@("`@("=M
M:6UE7W1Y<&5?<W5F9FEX)R`@("`@(#T^("=N;W1E)RP*("`@("`@("`@("`@
M("`@("=D969A=6QT7V9O;&1E<E]N86UE)R`@(#T^(%\H(DYO=&5S(BDL"B`@
M("`@("`@("`@("`@("`G<VAA<F5?;F%M92<@("`@("`@("`@("`]/B!?*")N
M;W1E<&%D(BDL"B`@("`@("`@("`@("`@("`G9&5F875L=%]S:&%R95]N86UE
M)R`@("`]/B!?*"(E<R=S($YO=&5P860B*2P*("`@("`@("`@("`@*3L*"B`@
M("`@("`@8V%S92`G:W)O;F]L:71H)SH*("`@("`@("`@("`@<F5T=7)N(&%R
M<F%Y*`H@("`@("`@("`@("`@("`@)VUI;65?='EP95]S=69F:7@G("`@("`@
M/3X@)V5V96YT)RP*("`@("`@("`@("`@("`@("=D969A=6QT7V9O;&1E<E]N
M86UE)R`@(#T^(%\H(D-A;&5N9&%R(BDL"B`@("`@("`@("`@("`@("`G<VAA
M<F5?;F%M92<@("`@("`@("`@("`]/B!?*")C86QE;F1A<B(I+`H@("`@("`@
M("`@("`@("`@)V1E9F%U;'1?<VAA<F5?;F%M92<@("`@/3X@7R@B)7,G<R!#
M86QE;F1A<B(I+`H@("`@("`@("`@("`I.PH*("`@("`@("!C87-E("=T=7)B
M82<Z"B`@("`@("`@("`@(')E='5R;B!A<G)A>2@*("`@("`@("`@("`@("`@
M("=M:6UE7W1Y<&5?<W5F9FEX)R`@("`@(#T^("=C;VYT86-T)RP*("`@("`@
M("`@("`@("`@("=D969A=6QT7V9O;&1E<E]N86UE)R`@(#T^(%\H(D-O;G1A
M8W1S(BDL"B`@("`@("`@("`@("`@("`G<VAA<F5?;F%M92<@("`@("`@("`@
M("`]/B!?*")A9&1R97-S(&)O;VLB*2P*("`@("`@("`@("`@("`@("=D969A
M=6QT7W-H87)E7VYA;64G("`@(#T^(%\H(B5S)W,@061D<F5S<R!";V]K(BDL
M"B`@("`@("`@("`@("D["@H@("`@("`@(&-A<V4@)VYA9R<Z"B`@("`@("`@
M("`@(')E='5R;B!A<G)A>2@*("`@("`@("`@("`@("`@("=M:6UE7W1Y<&5?
M<W5F9FEX)R`@("`@(#T^("=T87-K)RP*("`@("`@("`@("`@("`@("=D969A
M=6QT7V9O;&1E<E]N86UE)R`@(#T^(%\H(E1A<VMS(BDL"B`@("`@("`@("`@
M("`@("`G<VAA<F5?;F%M92<@("`@("`@("`@("`]/B!?*")T87-K(&QI<W0B
M*2P*("`@("`@("`@("`@("`@("=D969A=6QT7W-H87)E7VYA;64G("`@(#T^
M(%\H(B5S)W,@5&%S:VQI<W0B*2P*("`@("`@("`@("`@*3L*"B`@("`@("`@
M9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M<W!R:6YT9BA?*")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE
M(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(BDL("1A<'`I*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N($E-05`@04-,('-T
M<FEN9R!C;W)R97-P;VYD:6YG('1O('1H92!G:79E;B!(;W)D92!P97)M:7-S
M:6]N<PH@("`@("H@=F%L=64N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'!E<FUS("!4:&4@2&]R9&4@<&5R;6ES<VEO;G,@=F%L=64N"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D;W=N97(@(%=I;&P@=&AE($%#3"!S=')I;F<@
M8F4@=7-E9"!F;W(@=&AE(&9O;&1E<B!O=VYE<C\*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@5&AI<R!I;F-L=61E<R!T:&4@)V$G(')I9VAT<R!I
M;B!T:&4@04-,('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE($E-05`@04-,('-T<FEN9R!C;W)R97-P;VYD:6YG('1O("1P97)M
M<R!A;F0@)&]W;F5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!P97)M<U1O04-,
M*"1P97)M<RP@)&]W;F5R(#T@=')U92D*("`@('L*("`@("`@("`D<F5S=6QT
M(#T@)&]W;F5R(#\@)V$G(#H@)R<["B`@("`@("`@:68@*"1P97)M<R`F(%!%
M4DU37U-(3U<I('L*("`@("`@("`@("`@)')E<W5L="`N/2`G;"<["B`@("`@
M("`@?0H@("`@("`@(&EF("@D<&5R;7,@)B!015)-4U]214%$*2!["B`@("`@
M("`@("`@("1R97-U;'0@+CT@)W(G.PH@("`@("`@('T*("`@("`@("!I9B`H
M)'!E<FUS("8@4$5235-?141)5"D@>PH@("`@("`@("`@("`D<F5S=6QT("X]
M("=I<W=C)SL*("`@("`@("!]"B`@("`@("`@:68@*"1P97)M<R`F(%!%4DU3
M7T1%3$5412D@>PH@("`@("`@("`@("`D<F5S=6QT("X]("=D)SL*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!A($AO<F1E('!E<FUI<W-I;VYS('9A;'5E(&-O<G)E
M<W!O;F1I;F<@=&\@=&AE(&=I=F5N($E-05`@04-,"B`@("`@*B!S=')I;F<N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D86-L7W-T<FEN9R`@5&AE
M($E-05`@04-,('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G
M97(@(%1H92!(;W)D92!P97)M:7-S:6]N<R!V86QU92!C;W)R97-P;VYD:6YG
M('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("1A8VQ?<W1R:6YG+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!A8VQ4;U!E<FUS*"1A8VQ?<W1R:6YG*0H@("`@
M>PH@("`@("`@("1R97-U;'0@/2`P.PH*("`@("`@("!F;W(@*"1I(#T@,"P@
M)&H@/2!S=')L96XH)&%C;%]S=')I;F<I.R`D:2`\("1J.R`D:2LK*2!["B`@
M("`@("`@("`@('-W:71C:"`H)&%C;%]S=')I;F=;)&E=*2!["B`@("`@("`@
M("`@(&-A<V4@)VPG.@H@("`@("`@("`@("`@("`@)')E<W5L="!\/2!015)-
M4U]32$]7.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E("=R)SH*("`@("`@("`@("`@("`@("1R97-U;'0@?#T@4$5235-?4D5!
M1#L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G
M:2<Z"B`@("`@("`@("`@("`@("`D<F5S=6QT('P](%!%4DU37T5$250["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V0G.@H@
M("`@("`@("`@("`@("`@)')E<W5L="!\/2!015)-4U]$14Q%5$4["B`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M<F5A=&5S(&%N(&%S<V]C:6%T:79E(&%R<F%Y(&]U="!O9B!A;B!)34%0($%#
M3"!L:7-T(&%S(')E='5R;F5D(&)Y('1H90H@("`@("H@3F5T7TE-05`@;V)J
M96-T+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D86-L("!4:&4@24U!
M4"!!0TP@87)R87DN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@
M87-S;V-I871I=F4@87)R87DL('=H97)E('1H92!K97ES(&%R92!I;F1I=FED
M=6%L('5S97)S"B`@("`@*B`@("`@("`@("`@("`@("!A;F0@=&AE('9A;'5E
M<R!T:&4@04-,('-T<FEN9R!F;W(@=&AE('-P96-I9FEC('5S97(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%C;%1O07)R87DH)&%C;"D*("`@('L*("`@("`@
M("!I9B`H:7-?82@D86-L+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D86-L.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`](&%R
M<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&%C;"!A<R`D=7-E<BD@>PH@("`@
M("`@("`@("!I9B`H<')E9U]M871C:"@G+V=R;W5P.B@N*RDO)RP@)'5S97);
M)U5315(G72P@)&UA=&-H97,I*2!["B`@("`@("`@("`@("`@("`O*B!,;V]K
M('5P(&%N9"!E>'!A;F0@9W)O=7!S+B`J+PH@("`@("`@("`@("`@("`@<F5Q
M=6ER95]O;F-E("=(;W)D92]'<F]U<"YP:'`G.PH@("`@("`@("`@("`@("`@
M)&=R;W5P(#T@)D=R;W5P.CIS:6YG;&5T;VXH*3L*("`@("`@("`@("`@("`@
M("1G:60@/2`D9W)O=7`M/F=E=$=R;W5P260H)&UA=&-H97-;,5TI.PH@("`@
M("`@("`@("`@("`@)'5S97)S(#T@)&=R;W5P+3YL:7-T57-E<G,H)&=I9"D[
M"B`@("`@("`@("`@("`@("!F;W)E86-H("@D=7-E<G,@87,@)'4I('L*("`@
M("`@("`@("`@("`@("`@("`D<F5S=6QT6R1U72`]("1U<V5R6R=224=(5%,G
M73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1R97-U;'1;)'5S97);)U5315(G75T@/2`D=7-E<ELG
M4DE'2%13)UT["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%-H87)E36%P
M*"D*("`@('L*("`@("`@("!R971U<FX@96UP='DH)%]315-324].6TM/3$%"
M7U-(05)%7TU!4%TI"B`@("`@("`@("`_(&%R<F%Y*"D*("`@("`@("`@(#H@
M=6YS97)I86QI>F4H)%]315-324].6TM/3$%"7U-(05)%7TU!4%TI.PH@("`@
M?0H*("`@(&9U;F-T:6]N('-E=%-H87)E36%P*"1S:&%R95]M87`I"B`@("![
M"B`@("`@("`@)%]315-324].6TM/3$%"7U-(05)%7TU!4%T@/2!S97)I86QI
M>F4H)'-H87)E7VUA<"D["B`@("!]"@H@("`@9G5N8W1I;VX@=7!D871E36%P
M<&5D4VAA<F4H)B1S:&%R95]M87`L("1S:&%R95]U:60L("1I;6%P7V9O;&1E
M<BD*("`@('L*("`@("`@("`D<VAA<F5?;6%P6R1S:&%R95]U:61=(#T@)&EM
M87!?9F]L9&5R.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%-H87)E36%P<&EN
M9R@F)'-H87)E7VUA<"P@)'-H87)E7W5I9"P@)&1N95]R97-U;'0@/2`G)RD*
M("`@('L*("`@("`@("!R971U<FX@96UP='DH)'-H87)E7VUA<%LD<VAA<F5?
M=6ED72D@/R`D9&YE7W)E<W5L="`Z("1S:&%R95]M87!;)'-H87)E7W5I9%T[
M"B`@("!]"@H@("`@9G5N8W1I;VX@<F5M;W9E36%P<&5D4VAA<F4H)B1S:&%R
M95]M87`L("1S:&%R95]U:60I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1S
M:&%R95]M87!;)'-H87)E7W5I9%TI*2!["B`@("`@("`@("`@('5N<V5T*"1S
M:&%R95]M87!;)'-H87)E7W5I9%TI.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%-Y;F-H<F]N:7-E<R!T:&4@4&5R;7,@;V8@82!(;W)D92!S
M:&%R92!T;R!T:&4@04-,(&]F(&%N($E-05`@9F]L9&5R+`H@("`@("H@8W)E
M871I;F<@=&AE(&9O;&1E<B!I9B!N96-E<W-A<GDN($ET(&%L<V\@<V5T<R!T
M:&4@;F5C97-S87)Y(&%N;F]T871I;VYS"B`@("`@*B!I;F1I8V%T:6YG('=H
M870@9W)O=7!W87)E(&9O<FUA="!T>7!E(&ES(&-O;G1A:6YE9"!W:71H:6X@
M=&AE(&9O;&1E<BP*("`@("`J(&%N9"!W:&%T($AO<F1E('-H87)E(&ET(&-O
M<G)E<W!O;F1S('1O+@H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W0@)&EM
M87`@("!!(')E9F5R96YC92!T;R!A($YE=%])34%0(&]B:F5C="!T:&%T(&ES
M(&%L<F5A9'D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T
M960@86YD(&%U=&AE;G1I8V%T960@=&\@=&AE(&-O<G)E8W0@<V5R=F5R+@H@
M("`@("H@0'!A<F%M(&]B:F5C="`D<VAA<F4@($$@<F5F97)E;F-E('1O('1H
M92!(;W)D92!S:&%R92!O8FIE8W0@=&AA="!W92!A<F4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!I;G1E<F5S=&5D(&EN+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D87!P7V-O;G-T<R`@02!R969E<F5N8V4@=&\@=&AE(')E<W5L
M="!O9B!A(&=E=$%P<$-O;G-T<R@I"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!C86QL(&9O<B!T:&4@8W5R<F5N="!(;W)D92!A<'!L:6-A
M=&EO;BX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!(;W)D92]+;VQA
M8B!I;G1E9W)A=&EO;BUS=7!P;W)T960@87!P+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<RP@82!014%27T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S>6YC:')O
M;FES95-H87)E*"8D:6UA<"P@)B1S:&%R92P@)B1A<'!?8V]N<W1S*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@:68@*&5M<'1Y*"1S
M:&%R92DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M7R@B26YV86QI9"!S:&%R92!O8FIE8W0B*2D["B`@("`@("`@?0H*("`@("`@
M("`D<VAA<F5?=6ED(#T@)'-H87)E+3YG971.86UE*"D["B`@("`@("`@)&]W
M;F5R(#T@)'-H87)E+3YG970H)V]W;F5R)RD["B`@("`@("`@)&1E9F%U;'0@
M/2`D<VAA<F5?=6ED(#T]("1O=VYE<CL*"B`@("`@("`@)&YD>"`]('-T<G!O
M<R@D;W=N97(L("=`)RD["B`@("`@("`@)'5S97(@/2`D;F1X(#T]/2!F86QS
M92`_("1O=VYE<B`Z('-U8G-T<B@D;W=N97(L(#`L("1N9'@I.PH@("`@("`@
M("1D;VUA:6X@/2!S=')S='(H)&]W;F5R+"`G0"<I.PH*("`@("`@("`D9F]L
M9&5R7W1Y<&4@/2`D87!P7V-O;G-T<ULG;6EM95]T>7!E7W-U9F9I>"==("X@
M*"1D969A=6QT(#\@)RYD969A=6QT)R`Z("<G*3L*("`@("`@("`D9F]L9&5R
M7VYA;64@/2`B=7-E<B\D=7-E<B\B("X@*"1D969A=6QT(#\@)&%P<%]C;VYS
M='-;)V1E9F%U;'1?9F]L9&5R7VYA;64G72`Z("1S:&%R92T^9V5T*"=N86UE
M)RDI("X@)&1O;6%I;CL*("`@("`@("`O+TMO;&%B.CIE;F-O9&5);6%P1F]L
M9&5R3F%M92@D9&5F875L="`_("1A<'!?8V]N<W1S6R=D969A=6QT7V9O;&1E
M<E]N86UE)UT@.B`D<VAA<F4M/F=E="@G;F%M92<I*3L*("`@("`@("!I9B`H
M:7-?82@D9F]L9&5R7VYA;64L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1F;VQD97)?;F%M93L*("`@("`@("!]"@H@("`@("`@("1S
M:&%R95]M87`@/2!+;VQA8CHZ9V5T4VAA<F5-87`H*3L*"B`@("`@("`@)&]L
M9%]F;VQD97(@/2!+;VQA8CHZ9V5T4VAA<F5-87!P:6YG*"1S:&%R95]M87`L
M("1S:&%R95]U:60I.PH*("`@("`@("`D<F5S=6QT(#T@)&EM87`M/FUA:6QB
M;WA%>&ES="@D9F]L9&5R7VYA;64I.PH@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@?0H*("`@("`@("!I9B`H)&9O;&1E<E]N86UE("$]("1O
M;&1?9F]L9&5R*2!["B`@("`@("`@("`@(&EF("@D<F5S=6QT("8F("1O;&1?
M9F]L9&5R*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BAS<')I;G1F*%\H(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E
M<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(I+"`D9F]L9&5R7VYA
M;64L("1O;&1?9F]L9&5R*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(&EF("@D;VQD7V9O;&1E<BD@>PH@("`@("`@("`@("`@("`@)')E<W5L="`]
M("1I;6%P+3YR96YA;65-86EL8F]X*"1O;&1?9F]L9&5R+"`D9F]L9&5R7VYA
M;64I.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V5I9B`H)')E
M<W5L="`]/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D
M:6UA<"T^8W)E871E36%I;&)O>"@D9F]L9&5R7VYA;64I.PH@("`@("`@("`@
M("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!'<F%N
M="!T:&4@0WER=7,@061M:6YI<W1R871O<B!C<F5A=&4@)B!D96QE=&4@86-C
M97-S("AN965D960*("`@("`@("`O+R!F;W(@=&AE(&%D;6EN=7-E<B!T;R!D
M96QE=&4@=&AE(&UA:6QB;W@@=VAE;B!R96UO=FEN9R!S:&%R97,I"B`@("`@
M("`@)')E<W5L="`]("1I;6%P+3YS971!0TPH)&9O;&1E<E]N86UE+"`D8V]N
M9ELG:V]L86(G75LG:6UA<"==6R=A9&UI;G5S97(G72P@)V-D)RD["B`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("1A8VP@
M/2!+;VQA8CHZ86-L5&]!<G)A>2@D:6UA<"T^9V5T04-,*"1F;VQD97)?;F%M
M92DI.PH@("`@("`@(&EF("AI<U]A*"1A8VPL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1A8VP["B`@("`@("`@?0H*("`@("`@("`D
M<&5R;2`]("8D<VAA<F4M/F=E=%!E<FUI<W-I;VXH*3L*("`@("`@("`D<&5R
M;5]L:7-T(#T@)'!E<FTM/F=E=%5S97)097)M:7-S:6]N<R@I.PH*("`@("`@
M("!F;W)E86-H("@D<&5R;5]L:7-T(&%S("1U<V5R(#T^("1U<V5R7W!E<FUS
M*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D:6UA<"T^<V5T04-,*"1F;VQD
M97)?;F%M92P@)'5S97(L($MO;&%B.CIP97)M<U1O06-L*"1U<V5R7W!E<FUS
M+"`D=7-E<B`]/2`D;W=N97(I*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@("`@('T*"B`@("`@("`@("`@('5N<V5T*"1A
M8VQ;)'5S97)=*3L*("`@("`@("!]"@H@("`@("`@("\O($UA:V4@<W5R92!W
M92!D;VXG="!D96QE=&4@=&AE(&-U<G)E;G0@=7-E<B!O<B!T:&4@0WER=7,*
M("`@("`@("`O+R!!9&UI;FES=')A=&]R(&9R;VT@=&AE(&9O;&1E<B=S($%#
M3"P@;W(@96QS92!W92=L;"!B92!L;V-K960@;W5T"B`@("`@("`@=6YS970H
M)&%C;%LD;W=N97)=*3L*("`@("`@("!U;G-E="@D86-L6R1C;VYF6R=K;VQA
M8B==6R=I;6%P)UU;)V%D;6EN=7-E<B==72D["@H@("`@("`@(&9O<F5A8V@@
M*"1A8VP@87,@)'5S97(@/3X@)'5S97)?86-L*2!["B`@("`@("`@("`@("1R
M97-U;'0@/2`D:6UA<"T^9&5L971E04-,*"1F;VQD97)?;F%M92P@)'5S97(I
M.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]("1I;6%P+3YS971!
M;FYO=&%T:6]N*$M/3$%"7T%.3D]47T9/3$1%4E]465!%+"!A<G)A>2@G=F%L
M=64N<VAA<F5D)R`]/B`D9F]L9&5R7W1Y<&4I+"`D9F]L9&5R7VYA;64I.PH@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`D
M<F5S=6QT(#T@)&EM87`M/G-E=$%N;F]T871I;VXH2T],04)?04Y.3U1?4TA!
M4D5?54E$+"!A<G)A>2@G=F%L=64N<VAA<F5D)R`]/B`D<VAA<F5?=6ED*2P@
M)&9O;&1E<E]N86UE*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@('T*"B`@("`@("`@2V]L86(Z.G5P9&%T94UA<'!E9%-H87)E*"1S:&%R
M95]M87`L("1S:&%R95]U:60L("1F;VQD97)?;F%M92D["B`@("`@("`@2V]L
M86(Z.G-E=%-H87)E36%P*"1S:&%R95]M87`I.PH*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!U<&1A=&53:&%R92@F)'-H87)E
M*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GDL("1N;W1I9FEC871I
M;VX["@H@("`@("`@("1A<'`@/2`D<F5G:7-T<GDM/F=E=$%P<"@I.PH@("`@
M("`@(&EF("AA<G)A>5]S96%R8V@H)&%P<"P@87)R87DH)VUN96UO)RP@)VYA
M9R<L("=T=7)B82<L("=K<F]N;VQI=&@G*2D@/3T](&9A;'-E*2!["B`@("`@
M("`@("`@(&EF("AE;7!T>2@D7U-%4U-)3TY;2T],04)?3$%35%]364Y#2$5$
M7T%04%TI*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)&%P<"`]("1?4T534TE/3EM+3TQ!0E],
M05-47U-93D-(141?05!073L*("`@("`@("!]"@H@("`@("`@("1A<'!?8V]N
M<W1S(#T@2V]L86(Z.F=E=$%P<$-O;G-T<R@D87!P*3L*("`@("`@("!I9B`H
M:7-?82@D87!P7V-O;G-T<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@
M2V]L86(Z.E]U<&1A=&53:&%R92@D<VAA<F4L("1A<'!?8V]N<W1S*3L*("`@
M("`@("`D:60@/2`D<VAA<F4M/F=E="@G;F%M92<I.PH@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(DAO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%P<%]C;VYS='-;)W-H
M87)E7VYA;64G72P@)&ED+"`D<F5S=6QT+3YG971-97-S86=E*"DI+"`G:&]R
M9&4N97)R;W(G*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]U<&1A=&53:&%R92@F)'-H87)E+"`F)&%P
M<%]C;VYS=',I"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@
M("`D:6UA<"`](&YE=R!.971?24U!4"@D8V]N9ELG:V]L86(G75LG:6UA<"==
M6R=S97)V97(G72P@)&-O;F9;)VMO;&%B)UU;)VEM87`G75LG<&]R="==*3L*
M"B`@("`@("`@)')E<W5L="`]("1I;6%P+3YL;V=I;B@D8V]N9ELG:V]L86(G
M75LG:6UA<"==6R=A9&UI;G5S97(G72P@)&-O;F9;)VMO;&%B)UU;)VEM87`G
M75LG861M:6YP=R==+"!F86QS92P@9F%L<V4I.PH@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@2V]L86(Z
M.G-Y;F-H<F]N:7-E4VAA<F4H)&EM87`L("1S:&%R92P@)&%P<%]C;VYS=',I
M.PH*("`@("`@("`D:6UA<"T^9&ES8V]N;F5C="@I.PH*("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@('T*"B`@("!F=6YC=&EO;B!R96UO=F53:&%R92@F
M)'-H87)E*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GDL("1N;W1I
M9FEC871I;VX["@H@("`@("`@("1A<'`@/2`D<F5G:7-T<GDM/F=E=$%P<"@I
M.PH*("`@("`@("`O+R!792!O;FQY(')E;6]V92!S:&%R97,@:68@2V]L86(@
M:6YT96=R871I;VX@:7,@96YA8FQE9"P@86YD(&EF('=E)W9E"B`@("`@("`@
M+R\@<')E=FEO=7-L>2!S>6YC:')O;FES960@=&AE('-H87)E<R!L:7-T("AI
M+F4N('=E(&MN;W<@=VAA="!)34%0"B`@("`@("`@+R\@9F]L9&5R(&-O<G)E
M<W!O;F1S('1O('1H92!G:79E;B!S:&%R92DN"B`@("`@("`@:68@*&5M<'1Y
M*"1'3$]"04Q36R=C;VYF)UU;)VMO;&%B)UU;)V5N86)L960G72D@?'P*("`@
M("`@("`@("`@*"%E;7!T>2@D7U-%4U-)3TY;2T],04)?3$%35%]364Y#2$5$
M7T%04%TI("8F"B`@("`@("`@("`@("`D7U-%4U-)3TY;2T],04)?3$%35%]3
M64Y#2$5$7T%04%T@(3T@)&%P<"DI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@)&%P<%]C;VYS=',@/2!+;VQA8CHZ
M9V5T07!P0V]N<W1S*"1A<'`I.PH@("`@("`@(&EF("AI<U]A*"1A<'!?8V]N
M<W1S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2!+;VQA8CHZ7W)E;6]V
M95-H87)E*"1S:&%R92D["B`@("`@("`@)&ED(#T@)'-H87)E+3YG970H)VYA
M;64G*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?
M*")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S
M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M87!P7V-O;G-T<ULG<VAA<F5?;F%M92==+"`D:60L("1R97-U;'0M/F=E=$UE
M<W-A9V4H*2DL("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T@96QS96EF("@D
M<F5S=6QT(#T]/2!T<G5E*2!["B`@("`@("`@("`@("1N;W1I9FEC871I;VXM
M/G!U<V@H<W!R:6YT9BA?*")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E
M;6]V960@)7,@7"(E<UPB(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D87!P7V-O;G-T<ULG<VAA<F5?;F%M92==+"`D:60I
M+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;6]V95-H87)E*"8D<VAA
M<F4I"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("!I9B`H
M96UP='DH)'-H87)E*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*"));G9A;&ED('-H87)E(&]B:F5C="(I*3L*("`@("`@("!]
M"@H@("`@("`@("1S:&%R95]U:60@/2`D<VAA<F4M/F=E=$YA;64H*3L*"B`@
M("`@("`@)'-H87)E7VUA<"`]($MO;&%B.CIG9713:&%R94UA<"@I.PH*("`@
M("`@("`D9F]L9&5R(#T@2V]L86(Z.F=E=%-H87)E36%P<&EN9R@D<VAA<F5?
M;6%P+"`D<VAA<F5?=6ED*3L*("`@("`@("!I9B`H96UP='DH)&9O;&1E<BDI
M('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@
M("`D:6UA<"`](&YE=R!.971?24U!4"@D8V]N9ELG:V]L86(G75LG:6UA<"==
M6R=S97)V97(G72P@)&-O;F9;)VMO;&%B)UU;)VEM87`G75LG<&]R="==*3L*
M"B`@("`@("`@)')E<W5L="`]("1I;6%P+3YL;V=I;B@D8V]N9ELG:V]L86(G
M75LG:6UA<"==6R=A9&UI;G5S97(G72P@)&-O;F9;)VMO;&%B)UU;)VEM87`G
M75LG861M:6YP=R==+"!F86QS92P@9F%L<V4I.PH@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@)&EM87`M
M/F1E;&5T94UA:6QB;W@H)&9O;&1E<BD["B`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("!]"@H@("`@("`@("1I;6%P+3YD:7-C;VYN96-T*"D[
M"@H@("`@("`@($MO;&%B.CIR96UO=F5-87!P9613:&%R92@D<VAA<F5?;6%P
M+"`D<VAA<F5?=6ED*3L*"B`@("`@("`@2V]L86(Z.G-E=%-H87)E36%P*"1S
M:&%R95]M87`I.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("!F
M=6YC=&EO;B!S>6YC:')O;FES95-H87)E<R@F)'-H87)E<RP@)&%P<"D*("`@
M('L*("`@("`@("!I9B`H96UP='DH)$=,3T)!3%-;)V-O;F8G75LG:V]L86(G
M75LG96YA8FQE9"==*2!\?`H@("`@("`@("`@("!A<G)A>5]S96%R8V@H)&%P
M<"P@87)R87DH)VUN96UO)RP@)VYA9R<L("=T=7)B82<L("=K<F]N;VQI=&@G
M*2D@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]
M"@H@("`@("`@("\O(%1U<F)A(&1O97-N)W0@=7-E('-H87)E<RP@<V\@=V4@
M:G5S="!C<F5A=&4@82!D=6UM>2!S:&%R92!L:7-T("8*("`@("`@("`O+R!D
M969A=6QT('-H87)E(&AE<F4@=&\@;6%K92!S=7)E('1H92!F;VQL;W=I;F<@
M8V]D92!W;W)K<RX*("`@("`@("!I9B`H96UP='DH)'-H87)E<RD@)B8@)&%P
M<"`]/2`G='5R8F$G*2!["B`@("`@("`@("`@("1S:&%R97,@/2`F2&]R9&5?
M4VAA<F4Z.G-I;F=L971O;B@D87!P*3L*"B`@("`@("`@("`@("1A<'!?8V]N
M<W1S(#T@2V]L86(Z.F=E=$%P<$-O;G-T<R@D87!P*3L*"B`@("`@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O261E;G1I='DN<&AP)SL*("`@("`@("`@
M("`@)&ED96YT:71Y(#T@)DED96YT:71Y.CIS:6YG;&5T;VXH*3L*("`@("`@
M("`@("`@)&YA;64@/2`D:61E;G1I='DM/F=E=%9A;'5E*"=F=6QL;F%M92<I
M.PH@("`@("`@("`@("!I9B`H=')I;2@D;F%M92D@/3T@)R<I('L*("`@("`@
M("`@("`@("`@("1N86UE(#T@075T:#HZ<F5M;W9E2&]O:RA!=71H.CIG971!
M=71H*"DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1S:&%R92`]("8D
M<VAA<F5S+3YN97=3:&%R92A!=71H.CIG971!=71H*"DI.PH@("`@("`@("`@
M("`D<VAA<F4M/G-E="@G;F%M92<L('-P<FEN=&8H)&%P<%]C;VYS='-;)V1E
M9F%U;'1?<VAA<F5?;F%M92==+"`D;F%M92DI.PH@("`@("`@("`@("`D<VAA
M<F5S+3YA9&13:&%R92@D<VAA<F4I.PH@("`@("`@('T*"B`@("`@("`@+R\@
M0VAE8VL@:68@=V4G=F4@86QR96%D>2!S>6YC:')O;FES960@=&AE($E-05`@
M9F]L9&5R(&QI<W0[(&EF('=E(&AA=F4*("`@("`@("`O+R!T:&5N(&5X:70@
M96%R;'DN($9O;&1E<B!S>6YC:')O;FES871I;VX@:7,@9&]N92!O;B!A<'!L
M:6-A=&EO;@H@("`@("`@("\O('-T87)T=7`@+2!T:&ES(&EN8VQU9&5S('-W
M:71C:&EN9R!B971W965N(&%P<&QI8V%T:6]N<R!A<R!W96QL(&%S"B`@("`@
M("`@+R\@=7!O;B!I;FET:6%L(&QO9VEN+@H@("`@("`@(&EF("@A96UP='DH
M)%]315-324].6TM/3$%"7TQ!4U1?4UE.0TA%1%]!4%!=*2`F)@H@("`@("`@
M("`@("`D7U-%4U-)3TY;2T],04)?3$%35%]364Y#2$5$7T%04%T@/3T@)&%P
M<"D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!G
M;&]B86P@)&YO=&EF:6-A=&EO;CL*"B`@("`@("`@)')E<W5L="`]($MO;&%B
M.CI?<WEN8VA3:&%R97,H)'-H87)E<RD["B`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D;F]T:69I8V%T
M:6]N+3YP=7-H*'-P<FEN=&8H7R@B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S
M>6YC:')O;FES92!S:&%R97,Z("5S(BDL("1R97-U;'0M/F=E=$UE<W-A9V4H
M*2DL("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%-Y;F-H<F]N:7-E<R!T:&4@24U!4"!F;VQD97(@;&ES="!A;F0@
M=&AE($AO<F1E('-H87)E(&QI<W0N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@5')U92!O;B!A('-U8V-E<W-F=6P@<WEN8VAR;VYI<V%T:6]N+"!F
M86QS92!W:&5N(&$*("`@("`J("`@("`@("`@("`@("`@('-Y;F-H<F]N:7-A
M=&EO;B!I<R!N;W0@<F5Q=6ER960@*&DN92X@;75L=&EP;&4@<&%G92!L;V%D
M<PH@("`@("H@("`@("`@("`@("`@("`@:6X@82!S:6YG;&4@87!P;&EC871I
M;VXI+"!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N"B`@("`@*B`@("`@("`@
M("`@("`@("!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<WEN8VA3
M:&%R97,H)B1S:&%R97,I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R
M>2P@)&-O;F8["@H@("`@("`@("1A<'`@/2`D<F5G:7-T<GDM/F=E=$%P<"@I
M.PH*("`@("`@("`O+R!/=&AE<G=I<V4@=V4@;F5E9"!T;R!M87`@=&AE(&-U
M<G)E;G0@24U!4"!F;VQD97(@;&ES="!T;R!T:&4*("`@("`@("`O+R!A<'!L
M:6-A=&EO;G,@<VAA<F4@;&ES="X*"B`@("`@("`@+R\@36%K92!S=7)E('1H
M:7,@:7,@8F5I;F<@8V%L;&5D(&9R;VT@82!K;F]W;B!A<'!L:6-A=&EO;@H@
M("`@("`@("1A<'!?8V]N<W1S(#T@2V]L86(Z.F=E=$%P<$-O;G-T<R@D87!P
M*3L*("`@("`@("!I9B`H:7-?82@D87!P7V-O;G-T<RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&%P<%]C;VYS=',["B`@("`@("`@
M?0H*("`@("`@("`O+R!#;VYN96-T('1O('1H92!)34%0('-E<G9E<@H@("`@
M("`@("1I;6%P(#T@;F5W($YE=%])34%0*"1C;VYF6R=K;VQA8B==6R=I;6%P
M)UU;)W-E<G9E<B==+"`D8V]N9ELG:V]L86(G75LG:6UA<"==6R=P;W)T)UTI
M.PH*("`@("`@("`O+R!,;V=I;B!U<VEN9R!T:&4@8W5R<F5N="!(;W)D92!C
M<F5D96YT:6%L<PH@("`@("`@("1C=7)R96YT7W5S97(@/2!!=71H.CIG971!
M=71H*"D["B`@("`@("`@)&YD>"`]('-T<G!O<R@D8W5R<F5N=%]U<V5R+"`G
M0"<I.PH@("`@("`@("1U<V5R(#T@)&YD>"`]/3T@9F%L<V4@/R`D8W5R<F5N
M=%]U<V5R(#H@<W5B<W1R*"1C=7)R96YT7W5S97(L(#`L("1N9'@I.PH@("`@
M("`@("1D;VUA:6X@/2!S=')S='(H)&-U<G)E;G1?=7-E<BP@)T`G*3L*("`@
M("`@("`D<F5S=6QT(#T@)&EM87`M/FQO9VEN*"1C=7)R96YT7W5S97(L($%U
M=&@Z.F=E=$-R961E;G1I86PH)W!A<W-W;W)D)RDL(&9A;'-E+"!F86QS92D[
M"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@
M("\O($]B=&%I;B!A(&QI<W0@;V8@86QL(&9O;&1E<G,@=&AE(&-U<G)E;G0@
M=7-E<B!H87,@86-C97-S('1O"B`@("`@("`@)&9O;&1E<E]L:7-T(#T@)&EM
M87`M/F=E=$UA:6QB;WAE<R@I.PH@("`@("`@(&EF("AI<U]A*"1F;VQD97)?
M;&ES="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&9O
M;&1E<E]L:7-T.PH@("`@("`@('T*"B`@("`@("`@+R\@5V4G<F4@;VYL>2!I
M;G1E<F5S=&5D(&EN('1H92!F;VQD97)S(&]F('1H92!S<&5C:69I8R!R97-O
M=7)C92!T>7!E"B`@("`@("`@+R\@9F]R('1H92!C=7)R96YT(&%P<&QI8V%T
M:6]N+"!S;R!F:6QT97(@;W5T('1H92!R97-T"B`@("`@("`@)&QO8V%L7V9O
M;&1E<G,@/2!A<G)A>2@I.PH@("`@("`@("1R96UO=&5?9F]L9&5R<R`](&%R
M<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&9O;&1E<E]L:7-T(&%S("1F;VQD
M97(I('L*("`@("`@("`@("`@)&%N;F]T871I;VX@/2`D:6UA<"T^9V5T06YN
M;W1A=&EO;BA+3TQ!0E]!3DY/5%]&3TQ$15)?5%E012P@)W9A;'5E+G-H87)E
M9"<L("1F;VQD97(I.PH@("`@("`@("`@("!I9B`H:7-?82@D86YN;W1A=&EO
M;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1A
M;FYO=&%T:6]N.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!)9B!T
M:&5R92!I<R!N;R!A;FYO=&%T:6]N('1H96X@=V4@=')E870@:70@87,@82!S
M=&%N9&%R9"!M86EL"B`@("`@("`@("`@("\O(&9O;&1E<B`H:2YE+B!W92!I
M9VYO<F4@:70I+@H@("`@("`@("`@("!I9B`H96UP='DH)&%N;F]T871I;VXI
M*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@+R\@268@=&AE(&9O;&1E<B!I<R!O9B!T:&4@8V]R<F5C
M="!T>7!E('1H96X@=V4@861D(&ET('1O(&]U<B!L:7-T"B`@("`@("`@("`@
M("\O(&]F(&9O;&1E<G,@=&AA="!S:&]U;&0@8V]R<F5S<&]N9"!T;R!A('-H
M87)E+B!(97)E('=E(&=E="!A;GD*("`@("`@("`@("`@+R\@;W1H97(@861D
M:71I;VYA;"!I;F9O<FUA=&EO;B!W92!M87D@;F5E9"P@<W5C:"!A<R!W:&5T
M:&5R('1H90H@("`@("`@("`@("`O+R!F;VQD97(@=V%S('!R979I;W5S;'D@
M;6%P<&5D('1O(&$@<VAA<F4L(&ET<R!!0TPL(&ET<R!O=VYE<B`H:68*("`@
M("`@("`@("`@+R\@:70@:7,@82!S:&%R960@9F]L9&5R*2!A;F0@:71S(&1I
M<W!L87D@;F%M92X*("`@("`@("`@("`@)'1Y<&4@/2!E>'!L;V1E*"<N)RP@
M)&%N;F]T871I;VXI.PH@("`@("`@("`@("!I9B`H)'1Y<&5;,%T@/3T@)&%P
M<%]C;VYS='-;)VUI;65?='EP95]S=69F:7@G72D@>PH@("`@("`@("`@("`@
M("`@)&%C;"`]($MO;&%B.CIA8VQ4;T%R<F%Y*"1I;6%P+3YG971!0TPH)&9O
M;&1E<BDI.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)&%C;"P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D86-L.PH@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\O(%-K:7`@=&AE
M($-Y<G5S($%D;6EN:7-T<F%T;W(*("`@("`@("`@("`@("`@('5N<V5T*"1A
M8VQ;)&-O;F9;)VMO;&%B)UU;)VEM87`G75LG861M:6YU<V5R)UU=*3L*"B`@
M("`@("`@("`@("`@("`D<VAA<F5?=6ED(#T@)&EM87`M/F=E=$%N;F]T871I
M;VXH2T],04)?04Y.3U1?4TA!4D5?54E$+"`G=F%L=64N<VAA<F5D)RP@)&9O
M;&1E<BD["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D<VAA<F5?=6ED+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1S
M:&%R95]U:60["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M<')E9U]M871C:"@B.RA)3D)/6'QU<V5R+RA;7B]=*RDI+RA;7D!=*RDH0"XJ
M*3\[(BP@)&9O;&1E<BP@)&UA=&-H97,I.PH*("`@("`@("`@("`@("`@("1D
M969A=6QT(#T@*"%E;7!T>2@D='EP95LQ72D@)B8@)'1Y<&5;,5T@/3T@)V1E
M9F%U;'0G*3L*"B`@("`@("`@("`@("`@("!I9B`H)&UA=&-H97-;,5T@/3T@
M)TE.0D]8)RD@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D9&5F875L="D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E
M+TED96YT:71Y+G!H<"<["B`@("`@("`@("`@("`@("`@("`@("`@("1I9&5N
M=&ET>2`]("9)9&5N=&ET>3HZ<VEN9VQE=&]N*"D["B`@("`@("`@("`@("`@
M("`@("`@("`@("1N86UE(#T@)&ED96YT:71Y+3YG971686QU92@G9G5L;&YA
M;64G*3L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*'1R:6TH)&YA;64I
M(#T]("<G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F%M92`]
M($%U=&@Z.G)E;6]V94AO;VLH)&-U<G)E;G1?=7-E<BD["B`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&YA;64@
M/2!S<')I;G1F*"1A<'!?8V]N<W1S6R=D969A=6QT7W-H87)E7VYA;64G72P@
M)&YA;64I.PH@("`@("`@("`@("`@("`@("`@("`@("`D9F]L9&5R(#T@)&%P
M<%]C;VYS='-;)V1E9F%U;'1?9F]L9&5R7VYA;64G73L*("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;F%M
M92`]("1F;VQD97(@/2!+;VQA8CHZ9&5C;V1E26UA<$9O;&1E<DYA;64H)&UA
M=&-H97-;,UTI.PH@("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("`@("`@("`@)&9O;&1E<B`](")U<V5R+R1U<V5R+R1F;VQD97(D9&]M86EN
M(CL*"B`@("`@("`@("`@("`@("`@("`@)&QO8V%L7V9O;&1E<G-;)&9O;&1E
M<ET@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)W-H87)E7W5I
M9"<@("`@(#T^("1S:&%R95]U:60L"B`@("`@("`@("`@("`@("`@("`@("`@
M("=A8VPG("`@("`@("`@("`]/B`D86-L+`H@("`@("`@("`@("`@("`@("`@
M("`@("`G;F%M92<@("`@("`@("`@/3X@)&YA;64L"B`@("`@("`@("`@("`@
M("`@("`@("`@("=D969A=6QT)R`@("`@("`]/B`D9&5F875L="P*("`@("`@
M("`@("`@("`@("`@("`I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`D=7-E<E]D;VUA:6X@/2!I<W-E="@D;6%T8VAE
M<ULT72D@/R`D;6%T8VAE<ULT72`Z("1D;VUA:6X["B`@("`@("`@("`@("`@
M("`@("`@)&9O;&1E<B`](&ES<V5T*"1M871C:&5S6S1=*2`_("1F;VQD97(@
M.B`D9F]L9&5R("X@)'5S97)?9&]M86EN.PH@("`@("`@("`@("`@("`@("`@
M("1O=VYE<B`]("1M871C:&5S6S)=("X@)'5S97)?9&]M86EN.PH@("`@("`@
M("`@("`@("`@("`@(&EF("@D9&5F875L="D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TED96YT:71Y+G!H<"<["B`@
M("`@("`@("`@("`@("`@("`@("`@("1I9&5N=&ET>2`]("9)9&5N=&ET>3HZ
M<VEN9VQE=&]N*"=N;VYE)RP@)&]W;F5R*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&YA;64@/2`D:61E;G1I='DM/F=E=%9A;'5E*"=F=6QL;F%M92<I
M.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H=')I;2@D;F%M92D@/3T@
M)R<I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE(#T@075T
M:#HZ<F5M;W9E2&]O:R@D;W=N97(I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1N86UE(#T@<W!R:6YT9B@D
M87!P7V-O;G-T<ULG9&5F875L=%]S:&%R95]N86UE)UTL("1N86UE*3L*("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D;F%M92`]($MO;&%B.CID96-O9&5);6%P1F]L9&5R3F%M92@D;6%T
M8VAE<ULS72D["B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@("`@("`D<F5M;W1E7V9O;&1E<G-;)&9O;&1E<ET@/2!A<G)A>2@*("`@
M("`@("`@("`@("`@("`@("`@("`@)W-H87)E7W5I9"<@("`@(#T^("1S:&%R
M95]U:60L"B`@("`@("`@("`@("`@("`@("`@("`@("=A8VPG("`@("`@("`@
M("`]/B`D86-L+`H@("`@("`@("`@("`@("`@("`@("`@("`G;F%M92<@("`@
M("`@("`@/3X@)&YA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("=D969A
M=6QT)R`@("`@("`]/B`D9&5F875L="P*("`@("`@("`@("`@("`@("`@("`@
M("`@)V]W;F5R)R`@("`@("`@(#T^("1O=VYE<BP*("`@("`@("`@("`@("`@
M("`@("`I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`O+R!792!N;W<@;6%P('1H92!R96UA:6YI;F<@9F]L
M9&5R(&QI<W0@=&\@=&AE(&-U<G)E;G0@87!P;&EC871I;VYS"B`@("`@("`@
M+R\@<VAA<F4@;&ES="P@=&\@<WEN8V@@2&]R9&4@=VET:"!O=&AE<B!+;VQA
M8B!C;&EE;G1S('1H870@;6%Y(&AA=F4*("`@("`@("`O+R!P<F5V:6]U<VQY
M(&UO9&EF:65D('1H92!G<F]U<'=A<F4@9F]L9&5R<PH*("`@("`@("`D:6UA
M<"T^9&ES8V]N;F5C="@I.PH@("`@("`@("1I;6%P(#T@;F5W($YE=%])34%0
M*"1C;VYF6R=K;VQA8B==6R=I;6%P)UU;)W-E<G9E<B==+"`D8V]N9ELG:V]L
M86(G75LG:6UA<"==6R=P;W)T)UTI.PH*("`@("`@("`D<F5S=6QT(#T@)&EM
M87`M/FQO9VEN*"1C;VYF6R=K;VQA8B==6R=I;6%P)UU;)V%D;6EN=7-E<B==
M+"`D8V]N9ELG:V]L86(G75LG:6UA<"==6R=A9&UI;G!W)UTL(&9A;'-E+"!F
M86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@
M("`@("`@("\O(%1/1$\Z('-E92!I9B!T:&5R92!I<R!A(&UO<F4@86-C=7)A
M=&4@=V%Y(&]F(&QI<W1I;F<@86QL('-H87)E<R!T:&%T"B`@("`@("`@+R\@
M87)E(&%C8V5S<VEB;&4L(')E9V%R9&QE<W,@;V8@=VAA="!P97)M:7-S:6]N
M<R!T:&4@=7-E<B!H87,@*&DN92X@:68*("`@("`@("`O+R!T:&4@=7-E<B!H
M87,@870@;&5A<W0@;VYE('!E<FUI<W-I;VX@;&5V96P@=&\@=&AE('-H87)E
M+"!T:&4@<VAA<F4*("`@("`@("`O+R!S:&]U;&0@8F4@:6X@;VYE(&]F('1H
M97-E(&QI<W1S*2X*("`@("`@("`D;&]C86Q?<VAA<F5S(#T@)'-H87)E<RT^
M;&ES=%-H87)E<R@D8W5R<F5N=%]U<V5R+"!015)-4U]32$]7+"`D8W5R<F5N
M=%]U<V5R*3L*("`@("`@("`D86QL7W-H87)E<R`]("1S:&%R97,M/FQI<W13
M:&%R97,H)&-U<G)E;G1?=7-E<BP@4$5235-?4TA/5RD["B`@("`@("`@)')E
M;6]T95]S:&%R97,@/2!A<G)A>5]D:69F7V%S<V]C*"1A;&Q?<VAA<F5S+"`D
M;&]C86Q?<VAA<F5S*3L*("`@("`@("!+;VQA8CHZ<V5T4VAA<F5-87`H87)R
M87DH*2D["B`@("`@("`@)'-H87)E7VUA<"`](&%R<F%Y*"D["@H@("`@("`@
M("\O($YO=R!S>6YC:')O;FES92!T:&4@9F]L9&5R(&QI<W0@=VET:"!T:&4@
M<VAA<F4@;&ES=`H@("`@("`@(&9O<F5A8V@@*"1L;V-A;%]F;VQD97)S(&%S
M("1F;VQD97(@/3X@)&%T=')S*2!["B`@("`@("`@("`@(&EF("AE;7!T>2@D
M871T<G-;)W-H87)E7W5I9"==*2D@>PH@("`@("`@("`@("`@("`@+R\@3F\@
M<VAA<F4@8V]R<F5S<&]N9',@=&\@=&AI<R!F;VQD97(L('-O(&-R96%T92!O
M;F4*("`@("`@("`@("`@("`@("1U:60@/2!E;7!T>2@D871T<G-;)V1E9F%U
M;'0G72D@/R!M9#4H;6EC<F]T:6UE*"DI(#H@)&-U<G)E;G1?=7-E<CL*("`@
M("`@("`@("`@("`@("1S:&%R92`]("8D<VAA<F5S+3YN97=3:&%R92@D=6ED
M*3L*("`@("`@("`@("`@("`@("1S:&%R92T^<V5T*"=N86UE)RP@)&%T=')S
M6R=N86UE)UTI.PH@("`@("`@("`@("`@("`@)'-H87)E<RT^861D4VAA<F4H
M)'-H87)E*3L*"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)&EM87`M/G-E
M=$%N;F]T871I;VXH2T],04)?04Y.3U1?4TA!4D5?54E$+"!A<G)A>2@G=F%L
M=64N<VAA<F5D)R`]/B`D=6ED*2P@)&9O;&1E<BD["B`@("`@("`@("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@2V]L86(Z.G5P9&%T94UA<'!E9%-H87)E*"1S
M:&%R95]M87`L("1U:60L("1F;VQD97(I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@+R\@3W1H97)W:7-E('1H97)E(&ES(&$@<VAA
M<F4@8V]R<F5S<&]N9&EN9R!T;R!T:&ES(&9O;&1E<@H@("`@("`@("`@("`@
M("`@:68@*"$D<VAA<F5S+3YE>&ES=',H)&%T=')S6R=S:&%R95]U:60G72DI
M('L*("`@("`@("`@("`@("`@("`@("`O+R!)9B!I="=S(&YO="!P<F5S96YT
M(&9O<B!W:&%T979E<B!R96%S;VXL(&-R96%T92!I=`H@("`@("`@("`@("`@
M("`@("`@("1S:&%R92`]("8D<VAA<F5S+3YN97=3:&%R92@D871T<G-;)W-H
M87)E7W5I9"==*3L*("`@("`@("`@("`@("`@("`@("`D<VAA<F4M/G-E="@G
M;F%M92<L("1A='1R<ULG;F%M92==*3L*("`@("`@("`@("`@("`@("`@("`D
M<VAA<F5S+3YA9&13:&%R92@D<VAA<F4I.PH@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`O+R!/=&AE<G=I<V4@8VAE8VL@
M=&AA="!I="!I<R!N86UE9"!C;W)R96-T;'D*("`@("`@("`@("`@("`@("`@
M("`D<VAA<F4@/2`F)&QO8V%L7W-H87)E<ULD871T<G-;)W-H87)E7W5I9"==
M73L*("`@("`@("`@("`@("`@("`@("!I9B`H)'-H87)E+3YG970H)VYA;64G
M*2`A/2`D871T<G-;)VYA;64G72D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D<VAA<F4M/G-E="@G;F%M92<L("1A='1R<ULG;F%M92==*3L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`@("`@2V]L86(Z.G5P9&%T94UA<'!E9%-H87)E*"1S:&%R95]M87`L("1A
M='1R<ULG<VAA<F5?=6ED)UTL("1F;VQD97(I.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`D8W5R<F5N=%]U<V5R<R`]("1S:&%R92T^;&ES=%5S97)S
M*"D["@H@("`@("`@("`@("`D<&5R;2`]("8D<VAA<F4M/F=E=%!E<FUI<W-I
M;VXH*3L*("`@("`@("`@("`@)&UU<W1?<V%V92`](&9A;'-E.PH*("`@("`@
M("`@("`@9F]R96%C:"`H)&%T=')S6R=A8VPG72!A<R`D=7-E<B`]/B`D86-L
M*2!["B`@("`@("`@("`@("`@("`D<&5R;7,@/2!+;VQA8CHZ86-L5&]097)M
M<R@D86-L*3L*("`@("`@("`@("`@("`@(&EF("@D<&5R;7,@(3T@)$=,3T)!
M3%-;)W!E<FUS)UTM/F=E=%!E<FUI<W-I;VYS*"1P97)M+"`D=7-E<BDI('L*
M("`@("`@("`@("`@("`@("`@("`D<&5R;2T^861D57-E<E!E<FUI<W-I;VXH
M)'5S97(L("1P97)M<RP@9F%L<V4I.PH@("`@("`@("`@("`@("`@("`@("1M
M=7-T7W-A=F4@/2!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)&YD>"`](&%R<F%Y7W-E87)C:"@D=7-E<BP@)&-U<G)E;G1?=7-E
M<G,I.PH@("`@("`@("`@("`@("`@:68@*"1N9'@@(3T](&9A;'-E*2!["B`@
M("`@("`@("`@("`@("`@("`@=6YS970H)&-U<G)E;G1?=7-E<G-;)&YD>%TI
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!F;W)E86-H("@D8W5R<F5N=%]U<V5R<R!A<R`D=7-E<BD@>PH@("`@("`@
M("`@("`@("`@:68@*"1'3$]"04Q36R=P97)M<R==+3YG971097)M:7-S:6]N
M<R@D<&5R;2P@)'5S97(I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@
M("`@("1P97)M+3YR96UO=F55<V5R4&5R;6ES<VEO;B@D=7-E<BP@4$5235-?
M04Q,+"!F86QS92D["B`@("`@("`@("`@("`@("`@("`@)&UU<W1?<V%V92`]
M('1R=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(&EF("@D;75S=%]S879E*2!["B`@("`@("`@("`@("`@("`D<VAA
M<F4M/G-E=%!E<FUI<W-I;VXH)'!E<FTL(&9A;'-E*3L*("`@("`@("`@("`@
M("`@("1S:&%R92T^<V%V92@I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1A='1R<ULG<VAA<F5?=6ED)UTI*2!["B`@("`@("`@
M("`@("`@("!U;G-E="@D;&]C86Q?<VAA<F5S6R1A='1R<ULG<VAA<F5?=6ED
M)UU=*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!U;G-E="@D
M;&]C86Q?<VAA<F5S6R1C=7)R96YT7W5S97)=*3L*"B`@("`@("`@+R\@57!D
M871E('-H87)E<R!T:&%T(&%R92!N;W0@;W=N960@8GD@=&AE(&-U<G)E;G0@
M=7-E<B`H;VYL>2!I9B!T:&5R90H@("`@("`@("\O(&%R92!S:&%R960@9F]L
M9&5R<R!A8V-E<W-I8FQE('1O('1H92!C=7)R96YT('5S97(I"B`@("`@("`@
M:68@*"%E;7!T>2@D<F5M;W1E7V9O;&1E<G,I*2!["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1R96UO=&5?9F]L9&5R<R!A<R`D9F]L9&5R(#T^("1A='1R<RD@
M>PH@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1A='1R<ULG<VAA<F5?=6ED
M)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)'5I9"`](&5M<'1Y*"1A='1R
M<ULG9&5F875L="==*2`_(&UD-2AM:6-R;W1I;64H*2D@.B`D871T<G-;)V]W
M;F5R)UT["B`@("`@("`@("`@("`@("`@("`@)'-H87)E(#T@)B1S:&%R97,M
M/FYE=U-H87)E*"1U:60I.PH@("`@("`@("`@("`@("`@("`@("1S:&%R92T^
M<V5T*"=O=VYE<B<L("1A='1R<ULG;W=N97(G72D["B`@("`@("`@("`@("`@
M("`@("`@)'-H87)E+3YS970H)VYA;64G+"`D871T<G-;)VYA;64G72D["B`@
M("`@("`@("`@("`@("`@("`@)'-H87)E<RT^861D4VAA<F4H)'-H87)E*3L*
M"B`@("`@("`@("`@("`@("`@("`@)')E<W5L="`]("1I;6%P+3YS971!;FYO
M=&%T:6]N*$M/3$%"7T%.3D]47U-(05)%7U5)1"P@87)R87DH)W9A;'5E+G-H
M87)E9"<@/3X@)'5I9"DL("1F;VQD97(I.PH@("`@("`@("`@("`@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@("`@("!+;VQA8CHZ=7!D871E36%P
M<&5D4VAA<F4H)'-H87)E7VUA<"P@)'5I9"P@)&9O;&1E<BD["B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF("@A)'-H
M87)E<RT^97AI<W1S*"1A='1R<ULG<VAA<F5?=6ED)UTI*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1S:&%R92`]("8D<VAA<F5S+3YN97=3:&%R92@D
M871T<G-;)W-H87)E7W5I9"==*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'-H87)E+3YS970H)V]W;F5R)RP@)&%T=')S6R=O=VYE<B==*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'-H87)E+3YS970H)VYA;64G+"`D871T<G-;
M)VYA;64G72D["B`@("`@("`@("`@("`@("`@("`@("`@("1S:&%R97,M/F%D
M9%-H87)E*"1S:&%R92D["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@5&AE('-H87)E(&5X:7-T<R!G
M;&]B86QL>2P@8G5T(&UA>2!N;W0@>65T(&)E(&QI<W1E9`H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H96UP='DH)')E;6]T95]S:&%R97-;)&%T=')S
M6R=S:&%R95]U:60G75TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<VAA<F4@/2`F)'-H87)E<RT^9V5T4VAA<F4H)&%T=')S6R=S:&%R95]U
M:60G72D["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<VAA<F4@/2`F)')E;6]T95]S:&%R
M97-;)&%T=')S6R=S:&%R95]U:60G75T["B`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1S:&%R92T^9V5T
M*"=N86UE)RD@(3T@)&%T=')S6R=N86UE)UTI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1S:&%R92T^<V5T*"=N86UE)RP@)&%T=')S6R=N86UE
M)UTI.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@("`@("!+;VQA8CHZ=7!D871E36%P
M<&5D4VAA<F4H)'-H87)E7VUA<"P@)&%T=')S6R=S:&%R95]U:60G72P@)&9O
M;&1E<BD["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)&-U
M<G)E;G1?=7-E<G,@/2`D<VAA<F4M/FQI<W15<V5R<R@I.PH*("`@("`@("`@
M("`@("`@("1P97)M(#T@)B1S:&%R92T^9V5T4&5R;6ES<VEO;B@I.PH@("`@
M("`@("`@("`@("`@)&UU<W1?<V%V92`](&9A;'-E.PH*("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1A='1R<ULG86-L)UT@87,@)'5S97(@/3X@)&%C;"D@
M>PH@("`@("`@("`@("`@("`@("`@("1P97)M<R`]($MO;&%B.CIA8VQ4;U!E
M<FUS*"1A8VPI.PH@("`@("`@("`@("`@("`@("`@(&EF("@D<&5R;7,@(3T@
M)$=,3T)!3%-;)W!E<FUS)UTM/F=E=%!E<FUI<W-I;VYS*"1P97)M+"`D=7-E
M<BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'!E<FTM/F%D9%5S97)0
M97)M:7-S:6]N*"1U<V5R+"`D<&5R;7,L(&9A;'-E*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&UU<W1?<V%V92`]('1R=64["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1N9'@@/2!A<G)A>5]S96%R
M8V@H)'5S97(L("1C=7)R96YT7W5S97)S*3L*("`@("`@("`@("`@("`@("`@
M("!I9B`H)&YD>"`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@=6YS970H)&-U<G)E;G1?=7-E<G-;)&YD>%TI.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D8W5R<F5N=%]U<V5R<R!A<R`D=7-E<BD@>PH@("`@("`@("`@
M("`@("`@("`@(&EF("@D1TQ/0D%,4ULG<&5R;7,G72T^9V5T4&5R;6ES<VEO
M;G,H)'!E<FTL("1U<V5R*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)'!E<FTM/G)E;6]V955S97)097)M:7-S:6]N*"1U<V5R+"!0
M15)-4U]!3$PL(&9A;'-E*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&UU
M<W1?<V%V92`]('1R=64["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("@D;75S=%]S879E*2![
M"B`@("`@("`@("`@("`@("`@("`@)'-H87)E+3YS971097)M:7-S:6]N*"1P
M97)M+"!F86QS92D["B`@("`@("`@("`@("`@("`@("`@)'-H87)E+3YS879E
M*"D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*"%E
M;7!T>2@D871T<G-;)W-H87)E7W5I9"==*2D@>PH@("`@("`@("`@("`@("`@
M("`@('5N<V5T*"1R96UO=&5?<VAA<F5S6R1A='1R<ULG<VAA<F5?=6ED)UU=
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+R\@1FEN86QL>2P@<F5M;W9E(&%N>2!E>'1R82!S:&%R97,@
M=V4@;6%Y(&AA=F4@*'1H97-E('=E<F4@;VYC92!F;VQD97)S"B`@("`@("`@
M+R\@=&AA="!W97)E('-U8G-E<75E;G1L>2!D96QE=&5D(&)Y(&%N;W1H97(@
M2V]L86(@8VQI96YT*2X@5&AI<R!I<R!O;FQY"B`@("`@("`@+R\@9&]N92!F
M;W(@<VAA<F5S('1H870@=&AE(&-U<G)E;G0@=7-E<B!O=VYS+"!I+F4N('-H
M87)E<R!T:&%T('=E<F4*("`@("`@("`O+R!S=6)F;VQD97)S(&]F('1H92!C
M=7)R96YT('5S97)S)R!)3D)/6"X*("`@("`@("!F;W)E86-H("@D;&]C86Q?
M<VAA<F5S(&%S("1S:&%R92D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@)'-H
M87)E<RT^<F5M;W9E4VAA<F4H)'-H87)E*3L*("`@("`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("\O($9O<B!R96UO=&4@<VAA<F5S+"!W92!S:6UP;'D@<F5M;W9E('1H
M92!C=7)R96YT('5S97(@9G)O;2!T:&4@<VAA<F5S"B`@("`@("`@+R\@<&5R
M;6ES<VEO;G,@;&ES="X*("`@("`@("!F;W)E86-H("@D<F5M;W1E7W-H87)E
M<R!A<R`D=6ED(#T^("1S:&%R92D@>PH@("`@("`@("`@("`D<&5R;2`]("8D
M<VAA<F4M/F=E=%!E<FUI<W-I;VXH*3L*("`@("`@("`@("`@)'!E<FTM/G)E
M;6]V955S97)097)M:7-S:6]N*"1C=7)R96YT7W5S97(L(%!%4DU37T%,3"P@
M9F%L<V4I.PH@("`@("`@("`@("`D<VAA<F4M/G-E=%!E<FUI<W-I;VXH)'!E
M<FTL(&9A;'-E*3L*("`@("`@("`@("`@)'-H87)E+3YS879E*"D["B`@("`@
M("`@?0H*("`@("`@("`O+R!!;F0@=V4G<F4@9&]N92$@1&ES8V]N;F5C="!F
M<F]M($E-05`L('-E="!T:&4@;&%S="!S>6YC:"=E9"!A<'`*("`@("`@("`O
M+R!F;&%G('1O('1H92!C=7)R96YT(&%P<&QI8V%T:6]N+"!A;F0@=7!D871E
M('1H92!S:&%R92!M87`N"B`@("`@("`@)&EM87`M/F1I<V-O;FYE8W0H*3L*
M"B`@("`@("`@)%]315-324].6TM/3$%"7TQ!4U1?4UE.0TA%1%]!4%!=(#T@
M)&%P<#L*("`@("`@("!+;VQA8CHZ<V5T4VAA<F5-87`H)'-H87)E7VUA<"D[
M"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@9W)O=7!W87)E('1Y<&4@;V8@=&AE(&=I=F5N($E-05`@
M9F]L9&5R+@H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W0@)&UA:6QB;W@@
M(%1H92!M86EL8F]X(&]F(&EN=&5R97-T+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@($$@<W1R:6YG(&EN9&EC871I;F<@=&AE(&=R;W5P=V%R92!T
M>7!E(&]F("1M86EL8F]X(&]R"B`@("`@*B`@("`@("`@("`@("`@("!B;V]L
M96%N(")F86QS92(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$UA:6QB;WA4>7!E*"1M86EL8F]X*0H@("`@>PH@("`@("`@(&=L;V)A;"`D
M8V]N9CL*"B`@("`@("`@)'1Y<&4@/2!F86QS93L*"B`@("`@("`@+R\@0V]N
M;F5C="!T;R!T:&4@24U!4"!S97)V97(*("`@("`@("`D:6UA<"`](&YE=R!.
M971?24U!4"@D8V]N9ELG:V]L86(G75LG:6UA<"==6R=S97)V97(G72P@)&-O
M;F9;)VMO;&%B)UU;)VEM87`G75LG<&]R="==*3L*"B`@("`@("`@+R\@3&]G
M:6X@=7-I;F<@=&AE(&-U<G)E;G0@2&]R9&4@8W)E9&5N=&EA;',*("`@("`@
M("`D<F5S=6QT(#T@)&EM87`M/FQO9VEN*$%U=&@Z.F=E=$%U=&@H*2P@075T
M:#HZ9V5T0W)E9&5N=&EA;"@G<&%S<W=O<F0G*2P@9F%L<V4L(&9A;'-E*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=5;F%B;&4@=&\@875T:&5N
M=&EC871E('=I=&@@=&AE($MO;&%B($E-05`@<V5R=F5R)RP@7U]&24Q%7U\L
M(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("`D:6UA<"T^
M9&ES8V]N;F5C="@I.PH@("`@("`@("`@("!R971U<FX@)'1Y<&4["B`@("`@
M("`@?0H*("`@("`@("`O+R!/8G1A:6X@=&AE(&=R;W5P=V%R92!A;FYO=&%T
M:6]N(&]F("1M86EL8F]X"B`@("`@("`@)&%N;F]T871I;VX@/2`D:6UA<"T^
M9V5T06YN;W1A=&EO;BA+3TQ!0E]!3DY/5%]&3TQ$15)?5%E012P@)W9A;'5E
M+G-H87)E9"<L("1M86EL8F]X*3L*("`@("`@("!I9B`H(6ES7V$H)&%N;F]T
M871I;VXL("=014%27T5R<F]R)RD@)B8@(65M<'1Y*"1A;FYO=&%T:6]N*2D@
M>PH@("`@("`@("`@("`D='EP92`](&5X<&QO9&4H)RXG+"`D86YN;W1A=&EO
M;BD["B`@("`@("`@("`@(&EF("@H(65M<'1Y*"1T>7!E6S%=*2`F)B`D='EP
M95LQ72`]/2`G9&5F875L="<I('Q\("AE;7!T>2@D='EP95LQ72DI*2!["B`@
M("`@("`@("`@("`@("`D='EP92`]("1T>7!E6S!=.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`D:6UA<"T^9&ES8V]N;F5C="@I.PH*("`@
M("`@("!R971U<FX@)'1Y<&4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FX@82!L:7-T(&]F(&%L;"!)34%0(&9O;&1E<G,@*&EN8VQU9&EN9R!T:&5I
M<B!G<F]U<'=A<F4@='EP92D@=&AA=`H@("`@("H@=&AE(&-U<G)E;G0@=7-E
M<B!H87,@86-C8V5S<R!T;RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!!;B!A<G)A>2!O9B!A<G)A>2@D9F]L9&5R;F%M92P@)&9O;&1E<G1Y<&4I
M(&ET96US("AE;7!T>0H@("`@("H@("`@("`@("`@("`@("`@;VX@97)R;W(I
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T1F]L9&5R<R@I"B`@("!["B`@
M("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("`D9F]L9&5R<R`](&%R<F%Y
M*"D["@H@("`@("`@("\O($-O;FYE8W0@=&\@=&AE($E-05`@<V5R=F5R"B`@
M("`@("`@)&EM87`@/2!N97<@3F5T7TE-05`H)&-O;F9;)VMO;&%B)UU;)VEM
M87`G75LG<V5R=F5R)UTL("1C;VYF6R=K;VQA8B==6R=I;6%P)UU;)W!O<G0G
M72D["@H@("`@("`@("\O($QO9VEN('5S:6YG('1H92!C=7)R96YT($AO<F1E
M(&-R961E;G1I86QS"B`@("`@("`@)')E<W5L="`]("1I;6%P+3YL;V=I;BA!
M=71H.CIG971!=71H*"DL($%U=&@Z.F=E=$-R961E;G1I86PH)W!A<W-W;W)D
M)RDL(&9A;'-E+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G
M92@G56YA8FQE('1O(&%U=&AE;G1I8V%T92!W:71H('1H92!+;VQA8B!)34%0
M('-E<G9E<B<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*
M("`@("`@("`@("`@)&EM87`M/F1I<V-O;FYE8W0H*3L*("`@("`@("`@("`@
M<F5T=7)N("1F;VQD97)S.PH@("`@("`@('T*"B`@("`@("`@+R\@3V)T86EN
M(&$@;&ES="!O9B!A;&P@9F]L9&5R<R!T:&4@8W5R<F5N="!U<V5R(&AA<R!A
M8V-E<W,@=&\*("`@("`@("`D9F]L9&5R7VQI<W0@/2`D:6UA<"T^9V5T36%I
M;&)O>&5S*"D["B`@("`@("`@:68@*&ES7V$H)&9O;&1E<E]L:7-T+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=5
M;F%B;&4@=&\@;V)T86EN($E-05`@9F]L9&5R(&QI<W0G+"!?7T9)3$5?7RP@
M7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@("1I;6%P+3YD
M:7-C;VYN96-T*"D["B`@("`@("`@("`@(')E='5R;B`D9F]L9&5R<SL*("`@
M("`@("!]"@H@("`@("`@("\O($ET97)A=&4@;W9E<B!A;&P@=&AE(&9O;&1E
M<G,@;V)T86EN:6YG('1H96ER(&=R;W5P=V%R92!T>7!E<PH@("`@("`@(&9O
M<F5A8V@@*"1F;VQD97)?;&ES="!A<R`D9F]L9&5R*2!["B`@("`@("`@("`@
M("1F;VQD97)T>7!E(#T@)VUA:6PG.PH*("`@("`@("`@("`@)&%N;F]T871I
M;VX@/2`D:6UA<"T^9V5T06YN;W1A=&EO;BA+3TQ!0E]!3DY/5%]&3TQ$15)?
M5%E012P@)W9A;'5E+G-H87)E9"<L("1F;VQD97(I.PH@("`@("`@("`@("!I
M9B`H(6ES7V$H)&%N;F]T871I;VXL("=014%27T5R<F]R)RD@)B8@(65M<'1Y
M*"1A;FYO=&%T:6]N*2D@>PH@("`@("`@("`@("`@("`@)'1Y<&4@/2!E>'!L
M;V1E*"<N)RP@)&%N;F]T871I;VXI.PH@("`@("`@("`@("`@("`@:68@*"@A
M96UP='DH)'1Y<&5;,5TI("8F("1T>7!E6S%=(#T]("=D969A=6QT)RD@?'P@
M*&5M<'1Y*"1T>7!E6S%=*2DI('L*("`@("`@("`@("`@("`@("`@("`D9F]L
M9&5R='EP92`]("1T>7!E6S!=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D9F]L9&5R<UM=(#T@87)R87DH)&9O;&1E
M<BP@)&9O;&1E<G1Y<&4I.PH@("`@("`@('T*"B`@("`@("`@)&EM87`M/F1I
M<V-O;FYE8W0H*3L*"B`@("`@("`@<F5T=7)N("1F;VQD97)S.PH@("`@?0H*
M("`@("\J*@H@("`@("H@5')I9V=E<G,@=&AE(&9R965B=7-Y('5P9&%T92!F
M;W(@=&AE(&=I=F5N('-H87)E('5I9"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@5')U92!I9B!U<&1A=&4@=V%S('-U8V-E<W-F=6QL+"!F86QS
M92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N('1R:6=G97)&<F5E
M0G5S>55P9&%T92@D<VAA<F5?=6ED*0H@("`@>PH@("`@("`@("1S:&%R95]M
M87`@/2!+;VQA8CHZ9V5T4VAA<F5-87`H*3L*("`@("`@("!I9B`H96UP='DH
M)'-H87)E7VUA<%LD<VAA<F5?=6ED72DI('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)&9O;&1E<E]P871H(#T@)'-H
M87)E7VUA<%LD<VAA<F5?=6ED73L*"B`@("`@("`@+R\@24U!4"!P871H(&ES
M(&5I=&AE<B`O24Y"3U@O/'!A=&@^0&1O;6%I;B!O<B`O=7-E<B]S;VUE;VYE
M+SQP871H/D!D;VUA:6X*("`@("`@("`O+R!S=')I<"!D;VUA:6X*("`@("`@
M("`D96YD(#T@<W1R<G!O<R@D9F]L9&5R7W!A=&@L("=`)RD["B`@("`@("`@
M)&9O;&1E<B`]('-U8G-T<B@D9F]L9&5R7W!A=&@L(#`L("1E;F0I.PH*("`@
M("`@("!I9B`H(21F;VQD97);,%T@/3T@)R\G*2!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@)'-E8V]N9%]S;&%S:"`]
M('-T<G!O<R@D9F]L9&5R+"`G+R<L(#$I.PH@("`@("`@(&EF("@D<V5C;VYD
M7W-L87-H(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H<W1R;F-M<"@D9F]L9&5R+"`G+TE.
M0D]8+R<L(#<I(#T](#`I('L*("`@("`@("`@("`@)&9O;&1E<B`]($%U=&@Z
M.F=E=$%U=&@H*2YS=6)S='(H)&9O;&1E<BP@)'-E8V]N9%]S;&%S:"D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&9O;&1E<B`]('-U8G-T<B@D
M9F]L9&5R+"`D<V5C;VYD7W-L87-H("L@,2D["B`@("`@("`@?0H@("`@("`@
M("1U<FP@/2`G:'1T<',Z+R\G("X@)$=,3T)!3%-;)V-O;F8G75LG:V]L86(G
M75LG:6UA<"==6R=S97)V97(G72`N("<O9G)E96)U<WDO=')I9V=E<B\G("X@
M)&9O;&1E<B`N("<N<&9B)SL*"B`@("`@("`@+R\@;F]W('-T87)T('1H92!R
M97%U97-T"B`@("`@("`@<F5Q=6ER95]O;F-E("=(5%10+U)E<75E<W0N<&AP
M)SL*("`@("`@("`D:'1T<"`](&YE=R!(5%107U)E<75E<W0H)'5R;"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)VUE=&AO9"<@
M/3X@)T=%5"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=T:6UE;W5T)R`]/B`U+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G86QL;W=2961I<F5C=',G(#T^('1R=64I*3L*("`@
M("`@("`D:'1T<"T^<V5T0F%S:6-!=71H*$%U=&@Z.F=E=$%U=&@H*2P@075T
M:#HZ9V5T0W)E9&5N=&EA;"@G<&%S<W=O<F0G*2D["@H@("`@("`@($`D:'1T
M<"T^<V5N9%)E<75E<W0H*3L*("`@("`@("!I9B`H)&AT='`M/F=E=%)E<W!O
M;G-E0V]D92@I("$](#(P,"D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T;R!T<FEG9V5R(&9R964O
M8G5S>2!U<&1A=&4@9F]R("5S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1E;6%I;"DI.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O3$1!4"YP:'``
M````````````````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U,3,S
M`#$P-3$U-#,S-S4R`#`R,#<Q-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@5&AI<R!I<R!A('5T:6QI
M='D@8VQA<W,L(&5V97)Y(&UE=&AO9"!I<R!S=&%T:6,N"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+TQ$05`O3$1!4"YP:'`L=B`Q+C4N,3(N,3`@,C`P-B\P
M,2\P,2`R,3HR.#HR,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM
M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,BXR"B`J($!P86-K86=E
M($AO<F1E7TQ$05`*("HO"F-L87-S($AO<F1E7TQ$05`@>PH*("`@("\J*@H@
M("`@("H@4F5T=7)N(&$@8F]O;&5A;B!E>'!R97-S:6]N('5S:6YG('1H92!S
M<&5C:69I960@;W!E<F%T;W(N"B`@("`@*@H@("`@("H@0'-T871I8PH@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&QH<R`@5&AE(&%T=')I8G5T92!T
M;R!T97-T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;W`@("!4:&4@;W!E<F%T
M;W(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1R:',@(%1H92!C;VUP87)I<V]N
M('9A;'5E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@3$1!
M4"!S96%R8V@@9G)A9VUE;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&)U:6QD
M0VQA=7-E*"1L:',L("1O<"P@)')H<RD*("`@('L*("`@("`@("!S=VET8V@@
M*"1O<"D@>PH@("`@("`@(&-A<V4@)TQ)2T4G.@H@("`@("`@("`@("!R971U
M<FX@96UP='DH)')H<RD@/PH@("`@("`@("`@("`@("`@<W!R:6YT9B@G*"5S
M/2HI)RP@)&QH<RD@.@H@("`@("`@("`@("`@("`@<W!R:6YT9B@G*"5S/2HE
M<RHI)RP@)&QH<RP@2&]R9&5?3$1!4#HZ<75O=&4H)')H<RDI.PH*("`@("`@
M("!D969A=6QT.@H@("`@("`@("`@("!R971U<FX@<W!R:6YT9B@G*"5S)7,E
M<RDG+"`D;&AS+"`D;W`L($AO<F1E7TQ$05`Z.G%U;W1E*"1R:',I*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!%<V-A<&4@8VAA<F%C=&5R
M<R!W:71H('-P96-I86P@;65A;FEN9R!I;B!,1$%0('-E87)C:&5S+@H@("`@
M("H*("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1C;&%U<V4@(%1H92!S=')I;F<@=&\@97-C87!E+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@97-C87!E9"!S=')I;F<N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('%U;W1E*"1C;&%U<V4I"B`@("!["B`@("`@("`@<F5T
M=7)N('-T<E]R97!L86-E*&%R<F%Y*"=<7"<L("`@)R@G+"`@)RDG+"`@)RHG
M+"`@(EPP(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=<
M7#5C)RP@)UPH)RP@)UPI)RP@)UPJ)RP@(EQ<,#`B*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&-L875S92D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!486ME(&%N(&%R<F%Y(&]F($1.(&5L96UE;G1S(&%N9"!P<F]P97)L>2!Q
M=6]T92!I="!A8V-O<F1I;F<@=&\@4D9#"B`@("`@*B`Q-#@U+@H@("`@("H*
M("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<G1S("!!;B!A<G)A>2!O9B!T=7!L97,@8V]N=&%I;FEN9R!T:&4@871T<FEB
M=71E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!N86UE(&%N9"!T:&%T
M(&%T=')I8G5T92=S('9A;'5E('=H:6-H(&UA:V4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@('5P('1H92!$3BX@17AA;7!L93H*("`@("`J"B`@("`@
M*B`@("`D<&%R=',@/2!A<G)A>2@P(#T^(&%R<F%Y*"=C;B<L("=*;VAN(%-M
M:71H)RDL"B`@("`@*B`@("`@("`@("`@("`@("`@("`Q(#T^(&%R<F%Y*"=D
M8R<L("=E>&%M<&QE)RDL"B`@("`@*B`@("`@("`@("`@("`@("`@("`R(#T^
M(&%R<F%Y*"=D8R<L("=C;VTG*2D["B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!P<F]P97)L>2!Q=6]T960@<W1R:6YG($1.+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!Q=6]T941.*"1P87)T<RD*("`@('L*("`@("`@("`D
M9&X@/2`G)SL*("`@("`@("`D8V]U;G0@/2!C;W5N="@D<&%R=',I.PH@("`@
M("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C;W5N=#L@)&DK*RD@>PH@("`@("`@
M("`@("!I9B`H)&D@/B`P*2!["B`@("`@("`@("`@("`@("`D9&X@+CT@)RPG
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1D;B`N/2`D<&%R='-;)&E=
M6S!=("X@)STG.PH*("`@("`@("`@("`@+R\@4V5E(&EF('=E(&YE960@=&\@
M<75O=&4@=&AE('9A;'5E+@H@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G
M+UY<<WQ<<R1\7'-<<WQ;+"L](EQR7&X\/B,[72\G+"`D<&%R='-;)&E=6S%=
M*2D@>PH@("`@("`@("`@("`@("`@)&1N("X]("<B)R`N('-T<E]R97!L86-E
M*"<B)RP@)UQ<(B<L("1P87)T<ULD:5U;,5TI("X@)R(G.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&1N("X]("1P87)T<ULD:5U;
M,5T["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M9&X["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]-86EN=&5N86YC92YP:'``````````````
M````````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-C,P,C8`,3`U,34T,S,W-3(`,#(R
M-#(V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"@HO*BH*("H@1&\@=&%S:R!Y96%R;'D@*$9I<G-T(&QO9VEN(&%F
M=&5R+V]N($IA;G5A<GD@,2DN"B`J+PID969I;F4H)TU!24Y414Y!3D-%7UE%
M05),62<L(#$I.PH*+RHJ"B`J($1O('1A<VL@;6]N=&AL>2`H1FER<W0@;&]G
M:6X@869T97(O;VX@9FER<W0@;V8@;6]N=&@I+@H@*B\*9&5F:6YE*"=-04E.
M5$5.04Y#15]-3TY42$Q9)RP@,BD["@HO*BH*("H@1&\@=&%S:R!W965K;'D@
M*$9I<G-T(&QO9VEN(&%F=&5R+V]N(&$@4W5N9&%Y*2X*("HO"F1E9FEN92@G
M34%)3E1%3D%.0T5?5T5%2TQ9)RP@,RD["@HO*BH*("H@1&\@=&%S:R!D86EL
M>2`H1FER<W0@;&]G:6X@;V8@=&AE(&1A>2DN"B`J+PID969I;F4H)TU!24Y4
M14Y!3D-%7T1!24Q9)RP@-"D["@HO*BH*("H@1&\@=&%S:R!E=F5R>2!L;V=I
M;BX*("HO"F1E9FEN92@G34%)3E1%3D%.0T5?159%4EDG+"`U*3L*"B\J*@H@
M*B!$;R!T87-K(&]N(&9I<G-T(&QO9VEN(&]N;'DN"B`J+PID969I;F4H)TU!
M24Y414Y!3D-%7T9)4E-47TQ/1TE.)RP@-BD["@HO*BH*("H@0V]N9FER;6%T
M:6]N+7-T>6QE(&]U='!U="!F;W(@;6%I;G1E;F%N8V4@<&%G92X*("HO"F1E
M9FEN92@G34%)3E1%3D%.0T5?3U544%547T-/3D9)4DTG+"`W*3L*"B\J*@H@
M*B!!9W)E96UE;G0M<W1Y;&4@;W5T<'5T(&9O<B!M86EN=&5N86YC92!P86=E
M+@H@*B\*9&5F:6YE*"=-04E.5$5.04Y#15]/5510551?04=2144G+"`X*3L*
M"B\J*@H@*B!.;W1I8V4M<W1Y;&4@;W5T<'5T(&9O<B!M86EN=&5N86YC92!P
M86=E+@H@*B\*9&5F:6YE*"=-04E.5$5.04Y#15]/5510551?3D]424-%)RP@
M.2D["@HO*BH*("H@5&AE(&YA;64@;V8@=&AE(%523"!P87)A;65T97(@=&AA
M="!I;F1I8V%T97,@=&AA="!T:&4@;6%I;G1E;F%N8V4@=&%S:W,@87)E"B`J
M(&-O;7!L971E9"X*("HO"F1E9FEN92@G34%)3E1%3D%.0T5?1$].15]005)!
M32<L("=M86EN=&5N86YC95]D;VYE)RD["@HO*B!);G1E<G9A;',@:&%S:"`M
M('5S960@=&\@8G5I;&0@<V5L96-T('1A8FQE<R!I;B!P<F5F97)E;F-E<R!M
M96YU+B`J+PHD:6YT97)V86QS(#T@87)R87DH*3L*)&EN=&5R=F%L<UM-04E.
M5$5.04Y#15]914%23%E=("`](%\H(EEE87)L>2(I.PHD:6YT97)V86QS6TU!
M24Y414Y!3D-%7TU/3E1(3%E=(#T@7R@B36]N=&AL>2(I.PHD:6YT97)V86QS
M6TU!24Y414Y!3D-%7U=%14M,65T@(#T@7R@B5V5E:VQY(BD["B1I;G1E<G9A
M;'-;34%)3E1%3D%.0T5?1$%)3%E=("`@/2!?*")$86EL>2(I.PHD:6YT97)V
M86QS6TU!24Y414Y!3D-%7T5615)972`@(#T@7R@B179E<GD@3&]G:6XB*3L*
M)$=,3T)!3%-;)VEN=&5R=F%L<R==(#T@)B1I;G1E<G9A;',["@HO*BH*("H@
M5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@<')O=FED97,@82!S970@;V8@;65T
M:&]D<R!F;W(@9&5A;&EN9R!W:71H"B`J(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@<G5N('5P;VX@;&]G:6X@=&\@2&]R9&4@87!P;&EC871I;VYS+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP
M:'`L=B`Q+C4R+C$P+C$S(#(P,#8O,#$O,#$@,C$Z,C@Z,C8@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS
M;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M
M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,2XS+C4*("H@0'!A
M8VMA9V4@2&]R9&5?36%I;G1E;F%N8V4*("HO"F-L87-S($UA:6YT96YA;F-E
M('L*"B`@("`O*BH*("`@("`J($AA<V@@:&]L9&EN9R!M86EN=&5N86YC92!P
M<F5F97)E;F-E(&YA;65S+@H@("`@("H@4WEN=&%X.B`@4%)%1DY!344@/3X@
M:6YT97)V86P*("`@("`J(%9A;&ED(&EN=&5R=F%L<R!A<F4Z($U!24Y414Y!
M3D-%7UE%05),62P@34%)3E1%3D%.0T5?34].5$A,62P*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@($U!24Y414Y!3D-%7U=%14M,62P@34%)3E1%3D%.
M0T5?1$%)3%DL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!-04E.5$5.
M04Y#15]%5D5262P@($U!24Y414Y!3D-%7T9)4E-47TQ/1TE."B`@("`@*B!/
M<&5R871I;VYS('=I;&P@8F4@<G5N(&EN('1H92!O<F1E<B!T:&5Y(&%P<&5A
M<B!I;B!T:&4@87)R87D@+0H@("`@("H@("!-04M%(%-54D4@1E5.0U1)3TY3
M($%212!)3B!42$4@0T]24D5#5"!/4D1%4B$*("`@("`J($]P97)A=&EO;G,@
M8V%N(&%P<&5A<B!M;W)E('1H86X@;VYC92`M('1H97D@=VEL;"!O;FQY(&)E
M(')U;B!O;F-E('!E<@H@("`@("H@("!L;V=I;B!T:&]U9V@@*'1H92!O<&5R
M871I;VX@=VEL;"!R=6X@=&AE(&9I<G-T('1I;64@:70@:7,@<V5E;B!I;@H@
M("`@("H@("!T:&4@87)R87DI+@H@("`@("H*("`@("`J(%1H:7,@87)R87D@
M<VAO=6QD(&)E(&9I;&QE9"!I;B!F;W(@96%C:"!(;W)D92!M;V1U;&4@=&AA
M="!E>'1E;F1S"B`@("`@*B`@('1H92!-86EN=&5N86YC92!C;&%S<RX*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D;6%I;G1?
M=&%S:W,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@54Y)6"!T:6UE<W1A
M;7`@;V8@=&AE(&QA<W0@;6%I;G1E;F%N8V4@<G5N(&9O<B!U<V5R+@H@("`@
M("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]L87-T
M4G5N(#T@,#L*"B`@("`O*BH*("`@("`J(%1H92!-86EN=&5N86YC95]487-K
M;&ES="!O8FIE8W0@9F]R('1H:7,@;&]G:6XN"B`@("`@*@H@("`@("H@0'9A
M<B!-86EN=&5N86YC95]487-K;&ES=`H@("`@("HO"B`@("!V87(@)%]T87-K
M;&ES=#L*"B`@("`O*BH*("`@("`J($%R<F%Y('1O('-T;W)E($UA:6YT96YA
M;F-E7U1A<VL@;V)J96-T<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D7W1A<VM#86-H92`](&%R<F%Y*"D["@H@("`@+RHJ
M"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!-86EN=&5N
M86YC95\J(&]B:F5C="!B87-E9"!O;B!T:&4@;6]D=6QE"B`@("`@*B!N86UE
M('!A<W-E9"!I;G1O(&ET+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&UO9'5L92`@5&AE(&YA;64@;V8@=&AE($AO<F1E(&UO9'5L92X*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86US("`@02!H87-H(&-O;G1A:6YI;F<@861D
M:71I;VYA;"!D871A(&YE961E9"!B>2!T:&4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@8V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0')E='5R
M;B!-86EN=&5N86YC92`@5&AE($UA:6YT96YA;F-E(&]B:F5C="P@;W(@9F%L
M<V4@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1M
M;V1U;&4L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&=L;V)A
M;"`D<F5G:7-T<GD["@H@("`@("`@("\J(%-P87=N('1H92!R96QE=F%N="!D
M<FEV97(L(&%N9"!R971U<FX@:70@*&]R(&9A;'-E(&]N(&9A:6QU<F4I+B`J
M+PH@("`@("`@(&EN8VQU9&5?;VYC92`D<F5G:7-T<GDM/F=E="@G9FEL97)O
M;W0G+"`D;6]D=6QE*2`N("<O;&EB+TUA:6YT96YA;F-E+R<@+B`D;6]D=6QE
M("X@)RYP:'`G.PH@("`@("`@("1C;&%S<R`]("=-86EN=&5N86YC95\G("X@
M)&UO9'5L93L*("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*
M("`@("`@("`@("`@)&UA:6YT96YA;F-E(#T@)FYE=R`D8VQA<W,H)'!A<F%M
M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&UA:6YT96YA;F-E
M(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&UA:6YT96YA
M;F-E.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN
M:6YG('1H92!F;VQL;W=I;F<@96YT<FEE<SH*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`G;&%S=%]M86EN=&5N86YC92<@/3X@5&AE(&QA<W0@=&EM
M92!M86EN=&5N86YC92!W87,@<G5N("AU;FEX('1I;65S=&%M<"DN"B`@("`@
M*B\*("`@(&9U;F-T:6]N($UA:6YT96YA;F-E*"1P87)A;7,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@("\J(%-E="!T:&4@8VQA<W,@=F%R:6%B;&4@)%]L
M87-T4G5N+B`J+PH@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=L87-T7VUA
M:6YT96YA;F-E)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?;&%S=%)U;B`]
M("1P87)A;7-;)VQA<W1?;6%I;G1E;F%N8V4G73L*("`@("`@("!]"@H@("`@
M("`@("1T:&ES+3Y?<F5T<FEE=F5487-K;&ES="@I.PH@("`@("`@("1T:&ES
M+3Y?<VAU=&1O=VXH*3L*("`@('T*"B`@("`O*BH*("`@("`J($1O(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@;F5E9&5D(&9O<B!T:&ES(&QO9VEN+B`@5&AI
M<R!F=6YC=&EO;@H@("`@("H@=VEL;"!G96YE<F%T92!T:&4@;&ES="!O9B!T
M87-K<R!T;R!P97)F;W)M(&1U<FEN9R!T:&ES(&QO9VEN"B`@("`@*B!A;F0@
M=VEL;"!R961I<F5C="!T;R!T:&4@;6%I;G1E;F%N8V4@<&%G92!I9B!N96-E
M<W-A<GDN("!4:&ES"B`@("`@*B!I<R!T:&4@9G5N8W1I;VX@=&AA="!S:&]U
M;&0@8F4@8V%L;&5D(&9R;VT@=&AE(&%P<&QI8V%T:6]N('5P;VX*("`@("`J
M(&QO9VEN+@H@("`@("HO"B`@("!F=6YC=&EO;B!R=6Y-86EN=&5N86YC92@I
M"B`@("!["B`@("`@("`@+RH@0VAE8VL@=&\@<V5E(&EF('=E(&%R92!F:6YI
M<VAE9"!W:71H(&UA:6YT96YA;F-E"B`@("`@("`@("H@;W!E<F%T:6]N<RX@
M*B\*("`@("`@("!I9B`H(55T:6PZ.F=E=$9O<FU$871A*$U!24Y414Y!3D-%
M7T1/3D5?4$%204TI*2!["B`@("`@("`@("`@("\J($1E=&5R;6EN92!I9B!W
M92!S:&]U;&0@<F5D:7)E8W0@=&\@=&AE(&UA:6YT96YA;F-E('!A9V4N("HO
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^7VYE961-86EN=&5N86YC95!A9V4H
M*2`A/3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@:&5A9&5R*"=,;V-A=&EO
M;CH@)R`N("1T:&ES+3Y?9V5T36%I;G1E;F%N8V554DPH*2P@=')U92D["B`@
M("`@("`@("`@("`@("!E>&ET.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`O*B!&:6YA;&QY+"!R=6X@86YY('1A<VMS('1H870@;F5E9"!T
M;R!B92!E>&5C=71E9"X@*B\*("`@("`@("`D=&AI<RT^7V1O36%I;G1E;F%N
M8V5487-K<R@I.PH@("`@?0H*("`@("\J*@H@("`@("H@1&\@=&AE(&YE8V5S
M<V%R>2!M86EN=&5N86YC92!T87-K<R!F;W(@=&AI<R!L;V%D:6YG(&]F('1H
M92!M86EN=&5N86YC90H@("`@("H@<&%G92X@(%1H:7,@:7,@=&AE(&9U;F-T
M:6]N('1H870@:7,@8V%L;&5D(&9R;VT@=&AE(&UA:6YT96YA;F-E('!A9V4*
M("`@("`J(&5V97)Y('1I;64@:70@:7,@;&]A9&5D+@H@("`@("H*("`@("`J
M($!R971U<FX@:6YT96=E<B`@5&AE(&1I<W!L87D@<F5Q=6ER960@9F]R('1H
M92!M86EN=&5N86YC92!P86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R=6Y-
M86EN=&5N86YC95!A9V4H*0H@("`@>PH@("`@("`@("\J(%-H;W5L9"!W92!R
M=6X@86YY('1A<VMS/R`J+PH@("`@("`@("1T:&ES+3Y?9&]-86EN=&5N86YC
M951A<VMS*"D["@H@("`@("`@("\J($=E="!T:&4@;&ES="!O9B!T87-K<R!W
M92!N965D('1O(&1I<W!L87D@=&\@=&AE('5S97(N("HO"B`@("`@("`@)'1A
M<VM?;F\@/2`D=&AI<RT^7VYE961-86EN=&5N86YC95!A9V4H*3L*("`@("`@
M("`D=&%S:W,@/2`D=&AI<RT^7W1A<VML:7-T+3YG971,:7-T*"D["@H@("`@
M("`@("\J(%)E;6]V92`G;F5W9FQA9R<@9G)O;2!F:7)S="!T87-K+B`J+PH@
M("`@("`@(&EF("@A)'1H:7,M/E]T87-K;&ES="T^<')O8V5S<V5D*'1R=64I
M*2!["B`@("`@("`@("`@(&EF("AC;W5N="@D=&%S:W,I*2!["B`@("`@("`@
M("`@("`@("!R97-E="@D=&%S:W,I.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]T87-K;&ES="T^<V5T3F5W4&%G92AK97DH)'1A<VMS*2P@9F%L<V4I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES7VYU;&PH
M)'1A<VM?;F\I*2!["B`@("`@("`@("`@("1T87-K<R`](&%R<F%Y7W-L:6-E
M*"1T87-K<RP@,"P@)'1A<VM?;F\@*R`Q*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("AC;W5N="@D=&%S:W,I*2!["B`@("`@("`@("`@(')E<V5T*"1T87-K
M<RD["B`@("`@("`@("`@("1A8W1I;VX@/2`D=&%S:W-;:V5Y*"1T87-K<RE=
M6R=D:7-P;&%Y)UT["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&%C
M=&EO;B`](&YU;&P["B`@("`@("`@?0H*("`@("`@("!R971U<FX@87)R87DH
M)&%C=&EO;BP@87)R87E?:V5Y<R@D=&%S:W,I*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE(&EN9F]R;6%T:6]N86P@=&5X="!M97-S86=E
M(&]N('=H870@=&AE(&]P97)A=&EO;B!I<PH@("`@("H@86)O=70@=&\@9&\N
M($%L<V\@:6YD:6-A=&5S('=H971H97(@=&AE(&)O>"!S:&]U;&0@8F4@8VAE
M8VME9`H@("`@("H@8GD@9&5F875L="!O<B!N;W0N($]P97)A=&EO;G,@=&AA
M="!H879E(&)E96X@;&]C:V5D(&)Y('1H90H@("`@("H@861M:6X@=VEL;"!R
M971U<FX@;G5L;"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<F5F
M("!.86UE(&]F('1H92!O<&5R871I;VX@=&\@9V5T(&EN9F]R;6%T:6]N(&9O
M<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("`Q<W0@96QE;65N="`M
M($1E<V-R:7!T:6]N(&]F('=H870@=&AE(&]P97)A=&EO;B!I<R!A8F]U=`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T;R!D;R!D=7)I
M;F<@=&AI<R!L;V=I;BX*("`@("`J("`@("`@("`@("`@("`@(#)N9"!E;&5M
M96YT("T@5VAE=&AE<B!T:&4@<')E9F5R96YC92!I<R!S970@=&\@;VX@;W(@
M;F]T+@H@("`@("HO"B`@("!F=6YC=&EO;B!I;F9O36%I;G1E;F%N8V4H)'!R
M968I"B`@("!["B`@("`@("`@9VQO8F%L("1P<F5F<SL*"B`@("`@("`@+RH@
M268@=&AE('!R969E<F5N8V4@:&%S(&)E96X@;&]C:V5D(&)Y('1H92!A9&UI
M;BP@9&\@;F]T('-H;W<*("`@("`@("`@("!T:&4@=7-E<BX@*B\*("`@("`@
M("!I9B`H)'!R969S+3YI<TQO8VME9"@D<')E9BDI('L*("`@("`@("`@("`@
M<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)&UO9"`]("8D=&AI<RT^7VQO
M861-;V1U;&4H)'!R968I.PH@("`@("`@(')E='5R;B!A<G)A>2@D;6]D+3YD
M97-C<FEB94UA:6YT96YA;F-E*"DL("1P<F5F<RT^9V5T5F%L=64H)'!R968I
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($5X<&]R="!V87)I86)L92!N86UE
M<R!T;R!U<V4@9F]R(&-R96%T:6YG('-E;&5C="!T86)L97,@:6X@=&AE"B`@
M("`@*B!P<F5F97)E;F-E<R!M96YU+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@($%N(&%R<F%Y(&]F('9A<FEA8FQE(&YA;65S('1O(&)E(&EM<&]R
M=&5D(&EN=&\@=&AE"B`@("`@*B`@("`@("`@("`@("`@("!P<F5F<RYP:'`@
M;F%M97-P86-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>'!O<G1);G1E<G9A
M;%!R969S*"D*("`@('L*("`@("`@("!G;&]B86P@)'!R969S.PH*("`@("`@
M("`D<F5T=7)N7V%R<F%Y(#T@87)R87DH*3L*"B`@("`@("`@9F]R96%C:"`H
M87)R87E?:V5Y<R@D=&AI<RT^;6%I;G1?=&%S:W,I(&%S("1V86PI('L*("`@
M("`@("`@("`@:68@*"$D<')E9G,M/FES3&]C:V5D*"1V86P@+B`G7VEN=&5R
M=F%L)RDI('L*("`@("`@("`@("`@("`@("1R971U<FY?87)R87E;72`]("1V
M86P@+B`G7VEN=&5R=F%L7V]P=&EO;G,G.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)')E='5R;E]A<G)A>3L*("`@('T*"B`@
M("`O*BH*("`@("`J($]U='!U="!H:61D96X@9F]R(&5L96UE;G1S(&9O<B!T
M:&4@4$]35"!F;W)M('1O(&5N<W5R92!T:&4@8V%L;&EN9PH@("`@("H@<V-R
M:7!T(&AA<R!T:&4@<V%M92!03U-4(&5L96UE;G1S(&%S('=H96X@=&AE(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,*("`@("`J(&9I<G-T(')U;BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&9O<FT@9&%T82X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T4&]S=$1A=&$H*0H@("`@>PH@("`@("`@("1T
M97AT(#T@)R<["@H@("`@("`@(&EF("@H)&1A=&$@/2`D=&AI<RT^7W1A<VML
M:7-T+3YG9710;W-T1&%T82@I*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D
M9&%T82!A<R`D;F%M92`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("`D=&5X
M="`N/2`G/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB)R`N(&AT;6QS<&5C
M:6%L8VAA<G,H)&YA;64I("X@)R(@=F%L=64](B<@+B!H=&UL<W!E8VEA;&-H
M87)S*"1V86PI("X@)R(@+SXG("X@(EQN(CL*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1T97AT.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N('1H92!54DP@;F5E9&5D(&9O<B!T:&4@;6%I;G1E;F%N
M8V4@9F]R;2X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(%52
M3"!T;R!R961I<F5C="!T;RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T36%I
M;G1E;F%N8V5&;W)M55),*"D*("`@('L*("`@("`@(&EF("@D=&AI<RT^7VYE
M961-86EN=&5N86YC95!A9V4H*2`A/3T@;G5L;"D@>PH@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7V=E=$UA:6YT96YA;F-E55),*"D["B`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V=E=$EN:71I86Q086=E
M55),*"D["B`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S
M('1H92!L:7-T(&]F(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@=&AA="!A<F4@
M879A:6QA8FQE"B`@("`@*B!F;W(@=&AI<R!S97-S:6]N("AS=&]R960@:6X@
M82!-86EN=&5N86YC95]487-K;&ES="!O8FIE8W0I+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@4F5T=7)N<R!T<G5E(&EF(&QI<W0@=V%S(&-R96%T960N"B`@("`@*B`@
M("`@("`@("`@("`@("`@($9A;'-E(&EF(&YO="`H92YG+B!L:7-T(&%L<F5A
M9'D@97AI<W1S*2X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-R96%T951A<VM,
M:7-T*"D*("`@('L*("`@("`@("!G;&]B86P@)'!R969S.PH*("`@("`@("`O
M*B!#<F5A=&4@82!N97<@36%I;G1E;F%N8V5?5&%S:VQI<W0@;V)J96-T+B`J
M+PH@("`@("`@("1T:&ES+3Y?=&%S:VQI<W0@/2`F;F5W($UA:6YT96YA;F-E
M7U1A<VML:7-T*"D["@H@("`@("`@("\J($-R96%T92!T:6UE(&]B:F5C=',@
M9F]R('1O9&%Y)W,@9&%T92!A;F0@;&%S="!L;V=I;B!D871E+B`J+PH@("`@
M("`@("1L87-T7V1A=&4@/2!G971D871E*"1T:&ES+3Y?;&%S=%)U;BD["B`@
M("`@("`@)&-U<E]D871E("`](&=E=&1A=&4H*3L*"B`@("`@("`@+RH@1V\@
M=&AR;W5G:"!E86-H(&ET96T@:6X@)&UA:6YT7W1A<VMS(&%N9"!D971E<FUI
M;F4@:68@=V4@;F5E9"!T;PH@("`@("`@("`@(')U;B!I="!D=7)I;F<@=&AI
M<R!M86EN=&5N86YC92!R=6XN("HO"B`@("`@("`@9F]R96%C:"`H)'1H:7,M
M/FUA:6YT7W1A<VMS(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`O
M*B!3:VEP(&ET96T@:68@:70@86QR96%D>2!A<'!E87)S(&EN('1H92!T87-K
M<R!L:7-T+B`J+PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]T87-K;&ES="T^
M:6Y,:7-T*"1K97DI*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+RH@1&5T97)M:6YE('1H92!C;W)R
M96-T(&EN=&5R=F%L(&9O<B!T:&4@:71E;2X@*B\*("`@("`@("`@("`@:68@
M*"@D:6YT97)V86P@/2`D<')E9G,M/F=E=%9A;'5E*"1K97D@+B`G7VEN=&5R
M=F%L)RDI*2!["B`@("`@("`@("`@("`@("`D=F%L(#T@)&EN=&5R=F%L.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D861D5&%S:R`](&9A;'-E.PH*
M("`@("`@("`@("`@+RH@1DE24U0@3$]'24X@3U!%4D%424].4R`J+PH@("`@
M("`@("`@("`O*B!)9B`D7VQA<W12=6X@:7,@96UP='D@*#T@,"DL('1H:7,@
M:7,@=&AE(&9I<G-T('1I;64@=&AE('5S97(*("`@("`@("`@("`@("`@:&%S
M(&QO9V=E9"!I;BX@1&]N)W0@<G5N(&%N>2!O=&AE<B!M86EN=&5N86YC92!O
M<&5R871I;VYS(&]N"B`@("`@("`@("`@("`@('1H92!F:7)S="!L;V=I;BX@
M*B\*("`@("`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?;&%S=%)U;BDI('L*
M("`@("`@("`@("`@("`@(&EF("@D=F%L(#T]($U!24Y414Y!3D-%7T9)4E-4
M7TQ/1TE.*2!["B`@("`@("`@("`@("`@("`@("`@)&%D9%1A<VL@/2!T<G5E
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`O*B!914%23%E?3U!%4D%424].4R`J+PH@("`@("`@("`@("!E;'-E:68@
M*"@D=F%L(#T]($U!24Y414Y!3D-%7UE%05),62D@)B8*("`@("`@("`@("`@
M("`@("`@("`H)&-U<E]D871E6R=Y96%R)UT@/B`D;&%S=%]D871E6R=Y96%R
M)UTI*2!["B`@("`@("`@("`@("`@("`D861D5&%S:R`]('1R=64["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("\J($U/3E1(3%D@3U!%4D%424].4R`J
M+PH@("`@("`@("`@("!E;'-E:68@*"@D=F%L(#T]($U!24Y414Y!3D-%7TU/
M3E1(3%DI("8F"B`@("`@("`@("`@("`@("`@("`@*"@D8W5R7V1A=&5;)WEE
M87(G72`^("1L87-T7V1A=&5;)WEE87(G72D@?'P@*"1C=7)?9&%T95LG;6]N
M)UT@/B`D;&%S=%]D871E6R=M;VXG72DI*2!["B`@("`@("`@("`@("`@("`D
M861D5&%S:R`]('1R=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J
M(%=%14M,62!/4$52051)3TY3("HO"B`@("`@("`@("`@(&5L<V5I9B`H*"1V
M86P@/3T@34%)3E1%3D%.0T5?5T5%2TQ9*2`F)@H@("`@("`@("`@("`@("`@
M("`@("@H)&-U<E]D871E6R=W9&%Y)UT@/"`D;&%S=%]D871E6R=W9&%Y)UTI
M('Q\("@H=&EM92@I("T@-C`T.#`P*2`^("1T:&ES+3Y?;&%S=%)U;BDI*2![
M"B`@("`@("`@("`@("`@("`D861D5&%S:R`]('1R=64["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("\J($1!24Q9($]015)!5$E/3E,@*B\*("`@("`@
M("`@("`@96QS96EF("@H)'9A;"`]/2!-04E.5$5.04Y#15]$04E,62D@)B8*
M("`@("`@("`@("`@("`@("`@("`H*"1C=7)?9&%T95LG>65A<B==(#X@)&QA
M<W1?9&%T95LG>65A<B==*2!\?"`H)&-U<E]D871E6R=Y9&%Y)UT@/B`D;&%S
M=%]D871E6R=Y9&%Y)UTI*2D@>PH@("`@("`@("`@("`@("`@)&%D9%1A<VL@
M/2!T<G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!%5D5262!,
M3T=)3B!/4$52051)3TY3("HO"B`@("`@("`@("`@(&5L<V5I9B`H)'9A;"`]
M/2!-04E.5$5.04Y#15]%5D5262D@>PH@("`@("`@("`@("`@("`@)&%D9%1A
M<VL@/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("\J(%-K:7`@
M=&AE('1A<VL@:68@86YY(&]F('1H92!F;VQL;W=I;F<Z"B`@("`@("`@("`@
M("`@("L@5&AI<R!T87-K(&1O97,@;F]T(&YE960@=&\@8F4@<G5N(&EN('1H
M:7,@;&]G:6X*("`@("`@("`@("`@("`@*R!4:&ES('1A<VL@:7,@;F]T('-E
M="!I;B!T:&4@<')E9F5R96YC97,@*B\*("`@("`@("`@("`@:68@*"$D861D
M5&%S:R!\?"`A)'!R969S+3YG971686QU92@D:V5Y*2D@8V]N=&EN=64["@H@
M("`@("`@("`@("`O*B!,;V%D('1H92!T87-K(&UO9'5L92!N;W<N("HO"B`@
M("`@("`@("`@("1M;V0@/2`F)'1H:7,M/E]L;V%D36]D=6QE*"1K97DI.PH*
M("`@("`@("`@("`@+RH@1&5T97)M:6YE(&EF('1H:7,@=&%S:R!H87,@86QR
M96%D>2!B965N(&-O;F9I<FUE9"]S970@=FEA('-O;64*("`@("`@("`@("`@
M("`@<V]R="!O9B!A9&UI;B!S971T:6YG+B!!;'-O+"!I9B!T:&4@=7-E<B]A
M9&UI;B!H87,@<V5T('1H90H@("`@("`@("`@("`@("`G8V]N9FER;5]M86EN
M=&5N86YC92<@9FQA9RP@<VMI<"!C;VYF:7)M871I;VXN("HO"B`@("`@("`@
M("`@("1C;VYF:7)M960@/2!F86QS93L*("`@("`@("`@("`@:68@*"1P<F5F
M<RT^:7-,;V-K960H)&ME>2D@?'P*("`@("`@("`@("`@("`@("$D<')E9G,M
M/F=E=%9A;'5E*"=C;VYF:7)M7VUA:6YT96YA;F-E)RDI('L*("`@("`@("`@
M("`@("`@("1C;VYF:7)M960@/2!T<G5E.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`O*B!!9&0@=&AE('1A<VL@=&\@=&AE('1A<VML:7-T+B`J+PH@
M("`@("`@("`@("`D=&AI<RT^7W1A<VML:7-T+3YA9&1487-K*"1K97DL("1C
M;VYF:7)M960L("1M;V0M/F=E=$1I<W!L87E4>7!E*"DI.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($QO860@;6]D=6QE("AI9B!N;W0@86QR
M96%D>2!L;V%D960I+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UO9&YA;64@($YA;64@;V8@
M=&AE(&UO9'5L92!T;R!L;V%D+@H@("`@("H*("`@("`J($!R971U<FX@36%I
M;G1E;F%N8V5?5&%S:R`@02!R969E<F5N8V4@=&\@=&AE(')E<75E<W1E9"!M
M;V1U;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9?;&]A9$UO9'5L92@D;6]D
M;F%M92D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3Y?=&%S:T-A8VAE6R1M;V1N86UE72DI('L*
M("`@("`@("`@("`@:6YC;'5D95]O;F-E("1R96=I<W1R>2T^9V5T*"=F:6QE
M<F]O="<L("1T:&ES+3Y?=&%S:VQI<W0M/F=E=$UO9'5L92@I*2`N("<O;&EB
M+TUA:6YT96YA;F-E+U1A<VLO)R`N("1M;V1N86UE("X@)RYP:'`G.PH@("`@
M("`@("`@("`D8VQA<W,@/2`G36%I;G1E;F%N8V5?5&%S:U\G("X@)&UO9&YA
M;64["B`@("`@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]T87-K0V%C:&5;)&UO9&YA;65=(#T@
M)FYE=R`D8VQA<W,["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H
M(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(BDL
M("1C;&%S<RDI+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]T87-K0V%C:&5;
M)&UO9&YA;65=.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H92!54DP@
M9F]R('1H92!I;FET:6%L('!A9V4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!54DP@
M9F]R('1H92!I;FET:6%L('!A9V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G
M971);FET:6%L4&%G95523"@I"B`@("!["B`@("`@("`@<F5T=7)N(%5T:6PZ
M.F%D9%!A<F%M971E<B@D=&AI<RT^7W1A<VML:7-T+3YG971487)G970H*2P@
M87)R87DH34%)3E1%3D%.0T5?1$].15]005)!32`]/B`Q+"`G9&]M86EN=&5N
M86YC92<@/3X@,2DL(&YU;&PL(&9A;'-E*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($=E="!T:&4@55),(&9O<B!T:&4@;6%I;G1E;F%N8V4@<&%G92X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(%523"!F;W(@=&AE(&UA:6YT96YA;F-E('!A9V4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971-86EN=&5N86YC95523"@I"B`@
M("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@+RH@5V4@
M;F5E9"!T;R!P87-S('1H92!C86-H92!)1"!A;F0@)VUO9'5L92<@<&%R86UE
M=&5R<RX@*B\*("`@("`@("`D=7)L(#T@2&]R9&4Z.G5R;"@D<F5G:7-T<GDM
M/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`G+"!T<G5E*3L*("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R
M86UE=&5R*"1U<FPL(&%R<F%Y*"=M;V1U;&4G(#T^("1T:&ES+3Y?=&%S:VQI
M<W0M/F=E=$UO9'5L92@I+"`G9&]M86EN=&5N86YC92<@/3X@,2DL(&YU;&PL
M(&9A;'-E*3L*"B`@("`@("`@<F5T=7)N("1U<FP["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!296=I<W1E<B!T:&4@<VAU=&1O=VX@9G5N8W1I;VX@9F]R('-T
M;W)I;F<@=&AE(&UA:6YT96YA;F-E"B`@("`@*B!T87-K;&ES="X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@
M7W-H=71D;W=N*"D*("`@('L*("`@("`@("!R96=I<W1E<E]S:'5T9&]W;E]F
M=6YC=&EO;BAA<G)A>2@F)'1H:7,L("=?8V%C:&5487-K;&ES="<I*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($-A8VAE('1H92!M86EN=&5N86YC92!T87-K
M;&ES="!B971W965N('!A9V4@<F5Q=65S=',N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C86-H951A<VML
M:7-T*"D*("`@('L*("`@("`@("`D7U-%4U-)3TY;)VAO<F1E7VUA:6YT96YA
M;F-E7W1A<VML:7-T)UT@/2!S97)I86QI>F4H)'1H:7,M/E]T87-K;&ES="D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V97,@82!C86-H960@;6%I
M;G1E;F%N8V4@=&%S:VQI<W0@;W(@;6%K97,@<W5R92!O;F4@:7,*("`@("`J
M(&-R96%T960N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]R971R:65V951A<VML:7-T*"D*("`@('L*("`@
M("`@("!I9B`H:7-S970H)%]315-324].6R=H;W)D95]M86EN=&5N86YC95]T
M87-K;&ES="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W1A<VML:7-T(#T@
M=6YS97)I86QI>F4H)%]315-324].6R=H;W)D95]M86EN=&5N86YC95]T87-K
M;&ES="==*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^
M7V-R96%T951A<VML:7-T*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@17AE8W5T92!A;&P@8V]N9FER;65D('1A<VMS+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?9&]-
M86EN=&5N86YC951A<VMS*"D*("`@('L*("`@("`@("`D=&%S:W,@/2`D=&AI
M<RT^7W1A<VML:7-T+3YG971,:7-T*"D["@H@("`@("`@(&9O<F5A8V@@*"1T
M87-K<R!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@:68@*"1V86Q;
M)VYE=W!A9V4G72D@>PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?=&%S
M:VQI<W0M/G!R;V-E<W-E9"@I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]T87-K;&ES="T^<V5T3F5W4&%G92@D:V5Y+"!F86QS92D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@?2!E;'-E:68@*"1V86Q;)V-O;F9I<FUE9"==('Q\"B`@("`@("`@("`@
M("`@("`@("`@("!5=&EL.CIG971&;W)M1&%T82@D:V5Y("X@)U]C;VYF:7)M
M)RDI('L*("`@("`@("`@("`@("`@("\J(%!E<F9O<FT@;6%I;G1E;F%N8V4@
M:68@8V]N9FER;65D+B`J+PH@("`@("`@("`@("`@("`@)&UO9"`]("8D=&AI
M<RT^7VQO861-;V1U;&4H)&ME>2D["B`@("`@("`@("`@("`@("`D;6]D+3YD
M;TUA:6YT96YA;F-E*"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H
M:7,M/E]T87-K;&ES="T^<F5M;W9E5&%S:R@D:V5Y*3L*("`@("`@("!]"@H@
M("`@("`@("\J($EF('=E)W9E('-U8V-E<W-F=6QL>2!C;VUP;&5T960@979E
M<GD@=&%S:R!I;B!T:&4@;&ES="`H;W(*("`@("`@("`@*B!S:VEP<&5D(&ET
M*2P@<F5C;W)D(&YO=R!A<R!T:&4@;&%S="!T:6UE(&UA:6YT96YA;F-E('=A
M<PH@("`@("`@("`J(')U;BX@*B\*("`@("`@("!I9B`H(6-O=6YT*"1T:&ES
M+3Y?=&%S:VQI<W0M/F=E=$QI<W0H*2DI('L*("`@("`@("`@("`@)$=,3T)!
M3%-;)W!R969S)UTM/G-E=%9A;'5E*"=L87-T7VUA:6YT96YA;F-E)RP@=&EM
M92@I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$;R!A;GD@
M;V8@=&AE('1A<VMS(')E<75I<F4@=&AE(&UA:6YT96YA;F-E('!A9V4_"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E
M='5R;B!I;G1E9V5R("!4:&4@:V5Y(&]F('1H92!T87-K('1H870@<F5Q=6ER
M97,@=&AE(&UA:6YT96YA;F-E"B`@("`@*B`@("`@("`@("`@("`@("`@('!A
M9V4N(%)E='5R;G,@;G5L;"!I9B!T:&4@;6%I;G1E;F%N8V4@<&%G92!I<R!N
M;PH@("`@("H@("`@("`@("`@("`@("`@("!L;VYG97(@;F5E9&5D+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?;F5E9$UA:6YT96YA;F-E4&%G92@I"B`@("![
M"B`@("`@("`@)&D@/2`P.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?=&%S
M:VQI<W0M/F=E=$QI<W0H*2!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@
M("`@:68@*"1V86Q;)VYE=W!A9V4G72D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A96UP='DH
M)'9A;%LG<')O8V5S<R==*2`F)@H@("`@("`@("`@("`@("`@(55T:6PZ.F=E
M=$9O<FU$871A*"=D;VUA:6YT96YA;F-E)RDI('L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?=&%S:VQI<W0M/G-E=$YE=U!A9V4H)&ME>2P@=')U92D["B`@
M("`@("`@("`@("`@("!R971U<FX@)&D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&DK*SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!N=6QL.PH@
M("`@?0H*?0H*+RHJ"B`J(%1H92!-86EN=&5N86YC95]487-K;&ES=#HZ(&-L
M87-S(&ES('5S960@=&\@<W1O<F4@=&AE(&QI<W0@;V8@;6%I;G1E;F%N8V4*
M("H@=&%S:W,@=&AA="!N965D('1O(&)E(')U;B!D=7)I;F<@=&AI<R!L;V=I
M;BX*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%-L=7-A<GH@
M/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O
M<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A
M8VMA9V4@2&]R9&5?36%I;G1E;F%N8V4*("HO"F-L87-S($UA:6YT96YA;F-E
M7U1A<VML:7-T('L*"B`@("`O*BH*("`@("`J(%1H92!(;W)D92!M;V1U;&4@
M<G5N;FEN9R!T:&4@;6%I;G1E;F%N8V4@=&%S:W,N"B`@("`@*@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?;6]D=6QE.PH*("`@("\J
M*@H@("`@("H@5&AE(%523"!O9B!T:&4@=V5B('!A9V4@=&\@;&]A9"!A9G1E
M<B!M86EN=&5N86YC92!I<R!C;VUP;&5T92X*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]T87)G970["@H@("`@+RHJ"B`@
M("`@*B!03U-4(&1A=&$@9F]R('1H92!C86QL:6YG('-C<FEP="X*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!O<W1D871A
M.PH*("`@("\J*@H@("`@("H@5&AE(&QI<W0@;V8@=&%S:W,@=&\@<G5N(&1U
M<FEN9R!T:&ES(&QO9VEN+@H@("`@("H*("`@("`J($M%63H@("`@5&%S:R!N
M86UE"B`@("`@*B!604Q513H@($%R<F%Y(#T^("@*("`@("`J("`@("`@("`@
M("`G8V]N9FER;65D)R`@/3X@(&)O;VQE86XL"B`@("`@*B`@("`@("`@("`@
M)V1I<W!L87DG("`@(#T^("!I;G1E9V5R+`H@("`@("H@("`@("`@("`@("=N
M97=P86=E)R`@("`]/B`@8F]O;&5A;BP*("`@("`J("`@("`@("`@("`G<')O
M8V5S<R<@("`@/3X@(&)O;VQE86X*("`@("`J("`@("`@("`@*0H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?=&%S:W,@/2!A
M<G)A>2@I.PH*("`@("\J*@H@("`@("H@26YT97)N86P@9FQA9R!F;W(@861D
M5&%S:R@I+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@
M("!V87(@)%]A9&1&;&%G(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!(87,@
M=&AE('1A<VML:7-T(&)E96X@<')O8V5S<V5D('EE=#\*("`@("`J"B`@("`@
M*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?<')O8V5S<V5D(#T@
M9F%L<V4["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@36%I;G1E;F%N8V5?5&%S:VQI<W0H*0H@("`@>PH@("`@
M("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@("1T:&ES+3Y?;6]D=6QE
M(#T@)')E9VES=')Y+3YG971!<'`H*3L*("`@("`@("`D=&AI<RT^7W1A<F=E
M="`]($AO<F1E.CIS96QF57)L*'1R=64I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@061D<R!A('1A<VL@=&\@=&AE('1A<VML:7-T+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&ME>2`@("`@("`@(%1H92!N86UE(&]F('1H92!T
M87-K('1O('!E<F9O<FTN"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8V]N9FER
M;65D("!(87,@=&AE('1A<VL@8F5E;B!C;VYF:7)M960_"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D9&ES<&QA>2`@("!4:&4@9&ES<&QA>2!T>7!E(&]F('1H
M92!T87-K+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1487-K*"1K97DL("1C
M;VYF:7)M960L("1D:7-P;&%Y*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=&%S
M:W-;)&ME>5T@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3Y?=&%S:W-;)&ME
M>5U;)V-O;F9I<FUE9"==(#T@)&-O;F9I<FUE9#L*("`@("`@("`D=&AI<RT^
M7W1A<VMS6R1K97E=6R=D:7-P;&%Y)UT@/2`D9&ES<&QA>3L*"B`@("`@("`@
M:68@*"@D9&ES<&QA>2`]/2!-04E.5$5.04Y#15]/5510551?04=2144I('Q\
M"B`@("`@("`@("`@("@D9&ES<&QA>2`]/2!-04E.5$5.04Y#15]/5510551?
M3D]424-%*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W1A<VMS6R1K97E=6R=N
M97=P86=E)UT@/2!T<G5E.PH@("`@("`@("`@("`D=&AI<RT^7V%D9$9L86<@
M/2!F86QS93L*("`@("`@("!](&5L<V5I9B`H*"1C;VYF:7)M960@/3T@9F%L
M<V4I("8F("@A)'1H:7,M/E]A9&1&;&%G*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7W1A<VMS6R1K97E=6R=N97=P86=E)UT@/2!T<G5E.PH@("`@("`@("`@
M("`D=&AI<RT^7V%D9$9L86<@/2!T<G5E.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1T:&ES+3Y?=&%S:W-;)&ME>5U;)VYE=W!A9V4G72`](&9A
M;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE
M(&YE=W!A9V4@9FQA9R!F;W(@82!T87-K+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'1A<VL@(%1H92!N86UE(&]F('1H92!T87-K('1O(&%L=&5R
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FQA9R`@2&]W('1O('-E="!T:&4@
M9FQA9RX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T3F5W4&%G92@D=&%S:RP@
M)&9L86<I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YI;DQI<W0H)'1A<VLI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?=&%S:W-;)'1A<VM=6R=N97=P86=E
M)UT@/2`D9FQA9SL*("`@("`@("`@("`@)'1H:7,M/E]T87-K<ULD=&%S:UU;
M)W!R;V-E<W,G72`]("$D9FQA9SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!296UO=F5S('1H92!T87-K(&9R;VT@=&AE('1A<VML:7-T+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1A<VL@(%1H92!N86UE(&]F
M('1H92!T87-K('1O(&%L=&5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO
M=F5487-K*"1T87-K*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^:6Y,:7-T
M*"1T87-K*2D@>PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^7W1A<VMS6R1T
M87-K72D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@27,@=&AI
M<R!T87-K(&%L<F5A9'D@:6X@=&AE('1A<VML:7-T/PH@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'1A<VL@(%1H92!N86UE(&]F('1H92!T87-K+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!T:&4@=&%S
M:R!I<R!A;')E861Y(&EN('1H92!T87-K;&ES="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@:6Y,:7-T*"1T87-K*0H@("`@>PH@("`@("`@(')E='5R;B!I<W-E
M="@D=&AI<RT^7W1A<VMS6R1T87-K72D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@=&AE(&QI<W0@;V8@=&%S:W,N"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@5&AE(&QI<W0@;V8@=&%S:W,@=&AA="!S=&EL;"!N965D
M('1O(&)E(&1O;F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$QI<W0H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W1A<VMS.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N('1H92!(;W)D92!M;V1U;&4@=&AE('1A<VMS
M(&%R92!R=6YN:6YG('5N9&5R+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@2&]R9&4@;6]D=6QE(&YA;64N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$UO9'5L92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M;6]D=6QE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!03U-4
M(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(%!/4U0@
M9&%T82!F<F]M('1H92!I;FET:6%L(%523"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4&]S=$1A=&$H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7W!O<W1D871A.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!5
M4DP@;V8@=&AE('=E8B!P86=E('1O(&QO860@869T97(@;6%I;G1E;F%N8V4@
M:7,@8V]M<&QE=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!T87)G970@55),+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971487)G970H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W1A<F=E=#L*("`@('T*
M"B`@("`O*BH*("`@("`J(%-E=',O9&ES<&QA>7,@=&AE(&9L86<@=&\@<VAO
M=R!T:&%T('1A<VML:7-T(&AA<R!B965N('!R;V-E<W-E9"!A=`H@("`@("H@
M;&5A<W0@;VYC92X*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<V5T
M("!3970@=&AE(&9L86<_"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!(87,@=&AE('1A<VML:7-T(&)E96X@<')O8V5S<V5D(&)E9F]R93\*("`@
M("`J+PH@("`@9G5N8W1I;VX@<')O8V5S<V5D*"1S970@/2!F86QS92D*("`@
M('L*("`@("`@("`D<F5T=F%L=64@/2`D=&AI<RT^7W!R;V-E<W-E9#L*("`@
M("`@("!I9B`H)'-E="D@>PH@("`@("`@("`@("`D=&AI<RT^7W!R;V-E<W-E
M9"`]('1R=64["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5T=F%L=64[
M"B`@("!]"@I]"@HO*BH*("H@06)S=')A8W0@8VQA<W,@=&\@86QL;W<@9F]R
M(&UO9'5L87)I>F%T:6]N(&]F('-P96-I9FEC(&UA:6YT96YA8V4@=&%S:W,N
M"B`J"B`J($9O<B!T:&ES(&5X<&QA;F%T:6]N+"!T:&4@<W!E8VEF:6,@2&]R
M9&4@87!P;&EC871I;VX@>6]U('=A;G0@=&\@8W)E871E"B`J(&UA:6YT96YA
M;F-E(&%C=&EO;G,@9F]R('=I;&P@8F4@;&%B96QE9"!(3U)$14%04"X*("H*
M("H@5&\@861D(&$@;F5W(&UA:6YT96YA;F-E('1A<VLL('EO=2!N965D('1O
M(&1O('1H92!F;VQL;W=I;F<Z"B`J(%LQ72!!9&0@<')E9F5R96YC92!T;R`B
M2$]21$5!4%`O8V]N9FEG+W!R969S+G!H<"(@9FEL92X*("H@("`@("A4:&4@
M;F%M92!O9B!T:&ES('!R969E<F5N8V4@=VEL;"!B92!R969E<G)E9"!T;R!A
M<R!04D5&3D%-12D*("H@("`@(%1H:7,@<')E9F5R96YC92!S:&]U;&0@8F4@
M;V8@='EP92`G8VAE8VMB;W@G("AI+F4N(#$@/2!O;CL@,"`](&]F9BDN"B`J
M("`@("!;3W!T:6]N86PZ72`@061D(&$@<')E9F5R96YC92!I;B!P<F5F<RYP
M:'`@;V8@=&AE(&YA;64*("H@("`@("`@("`@("`@("`@("`G4%)%1DY!345?
M:6YT97)V86PG('1O(&%L;&]W('1H92!U<V5R('1O('-E="!T:&4@:6YT97)V
M86PN"B`J("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G('9A;'5E('-H;W5L
M9"!B92!S970@=&\@=&AE('9A;'5E<R!O9B!T:&4@:6YT97)V86P*("H@("`@
M("`@("`@("`@("`@("!C;VYS=&%N=',@86)O=F4N"B`J("`@("`@("`@("`@
M("`@("`@268@=&AI<R!P<F5F97)E;F-E(&1O97-N)W0@97AI<W0L('1H92!D
M969A=6QT(&EN=&5R=F%L"B`J("`@("`@("`@("`@("`@("`@=7-E9"!W:6QL
M(&)E('1H92!O;F4@=&AA="!A<'!E87)S(&EN("1M86EN=%]T87-K<RX*("H@
M6S)=($-R96%T92!A(&1I<F5C=&]R>2!N86UE9"`B2$]21$5!4%`O;&EB+TUA
M:6YT96YA;F-E(BX*("H@6S-=($-R96%T92!A(&-L87-S(&5N=&ET;&5D($UA
M:6YT96YA;F-E7TA/4D1%05!0('1H870@97AT96YD<R!T:&4*("H@("`@($UA
M:6YT96YA;F-E(&-L87-S+@H@*B`@("`@5&AI<R!C;&%S<R!S:&]U;&0@8V]N
M=&%I;B!O;FQY('1H92!A<'!L:6-A=&EO;B!S<&5C:69I8R!D969I;FET:6]N
M<R!O9@H@*B`@("`@)&UA:6YT7W1A<VMS("AS964@86)O=F4@9F]R(&1E<V-R
M:7!T:6]N*2X*("H@("`@(%-A=F4@=&AI<R!F:6QE(&%S(")(3U)$14%04"]L
M:6(O36%I;G1E;F%N8V4O2$]21$5!4%`N<&AP(BX*("H@6S1=($-R96%T92!A
M(&1I<F5C=&]R>2!T:71L960@(DA/4D1%05!0+VQI8B]-86EN=&5N86YC92]4
M87-K(BX*("H@6S5=($-R96%T92!M;V1U;&5S(&EN($A/4D1%05!0+VQI8B]-
M86EN=&5N86YC92]487-K(&YA;65D("=04D5&3D%-12YP:'`G"B`J("`@("!T
M:&%T(&5X=&5N9"!T:&4@36%I;G1E;F%N8V5?5&%S:R!C;&%S<RX*("H@("`@
M(%1H92!C;&%S<R!S:&]U;&0@8F4@;F%M960@36%I;G1E;F%N8V5?5&%S:U]0
M4D5&3D%-12X*("H@("`@(%1H92!C;&%S<R!S:&]U;&0@9&5C;&%R92!T:&4@
M9F]L;&]W:6YG('1W;R!M971H;V1S.@H@*B`@("`@("`G9&]-86EN=&5N86YC
M92<@+2!4:&ES(&ES('1H92!F=6YC=&EO;B!T:&%T(&ES(')U;B!T;R!D;R!T
M:&4*("H@("`@("`@("`@("`@("`@("`@("`@("`@<W!E8VEF:65D(&UA:6YT
M96YA;F-E(&]P97)A=&EO;BX*("H@("`@("`@)V1E<V-R:6)E36%I;G1E;F%N
M8V4G("T@5&AI<R!F=6YC=&EO;B!S971S('1H92!P<F5F97)E;F-E('1E>'0*
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@86YD('1E>'0@=&\@
M8F4@=7-E9"!O;B!T:&4@8V]N9FER;6%T:6]N"B`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('!A9V4N("!3:&]U;&0@<F5T=7)N(&$@9&5S8W)I
M<'1I;VX@;V8@=VAA=`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!Y;W5R("=D;TUA:6YT96YA;F-E)R!F=6YC=&EO;B!I<R!A8F]U="!T;R!D
M;RX*("H@("`@($YE:71H97(@9G5N8W1I;VX@<F5Q=6ER97,@86YY('!A<F%M
M971E<G,@<&%S<V5D(&EN+@H@*@H@*B!4:&5R92!A<F4@,R!D:69F97)E;G0@
M='EP97,@;V8@;6%I;G1E;F%N8V4@*'-E="!V:6$@)%]D:7-P;&%Y7W1Y<&4I
M.@H@*B!;,5T@34%)3E1%3D%.0T5?3U544%547T-/3D9)4DT*("H@("`@($5A
M8V@@;W5T<'5T(&9R;VT@9&5S8W)I8F5-86EN=&5N86YC92@I('=I;&P@:&%V
M92!A(&-H96-K8F]X(&%S<V]C:6%T960*("H@("`@('=I=&@@:70N($9O<B!E
M86-H(&-H96-K8F]X('-E;&5C=&5D+"!D;TUA:6YT96YA;F-E*"D@9F]R('1H
M870@=&%S:R!W:6QL"B`J("`@("!B92!R=6XN($UO<F4@=&AA;B`Q(&-O;F9I
M<FUA=&EO;B!M97-S86=E(&-A;B!B92!D:7-P;&%Y960@;VX@=&AE"B`J("`@
M("!M86EN=&5N86YC92!P86=E(&%T(&]N8V4N"B`J"B`J(%LR72!-04E.5$5.
M04Y#15]/5510551?04=2144*("H@("`@(%1H92!O=71P=70@9G)O;2!D97-C
M<FEB94UA:6YT96YA;F-E*"D@<VAO=6QD(&)E('1E>'0@87-K:6YG('1H92!U
M<V5R('1O"B`J("`@("!A9W)E92]D:7-A9W)E92!T;R!S<&5C:69I960@=&5R
M;7,N($EF("=Y97,G(&ES('-E;&5C=&5D+"!T:&4@4$]35`H@*B`@("`@=F%R
M:6%B;&4@)V%G<F5E)R!W:6QL(&)E('-E="X@268@)VYO)R!I<R!S96QE8W1E
M9"P@=&AE(%!/4U0@=F%R:6%B;&4*("H@("`@("=N;W1?86=R964G('=I;&P@
M8F4@<V5T+B!);B!E:71H97(@8V%S92P@9&]-86EN=&5N86YC92@I('=I;&P@
M04Q705E3(&)E"B`J("`@("!R=6XN"B`J("`@("`J(%1H:7,@<W1Y;&4@=VEL
M;"!B92!D:7-P;&%Y960@;VX@:71S(&]W;BP@<V5P87)A=&4@;6%I;G1E;F%N
M8V4@<&%G92X@*@H@*@H@*B!;,UT@34%)3E1%3D%.0T5?3U544%547TY/5$E#
M10H@*B`@("`@5&AE(&]U='!U="!F<F]M(&1E<V-R:6)E36%I;G1E;F%N8V4H
M*2!S:&]U;&0@8F4@86YY(&YO;BUI;G1E<F%C=&EV92!T97AT"B`J("`@("!D
M97-I<F5D+B!4:&5R92!W:6QL(&)E(&$@<VEN9VQE("=#;&EC:R!T;R!#;VYT
M:6YU92<@8G5T=&]N(&)E;&]W('1H:7,*("H@("`@('1E>'0N(&1O36%I;G1E
M;F%N8V4H*2!W:6QL($%,5T%94R!B92!R=6XN"B`J("`@("`J(%1H:7,@<W1Y
M;&4@=VEL;"!B92!D:7-P;&%Y960@;VX@:71S(&]W;BP@<V5P87)A=&4@;6%I
M;G1E;F%N8V4@<&%G92X@*@H@*@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V($UI
M8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@
M/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($AO
M<F1E(#$N,RXU"B`J($!P86-K86=E($AO<F1E7TUA:6YT96YA;F-E"B`J+PIC
M;&%S<R!-86EN=&5N86YC95]487-K('L*"B`@("`O*BH*("`@("`J(%1H92!S
M='EL92!O9B!T:&4@;6%I;G1E;F%N8V4@<&%G92!O=71P=70N"B`@("`@*B!0
M;W-S:6)L92!V86QU97,Z($U!24Y414Y!3D-%7T]55%!55%]#3TY&25)-+`H@
M("`@("H@("`@("`@("`@("`@("`@("!-04E.5$5.04Y#15]/5510551?04=2
M144L"B`@("`@*B`@("`@("`@("`@("`@("`@($U!24Y414Y!3D-%7T]55%!5
M5%].3U1)0T4*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@
M("`@=F%R("1?9&ES<&QA>5]T>7!E(#T@34%)3E1%3D%.0T5?3U544%547T-/
M3D9)4DT["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("HO"B`@
M("!F=6YC=&EO;B!-86EN=&5N86YC95]487-K*"D*("`@('L*("`@('T*"B`@
M("`O*BH*("`@("`J($1O(&UA:6YT96YA;F-E(&]P97)A=&EO;B`H:68@:70@
M:&%S(&)E96X@8V]N9FER;65D*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%=H971H97(@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;B!W87,@
M<W5C8V5S<V9U;"!O<@H@("`@("H@("`@("`@("`@("`@("`@("!N;W0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&1O36%I;G1E;F%N8V4H*0H@("`@>PH@("`@
M("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!D97-C<FEP=&EO;B!I;F9O<FUA=&EO;B!F;W(@=&AE(&UA:6YT96YA;F-E
M('!A9V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($1E<V-R:7!T
M:6]N('1H870@=VEL;"!B92!D:7-P;&%Y960@;VX@=&AE(&UA:6YT96YA;F-E
M"B`@("`@*B`@("`@("`@("`@("`@("`@8V]N9FER;6%T:6]N('!A9V4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&1E<V-R:6)E36%I;G1E;F%N8V4H*0H@("`@
M>PH@("`@("`@(')E='5R;B`G)SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE(&1E<VER960@;W5T<'5T('1Y<&4@9F]R('1H92!M86EN=&5N
M86YC92!P86=E+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@1&5S
M:7)E9"!O=71P=70@='EP92!F;W(@=&AE(&UA:6YT96YA;F-E(&-O;F9I<FUA
M=&EO;@H@("`@("H@("`@("`@("`@("`@("`@("!P86=E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971$:7-P;&%Y5'EP92@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?9&ES<&QA>5]T>7!E.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O365N=2YP:'``````````````````````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(T-C8Q`#$P-3$U-#,S-S4Q`#`R
M,3$Q,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`H*9&5F:6YE*"=(3U)$15]-14Y57U!/4U],05-4)RP@.3DY*3L*
M"F1E9FEN92@G2$]21$5?345.55]-05-+7TY/3D4G+"`@("`@,"D["F1E9FEN
M92@G2$]21$5?345.55]-05-+7TA%3%`G+"`@("`@,2D["F1E9FEN92@G2$]2
M1$5?345.55]-05-+7TQ/1TE.)RP@("`@,BD["F1E9FEN92@G2$]21$5?345.
M55]-05-+7U!21493)RP@("`@-"D["F1E9FEN92@G2$]21$5?345.55]-05-+
M7U!23T),14TG+"`@."D["F1E9FEN92@G2$]21$5?345.55]-05-+7T%,3"<L
M("`@("`Q-2D["@HO*BH*("H@5&AE($UE;G4Z.B!C;&%S<R!P<F]V:61E<R!S
M=&%N9&%R9&EZ960@;65T:&]D<R!F;W(@8W)E871I;F<@;65N=7,@:6X*("H@
M2&]R9&4@87!P;&EC871I;VYS+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]-96YU+G!H<"QV(#$N,S4N,BXQ,2`R,#`V+S`W+S(P(#`T
M.C,Q.C(W('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P
M-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I
M9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!H;W)D
M92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D
M95]&<F%M97=O<FL*("HO"F-L87-S($UE;G4@>PH*("`@("\J*@H@("`@("H@
M365N=2!A<G)A>2X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D7VUE;G4@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@36%S
M:R!D969I;FEN9R!W:&%T(&=E;F5R86P@2&]R9&4@;&EN:W,@87)E('-H;W=N
M(&EN('1H:7,@365N=2X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@
M("`J+PH@("`@=F%R("1?;6%S:SL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=&]R"B`@("`@*B\*("`@(&9U;F-T:6]N($UE;G4H)&UA<VL@/2!(3U)$15]-
M14Y57TU!4TM?04Q,*0H@("`@>PH@("`@("`@("\J($UE;G5I=&5M(&UA<VLN
M("HO"B`@("`@("`@)'1H:7,M/E]M87-K(#T@)&UA<VL["@H@("`@("`@("\J
M($QO8V%T:6]N(&]F('1H92!M96YU9FEL92X@*B\*("`@("`@("`D=&AI<RT^
M7VUE;G5F:6QE(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G9FEL97)O
M;W0G*2`N("<O8V]N9FEG+VUE;G4N<&AP)SL*("`@('T*"B`@("`O*BH*("`@
M("`J($%D9"!A;B!I=&5M('1O('1H92!M96YU(&%R<F%Y+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'5R;"`@("`@("`@4W1R:6YG(&-O;G1A:6YI
M;F<@=&AE('9A;'5E(&9O<B!T:&4@:'EP97)L:6YK+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=&5X="`@("`@("!3=')I;F<@8V]N=&%I;FEN9R!T:&4@;&%B
M96P@9F]R('1H:7,@;65N=0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I=&5M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:6-O;B`@("`@("!3
M=')I;F<@8V]N=&%I;FEN9R!T:&4@9FEL96YA;64@;V8@=&AE(&EM86=E"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&EC;VX@=&\@9&ES<&QA
M>2!F;W(@=&AI<R!M96YU(&ET96TN"B`@("`@*B!`<&%R86T@<W1R:6YG("1I
M8V]N7W!A=&@@($EF('1H92!I8V]N(&QI=F5S(&EN(&$@;F]N+61E9F%U;'0@
M9&ER96-T;W)Y+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!W
M:&5R92!I<R!I=#\*("`@("`J($!P87)A;2!S=')I;F<@)'1A<F=E="`@("`@
M268@=&AE(&QI;FL@;F5E9',@=&\@;W!E;B!I;B!A;F]T:&5R(&9R86UE(&]R
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@('=I;F1O=RP@=VAA
M="!I<R!I=',@;F%M93\*("`@("`J($!P87)A;2!S=')I;F<@)&]N8VQI8VL@
M("`@3VYC;&EC:R!J879A<V-R:7!T+"!I9B!D97-I<F5D+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D8VQA<W,@("`@("!#4U,@8VQA<W,@9F]R('1H92!M96YU
M(&ET96TN"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@:60@
M*$Y/5"!G=6%R86YT965D('1O(&)E(&%N(&%R<F%Y(&EN9&5X*2!O9B!T:&4*
M("`@("`J("`@("`@("`@("`@("`@("`@:71E;2!J=7-T(&%D9&5D('1O('1H
M92!M96YU+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&0H)'5R;"P@)'1E>'0L
M("1I8V]N(#T@)R<L("1I8V]N7W!A=&@@/2!N=6QL+`H@("`@("`@("`@("`@
M("`@("1T87)G970@/2`G)RP@)&]N8VQI8VL@/2!N=6QL+"`D8VQA<W,@/2!N
M=6QL*0H@("`@>PH@("`@("`@("1P;W,@/2!C;W5N="@D=&AI<RT^7VUE;G4I
M.PH@("`@("`@(&EF("@A)'!O<R!\?"`H)'!O<R`M(#$@(3T@;6%X*&%R<F%Y
M7VME>7,H)'1H:7,M/E]M96YU*2DI*2!["B`@("`@("`@("`@("1P;W,@/2!C
M;W5N="@D=&AI<RT^7VUE;G4I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/E]M96YU6R1P;W-=(#T*("`@("`@("`@("`@87)R87DH"B`@("`@("`@("`@
M("`@("`G=7)L)R`]/B`D=7)L+`H@("`@("`@("`@("`@("`@)W1E>'0G(#T^
M("1T97AT+`H@("`@("`@("`@("`@("`@)VEC;VXG(#T^("1I8V]N+`H@("`@
M("`@("`@("`@("`@)VEC;VY?<&%T:"<@/3X@)&EC;VY?<&%T:"P*("`@("`@
M("`@("`@("`@("=T87)G970G(#T^("1T87)G970L"B`@("`@("`@("`@("`@
M("`G;VYC;&EC:R<@/3X@)&]N8VQI8VLL"B`@("`@("`@("`@("`@("`G8VQA
M<W,G(#T^("1C;&%S<PH@("`@("`@("`@("`I.PH*("`@("`@("!R971U<FX@
M)'!O<SL*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!A;B!I=&5M('1O('1H
M92!M96YU(&%R<F%Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5R
M;"`@("`@("`@4W1R:6YG(&-O;G1A:6YI;F<@=&AE('9A;'5E(&9O<B!T:&4@
M:'EP97)L:6YK+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@("`@("!3
M=')I;F<@8V]N=&%I;FEN9R!T:&4@;&%B96P@9F]R('1H:7,@;65N=0H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("!I=&5M+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D:6-O;B`@("`@("!3=')I;F<@8V]N=&%I;FEN9R!T:&4@
M9FEL96YA;64@;V8@=&AE(&EM86=E"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EC;VX@=&\@9&ES<&QA>2!F;W(@=&AI<R!M96YU(&ET96TN
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1I8V]N7W!A=&@@($EF('1H92!I8V]N
M(&QI=F5S(&EN(&$@;F]N+61E9F%U;'0@9&ER96-T;W)Y+`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("!W:&5R92!I<R!I=#\*("`@("`J($!P
M87)A;2!S=')I;F<@)'1A<F=E="`@("`@268@=&AE(&QI;FL@;F5E9',@=&\@
M;W!E;B!I;B!A;F]T:&5R(&9R86UE(&]R"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@('=I;F1O=RP@=VAA="!I<R!I=',@;F%M93\*("`@("`J
M($!P87)A;2!S=')I;F<@)&]N8VQI8VL@("`@3VYC;&EC:R!J879A<V-R:7!T
M+"!I9B!D97-I<F5D+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VQA<W,@("`@
M("!#4U,@8VQA<W,@9F]R('1H92!M96YU(&ET96TN"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G1E9V5R("!4:&4@:60@*$Y/5"!G=6%R86YT965D('1O(&)E
M(&%N(&%R<F%Y(&EN9&5X*2!O9B!T:&4@:71E;0H@("`@("H@("`@("`@("`@
M("`@("`@("!J=7-T(&%D9&5D('1O('1H92!M96YU+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!A9&1!<G)A>2@D:71E;2D*("`@('L*("`@("`@("`D<&]S(#T@
M8V]U;G0H)'1H:7,M/E]M96YU*3L*("`@("`@("!I9B`H(21P;W,@?'P@*"1P
M;W,@+2`Q("$](&UA>"AA<G)A>5]K97ES*"1T:&ES+3Y?;65N=2DI*2D@>PH@
M("`@("`@("`@("`D<&]S(#T@8V]U;G0H)'1H:7,M/E]M96YU*3L*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3Y?;65N=5LD<&]S72`]("1I=&5M.PH*("`@
M("`@("!R971U<FX@)'!O<SL*("`@('T*"B`@("!F=6YC=&EO;B!S9710;W-I
M=&EO;B@D:60L("1P;W,I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7VUE;G5;)&ED72D@?'P@:7-S970H)'1H:7,M/E]M96YU6R1P;W-=*2D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("`D:71E;2`]("1T:&ES+3Y?;65N=5LD:61=.PH@("`@("`@('5N<V5T*"1T
M:&ES+3Y?;65N=5LD:61=*3L*("`@("`@("`D=&AI<RT^7VUE;G5;)'!O<UT@
M/2`D:71E;3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FX@=&AE('5N;W)D97)E9"!L:7-T(')E<')E<V5N=&EN
M9R!T:&4@;&ES="!O9B!M96YU(&ET96US+B!3='EL:6YG"B`@("`@*B!I<R!D
M;VYE('1H<F]U9V@@0U-3+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!!;B!U;F]R9&5R960@;&ES="!O9B!M96YU(&5L96UE;G1S('1H870@8V%N
M(&)E(&5N=&ER96QY"B`@("`@*B`@("`@("`@("`@("`@("`@<W1Y;&5D('=I
M=&@@0U-3+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H*0H@("`@>PH@
M("`@("`@(&=L;V)A;"`D8V]N9BP@)')E9VES=')Y+"`D<')E9G,["@H@("`@
M("`@("1G<F%P:&EC<R`]("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E
M)RD["B`@("`@("`@)&%P<"`]("1R96=I<W1R>2T^9V5T07!P*"D["@H@("`@
M("`@(&EF("@D=&AI<RT^7VUA<VL@(3T]($A/4D1%7TU%3E5?34%32U].3TY%
M*2!["B`@("`@("`@("`@("\J($%D9"!A;GD@8W5S=&]M(&UE;G4@:71E;7,N
M("HO"B`@("`@("`@("`@("1T:&ES+3YA9&13:71E3&EN:W,H*3L*"B`@("`@
M("`@("`@("\J($%D9"!A;GD@87!P(&UE;G4@:71E;7,N("HO"B`@("`@("`@
M("`@("1T:&ES+3YA9&1!<'!,:6YK<R@I.PH@("`@("`@('T*"B`@("`@("`@
M+RH@061D('-E='1I;F=S(&QI;FLN("HO"B`@("`@("`@:68@*"1T:&ES+3Y?
M;6%S:R`F($A/4D1%7TU%3E5?34%32U]04D5&4R`F)B`D=7)L(#T@2&]R9&4Z
M.F=E=%-E<G9I8V5,:6YK*"=O<'1I;VYS)RP@)&%P<"DI('L*("`@("`@("`@
M("`@)'1H:7,M/F%D9"@D=7)L+"!?*")?3W!T:6]N<R(I+"`G<')E9G,N<&YG
M)RP@)&=R87!H:6-S*3L*("`@("`@("!]"@H@("`@("`@("\J($%D9"!P<F]B
M;&5M(&QI;FLN("HO"B`@("`@("`@:68@*"1T:&ES+3Y?;6%S:R`F($A/4D1%
M7TU%3E5?34%32U]04D]"3$5-("8F("1P<F]B;&5M7VQI;FL@/2!(;W)D93HZ
M9V5T4V5R=FEC94QI;FLH)W!R;V)L96TG+"`D87!P*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^861D*"1P<F]B;&5M7VQI;FLL(%\H(E!R;V)L96TB*2P@)W!R
M;V)L96TN<&YG)RP@)&=R87!H:6-S*3L*("`@("`@("!]"@H@("`@("`@("\J
M($%D9"!H96QP(&QI;FLN("HO"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D
M92](96QP+G!H<"<["B`@("`@("`@:68@*"1T:&ES+3Y?;6%S:R`F($A/4D1%
M7TU%3E5?34%32U](14Q0("8F("1H96QP7VQI;FL@/2!(;W)D93HZ9V5T4V5R
M=FEC94QI;FLH)VAE;'`G+"`D87!P*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M861D*"1H96QP7VQI;FLL(%\H(DAE;'`B*2P@)VAE;'!?:6YD97@N<&YG)RP@
M)&=R87!H:6-S+"`G:&5L<"<L("=P;W!U<"AT:&ES+FAR968I.R!R971U<FX@
M9F%L<V4[)RD["B`@("`@("`@?0H*("`@("`@("`O*B!,;V=I;B],;V=O=70N
M("HO"B`@("`@("`@:68@*"1T:&ES+3Y?;6%S:R`F($A/4D1%7TU%3E5?34%3
M2U],3T=)3BD@>PH@("`@("`@("`@("`O*B!)9B!T:&4@<VED96)A<B!I<VXG
M="!A;'=A>7,@<VAO=VXL(&)U="!I<R!S;VUE=&EM97,*("`@("`@("`@("`@
M("H@<VAO=VXL('1H96X@;&]G;W5T(&QI;FMS('-H;W5L9"!B92!T;R!T:&4@
M<&%R96YT"B`@("`@("`@("`@("`J(&9R86UE+B`J+PH@("`@("`@("`@("`D
M875T:%]T87)G970@/2!N=6QL.PH@("`@("`@("`@("!I9B`H)&-O;F9;)VUE
M;G4G75LG86QW87ES)UT@?'P@)'!R969S+3YG971686QU92@G<VAO=U]S:61E
M8F%R)RDI('L*("`@("`@("`@("`@("`@("1A=71H7W1A<F=E="`]("=?<&%R
M96YT)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*$%U=&@Z.F=E
M=$%U=&@H*2D@>PH@("`@("`@("`@("`@("`@:68@*"1L;V=O=71?;&EN:R`]
M($AO<F1E.CIG971397)V:6-E3&EN:R@G;&]G;W5T)RP@)&%P<"P@(21P<F5F
M<RT^9V5T5F%L=64H)W-H;W=?<VED96)A<B<I*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YA9&0H)&QO9V]U=%]L:6YK+"!?*")?3&]G(&]U="(I
M+"`G;&]G;W5T+G!N9R<L("1G<F%P:&EC<RP@)&%U=&A?=&%R9V5T+"!N=6QL
M+"`G7U]N;W-E;&5C=&EO;B<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:68@*"1L;V=I;E]L:6YK
M(#T@2&]R9&4Z.F=E=%-E<G9I8V5,:6YK*"=L;V=I;B<L("1A<'`I*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/F%D9"@D;&]G:6Y?;&EN:RP@7R@B
M7TQO9R!I;B(I+"`G;&]G:6XN<&YG)RP@)&=R87!H:6-S+"`D875T:%]T87)G
M970L(&YU;&PL("=?7VYO<V5L96-T:6]N)RD["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($YO(&YE960@
M=&\@<F5T=7)N(&%N(&5M<'1Y(&QI<W0@:68@=&AE<F4@87)E(&YO(&UE;G4*
M("`@("`@("`@*B!I=&5M<RX@*B\*("`@("`@("!I9B`H(6-O=6YT*"1T:&ES
M+3Y?;65N=2DI('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*
M"B`@("`@("`@+RH@4V]R="!T;R!M871C:"!E>'!L:6-I=&QY('-E="!P;W-I
M=&EO;G,N("HO"B`@("`@("`@:W-O<G0H)'1H:7,M/E]M96YU*3L*("`@("`@
M("!I9B`H(65M<'1Y*"1'3$]"04Q36R=N;',G75LG<G1L)UU;)$=,3T)!3%-;
M)VQA;F=U86=E)UU=*2D@('L*("`@("`@("`@("`@)'1H:7,M/E]M96YU(#T@
M87)R87E?<F5V97)S92@D=&AI<RT^7VUE;G4I(#L*("`@("`@("!]"@H@("`@
M("`@("1M96YU7W9I97<@/2`D<')E9G,M/F=E=%9A;'5E*"=M96YU7W9I97<G
M*3L*("`@("`@("`D;W5T<'5T(#T@)SQU;#XG.PH@("`@("`@(&9O<F5A8V@@
M*"1T:&ES+3Y?;65N=2!A<R`D;2D@>PH@("`@("`@("`@("`O*B!)=&5M(&-L
M87-S(&%N9"!S96QE8W1E9"!I;F1I8V%T:6]N+B`J+PH@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1M6R=C;&%S<R==*2D@>PH@("`@("`@("`@("`@("`@+RH@
M5')Y('1O(&UA=&-H('1H92!I=&5M)W,@<&%T:"!A9V%I;G-T('1H92!C=7)R
M96YT"B`@("`@("`@("`@("`@("`@*B!S8W)I<'0@9FEL96YA;64@87,@=V5L
M;"!A<R!O=&AE<B!P;W-S:6)L92!54DQS('1O"B`@("`@("`@("`@("`@("`@
M*B!T:&ES('-C<FEP="X@*B\*("`@("`@("`@("`@("`@(&EF("A-96YU.CII
M<U-E;&5C=&5D*"1M6R=U<FPG72DI('L*("`@("`@("`@("`@("`@("`@("`D
M;5LG8VQA<W,G72`]("=C=7)R96YT)SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?2!E;'-E:68@*"1M6R=C;&%S<R==(#T]/2`G7U]N;W-E;&5C
M=&EO;B<I('L*("`@("`@("`@("`@("`@('5N<V5T*"1M6R=C;&%S<R==*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@26-O;BX@*B\*("`@("`@
M("`@("`@)&EC;VX@/2`G)SL*("`@("`@("`@("`@:68@*"1M96YU7W9I97<@
M/3T@)VEC;VXG('Q\("1M96YU7W9I97<@/3T@)V)O=&@G*2!["B`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1M6R=I8V]N7W!A=&@G72DI('L*("`@("`@
M("`@("`@("`@("`@("`D;5LG:6-O;E]P871H)UT@/2!N=6QL.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&EC;VX@/2!(;W)D93HZ:6UG
M*"1M6R=I8V]N)UTL($AO<F1E.CIS=')I<$%C8V5S<TME>2@D;5LG=&5X="==
M*2P@)R<L("1M6R=I8V]N7W!A=&@G72D["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("\J($QI;FLN("HO"B`@("`@("`@("`@("1A8V-E<W-K97D@/2!(
M;W)D93HZ9V5T06-C97-S2V5Y*"1M6R=T97AT)UTI.PH@("`@("`@("`@("`D
M;&EN:R`]($AO<F1E.CIL:6YK*"1M6R=U<FPG72P@)&UE;G5?=FEE=R`]/2`G
M:6-O;B<@/R`D;5LG=&5X="==(#H@)R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:7-S970H)&U;)V-L87-S)UTI(#\@)&U;)V-L87-S)UT@
M.B`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I<W-E="@D
M;5LG=&%R9V5T)UTI(#\@)&U;)W1A<F=E="==(#H@)R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:7-S970H)&U;)V]N8VQI8VLG72D@/R`D
M;5LG;VYC;&EC:R==(#H@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)R<L("1A8V-E<W-K97DI.PH*("`@("`@("`@("`@)&]U='!U="`N
M/2!S<')I;G1F*")<;CQL:3XE<R5S/&)R("\^)7,\+V$^/"]L:3XB+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&QI;FLL("1I8V]N+"`H)&UE
M;G5?=FEE=R`A/2`G:6-O;B<I(#\@2&]R9&4Z.FAI9VAL:6=H=$%C8V5S<TME
M>2@D;5LG=&5X="==+"`D86-C97-S:V5Y*2`Z("<G*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D;W5T<'5T("X@)SPO=6P^)SL*("`@('T*"B`@("`O
M*BH*("`@("`J($%N>2!L:6YK<R!T;R!O=&AE<B!(;W)D92!A<'!L:6-A=&EO
M;G,@9&5F:6YE9"!I;B!A;B!A<'!L:6-A=&EO;B=S(&-O;F9I9PH@("`@("H@
M9FEL92!B>2!T:&4@)&-O;F9;)VUE;G4G75LG87!P<R==(&%R<F%Y(&%R92!A
M9&1E9"!T;R!T:&4@;65N=2!A<G)A>2X*("`@("`J+PH@("`@9G5N8W1I;VX@
M861D07!P3&EN:W,H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9BP@)')E
M9VES=')Y.PH*("`@("`@("!I9B`H:7-S970H)&-O;F9;)VUE;G4G75LG87!P
M<R==*2`F)B!I<U]A<G)A>2@D8V]N9ELG;65N=2==6R=A<'!S)UTI*2!["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1C;VYF6R=M96YU)UU;)V%P<',G72!A<R`D
M87!P*2!["B`@("`@("`@("`@("`@("!I9B`H)')E9VES=')Y+3YG970H)W-T
M871U<R<L("1A<'`I("$]("=I;F%C=&EV92<@)B8@)')E9VES=')Y+3YH87-0
M97)M:7-S:6]N*"1A<'`L(%!%4DU37U-(3U<I*2!["B`@("`@("`@("`@("`@
M("`@("`@)'5R;"`]("1R96=I<W1R>2T^9V5T26YI=&EA;%!A9V4H)&%P<"D[
M"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<U]A*"1U<FPL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F%D9"A(
M;W)D93HZ=7)L*"1U<FPI+"`D<F5G:7-T<GDM/F=E="@G;F%M92<L("1A<'`I
M+"`D<F5G:7-T<GDM/F=E="@G:6-O;B<L("1A<'`I+"`G)RD["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@061D(&%N>2!O=&AE
M<B!L:6YK<R!F;W5N9"!I;B`D=&AI<RT^7VUE;G5F:6QE('1O(&)E(&EN8VQU
M9&5D(&EN('1H90H@("`@("H@;65N=2X*("`@("`J+PH@("`@9G5N8W1I;VX@
M861D4VET94QI;FMS*"D*("`@('L*("`@("`@("!I9B`H0&ES7W)E861A8FQE
M*"1T:&ES+3Y?;65N=69I;&4I*2!["B`@("`@("`@("`@(&EN8VQU9&4@)'1H
M:7,M/E]M96YU9FEL93L*("`@("`@("`@("`@:68@*&ES<V5T*"1?;65N=2D@
M)B8@:7-?87)R87DH)%]M96YU*2D@>PH@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)%]M96YU(&%S("1M96YU:71E;2D@>PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YA9&1!<G)A>2@D;65N=6ET96TI.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@0VAE8VMS('1O('-E92!I9B!T:&4@8W5R<F5N="!U<FP@;6%T8VAE<R!T
M:&4@9VEV96X@=7)L+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M5VAE=&AE<B!T:&4@9VEV96X@55),(&ES('1H92!C=7)R96YT(&QO8V%T:6]N
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<U-E;&5C=&5D*"1U<FPI"B`@("![
M"B`@("`@("`@)'-E<G9E<E]U<FP@/2!P87)S95]U<FPH)%]315)615);)U!(
M4%]314Q&)UTI.PH@("`@("`@("1C:&5C:U]U<FP@/2!P87)S95]U<FPH)'5R
M;"D["@H@("`@("`@("\J(%1R>2!T;R!M871C:"!T:&4@:71E;2=S('!A=&@@
M86=A:6YS="!T:&4@8W5R<F5N="!S8W)I<'0*("`@("`@("`@("!F:6QE;F%M
M92!A<R!W96QL(&%S(&]T:&5R('!O<W-I8FQE(%523',@=&\@=&AI<R!S8W)I
M<'0N("HO"B`@("`@("`@:68@*&ES<V5T*"1C:&5C:U]U<FQ;)W!A=&@G72D@
M)B8*("`@("`@("`@("`@*"@D8VAE8VM?=7)L6R=P871H)UT@/3T@)'-E<G9E
M<E]U<FQ;)W!A=&@G72D@?'P*("`@("`@("`@("`@("@D8VAE8VM?=7)L6R=P
M871H)UT@+B`G:6YD97@N<&AP)R`]/2`D<V5R=F5R7W5R;%LG<&%T:"==*2!\
M?`H@("`@("`@("`@("`@*"1C:&5C:U]U<FQ;)W!A=&@G72`N("<O:6YD97@N
M<&AP)R`]/2`D<V5R=F5R7W5R;%LG<&%T:"==*2DI('L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+P``````
M````````````````````````````````````````````````````````````
M````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`U,34T,S,W-3``,#(P,C$Q`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+TU)344O0V]N=&5N=',N<&AP````````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#$P-3`W,``Q,#4Q-30S,S<T-P`P,C(U,S``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"G)E<75I
M<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O365S<V%G92YP:'`G.PH*
M+RHJ"B`J(%1H92!N86UE(&]F('1H92!54DP@<&%R86UE=&5R('1H870@:&]L
M9',@=&AE($U)345?0V]N=&5N=',@8V%C:&4*("H@:61E;G1I9FEE<BX*("HO
M"F1E9FEN92@G34E-15]#3TY414Y44U]#04-(12<L("=M:6UE8V%C:&4G*3L*
M"B\J*@H@*B!$:7-P;&%Y(&%T=&%C:&UE;G0@:6YF;W)M871I;VX@:6X@;&ES
M="!F;W)M870N"B`J+PID969I;F4H)TU)345?0T].5$5.5%-?1$E34$Q!65]4
M65!%7TQ)4U0G+"`P*3L*"B\J*@H@*B!$:7-P;&%Y(&%T=&%C:&UE;G0@:6YF
M;W)M871I;VX@:6YL:6YE('=I=&@@871T86-H;65N="X*("HO"F1E9FEN92@G
M34E-15]#3TY414Y44U]$25-03$%97U194$5?24Y,24Y%)RP@,2D["@HO*BH*
M("H@1&ES<&QA>2!A='1A8VAM96YT(&EN9F]R;6%T:6]N(&)O=&@@:6X@;&ES
M="!F;W)M870@86YD(&EN;&EN92!W:71H"B`J(&%T=&%C:&UE;G0N"B`J+PID
M969I;F4H)TU)345?0T].5$5.5%-?1$E34$Q!65]465!%7T)/5$@G+"`R*3L*
M"B\J*@H@*B!4:&4@34E-15]#;VYT96YT<SHZ(&-L87-S(&-O;G1A:6YS(&9U
M;F-T:6]N<R!R96QA=&5D('1O(&AA;F1L:6YG('1H92!O=71P=70*("H@;V8@
M34E-12!C;VYT96YT+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP+'8@,2XQ,CDN-"XS-2`R,#`V+S`U+S`U(#`S.C,P
M.C(R('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-
M:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]G<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS
M;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!(;W)D
M92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?34E-10H@*B\*8VQA<W,@34E-15]#
M;VYT96YT<R!["@H@("`@+RHJ"B`@("`@*B!4:&4@34E-15]-97-S86=E(&]B
M:F5C="!F;W(@=&AE(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0'9A<B!-24U%
M7TUE<W-A9V4*("`@("`J+PH@("`@=F%R("1?;65S<V%G93L*"B`@("`O*BH*
M("`@("`J(%1H92!-24U%7TUE<W-A9V4@;V)J96-T('=E('5S92!W:&5N(&-A
M8VAI;F<N"B`@("`@*@H@("`@("H@0'9A<B!-24U%7TUE<W-A9V4*("`@("`J
M+PH@("`@=F%R("1?8V%C:&5M97-S86=E.PH*("`@("\J*@H@("`@("H@5&AE
M(&%T=&%C:&UE;G1S(&QI<W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]A=&,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H@5&AE(&UE<W-A9V4@<&%R=',@;&ES="X*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<G1S(#T@87)R87DH*3L*"B`@
M("`O*BH*("`@("`J(%1H92!S=6UM87)Y('!A<G1S(&QI<W0N"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]S=6UM87)Y(#T@
M87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!S=6UM87)Y('1Y<&4N"B`@
M("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<W5M
M;6%R>51Y<&4@/2!N=6QL.PH*("`@("\J*@H@("`@("H@5&AE($-A8VAE7W-E
M<W-I;VX@:61E;G1I9FEE<BX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)%]S97-S:6]N0V%C:&5)1"`](&YU;&P["@H@("`@
M+RHJ"B`@("`@*B!4:&4@34E-15]6:65W97(@;V)J96-T(&-A8VAE+@H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?=FEE=V5R
M0V%C:&4@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@5&AE(&%T=&%C:&UE
M;G0@9&ES<&QA>2!T>7!E('1O('5S92X*("`@("`J"B`@("`@*B!`=F%R(&EN
M=&5G97(*("`@("`J+PH@("`@=F%R("1?9&ES<&QA>51Y<&4@/2!-24U%7T-/
M3E1%3E137T1)4U!,05E?5%E015]"3U1(.PH*("`@("\J*@H@("`@("H@5&AE
M($U)344@:6YD97@@:V5Y('1O('5S92X*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]M:6UE:V5Y(#T@;G5L;#L*"B`@("`O
M*BH*("`@("`J(%1H92!A8W1I;VY)1"!V86QU92!F;W(@=F%R:6]U<R!A8W1I
M;VYS+@H@("`@("H@)V1O=VYL;V%D)R`@+2T@($1O=VYL;V%D:6YG(&$@<&%R
M="]A='1A8VAM96YT+@H@("`@("H@)W9I97<G("`@("`@+2T@(%9I97=I;F<@
M82!P87)T+V%T=&%C:&UE;G0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]V:65W240@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@4VAO=R!T:&4@;&EN:W,@:6X@=&AE('-U;6UA<FEE<S\*("`@("`J
M"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?;&EN:W,@
M/2!T<G5E.PH*("`@("\J*@H@("`@("H@5&AE(&)A<V4@34E-15]#;VYT96YT
M<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'9A<B!-24U%7T-O;G1E;G1S"B`@
M("`@*B\*("`@('9A<B`D7V)A<V4@/2!N=6QL.PH*("`@("\J*@H@("`@("H@
M5&AE(&YU;6)E<B!O9B!M97-S86=E+W)F8S@R,B!L979E;',@;&%B96QE9"!A
M<R`G871T86-H;65N=',G(&]F('1H90H@("`@("H@8W5R<F5N="!P87)T+@H@
M("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]A
M='1A8V@X,C(@/2`P.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@
M("`@*@H@("`@("H@0'!A<F%M($U)345?365S<V%G92`D;65S<V%G94]B("!4
M:&4@;V)J96-T('1O('=O<FL@=VET:"X*("`@("`J($!P87)A;2!A<G)A>2`D
M=FEE=TE$("`@("`@("`@("`@5&AE(&%C=&EO;DE$('9A;'5E<R!F;W(@=FEE
M=VEN9PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!P
M87)T<R]A='1A8VAM96YT<RX*("`@("`J($!P87)A;2!A<G)A>2`F)&-O;G1E
M;G1S("`@("`@("`@07)R87D@8V]N=&%I;FEN9R!A('-I;F=L92!V86QU93H*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@82!R969E
M<F5N8V4@=&\@=&AE(&)A<V4@;V)J96-T+@H@("`@("H@*%1H:7,@;&%S="!P
M87)A;65T97(@;F5E9',@=&\@8F4@:&%N9&QE9"!V:6$@86X@87)R87D@8F5C
M875S92!02%`@/`H@("`@("H@(#4N,"!D;V5S;B=T(&AA;F1L92!O<'1I;VYA
M;"!P;VEN=&5R('!A<F%M971E<G,@;W1H97)W:7-E+BD*("`@("`J+PH@("`@
M9G5N8W1I;VX@34E-15]#;VYT96YT<R@D;65S<V%G94]B+"`D=FEE=TE$(#T@
M87)R87DH*2P@)&-O;G1E;G1S(#T@87)R87DH*2D*("`@('L*("`@("`@("`D
M=&AI<RT^7VUE<W-A9V4@/2`D;65S<V%G94]B.PH@("`@("`@("1T:&ES+3Y?
M8V%C:&5M97-S86=E(#T@571I;#HZ8VQO;F5/8FIE8W0H)&UE<W-A9V5/8BD[
M"B`@("`@("`@)'1H:7,M/E]V:65W240@/2`D=FEE=TE$.PH*("`@("`@("`O
M*B!#<F5A=&4@=&AE('!O:6YT97(@=&\@=&AE(&)A<V4@;V)J96-T+B`J+PH@
M("`@("`@(&EF("@A96UP='DH)&-O;G1E;G1S*2D@>PH@("`@("`@("`@("`D
M<'1R(#T@<F5S970H)&-O;G1E;G1S*3L*("`@("`@("`@("`@)&]L9%]P='(@
M/2`F)'!T<BT^9V5T0F%S94]B:F5C=%!T<B@I.PH@("`@("`@("`@("`D=&AI
M<RT^7V)A<V4@/2`D;VQD7W!T<CL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!E;G1I<F4@8F]D>2!O9B!T:&4@;65S<V%G
M92X*("`@("`J(%EO=2!P<F]B86)L>2!W86YT('1O(&]V97)R:61E('1H:7,@
M9G5N8W1I;VX@:6X@86YY('-U8F-L87-S+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@=&5X="!O9B!T:&4@8F]D>2!O9B!T:&4@;65S<V%G
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0F]D>2@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?;65S<V%G92T^=&]3=')I;F<H*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(')A=R!T97AT(&9O<B!O;F4@
M<V5C=&EO;B!O9B!T:&4@;65S<V%G92X*("`@("`J(%EO=2!P<F]B86)L>2!W
M86YT('1O(&]V97)R:61E('1H:7,@9G5N8W1I;VX@:6X@86YY('-U8F-L87-S
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@240@;V8@
M=&AE($U)345?4&%R="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE('1E>'0@;V8@=&AE('!A<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$)O9'E087)T*"1I9"D*("`@('L*("`@("`@("!I9B`H*"1P87)T(#T@)B1T
M:&ES+3YG971-24U%4&%R="@D:60I*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'!A<G0M/F=E=$-O;G1E;G1S*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE($U)345?365S<V%G92!O8FIE8W0@9F]R('1H92!M
M86EL(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0')E='5R;B!-24U%7TUE<W-A
M9V4@($$@34E-15]-97-S86=E(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T34E-14UE<W-A9V4H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7VUE<W-A9V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&971C:"!A('!A
M<G0@;V8@82!-24U%(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&ED("!4:&4@34E-12!I;F1E>"!O9B!T:&4@<&%R="!R97%U97-T
M960N"B`@("`@*@H@("`@("H@0')E='5R;B!-24U%7U!A<G0@(%1H92!R87<@
M34E-12!P87)T(&%S:V5D(&9O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E
M=$U)345087)T*"1I9"D*("`@('L*("`@("`@("`D<&%R="`]("1T:&ES+3Y?
M;65S<V%G92T^9V5T4&%R="@D:60I.PH@("`@("`@(')E='5R;B`D<&%R=#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E8G5I;&0@=&AE($U)345?4&%R="!S
M=')U8W1U<F4@;V8@82!M97-S86=E+@H@("`@("H@66]U('!R;V)A8FQY('=A
M;G0@=&\@;W9E<G)I9&4@=&AI<R!F=6YC=&EO;B!I;B!A;GD@<W5B8VQA<W,N
M"B`@("`@*@H@("`@("H@0')E='5R;B!-24U%7TUE<W-A9V4@($$@34E-15]-
M97-S86=E(&]B:F5C="!W:71H(&%L;"!O9B!T:&4@8F]D>2!T97AT"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@<W1O<F5D(&EN('1H92!I;F1I=FED
M=6%L($U)345?4&%R=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E8G5I;&1-
M97-S86=E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]M97-S86=E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1F5T8V@@<&%R="!O9B!A($U)344@
M;65S<V%G92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:60@("!4
M:&4@34E-12!)1"!O9B!T:&4@<&%R="!R97%U97-T960N"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D86QL("!)9B!T:&ES(&ES(&$@:&5A9&5R('!A<G0L('-H
M;W5L9"!W92!R971U<FX@86QL('1E>'0*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@(&EN('1H92!B;V1Y/PH@("`@("H*("`@("`J($!R971U<FX@34E-
M15]087)T("!4:&4@34E-15]087)T+@H@("`@("HO"B`@("!F=6YC=&EO;B`F
M9V5T4F%W34E-15!A<G0H)&ED+"`D86QL(#T@9F%L<V4I"B`@("!["B`@("`@
M("`@)&UI;65?<&%R="`]("8D=&AI<RT^9V5T34E-15!A<G0H)&ED*3L*("`@
M("`@("!I9B`H(6ES7V$H)&UI;65?<&%R="P@)TU)345?4&%R="<I*2!["B`@
M("`@("`@("`@("1M:6UE7W!A<G0@/2!N=6QL.PH@("`@("`@("`@("!R971U
M<FX@)&UI;65?<&%R=#L*("`@("`@("!]"@H@("`@("`@("\J($EF(&%L;"!T
M97AT(&ES(')E<75E<W1E9"P@8VAA;F=E('1H92!)1"!N;W<N("HO"B`@("`@
M("`@:68@*"1A;&P@)B8@)&UI;65?<&%R="T^9V5T26YF;W)M871I;VXH)VAE
M861E<B<I*2!["B`@("`@("`@("`@("1I9"`]('-U8G-T<B@D:60L(#`L('-T
M<G)P;W,H)&ED+"`G+B<I*3L*("`@("`@("!]"@H@("`@("`@("\J($]N;'D@
M<V5T(&-O;G1E;G1S(&EF('1H97)E(&ES(&-U<G)E;G1L>2!N;VYE(&EN('1H
M92!-24U%(%!A<G0N("HO"B`@("`@("`@:68@*"$D;6EM95]P87)T+3YG971#
M;VYT96YT<R@I*2!["B`@("`@("`@("`@("1M:6UE7W!A<G0M/G-E=$-O;G1E
M;G1S*"1T:&ES+3YG971";V1Y4&%R="@D:60I*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D;6EM95]P87)T.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1F5T8V@@<&%R="!O9B!A($U)344@;65S<V%G92!A;F0@9&5C;V1E(&ET+"!I
M9B!I="!I<R!B87-E7S8T(&]R"B`@("`@*B!Q<')I;G0@96YC;V1E9"X*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:60@("!4:&4@34E-12!)1"!O
M9B!T:&4@<&%R="!R97%U97-T960N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M86QL("!)9B!T:&ES(&ES(&$@:&5A9&5R('!A<G0L('-H;W5L9"!W92!R971U
M<FX@86QL('1E>'0*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&EN('1H
M92!B;V1Y/PH@("`@("H*("`@("`J($!R971U<FX@34E-15]087)T("!4:&4@
M34E-15]087)T('=I=&@@:71S(&-O;G1E;G1S(&1E8V]D960N"B`@("`@*B\*
M("`@(&9U;F-T:6]N("9G971$96-O9&5D34E-15!A<G0H)&ED+"`D86QL(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@:68@*"@D;6EM95]P87)T(#T@)B1T:&ES
M+3YG971287=-24U%4&%R="@D:60L("1A;&PI*2D@>PH@("`@("`@("`@("`D
M;6EM95]P87)T+3YT<F%N<V9E<D1E8V]D94-O;G1E;G1S*"D["B`@("`@("`@
M("`@("\O($YO;W`N"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&UI
M;65?<&%R="`](&YU;&P["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D;6EM
M95]P87)T.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!A='1A
M8VAM96YT(&QI<W0@*$A434P@=&%B;&4@9F]R;6%T*2X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(&QI<W0@;V8@871T86-H;65N=',@9F]R
M;6%T=&5D(&EN=&\@2%1-3"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T071T
M86-H;65N=',H*0H@("`@>PH@("`@("`@("1M<V<@/2`G)SL*"B`@("`@("`@
M)&%K97ES(#T@87)R87E?:V5Y<R@D=&AI<RT^7V%T8RD["B`@("`@("`@;F%T
M<V]R="@D86ME>7,I.PH@("`@("`@(&9O<F5A8V@@*"1A:V5Y<R!A<R`D:V5Y
M*2!["B`@("`@("`@("`@("1M<V<@+CT@)'1H:7,M/E]A<G)A>51O5&%B;&52
M;W<H)'1H:7,M/E]A=&-;)&ME>5TI.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1M<V<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&UE
M<W-A9V4@;&ES="`H2%1-3"!T86)L92!F;W)M870I+@H@("`@("H*("`@("`J
M($!P87)A;2!B;V]L96%N("1O;F5F<F%M92`@4VAO=6QD('1H92!O=71P=70@
M8F4@9&5S:6=N960@9F]R(&1I<W!L87D@:6X@80H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("!S:6YG;&4@9G)A;64_"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!M97-S86=E(&9O<FUA='1E9"!I;G1O($A4
M34PN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$UE<W-A9V4H)&]N969R86UE
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&US9R`]("<G.PH@("`@("`@("1M
M<V=#;W5N="`](&-O=6YT*"1T:&ES+3Y?<&%R=',I.PH@("`@("`@("1P87)T
M1&ES<&QA>65D(#T@9F%L<V4["@H@("`@("`@(&EF("@D;VYE9G)A;64I('L*
M("`@("`@("`@("`@)&US9R`N/2`G/'-T>6QE('1Y<&4](G1E>'0O8W-S(CXN
M;VYE9G(@>W!A9&1I;F<Z,7!X.R!M87)G:6XM8F]T=&]M.C%P>#L@8F]R9&5R
M.C%P>"!D87-H960@(S`P8SL@8F%C:V=R;W5N9#HC965F.R!C;VQO<CHC,#`V
M?3PO<W1Y;&4^)R`N(")<;B(["B`@("`@("`@?0H*("`@("`@("`O+R!43T1/
M.B!496UP;W)A<GD@:&%C:R!T;R!D:7-P;&%Y(&AE861E<B!I;F9O(&9O<B!A
M(&UE<W-A9V4@=VET:"!O;F4*("`@("`@("`O+R!-24U%('!A<G0@=&AA="!C
M86YN;W0@8F4@9&ES<&QA>65D(&EN;&EN92X*("`@("`@("!I9B`H(21M<V=#
M;W5N="!\?"`H)&US9T-O=6YT(#T](#$@)B8@(7)E<V5T*"1T:&ES+3Y?<&%R
M=',I*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T4W5M;6%R>2@D=&AI<RT^
M7VUE<W-A9V4L("=P87)T)RD["B`@("`@("`@("`@("1M<V=#;W5N="`](#$[
M"B`@("`@("`@?0H@("`@("`@("`@("`*("`@("`@("!F;W)E86-H("@D=&AI
M<RT^7W!A<G1S(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7W-U;6UA<GE;)&ME>5TI("8F"B`@("`@("`@("`@
M("`@("`H*"@D;7-G0V]U;G0@/3T@,2D@)B8@96UP='DH)'9A;'5E*2D@?'P@
M*"1M<V=#;W5N="`^(#$I*2D@>PH@("`@("`@("`@("`@("`@)&US9R`N/2`G
M/'1R/CQT9#XG.PH@("`@("`@("`@("`@("`@:68@*"1O;F5F<F%M92D@>PH@
M("`@("`@("`@("`@("`@("`@("1M<V<@+CT@)SQT86)L92!C;&%S<STB;VYE
M9G(B/B<["B`@("`@("`@("`@("`@("`@("`@)'-U;6UA<GD@/2`D=&AI<RT^
M7W-U;6UA<GE;)&ME>5T["B`@("`@("`@("`@("`@("`@("`@)'-U;6UA<GD@
M/2!A<G)A>5]M97)G92AA<G)A>5]S<&QI8V4H)'-U;6UA<GDL(#`L(#$I+"!A
M<G)A>5]S<&QI8V4H)'-U;6UA<GDL(#$I*3L*("`@("`@("`@("`@("`@("`@
M("`D;7-G("X]("1T:&ES+3Y?87)R87E4;U1A8FQE4F]W*"1S=6UM87)Y*3L*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)&US9R`N/2`G/'1A8FQE/B<["B`@("`@("`@("`@("`@("`@("`@)&US9R`N
M/2`D=&AI<RT^7V%R<F%Y5&]486)L95)O=R@D=&AI<RT^7W-U;6UA<GE;)&ME
M>5TI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&US9R`N
M/2`G/"]T86)L93X\+W1D/CPO='(^)SL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1V86QU92DI('L*("`@("`@("`@("`@("`@("1M
M<V<@+CT@)SQT<CX\=&0@8VQA<W,](G1E>'0B/B<@+B`D=F%L=64@+B`G/"]T
M9#X\+W1R/B<["B`@("`@("`@("`@("`@("`D<&%R=$1I<W!L87EE9"`]('1R
M=64["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A)'!A
M<G1$:7-P;&%Y960I('L*("`@("`@("`@("`@)&US9R`N/2`G/'1R/CQT9"!C
M;&%S<STB=&5X="(@86QI9VX](FQE9G0B/CQE;3XG("X@7R@B5&AE<F4@87)E
M(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(BD@+B`G
M/"]E;3X\+W1D/CPO='(^)SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M;7-G.PH@("`@?0H*("`@("\J*@H@("`@("H@17AP86YD<R!A;B!A<G)A>2!I
M;G1O(&$@=&%B;&4@<F]W+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D87)R87D@(%1H92!A<G)A
M>2!T;R!E>'!A;F0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!A<G)A>2!E>'!A;F1E9"!T;R!A($A434P@=&%B;&4@<F]W+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?87)R87E4;U1A8FQE4F]W*"1A<G)A>2D*("`@('L*
M("`@("`@("`D=&5X="`]("<\='(@=F%L:6=N/2)M:61D;&4B/B<["@H@("`@
M("`@(&9O<F5A8V@@*"1A<G)A>2!A<R`D96QE;2D@>PH@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1E;&5M*2D@>PH@("`@("`@("`@("`@("`@)'1E>'0@+CT@
M(CQT9#XD96QE;29N8G-P.SPO=&0^7&XB.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'1E>'0@+B`B/"]T<CY<;B(["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!D871A(&9O<B!A('-P96-I
M9FEC($U)344@:6YD97@N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M:60@("`@(%1H92!-24U%(&EN9&5X+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9FEE;&0@(%1H92!F:65L9"!T;R!R971U<FX@*&UE<W-A9V4L(&%T8RP@<W5M
M;6%R>2D*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('1E>'0@
M8W5R<F5N=&QY('-E="!F;W(@=&AA="!I;F1E>"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T26YD97@H)&ED+"`D9FEE;&0I"B`@("!["B`@("`@("`@)&9I
M96QD(#T@)U\G("X@)&9I96QD.PH@("`@("`@(&EF("AI<U]A<G)A>2@D=&AI
M<RT^)&9I96QD*2`F)B!A<G)A>5]K97E?97AI<W1S*"1I9"P@)'1H:7,M/B1F
M:65L9"DI('L*("`@("`@("`@("`@)&5N=')Y(#T@)'1H:7,M/B1F:65L9#L*
M("`@("`@("`@("`@<F5T=7)N("1E;G1R>5LD:61=.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E;6]V97,@=&AE(&UE<W-A9V4@=&5X="!A;F0@
M<W5M;6%R>2!F;W(@82!S<&5C:69I8R!-24U%(&EN9&5X+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@34E-12!I;F1E>"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5M;W9E26YD97@H)&ED*0H@("`@>PH@("`@("`@
M('5N<V5T*"1T:&ES+3Y?<&%R='-;)&ED72D["B`@("`@("`@=6YS970H)'1H
M:7,M/E]S=6UM87)Y6R1I9%TI.PH@("`@("`@('5N<V5T*"1T:&ES+3Y?871C
M6R1I9%TI.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE(&EF('=E
M(&-A;B`H86YD(&MN;W<@:&]W('1O*2!I;FQI;F4@82!-24U%(%!A<G0N"B`@
M("`@*@H@("`@("H@0'!A<F%M($U)345?4&%R="`F)&UI;65?<&%R="`@02!-
M24U%7U!A<G0@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5')U92!I9B!P87)T(&-A;B!B92!I;FQI;F5D+@H@("`@("H@("`@("`@
M("`@("`@("`@("!&86QS92!I9B!I="!C86YN;W0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&-A;D1I<W!L87E);FQI;F4H)B1M:6UE7W!A<G0I"B`@("!["B`@
M("`@("`@)'9I97=E<B`]("8D=&AI<RT^9V5T34E-159I97=E<B@D;6EM95]P
M87)T*3L*"B`@("`@("`@+RH@1FER<W0@8VAE8VLZ(%1H92!-24U%(&AE861E
M<G,@86QL;W<@=&AE('!A<G0@=&\@8F4@:6YL:6YE9"X*("`@("`@("`@*B!(
M;W=E=F5R+"!I9B!W92!A<F4@86QR96%D>2!I;B!V:65W(&UO9&4L('1H96X@
M=V4@8V%N('-K:7`@=&AI<PH@("`@("`@("`J(&-H96-K+B`J+PH@("`@("`@
M(&EF("@A)'1H:7,M/G9I97=!<T%T=&%C:&UE;G0H*2`F)@H@("`@("`@("`@
M("`H)&UI;65?<&%R="T^9V5T1&ES<&]S:71I;VXH*2`A/2`G:6YL:6YE)RD@
M)B8*("`@("`@("`@("`@(21V:65W97(M/F9O<F-E26YL:6YE5FEE=R@I*2![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@
M("\J(%-E8V]N9"!C:&5C:R`H<V%V92!T:&4@;6]S="!E>'!E;G-I=F4@9F]R
M(&QA<W0I.@H@("`@("`@("`J($-H96-K('1O('-E92!I9B!T:&4@9')I=F5R
M(&ES('-E="!T;R!I;FQI;F4N("HO"B`@("`@("`@<F5T=7)N("AI<U]A*"1V
M:65W97(L("=-24U%7U9I97=E<B<I("8F("1V:65W97(M/F-A;D1I<W!L87E)
M;FQI;F4H*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@34E-15]6:65W
M97(@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!-24U%7U!A<G0@)B1M
M:6UE7W!A<G0@($$@34E-15]087)T(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N($U)345?5FEE=V5R("!4:&4@34E-15]6:65W97(@;V)J96-T+"!O
M<B!F86QS92!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$U)
M3456:65W97(H)B1M:6UE7W!A<G0I"B`@("!["B`@("`@("`@+RH@36%K92!S
M=7)E('=E(&AA=F4@82!-24U%7U!A<G0@=&\@<')O8V5S<RX@*B\*("`@("`@
M("!I9B`H96UP='DH)&UI;65?<&%R="DI('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA
M;64H7U]&24Q%7U\I("X@)R]6:65W97(N<&AP)SL*"B`@("`@("`@)&ME>2`]
M("1M:6UE7W!A<G0M/F=E=%5N:7%U94E$*"D@+B`G?"<@+B`D;6EM95]P87)T
M+3YG9714>7!E*"D["B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W9I97=E
M<D-A8VAE6R1K97E=*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W9I97=E<D-A
M8VAE6R1K97E=(#T@)DU)345?5FEE=V5R.CIF86-T;W)Y*"1M:6UE7W!A<G0I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=FEE=V5R0V%C
M:&5;)&ME>5T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE($U)344@
M0V]N=&5N="U4>7!E(&]U='!U="!B>2!A($U)345?5FEE=V5R(&9O<B!A('!A
M<G1I8W5L87(*("`@("`J($U)345?4&%R="X*("`@("`J"B`@("`@*B!`<&%R
M86T@34E-15]087)T("8D;6EM95]P87)T("!!($U)345?4&%R="!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!-24U%('1Y<&4@
M;W5T<'5T(&)Y('1H92!-24U%7U9I97=E<BP@;W(@9F%L<V4@;VX*("`@("`J
M("`@("`@("`@("`@("`@("!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T34E-159I97=E<E1Y<&4H)B1M:6UE7W!A<G0I"B`@("!["B`@("`@("`@
M:68@*"@D=FEE=V5R(#T@)B1T:&ES+3YG971-24U%5FEE=V5R*"1M:6UE7W!A
M<G0I*2D@>PH@("`@("`@("`@("!R971U<FX@)'9I97=E<BT^9V5T5'EP92@I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!K
M97D@=&\@=7-E(&9O<B!A('!A<G1I8W5L87(@34E-15]087)T+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!-
M24U%7U!A<G0@)B1M:6UE7W!A<G0@($$@34E-15]087)T(&]B:F5C="X*("`@
M("`J($!P87)A;2!B;V]L96%N("1O=F5R<FED92`@("`@(%)E<W!E8W0@=&AE
M($U)344@:V5Y(&]V97)R:61E('9A;'5E/PH@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@=6YI<75E(&ED96YT:69I97(@;V8@=&AE($U)345?
M4&%R="X*("`@("`J("`@("`@("`@("`@("`@("!2971U<FYS(&9A;'-E(&EF
M(&YO(&ME>2!F;W5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$U)345+
M97DH)B1M:6UE7W!A<G0L("1O=F5R<FED92`]('1R=64I"B`@("!["B`@("`@
M("`@)&ED(#T@)'1H:7,M/F=E=$U)345+97E/=F5R<FED92@I.PH*("`@("`@
M("!I9B`H)&]V97)R:61E("8F("%I<U]N=6QL*"1I9"DI('L*("`@("`@("`@
M("`@<F5T=7)N("1I9#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M:60@/2`D;6EM95]P87)T+3YG971-24U%260H*3L*("`@("`@("`@("`@:68@
M*&ES7VYU;&PH)&ED*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1I9#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($=E=',@=&AE($U)344@:V5Y(&]V97)R:61E+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@34E-12!K97D@;W9E<G)I9&4@+2!N
M=6QL(&EF(&YO(&]V97)R:61E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971-
M24U%2V5Y3W9E<G)I9&4H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7VUI;65K97D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S(&%N(&]V97)R
M:61E(&9O<B!T:&4@34E-12!K97DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;6EM96ME>0H@("`@("HO"B`@("!F=6YC=&EO;B!S971-24U%2V5Y
M3W9E<G)I9&4H)&UI;65K97D@/2!N=6QL*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?;6EM96ME>2`]("1M:6UE:V5Y.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4VAO=6QD('=E(&1I<W!L87D@;&EN:W,@9F]R('1H92!S=6UM87)I97,_"B`@
M("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-H;W<@(%-H;W<@=&AE('-U
M;6UA<GD@;&EN:W,_"B`@("`@*B\*("`@(&9U;F-T:6]N('-H;W=3=6UM87)Y
M3&EN:W,H)'-H;W<@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L
M;"@D<VAO=RDI('L*("`@("`@("`@("`@)'1H:7,M/E]L:6YK<R`]("1S:&]W
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;&EN:W,["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!296YD97(@82!-24U%(%!A<G0N"B`@("`@
M*@H@("`@("H@0'!A<F%M($U)345?4&%R="`F)&UI;65?<&%R="`@02!-24U%
M7U!A<G0@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@<F5N9&5R960@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R
M34E-15!A<G0H)B1M:6UE7W!A<G0I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<F5N9&5R34E-15!A<G0H)&UI;65?<&%R="P@9F%L<V4I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5N9&5R($U)344@4&%R="!A='1A8VAM96YT
M(&EN9F\N"B`@("`@*@H@("`@("H@0'!A<F%M($U)345?4&%R="`F)&UI;65?
M<&%R="`@02!-24U%7U!A<G0@;V)J96-T+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@<F5N9&5R960@9&%T82X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5N9&5R34E-14%T=&%C:&UE;G1);F9O*"8D;6EM95]P87)T*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W)E;F1E<DU)345087)T*"1M
M:6UE7W!A<G0L('1R=64I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5N9&5R
M($U)344@4&%R="!D871A+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!-24U%7U!A<G0@)B1M:6UE7W!A<G0@
M($$@34E-15]087)T(&]B:F5C="X*("`@("`J($!P87)A;2!B;V]L96%N("1A
M='1A8VAM96YT("`@(%)E;F1E<B!-24U%(%!A<G0@871T86-H;65N="!I;F9O
M/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5N9&5R960@
M9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@7W)E;F1E<DU)345087)T*"8D
M;6EM95]P87)T+"`D871T86-H;65N="`](&9A;'-E*0H@("`@>PH@("`@("`@
M("\J($=E="!T:&4@34E-15]6:65W97(@;V)J96-T(&9O<B!T:&ES($U)344@
M<&%R="`J+PH@("`@("`@("1V:65W97(@/2`F)'1H:7,M/F=E=$U)3456:65W
M97(H)&UI;65?<&%R="D["B`@("`@("`@:68@*"%I<U]A*"1V:65W97(L("=-
M24U%7U9I97=E<B<I*2!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@
M("!]"@H@("`@("`@("1M<V<@/2`G)SL*"B`@("`@("`@)&UI;65?<&%R="T^
M=')A;G-F97)$96-O9&5#;VYT96YT<R@I.PH*("`@("`@("`O*B!)9B!T:&ES
M(&ES(&$@=&5X="\J('!A<G0L($%.1"!T:&4@=&5X="!I<R!I;B!A(&1I9F9E
M<F5N="!C:&%R86-T97(*("`@("`@("`@*B!S970@=&AA;B!T:&4@8G)O=W-E
M<BP@8V]N=F5R="!T;R!T:&4@8W5R<F5N="!C:&%R86-T97(@<V5T+@H@("`@
M("`@("`J($%D9&ET:6]N86QL>2P@:68@=&AE(&)R;W=S97(@9&]E<R!N;W0@
M<W5P<&]R="!55$8M."P@9VEV92!T:&4*("`@("`@("`@*B!U<V5R(&$@;&EN
M:R!T;R!O<&5N('1H92!P87)T(&EN(&$@;F5W('=I;F1O=R!W:71H('1H92!C
M;W)R96-T"B`@("`@("`@("H@8VAA<F%C=&5R('-E="X@*B\*("`@("`@("`D
M8VAA<G-E="`]("1M:6UE7W!A<G0M/F=E=$-H87)S970H*3L*("`@("`@("!I
M9B`H)&-H87)S970I('L*("`@("`@("`@("`@)&-H87)S971?=7!P97(@/2!3
M=')I;F<Z.G5P<&5R*"1C:&%R<V5T*3L*("`@("`@("`@("`@:68@*"@D8VAA
M<G-E=%]U<'!E<B`A/2`G55,M05-#24DG*2`F)@H@("`@("`@("`@("`@("`@
M(21T:&ES+3YV:65W07-!='1A8VAM96YT*"DI('L*("`@("`@("`@("`@("`@
M("1D969A=6QT7V-H87)S970@/2!3=')I;F<Z.G5P<&5R*$Y,4SHZ9V5T0VAA
M<G-E="@I*3L*("`@("`@("`@("`@("`@(&EF("@D8VAA<G-E=%]U<'!E<B`A
M/2`D9&5F875L=%]C:&%R<V5T*2!["B`@("`@("`@("`@("`@("`@("`@)&UI
M;65?<&%R="T^<V5T0V]N=&5N=',H4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D
M;6EM95]P87)T+3YG971#;VYT96YT<R@I+"`D8VAA<G-E="P@)&1E9F%U;'1?
M8VAA<G-E="DI.PH@("`@("`@("`@("`@("`@("`@("1M:6UE7W!A<G0M/G-E
M=$-H87)S970H)&1E9F%U;'1?8VAA<G-E="D["B`@("`@("`@("`@("`@("`@
M("`@:68@*"1D969A=6QT7V-H87)S970@(3T@)U541BTX)RD@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D<W1A='5S(#T@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!S<')I;G1F*%\H(E1H:7,@;65S<V%G92!W87,@
M=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO
M=7(@;W=N+B(I+"!H=&UL<W!E8VEA;&-H87)S*"1C:&%R<V5T*2DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!S<')I;G1F*%\H(DEF(&ET(&ES(&YO
M="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W
M('=I;F1O=RXB*2P@)'1H:7,M/FQI;FM6:65W2E,H)&UI;65?<&%R="P@)W9I
M97=?871T86-H)RP@7R@B8VQI8VL@:&5R92(I*2D*("`@("`@("`@("`@("`@
M("`@("`@("`@*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&US9R`]("1T
M:&ES+3YF;W)M8713=&%T=7--<V<H)'-T871U<RP@;G5L;"P@9F%L<V4I("X@
M)&US9SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1V:65W97(M/G-E
M=$U)345087)T*"1M:6UE7W!A<G0I.PH@("`@("`@("1P87)A;7,@/2!A<G)A
M>2@F)'1H:7,I.PH@("`@("`@(&EF("@D871T86-H;65N="D@>PH@("`@("`@
M("`@("`D;7-G("X]("1V:65W97(M/G)E;F1E<D%T=&%C:&UE;G1);F9O*"1P
M87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1M<V<@+CT@
M)'9I97=E<BT^<F5N9&5R*"1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1M<V<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9"!T:&4@
M;65S<V%G92!D96-I9&EN9R!W:&%T($U)344@4&%R=',@=&\@<VAO=RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@($9A;'-E(&]N(&5R<F]R+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!B=6EL9$UE<W-A9V4H*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?871C(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^7W!A
M<G1S(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^7W-U;6UA<GD@/2!A<G)A
M>2@I.PH*("`@("`@("!I9B`H(6ES7V$H)'1H:7,M/E]M97-S86=E+"`G34E-
M15]-97-S86=E)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@+RH@3F]W(&1I<W!L87D@=&AE('!A<G1S+B`J+PH@
M("`@("`@("1M:6UE7W!A<G0@/2`D=&AI<RT^7VUE<W-A9V4M/F=E=$)A<V50
M87)T*"D["B`@("`@("`@)'1H:7,M/F)U:6QD365S<V%G95!A<G0H)&UI;65?
M<&%R="D["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4')O8V5S<V5S(&$@34E-15]087)T(&%N9"!S=&]R97,@=&AE(&1I
M<W!L87D@:6YF;W)M871I;VX@:6X@=&AE(&EN=&5R;F%L"B`@("`@*B!C;&%S
M<R!V87)I86)L97,N"B`@("`@*@H@("`@("H@0'!A<F%M($U)345?4&%R="`F
M)&UI;65?<&%R="`@5&AE($U)345?4&%R="!O8FIE8W0@=&\@<')O8V5S<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D('1E
M>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&)U:6QD365S<V%G95!A<G0H)B1M
M:6UE7W!A<G0I"B`@("!["B`@("`@("`@)&US9R`]("<G.PH*("`@("`@("`O
M*B!)9B!W92!C86XG="!D:7-P;&%Y('1H92!P87)T(&EN;&EN92P@861D(&ET
M('1O('1H92!A='1A8VAM96YT"B`@("`@("`@("`@;&ES="X@268@=&AE($U)
M344@240@;V8@=&AE(&-U<G)E;G0@<&%R="!I<R`G,"<L('1H96X@9F]R8V4@
M80H@("`@("`@("`@(')E;F1E<B!O9B!T:&4@<&%R="`H<VEN8V4@:70@:7,@
M=&AE(&)A<V4@<&%R="!A;F0L('=I=&AO=70*("`@("`@("`@("!A='1E;7!T
M:6YG('1O(')E;F1E<BP@=&AE(&UE<W-A9V4@=VEL;"!!3%=!65,@87!P96%R
M(&5M<'1Y+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/F-A;D1I<W!L87E);FQI
M;F4H)&UI;65?<&%R="D@)B8*("`@("`@("`@("`@*"1M:6UE7W!A<G0M/F=E
M=$U)345)9"@I("$](#`I*2!["B`@("`@("`@("`@("\J($YO="!D:7-P;&%Y
M:6YG(&EN;&EN93L@861D('1O('1H92!A='1A8VAM96YT<R!L:7-T+B`J+PH@
M("`@("`@("`@("!I9B`H*"1T:&ES+3Y?9&ES<&QA>51Y<&4@/3T@34E-15]#
M3TY414Y44U]$25-03$%97U194$5?3$E35"D@?'P*("`@("`@("`@("`@("`@
M("@D=&AI<RT^7V1I<W!L87E4>7!E(#T]($U)345?0T].5$5.5%-?1$E34$Q!
M65]465!%7T)/5$@I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T4W5M
M;6%R>2@D;6EM95]P87)T+"`G871T86-H;65N="<I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("@H)'1H:7,M/E]D:7-P;&%Y5'EP92`]/2!-24U%
M7T-/3E1%3E137T1)4U!,05E?5%E015])3DQ)3D4I('Q\"B`@("`@("`@("`@
M("`@("`H)'1H:7,M/E]D:7-P;&%Y5'EP92`]/2!-24U%7T-/3E1%3E137T1)
M4U!,05E?5%E015]"3U1(*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E
M=%-U;6UA<GDH)&UI;65?<&%R="P@)W!A<G0G*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@+RH@0VAE8VL@=&\@<V5E(&EF(&%N>2!A='1A8VAM96YT
M(&EN9F]R;6%T:6]N(&-A;B!B92!R96YD97)E9"!B>0H@("`@("`@("`@("`@
M("!T:&4@34E-15]6:65W97(N("HO"B`@("`@("`@("`@("1M<V<@/2`D=&AI
M<RT^<F5N9&5R34E-14%T=&%C:&UE;G1);F9O*"1M:6UE7W!A<G0I.PH@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1M<V<I*2!["B`@("`@("`@("`@("`@("`D
M:V5Y(#T@)'1H:7,M/E]G971-24U%2V5Y*"1M:6UE7W!A<G0I.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)T<ULD:V5Y72`]("1M<V<["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;7-G(#T@)'1H
M:7,M/G)E;F1E<DU)345087)T*"1M:6UE7W!A<G0I.PH@("`@("`@("`@("`D
M:V5Y(#T@)'1H:7,M/E]G971-24U%2V5Y*"1M:6UE7W!A<G0I.PH@("`@("`@
M("`@("!I9B`H(21T:&ES+3Y?871T86-H.#(R*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<G1S6R1K97E=(#T@)&US9SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`O*B!3;VUE($U)345?5FEE=V5R<R!S970@=&AE('-U;6UA
M<GD@8GD@=&AE;65L=F5S+"!S;R!O;FQY"B`@("`@("`@("`@("`J(&%D9"!T
M;R!A='1A8VAM96YT+VEN;&EN92!L:7-T<R!I9B!N;W1H:6YG(&AA<R!B965N
M('-E=`H@("`@("`@("`@("`@*B!A<R!O9B!Y970N("HO"B`@("`@("`@("`@
M(&EF("@H*"1M:6UE7W!A<G0M/F=E=%1Y<&4H*2`A/2`G;75L=&EP87)T+VUI
M>&5D)RD@?'P*("`@("`@("`@("`@("`@("`A96UP='DH)&US9RDI("8F"B`@
M("`@("`@("`@("`@("`A96UP='DH)&ME>2D@)B8*("`@("`@("`@("`@("`@
M("$D=&AI<RT^9V5T26YD97@H)&ME>2P@)W-U;6UA<GDG*2D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E=%-U;6UA<GDH)&UI;65?<&%R="P@)W!A<G0G
M*3L*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7V%T=&%C:#@R,B`F)@H@
M("`@("`@("`@("`@("`@("`@("@H)'1H:7,M/E]D:7-P;&%Y5'EP92`]/2!-
M24U%7T-/3E1%3E137T1)4U!,05E?5%E015],25-4*2!\?`H@("`@("`@("`@
M("`@("`@("`@("@D=&AI<RT^7V1I<W!L87E4>7!E(#T]($U)345?0T].5$5.
M5%-?1$E34$Q!65]465!%7T)/5$@I*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YS9713=6UM87)Y*"1M:6UE7W!A<G0L("=A='1A8VAM96YT)RD[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(&EF("@D;6EM95]P87)T+3YG971);F9O<FUA=&EO;B@G:&5A9&5R
M)RDI('L*("`@("`@("`@("`@+RH@268@=&AI<R!I<R!M97-S86=E+W)F8S@R
M,B!P87)T+"!A;F0@:70@:7,@;6%R:V5D(&%S(&%N"B`@("`@("`@("`@("`J
M(&%T=&%C:&UE;G0L('=E(&YE960@=&\@;&5T(&9U='5R92!C86QL<R!T;R!B
M=6EL9$UE<W-A9V5087)T*"D*("`@("`@("`@("`@("H@:VYO=R!T:&%T(&ET
M('-H;W5L9"!M87)K(&5M8F5D9&5D('!A<G1S(&%S(&YO="!V:65W86)L90H@
M("`@("`@("`@("`@*B!I;FQI;F4N("HO"B`@("`@("`@("`@("1I;F-R96UE
M;G1?.#(R(#T@9F%L<V4["B`@("`@("`@("`@(&EF("@H)&UI;65?<&%R="T^
M9V5T5'EP92@I(#T]("=M97-S86=E+W)F8S@R,B<I("8F"B`@("`@("`@("`@
M("`@("`H)&UI;65?<&%R="T^9V5T1&ES<&]S:71I;VXH*2`]/2`G871T86-H
M;65N="<I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V%T=&%C:#@R,BLK
M.PH@("`@("`@("`@("`@("`@)&EN8W)E;65N=%\X,C(@/2!T<G5E.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!F;W)E86-H("@D;6EM95]P87)T+3YG
M971087)T<R@I(&%S("1P87)T*2!["B`@("`@("`@("`@("`@("`D;7-G("X]
M("1T:&ES+3YB=6EL9$UE<W-A9V5087)T*"1P87)T*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@:68@*"1I;F-R96UE;G1?.#(R*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V%T=&%C:#@R,BTM.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&US9SL*("`@('T*"B`@("`O*BH*
M("`@("`J($%R92!W92!V:65W:6YG('1H:7,@<&%G92!A<R!A;B!A='1A8VAM
M96YT('1H<F]U9V@@=FEE=RYP:'`_"B`@("`@*B!4:&ES(&UE=&AO9"!C86X@
M86QS;R!B92!C86QL960@=FEA($U)345?0V]N=&5N=',Z.G9I97=!<T%T=&%C
M:&UE;G0H*2X*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<&]P=7`@
M($EF('1R=64L(&%L<V\@8VAE8VL@:68@=V4@87)E('9I97=I;F<@871T86-H
M;65N=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!I;B!P;W!U<"!V
M:65W('=I;F1O=RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R
M=64@:68@=V4@87)E('9I97=I;F<@=&AI<R!P87)T(&%S(&%N(&%T=&%C:&UE
M;G0*("`@("`J("`@("`@("`@("`@("`@("`@=&AR;W5G:"!V:65W+G!H<"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@=FEE=T%S071T86-H;65N="@D<&]P=7`@
M/2!F86QS92D*("`@('L*("`@("`@("!R971U<FX@*"AS=')P;W,H)%]315)6
M15);)U!(4%]314Q&)UTL("=V:65W+G!H<"<I("$]/2!F86QS92D@)B8*("`@
M("`@("`@("`@("`@("@A)'!O<'5P('Q\(%5T:6PZ.F=E=$9O<FU$871A*"=P
M;W!U<%]V:65W)RDI*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@82!S
M=6UM87)Y(&5N=')Y+@H@("`@("H*("`@("`J($!P87)A;2!-24U%7U!A<G0@
M)B1M:6UE7W!A<G0@(%1H92!-24U%7U!A<G0@;V)J96-T+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D='EP92`@("`@("`@("`@5&AE('-U;6UA<GD@8V%C:&4@
M=&\@=7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S9713=6UM87)Y*"8D;6EM
M95]P87)T+"`D='EP92D*("`@('L*("`@("`@("!I9B`H)'1Y<&4@/3T@)V%T
M=&%C:&UE;G0G*2!["B`@("`@("`@("`@("1C86-H92`]("8D=&AI<RT^7V%T
M8SL*("`@("`@("!](&5L<V5I9B`H)'1Y<&4@/3T@)W!A<G0G*2!["B`@("`@
M("`@("`@("1C86-H92`]("8D=&AI<RT^7W-U;6UA<GD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@
M)&ME>2`]("1T:&ES+3Y?9V5T34E-14ME>2@D;6EM95]P87)T*3L*"B`@("`@
M("`@)'1H:7,M/E]S=6UM87)Y5'EP92`]("1T>7!E.PH@("`@("`@("1S=6UM
M87)Y(#T@)'1H:7,M/G!A<G13=6UM87)Y*"1M:6UE7W!A<G0L(&YU;&PI.PH@
M("`@("`@("1T:&ES+3Y?<W5M;6%R>51Y<&4@/2!N=6QL.PH*("`@("`@("!I
M9B`H(65M<'1Y*"1S=6UM87)Y*2D@>PH@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?<&%R='-;)&ME>5TI*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<G1S6R1K97E=(#T@;G5L;#L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D8V%C:&5;)&ME>5T@/2`D<W5M;6%R>3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%R<F%Y('-U;6UA<FEZ:6YG
M(&$@<&%R="!O9B!A($U)344@;65S<V%G92X*("`@("`J"B`@("`@*B!`<&%R
M86T@34E-15]087)T("8D;6EM95]P87)T("!4:&4@34E-15]087)T('1O('-U
M;6UA<FEZ92X*("`@("`J($!P87)A;2!B;V]L96%N("1G=65S<R`@("`@("`@
M($ES('1H:7,@82!T96UP;W)A<GD@9W5E<W-E9"UT>7!E('!A<G0_"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE('-U;6UA<GD@;V8@=&AE('!A
M<G0N"B`@("`@*B`@("`@("`@("`@("`@("!;,%T@/2!)8V]N"B`@("`@*B`@
M("`@("`@("`@("`@("!;,5T@/2!)34%0($E$"B`@("`@*B`@("`@("`@("`@
M("`@("!;,ET@/2!$97-C<FEP=&EO;@H@("`@("H@("`@("`@("`@("`@("`@
M6S-=(#T@34E-12!4>7!E"B`@("`@*B`@("`@("`@("`@("`@("!;-%T@/2!3
M:7IE"B`@("`@*B`@("`@("`@("`@("`@("!;-5T@/2!$;W=N;&]A9"!L:6YK
M+VEC;VX*("`@("`J+PH@("`@9G5N8W1I;VX@<&%R=%-U;6UA<GDH)B1M:6UE
M7W!A<G0L("1G=65S<R`](&9A;'-E*0H@("`@>PH@("`@("`@("1A='1A8VAM
M96YT(#T@*"1M:6UE7W!A<G0M/F=E=$1I<W!O<VET:6]N*"D@/3T@)V%T=&%C
M:&UE;G0G*3L*("`@("`@("`D8GET97,@/2`D;6EM95]P87)T+3YG971">71E
M<R@I.PH@("`@("`@("1D97-C<FEP=&EO;B`](&AT;6QS<&5C:6%L8VAA<G,H
M)&UI;65?<&%R="T^9V5T1&5S8W)I<'1I;VXH=')U92P@=')U92DI.PH@("`@
M("`@("1S=6UM87)Y(#T@87)R87DH*3L*("`@("`@("`D='EP92`](&AT;6QS
M<&5C:6%L8VAA<G,H)&UI;65?<&%R="T^9V5T5'EP92@I*3L*("`@("`@("`D
M=FEE=V5R(#T@)B1T:&ES+3YG971-24U%5FEE=V5R*"1M:6UE7W!A<G0I.PH@
M("`@("`@(&EF("@A)'9I97=E<BD@>PH@("`@("`@("`@("!R971U<FX@)'-U
M;6UA<GD["B`@("`@("`@?0H*("`@("`@("`O*B!2971U<FX@:68@=V4@<W1I
M;&P@9&ED;B=T(&9I;F0@82!N871I=F4@;6EM92!V:65W97(*("`@("`@("`@
M*B!F;W(@82!G=65S<V5D(&UI;64@='EP92X@*B\*("`@("`@("!I9B`H)&=U
M97-S("8F(&ES7V$H)'9I97=E<BP@)TU)345?5FEE=V5R7V1E9F%U;'0G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'-U;6UA<GD["B`@("`@("`@?0H*("`@
M("`@("`O*B!'970@=&AE($U)344@:60@:6YD97@N("HO"B`@("`@("`@)&ED
M(#T@)'1H:7,M/E]G971-24U%2V5Y*"1M:6UE7W!A<G0I.PH*("`@("`@("`O
M*B!)8V]N(&-O;'5M;BX@*B\*("`@("`@("`D<W5M;6%R>5M=(#T@2&]R9&4Z
M.FEM9R@D=FEE=V5R+3YG971)8V]N*"1T>7!E*2P@;G5L;"P@;G5L;"P@)R<I
M.PH*("`@("`@("`O*B!.=6UB97(@8V]L=6UN+B`J+PH@("`@("`@(&EF("@H
M)'1H:7,M/E]D:7-P;&%Y5'EP92`]/2!-24U%7T-/3E1%3E137T1)4U!,05E?
M5%E015]"3U1(*2`F)@H@("`@("`@("`@("`A:7-?;G5L;"@D=&AI<RT^7W-U
M;6UA<GE4>7!E*2D@>PH@("`@("`@("`@("`D<W5M;6%R>5M=(#T@)SQA(&ED
M/2)M:6UE7V-O;G1E;G1S7R<@+B`D=&AI<RT^7W-U;6UA<GE4>7!E("X@)U\G
M("X@)&ED("X@)R(@:')E9CTB(VUI;65?8V]N=&5N='-?)R`N("@H)'1H:7,M
M/E]S=6UM87)Y5'EP92`]/2`G871T86-H;65N="<I(#\G<&%R="<@.B`G871T
M86-H;65N="<I("X@)U\G("X@)&ED("X@)R(^)R`N("1I9"`N("<\+V$^)SL*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<W5M;6%R>5M=(#T@)&ED
M.PH@("`@("`@('T*"B`@("`@("`@+RH@3F%M92]T97AT('!A<G0@8V]L=6UN
M+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/E]L:6YK<R!\?`H@("`@("`@("`@
M("`H(21A='1A8VAM96YT("8F(&5M<'1Y*"1B>71E<RDI("!\?`H@("`@("`@
M("`@("`A:7-S970H)'1H:7,M/E]V:65W241;)W9I97<G72D@?'P*("`@("`@
M("`@("`@:7-?82@D=FEE=V5R+"`G34E-15]6:65W97)?9&5F875L="<I*2![
M"B`@("`@("`@("`@("1S=6UM87)Y6UT@/2`D9&5S8W)I<'1I;VX["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'!A<F%M7V%R<F%Y(#T@87)R87DH
M*3L*("`@("`@("`@("`@:68@*"1G=65S<R`]/3T@=')U92D@>PH@("`@("`@
M("`@("`@("`@)'!A<F%M7V%R<F%Y6R=C='EP92==(#T@)'1Y<&4["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'-U;6UA<GE;72`]("1T:&ES+3YL:6YK
M5FEE=TI3*"1M:6UE7W!A<G0L("1T:&ES+3Y?=FEE=TE$6R=V:65W)UTL("1D
M97-C<FEP=&EO;BP@;G5L;"P@;G5L;"P@)'!A<F%M7V%R<F%Y*3L*("`@("`@
M("!]"@H@("`@("`@("\J($U)344@='EP92!C;VQU;6XN("HO"B`@("`@("`@
M:68@*"1G=65S<RD@>PH@("`@("`@("`@("`D<W5M;6%R>5M=(#T@)SQE;3XG
M("X@<W!R:6YT9BA?*")6:65W(&%S("5S(BDL("1T>7!E*2`N("<\+V5M/B<[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-U;6UA<GE;72`]("=;
M)R`N("1T>7!E("X@)UTG.PH@("`@("`@('T*"B`@("`@("`@+RH@4VEZ92!#
M;VQU;6XN("HO"B`@("`@("`@)'-I>F4@/2`D;6EM95]P87)T+3YG9713:7IE
M*'1R=64I.PH@("`@("`@(&EF("@A96UP='DH)&)Y=&5S*2`F)@H@("`@("`@
M("`@("`H)&UI;65?<&%R="T^9V5T0W5R<F5N=$5N8V]D:6YG*"D@/3T@)V)A
M<V4V-"<I*2!["B`@("`@("`@("`@("\J($9R;VT@4D9#(#(P-#4@6S8N.%TZ
M("(N+BYT:&4@96YC;V1E9"!D871A(&%R92!C;VYS:7-T96YT;'D*("`@("`@
M("`@("`@("`@;VYL>2!A8F]U="`S,R!P97)C96YT(&QA<F=E<B!T:&%N('1H
M92!U;F5N8V]D960@9&%T82XB("HO"B`@("`@("`@("`@("1S:7IE(#T@;G5M
M8F5R7V9O<FUA="AM87@H*"@D8GET97,@*B`P+C<U*2`O(#$P,C0I+"`Q*2D[
M"B`@("`@("`@("`@("1S=6UM87)Y6UT@/2`G/&%C<F]N>6T@=&ET;&4](B<@
M+B!?*")!<'!R;WAI;6%T92!3:7IE(BD@+B`G(CXG("X@<W!R:6YT9BA?*"(E
M<R!+0B(I+"`D<VEZ92D@+B`G/"]A8W)O;GEM/B<["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'-U;6UA<GE;72`]('-P<FEN=&8H7R@B)7,@2T(B
M*2P@)'-I>F4I.PH@("`@("`@('T*"B`@("`@("`@+RH@1&]W;FQO860@8V]L
M=6UN+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/E]L:6YK<R!\?`H@("`@("`@
M("`@("!I<U]N=6QL*"1S:7IE*2!\?`H@("`@("`@("`@("`A:7-S970H)'1H
M:7,M/E]V:65W241;)V1O=VYL;V%D)UTI*2!["B`@("`@("`@("`@("1S=6UM
M87)Y6UT@/2!N=6QL.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S
M=6UM87)Y6UT@/2`D=&AI<RT^;&EN:U9I97<H)&UI;65?<&%R="P@)'1H:7,M
M/E]V:65W241;)V1O=VYL;V%D)UTL($AO<F1E.CII;6<H)V1O=VYL;V%D+G!N
M9R<L(%\H(D1O=VYL;V%D(BDL(&YU;&PL("1'3$]"04Q36R=R96=I<W1R>2==
M+3YG971);6%G941I<B@G:&]R9&4G*2DL(&%R<F%Y*"=J<W1E>'0G(#T^('-P
M<FEN=&8H7R@B1&]W;FQO860@)7,B*2P@)&UI;65?<&%R="T^9V5T1&5S8W)I
M<'1I;VXH=')U92P@=')U92DI*2P@=')U92D["B`@("`@("`@?0H*("`@("`@
M("`O*B!)9B!T:&4@34E-12!4>7!E(&ES(&%P<&QI8V%T:6]N+V]C=&5T+7-T
M<F5A;2P@=')Y('1O('5S90H@("`@("`@("`@('1H92!F:6QE(&5X=&5N<VEO
M;B!T;R!D971E<FUI;F4@=&AE(&%C='5A;"!-24U%('1Y<&4N("HO"B`@("`@
M("`@:68@*"1T:&ES+3Y?;&EN:W,@)B8*("`@("`@("`@("`@(21G=65S<R`F
M)@H@("`@("`@("`@("`A:7-?;G5L;"@D<VEZ92D@)B8*("`@("`@("`@("`@
M*"1T>7!E(#T]("=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG*2!\?`H@("`@
M("`@("`@("`H)'1Y<&4@/3T@)V%P<&QI8V%T:6]N+V)A<V4V-"<I*2!["B`@
M("`@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O
M36%G:6,N<&AP)SL*("`@("`@("`@("`@)&YE=U]T>7!E(#T@34E-15]-86=I
M8SHZ9FEL96YA;654;TU)344H34E-13HZ9&5C;V1E*"1M:6UE7W!A<G0M/F=E
M=$YA;64H*2DI.PH@("`@("`@("`@("!I9B`H)&YE=U]T>7!E("$]("=A<'!L
M:6-A=&EO;B]O8W1E="US=')E86TG*2!["B`@("`@("`@("`@("`@("`D=&5M
M<%]P87)T(#T@)&UI;65?<&%R=#L*("`@("`@("`@("`@("`@("1T96UP7W!A
M<G0M/G-E=%1Y<&4H)&YE=U]T>7!E*3L*("`@("`@("`@("`@("`@("1S=6UM
M87)Y(#T@87)R87E?;6%P*`H@("`@("`@("`@("`@("`@("`@(&-R96%T95]F
M=6YC=&EO;B@G)&$L("1B)RP@)W)E='5R;B!E;7!T>2@D8BD@/R`D82`Z("1A
M("X@7"<\8G(@+SY<)R`N("1B.R<I+`H@("`@("`@("`@("`@("`@("`@("1S
M=6UM87)Y+`H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YP87)T4W5M;6%R
M>2@D=&5M<%]P87)T+"!T<G5E*2D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D<W5M;6%R>3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!T:&4@55),('1O('1H92!V:65W+G!H<"!P86=E+@H@("`@
M("H*("`@("`J($!P87)A;2!-24U%7U!A<G0@)B1M:6UE7W!A<G0@(%1H92!-
M24U%7U!A<G0@;V)J96-T('1O('9I97<N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D86-T:6]N240@("`@("!4:&4@06-T:6]N240@=&\@<&5R9F]R;2X*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@("`@("`@($$@;&ES="!O9B!A
M;GD@861D:71I;VYA;"!P87)A;65T97)S('1H870*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&YE960@=&\@8F4@<&%S<V5D('1O('9I
M97<N<&AP+B`H:V5Y(#T*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&YA;64I"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&QO860@("`@
M("`@("!3:&]U;&0@=V4@9V5N97)A=&4@82!D;W=N;&]A9"!L:6YK/PH@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@55),('1O('9I97<N<&AP
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!U<FQ6:65W*"8D;6EM95]P87)T+"`D
M86-T:6]N240L("1P87)A;7,@/2!A<G)A>2@I+"`D9&QO860@/2!F86QS92D*
M("`@('L*("`@("`@("`O*B!'970@=&AE($U)344@240@9F]R('1H:7,@<&%R
M="X@*B\*("`@("`@("`D:60@/2`H:7-S970H)'!A<F%M<ULG:60G72DI(#\@
M)'!A<F%M<ULG:60G72`Z("1M:6UE7W!A<G0M/F=E=$U)345)9"@I.PH*("`@
M("`@("`O*B!!9&0@=&AE(&YE8V5S<V%R>2!L;V-A;"!P87)A;65T97)S+B`J
M+PH@("`@("`@("1P87)A;7-;)V%C=&EO;DE$)UT@/2`D86-T:6]N240["B`@
M("`@("`@)'!A<F%M<ULG:60G72`]("1I9#L*("`@("`@("`D<&%R86US(#T@
M87)R87E?;65R9V4H)'!A<F%M<RP@)'1H:7,M/F-A8VAE24154DQ087)A;2@I
M*3L*"B`@("`@("`@:68@*"1D;&]A9"D@>PH@("`@("`@("`@("`D=7)L(#T@
M2&]R9&4Z.F1O=VYL;V%D57)L*"1M:6UE7W!A<G0M/F=E=$YA;64H=')U92P@
M=')U92DL("1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H2&]R9&4Z.F%P<&QI8V%T:6]N
M57)L*"=V:65W+G!H<"<I+"`D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D=7)L.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A=&4@
M82!L:6YK('1O('1H92!V:65W+G!H<"!P86=E+@H@("`@("H*("`@("`J($!P
M87)A;2!-24U%7U!A<G0@)B1M:6UE7W!A<G0@(%1H92!-24U%7U!A<G0@;V)J
M96-T('1O('9I97<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D86-T:6]N240@
M("`@("!4:&4@86-T:6]N240@=F%L=64N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T97AT("`@("`@("`@("!4:&4@;&EN:R!T97AT+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@("`@("`@("`@02!L:7-T(&]F(&%D9&ET:6]N86P@
M<&%R86UE=&5R<RX*("`@("`J("`@)V-L87-S)R`@("`@("`M("!4:&4@0U-3
M(&-L87-S('1O('5S92X*("`@("`J("`@)VIS=&5X="<@("`@("`M("!4:&4@
M2E,@=&5X="!T;R!U<V4N"B`@("`@*B`@("=V:65W<&%R86US)R`@+2`@02!L
M:7-T(&]F(&%N>2!A9&1I=&EO;F%L('!A<F%M971E<G,@=&AA="!N965D('1O
M(&)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@<&%S<V5D('1O('9I97<N
M<&AP+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&1L;V%D("`@("`@("`@4VAO
M=6QD('=E(&=E;F5R871E(&$@9&]W;FQO860@;&EN:S\*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@02!(5$U,(&AR968@;&EN:R!T;R!V:65W+G!H
M<"X*("`@("`J+PH@("`@9G5N8W1I;VX@;&EN:U9I97<H)B1M:6UE7W!A<G0L
M("1A8W1I;VY)1"P@)'1E>'0L("1P87)A;7,@/2!A<G)A>2@I+`H@("`@("`@
M("`@("`@("`@("`@("`@)&1L;V%D(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M:68@*"%I<W-E="@D<&%R86US6R=C;&%S<R==*2D@>PH@("`@("`@("`@("`D
M<&%R86US6R=C;&%S<R==(#T@;G5L;#L*("`@("`@("!]"B`@("`@("`@:68@
M*"%I<W-E="@D<&%R86US6R=J<W1E>'0G72DI('L*("`@("`@("`@("`@)'!A
M<F%M<ULG:G-T97AT)UT@/2`D=&5X=#L*("`@("`@("!]"B`@("`@("`@:68@
M*"%I<W-E="@D<&%R86US6R=V:65W<&%R86US)UTI*2!["B`@("`@("`@("`@
M("1P87)A;7-;)W9I97=P87)A;7,G72`](&%R<F%Y*"D["B`@("`@("`@?0H*
M("`@("`@("!I9B`H)&1L;V%D*2!["B`@("`@("`@("`@("1W:6YD;W<@/2!N
M=6QL.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1W:6YD;W<@/2`G
M=FEE=U\G("X@86)S*&-R8S,R*&UI8W)O=&EM92@I*2D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@2&]R9&4Z.FQI;FLH)'1H:7,M/G5R;%9I97<H)&UI
M;65?<&%R="P@)&%C=&EO;DE$+"`D<&%R86US6R=V:65W<&%R86US)UTL("1D
M;&]A9"DL("1P87)A;7-;)VIS=&5X="==+"`D<&%R86US6R=C;&%S<R==+"`D
M=VEN9&]W*2`N("1T97AT("X@)SPO83XG.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1V5N97)A=&4@82!J879A<V-R:7!T(&QI;FL@=&\@=&AE('9I97<N<&AP
M('!A9V4N"B`@("`@*@H@("`@("H@0'!A<F%M($U)345?4&%R="`F)&UI;65?
M<&%R="`@5&AE($U)345?4&%R="!O8FIE8W0@=&\@=FEE=RX*("`@("`J($!P
M87)A;2!I;G1E9V5R("1A8W1I;VY)1"`@("`@(%1H92!!8W1I;VY)1"!T;R!P
M97)F;W)M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@("`@("`@("`@
M5&AE(&QI;FL@=&5X="X*("`@("`J($!P87)A;2!S=')I;F<@)&IS=&5X="`@
M("`@("`@(%1H92!*879A<V-R:7!T(&QI;FL@=&5X="X*("`@("`J($!P87)A
M;2!S=')I;F<@)&-S<R`@("`@("`@("`@(%1H92!#4U,@8VQA<W,@=&\@=7-E
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("`@("`@("`@02!L:7-T
M(&]F(&%N>2!A9&1I=&EO;F%L('!A<F%M971E<G,@=&AA=`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@;F5E9"!T;R!B92!P87-S960@
M=&\@=FEE=RYP:'`N("AK97D@/0H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@;F%M92D*("`@("`J($!P87)A;2!B;V]L96%N("1W:61G
M970@("`@("`@($EF('1R=64@=7-E($AO<F1E.CIW:61G970H*2!T;R!G96YE
M<F%T92P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($AO
M<F1E.CIL:6YK*"D@;W1H97)W:7-E+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!!($A434P@:')E9B!L:6YK('1O('9I97<N<&AP+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!L:6YK5FEE=TI3*"8D;6EM95]P87)T+"`D86-T:6]N
M240L("1T97AT+"`D:G-T97AT(#T@;G5L;"P*("`@("`@("`@("`@("`@("`@
M("`@("`@)&-S<R`](&YU;&PL("1P87)A;7,@/2!A<G)A>2@I+"`D=VED9V5T
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@+RH@268@=FEE=VEN9R!V:6$@=FEE
M=RYP:'`L('=E(&1O;B=T('=A;G0@82!*4R!L:6YK+B`J+PH@("`@("`@(&EF
M("@D=&AI<RT^=FEE=T%S071T86-H;65N="@I*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^;&EN:U9I97<H)&UI;65?<&%R="P@)&%C=&EO;DE$+"`D
M=&5X="P@)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH
M)&IS=&5X="DI('L*("`@("`@("`@("`@)&IS=&5X="`]('-P<FEN=&8H7R@B
M5FEE=R`E<R(I+"`D;6EM95]P87)T+3YG971$97-C<FEP=&EO;BAT<G5E+"!T
M<G5E*2D["B`@("`@("`@?0H@("`@("`@("1P87)A;7-;)W!O<'5P7W9I97<G
M72`](#$["@H@("`@("`@("1U<FP@/2`D=&AI<RT^=7)L5FEE=R@D;6EM95]P
M87)T+"`D86-T:6]N240L("1P87)A;7,I.PH*("`@("`@("!I9B`H(2@D:60@
M/2`D;6EM95]P87)T+3YG971-24U%260H*2DI('L*("`@("`@("`@("`@)&ED
M(#T@86)S*&-R8S,R*'-E<FEA;&EZ92@D;6EM95]P87)T*2DI.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"1W:61G970I('L*("`@("`@("`@("`@<F5T=7)N
M($AO<F1E.CIW:61G970H)R,G+"`D:G-T97AT+"`D8W-S+"!N=6QL+"`B=FEE
M=R@G(B`N("1U<FP@+B`B)RP@)R(@+B`D:60@+B`B)RD[(')E='5R;B!F86QS
M93LB+"`D=&5X="D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N($AO<F1E.CIL:6YK*"<C)RP@)&IS=&5X="P@)&-S<RP@;G5L;"P@(G9I
M97<H)R(@+B`D=7)L("X@(B<L("<B("X@)&ED("X@(B<I.R!R971U<FX@9F%L
M<V4[(BD@+B`D=&5X="`N("<\+V$^)SL*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!0<FEN=',@;W5T('1H92!S=&%T=7,@;65S<V%G92!F;W(@
M82!G:79E;B!-24U%(%!A<G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;7-G("`@("!4:&4@;65S<V%G92!T;R!O=71P=70N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1I;6<@("`@($%N(&EM86=E(&QI;FL@=&\@861D('1O('1H
M92!B96=I;FYI;F<@;V8@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@(&UE<W-A9V4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<')I;G0@($]U
M='!U="!T:&ES(&UE<W-A9V4@=VAE;B!I;B!A('!R:6YT('9I97<_"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1C;&%S<R`@($%N(&]P=&EO;F%L('-T>6QE(&9O
M<B!T:&4@<W1A='5S(&)O>"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&9O<FUA='1E9"!S=&%T=7,@;65S<V%G92!S=')I;F<N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&9O<FUA=%-T871U<TUS9R@D;7-G+"`D:6UG(#T@
M;G5L;"P@)'!R:6YT86)L92`]('1R=64L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&-L87-S(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES
M7V%R<F%Y*"1M<V<I*2!["B`@("`@("`@("`@("1M<V<@/2!A<G)A>2@D;7-G
M*3L*("`@("`@("!]"@H@("`@("`@("\J($EF('=E(&%R92!V:65W:6YG(&%S
M(&%N(&%T=&%C:&UE;G0L(&1O;B=T('!R:6YT($A434P@8V]D92X@*B\*("`@
M("`@("!I9B`H)'1H:7,M/G9I97=!<T%T=&%C:&UE;G0H*2D@>PH@("`@("`@
M("`@("!R971U<FX@:6UP;&]D92@B7&XB+"`D;7-G*3L*("`@("`@("!]"@H@
M("`@("`@(&EF("AI<U]N=6QL*"1C;&%S<RDI('L*("`@("`@("`@("`@)&-L
M87-S(#T@)VUI;653=&%T=7--97-S86=E)SL*("`@("`@("!]"B`@("`@("`@
M)'1E>'0@/2`G/'1A8FQE(&-L87-S/2(G("X@)&-L87-S("X@)R(^)SL*"B`@
M("`@("`@+RH@268@;F\@:6UA9V4L('-I;7!L>2!P<FEN="!O=70@=&AE(&UE
M<W-A9V4N("HO"B`@("`@("`@:68@*&ES7VYU;&PH)&EM9RDI('L*("`@("`@
M("`@("`@9F]R96%C:"`H)&US9R!A<R`D=F%L*2!["B`@("`@("`@("`@("`@
M("`D=&5X="`N/2`G/'1R/CQT9#XG("X@)'9A;"`N("<\+W1D/CPO='(^)R`N
M(")<;B(["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=&5X="`N/2`G/'1R/CQT9"!V86QI9VX](FUI9&1L92(^)R`N("1I
M;6<@+B`G)FYB<W`[/"]T9#XG.PH@("`@("`@("`@("`D=&5X="`N/2`G/'1D
M/B<["@H@("`@("`@("`@("!I9B`H8V]U;G0H)&US9RD@/3T@,2D@>PH@("`@
M("`@("`@("`@("`@)'1E>'0@+CT@)&US9ULP73L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1T97AT("X]("<\=&%B;&4^)SL*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1M<V<@87,@)'9A;"D@>PH@("`@("`@
M("`@("`@("`@("`@("1T97AT("X]("<\='(^/'1D/B<@+B`D=F%L("X@)SPO
M=&0^/"]T<CXG("X@(EQN(CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1T97AT("X]("<\+W1A8FQE/B<["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)'1E>'0@+CT@)SPO=&0^/"]T<CXG("X@(EQN(CL*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D=&5X="`N("<\+W1A8FQE/B<["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@82!P;VEN=&5R('1O('1H92!B87-E
M(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!2971U<FYS
M(&$@<&]I;G1E<B!T;R!T:&4@8F%S92!O8FIE8W0N"B`@("`@*B`@("`@("`@
M("`@("`@("!2971U<FYS(&9A;'-E(&EF('1H97)E(&ES(&YO(&)A<V4@;V)J
M96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T0F%S94]B:F5C=%!T<B@I
M"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)'1H:7,M/E]B87-E*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8F%S93L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3970@=&AE($U)345?0V]N=&5N=',Z.B!O8FIE
M8W0@=&\@8F4@8V%C:&5D+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@(%1H92!C86-H92!/240N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A9&1#86-H92@I"B`@("!["B`@("`@
M("`@:68@*&ES7VYU;&PH)'1H:7,M/E]S97-S:6]N0V%C:&5)1"DI('L*("`@
M("`@("`@("`@)'1H:7,M/E]S97-S:6]N0V%C:&5)1"`]("1T:&ES+3Y?8W)E
M871E0V%C:&5)1"@I.PH@("`@("`@("`@("!R96=I<W1E<E]S:'5T9&]W;E]F
M=6YC=&EO;BAA<G)A>2@F)'1H:7,L("=?861D0V%C:&53:'5T9&]W;B<I*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7W-E<W-I;VY#86-H
M94E$.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A('5N:7%U92!C
M86-H92!)1"!F;W(@=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($$@=6YI
M<75E(&-A8VAE($E$+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8W)E871E0V%C
M:&5)1"@I"B`@("!["B`@("`@("`@<F5T=7)N(&UD-2AM:6-R;W1I;64H*2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3879E<R!A(&-O<'D@;V8@=&AE($U)
M345?0V]N=&5N=',@;V)J96-T(&%T('1H92!E;F0@;V8@82!R97%U97-T+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC
M=&EO;B!?861D0V%C:&53:'5T9&]W;B@I"B`@("!["B`@("`@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]397-S:6]N3V)J96-T<RYP:'`G.PH@("`@("`@("1C
M86-H92`]("9(;W)D95]397-S:6]N3V)J96-T<SHZ<VEN9VQE=&]N*"D["@H@
M("`@("`@("\J($1O;B=T('-A=F4@=&AE($U)345?5FEE=V5R(&-A8VAE9"!O
M8FIE8W1S('-I;F-E('1H97)E(&ES(&YO(&5A<WD*("`@("`@("`@("!W87D@
M=&\@<F5G96YE<F%T92!T:&5M(&]N(&-A8VAE(')E;&]A9"X@*B\*("`@("`@
M("`D=&AI<RT^7W9I97=E<D-A8VAE(#T@87)R87DH*3L*"B`@("`@("`@+RH@
M0V]P>2!T:&4@34E-15]-97-S86=E(&-A8VAE(&]B:F5C="!T;R!T:&4@7VUE
M<W-A9V4@=F%R:6%B;&4N("HO"B`@("`@("`@)'1H:7,M/E]M97-S86=E(#T@
M)'1H:7,M/E]C86-H96UE<W-A9V4["@H@("`@("`@("1C86-H92T^<W1O<F4H
M)'1H:7,M/E]S97-S:6]N0V%C:&5)1"P@)'1H:7,I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@8V%C:&5D($U)345?0V]N=&5N=',Z.B!O
M8FIE8W0N"B`@("`@*B!4:&ES(&9U;F-T:6]N('-H;W5L9"!B92!C86QL960@
M<W1A=&EC86QL>2!E+F<N.@H@("`@("H@)'!T<B`]("9-24U%7T-O;G1E;G1S
M.CIG971#86-H92@I+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-A
M8VAE:60@(%1H92!C86-H92!)1"!T;R!U<V4N("!)9B!E;7!T>2P@=VEL;"!U
M<V4@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!C86-H92!)
M1"!L;V-A=&5D(&EN('1H92!54DP@<&%R86UE=&5R(&YA;65D"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!-24U%7T-/3E1%3E137T-!0TA%+@H@
M("`@("H*("`@("`J($!R971U<FX@34E-15]#;VYT96YT<R`@5&AE($U)345?
M0V]N=&5N=',@;V)J96-T+"!O<B!N=6QL(&EF(&ET(&1O97,@;F]T"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@(&5X:7-T+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F9V5T0V%C:&4H)&-A8VAE:60@/2!N=6QL*0H@("`@>PH@("`@
M("`@(&EF("AI<U]N=6QL*"1C86-H96ED*2D@>PH@("`@("`@("`@("`D8V%C
M:&5I9"`](%5T:6PZ.F=E=$9O<FU$871A*$U)345?0T].5$5.5%-?0T%#2$4I
M.PH@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]397-S
M:6]N3V)J96-T<RYP:'`G.PH@("`@("`@("1C86-H92`]("9(;W)D95]397-S
M:6]N3V)J96-T<SHZ<VEN9VQE=&]N*"D["B`@("`@("`@)&-O;G1E;G1S(#T@
M)B1C86-H92T^<75E<GDH)&-A8VAE:60I.PH@("`@("`@(')E='5R;B`D8V]N
M=&5N=',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@=&AE(&-U<G)E;G0@
M;V)J96-T('1O('1H92!C86-H92P@86YD(')E='5R;B!T:&4@8V%C:&4@:61E
M;G1I9FEE<@H@("`@("H@=&\@8F4@=7-E9"!I;B!54DQS+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@(%1H92!P87)A;65T97(@:V5Y+W9A;'5E('-E
M="!T;R!U<V4@:6X@55),<RX*("`@("`J+PH@("`@9G5N8W1I;VX@8V%C:&5)
M1%523%!A<F%M*"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH34E-15]#
M3TY414Y44U]#04-(12`]/B`D=&AI<RT^7V%D9$-A8VAE*"DI.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-
M24U%+TAE861E<G,N<&AP````````````````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P-3`P,S``,3`U,34T,S,W-#<`,#(R,S`Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@9&5S
M8W)I<'1I;VX@;V8@2&]R9&4@=&\@=7-E(&EN('1H92`G57-E<BU!9V5N=#HG
M(&AE861E<BX*("HO"F1E9FEN92@G2$]21$5?04=%3E1?2$5!1$52)RP@)TAO
M<F1E($%P<&QI8V%T:6]N($9R86UE=V]R:R`S+C$G*3L*"B\J*@H@*B!4:&4@
M34E-15](96%D97)S.CH@8VQA<W,@8V]N=&%I;G,@9V5N97)I8R!F=6YC=&EO
M;G,@<F5L871E9"!T;PH@*B!H86YD;&EN9R!T:&4@:&5A9&5R<R!O9B!M86EL
M(&UE<W-A9V5S+@H@*@H@*B!4:&4@9&5F875L="!C:&%R86-T97(@<V5T('1O
M('5S92!F;W(@:&5A9&5R<R!S:&]U;&0@8F4@9&5F:6YE9"!I;B!T:&4*("H@
M=F%R:6%B;&4@)$=,3T)!3%-;)VUI;65?:&5A9&5R<R==6R=D969A=6QT7V-H
M87)S970G72`H9&5F875L=',@=&\@55,M05-#24D*("H@<&5R(%)&0R`R,#0U
M*2X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N
M<&AP+'8@,2XR.2XQ,"XR,"`R,#`V+S`T+S$U(#$W.C(T.C$Y('-L=7-A<GH@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%-L=7-A
M<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG
M=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`
M<&%C:V%G92!(;W)D95]-24U%"B`J+PIC;&%S<R!-24U%7TAE861E<G,@>PH*
M("`@("\J*@H@("`@("H@5&AE(&EN=&5R;F%L(&AE861E<G,@87)R87DN"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]H96%D
M97)S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-A8VAE9"!O=71P=70@
M;V8@=&AE($U)345?4W1R=6-T=7)E.CIP87)S94U)345(96%D97)S*"D@8V]M
M;6%N9"X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7V%L;$AE861E<G,["@H@("`@+RHJ"B`@("`@*B!#86-H960@;W5T<'5T
M(&]F('1H92!I;6%P7V9E=&-H:&5A9&5R*"D@8V]M;6%N9"X*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]H96%D97)497AT
M.PH*("`@("\J*@H@("`@("H@5&AE(&AE861E<B!O8FIE8W0@<F5T=7)N960@
M9G)O;2!I;6%P7VAE861E<FEN9F\H*2X*("`@("`J"B`@("`@*B!`=F%R('-T
M9$-L87-S"B`@("`@*B\*("`@('9A<B`D7VAE861E<D]B:F5C=#L*"B`@("`O
M*BH*("`@("`J(%1H92!I;G1E<FYA;"!F;&%G<R!A<G)A>2X*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V9L86=S(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!5<V5R+4%G96YT('-T<FEN9R!T
M;R!U<V4N"B`@("`@*B!42$E3(%9!3%5%(%-(3U5,1"!"12!/5D524DE$14X@
M0ED@04Q,(%-50D-,05-315,N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1?86=E;G0@/2!(3U)$15]!1T5.5%](14%$15([
M"@H@("`@+RHJ"B`@("`@*B!4:&4@<V5Q=65N8V4@=&\@=7-E(&%S($5/3"!F
M;W(@=&AE(&AE861E<G,N"B`@("`@*B!4:&4@9&5F875L="!I<R!C=7)R96YT
M;'D@=&\@;W5T<'5T('1H92!%3TP@<V5Q=65N8V4@:6YT97)N86QL>2!A<PH@
M("`@("H@:G5S="`B7&XB(&EN<W1E860@;V8@=&AE(&-A;F]N:6-A;"`B7')<
M;B(@<F5Q=6ER960@:6X@4D9#(#@R,B`F(#(P-#4N"B`@("`@*B!4;R!B92!2
M1D,@8V]M<&QA:6YT+"!T:&4@9G5L;"`\0U(^/$Q&/B!%3TP@8V]M8FEN871I
M;VX@<VAO=6QD(&)E('5S960*("`@("`J('=H96X@<V5N9&EN9R!A(&UE<W-A
M9V4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?96]L(#T@(EQN(CL*"B`@("`O*BH*("`@("`J(%1H92!I;F1E>"!O9B!T
M:&4@;65S<V%G92X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J
M+PH@("`@=F%R("1?:6YD97@["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O
M<BX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:6YD97@@(%1H92!M
M97-S86=E(&EN9&5X('1O('!A<G-E(&AE861E<G,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N($U)345?2&5A9&5R<R@D:6YD97@@/2!N=6QL*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?:6YD97@@/2`D:6YD97@["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS(&$@<F5F97)E;F-E('1O(&$@8W5R<F5N=&QY(&]P96X@
M24U!4"!S=')E86TN"B`@("`@*B!42$E3(%9!3%5%(%-(3U5,1"!"12!/5D52
M4DE$14X@0ED@04Q,(%-50D-,05-315,N"B`@("`@*@H@("`@("H@0')E='5R
M;B!R97-O=7)C92`@06X@24U!4"!R97-O=7)C92!S=')E86TN"B`@("`@*B\*
M("`@(&9U;F-T:6]N("9?9V5T4W1R96%M*"D*("`@('L*("`@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&9U
M;&P@;&ES="!O9B!H96%D97)S(&9R;VT@=&AE(&EM87!?9F5T8VAH96%D97(H
M*2!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@4V5E
M(&EM87!?9F5T8VAH96%D97(H*2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M2&5A9&5R5&5X="@I"B`@("!["B`@("`@("`@:68@*"%I<U]N=6QL*"1T:&ES
M+3Y?:6YD97@I("8F(&5M<'1Y*"1T:&ES+3Y?:&5A9&5R5&5X="DI('L*("`@
M("`@("`@("`@)'1H:7,M/E]H96%D97)497AT(#T@0&EM87!?9F5T8VAH96%D
M97(H)'1H:7,M/E]G9713=')E86TH*2P@)'1H:7,M/E]I;F1E>"P@1E1?54E$
M*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D1TQ/0D%,4ULG;6EM95]H96%D
M97)S)UU;)V1E9F%U;'1?8VAA<G-E="==*2D@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]H96%D97)497AT(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D
M=&AI<RT^7VAE861E<E1E>'0L("1'3$]"04Q36R=M:6UE7VAE861E<G,G75LG
M9&5F875L=%]C:&%R<V5T)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'1H:7,M/E]H96%D97)497AT.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N('1H92!F=6QL(&QI<W0@;V8@:&5A9&5R<RX*
M("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&5C;V1E("!$96-O9&4@
M=&AE(&AE861E<G,_"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@4V5E
M($U)345?4W1R=6-T=7)E.CIP87)S94U)345(96%D97)S*"DN"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$%L;$AE861E<G,H)&1E8V]D92`]('1R=64I"B`@
M("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+U-T<G5C='5R
M92YP:'`G.PH*("`@("`@("!I9B`H(6ES7VYU;&PH)'1H:7,M/E]I;F1E>"D@
M)B8@96UP='DH)'1H:7,M/E]A;&Q(96%D97)S*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7V%L;$AE861E<G,@/2!-24U%7U-T<G5C='5R93HZ<&%R<V5-24U%
M2&5A9&5R<R@D=&AI<RT^9V5T2&5A9&5R5&5X="@I+"`D9&5C;V1E*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7V%L;$AE861E<G,["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&AE861E<B!O8FIE8W0@
M9G)O;2!I;6%P7VAE861E<FEN9F\H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T9$-L87-S("!3964@:6UA<%]H96%D97)I;F9O*"DN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$AE861E<D]B:F5C="@I"B`@("!["B`@("`@("`@:68@
M*"%I<U]N=6QL*"1T:&ES+3Y?:6YD97@I("8F(&5M<'1Y*"1T:&ES+3Y?:&5A
M9&5R3V)J96-T*2D@>PH@("`@("`@("`@("`D<W1R96%M(#T@)'1H:7,M/E]G
M9713=')E86TH*3L*("`@("`@("`@("`@)'1H:7,M/E]H96%D97)/8FIE8W0@
M/2!`:6UA<%]H96%D97)I;F9O*"1S=')E86TL($!I;6%P7VUS9VYO*"1S=')E
M86TL("1T:&ES+3Y?:6YD97@I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D=&AI<RT^7VAE861E<D]B:F5C=#L*("`@('T*"B`@("`O*BH*("`@("`J
M($)U:6QD('1H92!H96%D97(@87)R87DN"B`@("`@*@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&1E8V]D92`@34E-12!D96-O9&4@=&AE(&AE861E<G,_"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&)U:6QD2&5A9&5R<R@D9&5C;V1E(#T@=')U
M92D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?:&5A9&5R<RDI
M('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@+RH@
M4&%R<V4@=&AR;W5G:"!T:&4@;&ES="!O9B!A;&P@:&5A9&5R<RX@*B\*("`@
M("`@("!F;W)E86-H("@D=&AI<RT^9V5T06QL2&5A9&5R<R@D9&5C;V1E*2!A
M<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@)'1H:7,M/F%D9$AE861E
M<B@D:V5Y+"`D=F%L*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!"=6EL9"!T:&4@9FQA9W,@87)R87DN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&)U:6QD1FQA9W,H*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M
M/E]F;&%G<RDI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@
M("`@("`@+RH@1V5T('1H92!)34%0(&AE861E<B!O8FIE8W0N("HO"B`@("`@
M("`@)&]B(#T@)'1H:7,M/F=E=$AE861E<D]B:F5C="@I.PH@("`@("`@(&EF
M("@A:7-?;V)J96-T*"1O8BDI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@
M("`@('T*"B`@("`@("`@+RH@56YS965N(&9L86<@*B\*("`@("`@("!I9B`H
M*"1O8BT^56YS965N(#T]("=5)RD@?'P@*"1O8BT^4F5C96YT(#T]("=.)RDI
M('L*("`@("`@("`@("`@)'1H:7,M/E]F;&%G<ULG=6YS965N)UT@/2!T<G5E
M.PH@("`@("`@('T*"B`@("`@("`@+RH@4F5C96YT(&9L86<@*B\*("`@("`@
M("!I9B`H*"1O8BT^4F5C96YT(#T]("=.)RD@?'P@*"1O8BT^4F5C96YT(#T]
M("=2)RDI('L*("`@("`@("`@("`@)'1H:7,M/E]F;&%G<ULG<F5C96YT)UT@
M/2!T<G5E.PH@("`@("`@('T*"B`@("`@("`@+RH@06YS=V5R960@9FQA9R`J
M+PH@("`@("`@(&EF("@D;V(M/D%N<W=E<F5D(#T]("=!)RD@>PH@("`@("`@
M("`@("`D=&AI<RT^7V9L86=S6R=A;G-W97)E9"==(#T@=')U93L*("`@("`@
M("!]"@H@("`@("`@("\J($1R869T(&9L86<@*B\*("`@("`@("!I9B`H:7-S
M970H)&]B+3Y$<F%F="D@)B8@*"1O8BT^1')A9G0@/3T@)U@G*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7V9L86=S6R=D<F%F="==(#T@=')U93L*("`@("`@
M("!]"@H@("`@("`@("\J($9L86=G960@9FQA9R`J+PH@("`@("`@(&EF("@D
M;V(M/D9L86=G960@/3T@)T8G*2!["B`@("`@("`@("`@("1T:&ES+3Y?9FQA
M9W-;)V9L86=G960G72`]('1R=64["B`@("`@("`@?0H*("`@("`@("`O*B!$
M96QE=&5D(&9L86<@*B\*("`@("`@("!I9B`H)&]B+3Y$96QE=&5D(#T]("=$
M)RD@>PH@("`@("`@("`@("`D=&AI<RT^7V9L86=S6R=D96QE=&5D)UT@/2!T
M<G5E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE(&EN=&5R;F%L(&AE861E<B!A<G)A>2!I;B!A<G)A>2!F;W)M870N"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&AE861E<G,@:6X@87)R
M87D@9F]R;6%T+@H@("`@("HO"B`@("!F=6YC=&EO;B!T;T%R<F%Y*"D*("`@
M('L*("`@("`@("`D<F5T=7)N7V%R<F%Y(#T@87)R87DH*3L*"B`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]H96%D97)S(&%S("1O8BD@>PH@("`@("`@("`@
M("`D96]L(#T@)'1H:7,M/F=E=$5/3"@I.PH@("`@("`@("`@("`D:&5A9&5R
M(#T@)&]B6R=H96%D97(G73L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1O
M8ELG=F%L=64G72DI('L*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92!D
M:7)N86UE*%]?1DE,15]?*2`N("<O+BXO34E-12YP:'`G.PH@("`@("`@("`@
M("`@("`@)')E='5R;E]A<G)A>5LD:&5A9&5R72`]($U)344Z.G=R87!(96%D
M97)S*"1H96%D97(L(')E<V5T*"1O8ELG=F%L=64G72DI.PH@("`@("`@("`@
M("`@("`@;F5X="@D;V);)W9A;'5E)UTI.PH@("`@("`@("`@("`@("`@=VAI
M;&4@*&QI<W0H+"1V86PI(#T@96%C:"@D;V);)W9A;'5E)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@)')E='5R;E]A<G)A>5LD:&5A9&5R72`N/2`D96]L
M("X@)&AE861E<B`N("<Z("<@+B!-24U%.CIW<F%P2&5A9&5R<R@D:&5A9&5R
M+"`D=F%L+"`D96]L*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1R971U<FY?87)R87E;)&AE861E
M<ET@/2`D;V);)W9A;'5E)UT["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D<F5T=7)N7V%R<F%Y.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@:6YT97)N86P@:&5A9&5R(&%R<F%Y(&EN('-T
M<FEN9R!F;W)M870N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!H96%D97)S(&EN('-T<FEN9R!F;W)M870N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('1O4W1R:6YG*"D*("`@('L*("`@("`@("`D96]L(#T@)'1H:7,M/F=E
M=$5/3"@I.PH@("`@("`@("1T97AT(#T@)R<["@H@("`@("`@(&9O<F5A8V@@
M*"1T:&ES+3Y?:&5A9&5R<R!A<R`D;V(I('L*("`@("`@("`@("`@:68@*"%I
M<U]A<G)A>2@D;V);)W9A;'5E)UTI*2!["B`@("`@("`@("`@("`@("`D;V);
M)W9A;'5E)UT@/2!A<G)A>2@D;V);)W9A;'5E)UTI.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1O8ELG=F%L=64G72!A<R`D96YT<GDI
M('L*("`@("`@("`@("`@("`@("1T97AT("X]("1O8ELG:&5A9&5R)UT@+B`G
M.B`G("X@)&5N=')Y("X@)&5O;#L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1T97AT("X@)&5O;#L*("`@('T*"B`@("`O*BH*
M("`@("`J($=E;F5R871E('1H92`G4F5C96EV960G(&AE861E<B!F;W(@=&AE
M(%=E8B!B<F]W<V5R+3Y(;W)D92!H;W`*("`@("`J("AA='1E;7!T<R!T;R!C
M;VYF;W)M('1O(&=U:61E;&EN97,@:6X@4D9#(#(X,C$I+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!A9&1296-E:79E9$AE861E<B@I"B`@("!["B`@("`@("`@
M:68@*&ES<V5T*"1?4T525D526R=(5%107UA?1D]25T%21$5$7T9/4B==*2D@
M>PH@("`@("`@("`@("`O*B!4:&ES(&EN9&EC871E<R!T:&4@=7-E<B!I<R!C
M;VYN96-T:6YG('1H<F]U9V@@82!P<F]X>2X@*B\*("`@("`@("`@("`@)')E
M;6]T95]P871H(#T@97AP;&]D92@G+"<L("1?4T525D526R=(5%107UA?1D]2
M5T%21$5$7T9/4B==*3L*("`@("`@("`@("`@)')E;6]T95]A9&1R(#T@)')E
M;6]T95]P871H6S!=.PH@("`@("`@("`@("`D<F5M;W1E(#T@0&=E=&AO<W1B
M>6%D9'(H)')E;6]T95]A9&1R*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D<F5M;W1E7V%D9'(@/2`D7U-%4E9%4ELG4D5-3U1%7T%$1%(G73L*
M("`@("`@("`@("`@:68@*&5M<'1Y*"1?4T525D526R=214U/5$5?2$]35"==
M*2D@>PH@("`@("`@("`@("`@("`@)')E;6]T92`]($!G971H;W-T8GEA9&1R
M*"1R96UO=&5?861D<BD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D<F5M;W1E(#T@)%]315)615);)U)%34]415](3U-4)UT["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@)')E8V5I=F5D(#T@)V9R
M;VT@)R`N("1R96UO=&4@+B`G("@G.PH*("`@("`@("!I9B`H(65M<'1Y*"1?
M4T525D526R=214U/5$5?241%3E0G72DI('L*("`@("`@("`@("`@)')E8V5I
M=F5D("X]("1?4T525D526R=214U/5$5?241%3E0G72`N("=`)R`N("1R96UO
M=&4@+B`G("<["B`@("`@("`@?2!E;'-E:68@*"1R96UO=&4@(3T@)%]315)6
M15);)U)%34]415]!1$12)UTI('L*("`@("`@("`@("`@)')E8V5I=F5D("X]
M("1R96UO=&4@+B`G("<["B`@("`@("`@?0H@("`@("`@("1R96-E:79E9"`N
M/2`G6R<@+B`D<F5M;W1E7V%D9'(@+B`G72D@)SL*"B`@("`@("`@:68@*"%E
M;7!T>2@D1TQ/0D%,4ULG8V]N9B==6R=S97)V97(G75LG;F%M92==*2D@>PH@
M("`@("`@("`@("`D<V5R=F5R7VYA;64@/2`D1TQ/0D%,4ULG8V]N9B==6R=S
M97)V97(G75LG;F%M92==.PH@("`@("`@('T@96QS96EF("@A96UP='DH)%]3
M15)615);)U-%4E9%4E].04U%)UTI*2!["B`@("`@("`@("`@("1S97)V97)?
M;F%M92`]("1?4T525D526R=315)615)?3D%-12==.PH@("`@("`@('T@96QS
M96EF("@A96UP='DH)%]315)615);)TA45%!?2$]35"==*2D@>PH@("`@("`@
M("`@("`D<V5R=F5R7VYA;64@/2`D7U-%4E9%4ELG2%144%](3U-4)UT["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-E<G9E<E]N86UE(#T@)W5N
M:VYO=VXG.PH@("`@("`@('T*("`@("`@("`D<F5C96EV960@+CT@)V)Y("<@
M+B`D<V5R=F5R7VYA;64@+B`G("A(;W)D92!-24U%(&QI8G)A<GDI('=I=&@@
M2%144#L@)SL*"B`@("`@("`@)')E8V5I=F5D("X](&1A=&4H)W(G*3L*"B`@
M("`@("`@)'1H:7,M/F%D9$AE861E<B@G4F5C96EV960G+"`D<F5C96EV960I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A=&4@=&AE("=-97-S86=E
M+4E$)R!H96%D97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$UE<W-A9V5)
M9$AE861E<B@I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H
M7U]&24Q%7U\I("X@)R\N+B]-24U%+G!H<"<["B`@("`@("`@)'1H:7,M/F%D
M9$AE861E<B@G365S<V%G92U)1"<L($U)344Z.F=E;F5R871E365S<V%G94E$
M*"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A=&4@=&AE("=297-E
M;G0G(&AE861E<G,@*&-O;F9O<FUS('1O(&=U:61E;&EN97,@:6X*("`@("`J
M(%)&0R`R.#(R(%LS+C8N-ETI+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&9R;VT@(%1H92!A9&1R97-S('1O('5S92!F;W(@)U)E<V5N="U&<F]M
M)RX*("`@("`J($!P87)A;2!S=')I;F<@)'1O("`@(%1H92!A9&1R97-S('1O
M('5S92!F;W(@)U)E<V5N="U4;R<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D
M9%)E<V5N=$AE861E<G,H)&9R;VTL("1T;RD*("`@('L*("`@("`@("!R97%U
M:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+TU)344N<&AP)SL*
M"B`@("`@("`@+RH@5V4@9&]N)W0@<V5T(%)E<V5N="U396YD97(L(%)E<V5N
M="U#8RP@;W(@4F5S96YT+4)C8RX@*B\*("`@("`@("`D=&AI<RT^861D2&5A
M9&5R*"=297-E;G0M1&%T92<L(&1A=&4H)W(G*2D["B`@("`@("`@)'1H:7,M
M/F%D9$AE861E<B@G4F5S96YT+49R;VTG+"`D9G)O;2D["B`@("`@("`@)'1H
M:7,M/F%D9$AE861E<B@G4F5S96YT+51O)RP@)'1O*3L*("`@("`@("`D=&AI
M<RT^861D2&5A9&5R*"=297-E;G0M365S<V%G92U)1"<L($U)344Z.F=E;F5R
M871E365S<V%G94E$*"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A
M=&4@9&5L:79E<GD@<F5C96EP="!H96%D97)S+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'1O("!4:&4@861D<F5S<R!T:&4@<F5C96EP="!S:&]U
M;&0@8F4@;6%I;&5D('1O+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1$96QI
M=F5R>5)E8V5I<'1(96%D97)S*"1T;RD*("`@('L*("`@("`@("`O*B!4:&ES
M(&ES(&]L9"!S96YD;6%I;"`H<')E+3@N-RD@8F5H879I;W(N("HO"B`@("`@
M("`@)'1H:7,M/F%D9$AE861E<B@G4F5T=7)N+5)E8V5I<'0M5&\G+"`D=&\I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A=&4@=&AE('5S97(@86=E
M;G0@9&5S8W)I<'1I;VX@:&5A9&5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!A
M9&1!9V5N=$AE861E<B@I"B`@("!["B`@("`@("`@)'1H:7,M/F%D9$AE861E
M<B@G57-E<BU!9V5N="<L("1T:&ES+3Y?86=E;G0I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@=7-E<B!A9V5N="!D97-C<FEP=&EO;B!H
M96%D97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!U<V5R
M(&%G96YT(&AE861E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T06=E;G1(
M96%D97(H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V%G96YT.PH@
M("`@?0H*("`@("\J*@H@("`@("H@061D(&$@:&5A9&5R('1O('1H92!H96%D
M97(@87)R87DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:&5A9&5R
M("!4:&4@:&5A9&5R(&YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU
M92`@(%1H92!H96%D97(@=F%L=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D
M9$AE861E<B@D:&5A9&5R+"`D=F%L=64I"B`@("!["B`@("`@("`@)&AE861E
M<B`]('1R:6TH)&AE861E<BD["B`@("`@("`@)&QC2&5A9&5R(#T@4W1R:6YG
M.CIL;W=E<B@D:&5A9&5R*3L*"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7VAE861E<G-;)&QC2&5A9&5R72DI('L*("`@("`@("`@("`@)'1H:7,M/E]H
M96%D97)S6R1L8TAE861E<ET@/2!A<G)A>2@I.PH@("`@("`@('T*("`@("`@
M("`D=&AI<RT^7VAE861E<G-;)&QC2&5A9&5R75LG:&5A9&5R)UT@/2`D:&5A
M9&5R.PH@("`@("`@("1T:&ES+3Y?:&5A9&5R<ULD;&-(96%D97)=6R=V86QU
M92==(#T@)'9A;'5E.PH@("`@("`@("1T:&ES+3Y?:&5A9&5R<ULD;&-(96%D
M97)=6R=?86QT97(G72`](&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5M;W9E(&$@:&5A9&5R(&9R;VT@=&AE(&AE861E<B!A<G)A>2X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1H96%D97(@(%1H92!H96%D97(@;F%M
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E2&5A9&5R*"1H96%D97(I
M"B`@("!["B`@("`@("`@)&AE861E<B`]('1R:6TH)&AE861E<BD["B`@("`@
M("`@)&QC2&5A9&5R(#T@4W1R:6YG.CIL;W=E<B@D:&5A9&5R*3L*("`@("`@
M("!U;G-E="@D=&AI<RT^7VAE861E<G-;)&QC2&5A9&5R72D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!3970@82!V86QU92!F;W(@82!P87)T:6-U;&%R(&AE
M861E<B!/3DQ9(&EF('1H870@:&5A9&5R(&ES('-E="X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1H96%D97(@(%1H92!H96%D97(@;F%M92X*("`@
M("`J($!P87)A;2!S=')I;F<@)'9A;'5E("`@5&AE(&AE861E<B!V86QU92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=F%L=64@
M=V%S('-E="P@9F%L<V4@:68@;F]T+@H@("`@("HO"B`@("!F=6YC=&EO;B!S
M971686QU92@D:&5A9&5R+"`D=F%L=64I"B`@("!["B`@("`@("`@)&QC2&5A
M9&5R(#T@4W1R:6YG.CIL;W=E<B@D:&5A9&5R*3L*("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/E]H96%D97)S6R1L8TAE861E<ETI*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?:&5A9&5R<ULD;&-(96%D97)=6R=V86QU92==(#T@)'9A;'5E
M.PH@("`@("`@("`@("`D=&AI<RT^7VAE861E<G-;)&QC2&5A9&5R75LG7V%L
M=&5R)UT@/2!T<G5E.PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N('1H
M92!H96%D97(@:6X@=&AE(&-O<G)E8W0@8V%S92X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1H96%D97(@(%1H92!H96%D97(@=&\@<V5A<F-H(&9O
M<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('9A;'5E(&9O
M<B!T:&4@9VEV96X@:&5A9&5R+@H@("`@("H@("`@("`@("`@("`@("`@($EF
M('1H92!H96%D97(@:7,@;F]T(&9O=6YD+"!R971U<FYS(&YU;&PN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%-T<FEN9R@D:&5A9&5R*0H@("`@>PH@("`@
M("`@("1L8TAE861E<B`](%-T<FEN9SHZ;&]W97(H)&AE861E<BD["B`@("`@
M("`@<F5T=7)N("AI<W-E="@D=&AI<RT^7VAE861E<G-;)&QC2&5A9&5R72DI
M(#\@)'1H:7,M/E]H96%D97)S6R1L8TAE861E<EU;)VAE861E<B==(#H@;G5L
M;#L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'0@=&\@<F5T=7)N('1H
M92!V86QU92!F;W(@82!G:79E;B!H96%D97(N"B`@("`@*B!4:&4@9F]L;&]W
M:6YG(&AE861E<B!F:65L9',@8V%N(&]N;'D@:&%V92`Q(&5N=')Y+"!S;R!I
M9B!D=7!L:6-A=&4*("`@("`J(&5N=')I97,@97AI<W0L('1H92!F:7)S="!V
M86QU92!W:6QL(&)E('5S960Z"B`@("`@*B`@("H@5&\L($9R;VTL($-C+"!"
M8V,L($1A=&4L(%-E;F1E<BP@4F5P;'DM=&\L($UE<W-A9V4M240L($EN+5)E
M<&QY+51O+`H@("`@("H@("`@(%)E9F5R96YC97,L(%-U8FIE8W0@*%)&0R`R
M.#(R(%LS+C9=*0H@("`@("H@("`J($%L;"!,:7-T($AE861E<G,@*%)&0R`R
M,S8Y(%LS72D*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1H96%D97(@
M(%1H92!H96%D97(@=&\@<V5A<F-H(&9O<BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4:&4@=F%L=64@9F]R('1H92!G:79E;B!H96%D97(N"B`@
M("`@*B`@("`@("`@("`@("`@("!)9B!T:&4@:&5A9&5R(&ES(&YO="!F;W5N
M9"P@<F5T=7)N<R!N=6QL+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971686QU
M92@D:&5A9&5R*0H@("`@>PH@("`@("`@("1H96%D97(@/2!3=')I;F<Z.FQO
M=V5R*"1H96%D97(I.PH*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]H96%D
M97)S6R1H96%D97)=*2D@>PH@("`@("`@("`@("`D<VEN9VQE(#T@87)R87DH
M)W1O)RP@)V9R;VTG+"`G8V,G+"`G8F-C)RP@)V1A=&4G+"`G<V5N9&5R)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97!L>2UT;R<L("=M97-S
M86=E+6ED)RP@)VEN+7)E<&QY+71O)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=R969E<F5N8V5S)RP@)W-U8FIE8W0G+"`G>"UP<FEO<FET>2<I
M.PH@("`@("`@("`@("`D<VEN9VQE(#T@87)R87E?;65R9V4H)'-I;F=L92P@
M87)R87E?:V5Y<R@D=&AI<RT^;&ES=$AE861E<G,H*2DI.PH@("`@("`@("`@
M("!I9B`H:7-?87)R87DH)'1H:7,M/E]H96%D97)S6R1H96%D97)=6R=V86QU
M92==*2`F)@H@("`@("`@("`@("`@("`@:6Y?87)R87DH)&AE861E<BP@)'-I
M;F=L92DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VAE861E
M<G-;)&AE861E<EU;)W9A;'5E)UU;,%T["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]H96%D97)S6R1H96%D
M97)=6R=V86QU92==.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@2&%S('1H92!H96%D97(@8F5E;B!A;'1E<F5D(&9R;VT@
M=&AE(&]R:6=I;F%L/PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&AE
M861E<B`@5&AE(&AE861E<B!T;R!A;F%L>7IE+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@:&5A9&5R(&AA<R!B965N(&%L
M=&5R960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%L=&5R961(96%D97(H)&AE
M861E<BD*("`@('L*("`@("`@("`D;&-(96%D97(@/2!3=')I;F<Z.FQO=V5R
M*"1H96%D97(I.PH@("`@("`@(')E='5R;B`H:7-S970H)'1H:7,M/E]H96%D
M97)S6R1L8TAE861E<ETI*2`_("1T:&ES+3Y?:&5A9&5R<ULD;&-(96%D97)=
M6R=?86QT97(G72`Z(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@5')A
M;G-F;W)M<R!A($AE861E<B!V86QU92!U<VEN9R!T:&4@;&ES="!O9B!F=6YC
M=&EO;G,@<')O=FED960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M:&5A9&5R("!4:&4@:&5A9&5R('1O(&%L=&5R+@H@("`@("H@0'!A<F%M(&UI
M>&5D("1F=6YC<R`@("!!(&9U;F-T:6]N+"!O<B!A;B!A<G)A>2!O9B!F=6YC
M=&EO;G,N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(%1H92!F=6YC
M=&EO;G,@=VEL;"!B92!P97)F;W)M960@9G)O;2!R:6=H="!T;PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("!L969T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!S971686QU94)Y1G5N8W1I;VXH)&AE861E<BP@)&9U;F-S*0H@("`@
M>PH@("`@("`@("1H96%D97(@/2!3=')I;F<Z.FQO=V5R*"1H96%D97(I.PH*
M("`@("`@("!I9B`H:7-?87)R87DH)&9U;F-S*2D@>PH@("`@("`@("`@("`D
M9G5N8W,@/2!A<G)A>5]R979E<G-E*"1F=6YC<RD["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&9U;F-S(#T@87)R87DH)&9U;F-S*3L*("`@("`@
M("!]"@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VAE861E<G-;)&AE861E
M<ETI*2!["B`@("`@("`@("`@("1V86P@/2`D=&AI<RT^9V5T5F%L=64H)&AE
M861E<BD["B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=F%L*2D@>PH@("`@
M("`@("`@("`@("`@)'9A;"`](&EM<&QO9&4H(EQN(BP@)'9A;"D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@9F]R96%C:"`H)&9U;F-S(&%S("1F=6YC
M*2!["B`@("`@("`@("`@("`@("`D=F%L(#T@8V%L;%]U<V5R7V9U;F,H)&9U
M;F,L("1V86PI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3YS
M971686QU92@D:&5A9&5R+"`D=F%L*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!9&0@86YY($U)344@:&5A9&5R<R!R97%U:7)E9"!F;W(@
M=&AE($U)345?4&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T
M("8D;6EM95]P87)T("!4:&4@34E-15]087)T(&]B:F5C="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@861D34E-14AE861E<G,H)B1M:6UE7W!A<G0I"B`@("![
M"B`@("`@("`@9F]R96%C:"`H)&UI;65?<&%R="T^:&5A9&5R*&%R<F%Y*"DI
M(&%S("1H96%D(#T^("1V86PI('L*("`@("`@("`@("`@)'1H:7,M/F%D9$AE
M861E<B@D:&5A9"P@)'9A;"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N('1H92!L:7-T(&]F(&%D9')E<W-E<R!F;W(@82!H96%D
M97(@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D;V)S("!!
M;B!A<G)A>2!O9B!H96%D97(@;V)J96-T<R`H4V5E(&EM87!?:&5A9&5R:6YF
M;R@I"B`@("`@*B`@("`@("`@("`@("`@("`@("`@9F]R('1H92!O8FIE8W0@
M<W1R=6-T=7)E*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A
M<G)A>2!O9B!O8FIE8W1S+@H@("`@("H@/'!R93X*("`@("`J($]B:F5C="!E
M;&5M96YT<SH*("`@("`J("=A9&1R97-S)R`@("T@($9U;&P@861D<F5S<PH@
M("`@("H@)VAO<W0G("`@("`@+2`@2&]S="!N86UE"B`@("`@*B`G:6YN97(G
M("`@("`M("!4<FEM;65D+"!B87)E(&%D9')E<W,*("`@("`J("=P97)S;VYA
M;"<@("T@(%!E<G-O;F%L('-T<FEN9PH@("`@("H@/"]P<F4^"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$%D9')E<W-E<T9R;VU/8FIE8W0H)&]B<RD*("`@
M('L*("`@("`@("`D<F5T07)R87D@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H
M(6ES7V%R<F%Y*"1O8G,I('Q\(&5M<'1Y*"1O8G,I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<F5T07)R87D["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H
M("@D;V)S(&%S("1O8BD@>PH@("`@("`@("`@("`O*B!%;G-U<F4@=V4G<F4@
M=V]R:VEN9R!W:71H(&EN:71I86QI>F5D('9A;'5E<RX@*B\*("`@("`@("`@
M("`@:68@*&ES<V5T*"1O8BT^<&5R<V]N86PI*2!["B`@("`@("`@("`@("`@
M("`D;V(M/G!E<G-O;F%L(#T@34E-13HZ9&5C;V1E*"1O8BT^<&5R<V]N86PI
M.PH@("`@("`@("`@("`@("`@:68@*"AS=6)S='(H)&]B+3YP97)S;VYA;"P@
M,"P@,2D@/3T@)R(G*2`F)@H@("`@("`@("`@("`@("`@("`@("AS=6)S='(H
M)&]B+3YP97)S;VYA;"P@+3$I(#T]("<B)RDI('L*("`@("`@("`@("`@("`@
M("`@("`D;V(M/G!E<G-O;F%L(#T@<W5B<W1R*"1O8BT^<&5R<V]N86PL(#$L
M("TQ*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1O8BT^<&5R<V]N86P@/2`G)SL*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@:68@*&ES<V5T*"1O8BT^;6%I;&)O>"DI('L*
M("`@("`@("`@("`@("`@("\J($1O;B=T('!R;V-E<W,@:6YV86QI9"!A9&1R
M97-S97,N("HO"B`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1O8BT^;6%I
M;&)O>"P@)U5.15A014-4141?1$%405]!1E1%4E]!1$1215-3)RD@(3T](&9A
M;'-E('Q\"B`@("`@("`@("`@("`@("`@("`@<W1R<&]S*"1O8BT^;6%I;&)O
M>"P@)TE.5D%,241?041$4D534R<I("$]/2!F86QS92D@>PH@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&]B+3YM86EL8F]X(#T@
M)R<["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@A:7-S970H)&]B
M+3YH;W-T*2D@>PH@("`@("`@("`@("`@("`@)&]B+3YH;W-T(#T@)R<["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("\J($=E;F5R871E('1H92!N97<@
M;V)J96-T+B`J+PH@("`@("`@("`@("`D;F5W3V(@/2`F;F5W('-T9$-L87-S
M.PH@("`@("`@("`@("`D;F5W3V(M/F%D9')E<W,@/2!-24U%.CIA9&1R3V)J
M96-T,E-T<FEN9R@D;V(L(&%R<F%Y*"=U;F1I<V-L;W-E9"UR96-I<&EE;G1S
M0"<L("=5;F1I<V-L;W-E9"!R96-I<&EE;G1S0"<I*3L*("`@("`@("`@("`@
M)&YE=T]B+3YH;W-T(#T@)&]B+3YH;W-T.PH@("`@("`@("`@("`D;F5W3V(M
M/FEN;F5R(#T@34E-13HZ=')I;45M86EL061D<F5S<RA-24U%.CIR9F,X,C)7
M<FET94%D9')E<W,H)&]B+3YM86EL8F]X+"`D;V(M/FAO<W0L("<G*2D["B`@
M("`@("`@("`@("1N97=/8BT^<&5R<V]N86P@/2`D;V(M/G!E<G-O;F%L.PH*
M("`@("`@("`@("`@)')E=$%R<F%Y6UT@/2`F)&YE=T]B.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1R971!<G)A>3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE(&QI<W0@;V8@=F%L:60@;6%I;&EN9R!L:7-T(&AE
M861E<G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&QI<W0@
M;V8@=F%L:60@;6%I;&EN9R!L:7-T(&AE861E<G,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&QI<W1(96%D97)S*"D*("`@('L*("`@("`@("!R971U<FX@87)R
M87DH"B`@("`@("`@("`@("\J(%)&0R`R,S8Y("HO"B`@("`@("`@("`@("=L
M:7-T+6AE;'`G("`@("`@("`@/3X@(%\H(DQI<W0M2&5L<"(I+`H@("`@("`@
M("`@("`G;&ES="UU;G-U8G-C<FEB92<@(#T^("!?*"),:7-T+55N<W5B<V-R
M:6)E(BDL"B`@("`@("`@("`@("=L:7-T+7-U8G-C<FEB92<@("`@/3X@(%\H
M(DQI<W0M4W5B<V-R:6)E(BDL"B`@("`@("`@("`@("=L:7-T+6]W;F5R)R`@
M("`@("`@/3X@(%\H(DQI<W0M3W=N97(B*2P*("`@("`@("`@("`@)VQI<W0M
M<&]S="<@("`@("`@("`]/B`@7R@B3&ES="U0;W-T(BDL"B`@("`@("`@("`@
M("=L:7-T+6%R8VAI=F4G("`@("`@/3X@(%\H(DQI<W0M07)C:&EV92(I+`H@
M("`@("`@("`@("`O*B!21D,@,CDQ.2`J+PH@("`@("`@("`@("`G;&ES="UI
M9"<@("`@("`@("`@(#T^("!?*"),:7-T+4ED(BD*("`@("`@("`I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1&\@86YY(&UA:6QI;F<@;&ES="!H96%D97)S
M(&5X:7-T/PH@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I
M9B!A;GD@;6%I;&EN9R!L:7-T(&AE861E<G,@97AI<W0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&QI<W1(96%D97)S17AI<W0H*0H@("`@>PH@("`@("`@(&9O
M<F5A8V@@*"1T:&ES+3YL:7-T2&5A9&5R<R@I(&%S("1V86P@/3X@)'-T<BD@
M>PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]H96%D97)S6R1V86Q=
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E=',@82!N97<@<W1R:6YG('1O('5S92!F;W(@14],
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1E;VP@(%1H92!S=')I
M;F<@=&\@=7-E(&9O<B!%3TQS+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971%
M3TPH)&5O;"D*("`@('L*("`@("`@("`D=&AI<RT^7V5O;"`]("1E;VP["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE('-T<FEN9R!T;R!U<V4@9F]R
M($5/3',N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!S=')I
M;F<@=&\@=7-E(&9O<B!%3TQS+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971%
M3TPH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V5O;#L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&9L86<@<W1A='5S+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&9L86<@($ES('1H:7,@9FQA9R!S
M970_"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!&;&%G<SH@<F5C96YT
M+"!U;G-E96XL(&%N<W=E<F5D+"!D<F%F="P@:6UP;W)T86YT+`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1E;&5T960*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE(&9L86<@:&%S(&)E
M96X@<V5T+"!F86QS92!I9B!N;W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$9L86<H)&9L86<I"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^
M7V9L86=S6U-T<FEN9SHZ;&]W97(H)&9L86<I72DI('L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E
M="!T:&4@<')I;6%R>2!F<F]M(&%D9')E<W,@*&9I<G-T(&%D9')E<W,@:6X@
M=&AE($9R;VTZ(&AE861E<BDN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!F<F]M(&%D9')E<W,@*'5S97)`:&]S="DN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$9R;VU!9&1R97-S*"D*("`@('L*("`@("`@("!I9B`H
M(2@D;V(@/2`D=&AI<RT^9V5T3V(H)V9R;VTG*2DI('L*("`@("`@("`@("`@
M<F5T=7)N(&YU;&P["B`@("`@("`@?0H*("`@("`@("!R97%U:7)E7V]N8V4@
M)TAO<F1E+TU)344N<&AP)SL*"B`@("`@("`@<F5T=7)N('1R:6TH34E-13HZ
M=')I;45M86EL061D<F5S<RA-24U%.CIR9F,X,C)7<FET94%D9')E<W,H)&]B
M6S!=+3YM86EL8F]X+"`H:7-S970H)&]B6S!=+3YH;W-T*2D@/R`D;V);,%TM
M/FAO<W0@.B`G)RP@)R<I*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@
M82!H96%D97(@9G)O;2!T:&4@:&5A9&5R(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`=&]D;R!297!L86-E('=I=&@@9V5T3V(H*2!F<F]M($E-4"=S($E-4%](
M96%D97)S(&9O<B!(;W)D92`T+C`N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9FEE;&0@("`@5&AE(&]B:F5C="!F:65L9"!T;R!R971R:65V92`H
M<V5E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!I;6%P7VAE861E
M<FEN9F\H*2!F;W(@=&AE(&QI<W0@;V8@9FEE;&1S*2X*("`@("`J($!P87)A
M;2!B;V]L96%N("1D96-O9&4@(%-H;W5L9"!T:&4@<F5T=7)N('9A;'5E(&)E
M($U)344@9&5C;V1E9#\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M($ET('=I;&P@;VYL>2!B92!D96-O9&5D(&EF(&ET(&ES(&YO="!A;B!O8FIE
M8W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&ET<V5L9BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@9FEE;&0@<F5Q=65S=&5D
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971/8B@D9FEE;&0L("1D96-O9&4@
M/2!F86QS92D*("`@('L*("`@("`@("`D9&%T82`](&%R<F%Y*"D["@H@("`@
M("`@("1O8B`]("1T:&ES+3YG971(96%D97)/8FIE8W0H*3L*("`@("`@("!I
M9B`H(6ES7V]B:F5C="@D;V(I*2!["B`@("`@("`@("`@(')E='5R;B`D9&%T
M83L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D;V(M/B1F:65L9"DI
M('L*("`@("`@("`@("`@)&1A=&$@/2`D;V(M/B1F:65L9#L*("`@("`@("`@
M("`@:68@*"%E;7!T>2@D9&5C;V1E*2`F)B`A:7-?;V)J96-T*"1D871A*2`F
M)B`A:7-?87)R87DH)&1A=&$I*2!["B`@("`@("`@("`@("`@("!I;F-L=61E
M7V]N8V4@)TAO<F1E+TU)344N<&AP)SL*("`@("`@("`@("`@("`@(&EF("@A
M96UP='DH)$=,3T)!3%-;)VUI;65?:&5A9&5R<R==6R=D969A=6QT7V-H87)S
M970G72DI('L*("`@("`@("`@("`@("`@("`@("`D9&%T82`](%-T<FEN9SHZ
M8V]N=F5R=$-H87)S970H)&1A=&$L("1'3$]"04Q36R=M:6UE7VAE861E<G,G
M75LG9&5F875L=%]C:&%R<V5T)UTI.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@)&1A=&$@/2!-24U%.CID96-O9&4H)&1A=&$I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@*&ES7W-T<FEN
M9R@D9&%T82DI(#\@<W1R='(H)&1A=&$L(")<="(L("<@)RD@.B`D9&%T83L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+TUA
M9VEC+G!H<```````````````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C`U
M-C4`,3`U,34T,S,W-#<`,#(Q-S8P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!4:&4@34E-15]-86=I
M8SHZ(&-L87-S('!R;W9I9&5S(&%N(&EN=&5R9F%C92!T;R!D971E<FUI;F4@
M80H@*B!-24U%('1Y<&4@9F]R('9A<FEO=7,@8V]N=&5N="P@:68@:70@<')O
M=FED960@=VET:"!D:69F97)E;G0*("H@;&5V96QS(&]F(&EN9F]R;6%T:6]N
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O36%G:6,N<&AP
M+'8@,2XU,BXX+C$R(#(P,#8O,#$O,#$@,C$Z,C@Z,C0@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@06YI;"!-861H879A<&5D9'D@/&%N
M:6Q`<F5C;VEL+F]R9SX*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L
M(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P961D>2`\86YI
M;$!R96-O:6PN;W)G/@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L
M=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($AO<F1E
M(#$N,PH@*B!`<&%C:V%G92!(;W)D95]-24U%"B`J+PIC;&%S<R!-24U%7TUA
M9VEC('L*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!C;W!Y(&]F('1H92!-
M24U%(&5X=&5N<VEO;B!M87`N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE($U)344@97AT
M96YS:6]N(&UA<"X*("`@("`J+PH@("`@9G5N8W1I;VX@)E]G971-:6UE17AT
M96YS:6]N36%P*"D*("`@('L*("`@("`@("!S=&%T:6,@)&UI;65?97AT96YS
M:6]N7VUA<#L*"B`@("`@("`@:68@*"%I<W-E="@D;6EM95]E>'1E;G-I;VY?
M;6%P*2D@>PH@("`@("`@("`@("!R97%U:7)E(&1I<FYA;64H7U]&24Q%7U\I
M("X@)R]M:6UE+FUA<'!I;F<N<&AP)SL*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D;6EM95]E>'1E;G-I;VY?;6%P.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A(&-O<'D@;V8@=&AE($U)344@;6%G:6,@9FEL92X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!4:&4@34E-12!M86=I8R!F:6QE+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F7V=E=$UI;65-86=I8T9I;&4H*0H@("`@>PH@("`@("`@('-T
M871I8R`D;6EM95]M86=I8SL*"B`@("`@("`@:68@*"%I<W-E="@D;6EM95]M
M86=I8RDI('L*("`@("`@("`@("`@<F5Q=6ER92!D:7)N86UE*%]?1DE,15]?
M*2`N("<O;6EM92YM86=I8RYP:'`G.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1M:6UE7VUA9VEC.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP
M="!T;R!C;VYV97)T(&$@9FEL92!E>'1E;G-I;VX@=&\@82!-24U%('1Y<&4L
M(&)A<V5D"B`@("`@*B!O;B!T:&4@9VQO8F%L($AO<F1E(&%N9"!A<'!L:6-A
M=&EO;B!S<&5C:69I8R!C;VYF:6<@9FEL97,N"B`@("`@*@H@("`@("H@268@
M=V4@8V%N;F]T(&UA<"!T:&4@9FEL92!E>'1E;G-I;VX@=&\@82!S<&5C:69I
M8R!T>7!E+"!T:&5N"B`@("`@*B!W92!F86QL(&)A8VL@=&\@82!C=7-T;VT@
M34E-12!H86YD;&5R("=X+65X=&5N<VEO;B\D97AT)RP@=VAI8V@*("`@("`J
M(&-A;B!B92!U<V5D(&%S(&$@;F]R;6%L($U)344@='EP92!I;G1E<FYA;&QY
M('1H<F]U9VAO=70@2&]R9&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D97AT("!4:&4@9FEL92!E>'1E;G-I;VX@=&\@8F4@;6%P<&5D('1O(&$@
M34E-12!T>7!E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M34E-12!T>7!E(&]F('1H92!F:6QE(&5X=&5N<VEO;BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@97AT5&]-24U%*"1E>'0I"B`@("!["B`@("`@("`@:68@*&5M
M<'1Y*"1E>'0I*2!["B`@("`@("`@("`@<F5T=7)N("=A<'!L:6-A=&EO;B]O
M8W1E="US=')E86TG.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1E
M>'0@/2!3=')I;F<Z.FQO=V5R*"1E>'0I.PH@("`@("`@("`@("`D;6%P(#T@
M)DU)345?36%G:6,Z.E]G971-:6UE17AT96YS:6]N36%P*"D["B`@("`@("`@
M("`@("1P;W,@/2`P.PH@("`@("`@("`@("!W:&EL92`H(6ES<V5T*"1M87!;
M)&5X=%TI("8F("1P;W,@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D
M<&]S(#T@<W1R<&]S*"1E>'0L("<N)RD["B`@("`@("`@("`@("`@("!I9B`H
M)'!O<R`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("`D97AT(#T@
M<W5B<W1R*"1E>'0L("1P;W,@*R`Q*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@:68@*&ES<V5T*"1M87!;)&5X=%TI
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&UA<%LD97AT73L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B`G>"UE>'1E
M;G-I;VXO)R`N("1E>'0["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T('1O(&-O;G9E<G0@82!F:6QE;F%M
M92!T;R!A($U)344@='EP92P@8F%S960@;VX@=&AE(&=L;V)A;"!(;W)D90H@
M("`@("H@86YD(&%P<&QI8V%T:6]N('-P96-I9FEC(&-O;F9I9R!F:6QE<RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE;F%M92`@5&AE(&9I
M;&5N86UE('1O(&)E(&UA<'!E9"!T;R!A($U)344@='EP92X*("`@("`J($!P
M87)A;2!B;V]L96%N("1U;FMN;W=N("!(;W<@<VAO=6QD('5N:VYO=VX@97AT
M96YS:6]N<R!B92!H86YD;&5D/R!)9@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@('1R=64L('=I;&P@<F5T=7)N("=X+65X=&5N<VEO;B\J)R!T
M>7!E<RX@($EF"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@9F%L
M<V4L('=I;&P@<F5T=7)N("=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@34E-12!T>7!E(&]F
M('1H92!F:6QE;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9FEL96YA;654
M;TU)344H)&9I;&5N86UE+"`D=6YK;F]W;B`]('1R=64I"B`@("!["B`@("`@
M("`@)'!O<R`]('-T<FQE;B@D9FEL96YA;64I("L@,3L*("`@("`@("`D='EP
M92`]("<G.PH*("`@("`@("`D;6%P(#T@)DU)345?36%G:6,Z.E]G971-:6UE
M17AT96YS:6]N36%P*"D["B`@("`@("`@9F]R("@D:2`](#`["B`@("`@("`@
M("`@("`D:2`\/2`D;6%P6R=?7TU!6%!%4DE/1%]?)UT@)B8*("`@("`@("`@
M("`@("`@("!S=')R<&]S*'-U8G-T<B@D9FEL96YA;64L(#`L("1P;W,@+2`Q
M*2P@)RXG*2`A/3T@9F%L<V4["B`@("`@("`@("`@("`D:2LK*2!["B`@("`@
M("`@("`@("1P;W,@/2!S=')R<&]S*'-U8G-T<B@D9FEL96YA;64L(#`L("1P
M;W,@+2`Q*2P@)RXG*2`K(#$["B`@("`@("`@?0H@("`@("`@("1T>7!E(#T@
M34E-15]-86=I8SHZ97AT5&]-24U%*'-U8G-T<B@D9FEL96YA;64L("1P;W,I
M*3L*"B`@("`@("`@:68@*&5M<'1Y*"1T>7!E*2!\?`H@("`@("`@("`@("`H
M(21U;FMN;W=N("8F("AS=')P;W,H)'1Y<&4L("=X+65X=&5N<VEO;B<I("$]
M/2!F86QS92DI*2!["B`@("`@("`@("`@(')E='5R;B`G87!P;&EC871I;VXO
M;V-T970M<W1R96%M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@)'1Y<&4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M071T96UP="!T;R!C;VYV97)T(&$@34E-12!T>7!E('1O(&$@9FEL92!E>'1E
M;G-I;VXL(&)A<V5D"B`@("`@*B!O;B!T:&4@9VQO8F%L($AO<F1E(&%N9"!A
M<'!L:6-A=&EO;B!S<&5C:69I8R!C;VYF:6<@9FEL97,N"B`@("`@*@H@("`@
M("H@268@=V4@8V%N;F]T(&UA<"!T:&4@='EP92!T;R!A(&9I;&4@97AT96YS
M:6]N+"!W92!R971U<FX@9F%L<V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D='EP92`@5&AE($U)344@='EP92!T;R!B92!M87!P960@=&\@82!F
M:6QE(&5X=&5N<VEO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(&9I;&4@97AT96YS:6]N(&]F('1H92!-24U%('1Y<&4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N($U)3454;T5X="@D='EP92D*("`@('L*("`@("`@("!I
M9B`H96UP='DH)'1Y<&4I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"@H@("`@("`@("1K97D@/2!A<G)A>5]S96%R8V@H)'1Y<&4L
M($U)345?36%G:6,Z.E]G971-:6UE17AT96YS:6]N36%P*"DI.PH@("`@("`@
M(&EF("@D:V5Y(#T]/2!F86QS92D@>PH@("`@("`@("`@("!L:7-T*"1M86IO
M<BP@)&UI;F]R*2`](&5X<&QO9&4H)R\G+"`D='EP92D["B`@("`@("`@("`@
M(&EF("@D;6%J;W(@/3T@)W@M97AT96YS:6]N)RD@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1M:6YO<CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H<W1R<&]S*"1M:6YO<BP@)W@M)RD@/3T](#`I('L*("`@("`@("`@("`@
M("`@(')E='5R;B!S=6)S='(H)&UI;F]R+"`R*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N("1K97D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@57-E<R!V87)I86YT<R!O9B!T:&4@54Y)6"`B9FEL92(@8V]M
M;6%N9"!T;R!A='1E;7!T('1O(&1E=&5R;6EN92!T:&4*("`@("`J($U)344@
M='EP92!O9B!A;B!U;FMN;W=N(&9I;&4N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<&%T:"`@("`@(%1H92!P871H('1O('1H92!F:6QE('1O(&%N
M86QY>F4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1M86=I8U]D8B`@4&%T:"!T
M;R!T:&4@;6EM92!M86=I8R!D871A8F%S92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE($U)344@='EP92!O9B!T:&4@9FEL92X@(%)E='5R
M;G,@9F%L<V4@:68@=&AE(&9I;&4*("`@("`J("`@("`@("`@("`@("`@("!T
M>7!E(&ES;B=T(')E8V]G;FEZ960@;W(@86X@97)R;W(@:&%P<&5N960N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%N86QY>F5&:6QE*"1P871H+"`D;6%G:6-?
M9&(@/2!N=6QL*0H@("`@>PH@("`@("`@("\J($EF('1H92!02%`@36EM971Y
M<&4@97AT96YS:6]N(&ES(&%V86EL86)L92P@=7-E('1H870N("HO"B`@("`@
M("`@:68@*%5T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G9FEL96EN9F\G*2D@>PH@
M("`@("`@("`@("!I9B`H96UP='DH)&UA9VEC7V1B*2D@>PH@("`@("`@("`@
M("`@("`@)')E<R`]($!F:6YF;U]O<&5N*$9)3$5)3D9/7TU)344I.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E<R`]($!F:6YF
M;U]O<&5N*$9)3$5)3D9/7TU)344L("1M86=I8U]D8BD["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*"1R97,I('L*("`@("`@("`@("`@("`@("1T
M>7!E(#T@9FEN9F]?9FEL92@D<F5S+"`D<&%T:"D["B`@("`@("`@("`@("`@
M("!F:6YF;U]C;&]S92@D<F5S*3L*"B`@("`@("`@("`@("`@("`O*B!296UO
M=F4@86YY(&%D9&ET:6]N86P@:6YF;W)M871I;VXN("HO"B`@("`@("`@("`@
M("`@("!F;W)E86-H("AA<G)A>2@G.R<L("<L)RP@)UQ<,"<I(&%S("1S97!A
M<F%T;W(I('L*("`@("`@("`@("`@("`@("`@("`D<&]S(#T@<W1R<&]S*"1T
M>7!E+"`D<V5P87)A=&]R*3L*("`@("`@("`@("`@("`@("`@("!I9B`H)'!O
M<R`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1Y<&4@
M/2!R=')I;2AS=6)S='(H)'1Y<&4L(#`L("1P;W,I*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M:68@*'!R96=?;6%T8V@H)WQ>6V$M>C`M.5TK+ULN+6$M>C`M.5TK)'QI)RP@
M)'1Y<&4I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T>7!E.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!I9B`H571I;#HZ97AT96YS:6]N17AI<W1S*"=M:6UE7VUA9VEC)RDI
M('L*("`@("`@("`@("`@<F5T=7)N('1R:6TH;6EM95]C;VYT96YT7W1Y<&4H
M)'!A=&@I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!5<V4@
M82!B=6EL="UI;B!M86=I8R!F:6QE+B`J+PH@("`@("`@("`@("`D;6EM95]M
M86=I8R`]("9-24U%7TUA9VEC.CI?9V5T36EM94UA9VEC1FEL92@I.PH@("`@
M("`@("`@("!I9B`H(2@D9G`@/2!`9F]P96XH)'!A=&@L("=R8B<I*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1M:6UE7VUA9VEC(&%S("1O9F9S970@/3X@
M)&]D871A*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D;V1A=&$@87,@
M)&QE;F=T:"`]/B`D;&1A=&$I('L*("`@("`@("`@("`@("`@("`@("!`9G-E
M96LH)&9P+"`D;V9F<V5T+"!3145+7U-%5"D["B`@("`@("`@("`@("`@("`@
M("`@)&QO;VMU<"`]($!F<F5A9"@D9G`L("1L96YG=&@I.PH@("`@("`@("`@
M("`@("`@("`@(&EF("@A96UP='DH)&QD871A6R1L;V]K=7!=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1L9&%T85LD;&]O:W5P73L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@9F%L<V4["B`@("!]"@H*("`@("\J*@H@("`@("H@57-E<R!V87)I
M86YT<R!O9B!T:&4@54Y)6"`B9FEL92(@8V]M;6%N9"!T;R!A='1E;7!T('1O
M(&1E=&5R;6EN92!T:&4*("`@("`J($U)344@='EP92!O9B!A;B!U;FMN;W=N
M(&)Y=&4@<W1R96%M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1A
M=&$@("`@("!4:&4@9FEL92!D871A('1O(&%N86QY>F4N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1M86=I8U]D8B`@4&%T:"!T;R!T:&4@;6EM92!M86=I8R!D
M871A8F%S92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($U)
M344@='EP92!O9B!T:&4@9FEL92X@(%)E='5R;G,@9F%L<V4@:68@=&AE(&9I
M;&4*("`@("`J("`@("`@("`@("`@("`@("!T>7!E(&ES;B=T(')E8V]G;FEZ
M960@;W(@86X@97)R;W(@:&%P<&5N960N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%N86QY>F5$871A*"1D871A+"`D;6%G:6-?9&(@/2!N=6QL*0H@("`@>PH@
M("`@("`@("\J($EF('1H92!02%`@36EM971Y<&4@97AT96YS:6]N(&ES(&%V
M86EL86)L92P@=7-E('1H870N("HO"B`@("`@("`@:68@*%5T:6PZ.F5X=&5N
M<VEO;D5X:7-T<R@G9FEL96EN9F\G*2D@>PH@("`@("`@("`@("!I9B`H96UP
M='DH)&UA9VEC7V1B*2D@>PH@("`@("`@("`@("`@("`@)')E<R`]($!F:6YF
M;U]O<&5N*$9)3$5)3D9/7TU)344I.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)')E<R`]($!F:6YF;U]O<&5N*$9)3$5)3D9/7TU)
M344L("1M86=I8U]D8BD["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*"$D<F5S*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1T>7!E(#T@9FEN9F]?8G5F9F5R*"1R
M97,L("1D871A*3L*("`@("`@("`@("`@9FEN9F]?8VQO<V4H)')E<RD["@H@
M("`@("`@("`@("`O*B!296UO=F4@86YY(&%D9&ET:6]N86P@:6YF;W)M871I
M;VXN("HO"B`@("`@("`@("`@("1P;W,@/2!S=')P;W,H)'1Y<&4L("<[)RD[
M"B`@("`@("`@("`@(&EF("@D<&]S("$]/2!F86QS92D@>PH@("`@("`@("`@
M("`@("`@)'1Y<&4@/2!R=')I;2AS=6)S='(H)'1Y<&4L(#`L("1P;W,I*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D<&]S(#T@<W1R<&]S*"1T>7!E
M+"`G+"<I.PH@("`@("`@("`@("!I9B`H)'!O<R`A/3T@9F%L<V4I('L*("`@
M("`@("`@("`@("`@("1T>7!E(#T@<G1R:6TH<W5B<W1R*"1T>7!E+"`P+"`D
M<&]S*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1T>7!E
M.PH@("`@("`@('T*"B`@("`@("`@+RH@57-E(&$@8G5I;'0M:6X@;6%G:6,@
M9FEL92X@*B\*("`@("`@("`D;6EM95]M86=I8R`]("9-24U%7TUA9VEC.CI?
M9V5T36EM94UA9VEC1FEL92@I.PH@("`@("`@(&9O<F5A8V@@*"1M:6UE7VUA
M9VEC(&%S("1O9F9S970@/3X@)&]D871A*2!["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1O9&%T82!A<R`D;&5N9W1H(#T^("1L9&%T82D@>PH@("`@("`@("`@
M("`@("`@)&QO;VMU<"`]('-U8G-T<B@D9&%T82P@)&]F9G-E="P@)&QE;F=T
M:"D["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1L9&%T85LD;&]O:W5P
M72DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)&QD871A6R1L;V]K
M=7!=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+TU$3BYP:'``````
M````````````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C(W,S(`,3`U,34T
M,S,W-#<`,#(Q,S4T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!4:&4@34E-15]-1$XZ.B!C;&%S<R!I
M;7!L96UE;G1S($UE<W-A9V4@1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N<R!A
M<PH@*B!D97-C<FEB960@8GD@4D9#(#(R.3@N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+TU)344O34E-12]-1$XN<&AP+'8@,2XT+C$P+C@@,C`P-B\P,2\R
M-"`R,3HS,CHU-B!S;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T
M+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&-U<F5C86YT:2YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@
M/'-L=7-A<GI`8W5R96-A;G1I+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP
M"B`J($!P86-K86=E($AO<F1E7TU)344*("HO"F-L87-S($U)345?341.('L*
M"B`@("`O*BH*("`@("`J(%1H92!-24U%7TAE861E<G,@;V)J96-T+@H@("`@
M("H*("`@("`J($!V87(@34E-15](96%D97)S"B`@("`@*B\*("`@('9A<B`D
M7VAE861E<G,["@H@("`@+RHJ"B`@("`@*B!4:&4@=&5X="!O9B!T:&4@;W)I
M9VEN86P@;65S<V%G92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)%]M<V=T97AT(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@
M*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@34E-15](96%D
M97)S("1M:6UE7VAE861E<G,@($$@34E-15](96%D97)S(&]B:F5C="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@34E-15]-1$XH)&UI;65?:&5A9&5R<R`](&YU
M;&PI"B`@("!["B`@("`@("`@)'1H:7,M/E]H96%D97)S(#T@)&UI;65?:&5A
M9&5R<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&%D9')E
M<W,@=&\@<F5T=7)N('1H92!-1$X@=&\N"B`@("`@*B!2971U<FYS(&YU;&P@
M:68@;F\@341.(&ES(')E<75E<W1E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE(&%D9')E<W,@=&\@<V5N9"!T:&4@341.('1O+B!2971U
M<FYS(&YU;&P@:68@;F\*("`@("`J("`@("`@("`@("`@("`@("!-1$X@:7,@
M<F5Q=65S=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971-1$Y2971U<FY!
M9&1R*"D*("`@('L*("`@("`@("`O*B!21D,@,C(Y."!;,BXQ72!R97%U:7)E
M<R!T:&4@1&ES<&]S:71I;VXM3F]T:69I8V%I;VXM5&\@:&5A9&5R"B`@("`@
M("`@("H@9F]R(&%N($U$3B!T;R!B92!C<F5A=&5D+B`J+PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7VAE861E<G,M/F=E=%9A;'5E*"=$:7-P;W-I=&EO;BU.
M;W1I9FEC871I;VXM5&\G*3L*("`@('T*"B`@("`O*BH*("`@("`J($ES('5S
M97(@:6YP=70@<F5Q=6ER960@=&\@<V5N9"!T:&4@341./PH@("`@("H@17AP
M;&EC:70@8V]N9FER;6%T:6]N(&ES(&YE961E9"!I;B!S;VUE(&-A<V5S('1O
M('!R979E;G0@;6%I;"!L;V]P<PH@("`@("H@86YD('1H92!U<V4@;V8@341.
M<R!F;W(@;6%I;"!B;VUB:6YG+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@27,@97AP;&EC:70@=7-E<B!I;G!U="!R97%U:7)E9"!T;R!S96YD
M('1H92!-1$X_"B`@("`@*B\*("`@(&9U;F-T:6]N('5S97)#;VYF:7)M871I
M;VY.965D960H*0H@("`@>PH@("`@("`@("1R971U<FY?<&%T:"`]("1T:&ES
M+3Y?:&5A9&5R<RT^9V5T5F%L=64H)U)E='5R;BU0871H)RD["@H@("`@("`@
M("\J(%)&0R`R,CDX(%LR+C%=.B!%>'!L:6-I="!C;VYF:7)M871I;VX@:7,@
M;F5E9&5D(&EF('1H97)E(&ES(&YO"B`@("`@("`@("H@4F5T=7)N+5!A=&@@
M:6X@=&AE(&AE861E<BX@06QS;RP@(FEF('1H92!M97-S86=E(&-O;G1A:6YS
M(&UO<F4*("`@("`@("`@*B!T:&%N(&]N92!2971U<FXM4&%T:"!H96%D97(L
M('1H92!I;7!L96UE;G1A=&EO;B!M87D@6UT@=')E870@=&AE"B`@("`@("`@
M("H@<VET=6%T:6]N(&%S(&$@9F%I;'5R92!O9B!T:&4@8V]M<&%R:7-O;BX@
M*B\*("`@("`@("!I9B`H96UP='DH)')E='5R;E]P871H*2!\?"!I<U]A<G)A
M>2@D<F5T=7)N7W!A=&@I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E("=-86EL+U)&0S@R,BYP
M:'`G.PH@("`@("`@("1P87)S97(@/2`F;F5W($UA:6Q?4D9#.#(R*"D["@H@
M("`@("`@("\J(%)&0R`R,CDX(%LR+C%=.B!%>'!L:6-I="!C;VYF:7)M871I
M;VX@:7,@;F5E9&5D(&EF('1H97)E(&ES(&UO<F4*("`@("`@("`@*B!T:&%N
M(&]N92!D:7-T:6YC="!A9&1R97-S(&EN('1H92!$:7-P;W-I=&EO;BU.;W1I
M9FEC871I;VXM5&\*("`@("`@("`@*B!H96%D97(N("HO"B`@("`@("`@)&%D
M9')?87)R(#T@)'!A<G-E<BT^<&%R<V5!9&1R97-S3&ES="@D=&AI<RT^9V5T
M341.4F5T=7)N061D<B@I+"!N=6QL+"!N=6QL+"!F86QS92D["B`@("`@("`@
M:68@*&ES7V$H)&%D9')?87)R+"`G4$5!4E]%<G)O<B<I('Q\("AC;W5N="@D
M861D<E]A<G(I(#X@,2DI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?0H*("`@("`@("`O*B!21D,@,C(Y."!;,BXQ72!S=&%T97,@=&AA
M="`B341.<R!32$]53$0@3D]4(&)E('-E;G0@875T;VUA=&EC86QL>0H@("`@
M("`@("`J(&EF('1H92!A9&1R97-S(&EN('1H92!$:7-P;W-I=&EO;BU.;W1I
M9FEC871I;VXM5&\@:&5A9&5R(&1I9F9E<G,*("`@("`@("`@*B!F<F]M('1H
M92!A9&1R97-S(&EN('1H92!2971U<FXM4&%T:"!H96%D97(N(B!4:&ES(&-O
M;7!A<FES;VX@:7,*("`@("`@("`@*B!C87-E+7-E;G-I=&EV92!F;W(@=&AE
M(&UA:6QB;W@@<&%R="!A;F0@8V%S92UI;G-E;G-I=&EV92!F;W(@=&AE"B`@
M("`@("`@("H@:&]S="!P87)T+B`J+PH@("`@("`@("1R971?87)R(#T@)'!A
M<G-E<BT^<&%R<V5!9&1R97-S3&ES="@D<F5T=7)N7W!A=&@L(&YU;&PL(&YU
M;&PL(&9A;'-E*3L*("`@("`@("!I9B`H(6ES7V$H)')E=%]A<G(L("=014%2
M7T5R<F]R)RD@)B8*("`@("`@("`@("`@*"@D861D<E]A<G);,%TM/FUA:6QB
M;W@@(3T@)')E=%]A<G);,%TM/FUA:6QB;W@I('Q\"B`@("`@("`@("`@("A3
M=')I;F<Z.FQO=V5R*"1A9&1R7V%R<ELP72T^:&]S="D@(3T@4W1R:6YG.CIL
M;W=E<B@D<F5T7V%R<ELP72T^:&]S="DI*2D@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%=H96X@9V5N97)A=&EN9R!T:&4@341.+"!S
M:&]U;&0@=V4@<F5T=7)N('1H92!E;FET<F4@=&5X="!O9B!T:&4*("`@("`J
M(&]R:6=I;F%L(&UE<W-A9V4_("!4:&4@9&5F875L="!I<R!N;R`M('=E(&]N
M;'D@<F5T=7)N('1H92!H96%D97)S(&]F"B`@("`@*B!T:&4@;W)I9VEN86P@
M;65S<V%G92X@268@=&AE('1E>'0@:7,@<&%S<V5D(&EN('9I82!T:&ES(&UE
M=&AO9"P@=V4*("`@("`J('=I;&P@<F5T=7)N('1H92!E;G1I<F4@;65S<V%G
M92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X
M="!O9B!T:&4@;W)I9VEN86P@;65S<V%G92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@;W)I9VEN86Q-97-S86=E5&5X="@D=&5X="D*("`@('L*("`@("`@("`D
M=&AI<RT^7VUS9W1E>'0@/2`D=&5X=#L*("`@('T*"B`@("`O*BH*("`@("`J
M($=E;F5R871E('1H92!-1$X@86-C;W)D:6YG('1O('1H92!S<&5C:69I8V%T
M:6]N<R!L:7-T960@:6X@4D9#"B`@("`@*B`R,CDX(%LS72X*("`@("`J"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D86-T:6]N("`@5V%S('1H:7,@341.('1Y
M<&4@82!R97-U;'0@;V8@82!M86YU86P@86-T:6]N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@;VX@<&%R="!O9B!T:&4@=7-E<C\*("`@("`J
M($!P87)A;2!B;V]L96%N("1S96YD:6YG("!787,@=&AI<R!-1$X@<V5N="!A
M<R!A(')E<W5L="!O9B!A(&UA;G5A;`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%C=&EO;B!O;B!P87)T(&]F('1H92!U<V5R/PH@("`@("H@
M0'!A<F%M('-T<FEN9R`D='EP92`@("`@(%1H92!T>7!E(&]F(&%C=&EO;B!P
M97)F;W)M960@8GD@=&AE('5S97(N"B`@("`@*B`\<')E/@H@("`@("H@4&5R
M(%)&0R`R,CDX(%LS+C(N-BXR72!T:&4@9F]L;&]W:6YG('1Y<&5S(&%R92!V
M86QI9#H*("`@("`J(#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T*("`@("`J("=D:7-P;&%Y960G"B`@("`@
M*B`G9&ES<&%T8VAE9"<*("`@("`J("=P<F]C97-S960G"B`@("`@*B`G9&5L
M971E9"<*("`@("`J("=D96YI960G"B`@("`@*B`G9F%I;&5D)PH@("`@("H@
M/"]P<F4^"B`@("`@*B!`<&%R86T@87)R87D@)&UO9"`@("`@("`@5&AE(&QI
M<W0@;V8@;6]D:69I8V%T:6]N<RX*("`@("`J(#QP<F4^"B`@("`@*B!097(@
M4D9#(#(R.3@@6S,N,BXV+C-=('1H92!F;VQL;W=I;F<@;6]D:69I8V%T:6]N
M<R!A<F4@=F%L:60Z"B`@("`@*B`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*("`@("`J("=E
M<G)O<B<*("`@("`J("=W87)N:6YG)PH@("`@("H@)W-U<&5R<V5D960G"B`@
M("`@*B`G97AP:7)E9"<*("`@("`J("=M86EL8F]X+71E<FUI;F%T960G"B`@
M("`@*B`\+W!R93X*("`@("`J($!P87)A;2!A<G)A>2`D97)R("`@("`@("!)
M9B`D='EP92!I<R`G9F%I;'5E)R!O<B`D;6]D(&ES(&5I=&AE<B`G97)R;W(G
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@;W(@)W=A<FYI;F<G
M+"!T:&4@861D:71I;VYA;"!I;F9O<FUA=&EO;B!T;PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@('!R;W9I9&4N("!+97D@:7,@=&AE('1Y<&4@
M;V8@;6]D:69I8V%T:6]N+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@('9A;'5E(&ES('1H92!T97AT+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1R=64@;VX@<W5C8V5S<RP@4$5!4E]%<G)O<B!O8FIE8W0@;VX@
M97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E;F5R871E*"1A8W1I;VXL
M("1S96YD:6YG+"`D='EP92P@)&UO9"`](&%R<F%Y*"DL("1E<G(@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12](
M96%D97)S+G!H<"<["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%
M+TUE<W-A9V4N<&AP)SL*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TED
M96YT:71Y+G!H<"<["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]497AT
M+G!H<"<["@H@("`@("`@("\J(%-E="!U<"!S;VUE('9A<FEA8FQE<R!W92!U
M<V4@;&%T97(N("HO"B`@("`@("`@)&ED96YT:71Y(#T@)DED96YT:71Y.CIS
M:6YG;&5T;VXH*3L*("`@("`@("`D9G)O;5]A9&1R(#T@)&ED96YT:71Y+3YG
M971$969A=6QT1G)O;4%D9')E<W,H*3L*"B`@("`@("`@)'1O(#T@)'1H:7,M
M/F=E=$U$3E)E='5R;D%D9'(H*3L*"B`@("`@("`@)'5A(#T@)'1H:7,M/E]H
M96%D97)S+3YG971!9V5N=$AE861E<B@I.PH*("`@("`@("`D;W)I9U]R96-I
M<"`]("1T:&ES+3Y?:&5A9&5R<RT^9V5T5F%L=64H)T]R:6=I;F%L+5)E8VEP
M:65N="<I.PH@("`@("`@(&EF("@A96UP='DH)&]R:6=?<F5C:7`I("8F(&ES
M7V%R<F%Y*"1O<FEG7W)E8VEP*2D@>PH@("`@("`@("`@("`D;W)I9U]R96-I
M<"`]("1O<FEG7W)E8VEP6S!=.PH@("`@("`@('T*"B`@("`@("`@)&US9U]I
M9"`]("1T:&ES+3Y?:&5A9&5R<RT^9V5T5F%L=64H)TUE<W-A9V4M240G*3L*
M"B`@("`@("`@+RH@0W)E871E('1H92!$:7-P;W-I=&EO;B!F:65L9"!N;W<@
M*%)&0R`R,CDX(%LS+C(N-ETI+B`J+PH@("`@("`@("1D:7-P;R`]("=$:7-P
M;W-I=&EO;CH@)R`N"B`@("`@("`@("`@("`@("`@*"@D86-T:6]N*2`_("=M
M86YU86PM86-T:6]N)R`Z("=A=71O;6%T:6,M86-T:6]N)RD@+@H@("`@("`@
M("`@("`@("`@("<O)R`N"B`@("`@("`@("`@("`@("`@*"@D<V5N9&EN9RD@
M/R`G341.+7-E;G0M;6%N=6%L;'DG(#H@)TU$3BUS96YT+6%U=&]M871I8V%L
M;'DG*2`N"B`@("`@("`@("`@("`@("`@)SL@)R`N"B`@("`@("`@("`@("`@
M("`@)'1Y<&4["B`@("`@("`@:68@*"%E;7!T>2@D;6]D*2D@>PH@("`@("`@
M("`@("`D9&ES<&\@+CT@)R\G("X@:6UP;&]D92@G+"`G+"`D;6]D*3L*("`@
M("`@("!]"@H@("`@("`@("\J(%-E="!U<"!T:&4@;6%I;"!H96%D97)S+B`J
M+PH@("`@("`@("1M<V=?:&5A9&5R<R`]("9N97<@34E-15](96%D97)S*"D[
M"B`@("`@("`@)&US9U]H96%D97)S+3YA9&1-97-S86=E261(96%D97(H*3L*
M("`@("`@("`D;7-G7VAE861E<G,M/F%D9$%G96YT2&5A9&5R*"1U82D["B`@
M("`@("`@)&US9U]H96%D97)S+3YA9&1(96%D97(H)T1A=&4G+"!D871E*"=R
M)RDI.PH@("`@("`@("1M<V=?:&5A9&5R<RT^861D2&5A9&5R*"=&<F]M)RP@
M)&9R;VU?861D<BD["B`@("`@("`@)&US9U]H96%D97)S+3YA9&1(96%D97(H
M)U1O)RP@)'1H:7,M/F=E=$U$3E)E='5R;D%D9'(H*2D["B`@("`@("`@)&US
M9U]H96%D97)S+3YA9&1(96%D97(H)U-U8FIE8W0G+"!?*")$:7-P;W-I=&EO
M;B!.;W1I9FEC871I;VXB*2D["@H@("`@("`@("\J($U$3G,@87)E(&$@<W5B
M='EP92!O9B`G;75L=&EP87)T+W)E<&]R="<N("HO"B`@("`@("`@)&US9R`]
M("9N97<@34E-15]-97-S86=E*"D["B`@("`@("`@)&US9RT^<V5T5'EP92@G
M;75L=&EP87)T+W)E<&]R="<I.PH@("`@("`@("1M<V<M/G-E=$-O;G1E;G14
M>7!E4&%R86UE=&5R*"=R97!O<G0M='EP92<L("=D:7-P;W-I=&EO;BUN;W1I
M9FEC871I;VXG*3L*"B`@("`@("`@+RH@5&AE(&9I<G-T('!A<G0@:7,@82!H
M=6UA;B!R96%D86)L92!M97-S86=E+B`J+PH@("`@("`@("1P87)T7V]N92`]
M("9N97<@34E-15]087)T*"=T97AT+W!L86EN)RD["B`@("`@("`@)'!A<G1?
M;VYE+3YS971#:&%R<V5T*$Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("!I
M9B`H)'1Y<&4@/3T@)V1I<W!L87EE9"<I('L*("`@("`@("`@("`@)'!A<G1?
M;VYE+3YS971#;VYT96YT<RAS<')I;G1F*%\H(E1H92!M97-S86=E('-E;G0@
M;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P
M;&%Y960N7&Y4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E
M(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB*2P@)'1H:7,M/E]H96%D
M97)S+3YG971686QU92@G1&%T92<I+"`D=&AI<RT^7VAE861E<G,M/F=E=%9A
M;'5E*"=4;R<I+"`D=&AI<RT^7VAE861E<G,M/F=E=%9A;'5E*"=3=6)J96-T
M)RDI*3L*("`@("`@("!]"B`@("`@("`@+R\@5$]$3SH@365S<V%G97,@9F]R
M(&]T:&5R(&YO=&EF:6-A=&EO;B!T>7!E<RX*("`@("`@("`D;7-G+3YA9&10
M87)T*"1P87)T7V]N92D["@H@("`@("`@("\J(%1H92!S96-O;F0@<&%R="!I
M<R!A(&UA8VAI;F4M<&%R<V5A8FQE(&1E<V-R:7!T:6]N+B`J+PH@("`@("`@
M("1P87)T7W1W;R`]("9N97<@34E-15]087)T*"=M97-S86=E+V1I<W!O<VET
M:6]N+6YO=&EF:6-A=&EO;B<I.PH@("`@("`@("1P87)T7W1W;RT^<V5T0V]N
M=&5N=',H)U)E<&]R=&EN9RU503H@)R`N("1'3$]"04Q36R=C;VYF)UU;)W-E
M<G9E<B==6R=N86UE)UT@+B`G.R`G("X@)'5A("X@(EQN(BD["B`@("`@("`@
M:68@*"%E;7!T>2@D;W)I9U]R96-I<"DI('L*("`@("`@("`@("`@)'!A<G1?
M='=O+3YA<'!E;F1#;VYT96YT<R@G3W)I9VEN86PM4F5C:7!I96YT.B!R9F,X
M,C([)R`N("1O<FEG7W)E8VEP("X@(EQN(BD["B`@("`@("`@?0H@("`@("`@
M("1P87)T7W1W;RT^87!P96YD0V]N=&5N=',H)T9I;F%L+5)E8VEP:65N=#H@
M<F9C.#(R.R<@+B`D9G)O;5]A9&1R("X@(EQN(BD["B`@("`@("`@:68@*"%E
M;7!T>2@D;7-G7VED*2D@>PH@("`@("`@("`@("`D<&%R=%]T=V\M/F%P<&5N
M9$-O;G1E;G1S*"=/<FEG:6YA;"U-97-S86=E+4E$.B!R9F,X,C([)R`N("1M
M<V=?:60@+B`B7&XB*3L*("`@("`@("!]"B`@("`@("`@)'!A<G1?='=O+3YA
M<'!E;F1#;VYT96YT<R@D9&ES<&\@+B`B7&XB*3L*("`@("`@("!I9B`H*"1T
M>7!E(#T]("=F86EL960G*2`F)B!I<W-E="@D97)R6R=F86EL960G72DI('L*
M("`@("`@("`@("`@)'!A<G1?='=O+3YA<'!E;F1#;VYT96YT<R@G1F%I;'5R
M93H@)R`N("1E<G);)V9A:6QE9"==("X@(EQN(BD["B`@("`@("`@?0H@("`@
M("`@(&EF("AI;E]A<G)A>2@G97)R;W(G+"`D;6]D*2`F)B!I<W-E="@D97)R
M6R=E<G)O<B==*2D@>PH@("`@("`@("`@("`D<&%R=%]T=V\M/F%P<&5N9$-O
M;G1E;G1S*"=%<G)O<CH@)R`N("1E<G);)V5R<F]R)UT@+B`B7&XB*3L*("`@
M("`@("!]"B`@("`@("`@:68@*&EN7V%R<F%Y*"=W87)N:6YG)RP@)&UO9"D@
M)B8@:7-S970H)&5R<ELG=V%R;FEN9R==*2D@>PH@("`@("`@("`@("`D<&%R
M=%]T=V\M/F%P<&5N9$-O;G1E;G1S*"=787)N:6YG.B`G("X@)&5R<ELG=V%R
M;FEN9R==("X@(EQN(BD["B`@("`@("`@?0H@("`@("`@("1M<V<M/F%D9%!A
M<G0H)'!A<G1?='=O*3L*"B`@("`@("`@+RH@5&AE('1H:7)D('!A<G0@:7,@
M=&AE('1E>'0@;V8@=&AE(&]R:6=I;F%L(&UE<W-A9V4N("!21D,@,C(Y."!;
M,UT*("`@("`@("`@*B!A;&QO=W,@=7,@=&\@<F5T=7)N(&]N;'D@82!P;W)T
M:6]N(&]F('1H92!E;G1I<F4@;65S<V%G92`M('1H:7,*("`@("`@("`@*B!I
M<R!L969T('5P('1O('1H92!U<V5R+B`J+PH@("`@("`@("1P87)T7W1H<F5E
M(#T@)FYE=R!-24U%7U!A<G0H)VUE<W-A9V4O<F9C.#(R)RD["B`@("`@("`@
M)'!A<G1?=&AR964M/G-E=$-O;G1E;G1S*"1T:&ES+3Y?:&5A9&5R<RT^=&]3
M=')I;F<H*2D["B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7VUS9W1E>'0I
M*2!["B`@("`@("`@("`@("1P87)T7W1H<F5E+3YA<'!E;F1#;VYT96YT<R@B
M7&XB("X@)'1H:7,M/E]M<V=T97AT*3L*("`@("`@("!]"B`@("`@("`@)&US
M9RT^861D4&%R="@D<&%R=%]T:')E92D["@H@("`@("`@("1M<V=?:&5A9&5R
M<RT^861D34E-14AE861E<G,H)&US9RD["@H@("`@("`@(')E='5R;B`D;7-G
M+3YS96YD*"1T;RP@)&US9U]H96%D97)S*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($%D9"!A($U$3B`H<F5A9"!R96-E:7!T*2!R97%U97-T(&AE861E<G,@
M=&\@=&AE($U)345?2&5A9&5R<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A
M<F%M($U)345?2&5A9&5R<R`F)&AE861O8B`@5&AE($U)345?2&5A9&5R<R!O
M8FIE8W0@=&\@861D('1H92!H96%D97)S"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!T;RX*("`@("`J($!P87)A;2!S=')I;F<@)'1O
M("`@("`@("`@("`@(%1H92!A9&1R97-S('1H92!R96-E:7!T('-H;W5L9"!B
M92!M86EL960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('1O+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1-1$Y297%U97-T2&5A9&5R
M<R@F)&AE861O8BP@)'1O*0H@("`@>PH@("`@("`@("\J(%1H:7,@:7,@=&AE
M(%)&0R`R,CDX('=A>2!O9B!R97%U97-T:6YG(&$@<F5C96EP="X@*B\*("`@
M("`@("`D:&5A9&]B+3YA9&1(96%D97(H)T1I<W!O<VET:6]N+4YO=&EF:6-A
M=&EO;BU4;R<L("1T;RD["B`@("!]"@I]"@``````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O34E-12]-97-S86=E+G!H<```````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#(T,C0Q`#$P-3$U-#,S-S4P`#`R,C,Q,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`H*<F5Q
M=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]087)T+G!H<"<["@HO
M*BH*("H@5&AE($U)345?365S<V%G93HZ(&-L87-S('!R;W9I9&5S(&UE=&AO
M9',@9F]R(&-R96%T:6YG(&%N9"!M86YI<'5L871I;F<*("H@34E-12!E;6%I
M;"!M97-S86=E<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP+'8@,2XW-BXQ,"XQ,B`R,#`V+S`Q+S`Q(#(Q.C(X.C(T
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P,BTR
M,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O
M+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N
M8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!-:6-H865L(%-L
M=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC
M92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]-24U%"B`J+PIC;&%S
M<R!-24U%7TUE<W-A9V4@97AT96YD<R!-24U%7U!A<G0@>PH*("`@("\J*@H@
M("`@("H@2&%S('1H92!M97-S86=E(&)E96X@<&%R<V5D('9I82!B=6EL9$UE
M<W-A9V4H*3\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@
M("`@=F%R("1?8G5I;&0@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%1H92!S
M97)V97(@=&\@9&5F875L="!U;G%U86QI9FEE9"!A9&1R97-S97,@=&\N"B`@
M("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?9&5F
M875L=%-E<G9E<B`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O
M<B`M(&-R96%T97,@82!N97<@34E-12!E;6%I;"!M97-S86=E+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&1E9F%U;'1397)V97(@(%1H92!S97)V
M97(@=&\@9&5F875L="!U;G%U86QI9FEE9`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@861D<F5S<V5S('1O+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!-24U%7TUE<W-A9V4H)&1E9F%U;'1397)V97(@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1D969A=6QT4V5R=F5R*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7V1E9F%U;'1397)V97(@/2`D7U-%4E9%4ELG
M4T525D527TY!344G73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M=&AI<RT^7V1E9F%U;'1397)V97(@/2`D9&5F875L=%-E<G9E<CL*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@82!-24U%7TUE<W-A
M9V4@;V)J96-T(&9R;VT@82!-24U%7U!A<G0@;V)J96-T+@H@("`@("H@5&AI
M<R!F=6YC=&EO;B!C86X@8F4@8V%L;&5D('-T871I8V%L;'D@=FEA.@H@("`@
M("H@("`@34E-15]-97-S86=E.CIC;VYV97)T34E-15!A<G0H*3L*("`@("`J
M"B`@("`@*B!`<&%R86T@34E-15]087)T("8D;6EM95]P87)T("!4:&4@34E-
M15]087)T(&]B:F5C="X*("`@("`J($!P87)A;2!S=')I;F<@)'-E<G9E<B`@
M("`@("`@(%1H92!S97)V97(@=&\@9&5F875L="!U;G%U86QI9FEE9`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@861D<F5S<V5S('1O
M+@H@("`@("H*("`@("`J($!R971U<FX@34E-15]-97-S86=E("!4:&4@;F5W
M($U)345?365S<V%G92!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N("9C
M;VYV97)T34E-15!A<G0H)B1M:6UE7W!A<G0L("1S97)V97(@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&EF("@A)&UI;65?<&%R="T^9V5T34E-14ED*"DI('L*
M("`@("`@("`@("`@)&UI;65?<&%R="T^<V5T34E-14ED*#$I.PH@("`@("`@
M('T*"B`@("`@("`@)&UI;65?;65S<V%G92`]("9N97<@34E-15]-97-S86=E
M*"1S97)V97(I.PH@("`@("`@("1M:6UE7VUE<W-A9V4M/F%D9%!A<G0H)&UI
M;65?<&%R="D["B`@("`@("`@)&UI;65?;65S<V%G92T^8G5I;&1-97-S86=E
M*"D["@H@("`@("`@(')E='5R;B`D;6EM95]M97-S86=E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5N9',@=&AI<R!M97-S86=E+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&5M86EL("`@(%1H92!A9&1R97-S(&QI<W0@=&\@
M<V5N9"!T;RX*("`@("`J($!P87)A;2!M:7AE9"`F)&AE861E<G,@(%1H92!-
M24U%7TAE861E<G,@;V)J96-T(&AO;&1I;F<@=&AI<R!M97-S86=E)W,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@(&AE861E<G,L(&]R(&$@:&%S
M:"!W:71H(&AE861E<BT^=F%L=64@;6%P<&EN9W,N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1D<FEV97(@("!4:&4@36%I;"!D<FEV97(@=&\@=7-E("AS:6YC
M92!(;W)D92`S+C`N-"DN"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@
M("!!;GD@<&%R86UE=&5R<R!N96-E<W-A<GD@9F]R('1H92!-86EL(&1R:79E
M<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@*'-I;F-E($AO<F1E
M(#,N,"XT*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N
M('-U8V-E<W,L(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E;F0H)&5M86EL+"`F)&AE861E<G,L("1D<FEV97(@/2!N=6QL
M+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!G;&]B86P@)&-O
M;F8["B`@("`@("`@<W1A=&EC("1M86EL97(["@H@("`@("`@(&EF("@A:7-S
M970H)&UA:6QE<BDI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=-86EL
M+G!H<"<["B`@("`@("`@("`@(&EF("@A:7-S970H)&1R:79E<BDI('L*("`@
M("`@("`@("`@("`@("1D<FEV97(@/2`D8V]N9ELG;6%I;&5R)UU;)W1Y<&4G
M73L*("`@("`@("`@("`@("`@("1P87)A;7,@/2`D8V]N9ELG;6%I;&5R)UU;
M)W!A<F%M<R==.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1M86EL97(@
M/2!-86EL.CIF86-T;W)Y*"1D<FEV97(L("1P87)A;7,I.PH@("`@("`@('T*
M"B`@("`@("`@)&US9R`]("1T:&ES+3YT;U-T<FEN9R@I.PH@("`@("`@(&EF
M("AI<U]O8FIE8W0H)&AE861E<G,I*2!["B`@("`@("`@("`@("1H96%D97)!
M<G)A>2`]("1T:&ES+3YE;F-O9&4H)&AE861E<G,M/G1O07)R87DH*2P@)'1H
M:7,M/F=E=$-H87)S970H*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&AE861E<D%R<F%Y(#T@)'1H:7,M/F5N8V]D92@D:&5A9&5R<RP@)'1H
M:7,M/F=E=$-H87)S970H*2D["B`@("`@("`@?0H*("`@("`@("`O*B!-86ME
M('-U<F4@=&AE(&UE<W-A9V4@:&%S(&$@=')A:6QI;F<@;F5W;&EN92X@*B\*
M("`@("`@("!I9B`H<W5B<W1R*"1M<V<L("TQ*2`A/2`B7&XB*2!["B`@("`@
M("`@("`@("1M<V<@+CT@(EQN(CL*("`@("`@("!]"@H@("`@("`@("1R97-U
M;'0@/2`D;6%I;&5R+3YS96YD*$U)344Z.F5N8V]D94%D9')E<W,H)&5M86EL
M*2P@)&AE861E<D%R<F%Y+"`D;7-G*3L*"B`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2`F)@H@("`@("`@("`@("`D8V]N9ELG;6%I
M;&5R)UU;)W1Y<&4G72`]/2`G<V5N9&UA:6PG*2!["B`@("`@("`@("`@("\O
M($EN=&5R<')E="!R971U<FX@=F%L=65S(&%S(&1E9FEN960@:6X@+W5S<B]I
M;F-L=61E+W-Y<V5X:71S+F@*("`@("`@("`@("`@<W=I=&-H("@D<F5S=6QT
M+3YG971#;V1E*"DI('L*("`@("`@("`@("`@8V%S92`V-#H@+R\@15A?55-!
M1T4*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H
M(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(I("X@)R`H-C0I)SL*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`V-3H@+R\@15A?
M1$%404524@H@("`@("`@("`@("`@("`@)&5R<F]R(#T@)W-E;F1M86EL.B`G
M("X@7R@B9&%T82!F;W)M870@97)R;W(B*2`N("<@*#8U*2<["B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@-C8Z("\O($587TY/
M24Y0550*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N
M(%\H(F-A;FYO="!O<&5N(&EN<'5T(BD@+B`G("@V-BDG.PH@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#8W.B`O+R!%6%].3U53
M15(*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H
M(F%D9')E<W-E92!U;FMN;W=N(BD@+B`G("@V-RDG.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#8X.B`O+R!%6%].3TA/4U0*
M("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H(FAO
M<W0@;F%M92!U;FMN;W=N(BD@+B`G("@V."DG.PH@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("!C87-E(#8Y.B`O+R!%6%]53D%604E,04),
M10H@("`@("`@("`@("`@("`@)&5R<F]R(#T@)W-E;F1M86EL.B`G("X@7R@B
M<V5R=FEC92!U;F%V86EL86)L92(I("X@)R`H-CDI)SL*("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`W,#H@+R\@15A?4T]&5%=!
M4D4*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H
M(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(BD@+B`G("@W,"DG.PH@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#<Q.B`O+R!%6%]/
M4T524@H@("`@("`@("`@("`@("`@)&5R<F]R(#T@)W-E;F1M86EL.B`G("X@
M7R@B<WES=&5M(&5R<F]R(BD@+B`G("@W,2DG.PH@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("!C87-E(#<R.B`O+R!%6%]/4T9)3$4*("`@
M("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H(F-R:71I
M8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B*2`N("<@*#<R*2<["B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@-S,Z("\O($587T-!
M3E1#4D5!5`H@("`@("`@("`@("`@("`@)&5R<F]R(#T@)W-E;F1M86EL.B`G
M("X@7R@B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(I("X@)R`H-S,I)SL*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`W-#H@
M+R\@15A?24]%4E(*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I
M;#H@)R`N(%\H(FEN<'5T+V]U='!U="!E<G)O<B(I("X@)R`H-S0I)SL*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`W-3H@+R\@
M15A?5$5-4$9!24P*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I
M;#H@)R`N(%\H(G1E;7!O<F%R>2!F86EL=7)E(BD@+B`G("@W-2DG.PH@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#<V.B`O+R!%
M6%]04D]43T-/3`H@("`@("`@("`@("`@("`@)&5R<F]R(#T@)W-E;F1M86EL
M.B`G("X@7R@B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(BD@+B`G("@W-BDG
M.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#<W
M.B`O+R!%6%].3U!%4DT*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD
M;6%I;#H@)R`N(%\H(G!E<FUI<W-I;VX@9&5N:65D(BD@+B`G("@W-RDG.PH@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#<X.B`O
M+R!%6%]#3TY&24<*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I
M;#H@)R`N(%\H(F-O;F9I9W5R871I;VX@97)R;W(B*2`N("<@*#<X*2<["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@-SDZ("\O
M($587TY/5$9/54Y$"B`@("`@("`@("`@("`@("`D97)R;W(@/2`G<V5N9&UA
M:6PZ("<@+B!?*")E;G1R>2!N;W0@9F]U;F0B*2`N("<@*#<Y*2<["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@
M("`@("`@("`@("`D97)R;W(@/2`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1E<G)O<BD["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O
M*BH*("`@("`J(%1A:V4@82!S970@;V8@:&5A9&5R<R!A;F0@;6%K92!S=7)E
M('1H97D@87)E(&5N8V]D960@<')O<&5R;'DN"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1H96%D97)S("`@5&AE(&AE861E<G,@=&\@96YC;V1E+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D8VAA<G-E="`@5&AE(&-H87)A8W1E<B!S
M970@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!A
M<G)A>2!O9B!E;F-O9&5D(&AE861E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&5N8V]D92@D:&5A9&5R<RP@)&-H87)S970I"B`@("!["B`@("`@("`@<F5Q
M=6ER95]O;F-E("=(;W)D92]-24U%+G!H<"<["@H@("`@("`@("1A9&1R97-S
M2V5Y<R`](&%R<F%Y*"=4;R<L("=#8R<L("="8V,G+"`G1G)O;2<I.PH@("`@
M("`@(&9O<F5A8V@@*"1H96%D97)S(&%S("1K97D@/3X@)'9A;"D@>PH@("`@
M("`@("`@("!I9B`H:6Y?87)R87DH)&ME>2P@)&%D9')E<W-+97ES*2D@>PH@
M("`@("`@("`@("`@("`@)'1E>'0@/2!-24U%.CIE;F-O9&5!9&1R97-S*"1V
M86PL("1C:&%R<V5T+"`D=&AI<RT^7V1E9F%U;'1397)V97(I.PH@("`@("`@
M("`@("`@("`@:68@*&ES7V$H)'1E>'0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@("`@("`D=&5X="`]("1V86P["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&5X
M="`]($U)344Z.F5N8V]D92@D=F%L+"`D8VAA<G-E="D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)&AE861E<G-;)&ME>5T@/2!-24U%.CIW<F%P2&5A
M9&5R<R@D:V5Y+"`D=&5X="P@)'1H:7,M/F=E=$5/3"@I*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D:&5A9&5R<SL*("`@('T*"B`@("`O*BH*("`@
M("`J($%D9"!T:&4@<')O<&5R('-E="!O9B!-24U%(&AE861E<G,@9F]R('1H
M:7,@;65S<V%G92!T;R!A;B!A<G)A>2X*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)&AE861E<G,@(%1H92!H96%D97)S('1O(&%D9"!T:&4@34E-12!H
M96%D97)S('1O+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!F
M=6QL('-E="!O9B!H96%D97)S(&EN8VQU9&EN9R!-24U%(&AE861E<G,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&AE861E<B@D:&5A9&5R<R`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@+RH@4&5R(%)&0R`R,#0U(%LT72P@=&AI<R!-55-4
M(&%P<&5A<B!I;B!T:&4@;65S<V%G92!H96%D97)S+B`J+PH@("`@("`@("1H
M96%D97)S6R=-24U%+59E<G-I;VXG72`]("<Q+C`G.PH*("`@("`@("!I9B`H
M)'1H:7,M/E]B=6EL9"D@>PH@("`@("`@("`@("!R971U<FX@<&%R96YT.CIH
M96%D97(H)&AE861E<G,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1T:&ES+3YB=6EL9$UE<W-A9V4H*3L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YE;F-O9&4H)'1H:7,M/FAE861E<B@D:&5A9&5R<RDL("1T:&ES+3YG
M971#:&%R<V5T*"DI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;B!T:&4@96YT:7)E(&UE<W-A9V4@8V]N=&5N=',L(&EN8VQU9&EN
M9R!H96%D97)S+"!A<R!A('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE(&5N8V]D960L(&=E;F5R871E9"!M97-S86=E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!T;U-T<FEN9R@I"B`@("!["B`@("`@("`@:68@
M*"1T:&ES+3Y?8G5I;&0I('L*("`@("`@("`@("`@<F5T=7)N('!A<F5N=#HZ
M=&]3=')I;F<H9F%L<V4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1T:&ES+3YB=6EL9$UE<W-A9V4H*3L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YT;U-T<FEN9R@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($)U:6QD(&UE<W-A9V4@9G)O;2!C=7)R96YT(&-O;G1E;G1S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!B=6EL9$UE<W-A9V4H*0H@("`@>PH@("`@("`@
M(&EF("@D=&AI<RT^7V)U:6QD*2!["B`@("`@("`@("`@(')E='5R;CL*("`@
M("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7V9L86=S6R=S9714
M>7!E)UTI*2!["B`@("`@("`@("`@(&EF("AC;W5N="@D=&AI<RT^7W!A<G1S
M*2`^(#$I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS9714>7!E*"=M=6QT
M:7!A<G0O;6EX960G*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("\J($-O<'D@=&AE(&EN9F]R;6%T:6]N(&9R;VT@=&AE('-I;F=L
M92!P87)T('1O('1H92!C=7)R96YT"B`@("`@("`@("`@("`@("`@("!B87-E
M('!A<G0N("HO"B`@("`@("`@("`@("`@("!I9B`H*"1O8E9A<G,@/2!G971?
M;V)J96-T7W9A<G,H<F5S970H)'1H:7,M/E]P87)T<RDI*2D@>PH@("`@("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1O8E9A<G,@87,@)&ME>2`]/B`D=F%L
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3XD:V5Y(#T@)'9A
M;#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%-E="!T:&4@8G5I
M;&0@9FQA9R!N;W<N("HO"B`@("`@("`@)'1H:7,M/E]B=6EL9"`]('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F(&%L;"!-24U%
M('-U8G!A<G1S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R
M<F%Y(&]F('1H92!-24U%7U!A<G0@<W5B<&%R=',N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%!A<G1S*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]B
M=6EL9"D@>PH@("`@("`@("`@("!R971U<FX@<&%R96YT.CIG971087)T<R@I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YB=6EL9$UE
M<W-A9V4H*3L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG971087)T<R@I
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@
M8F%S92!P87)T(&]F('1H92!M97-S86=E+B!4:&ES(&9U;F-T:6]N(&1O97,@
M3D]4"B`@("`@*B!R971U<FX@82!R969E<F5N8V4@=&\@;6%K92!S=7)E('1H
M870@=&AE('=H;VQE($U)345?365S<V%G90H@("`@("H@;V)J96-T(&ES;B=T
M(&%C8VED96YT86QL>2!M;V1I9FEE9"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M($U)345?365S<V%G92`@5&AE(&)A<V4@34E-15]087)T(&]F('1H92!M97-S
M86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971"87-E4&%R="@I"B`@("![
M"B`@("`@("`@)'1H:7,M/F)U:6QD365S<V%G92@I.PH@("`@("`@(')E='5R
M;B`D=&AI<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E(&$@<W!E
M8VEF:6,@34E-12!P87)T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&ED("!4:&4@34E-15]087)T($E$('-T<FEN9RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N($U)345?4&%R="`@5&AE($U)345?4&%R="!R97%U97-T960L(&]R
M(&9A;'-E(&EF('1H92!P87)T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M9&]E<VXG="!E>&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=%!A<G0H
M)&ED*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V)U:6QD*2!["B`@("`@
M("`@("`@("1P87)T(#T@<&%R96YT.CIG971087)T*"1I9"D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/F)U:6QD365S<V%G92@I.PH@
M("`@("`@("`@("`D<&%R="`]("1T:&ES+3YG971087)T*"1I9"D["B`@("`@
M("`@?0H@("`@("`@(&EF("AI<U]A*"1P87)T+"`G34E-15]-97-S86=E)RDI
M('L*("`@("`@("`@("`@)&YE=W!A<G0@/2`F;F5W($U)345?4&%R="@I.PH@
M("`@("`@("`@("`D<VMI<"`](&%R<F%Y*"=?8G5I;&0G+"`G7V1E9F%U;'13
M97)V97(G*3L*("`@("`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<RAG971?
M;V)J96-T7W9A<G,H)'!A<G0I*2!A<R`D:V5Y*2!["B`@("`@("`@("`@("`@
M("`O*B!)9VYO<F4@;&]C86P@=F%R:6%B;&5S('1H870@87)E;B=T(&$@<&%R
M="!O9B!T:&4@;W)I9VEN86P*("`@("`@("`@("`@("`@("`J(&-L87-S+B`J
M+PH@("`@("`@("`@("`@("`@:68@*"%I;E]A<G)A>2@D:V5Y+"`D<VMI<"DI
M('L*("`@("`@("`@("`@("`@("`@("`D;F5W<&%R="T^)&ME>2`]("8D<&%R
M="T^)&ME>3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!R971U<FX@)&YE=W!A<G0["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N("1P87)T.PH@("`@("`@?0H@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+VUI;64N;6%G:6,N<&AP````
M````````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-C<T,S4`,3`U,34T,S,W-3``
M,#(R-S0W`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!$871A(&9I;&4@=7-E9"!B>2!-24U%7TUA9VEC
M.CHN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-12]M:6UE+FUA
M9VEC+G!H<"QV(#$N-2`R,#`T+S`S+S(P(#(R.C0U.C,W(&IA;B!%>'`@)`H@
M*@H@*B!`<&%C:V%G92!(;W)D95]-24U%"B`J+PHD;6EM95]M86=I8ULP75LS
M,%U;(EPQ-#5<,38V7#$T,5PQ-31<-#!<-#)<,30U7#$W,%PQ-#5<,30S7#0P
M7#4W7#$V-5PQ-C-<,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<-3=<,30R
M7#$U,5PQ-39<-3=<,38P7#$T-5PQ-C)<,34T(ET@/2`G87!P;&EC871I;VXO
M>"UP97)L)SL*)&UI;65?;6%G:6-;,%U;,C1=6R)<,30U7#$V-EPQ-#%<,34T
M7#0P7#0R7#$T-5PQ-S!<,30U7#$T,UPT,%PU-UPQ-C5<,38S7#$V,EPU-UPQ
M-#)<,34Q7#$U-EPU-UPQ-C!<,30U7#$V,EPQ-30B72`]("=A<'!L:6-A=&EO
M;B]X+7!E<FPG.PHD;6EM95]M86=I8ULP75LR,UU;(EPQ,#-<,34W7#$U-5PQ
M-35<,34W7#$U-EPT,%PQ-C-<,38U7#$T,EPQ-#1<,34Q7#$V,EPQ-#5<,30S
M7#$V-%PQ-3=<,38R7#$U,5PQ-#5<,38S7#<R7#0P(ET@/2`G=&5X="]X+7!A
M=&-H)SL*)&UI;65?;6%G:6-;,%U;,C-=6R)<-S5<-S1<,34T7#$U,5PQ-C-<
M,38T7#<V7#$U-EPW-%PQ-C!<,38R7#$U-UPQ-C1<,34W7#$T,UPQ-3=<,34T
M7#0P7#$T,EPQ-#)<,34V7#4U7#$U-2)=(#T@)V%P<&QI8V%T:6]N+V1A=&$G
M.PHD;6EM95]M86=I8ULP75LR,EU;(EPQ,#%<,3$U7#$P,5PQ,39<,3`T7#$P
M,5PW,EPT,%PQ,C1<,3`Q7#$R,%PQ,#5<,3(S7#$R-%PQ,#%<,3(R7#$R-%PT
M,%PQ,#1<,3`Q7#$R-%PQ,#4B72`]("=A<'!L:6-A=&EO;B]X+6%M86YD82UH
M96%D97(G.PHD;6EM95]M86=I8ULP75LR,EU;(EPQ,#=<,3`V7#8Q7#$R,%PQ
M,#%<,3(T7#$P,UPQ,3!<-C%<-C!<-C!<-C!<,3$Q7#$P-%PT,UPV,%PV,%PV
M,%PV,%PV,%PV,EPV,")=(#T@)V%U9&EO+W@M9W5S+7!A=&-H)SL*)&UI;65?
M;6%G:6-;,%U;,C)=6R)<,3`W7#$P-EPV,5PQ,C!<,3`Q7#$R-%PQ,#-<,3$P
M7#8Q7#8Q7#8P7#8P7#$Q,5PQ,#1<-#-<-C!<-C!<-C!<-C!<-C!<-C)<-C`B
M72`]("=A=61I;R]X+6=U<RUP871C:"<["B1M:6UE7VUA9VEC6S!=6S(R75LB
M7#0S7#0Q7#$Q7#4W7#$V-5PQ-C-<,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ
M-31<-3=<,30R7#$U,5PQ-39<-3=<,30R7#$T,5PQ-C-<,34P(ET@/2`G87!P
M;&EC871I;VXO>"US:"<["B1M:6UE7VUA9VEC6S!=6S(R75LB7#0S7#0Q7#$Q
M7#4W7#$V-5PQ-C-<,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<-3=<,30R
M7#$U,5PQ-39<-3=<,30W7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO
M>"UA=VLG.PHD;6EM95]M86=I8ULP75LR,EU;(EPT,UPT,5PQ,5PU-UPQ-C5<
M,38S7#$V,EPU-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V
M7#4W7#$U-EPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M87=K)SL*
M)&UI;65?;6%G:6-;,%U;,C)=6R)<-#-<-#%<,3%<-3=<,38U7#$V,UPQ-C)<
M-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-C!<
M,30U7#$V,EPQ-30B72`]("=A<'!L:6-A=&EO;B]X+7!E<FPG.PHD;6EM95]M
M86=I8ULP75LR,EU;(EPT,UPT,5PQ,5PU-UPQ-C5<,38S7#$V,EPU-UPQ-31<
M,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$V-%PQ-#-<,38S
M7#$U,")=(#T@)V%P<&QI8V%T:6]N+W@M8W-H)SL*)&UI;65?;6%G:6-;,%U;
M,C)=6R)<-#-<-#%<-#!<-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<
M,30Q7#$U-%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-#)<,30Q7#$V,UPQ-3`B72`]
M("=A<'!L:6-A=&EO;B]X+7-H)SL*)&UI;65?;6%G:6-;,%U;,C)=6R)<-#-<
M-#%<-#!<-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU
M-UPQ-#)<,34Q7#$U-EPU-UPQ-#=<,30Q7#$V-UPQ-3,B72`]("=A<'!L:6-A
M=&EO;B]X+6%W:R<["B1M:6UE7VUA9VEC6S!=6S(R75LB7#0S7#0Q7#0P7#4W
M7#$V-5PQ-C-<,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<-3=<,30R7#$U
M,5PQ-39<-3=<,34V7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA
M=VLG.PHD;6EM95]M86=I8ULP75LR,EU;(EPT,UPT,5PT,%PU-UPQ-C5<,38S
M7#$V,EPU-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W
M7#$V,%PQ-#5<,38R7#$U-")=(#T@)V%P<&QI8V%T:6]N+W@M<&5R;"<["B1M
M:6UE7VUA9VEC6S!=6S(R75LB7#0S7#0Q7#0P7#4W7#$V-5PQ-C-<,38R7#4W
M7#$U-%PQ-3=<,30S7#$T,5PQ-31<-3=<,30R7#$U,5PQ-39<-3=<,38T7#$T
M,UPQ-C-<,34P(ET@/2`G87!P;&EC871I;VXO>"UC<V@G.PHD;6EM95]M86=I
M8ULP75LR,5U;(EPT,UPT,5PQ,5PU-UPQ-C5<,38S7#$V,EPU-UPQ-31<,34W
M7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$T,5PQ-C-<,34P(ET@
M/2`G87!P;&EC871I;VXO>"UZ<V@G.PHD;6EM95]M86=I8ULP75LR,5U;(EPT
M,UPT,5PQ,5PU-UPQ-C5<,38S7#$V,EPU-UPQ-31<,34W7#$T,UPQ-#%<,34T
M7#4W7#$T,EPQ-3%<,34V7#4W7#$W,EPQ-C-<,34P(ET@/2`G87!P;&EC871I
M;VXO>"UZ<V@G.PHD;6EM95]M86=I8ULP75LR,5U;(EPT,UPT,5PT,%PU-UPQ
M-C5<,38S7#$V,EPU-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<
M,34V7#4W7#$T,5PQ-C-<,34P(ET@/2`G87!P;&EC871I;VXO>"UZ<V@G.PHD
M;6EM95]M86=I8ULP75LR,5U;(EPT,UPT,5PT,%PU-UPQ-C5<,38S7#$V,EPU
M-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$W,EPQ
M-C-<,34P(ET@/2`G87!P;&EC871I;VXO>"UZ<V@G.PHD;6EM95]M86=I8ULP
M75LR,5U;(EPT,UPT,5PU-UPQ-C5<,38S7#$V,EPU-UPQ-31<,34W7#$T,UPQ
M-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$T,EPQ-#%<,38S7#$U,")=(#T@
M)V%P<&QI8V%T:6]N+W@M<V@G.PHD;6EM95]M86=I8ULP75LR,5U;(EPT,UPT
M,5PU-UPQ-C5<,38S7#$V,EPU-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T
M,EPQ-3%<,34V7#4W7#$T-UPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N
M+W@M87=K)SL*)&UI;65?;6%G:6-;,%U;,C%=6R)<-#-<-#%<-3=<,38U7#$V
M,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<,34Q7#$U-EPU
M-UPQ-39<,30Q7#$V-UPQ-3,B72`]("=A<'!L:6-A=&EO;B]X+6%W:R<["B1M
M:6UE7VUA9VEC6S!=6S(Q75LB7#0S7#0Q7#4W7#$V-5PQ-C-<,38R7#4W7#$U
M-%PQ-3=<,30S7#$T,5PQ-31<-3=<,30R7#$U,5PQ-39<-3=<,38P7#$T-5PQ
M-C)<,34T(ET@/2`G87!P;&EC871I;VXO>"UP97)L)SL*)&UI;65?;6%G:6-;
M,%U;,C%=6R)<-#-<-#%<-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<
M,30Q7#$U-%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-C1<,30S7#$V,UPQ-3`B72`]
M("=A<'!L:6-A=&EO;B]X+6-S:"<["B1M:6UE7VUA9VEC6S!=6S(P75LB7#$T
M-5PQ-C9<,30Q7#$U-%PT,%PT,EPQ-#5<,3<P7#$T-5PQ-#-<-#!<-3=<,30R
M7#$U,5PQ-39<-3=<,38P7#$T-5PQ-C)<,34T(ET@/2`G87!P;&EC871I;VXO
M>"UP97)L)SL*)&UI;65?;6%G:6-;,%U;,C!=6R)<-#-<-#%<,3%<-3=<,38U
M7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<,34Q7#$U
M-EPU-UPQ-#%<,30U(ET@/2`G=&5X="]S8W)I<'0G.PHD;6EM95]M86=I8ULP
M75LR,%U;(EPT,UPT,5PT,%PU-UPQ-C5<,38S7#$V,EPU-UPQ-31<,34W7#$T
M,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$T,5PQ-#4B72`]("=T97AT
M+W-C<FEP="<["B1M:6UE7VUA9VEC6S!=6S(P75LB7#0S7#0Q7#4W7#$V-5PQ
M-C-<,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<-3=<,30R7#$U,5PQ-39<
M-3=<,30Q7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+7-H)SL*)&UI;65?
M;6%G:6-;,%U;,C!=6R)<-#-<-#%<-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U
M-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-S)<,38S7#$U,")=
M(#T@)V%P<&QI8V%T:6]N+W@M>G-H)SL*)&UI;65?;6%G:6-;,%U;,3E=6R)<
M,3`S7#$V,EPQ-#5<,30Q7#$V-%PQ-3%<,38V7#$T-5PT,%PQ,C9<,34W7#$U
M,5PQ-#-<,30U7#0P7#$P-EPQ-3%<,34T7#$T-2)=(#T@)V%U9&EO+W@M=F]C
M)SL*)&UI;65?;6%G:6-;,%U;,3E=6R)<-#%<-S1<,30Q7#$V,EPQ-#-<,34P
M7#<V7#$U-EPQ,S=<,3,W7#$S-UPQ,S=<,3,W7#$S-UPQ,S=<,3,W7#$S-UPQ
M,S=<,3`U(ET@/2`G87!P;&EC871I;VXO>"UA<B<["B1M:6UE7VUA9VEC6S!=
M6S$Y75LB7#0Q7#<T7#$T,5PQ-C)<,30S7#$U,%PW-EPQ-39<,3,W7#$S-UPQ
M,S=<,3,W7#$S-UPQ,S=<,3,W7#$S-UPV-EPV-%PQ,#4B72`]("=A<'!L:6-A
M=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;,3E=6R)<-#-<-#%<-3=<,38U
M7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<,34Q7#$U
M-EPU-UPQ-#%<,30U(ET@/2`G=&5X="]S8W)I<'0G.PHD;6EM95]M86=I8ULP
M75LQ.%U;(EPQ,#9<,34Q7#$Q-%PQ-#5<,3(S7#$V-%PQ,#%<,38R7#$R-%PQ
M-#9<,3$Q7#$U-%PQ,#5<,38S7#$R-%PQ-#%<,3(R7#$V-")=(#T@)W1E>'0O
M>"UA<'!L92UB:6YS8VEI)SL*)&UI;65?;6%G:6-;,%U;,3A=6R)<-#-<-#%<
M-#!<-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ
M-C1<,30S7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+6-S:"<["B1M:6UE
M7VUA9VEC6S!=6S$X75LB7#0U7#0Q7#$R,%PQ,C-<-35<,3`Q7#$T-%PQ-3=<
M,30R7#$T-5PQ,#9<,34W7#$U-EPQ-C1<-35<-C%<-39<-C`B72`]("=F;VYT
M+W1Y<&4Q)SL*)&UI;65?;6%G:6-;,%U;,3==6R)<-#-<-#%<-3=<,38U7#$V
M,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-C1<,30S7#$V,UPQ
M-3`B72`]("=A<'!L:6-A=&EO;B]X+6-S:"<["B1M:6UE7VUA9VEC6S!=6S$V
M75LB7#$P-5PQ-S!<,38T7#$T-5PQ-39<,30T7#$T-5PQ-#1<-#!<,3$U7#$U
M-UPQ-#1<,38U7#$U-%PQ-#5<-S(B72`]("=A=61I;R]X+69T,BUM;V0G.PHD
M;6EM95]M86=I8ULP75LQ-EU;(EPQ,C-<,38T7#$T,5PQ-C)<,38T7#$P-EPQ
M-3=<,34V7#$V-%PQ,35<,30U7#$V-%PQ-C)<,34Q7#$T,UPQ-C,B72`]("=F
M;VYT+W@M<W5N;W,M;F5W<R<["B1M:6UE7VUA9VEC6S!=6S$V75LB7#0S7#0Q
M7#$Q7#4W7#$V-5PQ-C-<,38R7#4W7#$T,EPQ-3%<,34V7#4W7#$T-UPQ-#%<
M,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M87=K)SL*)&UI;65?;6%G:6-;
M,%U;,39=6R)<-#-<-#%<,3%<-3=<,38U7#$V,UPQ-C)<-3=<,30R7#$U,5PQ
M-39<-3=<,34V7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA=VLG
M.PHD;6EM95]M86=I8ULP75LQ-EU;(EPT,UPT,5PQ,5PU-UPQ-C5<,38S7#$V
M,EPU-UPQ-#)<,34Q7#$U-EPU-UPQ-C!<,30U7#$V,EPQ-30B72`]("=A<'!L
M:6-A=&EO;B]X+7!E<FPG.PHD;6EM95]M86=I8ULP75LQ-EU;(EPT,UPT,5PT
M,%PU-UPQ-C5<,38S7#$V,EPU-UPQ-#)<,34Q7#$U-EPU-UPQ-#=<,30Q7#$V
M-UPQ-3,B72`]("=A<'!L:6-A=&EO;B]X+6%W:R<["B1M:6UE7VUA9VEC6S!=
M6S$V75LB7#0S7#0Q7#0P7#4W7#$V-5PQ-C-<,38R7#4W7#$T,EPQ-3%<,34V
M7#4W7#$U-EPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M87=K)SL*
M)&UI;65?;6%G:6-;,%U;,39=6R)<-#-<-#%<-#!<-3=<,38U7#$V,UPQ-C)<
M-3=<,30R7#$U,5PQ-39<-3=<,38P7#$T-5PQ-C)<,34T(ET@/2`G87!P;&EC
M871I;VXO>"UP97)L)SL*)&UI;65?;6%G:6-;,%U;,39=6R)<-S1<,3$U7#$T
M,5PQ-3-<,30U7#$V,EPQ,#1<,34Q7#$T,UPQ-C1<,34Q7#$U-UPQ-39<,30Q
M7#$V,EPQ-S$B72`]("=A<'!L:6-A=&EO;B]X+69R86UE;6%K97(G.PHD;6EM
M95]M86=I8ULP75LQ-EU;(EPW-%PQ,35<,30Q7#$U,UPQ-#5<,38R7#$R,UPQ
M-#-<,38R7#$T-5PQ-#5<,34V7#$P-EPQ-3=<,34V7#$V-")=(#T@)V9O;G0O
M>"UF<F%M96UA:V5R)SL*)&UI;65?;6%G:6-;,%U;,35=6R)<-#-<-#%<,3%<
M-3=<,38U7#$V,UPQ-C)<-3=<,30R7#$U,5PQ-39<-3=<,30Q7#$V-UPQ-3,B
M72`]("=A<'!L:6-A=&EO;B]X+6%W:R<["B1M:6UE7VUA9VEC6S!=6S$U75LB
M7#0S7#0Q7#0P7#4W7#$V-5PQ-C-<,38R7#4W7#$T,EPQ-3%<,34V7#4W7#$T
M,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA=VLG.PHD;6EM95]M86=I
M8ULP75LQ-5U;(EPT,UPT,5PU-UPQ-C5<,38S7#$V,EPU-UPQ-#)<,34Q7#$U
M-EPU-UPQ-#=<,30Q7#$V-UPQ-3,B72`]("=A<'!L:6-A=&EO;B]X+6%W:R<[
M"B1M:6UE7VUA9VEC6S!=6S$U75LB7#0S7#0Q7#4W7#$V-5PQ-C-<,38R7#4W
M7#$T,EPQ-3%<,34V7#4W7#$U-EPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T
M:6]N+W@M87=K)SL*)&UI;65?;6%G:6-;,%U;,35=6R)<-#-<-#%<-3=<,38U
M7#$V,UPQ-C)<-3=<,30R7#$U,5PQ-39<-3=<,38P7#$T-5PQ-C)<,34T(ET@
M/2`G87!P;&EC871I;VXO>"UP97)L)SL*)&UI;65?;6%G:6-;,%U;,31=6R)<
M-#%<-S1<,30Q7#$V,EPQ-#-<,34P7#<V7#$U-EPQ-#1<,30U7#$T,EPQ-3%<
M,30Q7#$U-B)=(#T@)V%P<&QI8V%T:6]N+W@M9'!K9R<["B1M:6UE7VUA9VEC
M6S!=6S$T75LB7#0S7#0Q7#4W7#$V-5PQ-C-<,38R7#4W7#$T,EPQ-3%<,34V
M7#4W7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA=VLG.PHD;6EM
M95]M86=I8ULP75LQ-%U;(EPW-%PT,5PQ,#1<,3$W7#$P,UPQ,C1<,3,Q7#$R
M,%PQ,#5<-#!<,3$P7#$R-%PQ,35<,3$T(ET@/2`G=&5X="]H=&UL)SL*)&UI
M;65?;6%G:6-;,%U;,31=6R)<-S1<-#%<,30T7#$U-UPQ-#-<,38T7#$W,5PQ
M-C!<,30U7#0P7#$U,%PQ-C1<,34U7#$U-")=(#T@)W1E>'0O:'1M;"<["B1M
M:6UE7VUA9VEC6S!=6S$S75LB7#$P-UPQ,3%<,3$U7#$R,%PT,%PQ,#=<,38R
M7#$T,5PQ-#1<,34Q7#$T-5PQ-39<,38T(ET@/2`G87!P;&EC871I;VXO>"UG
M:6UP+6=R861I96YT)SL*)&UI;65?;6%G:6-;,%U;,3)=6R)<,3(R7#$T-5PQ
M-C1<,38U7#$V,EPQ-39<-35<,3(P7#$T,5PQ-C1<,34P7#<R(ET@/2`G;65S
M<V%G92]R9F,X,C(G.PHD;6EM95]M86=I8ULP75LQ,EU;(EPT,UPT,5PQ,5PU
M-UPQ-#)<,34Q7#$U-EPU-UPQ-#)<,30Q7#$V,UPQ-3`B72`]("=A<'!L:6-A
M=&EO;B]X+7-H)SL*)&UI;65?;6%G:6-;,%U;,3)=6R)<-#-<-#%<,3%<-3=<
M,30R7#$U,5PQ-39<-3=<,30W7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I
M;VXO>"UA=VLG.PHD;6EM95]M86=I8ULP75LQ,EU;(EPT,UPT,5PQ,5PU-UPQ
M-#)<,34Q7#$U-EPU-UPQ-39<,30Q7#$V-UPQ-3,B72`]("=A<'!L:6-A=&EO
M;B]X+6%W:R<["B1M:6UE7VUA9VEC6S!=6S$R75LB7#0S7#0Q7#$Q7#4W7#$T
M,EPQ-3%<,34V7#4W7#$V,%PQ-#5<,38R7#$U-")=(#T@)V%P<&QI8V%T:6]N
M+W@M<&5R;"<["B1M:6UE7VUA9VEC6S!=6S$R75LB7#0S7#0Q7#$Q7#4W7#$T
M,EPQ-3%<,34V7#4W7#$V-%PQ-#-<,38S7#$U,")=(#T@)V%P<&QI8V%T:6]N
M+W@M8W-H)SL*)&UI;65?;6%G:6-;,%U;,3)=6R)<-#-<-#%<-#!<-3=<,30R
M7#$U,5PQ-39<-3=<,30R7#$T,5PQ-C-<,34P(ET@/2`G87!P;&EC871I;VXO
M>"US:"<["B1M:6UE7VUA9VEC6S!=6S$R75LB7#0S7#0Q7#0P7#4W7#$T,EPQ
M-3%<,34V7#4W7#$T-UPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M
M87=K)SL*)&UI;65?;6%G:6-;,%U;,3)=6R)<-#-<-#%<-#!<-3=<,30R7#$U
M,5PQ-39<-3=<,34V7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA
M=VLG.PHD;6EM95]M86=I8ULP75LQ,EU;(EPT,UPT,5PT,%PU-UPQ-#)<,34Q
M7#$U-EPU-UPQ-C!<,30U7#$V,EPQ-30B72`]("=A<'!L:6-A=&EO;B]X+7!E
M<FPG.PHD;6EM95]M86=I8ULP75LQ,EU;(EPT,UPT,5PT,%PU-UPQ-#)<,34Q
M7#$U-EPU-UPQ-C1<,30S7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+6-S
M:"<["B1M:6UE7VUA9VEC6S!=6S$Q75LB7#0S7#0Q7#$Q7#4W7#$T,EPQ-3%<
M,34V7#4W7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA=VLG.PHD
M;6EM95]M86=I8ULP75LQ,5U;(EPT,UPT,5PQ,5PU-UPQ-#)<,34Q7#$U-EPU
M-UPQ-#-<,38S7#$U,")=(#T@)V%P<&QI8V%T:6]N+W@M8W-H)SL*)&UI;65?
M;6%G:6-;,%U;,3%=6R)<-#-<-#%<,3%<-3=<,30R7#$U,5PQ-39<-3=<,34S
M7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+6MS:"<["B1M:6UE7VUA9VEC
M6S!=6S$Q75LB7#0S7#0Q7#0P7#4W7#$T,EPQ-3%<,34V7#4W7#$T,5PQ-C=<
M,34S(ET@/2`G87!P;&EC871I;VXO>"UA=VLG.PHD;6EM95]M86=I8ULP75LQ
M,5U;(EPT,UPT,5PT,%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-#-<,38S7#$U,")=
M(#T@)V%P<&QI8V%T:6]N+W@M8W-H)SL*)&UI;65?;6%G:6-;,%U;,3%=6R)<
M-#-<-#%<-#!<-3=<,30R7#$U,5PQ-39<-3=<,34S7#$V,UPQ-3`B72`]("=A
M<'!L:6-A=&EO;B]X+6MS:"<["B1M:6UE7VUA9VEC6S!=6S$Q75LB7#0S7#0Q
M7#4W7#$T,EPQ-3%<,34V7#4W7#$T,EPQ-#%<,38S7#$U,")=(#T@)V%P<&QI
M8V%T:6]N+W@M<V@G.PHD;6EM95]M86=I8ULP75LQ,5U;(EPT,UPT,5PU-UPQ
M-#)<,34Q7#$U-EPU-UPQ-#=<,30Q7#$V-UPQ-3,B72`]("=A<'!L:6-A=&EO
M;B]X+6%W:R<["B1M:6UE7VUA9VEC6S!=6S$Q75LB7#0S7#0Q7#4W7#$T,EPQ
M-3%<,34V7#4W7#$U-EPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M
M87=K)SL*)&UI;65?;6%G:6-;,%U;,3%=6R)<-#-<-#%<-3=<,30R7#$U,5PQ
M-39<-3=<,38P7#$T-5PQ-C)<,34T(ET@/2`G87!P;&EC871I;VXO>"UP97)L
M)SL*)&UI;65?;6%G:6-;,%U;,3%=6R)<-#-<-#%<-3=<,30R7#$U,5PQ-39<
M-3=<,38T7#$T,UPQ-C-<,34P(ET@/2`G87!P;&EC871I;VXO>"UC<V@G.PHD
M;6EM95]M86=I8ULP75LQ,%U;(EPQ,#)<,34Q7#$V-%PQ-35<,30Q7#$V,%PQ
M-#9<,34Q7#$U-%PQ-#4B72`]("=I;6%G92]U;FMN;W=N)SL*)&UI;65?;6%G
M:6-;,%U;,3!=6R)<,3(S7#$R-%PQ,#%<,3(R7#$R-%PQ,#9<,3$W7#$Q-EPQ
M,C1<-#`B72`]("=F;VYT+W@M8F1F)SL*)&UI;65?;6%G:6-;,%U;,3!=6R)<
M-#-<-#%<,3%<-3=<,30R7#$U,5PQ-39<-3=<,38R7#$T,R)=(#T@)W1E>'0O
M<V-R:7!T)SL*)&UI;65?;6%G:6-;,%U;,3!=6R)<-#-<-#%<,3%<-3=<,30R
M7#$U,5PQ-39<-3=<,38S7#$U,")=(#T@)V%P<&QI8V%T:6]N+W@M<V@G.PHD
M;6EM95]M86=I8ULP75LQ,%U;(EPT,UPT,5PT,%PU-UPQ-#)<,34Q7#$U-EPU
M-UPQ-C)<,30S(ET@/2`G=&5X="]S8W)I<'0G.PHD;6EM95]M86=I8ULP75LQ
M,%U;(EPT,UPT,5PT,%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-C-<,34P(ET@/2`G
M87!P;&EC871I;VXO>"US:"<["B1M:6UE7VUA9VEC6S!=6S$P75LB7#0S7#0Q
M7#4W7#$T,EPQ-3%<,34V7#4W7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I
M;VXO>"UA=VLG.PHD;6EM95]M86=I8ULP75LQ,%U;(EPT,UPT,5PU-UPQ-#)<
M,34Q7#$U-EPU-UPQ-#-<,38S7#$U,")=(#T@)V%P<&QI8V%T:6]N+W@M8W-H
M)SL*)&UI;65?;6%G:6-;,%U;,3!=6R)<-#-<-#%<-3=<,30R7#$U,5PQ-39<
M-3=<,34S7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+6MS:"<["B1M:6UE
M7VUA9VEC6S!=6S$P75LB7#<T7#$Q-5PQ-#%<,34S7#$T-5PQ-C)<,3`V7#$U
M,5PQ-31<,30U(ET@/2`G87!P;&EC871I;VXO>"UF<F%M96UA:V5R)SL*)&UI
M;65?;6%G:6-;,%U;.5U;(EPQ,C)<,30U7#$T,UPQ-#5<,34Q7#$V-EPQ-#5<
M,30T7#<R(ET@/2`G;65S<V%G92]R9F,X,C(G.PHD;6EM95]M86=I8ULP75LY
M75LB7#$R,UPQ-C1<,30Q7#$V,EPQ-C1<,3`V7#$U-UPQ-39<,38T(ET@/2`G
M9F]N="]X+7-U;F]S+6YE=W,G.PHD;6EM95]M86=I8ULP75LY75LB7#(Q,5PQ
M,31<,3,R7#$Q-UPP7#$U7#$R7#,R7#$R(ET@/2`G87!P;&EC871I;VXO9&%T
M82<["B1M:6UE7VUA9VEC6S!=6SE=6R)<-#-<-#%<-3=<,30R7#$U,5PQ-39<
M-3=<,38R7#$T,R)=(#T@)W1E>'0O<V-R:7!T)SL*)&UI;65?;6%G:6-;,%U;
M.5U;(EPT,UPT,5PU-UPQ-#)<,34Q7#$U-EPU-UPQ-C-<,34P(ET@/2`G87!P
M;&EC871I;VXO>"US:"<["B1M:6UE7VUA9VEC6S!=6SE=6R)<-35<,38R7#$U
M-UPQ-35<-C%<,30V7#$V,UPU-5PV,")=(#T@)V%P<&QI8V%T:6]N+W@M9FEL
M97-Y<W1E;2<["B1M:6UE7VUA9VEC6S!=6SE=6R)<-S1<,3`R7#$U-UPQ-3=<
M,34S7#$P-EPQ-3%<,34T7#$T-2)=(#T@)V%P<&QI8V%T:6]N+W@M9G)A;65M
M86ME<B<["B1M:6UE7VUA9VEC6S!=6SA=6R)<,3$W7#$U-EPQ-31<,3<Q7#0P
M7#$U,5PQ-39<-#`B72`]("=T97AT+W@M<&%T8V@G.PHD;6EM95]M86=I8ULP
M75LX75LB7#$T-UPQ-3%<,34U7#$V,%PT,%PQ-S!<,30S7#$T-B)=(#T@)V%P
M<&QI8V%T:6]N+W@M9VEM<"UI;6%G92<["B1M:6UE7VUA9VEC6S!=6SA=6R)<
M,34U7#$V,UPQ-#=<,30S7#$T,5PQ-C1<-C!<-C$B72`]("=A<'!L:6-A=&EO
M;B]X+6QO8V%L92<["B1M:6UE7VUA9VEC6S!=6SA=6R)<,S)<,30Q7#$V,EPQ
M-#-<,34P7#$U,5PQ-C9<,30U(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M
M:6UE7VUA9VEC6S!=6SA=6R)<-#%<-S1<,3(P7#$P-%PQ,#9<-S9<-#%<,34V
M(ET@/2`G87!P;&EC871I;VXO>"UP<F]F)SL*)&UI;65?;6%G:6-;,%U;.%U;
M(EPW-%PQ,35<,3$Q7#$P-EPQ,#9<,34Q7#$U-%PQ-#4B72`]("=A<'!L:6-A
M=&EO;B]X+69R86UE;6%K97(G.PHD;6EM95]M86=I8ULP75LW75LB7#$P,5PQ
M-C)<,38T7#$U,5PQ-#-<,34T7#$T-2)=(#T@)VUE<W-A9V4O;F5W<R<["B1M
M:6UE7VUA9VEC6S!=6S==6R)<,3(P7#$P,UPQ,#1<,3,W7#$Q-UPQ,C!<,3`Q
M(ET@/2`G>"]X+7!H;W1O+6-D+6]V97)F:65W+69I;&4G.PHD;6EM95]M86=I
M8ULP75LW75LB7#,U,5PU-%PQ7#$Q,EPQ,#%<,3$U7#$Q(ET@/2`G87!P;&EC
M871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S==6R)<-#%<-S1<,30Q7#$V
M,EPQ-#-<,34P7#<V(ET@/2`G87!P;&EC871I;VXO>"UA<B<["B1M:6UE7VUA
M9VEC6S!=6S==6R)<-S)<-#!<,38S7#$U,%PQ-#5<,34T7#$U-")=(#T@)V%P
M<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LV75LB7#$Q-EPQ-C5<
M,3`V7#$U,5PQ-31<,30U(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE
M7VUA9VEC6S!=6S9=6R)<,3$V7#,V-5PQ,#9<,S4Q7#$U-%PS-#4B72`]("=A
M<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;-EU;(EPV,%PV-UPV
M,%PV-UPV,%PV,2)=(#T@)V%P<&QI8V%T:6]N+W@M8W!I;R<["B1M:6UE7VUA
M9VEC6S!=6S9=6R)<-C!<-C=<-C!<-C=<-C!<-C(B72`]("=A<'!L:6-A=&EO
M;B]X+6-P:6\G.PHD;6EM95]M86=I8ULP75LV75LB7#8P7#8W7#8P7#8W7#8P
M7#8W(ET@/2`G87!P;&EC871I;VXO>"UC<&EO)SL*)&UI;65?;6%G:6-;,%U;
M-EU;(EPW-%PQ,35<,30Q7#$U,UPQ-#5<,38R(ET@/2`G87!P;&EC871I;VXO
M>"UF<F%M96UA:V5R)SL*)&UI;65?;6%G:6-;,%U;-EU;(EPW-%PQ,C1<,3$Q
M7#$R-%PQ,31<,3`U(ET@/2`G=&5X="]H=&UL)SL*)&UI;65?;6%G:6-;,%U;
M-EU;(EPW-%PQ-C1<,34Q7#$V-%PQ-31<,30U(ET@/2`G=&5X="]H=&UL)SL*
M)&UI;65?;6%G:6-;,%U;-5U;(EPP7#%<,%PP7#`B72`]("=F;VYT+W1T9B<[
M"B1M:6UE7VUA9VEC6S!=6S5=6R)<,%PT7#,V7#(Q,EPR,#`B72`]("=A<'!L
M:6-A=&EO;B]C;W)E)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPQ,#)<,3`Q7#$P
M,EPQ,S%<,3$T(ET@/2`G;65S<V%G92]X+6=N=2UR;6%I;"<["B1M:6UE7VUA
M9VEC6S!=6S5=6R)<,3`R7#$P-5PQ,#=<,3$Q7#$Q-B)=(#T@)V%P<&QI8V%T
M:6]N+W@M87=K)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPQ,#-<,34W7#$V,EPQ
M-#5<,2)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI
M;65?;6%G:6-;,%U;-5U;(EPQ,#1<-C%<-39<-C!<,34B72`]("=F;VYT+W@M
M<W!E961O)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPQ,#9<,38R7#$U-UPQ-35<
M-S(B72`]("=M97-S86=E+W)F8S@R,B<["B1M:6UE7VUA9VEC6S!=6S5=6R)<
M,3$U7#$P,5PQ,C-<,3,W7#$R-2)=(#T@)V%U9&EO+W@M;75L=&EM871E+6UO
M9"<["B1M:6UE7VUA9VEC6S!=6S5=6R)<,3(P7#$Q-UPQ,S9<,3(Q7#$T,")=
M(#T@)W1E>'0O=FYD+FUS+7=O<F0G.PHD;6EM95]M86=I8ULP75LU75LB7#$R
M,%PQ-#%<,38T7#$U,%PW,B)=(#T@)VUE<W-A9V4O;F5W<R<["B1M:6UE7VUA
M9VEC6S!=6S5=6R)<,3,P7#$V,EPQ-#5<,30V7#<R(ET@/2`G;65S<V%G92]N
M97=S)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPQ-#1<,34Q7#$T-EPQ-#9<-#`B
M72`]("=T97AT+W@M<&%T8V@G.PHD;6EM95]M86=I8ULP75LU75LB7#(R-5PV
M-%PV,EPV,EPS,S8B72`]("=A<'!L:6-A=&EO;B]X+6QO8V%L92<["B1M:6UE
M7VUA9VEC6S!=6S5=6R)<,S,V7#8R7#8R7#8T7#(R-2)=(#T@)V%P<&QI8V%T
M:6]N+W@M;&]C86QE)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPW-%PQ,3!<,3`U
M7#$P,5PQ,#0B72`]("=T97AT+VAT;6PG.PHD;6EM95]M86=I8ULP75LU75LB
M7#<T7#$Q,%PQ,C1<,3$U7#$Q-")=(#T@)W1E>'0O:'1M;"<["B1M:6UE7VUA
M9VEC6S!=6S5=6R)<-S1<,34P7#$T-5PQ-#%<,30T(ET@/2`G=&5X="]H=&UL
M)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPW-%PQ-3!<,38T7#$U-5PQ-30B72`]
M("=T97AT+VAT;6PG.PHD;6EM95]M86=I8ULP75LU75LB7#<U7#<T7#$T,5PQ
M-C)<-S8B72`]("=A<'!L:6-A=&EO;B]X+6%R)SL*)&UI;65?;6%G:6-;,%U;
M-%U;(EPP7#!<,%PS,30B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M
M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,%PP7#!<-")=(#T@)V9O;G0O
M>"US;F8G.PHD;6EM95]M86=I8ULP75LT75LB7#!<,%PQ7#$P-R)=(#T@)V%P
M<&QI8V%T:6]N+W@M;V)J96-T+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB
M7#!<,%PQ7#$Q,R)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE
M)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPP7#!<,5PQ,34B72`]("=A<'!L:6-A
M=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<
M,%PP7#%<,3$W(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G
M.PHD;6EM95]M86=I8ULP75LT75LB7#!<,%PQ7#(P,2)=(#T@)V%P<&QI8V%T
M:6]N+W@M;V)J96-T+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#!<,%PQ
M7#(P-R)=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LT
M75LB7#!<,%PQ7#(V,R)=(#T@)W9I9&5O+VUP96<G.PHD;6EM95]M86=I8ULP
M75LT75LB7#!<,%PQ7#(W,B)=(#T@)W9I9&5O+VUP96<G.PHD;6EM95]M86=I
M8ULP75LT75LB7#!<,%PQ7#8B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B
M;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,%PP7#(P,5PQ-30B72`]
M("=A<'!L:6-A=&EO;B]X+6%P;"UW;W)K<W!A8V4G.PHD;6EM95]M86=I8ULP
M75LT75LB7#!<,%PS-S=<,30U(ET@/2`G87!P;&EC871I;VXO>"UL:6)R87)Y
M+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#!<,%PS-S=<,34U(ET@/2`G
M87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,%PP7#-<
M,S0W(ET@/2`G87!P;&EC871I;VXO>"UL:6)R87)Y+69I;&4G.PHD;6EM95]M
M86=I8ULP75LT75LB7#!<,%PS7#,V,R)=(#T@)V%P<&QI8V%T:6]N+W@M97AE
M8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPP7#$T-%PQ-C-<
M-38B72`]("=A=61I;R]B87-I8R<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,%PQ
M7#(R7#$R-R)=(#T@)V%P<&QI8V%T:6]N+V-O<F4G.PHD;6EM95]M86=I8ULP
M75LT75LB7#!<,C)<,S(V7#(P-R)=(#T@)VEM86=E+W@Q,2<["B1M:6UE7VUA
M9VEC6S!=6S1=6R)<,%PS7#(S,UPS-34B72`]("=A<'!L:6-A=&EO;B]D871A
M)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPP7#-<,C,S7#,U-B)=(#T@)V%P<&QI
M8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LT75LB7#!<-5PR-EPP(ET@
M/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,%PU
M7#(V7#<B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;
M-%U;(EPP7#5<-C%<,30R(ET@/2`G87!P;&EC871I;VXO>"UD8B<["B1M:6UE
M7VUA9VEC6S!=6S1=6R)<,%PV7#(U7#$T,2)=(#T@)V%P<&QI8V%T:6]N+W@M
M9&(G.PHD;6EM95]M86=I8ULP75LT75LB7#$P,UPQ,C1<,3$U7#$P-B)=(#T@
M)V%U9&EO+W@M8VUF)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,#5<,3$U7#$Q
M-UPQ,#0B72`]("=A=61I;R]X+65M;V0G.PHD;6EM95]M86=I8ULP75LT75LB
M7#$P-EPQ,#9<,3$Q7#$Q-")=(#T@)V9O;G0O='1F)SL*)&UI;65?;6%G:6-;
M,%U;-%U;(EPQ,#9<,3$W7#$Q-EPQ,C0B72`]("=F;VYT+W@M=F9O;G0G.PHD
M;6EM95]M86=I8ULP75LT75LB7#$P-UPQ,#1<,3`R7#$Q-2)=(#T@)V%P<&QI
M8V%T:6]N+W@M9V1B;2<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,3`W7#$Q,5PQ
M,#9<-S`B72`]("=I;6%G92]G:68G.PHD;6EM95]M86=I8ULP75LT75LB7#$P
M7#$V7#$R7#$W(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC
M6S!=6S1=6R)<,3$P7#$R,%PQ,#%<,3$S(ET@/2`G87!P;&EC871I;VXO9&%T
M82<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,3$Q7#$Q,5PQ,39<-C$B72`]("=I
M;6%G92]T:69F)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,3%<,3$Q7#4R7#`B
M72`]("=I;6%G92]T:69F)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,31<,3`T
M7#$Q,%PQ-3$B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;
M,%U;-%U;(EPQ,31<,3(W7#$P-EPQ,38B72`]("=F;VYT+W1Y<&4Q)SL*)&UI
M;65?;6%G:6-;,%U;-%U;(EPQ,35<,3$U7#!<-3(B72`]("=I;6%G92]T:69F
M)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,35<,3$W7#$R-EPQ,3$B72`]("=V
M:61E;R]X+7-G:2UM;W9I92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,3$U7#$R
M-%PQ-3!<,30T(ET@/2`G875D:6\O;6ED:2<["B1M:6UE7VUA9VEC6S!=6S1=
M6R)<,3$U7#(T-UPS-39<,S4P(ET@/2`G9F]N="]X+6AP+7=I;F1O=W,G.PHD
M;6EM95]M86=I8ULP75LT75LB7#$Q-EPQ,C1<,3(R7#$Q,R)=(#T@)V%U9&EO
M+W@M;75L=&ET<F%C:R<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,3(P7#$Q,UPS
M7#0B72`]("=A<'!L:6-A=&EO;B]Z:7`G.PHD;6EM95]M86=I8ULP75LT75LB
M7#$R,EPQ,3%<,3`V7#$P-B)=(#T@)V%U9&EO+W@M=V%V)SL*)&UI;65?;6%G
M:6-;,%U;-%U;(EPQ,C)<,30Q7#$V,EPT,2)=(#T@)V%P<&QI8V%T:6]N+W@M
M<F%R)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,C-<,3(Q7#$R,UPQ,3`B72`]
M("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,C1<
M,3`Q7#$P-%PQ,C,B72`]("=A<'!L:6-A=&EO;B]X+71A9',M9V%M92<["B1M
M:6UE7VUA9VEC6S!=6S1=6R)<,3(U7#$P,UPV,EPS,B)=(#T@)V%P<&QI8V%T
M:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LT75LB7#$R-5PQ,39<-C!<-C4B
M72`]("=A=61I;R]X+6UI:VUO9"UU;FDG.PHD;6EM95]M86=I8ULP75LT75LB
M7#$R7#$W7#$P7#$V(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA
M9VEC6S!=6S1=6R)<,3,Q7#(T-EPQ-3)<,C(U(ET@/2`G>"]X+6EM86=E+7-U
M;BUR87-T97(G.PHD;6EM95]M86=I8ULP75LT75LB7#$T-5PS-S=<,%PP(ET@
M/2`G87!P;&EC871I;VXO>"UA<B<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,34P
M7#$V,UPQ-3%<-C$B72`]("=I;6%G92]X+6IP96<M<')O<')I971A<GDG.PHD
M;6EM95]M86=I8ULP75LT75LB7#$V7#$P7#$W7#$R(ET@/2`G87!P;&EC871I
M;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,3<W7#$P-5PQ,31<,3`V
M(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M
M86=I8ULP75LT75LB7#$W7#$R7#$V7#$P(ET@/2`G87!P;&EC871I;VXO9&%T
M82<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,5PQ,S!<-#%<,C0V(ET@/2`G87!P
M;&EC871I;VXO8V]R92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,5PQ-#9<,30S
M7#$V,")=(#T@)V9O;G0O>"UP8V8G.PHD;6EM95]M86=I8ULP75LT75LB7#(Q
M,5PQ,C!<,3$V7#$P-R)=(#T@)VEM86=E+W@M<&YG)SL*)&UI;65?;6%G:6-;
M,%U;-%U;(EPR,UPQ,C=<,C,R7#,Q-B)=(#T@)V%P<&QI8V%T:6]N+W@M9V1B
M;2<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,C-<,3<R7#4Q7#$P-")=(#T@)V9O
M;G0O>"US=6YO<RUN97=S)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR,UPQ-S)<
M-3%<,3`W(ET@/2`G9F]N="]X+7-U;F]S+6YE=W,G.PHD;6EM95]M86=I8ULP
M75LT75LB7#(S7#$W,EPU,5PQ,C`B72`]("=F;VYT+W@M<W5N;W,M;F5W<R<[
M"B1M:6UE7VUA9VEC6S!=6S1=6R)<,C-<,3<R7#4Q7#$R,2)=(#T@)V9O;G0O
M>"US=6YO<RUN97=S)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR-%PR7#$S,5PS
M,2)=(#T@)V9O;G0O>"UL:6)G<G@G.PHD;6EM95]M86=I8ULP75LT75LB7#(V
M,%PV,5PV,UPQ-#`B72`]("=A<'!L:6-A=&EO;B]X+6)O;W1A8FQE)SL*)&UI
M;65?;6%G:6-;,%U;-%U;(EPR7#$P7#%<,3`B72`]("=A<'!L:6-A=&EO;B]X
M+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ,%PQ
M7#8B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE
M7VUA9VEC6S!=6S1=6R)<,EPQ,%PQ7#<B72`]("=A<'!L:6-A=&EO;B]X+65X
M96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ,%PS-S=<
M,30U(ET@/2`G87!P;&EC871I;VXO>"UL:6)R87)Y+69I;&4G.PHD;6EM95]M
M86=I8ULP75LT75LB7#)<,3)<,5PQ,")=(#T@)V%P<&QI8V%T:6]N+W@M97AE
M8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR7#$R7#%<-R)=
M(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G
M:6-;,%U;-%U;(EPR7#$R7#,W-UPQ-#4B72`]("=A<'!L:6-A=&EO;B]X+6QI
M8G)A<GDM9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ,UPQ7#$P(ET@
M/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I
M8ULP75LT75LB7#)<,3-<,5PQ,R)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T
M86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR7#$S7#%<,34B72`]
M("=A<'!L:6-A=&EO;B]X+6QI8G)A<GDM9FEL92<["B1M:6UE7VUA9VEC6S!=
M6S1=6R)<,EPQ,UPQ7#$V(ET@/2`G87!P;&EC871I;VXO>"UL:6)R87)Y+69I
M;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#)<,3-<,5PV(ET@/2`G87!P;&EC
M871I;VXO>"UO8FIE8W0M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ
M,UPQ7#<B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M
M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ-%PQ7#$P(ET@/2`G87!P;&EC871I;VXO
M>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#)<,31<
M,5PQ,R)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI
M;65?;6%G:6-;,%U;-%U;(EPR7#$T7#%<,30B72`]("=A<'!L:6-A=&EO;B]X
M+6QI<W`G.PHD;6EM95]M86=I8ULP75LT75LB7#)<,31<,5PQ-2)=(#T@)V%P
M<&QI8V%T:6]N+W@M;&EB<F%R>2UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;
M(EPR7#$T7#%<,38B72`]("=A<'!L:6-A=&EO;B]X+6QI8G)A<GDM9FEL92<[
M"B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ-%PQ7#8B72`]("=A<'!L:6-A=&EO
M;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ
M-%PQ7#<B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M
M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ-%PS-S=<,30U(ET@/2`G87!P;&EC871I
M;VXO>"UL:6)R87)Y+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#)<,C!<
M,5PQ,")=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI
M;65?;6%G:6-;,%U;-%U;(EPR7#(P7#%<,3,B72`]("=A<'!L:6-A=&EO;B]X
M+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPR,%PQ
M7#$U(ET@/2`G87!P;&EC871I;VXO>"UL:6)R87)Y+69I;&4G.PHD;6EM95]M
M86=I8ULP75LT75LB7#)<,C!<,5PQ-B)=(#T@)V%P<&QI8V%T:6]N+W@M;&EB
M<F%R>2UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR7#(P7#%<-B)=(#T@
M)V%P<&QI8V%T:6]N+W@M;V)J96-T+69I;&4G.PHD;6EM95]M86=I8ULP75LT
M75LB7#)<,C!<,5PW(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I
M;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#)<,C1<,5PQ,")=(#T@)V%P<&QI
M8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;
M(EPR7#(T7#%<,3,B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL
M92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPR-%PQ7#$U(ET@/2`G87!P;&EC
M871I;VXO>"UO8FIE8W0M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPR
M-%PQ7#$V(ET@/2`G87!P;&EC871I;VXO>"UL:6)R87)Y+69I;&4G.PHD;6EM
M95]M86=I8ULP75LT75LB7#)<,C1<,5PV(ET@/2`G87!P;&EC871I;VXO>"UO
M8FIE8W0M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPR-%PQ7#<B72`]
M("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC
M6S!=6S1=6R)<,S8Q7#8P7#$P,%PR-S,B72`]("=I;6%G92]X+6-M=2UR87-T
M97(G.PHD;6EM95]M86=I8ULP75LT75LB7#,V-EPS-C9<,S8V7#,V-B)=(#T@
M)V%P<&QI8V%T:6]N+W@M<&,M9FQO<'!Y)SL*)&UI;65?;6%G:6-;,%U;-%U;
M(EPS-S=<,3`V7#$Q-UPQ,38B72`]("=F;VYT+W@M9&]S)SL*)&UI;65?;6%G
M:6-;,%U;-%U;(EPT,5PW-%PQ-#%<,38R(ET@/2`G87!P;&EC871I;VXO>"UA
M<B<["B1M:6UE7VUA9VEC6S!=6S1=6R)<-#-<-#%<,3%<-3<B72`]("=T97AT
M+W-C<FEP="<["B1M:6UE7VUA9VEC6S!=6S1=6R)<-#-<-#%<-#!<-3<B72`]
M("=T97AT+W-C<FEP="<["B1M:6UE7VUA9VEC6S!=6S1=6R)<-3)<,3(S7#$R
M-%PQ,#$B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;
M-%U;(EPU,EPU,EPU,EPT,")=(#T@)W1E>'0O>"UP871C:"<["B1M:6UE7VUA
M9VEC6S!=6S1=6R)<-39<,38R7#$T,5PS-S4B72`]("=A=61I;R]X+7!N+7)E
M86QA=61I;R<["B1M:6UE7VUA9VEC6S!=6S1=6R)<-39<,38S7#$U-EPQ-#0B
M72`]("=A=61I;R]B87-I8R<["B1M:6UE7VUA9VEC6S!=6S1=6R)<-C%<,30S
M7#$V-UPT,")=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP
M75LT75LB7#8Q7#(W-EPP7#`B72`]("=T97AT+W9N9"YM<RUW;W)D)SL*)&UI
M;65?;6%G:6-;,%U;-%U;(EPV,EPV,EPV-UPW,")=(#T@)V%P<&QI8V%T:6]N
M+V1A=&$G.PHD;6EM95]M86=I8ULP75LT75LB7#<T7#$Q-5PQ,35<,3$T(ET@
M/2`G87!P;&EC871I;VXO>"UF<F%M96UA:V5R)SL*)&UI;65?;6%G:6-;,%U;
M-%U;(EPW-%PQ-#%<,38R7#<V(ET@/2`G87!P;&EC871I;VXO>"UA<B<["B1M
M:6UE7VUA9VEC6S!=6S-=6R)<,3`R7#$S,EPQ-3`B72`]("=A<'!L:6-A=&EO
M;B]X+6)Z:7`R)SL*)&UI;65?;6%G:6-;,%U;,UU;(EPQ,#9<,3`Q7#$R,B)=
M(#T@)V%U9&EO+VUO9"<["B1M:6UE7VUA9VEC6S!=6S-=6R)<,3$U7#$R-%PQ
M,34B72`]("=A=61I;R]X+6UU;'1I=')A8VLG.PHD;6EM95]M86=I8ULP75LS
M75LB7#$R,UPQ,#)<,3$Q(ET@/2`G875D:6\O>"US8FDG.PHD;6EM95]M86=I
M8ULP75LS75LB7#$R-%PQ,3=<,3`S(ET@/2`G875D:6\O>"UT;V,G.PHD;6EM
M95]M86=I8ULP75LS75LB7#$R7#$P-UPQ,30B72`]("=A<'!L:6-A=&EO;B]D
M871A)SL*)&UI;65?;6%G:6-;,%U;,UU;(EPQ-#9<,34T7#$T,R)=(#T@)V%P
M<&QI8V%T:6]N+W@M9F]N="<["B1M:6UE7VUA9VEC6S!=6S-=6R)<,30V7#$U
M-%PQ-#8B72`]("=F;VYT+W@M9FEG;&5T)SL*)&UI;65?;6%G:6-;,%U;,UU;
M(EPS,UPQ,#5<,S,B72`]("=I;6%G92]X+7!C;"UH<"<["B1M:6UE7VUA9VEC
M6S!=6S-=6R)<,S-<,30S7#,S(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M
M:6UE7VUA9VEC6S!=6S-=6R)<,S<W7#,W-UPQ-S0B72`]("=A<'!L:6-A=&EO
M;B]D871A)SL*)&UI;65?;6%G:6-;,%U;,UU;(EPS-S=<,S<W7#$W-B)=(#T@
M)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LS75LB7#,W-UPS
M-S=<,3<W(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=
M6S-=6R)<-#-<-#%<-#`B72`]("=T97AT+W-C<FEP="<["B1M:6UE7VUA9VEC
M6S!=6S-=6R)<-#-<-#%<-3<B72`]("=T97AT+W-C<FEP="<["B1M:6UE7VUA
M9VEC6S!=6S-=6R)<-%PT-5PT,2)=(#T@)V%P<&QI8V%T:6]N+W!O<W1S8W)I
M<'0G.PHD;6EM95]M86=I8ULP75LS75LB7#4U7#$U,%PU-2)=(#T@)V%P<&QI
M8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LS75LB7#8Q7#$T,UPQ-C<B
M72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPP
M7#`B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE
M7VUA9VEC6S!=6S)=6R)<,3`R7#$Q-2)=(#T@)VEM86=E+W@M8FUP)SL*)&UI
M;65?;6%G:6-;,%U;,EU;(EPQ,#)<,3,R(ET@/2`G87!P;&EC871I;VXO>"UB
M>FEP)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ,3%<,3`S(ET@/2`G:6UA9V4O
M>"UI8V\G.PHD;6EM95]M86=I8ULP75LR75LB7#$Q,EPQ,38B72`]("=A=61I
M;R]X+38V.2UM;V0G.PHD;6EM95]M86=I8ULP75LR75LB7#$Q-5PQ,S(B72`]
M("=A<'!L:6-A=&EO;B]X+6US+61O<RUE>&5C=71A8FQE)SL*)&UI;65?;6%G
M:6-;,%U;,EU;(EPQ,C!<-C$B72`]("=I;6%G92]X+7!O<G1A8FQE+6)I=&UA
M<"<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,3(P7#8R(ET@/2`G:6UA9V4O>"UP
M;W)T86)L92UG<F%Y;6%P)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ,C!<-C,B
M72`]("=I;6%G92]X+7!O<G1A8FQE+7!I>&UA<"<["B1M:6UE7VUA9VEC6S!=
M6S)=6R)<,3(P7#8T(ET@/2`G:6UA9V4O>"UP;W)T86)L92UB:71M87`G.PHD
M;6EM95]M86=I8ULP75LR75LB7#$R,%PV-2)=(#T@)VEM86=E+W@M<&]R=&%B
M;&4M9W)A>6UA<"<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,3(P7#8V(ET@/2`G
M:6UA9V4O>"UP;W)T86)L92UP:7AM87`G.PHD;6EM95]M86=I8ULP75LR75LB
M7#$U,5PQ-#8B72`]("=A=61I;R]X+38V.2UM;V0G.PHD;6EM95]M86=I8ULP
M75LR75LB7#$V,5PS,#<B72`]("=A<'!L:6-A=&EO;B]X+6-P:6\G.PHD;6EM
M95]M86=I8ULP75LR75LB7#$V-EPS-S<B72`]("=A<'!L:6-A=&EO;B]D871A
M)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ7#$Q,")=(#T@)V%P<&QI8V%T:6]N
M+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ7#$Q
M,2)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?
M;6%G:6-;,%U;,EU;(EPQ7#$R-")=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD
M;6EM95]M86=I8ULP75LR75LB7#%<,3(U(ET@/2`G87!P;&EC871I;VXO>"UE
M>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LR75LB7#%<,38P(ET@
M/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I
M8ULP75LR75LB7#%<,38Q(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE
M+69I;&4G.PHD;6EM95]M86=I8ULP75LR75LB7#%<,3<U(ET@/2`G87!P;&EC
M871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LR75LB
M7#%<,3<W(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD
M;6EM95]M86=I8ULP75LR75LB7#%<,C`B72`]("=A<'!L:6-A=&EO;B]X+65X
M96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,5PR,#,B72`]
M("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC
M6S!=6S)=6R)<,5PR,2)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF
M:6QE)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ7#(Q,")=(#T@)V%P<&QI8V%T
M:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ
M7#(Q-R)=(#T@)V%P<&QI8V%T:6]N+W@M;V)J96-T+69I;&4G.PHD;6EM95]M
M86=I8ULP75LR75LB7#%<,C(T(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A
M8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LR75LB7#%<,C(W(ET@/2`G87!P
M;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LR
M75LB7#%<,S,R(ET@/2`G>"]X+6EM86=E+7-G:2<["B1M:6UE7VUA9VEC6S!=
M6S)=6R)<,5PS-B)=(#T@)V9O;G0O>"UV9F]N="<["B1M:6UE7VUA9VEC6S!=
M6S)=6R)<,5PV(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G
M.PHD;6EM95]M86=I8ULP75LR75LB7#,P-UPQ-C$B72`]("=A<'!L:6-A=&EO
M;B]X+6)C<&EO)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPS,3-<-2)=(#T@)V%P
M<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LR75LB7#,U,EPQ-#`B
M72`]("=A<'!L:6-A=&EO;B]X+6%R:B<["B1M:6UE7VUA9VEC6S!=6S)=6R)<
M,S8W7#$S,2)=(#T@)V9O;G0O>"UT97@G.PHD;6EM95]M86=I8ULP75LR75LB
M7#,V-UPR,#,B72`]("=F;VYT+W@M=&5X)SL*)&UI;65?;6%G:6-;,%U;,EU;
M(EPS-C=<,S$R(ET@/2`G9F]N="]X+71E>"<["B1M:6UE7VUA9VEC6S!=6S)=
M6R)<,S9<,2)=(#T@)V9O;G0O>"UV9F]N="<["B1M:6UE7VUA9VEC6S!=6S)=
M6R)<,S<U7#$V-B)=(#T@)V%P<&QI8V%T:6]N+W@M;'IH)SL*)&UI;65?;6%G
M:6-;,%U;,EU;(EPS-S9<,38V(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M
M:6UE7VUA9VEC6S!=6S)=6R)<,S<W7#$T-2)=(#T@)V%P<&QI8V%T:6]N+V1A
M=&$G.PHD;6EM95]M86=I8ULP75LR75LB7#,W-UPQ-34B72`]("=A<'!L:6-A
M=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPS-S=<,38V(ET@/2`G
M87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,S<W7#,S
M,")=(#T@)VEM86=E+VIP96<G.PHD;6EM95]M86=I8ULP75LR75LB7#,W-UPS
M-R)=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LR75LB
M7#,W7#(Q,R)=(#T@)V%P<&QI8V%T:6]N+W@M9WII<"<["B1M:6UE7VUA9VEC
M6S!=6S)=6R)<,S=<,C,U(ET@/2`G87!P;&EC871I;VXO8V]M<')E<W,G.PHD
M;6EM95]M86=I8ULP75LR75LB7#,W7#(S-B)=(#T@)V%P<&QI8V%T:6]N+V1A
M=&$G.PHD;6EM95]M86=I8ULP75LR75LB7#,W7#(S-R)=(#T@)V%P<&QI8V%T
M:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LR75LB7#,W7#(T,")=(#T@)V%P
M<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LR75LB7#,W7#,V(ET@
M/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,S=<
M,S<B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;,EU;
M(EPS-UPS-S<B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;
M,%U;,EU;(EPT-5PT,2)=(#T@)V%P<&QI8V%T:6]N+W!O<W1S8W)I<'0G.PHD
M;6EM95]M86=I8ULP75LR75LB7#1<-C8B72`]("=F;VYT+VQI;G5X+7!S9B<[
M"B1M:6UE7VUA9VEC6S!=6S)=6R)<-3=<-3<B72`]("=T97AT+V-P<"<["B1M
M:6UE7VUA9VEC6S!=6S)=6R)<-5PQ(ET@/2`G87!P;&EC871I;VXO>"UL;V-A
M;&4G.PHD;6EM95]M86=I8ULP75LR75LB7#9<,2)=(#T@)V%P<&QI8V%T:6]N
M+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPV7#(B
M72`]("=A<'!L:6-A=&EO;B]X+6%L86XM861V96YT=7)E+6=A;64G.PHD;6EM
M95]M86=I8ULP75LR75LB7#=<,2)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T
M86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,5U;,UU;(EPQ,C!<,3$V7#$P-R)=
M(#T@)VEM86=E+W@M<&YG)SL*)&UI;65?;6%G:6-;,5U;,UU;(EPQ,C=<,3(P
M7#$P,R)=(#T@)V%P<&QI8V%T:6]N+W9N9"YW;W)D<&5R9F5C="<["B1M:6UE
M7VUA9VEC6S)=6S9=6R)<-35<,34T7#$U,%PV-%PV,%PU-2)=(#T@)V%P<&QI
M8V%T:6]N+W@M;&AA)SL*)&UI;65?;6%G:6-;,EU;-5U;(EPU-5PQ-31<,34P
M7#$T-%PU-2)=(#T@)V%P<&QI8V%T:6]N+W@M;&AA)SL*)&UI;65?;6%G:6-;
M,EU;-5U;(EPU-5PQ-31<,34P7#8P7#4U(ET@/2`G87!P;&EC871I;VXO>"UL
M:&$G.PHD;6EM95]M86=I8ULR75LU75LB7#4U7#$U-%PQ-3!<-C%<-34B72`]
M("=A<'!L:6-A=&EO;B]X+6QH82<["B1M:6UE7VUA9VEC6S)=6S5=6R)<-35<
M,34T7#$U,%PV,EPU-2)=(#T@)V%P<&QI8V%T:6]N+W@M;&AA)SL*)&UI;65?
M;6%G:6-;,EU;-5U;(EPU-5PQ-31<,34P7#8S7#4U(ET@/2`G87!P;&EC871I
M;VXO>"UL:&$G.PHD;6EM95]M86=I8ULR75LU75LB7#4U7#$U-%PQ-3!<-C1<
M-34B72`]("=A<'!L:6-A=&EO;B]X+6QH82<["B1M:6UE7VUA9VEC6S)=6S5=
M6R)<-35<,34T7#$U,%PV-5PU-2)=(#T@)V%P<&QI8V%T:6]N+W@M;&AA)SL*
M)&UI;65?;6%G:6-;,EU;-5U;(EPU-5PQ-31<,3<R7#$V,UPU-2)=(#T@)V%P
M<&QI8V%T:6]N+W@M;&AA)SL*)&UI;65?;6%G:6-;,EU;-5U;(EPU-5PQ-31<
M,3<R7#8T7#4U(ET@/2`G87!P;&EC871I;VXO>"UL:&$G.PHD;6EM95]M86=I
M8ULR75LU75LB7#4U7#$U-%PQ-S)<-C5<-34B72`]("=A<'!L:6-A=&EO;B]X
M+6QH82<["B1M:6UE7VUA9VEC6S)=6S)=6R)<,%PR,2)=(#T@)V9O;G0O>"UT
M97@M=&9M)SL*)&UI;65?;6%G:6-;,EU;,EU;(EPP7#(R(ET@/2`G9F]N="]X
M+71E>"UT9FTG.PHD;6EM95]M86=I8ULT75LT75LB7#$U-5PQ-#1<,30Q7#$V
M-")=(#T@)W9I9&5O+W%U:6-K=&EM92<["B1M:6UE7VUA9VEC6S1=6S1=6R)<
M,34U7#$U-UPQ-3=<,38V(ET@/2`G=FED96\O<75I8VMT:6UE)SL*)&UI;65?
M;6%G:6-;-%U;-%U;(EPQ-C!<,34Q7#$V,%PQ-#4B72`]("=A<'!L:6-A=&EO
M;B]D871A)SL*)&UI;65?;6%G:6-;-%U;-%U;(EPQ-C!<,38R7#$U-UPQ-#8B
M72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;-%U;,EU;(EPR
M-3=<,C$B72`]("=V:61E;R]F;&DG.PHD;6EM95]M86=I8ULT75LR75LB7#(U
M-UPR,B)=(#T@)W9I9&5O+V9L8R<["B1M:6UE7VUA9VEC6S9=6S$X75LB7#0U
M7#0Q7#$R,%PQ,C-<-35<,3`Q7#$T-%PQ-3=<,30R7#$T-5PQ,#9<,34W7#$U
M-EPQ-C1<-35<-C%<-39<-C`B72`]("=F;VYT+W1Y<&4Q)SL*)&UI;65?;6%G
M:6-;-UU;,C)=6R)<,S4W7#(P7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P
M7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P(ET@/2`G87!P;&EC
M871I;VXO8V]R92<["B1M:6UE7VUA9VEC6S==6S1=6R)<,%PQ,#5<,3`W7#$P
M,2)=(#T@)V9O;G0O>"UD;W,G.PHD;6EM95]M86=I8ULW75LT75LB7#!<,3(V
M7#$Q,5PQ,#0B72`]("=F;VYT+W@M9&]S)SL*)&UI;65?;6%G:6-;.%U;-%U;
M(EPR,UPQ-S)<-3-<,3`U(ET@/2`G9F]N="]X+7-U;F]S+6YE=W,G.PHD;6EM
M95]M86=I8ULX75LT75LB7#(S7#$W,EPU,UPQ,3`B72`]("=F;VYT+W@M<W5N
M;W,M;F5W<R<["B1M:6UE7VUA9VEC6S$P75LR-5U;(EPT,UPT,%PQ,C1<,34P
M7#$U,5PQ-C-<-#!<,34Q7#$V,UPT,%PQ-#%<-#!<,38S7#$U,%PQ-#5<,34T
M7#$U-%PT,%PQ-#%<,38R7#$T,UPQ-3!<,34Q7#$V-EPQ-#4B72`]("=A<'!L
M:6-A=&EO;B]X+7-H87(G.PHD;6EM95]M86=I8ULR,%U;-%U;(EPQ,#=<,3$Q
M7#$Q-5PQ,C`B72`]("=A<'!L:6-A=&EO;B]X+6=I;7`M8G)U<V@G.PHD;6EM
M95]M86=I8ULR,%U;-%U;(EPQ,#=<,3(P7#$P,5PQ,C0B72`]("=A<'!L:6-A
M=&EO;B]X+6=I;7`M<&%T=&5R;B<["B1M:6UE7VUA9VEC6S(P75LT75LB7#,W
M-5PS,#1<,C0W7#,S-")=(#T@)V%P<&QI8V%T:6]N+W@M>F]O)SL*)&UI;65?
M;6%G:6-;,C%=6SA=6R)<-#%<,3(S7#$P,UPQ,C)<,3`U7#$P,5PQ,35<-#$B
M72`]("=A=61I;R]X+7-T,BUM;V0G.PHD;6EM95]M86=I8ULR-%U;-%U;(EPP
M7#!<,S4R7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M9'5M<"<["B1M:6UE7VUA
M9VEC6S(T75LT75LB7#!<,%PS-3)<,34T(ET@/2`G87!P;&EC871I;VXO>"UD
M=6UP)SL*)&UI;65?;6%G:6-;,C1=6S1=6R)<,%PP7#,U,EPQ-34B72`]("=A
M<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,C1=6S1=6R)<,%PP7#,U
M,EPQ-38B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;-C5=
M6S1=6R)<,3`V7#$P-EPQ,3%<,3$T(ET@/2`G9F]N="]T=&8G.PHD;6EM95]M
M86=I8ULV-5U;-%U;(EPQ,31<,3(W7#$P-EPQ,38B72`]("=F;VYT+W1Y<&4Q
M)SL*)&UI;65?;6%G:6-;,C4W75LX75LB7#$V-5PQ-C-<,38T7#$T,5PQ-C)<
M-#!<-#!<-C`B72`]("=A<'!L:6-A=&EO;B]X+6=T87(G.PHD;6EM95]M86=I
M8ULR-3==6S9=6R)<,38U7#$V,UPQ-C1<,30Q7#$V,EPV,")=(#T@)V%P<&QI
M8V%T:6]N+W@M=&%R)SL*)&UI;65?;6%G:6-;,#<W-%U;,EU;(EPS,S)<,C<V
M(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S$P.#!=6S1=
M6R)<,3`S7#$P-%PW,%PV,2)=(#T@)V%U9&EO+W@M;VMT86QY>F5R+6UO9"<[
M"B1M:6UE7VUA9VEC6S$P.#!=6S1=6R)<,3`V7#$Q-%PQ,C1<-C0B72`]("=A
M=61I;R]X+7-T87)T<F%C:V5R+6UO9"<["B1M:6UE7VUA9VEC6S$P.#!=6S1=
M6R)<,3$U7#0Q7#$Q,UPT,2)=(#T@)V%U9&EO+W@M<')O=')A8VME<BUM;V0G
M.PHD;6EM95]M86=I8ULQ,#@P75LT75LB7#$Q-5PU-EPQ,3-<-38B72`]("=A
M=61I;R]X+7!R;W1R86-K97(M;6]D)SL*)&UI;65?;6%G:6-;,3`X,%U;-%U;
M(EPQ,3=<,3$S7#$R-%PQ,#$B72`]("=A=61I;R]X+6]K=&%L>7IE<BUM;V0G
M.PHD;6EM95]M86=I8ULQ,#@P75LT75LB7#8Q7#8V7#$P,UPQ,38B72`]("=A
M=61I;R]X+71A:V5T<F%C:V5R+6UO9"<["B1M:6UE7VUA9VEC6S$P.#!=6S1=
M6R)<-C-<-C)<,3`S7#$Q-B)=(#T@)V%U9&EO+W@M=&%K971R86-K97(M;6]D
M)SL*)&UI;65?;6%G:6-;,3`X,%U;-%U;(EPV-%PQ,#-<,3$P7#$Q-B)=(#T@
M)V%U9&EO+W@M9F%S='1R86-K97(M;6]D)SL*)&UI;65?;6%G:6-;,3`X,%U;
M-%U;(EPV-EPQ,#-<,3$P7#$Q-B)=(#T@)V%U9&EO+W@M9F%S='1R86-K97(M
M;6]D)SL*)&UI;65?;6%G:6-;,3`X,%U;-%U;(EPW,%PQ,#-<,3$P7#$Q-B)=
M(#T@)V%U9&EO+W@M9F%S='1R86-K97(M;6]D)SL*)&UI;65?;6%G:6-;,C`T
M.%U;-UU;(EPQ,C!<,3`S7#$P-%PQ,S=<,3$Q7#$R,%PQ,3$B72`]("=X+W@M
M<&AO=&\M8V0M<&%C:RUF:6QE)SL*)&UI;65?;6%G:6-;,C`X,%U;,CE=6R)<
M,3$U7#$U,5PQ-#-<,38R7#$U-UPQ-C-<,34W7#$T-EPQ-C1<-#!<,3`U7#$W
M,%PQ-#-<,30U7#$U-%PT,%PV-5PU-EPV,%PT,%PQ,C=<,34W7#$V,EPQ-3-<
M,38S7#$U,%PQ-#5<,30U7#$V-")=(#T@)V%P<&QI8V%T:6]N+W9N9"YM<RUE
M>&-E;"<["B1M:6UE7VUA9VEC6S(P.#!=6S(W75LB7#$Q-5PQ-3%<,30S7#$V
M,EPQ-3=<,38S7#$U-UPQ-#9<,38T7#0P7#$R-UPQ-3=<,38R7#$T-%PT,%PV
M-EPU-EPV,%PT,%PQ,#1<,34W7#$T,UPQ-C5<,34U7#$T-5PQ-39<,38T(ET@
M/2`G=&5X="]V;F0N;7,M=V]R9"<["B1M:6UE7VUA9VEC6S(P.#!=6S(V75LB
M7#$P-%PQ-3=<,30S7#$V-5PQ-35<,30U7#$U-EPQ-C1<,34W7#0P7#$Q-5PQ
M-3%<,30S7#$V,EPQ-3=<,38S7#$U-UPQ-#9<,38T7#0P7#$R-UPQ-3=<,38R
M7#$T-%PT,%PV-B)=(#T@)W1E>'0O=FYD+FUS+7=O<F0G.PHD;6EM95]M86=I
M8ULR,3$R75LY75LB7#$Q-5PQ,C-<,3(W7#$U-UPQ-C)<,30T7#$P-%PQ-3=<
M,30S(ET@/2`G=&5X="]V;F0N;7,M=V]R9"<["B1M:6UE7VUA9VEC6S(Q,31=
M6S5=6R)<,3`R7#$U,5PQ-#9<,30V7#8U(ET@/2`G87!P;&EC871I;VXO=FYD
M+FUS+65X8V5L)SL*)&UI;65?;6%G:6-;-#`Y.%U;-UU;(EPQ,#1<,3$W7#$R
M,UPQ,#9<,3$W7#$Q-EPQ,C0B72`]("=F;VYT+W@M9&]S)SL*)&UI;65?;6%G
M:6-;-C@Q-3@T.#!=6S)=6R)<,C-<,3<W(ET@/2`G87!P;&EC871I;VXO>"UF
M:6QE<WES=&5M)SL*)&UI;65?;6%G:6-;-C@Q-3@T.#!=6S)=6R)<,C-<,C$W
M(ET@/2`G87!P;&EC871I;VXO>"UF:6QE<WES=&5M)SL*)&UI;65?;6%G:6-;
M-C@Q-3@T.#!=6S)=6R)<-#1<,34P(ET@/2`G87!P;&EC871I;VXO>"UF:6QE
M<WES=&5M)SL*)&UI;65?;6%G:6-;-C@Q-3@T.#!=6S)=6R)<-#1<,3<P(ET@
M/2`G87!P;&EC871I;VXO>"UF:6QE<WES=&5M)SL*)&UI;65?;6%G:6-;-S`W
M-SDY-C!=6S)=6R)<,S4W7#$R,R)=(#T@)V%P<&QI8V%T:6]N+W@M;&EN=7@M
M97AT,F9S)SL*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]-24U%+VUI;64N;6%P<&EN9RYP:'``````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P-3,S-#``,3`U,34T,S,W-3``,#(S,S$P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!4:&ES
M(&9I;&4@8V]N=&%I;G,@82!M87!P:6YG(&]F(&-O;6UO;B!F:6QE(&5X=&5N
M<VEO;G,@=&\*("H@34E-12!T>7!E<RX@270@:&%S(&)E96X@875T;VUA=&EC
M86QL>2!G96YE<F%T960@9G)O;2!T:&4*("H@:&]R9&4O<V-R:7!T<R]M:6UE
M7VUA<'!I;F<@9&ER96-T;W)Y+@H@*@H@*B!!3$P@8VAA;F=E<R!S:&]U;&0@
M8F4@;6%D92!T;R!H;W)D92]S8W)I<'1S+VUI;65?;6%P<&EN9R]M:6UE+G1Y
M<&5S+FAO<F1E"B`J(&]R(&5L<V4@=&AE>2!W:6QL(&)E(&QO<W0@=VAE;B!T
M:&ES(&9I;&4@:7,@<F5G96YE<F%T960N"B`J"B`J($%N>2!U;FMN;W=N(&9I
M;&4@97AT96YS:6]N<R!W:6QL(&%U=&]M871I8V%L;'D@8F4@;6%P<&5D('1O
M"B`J("=X+65X=&5N<VEO;B\\97AT/B<@=VAE<F4@/&5X=#X@:7,@=&AE('5N
M:VYO=VX@9FEL92!E>'1E;G-I;VXN"B`J"B`J($!P86-K86=E($AO<F1E7TU)
M344*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%+VUI;64N;6%P
M<&EN9RYP:'`L=B`Q+C$Q+C(N,R`R,#`V+S`R+S$P(#$P.C,W.C,S(&IA;B!%
M>'`@)`H@*@H@*B!'96YE<F%T960Z(#`R+S$P+S`V(#`P.C$X.C0U(&)Y('-L
M=7-A<GH@;VX@8FEG=V]R;2YC=7)E8V%N=&DN;W)G"B`J+PHD;6EM95]E>'1E
M;G-I;VY?;6%P(#T@87)R87DH"B=?7TU!6%!%4DE/1%]?)R`]/B`G,2<L"B`@
M("`G,V1S)R`@("`@("`@("`@/3X@)VEM86=E+W@M,V1S)RP*("`@("="3$5.
M1"<@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UB;&5N9&5R)RP*("`@("=#
M)R`@("`@("`@("`@("`]/B`G=&5X="]X+6,K*W-R8R<L"B`@("`G0U-33"<@
M("`@("`@("`@/3X@)W1E>'0O8W-S)RP*("`@("=.4U8G("`@("`@("`@("`]
M/B`G=FED96\O>"UN<W8G+`H@("`@)U!!4C(G("`@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]X+7!A<C(G+`H@("`@)UA-)R`@("`@("`@("`@(#T^("=A=61I
M;R]X+6UO9"<L"B`@("`G6B<@("`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N
M+W@M8V]M<')E<W,G+`H@("`@)V$G("`@("`@("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]X+6%R8VAI=F4G+`H@("`@)V%B=R<@("`@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]X+6%B:7=O<F0G+`H@("`@)V%B=RY#4D%32$5$)R`@(#T^("=A
M<'!L:6-A=&EO;B]X+6%B:7=O<F0G+`H@("`@)V%B=RYG>B<@("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]X+6%B:7=O<F0G+`H@("`@)V%C,R<@("`@("`@("`@
M(#T^("=A=61I;R]A8S,G+`H@("`@)V%D8B<@("`@("`@("`@(#T^("=T97AT
M+W@M861A<W)C)RP*("`@("=A9',G("`@("`@("`@("`]/B`G=&5X="]X+6%D
M87-R8R<L"B`@("`G869M)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M
M9F]N="UA9FTG+`H@("`@)V%G)R`@("`@("`@("`@(#T^("=I;6%G92]X+6%P
M<&QI>"UG<F%P:&EC<R<L"B`@("`G86DG("`@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+VEL;'5S=')A=&]R)RP*("`@("=A:68G("`@("`@("`@("`]/B`G
M875D:6\O>"UA:69F)RP*("`@("=A:69C)R`@("`@("`@("`]/B`G875D:6\O
M>"UA:69F)RP*("`@("=A:69F)R`@("`@("`@("`]/B`G875D:6\O>"UA:69F
M)RP*("`@("=A;"<@("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UP97)L
M)RP*("`@("=A<FHG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UA<FHG
M+`H@("`@)V%S)R`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6%P<&QI
M>"US<')E861S:&5E="<L"B`@("`G87-C)R`@("`@("`@("`@/3X@)W1E>'0O
M<&QA:6XG+`H@("`@)V%S9B<@("`@("`@("`@(#T^("=V:61E;R]X+6US+6%S
M9B<L"B`@("`G87-P)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M87-P
M)RP*("`@("=A<W@G("`@("`@("`@("`]/B`G=FED96\O>"UM<RUA<V8G+`H@
M("`@)V%T;VTG("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]A=&]M*WAM;"<L
M"B`@("`G874G("`@("`@("`@("`@/3X@)V%U9&EO+V)A<VEC)RP*("`@("=A
M=FDG("`@("`@("`@("`]/B`G=FED96\O>"UM<W9I9&5O)RP*("`@("=A=R<@
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UA<'!L:7@M=V]R9"<L"B`@
M("`G8F%K)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M=')A<V@G+`H@
M("`@)V)C<&EO)R`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6)C<&EO)RP*
M("`@("=B9&8G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UF;VYT+6)D
M9B<L"B`@("`G8FEB)R`@("`@("`@("`@/3X@)W1E>'0O>"UB:6)T97@G+`H@
M("`@)V)I;B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]O8W1E="US=')E
M86TG+`H@("`@)V)L96YD)R`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6)L
M96YD97(G+`H@("`@)V)L96YD97(G("`@("`@(#T^("=A<'!L:6-A=&EO;B]X
M+6)L96YD97(G+`H@("`@)V)M<"<@("`@("`@("`@(#T^("=I;6%G92]B;7`G
M+`H@("`@)V)Z)R`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6)Z:7`G
M+`H@("`@)V)Z,B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6)Z:7`G
M+`H@("`@)V,G("`@("`@("`@("`@(#T^("=T97AT+W@M8W-R8R<L"B`@("`G
M8RLK)R`@("`@("`@("`@/3X@)W1E>'0O>"UC*RMS<F,G+`H@("`@)V-C)R`@
M("`@("`@("`@(#T^("=T97AT+W@M8RLK<W)C)RP*("`@("=C9&8G("`@("`@
M("`@("`]/B`G87!P;&EC871I;VXO>"UN971C9&8G+`H@("`@)V-D<B<@("`@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N8V]R96PM9')A=R<L"B`@("`G
M8V5R)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M>#4P.2UC82UC97)T
M)RP*("`@("=C97)T)R`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UX-3`Y
M+6-A+6-E<G0G+`H@("`@)V-G:2<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]X+6-G:2<L"B`@("`G8V=M)R`@("`@("`@("`@/3X@)VEM86=E+V-G;2<L
M"B`@("`G8VAM)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M8VAM)RP*
M("`@("=C:')T)R`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UK8VAA<G0G
M+`H@("`@)V-L87-S)R`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6IA=F$G
M+`H@("`@)V-L<R<@("`@("`@("`@(#T^("=T97AT+W@M=&5X)RP*("`@("=C
M<&EO)R`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UC<&EO)RP*("`@("=C
M<&EO+F=Z)R`@("`@("`]/B`G87!P;&EC871I;VXO>"UC<&EO+6-O;7!R97-S
M960G+`H@("`@)V-P<"<@("`@("`@("`@(#T^("=T97AT+W@M8RLK<W)C)RP*
M("`@("=C<'0G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO;6%C+6-O;7!A
M8W1P<F\G+`H@("`@)V-R="<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X
M+7@U,#DM8V$M8V5R="<L"B`@("`G8W,G("`@("`@("`@("`@/3X@)W1E>'0O
M>"UC<VAA<G`G+`H@("`@)V-S:"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]X+6-S:"<L"B`@("`G8W-S)R`@("`@("`@("`@/3X@)W1E>'0O8W-S)RP*
M("`@("=C<W8G("`@("`@("`@("`]/B`G=&5X="]X+6-O;6UA+7-E<&%R871E
M9"UV86QU97,G+`H@("`@)V-U<B<@("`@("`@("`@(#T^("=I;6%G92]X+7=I
M;BUB:71M87`G+`H@("`@)V-X>"<@("`@("`@("`@(#T^("=T97AT+W@M8RLK
M<W)C)RP*("`@("=D)R`@("`@("`@("`@("`]/B`G=&5X="]X+61S<F,G+`H@
M("`@)V1A="<@("`@("`@("`@(#T^("=V:61E;R]M<&5G)RP*("`@("=D8F8G
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UD8F%S92<L"B`@("`G9&,G
M("`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9&,M<F]M)RP*("`@("=D
M8VPG("`@("`@("`@("`]/B`G=&5X="]X+61C;"<L"B`@("`G9&-M)R`@("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+V1I8V]M)RP*("`@("=D8W(G("`@("`@
M("`@("`]/B`G87!P;&EC871I;VXO>"UD:7)E8W1O<B<L"B`@("`G9&5B)R`@
M("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9&5B)RP*("`@("=D97(G("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO>"UX-3`Y+6-A+6-E<G0G+`H@("`@
M)V1E<VMT;W`G("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+61E<VMT;W`G+`H@
M("`@)V1I82<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+61I82UD:6%G
M<F%M)RP*("`@("=D:69F)R`@("`@("`@("`]/B`G=&5X="]X+7!A=&-H)RP*
M("`@("=D:7(G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UD:7)E8W1O
M<B<L"B`@("`G9&IV)R`@("`@("`@("`@/3X@)VEM86=E+W9N9"YD:G9U)RP*
M("`@("=D:G9U)R`@("`@("`@("`]/B`G:6UA9V4O=FYD+F1J=G4G+`H@("`@
M)V1L;"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG
M+`H@("`@)V1M9R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]O8W1E="US
M=')E86TG+`H@("`@)V1M<R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]O
M8W1E="US=')E86TG+`H@("`@)V1O8R<@("`@("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]M<W=O<F0G+`H@("`@)V1S;"<@("`@("`@("`@(#T^("=T97AT+W@M
M9'-L)RP*("`@("=D=&0G("`@("`@("`@("`]/B`G=&5X="]X+61T9"<L"B`@
M("`G9'9I)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9'9I)RP*("`@
M("=D=V<G("`@("`@("`@("`]/B`G:6UA9V4O=FYD+F1W9R<L"B`@("`G9'AF
M)R`@("`@("`@("`@/3X@)VEM86=E+W9N9"YD>&8G+`H@("`@)V1X<B<@("`@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+61I<F5C=&]R)RP*("`@("=E9V]N
M)R`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UE9V]N)RP*("`@("=E;"<@
M("`@("`@("`@("`]/B`G=&5X="]X+65M86-S+6QI<W`G+`H@("`@)V5P<R<@
M("`@("`@("`@(#T^("=I;6%G92]X+65P<R<L"B`@("`G97!S9B<@("`@("`@
M("`@/3X@)VEM86=E+W@M97!S)RP*("`@("=E<'-I)R`@("`@("`@("`]/B`G
M:6UA9V4O>"UE<',G+`H@("`@)V5T:&5M92<@("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]X+64M=&AE;64G+`H@("`@)V5T>"<@("`@("`@("`@(#T^("=T97AT
M+W@M<V5T97AT)RP*("`@("=E>&4G("`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO>"UM<RUD;W,M97AE8W5T86)L92<L"B`@("`G97HG("`@("`@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+V%N9')E=RUI;G-E="<L"B`@("`G9B<@("`@("`@
M("`@("`@/3X@)W1E>'0O>"UF;W)T<F%N)RP*("`@("=F:6<G("`@("`@("`@
M("`]/B`G:6UA9V4O>"UX9FEG)RP*("`@("=F:71S)R`@("`@("`@("`]/B`G
M:6UA9V4O>"UF:71S)RP*("`@("=F;&%C)R`@("`@("`@("`]/B`G875D:6\O
M>"UF;&%C)RP*("`@("=F;&,G("`@("`@("`@("`]/B`G=FED96\O>"UF;&EC
M)RP*("`@("=F;&DG("`@("`@("`@("`]/B`G=FED96\O>"UF;&EC)RP*("`@
M("=F;'<G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UK:79I;R<L"B`@
M("`G9F\G("`@("`@("`@("`@/3X@)W1E>'0O>"UX<VQF;R<L"B`@("`G9S,G
M("`@("`@("`@("`@/3X@)VEM86=E+V9A>"UG,R<L"B`@("`G9V(G("`@("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9V%M96)O>2UR;VTG+`H@("`@)V=C
M<F0G("`@("`@("`@(#T^("=T97AT+V1I<F5C=&]R>2<L"B`@("`G9V5N)R`@
M("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9V5N97-I<RUR;VTG+`H@("`@
M)V=G)R`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7-M<RUR;VTG+`H@
M("`@)V=I9B<@("`@("`@("`@(#T^("=I;6%G92]G:68G+`H@("`@)V=L861E
M)R`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6=L861E)RP*("`@("=G;6\G
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UG971T97AT+71R86YS;&%T
M:6]N)RP*("`@("=G;F,G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UG
M;G5C87-H)RP*("`@("=G;G5C87-H)R`@("`@("`]/B`G87!P;&EC871I;VXO
M>"UG;G5C87-H)RP*("`@("=G;G5M97)I8R<@("`@("`]/B`G87!P;&EC871I
M;VXO>"UG;G5M97)I8R<L"B`@("`G9W)A)R`@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+W@M9W)A<&AI=&4G+`H@("`@)V=R86TG("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]S<F=S)RP*("`@("=G<GAM;"<@("`@("`@("`]/B`G87!P
M;&EC871I;VXO<W)G<RMX;6PG+`H@("`@)V=S9B<@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]X+69O;G0M='EP93$G+`H@("`@)V=S;2<@("`@("`@("`@
M(#T^("=A=61I;R]X+6=S;2<L"B`@("`G9W1A<B<@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W@M9W1A<B<L"B`@("`G9WHG("`@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W@M9WII<"<L"B`@("`G:"<@("`@("`@("`@("`@/3X@)W1E
M>'0O>"UC:&1R)RP*("`@("=H*RLG("`@("`@("`@("`]/B`G=&5X="]X+6-H
M9'(G+`H@("`@)VAD9B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6AD
M9B<L"B`@("`G:&@G("`@("`@("`@("`@/3X@)W1E>'0O>"UC*RMH9'(G+`H@
M("`@)VAP)R`@("`@("`@("`@(#T^("=T97AT+W@M8VAD<B<L"B`@("`G:'!G
M;"<@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YH<"UH<&=L)RP*("`@
M("=H<7@G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO;6%C+6)I;FAE>#0P
M)RP*("`@("=H<R<@("`@("`@("`@("`]/B`G=&5X="]X+6AA<VME;&PG+`H@
M("`@)VAT;2<@("`@("`@("`@(#T^("=T97AT+VAT;6PG+`H@("`@)VAT;6PG
M("`@("`@("`@(#T^("=T97AT+VAT;6PG+`H@("`@)VEC8B<@("`@("`@("`@
M(#T^("=I;6%G92]X+6EC8B<L"B`@("`G:6-E)R`@("`@("`@("`@/3X@)W@M
M8V]N9F5R96YC92]X+6-O;VQT86QK)RP*("`@("=I8V\G("`@("`@("`@("`]
M/B`G:6UA9V4O>"UI8V\G+`H@("`@)VEC<R<@("`@("`@("`@(#T^("=T97AT
M+V-A;&5N9&%R)RP*("`@("=I9&PG("`@("`@("`@("`]/B`G=&5X="]X+6ED
M;"<L"B`@("`G:65F)R`@("`@("`@("`@/3X@)VEM86=E+VEE9B<L"B`@("`G
M:69B)R`@("`@("`@("`@/3X@)W1E>'0O8V%L96YD87(G+`H@("`@)VEF9B<@
M("`@("`@("`@(#T^("=I;6%G92]X+6EF9B<L"B`@("`G:6=E<R<@("`@("`@
M("`@/3X@)VUO9&5L+VEG97,G+`H@("`@)VEG<R<@("`@("`@("`@(#T^("=M
M;V1E;"]I9V5S)RP*("`@("=I;&)M)R`@("`@("`@("`]/B`G:6UA9V4O>"UI
M;&)M)RP*("`@("=I<V\G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UC
M9"UI;6%G92<L"B`@("`G:70G("`@("`@("`@("`@/3X@)V%U9&EO+W@M:70G
M+`H@("`@)VIA<B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6IA<B<L
M"B`@("`G:F%V82<@("`@("`@("`@/3X@)W1E>'0O>"UJ879A)RP*("`@("=J
M;F<G("`@("`@("`@("`]/B`G:6UA9V4O>"UJ;F<G+`H@("`@)VIN;'`G("`@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6IA=F$M:FYL<"UF:6QE)RP*("`@
M("=J<#(G("`@("`@("`@("`]/B`G:6UA9V4O:G!E9S(P,#`G+`H@("`@)VIP
M9R<@("`@("`@("`@(#T^("=I;6%G92]J<&5G)RP*("`@("=J<&4G("`@("`@
M("`@("`]/B`G:6UA9V4O:G!E9R<L"B`@("`G:G!E9R<@("`@("`@("`@/3X@
M)VEM86=E+VIP96<G+`H@("`@)VIP<B<@("`@("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]X+6IB=6EL9&5R+7!R;VIE8W0G+`H@("`@)VIP>"<@("`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]X+6IB=6EL9&5R+7!R;VIE8W0G+`H@("`@)VIS
M)R`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6IA=F%S8W)I<'0G+`H@
M("`@)VMA<B<@("`@("`@("`@(#T^("=A=61I;R]M:61I)RP*("`@("=K87)B
M;VXG("`@("`@("`]/B`G87!P;&EC871I;VXO>"UK87)B;VXG+`H@("`@)VMD
M96QN:R<@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+61E<VMT;W`G+`H@("`@
M)VMF;R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6MF;W)M=6QA)RP*
M("`@("=K:6PG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UK:6QL=7-T
M<F%T;W(G+`H@("`@)VMO;B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X
M+6MO;G1O=7(G+`H@("`@)VMP;2<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]X+6MP;W9M;V1E;&5R)RP*("`@("=K<'(G("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UK<')E<V5N=&5R)RP*("`@("=K<'0G("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO>"UK<')E<V5N=&5R)RP*("`@("=K<F$G("`@("`@
M("`@("`]/B`G87!P;&EC871I;VXO>"UK<FET82<L"B`@("`G:W-P)R`@("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M:W-P<F5A9"<L"B`@("`G:W5D)R`@
M("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M:W5G87(G+`H@("`@)VMW9"<@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6MW;W)D)RP*("`@("=K=W0G
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UK=V]R9"<L"B`@("`G;&$G
M("`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<VAA<F5D+6QI8G)A<GDM
M;&$G+`H@("`@)VQA=&5X)R`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6QA
M=&5X)RP*("`@("=L:&$G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UL
M:&$G+`H@("`@)VQH<R<@("`@("`@("`@(#T^("=T97AT+W@M;&ET97)A=&4M
M:&%S:V5L;"<L"B`@("`G;&AZ)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N
M+W@M;&AZ)RP*("`@("=L;V<G("`@("`@("`@("`]/B`G=&5X="]X+6QO9R<L
M"B`@("`G;'1X)R`@("`@("`@("`@/3X@)W1E>'0O>"UT97@G+`H@("`@)VQW
M;R<@("`@("`@("`@(#T^("=I;6%G92]X+6QW;R<L"B`@("`G;'=O8B<@("`@
M("`@("`@/3X@)VEM86=E+W@M;'=O)RP*("`@("=L=W,G("`@("`@("`@("`]
M/B`G:6UA9V4O>"UL=W,G+`H@("`@)VQY>"<@("`@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]X+6QY>"<L"B`@("`G;'IH)R`@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+W@M;&AA)RP*("`@("=L>F\G("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO>"UL>F]P)RP*("`@("=M)R`@("`@("`@("`@("`]/B`G=&5X="]X
M+6]B:F-S<F,G+`H@("`@)VTQ-2<@("`@("`@("`@(#T^("=A=61I;R]X+6UO
M9"<L"B`@("`G;3-U)R`@("`@("`@("`@/3X@)V%U9&EO+W@M;7!E9W5R;"<L
M"B`@("`G;31A)R`@("`@("`@("`@/3X@)V%U9&EO+W@M;31A)RP*("`@("=M
M-'4G("`@("`@("`@("`]/B`G=FED96\O=FYD+FUP96=U<FPG+`H@("`@)VUA
M;B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+71R;V9F+6UA;B<L"B`@
M("`G;6%T:&UL)R`@("`@("`@/3X@)V%P<&QI8V%T:6]N+VUA=&AM;"MX;6PG
M+`H@("`@)VUD)R`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6=E;F5S
M:7,M<F]M)RP*("`@("=M92<@("`@("`@("`@("`]/B`G=&5X="]X+71R;V9F
M+6UE)RP*("`@("=M97-H)R`@("`@("`@("`]/B`G;6]D96PO;65S:"<L"B`@
M("`G;6=P)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M;6%G:6-P;VEN
M="<L"B`@("`G;6ED)R`@("`@("`@("`@/3X@)V%U9&EO+VUI9&DG+`H@("`@
M)VUI9&DG("`@("`@("`@(#T^("=A=61I;R]M:61I)RP*("`@("=M:68G("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO>"UM:68G+`H@("`@)VUK=B<@("`@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6UA=')O<VMA)RP*("`@("=M;2<@
M("`@("`@("`@("`]/B`G=&5X="]X+71R;V9F+6UM)RP*("`@("=M;6PG("`@
M("`@("`@("`]/B`G=&5X="]M871H;6PG+`H@("`@)VUN9R<@("`@("`@("`@
M(#T^("=V:61E;R]X+6UN9R<L"B`@("`G;6]C)R`@("`@("`@("`@/3X@)W1E
M>'0O>"UM;V,G+`H@("`@)VUO9"<@("`@("`@("`@(#T^("=A=61I;R]X+6UO
M9"<L"B`@("`G;6]O=B<@("`@("`@("`@/3X@)W9I9&5O+W%U:6-K=&EM92<L
M"B`@("`G;6]V)R`@("`@("`@("`@/3X@)W9I9&5O+W%U:6-K=&EM92<L"B`@
M("`G;6]V:64G("`@("`@("`@/3X@)W9I9&5O+W@M<V=I+6UO=FEE)RP*("`@
M("=M<#(G("`@("`@("`@("`]/B`G=FED96\O;7!E9R<L"B`@("`G;7`S)R`@
M("`@("`@("`@/3X@)V%U9&EO+VUP96<G+`H@("`@)VUP92<@("`@("`@("`@
M(#T^("=V:61E;R]M<&5G)RP*("`@("=M<&5G)R`@("`@("`@("`]/B`G=FED
M96\O;7!E9R<L"B`@("`G;7!G)R`@("`@("`@("`@/3X@)W9I9&5O+VUP96<G
M+`H@("`@)VUP9V$G("`@("`@("`@(#T^("=A=61I;R]M<&5G)RP*("`@("=M
M<R<@("`@("`@("`@("`]/B`G=&5X="]X+71R;V9F+6US)RP*("`@("=M<V@G
M("`@("`@("`@("`]/B`G;6]D96PO;65S:"<L"B`@("`G;7-O9"<@("`@("`@
M("`@/3X@)VEM86=E+W@M;7-O9"<L"B`@("`G;7-X)R`@("`@("`@("`@/3X@
M)V%P<&QI8V%T:6]N+W@M;7-X+7)O;2<L"B`@("`G;71M)R`@("`@("`@("`@
M/3X@)V%U9&EO+W@M;6]D)RP*("`@("=M>'4G("`@("`@("`@("`]/B`G=FED
M96\O=FYD+FUP96=U<FPG+`H@("`@)VXV-"<@("`@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]X+6XV-"UR;VTG+`H@("`@)VYB)R`@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]M871H96UA=&EC82<L"B`@("`G;F,G("`@("`@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+W@M;F5T8V1F)RP*("`@("=N97,G("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO>"UN97,M<F]M)RP*("`@("=N<W8G("`@("`@
M("`@("`]/B`G=FED96\O>"UN<W8G+`H@("`@)V\G("`@("`@("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]X+6]B:F5C="<L"B`@("`G;V)J)R`@("`@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+W@M=&=I9B<L"B`@("`G;V1A)R`@("`@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+V]D82<L"B`@("`G;V1B)R`@("`@("`@("`@/3X@
M)V%P<&QI8V%T:6]N+W9N9"YO87-I<RYO<&5N9&]C=6UE;G0N9&%T86)A<V4G
M+`H@("`@)V]D8R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;V%S
M:7,N;W!E;F1O8W5M96YT+F-H87)T)RP*("`@("=O9&8G("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO=FYD+F]A<VES+F]P96YD;V-U;65N="YF;W)M=6QA
M)RP*("`@("=O9&<G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+F]A
M<VES+F]P96YD;V-U;65N="YG<F%P:&EC<R<L"B`@("`G;V1I)R`@("`@("`@
M("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YO87-I<RYO<&5N9&]C=6UE;G0N:6UA
M9V4G+`H@("`@)V]D;2<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N
M;V%S:7,N;W!E;F1O8W5M96YT+G1E>'0M;6%S=&5R)RP*("`@("=O9'`G("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+F]A<VES+F]P96YD;V-U;65N
M="YP<F5S96YT871I;VXG+`H@("`@)V]D<R<@("`@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]V;F0N;V%S:7,N;W!E;F1O8W5M96YT+G-P<F5A9'-H965T)RP*
M("`@("=O9'0G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+F]A<VES
M+F]P96YD;V-U;65N="YT97AT)RP*("`@("=O9V<G("`@("`@("`@("`]/B`G
M87!P;&EC871I;VXO;V=G)RP*("`@("=O;&0G("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UT<F%S:"<L"B`@("`G;VQE;R<@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W@M;VQE;R<L"B`@("`G;V]T)R`@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W9N9"YO87-I<RYO<&5N9&]C=6UE;G0N=&5X="<L"B`@("`G
M;W1G)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YO87-I<RYO<&5N
M9&]C=6UE;G0N9W)A<&AI8W,M=&5M<&QA=&4G+`H@("`@)V]T:"<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;V%S:7,N;W!E;F1O8W5M96YT+G1E
M>'0M=V5B)RP*("`@("=O='`G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M=FYD+F]A<VES+F]P96YD;V-U;65N="YP<F5S96YT871I;VXM=&5M<&QA=&4G
M+`H@("`@)V]T<R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;V%S
M:7,N;W!E;F1O8W5M96YT+G-P<F5A9'-H965T+71E;7!L871E)RP*("`@("=O
M='0G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+F]A<VES+F]P96YD
M;V-U;65N="YT97AT+71E;7!L871E)RP*("`@("=P)R`@("`@("`@("`@("`]
M/B`G=&5X="]X+7!A<V-A;"<L"B`@("`G<#$R)R`@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W@M<&MC<S$R)RP*("`@("=P-W,G("`@("`@("`@("`]/B`G
M87!P;&EC871I;VXO<&MC<S<M<VEG;F%T=7)E)RP*("`@("=P87(R)R`@("`@
M("`@("`]/B`G87!P;&EC871I;VXO>"UP87(R)RP*("`@("=P87,G("`@("`@
M("`@("`]/B`G=&5X="]X+7!A<V-A;"<L"B`@("`G<&%T8V@G("`@("`@("`@
M/3X@)W1E>'0O>"UP871C:"<L"B`@("`G<&)M)R`@("`@("`@("`@/3X@)VEM
M86=E+W@M<&]R=&%B;&4M8FET;6%P)RP*("`@("=P8V0G("`@("`@("`@("`]
M/B`G:6UA9V4O>"UP:&]T;RUC9"<L"B`@("`G<&-F)R`@("`@("`@("`@/3X@
M)V%P<&QI8V%T:6]N+W@M9F]N="UP8V8G+`H@("`@)W!C9BY:)R`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]X+69O;G0M='EP93$G+`H@("`@)W!C;"<@("`@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N:'`M<&-L)RP*("`@("=P9&(G
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+G!A;&TG+`H@("`@)W!D
M9B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]P9&8G+`H@("`@)W!E;2<@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7@U,#DM8V$M8V5R="<L"B`@
M("`G<&5R;"<@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<&5R;"<L"B`@
M("`G<&9A)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9F]N="UT>7!E
M,2<L"B`@("`G<&9B)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9F]N
M="UT>7!E,2<L"B`@("`G<&9X)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N
M+W@M<&MC<S$R)RP*("`@("=P9VTG("`@("`@("`@("`]/B`G:6UA9V4O>"UP
M;W)T86)L92UG<F%Y;6%P)RP*("`@("=P9VXG("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UC:&5S<RUP9VXG+`H@("`@)W!G<"<@("`@("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]P9W`G+`H@("`@)W!H<"<@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]X+7!H<"<L"B`@("`G<&AP,R<@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W@M<&AP)RP*("`@("=P:'`T)R`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UP:'`G+`H@("`@)W!I8W0G("`@("`@("`@(#T^("=I;6%G
M92]X+7!I8W0G+`H@("`@)W!I8W0Q)R`@("`@("`@(#T^("=I;6%G92]X+7!I
M8W0G+`H@("`@)W!I8W0R)R`@("`@("`@(#T^("=I;6%G92]X+7!I8W0G+`H@
M("`@)W!L)R`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7!E<FPG+`H@
M("`@)W!L<R<@("`@("`@("`@(#T^("=A=61I;R]X+7-C<&QS)RP*("`@("=P
M;2<@("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UP97)L)RP*("`@("=P
M;F<G("`@("`@("`@("`]/B`G:6UA9V4O<&YG)RP*("`@("=P;FTG("`@("`@
M("`@("`]/B`G:6UA9V4O>"UP;W)T86)L92UA;GEM87`G+`H@("`@)W!O)R`@
M("`@("`@("`@(#T^("=T97AT+W@M9V5T=&5X="UT<F%N<VQA=&EO;B<L"B`@
M("`G<&]T)R`@("`@("`@("`@/3X@)W1E>'0O>"UG971T97AT+71R86YS;&%T
M:6]N+71E;7!L871E)RP*("`@("=P<&TG("`@("`@("`@("`]/B`G:6UA9V4O
M>"UP;W)T86)L92UP:7AM87`G+`H@("`@)W!P<R<@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]V;F0N;7,M<&]W97)P;VEN="<L"B`@("`G<'!T)R`@("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YM<RUP;W=E<G!O:6YT)RP*("`@
M("=P<'HG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+FUS+7!O=V5R
M<&]I;G0G+`H@("`@)W!S)R`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]P
M;W-T<V-R:7!T)RP*("`@("=P<RYG>B<@("`@("`@("`]/B`G87!P;&EC871I
M;VXO>"UG>G!O<W1S8W)I<'0G+`H@("`@)W!S9"<@("`@("`@("`@(#T^("=I
M;6%G92]X+7!S9"<L"B`@("`G<'-F)R`@("`@("`@("`@/3X@)V%P<&QI8V%T
M:6]N+W@M9F]N="UL:6YU>"UP<V8G+`H@("`@)W!S:60G("`@("`@("`@(#T^
M("=A=61I;R]P<G,N<VED)RP*("`@("=P=R<@("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UP=R<L"B`@("`G<'DG("`@("`@("`@("`@/3X@)W1E>'0O
M>"UP>71H;VXG+`H@("`@)W!Y8R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]X+7!Y=&AO;BUB>71E8V]D92<L"B`@("`G<'EO)R`@("`@("`@("`@/3X@
M)V%P<&QI8V%T:6]N+W@M<'ET:&]N+6)Y=&5C;V1E)RP*("`@("=Q:68G("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO>"UQ=R<L"B`@("`G<70G("`@("`@
M("`@("`@/3X@)W9I9&5O+W%U:6-K=&EM92<L"B`@("`G<71V<B<@("`@("`@
M("`@/3X@)W9I9&5O+W%U:6-K=&EM92<L"B`@("`G<F$G("`@("`@("`@("`@
M/3X@)V%U9&EO+W@M<&XM<F5A;&%U9&EO)RP*("`@("=R86TG("`@("`@("`@
M("`]/B`G875D:6\O>"UP;BUR96%L875D:6\G+`H@("`@)W)A<B<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]X+7)A<B<L"B`@("`G<F%S)R`@("`@("`@
M("`@/3X@)VEM86=E+W@M8VUU+7)A<W1E<B<L"B`@("`G<F1F)R`@("`@("`@
M("`@/3X@)W1E>'0O<F1F)RP*("`@("=R96HG("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UR96IE8W0G+`H@("`@)W)G8B<@("`@("`@("`@(#T^("=I
M;6%G92]X+7)G8B<L"B`@("`G<FQE)R`@("`@("`@("`@/3X@)VEM86=E+W)L
M92<L"B`@("`G<FTG("`@("`@("`@("`@/3X@)V%U9&EO+W@M<&XM<F5A;&%U
M9&EO)RP*("`@("=R;V9F)R`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UT
M<F]F9B<L"B`@("`G<G!M)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M
M<G!M)RP*("`@("=R<W,G("`@("`@("`@("`]/B`G=&5X="]R<W,G+`H@("`@
M)W)T9B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]R=&8G+`H@("`@)W)T
M>"<@("`@("`@("`@(#T^("=T97AT+W)I8VAT97AT)RP*("`@("=S,VTG("`@
M("`@("`@("`]/B`G875D:6\O>"US,VTG+`H@("`@)W-A;2<@("`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]X+6%M:7!R;R<L"B`@("`G<V-M)R`@("`@("`@
M("`@/3X@)W1E>'0O>"US8VAE;64G+`H@("`@)W-D82<@("`@("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]V;F0N<W1A<F1I=FES:6]N+F1R87<G+`H@("`@)W-D
M8R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N<W1A<F1I=FES:6]N
M+F-A;&,G+`H@("`@)W-D9"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V
M;F0N<W1A<F1I=FES:6]N+FEM<')E<W,G+`H@("`@)W-D<"<@("`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]V;F0N<W1A<F1I=FES:6]N+FEM<')E<W,G+`H@
M("`@)W-D<R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N<W1A<F1I
M=FES:6]N+F-H87)T)RP*("`@("=S9'<G("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO=FYD+G-T87)D:79I<VEO;BYW<FET97(G+`H@("`@)W-G:2<@("`@
M("`@("`@(#T^("=I;6%G92]X+7-G:2<L"B`@("`G<V=L)R`@("`@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+W9N9"YS=&%R9&EV:7-I;VXN=W)I=&5R)RP*("`@
M("=S9VTG("`@("`@("`@("`]/B`G=&5X="]S9VUL)RP*("`@("=S9VUL)R`@
M("`@("`@("`]/B`G=&5X="]S9VUL)RP*("`@("=S:"<@("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO>"US:&5L;'-C<FEP="<L"B`@("`G<VAA<B<@("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<VAA<B<L"B`@("`G<VAT;6PG("`@
M("`@("`@/3X@)W1E>'0O:'1M;"<L"B`@("`G<VEA9R<@("`@("`@("`@/3X@
M)V%P<&QI8V%T:6]N+W@M<VEA9R<L"B`@("`G<VED)R`@("`@("`@("`@/3X@
M)V%U9&EO+W!R<RYS:60G+`H@("`@)W-I:R<@("`@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]X+71R87-H)RP*("`@("=S:6QO)R`@("`@("`@("`]/B`G;6]D
M96PO;65S:"<L"B`@("`G<VET)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N
M+W-T=69F:70G+`H@("`@)W-K9"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]X+6MO86XG+`H@("`@)W-K;2<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]X+6MO86XG+`H@("`@)W-K<"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]X+6MO86XG+`H@("`@)W-K="<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]X+6MO86XG+`H@("`@)W-L:R<@("`@("`@("`@(#T^("=T97AT+W-P<F5A
M9'-H965T)RP*("`@("=S;60G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M=FYD+G-T87)D:79I<VEO;BYM86EL)RP*("`@("=S;68G("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO=FYD+G-T87)D:79I<VEO;BYM871H)RP*("`@("=S
M;6DG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO<VUI;"<L"B`@("`G<VUI
M;"<@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W-M:6PG+`H@("`@)W-M;"<@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]S;6EL)RP*("`@("=S;7,G("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO>"US;7,M<F]M)RP*("`@("=S;F0G
M("`@("`@("`@("`]/B`G875D:6\O8F%S:6,G+`H@("`@)W-O)R`@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]X+7-H87)E9&QI8B<L"B`@("`G<W!D)R`@
M("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9F]N="US<&5E9&\G+`H@("`@
M)W-P;"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+69U='5R97-P;&%S
M:"<L"B`@("`G<W%L)R`@("`@("`@("`@/3X@)W1E>'0O>"US<6PG+`H@("`@
M)W-R8R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7=A:7,M<V]U<F-E
M)RP*("`@("=S=&,G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+G-U
M;BYX;6PN8V%L8RYT96UP;&%T92<L"B`@("`G<W1D)R`@("`@("`@("`@/3X@
M)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+F1R87<N=&5M<&QA=&4G+`H@("`@
M)W-T:2<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YI
M;7!R97-S+G1E;7!L871E)RP*("`@("=S=&TG("`@("`@("`@("`]/B`G875D
M:6\O>"US=&TG+`H@("`@)W-T=R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]V;F0N<W5N+GAM;"YW<FET97(N=&5M<&QA=&4G+`H@("`@)W-T>2<@("`@
M("`@("`@(#T^("=T97AT+W@M=&5X)RP*("`@("=S=6XG("`@("`@("`@("`]
M/B`G:6UA9V4O>"US=6XM<F%S=&5R)RP*("`@("=S=C1C<&EO)R`@("`@("`]
M/B`G87!P;&EC871I;VXO>"US=C1C<&EO)RP*("`@("=S=C1C<F,G("`@("`@
M("`]/B`G87!P;&EC871I;VXO>"US=C1C<F,G+`H@("`@)W-V9R<@("`@("`@
M("`@(#T^("=I;6%G92]S=F<K>&UL)RP*("`@("=S=V8G("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO>"US:&]C:W=A=F4M9FQA<V@G+`H@("`@)W-X8R<@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YC86QC)RP*
M("`@("=S>&0G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+G-U;BYX
M;6PN9')A=R<L"B`@("`G<WAG)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N
M+W9N9"YS=6XN>&UL+G=R:71E<BYG;&]B86PG+`H@("`@)W-X:2<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YI;7!R97-S)RP*("`@
M("=S>&TG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+G-U;BYX;6PN
M;6%T:"<L"B`@("`G<WAW)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N
M9"YS=6XN>&UL+G=R:71E<B<L"B`@("`G<WEL:R<@("`@("`@("`@/3X@)W1E
M>'0O<W!R96%D<VAE970G+`H@("`@)W0G("`@("`@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]X+71R;V9F)RP*("`@("=T87(G("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UT87(G+`H@("`@)W1A<BY:)R`@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]X+71A<GHG+`H@("`@)W1A<BYB>B<@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]X+6)Z:7`M8V]M<')E<W-E9"UT87(G+`H@("`@)W1A<BYB>C(G
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6)Z:7`M8V]M<')E<W-E9"UT87(G
M+`H@("`@)W1A<BYG>B<@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6-O;7!R
M97-S960M=&%R)RP*("`@("=T87(N;'IO)R`@("`@("`]/B`G87!P;&EC871I
M;VXO>"UT>F\G+`H@("`@)W1C;"<@("`@("`@("`@(#T^("=T97AT+W@M=&-L
M)RP*("`@("=T97@G("`@("`@("`@("`]/B`G=&5X="]X+71E>"<L"B`@("`G
M=&5X:2<@("`@("`@("`@/3X@)W1E>'0O>"UT97AI;F9O)RP*("`@("=T97AI
M;F9O)R`@("`@("`]/B`G=&5X="]X+71E>&EN9F\G+`H@("`@)W1G82<@("`@
M("`@("`@(#T^("=I;6%G92]X+71G82<L"B`@("`G=&=Z)R`@("`@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+W@M8V]M<')E<W-E9"UT87(G+`H@("`@)W1H96UE
M)R`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+71H96UE)RP*("`@("=T:68G
M("`@("`@("`@("`]/B`G:6UA9V4O=&EF9B<L"B`@("`G=&EF9B<@("`@("`@
M("`@/3X@)VEM86=E+W1I9F8G+`H@("`@)W1K)R`@("`@("`@("`@(#T^("=T
M97AT+W@M=&-L)RP*("`@("=T;W)R96YT)R`@("`@("`]/B`G87!P;&EC871I
M;VXO>"UB:71T;W)R96YT)RP*("`@("=T<B<@("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UT<F]F9B<L"B`@("`G=',G("`@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W@M;&EN9W5I<W0G+`H@("`@)W1S=B<@("`@("`@("`@(#T^
M("=T97AT+W1A8BUS97!A<F%T960M=F%L=65S)RP*("`@("=T=&8G("`@("`@
M("`@("`]/B`G87!P;&EC871I;VXO>"UF;VYT+71T9B<L"B`@("`G='AT)R`@
M("`@("`@("`@/3X@)W1E>'0O<&QA:6XG+`H@("`@)W1Z;R<@("`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]X+71Z;R<L"B`@("`G=6DG("`@("`@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+W@M9&5S:6=N97(G+`H@("`@)W5I;"<@("`@("`@
M("`@(#T^("=T97AT+W@M=6EL)RP*("`@("=U;'0G("`@("`@("`@("`]/B`G
M875D:6\O>"UM;V0G+`H@("`@)W5N:2<@("`@("`@("`@(#T^("=A=61I;R]X
M+6UO9"<L"B`@("`G=7)I)R`@("`@("`@("`@/3X@)W1E>'0O>"UU<FDG+`H@
M("`@)W5R;"<@("`@("`@("`@(#T^("=T97AT+W@M=7)I)RP*("`@("=U<W1A
M<B<@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UU<W1A<B<L"B`@("`G=F-D
M)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M8V1L:6YK)RP*("`@("=V
M8V8G("`@("`@("`@("`]/B`G=&5X="]D:7)E8W1O<GDG+`H@("`@)W9C<R<@
M("`@("`@("`@(#T^("=T97AT+V-A;&5N9&%R)RP*("`@("=V8W0G("`@("`@
M("`@("`]/B`G=&5X="]D:7)E8W1O<GDG+`H@("`@)W9F8B<@("`@("`@("`@
M(#T^("=T97AT+V-A;&5N9&%R)RP*("`@("=V;V(G("`@("`@("`@("`]/B`G
M=FED96\O;7!E9R<L"B`@("`G=F]C)R`@("`@("`@("`@/3X@)V%U9&EO+W@M
M=F]C)RP*("`@("=V;W(G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD
M+G-T87)D:79I<VEO;BYW<FET97(G+`H@("`@)W9R;6PG("`@("`@("`@(#T^
M("=M;V1E;"]V<FUL)RP*("`@("=V<V0G("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO=FYD+G9I<VEO)RP*("`@("=V>&UL)R`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO=F]I8V5X;6PK>&UL)RP*("`@("=W878G("`@("`@("`@("`]
M/B`G875D:6\O>"UW878G+`H@("`@)W=A>"<@("`@("`@("`@(#T^("=A=61I
M;R]X+6US+7=A>"<L"B`@("`G=V(Q)R`@("`@("`@("`@/3X@)V%P<&QI8V%T
M:6]N+W@M<75A='1R;W!R;R<L"B`@("`G=V(R)R`@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W@M<75A='1R;W!R;R<L"B`@("`G=V(S)R`@("`@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+W@M<75A='1R;W!R;R<L"B`@("`G=V)M<"<@("`@
M("`@("`@/3X@)VEM86=E+W9N9"YW87`N=V)M<"<L"B`@("`G=V)X;6PG("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YW87`N=V)X;6PG+`H@("`@)W=K
M,2<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;&]T=7,M,2TR+3,G
M+`H@("`@)W=K,R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;&]T
M=7,M,2TR+3,G+`H@("`@)W=K-"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]V;F0N;&]T=7,M,2TR+3,G+`H@("`@)W=K<R<@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]V;F0N;&]T=7,M,2TR+3,G+`H@("`@)W=M)R`@("`@("`@
M("`@(#T^("=V:61E;R]X+6US+7=M)RP*("`@("=W;6$G("`@("`@("`@("`]
M/B`G875D:6\O>"UM<RUW;6$G+`H@("`@)W=M9"<@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]X+6US+7=M9"<L"B`@("`G=VUF)R`@("`@("`@("`@/3X@
M)VEM86=E+W@M=VUF)RP*("`@("=W;6PG("`@("`@("`@("`]/B`G=&5X="]V
M;F0N=V%P+G=M;"<L"B`@("`G=VUL8R<@("`@("`@("`@/3X@)V%P<&QI8V%T
M:6]N+W9N9"YW87`N=VUL8R<L"B`@("`G=VUL<R<@("`@("`@("`@/3X@)W1E
M>'0O=FYD+G=A<"YW;6QS8W)I<'0G+`H@("`@)W=M;'-C)R`@("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]V;F0N=V%P+G=M;'-C<FEP=&,G+`H@("`@)W=M=B<@
M("`@("`@("`@(#T^("=V:61E;R]X+6US+7=M=B<L"B`@("`G=VUX)R`@("`@
M("`@("`@/3X@)W9I9&5O+W@M;7,M=VUX)RP*("`@("=W;7HG("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO>"UM<RUW;7HG+`H@("`@)W=P9"<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N=V]R9'!E<F9E8W0G+`H@("`@)W=P
M9R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7=P9R<L"B`@("`G=W)I
M)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M;7-W<FET92<L"B`@("`G
M=W)L)R`@("`@("`@("`@/3X@)VUO9&5L+W9R;6PG+`H@("`@)W=V>"<@("`@
M("`@("`@(#T^("=V:61E;R]X+6US+7=V>"<L"B`@("`G>&%C)R`@("`@("`@
M("`@/3X@)V%P<&QI8V%T:6]N+W@M9VYU8V%S:"<L"B`@("`G>&)E;"<@("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M>&)E;"<L"B`@("`G>&)M)R`@("`@
M("`@("`@/3X@)VEM86=E+W@M>&)I=&UA<"<L"B`@("`G>&-F)R`@("`@("`@
M("`@/3X@)VEM86=E+W@M>&-F)RP*("`@("=X8V8N8GHR)R`@("`@("`]/B`G
M:6UA9V4O>"UC;VUP<F5S<V5D+7AC9B<L"B`@("`G>&-F+F=Z)R`@("`@("`@
M/3X@)VEM86=E+W@M8V]M<')E<W-E9"UX8V8G+`H@("`@)WAH="<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]X:'1M;"MX;6PG+`H@("`@)WAH=&UL)R`@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]X:'1M;"MX;6PG+`H@("`@)WAI)R`@
M("`@("`@("`@(#T^("=A=61I;R]X+7AI)RP*("`@("=X;&$G("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO=FYD+FUS+65X8V5L)RP*("`@("=X;&,G("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+FUS+65X8V5L)RP*("`@("=X
M;&0G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+FUS+65X8V5L)RP*
M("`@("=X;&PG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+FUS+65X
M8V5L)RP*("`@("=X;&TG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD
M+FUS+65X8V5L)RP*("`@("=X;',G("`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO=FYD+FUS+65X8V5L)RP*("`@("=X;'0G("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO=FYD+FUS+65X8V5L)RP*("`@("=X;'<G("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO=FYD+FUS+65X8V5L)RP*("`@("=X;2<@("`@("`@
M("`@("`]/B`G875D:6\O>"UX;2<L"B`@("`G>&UI)R`@("`@("`@("`@/3X@
M)W1E>'0O>"UX;6DG+`H@("`@)WAM;"<@("`@("`@("`@(#T^("=T97AT+WAM
M;"<L"B`@("`G>'!M)R`@("`@("`@("`@/3X@)VEM86=E+W@M>'!I>&UA<"<L
M"B`@("`G>'-L)R`@("`@("`@("`@/3X@)W1E>'0O>"UX<VQT)RP*("`@("=X
M<VQF;R<@("`@("`@("`]/B`G=&5X="]X+7AS;&9O)RP*("`@("=X<VQT)R`@
M("`@("`@("`]/B`G=&5X="]X+7AS;'0G+`H@("`@)WAU;"<@("`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]V;F0N;6]Z:6QL82YX=6PK>&UL)RP*("`@("=X
M=V0G("`@("`@("`@("`]/B`G:6UA9V4O>"UX=VEN9&]W9'5M<"<L"B`@("`G
M>'EZ)R`@("`@("`@("`@/3X@)V-H96UI8V%L+W@M>'EZ)RP*("`@("=Z86)W
M)R`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UA8FEW;W)D)RP*("`@("=Z
M:7`G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>FEP)RP*("`@("=Z;V\G
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UZ;V\G+`H@("`@)S$R,R<@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;&]T=7,M,2TR+3,G+`H@
M("`@)S8V.2<@("`@("`@("`@(#T^("=A=61I;R]X+6UO9"<**3L`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]-24U%+U!A<G0N<&AP````````````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`Q,C,R,3$`,3`U,34T,S,W-#<`,#(Q-C,V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N
M8V4@)TAO<F1E+U-T<FEN9RYP:'`G.PIR97%U:7)E7V]N8V4@9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+RXN+TU)344N<&AP)SL*"B\J*@H@*B!4:&4@8VAA<F%C
M=&5R*',I('5S960@:6YT97)N86QL>2!F;W(@14],<RX*("HO"F1E9FEN92@G
M34E-15]005)47T5/3"<L(")<;B(I.PH*+RHJ"B`J(%1H92!C:&%R86-T97(@
M<W1R:6YG(&1E<VEG;F%T960@8GD@4D9#<R`X,C(O,C`T-2!T;R!D97-I9VYA
M=&4@14],<R!I;B!-24U%"B`J(&UE<W-A9V5S+@H@*B\*9&5F:6YE*"=-24U%
M7U!!4E1?4D9#7T5/3"<L(")<<EQN(BD["@HO*B!$969A=6QT($U)344@<&%R
M86UE=&5R<RX@*B\*"B\J*@H@*B!4:&4@9&5F875L="!-24U%(&-H87)A8W1E
M<B!S970N"B`J+PID969I;F4H)TU)345?1$5&055,5%]#2$%24T54)RP@)W5S
M+6%S8VEI)RD["@HO*BH*("H@5&AE(&1E9F%U;'0@34E-12!D97-C<FEP=&EO
M;BX*("HO"F1E9FEN92@G34E-15]$149!54Q47T1%4T-225!424].)RP@7R@B
M=6YN86UE9"(I*3L*"B\J*@H@*B!4:&4@9&5F875L="!-24U%(&1I<W!O<VET
M:6]N+@H@*B\*9&5F:6YE*"=-24U%7T1%1D%53%1?1$E34$]3251)3TXG+"`G
M:6YL:6YE)RD["@HO*BH*("H@5&AE(&1E9F%U;'0@34E-12!E;F-O9&EN9RX*
M("HO"F1E9FEN92@G34E-15]$149!54Q47T5.0T]$24Y')RP@)S=B:70G*3L*
M"B\J*@H@*B!4:&4@34E-15]087)T.CH@8VQA<W,@<')O=FED97,@82!W<F%P
M<&5R(&%R;W5N9"!-24U%('!A<G1S(&%N9"!M971H;V1S"B`J(&9O<B!D96%L
M:6YG('=I=&@@=&AE;2X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-
M24U%+U!A<G0N<&AP+'8@,2XQ-S<N-"XR,"`R,#`V+S`S+S`Y(#(Q.C4Y.C,Q
M(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`R
M+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A
M9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@($UI8VAA96P@
M4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I
M;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7TU)344*("HO"F-L
M87-S($U)345?4&%R="!["@H@("`@+RHJ"B`@("`@*B!4:&4@='EP92`H97@N
M.B!T97AT*2!O9B!T:&ES('!A<G0N"B`@("`@*B!097(@4D9#(#(P-#4L('1H
M92!D969A=6QT(&ES("=A<'!L:6-A=&EO;B<N"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?='EP92`]("=A<'!L:6-A=&EO
M;B<["@H@("`@+RHJ"B`@("`@*B!4:&4@<W5B='EP92`H97@N.B!P;&%I;BD@
M;V8@=&AI<R!P87)T+@H@("`@("H@4&5R(%)&0R`R,#0U+"!T:&4@9&5F875L
M="!I<R`G;V-T970M<W1R96%M)RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)%]S=6)T>7!E(#T@)V]C=&5T+7-T<F5A;2<[
M"@H@("`@+RHJ"B`@("`@*B!4:&4@8F]D>2!O9B!T:&4@<&%R="X*("`@("`J
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]C;VYT96YT
M<R`]("<G.PH*("`@("\J*@H@("`@("H@5&AE(&1E<VER960@=')A;G-F97(@
M96YC;V1I;F<@;V8@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D7W1R86YS9F5R16YC;V1I;F<@/2!-24U%
M7T1%1D%53%1?14Y#3T1)3D<["@H@("`@+RHJ"B`@("`@*B!4:&4@8W5R<F5N
M="!T<F%N<V9E<B!E;F-O9&EN9R!O9B!T:&4@8V]N=&5N=',@;V8@=&AI<R!P
M87)T+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D7V-U<G)E;G1%;F-O9&EN9R`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!3
M:&]U;&0@=&AE(&UE<W-A9V4@8F4@96YC;V1E9"!V:6$@-RUB:70_"B`@("`@
M*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V5N8V]D
M93=B:70@/2!T<G5E.PH*("`@("\J*@H@("`@("H@5&AE(&1E<V-R:7!T:6]N
M(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)%]D97-C<FEP=&EO;B`]("<G.PH*("`@("\J*@H@("`@
M("H@5&AE(&1I<W!O<VET:6]N(&]F('1H:7,@<&%R="`H:6YL:6YE(&]R(&%T
M=&%C:&UE;G0I+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7V1I<W!O<VET:6]N(#T@34E-15]$149!54Q47T1)4U!/4TE4
M24]..PH*("`@("\J*@H@("`@("H@5&AE(&1I<W!O<VET:6]N('!A<F%M971E
M<G,@;V8@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1?9&ES<&]S:71I;VY087)A;65T97)S(#T@87)R87DH
M*3L*"B`@("`O*BH*("`@("`J(%1H92!C;VYT96YT('1Y<&4@<&%R86UE=&5R
M<R!O9B!T:&ES('!A<G0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)%]C;VYT96YT5'EP95!A<F%M971E<G,@/2!A<G)A>2@I
M.PH*("`@("\J*@H@("`@("H@5&AE('-U8G!A<G1S(&]F('1H:7,@<&%R="X*
M("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A
M<G1S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($EN9F]R;6%T:6]N+U-T
M871I<W1I8W,@;VX@=&AE('-U8G!A<G0N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]I;F9O<FUA=&EO;B`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`@*B!4:&4@;&ES="!O9B!#241S(&9O<B!T:&ES('!A
M<G0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)%]C:61S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!-24U%($E$
M(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)%]M:6UE:60@/2!N=6QL.PH*("`@("\J*@H@("`@("H@
M5&AE('-E<75E;F-E('1O('5S92!A<R!%3TP@9F]R('1H:7,@<&%R="X*("`@
M("`J(%1H92!D969A=6QT(&ES(&-U<G)E;G1L>2!T;R!O=71P=70@=&AE($5/
M3"!S97%U96YC92!I;G1E<FYA;&QY(&%S"B`@("`@*B!J=7-T(")<;B(@:6YS
M=&5A9"!O9B!T:&4@8V%N;VYI8V%L(")<<EQN(B!R97%U:7)E9"!I;B!21D,@
M.#(R("8@,C`T-2X*("`@("`J(%1O(&)E(%)&0R!C;VUP;&%I;G0L('1H92!F
M=6QL(#Q#4CX\3$8^($5/3"!C;VUB:6YA=&EO;B!S:&]U;&0@8F4@=7-E9`H@
M("`@("H@=VAE;B!S96YD:6YG(&$@;65S<V%G92X*("`@("`J($ET(&ES(&YO
M="!C<G5C:6%L(&AE<F4@<VEN8V4@=&AE(%!(4"]014%2(&UA:6QI;F<@9G5N
M8W1I;VYS('=I;&P@:&%N9&QE"B`@("`@*B!T:&4@14],(&1E=&%I;',N"B`@
M("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?96]L
M(#T@34E-15]005)47T5/3#L*"B`@("`O*BH*("`@("`J($EN=&5R;F%L(&-L
M87-S(&9L86=S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1?9FQA9W,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@4&%R
M="`M/B!)1"!M87!P:6YG(&-A8VAE+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?:61M87`@/2!A<G)A>2@I.PH*("`@("\J
M*@H@("`@("H@56YI<75E($U)345?4&%R="!B;W5N9&%R>2!S=')I;F<N"B`@
M("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8F]U
M;F1A<GD@/2!N=6QL.PH*("`@("\J*@H@("`@("H@1&5F875L="!V86QU92!F
M;W(@=&AI<R!087)T)W,@<VEZ92X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G
M97(*("`@("`J+PH@("`@=F%R("1?8GET97,@/2`P.PH*("`@("\J*@H@("`@
M("H@5&AE(&-O;G1E;G0M240@9F]R('1H:7,@<&%R="X*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]C;VYT96YT:60@/2!N
M=6QL.PH*("`@("\J*@H@("`@("H@34E-15]087)T(&-O;G-T<G5C=&]R+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UI;65T>7!E("`@("!4:&4@
M8V]N=&5N="!T>7!E(&]F('1H92!P87)T+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D8V]N=&5N=',@("`@(%1H92!B;V1Y(&]F('1H92!P87)T+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8VAA<G-E="`@("`@(%1H92!C:&%R86-T97(@<V5T
M(&]F('1H92!P87)T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&ES<&]S:71I
M;VX@(%1H92!C;VYT96YT(&1I<W!O<VET:6]N(&]F('1H92!P87)T+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D96YC;V1I;F<@("`@(%1H92!C;VYT96YT(&5N
M8V]D:6YG(&]F('1H92!C;VYT96YT<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M34E-15]087)T*"1M:6UE='EP92`](&YU;&PL("1C;VYT96YT<R`](&YU;&PL
M"B`@("`@("`@("`@("`@("`@("`@("`@)&-H87)S970@/2!-24U%7T1%1D%5
M3%1?0TA!4E-%5"P@)&1I<W!O<VET:6]N(#T@;G5L;"P*("`@("`@("`@("`@
M("`@("`@("`@("`D96YC;V1I;F<@/2!N=6QL*0H@("`@>PH@("`@("`@("\J
M($-R96%T92!T:&4@=6YI<75E($U)345?4&%R="!B;W5N9&%R>2!S=')I;F<N
M("HO"B`@("`@("`@)'1H:7,M/E]G96YE<F%T94)O=6YD87)Y*"D["@H@("`@
M("`@("\J(%1H92!C:&%R86-T97(@<V5T('-H;W5L9"!A;'=A>7,@8F4@<V5T
M+"!E=F5N(&EF('=E(&%R92!D96%L:6YG"B`@("`@("`@("H@=VET:"!#;VYT
M96YT+51Y<&5S(&]T:&5R('1H86X@=&5X="\J+B`J+PH@("`@("`@("1T:&ES
M+3YS971#:&%R<V5T*"1C:&%R<V5T*3L*"B`@("`@("`@:68@*"%I<U]N=6QL
M*"1M:6UE='EP92DI('L*("`@("`@("`@("`@)'1H:7,M/G-E=%1Y<&4H)&UI
M;65T>7!E*3L*("`@("`@("!]"B`@("`@("`@:68@*"%I<U]N=6QL*"1C;VYT
M96YT<RDI('L*("`@("`@("`@("`@)'1H:7,M/G-E=$-O;G1E;G1S*"1C;VYT
M96YT<RP@)&5N8V]D:6YG*3L*("`@("`@("!]"B`@("`@("`@:68@*"%I<U]N
M=6QL*"1D:7-P;W-I=&EO;BDI('L*("`@("`@("`@("`@)'1H:7,M/G-E=$1I
M<W!O<VET:6]N*"1D:7-P;W-I=&EO;BD["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T('1H92!C;VYT96YT+61I<W!O<VET:6]N(&]F('1H
M:7,@<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D:7-P;W-I
M=&EO;B`@5&AE(&-O;G1E;G0M9&ES<&]S:71I;VX@=&\@<V5T("AI;FQI;F4@
M;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A='1A8VAM
M96YT*2X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1&ES<&]S:71I;VXH)&1I
M<W!O<VET:6]N*0H@("`@>PH@("`@("`@("1D:7-P;W-I=&EO;B`](%-T<FEN
M9SHZ;&]W97(H)&1I<W!O<VET:6]N*3L*"B`@("`@("`@:68@*"@D9&ES<&]S
M:71I;VX@/3T@)VEN;&EN92<I('Q\("@D9&ES<&]S:71I;VX@/3T@)V%T=&%C
M:&UE;G0G*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V1I<W!O<VET:6]N(#T@
M)&1I<W!O<VET:6]N.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($=E="!T:&4@8V]N=&5N="UD:7-P;W-I=&EO;B!O9B!T:&ES('!A<G0N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!P87)T)W,@8V]N=&5N
M="UD:7-P;W-I=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&ES<&]S
M:71I;VXH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1I<W!O<VET
M:6]N.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!N86UE(&]F('1H
M:7,@<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE(%1H
M92!N86UE('1O('-E="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T3F%M92@D
M;F%M92D*("`@('L*("`@("`@("`D=&AI<RT^<V5T0V]N=&5N=%1Y<&5087)A
M;65T97(H)VYA;64G+"`D;F%M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M970@=&AE(&YA;64@;V8@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!P87)A
M;2!B;V]L96%N("1D96-O9&4@("!-24U%(&1E8V]D92!D97-C<FEP=&EO;C\*
M("`@("`J($!P87)A;2!B;V]L96%N("1D969A=6QT("!)9B!T:&4@;F%M92!P
M87)A;65T97(@9&]E<VXG="!E>&ES="P@<VAO=6QD('=E"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@=7-E('1H92!D969A=6QT(&YA;64@9G)O
M;2!T:&4@9&5S8W)I<'1I;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("!P87)A;65T97(_"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!N86UE(&]F('1H92!P87)T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971.86UE*"1D96-O9&4@/2!F86QS92P@)&1E9F%U;'0@/2!F86QS92D*("`@
M('L*("`@("`@("`D;F%M92`]("1T:&ES+3YG971#;VYT96YT5'EP95!A<F%M
M971E<B@G;F%M92<I.PH*("`@("`@("!I9B`H)&1E9F%U;'0@)B8@96UP='DH
M)&YA;64I*2!["B`@("`@("`@("`@("1N86UE(#T@<')E9U]R97!L86-E*"=\
M7%=\)RP@)U\G+"`D=&AI<RT^9V5T1&5S8W)I<'1I;VXH9F%L<V4L('1R=64I
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D9&5C;V1E*2!["B`@("`@("`@
M("`@(')E='5R;B!T<FEM*$U)344Z.F1E8V]D92@D;F%M92DI.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D;F%M93L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&)O9'D@8V]N=&5N=',@
M;V8@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-O
M;G1E;G1S("!4:&4@<&%R="!B;V1Y+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M96YC;V1I;F<@(%1H92!C=7)R96YT(&5N8V]D:6YG(&]F('1H92!C;VYT96YT
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T0V]N=&5N=',H)&-O;G1E;G1S
M+"`D96YC;V1I;F<@/2!N=6QL*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8V]N
M=&5N=',@/2`D8V]N=&5N=',["B`@("`@("`@)'1H:7,M/E]F;&%G<ULG8V]N
M=&5N='-3970G72`]('1R=64["B`@("`@("`@)'1H:7,M/E]C=7)R96YT16YC
M;V1I;F<@/2`H:7-?;G5L;"@D96YC;V1I;F<I*2`_("1T:&ES+3YG971#=7)R
M96YT16YC;V1I;F<H*2`Z($U)344Z.F5N8V]D:6YG*"1E;F-O9&EN9RP@34E-
M15]35%))3D<I.PH@("`@?0H*("`@("\J*@H@("`@("H@061D('1O('1H92!B
M;V1Y(&-O;G1E;G1S(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1C;VYT96YT<R`@5&AE(&-O;G1E;G1S('1O(&%P<&5N9"!T
M;R!T:&4@8W5R<F5N="!P87)T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@8F]D>2X*("`@("`J($!P87)A;2!S=')I;F<@)&5N8V]D:6YG("!4
M:&4@8W5R<F5N="!E;F-O9&EN9R!O9B!T:&4@8V]N=&5N=',N($EF(&YO=`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('-P96-I9FEE9"P@=VEL
M;"!T<GD@=&\@875T;R!D971E<FUI;F4@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@96YC;V1I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%P<&5N9$-O;G1E;G1S*"1C;VYT96YT<RP@)&5N8V]D:6YG(#T@;G5L;"D*
M("`@('L*("`@("`@("`D=&AI<RT^<V5T0V]N=&5N=',H)'1H:7,M/E]C;VYT
M96YT<R`N("1C;VYT96YT<RP@)&5N8V]D:6YG*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($-L96%R<R!T:&4@8F]D>2!C;VYT96YT<R!O9B!T:&ES('!A<G0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L96%R0V]N=&5N=',H*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?8V]N=&5N=',@/2`G)SL*("`@("`@("`D=&AI<RT^
M7V9L86=S6R=C;VYT96YT<U-E="==(#T@9F%L<V4["B`@("`@("`@)'1H:7,M
M/E]C=7)R96YT16YC;V1I;F<@/2!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N('1H92!B;V1Y(&]F('1H92!P87)T+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@<F%W(&)O9'D@;V8@=&AE('!A<G0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$-O;G1E;G1S*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]C;VYT96YT<SL*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE(&-O;G1E;G1S(&EN('-T<FEC="!21D,@.#(R("8@
M,C`T-2!O=71P=70@+2!N86UE;'DL(&%L;`H@("`@("H@;F5W;&EN97,@96YD
M('=I=&@@=&AE(&-A;F]N:6-A;"`\0U(^/$Q&/B!S97%U96YC92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&5N=&ER92!-24U%('!A<G0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-A;F]N:6-A;$-O;G1E;G1S*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G)E<&QA8V5%3TPH)'1H:7,M
M/E]C;VYT96YT<RP@34E-15]005)47U)&0U]%3TPI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@5')A;G-F97(@96YC;V1E('1H92!C;VYT96YT<R`H=&\@=&AE
M('1R86YS9F5R(&5N8V]D:6YG(&ED96YT:69I960@=FEA"B`@("`@*B!G9714
M<F%N<V9E<D5N8V]D:6YG*"DI(&%N9"!S970@87,@=&AE('!A<G0G<R!N97<@
M8V]N=&5N=',N"B`@("`@*B\*("`@(&9U;F-T:6]N('1R86YS9F5R16YC;V1E
M0V]N=&5N=',H*0H@("`@>PH@("`@("`@("1C;VYT96YT<R`]("1T:&ES+3YT
M<F%N<V9E<D5N8V]D92@I.PH@("`@("`@("1T:&ES+3Y?8W5R<F5N=$5N8V]D
M:6YG(#T@)'1H:7,M/E]F;&%G<ULG;&%S=%1R86YS9F5R16YC;V1E)UT["B`@
M("`@("`@)'1H:7,M/G-E=$-O;G1E;G1S*"1C;VYT96YT<RP@)'1H:7,M/E]C
M=7)R96YT16YC;V1I;F<I.PH@("`@("`@("1T:&ES+3YS9714<F%N<V9E<D5N
M8V]D:6YG*"1T:&ES+3Y?8W5R<F5N=$5N8V]D:6YG*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%1R86YS9F5R(&1E8V]D92!T:&4@8V]N=&5N=',@86YD('-E
M="!T:&5M(&%S('1H92!N97<@8V]N=&5N=',N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('1R86YS9F5R1&5C;V1E0V]N=&5N=',H*0H@("`@>PH@("`@("`@("1C
M;VYT96YT<R`]("1T:&ES+3YT<F%N<V9E<D1E8V]D92@I.PH@("`@("`@("1T
M:&ES+3Y?8W5R<F5N=$5N8V]D:6YG(#T@)'1H:7,M/E]F;&%G<ULG;&%S=%1R
M86YS9F5R1&5C;V1E)UT["B`@("`@("`@)'1H:7,M/G-E=%1R86YS9F5R16YC
M;V1I;F<H)'1H:7,M/E]C=7)R96YT16YC;V1I;F<I.PH*("`@("`@("`O*B!$
M;VXG="!S970@8V]N=&5N=',@:68@=&AE>2!A<F4@96UP='DL(&)E8V%U<V4@
M=&AI<R!W:6QL(&1O('-T=69F"B`@("`@("`@("`@;&EK92!R97-E="!T:&4@
M:6YT97)N86P@8GET97,@9FEE;&0L(&5V96X@=&AO=6=H('=E('-H;W5L9&XG
M="!D;PH@("`@("`@("`@('1H870@*'1H92!U<V5R(&AA<R!T:&5I<B!R96%S
M;VYS('1O('-E="!T:&4@8GET97,@9FEE;&0@=&\@80H@("`@("`@("`@(&YO
M;BUZ97)O('9A;'5E('=I=&AO=70@<'5T=&EN9R!T:&4@8V]N=&5N=',@:6YT
M;R!T:&ES('!A<G0N("HO"B`@("`@("`@:68@*'-T<FQE;B@D8V]N=&5N=',I
M*2!["B`@("`@("`@("`@("1T:&ES+3YS971#;VYT96YT<R@D8V]N=&5N=',L
M("1T:&ES+3Y?8W5R<F5N=$5N8V]D:6YG*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!3970@=&AE(&UI;65T>7!E(&]F('1H:7,@<&%R="X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M:6UE='EP92`@5&AE(&UI
M;65T>7!E('1O('-E="`H97@N.B!T97AT+W!L86EN*2X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T5'EP92@D;6EM971Y<&4I"B`@("!["B`@("`@("`@+RH@
M4D9#(#(P-#4Z($%N>2!E;G1I='D@=VET:"!U;G)E8V]G;FEZ960@96YC;V1I
M;F<@;75S="!B92!T<F5A=&5D"B`@("`@("`@("`@87,@:68@:70@:&%S(&$@
M0V]N=&5N="U4>7!E(&]F(")A<'!L:6-A=&EO;B]O8W1E="US=')E86TB"B`@
M("`@("`@("`@<F5G87)D;&5S<R!O9B!W:&%T('1H92!#;VYT96YT+51Y<&4@
M9FEE;&0@86-T=6%L;'D@<V%Y<RX@*B\*("`@("`@("!I9B`H)'1H:7,M/E]T
M<F%N<V9E<D5N8V]D:6YG(#T]("=X+75N:VYO=VXG*2!["B`@("`@("`@("`@
M(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("\J(%-E="!T:&4@)W-E=%1Y
M<&4G(&9L86<N("HO"B`@("`@("`@)'1H:7,M/E]F;&%G<ULG<V5T5'EP92==
M(#T@=')U93L*"B`@("`@("`@;&ES="@D=&AI<RT^7W1Y<&4L("1T:&ES+3Y?
M<W5B='EP92D@/2!E>'!L;V1E*"<O)RP@4W1R:6YG.CIL;W=E<B@D;6EM971Y
M<&4I*3L*("`@("`@("!I9B`H*"1T>7!E(#T@34E-13HZ='EP92@D=&AI<RT^
M7W1Y<&4L($U)345?4U1224Y'*2DI('L*("`@("`@("`@("`@)'1H:7,M/E]T
M>7!E(#T@)'1Y<&4["@H@("`@("`@("`@("`O*B!3970@=&AE(&)O=6YD87)Y
M('-T<FEN9R!F;W(@)VUU;'1I<&%R="\J)R!P87)T<RX@*B\*("`@("`@("`@
M("`@:68@*"1T>7!E(#T]("=M=6QT:7!A<G0G*2!["B`@("`@("`@("`@("`@
M("!I9B`H(21T:&ES+3YG971#;VYT96YT5'EP95!A<F%M971E<B@G8F]U;F1A
M<GDG*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971#;VYT96YT
M5'EP95!A<F%M971E<B@G8F]U;F1A<GDG+"`D=&AI<RT^7V=E;F5R871E0F]U
M;F1A<GDH*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D=&AI<RT^8VQE87)#;VYT96YT5'EP95!A
M<F%M971E<B@G8F]U;F1A<GDG*3L*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?='EP92`]("=X+75N:VYO=VXG
M.PH@("`@("`@("`@("`D=&AI<RT^8VQE87)#;VYT96YT5'EP95!A<F%M971E
M<B@G8F]U;F1A<GDG*3L*("`@("`@("!]"B`@("!]"@H@("`@("\J*@H@("`@
M("`J($=E="!T:&4@9G5L;"!-24U%($-O;G1E;G0M5'EP92!O9B!T:&ES('!A
M<G0N"B`@("`@("H*("`@("`@*B!`<&%R86T@8F]O;&5A;B`D8VAA<G-E="`@
M07!P96YD(&-H87)A8W1E<B!S970@:6YF;W)M871I;VX@=&\@=&AE(&5N9"!O
M9@H@("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@8V]N=&5N
M="!T>7!E(&EF('1H:7,@:7,@82!T97AT+RH@<&%R="X*("`@("`@*@H@("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@;6EM971Y<&4@;V8@=&AI<R!P87)T
M"B`@("`@("H@("`@("`@("`@("`@("`@("AE>"XZ('1E>'0O<&QA:6X[(&-H
M87)S970]=7,M87-C:6DI+@H@("`@("`J+PH@("`@(&9U;F-T:6]N(&=E=%1Y
M<&4H)&-H87)S970@/2!F86QS92D*("`@("!["B`@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]T>7!E*2!\?"`A:7-S970H)'1H:7,M/E]S=6)T>7!E*2D@
M>PH@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("!]"B`@("`@
M("`@("1P='EP92`]("1T:&ES+3YG9710<FEM87)Y5'EP92@I.PH@("`@("`@
M("`D='EP92`]("1P='EP92`N("<O)R`N("1T:&ES+3YG9713=6)4>7!E*"D[
M"B`@("`@("`@(&EF("@D8VAA<G-E="`F)B`H)'!T>7!E(#T]("=T97AT)RDI
M('L*("`@("`@("`@("`@("1T>7!E("X]("<[(&-H87)S970])R`N("1T:&ES
M+3YG971#:&%R<V5T*"D["B`@("`@("`@('T*("`@("`@("`@<F5T=7)N("1T
M>7!E.PH@("`@('T*"B`@("`O*BH*("`@("`J($EF('1H92!S=6)T>7!E(&]F
M(&$@34E-12!P87)T(&ES('5N<F5C;V=N:7IE9"!B>2!A;B!A<'!L:6-A=&EO
M;BP@=&AE"B`@("`@*B!D969A=6QT('1Y<&4@<VAO=6QD(&)E('5S960@:6YS
M=&5A9"`H4V5E(%)&0R`R,#0V*2X@(%1H:7,@;65T:&]D"B`@("`@*B!R971U
M<FYS('1H92!D969A=6QT('-U8G1Y<&4@9F]R(&$@<&%R=&EC=6QA<B!P<FEM
M87)Y($U)344@5'EP92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(&1E9F%U;'0@;6EM971Y<&4@;V8@=&AI<R!P87)T("AE>"XZ('1E>'0O
M<&QA:6XI+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$969A=6QT5'EP92@I
M"B`@("!["B`@("`@("`@<W=I=&-H("@D=&AI<RT^9V5T4')I;6%R>51Y<&4H
M*2D@>PH@("`@("`@(&-A<V4@)W1E>'0G.@H@("`@("`@("`@("`O*B!21D,@
M,C`T-B`H-"XQ+C0I.B!T97AT('!A<G1S(&1E9F%U;'0@=&\@=&5X="]P;&%I
M;BX@*B\*("`@("`@("`@("`@<F5T=7)N("=T97AT+W!L86EN)SL*"B`@("`@
M("`@8V%S92`G;75L=&EP87)T)SH*("`@("`@("`@("`@+RH@4D9#(#(P-#8@
M*#4N,2XS*3H@;75L=&EP87)T('!A<G1S(&1E9F%U;'0@=&\@;75L=&EP87)T
M+VUI>&5D+B`J+PH@("`@("`@("`@("!R971U<FX@)VUU;'1I<&%R="]M:7AE
M9"<["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("\J(%)&0R`R,#0V
M("@T+C(L(#0N,RP@-"XT+"`T+C4N,RP@-2XR+C0I.B!A;&P@;W1H97)S(&1E
M9F%U;'0@=&\*("`@("`@("`@("`@("`@87!P;&EC871I;VXO;V-T970M<W1R
M96%M+B`J+PH@("`@("`@("`@("!R971U<FX@)V%P<&QI8V%T:6]N+V]C=&5T
M+7-T<F5A;2<["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1V5T
M('1H92!P<FEM87)Y('1Y<&4@;V8@=&AI<R!P87)T+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@<')I;6%R>2!-24U%('1Y<&4@;V8@=&AI
M<R!P87)T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9710<FEM87)Y5'EP92@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?='EP93L*("`@('T*"B`@
M("`O*BH*("`@("`J($=E="!T:&4@<W5B='EP92!O9B!T:&ES('!A<G0N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!-24U%('-U8G1Y<&4@
M;V8@=&AI<R!P87)T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9713=6)4>7!E
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]S=6)T>7!E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4V5T('1H92!C:&%R86-T97(@<V5T(&]F('1H
M:7,@<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:&%R<V5T
M("!4:&4@8VAA<F%C=&5R('-E="!O9B!T:&ES('!A<G0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-E=$-H87)S970H)&-H87)S970I"B`@("!["B`@("`@("`@
M)'1H:7,M/G-E=$-O;G1E;G14>7!E4&%R86UE=&5R*"=C:&%R<V5T)RP@)&-H
M87)S970I.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H92!C:&%R86-T
M97(@<V5T('1O('5S92!F;W(@;V8@=&AI<R!P87)T+B`@4F5T=7)N<R!A(&-H
M87)S970@9F]R"B`@("`@*B!A;&P@='EP97,@*&YO="!J=7-T("=T97AT+RHG
M*2!S:6YC92!W92!U<V4@=&AI<R!C:&%R<V5T('1O(&1E=&5R;6EN90H@("`@
M("H@:&]W('1O(&5N8V]D92!T97AT(&EN($U)344@:&5A9&5R<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-H87)A8W1E<B!S970@;V8@
M=&AI<R!P87)T+B`@4F5T=7)N<R!N=6QL(&EF('1H97)E"B`@("`@*B`@("`@
M("`@("`@("`@("`@:7,@;F\@8VAA<F%C=&5R('-E="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T0VAA<G-E="@I"B`@("!["B`@("`@("`@)&-H87)S970@
M/2`D=&AI<RT^9V5T0V]N=&5N=%1Y<&5087)A;65T97(H)V-H87)S970G*3L*
M("`@("`@("!R971U<FX@*&5M<'1Y*"1C:&%R<V5T*2D@/R!N=6QL(#H@)&-H
M87)S970["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&1E<V-R:7!T
M:6]N(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1D97-C<FEP=&EO;B`@5&AE(&1E<V-R:7!T:6]N(&]F('1H:7,@<&%R="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1&5S8W)I<'1I;VXH)&1E<V-R:7!T
M:6]N*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9&5S8W)I<'1I;VX@/2!-24U%
M.CIE;F-O9&4H)&1E<V-R:7!T:6]N+"`D=&AI<RT^9V5T0VAA<G-E="@I*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@9&5S8W)I<'1I;VX@;V8@
M=&AI<R!P87)T+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1D96-O
M9&4@("!-24U%(&1E8V]D92!D97-C<FEP=&EO;C\*("`@("`J($!P87)A;2!B
M;V]L96%N("1D969A=6QT("!)9B!T:&4@;F%M92!P87)A;65T97(@9&]E<VXG
M="!E>&ES="P@<VAO=6QD('=E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@=7-E('1H92!D969A=6QT(&YA;64@9G)O;2!T:&4@9&5S8W)I<'1I
M;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!P87)A;65T97(_
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D97-C<FEP=&EO
M;B!O9B!T:&ES('!A<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1E<V-R
M:7!T:6]N*"1D96-O9&4@/2!F86QS92P@)&1E9F%U;'0@/2!F86QS92D*("`@
M('L*("`@("`@("`D9&5S8R`]("1T:&ES+3Y?9&5S8W)I<'1I;VX["@H@("`@
M("`@(&EF("@D9&5F875L="`F)B!E;7!T>2@D9&5S8RDI('L*("`@("`@("`@
M("`@)&1E<V,@/2`D=&AI<RT^9V5T3F%M92@I.PH@("`@("`@("`@("!I9B`H
M96UP='DH)&1E<V,I*2!["B`@("`@("`@("`@("`@("`D9&5S8R`]($U)345?
M1$5&055,5%]$15-#4DE05$E/3CL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@:68@*"1D96-O9&4I('L*("`@("`@("`@("`@<F5T=7)N($U)
M344Z.F1E8V]D92@D9&5S8RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N("1D97-C.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E="!T:&4@=')A;G-F97(@96YC;V1I;F<@=&\@=7-E(&9O<B!T:&ES
M('!A<G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D96YC;V1I;F<@
M(%1H92!T<F%N<V9E<B!E;F-O9&EN9R!T;R!U<V4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E=%1R86YS9F5R16YC;V1I;F<H)&5N8V]D:6YG*0H@("`@>PH@
M("`@("`@(&EF("@H)&UI;65?96YC;V1I;F<@/2!-24U%.CIE;F-O9&EN9R@D
M96YC;V1I;F<L($U)345?4U1224Y'*2DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]T<F%N<V9E<D5N8V]D:6YG(#T@)&UI;65?96YC;V1I;F<["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@+RH@4D9#(#(P-#4Z($%N>2!E;G1I='D@
M=VET:"!U;G)E8V]G;FEZ960@96YC;V1I;F<@;75S="!B92!T<F5A=&5D"B`@
M("`@("`@("`@("`@(&%S(&EF(&ET(&AA<R!A($-O;G1E;G0M5'EP92!O9B`B
M87!P;&EC871I;VXO;V-T970M<W1R96%M(@H@("`@("`@("`@("`@("!R96=A
M<F1L97-S(&]F('=H870@=&AE($-O;G1E;G0M5'EP92!F:65L9"!A8W1U86QL
M>2!S87ES+B`J+PH@("`@("`@("`@("`D=&AI<RT^<V5T5'EP92@G87!P;&EC
M871I;VXO;V-T970M<W1R96%M)RD["B`@("`@("`@("`@("1T:&ES+3Y?=')A
M;G-F97)%;F-O9&EN9R`]("=X+75N:VYO=VXG.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($%D9"!A($U)344@<W5B<&%R="X*("`@("`J"B`@
M("`@*B!`<&%R86T@34E-15]087)T("1M:6UE7W!A<G0@($%D9"!A($U)345?
M4&%R="!S=6)P87)T('1O('1H92!C=7)R96YT"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@($U)345?4&%R="X*("`@("`J($!P87)A;2!S
M=')I;F<@)&EN9&5X("`@("`@("`@5&AE(&EN9&5X(&]F('1H92!A9&1E9"!-
M24U%7U!A<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9%!A<G0H)&UI;65?
M<&%R="P@)&EN9&5X(#T@;G5L;"D*("`@('L*("`@("`@("`O*B!!9&0@=&AE
M('!A<G0@=&\@=&AE('!A<G1S(&QI<W0N("HO"B`@("`@("`@:68@*&ES7VYU
M;&PH)&EN9&5X*2D@>PH@("`@("`@("`@("!E;F0H)'1H:7,M/E]P87)T<RD[
M"B`@("`@("`@("`@("1I9"`](&ME>2@D=&AI<RT^7W!A<G1S*2`K(#$["B`@
M("`@("`@("`@("1P='(@/2`F)'1H:7,M/E]P87)T<SL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D<'1R(#T@)B1T:&ES+3Y?<&%R=$9I;F0H)&EN
M9&5X+"`D=&AI<RT^7W!A<G1S+"!T<G5E*3L*("`@("`@("`@("`@:68@*"@D
M<&]S(#T@<W1R<G!O<R@D:6YD97@L("<N)RDI*2!["B`@("`@("`@("`@("`@
M("`D:60@/2!S=6)S='(H)&EN9&5X+"`D<&]S("L@,2D["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D:60@/2`D:6YD97@["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%-E="!T:&4@34E-12!)
M1"!I9B!I="!H87,@;F]T(&%L<F5A9'D@8F5E;B!S970N("HO"B`@("`@("`@
M:68@*"1M:6UE7W!A<G0M/F=E=$U)345)9"@I(#T]/2!N=6QL*2!["B`@("`@
M("`@("`@("1M:6UE7W!A<G0M/G-E=$U)345)9"@D:60I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@4W1O<F4@=&AE('!A<G0@;F]W+B`J+PH@("`@("`@("1P
M=');)&ED72`]("1M:6UE7W!A<G0["@H@("`@("`@("\J($-L96%R('1H92!)
M1"`M/B!087)T(&UA<'!I;F<@8V%C:&4N("HO"B`@("`@("`@)'1H:7,M/E]I
M9&UA<"`](&%R<F%Y*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L
M:7-T(&]F(&%L;"!-24U%('-U8G!A<G1S+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@($%N(&%R<F%Y(&]F('1H92!-24U%7U!A<G0@<W5B<&%R=',N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<G1S*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]P87)T<SL*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E=')I979E(&$@<W!E8VEF:6,@34E-12!P87)T+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&ED("!4:&4@34E-15]087)T($E$('-T<FEN9RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N($U)345?4&%R="`@5&AE($U)345?4&%R
M="!R97%U97-T960L(&]R(&9A;'-E(&EF('1H92!P87)T"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@9&]E<VXG="!E>&ES="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4&%R="@D:60I"B`@("!["B`@("`@("`@)&UI;65I9"`]("1T
M:&ES+3YG971-24U%260H*3L*"B`@("`@("`@+RH@5&AI<R!W:6QL(&-O;G9E
M<G0@)R,N,"<@=&\@<VEM<&QY("<C)RP@=VAI8V@@:7,@:&]W('1H92!P87)T
M(&ES"B`@("`@("`@("H@:6YT97)N86QL>2!S=&]R960N("HO"B`@("`@("`@
M)'-E87)C:%]I9"`]("1I9#L*("`@("`@("!I9B`H*"1S='(@/2!S=')R8VAR
M*"1I9"P@)RXG*2D@)B8*("`@("`@("`@("`@*"1S='(@/3T@)RXP)RDI('L*
M("`@("`@("`@("`@)'-E87)C:%]I9"`]('-U8G-T<B@D<V5A<F-H7VED+"`P
M+"`M,BD["B`@("`@("`@?0H*("`@("`@("`O*B!2971U<FX@=&AI<R!P87)T
M(&EF.@H@("`@("`@("`@(#$I(%1H97)E(&ES(&]N;'D@;VYE('!A<G0@*&4N
M9RX@=&AE($U)344@240@:7,@,"P@;W(@=&AE"B`@("`@("`@("`@("`@34E-
M12!)1"!I<R`Q(&%N9"!T:&5R92!A<F4@;F\@<W5B<&%R=',N"B`@("`@("`@
M("`@,BD@)&ED(&UA=&-H97,@=&AI<R!P87)T<R!-24U%($E$+B`J+PH@("`@
M("`@(&EF("@H)'-E87)C:%]I9"`]/2`P*2!\?`H@("`@("`@("`@("`H*"1S
M96%R8VA?:60@/3T@,2D@)B8@(6-O=6YT*"1T:&ES+3Y?<&%R=',I*2!\?`H@
M("`@("`@("`@("`H(65M<'1Y*"1M:6UE:60I("8F("@D<V5A<F-H7VED(#T]
M("1M:6UE:60I*2D@>PH@("`@("`@("`@("`D<&%R="`]("1T:&ES.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1P87)T(#T@)'1H:7,M/E]P87)T
M1FEN9"@D:60L("1T:&ES+3Y?<&%R=',I.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"1P87)T("8F"B`@("`@("`@("`@("@D<V5A<F-H7VED("$]("1I9"D@
M)B8*("`@("`@("`@("`@*"1P87)T+3YG9714>7!E*"D@/3T@)VUE<W-A9V4O
M<F9C.#(R)RDI('L*("`@("`@("`@("`@)')E=%]P87)T(#T@571I;#HZ8VQO
M;F5/8FIE8W0H)'!A<G0I.PH@("`@("`@("`@("`D<F5T7W!A<G0M/E]P87)T
M<R`](&%R<F%Y*"D["B`@("`@("`@("`@(')E='5R;B`D<F5T7W!A<G0["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)'!A<G0["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!296UO=F4@82!-24U%7U!A<G0@<W5B<&%R="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE($U)344@4&%R="!T;R!D96QE
M=&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V95!A<G0H)&ED*0H@("`@
M>PH@("`@("`@(&EF("@H)'!T<B`]("8D=&AI<RT^7W!A<G1&:6YD*"1I9"P@
M)'1H:7,M/E]P87)T<RDI*2!["B`@("`@("`@("`@('5N<V5T*"1P='(I.PH@
M("`@("`@("`@("`D=&AI<RT^7VED;6%P(#T@87)R87DH*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!;'1E<B!A(&-U<G)E;G0@34E-12!S
M=6)P87)T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("`@("`@
M("`@("`@5&AE($U)344@4&%R="!)1"!T;R!A;'1E<BX*("`@("`J($!P87)A
M;2!-24U%7U!A<G0@)&UI;65?<&%R="`@5&AE($U)344@4&%R="!T;R!S=&]R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@86QT97)087)T*"1I9"P@)&UI;65?
M<&%R="D*("`@('L*("`@("`@("!I9B`H*"1P='(@/2`F)'1H:7,M/E]P87)T
M1FEN9"@D:60L("1T:&ES+3Y?<&%R=',I*2D@>PH@("`@("`@("`@("`D<'1R
M(#T@)&UI;65?<&%R=#L*("`@("`@("`@("`@)'1H:7,M/E]I9&UA<"`](&%R
M<F%Y*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1G5N8W1I
M;VX@=7-E9"!T;R!F:6YD(&$@<W!E8VEF:6,@34E-12!087)T(&)Y($E$+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&ED("`@("`@("`@5&AE($U)345?4&%R="!)1"!S=')I
M;F<N"B`@("`@*B!`<&%R86T@87)R87D@)B1P87)T<R`@("`@($$@;&ES="!O
M9B!-24U%7U!A<G0@;V)J96-T<RX*("`@("`J($!P87)A;2!B;V]L96%N("1R
M971A<G)A>2`@4F5T=7)N(&$@<&]I;G1E<B!T;R!T:&4@87)R87D@=&AA="!S
M=&]R97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@*'=O=6QD
M('-T;W)E*2!T:&4@<&%R="!R871H97(@=&AA;B!T:&4@<&%R=`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I='-E;&8_"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9?<&%R=$9I;F0H)&ED+"`F)'!A<G1S+"`D<F5T87)R87D@
M/2!F86QS92D*("`@('L*("`@("`@("`O*B!0;VEN=&5R<R!D;VXG="!P97)S
M:7-T('1H<F]U9V@@<V5S<VEO;G,[('1H97)E9F]R92P@=V4@;75S="!M86ME
M"B`@("`@("`@("H@<W5R92!T:&%T('1H92!)9$UA<"!I<R!D97-T<F]Y960@
M870@=&AE(&5N9"!O9B!E86-H(')E<75E<W0N"B`@("`@("`@("H@2&]W(&-A
M;B!W92!D;R!T:&ES/R!792!C:&5C:R!T;R!S964@:68@)%]I9&UA<"!C;VYT
M86EN<R!A;B!A<G)A>0H@("`@("`@("`J(&]F($U)345?4&%R=',@;W(@86X@
M87)R87D@;V8@87)R87ES+B`J+PH@("`@("`@("1C:&5C:R`](')E<V5T*"1T
M:&ES+3Y?:61M87`I.PH@("`@("`@(&EF("AE;7!T>2@D8VAE8VLI('Q\("%I
M<U]A*"1C:&5C:RP@)TU)345?4&%R="<I*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?:61M87`@/2!A<G)A>2@I.PH@("`@("`@("`@("`D=&AI<RT^7V=E;F5R
M871E261-87`H)'1H:7,M/E]P87)T<RD["B`@("`@("`@?0H*("`@("`@("!I
M9B`H)')E=&%R<F%Y*2!["B`@("`@("`@("`@(&EF("@D<&]S(#T@<W1R<G!O
M<R@D:60L("<N)RDI('L*("`@("`@("`@("`@("`@("1I9"`]('-U8G-T<B@D
M:60L(#`L("1P;W,I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1P87)T<SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?:61M87!;)&ED72DI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:61M87!;)&ED73L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D<&%R="`](&9A;'-E.PH@("`@("`@("`@
M("!R971U<FX@)'!A<G0["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@1V5N97)A=&5S(&$@;6%P<&EN9R!O9B!-24U%7U!A<G1S('=I=&@@=&AE
M:7(@34E-12!)1',N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D<&%R=',@($%N(&%R<F%Y(&]F
M($U)345?4&%R=',@=&\@;6%P+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5N
M97)A=&5)9$UA<"@F)'!A<G1S*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH
M)'!A<G1S*2D@>PH@("`@("`@("`@("!F;W)E86-H("AA<G)A>5]K97ES*"1P
M87)T<RD@87,@)&ME>2D@>PH@("`@("`@("`@("`@("`@)'!T<B`]("8D<&%R
M='-;)&ME>5T["B`@("`@("`@("`@("`@("`D=&AI<RT^7VED;6%P6R1P='(M
M/F=E=$U)345)9"@I72`]("8D<'1R.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]G96YE<F%T94ED36%P*"1P='(M/E]P87)T<RD["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@:6YF;W)M871I
M;VX@86)O=70@=&AE($U)345?4&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1L86)E;"`@5&AE(&EN9F]R;6%T:6]N(&QA8F5L+@H@("`@("H@
M0'!A<F%M(&UI>&5D("1D871A("`@(%1H92!I;F9O<FUA=&EO;B!T;R!S=&]R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T26YF;W)M871I;VXH)&QA8F5L
M+"`D9&%T82D*("`@('L*("`@("`@("`D=&AI<RT^7VEN9F]R;6%T:6]N6R1L
M86)E;%T@/2`D9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E
M(&EN9F]R;6%T:6]N(&%B;W5T('1H92!-24U%7U!A<G0N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;&%B96P@(%1H92!I;F9O<FUA=&EO;B!L86)E
M;"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@:6YF;W)M871I
M;VX@<F5Q=65S=&5D+@H@("`@("H@("`@("`@("`@("`@("`@4F5T=7)N<R!F
M86QS92!I9B`D;&%B96P@:7,@;F]T('-E="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T26YF;W)M871I;VXH)&QA8F5L*0H@("`@>PH@("`@("`@(')E='5R
M;B`H:7-S970H)'1H:7,M/E]I;F9O<FUA=&EO;ELD;&%B96Q=*2D@/R`D=&AI
M<RT^7VEN9F]R;6%T:6]N6R1L86)E;%T@.B!F86QS93L*("`@('T*"B`@("`O
M*BH*("`@("`J($%D9"!A(&1I<W!O<VET:6]N('!A<F%M971E<B!T;R!T:&ES
M('!A<G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&%B96P@(%1H
M92!D:7-P;W-I=&EO;B!P87)A;65T97(@;&%B96PN"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1D871A("`@5&AE(&1I<W!O<VET:6]N('!A<F%M971E<B!D871A
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971$:7-P;W-I=&EO;E!A<F%M971E
M<B@D;&%B96PL("1D871A*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9&ES<&]S
M:71I;VY087)A;65T97)S6R1L86)E;%T@/2`D9&%T83L*("`@('T*"B`@("`O
M*BH*("`@("`J($=E="!A(&1I<W!O<VET:6]N('!A<F%M971E<B!F<F]M('1H
M:7,@<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1L86)E;"`@
M5&AE(&1I<W!O<VET:6]N('!A<F%M971E<B!L86)E;"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(&1A=&$@<F5Q=65S=&5D+@H@("`@("H@
M("`@("`@("`@("`@("`@(%)E='5R;G,@9F%L<V4@:68@)&QA8F5L(&ES(&YO
M="!S970N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1I<W!O<VET:6]N4&%R
M86UE=&5R*"1L86)E;"D*("`@('L*("`@("`@("!R971U<FX@*&ES<V5T*"1T
M:&ES+3Y?9&ES<&]S:71I;VY087)A;65T97)S6R1L86)E;%TI*2`_("1T:&ES
M+3Y?9&ES<&]S:71I;VY087)A;65T97)S6R1L86)E;%T@.B!F86QS93L*("`@
M('T*"B`@("`O*BH*("`@("`J($=E="!A;&P@<&%R86UE=&5R<R!F<F]M('1H
M92!#;VYT96YT+41I<W!O<VET:6]N(&AE861E<BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B!A;&P@=&AE('!A<F%M971E<G,*
M("`@("`J("`@("`@("`@("`@("`@(%)E='5R;G,@=&AE(&5M<'1Y(&%R<F%Y
M(&EF(&YO('!A<F%M971E<G,@<V5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971!;&Q$:7-P;W-I=&EO;E!A<F%M971E<G,H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7V1I<W!O<VET:6]N4&%R86UE=&5R<SL*("`@('T*"B`@
M("`O*BH*("`@("`J($%D9"!A(&-O;G1E;G0@='EP92!P87)A;65T97(@=&\@
M=&AI<R!P87)T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&QA8F5L
M("!4:&4@9&ES<&]S:71I;VX@<&%R86UE=&5R(&QA8F5L+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9&%T82`@(%1H92!D:7-P;W-I=&EO;B!P87)A;65T97(@
M9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T0V]N=&5N=%1Y<&5087)A
M;65T97(H)&QA8F5L+"`D9&%T82D*("`@('L*("`@("`@("`D=&AI<RT^7V-O
M;G1E;G14>7!E4&%R86UE=&5R<ULD;&%B96Q=(#T@)&1A=&$["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#;&5A<G,@82!C;VYT96YT('1Y<&4@<&%R86UE=&5R
M(&9R;VT@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&QA8F5L("!4:&4@9&ES<&]S:71I;VX@<&%R86UE=&5R(&QA8F5L+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9&%T82`@(%1H92!D:7-P;W-I=&EO;B!P87)A
M;65T97(@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@8VQE87)#;VYT96YT
M5'EP95!A<F%M971E<B@D;&%B96PI"B`@("!["B`@("`@("`@=6YS970H)'1H
M:7,M/E]C;VYT96YT5'EP95!A<F%M971E<G-;)&QA8F5L72D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!'970@82!C;VYT96YT('1Y<&4@<&%R86UE=&5R(&9R
M;VT@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&QA
M8F5L("!4:&4@8V]N=&5N="!T>7!E('!A<F%M971E<B!L86)E;"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&1A=&$@<F5Q=65S=&5D+@H@
M("`@("H@("`@("`@("`@("`@("`@(%)E='5R;G,@9F%L<V4@:68@)&QA8F5L
M(&ES(&YO="!S970N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-O;G1E;G14
M>7!E4&%R86UE=&5R*"1L86)E;"D*("`@('L*("`@("`@("!R971U<FX@*&ES
M<V5T*"1T:&ES+3Y?8V]N=&5N=%1Y<&5087)A;65T97)S6R1L86)E;%TI*2`_
M("1T:&ES+3Y?8V]N=&5N=%1Y<&5087)A;65T97)S6R1L86)E;%T@.B!F86QS
M93L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A;&P@<&%R86UE=&5R<R!F
M<F]M('1H92!#;VYT96YT+51Y<&4@:&5A9&5R+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@($%N(&%R<F%Y(&]F(&%L;"!T:&4@<&%R86UE=&5R<PH@
M("`@("H@("`@("`@("`@("`@("`@4F5T=7)N<R!T:&4@96UP='D@87)R87D@
M:68@;F\@<&%R86UE=&5R<R!S970N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$%L;$-O;G1E;G14>7!E4&%R86UE=&5R<R@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?8V]N=&5N=%1Y<&5087)A;65T97)S.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T<R!A(&YE=R!S=')I;F<@=&\@=7-E(&9O<B!%3TQS
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&5O;"`@5&AE('-T<FEN
M9R!T;R!U<V4@9F]R($5/3',N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$5/
M3"@D96]L*0H@("`@>PH@("`@("`@("1T:&ES+3Y?96]L(#T@)&5O;#L*("`@
M('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@<W1R:6YG('1O('5S92!F;W(@
M14],<RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('-T<FEN
M9R!T;R!U<V4@9F]R($5/3',N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$5/
M3"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?96]L.PH@("`@?0H*
M("`@("\J*@H@("`@("H@061D('1H92!A<'!R;W!R:6%T92!-24U%(&AE861E
M<G,@9F]R('1H:7,@<&%R="!T;R!A;B!E>&ES=&EN9R!A<G)A>2X*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)&AE861E<G,@($%N(&%R<F%Y(&]F(&%N
M>2!O=&AE<B!H96%D97)S(&9O<B!T:&4@<&%R="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!4:&4@:&5A9&5R<RP@=VET:"!T:&4@34E-12!H96%D
M97)S(&%D9&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!H96%D97(H)&AE861E
M<G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1E;VP@/2`D=&AI<RT^9V5T
M14],*"D["B`@("`@("`@)'!T>7!E(#T@)'1H:7,M/F=E=%!R:6UA<GE4>7!E
M*"D["B`@("`@("`@)'-T>7!E(#T@)'1H:7,M/F=E=%-U8E1Y<&4H*3L*"B`@
M("`@("`@+RH@1V5T('1H92!C:&%R86-T97(@<V5T(&9O<B!T:&ES('!A<G0N
M("HO"B`@("`@("`@)&-H87)S970@/2`D=&AI<RT^9V5T0VAA<G-E="@I.PH*
M("`@("`@("`O*B!'970@=&AE($-O;G1E;G0M5'EP92`M('1H:7,@:7,@04Q7
M05E3(')E<75I<F5D+B`J+PH@("`@("`@("1C='EP92`]("1T:&ES+3YG9714
M>7!E*'1R=64I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YG971!;&Q#;VYT
M96YT5'EP95!A<F%M971E<G,H*2!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@
M("`@("`@("`O*B!3:VEP('1H92!C:&%R<V5T(&ME>2!S:6YC92!T:&%T('=O
M=6QD(&AA=F4@86QR96%D>2!B965N"B`@("`@("`@("`@("`J(&%D9&5D('1O
M("1C='EP92!B>2!G9714>7!E*"DN("HO"B`@("`@("`@("`@(&EF("@D:V5Y
M(#T]("=C:&%R<V5T)RD@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&-T>7!E("X]("<[("<@+B`D:V5Y
M("X@)STB)R`N('-T<E]R97!L86-E*"<B)RP@)UPB)RP@34E-13HZ96YC;V1E
M*"1V86QU92P@)&-H87)S970I*2`N("<B)SL*("`@("`@("!]"B`@("`@("`@
M)&AE861E<G-;)T-O;G1E;G0M5'EP92==(#T@34E-13HZ=W)A<$AE861E<G,H
M)T-O;G1E;G0M5'EP92<L("1C='EP92P@)&5O;"D["@H@("`@("`@("\J($=E
M="!T:&4@9&5S8W)I<'1I;VXL(&EF(&%N>2X@*B\*("`@("`@("!I9B`H*"1D
M97-C<FEP(#T@)'1H:7,M/F=E=$1E<V-R:7!T:6]N*"DI*2!["B`@("`@("`@
M("`@("1H96%D97)S6R=#;VYT96YT+41E<V-R:7!T:6]N)UT@/2!-24U%.CIW
M<F%P2&5A9&5R<R@G0V]N=&5N="U$97-C<FEP=&EO;B<L($U)344Z.F5N8V]D
M92@D9&5S8W)I<"P@)&-H87)S970I+"`D96]L*3L*("`@("`@("!]"@H@("`@
M("`@("\J(%)&0R`R,#0U(%LT72`M(&UE<W-A9V4O<F9C.#(R(&%N9"!M97-S
M86=E+W!A<G1I86P@<F5Q=6ER92!T:&4*("`@("`@("`@("!-24U%+59E<G-I
M;VX@:&5A9&5R(&]N;'D@:68@=&AE>2!T:&5M<V5L=F5S(&-L86EM('1O(&)E
M($U)344*("`@("`@("`@("!C;VUP;&EA;G0N("HO"B`@("`@("`@:68@*"@D
M<'1Y<&4@/3T@)VUE<W-A9V4G*2`F)@H@("`@("`@("`@("`H*"1S='EP92`]
M/2`G<F9C.#(R)RD@?'P@*"1S='EP92`]/2`G<&%R=&EA;"<I*2`F)@H@("`@
M("`@("`@("`H<W1R<&]S*"1T:&ES+3Y?8V]N=&5N=',L("=-24U%+59E<G-I
M;VXZ(#$N,"<I("$]/2!F86QS92DI('L*("`@("`@("`@("`@)&AE861E<G-;
M)TU)344M5F5R<VEO;B==(#T@)S$N,"<["B`@("`@("`@?0H*("`@("`@("`O
M*B!M97-S86=E+RH@<&%R=',@<F5Q=6ER92!N;R!A9&1I=&EO;F%L(&AE861E
M<B!I;F9O<FUA=&EO;BX@*B\*("`@("`@("!I9B`H)'!T>7!E(#T]("=M97-S
M86=E)RD@>PH@("`@("`@("`@("!R971U<FX@)&AE861E<G,["B`@("`@("`@
M?0H*("`@("`@("`O*B!$;VXG="!S:&]W($-O;G1E;G0M1&ES<&]S:71I;VX@
M9F]R(&UU;'1I<&%R="!M97-S86=E<R!U;FQE<W,*("`@("`@("`@("!T:&5R
M92!I<R!A(&YA;64@<&%R86UE=&5R+B`J+PH@("`@("`@("1N86UE(#T@)'1H
M:7,M/F=E=$YA;64H*3L*("`@("`@("!I9B`H*"1P='EP92`A/2`G;75L=&EP
M87)T)RD@?'P@(65M<'1Y*"1N86UE*2D@>PH@("`@("`@("`@("`D9&ES<"`]
M("1T:&ES+3YG971$:7-P;W-I=&EO;B@I.PH*("`@("`@("`@("`@+RH@061D
M(&%N>2!D:7-P;W-I=&EO;B!P87)A;65T97(@:6YF;W)M871I;VXL(&EF(&%V
M86EL86)L92X@*B\*("`@("`@("`@("`@:68@*"%E;7!T>2@D;F%M92DI('L*
M("`@("`@("`@("`@("`@("1D:7-P("X]("<[("<@+B`G9FEL96YA;64](B<@
M+B!-24U%.CIE;F-O9&4H)&YA;64L("1C:&%R<V5T*2`N("<B)SL*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)&AE861E<G-;)T-O;G1E;G0M1&ES<&]S
M:71I;VXG72`]($U)344Z.G=R87!(96%D97)S*"=#;VYT96YT+41I<W!O<VET
M:6]N)RP@)&1I<W`L("1E;VPI.PH@("`@("`@('T*"B`@("`@("`@+RH@061D
M('1R86YS9F5R(&5N8V]D:6YG(&EN9F]R;6%T:6]N+B`J+PH@("`@("`@("1H
M96%D97)S6R=#;VYT96YT+51R86YS9F5R+45N8V]D:6YG)UT@/2`D=&AI<RT^
M9V5T5')A;G-F97)%;F-O9&EN9R@I.PH*("`@("`@("`O*B!!9&0@8V]N=&5N
M="!)1"!I;F9O<FUA=&EO;BX@*B\*("`@("`@("!I9B`H(6ES7VYU;&PH)'1H
M:7,M/E]C;VYT96YT:60I*2!["B`@("`@("`@("`@("1H96%D97)S6R=#;VYT
M96YT+4E$)UT@/2`D=&AI<RT^7V-O;G1E;G1I9#L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D:&5A9&5R<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!T:&4@96YT:7)E('!A<G0@:6X@34E-12!F;W)M870N($EN8VQU9&5S
M(&AE861E<G,@;VX@<F5Q=65S="X*("`@("`J"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D:&5A9&5R<R`@26YC;'5D92!T:&4@34E-12!H96%D97)S/PH@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@34E-12!S=')I;F<N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('1O4W1R:6YG*"1H96%D97)S(#T@=')U92D*
M("`@('L*("`@("`@("`D96]L(#T@)'1H:7,M/F=E=$5/3"@I.PH@("`@("`@
M("1P='EP92`]("1T:&ES+3YG9710<FEM87)Y5'EP92@I.PH*("`@("`@("!I
M9B`H)&AE861E<G,I('L*("`@("`@("`@("`@)'1E>'0@/2`G)SL*("`@("`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/FAE861E<B@I(&%S("1K97D@/3X@)'9A
M;"D@>PH@("`@("`@("`@("`@("`@)'1E>'0@+CT@)&ME>2`N("<Z("<@+B`D
M=F%L("X@)&5O;#L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&5X="`N
M/2`D96]L.PH@("`@("`@('T*"B`@("`@("`@+RH@06YY(&EN9F]R;6%T:6]N
M(&%B;W5T(&$@;65S<V%G92\J(&ES(&5M8F5D9&5D(&EN('1H92!M97-S86=E
M"B`@("`@("`@("`@8V]N=&5N=',@=&AE;7-E;&8N(%-I;7!L>2!O=71P=70@
M=&AE(&-O;G1E;G1S(&]F('1H92!P87)T"B`@("`@("`@("`@9&ER96-T;'D@
M86YD(')E='5R;BX@*B\*("`@("`@("!I9B`H)'!T>7!E(#T]("=M97-S86=E
M)RD@>PH@("`@("`@("`@("!I9B`H:7-S970H)'1E>'0I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)'1E>'0@+B`D=&AI<RT^7V-O;G1E;G1S.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?8V]N=&5N=',["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(&EF("AI<W-E="@D=&5X="DI('L*("`@("`@("`@("`@)'1E>'0@+CT@)'1H
M:7,M/G1R86YS9F5R16YC;V1E*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'1E>'0@/2`D=&AI<RT^=')A;G-F97)%;F-O9&4H*3L*("`@("`@
M("!]"@H@("`@("`@("\J($1E86P@=VET:"!M=6QT:7!A<G0@;65S<V%G97,N
M("HO"B`@("`@("`@:68@*"1P='EP92`]/2`G;75L=&EP87)T)RD@>PH@("`@
M("`@("`@("`D8F]U;F1A<GD@/2!T<FEM*"1T:&ES+3YG971#;VYT96YT5'EP
M95!A<F%M971E<B@G8F]U;F1A<GDG*2P@)R(G*3L*("`@("`@("`@("`@:68@
M*"%S=')L96XH)'1H:7,M/E]C;VYT96YT<RDI('L*("`@("`@("`@("`@("`@
M("1T97AT("X]("=4:&ES(&UE<W-A9V4@:7,@:6X@34E-12!F;W)M870N)R`N
M("1E;VP["B`@("`@("`@("`@('T*("`@("`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/F=E=%!A<G1S*"D@87,@)'!A<G0I('L*("`@("`@("`@("`@("`@("1T
M97AT("X]("1E;VP@+B`G+2TG("X@)&)O=6YD87)Y("X@)&5O;#L*("`@("`@
M("`@("`@("`@("1O;&1%3TP@/2`D<&%R="T^9V5T14],*"D["B`@("`@("`@
M("`@("`@("`D<&%R="T^<V5T14],*"1E;VPI.PH@("`@("`@("`@("`@("`@
M)'1E>'0@+CT@)'!A<G0M/G1O4W1R:6YG*'1R=64I.PH@("`@("`@("`@("`@
M("`@)'!A<G0M/G-E=$5/3"@D;VQD14],*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D=&5X="`N/2`D96]L("X@)RTM)R`N("1B;W5N9&%R>2`N("<M
M+2<@+B`D96]L.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T97AT.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@96YC;V1E9"!P87)T
M(&EN('-T<FEC="!21D,@.#(R("8@,C`T-2!O=71P=70@+2!N86UE;'DL(&%L
M;`H@("`@("H@;F5W;&EN97,@96YD('=I=&@@=&AE(&-A;F]N:6-A;"`\0U(^
M/$Q&/B!S97%U96YC92X*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M:&5A9&5R<R`@26YC;'5D92!T:&4@34E-12!H96%D97)S/PH@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@96YT:7)E($U)344@<&%R="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@=&]#86YO;FEC86Q3=')I;F<H)&AE861E<G,@
M/2!T<G5E*0H@("`@>PH@("`@("`@("1S=')I;F<@/2`D=&AI<RT^=&]3=')I
M;F<H)&AE861E<G,I.PH@("`@("`@(')E='5R;B`D=&AI<RT^<F5P;&%C945/
M3"@D<W1R:6YG+"!-24U%7U!!4E1?4D9#7T5/3"D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3:&]U;&0@=V4@;6%K92!S=7)E('1H92!M97-S86=E(&ES(&5N
M8V]D960@=FEA(#<M8FET("AE+F<N('1O(&%D:&5R90H@("`@("H@=&\@;6%I
M;"!D96QI=F5R>2!S=&%N9&%R9',@<W5C:"!A<R!21D,@,C@R,2D_"B`@("`@
M*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'5S93=B:70@(%5S92`W+6)I="!E
M;F-O9&EN9S\*("`@("`J+PH@("`@9G5N8W1I;VX@<W1R:6-T-V)I="@D=7-E
M-V)I="D*("`@('L*("`@("`@("`D=&AI<RT^7V5N8V]D93=B:70@/2`D=7-E
M-V)I=#L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@=')A;G-F97(@
M96YC;V1I;F<@9F]R('1H92!P87)T(&)A<V5D(&]N('1H92!U<V5R(')E<75E
M<W1E9`H@("`@("H@=')A;G-F97(@96YC;V1I;F<@86YD('1H92!C=7)R96YT
M(&-O;G1E;G1S(&]F('1H92!P87)T+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@=')A;G-F97(M96YC;V1I;F<@;V8@=&AI<R!P87)T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G9714<F%N<V9E<D5N8V]D:6YG*"D*("`@
M('L*("`@("`@("`D96YC;V1I;F<@/2`D=&AI<RT^7W1R86YS9F5R16YC;V1I
M;F<["B`@("`@("`@)'!T>7!E(#T@)'1H:7,M/F=E=%!R:6UA<GE4>7!E*"D[
M"B`@("`@("`@)'1E>'0@/2!S=')?<F5P;&%C92@D=&AI<RT^9V5T14],*"DL
M("<@)RP@)'1H:7,M/E]C;VYT96YT<RD["@H@("`@("`@("\J($EF('1H97)E
M(&%R92!N;R!C;VYT96YT<RP@<F5T=7)N('=H871E=F5R('1H92!C=7)R96YT
M('9A;'5E(&]F"B`@("`@("`@("`@)%]T<F%N<V9E<D5N8V]D:6YG(&ES+B`J
M+PH@("`@("`@(&EF("AE;7!T>2@D=&5X="DI('L*("`@("`@("`@("`@<F5T
M=7)N("1E;F-O9&EN9SL*("`@("`@("!]"@H@("`@("`@('-W:71C:"`H)'!T
M>7!E*2!["B`@("`@("`@8V%S92`G;65S<V%G92<Z"B`@("`@("`@("`@("\J
M(%)&0R`R,#0V(%LU+C(N,5T@+2!M97-S86=E+W)F8S@R,B!M97-S86=E<R!O
M;FQY(&%L;&]W(#=B:70L"B`@("`@("`@("`@("`@(#AB:70L(&%N9"!B:6YA
M<GD@96YC;V1I;F=S+B!)9B!T:&4@8W5R<F5N="!E;F-O9&EN9R!I<R!E:71H
M97(*("`@("`@("`@("`@("`@8F%S938T(&]R('$M<"P@<W=I=&-H(&ET('1O
M(#AB:70@:6YS=&5A9"X*("`@("`@("`@("`@("`@4D9#(#(P-#8@6S4N,BXR
M+"`U+C(N,RP@-2XR+C1=("T@06QL(&]T:&5R(&UE<W-A9V4O*B!M97-S86=E
M<PH@("`@("`@("`@("`@("!O;FQY(&%L;&]W(#=B:70@96YC;V1I;F=S+B`J
M+PH@("`@("`@("`@("`D96YC;V1I;F<@/2`H)'1H:7,M/F=E=%-U8E1Y<&4H
M*2`]/2`G<F9C.#(R)RD@/R`G.&)I="<@.B`G-V)I="<["B`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("!C87-E("=T97AT)SH*("`@("`@("`@("`@:68@
M*$U)344Z.FES.&)I="@D=&5X="DI('L*("`@("`@("`@("`@("`@("1E;F-O
M9&EN9R`]("@D=&AI<RT^7V5N8V]D93=B:70I(#\@)W%U;W1E9"UP<FEN=&%B
M;&4G(#H@)SAB:70G.PH@("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C
M:"@B+R@_.EQN?%XI6UY<;EU[.3DY+'TH/SI<;GPD*2\B+"`D=&5X="DI('L*
M("`@("`@("`@("`@("`@("\J($EF('1H92!T97AT(&ES(&QO;F=E<B!T:&%N
M(#DY."!C:&%R86-T97)S(&)E='=E96X*("`@("`@("`@("`@("`@("`J(&QI
M;F5B<F5A:W,L('5S92!Q=6]T960M<')I;G1A8FQE(&5N8V]D:6YG('1O(&5N
M<W5R92!T:&4*("`@("`@("`@("`@("`@("`J('1E>'0@=VEL;"!N;W0@8F4@
M8VAO<'!E9"`H:2YE+B!B>2!S96YD;6%I;"!I9B!B96EN9R!S96YT"B`@("`@
M("`@("`@("`@("`@*B!A<R!M86EL('1E>'0I+B`J+PH@("`@("`@("`@("`@
M("`@)&5N8V]D:6YG(#T@)W%U;W1E9"UP<FEN=&%B;&4G.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@
M("`@("`@("!I9B`H34E-13HZ:7,X8FET*"1T97AT*2D@>PH@("`@("`@("`@
M("`@("`@)&5N8V]D:6YG(#T@*"1T:&ES+3Y?96YC;V1E-V)I="D@/R`G8F%S
M938T)R`Z("<X8FET)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("!]"@H@("`@("`@("\J($YE960@=&\@9&\@;VYE(&QA<W0@
M8VAE8VL@9F]R(&)I;F%R>2!D871A(&EF(&5N8V]D:6YG(&ES(#=B:70@;W(*
M("`@("`@("`@*B`X8FET+B`@268@=&AE(&UE<W-A9V4@8V]N=&%I;G,@82!.
M54Q,(&-H87)A8W1E<B!A="!A;&PL('1H92!M97-S86=E"B`@("`@("`@("H@
M35535"!B92!I;B!B:6YA<GD@9F]R;6%T+B!21D,@,C`T-B!;,BXW+"`R+C@L
M(#(N.5TN(%$M4"!A;F0@8F%S938T"B`@("`@("`@("H@8V%N(&AA;F1L92!B
M:6YA<GD@9&%T82!F:6YE('-O(&YO(&YE960@=&\@<W=I=&-H('1H;W-E(&5N
M8V]D:6YG<RX@*B\*("`@("`@("!I9B`H*"@D96YC;V1I;F<@/3T@)SAB:70G
M*2!\?"`H)&5N8V]D:6YG(#T]("<W8FET)RDI("8F"B`@("`@("`@("`@('!R
M96=?;6%T8V@H)R]<>#`P+R<L("1T97AT*2D@>PH@("`@("`@("`@("`D96YC
M;V1I;F<@/2`H)'1H:7,M/E]E;F-O9&4W8FET*2`_("=B87-E-C0G(#H@)V)I
M;F%R>2<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&5N8V]D:6YG.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S('1H92!C=7)R96YT(&5N
M8V]D:6YG(&]F('1H92!C;VYT96YT<R!I;B!T:&4@;V)J96-T+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8W5R<F5N="!E;F-O9&EN9RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0W5R<F5N=$5N8V]D:6YG*"D*("`@
M('L*("`@("`@("!R971U<FX@*&ES7VYU;&PH)'1H:7,M/E]C=7)R96YT16YC
M;V1I;F<I*2`_("1T:&ES+3Y?=')A;G-F97)%;F-O9&EN9R`Z("1T:&ES+3Y?
M8W5R<F5N=$5N8V]D:6YG.PH@("`@?0H*("`@("\J*@H@("`@("H@16YC;V1E
M<R!T:&4@8V]N=&5N=',@=VET:"!T:&4@<&%R="=S('1R86YS9F5R(&5N8V]D
M:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@96YC;V1E
M9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!T<F%N<V9E<D5N8V]D92@I
M"B`@("!["B`@("`@("`@)&5N8V]D:6YG(#T@)'1H:7,M/F=E=%1R86YS9F5R
M16YC;V1I;F<H*3L*("`@("`@("`D96]L(#T@)'1H:7,M/F=E=$5/3"@I.PH*
M("`@("`@("`O*B!3970@=&AE("=L87-T5')A;G-F97)%;F-O9&4G(&9L86<@
M<V\@=&AA="!T<F%N<V9E<D5N8V]D94-O;G1E;G1S*"D*("`@("`@("`@("!C
M86X@<V%V92!A(&-A;&P@=&\@9V5T5')A;G-F97)%;F-O9&EN9R@I+B`J+PH@
M("`@("`@("1T:&ES+3Y?9FQA9W-;)VQA<W14<F%N<V9E<D5N8V]D92==(#T@
M)&5N8V]D:6YG.PH*("`@("`@("`O*B!)9B!C;VYT96YT<R!A<F4@96UP='DL
M(&]R(&-O;G1E;G1S(&%R92!A;')E861Y(&5N8V]D960@=&\@=&AE"B`@("`@
M("`@("`@8V]R<F5C="!E;F-O9&EN9RP@<F5T=7)N(&YO=RX@*B\*("`@("`@
M("!I9B`H(7-T<FQE;B@D=&AI<RT^7V-O;G1E;G1S*2!\?`H@("`@("`@("`@
M("`H)&5N8V]D:6YG(#T]("1T:&ES+3Y?8W5R<F5N=$5N8V]D:6YG*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]C;VYT96YT<SL*("`@("`@("!]
M"@H@("`@("`@('-W:71C:"`H)&5N8V]D:6YG*2!["B`@("`@("`@+RH@0F%S
M938T($5N8V]D:6YG.B!3964@4D9#(#(P-#4L('-E8W1I;VX@-BXX("HO"B`@
M("`@("`@8V%S92`G8F%S938T)SH*("`@("`@("`@("`@+RH@2V5E<&EN9R!T
M:&5S92!T=V\@;&EN97,@<V5P87)A=&4@<V5E;7,@=&\@=7-E(&UU8V@@;&5S
M<PH@("`@("`@("`@("`@("!M96UO<GD@=&AA;B!C;VUB:6YI;F<@=&AE;2`H
M87,@;V8@4$A0(#0N,RDN("HO"B`@("`@("`@("`@("1E;F-O9&5D7V-O;G1E
M;G1S(#T@8F%S938T7V5N8V]D92@D=&AI<RT^7V-O;G1E;G1S*3L*("`@("`@
M("`@("`@<F5T=7)N(&-H=6YK7W-P;&ET*"1E;F-O9&5D7V-O;G1E;G1S+"`W
M-BP@)&5O;"D["@H@("`@("`@("\J(%%U;W1E9"U0<FEN=&%B;&4@16YC;V1I
M;F<Z(%-E92!21D,@,C`T-2P@<V5C=&EO;B`V+C<@*B\*("`@("`@("!C87-E
M("=Q=6]T960M<')I;G1A8FQE)SH*("`@("`@("`@("`@)&]U='!U="`]($U)
M344Z.G%U;W1E9%!R:6YT86)L945N8V]D92@D=&AI<RT^7V-O;G1E;G1S+"`D
M96]L*3L*("`@("`@("`@("`@:68@*"@D96]L;&5N9W1H(#T@4W1R:6YG.CIL
M96YG=&@H)&5O;"DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@<W5B<W1R
M*"1O=71P=70L(#`L("1E;VQL96YG=&@@*B`M,2D["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@)&]U='!U=#L*("`@("`@
M("`@("`@?0H*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)E<&QA8V5%3TPH)'1H:7,M/E]C;VYT96YT<RD["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5C;V1E<R!T:&4@8V]N=&5N=',@
M;V8@=&AE('!A<G0@=&\@96ET:&5R(&$@-V)I="!O<B`X8FET(&5N8V]D:6YG
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9&5C;V1E9"!T
M97AT+@H@("`@("H@("`@("`@("`@("`@("`@(%)E='5R;G,@=&AE(&5M<'1Y
M('-T<FEN9R!I9B!T:&5R92!I<R!N;R!T97AT('1O(&1E8V]D92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@=')A;G-F97)$96-O9&4H*0H@("`@>PH@("`@("`@
M("1E;F-O9&EN9R`]("1T:&ES+3YG971#=7)R96YT16YC;V1I;F<H*3L*"B`@
M("`@("`@+RH@268@=&AE(&-O;G1E;G1S(&%R92!E;7!T>2P@<F5T=7)N(&YO
M=RX@*B\*("`@("`@("!I9B`H(7-T<FQE;B@D=&AI<RT^7V-O;G1E;G1S*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7V9L86=S6R=L87-T5')A;G-F97)$96-O
M9&4G72`]("1E;F-O9&EN9SL*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M8V]N=&5N=',["B`@("`@("`@?0H*("`@("`@("!S=VET8V@@*"1E;F-O9&EN
M9RD@>PH@("`@("`@(&-A<V4@)V)A<V4V-"<Z"B`@("`@("`@("`@("1M97-S
M86=E(#T@8F%S938T7V1E8V]D92@D=&AI<RT^7V-O;G1E;G1S*3L*("`@("`@
M("`@("`@)'1H:7,M/E]F;&%G<ULG;&%S=%1R86YS9F5R1&5C;V1E)UT@/2`G
M.&)I="<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=Q=6]T
M960M<')I;G1A8FQE)SH*("`@("`@("`@("`@)&UE<W-A9V4@/2!P<F5G7W)E
M<&QA8V4H(B\]7'(_7&XO(BP@)R<L("1T:&ES+3Y?8V]N=&5N=',I.PH@("`@
M("`@("`@("`D;65S<V%G92`]("1T:&ES+3YR97!L86-E14],*"1M97-S86=E
M*3L*("`@("`@("`@("`@)&UE<W-A9V4@/2!Q=6]T961?<')I;G1A8FQE7V1E
M8V]D92@D;65S<V%G92D["B`@("`@("`@("`@("1T:&ES+3Y?9FQA9W-;)VQA
M<W14<F%N<V9E<D1E8V]D92==(#T@*$U)344Z.FES.&)I="@D;65S<V%G92DI
M(#\@)SAB:70G(#H@)S=B:70G.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@+RH@4W5P<&]R="!F;W(@=75E;F-O9&5D(&5N8V]D:6YG("T@86QT:&]U
M9V@@;F]T(')E<75I<F5D(&)Y(%)&0W,L"B`@("`@("`@("`@<V]M92!M86EL
M97)S(&UA>2!S=&EL;"!E;F-O9&4@=&AI<R!W87DN("HO"B`@("`@("`@8V%S
M92`G=75E;F-O9&4G.@H@("`@("`@(&-A<V4@)W@M=75E;F-O9&4G.@H@("`@
M("`@(&-A<V4@)W@M=75E)SH*("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X
M:7-T<R@G8V]N=F5R=%]U=61E8V]D92<I*2!["B`@("`@("`@("`@("`@("`D
M;65S<V%G92`](&-O;G9E<G1?=75E;F-O9&4H)'1H:7,M/E]C;VYT96YT<RD[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)TUA:6PO;6EM941E8V]D92YP:'`G.PH@("`@("`@("`@("`@("`@
M)&9I;&5S(#T@)DUA:6Q?;6EM941E8V]D93HZ=75D96-O9&4H)'1H:7,M/E]C
M;VYT96YT<RD["B`@("`@("`@("`@("`@("`D;65S<V%G92`]("1F:6QE<ULP
M75LG9FEL961A=&$G73L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)TUA:6PO;6EM941E8V]D92YP:'`G.PH@("`@("`@("`@("`D
M9FEL97,@/2`F36%I;%]M:6UE1&5C;V1E.CIU=61E8V]D92@D=&AI<RT^7V-O
M;G1E;G1S*3L*("`@("`@("`@("`@)&UE<W-A9V4@/2`D9FEL97-;,%U;)V9I
M;&5D871A)UT["B`@("`@("`@("`@("1T:&ES+3Y?9FQA9W-;)VQA<W14<F%N
M<V9E<D1E8V]D92==(#T@)SAB:70G.PH@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@9&5F875L=#H*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M9FQA9W-;)VQA<W14<F%N<V9E<D1E8V]D92==*2`F)@H@("`@("`@("`@("`@
M("`@*"1T:&ES+3Y?9FQA9W-;)VQA<W14<F%N<V9E<D1E8V]D92==("$]("1E
M;F-O9&EN9RDI('L*("`@("`@("`@("`@("`@("1M97-S86=E(#T@)'1H:7,M
M/G)E<&QA8V5%3TPH)'1H:7,M/E]C;VYT96YT<RD["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D;65S<V%G92`]("1T:&ES+3Y?8V]N
M=&5N=',["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]F;&%G
M<ULG;&%S=%1R86YS9F5R1&5C;V1E)UT@/2`D96YC;V1I;F<["B`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1M97-S86=E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4W!L:70@=&AE(&-O;G1E;G1S(&]F
M('1H92!C=7)R96YT(%!A<G0@:6YT;R!I=',@<F5S<&5C=&EV92!S=6)P87)T
M<RP*("`@("`J(&EF(&ET(&ES(&UU;'1I<&%R="!-24U%(&5N8V]D:6YG+B!5
M;FQI:V4@=&AE(&EM87!?*B@I(&9U;F-T:6]N<RP@=&AI<PH@("`@("H@=VEL
M;"!P<F5S97)V92!A;&P@34E-12!H96%D97(@:6YF;W)M871I;VXN"B`@("`@
M*@H@("`@("H@5&AE(&)O=6YD87)Y(&-O;G1E;G0M='EP92!P87)A;65T97(@
M;75S="!B92!S970@9F]R('1H:7,@9G5N8W1I;VX@=&\*("`@("`J('=O<FL@
M8V]R<F5C=&QY+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U
M92!I9B!T:&4@8V]N=&5N=',@=V5R92!S=6-C97-S9G5L;'D@<W!L:70N"B`@
M("`@*B`@("`@("`@("`@("`@("`@($9A;'-E(&EF(&%N>2!E<G)O<B!O8V-U
M<G)E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<W!L:71#;VYT96YT<R@I"B`@
M("!["B`@("`@("`@:68@*"$H)&)O=6YD87)Y(#T@)'1H:7,M/F=E=$-O;G1E
M;G14>7!E4&%R86UE=&5R*"=B;W5N9&%R>2<I*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H(7-T<FQE;B@D
M=&AI<RT^7V-O;G1E;G1S*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("`D96]L(#T@)'1H:7,M/F=E=$5/3"@I.PH@
M("`@("`@("1R971V86QU92`](&9A;'-E.PH*("`@("`@("!F;W)E86-H("AE
M>'!L;V1E*"1E;VPL("1T:&ES+3Y?8V]N=&5N=',I(&%S("1L:6YE*2!["B`@
M("`@("`@("`@("1P;W,@/2!S=')P;W,H)&QI;F4L("<M+2<@+B`D8F]U;F1A
M<GDI.PH@("`@("`@("`@("!I9B`H*"1P;W,@/3T](&9A;'-E*2`F)B!I<W-E
M="@D<&%R=%]P='(I*2!["B`@("`@("`@("`@("`@("`D9&%T85M=(#T@)&QI
M;F4["B`@("`@("`@("`@('T@96QS96EF("@D<&]S(#T]/2`P*2!["B`@("`@
M("`@("`@("`@("`D<F5T=F%L=64@/2!T<G5E.PH@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1P87)T7W!T<BDI('L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A<G1S6R1P87)T7W!T<ETM/G-E=$-O;G1E;G1S*&EM<&QO9&4H
M)&5O;"P@)&1A=&$I*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<G1S6R1P87)T7W!T<ETM/G-P;&ET0V]N=&5N=',H*3L*("`@("`@("`@("`@
M("`@("`@("!N97AT*"1T:&ES+3Y?<&%R=',I.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!R97-E="@D=&AI<RT^7W!A
M<G1S*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D9&%T82DI('L*("`@("`@("`@("`@("`@("`@("!U;G-E="@D9&%T
M82D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D9&%T82`]
M(&%R<F%Y*"D["B`@("`@("`@("`@("`@("`D<&%R=%]P='(@/2!K97DH)'1H
M:7,M/E]P87)T<RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D<F5T=F%L=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!297!L
M86-E(&YE=VQI;F5S(&EN('1H:7,@<&%R="=S(&-O;G1E;G1S('=I=&@@=&AO
M<V4@<W!E8VEF:65D(&)Y(&5I=&AE<@H@("`@("H@=&AE(&=I=F5N(&YE=VQI
M;F4@<V5Q=65N8V4@;W(@=&AE('!A<G0G<R!C=7)R96YT($5/3"!S971T:6YG
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT
M('1O(')E<&QA8V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1E;VP@("!4:&4@
M14],('-E<75E;F-E('1O('5S92X@268@;F]T('!R97-E;G0L('5S97,@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!P87)T)W,@8W5R<F5N="!%
M3TP@<V5T=&EN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M('1E>'0@=VET:"!T:&4@;F5W;&EN97,@<F5P;&%C960@8GD@=&AE(&1E<VER
M960*("`@("`J("`@("`@("`@("`@("`@("!N97=L:6YE('-E<75E;F-E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!R97!L86-E14],*"1T97AT+"`D96]L(#T@
M;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D96]L*2D@>PH@("`@
M("`@("`@("`D96]L(#T@)'1H:7,M/F=E=$5/3"@I.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@<')E9U]R97!L86-E*"(O7'(_7&XO(BP@)&5O;"P@)'1E
M>'0I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!U;FEQ=64@
M34E-15]087)T(&)O=6YD87)Y('-T<FEN9R!G96YE<F%T960@9F]R('1H:7,@
M;V)J96-T+@H@("`@("H@5&AI<R!M87D@;F]T(&)E('1H92!B;W5N9&%R>2!S
M=')I;F<@=7-E9"!W:&5N(&)U:6QD:6YG('1H92!M97-S86=E"B`@("`@*B!S
M:6YC92!A('5S97(@9&5F:6YE9"`G8F]U;F1A<GDG($-O;G1E;G0M5'EP92!P
M87)A;65T97(@=VEL;"!O=F5R<FED90H@("`@("H@=&AI<R!V86QU92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('5N:7%U92!B;W5N9&%R
M>2!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%5N:7%U94E$*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]B;W5N9&%R>3L*("`@('T*
M"B`@("`O*BH*("`@("`J($1E=&5R;6EN92!T:&4@<VEZ92!O9B!A($U)345?
M4&%R="!A;F0@:71S(&-H:6QD(&UE;6)E<G,N"B`@("`@*@H@("`@("H@0')E
M='5R;B!I;G1E9V5R("!3:7IE(&]F('1H92!-24U%7U!A<G0L(&EN(&)Y=&5S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971">71E<R@I"B`@("!["B`@("`@
M("`@)&)Y=&5S(#T@,#L*"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?9FQA
M9W-;)V-O;G1E;G1S4V5T)UTI("8F("1T:&ES+3Y?8GET97,I('L*("`@("`@
M("`@("`@)&)Y=&5S(#T@)'1H:7,M/E]B>71E<SL*("`@("`@("!](&5L<V5I
M9B`H)'1H:7,M/F=E=%!R:6UA<GE4>7!E*"D@/3T@)VUU;'1I<&%R="<I('L*
M("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/F=E=%!A<G1S*"D@87,@)'!A
M<G0I('L*("`@("`@("`@("`@("`@("\J(%-K:7`@;75L=&EP87)T(&5N=')I
M97,@*'-I;F-E('1H:7,@;6%Y(')E<W5L="!I;B!D;W5B;&4*("`@("`@("`@
M("`@("`@("`@(&-O=6YT:6YG*2X@*B\*("`@("`@("`@("`@("`@(&EF("@D
M<&%R="T^9V5T4')I;6%R>51Y<&4H*2`A/2`G;75L=&EP87)T)RD@>PH@("`@
M("`@("`@("`@("`@("`@("1B>71E<R`K/2`D<&%R="T^9V5T0GET97,H*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(&EF("@D=&AI<RT^9V5T4')I;6%R>51Y<&4H*2`]
M/2`G=&5X="<I('L*("`@("`@("`@("`@("`@("1B>71E<R`](%-T<FEN9SHZ
M;&5N9W1H*"1T:&ES+3Y?8V]N=&5N=',L("1T:&ES+3YG971#:&%R<V5T*"DI
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&)Y=&5S
M(#T@<W1R;&5N*"1T:&ES+3Y?8V]N=&5N=',I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&)Y=&5S.PH@("`@?0H*("`@("\J
M*@H@("`@("H@17AP;&EC:71L>2!S970@=&AE('-I>F4@*&EN(&)Y=&5S*2!O
M9B!T:&ES('!A<G0N(%1H:7,@=F%L=64@=VEL;"!O;FQY"B`@("`@*B!B92!R
M971U<FYE9"`H=FEA(&=E=$)Y=&5S*"DI(&EF('1H97)E(&%R92!N;R!C;VYT
M96YT<R!C=7)R96YT;'D@<V5T+@H@("`@("H@5&AI<R!F=6YC=&EO;B!I<R!U
M<V5F=6P@9F]R('-E='1I;F<@=&AE('-I>F4@;V8@=&AE('!A<G0@=VAE;B!T
M:&4*("`@("`J(&-O;G1E;G1S(&]F('1H92!P87)T(&%R92!N;W0@9G5L;'D@
M;&]A9&5D("AI+F4N(&-R96%T:6YG(&$@34E-15]087)T"B`@("`@*B!O8FIE
M8W0@9G)O;2!)34%0(&AE861E<B!I;F9O<FUA=&EO;B!W:71H;W5T(&QO861I
M;F<@=&AE(&1A=&$@;V8@=&AE"B`@("`@*B!P87)T*2X*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D8GET97,@(%1H92!S:7IE(&]F('1H:7,@<&%R
M="!I;B!B>71E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T0GET97,H)&)Y
M=&5S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8GET97,@/2`D8GET97,["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!/=71P=70@=&AE('-I>F4@;V8@=&AI<R!-
M24U%7U!A<G0@:6X@2T(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%-I>F4@;V8@=&AE($U)345?4&%R="P@:6X@<W1R:6YG(&9O<FUA="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T4VEZ92@I"B`@("!["B`@("`@("`@)&)Y
M=&5S(#T@)'1H:7,M/F=E=$)Y=&5S*"D["B`@("`@("`@:68@*&5M<'1Y*"1B
M>71E<RDI('L*("`@("`@("`@("`@<F5T=7)N("1B>71E<SL*("`@("`@("!]
M"@H@("`@("`@("1L;V-A;&5I;F9O(#T@3DQ3.CIG971,;V-A;&5);F9O*"D[
M"B`@("`@("`@<F5T=7)N(&YU;6)E<E]F;W)M870H)&)Y=&5S("\@,3`R-"P@
M,BP@)&QO8V%L96EN9F];)V1E8VEM86Q?<&]I;G0G72P@)&QO8V%L96EN9F];
M)W1H;W5S86YD<U]S97`G72D["B`@("`@?0H*("`@("\J*@H@("`@("H@061D
M('1O('1H92!L:7-T(&]F($-)1',@9F]R('1H:7,@<&%R="X*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)&-I9',@($$@;&ES="!O9B!-24U%($E$<R!O
M9B!T:&4@<&%R="X*("`@("`J("`@("`@("`@("`@("`@("`@("`@2V5Y("T@
M34E-12!)1`H@("`@("H@("`@("`@("`@("`@("`@("`@("!686QU92`M($-)
M1"!F;W(@=&AE('!A<G0*("`@("`J+PH@("`@9G5N8W1I;VX@861D0TE$*"1C
M:61S(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7V-I9',@*ST@
M)&-I9',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!L:7-T
M(&]F($-)1',@9F]R('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!4:&4@;&ES="!O9B!#241S(&9O<B!T:&ES('!A<G0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$-)1$QI<W0H*0H@("`@>PH@("`@("`@(&%S
M;W)T*"1T:&ES+3Y?8VED<RP@4T]25%]35%))3D<I.PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7V-I9',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H
M92!#;VYT96YT+4E$(&AE861E<B!F;W(@=&AI<R!P87)T+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&-I9"`@57-E('1H:7,@0TE$("AI9B!N;W0@
M86QR96%D>2!S970I+B`@16QS92P@9V5N97)A=&4@80H@("`@("H@("`@("`@
M("`@("`@("`@("`@("!R86YD;VT@0TE$+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S971#;VYT96YT240H)&-I9"`](&YU;&PI"B`@("!["B`@("`@("`@:68@
M*&ES7VYU;&PH)'1H:7,M/E]C;VYT96YT:60I*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?8V]N=&5N=&ED(#T@*&ES7VYU;&PH)&-I9"DI(#\@*&)A<V5?8V]N
M=F5R="AM:6-R;W1I;64H*2P@,3`L(#,V*2`N("=`)R`N("1?4T525D526R=3
M15)615)?3D%-12==*2`Z("1C:60["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D=&AI<RT^7V-O;G1E;G1I9#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE($-O;G1E;G0M240@9F]R('1H:7,@<&%R="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($-O;G1E;G0M240@9F]R('1H:7,@
M<&%R="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0V]N=&5N=$E$*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/E]C;VYT96YT:60["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!;'1E<B!T:&4@34E-12!)1"!O9B!T:&ES('!A<G0N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6EM96ED("!4:&4@34E-
M12!)1"X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T34E-14ED*"1M:6UE:60I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]M:6UE:60@/2`D;6EM96ED.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@34E-12!)1"!O9B!T:&ES
M('!A<G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!-24U%
M($E$+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971-24U%260H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7VUI;65I9#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE(')E;&%T:79E($U)344@240@;V8@=&AI<R!P
M87)T+@H@("`@("H@92YG+BP@:68@=&AE(&)A<V4@<&%R="!H87,@34E-12!)
M1"!O9B`R+"!A;F0@>6]U('=A;G0@=&AE(&9I<G-T"B`@("`@*B!S=6)P87)T
M(&]F('1H92!B87-E('!A<G0L('1H92!R96QA=&EV92!-24U%($E$(&ES(#(N
M,2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE(')E;&%T
M:79E('!A<G0@240N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!R96QA=&EV92!-24U%($E$+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9712
M96QA=&EV94U)345)9"@D:60I"B`@("!["B`@("`@("`@)')E;"`]("1T:&ES
M+3YG971-24U%260H*3L*("`@("`@("!R971U<FX@*&5M<'1Y*"1R96PI*2`_
M("1I9"`Z("1R96P@+B`G+B<@+B`D:60["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&$@;6%P<&EN9R!O9B!A;&P@34E-12!)1',@=&\@=&AE:7(@
M8V]N=&5N="UT>7!E<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!+
M15DZ($U)344@240L(%9!3%5%.B!#;VYT96YT('1Y<&4*("`@("`J+PH@("`@
M9G5N8W1I;VX@8V]N=&5N=%1Y<&5-87`H*0H@("`@>PH@("`@("`@("1M87`@
M/2!A<G)A>2@D=&AI<RT^9V5T34E-14ED*"D@/3X@)'1H:7,M/F=E=%1Y<&4H
M*2D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P87)T<R!A<R`D=F%L*2![
M"B`@("`@("`@("`@("1M87`@*ST@)'9A;"T^8V]N=&5N=%1Y<&5-87`H*3L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1M87`["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'96YE<F%T92!T:&4@=6YI<75E(&)O=6YD87)Y('-T<FEN9R`H
M:68@;F]T(&%L<F5A9'D@9&]N92DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!B;W5N
M9&%R>2!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G96YE<F%T94)O
M=6YD87)Y*"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7V)O
M=6YD87)Y*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V)O=6YD87)Y(#T@)SU?
M)R`N(&)A<V5?8V]N=F5R="AM:6-R;W1I;64H*2P@,3`L(#,V*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8F]U;F1A<GD["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+TU)344O4W1R=6-T=7)E+G!H<```````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`S-3`V-``Q,#4Q-30S,S<T-P`P,C(W-#``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"G)E<75I
M<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O365S<V%G92YP:'`G.PIR
M97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+U!A<G0N<&AP)SL*
M<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B]-24U%+G!H
M<"<["@HO*BH*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%+U-T<G5C
M='5R92YP:'`L=B`Q+C@W+C$P+C$Y(#(P,#8O,#4O,#0@,3@Z,#,Z,C4@<VQU
M<V%R>B!%>'`@)`H@*@H@*B!4:&4@34E-15]3=')U8W1U<F4Z.B!C;&%S<R!P
M<F]V:61E<R!M971H;V1S(&9O<B!D96%L:6YG('=I=&@@34E-12!M86EL+@H@
M*@H@*B!4:&4@9&5F875L="!C:&%R86-T97(@<V5T('1O('5S92!F;W(@;65S
M<V%G97,@<VAO=6QD(&)E(&1E9FEN960@:6X@=&AE"B`J('9A<FEA8FQE("1'
M3$]"04Q36R=M:6UE7W-T<G5C='5R92==6R=D969A=6QT7V-H87)S970G72`H
M9&5F875L=',@=&\@55,M05-#24D*("H@<&5R(%)&0R`R,#0U*2X*("H*("H@
M5$]$3SH@0V]N=F5R="!T;R!/3PH@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG
M:'0@,C`P,BTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M
M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!-
M:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^
M"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]-24U%
M"B`J+PIC;&%S<R!-24U%7U-T<G5C='5R92!["@H@("`@+RHJ"B`@("`@*B!'
M:79E;B!T:&4@<F5S=6QT<R!O9B!I;6%P7V9E=&-H<W1R=6-T=7)E*"DL('!A
M<G-E('1H92!S=')U8W1U<F4*("`@("`J(&]F('1H92!M97-S86=E+"!F:6=U
M<FEN9R!O=70@8V]R<F5C="!B;V1Y<&%R="!N=6UB97)S+"!E=&,N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T9$-L87-S("1B;V1Y("!4:&4@<F5S=6QT(&]F
M(&EM87!?9F5T8VAS=')U8W1U<F4H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N
M("9-24U%7TUE<W-A9V4@(%1H92!M97-S86=E('!A<G-E9"!I;G1O(&$@34E-
M15]-97-S86=E(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@)G!A<G-E
M*"1B;V1Y*0H@("`@>PH@("`@("`@("1M<V=/8B`]("9N97<@34E-15]-97-S
M86=E*"D["B`@("`@("`@)&US9T]B+3YA9&1087)T*$U)345?4W1R=6-T=7)E
M.CI?<&%R<V4H)&)O9'DI*3L*("`@("`@("`D;7-G3V(M/F)U:6QD365S<V%G
M92@I.PH*("`@("`@("`D<'1R(#T@87)R87DH)B1M<V=/8BD["B`@("`@("`@
M34E-15]3=')U8W1U<F4Z.E]A9&1-=6QT:7!A<G1);F9O*"1P='(I.PH*("`@
M("`@("!R971U<FX@)&US9T]B.PH@("`@?0H*("`@("\J*@H@("`@("H@1VEV
M96X@=&AE(')E<W5L=',@;V8@:6UA<%]F971C:'-T<G5C='5R92@I+"!P87)S
M92!T:&4@<W1R=6-T=7)E"B`@("`@*B!O9B!T:&4@;65S<V%G92P@9FEG=7)I
M;F<@;W5T(&-O<G)E8W0@8F]D>7!A<G0@;G5M8F5R<RP@971C+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S
M=&1#;&%S<R`D8F]D>2`@5&AE(')E<W5L="!O9B!I;6%P7V9E=&-H<W1R=6-T
M=7)E*"DN"B`@("`@*B!`<&%R86T@<W1R:6YG("1R968@("`@(%1H92!C=7)R
M96YT(&)O9'EP87)T+@H@("`@("H*("`@("`J($!R971U<FX@34E-15]087)T
M("!!($U)345?4&%R="!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N("9?
M<&%R<V4H)&)O9'DL("1R968@/2`P*0H@("`@>PH@("`@("`@('-T871I8R`D
M;65S<V%G92P@)&UU;'1I<&%R=#L*"B`@("`@("`@:68@*"%I<W-E="@D;65S
M<V%G92DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!-24U%.CIT>7!E*"=M
M97-S86=E)RD["B`@("`@("`@("`@("1M=6QT:7!A<G0@/2!-24U%.CIT>7!E
M*"=M=6QT:7!A<G0G*3L*("`@("`@("!]"@H@("`@("`@("1M:6UE7W!A<G0@
M/2`F;F5W($U)345?4&%R="@I.PH*("`@("`@("`O*B!4;W`@;75L=&EP87)T
M<R!D;VXG="!G970@=&AE:7(@;W=N(&QI;F4N("HO"B`@("`@("`@:68@*&5M
M<'1Y*"1R968I("8F"B`@("`@("`@("`@("@A:7-S970H)&)O9'DM/G1Y<&4I
M('Q\("@D8F]D>2T^='EP92`A/2`D;75L=&EP87)T*2DI('L*("`@("`@("`@
M("`@)')E9B`](#$["B`@("`@("`@?0H*("`@("`@("!-24U%7U-T<G5C='5R
M93HZ7W-E=$EN9F\H)&)O9'DL("1M:6UE7W!A<G0L("1R968I.PH*("`@("`@
M("!I9B`H:7-S970H)&)O9'DM/G1Y<&4I("8F("@D8F]D>2T^='EP92`]/2`D
M;65S<V%G92D@)B8*("`@("`@("`@("`@)&)O9'DM/FEF<W5B='EP92`F)B`H
M)&)O9'DM/G-U8G1Y<&4@/3T@)U)&0S@R,B<I*2!["B`@("`@("`@("`@("1M
M:6UE7W!A<G0M/G-E=$U)345)9"@D<F5F("X@)RXP)RD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&UI;65?<&%R="T^<V5T34E-14ED*"1R968I
M.PH@("`@("`@('T*"B`@("`@("`@+RH@1&5A;"!W:71H(&UU;'1I<&%R="!D
M871A+B`J+PH@("`@("`@(&EF("AI<W-E="@D8F]D>2T^<&%R=',I*2!["B`@
M("`@("`@("`@("1S=6)?:60@/2`Q.PH@("`@("`@("`@("!F;W)E86-H("@D
M8F]D>2T^<&%R=',@87,@)'-U8E]P87)T*2!["B`@("`@("`@("`@("`@("`O
M*B!!<F4@=V4@9&5A;&EN9R!W:71H(&$@;75L=&EP87)T(&UE<W-A9V4_("HO
M"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&)O9'DM/G1Y<&4I("8F("@D
M8F]D>2T^='EP92`]/2`D;65S<V%G92D@)B8*("`@("`@("`@("`@("`@("`@
M("!I<W-E="@D<W5B7W!A<G0M/G1Y<&4I("8F("@D<W5B7W!A<G0M/G1Y<&4@
M/3T@)&UU;'1I<&%R="DI('L*("`@("`@("`@("`@("`@("`@("`D<W5B7W)E
M9B`]("1R968["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1S=6)?<F5F(#T@*&5M<'1Y*"1R968I*2`_("1S=6)?:60@
M.B`D<F5F("X@)RXG("X@)'-U8E]I9#L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1M:6UE7W!A<G0M/F%D9%!A<G0H34E-15]3=')U8W1U
M<F4Z.E]P87)S92@D<W5B7W!A<G0L("1S=6)?<F5F*2P@)'-U8E]I9"LK*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1M:6UE
M7W!A<G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!':79E;B!A(&UI;64@<&%R
M="!F<F]M(&EM87!?9F5T8VAS=')U8W1U<F4H*2P@;75N9V4@:70@:6YT;R!A
M"B`@("`@*B!U<V5F=6P@9F]R;2!A;F0@;6%K92!S=7)E('1H870@86YY('!A
M<F%M971E<G,@=VAI8V@@87)E(&UI<W-I;F<*("`@("`J(&%R92!G:79E;B!D
M969A=6QT('9A;'5E<RX*("`@("`J"B`@("`@*B!4;R!S<&5C:69Y('1H92!D
M969A=6QT(&-H87)A8W1E<B!S970L(&1E9FEN92!T:&4@9VQO8F%L('9A<FEA
M8FQE"B`@("`@*B`D1TQ/0D%,4ULG;6EM95]S=')U8W5T<F4G75LG9&5F875L
M=%]C:&%R<V5T)UTN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T9$-L87-S("1P87)T("!4:&4@;W)I9VEN
M86P@<&%R="!I;F9O+@H@("`@("H@0'!A<F%M($U)345?4&%R="`F)&]B("!!
M($U)345?4&%R="!O8FIE8W0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1R968@
M("`@(%1H92!)1"!O9B!T:&ES('!A<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]S971);F9O*"1P87)T+"`F)&]B+"`D<F5F*0H@("`@>PH@("`@("`@("\J
M(%-T;W)E($-O;G1E;G0M='EP92!I;F9O<FUA=&EO;BX@*B\*("`@("`@("`D
M<')I;6%R>5]T>7!E(#T@*&ES<V5T*"1P87)T+3YT>7!E*2D@/R!3=')I;F<Z
M.FQO=V5R*"1P87)T+3YT>7!E*2`Z($U)344Z.G1Y<&4H)W1E>'0G*3L*("`@
M("`@("`D<V5C7W1Y<&4@/2`H)'!A<G0M/FEF<W5B='EP92`F)B`D<&%R="T^
M<W5B='EP92D@/R!3=')I;F<Z.FQO=V5R*"1P87)T+3YS=6)T>7!E*2`Z("=X
M+75N:VYO=VXG.PH@("`@("`@("1O8BT^<V5T5'EP92@D<')I;6%R>5]T>7!E
M("X@)R\G("X@)'-E8U]T>7!E*3L*"B`@("`@("`@+RH@4V5T('1R86YS9F5R
M(&5N8V]D:6YG+B`J+PH@("`@("`@(&EF("AI<W-E="@D<&%R="T^96YC;V1I
M;F<I*2!["B`@("`@("`@("`@("1E;F-O9&EN9R`]("1P87)T+3YE;F-O9&EN
M9SL*("`@("`@("`@("`@)&]B+3YS9714<F%N<V9E<D5N8V]D:6YG*"1E;F-O
M9&EN9RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&5N8V]D:6YG
M(#T@;G5L;#L*("`@("`@("!]"@H@("`@("`@("\J(%-E="!T<F%N<V9E<B!D
M:7-P;W-I=&EO;BX@*B\*("`@("`@("`D;V(M/G-E=$1I<W!O<VET:6]N*"@D
M<&%R="T^:69D:7-P;W-I=&EO;BD@/R!3=')I;F<Z.FQO=V5R*"1P87)T+3YD
M:7-P;W-I=&EO;BD@.B!-24U%7T1%1D%53%1?1$E34$]3251)3TXI.PH*("`@
M("`@("`O*B!)9B`G8F]D>2<@:7,@<V5T+"!S970@87,@=&AE(&-O;G1E;G1S
M(&]F('1H92!P87)T+B`J+PH@("`@("`@(&EF("AI<W-E="@D<&%R="T^8F]D
M>2DI('L*("`@("`@("`@("`@)&]B+3YS971#;VYT96YT<R@D<&%R="T^8F]D
M>2P@)&5N8V]D:6YG*3L*("`@("`@("!]"@H@("`@("`@("\J($EF("=B>71E
M<R<@:7,@<V5T+"!S=&]R92!A<R!I;F9O<FUA=&EO;B!V87)I86)L92X@*B\*
M("`@("`@("!I9B`H:7-S970H)'!A<G0M/F)Y=&5S*2D@>PH@("`@("`@("`@
M("`D;V(M/G-E=$)Y=&5S*"1P87)T+3YB>71E<RD["B`@("`@("`@?0H*("`@
M("`@("`O*B!3970@=&AE('!A<G0G<R!I9&5N=&EF:6-A=&EO;B!S=')I;F<L
M(&EF(&%V86EL86)L92X@*B\*("`@("`@("!I9B`H(65M<'1Y*"1R968I("8F
M("1P87)T+3YI9FED*2!["B`@("`@("`@("`@("1O8BT^<V5T0V]N=&5N=$E$
M*"1P87)T+3YI9"D["B`@("`@("`@?0H*("`@("`@("`O*B!';R!T:')O=6=H
M('1H92!C;VYT96YT+71Y<&4@<&%R86UE=&5R<RP@:68@86YY+B`J+PH@("`@
M("`@(&9O<F5A8V@@*$U)345?4W1R=6-T=7)E.CI?9V5T4&%R86UE=&5R<R@D
M<&%R="P@,2D@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@(&EF("@D
M:V5Y(#T]("=C:&%R<V5T)RD@>PH@("`@("`@("`@("`@("`@)&]B+3YS971#
M:&%R<V5T*"1V86PI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)&]B+3YS971#;VYT96YT5'EP95!A<F%M971E<B@D:V5Y+"`D=F%L
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@4V5T('1H
M92!D969A=6QT(&-H87)A8W1E<B!S970N("HO"B`@("`@("`@:68@*"@D;V(M
M/F=E=$-H87)S970H*2`]/2`G=7,M87-C:6DG*2`F)@H@("`@("`@("`@("!I
M<W-E="@D1TQ/0D%,4ULG;6EM95]S=')U8W1U<F4G75LG9&5F875L=%]C:&%R
M<V5T)UTI*2!["B`@("`@("`@("`@("1O8BT^<V5T0VAA<G-E="@D1TQ/0D%,
M4ULG;6EM95]S=')U8W1U<F4G75LG9&5F875L=%]C:&%R<V5T)UTI.PH@("`@
M("`@('T*"B`@("`@("`@+RH@1V\@=&AR;W5G:"!T:&4@9&ES<&]S:71I;VX@
M<&%R86UE=&5R<RP@:68@86YY+B`J+PH@("`@("`@(&9O<F5A8V@@*$U)345?
M4W1R=6-T=7)E.CI?9V5T4&%R86UE=&5R<R@D<&%R="P@,BD@87,@)&ME>2`]
M/B`D=F%L*2!["B`@("`@("`@("`@("1O8BT^<V5T1&ES<&]S:71I;VY087)A
M;65T97(H)&ME>2P@)'9A;"D["B`@("`@("`@?0H*("`@("`@("`O*B!3970@
M=&AE(&YA;64N("HO"B`@("`@("`@:68@*"1O8BT^9V5T0V]N=&5N=%1Y<&50
M87)A;65T97(H)V9I;&5N86UE)RDI('L*("`@("`@("`@("`@)&]B+3YS971.
M86UE*"1O8BT^9V5T0V]N=&5N=%1Y<&5087)A;65T97(H)V9I;&5N86UE)RDI
M.PH@("`@("`@('T@96QS96EF("@D;V(M/F=E=$1I<W!O<VET:6]N4&%R86UE
M=&5R*"=F:6QE;F%M92<I*2!["B`@("`@("`@("`@("1O8BT^<V5T3F%M92@D
M;V(M/F=E=$1I<W!O<VET:6]N4&%R86UE=&5R*"=F:6QE;F%M92<I*3L*("`@
M("`@("!]"@H@("`@("`@("\J(%-E="!T:&4@9&5S8W)I<'1I;VXN("HO"B`@
M("`@("`@:68@*&ES<V5T*"1P87)T+3YD97-C<FEP=&EO;BDI('L*("`@("`@
M("`@("`@)&]B+3YS971$97-C<FEP=&EO;B@D<&%R="T^9&5S8W)I<'1I;VXI
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A;&P@<&%R
M86UE=&5R<R!F;W(@82!G:79E;B!P;W)T:6]N(&]F(&$@;65S<V%G92X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1D0VQA<W,@)'!A<G0@(%1H92!O<FEG:6YA;"!P87)T(&EN9F\N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D='EP92`@(%1H92!P87)A;65T97(@='EP
M92!T;R!R971R:65V92X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M,2`](&-O;G1E;G0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@,B`]
M(&1I<W!O<VET:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@
M87)R87D@;V8@<&%R86UE=&5R(&ME>2]V86QU92!P86ER<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V=E=%!A<F%M971E<G,H)'!A<G0L("1T>7!E*0H@("`@
M>PH@("`@("`@("1P87)A;5]L:7-T(#T@87)R87DH*3L*"B`@("`@("`@:68@
M*"1T>7!E(#T](#$I('L*("`@("`@("`@("`@)'!T>7!E(#T@)W!A<F%M971E
M<G,G.PH@("`@("`@('T@96QS96EF("@D='EP92`]/2`R*2!["B`@("`@("`@
M("`@("1P='EP92`]("=D<&%R86UE=&5R<R<["B`@("`@("`@?0H@("`@("`@
M("1P97AI<W1S(#T@)VEF)R`N("1P='EP93L*"B`@("`@("`@:68@*"1P87)T
M+3XD<&5X:7-T<RD@>PH@("`@("`@("`@("!F;W)E86-H("@D<&%R="T^)'!T
M>7!E(&%S("1P87)A;2D@>PH@("`@("`@("`@("`@("`@)'!A<F%M+3YV86QU
M92`]('-T<E]R97!L86-E*&%R<F%Y*")<="(L("=<(B<I+"!A<G)A>2@G("<L
M("<B)RDL("1P87)A;2T^=F%L=64I.PH*("`@("`@("`@("`@("`@("1R97,@
M/2!-24U%.CID96-O9&521D,R,C,Q*"1P87)A;2T^871T<FEB=71E("X@)STG
M("X@)'!A<F%M+3YV86QU92D["B`@("`@("`@("`@("`@("!I9B`H)')E<RD@
M>PH@("`@("`@("`@("`@("`@("`@("1P87)A;2T^871T<FEB=71E(#T@)')E
M<ULG871T<FEB=71E)UT["B`@("`@("`@("`@("`@("`@("`@)'!A<F%M+3YV
M86QU92`]("1R97-;)W9A;'5E)UT["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D9FEE;&0@/2!3=')I;F<Z.FQO=V5R*"1P87)A;2T^871T
M<FEB=71E*3L*("`@("`@("`@("`@("`@(&EF("@D9FEE;&0@/3T@)W1Y<&4G
M*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"@D='EP92`]($U)344Z.G1Y
M<&4H)'!A<F%M+3YV86QU92DI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1P87)A;5]L:7-T6R=T>7!E)UT@/2`D='EP93L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1P87)A;5]L:7-T6R1F:65L9%T@/2`D<&%R86TM/G9A;'5E.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)'!A<F%M7VQI<W0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3970@=&AE('-P96-I86P@:6YF;W)M871I;VX@9F]R(&-E<G1A:6X@34E-
M12!T>7!E<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)B1P87)T<R`@5&AE(&QI<W0@;V8@<&%R
M=',@8V]N=&%I;F5D('=I=&AI;B!T:&4@;75L=&EP87)T"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@;V)J96-T+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1I;F9O("`@($EN9F]R;6%T:6]N(&%B;W5T('1H92!M=6QT:7!A<G0@<W1R
M=6-T=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?861D375L=&EP87)T26YF
M;R@F)'!A<G1S+"`D:6YF;R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@
M*&5M<'1Y*"1P87)T<RDI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@
M('T*"B`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D<&%R=',I(&%S("1K
M97DI('L*("`@("`@("`@("`@)'!T<B`]("8D<&%R='-;)&ME>5T["B`@("`@
M("`@("`@("1N97=?:6YF;R`]("1I;F9O.PH*("`@("`@("`@("`@:68@*&ES
M<V5T*"1I;F9O6R=A;'0G72DI('L*("`@("`@("`@("`@("`@("1P='(M/G-E
M=$EN9F]R;6%T:6]N*"=A;'1E<FYA=&EV92<L("AI<U]N=6QL*"1I;F9O6R=A
M;'0G72DI(#\@)RTG(#H@)&EN9F];)V%L="==*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H:7-S970H)&EN9F];)W)E;&%T960G72DI('L*("`@
M("`@("`@("`@("`@("1P='(M/G-E=$EN9F]R;6%T:6]N*"=R96QA=&5D7W!A
M<G0G+"`D:6YF;ULG<F5L871E9"==+3YG971-24U%260H*2D["B`@("`@("`@
M("`@("`@("!I9B`H)&ED(#T@)'!T<BT^9V5T0V]N=&5N=$E$*"DI('L*("`@
M("`@("`@("`@("`@("`@("`D:6YF;ULG<F5L871E9"==+3YA9&1#240H87)R
M87DH)'!T<BT^9V5T34E-14ED*"D@/3X@)&ED*2D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9O
M6R=R9F,X,C(G72DI('L*("`@("`@("`@("`@("`@("1P='(M/G-E=$EN9F]R
M;6%T:6]N*"=R9F,X,C)?<&%R="<L("1I;F9O6R=R9F,X,C(G72D["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@('-W:71C:"`H)'!T<BT^9V5T5'EP92@I
M*2!["B`@("`@("`@("`@(&-A<V4@)VUU;'1I<&%R="]A;'1E<FYA=&EV92<Z
M"B`@("`@("`@("`@("`@("`D;F5W7VEN9F];)V%L="==(#T@)'!T<BT^9V5T
M34E-14ED*"D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&-A<V4@)VUU;'1I<&%R="]R96QA=&5D)SH*("`@("`@("`@("`@("`@("1N
M97=?:6YF;ULG<F5L871E9"==(#T@)B1P='(["B`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VUE<W-A9V4O<F9C.#(R)SH*("`@
M("`@("`@("`@("`@("1N97=?:6YF;ULG<F9C.#(R)UT@/2`D<'1R+3YG971-
M24U%260H*3L*("`@("`@("`@("`@("`@("1P='(M/G-E=$EN9F]R;6%T:6]N
M*"=H96%D97(G+"!T<G5E*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!-24U%7U-T<G5C='5R93HZ7V%D9$UU
M;'1I<&%R=$EN9F\H)'!T<BT^7W!A<G1S+"`D;F5W7VEN9F\I.PH@("`@("`@
M('T*("`@('T*"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!B=6EL9"!A
M($U)345?365S<V%G92!O8FIE8W0@9G)O;2!A('1E>'0@;65S<V%G92X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!O9B!T
M:&4@34E-12!M97-S86=E+@H@("`@("H*("`@("`J($!R971U<FX@34E-15]-
M97-S86=E("!!($U)345?365S<V%G92!O8FIE8W0L(&]R(&9A;'-E(&]N(&5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<&%R<V5497AT34E-14UE<W-A
M9V4H)'1E>'0I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=-86EL+VUI
M;65$96-O9&4N<&AP)SL*"B`@("`@("`@+RH@4V5T('5P('1H92!O<'1I;VYS
M(&9O<B!T:&4@;6EM941E8V]D92!C;&%S<RX@*B\*("`@("`@("`D9&5C;V1E
M7V%R9W,@/2!A<G)A>2@I.PH@("`@("`@("1D96-O9&5?87)G<ULG:6YC;'5D
M95]B;V1I97,G72`]('1R=64["B`@("`@("`@)&1E8V]D95]A<F=S6R=D96-O
M9&5?8F]D:65S)UT@/2!F86QS93L*("`@("`@("`D9&5C;V1E7V%R9W-;)V1E
M8V]D95]H96%D97)S)UT@/2!F86QS93L*"B`@("`@("`@)&UI;65$96-O9&4@
M/2`F;F5W($UA:6Q?;6EM941E8V]D92@D=&5X="P@34E-15]005)47T5/3"D[
M"B`@("`@("`@:68@*"$H)'-T<G5C='5R92`]("1M:6UE1&5C;V1E+3YD96-O
M9&4H)&1E8V]D95]A<F=S*2DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!F
M86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!0=70@=&AE
M(&]B:F5C="!I;G1O(&EM87!?<&%R<V5S=')U8W1U<F4H*2!F;W)M+B`J+PH@
M("`@("`@("`@("!-24U%7U-T<G5C='5R93HZ7V-O;G9E<G1-:6UE1&5C;V1E
M1&%T82@D<W1R=6-T=7)E*3L*"B`@("`@("`@("`@("1M97-S86=E(#T@34E-
M15]3=')U8W1U<F4Z.G!A<G-E*"1S=')U8W1U<F4I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1M97-S86=E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0V]N=F5R="!T:&4@;W5T<'5T(&9R;VT@;6EM941E8V]D93HZ9&5C;V1E*"D@
M:6YT;R!A('-T<G5C='5R92!T:&%T"B`@("`@*B!M871C:&5S(&EM87!?9F5T
M8VAS=')U8W1U<F4H*2!O=71P=70N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T9$-L87-S("8D;V(@(%1H
M92!O=71P=70@9G)O;2!M:6UE1&5C;V1E.CID96-O9&4H*2X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V-O;G9E<G1-:6UE1&5C;V1E1&%T82@F)&]B*0H@("`@
M>PH@("`@("`@("\J(%!R:6UA<GD@8V]N=&5N="UT>7!E+B`J+PH@("`@("`@
M("1O8BT^='EP92`](&EN='9A;"A-24U%.CIT>7!E*"1O8BT^8W1Y<&5?<')I
M;6%R>2DI.PH*("`@("`@("`O*B!396-O;F1A<GD@8V]N=&5N="UT>7!E+B`J
M+PH@("`@("`@(&EF("AI<W-E="@D;V(M/F-T>7!E7W-E8V]N9&%R>2DI('L*
M("`@("`@("`@("`@)&]B+3YS=6)T>7!E(#T@4W1R:6YG.CIU<'!E<B@D;V(M
M/F-T>7!E7W-E8V]N9&%R>2D["B`@("`@("`@("`@("1O8BT^:69S=6)T>7!E
M(#T@,3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;V(M/FEF<W5B
M='EP92`](#`["B`@("`@("`@?0H*("`@("`@("`O*B!#;VYT96YT('1R86YS
M9F5R(&5N8V]D:6YG+B`J+PH@("`@("`@(&EF("AI<W-E="@D;V(M/FAE861E
M<G-;)V-O;G1E;G0M=')A;G-F97(M96YC;V1I;F<G72DI('L*("`@("`@("`@
M("`@)&]B+3YE;F-O9&EN9R`]($U)344Z.F5N8V]D:6YG*"1O8BT^:&5A9&5R
M<ULG8V]N=&5N="UT<F%N<V9E<BUE;F-O9&EN9R==*3L*("`@("`@("!]"@H@
M("`@("`@("\J($-O;G1E;G0M='EP92!A;F0@1&ES<&]S:71I;VX@<&%R86UE
M=&5R<RX@*B\*("`@("`@("`D<&%R86U?='EP97,@/2!A<G)A>2`H)V-T>7!E
M7W!A<F%M971E<G,G(#T^("=P87)A;65T97)S)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V1?<&%R86UE=&5R<R<@/3X@)V1P87)A;65T97)S
M)RD["B`@("`@("`@9F]R96%C:"`H)'!A<F%M7W1Y<&5S(&%S("1P87)A;5]K
M97D@/3X@)'!A<F%M7W9A;'5E*2!["B`@("`@("`@("`@("1I9E]V87(@/2`G
M:68G("X@)'!A<F%M7W9A;'5E.PH@("`@("`@("`@("!I9B`H:7-S970H)&]B
M+3XD<&%R86U?:V5Y*2D@>PH@("`@("`@("`@("`@("`@)&]B+3XD:69?=F%R
M(#T@,3L*("`@("`@("`@("`@("`@("1O8BT^)'!A<F%M7W9A;'5E(#T@87)R
M87DH*3L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1O8BT^)'!A<F%M7VME
M>2!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@("`@("`D;F5W
M3V(@/2`F;F5W('-T9$-L87-S.PH@("`@("`@("`@("`@("`@("`@("1N97=/
M8BT^871T<FEB=71E(#T@)&ME>3L*("`@("`@("`@("`@("`@("`@("`D;F5W
M3V(M/G9A;'5E(#T@)'9A;#L*("`@("`@("`@("`@("`@("`@("!A<G)A>5]P
M=7-H*"1O8BT^)'!A<F%M7W9A;'5E+"`D;F5W3V(I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&]B
M+3XD:69?=F%R(#T@,#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@+RH@0V]N=&5N="U$:7-P;W-I=&EO;BX@*B\*("`@("`@("!I9B`H:7-S
M970H)&]B+3YH96%D97)S6R=C;VYT96YT+61I<W!O<VET:6]N)UTI*2!["B`@
M("`@("`@("`@("1O8BT^:69D:7-P;W-I=&EO;B`](#$["B`@("`@("`@("`@
M("1H9'(@/2`D;V(M/FAE861E<G-;)V-O;G1E;G0M9&ES<&]S:71I;VXG73L*
M("`@("`@("`@("`@)'!O<R`]('-T<G!O<R@D:&1R+"`G.R<I.PH@("`@("`@
M("`@("!I9B`H)'!O<R`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1H
M9'(@/2!S=6)S='(H)&AD<BP@,"P@)'!O<RD["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&]B+3YD:7-P;W-I=&EO;B`]("1H9'(["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&]B+3YI9F1I<W!O<VET:6]N(#T@,#L*("`@
M("`@("!]"@H@("`@("`@("\J($-O;G1E;G0M240N("HO"B`@("`@("`@:68@
M*&ES<V5T*"1O8BT^:&5A9&5R<ULG8V]N=&5N="UI9"==*2D@>PH@("`@("`@
M("`@("`D;V(M/FEF:60@/2`Q.PH@("`@("`@("`@("`D;V(M/FED(#T@)&]B
M+3YH96%D97)S6R=C;VYT96YT+6ED)UT["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&]B+3YI9FED(#T@,#L*("`@("`@("!]"@H@("`@("`@("\J
M($=E="!F:6QE('-I>F4@*&EF("=B;V1Y)R!T97AT(&ES('-E="DN("HO"B`@
M("`@("`@:68@*&ES<V5T*"1O8BT^8F]D>2DI('L*("`@("`@("`@("`@)&]B
M+3YB>71E<R`]('-T<FQE;B@D;V(M/F)O9'DI.PH@("`@("`@('T*"B`@("`@
M("`@+RH@4')O8V5S<R!P87)T<R!A;'-O+B`J+PH@("`@("`@(&EF("AI<W-E
M="@D;V(M/G!A<G1S*2D@>PH@("`@("`@("`@("!F;W)E86-H("AA<G)A>5]K
M97ES*"1O8BT^<&%R=',I(&%S("1K97DI('L*("`@("`@("`@("`@("`@($U)
M345?4W1R=6-T=7)E.CI?8V]N=F5R=$UI;65$96-O9&5$871A*"1O8BT^<&%R
M='-;)&ME>5TI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@0G5I;&1S(&%N(&%R<F%Y(&-O;G-I<W1I;F<@;V8@34E-
M12!H96%D97(O=F%L=64@<&%I<G,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D:&5A9&5R<R`@("`@02!T97AT('-T<FEN9R!C;VYT86EN:6YG('1H
M92!H96%D97)S("AE+F<N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!O=71P=70@9G)O;2!I;6%P7V9E=&-H:&5A9&5R*"DI+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)&1E8V]D92`@("`@4VAO=6QD('1H92!H96%D97)S
M(&)E(&1E8V]D960_"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;&]W97)C87-E
M("!3:&]U;&0@=&AE(&ME>7,@8F4@:6X@;&]W97)C87-E/PH@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y(&-O;G-I<W1I;F<@;V8@=&AE
M(&AE861E<B!N86UE(&%S('1H92!K97D@86YD"B`@("`@*B`@("`@("`@("`@
M("`@("!T:&4@:&5A9&5R('9A;'5E(&%S('1H92!V86QU92X*("`@("`J("`@
M("`@("`@("`@("`@($$@:&5A9&5R('=I=&@@;75L=&EP;&4@96YT<FEE<R!W
M:6QL(&)E('-T;W)E9"!I;@H@("`@("H@("`@("`@("`@("`@("`@)W9A;'5E
M)R!A<R!A;B!A<G)A>2X*("`@("`J+PH@("`@9G5N8W1I;VX@<&%R<V5-24U%
M2&5A9&5R<R@D:&5A9&5R<RP@)&1E8V]D92`]('1R=64L("1L;W=E<F-A<V4@
M/2!F86QS92D*("`@('L*("`@("`@("`D:&5A9&5R(#T@)R<["B`@("`@("`@
M)&]B(#T@87)R87DH*3L*"B`@("`@("`@9F]R96%C:"`H97AP;&]D92@B7&XB
M+"`D:&5A9&5R<RD@87,@)'9A;"D@>PH@("`@("`@("`@("!I9B`H)&1E8V]D
M92D@>PH@("`@("`@("`@("`@("`@)'9A;"`]($U)344Z.F1E8V]D92@D=F%L
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H<')E9U]M871C:"@B
M+UXH6UY<<UTK*5PZ*"XJ*2\B+"`D=F%L+"`D;6%T8VAE<RDI('L*("`@("`@
M("`@("`@("`@("1V86P@/2!T<FEM*"1M871C:&5S6S)=*3L*("`@("`@("`@
M("`@("`@("1H96%D97(@/2`D;6%T8VAE<ULQ73L*("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D;V);)&AE861E<ETI*2!["B`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<U]A<G)A>2@D;V);)&AE861E<ETI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1T96UP(#T@)&]B6R1H96%D97)=.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D;V);)&AE861E<ET@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D;V);)&AE861E<EU;72`]("1T96UP.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D;V);)&AE
M861E<EU;72`]("1V86P["B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D=F%L(#T@)R`G("X@=')I;2@D=F%L*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@:68@*"%E;7!T>2@D:&5A9&5R*2D@>PH@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1O8ELD:&5A9&5R72DI('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)&]B6R1H96%D97)=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!E;F0H)&]B6R1H96%D97)=*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&]B6R1H96%D97)=6VME>2@D;V);)&AE
M861E<ETI72`N/2`D=F%L.PH@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1O8ELD:&5A9&5R72`N/2`D=F%L
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)&]B6R1H96%D97)=(#T@)'9A;#L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("@D;&]W97)C87-E*2`_(&%R<F%Y7V-H86YG95]K97E?
M8V%S92@D;V(L($-!4T5?3$]715(I(#H@)&]B.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6
M:65W97(O````````````````````````````````````````````````````
M`````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-3$U-#,S-S0W`#`R,30V,``@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]-24U%+U9I97=E<B]C<W,N<&AP````````````````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#8W,#4`,3`U,34T,S,W-#<`,#(R-S<Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@IR
M97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+W-O=7)C92YP:'`G
M.PH*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]C<W,@8VQA<W,@<F5N9&5R<R!#
M4U,@<V]U<F-E(&%S($A434P@=VET:"!A;B!E9F9O<G0*("H@=&\@<F5M;W9E
M('!O=&5N=&EA;&QY(&UA;&EC:6]U<R!C;V1E+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V-S<RYP:'`L=B`Q+C$N,3`N."`R
M,#`V+S`V+S`Q(#`S.C`X.C4S(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`T+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P
M86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E
M<E]C<W,@97AT96YD<R!-24U%7U9I97=E<E]S;W5R8V4@>PH*("`@("\J*@H@
M("`@("H@4F5N9&5R(&]U="!T:&4@8W5R<F5N=&QY('-E="!C;VYT96YT<RX*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY('!A<F%M
M971E<G,@=&AE('9I97=E<B!M87D@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D('1E>'0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(')E;F1E<B@D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("`D
M8W-S(#T@:'1M;'-P96-I86QC:&%R<R@D=&AI<RT^;6EM95]P87)T+3YG971#
M;VYT96YT<R@I+"!%3E1?3D]154]415,I.PH@("`@("`@("1C<W,@/2!P<F5G
M7W)E<&QA8V5?8V%L;&)A8VLH)R$H?7Q<*B\I+BH_*'M\+UPJ*2%S)RP@87)R
M87DH)'1H:7,L("=?:&%N9&QE<R<I+"`D8W-S*3L*("`@("`@("`D8W-S(#T@
M<')E9U]R97!L86-E7V-A;&QB86-K*"<A>UM>?5TJ?2%S)RP@87)R87DH)'1H
M:7,L("=?871T<FEB=71E<R<I+"`D8W-S*3L*("`@("`@("`D8W-S(#T@<')E
M9U]R97!L86-E7V-A;&QB86-K*"<A+UPJ+BH_7"HO(7,G+"!A<G)A>2@D=&AI
M<RP@)U]C;VUM96YT<R<I+"`D8W-S*3L*("`@("`@("`D8W-S(#T@=')I;2@D
M8W-S*3L*"B`@("`@("`@+R\@161U8V%T960@1W5E<W,@870@=VAE=&AE<B!W
M92!A<F4@:6YL:6YE(&]R(&YO="X*("`@("`@("!I9B`H:&5A9&5R<U]S96YT
M*"D@?'P@;V)?9V5T7VQE;F=T:"@I*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^;&EN94YU;6)E<B@D8W-S*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@571I;#HZ8G5F9F5R3W5T<'5T*"=R97%U:7)E)RP@
M)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E
M)RD@+B`G+V-O;6UO;BUH96%D97(N:6YC)RD@+@H@("`@("`@("`@("`@("`@
M)'1H:7,M/FQI;F5.=6UB97(H)&-S<RD@+@H@("`@("`@("`@("`@("`@571I
M;#HZ8G5F9F5R3W5T<'5T*"=R97%U:7)E)RP@)$=,3T)!3%-;)W)E9VES=')Y
M)UTM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUF;V]T
M97(N:6YC)RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]C;VUM
M96YT<R@D;6%T8VAE<RD*("`@('L*("`@("`@("`D<&%T=&5R;G-;72`]("<A
M*&AT='`Z+R];+UQW+2Y=*RDA<R<["B`@("`@("`@)')E<&QA8V5S6UT@/2`G
M/&$@:')E9CTB7%PQ(CY<7#$\+V$^)SL*"B`@("`@("`@)&-O;6UE;G1S(#T@
M<')E9U]R97!L86-E*"1P871T97)N<RP@)')E<&QA8V5S+"`D;6%T8VAE<ULP
M72D["@H@("`@("`@(')E='5R;B`G/'-P86X@8VQA<W,](F-O;6UE;G0B/B<@
M+B`D8V]M;65N=',@+B`G/"]S<&%N/B<["B`@("!]"@H@("`@9G5N8W1I;VX@
M7V%T=')I8G5T97,H)&UA=&-H97,I"B`@("!["B`@("`@("`@+R\@071T<FEB
M=71E<RX*("`@("`@("`D<&%T=&5R;G-;72`]("<A*%LM7'==*UQS*BDZ(7,G
M.PH@("`@("`@("1R97!L86-E<UM=(#T@)SQS<&%N(&-L87-S/2)A='1R(B(^
M7%PQ/"]S<&%N/CHG.PH*("`@("`@("`O+R!686QU97,N"B`@("`@("`@)'!A
M='1E<FYS6UT@/2`G(3HH7',J*2@N*S\I*%QS*CLI(7,G.PH@("`@("`@("1R
M97!L86-E<UM=(#T@)SI<7#$\<W!A;B!C;&%S<STB=F%L=64B/EQ<,CPO<W!A
M;CX\<W!A;B!C;&%S<STB96]L(CY<7#,\+W-P86X^)SL*"B`@("`@("`@+R\@
M55),<RX*("`@("`@("`D<&%T=&5R;G-;72`]("<A*'5R;%PH6UPG(ET_*2@N
M*C\I*%M<)R)=/UPI*2%S)SL*("`@("`@("`D<F5P;&%C97-;72`]("<\<W!A
M;B!C;&%S<STB=7)L(CY<7#$\<W!A;B!C;&%S<STB9FEL92(^7%PR/"]S<&%N
M/EQ<,SPO<W!A;CXG.PH*("`@("`@("`O+R!#;VQO<G,N"B`@("`@("`@)'!A
M='1E<FYS6UT@/2`G(2@C6ULZ>&1I9VET.EU=>S,L-GTI(7,G.PH@("`@("`@
M("1R97!L86-E<UM=(#T@)SQS<&%N(&-L87-S/2)C;VQO<B(^7%PQ/"]S<&%N
M/B<["@H@("`@("`@("\O(%!A<F5N=&AE<V5S+@H@("`@("`@("1P871T97)N
M<UM=(#T@)R$H>WQ]*2%S)SL*("`@("`@("`D<F5P;&%C97-;72`]("<\<W!A
M;B!C;&%S<STB<&%R96YT:&5S97,B/EQ<,3PO<W!A;CXG.PH*("`@("`@("`O
M+R!5;FET>2X*("`@("`@("`D<&%T=&5R;G-;72`]("<A*&5M?'!X?"4I7&(A
M<R<["B`@("`@("`@)')E<&QA8V5S6UT@/2`G/&5M/EQ<,3PO96T^)SL*"B`@
M("`@("`@<F5T=7)N('!R96=?<F5P;&%C92@D<&%T=&5R;G,L("1R97!L86-E
M<RP@)&UA=&-H97-;,%TI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]H86YD;&5S
M*"1M871C:&5S*0H@("`@>PH@("`@("`@("\O($A434P@5&%G<RX*("`@("`@
M("`D<&%T=&5R;G-;72`]("<A7&(H8F]D>7QH7&1\87QS<&%N?&1I=GQA8W)O
M;GEM?'-M86QL?'-T<F]N9WQE;7QP<F5\=6Q\;VQ\;&E\<"E<8B%S)SL*("`@
M("`@("`D<F5P;&%C97-;72`]("<\<W!A;B!C;&%S<STB:'1A9R(^7%PQ/"]S
M<&%N/EQ<,B<["@H@("`@("`@("\O($E$<RX*("`@("`@("`D<&%T=&5R;G-;
M72`]("<A*"-;+5QW72LI(7,G.PH@("`@("`@("1R97!L86-E<UM=(#T@)SQS
M<&%N(&-L87-S/2)I9"(^7%PQ/"]S<&%N/B<["@H@("`@("`@("\O($-L87-S
M+@H@("`@("`@("1P871T97)N<UM=(#T@)R$H7"Y;+5QW72LI7&(A<R<["B`@
M("`@("`@)')E<&QA8V5S6UT@/2`G/'-P86X@8VQA<W,](F-L87-S(CY<7#$\
M+W-P86X^)SL*"B`@("`@("`@+R\@345407,N"B`@("`@("`@)'!A='1E<FYS
M6UT@/2`G(2@Z;&EN:WPZ=FES:71E9'PZ:&]V97)\.F%C=&EV97PZ9FER<W0M
M;&5T=&5R*2%S)SL*("`@("`@("`D<F5P;&%C97-;72`]("<\<W!A;B!C;&%S
M<STB;65T86,B/EQ<,3PO<W!A;CXG.PH*("`@("`@("!R971U<FX@<')E9U]R
M97!L86-E*"1P871T97)N<RP@)')E<&QA8V5S+"`D;6%T8VAE<ULP72D["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O34E-12]6:65W97(O9&5B+G!H<```````````````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`S-#`W`#$P-3$U-#,S-S0W`#`R,C<R-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@5&AE($U)345?5FEE=V5R7V1E8B!C;&%S<R!R96YD97)S(&]U="!L
M:7-T<R!O9B!F:6QE<R!I;B!$96)I86X@<&%C:V%G97,@8GD*("H@=7-I;F<@
M=&AE(&1P:V<@=&]O;"!T;R!Q=65R>2!T:&4@<&%C:V%G92X*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N<&AP+'8@,2XQ
M,2XQ,"XX(#(P,#8O,#$O,#$@,C$Z,C@Z,C4@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`Q.3DY+3(P,#8@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C
M;VEL+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($%N:6P@36%D
M:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!S:6YC92`@($AO<F1E
M(#$N,PH@*B!`<&%C:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@
M34E-15]6:65W97)?9&5B(&5X=&5N9',@34E-15]6:65W97(@>PH*("`@("\J
M*@H@("`@("H@4F5N9&5R('1H92!D871A+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("!!;GD@<&%R86UE=&5R<R!T:&4@=FEE=V5R(&UA
M>2!N965D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5N
M9&5R960@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&=L;V)A;"`D;6EM95]D<FEV
M97)S.PH*("`@("`@("`O*B!#:&5C:R!T;R!M86ME('-U<F4@=&AE('!R;V=R
M86T@86-T=6%L;'D@97AI<W1S+B`J+PH@("`@("`@(&EF("@A9FEL95]E>&ES
M=',H)&UI;65?9')I=F5R<ULG:&]R9&4G75LG9&5B)UU;)VQO8V%T:6]N)UTI
M*2!["B`@("`@("`@("`@(')E='5R;B`G/'!R93XG("X@<W!R:6YT9BA?*")4
M:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W
M87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(BDL("1M:6UE7V1R:79E<G-;
M)VAO<F1E)UU;)V1E8B==6R=L;V-A=&EO;B==*2`N("<\+W!R93XG.PH@("`@
M("`@('T*"B`@("`@("`@)'1M<%]D96(@/2!(;W)D93HZ9V5T5&5M<$9I;&4H
M)VAO<F1E7V1E8B<I.PH*("`@("`@("`D9F@@/2!F;W!E;B@D=&UP7V1E8BP@
M)W<G*3L*("`@("`@("!F=W)I=&4H)&9H+"`D=&AI<RT^;6EM95]P87)T+3YG
M971#;VYT96YT<R@I*3L*("`@("`@("!F8VQO<V4H)&9H*3L*"B`@("`@("`@
M)&9H(#T@<&]P96XH)&UI;65?9')I=F5R<ULG:&]R9&4G75LG9&5B)UU;)VQO
M8V%T:6]N)UT@+B`B("UF("1T;7!?9&5B(#(^)C$B+"`G<B<I.PH@("`@("`@
M('=H:6QE("@H)')C(#T@9F=E=',H)&9H+"`X,3DR*2DI('L*("`@("`@("`@
M("`@)&1A=&$@+CT@)')C.PH@("`@("`@('T*("`@("`@("!P8VQO<V4H)&9H
M*3L*"B`@("`@("`@<F5T=7)N("<\<')E/B<@+B!H=&UL<W!E8VEA;&-H87)S
M*"1D871A*2`N("<\+W!R93XG.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N('1H92!-24U%(&-O;G1E;G0@='EP92!O9B!T:&4@<F5N9&5R960@8V]N
M=&5N="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O;G1E
M;G0@='EP92!O9B!T:&4@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)W1E>'0O:'1M;#L@8VAA
M<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"D["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+TU)344O5FEE=V5R+V1E9F%U;'0N<&AP````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,3$W-P`Q,#4Q-30S,S<T-P`P,C,V,C,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M(%1H92!-24U%7U9I97=E<E]D969A=6QT(&-L87-S('-I;7!L>2!P<FEN=',@
M;W5T('1H92!E;F-A<'-U;&%T960*("H@8V]N=&5N="X@($ET(&5X:7-T<R!A
M<R!A(&9A;&QB86-K(&EF(&YO(&]T:&5R(&EN=&5L;&EG96YT(')E;F1E<FEN
M9PH@*B!M96-H86YI<VT@8V]U;&0@8F4@=7-E9"X*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D969A=6QT+G!H<"QV(#$N.2XQ
M,BXT(#(P,#8O,#$O,#$@,C$Z,C@Z,C4@:F%N($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`Q.3DY+3(P,#8@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($%N:6P@36%D:&%V
M87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N
M,PH@*B!`<&%C:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-
M15]6:65W97)?9&5F875L="!E>'1E;F1S($U)345?5FEE=V5R('L*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V5N<FEC:&5D+G!H<```````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`R,#$S,0`Q,#4Q-30S,S<T-P`P,C,W-#<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J(%1H92!-24U%7U9I97=E<E]E;G)I8VAE9"!C;&%S<R!R96YD97)S
M(&]U="!P;&%I;B!T97AT(&9R;VT*("H@96YR:6-H960@8V]N=&5N="!T86=S
M+"!A;&$@4D9#(#$X.38N"B`J"B`J($)Y(%)&0RP@=V4@;75S="!D;R!T:&4@
M;6EN:6UA;"!C;VYF;W)M86YC92!M96%S=7)E<R!O9CH@02!M:6YI;6%L"B`J
M('1E>'0O96YR:6-H960@:6UP;&5M96YT871I;VX@:7,@;VYE('1H870@8V]N
M=F5R=',@(CP\(B!T;R`B/"(L"B`J(')E;6]V97,@979E<GET:&EN9R!B971W
M965N(&$@/'!A<F%M/B!C;VUM86YD(&%N9"!T:&4@;F5X="!B86QA;F-I;F<*
M("H@/"]P87)A;3X@<F5M;W9E<R!A;&P@;W1H97(@9F]R;6%T=&EN9R!C;VUM
M86YD<R`H86QL('1E>'0@96YC;&]S960*("H@:6X@86YG;&4@8G)A8VME=',I
M+"!A;F0@;W5T<VED92!O9B`\;F]F:6QL/B!E;G9I<F]N;65N=',@8V]N=F5R
M=',*("H@86YY('-E<FEE<R!O9B!N($-23$9S('1O(&XM,2!#4DQ&<RP@86YD
M(&-O;G9E<G1S(&%N>2!L;VYE($-23$8*("H@<&%I<G,@=&\@4U!!0T4N"B`J
M"B`J(%=E(&1O;B=T('%U86QI9GD@87,@=V4@9&]N)W0@8W5R<F5N=&QY('1R
M86-K('1H92`\;F]F:6QL/@H@*B!E;G9I<F]N;65N="P@=&AA="!I<R!W92!D
M;R!#4DQ&(&-O;G9E<G-I;VX@979E;B!I9B`\;F]F:6QL/B!I<PH@*B!S<&5C
M:69I960@:6X@=&AE('1E>'0L(&)U="!W92=R92!C;&]S92!A="!L96%S="X*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]E;G)I
M8VAE9"YP:'`L=B`Q+C(S+C$P+C8@,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!%<FEC(%)O<W1E='1E
M<B`\97)I8RYR;W-T971T97)`<&AY<VEC<RYU=&5X87,N961U/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@17)I8R!2;W-T971T97(@/&5R:6,N<F]S
M=&5T=&5R0'!H>7-I8W,N=71E>&%S+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@
M,BXQ"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-
M24U%7U9I97=E<E]E;G)I8VAE9"!E>'1E;F1S($U)345?5FEE=V5R('L*"B`@
M("`O*BH*("`@("`J(%)E;F1E<B!O=70@=&AE(&-U<G)E;G1L>2!S970@8V]N
M=&5N=',@:6X@2%1-3"!F;W)M870N(%1H90H@("`@("H@)&UI;65?<&%R="!C
M;&%S<R!V87)I86)L92!H87,@=&AE(&EN9F]R;6%T:6]N('1O(')E;F1E<B!O
M=70L"B`@("`@*B!E;F-A<'-U;&%T960@:6X@82!-24U%7U!A<G0@;V)J96-T
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H*0H@("`@>PH@("`@("`@
M(&EF("@H)'1E>'0@/2`D=&AI<RT^;6EM95]P87)T+3YG971#;VYT96YT<R@I
M*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@:68@*'1R:6TH)'1E>'0I(#T]("<G*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&5X=#L*("`@("`@("!]"@H@("`@("`@("\O(%=E
M(&%D9"!S<&%C92!A="!T:&4@8F5G:6YN:6YG(&%N9"!E;F0@;V8@=&AE('-T
M<FEN9R!A<R!I="!W:6QL"B`@("`@("`@+R\@;6%K92!S;VUE(')E9W5L87(@
M97AP<F5S<VEO;B!C:&5C:W,@;&%T97(@;75C:"!E87-I97(@*'-O('=E"B`@
M("`@("`@+R\@9&]N)W0@:&%V92!T;R!W;W)R>2!A8F]U="!S=&%R="]E;F0@
M;V8@;&EN92!C:&%R86-T97)S*0H@("`@("`@("1T97AT(#T@)R`G("X@)'1E
M>'0@+B`G("<["@H@("`@("`@("\O(%=E(&YE960@=&\@<')E<V5R=F4@/#P@
M=&%G<RP@<V\@;6%P('1H96T@=&\@87-C:6D@,2!O<B!A<V-I:2`R-34*("`@
M("`@("`O+R!792!M86ME('1H92!A<W-U;7!T:6]N(&AE<F4@=&AA="!T:&5R
M92!W;W5L9"!N979E<B!B92!A;B!A<V-I:0H@("`@("`@("\O(#$@:6X@86X@
M96UA:6PL('=H:6-H(&UA>2!N;W0@8F4@=F%L:60L(&)U="!S965M<R!R96%S
M;VYA8FQE+BXN"B`@("`@("`@+R\@87-C:6D@,C4U('=O=6QD('=O<FL@:68@
M9F]R('-O;64@<F5A<V]N('EO=2!D;VXG="!L:6ME(&%S8VEI(#$*("`@("`@
M("`O+R!A<V-I:2`P(&1O97,@3D]4('-E96T@=&\@=V]R:R!F;W(@=&AI<RP@
M=&AO=6=H($DG;2!N;W0@<W5R92!W:'D*("`@("`@("`D=&5X="`]('-T<E]R
M97!L86-E*"<\/"<L(&-H<B@Q*2P@)'1E>'0I.PH*("`@("`@("`O+R!296UO
M=F4@86YY('5N<F5C;V=N:7IE9"!T86=S(&EN('1H92!T97AT("AV:6$@4D9#
M(&UI;FEM86P@<W!E8W,I"B`@("`@("`@+R\@86YY('1A9W,@=V4@:G5S="!D
M;VXG="!W86YT('1O(&EM<&QE;65N="!C86X@86QS;R!B92!R96UO=F5D(&AE
M<F4*("`@("`@("`O+R!.;W1E('1H870@=&AI<R!W:6QL(')E;6]V92!A;GD@
M:'1M;"!L:6YK<RP@8G5T('1H:7,@:7,@:6YT96YD960*("`@("`@("`D:6UP
M;&5M96YT961486=S(#T@)SQP87)A;3X\8F]L9#X\:71A;&EC/CQU;F1E<FQI
M;F4^/&9I>&5D/CQE>&-E<G!T/B<@+@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G/'-M86QL97(^/&)I9V=E<CX\8V5N=&5R/CQC;VQO<CX\9F]N=&9A
M;6EL>3XG("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@)SQF;'5S:&QE
M9G0^/&9L=7-H<FEG:'0^/&9L=7-H8F]T:#X\<&%R86EN9&5N=#XG.PH@("`@
M("`@("\O("1U;DEM<&QE;65N=&5D5&%G<R`]("<\;F]F:6QL/CQL86YG/B<[
M"B`@("`@("`@)'1E>'0@/2!S=')I<%]T86=S*"1T97AT+"`D:6UP;&5M96YT
M961486=S*3L*"B`@("`@("`@+R\@<F5S=&]R92!T:&4@/#P@=&%G<R!A<R`\
M('1A9W,@;F]W+BXN"B`@("`@("`@)'1E>'0@/2!S=')?<F5P;&%C92AC:'(H
M,2DL("<\/"<L("1T97AT*3L*("`@("`@("`O+R`D=&5X="`]('-T<E]R97!L
M86-E*&-H<B@R-34I+"`G/"<L("1T97AT*3L*"B`@("`@("`@+R\@1V5T(&-O
M;&]R('!A<F%M971E<G,@:6YT;R!A(&UO<F4@=7-E86)L92!F;W)M870N"B`@
M("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\\8V]L;W(^/'!A<F%M/BA;
M7&1A+69!+49=*RDL*%M<9&$M9D$M1ETK*2PH6UQD82UF02U&72LI/%PO<&%R
M86T^+U5I<R<L("<\8V]L;W(@<CU<,2!G/5PR(&(]7#,^)RP@)'1E>'0I.PH@
M("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O/&-O;&]R/CQP87)A;3XH
M<F5D?&)L=65\9W)E96Y\>65L;&]W?&-Y86Y\;6%G96YT87QB;&%C:WQW:&ET
M92D\7"]P87)A;3XO56ES)RP@)SQC;VQO<B!N/5PQ/B<L("1T97AT*3L*"B`@
M("`@("`@+R\@1V5T(&9O;G0@9F%M:6QY('!A<F%M971E<G,@:6YT;R!A(&UO
M<F4@=7-E86)L92!F;W)M870N"B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA
M8V4H)R\\9F]N=&9A;6EL>3X\<&%R86T^*%QW*RD\7"]P87)A;3XO56ES)RP@
M)SQF;VYT9F%M:6QY(&8]7#$^)RP@)'1E>'0I.PH*("`@("`@("`O+R!*=7-T
M(')E;6]V92!A;GD@<F5M86EN:6YG('!A<F%M971E<G,@+2T@=V4@=V]N)W0@
M=7-E"B`@("`@("`@+R\@=&AE;2X@06YY('1A9W,@=VET:"!P87)A;65T97)S
M('1H870@=V4@=V%N="!T;R!I;7!L96UE;G0*("`@("`@("`O+R!W:6QL(&AA
M=F4@=&\@8V]M92!B969O<F4@=&AI<R!3;VUE9&%Y('=E(&AO<&4@=&\@=7-E
M('1H97-E"B`@("`@("`@+R\@=&%G<R`H92YG+B!F;W(@/&-O;&]R/CQP87)A
M;3X@=&%G<RD*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+SQP87)A
M;3XN*CQ<+W!A<F%M/B]5:7,G+"`G)RP@)'1E>'0I.PH*("`@("`@("`O+R!3
M:6YG;&4@;&EN92!B<F5A:W,@8F5C;VUE('-P86-E<RP@9&]U8FQE(&QI;F4@
M8G)E86MS(&%R92!A"B`@("`@("`@+R\@<F5A;"!B<F5A:RX@5&AI<R!N965D
M<R!T;R!D;R`\;F]F:6QL/B!T<F%C:VEN9R!T;R!B90H@("`@("`@("\O(&-O
M;7!L:6%N="!B=70@=V4@9&]N)W0@=V%N="!T;R!D96%L('=I=&@@<W1A=&4@
M870@=&AI<PH@("`@("`@("\O('1I;64L('-O('=E(&9A:V4@:70@<V]M92!D
M87D@=V4@<VAO=6QD(')E=W)I=&4@=&AI<R!T;PH@("`@("`@("\O(&AA;F1L
M92`\;F]F:6QL/B!C;W)R96-T;'DN"B`@("`@("`@)'1E>'0@/2!P<F5G7W)E
M<&QA8V4H)R\H6UY<;ETI7')<;BA;7EQR72DO)RP@)UPQ(%PR)RP@)'1E>'0I
M.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O*%QR7&XI7')<;B\G
M+"`G7#$G+"`D=&5X="D["@H@("`@("`@("\O(%=E('1R>2!T;R!P<F]T96-T
M(&%G86EN<W0@8F%D('-T=69F(&AE<F4N"B`@("`@("`@)'1E>'0@/2!`:'1M
M;'-P96-I86QC:&%R<R@D=&5X="P@14Y47U%53U1%4RP@)'1H:7,M/FUI;65?
M<&%R="T^9V5T0VAA<G-E="@I*3L*"B`@("`@("`@+R\@3F]W(&-O;G9E<G0@
M=&AE(&MN;W=N('1A9W,@=&\@:'1M;"X@5')Y('1O(')E;6]V92!A;GD@=&%G
M"B`@("`@("`@+R\@<&%R86UE=&5R<R!T;R!S=&]P('!E;W!L92!F<F]M('1R
M>6EN9R!T;R!P=6QL(&$@9F%S="!O;F4*("`@("`@("`D=&5X="`]('!R96=?
M<F5P;&%C92@G+R@_/"$F;'0[*29L=#MB;VQD+BHF9W0[*"XJ*29L=#M<+V)O
M;&0F9W0[+U5I<R<L("<\<W!A;B!S='EL93TB9F]N="UW96EG:'0Z(&)O;&0B
M/EPQ/"]S<&%N/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P
M;&%C92@G+R@_/"$F;'0[*29L=#MI=&%L:6,N*B9G=#LH+BHI)FQT.UPO:71A
M;&EC)F=T.R]5:7,G+"`G/'-P86X@<W1Y;&4](F9O;G0M<W1Y;&4Z(&ET86QI
M8R(^7#$\+W-P86X^)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R
M97!L86-E*"<O*#\\(29L=#LI)FQT.W5N9&5R;&EN92XJ)F=T.R@N*BDF;'0[
M7"]U;F1E<FQI;F4F9W0[+U5I<R<L("<\<W!A;B!S='EL93TB=&5X="UD96-O
M<F%T:6]N.B!U;F1E<FQI;F4B/EPQ/"]S<&%N/B<L("1T97AT*3L*("`@("`@
M("`D=&5X="`]('!R96=?<F5P;&%C95]C86QL8F%C:R@G+R@_/"$F;'0[*29L
M=#MC;VQO<B!R/2A;7&1A+69!+49=*RD@9STH6UQD82UF02U&72LI(&(]*%M<
M9&$M9D$M1ETK*29G=#LH+BHI)FQT.UPO8V]L;W(F9W0[+U5I<R<L(&%R<F%Y
M*"1T:&ES+"`G8V]L;W)I>F4G*2P@)'1E>'0I.PH@("`@("`@("1T97AT(#T@
M<')E9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.V-O;&]R(&X]*')E9'QB;'5E
M?&=R965N?'EE;&QO=WQC>6%N?&UA9V5N=&%\8FQA8VM\=VAI=&4I)F=T.R@N
M*BDF;'0[7"]C;VQO<B9G=#LO56ES)RP@)SQS<&%N('-T>6QE/2)C;VQO<CH@
M7#$B/EPR/"]S<&%N/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?
M<F5P;&%C92@G+R@_/"$F;'0[*29L=#MF;VYT9F%M:6QY)F=T.R@N*BDF;'0[
M7"]F;VYT9F%M:6QY)F=T.R]5:7,G+"`G7#$G+"`D=&5X="D["B`@("`@("`@
M)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[9F]N=&9A;6EL
M>2!F/2A<=RLI)F=T.R@N*BDF;'0[7"]F;VYT9F%M:6QY)F=T.R]5:7,G+"`G
M/'-P86X@<W1Y;&4](F9O;G0M9F%M:6QY.B!<,2(^7#(\+W-P86X^)RP@)'1E
M>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L=#LI
M)FQT.W-M86QL97(N*B9G=#LO56ES)RP@)SQS<&%N('-T>6QE/2)F;VYT+7-I
M>F4Z('-M86QL97(B/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?
M<F5P;&%C92@G+R@_/"$F;'0[*29L=#M<+W-M86QL97(F9W0[+U5I<R<L("<\
M+W-P86X^)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E
M*"<O*#\\(29L=#LI)FQT.V)I9V=E<BXJ)F=T.R]5:7,G+"`G/'-P86X@<W1Y
M;&4](F9O;G0M<VEZ93H@;&%R9V5R(CXG+"`D=&5X="D["B`@("`@("`@)'1E
M>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[7"]B:6=G97(F9W0[
M+U5I<R<L("<\+W-P86X^)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E
M9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.V9I>&5D+BHF9W0[*"XJ*29L=#M<
M+V9I>&5D)F=T.R]5:7,G+"`G/&9O;G0@9F%C93TB9FEX960B/EPQ/"]F;VYT
M/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_
M/"$F;'0[*29L=#MC96YT97(N*B9G=#LH+BHI)FQT.UPO8V5N=&5R)F=T.R]5
M:7,G+"`G/&1I=B!A;&EG;CTB8V5N=&5R(CY<,3PO9&EV/B<L("1T97AT*3L*
M("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F;'0[*29L=#MF
M;'5S:&QE9G0N*B9G=#LH+BHI)FQT.UPO9FQU<VAL969T)F=T.R]5:7,G+"`G
M/&1I=B!A;&EG;CTB;&5F="(^7#$\+V1I=CXG+"`D=&5X="D["B`@("`@("`@
M)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[9FQU<VAR:6=H
M="XJ)F=T.R@N*BDF;'0[7"]F;'5S:')I9VAT)F=T.R]5:7,G+"`G/&1I=B!A
M;&EG;CTB<FEG:'0B/EPQ/"]D:78^)RP@)'1E>'0I.PH@("`@("`@("1T97AT
M(#T@<')E9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.V9L=7-H8F]T:"XJ)F=T
M.R@N*BDF;'0[7"]F;'5S:&)O=&@F9W0[+U5I<R<L("<\9&EV(&%L:6=N/2)J
M=7-T:69Y(CY<,3PO9&EV/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R
M96=?<F5P;&%C92@G+R@_/"$F;'0[*29L=#MP87)A:6YD96YT+BHF9W0[*"XJ
M*29L=#M<+W!A<F%I;F1E;G0F9W0[+U5I<R<L("<\8FQO8VMQ=6]T93Y<,3PO
M8FQO8VMQ=6]T93XG+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E
M<&QA8V4H)R\H/SPA)FQT.RDF;'0[97AC97)P="XJ)F=T.R@N*BDF;'0[7"]E
M>&-E<G!T)F=T.R]5:7,G+"`G/&)L;V-K<75O=&4^7#$\+V)L;V-K<75O=&4^
M)RP@)'1E>'0I.PH*("`@("`@("`O+R!297!L86-E(#P\('=I=&@@/"!N;W<@
M*&9R;VT@=')A;G-L871E9"!(5$U,(&9O<FTI+@H@("`@("`@("1T97AT(#T@
M<W1R7W)E<&QA8V4H)R9L=#LF;'0[)RP@)R9L=#LG+"`D=&5X="D["@H@("`@
M("`@("\O($YO=R!W92!R96UO=F4@=&AE(&QE861I;F<O=')A:6QI;F<@<W!A
M8V4@=V4@861D960@870@=&AE"B`@("`@("`@+R\@<W1A<G0N"B`@("`@("`@
M)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R]>("@N*BD@)"]S)RP@)UPQ)RP@)'1E
M>'0I.PH*("`@("`@("`O+R!-86ME(%523',@8VQI8VMA8FQE+@H@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O5&5X="]&:6QT97(N<&AP)SL*("`@("`@
M("`D=&5X="`](%1E>'1?1FEL=&5R.CIF:6QT97(H)'1E>'0L("=L:6YK=7)L
M<R<L(&%R<F%Y*"=C86QL8F%C:R<@/3X@)TAO<F1E.CIE>'1E<FYA;%5R;"<I
M*3L*"B`@("`@("`@+R\@5V]R9'=R87`@+2T@;F]T92!T:&ES(&-O=6QD(&EM
M<&%C="!O;B!O=7(@86)O=F4@4D9#"B`@("`@("`@+R\@8V]M<&QI86YC92`J
M248J('=E(&AO;F]R960@;F]F:6QL('1A9W,@*'=H:6-H('=E(&1O;B=T"B`@
M("`@("`@+R\@>65T*2X*("`@("`@("`D=&5X="`]('-T<E]R97!L86-E*")<
M="(L("<@("`@("`@("<L("1T97AT*3L*("`@("`@("`D=&5X="`]('-T<E]R
M97!L86-E*"<@("<L("<@)FYB<W`[)RP@)'1E>'0I.PH@("`@("`@("1T97AT
M(#T@<W1R7W)E<&QA8V4H(EQN("(L(")<;B9N8G-P.R(L("1T97AT*3L*("`@
M("`@("!I9B`H)'1E>'1;,%T@/3T@)R`G*2!["B`@("`@("`@("`@("1T97AT
M(#T@)R9N8G-P.R<@+B!S=6)S='(H)'1E>'0L(#$I.PH@("`@("`@('T*("`@
M("`@("`D=&5X="`](&YL,F)R*"1T97AT*3L*("`@("`@("`D=&5X="`]("<\
M<"!C;&%S<STB9FEX960B/B<@+B`D=&5X="`N("<\+W`^)SL*"B`@("`@("`@
M<F5T=7)N("1T97AT.PH@("`@?0H*("`@(&9U;F-T:6]N(&-O;&]R:7IE*"1C
M;VQO<G,I"B`@("!["B`@("`@("`@9F]R("@D:2`](#$[("1I(#P@-#L@)&DK
M*RD@>PH@("`@("`@("`@("`D8V]L;W)S6R1I72`]('-P<FEN=&8H)R4P,E@G
M+"!R;W5N9"AH97AD96,H)&-O;&]R<ULD:5TI("\@,C4U*2D["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`G/'-P86X@<W1Y;&4](F-O;&]R.B`C)R`N("1C
M;VQO<G-;,5T@+B`D8V]L;W)S6S)=("X@)&-O;&]R<ULS72`N("<B/B<@+B`D
M8V]L;W)S6S1=("X@)SPO<W!A;CXG.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N('1H92!-24U%(&-O;G1E;G0@='EP92!O9B!T:&4@<F5N9&5R960@
M8V]N=&5N="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O
M;G1E;G0@='EP92!O9B!T:&4@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)W1E>'0O:'1M;#L@
M8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"D["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<```````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-S8U-0`Q,#4Q-30S,S<T-P`P,C0P,S4`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*"G)E<75I<F5?
M;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O<V]U<F-E+G!H<"<["@HO*BH*
M("H@5&AE($U)345?5FEE=V5R7V5N<V-R:7!T(&-L87-S(')E;F1E<G,@;W5T
M('9A<FEO=7,@8V]N=&5N=`H@*B!I;B!(5$U,(&9O<FUA="!B>2!U<VEN9R!'
M3E4@16YS8W)I<'0N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O96YS8W)I<'0N<&AP+'8@,2XS.2XQ,"XX(#(P,#8O,#8O,#$@
M,#,Z,#@Z-3,@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P
M-B!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`
M<F5C;VEL+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E
M($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]E;G-C
M<FEP="!E>'1E;F1S($U)345?5FEE=V5R7W-O=7)C92!["@H@("`@+RHJ"B`@
M("`@*B!296YD97(@;W5T('1H92!D871A('5S:6YG($5N<V-R:7!T+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@<&%R86UE=&5R
M<R!T:&4@5FEE=V5R(&UA>2!N965D+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@<F5N9&5R960@9&%T82X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5N9&5R*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&=L
M;V)A;"`D;6EM95]D<FEV97)S.PH*("`@("`@("`O*B!#:&5C:R!T;R!M86ME
M('-U<F4@=&AE('!R;V=R86T@86-T=6%L;'D@97AI<W1S+B`J+PH@("`@("`@
M(&EF("@A9FEL95]E>&ES=',H)&UI;65?9')I=F5R<ULG:&]R9&4G75LG96YS
M8W)I<'0G75LG;&]C871I;VXG72DI('L*("`@("`@("`@("`@<F5T=7)N("<\
M<')E/B<@+B!S<')I;G1F*%\H(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T
M:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E
M;2XB*2P@)&UI;65?9')I=F5R<ULG:&]R9&4G75LG96YS8W)I<'0G75LG;&]C
M871I;VXG72D@+B`G/"]P<F4^)SL*("`@("`@("!]"@H@("`@("`@("\J($-R
M96%T92!T96UP;W)A<GD@9FEL97,@9F]R(&EN<'5T('1O($5N<V-R:7!T+B!.
M;W1E('1H870@=V4*("`@("`@("`@("!C86YN;W0@=7-E(&$@<&EP92P@<VEN
M8V4@96YS8W)I<'0@;75S="!H879E(&%C8V5S<R!T;R!T:&4*("`@("`@("`@
M("!W:&]L92!F:6QE('1O(&1E=&5R;6EN92!I=',@='EP92!F;W(@8V]L;W5R
M960@<WEN=&%X"B`@("`@("`@("`@:&EG:&QI9VAT:6YG+B`J+PH@("`@("`@
M("1T;7!I;B`]($AO<F1E.CIG971496UP1FEL92@G16YS8W)I<'1);B<I.PH*
M("`@("`@("`O*B!7<FET92!T:&4@8V]N=&5N=',@;V8@;W5R(&)U9F9E<B!T
M;R!T:&4@=&5M<&]R87)Y(&EN<'5T(&9I;&4N("HO"B`@("`@("`@)&-O;G1E
M;G1S(#T@)'1H:7,M/FUI;65?<&%R="T^9V5T0V]N=&5N=',H*3L*("`@("`@
M("`D9F@@/2!F;W!E;B@D=&UP:6XL("=W8B<I.PH@("`@("`@(&9W<FET92@D
M9F@L("1C;VYT96YT<RP@<W1R;&5N*"1C;VYT96YT<RDI.PH@("`@("`@(&9C
M;&]S92@D9F@I.PH*("`@("`@("`O*B!%>&5C=71E('1H92!E;G-C<FEP="!C
M;VUM86YD+B`J+PH@("`@("`@("1L86YG(#T@97-C87!E<VAE;&QA<F<H)'1H
M:7,M/E]T>7!E5&],86YG*"1T:&ES+3YM:6UE7W!A<G0M/F=E=%1Y<&4H*2DI
M.PH@("`@("`@("1R97-U;'1S(#T@<VAE;&Q?97AE8R@D;6EM95]D<FEV97)S
M6R=H;W)D92==6R=E;G-C<FEP="==6R=L;V-A=&EO;B==("X@(B`M121L86YG
M("TM;&%N9W5A9V4]:'1M;"`M+6-O;&]R("TM;W5T<'5T/2T@/"`D=&UP:6XB
M*3L*"B`@("`@("`@+RH@4W1R:7`@;W5T('1H92!E>'1R86YE;W5S($A434P@
M9G)O;2!%;G-C<FEP="P@86YD(&]U='!U="!I="X@*B\*("`@("`@("`D<F5S
M7V%R<B`]('!R96=?<W!L:70H)R]</%PO/W!R95P^+VDG+"`D<F5S=6QT<RD[
M"B`@("`@("`@:68@*&-O=6YT*"1R97-?87)R*2`]/2`S*2!["B`@("`@("`@
M("`@("1R97-U;'1S(#T@=')I;2@D<F5S7V%R<ELQ72D["B`@("`@("`@?0H*
M("`@("`@("`O*B!%9'5C871E9"!'=65S<R!A="!W:&5T:&5R('=E(&%R92!I
M;FQI;F4@;W(@;F]T+B`J+PH@("`@("`@(&EF("AH96%D97)S7W-E;G0H*2!\
M?"!O8E]G971?;&5N9W1H*"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YL:6YE3G5M8F5R*"1R97-U;'1S*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@571I;#HZ8G5F9F5R3W5T<'5T*"=R97%U:7)E)RP@
M)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E
M)RD@+B`G+V-O;6UO;BUH96%D97(N:6YC)RD@+@H@("`@("`@("`@("`@("`@
M)'1H:7,M/FQI;F5.=6UB97(H)')E<W5L=',I("X*("`@("`@("`@("`@("`@
M(%5T:6PZ.F)U9F9E<D]U='!U="@G<F5Q=6ER92<L("1'3$]"04Q36R=R96=I
M<W1R>2==+3YG970H)W1E;7!L871E<R<L("=H;W)D92<I("X@)R]C;VUM;VXM
M9F]O=&5R+FEN8R<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($%T=&5M<'1S('1O(&1E=&5R;6EN92!W:&%T(&QA;F=U86=E('1O('5S92!F
M;W(@=&AE(&5N<V-R:7!T('!R;V=R86T*("`@("`J(&9R;VT@82!-24U%('1Y
M<&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D='EP92`@5&AE($U)344@='EP92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&5N<V-R:7!T("=L86YG=6%G
M92<@<&%R86UE=&5R('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W1Y
M<&54;TQA;F<H)'1Y<&4I"B`@("!["B`@("`@("`@:6YC;'5D95]O;F-E(&1I
M<FYA;64H7U]&24Q%7U\I("X@)R\N+B]-86=I8RYP:'`G.PH*("`@("`@("`D
M97AT(#T@34E-15]-86=I8SHZ34E-151O17AT*"1T>7!E*3L*"B`@("`@("`@
M<W=I=&-H("@D97AT*2!["B`@("`@("`@8V%S92`G8W,G.@H@("`@("`@("`@
M("!R971U<FX@)VIA=F$G.PH*("`@("`@("!C87-E("=E;"<Z"B`@("`@("`@
M("`@(')E='5R;B`G96QI<W`G.PH*("`@("`@("!C87-E("=H)SH*("`@("`@
M("`@("`@<F5T=7)N("=C)SL*"B`@("`@("`@8V%S92`G0R<Z"B`@("`@("`@
M8V%S92`G2"<Z"B`@("`@("`@8V%S92`G8V,G.@H@("`@("`@(&-A<V4@)VAH
M)SH*("`@("`@("!C87-E("=C*RLG.@H@("`@("`@(&-A<V4@)V-X>"<Z"B`@
M("`@("`@8V%S92`G8W!P)SH*("`@("`@("`@("`@<F5T=7)N("=C<'`G.PH*
M("`@("`@("!C87-E("=H=&TG.@H@("`@("`@(&-A<V4@)W-H=&UL)SH*("`@
M("`@("!C87-E("=X;6PG.@H@("`@("`@("`@("!R971U<FX@)VAT;6PG.PH*
M("`@("`@("!C87-E("=J<R<Z"B`@("`@("`@("`@(')E='5R;B`G:F%V87-C
M<FEP="<["@H@("`@("`@(&-A<V4@)W!A<R<Z"B`@("`@("`@("`@(')E='5R
M;B`G<&%S8V%L)SL*"B`@("`@("`@8V%S92`G86PG.@H@("`@("`@(&-A<V4@
M)V-G:2<Z"B`@("`@("`@8V%S92`G<&PG.@H@("`@("`@(&-A<V4@)W!M)SH*
M("`@("`@("`@("`@<F5T=7)N("=P97)L)SL*"B`@("`@("`@8V%S92`G<',G
M.@H@("`@("`@("`@("!R971U<FX@)W!O<W1S8W)I<'0G.PH*("`@("`@("!C
M87-E("=V8B<Z"B`@("`@("`@("`@(')E='5R;B`G=F)A)SL*"B`@("`@("`@
M8V%S92`G=FAD)SH*("`@("`@("`@("`@<F5T=7)N("=V:&1L)SL*"B`@("`@
M("`@8V%S92`G<&%T8V@G.@H@("`@("`@(&-A<V4@)V1I9F8G.@H@("`@("`@
M("`@("!R971U<FX@)V1I9F9U)SL*"B`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@<F5T=7)N("1E>'0["B`@("`@("`@?0H@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+VAT;6PN<&AP````
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-#4Q,0`Q,#4Q-30S,S<T-P`P
M,C,Q,S<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]H=&UL(&-L87-S(')E
M;F1E<G,@;W5T($A434P@=&5X="!W:71H(&%N(&5F9F]R="!T;PH@*B!R96UO
M=F4@<&]T96YT:6%L;'D@;6%L:6-I;W5S(&-O9&4N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`L=B`Q+C$T+C0N
M,C`@,C`P-B\P-B\P-R`Q,SHS-#HQ-B!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#$Y.3DM,C`P-B!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN
M;W)G/@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H
M;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E;"!3;'5S
M87)Z(#QS;'5S87)Z0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+V=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`
M875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!`875T:&]R
M("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`:&]R9&4N;W)G/@H@*B!`<VEN
M8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W97(*
M("HO"F-L87-S($U)345?5FEE=V5R7VAT;6P@97AT96YD<R!-24U%7U9I97=E
M<B!["@H@("`@+RHJ"B`@("`@*B!296YD97(@;W5T('1H92!C=7)R96YT;'D@
M<V5T(&-O;G1E;G1S+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("!!;GD@<&%R86UE=&5R<R!T:&4@=FEE=V5R(&UA>2!N965D+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5N9&5R960@=&5X="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,@/2!N=6QL*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V-L96%N2%1-3"@D=&AI<RT^
M;6EM95]P87)T+3YG971#;VYT96YT<R@I*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($9I;'1E<G,@86-T:79E(&-O;G1E;G0L(&1E<F5F97)E;F-E<R!E>'1E
M<FYA;"!L:6YK<RP@9&5T96-T<R!P:&ES:&EN9RP*("`@("`J(&5T8RX*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1D871A("!4:&4@2%1-3"!D871A+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@8VQE86YE9"!(5$U,(&1A=&$N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]C;&5A;DA434PH)&1A=&$I"B`@("!["B`@("`@
M("`@9VQO8F%L("1B<F]W<V5R+"`D<')E9G,["@H@("`@("`@("1P:&ES:%]W
M87)N(#T@9F%L<V4["@H@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-
M12]#;VYT96YT<RYP:'`G.PH@("`@("`@("1A='1A8VAM96YT(#T@34E-15]#
M;VYT96YT<SHZ=FEE=T%S071T86-H;65N="@I.PH*("`@("`@("`O*B!$96%L
M('=I=&@@/&)A<V4^('1A9W,@:6X@=&AE($A434PL('-I;F-E('1H97D@=VEL
M;"!S8W)E=R!U<"!O=7(@;W=N"B`@("`@("`@("H@<F5L871I=F4@<&%T:',N
M("HO"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R\\8F%S92!H<F5F/2(_*%M>
M(CX@72HI(C\@/UPO/SXO:2<L("1D871A+"`D;6%T8VAE<RDI('L*("`@("`@
M("`@("`@)&)A<V4@/2`D;6%T8VAE<ULQ73L*("`@("`@("`@("`@:68@*'-U
M8G-T<B@D8F%S92P@+3$L(#$I("$]("<O)RD@>PH@("`@("`@("`@("`@("`@
M)&)A<V4@+CT@)R\G.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!2
M96-U<G-I=F5L>2!C86QL(%]C;&5A;DA434PH*2!T;R!P<F5V96YT(&-L979E
M<B!F:65N9',@9G)O;0H@("`@("`@("`@("`@*B!S;F5A:VEN9R!N87-T>2!T
M:&EN9W,@:6YT;R!T:&4@<&%G92!V:6$@)&)A<V4N("HO"B`@("`@("`@("`@
M("1B87-E(#T@)'1H:7,M/E]C;&5A;DA434PH)&)A<V4I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@071T96UP="!T;R!F:7@@<&%T:',@=&AA="!W97)E(')E
M;'EI;F<@;VX@82`\8F%S93X@=&%G+B`J+PH@("`@("`@(&EF("@A96UP='DH
M)&)A<V4I*2!["B`@("`@("`@("`@("1P871T97)N(#T@87)R87DH)WQS<F,]
M*%LB7"==*2A;7CHB7"==*RE<,7QI)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G?'-R8STH6UXZ(#XB7"==*RE\:2<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)WQH<F5F/2`J*%LB7"==*2A;7CHB7"==*RE<,7QI
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G?&AR968]*%M>.B`^
M(EPG72LI?&DG*3L*("`@("`@("`@("`@)')E<&QA8V4@/2!A<G)A>2@G<W)C
M/5PQ)R`N("1B87-E("X@)UPR7#$G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=S<F,])R`N("1B87-E("X@)UPQ)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G:')E9CU<,2<@+B`D8F%S92`N("=<,EPQ)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G:')E9CTG("X@)&)A<V4@+B`G
M7#$G*3L*("`@("`@("`@("`@)&1A=&$@/2!P<F5G7W)E<&QA8V4H)'!A='1E
M<FXL("1R97!L86-E+"`D9&%T82D["B`@("`@("`@?0H*("`@("`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+U1E>'0O1FEL=&5R+G!H<"<["B`@("`@("`@)'-T
M<FEP7W-T>6QE<R`]("$D871T86-H;65N="!\?`H@("`@("`@("`@("`H)&)R
M;W=S97(M/FES0G)O=W-E<B@G;6]Z:6QL82<I("8F"B`@("`@("`@("`@("`D
M8G)O=W-E<BT^9V5T36%J;W(H*2`]/2`T*2!\?`H@("`@("`@("`@("`D8G)O
M=W-E<BT^:7-"<F]W<V5R*"=M<VEE)RD["B`@("`@("`@)&1A=&$@/2!497AT
M7T9I;'1E<CHZ9FEL=&5R*"1D871A+"`G>'-S)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)V)O9'E?;VYL>2<@/3X@(21A
M='1A8VAM96YT+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<W1R:7!?<W1Y;&5S)R`]/B`D<W1R:7!?<W1Y;&5S*2D["@H@
M("`@("`@("\J($-H96-K(&9O<B!P:&ES:&EN9R!E>'!L;VET<RX@*B\*("`@
M("`@("!I9B`H<')E9U]M871C:"@G+VAR969<<RH]7',J6R)<)UT_7',J*&AT
M='!\:'1T<'-\9G1P*3I<+UPO7&1[,2PS?5PN7&1[,2PS?5PN7&1[,2PS?5PN
M7&1[,2PS?2]I)RP@)&1A=&$I*2!["B`@("`@("`@("`@("\J($-H96-K(#$Z
M($-H96-K(&9O<B!)4"!A9&1R97-S(&QI;FMS+B`J+PH@("`@("`@("`@("`D
M<&AI<VA?=V%R;B`]('1R=64["B`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T
M8VA?86QL*"<O:')E9EQS*CU<<RI;(EPG73]<<RHH/SIH='1P?&AT='!S?&9T
M<"DZ7"]<+RA;7EQS(EPG/ETK*5LB7"==/UM>/ETJ/EQS*B@_.B@_.FAT='!\
M:'1T<'-\9G1P*3I<+UPO*3\H+BH_*3Q<+V$O:7,G+"`D9&%T82P@)&TI*2![
M"B`@("`@("`@("`@("\J("1M6S%=(#T@3&EN:SL@)&U;,ET@/2!487)G970*
M("`@("`@("`@("`@("H@0VAE8VL@,CH@0VAE8VL@9F]R(&QI;FMS('1H870@
M<&]I;G0@=&\@82!D:69F97)E;G0@:&]S="!T:&%N"B`@("`@("`@("`@("`J
M('1H92!T87)G970@=7)L.R!I9B!T87)G970@;&]O:W,@;&EK92!A(&1O;6%I
M;B!N86UE+"!C:&5C:R!I=`H@("`@("`@("`@("`@*B!A9V%I;G-T('1H92!L
M:6YK+B`J+PH@("`@("`@("`@("`D;&EN:W,@/2!C;W5N="@D;5LP72D["B`@
M("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1L:6YK<SL@)&DK*RD@>PH@
M("`@("`@("`@("`@("`@)&U;,5U;)&E=(#T@<W1R=&]L;W=E<BAU<FQD96-O
M9&4H)&U;,5U;)&E=*2D["B`@("`@("`@("`@("`@("`D;5LR75LD:5T@/2!S
M=')T;VQO=V5R*'!R96=?<F5P;&%C92@G+UXH:'1T<'QH='1P<WQF='`I.EPO
M7"\O)RP@)R<L('-T<FEP7W1A9W,H)&U;,EU;)&E=*2DI.PH@("`@("`@("`@
M("`@("`@:68@*'!R96=?;6%T8V@H)R]>6RTN7UQD82UZ72M<+EMA+7I=>S(L
M?2]I)RP@)&U;,EU;)&E=*2`F)@H@("`@("`@("`@("`@("`@("`@('-T<G!O
M<R@D;5LQ75LD:5TL("1M6S)=6R1I72D@(3T](#`@)B8*("`@("`@("`@("`@
M("`@("`@("!S=')P;W,H)&U;,EU;)&E=+"`D;5LQ75LD:5TI("$]/2`P*2![
M"B`@("`@("`@("`@("`@("`@("`@+RH@1&]N)W0@8V]N<VED97(@=&AE(&QI
M;FL@82!P:&ES:&EN9R!L:6YK(&EF('1H92!D;VUA:6X*("`@("`@("`@("`@
M("`@("`@("`@*B!I<R!T:&4@<V%M92!O;B!B;W1H(&QI;FMS("AE+F<N(&%D
M=')A8VMI;F<N97AA;7!L92YC;VT*("`@("`@("`@("`@("`@("`@("`@*B`F
M('=W=RYE>&%M<&QE+F-O;2DN("HO"B`@("`@("`@("`@("`@("`@("`@<')E
M9U]M871C:"@G+UPN/RA;7EPN7"]=*UPN6UY<+EPO72LI7"\O)RP@)&U;,5U;
M)&E=+"`D:&]S=#$I.PH@("`@("`@("`@("`@("`@("`@('!R96=?;6%T8V@H
M)R]<+C\H6UY<+EPO72M<+EM>7"Y<+UTK*2A<+RXJ*3\D+R<L("1M6S)=6R1I
M72P@)&AO<W0R*3L*("`@("`@("`@("`@("`@("`@("!I9B`H(2AC;W5N="@D
M:&]S=#$I("8F(&-O=6YT*"1H;W-T,BDI('Q\"B`@("`@("`@("`@("`@("`@
M("`@("`@('-T<F-A<V5C;7`H)&AO<W0Q6S%=+"`D:&]S=#);,5TI("$]/2`P
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1P:&ES:%]W87)N(#T@=')U
M93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%1R>2!T;R!D97)E
M9F5R(&%L;"!E>'1E<FYA;"!R969E<F5N8V5S+B`J+PH@("`@("`@("1D871A
M(#T@<')E9U]R97!L86-E7V-A;&QB86-K*"<O:')E9EQS*CU<<RHH6R)<)UTI
M/R@H/R@Q*5M>7#%=*C]\6UY<<SY=*RDI*#\H,2E<,7PI+VDG+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-R96%T95]F=6YC=&EO
M;B@G)&TG+"`G<F5T=7)N(%PG:')E9CTB7"<@+B`H<W1R;&5N*"1M6S)=*2`F
M)B`D;5LR77LP?2`]/2!<)R-<)R`_("1M6S)=(#H@2&]R9&4Z.F5X=&5R;F%L
M57)L*"1M6S)=*2D@+B!<)R)<)SLG*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9&%T82D["@H@("`@("`@("\J(%!R97!E;F0@
M<&AI<VAI;F<@=V%R;FEN9RX@*B\*("`@("`@("!I9B`H)'!H:7-H7W=A<FXI
M('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+T-O;G1E
M;G1S+G!H<"<["B`@("`@("`@("`@("1C;VYT96YT<R`]("9N97<@34E-15]#
M;VYT96YT<RAN97<@34E-15]087)T*"DI.PH@("`@("`@("`@("`D<&AI<VA?
M=V%R;FEN9R`]('-P<FEN=&8H7R@B)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T
M(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL
M;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N
M9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(I+"!?*")787)N
M:6YG(BDI.PH@("`@("`@("`@("!I9B`H)&-O;G1E;G1S+3YV:65W07-!='1A
M8VAM96YT*"DI('L*("`@("`@("`@("`@("`@("1P:&ES:%]W87)N:6YG(#T@
M)SQS<&%N('-T>6QE/2)B86-K9W)O=6YD+6-O;&]R.B-F9F0P868[8V]L;W(Z
M8FQA8VLB/B<@+B!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1P:&ES:%]W87)N
M:6YG+"!.3%,Z.F=E=$-H87)S970H*2P@)'1H:7,M/FUI;65?<&%R="T^9V5T
M0VAA<G-E="@I*2`N("<\+W-P86X^/&)R("\^)SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D<&AI<VA?=V%R;FEN9R`]("1C;VYT96YT<RT^9F]R;6%T
M4W1A='5S37-G*"1P:&ES:%]W87)N:6YG+"!N=6QL+"!T<G5E+"`G;6EM95-T
M871U<U=A<FYI;F<G*3L*("`@("`@("`@("`@:68@*'-T<FES='(H)&1A=&$L
M("<\8F]D>2<I(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)&1A=&$@
M/2`D<&AI<VA?=V%R;FEN9R`N("1D871A.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)&1A=&$@/2!P<F5G7W)E<&QA8V4H)R\H+BH\
M8F]D>2XJ/SXI*"XJ*2]I)RP@)R0Q)R`N("1P:&ES:%]W87)N:6YG("X@)R0R
M)RP@)&1A=&$I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE
M(&-O;G1E;G0M='EP92!O9B!T:&4@<F5N9&5R960@=&5X="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($U)344@0V]N=&5N="U4>7!E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+TU)344O0V]N=&5N=',N<&AP)SL*("`@("`@
M("!R971U<FX@34E-15]#;VYT96YT<SHZ=FEE=T%S071T86-H;65N="@I(#\@
M)'1H:7,M/FUI;65?<&%R="T^9V5T5'EP92AT<G5E*2`Z("=T97AT+VAT;6P[
M(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E
M<B]I;6%G97,N<&AP````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8V,3$`
M,3`U,34T,S,W-#<`,#(S-#0R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!4:&4@34E-15]6:65W97)?
M:6UA9V5S(&-L87-S(&%L;&]W<R!I;6%G97,@=&\@8F4@9&ES<&QA>65D+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E
M<RYP:'`L=B`Q+C$X+C@N.2`R,#`V+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@4VQU<V%R>B`\
M<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M
M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,BXR"B`J($!P86-K
M86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]I
M;6%G97,@97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@("`@*B!2
M971U<FX@=&AE(&-O;G1E;G0M='EP92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE(&-O;G1E;G0M='EP92!O9B!T:&4@;W5T<'5T+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("`D='EP
M92`]("1T:&ES+3YM:6UE7W!A<G0M/F=E=%1Y<&4H*3L*("`@("`@("!I9B`H
M)$=,3T)!3%-;)V)R;W=S97(G72T^:7-"<F]W<V5R*"=M;WII;&QA)RD@)B8*
M("`@("`@("`@("`@*"1T>7!E(#T]("=I;6%G92]P:G!E9R<I*2!["B`@("`@
M("`@("`@("\J(&EM86=E+VIP96<@86YD(&EM86=E+W!J<&5G("IA<'!E87(J
M('1O(&)E('1H92!S86UE"B`@("`@("`@("`@("`J(&5N=&ET>2P@8G5T($UO
M>FEL;&$@9&]N)W0@<V5E;2!T;R!W86YT('1O(&%C8V5P="!T:&4*("`@("`@
M("`@("`@("H@;&%T=&5R+B`@1F]R(&]U<B!P=7)P;W-E<RP@=V4@=VEL;"!T
M<F5A="!T:&5M('1H90H@("`@("`@("`@("`@*B!S86UE+B`J+PH@("`@("`@
M("`@("!R971U<FX@)VEM86=E+VIP96<G.PH@("`@("`@('T@96QS96EF("@D
M='EP92`]/2`G:6UA9V4O>"UP;F<G*2!["B`@("`@("`@("`@("\J(&EM86=E
M+W@M<&YG(&ES(&5Q=6EV86QE;G0@=&\@:6UA9V4O<&YG+B`J+PH@("`@("`@
M("`@("!R971U<FX@)VEM86=E+W!N9R<["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N("1T>7!E.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($=E;F5R871E($A434P@;W5T<'5T(&9O<B!A(&IA=F%S8W)I
M<'0@875T;RUR97-I>F4@=FEE=R!W:6YD;W<N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7)L
M("`@(%1H92!54DP@=VAI8V@@8V]N=&%I;G,@=&AE(&%C='5A;"!I;6%G92!D
M871A+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&ET;&4@(%1H92!T:71L92!T
M;R!U<V4@9F]R('1H92!P86=E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@2%1-3"!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P
M;W!U<$EM86=E5VEN9&]W*"1U<FPL("1T:71L92D*("`@('L*("`@("`@("!G
M;&]B86P@)&)R;W=S97(["@H@("`@("`@("1S='(@/2`\/#Q%3T0*/&AT;6P^
M"CQH96%D/@H\=&ET;&4^)'1I=&QE/"]T:71L93X*/'-T>6QE('1Y<&4](G1E
M>'0O8W-S(CX\(2TM(&)O9'D@>R!M87)G:6XZ,'!X.R!P861D:6YG.C!P>#L@
M?2`M+3X\+W-T>6QE/@I%3T0["@H@("`@("`@("\J($]N;'D@=7-E(&IA=F%S
M8W)I<'0@:68@=V4@87)E('5S:6YG(&$@1$]-(&-A<&%B;&4@8G)O=W-E<BX@
M*B\*("`@("`@("!I9B`H)&)R;W=S97(M/F=E=$9E871U<F4H)V1O;2<I*2![
M"B`@("`@("`@("`@("\J(%1R86YS;&%T92`G)F%M<"<@96YT:71I97,@=&\@
M)R8G(&9O<B!*4R!54DP@;&EN:W,N("HO"B`@("`@("`@("`@("1U<FP@/2!S
M=')?<F5P;&%C92@G)F%M<#LG+"`G)B<L("1U<FPI.PH*("`@("`@("`@("`@
M+RH@36]Z:6QL82!A;F0@244@9&5T97)M:6YE('=I;F1O=R!D:6UE;G-I;VYS
M(&EN(&1I9F9E<F5N="!W87ES+B`J+PH@("`@("`@("`@("!I9B`H)&)R;W=S
M97(M/FES0G)O=W-E<B@G;7-I92<I*2!["B`@("`@("`@("`@("`@("`D:5=I
M9'1H7V-O9&4@/2`G9&]C=6UE;G0N8F]D>2YC;&EE;G17:61T:#LG.PH@("`@
M("`@("`@("`@("`@)&E(96EG:'1?8V]D92`]("=D;V-U;65N="YB;V1Y+F-L
M:65N=$AE:6=H=#LG.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)&E7:61T:%]C;V1E(#T@)W=I;F1O=RYI;FYE<E=I9'1H.R<["B`@
M("`@("`@("`@("`@("`D:4AE:6=H=%]C;V1E(#T@)W=I;F1O=RYI;FYE<DAE
M:6=H=#LG.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!*879A<V-R
M:7!T(&1I<W!L87DN("HO"B`@("`@("`@("`@("1L;V%D:6YG(#T@7R@B3&]A
M9&EN9RXN+B(I.PH@("`@("`@("`@("`D<W1R("X](#P\/$5/1`H\<V-R:7!T
M('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"F9U;F-T:6]N(')E<VEZ95=I;F1O
M=R@I('L*("`@('=I;F1O=RYM;W9E5&\H,"P@,"D["B`@("!D;V-U;65N="YG
M971%;&5M96YT0GE)9"@G<W!L87-H)RDN<W1Y;&4N9&ES<&QA>2`]("=N;VYE
M)SL*("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=D:7-P7VEM86=E)RDN
M<W1Y;&4N9&ES<&QA>2`]("=B;&]C:R<["B`@("!V87(@:5=I9'1H(#T@9&]C
M=6UE;G0N:6UA9V5S6S!=+G=I9'1H("T@)&E7:61T:%]C;V1E"B`@("!V87(@
M:4AE:6=H="`](&1O8W5M96YT+FEM86=E<ULP72YH96EG:'0@+2`D:4AE:6=H
M=%]C;V1E"B`@("!W:6YD;W<N<F5S:7IE0GDH:5=I9'1H+"!I2&5I9VAT*3L*
M("`@('-E;&8N9F]C=7,H*3L@"GT*/"]S8W)I<'0^/"]H96%D/@H\8F]D>2!O
M;FQO860](G)E<VEZ95=I;F1O=R@I.R(^/'-P86X@:60](G-P;&%S:"(@<W1Y
M;&4](F-O;&]R.F=R87D[9F]N="UF86UI;'DZ<V%N<RUS97)I9CMP861D:6YG
M.C)P>#LB/B1L;V%D:6YG/"]S<&%N/CQI;6<@:60](F1I<W!?:6UA9V4B('-T
M>6QE/2)D:7-P;&%Y.FYO;F4[(B!S<F,](B1U<FPB("\^/"]B;V1Y/CPO:'1M
M;#X*14]$.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J($YO;BUJ
M879A<V-R:7!T(&1I<W!L87DN("HO"B`@("`@("`@("`@("1I;6=?='AT(#T@
M7R@B26UA9V4B*3L*("`@("`@("`@("`@)'-T<B`N/2`\/#Q%3T0*/"]H96%D
M/@H\8F]D>2!B9V-O;&]R/2(C9F9F9F9F(B!T;W!M87)G:6X](C`B(&UA<F=I
M;FAE:6=H=#TB,"(@;&5F=&UA<F=I;CTB,"(@;6%R9VEN=VED=&@](C`B/@H\
M:6UG(&)O<F1E<CTB,"(@<W)C/2(D=7)L(B!A;'0](B1I;6=?='AT(B`O/@H\
M+V)O9'D^"CPO:'1M;#X*14]$.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1S='(["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W
M97(O;7-E>&-E;"YP:'``````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-#0P
M`#$P-3$U-#,S-S0W`#`R,S8S,@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@5&AE($U)345?5FEE=V5R
M7VUS97AC96P@8VQA<W,@<F5N9&5R<R!O=70@36EC<F]S;V9T($5X8V5L"B`J
M(&1O8W5M96YT<R!I;B!(5$U,(&9O<FUA="!B>2!U<VEN9R!T:&4@>&Q(=&UL
M('!A8VMA9V4N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O;7-E>&-E;"YP:'`L=B`Q+C(P+C$P+C<@,C`P-B\P,2\P,2`R,3HR
M.#HR-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!!;FEL
M($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL
M+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E
M7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]M<V5X8V5L(&5X
M=&5N9',@34E-15]6:65W97(@>PH*("`@("\J*@H@("`@("H@4F5N9&5R(&]U
M="!T:&4@8W5R<F5N=&QY(&1A=&$@=7-I;F<@>&QH=&UL+@H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@<&%R86US('1H:7,@5FEE
M=V5R(&UA>2!N965D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@<F5N9&5R960@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R
M*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&=L;V)A;"`D;6EM
M95]D<FEV97)S.PH*("`@("`@("`O*B!#:&5C:R!T;R!M86ME('-U<F4@=&AE
M('!R;V=R86T@86-T=6%L;'D@97AI<W1S+B`J+PH@("`@("`@(&EF("@A9FEL
M95]E>&ES=',H)&UI;65?9')I=F5R<ULG:&]R9&4G75LG;7-E>&-E;"==6R=L
M;V-A=&EO;B==*2D@>PH@("`@("`@("`@("!R971U<FX@)SQP<F4^)R`N('-P
M<FEN=&8H7R@B5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T
M>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(I+"`D;6EM
M95]D<FEV97)S6R=H;W)D92==6R=M<V5X8V5L)UU;)VQO8V%T:6]N)UTI("X@
M)SPO<')E/B<["B`@("`@("`@?0H*("`@("`@("`D9&%T82`]("<G.PH@("`@
M("`@("1T;7!?>&QS(#T@2&]R9&4Z.F=E=%1E;7!&:6QE*"=H;W)D95]M<V5X
M8V5L)RD["@H@("`@("`@("1F:"`](&9O<&5N*"1T;7!?>&QS+"`G=R<I.PH@
M("`@("`@(&9W<FET92@D9F@L("1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E
M;G1S*"DI.PH@("`@("`@(&9C;&]S92@D9F@I.PH*("`@("`@("`D9F@@/2!P
M;W!E;B@D;6EM95]D<FEV97)S6R=H;W)D92==6R=M<V5X8V5L)UU;)VQO8V%T
M:6]N)UT@+B`B("UN:"`D=&UP7WAL<R`R/B8Q(BP@)W(G*3L*("`@("`@("!W
M:&EL92`H*"1R8R`](&9G971S*"1F:"P@.#$Y,BDI*2!["B`@("`@("`@("`@
M("1D871A("X]("1R8SL*("`@("`@("!]"B`@("`@("`@<&-L;W-E*"1F:"D[
M"@H@("`@("`@(')E='5R;B`D9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;B!T:&4@34E-12!C;VYT96YT('1Y<&4@;V8@=&AE(')E;F1E<F5D
M(&-O;G1E;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C
M;VYT96YT('1Y<&4@;V8@=&AE(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=T97AT+VAT;6P[
M(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS
M<&]W97)P;VEN="YP:'``````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S4Q,@`Q,#4Q
M-30S,S<T-P`P,C0W-#``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]M<W!O
M=V5R<&]I;G0@8VQA<W,@<F5N9&5R<R!O=70@36EC<F]S;V9T(%!O=V5R<&]I
M;G0*("H@9&]C=6UE;G1S(&EN($A434P@9F]R;6%T(&)Y('5S:6YG('1H92!X
M;$AT;6P@<&%C:V%G92X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP+'8@,2XQ,RXQ,"XW(#(P,#8O
M,#$O,#$@,C$Z,C@Z,C4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY
M+3(P,#8@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA
M;FEL0')E8V]I;"YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C
M:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6:65W97)?
M;7-P;W=E<G!O:6YT(&5X=&5N9',@34E-15]6:65W97(@>PH*("`@("\J*@H@
M("`@("H@4F5N9&5R(&]U="!T:&4@8W5R<F5N="!D871A('5S:6YG('!P=&AT
M;6PN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N>2!P
M87)A;65T97)S('1H92!6:65W97(@;6%Y(&YE960N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!C;VYT96YT<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D;6EM95]D<FEV97)S.PH*("`@("`@("`O*B!#
M:&5C:R!T;R!M86ME('-U<F4@=&AE('!R;V=R86T@86-T=6%L;'D@97AI<W1S
M+B`J+PH@("`@("`@(&EF("@A9FEL95]E>&ES=',H)&UI;65?9')I=F5R<ULG
M:&]R9&4G75LG;7-P;W=E<G!O:6YT)UU;)VQO8V%T:6]N)UTI*2!["B`@("`@
M("`@("`@(')E='5R;B`G/'!R93XG("X@<W!R:6YT9BA?*")4:&4@<')O9W)A
M;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O
M=6YD(&]N('1H92!S>7-T96TN(BDL("1M:6UE7V1R:79E<G-;)VAO<F1E)UU;
M)VUS<&]W97)P;VEN="==6R=L;V-A=&EO;B==*2`N("<\+W!R93XG.PH@("`@
M("`@('T*"B`@("`@("`@)&1A=&$@/2`G)SL*("`@("`@("`D=&UP7W!P="`]
M($AO<F1E.CIG971496UP1FEL92@G:&]R9&5?;7-P;W=E<G!O:6YT)RD["@H@
M("`@("`@("1F:"`](&9O<&5N*"1T;7!?<'!T+"`G=R<I.PH@("`@("`@(&9W
M<FET92@D9F@L("1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"DI.PH@
M("`@("`@(&9C;&]S92@D9F@I.PH*("`@("`@("`D9F@@/2!P;W!E;B@D;6EM
M95]D<FEV97)S6R=H;W)D92==6R=M<W!O=V5R<&]I;G0G75LG;&]C871I;VXG
M72`N("(@)'1M<%]P<'0@,CXF,2(L("=R)RD["B`@("`@("`@=VAI;&4@*"@D
M<F,@/2!F9V5T<R@D9F@L(#@Q.3(I*2D@>PH@("`@("`@("`@("`D9&%T82`N
M/2`D<F,["B`@("`@("`@?0H@("`@("`@('!C;&]S92@D9F@I.PH*("`@("`@
M("!R971U<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@
M=&AE($U)344@8V]N=&5N="!T>7!E(&]F('1H92!R96YD97)E9"!C;VYT96YT
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]N=&5N="!T
M>7!E(&]F('1H92!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y
M<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G=&5X="]H=&UL.R!C:&%R<V5T
M/2<@+B!.3%,Z.F=E=$-H87)S970H*3L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]M<W=O<F0N
M<&AP````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4Q,C0`,3`U,34T,S,W
M-#<`,#(S-3`V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&4@34E-15]6:65W97)?;7-W;W)D(&-L
M87-S(')E;F1E<G,@;W5T($UI8W)O<V]F="!7;W)D"B`J(&1O8W5M96YT<R!I
M;B!(5$U,(&9O<FUA="!B>2!U<VEN9R!T:&4@=W9787)E('!A8VMA9V4N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D
M+G!H<"QV(#$N,C4N,3`N."`R,#`V+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($%N:6P@36%D:&%V87!E9&1Y
M(#QA;FEL0')E8V]I;"YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`<VEN
M8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W97(*
M("HO"F-L87-S($U)345?5FEE=V5R7VUS=V]R9"!E>'1E;F1S($U)345?5FEE
M=V5R('L*"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@=&AE(&-U<G)E;G0@
M9&%T82!U<VEN9R!W=E=A<F4N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@($%N>2!P87)A;65T97)S('1H92!6:65W97(@;6%Y(&YE960N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!C
M;VYT96YT<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&=L;V)A;"`D;6EM95]D<FEV97)S
M.PH*("`@("`@("`O*B!#:&5C:R!T;R!M86ME('-U<F4@=&AE('!R;V=R86T@
M86-T=6%L;'D@97AI<W1S+B`J+PH@("`@("`@(&EF("@A9FEL95]E>&ES=',H
M)&UI;65?9')I=F5R<ULG:&]R9&4G75LG;7-W;W)D)UU;)VQO8V%T:6]N)UTI
M*2!["B`@("`@("`@("`@(')E='5R;B`G/'!R93XG("X@<W!R:6YT9BA?*")4
M:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W
M87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(BDL("1M:6UE7V1R:79E<G-;
M)VAO<F1E)UU;)VUS=V]R9"==6R=L;V-A=&EO;B==*2`N("<\+W!R93XG.PH@
M("`@("`@('T*"B`@("`@("`@)&1A=&$@/2`G)SL*("`@("`@("`D=&UP7W=O
M<F0@("`]($AO<F1E.CIG971496UP1FEL92@G;7-W;W)D)RD["B`@("`@("`@
M)'1M<%]O=71P=70@/2!(;W)D93HZ9V5T5&5M<$9I;&4H)VUS=V]R9"<I.PH@
M("`@("`@("1T;7!?9&ER("`@(#T@2&]R9&4Z.F=E=%1E;7!$:7(H*3L*("`@
M("`@("`D=&UP7V9I;&4@("`]('-T<E]R97!L86-E*"1T;7!?9&ER("X@)R\G
M+"`G)RP@)'1M<%]O=71P=70I.PH*("`@("`@("!I9B`H3U-?5TE.1$]74RD@
M>PH@("`@("`@("`@("`D87)G<R`]("<@+7@@)R`N(&1I<FYA;64H)&UI;65?
M9')I=F5R<ULG:&]R9&4G75LG;7-W;W)D)UU;)VQO8V%T:6]N)UTI("X@(EQ<
M=W9(=&UL+GAM;"`M9"`D=&UP7V1I<B`M,2`D=&UP7W=O<F0@/B`D=&UP7V]U
M='!U="(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'9E<G-I;VX@
M/2!E>&5C*"1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)VUS=V]R9"==6R=L;V-A
M=&EO;B==("X@)R`M+79E<G-I;VXG*3L*("`@("`@("`@("`@:68@*'9E<G-I
M;VY?8V]M<&%R92@D=F5R<VEO;BP@)S`N-RXP)RD@/CT@,"D@>PH@("`@("`@
M("`@("`@("`@)&%R9W,@/2`B("TM8VAA<G-E=#TB("X@3DQ3.CIG971#:&%R
M<V5T*"D@+B`B("TM=&%R9V5T9&ER/21T;7!?9&ER("1T;7!?=V]R9"`D=&UP
M7V9I;&4B.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)&%R9W,@/2`B("1T;7!?=V]R9"`D=&UP7V]U='!U="(["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("1F:"`](&9O<&5N*"1T;7!?=V]R9"P@
M)W<G*3L*("`@("`@("!F=W)I=&4H)&9H+"`D=&AI<RT^;6EM95]P87)T+3YG
M971#;VYT96YT<R@I*3L*("`@("`@("!F8VQO<V4H)&9H*3L*"B`@("`@("`@
M97AE8R@D;6EM95]D<FEV97)S6R=H;W)D92==6R=M<W=O<F0G75LG;&]C871I
M;VXG72`N("1A<F=S*3L*"B`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D=&UP
M7V]U='!U="DI('L*("`@("`@("`@("`@<F5T=7)N(%\H(E5N86)L92!T;R!T
M<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(BD["B`@("`@("`@?0H*("`@
M("`@("`D9F@@/2!F;W!E;B@D=&UP7V]U='!U="P@)W(G*3L*("`@("`@("!W
M:&EL92`H*"1R8R`](&9G971S*"1F:"P@.#$Y,BDI*2!["B`@("`@("`@("`@
M("1D871A("X]("1R8SL*("`@("`@("!]"B`@("`@("`@9F-L;W-E*"1F:"D[
M"@H@("`@("`@(')E='5R;B`D9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;B!T:&4@34E-12!C;VYT96YT('1Y<&4@;V8@=&AE(')E;F1E<F5D
M(&-O;G1E;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C
M;VYT96YT('1Y<&4@;V8@=&AE(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=T97AT+VAT;6P[
M(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+TU)344O5FEE=V5R+V]O;R\`````````````````````````
M```````````````````````````````````````P,#`P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<T-P`P,C(R-30`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O;V]O+V-O
M;6UO;BYX<VP`````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,38W,#<S`#$P-3$U-#,S
M-S0W`#`R-#,Q,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\(2TM"@H@("!4:&4@0V]N=&5N=',@;V8@=&AI<R!F:6QE(&%R
M92!M861E(&%V86EL86)L92!S=6)J96-T('1O('1H92!T97)M<R!O9@H@("!E
M:71H97(@;V8@=&AE(&9O;&QO=VEN9R!L:6-E;G-E<PH*("`@("`@("`@("T@
M1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(%9E<G-I;VX@,BXQ
M"B`@("`@("`@("`M(%-U;B!);F1U<W1R>2!3=&%N9&%R9',@4V]U<F-E($QI
M8V5N<V4@5F5R<VEO;B`Q+C$*"B`@(%-U;B!-:6-R;W-Y<W1E;7,@26YC+BP@
M3V-T;V)E<BP@,C`P,`H*("`@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,
M:6-E;G-E(%9E<G-I;VX@,BXQ"B`@(#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@("!#;W!Y<FEG:'0@,C`P,"!B>2!3
M=6X@36EC<F]S>7-T96US+"!);F,N"B`@(#DP,2!386X@06YT;VYI;R!2;V%D
M+"!086QO($%L=&\L($-!(#DT,S`S+"!54T$*"B`@(%1H:7,@;&EB<F%R>2!I
M<R!F<F5E('-O9G1W87)E.R!Y;W4@8V%N(')E9&ES=')I8G5T92!I="!A;F0O
M;W(*("`@;6]D:69Y(&ET('5N9&5R('1H92!T97)M<R!O9B!T:&4@1TY5($QE
M<W-E<B!'96YE<F%L(%!U8FQI8PH@("!,:6-E;G-E('9E<G-I;VX@,BXQ+"!A
M<R!P=6)L:7-H960@8GD@=&AE($9R964@4V]F='=A<F4@1F]U;F1A=&EO;BX*
M"B`@(%1H:7,@;&EB<F%R>2!I<R!D:7-T<FEB=71E9"!I;B!T:&4@:&]P92!T
M:&%T(&ET('=I;&P@8F4@=7-E9G5L+`H@("!B=70@5TE42$]55"!!3ED@5T%2
M4D%.5%D[('=I=&AO=70@979E;B!T:&4@:6UP;&EE9"!W87)R86YT>2!O9@H@
M("!-15)#2$%.5$%"24Q)5%D@;W(@1DE43D534R!&3U(@02!005)424-53$%2
M(%!54E!/4T4N("!3964@=&AE($=.50H@("!,97-S97(@1V5N97)A;"!0=6)L
M:6,@3&EC96YS92!F;W(@;6]R92!D971A:6QS+@H*("`@66]U('-H;W5L9"!H
M879E(')E8V5I=F5D(&$@8V]P>2!O9B!T:&4@1TY5($QE<W-E<B!'96YE<F%L
M(%!U8FQI8PH@("!,:6-E;G-E(&%L;VYG('=I=&@@=&AI<R!L:6)R87)Y.R!I
M9B!N;W0L('=R:71E('1O('1H92!&<F5E(%-O9G1W87)E"B`@($9O=6YD871I
M;VXL($EN8RXL(#4Y(%1E;7!L92!0;&%C92P@4W5I=&4@,S,P+"!";W-T;VXL
M"B`@($U!("`P,C$Q,2TQ,S`W("!54T$*"@H@("!3=6X@26YD=7-T<GD@4W1A
M;F1A<F1S(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ"B`@(#T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*("`@
M5&AE(&-O;G1E;G1S(&]F('1H:7,@9FEL92!A<F4@<W5B:F5C="!T;R!T:&4@
M4W5N($EN9'5S=')Y(%-T86YD87)D<PH@("!3;W5R8V4@3&EC96YS92!697)S
M:6]N(#$N,2`H=&AE("),:6-E;G-E(BD[(%EO=2!M87D@;F]T('5S92!T:&ES
M(&9I;&4*("`@97AC97!T(&EN(&-O;7!L:6%N8V4@=VET:"!T:&4@3&EC96YS
M92X@66]U(&UA>2!O8G1A:6X@82!C;W!Y(&]F('1H90H@("!,:6-E;G-E(&%T
M(&AT='`Z+R]W=W<N;W!E;F]F9FEC92YO<F<O;&EC96YS92YH=&UL+@H*("`@
M4V]F='=A<F4@<')O=FED960@=6YD97(@=&AI<R!,:6-E;G-E(&ES('!R;W9I
M9&5D(&]N(&%N(")!4R!)4R(@8F%S:7,L"B`@(%=)5$A/550@5T%24D%.5%D@
M3T8@04Y9($M)3D0L($5)5$A%4B!%6%!215-3($]2($E-4$Q)140L($E.0TQ5
M1$E.1RP*("`@5TE42$]55"!,24U)5$%424].+"!705)204Y42453(%1(050@
M5$A%(%-/1E1705)%($E3($92144@3T8@1$5&14-44RP*("`@34520TA!3E1!
M0DQ%+"!&250@1D]2($$@4$%25$E#54Q!4B!055)03U-%+"!/4B!.3TXM24Y&
M4DE.1TE.1RX*("`@4V5E('1H92!,:6-E;G-E(&9O<B!T:&4@<W!E8VEF:6,@
M<')O=FES:6]N<R!G;W9E<FYI;F<@>6]U<B!R:6=H=',@86YD"B`@(&]B;&EG
M871I;VYS(&-O;F-E<FYI;F<@=&AE(%-O9G1W87)E+@H*("`@5&AE($EN:71I
M86P@1&5V96QO<&5R(&]F('1H92!/<FEG:6YA;"!#;V1E(&ES.B!3=6X@36EC
M<F]S>7-T96US+"!);F,N"@H@("!#;W!Y<FEG:'0@PJD@,C`P,B!B>2!3=6X@
M36EC<F]S>7-T96US+"!);F,N"@H@("!!;&P@4FEG:'1S(%)E<V5R=F5D+@H*
M("`@0V]N=')I8G5T;W(H<RDZ(%]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7PH*+2T^"CQX<VPZ<W1Y;&5S:&5E="!V97)S:6]N/2(Q
M+C`B"B`@("`@("`@("`@("`@("!X;6QN<SIX<VP](FAT='`Z+R]W=W<N=S,N
M;W)G+S$Y.3DO6%-,+U1R86YS9F]R;2(*("`@("`@("`@("`@("`@('AM;&YS
M.F]F9FEC93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O;V9F:6-E(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z<W1Y;&4](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`P+W-T>6QE(@H@("`@("`@("`@("`@("`@>&UL;G,Z=&5X=#TB
M:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O=&5X="(*("`@("`@("`@("`@
M("`@('AM;&YS.G1A8FQE/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]T
M86)L92(*("`@("`@("`@("`@("`@('AM;&YS.F1R87<](FAT='`Z+R]O<&5N
M;V9F:6-E+F]R9R\R,#`P+V1R87=I;F<B"B`@("`@("`@("`@("`@("!X;6QN
M<SIF;STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]84TPO1F]R;6%T(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z>&QI;FL](FAT='`Z+R]W=W<N=S,N;W)G+S$Y
M.3DO>&QI;FLB"B`@("`@("`@("`@("`@("!X;6QN<SIN=6UB97(](FAT='`Z
M+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1A=&%S='EL92(*("`@("`@("`@("`@
M("`@('AM;&YS.G-V9STB:'1T<#HO+W=W=RYW,RYO<F<O,C`P,"]S=F<B"B`@
M("`@("`@("`@("`@("!X;6QN<SIC:&%R=#TB:'1T<#HO+V]P96YO9F9I8V4N
M;W)G+S(P,#`O8VAA<G0B"B`@("`@("`@("`@("`@("!X;6QN<SID<C-D/2)H
M='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D<C-D(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z;6%T:#TB:'1T<#HO+W=W=RYW,RYO<F<O,3DY."]-871H+TUA
M=&A-3"(*("`@("`@("`@("`@("`@('AM;&YS.F9O<FT](FAT='`Z+R]O<&5N
M;V9F:6-E+F]R9R\R,#`P+V9O<FTB"B`@("`@("`@("`@("`@("!X;6QN<SIS
M8W)I<'0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W-C<FEP="(*("`@
M("`@("`@("`@("`@(&]F9FEC93IC;&%S<STB=&5X="(*("`@("`@("`@("`@
M("`@(&]F9FEC93IV97)S:6]N/2(Q+C`B"B`@("`@("`@("`@("`@("!X;6QN
M<SID8STB:'1T<#HO+W!U<FPN;W)G+V1C+V5L96UE;G1S+S$N,2\B"B`@("`@
M("`@("`@("`@("!X;6QN<SIM971A/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O
M,C`P,"]M971A(@H@("`@("`@("`@("`@("`@>&UL;G,Z8V]N9FEG/2)H='1P
M.B\O;W!E;F]F9FEC92YO<F<O,C`P,2]C;VYF:6<B"B`@("`@("`@("`@("`@
M("!X;6QN<SIH96QP/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]H96QP
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z>'0](FAT='`Z+R]W=W<N:F-L87)K
M+F-O;2]X="(*("`@("`@("`@("`@("`@(&5X=&5N<VEO;BUE;&5M96YT+7!R
M969I>&5S/2)X="(*("`@("`@("`@("`@("`@('AM;&YS.GAA;&%N/2)H='1P
M.B\O>&UL+F%P86-H92YO<F<O>&%L86XB"B`@("`@("`@("`@("`@("!X;6QN
M<SIJ879A/2)H='1P.B\O>&UL+F%P86-H92YO<F<O>'-L="]J879A(@H@("`@
M("`@("`@("`@("`@97AC;'5D92UR97-U;'0M<')E9FEX97,](FIA=F$B/@H*
M"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!B;V1Y
M("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ("TM/@H*"B`@("`\>'-L
M.G1E;7!L871E(&UA=&-H/2(O*B]O9F9I8V4Z8F]D>2(^"B`@("`@("`@/'AS
M;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"@H@("`@("`@
M(#PA+2T@:7-$96)U9TUO9&4M4U1!4E0Z(&]N;'D@:7-$96)U9TUO9&4@<'5R
M<&]S93H@<VAO=W,@=&AE(&EN;&EN960@<W1Y;&4@871T<FEB=71E<R!O9B!T
M:&4@=&5M<&]R87)Y('9A<FEA8FQE("TM/@H@("`@("`@(#QX<VPZ:68@=&5S
M=#TB)&ES1&5B=6=-;V1E(&%N9"!N;W0H)&]U='!U=%1Y<&4@/2`G0U-37TA%
M041%4B<I(CX*("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F1E8G5G
M7W1R965?;V9?<W1Y;&5S(CX\>'-L.G1E>'0^"B`@("`@("`@("`@(#PO>'-L
M.G1E>'0^/'AS;#IF;W(M96%C:"!S96QE8W0](B1C;VQL96-T961';&]B86Q$
M871A+V%L;'-T>6QE<R\J(CX*/'AS;#IT97AT/B`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)N86UE*"DB
M+SX\>'-L.G1E>'0^(#T@/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB+B(O/CQX<VPZ=&5X=#X*("`@("`@("`@("`@/"]X<VPZ=&5X=#X*("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IF;W(M96%C:#X*("`@("`@("`@("`@
M/"]X<VPZ96QE;65N=#X*("`@("`@("`\+WAS;#II9CX*("`@(#PA+2T@:7-$
M96)U9TUO9&4M14Y$("TM/@H*"@D)/"$M+2!N;W0@=7-I;F<@;V8@)V%P<&QY
M+7-T>6QE<RUA;F0M8V]N=&5N="<@87,@=&AE(&-O;G1E;G0@=&%B;&4@:6YF
M;W)M871I;VX@;6EG=&@@:&%V92!B965N(&%D9&5D('1O("=C;VQL96-T961'
M;&]B86Q$871A)R!V87)I86)L92`M+3X*("`@("`@("`\>'-L.F%P<&QY+71E
M;7!L871E<R!S96QE8W0](D!T97AT.G-T>6QE+6YA;64@?"!`9')A=SIS='EL
M92UN86UE('P@0&1R87<Z=&5X="US='EL92UN86UE('P@0'1A8FQE.G-T>6QE
M+6YA;64B/CPA+2T@?"!`<')E<V5N=&%T:6]N.G-T>6QE+6YA;64@+2T^"B`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B
M86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@
M("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H*"B`@("`@("`@/"$M+2!5<V%B
M:6QI='D@9F5A='5R92P@82!L:6YK('1O('1H92!#;VYT96YT('1A;&)E(&%B
M;W9E(&%L;"!L979E;"`Q(&AE861E<B`M+3X*("`@("`@("`\>'-L.FEF('1E
M<W0](B1C;VYT96YT5&%B;&5(96%D:6YG<R(^"B`@("`@("`@("`@(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)A9&0M8VAI;&0M9&]C=6UE;G0M=7-A8FEL
M:71Y+6QI;FMS(B\^"B`@("`@("`@/"]X<VPZ:68^"@H*"0D\>'-L.F-H;V]S
M93X*"2`@("`@("`@/'AS;#IW:&5N('1E<W0](FYO="@D;W5T<'5T5'EP92`]
M("=734PG*2!A;F0@;F]T*"1O=71P=714>7!E(#T@)U!!3$TG*2(^"@D@("`@
M("`@(`D\>'-L.F-H;V]S93X*"0D)("`@("`@("`\(2TM268@=&AE(&EN<'5T
M(&1O8W5M96YT(&ES(&$@9VQO8F%L(&1O8W5M96YT(&%N9"!E;6)E9"!C:&EL
M9"!D;V-U;65N=',@*&QI;FMS*2!T:&4@=')A;G-F;W)M871I;VX@;V8@=&AE
M(&-H:6QD<F5N('=I;&P@8F4@<W1A<G1E9"!A<R!W96QL+@H)"0D@("`@("`@
M("`@("!4:&ES(&ES(&YE8V5S<V%R>2!A<R!C:&EL9"!D;V-U;65N=',@9&\@
M;F]T(&MN;W<@86YY=&AI;F<@86)O=70@=&AE:7(@96UB961D:6YG(&EN=&\@
M82!G;&]B86P@9&]C=6UE;G0N($-H87!T97)S(&]F(&-H:6QD<PH)"0D@("`@
M("`@("`@("!A;'=A>7,@<W1A<G0@=&\@8V]U;G0@8GD@>F5R;R!I;G-T96%D
M(&]F(&-O;G1I;F]U<VQY(&YU;6)E<FEN9RX*"0D)("`@("`@("`@("`@1F]R
M('1H:7,L('1H92!C:&%P=&5R(&YU;6)E<G,@;V8@=&AE(&-U<G)E;G0@9&]C
M=6UE;G0@*&%S(&$@<V5Q=65N8V4@;V8@82!G;&]B86P@9&]C=6UE;G0I(&ES
M(&1E<&5N9&5N=`H)"0D@("`@("`@("`@("!O9B!T:&4@;G5M8F5R(&]F(&-H
M87!T97(@;V8@=&AE('-A;64@;&5V96P@:6X@<')E8V5D:6YG(&1O8W5M96YT
M<RX*"0D)("`@("`@("`@("`@26X@8V%S92!O9B!M=6QT:7!L92!C:&EL9')E
M;BP@9F]R('5S86)I;&ET>2!R96%S;VYS('-O;64@;&EN:VEN9R!I<R!G;VYN
M82!B92!O9F9E<F5D(&%N9"!T:&4@55),<R!O9B!T:&4@8V]N=&5N="UT86)L
M92P*"0D)("`@("`@("`@("`@<')E8V5D:6YG(&%N9"!F;VQL;W=I;F<@9FEL
M92!H879E('1O(&)E(&=I=F5N(&9O<B!T:&4@=')A;G-F;W)M871I;VXN"@D)
M"2`@("`@("`@("`@("TM/@H)"2`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2(O*B]`;V9F:6-E.F-L87-S/2=T97AT+6=L;V)A;"<@86YD("\J+V]F9FEC
M93IB;V1Y+W1E>'0Z<V5C=&EO;B]T97AT.G-E8W1I;VXM<V]U<F-E+T!X;&EN
M:SIH<F5F(CX*"0D)"0D)/"$M+2!T:&4@8VAI;&1R96X@=VEL;"!B92!C86QL
M960@;&%T97(@=VET:"!A(&UO9&EF:65D("=C;VQL96-T961';&]B86Q$871A
M)R!V87)I86)L92`M+3X*"0D@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E
M;7!L871E(&YA;64](G1R86YS9F]R;2UG;&]B86PM9&]C=6UE;G0M86YD+6-H
M:6QD<F5N(CX*"0D@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T
M961';&]B86Q$871A(B\^"@D)("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM
M=&5M<&QA=&4^"@D)("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"0D)"0D\>'-L
M.F]T:&5R=VES93X*"0D)"2`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^
M"@D)"0D@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C
M=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O
M/@H)"0D)("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"@D)"0D)/"]X
M<VPZ;W1H97)W:7-E/@H)"0D)/"]X<VPZ8VAO;W-E/@H)("`@("`@("`\+WAS
M;#IW:&5N/@H)"0D\>'-L.F]T:&5R=VES93X*"0D@("`@("`@(#QX<VPZ87!P
M;'DM=&5M<&QA=&5S/@H)"2`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961'
M;&]B86Q$871A(B\^"@D)("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^
M"@D)"3PO>'-L.F]T:&5R=VES93X*"0D\+WAS;#IC:&]O<V4^"@H*"B`@("`@
M("`@/"$M+2!5<V%B:6QI='D@9F5A='5R92P@82!L:6YK('1O('1H92!#;VYT
M96YT('1A;&)E(&%B;W9E(&%L;"!L979E;"`Q(&AE861E<B`M+3X*("`@("`@
M("`\>'-L.FEF('1E<W0](B1C;VYT96YT5&%B;&5(96%D:6YG<R(^"B`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A9&0M8VAI;&0M9&]C
M=6UE;G0M=7-A8FEL:71Y+6QI;FMS(B\^"B`@("`@("`@/"]X<VPZ:68^"@H*
M("`@(#PO>'-L.G1E;7!L871E/@H*"@H*("`@(#PA+2T@9&5A8W1I=F%T:6YG
M(&1E9F%U;'0@=&5M<&QA=&4@+2T^"B`@("`\>'-L.G1E;7!L871E(&UA=&-H
M/2(J(B\^"@H*("`@(#PA+2T@86QL;W=I;F<@86QL(&UA=&-H960@=&5X="!N
M;V1E<R`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](G1E>'0H*2(^"CPA
M+2T@5TU,("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](FYO<FUA;&EZ
M92US<&%C92@N*2(O/B`M+3X*("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB+B(O/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\(2TM(",C(R,C
M(R,C(R,C(R,C(R,C(R,@+2T^"B`@("`\(2TM(",C(R!)3DQ)3D4M5$585"`C
M(R,@+2T^"B`@("`\(2TM(",C(R,C(R,C(R,C(R,C(R,C(R,@+2T^"@H*("`@
M(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@5VAI
M=&5S<&%C92`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M
M+3X*"@H@("`@/'AS;#IT96UP;&%T92!M871C:#TB=&5X=#IS(CX*("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M8G)E86MA8FQE+7=H
M:71E<W!A8V4B/@H@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M=VAI=&5S<&%C97,B('-E;&5C=#TB0'1E>'0Z8R(O/@H@("`@("`@(#PO>'-L
M.F-A;&PM=&5M<&QA=&4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/"$M
M+7=R:71E('1H92!N=6UB97(@;V8@)W=H:71E<W!A8V5S)R`M+3X*("`@(#QX
M<VPZ=&5M<&QA=&4@;F%M93TB=W)I=&4M8G)E86MA8FQE+7=H:71E<W!A8V4B
M/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB=VAI=&5S<&%C97,B+SX*"B`@
M("`@("`@/"$M+7=R:71E('1W;R!S<&%C92!C:&%R<R!A<R!T:&4@;F]R;6%L
M('=H:71E('-P86-E(&-H87)A8W1E<B!W:6QL(&)E('-T<FEP<&5D"B`@("`@
M("`@("`@(&%N9"!T:&4@;W1H97(@:7,@86)L92!T;R!B<F5A:R`M+3X*("`@
M("`@("`\>'-L.G1E>'0^)B,Q-C`[/"]X<VPZ=&5X=#X*("`@("`@("`\>'-L
M.FEF('1E<W0](B1W:&ET97-P86-E<R`^/2`R(CX*("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+6)R96%K86)L92UW:&ET97-P
M86-E+3(B/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(G=H:71E<W!A8V5S(B!S96QE8W0](B1W:&ET97-P86-E<R`M(#$B+SX*("`@
M("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`\+WAS;#II
M9CX*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\(2TM=W)I=&4@=&AE(&YU
M;6)E<B!O9B`G=VAI=&5S<&%C97,G("TM/@H@("`@/'AS;#IT96UP;&%T92!N
M86UE/2)W<FET92UB<F5A:V%B;&4M=VAI=&5S<&%C92TR(CX*("`@("`@("`\
M>'-L.G!A<F%M(&YA;64](G=H:71E<W!A8V5S(B\^"B`@("`@("`@/"$M+7=R
M:71E('1W;R!S<&%C92!C:&%R<R!A<R!T:&4@;F]R;6%L('=H:71E('-P86-E
M(&-H87)A8W1E<B!W:6QL(&)E('-T<FEP<&5D"B`@("`@("`@("`@(&%N9"!T
M:&4@;W1H97(@:7,@86)L92!T;R!B<F5A:R`M+3X*("`@("`@("`\>'-L.G1E
M>'0^(#PO>'-L.G1E>'0^"B`@("`@("`@/'AS;#II9B!T97-T/2(D=VAI=&5S
M<&%C97,@/CT@,B(^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)W<FET92UB<F5A:V%B;&4M=VAI=&5S<&%C92(^"B`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=VAI=&5S<&%C97,B('-E;&5C
M=#TB)'=H:71E<W!A8V5S("T@,2(O/@H@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@(#PO>'-L.FEF/@H@("`@/"]X<VPZ=&5M<&QA
M=&4^"@H*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM
M("HJ*B!497AT8F]X("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ
M("TM/@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](F1R87<Z=&5X="UB;W@B
M/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T
M82(O/@H*("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@
M("`\(2TM*RLK*RL@0U-3("A#05-#041)3D<@4U1,644@4TA%150I($A%041%
M4B!35%E,12!705D@*RLK*RLM+3X*("`@("`@("`@("`@("`@(#PA+2T@("`@
M("`@("`@("`@("`@;W(@("`@("`@("`@("`@("`@("`M+3X*("`@("`@("`@
M("`@("`@(#PA+2TK*RLK*R!(5$U,(#0N,"!)3DQ)3D5$(%=!62`@*RLK*RLM
M+3X*("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP
M92`]("=#4U-?2$5!1$52)R!O<B`D;W5T<'5T5'EP92`]("=#4U-?24Y,24Y%
M1"<B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)S
M<&%N(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2)`
M9F\Z;6EN+6AE:6=H="!\($!S=F<Z=VED=&@B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB<W1Y;&4B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB;F]T*$!S=F<Z=VED=&@I(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YH96EG:'0Z(#PO>'-L.G1E>'0^
M/'AS;#IV86QU92UO9B!S96QE8W0](D!F;SIM:6XM:&5I9VAT(B\^/'AS;#IT
M97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](FYO="A`9F\Z;6EN+6AE:6=H
M="DB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IT97AT/G=I9'1H.B`\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L
M96-T/2)`<W9G.G=I9'1H(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE
M<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G1E>'0^:&5I9VAT.B`\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@
M<V5L96-T/2)`9F\Z;6EN+6AE:6=H="(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E
M>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G1E>'0^=VED=&@Z(#PO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE
M8W0](D!S=F<Z=VED=&@B+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I
M<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB
M=71E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#II9CX*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,@<V5L96-T
M/2)`9')A=SIN86UE(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M
M96YT/@H@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M("`@(#PA+2T@,D1/('!R;W9E(&)E<W0@=7-A9V4@9F]R(%!!3$T@+2T^"B`@
M("`@("`@("`@("`@("`\(2TM*RLK*RL@4$%,32`S+C(@4U5"4T54($E.3$E.
M140@5T%9("`K*RLK*RTM/@H@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](B1O=71P=714>7!E(#T@)U!!3$TG(CX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.F5L96UE;G0@;F%M93TB<W!A;B(^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M
M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C
M=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@(#PA+2T@,D1/('!R;W9E(&)E<W0@=7-A9V4@9F]R
M(%=-3"`M+3X*("`@("`@("`@("`@("`@(#PA+2TK*RLK*R!734P@+R!705`@
M("LK*RLK+2T^"B`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@
M("`@("`@("`@("`@("`@("`\(2TM(&YO(&YE<W1E9"!P('1A9W,@:6X@=VUL
M,2XQ(&%L;&]W960@+2T^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O
M<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)A
M;F-E<W1O<CHZ*EMC;VYT86EN<R@D=V%P+7!A<F%G<F%P:"UE;&5M96YT<RP@
M;F%M92@I*5TB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC
M86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE
M8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H
M97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M
M96YT(&YA;64](G`B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O
M;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L
M96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@(#PO>'-L.F]T
M:&5R=VES93X*("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ
M=&5M<&QA=&4^"@H@("`@/"$M+2!)1"`O($Y!344@;V8@=&5X="UB;W@@+2T^
M"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2)`9')A=SIN86UE(CX*"B`@("`@
M("`@/'AS;#IA='1R:6)U=&4@;F%M93TB:60B/@H@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB+B(O/@H@("`@("`@(#PO>'-L.F%T=')I8G5T
M93X*("`@(#PO>'-L.G1E;7!L871E/@H*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ
M*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!087)A9W)A<&AS("HJ*B`M+3X*
M("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*("`@(#QX<VPZ=&5M
M<&QA=&4@;6%T8V@](G1E>'0Z<"!\(&1R87<Z<&%G92(^"B`@("`@("`@/'AS
M;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"@H@("`@("`@
M("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@(#PA+2TK*RLK*R!#
M4U,@*$-!4T-!1$E.1R!35$Q912!32$5%5"D@2$5!1$52(%-464Q%(%=!62`K
M*RLK*RTM/@H@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1O=71P
M=714>7!E(#T@)T-34U](14%$15(G(CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.F5L96UE;G0@;F%M93TB<"(^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O
M;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O
M;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@
M("`@("`@("`@("`\(2TM*RLK*RL@2%1-3"`T+C`@24Y,24Y%1"!705D@("LK
M*RLK+2T^"B`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U
M=%1Y<&4@/2`G0U-37TE.3$E.140G(CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.F5L96UE;G0@;F%M93TB<"(^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O
M;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O
M;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@(#PA+2TK*RLK*R!004Q-(#,N,B!354)3150@24Y,24Y%1"!7
M05D@("LK*RLK+2T^"B`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M)&]U='!U=%1Y<&4@/2`G4$%,32<B/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\(2TM(&EN('!A
M;&T@<&%R86=R87!H<R!C:&EL9')E;B!O9B!T97AT.FQI<W0M:71E;7,@87)E
M(&)E='1E<B!S:&]W;B!W:71H;W5T("=P)R!T86<M+3X*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](FYA;64H<&%R96YT.CHJ*2`]
M("=T97AT.FQI<W0M:71E;2<B/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M
M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C
M=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IE;&5M96YT(&YA;64](G`B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL
M97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L
M1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@(#PA+2TK*RLK*R!734P@+R!7
M05`@("LK*RLK+2T^"B`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@("`@("`\(2TM(&YO(&YE<W1E9"!P('1A9W,@:6X@
M=VUL,2XQ(&%L;&]W960@+2T^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC
M:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)A;F-E<W1O<CHZ*EMC;VYT86EN<R@D=V%P+7!A<F%G<F%P:"UE;&5M96YT
M<RP@;F%M92@I*5TB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N
M="(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O
M;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE
M;&5M96YT(&YA;64](G`B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD
M+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@(#PO>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X
M<VPZ=&5M<&QA=&4^"@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM
M/@H@("`@/"$M+2`J*BH@5&5X="!3<&%N("HJ*B`M+3X*("`@(#PA+2T@*BHJ
M*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H@("`@/'AS;#IT96UP;&%T92!M871C:#TB
M=&5X=#IS<&%N(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@
M("`@(#PA+2TK*RLK*R!#4U,@*$-!4T-!1$E.1R!35$Q912!32$5%5"D@2$5!
M1$52(%-464Q%(%=!62`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB)&]U='!U=%1Y<&4@/2`G0U-37TA%041%4B<B/@H@("`@("`@("`@
M("`@("`@/'AS;#IE;&5M96YT(&YA;64](G-P86XB/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M
M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D
M8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IE;&5M
M96YT/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H*("`@("`@("`@("`@/"$M
M+2LK*RLK($A434P@-"XP($E.3$E.140@5T%9("`K*RLK*RTM/@H@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G0U-37TE.3$E.
M140G(CX*("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)S<&%N
M(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@
M("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@/"$M+2LK*RLK(%!!3$T@,RXR(%-50E-%5"!)3DQ)3D5$
M(%=!62`@*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1O
M=71P=714>7!E(#T@)U!!3$TG(CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L
M;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL
M96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A
M(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\(2TM*RLK*RL@5TU,
M("\@5T%0("`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@(#PA+2T@;F\@;F5S=&5D('`@=&%G<R!I;B!W;6PQ
M+C$@86QL;W=E9"`M+3X*("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)A;F-E<W1O<CHZ
M*EMC;VYT86EN<R@D=V%P+7!A<F%G<F%P:"UE;&5M96YT<RP@;F%M92@I*5TB
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@
M;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T
M961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^
M"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IE;&5M96YT(&YA;64](G`B/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE
M<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/"]X<VPZ
M8VAO;W-E/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@
M/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\(2TM
M("HJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!(96%D:6YG<R`J
M*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H@("`@/'AS
M;#IT96UP;&%T92!M871C:#TB=&5X=#IH(CX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/"$M+2!%
M=F5R>2!H96%D:6YG(&5L96UE;G0@=VEL;"!G970@86X@=6YI<75E(&%N8VAO
M<B!F;W(@:71S(&9I;&4L(&9R;VT@:71S(&AI96%R8VAY(&QE=F5L(&%N9"!N
M86UE.@H@("`@("`@("`@("!&;W(@97AA;7!L93H@(%1H92!H96%D:6YG('1I
M=&QE("=->2!F879O<FET92!H96%D:6YG)R!M:6=H="!G970@/&$@;F%M93TB
M,2LR*S(K37DK9F%V;W)I=&4K:&5A9&EN9R(O/B`M+3X*("`@("`@("`\>'-L
M.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1D:7-A8FQE
M3&EN:V5D5&%B;&5/9D-O;G1E;G0@;W(@)&ES2F%V841I<V%B;&5D(&]R(&YO
M="@D;W5T<'5T5'EP92`]("=#4U-?2$5!1$52)RDB/@H@("`@("`@("`@("`\
M(2TM(%1H92!54DP@;&EN:VEN9R!O9B!A;B!T86)L92UO9BUC;VYT96YT(&ES
M(&1U92!T;R!A(&)U9R`H8VUP+B!B=6<@:60C(#$P,C,Q,2D@;F]T(&UA<'!E
M9"!A<R!54DP@:6X@=&AE(%A-3"X*("`@("`@("`@("`@("`@("!,:6YK:6YG
M(&]F('1H92!T86)L92UO9BUC;VYT96YT(&-A;B!T:&5R969O<F4@;VYL>2!B
M92!A<F-H:65V960@8GD@82!W;W)K+6%R;W5N9"!I;B!(5$U,("TM/@H@("`@
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R96%T92UH
M96%D:6YG(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D
M1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP
M;&%T93X*("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@(#QX<VPZ
M;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/"$M+2!N96-E<W-A<GD@87,@
M86YC:&]R(&9O<B!T:&4@8V]N=&5N="!T86)L92`M+3X*("`@("`@("`@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C<F5A=&4M:&5A9&EN9RUA
M;F-H;W(B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961'
M;&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L
M871E/@H*("`@("`@("`@("`@("`@(#PA+2T@;F\@96UB961D:6YG('1H92!O
M<F=I;F%L(&AE861E<BP@87,@86X@97AP;&EC:70@86YC:&]R(&UI9VAT(&)E
M(&%L<F5A9'D@<V5T("TM/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E
M;7!L871E(&YA;64](F-R96%T92UH96%D:6YG(CX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T
M82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ
M;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E
M;7!L871E/@H*"B`@("`\(2TM(&1E9F%U;'0@;6%T8VAI;F<@9F]R(&AE861E
M<B!E;&5M96YT<R`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB8W)E871E
M+6AE861I;F<B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D
M1VQO8F%L1&%T82(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@
M("`@/"$M+2LK*RLK($-34R`H0T%30T%$24Y'(%-43%E%(%-(1454*2!(14%$
M15(@4U193$4@5T%9("LK*RLK+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2(D;W5T<'5T5'EP92`]("=#4U-?2$5!1$52)R(^"@H@("`@("`@("`@
M("`@("`@/'AS;#IV87)I86)L92!N86UE/2)H96%D97)T>7`B('-E;&5C=#TB
M8V]N8V%T*"=H)RP@0'1E>'0Z;&5V96PI(B\^"B`@("`@("`@("`@("`@("`\
M>'-L.F5L96UE;G0@;F%M93TB>R1H96%D97)T>7!](CX*"B`@("`@("`@("`@
M("`@("`@("`@/"$M+2!O=71L:6YE('-T>6QE("=T97AT.FUI;BUL86)E;"UW
M:61T:"<@:7,@:6YT97)P<F5T960@87,@82!#4U,@)VUA<F=I;BUL969T)R!A
M='1R:6)U=&4@+2T^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L
M92!N86UE/2)M:6XM;&%B96PB('-E;&5C=#TB)&]F9FEC93IS='EL97,O=&5X
M=#IO=71L:6YE+7-T>6QE+W1E>'0Z;W5T;&EN92UL979E;"US='EL95M`=&5X
M=#IL979E;"`](&-U<G)E;G0H*2]`=&5X=#IL979E;%TO<W1Y;&4Z<')O<&5R
M=&EE<R]`=&5X=#IM:6XM;&%B96PM=VED=&@B+SX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.FEF('1E<W0](B1M:6XM;&%B96PB/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)S='EL92(^/'AS;#IT
M97AT/FUA<F=I;BUL969T.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE
M8W0](B1M:6XM;&%B96PB+SX\>'-L.G1E>'0^.SPO>'-L.G1E>'0^/"]X<VPZ
M871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H*"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8VQA<W,B
M/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)T<F%N<VQA=&4H0'1E>'0Z<W1Y;&4M
M;F%M92P@)RX@)2@I+UPG+"`G)RDB+SX\+WAS;#IA='1R:6)U=&4^"@H@("`@
M("`@("`@("`@("`@("`@(#PA+2T@=W)I=&EN9R!O=70@82!C:&%P=&5R(&YU
M;6)E<B!I9B!D97-I<F5D("AN;W1I8V%B;&4@=VAE;B!A(&-O<G)E<W!O;F1I
M;F<@)W1E>'0Z;W5T;&EN92US='EL92<@97AI<W0@+2T^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#II9B!T97-T/2)S=')I;F<M;&5N9W1H*"1O9F9I8V4Z
M<W1Y;&5S+W1E>'0Z;W5T;&EN92US='EL92]T97AT.F]U=&QI;F4M;&5V96PM
M<W1Y;&5;0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=+T!S
M='EL93IN=6TM9F]R;6%T*2`A/2`P(CX*"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](B1D:7-A8FQE3&EN:V5D5&%B;&5/9D-O;G1E;G0@
M;W(@)&ES2F%V841I<V%B;&5D(&]R(&YO="@D;W5T<'5T5'EP92`]("=#4U-?
M2$5!1$52)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA
M+2T@=&AE(&-H87!T97(@;G5M8F5R(&ES('1H92!S=6T@;V8@)W1E>'0Z<W1A
M<G0M=F%L=64G(&%N9"!P<F5C961I;F<@<VEB;&EN9W,@;V8@)W1E>'0Z:"<@
M=VET:"!T:&4@<V%M92`G=&5X=#IL979E;"<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!F=7)T:&5R;6]R92!W:&5N('1H92!C=7)R
M96YT(&1O8W5M96YT(&ES(')E9F5R96YC960@8GD@82!G;&]B86P@9&]C=6UE
M;G0@+2!A<R!P87)T(&]F(&$@=VAO;&4@<V5Q=65N8V4@;V8@9&]C=6UE;G1S
M("TL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@
M8VAA<'1E<B!N;RX@:7,@9&5P96YD96YT(&]F('1H92!A;6]U;G0@;V8@<W1A
M<G1E9"!H96%D97)S(&EN('!R96-E9&EN9R!D;V-U;65N=',N"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!)9B!T:&4@)W1E>'0Z<W1A
M<G0M=F%L=64@:7,@;F]T('-E="!T:&4@9&5F875L="!V86QU92!O9B`G,2<@
M:&%S('1O(&)E('1A:V5N+B`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G-T87)T5F%L=64B('-E;&5C
M=#TB)&]F9FEC93IS='EL97,O=&5X=#IO=71L:6YE+7-T>6QE+W1E>'0Z;W5T
M;&EN92UL979E;"US='EL95M`=&5X=#IL979E;"`](&-U<G)E;G0H*2]`=&5X
M=#IL979E;%TO0'1E>'0Z<W1A<G0M=F%L=64B+SX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1S=&%R=%9A
M;'5E(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&5X=#IL979E;#TG,2<B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H<')E8V5D:6YG+7-I
M8FQI;F<Z.G1E>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E;G0H*2]`=&5X=#IL
M979E;%TI"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("L@)'!R96-E9&EN9T-H87!T97),979E
M;#$*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@*R`D<W1A<G1686QU92(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](D!T97AT.FQE=F5L/2<R)R(^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2)C;W5N="AP<F5C961I;F<M<VEB;&EN9SHZ=&5X=#IH
M6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L72D*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@*R`D<')E8V5D:6YG0VAA<'1E<DQE=F5L,@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`K("1S=&%R=%9A;'5E(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB0'1E>'0Z;&5V96P])S,G(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0]
M(F-O=6YT*'!R96-E9&EN9RUS:6)L:6YG.CIT97AT.FA;0'1E>'0Z;&5V96P@
M/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=*0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K("1P
M<F5C961I;F=#:&%P=&5R3&5V96PS"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@)'-T87)T
M5F%L=64B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&5X=#IL979E
M;#TG-"<B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H<')E8V5D
M:6YG+7-I8FQI;F<Z.G1E>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E;G0H*2]`
M=&5X=#IL979E;%TI"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@)'!R96-E9&EN9T-H87!T
M97),979E;#0*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*R`D<W1A<G1686QU92(O/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](D!T97AT.FQE=F5L/2<U)R(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)C;W5N="AP<F5C961I;F<M<VEB;&EN9SHZ
M=&5X=#IH6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L72D*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*R`D<')E8V5D:6YG0VAA<'1E<DQE=F5L-0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`K("1S=&%R=%9A;'5E(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB0'1E>'0Z;&5V96P])S8G(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](F-O=6YT*'!R96-E9&EN9RUS:6)L:6YG.CIT97AT.FA;0'1E>'0Z
M;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=*0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`K("1P<F5C961I;F=#:&%P=&5R3&5V96PV"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@
M)'-T87)T5F%L=64B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&5X
M=#IL979E;#TG-R<B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H
M<')E8V5D:6YG+7-I8FQI;F<Z.G1E>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E
M;G0H*2]`=&5X=#IL979E;%TI"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@)'!R96-E9&EN
M9T-H87!T97),979E;#<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`D<W1A<G1686QU92(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!T97AT.FQE=F5L/2<X)R(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;W5N="AP<F5C961I;F<M<VEB
M;&EN9SHZ=&5X=#IH6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE
M=F5L72D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@*R`D<')E8V5D:6YG0VAA<'1E<DQE=F5L
M.`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`K("1S=&%R=%9A;'5E(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TB0'1E>'0Z;&5V96P])SDG(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU
M92UO9B!S96QE8W0](F-O=6YT*'!R96-E9&EN9RUS:6)L:6YG.CIT97AT.FA;
M0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=*0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`K("1P<F5C961I;F=#:&%P=&5R3&5V96PY"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("L@)'-T87)T5F%L=64B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)`=&5X=#IL979E;#TG,3`G(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0]
M(F-O=6YT*'!R96-E9&EN9RUS:6)L:6YG.CIT97AT.FA;0'1E>'0Z;&5V96P@
M/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=*0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K("1P
M<F5C961I;F=#:&%P=&5R3&5V96PQ,`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K("1S=&%R
M=%9A;'5E(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S
M93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TB0'1E>'0Z;&5V96P])S$G(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](F-O=6YT*'!R96-E9&EN9RUS:6)L:6YG.CIT97AT
M.FA;0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=*0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`K("1P<F5C961I;F=#:&%P=&5R3&5V96PQ"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("L@,2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!T97AT
M.FQE=F5L/2<R)R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;W5N="AP
M<F5C961I;F<M<VEB;&EN9SHZ=&5X=#IH6T!T97AT.FQE=F5L(#T@8W5R<F5N
M="@I+T!T97AT.FQE=F5L72D*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`D<')E8V5D:6YG
M0VAA<'1E<DQE=F5L,@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K(#$B+SX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2)`=&5X=#IL979E;#TG,R<B/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB8V]U;G0H<')E8V5D:6YG+7-I8FQI;F<Z.G1E>'0Z
M:%M`=&5X=#IL979E;"`](&-U<G)E;G0H*2]`=&5X=#IL979E;%TI"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("L@)'!R96-E9&EN9T-H87!T97),979E;#,*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@*R`Q(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'1E>'0Z
M;&5V96P])S0G(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O=6YT*'!R
M96-E9&EN9RUS:6)L:6YG.CIT97AT.FA;0'1E>'0Z;&5V96P@/2!C=7)R96YT
M*"DO0'1E>'0Z;&5V96Q=*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K("1P<F5C961I;F=#
M:&%P=&5R3&5V96PT"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@,2(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](D!T97AT.FQE=F5L/2<U)R(^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2)C;W5N="AP<F5C961I;F<M<VEB;&EN9SHZ=&5X=#IH
M6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L72D*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@*R`D<')E8V5D:6YG0VAA<'1E<DQE=F5L-0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`K(#$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&5X=#IL
M979E;#TG-B<B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H<')E
M8V5D:6YG+7-I8FQI;F<Z.G1E>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E;G0H
M*2]`=&5X=#IL979E;%TI"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@)'!R96-E9&EN9T-H
M87!T97),979E;#8*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`Q(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TB0'1E>'0Z;&5V96P])S<G(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU
M92UO9B!S96QE8W0](F-O=6YT*'!R96-E9&EN9RUS:6)L:6YG.CIT97AT.FA;
M0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=*0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`K("1P<F5C961I;F=#:&%P=&5R3&5V96PW"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("L@,2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!T97AT.FQE
M=F5L/2<X)R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;W5N="AP<F5C
M961I;F<M<VEB;&EN9SHZ=&5X=#IH6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I
M+T!T97AT.FQE=F5L72D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`D<')E8V5D:6YG0VAA
M<'1E<DQE=F5L.`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`K(#$B+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2)`=&5X=#IL979E;#TG.2<B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB8V]U;G0H<')E8V5D:6YG+7-I8FQI;F<Z.G1E>'0Z:%M`
M=&5X=#IL979E;"`](&-U<G)E;G0H*2]`=&5X=#IL979E;%TI"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("L@)'!R96-E9&EN9T-H87!T97),979E;#D*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@*R`Q(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'1E>'0Z;&5V
M96P])S$P)R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;W5N="AP<F5C
M961I;F<M<VEB;&EN9SHZ=&5X=#IH6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I
M+T!T97AT.FQE=F5L72D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`D<')E8V5D:6YG0VAA
M<'1E<DQE=F5L,3`*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`Q(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9V5T+6%B<V]L=71E+6-H87!T97(M
M;F\B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB<')E8V5D:6YG0VAA<'1E<DQE=F5L,2(@("`@
M<V5L96-T/2(D<')E8V5D:6YG0VAA<'1E<DQE=F5L,2(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@("`@("`@<V5L96-T/2(D8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IT97AT/B`F(S$V,#L@)B,Q-C`[/"]X<VPZ=&5X=#X*("`@("`@("`@("`@
M("`@("`@("`\+WAS;#II9CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F%P
M<&QY+71E;7!L871E<SX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB
M)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IA<'!L>2UT96UP;&%T97,^"@H@("`@("`@("`@("`@("`@/"]X<VPZ
M96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"@H@("`@("`@("`@
M("`\(2TM*RLK*RL@2%1-3"`T+C`@24Y,24Y%1"!705D@("LK*RLK+2T^"B`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=#4U-?
M24Y,24Y%1"<B/@H@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE
M/2)H96%D97)T>7`B('-E;&5C=#TB8V]N8V%T*"=H)RP@0'1E>'0Z;&5V96PI
M(B\^"B`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB>R1H96%D
M97)T>7!](CX*"B`@("`@("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP
M;&%T97,@<V5L96-T/2)`=&5X=#IS='EL92UN86UE(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L
M;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"@H@("`@
M("`@("`@("`@("`@("`@(#PA+2T@=W)I=&EN9R!O=70@82!C:&%P=&5R(&YU
M;6)E<B!I9B!D97-I<F5D("AN;W1I8V%B;&4@=VAE;B!A(&-O<G)E<W!O;F1I
M;F<@)W1E>'0Z;W5T;&EN92US='EL92<@97AI<W0@+2T^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#II9B!T97-T/2(D;V9F:6-E.G-T>6QE<R]T97AT.F]U
M=&QI;F4M<W1Y;&4O=&5X=#IO=71L:6YE+6QE=F5L+7-T>6QE6T!T97AT.FQE
M=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L72]`=&5X=#IS='EL92UN86UE
M(CX*"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@=&AE(&-H87!T97(@
M;G5M8F5R(&ES('1H92!S=6T@;V8@)W1E>'0Z<W1A<G0M=F%L=64G(&%N9"!P
M<F5C961I;F<@<VEB;&EN9W,@;V8@)W1E>'0Z:"<@=VET:"!T:&4@<V%M92`G
M=&5X=#IL979E;"<@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2)C;W5N="AP<F5C961I;F<M<VEB;&EN9SHZ=&5X
M=#IH6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L72D*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K("1O
M9F9I8V4Z<W1Y;&5S+W1E>'0Z;W5T;&EN92US='EL92]T97AT.F]U=&QI;F4M
M;&5V96PM<W1Y;&5;0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V
M96Q=+T!T97AT.G-T87)T+79A;'5E(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=&5X=#X@)B,Q-C`[("8C,38P.SPO>'-L.G1E>'0^"B`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ:68^"@H@("`@("`@("`@("`@("`@/"]X
M<VPZ96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@
M("`@(#PA+2T@,D1/.B!A9&0@0VAA<'1E<B!.;RX@9F]R(%!!3$T@86YD(%=-
M3"`\+3X@<')O8FQE;2!N97-T960@87!P;'DM=&5M<&QA=&5S("TM/@H*("`@
M("`@("`@("`@/"$M+2LK*RLK(%!!3$T@,RXR(%-50E-%5"!)3DQ)3D5$(%=!
M62`@*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1O=71P
M=714>7!E(#T@)U!!3$TG(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B
M;&4@;F%M93TB:&5A9&5R='EP(B!S96QE8W0](F-O;F-A="@G:"<L($!T97AT
M.FQE=F5L*2(O/@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64]
M(GLD:&5A9&5R='EP?2(^"@H*("`@("`@("`@("`@("`@("`@("`\(2TM($%L
M;"!C:&EL9')E;B!C;VYT96YT(&AA=F4@=&\@8F4@;F5S=&5D(&EN('1H92!S
M='EL97,@*&4N9RX@/&D^/&(^04Y9($-/3E1%3E0\+V(^/"]I/BD*("`@("`@
M("`@("`@("`@("`@("`@("`@(&9O<B!T:&ES('AS;#IA<'!L>2UT96UP;&%T
M97,@=VEL;"!B92!C86QL960@;&%T97(@+R!I;7!L:6-I="`M+3X*("`@("`@
M("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8W)E871E
M+6%T=')I8G5T92U!3$E'3B(^"B`@("`@("`@("`@("`@("`@("`@("`@(#PA
M+2T@9V5T=&EN9R!T:&4@8W-S('-T>6QE<R!F;W(@=&AE('-T>6QE(&YA;64@
M*&UA<'!E9"!B>2!S='EL92UM87!P:6YG+GAS;"D@+2T^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL95!R;W!E
M<G1I97,B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$O86QL<W1Y;&5S
M+RI;;F%M92@I/6-U<G)E;G0H*2]`=&5X=#IS='EL92UN86UE72(O/@H@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@
M("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H*("`@("`@("`@("`@/"$M+2LK*RLK(%=-3"`O(%=!4"`@*RLK*RLM+3X*
M("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\
M(2TM(&YO(&YE<W1E9"!P('1A9W,@:6X@=VUL,2XQ(&%L;&]W960@+2T^"B`@
M("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TB86YC97-T;W(Z.BI;8V]N=&%I;G,H)'=A<"UP
M87)A9W)A<&@M96QE;65N=',L(&YA;64H*2E=(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/"$M+2!S:6YC92!N;R!H96%D97(@<W1Y;&5S(&5X:7-T+"!A
M;B!E;7!H87-I<R!I<R!U<V5D("TM/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F5L96UE;G0@;F%M93TB96TB/@H*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PA+2T@=W)I=&EN9R!O=70@82!C:&%P=&5R(&YU;6)E<B!I
M9B!D97-I<F5D("AN;W1I8V%B;&4@=VAE;B!A(&-O<G)E<W!O;F1I;F<@)W1E
M>'0Z;W5T;&EN92US='EL92<@97AI<W0@+2T^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.FEF('1E<W0](B1O9F9I8V4Z<W1Y;&5S+W1E>'0Z
M;W5T;&EN92US='EL92]T97AT.F]U=&QI;F4M;&5V96PM<W1Y;&5;0'1E>'0Z
M;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=+T!T97AT.G-T>6QE+6YA
M;64B/@H*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM('1H
M92!C:&%P=&5R(&YU;6)E<B!I<R!T:&4@<W5M(&]F("=T97AT.G-T87)T+79A
M;'5E)R!A;F0@<')E8V5D:6YG('-I8FQI;F=S(&]F("=T97AT.F@G('=I=&@@
M=&AE('-A;64@)W1E>'0Z;&5V96PG("TM/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;W5N="AP<F5C
M961I;F<M<VEB;&EN9SHZ=&5X=#IH6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I
M+T!T97AT.FQE=F5L72D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("L@)&]F9FEC93IS='EL97,O=&5X=#IO
M=71L:6YE+7-T>6QE+W1E>'0Z;W5T;&EN92UL979E;"US='EL95M`=&5X=#IL
M979E;"`](&-U<G)E;G0H*2]`=&5X=#IL979E;%TO0'1E>'0Z<W1A<G0M=F%L
M=64B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E
M>'0^("8C,38P.R`F(S$V,#L\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ:68^"@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,@<V5L96-T/2)`=&5X=#IS='EL
M92UN86UE(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T
M/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H*("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M
M93TB<"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM('-I;F-E
M(&YO(&AE861E<B!S='EL97,@97AI<W0L(&%N(&5M<&AA<VES(&ES('5S960@
M+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@
M;F%M93TB96TB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E
M;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T
M/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S
M93X*("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L
M.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*"@H@("`@/"$M+2`J*BHJ
M*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@3&EN:R`@*BHJ("TM/@H@("`@
M/"$M+2`J*BHJ*BHJ*BHJ*BHJ("TM/@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T
M8V@](G1E>'0Z82!\(&1R87<Z82(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B\^"@H@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)C<F5A=&4M8V]M;6]N+6QI;FLB/@H@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@(#PO>'-L
M.F-A;&PM=&5M<&QA=&4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/'AS
M;#IT96UP;&%T92!N86UE/2)C<F5A=&4M8V]M;6]N+6QI;FLB/@H@("`@("`@
M(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@
M("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(FYO="@D;W5T<'5T5'EP92`]("=734PG*2(^"B`@("`@("`@("`@("`@("`\
M>'-L.F5L96UE;G0@;F%M93TB82(^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IA='1R:6)U=&4@;F%M93TB:')E9B(^/'AS;#IV86QU92UO9B!S96QE8W0]
M(D!X;&EN:SIH<F5F(B\^/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@
M("`@("`@(#PA+2T\>'-L.F%T=')I8G5T92!N86UE/2)C;&%S<R(^0V]N=&5N
M=$QI;FL\+WAS;#IA='1R:6)U=&4^+2T^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N
M=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T
M961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L
M;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@/"$M+2!N;R!N97-T960@<"!T86=S(&EN
M('=M;#$N,2!A;&QO=V5D("TM/@H@("`@("`@("`@("`@("`@/'AS;#IC:&]O
M<V4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F%N8V5S
M=&]R.CHJ6V-O;G1A:6YS*"1W87`M<&%R86=R87!H+65L96UE;G1S+"!N86UE
M*"DI72(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N
M86UE/2)A(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T
M<FEB=71E(&YA;64](FAR968B/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)`>&QI
M;FLZ:')E9B(O/CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S('-E;&5C=#TB9&5S8V5N
M9&%N=#HZ=&5X="@I(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G`B/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F$B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA
M;64](FAR968B/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)`>&QI;FLZ:')E9B(O
M/CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.F%P<&QY+71E;7!L871E<R!S96QE8W0](F1E<V-E;F1A;G0Z
M.G1E>'0H*2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N
M=#X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@
M("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO>'-L.F]T
M:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP
M;&%T93X*"@H*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@
M("`@/"$M+2`J*BH@26UA9V4@3&EN:R`@*BHJ("TM/@H@("`@/"$M+2`J*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@]
M(F1R87<Z:6UA9V4B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`\(2TM($Y/($E-04=%4R!355!0
M3$E%1"!&3U(@5T%0($]2(%!!3$T@+2T^"B`@("`@("`@/'AS;#II9B!T97-T
M/2(D;W5T<'5T5'EP92`]("=#4U-?2$5!1$52)R!O<B`D;W5T<'5T5'EP92`]
M("=#4U-?24Y,24Y%1"<B/@H*("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA
M;64](FEM9R(^"B`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](D!S=F<Z
M=VED=&@B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA
M;64](G=I9'1H(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64](F-O;G9E<G0R<&EX96PB/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G9A;'5E(B!S
M96QE8W0](D!S=F<Z=VED=&@B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`\+WAS;#II9CX*("`@("`@
M("`@("`@("`@(#QX<VPZ:68@=&5S=#TB0'-V9SIH96EG:'0B/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](FAE:6=H="(^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE
M/2)C;VYV97)T,G!I>&5L(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)V86QU92(@<V5L96-T/2)`<W9G.FAE
M:6=H="(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E
M;7!L871E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*
M("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@("`@("`@/'AS
M;#II9B!T97-T/2)S=F<Z9&5S8R(^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IA='1R:6)U=&4@;F%M93TB86QT(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-V9SID97-C(B\^"B`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@
M/"]X<VPZ:68^"B`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@
M("`@("`@("`@("`@("`@/"$M+2!F;W(@:6UA9V5S(&IA<F5D(&EN(&]P96X@
M;V9F:6-E(&1O8W5M96YT("TM/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2)C;VYT86EN<RA`>&QI;FLZ:')E9BP@)R-0:6-T=7)E<R\G
M*2(^"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@8W)E871I;F<@86X@
M86)S;VQU=&4@:'1T<"!54DP@=&\@=&AE('!A8VME9"!I;6%G92!F:6QE("TM
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE
M/2)S<F,B/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H)&IA<F5D4F]O
M=%523"P@)R]0:6-T=7)E<R\G+"!S=6)S=')I;F<M869T97(H0'AL:6YK.FAR
M968L("<C4&EC='5R97,O)RDL("1O<'1I;VYA;%523%-U9F9I>"DB+SX\+WAS
M;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M/"$M+2`@("`@("`@("`@("`@("`@("`@1'5E('1O(&$@6%0@8G5G(&YO($1/
M4R`G.B<@8F5F;W)E($12259%(&QE='1E<B!I<R!A;&QO=V5D+"!I="!W;W5L
M9"!R97-U;'0@:6X@82!U;FMO=VX@<')O=&]C;R!E>&-E<'1I;VXL(&)U="!A
M(&9I;&4@55),(&9O<B!A($1/4PH)"0D)"0EP871H(&YE961S('1H92!$4DE6
M12!L971T97(L('1H97)E9F]R92!A;&P@<F5L871I=F4@55),<R!R96UA:6X@
M<F5L871I=@H*"0D)"0D\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H0'AL:6YK
M.FAR968L)R\O)RD@;W(@*'-U8G-T<FEN9RA`>&QI;FLZ:')E9BPR+#$I(#T@
M)SHG*2!O<B!S=&%R=',M=VET:"A`>&QI;FLZ:')E9BP@)R\G*2(^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](G-R8R(^
M/'AS;#IV86QU92UO9B!S96QE8W0](D!X;&EN:SIH<F5F(B\^/"]X<VPZ871T
M<FEB=71E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#PA?GX@8W)E871I;F<@82!A8G-O;'5T92!P871H+U523"!F
M;W(@=&AE(')E9F5R96YC960@<F5S;W5R8V4@?GX^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](G-R8R(^/'AS;#IV86QU
M92UO9B!S96QE8W0](F-O;F-A="@D86)S;VQU=&53;W5R8V5$:7)2968L($!X
M;&EN:SIH<F5F+"`D;W!T:6]N86Q54DQ3=69F:7@I(B\^/"]X<VPZ871T<FEB
M=71E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*+2T^
M"@D)"0D)/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ871T<FEB=71E(&YA;64](G-R8R(^/'AS;#IV86QU92UO9B!S96QE
M8W0](D!X;&EN:SIH<F5F(B\^/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#PO
M>'-L.F-H;V]S93X*"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA
M=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@
M/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@/"$M+2!A9&1I;F<@82!L:6YE
M(&)R96%K('1O(&UA:V4@=&AE('!R97-E;G1A=&EO;B!M;W)E(&5V96X@=VET
M:"!T:&4@3T]O('9I97<@+2T^"B`@("`@("`@("`@(#QX<VPZ96QE;65N="!N
M86UE/2)B<B(O/@H@("`@("`@(#PO>'-L.FEF/@H@("`@/"]X<VPZ=&5M<&QA
M=&4^"@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@
M/"$M+2`J*BH@;W)D97)E9"!L:7-T("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H@("`@/'AS;#IT96UP;&%T92!M871C:#TB
M=&5X=#IO<F1E<F5D+6QI<W0B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB
M8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`@("`@/'AS;#IC:&]O
M<V4^"B`@("`@("`@("`@("`@("`\(2TM*RLK*RL@0U-3("A#05-#041)3D<@
M4U1,644@4TA%150I($A%041%4B!35%E,12!705D@*RLK*RLM+3X*("`@("`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=#4U-?
M2$5!1$52)R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA
M;64](F]L(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E
M;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L
M1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E
M;7!L871E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@/"$M
M+2LK*RLK($A434P@-"XP($E.3$E.140@5T%9("`K*RLK*RTM/@H@("`@("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1O=71P=714>7!E(#T@)T-34U])
M3DQ)3D5$)R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA
M;64](F]L(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E
M;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L
M1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E
M;7!L871E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@/"$M
M+2LK*RLK(%!!3$T@,RXR(%-50E-%5"!!3D0@5T%0($E.3$E.140@5T%9("`K
M*RLK*RTM/@H@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1O=71P
M=714>7!E(#T@)U!!3$TG(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F5L
M96UE;G0@;F%M93TB;VPB/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T
M961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE
M;65N=#X*("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M("`@("`\(2TM*RLK*RL@5TU,("\@5T%0("`K*RLK*RTM/@H@("`@("`@("`@
M("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@<VEM=6QA
M=&EN9R!C;VYT96YT(&)R96%K(&]F(&-A<'-U;&%T960@;&ES="!E;&5M96YT
M<R`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(F%N8V5S=&]R.CIT97AT.FQI<W0M:71E;2(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB86YC97-T;W(Z.BI;8V]N=&%I
M;G,H)'=A<"UP87)A9W)A<&@M96QE;65N=',L(&YA;64H*2E=(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!S:6UU;&%T:6YG
M(&-O;G1E;G0@8G)E86L@;V8@8V%P<W5L871E9"!L:7-T(&5L96UE;G1S("TM
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L
M96UE;G0@;F%M93TB8G(B/CPO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE
M/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB<"(^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM('-I;75L871I
M;F<@8V]N=&5N="!B<F5A:R!O9B!C87!S=6QA=&5D(&QI<W0@96QE;65N=',@
M+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F5L96UE;G0@;F%M93TB8G(B/CPO>'-L.F5L96UE;G0^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D
M8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I
M<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY
M+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`\
M+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@
M(#PO>'-L.G1E;7!L871E/@H*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@=6YO<F1E<F5D(&QI<W0@*BHJ("TM
M/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*("`@(#QX
M<VPZ=&5M<&QA=&4@;6%T8V@](G1E>'0Z=6YO<F1E<F5D+6QI<W0B/@H@("`@
M("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*
M("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/"$M+2LK*RLK($-3
M4R`H0T%30T%$24Y'(%-43%E%(%-(1454*2!(14%$15(@4U193$4@5T%9("LK
M*RLK+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP
M92`]("=#4U-?2$5!1$52)R(^"B`@("`@("`@("`@("`@("`\>'-L.F5L96UE
M;G0@;F%M93TB=6PB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T
M82(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^
M"B`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H*("`@("`@("`@("`@/"$M+2LK*RLK($A434P@-"XP($E.
M3$E.140@5T%9("`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB)&]U='!U=%1Y<&4@/2`G0U-37TE.3$E.140G(CX*("`@("`@("`@("`@
M("`@(#QX<VPZ96QE;65N="!N86UE/2)U;"(^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M
M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL
M96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^
M"B`@("`@("`@("`@(#PO>'-L.G=H96X^"@H@("`@("`@("`@("`\(2TM*RLK
M*RL@4$%,32`S+C(@4U5"4T54($%.1"!705`@24Y,24Y%1"!705D@("LK*RLK
M+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]
M("=004Q-)R(^"B`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB
M=6PB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@
M("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H*("`@("`@("`@("`@/"$M+2LK*RLK(%=-3"`O(%=!4"`@*RLK*RLM+3X*
M("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\
M>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`\(2TM('-I;75L871I
M;F<@8V]N=&5N="!B<F5A:R!O9B!C87!S=6QA=&5D(&QI<W0@96QE;65N=',@
M+2T^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F%N8V5S
M=&]R.CIT97AT.FQI<W0M:71E;2(^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](F%N8V5S=&]R.CHJ6V-O;G1A:6YS*"1W87`M<&%R86=R
M87!H+65L96UE;G1S+"!N86UE*"DI72(^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"$M+2!S:6UU;&%T:6YG(&-O;G1E;G0@8G)E86L@;V8@
M8V%P<W5L871E9"!L:7-T(&5L96UE;G1S("TM/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)B<B(^/"]X<VPZ
M96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB
M)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)P(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!S:6UU;&%T:6YG(&-O
M;G1E;G0@8G)E86L@;V8@8V%P<W5L871E9"!L:7-T(&5L96UE;G1S("TM/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE
M;G0@;F%M93TB8G(B/CPO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A
M<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O
M;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A
M=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY
M+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T
M82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#PO
M>'-L.F-H;V]S93X*("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@
M("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*"@H@("`@
M/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!L:7-T
M(&ET96T@("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM
M/@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](G1E>'0Z;&ES="UI=&5M(CX*
M("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#PA+2TK*RLK
M*R!#4U,@*$-!4T-!1$E.1R!35$Q912!32$5%5"D@2$5!1$52(%-464Q%(%=!
M62`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U
M=%1Y<&4@/2`G0U-37TA%041%4B<B/@H@("`@("`@("`@("`@("`@/'AS;#IE
M;&5M96YT(&YA;64](FQI(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A
M;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L
M871E/@H@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@(#PA+2TK*RLK*R!(5$U,(#0N
M,"!)3DQ)3D5$(%=!62`@*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](B1O=71P=714>7!E(#T@)T-34U])3DQ)3D5$)R(^"B`@("`@("`@
M("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB;&DB/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M
M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D
M8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IE;&5M
M96YT/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H*("`@("`@("`@("`@/"$M
M+2LK*RLK(%!!3$T@,RXR(%-50E-%5"!!3D0@5T%0($E.3$E.140@5T%9("`K
M*RLK*RTM/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y
M<&4@/2`G4$%,32<B/@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA
M;64](FQI(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA
M=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*"B`@("`@("`@("`@(#PA+2TK*RLK*R!734P@+R!705`@("LK*RLK
M+2T^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@
M("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](F%N8V5S=&]R.CHJ6V-O;G1A:6YS*"1W87`M<&%R86=R87!H+65L
M96UE;G1S+"!N86UE*"DI72(^"B`@("`@("`@("`@("`@("`@("`@("`@(#PA
M+2T@<VEM=6QA=&EN9R!L:7-T(&5L96UE;G1S("TM/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB86YC97-T;W(Z.G1E
M>'0Z;&ES="UI=&5M(CXJ/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=&5X=#XJ(#PO>'-L.G1E>'0^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US
M='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@
M("`@("`@("`@("`@/"$M+2!L:7-T(&ET96T@8G)E86L@<VEM=6QA=&EO;B`H
M;F]T(&EN(&$@=&%B;&4I+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ:68@=&5S=#TB;F]T*&%N8V5S=&]R.CIT86)L93IT86)L92UC96QL*2!O
M<B!F;VQL;W=I;F<M<VEB;&EN9SHZ=&5X=#IL:7-T+6ET96TB/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F)R(B\^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE
M;65N="!N86UE/2)P(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA
M+2T@<VEM=6QA=&EN9R!L:7-T(&5L96UE;G1S("TM/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](F%N8V5S=&]R
M.CIT97AT.FQI<W0M:71E;2(^*CPO>'-L.F9O<BUE86-H/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/BH@/"]X<VPZ=&5X=#X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL
M96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E
M;7!L871E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!L:7-T
M(&ET96T@8G)E86L@<VEM=6QA=&EO;B`H;F]T(&EN(&$@=&%B;&4I+2T^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](FYO="AA
M;F-E<W1O<CHZ=&%B;&4Z=&%B;&4M8V5L;"D@;W(@9F]L;&]W:6YG+7-I8FQI
M;F<Z.G1E>'0Z;&ES="UI=&5M(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB8G(B+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@
M("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S
M93X*("`@(#PO>'-L.G1E;7!L871E/@H*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@
M/"$M+2`J*BH@5&5X="!396-T:6]N("AC;VYT86EN<SH@9')A=SIT97AT+6)O
M>"D@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*("`@("`@("`\>'-L.G1E;7!L
M871E(&UA=&-H/2)T97AT.G-E8W1I;VXB/@H@("`@("`@(#QX<VPZ<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`\>'-L.FEF
M('1E<W0](FYO="AC;VYT86EN<RA`=&5X=#ID:7-P;&%Y+"`G;F]N92<I*2(^
M"B`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@/"$M
M+2LK*RLK($-34R`H0T%30T%$24Y'(%-43%E%(%-(1454*2!(14%$15(@4U19
M3$4@5T%9("LK*RLK+2T^"B`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB)&]U='!U=%1Y<&4@/2`G0U-37TA%041%4B<B/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)S<&%N(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T
M>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@/"$M+2LK*RLK($A434P@-"XP($E.3$E.
M140@5T%9("`K*RLK*RTM/@H@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](B1O=71P=714>7!E(#T@)T-34U])3DQ)3D5$)R(^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G-P86XB/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM
M<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A
M(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@("`@("`\(2TM*RLK*RL@4$%,32`S+C(@4U5"
M4T54($E.3$E.140@5T%9("`K*RLK*RTM/@H@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](B1O=71P=714>7!E(#T@)U!!3$TG(CX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](FYA;64H<&%R96YT.CHJ*2`]("=T97AT.FQI
M<W0M:71E;2<B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA
M;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L
M;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A
M;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H
M96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64]
M(G`B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L
M;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L
M;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@(#PA+2TK*RLK*R!734P@+R!705`@("LK*RLK+2T^"B`@("`@
M("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@
M("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](FYO="@D;W5T<'5T5'EP92`]("=734PG*2(^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB82(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@
M;F%M93TB:')E9B(^/'AS;#IV86QU92UO9B!S96QE8W0](D!X;&EN:SIH<F5F
M(B\^/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M
M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T
M82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PA+2T@;F\@;F5S=&5D('`@=&%G<R!I;B!W;6PQ+C$@86QL
M;W=E9"`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2)A;F-E<W1O<CHZ*EMC;VYT86EN<R@D=V%P+7!A<F%G<F%P:"UE
M;&5M96YT<RP@;F%M92@I*5TB/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y
M;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961'
M;&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM
M=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IE;&5M96YT(&YA;64](G`B/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M(F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L
M;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@/"]X<VPZ;W1H
M97)W:7-E/@H@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@/"]X
M<VPZ:68^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*("`@(#QX<VPZ=&5M<&QA
M=&4@;6%T8V@](G1E>'0Z;&EN92UB<F5A:R(^"B`@("`@("`@/'AS;#IE;&5M
M96YT(&YA;64](F)R(B\^"B`@("`\+WAS;#IT96UP;&%T93X*"@H\(2TM"B`@
M("!404)(04Y$3$E.1R!04D]"3$5-.B!486)S(&%R92!P;W-S:6)L92!T;R!B
M92!S:&]W;B!I;B!T:&4@2%1-3"!T97AT(&9I;&4L(&)U="!W:6QL(&)E(&QA
M=&5R('-T<FEP<&5D(&%S('=H:71E<W!A8V5S+@H@("`@("`@(%1O('!R979E
M;G0@=&AI<R!O;F4@=V%Y('=O=6QD(&)E('1H92!04D4@=&%G('=H:6-H('5N
M9F]R='5N871E;'D@04Q705E3(')E<W5L="!I;G1O(&$@;&EN92UB<F5A:RX@
M3F\@<W5R<F]U;F1I;F<@3D]"4B!T86=S(&AE;'`N"@H@("`@/'AS;#IT96UP
M;&%T92!M871C:#TB=&5X=#IT86(M<W1O<"(^"B`@("`@("`@/'AS;#II9B!T
M97-T/2)N;W0H<')E8V5D:6YG+7-I8FQI;F<Z.G1E>'0Z=&%B+7-T;W`I(CX*
M("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G!R92(^/'AS;#IT97AT
M/B8C.3L\+WAS;#IT97AT/CQX<VPZ9F]R+65A8V@@<V5L96-T/2)F;VQL;W=I
M;F<M<VEB;&EN9SHZ=&5X=#IT86(M<W1O<"(^/'AS;#IT97AT/B8C.3L\+WAS
M;#IT97AT/CPO>'-L.F9O<BUE86-H/CPO>'-L.F5L96UE;G0^"B`@("`@("`@
M/"]X<VPZ:68^"B`@("`@/"]X<VPZ=&5M<&QA=&4^"@H@("`@/'AS;#IT96UP
M;&%T92!M871C:#TB=&5X=#IT86(M<W1O<"(^/'AS;#IT97AT/B8C.3L\+WAS
M;#IT97AT/CPO>'-L.G1E;7!L871E/@HM+3X*("`@(#PA+2T@2$]41DE8.B`X
M(&YO;BUB<F5A:V%B;&4M<W!A8V5S(&EN<W1E860@;V8@82!404(@:7,@82!H
M86-K('-O;65T:6UE<R!L97-S(%1A8G,@87)E(&YE961E9"!A;F0@=&AE(&-O
M9&4@;6]R92!D:69F:6-U;'0@=&\@<F5A9"`M+3X*("`@(#QX<VPZ=&5M<&QA
M=&4@;6%T8V@](G1E>'0Z=&%B+7-T;W`B/@H@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)W<FET92UB<F5A:V%B;&4M=VAI=&5S<&%C92(^"B`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)W:&ET97-P86-E<R(@
M<V5L96-T/2(X(B\^"B`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@
M(#PO>'-L.G1E;7!L871E/@H*("`@(#PA+2T@8W5R<F5N=&QY('1H97)E(&AA
M=F4@=&\@8F4@86X@97AP;&EC:70@8V%L;"!O9B!T:&4@<W1Y;&4@871T<FEB
M=71E(&YO9&5S+"!M87EB92!T:&4@871T<FEB=71E<R!N;V1E<R!H879E(&YO
M('!R:6]R:71Y(&]N;'D@;W)D97(@<F5L979A;G0M+3X*("`@(#PA+2T@4U12
M04Y'13H@8VAE8VME9"!W:71H(&)I;W)Y=&AM+G-X8R!A('-I;7!L92!X<VPZ
M87!P;'DM=&5M<&QA=&5S(&1I9"!N;W0@<F5C;V=N:6-E('1H92!S='EL97,N
M($UA>6)E(&-A=7-E9"!B>2!T:&4@=&5M<&QA=&4@;6%T8V@@;W)D97(_("`M
M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC
M;VYT96YT(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L
M;V)A;$1A=&$B+SX*"B`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,@<V5L
M96-T/2)`=&5X=#IS='EL92UN86UE('P@0&1R87<Z<W1Y;&4M;F%M92!\($!D
M<F%W.G1E>'0M<W1Y;&4M;F%M92!\($!T86)L93IS='EL92UN86UE(CX\(2TM
M('P@0'!R97-E;G1A=&EO;CIS='EL92UN86UE("TM/@H@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L
M96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@(#PO>'-L.F%P
M<&QY+71E;7!L871E<SX*"B`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^
M"B`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961'
M;&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@
M("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@/"]X<VPZ=&5M<&QA
M=&4^"@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](D!T97AT.G-T>6QE+6YA
M;64@?"!`9')A=SIS='EL92UN86UE('P@0&1R87<Z=&5X="US='EL92UN86UE
M('P@0'1A8FQE.G-T>6QE+6YA;64B/CPA+2T@?"!`<')E<V5N=&%T:6]N.G-T
M>6QE+6YA;64M+3X*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@
M("`@(#PA+2TK*RLK*R!#4U,@*$-!4T-!1$E.1R!35$Q912!32$5%5"D@2$5!
M1$52(%-464Q%(%=!62`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB)&]U='!U=%1Y<&4@/2`G0U-37TA%041%4B<B/@H@("`@("`@("`@
M("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8VQA<W,B/CQX<VPZ=F%L=64M
M;V8@<V5L96-T/2)T<F%N<VQA=&4H+BP@)RX@)2@I+UPG+"`G)RDB+SX\+WAS
M;#IA='1R:6)U=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"@H@("`@("`@
M("`@("`\(2TM*RLK*RL@2%1-3"`T+C`@24Y,24Y%1"!705D@("LK*RLK+2T^
M"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=#
M4U-?24Y,24Y%1"<B/@H@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@
M;F%M93TB<W1Y;&4B/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(D8V]L;&5C=&5D
M1VQO8F%L1&%T82]A;&QS='EL97,O*EMN86UE*"D]8W5R<F5N="@I+RY=(B\^
M/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H*("`@
M("`@("`@("`@/"$M+2LK*RLK(%!!3$T@,RXR(%-50E-%5"!)3DQ)3D5$(%=!
M62`@86YD("!734P@+R!705`@("`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G4$%,32<@;W(@)&]U='!U=%1Y
M<&4@/2`G5TU,)R(^"B`@("`@("`@("`@("`@("`\(2TM(&=E='1I;F<@=&AE
M(&-S<R!S='EL97,@9F]R('1H92!S='EL92!N86UE("AM87!P960@8GD@<W1Y
M;&4M;6%P<&EN9RYX<VPI("TM/@H@("`@("`@("`@("`@("`@/'AS;#IV87)I
M86)L92!N86UE/2)S='EL95!R;W!E<G1I97,B('-E;&5C=#TB)&-O;&QE8W1E
M9$=L;V)A;$1A=&$O86QL<W1Y;&5S+RI;;F%M92@I/6-U<G)E;G0H*2\N72(O
M/@H@("`@("`@("`@("`@("`@/"$M+2!C:&%N9VEN9R!T:&4@8V]N=&5X="!N
M;V1E("TM/@H@("`@("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0]
M(G!A<F5N=#HZ*B(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E
M;7!L871E(&YA;64](F-R96%T92UN97-T960M9F]R;6%T+71A9W,B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y
M;&50<F]P97)T:65S(B!S96QE8W0](B1S='EL95!R;W!E<G1I97,B+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O
M;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A
M=&$B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E
M/@H@("`@("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ
M=&5M<&QA=&4^"@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](G1E>'0Z<V5Q
M=65N8V4B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H*("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<SX*("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@
M("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"B`@("`\+WAS;#IT96UP;&%T93X*
M"@H\+WAS;#IS='EL97-H965T/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]O;V\O9VQO8F%L7V1O8W5M96YT
M+GAS;```````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`R-3(U,S<`,3`U,34T,S,W-#<`,#(V,38P`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"`\(2TM
M"@H@("!4:&4@0V]N=&5N=',@;V8@=&AI<R!F:6QE(&%R92!M861E(&%V86EL
M86)L92!S=6)J96-T('1O('1H92!T97)M<R!O9@H@("!E:71H97(@;V8@=&AE
M(&9O;&QO=VEN9R!L:6-E;G-E<PH*("`@("`@("`@("T@1TY5($QE<W-E<B!'
M96YE<F%L(%!U8FQI8R!,:6-E;G-E(%9E<G-I;VX@,BXQ"B`@("`@("`@("`M
M(%-U;B!);F1U<W1R>2!3=&%N9&%R9',@4V]U<F-E($QI8V5N<V4@5F5R<VEO
M;B`Q+C$*"B`@(%-U;B!-:6-R;W-Y<W1E;7,@26YC+BP@3V-T;V)E<BP@,C`P
M,`H*("`@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(%9E<G-I
M;VX@,BXQ"B`@(#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/0H@("!#;W!Y<FEG:'0@,C`P,"!B>2!3=6X@36EC<F]S>7-T
M96US+"!);F,N"B`@(#DP,2!386X@06YT;VYI;R!2;V%D+"!086QO($%L=&\L
M($-!(#DT,S`S+"!54T$*"B`@(%1H:7,@;&EB<F%R>2!I<R!F<F5E('-O9G1W
M87)E.R!Y;W4@8V%N(')E9&ES=')I8G5T92!I="!A;F0O;W(*("`@;6]D:69Y
M(&ET('5N9&5R('1H92!T97)M<R!O9B!T:&4@1TY5($QE<W-E<B!'96YE<F%L
M(%!U8FQI8PH@("!,:6-E;G-E('9E<G-I;VX@,BXQ+"!A<R!P=6)L:7-H960@
M8GD@=&AE($9R964@4V]F='=A<F4@1F]U;F1A=&EO;BX*"B`@(%1H:7,@;&EB
M<F%R>2!I<R!D:7-T<FEB=71E9"!I;B!T:&4@:&]P92!T:&%T(&ET('=I;&P@
M8F4@=7-E9G5L+`H@("!B=70@5TE42$]55"!!3ED@5T%24D%.5%D[('=I=&AO
M=70@979E;B!T:&4@:6UP;&EE9"!W87)R86YT>2!O9@H@("!-15)#2$%.5$%"
M24Q)5%D@;W(@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/4T4N("!3
M964@=&AE($=.50H@("!,97-S97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!F
M;W(@;6]R92!D971A:6QS+@H*("`@66]U('-H;W5L9"!H879E(')E8V5I=F5D
M(&$@8V]P>2!O9B!T:&4@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8PH@("!,
M:6-E;G-E(&%L;VYG('=I=&@@=&AI<R!L:6)R87)Y.R!I9B!N;W0L('=R:71E
M('1O('1H92!&<F5E(%-O9G1W87)E"B`@($9O=6YD871I;VXL($EN8RXL(#4Y
M(%1E;7!L92!0;&%C92P@4W5I=&4@,S,P+"!";W-T;VXL"B`@($U!("`P,C$Q
M,2TQ,S`W("!54T$*"@H@("!3=6X@26YD=7-T<GD@4W1A;F1A<F1S(%-O=7)C
M92!,:6-E;G-E(%9E<G-I;VX@,2XQ"B`@(#T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*("`@5&AE(&-O;G1E;G1S
M(&]F('1H:7,@9FEL92!A<F4@<W5B:F5C="!T;R!T:&4@4W5N($EN9'5S=')Y
M(%-T86YD87)D<PH@("!3;W5R8V4@3&EC96YS92!697)S:6]N(#$N,2`H=&AE
M("),:6-E;G-E(BD[(%EO=2!M87D@;F]T('5S92!T:&ES(&9I;&4*("`@97AC
M97!T(&EN(&-O;7!L:6%N8V4@=VET:"!T:&4@3&EC96YS92X@66]U(&UA>2!O
M8G1A:6X@82!C;W!Y(&]F('1H90H@("!,:6-E;G-E(&%T(&AT='`Z+R]W=W<N
M;W!E;F]F9FEC92YO<F<O;&EC96YS92YH=&UL+@H*("`@4V]F='=A<F4@<')O
M=FED960@=6YD97(@=&AI<R!,:6-E;G-E(&ES('!R;W9I9&5D(&]N(&%N(")!
M4R!)4R(@8F%S:7,L"B`@(%=)5$A/550@5T%24D%.5%D@3T8@04Y9($M)3D0L
M($5)5$A%4B!%6%!215-3($]2($E-4$Q)140L($E.0TQ51$E.1RP*("`@5TE4
M2$]55"!,24U)5$%424].+"!705)204Y42453(%1(050@5$A%(%-/1E1705)%
M($E3($92144@3T8@1$5&14-44RP*("`@34520TA!3E1!0DQ%+"!&250@1D]2
M($$@4$%25$E#54Q!4B!055)03U-%+"!/4B!.3TXM24Y&4DE.1TE.1RX*("`@
M4V5E('1H92!,:6-E;G-E(&9O<B!T:&4@<W!E8VEF:6,@<')O=FES:6]N<R!G
M;W9E<FYI;F<@>6]U<B!R:6=H=',@86YD"B`@(&]B;&EG871I;VYS(&-O;F-E
M<FYI;F<@=&AE(%-O9G1W87)E+@H*("`@5&AE($EN:71I86P@1&5V96QO<&5R
M(&]F('1H92!/<FEG:6YA;"!#;V1E(&ES.B!3=6X@36EC<F]S>7-T96US+"!)
M;F,N"@H@("!#;W!Y<FEG:'0@PJD@,C`P,B!B>2!3=6X@36EC<F]S>7-T96US
M+"!);F,N"@H@("!!;&P@4FEG:'1S(%)E<V5R=F5D+@H*("`@0V]N=')I8G5T
M;W(H<RDZ(%]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7PH*+2T^"CQX<VPZ<W1Y;&5S:&5E="!V97)S:6]N/2(Q+C`B"B`@("`@("`@
M("`@("`@("!X;6QN<SIX<VP](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3DO6%-,
M+U1R86YS9F]R;2(*("`@("`@("`@("`@("`@('AM;&YS.F]F9FEC93TB:'1T
M<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O;V9F:6-E(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z<W1Y;&4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W-T
M>6QE(@H@("`@("`@("`@("`@("`@>&UL;G,Z=&5X=#TB:'1T<#HO+V]P96YO
M9F9I8V4N;W)G+S(P,#`O=&5X="(*("`@("`@("`@("`@("`@('AM;&YS.G1A
M8FQE/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]T86)L92(*("`@("`@
M("`@("`@("`@('AM;&YS.F1R87<](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R
M,#`P+V1R87=I;F<B"B`@("`@("`@("`@("`@("!X;6QN<SIF;STB:'1T<#HO
M+W=W=RYW,RYO<F<O,3DY.2]84TPO1F]R;6%T(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z>&QI;FL](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3DO>&QI;FLB"B`@
M("`@("`@("`@("`@("!X;6QN<SIN=6UB97(](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`P+V1A=&%S='EL92(*("`@("`@("`@("`@("`@('AM;&YS.G-V
M9STB:'1T<#HO+W=W=RYW,RYO<F<O,C`P,"]S=F<B"B`@("`@("`@("`@("`@
M("!X;6QN<SIC:&%R=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O8VAA
M<G0B"B`@("`@("`@("`@("`@("!X;6QN<SID<C-D/2)H='1P.B\O;W!E;F]F
M9FEC92YO<F<O,C`P,"]D<C-D(@H@("`@("`@("`@("`@("`@>&UL;G,Z;6%T
M:#TB:'1T<#HO+W=W=RYW,RYO<F<O,3DY."]-871H+TUA=&A-3"(*("`@("`@
M("`@("`@("`@('AM;&YS.F9O<FT](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R
M,#`P+V9O<FTB"B`@("`@("`@("`@("`@("!X;6QN<SIS8W)I<'0](FAT='`Z
M+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W-C<FEP="(*("`@("`@("`@("`@("`@
M(&]F9FEC93IC;&%S<STB=&5X="(*("`@("`@("`@("`@("`@(&]F9FEC93IV
M97)S:6]N/2(Q+C`B"B`@("`@("`@("`@("`@("!X;6QN<SID8STB:'1T<#HO
M+W!U<FPN;W)G+V1C+V5L96UE;G1S+S$N,2\B"B`@("`@("`@("`@("`@("!X
M;6QN<SIM971A/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]M971A(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z8V]N9FEG/2)H='1P.B\O;W!E;F]F9FEC
M92YO<F<O,C`P,2]C;VYF:6<B"B`@("`@("`@("`@("`@("!X;6QN<SIH96QP
M/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]H96QP(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z>'0](FAT='`Z+R]W=W<N:F-L87)K+F-O;2]X="(*("`@
M("`@("`@("`@("`@(&5X=&5N<VEO;BUE;&5M96YT+7!R969I>&5S/2)X="(*
M("`@("`@("`@("`@("`@('AM;&YS.G5R;&5N8V]D97(](FAT='`Z+R]W=W<N
M:F-L87)K+F-O;2]X="]J879A+VIA=F$N;F5T+E523$5N8V]D97(B"B`@("`@
M("`@("`@("`@("!X;6QN<SIS>&=H96QP97(](FAT='`Z+R]W=W<N:F-L87)K
M+F-O;2]X="]J879A+V-O;2YS=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#:&EL
M9%1R86YS9F]R;65R(@H@("`@("`@("`@("`@("`@>&UL;G,Z>&%L86X](FAT
M='`Z+R]X;6PN87!A8VAE+F]R9R]X86QA;B(*("`@("`@("`@("`@("`@('AM
M;&YS.FIA=F$](FAT='`Z+R]X;6PN87!A8VAE+F]R9R]X<VQT+VIA=F$B"B`@
M("`@("`@("`@("`@("!E>&-L=61E+7)E<W5L="UP<F5F:7AE<STB:F%V82(^
M"@H*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@1VQO8F%L($1O8W5M
M96YT("T@(%1A8FQE(&]F($-O;G1E;G0@("`@*BHJ("TM/@H@("`@/"$M+2`J
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M("TM/@H*"@H@("`@/'AS;#IT96UP;&%T92!M871C:#TB=&5X=#IT86)L92UO
M9BUC;VYT96YT(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^
M"B`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961'
M;&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@
M("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@/"]X<VPZ=&5M<&QA
M=&4^"@H*"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2)T97AT.FEN9&5X+6)O
M9'DB/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L
M1&%T82(O/@H*("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<R!M;V1E/2)C
M;VYT96YT+71A8FQE(CX*("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L
M;V)A;$1A=&$B+SX*("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"B`@
M("`\+WAS;#IT96UP;&%T93X*"@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@]
M(G1E>'0Z:6YD97@M=&ET;&4B(&UO9&4](F-O;G1E;G0M=&%B;&4B/@H@("`@
M("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*
M("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C
M=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\+WAS;#IA<'!L
M>2UT96UP;&%T97,^"B`@("`\+WAS;#IT96UP;&%T93X*"B`@("`\>'-L.G1E
M;7!L871E(&UA=&-H/2)T97AT.G)E9F5R96YC92UR968B/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@
M("`\(2TM($IA=F$@:7,@;F5E9&5D(&%S('=E(&AA=F4@=&\@96YC;V1E('1H
M92!R96QA=&EV92!L:6YK<R`H8G5G(S$P,C,Q,2D@+2T^"B`@("`@("`@/'AS
M;#II9B!T97-T/2)N;W0H)&ES2F%V841I<V%B;&5D*2(^"B`@("`@("`@("`@
M(#QX<VPZ96QE;65N="!N86UE/2)A(CX*("`@("`@("`@("`@("`@(#QX<VPZ
M871T<FEB=71E(&YA;64](FAR968B/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=&5X=#XC/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`\>'-L
M.F-A;&PM=&5M<&QA=&4@;F%M93TB96YC;V1E+7-T<FEN9R(^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#PA+2T@=&AE('-P86-E(&AA<R!T;R!B92!N;W)M
M86QI>F5D+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@;W1H97)W:7-E
M(&%N(&EL;&5G86P@87)G=6UE;G0@97AC97!T:6]N('=I;&P@8F4@=&AR;W=N
M(&9O<B!85"TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](G1E>'14;T)E16YC;V1E9"(@<V5L96-T/2)`=&5X=#IR
M968M;F%M92(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"@H@("`@
M("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@
M("`@("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*"B`@("`@("`@("`@
M(#PO>'-L.F5L96UE;G0^"B`@("`@("`@/"]X<VPZ:68^"B`@("`\+WAS;#IT
M96UP;&%T93X*"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2)T97AT.G)E9F5R
M96YC92UM87)K(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/"$M+2!*879A(&ES(&YE961E9"!A
M<R!W92!H879E('1O(&5N8V]D92!T:&4@<F5L871I=F4@;&EN:W,@*&)U9R,Q
M,#(S,3$I("TM/@H@("`@("`@(#QX<VPZ:68@=&5S=#TB;F]T*"1I<TIA=F%$
M:7-A8FQE9"DB/@H@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB82(^
M"B`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)N86UE(CX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB
M96YC;V1E+7-T<FEN9R(^"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@
M=&AE('-P86-E(&AA<R!T;R!B92!N;W)M86QI>F5D+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@;W1H97)W:7-E(&%N(&EL;&5G86P@87)G=6UE;G0@
M97AC97!T:6]N('=I;&P@8F4@=&AR;W=N(&9O<B!85"TM/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=&5X=%1O0F5%
M;F-O9&5D(B!S96QE8W0](D!T97AT.FYA;64B+SX*("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@/"]X
M<VPZ871T<FEB=71E/@H*("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M
M<&QA=&5S/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961'
M;&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP
M;&%T97,^"@H@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@(#PO
M>'-L.FEF/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\>'-L.G1E;7!L
M871E(&UA=&-H/2)T97AT.G)E9F5R96YC92UM87)K+7-T87)T(CX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@
M("`@("`@/"$M+2!*879A(&ES(&YE961E9"!A<R!W92!H879E('1O(&5N8V]D
M92!T:&4@<F5L871I=F4@;&EN:W,@*&)U9R,Q,#(S,3$I("TM/@H@("`@("`@
M(#QX<VPZ:68@=&5S=#TB;F]T*"1I<TIA=F%$:7-A8FQE9"DB/@H@("`@("`@
M("`@("`\>'-L.F5L96UE;G0@;F%M93TB82(^"B`@("`@("`@("`@("`@("`\
M>'-L.F%T=')I8G5T92!N86UE/2)N86UE(CX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB96YC;V1E+7-T<FEN9R(^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#PA+2T@=&AE('-P86-E(&AA<R!T;R!B
M92!N;W)M86QI>F5D+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@;W1H
M97)W:7-E(&%N(&EL;&5G86P@87)G=6UE;G0@97AC97!T:6]N('=I;&P@8F4@
M=&AR;W=N(&9O<B!85"TM/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB=&5X=%1O0F5%;F-O9&5D(B!S96QE8W0](D!T
M97AT.FYA;64B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E
M;7!L871E/@H@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H*("`@
M("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB96YD3V92969E<F5N
M8V4B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T
M/2)T97AT.G)E9F5R96YC92UM87)K+65N9%M`;F%M93UC=7)R96YT*"DO0'1E
M>'0Z;F%M95TB/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB<&]S:71I;VXH*2(O/@H@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F9O<BUE86-H/@H@("`@("`@("`@("`@("`@/"]X<VPZ=F%R:6%B
M;&4^"@H@("`@("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](F9O
M;&QO=VEN9RUS:6)L:6YG.CHJ6W!O<VET:6]N*"D@)FQT.R`D96YD3V92969E
M<F5N8V5=(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L
M871E<SX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IA<'!L
M>2UT96UP;&%T97,^"B`@("`@("`@("`@("`@("`\+WAS;#IF;W(M96%C:#X*
M("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@(#PO>'-L.FEF/@H@
M("`@/"]X<VPZ=&5M<&QA=&4^"@H*"@H@("`@(#PA+2T@8V]N=&5N="!T86)L
M92!L:6YK("`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](G1E>'0Z82(@
M;6]D93TB8V]N=&5N="UT86)L92(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B\^"@H*("`@("`@("`\(2TM($9O<B!A
M;F-H;W)S(&EN(&-O;G1E;G0M:&5A9&5R<R!A(&)U9R!E>&ES=',@*&-P+B!B
M=6<@:60C(#$P,C,Q,2D@86YD('1H97D@:&%V92!T;R!B92!W;W)K960@;W5T
M('-E<&%R871E;'DN"B`@("`@("`@("`@($-U<G)E;G1L>2!T:&4@;&EN:R!U
M<V5D(&EN('1H92!C;VYT96YT+71A8FQE(&]F(&%N($]F9FEC92!834P@*&4N
M9RX@:6X@=&AE(&-O;G1E;G0@=&%B;&4@87,@)R,W+E-O;64E,C!%>&%M<&QE
M)3(P2&5A9&QI;F4E-T]U=&QI;F4G*0H@("`@("`@("`@("!I<R!N;W0@82!V
M86QI9"!54DP@*&-P+B!B=6<@:60C(#$P,C,Q,2DN($YO(&9I;&4@9&5S=&EN
M871I;VX@:7,@<W!E8VEF:65D(&YO<B!E>&ES="!A;GD@86YC:&]R(&5L96UE
M;G0@9F]R('1H97-E"B`@("`@("`@("`@(&QI;FMS(&EN('1H92!/9F9I8V4@
M6$U,+"!N;W(@:7,@=&AE(&-H87!T97(@;F\N(&MN;W=N(&EN('1H92!L:6YK
M960@9FEL97,N"B`@("`@("`@("`@($$@=V]R:V%R;W5N9"!F;W(@=&AI<R!T
M<F%N<V9O<FUA=&EO;B!T:&5R969O<F4@:&%D('1O(&)E(&UA9&4N(%1H:7,@
M=&EM92UC;VYS=6UI;F<@;65C:&%N:7-M(&ES(&1I<V%B;&5D(&)Y(&1E9F%U
M;'0@86YD"B`@("`@("`@("`@(&-A;B!B92!A8W1I=F%T960@8GD@82!P87)A
M;65T97(@*&DN92X@)V1I<V%B;&5,:6YK961486)L94]F0V]N=&5N="<I+B!!
M(&-R96%T:6]N(&]F(&%N(&%N8VAO<B!I<R!M861E(&9O<B!E86-H(&AE861E
M<B!E;&5M96YT+@H@("`@("`@("`@("!!;&P@:&5A9&5R('1I=&QE<R!G;VYN
M82!B92!E;F-O9&EN9R!T;R!B92!U<V%B;&4@:6X@82!R96QA=&EV92!54DPN
M("TM/@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB)&1I<V%B;&5,:6YK961486)L94]F0V]N=&5N="!O<B`D:7-*
M879A1&ES86)L960B/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L
M871E(&YA;64](F-R96%T92UC;VUM;VXM;&EN:R(^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A
M=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@
M("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R96%T92UC;VYT96YT
M+71A8FQE+6QI;FLB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B`@("`@("!S96QE8W0]
M(B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`\+WAS
M;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^
M"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*
M"B`@("`\>'-L.G1E;7!L871E(&YA;64](F=E="UA8G-O;'5T92UC:&%P=&5R
M+6YO(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G!R96-E9&EN9T-H
M87!T97),979E;#$B+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2(D9VQO8F%L1&]C=6UE;G129694;T-U<G)E
M;G1&:6QE(CX*"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64]
M(F-U<G)E;G1&:6QE2&5A9&EN9TYO(CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9V5T+6-U<G)E;G0M9FEL92UH96%D
M:6YG+6YO(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IV87)I86)L93X*("`@
M("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB=&5S=%)E<W5L="(@
M<V5L96-T/2(D8V]N=&5N=%1A8FQE2&5A9&EN9W,O:&5A9&EN9ULD9VQO8F%L
M1&]C=6UE;G129694;T-U<G)E;G1&:6QE(#T@0&9I;&4M=7)L75MN=6UB97(H
M)&-U<G)E;G1&:6QE2&5A9&EN9TYO*5TB+SX*"B`@("`@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9V5T+6=L;V)A;"UH96%D:6YG+6YO
M(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M8W5R<F5N=$9I;&5(96%D:6YG3F\B('-E;&5C=#TB=')A;G-L871E*"1T97-T
M4F5S=6QT+T!A8G-O;'5T92UC:&%P=&5R+6QE=F5L+"`G*R<L("<N)RDB+SX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<')E
M8V5D:6YG0VAA<'1E<DQE=F5L,2(@<V5L96-T/2(D<')E8V5D:6YG0VAA<'1E
M<DQE=F5L,2(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T
M93X*"B`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`\>'-L.F]T
M:&5R=VES93X*("`@("`@("`@("`@("`@(#PA+2T@5VAE;B!T:&4@8VAA<'1E
M<B!I<R!I;B!T:&4@9VQO8F%L(&1O8W5M96YT(&ET<V5L9B!T:&4@;&EN:R!H
M87,@=&\@8F4@<F5L871I=F4@*&4N9RX@(VEN9&5X*2!A(&%B<V]L=71E(&AR
M968@9&]E<R!N;W0*("`@("`@("`@("`@("`@("`@("!W;W)K('=I=&@@=&AE
M(&)R;W=S97(N($EN(&-A<V4@;V8@8VAA<'1E<B!I;B!T:&4@9VQO8F%L(&1O
M8W5M96YT+"!T:&4@;W5T<'5T(%523"!O9B!T:&4@9VQO8F%L(&1O8W5M96YT
M('=A<R!T86ME;BX@+2T^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE
M(&YA;64](F-U<G)E;G1&:6QE2&5A9&EN9TYO(CX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9V5T+6-U<G)E;G0M9FEL
M92UH96%D:6YG+6YO(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IV87)I86)L
M93X*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB=&5S=%)E
M<W5L="(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82]C;VYT96YT+71A
M8FQE+6AE861I;F=S+VAE861I;F=;)&-O;G1E;G1486)L95523"`]($!F:6QE
M+75R;%U;;G5M8F5R*"1C=7)R96YT1FEL94AE861I;F=.;RE=(B\^"@H@("`@
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F=E="UG;&]B
M86PM:&5A9&EN9RUN;R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-U<G)E;G1&:6QE2&5A9&EN9TYO(B!S96QE8W0](G1R
M86YS;&%T92@D=&5S=%)E<W5L="]`86)S;VQU=&4M8VAA<'1E<BUL979E;"P@
M)RLG+"`G+B<I(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](G!R96-E9&EN9T-H87!T97),979E;#$B('-E;&5C=#TB)'!R
M96-E9&EN9T-H87!T97),979E;#$B+SX*("`@("`@("`@("`@("`@(#PO>'-L
M.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*
M("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@
M("`@/'AS;#IT96UP;&%T92!N86UE/2)G970M8W5R<F5N="UF:6QE+6AE861I
M;F<M;F\B/@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=S>&=H96QP97(Z9V5T
M+6-U<G)E;G0M8VAI;&0M:&5A9&EN9RUN;R<I(CX*("`@("`@("`@("`@("`@
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S>&=H96QP97(Z9V5T+6-U<G)E;G0M
M8VAI;&0M:&5A9&EN9RUN;R@I(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B
M;&4H)VIA=F$Z8V]M+G-U;BYS=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A
M;G-F;W)M97(N9V5T0W5R<F5N=$-H:6QD2&5A9&EN9TYO)RDB/@H@("`@("`@
M("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](FIA=F$Z8V]M+G-U;BYS
M=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N9V5T0W5R<F5N
M=$-H:6QD2&5A9&EN9TYO*"DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@
M("`@/'AS;#IT96UP;&%T92!N86UE/2)G970M;F5X="UC=7)R96YT+69I;&4M
M:&5A9&EN9RUN;R(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)F:6QE(B\^
M"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)W-X9VAE;'!E<CIG970M;F5X="UC
M=7)R96YT+6-H:6QD+6AE861I;F<M;F\G*2(^"B`@("`@("`@("`@("`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB<WAG:&5L<&5R.F=E="UN97AT+6-U<G)E
M;G0M8VAI;&0M:&5A9&EN9RUN;R@D9FEL92DB+SX*("`@("`@("`@("`@/"]X
M<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N
M+6%V86EL86)L92@G:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG
M0VAI;&14<F%N<V9O<FUE<BYG971.97AT0W5R<F5N=$-H:6QD2&5A9&EN9TYO
M)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](FIA
M=F$Z8V]M+G-U;BYS=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M
M97(N9V5T3F5X=$-U<G)E;G1#:&EL9$AE861I;F=.;R@D9FEL92DB+SX*("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@
M("`\+WAS;#IT96UP;&%T93X*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)G
M970M9VQO8F%L+6AE861I;F<M;F\B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M
M93TB8W5R<F5N=$9I;&5(96%D:6YG3F\B+SX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](G!R96-E9&EN9T-H87!T97),979E;#$B+SX*"B`@("`@("`@/'AS
M;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO
M;BUA=F%I;&%B;&4H)W-X9VAE;'!E<CIG970M9VQO8F%L+6AE861I;F<M;F\G
M*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<WAG
M:&5L<&5R.F=E="UG;&]B86PM:&5A9&EN9RUN;RAS=')I;F<H)&-U<G)E;G1&
M:6QE2&5A9&EN9TYO*2P@;G5M8F5R*"1P<F5C961I;F=#:&%P=&5R3&5V96PQ
M*2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G:F%V83IC;VTN<W5N
M+G-T87(N>'-L="YH96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYG971';&]B
M86Q(96%D:6YG3F\G*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG0VAI
M;&14<F%N<V9O<FUE<BYG971';&]B86Q(96%D:6YG3F\H<W1R:6YG*"1C=7)R
M96YT1FEL94AE861I;F=.;RDL(&YU;6)E<B@D<')E8V5D:6YG0VAA<'1E<DQE
M=F5L,2DI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@/"]X
M<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"@H@("`@/"$M+2!N
M96-E<W-A<GD@87,@86YC:&]R(&9O<B!T:&4@8V]N=&5N="!T86)L92`M+3X*
M("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB8W)E871E+6AE861I;F<M86YC:&]R
M(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A
M=&$B+SX*"B`@("`@("`@/"$M+0H@("`@("`@($-U<G)E;G1L>2!T:&4@;&EN
M:R!U<V5D(&EN('1H92!/9F9I8V4@6$U,("AE+F<N(&EN('1H92!C;VYT96YT
M('1A8FQE(&%S("<C-RY3;VUE)3(P17AA;7!L924R,$AE861L:6YE)3=/=71L
M:6YE)RD*("`@("`@("!I<R!N;W0@82!V86QI9"!54DP@*&-M<"X@8G5G(&ED
M(R`Q,#(S,3$I+B!.;R!F:6QE(&1E<W1I;F%T:6]N(&ES('-P96-I9FEE9"!N
M;W(@97AI<W0@86YY(&%N8VAO<B!E;&5M96YT(&9O<B!T:&5S90H@("`@("`@
M(&QI;FMS(&EN('1H92!/9F9I8V4@6$U,+@H@("`@("`@($AE<F4@=V4@87)E
M(&-R96%T:6YG(&%N(&%N8VAO<B!W:71H('1H92!S<&%C92!N;W)M86QI>F5D
M('1E>'0@;V8@=&AI<R!H96%D97(@87,@<&]T96YT:6%L(&IU;7`@861D<F5S
M<R!O9B!T:&4@8V]N=&5N="!T86)L92`M+3X*"B`@("`@("`@/'AS;#IC:&]O
M<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D9VQO8F%L1&]C=6UE
M;G129694;T-U<G)E;G1&:6QE(CX*"B`@("`@("`@("`@("`@("`\>'-L.G9A
M<FEA8FQE(&YA;64](F-U<G)E;G1&:6QE2&5A9&EN9TYO(CX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9V5T+6YE>'0M
M8W5R<F5N="UF:6QE+6AE861I;F<M;F\B/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F9I;&4B('-E;&5C=#TB)&=L
M;V)A;$1O8W5M96YT4F5F5&]#=7)R96YT1FEL92(O/@H@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\
M+WAS;#IV87)I86)L93X*"@H@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L
M92!N86UE/2)T97-T4F5S=6QT(B!S96QE8W0](B1C;VYT96YT5&%B;&5(96%D
M:6YG<R]H96%D:6YG6R1G;&]B86Q$;V-U;65N=%)E9E1O0W5R<F5N=$9I;&4@
M/2!`9FEL92UU<FQ=6VYU;6)E<B@D8W5R<F5N=$9I;&5(96%D:6YG3F\I72(O
M/@H@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO9&4B
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93Y-871C:&EN9R!C
M:&EL9"!D;V-U;65N="!H96%D97(@3F\N(#QX<VPZ=F%L=64M;V8@<V5L96-T
M/2(D8W5R<F5N=$9I;&5(96%D:6YG3F\B+SX\+WAS;#IM97-S86=E/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93YA8G-O;'5T92UC:&%P=&5R
M+6QE=F5L.B`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D=&5S=%)E
M<W5L="]`86)S;VQU=&4M8VAA<'1E<BUL979E;"(O/CPO>'-L.FUE<W-A9V4^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/F5N8V]D9614:71L
M93H@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1T
M97-T4F5S=6QT+T!E;F-O9&5D+71I=&QE(B\^/"]X<VPZ;65S<V%G93X*("`@
M("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^9VQO8F%L1&]C=6UE;G12
M9694;T-U<G)E;G1&:6QE.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&=L;V)A
M;$1O8W5M96YT4F5F5&]#=7)R96YT1FEL92(O/CPO>'-L.FUE<W-A9V4^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/BHJ*B`\+WAS;#IM97-S
M86=E/@H@("`@("`@("`@("`@("`@/"]X<VPZ:68^"@H@("`@("`@("`@("`@
M("`@/'AS;#IE;&5M96YT(&YA;64](F$B/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ871T<FEB=71E(&YA;64](FYA;64B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'1E<W1297-U;'0O0&%B
M<V]L=71E+6-H87!T97(M;&5V96PB+SX*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IT97AT/BL\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'1E<W1297-U;'0O0&5N8V]D
M960M=&ET;&4B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U
M=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@
M(#PO>'-L.G=H96X^"@H@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@/"$M+2!7:&5N('1H92!C:&%P=&5R(&ES(&EN('1H92!G
M;&]B86P@9&]C=6UE;G0@:71S96QF('1H92!L:6YK(&AA<R!T;R!B92!R96QA
M=&EV92`H92YG+B`C:6YD97@I(&$@86)S;VQU=&4@:')E9B!D;V5S(&YO=`H@
M("`@("`@("`@("`@("`@("`@('=O<FL@=VET:"!T:&4@8G)O=W-E<BX@26X@
M8V%S92!O9B!C:&%P=&5R(&EN('1H92!G;&]B86P@9&]C=6UE;G0L('1H92!O
M=71P=70@55),(&]F('1H92!G;&]B86P@9&]C=6UE;G0@=V%S('1A:V5N+B`M
M+3X*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8W5R<F5N
M=$9I;&5(96%D:6YG3F\B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L
M;"UT96UP;&%T92!N86UE/2)G970M;F5X="UC=7)R96YT+69I;&4M:&5A9&EN
M9RUN;R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB9FEL92(@<V5L96-T/2(D8V]N=&5N=%1A8FQE55),(B\^"B`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@
M("`@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H*"B`@("`@("`@("`@("`@("`\
M>'-L.G9A<FEA8FQE(&YA;64](G1E<W1297-U;'0B('-E;&5C=#TB)&-O;&QE
M8W1E9$=L;V)A;$1A=&$O8V]N=&5N="UT86)L92UH96%D:6YG<R]H96%D:6YG
M6R1C;VYT96YT5&%B;&554DP@/2!`9FEL92UU<FQ=6VYU;6)E<B@D8W5R<F5N
M=$9I;&5(96%D:6YG3F\I72(O/@H*("`@("`@("`@("`@("`@(#QX<VPZ:68@
M=&5S=#TB)&ES1&5B=6=-;V1E(CX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.FUE<W-A9V4^36%T8VAI;F<@9VQO8F%L(&1O8W5M96YT(&AE861E<B!.;RX@
M/'AS;#IV86QU92UO9B!S96QE8W0](B1C=7)R96YT1FEL94AE861I;F=.;R(O
M/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IM97-S
M86=E/F%B<V]L=71E+6-H87!T97(M;&5V96PZ("`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB)'1E<W1297-U;'0O0&%B<V]L=71E+6-H87!T97(M;&5V96PB+SX\
M+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G
M93YE;F-O9&5D5&ET;&4Z("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE
M8W0](B1T97-T4F5S=6QT+T!E;F-O9&5D+71I=&QE(B\^/"]X<VPZ;65S<V%G
M93X*("`@("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^8V]N=&5N=%1A
M8FQE55),.B`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8V]N=&5N
M=%1A8FQE55),(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@("`@
M("`\>'-L.FUE<W-A9V4^*BHJ(#PO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@
M("`@("`\+WAS;#II9CX*"B`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@
M;F%M93TB82(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@
M;F%M93TB;F%M92(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2(D=&5S=%)E<W5L="]`86)S;VQU=&4M8VAA<'1E<BUL
M979E;"(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^*SPO
M>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2(D=&5S=%)E<W5L="]`96YC;V1E9"UT:71L92(O/@H@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@
M("`@(#PO>'-L.F5L96UE;G0^"@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I
M<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H*"@H\(2TM"@H@("`@("`@(#QX
M<VPZ=F%R:6%B;&4@;F%M93TB=&ET;&4B('-E;&5C=#TB;F]R;6%L:7IE+7-P
M86-E*"XI(B\^"B`@("`@("`@/"%^?D1/3B=4(%=/4DL@("`@/'AS;#IV87)I
M86)L92!N86UE/2)T:71L92(@<V5L96-T/2)N;W)M86QI>F4M<W!A8V4H9&5S
M8V5N9&%N=#HZ=&5X="@I*2(O/B`@("`@("`@?GX^"B`@("`@("`@(#QX<VPZ
M8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&=L;V)A;$1O
M8W5M96YT4F5F5&]#=7)R96YT1FEL92(^"B`@("`@("`@("`@("`@("`\>'-L
M.G9A<FEA8FQE(&YA;64](G1E<W1297-U;'1S(B!S96QE8W0](B1C;VYT96YT
M5&%B;&5(96%D:6YG<R]H96%D:6YG6R1G;&]B86Q$;V-U;65N=%)E9E1O0W5R
M<F5N=$9I;&4@/2!`9FEL92UU<FQ=6R1T:71L92`]($!T:71L95U;8W5R<F5N
M="@I+T!T97AT.FQE=F5L(#T@0&QE=F5L72(O/@H@("`@("`@("`@("`@("`@
M/'AS;#II9B!T97-T/2(Q("9L=#L@8V]U;G0H)'1E<W1297-U;'1S*2(^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/B`J*BH@0T%55$E/3CH@
M375L=&EP;&4@8VAA<'1E<B!H96%D:6YG<R!W:71H('-I;6EL87(@;F%M97,Z
M(#PO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IM97-S
M86=E/B`J*BH@5&ET;&4Z(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D=&ET;&4B
M+SX@3&5V96PZ(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)`=&5X=#IL979E;"(O
M/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`\+WAS;#II9CX*"B`@
M("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)E;F-O9&5D5&ET
M;&4B('-E;&5C=#TB)'1E<W1297-U;'1S+T!E;F-O9&5D+71I=&QE(B\^"B`@
M("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2(D96YC;V1E9%1I=&QE(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)A(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](FYA
M;64B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2(D96YC;V1E9%1I=&QE(B\^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R
M=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@/"%^?B!E=F5N('=H96X@
M:70@:7,@;F]T('Y^/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A
M<FEA8FQE(&YA;64](FYE=T5N8V]D9614:71L92(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB96YC;V1E
M+7-T<FEN9R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"%^
M?B!T:&4@<W!A8V4@:&%S('1O(&)E(&YO<FUA;&EZ960L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&]T:&5R=VES92!A;B!I;&QE9V%L
M(&%R9W5M96YT(&5X8V5P=&EO;B!W:6QL(&)E('1H<F]W;B!F;W(@6%1^?CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](G1E>'14;T)E16YC;V1E9"(@<V5L96-T/2(D=&ET;&4B+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA
M=&4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F$B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@
M;F%M93TB;F%M92(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IV86QU92UO9B!S96QE8W0](B1N97=%;F-O9&5D5&ET;&4B+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@
M("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/'AS;#IV
M87)I86)L92!N86UE/2)T97-T4F5S=6QT<R(@<V5L96-T/2(D8V]L;&5C=&5D
M1VQO8F%L1&%T82]C;VYT96YT+71A8FQE+6AE861I;F=S+VAE861I;F=;)&-O
M;G1E;G1486)L95523"`]($!F:6QE+75R;%U;)'1I=&QE(#T@0'1I=&QE75MC
M=7)R96YT*"DO0'1E>'0Z;&5V96P@/2!`;&5V96Q=(B\^"B`@("`@("`@("`@
M("`@("`\>'-L.FEF('1E<W0](C$@)FQT.R!C;W5N="@D=&5S=%)E<W5L=',I
M(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^("HJ*B!#0554
M24]..B!-=6QT:7!L92!C:&%P=&5R(&AE861I;F=S('=I=&@@<VEM:6QA<B!N
M86UE<SH@/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@("`@("`\>'-L
M.FUE<W-A9V4^("HJ*B!4:71L93H@/'AS;#IV86QU92UO9B!S96QE8W0](B1T
M:71L92(O/B!,979E;#H@/'AS;#IV86QU92UO9B!S96QE8W0](D!T97AT.FQE
M=F5L(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@("`@("`\>'-L
M.FUE<W-A9V4^("HJ*B`\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@
M/"]X<VPZ:68^"@H@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE
M/2)E;F-O9&5D5&ET;&4B('-E;&5C=#TB)'1E<W1297-U;'1S+T!E;F-O9&5D
M+71I=&QE(B\^"B`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1E;F-O9&5D5&ET;&4B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64]
M(F$B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U
M=&4@;F%M93TB;F%M92(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1E;F-O9&5D5&ET;&4B+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\(7Y^
M(&5V96X@=VAE;B!I="!I<R!N;W0@?GX^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB;F5W16YC;V1E9%1I=&QE(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)E;F-O9&4M<W1R:6YG(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\(7Y^('1H92!S<&%C92!H87,@=&\@8F4@;F]R;6%L:7IE9"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;W1H97)W:7-E
M(&%N(&EL;&5G86P@87)G=6UE;G0@97AC97!T:6]N('=I;&P@8F4@=&AR;W=N
M(&9O<B!85'Y^/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB=&5X=%1O0F5%;F-O9&5D(B!S96QE8W0]
M(B1T:71L92(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M=F%R:6%B;&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE
M;G0@;F%M93TB82(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F%T=')I8G5T92!N86UE/2)N86UE(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&YE=T5N8V]D9614
M:71L92(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T
M<FEB=71E/@H@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N
M=#X*("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@/"]X<VPZ
M;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*"BTM/@H*("`@(#PO
M>'-L.G1E;7!L871E/@H*"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("`@($-214%424].
M($]&($$@0T].5$5.5"!404),12!,24Y+("`@("TM/@H@("`@/"$M+2`J*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"@H@("`@
M/"$M+2!A('-P96-I86P@8F5H879I;W(@;V8@=&5X=#IA"B`@("`@("`@*&-A
M;&QE9"!F<F]M('1H92`G=&5X=#IA)R!T96UP;&%T92D@+2T^"@H@("`@/'AS
M;#IT96UP;&%T92!N86UE/2)C<F5A=&4M8V]N=&5N="UT86)L92UL:6YK(CX*
M("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2)N;W0H)&]U='!U=%1Y<&4@/2`G5TU,)RDB/@H@("`@("`@("`@
M("`@("`@/'AS;#IE;&5M96YT(&YA;64](F$B/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ871T<FEB=71E(&YA;64](FAR968B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2)S=&%R=',M=VET:"A`>&QI;FLZ:')E
M9BP@)R,G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IV87)I86)L92!N86UE/2)C;W)R96-T2&5A9&EN9R(@<V5L96-T/2(D8V]L
M;&5C=&5D1VQO8F%L1&%T82]C;VYT96YT+71A8FQE+6AE861I;F=S+VAE861I
M;F=;8W5R<F5N="@I+T!X;&EN:SIH<F5F(#T@0&-O;G1E;G0M=&%B;&4M:61=
M(B\^"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2(D8V]R<F5C=$AE861I;F<O0&]U="UF:6QE+75R;"(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#XC
M/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB)&-O<G)E8W1(96%D:6YG+T!A8G-O;'5T
M92UC:&%P=&5R+6QE=F5L(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IT97AT/BL\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8V]R<F5C
M=$AE861I;F<O0&5N8V]D960M=&ET;&4B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8W)E871E+6-O;6UO
M;BUL:6YK(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E
M;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ871T<FEB=71E/@H*("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT
M96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IO=&AE<G=I
M<V4^"B`@("`@("`@("`@("`@("`\(2TM(#)$3SH@8W5R<F5N=&QY(&YO(%=-
M3"!S=7!P;W)T"@H@("`@("`@("`@("`@("`@/"%^?B!N;R!N97-T960@<"!T
M86=S(&EN('=M;#$N,2!A;&QO=V5D('Y^/@H@("`@("`@("`@("`@("`@/'AS
M;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(F%N8V5S=&]R.CHJ6V-O;G1A:6YS*"1W87`M<&%R86=R87!H+65L96UE;G1S
M+"!N86UE*"DI72(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE
M;65N="!N86UE/2)A(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ871T<FEB=71E(&YA;64](FAR968B/CQX<VPZ=F%L=64M;V8@<V5L96-T
M/2)`>&QI;FLZ:')E9B(O/CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S('-E;&5C=#TB
M+B(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ96QE;65N="!N86UE/2)P(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)A(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)H<F5F(CX\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB0'AL:6YK.FAR968B+SX\+WAS;#IA='1R
M:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA
M<'!L>2UT96UP;&%T97,@<V5L96-T/2(N(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X@("TM
M/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ
M8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"3PA+2T*"2`@("!#4D5!
M5$E/3B!/1B!!($A%3%!%4B!605))04),12!!4R!73U)+05)/54Y$($9/4B!4
M2$4@0T].5$5.5"!404),12!53%(@0E5'"@H*("`@("`@("!!<R!N;R!V86QI
M9"!54DP@9G)O;2!T:&4@8V]N=&5N="!T86)L92!T;R!T:&4@8VAI;&0@9&]C
M=6UE;G1S(&5X:7-T(&EN('1H92!C;VYT96YT('1A8FQE+`H@("`@("`@(&$@
M=V]R:RUA<F]U;F0@:7,@9&]N93H*"B`@("`@("`@1FER<W0@='=O(&AE;'!E
M<B!V87)I86)L97,@87)E(&)E:6YG(&-R96%T960N"@H@("`@("`@($]N92!C
M;VYT86EN:6YG('1H92!L:7-T(&]F(&%L;"!R969E<F5N8V5S(&]F('1H92!G
M;&]B86P@9&]C=6UE;G0Z"B`@("`@("`@8V]N=&%I;F<@86QL('1H96ER('1I
M=&QE+`H@("`@("`@(&9O<B!E>&%M<&QE.@H*("`@("`@("`@(`D\8VAA<'1E
M<BUR968@=&ET;&4](F%4:71L92`Q(B\^"B`@("`@("`@("`)/&-H87!T97(M
M<F5F('1I=&QE/2)A5&ET;&4@,B(O/@H@("`@("`@("`@"3QC:&%P=&5R+7)E
M9B!T:71L93TB851I=&QE(#(O/@H@("`@("`@("`@"3QC:&%P=&5R+7)E9B!T
M:71L93TB851I=&QE(#,O/@H*("`@("`@("!4:&4@;W1H97(@8V]N=&%I;FEN
M9R!A;&P@:&5A9&EN9R!F<F]M('1H92!C:&EL9"!D;V-U;65N=',@;&EN:V5D
M(&9R;VT@=&AE(&=L;V)A;"!D;V-U;65N="X*("`@("`@("!4:&4@=F%R:6%B
M;&4@)V-H:6QD<F5N2&5A9&EN9W,G(&-O;G1A:6YS('1H96ER('1I=&QE(&%N
M9"!T:&4@;G5M8F5R(&]F('!R96-E9&EN9R!S:6UI;&%R('1I=&QE<RP*("`@
M("`@("!F;W(@97AA;7!L93H*"@H@("`@("`@("`@"3QC:&EL9"!F:6QE+75R
M;#TB85523"(^"B`@("`@("`@("`)"3QH96%D:6YG('1I=&QE/2)A5&ET;&4Q
M(B!L979E;#TB,2(^"B`@("`@("`@("`)"3QH96%D:6YG('1I=&QE/2)A5&ET
M;&4R(B!L979E;#TB,B(^"B`@("`@("`@("`)"3QH96%D:6YG('1I=&QE/2)A
M5&ET;&4S(B!L979E;#TB,2(^"B`@("`@("`@("`@(#PO8VAI;&0^"@H@("`@
M("`@($9O<B!E86-H(&-H87!T97(@<F5F97)E;F-E(&9R;VT@=&AE(&-O;G1E
M;G0@=&%B;&4@=&AE"@H@("`@("`@("!B>2!E;F-O9&EN9R!T:&4@8VAA<'1E
M<B!N86UE<R!O9B!T:&4@8VAI;&0@9&]C=6UE;G0@=VET:"!T:&4@:F%V82!5
M4DQ%;F-O9&5R(&%N9`H@("`@("`@('5S92!T:&ES(&%S(&$@<&%R="!O9B!A
M(&QI;FLN($9U<G1H97)M;W)E(&9O<B!A;&P@:&5A9&EN9R!E;&5M96YT<R!A
M(&5N8V]D960@86YC:&]R('=I;&P@8F4@8W)E871E9"!F<F]M('1H92!H96%D
M:6YG+@H@("`@("`@($QA<W0@=&AE('=O<FMA<F]U;F0@<&%R<V5S(&%L;"!C
M:&EL9')E;B!D;V-U;65N=',@9F]R('1H:7,@86YH;W(L(&%S('1H97)E(&ES
M(&YO(&1I<W1I;F-T:6]N(&]F(&9I;&5S(&9R;VT@=&AE(&-O;G1E;G0@=&%B
M;&4@96YT<FEE<RX*"B`@("`@("`@5&AE(&YE=R!A9&1E9"!N;V1E('-E="!T
M;R!T:&4@8V]L;&5C=&5D1VQO8F%L1&%T82!V87)I86)L92!C;VYC97)I;F<@
M=&AE(&-O;G1E;G0@=&%B;&4@:7,@=W)I='1E;B!A<PH*"@D)/&-O;G1E;G0M
M=&%B;&4M:&5A9&EN9W,@8V]N=&5N="UT86)L92UU<FP](F%54DQ?5&]4:&5'
M96YE<F%T961#;VYT96YT5&%B;&4B/@H@("`@("`)"3QH96%D:6YG(&9I;&4M
M=7)L/2)A1FEL95523%1O5&AE1V5N97)A=&5D2&5A9&EN9S$B(&QE=F5L/2(Q
M(CX*("`@("`@"0D\:&5A9&EN9R!F:6QE+75R;#TB849I;&554DQ4;U1H94=E
M;F5R871E9$AE861I;F<R(B!L979E;#TB,B(^"B`@("`@(`D)/&AE861I;F<@
M9FEL92UU<FP](F%&:6QE55),5&]4:&5'96YE<F%T961(96%D:6YG,2(@;&5V
M96P](C$B/@H@("`@("`)"3QH96%D:6YG(&9I;&4M=7)L/2)A1FEL95523%1O
M5&AE1V5N97)A=&5D2&5A9&EN9S(B(&QE=F5L/2(R(CX*"0D\+V-O;G1E;G0M
M=&%B;&4M:&5A9&EN9W,^"@H*("`@("`@("!0<F5C;VYD:71I;VYS.@H)"51H
M92!C;W)R96-T('-E<75E;F-E(&]F(&-H:6QD(&1O8W5M96YT<R!A8V-O<F1I
M;F<@=&\@=&AE($-O;G1E;G0@5&%B;&4@:7,@;F5C97-S87)Y+"!G<F%N=&5D
M(&)Y('1H92!O9F9I8V4N"@DM+3X*"3QX<VPZ=&5M<&QA=&4@;F%M93TB0W)E
M871E+6AE;'!E<BUV87)I86)L97,M9F]R+4-O;G1E;G0M5&%B;&4B/@H@("`@
M("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*
M("`@("`@("`\>'-L.FEF('1E<W0](B1I<T1E8G5G36]D92(^/'AS;#IM97-S
M86=E/D-R96%T:6]N(&]F(&=L;V)A;"!D;V-U;65N="!H96QP97(@=F%R:6%B
M;&4@9F]R('1H92!C;VYT96YT('1A8FQE+BXN+CPO>'-L.FUE<W-A9V4^/"]X
M<VPZ:68^"@H@("`@("`@(#PA+2T@2&5R92!A(&AE;'!E<B!V87)I86)L92!O
M9B!T:&4@8V]N=&5N="!T86)L92!I<R!C<F5A=&5D+"!O9B!A;&P@8VAA<'1E
M<BUR969E<F5N8V5S('=H:6-H('!O:6YT('1O(&$@8VAI;&0@9&]C=6UE;G0N
M"B`@("`@("`@("`@("!A;B`G8VAA<'1E<BUR968G(&5L96UE;G0@=VEL;"!B
M92!C<F5A=&5D+"!C;VYT86EN9R!T:&5I<B!T:71L92!A;F0@=&AE(&YU;6)E
M<B!O9B!P<F5C961I;F<@<VEM:6QA<B!T:71L97,L"B`@("`@("`@("`@("!F
M;W(@97AA;7!L93H*"B`@("`@("`@("`@("`@"3QC:&%P=&5R+7)E9B!T:71L
M93TB851I=&QE(#$B+SX*("`@("`@("`@("`@("`)/&-H87!T97(M<F5F('1I
M=&QE/2)A5&ET;&4@,B(O/@H@("`@("`@("`@("`@(`D\8VAA<'1E<BUR968@
M=&ET;&4](F%4:71L92`R(B\^"B`@("`@("`@("`@("`@"3QC:&%P=&5R+7)E
M9B!T:71L93TB851I=&QE(#,B+SX*("`@("`@("`@("`@+2T^"B`@("`@("`@
M/'AS;#IV87)I86)L92!N86UE/2)C:&%P=&5R4F5F<RU25$8B/@H@("`@("`@
M("`@("`\(2TM("<O*B\G(&%S('1H92!F;&%T(&%N9"!T:&4@>FEP<&5D(%A-
M3"!F:6QE(&9O<FUA="!H879E(&1I9F9E<F5N="!R;V]T(&5L96UE;G1S("TM
M/@H@("`@("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB+RHO;V9F:6-E
M.F)O9'DO=&5X=#IT86)L92UO9BUC;VYT96YT+W1E>'0Z:6YD97@M8F]D>2]T
M97AT.G`O=&5X=#IA(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@
M;F%M93TB8W5R<F5N=%1I=&QE(B!S96QE8W0](FYO<FUA;&EZ92US<&%C92AS
M=')I;F<H+BDI(B\^"B`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M
M93TB8VAA<'1E<BUR968B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T
M<FEB=71E(&YA;64](G1I=&QE(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IV86QU92UO9B!S96QE8W0](B1C=7)R96YT5&ET;&4B+SX*("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8V]N=&5N="UT86)L92UI9"(^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T
M/2)`>&QI;FLZ:')E9B(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T
M=')I8G5T93X*("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@
M("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@/"]X<VPZ=F%R:6%B;&4^
M"B`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO9&4B/CQX<VPZ;65S
M<V%G93Y&:6YI<VAE9"!T:&4@0W)E871I;VX@;V8@9VQO8F%L(&1O8W5M96YT
M(&AE;'!E<B!V87)I86)L92!F;W(@=&AE(&-O;G1E;G0@=&%B;&4A/"]X<VPZ
M;65S<V%G93X\+WAS;#II9CX*"@H*"B`@("`@("`@/'AS;#II9B!T97-T/2(D
M:7-$96)U9TUO9&4B/CQX<VPZ;65S<V%G93Y#<F5A=&EO;B!O9B!G;&]B86P@
M9&]C=6UE;G0@:&5L<&5R('9A<FEA8FQE(&9O<B!T:&4@8VAI;&0@9&]C=6UE
M;G1S+BXN+CPO>'-L.FUE<W-A9V4^/"]X<VPZ:68^"B`@("`@("`@/"$M+2!(
M97)E(&$@:&5L<&5R('9A<FEA8FQE(&]F(&-R96%T960@9G)O;2!T:&4@8VAI
M;&1R96X@9&]C=6UE;G1S+@H@("`@("`@("`@("`@0V]N=&%I;F<@86QL(&AE
M861I;F<@96QE;65N=',@9G)O;2!T:&4@8VAI;&0@9&]C=6UE;G1S+B!3;VUE
M(&]R(&%L;"!O9B!T:&5M(&%R90H@("`@("`@("`@("`@8VAA<'1E<G,@<F5F
M97)E;F-E9"!B>2!T:&4@1VQO8F%L($1O8W5M96YT+@H@("`@("`@("`@("`@
M5&AE('9A<FEA8FQE(&-O;G1A:6YS('1H96ER('1I=&QE+"!T:&4@;&5V96P@
M;V8@=&AE(&AE861I;F<@86YD('1H92!F:6QE(%523"!O9B!T:&4@8VAI;&0L
M"B`@("`@("`@("`@("!F;W(@97AA;7!L93H*"B`@("`@("`@("`)"3QH96%D
M:6YG('1I=&QE/2)A5&ET;&4Q(B!L979E;#TB,2(@9FEL92UU<FP](F%54DPQ
M(CX*("`@("`@("`@(`D)/&AE861I;F<@=&ET;&4](F%4:71L93(B(&QE=F5L
M/2(R(B!F:6QE+75R;#TB85523#$B/@H@("`@("`@("`@"0D\:&5A9&EN9R!T
M:71L93TB851I=&QE,R(@;&5V96P](C$B(&9I;&4M=7)L/2)A55),,2(^"B`@
M("`@("`@("`)"3QH96%D:6YG('1I=&QE/2)A5&ET;&4T(B!L979E;#TB,2(@
M9FEL92UU<FP](F%54DPR(CX*("`@("`@("`@(`D)/&AE861I;F<@=&ET;&4]
M(F%4:71L934B(&QE=F5L/2(R(B!F:6QE+75R;#TB85523#(B/@H@("`@("`@
M("`@"0D\:&5A9&EN9R!T:71L93TB851I=&QE,B(@;&5V96P](C,B(&9I;&4M
M=7)L/2)A55),,B(^"B`@("`@("`@("`)"3QH96%D:6YG('1I=&QE/2)A5&ET
M;&4V(B!L979E;#TB,R(@9FEL92UU<FP](F%54DPR(CX*("`@("`@("`@("`@
M("`@(#QH96%D:6YG+6-O=6YT/C<\+VAE861I;F<M8V]U;G0^"B`@("`@("`@
M("`@("TM/@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8VAI;&1R96Y(
M96%D:6YG<RU25$8B/@H@("`@("`@("`@("`\(2TM(&%L;"!H96%D97)S(&9R
M;VT@8VAI;&1R96X@9&]C=6UE;G1S('=I;&P@8F4@861D960@+2T^"B`@("`@
M("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S('-E;&5C=#TB+RHO;V9F:6-E
M.F)O9'DO=&5X=#IS96-T:6]N(B!M;V1E/2)C<F5A=&EO;BUO9BUV87)I86)L
M92(O/@H@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H@("`@("`@(#QX<VPZ:68@
M=&5S=#TB)&ES1&5B=6=-;V1E(CX\>'-L.FUE<W-A9V4^1FEN:7-H960@=&AE
M($-R96%T:6]N(&]F(&=L;V)A;"!D;V-U;65N="!H96QP97(@=F%R:6%B;&4@
M9F]R('1H92!C:&EL9"!D;V-U;65N=',A/"]X<VPZ;65S<V%G93X\+WAS;#II
M9CX*"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=X=#IN;V1E+7-E="<I(CX*
M("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)#<F5A
M=&4M9VQO8F%L+79A<FEA8FQE+69O<BU#;VYT96YT+51A8FQE(CX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8VAA<'1E<E)E
M9G,B("`@("!S96QE8W0](GAT.FYO9&4M<V5T*"1C:&%P=&5R4F5F<RU25$8I
M(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-H:6QD<F5N2&5A9&EN9W,B("`@("!S96QE8W0](GAT.FYO9&4M<V5T*"1C
M:&EL9')E;DAE861I;F=S+5)41BDB+SX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@('-E
M;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B
M;&4H)WAA;&%N.FYO9&5S970G*2(^"B`@("`@("`@("`@("`@("`\>'-L.F-A
M;&PM=&5M<&QA=&4@;F%M93TB0W)E871E+6=L;V)A;"UV87)I86)L92UF;W(M
M0V]N=&5N="U486)L92(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-H87!T97)2969S(B`@("`@<V5L96-T/2)X86QA;CIN
M;V1E<V5T*"1C:&%P=&5R4F5F<RU25$8I(B\^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-H:6QD<F5N2&5A9&EN9W,B("`@
M("!S96QE8W0](GAA;&%N.FYO9&5S970H)&-H:6QD<F5N2&5A9&EN9W,M4E1&
M*2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B`@<V5L96-T/2(D8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T
M93X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`\+WAS;#IC:&]O
M<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*"B`@("`\>'-L.G1E;7!L871E
M(&YA;64](D-R96%T92UG;&]B86PM=F%R:6%B;&4M9F]R+4-O;G1E;G0M5&%B
M;&4B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8VAA<'1E<E)E9G,B+SX*
M("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-H:6QD<F5N2&5A9&EN9W,B+SX*
M("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M+SX*"@H@("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B=6=-;V1E(CX*("`@
M("`@("`@("`@/"$M+2!H96QP97(@=F%R:6%B;&4@8V]L;&5C=&EN9R!A;&P@
M:&5A9&EN9W,@9G)O;2!T:&4@9VQO8F%L(&1O8W5M96YT(&9I;&4@8VAI;&1R
M96XM+3X*("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1C:&EL
M9')E;DAE861I;F=S+VAE861I;F<B/@H@("`@("`@("`@("`@("`@/'AS;#IM
M97-S86=E/B,@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)P
M;W-I=&EO;B@I(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@(#QX
M<VPZ;65S<V%G93YL979E;#H@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB0&QE=F5L(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@(#QX
M<VPZ;65S<V%G93YT:71L93H@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB0'1I=&QE(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@(#QX
M<VPZ;65S<V%G93YE;F-O9&5D+71I=&QE.B`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB0&5N8V]D960M=&ET;&4B+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@
M("`@("`@/'AS;#IM97-S86=E/F9I;&4M=7)L.B`@("`@(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2)`9FEL92UU<FPB+SX\+WAS;#IM97-S86=E/@H@("`@("`@
M("`@("`@("`@/'AS;#IM97-S86=E/FAE861E<BUN;SH@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2)`:&5A9&5R+6YO(B\^/"]X<VPZ;65S<V%G93X*("`@
M("`@("`@("`@("`@(#QX<VPZ;65S<V%G93XJ*CPO>'-L.FUE<W-A9V4^"B`@
M("`@("`@("`@(#PO>'-L.F9O<BUE86-H/@H@("`@("`@("`@("`\>'-L.FUE
M<W-A9V4^*BH\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\>'-L.FUE<W-A
M9V4^*BH\+WAS;#IM97-S86=E/@H*("`@("`@("`@("`@/"$M+2!H96QP97(@
M=F%R:6%B;&4@8V]L;&5C=&EN9R!A;&P@:&5A9&EN9R!R969E<F5N8V5S(&9R
M;VT@=&AE(&-O;G1E;G0@=&%B;&4@;V8@=&AE('1H92!G;&]B86P@9&]C=6UE
M;G0@+2T^"B`@("`@("`@("`@(#QX<VPZ;65S<V%G93YC:&EL9')E;DAE861I
M;F=S+VAE861I;F<M8V]U;G0Z(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8VAI
M;&1R96Y(96%D:6YG<R]H96%D:6YG+6-O=6YT(B\^/"]X<VPZ;65S<V%G93X*
M("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1C:&%P=&5R4F5F
M<R]C:&%P=&5R+7)E9B(^"B`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^
M(R`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<&]S:71I;VXH*2(O/CPO>'-L.FUE
M<W-A9V4^"B`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^=&ET;&4Z(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)`=&ET;&4B+SX\+WAS;#IM97-S86=E/@H@
M("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/BHJ/"]X<VPZ;65S<V%G93X*
M("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@/"]X<VPZ:68^
M"@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G<WAG:&5L<&5R.G-E="UH96%D
M:6YG+6YO)RDB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@
M<V5L96-T/2)S>&=H96QP97(Z<V5T+6AE861I;F<M;F\H,2DB+SX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<WAG:&5L<&5R
M.G-E="UC=7)R96YT+6-H:6QD+6YO*#$I(B\^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-X9VAE;'!E<CIS970M8W5R<F5N
M="UC:&EL9"UU<FPH<W1R:6YG*"1C:&EL9')E;DAE861I;F=S+VAE861I;F<O
M0&9I;&4M=7)L*2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G:F%V
M83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG0VAI;&14<F%N<V9O<FUE
M<BYS971(96%D:6YG3F\G*2(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](FIA=F$Z8V]M+G-U;BYS=&%R+GAS;'0N:&5L<&5R
M+E-X9T-H:6QD5')A;G-F;W)M97(N<V5T2&5A9&EN9TYO*#$I(B\^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](FIA=F$Z8V]M
M+G-U;BYS=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N<V5T
M0W5R<F5N=$-H:6QD3F\H,2DB+SX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP
M97(N4WAG0VAI;&14<F%N<V9O<FUE<BYS971#=7)R96YT0VAI;&15<FPH<W1R
M:6YG*"1C:&EL9')E;DAE861I;F=S+VAE861I;F<O0&9I;&4M=7(I*2(O/@H@
M("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@(#PO>'-L.F-H;V]S93X*
M"B`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO9&4B/CQX<VPZ;65S
M<V%G93Y#<F5A=&EN9R!G;&]B86P@9&]C=6UE;G0@=F%R:6%B;&4@9F]R(&-H
M87!T97(@<F5L871I;VYS+BXN+CPO>'-L.FUE<W-A9V4^/"]X<VPZ:68^"B`@
M("`@("`@/'AS;#IV87)I86)L92!N86UE/2)C;VYT96YT5&%B;&5(96%D:6YG
M<T=L;V)A;$1A=&$M4E1&(CX*("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA
M;64](F-O;G1E;G0M=&%B;&4M:&5A9&EN9W,B/@H@("`@("`@("`@("`@("`@
M/"$M+2!A;&P@:&5A9&EN9W,@87)E(&QI;FME9"!F<F]M('1H92!C=7)R96YT
M(&=L;V)A;"!D;V-U;65N="!I;G!U="!F:6QE("TM/@H@("`@("`@("`@("`@
M("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8V]N=&5N="UT86)L92UU<FPB/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8V]N
M=&5N=%1A8FQE55),(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U
M=&4^"@H@("`@("`@("`@("`@("`@/"$M+2!H860@=&\@=7-E(&$@9F]R(&QO
M;W`L(&%S(&$@<F5C=7)S:6]N(&5N9',@=VET:"!A;B!S=&%C:V]V97)F;&]W
M(&5X8V5P=&EO;B!A9G1E<B!A8F]U="`V,#`@<F5C=7)S:79E(&-A;&QS("TM
M/@H@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G<WAG
M:&5L<&5R.F=E="UH96%D:6YG+6YO)RDB/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1C:&%P=&5R4F5F<R]C:&%P
M=&5R+7)E9B(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A
M;&PM=&5M<&QA=&4@;F%M93TB<V5A<F-H2&5A9&EN9TEN0VAI;&1$;V-U;65N
M="(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-H87!T97)2969S(B`@("`@("`@('-E;&5C=#TB)&-H
M87!T97)2969S(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F-H:6QD<F5N2&5A9&EN9W,B("`@('-E
M;&5C=#TB)&-H:6QD<F5N2&5A9&EN9W,B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8W5R<F5N=$-H
M87!T97)2969.;R(@<V5L96-T/2)P;W-I=&EO;B@I(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-U
M<G)E;G1(96%D:6YG3F\B("`@('-E;&5C=#TB<WAG:&5L<&5R.F=E="UH96%D
M:6YG+6YO*"DB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB8W5R<F5N=$-H:6QD55),(B`@("`@<V5L
M96-T/2)S>&=H96QP97(Z9V5T+6-U<G)E;G0M8VAI;&0M=7)L*"DB+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB8W5R<F5N=$-H:6QD3F\B("`@("`@<V5L96-T/2)S>&=H96QP97(Z
M9V5T+6-U<G)E;G0M8VAI;&0M;F\H*2(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](F9U;F-T:6]N+6%V86EL86)L92@G:F%V83IC;VTN<W5N+G-T87(N>'-L
M="YH96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYG971(96%D:6YG3F\G*2(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C
M=#TB)&-H87!T97)2969S+V-H87!T97(M<F5F(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)S96%R8VA(
M96%D:6YG26Y#:&EL9$1O8W5M96YT(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8VAA<'1E<E)E9G,B
M("`@("`@("`@<V5L96-T/2(D8VAA<'1E<E)E9G,B+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8VAI
M;&1R96Y(96%D:6YG<R(@("`@<V5L96-T/2(D8VAI;&1R96Y(96%D:6YG<R(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)C=7)R96YT0VAA<'1E<E)E9DYO(B!S96QE8W0](G!O<VET
M:6]N*"DB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB8W5R<F5N=$AE861I;F=.;R(@("`@<V5L96-T
M/2)J879A.F-O;2YS=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS
M9F]R;65R+F=E=$AE861I;F=.;R@I(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-U<G)E;G1#:&EL
M9%523"(@("`@('-E;&5C=#TB:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP
M97(N4WAG0VAI;&14<F%N<V9O<FUE<BYG971#=7)R96YT0VAI;&15<FPH*2(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)C=7)R96YT0VAI;&1.;R(@("`@("!S96QE8W0](FIA=F$Z
M8V]M+G-U;BYS=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N
M9V5T0W5R<F5N=$-H:6QD3F\H*2(O/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ=VAE;CX*("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@
M("`@("`@/"]X<VPZ96QE;65N=#X*"B`@("`@("`@("`@(#PA+2T@861D:6YG
M('1H92!A;')E861Y(&5X:7-I=&EN9R!G;&]B86P@9&%T82!E;G9I<F]N;65N
M="`M+3X*("`@("`@("`@("`@/'AS;#IC;W!Y+6]F('-E;&5C=#TB)&-O;&QE
M8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\+WAS;#IV87)I86)L93X*("`@
M("`@("`\>'-L.FEF('1E<W0](B1I<T1E8G5G36]D92(^/'AS;#IM97-S86=E
M/D9I;FES:&5D(&=L;V)A;"!D;V-U;65N="!V87)I86)L92!F;W(@8VAA<'1E
M<B!R96QA=&EO;G,A/"]X<VPZ;65S<V%G93X\+WAS;#II9CX*"B`@("`@("`@
M/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC
M=&EO;BUA=F%I;&%B;&4H)WAT.FYO9&4M<V5T)RDB/@H@("`@("`@("`@("`@
M("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G-T87)T+7-E;&8M86YD+6-H
M:6QD<F5N+71R86YS9F]R;6%T:6]N(CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@("`@
M("`@<V5L96-T/2)X=#IN;V1E+7-E="@D8V]N=&5N=%1A8FQE2&5A9&EN9W-'
M;&]B86Q$871A+5)41BDB+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM
M=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)WAA;&%N.FYO
M9&5S970G*2(^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@
M;F%M93TB<W1A<G0M<V5L9BUA;F0M8VAI;&1R96XM=')A;G-F;W)M871I;VXB
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C
M;VQL96-T961';&]B86Q$871A(B`@("`@("!S96QE8W0](GAA;&%N.FYO9&5S
M970H)&-O;G1E;G1486)L94AE861I;F=S1VQO8F%L1&%T82U25$8I(B\^"B`@
M("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L
M.G1E;7!L871E/@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64](G-E87)C:$AE
M861I;F=);D-H:6QD1&]C=6UE;G0B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M
M93TB8VAA<'1E<E)E9G,B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-H
M:6QD<F5N2&5A9&EN9W,B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-U
M<G)E;G1#:&%P=&5R4F5F3F\B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(F-U<G)E;G1(96%D:6YG3F\B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(F-U<G)E;G1#:&EL9%523"(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB
M8W5R<F5N=$-H:6QD3F\B+SX*"@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M
M93TB8W5R<F5N=$-H87!T97)2968B("`@("`@<V5L96-T/2(D8VAA<'1E<E)E
M9G,O8VAA<'1E<BUR969;)&-U<G)E;G1#:&%P=&5R4F5F3F]=(B\^"B`@("`@
M("`@/'AS;#IV87)I86)L92!N86UE/2)C=7)R96YT0VAA<'1E<DE$(B`@("`@
M("!S96QE8W0](B1C=7)R96YT0VAA<'1E<E)E9B]`8V]N=&5N="UT86)L92UI
M9"(O/@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8W5R<F5N=$-H87!T
M97)4:71L92(@("`@<V5L96-T/2(D8W5R<F5N=$-H87!T97)2968O0'1I=&QE
M(B\^"@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8W5R<F5N=$-H:6QD
M2&5A9&EN9R(@("`@<V5L96-T/2(D8VAI;&1R96Y(96%D:6YG<R]H96%D:6YG
M6R1C=7)R96YT2&5A9&EN9TYO72(O/@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@
M;F%M93TB:&5A9&EN9U1I=&QE(B`@("`@("`@("`@<V5L96-T/2(D8W5R<F5N
M=$-H:6QD2&5A9&EN9R]`=&ET;&4B+SX*("`@("`@("`\>'-L.G9A<FEA8FQE
M(&YA;64](FAE861I;F=,979E;"(@("`@("`@("`@('-E;&5C=#TB)&-U<G)E
M;G1#:&EL9$AE861I;F<O0&QE=F5L(B\^"B`@("`@("`@/'AS;#IV87)I86)L
M92!N86UE/2)H96%D:6YG3F\B("`@("`@("`@("`@("!S96QE8W0](B1C=7)R
M96YT0VAI;&1(96%D:6YG+T!H96%D97(M;F\B+SX*("`@("`@("`\>'-L.G9A
M<FEA8FQE(&YA;64](FYE=T-H:6QD55),(B`@("`@("`@("`@('-E;&5C=#TB
M)&-U<G)E;G1#:&EL9$AE861I;F<O0&9I;&4M=7)L(B\^"@H@("`@("`@(#QX
M<VPZ:68@=&5S=#TB)&ES1&5B=6=-;V1E(CX*("`@("`@("`@("`@/'AS;#IM
M97-S86=E/BHJ*B!N97<@:&5A9&EN9R`\+WAS;#IM97-S86=E/@H@("`@("`@
M("`@("`\>'-L.FUE<W-A9V4^8W5R<F5N=$-H87!T97))1#H@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](B1C=7)R96YT0VAA<'1E<DE$(B\^/"]X<VPZ;65S
M<V%G93X*("`@("`@("`@("`@/'AS;#IM97-S86=E/F-U<G)E;G1#:&%P=&5R
M5&ET;&4Z(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8W5R<F5N=$-H87!T97)4
M:71L92(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@(#QX<VPZ;65S<V%G
M93YC=7)R96YT0VAA<'1E<DE$.B`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M)&-U<G)E;G1#:&%P=&5R240B+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@
M("`\>'-L.FUE<W-A9V4^8W5R<F5N=$AE861I;F=.;SH@("`@/'AS;#IV86QU
M92UO9B!S96QE8W0](B1C=7)R96YT2&5A9&EN9TYO(B\^/"]X<VPZ;65S<V%G
M93X*("`@("`@("`@("`@/'AS;#IM97-S86=E/FAE861I;F=4:71L93H@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D:&5A9&EN9U1I=&QE(B\^/"]X
M<VPZ;65S<V%G93X*("`@("`@("`@("`@/'AS;#IM97-S86=E/FAE861I;F=,
M979E;#H@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D:&5A9&EN9TQE
M=F5L(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@/'AS;#IM97-S86=E
M/FAE861I;F=.;SH@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D
M:&5A9&EN9TYO(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@/'AS;#IM
M97-S86=E/FYE=T-H:6QD55),.B`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2(D;F5W0VAI;&154DPB+SX\+WAS;#IM97-S86=E/@H@("`@("`@(#PO
M>'-L.FEF/@H*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F]U=$9I;&55
M4DPB/@H@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TB<W5B<W1R:6YG+6)E9F]R92@D;F5W0VAI;&15
M4DPL)RYX;6PG*2(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](F-O;F-A="AS=6)S=')I;F<M8F5F;W)E*"1N97=#:&EL9%52
M3"PG+GAM;"<I+"<N:'1M)RDB+SX*("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)S=6)S=')I
M;F<M8F5F;W)E*"1N97=#:&EL9%523"PG+G-X)RDB/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H<W5B<W1R:6YG
M+6)E9F]R92@D;F5W0VAI;&154DPL)RYS>"<I+"<N:'1M)RDB+SX*("`@("`@
M("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\+WAS;#IC:&]O
M<V4^"B`@("`@("`@/"]X<VPZ=F%R:6%B;&4^"B`@("`@("`@/'AS;#IV87)I
M86)L92!N86UE/2)I<T-H87!T97)(96%D:6YG(B!S96QE8W0](B1H96%D:6YG
M5&ET;&4@/2`D8W5R<F5N=$-H87!T97)4:71L92(O/@H@("`@("`@(#QX<VPZ
M=F%R:6%B;&4@;F%M93TB:7-.97=&:6QE(B!S96QE8W0](G-T<FEN9R@D;F5W
M0VAI;&154DPI("$]('-T<FEN9R@D8W5R<F5N=$-H:6QD55),*2(O/@H*"@H*
M("`@("`@("`\>'-L.FEF('1E<W0](B1I<TYE=T9I;&4B/@H@("`@("`@("`@
M("`\(2TM(')E<V5T(&]F('1H92!A;')E861Y(&-O;&QE8W1E9"!C:&EL9"!H
M96%D97)S("TM/@H@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TB8V%L8RUC:&%P=&5R+6YU;6)E<G,B/@H@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)L979E;"(@<V5L96-T/2(P(B\^"B`@("`@
M("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@/"]X<VPZ:68^
M"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)A8G-O;'5T94-H87!T97),
M979E;"(^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C
M86QC+6-H87!T97(M;G5M8F5R<R(^"B`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](FQE=F5L(B!S96QE8W0](FYU;6)E<B@D:&5A9&EN
M9TQE=F5L*2(O/@H@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@
M("`@("`@(#PO>'-L.G9A<FEA8FQE/@H*"B`@("`@("`@/'AS;#IE;&5M96YT
M(&YA;64](FAE861I;F<B/@H@("`@("`@("`@("`\(2TM(&YE8V5S<V%R>2!T
M;R!A<R!)1"!F<F]M('1H92!C;VYT96YT('1A8FQE('1O(&=E="!T:&4@8V]R
M<F5C="!H96%D:6YG(&5L96UE;G0@*'1H92!B=6=G>2!54DP@=7-E9"!A<R!)
M1"DM+3X*("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8V]N=&5N
M="UT86)L92UI9"(^"B`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&ES0VAA<'1E<DAE
M861I;F<B/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB)&-U<G)E;G1#:&%P=&5R240B+SX*("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H
M97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^;VYL
M>2!A(&AE861I;F<L(&)U="!N;W0@82!C:&%P=&5R/"]X<VPZ=&5X=#X*("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@
M("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T
M93X*("`@("`@("`@("`@/"$M+2!N;R!O9B!T:&4@=7-E9"!C:&EL9"P@;F5C
M97-S87)Y(&9O<B!Q=6EC:R!F:6YD:6YG(&]F(&-H87!T97)S(&]F(&YE>'0@
M9FEL92`@+2T^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F-H
M:6QD+61O8W5M96YT+6YO(CX*("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D:7-.97=&
M:6QE(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](B1C=7)R96YT0VAI;&1.;R`K(#$B+SX*("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H
M97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB)&-U<G)E;G1#:&EL9$YO(B\^"B`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@
M(#PA+2T@=&AE(%523"!O9B!T:&4@8VAI;&0@9&]C=6UE;G0@<V]U<F-E+"!C
M;VYT86EN:6YG('1H92!H96%D:6YG("TM/@H@("`@("`@("`@("`\>'-L.F%T
M=')I8G5T92!N86UE/2)F:6QE+75R;"(^"B`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB)&YE=T-H:6QD55),(B\^"B`@("`@("`@("`@
M(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@
M;F%M93TB;W5T+69I;&4M=7)L(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2(D;W5T1FEL95523"(O/@H@("`@("`@("`@("`\+WAS
M;#IA='1R:6)U=&4^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64]
M(FQE=F5L(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T
M/2(D:&5A9&EN9TQE=F5L(B\^"B`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T
M93X*("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB=&ET;&4B/@H@
M("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1H96%D:6YG
M5&ET;&4B+SX*("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@
M("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)E;F-O9&5D+71I=&QE(CX*("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8W5R<F5N=$-H
M:6QD2&5A9&EN9R]`96YC;V1E9"UT:71L92(O/@H@("`@("`@("`@("`\+WAS
M;#IA='1R:6)U=&4^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64]
M(F%B<V]L=71E+6-H87!T97(M;&5V96PB/@H@("`@("`@("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](B1A8G-O;'5T94-H87!T97),979E;"(O/@H@
M("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@/"]X<VPZ96QE
M;65N=#X*"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB)&-H:6QD<F5N2&5A9&EN9W,O:&5A9&EN9RUC;W5N="`A
M/2`D8W5R<F5N=$AE861I;F=.;R(^"B`@("`@("`@("`@("`@("`\(2TM('!R
M;V-E9&4@87,@;&]N9R!T:&4@;&ES="!O9B!C:&EL9')E;B!I<VXG;G0@=V]R
M:V5D('1H<F]U9V@@+2T^"B`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&ES0VAA<'1E
M<DAE861I;F<B/@H@("`@("`@("`@("`@("`@("`@("`@("`\(2TM(&=L;V)A
M;"!V87)I86)L97,@:&%V92!T;R!B92!S970L('-O('1H92!F;W(M96%C:"!L
M;V]P(&-A;B!A8V-E<W,@=&AE;2`M+3X*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=S>&=H96QP97(Z
M<V5T+6AE861I;F<M;F\G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-X9VAE;'!E<CIS970M:&5A
M9&EN9RUN;R@D8W5R<F5N=$AE861I;F=.;R`K(#$I(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2(D:7-.97=&:6QE
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](G-X9VAE;'!E<CIS970M8W5R<F5N="UC:&EL9"UN
M;R@D8W5R<F5N=$-H:6QD3F\@*R`Q*2(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<WAG:&5L
M<&5R.G-E="UC=7)R96YT+6-H:6QD+75R;"AS=')I;F<H)&YE=T-H:6QD55),
M*2DB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#II
M9CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U
M;F-T:6]N+6%V86EL86)L92@G:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP
M97(N4WAG0VAI;&14<F%N<V9O<FUE<BYS971(96%D:6YG3F\G*2(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE
M8W0](FIA=F$Z8V]M+G-U;BYS=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A
M;G-F;W)M97(N<V5T2&5A9&EN9TYO*"1C=7)R96YT2&5A9&EN9TYO("L@,2DB
M+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E
M<W0](B1I<TYE=T9I;&4B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB:F%V83IC;VTN<W5N+G-T
M87(N>'-L="YH96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYS971#=7)R96YT
M0VAI;&1.;R@D8W5R<F5N=$-H:6QD3F\@*R`Q*2(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG0VAI;&14<F%N<V9O
M<FUE<BYS971#=7)R96YT0VAI;&15<FPH)&YE=T-H:6QD55),*2(O/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I
M<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@;F]T(&$@8VAA<'1E
M<B!H96%D:6YG+"!C86QL(&ET<V5L9B!U;G1I;"!A(&-H87!T97(@<F5F(&ES
M(&9O=6YD(&]R('1H92!E;F0@;V8@:&5A9&EN9W,@:7,@<F5A8VAE9"`M+3X*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA
M;64](G-E87)C:$AE861I;F=);D-H:6QD1&]C=6UE;G0B/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-H87!T
M97)2969S(B`@("`@("`@('-E;&5C=#TB)&-H87!T97)2969S(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M8VAI;&1R96Y(96%D:6YG<R(@("`@<V5L96-T/2(D8VAI;&1R96Y(96%D:6YG
M<R(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](F-U<G)E;G1#:&%P=&5R4F5F3F\B('-E;&5C=#TB)&-U<G)E
M;G1#:&%P=&5R4F5F3F\B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C=7)R96YT2&5A9&EN9TYO(B`@("!S
M96QE8W0](B1C=7)R96YT2&5A9&EN9TYO("L@,2(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-U<G)E;G1#
M:&EL9%523"(@("`@('-E;&5C=#TB)&-U<G)E;G1#:&EL9%523"(O/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-U<G)E;G1#:&EL9$YO(B`@("`@('-E;&5C=#TB)&-U<G)E;G1#:&EL9$YO
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA
M=&4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@
M("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B=6=-;V1E(CX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.FUE<W-A9V4^06QL(&-H:6QD(&1O8W5M96YT<R!H879E
M(&)E96X@=V%L:V5D('1H<F]U9V@@=VET:&]U="!F:6YD:6YG('1H92!C:&%P
M=&5R(&YA;64A/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@("`@("`\
M>'-L.FUE<W-A9V4^("`@("`@(&-H:6QD<F5N2&5A9&EN9W,O:&5A9&EN9RUC
M;W5N=#H@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1C:&EL9')E;DAE861I
M;F=S+VAE861I;F<M8V]U;G0B+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ;65S<V%G93X@("`@("`@8W5R<F5N=$AE861I;F=.
M;SH@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&-U
M<G)E;G1(96%D:6YG3F\B+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ:68^"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@
M("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*"@H)
M/"$M+2!#:&%P=&5R<R!F<F]M('1H92!#;VYT96YT(%1A8FQE(&AA=F4@8W5R
M<F5N=&QY(&YO(&%N8VAO<B!T;R!C:&EL9"!D;V-U;65N=',@:6X@3T]O(%A-
M3"X*"0D@07,@<V]L=71I;VXL('=H96YE=F5R(&$@82!G;&]B86P@9&]C=6UE
M;G0@(&5V97)Y(&AE861E<B!O9B!T:&4@2%1-3"!O=71P=70@9V5T<R!G970G
M<R!A;B!A;F-H;W(@:6X@=&AE(%1H97)E9F]R92TM/@H@("`@/'AS;#IT96UP
M;&%T92!N86UE/2)E;F-O9&4M<W1R:6YG(CX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](F5N8V]D:6YG(B!S96QE8W0](B=55$8M."<B+SX*("`@("`@("`\
M>'-L.G!A<F%M(&YA;64](G1E>'14;T)E16YC;V1E9"(O/@H*("`@("`@("`\
M>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T
M:6]N+6%V86EL86)L92@G=7)L96YC;V1E<CIE;F-O9&4G*2(^"B`@("`@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB=7)L96YC;V1E<CIE;F-O
M9&4H;F]R;6%L:7IE+7-P86-E*"1T97AT5&]"945N8V]D960I+"1E;F-O9&EN
M9RDB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G:F%V83IJ879A+FYE
M="Y54DQ%;F-O9&5R+F5N8V]D92<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2)J879A.FIA=F$N;F5T+E523$5N8V]D97(N96YC
M;V1E*'-T<FEN9RAN;W)M86QI>F4M<W!A8V4H)'1E>'14;T)E16YC;V1E9"DI
M+'-T<FEN9R@D96YC;V1I;F<I*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*
M"@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@
M(%1204Y31D]234%424].($]&($%,3"!#2$E,1"!$3T-5345.5%,@3T8@5$A%
M($=,3T)!3"!$3T-5345.5%,@0ED@55-)3D<@02!%6%1%4DY!3"!(14Q015(@
M0TQ!4U,@("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H*
M"3PA+2T@82!N97<@96QE;65N="`G8V]N=&5N=%1A8FQE2&5A9&EN9W,G('=I
M;&P@8F4@861D960@=&\@=&AE(&AE;'!E<B!V87)I86)L92!T:&4@9FER<W0@
M=&EM92!A(&-H:6QD('=I;&P@8F4@=')A;G-F;W)M960@+2T^"B`@("`\>'-L
M.G1E;7!L871E(&YA;64](G1R86YS9F]R;2UG;&]B86PM9&]C=6UE;G0M86YD
M+6-H:6QD<F5N(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$O8V]N
M=&5N="UT86)L92UH96%D:6YG<R(^"B`@("`@("`@("`@("`@("`\>'-L.F-A
M;&PM=&5M<&QA=&4@;F%M93TB<W1A<G0M8VAI;&0M=')A;G-F;W)M871I;VXB
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C
M;VQL96-T961';&]B86Q$871A(B`@('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^
M"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H
M97)W:7-E/@H)("`@("`@("`@("`@/"$M+2!4:&4@;F5C97-S87)Y(&%U>&EL
M:6%R>2!V87)I86)L92!H87-N)W0@8G5I;&0@>65T+@H)("`@("`@("`@("`@
M5&AI<R!V87)I86)L92!G;VYN82!S=&]R92!A;&P@:&5A9&5R<R`H=VET:"!C
M:&%P=&5R(&YU;6)E<G,I(&%N9"!T:&4@55),(&]F('1H96ER(&9I;&5S("TM
M/@H*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)#
M<F5A=&4M:&5L<&5R+79A<FEA8FQE<RUF;W(M0V]N=&5N="U486)L92(^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE
M8W1E9$=L;V)A;$1A=&$B("`@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T
M82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*"B`@
M("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O
M<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*"3QX<VPZ=&5M<&QA=&4@;F%M
M93TB<W1A<G0M<V5L9BUA;F0M8VAI;&1R96XM=')A;G-F;W)M871I;VXB/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O
M/@H*("`@("`@("`\>'-L.FEF('1E<W0](B1I<T1E8G5G36]D92(^"B`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)D96)U9RUC;VYT96YT
M+71A8FQE+6AE861I;F=S+79A<FEA8FQE(CX*("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE
M8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@(#PO>'-L
M.F-A;&PM=&5M<&QA=&4^"@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^4&%R
M<VEN9R!T:&4@9VQO8F%L(&1O8W5M96YT+BXN/"]X<VPZ;65S<V%G93X*("`@
M("`@("`\+WAS;#II9CX*"B`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^
M"B`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961'
M;&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@
M("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H*"B`@("`@("`@/'AS;#II
M9B!T97-T/2(D:7-$96)U9TUO9&4B/CQX<VPZ;65S<V%G93Y087)S:6YG('1H
M92!C:&EL9"!D;V-U;65N=',N+BX\+WAS;#IM97-S86=E/CPO>'-L.FEF/@H@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)S=&%R="UC:&EL9"UT
M<F%N<V9O<FUA=&EO;B(^"B`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961'
M;&]B86Q$871A(B\^"B`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*"@D\
M+WAS;#IT96UP;&%T93X*"@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64](G-T
M87)T+6-H:6QD+71R86YS9F]R;6%T:6]N(CX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/'AS;#II
M9B!T97-T/2(D:7-$96)U9TUO9&4B/CQX<VPZ;65S<V%G93Y3=&%R=&EN9R!T
M:&4@8VAI;&0@=')A;G-F;W)M871I;VYS+BXN/"]X<VPZ;65S<V%G93X\+WAS
M;#II9CX*"B`@("`@("`@/"$M+2!!<R!T:&4@8VAI;&1S(&]F(&$@9VQO8F%L
M(&1O8W5M96YT("AW:71H('-U9F9I>"`N<WAG*2!D;R!N;W0@:VYO=R!A;GET
M:&EN9R!A8F]U="!T:&5I<B!G;&]B86P@<&%R96YT+`H@("`@("`@("`@("!T
M:&4@=')A;G-F;W)M871I;VX@;V8@9VQO8F%L(&1O8W5M96YT<R!C:&EL9')E
M;B!H879E('1O(&)E(&1O;F4@:6UP;&EZ:70N"B`@("`@("`@("`@($]T:&5R
M=VES92!T:&4@8VAA<'1E<B!N=6UB97(@;V8@=&AE(&-H:6QD<F5N('=I;&P@
M86QW87ES('-T87)T('=I=&@@>F5R;RP@87,@=&AE>2!D;R!N;W0@:VYO=R!A
M;GET:&EN9R!A8F]U="!T:&4*("`@("`@("`@("`@<')O8V5D:6YG(&-H87!T
M97)S+@H@("`@("`@("`@("!&=7)T:&5R;6]R92P@=&AE>2!D;VXG="!H879E
M(&%N>2!L:6YK<R!A8F]U="!P<F5C965D:6YG(&%N9"!F;VQL;W=I;F<@9&]C
M=6UE;G1S(&%N9"!N;R!L:6YK:6YG(&9O<B!U<V%B:6QI='D@<F5A<V]N<PH@
M("`@("`@("`@("!C;W5L9"!B92!D;VYE+B!4:&5R969O<F4@=&AE(&-H:6QD
M<F5N(&AA=F4@=&\@8F4@=')A;G-F;W)M960@9'5R:6YG('1H92!T<F%N<V9O
M<FUA=&EO;B!O9B!A(&=L;V)A;"`H<WAG*2!D;V-U;65N="`M+3X*"0D\>'-L
M.FEF('1E<W0](B1I<T1E8G5G36]D92(^"B`@("`@("`@("`@(#QX<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1C;VQL96-T
M961';&]B86Q$871A+V-O;G1E;G0M=&%B;&4M:&5A9&EN9W,B/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ;65S<V%G93Y#;VYT96YT86)L92!D871A(&5X
M:7-T<R!A<R!G;&]B86P@9&%T82$\+WAS;#IM97-S86=E/@H@("`@("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93Y.;R!#;VYT
M96YT86)L92!G;&]B86P@9&%T82!E>&ES=',A/"]X<VPZ;65S<V%G93X*("`@
M("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@/"]X
M<VPZ8VAO;W-E/@H@("`@("`@(#PO>'-L.FEF/@H*("`@("`@("`\(2TM(&-U
M<G)E;G1L>2!T:&ES(&9U;F-T:6]N(&]N;'D@=V]R:W,@=VET:"!N;V1E+7-E
M=',@9G)O;2!85"`M+3X*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G<WAG:&5L
M<&5R.G1R86YS9F]R;2UC:&EL9')E;B<I(CX*("`@("`@("`@("`@("`@(#QX
M<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB<WAG:&5L<&5R.G1R86YS9F]R;2UC:&EL9')E;B@@)&-O;&QE
M8W1E9$=L;V)A;$1A=&$O8V]N=&5N="UT86)L92UH96%D:6YG<RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<W1R:6YG*"1J87)E9%)O;W154DPI+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!S=')I;F<H)&%B<V]L=71E4V]U
M<F-E1&ER4F5F*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R:6YG
M*"1O<'1I;VYA;%523%-U9F9I>"DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('-T<FEN9R@D9'!I*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<W1R:6YG*"1O=71P=714>7!E*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&ES1&5B=6=-;V1E*2(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ;65S
M<V%G93X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS
M;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^2F%V
M82!M971H;V0@=')A;G-F;W)M0VAI;&1R96X@=&\@=')A;G-F;W)M(&%L;"!C
M:&EL9')E;B!O9B!A(&=L;V)A;"!D;V-U;65N="!C;W5L9"!N;W0@8F4@9F]U
M;F0N($)E('-U<F4@=&\@=7-E('1H92!85"!P<F]C97-S;W(N/"]X<VPZ;65S
M<V%G93X*("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO
M>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*"@H*"B`@("`\(2TM
M("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\
M(2TM("HJ*B`@0W)E871I;VX@;V8@:&5L<&5R('9A<FEA8FQE(&]F('1H92!H
M96%D:6YG<R!O9B!A;&P@8VAI;&1R96X@9&]C=6UE;G1S("`J*BH@+2T^"B`@
M("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^
M"@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](B\J+V]F9FEC93IB;V1Y+W1E
M>'0Z<V5C=&EO;B(@;6]D93TB8W)E871I;VXM;V8M=F%R:6%B;&4B/@H@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G971#:&EL9%)O;W1.;V1E
M(B\^"@H@("`@("`@(#PA+2T@869T97(@=&AE(&QA<W0@8VAI;&0@9&]C=6UE
M;G0@=&AE(&=L;V)A;"!D;V-U;65N="!W:6QL(&)E('!A<G-E9"`M+3X*("`@
M("`@("`\>'-L.FEF('1E<W0](G!O<VET:6]N*"D@/2!L87-T*"DB/@H@("`@
M("`@("`@("`\(2TM('-E87)C:"!T:&4@9VQO8F%L(&1O8W5M96YT(&%F=&5R
M(&%L;"!C:&EL9"!D;V-U;65N=',@:&%V92!B965N('-E87)C:&5D"@I/1$L@
M4$%40T@@3D\@24Y$15@@14Q%345.5"!704Y4140@(2$@+2!N=6QL('!O:6YT
M97(@97AC97!T:6]N"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)G9710<F5V:6]U<TAE861E<DYO(CX*("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)F:6QE55),(B`@("`@("`@("`@("`@("`@
M('-E;&5C=#TB)&-O;G1E;G1486)L95523"(O/@H@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F%M;W5N=$]F0W5R<F5N=$AE861I;F<B
M("`@<V5L96-T/2)C;W5N="AF;VQL;W=I;F<M<VEB;&EN9SHZ=&5X=#IH*2(O
M/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FYO9&54
M;U-E87)C:$9O<DAE861I;F<B("`@<V5L96-T/2)F;VQL;W=I;F<M<VEB;&EN
M9SHZ=&5X=#IH(B\^"B`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^
M"BTM/@H@("`@("`@("`@(#PA+2T@9V5T('1H92!O=F5R86QL($YO(&]F($AE
M861E<G,@+2T^"B`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M(F=E=$%L;$AE861E<DYO(B\^"B`@("`@("`@/"]X<VPZ:68^"B`@("`\+WAS
M;#IT96UP;&%T93X*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)G971#:&EL
M9%)O;W1.;V1E(CX*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F9I;&55
M4DPB("`@('-E;&5C=#TB=&5X=#IS96-T:6]N+7-O=7)C92]`>&QI;FLZ:')E
M9B(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`)/"$M+2!I
M9B!A8G-O;'5T92!54DP@;W(@86)S;VQU=&4@1$]3(%!!5$@@;W(@86)S;VQU
M=&4@56YI>"!P871H("TM/@H)"0D\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H
M)&9I;&554DPL)R\O)RD@;W(@*'-U8G-T<FEN9R@D9FEL95523"PR+#$I(#T@
M)SHG*2!O<B!S=&%R=',M=VET:"@D9FEL95523"P@)R\G*2(^"B`@("`)"0D\
M>'-L.G9A<FEA8FQE(&YA;64](F-H:6QD4F]O=$YO9&4B('-E;&5C=#TB9&]C
M=6UE;G0H)&9I;&554DPI(B\^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM
M=&5M<&QA=&4@;F%M93TB9V5T4')E=FEO=7-(96%D97).;R(^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F9I;&554DPB("`@
M("`@("`@("`@("`@('-E;&5C=#TB)&9I;&554DPB+SX*("`@("`@("`@("`@
M("`@(`D\(2TM($Y/(&%B<V]L=71E('-O=7)C92!P871H('=I;&P@8F4@861D
M960@87,@<')E9FEX("TM/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)A;6]U;G1/9D-U<G)E;G1(96%D:6YG(B!S96QE8W0]
M(F-O=6YT*"1C:&EL9%)O;W1.;V1E+RHO;V9F:6-E.F)O9'DO9&5S8V5N9&%N
M=#HZ=&5X=#IH*2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)N;V1E5&]396%R8VA&;W)(96%D:6YG(B!S96QE8W0](B1C
M:&EL9%)O;W1.;V1E+RHO;V9F:6-E.F)O9'DO9&5S8V5N9&%N=#HZ=&5X=#IH
M(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES
M93X*("`@(`D)"3QX<VPZ=F%R:6%B;&4@;F%M93TB8VAI;&12;V]T3F]D92(@
M<V5L96-T/2)D;V-U;65N="AC;VYC870H)&%B<V]L=71E4V]U<F-E1&ER4F5F
M+"<O)RPD9FEL95523"DI(B\^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM
M=&5M<&QA=&4@;F%M93TB9V5T4')E=FEO=7-(96%D97).;R(^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F9I;&554DPB("`@
M("`@("`@("`@("`@('-E;&5C=#TB)&9I;&554DPB+SX*("`@("`@("`@("`@
M("`@(`D\(2TM('1H92!A8G-O;'5T92!S;W5R8V4@<&%T:"!W:6QL(&)E(&%D
M9&5D(&%S('!R969I>"`M+3X*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB86UO=6YT3V9#=7)R96YT2&5A9&EN9R(@<V5L96-T
M/2)C;W5N="@D8VAI;&12;V]T3F]D92\J+V]F9FEC93IB;V1Y+V1E<V-E;F1A
M;G0Z.G1E>'0Z:"DB+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB;F]D951O4V5A<F-H1F]R2&5A9&EN9R(@<V5L96-T/2(D
M8VAI;&12;V]T3F]D92\J+V]F9FEC93IB;V1Y+V1E<V-E;F1A;G0Z.G1E>'0Z
M:"(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@
M("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S
M93X*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\>'-L.G1E;7!L871E(&YA
M;64](F=E=%!R979I;W5S2&5A9&5R3F\B/@H@("`@("`@(#QX<VPZ<&%R86T@
M;F%M93TB9FEL95523"(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB;F]D
M951O4V5A<F-H1F]R2&5A9&EN9R(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M
M93TB86UO=6YT3V9#=7)R96YT2&5A9&EN9R(O/@H*("`@("`@("`\>'-L.F-H
M;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V
M86EL86)L92@G<WAG:&5L<&5R.F=E="UP<F5V:6]U<RUC:&EL9"UD;V-U;65N
M=',M:&5A9&EN9RUC;W5N="<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L
M;"UT96UP;&%T92!N86UE/2)A9&1(96%D:6YG26YF;R(^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FYO9&54;U-E87)C:$9O
M<DAE861I;F<B("`@<V5L96-T/2(D;F]D951O4V5A<F-H1F]R2&5A9&EN9R(O
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)F
M:6QE55),(B`@("`@("`@("`@("`@("`@('-E;&5C=#TB)&9I;&554DPB+SX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<')E
M=FEO=7-(96%D97(B("`@("`@("`@("!S96QE8W0](G-X9VAE;'!E<CIG970M
M<')E=FEO=7,M8VAI;&0M9&]C=6UE;G1S+6AE861I;F<M8V]U;G0H)&%M;W5N
M=$]F0W5R<F5N=$AE861I;F<I(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC
M86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=J879A
M.F-O;2YS=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS9F]R;65R
M+F=E=%!R979I;W5S0VAI;&1$;V-U;65N='-(96%D:6YG0V]U;G0G*2(^"B`@
M("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB861D2&5A
M9&EN9TEN9F\B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)N;V1E5&]396%R8VA&;W)(96%D:6YG(B`@('-E;&5C=#TB)&YO
M9&54;U-E87)C:$9O<DAE861I;F<B+SX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB9FEL95523"(@("`@("`@("`@("`@("`@
M("!S96QE8W0](B1F:6QE55),(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](G!R979I;W5S2&5A9&5R(B`@("`@("`@("`@
M<V5L96-T/2)J879A.F-O;2YS=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#:&EL
M9%1R86YS9F]R;65R+F=E=%!R979I;W5S0VAI;&1$;V-U;65N='-(96%D:6YG
M0V]U;G0H)&%M;W5N=$]F0W5R<F5N=$AE861I;F<I(B\^"B`@("`@("`@("`@
M("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@(#PO>'-L.F-H;V]S93X*"B`@("`\+WAS;#IT96UP;&%T
M93X*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)A9&1(96%D:6YG26YF;R(^
M"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)F:6QE55),(B\^"B`@("`@("`@
M/'AS;#IP87)A;2!N86UE/2)P<F5V:6]U<TAE861E<B(O/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB;F]D951O4V5A<F-H1F]R2&5A9&EN9R(O/@H*("`@
M("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G!R979I;W5S2&5A9&5R,B(@<V5L
M96-T/2)N=6UB97(H)'!R979I;W5S2&5A9&5R*2(O/@H@("`@("`@(#QX<VPZ
M9F]R+65A8V@@<V5L96-T/2(D;F]D951O4V5A<F-H1F]R2&5A9&EN9R(^"@H@
M("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G1I=&QE(B!S96QE8W0]
M(FYO<FUA;&EZ92US<&%C92@N*2(O/@H*("`@("`@("`@("`@/'AS;#IV87)I
M86)L92!N86UE/2)E;F-O9&5D5&ET;&4B/@H@("`@("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](F5N8V]D92US=')I;F<B/@H@("`@("`@
M("`@("`@("`@("`@(#PA+2T@=&AE('-P86-E(&AA<R!T;R!B92!N;W)M86QI
M>F5D+`H@("`@("`@("`@("`@("`@("`@("`@("!O=&AE<G=I<V4@86X@:6QL
M96=A;"!A<F=U;65N="!E>&-E<'1I;VX@=VEL;"!B92!T:')O=VX@9F]R(%A4
M+2T^"B`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)T97AT5&]"945N8V]D960B('-E;&5C=#TB)'1I=&QE(B\^"B`@("`@("`@
M("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS
M;#IV87)I86)L93X*"B`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)H
M96%D:6YG(CX*("`@("`@("`@("`@("`@(#PA+2T@;V1D(&)U="`G9&5S8V5N
M9&%N=#IT97AT*"DG(&1I9&XG="!W;W)K+"!B=70@)RXG+"!T;R!G970@86QL
M('1E>'0@;F]D97,@;V8@=&AE(&AE861E<B`M+3X*("`@("`@("`@("`@("`@
M(#QX<VPZ871T<FEB=71E(&YA;64](G1I=&QE(CX\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB)'1I=&QE(B\^/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@
M("`@/'AS;#IA='1R:6)U=&4@;F%M93TB96YC;V1E9"UT:71L92(^/'AS;#IV
M86QU92UO9B!S96QE8W0](B1E;F-O9&5D5&ET;&4B+SX\+WAS;#IA='1R:6)U
M=&4^"B`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)L979E
M;"(^/'AS;#IV86QU92UO9B!S96QE8W0](D!T97AT.FQE=F5L(B\^/"]X<VPZ
M871T<FEB=71E/@H@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M
M93TB9FEL92UU<FPB/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(D9FEL95523"(O
M/CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB
M=71E(&YA;64](FAE861E<BUN;R(^/'AS;#IV86QU92UO9B!S96QE8W0](G!O
M<VET:6]N*"D@*R`D<')E=FEO=7-(96%D97(R(B\^/"]X<VPZ871T<FEB=71E
M/@H@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@(#PO>'-L.F9O
M<BUE86-H/@H*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\>'-L.G1E;7!L
M871E(&YA;64](F=E=$%L;$AE861E<DYO(CX*"B`@("`@("`@/'AS;#IC:&]O
M<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I
M;&%B;&4H)W-X9VAE;'!E<CIG970M86QL+6-H:6QD+61O8W5M96YT<RUH96%D
M:6YG+6-O=6YT)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L
M871E(&YA;64](F%D9$%L;$AE861E<DYO16QE;65N="(^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;$AE861E<B(@("!S
M96QE8W0](G-X9VAE;'!E<CIG970M86QL+6-H:6QD+61O8W5M96YT<RUH96%D
M:6YG+6-O=6YT*"DB+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)VIA=F$Z8V]M+G-U
M;BYS=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N9V5T06QL
M0VAI;&1$;V-U;65N='-(96%D:6YG0V]U;G0G*2(^"B`@("`@("`@("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB861D06QL2&5A9&5R3F]%;&5M
M96YT(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB86QL2&5A9&5R(B`@('-E;&5C=#TB:F%V83IC;VTN<W5N+G-T87(N>'-L
M="YH96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYG971!;&Q#:&EL9$1O8W5M
M96YT<TAE861I;F=#;W5N="@I(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC
M86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*("`@(#QX<VPZ
M=&5M<&QA=&4@;F%M93TB861D06QL2&5A9&5R3F]%;&5M96YT(CX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](F%L;$AE861E<B(O/@H*("`@("`@("`\>'-L
M.F5L96UE;G0@;F%M93TB:&5A9&EN9RUC;W5N="(^"B`@("`@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2(D86QL2&5A9&5R(B\^"B`@("`@("`@/"]X
M<VPZ96QE;65N=#X*"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/"$M+2`J
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@($-R96%T:6]N(&]F(&$@
M;&EN92!O9B!L:6YK<R!A="!T:&4@8F5G:6YN:6YG(&%N9"!E;F0@;V8@82!C
M:&EL9"!D;V-U;65N="!T;R!E;FAA;F-E('5S86)I;&ET>2`@*BHJ("TM/@H@
M("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*("`@(#QX<VPZ=&5M<&QA=&4@
M;F%M93TB861D+6-H:6QD+61O8W5M96YT+75S86)I;&ET>2UL:6YK<R(^"B`@
M("`@("`@/'AS;#IE;&5M96YT(&YA;64](F-E;G1E<B(^"B`@("`@("`@("`@
M(#QX<VPZ96QE;65N="!N86UE/2)S;6%L;"(^"B`@("`@("`@("`@("`@("`\
M>'-L.G1E>'0^6R`\+WAS;#IT97AT/@H*"B`@("`@("`@("`@("`@("`\>'-L
M.G9A<FEA8FQE(&YA;64](F=L;V)A;$1O8W5M96YT1&ER(B!S96QE8W0](G-X
M9VAE;'!E<CIG970M9VQO8F%L+61O8W5M96YT+61I<B@I(B\^"B`@("`@("`@
M("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F-U<G)E;G1#:&EL9$YO(B!S
M96QE8W0](FYU;6)E<B@D8V]N=&5N=%1A8FQE2&5A9&EN9W,O:&5A9&EN9ULD
M9VQO8F%L1&]C=6UE;G129694;T-U<G)E;G1&:6QE(#T@0&9I;&4M=7)L72]`
M8VAI;&0M9&]C=6UE;G0M;F\I(B\^"B`@("`@("`@("`@("`@("`\>'-L.G9A
M<FEA8FQE(&YA;64](F5A<FQI97)$;V-54DPB('-E;&5C=#TB)&-O;G1E;G14
M86)L94AE861I;F=S+VAE861I;F=;*"1C=7)R96YT0VAI;&1.;R`M(#$I(#T@
M0&-H:6QD+61O8W5M96YT+6YO72]`;W5T+69I;&4M=7)L(B\^"CPA+2T*/'AS
M;#IM97-S86=E/F9R;VTZ(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D9VQO8F%L
M1&]C=6UE;G129694;T-U<G)E;G1&:6QE(B\^/"]X<VPZ;65S<V%G93X*/'AS
M;#IM97-S86=E/G1O.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&5A<FQI97)$
M;V-54DPB+SX\+WAS;#IM97-S86=E/@H\>'-L.FUE<W-A9V4^27,Z(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)G970M<F5L871I=F4M9FEL92UR968B/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S;W5R
M8V5&:6QE4F5F(B!S96QE8W0](B1G;&]B86Q$;V-U;65N=%)E9E1O0W5R<F5N
M=$9I;&4B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB=&%R9V5T1FEL95)E9B(@<V5L96-T/2(D96%R;&EE<D1O8U523"(O
M/@H@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"CPO>'-L
M.FUE<W-A9V4^+2T^"@H*("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB
M)&5A<FQI97)$;V-54DPB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE
M;65N="!N86UE/2)A(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA
M='1R:6)U=&4@;F%M93TB:')E9B(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\(2TM('=H96X@=&AE(&QI;FMS('-T87)T<R!W:71H(&$@)R,G(&ET
M)W,@82!L:6YK('1O('1H92!#;VYT96YT(%1A8FQE+2T^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB<W1A<G1S+7=I=&@H
M)&5A<FQI97)$;V-54DPL("<C)RDB/@H*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F=E="UR
M96QA=&EV92UF:6QE+7)E9B(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<V]U<F-E1FEL
M95)E9B(@<V5L96-T/2(D9VQO8F%L1&]C=6UE;G129694;T-U<G)E;G1&:6QE
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB=&%R9V5T1FEL95)E9B(@<V5L96-T/2(N
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F-A;&PM=&5M<&QA=&4^"CPA+2T@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2)C;VYC870H)&-O;G1E;G1486)L95523"P@)&5A<FQI97)$;V-54DPI
M(B\^+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T
M:&5R=VES93X*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G970M<F5L871I=F4M9FEL92UR
M968B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](G-O=7)C949I;&52968B('-E;&5C=#TB
M)&=L;V)A;$1O8W5M96YT4F5F5&]#=7)R96YT1FEL92(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](G1A<F=E=$9I;&52968B('-E;&5C=#TB)&5A<FQI97)$;V-54DPB
M+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M8V%L;"UT96UP;&%T93X*/"$M+0H*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O;F-A="@D9VQO
M8F%L1&]C=6UE;G1$:7(L("1E87)L:65R1&]C55),*2(O/BTM/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G1E>'0^4')E=FEO=7,@9&]C=6UE;G0\+WAS
M;#IT97AT/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#X@?"`\+WAS;#IT97AT/@H@
M("`@("`@("`@("`@("`@/"]X<VPZ:68^"@H@("`@("`@("`@("`@("`@/'AS
M;#IE;&5M96YT(&YA;64](F$B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M871T<FEB=71E(&YA;64](FAR968B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\(2TM('=H96X@9VQO8F%L1&]C=6UE;G129694;T-U<G)E;G1&:6QE(&ES
M('5N<V5T('1H92!C=7)R96YT(&9I;&4@:7,@=&AE($-O;G1E;G0@5&%B;&4M
M+3X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&=L;V)A
M;$1O8W5M96YT4F5F5&]#=7)R96YT1FEL92(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)C;VYT96YT5&%B
M;&5$:7(B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9V5T+6YA;64M;V8M=&%B;&4M;V8M
M8V]N=&5N="UD;V-U;65N="(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G9A<FEA8FQE/@H*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9V5T+7)E;&%T
M:79E+69I;&4M<F5F(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-O=7)C949I;&52968B('-E
M;&5C=#TB)&=L;V)A;$1O8W5M96YT4F5F5&]#=7)R96YT1FEL92(O/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB=&%R9V5T1FEL95)E9B(@<V5L96-T/2(D8V]N=&5N=%1A8FQE
M1&ER(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T
M:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G1E>'0^(SPO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F-H;V]S93X*"CPA+2T@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2(D8V]N=&5N=%1A8FQE55),(B\^+2T^"B`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=&5X=#Y#;VYT96YT(%1A8FQE/"]X<VPZ=&5X=#X*("`@("`@
M("`@("`@("`@(#PO>'-L.F5L96UE;G0^"@H*("`@("`@("`@("`@("`@(#QX
M<VPZ=F%R:6%B;&4@;F%M93TB;F5X=$1O8U523"(@<V5L96-T/2(D8V]N=&5N
M=%1A8FQE2&5A9&EN9W,O:&5A9&EN9ULH)&-U<G)E;G1#:&EL9$YO("L@,2D@
M/2!`8VAI;&0M9&]C=6UE;G0M;F]=+T!O=70M9FEL92UU<FPB+SX*("`@("`@
M("`@("`@("`@(#QX<VPZ:68@=&5S=#TB)&YE>'1$;V-54DPB/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=&5X=#X@?"`\+WAS;#IT97AT/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)A(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB:')E9B(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM('=H96X@=&AE(&QI;FMS
M('-T87)T<R!W:71H(&$@)R,G(&ET)W,@82!L:6YK('1O('1H92!#;VYT96YT
M(%1A8FQE+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-H
M;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB<W1A<G1S+7=I=&@H)&YE>'1$;V-54DPL("<C)RDB/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB9V5T+7)E;&%T:79E+69I;&4M<F5F(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)S;W5R8V5&:6QE4F5F(B!S96QE8W0](B1G;&]B86Q$;V-U;65N
M=%)E9E1O0W5R<F5N=$9I;&4B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T87)G971&
M:6QE4F5F(B!S96QE8W0](BXB+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*/"$M+2`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0]
M(F-O;F-A="@D8V]N=&5N=%1A8FQE55),+"`D;F5X=$1O8U523"DB+SXM+3X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A
M;&PM=&5M<&QA=&4@;F%M93TB9V5T+7)E;&%T:79E+69I;&4M<F5F(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)S;W5R8V5&:6QE4F5F(B!S96QE8W0](B1G;&]B86Q$
M;V-U;65N=%)E9E1O0W5R<F5N=$9I;&4B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T
M87)G971&:6QE4F5F(B!S96QE8W0](B1N97AT1&]C55),(B\^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA
M=&4^"CPA+2T@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"1G;&]B86Q$;V-U;65N=$1I<BP@
M)&YE>'1$;V-54DPI(B\^+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=&5X=#Y.97AT(&1O8W5M96YT/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@/"]X<VPZ:68^
M"B`@("`@("`@("`@("`@("`\>'-L.G1E>'0^(%T\+WAS;#IT97AT/@H@("`@
M("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@(#PO>'-L.F5L96UE;G0^
M"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/'AS;#IT96UP;&%T92!N86UE
M/2)G970M<F5L871I=F4M9FEL92UR968B/@H@("`@("`@(#QX<VPZ<&%R86T@
M;F%M93TB<V]U<F-E1FEL95)E9B(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M
M93TB=&%R9V5T1FEL95)E9B(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G
M<WAG:&5L<&5R.F=E="UR96QA=&EV92UF:6QE+7)E9B<I(CX*("`@("`@("`@
M("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S>&=H96QP97(Z9V5T+7)E
M;&%T:79E+69I;&4M<F5F*'-T<FEN9R@D<V]U<F-E1FEL95)E9BDL('-T<FEN
M9R@D=&%R9V5T1FEL95)E9BDI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B
M;&4H)VIA=F$Z8V]M+G-U;BYS=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A
M;G-F;W)M97(N9V5T4F5L871I=F5&:6QE4F5F)RDB/@H@("`@("`@("`@("`@
M("`@/'AS;#IV86QU92UO9B!S96QE8W0](FIA=F$Z8V]M+G-U;BYS=&%R+GAS
M;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N9V5T4F5L871I=F5&:6QE
M4F5F*'-T<FEN9R@D<V]U<F-E1FEL95)E9BDL('-T<FEN9R@D=&%R9V5T1FEL
M95)E9BDI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@/"]X
M<VPZ8VAO;W-E/@H*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\>'-L.G1E
M;7!L871E(&YA;64](F=E="UN86UE+6]F+71A8FQE+6]F+6-O;G1E;G0M9&]C
M=6UE;G0B/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G<WAG:&5L<&5R.F=E
M="UN86UE+6]F+71A8FQE+6]F+6-O;G1E;G0M9&]C=6UE;G0G*2(^"B`@("`@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<WAG:&5L<&5R.F=E
M="UN86UE+6]F+71A8FQE+6]F+6-O;G1E;G0M9&]C=6UE;G0H*2(O/@H@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB9G5N8W1I;VXM879A:6QA8FQE*"=J879A.F-O;2YS=6XN<W1A<BYX<VQT
M+FAE;'!E<BY3>&=#:&EL9%1R86YS9F]R;65R+F=E=$YA;65/9E1A8FQE3V9#
M;VYT96YT1&]C=6UE;G0G*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG
M0VAI;&14<F%N<V9O<FUE<BYG971.86UE3V9486)L94]F0V]N=&5N=$1O8W5M
M96YT*"DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`\+WAS
M;#IC:&]O<V4^"@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"3QX<VPZ=&5M<&QA
M=&4@;F%M93TB9&5B=6<M8V]N=&5N="UT86)L92UH96%D:6YG<RUV87)I86)L
M92(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$
M871A(B\^"@H@("`@("`@(#QX<VPZ;65S<V%G93X\>'-L.G1E>'0^*BHJ*B!4
M2$4@2$5!1$E.1R!605))04),12`J*BHJ(#PO>'-L.G1E>'0^/"]X<VPZ;65S
M<V%G93X*("`@("`@("`\>'-L.FUE<W-A9V4^8V]N=&5N="UT86)L92UU<FPZ
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VQL96-T961';&]B86Q$871A+V-O
M;G1E;G0M=&%B;&4M:&5A9&EN9W,O8V]N=&5N="UT86)L92UU<FPB+SX\+WAS
M;#IM97-S86=E/@H*("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB)&-O
M;&QE8W1E9$=L;V)A;$1A=&$O8V]N=&5N="UT86)L92UH96%D:6YG<R]H96%D
M:6YG(CX*("`@("`@("`@("`@/'AS;#IM97-S86=E/CQX<VPZ=&5X=#XJ*BHJ
M(&YE=R!H96%D:6YG.B`@("`@("`@/"]X<VPZ=&5X=#X\+WAS;#IM97-S86=E
M/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^8V]N=&5N="UT86)L92UI9#H@
M("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB0&-O;G1E;G0M=&%B;&4M:60B
M+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^8VAI
M;&0M9&]C=6UE;G0M;F\Z("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB0&-H
M:6QD+61O8W5M96YT+6YO(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@
M/'AS;#IM97-S86=E/F9I;&4M=7)L.B`@("`@("`@("`@("`@/'AS;#IV86QU
M92UO9B!S96QE8W0](D!F:6QE+75R;"(O/CPO>'-L.FUE<W-A9V4^"B`@("`@
M("`@("`@(#QX<VPZ;65S<V%G93YO=70M9FEL92UU<FPZ("`@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)`;W5T+69I;&4M=7)L(B\^/"]X<VPZ;65S
M<V%G93X*("`@("`@("`@("`@/'AS;#IM97-S86=E/FQE=F5L.B`@("`@("`@
M("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](D!L979E;"(O/CPO>'-L
M.FUE<W-A9V4^"B`@("`@("`@("`@(#QX<VPZ;65S<V%G93YT:71L93H@("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)`=&ET;&4B+SX\
M+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^96YC;V1E
M9"UT:71L93H@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB0&5N8V]D
M960M=&ET;&4B+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\>'-L.FUE
M<W-A9V4^86)S;VQU=&4M8VAA<'1E<BUL979E;#H\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB0&%B<V]L=71E+6-H87!T97(M;&5V96PB+SX\+WAS;#IM97-S86=E
M/@H@("`@("`@(#PO>'-L.F9O<BUE86-H/@H*"3PO>'-L.G1E;7!L871E/@H*
M"@D\(2TM(%1O(&UA:V4@=&AE(&AE861I;F=S('5N:7%U92P@=&AE(&%B<V]L
M=71E(&AE861I;F<@:7,@861D960@=&\@=&AE;0H)("`@("!%+F<N(%1H92!L
M979E;"`Q+C(N,RXT+B!W;W5L9"!R97-U;'0@:6YT;R!A(#$K,BLS*S0@<W1R
M:6YG("TM/@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)C86QC+6-H87!T97(M
M;G5M8F5R<R(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)L979E;"(O/@H*
M("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](F9U;F-T:6]N+6%V86EL86)L92@G<WAG:&5L<&5R.F-A;&,M8VAA<'1E
M<BUN=6UB97)S)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](G-X9VAE;'!E<CIC86QC+6-H87!T97(M;G5M8F5R<R@D;&5V96PI
M(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)VIA=F$Z8V]M+G-U;BYS
M=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N8V%L8T-H87!T
M97).=6UB97)S)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](FIA=F$Z8V]M+G-U;BYS=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD
M5')A;G-F;W)M97(N8V%L8T-H87!T97).=6UB97)S*"1L979E;"DB+SX*("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`\+WAS;#IC:&]O<V4^"@H@
M("`@/"]X<VPZ=&5M<&QA=&4^"@H*"@H@("`@/'AS;#IT96UP;&%T92!M871C
M:#TB=&5X=#IP(B!M;V1E/2)C;VYT96YT+71A8FQE(CX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@
M/'AS;#IV87)I86)L92!N86UE/2)A;&Q486)3=&]P4W1Y;&5S(B!S96QE8W0]
M(B1O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R]S='EL93IS='EL95M`<W1Y;&4Z
M;F%M92`](&-U<G)E;G0H*2]`=&5X=#IS='EL92UN86UE72]S='EL93IP<F]P
M97)T:65S+W-T>6QE.G1A8BUS=&]P<R(O/@H*("`@("`@("`\>'-L.F5L96UE
M;G0@;F%M93TB=&%B;&4B/@H@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N
M86UE/2)B;W)D97(B/C`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@(#QX
M<VPZ871T<FEB=71E(&YA;64](F-L87-S(CX\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB0'1E>'0Z<W1Y;&4M;F%M92(O/CPO>'-L.F%T=')I8G5T93X*/"$M+0H\
M>'-L.FUE<W-A9V4^*BHJ*BHJ*BHJ/"]X<VPZ;65S<V%G93X*/'AS;#IM97-S
M86=E/E-T>6QE;F%M93H\>'-L.G9A;'5E+6]F('-E;&5C=#TB0'1E>'0Z<W1Y
M;&4M;F%M92(O/CPO>'-L.FUE<W-A9V4^"CQX<VPZ;65S<V%G93YP;W-I=&EO
M;CH@/'AS;#IV86QU92UO9B!S96QE8W0](F-O=6YT*"1A;&Q486)3=&]P4W1Y
M;&5S+W-T>6QE.G1A8BUS=&]P*2(O/CPO>'-L.FUE<W-A9V4^"BTM/@H*("`@
M("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F-O;&=R;W5P(CX*("`@("`@
M("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C<F5A=&4M8V]L
M+65L96UE;G0B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)L87-T3F]D95!O<VET:6]N(B!S96QE8W0](F-O=6YT*"1A;&Q4
M86)3=&]P4W1Y;&5S+W-T>6QE.G1A8BUS=&]P*2(O/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q486)3=&]P4W1Y;&5S
M(B!S96QE8W0](B1A;&Q486)3=&]P4W1Y;&5S(B\^"B`@("`@("`@("`@("`@
M("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IE;&5M
M96YT/@H*"B`@("`@("`@("`@(#PA+2T@86QL(&5L96UE;G1S(&)E9F]R92!T
M:&4@9FER<W0@=&%B4W1O<"`M+3X*("`@("`@("`@("`@/'AS;#IV87)I86)L
M92!N86UE/2)T97-T3F\M4E1&(CX*("`@("`@("`@("`@("`@(#QX<VPZ87!P
M;'DM=&5M<&QA=&5S('-E;&5C=#TB;F]D92@I(B!M;V1E/2)C96QL+6-O;G1E
M;G0B+SX*("`@("`@("`@("`@/"]X<VPZ=F%R:6%B;&4^"@H*("`@("`@("`\
M>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T
M:6]N+6%V86EL86)L92@G>'0Z;F]D92US970G*2(^"B`@("`@("`@("`@("`@
M("`\>'-L.G9A<FEA8FQE(&YA;64](G1A8DYO9&50;W-I=&EO;G,B('-E;&5C
M=#TB>'0Z;F]D92US970H)'1E<W1.;RU25$8I(B\^"@D)"3QX<VPZ96QE;65N
M="!N86UE/2)T<B(^"B`@("`@("`@("`@("`@(`D@/'AS;#IC86QL+71E;7!L
M871E(&YA;64](F-R96%T92UT9"UE;&5M96YT<R(^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FQA<W1.;V1E4&]S:71I;VXB
M('-E;&5C=#TB8V]U;G0H)&%L;%1A8E-T;W!3='EL97,O<W1Y;&4Z=&%B+7-T
M;W`I(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](G!O<VET:6]N(B`@("`@("`@('-E;&5C=#TB,2(O/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q486)3=&]P4W1Y
M;&5S(B!S96QE8W0](B1A;&Q486)3=&]P4W1Y;&5S(B\^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G1A8DYO9&50;W-I=&EO
M;G,B('-E;&5C=#TB)'1A8DYO9&50;W-I=&EO;G,B+SX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L
M1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@
M("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X
M<VPZ96QE;65N=#X*"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)WAA;&%N
M.FYO9&5S970G*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA
M;64](G1A8DYO9&50;W-I=&EO;G,B('-E;&5C=#TB>&%L86XZ;F]D97-E="@D
M=&5S=$YO+5)41BDB+SX*"0D)/'AS;#IE;&5M96YT(&YA;64](G1R(CX*("`@
M("`@("`@("`@("`@"2`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8W)E871E
M+71D+65L96UE;G1S(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB;&%S=$YO9&50;W-I=&EO;B(@<V5L96-T/2)C;W5N="@D
M86QL5&%B4W1O<%-T>6QE<R]S='EL93IT86(M<W1O<"DB+SX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&]S:71I;VXB("`@
M("`@("`@<V5L96-T/2(Q(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F%L;%1A8E-T;W!3='EL97,B('-E;&5C=#TB)&%L
M;%1A8E-T;W!3='EL97,B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB=&%B3F]D95!O<VET:6]N<R(@<V5L96-T/2(D=&%B
M3F]D95!O<VET:6]N<R(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C
M;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC
M86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H*("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`\+WAS;#IC:&]O<V4^"@H@
M("`@("`@("`@(#PA+2T@/'AS;#IV87)I86)L92!N86UE/2)T86).;V1E4&]S
M:71I;VYS(B!S96QE8W0](GAT.FYO9&4M<V5T*"1T97-T3F\M4E1&*2(O/@H*
M("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G1R(CX*("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C<F5A=&4M=&0M96QE
M;65N=',B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)L87-T3F]D95!O<VET:6]N(B!S96QE8W0](F-O=6YT*"1A;&Q486)3
M=&]P4W1Y;&5S+W-T>6QE.G1A8BUS=&]P*2(O/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P;W-I=&EO;B(@("`@("`@("!S
M96QE8W0](C$B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB86QL5&%B4W1O<%-T>6QE<R(@<V5L96-T/2(D86QL5&%B4W1O
M<%-T>6QE<R(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)T86).;V1E4&]S:71I;VYS(B!S96QE8W0](B1T86).;V1E4&]S
M:71I;VYS(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^+2T^"@H*("`@("`@
M("`\+WAS;#IE;&5M96YT/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#QX
M<VPZ=&5M<&QA=&4@;F%M93TB8W)E871E+6-O;"UE;&5M96YT(CX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](FQA<W1.;V1E4&]S:71I;VXB+SX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](F%L;%1A8E-T;W!3='EL97,B+SX*"B`@("`@
M("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1A;&Q486)3=&]P4W1Y;&5S+W-T
M>6QE.G1A8BUS=&]P(CX*("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64]
M(F-O;"(^"B`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)S
M='EL92(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/G=I9'1H.B`\
M+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP
M;&%T92!N86UE/2)G<F%P+6-E;&PM=VED=&@B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&]S:71I;VXB("`@("`@
M("`@<V5L96-T/2)P;W-I=&EO;B@I(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q486)3=&]P4W1Y;&5S(B!S
M96QE8W0](B1A;&Q486)3=&]P4W1Y;&5S(B\^"B`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L
M.F%T=')I8G5T93X*("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@
M("`\+WAS;#IF;W(M96%C:#X*"B`@("`\+WAS;#IT96UP;&%T93X*/"$M+0I3
M8V5N87)I;W,@=&%B<W1O<',*"C$I('-T>6QE.G1Y<&4@;V8@<W1Y;&4Z=&%B
M+7-T;W`@:7,@)W)I9VAT)R!A;F0@96%R;&EE<B!T86)3=&]P(&ES(&YO="!R
M:6=H=`H@+3X@16%R;&EE<B!T97AT+6YO9&5S(&%N9"!F;VQL;W=I;F<@=&5X
M="UN;V1E<RP@=VEL;"!B92!P=70@:6YT;R!A;B!I;FYE<B!T86)L92P@=VET
M:"!T=V\@5$0@9FER<W0@86QI9VYE9"!L969T+"!W:71H('!R;V-E9&EN9R!T
M97AT;F]D97,L('1H92!L871T97(@86QI9VYE9"!R:6=H="X*"C(I('-T>6QE
M.G1Y<&4@:7,@)W)I9VAT)R!A;F0@96%R;&EE<B!T86)3=&]P(&ES(')I9VAT
M"B`M/B!F;VQL;W=I;F<@=&5X="UN;V1E<RP@=VEL;"!B92!P=70@:6YT;R!A
M(')I9VAT(&%L:6=N960@5$0*"C,I('-T>6QE.G1Y<&4@:7,@)VYO;BUR:6=H
M="<@86YD(&5A<FQI97(@=&%B4W1O<"`G;F]N+7)I9VAT)R!A<R!W96QL"B`M
M/B!P=70@=&AE('!R96-E9&EN9R!T86(@<W1O<',@:6YT;R!A(%1$("AL969T
M(&%L:6=N960@:7,@9&5F875L="D*"C0I(&9I<G-T('-T>6QE.G1Y<&4@=V]U
M;&0@:&%V92!N;R!R:6=H="!P<F5C961I9VX@=&%B4W1O<`H@+3X@=V]R:W,@
M=V5L;"!W:71H(&9I<G-T('-C96%N<FEO<R`Q(&%N9"`S"@HU*2!L87-T('-T
M>6QE.G1Y<&4@=V]U;&0@8F4@82!S<&5C:6%L(&-A<V4L(&EF(&ET('=O=6QD
M(&)E(&QE9G0@86QI9VYE9"P@8G5T('1H:7,@=V]N)W0@:&%P<&5N(&EN(&]U
M<B!C87-E+BX@.D0*"E-C96YA<FEO<R!U;FUA=&-H960Z"BT@=&5X=#IS='EL
M97!O<VET:6]N("=C96YT97(G('=I;&P@;F]T(&)E(&UA=&-H960@:6X@;W5R
M(&-A<V4@*&5F9F]R="!F;W(@;F]T:&EN9RDL('1H97)E('=I;&P@8F4@;VYL
M>2`G<FEG:'0G(&%N9"!N;W0@)W)I9VAT)PHM($EF('1H92!L87-T('1A8E-T
M;W`@:7,@;F]T(&9R;VT@=&5X=#IS='EL97!O<W1I;VX@)W)I9VAT)RP@=&AE
M(&QE;F=T:"!O9B!T:&4@;&%S="!C96QL(&ES('5N9&5F:6YE9"!A;F0@82!D
M;V-U;65N="!L96YG=&@@;75S="!B92!F;W5N9"X*("!.;W0@:&%P<&5N<R!I
M;B!O=7(@9VQO8F%L(&1O8W5M96YT(&-A<V4N($%L<V\@=&AE(&%L9V]R:71H
M;2!B96QO=R!W;W5L9"!H879E('1O(&)E(&5X<&%N9&5D("AC<"X@<V-E;F%R
M:6\@-2DN"@HM+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB8W)E871E+71D
M+65L96UE;G1S(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](FQA<W1.
M;V1E4&]S:71I;VXB+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G!O<VET
M:6]N(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)A;&Q486)3=&]P4W1Y
M;&5S(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)T86).;V1E4&]S:71I
M;VYS(B\^"CPA+2T*/'AS;#IM97-S86=E/BLK*RLK*RLK/"]X<VPZ;65S<V%G
M93X*/'AS;#IM97-S86=E/E!O<VET:6]N.B`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB)'!O<VET:6]N(B\^/"]X<VPZ;65S<V%G93X*/'AS;#IM97-S86=E/FQA
M<W1.;V1E4&]S:71I;VXZ(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D;&%S=$YO
M9&50;W-I=&EO;B(O/CPO>'-L.FUE<W-A9V4^"BTM/@H*("`@("`@("`\>'-L
M.G9A<FEA8FQE(&YA;64](F-U<G)E;G13='EL951Y<&4B('-E;&5C=#TB)&%L
M;%1A8E-T;W!3='EL97,O<W1Y;&4Z=&%B+7-T;W!;)'!O<VET:6]N72]`<W1Y
M;&4Z='EP92(O/@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB96%R;&EE
M<E-T>6QE5'EP92(@<V5L96-T/2(D86QL5&%B4W1O<%-T>6QE<R]S='EL93IT
M86(M<W1O<%LD<&]S:71I;VX@+2`Q72]`<W1Y;&4Z='EP92(O/@H@("`@("`@
M(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&-U
M<G)E;G13='EL951Y<&4@/2`G<FEG:'0G(CX*("`@("`@("`@("`@("`@(#QX
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2(D96%R;&EE<E-T>6QE5'EP92`]("=R:6=H="<B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\(2TM"B`@("`@("`@("`@("`@("`@("`@("`@(#(I('-T
M>6QE.G1Y<&4@:7,@)W)I9VAT)R!A;F0@96%R;&EE<B!T86)3=&]P(&ES(')I
M9VAT"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`M/B!F;VQL;W=I;F<@
M=&5X="UN;V1E<RP@=VEL;"!B92!P=70@:6YT;R!A(')I9VAT(&%L:6=N960@
M5$0@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N
M86UE/2)T9"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%T
M=')I8G5T92!N86UE/2)S='EL92(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IT97AT/F%L:6=N.B!R:6=H=#PO>'-L.G1E>'0^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@
M;F%M93TB9W)A<"UC96QL+6-O;G1E;G0M8F5F;W)E+71A8BUS=&]P(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D
M1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)E;F1I;F=486)3=&]P4&]S:71I;VXB
M("!S96QE8W0](B1P;W-I=&EO;B`K(#$B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;&%S=$YO9&50
M;W-I=&EO;B(@<V5L96-T/2(D;&%S=$YO9&50;W-I=&EO;B(O/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)T86).;V1E4&]S:71I;VYS(B!S96QE8W0](B1T86).;V1E4&]S:71I;VYS
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E
M;7!L871E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT
M/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@
M/"$M+0H@("`@("`@("`@("`@("`@("`@("`@("`Q*2!S='EL93IT>7!E(&]F
M('-T>6QE.G1A8BUS=&]P(&ES("=R:6=H="<@86YD(&5A<FQI97(@=&%B4W1O
M<"!I<R!N;W0@<FEG:'0*("`@("`@("`@("`@("`@("`@("`@("`@("T^($5A
M<FQI97(@=&5X="UN;V1E<R!A;F0@9F]L;&]W:6YG('1E>'0M;F]D97,L('=I
M;&P@8F4@<'5T(&EN=&\@86X@:6YN97(@=&%B;&4L('=I=&@@='=O(%1$(&9I
M<G-T(&%L:6=N960@;&5F="P@=VET:"!P<F]C961I;F<@=&5X=&YO9&5S+"!T
M:&4@;&%T=&5R(&%L:6=N960@<FEG:'0N+2T^"CPA+2T@=F%L:60@2%1-3"!B
M=70@8G)O=W-E<G,@;6%K92!A(&QI;F4@8G)E86L@*&)O<F1E<CTP(&%N9"!P
M87)A9W)A<&AS='EL92!A;'-O(&UI<W-I;F<I.@H@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB=&%B;&4B/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G1D(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA
M=&4@;F%M93TB9W)A<"UC96QL+6-O;G1E;G0M8F5F;W)E+71A8BUS=&]P(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O
M;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F5N9&EN9U1A8E-T
M;W!0;W-I=&EO;B(@('-E;&5C=#TB)'!O<VET:6]N(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)L87-T3F]D95!O<VET:6]N(B!S96QE8W0](B1L87-T3F]D95!O<VET:6]N
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)T86).;V1E4&]S:71I;VYS(B!S96QE8W0](B1T
M86).;V1E4&]S:71I;VYS(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB=&0B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](G-T>6QE
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT
M97AT/F%L:6=N.B!R:6=H=#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G
M<F%P+6-E;&PM8V]N=&5N="UB969O<F4M=&%B+7-T;W`B/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB96YD:6YG5&%B4W1O<%!O<VET:6]N
M(B`@<V5L96-T/2(D<&]S:71I;VX@*R`Q(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)L87-T
M3F]D95!O<VET:6]N(B!S96QE8W0](B1L87-T3F]D95!O<VET:6]N(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)T86).;V1E4&]S:71I;VYS(B!S96QE8W0](B1T86).;V1E
M4&]S:71I;VYS(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F5L96UE;G0^"BTM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IE;&5M96YT(&YA;64](G1D(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9W)A<"UC96QL
M+6-O;G1E;G0M8F5F;W)E+71A8BUS=&]P(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE
M8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B
M+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F5N9&EN9U1A8E-T;W!0;W-I=&EO;B(@('-E;&5C
M=#TB)'!O<VET:6]N(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)L87-T3F]D95!O<VET:6]N
M(B!S96QE8W0](B1L87-T3F]D95!O<VET:6]N(B\^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T
M86).;V1E4&]S:71I;VYS(B!S96QE8W0](B1T86).;V1E4&]S:71I;VYS(B\^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*/"$M+2!/1$L@1D5!5%5212!.3R!004=%4PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)T9"(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T
M<FEB=71E(&YA;64](G-T>6QE(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YA;&EG;CH@<FEG:'0\+WAS;#IT
M97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G<F%P+6-E;&PM8V]N=&5N
M="UB969O<F4M=&%B+7-T;W`B/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)E;F1I;F=486)3=&]P4&]S:71I;VXB("!S96QE
M8W0](B1P;W-I=&EO;B`K(#$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)L87-T3F]D
M95!O<VET:6]N(B!S96QE8W0](B1L87-T3F]D95!O<VET:6]N(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB=&%B3F]D95!O<VET:6]N<R(@<V5L96-T/2(D=&%B3F]D
M95!O<VET:6]N<R(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^("`@("`@("`@("TM/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@
M("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/'AS;#IC
M:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1E
M87)L:65R4W1Y;&54>7!E(#T@)W)I9VAT)R(^"B`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R
M=VES93X*("`@("`@("`@("`@("`@("`@("`\(2TM"B`@("`@("`@("`@("`@
M("`@("`@("`@,RD@<W1Y;&4Z='EP92!I<R`G;F]N+7)I9VAT)R!A;F0@96%R
M;&EE<B!T86)3=&]P("=N;VXM<FEG:'0G(&%S('=E;&P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("T^('!U="!T:&4@<')E8V5D:6YG('1A8B!S=&]P
M<R!I;G1O(&$@5$0@*&QE9G0@86QI9VYE9"!I<R!D969A=6QT*2`M+3X*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G1D(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T
M92!N86UE/2)G<F%P+6-E;&PM8V]N=&5N="UB969O<F4M=&%B+7-T;W`B/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T
M961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F5N9&EN9U1A8E-T;W!0;W-I=&EO
M;B(@('-E;&5C=#TB)'!O<VET:6]N(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FQA<W1.;V1E4&]S
M:71I;VXB('-E;&5C=#TB)&QA<W1.;V1E4&]S:71I;VXB+SX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M=&%B3F]D95!O<VET:6]N<R(@<V5L96-T/2(D=&%B3F]D95!O<VET:6]N<R(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP
M;&%T93X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@
M("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO>'-L.F]T:&5R
M=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"@H@("`@("`@(#QX<VPZ:68@
M=&5S=#TB)'!O<VET:6]N("$]("1L87-T3F]D95!O<VET:6]N(CX*("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R96%T92UT9"UE;&5M
M96YT<R(^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L
M1&%T82(O/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(FQA<W1.;V1E4&]S:71I;VXB('-E;&5C=#TB)&QA<W1.;V1E4&]S:71I;VXB
M+SX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P;W-I
M=&EO;B(@("`@("`@("!S96QE8W0](B1P;W-I=&EO;B`K(#$B+SX*("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q486)3=&]P4W1Y
M;&5S(B!S96QE8W0](B1A;&Q486)3=&]P4W1Y;&5S(B\^"B`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=&%B3F]D95!O<VET:6]N<R(@
M<V5L96-T/2(D=&%B3F]D95!O<VET:6]N<R(O/@H@("`@("`@("`@("`\+WAS
M;#IC86QL+71E;7!L871E/@H@("`@("`@(#PO>'-L.FEF/@H@("`@/"]X<VPZ
M=&5M<&QA=&4^"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB9W)A<"UC96QL
M+6-O;G1E;G0M8F5F;W)E+71A8BUS=&]P(CX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\>'-L.G!A
M<F%M(&YA;64](F5N9&EN9U1A8E-T;W!0;W-I=&EO;B(O/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB=&%B3F]D95!O<VET:6]N<R(O/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB;&%S=$YO9&50;W-I=&EO;B(O/@H*("`@("`@("`\
M>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1E;F1I
M;F=486)3=&]P4&]S:71I;VX@/2`Q(CX*("`@("`@("`@("`@("`@(#QX<VPZ
M87!P;'DM=&5M<&QA=&5S(&UO9&4](F-O;G1E;G0M=&%B;&4B('-E;&5C=#TB
M;F]D92@I6W!O<VET:6]N*"D@)FQT.R`D=&%B3F]D95!O<VET:6]N<R]T86(M
M<W1O<"UN;V1E+7!O<VET:6]N6R1E;F1I;F=486)3=&]P4&]S:71I;VY=72(^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O
M;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A
M=&$B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](B1E;F1I;F=486)3=&]P4&]S:71I;VX@/B`D;&%S=$YO9&50;W-I
M=&EO;B(^"B`@("`@("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<R!M
M;V1E/2)C;VYT96YT+71A8FQE(B!S96QE8W0](FYO9&4H*5MP;W-I=&EO;B@I
M(#X@)'1A8DYO9&50;W-I=&EO;G,O=&%B+7-T;W`M;F]D92UP;W-I=&EO;ELD
M96YD:6YG5&%B4W1O<%!O<VET:6]N("T@,5U=(CX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T
M82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@
M("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@
M("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S(&UO9&4](F-O;G1E;G0M=&%B
M;&4B('-E;&5C=#TB;F]D92@I6W!O<VET:6]N*"D@)FQT.R`D=&%B3F]D95!O
M<VET:6]N<R]T86(M<W1O<"UN;V1E+7!O<VET:6]N6R1E;F1I;F=486)3=&]P
M4&]S:71I;VY=75MP;W-I=&EO;B@I(#X@)'1A8DYO9&50;W-I=&EO;G,O=&%B
M+7-T;W`M;F]D92UP;W-I=&EO;ELD96YD:6YG5&%B4W1O<%!O<VET:6]N("T@
M,5U=(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA
M=&5S/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X
M<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H@("`@/'AS;#IT96UP
M;&%T92!M;V1E/2)C;VYT96YT+71A8FQE(B!M871C:#TB=&5X=#IS(CX*("`@
M("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M8G)E86MA8FQE
M+7=H:71E<W!A8V4B/@H@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB=VAI=&5S<&%C97,B('-E;&5C=#TB0'1E>'0Z8R(O/@H@("`@("`@(#PO
M>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@
M/'AS;#IT96UP;&%T92!M871C:#TB*B(@;6]D93TB8V5L;"UC;VYT96YT(CX*
M"B`@("`@("`@/'AS;#II9B!T97-T/2)N86UE*"D@/2`G=&5X=#IT86(M<W1O
M<"<@;W(@*EMN86UE*"D@/2`G=&5X=#IT86(M<W1O<"==(CX*("`@("`@("`@
M("`@/'AS;#IE;&5M96YT(&YA;64](G1A8BUS=&]P+6YO9&4M<&]S:71I;VXB
M/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G!O<VET
M:6]N*"DB+SX*("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`\
M+WAS;#II9CX*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\>'-L.G1E;7!L
M871E(&YA;64](F=R87`M8V5L;"UW:61T:"(^"B`@("`@("`@/'AS;#IP87)A
M;2!N86UE/2)P;W-I=&EO;B(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB
M86QL5&%B4W1O<%-T>6QE<R(O/@H*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA
M;64](G1A8E-T;W!0;W-I=&EO;B(@<V5L96-T/2(D86QL5&%B4W1O<%-T>6QE
M<R]S='EL93IT86(M<W1O<%LD<&]S:71I;VY=+T!S='EL93IP;W-I=&EO;B(O
M/@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB8V]N=&%I;G,H)'1A8E-T;W!0;W-I=&EO;BP@)V-M)RDB/@H@("`@
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R96%T92UC
M96QL+7=I9'1H(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB=VED=&@B("`@('-E;&5C=#TB;G5M8F5R*'-U8G-T<FEN9RUB
M969O<F4H)'1A8E-T;W!0;W-I=&EO;BPG8VTG*2DB+SX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=6YI="(@("`@('-E;&5C
M=#TB)V-M)R(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)P;W-I=&EO;B(@<V5L96-T/2(D<&]S:71I;VX@+2`Q(B\^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;%1A
M8E-T;W!3='EL97,B('-E;&5C=#TB)&%L;%1A8E-T;W!3='EL97,B+SX*("`@
M("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT
M86EN<R@D=&%B4W1O<%!O<VET:6]N+"`G:6XG*2(^"B`@("`@("`@("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8W)E871E+6-E;&PM=VED=&@B
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)W
M:61T:"(@("`@<V5L96-T/2)N=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=&%B
M4W1O<%!O<VET:6]N+"=I;B<I*2(O/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)U;FET(B`@("`@<V5L96-T/2(G:6XG(B\^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!O
M<VET:6]N(B!S96QE8W0](B1P;W-I=&EO;B`M(#$B+SX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL5&%B4W1O<%-T>6QE
M<R(@<V5L96-T/2(D86QL5&%B4W1O<%-T>6QE<R(O/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1T86)3
M=&]P4&]S:71I;VXL("=C:"<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L
M;"UT96UP;&%T92!N86UE/2)C<F5A=&4M8V5L;"UW:61T:"(^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G=I9'1H(B`@("!S
M96QE8W0](FYU;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1T86)3=&]P4&]S:71I
M;VXL)V-H)RDI(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](G5N:70B("`@("!S96QE8W0](B=C:"<B+SX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&]S:71I;VXB('-E
M;&5C=#TB)'!O<VET:6]N("T@,2(O/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q486)3=&]P4W1Y;&5S(B!S96QE8W0]
M(B1A;&Q486)3=&]P4W1Y;&5S(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC
M86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'1A8E-T;W!0;W-I=&EO
M;BP@)W!T)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64](F-R96%T92UC96QL+7=I9'1H(CX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=VED=&@B("`@('-E;&5C=#TB;G5M
M8F5R*'-U8G-T<FEN9RUB969O<F4H)'1A8E-T;W!0;W-I=&EO;BPG<'0G*2DB
M+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M=6YI="(@("`@('-E;&5C=#TB)W!T)R(O/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P;W-I=&EO;B(@<V5L96-T/2(D<&]S
M:71I;VX@+2`Q(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](F%L;%1A8E-T;W!3='EL97,B('-E;&5C=#TB)&%L;%1A8E-T
M;W!3='EL97,B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA
M=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H@("`@/'AS;#IT96UP;&%T92!N
M86UE/2)C<F5A=&4M8V5L;"UW:61T:"(^"B`@("`@("`@/'AS;#IP87)A;2!N
M86UE/2)W:61T:"(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB=6YI="(O
M/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<&]S:71I;VXB+SX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](F%L;%1A8E-T;W!3='EL97,B+SX*"B`@("`@
M("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D
M<&]S:71I;VX@/B`Q(CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP
M;&%T92!N86UE/2)C<F5A=&4M8V5L;"UW:61T:"(^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G=I9'1H(B`@("!S96QE8W0]
M(B1W:61T:"`M(&YU;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1A;&Q486)3=&]P
M4W1Y;&5S+W-T>6QE.G1A8BUS=&]P6R1P;W-I=&EO;ETO0'-T>6QE.G!O<VET
M:6]N+"1U;FET*2DB+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB=6YI="(@("`@('-E;&5C=#TB)'5N:70B+SX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&]S:71I;VXB
M('-E;&5C=#TB)'!O<VET:6]N("T@,2(O/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q486)3=&]P4W1Y;&5S(B!S96QE
M8W0](B1A;&Q486)3=&]P4W1Y;&5S(B\^"B`@("`@("`@("`@("`@("`\+WAS
M;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB)'!O<VET:6]N(#T@,2(^"B`@("`@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"1W:61T
M:"`M(&YU;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1A;&Q486)3=&]P4W1Y;&5S
M+W-T>6QE.G1A8BUS=&]P6R1P;W-I=&EO;ETO0'-T>6QE.G!O<VET:6]N+"1U
M;FET*2DL("1U;FET*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2)C;VYC870H)'=I9'1H+"`D=6YI="DB+SX*("`@
M("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S
M93X*("`@(#PO>'-L.G1E;7!L871E/@H*/"]X<VPZ<W1Y;&5S:&5E=#X`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V]O;R]M86EN7VAT;6PN>'-L````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`U-C4S,P`Q,#4Q-30S,S<T-P`P,C0W-S``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/"$M+0H*
M("`@5&AE($-O;G1E;G1S(&]F('1H:7,@9FEL92!A<F4@;6%D92!A=F%I;&%B
M;&4@<W5B:F5C="!T;R!T:&4@=&5R;7,@;V8*("`@96ET:&5R(&]F('1H92!F
M;VQL;W=I;F<@;&EC96YS97,*"B`@("`@("`@("`M($=.52!,97-S97(@1V5N
M97)A;"!0=6)L:6,@3&EC96YS92!697)S:6]N(#(N,0H@("`@("`@("`@+2!3
M=6X@26YD=7-T<GD@4W1A;F1A<F1S(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@
M,2XQ"@H@("!3=6X@36EC<F]S>7-T96US($EN8RXL($]C=&]B97(L(#(P,#`*
M"B`@($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!697)S:6]N
M(#(N,0H@("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T*("`@0V]P>7)I9VAT(#(P,#`@8GD@4W5N($UI8W)O<WES=&5M
M<RP@26YC+@H@("`Y,#$@4V%N($%N=&]N:6\@4F]A9"P@4&%L;R!!;'1O+"!#
M02`Y-#,P,RP@55-!"@H@("!4:&ES(&QI8G)A<GD@:7,@9G)E92!S;V9T=V%R
M93L@>6]U(&-A;B!R961I<W1R:6)U=&4@:70@86YD+V]R"B`@(&UO9&EF>2!I
M="!U;F1E<B!T:&4@=&5R;7,@;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0
M=6)L:6,*("`@3&EC96YS92!V97)S:6]N(#(N,2P@87,@<'5B;&ES:&5D(&)Y
M('1H92!&<F5E(%-O9G1W87)E($9O=6YD871I;VXN"@H@("!4:&ES(&QI8G)A
M<GD@:7,@9&ES=')I8G5T960@:6X@=&AE(&AO<&4@=&AA="!I="!W:6QL(&)E
M('5S969U;"P*("`@8G5T(%=)5$A/550@04Y9(%=!4E)!3E19.R!W:71H;W5T
M(&5V96X@=&AE(&EM<&QI960@=V%R<F%N='D@;V8*("`@34520TA!3E1!0DE,
M2519(&]R($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%+B`@4V5E
M('1H92!'3E4*("`@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@9F]R
M(&UO<F4@9&5T86EL<RX*"B`@(%EO=2!S:&]U;&0@:&%V92!R96-E:79E9"!A
M(&-O<'D@;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*("`@3&EC
M96YS92!A;&]N9R!W:71H('1H:7,@;&EB<F%R>3L@:68@;F]T+"!W<FET92!T
M;R!T:&4@1G)E92!3;V9T=V%R90H@("!&;W5N9&%T:6]N+"!);F,N+"`U.2!4
M96UP;&4@4&QA8V4L(%-U:71E(#,S,"P@0F]S=&]N+`H@("!-02`@,#(Q,3$M
M,3,P-R`@55-!"@H*("`@4W5N($EN9'5S=')Y(%-T86YD87)D<R!3;W5R8V4@
M3&EC96YS92!697)S:6]N(#$N,0H@("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@(%1H92!C;VYT96YT<R!O
M9B!T:&ES(&9I;&4@87)E('-U8FIE8W0@=&\@=&AE(%-U;B!);F1U<W1R>2!3
M=&%N9&%R9',*("`@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$@*'1H92`B
M3&EC96YS92(I.R!9;W4@;6%Y(&YO="!U<V4@=&AI<R!F:6QE"B`@(&5X8V5P
M="!I;B!C;VUP;&EA;F-E('=I=&@@=&AE($QI8V5N<V4N(%EO=2!M87D@;V)T
M86EN(&$@8V]P>2!O9B!T:&4*("`@3&EC96YS92!A="!H='1P.B\O=W=W+F]P
M96YO9F9I8V4N;W)G+VQI8V5N<V4N:'1M;"X*"B`@(%-O9G1W87)E('!R;W9I
M9&5D('5N9&5R('1H:7,@3&EC96YS92!I<R!P<F]V:61E9"!O;B!A;B`B05,@
M25,B(&)A<VES+`H@("!7251(3U54(%=!4E)!3E19($]&($%.62!+24Y$+"!%
M251(15(@15A04D534R!/4B!)35!,245$+"!)3D-,541)3D<L"B`@(%=)5$A/
M550@3$E-251!5$E/3BP@5T%24D%.5$E%4R!42$%4(%1(12!33T945T%212!)
M4R!&4D5%($]&($1%1D5#5%,L"B`@($U%4D-(04Y404),12P@1DE4($9/4B!!
M(%!!4E1)0U5,05(@4%524$]312P@3U(@3D].+4E.1E))3D=)3D<N"B`@(%-E
M92!T:&4@3&EC96YS92!F;W(@=&AE('-P96-I9FEC('!R;W9I<VEO;G,@9V]V
M97)N:6YG('EO=7(@<FEG:'1S(&%N9`H@("!O8FQI9V%T:6]N<R!C;VYC97)N
M:6YG('1H92!3;V9T=V%R92X*"B`@(%1H92!);FET:6%L($1E=F5L;W!E<B!O
M9B!T:&4@3W)I9VEN86P@0V]D92!I<SH@4W5N($UI8W)O<WES=&5M<RP@26YC
M+@H*("`@0V]P>7)I9VAT(,*I(#(P,#(@8GD@4W5N($UI8W)O<WES=&5M<RP@
M26YC+@H*("`@06QL(%)I9VAT<R!297-E<G9E9"X*"B`@($-O;G1R:6)U=&]R
M*',I.B!?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U\*
M"BTM/@H\>'-L.G-T>6QE<VAE970@=F5R<VEO;CTB,2XP(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z>'-L/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+UA33"]4
M<F%N<V9O<FTB"B`@("`@("`@("`@("`@("!X;6QN<SIO9F9I8V4](FAT='`Z
M+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V]F9FEC92(*("`@("`@("`@("`@("`@
M('AM;&YS.G-T>6QE/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]S='EL
M92(*("`@("`@("`@("`@("`@('AM;&YS.G1E>'0](FAT='`Z+R]O<&5N;V9F
M:6-E+F]R9R\R,#`P+W1E>'0B"B`@("`@("`@("`@("`@("!X;6QN<SIT86)L
M93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O=&%B;&4B"B`@("`@("`@
M("`@("`@("!X;6QN<SID<F%W/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P
M,"]D<F%W:6YG(@H@("`@("`@("`@("`@("`@>&UL;G,Z9F\](FAT='`Z+R]W
M=W<N=S,N;W)G+S$Y.3DO6%-,+T9O<FUA="(*("`@("`@("`@("`@("`@('AM
M;&YS.GAL:6YK/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+WAL:6YK(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z;G5M8F5R/2)H='1P.B\O;W!E;F]F9FEC92YO
M<F<O,C`P,"]D871A<W1Y;&4B"B`@("`@("`@("`@("`@("!X;6QN<SIS=F<]
M(FAT='`Z+R]W=W<N=S,N;W)G+S(P,#`O<W9G(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z8VAA<G0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V-H87)T
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z9'(S9#TB:'1T<#HO+V]P96YO9F9I
M8V4N;W)G+S(P,#`O9'(S9"(*("`@("`@("`@("`@("`@('AM;&YS.FUA=&@]
M(FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3@O36%T:"]-871H34PB"B`@("`@("`@
M("`@("`@("!X;6QN<SIF;W)M/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P
M,"]F;W)M(@H@("`@("`@("`@("`@("`@>&UL;G,Z<V-R:7!T/2)H='1P.B\O
M;W!E;F]F9FEC92YO<F<O,C`P,"]S8W)I<'0B"B`@("`@("`@("`@("`@("!O
M9F9I8V4Z8VQA<W,](G1E>'0B"B`@("`@("`@("`@("`@("!O9F9I8V4Z=F5R
M<VEO;CTB,2XP(@H@("`@("`@("`@("`@("`@>&UL;G,Z9&,](FAT='`Z+R]P
M=7)L+F]R9R]D8R]E;&5M96YT<R\Q+C$O(@H@("`@("`@("`@("`@("`@>&UL
M;G,Z;65T83TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O;65T82(*("`@
M("`@("`@("`@("`@('AM;&YS.F-O;F9I9STB:'1T<#HO+V]P96YO9F9I8V4N
M;W)G+S(P,#$O8V]N9FEG(@H@("`@("`@("`@("`@("`@>&UL;G,Z:&5L<#TB
M:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O:&5L<"(*("`@("`@("`@("`@
M("`@('AM;&YS.GAT/2)H='1P.B\O=W=W+FIC;&%R:RYC;VTO>'0B"B`@("`@
M("`@("`@("`@("!X;6QN<SIS>7-T96T](FAT='`Z+R]W=W<N:F-L87)K+F-O
M;2]X="]J879A+VIA=F$N;&%N9RY3>7-T96TB"B`@("`@("`@("`@("`@("!X
M;6QN<SIU<FQE;F-O9&5R/2)H='1P.B\O=W=W+FIC;&%R:RYC;VTO>'0O:F%V
M82]J879A+FYE="Y54DQ%;F-O9&5R(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M>&%L86X](FAT='`Z+R]X;6PN87!A8VAE+F]R9R]X86QA;B(*("`@("`@("`@
M("`@("`@('AM;&YS.FIA=F$](FAT='`Z+R]X;6PN87!A8VAE+F]R9R]X<VQT
M+VIA=F$B"B`@("`@("`@("`@("`@("!E>&-L=61E+7)E<W5L="UP<F5F:7AE
M<STB:F%V82(^"@H@("`@/'AS;#IO=71P=70@;65T:&]D("`@("`@/2)X;6PB
M"B`@("`@("`@("`@("`@("!E;F-O9&EN9R`@("`](E541BTX(@H@("`@("`@
M("`@("`@("`@:6YD96YT("`@("`@/2)Y97,B+SX*"@H*("`@(#PA+2TK*RLK
M*R!)3D-,541%1"!84TP@34]$54Q%4R`K*RLK*RTM/@H@("`@/"$M+2!I;FAE
M<FET960@<W1Y;&4@<')O<&5R=&EE<R!W:6QL(&)E(&-O;&QE8W1E9"!A;F0@
M=W)I='1E;B!I;B!A($-34R!H96%D97(@*$-34RD@+2T^"B`@("`\>'-L.FEN
M8VQU9&4@:')E9CTB<W1Y;&5?:&5A9&5R+GAS;"(O/@H*("`@(#PA+2T@:6YH
M97)I=&5D('-T>6QE('!R;W!E<G1I97,@=VEL;"!B92!C;VQL96-T960@86YD
M('=R:71T96X@87,@:'1M;"!P<F]P97)T:65S(&EN(&$@=&5M<&]R87)Y('9A
M<FEA8FQE("A(5$U,-"P@4$%,32D@+2T^"B`@("`\>'-L.FEN8VQU9&4@:')E
M9CTB<W1Y;&5?:6YL:6YE9"YX<VPB+SX*"B`@("`\(2TM(&]U<B!X;6P@<W1Y
M;&4@<')O<&5R=&EE<R!W:6QL(&)E(&UA<'!E9"!T;R!#4U,@86YD($A434PT
M+G@@<')O<&5R=&EE<R`M+3X*("`@(#QX<VPZ:6YC;'5D92!H<F5F/2)S='EL
M95]M87!P:6YG+GAS;"(O/@H*("`@(#PA+2T@8V]M;6]N(&5L96UE;G0@:&%N
M9&QI;F<@+2T^"B`@("`\>'-L.FEN8VQU9&4@:')E9CTB8V]M;6]N+GAS;"(O
M/@H*("`@(#PA+2T@=&%B;&4@:&%N9&QI;F<@+2T^"B`@("`\>'-L.FEN8VQU
M9&4@:')E9CTB=&%B;&4N>'-L(B\^"@H@("`@/"$M+2!P86QM(&AA;F1L:6YG
M("TM/@H@("`@/'AS;#II;F-L=61E(&AR968](G!A;&TN>'-L(B\^"@H@("`@
M/"$M+2!G;&]B86P@9&]C=6UE;G0@:&%N9&QI;F<@+2T^"B`@("`\>'-L.FEN
M8VQU9&4@:')E9CTB9VQO8F%L7V1O8W5M96YT+GAS;"(O/@H*"@H*"@H*("`@
M(#PA+2TK*RLK*R!005)!345415(@1E)/32!42$4@05!03$E#051)3TX@04Y$
M($=,3T)!3"!605))04),15,@*RLK*RLM+3X*"B`@("`\(2TM($U!3D1!5$]2
M63H@55),(&]F(&UE=&$@<W1R96%M("TM/@H@("`@/'AS;#IP87)A;2!N86UE
M/2)M971A1FEL95523"(O/@H*("`@(#PA+2T@34%.1$%43U)9.B!54DP@;V8@
M<W1Y;&5S('-T<F5A;2`M+3X*("`@(#QX<VPZ<&%R86T@;F%M93TB<W1Y;&5S
M1FEL95523"(O/@H*("`@(#PA+2T@34%.1$%43U)9.B!F;W(@<F5S;VQV:6YG
M(')E;&%T:79E(&QI;FMS"B`@("`@("`@1F]R(')E<V]L=FEN9R!R96%L=&EV
M92!L:6YK<R!T;R!T:&4@<&%C:V5D(%-/(&1O8W5M96YT+"!I+F4N('1H92!P
M871H+U523"!O9B!T:&4@:F%R960@<WAW(&9I;&4@*&4N9RX@;65T82YX;6PL
M('-T>6QE<RYX;6PL(&QI;FMS('1O(&=R87!H:6-S(&EN(&$@<F5L871I=F4@
M9&ER96-T;W)Y*2`M+3X*("`@(#QX<VPZ<&%R86T@;F%M93TB86)S;VQU=&53
M;W5R8V5$:7)2968B+SX*"B`@("`\(2TM($]05$E/3D%,("AM86YD871O<GDL
M('=H96X@=VAE;B!S;W5R8V4@:7,@8V]M<')E<W-E9"DZ($YE8V5S<V%R>2!F
M;W(@=&AE(&EN('1H92!P86-K960@3T\@9&]C=6UE;G0@96UB961D960@9FEL
M97,@*&UO<W1L>2!G<F%P:&EC<R!F<F]M('1H92!C;VUP<F5S<V5D("]0:6-T
M=7)E(&1I<BDN"B`@("`@("`@(%=H96X@=&AE($]P96Y/9F9I8V4@*$]/*2!F
M:6QE(&AA<R!B965N('5N<&%C:V5D('1H92!A8G-O;'5T95-O=7)E1&ER4F5F
M(&-A;B!B92!T86ME;BP*("`@("`@("`@3W1H97)W:7-E+"!A($I!4B!54DP@
M8V]U;&0@8F4@8VAO;W-E;B!O<B!W:&5N('=O<FMI;F<@=VET:"!/<&5N3V9F
M:6-E(&$@<V\@8V%L;&5D(%!A8VMA9V4M55),(&5N8V]D960@;W9E<B!(5%10
M(&-A;B!B92!U<V5D('1O"B`@("`@("`@(&%C8V5S<R!T:&4@:F%R960@8V]N
M=&5N=',@;V8@=&AE('1H92!J87)E9"!D;V-U;65N="X@+B`M+3X*("`@(#QX
M<VPZ<&%R86T@;F%M93TB:F%R9612;V]T55),(B!S96QE8W0](B1A8G-O;'5T
M95-O=7)C941I<E)E9B(O/@H*("`@(#PA+2T@3U!424].04P@*&UA;F1A=&]R
M>2P@=VAE;B!U<V5D(&EN('-E<W-I;VX@8F%S960@96YV:7)O;FUE;G0I"B`@
M("`@("`@(%5S969U;"!F;W(@5V5B07!P;&EC871I;VYS.B!I9B!A($A45%`@
M<V5S<VEO;B!I<R!N;W0@8V]O:VEE(&)A<V5D+"!54DP@<F5W<FET:6YG(&ES
M(&)E96EN9R!U<V5D("AT:&4@<V5S<VEO;B!I<R!A<'!E;F1E9"!T;R!T:&4@
M55),*2X*("`@("`@("`@5&AI<R!54DP@<V5S<VEO;B!I<R!U<V5D('=H96X@
M8W)E871I;F<@;&EN:W,@=&\@9W)A<&AI8W,@8GD@6%-,5"X@3W1H97)W:7-E
M('1H92!U<V5R(&AA=G0@=&\@;&]G(&%G86EN(&EN(&9O<B!E=F5R>2!G<F%P
M:&EC(&AE('=O=6QD(&QI:V4@=&\@<V5E+B`M+3X*("`@(#QX<VPZ<&%R86T@
M;F%M93TB;W!T:6]N86Q54DQ3=69F:7@B+SX*"B`@("`\(2TM($]05$E/3D%,
M.B!$4$D@*&1O=',@<&5R(&EN8V@I('1H92!S=&%N9&%R9"!S;VQU=&EO;B!O
M9B!G:79E;B!P:6-T=7)E<R`H;F5C97-S87)Y(&9O<B!T:&4@8V]N=F5R<VEO
M;B!O9B`G8VTG(&EN=&\@)W!I>&5L)RDM+3X*("`@(#PA+2T@06QT:&]U9V@@
M;6%N>2!P:6-T=7)E<R!H879E('1H92`Y-B!D<&D@<F5S;VQU=&EO;BP@82!H
M:6=H97(@<F5S;VQT:6]N(&=I=F4@8F5T=&5R(')E<W5L=',@9F]R(&-O;6UO
M;B!B<F]W<V5R<R`M+3X*("`@(#QX<VPZ<&%R86T@;F%M93TB9'!I(B!S96QE
M8W0](CDV(B\^"@H@("`@/"$M+2!/4%1)3TY!3#H@:6X@8V%S92!O9B!U<VEN
M9R!A(&1I9F9E<F5N="!P<F]C97-S;W(@=&AA;B!A($I!5D$@6%-,5"P@>6]U
M(&-A;B!U;F%B;&4@=&AE($IA=F$@9G5N8W1I;VYA;&ET>0H@("`@("`@("`H
M:2YE+B!D96)U9V=I;F<@=&EM92!A;F0@96YC;V1I;F<@8VAA<'1E<B!N86UE
M<R!F;W(@=&AE(&-O;G1E;G0M=&%B;&4@87,@:')E9B!A;F0@86YC:&]R<R`I
M("TM/@H@("`@/'AS;#IP87)A;2!N86UE/2)D:7-A8FQE2F%V82(@("`@<V5L
M96-T/2)F86QS92(O/@H@("`@/'AS;#IP87)A;2!N86UE/2)I<TIA=F%$:7-A
M8FQE9"(@<V5L96-T/2)B;V]L96%N*"1D:7-A8FQE2F%V82DB+SX*"B`@("`\
M(2TM($]05$E/3D%,.B!U<V5R+6%G96YT('=I;&P@8F4@9&EF9F5R;G1I871E
M9"!B>2!T:&ES('!A<F%M971E<B!G:79E;B!B>2!A<'!L:6-A=&EO;B`H92YG
M+B!J879A('-E<G9L970I+2T^"B`@("`\>'-L.G!A<F%M(&YA;64](F]U='!U
M=%1Y<&4B('-E;&5C=#TB)T-34U](14%$15(G(B\^"B`@("`\(2TM('-E="!O
M9B!P;W-S:6)L92!D979I8V54>7!S("A734P@:7,@<V5T(&EN(&ET<R!O=VX@
M<W1A<G1F:6QE(&UA:6Y?=VUL+GAS;"DZ"B`@("`\>'-L.G!A<F%M(&YA;64]
M(F]U='!U=%1Y<&4B('-E;&5C=#TB)T-34U](14%$15(G(B\^"B`@("`\>'-L
M.G!A<F%M(&YA;64](F]U='!U=%1Y<&4B('-E;&5C=#TB)T-34U])3DQ)3D5$
M)R(O/@H@("`@/'AS;#IP87)A;2!N86UE/2)O=71P=714>7!E(B!S96QE8W0]
M(B=004Q-)R(O/B`M+3X*"B`@("`\(2TM($]05$E/3D%,.B!F;W(@86-T:79A
M=&EN9R!T:&4@9&5B=6<@;6]D92!S970@=&AE('9A<FEA8FQE(&AE<F4@=&\@
M)W1R=64H*2<@;W(@9VEV92!A;GD@=F%L=64@9G)O;2!O=71S:61E("TM/@H@
M("`@/'AS;#IP87)A;2!N86UE/2)D96)U9R(@("`@("`@("!S96QE8W0](F9A
M;'-E(B\^"B`@("`\>'-L.G!A<F%M(&YA;64](FES1&5B=6=-;V1E(B`@('-E
M;&5C=#TB8F]O;&5A;B@D9&5B=6<I(B\^"@H\(2TM("HJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BH*("`@($]05$E/3D%,.B!.145$140@24X@0T].3D5#
M5$E/3B!7251(($$@1TQ/0D%,($1/0U5-14Y4("TM/@H*("`@(#PA+2U354U-
M05)9.@H@("`@("`@("!F;VQL;W=I;F<@<&%R86UE=&5R('1R:6=G97)S(&$@
M*'%U:71E('1I;64@8V]N<W5M:6YG*2!E;F%B;&EN9R!O9B!B;V]K;6%R:W,@
M:6X@=&AE('1A8FQE+6]F+6-O;G1E;G0N"B`@("`@("`@24X@1$5404E,.@H@
M("`@("`@("!#=7)R96YT;'D@<V]M92!L:6YK<R!U<V5D(&EN('1H92!/9F9I
M8V4@6$U,("AE+F<N(&EN('1H92!C;VYT96YT('1A8FQE(&%S("<C-RY3;VUE
M)3(P17AA;7!L924R,$AE861L:6YE)3=/=71L:6YE)RD*("`@("`@("`@:7,@
M;F]T(&$@=F%L:60@55),("AC;7`N(&)U9R!I9",@,3`R,S$Q*2X@3F\@9FEL
M92!D97-T:6YA=&EO;B!I<R!S<&5C:69I960@;F]R(&5X:7-T(&%N>2!A;F-H
M;W(@96QE;65N="!F;W(@=&AE<V4*("`@("`@("`@;&EN:W,@:6X@=&AE($]F
M9FEC92!834PN"B`@("`@("`@($$@=V]R:V%R;W5N9"!F;W(@=&AI<R!T<F%N
M<V9O<FUA=&EO;B!T:&5R969O<F4@:&%D('1O(&)E(&UA9&4N(%1H:7,@=&EM
M92UC;VYS=6UI;F<@;65C:&%N:7-M(&ES(&1I<V%B;&5D(&)Y(&1E9F%U;'0@
M86YD"B`@("`@("`@(&-A;B!B92!A8W1I=F%T960@8GD@82!P87)A;65T97(@
M*&DN92X@)V1I<V%B;&5,:6YK961486)L94]F0V]N=&5N="<I+B!!(&-R96%T
M:6]N(&]F(&%N(&%N8VAO<B!I<R!M861E(&9O<B!E86-H(&AE861E<B!E;&5M
M96YT+@H@("`@("`@("!!;&P@:&5A9&5R('1I=&QE<R!G;VYN82!B92!E;F-O
M9&EN9R!T;R!B92!U<V%B;&4@:6X@82!R96QA=&EV92!54DPN("`@("TM/@H@
M("`@/'AS;#IP87)A;2!N86UE/2)D:7-A8FQE3&EN:V5D5&%B;&5/9D-O;G1E
M;G0B('-E;&5C=#TB9F%L<V4H*2(O/@H*("`@(#PA+2T@5&AE(&-H87!T97(@
M;G5M8F5R<R!O9B!T:&4@8W5R<F5N="!D;V-U;65N="`H87,@82!S97%U96YC
M92!O9B!A(&=L;V)A;"!D;V-U;65N="D@:7,@9&5P96YD96YT(&]F('1H92!N
M=6UB97(*("`@("`@("!O9B!C:&%P=&5R(&]F('1H92!S86UE(&QE=F5L(&EN
M('!R96-E9&EN9R!D;V-U;65N=',N("TM/@H@("`@/'AS;#IP87)A;2!N86UE
M/2)P<F5C961I;F=#:&%P=&5R3&5V96PQ(B`@<V5L96-T/2(P(B\^"B`@("`\
M>'-L.G!A<F%M(&YA;64](G!R96-E9&EN9T-H87!T97),979E;#(B("!S96QE
M8W0](C`B+SX*("`@(#QX<VPZ<&%R86T@;F%M93TB<')E8V5D:6YG0VAA<'1E
M<DQE=F5L,R(@('-E;&5C=#TB,"(O/@H@("`@/'AS;#IP87)A;2!N86UE/2)P
M<F5C961I;F=#:&%P=&5R3&5V96PT(B`@<V5L96-T/2(P(B\^"B`@("`\>'-L
M.G!A<F%M(&YA;64](G!R96-E9&EN9T-H87!T97),979E;#4B("!S96QE8W0]
M(C`B+SX*("`@(#QX<VPZ<&%R86T@;F%M93TB<')E8V5D:6YG0VAA<'1E<DQE
M=F5L-B(@('-E;&5C=#TB,"(O/@H@("`@/'AS;#IP87)A;2!N86UE/2)P<F5C
M961I;F=#:&%P=&5R3&5V96PW(B`@<V5L96-T/2(P(B\^"B`@("`\>'-L.G!A
M<F%M(&YA;64](G!R96-E9&EN9T-H87!T97),979E;#@B("!S96QE8W0](C`B
M+SX*("`@(#QX<VPZ<&%R86T@;F%M93TB<')E8V5D:6YG0VAA<'1E<DQE=F5L
M.2(@('-E;&5C=#TB,"(O/@H@("`@/'AS;#IP87)A;2!N86UE/2)P<F5C961I
M;F=#:&%P=&5R3&5V96PQ,"(@<V5L96-T/2(P(B\^"@H@("`@/"$M+2!834P@
M9&]C=6UE;G1S(&-O;G1A:6YI;F<@82!T86)L92!O9B!C;VYT96YT<RP*("`@
M("`@("!G;VYN82!L:6YK(&9O<B!U<V%B:6QI='D@<F5A<V]N(&%B;W9E(&5A
M8V@@8VAA<'1E<B!T;R!T:&4@<')E8V5D:6YG(&%N9"!F;VQL;W=I;F<@9&]C
M=6UE;G0@86YD('1H92!C;VYT96YT('1A8FQE("TM/@H@("`@/'AS;#IP87)A
M;2!N86UE/2)C;VYT96YT5&%B;&554DPB+SX*"B`@("`\(2TM($YE961E9"!F
M;W(@=&AE(&)U9R!W;W)K87)O=6YD(&]F(&UI<W-I;F<@8V]N=&5N="!T86)L
M92!L:6YK<PH@("`@("`@(&)Y('1H:7,@86UB:6=O=7,@2%1-3"!R969E<F5N
M8V5S(&9R;VT@=&AE(&-O;G1E;G0@=&%B;&4@8V%N(&)E(&5V;VED960M+3X*
M("`@(#QX<VPZ<&%R86T@;F%M93TB9VQO8F%L1&]C=6UE;G129694;T-U<G)E
M;G1&:6QE(B\^"@H@("`@/"$M+2!.965D960@9F]R('1H92!B=6<@=V]R:V%R
M;W5N9"!O9B!M:7-S:6YG(&-O;G1E;G0@=&%B;&4@;&EN:W,*("`@("`@("!B
M>2!T:&ES(&YO9&4M<V5T('1H92!R96QA=&EO;B!B971W965N(&-O;G1E;G0M
M=&%B;&4@;&EN:R!A;F0@8VAI;&1R96X@9&]C=6UE;G0@:&5A9&5R(&-A;B!B
M92!U;F%M8FEG;W5S(&5S=&%B;&ES:&5D("TM/@H@("`@/'AS;#IP87)A;2!N
M86UE/2)C;VYT96YT5&%B;&5(96%D:6YG<R(O/@H*"CPA+2T@14Y$($]&($=,
M3T)!3"!$3T-5345.5"!314-424]."BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHM+3X*"@H*("`@(#PA+2T@=V]R:W,@9F]R(&YO<FUA;"!S97!A<F%T
M960@>FEP<&5D('AM;"!F:6QE<R!A<R!F;W(@9FQA="!F:6QT97(@<VEN9VQE
M('AM;"!F:6QE(&9O<FUA="!A<R!W96QL("TM/@H@("`@/'AS;#IV87)I86)L
M92!N86UE/2)O9F9I8V4Z;65T82UF:6QE(B`@("`@("`@("`@<V5L96-T/2)D
M;V-U;65N="@D;65T849I;&554DPI(B\^"B`@("`\>'-L.G9A<FEA8FQE(&YA
M;64](F]F9FEC93IS='EL97,M9FEL92(@("`@("`@("!S96QE8W0](F1O8W5M
M96YT*"1S='EL97-&:6QE55),*2(O/@H@("`@/'AS;#IV87)I86)L92!N86UE
M/2)O9F9I8V4Z9F]N="UD96-L<R(@("`@("`@("`@<V5L96-T/2(D;V9F:6-E
M.G-T>6QE<RUF:6QE+RHO;V9F:6-E.F9O;G0M9&5C;',B+SX*("`@(#QX<VPZ
M=F%R:6%B;&4@;F%M93TB;V9F:6-E.G-T>6QE<R(@("`@("`@("`@("`@('-E
M;&5C=#TB)&]F9FEC93IS='EL97,M9FEL92\J+V]F9FEC93IS='EL97,B+SX*
M("`@(#PA+2T@;V9F:6-E.F%U=&]M871I8RUS='EL97,@;6%Y(&]C8W5R92!I
M;B!T=V\@9&EF9F5R96YT(&9I;&5S("AI+F0N(&-O;G1E;G0N>&UL(&%N9"!S
M='EL97,N>&UL*2X@1G5R=&AE<FUO<F4@=&AE('1O<"!L979E;"!T86<@:7,@
M9&EF9F5R96YT(&EN(&$@9FQA="!X;6P@9FEL92`M+3X*("`@(#QX<VPZ=F%R
M:6%B;&4@;F%M93TB;V9F:6-E.F%U=&]M871I8RUS='EL97,B("`@('-E;&5C
M=#TB+RHO;V9F:6-E.F%U=&]M871I8RUS='EL97,B+SX*"B`@("`\(2TM('-I
M;7!L92!D96-L87)A=&EO;B!O9B!734P@=7-E9"!T;R!A=F]I9"!P87)S97(@
M97)R;W)S("TM/@H@("`@/'AS;#IV87)I86)L92!N86UE/2)W87`M<&%R86=R
M87!H+65L96UE;G1S+7=I=&AO=70M=&%B;&4M<F]W(B\^"B`@("`\>'-L.G9A
M<FEA8FQE(&YA;64](G=A<"UP87)A9W)A<&@M96QE;65N=',B+SX*("`@(#QX
M<VPZ=&5M<&QA=&4@;F%M93TB=VUL+7)E<&5A="UW<FET92UR;W<B+SX*"@H@
M("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M("TM/@H@("`@/"$M+2`J*BH@8G5I;&0@=&AE('!R;W!R:6%T92!(5$U,(&9I
M;&4@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ("TM/@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](B\B
M/@H*("`@("`@("`\(2TM/'AS;#IM97-S86=E/@H*"B`@("`@("`@16YT97)E
M9"!T:&4@<W1Y;&53:&5E=',L('1R86YS9F]R;6%T:6]N(&)E9VEN<RXN+B`\
M+WAS;#IM97-S86=E/BTM/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](B1I<T1E8G5G36]D92(^"B`@("`@("`@
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8VAE8VLM<&%R86UE
M=&5R(B\^"@H@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2)N;W0H)&ES
M2F%V841I<V%B;&5D*2(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64](F1E8G5G+7-T>6QE+6-O;&QE8W1I;F<M=&EM92(O
M/@H@("`@("`@("`@("`@("`@/"]X<VPZ:68^"B`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@
M("`@("`@/"$M+2!T;R!A8V-E<W,@=&AE('9A<FEA8FQE(&QI:V4@82!N;V1E
M+7-E="!I="!I<R!N96-E<W-A<GD@=&\@8V]N=F5R="!I=`H@("`@("`@("`@
M("`@("`@("`@("!F<F]M(&$@<F5S=6QT+71R964M9G)A9VUE;G0@*%)41BD@
M=&\@82!N;V1E('-E="!U<VEN9R!T:&4@2F%M97,@0VQA<FL@97AT96YS:6]N
M("TM/@H@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)C;VQL
M96-T961';&]B86Q$871A+5)41B(^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64])V-R96%T92UA;&PM:6YL:6YE+7-T>6QE
M<R<O/@H@("`@("`@("`@("`@("`@/"]X<VPZ=F%R:6%B;&4^"@H@("`@("`@
M("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G>'0Z;F]D92US970G
M*2(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T
M92!N86UE/2)S=&%R="(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L
M96-T/2)X=#IN;V1E+7-E="@D8V]L;&5C=&5D1VQO8F%L1&%T82U25$8I(B\^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^
M"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=X
M86QA;CIN;V1E<V5T)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F-A;&PM=&5M<&QA=&4@;F%M93TB<W1A<G0B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L
M;V)A;$1A=&$B('-E;&5C=#TB>&%L86XZ;F]D97-E="@D8V]L;&5C=&5D1VQO
M8F%L1&%T82U25$8I(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](DYO9&53971&
M=6YC=&EO;DYO=$%V86EL86)L92(O/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB<W1A<G0B+SX*("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\
M+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@
M("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"B`@("`\
M>'-L.G1E;7!L871E(&YA;64](G-T87)T(CX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/'AS;#IC
M:&]O<V4^"B`@("`@("`@("`@(#PA+2TK*RLK*R!#4U,@*$-!4T-!1$E.1R!3
M5$Q912!32$5%5"D@2$5!1$52(%-464Q%(%=!62`K*RLK*RTM/@H@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G0U-37TA%041%
M4B<B/@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](FAT;6PB
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)H96%D
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$
M96)U9TUO9&4B/CQX<VPZ;65S<V%G93Y#4U,@:&5L<&5R('9A<FEA8FQE('=I
M;&P@8F4@8W)E871E9"XN+BX\+WAS;#IM97-S86=E/CPO>'-L.FEF/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TG
M8V]M;6]N+6AE861E<BUP<F]P97)T:65S)R\^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B=6=-;V1E(CX\>'-L.FUE<W-A
M9V4^0U-3('9A<FEA8FQE(')E861Y+"!H96%D97(@=VEL;"!B92!C<F5A=&5D
M+BXN+CPO>'-L.FUE<W-A9V4^/"]X<VPZ:68^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#PA+2T@8V]N<W1R=6-T:6YG('1H92!C<W,@:&5A9&5R('-I;75L
M871I;F<@:6YH97)I=&%N8V4@;V8@<W1Y;&4M9F%M:6QI97,@8GD@<W1Y;&4@
M;W)D97(@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2=C<F5A=&4M8W-S+7-T>6QE:&5A9&5R)R\^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B=6=-;V1E
M(CX\>'-L.FUE<W-A9V4^0U-3(&AE861E<B!C<F5A=&EO;B!F:6YI<VAE9"$\
M+WAS;#IM97-S86=E/CPO>'-L.FEF/@H@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F5L96UE;G0^"@H*"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV87)I
M86)L92!N86UE/2)B86-K9W)O=6YD26UA9V554DPB('-E;&5C=#TB)&]F9FEC
M93IA=71O;6%T:6,M<W1Y;&5S+W-T>6QE.G!A9V4M;6%S=&5R+W-T>6QE.G!R
M;W!E<G1I97,O<W1Y;&4Z8F%C:V=R;W5N9"UI;6%G92]`>&QI;FLZ:')E9B(O
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)B;V1Y
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!B86-K9W)O=6YD(&EM
M86=E("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0]
M(B1B86-K9W)O=6YD26UA9V554DPB/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8F%C:V=R;W5N9"(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@9F]R(&EM86=E
M<R!J87)E9"!I;B!O<&5N(&]F9FEC92!D;V-U;65N="`M+3X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O
M;G1A:6YS*"1B86-K9W)O=6YD26UA9V554DPL("<C4&EC='5R97,O)RDB/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!C
M<F5A=&EN9R!A;B!A8G-O;'5T92!H='1P(%523"!T;R!T:&4@8V]N=&%I;F5D
M+W!A8VME9"!I;6%G92!F:6QE("TM/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O;F-A
M="@D:F%R9612;V]T55),+"`G+U!I8W1U<F5S+R<L('-U8G-T<FEN9RUA9G1E
M<B@D8F%C:V=R;W5N9$EM86=E55),+"`G(U!I8W1U<F5S+R<I+"`D;W!T:6]N
M86Q54DQ3=69F:7@I(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB<W)C
M(CX\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&)A8VMG<F]U;F1);6%G95523"(O
M/CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ:68^"@H@("`@("`@("`@("`@("`@("`@("`@("`\(2TM
M('!R;V-E<W-I;F<@=&AE(&-O;G1E;G0@;V8@=&AE('AM;"!F:6QE("TM/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<R!S
M96QE8W0](B\J+V]F9FEC93IB;V1Y(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$
M871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H*("`@("`@("`@("`@("`@
M(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"@H@("`@
M("`@("`@("`\(2TM*RLK*RL@2%1-3"`T+C`@24Y,24Y)3D<@("LK*RLK+2T^
M"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=#
M4U-?24Y,24Y%1"<B/@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA
M;64](FAT;6PB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N
M86UE/2)H96%D(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64])V-O;6UO;BUH96%D97(M<')O<&5R=&EE<R<O/@H@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8F%C:V=R;W5N9$EM86=E
M55),(B!S96QE8W0](B1O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R]S='EL93IP
M86=E+6UA<W1E<B]S='EL93IP<F]P97)T:65S+W-T>6QE.F)A8VMG<F]U;F0M
M:6UA9V4O0'AL:6YK.FAR968B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.F5L96UE;G0@;F%M93TB8F]D>2(^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#PA+2T@8F%C:V=R;W5N9"!I;6%G92`M+3X*("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#II9B!T97-T/2(D8F%C:V=R;W5N9$EM86=E55),(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64]
M(F)A8VMG<F]U;F0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\(2TM(&9O<B!I;6%G97,@:F%R960@:6X@;W!E;B!O9F9I8V4@9&]C
M=6UE;G0@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D8F%C:V=R;W5N9$EM86=E55),
M+"`G(U!I8W1U<F5S+R<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PA+2T@8W)E871I;F<@86X@86)S;VQU=&4@:'1T<"!5
M4DP@=&\@=&AE(&-O;G1A:6YE9"]P86-K960@:6UA9V4@9FEL92`M+3X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2)C;VYC870H)&IA<F5D4F]O=%523"P@)R]0:6-T=7)E
M<R\G+"!S=6)S=')I;F<M869T97(H)&)A8VMG<F]U;F1);6%G95523"P@)R-0
M:6-T=7)E<R\G*2P@)&]P=&EO;F%L55),4W5F9FEX*2(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M871T<FEB=71E(&YA;64](G-R8R(^/'AS;#IV86QU92UO9B!S96QE8W0](B1B
M86-K9W)O=6YD26UA9V554DPB+SX\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<R!S96QE8W0](B\J
M+V]F9FEC93IB;V1Y(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE
M8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@/"]X<VPZ96QE
M;65N=#X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@(#PA
M+2TK*RLK*R!004Q-+59)22`H,RXR($A434P@4U5"4T54*2`@*RLK*RLM+3X*
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1O=71P=714>7!E(#T@)U!!
M3$TG(CX*("`@("`@("`@("`@("`@(#PA+2T@=&AE('!R;WAY('=I;&P@8V]N
M=F5R="!T:&4@:'1M;"!F:6QE(&QA=&5R('1O(%!102`M+3X*("`@("`@("`@
M("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)H=&UL(CX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB:&5A9"(^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2=P86QM+6AE
M861E<BUP<F]P97)T:65S)R\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M96QE;65N=#X*"B`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA
M;64](F)O9'DB/@H@("`@("`@("`@("`@("`@("`@("`@("`\(2TM('!R;V-E
M<W-I;F<@=&AE(&-O;G1E;G0@;V8@=&AE('AM;"!F:6QE("TM/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<R!S96QE8W0]
M(B\J+V]F9FEC93IB;V1Y(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S
M96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@/"]X<VPZ
M96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`\+WAS
M;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*("`@(#PA+2T@*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM
M/@H@("`@/"$M+2`J*BH@2&5A9&5R(&9O<B!#4U-?24Y,24Y%1"!A;F0@0U-3
M7TA%041%4B`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"B`@("`\>'-L.G1E;7!L
M871E(&YA;64])V-O;6UO;BUH96%D97(M<')O<&5R=&EE<R<^"B`@("`@("`@
M/'AS;#IA<'!L>2UT96UP;&%T97,@<V5L96-T/2(D;V9F:6-E.FUE=&$M9FEL
M92\J+V]F9FEC93IM971A+V1C.G1I=&QE(B\^"B`@("`@("`@/'AS;#IA<'!L
M>2UT96UP;&%T97,@<V5L96-T/2(D;V9F:6-E.FUE=&$M9FEL92\J+V]F9FEC
M93IM971A+V1C.F1E<V-R:7!T:6]N(B\^"CPA+2TR1$\@861D(&9U<G1H97(@
M:&5A9&5R(&5L96UE;G1S+BX*("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E
M<R!S96QE8W0](B1O9F9I8V4Z;65T82UF:6QE+RHO;V9F:6-E.FUE=&$O9&,Z
M<W5B:F5C="(O/@H@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S('-E;&5C
M=#TB)&]F9FEC93IM971A+69I;&4O*B]O9F9I8V4Z;65T82]M971A.FME>7=O
M<F1S6W!O<W1I=&EO;B@I/3%=(B\^+2T^"B`@("`\+WAS;#IT96UP;&%T93X*
M"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2)D8SIT:71L92(^"B`@("`@("`@
M/'AS;#IE;&5M96YT(&YA;64](G1I=&QE(CX*("`@("`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](BXB+SX*("`@("`@("`\+WAS;#IE;&5M96YT/@H@
M("`@/"]X<VPZ=&5M<&QA=&4^"@H@("`@/'AS;#IT96UP;&%T92!M871C:#TB
M9&,Z9&5S8W)I<'1I;VXB/@H@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)M
M971A(CX*("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB;F%M92(^
M"B`@("`@("`@("`@("`@("`\>'-L.G1E>'0^9&5S8W)I<'1I;VX\+WAS;#IT
M97AT/@H@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@
M(#QX<VPZ871T<FEB=71E(&YA;64](F-O;G1E;G0B/@H@("`@("`@("`@("`@
M("`@/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX*("`@("`@("`@("`@/"]X
M<VPZ871T<FEB=71E/@H@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`\+WAS
M;#IT96UP;&%T93X*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!-96%S
M=7)I;F<@=&AE('1I;64@9F]R('-T>6QE(&-R96%T:6YG("HJ*B`M+3X*("`@
M(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ("TM/@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64](F1E8G5G+7-T
M>6QE+6-O;&QE8W1I;F<M=&EM92(^"@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@
M;F%M93TB<W1A<G14:6UE+5)41B(^"B`@("`@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V
M86EL86)L92@G<WES=&5M.F-U<G)E;G0M=&EM92UM:6QL:7,G*2(^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-Y<W1E;3IC
M=7)R96YT+71I;64M;6EL;&ES*"DB+SX*("`@("`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I
M;VXM879A:6QA8FQE*"=J879A.FIA=F$N;&%N9RY3>7-T96TN8W5R<F5N=%1I
M;65-:6QL:7,G*2(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](FIA=F$Z:F%V82YL86YG+E-Y<W1E;2YC=7)R96YT5&EM94UI
M;&QI<R@I(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@/"]X<VPZ=F%R:6%B;&4^"@H*
M"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)C;VQL96-T961';&]B86Q$
M871A+5)41B(^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE
M/2=C<F5A=&4M86QL+6EN;&EN92US='EL97,G+SX*("`@("`@("`\+WAS;#IV
M87)I86)L93X*"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=X=#IN;V1E+7-E
M="<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93Y#<F5A=&EN9R!T
M:&4@:6YL:6YE('-T>6QE<RXN+BX\+WAS;#IM97-S86=E/@H@("`@("`@("`@
M("`@("`@/'AS;#IV87)I86)L92!N86UE/2)S=&%R=%1I;64B("`@("`@("`@
M("`@("!S96QE8W0](FYU;6)E<BAX=#IN;V1E+7-E="@D<W1A<G14:6UE+5)4
M1BDI(B\^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F-O
M;&QE8W1E9$=L;V)A;$1A=&$B("`@('-E;&5C=#TB>'0Z;F]D92US970H)&-O
M;&QE8W1E9$=L;V)A;$1A=&$M4E1&*2(O/@H@("`@("`@("`@("`@("`@/'AS
M;#IV87)I86)L92!N86UE/2)E;F14:6UE(B`@("`@("`@("`@("`@("!S96QE
M8W0](G-Y<W1E;3IC=7)R96YT+71I;64M;6EL;&ES*"DB+SX*"B`@("`@("`@
M("`@("`@("`\>'-L.FUE<W-A9V4^5&EM92!F;W(@:6YS=&%N=&EA=&EN9R!S
M='EL92!V87)I86)L93H@/'AS;#IV86QU92UO9B!S96QE8W0](B@D96YD5&EM
M92`M("1S=&%R=%1I;64I(B\^(&US/"]X<VPZ;65S<V%G93X*("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)S=&%R="(^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*
M("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F
M=6YC=&EO;BUA=F%I;&%B;&4H)WAA;&%N.FYO9&5S970G*2(^"B`@("`@("`@
M("`@("`@("`\>'-L.FUE<W-A9V4^0W)E871I;F<@=&AE(&EN;&EN92!S='EL
M97,N+BXN/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@(#QX<VPZ=F%R
M:6%B;&4@;F%M93TB<W1A<G14:6UE(B`@("`@("`@("`@("`@<V5L96-T/2)N
M=6UB97(H>&%L86XZ;F]D97-E="@D<W1A<G14:6UE+5)41BDI(B\^"B`@("`@
M("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F5N9%1I;64B("`@("`@
M("`@("`@("`@('-E;&5C=#TB:F%V83IJ879A+FQA;F<N4WES=&5M+F-U<G)E
M;G14:6UE36EL;&ES*"DB+SX*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B
M;&4@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@("`@<V5L96-T/2)X86QA
M;CIN;V1E<V5T*"1C;VQL96-T961';&]B86Q$871A+5)41BDB+SX*"B`@("`@
M("`@("`@("`@("`\>'-L.FUE<W-A9V4^5&EM92!F;W(@:6YS=&%N=&EA=&EN
M9R!S='EL92!V87)I86)L93H@/'AS;#IV86QU92UO9B!S96QE8W0](B@D96YD
M5&EM92`M("1S=&%R=%1I;64I(B\^(&US/"]X<VPZ;65S<V%G93X*("`@("`@
M("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)S=&%R="(^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE
M8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B
M+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H*("`@
M(#PO>'-L.G1E;7!L871E/@H*("`@(#PA+2T@1$5"54<@<'5R<&]S92!O;FQY
M.B!C:&5C:VEN9R!T:&4@<&%R86UE=&5R<R!O9B!T:&ES('1E;7!L871E+2T^
M"B`@("`\>'-L.G1E;7!L871E(&YA;64](F-H96-K+7!A<F%M971E<B(^"B`@
M("`@("`@/'AS;#IM97-S86=E/E!A<F%M971E<B!D<&DZ(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2(D9'!I(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`\>'-L
M.FUE<W-A9V4^4&%R86UE=&5R(&UE=&%&:6QE55),.B`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB)&UE=&%&:6QE55),(B\^/"]X<VPZ;65S<V%G93X*("`@("`@
M("`\>'-L.FUE<W-A9V4^4&%R86UE=&5R('-T>6QE<T9I;&554DPZ(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2(D<W1Y;&5S1FEL95523"(O/CPO>'-L.FUE<W-A
M9V4^"B`@("`@("`@/'AS;#IM97-S86=E/E!A<F%M971E<B!A8G-O;'5T95-O
M=7)C941I<E)E9CH@/'AS;#IV86QU92UO9B!S96QE8W0](B1A8G-O;'5T95-O
M=7)C941I<E)E9B(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@/'AS;#IM97-S
M86=E/E!A<F%M971E<B!P<F5C961I;F=#:&%P=&5R3&5V96PQ(#H@/'AS;#IV
M86QU92UO9B!S96QE8W0](B1P<F5C961I;F=#:&%P=&5R3&5V96PQ(B\^/"]X
M<VPZ;65S<V%G93X*("`@("`@("`\>'-L.FUE<W-A9V4^4&%R86UE=&5R('!R
M96-E9&EN9T-H87!T97),979E;#(@.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M)'!R96-E9&EN9T-H87!T97),979E;#(B+SX\+WAS;#IM97-S86=E/@H@("`@
M("`@(#QX<VPZ;65S<V%G93Y087)A;65T97(@<')E8V5D:6YG0VAA<'1E<DQE
M=F5L,R`Z(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D<')E8V5D:6YG0VAA<'1E
M<DQE=F5L,R(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@/'AS;#IM97-S86=E
M/E!A<F%M971E<B!P<F5C961I;F=#:&%P=&5R3&5V96PT(#H@/'AS;#IV86QU
M92UO9B!S96QE8W0](B1P<F5C961I;F=#:&%P=&5R3&5V96PT(B\^/"]X<VPZ
M;65S<V%G93X*("`@("`@("`\>'-L.FUE<W-A9V4^4&%R86UE=&5R('!R96-E
M9&EN9T-H87!T97),979E;#4@.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'!R
M96-E9&EN9T-H87!T97),979E;#4B+SX\+WAS;#IM97-S86=E/@H@("`@("`@
M(#QX<VPZ;65S<V%G93Y087)A;65T97(@<')E8V5D:6YG0VAA<'1E<DQE=F5L
M-B`Z(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D<')E8V5D:6YG0VAA<'1E<DQE
M=F5L-B(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@/'AS;#IM97-S86=E/E!A
M<F%M971E<B!P<F5C961I;F=#:&%P=&5R3&5V96PW(#H@/'AS;#IV86QU92UO
M9B!S96QE8W0](B1P<F5C961I;F=#:&%P=&5R3&5V96PW(B\^/"]X<VPZ;65S
M<V%G93X*("`@("`@("`\>'-L.FUE<W-A9V4^4&%R86UE=&5R('!R96-E9&EN
M9T-H87!T97),979E;#@@.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'!R96-E
M9&EN9T-H87!T97),979E;#@B+SX\+WAS;#IM97-S86=E/@H@("`@("`@(#QX
M<VPZ;65S<V%G93Y087)A;65T97(@<')E8V5D:6YG0VAA<'1E<DQE=F5L.2`Z
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D<')E8V5D:6YG0VAA<'1E<DQE=F5L
M.2(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@/'AS;#IM97-S86=E/E!A<F%M
M971E<B!P<F5C961I;F=#:&%P=&5R3&5V96PQ,#H@/'AS;#IV86QU92UO9B!S
M96QE8W0](B1P<F5C961I;F=#:&%P=&5R3&5V96PQ,"(O/CPO>'-L.FUE<W-A
M9V4^"B`@("`\+WAS;#IT96UP;&%T93X*"CPO>'-L.G-T>6QE<VAE970^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V]O;R]P86QM+GAS;```
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T,34S-P`Q,#4Q-30S,S<T-P`P,C,W
M-#<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/"$M+0H*("`@5&AE($-O;G1E;G1S(&]F('1H:7,@9FEL92!A<F4@;6%D92!A
M=F%I;&%B;&4@<W5B:F5C="!T;R!T:&4@=&5R;7,@;V8*("`@96ET:&5R(&]F
M('1H92!F;VQL;W=I;F<@;&EC96YS97,*"B`@("`@("`@("`M($=.52!,97-S
M97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!697)S:6]N(#(N,0H@("`@("`@
M("`@+2!3=6X@26YD=7-T<GD@4W1A;F1A<F1S(%-O=7)C92!,:6-E;G-E(%9E
M<G-I;VX@,2XQ"@H@("!3=6X@36EC<F]S>7-T96US($EN8RXL($]C=&]B97(L
M(#(P,#`*"B`@($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!6
M97)S:6]N(#(N,0H@("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T*("`@0V]P>7)I9VAT(#(P,#`@8GD@4W5N($UI8W)O
M<WES=&5M<RP@26YC+@H@("`Y,#$@4V%N($%N=&]N:6\@4F]A9"P@4&%L;R!!
M;'1O+"!#02`Y-#,P,RP@55-!"@H@("!4:&ES(&QI8G)A<GD@:7,@9G)E92!S
M;V9T=V%R93L@>6]U(&-A;B!R961I<W1R:6)U=&4@:70@86YD+V]R"B`@(&UO
M9&EF>2!I="!U;F1E<B!T:&4@=&5R;7,@;V8@=&AE($=.52!,97-S97(@1V5N
M97)A;"!0=6)L:6,*("`@3&EC96YS92!V97)S:6]N(#(N,2P@87,@<'5B;&ES
M:&5D(&)Y('1H92!&<F5E(%-O9G1W87)E($9O=6YD871I;VXN"@H@("!4:&ES
M(&QI8G)A<GD@:7,@9&ES=')I8G5T960@:6X@=&AE(&AO<&4@=&AA="!I="!W
M:6QL(&)E('5S969U;"P*("`@8G5T(%=)5$A/550@04Y9(%=!4E)!3E19.R!W
M:71H;W5T(&5V96X@=&AE(&EM<&QI960@=V%R<F%N='D@;V8*("`@34520TA!
M3E1!0DE,2519(&]R($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%
M+B`@4V5E('1H92!'3E4*("`@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N
M<V4@9F]R(&UO<F4@9&5T86EL<RX*"B`@(%EO=2!S:&]U;&0@:&%V92!R96-E
M:79E9"!A(&-O<'D@;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*
M("`@3&EC96YS92!A;&]N9R!W:71H('1H:7,@;&EB<F%R>3L@:68@;F]T+"!W
M<FET92!T;R!T:&4@1G)E92!3;V9T=V%R90H@("!&;W5N9&%T:6]N+"!);F,N
M+"`U.2!496UP;&4@4&QA8V4L(%-U:71E(#,S,"P@0F]S=&]N+`H@("!-02`@
M,#(Q,3$M,3,P-R`@55-!"@H*("`@4W5N($EN9'5S=')Y(%-T86YD87)D<R!3
M;W5R8V4@3&EC96YS92!697)S:6]N(#$N,0H@("`]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@(%1H92!C;VYT
M96YT<R!O9B!T:&ES(&9I;&4@87)E('-U8FIE8W0@=&\@=&AE(%-U;B!);F1U
M<W1R>2!3=&%N9&%R9',*("`@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$@
M*'1H92`B3&EC96YS92(I.R!9;W4@;6%Y(&YO="!U<V4@=&AI<R!F:6QE"B`@
M(&5X8V5P="!I;B!C;VUP;&EA;F-E('=I=&@@=&AE($QI8V5N<V4N(%EO=2!M
M87D@;V)T86EN(&$@8V]P>2!O9B!T:&4*("`@3&EC96YS92!A="!H='1P.B\O
M=W=W+F]P96YO9F9I8V4N;W)G+VQI8V5N<V4N:'1M;"X*"B`@(%-O9G1W87)E
M('!R;W9I9&5D('5N9&5R('1H:7,@3&EC96YS92!I<R!P<F]V:61E9"!O;B!A
M;B`B05,@25,B(&)A<VES+`H@("!7251(3U54(%=!4E)!3E19($]&($%.62!+
M24Y$+"!%251(15(@15A04D534R!/4B!)35!,245$+"!)3D-,541)3D<L"B`@
M(%=)5$A/550@3$E-251!5$E/3BP@5T%24D%.5$E%4R!42$%4(%1(12!33T94
M5T%212!)4R!&4D5%($]&($1%1D5#5%,L"B`@($U%4D-(04Y404),12P@1DE4
M($9/4B!!(%!!4E1)0U5,05(@4%524$]312P@3U(@3D].+4E.1E))3D=)3D<N
M"B`@(%-E92!T:&4@3&EC96YS92!F;W(@=&AE('-P96-I9FEC('!R;W9I<VEO
M;G,@9V]V97)N:6YG('EO=7(@<FEG:'1S(&%N9`H@("!O8FQI9V%T:6]N<R!C
M;VYC97)N:6YG('1H92!3;V9T=V%R92X*"B`@(%1H92!);FET:6%L($1E=F5L
M;W!E<B!O9B!T:&4@3W)I9VEN86P@0V]D92!I<SH@4W5N($UI8W)O<WES=&5M
M<RP@26YC+@H*("`@0V]P>7)I9VAT(,*I(#(P,#(@8GD@4W5N($UI8W)O<WES
M=&5M<RP@26YC+@H*("`@06QL(%)I9VAT<R!297-E<G9E9"X*"B`@($-O;G1R
M:6)U=&]R*',I.B!?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U\*"BTM/@H\>'-L.G-T>6QE<VAE970@=F5R<VEO;CTB,2XP(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z>'-L/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY
M+UA33"]4<F%N<V9O<FTB"B`@("`@("`@("`@("`@("!X;6QN<SIO9F9I8V4]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V]F9FEC92(*("`@("`@("`@
M("`@("`@('AM;&YS.G-T>6QE/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P
M,"]S='EL92(*("`@("`@("`@("`@("`@('AM;&YS.G1E>'0](FAT='`Z+R]O
M<&5N;V9F:6-E+F]R9R\R,#`P+W1E>'0B"B`@("`@("`@("`@("`@("!X;6QN
M<SIT86)L93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O=&%B;&4B"B`@
M("`@("`@("`@("`@("!X;6QN<SID<F%W/2)H='1P.B\O;W!E;F]F9FEC92YO
M<F<O,C`P,"]D<F%W:6YG(@H@("`@("`@("`@("`@("`@>&UL;G,Z9F\](FAT
M='`Z+R]W=W<N=S,N;W)G+S$Y.3DO6%-,+T9O<FUA="(*("`@("`@("`@("`@
M("`@('AM;&YS.GAL:6YK/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+WAL:6YK
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z;G5M8F5R/2)H='1P.B\O;W!E;F]F
M9FEC92YO<F<O,C`P,"]D871A<W1Y;&4B"B`@("`@("`@("`@("`@("!X;6QN
M<SIS=F<](FAT='`Z+R]W=W<N=S,N;W)G+S(P,#`O<W9G(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z8VAA<G0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P
M+V-H87)T(@H@("`@("`@("`@("`@("`@>&UL;G,Z9'(S9#TB:'1T<#HO+V]P
M96YO9F9I8V4N;W)G+S(P,#`O9'(S9"(*("`@("`@("`@("`@("`@('AM;&YS
M.FUA=&@](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3@O36%T:"]-871H34PB"B`@
M("`@("`@("`@("`@("!X;6QN<SIF;W)M/2)H='1P.B\O;W!E;F]F9FEC92YO
M<F<O,C`P,"]F;W)M(@H@("`@("`@("`@("`@("`@>&UL;G,Z<V-R:7!T/2)H
M='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]S8W)I<'0B"B`@("`@("`@("`@
M("`@("!O9F9I8V4Z8VQA<W,](G1E>'0B"B`@("`@("`@("`@("`@("!O9F9I
M8V4Z=F5R<VEO;CTB,2XP(@H@("`@("`@("`@("`@("`@>&UL;G,Z9&,](FAT
M='`Z+R]P=7)L+F]R9R]D8R]E;&5M96YT<R\Q+C$O(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z;65T83TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O;65T
M82(*("`@("`@("`@("`@("`@('AM;&YS.F-O;F9I9STB:'1T<#HO+V]P96YO
M9F9I8V4N;W)G+S(P,#$O8V]N9FEG(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M:&5L<#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O:&5L<"(*("`@("`@
M("`@("`@("`@('AM;&YS.GAT/2)H='1P.B\O=W=W+FIC;&%R:RYC;VTO>'0B
M"B`@("`@("`@("`@("`@("!X;6QN<SIS>7-T96T](FAT='`Z+R]W=W<N:F-L
M87)K+F-O;2]X="]J879A+VIA=F$N;&%N9RY3>7-T96TB"B`@("`@("`@("`@
M("`@("!X;6QN<SIX86QA;CTB:'1T<#HO+WAM;"YA<&%C:&4N;W)G+WAA;&%N
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z:F%V83TB:'1T<#HO+WAM;"YA<&%C
M:&4N;W)G+WAS;'0O:F%V82(*("`@("`@("`@("`@("`@(&5X8VQU9&4M<F5S
M=6QT+7!R969I>&5S/2)J879A(CX*"B`@("`\>'-L.F]U='!U="!C9&%T82US
M96-T:6]N+65L96UE;G1S/2)M971A(B\^"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ('-P96-I9FEC
M('!A;&T@:&5A9&5R("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*B`M+3X*"B`@("`\>'-L.G1E;7!L871E(&YA;64])W!A
M;&TM:&5A9&5R+7!R;W!E<G1I97,G/@H@("`@("`@(#QX<VPZ96QE;65N="!N
M86UE/2)M971A(CX*("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB
M;F%M92(^4&%L;4-O;7!U=&EN9U!L871F;W)M/"]X<VPZ871T<FEB=71E/@H@
M("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)C;VYT96YT(CYT<G5E
M/"]X<VPZ871T<FEB=71E/@H@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@
M("`@/'AS;#IE;&5M96YT(&YA;64](FUE=&$B/@H@("`@("`@("`@("`\>'-L
M.F%T=')I8G5T92!N86UE/2)N86UE(CY(86YD:&5L9$9R:65N9&QY/"]X<VPZ
M871T<FEB=71E/@H@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)C
M;VYT96YT(CYT<G5E/"]X<VPZ871T<FEB=71E/@H@("`@("`@(#PO>'-L.F5L
M96UE;G0^"B`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](FUE=&$B/@H@("`@
M("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)N86UE(CY(:7-T;W)Y3&ES
M=%1E>'0\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@(#QX<VPZ871T<FEB
M=71E(&YA;64](F-O;G1E;G0B/D1A=&5I;6%N86=E<B8C,3`[.B`F86UP.V1A
M=&4@)F%M<#MT:6UE/"]X<VPZ871T<FEB=71E/@H@("`@("`@(#PO>'-L.F5L
M96UE;G0^"B`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](FUE=&$B/@H@("`@
M("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)N86UE(CYD97-C<FEP=&EO
M;CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@
M;F%M93TB8V]N=&5N="(^4W1A<E!O<G1A;#PO>'-L.F%T=')I8G5T93X*("`@
M("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@(#QX<VPZ96QE;65N="!N86UE
M/2)M971A(CX*("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB;F%M
M92(^:V5Y=V]R9',\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@(#QX<VPZ
M871T<FEB=71E(&YA;64](F-O;G1E;G0B/G-T87)P;W)T86PL('-T87)O9F9I
M8V4L('-O9G1W87)E/"]X<VPZ871T<FEB=71E/@H@("`@("`@(#PO>'-L.F5L
M96UE;G0^"B`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](FUE=&$B/@H@("`@
M("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)H='1P+65Q=6EV(CY#;VYT
M96YT+51Y<&4\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@(#QX<VPZ871T
M<FEB=71E(&YA;64](F-O;G1E;G0B/G1E>'0O:'1M;#L@8VAA<G-E=#UI<V\M
M.#@U.2TQ/"]X<VPZ871T<FEB=71E/@H@("`@("`@(#PO>'-L.F5L96UE;G0^
M"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!C<F5A=&EN
M9R!T86)L92!A='1R:6)U=&5S("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*("`@(#PA+2T@=&%B;&4@
M9&%T82`H=&0I(&%N9"!T86)L92!H96%D97(@*'1H*2!A='1R:6)U=&5S("TM
M/@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)C<F5A=&4M871T<FEB=71E+4%,
M24=.(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G-T>6QE4')O<&5R=&EE
M<R(O/@H*("`@("`@("`\>'-L.FEF('1E<W0](F-O;G1A:6YS*"1S='EL95!R
M;W!E<G1I97,L("=A;&EG;B<I(CX*("`@("`@("`@("`@/'AS;#IA='1R:6)U
M=&4@;F%M93TB86QI9VXB/@H@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN
M<R@D<W1Y;&50<F]P97)T:65S+"`G86QI9VXZ;&5F="<I(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IT97AT/FQE9G0\+WAS;#IT97AT/@H@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1S='EL95!R;W!E<G1I97,L
M("=A;&EG;CIR:6=H="<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IT97AT/G)I9VAT/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^8V5N=&5R/"]X
M<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^
M"B`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`\
M+WAS;#IA='1R:6)U=&4^"B`@("`@("`@/"]X<VPZ:68^"B`@("`\+WAS;#IT
M96UP;&%T93X*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!C<F5A=&EN9R!,:7-T(&%T=')I
M8G5T97,@("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ("TM/@H\(2TM"B`@("`\>'-L.G1E;7!L871E(&YA;64]
M(F-R96%T92UL:7-T+6%T=')I8G5T97,B/@H@("`@("`@(#QX<VPZ<&%R86T@
M;F%M93TB<W1Y;&50<F]P97)T:65S(B\^"@H*(2$A(2$A(2$A(2$A(2$A(2$A
M(2$A(2$A(2$A(2$*,B!B92!I;7!L96UE;G1E9`HA(2$A(2$A(2$A(2$A(2$A
M(2$A(2$A(2$A(2$A(0H*"B`@("`\+WAS;#IT96UP;&%T93X*+2T^"@H@("`@
M/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!C<F5A=&EN9R!N97-T960@9F]R
M;6%T('1A9W,@*%!!3$T@)B!734PI("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM
M/@H*("`@(#PA+2T@271A;&EC("TM/@H@("`@/'AS;#IT96UP;&%T92!N86UE
M/2)C<F5A=&4M;F5S=&5D+69O<FUA="UT86=S(CX*("`@("`@("`\>'-L.G!A
M<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](G-T>6QE4')O<&5R=&EE<R(O/@H@("`@("`@(#QX<VPZ
M8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H
M)'-T>6QE4')O<&5R=&EE<RP@)VET86QI8R<I(CX*("`@("`@("`@("`@("`@
M(#QX<VPZ96QE;65N="!N86UE/2)I(CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8F]L9"(^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL95!R;W!E<G1I
M97,B('-E;&5C=#TB)'-T>6QE4')O<&5R=&EE<R(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@
M("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@
M(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)B;VQD(CX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&50<F]P97)T:65S
M(B!S96QE8W0](B1S='EL95!R;W!E<G1I97,B+SX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T
M82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ
M;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E
M;7!L871E/@H*"B`@("`\(2TM($)O;&0@+2T^"B`@("`\>'-L.G1E;7!L871E
M(&YA;64](F)O;&0B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<W1Y
M;&50<F]P97)T:65S(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'-T>6QE4')O<&5R=&EE
M<RP@)V)O;&0G*2(^"B`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M
M93TB8B(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64](G5N9&5R;&EN92(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)S='EL95!R;W!E<G1I97,B('-E;&5C=#TB
M)'-T>6QE4')O<&5R=&EE<R(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L
M96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS
M;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)U;F1E<FQI;F4B/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL95!R;W!E<G1I97,B('-E;&5C
M=#TB)'-T>6QE4')O<&5R=&EE<R(O/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE
M8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`\
M+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I
M<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^
M"@H*("`@(#PA+2T@56YD97)L:6YE(#H@;&%S="!F;W)M870@871T<FEB=71E
M+"!W:&EC:"!I<R!A;'-O('5S960@9G)O;2!734P@+2!734P@96YD<R!H97)E
M(2`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB=6YD97)L:6YE(CX*("`@
M("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*
M("`@("`@("`\>'-L.G!A<F%M(&YA;64](G-T>6QE4')O<&5R=&EE<R(O/@H*
M("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](B1O=71P=714>7!E(#T@)U!!3$TG(CX*("`@("`@("`@("`@("`@(#QX
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)C;VYT86EN<R@D<W1Y;&50<F]P97)T:65S+"`G=6YD97)L:6YE)RDB/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB=2(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA
M=&4@;F%M93TB<W1R:6ME=&AR;W5G:"(^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE4')O<&5R
M=&EE<R(@<V5L96-T/2(D<W1Y;&50<F]P97)T:65S(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O
M;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A
M=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM
M=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE
M;G0^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G-T<FEK971H<F]U9V@B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](G-T>6QE4')O<&5R=&EE<R(@<V5L96-T/2(D<W1Y;&50<F]P97)T
M:65S(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L
M;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IO=&AE<G=I
M<V4^"B`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'-T>6QE4')O<&5R
M=&EE<RP@)W5N9&5R;&EN92<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IE;&5M96YT(&YA;64](G4B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%P<&QY+71E;7!L
M871E<SX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$
M871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@
M("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*
M("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@
M("`@/"$M+2!S=')I:V5T:')O=6=H("TM/@H@("`@/'AS;#IT96UP;&%T92!N
M86UE/2)S=')I:V5T:')O=6=H(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA
M;64](G-T>6QE4')O<&5R=&EE<R(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1S='EL95!R
M;W!E<G1I97,L("=S=')I:V4G*2(^"B`@("`@("`@("`@("`@("`\>'-L.F5L
M96UE;G0@;F%M93TB<W1R:6ME(CX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.F-A;&PM=&5M<&QA=&4@;F%M93TB86QI9VXB/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&50<F]P97)T:65S
M(B!S96QE8W0](B1S='EL95!R;W!E<G1I97,B+SX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@
M("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB86QI9VXB/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL95!R;W!E<G1I97,B
M('-E;&5C=#TB)'-T>6QE4')O<&5R=&EE<R(O/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A
M(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@
M("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IO
M=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M
M<&QA=&4^"@H*("`@(#PA+2T@06QI9VYM96YT("TM/@H@("`@/'AS;#IT96UP
M;&%T92!N86UE/2)A;&EG;B(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C
M;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE
M/2)S='EL95!R;W!E<G1I97,B+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D<W1Y;&50<F]P
M97)T:65S+"`G86QI9VXG*2(^"B`@("`@("`@("`@("`@("`\>'-L.F5L96UE
M;G0@;F%M93TB9&EV(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I
M8G5T92!N86UE/2)A;&EG;B(^"B`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2)C;VYT86EN<R@D<W1Y;&50<F]P97)T:65S+"`G86QI9VXZ
M;&5F="<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G1E>'0^;&5F=#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1S='EL95!R;W!E<G1I97,L("=A
M;&EG;CIR:6=H="<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G1E>'0^<FEG:'0\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=&5X=#YC96YT97(\+WAS;#IT97AT/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9F]N=%]C;VUB:6YE9"(^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL
M95!R;W!E<G1I97,B('-E;&5C=#TB)'-T>6QE4')O<&5R=&EE<R(O/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T
M82(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^
M"B`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@
M("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)F;VYT7V-O;6)I
M;F5D(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB<W1Y;&50<F]P97)T:65S(B!S96QE8W0](B1S='EL95!R;W!E<G1I97,B
M+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L
M1&%T82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*
M("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H
M;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\(2TM($)O=&@@<VEZ
M92!A;F0@0V]L;W(@9F]R(&9O;G0@+2T^"B`@("`\>'-L.G1E;7!L871E(&YA
M;64](F9O;G1?8V]M8FEN960B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB
M8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M
M93TB<W1Y;&50<F]P97)T:65S(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@
M("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'-T>6QE4')O
M<&5R=&EE<RP@)V-O;&]R)RD@86YD(&-O;G1A:6YS*"1S='EL95!R;W!E<G1I
M97,L("=S:7IE)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA
M;64](F9O;G0B/@H*("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T
M92!N86UE/2)C;VQO<B(^"B`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2)C;VYT86EN<R@D<W1Y;&50<F]P97)T:65S+"`G8V]L;W(Z(S`P
M,#`P,"<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G1E>'0^(S`P,#`P,#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IT97AT/B-&1D9&1D8\+WAS;#IT97AT/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F%T=')I8G5T93X*"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IA='1R:6)U=&4@;F%M93TB<VEZ92(^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I;F<M869T97(H<W5B
M<W1R:6YG+6)E9F]R92@D<W1Y;&50<F]P97)T:65S("PG.G-I>F4G*2P@)W-I
M>F4Z)RDB+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^
M"@H@("`@("`@("`@("`@("`@("`@(#PA+2T@9V5T('1H92!E;6)E9&1E9"!C
M;VYT96YT("TM/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M
M<&QA=&5S/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%P
M<&QY+71E;7!L871E<SX*("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^
M"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H
M97)W:7-E/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA
M;64](F9O;G1?<VEM<&QE(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB<W1Y;&50<F]P97)T:65S(B!S96QE8W0](B1S='EL
M95!R;W!E<G1I97,B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L
M;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L
M;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@
M("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\
M(2TM('-I>F4@;W(@0V]L;W(@9F]R(&9O;G0@+2T^"B`@("`\>'-L.G1E;7!L
M871E(&YA;64](F9O;G1?<VEM<&QE(CX*("`@("`@("`\>'-L.G!A<F%M(&YA
M;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](G-T>6QE4')O<&5R=&EE<R(O/@H*("`@("`@("`\>'-L.F-H;V]S
M93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1S='EL
M95!R;W!E<G1I97,L("=C;VQO<B<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ
M96QE;65N="!N86UE/2)F;VYT(CX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.F%T=')I8G5T92!N86UE/2)C;VQO<B(^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D<W1Y;&50<F]P97)T:65S+"`G
M8V]L;W(Z(S`P,#`P,"<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G1E>'0^(S`P,#`P,#PO>'-L.G1E>'0^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IT97AT/B-&1D9&1D8\+WAS;#IT97AT/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*"B`@("`@("`@("`@("`@
M("`@("`@/"$M+2!G970@=&AE(&5M8F5D9&5D(&-O;G1E;G0@+2T^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T
M961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^
M"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@
M("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@/"]X
M<VPZ=VAE;CX*"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN
M<R@D<W1Y;&50<F]P97)T:65S+"`G<VEZ92<I(CX*("`@("`@("`@("`@("`@
M(#QX<VPZ96QE;65N="!N86UE/2)F;VYT(CX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.F%T=')I8G5T92!N86UE/2)S:7IE(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN9RUA9G1E
M<BAS=6)S=')I;F<M8F5F;W)E*"1S='EL95!R;W!E<G1I97,@+"<Z<VEZ92<I
M+"`G<VEZ93HG*2(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I
M8G5T93X*"B`@("`@("`@("`@("`@("`@("`@/"$M+2!G970@=&AE(&5M8F5D
M9&5D(&-O;G1E;G0@+2T^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IA<'!L
M>2UT96UP;&%T97,^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C
M;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`@("`@/"]X<VPZ96QE
M;65N=#X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@(#QX
M<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/"$M+2!G970@=&AE(&5M
M8F5D9&5D(&-O;G1E;G0@+2T^"B`@("`@("`@("`@("`@("`\>'-L.F%P<&QY
M+71E;7!L871E<SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ87!P;'DM
M=&5M<&QA=&5S/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@
M("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*/"]X<VPZ
M<W1Y;&5S:&5E=#X*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]O;V\O
M<W1Y;&5?:&5A9&5R+GAS;```````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#(S,S8`,3`U,34T
M,S,W-#<`,#(U-#8T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#PA+2T*"B`@(%1H92!#;VYT96YT<R!O9B!T:&ES(&9I;&4@
M87)E(&UA9&4@879A:6QA8FQE('-U8FIE8W0@=&\@=&AE('1E<FUS(&]F"B`@
M(&5I=&AE<B!O9B!T:&4@9F]L;&]W:6YG(&QI8V5N<V5S"@H@("`@("`@("`@
M+2!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO;B`R
M+C$*("`@("`@("`@("T@4W5N($EN9'5S=')Y(%-T86YD87)D<R!3;W5R8V4@
M3&EC96YS92!697)S:6]N(#$N,0H*("`@4W5N($UI8W)O<WES=&5M<R!);F,N
M+"!/8W1O8F5R+"`R,#`P"@H@("!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC
M($QI8V5N<V4@5F5R<VEO;B`R+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@($-O<'ER:6=H="`R,#`P(&)Y
M(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*("`@.3`Q(%-A;B!!;G1O;FEO(%)O
M860L(%!A;&\@06QT;RP@0T$@.30S,#,L(%5300H*("`@5&AI<R!L:6)R87)Y
M(&ES(&9R964@<V]F='=A<F4[('EO=2!C86X@<F5D:7-T<FEB=71E(&ET(&%N
M9"]O<@H@("!M;V1I9GD@:70@=6YD97(@=&AE('1E<FUS(&]F('1H92!'3E4@
M3&5S<V5R($=E;F5R86P@4'5B;&EC"B`@($QI8V5N<V4@=F5R<VEO;B`R+C$L
M(&%S('!U8FQI<VAE9"!B>2!T:&4@1G)E92!3;V9T=V%R92!&;W5N9&%T:6]N
M+@H*("`@5&AI<R!L:6)R87)Y(&ES(&1I<W1R:6)U=&5D(&EN('1H92!H;W!E
M('1H870@:70@=VEL;"!B92!U<V5F=6PL"B`@(&)U="!7251(3U54($%.62!7
M05)204Y463L@=VET:&]U="!E=F5N('1H92!I;7!L:65D('=A<G)A;G1Y(&]F
M"B`@($U%4D-(04Y404))3$E462!O<B!&251.15-3($9/4B!!(%!!4E1)0U5,
M05(@4%524$]312X@(%-E92!T:&4@1TY5"B`@($QE<W-E<B!'96YE<F%L(%!U
M8FQI8R!,:6-E;G-E(&9O<B!M;W)E(&1E=&%I;',N"@H@("!9;W4@<VAO=6QD
M(&AA=F4@<F5C96EV960@82!C;W!Y(&]F('1H92!'3E4@3&5S<V5R($=E;F5R
M86P@4'5B;&EC"B`@($QI8V5N<V4@86QO;F<@=VET:"!T:&ES(&QI8G)A<GD[
M(&EF(&YO="P@=W)I=&4@=&\@=&AE($9R964@4V]F='=A<F4*("`@1F]U;F1A
M=&EO;BP@26YC+BP@-3D@5&5M<&QE(%!L86-E+"!3=6ET92`S,S`L($)O<W1O
M;BP*("`@34$@(#`R,3$Q+3$S,#<@(%5300H*"B`@(%-U;B!);F1U<W1R>2!3
M=&%N9&%R9',@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$*("`@/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@
M("!4:&4@8V]N=&5N=',@;V8@=&AI<R!F:6QE(&%R92!S=6)J96-T('1O('1H
M92!3=6X@26YD=7-T<GD@4W1A;F1A<F1S"B`@(%-O=7)C92!,:6-E;G-E(%9E
M<G-I;VX@,2XQ("AT:&4@(DQI8V5N<V4B*3L@66]U(&UA>2!N;W0@=7-E('1H
M:7,@9FEL90H@("!E>&-E<'0@:6X@8V]M<&QI86YC92!W:71H('1H92!,:6-E
M;G-E+B!9;W4@;6%Y(&]B=&%I;B!A(&-O<'D@;V8@=&AE"B`@($QI8V5N<V4@
M870@:'1T<#HO+W=W=RYO<&5N;V9F:6-E+F]R9R]L:6-E;G-E+FAT;6PN"@H@
M("!3;V9T=V%R92!P<F]V:61E9"!U;F1E<B!T:&ES($QI8V5N<V4@:7,@<')O
M=FED960@;VX@86X@(D%3($E3(B!B87-I<RP*("`@5TE42$]55"!705)204Y4
M62!/1B!!3ED@2TE.1"P@14E42$52($584%)%4U,@3U(@24U03$E%1"P@24Y#
M3%5$24Y'+`H@("!7251(3U54($Q)34E4051)3TXL(%=!4E)!3E1)15,@5$A!
M5"!42$4@4T]&5%=!4D4@25,@1E)%12!/1B!$149%0U13+`H@("!-15)#2$%.
M5$%"3$4L($9)5"!&3U(@02!005)424-53$%2(%!54E!/4T4L($]2($Y/3BU)
M3D9224Y'24Y'+@H@("!3964@=&AE($QI8V5N<V4@9F]R('1H92!S<&5C:69I
M8R!P<F]V:7-I;VYS(&=O=F5R;FEN9R!Y;W5R(')I9VAT<R!A;F0*("`@;V)L
M:6=A=&EO;G,@8V]N8V5R;FEN9R!T:&4@4V]F='=A<F4N"@H@("!4:&4@26YI
M=&EA;"!$979E;&]P97(@;V8@=&AE($]R:6=I;F%L($-O9&4@:7,Z(%-U;B!-
M:6-R;W-Y<W1E;7,L($EN8RX*"B`@($-O<'ER:6=H="#"J2`R,#`R(&)Y(%-U
M;B!-:6-R;W-Y<W1E;7,L($EN8RX*"B`@($%L;"!2:6=H=',@4F5S97)V960N
M"@H@("!#;VYT<FEB=71O<BAS*3H@7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?"@HM+3X*/'AS;#IS='EL97-H965T('9E<G-I;VX]
M(C$N,"(*("`@("`@("`@("`@("`@('AM;&YS.GAS;#TB:'1T<#HO+W=W=RYW
M,RYO<F<O,3DY.2]84TPO5')A;G-F;W)M(@H@("`@("`@("`@("`@("`@>&UL
M;G,Z;V9F:6-E/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]O9F9I8V4B
M"B`@("`@("`@("`@("`@("!X;6QN<SIS='EL93TB:'1T<#HO+V]P96YO9F9I
M8V4N;W)G+S(P,#`O<W1Y;&4B"B`@("`@("`@("`@("`@("!X;6QN<SIT97AT
M/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]T97AT(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z=&%B;&4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P
M+W1A8FQE(@H@("`@("`@("`@("`@("`@>&UL;G,Z9')A=STB:'1T<#HO+V]P
M96YO9F9I8V4N;W)G+S(P,#`O9')A=VEN9R(*("`@("`@("`@("`@("`@('AM
M;&YS.F9O/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+UA33"]&;W)M870B"B`@
M("`@("`@("`@("`@("!X;6QN<SIX;&EN:STB:'1T<#HO+W=W=RYW,RYO<F<O
M,3DY.2]X;&EN:R(*("`@("`@("`@("`@("`@('AM;&YS.FYU;6)E<CTB:'1T
M<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9&%T87-T>6QE(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z<W9G/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`P+W-V9R(*
M("`@("`@("`@("`@("`@('AM;&YS.F-H87)T/2)H='1P.B\O;W!E;F]F9FEC
M92YO<F<O,C`P,"]C:&%R="(*("`@("`@("`@("`@("`@('AM;&YS.F1R,V0]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1R,V0B"B`@("`@("`@("`@
M("`@("!X;6QN<SIM871H/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DX+TUA=&@O
M36%T:$U,(@H@("`@("`@("`@("`@("`@>&UL;G,Z9F]R;3TB:'1T<#HO+V]P
M96YO9F9I8V4N;W)G+S(P,#`O9F]R;2(*("`@("`@("`@("`@("`@('AM;&YS
M.G-C<FEP=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O<V-R:7!T(@H@
M("`@("`@("`@("`@("`@;V9F:6-E.F-L87-S/2)T97AT(@H@("`@("`@("`@
M("`@("`@;V9F:6-E.G9E<G-I;VX](C$N,"(*("`@("`@("`@("`@("`@('AM
M;&YS.F1C/2)H='1P.B\O<'5R;"YO<F<O9&,O96QE;65N=',O,2XQ+R(*("`@
M("`@("`@("`@("`@('AM;&YS.FUE=&$](FAT='`Z+R]O<&5N;V9F:6-E+F]R
M9R\R,#`P+VUE=&$B"B`@("`@("`@("`@("`@("!X;6QN<SIC;VYF:6<](FAT
M='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`Q+V-O;F9I9R(*("`@("`@("`@("`@
M("`@('AM;&YS.FAE;'`](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+VAE
M;'`B"B`@("`@("`@("`@("`@("!X;6QN<SIX=#TB:'1T<#HO+W=W=RYJ8VQA
M<FLN8V]M+WAT(@H@("`@("`@("`@("`@("`@>&UL;G,Z<WES=&5M/2)H='1P
M.B\O=W=W+FIC;&%R:RYC;VTO>'0O:F%V82]J879A+FQA;F<N4WES=&5M(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z>&%L86X](FAT='`Z+R]X;6PN87!A8VAE
M+F]R9R]X86QA;B(*("`@("`@("`@("`@("`@('AM;&YS.FIA=F$](FAT='`Z
M+R]X;6PN87!A8VAE+F]R9R]X<VQT+VIA=F$B"B`@("`@("`@("`@("`@("!E
M>&-L=61E+7)E<W5L="UP<F5F:7AE<STB:F%V82(^"@H*"B`@("`\(2TM("HJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ
M('-T>6QE('-H965T('!R;V-E<W-I;F<@*BHJ("TM/@H@("`@/"$M+2`J*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H*("`@(#QX<VPZ=&5M
M<&QA=&4@;F%M93TG8W)E871E+6-S<RUS='EL96AE861E<B<^"B`@("`@("`@
M/'AS;#IC;VUM96YT/@H@("`@("`@("`@("`\>'-L.G1E>'0^5&AE($-34R!S
M='EL92!H96%D97(@;65T:&]D(&9O<B!S971T:6YG('-T>6QE<SPO>'-L.G1E
M>'0^"B`@("`@("`@/"]X<VPZ8V]M;65N=#X*("`@("`@("`\>'-L.F5L96UE
M;G0@;F%M93TB<W1Y;&4B/@H@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N
M86UE/2)T>7!E(CYT97AT+V-S<SPO>'-L.F%T=')I8G5T93X*("`@("`@("`@
M("`@/'AS;#IC;VUM96YT/@H@("`@("`@("`@("`@("`@/'AS;#IT97AT/@H*
M("`@("`@("`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64](G=R:71E+61E9F%U;'0M<W1Y;&5S(B\^"@H@("`@
M("`@("`@("`@("`@/"$M+2!42$4@4U193$4@4%)/4$525$E%4R!/1B!42$4@
M1DE24U0@5U))5%1%3B!35%E,12`H4$%214Y4*2!)4R!'259%3B!/550@+2T^
M"@H@("`@("`@("`@("`@("`@/"$M+2`Q*2!S='EL97,@9G)O;2!O9F9I8V4Z
M<W1Y;&5S(&%R92!P;W-S:6)L92!P87)E;G0@9G)O;2!A;&P@*&ET<V5L9B!O
M<B!O9F9I8V4Z875T;VUA=&EC+7-T>6QE<RDN"B`@("`@("`@("`@("`@("`@
M("`@(%1H97)E9F]R92!T:&5Y(&%R92!C<F5A=&5D(&9I<G-T+@H@("`@("`@
M("`@("`@("`@("`@("!"96=I;FYI;F<@=VET:"!T:&4@=&]P+6QE=F5L('!A
M<F5N=',@*'1H92!S='EL97,@=VET:&]U="!A;GD@<&%R96YT*2X@+2T^"B`@
M("`@("`@("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB)&]F9FEC93IS
M='EL97,O<W1Y;&4Z<W1Y;&5;;F]T*$!S='EL93IP87)E;G0M<W1Y;&4M;F%M
M92E=(CX*"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64](G=R:71E+7-T>6QE<')O<&5R='DM;&EN92(O/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)W<FET92US='EL
M97!R;W!E<G1Y+6QI;F5S+69O<BUC:&EL9')E;B(O/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ9F]R+65A8V@^"@H@("`@("`@("`@("`@("`@/'AS;#IT97AT
M/B`\+WAS;#IT97AT/@H*("`@("`@("`@("`@("`@(#PA+2T@,BD@<W1Y;&5S
M(&9R;VT@;V9F:6-E.F%U=&]M871I8RUS='EL97,@8V%N(&]N;'D@8F4@<&%R
M96YT(&]F('-T>6QE<R!F<F]M('1H92!O9F9I8V4Z875T;VUA=&EC+7-T>6QE
M<R!S96-T:6]N+@H@("`@("`@("`@("`@("`@("`@("!"96=I;FYI;F<@=VET
M:"!T;W`M;&5V96P@<W1Y;&5S+"!A9V%I;BP@86QL(&-H:6QD<F5N('-T>6QE
M('=I;&P@8F4@<F5C=7)S:79L>2!T<F%V97)S960@+2T^"B`@("`@("`@("`@
M("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB)&]F9FEC93IA=71O;6%T:6,M
M<W1Y;&5S+W-T>6QE.G-T>6QE6VYO="A`<W1Y;&4Z<&%R96YT+7-T>6QE+6YA
M;64I72(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64](G=R:71E+7-T>6QE<')O<&5R='DM;&EN92(^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S96%R8VA/;FQY
M26Y!=71O;6%T:6-3='EL97,B('-E;&5C=#TB=')U92@I(B\^"B`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M<W1Y;&5P
M<F]P97)T>2UL:6YE<RUF;W(M8VAI;&1R96XB/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<V5A<F-H3VYL>4EN075T
M;VUA=&EC4W1Y;&5S(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L
M;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.F9O<BUE86-H/@H@
M("`@("`@("`@("`O+SPO>'-L.F-O;6UE;G0^"B`@("`@("`@/"]X<VPZ96QE
M;65N=#X*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\>'-L.G1E;7!L871E
M(&YA;64])W=R:71E+7-T>6QE<')O<&5R='DM;&EN92<^"B`@("`@("`@/'AS
M;#IP87)A;2!N86UE/2)S96%R8VA/;FQY26Y!=71O;6%T:6-3='EL97,B+SX*
M"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)S='EL95!R;W!E<G1I97,B
M/@H@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M
M<W1Y;&4M<')O<&5R=&EE<R(^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB<W1Y;&5!='1R:6)U=&50871H(B`@('-E;&5C=#TB8W5R
M<F5N="@I+W-T>6QE.G!R;W!E<G1I97,O0"HB+SX*("`@("`@("`@("`@/"]X
M<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`\+WAS;#IV87)I86)L93X*"B`@
M("`@("`@/"$M+2!D;R!N;W0@=W)I=&4@<W1Y;&5S('=I=&@@;F\@8W-S('!R
M;W!E<G1Y("TM/@H@("`@("`@(#QX<VPZ:68@=&5S=#TB;F]T*'-T<FEN9RUL
M96YG=&@H)'-T>6QE4')O<&5R=&EE<RD@/2`P*2(^"B`@("`@("`@("`@(#PA
M+2T@=W)I=&4@;W5T('1H92!N86UE(&]F('1H92!C=7)R96YT("AP87)E;G0I
M('-T>6QE(&EN('1H92!#4U,@:&5A9&5R<V5C=&EO;B`H92YG+B`B<W!A;BYM
M>5-T>6QE(BD@+2T^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)W<FET92US='EL92UN86UE(CX*("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)I<RUP87)E;G0M<W1Y;&4B('-E;&5C=#TB=')U
M92@I(B\^"B`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"@H@("`@
M("`@("`@("`\(2TM('1H92!N86UE<R!O9B!A;&P@<W1Y;&5S(&-H:6QD<F5N
M('=I;&P@8F4@=W)I='1E;B!O=70H;V9F:6-E.G-T>6QE($%.1"!O9F9I8V4Z
M875T;VUA=&EC+7-T>6QE*2`M+3X*("`@("`@("`@("`@/'AS;#IC86QL+71E
M;7!L871E(&YA;64](G=R:71E+6-H:6QD<F5N+7-T>6QE+6YA;65S(CX*("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P87)E;G13='EL
M94YA;64B("`@("`@("`@('-E;&5C=#TB0'-T>6QE.FYA;64B+SX*("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P87)E;G13='EL949A
M;6EL>2(@("`@("`@('-E;&5C=#TB0'-T>6QE.F9A;6EL>2(O/@H@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-E87)C:$]N;'E);D%U
M=&]M871I8U-T>6QE<R(O/@H@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L
M871E/@H*("`@("`@("`\(2TM('1H92!S='EL92!P<F]P97)T:65S(&]F('1H
M92!F:7)S="!W<FET=&5N('-T>6QE("AP87)E;G0I(&ES(&=I=F5N(&]U="`M
M+3X*("`@("`@("`\>'-L.G1E>'0^('L*("`@("`@("`@("`@("`@(#PO>'-L
M.G1E>'0^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M)'-T>6QE4')O<&5R=&EE<R(O/@H@("`@("`@(#QX<VPZ=&5X=#Y]"B`@("`@
M("`@/"]X<VPZ=&5X=#X*"B`@("`@("`@/"]X<VPZ:68^"@H*"B`@("`\+WAS
M;#IT96UP;&%T93X*"@H*"B`@("`\(2TM(%)%0U524TE/3B!7251(($5.1$-/
M3D1)5$]..B!A9&1I;F<@<W1Y;&4@8VQA<W-E<R!F;W(@86QL(&5X:7-T:6YG
M(&-H:6QD<R`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TG=W)I=&4M<W1Y
M;&5P<F]P97)T>2UL:6YE<RUF;W(M8VAI;&1R96XG/@H@("`@("`@(#QX<VPZ
M<&%R86T@;F%M93TB<V5A<F-H3VYL>4EN075T;VUA=&EC4W1Y;&5S(B\^"@H@
M("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB<&%R96YT4W1Y;&5.86UE(B`@
M("!S96QE8W0](D!S='EL93IN86UE(B\^"B`@("`@("`@/'AS;#IV87)I86)L
M92!N86UE/2)P87)E;G13='EL949A;6EL>2(@('-E;&5C=#TB0'-T>6QE.F9A
M;6EL>2(O/@H*("`@("`@("`\>'-L.FEF('1E<W0](FYO="AS96%R8VA/;FQY
M26Y!=71O;6%T:6-3='EL97,I(CX*("`@("`@("`@("`@/'AS;#IF;W(M96%C
M:"!S96QE8W0](BXN+W-T>6QE.G-T>6QE6T!S='EL93IF86UI;'D])'!A<F5N
M=%-T>6QE1F%M:6QY(&%N9"!`<W1Y;&4Z<&%R96YT+7-T>6QE+6YA;64])'!A
M<F5N=%-T>6QE3F%M95TB/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E
M;7!L871E(&YA;64](G=R:71E+7-T>6QE<')O<&5R='DM;&EN92(O/@H@("`@
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+7-T
M>6QE<')O<&5R='DM;&EN97,M9F]R+6-H:6QD<F5N(B\^"B`@("`@("`@("`@
M(#PO>'-L.F9O<BUE86-H/@H@("`@("`@(#PO>'-L.FEF/@H@("`@("`@(#QX
M<VPZ9F]R+65A8V@@<V5L96-T/2(D;V9F:6-E.F%U=&]M871I8RUS='EL97,O
M<W1Y;&4Z<W1Y;&5;0'-T>6QE.F9A;6EL>3TD<&%R96YT4W1Y;&5&86UI;'D@
M86YD($!S='EL93IP87)E;G0M<W1Y;&4M;F%M93TD<&%R96YT4W1Y;&5.86UE
M72(^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)W<FET
M92US='EL97!R;W!E<G1Y+6QI;F4B/@H@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](G-E87)C:$]N;'E);D%U=&]M871I8U-T>6QE<R(O
M/@H@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M<W1Y;&5P<F]P97)T
M>2UL:6YE<RUF;W(M8VAI;&1R96XB/@H@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](G-E87)C:$]N;'E);D%U=&]M871I8U-T>6QE<R(O
M/@H@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@(#PO
M>'-L.F9O<BUE86-H/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#QX<VPZ
M=&5M<&QA=&4@;F%M93TB=W)I=&4M9&5F875L="US='EL97,B/@H*("`@("`@
M("`\(2TM('-O;64@9&5F875L="!A='1R:6)U=&5S(&EN('AM;"!H879E('1O
M(&)E(&5X<&QI8VET;'D@<V5T(&EN($A434P@*&4N9RX@;6%R9VEN+71O<#TB
M,"(I("TM/@H@("`@("`@(#QX<VPZ=&5X=#XJ+D]/;U]D969A=6QT<SPO>'-L
M.G1E>'0^"@H@("`@("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0]
M(B1O9F9I8V4Z<W1Y;&5S+W-T>6QE.G-T>6QE(CX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G1E>'0^+"`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H)RHN)RP@=')A;G-L
M871E*$!S='EL93IN86UE+"`G+B`E*"DO7"<L("<G*2DB+SX*("`@("`@("`@
M("`@("`@(#PO>'-L.F9O<BUE86-H/@H*("`@("`@("`@("`@("`@(#QX<VPZ
M9F]R+65A8V@@<V5L96-T/2(D;V9F:6-E.F%U=&]M871I8RUS='EL97,O<W1Y
M;&4Z<W1Y;&4B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#XL(#PO
M>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](F-O;F-A="@G*BXG+"!T<F%N<VQA=&4H0'-T>6QE.FYA;64L("<N
M("4H*2]<)RP@)R<I*2(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ9F]R+65A
M8V@^"B`@("`@("`@/"$M+2`R1$\Z('1H92!D969A=6QT<R!M:6=H="!B92!B
M971T97(@8V]L;&5C=&5D(&%N9"!W<FET=&5N(&EN(&$@<V5P87)A=&5D("A8
M34PI(&9I;&4@+2T^"CQX<VPZ=&5X=#X@>PH@("`@("`@("`@("`@("`@;6%R
M9VEN+71O<#HP8VT[(&UA<F=I;BUB;W1T;VTZ,&-M.R!]"B`@("`@("`@/"]X
M<VPZ=&5X=#X*"B`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1O9F9I
M8V4Z<W1Y;&5S+W-T>6QE.F1E9F%U;'0M<W1Y;&4B/@H@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M9&5F875L="US='EL92(O
M/@H@("`@("`@(#PO>'-L.F9O<BUE86-H/@H*("`@("`@("`\>'-L.F9O<BUE
M86-H('-E;&5C=#TB)&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S+W-T>6QE.F1E
M9F%U;'0M<W1Y;&4B/@H@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@
M;F%M93TB=W)I=&4M9&5F875L="US='EL92(O/@H@("`@("`@(#PO>'-L.F9O
M<BUE86-H/@H*("`@(#PO>'-L.G1E;7!L871E/@H*"@H@("`@/'AS;#IT96UP
M;&%T92!N86UE/2)W<FET92UD969A=6QT+7-T>6QE(CX*("`@("`@("`\>'-L
M.G9A<FEA8FQE(&YA;64](F9A;6EL>2US='EL92(@<V5L96-T/2)`<W1Y;&4Z
M9F%M:6QY(B\^"@H@("`@("`@(#PA+2T@<V]M92!D969A=6QT(&%T=')I8G5T
M97,@9F]R(&9O<FUA="!F86UI;&EE<R`H92YG+B!G<F%P:&EC<RP@<&%R86=R
M87!H<RP@971C+BD@=W)I='1E;B!A<R!S='EL93ID969A=6QT+7-T>6QE("TM
M/@H@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H)RHN)RP@
M=')A;G-L871E*"1F86UI;'DM<W1Y;&4L("<N("4H*2]<)RP@)R<I+"`G7V1E
M9F%U;'1S)RDB+SX*"B`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1O
M9F9I8V4Z<W1Y;&5S+W-T>6QE.G-T>6QE6T!S='EL93IF86UI;'D@/2`D9F%M
M:6QY+7-T>6QE72(^"B`@("`@("`@("`@(#QX<VPZ=&5X=#XL(#PO>'-L.G1E
M>'0^"B`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H
M)RHN)RP@=')A;G-L871E*$!S='EL93IN86UE+"`G+B`E*"DO7"<L("<G*2DB
M+SX*("`@("`@("`\+WAS;#IF;W(M96%C:#X*"B`@("`@("`@/'AS;#IF;W(M
M96%C:"!S96QE8W0](B1O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R]S='EL93IS
M='EL95M`<W1Y;&4Z9F%M:6QY(#T@)&9A;6EL>2US='EL95TB/@H@("`@("`@
M("`@("`\>'-L.G1E>'0^+"`\+WAS;#IT97AT/@H@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"<J+B<L('1R86YS;&%T92A`<W1Y
M;&4Z;F%M92P@)RX@)2@I+UPG+"`G)RDI(B\^"B`@("`@("`@/"]X<VPZ9F]R
M+65A8V@^"@H*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G-T>6QE4')O
M<&5R=&EE<R(^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE
M/2)W<FET92US='EL92UP<F]P97)T:65S(CX*("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)S='EL94%T=')I8G5T95!A=&@B("`@<V5L
M96-T/2)C=7)R96YT*"DO<W1Y;&4Z<')O<&5R=&EE<R]`*B(O/@H@("`@("`@
M("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@(#PO>'-L.G9A<FEA
M8FQE/@H*("`@("`@("`\(2TM(&1O(&YO="!W<FET92!S='EL97,@=VET:"!N
M;R!C<W,@<')O<&5R='D@+2T^"B`@("`@("`@/'AS;#II9B!T97-T/2)N;W0H
M<W1R:6YG+6QE;F=T:"@D<W1Y;&50<F]P97)T:65S*2`](#`I(CX*("`@("`@
M("`\(2TM('1H92!S='EL92!P<F]P97)T:65S(&]F('1H92!F:7)S="!W<FET
M=&5N('-T>6QE("AP87)E;G0I(&ES(&=I=F5N(&]U="`M+3X*("`@("`@("`\
M>'-L.G1E>'0^('L*("`@("`@("`@("`@("`@(#PO>'-L.G1E>'0^"B`@("`@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'-T>6QE4')O<&5R
M=&EE<R(O/@H@("`@("`@(#QX<VPZ=&5X=#Y]"B`@("`@("`@/"]X<VPZ=&5X
M=#X*("`@("`@("`\+WAS;#II9CX*"B`@("`\+WAS;#IT96UP;&%T93X*"@H@
M("`@/"$M+2LK"B`@("`@("`@("!4:&4@<&%R96YT('-T>6QE('=I;&P@8F4@
M=W)I='1E;B!O=70A"B`@("`@("`@("!&;W(@96%C:"!3='EL93IF86UI;'D@
M82!P<F5F:7@@;75S="!B92!A9&1E9`H@("`@("`@("`@("`\(45.5$E462`E
M('-T>6QE1F%M:6QY"B`@("`@("`@("`@("(H<&%R86=R87!H?'1E>'1\<V5C
M=&EO;GQT86)L97QT86)L92UC;VQU;6Y\=&%B;&4M<F]W?'1A8FQE+6-E;&Q\
M=&%B;&4M<&%G97QC:&%R='QG<F%P:&EC<WQD969A=6QT?&1R87=I;F<M<&%G
M97QP<F5S96YT871I;VY\8V]N=')O;"DB/@H@("`@("`@("LK+2T^"B`@("`\
M>'-L.G1E;7!L871E(&YA;64](G=R:71E+7-T>6QE+6YA;64B/@H@("`@("`@
M(#QX<VPZ<&%R86T@;F%M93TB:7,M<&%R96YT+7-T>6QE(B\^"@H@("`@("`@
M(#PA+2T@5&AI<R!C;VYS=')U8W0@:7,@9F]R(&QI<W0@96QE;65N=',N(%=H
M96YE=F5R(&$@<&%R86=R87!H(&5L96UE;G0@:7,@8F5I;F<@=7-E9"!A<R!C
M:&EL9"!O9B!A(&QI<W0@96QE;65N="!T:&4@;F%M92!P87)A9W)A<&@@<W1Y
M;&4@:7,@8F5E;B!U<V5D(&9O<@H@("`@("`@("`@("!T:&4@;&ES="!I=&5M
M+B!4:&ES(&-A;B!B92!S=VET8VAE9"!A<R!T:&4@<&%R86=A<&@@<W1Y;&4M
M;F%M92!A;F0@=&AE(&QI<W0M<W1Y;&4M;F%M92!A<F4@:6X@=&AE('-A;64@
M96QE;65N="X*("`@("`@("`@("`@3W1H97)W:7-E('1H97)E('=O=6QD(&)E
M(&9O<FUA='1I;F<@97)R;W)S("AE+F<N(&UA<F=I;BUL969T('=I;&P@8F4@
M=7-E9"!F;W(@=&AE(&-O;G1E;G0@:6X@=&AE(&QI<W0@96QM96YT(&%N9"!N
M;W0@9F]R('1H92!L:7-T(&5L96UE;G0@:71S96QF*2X@+2T^"B`@("`@("`@
M/'AS;#IV87)I86)L92!N86UE/2)S='EL92UN86UE(CX*("`@("`@("`@("`@
M/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M0'-T>6QE.FQI<W0M<W1Y;&4M;F%M92(^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IV86QU92UO9B!S96QE8W0](D!S='EL93IL:7-T+7-T>6QE+6YA;64B
M+SX*("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@
M("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB0'-T>6QE.FYA;64B+SX*("`@("`@("`@("`@("`@
M(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@
M("`@("`@(#PO>'-L.G9A<FEA8FQE/@H*("`@("`@("`\>'-L.FEF('1E<W0]
M(FYO="@D:7,M<&%R96YT+7-T>6QE*2(^"B`@("`@("`@("`@(#QX<VPZ=&5X
M=#XL(#PO>'-L.G1E>'0^"B`@("`@("`@/"]X<VPZ:68^"@H@("`@("`@(#QX
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`\(2TM(&YO<FUA;&QY("=P+B<@=V]U
M;&0@8F4@=7-E9"!A<R!#4U,@96QE;65N="P*("`@("`@("`@("`@("`@("!B
M=70@:&5A9&5R("AH,2P@:#(L+BXN*2!A<F4@86QS;R!F<F]M('1H92!S='EL
M93IF86UI;'D@<&%R86=R87!H("TM/@H@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB0'-T>6QE.F9A;6EL>3TG<&%R86=R87!H)R(^"B`@("`@("`@("`@
M("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"<J+B<L('1R86YS
M;&%T92@D<W1Y;&4M;F%M92P@)RX@)2@I+UPG+"`G)RDI(B\^"B`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`
M<W1Y;&4Z9F%M:6QY/2=T97AT)R(^"B`@("`@("`@("`@("`@("`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB8V]N8V%T*"<J+B<L('1R86YS;&%T92@D<W1Y;&4M
M;F%M92P@)RX@)2@I+UPG+"`G)RDI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H
M96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`<W1Y;&4Z9F%M:6QY
M/2=S96-T:6]N)R(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB8V]N8V%T*"<J+B<L('1R86YS;&%T92@D<W1Y;&4M;F%M92P@)RX@
M)2@I+UPG+"`G)RDI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`<W1Y;&4Z9F%M:6QY/2=T86)L92<B
M/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O;F-A
M="@G=&%B;&4N)RP@=')A;G-L871E*"1S='EL92UN86UE+"`G+B`E*"DO7"<L
M("<G*2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](D!S='EL93IF86UI;'D])W1A8FQE+6-O;'5M;B<B
M/@H@("`@("`@("`@("`\(2TM(&%S(&-O;'5M;B!S='EL97,@:&%V92!T;R!B
M92!I;F-L=61E9"!A<R!S<&%N('-T>6QE<R!!1E1%4B!T:&4@=&%B;&4@*&YO
M('1W;R!C;&%S<R!A='1R:6)U=&5S(&EN(%1$(&%L;&]W960@+2T^"B`@("`@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"<J+B<L
M('1R86YS;&%T92@D<W1Y;&4M;F%M92P@)RX@)2@I+UPG+"`G)RDI(B\^"B`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2)`<W1Y;&4Z9F%M:6QY/2=T86)L92UR;W<G(CX*("`@("`@("`@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H)W1R+B<L('1R86YS
M;&%T92@D<W1Y;&4M;F%M92P@)RX@)2@I+UPG+"`G)RDI(B\^"B`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`
M<W1Y;&4Z9F%M:6QY/2=T86)L92UC96QL)R(^"B`@("`@("`@("`@("`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"<J+B<L('1R86YS;&%T92@D
M<W1Y;&4M;F%M92P@)RX@)2@I+UPG+"`G)RDI(B\^"B`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`<W1Y;&4Z
M9F%M:6QY/2=T86)L92UP86=E)R(^"B`@("`@("`@("`@("`@("`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB8V]N8V%T*"<J+B<L('1R86YS;&%T92@D<W1Y;&4M
M;F%M92P@)RX@)2@I+UPG+"`G)RDI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H
M96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`<W1Y;&4Z9F%M:6QY
M/2=C:&%R="<B/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE
M8W0](F-O;F-A="@G*BXG+"!T<F%N<VQA=&4H)'-T>6QE+6YA;64L("<N("4H
M*2]<)RP@)R<I*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB0'-T>6QE.F9A;6EL>3TG9W)A<&AI8W,G
M(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC
M870H)RHN)RP@=')A;G-L871E*"1S='EL92UN86UE+"`G+B`E*"DO7"<L("<G
M*2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](D!S='EL93IF86UI;'D])V1E9F%U;'0G(CX*("`@("`@
M("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H)RHN)RP@
M=')A;G-L871E*"1S='EL92UN86UE+"`G+B`E*"DO7"<L("<G*2DB+SX*("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](D!S='EL93IF86UI;'D])V1R87=I;F<M<&%G92<B/@H@("`@("`@("`@
M("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O;F-A="@G*BXG+"!T<F%N
M<VQA=&4H)'-T>6QE+6YA;64L("<N("4H*2]<)RP@)R<I*2(O/@H@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M0'-T>6QE.F9A;6EL>3TG<')E<V5N=&%T:6]N)R(^"B`@("`@("`@("`@("`@
M("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"<J+B<L('1R86YS;&%T
M92@D<W1Y;&4M;F%M92P@)RX@)2@I+UPG+"`G)RDI(B\^"B`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`<W1Y
M;&4Z9F%M:6QY/2=C;VYT<F]L)R(^"B`@("`@("`@("`@("`@("`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB8V]N8V%T*"<J+B<L('1R86YS;&%T92@D<W1Y;&4M
M;F%M92P@)RX@)2@I+UPG+"`G)RDI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H
M96X^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^
M"@H*("`@(#PA+2T@9FEN9&EN9R!A;&P@<W1Y;&4@8VAI;&0@;V8@82!S96-T
M:6]N(&%N9"!G:79E('1H96ER('-T>6QE261E;G1I9FEE<B!T;R!T:&4@;W5T
M<'5T("TM/@H@("`@/'AS;#IT96UP;&%T92!N86UE/2=W<FET92UC:&EL9')E
M;BUS='EL92UN86UE<R<^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)P87)E
M;G13='EL94YA;64B('-E;&5C=#TB0'-T>6QE.FYA;64B+SX*("`@("`@("`\
M>'-L.G!A<F%M(&YA;64](G!A<F5N=%-T>6QE1F%M:6QY(B!S96QE8W0](D!S
M='EL93IF86UI;'DB+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G-E87)C
M:$]N;'E);D%U=&]M871I8U-T>6QE<R(O/@H*"B`@("`@("`@/"$M+2HJ('1H
M92!N86UE<R!O9B!A;&P@;V9F:6-E.G-T>6QE<R!C:&EL9')E;B!W:6QL(&)E
M('=R:71T96X@;W5T"B`@("`@("`@("`@("HJ("AA(&%U=&]M871I8R!S='EL
M92!C86X@;VYL>2!H879E(&-H:6QD<F5N(&EN('1H92!O9F9I8V4Z875T;VUA
M=&EC+7-T>6QE('-E8W1I;VXI("TM/@H*("`@("`@("`\(2TM(&EF($Y/5"!C
M86QL960@9G)O;2!A(&]F9FEC93IA=71O;6%T:6,M<W1Y;&4@<&%R96YT("TM
M/@H@("`@("`@(#QX<VPZ:68@=&5S=#TB;F]T*'-E87)C:$]N;'E);D%U=&]M
M871I8U-T>6QE<RDB/@H@("`@("`@("`@("`\(2TM(&9O<B!A;&P@8VAI;&1R
M96X@:6X@=&AE(&]F9FEC93IS='EL92!S96-T:6]N("TM/@H@("`@("`@("`@
M("`\>'-L.F9O<BUE86-H('-E;&5C=#TB+BXO<W1Y;&4Z<W1Y;&5;0'-T>6QE
M.F9A;6EL>3TD<&%R96YT4W1Y;&5&86UI;'D@86YD($!S='EL93IP87)E;G0M
M<W1Y;&4M;F%M93TD<&%R96YT4W1Y;&5.86UE72(^"B`@("`@("`@("`@("`@
M("`\(2TM('=R:71E('1H92!S='EL92!N86UE(&EN('1H92!C<W,@:&5A9&5R
M("TM/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M(G=R:71E+7-T>6QE+6YA;64B+SX*"B`@("`@("`@("`@("`@("`\(2TM('-E
M87)C:"!F;W(@8VAI;&0@<W1Y;&5S("TM/@H@("`@("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+6-H:6QD<F5N+7-T>6QE+6YA
M;65S(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB<&%R96YT4W1Y;&5.86UE(B!S96QE8W0](D!S='EL93IN86UE(B\^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!A<F5N
M=%-T>6QE1F%M:6QY(B!S96QE8W0](D!S='EL93IF86UI;'DB+SX*("`@("`@
M("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"@H@("`@("`@("`@("`\
M+WAS;#IF;W(M96%C:#X*("`@("`@("`\+WAS;#II9CX*"B`@("`@("`@/"$M
M+2HJ('1H92!N86UE<R!O9B!A;&P@;V9F:6-E.F%U=&]M871I8RUS='EL97,@
M8VAI;&1R96X@=VEL;"!B92!W<FET=&5N(&]U="`M+3X*"B`@("`@("`@/"$M
M+2!F;W(@86QL(&-H:6QD<F5N(&EN('1H92!O9F9I8V4Z875T;VUA=&EC+7-T
M>6QE('-E8W1I;VX@+2T^"B`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0]
M(B1O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R]S='EL93IS='EL95M`<W1Y;&4Z
M9F%M:6QY/21P87)E;G13='EL949A;6EL>2!A;F0@0'-T>6QE.G!A<F5N="US
M='EL92UN86UE/21P87)E;G13='EL94YA;65=(CX*("`@("`@("`@("`@/"$M
M+2!W<FET92!T:&4@<W1Y;&4@;F%M92!I;B!T:&4@8W-S(&AE861E<B`M+3X*
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+7-T
M>6QE+6YA;64B+SX*"B`@("`@("`@("`@(#PA+2T@<V5A<F-H(&9O<B!C:&EL
M9"!S='EL97,@+2T^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)W<FET92UC:&EL9')E;BUS='EL92UN86UE<R(^"B`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&%R96YT4W1Y;&5.86UE(B!S
M96QE8W0](D!S='EL93IN86UE(B\^"B`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB<&%R96YT4W1Y;&5&86UI;'DB('-E;&5C=#TB0'-T
M>6QE.F9A;6EL>2(O/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](G-E87)C:$]N;'E);D%U=&]M871I8U-T>6QE<R(O/@H@("`@("`@
M("`@("`\+WAS;#IC86QL+71E;7!L871E/@H*("`@("`@("`\+WAS;#IF;W(M
M96%C:#X*("`@(#PO>'-L.G1E;7!L871E/@H*/"]X<VPZ<W1Y;&5S:&5E=#X*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]-24U%+U9I97=E<B]O;V\O<W1Y;&5?:6YL:6YE9"YX<VP`
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P-38S,C,`,3`U,34T,S,W-#<`,#(U-C4W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#PA+2T*"B`@
M(%1H92!#;VYT96YT<R!O9B!T:&ES(&9I;&4@87)E(&UA9&4@879A:6QA8FQE
M('-U8FIE8W0@=&\@=&AE('1E<FUS(&]F"B`@(&5I=&AE<B!O9B!T:&4@9F]L
M;&]W:6YG(&QI8V5N<V5S"@H@("`@("`@("`@+2!'3E4@3&5S<V5R($=E;F5R
M86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO;B`R+C$*("`@("`@("`@("T@4W5N
M($EN9'5S=')Y(%-T86YD87)D<R!3;W5R8V4@3&EC96YS92!697)S:6]N(#$N
M,0H*("`@4W5N($UI8W)O<WES=&5M<R!);F,N+"!/8W1O8F5R+"`R,#`P"@H@
M("!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO;B`R
M+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]"B`@($-O<'ER:6=H="`R,#`P(&)Y(%-U;B!-:6-R;W-Y<W1E;7,L
M($EN8RX*("`@.3`Q(%-A;B!!;G1O;FEO(%)O860L(%!A;&\@06QT;RP@0T$@
M.30S,#,L(%5300H*("`@5&AI<R!L:6)R87)Y(&ES(&9R964@<V]F='=A<F4[
M('EO=2!C86X@<F5D:7-T<FEB=71E(&ET(&%N9"]O<@H@("!M;V1I9GD@:70@
M=6YD97(@=&AE('1E<FUS(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@4'5B
M;&EC"B`@($QI8V5N<V4@=F5R<VEO;B`R+C$L(&%S('!U8FQI<VAE9"!B>2!T
M:&4@1G)E92!3;V9T=V%R92!&;W5N9&%T:6]N+@H*("`@5&AI<R!L:6)R87)Y
M(&ES(&1I<W1R:6)U=&5D(&EN('1H92!H;W!E('1H870@:70@=VEL;"!B92!U
M<V5F=6PL"B`@(&)U="!7251(3U54($%.62!705)204Y463L@=VET:&]U="!E
M=F5N('1H92!I;7!L:65D('=A<G)A;G1Y(&]F"B`@($U%4D-(04Y404))3$E4
M62!O<B!&251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]312X@(%-E92!T
M:&4@1TY5"B`@($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(&9O<B!M
M;W)E(&1E=&%I;',N"@H@("!9;W4@<VAO=6QD(&AA=F4@<F5C96EV960@82!C
M;W!Y(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC"B`@($QI8V5N
M<V4@86QO;F<@=VET:"!T:&ES(&QI8G)A<GD[(&EF(&YO="P@=W)I=&4@=&\@
M=&AE($9R964@4V]F='=A<F4*("`@1F]U;F1A=&EO;BP@26YC+BP@-3D@5&5M
M<&QE(%!L86-E+"!3=6ET92`S,S`L($)O<W1O;BP*("`@34$@(#`R,3$Q+3$S
M,#<@(%5300H*"B`@(%-U;B!);F1U<W1R>2!3=&%N9&%R9',@4V]U<F-E($QI
M8V5N<V4@5F5R<VEO;B`Q+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@("!4:&4@8V]N=&5N=',@;V8@
M=&AI<R!F:6QE(&%R92!S=6)J96-T('1O('1H92!3=6X@26YD=7-T<GD@4W1A
M;F1A<F1S"B`@(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ("AT:&4@(DQI
M8V5N<V4B*3L@66]U(&UA>2!N;W0@=7-E('1H:7,@9FEL90H@("!E>&-E<'0@
M:6X@8V]M<&QI86YC92!W:71H('1H92!,:6-E;G-E+B!9;W4@;6%Y(&]B=&%I
M;B!A(&-O<'D@;V8@=&AE"B`@($QI8V5N<V4@870@:'1T<#HO+W=W=RYO<&5N
M;V9F:6-E+F]R9R]L:6-E;G-E+FAT;6PN"@H@("!3;V9T=V%R92!P<F]V:61E
M9"!U;F1E<B!T:&ES($QI8V5N<V4@:7,@<')O=FED960@;VX@86X@(D%3($E3
M(B!B87-I<RP*("`@5TE42$]55"!705)204Y462!/1B!!3ED@2TE.1"P@14E4
M2$52($584%)%4U,@3U(@24U03$E%1"P@24Y#3%5$24Y'+`H@("!7251(3U54
M($Q)34E4051)3TXL(%=!4E)!3E1)15,@5$A!5"!42$4@4T]&5%=!4D4@25,@
M1E)%12!/1B!$149%0U13+`H@("!-15)#2$%.5$%"3$4L($9)5"!&3U(@02!0
M05)424-53$%2(%!54E!/4T4L($]2($Y/3BU)3D9224Y'24Y'+@H@("!3964@
M=&AE($QI8V5N<V4@9F]R('1H92!S<&5C:69I8R!P<F]V:7-I;VYS(&=O=F5R
M;FEN9R!Y;W5R(')I9VAT<R!A;F0*("`@;V)L:6=A=&EO;G,@8V]N8V5R;FEN
M9R!T:&4@4V]F='=A<F4N"@H@("!4:&4@26YI=&EA;"!$979E;&]P97(@;V8@
M=&AE($]R:6=I;F%L($-O9&4@:7,Z(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*
M"B`@($-O<'ER:6=H="#"J2`R,#`R(&)Y(%-U;B!-:6-R;W-Y<W1E;7,L($EN
M8RX*"B`@($%L;"!2:6=H=',@4F5S97)V960N"@H@("!#;VYT<FEB=71O<BAS
M*3H@7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?"@HM
M+3X*/'AS;#IS='EL97-H965T('9E<G-I;VX](C$N,"(*("`@("`@("`@("`@
M("`@('AM;&YS.GAS;#TB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]84TPO5')A
M;G-F;W)M(@H@("`@("`@("`@("`@("`@>&UL;G,Z;V9F:6-E/2)H='1P.B\O
M;W!E;F]F9FEC92YO<F<O,C`P,"]O9F9I8V4B"B`@("`@("`@("`@("`@("!X
M;6QN<SIS='EL93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O<W1Y;&4B
M"B`@("`@("`@("`@("`@("!X;6QN<SIT97AT/2)H='1P.B\O;W!E;F]F9FEC
M92YO<F<O,C`P,"]T97AT(@H@("`@("`@("`@("`@("`@>&UL;G,Z=&%B;&4]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W1A8FQE(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z9')A=STB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O
M9')A=VEN9R(*("`@("`@("`@("`@("`@('AM;&YS.F9O/2)H='1P.B\O=W=W
M+G<S+F]R9R\Q.3DY+UA33"]&;W)M870B"B`@("`@("`@("`@("`@("!X;6QN
M<SIX;&EN:STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]X;&EN:R(*("`@("`@
M("`@("`@("`@('AM;&YS.FYU;6)E<CTB:'1T<#HO+V]P96YO9F9I8V4N;W)G
M+S(P,#`O9&%T87-T>6QE(@H@("`@("`@("`@("`@("`@>&UL;G,Z<W9G/2)H
M='1P.B\O=W=W+G<S+F]R9R\R,#`P+W-V9R(*("`@("`@("`@("`@("`@('AM
M;&YS.F-H87)T/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]C:&%R="(*
M("`@("`@("`@("`@("`@('AM;&YS.F1R,V0](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`P+V1R,V0B"B`@("`@("`@("`@("`@("!X;6QN<SIM871H/2)H
M='1P.B\O=W=W+G<S+F]R9R\Q.3DX+TUA=&@O36%T:$U,(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z9F]R;3TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O
M9F]R;2(*("`@("`@("`@("`@("`@('AM;&YS.G-C<FEP=#TB:'1T<#HO+V]P
M96YO9F9I8V4N;W)G+S(P,#`O<V-R:7!T(@H@("`@("`@("`@("`@("`@;V9F
M:6-E.F-L87-S/2)T97AT(@H@("`@("`@("`@("`@("`@;V9F:6-E.G9E<G-I
M;VX](C$N,"(*("`@("`@("`@("`@("`@('AM;&YS.F1C/2)H='1P.B\O<'5R
M;"YO<F<O9&,O96QE;65N=',O,2XQ+R(*("`@("`@("`@("`@("`@('AM;&YS
M.FUE=&$](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+VUE=&$B"B`@("`@
M("`@("`@("`@("!X;6QN<SIC;VYF:6<](FAT='`Z+R]O<&5N;V9F:6-E+F]R
M9R\R,#`Q+V-O;F9I9R(*("`@("`@("`@("`@("`@('AM;&YS.FAE;'`](FAT
M='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+VAE;'`B"B`@("`@("`@("`@("`@
M("!X;6QN<SIX=#TB:'1T<#HO+W=W=RYJ8VQA<FLN8V]M+WAT(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z<WES=&5M/2)H='1P.B\O=W=W+FIC;&%R:RYC;VTO
M>'0O:F%V82]J879A+FQA;F<N4WES=&5M(@H@("`@("`@("`@("`@("`@>&UL
M;G,Z>&%L86X](FAT='`Z+R]X;6PN87!A8VAE+F]R9R]X86QA;B(*("`@("`@
M("`@("`@("`@('AM;&YS.FIA=F$](FAT='`Z+R]X;6PN87!A8VAE+F]R9R]X
M<VQT+VIA=F$B"B`@("`@("`@("`@("`@("!E>&-L=61E+7)E<W5L="UP<F5F
M:7AE<STB:F%V82(^"@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ(&AA
M<F0@871T<FEB=71E9"`H:6YL:6YE9"D@<')O<&5R=&EE<R`@*BHJ("TM/@H@
M("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BH@+2T^"@H*("`@(#PA+2T@4D535%))0U1)3TY3.@H@("`@("`@
M("`@("`Q*2`@07,@=&AE('-T>6QE<RUN;V1E+79A<FEA8FQE<R!A<F4@3D]4
M(&=L;V)A;"P@=&AE('-T>6QE('9A<FEA8FQE<R!A<F4@;F]T(&=L;V)A;"P@
M96ET:&5R(2$*("`@("`@("`@("`@,BD@($%S(&$@;&ES="!O9B!E;&5M96YT
M<R!C86X@;VYL>2!B92!A9&1E9"!T;R!A('9A<FEA8FQE(&%S(&$@<F5S=6QT
M('1R964@9G)A9VUE;G0@=&AE"B`@("`@("`@("`@("`@("!E>'1E;G-I;VX@
M:7,@;F5C8V5S<V%R>2$A"B`@("`M+3X*"B`@("`\(2TM(#)$3SH@26YL:6YE
M('-T>6QE<R!D;R!N;W0@:6YH97)I="!F<F]M(%A-3"!O9F9I8V4@9&5F875L
M=',@;F]R(&9O;G0Z9F%M:6QY(&1E9F%U;'1S(&%S('1H92!S='EL92!H96%D
M97(@9&]E<PH@("`@("`@("`@("`@("AC<"X@<W1Y;&5S:&5E="`G<W1Y;&5?
M:&5A9&5R+GAS;"<@86YD('1H92`G=W)I=&4M9&5F875L="US='EL97,G('1E
M;7!L871E*2`M+3X*"B`@("`\>'-L.G1E;7!L871E(&YA;64])V-R96%T92UA
M;&PM:6YL:6YE+7-T>6QE<R<^"@H@("`@("`@(#PA+2TJ*B!T<F%V97)S964@
M86QL('-T>6QE('1R965S(&%N9"!T:&5I<B!B<F%N8VAE<R!C;VQL96-T:6YG
M('-T>6QE('!R;W!E<G1I97,@*BHM+3X*("`@("`@("`\>'-L.F5L96UE;G0@
M;F%M93TB86QL<W1Y;&5S(CX*("`@("`@("`\(2TM*BH@=')A=F5R<V5E(&%L
M;"!O9F9I8V4Z<W1Y;&5S('1R965S(&)E9VEN;FEN9R!W:71H('1H92!T;W`M
M;&5V96P@<W1Y;&5S*BHM+3X*("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S
M96QE8W0](B1O9F9I8V4Z<W1Y;&5S+W-T>6QE.G-T>6QE6VYO="A`<W1Y;&4Z
M<&%R96YT+7-T>6QE+6YA;64I72(^"@H@("`@("`@("`@("`@("`@/"$M+2HJ
M(&=I=F4@;W5T('1H92!S='EL92!P<F]P97)T:65S(&]F('1H92!P87)E;G0@
M;F]D92`J*BTM/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64])W=R:71E+6-U<G)E;G0M86YD+6EN:&5R:71E9"US='EL92UP<F]P
M97)T:65S)SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB<W1Y;&5S+6YO9&4B("`@("`@("`@("`@("`@("`@<V5L96-T/2(D
M;V9F:6-E.G-T>6QE<R(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)S='EL92UF86UI;'DB("`@("`@("`@("`@("`@("!S
M96QE8W0](D!S='EL93IF86UI;'DB+SX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&4M;F%M92UT;VME;FEZ960B("`@
M("`@("`@<V5L96-T/2)T<F%N<VQA=&4H0'-T>6QE.FYA;64L("<N("4H*2]<
M)RP@)R<I(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E
M/@H*("`@("`@("`@("`@("`@(#PA+2TJ*B!A;&P@;V9F:6-E.G-T>6QE<R!C
M:&EL9')E;B!O9B!T:&4@8W5R<F5N="!T;W`M;&5V96P@;V9F:6-E.G-T>6QE
M<R`J*BTM/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA
M;64])V9O<BUA;&PM=&5M<&QA=&5S+6-H:6QD+7-T>6QE<R<^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!A<F5N=%-T>6QE
M3F%M92(@("`@("`@("`@("`@('-E;&5C=#TB0'-T>6QE.FYA;64B+SX*("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&%R96YT
M4W1Y;&5&86UI;'DB("`@("`@("`@("`@<V5L96-T/2)`<W1Y;&4Z9F%M:6QY
M(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(G-T>6QE+6YA;64M=&]K96YI>F5D(B`@("`@("`@('-E;&5C=#TB=')A;G-L
M871E*$!S='EL93IN86UE+"`G+B`E*"DO7"<L("<G*2(O/@H@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*"B`@("`@("`@("`@("`@("`\
M(2TM*BH@86QL(&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S(&-H:6QD<F5N(&]F
M('1H92!C=7)R96YT('1O<"UL979E;"!S='EL92`J*BTM/@H@("`@("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64])V9O<BUA;&PM875T;VUA
M=&EC+6-H:6QD+7-T>6QE<R<^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](G!A<F5N=%-T>6QE3F%M92(@("`@("`@("`@("`@
M('-E;&5C=#TB0'-T>6QE.FYA;64B+SX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB<&%R96YT4W1Y;&5&86UI;'DB("`@("`@
M("`@("`@<V5L96-T/2)`<W1Y;&4Z9F%M:6QY(B\^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE+6YA;64M=&]K96YI
M>F5D(B`@("`@("`@('-E;&5C=#TB=')A;G-L871E*$!S='EL93IN86UE+"`G
M+B`E*"DO7"<L("<G*2(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"@H@("`@("`@
M(#PA+2TJ*B!T<F%V97)S964@86QL(&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S
M('1R965S(&)E9VEN;FEN9R!W:71H('1H92!T;W`M;&5V96P@<W1Y;&5S("HJ
M+2T^"B`@("`@("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T/2(D;V9F:6-E
M.F%U=&]M871I8RUS='EL97,O<W1Y;&4Z<W1Y;&5;;F]T*$!S='EL93IP87)E
M;G0M<W1Y;&4M;F%M92E=(CX*("`@("`@("`@("`@("`@(#PA+2TJ*B!G:79E
M(&]U="!T:&4@<W1Y;&4@<')O<&5R=&EE<R!O9B!T:&4@<&%R96YT(&YO9&4@
M*BHM+3X*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE
M/2=W<FET92UC=7)R96YT+6%N9"UI;FAE<FET960M<W1Y;&4M<')O<&5R=&EE
M<R<^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(G-T>6QE<RUN;V1E(B`@("`@("`@("`@("`@("`@('-E;&5C=#TB)&]F9FEC
M93IA=71O;6%T:6,M<W1Y;&5S(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](G-T>6QE+69A;6EL>2(@("`@("`@("`@("`@
M("`@('-E;&5C=#TB0'-T>6QE.F9A;6EL>2(O/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL92UN86UE+71O:V5N:7IE
M9"(@("`@("`@("!S96QE8W0](G1R86YS;&%T92A`<W1Y;&4Z;F%M92P@)RX@
M)2@I+UPG+"`G)RDB+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"@H@("`@("`@("`@("`@("`@/"$M+2HJ(&%L;"!C:&EL9')E;B!O
M9B!T:&4@=&]P+6QE=F5L(&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S<R`@*BHM
M+3X*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2=F
M;W(M86QL+6%U=&]M871I8RUC:&EL9"US='EL97,G/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P87)E;G13='EL94YA;64B
M("`@("`@("`@("`@("!S96QE8W0](D!S='EL93IN86UE(B\^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!A<F5N=%-T>6QE
M1F%M:6QY(B`@("`@("`@("`@('-E;&5C=#TB0'-T>6QE.F9A;6EL>2(O/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL
M92UN86UE+71O:V5N:7IE9"(@("`@("`@("!S96QE8W0](G1R86YS;&%T92A`
M<W1Y;&4Z;F%M92P@)RX@)2@I+UPG+"`G)RDB+SX*("`@("`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.F9O<BUE
M86-H/@H@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`\+WAS;#IT96UP;&%T
M93X*"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TG9F]R+6%L;"UT96UP;&%T
M97,M8VAI;&0M<W1Y;&5S)SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G!A
M<F5N=%-T>6QE3F%M92(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<&%R
M96YT4W1Y;&5&86UI;'DB+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G-T
M>6QE+6YA;64M=&]K96YI>F5D(B\^"@H@("`@("`@(#QX<VPZ9F]R+65A8V@@
M<V5L96-T/2(N+B]S='EL93IS='EL95M`<W1Y;&4Z9F%M:6QY/21P87)E;G13
M='EL949A;6EL>2!A;F0@0'-T>6QE.G!A<F5N="US='EL92UN86UE/21P87)E
M;G13='EL94YA;65=(CX*("`@("`@("`@("`@/"$M+2HJ(&=I=F4@;W5T('1H
M92!S='EL92!P<F]P97)T:65S(&]F('1H92!C=7)R96YT(&YO9&4@*BHM+3X*
M("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](GLD<W1Y;&4M;F%M92UT
M;VME;FEZ961](CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T
M92!N86UE/2=W<FET92UC=7)R96YT+6%N9"UI;FAE<FET960M<W1Y;&4M<')O
M<&5R=&EE<R<^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](G-T>6QE<RUN;V1E(B`@("`@("`@("`@("`@("`@('-E;&5C=#TB
M)&]F9FEC93IS='EL97,B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB<W1Y;&4M9F%M:6QY(B`@("`@("`@("`@("`@("`@
M<V5L96-T/2)`<W1Y;&4Z9F%M:6QY(B\^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE+6YA;64M=&]K96YI>F5D(B`@
M("`@("`@('-E;&5C=#TB=')A;G-L871E*$!S='EL93IN86UE+"`G+B`E*"DO
M7"<L("<G*2(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T
M93X*("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*"B`@("`@("`@("`@(#PA
M+2TJ*B!F;W(@86QL('1E;7!L871E+6-H:6QD<F5N(&]F('1H92!C=7)R96YT
M(&]F9FEC93IS='EL97,@("HJ+2T^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2=F;W(M86QL+71E;7!L871E<RUC:&EL9"US='EL97,G
M/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE
M<RUN;V1E(B`@("`@("`@("`@("`@("`@('-E;&5C=#TB)&]F9FEC93IS='EL
M97,B+SX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P
M87)E;G13='EL94YA;64B("`@("`@("`@("`@("!S96QE8W0](D!S='EL93IN
M86UE(B\^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M<&%R96YT4W1Y;&5&86UI;'DB("`@("`@("`@("`@<V5L96-T/2)`<W1Y;&4Z
M9F%M:6QY(B\^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB<W1Y;&4M;F%M92UT;VME;FEZ960B("`@("`@("`@<V5L96-T/2)T<F%N
M<VQA=&4H0'-T>6QE.FYA;64L("<N("4H*2]<)RP@)R<I(B\^"B`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"@H@("`@("`@("`@("`\(2TM*BH@
M9F]R(&%L;"!A=71O;6%T:6,M8VAI;&1R96X@;V8@=&AE(&-U<G)E;G0@;V9F
M:6-E.G-T>6QE<R`@*BHM+3X*("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L
M871E(&YA;64])V9O<BUA;&PM875T;VUA=&EC+6-H:6QD+7-T>6QE<R<^"B`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&5S+6YO
M9&4B("`@("`@("`@("`@("`@("`@<V5L96-T/2(D;V9F:6-E.F%U=&]M871I
M8RUS='EL97,B+SX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)P87)E;G13='EL94YA;64B("`@("`@("`@("`@("!S96QE8W0](D!S
M='EL93IN86UE(B\^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB<&%R96YT4W1Y;&5&86UI;'DB("`@("`@("`@("`@<V5L96-T/2)`
M<W1Y;&4Z9F%M:6QY(B\^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB<W1Y;&4M;F%M92UT;VME;FEZ960B("`@("`@("`@<V5L96-T
M/2)T<F%N<VQA=&4H0'-T>6QE.FYA;64L("<N("4H*2]<)RP@)R<I(B\^"B`@
M("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"@H@("`@("`@(#PO>'-L
M.F9O<BUE86-H/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\>'-L.G1E
M;7!L871E(&YA;64])V9O<BUA;&PM875T;VUA=&EC+6-H:6QD+7-T>6QE<R<^
M"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)S='EL97,M;F]D92(O/@H@("`@
M("`@(#QX<VPZ<&%R86T@;F%M93TB<&%R96YT4W1Y;&5.86UE(B\^"B`@("`@
M("`@/'AS;#IP87)A;2!N86UE/2)P87)E;G13='EL949A;6EL>2(O/@H@("`@
M("`@(#QX<VPZ<&%R86T@;F%M93TB<W1Y;&4M;F%M92UT;VME;FEZ960B+SX*
M"B`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1O9F9I8V4Z875T;VUA
M=&EC+7-T>6QE<R]S='EL93IS='EL95M`<W1Y;&4Z9F%M:6QY/21P87)E;G13
M='EL949A;6EL>2!A;F0@0'-T>6QE.G!A<F5N="US='EL92UN86UE/21P87)E
M;G13='EL94YA;65=(CX*("`@("`@("`@("`@/"$M+2HJ(&=I=F4@;W5T('1H
M92!S='EL92!P<F]P97)T:65S(&]F('1H92!C=7)R96YT(&YO9&4@*BHM+3X*
M("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](GLD<W1Y;&4M;F%M92UT
M;VME;FEZ961](CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T
M92!N86UE/2=W<FET92UC=7)R96YT+6%N9"UI;FAE<FET960M<W1Y;&4M<')O
M<&5R=&EE<R<^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](G-T>6QE<RUN;V1E(B`@("`@("`@("`@("`@("`@('-E;&5C=#TB
M)&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S(B\^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE+69A;6EL>2(@("`@("`@
M("`@("`@("`@('-E;&5C=#TB0'-T>6QE.F9A;6EL>2(O/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL92UN86UE+71O
M:V5N:7IE9"(@("`@("`@("!S96QE8W0](G1R86YS;&%T92A`<W1Y;&4Z;F%M
M92P@)RX@)2@I+UPG+"`G)RDB+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A
M;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"@H@("`@
M("`@("`@("`\(2TM*BH@9F]R(&%L;"!A=71O;6%T:6,M8VAI;&1R96X@;V8@
M=&AE(&-U<G)E;G0@;V9F:6-E.F%U=&]M871I8RUS='EL97,@("HJ+2T^"B`@
M("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2=F;W(M86QL+6%U
M=&]M871I8RUC:&EL9"US='EL97,G/@H@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](G-T>6QE<RUN;V1E(B`@("`@("`@("`@("`@("`@
M('-E;&5C=#TB)&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S(B\^"B`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&%R96YT4W1Y;&5.86UE
M(B`@("`@("`@("`@("`@<V5L96-T/2)`<W1Y;&4Z;F%M92(O/@H@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!A<F5N=%-T>6QE1F%M
M:6QY(B`@("`@("`@("`@('-E;&5C=#TB0'-T>6QE.F9A;6EL>2(O/@H@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE+6YA;64M
M=&]K96YI>F5D(B`@("`@("`@('-E;&5C=#TB=')A;G-L871E*$!S='EL93IN
M86UE+"`G+B`E*"DO7"<L("<G*2(O/@H@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@(#PO>'-L.F9O<BUE86-H/@H@("`@/"]X<VPZ
M=&5M<&QA=&4^"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TG=W)I=&4M8W5R
M<F5N="UA;F0M:6YH97)I=&5D+7-T>6QE+7!R;W!E<G1I97,G/@H@("`@("`@
M(#QX<VPZ<&%R86T@;F%M93TB<W1Y;&4M9F%M:6QY(B\^"B`@("`@("`@/'AS
M;#IP87)A;2!N86UE/2)S='EL97,M;F]D92(O/@H@("`@("`@(#QX<VPZ<&%R
M86T@;F%M93TB<W1Y;&4M;F%M92UT;VME;FEZ960B+SX*"B`@("`@("`@/'AS
M;#IE;&5M96YT(&YA;64](GLD<W1Y;&4M;F%M92UT;VME;FEZ961](CX*("`@
M("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)C=7)R96YT+7-T>6QE+6YA
M;64B('-E;&5C=#TB0'-T>6QE.FYA;64B+SX*("`@("`@("`@("`@/'AS;#IV
M87)I86)L92!N86UE/2)P87)E;G0M<W1Y;&4M;F%M92(@<V5L96-T/2)`<W1Y
M;&4Z<&%R96YT+7-T>6QE+6YA;64B+SX*"B`@("`@("`@("`@(#QX<VPZ=F%R
M:6%B;&4@;F%M93TB;F5W+7!R;W!E<G1Y+6QI<W0B/@H@("`@("`@("`@("`@
M("`@/"$M+2HJ*B!#3TQ,14-4(%-464Q%($%45%))0E5415,@*&]N;'D@=&]P
M;&5V96PI("HJ*BTM/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L
M871E(&YA;64](G=R:71E+7-T>6QE+7!R;W!E<G1I97,B/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL94%T=')I8G5T
M95!A=&@B("`@<V5L96-T/2(D<W1Y;&5S+6YO9&4O<W1Y;&4Z<W1Y;&5;0'-T
M>6QE.F9A;6EL>3TD<W1Y;&4M9F%M:6QY(&%N9"!`<W1Y;&4Z;F%M93TD8W5R
M<F5N="US='EL92UN86UE72]S='EL93IP<F]P97)T:65S+T`J(B\^"B`@("`@
M("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\
M+WAS;#IV87)I86)L93X*("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@
M("`@("`@("`@("`\(2TM*BHJ($!%;F0Z($=)5D4@3U54($%L;"!#3TQ,14-4
M140@4U193$4@05144DE"551%4R`H;VYL>2!T;W!L979E;"D@*BHJ+2T^"B`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB<W1R:6YG+6QE;F=T:"@D
M<&%R96YT+7-T>6QE+6YA;64I/3`B/@H@("`@("`@("`@("`@("`@/"$M+2HJ
M(&EF(&YO('-T>6QE4&%R96YT(&ES(&=I=F5N+"!T:&4@<')O<&5R=&EE<R!A
M<F4@9VEV96X@;W5T(&%T(&]N8V4@*BHM+3X*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB;F]R;6%L:7IE+7-P86-E*"1N97<M
M<')O<&5R='DM;&ES="DB+SX*("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](FYE=RUP<F]P97)T>2UN86UE
M<R(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L
M96-T/2(D<W1Y;&5S+6YO9&4O<W1Y;&4Z<W1Y;&5;0'-T>6QE.F9A;6EL>3TD
M<W1Y;&4M9F%M:6QY(&%N9"!`<W1Y;&4Z;F%M93TD8W5R<F5N="US='EL92UN
M86UE72]S='EL93IP<F]P97)T:65S+T`J(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)N86UE*"DB+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ=F%R:6%B;&4^"B`@("`@("`@("`@("`@("`@
M("`@/"$M+2HJ(&9U<G1H97(@871T<FEB=71E<R!O9B!T:&4@<&%R96YT('-T
M>6QE(&UU<W0@8F4@8V]L;&5C=&5D("HJ+2T^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%D9"UP87)E;G0M<W1Y;&4M
M871T<FEB=71E<R(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)P<F]P97)T>2UN86UE+6QI<W0B("`@("`@('-E;&5C
M=#TB)&YE=RUP<F]P97)T>2UN86UE<R(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]M<&QE=&4M<')O<&5R='DM
M;&ES="(@("!S96QE8W0](FYO<FUA;&EZ92US<&%C92@D;F5W+7!R;W!E<G1Y
M+6QI<W0I(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)C=7)R96YT+7-T>6QE+6YA;64B("`@("`@('-E;&5C=#TB
M)&-U<G)E;G0M<W1Y;&4M;F%M92(O/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&%R96YT+7-T>6QE+6YA;64B("`@
M("`@("!S96QE8W0](B1P87)E;G0M<W1Y;&4M;F%M92(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&4M9F%M
M:6QY(B`@("`@("`@("`@("!S96QE8W0](B1S='EL92UF86UI;'DB+SX*("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`\+WAS;#IC
M:&]O<V4^"B`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@(#PO>'-L.G1E;7!L
M871E/@H*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)A9&0M<&%R96YT+7-T
M>6QE+6%T=')I8G5T97,B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<')O
M<&5R='DM;F%M92UL:7-T(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C
M;VUP;&5T92UP<F]P97)T>2UL:7-T(B\^"B`@("`@("`@/'AS;#IP87)A;2!N
M86UE/2)C=7)R96YT+7-T>6QE+6YA;64B+SX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](G!A<F5N="US='EL92UN86UE(B\^"B`@("`@("`@/'AS;#IP87)A
M;2!N86UE/2)S='EL92UF86UI;'DB+SX*"B`@("`@("`@/"$M+2HJ*B!.97<@
M='=O(&)E(&%D9&5D('!R;W!E<G1Y(&YA;65S('=I;&P@8F4@8V]L;&5C=&5D
M("AO;FQY(&]N92!V87)I86)L92!P97(@=&5M<&QA=&4I("HJ*BTM/@H@("`@
M("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB;F5W+7!R;W!E<G1Y+6YA;65S(CX*
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F=E="UN97<M
M<W1Y;&4M;F%M97,B/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](G!R;W!E<G1Y+6YA;64M;&ES="(@("`@("`@<V5L96-T/2(D<')O
M<&5R='DM;F%M92UL:7-T(B\^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB<&%R96YT+7-T>6QE+6YA;64B("`@("`@("!S96QE8W0]
M(B1P87)E;G0M<W1Y;&4M;F%M92(O/@H@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F-U<G)E;G0M<W1Y;&4M;F%M92(@("`@("`@<V5L
M96-T/2(D8W5R<F5N="US='EL92UN86UE(B\^"B`@("`@("`@("`@(#PO>'-L
M.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@/"]X<VPZ=F%R:6%B;&4^"@H@("`@
M("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\(2TM*BHJ(&-H96-K(&EF
M('1H92!N97<@<&%R96YT('-T>6QE(&5X:7-T(&EN('1H92!O9F9I8V4Z875T
M;VUA=&EC+7-T>6QE<R!S96-T:6]N("AD969I;F5D(&)Y(&YA;64@86YD(&9A
M;6EL>2D@*BHJ+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;V9F
M:6-E.F%U=&]M871I8RUS='EL97,O<W1Y;&4Z<W1Y;&5;0'-T>6QE.F9A;6EL
M>3TG<&%R86=R87!H)R!A;F0@0'-T>6QE.FYA;64])&-U<G)E;G0M<W1Y;&4M
M;F%M95TB/@H@("`@("`@("`@("`@("`@/"$M+2HJ*B!214-54E-)3TXZ(&%D
M9&EN9R!N97<@<&%R96YT('-T>6QE(&%T=')I8G5T97,@=&\@=&AE(&-U<G)E
M;G0@<W1Y;&4@*BHJ+2T^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE
M(&YA;64](FYE=RUP<F]P97)T>2UA='1R:6)U=&5S(CX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9V5T+6YE=RUS='EL
M92UA='1R:6)U=&5S(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](FYE=RUP<F]P97)T>2UN86UE<R(@("`@("`@("`@
M('-E;&5C=#TB)&YE=RUP<F]P97)T>2UN86UE<R(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8W5R<F5N="US='EL
M92UN86UE(B`@("`@("`@("`@<V5L96-T/2(D8W5R<F5N="US='EL92UN86UE
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)P87)E;G0M<W1Y;&4M;F%M92(@("`@("`@("`@("!S96QE8W0](B1P
M87)E;G0M<W1Y;&4M;F%M92(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IV87)I86)L
M93X*("`@("`@("`@("`@("`@(#PA+2TJ*BH@16YD($-/3D1)5$E/3CH@=&AE
M(&QA<W0@<W1Y;&4@<&%R96YT(&AA<R!A;')E861Y(&)E96X@97AE8W5T960@
M*BHJ+2T^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](FYE
M=RUP87)E;G0M<W1Y;&4M;F%M92(@('-E;&5C=#TB)&]F9FEC93IA=71O;6%T
M:6,M<W1Y;&5S+W-T>6QE.G-T>6QE6T!S='EL93IF86UI;'D])W!A<F%G<F%P
M:"<@86YD($!S='EL93IN86UE/21P87)E;G0M<W1Y;&4M;F%M95TO0'-T>6QE
M.G!A<F5N="US='EL92UN86UE(B\^"B`@("`@("`@("`@("`@("`\>'-L.F-H
M;V]S93X*("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB<W1R
M:6YG+6QE;F=T:"@D;F5W+7!A<F5N="US='EL92UN86UE*3TP(CX*("`@("`@
M("`@("`@("`@("`@("`\(2TM*BH@;F\@9G5R=&AE<B!P87)E;G0@:7,@9F]U
M;F0L('1H92!G:79E;B!P87)A;65T97(@<')O<&5R='DM;F]D92!I<R!T:&4@
M9FEN86P@<W1Y;&4@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2)C;VYC870H)&-O;7!L971E+7!R;W!E<G1Y+6QI
M<W0L)&YE=RUP<F]P97)T>2UA='1R:6)U=&5S*2(O/@H@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IO
M=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@/"$M+2HJ(&9U<G1H97(@
M871T<FEB=71E<R!O9B!T:&4@<&%R96YT('-T>6QE(&UU<W0@8F4@8V]L;&5C
M=&5D("HJ+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)A9&0M<&%R96YT+7-T>6QE+6%T=')I8G5T97,B/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](G!R;W!E<G1Y+6YA;64M;&ES="(@("`@("`@<V5L96-T/2)C;VYC870H
M)'!R;W!E<G1Y+6YA;64M;&ES="P@)&YE=RUP<F]P97)T>2UN86UE<RDB+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C;VUP;&5T92UP<F]P97)T>2UL:7-T(B`@('-E;&5C=#TB8V]N8V%T
M*"1C;VUP;&5T92UP<F]P97)T>2UL:7-T+"1N97<M<')O<&5R='DM871T<FEB
M=71E<RDB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C=7)R96YT+7-T>6QE+6YA;64B("`@("`@('-E;&5C
M=#TB)'!A<F5N="US='EL92UN86UE(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&%R96YT+7-T>6QE+6YA
M;64B("`@("`@("!S96QE8W0](B1N97<M<&%R96YT+7-T>6QE+6YA;64B+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)S='EL92UF86UI;'DB("`@("`@("`@("`@('-E;&5C=#TB)'-T>6QE
M+69A;6EL>2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES
M93X*("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@(#PA+2TJ*B!T:&4@<W!E8VEF:6,@
M<W1Y;&4@*&1E9FEN960@8GD@;F%M92!A;F0@9F%M:6QY*2!M=7-T(&)E(&9O
M=6YD(&EN('1H92!O9F9I8V4Z<W1Y;&5S('-E8W1I;VX@+2T^"B`@("`@("`@
M("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/"$M+2HJ*B!2
M14-54E-)3TXZ(&%D9&EN9R!N97<@<&%R96YT('-T>6QE(&%T=')I8G5T97,@
M=&\@=&AE(&-U<G)E;G0@<W1Y;&4@*BHJ+2T^"B`@("`@("`@("`@("`@("`\
M(2TM*BHJ(&%D9&EN9R!N97<@<&%R96YT('-T>6QE(&%T=')I8G5T97,@=&\@
M=&AE(&-U<G)E;G0@<W1Y;&4@*BHJ+2T^"B`@("`@("`@("`@("`@("`\>'-L
M.G9A<FEA8FQE(&YA;64](FYE=RUP<F]P97)T>2UA='1R:6)U=&5S(CX*("`@
M("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9V5T
M+6YE=RUS='EL92UA='1R:6)U=&5S(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FYE=RUP<F]P97)T>2UN86UE<R(@
M("`@("`@("`@('-E;&5C=#TB)&YE=RUP<F]P97)T>2UN86UE<R(O/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8W5R
M<F5N="US='EL92UN86UE(B`@("`@("`@("`@<V5L96-T/2(D8W5R<F5N="US
M='EL92UN86UE(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)P87)E;G0M<W1Y;&4M;F%M92(@("`@("`@("`@("!S
M96QE8W0](B1P87)E;G0M<W1Y;&4M;F%M92(O/@H@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS
M;#IV87)I86)L93X*("`@("`@("`@("`@("`@(#PA+2TJ*BH@16YD($-/3D1)
M5$E/3CH@=&AE(&QA<W0@<W1Y;&4@<&%R96YT(&AA<R!A;')E861Y(&)E96X@
M97AE8W5T960@*BHJ+2T^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE
M(&YA;64](FYE=RUP87)E;G0M<W1Y;&4M;F%M92(@('-E;&5C=#TB)&]F9FEC
M93IS='EL97,O<W1Y;&4Z<W1Y;&5;0'-T>6QE.F9A;6EL>3TG<&%R86=R87!H
M)R!A;F0@0'-T>6QE.FYA;64])'!A<F5N="US='EL92UN86UE72]`<W1Y;&4Z
M<&%R96YT+7-T>6QE+6YA;64B+SX*("`@("`@("`@("`@("`@(#QX<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)S=')I
M;F<M;&5N9W1H*"1N97<M<&%R96YT+7-T>6QE+6YA;64I/3`B/@H@("`@("`@
M("`@("`@("`@("`@(#PA+2TJ*B!N;R!F=7)T:&5R('!A<F5N="!I<R!F;W5N
M9"P@=&AE(&=I=F5N('!A<F%M971E<B!P<F]P97)T>2UN;V1E(&ES('1H92!F
M:6YA;"!S='EL92`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](F-O;F-A="@D8V]M<&QE=&4M<')O<&5R='DM;&ES
M="PD;F5W+7!R;W!E<G1Y+6%T=')I8G5T97,I(B\^"B`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F]T
M:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`\(2TM*BH@9G5R=&AE<B!A
M='1R:6)U=&5S(&]F('1H92!P87)E;G0@<W1Y;&4@;75S="!B92!C;VQL96-T
M960@*BH@("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM
M=&5M<&QA=&4@;F%M93TB861D+7!A<F5N="US='EL92UA='1R:6)U=&5S(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)P<F]P97)T>2UN86UE+6QI<W0B("`@("`@('-E;&5C=#TB8V]N8V%T
M*"1P<F]P97)T>2UN86UE+6QI<W0L("1N97<M<')O<&5R='DM;F%M97,I(B\^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB8V]M<&QE=&4M<')O<&5R='DM;&ES="(@("!S96QE8W0](F-O;F-A
M="@D8V]M<&QE=&4M<')O<&5R='DM;&ES="PD;F5W+7!R;W!E<G1Y+6%T=')I
M8G5T97,I(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB8W5R<F5N="US='EL92UN86UE(B`@("`@("!S96QE
M8W0](B1P87)E;G0M<W1Y;&4M;F%M92(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!A<F5N="US='EL92UN
M86UE(B`@("`@("`@<V5L96-T/2(D;F5W+7!A<F5N="US='EL92UN86UE(B\^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB<W1Y;&4M9F%M:6QY(B`@("`@("`@("`@("!S96QE8W0](B1S='EL
M92UF86UI;'DB+SX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L
M;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I
M<V4^"B`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@
M(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\
M+WAS;#IT96UP;&%T93X*"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB9V5T
M+6YE=RUS='EL92UN86UE<R(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)P
M<F]P97)T>2UN86UE+6QI<W0B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(G!A<F5N="US='EL92UN86UE(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE
M/2)C=7)R96YT+7-T>6QE+6YA;64B+SX*("`@("`@("`\(2TM*BH@=VAE<F4@
M=&\@9FEN9"!T:&4@<W!E8VEF:6,@<W1Y;&4@*&1E9FEN960@8GD@;F%M92!A
M;F0@9F%M:6QY*2!W:&5T97(@:6X@;V9F:6-E.F%U=&]M871I8RUS='EL97,@
M;W(@;V9F:6-E.G-T>6QE<R!S96-T:6]N("TM/@H@("`@("`@(#QX<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`\(2TM*BH@:68@=&AE('-P96-I9FEC('-T>6QE
M("AD969I;F5D(&)Y(&YA;64@86YD(&9A;6EL>2D@8V%N(&)E(&9O=6YD(&EN
M('1H92!O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R!S96-T:6]N("TM/@H@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]F9FEC93IA=71O;6%T:6,M<W1Y
M;&5S+W-T>6QE.G-T>6QE6T!S='EL93IF86UI;'D])W!A<F%G<F%P:"<@86YD
M($!S='EL93IN86UE/21P87)E;G0M<W1Y;&4M;F%M95TB/@H@("`@("`@("`@
M("`@("`@/'AS;#IV87)I86)L92!N86UE/2)P87)E;G0M<')O<&5R='DM;F]D
M92(@<V5L96-T/2(D;V9F:6-E.F%U=&]M871I8RUS='EL97,O<W1Y;&4Z<W1Y
M;&5;0'-T>6QE.F9A;6EL>3TG<&%R86=R87!H)R!A;F0@0'-T>6QE.FYA;64]
M)'!A<F5N="US='EL92UN86UE72]S='EL93IP<F]P97)T:65S(B\^"@H@("`@
M("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)N97<M<')O<&5R='DM
M;F%M92UL:7-T(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F9O<BUE86-H
M('-E;&5C=#TB)'!A<F5N="UP<F]P97)T>2UN;V1E+T`J6VYO="AC;VYT86EN
M<R@D<')O<&5R='DM;F%M92UL:7-T+"!N86UE*"DI*5TB/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB;F%M92@I(B\^
M"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@
M("`@("`@("`\+WAS;#IV87)I86)L93X*("`@("`@("`@("`@("`@(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2(D;F5W+7!R;W!E<G1Y+6YA;64M;&ES="(O/@H@
M("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\(2TM*BH@=&AE
M('-P96-I9FEC('-T>6QE("AD969I;F5D(&)Y(&YA;64@86YD(&9A;6EL>2D@
M<VAO=6QD(&)E(&9O=6YD(&EN('1H92!O9F9I8V4Z<W1Y;&5S('-E8W1I;VX@
M+2T^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@
M("`@/'AS;#IV87)I86)L92!N86UE/2)P87)E;G0M<')O<&5R='DM;F]D92(@
M<V5L96-T/2(D;V9F:6-E.G-T>6QE<R]S='EL93IS='EL95M`<W1Y;&4Z9F%M
M:6QY/2=P87)A9W)A<&@G(&%N9"!`<W1Y;&4Z;F%M93TD<&%R96YT+7-T>6QE
M+6YA;65=+W-T>6QE.G!R;W!E<G1I97,B+SX*("`@("`@("`@("`@("`@(#QX
M<VPZ=F%R:6%B;&4@;F%M93TB;F5W+7!R;W!E<G1Y+6YA;64M;&ES="(^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1P87)E
M;G0M<')O<&5R='DM;F]D92]`*EMN;W0H8V]N=&%I;G,H)'!R;W!E<G1Y+6YA
M;64M;&ES="P@;F%M92@I*2E=(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IV86QU92UO9B!S96QE8W0](FYA;64H*2(O/@H@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F9O<BUE86-H/@H@("`@("`@("`@("`@("`@/"]X<VPZ
M=F%R:6%B;&4^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB)&YE=RUP<F]P97)T>2UN86UE+6QI<W0B+SX*("`@("`@("`@("`@/"]X
M<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L
M.G1E;7!L871E/@H*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)G970M;F5W
M+7-T>6QE+6%T=')I8G5T97,B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB
M;F5W+7!R;W!E<G1Y+6YA;65S(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE
M/2)C=7)R96YT+7-T>6QE+6YA;64B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA
M;64](G!A<F5N="US='EL92UN86UE(B\^"@H@("`@("`@(#PA+2TJ*B!W:&5R
M92!T;R!F:6YD('1H92!S<&5C:69I8R!S='EL92`H9&5F:6YE9"!B>2!N86UE
M(&%N9"!F86UI;'DI('=H971H97(@:6X@;V9F:6-E.F%U=&]M871I8RUS='EL
M97,@;W(@;V9F:6-E.G-T>6QE<R!S96-T:6]N("TM/@H@("`@("`@(#QX<VPZ
M8VAO;W-E/@H@("`@("`@("`@("`\(2TM*BH@:68@=&AE('-P96-I9FEC('-T
M>6QE("AD969I;F5D(&)Y(&YA;64@86YD(&9A;6EL>2D@8V%N(&)E(&9O=6YD
M(&EN('1H92!O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R!S96-T:6]N("TM/@H@
M("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]F9FEC93IA=71O;6%T:6,M
M<W1Y;&5S+W-T>6QE.G-T>6QE6T!S='EL93IF86UI;'D])W!A<F%G<F%P:"<@
M86YD($!S='EL93IN86UE/21P87)E;G0M<W1Y;&4M;F%M95TB/@H@("`@("`@
M("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)P87)E;G0M<')O<&5R='DM
M;F]D92(@<V5L96-T/2(D;V9F:6-E.F%U=&]M871I8RUS='EL97,O<W1Y;&4Z
M<W1Y;&5;0'-T>6QE.F9A;6EL>3TG<&%R86=R87!H)R!A;F0@0'-T>6QE.FYA
M;64])'!A<F5N="US='EL92UN86UE72]S='EL93IP<F]P97)T:65S(B\^"B`@
M("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](FYE=RUP<F]P97)T
M>2UN86UE+6QI<W0B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)W<FET92US='EL92UP<F]P97)T:65S(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE
M071T<FEB=71E4&%T:"(@("!S96QE8W0](B1P87)E;G0M<')O<&5R='DM;F]D
M92]`*EMC;VYT86EN<R@D;F5W+7!R;W!E<G1Y+6YA;65S+"!N86UE*"DI72(O
M/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@("`@("`\+WAS;#IV87)I86)L93X*("`@("`@("`@("`@("`@
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)N;W)M86QI>F4M<W!A8V4H)&YE=RUP
M<F]P97)T>2UN86UE+6QI<W0I(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@(#PA+2TJ*B!O=&AE<G=I<V4@=&AE('-P96-I9FEC('-T
M>6QE("AD969I;F5D(&)Y(&YA;64@86YD(&9A;6EL>2D@<VAO=6QD(&)E(&9O
M=6YD(&EN('1H92!O9F9I8V4Z<W1Y;&5S('-E8W1I;VX@+2T^"B`@("`@("`@
M("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/'AS;#IV87)I
M86)L92!N86UE/2)P87)E;G0M<')O<&5R='DM;F]D92(@<V5L96-T/2(D;V9F
M:6-E.G-T>6QE<R]S='EL93IS='EL95M`<W1Y;&4Z9F%M:6QY/2=P87)A9W)A
M<&@G(&%N9"!`<W1Y;&4Z;F%M93TD<&%R96YT+7-T>6QE+6YA;65=+W-T>6QE
M.G!R;W!E<G1I97,B+SX*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@
M;F%M93TB;F5W+7!R;W!E<G1Y+6YA;64M;&ES="(^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+7-T>6QE+7!R
M;W!E<G1I97,B/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB<W1Y;&5!='1R:6)U=&50871H(B`@('-E;&5C=#TB)'!A
M<F5N="UP<F]P97)T>2UN;V1E+T`J6V-O;G1A:6YS*"1N97<M<')O<&5R='DM
M;F%M97,L(&YA;64H*2E=(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.G9A<FEA8FQE
M/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](FYO<FUA
M;&EZ92US<&%C92@D;F5W+7!R;W!E<G1Y+6YA;64M;&ES="DB+SX*("`@("`@
M("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*
M("`@(#PO>'-L.G1E;7!L871E/@H*"CPO>'-L.G-T>6QE<VAE970^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]O;V\O<W1Y;&5?;6%P<&EN
M9RYX<VP`````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,3`T,S(`,3`U,34T,S,W-#<`,#(U-C8P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#PA
M+2T*"B`@(%1H92!#;VYT96YT<R!O9B!T:&ES(&9I;&4@87)E(&UA9&4@879A
M:6QA8FQE('-U8FIE8W0@=&\@=&AE('1E<FUS(&]F"B`@(&5I=&AE<B!O9B!T
M:&4@9F]L;&]W:6YG(&QI8V5N<V5S"@H@("`@("`@("`@+2!'3E4@3&5S<V5R
M($=E;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO;B`R+C$*("`@("`@("`@
M("T@4W5N($EN9'5S=')Y(%-T86YD87)D<R!3;W5R8V4@3&EC96YS92!697)S
M:6]N(#$N,0H*("`@4W5N($UI8W)O<WES=&5M<R!);F,N+"!/8W1O8F5R+"`R
M,#`P"@H@("!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R
M<VEO;B`R+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]"B`@($-O<'ER:6=H="`R,#`P(&)Y(%-U;B!-:6-R;W-Y
M<W1E;7,L($EN8RX*("`@.3`Q(%-A;B!!;G1O;FEO(%)O860L(%!A;&\@06QT
M;RP@0T$@.30S,#,L(%5300H*("`@5&AI<R!L:6)R87)Y(&ES(&9R964@<V]F
M='=A<F4[('EO=2!C86X@<F5D:7-T<FEB=71E(&ET(&%N9"]O<@H@("!M;V1I
M9GD@:70@=6YD97(@=&AE('1E<FUS(&]F('1H92!'3E4@3&5S<V5R($=E;F5R
M86P@4'5B;&EC"B`@($QI8V5N<V4@=F5R<VEO;B`R+C$L(&%S('!U8FQI<VAE
M9"!B>2!T:&4@1G)E92!3;V9T=V%R92!&;W5N9&%T:6]N+@H*("`@5&AI<R!L
M:6)R87)Y(&ES(&1I<W1R:6)U=&5D(&EN('1H92!H;W!E('1H870@:70@=VEL
M;"!B92!U<V5F=6PL"B`@(&)U="!7251(3U54($%.62!705)204Y463L@=VET
M:&]U="!E=F5N('1H92!I;7!L:65D('=A<G)A;G1Y(&]F"B`@($U%4D-(04Y4
M04))3$E462!O<B!&251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]312X@
M(%-E92!T:&4@1TY5"B`@($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E
M(&9O<B!M;W)E(&1E=&%I;',N"@H@("!9;W4@<VAO=6QD(&AA=F4@<F5C96EV
M960@82!C;W!Y(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC"B`@
M($QI8V5N<V4@86QO;F<@=VET:"!T:&ES(&QI8G)A<GD[(&EF(&YO="P@=W)I
M=&4@=&\@=&AE($9R964@4V]F='=A<F4*("`@1F]U;F1A=&EO;BP@26YC+BP@
M-3D@5&5M<&QE(%!L86-E+"!3=6ET92`S,S`L($)O<W1O;BP*("`@34$@(#`R
M,3$Q+3$S,#<@(%5300H*"B`@(%-U;B!);F1U<W1R>2!3=&%N9&%R9',@4V]U
M<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@("!4:&4@8V]N=&5N
M=',@;V8@=&AI<R!F:6QE(&%R92!S=6)J96-T('1O('1H92!3=6X@26YD=7-T
M<GD@4W1A;F1A<F1S"B`@(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ("AT
M:&4@(DQI8V5N<V4B*3L@66]U(&UA>2!N;W0@=7-E('1H:7,@9FEL90H@("!E
M>&-E<'0@:6X@8V]M<&QI86YC92!W:71H('1H92!,:6-E;G-E+B!9;W4@;6%Y
M(&]B=&%I;B!A(&-O<'D@;V8@=&AE"B`@($QI8V5N<V4@870@:'1T<#HO+W=W
M=RYO<&5N;V9F:6-E+F]R9R]L:6-E;G-E+FAT;6PN"@H@("!3;V9T=V%R92!P
M<F]V:61E9"!U;F1E<B!T:&ES($QI8V5N<V4@:7,@<')O=FED960@;VX@86X@
M(D%3($E3(B!B87-I<RP*("`@5TE42$]55"!705)204Y462!/1B!!3ED@2TE.
M1"P@14E42$52($584%)%4U,@3U(@24U03$E%1"P@24Y#3%5$24Y'+`H@("!7
M251(3U54($Q)34E4051)3TXL(%=!4E)!3E1)15,@5$A!5"!42$4@4T]&5%=!
M4D4@25,@1E)%12!/1B!$149%0U13+`H@("!-15)#2$%.5$%"3$4L($9)5"!&
M3U(@02!005)424-53$%2(%!54E!/4T4L($]2($Y/3BU)3D9224Y'24Y'+@H@
M("!3964@=&AE($QI8V5N<V4@9F]R('1H92!S<&5C:69I8R!P<F]V:7-I;VYS
M(&=O=F5R;FEN9R!Y;W5R(')I9VAT<R!A;F0*("`@;V)L:6=A=&EO;G,@8V]N
M8V5R;FEN9R!T:&4@4V]F='=A<F4N"@H@("!4:&4@26YI=&EA;"!$979E;&]P
M97(@;V8@=&AE($]R:6=I;F%L($-O9&4@:7,Z(%-U;B!-:6-R;W-Y<W1E;7,L
M($EN8RX*"B`@($-O<'ER:6=H="#"J2`R,#`R(&)Y(%-U;B!-:6-R;W-Y<W1E
M;7,L($EN8RX*"B`@($%L;"!2:6=H=',@4F5S97)V960N"@H@("!#;VYT<FEB
M=71O<BAS*3H@7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?"@HM+3X*/'AS;#IS='EL97-H965T('9E<G-I;VX](C$N,"(*("`@("`@
M("`@("`@("`@('AM;&YS.GAS;#TB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]8
M4TPO5')A;G-F;W)M(@H@("`@("`@("`@("`@("`@>&UL;G,Z;V9F:6-E/2)H
M='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]O9F9I8V4B"B`@("`@("`@("`@
M("`@("!X;6QN<SIS='EL93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O
M<W1Y;&4B"B`@("`@("`@("`@("`@("!X;6QN<SIT97AT/2)H='1P.B\O;W!E
M;F]F9FEC92YO<F<O,C`P,"]T97AT(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M=&%B;&4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W1A8FQE(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z9')A=STB:'1T<#HO+V]P96YO9F9I8V4N;W)G
M+S(P,#`O9')A=VEN9R(*("`@("`@("`@("`@("`@('AM;&YS.F9O/2)H='1P
M.B\O=W=W+G<S+F]R9R\Q.3DY+UA33"]&;W)M870B"B`@("`@("`@("`@("`@
M("!X;6QN<SIX;&EN:STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]X;&EN:R(*
M("`@("`@("`@("`@("`@('AM;&YS.FYU;6)E<CTB:'1T<#HO+V]P96YO9F9I
M8V4N;W)G+S(P,#`O9&%T87-T>6QE(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M<W9G/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`P+W-V9R(*("`@("`@("`@("`@
M("`@('AM;&YS.F-H87)T/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]C
M:&%R="(*("`@("`@("`@("`@("`@('AM;&YS.F1R,V0](FAT='`Z+R]O<&5N
M;V9F:6-E+F]R9R\R,#`P+V1R,V0B"B`@("`@("`@("`@("`@("!X;6QN<SIM
M871H/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DX+TUA=&@O36%T:$U,(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z9F]R;3TB:'1T<#HO+V]P96YO9F9I8V4N;W)G
M+S(P,#`O9F]R;2(*("`@("`@("`@("`@("`@('AM;&YS.G-C<FEP=#TB:'1T
M<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O<V-R:7!T(@H@("`@("`@("`@("`@
M("`@;V9F:6-E.F-L87-S/2)T97AT(@H@("`@("`@("`@("`@("`@;V9F:6-E
M.G9E<G-I;VX](C$N,"(*("`@("`@("`@("`@("`@('AM;&YS.F1C/2)H='1P
M.B\O<'5R;"YO<F<O9&,O96QE;65N=',O,2XQ+R(*("`@("`@("`@("`@("`@
M('AM;&YS.FUE=&$](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+VUE=&$B
M"B`@("`@("`@("`@("`@("!X;6QN<SIC;VYF:6<](FAT='`Z+R]O<&5N;V9F
M:6-E+F]R9R\R,#`Q+V-O;F9I9R(*("`@("`@("`@("`@("`@('AM;&YS.FAE
M;'`](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+VAE;'`B"B`@("`@("`@
M("`@("`@("!X;6QN<SIX=#TB:'1T<#HO+W=W=RYJ8VQA<FLN8V]M+WAT(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z<WES=&5M/2)H='1P.B\O=W=W+FIC;&%R
M:RYC;VTO>'0O:F%V82]J879A+FQA;F<N4WES=&5M(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z>&%L86X](FAT='`Z+R]X;6PN87!A8VAE+F]R9R]X86QA;B(*
M("`@("`@("`@("`@("`@('AM;&YS.FIA=F$](FAT='`Z+R]X;6PN87!A8VAE
M+F]R9R]X<VQT+VIA=F$B"B`@("`@("`@("`@("`@("!E>&-L=61E+7)E<W5L
M="UP<F5F:7AE<STB:F%V82(^"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB
M=W)I=&4M<W1Y;&4M<')O<&5R=&EE<R(^"B`@("`@("`@/'AS;#IP87)A;2!N
M86UE/2)S='EL94%T=')I8G5T95!A=&@B+SX*"B`@("`@("`@/'AS;#IC:&]O
M<V4^"B`@("`@("`@("`@(#PA+2TK*RLK*R!#4U,@4%)/4$525$E%4R`@*RLK
M*RLM+3X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1O=71P=714>7!E
M(#T@)T-34U](14%$15(G(&]R("1O=71P=714>7!E(#T@)T-34U])3DQ)3D5$
M)R(^"@H@("`@("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1S
M='EL94%T=')I8G5T95!A=&@B/@H@("`@("`@("`@("`@("`@/"$M+2!I<T1E
M8G5G36]D94U%4U-!1T4Z"B`@("`@("`@("`@("`@("`@("`@/'AS;#IM97-S
M86=E/B!.86UE.CQX<VPZ=F%L=64M;V8@<V5L96-T/2)N86UE*"DB+SX@5F%L
M=64Z/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX\+WAS;#IM97-S86=E/B`@
M("`@("TM/@H*"B`@("`@("`@("`@("`@("`@("`@/"$M+2`\(4%45$Q)4U0@
M<W1Y;&4Z<')O<&5R=&EE<R!S='EL93IH;W)I>F]N=&%L+7!O<R`H9G)O;2UL
M969T?&QE9G1\8V5N=&5R?')I9VAT?&9R;VTM:6YS:61E?&EN<VED97QO=71S
M:61E*2-)35!,245$/BTM/@H@("`@("`@("`@("`@("`@("`@(#PA+2T@,D1/
M.B!I<R!I;G-I9&4O9G)O;2UI;G-I9&4@86QS;R!B971T97(@<VAO=V%B;&4@
M/R`M+3X*("`@("`@("`@("`@("`@("`@("`\(2TM("$A(2$@,D1/.B!3=&EL
M;"!T:&5R92!H879E('1O(&)E('!L86-E9"!A(#QB<B!C;&5A<CTG86QL)R\^
M('1O(&1I<V%B;&4@=&AE(&9L;W<A(2$A+2T^"B`@("`@("`@("`@("`@("`@
M("`@/"$M+2`@("`@("`@("`@5&AE($]/;R!A='1R:6)U=&4@)W-T>6QE.FYU
M;6)E<BUW<F%P<&5D+7!A<F%G<F%P:',G(&ES(&-U<G)E;G1L>2!I9VYO<F5D
M("TM/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG;F%M92@N*3TB<W1Y
M;&4Z=W)A<"(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC
M:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0])RX](FQE9G0B)SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IT97AT/F9L;V%T.B!R:6=H=#L@/"]X<VPZ=&5X
M=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2<N/2)R:6=H="(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G1E>'0^9FQO870Z(&QE9G0[(#PO>'-L.G1E>'0^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI(#T@(G-T>6QE.FAO
M<FEZ;VYT86PM<&]S(B<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TG+CTB;&5F="(G/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^86QI9VXZ(&QE9G0[(#PO>'-L
M.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TG+CTB<FEG:'0B)SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IT97AT/F%L:6=N.B!R:6=H=#L@/"]X<VPZ=&5X
M=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2<N/2)C96YT97(B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IT97AT/F%L:6=N.B!C96YT97([(#PO>'-L.G1E>'0^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*/"$M+2!R97-U;'1S
M(&EN=&\@82!B860@=FEE=R`H;W9E<FQA<'!E9"D@:6X@36]Z:6QL82`Q+C`*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H
M+BD@/2`B=&%B;&4Z86QI9VXB)SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2<N/2)L969T(B<^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YF;&]A=#H@<FEG:'0[
M(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TG+CTB<FEG:'0B)SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/F9L;V%T.B!L969T.R`\+WAS
M;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O
M<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"BTM/@H*
M("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!0041$24Y'(&9O<B!A;&P@
M=F%R:6%T:6]N<SH@9F\Z<&%D9&EN9RP@9F\Z<&%D9&EN9RUT;W`L(&9O.G!A
M9&1I;F<M8F]T=&]M+"!F;SIP861D:6YG+6QE9G0L(&9O.G!A9&1I;F<M<FEG
M:'0@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2=C;VYT86EN<RAN86UE*"XI+")F;SIP861D:6YG(BDG/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/G!A9&1I;F<Z(#PO>'-L.G1E
M>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB+B(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@/"$M+0H@("`@
M("`@("`@("`@("`@("`@("`@("!F;SIB;W)D97(*("`@("`@("`@("`@("`@
M("`@("`@("`@9F\Z8F]R9&5R+71O<`H@("`@("`@("`@("`@("`@("`@("`@
M("!F;SIB;W)D97(M8F]T=&]M"B`@("`@("`@("`@("`@("`@("`@("`@(&9O
M.F)O<F1E<BUL969T"B`@("`@("`@("`@("`@("`@("`@("`@(&9O.F)O<F1E
M<BUR:6=H=`H*("`@("`@("`@("`@("`@("`@("`@("`@("`@($%T('!R97-E
M;G0L(&%L;"!F;W5R(&)O<F1E<G,@;75S="!B92!S970@<VEM=6QT86YE;W5S
M;'D@8GD@=7-I;F<@96ET:&5R"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!T:&4@9F\Z8F]R9&5R('!R;W!E<G1Y(&]R(&)Y(&%T=&%C:&EN9R!A;&P@
M9F]U<B!O9B!T:&4@;W1H97(@8F]R9&5R"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!P<F]P97)T:65S('1O(&%N(&ET96T@<V5T(&5L96UE;G0N($EN
M('1H92!L871T97(@8V%S92P@:68@;VYE(&]R(&UO<F4*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&]F('1H92!P<F]P97)T:65S(&ES(&UI<W-I;F<@
M=&AE:7(@=F%L=65S(&%R92!A<W-U;65D('1O(&)E(&YO;F4N(%1H90H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@;VYL>2!B;W)D97(@<W1Y;&5S('-U
M<'!O<G1E9"!A<F4@;F]N92!O<B!H:61D96XL('-O;&ED+"!A;F0@9&]U8FQE
M+B!!;GD*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]T:&5R(&)O<F1E
M<B!S='EL92!S<&5C:69I960@:7,@9&ES<&QA>65D(&%S('-O;&ED+B!4<F%N
M<W!A<F5N="!B;W)D97)S"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<F4@;F]T('-U<'!O<G1E9"!A;F0@=&AE(&)O<F1E<B!W:61T:',@=&AI;BP@
M;65D:75M+"!A;F0@=&AI8VL@87)E"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!M87!P960@=&\@;&5N9W1H<RX@26X@861D:71I;VXL(&]N;'D@<V]M
M92!D:7-T:6YC="!B;W)D97(@=VED=&AS(&%R90H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<W5P<&]R=&5D+B!5;G-U<'!O<G1E9"!W:61T:',@87)E
M(')O=6YD960@=7`@=&\@=&AE(&YE>'0@<W5P<&]R=&5D"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!W:61T:"X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@($EF('1H97)E(&%R92!N;R!P861D:6YG('!R;W!E<G1I97,@<W!E
M8VEF:65D('=I=&AI;B!T:&4@<V%M90H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:71E;2!S970@96QE;65N="P@82!D969A=6QT('!A9&1I;F<@:7,@
M=7-E9"!F;W(@<VED97,@=&AA="!H879E(&$*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)O<F1E<BX@02!V86QU92!O9B`P8VT@:7,@=7-E9"!F;W(@
M<VED97,@=VET:&]U="!A(&)O<F1E<BX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("AC<"X@=V0M<V\M>&UL+71E>'0N<V1W*0H@("`@("`@("`@("`@
M("`@("`@("`@("`M+3X*"CPA+2TR1$\@4U1!4E0Z(&-H86YG92!M96%S=7)E
M;65N="!E<75A;&QY("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TG;F%M92@N*3TB9F\Z8F]R9&5R(B<^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\(2TM(&-H86YG:6YG('1H92!D:7-T86YC92!M
M96%S=7)E.B!I;F-H('1O(&EN("TM/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@N+"`G8V@G*2(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X
M=#YB;W)D97(M=VED=&@Z/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB<W5B<W1R:6YG+6)E9F]R92@N+"=C:"`G*2(O/CQX<VPZ=&5X=#X[(#PO
M>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=&5X=#YB;W)D97(M<W1Y;&4Z/"]X<VPZ=&5X=#X\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB<W5B<W1R:6YG+6)E9F]R92AS=6)S=')I;F<M869T97(H
M+BPG8V@@)RDL("<@)RDB+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^8F]R
M9&5R+6-O;&]R.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](G-U
M8G-T<FEN9RUA9G1E<BAS=6)S=')I;F<M869T97(H+BPG8V@@)RDL("<@)RDB
M+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"XL("=C;2<I
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT
M97AT/F)O<F1E<BUW:61T:#H\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L
M96-T/2)S=6)S=')I;F<M8F5F;W)E*"XL)R`G*2(O/CQX<VPZ=&5X=#X[(#PO
M>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=&5X=#YB;W)D97(M<W1Y;&4Z/"]X<VPZ=&5X=#X\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB<W5B<W1R:6YG+6)E9F]R92AS=6)S=')I;F<M869T97(H
M+BPG8VT@)RDL("<@)RDB+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^8F]R
M9&5R+6-O;&]R.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](G-U
M8G-T<FEN9RUA9G1E<BAS=6)S=')I;F<M869T97(H+BPG8VT@)RDL("<@)RDB
M+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"XL("=P="<I
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT
M97AT/F)O<F1E<BUW:61T:#H\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L
M96-T/2)S=6)S=')I;F<M8F5F;W)E*"XL)R`G*2(O/CQX<VPZ=&5X=#X[(#PO
M>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=&5X=#YB;W)D97(M<W1Y;&4Z/"]X<VPZ=&5X=#X\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB<W5B<W1R:6YG+6)E9F]R92AS=6)S=')I;F<M869T97(H
M+BPG<'0@)RDL("<@)RDB+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^8F]R
M9&5R+6-O;&]R.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](G-U
M8G-T<FEN9RUA9G1E<BAS=6)S=')I;F<M869T97(H+BPG<'0@)RDL("<@)RDB
M+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2=N86UE*"XI/2)F;SIB;W)D97(M=&]P(B<^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^8F]R9&5R+71O<#H@/"]X<VPZ
M=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/CQX<VPZ=&5X=#X[(#PO
M>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE
M*"XI/2)F;SIB;W)D97(M8F]T=&]M(B<^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G1E>'0^8F]R9&5R+6)O='1O;3H@/"]X<VPZ=&5X=#X\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E
M>'0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F
M;SIB;W)D97(M;&5F="(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IT97AT/F)O<F1E<BUL969T.B`\+WAS;#IT97AT/CQX<VPZ=F%L=64M
M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O.F)O<F1E<BUR
M:6=H="(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT
M/F)O<F1E<BUR:6=H=#H@/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB+B(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)S='EL93IC;VQU;6XM=VED=&@B
M)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@8VAA;F=I;F<@
M=&AE(&1I<W1A;F-E(&UE87-U<F4Z(&EN8V@@=&\@:6X@+2T^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A
M:6YS*"XL("=C:"<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IT97AT/G=I9'1H.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO
M9B!S96QE8W0](G-U8G-T<FEN9RUB969O<F4H+BPG8V@G*2(O/CQX<VPZ=&5X
M=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IT97AT/G=I9'1H.CPO>'-L.G1E>'0^/'AS;#IV86QU
M92UO9B!S96QE8W0](BXB+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](G-T>6QE.G)O
M=RUH96EG:'0B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@
M8VAA;F=I;F<@=&AE(&1I<W1A;F-E(&UE87-U<F4Z(&EN8V@@=&\@:6X@+2T^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](F-O;G1A:6YS*"XL("=C:"<I(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IT97AT/FAE:6=H=#H\+WAS;#IT97AT/CQX
M<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I;F<M8F5F;W)E*"XL)V-H)RDB
M+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YH96EG:'0Z/"]X<VPZ=&5X
M=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/CQX<VPZ=&5X=#X[(#PO>'-L
M.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG;F%M92@N
M*3TB9F\Z=VED=&@B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA
M+2T@8VAA;F=I;F<@=&AE(&1I<W1A;F-E(&UE87-U<F4Z(&EN8V@@=&\@:6X@
M+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](F-O;G1A:6YS*"XL("=C:"<I(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/G=I9'1H.CPO>'-L.G1E>'0^
M/'AS;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN9RUB969O<F4H+BPG8V@G
M*2(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/G=I9'1H.CPO>'-L.G1E
M>'0^/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX\>'-L.G1E>'0^.R`\+WAS
M;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M/"$M+3)$3R!%3D0Z(&-H86YG92!M96%S=7)E;65N="!E<75A;&QY("TM/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG;F%M92@N
M*3TB9F\Z9F]N="US='EL92(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN9RUA9G1E<BAN86UE
M*"XI+"`G.B<I(B\^/'AS;#IT97AT/CH\+WAS;#IT97AT/CQX<VPZ=F%L=64M
M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](G-T>6QE.F9O;G0M
M;F%M92(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT
M/F9O;G0M9F%M:6QY.CPO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)C;VYT96YT(B!S96QE
M8W0](BXB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB)&]F9FEC93IF;VYT+61E8VQS+W-T>6QE.F9O
M;G0M9&5C;%M`<W1Y;&4Z;F%M93TD8V]N=&5N=%TO0&9O.F9O;G0M9F%M:6QY
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^.R`\
M+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#II
M9B!T97-T/2)C;VYT86EN<R@D;V9F:6-E.F9O;G0M9&5C;',O<W1Y;&4Z9F]N
M="UD96-L6T!S='EL93IN86UE/21C;VYT96YT72]`<W1Y;&4Z9F]N="US='EL
M92UN86UE+"`G271A;&EC)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=&5X=#YF;VYT+7-T>6QE.FET86QI8SL@/"]X<VPZ=&5X
M=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2)C;VYT86EN
M<R@D;V9F:6-E.F9O;G0M9&5C;',O<W1Y;&4Z9F]N="UD96-L6T!S='EL93IN
M86UE/21C;VYT96YT72]`<W1Y;&4Z9F]N="US='EL92UN86UE+"`G0F]L9"<I
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^
M9F]N="UW96EG:'0Z8F]L9#L@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TG;F%M92@N*3TB9F\Z9F]N="UW96EG:'0B)SX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S
M=')I;F<M869T97(H;F%M92@N*2P@)SHG*2(O/CQX<VPZ=&5X=#XZ/"]X<VPZ
M=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/CQX<VPZ=&5X=#X[(#PO
M>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE
M*"XI/2)F;SIF;VYT+7-I>F4B)SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I;F<M869T97(H;F%M
M92@N*2P@)SHG*2(O/CQX<VPZ=&5X=#XZ/"]X<VPZ=&5X=#X\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB+B(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIF;VYT+69A
M;6EL>2(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU
M92UO9B!S96QE8W0](G-U8G-T<FEN9RUA9G1E<BAN86UE*"XI+"`G.B<I(B\^
M/'AS;#IT97AT/CH\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N
M(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0])VYA;64H+BD](F9O.F-O;&]R(B<^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<W5B<W1R
M:6YG+6%F=&5R*&YA;64H+BDL("<Z)RDB+SX\>'-L.G1E>'0^.CPO>'-L.G1E
M>'0^/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX\>'-L.G1E>'0^.R`\+WAS
M;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG;F%M92@N
M*3TB9F\Z;6%R9VEN+6QE9G0B)SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I;F<M869T97(H;F%M
M92@N*2P@)SHG*2(O/CQX<VPZ=&5X=#XZ/"]X<VPZ=&5X=#X\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB+B(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIM87)G:6XM
M<FEG:'0B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2)S=6)S=')I;F<M869T97(H;F%M92@N*2P@)SHG*2(O
M/CQX<VPZ=&5X=#XZ/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M+B(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIM87)G:6XM=&]P(B<^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M<W5B<W1R:6YG+6%F=&5R*&YA;64H+BDL("<Z)RDB+SX\>'-L.G1E>'0^.CPO
M>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX\>'-L.G1E>'0^
M.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG
M;F%M92@N*3TB9F\Z;6%R9VEN+6)O='1O;2(G/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN9RUA
M9G1E<BAN86UE*"XI+"`G.B<I(B\^/'AS;#IT97AT/CH\+WAS;#IT97AT/CQX
M<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X
M=#X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O
M.FQI;F4M:&5I9VAT(B<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG+6%F=&5R*&YA;64H+BDL
M("<Z)RDB+SX\>'-L.G1E>'0^.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S
M96QE8W0](BXB+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TG;F%M92@N*3TB9F\Z=&5X="UA;&EG;B(G
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!)35!/4E1!3E0@
M:7,@;F5C97-S87)Y(&%S('1A8FQE(&-E;&P@=F%L=64@86QI9VYM96YT(&ES
M(&1E8VED960@8GD@<G5N=&EM92!O=F5R('1H92!V86QU971Y<&4*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@3W1H97)W:7-E(&$@=&%B;&4@
M8V5L;"!S='EL92UC;&%S<R!W:6QL($%,5T%94R!B92!O=F5R=W)I='1E;B!B
M>2!T:&4@<G5N+71I;64@=F%L=64@+2T^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"XL("=S=&%R="<I
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT
M97AT/G1E>'0M86QI9VXZ;&5F="`A(&EM<&]R=&%N=#L@/"]X<VPZ=&5X=#X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)C;VYT86EN<R@N+"`G96YD)RDB/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G1E>'0^=&5X="UA;&EG;CIR:6=H="`A(&EM
M<&]R=&%N=#L@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G1E>'0^=&5X="UA;&EG;CH\+WAS;#IT97AT
M/CQX<VPZ=F%L=64M;V8@<V5L96-T/2<N)R\^/'AS;#IT97AT/B`A(&EM<&]R
M=&%N=#L@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TG;F%M92@N*3TB9F\Z=&5X="UI;F1E;G0B)SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I
M;F<M869T97(H;F%M92@N*2P@)SHG*2(O/CQX<VPZ=&5X=#XZ/"]X<VPZ=&5X
M=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/CQX<VPZ=&5X=#X[(#PO>'-L
M.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI
M/2)S='EL93IT97AT+6)A8VMG<F]U;F0M8V]L;W(B)SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YB86-K9W)O=6YD+6-O;&]R.CPO
M>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX\>'-L.G1E>'0^
M.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG
M;F%M92@N*3TB9F\Z8F%C:V=R;W5N9"UC;VQO<B(G/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IT97AT/F)A8VMG<F]U;F0M8V]L;W(Z/"]X
M<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/CQX<VPZ=&5X=#X[
M(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H
M96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N
M86UE*"XI/2)S='EL93IB86-K9W)O=6YD+6EM86=E(B<^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^8F%C:V=R;W5N9"UI;6%G93IU
M<FPH/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB0'AL:6YK.FAR
M968B+SX\>'-L.G1E>'0^*3L@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`<W1Y;&4Z<F5P96%T(#T@
M)W)E<&5A="<B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G1E>'0^8F%C:V=R;W5N9"UR97!E870Z<F5P96%T.R`\+WAS;#IT
M97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H
M96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE
M<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=&5X=#YB86-K9W)O=6YD+7)E<&5A=#IN;RUR97!E870[(#PO>'-L.G1E
M>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H
M97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\(2TM('1E>'0M<VAA9&]W(&ES(&$@0U-3
M,B!F96%T=7)E(&%N9"!Y970@;F]T(&-O;6UO;B!U<V5D(&EN('5S97(M86=E
M;G1S("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TG;F%M92@N*3TB9F\Z=&5X="US:&%D;W<B)SX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I;F<M
M869T97(H;F%M92@N*2P@)SHG*2(O/CQX<VPZ=&5X=#XZ/"]X<VPZ=&5X=#X\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E
M>'0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)S
M='EL93IT97AT+6-R;W-S:6YG+6]U="(G/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#II9B!T97-T/2=N;W0H+CTB;F]N92(I)SX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^=&5X="UD96-O
M<F%T:6]N.FQI;F4M=&AR;W5G:#L@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TG;F%M92@N*3TB<W1Y;&4Z=&5X="UU;F1E<FQI;F4B)SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TG;F]T
M*"X](FYO;F4B*2<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IT97AT/G1E>'0M9&5C;W)A=&EO;CIU;F1E<FQI;F4[(#PO>'-L.G1E
M>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#II9CX*("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](G-T>6QE.G1E
M>'0M<&]S:71I;VXB)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ:68@=&5S=#TG8V]N=&%I;G,H+BP@(G-U8B(I)SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^=F5R=&EC86PM86QI9VXZ
M<W5B.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ:68^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF
M('1E<W0])V-O;G1A:6YS*"XL(")S=7`B*2<^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IT97AT/G9E<G1I8V%L+6%L:6=N.G-U<#L@
M/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.FEF/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\(2TM(&ES1&5B=6=-;V1E34534T%'13H*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/DYO('1R
M86YS9F]R;6%T:6]N(&EM<&QE;65N=&5D(&9O<B!A='1R:6)U=&4M='EP(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)N86UE*"XI(B\^/"]X<VPZ;65S<V%G93X*
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/BTM/@H@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@
M("`@(#PO>'-L.F9O<BUE86-H/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`\(2TM*RLK*RL@4$%,32`S+C(@4U5"4T54($%.1"!705`@
M4%)/4$525$E%4R`@*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IO=&AE<G=I
M<V4^"B`@("`@("`@("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB)'-T
M>6QE071T<FEB=71E4&%T:"(^"B`@("`@("`@("`@("`@("`@("`@/"$M+2!I
M<T1E8G5G36]D94U%4U-!1T4Z"B`@("`@("`@("`@("`@("`@("`@/'AS;#IM
M97-S86=E/B!.86UE.CQX<VPZ=F%L=64M;V8@<V5L96-T/2)N86UE*"DB+SX@
M5F%L=64Z/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX\+WAS;#IM97-S86=E
M/B`@("`@("TM/@H*("`@("`@("`@("`@("`@("`@("`\(2TM($)51R!73U)+
M($%23U5.1#H*("`@("`@("`@("`@("`@("`@("!$=64@=&\@82!B=6<@:6X@
M=&AE(%A4(%!R;V-E<W-O<BP@:70@:7,@;F]T('!O<W-I8FQE('1O(&-R96%T
M92!S97)V97)A;"!E;&5M96YT<R!I;B!V87)I86)L92!A;F0@<V5A<F-H(&]V
M97(@=&AE;2P*("`@("`@("`@("`@("`@("`@("!A9G1E<B!E>'!L:6-I="!C
M;VYV97)S:6]N('1O(&YO9&5S970*("`@("`@("`@("`@("`@("`@("!4:&ES
M(&=E;F5R871E9"!S=&EN9R!I9&5N=&EF:65R('-H86QL(&)E(&QA=&5R(&-H
M86YG960@8F%C:R!T;R!A('-E="!O9B!E;&5M96YT<PH@("`@("`@("`@("`@
M("`@("`@("TM/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\(2TM*BHJ($9/4DU!5"!!5%1224)5
M5$53("HJ*BTM/@H*("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!)=&%L
M:6,@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2=N86UE*"XI/2)F;SIF;VYT+7-T>6QE(B<^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.FEF('1E<W0](F-O;G1A:6YS*"XL("=I=&%L:6,G
M*2!O<B!C;VYT86EN<R@N+"`G;V)L:7%U92<I(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^:71A;&EC+"`\+WAS;#IT97AT
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ:68^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"@H@("`@("`@("`@("`@
M("`@("`@("`@("`\(2TM($)O;&1F86-E("TM/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TG;F%M92@N*3TB9F\Z9F]N="UW96EG
M:'0B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S
M=#TB8V]N=&%I;G,H+BP@)V)O;&0G*2!O<B!C;VYT86EN<R@N+"`G8F]L9&5R
M)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X
M=#YB;VQD+"`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ:68^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H
M96X^"@H@("`@("`@("`@("`@("`@("`@("`@("`\(2TM(%5N9&5R;&EN92`M
M+3X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA
M;64H+BD](G-T>6QE.G1E>'0M=6YD97)L:6YE(B<^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G1E>'0^=6YD97)L:6YE+"`\+WAS;#IT97AT
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H*("`@("`@
M("`@("`@("`@("`@("`@("`@/"$M+2!!;&EG;FUE;G0@+2T^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIT
M97AT+6%L:6=N(B<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](F-O;G1A:6YS*"XL("=S=&%R="<I(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/F%L:6=N.FQE
M9G0L(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H+BP@)V5N9"<I(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/F%L:6=N
M.G)I9VAT+"`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"XL("=C96YT97(G*2(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X
M=#YA;&EG;CIC96YT97(L(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.G=H96X^"@H@("`@("`@("`@("`@("`@("`@("`@("`\(2TM
M('-T<FEK971H<F]U9V@@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)S='EL93IT97AT+6-R;W-S:6YG+6]U
M="(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/G-T
M<FEK92P@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ=VAE;CX*"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@1F]N="`M
M('-I>F4@*%!A;&TZ(&5M=6QA=&]R('1R86YS9F]R;65D('-I>F5S('1O(&%V
M86EL86)L92!S970@*&4N9RX@,S`@=&\@*'!R;V)A8FQY*2`Y*2TM/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG;F%M92@N*3TB
M9F\Z9F]N="US:7IE(B<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G1E>'0^<VEZ93H\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T
M/2(N(B\^/'AS;#IT97AT/CIS:7IE+"`\+WAS;#IT97AT/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H*("`@("`@("`@("`@("`@("`@
M("`@("`@/"$M+2!&;VYT("T@0V]L;W(@*%!!3$TZ(&)U="!M;W-T;'D@;VYL
M>2`R(&%V86EL86)L92D*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)L
M86-K("@C,#`P,#`P*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@9W)A
M>2`H(S@P.#`X,"DH<F5N9&5R960@87,@9&%R:R!G<F%Y*0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<VEL=F5R("@C0S!#,$,P*2AR96YD97)E9"!A
M<R!L:6=H="!G<F%Y*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=VAI
M=&4@*"-&1D9&1D8I+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2=N86UE*"XI/2)F;SIC;VQO<B(G/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"X@+"`G
M(T9&1D9&1B<I(&]R(&-O;G1A:6YS*"X@+"`G(V9F9F9F9B<I(&]R(&-O;G1A
M:6YS*"X@+"`G=VAI=&4G*2!O<B!C;VYT86EN<R@N("P@)U=(251%)RDB/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^
M8V]L;W(Z(T9&1D9&1BP@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^8V]L;W(Z(S`P,#`P,"P@
M/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H
M96X^"@H*("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2HJ*B!404),12!!
M5%1224)55$53("HJ*BTM/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TG;F%M92@N*3TB9F\Z9F]N="US:7IE(B<^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^<VEZ93H\+WAS;#IT97AT
M/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT/CIS:7IE+"`\
M+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG;F%M
M92@N*3TB<W1Y;&4Z8V]L=6UN+7=I9'1H(B<^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\(2TM(&-H86YG:6YG('1H92!D:7-T86YC92!M96%S=7)E
M.B!I;F-H('1O(&EN("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@N+"`G8V@G*2(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YW:61T
M:#H\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I;F<M
M8F5F;W)E*"XL)V-H)RDB+SX\>'-L.G1E>'0^.G=I9'1H+"`\+WAS;#IT97AT
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I
M<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=&5X=#YW:61T:#H\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N
M(B\^/'AS;#IT97AT/CIW:61T:#L@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)S='EL93IR;W<M:&5I9VAT
M(B<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM(&-H86YG:6YG
M('1H92!D:7-T86YC92!M96%S=7)E.B!I;F-H('1O(&EN("TM/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT
M86EN<R@N+"`G8V@G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=&5X=#YH96EG:'0Z/"]X<VPZ=&5X=#X\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB<W5B<W1R:6YG+6)E9F]R92@N+"=C:"<I(B\^/'AS;#IT
M97AT/CIH96EG:'0[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/FAE:6=H=#H\+WAS;#IT97AT
M/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT/CIH96EG:'0[
M(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG
M;F%M92@N*3TB<W1Y;&4Z=VED=&@B)SX@/"$M+65A<FQI97(@9F\Z=VED=&@M
M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@8VAA;F=I;F<@
M=&AE(&1I<W1A;F-E(&UE87-U<F4Z(&EN8V@@=&\@:6X@+2T^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A
M:6YS*"XL("=C:"<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IT97AT/G=I9'1H.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO
M9B!S96QE8W0](G-U8G-T<FEN9RUB969O<F4H+BPG8V@G*2(O/CQX<VPZ=&5X
M=#XZ=VED=&@[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IT97AT/G=I9'1H.CPO>'-L.G1E>'0^/'AS
M;#IV86QU92UO9B!S96QE8W0](BXB+SX\>'-L.G1E>'0^.G=I9'1H.R`\+WAS
M;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@
M("`@("`\+WAS;#IF;W(M96%C:#X*("`@("`@("`@("`@/"]X<VPZ;W1H97)W
M:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E
M/@H*"@H\(2TM(#)$3SH@3D%-24Y'($-/3E9%3E1)3TX@=F%R:6%B;&4@87)E
M('=R:71T96X@=VET:"`G+2<@:6YS=&5A9"!O9B!C87-E+7-E;G-I=&EV92!W
M<FET:6YG("TM/@H*"@H@("`@/"$M+2`J*BHJ*B!-14%355)%345.5"!#3TY6
M15)324].4R`J*BHJ*@H*("`@("`J(#$@8V5N=&EM971E<B`](#$P(&UM"@H@
M("`@("H@,2!I;F-H(#T@,C4N-"!M;0H@("`@("`@(%=H:6QE('1H92!%;F=L
M:7-H(&AA=F4@86QR96%D>2!S965N('1H92!L:6=H="`H<F5A9#H@=&AE(&UE
M=')I8R!S>7-T96TI+"!T:&4@55,*("`@("`@("!R96UA:6YS(&QO>6%L('1O
M('1H:7,@;65D:65V86P@<WES=&5M+@H*("`@("`J(#$@9&ED;W0@<&]I;G0@
M/2`P+C,W-C`V-2!M;0H@("`@("`@("`@("!4:&4@9&ED;W0@<WES=&5M(&]R
M:6=I;F%T960@:6X@1G)A;F-E(&)U="!W87,@=7-E9"!I;B!M;W-T(&]F($5U
M<F]P90H*("`@("`J(#$@<&EC82!P;VEN="`](#`N,S4Q-#8@;6T*("`@("`@
M("`@("`@5&AE(%!I8V$@<&]I;G1S('-Y<W1E;2!W87,@9&5V96QO<&5D(&EN
M($5N9VQA;F0@86YD(&ES('5S960@:6X@1W)E870M0G)I=&%I;B!A;F0@=&AE
M(%53+@H*("`@("`J(#$@4&]S=%-C<FEP="!P;VEN="`](#`N,S4R-S<Q,S@@
M;6T*("`@("`@("`@("`@5VAE;B!!9&]B92!C<F5A=&5D(%!O<W138W)I<'0L
M('1H97D@861D960@=&AE:7(@;W=N('-Y<W1E;2!O9B!P;VEN=',N"B`@("`@
M("`@("`@(%1H97)E(&%R92!E>&%C=&QY(#<R(%!O<W138W)I<'0@<&]I;G1S
M(&EN(#$@:6YC:"X*"B`@("`@*B`Q('!I>&5L(#T@,"XR-C0U.#,S,RXN(&UM
M("`@*&)Y(#DV(&1P:2D*("`@("`@("`@("`@36]S="!P:6-T=7)E<R!H879E
M('1H92`Y-B!D<&D@<F5S;VQU=&EO;BP@8G5T('1H92!D<&D@=F%R:6%B;&4@
M;6%Y('9A<GD@8GD@<W1Y;&5S:&5E="!P87)A;65T97(*("`@("TM/@H*"B`@
M("`\(2TM(&-H86YG:6YG(&UE87-U<F4@=&\@;6T@+2T^"B`@("`\>'-L.G1E
M;7!L871E(&YA;64](F-O;G9E<G0R;6TB/@H@("`@("`@(#QX<VPZ<&%R86T@
M;F%M93TB=F%L=64B+SX*"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C96YT
M:6UE=&5R+6EN+6UM(B`@("`@("`@("!S96QE8W0](C$P(B\^"B`@("`@("`@
M/'AS;#IP87)A;2!N86UE/2)I;F-H+6EN+6UM(B`@("`@("`@("`@("`@("!S
M96QE8W0](C(U+C0B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F1I9&]T
M+7!O:6YT+6EN+6UM(B`@("`@("`@('-E;&5C=#TB,"XS-S8P-C4B+SX*("`@
M("`@("`\>'-L.G!A<F%M(&YA;64](G!I8V$M<&]I;G0M:6XM;6TB("`@("`@
M("`@('-E;&5C=#TB,"XS-3$T-B(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1V86QU92P@
M)V-M)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0]
M(G)O=6YD*&YU;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1V86QU92PG8VTG("DI
M("H@)&-E;G1I;65T97(M:6XM;6TI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H
M96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D=F%L
M=64L("=I;B<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2)R;W5N9"AN=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=F%L=64L)VEN
M)R`I*2`J("1I;F-H+6EN+6UM*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A;'5E
M+"`G9'!T)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE
M8W0](G)O=6YD*&YU;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1V86QU92PG9'!T
M)RDI("H@)&1I9&]T+7!O:6YT+6EN+6UM*2(O/@H@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H
M)'9A;'5E+"`G<'!T)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](G)O=6YD*&YU;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1V86QU
M92PG<'!T)RDI("H@)'!I8V$M<&]I;G0M:6XM;6TI(B\^"B`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1V86QU92(O/@H@
M("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#PA+2T@8VAA;F=I;F<@
M;65A<W5R92!T;R!C;2`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB8V]N
M=F5R=#)C;2(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)V86QU92(O/@H*
M("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-E;G1I;65T97(M:6XM;6TB("`@
M("`@("`@('-E;&5C=#TB,3`B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(FEN8V@M:6XM;6TB("`@("`@("`@("`@("`@('-E;&5C=#TB,C4N-"(O/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB9&ED;W0M<&]I;G0M:6XM;6TB("`@
M("`@("`@<V5L96-T/2(P+C,W-C`V-2(O/@H@("`@("`@(#QX<VPZ<&%R86T@
M;F%M93TB<&EC82UP;VEN="UI;BUM;2(@("`@("`@("`@<V5L96-T/2(P+C,U
M,30V(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A;'5E+"`G;6TG*2(^"B`@("`@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U
M8G-T<FEN9RUB969O<F4H)'9A;'5E+"`G;6TG*2D@9&EV("1C96YT:6UE=&5R
M+6EN+6UM*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A;'5E+"`G:6XG*2(^"B`@
M("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U;F0H;G5M
M8F5R*'-U8G-T<FEN9RUB969O<F4H)'9A;'5E+"`G:6XG*2D@9&EV("1C96YT
M:6UE=&5R+6EN+6UM("H@)&EN8V@M:6XM;6TI(B\^"B`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN
M<R@D=F%L=64L("=D<'0G*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H)'9A
M;'5E+"=D<'0G*2D@9&EV("1C96YT:6UE=&5R+6EN+6UM("H@)&1I9&]T+7!O
M:6YT+6EN+6UM*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A;'5E+"`G<'!T)RDB
M/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G)O=6YD
M*&YU;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1V86QU92PG<'!T)RDI(&1I=B`D
M8V5N=&EM971E<BUI;BUM;2`J("1P:6-A+7!O:6YT+6EN+6UM*2(O/@H@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES
M93X*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D=F%L
M=64B+SX*("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO
M>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*("`@(#PA+2T@8VAA
M;F=I;F<@;65A<W5R92!T;R!I;F-H("AC<"X@<V5C=&EO;B!C;VUM96YT*2`M
M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB8V]N=F5R=#)I;F-H(CX*("`@
M("`@("`\>'-L.G!A<F%M(&YA;64](G9A;'5E(B\^"@H@("`@("`@(#QX<VPZ
M<&%R86T@;F%M93TB8V5N=&EM971E<BUI;BUM;2(@("`@("`@("`@<V5L96-T
M/2(Q,"(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB:6YC:"UI;BUM;2(@
M("`@("`@("`@("`@("`@<V5L96-T/2(R-2XT(B\^"B`@("`@("`@/'AS;#IP
M87)A;2!N86UE/2)D:61O="UP;VEN="UI;BUM;2(@("`@("`@("!S96QE8W0]
M(C`N,S<V,#8U(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)P:6-A+7!O
M:6YT+6EN+6UM(B`@("`@("`@("!S96QE8W0](C`N,S4Q-#8B+SX*"B`@("`@
M("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C
M;VYT86EN<R@D=F%L=64L("=M;2<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2)R;W5N9"AN=6UB97(H<W5B<W1R:6YG+6)E9F]R
M92@D=F%L=64L("=M;2<I*2!D:78@)&EN8V@M:6XM;6TI(B\^"B`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C
M;VYT86EN<R@D=F%L=64L("=C;2<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2)R;W5N9"AN=6UB97(H<W5B<W1R:6YG+6)E9F]R
M92@D=F%L=64L("=C;2<I*2!D:78@)&EN8V@M:6XM;6T@*B`D8V5N=&EM971E
M<BUI;BUM;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1V86QU92P@)V1P="<I(CX*
M("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)R;W5N9"AN
M=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=F%L=64L)V1P="<I*2!D:78@)&EN
M8V@M:6XM;6T@*B`D9&ED;W0M<&]I;G0M:6XM;6TI(B\^"B`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT
M86EN<R@D=F%L=64L("=P<'0G*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H
M)'9A;'5E+"=P<'0G*2D@9&EV("1I;F-H+6EN+6UM("H@)'!I8V$M<&]I;G0M
M:6XM;6TI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](B1V86QU92(O/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I
M<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^
M"@H*("`@(#PA+2T@8VAA;F=I;F<@;65A<W5R92!T;R!D<'0@*&-P+B!S96-T
M:6]N(&-O;6UE;G0I("TM/@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)C;VYV
M97)T,F1P="(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)V86QU92(O/@H*
M("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-E;G1I;65T97(M:6XM;6TB("`@
M("`@("`@('-E;&5C=#TB,3`B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(FEN8V@M:6XM;6TB("`@("`@("`@("`@("`@('-E;&5C=#TB,C4N-"(O/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB9&ED;W0M<&]I;G0M:6XM;6TB("`@
M("`@("`@<V5L96-T/2(P+C,W-C`V-2(O/@H@("`@("`@(#QX<VPZ<&%R86T@
M;F%M93TB<&EC82UP;VEN="UI;BUM;2(@("`@("`@("`@<V5L96-T/2(P+C,U
M,30V(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A;'5E+"`G;6TG*2(^"B`@("`@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U
M8G-T<FEN9RUB969O<F4H)'9A;'5E+"`G;6TG*2D@9&EV("1D:61O="UP;VEN
M="UI;BUM;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1V86QU92P@)V-M)RDB/@H@
M("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G)O=6YD*&YU
M;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1V86QU92P@)V-M)RDI(&1I=B`D9&ED
M;W0M<&]I;G0M:6XM;6T@*B`D8V5N=&EM971E<BUI;BUM;2DB+SX*("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(F-O;G1A:6YS*"1V86QU92P@)VEN)RDB/@H@("`@("`@("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](G)O=6YD*&YU;6)E<BAS=6)S=')I;F<M8F5F
M;W)E*"1V86QU92P@)VEN)RDI(&1I=B`D9&ED;W0M<&]I;G0M:6XM;6T@*B`D
M:6YC:"UI;BUM;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1V86QU92P@)W!P="<I
M(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)R;W5N
M9"AN=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=F%L=64L)W!P="<I*2!D:78@
M)&1I9&]T+7!O:6YT+6EN+6UM("H@)'!I8V$M<&]I;G0M:6XM;6TI(B\^"B`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1V
M86QU92(O/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@
M/"]X<VPZ8VAO;W-E/@H*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\(2TM
M(&-H86YG:6YG(&UE87-U<F4@=&\@<'!T("AC<"X@<V5C=&EO;B!C;VUM96YT
M*2`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB8V]N=F5R=#)P<'0B/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB=F%L=64B+SX*"B`@("`@("`@/'AS
M;#IP87)A;2!N86UE/2)C96YT:6UE=&5R+6EN+6UM(B`@("`@("`@("!S96QE
M8W0](C$P(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)I;F-H+6EN+6UM
M(B`@("`@("`@("`@("`@("!S96QE8W0](C(U+C0B+SX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](F1I9&]T+7!O:6YT+6EN+6UM(B`@("`@("`@('-E;&5C
M=#TB,"XS-S8P-C4B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G!I8V$M
M<&]I;G0M:6XM;6TB("`@("`@("`@('-E;&5C=#TB,"XS-3$T-B(O/@H*("`@
M("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(F-O;G1A:6YS*"1V86QU92P@)VUM)RDB/@H@("`@("`@("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](G)O=6YD*&YU;6)E<BAS=6)S=')I;F<M8F5F
M;W)E*"1V86QU92P@)VUM)RDI(&1I=B`D<&EC82UP;VEN="UI;BUM;2DB+SX*
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](F-O;G1A:6YS*"1V86QU92P@)V-M)RDB/@H@("`@("`@("`@("`@
M("`@/'AS;#IV86QU92UO9B!S96QE8W0](G)O=6YD*&YU;6)E<BAS=6)S=')I
M;F<M8F5F;W)E*"1V86QU92P@)V-M)RDI(&1I=B`D<&EC82UP;VEN="UI;BUM
M;2`J("1C96YT:6UE=&5R+6EN+6UM*2(O/@H@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A
M;'5E+"`G:6XG*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB<F]U;F0H;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H)'9A;'5E+"`G
M:6XG*2D@9&EV("1P:6-A+7!O:6YT+6EN+6UM("H@)&EN8V@M:6XM;6TI(B\^
M"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2)C;VYT86EN<R@D=F%L=64L("=D<'0G*2(^"B`@("`@("`@("`@
M("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U8G-T
M<FEN9RUB969O<F4H)'9A;'5E+"=D<'0G*2D@9&EV("1P:6-A+7!O:6YT+6EN
M+6UM("H@)&1I9&]T+7!O:6YT+6EN+6UM*2(O/@H@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@
M("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D=F%L=64B+SX*("`@("`@
M("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*
M("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\(2TM(&-H86YG:6YG(&UE87-U
M<F4@=&\@<&EX96P@8GD@=FEA('!A<F%M971E<B!P<F]V:61E9"!D<&D@*&1O
M=',@<&5R(&EN8V@I('-T86YD87)D(&9A8W1O<B`H8W`N('-E8W1I;VX@8V]M
M;65N="D@+2T^"B`@("`\>'-L.G1E;7!L871E(&YA;64](F-O;G9E<G0R<&EX
M96PB/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB=F%L=64B+SX*"B`@("`@
M("`@/'AS;#IP87)A;2!N86UE/2)C96YT:6UE=&5R+6EN+6UM(B`@("`@("`@
M("!S96QE8W0](C$P(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)I;F-H
M+6EN+6UM(B`@("`@("`@("`@("`@("!S96QE8W0](C(U+C0B+SX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](F1I9&]T+7!O:6YT+6EN+6UM(B`@("`@("`@
M('-E;&5C=#TB,"XS-S8P-C4B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(G!I8V$M<&]I;G0M:6XM;6TB("`@("`@("`@('-E;&5C=#TB,"XS-3$T-B(O
M/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<&EX96PM:6XM;6TB("`@("`@
M("`@("`@("`@<V5L96-T/2(D:6YC:"UI;BUM;2!D:78@)&1P:2(O/@H*("`@
M("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(F-O;G1A:6YS*"1V86QU92P@)VUM)RDB/@H@("`@("`@("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](G)O=6YD*&YU;6)E<BAS=6)S=')I;F<M8F5F
M;W)E*"1V86QU92P@)VUM)RDI(&1I=B`D<&EX96PM:6XM;6TI(B\^"B`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)C;VYT86EN<R@D=F%L=64L("=C;2<I(CX*("`@("`@("`@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)R;W5N9"AN=6UB97(H<W5B<W1R:6YG+6)E
M9F]R92@D=F%L=64L("=C;2<I*2!D:78@)'!I>&5L+6EN+6UM("H@)&-E;G1I
M;65T97(M:6XM;6TI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D=F%L=64L("=I;B<I
M(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)R;W5N
M9"AN=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=F%L=64L("=I;B<I*2!D:78@
M)'!I>&5L+6EN+6UM("H@)&EN8V@M:6XM;6TI(B\^"B`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN
M<R@D=F%L=64L("=D<'0G*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H)'9A
M;'5E+"=D<'0G*2D@9&EV("1P:7AE;"UI;BUM;2`J("1D:61O="UP;VEN="UI
M;BUM;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB)'9A;'5E(B\^"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES
M93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*
M"CPO>'-L.G-T>6QE<VAE970^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O;V]O+W1A8FQE+GAS;```````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#0S-S`P`#$P-3$U-#,S-S0W`#`R-#`W-P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\(2TM
M"@H@("!4:&4@0V]N=&5N=',@;V8@=&AI<R!F:6QE(&%R92!M861E(&%V86EL
M86)L92!S=6)J96-T('1O('1H92!T97)M<R!O9@H@("!E:71H97(@;V8@=&AE
M(&9O;&QO=VEN9R!L:6-E;G-E<PH*("`@("`@("`@("T@1TY5($QE<W-E<B!'
M96YE<F%L(%!U8FQI8R!,:6-E;G-E(%9E<G-I;VX@,BXQ"B`@("`@("`@("`M
M(%-U;B!);F1U<W1R>2!3=&%N9&%R9',@4V]U<F-E($QI8V5N<V4@5F5R<VEO
M;B`Q+C$*"B`@(%-U;B!-:6-R;W-Y<W1E;7,@26YC+BP@3V-T;V)E<BP@,C`P
M,`H*("`@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(%9E<G-I
M;VX@,BXQ"B`@(#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/0H@("!#;W!Y<FEG:'0@,C`P,"!B>2!3=6X@36EC<F]S>7-T
M96US+"!);F,N"B`@(#DP,2!386X@06YT;VYI;R!2;V%D+"!086QO($%L=&\L
M($-!(#DT,S`S+"!54T$*"B`@(%1H:7,@;&EB<F%R>2!I<R!F<F5E('-O9G1W
M87)E.R!Y;W4@8V%N(')E9&ES=')I8G5T92!I="!A;F0O;W(*("`@;6]D:69Y
M(&ET('5N9&5R('1H92!T97)M<R!O9B!T:&4@1TY5($QE<W-E<B!'96YE<F%L
M(%!U8FQI8PH@("!,:6-E;G-E('9E<G-I;VX@,BXQ+"!A<R!P=6)L:7-H960@
M8GD@=&AE($9R964@4V]F='=A<F4@1F]U;F1A=&EO;BX*"B`@(%1H:7,@;&EB
M<F%R>2!I<R!D:7-T<FEB=71E9"!I;B!T:&4@:&]P92!T:&%T(&ET('=I;&P@
M8F4@=7-E9G5L+`H@("!B=70@5TE42$]55"!!3ED@5T%24D%.5%D[('=I=&AO
M=70@979E;B!T:&4@:6UP;&EE9"!W87)R86YT>2!O9@H@("!-15)#2$%.5$%"
M24Q)5%D@;W(@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/4T4N("!3
M964@=&AE($=.50H@("!,97-S97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!F
M;W(@;6]R92!D971A:6QS+@H*("`@66]U('-H;W5L9"!H879E(')E8V5I=F5D
M(&$@8V]P>2!O9B!T:&4@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8PH@("!,
M:6-E;G-E(&%L;VYG('=I=&@@=&AI<R!L:6)R87)Y.R!I9B!N;W0L('=R:71E
M('1O('1H92!&<F5E(%-O9G1W87)E"B`@($9O=6YD871I;VXL($EN8RXL(#4Y
M(%1E;7!L92!0;&%C92P@4W5I=&4@,S,P+"!";W-T;VXL"B`@($U!("`P,C$Q
M,2TQ,S`W("!54T$*"@H@("!3=6X@26YD=7-T<GD@4W1A;F1A<F1S(%-O=7)C
M92!,:6-E;G-E(%9E<G-I;VX@,2XQ"B`@(#T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*("`@5&AE(&-O;G1E;G1S
M(&]F('1H:7,@9FEL92!A<F4@<W5B:F5C="!T;R!T:&4@4W5N($EN9'5S=')Y
M(%-T86YD87)D<PH@("!3;W5R8V4@3&EC96YS92!697)S:6]N(#$N,2`H=&AE
M("),:6-E;G-E(BD[(%EO=2!M87D@;F]T('5S92!T:&ES(&9I;&4*("`@97AC
M97!T(&EN(&-O;7!L:6%N8V4@=VET:"!T:&4@3&EC96YS92X@66]U(&UA>2!O
M8G1A:6X@82!C;W!Y(&]F('1H90H@("!,:6-E;G-E(&%T(&AT='`Z+R]W=W<N
M;W!E;F]F9FEC92YO<F<O;&EC96YS92YH=&UL+@H*("`@4V]F='=A<F4@<')O
M=FED960@=6YD97(@=&AI<R!,:6-E;G-E(&ES('!R;W9I9&5D(&]N(&%N(")!
M4R!)4R(@8F%S:7,L"B`@(%=)5$A/550@5T%24D%.5%D@3T8@04Y9($M)3D0L
M($5)5$A%4B!%6%!215-3($]2($E-4$Q)140L($E.0TQ51$E.1RP*("`@5TE4
M2$]55"!,24U)5$%424].+"!705)204Y42453(%1(050@5$A%(%-/1E1705)%
M($E3($92144@3T8@1$5&14-44RP*("`@34520TA!3E1!0DQ%+"!&250@1D]2
M($$@4$%25$E#54Q!4B!055)03U-%+"!/4B!.3TXM24Y&4DE.1TE.1RX*("`@
M4V5E('1H92!,:6-E;G-E(&9O<B!T:&4@<W!E8VEF:6,@<')O=FES:6]N<R!G
M;W9E<FYI;F<@>6]U<B!R:6=H=',@86YD"B`@(&]B;&EG871I;VYS(&-O;F-E
M<FYI;F<@=&AE(%-O9G1W87)E+@H*("`@5&AE($EN:71I86P@1&5V96QO<&5R
M(&]F('1H92!/<FEG:6YA;"!#;V1E(&ES.B!3=6X@36EC<F]S>7-T96US+"!)
M;F,N"@H@("!#;W!Y<FEG:'0@PJD@,C`P,B!B>2!3=6X@36EC<F]S>7-T96US
M+"!);F,N"@H@("!!;&P@4FEG:'1S(%)E<V5R=F5D+@H*("`@0V]N=')I8G5T
M;W(H<RDZ(%]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7PH*+2T^"CQX<VPZ<W1Y;&5S:&5E="!V97)S:6]N/2(Q+C`B"B`@("`@("`@
M("`@("`@("!X;6QN<SIX<VP](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3DO6%-,
M+U1R86YS9F]R;2(*("`@("`@("`@("`@("`@('AM;&YS.F]F9FEC93TB:'1T
M<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O;V9F:6-E(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z<W1Y;&4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W-T
M>6QE(@H@("`@("`@("`@("`@("`@>&UL;G,Z=&5X=#TB:'1T<#HO+V]P96YO
M9F9I8V4N;W)G+S(P,#`O=&5X="(*("`@("`@("`@("`@("`@('AM;&YS.G1A
M8FQE/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]T86)L92(*("`@("`@
M("`@("`@("`@('AM;&YS.F1R87<](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R
M,#`P+V1R87=I;F<B"B`@("`@("`@("`@("`@("!X;6QN<SIF;STB:'1T<#HO
M+W=W=RYW,RYO<F<O,3DY.2]84TPO1F]R;6%T(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z>&QI;FL](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3DO>&QI;FLB"B`@
M("`@("`@("`@("`@("!X;6QN<SIN=6UB97(](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`P+V1A=&%S='EL92(*("`@("`@("`@("`@("`@('AM;&YS.G-V
M9STB:'1T<#HO+W=W=RYW,RYO<F<O,C`P,"]S=F<B"B`@("`@("`@("`@("`@
M("!X;6QN<SIC:&%R=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O8VAA
M<G0B"B`@("`@("`@("`@("`@("!X;6QN<SID<C-D/2)H='1P.B\O;W!E;F]F
M9FEC92YO<F<O,C`P,"]D<C-D(@H@("`@("`@("`@("`@("`@>&UL;G,Z;6%T
M:#TB:'1T<#HO+W=W=RYW,RYO<F<O,3DY."]-871H+TUA=&A-3"(*("`@("`@
M("`@("`@("`@('AM;&YS.F9O<FT](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R
M,#`P+V9O<FTB"B`@("`@("`@("`@("`@("!X;6QN<SIS8W)I<'0](FAT='`Z
M+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W-C<FEP="(*("`@("`@("`@("`@("`@
M(&]F9FEC93IC;&%S<STB=&5X="(*("`@("`@("`@("`@("`@(&]F9FEC93IV
M97)S:6]N/2(Q+C`B"B`@("`@("`@("`@("`@("!X;6QN<SID8STB:'1T<#HO
M+W!U<FPN;W)G+V1C+V5L96UE;G1S+S$N,2\B"B`@("`@("`@("`@("`@("!X
M;6QN<SIM971A/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]M971A(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z8V]N9FEG/2)H='1P.B\O;W!E;F]F9FEC
M92YO<F<O,C`P,2]C;VYF:6<B"B`@("`@("`@("`@("`@("!X;6QN<SIH96QP
M/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]H96QP(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z>'0](FAT='`Z+R]W=W<N:F-L87)K+F-O;2]X="(*("`@
M("`@("`@("`@("`@('AM;&YS.G-Y<W1E;3TB:'1T<#HO+W=W=RYJ8VQA<FLN
M8V]M+WAT+VIA=F$O:F%V82YL86YG+E-Y<W1E;2(*("`@("`@("`@("`@("`@
M('AM;&YS.GAA;&%N/2)H='1P.B\O>&UL+F%P86-H92YO<F<O>&%L86XB"B`@
M("`@("`@("`@("`@("!X;6QN<SIJ879A/2)H='1P.B\O>&UL+F%P86-H92YO
M<F<O>'-L="]J879A(@H@("`@("`@("`@("`@("`@97AC;'5D92UR97-U;'0M
M<')E9FEX97,](FIA=F$B/@H*"B`@("`\(2TM('1A8FQE(')O=R!H86YD;&EN
M9R`M+3X*("`@(#QX<VPZ:6YC;'5D92!H<F5F/2)T86)L95]R;W=S+GAS;"(O
M/@H@("`@/"$M+2!T86)L92!C;VQU;6X@:&%N9&QI;F<@+2T^"B`@("`\>'-L
M.FEN8VQU9&4@:')E9CTB=&%B;&5?8V]L=6UN<RYX<VPB+SX*("`@(#PA+2T@
M=&%B;&4@8V5L;"!H86YD;&EN9R`M+3X*("`@(#QX<VPZ:6YC;'5D92!H<F5F
M/2)T86)L95]C96QL<RYX<VPB+SX*"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ(&UA:6X@=&%B;&4@("HJ*B`M+3X*
M("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"B`@("`\>'-L.G1E
M;7!L871E(&UA=&-H/2)T86)L93IT86)L92!\('1A8FQE.G-U8BUT86)L92(^
M"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A
M(B\^"@H@("`@("`@(#PA+2T@82!T86)L92!W:6QL(&]N;'D@8F4@8W)E871E
M9"!I9B!T:&4@(G-C96YA<FEO(B!I<R!A8W1I=F4@+2T^"B`@("`@("`@/'AS
M;#II9B!T97-T/2)S=')I;F<M;&5N9W1H*'1A8FQE.G-C96YA<FEO+T!T86)L
M93II<RUA8W1I=F4I(#T@,"(^"B`@("`@("`@("`@(#PA+2T@8V]L;&5C=&EN
M9R!A;&P@=FES:6)L92`B=&%B;&4Z=&%B;&4M<F]W(B!E;&5M96YT<R!O9B!T
M:&4@=&%B;&4@+2T^"B`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB
M86QL5FES:6)L951A8FQE4F]W<R(@<V5L96-T/2)T86)L93IT86)L92UR;W=;
M;F]T*$!T86)L93IV:7-I8FEL:71Y(#T@)V-O;&QA<'-E)R!O<B!`=&%B;&4Z
M=FES:6)I;&ET>2`]("=F:6QT97(G*5T*("`@("`@("`@("`@("`@("`@("!\
M("`@('1A8FQE.G1A8FQE+6AE861E<BUR;W=S+V1E<V-E;F1A;G0Z.G1A8FQE
M.G1A8FQE+7)O=UMN;W0H0'1A8FQE.G9I<VEB:6QI='D@/2`G8V]L;&%P<V4G
M(&]R($!T86)L93IV:7-I8FEL:71Y(#T@)V9I;'1E<B<I70H@("`@("`@("`@
M("`@("`@("`@('P@("`@=&%B;&4Z=&%B;&4M<F]W+6=R;W5P+V1E<V-E;F1A
M;G0Z.G1A8FQE.G1A8FQE+7)O=UMN;W0H0'1A8FQE.G9I<VEB:6QI='D@/2`G
M8V]L;&%P<V4G(&]R($!T86)L93IV:7-I8FEL:71Y(#T@)V9I;'1E<B<I72(O
M/@H@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@(#PA
M+2T@9F]R(&%L;"!B=70@5T%0+U=-3"!D979I8V5S(&$@=&%B;&4@8F]R9&5R
M(&-H96-K(&ES(&1O;F4@*&-P+B`B8VAE8VLM9F]R+71A8FQE+6)O<F1E<B(I
M("TM/@H@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](FYO="@D;W5T
M<'5T5'EP92`]("=734PG*2(^"@H@("`@("`@("`@("`@("`@("`@(#PA+2T@
M07,@=&AE(&%L:6=N;65N="!O9B!A('1A8FQE(&ES(&)Y("=A;&EG;B<@871T
M<FEB=70@:7,@9&5P<F5C871E9"!A;F0@87,@=&AE($-34R`G9FQO870G(&%T
M=')I8G5T92!N;W0@=V5L;"!D:7-P;&%Y960L"B`@("`@("`@("`@("`@("`@
M("`@("`@("!W92!D;R!A(&QI='1L92!T<FEC:R!B>2!E;F-A<'-U;&%T:6YG
M('1H92!T86)L92!W:71H(&$@86QI9VYE9"`G9&EV)R!E;&5M96YT+2T^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)T86)L92UA
M;&EG;FUE;G0B('-E;&5C=#TB)&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S+W-T
M>6QE.G-T>6QE6T!S='EL93IN86UE(#T@8W5R<F5N="@I+T!T86)L93IS='EL
M92UN86UE72]S='EL93IP<F]P97)T:65S+T!T86)L93IA;&EG;B(O/@H*("`@
M("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0](G-T<FEN9RUL96YG=&@H)'1A8FQE
M+6%L:6=N;65N="D@(3T@,"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F5L96UE;G0@;F%M93TB9&EV(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)A;&EG;B(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0])R1T86)L92UA;&EG;FUE;G0](FQE9G0B(&]R("1T86)L
M92UA;&EG;FUE;G0](FUA<F=I;G,B)SX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/FQE9G0\+WAS
M;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2<D=&%B;&4M86QI9VYM96YT/2)R
M:6=H="(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=&5X=#YR:6=H=#PO>'-L.G1E>'0^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0])R1T86)L92UA;&EG;FUE;G0](F-E;G1E<B(G/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YC
M96YT97(\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB=&%B;&4B
M/@H*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA
M<'!L>2UT96UP;&%T97,@<V5L96-T/2)`=&%B;&4Z<W1Y;&4M;F%M92(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D
M8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM('=O<FMA<F]U;F0L
M('-E="!T86)L92!B;W)D97(@871T<FEB=70@:68@86YY(&-E;&PM8F]R9&5R
M(&5X:7-T<PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8VAE8VLM9F]R+71A8FQE+6)O<F1E
M<B(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB86QL5FES:6)L951A8FQE4F]W<R(@<V5L
M96-T/2(D86QL5FES:6)L951A8FQE4F]W<R(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/B`M+3X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64](F-R96%T92UC;VQU;6XM<W1Y;&4M=F%R:6%B;&4B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F%L;%9I<VEB;&5486)L95)O=W,B('-E;&5C
M=#TB)&%L;%9I<VEB;&5486)L95)O=W,B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C
M;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$
M871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT
M(&YA;64](G1A8FQE(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F%P<&QY+71E;7!L871E<R!S96QE8W0](D!T86)L93IS='EL92UN
M86UE(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C
M=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@=V]R:V%R;W5N9"P@<V5T
M('1A8FQE(&)O<F1E<B!A='1R:6)U="!I9B!A;GD@8V5L;"UB;W)D97(@97AI
M<W1S"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64](F-H96-K+69O<BUT86)L92UB;W)D97(B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB86QL5FES:6)L951A8FQE4F]W<R(@<V5L96-T/2(D86QL5FES
M:6)L951A8FQE4F]W<R(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^("`M+3X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8W)E
M871E+6-O;'5M;BUS='EL92UV87)I86)L92(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q6
M:7-I8FQE5&%B;&52;W=S(B!S96QE8W0](B1A;&Q6:7-I8FQE5&%B;&52;W=S
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T
M/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ8VAO;W-E/@H*("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@
M("`@(#PA+2T@9F]R(%=-3"!D979I8V5S(&]N;'D@05-#24D@=&%B;&4@87)E
M('=R:71T96X@87,@=&%B;&5S(&%R92!N;W0@:6UP;&5M96YT960@=VED;&5Y
M+@H@("`@("`@("`@("`@("`@("`@("!"96=I;FYI;F<@9G)O;2`G<F5P96%T
M+7=R:71E+7)O=R<@=&AE('1E;7!L871E<R!A<F4@:&%N9&QE9"!B>2!T:&4@
M=&%B;&5?=VUL+GAS;"!S='EL97-H965T("TM/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C<F5A=&4M8V]L=6UN+7-T
M>6QE+79A<FEA8FQE(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B("`@<V5L96-T
M/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL5FES:6)L951A8FQE4F]W
M<R(@('-E;&5C=#TB)&%L;%9I<VEB;&5486)L95)O=W,B+SX*("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`\+WAS;#IC:&]O<V4^
M"B`@("`@("`@/"]X<VPZ:68^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*("`@
M(#QX<VPZ=&5M<&QA=&4@;F%M93TB8W)E871E+6-O;'5M;BUS='EL92UV87)I
M86)L92(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B
M86Q$871A(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)A;&Q6:7-I8FQE
M5&%B;&52;W=S(B\^"@H@("`@("`@(#PA+2T@86QL(&-O;'5M;G,@;V8@=&AE
M('1A8FQE("TM/@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB86QL5&%B
M;&5#;VQU;6YS(B!S96QE8W0](G1A8FQE.G1A8FQE+6-O;'5M;B!\"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@=&%B;&4Z=&%B;&4M8V]L=6UN+6=R;W5P+V1E<V-E;F1A;G0Z.G1A8FQE
M.G1A8FQE+6-O;'5M;B!\"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=&%B;&4Z=&%B;&4M:&5A9&5R+6-O
M;'5M;G,O9&5S8V5N9&%N=#HZ=&%B;&4Z=&%B;&4M8V]L=6UN(B\^"B`@("`@
M("`@/"$M+2!A;&Q#;VQU;6Y3='EL945N=')I97,Z($-O;G1A:6YI;F<@86QL
M(&-O;'5M;G,@;V8@=&AE('1A8FQE+"!H:61D96X@86YD('9I97=E9"X*("`@
M("`@("`@("`@+2!I9B!A(&-O;'5M;B!I<R!H:61D96XL(&ET(&-O;G1A:6YS
M('1H92!H:61D96X@871T<FEB=71E+"!O=&AE<G=I<V4@=&AE('-T>6QE+7!R
M;W!E<G1I97,@=VEL;"!B92!S=&]R960*("`@("`@("`@("`@+2!I9B!A(&-O
M;'5M;B!I<R!B96EN9R!R97!E871E9"P@96%C:"!R97!E871E9"!C;VQU;6X@
M:7,@97AP;&EC:71L>2!W<FET=&5N(&%S(&5N=')Y(&EN('1H:7,@=F%R:6%B
M;&4N"B`@("`@("`@("`@("`@3&%T97(@*&1U<FEN9R!T96UP;&%T92`B=W)I
M=&4M8V5L;"(I('1H92!S='EL92!O9B!T:&4@8V]L=6UN('=I;&P@8F4@;6EX
M960@=VET:"!T:&4@8V5L;"US='EL92!B>2!U<VEN9PH@("`@("`@("`@("`@
M('1H92!P;W-I=&EO;B@I(&]F('1H92!C;VQU;6X@96YT<GD@86YD(&-O;7!A
M<FEN9R!I="!W:71H('1H92!I=&5R871I;F<@8V5L;"!N=6UB97(N("TM/@H@
M("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB86QL0V]L=6UN4W1Y;&5%;G1R
M:65S+5)41B(^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE
M/2)A9&1I;F<M8V]L=6UN+7-T>6QE<RUE;G1R:65S(CX*("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A
M(B`@('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q486)L94-O;'5M;G,B
M("`@("`@<V5L96-T/2(D86QL5&%B;&5#;VQU;6YS(B\^"B`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@/"]X<VPZ=F%R:6%B;&4^
M"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=X=#IN;V1E+7-E="<I(CX*("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C<F5A=&4M
M=&%B;&4B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B`@("`@("!S96QE8W0](B1C;VQL
M96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F%L;%9I<VEB;&5486)L95)O=W,B("`@("`@<V5L
M96-T/2(D86QL5FES:6)L951A8FQE4F]W<R(O/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q#;VQU;6Y3='EL945N=')I
M97,B("`@('-E;&5C=#TB>'0Z;F]D92US970H)&%L;$-O;'5M;E-T>6QE16YT
M<FEE<RU25$8I(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L
M871E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=X86QA;CIN;V1E<V5T
M)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M(F-R96%T92UT86)L92(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B("`@("`@('-E;&5C
M=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL5FES:6)L951A8FQE4F]W<R(@
M("`@("!S96QE8W0](B1A;&Q6:7-I8FQE5&%B;&52;W=S(B\^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;$-O;'5M;E-T
M>6QE16YT<FEE<R(@("`@<V5L96-T/2)X86QA;CIN;V1E<V5T*"1A;&Q#;VQU
M;6Y3='EL945N=')I97,M4E1&*2(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ
M8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`\+WAS;#IC:&]O<V4^"@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\
M>'-L.G1E;7!L871E(&YA;64](F-R96%T92UT86)L92(^"B`@("`@("`@/'AS
M;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@
M/'AS;#IP87)A;2!N86UE/2)A;&Q6:7-I8FQE5&%B;&52;W=S(B\^"B`@("`@
M("`@/'AS;#IP87)A;2!N86UE/2)A;&Q#;VQU;6Y3='EL945N=')I97,B+SX*
M"@H@("`@("`@(#PA+2T@4V]M92!/9F9I8V4@0V%L8R!D;V-U;65N=',@<VEM
M=6QA=&4@82!B86-K9W)O=6YD(&)Y(')E<&5A=&EN9R!T:&4@;&%S="!C96QL
M('5N=&EL(&5N9"!O9B!S<&%C90H@("`@("`@("`@("`@*%1H92!V86QU92!O
M9B`B=&%B;&4Z;G5M8F5R+6-O;'5M;G,M<F5P96%T960B(&ES(&5N;W5R;6]U
M<RDN(%=R:71I;F<@;W5T(&%L;"!T:&5S92!C96QL<R!W;W5L9"!B92!F871A
M;"X*("`@("`@("`@("`@(%1H97)E9F]R92P@=&AI<R!G;&]B86P@=F%R:6%B
M;&4@<VAO=W,@=7,@=&AE(&QO;F=E<W0@<F]W('=I=&@@8V]N=&5N="X*"B`@
M("`@("`@16%R;&EE<B!O;FQY('1H92!V:65W86)L92!C;VQU;6YS('=E<F4@
M;&ES=&5D+"!B=70@:70@:7,@96%S:65R('1O(&AA;F1L92!W:71H(&%L;"!C
M;VQU;6YS.@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB;6%X4F]W3&5N
M9W1H(B!S96QE8W0](F-O=6YT*"1A;&Q#;VQU;6Y3='EL945N=')I97,O8V]L
M=6UN+7-T>6QE+65N=')Y6VYO="A`8V]L=6UN+6AI9&1E;BUF;&%G*5TI(B\^
M("TM/@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB;6%X4F]W3&5N9W1H
M(B!S96QE8W0](F-O=6YT*"1A;&Q#;VQU;6Y3='EL945N=')I97,O8V]L=6UN
M+7-T>6QE+65N=')Y*2(O/@H*"B`@("`@("`@/"$M+6ES1&5B=6=-;V1E+5-4
M05)4+2T^"B`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO9&4B/@H@
M("`@("`@("`@("`\>'-L.FUE<W-A9V4^;6%X4F]W3&5N9W1H.B`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB)&UA>%)O=TQE;F=T:"(O/CPO>'-L.FUE<W-A9V4^
M"B`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB;G5M8F5R3V9(:61D
M96Y#;VQU;6YS(B!S96QE8W0](F-O=6YT*"1A;&Q#;VQU;6Y3='EL945N=')I
M97,O8V]L=6UN+7-T>6QE+65N=')Y6T!C;VQU;6XM:&ED9&5N+69L86==*2(O
M/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^;G5M8F5R3V9(:61D96Y#;VQU
M;6YS.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&YU;6)E<D]F2&ED9&5N0V]L
M=6UN<R(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)T86)L92UD96)U9RUA;&Q#;VQU;6Y3='EL945N=')I
M97,B/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L
M;$-O;'5M;E-T>6QE16YT<FEE<R(@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%
M;G1R:65S(B\^"B`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@/"]X<VPZ:68^"B`@("`@("`@/"$M+6ES1&5B=6=-;V1E+45.1"TM
M/@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB)&]U='!U=%1Y<&4@/2`G5TU,)R(^"B`@("`@("`@("`@("`@("`\
M(2TM(&UA=&-H:6YG(&%L;"!R;W=S("T@=V4@8V%N(&YO="!U<V4@>'-L.F%P
M<&QY+71E;7!L871E('=I=&@@82!N;V1E+7-E="!P87)A;65T97(@87,@8GD@
M82!B=6<@:6X@6%0@*$IA;65S($-L87)K*0H@("`@("`@("`@("`@("`@("`@
M("`H:&5R93H@86QL0V]L=6UN4W1Y;&5%;G1R:65S*2!W:6QL(&)E(&EN=&5R
M<')E=&5D(&%S(&$@<F5S=6QT('1R964@9G)A9VUE;G0L('=H97)E(&YO('-E
M87)C:"!E>'!R97-S:6]N("A84&%T:"D@8V%N(&)E('5S960*("`@("`@("`@
M("`@("`@("`@("`@,D1/.D-(14-+(%=)5$@@6$%,04XM+3X*("`@("`@("`@
M("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T/2(D86QL5FES:6)L951A8FQE
M4F]W<R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64](G=M;"UR97!E870M=W)I=&4M<F]W(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B("`@("`@('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@("`@<V5L96-T/2(D86QL0V]L=6UN
M4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)N=6UB97(M<F]W<RUR97!E871E9"(@("`@('-E
M;&5C=#TB0'1A8FQE.FYU;6)E<BUR;W=S+7)E<&5A=&5D(B\^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)M87A2;W=,
M96YG=&@B("`@("`@("`@("`@('-E;&5C=#TB)&UA>%)O=TQE;F=T:"(O/@H@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@
M("`@("`@("`@("`\+WAS;#IF;W(M96%C:#X*("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@
M("`@("`\(2TM(&UA=&-H:6YG(&%L;"!R;W=S("T@=V4@8V%N(&YO="!U<V4@
M>'-L.F%P<&QY+71E;7!L871E('=I=&@@82!N;V1E+7-E="!P87)A;65T97(@
M87,@8GD@82!B=6<@:6X@6%0@*$IA;65S($-L87)K*0H@("`@("`@("`@("`@
M("`@("`@("`H:&5R93H@86QL0V]L=6UN4W1Y;&5%;G1R:65S*2!W:6QL(&)E
M(&EN=&5R<')E=&5D(&%S(&$@<F5S=6QT('1R964@9G)A9VUE;G0L('=H97)E
M(&YO('-E87)C:"!E>'!R97-S:6]N("A84&%T:"D@8V%N(&)E('5S960*("`@
M("`@("`@("`@("`@("`@("`@,D1/.D-(14-+(%=)5$@@6$%,04X@+2T^"B`@
M("`@("`@("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB)&%L;%9I<VEB
M;&5486)L95)O=W,B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)R97!E870M=W)I=&4M<F]W(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L
M;V)A;$1A=&$B("`@("`@('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B
M+SX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@("`@<V5L96-T/2(D86QL0V]L
M=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)N=6UB97(M<F]W<RUR97!E871E9"(@("`@
M('-E;&5C=#TB0'1A8FQE.FYU;6)E<BUR;W=S+7)E<&5A=&5D(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)M87A2
M;W=,96YG=&@B("`@("`@("`@("`@('-E;&5C=#TB)&UA>%)O=TQE;F=T:"(O
M/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@("`@("`\+WAS;#IF;W(M96%C:#X*("`@("`@("`@("`@/"]X
M<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L
M.G1E;7!L871E/@H*"@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!(14Q015(Z('1A8FQE(&)O<F1E
M<B`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BH@+2T^"@H@("`@/"$M+2!O;FQY(&]N92!T86)L92!B;W)D97(@9F]R($A4
M34PT(&]R($-34R!D979I8V5S('=H:6-H(&-O;G1A:6X@;VYE(&]R(&UO<F4@
M)V9O.F)O<F1E<BUT;W`G(&%T=')I8G5T97,@*'!A<G,@<')O('1O=&\L(&EF
M(&]N92!E>&ES="!T:&4@;W1H97(@=7-U86QL>2!E>&ES="P@=&]O*2`M+3X*
M("`@(#PA+2T@=&AI<R!W87,@82!W;W)K+6%R;W5N9"!F;W(@=&AE(&YE='-C
M87!E(#0N>'@@8G5T(&YO="!L;VYG97(@;F5C97-S87)Y(&9O<B!-;WII;&QA
M("TM/@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)C:&5C:RUF;W(M=&%B;&4M
M8F]R9&5R(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F%L;%9I<VEB;&54
M86)L95)O=W,B+SX*"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)S=&%R
M=%1I;64B/@H@("`@("`@("`@("`\>'-L.FEF('1E<W0](B1I<T1E8G5G36]D
M92!A;F0@;F]T*"1I<TIA=F%$:7-A8FQE9"DB/@H@("`@("`@("`@("`@("`@
M/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](F9U;F-T:6]N+6%V86EL86)L92@G<WES=&5M.F-U<G)E;G0M=&EM92UM
M:6QL:7,G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2)S>7-T96TZ8W5R<F5N="UT:6UE+6UI;&QI<R@I(B\^"B`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=J879A
M.FIA=F$N;&%N9RY3>7-T96TN8W5R<F5N=%1I;65-:6QL:7,G*2(^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)J879A
M.FIA=F$N;&%N9RY3>7-T96TN8W5R<F5N=%1I;65-:6QL:7,H*2(O/@H@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`\
M+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@(#PO
M>'-L.G9A<FEA8FQE/@H*("`@("`@("`\(2TM(&-H96-K<R!I9B!O;F4@8V5L
M;"`H=&%B;&4Z=&%B;&4M8V5L;"D@;V8@=&AE(')O=W,@;V8@=&AI<R!T86)L
M92`H86QL5FES:6)L951A8FQE4F]W<RD@8V]N=&%I;G,@82!B;W)D97(@<W1Y
M;&4@*&DN92X@9F\Z8F]R9&5R+71O<"D*("`@("`@("`@("`@($EF(&]N;'D@
M;VYE('-I;F=L92!B;W)D97(@96QE;65N="!E>&ES="P@=&AE('=H;VQE('1A
M8FQE('=I;&P@9V5T<R!P<F4M9&5F:6YE9"!B;W)D97)S("AS:6UP;&4@:&5U
M<FES=&EC(&9O<B!B971T97(@8G)O=W-E<B!D:7-P;&%Y*2`M+3X*("`@("`@
M("`\>'-L.FEF('1E<W0](B1A;&Q6:7-I8FQE5&%B;&52;W=S+W1A8FQE.G1A
M8FQE+6-E;&Q;0'1A8FQE.G-T>6QE+6YA;64]+RHO*B]S='EL93IS='EL95MS
M='EL93IP<F]P97)T:65S+T!F;SIB;W)D97(M=&]P72]`<W1Y;&4Z;F%M95TB
M/@H@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)B;W)D97(B/C$\
M+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA
M;64](F)O<F1E<F-O;&]R(CXC,#`P,#`P/"]X<VPZ871T<FEB=71E/@H@("`@
M("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)C96QL<&%D9&EN9R(^,CPO
M>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M
M93TB8V5L;'-P86-I;F<B/C`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@
M(#QX<VPZ871T<FEB=71E(&YA;64](G!A9V4M8G)E86LM:6YS:61E(CYP86=E
M+6)R96%K+6EN<VED93IA=F]I9#PO>'-L.F%T=')I8G5T93X*("`@("`@("`\
M+WAS;#II9CX*"@H@("`@("`@(#PA+2T@8VAE8VL@=&AE('1I;64@9F]R(&)O
M<F1E<F-H96-K:6YG("AD96)U9RDM+3X*("`@("`@("`\>'-L.FEF('1E<W0]
M(B1I<T1E8G5G36]D92!A;F0@;F]T*"1I<TIA=F%$:7-A8FQE9"DB/@H@("`@
M("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F5N9%1I;64B/@H@("`@("`@
M("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G<WES=&5M.F-U<G)E
M;G0M=&EM92UM:6QL:7,G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)S>7-T96TZ8W5R<F5N="UT:6UE+6UI;&QI
M<R@I(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA
M8FQE*"=J879A.FIA=F$N;&%N9RY3>7-T96TN8W5R<F5N=%1I;65-:6QL:7,G
M*2(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2)J879A.FIA=F$N;&%N9RY3>7-T96TN8W5R<F5N=%1I;65-:6QL:7,H
M*2(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@
M("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO>'-L.G9A<FEA
M8FQE/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^5&EM92!F;W(@8VAE8VMI
M;F<@0F]R9&5R4W1Y;&4Z(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(H)&5N9%1I
M;64@+2`D<W1A<G14:6UE*2(O/B!M<SPO>'-L.FUE<W-A9V4^"B`@("`@("`@
M/"]X<VPZ:68^"B`@("`\+WAS;#IT96UP;&%T93X*"CPO>'-L.G-T>6QE<VAE
M970^"@``````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]O;V\O=&%B;&5?8V5L;',N>'-L
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P-C8R-S(`,3`U,34T,S,W-#<`,#(U,C<R`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#PA+2T*
M"B`@(%1H92!#;VYT96YT<R!O9B!T:&ES(&9I;&4@87)E(&UA9&4@879A:6QA
M8FQE('-U8FIE8W0@=&\@=&AE('1E<FUS(&]F"B`@(&5I=&AE<B!O9B!T:&4@
M9F]L;&]W:6YG(&QI8V5N<V5S"@H@("`@("`@("`@+2!'3E4@3&5S<V5R($=E
M;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO;B`R+C$*("`@("`@("`@("T@
M4W5N($EN9'5S=')Y(%-T86YD87)D<R!3;W5R8V4@3&EC96YS92!697)S:6]N
M(#$N,0H*("`@4W5N($UI8W)O<WES=&5M<R!);F,N+"!/8W1O8F5R+"`R,#`P
M"@H@("!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO
M;B`R+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]"B`@($-O<'ER:6=H="`R,#`P(&)Y(%-U;B!-:6-R;W-Y<W1E
M;7,L($EN8RX*("`@.3`Q(%-A;B!!;G1O;FEO(%)O860L(%!A;&\@06QT;RP@
M0T$@.30S,#,L(%5300H*("`@5&AI<R!L:6)R87)Y(&ES(&9R964@<V]F='=A
M<F4[('EO=2!C86X@<F5D:7-T<FEB=71E(&ET(&%N9"]O<@H@("!M;V1I9GD@
M:70@=6YD97(@=&AE('1E<FUS(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@
M4'5B;&EC"B`@($QI8V5N<V4@=F5R<VEO;B`R+C$L(&%S('!U8FQI<VAE9"!B
M>2!T:&4@1G)E92!3;V9T=V%R92!&;W5N9&%T:6]N+@H*("`@5&AI<R!L:6)R
M87)Y(&ES(&1I<W1R:6)U=&5D(&EN('1H92!H;W!E('1H870@:70@=VEL;"!B
M92!U<V5F=6PL"B`@(&)U="!7251(3U54($%.62!705)204Y463L@=VET:&]U
M="!E=F5N('1H92!I;7!L:65D('=A<G)A;G1Y(&]F"B`@($U%4D-(04Y404))
M3$E462!O<B!&251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]312X@(%-E
M92!T:&4@1TY5"B`@($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(&9O
M<B!M;W)E(&1E=&%I;',N"@H@("!9;W4@<VAO=6QD(&AA=F4@<F5C96EV960@
M82!C;W!Y(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC"B`@($QI
M8V5N<V4@86QO;F<@=VET:"!T:&ES(&QI8G)A<GD[(&EF(&YO="P@=W)I=&4@
M=&\@=&AE($9R964@4V]F='=A<F4*("`@1F]U;F1A=&EO;BP@26YC+BP@-3D@
M5&5M<&QE(%!L86-E+"!3=6ET92`S,S`L($)O<W1O;BP*("`@34$@(#`R,3$Q
M+3$S,#<@(%5300H*"B`@(%-U;B!);F1U<W1R>2!3=&%N9&%R9',@4V]U<F-E
M($QI8V5N<V4@5F5R<VEO;B`Q+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@("!4:&4@8V]N=&5N=',@
M;V8@=&AI<R!F:6QE(&%R92!S=6)J96-T('1O('1H92!3=6X@26YD=7-T<GD@
M4W1A;F1A<F1S"B`@(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ("AT:&4@
M(DQI8V5N<V4B*3L@66]U(&UA>2!N;W0@=7-E('1H:7,@9FEL90H@("!E>&-E
M<'0@:6X@8V]M<&QI86YC92!W:71H('1H92!,:6-E;G-E+B!9;W4@;6%Y(&]B
M=&%I;B!A(&-O<'D@;V8@=&AE"B`@($QI8V5N<V4@870@:'1T<#HO+W=W=RYO
M<&5N;V9F:6-E+F]R9R]L:6-E;G-E+FAT;6PN"@H@("!3;V9T=V%R92!P<F]V
M:61E9"!U;F1E<B!T:&ES($QI8V5N<V4@:7,@<')O=FED960@;VX@86X@(D%3
M($E3(B!B87-I<RP*("`@5TE42$]55"!705)204Y462!/1B!!3ED@2TE.1"P@
M14E42$52($584%)%4U,@3U(@24U03$E%1"P@24Y#3%5$24Y'+`H@("!7251(
M3U54($Q)34E4051)3TXL(%=!4E)!3E1)15,@5$A!5"!42$4@4T]&5%=!4D4@
M25,@1E)%12!/1B!$149%0U13+`H@("!-15)#2$%.5$%"3$4L($9)5"!&3U(@
M02!005)424-53$%2(%!54E!/4T4L($]2($Y/3BU)3D9224Y'24Y'+@H@("!3
M964@=&AE($QI8V5N<V4@9F]R('1H92!S<&5C:69I8R!P<F]V:7-I;VYS(&=O
M=F5R;FEN9R!Y;W5R(')I9VAT<R!A;F0*("`@;V)L:6=A=&EO;G,@8V]N8V5R
M;FEN9R!T:&4@4V]F='=A<F4N"@H@("!4:&4@26YI=&EA;"!$979E;&]P97(@
M;V8@=&AE($]R:6=I;F%L($-O9&4@:7,Z(%-U;B!-:6-R;W-Y<W1E;7,L($EN
M8RX*"B`@($-O<'ER:6=H="#"J2`R,#`R(&)Y(%-U;B!-:6-R;W-Y<W1E;7,L
M($EN8RX*"B`@($%L;"!2:6=H=',@4F5S97)V960N"@H@("!#;VYT<FEB=71O
M<BAS*3H@7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M"@HM+3X*/'AS;#IS='EL97-H965T('9E<G-I;VX](C$N,"(*("`@("`@("`@
M("`@("`@('AM;&YS.GAS;#TB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]84TPO
M5')A;G-F;W)M(@H@("`@("`@("`@("`@("`@>&UL;G,Z;V9F:6-E/2)H='1P
M.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]O9F9I8V4B"B`@("`@("`@("`@("`@
M("!X;6QN<SIS='EL93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O<W1Y
M;&4B"B`@("`@("`@("`@("`@("!X;6QN<SIT97AT/2)H='1P.B\O;W!E;F]F
M9FEC92YO<F<O,C`P,"]T97AT(@H@("`@("`@("`@("`@("`@>&UL;G,Z=&%B
M;&4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W1A8FQE(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z9')A=STB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P
M,#`O9')A=VEN9R(*("`@("`@("`@("`@("`@('AM;&YS.F9O/2)H='1P.B\O
M=W=W+G<S+F]R9R\Q.3DY+UA33"]&;W)M870B"B`@("`@("`@("`@("`@("!X
M;6QN<SIX;&EN:STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]X;&EN:R(*("`@
M("`@("`@("`@("`@('AM;&YS.FYU;6)E<CTB:'1T<#HO+V]P96YO9F9I8V4N
M;W)G+S(P,#`O9&%T87-T>6QE(@H@("`@("`@("`@("`@("`@>&UL;G,Z<W9G
M/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`P+W-V9R(*("`@("`@("`@("`@("`@
M('AM;&YS.F-H87)T/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]C:&%R
M="(*("`@("`@("`@("`@("`@('AM;&YS.F1R,V0](FAT='`Z+R]O<&5N;V9F
M:6-E+F]R9R\R,#`P+V1R,V0B"B`@("`@("`@("`@("`@("!X;6QN<SIM871H
M/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DX+TUA=&@O36%T:$U,(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z9F]R;3TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P
M,#`O9F]R;2(*("`@("`@("`@("`@("`@('AM;&YS.G-C<FEP=#TB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O<V-R:7!T(@H@("`@("`@("`@("`@("`@
M;V9F:6-E.F-L87-S/2)T97AT(@H@("`@("`@("`@("`@("`@;V9F:6-E.G9E
M<G-I;VX](C$N,"(*("`@("`@("`@("`@("`@('AM;&YS.F1C/2)H='1P.B\O
M<'5R;"YO<F<O9&,O96QE;65N=',O,2XQ+R(*("`@("`@("`@("`@("`@('AM
M;&YS.FUE=&$](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+VUE=&$B"B`@
M("`@("`@("`@("`@("!X;6QN<SIC;VYF:6<](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`Q+V-O;F9I9R(*("`@("`@("`@("`@("`@('AM;&YS.FAE;'`]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+VAE;'`B"B`@("`@("`@("`@
M("`@("!X;6QN<SIX=#TB:'1T<#HO+W=W=RYJ8VQA<FLN8V]M+WAT(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z<WES=&5M/2)H='1P.B\O=W=W+FIC;&%R:RYC
M;VTO>'0O:F%V82]J879A+FQA;F<N4WES=&5M(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z>&%L86X](FAT='`Z+R]X;6PN87!A8VAE+F]R9R]X86QA;B(*("`@
M("`@("`@("`@("`@('AM;&YS.FIA=F$](FAT='`Z+R]X;6PN87!A8VAE+F]R
M9R]X<VQT+VIA=F$B"B`@("`@("`@("`@("`@("!E>&-L=61E+7)E<W5L="UP
M<F5F:7AE<STB:F%V82(^"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!W<FET92!R97!E
M871I;F<@=&%B;&4@8V5L;',@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"@H@("`@/"$M+2!M871C
M:&EN9R!C96QL<R!T;R!G:79E(&]U="`M/B!C;W9E<F5D('1A8FQE(&-E;&QS
M(&%R92!N;W0@=W)I='1E;B!O=70@+2T^"B`@("`\>'-L.G1E;7!L871E(&UA
M=&-H/2)T86)L93IT86)L92UC96QL(CX*("`@("`@("`\>'-L.G!A<F%M(&YA
M;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\(2TM('!O<VET
M:6]N(&]F('1H92!C=7)R96YT(&EN<'5T(&-E;&P@=&\@9V5T('1H92!C;W)R
M96-T(&-O;'5M('-T>6QE("AH:61D96X@87)E(&%L<V\@8V]U;G1E9"DM+3X*
M("`@("`@("`\>'-L.G!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE
M<R(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB;6%X4F]W3&5N9W1H(B\^
M"@H@("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B=6=-;V1E(CX*("`@("`@
M("`@("`@/'AS;#IM97-S86=E/@HM+2TM+2TM+2TM+2TM+3X@=&%B;&4Z=&%B
M;&4M8V5L;"!H87,@8F5E;B!E;G1E<F5D('=I=&@@;F]D92!V86QU93H@/'AS
M;#IV86QU92UO9B!S96QE8W0](BXB+SX\+WAS;#IM97-S86=E/@H@("`@("`@
M("`@("`\>'-L.FUE<W-A9V4^=&%B;&4Z;G5M8F5R+6-O;'5M;G,M<F5P96%T
M960Z("T\>'-L.G9A;'5E+6]F('-E;&5C=#TB0'1A8FQE.FYU;6)E<BUC;VQU
M;6YS+7)E<&5A=&5D(B\^+3PO>'-L.FUE<W-A9V4^"B`@("`@("`@/"]X<VPZ
M:68^"@H@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C<F5A=&4M
M8V]L=6UN+7!O<VET:6]N+79A<FEA8FQE(CX*("`@("`@("`@("`@/"$M+2!P
M;W-I=&EO;B!O9B!T:&4@8W5R<F5N="!I;G!U="!C96QL('1O(&=E="!T:&4@
M8V]R<F5C="!C;VQU;2!S='EL92`H:&ED9&5N(&%R92!A;'-O(&-O=6YT960I
M+2T^"B`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q#;VQU
M;6Y3='EL945N=')I97,B("`@('-E;&5C=#TB)&%L;$-O;'5M;E-T>6QE16YT
M<FEE<R(O/@H@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82(@("`@("`@<V5L96-T/2(D8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M;6%X4F]W3&5N9W1H(B`@("`@("`@("`@("!S96QE8W0](B1M87A2;W=,96YG
M=&@B+SX*("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H*("`@(#PO>'-L
M.G1E;7!L871E/@H*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)C<F5A=&4M
M8V]L=6UN+7!O<VET:6]N+79A<FEA8FQE(CX*("`@("`@("`\(2TM('!O<VET
M:6]N(&]F('1H92!C=7)R96YT(&EN<'5T(&-E;&P@=&\@9V5T('1H92!C;W)R
M96-T(&-O;'5M('-T>6QE("AH:61D96X@87)E(&%L<V\@8V]U;G1E9"DM+3X*
M("`@("`@("`\>'-L.G!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE
M<R(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L
M1&%T82(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB;6%X4F]W3&5N9W1H
M(B\^"@H@("`@("`@(#PA+2T@8V]L=6UN('!O<VET:6]N(&YE961E9"!F;W(@
M<W1Y;&5S+"!E<W`N(&9O<B!C;VQU;6XM:&ED9&5N+69L86<@+2T^"B`@("`@
M("`@/'AS;#IV87)I86)L92!N86UE/2)P<F5C961I;F<M8V]L=6UN<R(^"B`@
M("`@("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T/2)P<F5C961I;F<M<VEB
M;&EN9SHZ*B(^"B`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB
M<75A;G1I='DB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB<W1R:6YG
M+6QE;F=T:"A`=&%B;&4Z;G5M8F5R+6-O;'5M;G,M<F5P96%T960I(#T@,"(^
M,3PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H
M97)W:7-E/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)`=&%B;&4Z;G5M8F5R+6-O
M;'5M;G,M<F5P96%T960B+SX\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@/"]X<VPZ
M96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@
M/"]X<VPZ=F%R:6%B;&4^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=X=#IN
M;V1E+7-E="<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T
M92!N86UE/2)C<F5A=&4M=&%B;&4M8V5L;"(^"B`@("`@("`@("`@("`@("`@
M("`@/"$M+2!P;W-I=&EO;B!O9B!T:&4@8W5R<F5N="!I;G!U="!C96QL('1O
M(&=E="!T:&4@8V]R<F5C="!C;VQU;2!S='EL92`H:&ED9&5N(&%R92!A;'-O
M(&-O=6YT960I+2T^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@("`@<V5L96-T/2(D
M86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](FUA>%)O=TQE;F=T:"(@("`@("`@("`@
M("`@<V5L96-T/2(D;6%X4F]W3&5N9W1H(B\^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;'5M;BUP;W-I=&EO;B(@("`@
M("`@("`@<V5L96-T/2)S=6TH>'0Z;F]D92US970H)'!R96-E9&EN9RUC;VQU
M;6YS*2]Q=6%N=&ET>2D@*R`Q(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B("`@("`@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL
M86)L92@G>&%L86XZ;F]D97-E="<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)C<F5A=&4M=&%B;&4M8V5L;"(^"B`@("`@
M("`@("`@("`@("`@("`@/"$M+2!P;W-I=&EO;B!O9B!T:&4@8W5R<F5N="!I
M;G!U="!C96QL('1O(&=E="!T:&4@8V]R<F5C="!C;VQU;2!S='EL92`H:&ED
M9&5N(&%R92!A;'-O(&-O=6YT960I+2T^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@
M("`@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FUA>%)O=TQE;F=T
M:"(@("`@("`@("`@("`@<V5L96-T/2(D;6%X4F]W3&5N9W1H(B\^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;'5M;BUP
M;W-I=&EO;B(@("`@("`@("`@<V5L96-T/2)S=6TH>&%L86XZ;F]D97-E="@D
M<')E8V5D:6YG+6-O;'5M;G,I+W%U86YT:71Y*2`K(#$B+SX*("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(@("`@("!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^
M"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2).;V1E4V5T1G5N
M8W1I;VY.;W1!=F%I;&%B;&4B+SX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L
M;"UT96UP;&%T92!N86UE/2)C<F5A=&4M=&%B;&4M8V5L;"(O/@H@("`@("`@
M("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@
M("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64]
M(F-R96%T92UT86)L92UC96QL(CX*("`@("`@("`\(2TM('!O<VET:6]N(&]F
M('1H92!C=7)R96YT(&EN<'5T(&-E;&P@=&\@9V5T('1H92!C;W)R96-T(&-O
M;'5M('-T>6QE("AH:61D96X@87)E(&%L<V\@8V]U;G1E9"DM+3X*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(O/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O
M/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB;6%X4F]W3&5N9W1H(B\^"B`@
M("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQU;6XM<&]S:71I;VXB+SX*"@H@
M("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B=6=-;V1E(CX*("`@("`@("`@
M("`@/'AS;#IM97-S86=E/DY%5R!604Q513H@8V]L=6UN+7!O<VET:6]N.B`M
M/'AS;#IV86QU92UO9B!S96QE8W0](B1C;VQU;6XM<&]S:71I;VXB+SXM/"]X
M<VPZ;65S<V%G93X*("`@("`@("`\+WAS;#II9CX*"@H@("`@("`@(#PA+2T@
M82!H:61D96X@8V]L=6UN('=I;&P@9VEV92!O=70@;F]T:&EN9R`M+3X*("`@
M("`@("`\>'-L.FEF('1E<W0](FYO="@D86QL0V]L=6UN4W1Y;&5%;G1R:65S
M+V-O;'5M;BUS='EL92UE;G1R>5MP;W-I=&EO;B@I(#T@)&-O;'5M;BUP;W-I
M=&EO;ETO0&-O;'5M;BUH:61D96XM9FQA9RDB/@H@("`@("`@("`@("`\>'-L
M.F-H;V]S93X*("`@("`@("`@("`@("`@(#PA+2T@=VAE;B!T:&4@8V]L=6UN
M<R!A<F4@;F]T(')E<&5A=&5D('1H92!N97AT(&-O;'5M;BUP;W-I=&EO;G,@
M<F%I<V5S('5P('1O(#$L(&]T:&5R=VES92!U<"!T;R!T:&4@86UO=6YT(&]F
M(')E<&5A=&5D(&-O;'5M;G,@+2T^"B`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB0'1A8FQE.FYU;6)E<BUC;VQU;6YS+7)E<&5A=&5D(CX*("`@
M("`@("`@("`@("`@("`@("`\(2TM('=R:71E<R!M=6QT:7!L92!E;G1R:65S
M(&]F(&$@8V5L;"`M+3X*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM
M=&5M<&QA=&4@;F%M93TB<F5P96%T+7=R:71E+6-E;&PB/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D
M1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M86QL0V]L=6UN4W1Y;&5%;G1R:65S(B`@("!S96QE8W0](B1A;&Q#;VQU;6Y3
M='EL945N=')I97,B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F-O;'5M;BUP;W-I=&EO;B(@("`@("`@("`@<V5L
M96-T/2(D8V]L=6UN+7!O<VET:6]N(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)M87A2;W=,96YG=&@B("`@("`@
M("`@("`@('-E;&5C=#TB)&UA>%)O=TQE;F=T:"(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;G5M8F5R+6-O;'5M
M;G,M<F5P96%T960B("!S96QE8W0](D!T86)L93IN=6UB97(M8V]L=6UN<RUR
M97!E871E9"(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@/"$M
M+2!W<FET97,@86X@96YT<GD@;V8@82!C96QL("TM/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)W<FET92UC96QL(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@("`@<V5L96-T/2(D
M86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQU;6XM<&]S:71I;VXB("`@
M("`@("`@('-E;&5C=#TB)&-O;'5M;BUP;W-I=&EO;B(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;6%X4F]W3&5N
M9W1H(B`@("`@("`@("`@("!S96QE8W0](B1M87A2;W=,96YG=&@B+SX*("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`\+WAS;#IC
M:&]O<V4^"B`@("`@("`@/"]X<VPZ:68^"@H@("`@/"]X<VPZ=&5M<&QA=&4^
M"@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64](G)E<&5A="UW<FET92UC96QL
M(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A
M=&$B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE
M16YT<FEE<R(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L=6UN+7!O
M<VET:6]N(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)M87A2;W=,96YG
M=&@B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](FYU;6)E<BUC;VQU;6YS
M+7)E<&5A=&5D(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`\(2TM(#)$3SH@5&AI<R!I<R!T:&4@8W5R<F5N="!W;W)K87)O=6YD(&%G
M86EN<W0@=&AE(&)A8VMG<F]U;F0@<VEM=6QA=&EO;B!B>2!A;B`G96YD;&5S
M<R<@<F5P96%T:6YG(&-E;&P@+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2(D;G5M8F5R+6-O;'5M;G,M<F5P96%T960@/B`Q(&%N9"`D;6%X4F]W
M3&5N9W1H(#X@)&-O;'5M;BUP;W-I=&EO;B(^"@H@("`@("`@("`@("`@("`@
M/'AS;#II9B!T97-T/2(D:7-$96)U9TUO9&4B/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ;65S<V%G93XK*RLK*RLK*RL@<W1A<G1I;F<@8V5L;"!W<FET
M:6YG("LK*RLK*RLK*SPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IM97-S86=E/FYU;6)E<BUC;VQU;6YS+7)E<&5A=&5D.B`M/'AS
M;#IV86QU92UO9B!S96QE8W0](B1N=6UB97(M8V]L=6UN<RUR97!E871E9"(O
M/BT\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S
M<V%G93YM87A2;W=,96YG=&@Z("T\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&UA
M>%)O=TQE;F=T:"(O/BT\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ;65S<V%G93YC;VQU;6XM<&]S:71I;VXZ("T\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB)&-O;'5M;BUP;W-I=&EO;B(O/BT\+WAS;#IM97-S86=E
M/@H@("`@("`@("`@("`@("`@/"]X<VPZ:68^"@H@("`@("`@("`@("`@("`@
M/"$M+2!W<FET97,@86X@96YT<GD@;V8@82!C96QL("TM/@H@("`@("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+6-E;&PB/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL
M96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A
M(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@("`@<V5L96-T/2(D86QL0V]L=6UN
M4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-O;'5M;BUP;W-I=&EO;B(@("`@("`@("`@<V5L96-T
M/2(D8V]L=6UN+7!O<VET:6]N(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](FUA>%)O=TQE;F=T:"(@("`@("`@("`@("`@
M<V5L96-T/2(D;6%X4F]W3&5N9W1H(B\^"B`@("`@("`@("`@("`@("`\+WAS
M;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@/"$M+2!R97!E870@
M8V%L;&EN9R!T:&ES(&UE=&AO9"!U;G1I;"!A;&P@96QE;65N=',@=W)I='1E
M;B!O=70@+2T^"B`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](B1I<T1E
M8G5G36]D92(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/BLK
M*RLK*RLK*R!C96QL(')E<&5T:71I;VX@*RLK*RLK*RLK/"]X<VPZ;65S<V%G
M93X*("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64](G)E<&5A="UW<FET92UC96QL(CX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T
M82(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)A;&Q#;VQU;6Y3='EL945N=')I97,B("`@('-E;&5C=#TB)&%L;$-O;'5M
M;E-T>6QE16YT<FEE<R(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C;VQU;6XM<&]S:71I;VXB("`@("`@("`@('-E;&5C
M=#TB)&-O;'5M;BUP;W-I=&EO;B`K(#$B+SX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;6%X4F]W3&5N9W1H(B`@("`@("`@
M("`@("!S96QE8W0](B1M87A2;W=,96YG=&@B+SX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;G5M8F5R+6-O;'5M;G,M<F5P
M96%T960B("!S96QE8W0](B1N=6UB97(M8V]L=6UN<RUR97!E871E9"`M(#$B
M+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E
M/@H@("`@("`@("`@("`@("`@/"$M+2`R1$\Z(%1H:7,@:7,@=&AE(&-U<G)E
M;G0@=V]R:V%R;W5N9"!A9V%I;G-T('1H92!B86-K9W)O=6YD('-I;75L871I
M;VX@8GD@86X@)V5N9&QE<W,G(')E<&5A=&EN9R!C96QL("TM/@H@("`@("`@
M("`@("`@("`@/"$M+2`@("`@(%=H96X@=&AE(&UA>%)O=TQE;F=T:"!I<R!R
M96%C:&5D(&$@;&%S="!E;G1R>2!O9B!A(&-E;&P@:7,@=W)I='1E;B`M+3X*
M("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)W<FET
M92UC96QL(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@("`@("`@<V5L96-T/2(D8V]L
M;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)A;&Q#;VQU;6Y3='EL945N=')I97,B("`@('-E
M;&5C=#TB)&%L;$-O;'5M;E-T>6QE16YT<FEE<R(O/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQU;6XM<&]S:71I;VXB
M("`@("`@("`@('-E;&5C=#TB)&-O;'5M;BUP;W-I=&EO;B(O/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)M87A2;W=,96YG
M=&@B("`@("`@("`@("`@('-E;&5C=#TB)&UA>%)O=TQE;F=T:"(O/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@
M/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO
M>'-L.G1E;7!L871E/@H*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)W<FET
M92UC96QL(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L
M;V)A;$1A=&$B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F%L;$-O;'5M
M;E-T>6QE16YT<FEE<R(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L
M=6UN+7!O<VET:6]N(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)M87A2
M;W=,96YG=&@B+SX*"@H@("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B=6=-
M;V1E(CX*("`@("`@("`@("`@/'AS;#IM97-S86=E/E=R:71E5&5S="`M/B!)
M9B!N;W1H:6YG(&)E='=E96X@)RTG('=R:71E(&-E;&P@+3QX<VPZ=F%L=64M
M;V8@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S+V-O;'5M;BUS='EL
M92UE;G1R>5MP;W-I=&EO;B@I(#T@)&-O;'5M;BUP;W-I=&EO;ETO0&-O;'5M
M;BUH:61D96XM9FQA9R(O/BT\+WAS;#IM97-S86=E/@H@("`@("`@(#PO>'-L
M.FEF/@H*("`@("`@("`@("`@/'AS;#II9B!T97-T/2(D86QL0V]L=6UN4W1Y
M;&5%;G1R:65S+V-O;'5M;BUS='EL92UE;G1R>5MP;W-I=&EO;B@I(#T@)&-O
M;'5M;BUP;W-I=&EO;ETO0&-O;'5M;BUH:61D96XM9FQA9R(^"B`@("`@("`@
M("`@("`@("`\>'-L.FEF('1E<W0](B1I<T1E8G5G36]D92(^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IM97-S86=E/E1!0DQ%($-/3%5-3B!I<R!H:61D
M96XA/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@
M("`@("`@("`@("`\+WAS;#II9CX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@
M("`@("`@("`@(#PA+2T@82!H:61D96X@8V]L=6UN('=I;&P@9VEV92!O=70@
M;F]T:&EN9R`M+3X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1A;&Q#
M;VQU;6Y3='EL945N=')I97,O8V]L=6UN+7-T>6QE+65N=')Y6W!O<VET:6]N
M*"D@/2`D8V]L=6UN+7!O<VET:6]N72]`8V]L=6UN+6AI9&1E;BUF;&%G(CX*
M("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B=6=-;V1E(CX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^5$%"3$4@0T],54U.
M(&ES(&AI9&1E;B$\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@/"]X
M<VPZ:68^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"@H@("`@("`@("`@("`\
M(2TM($Y/5"!A(&AI9&1E;B!C;VQU;6X@+2T^"B`@("`@("`@("`@(#QX<VPZ
M;W1H97)W:7-E/@H*("`@("`@("`@("`@("`@(#PA+2T@82!T86)L92!I<R!A
M('1A8FQE(&AE861E<BP@=VAE;B!I="!H87,@82`B=&%B;&4Z=&%B;&4M:&5A
M9&5R+7)O=W,B(&%N8V5S=&]R("TM/@H@("`@("`@("`@("`@("`@/'AS;#IV
M87)I86)L92!N86UE/2)T86)L941A=&%4>7!E(CX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](F%N8V5S=&]R.CIT86)L93IT86)L92UH96%D97(M<F]W
M<R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^=&@\
M+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YT9#PO>'-L.G1E
M>'0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@
M("`@("`\+WAS;#IV87)I86)L93X*"B`@("`@("`@("`@("`@("`\>'-L.F-H
M;V]S93X*("`@("`@("`@("`@("`@("`@("`\(2TM*RLK*RL@0U-3("A#05-#
M041)3D<@4U1,644@4TA%150I($A%041%4B!35%E,12!705D@*RLK*RLM+3X*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y
M<&4@/2`G0U-37TA%041%4B<B/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F5L96UE;G0@;F%M93TB>R1T86)L941A=&%4>7!E?2(^"@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO
M9&4B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S
M<V%G93X**BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHG/'AS;#IV86QU92UO9B!S96QE8W0](B1T86)L941A=&%4>7!E(B\^)R!E
M;&5M96YT(&AA<R!B965N(&%D9&5D(3PO>'-L.FUE<W-A9V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#II9CX*"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](D!T86)L93IN=6UB97(M8V]L
M=6UN<RUS<&%N;F5D(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F%T=')I8G5T92!N86UE/2)C;VQS<&%N(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0]
M(D!T86)L93IN=6UB97(M8V]L=6UN<RUS<&%N;F5D(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ:68^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](D!T86)L93IN=6UB97(M<F]W
M<RUS<&%N;F5D(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F%T=')I8G5T92!N86UE/2)R;W=S<&%N(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](D!T
M86)L93IN=6UB97(M<F]W<RUS<&%N;F5D(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ:68^"@H*"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\(2TM("HJ*B!T:&4@8V5L;"US='EL92`J*BH@+2T^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM(%1H92!C96QL('-T>6QE
M(&AA<R!N;R!C;VYC;'5S:6]N('=I=&@@=&AE(&-O;'5M;B!S='EL92P@<V\@
M=V4@<W=I=&-H('1H92!O<F1E<B]P<FEO<FET:65S(&1U92!T;R!B<F]W<V5R
M(&ES<W5E<PH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!4:&4@
M8V5L;"US='EL92!D97!E;F1S(&]N('1W;R!A='1R:6)U=&5S.@H*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Q*2!T86)L93IS='EL92UN86UE
M("T@=&AE('-T>6QE('!R;W!E<G1I97,@;V8@8V5L;"X@5VAE;B!T:&5Y(&5X
M:7-T+"!A(&1E9F%U;'0@86QI9VYE;65N="`H8W`N(&)E;&]W*2!W:6QL(&)E
M(&%D9&5D(&9O<B!T:&4*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8V%S92!O9B!N;R!A;&EG;FUE;G0@
M:6X@=&AE('-T>6QE(&5X:7-T+@H*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`R*2!T86)L93IV86QU92UT>7!E("T@=&AE('9A;'5E('1Y<&4@
M;V8@=&AE('1A8FQE+6-E;&P@9VEV:6YG('1H92!D969A=6QT(&%L:6=N;65N
M=',N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($)Y(&1E9F%U;'0@82!S=')I;F<@=F%L=64@:7,@;&5F
M="!A;&EG;F5D+"!A;&P@;W1H97(@87)E(&%L:6=N960Z<FEG:'0N"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`M+3X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&%B;&4Z<W1Y;&4M;F%M92(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T
M<FEB=71E(&YA;64](G-T>6QE(CX*"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\(2TM($-%3$PM4U193$4Z(&%L:6=N;65N="!B
M>2!T86)L93IV86QU92UT>7!E("AW:71H;W5T(&5X:7-T:6YG('1A8FQE.G-T
M>6QE+6YA;64I+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F-E;&Q3='EL92(@<V5L96-T
M/2(D8V]L;&5C=&5D1VQO8F%L1&%T82]A;&QS='EL97,O*EMN86UE*"D]8W5R
M<F5N="@I+T!T86)L93IS='EL92UN86UE72(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](G-T<FEN9RUL96YG=&@H)&-E;&Q3='EL92D@/B`P(&%N9"!N;W0H
M8V]N=&%I;G,H)&-E;&Q3='EL92P@)W1E>'0M86QI9VXG*2DB/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM
M($-%3$PM4U193$4Z(&%L:6=N;65N="!B>2!T86)L93IV86QU92UT>7!E("TM
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\(2TM(&YO(&%L:6=N;65N="!I;B!T:&4@8V5L;"!S='EL92P@=&AE
M(&%L:6=N;65N="!B87-E9"!O;B!T:&4@=&%B;&4Z=F%L=64M='EP92!W:6QL
M(&)E(&%D9&5D("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2)`=&%B;&4Z=F%L=64M='EP92!A;F0@;F]T*$!T86)L93IV86QU
M92UT>7!E(#T@)W-T<FEN9R<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB8V]N8V%T*"1C;VQL96-T961';&]B86Q$871A+V%L;'-T>6QE
M<R\J6VYA;64H*3UC=7)R96YT*"DO0'1A8FQE.G-T>6QE+6YA;65=+"`G=&5X
M="UA;&EG;CIR:6=H=#L@)RDB+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB8V]N8V%T*"1C;VQL96-T961';&]B86Q$871A+V%L;'-T>6QE<R\J
M6VYA;64H*3UC=7)R96YT*"DO0'1A8FQE.G-T>6QE+6YA;65=+"`G=&5X="UA
M;&EG;CIL969T.R`G*2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M
M+2!#14Q,+5-464Q%.B!A;&EG;FUE;G0@8GD@=&%B;&4Z=F%L=64M='EP92`M
M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"$M+2!N;R!#4U,@<W1Y;&4@<')O<&5R=&EE<R!E>&ES="P@;VYL
M>2!A;&EG;FUE;G0@9G)O;2!T:&4@=&%B;&4Z=F%L=64M='EP92!W:6QL(&)E
M('5S960@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](D!T86)L93IV86QU92UT>7!E(&%N9"!N;W0H0'1A8FQE.G9A;'5E+71Y
M<&4@/2`G<W1R:6YG)RDB/G1E>'0M86QI9VXZ<FEG:'0[(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F]T:&5R=VES93YT97AT+6%L:6=N.FQE9G0[(#PO>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F-H;V]S93X*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"$M+2!C;VQU;6XM<W1Y;&4@*&1I<VIU;F-T(&]F(&-E;&P@<W1Y
M;&4@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"$M+2`R1$\Z(&]N;'D@86)S;VQU="!S='EL97,@87)E('-U<'!O<G1E
M9"P@<F5L871I=F4@<W1Y;&5S("AI+F4N("=S='EL93IR96PM8V]L=6UN+7=I
M9'1H)R!E+F<N('=I=&@@=F%L=64@(C@Y,S,J(B!A<F4@:6=N;W)E9"X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($ES
M<W5E.B!B<F]W<V5R<R`H;F]T('-U<F4@:68@0U-3*2!D;V5S(&YO="!S=7!P
M;W)T('1H92`G*B<@<F5L871I;VYS:&EP+"!O;FQY('1H92`G)2<L('=H97)E
M('1H92!S=6T@:7,@86QW87ES("<Q,#`G(0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@1F]R('1H:7,L(&ET(&ES(&5A
M<VEE<B!T;R!W;W)K(&]N('=I=&@@=&AE(&%B<V]L=71E('9A;'5E<RP@:6YS
M=&5A9"!O9B!C86QC=6QA=&EN9R!T:&4@=F%L=65S(&9O<B`Q,#`E("TM/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S+V-O;'5M
M;BUS='EL92UE;G1R>5MP;W-I=&EO;B@I/21C;VQU;6XM<&]S:71I;VY=(B\^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T
M=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"$M+2!#14Q,+5-464Q%.B!T86)L93IS='EL92UN86UE("TM/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N
M86UE/2)C;&%S<R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB=')A;G-L871E*$!T86)L
M93IS='EL92UN86UE+"`G+B`E*"DO7"<L("<G*2(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U
M=&4@;F%M93TB<W1Y;&4B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"$M+2!#14Q,+5-464Q%.B!A;&EG;FUE;G0@8GD@=&%B
M;&4Z=F%L=64M='EP92`H=VET:&]U="!E>&ES=&EN9R!T86)L93IS='EL92UN
M86UE*2TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"$M+2!N;R!T86)L93IS='EL92UN86UE(&5X:7-T+"!O;FQY(&%L:6=N
M;65N="!F<F]M('1H92!T86)L93IV86QU92UT>7!E('=I;&P@8F4@=7-E9"`M
M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&%B;&4Z=F%L=64M='EP92!A
M;F0@;F]T*$!T86)L93IV86QU92UT>7!E(#T@)W-T<FEN9R<I(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&5X
M="UA;&EG;CIR:6=H=#L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T
M97AT+6%L:6=N.FQE9G0["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U
M=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H
M97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@26X@8V%S
M92!O9B!N;R!C96QL(&-O;G1E;G0@82!N;VXM8G)E86MA8FQE('-P86-E('=I
M;&P@8F4@:6YS97)T960*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('1O(&UA:V4@=&AE(&)R;W=S97(@<VAO=R!T:&4@=&%B;&4M8V5L
M;"!G<FED("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2)N;W0H8VAI;&0Z.G1E>'0H*2D@86YD(&YO="AC:&EL
M9#HZ*BDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G1E>'0^("8C,38P.SPO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"$M+2`J*BH@=&AE(&-O;'5M;BUS='EL
M92`J*BH@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PA+2T@('1H92!C;VQU;6X@<W1Y;&4@:&%S(&YO(&-O;F-L=7-I;VX@=VET
M:"!T:&4@8V5L;"!S='EL92P@<V\@=V4@<W=I=&-H('1H92!O<F1E<B]P<FEO
M<FET:65S(&1U92!T;R!B<F]W<V5R(&ES<W5E<RTM/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB<W!A
M;B(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F%T=')I8G5T92!N86UE/2)C;&%S<R(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE
M8W0](B1A;&Q#;VQU;6Y3='EL945N=')I97,O8V]L=6UN+7-T>6QE+65N=')Y
M6W!O<VET:6]N*"D@/2`D8V]L=6UN+7!O<VET:6]N72]`<W1Y;&4M;F%M92(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@("`@("`@("`@/"$M
M+2LK*RLK($A434P@-"XP($E.3$E.140@5T%9("`K*RLK*RTM/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=#
M4U-?24Y,24Y%1"<B/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L
M96UE;G0@;F%M93TB>R1T86)L941A=&%4>7!E?2(^"@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2)`=&%B;&4Z;G5M8F5R+6-O
M;'5M;G,M<W!A;FYE9"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8V]L<W!A;B(^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T
M/2)`=&%B;&4Z;G5M8F5R+6-O;'5M;G,M<W!A;FYE9"(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2)`=&%B;&4Z;G5M8F5R+7)O
M=W,M<W!A;FYE9"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IA='1R:6)U=&4@;F%M93TB<F]W<W!A;B(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)`
M=&%B;&4Z;G5M8F5R+7)O=W,M<W!A;FYE9"(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](G-T>6QE(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM(&-E;&PM<W1Y;&4@+2T^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A+V%L;'-T>6QE<R\J6VYA
M;64H*3UC=7)R96YT*"DO0'1A8FQE.G-T>6QE+6YA;65=(B\^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!C;VQU;6XM<W1Y;&4@+2T^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](B1A;&Q#;VQU;6Y3='EL945N=')I97,O8V]L=6UN+7-T>6QE
M+65N=')Y6W!O<VET:6]N*"D])&-O;'5M;BUP;W-I=&EO;ETB+SX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM(%1!0DQ%.E9!3%5%+519
M4$4@+2!T:&4@=F%L=64@;V8@82!T86)L92UC96QL('=I;&P@8F4@86QI9VYE
M9"!L969T(&)Y(&1E9F%U;'0@;VYL>2!E>&QI8VET(&YO;BUS=')I;F<@:7,@
M86QI9VYE9#IR:6=H="TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'1A8FQE.G9A;'5E+71Y<&4@86YD
M(&YO="A`=&%B;&4Z=F%L=64M='EP92`]("=S=')I;F<G*2(^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^=&5X
M="UA;&EG;CIR:6=H=#L\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YT97AT
M+6%L:6=N.FQE9G0[/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\(2TM("8C,38P(&ES(&$@;F]N+6)R96%K86)L
M92!S<&%C92P@;F5C97-S87)Y('1O(&UA:V4@=&\@=&AE(&)R;W=S97(@<VAO
M=R!T:&4@=&%B;&4M8V5L;"!G<FED("TM/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#II9B!T97-T/2)N;W0H8VAI;&0Z.G1E>'0H*2D@86YD
M(&YO="AC:&EL9#HZ*BDB/B`F(S$V,#L\+WAS;#II9CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B
M86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA
M<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@("`@("`@("`\(2TM*RLK*RL@4$%,32!)3DQ)3D5$(%=!62`@
M*RLK*RLM+3X*("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M)&]U='!U=%1Y<&4@/2`G4$%,32<B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F5L96UE;G0@;F%M93TB>R1T86)L941A=&%4>7!E?2(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](D!T86)L93IN
M=6UB97(M8V]L=6UN<RUS<&%N;F5D(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)C;VQS<&%N(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](D!T86)L93IN=6UB97(M8V]L=6UN<RUS<&%N;F5D(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ:68^"@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2)`=&%B;&4Z
M;G5M8F5R+7)O=W,M<W!A;FYE9"(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB<F]W<W!A;B(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@
M<V5L96-T/2)`=&%B;&4Z;G5M8F5R+7)O=W,M<W!A;FYE9"(O/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L
M;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`@("`@("`@(#PA+2TK*RLK*R!734P@5T%9("`K*RLK*RTM
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T
M5'EP92`]("=734PG(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC
M:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB;F]T*"1A;&Q#;VQU;6Y3='EL945N=')I97,O8V]L=6UN+7-T>6QE
M+65N=')Y6VQA<W0H*2`]("1C;VQU;6XM<&]S:71I;VY=*2(^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C
M;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#XL(#PO>'-L.G1E>'0^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C
M;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA
M;64](F)R(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO
M=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S
M93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I
M<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^
M"CPO>'-L.G-T>6QE<VAE970^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O;V]O+W1A8FQE7V-O
M;'5M;G,N>'-L`````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(T-C0U`#$P-3$U-#,S-S0W`#`R
M-38T-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\(2TM"@H@("!4:&4@0V]N=&5N=',@;V8@=&AI<R!F:6QE(&%R92!M861E
M(&%V86EL86)L92!S=6)J96-T('1O('1H92!T97)M<R!O9@H@("!E:71H97(@
M;V8@=&AE(&9O;&QO=VEN9R!L:6-E;G-E<PH*("`@("`@("`@("T@1TY5($QE
M<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(%9E<G-I;VX@,BXQ"B`@("`@
M("`@("`M(%-U;B!);F1U<W1R>2!3=&%N9&%R9',@4V]U<F-E($QI8V5N<V4@
M5F5R<VEO;B`Q+C$*"B`@(%-U;B!-:6-R;W-Y<W1E;7,@26YC+BP@3V-T;V)E
M<BP@,C`P,`H*("`@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E
M(%9E<G-I;VX@,BXQ"B`@(#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/0H@("!#;W!Y<FEG:'0@,C`P,"!B>2!3=6X@36EC
M<F]S>7-T96US+"!);F,N"B`@(#DP,2!386X@06YT;VYI;R!2;V%D+"!086QO
M($%L=&\L($-!(#DT,S`S+"!54T$*"B`@(%1H:7,@;&EB<F%R>2!I<R!F<F5E
M('-O9G1W87)E.R!Y;W4@8V%N(')E9&ES=')I8G5T92!I="!A;F0O;W(*("`@
M;6]D:69Y(&ET('5N9&5R('1H92!T97)M<R!O9B!T:&4@1TY5($QE<W-E<B!'
M96YE<F%L(%!U8FQI8PH@("!,:6-E;G-E('9E<G-I;VX@,BXQ+"!A<R!P=6)L
M:7-H960@8GD@=&AE($9R964@4V]F='=A<F4@1F]U;F1A=&EO;BX*"B`@(%1H
M:7,@;&EB<F%R>2!I<R!D:7-T<FEB=71E9"!I;B!T:&4@:&]P92!T:&%T(&ET
M('=I;&P@8F4@=7-E9G5L+`H@("!B=70@5TE42$]55"!!3ED@5T%24D%.5%D[
M('=I=&AO=70@979E;B!T:&4@:6UP;&EE9"!W87)R86YT>2!O9@H@("!-15)#
M2$%.5$%"24Q)5%D@;W(@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/
M4T4N("!3964@=&AE($=.50H@("!,97-S97(@1V5N97)A;"!0=6)L:6,@3&EC
M96YS92!F;W(@;6]R92!D971A:6QS+@H*("`@66]U('-H;W5L9"!H879E(')E
M8V5I=F5D(&$@8V]P>2!O9B!T:&4@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI
M8PH@("!,:6-E;G-E(&%L;VYG('=I=&@@=&AI<R!L:6)R87)Y.R!I9B!N;W0L
M('=R:71E('1O('1H92!&<F5E(%-O9G1W87)E"B`@($9O=6YD871I;VXL($EN
M8RXL(#4Y(%1E;7!L92!0;&%C92P@4W5I=&4@,S,P+"!";W-T;VXL"B`@($U!
M("`P,C$Q,2TQ,S`W("!54T$*"@H@("!3=6X@26YD=7-T<GD@4W1A;F1A<F1S
M(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ"B`@(#T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*("`@5&AE(&-O
M;G1E;G1S(&]F('1H:7,@9FEL92!A<F4@<W5B:F5C="!T;R!T:&4@4W5N($EN
M9'5S=')Y(%-T86YD87)D<PH@("!3;W5R8V4@3&EC96YS92!697)S:6]N(#$N
M,2`H=&AE("),:6-E;G-E(BD[(%EO=2!M87D@;F]T('5S92!T:&ES(&9I;&4*
M("`@97AC97!T(&EN(&-O;7!L:6%N8V4@=VET:"!T:&4@3&EC96YS92X@66]U
M(&UA>2!O8G1A:6X@82!C;W!Y(&]F('1H90H@("!,:6-E;G-E(&%T(&AT='`Z
M+R]W=W<N;W!E;F]F9FEC92YO<F<O;&EC96YS92YH=&UL+@H*("`@4V]F='=A
M<F4@<')O=FED960@=6YD97(@=&AI<R!,:6-E;G-E(&ES('!R;W9I9&5D(&]N
M(&%N(")!4R!)4R(@8F%S:7,L"B`@(%=)5$A/550@5T%24D%.5%D@3T8@04Y9
M($M)3D0L($5)5$A%4B!%6%!215-3($]2($E-4$Q)140L($E.0TQ51$E.1RP*
M("`@5TE42$]55"!,24U)5$%424].+"!705)204Y42453(%1(050@5$A%(%-/
M1E1705)%($E3($92144@3T8@1$5&14-44RP*("`@34520TA!3E1!0DQ%+"!&
M250@1D]2($$@4$%25$E#54Q!4B!055)03U-%+"!/4B!.3TXM24Y&4DE.1TE.
M1RX*("`@4V5E('1H92!,:6-E;G-E(&9O<B!T:&4@<W!E8VEF:6,@<')O=FES
M:6]N<R!G;W9E<FYI;F<@>6]U<B!R:6=H=',@86YD"B`@(&]B;&EG871I;VYS
M(&-O;F-E<FYI;F<@=&AE(%-O9G1W87)E+@H*("`@5&AE($EN:71I86P@1&5V
M96QO<&5R(&]F('1H92!/<FEG:6YA;"!#;V1E(&ES.B!3=6X@36EC<F]S>7-T
M96US+"!);F,N"@H@("!#;W!Y<FEG:'0@PJD@,C`P,B!B>2!3=6X@36EC<F]S
M>7-T96US+"!);F,N"@H@("!!;&P@4FEG:'1S(%)E<V5R=F5D+@H*("`@0V]N
M=')I8G5T;W(H<RDZ(%]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7PH*+2T^"CQX<VPZ<W1Y;&5S:&5E="!V97)S:6]N/2(Q+C`B"B`@
M("`@("`@("`@("`@("!X;6QN<SIX<VP](FAT='`Z+R]W=W<N=S,N;W)G+S$Y
M.3DO6%-,+U1R86YS9F]R;2(*("`@("`@("`@("`@("`@('AM;&YS.F]F9FEC
M93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O;V9F:6-E(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z<W1Y;&4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R
M,#`P+W-T>6QE(@H@("`@("`@("`@("`@("`@>&UL;G,Z=&5X=#TB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O=&5X="(*("`@("`@("`@("`@("`@('AM
M;&YS.G1A8FQE/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]T86)L92(*
M("`@("`@("`@("`@("`@('AM;&YS.F1R87<](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`P+V1R87=I;F<B"B`@("`@("`@("`@("`@("!X;6QN<SIF;STB
M:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]84TPO1F]R;6%T(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z>&QI;FL](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3DO>&QI
M;FLB"B`@("`@("`@("`@("`@("!X;6QN<SIN=6UB97(](FAT='`Z+R]O<&5N
M;V9F:6-E+F]R9R\R,#`P+V1A=&%S='EL92(*("`@("`@("`@("`@("`@('AM
M;&YS.G-V9STB:'1T<#HO+W=W=RYW,RYO<F<O,C`P,"]S=F<B"B`@("`@("`@
M("`@("`@("!X;6QN<SIC:&%R=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P
M,#`O8VAA<G0B"B`@("`@("`@("`@("`@("!X;6QN<SID<C-D/2)H='1P.B\O
M;W!E;F]F9FEC92YO<F<O,C`P,"]D<C-D(@H@("`@("`@("`@("`@("`@>&UL
M;G,Z;6%T:#TB:'1T<#HO+W=W=RYW,RYO<F<O,3DY."]-871H+TUA=&A-3"(*
M("`@("`@("`@("`@("`@('AM;&YS.F9O<FT](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`P+V9O<FTB"B`@("`@("`@("`@("`@("!X;6QN<SIS8W)I<'0]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W-C<FEP="(*("`@("`@("`@
M("`@("`@(&]F9FEC93IC;&%S<STB=&5X="(*("`@("`@("`@("`@("`@(&]F
M9FEC93IV97)S:6]N/2(Q+C`B"B`@("`@("`@("`@("`@("!X;6QN<SID8STB
M:'1T<#HO+W!U<FPN;W)G+V1C+V5L96UE;G1S+S$N,2\B"B`@("`@("`@("`@
M("`@("!X;6QN<SIM971A/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]M
M971A(@H@("`@("`@("`@("`@("`@>&UL;G,Z8V]N9FEG/2)H='1P.B\O;W!E
M;F]F9FEC92YO<F<O,C`P,2]C;VYF:6<B"B`@("`@("`@("`@("`@("!X;6QN
M<SIH96QP/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]H96QP(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z>'0](FAT='`Z+R]W=W<N:F-L87)K+F-O;2]X
M="(*("`@("`@("`@("`@("`@('AM;&YS.G-Y<W1E;3TB:'1T<#HO+W=W=RYJ
M8VQA<FLN8V]M+WAT+VIA=F$O:F%V82YL86YG+E-Y<W1E;2(*("`@("`@("`@
M("`@("`@('AM;&YS.GAA;&%N/2)H='1P.B\O>&UL+F%P86-H92YO<F<O>&%L
M86XB"B`@("`@("`@("`@("`@("!X;6QN<SIJ879A/2)H='1P.B\O>&UL+F%P
M86-H92YO<F<O>'-L="]J879A(@H@("`@("`@("`@("`@("`@97AC;'5D92UR
M97-U;'0M<')E9FEX97,](FIA=F$B/@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M
M+2`J*BH@0W)E871E('1A8FQE(&-O;'5M;G,@<W1Y;&4@=F%R:6%B;&4@("HJ
M*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)A
M9&1I;F<M8V]L=6UN+7-T>6QE<RUE;G1R:65S(CX*("`@("`@("`\>'-L.G!A
M<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](F%L;%1A8FQE0V]L=6UN<R(O/@H*("`@("`@("`\>'-L
M.F9O<BUE86-H('-E;&5C=#TB)&%L;%1A8FQE0V]L=6UN<R(^"@H@("`@("`@
M("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F-O;'5M;BUS='EL92UE;G1R>2(@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82]A;&QS='EL97,O*EMN86UE
M*"D@/2!T<F%N<VQA=&4H8W5R<F5N="@I+T!T86)L93IS='EL92UN86UE+"`G
M+B`E*"DO7"<L("<G*5TB+SX*("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB;F]T*$!T86)L93IN=6UB
M97(M8V]L=6UN<RUR97!E871E9"DB/@H@("`@("`@("`@("`@("`@("`@(#PA
M+2T@=W)I=&5S(&%N(&5N=')Y(&]F(&$@8V]L=6UN(&EN('1H92!C;VQU;6YS
M+79A<FEA8FQE("TM/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)A9&1I;F<M8V]L=6UN+7-T>6QE+65N=')Y(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O
M;'5M;BUS='EL92UE;G1R>2(@<V5L96-T/2(D8V]L=6UN+7-T>6QE+65N=')Y
M(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*
M("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`\
M(2TM($YO(&AI9VAE<B!R97!E=&ET:6]N(&]F(&-E;&QS(&=R96%T97(@=&AA
M;B`T(&9O<B!T:&4@;&%S="!A;F0@<V5C;VYD(&QA<W0@8V]L=6UN("TM/@H@
M("`@("`@("`@("`@("`@/"$M+2!A(&AA8VL@9F]R('1H92!S86UP;&4@9&]C
M=6UE;G0@)U=A96AR=6YG<W5M<F5C:&YE<BYS>&,@:&%V:6YG(#(S,"!R97!E
M871E9"!C;VQU;6YS(&EN('1H92!S96-O;F0@;&%S="!C;VQU;6X@+2T^"B`@
M("`@("`@("`@("`@("`\(2TM(#\_/R`\>'-L.G=H96X@=&5S=#TB*'!O<VET
M:6]N*"D@/2!L87-T*"D@;W(@*'!O<VET:6]N*"D@/2`H;&%S="@I("T@,2DI
M(&%N9"!`=&%B;&4Z;G5M8F5R+6-O;'5M;G,M<F5P96%T960@)FQT.R`U*2(^
M(#\_/RTM/@H@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](G!O<VET
M:6]N*"D@/2!L87-T*"D@;W(@<&]S:71I;VXH*2`]("AL87-T*"D@+2`Q*2(^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2)`=&%B;&4Z;G5M
M8F5R+6-O;'5M;G,M<F5P96%T960@)FQT.R`U(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/"$M+2!W<FET97,@86X@96YT<GD@;V8@82!C;VQU;6X@:6X@
M=&AE(&-O;'5M;G,M=F%R:6%B;&4@+2T^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)R97!E870M861D:6YG+6-O
M;'5M;BUS='EL92UE;G1R>2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L=6UN+7-T>6QE+65N=')Y(B`@
M("`@("!S96QE8W0](B1C;VQU;6XM<W1Y;&4M96YT<GDB+SX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)N=6UB
M97(M8V]L=6UN<RUR97!E871E9"(@('-E;&5C=#TB,2(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@
M("`@("`@("`@(#PA+2T@<F5P96%T960@8V]L=6US('=I;&P@8F4@=W)I='1E
M;B!E>'!L:6-I="!S979E<F%L('1I;65S(&EN('1H92!V87)I86)L92TM/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)R
M97!E870M861D:6YG+6-O;'5M;BUS='EL92UE;G1R>2(^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQU;6XM<W1Y
M;&4M96YT<GDB("`@("`@("`@("!S96QE8W0](B1C;VQU;6XM<W1Y;&4M96YT
M<GDB+SX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](FYU;6)E<BUC;VQU;6YS+7)E<&5A=&5D(B`@("`@('-E;&5C=#TB
M0'1A8FQE.FYU;6)E<BUC;VQU;6YS+7)E<&5A=&5D(B\^"B`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@
M(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@
M("`@("`@(#PO>'-L.F9O<BUE86-H/@H@("`@(#PO>'-L.G1E;7!L871E/@H*
M"B`@("`\(2TM(%=2251%4R!42$4@4D5014%4140@0T],54U.(%-464Q%($58
M4$Q)0TE4($%3($%.($5,14U%3E0@24X@5$A%($-/3%5-3E,M5D%224%"3$4@
M+2T^"B`@("`\>'-L.G1E;7!L871E(&YA;64](G)E<&5A="UA9&1I;F<M8V]L
M=6UN+7-T>6QE+65N=')Y(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O
M;'5M;BUS='EL92UE;G1R>2(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB
M;G5M8F5R+6-O;'5M;G,M<F5P96%T960B+SX*"B`@("`@("`@/'AS;#IC:&]O
M<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;G5M8F5R+6-O;'5M
M;G,M<F5P96%T960@/B`Q(CX*("`@("`@("`@("`@("`@(#PA+2T@=W)I=&5S
M(&%N(&5N=')Y(&]F(&$@8V]L=6UN(&EN('1H92!C;VQU;6YS+79A<FEA8FQE
M("TM/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M(F%D9&EN9RUC;VQU;6XM<W1Y;&4M96YT<GDB/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQU;6XM<W1Y;&4M96YT<GDB
M("`@<V5L96-T/2(D8V]L=6UN+7-T>6QE+65N=')Y(B\^"B`@("`@("`@("`@
M("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@/"$M
M+2!R97!E870@8V%L;&EN9R!T:&ES(&UE=&AO9"!U;G1I;"!A;&P@96QE;65N
M=',@=W)I='1E;B!O=70@+2T^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM
M=&5M<&QA=&4@;F%M93TB<F5P96%T+6%D9&EN9RUC;VQU;6XM<W1Y;&4M96YT
M<GDB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)C;VQU;6XM<W1Y;&4M96YT<GDB("`@("`@('-E;&5C=#TB)&-O;'5M;BUS
M='EL92UE;G1R>2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)N=6UB97(M8V]L=6UN<RUR97!E871E9"(@('-E;&5C=#TB
M)&YU;6)E<BUC;VQU;6YS+7)E<&5A=&5D("T@,2(O/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@
M("`\(2TM('=R:71E<R!A;B!E;G1R>2!O9B!A(&-O;'5M;B!I;B!T:&4@8V]L
M=6UN<RUV87)I86)L92`M+3X*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)A9&1I;F<M8V]L=6UN+7-T>6QE+65N=')Y(CX*("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L=6UN
M+7-T>6QE+65N=')Y(B`@('-E;&5C=#TB)&-O;'5M;BUS='EL92UE;G1R>2(O
M/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@
M("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*
M("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\(2TM(%1(12!#3TQ534XM4U19
M3$4@5U))5$4M4$%45$523B!&3U(@14%#2"!#3TQ534X@5U))5%1%3B!)3B!!
M(%9!4DE!0DQ%("TM/@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)A9&1I;F<M
M8V]L=6UN+7-T>6QE+65N=')Y(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(F-O;'5M;BUS='EL92UE;G1R>2(O/@H*("`@("`@("`\>'-L.F5L96UE;G0@
M;F%M93TB8V]L=6UN+7-T>6QE+65N=')Y(CX*("`@("`@("`@("`@/'AS;#IC
M:&]O<V4^"B`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'1A8FQE
M.G9I<VEB:6QI='D@/2`G8V]L;&%P<V4G(&]R($!T86)L93IV:7-I8FEL:71Y
M(#T@)V9I;'1E<B<B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB
M=71E(&YA;64](F-O;'5M;BUH:61D96XM9FQA9R(^=')U93PO>'-L.F%T=')I
M8G5T93X*("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G9A<FEA8FQE("!N86UE/2)T86)L93IS='EL92UN86UE(B`@("`@("`@('-E
M;&5C=#TB=')A;G-L871E*$!T86)L93IS='EL92UN86UE+"`G+B`E*"DO7"<L
M("<G*2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA
M;64](G-T>6QE+6YA;64B/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(D=&%B;&4Z
M<W1Y;&4M;F%M92(O/CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&-O;'5M;BUS='EL92UE;G1R
M>2(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@
M("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@
M(#PO>'-L.G1E;7!L871E/@H*"@H@("`@/"$M+6ES1&5B=6=-;V1E+5-405)4
M+2T^"B`@("`\(2TM(&=I=FEN9R!O=70@=&AE("=A;&Q#;VQU;6Y3='EL92<@
M=F%R:6%B;&4Z"B`@("`@("`@1F]R(&5A8V@@)V-O;'5M;BUS='EL92UE;G1R
M>2<@;V8@=&AE("=A;&Q#;VQU;6Y3='EL945N=')I97,G('9A<FEA8FQE('1H
M92!S='EL92UN86UE(&ES(&=I=F5N(&]U="X*("`@("`@("!);B!C87-E(&]F
M("=C;VQU;6XM:&ED9&5N+69L86<G(&%T=')I8G5T92!T:&4@=&5X="`G0V]L
M=6UN(&ES(&AI9&1E;B!I<R!G:79E;B!O=70N+2T^"B`@("`\>'-L.G1E;7!L
M871E(&YA;64](G1A8FQE+61E8G5G+6%L;$-O;'5M;E-T>6QE16YT<FEE<R(^
M"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)A;&Q#;VQU;6Y3='EL945N=')I
M97,B+SX*"B`@("`@("`@/"$M+2!D96)U9R!O=71P=70@87,@=&%B;&4@<W5M
M;6%R>2!A='1R:6)U="!I;B!H=&UL("TM/@H@("`@("`@(#QX<VPZ871T<FEB
M=71E(&YA;64](G-U;6UA<GDB/@H@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB=&%B;&4M9&5B=6<M8V]L=6UN+6]U="(^"B`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL0V]L=6UN4W1Y;&5%
M;G1R:65S(B!S96QE8W0](B1A;&Q#;VQU;6Y3='EL945N=')I97,B+SX*("`@
M("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`\+WAS;#IA
M='1R:6)U=&4^"B`@("`@("`@/"$M+2!D96)U9R!O=71P=70@=&\@8V]N<V]L
M92`M+3X*("`@("`@("`\>'-L.FUE<W-A9V4^"B`@("`@("`@("`@(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)T86)L92UD96)U9RUC;VQU;6XM;W5T(CX*
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q#;VQU
M;6Y3='EL945N=')I97,B('-E;&5C=#TB)&%L;$-O;'5M;E-T>6QE16YT<FEE
M<R(O/@H@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M(#PO>'-L.FUE<W-A9V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/'AS
M;#IT96UP;&%T92!N86UE/2)T86)L92UD96)U9RUC;VQU;6XM;W5T(CX*("`@
M("`@("`\>'-L.G!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(O
M/@H@("`@("`@("`@("`\>'-L.G1E>'0^"B`@("`@("`@("`@($1E8G5G26YF
M;W)M871I;VXZ($9O<B!E86-H("=C;VQU;6XM<W1Y;&4M96YT<GDG(&]F('1H
M92`G86QL0V]L=6UN4W1Y;&5%;G1R:65S)R!V87)I86)L92!T:&4@<W1Y;&4M
M;F%M92!I<R!G:79E;B!O=70N"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@($EN(&-A<V4@;V8@)V-O;'5M;BUH:61D96XM9FQA9R<@871T<FEB=71E
M('1H92!T97AT("=C;VQU;6X@:7,@:&ED9&5N)R!I<R!G:79E;B!O=70N"B`@
M("`@("`@("`@(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`\>'-L.F9O
M<BUE86-H('-E;&5C=#TB)&%L;$-O;'5M;E-T>6QE16YT<FEE<R]C;VQU;6XM
M<W1Y;&4M96YT<GDB/@H@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB0&-O;'5M;BUH:61D96XM
M9FQA9R(^"B`@("`@("`@("`@(#QX<VPZ=&5X=#X@(#PO>'-L.G1E>'0^/'AS
M;#IV86QU92UO9B!S96QE8W0](D!S='EL92UN86UE(B\^/'AS;#IT97AT/F-O
M;'5M;B!I<R!H:61D96X\+WAS;#IT97AT/CQX<VPZ=&5X=#X*("`@("`@("`@
M("`@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@/'AS
M;#IT97AT/B`@/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB0'-T
M>6QE+6YA;64B+SX\>'-L.G1E>'0^(#T@/"]X<VPZ=&5X=#X\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB+B(O/CQX<VPZ=&5X=#X*("`@("`@("`@("`@/"]X<VPZ
M=&5X=#X*("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@
M("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`\+WAS;#IT96UP;&%T93X*("`@
M(#PA+2UI<T1E8G5G36]D92U%3D0M+3X*"CPO>'-L.G-T>6QE<VAE970^"@``
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E
M<B]O;V\O=&%B;&5?<F]W<RYX<VP`````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3<U,C4`
M,3`U,34T,S,W-#<`,#(U,34W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#PA+2T*"B`@(%1H92!#;VYT96YT<R!O9B!T:&ES
M(&9I;&4@87)E(&UA9&4@879A:6QA8FQE('-U8FIE8W0@=&\@=&AE('1E<FUS
M(&]F"B`@(&5I=&AE<B!O9B!T:&4@9F]L;&]W:6YG(&QI8V5N<V5S"@H@("`@
M("`@("`@+2!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R
M<VEO;B`R+C$*("`@("`@("`@("T@4W5N($EN9'5S=')Y(%-T86YD87)D<R!3
M;W5R8V4@3&EC96YS92!697)S:6]N(#$N,0H*("`@4W5N($UI8W)O<WES=&5M
M<R!);F,N+"!/8W1O8F5R+"`R,#`P"@H@("!'3E4@3&5S<V5R($=E;F5R86P@
M4'5B;&EC($QI8V5N<V4@5F5R<VEO;B`R+C$*("`@/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@($-O<'ER:6=H="`R
M,#`P(&)Y(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*("`@.3`Q(%-A;B!!;G1O
M;FEO(%)O860L(%!A;&\@06QT;RP@0T$@.30S,#,L(%5300H*("`@5&AI<R!L
M:6)R87)Y(&ES(&9R964@<V]F='=A<F4[('EO=2!C86X@<F5D:7-T<FEB=71E
M(&ET(&%N9"]O<@H@("!M;V1I9GD@:70@=6YD97(@=&AE('1E<FUS(&]F('1H
M92!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC"B`@($QI8V5N<V4@=F5R<VEO
M;B`R+C$L(&%S('!U8FQI<VAE9"!B>2!T:&4@1G)E92!3;V9T=V%R92!&;W5N
M9&%T:6]N+@H*("`@5&AI<R!L:6)R87)Y(&ES(&1I<W1R:6)U=&5D(&EN('1H
M92!H;W!E('1H870@:70@=VEL;"!B92!U<V5F=6PL"B`@(&)U="!7251(3U54
M($%.62!705)204Y463L@=VET:&]U="!E=F5N('1H92!I;7!L:65D('=A<G)A
M;G1Y(&]F"B`@($U%4D-(04Y404))3$E462!O<B!&251.15-3($9/4B!!(%!!
M4E1)0U5,05(@4%524$]312X@(%-E92!T:&4@1TY5"B`@($QE<W-E<B!'96YE
M<F%L(%!U8FQI8R!,:6-E;G-E(&9O<B!M;W)E(&1E=&%I;',N"@H@("!9;W4@
M<VAO=6QD(&AA=F4@<F5C96EV960@82!C;W!Y(&]F('1H92!'3E4@3&5S<V5R
M($=E;F5R86P@4'5B;&EC"B`@($QI8V5N<V4@86QO;F<@=VET:"!T:&ES(&QI
M8G)A<GD[(&EF(&YO="P@=W)I=&4@=&\@=&AE($9R964@4V]F='=A<F4*("`@
M1F]U;F1A=&EO;BP@26YC+BP@-3D@5&5M<&QE(%!L86-E+"!3=6ET92`S,S`L
M($)O<W1O;BP*("`@34$@(#`R,3$Q+3$S,#<@(%5300H*"B`@(%-U;B!);F1U
M<W1R>2!3=&%N9&%R9',@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$*("`@
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/0H@("!4:&4@8V]N=&5N=',@;V8@=&AI<R!F:6QE(&%R92!S=6)J96-T
M('1O('1H92!3=6X@26YD=7-T<GD@4W1A;F1A<F1S"B`@(%-O=7)C92!,:6-E
M;G-E(%9E<G-I;VX@,2XQ("AT:&4@(DQI8V5N<V4B*3L@66]U(&UA>2!N;W0@
M=7-E('1H:7,@9FEL90H@("!E>&-E<'0@:6X@8V]M<&QI86YC92!W:71H('1H
M92!,:6-E;G-E+B!9;W4@;6%Y(&]B=&%I;B!A(&-O<'D@;V8@=&AE"B`@($QI
M8V5N<V4@870@:'1T<#HO+W=W=RYO<&5N;V9F:6-E+F]R9R]L:6-E;G-E+FAT
M;6PN"@H@("!3;V9T=V%R92!P<F]V:61E9"!U;F1E<B!T:&ES($QI8V5N<V4@
M:7,@<')O=FED960@;VX@86X@(D%3($E3(B!B87-I<RP*("`@5TE42$]55"!7
M05)204Y462!/1B!!3ED@2TE.1"P@14E42$52($584%)%4U,@3U(@24U03$E%
M1"P@24Y#3%5$24Y'+`H@("!7251(3U54($Q)34E4051)3TXL(%=!4E)!3E1)
M15,@5$A!5"!42$4@4T]&5%=!4D4@25,@1E)%12!/1B!$149%0U13+`H@("!-
M15)#2$%.5$%"3$4L($9)5"!&3U(@02!005)424-53$%2(%!54E!/4T4L($]2
M($Y/3BU)3D9224Y'24Y'+@H@("!3964@=&AE($QI8V5N<V4@9F]R('1H92!S
M<&5C:69I8R!P<F]V:7-I;VYS(&=O=F5R;FEN9R!Y;W5R(')I9VAT<R!A;F0*
M("`@;V)L:6=A=&EO;G,@8V]N8V5R;FEN9R!T:&4@4V]F='=A<F4N"@H@("!4
M:&4@26YI=&EA;"!$979E;&]P97(@;V8@=&AE($]R:6=I;F%L($-O9&4@:7,Z
M(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*"B`@($-O<'ER:6=H="#"J2`R,#`R
M(&)Y(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*"B`@($%L;"!2:6=H=',@4F5S
M97)V960N"@H@("!#;VYT<FEB=71O<BAS*3H@7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7U]?7U]?"@HM+3X*/'AS;#IS='EL97-H965T('9E
M<G-I;VX](C$N,"(*("`@("`@("`@("`@("`@('AM;&YS.GAS;#TB:'1T<#HO
M+W=W=RYW,RYO<F<O,3DY.2]84TPO5')A;G-F;W)M(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z;V9F:6-E/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]O
M9F9I8V4B"B`@("`@("`@("`@("`@("!X;6QN<SIS='EL93TB:'1T<#HO+V]P
M96YO9F9I8V4N;W)G+S(P,#`O<W1Y;&4B"B`@("`@("`@("`@("`@("!X;6QN
M<SIT97AT/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]T97AT(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z=&%B;&4](FAT='`Z+R]O<&5N;V9F:6-E+F]R
M9R\R,#`P+W1A8FQE(@H@("`@("`@("`@("`@("`@>&UL;G,Z9')A=STB:'1T
M<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9')A=VEN9R(*("`@("`@("`@("`@
M("`@('AM;&YS.F9O/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+UA33"]&;W)M
M870B"B`@("`@("`@("`@("`@("!X;6QN<SIX;&EN:STB:'1T<#HO+W=W=RYW
M,RYO<F<O,3DY.2]X;&EN:R(*("`@("`@("`@("`@("`@('AM;&YS.FYU;6)E
M<CTB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9&%T87-T>6QE(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z<W9G/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`P
M+W-V9R(*("`@("`@("`@("`@("`@('AM;&YS.F-H87)T/2)H='1P.B\O;W!E
M;F]F9FEC92YO<F<O,C`P,"]C:&%R="(*("`@("`@("`@("`@("`@('AM;&YS
M.F1R,V0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1R,V0B"B`@("`@
M("`@("`@("`@("!X;6QN<SIM871H/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DX
M+TUA=&@O36%T:$U,(@H@("`@("`@("`@("`@("`@>&UL;G,Z9F]R;3TB:'1T
M<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9F]R;2(*("`@("`@("`@("`@("`@
M('AM;&YS.G-C<FEP=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O<V-R
M:7!T(@H@("`@("`@("`@("`@("`@;V9F:6-E.F-L87-S/2)T97AT(@H@("`@
M("`@("`@("`@("`@;V9F:6-E.G9E<G-I;VX](C$N,"(*("`@("`@("`@("`@
M("`@('AM;&YS.F1C/2)H='1P.B\O<'5R;"YO<F<O9&,O96QE;65N=',O,2XQ
M+R(*("`@("`@("`@("`@("`@('AM;&YS.FUE=&$](FAT='`Z+R]O<&5N;V9F
M:6-E+F]R9R\R,#`P+VUE=&$B"B`@("`@("`@("`@("`@("!X;6QN<SIC;VYF
M:6<](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`Q+V-O;F9I9R(*("`@("`@
M("`@("`@("`@('AM;&YS.FAE;'`](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R
M,#`P+VAE;'`B"B`@("`@("`@("`@("`@("!X;6QN<SIX=#TB:'1T<#HO+W=W
M=RYJ8VQA<FLN8V]M+WAT(@H@("`@("`@("`@("`@("`@>&UL;G,Z<WES=&5M
M/2)H='1P.B\O=W=W+FIC;&%R:RYC;VTO>'0O:F%V82]J879A+FQA;F<N4WES
M=&5M(@H@("`@("`@("`@("`@("`@>&UL;G,Z>&%L86X](FAT='`Z+R]X;6PN
M87!A8VAE+F]R9R]X86QA;B(*("`@("`@("`@("`@("`@('AM;&YS.FIA=F$]
M(FAT='`Z+R]X;6PN87!A8VAE+F]R9R]X<VQT+VIA=F$B"B`@("`@("`@("`@
M("`@("!E>&-L=61E+7)E<W5L="UP<F5F:7AE<STB:F%V82(^"@H*"B`@("`\
M(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*B`M+3X*("`@(#PA+2T@*BHJ('=R:71E("AE>'!L:6-I="D@<F5P96%T
M:6YG('1A8FQE(')O=W,@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H@("`@/'AS
M;#IT96UP;&%T92!N86UE/2)R97!E870M=W)I=&4M<F]W(CX*("`@("`@("`\
M>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(O/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB;G5M8F5R+7)O=W,M<F5P96%T960B
M('-E;&5C=#TB,2(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB;6%X4F]W
M3&5N9W1H(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\
M(2TM('=R:71E(&%N(&5N=')Y(&]F(&$@<F]W(&%N9"!R97!E870@8V%L;&EN
M9R!T:&ES(&UE=&AO9"!U;G1I;"!A;&P@96QE;65N=',@87)E('=R:71T96X@
M;W5T("TM/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&YU;6)E<BUR
M;W=S+7)E<&5A=&5D(#X@,2!A;F0@*'1A8FQE.G1A8FQE+6-E;&PO=&5X="@I
M(&]R('1A8FQE.G1A8FQE+6-E;&PO*BDB/@H@("`@("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+7)O=R(^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B("`@("`@('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL
M0V]L=6UN4W1Y;&5%;G1R:65S(B`@("!S96QE8W0](B1A;&Q#;VQU;6Y3='EL
M945N=')I97,B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB;6%X4F]W3&5N9W1H(B`@("`@("`@("`@("!S96QE8W0](B1M
M87A2;W=,96YG=&@B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"@H@("`@("`@("`@("`@("`@/"$M+2`R1$\Z('1A:V4@=F%R:6%B
M;&4@9G)O;2!T:&4@;W5T<'5T(&]F(')E<&5A=&5D('=R:71E+7)O=R!A;F0@
M:71E<F%T92!G:79I;F<@;W5T('1H92!V87)I86)L92`M+3X*("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)R97!E870M=W)I=&4M
M<F]W(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@("`@("`@<V5L96-T/2(D8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)A;&Q#;VQU;6Y3='EL945N=')I97,B("`@('-E;&5C
M=#TB)&%L;$-O;'5M;E-T>6QE16YT<FEE<R(O/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)M87A2;W=,96YG=&@B("`@("`@
M("`@("`@('-E;&5C=#TB)&UA>%)O=TQE;F=T:"(O/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)N=6UB97(M<F]W<RUR97!E
M871E9"(@("`@('-E;&5C=#TB)&YU;6)E<BUR;W=S+7)E<&5A=&5D("T@,2(O
M/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/"$M+2!W<FET92!A('-I
M;F=L92!E;G1R>2!O9B!A(')O=R`M+3X*("`@("`@("`@("`@/'AS;#IO=&AE
M<G=I<V4^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TB=W)I=&4M<F]W(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@("`@("`@<V5L96-T
M/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q#;VQU;6Y3='EL945N=')I97,B
M("`@('-E;&5C=#TB)&%L;$-O;'5M;E-T>6QE16YT<FEE<R(O/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)M87A2;W=,96YG
M=&@B("`@("`@("`@("`@('-E;&5C=#TB)&UA>%)O=TQE;F=T:"(O/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@
M/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO
M>'-L.G1E;7!L871E/@H*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)W<FET
M92UR;W<B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB86QL0V]L=6UN
M4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)M87A2
M;W=,96YG=&@B+SX*"@H@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)T<B(^
M"B`@("`@("`@("`@(#PA+2T@=W)I=&EN9R!T:&4@<W1Y;&4@;V8@=&AE(')O
M=R`M+3X*("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64])V%D
M9"US='EL92UP<F]P97)T:65S)SX*("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C
M;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@(#PO>'-L.F-A;&PM
M=&5M<&QA=&4^"@H@("`@("`@("`@("`\>'-L.FEF('1E<W0](B1I<T1E8G5G
M36]D92(^"B`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^"BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHG='(G(&5L96UE;G0@:&%S(&)E96X@861D960A
M/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@/"]X<VPZ:68^"@H@("`@("`@
M("`@("`\>'-L.F%P<&QY+71E;7!L871E<R!S96QE8W0](G1A8FQE.G1A8FQE
M+6-E;&PB/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B("`@("`@('-E;&5C=#TB)&-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)A;&Q#;VQU;6Y3='EL945N=')I97,B("`@('-E;&5C=#TB)&%L
M;$-O;'5M;E-T>6QE16YT<FEE<R(O/@H@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](FUA>%)O=TQE;F=T:"(@("`@("`@("`@("`@<V5L
M96-T/2(D;6%X4F]W3&5N9W1H(B\^"B`@("`@("`@("`@(#PO>'-L.F%P<&QY
M+71E;7!L871E<SX*"B`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@(#PO>'-L
M.G1E;7!L871E/@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!(14Q015(Z('1A8FQE('-T>6QE<R`J
M*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@
M+2T^"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)A9&0M<W1Y;&4M<')O<&5R
M=&EE<R(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B
M86Q$871A(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)A;&Q#;VQU;6Y3
M='EL945N=')I97,B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](FYO9&4M
M<&]S:71I;VXB+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@
M(#PA+2TK*RLK*R!#4U,@*$-!4T-!1$E.1R!35$Q912!32$5%5"D@2$5!1$52
M(%-464Q%(%=!62`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB)&]U='!U=%1Y<&4@/2`G0U-37TA%041%4B<B/@H@("`@("`@("`@("`@
M("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8VQA<W,B/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)T<F%N<VQA=&4H0'1A8FQE
M.G-T>6QE+6YA;64L("<N("4H*2]<)RP@)R<I(B\^"B`@("`@("`@("`@("`@
M("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"@H@
M("`@("`@("`@("`\(2TM*RLK*RL@2%1-3"`T+C`@24Y,24Y%1"!705D@("LK
M*RLK+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP
M92`]("=#4U-?24Y,24Y%1"<B/@H@("`@("`@("`@("`@("`@/'AS;#IA='1R
M:6)U=&4@;F%M93TB<W1Y;&4B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82]A;&QS='EL
M97,O*EMN86UE*"D]8W5R<F5N="@I+T!T86)L93IS='EL92UN86UE72(O/@H@
M("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E
M;7!L871E/@H*/"]X<VPZ<W1Y;&5S:&5E=#X*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O34E-12]6:65W97(O;V]O+G!H<```````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`W,C(Q`#$P-3$U-#,S-S0W`#`R,C<V-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@5&AE($U)345?5FEE=V5R7V]O;R!C;&%S<R!R96YD97)S(&]U="!/<&5N
M3V9F:6-E+F]R9PH@*B!D;V-U;65N=',@:6X@2%1-3"!F;W)M870N"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;V]O+G!H<"QV
M(#$N,30N,3`N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L
M;RYC;VT^"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@2F%N(%-C:&YE:61E<B`\
M:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UA
M<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J($!A=71H;W(@($IA;B!3
M8VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N
M,`H@*B!`<&%C:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-
M15]6:65W97)?;V]O(&5X=&5N9',@34E-15]6:65W97(@>PH*("`@("\J*@H@
M("`@("H@4F5N9&5R(&]U="!T:&4@8W5R<F5N="!D871A+@H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@<&%R86UE=&5R<R!T:&4@
M5FEE=V5R(&UA>2!N965D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@<F5N9&5R960@8V]N=&5N=',N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E;F1E<B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=7-E
M7WAS;'0@/2!5=&EL.CIE>'1E;G-I;VY%>&ES=',H)WAS;'0G*2!\?"!F=6YC
M=&EO;E]E>&ES=',H)V1O;7AM;%]X<VQT7W-T>6QE<VAE971?9FEL92<I.PH@
M("`@("`@(&EF("@D=7-E7WAS;'0I('L*("`@("`@("`@("`@)'1M<&1I<B`]
M(%5T:6PZ.F-R96%T951E;7!$:7(H=')U92D["B`@("`@("`@?0H*("`@("`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+T-O;7!R97-S+G!H<"<["B`@("`@("`@
M)'AM;%]T86=S("`](&%R<F%Y*"=T97AT.G`G+"`G=&%B;&4Z=&%B;&4@)RP@
M)W1A8FQE.G1A8FQE+7)O=R<L("=T86)L93IT86)L92UC96QL)RP@)W1A8FQE
M.FYU;6)E<BUC;VQU;6YS+7-P86YN960])RD["B`@("`@("`@)&AT;6Q?=&%G
M<R`](&%R<F%Y*"=P)RP@)W1A8FQE(&)O<F1E<CTB,"(@8V5L;'-P86-I;F<]
M(C$B(&-E;&QP861D:6YG/2(P(B`G+"`G='(@8F=C;VQO<CTB(V-C8V-C8R(G
M+"`G=&0G+"`G8V]L<W!A;CTG*3L*("`@("`@("`D>FEP(#T@)DAO<F1E7T-O
M;7!R97-S.CIS:6YG;&5T;VXH)WII<"<I.PH@("`@("`@("1L:7-T(#T@)'II
M<"T^9&5C;VUP<F5S<R@D=&AI<RT^;6EM95]P87)T+3YG971#;VYT96YT<R@I
M+`H@("`@("`@("`@("!A<G)A>2@G86-T:6]N)R`]/B!(3U)$15]#3TU04D53
M4U]:25!?3$E35"DI.PH@("`@("`@(&9O<F5A8V@@*"1L:7-T(&%S("1K97D@
M/3X@)&9I;&4I('L*("`@("`@("`@("`@:68@*"1F:6QE6R=N86UE)UT@/3T@
M)V-O;G1E;G0N>&UL)R!\?`H@("`@("`@("`@("`@("`@)&9I;&5;)VYA;64G
M72`]/2`G<W1Y;&5S+GAM;"<@?'P*("`@("`@("`@("`@("`@("1F:6QE6R=N
M86UE)UT@/3T@)VUE=&$N>&UL)RD@>PH@("`@("`@("`@("`@("`@)&-O;G1E
M;G0@/2`D>FEP+3YD96-O;7!R97-S*"1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O
M;G1E;G1S*"DL"B`@("`@("`@("`@("`@("`@("`@87)R87DH)V%C=&EO;B<@
M/3X@2$]21$5?0T]-4%)%4U-?6DE07T1!5$$L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VEN9F\G("`@/3X@)&QI<W0L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VME>2<@("`@/3X@)&ME>2DI.PH@("`@("`@("`@("`@("`@
M:68@*"1U<V5?>'-L="D@>PH@("`@("`@("`@("`@("`@("`@("1F<"`](&9O
M<&5N*"1T;7!D:7(@+B`D9FEL95LG;F%M92==+"`G=R<I.PH@("`@("`@("`@
M("`@("`@("`@(&9W<FET92@D9G`L("1C;VYT96YT*3L*("`@("`@("`@("`@
M("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("`@("`@("`@('T@96QS96EF
M("@D9FEL95LG;F%M92==(#T]("=C;VYT96YT+GAM;"<I('L*("`@("`@("`@
M("`@("`@("`@("`D8V]N=&5N="`]('-T<E]R97!L86-E*"1X;6Q?=&%G<RP@
M)&AT;6Q?=&%G<RP@)&-O;G1E;G0I.PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D8V]N=&5N=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!I9B`H(55T:6PZ.F5X=&5N<VEO;D5X:7-T
M<R@G>'-L="<I*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@
M("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V1O;7AM;%]X<VQT7W-T>6QE
M<VAE971?9FEL92<I*2!["B`@("`@("`@("`@("\O(%5S92!$3TU834P*("`@
M("`@("`@("`@)'AS;'0@/2!D;VUX;6Q?>'-L=%]S='EL97-H965T7V9I;&4H
M9&ER;F%M92A?7T9)3$5?7RD@+B`G+V]O;R]M86EN7VAT;6PN>'-L)RD["B`@
M("`@("`@("`@("1D;VT@(#T@9&]M>&UL7V]P96Y?9FEL92@D=&UP9&ER("X@
M)V-O;G1E;G0N>&UL)RD["B`@("`@("`@("`@("1R97-U;'0@/2!`)'AS;'0M
M/G!R;V-E<W,H)&1O;2P@87)R87DH)VUE=&%&:6QE55),)R`]/B`D=&UP9&ER
M("X@)VUE=&$N>&UL)RP@)W-T>6QE<T9I;&554DPG(#T^("1T;7!D:7(@+B`G
M<W1Y;&5S+GAM;"<L("=D:7-A8FQE2F%V82<@/3X@=')U92DI.PH@("`@("`@
M("`@("!R971U<FX@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D>'-L="T^<F5S
M=6QT7V1U;7!?;65M*"1R97-U;'0I+"`G551&+3@G+"!.3%,Z.F=E=$-H87)S
M970H*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@57-E(%A3
M3%0*("`@("`@("`@("`@)'AS;'0@/2!X<VQT7V-R96%T92@I.PH@("`@("`@
M("`@("`D<F5S=6QT(#T@0'AS;'1?<')O8V5S<R@D>'-L="P@)'1M<&1I<B`N
M("=C;VYT96YT+GAM;"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&1I<FYA;64H7U]&24Q%7U\I("X@)R]O;V\O;6%I;E]H=&UL+GAS
M;"<L(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=M971A1FEL95523"<@/3X@)'1M<&1I<B`N("=M971A
M+GAM;"<L("=S='EL97-&:6QE55),)R`]/B`D=&UP9&ER("X@)W-T>6QE<RYX
M;6PG+"`G9&ES86)L94IA=F$G(#T^('1R=64I*3L*("`@("`@("`@("`@:68@
M*"$D<F5S=6QT*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@>'-L=%]E
M<G)O<B@D>'-L="D["B`@("`@("`@("`@('T*("`@("`@("`@("`@>'-L=%]F
M<F5E*"1X<VQT*3L*("`@("`@("`@("`@<F5T=7)N(%-T<FEN9SHZ8V]N=F5R
M=$-H87)S970H)')E<W5L="P@)U541BTX)RP@3DQ3.CIG971#:&%R<V5T*"DI
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@
M34E-12!C;VYT96YT('1Y<&4@;V8@=&AE(')E;F1E<F5D(&-O;G1E;G0N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C;VYT96YT('1Y<&4@
M;V8@=&AE(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5'EP92@I
M"B`@("!["B`@("`@("`@<F5T=7)N("=T97AT+VAT;6P[(&-H87)S970])R`N
M($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O<&1F+G!H
M<```````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-3,Q`#$P-3$U-#,S
M-S0W`#`R,C<T,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&AE($U)345?5FEE=V5R7W!D9B!C;&%S
M<R!S:6UP;'D@;W5T<'5T<R!T:&4@4$1&(&9I;&4@=VET:"!T:&4@8V]N=&5N
M="UT>7!E"B`J("=A<'!L:6-A=&EO;B]P9&8G(&5N86)L:6YG('=E8B!B<F]W
M<V5R<R!W:71H(&$@4$1&('9I97=E<B!P;'5G:6X@=&\@=FEE=PH@*B!T:&4@
M4$1&(&9I;&4@:6YS:61E('1H92!B<F]W<V5R+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W!D9BYP:'`L=B`Q+C,N,3(N-2`R
M,#`V+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P,RTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O
M;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA
M96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@
M0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE
M=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]P9&8@97AT96YD<R!-24U%7U9I
M97=E<B!["@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&-O;G1E;G0M='EP
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O;G1E;G0M
M='EP92!O9B!T:&4@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714
M>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)V%P<&QI8V%T:6]N+W!D9B<[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O
M<&AP+G!H<```````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-S`U`#$P
M-3$U-#,S-S0W`#`R,C<V-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&
M24Q%7U\I("X@)R]S;W5R8V4N<&AP)SL*"B\J*@H@*B!4:&4@34E-15]6:65W
M97)?<&AP(&-L87-S(')E;F1E<G,@;W5T('-Y;G1A>"UH:6=H;&EG:'1E9"!0
M2%`@8V]D90H@*B!I;B!(5$U,(&9O<FUA="X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]P:'`N<&AP+'8@,2XR,BXQ,"XX(#(P
M,#8O,#8O,#$@,#,Z,#@Z-3,@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT
M(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A
M8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO"F-L87-S($U)345?5FEE=V5R
M7W!H<"!E>'1E;F1S($U)345?5FEE=V5R7W-O=7)C92!["@H@("`@+RHJ"B`@
M("`@*B!296YD97)S(&]U="!T:&4@8V]N=&5N=',N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N>2!P87)A;65T97)S('1H92!6:65W
M97(@;6%Y(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!R96YD97)E9"!C;VYT96YT<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N
M9&5R*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1R97-U;'1S
M(#T@=')I;2AS=')?<F5P;&%C92AA<G)A>2@B7&XB+"`G/&)R("\^)RDL(&%R
M<F%Y*"<G+"`B7&XB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:&EG:&QI9VAT7W-T<FEN9R@D=&AI<RT^;6EM95]P87)T+3YG971#
M;VYT96YT<R@I+"!T<G5E*2DI.PH*("`@("`@("`O+R!%9'5C871E9"!'=65S
M<R!A="!W:&5T:&5R('=E(&%R92!I;FQI;F4@;W(@;F]T+@H@("`@("`@(&EF
M("AH96%D97)S7W-E;G0H*2!\?"!O8E]G971?;&5N9W1H*"DI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YL:6YE3G5M8F5R*"1R97-U;'1S*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@571I;#HZ8G5F9F5R
M3W5T<'5T*"=R97%U:7)E)RP@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G
M=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUH96%D97(N:6YC)RD@
M+@H@("`@("`@("`@("`@("`@)'1H:7,M/FQI;F5.=6UB97(H)')E<W5L=',I
M("X*("`@("`@("`@("`@("`@(%5T:6PZ.F)U9F9E<D]U='!U="@G<F5Q=6ER
M92<L("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W1E;7!L871E<R<L("=H
M;W)D92<I("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<I.PH@("`@("`@('T*("`@
M('T*"GT*````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]-24U%+U9I97=E<B]P;&%I;BYP:'``````````````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#4T-S8`,3`U,34T,S,W-#<`,#(S,S$P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!4:&4@34E-15]6:65W97)?<&QA:6X@8VQA<W,@<F5N9&5R<R!O=70@
M<&QA:6X@=&5X="!W:71H(%523',@;6%D90H@*B!I;G1O(&AY<&5R;&EN:W,@
M*&EF('9I97=I;F<@:6YL:6YE*2X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]P;&%I;BYP:'`L=B`Q+C$X+C8N,3`@,C`P-B\P
M,2\R,R`Q-3HS-3HP-B!S;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q
M.3DY+3(P,#8@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*
M("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A
M<GI`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@06YI
M;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@0&%U=&AO<B`@
M36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&AO<F1E+F]R9SX*("H@0'-I;F-E
M("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J
M+PIC;&%S<R!-24U%7U9I97=E<E]P;&%I;B!E>'1E;F1S($U)345?5FEE=V5R
M('L*"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@=&AE(&-O;G1E;G1S+@H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@<&%R86UE
M=&5R<R!T:&4@5FEE=V5R(&UA>2!N965D+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@<F5N9&5R960@8V]N=&5N=',N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')E;F1E<B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@
M("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O0V]N=&5N=',N<&AP)SL*
M"B`@("`@("`@)'1E>'0@/2`D=&AI<RT^;6EM95]P87)T+3YG971#;VYT96YT
M<R@I.PH*("`@("`@("`O*B!#:&5C:R!F;W(@)V9L;W=E9"<@=&5X="!D871A
M+B`J+PH@("`@("`@("1F;&]W960@/2`H)'1H:7,M/FUI;65?<&%R="T^9V5T
M0V]N=&5N=%1Y<&5087)A;65T97(H)V9O<FUA="<I(#T]("=F;&]W960G*3L*
M("`@("`@("!I9B`H)&9L;W=E9"D@>PH@("`@("`@("`@("`D=&5X="`]("1T
M:&ES+3Y?9F]R;6%T1FQO=V5D*"1T97AT*3L*("`@("`@("!]"@H@("`@("`@
M("\J($EF(&-A;&QI;F<@87,@86X@871T86-H;65N="!F<F]M('9I97<N<&AP
M+"!W92!D;R!N;W0@=V%N=`H@("`@("`@("`@('1O(&%L=&5R('1H92!T97AT
M(&EN(&%N>2!W87D@=VET:"!(5$U,+B`J+PH@("`@("`@(&EF("A-24U%7T-O
M;G1E;G1S.CIV:65W07-!='1A8VAM96YT*"DI('L*("`@("`@("`@("`@<F5T
M=7)N("1T97AT.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G2&]R9&4O5&5X="]&:6QT97(N<&AP)SL*("`@("`@("`@("`@
M<F5T=7)N(%1E>'1?1FEL=&5R.CIF:6QT97(H)'1E>'0L("=T97AT,FAT;6PG
M+"!A<G)A>2@G<&%R<V5L979E;"<@/3X@5$585%](5$U,7TU)0U)/+"`G8VAA
M<G-E="<@/3X@;G5L;"P@)V-L87-S)R`]/B!N=6QL*2D["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!-24U%(&-O;G1E;G0@
M='EP92!O9B!T:&4@<F5N9&5R960@8V]N=&5N="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&-O;G1E;G0@='EP92!O9B!T:&4@;W5T<'5T
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O0V]N=&5N=',N<&AP)SL*("`@
M("`@("!R971U<FX@*$U)345?0V]N=&5N=',Z.G9I97=!<T%T=&%C:&UE;G0H
M*2D@/R`D=&AI<RT^;6EM95]P87)T+3YG9714>7!E*'1R=64I(#H@)W1E>'0O
M:'1M;#L@8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!&;W)M870@9FQO=V5D('1E>'0@9F]R($A434P@;W5T
M<'5T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("`@5&AE
M('1E>'0@=&\@9F]R;6%T+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&]P="`@
M("!4:&4@;W!T:6UA;"!L96YG=&@@=&\@=W)A<"X*("`@("`J($!P87)A;2!I
M;G1E9V5R("1M87@@("`@5&AE(&UA>&EM=6T@;&5N9W1H('1O('=R87`N(#`@
M;65A;G,@9&]N)W0@=W)A<"X*("`@("`J($!P87)A;2!B;V]L96%N("1D96QS
M<"`@5V%S('1E>'0@8W)E871E9"!W:71H($1E;%-P(&9O<FUA='1I;F<_"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!F;W)M871T960@=&5X
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@7V9O<FUA=$9L;W=E9"@D=&5X="P@
M)&]P="`](&YU;&PL("1M87@@/2!N=6QL+"`D9&5L<W`@/2!N=6QL*0H@("`@
M>PH@("`@("`@(')E<75I<F5?;VYC92`G5&5X="]&;&]W960N<&AP)SL*("`@
M("`@("`D9FQO=V5D(#T@)FYE=R!497AT7T9L;W=E9"@D=&AI<RT^;6EM95]P
M87)T+3YR97!L86-E14],*"1T97AT+"`B7&XB*2P@)'1H:7,M/FUI;65?<&%R
M="T^9V5T0VAA<G-E="@I*3L*("`@("`@("!I9B`H(6ES7VYU;&PH)&]P="DI
M('L*("`@("`@("`@("`@)&9L;W=E9"T^<V5T3W!T3&5N9W1H*"1O<'0I.PH@
M("`@("`@('T*("`@("`@("!I9B`H(6ES7VYU;&PH)&UA>"DI('L*("`@("`@
M("`@("`@)&9L;W=E9"T^<V5T36%X3&5N9W1H*"1M87@I.PH@("`@("`@('T*
M("`@("`@("!I9B`H(6ES7VYU;&PH)&1E;'-P*2D@>PH@("`@("`@("`@("`D
M9FQO=V5D+3YS971$96Q3<"@D9&5L<W`I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)&9L;W=E9"T^=&]&:7AE9"@I.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W)A<BYP:'``````````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q
M-C$R-@`Q,#4Q-30S,S<T-P`P,C(W-C,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!-24U%7U9I
M97=E<E]R87(@8VQA<W,@<F5N9&5R<R!O=70@=&AE(&-O;G1E;G1S(&]F("YR
M87(@87)C:&EV97,@:6X@2%1-3`H@*B!F;W)M870N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<"QV(#$N,3@N,3`N
M.2`R,#`V+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,3DY.2TR,#`V($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO
M<F<^"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E;"!#;V-H<F%N92`\
M;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J
M($!A=71H;W(@($UI8VAA96P@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN
M8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D
M95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6:65W97)?<F%R(&5X=&5N
M9',@34E-15]6:65W97(@>PH*("`@("\J*@H@("`@("H@4F%R(&-O;7!R97-S
M:6]N(&UE=&AO9',N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]M971H;V1S(#T@87)R87DH"B`@("`@("`@,'@S,"`@/3X@
M("=3=&]R92<L"B`@("`@("`@,'@S,2`@/3X@("=&87-T97-T)RP*("`@("`@
M("`P>#,R("`]/B`@)T9A<W0G+`H@("`@("`@(#!X,S,@(#T^("`G3F]R;6%L
M)RP*("`@("`@("`P>#,T("`]/B`@)T=O;V0G+`H@("`@("`@(#!X,S4@(#T^
M("`G0F5S="<*("`@("D["@H@("`@+RHJ"B`@("`@*B!296YD97(@;W5T('1H
M92!C=7)R96YT;'D@<V5T(&-O;G1E;G1S('5S:6YG(')A<BX*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY('!A<F%M971E<G,@=&AE
M(%9I97=E<B!M87D@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(')E;F1E<F5D(&-O;G1E;G1S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!R96YD97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)&-O
M;G1E;G1S(#T@)'1H:7,M/FUI;65?<&%R="T^9V5T0V]N=&5N=',H*3L*"B`@
M("`@("`@+RH@36%K92!S=7)E('1H:7,@:7,@82!V86QI9"!R87(@9FEL92X@
M*B\*("`@("`@("!I9B`H)'1H:7,M/F-H96-K4F%R1&%T82@D8V]N=&5N=',I
M(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@)SQP<F4^)R`N(%\H
M(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI
M=F4N(BD@+B`G/"]P<F4^)SL*("`@("`@("!]"@H@("`@("`@(')E<75I<F5?
M;VYC92`G2&]R9&4O5&5X="YP:'`G.PH*("`@("`@("`D<F%R1&%T82`]("1T
M:&ES+3YG971287)$871A*"1C;VYT96YT<RD["B`@("`@("`@)&9I;&5#;W5N
M="`](&-O=6YT*"1R87)$871A*3L*"B`@("`@("`@)'1E>'0@(#T@)SQS=')O
M;F<^)R`N(&AT;6QS<&5C:6%L8VAA<G,H<W!R:6YT9BA?*")#;VYT96YT<R!O
M9B!<(B5S7"(B*2P@)'1H:7,M/FUI;65?<&%R="T^9V5T3F%M92@I*2D@+B`G
M.CPO<W1R;VYG/B<@+B`B7&XB.PH@("`@("`@("1T97AT("X]("<\=&%B;&4^
M/'1R/CQT9"!A;&EG;CTB;&5F="(^/'1T/CQS<&%N(&-L87-S/2)F:7AE9"(^
M)SL*("`@("`@("`D=&5X="`N/2!497AT.CIH=&UL06QL4W!A8V5S*%\H(D%R
M8VAI=F4@3F%M92(I("X@)SH@("<@+B`D=&AI<RT^;6EM95]P87)T+3YG971.
M86UE*"DI("X@(EQN(CL*("`@("`@("`D=&5X="`N/2!497AT.CIH=&UL06QL
M4W!A8V5S*%\H(D%R8VAI=F4@1FEL92!3:7IE(BD@+B`G.B`G("X@<W1R;&5N
M*"1C;VYT96YT<RD@+B`G(&)Y=&5S)RD@+B`B7&XB.PH@("`@("`@("1T97AT
M("X](%1E>'0Z.FAT;6Q!;&Q3<&%C97,H*"1F:6QE0V]U;G0@(3T@,2D@/R!S
M<')I;G1F*%\H(D9I;&4@0V]U;G0Z("5S(&9I;&5S(BDL("1F:6QE0V]U;G0I
M(#H@<W!R:6YT9BA?*")&:6QE($-O=6YT.B`E<R!F:6QE(BDL("1F:6QE0V]U
M;G0I*3L*("`@("`@("`D=&5X="`N/2`B7&Y<;B(["B`@("`@("`@)'1E>'0@
M+CT@5&5X=#HZ:'1M;$%L;%-P86-E<R@*("`@("`@("`@("`@("`@("`@("`@
M<W1R7W!A9"A?*")&:6QE($YA;64B*2P@("`@(#4P+"`G("<L(%-44E]0041?
M4DE'2%0I("X*("`@("`@("`@("`@("`@("`@("`@<W1R7W!A9"A?*")!='1R
M:6)U=&5S(BDL("`@(#$P+"`G("<L(%-44E]0041?3$5&5"D@+@H@("`@("`@
M("`@("`@("`@("`@("!S=')?<&%D*%\H(E-I>F4B*2P@("`@("`@("`@,3`L
M("<@)RP@4U127U!!1%],1494*2`N"B`@("`@("`@("`@("`@("`@("`@('-T
M<E]P860H7R@B36]D:69I960@1&%T92(I+"`Q.2P@)R`G+"!35%)?4$%$7TQ%
M1E0I("X*("`@("`@("`@("`@("`@("`@("`@<W1R7W!A9"A?*")-971H;V0B
M*2P@("`@("`@(#$P+"`G("<L(%-44E]0041?3$5&5"D@+@H@("`@("`@("`@
M("`@("`@("`@("!S=')?<&%D*%\H(E)A=&EO(BDL("`@("`@("`@(#<L("<@
M)RP@4U127U!!1%],1494*0H@("`@("`@("`@("`@("`@("D@+B`B7&XB.PH*
M("`@("`@("`D=&5X="`N/2!S=')?<F5P96%T*"<M)RP@,3`V*2`N(")<;B([
M"@H@("`@("`@(&9O<F5A8V@@*"1R87)$871A(&%S("1V86PI('L*("`@("`@
M("`@("`@)')A=&EO(#T@*&5M<'1Y*"1V86Q;)W-I>F4G72DI(#\@,"`Z(#$P
M,"`J("@D=F%L6R=C<VEZ92==("\@)'9A;%LG<VEZ92==*3L*("`@("`@("`@
M("`@)'1E>'0@+CT@5&5X=#HZ:'1M;$%L;%-P86-E<R@*("`@("`@("`@("`@
M("`@("`@("`@("`@('-T<E]P860H)'9A;%LG;F%M92==+"`U,"P@)R`G+"!3
M5%)?4$%$7U))1TA4*2`N"B`@("`@("`@("`@("`@("`@("`@("`@("!S=')?
M<&%D*"1V86Q;)V%T='(G72P@,3`L("<@)RP@4U127U!!1%],1494*2`N"B`@
M("`@("`@("`@("`@("`@("`@("`@("!S=')?<&%D*"1V86Q;)W-I>F4G72P@
M,3`L("<@)RP@4U127U!!1%],1494*2`N"B`@("`@("`@("`@("`@("`@("`@
M("`@("!S=')?<&%D*'-T<F9T:6UE*"(E9"TE8BTE62`E2#HE32(L("1V86Q;
M)V1A=&4G72DL(#$Y+"`G("<L(%-44E]0041?3$5&5"D@+@H@("`@("`@("`@
M("`@("`@("`@("`@("`@<W1R7W!A9"@D=F%L6R=M971H;V0G72P@,3`L("<@
M)RP@4U127U!!1%],1494*2`N"B`@("`@("`@("`@("`@("`@("`@("`@("!S
M=')?<&%D*'-P<FEN=&8H(B4Q+C%F)24B+"`D<F%T:6\I+"`W+"`G("<L(%-4
M4E]0041?3$5&5"D*("`@("`@("`@("`@("`@("`@("`@*2`N(")<;B(["B`@
M("`@("`@?0H*("`@("`@("`D=&5X="`N/2!S=')?<F5P96%T*"<M)RP@,3`V
M*2`N(")<;B(["B`@("`@("`@)'1E>'0@+CT@)SPO<W!A;CX\+W1T/CPO=&0^
M/"]T<CX\+W1A8FQE/B<["@H@("`@("`@(')E='5R;B!N;#)B<B@D=&5X="D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!-24U%('1Y<&4@
M;V8@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@34E-12!T>7!E(&]F('1H:7,@<&%R="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=T97AT+VAT;6P[
M(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0VAE8VMS('1O('-E92!I9B!T:&4@9&%T82!I<R!A('9A;&ED
M(%)A<B!A<F-H:79E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)B1D
M871A("!4:&4@<F%R(&%R8VAI=F4@9&%T82X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@:68@=F%L:60L(&9A;'-E(&EF(&EN=F%L:60N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-H96-K4F%R1&%T82@F)&1A=&$I"B`@
M("!["B`@("`@("`@)&9I;&5(96%D97(@/2`B7'@U,EQX-C%<>#<R7'@R,5QX
M,6%<>#`W7'@P,"(["B`@("`@("`@:68@*'-T<G!O<R@D9&%T82P@)&9I;&5(
M96%D97(I(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H92!L:7-T(&]F
M(&9I;&5S+V1A=&$@9G)O;2!T:&4@<F%R(&%R8VAI=F4N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`F)&1A=&$@(%1H92!R87(@87)C:&EV92!D871A
M+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($M%63H@4&]S:71I;VX@
M:6X@4D%2(&%R8VAI=F4*("`@("`J("`@("`@("`@("`@("`@(%9!3%5%4SH@
M)V%T='(G("`@("TM("!&:6QE(&%T=')I8G5T97,*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@)V1A=&4G("`@("TM("!&:6QE(&UO9&EF:6-A=&EO
M;B!T:6UE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("=C<VEZ92<@
M("`M+2`@0V]M<')E<W-E9"!F:6QE('-I>F4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@)VUE=&AO9"<@("TM("!#;VUP<F5S<VEO;B!M971H;V0*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@)VYA;64G("`@("TM("!&
M:6QE;F%M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`G<VEZ92<@
M("`@+2T@($]R:6=I;F%L(&9I;&4@<VEZ90H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971287)$871A*"8D9&%T82D*("`@('L*("`@("`@("`D<F5T=7)N7V%R
M<F%Y(#T@87)R87DH*3L*"B`@("`@("`@)&)L;V-K4W1A<G0@/2!S=')P;W,H
M)&1A=&$L(")<>#4R7'@V,5QX-S)<>#(Q7'@Q85QX,#=<>#`P(BD["B`@("`@
M("`@)'!O<VET:6]N(#T@)&)L;V-K4W1A<G0@*R`W.PH*("`@("`@("!W:&EL
M92`H)'!O<VET:6]N(#P@<W1R;&5N*"1D871A*2D@>PH@("`@("`@("`@("`D
M:&5A9%]C<F,@("`]('-U8G-T<B@D9&%T82P@)'!O<VET:6]N("L@,"P@,BD[
M"B`@("`@("`@("`@("1H96%D7W1Y<&4@(#T@;W)D*'-U8G-T<B@D9&%T82P@
M)'!O<VET:6]N("L@,BP@,2DI.PH@("`@("`@("`@("`D:&5A9%]F;&%G<R`]
M('5N<&%C:R@G=D9L86=S)RP@<W5B<W1R*"1D871A+"`D<&]S:71I;VX@*R`S
M+"`R*2D["B`@("`@("`@("`@("1H96%D7V9L86=S(#T@)&AE861?9FQA9W-;
M)T9L86=S)UT["B`@("`@("`@("`@("1H96%D7W-I>F4@(#T@=6YP86-K*"=V
M4VEZ92<L('-U8G-T<B@D9&%T82P@)'!O<VET:6]N("L@-2P@,BDI.PH@("`@
M("`@("`@("`D:&5A9%]S:7IE("`]("1H96%D7W-I>F5;)U-I>F4G73L*"B`@
M("`@("`@("`@("1P;W-I=&EO;B`K/2`W.PH@("`@("`@("`@("`D:&5A9%]S
M:7IE("T](#<["@H@("`@("`@("`@("!S=VET8V@@*"1H96%D7W1Y<&4I('L*
M"B`@("`@("`@("`@(&-A<V4@,'@W,SH*("`@("`@("`@("`@("`@("\J($%R
M8VAI=F4@:&5A9&5R("HO"B`@("`@("`@("`@("`@("`D<&]S:71I;VX@*ST@
M)&AE861?<VEZ93L*"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@,'@W-#H*("`@("`@("`@("`@("`@("1F:6QE(#T@87)R87DH
M*3L*"B`@("`@("`@("`@("`@("`O*B!&:6QE($AE861E<B`J+PH@("`@("`@
M("`@("`@("`@)&EN9F\@/2!U;G!A8VLH)U9086-K960O5E5N<&%C:V5D+T-/
M4R]60U)#,S(O5E1I;64O0U9E<G-I;VXO0TUE=&AO9"]V3&5N9W1H+W9!='1R
M:6(G+"!S=6)S='(H)&1A=&$L("1P;W-I=&EO;BDI.PH*("`@("`@("`@("`@
M("`@("1F:6QE6R=N86UE)UT@/2!S=6)S='(H)&1A=&$L("1P;W-I=&EO;B`K
M(#(U+"`D:6YF;ULG3&5N9W1H)UTI.PH@("`@("`@("`@("`@("`@)&9I;&5;
M)W-I>F4G72`]("1I;F9O6R=5;G!A8VME9"==.PH@("`@("`@("`@("`@("`@
M)&9I;&5;)V-S:7IE)UT@/2`D:6YF;ULG4&%C:V5D)UT["@H@("`@("`@("`@
M("`@("`@)&9I;&5;)V1A=&4G72`](&UK=&EM92@H*"1I;F9O6R=4:6UE)UT@
M/CX@,3$I("8@,'@Q9BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("@H)&EN9F];)U1I;64G72`^/B`U*2`F(#!X,V8I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`H*"1I;F9O6R=4
M:6UE)UT@/#P@,2D@)B`P>#-E*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*"@D:6YF;ULG5&EM92==(#X^(#(Q*2`F(#!X,#<I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`H*"1I
M;F9O6R=4:6UE)UT@/CX@,38I("8@,'@Q9BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("@H*"1I;F9O6R=4:6UE)UT@/CX@,C4I
M("8@,'@W9BD@*R`X,"DI.PH*("`@("`@("`@("`@("`@("1F:6QE6R=M971H
M;V0G72`]("1T:&ES+3Y?;65T:&]D<ULD:6YF;ULG365T:&]D)UU=.PH*("`@
M("`@("`@("`@("`@("1F:6QE6R=A='1R)UT@(#T@)R<["B`@("`@("`@("`@
M("`@("`D9FEL95LG871T<B==("X]("@D:6YF;ULG071T<FEB)UT@)B`P>#$P
M*2`_("=$)R`Z("<M)SL*("`@("`@("`@("`@("`@("1F:6QE6R=A='1R)UT@
M+CT@*"1I;F9O6R=!='1R:6(G72`F(#!X,C`I(#\@)T$G(#H@)RTG.PH@("`@
M("`@("`@("`@("`@)&9I;&5;)V%T='(G72`N/2`H)&EN9F];)T%T=')I8B==
M("8@,'@P,RD@/R`G4R<@.B`G+2<["B`@("`@("`@("`@("`@("`D9FEL95LG
M871T<B==("X]("@D:6YF;ULG071T<FEB)UT@)B`P>#`R*2`_("=()R`Z("<M
M)SL*("`@("`@("`@("`@("`@("1F:6QE6R=A='1R)UT@+CT@*"1I;F9O6R=!
M='1R:6(G72`F(#!X,#$I(#\@)U(G(#H@)RTG.PH*("`@("`@("`@("`@("`@
M("1R971U<FY?87)R87E;72`]("1F:6QE.PH*("`@("`@("`@("`@("`@("1P
M;W-I=&EO;B`K/2`D:&5A9%]S:7IE.PH@("`@("`@("`@("`@("`@)'!O<VET
M:6]N("L]("1I;F9O6R=086-K960G73L*("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@("1P;W-I
M=&EO;B`K/2`D:&5A9%]S:7IE.PH@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1A9&1?<VEZ92DI('L*("`@("`@("`@("`@("`@("`@("`D<&]S:71I;VX@
M*ST@)&%D9%]S:7IE.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)')E='5R;E]A<G)A>3L*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-
M12]6:65W97(O<F5P;W)T+G!H<```````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`U,#<V`#$P-3$U-#,S-S0W`#`R,S4Q-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@5&AE($U)345?
M5FEE=V5R7W)E<&]R="!C;&%S<R!I<R!A('=R87!P97(@=7-E9"!T;R!L;V%D
M('1H92!A<'!R;W!R:6%T90H@*B!-24U%7U9I97=E<B!F;W(@;75L=&EP87)T
M+W)E<&]R="!D871A("A21D,@,S0V,BDN"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F5P;W)T+G!H<"QV(#$N-BXQ,"XV(#(P
M,#8O,#$O,#$@,C$Z,C@Z,C4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`S+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L
M;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E
M;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`
M<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W
M97(*("HO"F-L87-S($U)345?5FEE=V5R7W)E<&]R="!E>'1E;F1S($U)345?
M5FEE=V5R('L*"B`@("`O*BH*("`@("`J(%-T;W)E<R!T:&4@34E-15]6:65W
M97(@;V8@=&AE('-P96-I9FEE9"!P<F]T;V-O;"X*("`@("`J"B`@("`@*B!`
M=F%R($U)345?5FEE=V5R"B`@("`@*B\*("`@('9A<B`D7W9I97=E<CL*"B`@
M("`O*BH*("`@("`J(%)E;F1E<B!T:&4@;75L=&EP87)T+W)E<&]R="!D871A
M+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;B!A<G)A
M>2!O9B!P87)A;65T97)S(&YE961E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE(')E;F1E<F5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')E;F1E<B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`O
M*B!'970@=&AE(&%P<')O<')I871E($U)345?5FEE=V5R(&9O<B!T:&4@<')O
M=&]C;VP@<W!E8VEF:65D+B`J+PH@("`@("`@(&EF("@A*"1T:&ES+3Y?<F5S
M;VQV959I97=E<B@I*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@
M?0H*("`@("`@("`O*B!296YD97(@=7-I;F<@=&AE(&QO861E9"!-24U%7U9I
M97=E<B!O8FIE8W0N("HO"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=FEE=V5R
M+3YR96YD97(H)'!A<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!C;VYT96YT+71Y<&4@;V8@=&AE(%9I97=E<B!U<V5D('1O('9I
M97<@=&AE('!A<G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($$@
M8V]N=&5N="UT>7!E('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M5'EP92@I"B`@("!["B`@("`@("`@+RH@1V5T('1H92!A<'!R;W!R:6%T92!-
M24U%7U9I97=E<B!F;W(@=&AE('!R;W1O8V]L('-P96-I9FEE9"X@*B\*("`@
M("`@("!I9B`H(2@D=&AI<RT^7W)E<V]L=F56:65W97(H*2DI('L*("`@("`@
M("`@("`@<F5T=7)N("=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W9I97=E
M<BT^9V5T5'EP92@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($QO860@82!-24U%7U9I97=E<B!A8V-O<F1I;F<@=&\@=&AE(')E<&]R="UT
M>7!E('!A<F%M971E<B!S=&]R960*("`@("`J(&EN('1H92!-24U%7U!A<G0@
M=&\@<F5N9&5R+B!)9B!U;G-U8V-E<W-F=6PL('1R>2!T;R!L;V%D(&$@9V5N
M97)I8PH@("`@("H@;75L=&EP87)T($U)345?5FEE=V5R+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?<F5S;VQV959I97=E<B@I"B`@("!["B`@("`@
M("`@)'9I97=E<B`](&YU;&P["@H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^
M7W9I97=E<BDI('L*("`@("`@("`@("`@:68@*"$H)'1Y<&4@/2`D=&AI<RT^
M;6EM95]P87)T+3YG971#;VYT96YT5'EP95!A<F%M971E<B@G<F5P;W)T+71Y
M<&4G*2DI('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)'9I97=E<B`]("9-24U%7U9I97=E<CHZ
M9F%C=&]R>2@D=&AI<RT^;6EM95]P87)T+"`G;65S<V%G92\G("X@4W1R:6YG
M.CIL;W=E<B@D='EP92DI.PH@("`@("`@("`@("!I9B`H96UP='DH)'9I97=E
M<BD@?'P*("`@("`@("`@("`@("`@("A3=')I;F<Z.FQO=V5R*&=E=%]C;&%S
M<R@D=FEE=V5R*2D@/3T@)VUI;65?=FEE=V5R7V1E9F%U;'0G*2D@>PH@("`@
M("`@("`@("`@("`@:68@*"$H)'9I97=E<B`]("9-24U%7U9I97=E<CHZ9F%C
M=&]R>2@D=&AI<RT^;6EM95]P87)T+"`D=&AI<RT^;6EM95]P87)T+3YG9710
M<FEM87)Y5'EP92@I("X@)R\J)RDI*2!["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1T:&ES+3Y?=FEE=V5R(#T@)'9I97=E<CL*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8U,#``,3`U,34T,S,W
M-#<`,#(S,C`P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&4@34E-15]6:65W97)?<F9C.#(R(&-L
M87-S(')E;F1E<G,@;W5T(&UE<W-A9V5S(&9R;VT@=&AE"B`J(&UE<W-A9V4O
M<F9C.#(R(&-O;G1E;G0@='EP92X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP+'8@,2XX+C$P+C@@,C`P-B\P
M,2\P,2`R,3HR.#HR-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M
M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D
M;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]G<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S
M87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@
M("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO
M"F-L87-S($U)345?5FEE=V5R7W)F8S@R,B!E>'1E;F1S($U)345?5FEE=V5R
M('L*"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@=&AE(&-U<G)E;G1L>2!S
M970@8V]N=&5N=',N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@($%N(&%R<F%Y('=I=&@@86YY('!A<F%M971E<G,@;F5E9&5D+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5N9&5R960@=&5X="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@("1P87)T(#T@)'1H:7,M/FUI;65?<&%R=#L*("`@
M("`@("`D<&%R="T^=')A;G-F97)$96-O9&5#;VYT96YT<R@I.PH*("`@("`@
M("`D=&5X="`]("1P87)T+3YG971#;VYT96YT<R@I.PH@("`@("`@(&EF("@A
M)'1E>'0I('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%
M+T-O;G1E;G1S+G!H<"<["B`@("`@("`@("`@("1C;VYT96YT<R`]("9N97<@
M34E-15]#;VYT96YT<RAN97<@34E-15]087)T*"DI.PH@("`@("`@("`@("!R
M971U<FX@)&-O;G1E;G1S+3YF;W)M8713=&%T=7--<V<H7R@B5&AE<F4@=V%S
M(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B*2D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T97AT.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@871T86-H
M;65N="!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@06X@87)R87D@=VET:"!A;GD@<&%R86UE=&5R<R!N965D960N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!T
M97AT(&EN($A434PN"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<D%T=&%C
M:&UE;G1);F9O*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1M
M<V<@/2`G)SL*"B`@("`@("`@+RH@1V5T('1H92!T97AT(&]F('1H92!P87)T
M+B`@4VEN8V4@=V4@;F5E9"!T;R!L;V]K(&9O<B!T:&4@96YD(&]F"B`@("`@
M("`@("H@=&AE(&AE861E<G,@8GD@<V5A<F-H:6YG(&9O<B!T:&4@0U),1D-2
M3$8@<V5Q=65N8V4L('5S90H@("`@("`@("`J(&=E=$-A;F]N:6-A;$-O;G1E
M;G1S*"D@=&\@;6%K92!S=7)E('=E(&%R92!G971T:6YG('1H92!T97AT('=I
M=&@*("`@("`@("`@*B!#4DQ&)W,N("HO"B`@("`@("`@)'1E>'0@/2`D=&AI
M<RT^;6EM95]P87)T+3YG971#86YO;FEC86Q#;VYT96YT<R@I.PH*("`@("`@
M("`O*B!396%R8V@@9F]R('1H92!E;F0@;V8@=&AE(&AE861E<B!T97AT("A#
M4DQ&0U),1BDN("HO"B`@("`@("`@)'1E>'0@/2!S=6)S='(H)'1E>'0L(#`L
M('-T<G!O<R@D=&5X="P@(EQR7&Y<<EQN(BDI.PH*("`@("`@("`O*B!'970@
M=&AE(&QI<W0@;V8@:&5A9&5R<R!N;W<N("HO"B`@("`@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92]-24U%+U-T<G5C='5R92YP:'`G.PH@("`@("`@("1H96%D
M97)S(#T@34E-15]3=')U8W1U<F4Z.G!A<G-E34E-14AE861E<G,H)'1E>'0L
M('1R=64L('1R=64I.PH*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)
M344O0V]N=&5N=',N<&AP)SL*("`@("`@("`D8V]N=&5N=',@/2`F;F5W($U)
M345?0V]N=&5N=',H;F5W($U)345?4&%R="@I*3L*("`@("`@("`D;7-G(#T@
M)&-O;G1E;G1S+3YF;W)M8713=&%T=7--<V<H7R@B5&AE(&9O;&QO=VEN9R!A
M<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G
M92XB*2P@2&]R9&4Z.FEM9R@G:6YF;U]I8V]N+G!N9R<L(%\H(DEN9F\B*2P@
M)VAE:6=H=#TB,38B('=I9'1H/2(Q-B(G+"`D1TQ/0D%,4ULG<F5G:7-T<GDG
M72T^9V5T26UA9V5$:7(H)VAO<F1E)RDI+"!F86QS92D["@H@("`@("`@("1M
M<V<@+CT@)SQS<&%N(&-L87-S/2)F:7AE9"(^)SL*"B`@("`@("`@)&AE861E
M<E]A<G)A>2`](&%R<F%Y*`H@("`@("`@("`@("`G9&%T92<@/3X@7R@B1&%T
M92(I+`H@("`@("`@("`@("`G<W5B:F5C="<@/3X@7R@B4W5B:F5C="(I+`H@
M("`@("`@("`@("`G9G)O;2<@/3X@7R@B1G)O;2(I+`H@("`@("`@("`@("`G
M=&\G(#T^(%\H(E1O(BD*("`@("`@("`I.PH@("`@("`@("1H96%D97)?;W5T
M<'5T(#T@87)R87DH*3L*"B`@("`@("`@9F]R96%C:"`H)&AE861E<E]A<G)A
M>2!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@:68@*&ES<V5T*"1H
M96%D97)S6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y
M*"1H96%D97)S6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@("`@("1H96%D
M97)S6R1K97E=(#T@)&AE861E<G-;)&ME>5U;,%T["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D:&5A9&5R7V]U='!U=%M=(#T@)SQS=')O
M;F<^)R`N("1V86P@+B`G.CPO<W1R;VYG/B`G("X@)&AE861E<G-;)&ME>5T[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O5&5X="]&:6QT97(N<&AP)SL*("`@("`@("`D;7-G("X](&EM
M<&QO9&4H(CQB<B`O/EQN(BP@5&5X=%]&:6QT97(Z.F9I;'1E<B@D:&5A9&5R
M7V]U='!U="P@)V5M86EL<R<I*2`N("<\+W-P86X^)SL*"B`@("`@("`@<F5T
M=7)N("1M<V<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE($U)
M344@8V]N=&5N="!T>7!E(&9O<B!T:&4@<F5N9&5R960@9&%T82X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O;G1E;G0@='EP92!O9B!T
M:&4@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("![
M"B`@("`@("`@<F5T=7)N("=T97AT+W!L86EN.R!C:&%R<V5T/2<@+B!.3%,Z
M.F=E=$-H87)S970H*3L*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O<FEC:'1E
M>'0N<&AP````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$U-#,W`#$P-3$U-#,S
M-S0W`#`R-#`S-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&AE($U)345?5FEE=V5R7W)I8VAT97AT
M(&-L87-S(')E;F1E<G,@;W5T($A434P@=&5X="!F<F]M('1E>'0O<FEC:'1E
M>'0*("H@8V]N=&5N="!T86=S+"`H4D9#(#$X.38@6S<N,2XS72DN"B`J"B`J
M($$@;6EN:6UA;"!R:6-H=&5X="!I;7!L96UE;G1A=&EO;B!I<R!O;F4@=&AA
M="!S:6UP;'D@8V]N=F5R=',@(CQL=#XB('1O"B`J("(\(BP@8V]N=F5R=',@
M0U),1G,@=&\@4U!!0T4L(&-O;G9E<G1S(#QN;#X@=&\@82!N97=L:6YE(&%C
M8V]R9&EN9R!T;PH@*B!L;V-A;"!N97=L:6YE(&-O;G9E;G1I;VXL(')E;6]V
M97,@979E<GET:&EN9R!B971W965N(&$@/&-O;6UE;G0^(&-O;6UA;F0*("H@
M86YD('1H92!N97AT(&)A;&%N8VEN9R`\+V-O;6UE;G0^(&-O;6UA;F0L(&%N
M9"!R96UO=F5S(&%L;"!O=&AE<@H@*B!O=&AE<B!F;W)M871T:6YG(&-O;6UA
M;F1S("AA;&P@=&5X="!E;F-L;W-E9"!I;B!A;F=L92!B<F%C:V5T<RDN"B`J
M"B`J(%=E(&EM<&QE;65N="!T:&4@9F]L;&]W:6YG('1A9W,Z"B`J(#QB;VQD
M/BP@/&ET86QI8SXL(#QF:7AE9#XL(#QS;6%L;&5R/BP@/&)I9V=E<CXL(#QU
M;F1E<FQI;F4^+"`\8V5N=&5R/BP*("H@/&9L=7-H;&5F=#XL(#QF;'5S:')I
M9VAT/BP@/&EN9&5N=#XL(#QS=6)S8W)I<'0^+"`\97AC97)P=#XL(#QP87)A
M9W)A<&@^+`H@*B`\<VEG;F%T=7)E/BP@/&-O;6UE;G0^+"`\;F\M;W`^+"`\
M;'0^+"`\;FP^"B`J"B`J(%1H92!F;VQL;W=I;F<@=&%G<R!A<F4@:6UP;&5M
M96YT960@9&EF9F5R96YT;'D@=&AA;B!D97-C<FEB960@:6X@=&AE(%)&0PH@
M*B`H9'5E('1O(&QI;6ET871I;VYS(&EN($A434P@;W5T<'5T*3H*("H@/&AE
M861I;F<^("T@3W5T<'5T(&%S(&-E;G1E<F5D+"!B;VQD('1E>'0N"B`J(#QF
M;V]T:6YG/B`M($]U='!U="!A<R!C96YT97)E9"P@8F]L9"!T97AT+@H@*B`\
M;G`^("`@("`@+2!/=71P=70@87,@<&%R86=R87!H(&)R96%K+@H@*@H@*B!4
M:&4@9F]L;&]W:6YG('1A9W,@87)E($Y/5"!I;7!L96UE;G1E9#H*("H@/&EN
M9&5N=')I9VAT/BP@/&]U=&1E;G0^+"`\;W5T9&5N=')I9VAT/BP@/'-A;65P
M86=E/BP@/&ES;RTX.#4Y+5@^+`H@*B`\=7,M87-C:6D^+`H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)I8VAT97AT+G!H<"QV
M(#$N-"XQ,"XW(#(P,#8O,#$O,#$@,C$Z,C@Z,C4@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`T+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z
M0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A
M9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?34E-15]6:65W97(*("HO"F-L87-S($U)345?5FEE=V5R7W)I8VAT97AT
M(&5X=&5N9',@34E-15]6:65W97(@>PH*("`@("\J*@H@("`@("H@4F5N9&5R
M(&]U="!T:&4@8W5R<F5N=&QY('-E="!C;VYT96YT<R!I;B!(5$U,(&9O<FUA
M="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY('!A
M<F%M971E<G,@=&AE(%9I97=E<B!M87D@;F5E9"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&-O;G1E;G1S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!R96YD97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@:68@*"@D=&5X="`]("1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O
M;G1E;G1S*"DI(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H=')I;2@D=&5X="D@/3T@)R<I
M('L*("`@("`@("`@("`@<F5T=7)N("1T97AT.PH@("`@("`@('T*"B`@("`@
M("`@+RH@57-E('-T<E]I<F5P;&%C92@I(&EF('5S:6YG(%!(4"`U+C`K+B`J
M+PH@("`@("`@("1H87-?<W1R7VER97!L86-E(#T@9G5N8W1I;VY?97AI<W1S
M*"=S=')?:7)E<&QA8V4G*3L*"B`@("`@("`@+RH@5V4@861D('-P86-E(&%T
M('1H92!B96=I;FYI;F<@86YD(&5N9"!O9B!T:&4@<W1R:6YG(&%S(&ET('=I
M;&P*("`@("`@("`@*B!M86ME('-O;64@<F5G=6QA<B!E>'!R97-S:6]N(&-H
M96-K<R!L871E<B!M=6-H(&5A<VEE<B`H<V\@=V4*("`@("`@("`@*B!D;VXG
M="!H879E('1O('=O<G)Y(&%B;W5T('-T87)T+V5N9"!O9B!L:6YE(&-H87)A
M8W1E<G,I+B`J+PH@("`@("`@("1T97AT(#T@)R`G("X@)'1E>'0@+B`G("<[
M"@H@("`@("`@("\J(%)E;6]V92!E=F5R>71H:6YG(&)E='=E96X@/&-O;6UE
M;G0^('1A9W,N("HO"B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\\
M8V]M;65N="XJ/BXJ/%PO8V]M;65N=#XO56ES)RP@)R<L("1T97AT*3L*"B`@
M("`@("`@+RH@4F5M;W9E(&%N>2!U;G)E8V]G;FEZ960@=&%G<R!I;B!T:&4@
M=&5X="X@(%=E(&1O;B=T(&YE960@/&YO+6]P/@H@("`@("`@("`J(&EN("1T
M86=S('-I;F-E(&ET(&1O97-N)W0@9&\@86YY=&AI;F<@86YY=V%Y+B`@06QL
M(#QC;VUM96YT/B!T86=S"B`@("`@("`@("H@:&%V92!A;')E861Y(&)E96X@
M<F5M;W9E9"X@*B\*("`@("`@("`D=&%G<R`]("<\8F]L9#X\:71A;&EC/CQF
M:7AE9#X\<VUA;&QE<CX\8FEG9V5R/CQU;F1E<FQI;F4^/&-E;G1E<CX\9FQU
M<VAL969T/CQF;'5S:')I9VAT/CQI;F1E;G0^/'-U8G-C<FEP=#X\97AC97)P
M=#X\<&%R86=R87!H/CQS:6=N871U<F4^/&QT/CQN;#XG.PH@("`@("`@("1T
M97AT(#T@<W1R:7!?=&%G<R@D=&5X="P@)'1A9W,I.PH*("`@("`@("`O*B`\
M;'0^(&)E8V]M97,@82`G/"<N($-23$8@8F5C;VUE<R!A(%-004-%+B`J+PH@
M("`@("`@(&EF("@D:&%S7W-T<E]I<F5P;&%C92D@>PH@("`@("`@("`@("`D
M=&5X="`]('-T<E]I<F5P;&%C92AA<G)A>2@G/&QT/B<L(")<<EQN(BDL(&%R
M<F%Y*"<F;'0[)RP@)R`G*2P@)'1E>'0I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*&%R<F%Y*"<O/&QT/B]I
M)RP@(B]<<EQN+R(I+"!A<G)A>2@G)FQT.R<L("<@)RDL("1T97AT*3L*("`@
M("`@("!]"@H@("`@("`@("\J(%=E('1R>2!T;R!P<F]T96-T(&%G86EN<W0@
M8F%D('-T=69F(&AE<F4N("HO"B`@("`@("`@)'1E>'0@/2!`:'1M;'-P96-I
M86QC:&%R<R@D=&5X="P@14Y47U%53U1%4RP@)'1H:7,M/FUI;65?<&%R="T^
M9V5T0VAA<G-E="@I*3L*"B`@("`@("`@+RH@/&YL/B!B96-O;65S(&$@;F5W
M;&EN92`H/&)R("\^*3L*("`@("`@("`@*B`\;G`^(&)E8V]M97,@82!P87)A
M9W)A<&@@8G)E86L@*#QP("\^*2X@*B\*("`@("`@("!I9B`H)&AA<U]S=')?
M:7)E<&QA8V4I('L*("`@("`@("`@("`@)'1E>'0@/2!S=')?:7)E<&QA8V4H
M87)R87DH)R9L=#MN;"9G=#LG+"`G)FQT.VYP)F=T.R<I+"!A<G)A>2@G/&)R
M("\^)RP@)SQP("\^)RDL("1T97AT*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92AA<G)A>2@G+R@_/"$F;'0[
M*29L=#MN;"XJ)F=T.R]5:7,G+"`G+R@_/"$F;'0[*29L=#MN<"XJ)F=T.R]5
M:7,G*2P@87)R87DH)SQB<B`O/B<L("<\<"`O/B<I+"`D=&5X="D["B`@("`@
M("`@?0H*("`@("`@("`O*B!.;W<@8V]N=F5R="!T:&4@:VYO=VX@=&%G<R!T
M;R!H=&UL+B!4<GD@=&\@<F5M;W9E(&%N>2!T86<*("`@("`@("`@*B!P87)A
M;65T97)S('1O('-T;W`@<&5O<&QE(&9R;VT@=')Y:6YG('1O('!U;&P@82!F
M87-T(&]N92X@*B\*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_
M/"$F;'0[*29L=#MB;VQD+BHF9W0[*"XJ*29L=#M<+V)O;&0F9W0[+U5I<R<L
M("<\<W!A;B!S='EL93TB9F]N="UW96EG:'0Z(&)O;&0B/EPQ/"]S<&%N/B<L
M("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F
M;'0[*29L=#MI=&%L:6,N*B9G=#LH+BHI)FQT.UPO:71A;&EC)F=T.R]5:7,G
M+"`G/'-P86X@<W1Y;&4](F9O;G0M<W1Y;&4Z(&ET86QI8R(^7#$\+W-P86X^
M)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\
M(29L=#LI)FQT.V9I>&5D+BHF9W0[*"XJ*29L=#M<+V9I>&5D)F=T.R]5:7,G
M+"`G/&9O;G0@9F%C93TB9FEX960B/EPQ/"]F;VYT/B<L("1T97AT*3L*("`@
M("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F;'0[*29L=#MS;6%L
M;&5R+BHF9W0[+U5I<R<L("<\<W!A;B!S='EL93TB9F]N="US:7IE.B!S;6%L
M;&5R(CXG+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H
M)R\H/SPA)FQT.RDF;'0[7"]S;6%L;&5R)F=T.R]5:7,G+"`G/"]S<&%N/B<L
M("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F
M;'0[*29L=#MB:6=G97(N*B9G=#LO56ES)RP@)SQS<&%N('-T>6QE/2)F;VYT
M+7-I>F4Z(&QA<F=E<B(^)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E
M9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.UPO8FEG9V5R)F=T.R]5:7,G+"`G
M/"]S<&%N/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C
M92@G+R@_/"$F;'0[*29L=#MU;F1E<FQI;F4N*B9G=#LH+BHI)FQT.UPO=6YD
M97)L:6YE)F=T.R]5:7,G+"`G/'-P86X@<W1Y;&4](G1E>'0M9&5C;W)A=&EO
M;CH@=6YD97)L:6YE(CY<,3PO<W!A;CXG+"`D=&5X="D["B`@("`@("`@)'1E
M>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[8V5N=&5R+BHF9W0[
M*"XJ*29L=#M<+V-E;G1E<B9G=#LO56ES)RP@)SQD:78@86QI9VX](F-E;G1E
M<B(^7#$\+V1I=CXG+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E
M<&QA8V4H)R\H/SPA)FQT.RDF;'0[9FQU<VAL969T+BHF9W0[*"XJ*29L=#M<
M+V9L=7-H;&5F="9G=#LO56ES)RP@)SQD:78@86QI9VX](FQE9G0B/EPQ/"]D
M:78^)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O
M*#\\(29L=#LI)FQT.V9L=7-H<FEG:'0N*B9G=#LH+BHI)FQT.UPO9FQU<VAR
M:6=H="9G=#LO56ES)RP@)SQD:78@86QI9VX](G)I9VAT(CY<,3PO9&EV/B<L
M("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F
M;'0[*29L=#MI;F1E;G0N*B9G=#LH+BHI)FQT.UPO:6YD96YT)F=T.R]5:7,G
M+"`G/&)L;V-K<75O=&4^7#$\+V)L;V-K<75O=&4^)RP@)'1E>'0I.PH@("`@
M("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.V5X8V5R
M<'0N*B9G=#LH+BHI)FQT.UPO97AC97)P="9G=#LO56ES)RP@)SQC:71E/EPQ
M/"]C:71E/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C
M92@G+R@_/"$F;'0[*29L=#MS=6)S8W)I<'0N*B9G=#LH+BHI)FQT.UPO<W5B
M<V-R:7!T)F=T.R]5:7,G+"`G/'-U8CY<,3PO<W5B/B<L("1T97AT*3L*("`@
M("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F;'0[*29L=#MS=7!E
M<G-C<FEP="XJ)F=T.R@N*BDF;'0[7"]S=7!E<G-C<FEP="9G=#LO56ES)RP@
M)SQS=7`^7#$\+W-U<#XG+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G
M7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[:&5A9&EN9RXJ)F=T.R@N*BDF;'0[
M7"]H96%D:6YG)F=T.R]5:7,G+"`G/&)R("\^/&1I=B!A;&EG;CTB8V5N=&5R
M(B!S='EL93TB9F]N="UW96EG:'0Z(&)O;&0B/EPQ/"]D:78^/&)R("\^)RP@
M)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L
M=#LI)FQT.V9O;W1I;F<N*B9G=#LH+BHI)FQT.UPO9F]O=&EN9R9G=#LO56ES
M)RP@)SQB<B`O/CQD:78@86QI9VX](F-E;G1E<B(@<W1Y;&4](F9O;G0M=V5I
M9VAT.B!B;VQD(CY<,3PO9&EV/CQB<B`O/B<L("1T97AT*3L*("`@("`@("`D
M=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F;'0[*29L=#MP87)A9W)A<&@N
M*B9G=#LH+BHI)FQT.UPO<&%R86=R87!H)F=T.R]5:7,G+"`G/'`^7#$\+W`^
M)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\
M(29L=#LI)FQT.W-I9VYA='5R92XJ)F=T.R@N*BDF;'0[7"]S:6=N871U<F4F
M9W0[+U5I<R<L("<\861D<F5S<SY<,3PO861D<F5S<SXG+"`D=&5X="D["@H@
M("`@("`@("\J($YO=R!W92!R96UO=F4@=&AE(&QE861I;F<O=')A:6QI;F<@
M<W!A8V4@=V4@861D960@870@=&AE('-T87)T+B`J+PH@("`@("`@("1T97AT
M(#T@<W5B<W1R*"1T97AT+"`Q+"`M,2D["@H@("`@("`@("\J(%=O<F1W<F%P
M+B`J+PH@("`@("`@("1T97AT(#T@<W1R7W)E<&QA8V4H(EQT(BP@)R`@("`@
M("`@)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<W1R7W)E<&QA8V4H)R`@
M)RP@)R`F;F)S<#LG+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!S=')?<F5P
M;&%C92@B7&X@(BP@(EQN)FYB<W`[(BP@)'1E>'0I.PH@("`@("`@(&EF("@D
M=&5X=%LP72`]/2`G("<I('L*("`@("`@("`@("`@)'1E>'0@/2`G)FYB<W`[
M)R`N('-U8G-T<B@D=&5X="P@,2D["B`@("`@("`@?0H@("`@("`@("1T97AT
M(#T@;FPR8G(H)'1E>'0I.PH@("`@("`@("1T97AT(#T@)SQP(&-L87-S/2)F
M:7AE9"(^)R`N("1T97AT("X@)SPO<#XG.PH*("`@("`@("!R971U<FX@)'1E
M>'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE($U)344@8V]N
M=&5N="!T>7!E(&]F('1H92!R96YD97)E9"!C;VYT96YT+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]N=&5N="!T>7!E(&]F('1H92!O
M=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@
M("`@("`@(')E='5R;B`G=&5X="]H=&UL.R!C:&%R<V5T/2<@+B!.3%,Z.F=E
M=$-H87)S970H*3L*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O34E-12]6:65W97(O<G!M+G!H<```````````````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`S-#0U`#$P-3$U-#,S-S0W`#`R,C<W-0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@5&AE($U)345?5FEE=V5R7W)P;2!C;&%S<R!R96YD97)S(&]U="!L
M:7-T<R!O9B!F:6QE<R!I;B!24$T*("H@<&%C:V%G97,@8GD@=7-I;F<@=&AE
M(')P;2!T;V]L('1O('%U97)Y('1H92!P86-K86=E+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`L=B`Q+C$R+C$P
M+C<@,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#$Y.3DM,C`P-B!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A
M<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS
M"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%
M7U9I97=E<E]R<&T@97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@
M("`@*B!296YD97(@;W5T('1H92!24$T@8V]N=&5N=',N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N>2!P87)A;65T97)S('1H92!6
M:65W97(@;6%Y(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!R96YD97)E9"!C;VYT96YT<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F5N9&5R*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&=L;V)A
M;"`D;6EM95]D<FEV97)S.PH*("`@("`@("`O*B!#:&5C:R!T;R!M86ME('-U
M<F4@=&AE('!R;V=R86T@86-T=6%L;'D@97AI<W1S+B`J+PH@("`@("`@(&EF
M("@A9FEL95]E>&ES=',H)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<G!M)UU;
M)VQO8V%T:6]N)UTI*2!["B`@("`@("`@("`@(')E='5R;B`G/'!R93XG("X@
M<W!R:6YT9BA?*")4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A
M('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(BDL("1M
M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W)P;2==6R=L;V-A=&EO;B==*2`N("<\
M+W!R93XG.PH@("`@("`@('T*"B`@("`@("`@)&1A=&$@/2`G)SL*("`@("`@
M("`D=&UP7W)P;2`]($AO<F1E.CIG971496UP1FEL92@G:&]R9&5?<G!M)RD[
M"@H@("`@("`@("1F:"`](&9O<&5N*"1T;7!?<G!M+"`G=R<I.PH@("`@("`@
M(&9W<FET92@D9F@L("1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"DI
M.PH@("`@("`@(&9C;&]S92@D9F@I.PH*("`@("`@("`D9F@@/2!P;W!E;B@D
M;6EM95]D<FEV97)S6R=H;W)D92==6R=R<&TG75LG;&]C871I;VXG72`N("(@
M+7%I<"`D=&UP7W)P;2`R/B8Q(BP@)W(G*3L*("`@("`@("!W:&EL92`H*"1R
M8R`](&9G971S*"1F:"P@.#$Y,BDI*2!["B`@("`@("`@("`@("1D871A("X]
M("1R8SL*("`@("`@("!]"B`@("`@("`@<&-L;W-E*"1F:"D["@H@("`@("`@
M(')E='5R;B`G/'!R93XG("X@:'1M;&5N=&ET:65S*"1D871A*2`N("<\+W!R
M93XG.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!-24U%(&-O
M;G1E;G0@='EP92!O9B!T:&4@<F5N9&5R960@8V]N=&5N="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O;G1E;G0@='EP92!O9B!T:&4@
M;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*
M("`@("`@("!R971U<FX@)W1E>'0O:'1M;#L@8VAA<G-E=#TG("X@3DQ3.CIG
M971#:&%R<V5T*"D["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W-E8W5R:71Y+G!H<```````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-34Q-``Q,#4Q-30S,S<T-P`P,C0P-#4`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M(%1H92!-24U%7U9I97=E<E]S96-U<FET>2!C;&%S<R!I<R!A('=R87!P97(@
M=7-E9"!T;R!L;V%D('1H92!A<'!R;W!R:6%T90H@*B!-24U%7U9I97=E<B!F
M;W(@<V5C=7)E(&UU;'1I<&%R="!M97-S86=E<R`H9&5F:6YE9"!B>2!21D,@
M,3@T-RDN(%1H:7,*("H@8VQA<W,@:&%N9&QE<R!M=6QT:7!A<G0O<VEG;F5D
M(&%N9"!M=6QT:7!A<G0O96YC<GEP=&5D(&1A=&$N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<V5C=7)I='DN<&AP+'8@,2XV
M+C$P+C4@,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG
M=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE
M9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]-
M24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6:65W97)?<V5C=7)I='D@97AT
M96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@("`@*B!3=&]R97,@=&AE
M($U)345?5FEE=V5R(&]F('1H92!S<&5C:69I960@<V5C=7)I='D@<')O=&]C
M;VPN"B`@("`@*@H@("`@("H@0'9A<B!-24U%7U9I97=E<@H@("`@("HO"B`@
M("!V87(@)%]V:65W97(["@H@("`@+RHJ"B`@("`@*B!4:&4@)&UI;65?<&%R
M="!C;&%S<R!V87)I86)L92!H87,@=&AE(&EN9F]R;6%T:6]N('1O(')E;F1E
M<@H@("`@("H@;W5T+"!E;F-A<'-U;&%T960@:6X@82!-24U%7U!A<G0@;V)J
M96-T+@H@("`@("H*("`@("`J($!P87)A;2`D<&%R86US(&UI>&5D("!4:&4@
M<&%R86UE=&5R<R`H:68@86YY*2!T;R!P87-S('1O('1H92!U;F1E<FQY:6YG
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@34E-15]6:65W97(N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%)E;F1E<FEN9R!O9B!T:&4@
M8V]N=&5N="X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("\J($=E="!T:&4@87!P<F]P<FEA
M=&4@34E-15]6:65W97(@9F]R('1H92!P<F]T;V-O;"!S<&5C:69I960N("HO
M"B`@("`@("`@:68@*"$H)'1H:7,M/E]R97-O;'9E5FEE=V5R*"DI*2!["B`@
M("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("\J(%)E;F1E
M<B!U<VEN9R!T:&4@;&]A9&5D($U)345?5FEE=V5R(&]B:F5C="X@*B\*("`@
M("`@("!R971U<FX@)'1H:7,M/E]V:65W97(M/G)E;F1E<B@D<&%R86US*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-O;G1E;G0M='EP
M92!O9B!T:&4@5FEE=V5R('5S960@=&\@=FEE=R!T:&4@<&%R="X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@02!C;VYT96YT+71Y<&4@<W1R:6YG
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@
M("`O*B!'970@=&AE(&%P<')O<')I871E($U)345?5FEE=V5R(&9O<B!T:&4@
M<')O=&]C;VP@<W!E8VEF:65D+B`J+PH@("`@("`@(&EF("@A*"1T:&ES+3Y?
M<F5S;VQV959I97=E<B@I*2D@>PH@("`@("`@("`@("!R971U<FX@)V%P<&QI
M8V%T:6]N+V]C=&5T+7-T<F5A;2<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?=FEE=V5R+3YG9714>7!E*"D["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@3&]A9"!A($U)345?5FEE=V5R
M(&%C8V]R9&EN9R!T;R!T:&4@<')O=&]C;VP@<&%R86UE=&5R('-T;W)E9`H@
M("`@("H@:6X@=&AE($U)345?4&%R="!T;R!R96YD97(N($EF('5N<W5C8V5S
M<V9U;"P@=')Y('1O(&QO860@82!G96YE<FEC"B`@("`@*B!M=6QT:7!A<G0@
M34E-15]6:65W97(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L
M(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R97-O
M;'9E5FEE=V5R*"D*("`@('L*("`@("`@("`D=FEE=V5R(#T@;G5L;#L*"B`@
M("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?=FEE=V5R*2D@>PH@("`@("`@("`@
M("`D<')O=&]C;VP@/2`D=&AI<RT^;6EM95]P87)T+3YG971#;VYT96YT5'EP
M95!A<F%M971E<B@G<')O=&]C;VPG*3L*("`@("`@("`@("`@:68@*&5M<'1Y
M*"1P<F]T;V-O;"DI('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D=FEE=V5R(#T@)DU)345?5FEE
M=V5R.CIF86-T;W)Y*"1T:&ES+3YM:6UE7W!A<G0L("1P<F]T;V-O;"D["B`@
M("`@("`@("`@(&EF("AE;7!T>2@D=FEE=V5R*2!\?`H@("`@("`@("`@("`@
M("`@*%-T<FEN9SHZ;&]W97(H9V5T7V-L87-S*"1V:65W97(I*2`]/2`G;6EM
M95]V:65W97)?9&5F875L="<I*2!["B`@("`@("`@("`@("`@("`D=FEE=V5R
M(#T@)DU)345?5FEE=V5R.CIF86-T;W)Y*"1T:&ES+3YM:6UE7W!A<G0L("1T
M:&ES+3YM:6UE7W!A<G0M/F=E=%!R:6UA<GE4>7!E*"D@+B`G+RHG*3L*("`@
M("`@("`@("`@("`@(&EF("AE;7!T>2@D=FEE=V5R*2D@>PH@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7W9I97=E<B`]("1V:65W
M97(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W
M97(O<VEM<&QE+G!H<```````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,S4W
M`#$P-3$U-#,S-S0W`#`R,S0W,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@5&AE($U)345?5FEE=V5R
M7W-I;7!L92!C;&%S<R!R96YD97)S(&]U="!P;&%I;B!T97AT('=I=&AO=70@
M86YY"B`J(&UO9&EF:6-A=&EO;G,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<VEM<&QE+G!H<"QV(#$N,2XV+C4@,C`P-B\P
M,2\P,2`R,3HR.#HR-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M
M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S
M87)Z0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K
M86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]S
M:6UP;&4@97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@("`@*B!2
M971U<FX@=&AE($U)344@='EP92!O9B!T:&4@<F5N9&5R960@8V]N=&5N="X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@34E-12UT>7!E(&]F('1H
M92!O=71P=70@8V]N=&5N="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5'EP
M92@I"B`@("!["B`@("`@("`@<F5T=7)N("=T97AT+W!L86EN)SL*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-
M12]6:65W97(O<V]U<F-E+G!H<```````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R-#0W`#$P-3$U-#,S-S0W`#`R,S4P,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@5&AE($U)345?
M5FEE=V5R7W-O=7)C92!C;&%S<R!I<R!A(&-L87-S(&9O<B!A;GD@=FEE=V5R
M('1H870@=V%N=',*("H@=&\@<')O=FED92!L:6YE(&YU;6)E<G,@=&\@97AT
M96YD+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W-O=7)C92YP:'`L=B`Q+CDN,3`N.2`R,#`V+S`Q+S`Q(#(Q.C(X.C(U(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N
M8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S
M:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]-24U%7U9I97=E
M<@H@*B\*8VQA<W,@34E-15]6:65W97)?<V]U<F-E(&5X=&5N9',@34E-15]6
M:65W97(@>PH*("`@("\J*@H@("`@("H@061D(&QI;F4@;G5M8F5R<R!T;R!A
M(&)L;V-K(&]F(&-O9&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M8V]D92`@5&AE(&-O9&4@=&\@;G5M8F5R+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!L:6YE3G5M8F5R*"1C;V1E+"`D;&EN96)R96%K(#T@(EQN(BD*("`@('L*
M("`@("`@("`D;&EN97,@/2!S=6)S=')?8V]U;G0H)&-O9&4L("1L:6YE8G)E
M86LI("L@,3L*("`@("`@("`D:'1M;"`]("<\=&%B;&4@8VQA<W,](FQI;F5.
M=6UB97)E9"(@8V5L;'-P86-I;F<](C`B/CQT<CX\=&@^)SL*("`@("`@("!F
M;W(@*"1L(#T@,3L@)&P@/#T@)&QI;F5S.R`D;"LK*2!["B`@("`@("`@("`@
M("1H=&UL("X]('-P<FEN=&8H)SQA(&ED/2)L)7,B(&AR968](B-L)7,B/B5S
M/"]A/CQB<B`O/B<L("1L+"`D;"P@)&PI("X@(EQN(CL*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1H=&UL("X@)SPO=&@^/'1D/B<@+B`D8V]D92`N("<\
M+W1D/CPO='(^/"]T86)L93XG.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N('1H92!-24U%(&-O;G1E;G0@='EP92!O9B!T:&4@<F5N9&5R960@8V]N
M=&5N="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O;G1E
M;G0@='EP92!O9B!T:&4@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)W1E>'0O:'1M;#L@8VAA
M<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"D["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP
M:'``````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8V,#<`,3`U,34T,S,W-#<`,#(T
M-3`W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"@IR97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+W-O
M=7)C92YP:'`G.PH*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]S<F-H:6=H;&ET
M92!C;&%S<R!R96YD97)S(&]U="!V87)I;W5S(&-O;G1E;G0@:6X@2%1-3`H@
M*B!F;W)M870@8GD@=7-I;F<@4V]U<F-E+6AI9VAL:6=H="X*("H*("H@4V]U
M<F-E+6AI9VAL:6=H=#H@:'1T<#HO+W=W=RYG;G4N;W)G+W-O9G1W87)E+W-R
M8RUH:6=H;&ET92\*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]S<F-H:6=H;&ET92YP:'`L=B`Q+C$T+C$P+C@@,C`P-B\P-B\P
M,2`P,SHP.#HU,R!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR
M,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME
M0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@
M0'!A8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO"F-L87-S($U)345?5FEE
M=V5R7W-R8VAI9VAL:71E(&5X=&5N9',@34E-15]6:65W97)?<V]U<F-E('L*
M"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@=&AE(&-U<G)E;G1L>2!S970@
M8V]N=&5N=',@=7-I;F<@4V]U<F-E+6AI9VAL:6=H=`H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@<&%R86UE=&5R<R!T:&4@=FEE
M=V5R(&UA>2!N965D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@<F5N9&5R960@8V]N=&5N=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E
M;F1E<B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!G;&]B86P@
M)&UI;65?9')I=F5R<SL*"B`@("`@("`@+RH@0VAE8VL@=&\@;6%K92!S=7)E
M('1H92!P<F]G<F%M(&%C='5A;&QY(&5X:7-T<RX@*B\*("`@("`@("!I9B`H
M(69I;&5?97AI<W1S*"1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W-R8VAI9VAL
M:71E)UU;)VQO8V%T:6]N)UTI*2!["B`@("`@("`@("`@(')E='5R;B`G/'!R
M93XG("X@<W!R:6YT9BA?*")4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI
M<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN
M(BDL("1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W-R8VAI9VAL:71E)UU;)VQO
M8V%T:6]N)UTI("X@)SPO<')E/B<["B`@("`@("`@?0H*("`@("`@("`O*B!#
M<F5A=&4@=&5M<&]R87)Y(&9I;&5S(&9O<B!796)C<'`N("HO"B`@("`@("`@
M)'1M<&EN("`]($AO<F1E.CIG971496UP1FEL92@G4W)C26XG*3L*("`@("`@
M("`D=&UP;W5T(#T@2&]R9&4Z.F=E=%1E;7!&:6QE*"=3<F-/=70G+"!F86QS
M92D["@H@("`@("`@("\J(%=R:71E('1H92!C;VYT96YT<R!O9B!O=7(@8G5F
M9F5R('1O('1H92!T96UP;W)A<GD@:6YP=70@9FEL92X@*B\*("`@("`@("`D
M8V]N=&5N=',@/2`D=&AI<RT^;6EM95]P87)T+3YG971#;VYT96YT<R@I.PH@
M("`@("`@("1F:"`](&9O<&5N*"1T;7!I;BP@)W=B)RD["B`@("`@("`@9G=R
M:71E*"1F:"P@)&-O;G1E;G1S+"!S=')L96XH)&-O;G1E;G1S*2D["B`@("`@
M("`@9F-L;W-E*"1F:"D["@H@("`@("`@("\J($1E=&5R;6EN92!T:&4@;&%N
M9W5A9V4@9G)O;2!T:&4@;6EM92!T>7!E+B`J+PH@("`@("`@("1L86YG(#T@
M)R<["B`@("`@("`@<W=I=&-H("@D=&AI<RT^;6EM95]P87)T+3YG9714>7!E
M*"DI('L*("`@("`@("!C87-E("=T97AT+W@M:F%V82<Z"B`@("`@("`@("`@
M("1L86YG(#T@)VIA=F$G.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M8V%S92`G=&5X="]X+6-S<F,G.@H@("`@("`@(&-A<V4@)W1E>'0O>"UC*RMS
M<F,G.@H@("`@("`@(&-A<V4@)W1E>'0O8W!P)SH*("`@("`@("`@("`@)&QA
M;F<@/2`G8W!P)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@
M)V%P<&QI8V%T:6]N+W@M<&5R;"<Z"B`@("`@("`@("`@("1L86YG(#T@)W!E
M<FPG.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G87!P;&EC
M871I;VXO>"UP:'`G.@H@("`@("`@(&-A<V4@)W@M97AT96YS:6]N+W!H<',G
M.@H@("`@("`@(&-A<V4@)W@M97AT96YS:6]N+W!H<#-S)SH*("`@("`@("!C
M87-E("=A<'!L:6-A=&EO;B]X+6AT='!D+7!H<"<Z"B`@("`@("`@8V%S92`G
M87!P;&EC871I;VXO>"UH='1P9"UP:'`S)SH*("`@("`@("!C87-E("=A<'!L
M:6-A=&EO;B]X+6AT='!D+7!H<',G.@H@("`@("`@("`@("`D;&%N9R`]("=P
M:'`S)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)V%P<&QI
M8V%T:6]N+W@M<'ET:&]N)SH*("`@("`@("`@("`@)&QA;F<@/2`G<'ET:&]N
M)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`O+R`D;&%N9R`]
M("=P<F]L;V<G.PH@("`@("`@("`@("`O+R!B<F5A:SL*"B`@("`@("`@("`@
M("\O("1L86YG(#T@)V9L97@G.PH@("`@("`@("`@("`O+R!B<F5A:SL*"B`@
M("`@("`@("`@("\O("1L86YG(#T@)V-H86YG96QO9R<["B`@("`@("`@("`@
M("\O(&)R96%K.PH*("`@("`@("`@("`@+R\@)&QA;F<@/2`G<G5B>2<["B`@
M("`@("`@("`@("\O(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@+RH@17AE
M8W5T92!3;W5R8V4M2&EG:&QI=&4N("HO"B`@("`@("`@97AE8R@D;6EM95]D
M<FEV97)S6R=H;W)D92==6R=S<F-H:6=H;&ET92==6R=L;V-A=&EO;B==("X@
M(B`M+7-R8RUL86YG("1L86YG("TM;W5T+69O<FUA="!X:'1M;"`M+6EN<'5T
M("1T;7!I;B`M+6]U='!U="`D=&UP;W5T(BD["B`@("`@("`@)')E<W5L=',@
M/2!F:6QE7V=E=%]C;VYT96YT<R@D=&UP;W5T*3L*("`@("`@("!U;FQI;FLH
M)'1M<&]U="D["@H@("`@("`@("\J($5D=6-A=&5D($=U97-S(&%T('=H971H
M97(@=V4@87)E(&EN;&EN92!O<B!N;W0N("HO"B`@("`@("`@:68@*&AE861E
M<G-?<V5N="@I('Q\(&]B7V=E=%]L96YG=&@H*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/FQI;F5.=6UB97(H)')E<W5L=',I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B!5=&EL.CIB=69F97)/=71P=70H
M)W)E<75I<F4G+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=T96UP;&%T
M97,G+"`G:&]R9&4G*2`N("<O8V]M;6]N+6AE861E<BYI;F,G*2`N"B`@("`@
M("`@("`@("`@("`D=&AI<RT^;&EN94YU;6)E<B@D<F5S=6QT<RD@+@H@("`@
M("`@("`@("`@("`@571I;#HZ8G5F9F5R3W5T<'5T*"=R97%U:7)E)RP@)$=,
M3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@
M+B`G+V-O;6UO;BUF;V]T97(N:6YC)RD["B`@("`@("`@?0H@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<```````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P-#4V`#$P-3$U-#,S-S0W`#`R
M,S`P,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@5&AE($U)345?5FEE=V5R7W1G>B!C;&%S<R!R96YD
M97)S(&]U="!P;&%I;B!O<B!G>FEP<&5D('1A<F)A;&QS(&EN($A434PN"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<"QV(#$N,S<N,3`N,3,@,C`P-B\P,2\R-B`Q,#HR,CHT-B!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!!;FEL($UA9&AA=F%P961D>2`\
M86YI;$!R96-O:6PN;W)G/@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA
M96P@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R
M96-O:6PN;W)G/@H@*B!`875T:&]R("!-:6-H865L($-O8VAR86YE(#QM:6ME
M0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@
M0'!A8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO"F-L87-S($U)345?5FEE
M=V5R7W1G>B!E>'1E;F1S($U)345?5FEE=V5R('L*"B`@("`O*BH*("`@("`J
M(%)E;F1E<B!O=70@=&AE(&-U<G)E;G1L>2!S970@=&%R(&9I;&4@8V]N=&5N
M=',N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N>2!P
M87)A;65T97)S('1H92!6:65W97(@;6%Y(&YE960N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!C;VYT96YT<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@
M>PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O0V]M<')E<W,N<&AP)SL*
M"B`@("`@("`@)&-O;G1E;G1S(#T@)'1H:7,M/FUI;65?<&%R="T^9V5T0V]N
M=&5N=',H*3L*"B`@("`@("`@+RH@3VYL>2!D96-O;7!R97-S(&=Z:7!P960@
M9FEL97,N("HO"B`@("`@("`@)'-U8G1Y<&4@/2`D=&AI<RT^;6EM95]P87)T
M+3YG9713=6)4>7!E*"D["B`@("`@("`@:68@*"@D<W5B='EP92`]/2`G>"UC
M;VUP<F5S<V5D+71A<B<I('Q\"B`@("`@("`@("`@("@D<W5B='EP92`]/2`G
M=&=Z)RD@?'P*("`@("`@("`@("`@*"1S=6)T>7!E(#T]("=X+71G>B<I('Q\
M"B`@("`@("`@("`@("@D<W5B='EP92`]/2`G9WII<"<I('Q\"B`@("`@("`@
M("`@("@D<W5B='EP92`]/2`G>"UG>FEP)RD@?'P*("`@("`@("`@("`@*"1S
M=6)T>7!E(#T]("=X+6=Z:7`M8V]M<')E<W-E9"<I('Q\"B`@("`@("`@("`@
M("@D<W5B='EP92`]/2`G>"UG=&%R)RDI('L*("`@("`@("`@("`@)&=Z:7`@
M/2`F2&]R9&5?0V]M<')E<W,Z.G-I;F=L971O;B@G9WII<"<I.PH@("`@("`@
M("`@("`D8V]N=&5N=',@/2`D9WII<"T^9&5C;VUP<F5S<R@D8V]N=&5N=',I
M.PH@("`@("`@("`@("!I9B`H96UP='DH)&-O;G1E;G1S*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("<\<')E/B<@+B!?*")5;F%B;&4@=&\@;W!E;B!C
M;VUP<F5S<V5D(&%R8VAI=F4N(BD@+B`G/"]P<F4^)SL*("`@("`@("`@("`@
M?2!E;'-E:68@*&ES7V$H)&-O;G1E;G1S+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)SQP<F4^)R`N("1C;VYT96YT<RT^9V5T
M365S<V%G92@I("X@)SPO<')E/B<["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(&EF("@D<W5B='EP92`]/2`G9WII<"<@?'P*("`@("`@("`@
M("`@)'-U8G1Y<&4@/3T@)W@M9WII<"<@?'P*("`@("`@("`@("`@)'-U8G1Y
M<&4@/3T@)W@M9WII<"UC;VUP<F5S<V5D)RD@>PH@("`@("`@("`@("!G;&]B
M86P@)&-O;F8["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-
M12]-86=I8RYP:'`G.PH@("`@("`@("`@("`D;6EM95]T>7!E(#T@34E-15]-
M86=I8SHZ86YA;'EZ941A=&$H)&-O;G1E;G1S+"!I<W-E="@D8V]N9ELG;6EM
M92==6R=M86=I8U]D8B==*2`_("1C;VYF6R=M:6UE)UU;)VUA9VEC7V1B)UT@
M.B!N=6QL*3L*("`@("`@("`@("`@:68@*"$D;6EM95]T>7!E*2!["B`@("`@
M("`@("`@("`@("`D;6EM95]T>7!E(#T@7R@B56YK;F]W;B(I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(')E='5R;B`G/'!R93XG("X@7R@B0V]N=&5N
M="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@(BD@+B`D;6EM95]T>7!E("X@
M)SPO<')E/B<["B`@("`@("`@?0H*("`@("`@("`O*B!/8G1A:6X@=&AE(&QI
M<W0@;V8@9FEL97,O9&%T82!I;B!T:&4@=&%R(&9I;&4N("HO"B`@("`@("`@
M)'1A<B`]("9(;W)D95]#;VUP<F5S<SHZ<VEN9VQE=&]N*"=T87(G*3L*"B`@
M("`@("`@)'1A<D1A=&$@/2`D=&%R+3YD96-O;7!R97-S*"1C;VYT96YT<RD[
M"B`@("`@("`@:68@*&ES7V$H)'1A<D1A=&$L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("<\<')E/B<@+B`D=&%R1&%T82T^9V5T365S
M<V%G92@I("X@)SPO<')E/B<["B`@("`@("`@?0H*("`@("`@("`D9FEL94-O
M=6YT(#T@8V]U;G0H)'1A<D1A=&$I.PH*("`@("`@("!I;F-L=61E7V]N8V4@
M)TAO<F1E+U1E>'0N<&AP)SL*"B`@("`@("`@)'1E>'0@(#T@)SQS=')O;F<^
M)R`N(&AT;6QS<&5C:6%L8VAA<G,H<W!R:6YT9BA?*")#;VYT96YT<R!O9B!<
M(B5S7"(B*2P@)'1H:7,M/FUI;65?<&%R="T^9V5T3F%M92@I*2D@+B`G.CPO
M<W1R;VYG/B<@+B`B7&XB.PH@("`@("`@("1T97AT("X]("<\=&%B;&4^/'1R
M/CQT9"!A;&EG;CTB;&5F="(^/'1T/CQS<&%N(&-L87-S/2)F:7AE9"(^)SL*
M("`@("`@("`D=&5X="`N/2!497AT.CIH=&UL06QL4W!A8V5S*%\H(D%R8VAI
M=F4@3F%M92(I("X@)SH@("<@+B`D=&AI<RT^;6EM95]P87)T+3YG971.86UE
M*"DI("X@(EQN(CL*("`@("`@("`D=&5X="`N/2!497AT.CIH=&UL06QL4W!A
M8V5S*%\H(D%R8VAI=F4@1FEL92!3:7IE(BD@+B`G.B`G("X@<W1R;&5N*"1C
M;VYT96YT<RD@+B`G(&)Y=&5S)RD@+B`B7&XB.PH@("`@("`@("1T97AT("X]
M(%1E>'0Z.FAT;6Q!;&Q3<&%C97,H*"1F:6QE0V]U;G0@(3T@,2D@/R!S<')I
M;G1F*%\H(D9I;&4@0V]U;G0Z("5S(&9I;&5S(BDL("1F:6QE0V]U;G0I(#H@
M<W!R:6YT9BA?*")&:6QE($-O=6YT.B`E<R!F:6QE(BDL("1F:6QE0V]U;G0I
M*3L*("`@("`@("`D=&5X="`N/2`B7&Y<;B(["B`@("`@("`@)'1E>'0@+CT@
M5&5X=#HZ:'1M;$%L;%-P86-E<R@*("`@("`@("`@("`@("`@("`@("`@<W1R
M7W!A9"A?*")&:6QE($YA;64B*2P@("`@(#8R+"`G("<L(%-44E]0041?4DE'
M2%0I("X*("`@("`@("`@("`@("`@("`@("`@<W1R7W!A9"A?*")!='1R:6)U
M=&5S(BDL("`@(#$U+"`G("<L(%-44E]0041?3$5&5"D@+@H@("`@("`@("`@
M("`@("`@("`@("!S=')?<&%D*%\H(E-I>F4B*2P@("`@("`@("`@,3`L("<@
M)RP@4U127U!!1%],1494*2`N"B`@("`@("`@("`@("`@("`@("`@('-T<E]P
M860H7R@B36]D:69I960@1&%T92(I+"`Q.2P@)R`G+"!35%)?4$%$7TQ%1E0I
M"B`@("`@("`@("`@("`@("`@*2`N(")<;B(["@H@("`@("`@("1T97AT("X]
M('-T<E]R97!E870H)RTG+"`Q,#8I("X@(EQN(CL*"B`@("`@("`@9F]R96%C
M:"`H)'1A<D1A=&$@87,@)'9A;"D@>PH@("`@("`@("`@("1T97AT("X](%1E
M>'0Z.FAT;6Q!;&Q3<&%C97,H"B`@("`@("`@("`@("`@("`@("`@("`@('-T
M<E]P860H)'9A;%LG;F%M92==+"`V,BP@)R`G+"!35%)?4$%$7U))1TA4*2`N
M"B`@("`@("`@("`@("`@("`@("`@("`@('-T<E]P860H)'9A;%LG871T<B==
M+"`Q-2P@)R`G+"!35%)?4$%$7TQ%1E0I("X*("`@("`@("`@("`@("`@("`@
M("`@("`@<W1R7W!A9"@D=F%L6R=S:7IE)UTL(#$P+"`G("<L(%-44E]0041?
M3$5&5"D@+@H@("`@("`@("`@("`@("`@("`@("`@("!S=')?<&%D*'-T<F9T
M:6UE*"(E9"TE8BTE62`E2#HE32(L("1V86Q;)V1A=&4G72DL(#$Y+"`G("<L
M(%-44E]0041?3$5&5"D*("`@("`@("`@("`@("`@("`@("`I("X@(EQN(CL*
M("`@("`@("!]"@H@("`@("`@("1T97AT("X]('-T<E]R97!E870H)RTG+"`Q
M,#8I("X@(EQN(CL*("`@("`@("`D=&5X="`N/2`G/"]S<&%N/CPO='0^/"]T
M9#X\+W1R/CPO=&%B;&4^)SL*"B`@("`@("`@<F5T=7)N(&YL,F)R*"1T97AT
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@8V]N=&5N="UT
M>7!E"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C;VYT96YT
M+71Y<&4@;V8@=&AE(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=T97AT+VAT;6P[(&-H87)S
M970])R`N($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<```````````````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#,T-#``,3`U,34T,S,W-#<`,#(S,3(V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!4:&4@34E-15]6:65W97)?=&YE9B!C;&%S<R!A;&QO=W,@35,M5$Y%
M1B!A='1A8VAM96YT<R!T;R!B92!D:7-P;&%Y960N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`L=B`Q+C$S+C$P
M+CD@,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#(M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@
M*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R
M>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!A=71H
M;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O
M+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E
M7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]T;F5F(&5X=&5N
M9',@34E-15]6:65W97(@>PH*("`@("\J*@H@("`@("H@4F5N9&5R(&]U="!T
M:&4@8W5R<F5N="!T;F5F(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1P87)A;7,@($%N>2!P87)A;65T97)S('1H92!V:65W97(@;6%Y(&YE
M960N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E
M9"!C;VYT96YT<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O0V]M<')E<W,N<&AP)SL*"B`@("`@("`@)'1N968@/2`F2&]R9&5?0V]M
M<')E<W,Z.G-I;F=L971O;B@G=&YE9B<I.PH*("`@("`@("`D9&%T82`]("<\
M=&%B;&4@8F]R9&5R/2(Q(CXG.PH@("`@("`@("1I;F9O(#T@)'1N968M/F1E
M8V]M<')E<W,H)'1H:7,M/FUI;65?<&%R="T^9V5T0V]N=&5N=',H*2D["B`@
M("`@("`@:68@*&5M<'1Y*"1I;F9O*2!\?"!I<U]A*"1I;F9O+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("1D871A("X]("<\='(^/'1D/B<@+B!?
M*")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(BD@+B`G
M/"]T9#X\+W1R/B<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&1A
M=&$@+CT@)SQT<CX\=&0^)R`N(%\H(DYA;64B*2`N("<\+W1D/CQT9#XG("X@
M7R@B36EM92!4>7!E(BD@+B`G/"]T9#X\+W1R/B<["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1I;F9O(&%S("1P87)T*2!["B`@("`@("`@("`@("`@("`D9&%T
M82`N/2`G/'1R/CQT9#XG("X@)'!A<G1;)VYA;64G72`N("<\+W1D/CQT9#XG
M("X@)'!A<G1;)W1Y<&4G72`N("<O)R`N("1P87)T6R=S=6)T>7!E)UT@+B`G
M/"]T9#X\+W1R/B<["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M)&1A=&$@+CT@)SPO=&%B;&4^)SL*"B`@("`@("`@<F5T=7)N("1D871A.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!-24U%(&-O;G1E;G0@
M='EP92!O9B!T:&4@<F5N9&5R960@8V]N=&5N="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&-O;G1E;G0@='EP92!O9B!T:&4@;W5T<'5T
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@
M("!R971U<FX@)W1E>'0O:'1M;#L@8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R
M<V5T*"D["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#(W-#4V`#$P-3$U-#,S-S0W`#`R,S,P-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M5&AE($U)345?5FEE=V5R7W9C87)D(&-L87-S(')E;F1E<G,@;W5T('9#87)D
M<R!I;B!(5$U,(&9O<FUA="X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`L=B`Q+C,T+C$P+C<@,C`P-B\P,2\P
M,2`R,3HR.#HR-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P
M-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*
M("H@0'-I;F-E("`@2&]R9&4@,BXP"B`J($!P86-K86=E($AO<F1E7TU)345?
M5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]V8V%R9"!E>'1E;F1S($U)
M345?5FEE=V5R('L*"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@=&AE('9C
M87)D(&-O;G1E;G1S+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("!!;GD@<&%R86UE=&5R<R!T:&4@5FEE=V5R(&UA>2!N965D+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5N9&5R960@8V]N=&5N
M=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@D<&%R86US(#T@;G5L
M;"D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y+"`D<')E9G,["@H@
M("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O:4-A;&5N9&%R+G!H<"<["@H@
M("`@("`@("1A<'`@/2!F86QS93L*("`@("`@("`D9&%T82`]("1T:&ES+3YM
M:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"D["B`@("`@("`@)&AT;6P@/2`G)SL*
M("`@("`@("`D:6UP;W)T7VUS9R`](&YU;&P["B`@("`@("`@)'1I=&QE(#T@
M7R@B=D-A<F0B*3L*"B`@("`@("`@)&E#86P@/2`F;F5W($AO<F1E7VE#86QE
M;F1A<B@I.PH@("`@("`@(&EF("@A)&E#86PM/G!A<G-E=D-A;&5N9&%R*"1D
M871A*2D@>PH@("`@("`@("`@("`D:6UP;W)T7VUS9R`](%\H(E1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("A5=&EL.CIG971&;W)M1&%T82@G:6UP;W)T
M)RD@)B8*("`@("`@("`@("`@571I;#HZ9V5T1F]R;41A=&$H)W-O=7)C92<I
M("8F"B`@("`@("`@("`@("1R96=I<W1R>2T^:&%S365T:&]D*"=C;VYT86-T
M<R]I;7!O<G0G*2D@>PH@("`@("`@("`@("`D<V]U<F-E(#T@571I;#HZ9V5T
M1F]R;41A=&$H)W-O=7)C92<I.PH@("`@("`@("`@("`D8V]N=&%C=',@/2`D
M<F5G:7-T<GDM/F-A;&PH)V-O;G1A8W1S+VEM<&]R="<L(&%R<F%Y*"1D871A
M+"`G=&5X="]X+79C87)D)RP@)'-O=7)C92DI.PH@("`@("`@("`@("!I9B`H
M:7-?82@D8V]N=&%C=',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@("1I;7!O<G1?;7-G(#T@7R@B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@8V]N=&%C="!D871A+B(I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@:68@*"1I0V%L+3YG971#;VUP;VYE;G1#;W5N
M="@I(#T](#$I('L*("`@("`@("`@("`@("`@("`@("`D:6UP;W)T7VUS9R`]
M(%\H(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U
M<B!A9&1R97-S(&)O;VLN(BD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("1I;7!O<G1?;7-G(#T@7R@B0V]N=&%C=',@
M=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN
M(BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("1H=&UL("`](%5T:6PZ.F)U9F9E<D]U='!U="@G:6YC;'5D
M92<L("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N("<O
M8V]M;6]N+6AE861E<BYI;F,G*3L*("`@("`@("`D:'1M;"`N/2`G/'1A8FQE
M(&-E;&QS<&%C:6YG/2(Q(B!B;W)D97(](C`B(&-E;&QP861D:6YG/2(Q(CXG
M.PH@("`@("`@(&EF("@A:7-?;G5L;"@D:6UP;W)T7VUS9RDI('L*("`@("`@
M("`@("`@)&AT;6P@+CT@)SQT<CX\=&0@8V]L<W!A;CTB,B(@8VQA<W,](FAE
M861E<B(^)R`N("1I;7!O<G1?;7-G("X@)SPO=&0^/"]T<CX\='(^/'1D/B9N
M8G-P.SPO=&0^/"]T<CXG.PH@("`@("`@('T@96QS96EF("@D<F5G:7-T<GDM
M/FAA<TUE=&AO9"@G8V]N=&%C=',O:6UP;W)T)RD@)B8*("`@("`@("`@("`@
M("`@("`@)')E9VES=')Y+3YH87--971H;V0H)V-O;G1A8W1S+W-O=7)C97,G
M*2D@>PH@("`@("`@("`@("`D:'1M;"`N/2`G/'1R/CQT9"!C;VQS<&%N/2(R
M(B!C;&%S<STB:&5A9&5R(CX\9F]R;2!A8W1I;VX](B<@+B`D7U-%4E9%4ELG
M4$A07U-%3$8G72`N("<B(&UE=&AO9#TB9V5T(B!N86UE/2)V8V%R9%]I;7!O
M<G0B/B<@+B!5=&EL.CIF;W)M26YP=70H*3L*("`@("`@("`@("`@9F]R96%C
M:"`H)%]'150@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("`D
M:'1M;"`N/2`G/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB)R`N(&AT;6QS
M<&5C:6%L8VAA<G,H)&ME>2D@+B`G(B!V86QU93TB)R`N(&AT;6QS<&5C:6%L
M8VAA<G,H)'9A;"D@+B`G(B`O/B<["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1S;W5R8V5S(#T@)')E9VES=')Y+3YC86QL*"=C;VYT86-T<R]S;W5R
M8V5S)RP@87)R87DH=')U92DI.PH@("`@("`@("`@("!I9B`H8V]U;G0H)'-O
M=7)C97,I(#X@,2D@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@)SQI;G!U
M="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB(&YA;64](FEM<&]R="(@
M=F%L=64](B<@+B!?*")!9&0@=&\@861D<F5S<R!B;V]K.B(I("X@)R(@+SXG
M.PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@)SQS96QE8W0@;F%M93TB<V]U
M<F-E(CXG.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'-O=7)C97,@87,@
M)&ME>2`]/B`D;&%B96PI('L*("`@("`@("`@("`@("`@("`@("`D<V5L96-T
M960@/2`H)&ME>2`]/2`D<')E9G,M/F=E=%9A;'5E*"=A9&1?<V]U<F-E)RDI
M(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G.PH@("`@("`@("`@("`@
M("`@("`@("1H=&UL("X]("<\;W!T:6]N('9A;'5E/2(G("X@:'1M;'-P96-I
M86QC:&%R<R@D:V5Y*2`N("<B)R`N("1S96QE8W1E9"`N("<^)R`N(&AT;6QS
M<&5C:6%L8VAA<G,H)&QA8F5L*2`N("<\+V]P=&EO;CXG.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)&AT;6P@+CT@)SQI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB
M(&YA;64](FEM<&]R="(@=F%L=64](B<@+B!?*")!9&0@=&\@;7D@861D<F5S
M<R!B;V]K(BD@+B`G(B`O/B<["B`@("`@("`@("`@("`@("`D<V]U<F-E(#T@
M87)R87E?:V5Y<R@D<V]U<F-E<RD["B`@("`@("`@("`@("`@("`D:'1M;"`N
M/2`G/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB<V]U<F-E(B!V86QU93TB
M)R`N(&AT;6QS<&5C:6%L8VAA<G,H)'-O=7)C95LP72D@+B`G(B`O/B<["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1H=&UL("X]("<\+V9O<FT^/"]T
M9#X\+W1R/CQT<CX\=&0^)FYB<W`[/"]T9#X\+W1R/B<["B`@("`@("`@?0H*
M("`@("`@("`D:2`](#`["B`@("`@("`@9F]R96%C:"`H)&E#86PM/F=E=$-O
M;7!O;F5N=',H*2!A<R`D=F,I('L*("`@("`@("`@("`@:68@*"1I(#X@,"D@
M>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@)SQT<CX\=&0^)FYB<W`[/"]T
M9#X\+W1R/B<["B`@("`@("`@("`@('T*("`@("`@("`@("`@*RLD:3L*"B`@
M("`@("`@("`@("1H=&UL("X]("<\='(^/'1D(&-O;'-P86X](C(B(&-L87-S
M/2)H96%D97(B/B<["B`@("`@("`@("`@("1F=6QL;F%M92`]("1V8RT^9V5T
M071T<FEB=71E1&5F875L="@G1DXG+"!F86QS92D["B`@("`@("`@("`@(&EF
M("@D9G5L;&YA;64@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D:'1M
M;"`N/2`D9G5L;&YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&AT
M;6P@+CT@)SPO=&0^/"]T<CXG.PH*("`@("`@("`@("`@)&X@/2`D=F,M/G!R
M:6YT86)L94YA;64H*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D;BDI('L*
M("`@("`@("`@("`@("`@("1H=&UL("X]("1T:&ES+3Y?<F]W*%\H(DYA;64B
M*2P@)&XI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D86QI87-E<R`]
M("1V8RT^9V5T071T<FEB=71E5F%L=65S*"=!3$E!4R<I.PH@("`@("`@("`@
M("!I9B`H(6ES7V$H)&%L:6%S97,L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@("1H=&UL("X]("1T:&ES+3Y?<F]W*%\H(D%L:6%S(BDL(&EM
M<&QO9&4H)SQB<B`O/B<L("1A;&EA<V5S*2D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&)I<G1H9&%Y<R`]("1V8RT^9V5T071T<FEB=71E5F%L=65S
M*"="1$%9)RD["B`@("`@("`@("`@(&EF("@A:7-?82@D8FER=&AD87ES+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2`D=&AI
M<RT^7W)O=RA?*")":7)T:&1A>2(I+"!D871E*"=9+6TM9"<L("1B:7)T:&1A
M>7-;,%TI*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&QA8F5L<R`]
M("1V8RT^9V5T06QL071T<FEB=71E<R@G3$%"14PG*3L*("`@("`@("`@("`@
M9F]R96%C:"`H)&QA8F5L<R!A<R`D;&%B96PI('L*("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D;&%B96Q;)W!A<F%M<R==6R=465!%)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)&QA8F5L6R=P87)A;7,G75LG5%E0
M12==(&%S("1T>7!E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1L86)E
M;%LG<&%R86US)UU;4W1R:6YG.CIU<'!E<B@D='EP92E=(#T@=')U93L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&QA8F5L6R=P87)A;7,G75LG2$]-12==*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1H=&UL("X]("1T:&ES+3Y?<F]W*%\H
M(DAO;64@061D<F5S<R(I+"!N;#)B<B@D;&%B96Q;)W9A;'5E)UTI*3L*("`@
M("`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D;&%B96Q;)W!A<F%M<R==
M6R=73U)+)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@)'1H
M:7,M/E]R;W<H7R@B5V]R:R!!9&1R97-S(BDL(&YL,F)R*"1L86)E;%LG=F%L
M=64G72DI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?*")!9&1R97-S(BDL(&YL
M,F)R*"1L86)E;%LG=F%L=64G72DI.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O+R!&;W(@=D-A<F0@,RXP+@H@("`@
M("`@("`@("`D861R<R`]("1V8RT^9V5T06QL071T<FEB=71E<R@G0412)RD[
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1A9')S(&%S("1I=&5M*2!["B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&ET96U;)W!A<F%M<R==6R=465!%)UTI
M*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D:71E;5LG
M<&%R86US)UU;)U194$4G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&ET96U;)W!A<F%M<R==6R=465!%)UT@/2!A<G)A>2@D:71E;5LG<&%R86US
M)UU;)U194$4G72D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D:71E;5LG<&%R
M86US)UU;)U194$4G72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1I=&5M6R=P87)A;7,G75LG5T]22R==*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D:71E;5LG<&%R86US)UU;)U194$4G75M=(#T@
M)U=/4DLG.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&ET96U;)W!A<F%M<R==6R=(3TU%)UTI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1I=&5M6R=P87)A;7,G75LG5%E012==
M6UT@/2`G2$]-12<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@)&%D9')E<W,@/2`D:71E;5LG=F%L
M=65S)UT["B`@("`@("`@("`@("`@("!F;W)E86-H("@D:71E;5LG<&%R86US
M)UU;)U194$4G72!A<R`D861R*2!["B`@("`@("`@("`@("`@("`@("`@:68@
M*%-T<FEN9SHZ=7!P97(H)&%D<BD@/3T@)TA/344G*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1A(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1A9&1R97-S6U9#05)$7T%$4E]35%)%151=*2D@
M("![("1A6UT@/2`D861D<F5S<UM60T%21%]!1%)?4U12145473L@?0H@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%D9')E<W-;5D-!4D1?
M04127TQ/0T%,251972DI('L@)&%;72`]("1A9&1R97-S6U9#05)$7T%$4E],
M3T-!3$E465T[('T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1A9&1R97-S6U9#05)$7T%$4E]214=)3TY=*2D@("![("1A6UT@/2`D861D
M<F5S<UM60T%21%]!1%)?4D5'24].73L@?0H@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&%D9')E<W-;5D-!4D1?04127U!/4U1#3T1%72DI
M('L@)&%;72`]("1A9&1R97-S6U9#05)$7T%$4E]03U-40T]$15T[('T*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A9&1R97-S6U9#05)$
M7T%$4E]#3U5.5%)972DI("![("1A6UT@/2`D861D<F5S<UM60T%21%]!1%)?
M0T]53E1265T[('T*("`@("`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@
M)'1H:7,M/E]R;W<H7R@B2&]M92!!9&1R97-S(BDL(&YL,F)R*&EM<&QO9&4H
M(EQN(BP@)&$I*2D["@H@("`@("`@("`@("`@("`@("`@('T@96QS96EF("A3
M=')I;F<Z.G5P<&5R*"1A9'(I(#T]("=73U)+)RD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D82`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D861D<F5S<UM60T%21%]!1%)?4U12145472DI("`@
M>R`D85M=(#T@)&%D9')E<W-;5D-!4D1?04127U-44D5%5%T[('T*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A9&1R97-S6U9#05)$7T%$
M4E],3T-!3$E465TI*2![("1A6UT@/2`D861D<F5S<UM60T%21%]!1%)?3$]#
M04Q)5%E=.R!]"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M861D<F5S<UM60T%21%]!1%)?4D5'24].72DI("`@>R`D85M=(#T@)&%D9')E
M<W-;5D-!4D1?04127U)%1TE/3ET[('T*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1A9&1R97-S6U9#05)$7T%$4E]03U-40T]$15TI*2![
M("1A6UT@/2`D861D<F5S<UM60T%21%]!1%)?4$]35$-/1$5=.R!]"B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D861D<F5S<UM60T%21%]!
M1%)?0T]53E1265TI*2`@>R`D85M=(#T@)&%D9')E<W-;5D-!4D1?04127T-/
M54Y44EE=.R!]"B`@("`@("`@("`@("`@("`@("`@("`@("1H=&UL("X]("1T
M:&ES+3Y?<F]W*%\H(E=O<FL@061D<F5S<R(I+"!N;#)B<BAI;7!L;V1E*")<
M;B(L("1A*2DI.PH*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D82`](&%R<F%Y*"D["B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D861D<F5S<UM60T%21%]!1%)?4U12
M145472DI("`@>R`D85M=(#T@)&%D9')E<W-;5D-!4D1?04127U-44D5%5%T[
M('T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A9&1R97-S
M6U9#05)$7T%$4E],3T-!3$E465TI*2![("1A6UT@/2`D861D<F5S<UM60T%2
M1%]!1%)?3$]#04Q)5%E=.R!]"B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D861D<F5S<UM60T%21%]!1%)?4D5'24].72DI("`@>R`D85M=
M(#T@)&%D9')E<W-;5D-!4D1?04127U)%1TE/3ET[('T*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1A9&1R97-S6U9#05)$7T%$4E]03U-4
M0T]$15TI*2![("1A6UT@/2`D861D<F5S<UM60T%21%]!1%)?4$]35$-/1$5=
M.R!]"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D861D<F5S
M<UM60T%21%]!1%)?0T]53E1265TI*2`@>R`D85M=(#T@)&%D9')E<W-;5D-!
M4D1?04127T-/54Y44EE=.R!]"B`@("`@("`@("`@("`@("`@("`@("`@("1H
M=&UL("X]("1T:&ES+3Y?<F]W*%\H(D%D9')E<W,B*2P@;FPR8G(H:6UP;&]D
M92@B7&XB+"`D82DI*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1N=6UB97)S
M(#T@)'9C+3YG971!;&Q!='1R:6)U=&5S*"=414PG*3L*"B`@("`@("`@("`@
M(&9O<F5A8V@@*"1N=6UB97)S(&%S("1N=6UB97(I('L*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D;G5M8F5R6R=P87)A;7,G75LG5%E012==*2D@>PH@
M("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1N=6UB97);)W!A<F%M<R==
M6R=465!%)UT@87,@)'1Y<&4I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&YU;6)E<ELG<&%R86US)UU;4W1R:6YG.CIU<'!E<B@D='EP92E=(#T@=')U
M93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)&YU;6)E<ELG<&%R86US)UU;)T9!
M6"==*2D@>PH@("`@("`@("`@("`@("`@("`@("1H=&UL("X]("1T:&ES+3Y?
M<F]W*%\H(D9A>"(I+"`D;G5M8F5R6R=V86QU92==*3L*("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1N
M=6UB97);)W!A<F%M<R==6R=(3TU%)UTI*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1H=&UL("X]("1T:&ES+3Y?<F]W*%\H(DAO;64@4&AO;F4B*2P@
M)&YU;6)E<ELG=F%L=64G72D["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M:68@*&ES<V5T*"1N=6UB97);)W!A<F%M<R==6R=73U)+)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1H=&UL("X]("1T:&ES+3Y?<F]W*%\H(E=O
M<FL@4&AO;F4B*2P@)&YU;6)E<ELG=F%L=64G72D["B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E:68@*&ES<V5T*"1N=6UB97);)W!A<F%M<R==6R=#14Q,
M)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1H=&UL("X]("1T:&ES
M+3Y?<F]W*%\H(D-E;&P@4&AO;F4B*2P@)&YU;6)E<ELG=F%L=64G72D["B`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&AT;6P@+CT@)'1H:7,M/E]R;W<H7R@B4&AO;F4B*2P@)&YU;6)E
M<ELG=F%L=64G72D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`D861D<F5S<V5S
M(#T@)'9C+3YG971!;&Q!='1R:6)U=&5S*"=%34%)3"<I.PH@("`@("`@("`@
M("`D96UA:6QS(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R96%C:"`H)&%D
M9')E<W-E<R!A<R`D861D<F5S<RD@>PH@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1A9&1R97-S6R=P87)A;7,G75LG5%E012==*2D@>PH@("`@("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1A9&1R97-S6R=P87)A;7,G75LG5%E012==
M(&%S("1T>7!E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1A9&1R97-S
M6R=P87)A;7,G75M3=')I;F<Z.G5P<&5R*"1T>7!E*5T@/2!T<G5E.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1E;6%I;"`]("<\82!H<F5F/2(G.PH@("`@("`@("`@("`@("`@
M:68@*"1R96=I<W1R>2T^:&%S365T:&]D*"=M86EL+V-O;7!O<V4G*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1E;6%I;"`N/2`D<F5G:7-T<GDM/F-A;&PH
M)VUA:6PO8V]M<&]S92<L(&%R<F%Y*&%R<F%Y*"=T;R<@/3X@)&%D9')E<W-;
M)W9A;'5E)UTI*2D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1E;6%I;"`N/2`G;6%I;'1O.B<@+B`D861D<F5S<ULG
M=F%L=64G73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1E
M;6%I;"`N/2`G(CXG("X@)&%D9')E<W-;)W9A;'5E)UT@+B`G/"]A/B<["B`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)&%D9')E<W-;)W!A<F%M<R==6R=0
M4D5&)UTI*2!["B`@("`@("`@("`@("`@("`@("`@87)R87E?=6YS:&EF="@D
M96UA:6QS+"`D96UA:6PI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`D96UA:6QS6UT@/2`D96UA:6P["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("AC;W5N
M="@D96UA:6QS*2D@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@)'1H:7,M
M/E]R;W<H7R@B16UA:6PB*2P@:6UP;&]D92@G/&)R("\^)RP@)&5M86EL<RDI
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&ET;&4@/2`D=F,M/F=E
M=$%T=')I8G5T959A;'5E<R@G5$E43$4G*3L*("`@("`@("`@("`@:68@*"%I
M<U]A*"1T:71L92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M)&AT;6P@+CT@)'1H:7,M/E]R;W<H7R@B5&ET;&4B*2P@)'1I=&QE6S!=*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)')O;&4@/2`D=F,M/F=E=$%T
M=')I8G5T959A;'5E<R@G4D],12<I.PH@("`@("`@("`@("!I9B`H(6ES7V$H
M)')O;&4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1H=&UL
M("X]("1T:&ES+3Y?<F]W*%\H(E)O;&4B*2P@)')O;&5;,%TI.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D;W)G(#T@)'9C+3YG971!='1R:6)U=&56
M86QU97,H)T]21R<I.PH@("`@("`@("`@("!I9B`H(6ES7V$H)&]R9RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@)'1H:7,M
M/E]R;W<H7R@B0V]M<&%N>2(I+"`D;W)G6S!=*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)&YO=&5S(#T@)'9C+3YG971!='1R:6)U=&5686QU97,H
M)TY/5$4G*3L*("`@("`@("`@("`@:68@*"%I<U]A*"1N;W1E<RP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@)'1H:7,M/E]R
M;W<H7R@B3F]T97,B*2P@;FPR8G(H)&YO=&5S6S!=*2D["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1U<FP@/2`D=F,M/F=E=$%T=')I8G5T959A;'5E
M<R@G55),)RD["B`@("`@("`@("`@(&EF("@A:7-?82@D=7)L+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O
M=RA?*")54DPB*2P@)SQA(&AR968](B<@+B`D=7)L6S!=+B`G(B!T87)G970]
M(E]B;&%N:R(^)R`N("1U<FQ;,%T@+B`G/"]A/B<I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`D:'1M;"`N/2`G/"]T86)L93XG.PH@("`@
M("`@("1H=&UL("X](%5T:6PZ.F)U9F9E<D]U='!U="@G:6YC;'5D92<L("1R
M96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N("<O8V]M;6]N
M+69O;W1E<BYI;F,G*3L*"B`@("`@("`@<F5T=7)N("1H=&UL.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]R;W<H)&QA8F5L+"`D=F%L=64I"B`@("!["B`@("`@
M("`@<F5T=7)N("<\='(^/'1D(&-L87-S/2)I=&5M(B!V86QI9VX](G1O<"(^
M)R`N("1L86)E;"`N("<\+W1D/CQT9"!C;&%S<STB:71E;2(@=F%L:6=N/2)T
M;W`B/B<@+B`D=F%L=64@+B`B/"]T9#X\+W1R/EQN(CL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;B!T:&4@34E-12!C;VYT96YT('1Y<&4@;V8@=&AE
M(')E;F1E<F5D(&-O;G1E;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!C;VYT96YT('1Y<&4@;V8@=&AE(&]U='!U="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=T
M97AT+VAT;6P[(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]W96)C<'`N
M<&AP````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8S,S0`,3`U,34T,S,W
M-#<`,#(S-#4W`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&4@34E-15]6:65W97)?=V5B8W!P(&-L
M87-S(')E;F1E<G,@;W5T('9A<FEO=7,@8V]N=&5N=`H@*B!I;B!(5$U,(&9O
M<FUA="!B>2!U<VEN9R!796(@0R!0;'5S(%!L=7,N"B`J"B`J(%=E8B!#(%!L
M=7,@<&QU<SH@:'1T<#HO+W=E8F-P<"YS;W5R8V5F;W)G92YN970O"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H
M<"QV(#$N,3$N,3`N."`R,#`V+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`
M9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`
M<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W
M97(*("HO"F-L87-S($U)345?5FEE=V5R7W=E8F-P<"!E>'1E;F1S($U)345?
M5FEE=V5R('L*"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@=&AE(&-U<G)E
M;G1L>2!S970@8V]N=&5N=',@=7-I;F<@5V5B($,@4&QU<R!0;'5S+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@<&%R86UE=&5R
M<R!T:&4@5FEE=V5R(&UA>2!N965D+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@<F5N9&5R960@8V]N=&5N=',N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(')E;F1E<B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@
M("!G;&]B86P@)&UI;65?9')I=F5R<SL*"B`@("`@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92]-24U%+T-O;G1E;G1S+G!H<"<["B`@("`@("`@)&%T=&%C:&UE
M;G0@/2!-24U%7T-O;G1E;G1S.CIV:65W07-!='1A8VAM96YT*"D["@H@("`@
M("`@("\J($-H96-K('1O(&UA:V4@<W5R92!T:&4@<')O9W)A;2!A8W1U86QL
M>2!E>&ES=',N("HO"B`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D;6EM95]D
M<FEV97)S6R=H;W)D92==6R=W96)C<'`G75LG;&]C871I;VXG72DI('L*("`@
M("`@("`@("`@<F5T=7)N("<\<')E/B<@+B!S<')I;G1F*%\H(E1H92!P<F]G
M<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@
M9F]U;F0@;VX@=&AE('-Y<W1E;2XB*2P@)&UI;65?9')I=F5R<ULG:&]R9&4G
M75LG=V5B8W!P)UU;)VQO8V%T:6]N)UTI("X@)SPO<')E/B<["B`@("`@("`@
M?0H*("`@("`@("`O*B!#<F5A=&4@=&5M<&]R87)Y(&9I;&5S(&9O<B!796)C
M<'`N("HO"B`@("`@("`@)'1M<&EN("`]($AO<F1E.CIG971496UP1FEL92@G
M5V5B8W!P26XG*3L*("`@("`@("`D=&UP;W5T(#T@2&]R9&4Z.F=E=%1E;7!&
M:6QE*"=796)C<'!/=70G*3L*"B`@("`@("`@+RH@5W)I=&4@=&AE(&-O;G1E
M;G1S(&]F(&]U<B!B=69F97(@=&\@=&AE('1E;7!O<F%R>2!I;G!U="!F:6QE
M+B`J+PH@("`@("`@("1C;VYT96YT<R`]("1T:&ES+3YM:6UE7W!A<G0M/F=E
M=$-O;G1E;G1S*"D["B`@("`@("`@)&9H(#T@9F]P96XH)'1M<&EN+"`G=V(G
M*3L*("`@("`@("!F=W)I=&4H)&9H+"`D8V]N=&5N=',L('-T<FQE;B@D8V]N
M=&5N=',I*3L*("`@("`@("!F8VQO<V4H)&9H*3L*"B`@("`@("`@+RH@1V5T
M('1H92!E>'1E;G-I;VX@9F]R('1H92!M:6UE('1Y<&4N("HO"B`@("`@("`@
M:6YC;'5D95]O;F-E("=(;W)D92]-24U%+TUA9VEC+G!H<"<["B`@("`@("`@
M)&5X="`]($U)345?36%G:6,Z.DU)3454;T5X="@D=&AI<RT^;6EM95]P87)T
M+3YG9714>7!E*"DI.PH*("`@("`@("`O*B!%>&5C=71E(%=E8B!#(%!L=7,@
M4&QU<RX@4W!E8VEF>6EN9R!T:&4@:6X@86YD(&]U="!F:6QE<R!D:61N)W0*
M("`@("`@("`@("!W;W)K(&9O<B!M92!B=70@<&EP97,@9&ED+B`J+PH@("`@
M("`@(&5X96,H)&UI;65?9')I=F5R<ULG:&]R9&4G75LG=V5B8W!P)UU;)VQO
M8V%T:6]N)UT@+B`B("TM<&EP92`M+7!I<&4@+7@])&5X="`M;"`M82`M="`\
M("1T;7!I;B`^("1T;7!O=70B*3L*("`@("`@("`D<F5S=6QT<R`](&9I;&5?
M9V5T7V-O;G1E;G1S*"1T;7!O=70I.PH*("`@("`@("`O*B!)9B!W92!A<F4@
M;F]T(&1I<W!L87EI;F<@:6YL:6YE+"!A;&P@=&AE(&9O<FUA='1I;F<@:7,@
M86QR96%D>0H@("`@("`@("`J(&1O;F4@9F]R('5S+B`J+PH@("`@("`@(&EF
M("@D871T86-H;65N="D@>PH@("`@("`@("`@("`O*B!4:&4@9FER<W0@,B!L
M:6YE<R!A<F4@=&AE($-O;G1E;G0M5'EP92!L:6YE(&%N9"!A(&)L86YK(&QI
M;F4*("`@("`@("`@("`@("H@<V\@=V4@<VAO=6QD(')E;6]V92!T:&5M(&)E
M9F]R92!O=71P=71T:6YG+B`J+PH@("`@("`@("`@("!R971U<FX@<')E9U]R
M97!L86-E*"(O+BI<;BXJ7&XO(BP@)R<L("1R97-U;'1S+"`Q*3L*("`@("`@
M("!]"@H@("`@("`@("\J($5X=')A8W0@=&AE('-T>6QE('-H965T+"!R96UO
M=FEN9R!A;GD@9VQO8F%L(&)O9'D@9F]R;6%T=&EN9PH@("`@("`@("`J(&EF
M('=E)W)E(&1I<W!L87EI;F<@:6YL:6YE+B`J+PH@("`@("`@("1R97,@/2!P
M<F5G7W-P;&ET*"<[*#PO<W1Y;&4^*7PH/'-T>6QE('1Y<&4](G1E>'0O8W-S
M(CXI.R<L("1R97-U;'1S*3L*("`@("`@("`D<W1Y;&4@/2`D<F5S6S%=.PH@
M("`@("`@("1S='EL92`]('!R96=?<F5P;&%C92@G+UQN8F]D>5QS*S][+BH_
M?2]S)RP@)R<L("1S='EL92D["@H@("`@("`@("\J($5X=')A8W0@=&AE(&-O
M;G1E;G0N("HO"B`@("`@("`@)')E<R`]('!R96=?<W!L:70H)R]</%PO/W!R
M95P^+R<L("1R97-U;'1S*3L*("`@("`@("`D8F]D>2`]("1R97-;,5T["@H@
M("`@("`@(')E='5R;B`G/'-T>6QE/B<@+B`D<W1Y;&4@+B`G/"]S='EL93X\
M9&EV(&-L87-S/2)W96)C<'`B('-T>6QE/2)W:&ET92US<&%C93IP<F4[9F]N
M="UF86UI;'DZ;6]N;W-P86-E(CXG("X@)&)O9'D@+B`G/"]D:78^)SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@34E-12!C;VYT96YT('1Y
M<&4@;V8@=&AE(')E;F1E<F5D(&-O;G1E;G0N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!C;VYT96YT('1Y<&4@;V8@=&AE(&]U='!U="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@
M<F5T=7)N("=T97AT+VAT;6P[(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E
M="@I.PH@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H
M<```````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P-C8W`#$P-3$U-#,S
M-S0W`#`R,S`P-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&AE($U)345?5FEE=V5R7WII<"!C;&%S
M<R!R96YD97)S(&]U="!T:&4@8V]N=&5N=',@;V8@6DE0(&9I;&5S(&EN($A4
M34P*("H@9F]R;6%T+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`L=B`Q+C,P+C$P+C$P(#(P,#8O,#(O,3`@,3,Z
M-30Z,#0@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`P+3(P,#8@0VAU
M8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R
M,#`R+3(P,#8@36EC:&%E;"!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC
M;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N
M8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!-:6-H865L($-O
M8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(
M;W)D92`R+C`*("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO"F-L
M87-S($U)345?5FEE=V5R7WII<"!E>'1E;F1S($U)345?5FEE=V5R('L*"B`@
M("`O*BH*("`@("`J(%)E;F1E<B!O=70@=&AE(&-U<G)E;G0@>FEP(&-O;G1E
M;G1S+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@
M<&%R86UE=&5R<R!T:&4@5FEE=V5R(&UA>2!N965D+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@<F5N9&5R960@8V]N=&5N=',N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(')E;F1E<B@D<&%R86US(#T@87)R87DH*2D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/E]R96YD97(H)'1H:7,M/FUI;65?
M<&%R="T^9V5T0V]N=&5N=',H*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/
M=71P=70@=&AE(&9I;&4@;&ES="X*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT96YT<R`@
M5&AE(&-O;G1E;G1S(&]F('1H92!Z:7`@87)C:&EV92X*("`@("`J($!P87)A
M;2!M:7AE9"`D8V%L;&)A8VL@("!4:&4@8V%L;&)A8VL@9G5N8W1I;VX@=&\@
M=7-E(&]N('1H92!Z:7!F:6QE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@:6YF;W)M871I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!F:6QE(&QI<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R96YD
M97(H)&-O;G1E;G1S+"`D8V%L;&)A8VL@/2!N=6QL*0H@("`@>PH@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O0V]M<')E<W,N<&AP)SL*"B`@("`@("`@
M)'II<"`]("9(;W)D95]#;VUP<F5S<SHZ<VEN9VQE=&]N*"=Z:7`G*3L*"B`@
M("`@("`@+RH@36%K92!S=7)E('1H:7,@:7,@82!V86QI9"!Z:7`@9FEL92X@
M*B\*("`@("`@("!I9B`H)'II<"T^8VAE8VM::7!$871A*"1C;VYT96YT<RD@
M/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B`G/'!R93XG("X@7R@B
M5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB
M*2`N("<\+W!R93XG.PH@("`@("`@('T*"B`@("`@("`@)'II<$EN9F\@/2`D
M>FEP+3YD96-O;7!R97-S*"1C;VYT96YT<RP@87)R87DH)V%C=&EO;B<@/3X@
M2$]21$5?0T]-4%)%4U-?6DE07TQ)4U0I*3L*("`@("`@("!I9B`H:7-?82@D
M>FEP26YF;RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'II<$EN9F\M/F=E=$UE<W-A9V4H*3L*("`@("`@("!]"B`@("`@("`@)&9I
M;&5#;W5N="`](&-O=6YT*"1Z:7!);F9O*3L*"B`@("`@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92]497AT+G!H<"<["@H@("`@("`@("1T97AT(#T@)SQS=')O
M;F<^)R`N(&AT;6QS<&5C:6%L8VAA<G,H<W!R:6YT9BA?*")#;VYT96YT<R!O
M9B!<(B5S7"(B*2P@)'1H:7,M/FUI;65?<&%R="T^9V5T3F%M92@I*2D@+B`G
M.CPO<W1R;VYG/B<@+B`B7&XB.PH@("`@("`@("1T97AT("X]("<\=&%B;&4^
M/'1R/CQT9"!A;&EG;CTB;&5F="(^/'1T/CQS<&%N(&-L87-S/2)F:7AE9"(^
M)SL*("`@("`@("`D=&5X="`N/2!497AT.CIH=&UL06QL4W!A8V5S*%\H(D%R
M8VAI=F4@3F%M92(I("X@)SH@)R`N("1T:&ES+3YM:6UE7W!A<G0M/F=E=$YA
M;64H*2D@+B`B7&XB.PH@("`@("`@("1T97AT("X](%1E>'0Z.FAT;6Q!;&Q3
M<&%C97,H7R@B07)C:&EV92!&:6QE(%-I>F4B*2`N("<Z("<@+B!S=')L96XH
M)&-O;G1E;G1S*2`N("<@8GET97,G*2`N(")<;B(["B`@("`@("`@)'1E>'0@
M+CT@5&5X=#HZ:'1M;$%L;%-P86-E<R@H)&9I;&5#;W5N="`A/2`Q*2`_('-P
M<FEN=&8H7R@B1FEL92!#;W5N=#H@)7,@9FEL97,B*2P@)&9I;&5#;W5N="D@
M.B!S<')I;G1F*%\H(D9I;&4@0V]U;G0Z("5S(&9I;&4B*2P@)&9I;&5#;W5N
M="DI.PH@("`@("`@("1T97AT("X](")<;EQN(CL*("`@("`@("`D=&5X="`N
M/2!497AT.CIH=&UL06QL4W!A8V5S*`H@("`@("`@("`@("`@("`@("`@("!S
M=')?<&%D*%\H(D9I;&4@3F%M92(I+"`@("`@(#4P+"`G("<L(%-44E]0041?
M4DE'2%0I("X*("`@("`@("`@("`@("`@("`@("`@<W1R7W!A9"A?*")!='1R
M:6)U=&5S(BDL("`@("`Q,"P@)R`G+"!35%)?4$%$7TQ%1E0I("X*("`@("`@
M("`@("`@("`@("`@("`@<W1R7W!A9"A?*")3:7IE(BDL("`@("`@("`@("`Q
M,"P@)R`G+"!35%)?4$%$7TQ%1E0I("X*("`@("`@("`@("`@("`@("`@("`@
M<W1R7W!A9"A?*")-;V1I9FEE9"!$871E(BDL("`Q.2P@)R`G+"!35%)?4$%$
M7TQ%1E0I("X*("`@("`@("`@("`@("`@("`@("`@<W1R7W!A9"A?*")-971H
M;V0B*2P@("`@("`@("`Q,"P@)R`G+"!35%)?4$%$7TQ%1E0I("X*("`@("`@
M("`@("`@("`@("`@("`@<W1R7W!A9"A?*")#4D,B*2P@("`@("`@("`@("`Q
M,"P@)R`G+"!35%)?4$%$7TQ%1E0I("X*("`@("`@("`@("`@("`@("`@("`@
M<W1R7W!A9"A?*")2871I;R(I+"`@("`@("`@("`@-RP@)R`G+"!35%)?4$%$
M7TQ%1E0I"B`@("`@("`@("`@("`@("`@*2`N(")<;B(["@H@("`@("`@("1T
M97AT("X]('-T<E]R97!E870H)RTG+"`Q,38I("X@(EQN(CL*"B`@("`@("`@
M9F]R96%C:"`H)'II<$EN9F\@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@
M("`@("1R871I;R`]("AE;7!T>2@D=F%L6R=S:7IE)UTI*2`_(#`@.B`Q,#`@
M*B`H)'9A;%LG8W-I>F4G72`O("1V86Q;)W-I>F4G72D["@H@("`@("`@("`@
M("`D=F%L6R=N86UE)UT@/2!S=')?<&%D*"1V86Q;)VYA;64G72P@-3`L("<@
M)RP@4U127U!!1%]224=(5"D["B`@("`@("`@("`@("1V86Q;)V%T='(G72`]
M('-T<E]P860H)'9A;%LG871T<B==+"`Q,"P@)R`G+"!35%)?4$%$7TQ%1E0I
M.PH@("`@("`@("`@("`D=F%L6R=S:7IE)UT@/2!S=')?<&%D*"1V86Q;)W-I
M>F4G72P@,3`L("<@)RP@4U127U!!1%],1494*3L*("`@("`@("`@("`@)'9A
M;%LG9&%T92==(#T@<W1R7W!A9"AS=')F=&EM92@B)60M)6(M)5D@)4@Z)4TB
M+"`D=F%L6R=D871E)UTI+"`Q.2P@)R`G+"!35%)?4$%$7TQ%1E0I.PH@("`@
M("`@("`@("`D=F%L6R=M971H;V0G72`]('-T<E]P860H)'9A;%LG;65T:&]D
M)UTL(#$P+"`G("<L(%-44E]0041?3$5&5"D["B`@("`@("`@("`@("1V86Q;
M)V-R8R==(#T@<W1R7W!A9"@D=F%L6R=C<F,G72P@,3`L("<@)RP@4U127U!!
M1%],1494*3L*("`@("`@("`@("`@)'9A;%LG<F%T:6\G72`]('-T<E]P860H
M<W!R:6YT9B@B)3$N,68E)2(L("1R871I;RDL(#<L("<@)RP@4U127U!!1%],
M1494*3L*"B`@("`@("`@("`@("1V86P@/2!A<G)A>5]M87`H87)R87DH)U1E
M>'0G+"`G:'1M;$%L;%-P86-E<R<I+"`D=F%L*3L*"B`@("`@("`@("`@(&EF
M("@A:7-?;G5L;"@D8V%L;&)A8VLI*2!["B`@("`@("`@("`@("`@("`D=F%L
M(#T@8V%L;%]U<V5R7V9U;F,H)&-A;&QB86-K+"`D:V5Y+"`D=F%L*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)'1E>'0@+CT@)'9A;%LG;F%M92==
M("X@)'9A;%LG871T<B==("X@)'9A;%LG<VEZ92==("X*("`@("`@("`@("`@
M("`@("`@("`@)'9A;%LG9&%T92==("X@)'9A;%LG;65T:&]D)UT@+B`D=F%L
M6R=C<F,G72`N"B`@("`@("`@("`@("`@("`@("`@("1V86Q;)W)A=&EO)UT@
M+B`B7&XB.PH@("`@("`@('T*"B`@("`@("`@)'1E>'0@+CT@<W1R7W)E<&5A
M="@G+2<L(#$Q-BD@+B`B7&XB.PH@("`@("`@("1T97AT("X]("<\+W-P86X^
M/"]T=#X\+W1D/CPO='(^/"]T86)L93XG.PH*("`@("`@("!R971U<FX@;FPR
M8G(H)'1E>'0I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!C
M;VYT96YT+71Y<&4*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(&-O;G1E;G0M='EP92!O9B!T:&4@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)W1E>'0O:'1M
M;#L@8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"D["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<BYP:'``````````````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S8S,#,`,3`U,34T,S,W-3``,#(R,3<P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!4:&4@34E-15]6:65W97(Z.B!C;&%S<R!P<F]V:61E<R!A
M;B!A8G-T<F%C=&5D(&EN=&5R9F%C92!T;PH@*B!R96YD97(@;W5T($U)344@
M='EP97,@:6YT;R!(5$U,(&9O<FUA="X@($ET(&1E<&5N9',@;VX@80H@*B!S
M970@;V8@34E-15]6:65W97)?*B!D<FEV97)S('=H:6-H(&AA;F1L92!T:&4@
M86-T=6%L(')E;F1E<FEN9RP*("H@86YD(&%L<V\@82!C;VYF:6=U<F%T:6]N
M(&9I;&4@=&\@;6%P($U)344@='EP97,@=&\@9')I=F5R<RX*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<BYP:'`L=B`Q+C8T+C$P
M+C$P(#(P,#8O,#4O,#4@,#,Z,S`Z,C,@<VQU<V%R>B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,3DY.2TR,#`V($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E
M8V]I;"YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!!;FEL($UA
M9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`<VEN8V4@("!(;W)D
M92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO"F-L87-S
M($U)345?5FEE=V5R('L*"B`@("`O*BH*("`@("`J(%1H92!-24U%7U!A<G0@
M;V)J96-T('1O(')E;F1E<BX*("`@("`J"B`@("`@*B!`=F%R($U)345?4&%R
M=`H@("`@("HO"B`@("!V87(@)&UI;65?<&%R=#L*"B`@("`O*BH*("`@("`J
M($-O;F9I9W5R871I;VX@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V-O;F8@/2!A<G)A>2@I.PH*("`@
M("\J*@H@("`@("H@9V5T1')I=F5R(&-A8VAE+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?9')I=F5R0V%C:&4@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@1F]R8V4@=FEE=VEN9R!O9B!A('!A<G0@
M:6YL:6YE+"!R96=A<F1L97-S(&]F('1H92!#;VYT96YT+41I<W!O<VET:6]N
M"B`@("`@*B!O9B!T:&4@34E-12!087)T+@H@("`@("H*("`@("`J($!V87(@
M8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]F;W)C96EN;&EN92`](&9A;'-E
M.PH*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E
M=&4@34E-15]6:65W97)?*B!O8FIE8W0@8F%S960@;VX@=&AE"B`@("`@*B!T
M>7!E(&]F($U)345?4&%R="!P87-S960@;VYT;R!I="X*("`@("`J"B`@("`@
M*B!`<&%R86T@34E-15]087)T("8D;6EM95]P87)T("!2969E<F5N8V4@=&\@
M82!-24U%7U!A<G0@;V)J96-T('=I=&@@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I;F9O<FUA=&EO;B!T;R!B92!R96YD97)E
M9"X*("`@("`J($!P87)A;2!S=')I;F<@)&UI;65?='EP92`@("`@(%5S92!T
M:&ES($U)344@='EP92!I;G-T96%D(&]F('1H92!T>7!E"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!S=&]R960@:6X@=&AE("1M:6UE
M7W!A<G0N"B`@("`@*@H@("`@("H@0')E='5R;B!-24U%7U9I97=E<B`@5&AE
M($U)345?5FEE=V5R(&]B:F5C="P@;W(@9F%L<V4@;VX@97)R;W(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"8D;6EM95]P87)T+"`D;6EM95]T
M>7!E(#T@;G5L;"D*("`@('L*("`@("`@("`O*B!#:&5C:R!T:&%T('=E(&AA
M=F4@82!V86QI9"!-24U%7U!A<G0@;V)J96-T("HO"B`@("`@("`@:68@*"%I
M<U]A*"1M:6UE7W!A<G0L("=-24U%7U!A<G0G*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!$971E<FUI;F4@
M9')I=F5R('1Y<&4@9G)O;2!T:&4@34E-12!T>7!E("HO"B`@("`@("`@:68@
M*&5M<'1Y*"1M:6UE7W1Y<&4I*2!["B`@("`@("`@("`@("1M:6UE7W1Y<&4@
M/2`D;6EM95]P87)T+3YG9714>7!E*"D["B`@("`@("`@("`@(&EF("AE;7!T
M>2@D;6EM95]T>7!E*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=FEE=V5R(#T@
M9F%L<V4["@H@("`@("`@("\J(%-P87=N('1H92!R96QE=F%N="!D<FEV97(L
M(&%N9"!R971U<FX@:70@*&]R(&9A;'-E(&]N(&9A:6QU<F4I("HO"B`@("`@
M("`@:68@*"@D;V(@/2!-24U%7U9I97=E<CHZ:6YC;'5D941R:79E<B@D;6EM
M95]T>7!E*2DI('L*("`@("`@("`@("`@)&-L87-S(#T@*"@D;V(M/FUO9'5L
M92`]/2`G:&]R9&4G*2`_("<G(#H@)&]B+3YM;V1U;&4@+B`G7R<I("X@)TU)
M345?5FEE=V5R7R<@+B`D;V(M/F1R:79E<CL*("`@("`@("`@("`@:68@*&-L
M87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("`@("`D=FEE=V5R
M(#T@)FYE=R`D8VQA<W,H)&UI;65?<&%R="P@)$=,3T)!3%-;)VUI;65?9')I
M=F5R<R==6R1O8BT^;6]D=6QE75LD;V(M/F1R:79E<ETI.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'9I97=E<CL*("`@('T*
M"B`@("`O*BH*("`@("`J($EN8VQU9&4@=&AE(&-O9&4@9F]R('1H92!R96QE
M=F%N="!D<FEV97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6EM
M95]T>7!E("!4:&4@0V]N=&5N="UT>7!E(&]F('1H92!P87)T('1O(&)E(')E
M;F1E<F5D+@H@("`@("H*("`@("`J($!R971U<FX@<W1D0VQA<W,@(%-E92!-
M24U%7T1R:79E<CHZ9V5T1')I=F5R*"DN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&EN8VQU9&5$<FEV97(H)&UI;65?='EP92D*("`@('L*("`@("`@("`O+R!4
M3T1/.B!"0R`M('-W:71C:"!T;R!R97%U:7)E7V]N8V4@9F]R($AO<F1E(#0N
M,#L@9&]N)W0@;F5E9"`D8V]N9FEG.PH@("`@("`@("\O("`@("`@(&1O;B=T
M(&YE960@=&\@;6%K92!S=7)E('1H92`R('9A<FEA8FQE<R!A<F4@=6YS970N
M"B`@("`@("`@<W1A=&EC("1C;VYF:6<@/2!F86QS93L*("`@("`@("!G;&]B
M86P@)')E9VES=')Y.PH*("`@("`@("`D87!P(#T@)')E9VES=')Y+3YG971!
M<'`H*3L*"B`@("`@("`@:68@*"$D8V]N9FEG*2!["B`@("`@("`@("`@("1'
M3$]"04Q36R=M:6UE7V1R:79E<G,G72`]("1'3$]"04Q36R=M:6UE7V1R:79E
M<G-?;6%P)UT@/2!A<G)A>2@I.PH@("`@("`@("`@("!R97%U:7)E("1R96=I
M<W1R>2T^9V5T*"=F:6QE<F]O="<L("=H;W)D92<I("X@)R]C;VYF:6<O;6EM
M95]D<FEV97)S+G!H<"<["B`@("`@("`@("`@(&EF("@D87!P("$]("=H;W)D
M92<I('L*("`@("`@("`@("`@("`@("1B87-E(#T@)')E9VES=')Y+3YG970H
M)V9I;&5R;V]T)RP@)&%P<"D["B`@("`@("`@("`@("`@("!I9B`H:7-?<F5A
M9&%B;&4H)&)A<V4@+B`G+V-O;F9I9R]M:6UE7V1R:79E<G,N<&AP)RDI('L*
M("`@("`@("`@("`@("`@("`@("!R97%U:7)E("1B87-E("X@)R]C;VYF:6<O
M;6EM95]D<FEV97)S+G!H<"<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)$=,3T)!3%-;)VUI;65?9')I=F5R<R==(#T@
M)&UI;65?9')I=F5R<SL*("`@("`@("`@("`@)$=,3T)!3%-;)VUI;65?9')I
M=F5R<U]M87`G72`]("1M:6UE7V1R:79E<G-?;6%P.PH@("`@("`@("`@("`D
M8V]N9FEG(#T@=')U93L*("`@("`@("!]"@H@("`@("`@("\J($9I9W5R92!T
M:&4@8V]R<F5C="!D<FEV97(@9F]R('1H:7,@34E-12!T>7!E+B!)9B!T:&5R
M92!I<R!N;PH@("`@("`@("`@(&%P<&QI8V%T:6]N+7-P96-I9FEC(&UO9'5L
M92P@82!G96YE<F%L($AO<F1E(&]N92!W:6QL(&%T=&5M<'0@=&\*("`@("`@
M("`@("!B92!U<V5D+B`J+PH@("`@("`@(&EF("@H)&]B(#T@34E-15]6:65W
M97(Z.F=E=$1R:79E<B@D;6EM95]T>7!E+"`D<F5G:7-T<GDM/F=E=$%P<"@I
M*2DI('L*("`@("`@("`@("`@+RH@26YC;'5D92!T:&4@8VQA<W,N("HO"B`@
M("`@("`@("`@(')E<75I<F5?;VYC92!-24U%7U9I97=E<CHZ<F5S;VQV941R
M:79E<B@D;V(M/F1R:79E<BP@)&]B+3YM;V1U;&4I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1O8CL*("`@('T*"B`@("`O*BH*("`@("`J($-O;G-T
M<G5C=&]R(&9O<B!-24U%7U9I97=E<@H@("`@("H*("`@("`J($!P87)A;2!-
M24U%7U!A<G0@)B1M:6UE7W!A<G0@(%)E9F5R96YC92!T;R!A($U)345?4&%R
M="!O8FIE8W0@=VET:"!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EN9F]R;6%T:6]N('1O(&)E(')E;F1E<F5D+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!-24U%7U9I97=E<B@F)&UI;65?<&%R="P@)&-O;F8@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3YM:6UE7W!A<G0@/2`F
M)&UI;65?<&%R=#L*("`@("`@("`D=&AI<RT^7V-O;F8@/2`D8V]N9CL*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE($U)345?4&%R="!O8FIE8W0@
M9F]R('1H92!C;&%S<RX*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T
M("8D;6EM95]P87)T("!2969E<F5N8V4@=&\@82!-24U%7U!A<G0@;V)J96-T
M('=I=&@@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I;F9O<FUA=&EO;B!T;R!B92!R96YD97)E9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T34E-15!A<G0H)B1M:6UE7W!A<G0I"B`@("!["B`@("`@("`@
M)'1H:7,M/FUI;65?<&%R="`]("8D;6EM95]P87)T.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N('1H92!-24U%('1Y<&4@;V8@=&AE(')E;F1E<F5D
M(&-O;G1E;G0N("!4:&ES(&-A;B!B90H@("`@("H@;W9E<G)I9&1E;B!B>2!T
M:&4@:6YD:79I9'5A;"!D<FEV97)S+"!D97!E;F1I;F<@;VX@=VAA="!F;W)M
M870*("`@("`J('1H97D@;W5T<'5T(&EN+B!">2!D969A=6QT+"!I="!P87-S
M97,@=&AR;W5G:"!T:&4@34E-12!T>7!E(&]F"B`@("`@*B!T:&4@;V)J96-T
M+"!O<B!R97!L86-E<R!C=7-T;VT@97AT96YS:6]N('1Y<&5S('=I=&@*("`@
M("`J("=T97AT+W!L86EN)R!T;R!L970@=&AE(&)R;W=S97(@9&\@82!B97-T
M+6=U97-S(')E;F1E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M34E-12UT>7!E(&]F('1H92!O=71P=70@8V]N=&5N="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YM
M:6UE7W!A<G0M/F=E=%!R:6UA<GE4>7!E*"D@/3T@)W@M97AT96YS:6]N)RD@
M>PH@("`@("`@("`@("!R971U<FX@)W1E>'0O<&QA:6XG.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;6EM95]P87)T+3YG
M9714>7!E*'1R=64I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;B!T:&4@<F5N9&5R960@=F5R<VEO;B!O9B!T:&4@;V)J96-T+@H@
M("`@("H*("`@("`J(%-H;W5L9"!B92!O=F5R<FED9&5N(&)Y(&EN9&EV:61U
M86P@9')I=F5R<R!T;R!P97)F;W)M(&-U<W1O;2!T87-K<RX*("`@("`J(%1H
M92`D;6EM95]P87)T(&-L87-S('9A<FEA8FQE(&AA<R!T:&4@:6YF;W)M871I
M;VX@=&\@<F5N9&5R+`H@("`@("H@96YC87!S=6QA=&5D(&EN(&$@34E-15]0
M87)T(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)'!A<F%M
M<R`@06YY(&]P=&EO;F%L('!A<F%M971E<G,@=&AI<R!D<FEV97(@;F5E9',@
M870*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!R=6YT:6UE+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!296YD97)E9"!V97)S:6]N(&]F
M('1H92!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@D<&%R
M86US(#T@;G5L;"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FUI;65?
M<&%R="T^9V5T0V]N=&5N=',H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!T97AT+VAT;6P@;W5T<'5T('5S960@87,@86QT97)N871I=F4@;W5T
M<'5T('=H96X@=&AE(&9U;&QY"B`@("`@*B!R96YD97)E9"!O8FIE8W0@8V%N
M;F]T("AO<B!S:&]U;&0@;F]T*2!B92!D:7-P;&%Y960N("!&;W(@97AA;7!L
M92P*("`@("`J('1H:7,@9G5N8W1I;VX@<VAO=6QD(&)E('5S960@9F]R($U)
M344@871T86-H;65N=',@=&AA="!C86YN;W0@8F4*("`@("`J('9I97=E9"!I
M;FQI;F4L('=H97)E('1H92!U<V5R(&UA>2!B92!G:79E;B!O<'1I;VYS(&]N
M(&AO=R!T;R!V:65W"B`@("`@*B!T:&4@871T86-H;65N="X*("`@("`J(%-H
M;W5L9"!B92!O=F5R<FED9&5N(&)Y(&EN9&EV:61U86P@9')I=F5R<R!T;R!P
M97)F;W)M(&-U<W1O;2!T87-K<RX*("`@("`J(%1H92`D;6EM95]P87)T(&-L
M87-S('9A<FEA8FQE(&AA<R!T:&4@:6YF;W)M871I;VX@=&\@<F5N9&5R+`H@
M("`@("H@96YC87!S=6QA=&5D(&EN(&$@34E-15]087)T(&]B:F5C="X*("`@
M("`J"B`@("`@*B!`<&%R86T@;6EX960@)'!A<F%M<R`@06YY(&]P=&EO;F%L
M('!A<F%M971E<G,@=&AI<R!D<FEV97(@;F5E9',@870*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!R=6YT:6UE+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!497AT+VAT;6P@<F5N9&5R960@:6YF;W)M871I;VXN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<D%T=&%C:&UE;G1);F9O*"D*("`@
M('L*("`@('T*"B`@("`O*BH*("`@("`J($-A;B!T:&ES(&1R:79E<B!R96YD
M97(@=&AE('1H92!D871A(&EN;&EN93\*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%1R=64@:68@=&AE(&1R:79E<B!C86X@9&ES<&QA>2!I;FQI
M;F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-A;D1I<W!L87E);FQI;F4H*0H@
M("`@>PH@("`@("`@(&EF("@D=&AI<RT^9V5T0V]N9FEG4&%R86TH)VEN;&EN
M92<I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!':79E;B!A(&1R:79E<B!A;F0@86X@87!P;&EC
M871I;VXL('1H:7,@<F5T=7)N<R!T:&4@9G5L;'D*("`@("`J('%U86QI9FEE
M9"!F:6QE<WES=&5M('!A=&@@=&\@=&AE(&1R:79E<B!S;W5R8V4@9FEL92X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D<FEV97(@($1R:79E<B!N
M86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P("`@("!!<'!L:6-A=&EO
M;B!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!&:6QE<WES
M=&5M('!A=&@@;V8@=&AE(&1R:79E<B]A<'!L:6-A=&EO;B!Q=65R:65D+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!R97-O;'9E1')I=F5R*"1D<FEV97(@/2`G
M9&5F875L="<L("1A<'`@/2`G:&]R9&4G*0H@("`@>PH@("`@("`@(&EF("@D
M87!P(#T]("=H;W)D92<I('L*("`@("`@("`@("`@<F5T=7)N(&1I<FYA;64H
M7U]&24Q%7U\I("X@)R]6:65W97(O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q36R=R
M96=I<W1R>2==+3YA<'!L:6-A=&EO;G-;)&%P<%U;)V9I;&5R;V]T)UT@+B`G
M+VQI8B]-24U%+U9I97=E<B\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!':79E;B!A;B!I;G!U="!-24U%
M('1Y<&4@86YD(&$@;6]D=6QE(&YA;64L('1H:7,@9G5N8W1I;VX*("`@("`J
M(')E<V]L=F5S(&ET(&EN=&\@82!S<&5C:69I8R!O=71P=70@9')I=F5R('=H
M:6-H(&-A;B!H86YD;&4@:70N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;6EM951Y<&4@($U)344@='EP92!T;R!R97-O;'9E+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;6]D=6QE("`@($UO9'5L92!I;B!W:&EC:"!T;R!S96%R
M8V@@9F]R('1H92!D<FEV97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=&1#
M;&%S<R`@3V)J96-T('=I=&@@=&AE(&9O;&QO=VEN9R!I=&5M<SH*("`@("`J
M(#QP<F4^"B`@("`@*B`G9')I=F5R)R`@+2T@($YA;64@;V8@9')I=F5R("AE
M+F<N("=E;G-C<FEP="<I"B`@("`@*B`G97AA8W0G("`@+2T@(%=A<R!T:&4@
M9')I=F5R(&%N9"!E>&%C="!M871C:#\@*'1R=64O9F%L<V4I"B`@("`@*B`G
M;6]D=6QE)R`@+2T@(%1H92!M;V1U;&4@8V]N=&%I;FEN9R!D<FEV97(@*&4N
M9RX@)VAO<F1E)RD*("`@("`J(#PO<')E/@H@("`@("H@4F5T=7)N<R!F86QS
M92!I9B!D<FEV97(@8V]U;&0@;F]T(&)E(&9O=6YD+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971$<FEV97(H)&UI;654>7!E+"`D;6]D=6QE(#T@)VAO<F1E
M)RD*("`@('L*("`@("`@("!G;&]B86P@)&UI;65?9')I=F5R<RP@)&UI;65?
M9')I=F5R<U]M87`["@H@("`@("`@("1C86-H94YA;64@/2`D;6EM951Y<&4@
M+B`G?"<@+B`D;6]D=6QE.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RD@)B8@
M:7-S970H)'1H:7,M/E]D<FEV97)#86-H95LD8V%C:&5.86UE72DI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9')I=F5R0V%C:&5;)&-A8VAE3F%M
M95T["B`@("`@("`@?0H*("`@("`@("`D9')I=F5R(#T@)R<["B`@("`@("`@
M)&5X86-T1')I=F5R(#T@9F%L<V4["@H@("`@("`@(&QI<W0H)'!R:6UA<GE?
M='EP92P@*2`](&5X<&QO9&4H)R\G+"`D;6EM951Y<&4L(#(I.PH@("`@("`@
M("1A;&Q3=6(@/2`D<')I;6%R>5]T>7!E("X@)R\J)SL*"B`@("`@("`@+RH@
M268@=&AE(&UO9'5L92!D;V5S;B=T(&5X:7-T(&EN("1M:6UE7V1R:79E<G-?
M;6%P+"!C:&5C:R!F;W(*("`@("`@("`@("!(;W)D92!V:65W97)S+B`J+PH@
M("`@("`@(&EF("@A:7-S970H)&UI;65?9')I=F5R<U]M87!;)&UO9'5L95TI
M("8F("1M;V1U;&4@(3T@)VAO<F1E)RD@>PH@("`@("`@("`@("!R971U<FX@
M34E-15]6:65W97(Z.F=E=$1R:79E<B@D;6EM951Y<&4L("=H;W)D92<I.PH@
M("`@("`@('T*"B`@("`@("`@)&1R(#T@)B1M:6UE7V1R:79E<G-;)&UO9'5L
M95T["B`@("`@("`@)&UA<"`]("8D;6EM95]D<FEV97)S7VUA<%LD;6]D=6QE
M73L*"B`@("`@("`@+RH@268@86X@;W9E<G)I9&4@97AI<W1S(&9O<B!T:&ES
M($U)344@='EP92P@=&AE;B!U<V4@=&AA="`J+PH@("`@("`@(&EF("AI<W-E
M="@D;6%P6R=O=F5R<FED97,G75LD;6EM951Y<&5=*2D@>PH@("`@("`@("`@
M("`D9')I=F5R(#T@)&UA<%LG;W9E<G)I9&5S)UU;)&UI;654>7!E73L*("`@
M("`@("`@("`@)&5X86-T1')I=F5R(#T@=')U93L*("`@("`@("!](&5L<V5I
M9B`H:7-S970H)&UA<%LG;W9E<G)I9&5S)UU;)&%L;%-U8ETI*2!["B`@("`@
M("`@("`@("1D<FEV97(@/2`D;6%P6R=O=F5R<FED97,G75LD86QL4W5B73L*
M("`@("`@("`@("`@)&5X86-T1')I=F5R(#T@=')U93L*("`@("`@("!](&5L
M<V5I9B`H:7-S970H)&UA<%LG<F5G:7-T97)E9"==*2D@>PH@("`@("`@("`@
M("`O*B!)=&5R871E('1H<F]U9V@@=&AE(&QI<W0@;V8@<F5G:7-T97)E9"!D
M<FEV97)S+"!A;F0@<V5E(&EF"B`@("`@("`@("`@("`@('1H:7,@34E-12!T
M>7!E(&5X:7-T<R!I;B!T:&4@34E-12!T>7!E<R!T:&%T('1H97D@8VQA:6T@
M=&\*("`@("`@("`@("`@("`@:&%N9&QE+B!)9B!T:&4@9')I=F5R(&AA;F1L
M97,@:70L('1H96X@87-S:6=N(&ET(&%S('1H90H@("`@("`@("`@("`@("!R
M96YD97)I;F<@9')I=F5R+B!)9B!W92!F:6YD(&$@9V5N97)I8R!H86YD;&5R
M+"!K965P(&ET97)A=&EN9PH@("`@("`@("`@("`@("!T;R!S964@:68@=V4@
M8V%N(&9I;F0@82!S<&5C:69I8R!H86YD;&5R+B`J+PH@("`@("`@("`@("!F
M;W)E86-H("@D;6%P6R=R96=I<W1E<F5D)UT@87,@)'9A;"D@>PH@("`@("`@
M("`@("`@("`@:68@*&EN7V%R<F%Y*"1M:6UE5'EP92P@)&1R6R1V86Q=6R=H
M86YD;&5S)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&1R:79E<B`]("1V
M86P["B`@("`@("`@("`@("`@("`@("`@)&5X86-T1')I=F5R(#T@=')U93L*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T@
M96QS96EF("AI;E]A<G)A>2@D86QL4W5B+"`D9');)'9A;%U;)VAA;F1L97,G
M72DI('L*("`@("`@("`@("`@("`@("`@("`D9')I=F5R(#T@)'9A;#L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@+RH@268@=&AI<R!I<R!A;B!A<'!L:6-A=&EO;B!S<&5C:69I8R!M;V1U
M;&4L(&%N9"!A;B!E>&%C="!M871C:"!W87,*("`@("`@("`@("!N;W0@9F]U
M;F0L('-E87)C:"!F;W(@82!(;W)D92UW:61E('-P96-I9FEC(&1R:79E<BX@
M3VYL>2!U<V4@=&AE"B`@("`@("`@("`@2&]R9&4M<W!E8VEF:6,@9')I=F5R
M(&EF(&ET(&ES($Y/5"!T:&4@)V1E9F%U;'0G(&1R:79E<B!!3D0@=&AE"B`@
M("`@("`@("`@2&]R9&4@9')I=F5R(&ES(&%N(&5X86-T(&UA=&-H+B`J+PH@
M("`@("`@(&EF("@A)&5X86-T1')I=F5R("8F("1M;V1U;&4@(3T@)VAO<F1E
M)RD@>PH@("`@("`@("`@("`D;V(@/2!-24U%7U9I97=E<CHZ9V5T1')I=F5R
M*"1M:6UE5'EP92P@)VAO<F1E)RD["B`@("`@("`@("`@(&EF("AE;7!T>2@D
M9')I=F5R*2!\?`H@("`@("`@("`@("`@("`@*"@D;V(M/F1R:79E<B`A/2`G
M9&5F875L="<I("8F("1O8BT^97AA8W0I*2!["B`@("`@("`@("`@("`@("`D
M9')I=F5R(#T@)&]B+3YD<FEV97(["B`@("`@("`@("`@("`@("`D;6]D=6QE
M(#T@)VAO<F1E)SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M+RH@268@=&AE("=D969A=6QT)R!D<FEV97(@97AI<W1S(&EN('1H:7,@;6]D
M=6QE+"!F86QL(&)A8VL@=&\@=&AA="X@*B\*("`@("`@("!I9B`H96UP='DH
M)&1R:79E<BD@)B8*("`@("`@("`@("`@0&ES7V9I;&4H34E-15]6:65W97(Z
M.G)E<V]L=F5$<FEV97(H)V1E9F%U;'0G+"`D;6]D=6QE*2DI('L*("`@("`@
M("`@("`@)&1R:79E<B`]("=D969A=6QT)SL*("`@("`@("!]"@H@("`@("`@
M(&EF("AE;7!T>2@D9')I=F5R*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V1R
M:79E<D-A8VAE6R1C86-H94YA;65=(#T@9F%L<V4["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;V(@
M/2!N97<@<W1D0VQA<W,["B`@("`@("`@("`@("1O8BT^9')I=F5R(#T@)&1R
M:79E<CL*("`@("`@("`@("`@)&]B+3YE>&%C="`@/2`D97AA8W1$<FEV97([
M"B`@("`@("`@("`@("1O8BT^;6]D=6QE(#T@)&UO9'5L93L*("`@("`@("`@
M("`@:68@*&ES<V5T*"1T:&ES*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]D<FEV97)#86-H95LD8V%C:&5.86UE72`]("1O8CL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!R971U<FX@)&]B.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($=I=F5N(&$@34E-12!T>7!E+"!T:&ES(&9U;F-T:6]N
M('=I;&P@<F5T=7)N(&%N(&%P<')O<')I871E"B`@("`@*B!I8V]N+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&UI;654>7!E("!4:&4@34E-12!T
M>7!E('1H870@=V4@;F5E9"!A;B!I8V]N(&9O<BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(%523"!T;R!T:&4@87!P<F]P<FEA=&4@:6-O
M;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T26-O;B@D;6EM951Y<&4I"B`@
M("!["B`@("`@("`@)&%P<"`]("1'3$]"04Q36R=R96=I<W1R>2==+3YG971!
M<'`H*3L*("`@("`@("`D;V(@/2!-24U%7U9I97=E<CHZ7V=E=$EC;VXH)&UI
M;654>7!E+"`D87!P*3L*"B`@("`@("`@:68@*"1O8B`]/3T@;G5L;"D@>PH@
M("`@("`@("`@("!I9B`H)&%P<"`A/2`G:&]R9&4G*2!["B`@("`@("`@("`@
M("`@("`D;V)(;W)D92`]($U)345?5FEE=V5R.CI?9V5T26-O;B@D;6EM951Y
M<&4L("=H;W)D92<I.PH@("`@("`@("`@("`@("`@<F5T=7)N("@D;V)(;W)D
M92`]/3T@;G5L;"D@/R!N=6QL(#H@)&]B2&]R9&4M/G5R;#L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*"@D;V(M/FUA=&-H("$]/2`P
M*2`F)B`H)&%P<"`A/2`G:&]R9&4G*2D@>PH@("`@("`@("`@("`D;V)(;W)D
M92`]($U)345?5FEE=V5R.CI?9V5T26-O;B@D;6EM951Y<&4L("=H;W)D92<I
M.PH@("`@("`@("`@("!I9B`H)&]B+3YM871C:"`A/3T@;G5L;"`F)B`D;V(M
M/FUA=&-H(#P]("1O8DAO<F1E+3YM871C:"D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1O8BT^=7)L.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1O8DAO<F1E+3YU<FP["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)&]B+3YU<FP[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1VEV96X@86X@:6YP
M=70@34E-12!T>7!E(&%N9"!M;V1U;&4L('1H:7,@9G5N8W1I;VX@<F5T=7)N
M<R!T:&4*("`@("`J(%523"!O9B!A;B!I8V]N('1H870@8V%N(&)E(&%S<V]C
M:6%T960@=VET:"!I=`H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UI;654>7!E("!-24U%('1Y
M<&4@=&\@9V5T('1H92!I8V]N(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T9$-L87-S("!U<FPZ("`@55),('1O(&%N(&EC;VXL(&]R(&YU;&P@:68@
M;F]N90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&-O=6QD(&)E
M(&9O=6YD+@H@("`@("H@("`@("`@("`@("`@("`@("`@97AA8W0Z($AO=R!E
M>&%C="!T:&4@;6%T8V@@:7,N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@,"`]/B`G97AA8W0G+"`Q(#T^("=P<FEM87)Y)RP*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`R(#T^("=D<FEV97(G+"`S(#T^("=D
M969A=6QT)PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&]R(&YU
M;&PN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971)8V]N*"1M:6UE5'EP92P@
M)&UO9'5L92`]("=H;W)D92<I"B`@("!["B`@("`@("`@9VQO8F%L("1M:6UE
M7V1R:79E<G,["@H@("`@("`@("1O8B`]($U)345?5FEE=V5R.CIG971$<FEV
M97(H)&UI;654>7!E+"`D;6]D=6QE*3L*("`@("`@("!I9B`H(6ES7V]B:F5C
M="@D;V(I*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2AF86QS92P@;G5L
M;"D["B`@("`@("`@?0H@("`@("`@("1D<FEV97(@/2`D;V(M/F1R:79E<CL*
M"B`@("`@("`@;&ES="@D<')I;6%R>5]T>7!E+"D@/2!E>'!L;V1E*"<O)RP@
M)&UI;654>7!E+"`R*3L*("`@("`@("`D86QL4W5B(#T@)'!R:6UA<GE?='EP
M92`N("<O*B<["B`@("`@("`@)')E=$]B(#T@)FYE=R!S=&1#;&%S<R@I.PH@
M("`@("`@("1R971/8BT^;6%T8V@@/2!N=6QL.PH@("`@("`@("1R971/8BT^
M=7)L(#T@;G5L;#L*"B`@("`@("`@+RH@268@=&AE(&UO9'5L92!D;V5S;B=T
M(&5X:7-T(&EN("1M:6UE7V1R:79E<G,L(')E='5R;B!N;W<N("HO"B`@("`@
M("`@:68@*"%I<W-E="@D;6EM95]D<FEV97)S6R1M;V1U;&5=*2D@>PH@("`@
M("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@("`@)&1R(#T@
M)B1M:6UE7V1R:79E<G-;)&UO9'5L95T["@H@("`@("`@("\J($EF(&$@<W!E
M8VEF:6,@:6-O;B!F;W(@=&AI<R!D<FEV97(@86YD(&UI;65T>7!E(&ES(&1E
M9FEN960L"B`@("`@("`@("`@=&AE;B!U<V4@=&AA="X@*B\*("`@("`@("!I
M9B`H:7-S970H)&1R6R1D<FEV97)=6R=I8V]N<R==*2D@>PH@("`@("`@("`@
M("`D:6-O;F1R(#T@)B1M:6UE7V1R:79E<G-;)&UO9'5L95U;)&1R:79E<EU;
M)VEC;VYS)UT["B`@("`@("`@("`@("1I8V]N3&ES="`](&%R<F%Y*"1M:6UE
M5'EP92`]/B`P+"`D86QL4W5B(#T^(#$L("=D969A=6QT)R`]/B`R*3L*("`@
M("`@("`@("`@9F]R96%C:"`H)&EC;VY,:7-T(&%S("1K97D@/3X@)'9A;"D@
M>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I8V]N9');)&ME>5TI*2![
M"B`@("`@("`@("`@("`@("`@("`@)')E=$]B+3YU<FP@/2`D:6-O;F1R6R1K
M97E=.PH@("`@("`@("`@("`@("`@("`@("1R971/8BT^;6%T8V@@/2`D=F%L
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!4<GD@=&\@
M=7-E(&$@9&5F875L="!I8V]N(&EF(&YO;F4@86QR96%D>2!O8G1A:6YE9"X@
M*B\*("`@("`@("!I9B`H:7-?;G5L;"@D<F5T3V(M/G5R;"D@)B8@:7-S970H
M)&1R6R=D969A=6QT)UTI*2!["B`@("`@("`@("`@("1D<B`]("8D;6EM95]D
M<FEV97)S6R1M;V1U;&5=6R=D969A=6QT)UT["B`@("`@("`@("`@(&EF("AI
M<W-E="@D9');)VEC;VYS)UU;)V1E9F%U;'0G72DI('L*("`@("`@("`@("`@
M("`@("1R971/8BT^=7)L(#T@)&1R6R=D969A=6QT)UU;)VEC;VYS)UU;)V1E
M9F%U;'0G73L*("`@("`@("`@("`@("`@("1R971/8BT^;6%T8V@@/2`S.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES7VYU;&PH
M)')E=$]B+3YU<FPI*2!["B`@("`@("`@("`@("1R971/8BT^=7)L(#T@)$=,
M3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER*"1M;V1U;&4I("X@)R]M
M:6UE+R<@+B`D<F5T3V(M/G5R;#L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D<F5T3V(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C
M:&%R86-T97(@<V5T('5S960@9F]R('1H92!6:65W97(N"B`@("`@*B!3:&]U
M;&0@8F4@;W9E<G)I9&1E;B!B>2!I;F1I=FED=6%L(&1R:79E<G,@=&\@<&5R
M9F]R;2!C=7-T;VT@=&%S:W,N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!C:&%R86-T97(@<V5T('5S960@8GD@=&AI<R!6:65W97(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$-H87)S970H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^;6EM95]P87)T+3YG971#:&%R<V5T*"D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@82!C;VYF:6=U<F%T:6]N('!A<F%M
M971E<B!F;W(@=&AE(&-U<G)E;G0@=FEE=V5R+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'!A<F%M("!4:&4@<&%R86UE=&5R(&YA;64N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE('9A;'5E(&]F('1H92!P87)A
M;65T97([(')E='5R;G,@;G5L;"!I9B!T:&4@<&%R86UE=&5R"B`@("`@*B`@
M("`@("`@("`@("`@("!D;V5S;B=T(&5X:7-T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971#;VYF:6=087)A;2@D<&%R86TI"B`@("!["B`@("`@("`@<F5T
M=7)N("AI<W-E="@D=&AI<RT^7V-O;F9;)'!A<F%M72DI(#\@)'1H:7,M/E]C
M;VYF6R1P87)A;5T@.B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@4VAO
M=6QD('=E(&9O<F-E('9I97=I;F<@;V8@=&AI<R!-24U%(%!A<G0@:6YL:6YE
M+"!R96=A<F1L97-S(&]F('1H90H@("`@("H@0V]N=&5N="U$:7-P;W-I=&EO
M;B!O9B!T:&4@34E-12!087)T/PH@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@1F]R8V4@=FEE=VEN9R!I;FQI;F4_"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&9O<F-E26YL:6YE5FEE=R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?9F]R8V5I;FQI;F4["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12YP:'``````````````````````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#8W,38V`#$P-3$U-#,S-S4R`#`R
M,#<T-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`H*+RH@5V4@;F5E9"!T;R`H=6YF;W)T=6YA=&5L>2D@:&%R9"!C
M;V1E('1H97-E(&-O;G-T86YT<R!B96-A=7-E('1H97D@<F5S:61E(&EN"B`J
M('1H92!I;6%P(&UO9'5L92P@=VAI8V@@:7,@;F]T(')E<75I<F5D(&9O<B!(
M;W)D92X*("H@5&AE<V4@8V]N<W1A;G1S(&%R92!F;W5N9"!I;B!T:&4@55<M
M:6UA<"!C+6-L:65N="!D:7-T<FEB=71I;VXZ"B`J("`@9G1P.B\O9G1P+F-A
M8RYW87-H:6YG=&]N+F5D=2]I;6%P+PH@*B!4:&4@8V]N<W1A;G1S(&%P<&5A
M<B!I;B!T:&4@9FEL92!I;F-L=61E+VUA:6PN:"`J+PIR97%U:7)E7V]N8V4@
M)TAO<F1E+U5T:6PN<&AP)SL*:68@*"%5=&EL.CIE>'1E;G-I;VY%>&ES=',H
M)VEM87`G*2D@>PH@("`@+RH@4')I;6%R>2!B;V1Y('1Y<&5S("HO"B`@("!D
M969I;F4H)U194$5415A4)RP@,"D["B`@("!D969I;F4H)U194$5-54Q425!!
M4E0G+"`Q*3L*("`@(&1E9FEN92@G5%E014U%4U-!1T4G+"`R*3L*("`@(&1E
M9FEN92@G5%E014%04$Q)0T%424].)RP@,RD["B`@("!D969I;F4H)U194$5!
M541)3R<L(#0I.PH@("`@9&5F:6YE*"=465!%24U!1T4G+"`U*3L*("`@(&1E
M9FEN92@G5%E0159)1$5/)RP@-BD["B`@("!D969I;F4H)U194$5/5$A%4B<L
M(#@I.PH*("`@("\J($)O9'D@96YC;V1I;F=S("HO"B`@("!D969I;F4H)T5.
M0S="250G+"`P*3L*("`@(&1E9FEN92@G14Y#.$))5"<L(#$I.PH@("`@9&5F
M:6YE*"=%3D-"24Y!4EDG+"`R*3L*("`@(&1E9FEN92@G14Y#0D%3138T)RP@
M,RD["B`@("!D969I;F4H)T5.0U%53U1%1%!224Y404),12<L(#0I.PH@("`@
M9&5F:6YE*"=%3D-/5$A%4B<L(#4I.PI]"@HO*BH*("H@3VQD97(@=F5R<VEO
M;G,@;V8@4$A0)W,@:6UA<"!E>'1E;G-I;VX@9&]N)W0@9&5F:6YE(%194$5-
M3T1%3"X*("HO"FEF("@A9&5F:6YE9"@G5%E014U/1$5,)RDI('L*("`@(&1E
M9FEN92@G5%E014U/1$5,)RP@-RD["GT*"B\J*@H@*B!2971U<FX@82!C;V1E
M(&9O<B!T>7!E*"DO96YC;V1I;F<H*2X*("HO"F1E9FEN92@G34E-15]#3T1%
M)RP@,2D["@HO*BH*("H@4F5T=7)N(&$@<W1R:6YG(&9O<B!T>7!E*"DO96YC
M;V1I;F<H*2X*("HO"F1E9FEN92@G34E-15]35%))3D<G+"`R*3L*"@HO*BH*
M("H@5&AE($U)344Z.B!C;&%S<R!P<F]V:61E<R!M971H;V1S(&9O<B!D96%L
M:6YG('=I=&@@34E-12!S=&%N9&%R9',N"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+TU)344O34E-12YP:'`L=B`Q+C$S.2XT+C(P(#(P,#8O,#,O,C0@,#0Z
M,CDZ-3(@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?
M34E-10H@*B\*8VQA<W,@34E-12!["@H@("`@+RHJ"B`@("`@*B!!(&QI<W1I
M;F<@;V8@=&AE(&%L;&]W960@34E-12!T>7!E<RX*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D;6EM95]T>7!E<R`](&%R<F%Y
M*`H@("`@("`@(%194$5415A4(#T^("=T97AT)RP*("`@("`@("!465!%355,
M5$E005)4(#T^("=M=6QT:7!A<G0G+`H@("`@("`@(%194$5-15-304=%(#T^
M("=M97-S86=E)RP*("`@("`@("!465!%05!03$E#051)3TX@/3X@)V%P<&QI
M8V%T:6]N)RP*("`@("`@("!465!%055$24\@/3X@)V%U9&EO)RP*("`@("`@
M("!465!%24U!1T4@/3X@)VEM86=E)RP*("`@("`@("!465!%5DE$14\@/3X@
M)W9I9&5O)RP*("`@("`@("!465!%34]$14P@/3X@)VUO9&5L)RP*("`@("`@
M("!465!%3U1(15(@/3X@)V]T:&5R)PH@("`@*3L*"B`@("`O*BH*("`@("`J
M($$@;&ES=&EN9R!O9B!T:&4@86QL;W=E9"!-24U%(&5N8V]D:6YG<RX*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D;6EM95]E
M;F-O9&EN9W,@/2!A<G)A>2@*("`@("`@("!%3D,W0DE4(#T^("<W8FET)RP*
M("`@("`@("!%3D,X0DE4(#T^("<X8FET)RP*("`@("`@("!%3D-"24Y!4ED@
M/3X@)V)I;F%R>2<L"B`@("`@("`@14Y#0D%3138T(#T^("=B87-E-C0G+`H@
M("`@("`@($5.0U%53U1%1%!224Y404),12`]/B`G<75O=&5D+7!R:6YT86)L
M92<L"B`@("`@("`@14Y#3U1(15(@/3X@)W5N:VYO=VXG"B`@("`I.PH*("`@
M("\J*@H@("`@("H@1FEL=&5R(&9O<B!21D,X,C(N"B`@("`@*@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1R9F,X,C)?9FEL=&5R(#T@
M(B@I/#Y`+#LZ7%Q<(EM=7#%<,EPS7#1<-5PV7#=<,3!<,3%<,3)<,3-<,31<
M,35<,39<,3=<,C!<,C%<,C)<,C-<,C1<,C5<,C9<,C=<,S!<,S%<,S)<,S-<
M,S1<,S5<,S9<,S=<,3<W(CL*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@
M:68@82!S=')I;F<@8V]N=&%I;G,@."UB:70@8VAA<F%C=&5R<RX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=')I;F<@(%1H92!S=')I;F<@=&\@
M8VAE8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF
M(&ET(&1O97,L(&9A;'-E(&EF(&ET(&1O97-N)W0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&ES.&)I="@D<W1R:6YG*0H@("`@>PH@("`@("`@(')E='5R;B`H
M:7-?<W1R:6YG*"1S=')I;F<I("8F('!R96=?;6%T8V@H)R];7'@X,"U<>&9F
M72\G+"`D<W1R:6YG*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%;F-O9&5S
M(&$@<W1R:6YG(&-O;G1A:6YI;F<@;F]N+4%30TE)(&-H87)A8W1E<G,@86-C
M;W)D:6YG('1O(%)&0R`R,#0W+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'1E>'0@("`@(%1H92!T97AT('1O(&5N8V]D92X*("`@("`J($!P87)A
M;2!S=')I;F<@)&-H87)S970@(%1H92!C:&%R86-T97(@<V5T(&]F('1H92!T
M97AT+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=&5X="P@
M96YC;V1E9"!O;FQY(&EF(&ET(&-O;G1A:6YS(&YO;BU!4T-)20H@("`@("H@
M("`@("`@("`@("`@("`@(&-H87)A8W1E<G,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&5N8V]D92@D=&5X="P@)&-H87)S970@/2!N=6QL*0H@("`@>PH@("`@
M("`@("\J(%)E='5R;B!I9B!N;W1H:6YG(&YE961S('1O(&)E(&5N8V]D960N
M("HO"B`@("`@("`@:68@*"%-24U%.CII<SAB:70H)'1E>'0I*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&5X=#L*("`@("`@("!]"@H@("`@("`@(&EF("AI
M<U]N=6QL*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("`D8VAA<G-E="`]($Y,
M4SHZ9V5T0VAA<G-E="@I.PH@("`@("`@('T*"B`@("`@("`@)&-H87)S970@
M/2!3=')I;F<Z.FQO=V5R*"1C:&%R<V5T*3L*("`@("`@("`D;&EN92`]("<G
M.PH*("`@("`@("`O*B!'970@=&AE(&QI<W0@;V8@96QE;65N=',@:6X@=&AE
M('-T<FEN9RX@*B\*("`@("`@("`D<VEZ92`]('!R96=?;6%T8VA?86QL*"<O
M*%M>7'-=*RDH6UQS72HI+R<L("1T97AT+"`D;6%T8VAE<RP@4%)%1U]3151?
M3U)$15(I.PH*("`@("`@("!F;W)E86-H("@D;6%T8VAE<R!A<R`D:V5Y(#T^
M("1V86PI('L*("`@("`@("`@("`@:68@*$U)344Z.FES.&)I="@D=F%L6S%=
M*2D@>PH@("`@("`@("`@("`@("`@:68@*"@H)&ME>2`K(#$I(#P@)'-I>F4I
M("8F"B`@("`@("`@("`@("`@("`@("`@34E-13HZ:7,X8FET*"1M871C:&5S
M6R1K97D@*R`Q75LQ72DI('L*("`@("`@("`@("`@("`@("`@("`D;&EN92`N
M/2!-24U%.CI?96YC;V1E*"1V86Q;,5T@+B`D=F%L6S)=+"`D8VAA<G-E="D@
M+B`G("<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1L:6YE("X]($U)344Z.E]E;F-O9&4H)'9A;%LQ72P@)&-H87)S
M970I("X@)'9A;%LR73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1L:6YE("X]("1V86Q;,5T@+B`D
M=F%L6S)=.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@<G1R:6TH)&QI;F4I.PH@("`@?0H*("`@("\J*@H@("`@("H@26YT97)N
M86P@<F5C=7)S:79E(&9U;F-T:6]N('1O(%)&0R`R,#0W(&5N8V]D92!A('-T
M<FEN9RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@("!4:&4@=&5X="!T;R!E;F-O
M9&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:&%R<V5T("!4:&4@8VAA<F%C
M=&5R('-E="!O9B!T:&4@=&5X="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE('1E>'0L(&5N8V]D960@;VYL>2!I9B!I="!C;VYT86EN<R!N
M;VXM05-#24D*("`@("`J("`@("`@("`@("`@("`@("!C:&%R86-T97)S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?96YC;V1E*"1T97AT+"`D8VAA<G-E="D*
M("`@('L*("`@("`@("`D8VAA<E]L96X@/2!S=')L96XH)&-H87)S970I.PH@
M("`@("`@("1T>'1?;&5N(#T@<W1R;&5N*"1T97AT*2`J(#(["@H@("`@("`@
M("\J(%)&0R`R,#0W(%LR72!S=&%T97,@=&AA="!N;R!E;F-O9&5D('=O<F0@
M8V%N(&)E(&UO<F4@=&AA;B`W-0H@("`@("`@("`@(&-H87)A8W1E<G,@;&]N
M9RX@268@;&]N9V5R+"!Y;W4@;75S="!S<&QI="!T:&4@=V]R9"X@*B\*("`@
M("`@("!I9B`H*"1T>'1?;&5N("L@)&-H87)?;&5N("L@-RD@/B`W-2D@>PH@
M("`@("`@("`@("`D<&]S(#T@:6YT=F%L*"@V."`M("1C:&%R7VQE;BD@+R`R
M*3L*("`@("`@("`@("`@<F5T=7)N($U)344Z.E]E;F-O9&4H<W5B<W1R*"1T
M97AT+"`P+"`D<&]S*2P@)&-H87)S970I("X@)R`G("X@34E-13HZ7V5N8V]D
M92AS=6)S='(H)'1E>'0L("1P;W,I+"`D8VAA<G-E="D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N("<]/R<@+B`D8VAA<G-E="`N("<_
M8C\G("X@=')I;2AB87-E-C1?96YC;V1E*"1T97AT*2D@+B`G/STG.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($5N8V]D97,@82!L:6YE('9I
M82!Q=6]T960M<')I;G1A8FQE(&5N8V]D:6YG+@H@("`@("H@5W)A<',@;&EN
M97,@870@-S8@8VAA<F%C=&5R<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T97AT("!4:&4@=&5X="!T;R!E;F-O9&4N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1E;VP@("!4:&4@14],('-E<75E;F-E('1O('5S92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('%U;W1E9"UP<FEN=&%B;&4@
M96YC;V1E9"!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N('%U;W1E9%!R
M:6YT86)L945N8V]D92@D=&5X="P@)&5O;"D*("`@('L*("`@("`@("`D;W5T
M<'5T(#T@)R<["@H@("`@("`@(&9O<F5A8V@@*'!R96=?<W!L:70H(B]<<C]<
M;B\B+"`D=&5X="D@87,@)&QI;F4I('L*("`@("`@("`@("`@+RH@5V4@;F5E
M9"!T;R!G;R!C:&%R86-T97(@8GD@8VAA<F%C=&5R('1H<F]U9V@@=&AE(&QI
M;F4N("HO"B`@("`@("`@("`@("1L96YG=&@@/2!S=')L96XH)&QI;F4I.PH@
M("`@("`@("`@("`D8W5R<F5N=%]L:6YE(#T@)R<["B`@("`@("`@("`@("1C
M=7)R96YT7VQE;F=T:"`](#`["@H@("`@("`@("`@("!F;W(@*"1I(#T@,#L@
M)&D@/"`D;&5N9W1H.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D8VAA<B`]
M('-U8G-T<B@D;&EN92P@)&DL(#$I.PH@("`@("`@("`@("`@("`@)&%S8VEI
M(#T@;W)D*"1C:&%R*3L*"B`@("`@("`@("`@("`@("`O*B!3<&%C97,@;W(@
M=&%B<R!A="!T:&4@96YD(&]F('1H92!L:6YE(&%R92!.3U0@86QL;W=E9"X*
M("`@("`@("`@("`@("`@("`J($%L<V\L($-H87)A8W1E<G,@:6X@05-#24D@
M8F5L;W<@,S(@;W(@86)O=F4@,3(V($%.1"`V,0H@("`@("`@("`@("`@("`@
M("H@;75S="!B92!E;F-O9&5D+B`J+PH@("`@("`@("`@("`@("`@:68@*"@H
M*"1A<V-I:2`]/3T@.2D@?'P@*"1A<V-I:2`]/3T@,S(I*2`F)B`H)&D@/3T@
M*"1L96YG=&@@+2`Q*2DI('Q\"B`@("`@("`@("`@("`@("`@("`@*"@D87-C
M:6D@/"`S,BD@?'P@*"1A<V-I:2`^(#$R-BD@?'P@*"1A<V-I:2`]/3T@-C$I
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1C:&%R(#T@)STG("X@4W1R:6YG
M.CIU<'!E<BAS<')I;G1F*"<E,#)S)RP@9&5C:&5X*"1A<V-I:2DI*3L*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O*B!,:6YE<R!M=7-T
M(&)E(#<V(&-H87)A8W1E<G,@;W(@;&5S<RX@*B\*("`@("`@("`@("`@("`@
M("1C:&%R7VQE;F=T:"`]('-T<FQE;B@D8VAA<BD["B`@("`@("`@("`@("`@
M("`D8W5R<F5N=%]L96YG=&@@*ST@)&-H87)?;&5N9W1H.PH@("`@("`@("`@
M("`@("`@:68@*"1C=7)R96YT7VQE;F=T:"`^(#<V*2!["B`@("`@("`@("`@
M("`@("`@("`@)&]U='!U="`N/2`D8W5R<F5N=%]L:6YE("X@)STG("X@)&5O
M;#L*("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]L:6YE(#T@)R<["B`@
M("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?;&5N9W1H(#T@)&-H87)?;&5N
M9W1H.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&-U<G)E
M;G1?;&EN92`N/2`D8VAA<CL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M;W5T<'5T("X]("1C=7)R96YT7VQI;F4@+B`D96]L.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1O=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%
M;F-O9&5S(&$@<W1R:6YG(&-O;G1A:6YI;F<@96UA:6P@861D<F5S<V5S(&%C
M8V]R9&EN9R!T;R!21D,@,C`T-RX*("`@("`J"B`@("`@*B!4:&ES(&1I9F9E
M<G,@9G)O;2!-24U%.CIE;F-O9&4H*2!B96-A=7-E(&ET(&ME97!S(&5M86EL
M(&%D9')E<W-E<R!L96=A;"P*("`@("`J(&]N;'D@96YC;V1I;F<@=&AE('!E
M<G-O;F%L(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&%D9')E<W-E<R`@5&AE(&5M86EL(&%D9')E<W-E<R!T;R!E;F-O9&4N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:&%R<V5T("`@(%1H92!C:&%R86-T
M97(@<V5T(&]F('1H92!T97AT+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&5F
M<V5R=F5R("!4:&4@9&5F875L="!D;VUA:6X@=&\@87!P96YD('1O(&UA:6QB
M;WAE<RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('1E>'0L
M(&5N8V]D960@;VYL>2!I9B!I="!C;VYT86EN<R!N;VXM87-C:6D*("`@("`J
M("`@("`@("`@("`@("`@("!C:&%R86-T97)S+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!E;F-O9&5!9&1R97-S*"1A9&1R97-S97,L("1C:&%R<V5T(#T@;G5L
M;"P@)&1E9G-E<G9E<B`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1A9&1R97-S97,I*2!["B`@("`@("`@("`@("1A9&1R7V%R<B`]("1A
M9&1R97-S97,["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@<&%R
M<V5!9&1R97-S3&ES="@I(&1O97,@;F]T('!R;V-E<W,@=&AE(&YU;&P@96YT
M<GD*("`@("`@("`@("`@("H@)W5N9&ES8VQO<V5D+7)E8VEP:65N=',Z.R<@
M8V]R<F5C=&QY+B`J+PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+W5N
M9&ES8VQO<V5D+7)E8VEP:65N=',Z7',J.R]I)RP@=')I;2@D861D<F5S<V5S
M*2DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D861D<F5S<V5S.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TUA:6PO4D9#
M.#(R+G!H<"<["B`@("`@("`@("`@("1P87)S97(@/2`F;F5W($UA:6Q?4D9#
M.#(R*"D["B`@("`@("`@("`@("1A9&1R7V%R<B`]("1P87)S97(M/G!A<G-E
M061D<F5S<TQI<W0H)&%D9')E<W-E<RP@)&1E9G-E<G9E<BP@=')U92P@9F%L
M<V4I.PH@("`@("`@("`@("!I9B`H:7-?82@D861D<E]A<G(L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D861D<E]A<G(["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1T97AT(#T@)R<["B`@
M("`@("`@:68@*&ES7V%R<F%Y*"1A9&1R7V%R<BDI('L*("`@("`@("`@("`@
M9F]R96%C:"`H)&%D9')?87)R(&%S("1A9&1R*2!["B`@("`@("`@("`@("`@
M("`O+R!#:&5C:R!F;W(@9W)O=7!S+@H@("`@("`@("`@("`@("`@:68@*"%E
M;7!T>2@D861D<BT^9W)O=7!N86UE*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1T97AT("X]($U)344Z.F5N8V]D92@D861D<BT^9W)O=7!N86UE+"`D8VAA
M<G-E="D@+B`G.B`G("X@34E-13HZ96YC;V1E061D<F5S<R@D861D<BT^861D
M<F5S<V5S*2`N("<[)SL*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H96UP='DH
M)&%D9'(M/G!E<G-O;F%L*2D@>PH@("`@("`@("`@("`@("`@("`@("1P97)S
M;VYA;"`]("<G.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("!I9B`H*'-U8G-T<B@D861D<BT^<&5R<V]N86PL(#`L(#$I
M(#T]("<B)RD@)B8*("`@("`@("`@("`@("`@("`@("`@("`@*'-U8G-T<B@D
M861D<BT^<&5R<V]N86PL("TQ*2`]/2`G(B<I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1A9&1R+3YP97)S;VYA;"`]('-U8G-T<B@D861D<BT^<&5R
M<V]N86PL(#$L("TQ*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@)'!E<G-O;F%L(#T@34E-13HZ96YC;V1E*"1A9&1R+3YP
M97)S;VYA;"P@)&-H87)S970I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@:68@*'-T<FQE;B@D=&5X="D@(3T@,"D@>PH@("`@("`@("`@
M("`@("`@("`@("1T97AT("X]("<L("<["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D=&5X="`N/2!-24U%.CIT<FEM16UA:6Q!9&1R97-S
M*$U)344Z.G)F8S@R,E=R:71E061D<F5S<R@D861D<BT^;6%I;&)O>"P@)&%D
M9'(M/FAO<W0L("1P97)S;VYA;"DI.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'1E>'0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!$96-O9&5S(&%N(%)&0R`R,#0W+65N8V]D960@<W1R:6YG+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'-T<FEN9R`@("`@(%1H92!T97AT('1O
M(&1E8V]D92X*("`@("`J($!P87)A;2!S=')I;F<@)'1O7V-H87)S970@(%1H
M92!C:&%R<V5T('1H870@=&AE('1E>'0@<VAO=6QD(&)E(&1E8V]D960*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@('1O+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@9&5C;V1E9"!T97AT+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!D96-O9&4H)'-T<FEN9RP@)'1O7V-H87)S970@/2!N
M=6QL*0H@("`@>PH@("`@("`@(&EF("@H)'!O<R`]('-T<G!O<R@D<W1R:6YG
M+"`G/3\G*2D@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B`D<W1R
M:6YG.PH@("`@("`@('T*"B`@("`@("`@+RH@5&%K92!O=70@86YY('-P86-E
M<R!B971W965N(&UU;'1I<&QE(&5N8V]D960@=V]R9',N("HO"B`@("`@("`@
M)'-T<FEN9R`]('!R96=?<F5P;&%C92@G?%P_/5QS/5P_?"<L("<_/3T_)RP@
M)'-T<FEN9RD["@H@("`@("`@("\J(%-A=F4@86YY('!R96-E9&EN9R!T97AT
M+B`J+PH@("`@("`@("1P<F5C961I;F<@/2!S=6)S='(H)'-T<FEN9RP@,"P@
M)'!O<RD["@H@("`@("`@("1S96%R8V@@/2!S=6)S='(H)'-T<FEN9RP@)'!O
M<R`K(#(I.PH@("`@("`@("1D,2`]('-T<G!O<R@D<V5A<F-H+"`G/R<I.PH@
M("`@("`@(&EF("@D9#$@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R
M;B`D<W1R:6YG.PH@("`@("`@('T*"B`@("`@("`@)&-H87)S970@/2!S=6)S
M='(H)'-T<FEN9RP@)'!O<R`K(#(L("1D,2D["B`@("`@("`@)'-E87)C:"`]
M('-U8G-T<B@D<V5A<F-H+"`D9#$@*R`Q*3L*"B`@("`@("`@)&0R(#T@<W1R
M<&]S*"1S96%R8V@L("<_)RD["B`@("`@("`@:68@*"1D,B`]/3T@9F%L<V4I
M('L*("`@("`@("`@("`@<F5T=7)N("1S=')I;F<["B`@("`@("`@?0H*("`@
M("`@("`D96YC;V1I;F<@/2!S=6)S='(H)'-E87)C:"P@,"P@)&0R*3L*("`@
M("`@("`D<V5A<F-H(#T@<W5B<W1R*"1S96%R8V@L("1D,B`K(#$I.PH*("`@
M("`@("`D96YD(#T@<W1R<&]S*"1S96%R8V@L("<_/2<I.PH@("`@("`@(&EF
M("@D96YD(#T]/2!F86QS92D@>PH@("`@("`@("`@("`D96YD(#T@<W1R;&5N
M*"1S96%R8V@I.PH@("`@("`@('T*"B`@("`@("`@)&5N8V]D961?=&5X="`]
M('-U8G-T<B@D<V5A<F-H+"`P+"`D96YD*3L*("`@("`@("`D<F5S="`]('-U
M8G-T<B@D<W1R:6YG+"`H<W1R;&5N*"1P<F5C961I;F<@+B`D8VAA<G-E="`N
M("1E;F-O9&EN9R`N("1E;F-O9&5D7W1E>'0I("L@-BDI.PH*("`@("`@("!I
M9B`H(6ES<V5T*"1T;U]C:&%R<V5T*2D@>PH@("`@("`@("`@("`D=&]?8VAA
M<G-E="`]($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@("`@('T*"B`@("`@("`@
M<W=I=&-H("@D96YC;V1I;F<I('L*("`@("`@("!C87-E("=1)SH*("`@("`@
M("!C87-E("=Q)SH*("`@("`@("`@("`@)&5N8V]D961?=&5X="`]('-T<E]R
M97!L86-E*"=?)RP@)R`G+"`D96YC;V1E9%]T97AT*3L*("`@("`@("`@("`@
M)&1E8V]D960@/2!P<F5G7W)E<&QA8V4H)R\]*%LP+3EA+69=>S)]*2]I92<L
M("=C:'(H,'A<,2DG+"`D96YC;V1E9%]T97AT*3L*("`@("`@("`@("`@)&1E
M8V]D960@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1D96-O9&5D+"`D8VAA
M<G-E="P@)'1O7V-H87)S970I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@8V%S92`G0B<Z"B`@("`@("`@8V%S92`G8B<Z"B`@("`@("`@("`@("1D
M96-O9&5D(#T@8F%S938T7V1E8V]D92@D96YC;V1E9%]T97AT*3L*("`@("`@
M("`@("`@)&1E8V]D960@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1D96-O
M9&5D+"`D8VAA<G-E="P@)'1O7V-H87)S970I.PH@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@)&1E8V]D960@/2`G
M/3\G("X@)&-H87)S970@+B`G/R<@+B`D96YC;V1I;F<@+B`G/R<@+B`D96YC
M;V1E9%]T97AT("X@)S\])SL*("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'!R96-E9&EN9R`N("1D96-O9&5D("X@34E-
M13HZ9&5C;V1E*"1R97-T+"`D=&]?8VAA<G-E="D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$96-O9&5S(&%N(%)&0R`R,C,Q+65N8V]D960@<W1R:6YG+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T<FEN9R`@(%1H92!E;G1I
M<F4@<W1R:6YG('1O(&1E8V]D92P@:6YC;'5D:6YG('1H90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R(&YA;64N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1C:&%R<V5T("!4:&4@8VAA<G-E="!T:&%T('1H92!T
M97AT('-H;W5L9"!B92!D96-O9&5D('1O+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@(%1H92!D96-O9&5D('1E>'0L(&]R('1H92!O<FEG:6YA;"!S
M=')I;F<@:68@:70@=V%S(&YO=`H@("`@("H@("`@("`@("`@("`@("`@96YC
M;V1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C;V1E4D9#,C(S,2@D<W1R
M:6YG+"`D=&]?8VAA<G-E="`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"@D
M<&]S(#T@<W1R<&]S*"1S=')I;F<L("<J)RDI(#T]/2!F86QS92D@>PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H
M(6ES<V5T*"1T;U]C:&%R<V5T*2D@>PH@("`@("`@("`@("`D=&]?8VAA<G-E
M="`]($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@("`@('T*"B`@("`@("`@)&%T
M=')I8G5T92`]('-U8G-T<B@D<W1R:6YG+"`P+"`D<&]S*3L*("`@("`@("`D
M8VAA<G-E="`]("1L86YG(#T@;G5L;#L*("`@("`@("`D;W5T<'5T(#T@)R<[
M"@H@("`@("`@("\J($=E="!T:&4@8VAA<F%C=&5R('-E="!A;F0@;&%N9W5A
M9V4@=7-E9"!I;B!T:&4@96YC;V1I;F<L(&EF"B`@("`@("`@("H@86YY+B`J
M+PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"(O7EM>/5TK7"I</2A;7B==*BDG
M*%M>)UTJ*2<O(BP@)'-T<FEN9RP@)&UA=&-H97,I*2!["B`@("`@("`@("`@
M("1C:&%R<V5T(#T@)&UA=&-H97-;,5T["B`@("`@("`@("`@("1L86YG(#T@
M)&UA=&-H97-;,ET["B`@("`@("`@("`@("1S=')I;F<@/2!S=')?<F5P;&%C
M92@D8VAA<G-E="`N("(G(B`N("1L86YG("X@(B<B+"`G)RP@)'-T<FEN9RD[
M"B`@("`@("`@?0H*("`@("`@("`D;&EN97,@/2!P<F5G7W-P;&ET*"<O)R`N
M('!R96=?<75O=&4H)&%T=')I8G5T92D@+B`G*#\Z7"I<9"DJ+R<L("1S=')I
M;F<I.PH@("`@("`@(&9O<F5A8V@@*"1L:6YE<R!A<R`D;&EN92D@>PH@("`@
M("`@("`@("`D<&]S(#T@<W1R<&]S*"1L:6YE+"`G*CTG*3L*("`@("`@("`@
M("`@:68@*"1P;W,@/3T](#`I('L*("`@("`@("`@("`@("`@("1L:6YE(#T@
M<W5B<W1R*"1L:6YE+"`R*3L*("`@("`@("`@("`@("`@("1L:6YE(#T@<W1R
M7W)E<&QA8V4H)U\G+"`G)3(P)RP@)&QI;F4I.PH@("`@("`@("`@("`@("`@
M)&QI;F4@/2!S=')?<F5P;&%C92@G/2<L("<E)RP@)&QI;F4I.PH@("`@("`@
M("`@("`@("`@)&]U='!U="`N/2!U<FQD96-O9&4H)&QI;F4I.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&QI;F4@/2!S=6)S='(H
M)&QI;F4L(#$I.PH@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D;&EN93L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@4D9#(#(R,S$@
M=7-E<R!Q=6]T960@<')I;G1A8FQE(&5N8V]D:6YG+B`J+PH@("`@("`@(&EF
M("@A:7-?;G5L;"@D8VAA<G-E="DI('L*("`@("`@("`@("`@)&]U='!U="`]
M(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&]U='!U="P@)&-H87)S970L("1T
M;U]C:&%R<V5T*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>2@*
M("`@("`@("`@("`@)V%T=')I8G5T92<@/3X@)&%T=')I8G5T92P*("`@("`@
M("`@("`@)W9A;'5E)R`]/B`D;W5T<'5T"B`@("`@("`@*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($EF(&%N(&5M86EL(&%D9')E<W,@:&%S(&YO('!E<G-O
M;F%L(&EN9F]R;6%T:6]N+"!G970@<FED(&]F(&%N>2!A;F=L90H@("`@("H@
M8G)A8VME=',@*#P^*2!A<F]U;F0@:70N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D861D<F5S<R`@5&AE(&%D9')E<W,@=&\@=')I;2X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('1R:6UM960@861D<F5S<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@=')I;45M86EL061D<F5S<R@D861D<F5S
M<RD*("`@('L*("`@("`@("`D861D<F5S<R`]('1R:6TH)&%D9')E<W,I.PH*
M("`@("`@("!I9B`H*'-U8G-T<B@D861D<F5S<RP@,"P@,2D@/3T@)SPG*2`F
M)B`H<W5B<W1R*"1A9&1R97-S+"`M,2D@/3T@)SXG*2D@>PH@("`@("`@("`@
M("`D861D<F5S<R`]('-U8G-T<B@D861D<F5S<RP@,2P@+3$I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1A9&1R97-S.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0G5I;&1S(&%N(%)&0R`X,C(@8V]M<&QI86YT(&5M86EL(&%D9')E
M<W,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6%I;&)O>"`@($UA
M:6QB;W@@;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)&AO<W0@("`@("!$
M;VUA:6X@;F%M92!O9B!M86EL8F]X)W,@:&]S="X*("`@("`J($!P87)A;2!S
M=')I;F<@)'!E<G-O;F%L("!097)S;VYA;"!N86UE('!H<F%S92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O<G)E8W1L>2!E<V-A<&5D
M(&%N9"!Q=6]T960*("`@("`J("`@("`@("`@("`@("`@("`B)'!E<G-O;F%L
M(#PD;6%I;&)O>$`D:&]S=#XB('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F9C.#(R5W)I=&5!9&1R97-S*"1M86EL8F]X+"`D:&]S="`](&YU;&PL
M("1P97)S;VYA;"`]("<G*0H@("`@>PH@("`@("`@("1A9&1R97-S(#T@)R<[
M"@H@("`@("`@(&EF("@A96UP='DH)'!E<G-O;F%L*2D@>PH@("`@("`@("`@
M("`D=F%R<R`](&=E=%]C;&%S<U]V87)S*"=-24U%)RD["B`@("`@("`@("`@
M("1A9&1R97-S("X]($U)344Z.E]R9F,X,C)%;F-O9&4H)'!E<G-O;F%L+"`D
M=F%R<ULG<F9C.#(R7V9I;'1E<B==("X@)RXG*3L*("`@("`@("`@("`@)&%D
M9')E<W,@+CT@)R`\)SL*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?;G5L
M;"@D:&]S="DI('L*("`@("`@("`@("`@)&%D9')E<W,@+CT@34E-13HZ7W)F
M8S@R,D5N8V]D92@D;6%I;&)O>"D["B`@("`@("`@("`@(&EF("AS=6)S='(H
M)&AO<W0L(#`L(#$I("$]("=`)RD@>PH@("`@("`@("`@("`@("`@)&%D9')E
M<W,@+CT@)T`G("X@)&AO<W0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(&EF("@A96UP='DH)'!E<G-O;F%L*2D@>PH@("`@("`@("`@("`D
M861D<F5S<R`N/2`G/B<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&%D
M9')E<W,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'!L;V1E<R!A(%)&0R`X
M,C(@<W1R:6YG+"!I9VYO<FEN9R!A(&1E;&EM:71E<B!I9B!P<F5C961E9"!B
M>2!A(")<(@H@("`@("H@8VAA<F%C=&5R+"!O<B!I9B!D96QI;6ET97(@:7,@
M:6YS:61E('-I;F=L92!O<B!D;W5B;&4@<75O=&5S+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'-T<B`@("`@("`@5&AE(%)&0R`X,C(@<W1R:6YG
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&5L:6UI=&5R("!4:&4@9&5L:6UT
M97(N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&5X<&QO9&5D
M('-T<FEN9R!I;B!A;B!A<G)A>2X*("`@("`J+PH@("`@9G5N8W1I;VX@<F9C
M.#(R17AP;&]D92@D<W1R+"`D9&5L:6UI=&5R*0H@("`@>PH@("`@("`@("1A
M<G(@/2!A<G)A>2@I.PH@("`@("`@("1M871C:"`](#`["B`@("`@("`@)'%U
M;W1E<R`](&%R<F%Y*"<B)RP@(B<B*3L*("`@("`@("`D:6Y?<75O=&4@/2!N
M=6QL.PH@("`@("`@("1I;E]G<F]U<"`](&9A;'-E.PH@("`@("`@("1P<F5V
M(#T@;G5L;#L*"B`@("`@("`@:68@*&5M<'1Y*"1S='(I*2!["B`@("`@("`@
M("`@(')E='5R;B!A<G)A>2@D<W1R*3L*("`@("`@("!]"@H@("`@("`@(&EF
M("AI;E]A<G)A>2@D<W1R>S!]+"`D<75O=&5S*2D@>PH@("`@("`@("`@("`D
M:6Y?<75O=&4@/2`D<W1R>S!].PH@("`@("`@('T@96QS96EF("@D<W1R>S!]
M(#T]("<Z)RD@>PH@("`@("`@("`@("`D:6Y?9W)O=7`@/2!T<G5E.PH@("`@
M("`@('T@96QS96EF("@D<W1R>S!](#T]("1D96QI;6ET97(I('L*("`@("`@
M("`@("`@)&%R<EM=(#T@)R<["B`@("`@("`@("`@("1M871C:"`](#$["B`@
M("`@("`@?0H*("`@("`@("!F;W(@*"1I(#T@,3L@)&D@/"!S=')L96XH)'-T
M<BD[("1I*RLI('L*("`@("`@("`@("`@)&-H87(@/2`D<W1R>R1I?3L*("`@
M("`@("`@("`@:68@*&EN7V%R<F%Y*"1C:&%R+"`D<75O=&5S*2D@>PH@("`@
M("`@("`@("`@("`@:68@*"1P<F5V("$]/2`G7%PG*2!["B`@("`@("`@("`@
M("`@("`@("`@:68@*"1I;E]Q=6]T92`]/3T@)&-H87(I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&EN7W%U;W1E(#T@;G5L;#L*("`@("`@("`@("`@
M("`@("`@("!](&5L<V5I9B`H:7-?;G5L;"@D:6Y?<75O=&4I*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1I;E]Q=6]T92`]("1C:&%R.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?2!E;'-E:68@*"1I;E]G<F]U<"D@>PH@("`@("`@("`@("`@("`@:68@*"1C
M:&%R(#T]("<[)RD@>PH@("`@("`@("`@("`@("`@("`@("1A<G);72`]('-U
M8G-T<B@D<W1R+"`D;6%T8V@L("1I("T@)&UA=&-H("L@,2D["B`@("`@("`@
M("`@("`@("`@("`@)&UA=&-H(#T@)&D@*R`Q.PH@("`@("`@("`@("`@("`@
M("`@("1I;E]G<F]U<"`](&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!](&5L<V5I9B`H)&-H87(@/3T@)SHG*2!["B`@("`@("`@("`@
M("`@("`D:6Y?9W)O=7`@/2!T<G5E.PH@("`@("`@("`@("!](&5L<V5I9B`H
M)&-H87(@/3T@)&1E;&EM:71E<B`F)@H@("`@("`@("`@("`@("`@("`@("`@
M)'!R978@(3T]("=<7"<@)B8*("`@("`@("`@("`@("`@("`@("`@(&ES7VYU
M;&PH)&EN7W%U;W1E*2D@>PH@("`@("`@("`@("`@("`@)&%R<EM=(#T@<W5B
M<W1R*"1S='(L("1M871C:"P@)&D@+2`D;6%T8V@I.PH@("`@("`@("`@("`@
M("`@)&UA=&-H(#T@)&D@*R`Q.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1P<F5V(#T@)&-H87(["B`@("`@("`@?0H*("`@("`@("!I9B`H)&UA=&-H
M("$]("1I*2!["B`@("`@("`@("`@("\J(%1H92!S=')I;F<@96YD960@=VET
M:&]U="!A("1D96QI;6ET97(N("HO"B`@("`@("`@("`@("1A<G);72`]('-U
M8G-T<B@D<W1R+"`D;6%T8V@L("1I("T@)&UA=&-H*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D87)R.PH@("`@?0H*("`@("\J*@H@("`@("H@5&%K
M97,@86X@861D<F5S<R!O8FIE8W0L(&%S(')E='5R;F5D(&)Y(&EM87!?:&5A
M9&5R*"D@9F]R(&5X86UP;&4L(&%N9`H@("`@("H@9F]R;6%T<R!I="!A<R!A
M('-T<FEN9RX*("`@("`J"B`@("`@*B!/8FIE8W0@9F]R;6%T(&9O<B!T:&4@
M861D<F5S<R`B2F]H;B!$;V4@/&IO:&Y?9&]E0&5X86UP;&4N8V]M/B(@:7,Z
M"B`@("`@*B`\<')E/@H@("`@("H@("`D;V)J96-T+3YP97)S;VYA;"`](%!E
M<G-O;F%L(&YA;64@*")*;VAN($1O92(I"B`@("`@*B`@("1O8FIE8W0M/FUA
M:6QB;W@@(#T@5&AE('5S97(G<R!M86EL8F]X("@B:F]H;E]D;V4B*0H@("`@
M("H@("`D;V)J96-T+3YH;W-T("`@("`](%1H92!H;W-T('1H92!M86EL8F]X
M(&ES(&]N("@B97AA;7!L92YC;VTB*0H@("`@("H@/"]P<F4^"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T9$-L87-S("1O8B`@(%1H92!A9&1R97-S(&]B:F5C
M="!T;R!B92!T=7)N960@:6YT;R!A('-T<FEN9RX*("`@("`J($!P87)A;2!M
M:7AE9"`D9FEL=&5R("!!('5S97)`97AA;7!L92YC;VT@<W1Y;&4@8F%R92!A
M9&1R97-S('1O(&EG;F]R92X*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!%:71H97(@<VEN9VQE('-T<FEN9R!O<B!A;B!A<G)A>2!O9B!S=')I;F=S
M+B`@268*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T:&4@861D<F5S
M<R!M871C:&5S("1F:6QT97(L(&%N(&5M<'1Y('-T<FEN9R!W:6QL"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@8F4@<F5T=7)N960N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!F;W)M871T960@861D<F5S<R`H
M17AA;7!L93H@2F]H;B!$;V4*("`@("`J("`@("`@("`@("`@("`@("`\:F]H
M;E]D;V5`97AA;7!L92YC;VT^*2X*("`@("`J+PH@("`@9G5N8W1I;VX@861D
M<D]B:F5C=#)3=')I;F<H)&]B+"`D9FEL=&5R(#T@)R<I"B`@("!["B`@("`@
M("`@+RH@268@=&AE('!E<G-O;F%L(&YA;64@:7,@<V5T+"!D96-O9&4@:70N
M("HO"B`@("`@("`@)&]B+3YP97)S;VYA;"`](&ES<V5T*"1O8BT^<&5R<V]N
M86PI(#\@34E-13HZ9&5C;V1E*"1O8BT^<&5R<V]N86PI(#H@)R<["@H@("`@
M("`@("\J($EF(&)O=&@@=&AE(&UA:6QB;W@@86YD('1H92!H;W-T(&%R92!E
M;7!T>2P@<F5T=7)N(&%N(&5M<'1Y"B`@("`@("`@("`@<W1R:6YG+B`@268@
M=V4@:G5S="!L970@=&AI<R!C87-E(&9A;&P@=&AR;W5G:"P@=&AE(&-A;&P@
M=&\*("`@("`@("`@("!-24U%.CIR9F,X,C)7<FET94%D9')E<W,H*2!W:6QL
M(&5N9"!U<"!R971U<FX@:G5S="!A("=`)RP@=VAI8V@*("`@("`@("`@("!I
M<R!U;F1E<VER86)L92X@*B\*("`@("`@("!I9B`H96UP='DH)&]B+3YM86EL
M8F]X*2`F)B!E;7!T>2@D;V(M/FAO<W0I*2!["B`@("`@("`@("`@(')E='5R
M;B`G)SL*("`@("`@("!]"@H@("`@("`@("\J($UA:V4@<W5R92!T:&5S92!T
M=V\@=F%R:6%B;&5S(&AA=F4@<V]M92!S;W)T(&]F('9A;'5E+B`J+PH@("`@
M("`@(&EF("@A:7-S970H)&]B+3YM86EL8F]X*2D@>PH@("`@("`@("`@("`D
M;V(M/FUA:6QB;W@@/2`G)SL*("`@("`@("!](&5L<V5I9B`H)&]B+3YM86EL
M8F]X(#T]("=U;F1I<V-L;W-E9"UR96-I<&EE;G1S)RD@>PH@("`@("`@("`@
M("!R971U<FX@)R<["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)&]B
M+3YH;W-T*2D@>PH@("`@("`@("`@("`D;V(M/FAO<W0@/2`G)SL*("`@("`@
M("!]"@H@("`@("`@("\J($9I;'1E<B!O=70@=6YW86YT960@861D<F5S<V5S
M(&)A<V5D(&]N('1H92`D9FEL=&5R('-T<FEN9RX@*B\*("`@("`@("!I9B`H
M)&9I;'1E<BD@>PH@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1F:6QT97(I
M*2!["B`@("`@("`@("`@("`@("`D9FEL=&5R(#T@87)R87DH)&9I;'1E<BD[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@9F]R96%C:"`H)&9I;'1E<B!A
M<R`D9BD@>PH@("`@("`@("`@("`@("`@:68@*'-T<F-A<V5C;7`H)&8L("1O
M8BT^;6%I;&)O>"`N("=`)R`N("1O8BT^:&]S="D@/3T@,"D@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@4F5T=7)N('1H92!T
M<FEM;65D+"!F;W)M871T960@96UA:6P@861D<F5S<RX@*B\*("`@("`@("!R
M971U<FX@34E-13HZ=')I;45M86EL061D<F5S<RA-24U%.CIR9F,X,C)7<FET
M94%D9')E<W,H)&]B+3YM86EL8F]X+"`D;V(M/FAO<W0L("1O8BT^<&5R<V]N
M86PI*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1A:V5S(&%N(&%R<F%Y(&]F
M(&%D9')E<W,@;V)J96-T<RP@87,@<F5T=7)N960@8GD@:6UA<%]H96%D97)I
M;F9O*"DL"B`@("`@*B!F;W(@97AA;7!L92P@86YD('!A<W-E<R!E86-H(&]F
M('1H96T@=&AR;W5G:"!-24U%.CIA9&1R3V)J96-T,E-T<FEN9R@I+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D861D<F5S<V5S("!4:&4@87)R87D@
M;V8@861D<F5S<R!O8FIE8W1S+@H@("`@("H@0'!A<F%M(&UI>&5D("1F:6QT
M97(@("`@($$@=7-E<D!E>&%M<&QE+F-O;2!S='EL92!B87)E(&%D9')E<W,@
M=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!I9VYO<F4N("!)
M9B!A;GD@861D<F5S<R!M871C:&5S("1F:6QT97(L(&ET"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@=VEL;"!N;W0@8F4@:6YC;'5D960@:6X@
M=&AE(&9I;F%L('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@06QL(&]F('1H92!A9&1R97-S97,@:6X@82!C;VUM82UD96QI;6ET960@
M<W1R:6YG+@H@("`@("H@("`@("`@("`@("`@("`@(%)E='5R;G,@=&AE(&5M
M<'1Y('-T<FEN9R!O;B!E<G)O<B]N;R!A9&1R97-S97,@9F]U;F0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%D9')!<G)A>3)3=')I;F<H)&%D9')E<W-E<RP@
M)&9I;'1E<B`]("<G*0H@("`@>PH@("`@("`@("1A9&1R3&ES="`](&%R<F%Y
M*"D["@H@("`@("`@(&EF("@A:7-?87)R87DH)&%D9')E<W-E<RDI('L*("`@
M("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C
M:"`H)&%D9')E<W-E<R!A<R`D861D<BD@>PH@("`@("`@("`@("`D=F%L(#T@
M34E-13HZ861D<D]B:F5C=#)3=')I;F<H)&%D9'(L("1F:6QT97(I.PH@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1V86PI*2!["B`@("`@("`@("`@("`@("`D
M8F%R94%D9'(@/2!3=')I;F<Z.FQO=V5R*$U)344Z.F)A<F5!9&1R97-S*"1V
M86PI*3L*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&%D9'),:7-T6R1B
M87)E061D<ETI*2!["B`@("`@("`@("`@("`@("`@("`@)&%D9'),:7-T6R1B
M87)E061D<ET@/2`D=F%L.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH)&%D9'),:7-T*2D@
M>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N(&EM<&QO9&4H)RP@)RP@)&%D9'),:7-T*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!B87)E
M(&%D9')E<W,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D861D<F5S
M<R`@("!4:&4@861D<F5S<R!S=')I;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1D969S97)V97(@(%1H92!D969A=6QT(&1O;6%I;B!T;R!A<'!E;F0@=&\@
M;6%I;&)O>&5S+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&UU;'1I<&QE("!3
M:&]U;&0@=V4@<F5T=7)N(&UU;'1I<&QE(')E<W5L=',_"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@268@)&UU;'1I<&QE(&ES(&9A;'-E+"!R971U
M<FYS('1H92!M86EL8F]X0&AO<W0@92UM86EL"B`@("`@*B`@("`@("`@("`@
M("`@("!A9&1R97-S+B`@268@)&UU;'1I<&QE(&ES('1R=64L(')E='5R;G,@
M86X@87)R87D@;V8*("`@("`J("`@("`@("`@("`@("`@('1H97-E(&%D9')E
M<W-E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@8F%R94%D9')E<W,H)&%D9')E
M<W,L("1D969S97)V97(@/2!N=6QL+"`D;75L=&EP;&4@/2!F86QS92D*("`@
M('L*("`@("`@("`D861D<F5S<TQI<W0@/2!A<G)A>2@I.PH*("`@("`@("`O
M*B!5<V4@8G5I;'0M:6X@24U!4"!F=6YC=&EO;B!O;FQY(&EF(&%V86EL86)L
M92!A;F0@:68@;F]T('!A<G-I;F<*("`@("`@("`@*B!D:7-T<FEB=71I;VX@
M;&ES=',@8F5C875S92!I="!D;V5S;B=T('!A<G-E(&1I<W1R:6)U=&EO;B!L
M:7-T<PH@("`@("`@("`J('!R;W!E<FQY+B`J+PH@("`@("`@(&EF("A5=&EL
M.CIE>'1E;G-I;VY%>&ES=',H)VEM87`G*2`F)B!S=')P;W,H)&%D9')E<W,L
M("<Z)RD@/3T](&9A;'-E*2!["B`@("`@("`@("`@("1F<F]M(#T@:6UA<%]R
M9F,X,C)?<&%R<V5?861R;&ES="@D861D<F5S<RP@)&1E9G-E<G9E<BD["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=-86EL
M+U)&0S@R,BYP:'`G.PH@("`@("`@("`@("`D<&%R<V5R(#T@;F5W($UA:6Q?
M4D9#.#(R*"D["B`@("`@("`@("`@("1F<F]M(#T@)'!A<G-E<BT^<&%R<V5!
M9&1R97-S3&ES="@D861D<F5S<RP@)&1E9G-E<G9E<BP@9F%L<V4L(&9A;'-E
M*3L*("`@("`@("`@("`@:68@*&ES7V$H)&9R;VTL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D;75L=&EP;&4@/R!A<G)A>2@I
M(#H@)R<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&9O<F5A
M8V@@*"1F<F]M(&%S("1E;G1R>2D@>PH@("`@("`@("`@("!I9B`H:7-S970H
M)&5N=')Y+3YM86EL8F]X*2`F)@H@("`@("`@("`@("`@("`@)&5N=')Y+3YM
M86EL8F]X("$]("=U;F1I<V-L;W-E9"UR96-I<&EE;G1S)R`F)@H@("`@("`@
M("`@("`@("`@)&5N=')Y+3YM86EL8F]X("$]("=53D584$5#5$5$7T1!5$%?
M049415)?041$4D534R<I('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M96YT<GDM/FAO<W0I*2!["B`@("`@("`@("`@("`@("`@("`@)&%D9')E<W-,
M:7-T6UT@/2`D96YT<GDM/FUA:6QB;W@@+B`G0"<@+B`D96YT<GDM/FAO<W0[
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("1A9&1R97-S3&ES=%M=(#T@)&5N=')Y+3YM86EL8F]X.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&UU;'1I<&QE(#\@)&%D9')E<W-,:7-T(#H@87)R87E?<&]P*"1A9&1R
M97-S3&ES="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!1=6]T97,@86YD(&5S
M8V%P97,@=&AE(&=I=F5N('-T<FEN9R!I9B!N96-E<W-A<GDN"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<W1R("`@("!4:&4@<W1R:6YG('1O(&)E('%U;W1E9"!A;F0@97-C
M87!E9"X*("`@("`J($!P87)A;2!S=')I;F<@)&9I;'1E<B`@02!L:7-T(&]F
M(&-H87)A8W1E<G,@=&AA="!M86ME(&ET(&YE8V5S<V%R>2!T;PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("!Q=6]T92!T:&4@<W1R:6YG(&EF('1H
M97D@;V-C=7(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C
M;W)R96-T;'D@<75O=&5D(&%N9"!E<V-A<&5D('-T<FEN9RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@7W)F8S@R,D5N8V]D92@D<W1R+"`D9FEL=&5R(#T@)R<I
M"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1F:6QT97(I*2!["B`@("`@("`@
M("`@("1V87)S(#T@9V5T7V-L87-S7W9A<G,H)TU)344G*3L*("`@("`@("`@
M("`@)&9I;'1E<B`]("1V87)S6R=R9F,X,C)?9FEL=&5R)UT@+B`G("<["B`@
M("`@("`@?0H*("`@("`@("`O+R!3=')I<"!D;W5B;&4@<75O=&5S(&EF('1H
M97D@87)E(&%R;W5N9"!T:&4@<W1R:6YG(&%L<F5A9'DN"B`@("`@("`@:68@
M*'-U8G-T<B@D<W1R+"`P+"`Q*2`]/2`G(B<@)B8@<W5B<W1R*"1S='(L("TQ
M*2`]/2`G(B<I('L*("`@("`@("`@("`@)'-T<B`]('-U8G-T<B@D<W1R+"`Q
M+"`M,2D["B`@("`@("`@?0H*("`@("`@("!I9B`H<W1R8W-P;B@D<W1R+"`D
M9FEL=&5R*2`A/2!S=')L96XH)'-T<BDI('L*("`@("`@("`@("`@)'-T<B`]
M('-T<E]R97!L86-E*"=<(B<L("<B)RP@)'-T<BD["B`@("`@("`@("`@(')E
M='5R;B`G(B<@+B!S=')?<F5P;&%C92@G(B<L("=<7"(G+"!S=')?<F5P;&%C
M92@G7%PG+"`G7%Q<7"<L("1S='(I*2`N("<B)SL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@)'-T<CL*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!-24U%('1Y<&4@9F]R('1H92!G
M:79E;B!I;G!U="X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&EN<'5T
M("`@("!%:71H97(@=&AE($U)344@8V]D92!O<B!T>7!E('-T<FEN9RX*("`@
M("`J($!P87)A;2!I;G1E9V5R("1F;W)M870@($EF($U)345?0T]$12P@<F5T
M=7)N(&-O9&4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!)9B!-
M24U%7U-44DE.1RP@<F5T=7)N<R!L;W=E<F-A<V4@<W1R:6YG+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%-E92!A8F]V92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@='EP92@D:6YP=70L("1F;W)M870@/2!N=6QL*0H@("`@>PH@
M("`@("`@(')E='5R;B!-24U%.CI?9V5T0V]D92@D:6YP=70L("1F;W)M870L
M("=M:6UE7W1Y<&5S)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!-24U%(&5N8V]D:6YG(&9O<B!T:&4@9VEV96X@:6YP=70N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&UI>&5D("1I;G!U="`@("`@16ET:&5R('1H92!-
M24U%(&-O9&4@;W(@96YC;V1I;F<@<W1R:6YG+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&9O<FUA="`@268@34E-15]#3T1%+"!R971U<FX@8V]D92X*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@($EF($U)345?4U1224Y'+"!R
M971U<FYS(&QO=V5R8V%S92!S=')I;F<N"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("!)9B!N;W0@<V5T+"!R971U<FYS('1H92!O<'!O<VET92!V
M86QU92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!3964@86)O=F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8V]D:6YG*"1I;G!U="P@)&9O<FUA
M="`](&YU;&PI"B`@("!["B`@("`@("`@<F5T=7)N($U)344Z.E]G971#;V1E
M*"1I;G!U="P@)&9O<FUA="P@)VUI;65?96YC;V1I;F=S)RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971R:65V97,@34E-12!E;F-O9&EN9R]T>7!E(&1A
M=&$@9G)O;2!T:&4@:6YT97)N86P@87)R87ES+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D:6YP
M=70@("`@16ET:&5R('1H92!-24U%(&-O9&4@;W(@96YC;V1I;F<@<W1R:6YG
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T("!)9B!-24U%7T-/1$4L
M(')E='5R;G,@8V]D92X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M268@34E-15]35%))3D<L(')E='5R;G,@;&]W97)C87-E('-T<FEN9RX*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@268@;G5L;"P@<F5T=7)N<R!T
M:&4@;W!P<&]S:71E('9A;'5E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP
M92`@("!4:&4@;F%M92!O9B!T:&4@:6YT97)N86P@87)R87DN"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@4V5E(&%B;W9E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?9V5T0V]D92@D:6YP=70L("1F;W)M870L("1T>7!E*0H@("`@
M>PH@("`@("`@("1N=6UE<FEC(#T@:7-?;G5M97)I8R@D:6YP=70I.PH@("`@
M("`@(&EF("@A)&YU;65R:6,I('L*("`@("`@("`@("`@)&EN<'5T(#T@4W1R
M:6YG.CIL;W=E<B@D:6YP=70I.PH@("`@("`@('T*"B`@("`@("`@<W=I=&-H
M("@D9F]R;6%T*2!["B`@("`@("`@8V%S92!-24U%7T-/1$4Z"B`@("`@("`@
M("`@(&EF("@D;G5M97)I8RD@<F5T=7)N("1I;G!U=#L*("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@(&-A<V4@34E-15]35%))3D<Z"B`@("`@("`@("`@
M(&EF("@A)&YU;65R:6,I(')E='5R;B`D:6YP=70["B`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@('T*"B`@("`@("`@)'9A<G,@/2!G971?8VQA<W-?=F%R
M<R@G34E-12<I.PH*("`@("`@("!I9B`H)&YU;65R:6,I('L*("`@("`@("`@
M("`@:68@*&ES<V5T*"1V87)S6R1T>7!E75LD:6YP=71=*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1V87)S6R1T>7!E75LD:6YP=71=.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"@D<V5A
M<F-H(#T@87)R87E?<V5A<F-H*"1I;G!U="P@)'9A<G-;)'1Y<&5=*2DI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D<V5A<F-H.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@;G5L;#L*("`@('T*"B`@("`O
M*BH*("`@("`J($=E;F5R871E<R!A($UE<W-A9V4M240@<W1R:6YG(&-O;F9O
M<FUI;F<@=&\@4D9#(#(X,C(@6S,N-BXT72!A;F0@=&AE"B`@("`@*B!S=&%N
M9&%R9',@;W5T;&EN960@:6X@)V1R869T+6EE=&8M=7-E9F]R+6UE<W-A9V4M
M:60M,#$N='AT)RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("!!(&UE
M<W-A9V4@240@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!G96YE<F%T
M94UE<W-A9V5)1"@I"B`@("!["B`@("`@("`@<F5T=7)N("<\)R`N(&1A=&4H
M)UEM9$AI<R<I("X@)RXG("X*("`@("`@("`@("`@<W5B<W1R*&)A<V5?8V]N
M=F5R="AM:6-R;W1I;64H*2`N(&UT7W)A;F0H*2P@,3`L(#,V*2P@+3$V*2`N
M"B`@("`@("`@("`@("=`)R`N("1?4T525D526R=315)615)?3D%-12==("X@
M)SXG.PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!P<F]P97(@;&EN96)R
M96%K<R!T;R!A(&AE861E<B!S=')I;F<N"B`@("`@*B!21D,@,C@R,B!;,BXR
M+C-=('-A>7,@=&AA="!H96%D97)S(%-(3U5,1"!B92!W<F%P<&5D(&%T(#<X
M(&-H87)A8W1E<G,N"B`@("`@*B!(;W=E=F5R+"!S:6YC92!W92!M87D@8F4@
M9&5A;&EN9R!W:71H('%U;W1E9"!T97AT('1H870@8V]N=&%I;G,@<W!A8V5S
M+`H@("`@("H@<W1R:6-T('=R87!P:6YG(&%T(#<X(&-H87)A8W1E<G,@;6%Y
M(&%D9"!U;G=A;G1E9"!N97=L:6YE<R!A;F0@=&%B<R!T;PH@("`@("H@=&AE
M('%U;W1E9"!P87)A;65T97(N("!4:&4@8V]R<F5C="!W87D@=&\@9V5T(&%R
M;W5N9"!T:&ES(&ES('1O(&5N8V]D90H@("`@("H@<&%R865T97)S(&%C8V]R
M9&EN9R!T;R!21D,@,C(S,2X@($AO=V5V97(L('-I;F-E(&UO<W0@;6%I;&5R
M<R!D;R!N;W0*("`@("`J('-E96T@=&\@<W5P<&]R="!T:&ES+"!W92!W:6QL
M(&EN<W1E860@<VEM<&QY('5S92!L;VYG(&QI;F5S+B`@4D9#(#(X,C(*("`@
M("`J('-A>7,@:&5A9&5R<R!32$]53$0@;VYL>2!B92`W."!C:&%R86-T97)S
M(&$@;&EN92P@8G5T(&%L<V\@<V%Y<R!T:&%T"B`@("`@*B!A(&AE861E<B!L
M:6YE($U54U0@;F]T(&)E(&UO<F4@=&AA;B`Y.3@@8VAA<F%C=&5R<RX@(%1H
M97)E9F]R92P@=&AE"B`@("`@*B!C;VUP<F]M:7-E(&ES('1O('!U="!E86-H
M('!A<F%M971E<B!O;B!A('-E<&%R871E(&QI;F4@86YD(&-H;W`@:70*("`@
M("`J(&]N;'D@:68@:70@:7,@;&]N9V5R('1H86X@.3DX(&-H87)A8W1E<G,N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:&5A9&5R("!4:&4@:&5A
M9&5R(&YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@(%1H92!T
M97AT(&]F('1H92!H96%D97(@9FEE;&0N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1E;VP@("`@(%1H92!%3TP@<W1R:6YG('1O('5S92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(&AE861E<B!T97AT+"!W:71H(&QI;F5B
M<F5A:W,@:6YS97)T960N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R87!(96%D
M97)S*"1H96%D97(L("1T97AT+"`D96]L(#T@(EQR7&XB*0H@("`@>PH@("`@
M("`@("1H96%D97(@/2!R=')I;2@D:&5A9&5R*3L*"B`@("`@("`@+RH@4F5M
M;W9E(&%N>2!E>&ES=&EN9R!L:6YE8G)E86MS+B`J+PH@("`@("`@("1T97AT
M(#T@<')E9U]R97!L86-E*"(O7'(_7&Y<<S\O(BP@)R`G+"`D=&5X="D["B`@
M("`@("`@)'1E>'0@/2`D:&5A9&5R("X@)SH@)R`N(')T<FEM*"1T97AT*3L*
M"B`@("`@("`@)&5O;&QE;F=T:"`]('-T<FQE;B@D96]L*3L*("`@("`@("`D
M:&5A9&5R7VQO=V5R(#T@<W1R=&]L;W=E<B@D:&5A9&5R*3L*"B`@("`@("`@
M:68@*"@D:&5A9&5R7VQO=V5R("$]("=C;VYT96YT+71Y<&4G*2`F)@H@("`@
M("`@("`@("`H)&AE861E<E]L;W=E<B`A/2`G8V]N=&5N="UD:7-P;W-I=&EO
M;B<I*2!["B`@("`@("`@("`@("\J(%=R87`@=&AE(&QI;F4N("HO"B`@("`@
M("`@("`@("1L:6YE(#T@=V]R9'=R87`H)'1E>'0L(#<U+"`D96]L("X@(EQT
M(BD["@H@("`@("`@("`@("`O*B!-86ME('-U<F4@=&AE<F4@87)E(&YO(&5M
M<'1Y(&QI;F5S+B`J+PH@("`@("`@("`@("`D;&EN92`]('!R96=?<F5P;&%C
M92@G+R<@+B`D96]L("X@(EQT7',J(B`N("1E;VP@+B`B7'0O(BP@)R\G("X@
M)&5O;"`N(")<="\B+"`D;&EN92D["@H@("`@("`@("`@("!R971U<FX@<W5B
M<W1R*"1L:6YE+"!S=')L96XH)&AE861E<BD@*R`R*3L*("`@("`@("!]"@H@
M("`@("`@("\J(%-P;&ET('1H92!L:6YE(&)Y('1H92!21D,@<&%R86UE=&5R
M('-E<&%R871O<B`G.R<N("HO"B`@("`@("`@)'!A<F%M<R`]('!R96=?<W!L
M:70H(B]<<RH[7',J+R(L("1T97AT*3L*"B`@("`@("`@)&QI;F4@/2`G)SL*
M("`@("`@("`D;&5N9W1H(#T@,3`P,"`M("1E;VQL96YG=&@["B`@("`@("`@
M)'!A<F%M8V]U;G0@/2!C;W5N="@D<&%R86US*3L*"B`@("`@("`@9F]R96%C
M:"`H)'!A<F%M<R!A<R`D8V]U;G0@/3X@)'9A;"D@>PH@("`@("`@("`@("`O
M*B!)9B!L;VYG97(@=&AA;B!21D,@86QL;W=S+"!T:&5N('-I;7!L>2!C:&]P
M(&]F9B!T:&4@97AC97-S+B`J+PH@("`@("`@("`@("`D;6]R97!A<F%M<R`]
M("@H)&-O=6YT("L@,2D@(3T@)'!A<F%M8V]U;G0I.PH@("`@("`@("`@("`D
M;6%X;&5N9W1H(#T@)&QE;F=T:"`M("@A96UP='DH)&QI;F4I(#\@,2`Z(#`I
M("T@*"@D;6]R97!A<F%M<RD@/R`Q(#H@,"D["B`@("`@("`@("`@(&EF("AS
M=')L96XH)'9A;"D@/B`D;6%X;&5N9W1H*2!["B`@("`@("`@("`@("`@("`D
M=F%L(#T@<W5B<W1R*"1V86PL(#`L("1M87AL96YG=&@I.PH*("`@("`@("`@
M("`@("`@("\J($EF('=E(&AA=F4@86X@;W!E;FEN9R!Q=6]T92P@861D(&$@
M8VQO<VEN9R!Q=6]T92!A9G1E<@H@("`@("`@("`@("`@("`@("H@8VAO<'!I
M;F<@=&AE(')E<W0@;V8@=&AE('1E>'0N("HO"B`@("`@("`@("`@("`@("!I
M9B`H<W1R<&]S*"1V86PL("<B)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@
M("`@("`@("`@)'9A;"`]('-U8G-T<B@D=F%L+"`P+"`M,2D["B`@("`@("`@
M("`@("`@("`@("`@)'9A;"`N/2`G(B<["B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(65M<'1Y*"1L:6YE*2D@
M>PH@("`@("`@("`@("`@("`@)&QI;F4@+CT@(EQT(CL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D;&EN92`N/2`D=F%L("X@*"@D;6]R97!A<F%M<RD@
M/R`G.R<@.B`G)RD@+B`D96]L.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('-U8G-T<B@D;&EN92P@<W1R;&5N*"1H96%D97(I("L@,BP@*"1E;VQL96YG
M=&@@*B`M,2DI.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M36]B:6QE+P``````````````````````````````````````````````````
M`````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-3$U-#,S-S0V`#`R,#8W-@`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]-;V)I;&4O4F5N9&5R97(O````````````````
M````````````````````````````````````````````````,#`P,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-#8`,#(R-#0T
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TUO8FEL92]296YD
M97)E<B]H=&UL+G!H<```````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R-C0W,``Q
M,#4Q-30S,S<T-@`P,C0Q,S(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J($AO<F1E7TUO8FEL95]296YD
M97)E<CHZ(&]U='!U="!M;V1U;&4@9F]R('-I;7!L92!(5$U,(&%N9`H@*B!)
M;6]D92]!=F%N=&=O+W-I;6EL87(@9&5V:6-E<RX*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO36]B:6QE+TUO8FEL92]296YD97)E<B]H=&UL+G!H<"QV(#$N
M,C@N,3`N-B`R,#`V+S`Q+S`Q(#(Q.C(X.C(V(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N
M,`H@*B!`<&%C:V%G92!(;W)D95]-;V)I;&4*("HO"F-L87-S($AO<F1E7TUO
M8FEL95]296YD97)E<E]H=&UL(&5X=&5N9',@2&]R9&5?36]B:6QE7U)E;F1E
M<F5R('L*"B`@("`O*BH*("`@("`J(%!R;W!E<FQY(&5N8V]D92!C:&%R86-T
M97)S(&9O<B!O=71P=70@=&\@86X@2%1-3"!B<F]W<V5R+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&EN<'5T("!#:&%R86-T97)S('1O(&5N8V]D
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&5N8V]D960@
M=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@97-C87!E*"1I;G!U="D*("`@
M('L*("`@("`@("!R971U<FX@0&AT;6QS<&5C:6%L8VAA<G,H)&EN<'5T+"!%
M3E1?0T]-4$%4+"!.3%,Z.F=E=$-H87)S970H*2D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#<F5A=&5S('1H92!P86=E(&EN('1H92!A<'!R;W!R:6%T92!M
M87)K=7`N($1E<&5N9&EN9R!O;B!T:&4*("`@("`J(&-L:65N=',@8G)O=W-E
M<B!T>7!E('!U<F4@2%1-3"P@:&%N9&AE;&1F<FEE;F1L>2!!=F%N=$=O($A4
M34PL"B`@("`@*B!I+6UO9&4@8TA434PL(&]R($U-3"!I<R!C<F5A=&5D+@H@
M("`@("H*("`@("`J($!P87)A;2!(;W)D95]-;V)I;&4@)&1E8VL@(%1H92!D
M96-K('1O(')E;F1E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"8D
M9&5C:RD*("`@('L*("`@("`@("!I9B`H)&1E8VLM/E]D96)U9RD@>PH@("`@
M("`@("`@("!H96%D97(H)T-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA
M<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(&AE861E<B@G0V]N=&5N="U4>7!E.B!T97AT+VAT;6P[
M(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("!]"B`@
M("`@("`@:&5A9&5R*"=687)Y.B!!8V-E<'0M3&%N9W5A9V4G*3L*"B`@("`@
M("`@:68@*"$D=&AI<RT^:7-"<F]W<V5R*"=M;6PG*2D@>PH@("`@("`@("`@
M("!E8VAO("(\(41/0U194$4@:'1M;"!054),24,@7"(M+R]7,T,O+T141"!(
M5$U,(#0N,"!4<F%N<VET:6]N86PO+T5.7"(^7&XB.PH@("`@("`@('T*"B`@
M("`@("`@96-H;R`A96UP='DH)$=,3T)!3%-;)VQA;F=U86=E)UTI(#\@)SQH
M=&UL(&QA;F<](B<@+B!S=')T<B@D1TQ/0D%,4ULG;&%N9W5A9V4G72P@)U\G
M+"`G+2<I("X@)R(^)R`Z("<\:'1M;#XG.PH@("`@("`@(&5C:&\@)SQH96%D
M/B<["@H@("`@("`@(&EF("@D=&AI<RT^:7-"<F]W<V5R*"=A=F%N=&=O)RDI
M('L*("`@("`@("`@("`@96-H;R`G/&UE=&$@;F%M93TB2&%N9&AE;&1&<FEE
M;F1L>2(@8V]N=&5N=#TB5')U92(^)SL*("`@("`@("!]"@H@("`@("`@('!R
M:6YT9B@B/'1I=&QE/B5S/"]T:71L93Y<;B(L("1T:&ES+3YE<V-A<&4H)&1E
M8VLM/F=E="@G=&ET;&4G*2DI.PH*("`@("`@("!I9B`H)&1E8VLM/E]S:6UU
M;&%T;W(I('L*("`@("`@("`@("`@+R\@57-E('-I;75L871O<B`H;6]B:6QE
M('1H96UE*2!S='EL97-H965T+@H@("`@("`@("`@("!E8VAO($AO<F1E.CIS
M='EL97-H965T3&EN:R@G:&]R9&4G+"`G;6]B:6QE)RD["B`@("`@("`@?0H*
M("`@("`@("!E8VAO("<\+VAE860^/&)O9'D^)SL*"B`@("`@("`@:68@*"1D
M96-K+3Y?<VEM=6QA=&]R*2!["B`@("`@("`@("`@(&5C:&\@(CQC96YT97(^
M/&)R("\^7&XB.PH@("`@("`@("`@("`O+R!#<F5A=&4@9&5F875L="!D979I
M8V4@<VEM=6QA=&]R('1A8FQE(&QA>6]U="!W:71H"B`@("`@("`@("`@("\O
M(&-E;G1R86P@0U-3(&QA>6]U="X*("`@("`@("`@("`@96-H;R`B/'1A8FQE
M(&)O<F1E<CU<(C!<(B!C96QL<&%D9&EN9SU<(C!<(B!C96QL<W!A8VEN9SU<
M(C!<(CY<;B(["B`@("`@("`@("`@(&5C:&\@(CQT<CX\=&0@8V]L<W!A;CU<
M(C-<(B!C;&%S<SU<(G1O<%PB/B9N8G-P.SPO=&0^/"]T<CY<;B(["B`@("`@
M("`@("`@(&5C:&\@(CQT<CX\=&0@=F%L:6=N/5PB=&]P7"(@8VQA<W,]7")L
M969T7"(^)FYB<W`[/"]T9#Y<;B(["B`@("`@("`@("`@(&5C:&\@(CQT9"!V
M86QI9VX]7")T;W!<(B!C;&%S<SU<(F1I<W!L87E<(CY<;B(["B`@("`@("`@
M?0H*("`@("`@("`D9&EV<W1Y;&4@/2`G)SL*("`@("`@("!I9B`H)'1H:7,M
M/FAA<U%U:7)K*"=S8W)O;&Q?=&1S)RD@)B8@)&1E8VLM/E]S:6UU;&%T;W(I
M('L*("`@("`@("`@("`@+R\@36%K92!C;VYT96YT(&]F('1A8FQE(&5L96UE
M;G0@<V-R;VQL86)L92`H2&]R9&5?36]B:6QE"B`@("`@("`@("`@("\O('-I
M;75L871O<BDN"B`@("`@("`@("`@("1D:79S='EL92`]("<@8VQA<W,](G-I
M;61E=B(G.PH@("`@("`@('T*("`@("`@("!E8VAO("<\9&EV)R`N("1D:79S
M='EL92`N("<^)SL*"B`@("`@("`@:68@*"@D8VYT(#T@8V]U;G0H)&1E8VLM
M/E]C87)D<RDI("$]/2`P*2!["B`@("`@("`@("`@("1I(#T@,#L*("`@("`@
M("`@("`@9F]R96%C:"`H)&1E8VLM/E]C87)D<R!A<R`D8V%R9"D@>PH@("`@
M("`@("`@("`@("`@:68@*"1I("$](#`I('L*("`@("`@("`@("`@("`@("`@
M("!E8VAO("<\:'(@+SXG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]R96YD97)#87)D*"1C87)D*3L*("`@("`@("`@("`@
M("`@("1I*RL["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!F;W)E86-H("@D9&5C:RT^7V5L96UE;G1S(&%S("1P86=E7V5L
M96UE;G0I('L*("`@("`@("`@("`@("`@("1T:&ES+3YR96YD97)%;&5M96YT
M*"1P86=E7V5L96UE;G0I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!E8VAO("<\+V1I=CXG.PH*("`@("`@("!I9B`H)&1E8VLM/E]S:6UU
M;&%T;W(I('L*("`@("`@("`@("`@+R\@1&ES<&QA>2!L;W=E<B!P87)T(&]F
M($AO<F1E7TUO8FEL92!D969A=6QT(&1E=FEC90H@("`@("`@("`@("`O+R!S
M:6UU;&%T;W(N"B`@("`@("`@("`@(&5C:&\@)SPO=&0^/'1D('9A;&EG;CTB
M=&]P(B!C;&%S<STB<FEG:'0B/B9N8G-P.SPO=&0^/"]T<CX\='(^/'1D(&-O
M;'-P86X](C,B(&-L87-S/2)B;W1T;VTB/B9N8G-P.SPO=&0^/"]T<CX\+W1A
M8FQE/CPO8V5N=&5R/B<["B`@("`@("`@?0H*("`@("`@("!E8VAO("<\+V)O
M9'D^/"]H=&UL/B<["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<D-A<F0H
M)B1C87)D*0H@("`@>PH@("`@("`@("1N86UE(#T@)&-A<F0M/F=E="@G;F%M
M92<I(#\@)R!N86UE/2(G("X@)'1H:7,M/F5S8V%P92@D8V%R9"T^9V5T*"=N
M86UE)RDI("X@)R(G(#H@)R<["B`@("`@("`@<')I;G1F*"<\825S/B5S/"]A
M/B<L("1N86UE+"`D8V%R9"T^9V5T*"=T:71L92<I*3L*"B`@("`@("`@:68@
M*&-O=6YT*"1C87)D+3Y?<V]F=&ME>7,I*2!["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1C87)D+3Y?<V]F=&ME>7,@87,@)&ME>2D@>PH@("`@("`@("`@("`@
M("`@96-H;R`G('P@/&$@:')E9CTB)R`N("1K97E;)W5R;"==("X@)R(^)R`N
M("`D=&AI<RT^97-C87!E*"1K97E;)VQA8F5L)UTI("X@)SPO83XG.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!296YD97(@86QL('1A
M9W,N"B`@("`@("`@9F]R96%C:"`H)&-A<F0M/E]E;&5M96YT<R!A<R`D<&%G
M95]E;&5M96YT*2!["B`@("`@("`@("`@("1T:&ES+3YR96YD97)%;&5M96YT
M*"1P86=E7V5L96UE;G0I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO
M;B!?<F5N9&5R3&EN:R@F)&QI;FLI"B`@("!["B`@("`@("`@:68@*"1L:6YK
M+3YG970H)W1I=&QE)RD@)B8*("`@("`@("`@("`@(21T:&ES+3YI<T)R;W=S
M97(H)V%V86YT9V\G*2`F)@H@("`@("`@("`@("`A)'1H:7,M/FES0G)O=W-E
M<B@G:6UO9&4G*2`F)@H@("`@("`@("`@("`A)'1H:7,M/FES0G)O=W-E<B@G
M;6UL)RDI('L*("`@("`@("`@("`@)'1I=&QE7V]P=&EO;B`]('-P<FEN=&8H
M)R!O;FUO=7-E;W9E<CTB<V5L9BYS=&%T=7,]7"<E<UPG.W)E='5R;B!T<G5E
M.R(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^97-C87!E*"1L:6YK+3YG970H)W1I=&QE)RDI*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D=&ET;&5?;W!T:6]N(#T@)R<["B`@("`@("`@
M?0H*("`@("`@("`D86-C97-S:V5Y7V]P=&EO;B`]("<G.PH@("`@("`@(&EF
M("@D;&EN:RT^9V5T*"=A8V-E<W-K97DG*2D@>PH@("`@("`@("`@("!I9B`H
M)'1H:7,M/FES0G)O=W-E<B@G:6UO9&4G*2D@>PH@("`@("`@("`@("`@("`@
M)&%C8V5S<VME>5]O<'1I;VX@/2!S<')I;G1F*"<@86-C97-S:V5Y/2(E9"(G
M+"`D;&EN:RT^9V5T*"=A8V-E<W-K97DG*2D["B`@("`@("`@("`@('T@96QS
M96EF("@D=&AI<RT^:7-"<F]W<V5R*"=M;6PG*2D@>PH@("`@("`@("`@("`@
M("`@)&%C8V5S<VME>5]O<'1I;VX@/2!S<')I;G1F*"<@9&ER96-T:V5Y/2(E
M9"(G+"`D;&EN:RT^9V5T*"=A8V-E<W-K97DG*2D["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@('!R:6YT9B@G/&$@:')E9CTB)7,B)7,E<SXE
M<SPO83XG+`H@("`@("`@("`@("`@("!S=')?<F5P;&%C92@G)F%M<#MA;7`[
M)RP@)R9A;7`[)RP@)'1H:7,M/F5S8V%P92@D;&EN:RT^9V5T*"=U<FPG*2DI
M+`H@("`@("`@("`@("`@("`D=&ET;&5?;W!T:6]N+"`D86-C97-S:V5Y7V]P
M=&EO;BP*("`@("`@("`@("`@("`@)'1H:7,M/F5S8V%P92@D;&EN:RT^9V5T
M*"=L86)E;"<I*2D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<DQI;FMS
M970H)B1L:6YK<V5T*0H@("`@>PH@("`@("`@(&EF("AC;W5N="@D;&EN:W-E
M="T^7V5L96UE;G1S*2D@>PH@("`@("`@("`@("!E8VAO("<\;VP^)SL*("`@
M("`@("`@("`@9F]R96%C:"`H)&QI;FMS970M/E]E;&5M96YT<R!A<R`D=F%L
M*2!["B`@("`@("`@("`@("`@("!E8VAO("<\;&D^)SL*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<F5N9&5R3&EN:R@D=F%L*3L*("`@("`@("`@("`@("`@
M(&5C:&\@)SPO;&D^)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E8VAO
M("<\+V]L/B<["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD
M97)497AT*"8D96QE;65N="D*("`@('L*("`@("`@("!F;W)E86-H("@D96QE
M;65N="T^7V%T=')I8G5T97,@87,@)&%T=')I8G5T92D@>PH@("`@("`@("`@
M("!E8VAO("<\)R`N("1A='1R:6)U=&4@+B`G/B<["B`@("`@("`@?0H*("`@
M("`@("!I9B`H)&5L96UE;G0M/F=E="@G;&EN96)R96%K<R<I*2!["B`@("`@
M("`@("`@(&5C:&\@;FPR8G(H)'1H:7,M/F5S8V%P92@D96QE;65N="T^9V5T
M*"=T97AT)RDI*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!E8VAO
M("1T:&ES+3YE<V-A<&4H)&5L96UE;G0M/F=E="@G=&5X="<I*3L*("`@("`@
M("!]"@H@("`@("`@("1A='1R:6)U=&5S(#T@87)R87E?<F5V97)S92@D96QE
M;65N="T^7V%T=')I8G5T97,I.PH@("`@("`@(&9O<F5A8V@@*"1A='1R:6)U
M=&5S(&%S("1A='1R:6)U=&4I('L*("`@("`@("`@("`@96-H;R`G/"\G("X@
M)&%T=')I8G5T92`N("<^)SL*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I
M;VX@7W)E;F1E<DEM86=E*"8D:6UA9V4I"B`@("!["B`@("`@("`@)&%T=')I
M8G5T97,@/2`G)SL*("`@("`@("!F;W)E86-H("@D:6UA9V4M/E]A='1R:6)U
M=&5S(&%S("1A='1R:6)U=&4@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1A
M='1R:6)U=&5S("X]('-P<FEN=&8H)R`E<STB)7,B)RP@)&%T=')I8G5T92P@
M)'9A;'5E*3L*("`@("`@("!]"B`@("`@("`@<')I;G1F*"<\:6UG('-R8STB
M)7,N<&YG(B5S("\^)RP@)&EM86=E+3Y?<W)C+"`D871T<FEB=71E<RD["B`@
M("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<D9O<FTH)B1F;W)M*0H@("`@>PH@
M("`@("`@('!R:6YT9B@G/&9O<FT@86-T:6]N/2(E<R(@;65T:&]D/2(E<R(^
M)RP@)&9O<FTM/F=E="@G=7)L)RDL("1F;W)M+3YG970H)VUE=&AO9"<I*3L*
M("`@("`@("!P87)E;G0Z.E]R96YD97)&;W)M*"1F;W)M*3L*("`@("`@("!E
M8VAO("<\+V9O<FT^)SL*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R26YP
M=70H)B1I;G!U="D*("`@('L*("`@("`@("`D='EP92`]("=T>7!E/2(G("X@
M)&EN<'5T+3YG970H)W1Y<&4G*2`N("<B)SL*("`@("`@("`D<VEZ92`]("1I
M;G!U="T^9V5T*"=S:7IE)RD@/R!S<')I;G1F*"=S:7IE/2(E9"(G+"`D:6YP
M=70M/F=E="@G<VEZ92<I*2`Z("<G.PH@("`@("`@("1M87AL96YG=&@@/2`D
M:6YP=70M/F=E="@G;6%X;&5N9W1H)RD@/R!S<')I;G1F*"=M87AL96YG=&@]
M(B5D(B<L("1I;G!U="T^9V5T*"=M87AL96YG=&@G*2D@.B`G)SL*"B`@("`@
M("`@:68@*"1T:&ES+3YI<T)R;W=S97(H)VEM;V1E)RDI('L*("`@("`@("`@
M("`@)&UO9&4@/2!S<')I;G1F*"<@:7-T>6QE/2(E9"(G+"`D:6YP=70M/F=E
M="@G;6]D92<I*3L*("`@("`@("!](&5L<V5I9B`H)'1H:7,M/FES0G)O=W-E
M<B@G;6UL)RDI('L*("`@("`@("`@("`@)&UO9&4@/2`D=&AI<RT^7V=E=$UO
M9&4H)&EN<'5T+3YG970H)VUO9&4G*2D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&UO9&4@/2`G)SL*("`@("`@("!]"@H@("`@("`@("\O($-R
M96%T92!(5$U,(&EN<'5T+@H@("`@("`@('!R:6YT9B@G)7,@/&EN<'5T("5S
M(&YA;64](B5S(B!V86QU93TB)7,B)7,E<R5S+SXG+`H@("`@("`@("`@("`@
M("`D=&AI<RT^97-C87!E*"1I;G!U="T^9V5T*"=L86)E;"<I*2P@)'1Y<&4L
M"B`@("`@("`@("`@("`@("1T:&ES+3YE<V-A<&4H)&EN<'5T+3YG970H)VYA
M;64G*2DL("1T:&ES+3YE<V-A<&4H)&EN<'5T+3YG970H)W9A;'5E)RDI+"`D
M<VEZ92P@)&UA>&QE;F=T:"P@)&UO9&4I.PH@("`@?0H*("`@(&9U;F-T:6]N
M(%]R96YD97)497AT87)E82@F)'1E>'1A<F5A*0H@("`@>PH@("`@("`@(&EF
M("@D=&AI<RT^:7-"<F]W<V5R*"=I;6]D92<I*2!["B`@("`@("`@("`@("1M
M;V1E(#T@<W!R:6YT9B@G(&ES='EL93TB)60B)RP@)'1H:7,M/FUO9&4I.PH@
M("`@("`@('T@96QS96EF("@D=&AI<RT^:7-"<F]W<V5R*"=M;6PG*2D@>PH@
M("`@("`@("`@("`D;6]D92`]("1T:&ES+3Y?9V5T36]D92@D=&AI<RT^;6]D
M92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&UO9&4@/2`G)SL*
M("`@("`@("!]"@H@("`@("`@("1W<F%P(#T@)R<["B`@("`@("`@:68@*"$D
M=&AI<RT^:7-"<F]W<V5R*"=I;6]D92<I("8F("$D=&AI<RT^:7-"<F]W<V5R
M*"=M;6PG*2D@>PH@("`@("`@("`@("`D=W)A<"`]("<@=W)A<#TB=FER='5A
M;"(G.PH@("`@("`@('T*"B`@("`@("`@<')I;G1F*"<E<SQB<B`O/CQT97AT
M87)E82!N86UE/2(E<R(@<F]W<STB)7,B(&-O;',](B5S(B5S)7,^)7,\+W1E
M>'1A<F5A/B<L"B`@("`@("`@("`@("`@("1T:&ES+3YE<V-A<&4H)'1E>'1A
M<F5A+3YG970H)VQA8F5L)RDI+"`D=&5X=&%R96$M/F=E="@G;F%M92<I+"`D
M=&5X=&%R96$M/F=E="@G<F]W<R<I+`H@("`@("`@("`@("`@("`D=&5X=&%R
M96$M/F=E="@G8V]L<R<I+"`D;6]D92P@)'=R87`L("1T97AT87)E82T^9V5T
M*"=V86QU92<I*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R4V5L96-T
M*"8D<V5L96-T*0H@("`@>PH@("`@("`@(&5C:&\@)SQS96QE8W0@;F%M93TB
M)R`N("1S96QE8W0M/F=E="@G;F%M92<I("X@)R(@<VEZ93TB,2(^)SL*("`@
M("`@("!F;W)E86-H("@D<V5L96-T+3Y?;W!T:6]N<R!A<R`D=F%L*2!["B`@
M("`@("`@("`@(&EF("@D=F%L6R=V86QU92==(#T]("1S96QE8W0M/E]V86QU
M92D@>PH@("`@("`@("`@("`@("`@)'-E;"`]("<@<V5L96-T960](G-E;&5C
M=&5D(B<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M<V5L(#T@)R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96-H;R`G/&]P
M=&EO;B<@+B`D<V5L("X@)R!V86QU93TB)R`N("1V86Q;)W9A;'5E)UT@+B`G
M(CXG("X@)'1H:7,M/F5S8V%P92@D=F%L6R=L86)E;"==*2`N("<\+V]P=&EO
M;CXG.PH@("`@("`@('T*("`@("`@("!E8VAO("<\+W-E;&5C=#XG.PH@("`@
M?0H*("`@(&9U;F-T:6]N(%]R96YD97)2861I;R@F)')A9&EO*0H@("`@>PH@
M("`@("`@(&9O<F5A8V@@*"1R861I;RT^7V)U='1O;G,@87,@)'9A;"D@>PH@
M("`@("`@("`@("`D<V5L(#T@*"1V86Q;)W9A;'5E)UT@/3T@)')A9&EO+3Y?
M=F%L=64I(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G)SL*("`@("`@("`@
M("`@<')I;G1F*"<\:6YP=70@='EP93TB<F%D:6\B(&YA;64](B5S(B5S('9A
M;'5E/2(E<R(@+SX@)7,\8G(@+SXG+`H@("`@("`@("`@("`@("`@("`@)')A
M9&EO+3YG970H)VYA;64G*2P@)'-E;"P@)'9A;%LG=F%L=64G72P*("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YE<V-A<&4H)'9A;%LG;&%B96PG72DI.PH@
M("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R0VAE8VMB;W@H
M)B1C:&5C:V)O>"D*("`@('L*("`@("`@("`D<W1A=&4@/2`D8VAE8VMB;W@M
M/FES0VAE8VME9"@I(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G)SL*("`@
M("`@("!P<FEN=&8H)SQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB)7,B
M)7,@=F%L=64](B5S(B`O/B`E<SQB<B`O/B<L"B`@("`@("`@("`@("`@("1C
M:&5C:V)O>"T^9V5T*"=N86UE)RDL("1S=&%T92P@)&-H96-K8F]X+3YG970H
M)W9A;'5E)RDL"B`@("`@("`@("`@("`@("1T:&ES+3YE<V-A<&4H)&-H96-K
M8F]X+3YG970H)VQA8F5L)RDI*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N
M9&5R4W5B;6ET*"8D<W5B;6ET*0H@("`@>PH@("`@("`@("1N86UE(#T@(65M
M<'1Y*"1S=6)M:70M/E]N86UE*2`_("<@;F%M93TB)R`N("1S=6)M:70M/E]N
M86UE("X@)R(G(#H@)R<["B`@("`@("`@<')I;G1F*"<\:6YP=70@='EP93TB
M<W5B;6ET(B5S('9A;'5E/2(E<R(@+SX\8G(@+SXG+`H@("`@("`@("`@("`@
M("`D;F%M92P@)'1H:7,M/F5S8V%P92@D<W5B;6ET+3Y?;&%B96PI*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R2&ED9&5N*"8D:&ED9&5N*0H@("`@
M>PH@("`@("`@('!R:6YT9B@G/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB
M)7,B('9A;'5E/2(E<R(@+SXG+`H@("`@("`@("`@("`@("`D:&ED9&5N+3YG
M970H)VYA;64G*2P@)&AI9&1E;BT^9V5T*"=V86QU92<I*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!?<F5N9&5R5&%B;&4H)B1T86)L92D*("`@('L*("`@("`@
M("`D8F]R9&5R(#T@)'1A8FQE+3YG970H)V)O<F1E<B<I.PH@("`@("`@("1P
M861D:6YG(#T@)'1A8FQE+3YG970H)W!A9&1I;F<G*3L*("`@("`@("`D<W!A
M8VEN9R`]("1T86)L92T^9V5T*"=S<&%C:6YG)RD["@H@("`@("`@(&5C:&\@
M)SQT86)L92<["B`@("`@("`@:68@*"%I<U]N=6QL*"1B;W)D97(I*2!["B`@
M("`@("`@("`@(&5C:&\@)R!B;W)D97(](B<@+B`D8F]R9&5R("X@)R(G.PH@
M("`@("`@('T*("`@("`@("!I9B`H(6ES7VYU;&PH)'!A9&1I;F<I*2!["B`@
M("`@("`@("`@(&5C:&\@)R!C96QL<&%D9&EN9STB)R`N("1P861D:6YG("X@
M)R(G.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES7VYU;&PH)'-P86-I;F<I
M*2!["B`@("`@("`@("`@(&5C:&\@)R!C96QL<W!A8VEN9STB)R`N("1S<&%C
M:6YG("X@)R(G.PH@("`@("`@('T*("`@("`@("!E8VAO("<^)SL*"B`@("`@
M("`@<&%R96YT.CI?<F5N9&5R5&%B;&4H)'1A8FQE*3L*"B`@("`@("`@+R\@
M5&5R;6EN871E('1A8FQE+@H@("`@("`@(&EF("@D=&AI<RT^:7-"<F]W<V5R
M*"=M;6PG*2D@>PH@("`@("`@("`@("!E8VAO("<\+W1A8FQE/CQB<B`O/B<[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@34U,(&AA<R!P<F]B
M;&5M<R!W:71H('1H92!C;&5A<B!A='1R:6)U=&4N"B`@("`@("`@("`@(&5C
M:&\@)SPO=&%B;&4^/&)R(&-L96%R/2)A;&PB/B<["B`@("`@("`@?0H@("`@
M?0H*("`@(&9U;F-T:6]N(%]R96YD97)0:&]N92@F)'!H;VYE*0H@("`@>PH@
M("`@("`@(&EF("@D=&AI<RT^:7-"<F]W<V5R*"=I;6]D92<I*2!["B`@("`@
M("`@("`@("\O($-R96%T92!P:&]N971O.B!L:6YK(&9O<B!I+4UO9&4N"B`@
M("`@("`@("`@('!R:6YT9B@G/'`^/&$@:')E9CTB<&AO;F5T;SHE<R(^)7,\
M+V$^/"]P/B<L"B`@("`@("`@("`@("`@("`@("`D<&AO;F4M/F=E="@G;G5M
M8F5R)RDL("1P:&]N92T^9V5T*"=L86)E;"<I*3L*("`@("`@("!](&5L<V5I
M9B`H)'1H:7,M/FES0G)O=W-E<B@G;6UL)RDI('L*("`@("`@("`@("`@+R\@
M0W)E871E('1E;#H@;&EN:R!F;W(@34U,+@H@("`@("`@("`@("!P<FEN=&8H
M)SQP/CQA(&AR968](G1E;#HE<R(^)7,\+V$^/"]P/B<L"B`@("`@("`@("`@
M("`@("`@("`D<&AO;F4M/F=E="@G;G5M8F5R)RDL("1P:&]N92T^9V5T*"=L
M86)E;"<I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!$:7-P
M;&%Y('!H;VYE(&YU;6)E<B!A<R!P;&%I;B!T97AT+@H@("`@("`@("`@("!P
M<FEN=&8H)SQP/CQB:6<^)7,\+V)I9SX\+W`^)RP@)'!H;VYE+3YG970H)VQA
M8F5L)RDI.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R
M4G5L92@F)')U;&4I"B`@("!["B`@("`@("`@)'=I9'1H(#T@)')U;&4M/F=E
M="@G=VED=&@G*3L*("`@("`@("`D<VEZ92`]("1R=6QE+3YG970H)W-I>F4G
M*3L*"B`@("`@("`@96-H;R`G/&AR)R`N("@D=VED=&@@/R`G('=I9'1H/2(G
M("X@)'=I9'1H("X@)R(G(#H@)R<I("X@*"1S:7IE(#\@)R!S:7IE/2(G("X@
M)'-I>F4@+B`G(B<@.B`G)RD@+B`B("\^7&XB.PH@("`@?0H*("`@(&9U;F-T
M:6]N(%]G971-;V1E*"1M;V1E*0H@("`@>PH@("`@("`@('-W:71C:"`H)&UO
M9&4I('L*("`@("`@("!C87-E("=K871A:V%N82<Z"B`@("`@("`@("`@(')E
M='5R;B`G(&UO9&4](FMA=&%K86YA(B<["@H@("`@("`@(&-A<V4@)VAI<F%G
M86YA)SH*("`@("`@("`@("`@<F5T=7)N("<@;6]D93TB:&ER86=A;F$B)SL*
M"B`@("`@("`@8V%S92`G;G5M97)I8R<Z"B`@("`@("`@("`@(')E='5R;B`G
M(&UO9&4](FYU;65R:6,B)SL*"B`@("`@("`@8V%S92`G86QP:&$G.@H@("`@
M("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B`G(&UO9&4](F%L<&AA
M8F5T(B<["B`@("`@("`@?0H@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TUO8FEL92]2
M96YD97)E<B]W;6PN<&AP````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R-C4R
M,P`Q,#4Q-30S,S<T-@`P,C,W-C0`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J($AO<F1E7TUO8FEL95]2
M96YD97)E<CHZ(&]U='!U="!M;V1U;&4@9F]R(%=-3"`H5VER96QE<W,@36%R
M:W5P($QA;F=U86=E*2X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO36]B:6QE
M+TUO8FEL92]296YD97)E<B]W;6PN<&AP+'8@,2XS,BXQ,"XW(#(P,#8O,#(O
M,C0@,C`Z-#`Z,S@@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M
M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@
M2&]R9&5?36]B:6QE"B`J+PIC;&%S<R!(;W)D95]-;V)I;&5?4F5N9&5R97)?
M=VUL(&5X=&5N9',@2&]R9&5?36]B:6QE7U)E;F1E<F5R('L*"B`@("`O*BH*
M("`@("`J(%!R;W!E<FQY(&5N8V]D92!C:&%R86-T97)S(&9O<B!O=71P=70@
M=&\@82!734P@9&5V:6-E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&EN<'5T("!#:&%R86-T97)S('1O(&5N8V]D92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&5N8V]D960@=&5X="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@97-C87!E*"1I;G!U="D*("`@('L*("`@("`@("`O+R!%;F-O
M9&4@96YT:71I97,N"B`@("`@("`@)&]U='!U="`]($!H=&UL<W!E8VEA;&-H
M87)S*"1I;G!U="P@14Y47T-/35!!5"P@3DQ3.CIG971#:&%R<V5T*"DI.PH*
M("`@("`@("`O+R!%<V-A<&4@)"!C:&%R86-T97(@:6X@5TU,+@H@("`@("`@
M("1O=71P=70@/2!S=')?<F5P;&%C92@G)"<L("<D)"<L("1O=71P=70I.PH*
M("`@("`@("`O+R!'96YE<F%T92!55$8M."X*("`@("`@("`D;W5T<'5T(#T@
M4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D;W5T<'5T+"!.3%,Z.F=E=$-H87)S
M970H*2P@)W5T9BTX)RD["@H@("`@("`@(')E='5R;B`D;W5T<'5T.PH@("`@
M?0H*("`@("\J*@H@("`@("H@0W)E871E<R!T:&4@<&%G92!I;B!734PL(&%L
M;&]W:6YG(&9O<B!D:69F97)E;G0@5TU,(&)R;W=S97(@<75I<FMS+@H@("`@
M("H*("`@("`J($!P87)A;2!(;W)D95]-;V)I;&4@)&1E8VL@(%1H92!D96-K
M('1O(')E;F1E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"8D9&5C
M:RD*("`@('L*("`@("`@("!I9B`H)&1E8VLM/E]D96)U9RD@>PH@("`@("`@
M("`@("!H96%D97(H)T-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E
M=#UU=&8M."<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&AE861E
M<B@G0V]N=&5N="U4>7!E.B!T97AT+W9N9"YW87`N=VUL.R!C:&%R<V5T/75T
M9BTX)RD["B`@("`@("`@?0H*("`@("`@("!E8VAO("(\/WAM;"!V97)S:6]N
M/5PB,2XP7"(_/EQN(CL*("`@("`@("!I9B`H)'1H:7,M/FAA<U%U:7)K*"=O
M=U]G=6E?,2XS)RDI('L*("`@("`@("`@("`@96-H;R`G/"%$3T-465!%('=M
M;"!054),24,@(BTO+U!(3TY%+D-/32\O1%1$(%=-3"`Q+C,O+T5.(B`B:'1T
M<#HO+W=W=RYO<&5N=V%V92YC;VTO9'1D+W=M;#$S+F1T9"(^)SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!E8VAO("<\(41/0U194$4@=VUL(%!5
M0DQ)0R`B+2\O5T%01D]254TO+T141"!734P@,2XQ+R]%3B(@(FAT='`Z+R]W
M=W<N=V%P9F]R=6TN;W)G+T141"]W;6Q?,2XQ+GAM;"(^)SL*("`@("`@("!]
M"B`@("`@("`@96-H;R`G/'=M;#XG.PH*("`@("`@("!I9B`H8V]U;G0H)&1E
M8VLM/E]C87)D<RDI('L*("`@("`@("`@("`@9F]R96%C:"`H)&1E8VLM/E]C
M87)D<R!A<R`D8V%R9"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]R96YD
M97)#87)D*"1C87)D*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1T:71L92`]("1D96-K+3YG970H)W1I=&QE)RD@/R`G
M('1I=&QE/2(G("X@)'1H:7,M/F5S8V%P92@D9&5C:RT^9V5T*"=T:71L92<I
M*2`N("<B)R`Z("<G.PH@("`@("`@("`@("!P<FEN=&8H)SQC87)D)7,^)RP@
M)'1I=&QE*3L*"B`@("`@("`@("`@("\O(%)E;F1E<B!A;&P@=&%G<RX*("`@
M("`@("`@("`@9F]R96%C:"`H)&1E8VLM/E]E;&5M96YT<R!A<R`D<&%G95]E
M;&5M96YT*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<F5N9&5R16QE;65N
M="@D<&%G95]E;&5M96YT*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M96-H;R`G/"]C87)D/B<["B`@("`@("`@?0H*("`@("`@("`O+R!%;F0@=&AE
M(%=-3"!P86=E+@H@("`@("`@(&5C:&\@)SPO=VUL/B<["B`@("!]"@H@("`@
M9G5N8W1I;VX@7W)E;F1E<D-A<F0H)B1C87)D*0H@("`@>PH@("`@("`@("1N
M86UE(#T@)&-A<F0M/F=E="@G;F%M92<I(#\@)R!I9#TB)R`N("1T:&ES+3YE
M<V-A<&4H)&-A<F0M/F=E="@G;F%M92<I*2`N("<B)R`Z("<G.PH@("`@("`@
M("1T:71L92`]("1C87)D+3YG970H)W1I=&QE)RD@/R`G('1I=&QE/2(G("X@
M)'1H:7,M/F5S8V%P92@D8V%R9"T^9V5T*"=T:71L92<I*2`N("<B)R`Z("<G
M.PH@("`@("`@('!R:6YT9B@G/&-A<F0E<R5S/B<L("1N86UE+"`D=&ET;&4I
M.PH*("`@("`@("`O+R!);FET:6%L:7IE(%=-3"!V87)I86)L97,@=VET:"!T
M:&5I<B!D969A=6QT('9A;'5E<RX*("`@("`@("!I9B`H(6ES7VYU;&PH)&-A
M<F0M/E]F;W)M*2D@>PH@("`@("`@("`@("!E8VAO("<\;VYE=F5N="!T>7!E
M/2)O;F5N=&5R9F]R=V%R9"(^/')E9G)E<V@^)SL*("`@("`@("`@("`@)&1E
M9F%U;'1S(#T@)&-A<F0M/E]F;W)M+3YG971$969A=6QT<R@I.PH@("`@("`@
M("`@("!F;W)E86-H("@D9&5F875L=',@87,@)&0I('L*("`@("`@("`@("`@
M("`@('!R:6YT9B@G/'-E='9A<B!N86UE/2)?)7,B('9A;'5E/2(E<R(O/B<L
M("1D6R=N86UE)UTL("1T:&ES+3YE<V-A<&4H)&1;)W9A;'5E)UTI*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!E8VAO("<\+W)E9G)E<V@^/"]O;F5V
M96YT/B<["B`@("`@("`@?0H*("`@("`@("!I9B`H8V]U;G0H)&-A<F0M/E]S
M;V9T:V5Y<RDI('L*("`@("`@("`@("`@:68@*&-O=6YT*"1C87)D+3Y?<V]F
M=&ME>7,I(#T](#$I('L*("`@("`@("`@("`@("`@("\O($EF('1H97)E(&ES
M(&]N;'D@;VYE('-O9G1K97DL(&UA:V4@:70@;V8@='EP90H@("`@("`@("`@
M("`@("`@+R\@)V]P=&EO;G,G('-O('1H870@:70@86QW87ES('-H;W=S('5P
M(&]N('1H92!R:6=H="P*("`@("`@("`@("`@("`@("\O(&EN<W1E860@;V8@
M:&%V:6YG('1O('-H87)E('1H92!L969T('-O9G1K97D@=VET:`H@("`@("`@
M("`@("`@("`@+R\@86-T:79E(&QI;FMS+"!M86MI;F<@:70@;75C:"!H87)D
M97(@=&\@9V5T('1O+@H@("`@("`@("`@("`@("`@)'1Y<&4@/2`G;W!T:6]N
M<R<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D='EP
M92`]("=A8V-E<'0G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1C87)D+3Y?<V]F=&ME>7,@87,@)&ME>2D@>PH@("`@("`@("`@("`@
M("`@96-H;R`G/&1O('1Y<&4](B<@+B`D='EP92`N("<B(&QA8F5L/2(G("X@
M)'1H:7,M/F5S8V%P92@D:V5Y6R=L86)E;"==*2`N("<B/CQG;R!H<F5F/2(G
M("X@)&ME>5LG=7)L)UT@+B`G(B\^/"]D;SXG.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O+R!296YD97(@86QL('1A9W,N"B`@("`@("`@
M9F]R96%C:"`H)&-A<F0M/E]E;&5M96YT<R!A<R`D<&%G95]E;&5M96YT*2![
M"B`@("`@("`@("`@("1T:&ES+3YR96YD97)%;&5M96YT*"1P86=E7V5L96UE
M;G0I.PH@("`@("`@('T*"B`@("`@("`@96-H;R`G/"]C87)D/B<["B`@("!]
M"@H@("`@9G5N8W1I;VX@7W)E;F1E<DQI;FLH)B1L:6YK*0H@("`@>PH@("`@
M("`@("1T:71L95]O<'1I;VX@/2`D;&EN:RT^9V5T*"=T:71L92<I(#\@<W!R
M:6YT9B@G('1I=&QE/2(E<R(G+"`D=&AI<RT^97-C87!E*"1L:6YK+3YG970H
M)W1I=&QE)RDI*2`Z("<G.PH*("`@("`@("!P<FEN=&8H)SQA)7,@:')E9CTB
M)7,B/B5S/"]A/B<L"B`@("`@("`@("`@("`@("1T:71L95]O<'1I;VXL('-T
M<E]R97!L86-E*"<F86UP.V%M<#LG+"`G)F%M<#LG+"`D=&AI<RT^97-C87!E
M*"1L:6YK+3YG970H)W5R;"<I*2DL"B`@("`@("`@("`@("`@("1T:&ES+3YE
M<V-A<&4H)&QI;FLM/F=E="@G;&%B96PG*2DI.PH@("`@?0H*("`@(&9U;F-T
M:6]N(%]R96YD97),:6YK<V5T*"8D;&EN:W-E="D*("`@('L*("`@("`@("!I
M9B`H8V]U;G0H)&QI;FMS970M/E]E;&5M96YT<RDI('L*("`@("`@("`@("`@
M:68@*"1T:&ES+3YI<T)R;W=S97(H)W5P)RDI('L*("`@("`@("`@("`@("`@
M(&5C:&\@)SQS96QE8W0^)SL*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1L
M:6YK<V5T+3Y?96QE;65N=',@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@
M("`@("1T:71L92`]("1V86PM/F=E="@G=&ET;&4G*2`_("<@=&ET;&4](B<@
M+B`D=&AI<RT^97-C87!E*"1V86PM/F=E="@G=&ET;&4G*2D@+B`G(B<@.B`G
M)SL*("`@("`@("`@("`@("`@("`@("!P<FEN=&8H)SQO<'1I;VX@;VYP:6-K
M/2(E<R(E<SXE<SPO;W!T:6]N/B<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@('-T<E]R97!L86-E*"<F86UP.V%M<#LG+"`G)F%M<#LG+"`D=&AI<RT^
M97-C87!E*"1V86PM/F=E="@G=7)L)RDI*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1I=&QE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^97-C87!E*"1V86PM/F=E="@G;&%B96PG*2DI.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@96-H;R`G/"]S96QE8W0^)SL*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1L
M:6YK<V5T+3Y?96QE;65N=',@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<F5N9&5R3&EN:R@D=F%L*3L*("`@("`@("`@("`@("`@
M("`@("!E8VAO("<\8G(@+SXG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)4
M97AT*"8D96QE;65N="D*("`@('L*("`@("`@("!F;W)E86-H("@D96QE;65N
M="T^7V%T=')I8G5T97,@87,@)&%T=')I8G5T92D@>PH@("`@("`@("`@("!E
M8VAO("<\)R`N("1A='1R:6)U=&4@+B`G/B<["B`@("`@("`@?0H*("`@("`@
M("!I9B`H)&5L96UE;G0M/F=E="@G;&EN96)R96%K<R<I*2!["B`@("`@("`@
M("`@(&5C:&\@;FPR8G(H)'1H:7,M/F5S8V%P92@D96QE;65N="T^9V5T*"=T
M97AT)RDI*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!E8VAO("1T
M:&ES+3YE<V-A<&4H)&5L96UE;G0M/F=E="@G=&5X="<I*3L*("`@("`@("!]
M"@H@("`@("`@("1A='1R:6)U=&5S(#T@87)R87E?<F5V97)S92@D96QE;65N
M="T^7V%T=')I8G5T97,I.PH@("`@("`@(&9O<F5A8V@@*"1A='1R:6)U=&5S
M(&%S("1A='1R:6)U=&4I('L*("`@("`@("`@("`@96-H;R`G/"\G("X@)&%T
M=')I8G5T92`N("<^)SL*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@
M7W)E;F1E<DEM86=E*"8D:6UA9V4I"B`@("!["B`@("`@("`@)&%T=')I8G5T
M97,@/2`G)SL*("`@("`@("!F;W)E86-H("@D:6UA9V4M/E]A='1R:6)U=&5S
M(&%S("1A='1R:6)U=&4@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1A='1R
M:6)U=&5S("X]('-P<FEN=&8H)R`E<STB)7,B)RP@)&%T=')I8G5T92P@)'9A
M;'5E*3L*("`@("`@("!]"B`@("`@("`@<')I;G1F*"<\:6UG('-R8STB)7,N
M=V)M<"(E<R\^)RP@)&EM86=E+3Y?<W)C+"`D871T<FEB=71E<RD["B`@("!]
M"@H@("`@9G5N8W1I;VX@7W)E;F1E<DEN<'5T*"8D:6YP=70I"B`@("!["B`@
M("`@("`@)'1Y<&4@/2`G('1Y<&4](B<@+B`D:6YP=70M/F=E="@G='EP92<I
M("X@)R(G.PH@("`@("`@("1S:7IE(#T@)&EN<'5T+3YG970H)W-I>F4G*2`_
M('-P<FEN=&8H)R!S:7IE/2(E9"(G+"`D:6YP=70M/F=E="@G<VEZ92<I*2`Z
M("<G.PH@("`@("`@("1M87AL96YG=&@@/2`D:6YP=70M/F=E="@G;6%X;&5N
M9W1H)RD@/R!S<')I;G1F*"<@;6%X;&5N9W1H/2(E9"(G+"`D:6YP=70M/F=E
M="@G;6%X;&5N9W1H)RDI(#H@)R<["@H@("`@("`@('!R:6YT9B@G)7,\:6YP
M=70@96UP='EO:STB=')U92(@9F]R;6%T/2(E<R(E<R!N86UE/2)?)7,B('9A
M;'5E/2(E<R(E<R5S+SXG+`H@("`@("`@("`@("`@("`D=&AI<RT^97-C87!E
M*"1I;G!U="T^9V5T*"=L86)E;"<I*2P@)&EN<'5T+3YG970H)V9O<FUA="<I
M+`H@("`@("`@("`@("`@("`D='EP92P@)'1H:7,M/F5S8V%P92@D:6YP=70M
M/F=E="@G;F%M92<I*2P@)'1H:7,M/F5S8V%P92@D:6YP=70M/F=E="@G=F%L
M=64G*2DL("1S:7IE+"`D;6%X;&5N9W1H*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!?<F5N9&5R5&5X=&%R96$H)B1T97AT87)E82D*("`@('L*("`@("`@("!P
M<FEN=&8H)R5S/&EN<'5T(&5M<'1Y;VL](G1R=64B(&YA;64](E\E<R(@=F%L
M=64](B5S(B\^)RP*("`@("`@("`@("`@("`@)'1H:7,M/F5S8V%P92@D=&5X
M=&%R96$M/F=E="@G;&%B96PG*2DL"B`@("`@("`@("`@("`@("1T97AT87)E
M82T^9V5T*"=N86UE)RDL("1T97AT87)E82T^9V5T*"=V86QU92<I*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R4V5L96-T*"8D<V5L96-T*0H@("`@
M>PH@("`@("`@(&EF("@D=&AI<RT^:&%S475I<FLH)V]W7V=U:5\Q+C,G*2D@
M>PH@("`@("`@("`@("!S=VET8V@@*"1S96QE8W0M/F=E="@G='EP92<I*2![
M"B`@("`@("`@("`@(&-A<V4@)W-P:6XG.@H@("`@("`@("`@("`@("`@)'1Y
M<&5?;W!T:6]N(#T@)W1Y<&4](G-P:6XB)SL*("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@8V%S92`G<&]P=7`G.@H@("`@("`@("`@("!D
M969A=6QT.@H@("`@("`@("`@("`@("`@)'1Y<&5?;W!T:6]N(#T@)W1Y<&4]
M(G!O<'5P(B<["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@96-H;R`G/'-E;&5C="`G("X@)'1Y<&5?;W!T:6]N
M("X@)R!N86UE/2)?)R`N("1S96QE8W0M/F=E="@G;F%M92<I("X@)R(^)SL*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!E8VAO("<\<V5L96-T(&YA
M;64](E\G("X@)'-E;&5C="T^9V5T*"=N86UE)RD@+B`G(CXG.PH@("`@("`@
M('T*"B`@("`@("`@9F]R96%C:"`H)'-E;&5C="T^7V]P=&EO;G,@87,@)'9A
M;"D@>PH@("`@("`@("`@("!E8VAO("<\;W!T:6]N('9A;'5E/2(G("X@)'9A
M;%LG=F%L=64G72`N("<B/B<@+B`D=&AI<RT^97-C87!E*"1V86Q;)VQA8F5L
M)UTI("X@)SPO;W!T:6]N/B<["B`@("`@("`@?0H@("`@("`@(&5C:&\@)SPO
M<V5L96-T/B<["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E)A9&EO*"8D
M<F%D:6\I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YH87-1=6ER:R@G;W=?
M9W5I7S$N,R<I*2!["B`@("`@("`@("`@("\O($]P96YW879E($=522!E>'1E
M;G-I;VYS(&9O<B!734P@,2XS"B`@("`@("`@("`@('!R:6YT9B@G/'-E;&5C
M="!T>7!E/2)R861I;R(@;F%M93TB7R5S(CXG+"`D<F%D:6\M/F=E="@G;F%M
M92<I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!#;VYV96YT
M:6]N86P@5TU,("AS:6UI;&%R('1O($AO<F1E7TUO8FEL95]S96QE8W0I+@H@
M("`@("`@("`@("!P<FEN=&8H)SQS96QE8W0@;F%M93TB7R5S(CXG+"`D<F%D
M:6\M/F=E="@G;F%M92<I*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@
M*"1R861I;RT^7V)U='1O;G,@87,@)'9A;"D@>PH@("`@("`@("`@("!P<FEN
M=&8H)SQO<'1I;VX@=F%L=64](B5S(CXE<SPO;W!T:6]N/B<L"B`@("`@("`@
M("`@("`@("`@("`D=F%L6R=V86QU92==+"`D=&AI<RT^97-C87!E*"1V86Q;
M)VQA8F5L)UTI*3L*("`@("`@("!]"@H@("`@("`@(&5C:&\@)SPO<V5L96-T
M/B<["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<D-H96-K8F]X*"8D8VAE
M8VMB;W@I"B`@("!["B`@("`@("`@<')I;G1F*"<\<V5L96-T(&YA;64](E\E
M<R(@;75L=&EP;&4](G1R=64B/B<L("1C:&5C:V)O>"T^9V5T*"=N86UE)RDI
M.PH@("`@("`@('!R:6YT9B@G/&]P=&EO;B!V86QU93TB)7,B/B5S/"]O<'1I
M;VX^/"]S96QE8W0^)RP*("`@("`@("`@("`@("`@)&-H96-K8F]X+3YG970H
M)W9A;'5E)RDL("1T:&ES+3YE<V-A<&4H)&-H96-K8F]X+3YG970H)VQA8F5L
M)RDI*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R4W5B;6ET*"8D<W5B
M;6ET*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^:&%S475I<FLH)V]W7V=U
M:5\Q+C,G*2D@>PH@("`@("`@("`@("`O+R!#<F5A=&4@/&1O('1Y<&4](F)U
M='1O;B(^('-E<75E;F-E(&9O<B!/<&5N=V%V92!'54D*("`@("`@("`@("`@
M+R\@97AT96YS:6]N<R!734P@,2XS+@H@("`@("`@("`@("!P<FEN=&8H)SQD
M;R!T>7!E/2)B=71T;VXB(&QA8F5L/2(E<R(^)RP*("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YE<V-A<&4H)'-U8FUI="T^9V5T*"=L86)E;"<I*2D["B`@
M("`@("`@("`@("1T86<@/2`G9&\G.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("\O($-R96%T92`\86YC:&]R/B!S97%U96YC92!I;B!N;W)M86P@
M5TU,+@H@("`@("`@("`@("!P<FEN=&8H)SQA;F-H;W(@=&ET;&4](B5S(CXE
M<R<L"B`@("`@("`@("`@("`@("`@("`D=&AI<RT^97-C87!E*"1S=6)M:70M
M/F=E="@G;&%B96PG*2DL"B`@("`@("`@("`@("`@("`@("`D=&AI<RT^97-C
M87!E*"1S=6)M:70M/F=E="@G;&%B96PG*2DI.PH@("`@("`@("`@("`D=&%G
M(#T@)V%N8VAO<B<["B`@("`@("`@?0H*("`@("`@("!I9B`H)'-U8FUI="T^
M7V9O<FTM/F=E="@G;65T:&]D)RD@/3T@)W!O<W0G*2!["B`@("`@("`@("`@
M('!R:6YT9B@G/&=O(&AR968](B5S(B!M971H;V0](G!O<W0B/B<L($AO<F1E
M.CIU<FPH)'-U8FUI="T^7V9O<FTM/F=E="@G=7)L)RDI*3L*"B`@("`@("`@
M("`@("\O(%9A;'5E(&9O<B!T:&ES('-U8FUI="!E;&5M96YT+"!O;FQY(&EF
M(&YO;BUE;7!T>2!N86UE+@H@("`@("`@("`@("!I9B`H)'-U8FUI="T^9V5T
M*"=N86UE)RDI('L*("`@("`@("`@("`@("`@('!R:6YT9B@G/'!O<W1F:65L
M9"!N86UE/2(E<R(@=F%L=64](B5S(B\^)RP@)'-U8FUI="T^9V5T*"=N86UE
M)RDL("1T:&ES+3YE<V-A<&4H)'-U8FUI="T^9V5T*"=L86)E;"<I*2D["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1D969A=6QT<R`]("1S=6)M:70M
M/E]F;W)M+3YG971$969A=6QT<R@I.PH@("`@("`@("`@("!F;W)E86-H("@D
M9&5F875L=',@87,@)&0I('L*("`@("`@("`@("`@("`@(&EF("AA<G)A>5]K
M97E?97AI<W1S*"=H:61D96XG+"`D9"DI('L*("`@("`@("`@("`@("`@("`@
M("!P<FEN=&8H)SQP;W-T9FEE;&0@;F%M93TB)7,B('9A;'5E/2(E<R(O/B<L
M("1D6R=N86UE)UTL("1T:&ES+3YE<V-A<&4H)&1;)W9A;'5E)UTI*3L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@<')I
M;G1F*"<\<&]S=&9I96QD(&YA;64](B5S(B!V86QU93TB)"A?)7,I(B\^)RP@
M)&1;)VYA;64G72P@)&1;)VYA;64G72D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!3
M=&%R="!W:71H('1H92!V86QU92!F;W(@=&AI<R!S=6)M:70@96QE;65N="X*
M("`@("`@("`@("`@)'%U97)Y7W-T<FEN9R`]("1S=6)M:70M/F=E="@G;F%M
M92<I("X@)STG("X@)'1H:7,M/F5S8V%P92@D<W5B;6ET+3YG970H)VQA8F5L
M)RDI("X@)R9A;7`[)SL*"B`@("`@("`@("`@("1G971V87)S(#T@)'-U8FUI
M="T^7V9O<FTM/F=E=$=E=%9A<G,H*3L*("`@("`@("`@("`@9F]R96%C:"`H
M)&=E='9A<G,@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@)'%U97)Y7W-T
M<FEN9R`N/2`D=F%L("X@)STD*%\G("X@)'9A;"`N("<I)F%M<#LG.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!I9B`H<W5B<W1R*"1Q=65R>5]S=')I
M;F<L("TU*2`]/2`G)F%M<#LG*2!["B`@("`@("`@("`@("`@("`D<75E<GE?
M<W1R:6YG(#T@<W5B<W1R*"1Q=65R>5]S=')I;F<L(#`L('-T<FQE;B@D<75E
M<GE?<W1R:6YG*2`M(#4I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!P
M<FEN=&8H)SQG;R!H<F5F/2(E<S\E<R(^)RP@)'-U8FUI="T^7V9O<FTM/F=E
M="@G=7)L)RDL("1Q=65R>5]S=')I;F<I.PH@("`@("`@('T*"B`@("`@("`@
M96-H;R`B/"]G;SX\+R1T86<^(CL*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N
M9&5R5&%B;&4H)B1T86)L92D*("`@('L*("`@("`@("`O+R!#;W5N="!M87AI
M;75M(&YU;6)E<B!O9B!C;VQU;6YS(&EN('1A8FQE+@H@("`@("`@("1M87@@
M/2`P.PH@("`@("`@(&9O<F5A8V@@*"1T86)L92T^7W)O=W,@87,@)')O=RD@
M>PH@("`@("`@("`@("`D;6%X(#T@;6%X*"1M87@L("1R;W<M/F=E=$-O;'5M
M;D-O=6YT*"DI.PH@("`@("`@('T*("`@("`@("!P<FEN=&8H)SQT86)L92!C
M;VQU;6YS/2(E9"(^)RP@)&UA>"D["@H@("`@("`@('!A<F5N=#HZ7W)E;F1E
M<E1A8FQE*"1T86)L92D["@H@("`@("`@("\O(%1E<FUI;F%T92!T86)L92X*
M("`@("`@("!E8VAO("<\+W1A8FQE/B<["B`@("!]"@H@("`@9G5N8W1I;VX@
M7W)E;F1E<E!H;VYE*"8D<&AO;F4I"B`@("!["B`@("`@("`@)'1I=&QE(#T@
M)'!H;VYE+3YG970H)W1I=&QE)RD["B`@("`@("`@)'1I=&QE7V]P=&EO;B`]
M("@D=&ET;&4@/R!S<')I;G1F*"<@=&ET;&4](B5S(B<L("1T:&ES+3YE<V-A
M<&4H)'1I=&QE*2D@.B`G)RD["@H@("`@("`@('!R:6YT9B@G/&$E<R!H<F5F
M/2)W=&%I.B\O=W`O;6,[)7,B/B5S/"]A/B<L("1T:71L95]O<'1I;VXL"B`@
M("`@("`@("`@("`@('-T<E]R97!L86-E*"<K)RP@)R4R0B<L("1P:&]N92T^
M9V5T*"=N=6UB97(G*2DL("1P:&]N92T^9V5T*"=L86)E;"<I*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!?<F5N9&5R4G5L92@F)')U;&4I"B`@("!["B`@("`@
M("`@:68@*"1T:&ES+3YH87-1=6ER:R@G;W=?9W5I7S$N,R<I*2!["B`@("`@
M("`@("`@("\O(%=!4"!D979I8V4@86-C97!T<R!/<&5N=V%V92!'54D@97AT
M96YS:6]N<R!F;W(@5TU,(#$N,PH@("`@("`@("`@("`D=VED=&@@/2`D<G5L
M92T^9V5T*"=W:61T:"<I.PH@("`@("`@("`@("`D<VEZ92`]("1R=6QE+3YG
M970H)W-I>F4G*3L*"B`@("`@("`@("`@(&5C:&\@)SQH<B<@+B`H)'=I9'1H
M(#\@)R!W:61T:#TB)R`N("1W:61T:"`N("<B)R`Z("<G*2`N("@D<VEZ92`_
M("<@<VEZ93TB)R`N("1S:7IE("X@)R(G(#H@)R<I("X@)R`O/B<["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@5T%0(&1E=FEC92!D;V5S(&YO
M="!U;F1E<G-T86YD(#QH<B`O/B!T86=S+@H@("`@("`@("`@("`O+R`]/3X@
M9')A=R!S;VUE(&YU;6)E<B!O9B!H>7!H96YS('1O(&-R96%T92!A(')U;&4*
M("`@("`@("`@("`@96-H;R`G+2TM+2TM+2TM+3QB<B`O/B<["B`@("`@("`@
M?0H@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TUO8FEL
M92]296YD97)E<BYP:'``````````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q
M,3(P-@`Q,#4Q-30S,S<T-@`P,C,Q-34`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J($AO<F1E7TUO8FEL
M95]296YD97)E<CHZ(&9R86UE=V]R:R!F;W(@;6]B:6QE(&1E=FEC92!M87)K
M=7`*("H@<F5N9&5R97)S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-;V)I
M;&4O36]B:6QE+U)E;F1E<F5R+G!H<"QV(#$N,34N,3`N."`R,#`V+S`Q+S`Q
M(#(Q.C(X.C(V(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D
M92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D
M95]-;V)I;&4*("HO"F-L87-S($AO<F1E7TUO8FEL95]296YD97)E<B!E>'1E
M;F1S($AO<F1E7TUO8FEL92!["@H@("`@=F%R("1?8G)O=W-E<CL*"B`@("!F
M=6YC=&EO;B!(;W)D95]-;V)I;&5?4F5N9&5R97(H)&)R;W=S97(@/2!N=6QL
M*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1B<F]W<V5R*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7V)R;W=S97(@/2`F;F5W($)R;W=S97(H*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V)R;W=S97(@/2`D
M8G)O=W-E<CL*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@:7-"<F]W
M<V5R*"1A9V5N="D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]B<F]W
M<V5R+3YI<T)R;W=S97(H)&%G96YT*3L*("`@('T*"B`@("!F=6YC=&EO;B!H
M87-1=6ER:R@D<75I<FLI"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M8G)O=W-E<BT^:&%S475I<FLH)'%U:7)K*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E;F1E<B!A;GD@2&]R9&5?36]B:6QE7V5L96UE;G0@;V)J96-T+B!,
M;V]K<R!F;W(@=&AE"B`@("`@*B!A<'!R;W!R:6%T92!R96YD97)I;F<@9G5N
M8W1I;VX@:6X@=&AE(')E;F1E<F5R.R!I9B!T:&5R92!I<VXG=`H@("`@("H@
M;VYE+"!W92!I9VYO<F4@=&AI<R!E;&5M96YT+@H@("`@("H*("`@("`J($!P
M87)A;2!(;W)D95]-;V)I;&5?96QE;65N="`D96QE;65N="`@5&AE(&5L96UE
M;G0@=&\@<F5N9&5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97)%;&5M
M96YT*"8D96QE;65N="D*("`@('L*("`@("`@("`D9G5N8R`]("=?<F5N9&5R
M)R`N('5C9FER<W0H<W1R7W)E<&QA8V4H)VAO<F1E7VUO8FEL95\G+"`G)RP@
M<W1R=&]L;W=E<BAG971?8VQA<W,H)&5L96UE;G0I*2DI.PH@("`@("`@(&EF
M("AM971H;V1?97AI<W1S*"1T:&ES+"`D9G5N8RDI('L*("`@("`@("`@("`@
M)'1H:7,M/B1F=6YC*"1E;&5M96YT*3L*("`@("`@("!]"B`@("!]"@H@("`@
M9G5N8W1I;VX@7W)E;F1E<D)L;V-K*"8D8FQO8VLI"B`@("!["B`@("`@("`@
M:68@*&-O=6YT*"1B;&]C:RT^7V5L96UE;G1S*2D@>PH@("`@("`@("`@("!E
M8VAO("<\<#XG.PH@("`@("`@("`@("!F;W)E86-H("@D8FQO8VLM/E]E;&5M
M96YT<R!A<R`D8FQO8VM%;&5M96YT*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^<F5N9&5R16QE;65N="@D8FQO8VM%;&5M96YT*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!E8VAO("(\+W`^7&XB.PH@("`@("`@('T*("`@('T*
M"B`@("!F=6YC=&EO;B!?<F5N9&5R1F]R;2@F)&9O<FTI"B`@("!["B`@("`@
M("`@9F]R96%C:"`H)&9O<FTM/E]E;&5M96YT<R!A<R`D9F]R;45L96UE;G0I
M('L*("`@("`@("`@("`@)'1H:7,M/G)E;F1E<D5L96UE;G0H)&9O<FU%;&5M
M96YT*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E1A
M8FQE*"8D=&%B;&4I"B`@("!["B`@("`@("`@9F]R96%C:"`H)'1A8FQE+3Y?
M<F]W<R!A<R`D<F]W*2!["B`@("`@("`@("`@("1T:&ES+3Y?<F5N9&5R4F]W
M*"1R;W<I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R
M4F]W*"8D<F]W*0H@("`@>PH@("`@("`@(&5C:&\@)SQT<CXG.PH@("`@("`@
M(&9O<F5A8V@@*"1R;W<M/E]C;VQU;6YS(&%S("1C;VQU;6XI('L*("`@("`@
M("`@("`@96-H;R`G/'1D/B<["B`@("`@("`@("`@("\O($-A;&P@8W)E871E
M(&9U;F-T:6]N(&9O<B!E86-H(&-E;&QE;&5M96YT('1H870@:7,@80H@("`@
M("`@("`@("`O+R!(;W)D95]-;V)I;&4@;V)J96-T+@H@("`@("`@("`@("!I
M9B`H(6ES7VYU;&PH)&-O;'5M;BDI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3YR96YD97)%;&5M96YT*"1C;VQU;6XI.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&5C:&\@)SPO=&0^)SL*("`@("`@("!]"B`@("`@("`@96-H;R`B
M/"]T<CY<;B(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R
M971U<FX@82!C;VYC<F5T92!(;W)D95]-;V)I;&5?4F5N9&5R97(@:6YS=&%N
M8V4*("`@("`J(&)A<V5D(&]N("1T>7!E+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'1Y<&4@("`@("!4:&4@:VEN9"!O9B!M87)K=7`@*&AT;6PL
M(&AD;6PL('=M;"D@=V4@=V%N="!T;PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@(&=E;F5R871E+@H@("`@("H@0'!A<F%M($)R;W=S97(@)&)R
M;W=S97(@(%1H92!"<F]W<V5R(&]B:F5C="!T;R!U<V4N"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@("`@02!H87-H(&-O;G1A:6YI;F<@86YY(&]P
M=&EO;G,@9F]R('1H92!R96YD97)E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M($AO<F1E7TUO8FEL95]296YD97)E<B`@5&AE(&YE=VQY(&-R96%T960@8V]N
M8W)E=&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!(
M;W)D95]-;V)I;&5?4F5N9&5R97(@:6YS=&%N8V4L(&]R(&$*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!014%27T5R<F]R(&]B:F5C
M="!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH
M)'1Y<&4L("1B<F]W<V5R(#T@;G5L;"P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@)'1Y<&4@/2!B87-E;F%M92@D='EP92D["@H@("`@("`@
M(&EF("A`9FEL95]E>&ES=',H9&ER;F%M92A?7T9)3$5?7RD@+B`G+U)E;F1E
M<F5R+R<@+B`D='EP92`N("<N<&AP)RDI('L*("`@("`@("`@("`@:6YC;'5D
M95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]296YD97)E<B\G("X@)'1Y
M<&4@+B`G+G!H<"<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@0&EN
M8VQU9&5?;VYC92`G2&]R9&4O36]B:6QE+U)E;F1E<F5R+R<@+B`D='EP92`N
M("<N<&AP)SL*("`@("`@("!]"@H@("`@("`@("1C;&%S<R`]("=(;W)D95]-
M;V)I;&5?4F5N9&5R97)?)R`N("1T>7!E.PH@("`@("`@(&EF("AC;&%S<U]E
M>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D<F5N9&5R97(@/2`F;F5W
M("1C;&%S<R@D8G)O=W-E<BP@)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)')E;F1E<F5R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G0VQA
M<W,@9&5F:6YI=&EO;B!O9B`G("X@)&-L87-S("X@)R!N;W0@9F]U;F0N)RD[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E;F1E<F5R.PH@("`@?0H*
M("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@
M2&]R9&5?36]B:6QE7U)E;F1E<F5R(&EN<W1A;F-E"B`@("`@*B!B87-E9"!O
M;B`D='EP92X@270@=VEL;"!O;FQY(&-R96%T92!A(&YE=R!I;G-T86YC92!I
M9B!N;PH@("`@("H@<F5N9&5R97(@=VET:"!T:&4@<V%M92!P87)A;65T97)S
M(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D='EP92`@("`@(%1H92!K:6YD(&]F(&UA<FMU<"`H:'1M;"P@:&1M;"P@
M=VUL*2!W92!W86YT('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@9V5N97)A=&4N"B`@("`@*B!`<&%R86T@0G)O=W-E<B`D8G)O=W-E<B`@
M5&AE($)R;W=S97(@;V)J96-T('1O('5S92X*("`@("`J($!P87)A;2!A<G)A
M>2`D<&%R86US("`@("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@;W!T:6]N<R!F
M;W(@=&AE(')E;F1E<F5R+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?
M36]B:6QE7U)E;F1E<F5R("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($AO<F1E7TUO
M8FEL95]296YD97)E<B!I;G-T86YC92P@;W(@80H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%!%05)?17)R;W(@;V)J96-T(&]N(&%N
M(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1T>7!E
M+"`D8G)O=W-E<B`](&YU;&PL("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@('-T871I8R`D:6YS=&%N8V5S(#T@87)R87DH*3L*"B`@("`@("`@
M)'-I9VYA='5R92`](&UD-2AS97)I86QI>F4H87)R87DH)'1Y<&4L("1B<F]W
M<V5R+"`D<&%R86US*2DI.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E
M<ULD<VEG;F%T=7)E72DI('L*("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG
M;F%T=7)E72`]("9(;W)D95]-;V)I;&5?4F5N9&5R97(Z.F9A8W1O<GDH)'1Y
M<&4L("1B<F]W<V5R+"`D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]-;V)I;&4N<&AP````````````````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`Q,#<P-S,`,3`U,34T,S,W-3(`,#(Q-#$T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!`<&%C
M:V%G92!(;W)D95]-;V)I;&4*("HO"F-L87-S($AO<F1E7TUO8FEL95]C87)D
M(&5X=&5N9',@2&]R9&5?36]B:6QE7V5L96UE;G0@>PH*("`@('9A<B`D7VYA
M;64["B`@("!V87(@)%]T:71L93L*("`@('9A<B`D7V9O<FT["B`@("!V87(@
M)%]E;&5M96YT<R`](&%R<F%Y*"D["B`@("!V87(@)%]S;V9T:V5Y<R`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&YA;64@("!4:&4@;F%M92!O9B!T:&ES(&-A
M<F0N($-A;B!B92!U<V5D(&EN(&%N8VAO<@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(&QI;FMS+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&ET;&4@
M($EF(&$@<W1R:6YG(&ES('!R;W9I9&5D(&AE<F4L(&ET('=I;&P@8F4@9&ES
M<&QA>65D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:6X@=&AE($A4
M34P@=&ET;&4@8F%R+"!R97-P96-T:79E;'D@<V]M97=H97)E(&]N"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@=&AE(%=!4"!D:7-P;&%Y+B!5<VEN
M9R!A('1I=&QE('EO=2!W:6QL(&YO<FUA;&QY"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@:&%V92!T;R!S<&5N9"!O;F4@;V8@>6]U<B!F97<@;&EN
M97,@;VX@>6]U<B!705`*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!D
M:7-P;&%Y+B!#;VYS:61E<B!T:&%T('-O;64@5T%0('!H;VYE<R]31$LG<R!A
M;F0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!H86YD:&5L9"!D979I
M8V5S(&1O;B=T(&1I<W!L87D@=&AE('1I=&QE(&%T(&%L;"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@2&]R9&5?36]B:6QE7V-A<F0H)&YA;64@/2!N=6QL+"`D
M=&ET;&4@/2!N=6QL*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;F%M92`]("1N
M86UE.PH@("`@("`@("1T:&ES+3Y?=&ET;&4@/2`D=&ET;&4["B`@("!]"@H@
M("`@9G5N8W1I;VX@)F%D9"@F)&5L96UE;G0I"B`@("!["B`@("`@("`@<W1A
M=&EC("1L:6YK<V5T061D960["@H@("`@("`@(&EF("@A:7-?82@D96QE;65N
M="P@)TAO<F1E7TUO8FEL95]E;&5M96YT)RDI('L*("`@("`@("`@("`@)&5R
M<F]R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G26YV86QI9"!E;&5M96YT+B<I.PH@
M("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T@96QS96EF("AI
M<U]A*"1E;&5M96YT+"`G2&]R9&5?36]B:6QE7W1E>'0G*2!\?`H@("`@("`@
M("`@("`@("`@("!I<U]A*"1E;&5M96YT+"`G2&]R9&5?36]B:6QE7W1A8FQE
M)RD@?'P*("`@("`@("`@("`@("`@("`@:7-?82@D96QE;65N="P@)TAO<F1E
M7TUO8FEL95]I;6%G92<I('Q\"B`@("`@("`@("`@("`@("`@(&ES7V$H)&5L
M96UE;G0L("=(;W)D95]-;V)I;&5?;&EN:R<I('Q\"B`@("`@("`@("`@("`@
M("`@(&ES7V$H)&5L96UE;G0L("=(;W)D95]-;V)I;&5?<&AO;F4G*2!\?`H@
M("`@("`@("`@("`@("`@("!I<U]A*"1E;&5M96YT+"`G2&]R9&5?36]B:6QE
M7W)U;&4G*2D@>PH@("`@("`@("`@("`D8FQO8VL@/2`F;F5W($AO<F1E7TUO
M8FEL95]B;&]C:R@D96QE;65N="D["B`@("`@("`@("`@("1T:&ES+3Y?96QE
M;65N='-;72`]("8D8FQO8VL["B`@("`@("`@?2!E;'-E:68@*&ES7V$H)&5L
M96UE;G0L("=(;W)D95]-;V)I;&5?8FQO8VLG*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7V5L96UE;G1S6UT@/2`F)&5L96UE;G0["B`@("`@("`@?2!E;'-E
M:68@*&ES7V$H)&5L96UE;G0L("=(;W)D95]-;V)I;&5?9F]R;2<I*2!["B`@
M("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]F;W)M*2D@>PH@("`@("`@
M("`@("`@("`@)&5R<F]R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G0V%R9',@;6%Y
M(&]N;'D@8V]N=&%I;B!O;F4@1F]R;2!E;&5M96YT+B<I.PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D=&AI<RT^7V5L96UE;G1S6UT@/2`F)&5L96UE;G0["B`@("`@("`@("`@
M("1T:&ES+3Y?9F]R;2`]("8D96QE;65N=#L*("`@("`@("!](&5L<V5I9B`H
M:7-?82@D96QE;65N="P@)TAO<F1E7TUO8FEL95]L:6YK<V5T)RDI('L*("`@
M("`@("`@("`@:68@*"%E;7!T>2@D;&EN:W-E=$%D9&5D*2D@>PH@("`@("`@
M("`@("`@("`@)&5R<F]R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G0V%R9',@;6%Y
M(&]N;'D@8V]N=&%I;B!O;F4@3&EN:W-E="!E;&5M96YT+B<I.PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D8FQO8VL@/2`F;F5W($AO<F1E7TUO8FEL95]B;&]C:R@D96QE;65N
M="D["B`@("`@("`@("`@("1T:&ES+3Y?96QE;65N='-;72`]("8D8FQO8VL[
M"B`@("`@("`@("`@("1L:6YK<V5T061D960@/2!T<G5E.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H
M)U1H:7,@96QE;65N="!M=7-T(&)E(&EN<VED92!A;B!A<'!R;W!R:6%T92!C
M;VYT86EN97(@96QE;65N="XG*3L*("`@("`@("`@("`@<F5T=7)N("1E<G)O
M<CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D96QE;65N=#L*("`@('T*
M"B`@("!F=6YC=&EO;B!S;V9T:V5Y*"1U<FPL("1L86)E;"D*("`@('L*("`@
M("`@("`D=&AI<RT^7W-O9G1K97ES6UT@/2!A<G)A>2@G=7)L)R`]/B`D=7)L
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=L86)E;"<@
M/3X@)&QA8F5L*3L*("`@('T*"GT*"B\J*@H@*B!(;W)D95]-;V)I;&4Z.@H@
M*@H@*B!(;W)D92!!4$D@9F]R(&=E;F5R871I;F<@36]B:6QE(&-O;G1E;G0N
M($EN8VQU9&5S(&YU;65R;W5S('5T:6QI='D*("H@9G5N8W1I;VYS+"!G96YE
M<F%L:7IE9"!E;&5M96YT(&-L87-S97,L(&%N9"!R96YD97)E<G,@9F]R(&UA
M<FMU<`H@*B!L86YG=6%G97,@:6YC;'5D:6YG(%=-3"P@2$1-3"P@86YD($-(
M5$U,+@H@*@H@*B!4:&ES(&-L87-S(&ES('1H92!T;W`@;&5V96P@8VQA<W,@
M;V8@86QL($AO<F1E7TUO8FEL92!C;&%S<V5S+B!9;W5R"B`J('!A9V4@<VAO
M=6QD(&-O;G-I<W0@;V8@97AA8W1L>2!O;F4@2&]R9&5?36]B:6QE(&]B:F5C
M="X@07!P<F]P<FEA=&4*("H@;6%R:W5P("T@26UO9&4L(%=-3"P@2$1-3"P@
M971C+B`M(&ES(&=E;F5R871E9"!B>2!T:&4@87!P<F]P<FEA=&4*("H@<F5N
M9&5R97(@;V)J96-T"B`J"B`J($1O(&YO="!O=F5R<W1U9F8@2&]R9&5?36]B
M:6QE(&]B:F5C=',N(%)E;65M8F5R('1H870@82!L;W0@;V8@5T%0"B`J(&-L
M:65N=',@8V%N;F]T(&AA;F1L92!M;W)E('1H86X@86)O=70@,30P,"!B>71E
M<R!O9B!C;VUP:6QE9"!D871A+@H@*@H@*B!%>&%M<&QE<SH*("H*("H@)&UY
M4&%G92`](&YE=R!(;W)D95]-;V)I;&4H*3L*("H@)&UY4&%G92`](&YE=R!(
M;W)D95]-;V)I;&4H)TUY(%=!4"!P86=E)RD["B`J("1M>5!A9V4@/2!N97<@
M2&]R9&5?36]B:6QE*"<G+"`G8V5N=&5R)RD["B`J"B`J("\O($UO<F4@<W1U
M9F8*("H*("H@)&UY4&%G92T^861D*"1M>51E>'0I.PH@*@H@*B`O+R!-;W)E
M(&ET96US"B`J"B`J("1M>5!A9V4M/G)E;F1E<B@I.PH@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]-;V)I;&4O36]B:6QE+G!H<"QV(#$N,S(N,3`N.2`R,#`V
M+S`V+S(V(#`V.C(W.C(S('-E;'-K>2!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C
M:V%G92!(;W)D95]-;V)I;&4*("HO"F-L87-S($AO<F1E7TUO8FEL92!E>'1E
M;F1S($AO<F1E7TUO8FEL95]C87)D('L*"B`@("!V87(@)%]T:71L93L*("`@
M('9A<B`D7V5L96UE;G1S(#T@87)R87DH*3L*("`@('9A<B`D7V-A<F1S(#T@
M87)R87DH*3L*("`@('9A<B`D7V1E8G5G(#T@9F%L<V4["@H@("`@+R\@1&5C
M:61E('=H971H97(@=&AE('-I;75L871O<B!D979I8V4@:7,@=&\@8F4@=7-E
M9"X@3VYL>2!A9F9E8W1S"B`@("`O+R!(5$U,(&)R;W=S97(@;W5T<'5T+@H@
M("`@=F%R("1?<VEM=6QA=&]R(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1O<@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1I=&QE
M("!)9B!A('-T<FEN9R!I<R!P<F]V:61E9"!H97)E+"!I="!W:6QL(&)E(&1I
M<W!L87EE9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EN('1H92!(
M5$U,('1I=&QE(&)A<BP@<F5S<&5C=&EV96QY('-O;65W:&5R92!O;@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@('1H92!705`@9&ES<&QA>2X@57-I
M;F<@82!T:71L92!Y;W4@=VEL;"!N;W)M86QL>0H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(&AA=F4@=&\@<W!E;F0@;VYE(&]F('EO=7(@9F5W(&QI
M;F5S(&]N('EO=7(@5T%0"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M9&ES<&QA>2X@0V]N<VED97(@=&AA="!S;VUE(%=!4"!P:&]N97,O4T1+)W,@
M86YD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:&%N9&AE;&0@9&5V
M:6-E<R!D;VXG="!D:7-P;&%Y('1H92!T:71L92!A="!A;&PN"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1A9V5N="`@268@<W!E8VEF:65D+"!U<V4@:6YS=&5A
M9"!O9B!(5%107U5315)?04=%3E0N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO
M<F1E7TUO8FEL92@D=&ET;&4@/2!N=6QL+"`D86=E;G0@/2!N=6QL*0H@("`@
M>PH@("`@("`@(&EF("@A:7-?;G5L;"@D=&ET;&4I*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?=&ET;&4@/2`D=&ET;&4["B`@("`@("`@?0H*("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+T)R;W=S97(N<&AP)SL*("`@("`@("`D8G)O
M=W-E<B`]("9"<F]W<V5R.CIS:6YG;&5T;VXH)&%G96YT*3L*"B`@("`@("`@
M:68@*"1B<F]W<V5R+3YH87-&96%T=7)E*"=H=&UL)RDI('L*("`@("`@("`@
M("`@)&UL(#T@)VAT;6PG.PH@("`@("`@('T@96QS96EF("@D8G)O=W-E<BT^
M:&%S1F5A='5R92@G=VUL)RDI('L*("`@("`@("`@("`@)&UL(#T@)W=M;"<[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&UL(#T@)VAT;6PG.PH@
M("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%
M7U\I("X@)R]-;V)I;&4O4F5N9&5R97(N<&AP)SL*("`@("`@("`D=&AI<RT^
M7W)E;F1E<F5R(#T@)DAO<F1E7TUO8FEL95]296YD97)E<CHZ<VEN9VQE=&]N
M*"1M;"P@)&)R;W=S97(I.PH@("`@?0H*("`@(&9U;F-T:6]N("9A9&0H)B1E
M;&5M96YT*0H@("`@>PH@("`@("`@(&EF("AI<U]A*"1E;&5M96YT+"`G2&]R
M9&5?36]B:6QE7V-A<F0G*2D@>PH@("`@("`@("`@("!I9B`H8V]U;G0H)'1H
M:7,M/E]E;&5M96YT<RDI('L*("`@("`@("`@("`@("`@("1E<G)O<B`](%!%
M05(Z.G)A:7-E17)R;W(H)UEO=2!C86YN;W0@;6EX($AO<F1E7TUO8FEL95]C
M87)D<R!A;F0@;W1H97(@96QE;65N=',@870@=&AE(&1E8VL@;&5V96PN)RD[
M"B`@("`@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`D=&AI<RT^7W5S:6YG0V%R9',@/2!T<G5E.PH@("`@
M("`@("`@("`D=&AI<RT^7V-A<F1S6UT@/2`F)&5L96UE;G0["@H@("`@("`@
M("`@("!R971U<FX@)&5L96UE;G0["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@:68@*&-O=6YT*"1T:&ES+3Y?8V%R9',I*2!["B`@("`@("`@("`@
M("`@("`D97)R;W(@/2!014%2.CIR86ES945R<F]R*"=9;W4@8V%N;F]T(&UI
M>"!(;W)D95]-;V)I;&5?8V%R9',@86YD(&]T:&5R(&5L96UE;G1S(&%T('1H
M92!D96-K(&QE=F5L+B<I.PH@("`@("`@("`@("`@("`@<F5T=7)N("1E<G)O
M<CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<F5T=7)N('!A<F5N=#HZ
M861D*"1E;&5M96YT*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!8W1I=F%T97,@=&AE(&)U:6QT+6EN(&1E=FEC92!S:6UU;&%T;W(@;VX@
M8FEG<V-R965N(&)R;W=S97)S+@H@("`@("H@5&AE(&1E=FEC92!S:6UU;&%T
M;W(@:7,@;VYL>2!F=6QL>2UF=6YC=&EO;F%L(&EN($EN=&5R;F5T"B`@("`@
M*B!%>'!L;W)E<BP@8F5C875S92!T:&4@;&%Y;W5T(')E<75I<F5S(&$@<V-R
M;VQL86)L92!T86)L90H@("`@("H@96QE;65N="X@3W1H97(@8G)O=W-E<G,@
M=VEL;"!F86EL('1O('-H;W<@8V]N=&5N="!O;B!P86=E<PH@("`@("H@;&]N
M9V5R('1H86X@82!S:6YG;&4@<V-R965N+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!U<V53:6UU;&%T;W(H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<VEM=6QA
M=&]R(#T@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@=&AE
M('!A9V4@:6X@=&AE(&%P<')O<')I871E(&UA<FMU<"!L86YG=6%G92X@1&5P
M96YD:6YG"B`@("`@*B!O;B!T:&4@<F5N9&5R97(@='EP92P@2%1-3"`H<'5R
M92!(5$U,+"!H86YD:&5L9&9R:65N9&QY($%V86YT1V\*("`@("`J($A434PL
M(&DM;6]D92!C2%1-3"P@34U,*2P@5TU,(&]R($A$34P@8V]D92!I<R!C<F5A
M=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!D:7-P;&%Y*"D*("`@('L*("`@
M("`@("`D=&AI<RT^7W)E;F1E<F5R+3YR96YD97(H)'1H:7,I.PH@("`@?0H*
M?0H*+RHJ"B`J($!P86-K86=E($AO<F1E7TUO8FEL90H@*B\*8VQA<W,@2&]R
M9&5?36]B:6QE7V5L96UE;G0@>PH*("`@(&9U;F-T:6]N($AO<F1E7TUO8FEL
M95]E;&5M96YT*"D*("`@('L*("`@('T*"B`@("!F=6YC=&EO;B!G970H)&%T
M=')I8G5T92D*("`@('L*("`@("`@("`D871T<B`]("=?)R`N("1A='1R:6)U
M=&4["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3XD871T<BDI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3XD871T<CL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("!]"@H@("`@
M9G5N8W1I;VX@<V5T*"1A='1R:6)U=&4L("1V86QU92D*("`@('L*("`@("`@
M("`D871T<B`]("=?)R`N("1A='1R:6)U=&4["B`@("`@("`@)'1H:7,M/B1A
M='1R(#T@)'9A;'5E.PH@("`@?0H*?0H*+RHJ"B`J($!P86-K86=E($AO<F1E
M7TUO8FEL90H@*B\*8VQA<W,@2&]R9&5?36]B:6QE7V9O<FU%;&5M96YT(&5X
M=&5N9',@2&]R9&5?36]B:6QE7V5L96UE;G0@>PH*("`@('9A<B`D7VYA;64[
M"B`@("!V87(@)%]V86QU93L*("`@('9A<B`D7VQA8F5L.PH@("`@=F%R("1?
M<VEZ93L*("`@('9A<B`D7VUA>&QE;F=T:#L*("`@('9A<B`D7W1Y<&4["B`@
M("!V87(@)%]F;W)M870["B`@("!V87(@)%]M;V1E.PH*("`@("\J*@H@("`@
M("H@4V5T(&EN<'5T(&UO9&4O:7-T>6QE(&9O<B!J87!A;F5S92!-34PO:2UM
M;V1E(&1E=FEC97,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6]D
M92`@26YP=70@;6]D92P@;VYE(&]F.@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@)V%L<&AA)R`H9&5F875L="D*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("=K871A:V%N82<*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("=H:7)A9V%N82<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("=N=6UE
M<FEC)PH@("`@("HO"B`@("!F=6YC=&EO;B!S971-;V1E*"1M;V1E*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?;6]D92`]("1M;V1E.PH*("`@("`@("`O+R!-
M87`@=&AE(&UO9&4@:6YT;R!A;B!A<'!R;W!R:6%T92!F;W)M870@<W1R:6YG
M+"!U<V5D(&9O<@H@("`@("`@("\O(%=-3"!A;F0@2$1-3"X@268@82!F;W)M
M870@<W1R:6YG('=A<R!P<F]V:61E9"!E87)L:65R+"!I=`H@("`@("`@("\O
M('=I;&P@8F4@;W9E<G=R:71T96XN"B`@("`@("`@<W=I=&-H("@D;6]D92D@
M>PH@("`@("`@(&-A<V4@)VAI<F%G86YA)SH*("`@("`@("!C87-E("=K871A
M:V%N82<Z"B`@("`@("`@("`@("1T:&ES+3Y?9F]R;6%T(#T@)RI-)SL*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)V%L<&AA)SH*("`@("`@
M("`@("`@)'1H:7,M/E]F;W)M870@/2`G*FTG.PH@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@8V%S92`G;G5M97)I8R<Z"B`@("`@("`@("`@("1T:&ES
M+3Y?9F]R;6%T(#T@)RI.)SL*("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M?0H@("`@?0H*?0H*+RHJ"B`J(%1H:7,@8VQA<W,@9&5F:6YE<R!A(&9O<FT@
M=VET:"!V87)I;W5S('!O<W-I8FQE(&EN<'5T(&5L96UE;G1S+B!4:&4*("H@
M:6YP=70@96QE;65N=',@:&%V92!T;R!B92!D969I;F5D(&%S('-E<&%R871E
M(&]B:F5C=',@86YD(&%R90H@*B!L:6YK960@=&\@=&AE(&9O<FT@=VET:"!A
M('-P96-I86P@(F%D9"(@9G5N8W1I;VXN($]N92!(;W)D95]-;V)I;&4*("H@
M;V)J96-T(&-A;B!C;VYT86EN(&]N;'D@;VYE($AO<F1E7TUO8FEL95]F;W)M
M(&]B:F5C="X*("H*("H@17AA;7!L97,Z"B`J"B`J("1M>5!A9V4@/2!N97<@
M2&]R9&5?36]B:6QE*"XN+BD["B`J"B`J("1M>49O<FT@/2!N97<@2&]R9&5?
M36]B:6QE7V9O<FTH(B]M>6YE>'1P86=E+G=M;"(I.PH@*B`D;7E497AT(#T@
M;F5W($AO<F1E7TUO8FEL95]T97AT*"XN+BD["B`J("1M>49O<FTM/F%D9"@D
M;7E497AT*3L*("H@)&UY26YP=70@/2!N97<@2&]R9&5?36]B:6QE7VEN<'5T
M*"XN+BD["B`J("1M>49O<FTM/F%D9"@D;7E);G!U="D["B`J("1M>5-U8FUI
M="`](&YE=R!(;W)D95]-;V)I;&5?<W5B;6ET*"XN+BD["B`J("1M>49O<FTM
M/F%D9"@D;7E3=6)M:70I.PH@*@H@*B`D;7E086=E+3YA9&0H)&UY1F]R;2D[
M"B`J"B`J("1M>5!A9V4M/G)E;F1E<B@I.PH@*@H@*B!`<V5E($AO<F1E7TUO
M8FEL95]T97AT"B`J($!S964@2&]R9&5?36]B:6QE7VEM86=E"B`J($!S964@
M2&]R9&5?36]B:6QE7W1A8FQE"B`J($!S964@2&]R9&5?36]B:6QE7VEN<'5T
M"B`J($!S964@2&]R9&5?36]B:6QE7W1E>'1A<F5A"B`J($!S964@2&]R9&5?
M36]B:6QE7W-E;&5C=`H@*B!`<V5E($AO<F1E7TUO8FEL95]R861I;PH@*B!`
M<V5E($AO<F1E7TUO8FEL95]C:&5C:V)O>`H@*B!`<V5E($AO<F1E7TUO8FEL
M95]S=6)M:70*("H@0'-E92!(;W)D95]-;V)I;&5?<G5L90H@*@H@*B!`<&%C
M:V%G92!(;W)D95]-;V)I;&4*("HO"F-L87-S($AO<F1E7TUO8FEL95]F;W)M
M(&5X=&5N9',@2&]R9&5?36]B:6QE7V5L96UE;G0@>PH*("`@('9A<B`D7W5R
M;#L*("`@('9A<B`D7VUE=&AO9#L*("`@('9A<B`D7V5L96UE;G1S(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=7)L("`@("`@($%D9')E<W,@=VAE<F4@=&AE
M('5S97(@:6YP=70@:7,@<V5N="!T;RX*("`@("`J($!P87)A;2!S=')I;F<@
M)&UE=&AO9"`@("`G<&]S="<@*&1E9F%U;'0I(&]R("=G970G+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)'-E<W-I;VX@(%!R97-E<G9E('1H92!S97-I;VX@
M:60@:6X@=&AE(&9O<FT_($1E9F%U;'1S('1O('1R=64N"B`@("`@*B\*("`@
M(&9U;F-T:6]N($AO<F1E7TUO8FEL95]F;W)M*"1U<FPL("1M971H;V0@/2`G
M<&]S="<L("1S97-S:6]N(#T@=')U92D*("`@('L*("`@("`@("`D=&AI<RT^
M7W5R;"`]("1U<FP["B`@("`@("`@)'1H:7,M/E]M971H;V0@/2`D;65T:&]D
M.PH*("`@("`@("!I9B`H)'-E<W-I;VX@)B8@(6%R<F%Y7VME>5]E>&ES=',H
M<V5S<VEO;E]N86UE*"DL("1?0T]/2TE%*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^861D*&YE=R!(;W)D95]-;V)I;&5?:&ED9&5N*'-E<W-I;VY?;F%M92@I
M+"!S97-S:6]N7VED*"DI*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I
M;VX@)F%D9"@F)&9O<FU%;&5M96YT*0H@("`@>PH@("`@("`@(&EF("AI<U]A
M*"1F;W)M16QE;65N="P@)TAO<F1E7TUO8FEL95]S=6)M:70G*2D@>PH@("`@
M("`@("`@("`D9F]R;45L96UE;G0M/E]F;W)M(#T@)B1T:&ES.PH@("`@("`@
M("`@("`D8FQO8VL@/2`F;F5W($AO<F1E7TUO8FEL95]B;&]C:R@D9F]R;45L
M96UE;G0I.PH@("`@("`@("`@("`D=&AI<RT^7V5L96UE;G1S6UT@/2`F)&)L
M;V-K.PH@("`@("`@('T@96QS96EF("AI<U]A*"1F;W)M16QE;65N="P@)TAO
M<F1E7TUO8FEL95]H:61D96XG*2!\?`H@("`@("`@("`@("`@("`@("!I<U]A
M*"1F;W)M16QE;65N="P@)TAO<F1E7TUO8FEL95]B;&]C:R<I*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?96QE;65N='-;72`]("8D9F]R;45L96UE;G0["B`@
M("`@("`@?2!E;'-E:68@*&ES7V$H)&9O<FU%;&5M96YT+"`G2&]R9&5?36]B
M:6QE7V9O<FU%;&5M96YT)RD@?'P*("`@("`@("`@("`@("`@("`@:7-?82@D
M9F]R;45L96UE;G0L("=(;W)D95]-;V)I;&5?=&5X="<I('Q\"B`@("`@("`@
M("`@("`@("`@(&ES7V$H)&9O<FU%;&5M96YT+"`G2&]R9&5?36]B:6QE7W1A
M8FQE)RD@?'P*("`@("`@("`@("`@("`@("`@:7-?82@D9F]R;45L96UE;G0L
M("=(;W)D95]-;V)I;&5?<G5L92<I('Q\"B`@("`@("`@("`@("`@("`@(&ES
M7V$H)&9O<FU%;&5M96YT+"`G2&]R9&5?36]B:6QE7VEM86=E)RDI('L*("`@
M("`@("`@("`@)&)L;V-K(#T@)FYE=R!(;W)D95]-;V)I;&5?8FQO8VLH)&9O
M<FU%;&5M96YT*3L*("`@("`@("`@("`@)'1H:7,M/E]E;&5M96YT<UM=(#T@
M)B1B;&]C:SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D97)R;W(@
M/2!014%2.CIR86ES945R<F]R*"=3<&5C:69I960@96QE;65N="!C86YN;W0@
M8F4@:6YS:61E(&$@9F]R;2XG*3L*("`@("`@("`@("`@<F5T=7)N("1E<G)O
M<CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9F]R;45L96UE;G0["B`@
M("!]"@H@("`@9G5N8W1I;VX@9V5T1&5F875L=',H*0H@("`@>PH@("`@("`@
M("1D969A=6QT<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M
M/E]E;&5M96YT<R!A<R`D=F%L*2!["B`@("`@("`@("`@('-W:71C:"`H<W1R
M=&]L;W=E<BAG971?8VQA<W,H)'9A;"DI*2!["B`@("`@("`@("`@(&-A<V4@
M)VAO<F1E7VUO8FEL95]H:61D96XG.@H@("`@("`@("`@("`@("`@)&1E9F%U
M;'1S6UT@/2!A<G)A>2@G;F%M92<@/3X@)'9A;"T^9V5T*"=N86UE)RDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V86QU92<@/3X@
M)'9A;"T^9V5T*"=V86QU92<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G:&ED9&5N)R`]/B!T<G5E*3L*("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G:&]R9&5?;6]B:6QE7V)L;V-K
M)SH*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V86PM/E]E;&5M96YT<R!A
M<R`D8G9A;"D@>PH@("`@("`@("`@("`@("`@("`@('-W:71C:"`H<W1R=&]L
M;W=E<BAG971?8VQA<W,H)&)V86PI*2D@>PH@("`@("`@("`@("`@("`@("`@
M(&-A<V4@)VAO<F1E7VUO8FEL95]C:&5C:V)O>"<Z"B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@D8G9A;"T^:7-#:&5C:V5D*"DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1D969A=6QT<UM=(#T@87)R87DH)VYA;64G
M(#T^("1B=F%L+3YG970H)VYA;64G*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9A;'5E)R`]/B`D8G9A;"T^
M9V5T*"=V86QU92<I*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`@
M("`@8V%S92`G:&]R9&5?;6]B:6QE7VEN<'5T)SH*("`@("`@("`@("`@("`@
M("`@("!C87-E("=H;W)D95]M;V)I;&5?=&5X=&%R96$G.@H@("`@("`@("`@
M("`@("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL95]S96QE8W0G.@H@("`@("`@
M("`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL95]R861I;R<Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("1D969A=6QT<UM=(#T@87)R87DH)VYA;64G
M(#T^("1B=F%L+3YG970H)VYA;64G*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G=F%L=64G(#T^("1B=F%L+3YG970H
M)W9A;'5E)RDI.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@("`@("`@("`@8V%S92`G:&]R9&5?;6]B:6QE7VAI9&1E;B<Z
M"B`@("`@("`@("`@("`@("`@("`@("`@("1D969A=6QT<UM=(#T@87)R87DH
M)VYA;64G(#T^("1B=F%L+3YG970H)VYA;64G*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=F%L=64G(#T^("1B=F%L
M+3YG970H)W9A;'5E)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VAI9&1E;B<@/3X@=')U92D["B`@("`@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@("`@("!C87-E
M("=H;W)D95]M;V)I;&5?=&%B;&4G.@H@("`@("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D8G9A;"T^7W)O=W,@87,@)')O=RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)')O=RT^7V-O;'5M;G,@87,@
M)&-O;"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-W:71C
M:"`H<W1R=&]L;W=E<BAG971?8VQA<W,H)&-O;"DI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8V%S92`G:&]R9&5?;6]B:6QE7V-H96-K
M8F]X)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"1C;VPM/FES0VAE8VME9"@I*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9&5F875L='-;72`](&%R<F%Y*"=N86UE)R`]
M/B`D8G9A;"T^9V5T*"=N86UE)RDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V86QU92<@
M/3X@)&)V86PM/F=E="@G=F%L=64G*2D["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&-A<V4@)VAO<F1E7VUO8FEL95]I;G!U="<Z"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8V%S92`G:&]R9&5?;6]B:6QE7W1E>'1A<F5A
M)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C87-E("=H;W)D
M95]M;V)I;&5?<V5L96-T)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!C87-E("=H;W)D95]M;V)I;&5?<F%D:6\G.@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9&5F875L='-;72`](&%R<F%Y*"=N
M86UE)R`]/B`D8G9A;"T^9V5T*"=N86UE)RDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9A;'5E
M)R`]/B`D8G9A;"T^9V5T*"=V86QU92<I*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL95]H:61D96XG.@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5F875L='-;72`]
M(&%R<F%Y*"=N86UE)R`]/B`D8G9A;"T^9V5T*"=N86UE)RDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W9A;'5E)R`]/B`D8G9A;"T^9V5T*"=V86QU92<I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=H:61D96XG(#T^('1R=64I.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D9&5F875L=',["B`@("!]"@H@("`@9G5N8W1I
M;VX@9V5T1V5T5F%R<R@I"B`@("!["B`@("`@("`@+R\@1&5T97)M:6YE(&%L
M;"!E;&5M96YT<R!T:&%T(&AA=F4@=&\@8F4@<W5B;6ET=&5D+@H@("`@("`@
M("1G971V87)S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^
M7V5L96UE;G1S(&%S("1V86PI('L*("`@("`@("`@("`@<W=I=&-H("AS=')T
M;VQO=V5R*&=E=%]C;&%S<R@D=F%L*2DI('L*("`@("`@("`@("`@8V%S92`G
M:&]R9&5?;6]B:6QE7V)L;V-K)SH*("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1V86PM/E]E;&5M96YT<R!A<R`D8G9A;"D@>PH@("`@("`@("`@("`@("`@
M("`@('-W:71C:"`H<W1R=&]L;W=E<BAG971?8VQA<W,H)&)V86PI*2D@>PH@
M("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL95]I;G!U="<Z
M"B`@("`@("`@("`@("`@("`@("`@8V%S92`G:&]R9&5?;6]B:6QE7VAI9&1E
M;B<Z"B`@("`@("`@("`@("`@("`@("`@8V%S92`G:&]R9&5?;6]B:6QE7W1E
M>'1A<F5A)SH*("`@("`@("`@("`@("`@("`@("!C87-E("=H;W)D95]M;V)I
M;&5?<V5L96-T)SH*("`@("`@("`@("`@("`@("`@("!C87-E("=H;W)D95]M
M;V)I;&5?8VAE8VMB;W@G.@H@("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO
M<F1E7VUO8FEL95]R861I;R<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1G
M971V87)S6UT@/2`D8G9A;"T^9V5T*"=N86UE)RD["B`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@("`@("!C87-E("=H
M;W)D95]M;V)I;&5?=&%B;&4G.@H@("`@("`@("`@("`@("`@("`@("`@("!F
M;W)E86-H("@D8G9A;"T^7W)O=W,@87,@)')O=RD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)')O=RT^7V-O;'5M;G,@87,@)&-O
M;"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-W:71C:"`H
M<W1R=&]L;W=E<BAG971?8VQA<W,H)&-O;"DI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8V%S92`G:&]R9&5?;6]B:6QE7VEN<'5T)SH*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C87-E("=H;W)D95]M
M;V)I;&5?:&ED9&5N)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!C87-E("=H;W)D95]M;V)I;&5?=&5X=&%R96$G.@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL95]S96QE8W0G
M.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E
M7VUO8FEL95]C:&5C:V)O>"<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8V%S92`G:&]R9&5?;6]B:6QE7W)A9&EO)SH*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&=E='9A<G-;72`]("1C;VPM/F=E
M="@G;F%M92<I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D9V5T=F%R<SL*("`@('T*"GT*"B\J*@H@*B!4:&ES(&-L87-S
M(&AO;&1S('1E>'0M;&5V96P@96QE;65N=',@9F]R('5S92!I;B!(;W)D95]-
M;V)I;&4@;W(*("H@2&]R9&5?36]B:6QE7V9O<FT@;V)J96-T<RX*("H*("H@
M17AA;7!L97,Z"B`J"B`J("1B;&]C:R`](&YE=R!(;W)D95]-;V)I;&5?8FQO
M8VLH(DAE;&QO(%=!4"$B*3L*("H@)'1E>'0@/2!N97<@2&]R9&5?36]B:6QE
M7W1E>'0H(E=E;&-O;64@=&\@2&]R9&5?36]B:6QE(BP@)V(G*3L*("H@)&)L
M;V-K+3YA9&0H)'1E>'0I.PH@*@H@*B!`<V5E($AO<F1E7TUO8FEL90H@*B!`
M<V5E($AO<F1E7TUO8FEL95]F;W)M"B`J"B`J($!P86-K86=E($AO<F1E7TUO
M8FEL90H@*B\*8VQA<W,@2&]R9&5?36]B:6QE7V)L;V-K(&5X=&5N9',@2&]R
M9&5?36]B:6QE7V5L96UE;G0@>PH*("`@('9A<B`D7V5L96UE;G1S(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@
M("`J($!P87)A;2!M:7AE9"`D96QE;65N=',@($%N>2!E;&5M96YT<R`H82!S
M:6YG;&4@;VYE(&]R(&%N(&%R<F%Y*2!T;R!F:6QL('1H:7,@8FQO8VL@=VET
M:"X*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?36]B:6QE7V)L;V-K*"8D
M96QE;65N=',I"B`@("!["B`@("`@("`@:68@*"%I<U]N=6QL*"1E;&5M96YT
M<RDI('L*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D96QE;65N=',I*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^861D*"1E;&5M96YT<RD["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D96QE
M;65N=',@87,@)&5L96UE;G0I('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^861D*"1E;&5M96YT*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B`F861D*"8D96QE
M;65N="D*("`@('L*("`@("`@("!I9B`H(6ES7V$H)&5L96UE;G0L("=(;W)D
M95]-;V)I;&5?96QE;65N="<I*2!["B`@("`@("`@("`@("1E<G)O<B`](%!%
M05(Z.G)A:7-E17)R;W(H)TEN=F%L:60@96QE;65N="XG*3L*("`@("`@("!]
M(&5L<V5I9B`H:7-?82@D96QE;65N="P@)TAO<F1E7TUO8FEL95]T97AT)RD@
M?'P*("`@("`@("`@("`@("`@("`@:7-?82@D96QE;65N="P@)TAO<F1E7TUO
M8FEL95]T86)L92<I('Q\"B`@("`@("`@("`@("`@("`@(&ES7V$H)&5L96UE
M;G0L("=(;W)D95]-;V)I;&5?:6UA9V4G*2!\?`H@("`@("`@("`@("`@("`@
M("!I<U]A*"1E;&5M96YT+"`G2&]R9&5?36]B:6QE7V9O<FU%;&5M96YT)RD@
M?'P*("`@("`@("`@("`@("`@("`@:7-?82@D96QE;65N="P@)TAO<F1E7TUO
M8FEL95]L:6YK)RD@?'P*("`@("`@("`@("`@("`@("`@:7-?82@D96QE;65N
M="P@)TAO<F1E7TUO8FEL95]L:6YK<V5T)RD@?'P*("`@("`@("`@("`@("`@
M("`@:7-?82@D96QE;65N="P@)TAO<F1E7TUO8FEL95]P:&]N92<I('Q\"B`@
M("`@("`@("`@("`@("`@(&ES7V$H)&5L96UE;G0L("=(;W)D95]-;V)I;&5?
M<G5L92<I*2!["B`@("`@("`@("`@("1T:&ES+3Y?96QE;65N='-;72`]("8D
M96QE;65N=#L*("`@("`@("`@("`@<F5T=7)N("1E;&5M96YT.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1E<G)O<B`](%!%05(Z.G)A:7-E17)R
M;W(H)U1H92!E;&5M96YT(&ES(&YO="!A;&QO=V5D(&EN<VED92!A(&)L;V-K
M+B<I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@?0H*
M?0H*+RHJ"B`J(%1H:7,@8VQA<W,@:6YS97)T<R!P;&%I;B!T97AT(&EN=&\@
M82!(;W)D95]-;V)I;&5?8FQO8VL@;W(@80H@*B!(;W)D95]-;V)I;&5?<F]W
M(&]B:F5C="X*("H*("H@17AA;7!L97,Z"B`J"B`J("1M>51E>'0Q(#T@;F5W
M($AO<F1E7TUO8FEL95]T97AT*")(96QL;R!705`A(BD["B`J("1M>51E>'0R
M(#T@;F5W($AO<F1E7TUO8FEL95]T97AT*")796QC;VUE('1O($AO<F1E7TUO
M8FEL92(L("=B)RD["B`J("1M>51E>'0S(#T@;F5W($AO<F1E7TUO8FEL95]T
M97AT*")';V]D($UO<FYI;F<B+"!A<G)A>2@G8B<L("=B:6<G*2D["B`J"B`J
M($!S964@2&]R9&5?36]B:6QE7V)L;V-K"B`J($!S964@2&]R9&5?36]B:6QE
M7W)O=PH@*@H@*B!`<&%C:V%G92!(;W)D95]-;V)I;&4*("HO"F-L87-S($AO
M<F1E7TUO8FEL95]T97AT(&5X=&5N9',@2&]R9&5?36]B:6QE7V5L96UE;G0@
M>PH*("`@('9A<B`D7W1E>'0@/2`G)SL*("`@('9A<B`D7V%T=')I8G5T97,@
M/2!A<G)A>2@I.PH@("`@=F%R("1?;&EN96)R96%K<R`](&9A;'-E.PH*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J($!P87)A;2!S=')I;F<@
M)'1E>'0@("`@("`@5&AE('1E>'0@8V]N=&5N="!O9B!T:&4@96QE;65N="X*
M("`@("`J($!P87)A;2!A<G)A>2`D871T<FEB=71E<R`@5&5X="!A='1R:6)U
M=&5S+B!!;GD@;V8Z"B`@("`@*B`@("=B)PH@("`@("H@("`G=2<*("`@("`J
M("`@)VDG"B`@("`@*B`@("=B:6<G"B`@("`@*B`@("=S;6%L;"<*("`@("`J
M+PH@("`@9G5N8W1I;VX@2&]R9&5?36]B:6QE7W1E>'0H)'1E>'0L("1A='1R
M:6)U=&5S(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W1E>'0@
M/2`D=&5X=#L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1A='1R:6)U=&5S*2D@
M>PH@("`@("`@("`@("`D871T<FEB=71E<R`](&%R<F%Y*"1A='1R:6)U=&5S
M*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]A='1R:6)U=&5S(#T@)&%T
M=')I8G5T97,["B`@("!]"@I]"@HO*BH*("H@5&AI<R!C;&%S<R!A;&QO=W,@
M=&\@:6YS97)T(&)I=&UA<"!I;6%G97,@:6YT;R!A($AO<F1E7TUO8FEL95]B
M;&]C:RP*("H@2&]R9&5?36]B:6QE7V9O<FT@;W(@2&]R9&5?36]B:6QE7W)O
M=R!O8FIE8W0N"B`J"B`J($5X86UP;&5S.@H@*@H@*B`D:6UA9V4@/2!N97<@
M2&]R9&5?36]B:6QE7VEM86=E*"<O<&%T:"]T;R]I;6%G92YW8FUP)RP*("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G:&5I9VAT
M)R`]/B`Q,#`L("=W:61T:"<@/3X@,3`P*2D["B`J"B`J($!S964@2&]R9&5?
M36]B:6QE7V)L;V-K"B`J($!S964@2&]R9&5?36]B:6QE7V9O<FT*("H@0'-E
M92!(;W)D95]-;V)I;&5?<F]W"B`J"B`J($!P86-K86=E($AO<F1E7TUO8FEL
M90H@*B\*8VQA<W,@2&]R9&5?36]B:6QE7VEM86=E(&5X=&5N9',@2&]R9&5?
M36]B:6QE7V5L96UE;G0@>PH*("`@('9A<B`D7W-R8R`]("<G.PH@("`@=F%R
M("1?871T<FEB=71E<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS
M=')U8W1O<@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W)C("`@("`@("!4:&4@
M<V]U<F-E(&QO8V%T:6]N(&]F('1H92!I;6%G92X*("`@("`J($!P87)A;2!A
M<G)A>2`D871T<FEB=71E<R`@26UA9V4@871T<FEB=71E<RX@06YY(&]F.@H@
M("`@("H@("`G86QI9VXG"B`@("`@*B`@("=A;'0G"B`@("`@*B`@("=H96EG
M:'0G"B`@("`@*B`@("=H<W!A8V4G"B`@("`@*B`@("=V<W!A8V4G"B`@("`@
M*B`@("=W:61T:"<*("`@("`J("`@)V-L87-S)PH@("`@("H@("`G:60G"B`@
M("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TUO8FEL95]I;6%G92@D<W)C+"`D
M871T<FEB=71E<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]S
M<F,@/2`D<W)C.PH@("`@("`@("1T:&ES+3Y?871T<FEB=71E<R`]("1A='1R
M:6)U=&5S.PH@("`@?0H*?0H*+RHJ"B`J(%1H:7,@8VQA<W,@86QL;W=S('1O
M(&EN<V5R="!T86)L97,@:6YT;R!A($AO<F1E7TUO8FEL92!O<@H@*B!(;W)D
M95]-;V)I;&5?9F]R;2!O8FIE8W0N"B`J"B`J($5X86UP;&5S.@H@*@H@*B`D
M;7E486)L92`](&YE=R!(;W)D95]-;V)I;&5?=&%B;&4H*3L*("H*("H@)')O
M=S$@/2!N97<@2&]R9&5?36]B:6QE7W)O=R@I.PH@*B`D<F]W,2T^861D*"1I
M;6%G93$I.PH@*B`D<F]W,2T^861D*"1T97AT,2D["B`J("1M>51A8FQE+3YA
M9&0H)')O=S$I.PH@*@H@*B`D<F]W,B`](&YE=R!(;W)D95]-;V)I;&5?<F]W
M*"D["B`J("1R;W<R+3YA9&0H)&EM86=E,BD["B`J("1R;W<R+3YA9&0H)'1E
M>'0R*3L*("H@)&UY5&%B;&4M/F%D9"@D<F]W,BD["B`J"B`J("1M>41E8VLM
M/F%D9"@D;7E486)L92D["B`J"B`J($!S964@2&]R9&5?36]B:6QE"B`J($!S
M964@2&]R9&5?36]B:6QE7V9O<FT*("H@0'-E92!(;W)D95]-;V)I;&5?<F]W
M"B`J"B`J($!P86-K86=E($AO<F1E7TUO8FEL90H@*B\*8VQA<W,@2&]R9&5?
M36]B:6QE7W1A8FQE(&5X=&5N9',@2&]R9&5?36]B:6QE7V5L96UE;G0@>PH*
M("`@('9A<B`D7W)O=W,@/2!A<G)A>2@I.PH@("`@=F%R("1?8F]R9&5R(#T@
M;G5L;#L*("`@('9A<B`D7W!A9&1I;F<@/2!N=6QL.PH@("`@=F%R("1?<W!A
M8VEN9R`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@2&]R9&5?36]B
M:6QE7W)O=R!O8FIE8W0@=&\@2&]R9&5?36]B:6QE7W1A8FQE+@H@("`@("H*
M("`@("`J($!P87)A;2!(;W)D95]-;V)I;&5?<F]W("1R;W<@(%1H92!R;W<@
M;V)J96-T('1O(&%D9"X*("`@("`J+PH@("`@9G5N8W1I;VX@)F%D9"@F)')O
M=RD*("`@('L*("`@("`@("!I9B`H(6ES7V$H)')O=RP@)TAO<F1E7TUO8FEL
M95]R;W<G*2D@>PH@("`@("`@("`@("`D97)R;W(@/2!014%2.CIR86ES945R
M<F]R*"=2;W=S(&UU<W0@8F4@2&]R9&5?36]B:6QE7W)O=R!O8FIE8W1S+B<I
M.PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@
M("`@)'1H:7,M/E]R;W=S6UT@/2`F)')O=SL*("`@("`@("!R971U<FX@)')O
M=SL*("`@('T*"GT*"B\J*@H@*B!4:&ES(&-L87-S(&1E9FEN97,@=&AE(')O
M=W,@=&AA="!A($AO<F1E7TUO8FEL95]T86)L92!O8FIE8W0*("H@8V]N<VES
M=',@;V8N"B`J"B`J($5X86UP;&5S.@H@*@H@*B`D:6UA9V4Q(#T@;F5W($AO
M<F1E7TUO8FEL95]I;6%G92@B;7E?:6UA9V4N=V)M<"(L(")M>5]I;6%G92YP
M;F<B+"`B.BTI(BD["B`J("1T97AT,2`](&YE=R!(;W)D95]-;V)I;&5?=&5X
M="@B;7D@=&5X="(I.PH@*B`D<F]W,2`](&YE=R!(;W)D95]-;V)I;&5?<F]W
M*"D["B`J("1R;W<Q+3YA9&0H)&EM86=E,2D["B`J("1R;W<Q+3YA9&0H*3L*
M("H@)')O=S$M/F%D9"@D=&5X=#$I.PH@*@H@*B!`<V5E($AO<F1E7TUO8FEL
M95]T86)L90H@*B!`<V5E($AO<F1E7TUO8FEL95]T97AT"B`J($!S964@2&]R
M9&5?36]B:6QE7VEM86=E"B`J($!S964@2&]R9&5?36]B:6QE7VQI;FL*("H*
M("H@0'!A8VMA9V4@2&]R9&5?36]B:6QE"B`J+PIC;&%S<R!(;W)D95]-;V)I
M;&5?<F]W(&5X=&5N9',@2&]R9&5?36]B:6QE7V5L96UE;G0@>PH*("`@('9A
M<B`D7V-O;'5M;G,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@061D<R!A
M(&-O;'5M;B!E;&5M96YT('1O(&$@2&]R9&5?36]B:6QE7W)O=R!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0'!A<F%M($AO<F1E7TUO8FEL95]E;&5M96YT("1C
M96QL16QE;65N="`@0V%N(&)E(&$@2&]R9&5?36]B:6QE7W1E>'0*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]B
M:F5C="P@82!(;W)D95]-;V)I;&5?:6UA9V4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]B:F5C="P@82!(;W)D
M95]-;V)I;&5?;&EN:PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@;V)J96-T(&]R(&YU;&PN(%1H92!L871T97(*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(')E<W5L=',@:6X@86X@96UP='D@8V5L;"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@)F%D9"@D8V5L;$5L96UE;G0@/2!N=6QL*0H@("`@>PH@("`@("`@
M(&EF("AI<U]O8FIE8W0H)&-E;&Q%;&5M96YT*2D@>PH@("`@("`@("`@("!I
M9B`H(6ES7V$H)&-E;&Q%;&5M96YT+"`G2&]R9&5?36]B:6QE7W1E>'0G*2`F
M)@H@("`@("`@("`@("`@("`@(6ES7V$H)&-E;&Q%;&5M96YT+"`G2&]R9&5?
M36]B:6QE7VQI;FLG*2`F)@H@("`@("`@("`@("`@("`@(6ES7V$H)&-E;&Q%
M;&5M96YT+"`G2&]R9&5?36]B:6QE7VEM86=E)RDI('L*("`@("`@("`@("`@
M("`@("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)U1A8FQE(&-E;&QS(&-A
M;B!O;FQY(&-O;G1A:6X@=&5X="P@;&EN:W,L(&]R(&EM86=E<RXG*3L*("`@
M("`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)'1H:7,M/E]C;VQU;6YS6UT@/2`F)&-E;&Q%;&5M96YT.PH@
M("`@("`@("`@("!R971U<FX@)&-E;&Q%;&5M96YT.PH@("`@("`@('T@96QS
M96EF("@A:7-?;G5L;"@D8V5L;$5L96UE;G0I*2!["B`@("`@("`@("`@("1T
M(#T@)FYE=R!(;W)D95]-;V)I;&5?=&5X="@D8V5L;$5L96UE;G0I.PH@("`@
M("`@("`@("`D=&AI<RT^7V-O;'5M;G-;72`]("8D=#L*("`@("`@("`@("`@
M<F5T=7)N("1T.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES
M+3Y?8V]L=6UN<UM=(#T@)B1C96QL16QE;65N=#L*("`@("`@("`@("`@<F5T
M=7)N("1C96QL16QE;65N=#L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I
M;VX@9V5T0V]L=6UN0V]U;G0H*0H@("`@>PH@("`@("`@(')E='5R;B!C;W5N
M="@D=&AI<RT^7V-O;'5M;G,I.PH@("`@?0H*?0H*+RHJ"B`J(%1H:7,@8VQA
M<W,@<')O=FED97,@82!T97AT(&EN<'5T(&9I96QD(&EN(&$@2&]R9&5?36]B
M:6QE7V9O<FT@;V)J96-T+@H@*@H@*B!%>&%M<&QE<SH*("H*("H@)&UY26YP
M=70Q(#T@;F5W($AO<F1E7TUO8FEL95]I;G!U="@G8VED)RP@)R<L("=#=7-T
M;VUE<B!)1"<I.PH@*@H@*B`D;7E);G!U=#(@/2!N97<@2&]R9&5?36]B:6QE
M7VEN<'5T*"=C:60G+"`G)RP@)T-U<W1O;65R($E$)RP@)RI.)RD["B`J("1M
M>4EN<'5T,BT^<V5T7W-I>F4H-BD["B`J("1M>4EN<'5T,BT^<V5T7VUA>&QE
M;F=T:"@V*3L*("H*("H@)&UY26YP=70S(#T@;F5W($AO<F1E7TUO8FEL95]I
M;G!U="@G<'<G+"`G)RP@)U!A<W-W;W)D)RP@)RI.)RD["B`J("1M>4EN<'5T
M,RT^<V5T7W-I>F4H."D["B`J("1M>4EN<'5T,RT^<V5T7VUA>&QE;F=T:"@X
M*3L*("H@)&UY26YP=70S+3YS971?='EP92@G<&%S<W=O<F0G*3L*("H*("H@
M0'-E92!(;W)D95]-;V)I;&5?9F]R;0H@*@H@*B!`<&%C:V%G92!(;W)D95]-
M;V)I;&4*("HO"F-L87-S($AO<F1E7TUO8FEL95]I;G!U="!E>'1E;F1S($AO
M<F1E7TUO8FEL95]F;W)M16QE;65N="!["@H@("`@+RHJ"B`@("`@*B!#;VYS
M=')U8W1O<@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@
M5F%R:6%B;&4@:6X@=VAI8V@@=&AE(&EN<'5T(&ES('-E;G0@=&\@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&1E<W1I;F%T:6]N(%523"X*
M("`@("`J($!P87)A;2!S=')I;F<@)'9A;'5E("`@26YI=&EA;"!V86QU92!T
M:&%T('=I;&P@8F4@<')E<V5N=&5D(&EN('1H90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("!I;G!U="!F:65L9"X*("`@("`J($!P87)A;2!S=')I
M;F<@)&QA8F5L("`@1&5S8W)I8F5S('EO=7(@:6YP=70@9FEE;&0@;VX@=&AE
M('-U<F9E<B=S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@('-C<F5E
M;B]D:7-P;&%Y+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T("!);G!U
M="!F;W)M870@8V]D92!A8V-O<F1I;F<@=&\@=&AE(%=!4"!S=&%N9&%R9"X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@06QL;W=S('1H92!705`@
M=7-E<B!C;&EE;G0@92YG+B!T;R!I;G!U="!O;FQY"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@(&1I9VET<R!A;F0@;F\@8VAA<F%C=&5R<RX@3VX@
M86X@2%1-3"!G96YE<F%T960*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@<&%G92!T:&ES(&9O<FUA="!H87,@;F\@<VEG;FEF:6-A;F-E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!(;W)D95]-;V)I;&5?:6YP=70H)&YA;64L("1V
M86QU92P@)&QA8F5L(#T@)R<L("1F;W)M870@/2`G*DTG*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?;F%M92`]("1N86UE.PH@("`@("`@("1T:&ES+3Y?=F%L
M=64@/2`D=F%L=64["B`@("`@("`@)'1H:7,M/E]L86)E;"`]("1L86)E;#L*
M("`@("`@("`D=&AI<RT^7V9O<FUA="`]("1F;W)M870["B`@("`@("`@)'1H
M:7,M/E]T>7!E(#T@)W1E>'0G.PH@("`@("`@("1T:&ES+3Y?;6]D92`]("=A
M;'!H82<["B`@("!]"@I]"@HO*BH*("H@5&AI<R!C;&%S<R!P<F]V:61E<R!A
M;B!I;G!U="!T97AT87)E82!I;B!A($AO<F1E7TUO8FEL95]F;W)M(&]B:F5C
M="X*("H*("H@17AA;7!L97,Z"B`J"B`J("1M>4%R96$Q(#T@;F5W($AO<F1E
M7TUO8FEL95]T97AT87)E82@G9F(G+"`G)RP@)T9E961B86-K)RD["B`J("1M
M>4%R96$R(#T@;F5W($AO<F1E7TUO8FEL95]T97AT87)E82@G;7-G)RP@)T5N
M=&5R(&UE<W-A9V4@:&5R92`N+BXG+"`G365S<V%G92<L(#0P+"`U*3L*("H*
M("H@0'-E92!(;W)D95]-;V)I;&5?9F]R;0H@*@H@*B!`<&%C:V%G92!(;W)D
M95]-;V)I;&4*("HO"F-L87-S($AO<F1E7TUO8FEL95]T97AT87)E82!E>'1E
M;F1S($AO<F1E7TUO8FEL95]F;W)M16QE;65N="!["@H@("`@=F%R("1?<F]W
M<SL*("`@('9A<B`D7V-O;',["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O
M<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@5F%R:6%B
M;&4@:6X@=VAI8V@@=&AE(&EN<'5T(&ES('-E;G0@=&\@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@9&5S=&EN871I;VX@55),+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=F%L=64@($EN:71I86P@=F%L=64@=&AA="!W:6QL
M(&)E('!R97-E;G1E9"!I;B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!T97AT87)E82X*("`@("`J($!P87)A;2!S=')I;F<@)&QA8F5L("!$
M97-C<FEB97,@>6]U<B!T97AT87)E82!O;B!T:&4@<W5R9F5R)W,*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!S8W)E96XO9&ES<&QA>2X*("`@("`J
M($!P87)A;2!I;G1E9V5R("1R;W=S("!2;W=S+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&-O;',@($-O;'5M;G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO
M<F1E7TUO8FEL95]T97AT87)E82@D;F%M92P@)'9A;'5E+"`D;&%B96PL("1R
M;W=S(#T@,RP@)&-O;',@/2`Q-BD*("`@('L*("`@("`@("`D=&AI<RT^7VYA
M;64@/2`D;F%M93L*("`@("`@("`D=&AI<RT^7W9A;'5E(#T@)'9A;'5E.PH@
M("`@("`@("1T:&ES+3Y?;&%B96P@/2`D;&%B96P["B`@("`@("`@)'1H:7,M
M/E]R;W=S(#T@)')O=W,["B`@("`@("`@)'1H:7,M/E]C;VQS(#T@)&-O;',[
M"B`@("`@("`@)'1H:7,M/E]M;V1E(#T@)V%L<&AA)SL*("`@('T*"GT*"B\J
M*@H@*B!4:&ES(&-L87-S('!R;W9I9&5S(&$@<V5L96-T(&5L96UE;G0@:6X@
M82!(;W)D95]-;V)I;&5?9F]R;2!O8FIE8W0N"B`J($ET(&%L;&]W<R!T;R!C
M<F5A=&4@;W!T:6UI>F5D(%=-3"!F;W(@5T%0(&1E=FEC97,@=VAI8V@@87)E
M(&-A<&%B;&4*("H@=&\@:6YT97)P<F5T92!T:&4@3W!E;G=A=F4@1U5)(&5X
M=&5N<VEO;G,@9F]R(%=-3"`Q+C,N($%L;"!O=&AE<@H@*B!734P@9&5V:6-E
M<R!R96-E:79E(%=-3"`Q+C$@8V]M<&%T:6)L92!M87)K=7`@8V]D92P@=VAI
M8V@@:7,@<75I=&4*("H@<VEM:6QA<B!T;R!T:&4@;6%R:W5P(&-O9&4@8W)E
M871E9"!B>2!T:&4@2&]R9&5?36]B:6QE7W)A9&EO(&-L87-S+@H@*@H@*B!%
M>&%M<&QE<SH*("H*("H@)&UY4V5L96-T(#T@;F5W($AO<F1E7TUO8FEL95]S
M96QE8W0H)V-O;&]R)RD["B`J("1M>5-E;&5C="T^861D*"=";'5E)RP@)V(G
M*3L*("H@)&UY4V5L96-T+3YA9&0H)U)E9"<L("=R)RP@=')U92D["B`J("1M
M>5-E;&5C="T^861D*"=996QL;W<G+"`G>2<I.PH@*@H@*B!`<V5E($AO<F1E
M7TUO8FEL95]F;W)M"B`J"B`J($!P86-K86=E($AO<F1E7TUO8FEL90H@*B\*
M8VQA<W,@2&]R9&5?36]B:6QE7W-E;&5C="!E>'1E;F1S($AO<F1E7TUO8FEL
M95]F;W)M16QE;65N="!["@H@("`@=F%R("1?='EP93L*("`@('9A<B`D7V]P
M=&EO;G,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!687)I86)L92!I
M;B!W:&EC:"!T:&4@:6YF;W)M871I;VX@86)O=70@=&AE"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("!S96QE8W1E9"!O<'1I;VX@:7,@<V5N="!T;R!T
M:&4@9&5S=&EN871I;VX@55),+@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP
M92`@5'EP92!O9B!S96QE8W0@87)E83H*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("=P;W!U<"<Z('!O<'5P('1H92!W:&]L92!S96QE8W1I;VX@;&ES
M=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@)W-P:6XG.B`@<F]T871E
M(&]P=&EO;G,@;VX@82!705`@9&5V:6-E('-C<F5E;B`H3U<*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$N,R!'54D@;VYL>2DN"B`@
M("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TUO8FEL95]S96QE8W0H)&YA;64L
M("1T>7!E(#T@)W!O<'5P)RD*("`@('L*("`@("`@("`D=&AI<RT^7VYA;64@
M/2`D;F%M93L*("`@("`@("`D=&AI<RT^7W1Y<&4@/2`D='EP93L*("`@("`@
M("`D=&AI<RT^7W9A;'5E(#T@;G5L;#L*("`@('T*"B`@("`O*BH*("`@("`J
M($%D9',@;VYE(&]P=&EO;B!T;R!A($AO<F1E7TUO8FEL95]S96QE8W0@;V)J
M96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&QA8F5L("`@("`@
M("`@1&5S8W)I8F5S('1H92!O<'1I;VX@;VX@=&AE('-U<F9E<B=S"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-C<F5E;B]D:7-P;&%Y
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%L=64@("`@("`@("!686QU92!S
M96YT(&EN('1H92`B;F%M92(@=F%R:6%B;&4L(&EF('1H:7,*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:7,@=&AE(&]P=&EO;B!S96QE
M8W1E9"X*("`@("`J($!P87)A;2!B;V]L96%N("1I<U]S96QE8W1E9"`@06QL
M;W=E9"!V86QU97,@87)E('1R=64@;W(@9F%L<V4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%D9"@D;&%B96PL("1V86QU92P@)&ES7W-E;&5C=&5D(#T@9F%L
M<V4I"B`@("!["B`@("`@("`@)'1H:7,M/E]O<'1I;VYS6UT@/2!A<G)A>2@G
M;&%B96PG(#T^("1L86)E;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=V86QU92<@/3X@)'9A;'5E*3L*"B`@("`@("`@:68@*&ES7VYU
M;&PH)'1H:7,M/E]V86QU92D@?'P@)&ES7W-E;&5C=&5D*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?=F%L=64@/2`D=F%L=64["B`@("`@("`@?0H@("`@?0H*
M?0H*+RHJ"B`J(%1H:7,@8VQA<W,@<')O=FED97,@82!R861I;R!B=71T;VX@
M96QE;65N="!I;B!A($AO<F1E7TUO8FEL95]F;W)M(&]B:F5C="X*("H*("H@
M17AA;7!L97,Z"B`J"B`J("1M>5)A9&EO(#T@;F5W($AO<F1E7TUO8FEL95]R
M861I;R@G8V]U;G1R>2<I.PH@*B`D;7E2861I;RT^861D*"=&:6YL86YD)RP@
M)T8G*3L*("H@)&UY4F%D:6\M/F%D9"@G1V5R;6%N>2<L("=')RP@=')U92D[
M"B`J("1M>5)A9&EO+3YA9&0H)U-W961E;B<L("=3)RD["B`J"B`J($!S964@
M2&]R9&5?36]B:6QE7V9O<FT*("H*("H@0'!A8VMA9V4@2&]R9&5?36]B:6QE
M"B`J+PIC;&%S<R!(;W)D95]-;V)I;&5?<F%D:6\@97AT96YD<R!(;W)D95]-
M;V)I;&5?9F]R;45L96UE;G0@>PH*("`@('9A<B`D7V)U='1O;G,@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N86UE("!687)I86)L92!I;B!W:&EC:"!T:&4@
M:6YF;W)M871I;VX@86)O=70@=&AE('!R97-S960@8G5T=&]N"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("!I<R!S96YT('1O('1H92!D97-T:6YA=&EO
M;B!54DPN"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TUO8FEL95]R861I
M;R@D;F%M92D*("`@('L*("`@("`@("`D=&AI<RT^7VYA;64@/2`D;F%M93L*
M("`@("`@("`D=&AI<RT^7W9A;'5E(#T@;G5L;#L*("`@('T*"B`@("`O*BH*
M("`@("`J($%D9',@;VYE(')A9&EO(&)U='1O;B!T;R!A($AO<F1E7TUO8FEL
M95]R861I;R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;&%B96P@("`@("`@($1E<V-R:6)E<R!T:&4@<F%D:6]B=71T;VX@;VX@=&AE
M('-U<F9E<B=S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<V-R965N+V1I<W!L87DN"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU92`@
M("`@("`@5F%L=64@<V5N="!I;B!T:&4@(FYA;64B('9A<FEA8FQE+"!I9B!T
M:&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G5T=&]N
M(&ES('-E;&5C=&5D+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&ES7V-H96-K
M960@($%L;&]W960@=F%L=65S(&%R92!T<G5E(&]R(&9A;'-E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!A9&0H)&QA8F5L+"`D=F%L=64L("1I<U]C:&5C:V5D
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M/E]B=71T;VYS6UT@/2!A
M<G)A>2@G;&%B96PG(#T^("1L86)E;"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=V86QU92<@/3X@)'9A;'5E*3L*"B`@("`@("`@:68@
M*"$D=&AI<RT^7W9A;'5E('Q\("@D:7-?8VAE8VME9"DI('L*("`@("`@("`@
M("`@)'1H:7,M/E]V86QU92`]("1V86QU93L*("`@("`@("!]"B`@("!]"@I]
M"@HO*BH*("H@5&AI<R!C;&%S<R!P<F]V:61E<R!A('-I;F=L92!C:&5C:V)O
M>"!E;&5M96YT(&EN(&$@2&]R9&5?36]B:6QE7V9O<FT@;V)J96-T+@H@*@H@
M*B!%>&%M<&QE<SH*("H*("H@)&UY0VAE8VMB;W@@/2!N97<@2&]R9&5?36]B
M:6QE7V-H96-K8F]X*"=A9VUT)RP@)WEE<R<L("=)(&%G<F5E)RD["B`J("1M
M>4-H96-K8F]X(#T@;F5W($AO<F1E7TUO8FEL95]C:&5C:V)O>"@G86=M="<L
M("=Y97,G+"`G22!A9W)E92<L(&9A;'-E*3L*("H@)&UY0VAE8VMB;W@@/2!N
M97<@2&]R9&5?36]B:6QE7V-H96-K8F]X*"=A9VUT)RP@)WEE<R<L("=)(&%G
M<F5E)RP@=')U92D["B`J"B`J($!N;W1E(%1H92!F:7)S="!A;F0@<V5C;VYD
M(&5X86UP;&5S(&%R92!I9&5N=&EC86PN"B`J"B`J($!S964@2&]R9&5?36]B
M:6QE7V9O<FT*("H*("H@0'!A8VMA9V4@2&]R9&5?36]B:6QE"B`J+PIC;&%S
M<R!(;W)D95]-;V)I;&5?8VAE8VMB;W@@97AT96YD<R!(;W)D95]-;V)I;&5?
M9F]R;45L96UE;G0@>PH*("`@('9A<B`D7V-H96-K960["@H@("`@+RHJ"B`@
M("`@*B!#;VYS=')U8W1O<@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&YA;64@("`@("!687)I86)L92!I;B!W:&EC:"`B=F%L=64B(&ES('-E;G0@
M=&\@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@9&5S=&EN
M871I;VX@55),+"!I9B!T:&4@8F]X(&ES(&-H96-K960N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1V86QU92`@("`@4V5E(&YA;64N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1L86)E;"`@("`@1&5S8W)I8F5S('1H92!C:&5C:V)O>"!O;B!T
M:&4@<W5R9F5R)W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!S
M8W)E96XO9&ES<&QA>2X*("`@("`J($!P87)A;2!B;V]L96%N("1C:&5C:V5D
M("!!;&QO=V5D('9A;'5E<R!A<F4@=')U92!O<B!F86QS92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@2&]R9&5?36]B:6QE7V-H96-K8F]X*"1N86UE+"`D=F%L
M=64L("1L86)E;"P@)&-H96-K960@/2!F86QS92D*("`@('L*("`@("`@("`D
M=&AI<RT^7VYA;64@(#T@)&YA;64["B`@("`@("`@)'1H:7,M/E]V86QU92`]
M("1V86QU93L*("`@("`@("`D=&AI<RT^7VQA8F5L(#T@)&QA8F5L.PH@("`@
M("`@("1T:&ES+3Y?8VAE8VME9"`]("1C:&5C:V5D.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&ES0VAE8VME9"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?8VAE8VME9#L*("`@('T*"GT*"B\J*@H@*B!4:&ES(&-L87-S('!R;W9I
M9&5S(&AI9&1E;B!E;&5M96YT<R!I;B!(;W)D95]-;V)I;&5?9F]R;2!O8FIE
M8W1S+@H@*@H@*B!%>&%M<&QE<SH*("H*("H@)&AI9&1E;B`](&YE=R!(;W)D
M95]-;V)I;&5?:&ED9&5N*"=I;G1E<FYA;%]R969E<F5N8V4G+"`G,#@Q-30W
M,3$G*3L*("H*("H@0'-E92!(;W)D95]-;V)I;&5?9F]R;0H@*@H@*B!`<&%C
M:V%G92!(;W)D95]-;V)I;&4*("HO"F-L87-S($AO<F1E7TUO8FEL95]H:61D
M96X@97AT96YD<R!(;W)D95]-;V)I;&5?9F]R;45L96UE;G0@>PH*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1N86UE("`@5F%R:6%B;&4@:6X@=VAI8V@@)'9A;'5E(&ES('-E;G0@
M=&\@=&AE(&1E<W1I;F%T:6]N(%523"X*("`@("`J($!P87)A;2!S=')I;F<@
M)'9A;'5E("!3964@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?
M36]B:6QE7VAI9&1E;B@D;F%M92P@)'9A;'5E*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?;F%M92`]("1N86UE.PH@("`@("`@("1T:&ES+3Y?=F%L=64@/2`D
M=F%L=64["B`@("!]"@I]"@HO*BH*("H@5&AI<R!C;&%S<R!P<F]V:61E<R!A
M('-U8FUI="!B=71T;VX@9F]R(&$@2&]R9&5?36]B:6QE7V9O<FT@;V)J96-T
M+B!/;F4*("H@2&]R9&5?36]B:6QE7V9O<FT@;V)J96-T(&-A;B!C;VYT86EN
M(&]N;'D@;VYE($AO<F1E7TUO8FEL95]S=6)M:70@;V)J96-T+@H@*@H@*B!%
M>&%M<&QE<SH*("H@)&UY4W5B;6ET(#T@)FYE=R!(;W)D95]-;V)I;&5?<W5B
M;6ET*"=3=6)M:70G*3L*("H@)&UY4W5B;6ET(#T@)FYE=R!(;W)D95]-;V)I
M;&5?<W5B;6ET*"=3=6)M:70G+"`G=7-E<E]P<F5S<V5D)RD["B`J"B`J($!S
M964@2&]R9&5?36]B:6QE7V9O<FT*("H*("H@0'!A8VMA9V4@2&]R9&5?36]B
M:6QE"B`J+PIC;&%S<R!(;W)D95]-;V)I;&5?<W5B;6ET(&5X=&5N9',@2&]R
M9&5?36]B:6QE7V9O<FU%;&5M96YT('L*"B`@("!V87(@)%]F;W)M.PH*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1L86)E;"`@5VAA="=S('=R:71T96X@;VX@=&AE(&)U='1O;BX*
M("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("!687)I86)L92!I;B!W:&EC
M:"`B;&%B96PB(&ES('-E;G0@=&\@=&AE"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@9&5S=&EN871I;VX@55),+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!(;W)D95]-;V)I;&5?<W5B;6ET*"1L86)E;"P@)&YA;64@/2`G)RD*("`@
M('L*("`@("`@("`D=&AI<RT^7VQA8F5L(#T@)&QA8F5L.PH@("`@("`@("1T
M:&ES+3Y?;F%M92`]("1N86UE.PH@("`@?0H*?0H*+RHJ"B`J(%1H:7,@8VQA
M<W,@<')O=FED97,@82!L:6YK(&EN(&$@2&]R9&5?36]B:6QE+"!(;W)D95]-
M;V)I;&5?;&EN:W-E="!O<@H@*B!(;W)D95]-;V)I;&5?=&%B;&4@;V)J96-T
M+@H@*@H@*B!%>&%M<&QE<SH*("H*("H@)&UY4&%G92`](&YE=R!(;W)D95]-
M;V)I;&4H+BXN*3L*("H*("H@)&UY3&EN:R`](&YE=R!(;W)D95]-;V)I;&5?
M;&EN:R@G0V]N=&EN=64G+"`G+VUY;F5X='!A9V4N=VUL)RD["B`J("1M>5!A
M9V4M/F%D9"@D;7E,:6YK*3L*("H*("H@0'-E92!(;W)D95]-;V)I;&4*("H@
M0'-E92!(;W)D95]-;V)I;&5?;&EN:W-E=`H@*B!`<V5E($AO<F1E7TUO8FEL
M95]T86)L90H@*@H@*B!`<&%C:V%G92!(;W)D95]-;V)I;&4*("HO"F-L87-S
M($AO<F1E7TUO8FEL95]L:6YK(&5X=&5N9',@2&]R9&5?36]B:6QE7V5L96UE
M;G0@>PH*("`@('9A<B`D7VQA8F5L.PH@("`@=F%R("1?=7)L.PH@("`@=F%R
M("1?=&ET;&4["B`@("!V87(@)%]A8V-E<W-K97D["@H@("`@+RHJ"B`@("`@
M*B!#;VYS=')U8W1O<@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&QA
M8F5L("!$97-C<FEB97,@=&AE(&QI;FL@;VX@=&AE('-U<F9E<B=S('-C<F5E
M;B]D:7-P;&%Y+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7)L("`@($YE>'0@
M9&5S=&EN871I;VX@861D<F5S<RX@35535"!B92!V86QI9"!834P@*"9A;7`[
M(&EN<W1E860@;V8@)BP@971C+BDN"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M:71L92`@268@82!S=')I;F<@:7,@<')O=FED960@:&5R92P@:70@=VEL;"!B
M92!D:7-P;&%Y960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!I;B!T
M:&4@2%1-3"!B<F]W<V5R('-T871U<R!B87(@9'5R:6YG"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@(DUO=7-E3W9E<B(L(')E<W!E8W1I=F5L>2!S
M;VUE=VAE<F4@;VX@=&AE(%=!4`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&1I<W!L87DN($EN(&]R9&5R('1O('=O<FL@=V5L;"!W:71H(&$@8G)O
M860@<F%N9V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!O9B!U<V5R
M(&%G96YT<RP@:V5E<"!Y;W5R('1I=&QE('5N9&5R(#8*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!C:&%R86-T97)S+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!(;W)D95]-;V)I;&5?;&EN:R@D;&%B96PL("1U<FPL("1T:71L92`]
M("<G*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;&%B96P@/2`D;&%B96P["B`@
M("`@("`@)'1H:7,M/E]U<FP@/2`D=7)L.PH@("`@("`@("1T:&ES+3Y?=&ET
M;&4@/2`D=&ET;&4["@H@("`@("`@("\O($YO(&%C8V5S<VME>2!A<W-I9VYE
M9"!B>2!D969A=6QT.R!C86X@8F4@87-S:6=N960@;&%T97(*("`@("`@("`O
M+R!F<F]M(&$@2&]R9&5?36]B:6QE7VQI;FMS970@;V)J96-T(&EF(')E<75I
M<F5D+@H@("`@("`@("1T:&ES+3Y?86-C97-S:V5Y(#T@;G5L;#L*("`@('T*
M"GT*"B\J*@H@*B!4:&ES(&-L87-S('!R;W9I9&5S(&$@<&AO;F4@;G5M8F5R
M(&EN(&$@2&]R9&5?36]B:6QE(&]B:F5C="X@268@<W5P<&]R=&5D(&)Y"B`J
M('1H96ER(&UO8FEL92!D979I8V4L('5S97)S(&-A;B!E<W1A8FQI<V@@82!V
M;VEC92!C;VYN96-T:6]N('1O('1H90H@*B!S<&5C:69I960@;G5M8F5R+@H@
M*@H@*B!%>&%M<&QE<SH*("H*("H@)&UY4&AO;F4@/2`F;F5W($AO<F1E7TUO
M8FEL95]P:&]N92@G,3(S+30U-C<X)RP@)T-!3$PG*3L*("H@)&UY4&%G92T^
M861D*"1M>5!H;VYE*3L*("H*("H@0'-E92!(;W)D95]-;V)I;&4*("H*("H@
M0'!A8VMA9V4@2&]R9&5?36]B:6QE"B`J+PIC;&%S<R!(;W)D95]-;V)I;&5?
M<&AO;F4@97AT96YD<R!(;W)D95]-;V)I;&5?96QE;65N="!["@H@("`@=F%R
M("1?;&%B96P["B`@("!V87(@)%]N=6UB97(["B`@("!V87(@)%]T:71L93L*
M"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<&AO;F5?;G5M8F5R("!0:&]N92!N=6UB97(@=&\@9&EA
M;"X*("`@("`J($!P87)A;2!S=')I;F<@)'1I=&QE("`@("`@("`@268@82!S
M=')I;F<@:7,@<')O=FED960@:&5R92P@=&AE(&-A;&P*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8G5T=&]N(&]N(&$@5T%0+TA$34P@
M9&5V:6-E('=I;&P@8F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@96YA8FQE9"X@26X@;W)D97(@=&\@=V]R:R!W96QL('=I=&@*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@82!B<F]A9"!R86YG
M92!O9B!U<V5R(&%G96YT<RP@:V5E<"!Y;W5R"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('1I=&QE('5N9&5R(#8@8VAA<F%C=&5R<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?36]B:6QE7W!H;VYE*"1P:&]N
M95]N=6UB97(L("1T:71L92`]("<G*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M;&%B96P@/2`D<&AO;F5?;G5M8F5R.PH@("`@("`@("1T:&ES+3Y?;G5M8F5R
M(#T@<')E9U]R97!L86-E*"=\7$1\)RP@)R<L("1P:&]N95]N=6UB97(I.PH@
M("`@("`@("1T:&ES+3Y?=&ET;&4@/2`D=&ET;&4["B`@("!]"@I]"@HO*BH*
M("H@5&AI<R!C;&%S<R!D969I;F5S(&$@<V5T(&]F(&QI;FMS+B!4:&4@;&EN
M:W,@:&%V92!T;R!B92!D969I;F5D(&%S"B`J('-E<&%R871E($AO<F1E7TUO
M8FEL95]L:6YK(&]B:F5C=',@86YD(&%R92!A='1A8VAE9"!T;R!T:&4@;&EN
M:W-E=`H@*B!W:71H(&$@<W!E8VEA;"`B861D(B!F=6YC=&EO;BX@($9O<B!7
M05`@9&5V:6-E<R!B<F]W<V5R+61E<&5N9&5N=`H@*B!734P@8V]D92!W:6QL
M(&)E(&-R96%T960N($]N(&%L;"!54"UB<F]W<V5R+6)A<V5D(%=!4"!D979I
M8V5S"B`J(&QI;FMS971S(&%L;&]W(&5A<VEE<B!N879I9V%T:6]N('1H<F]U
M9V@@5TU,(&1E8VMS(&)Y('5S:6YG('1H90H@*B`B;VYP:6-K(B!734P@;W!T
M:6]N(&%N9"!T:&5R969O<F4@87)E(&EM<')O=FEN9R!T:&4@(G5S86)I;&ET
M>2(@;V8*("H@86X@87!P;&EC871I;VXN($EN<W1E860@;V8@<&%I;F9U;&QY
M(&YA=FEG871I;F<@=&AR;W5G:"!T:&4@;&EN:W,*("H@(G-P;W)T<RT^9F]O
M=&)A;&PM/G)E<W5L=',M/G1O9&%Y(B!T:&4@;6]B:6QE('5S97(@92YG+B!C
M86X@<')E<W,*("H@(C(T,S$B(&]N('1H92!K97EP860@=&\@96YT97(@:&ES
M(&9A=F]R:71E(&1E8VLN($9O<B!A;&P@;W1H97(@5T%0"B`J(&1E=FEC97,@
M;F]R;6%L(#QA/B!T86=S(&%R92!C<F5A=&5D+B!/;F4@2&]R9&5?36]B:6QE
M(&]B:F5C="!C86X*("H@8V]N=&%I;B!O;FQY(&]N92!L:6YK<V5T(&]B:F5C
M="X*("H*("H@17AA;7!L97,Z"B`J"B`J("1M>5!A9V4@/2!N97<@2&]R9&5?
M36]B:6QE*"XN+BD["B`J"B`J("1M>4QI;FMS970@/2!N97<@2&]R9&5?36]B
M:6QE7VQI;FMS970H*3L*("H@)&UY3&EN:S$@/2!N97<@2&]R9&5?36]B:6QE
M7VQI;FLH(E!H;VYE8F]O:R(L("(O=V%P+W!H;VYE8F]O:RYW;6PB*3L*("H@
M)&UY3&EN:W-E="T^861D*"1M>4QI;FLQ*3L*("H@)&UY3&EN:S(@/2!N97<@
M2&]R9&5?36]B:6QE7VQI;FLH(D1A=&5";V]K(BP@(B]W87`O9&%T96)O;VLN
M=VUL(BD["B`J("1M>4QI;FMS970M/F%D9"@D;7E,:6YK,BD["B`J"B`J("1M
M>5!A9V4M/F%D9"@D;7E,:6YK<V5T*3L*("H*("H@)&UY4&%G92T^<F5N9&5R
M*"D["B`J"B`J($!S964@2&]R9&5?36]B:6QE7VQI;FL*("H@0'-E92!(;W)D
M95]-;V)I;&4*("H*("H@0'!A8VMA9V4@2&]R9&5?36]B:6QE"B`J+PIC;&%S
M<R!(;W)D95]-;V)I;&5?;&EN:W-E="!E>'1E;F1S($AO<F1E7TUO8FEL95]E
M;&5M96YT('L*"B`@("!V87(@)%]E;&5M96YT<SL*"B`@("`O*BH*("`@("`J
M($%D9',@82!(;W)D95]-;V)I;&5?;&EN:R!O8FIE8W0@=&\@2&]R9&5?36]B
M:6QE7VQI;FMS970N"B`@("`@*@H@("`@("H@0'!A<F%M($AO<F1E7TUO8FEL
M95]L:6YK("1L:6YK("!4:&4@;&EN:R!O8FIE8W0@=&\@861D+@H@("`@("H*
M("`@("`J($!S964@2&]R9&5?36]B:6QE7VQI;FL*("`@("`J+PH@("`@9G5N
M8W1I;VX@)F%D9"@F)&QI;FLI"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1L
M:6YK+"`G2&]R9&5?36]B:6QE7VQI;FLG*2D@>PH@("`@("`@("`@("`D97)R
M;W(@/2!014%2.CIR86ES945R<F]R*"=,:6YK<R!M=7-T(&)E($AO<F1E7TUO
M8FEL95]L:6YK(&]B:F5C=',N)RD["B`@("`@("`@("`@(')E='5R;B`D97)R
M;W(["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V5L96UE;G1S6UT@/2`F
M)&QI;FL["B`@("`@("`@)&QI;FLM/G-E="@G86-C97-S:V5Y)RP@8V]U;G0H
M)'1H:7,M/E]E;&5M96YT<RDI.PH*("`@("`@("!R971U<FX@)&QI;FL["B`@
M("!]"@I]"@HO*BH*("H@5&AI<R!C;&%S<R!W:6QL(&-A=7-E(&$@:&]R:7IO
M;G1A;"!R=6QE('1O(&)E(&1R87=N(&%C<F]S<R!T:&4@<V-R965N+B`@66]U
M"B`J(&-A;B!U<V4@:70@=&\@<V5P87)A=&4@=&5X="!P87)A9W)A<&AS(&EN
M($AO<F1E7TUO8FEL92!O<B!(;W)D95]-;V)I;&5?9F]R;0H@*B!O8FIE8W1S
M+@H@*@H@*B!%>&%M<&QE<SH*("H*("H@)&UY1&5F875L=%)U;&4@/2!N97<@
M2&]R9&5?36]B:6QE7W)U;&4H*3L*("H@)&UY4W!E8VEA;%)U;&4@/2!N97<@
M2&]R9&5?36]B:6QE7W)U;&4H)S8P)2<L(#0I.PH@*@H@*B`D;7E086=E+3YA
M9&0H)&UY1&5F875L=%)U;&4I.PH@*@H@*B`D;7E086=E+3YA9&0H)&UY4W!E
M8VEA;%)U;&4I.PH@*@H@*B!`<V5E($AO<F1E7TUO8FEL90H@*B!`<V5E($AO
M<F1E7TUO8FEL95]F;W)M"B`J"B`J($!P86-K86=E($AO<F1E7TUO8FEL90H@
M*B\*8VQA<W,@2&]R9&5?36]B:6QE7W)U;&4@97AT96YD<R!(;W)D95]-;V)I
M;&5?96QE;65N="!["@H@("`@=F%R("1?=VED=&@["B`@("!V87(@)%]S:7IE
M.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D=VED=&@@(%!E<F-E;G1A9V4@;V8@<V-R965N('=I
M9'1H(&]R(&%B<V]L=71E('9A;'5E(&EN"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@(&YU;6)E<B!O9B!P:7AE;',@*&4N9RX@(C4P)2(L(#$P,"DN
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<VEZ92`@($AE:6=H="!O9B!T:&4@
M;&EN92!T;R!B92!D<F%W;B!I;B!P:7AE;',N"B`@("`@*B\*("`@(&9U;F-T
M:6]N($AO<F1E7TUO8FEL95]R=6QE*"1W:61T:"`]("<G+"`D<VEZ92`]("<G
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=VED=&@@/2`D=VED=&@["B`@("`@
M("`@)'1H:7,M/E]S:7IE(#T@)'-I>F4["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TY,4R\`````````````````
M````````````````````````````````````````````````````````````
M```P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,S<U,``P,C`Q,38`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M3DQ3+V-A<G-I9VYS+G!H<```````````````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`W,S(R`#$P-3$U-#,S-S4P`#`R,C0T-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@5&AE(&QI
M<W0@;V8@:6YT97)N871I;VYA;"!L:6-E;G-E('!L871E(&-O9&5S+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R].3%,O3DQ3+V-A<G-I9VYS+G!H<"QV(#$N
M,2`R,#`T+S`Y+S`X(#$U.C$X.C4W(&IA;B!%>'`@)`H@*@H@*B!`<&%C:V%G
M92!(;W)D95].3%,*("HO"@HD8V%R<VEG;G,@/2!A<G)A>2@*("`@("=A="<@
M/3X@)T$G+`H@("`@)V%F)R`]/B`G049')RP*("`@("=A9R<@/3X@)T%')RP*
M("`@("=A;"<@/3X@)T%,)RP*("`@("=A9"<@/3X@)T%.1"<L"B`@("`G86\G
M(#T^("=!3D<G+`H@("`@)V%M)R`]/B`G05)-)RP*("`@("=A=2<@/3X@)T%5
M4R<L"B`@("`G87HG(#T^("=!6B<L"B`@("`G8F4G(#T^("=")RP*("`@("=B
M9"<@/3X@)T)$)RP*("`@("=B8B<@/3X@)T)$4R<L"B`@("`G8F8G(#T^("="
M1B<L"B`@("`G8F<G(#T^("="1R<L"B`@("`G8GHG(#T^("="2"<L"B`@("`G
M8G0G(#T^("="2%0G+`H@("`@)V)A)R`]/B`G0DE()RP*("`@("=B;R<@/3X@
M)T)/3"<L"B`@("`G8G(G(#T^("="4B<L"B`@("`G8F@G(#T^("="4DXG+`H@
M("`@)V)N)R`]/B`G0E)5)RP*("`@("=B<R<@/3X@)T)3)RP*("`@("=B:2<@
M/3X@)T)5)RP*("`@("=V9R<@/3X@)T)622<L"B`@("`G8GDG(#T^("="62<L
M"B`@("`G8GHG(#T^("="6B<L"B`@("`G8W4G(#T^("=#)RP*("`@("=C;2<@
M/3X@)T-!32<L"B`@("`G8V0G(#T^("=#1"<L"B`@("`G8V$G(#T^("=#1$XG
M+`H@("`@)V-H)R`]/B`G0T@G+`H@("`@)V-I)R`]/B`G0TDG+`H@("`@)VQK
M)R`]/B`G0TPG+`H@("`@)V-O)R`]/B`G0T\G+`H@("`@)VMM)R`]/B`G0T]-
M)RP*("`@("=C<B<@/3X@)T-2)RP*("`@("=C=B<@/3X@)T-6)RP*("`@("=C
M>2<@/3X@)T-9)RP*("`@("=C>B<@/3X@)T-:)RP*("`@("=D92<@/3X@)T0G
M+`H@("`@)V1J)R`]/B`G1$I))RP*("`@("=D:R<@/3X@)T1+)RP*("`@("=D
M;R<@/3X@)T1/32<L"B`@("`G:W`G(#T^("=$5E)+)RP*("`@("=B:B<@/3X@
M)T19)RP*("`@("=D>B<@/3X@)T1:)RP*("`@("=E<R<@/3X@)T4G+`H@("`@
M)VME)R`]/B`G14%+)RP*("`@("=T>B<@/3X@)T5!5"<L"B`@("`G=6<G(#T^
M("=%054G+`H@("`@)V5C)R`]/B`G14,G+`H@("`@)V5R)R`]/B`G15(G+`H@
M("`@)W-V)R`]/B`G15,G+`H@("`@)V5E)R`]/B`G15-4)RP*("`@("=E9R<@
M/3X@)T54)RP*("`@("=E="<@/3X@)T542"<L"B`@("`G9G(G(#T^("=&)RP*
M("`@("=F:2<@/3X@)T9)3B<L"B`@("`G9FHG(#T^("=&2DDG+`H@("`@)VQI
M)R`]/B`G1DPG+`H@("`@)V9O)R`]/B`G1D\G+`H@("`@)V9M)R`]/B`G1E--
M)RP*("`@("=G82<@/3X@)T<G+`H@("`@)V=B)R`]/B`G1T(G+`H@("`@)V=I
M)R`]/B`G1T):)RP*("`@("=G="<@/3X@)T=#02<L"B`@("`G9V4G(#T^("='
M12<L"B`@("`G9V@G(#T^("='2"<L"B`@("`G9W$G(#T^("='42<L"B`@("`G
M9W(G(#T^("='4B<L"B`@("`G9WDG(#T^("='55DG+`H@("`@)VAU)R`]/B`G
M2"<L"B`@("`G:&LG(#T^("=(2R<L"B`@("`G:&XG(#T^("=(3B<L"B`@("`G
M:'(G(#T^("=(4B<L"B`@("`G:70G(#T^("=))RP*("`@("=I;"<@/3X@)TE,
M)RP*("`@("=I;B<@/3X@)TE.1"<L"B`@("`G:7(G(#T^("=)4B<L"B`@("`G
M:64G(#T^("=)4DPG+`H@("`@)VEQ)R`]/B`G25)1)RP*("`@("=I<R<@/3X@
M)TE3)RP*("`@("=J<"<@/3X@)THG+`H@("`@)VIM)R`]/B`G2D$G+`H@("`@
M)VIO)R`]/B`G2D]2)RP*("`@("=K:"<@/3X@)TLG+`H@("`@)VMI)R`]/B`G
M2TE2)RP*("`@("=G;"<@/3X@)TM.)RP*("`@("=K9R<@/3X@)TM3)RP*("`@
M("=S82<@/3X@)TM302<L"B`@("`G:W<G(#T^("=+5U0G+`H@("`@)VMZ)R`]
M/B`G2UHG+`H@("`@)VQU)R`]/B`G3"<L"B`@("`G;&$G(#T^("=,04\G+`H@
M("`@)VQY)R`]/B`G3$%2)RP*("`@("=L<B<@/3X@)TQ")RP*("`@("=L<R<@
M/3X@)TQ3)RP*("`@("=L="<@/3X@)TQ4)RP*("`@("=L=B<@/3X@)TQ6)RP*
M("`@("=M="<@/3X@)TTG+`H@("`@)VUA)R`]/B`G34$G+`H@("`@)VUY)R`]
M/B`G34%,)RP*("`@("=M8R<@/3X@)TU#)RP*("`@("=M9"<@/3X@)TU$)RP*
M("`@("=M>"<@/3X@)TU%6"<L"B`@("`G;6XG(#T^("=-1TPG+`H@("`@)VUH
M)R`]/B`G34@G+`H@("`@)VUK)R`]/B`G34LG+`H@("`@)VUZ)R`]/B`G34]#
M)RP*("`@("=M=2<@/3X@)TU3)RP*("`@("=M=B<@/3X@)TU6)RP*("`@("=M
M=R<@/3X@)TU7)RP*("`@("=M;2<@/3X@)TU902<L"B`@("`G;F\G(#T^("=.
M)RP*("`@("=A;B<@/3X@)TY!)RP*("`@("=N;"<@/3X@)TY,)RP*("`@("=N
M>B<@/3X@)TY:)RP*("`@("=O;2<@/3X@)T]-)RP*("`@("=P="<@/3X@)U`G
M+`H@("`@)W!A)R`]/B`G4$$G+`H@("`@)W!W)R`]/B`G4$%,)RP*("`@("=P
M92<@/3X@)U!%)RP*("`@("=P:R<@/3X@)U!+)RP*("`@("=P;"<@/3X@)U!,
M)RP*("`@("=P9R<@/3X@)U!.1R<L"B`@("`G8VXG(#T^("=04D,G+`H@("`@
M)W!S)R`]/B`G4%,G+`H@("`@)W!Y)R`]/B`G4%DG+`H@("`@)W%A)R`]/B`G
M42<L"B`@("`G87(G(#T^("=202<L"B`@("`G8G<G(#T^("=20B<L"B`@("`G
M='<G(#T^("=20R<L"B`@("`G8V8G(#T^("=20T$G+`H@("`@)V-D)R`]/B`G
M4D-")RP*("`@("=C;"<@/3X@)U)#2"<L"B`@("`G<F4G(#T^("=212<L"B`@
M("`G9VXG(#T^("=21R<L"B`@("`G:'0G(#T^("=22"<L"B`@("`G:60G(#T^
M("=222<L"B`@("`G;7(G(#T^("=224TG+`H@("`@)VQB)R`]/B`G4DPG+`H@
M("`@)VUG)R`]/B`G4DTG+`H@("`@)VUL)R`]/B`G4DU-)RP*("`@("=N92<@
M/3X@)U).)RP*("`@("=R;R<@/3X@)U)/)RP*("`@("=K<B<@/3X@)U)/2R<L
M"B`@("`G=7DG(#T^("=23U4G+`H@("`@)W!H)R`]/B`G4E`G+`H@("`@)W-M
M)R`]/B`G4E--)RP*("`@("=T9R<@/3X@)U)4)RP*("`@("=R=2<@/3X@)U)5
M4R<L"B`@("`G<G<G(#T^("=25T$G+`H@("`@)W-E)R`]/B`G4R<L"B`@("`G
M8W,G(#T^("=30T<G+`H@("`@)VMN)R`]/B`G4T-.)RP*("`@("=S>B<@/3X@
M)U-$)RP*("`@("=S9R<@/3X@)U-'4"<L"B`@("`G<VLG(#T^("=32R<L"B`@
M("`G<VDG(#T^("=33$\G+`H@("`@)W-R)R`]/B`G4TU%)RP*("`@("=S;B<@
M/3X@)U-.)RP*("`@("=S8B<@/3X@)U-/3"<L"B`@("`G<V\G(#T^("=34"<L
M"B`@("`G<W0G(#T^("=35%`G+`H@("`@)W-D)R`]/B`G4U5$)RP*("`@("=S
M8R<@/3X@)U-9)RP*("`@("=S>2<@/3X@)U-94B<L"B`@("`G=&0G(#T^("=4
M0T@G+`H@("`@)W1H)R`]/B`G5$A!)RP*("`@("=T:B<@/3X@)U1*)RP*("`@
M("=T;"<@/3X@)U1,)RP*("`@("=T;2<@/3X@)U1-)RP*("`@("=T;B<@/3X@
M)U1.)RP*("`@("=T;R<@/3X@)U1/)RP*("`@("=T<B<@/3X@)U12)RP*("`@
M("=T="<@/3X@)U14)RP*("`@("=T=B<@/3X@)U155B<L"B`@("`G=6$G(#T^
M("=502<L"B`@("`G864G(#T^("=5044G+`H@("`@)W5S)R`]/B`G55-!)RP*
M("`@("=U>B<@/3X@)U5:)RP*("`@("=V82<@/3X@)U8G+`H@("`@)W9N)R`]
M/B`G5DXG+`H@("`@)W9U)R`]/B`G5E4G+`H@("`@)T=-)R`]/B`G5T%')RP*
M("`@("=S;"<@/3X@)U=!3"<L"B`@("`G;F<G(#T^("=704XG+`H@("`@)V1M
M)R`]/B`G5T0G+`H@("`@)V=D)R`]/B`G5T<G+`H@("`@)VQC)R`]/B`G5TPG
M+`H@("`@)W=S)R`]/B`G5U,G+`H@("`@)W9C)R`]/B`G5U8G+`H@("`@)WEE
M)R`]/B`G64%2)RP*("`@("=V92<@/3X@)UE6)RP*("`@("=Z;2<@/3X@)UHG
M+`H@("`@)WIA)R`]/B`G6D$G+`H@("`@)WIW)R`]/B`G6E<G"BD["@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O3DQ3+V-O;W)D:6YA=&5S+G!H<```````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-S8U,S,T`#$P-3$U-#,S-S4P`#`R,S$V
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@5&AI<R!F:6QE(&QI<W1S('1H92!L;V-A=&EO;G,@;V8@
M8VET:65S(&%R;W5N9"!T:&4@=V]R;&0N(%1H90H@*B!F;W)M870@:7,Z"B`J
M"B`J("`@)&-O;W)D:6YA=&5S6R=C;W5N=')Y;F%M92==6R=L870Z;&]N9R==
M(#T@)V-I='EN86UE)SL*("H*("H@3&%T:71U9&4@86YD(&QO;F=I='5D92!A
M<F4@9&5C:6UA;',@*'-O=71H(&%N9"!W97-T(&%R92!N96=A=&EV92DN"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+TY,4R].3%,O8V]O<F1I;F%T97,N<&AP
M+'8@,2XR+C$R+C,@,C`P-2\Q,"\Q."`Q,3HP,3HQ."!J86X@17AP("0*("H*
M("H@0'!A8VMA9V4@2&]R9&5?3DQ3"B`J+PH*)&-O;W)D:6YA=&5S6R=!9F=H
M86YI<W1A;B==6R<S,2XP,#`Z-C$N.#4P)UT@/2`G6F%R86YJ)SL*)&-O;W)D
M:6YA=&5S6R=!9F=H86YI<W1A;B==6R<S,BXS-C<Z-C(N,3@S)UT@/2`G1F%R
M86@G.PHD8V]O<F1I;F%T97-;)T%F9VAA;FES=&%N)UU;)S,S+C0P,#HV,BXR
M.#,G72`]("=3:&EN9&%N9"<["B1C;V]R9&EN871E<ULG069G:&%N:7-T86XG
M75LG,S0N,C$W.C8R+C(Q-R==(#T@)TAE<F%T)SL*)&-O;W)D:6YA=&5S6R=!
M9F=H86YI<W1A;B==6R<S-"XT,S,Z-S`N-#8W)UT@/2`G2F%L86QA8F%D)SL*
M)&-O;W)D:6YA=&5S6R=!9F=H86YI<W1A;B==6R<S-"XV,S,Z-CDN,C`P)UT@
M/2`G2V%B=6P@06ER<&]R="<["B1C;V]R9&EN871E<ULG069G:&%N:7-T86XG
M75LG,S4N,3,S.C8Y+C(U,"==(#T@)TIA8G5L+5-A<F%J)SL*)&-O;W)D:6YA
M=&5S6R=!9F=H86YI<W1A;B==6R<S-BXU,#`Z-S$N,C4P)UT@/2`G6F5B86LG
M.PHD8V]O<F1I;F%T97-;)T%F9VAA;FES=&%N)UU;)S,V+C8V-SHV-2XW,3<G
M72`]("=3:&5B:7)G:&%N)SL*)&-O;W)D:6YA=&5S6R=!9F=H86YI<W1A;B==
M6R<S-BXW,#`Z-C<N,C`P)UT@/2`G36%Z87(M22U3:&%R:68G.PHD8V]O<F1I
M;F%T97-;)T%F9VAA;FES=&%N)UU;)S,W+C$Q-SHW,"XU,3<G72`]("=&86EZ
M86)A9"<["B1C;V]R9&EN871E<ULG06QB86YI82==6R<T,2XS,S,Z,3DN-S@S
M)UT@/2`G5&ER86YA)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S(T+C4U
M,#HY+C0V-R==(#T@)T1J86YE="<["B1C;V]R9&EN871E<ULG06QG97)I82==
M6R<R-BXU,#`Z."XT,3<G72`]("=);&QI>FDG.PHD8V]O<F1I;F%T97-;)T%L
M9V5R:6$G75LG,C<N-C8W.BTX+C$S,R==(#T@)U1I;F1O=68G.PHD8V]O<F1I
M;F%T97-;)T%L9V5R:6$G75LG,C<N.#@S.BTP+C(X,R==(#T@)T%D<F%R)SL*
M)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S(X+C`U,#HY+C8S,R==(#T@)TEN
M($%M96YA<R<["B1C;V]R9&EN871E<ULG06QG97)I82==6R<R.2XR-3`Z,"XR
M.#,G72`]("=4:6UI;6]U;B<["B1C;V]R9&EN871E<ULG06QG97)I82==6R<S
M,"XU-C<Z,BXX-C<G72`]("=%;"!';VQE82<["B1C;V]R9&EN871E<ULG06QG
M97)I82==6R<S,2XV,3<Z+3(N,C,S)UT@/2`G0F5C:&%R)SL*)&-O;W)D:6YA
M=&5S6R=!;&=E<FEA)UU;)S,Q+C8V-SHV+C$U,"==(#T@)TAA<W-I+4UE<W-A
M;W5D)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S,Q+CDQ-SHU+C0P,"==
M(#T@)T]U87)G;&$G.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G75LG,S(N,S@S
M.C,N.#$W)UT@/2`G1VAA<F1A:6$G.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G
M75LG,S,N,3$W.C8N,3,S)UT@/2`G5&]U9V=O=7)T)SL*)&-O;W)D:6YA=&5S
M6R=!;&=E<FEA)UU;)S,S+C4P,#HV+C$Q-R==(#T@)T5L($]U960G.PHD8V]O
M<F1I;F%T97-;)T%L9V5R:6$G75LG,S,N-S8W.C(N.3,S)UT@/2`G3&%G:&]U
M870G.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G75LG,S0N-C@S.C,N,C4P)UT@
M/2`G1&IE;&9A)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S,T+C@P,#HU
M+C<S,R==(#T@)T)I<VMR82<["B1C;V]R9&EN871E<ULG06QG97)I82==6R<S
M-"XY,S,Z+3`N-#,S)UT@/2`G365C:&5R:6$G.PHD8V]O<F1I;F%T97-;)T%L
M9V5R:6$G75LG,S4N,#$W.BTQ+C0V-R==(#T@)U1L96UC96X@6F5N871A)SL*
M)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S,U+C(P,#HM,"XQ,S,G72`]("=-
M87-C87)A+4=H<FES<R<["B1C;V]R9&EN871E<ULG06QG97)I82==6R<S-2XR
M-3`Z,2XT,S,G72`]("=4:6%R970G.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G
M75LG,S4N,S,S.C0N,C`P)UT@/2`G0F]U+5-A861A)SL*)&-O;W)D:6YA=&5S
M6R=!;&=E<FEA)UU;)S,U+C0X,SHX+C$S,R==(#T@)U1E8F5S<V$G.PHD8V]O
M<F1I;F%T97-;)T%L9V5R:6$G75LG,S4N-34P.C8N,3@S)UT@/2`G0F%T;F$G
M.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G75LG,S4N-C,S.BTP+C8P,"==(#T@
M)T]R86X@+R!%<R!396YI82<["B1C;V]R9&EN871E<ULG06QG97)I82==6R<S
M-BXQ.#,Z-2XT,3<G72`]("=3971I9B<["B1C;V]R9&EN871E<ULG06QG97)I
M82==6R<S-BXR,3<Z,2XS,S,G72`]("=#:&QE9B<["B1C;V]R9&EN871E<ULG
M06QG97)I82==6R<S-BXR.#,Z-BXV,3<G72`]("=#;VYS=&%N=&EN92<["B1C
M;V]R9&EN871E<ULG06QG97)I82==6R<S-BXW,3<Z,RXR-3`G72`]("=$87(M
M16PM0F5I9&$G.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G75LG,S8N-S$W.C4N
M,#8W)UT@/2`G0F5J86EA)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S,V
M+C@S,SHW+C@Q-R==(#T@)T%N;F%B82<["B1C;V]R9&EN871E<ULG06QG97)I
M82==6R<S-BXX.#,Z-2XX,3<G72`]("=*:6IE;"!!8VAO=6%T)SL*)&-O;W)D
M:6YA=&5S6R=!;&=E<FEA)UU;)S,V+CDS,SHV+CDU,"==(#T@)U-K:6MD82<[
M"B1C;V]R9&EN871E<ULG06YG;VQA)UU;)RTQ,BXS.#,Z,38N.34P)UT@/2`G
M0FEE(%-I;'9A(%!O<G1O)SL*)&-O;W)D:6YA=&5S6R=!;F=O;&$G75LG+3$R
M+C4X,SHQ,RXT,3<G72`]("=-;VYB86-A($)E;F=U96QA)SL*)&-O;W)D:6YA
M=&5S6R=!;F=O;&$G75LG+3$R+C@P,#HQ-2XW-3`G72`]("=(=6%M8F\@3F]V
M82!,:7-B;V$G.PHD8V]O<F1I;F%T97-;)T%N9V]L82==6R<M-2XU-3`Z,3(N
M,3@S)UT@/2`G0V%B:6YD82<["B1C;V]R9&EN871E<ULG06YG;VQA)UU;)RTX
M+C@U,#HQ,RXR,S,G72`]("=,=6%N9&$G.PHD8V]O<F1I;F%T97-;)T%N=&%R
M8W1I8V$G75LG+3<W+C@V-SHQ-C8N.38W)UT@/2`G5VEL;&EA;7,@1FEE;&0G
M.PHD8V]O<F1I;F%T97-;)T%N=&%R8W1I8V$G75LG+3DP+C`P,#HP+C`P,"==
M(#T@)T%M=6YD<V5N+5-C;W1T(%-O=71H(%!O;&4@4W1A=&EO;B<["B1C;V]R
M9&EN871E<ULG06YT:6=U82!A;F0@0F%R8G5D82==6R<Q-RXQ,3<Z+38Q+C<X
M,R==(#T@)U9C($)I<F0@26YT97)N871I;VYA;"!!:7)P;W)T($%N=&EG=6$G
M.PHD8V]O<F1I;F%T97-;)T%N=&EG=6$@86YD($)A<F)U9&$G75LG,3<N,C`P
M.BTV,BXU.#,G72`]("=#:&%R;&5S=&]W;B`O($YE=V-A<W0G.PHD8V]O<F1I
M;F%T97-;)T%R9V5N=&EN82==6R<M,C(N,3`P.BTV-2XV,#`G72`]("=,82!1
M=6EA8V$@3V)S97)V871O<FEO)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G
M75LG+3(R+C8U,#HM-C,N.#$W)UT@/2`G5&%R=&%G86P@065R;V1R;VUE)SL*
M)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3(S+C$U,#HM-C0N,S$W)UT@
M/2`G3W)A;B!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==
M6R<M,C0N,38W.BTV,BXY,#`G72`]("=2:79A9&%V:6$G.PHD8V]O<F1I;F%T
M97-;)T%R9V5N=&EN82==6R<M,C0N,S@S.BTV-2XP.#,G72`]("=*=6IU>2!!
M97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,C0N-S`P
M.BTV,"XU.#,G72`]("=,87,@3&]M:71A<R<["B1C;V]R9&EN871E<ULG07)G
M96YT:6YA)UU;)RTR-"XX-3`Z+38U+C0X,R==(#T@)U-A;'1A($%E<F]D<F]M
M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTR-2XW,S,Z+34T+C0V
M-R==(#T@)TEG=6%Z=2!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N
M=&EN82==6R<M,C8N,C`P.BTU."XR,S,G72`]("=&;W)M;W-A($%E<F]D<F]M
M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTR-BXX,3<Z+38P+C0U
M,"==(#T@)U!R97-I9&5N8VEA(%)O<75E(%-A96YZ(%!E;F$@065R;V1R;VUE
M)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3(V+C@U,#HM-C4N,3`P
M)UT@/2`G5'5C=6UA;B!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N
M=&EN82==6R<M,C<N,S8W.BTU-2XY-C<G72`]("=0;W-A9&%S($%E<F\N)SL*
M)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3(W+C0U,#HM-3@N-S8W)UT@
M/2`G0V]R<FEE;G1E<R!!97)O+B<["B1C;V]R9&EN871E<ULG07)G96YT:6YA
M)UU;)RTR-RXT-3`Z+34Y+C`U,"==(#T@)U)E<VES=&5N8VEA($%E<F\N)SL*
M)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3(W+C<V-SHM-C0N,S`P)UT@
M/2`G4V%N=&EA9V\@1&5L($5S=&5R;R!!97)O+B<["B1C;V]R9&EN871E<ULG
M07)G96YT:6YA)UU;)RTR."XP-C<Z+38W+C4V-R==(#T@)U1I;F]G87-T82<[
M"B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTR."XV,#`Z+38U+C<V-R==
M(#T@)T-A=&%M87)C82!!97)O+B<["B1C;V]R9&EN871E<ULG07)G96YT:6YA
M)UU;)RTR.2XR,3<Z+38W+C0S,R==(#T@)T-H:6QE8VET;R<["B1C;V]R9&EN
M871E<ULG07)G96YT:6YA)UU;)RTR.2XS.#,Z+38V+C@Q-R==(#T@)TQA(%)I
M;VIA($%E<F\N)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3(Y+C8X
M,SHM-3<N,34P)UT@/2`G4&%S;R!$92!,;W,@3&EB<F5S($%E<F]D<F]M92<[
M"B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTR.2XW.#,Z+34W+CDX,R==
M(#T@)T-U<G5Z=2!#=6%T:6$@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!
M<F=E;G1I;F$G75LG+3(Y+C@X,SHM-C$N.34P)UT@/2`G0V5R97,@065R;V1R
M;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3(Y+CDP,#HM-C,N
M-C@S)UT@/2`G5FEL;&$@1&4@36%R:6$@1&5L(%)I;R!396-O)SL*)&-O;W)D
M:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,P+C(U,#HM-C@N-S4P)UT@/2`G2F%C
M:&%L)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,P+C(V-SHM-3<N
M-C4P)UT@/2`G36]N=&4@0V%S97)O<R!!97)O9')O;64G.PHD8V]O<F1I;F%T
M97-;)T%R9V5N=&EN82==6R<M,S$N,S`P.BTU."XP,3<G72`]("=#;VYC;W)D
M:6$@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,Q
M+C,Q-SHM-C0N,C$W)UT@/2`G0V]R9&]B82!!97)O9')O;64G.PHD8V]O<F1I
M;F%T97-;)T%R9V5N=&EN82==6R<M,S$N,S,S.BTV-BXV,#`G72`]("=#:&5P
M97,G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S$N-38W.BTV."XX
M-C<G72`]("=386X@2G5A;B!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R
M9V5N=&EN82==6R<M,S$N-C8W.BTV,RXX.#,G72`]("=0:6QA<B!/8G-E<G9A
M=&]R:6\G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S$N-S`P.BTV
M,"XX,3<G72`]("=3875C92!6:65J;R!!97)O9')O;64G.PHD8V]O<F1I;F%T
M97-;)T%R9V5N=&EN82==6R<M,S$N-S@S.BTV,"XT.#,G72`]("=087)A;F$@
M065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,Q+C@U
M,#HM-3DN,#@S)UT@/2`G5FEL;&%G=6%Y($%E<F]D<F]M92<["B1C;V]R9&EN
M871E<ULG07)G96YT:6YA)UU;)RTS,2XY-3`Z+38U+C$S,R==(#T@)U9I;&QA
M($1O;&]R97,@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G
M75LG+3,R+C8P,#HM-CDN,S,S)UT@/2`G57-P86QL871A)SL*)&-O;W)D:6YA
M=&5S6R=!<F=E;G1I;F$G75LG+3,R+C<P,#HM-C(N,34P)UT@/2`G36%R8V]S
M($IU87)E>B!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==
M6R<M,S(N.#,S.BTV."XW.#,G72`]("=-96YD;WIA($%E<F]D<F]M92<["B1C
M;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS,BXY,3<Z+38P+C<X,R==(#T@
M)U)O<V%R:6\@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G
M75LG+3,S+C`P,#HM-3@N-C$W)UT@/2`G1W5A;&5G=6%Y8VAU($%E<F]D<F]M
M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS,RXP.#,Z+38X+C0Q
M-R==(#T@)U-A;B!-87)T:6XG.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==
M6R<M,S,N,3$W.BTV-"XR,S,G72`]("=2:6\@0W5A<G1O($%E<F]D<F]M92<[
M"B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS,RXR-C<Z+38V+C,U,"==
M(#T@)U-A;B!,=6ES($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT
M:6YA)UU;)RTS,RXW,S,Z+38U+C,X,R==(#T@)U9I;&QA(%)E>6YO;&1S($%E
M<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS,RXW-C<Z
M+38Y+C`S,R==(#T@)U-A;B!#87)L;W,G.PHD8V]O<F1I;F%T97-;)T%R9V5N
M=&EN82==6R<M,S0N,3,S.BTV,RXS-C<G72`]("=,86)O=6QA>64G.PHD8V]O
M<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S0N-#@S.BTU."XV,3<G72`]("=$
M;VX@5&]R8W5A=&\@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I
M;F$G75LG+3,T+C4U,#HM-C`N.3$W)UT@/2`G2G5N:6X@065R;V1R;VUE)SL*
M)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,T+C4V-SHM-3@N-#$W)UT@
M/2`G065R;W!A<G%U92!"<RX@07,N($%E<F]D<F]M92<["B1C;V]R9&EN871E
M<ULG07)G96YT:6YA)UU;)RTS-"XU.#,Z+34X+C0X,R==(#T@)T)U96YO<R!!
M:7)E<R!/8G-E<G9A=&]R:6\G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==
M6R<M,S0N-3@S.BTV."XT,#`G72`]("=386X@4F%F865L($%E<F]D<F]M92<[
M"B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS-"XV,#`Z+34X+C8P,"==
M(#T@)T5L(%!A;&]M87(@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E
M;G1I;F$G75LG+3,T+C@Q-SHM-3@N-3,S)UT@/2`G17IE:7IA($%E<F]D<F]M
M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS-"XY-C<Z+34W+CDP
M,"==(#T@)TQA(%!L871A($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G
M96YT:6YA)UU;)RTS-2XU,#`Z+38Y+C4X,R==(#T@)TUA;&%R9W5E($%E<F]D
M<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS-2XW,#`Z+38S
M+C<U,"==(#T@)T=E;F5R86P@4&EC;R!!97)O9')O;64G.PHD8V]O<F1I;F%T
M97-;)T%R9V5N=&EN82==6R<M,S4N.#8W.BTV,2XY,#`G72`]("=096AU86IO
M($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS-BXS
M-3`Z+34W+C<S,R==(#T@)T1O;&]R97,@065R;V1R;VUE)SL*)&-O;W)D:6YA
M=&5S6R=!<F=E;G1I;F$G75LG+3,V+C4V-SHM-C0N,C8W)UT@/2`G4V%N=&$@
M4F]S82!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M
M,S8N-S4P.BTU.2XX,S,G72`]("=!>G5L($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)T%R9V5N=&EN82==6R<M,S<N,C,S.BTU-RXP,S,G72`]("=6:6QL82!'
M97-E;&PG.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S<N,C,S.BTU
M.2XR-3`G72`]("=486YD:6P@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!
M<F=E;G1I;F$G75LG+3,W+C8P,#HM-C(N,S@S)UT@/2`G4&EG=64@065R;V1R
M;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,W+CDS,SHM-3<N
M-3@S)UT@/2`G36%R($1E;"!0;&%T82!!97)O9')O;64G.PHD8V]O<F1I;F%T
M97-;)T%R9V5N=&EN82==6R<M,S@N,S,S.BTV,"XR-3`G72`]("=4<F5S($%R
M<F]Y;W,G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S@N-S,S.BTV
M,BXQ-C<G72`]("="86AI82!";&%N8V$@065R;V1R;VUE)SL*)&-O;W)D:6YA
M=&5S6R=!<F=E;G1I;F$G75LG+3,X+CDU,#HM-C@N,3,S)UT@/2`G3F5U<75E
M;B!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,SDN
M,#$W.BTV-"XP.#,G72`]("=2:6\@0V]L;W)A9&\G.PHD8V]O<F1I;F%T97-;
M)T%R9V5N=&EN82==6R<M-#`N,#@S.BTW,2XQ,S,G72`]("=#:&%P96QC;R<[
M"B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTT,"XW.#,Z+38U+C$P,"==
M(#T@)U-A;B!!;G1O;FEO($]E<W1E($%E<F]D<F]M92<["B1C;V]R9&EN871E
M<ULG07)G96YT:6YA)UU;)RTT,"XX-3`Z+38S+C`Q-R==(#T@)U9I961M82!!
M97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M-#$N,34P
M.BTW,2XQ-C<G72`]("="87)I;&]C:&4@065R;V1R;VUE)SL*)&-O;W)D:6YA
M=&5S6R=!<F=E;G1I;F$G75LG+30Q+CDV-SHM-S$N-3$W)UT@/2`G16P@0F]L
M<V]N($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTT
M,BXY,S,Z+3<Q+C$U,"==(#T@)T5S<75E;"!!97)O9')O;64G.PHD8V]O<F1I
M;F%T97-;)T%R9V5N=&EN82==6R<M-#,N,C`P.BTV-2XR-C<G72`]("=4<F5L
M97<@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+30S
M+C@Q-SHM-C@N.#@S)UT@/2`G4&%S;R!$92!);F1I;W,G.PHD8V]O<F1I;F%T
M97-;)T%R9V5N=&EN82==6R<M-#4N-S@S.BTV-RXU,#`G72`]("=#;VUO9&]R
M;R!2:79A9&%V:6$@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I
M;F$G75LG+30V+C4Q-SHM-S$N,#$W)UT@/2`G4&5R:71O($UO<F5N;R!!97)O
M9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M-#<N-S,S.BTV
M-2XY,3<G72`]("=0=65R=&\@1&5S96%D;R!!97)O9')O;64G.PHD8V]O<F1I
M;F%T97-;)T%R9V5N=&EN82==6R<M-#@N-S@S.BTW,"XQ-C<G72`]("=';V)E
M<FYA9&]R($=R96=O<F5S($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G
M96YT:6YA)UU;)RTT.2XS,3<Z+38W+C<U,"==(#T@)U-A;B!*=6QI86X@065R
M;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+34P+C`Q-SHM
M-C@N-38W)UT@/2`G4V%N=&$@0W)U>B!!97)O9')O;64G.PHD8V]O<F1I;F%T
M97-;)T%R9V5N=&EN82==6R<M-3`N,S,S.BTW,BXS,#`G72`]("=,86=O($%R
M9V5N=&EN;R!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==
M6R<M-3$N-C$W.BTV.2XR.#,G72`]("=2:6\@1V%L;&5G;W,@065R;V1R;VUE
M)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+34S+C@P,#HM-C<N-S4P
M)UT@/2`G4FEO($=R86YD92!"+B!!+B<["B1C;V]R9&EN871E<ULG07)G96YT
M:6YA)UU;)RTU-"XX,#`Z+38X+C,Q-R==(#T@)U5S:'5A:6$@065R;V1R;VUE
M)SL*)&-O;W)D:6YA=&5S6R=!<FUE;FEA)UU;)S0P+C$S,SHT-"XT-C<G72`]
M("=997)E=F%N)SL*)&-O;W)D:6YA=&5S6R=!<G5B82==6R<Q,BXU,#`Z+3<P
M+C`Q-R==(#T@)U%U965N($)E871R:7@@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG075S=')A;&EA)UU;)RTQ,BXR-C<Z,3,V+C@Q-R==(#T@)T=O=F4@06ER
M<&]R="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTQ,BXT,#`Z,3,P
M+C@V-R==(#T@)T1A<G=I;B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T
M<F%L:6$G75LG+3$R+C8S,SHQ-#$N.#@S)UT@/2`G5V5I<&$@0VET>2<["B1C
M;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTQ-2XW-C<Z,3(X+C<P,"==(#T@
M)TMU;G5N=7)R82!+=6YU;G5R<F$@07=S)SL*)&-O;W)D:6YA=&5S6R=!=7-T
M<F%L:6$G75LG+3$V+C@X,SHQ-#4N-S4P)UT@/2`G0V%I<FYS($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,3<N,S`P.C$R,RXV,3<G
M72`]("=$97)B>2<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTQ-RXY
M-3`Z,3(R+C(Q-R==(#T@)T)R;V]M92!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S
M6R=!=7-T<F%L:6$G75LG+3$Y+C(U,#HQ-#8N-S4P)UT@/2`G5&]W;G-V:6QL
M92!!;6\G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,3DN-C,S.C$S
M-"XQ-C<G72`]("=496YN86YT($-R965K($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)T%U<W1R86QI82==6R<M,C`N,3`P.C$Q.2XU-C<G72`]("=0;W)T($AE
M9&QA;F0@4&%R9&]O)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3(P
M+C0X,SHQ-#@N-3,S)UT@/2`G4')O<V5R<&EN92!!:7)P;W)T)SL*)&-O;W)D
M:6YA=&5S6R=!=7-T<F%L:6$G75LG+3(P+C8V-SHQ,SDN-#8W)UT@/2`G36]U
M;G0@27-A($%M;R<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTR,2XQ
M,3<Z,30Y+C(P,"==(#T@)TUA8VMA>2!-;R<["B1C;V]R9&EN871E<ULG075S
M=')A;&EA)UU;)RTR,BXR,S,Z,3$T+C`X,R==(#T@)TQE87)M;VYT:"!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3(S+C,X,SHQ-3`N
M-#8W)UT@/2`G4F]C:VAA;7!T;VX@06ER<&]R="<["B1C;V]R9&EN871E<ULG
M075S=')A;&EA)UU;)RTR,RXT,S,Z,30T+C(V-R==(#T@)TQO;F=R96%C:"!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3(S+C@P,#HQ
M,S,N.#@S)UT@/2`G06QI8V4@4W!R:6YG<R!!97)O9')O;64G.PHD8V]O<F1I
M;F%T97-;)T%U<W1R86QI82==6R<M,C,N.#4P.C$U,2XR-3`G72`]("=';&%D
M<W1O;F4G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,C4N,3@S.C$S
M,"XY-C<G72`]("=9=6QA<F$@07=S)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L
M:6$G75LG+3(V+C0P,#HQ-#8N,C8W)UT@/2`G0VAA<FQE=FEL;&4@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTR-BXV,#`Z,3$X+C4S
M,R==(#T@)TUE96MA=&AA<G)A($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U
M<W1R86QI82==6R<M,C<N,S@S.C$U,RXQ,#`G72`]("="<FES8F%N92!!:7)P
M;W)T($TN($\G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,C<N-#$W
M.C$U,2XW,S,G72`]("=/86ME>2!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;
M)T%U<W1R86QI82==6R<M,C<N-38W.C$U,RXP,#`G72`]("=!<F-H97)F:65L
M9"!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,C<N
M-C,S.C$U,BXW,3<G72`]("=!;6)E<FQE>2!!97)O9')O;64G.PHD8V]O<F1I
M;F%T97-;)T%U<W1R86QI82==6R<M,C@N,38W.C$U,RXU,#`G72`]("=#;V]L
M86YG871T82!!:7)P;W)T($%W<R<["B1C;V]R9&EN871E<ULG075S=')A;&EA
M)UU;)RTR."XW.#,Z,3$T+C<P,"==(#T@)T=E<F%L9'1O;B!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3(Y+C`S,SHQ-C<N.3,S)UT@
M/2`G3F]R9F]L:R!)<VQA;F0@06ER<&]R="<["B1C;V]R9&EN871E<ULG075S
M=')A;&EA)UU;)RTS,"XS,3<Z,34S+C$Q-R==(#T@)T-O9F9S($AA<F)O=7(@
M36\G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S`N-3@S.C$S."XT
M,3<G72`]("=,96EG:"!#<F5E:R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=!
M=7-T<F%L:6$G75LG+3,P+C<X,SHQ,C$N-#4P)UT@/2`G2V%L9V]O<FQI92!"
M;W5L9&5R($%M;R<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS,"XX
M,S,Z,3(X+C$P,"==(#T@)T9O<G)E<W0@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG075S=')A;&EA)UU;)RTS,2XP.#,Z,34P+C@S,R==(#T@)U1A;7=O<G1H
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S$N,3,S
M.C$S-BXX,3<G72`]("=7;V]M97)A($%E<F]D<F]M92<["B1C;V]R9&EN871E
M<ULG075S=')A;&EA)UU;)RTS,2XV-C<Z,3$V+C`Q-R==(#T@)T)U;&QS8G)O
M;VL@4&5A<F-E($%M;R<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS
M,2XY,S,Z,3$U+CDU,"==(#T@)T)E;&UO;G0@4&5R=&@@06ER<&]R="<["B1C
M;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS,2XY-C<Z,30Q+C0V-R==(#T@
M)T)R;VME;B!(:6QL(%!A='1O;B!3=')E970G.PHD8V]O<F1I;F%T97-;)T%U
M<W1R86QI82==6R<M,S(N,3$W.C$S,RXW,#`G72`]("=#961U;F$@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS,BXR,#`Z,30X+C4V
M-R==(#T@)T1U8F)O)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3,R
M+C<X,SHQ-3$N.#$W)UT@/2`G5VEL;&EA;71O=VX@065R;V1R;VUE)SL*)&-O
M;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3,S+C8P,#HQ-3`N-S@S)UT@/2`G
M4FEC:&UO;F0@075S+4%F8B<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;
M)RTS,RXY,3<Z,34P+CDX,R==(#T@)T)A;FMS=&]W;B!!:7)P;W)T($%W<R<[
M"B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS,RXY-3`Z,34Q+C$X,R==
M(#T@)U-Y9&YE>2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G
M75LG+3,T+C`S,SHQ-3`N-C@S)UT@/2`G0V%M9&5N($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S0N,C$W.C$T,BXP.#,G72`]("=-
M:6QD=7)A($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M
M,S0N-S`P.C$S."XV,3<G72`]("=%9&EN8G5R9V@@32X@3RXG.PHD8V]O<F1I
M;F%T97-;)T%U<W1R86QI82==6R<M,S0N-S@S.C$S."XV,S,G72`]("=087)A
M9FEE;&0@06ER<&]R="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS
M-"XY,S,Z,3$W+C@P,"==(#T@)T%L8F%N>2!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R=!=7-T<F%L:6$G75LG+3,T+CDS,SHQ,S@N-3$W)UT@/2`G061E;&%I
M9&4@06ER<&]R="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS-"XY
M-3`Z,34P+C4S,R==(#T@)TYO=W)A(%)A;B!!:7(@4W1A=&EO;B<["B1C;V]R
M9&EN871E<ULG075S=')A;&EA)UU;)RTS-2XQ-3`Z,30W+C0U,"==(#T@)U=A
M9V=A($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S4N
M,S`P.C$T.2XQ.#,G72`]("=#86YB97)R82<["B1C;V]R9&EN871E<ULG075S
M=')A;&EA)UU;)RTS-BXP-C<Z,30V+CDU,"==(#T@)T%L8G5R>2!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3,V+C(S,SHQ-#DN,#@S
M)UT@/2`G0V]O;6$G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S<N
M-C8W.C$T-"XX,S,G72`]("=-96QB;W5R;F4@06ER<&]R="<["B1C;V]R9&EN
M871E<ULG075S=')A;&EA)UU;)RTS-RXW,S,Z,30P+C<X,R==(#T@)TUO=6YT
M($=A;6)I97(@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G
M75LG+3,W+C<S,SHQ-#4N-#`P)UT@/2`G1V]L9'-T<F5A;2!!=W,G.PHD8V]O
M<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S<N.#4P.C$T-"XW,S,G72`]("=,
M879E<G1O;B!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==
M6R<M,S<N.38W.C$T-2XQ,#`G72`]("=-;V]R86)B:6X@06ER<&]R="!!=W,G
M.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S@N,3`P.C$T-RXQ,S,G
M72`]("=%87-T(%-A;&4@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!=7-T
M<F%L:6$G75LG+30P+CDX,SHQ-#4N-S$W)UT@/2`G5WEN>6%R9"!797-T)SL*
M)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+30Q+C$V-SHQ-#8N,S8W)UT@
M/2`G1&5V;VYP;W)T($5A<W0G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==
M6R<M-#$N-3,S.C$T-RXR,#`G72`]("=,875N8V5S=&]N($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M-#(N.#,S.C$T-RXT.#,G72`]
M("=(;V)A<G0@06ER<&]R="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;
M)RTU-"XT.#,Z,34X+CDU,"==(#T@)TUA8W%U87)I92!)<VQA;F0G.PHD8V]O
M<F1I;F%T97-;)T%U<W1R:6$G75LG-#8N-C4P.C$T+C,S,R==(#T@)TML86=E
M;F9U<G0M1FQU9VAA9F5N)SL*)&-O;W)D:6YA=&5S6R=!=7-T<FEA)UU;)S0W
M+C`P,#HQ-2XT,S,G72`]("='<F%Z+51H86QE<FAO9BU&;'5G:&%F96XG.PHD
M8V]O<F1I;F%T97-;)T%U<W1R:6$G75LG-#<N,C`P.C$T+C<U,"==(#T@)UIE
M;'1W96<G.PHD8V]O<F1I;F%T97-;)T%U<W1R:6$G75LG-#<N,C8W.C$Q+C,U
M,"==(#T@)TEN;G-B<G5C:RU&;'5G:&%F96XG.PHD8V]O<F1I;F%T97-;)T%U
M<W1R:6$G75LG-#<N,S,S.C$Q+C<P,"==(#T@)U-C:'=A>B!(96QI<&]R="<[
M"B1C;V]R9&EN871E<ULG075S=')I82==6R<T-RXU,S,Z,30N,3,S)UT@/2`G
M06EG96X@26T@16YN<W1A;"<["B1C;V]R9&EN871E<ULG075S=')I82==6R<T
M-RXX,#`Z,3,N,#`P)UT@/2`G4V%L>F)U<F<M1FQU9VAA9F5N)SL*)&-O;W)D
M:6YA=&5S6R=!=7-T<FEA)UU;)S0W+CDV-#HQ-BXR-3DG72`]("=.:65D97)O
M<W1E<G)E:6-H("\@3'5G<&QA='H@(%9O<VQA=2<["B1C;V]R9&EN871E<ULG
M075S=')I82==6R<T."XQ,3<Z,38N-38W)UT@/2`G5VEE;B`O(%-C:'=E8VAA
M="U&;'5G:&%F96XG.PHD8V]O<F1I;F%T97-;)T%U<W1R:6$G75LG-#@N,C,S
M.C$T+C$X,R==(#T@)TAO<G-C:&EN9R!!=7,M069B)SL*)&-O;W)D:6YA=&5S
M6R=!=7-T<FEA)UU;)S0X+C(S,SHQ-"XQ.#,G72`]("=,:6YZ("\@2&]E<G-C
M:&EN9RU&;'5G:&%F96XG.PHD8V]O<F1I;F%T97-;)T%U<W1R:6$G75LG-#@N
M,S$W.C$V+C$Q-R==(#T@)U1U;&QN)SL*)&-O;W)D:6YA=&5S6R=!>F5R8F%I
M:F%N)UU;)S0P+C0U,#HU,"XP-C<G72`]("="86MU("\@0FEN92!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R="86AA;6%S)UU;)S(P+CDU,#HM-S,N-C@S)UT@
M/2`G36%T=&AE=R!4;W=N+"!);F%G=6$G.PHD8V]O<F1I;F%T97-;)T)A:&%M
M87,G75LG,C,N-#<U.BTW-2XW-C<G72`]("='96]R9V5T;W=N+"!%>'5M82<[
M"B1C;V]R9&EN871E<ULG0F%H86UA<R==6R<R-"XP-3`Z+3<T+C4S,R==(#T@
M)T-O8VMB=7)N(%1O=VXL(%-A;B!386QV861O<B<["B1C;V]R9&EN871E<ULG
M0F%H86UA<R==6R<R-2XP-3`Z+3<W+C0V-R==(#T@)TYA<W-A=2!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R="86AA;6%S)UU;)S(U+C<S,SHM-SDN,S`P)UT@
M/2`G06QI8V4@5&]W;BP@0FEM:6YI)SL*)&-O;W)D:6YA=&5S6R="86AA;6%S
M)UU;)S(V+C4U,#HM-S@N-S`P)UT@/2`G1G)E97!O<G0L($=R86YD($)A:&%M
M82<["B1C;V]R9&EN871E<ULG0F%H86UA<R==6R<R-BXW,#`Z+3<X+CDV-R==
M(#T@)U=E<W0@16YD+"!'<F%N9"!"86AA;6$G.PHD8V]O<F1I;F%T97-;)T)A
M:')A:6XG75LG,C8N,C8W.C4P+C8U,"==(#T@)T)A:')A:6X@26YT97)N871I
M;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R="86YG;&%D97-H)UU;)S(Q
M+C0S,SHY,2XY-C<G72`]("=#;WA<)W,@0F%Z87(G.PHD8V]O<F1I;F%T97-;
M)T)A;F=L861E<V@G75LG,C(N,C8W.CDQ+C@Q-R==(#T@)T-H:71T86=O;F<@
M4&%T96YG82<["B1C;V]R9&EN871E<ULG0F%N9VQA9&5S:"==6R<R,RXQ.#,Z
M.#DN,38W)UT@/2`G2F5S<V]R92<["B1C;V]R9&EN871E<ULG0F%N9VQA9&5S
M:"==6R<R,RXW-C<Z.3`N,S@S)UT@/2`G1&AA:V$G.PHD8V]O<F1I;F%T97-;
M)T)A;F=L861E<V@G75LG,C,N.#4P.CDP+C0P,"==(#T@)TMU<FUI=&]L82P@
M1&EA)SL*)&-O;W)D:6YA=&5S6R="86YG;&%D97-H)UU;)S(T+C$S,SHX.2XP
M-3`G72`]("=)<VAU<F1I)SL*)&-O;W)D:6YA=&5S6R="86YG;&%D97-H)UU;
M)S(T+C,V-SHX."XW,#`G72`]("=286IS:&%H:2<["B1C;V]R9&EN871E<ULG
M0F%N9VQA9&5S:"==6R<R-"XY,#`Z.3$N.#@S)UT@/2`G4WEL:&5T)SL*)&-O
M;W)D:6YA=&5S6R="87)B861O<R==6R<Q,RXP-C<Z+34Y+C0X,R==(#T@)T=R
M86YT;&5Y($%D86US)SL*)&-O;W)D:6YA=&5S6R="96QA<G5S)UU;)S4S+CDS
M,SHR-RXV,S,G72`]("=-:6YS:R<["B1C;V]R9&EN871E<ULG0F5L87)U<R==
M6R<U-2XQ-C<Z,S`N,C$W)UT@/2`G5FET96)S:R<["B1C;V]R9&EN871E<ULG
M0F5L9VEU;2==6R<T.2XY,#`Z-2XR,3<G72`]("="97)T<FEX($)E;"U!9F(G
M.PHD8V]O<F1I;F%T97-;)T)E;&=I=6TG75LG-3`N,#,S.C4N-#`P)UT@/2`G
M4W0M2'5B97)T)SL*)&-O;W)D:6YA=&5S6R="96QG:75M)UU;)S4P+C(S,SHT
M+C8U,"==(#T@)T9L;W)E;FYE<R<["B1C;V]R9&EN871E<ULG0F5L9VEU;2==
M6R<U,"XT-C<Z-"XT-3`G72`]("=#:&%R;&5R;VD@+R!';W-S96QI97,G.PHD
M8V]O<F1I;F%T97-;)T)E;&=I=6TG75LG-3`N-#8W.C8N,3@S)UT@/2`G16QS
M96YB;W)N)SL*)&-O;W)D:6YA=&5S6R="96QG:75M)UU;)S4P+C0X,SHU+CDQ
M-R==(#T@)U-P82`O($QA(%-A=79E;FEE<F4G.PHD8V]O<F1I;F%T97-;)T)E
M;&=I=6TG75LG-3`N-38W.C,N.#,S)UT@/2`G0VAI979R97,G.PHD8V]O<F1I
M;F%T97-;)T)E;&=I=6TG75LG-3`N-C4P.C4N-#4P)UT@/2`G0FEE<G-E="<[
M"B1C;V]R9&EN871E<ULG0F5L9VEU;2==6R<U,"XW-3`Z-"XW-C<G72`]("="
M96%U=F5C:&%I;B<["B1C;V]R9&EN871E<ULG0F5L9VEU;2==6R<U,"XW.#,Z
M-"XY-3`G72`]("=';V5T<V5N:&]V96XG.PHD8V]O<F1I;F%T97-;)T)E;&=I
M=6TG75LG-3`N.#`P.C4N,C`P)UT@/2`G4VEN="U4<G5I9&5N)SL*)&-O;W)D
M:6YA=&5S6R="96QG:75M)UU;)S4P+CDP,#HT+C4P,"==(#T@)TUE;'-B<F]E
M:R!"96PM069B)SL*)&-O;W)D:6YA=&5S6R="96QG:75M)UU;)S4P+CDP,#HT
M+C4S,R==(#T@)T)R=7AE;&QE<R!.871I;VYA;"<["B1C;V]R9&EN871E<ULG
M0F5L9VEU;2==6R<U,"XY,S,Z,RXW,S,G72`]("=-=6YT92<["B1C;V]R9&EN
M871E<ULG0F5L9VEU;2==6R<U,"XY,S,Z-2XU,#`G72`]("='96YK)SL*)&-O
M;W)D:6YA=&5S6R="96QG:75M)UU;)S4Q+C`P,#HU+C`V-R==(#T@)U-C:&%F
M9F5N)SL*)&-O;W)D:6YA=&5S6R="96QG:75M)UU;)S4Q+C`X,SHR+C8U,"==
M(#T@)TMO:W-I:F1E)SL*)&-O;W)D:6YA=&5S6R="96QG:75M)UU;)S4Q+C$V
M-SHU+C0V-R==(#T@)TML96EN92!"<F]G96PG.PHD8V]O<F1I;F%T97-;)T)E
M;&=I=6TG75LG-3$N,3@S.C,N.#$W)UT@/2`G1V5N="`O($EN9'5S=')I92U:
M;VYE)SL*)&-O;W)D:6YA=&5S6R="96QG:75M)UU;)S4Q+C(P,#HR+C@V-R==
M(#T@)T]O<W1E;F1E($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T)E;&=I=6TG
M75LG-3$N,C`P.C0N-#8W)UT@/2`G06YT=V5R<&5N("\@1&5U<FYE)SL*)&-O
M;W)D:6YA=&5S6R="96QG:75M)UU;)S4Q+C,S,SHT+C4P,"==(#T@)T)R87-S
M8VAA870G.PHD8V]O<F1I;F%T97-;)T)E;&=I=6TG75LG-3$N-#$W.C4N,#`P
M)UT@/2`G5V5E;&1E($UI;&ET87)Y)SL*)&-O;W)D:6YA=&5S6R="96QI>F4G
M75LG,3<N-3,S.BTX."XS,#`G72`]("="96QI>F4@+R!0:&EL;&EP($=O;&1S
M=&]N($EN=&PN($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T)E;FEN)UU;)S$P
M+C,Q-SHQ+C,X,R==(#T@)TYA=&ET:6YG;W4G.PHD8V]O<F1I;F%T97-;)T)E
M;FEN)UU;)S$Q+C$S,SHR+CDS,R==(#T@)TMA;F1I)SL*)&-O;W)D:6YA=&5S
M6R="96YI;B==6R<V+C,U,#HR+C,X,R==(#T@)T-O=&]N;W4G.PHD8V]O<F1I
M;F%T97-;)T)E;FEN)UU;)S<N,38W.C(N,#8W)UT@/2`G0F]H:6-O;B<["B1C
M;V]R9&EN871E<ULG0F5N:6XG75LG."XP,S,Z,BXT-C<G72`]("=3879E)SL*
M)&-O;W)D:6YA=&5S6R="96YI;B==6R<Y+C,U,#HR+C8Q-R==(#T@)U!A<F%K
M;W4G.PHD8V]O<F1I;F%T97-;)T)E<FUU9&$G75LG,S(N,S8W.BTV-"XV.#,G
M72`]("="97)M=61A)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ,"XX
M,3<Z+38U+C,U,"==(#T@)T=U87EA<F%M97)I;B<["B1C;V]R9&EN871E<ULG
M0F]L:79I82==6R<M,3$N,#`P.BTV-BXQ,3<G72`]("=2:6)E<F%L=&$G.PHD
M8V]O<F1I;F%T97-;)T)O;&EV:6$G75LG+3$Q+C`S,SHM-C@N-S@S)UT@/2`G
M0V]B:6IA)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ,RXP-C<Z+38T
M+C@Q-R==(#T@)U-A;B!*;V%Q=6EN)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA
M)UU;)RTQ,RXS,S,Z+38T+C$Q-R==(#T@)TUA9V1A;&5N82<["B1C;V]R9&EN
M871E<ULG0F]L:79I82==6R<M,3,N-S8W.BTV-2XT,S,G72`]("=386YT82!!
M;F$G.PHD8V]O<F1I;F%T97-;)T)O;&EV:6$G75LG+3$T+C,Q-SHM-C<N,S@S
M)UT@/2`G4F5Y97,G.PHD8V]O<F1I;F%T97-;)T)O;&EV:6$G75LG+3$T+C0V
M-SHM-C<N-38W)UT@/2`G4G5R<F5N86)A<75E)SL*)&-O;W)D:6YA=&5S6R="
M;VQI=FEA)UU;)RTQ-"XW,S,Z+38X+C4P,"==(#T@)T%P;VQO)SL*)&-O;W)D
M:6YA=&5S6R=";VQI=FEA)UU;)RTQ-"XX,3<Z+38T+CDQ-R==(#T@)U1R:6YI
M9&%D)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ-"XX-C<Z+38V+C@V
M-R==(#T@)U-A;B!";W)J82<["B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M
M,30N.3$W.BTV-2XV,#`G72`]("=386X@26=N86-I;R!$92!-;WAO<R<["B1C
M;V]R9&EN871E<ULG0F]L:79I82==6R<M,34N-S$W.BTV,RXQ,#`G72`]("=!
M<V-E;F-I;VX@1&4@1W5A<F%Y;W,G.PHD8V]O<F1I;F%T97-;)T)O;&EV:6$G
M75LG+3$V+C$U,#HM-C(N,#$W)UT@/2`G0V]N8V5P8VEO;B<["B1C;V]R9&EN
M871E<ULG0F]L:79I82==6R<M,38N,C8W.BTV,BXT-C<G72`]("=386X@2F%V
M:65R)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ-BXS.#,Z+38P+CDV
M-R==(#T@)U-A;B!)9VYA8VEO($1E(%9E;&%S8V\G.PHD8V]O<F1I;F%T97-;
M)T)O;&EV:6$G75LG+3$V+C4Q-SHM-C@N,3@S)UT@/2`G3&$@4&%Z("\@06QT
M;R<["B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M,3<N-#$W.BTV-BXQ.#,G
M72`]("=#;V-H86)A;6)A)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ
M-RXU.#,Z+38Y+C8P,"==(#T@)T-H87)A;F$G.PHD8V]O<F1I;F%T97-;)T)O
M;&EV:6$G75LG+3$W+C8S,SHM-C,N,3,S)UT@/2`G5FER=2U6:7)U)SL*)&-O
M;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ-RXX,#`Z+38P+C<S,R==(#T@)U-A
M;B!*;W-E($1E($-H:7%U:71O<R<["B1C;V]R9&EN871E<ULG0F]L:79I82==
M6R<M,3<N.#`P.BTV,RXQ.#,G72`]("=386YT82!#<G5Z("\@16P@5')O;7!I
M;&QO)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ-RXY-C<Z+38W+C`V
M-R==(#T@)T]R=7)O)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ."XS
M,3<Z+34Y+C<V-R==(#T@)U)O8F]R92<["B1C;V]R9&EN871E<ULG0F]L:79I
M82==6R<M,3@N.3@S.BTU-RXX,3<G72`]("=0=65R=&\@4W5A<F5Z)SL*)&-O
M;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ.2XP,3<Z+38U+C,P,"==(#T@)U-U
M8W)E)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ.2XU-3`Z+38U+C<S
M,R==(#T@)U!O=&]S:2<["B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M,C`N
M,#`P.BTV,RXU,S,G72`]("=#86UI<FDG.PHD8V]O<F1I;F%T97-;)T)O;&EV
M:6$G75LG+3(Q+C(U,#HM-C,N-#4P)UT@/2`G5FEL;&%M;VYT97,G.PHD8V]O
M<F1I;F%T97-;)T)O;&EV:6$G75LG+3(Q+C4U,#HM-C0N-S`P)UT@/2`G5&%R
M:6IA)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTR,2XY-3`Z+38S+C8U
M,"==(#T@)UEA8W5I8F$G.PHD8V]O<F1I;F%T97-;)T)O<VYI82!A;F0@2&5R
M>F5G;W9I;F$G75LG-#,N.#,S.C$W+C`Q-R==(#T@)TQI=FYO)SL*)&-O;W)D
M:6YA=&5S6R=";W1S=V%N82==6R<M,3<N.#$W.C(U+C$U,"==(#T@)TMA<V%N
M92<["B1C;V]R9&EN871E<ULG0F]T<W=A;F$G75LG+3$X+C,V-SHR,2XX-3`G
M72`]("=3:&%K87=E)SL*)&-O;W)D:6YA=&5S6R=";W1S=V%N82==6R<M,3DN
M.3@S.C(S+C0Q-R==(#T@)TUA=6XG.PHD8V]O<F1I;F%T97-;)T)O='-W86YA
M)UU;)RTR,"XT-C<Z,C4N.3@S)UT@/2`G4W5A+5!A;B<["B1C;V]R9&EN871E
M<ULG0F]T<W=A;F$G75LG+3(Q+C(Q-SHR-RXU,#`G72`]("=&<F%N8VES=&]W
M;B<["B1C;V]R9&EN871E<ULG0F]T<W=A;F$G75LG+3(Q+C0Q-SHR-2XV,#`G
M72`]("=,971L:&%K86YE)SL*)&-O;W)D:6YA=&5S6R=";W1S=V%N82==6R<M
M,C$N-S`P.C(Q+C8U,"==(#T@)T=H86YZ:2<["B1C;V]R9&EN871E<ULG0F]T
M<W=A;F$G75LG+3(T+C`Q-SHR,2XX.#,G72`]("=4<VAA;F4G.PHD8V]O<F1I
M;F%T97-;)T)O='-W86YA)UU;)RTR-"XR,3<Z,C4N.3$W)UT@/2`G4V5R971S
M92!+:&%M82!);G1E<FYA=&EO;F%L($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;
M)T)O='-W86YA)UU;)RTR-"XV,#`Z,C0N-C8W)UT@/2`G2G=A;F5N9R<["B1C
M;V]R9&EN871E<ULG0F]T<W=A;F$G75LG+3(V+C`U,#HR,BXT-3`G72`]("=4
M<V%B;VYG)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG,"XP,S,Z+34P+C`U
M,"==(#T@)TUA8V%P82<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTP+C$S
M,SHM-C<N,#@S)UT@/2`G4V%O($=A8G)I96P@1&$@0V%C:&]E:7)A)SL*)&-O
M;W)D:6YA=&5S6R="<F%Z:6PG75LG,"XV,3<Z+38Y+C(P,"==(#T@)TEA=6%R
M971E)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3`N.3@S.BTV,BXU.#,G
M72`]("="87)C96QO<R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTQ+C,X
M,SHM-#@N-#@S)UT@/2`G0F5L96T@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S
M6R="<F%Z:6PG75LG+3$P+C`P,#HM-C<N.#`P)UT@/2`G4FEO($)R86YC;R<[
M"B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTQ,"XW,#`Z+30X+C0P,"==(#T@
M)U!O<G1O($YA8VEO;F%L($%E<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A
M>FEL)UU;)RTQ,"XY.#,Z+3,W+C`V-R==(#T@)T%R86-A:G4@065R;W!O<G1O
M)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3$R+C<P,#HM-C`N,3`P)UT@
M/2`G5FEL:&5N82!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==
M6R<M,3(N.3`P.BTS."XS,S,G72`]("=386QV861O<B!!97)O<&]R=&\G.PHD
M8V]O<F1I;F%T97-;)T)R87II;"==6R<M,3,N,C8W.BTT,RXT,3<G72`]("="
M;VT@2F5S=7,@1&$@3&%P82<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTQ
M-"XW,#`Z+34R+C,U,"==(#T@)UAA=F%N=&EN82<["B1C;V]R9&EN871E<ULG
M0G)A>FEL)UU;)RTQ-"XX,3<Z+3,Y+C`S,R==(#T@)TEL:&5U<R!!97)O<&]R
M=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,30N.34P.BTT,"XX.#,G
M72`]("=6:71O<FEA($1A($-O;G%U:7-T82<["B1C;V]R9&EN871E<ULG0G)A
M>FEL)UU;)RTQ-2XV-3`Z+34V+C$P,"==(#T@)T-U:6%B82!!97)O<&]R=&\G
M.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,34N.#8W.BTT-RXY,S,G72`]
M("="<F%S:6QI82!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==
M6R<M,34N.#8W.BTU,BXS.#,G72`]("="87)R82!$;R!'87)C87,G.PHD8V]O
M<F1I;F%T97-;)T)R87II;"==6R<M,38N,#4P.BTT."XP-3`G72`]("='86UA
M)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3$V+C(S,SHM-#@N.38W)UT@
M/2`G06YA<&]L:7,@0G)A>BU!9F(G.PHD8V]O<F1I;F%T97-;)T)R87II;"==
M6R<M,38N-C,S.BTT.2XR,3<G72`]("=';VEA;FEA($%E<F]P;W)T;R<["B1C
M;V]R9&EN871E<ULG0G)A>FEL)UU;)RTQ-BXW,3<Z+30S+C@V-R==(#T@)TUO
M;G1E<R!#;&%R;W,G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,3<N-C,S
M.BTS.2XR-3`G72`]("=#87)A=F5L87,@065R;W!O<BU4;R<["B1C;V]R9&EN
M871E<ULG0G)A>FEL)UU;)RTQ.2XP.#,Z+34W+C4P,"==(#T@)T-O<G5M8F$G
M.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,3DN-S@S.BTT-RXY-C<G72`]
M("=58F5R86)A)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3$Y+C@U,#HM
M-#,N.34P)UT@/2`G0F5L;R!(;W)I>F]N=&4@065R;W!O<G1O)SL*)&-O;W)D
M:6YA=&5S6R="<F%Z:6PG75LG+3$Y+CDS,SHM-#,N.3,S)UT@/2`G0F5L;R!(
M;W)I>F]N=&4G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,BXT,S,Z+34T
M+C<Q-R==(#T@)U-A;G1A<F5M+4%E<F]P;W)T;R<["B1C;V]R9&EN871E<ULG
M0G)A>FEL)UU;)RTR+C8P,#HM-#0N,C,S)UT@/2`G4V%O($QU:7H@065R;W!O
M<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG,BXX,S,Z+38P+C<P,"==
M(#T@)T)O82!6:7-T82!!97)O<&]R+51O)SL*)&-O;W)D:6YA=&5S6R="<F%Z
M:6PG75LG+3(N.3$W.BTT,2XW-3`G72`]("=087)N86EB82!!97)O<&]R=&\G
M.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C`N,C8W.BTT,"XR.#,G72`]
M("=6:71O<FEA($%E<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;
M)RTR,"XT-C<Z+34T+C8V-R==(#T@)T-A;7!O($=R86YD92!!97)O<&]R=&\G
M.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C$N,C4P.BTT,RXW-C<G72`]
M("="87)B86-E;F$G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C$N-S4P
M.BTT,2XS,S,G72`]("=#86UP;W,G.PHD8V]O<F1I;F%T97-;)T)R87II;"==
M6R<M,C$N-S8W.BTT,RXS-3`G72`]("=*=6EZ($1E($9O<F$G.PHD8V]O<F1I
M;F%T97-;)T)R87II;"==6R<M,C$N.#4P.BTT-BXU-C<G72`]("=0;V-O<R!$
M92!#86QD87,G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C$N.3@S.BTT
M-RXS,S,G72`]("=0:7)A<W-U;G5N9V$G.PHD8V]O<F1I;F%T97-;)T)R87II
M;"==6R<M,C(N,#$W.BTT-RXX.#,G72`]("=386\@0V%R;&]S)SL*)&-O;W)D
M:6YA=&5S6R="<F%Z:6PG75LG+3(R+C$Q-SHM-3$N,S@S)UT@/2`G4')E<VED
M96YT92!0<G5D96YT92<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR,BXS
M,3<Z+30Y+C`V-R==(#T@)T)A=7)U)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG
M75LG+3(R+C0X,SHM-#0N-#8W)UT@/2`G4F5S96YD92<["B1C;V]R9&EN871E
M<ULG0G)A>FEL)UU;)RTR,BXU-3`Z+34U+C<P,"==(#T@)U!O;G1A(%!O<F$@
M065R;W!O<BU4;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR,BXW.#,Z
M+30U+C(P,"==(#T@)T=U87)A=&EN9W5E=&$G.PHD8V]O<F1I;F%T97-;)T)R
M87II;"==6R<M,C(N.#$W.BTT,BXQ,#`G72`]("=3+B!0+B!!;&1E:6$@065R
M;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(R+C@Q-SHM-#,N
M,C4P)UT@/2`G1V%L96%O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(R
M+C@V-SHM-#,N,S8W)UT@/2`G069O;G-O<R!!97)O<&]R=&\G.PHD8V]O<F1I
M;F%T97-;)T)R87II;"==6R<M,C(N.3`P.BTT,RXQ-C<G72`]("=2:6\@1&4@
M2F%N96ER;R!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M
M,C(N.3,S.BTT,RXW,3<G72`]("=386YT82!#<G5Z($%E<F]P;W(M5&\G.PHD
M8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C(N.3@S.BTT,RXS-C<G72`]("=2
M:6\@+R!*86-A<F5P86=U82<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR
M,RXP,#`Z+30W+C$S,R==(#T@)T-A;7!I;F%S($%E<F]P;W)T;R<["B1C;V]R
M9&EN871E<ULG0G)A>FEL)UU;)RTR,RXS,S,Z+34Q+C$S,R==(#T@)TQO;F1R
M:6YA($%E<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR,RXT
M,3<Z+34Q+CDU,"==(#T@)TUA<FEN9V$G.PHD8V]O<F1I;F%T97-;)T)R87II
M;"==6R<M,C,N-3$W.BTT-BXV,S,G72`]("=-87)T92!#:78@+R!-:6PG.PHD
M8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C,N-C$W.BTT-BXV-3`G72`]("=3
M86\@4&%U;&\@065R;W!O<BU4;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;
M)RTR,RXY,S,Z+30V+C,P,"==(#T@)U-A;G1O<R!!97)O<&]R=&\G.PHD8V]O
M<F1I;F%T97-;)T)R87II;"==6R<M,C4N-#,S.BTT.2XR-C<G72`]("=#=7)I
M=&EB82<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR-2XU,3<Z+30X+C4Q
M-R==(#T@)U!A<F%N86=U82<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR
M-2XU,3<Z+30Y+C$V-R==(#T@)T-U<FET:6)A($%E<F]P;W)T;R<["B1C;V]R
M9&EN871E<ULG0G)A>FEL)UU;)RTR-2XU,3<Z+34T+C4X,R==(#T@)T9O>B!$
M;R!)9W5A8W4@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG
M+3(W+C8V-SHM-#@N-34P)UT@/2`G1FQO<FEA;F]P;VQI<R!!97)O<&]R=&\G
M.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C@N,C4P.BTU,BXT,#`G72`]
M("=087-S;R!&=6YD;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR.2XW
M,3<Z+34S+C<P,"==(#T@)U-A;G1A($UA<FEA($%E<F\M4&]R=&\G.PHD8V]O
M<F1I;F%T97-;)T)R87II;"==6R<M,CDN-S@S.BTU-RXP,S,G72`]("=5<G5G
M=6%I86YA($%E<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTS
M+C`S,SHM-C`N,#4P)UT@/2`G161U87)D;R!';VUE<R!);G1E<FYA=&EO;F%L
M)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3,N,34P.BTU.2XY.#,G72`]
M("=-86YA=7,@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG
M+3,N,C`P.BTU,BXR,#`G72`]("=!;'1A;6ER82<["B1C;V]R9&EN871E<ULG
M0G)A>FEL)UU;)RTS+C,V-SHM-C0N-C@S)UT@/2`G5&5F92<["B1C;V]R9&EN
M871E<ULG0G)A>FEL)UU;)RTS+C8V-SHM-CDN-C8W)UT@/2`G5&%B871I;F=A
M)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3,N-S$W.BTT.2XW,3<G72`]
M("=4=6-U<G5I)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3,N-S@S.BTS
M."XU,S,G72`]("=&;W)T86QE>F$@065R;W!O<BU4;R<["B1C;V]R9&EN871E
M<ULG0G)A>FEL)UU;)S,N.#,S.BTU,2XX,S,G72`]("=/:6%P;W%U92<["B1C
M;V]R9&EN871E<ULG0G)A>FEL)UU;)RTS+C@U,#HM,S(N-#$W)UT@/2`G1F5R
M;F%N9&\@1&4@3F]R;VYH82<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTS
M,"XP,#`Z+34Q+C$X,R==(#T@)U!O<G1O($%L96=R92!!97)O+5!O<G1O)SL*
M)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3,P+C`Q-SHM-3$N,C$W)UT@/2`G
M4&]R=&\@06QE9W)E)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3,Q+C,U
M,#HM-30N,3$W)UT@/2`G0F%G92!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;
M)T)R87II;"==6R<M,S$N.#8W.BTU,BXS-3`G72`]("=096QO=&%S)SL*)&-O
M;W)D:6YA=&5S6R="<F%Z:6PG75LG+30N,C4P.BTU-BXP,#`G72`]("=)=&%I
M='5B82<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTT+C,X,SHM-S`N,#,S
M)UT@/2`G0F5N:F%M:6X@0V]N<W1A;G0G.PHD8V]O<F1I;F%T97-;)T)R87II
M;"==6R<M-2XP-3`Z+30R+C@Q-R==(#T@)U1E<F5S:6YA($%E<F]P;W)T;R<[
M"B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTU+C(P,#HM,S<N,S8W)UT@/2`G
M36]C;W)O("\@,3<@4F]S861O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG
M+34N,S4P.BTT.2XQ-3`G72`]("=-87)A8F$G.PHD8V]O<F1I;F%T97-;)T)R
M87II;"==6R<M-2XU,S,Z+30W+C4P,"==(#T@)TEM<&5R871R:7HG.PHD8V]O
M<F1I;F%T97-;)T)R87II;"==6R<M-2XX,3<Z+38Q+C,P,"==(#T@)TUA;FEC
M;W)E)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+34N.3$W.BTS-2XR-3`G
M72`]("=.871A;"!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==
M6R<M-BXR-C<Z+34W+C<S,R==(#T@)TIA8V%R96%C86YG82<["B1C;V]R9&EN
M871E<ULG0G)A>FEL)UU;)RTW+C$P,#HM,S0N.#8W)UT@/2`G2F]A;R!097-S
M;V$G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M-RXR,3<Z+3,U+C@X,R==
M(#T@)T-A;7!I;F$@1W)A;F1E)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG
M+3<N,S$W.BTT-RXT-C<G72`]("=-87)A;FAA;R`O($-A<F]L:6YA($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M-RXV,S,Z+3<R+C8V-R==
M(#T@)T-R=7IE:7)O($1O(%-U;"<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;
M)RTX+C`V-SHM,S0N.#4P)UT@/2`G4F5C:69E($%E<F]P;W)T;R<["B1C;V]R
M9&EN871E<ULG0G)A>FEL)UU;)RTX+C$V-SHM-S`N-S8W)UT@/2`G5&%R875A
M8V$G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M."XR-3`Z+30Y+C(X,R==
M(#T@)T-O;F-E:6-A;R!$;R!!<F%G=6%I82<["B1C;V]R9&EN871E<ULG0G)A
M>FEL)UU;)RTX+C<V-SHM-C,N.3$W)UT@/2`G4&]R=&\@5F5L:&\@065R;W!O
M<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3DN,S4P.BTT,"XU-3`G
M72`]("=0971R;VQI;F$@065R;W!O<BU4;R<["B1C;V]R9&EN871E<ULG0G)A
M>FEL)UU;)RTY+C0P,#HM,S@N,C$W)UT@/2`G4&%U;&\@069O;G-O)SL*)&-O
M;W)D:6YA=&5S6R="<F%Z:6PG75LG+3DN-3$W.BTS-2XW.#,G72`]("=-86-E
M:6\@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3DN.#8W
M.BTU-BXQ,#`G72`]("=!;'1A($9L;W)E<W1A($%E<F]P;W)T;R<["B1C;V]R
M9&EN871E<ULG0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y)UU;)RTW
M+C,P,#HW,BXT,#`G72`]("=$:65G;R!'87)C:6$G.PHD8V]O<F1I;F%T97-;
M)T)R=6YE:2!$87)U<W-A;&%M)UU;)S0N.3,S.C$Q-"XY,S,G72`]("="<G5N
M96D@06ER<&]R="<["B1C;V]R9&EN871E<ULG0G5L9V%R:6$G75LG-#(N,3,S
M.C(T+C<U,"==(#T@)U!L;W9D:78G.PHD8V]O<F1I;F%T97-;)T)U;&=A<FEA
M)UU;)S0R+C0X,SHR-RXT.#,G72`]("="=7)G87,G.PHD8V]O<F1I;F%T97-;
M)T)U;&=A<FEA)UU;)S0R+C8U,#HR,RXS.#,G72`]("=3;V9I82!/8G-E<G8N
M)SL*)&-O;W)D:6YA=&5S6R="=6QG87)I82==6R<T,RXR,#`Z,C<N.3$W)UT@
M/2`G5F%R;F$G.PHD8V]O<F1I;F%T97-;)T)U;&=A<FEA)UU;)S0S+C@U,#HR
M-2XY-3`G72`]("=2;W5S<V4G.PHD8V]O<F1I;F%T97-;)T)U<FMI;F$@1F%S
M;R==6R<Q,"XS,S,Z+3,N,3@S)UT@/2`G1V%O=6$G.PHD8V]O<F1I;F%T97-;
M)T)U<FMI;F$@1F%S;R==6R<Q,2XQ-3`Z+3$N,34P)UT@/2`G4&\G.PHD8V]O
M<F1I;F%T97-;)T)U<FMI;F$@1F%S;R==6R<Q,2XQ-C<Z+30N,S$W)UT@/2`G
M0F]B;RU$:6]U;&%S<V\G.PHD8V]O<F1I;F%T97-;)T)U<FMI;F$@1F%S;R==
M6R<Q,2XW-3`Z+3(N.3,S)UT@/2`G0F]R;VUO)SL*)&-O;W)D:6YA=&5S6R="
M=7)K:6YA($9A<V\G75LG,3(N,#,S.C`N,S8W)UT@/2`G1F%D82!.7"=';W5R
M;6$G.PHD8V]O<F1I;F%T97-;)T)U<FMI;F$@1F%S;R==6R<Q,BXS-3`Z+3$N
M-3$W)UT@/2`G3W5A9V%D;W5G;W4G.PHD8V]O<F1I;F%T97-;)T)U<FMI;F$@
M1F%S;R==6R<Q,BXT-C<Z+3,N-#@S)UT@/2`G1&5D;W5G;W4G.PHD8V]O<F1I
M;F%T97-;)T)U<FMI;F$@1F%S;R==6R<Q,RXU-C<Z+3(N-#$W)UT@/2`G3W5A
M:&EG;W5Y82<["B1C;V]R9&EN871E<ULG0G5R:VEN82!&87-O)UU;)S$T+C`S
M,SHM,"XP,S,G72`]("=$;W)I)SL*)&-O;W)D:6YA=&5S6R="=7)U;F1I)UU;
M)RTS+C,Q-SHR.2XS,3<G72`]("="=6IU;6)U<F$G.PHD8V]O<F1I;F%T97-;
M)T-A;6)O9&EA)UU;)S$Q+C4U,#HQ,#0N.#4P)UT@/2`G4&AN;VTM4&5N:"`O
M(%!O8VAE;G1O;F<G.PHD8V]O<F1I;F%T97-;)T-A;6)O9&EA)UU;)S$R+C`P
M,#HQ,#4N-#4P)UT@/2`G2V]M<&]N9RU#:&%M)SL*)&-O;W)D:6YA=&5S6R=#
M86UB;V1I82==6R<Q,RXS-C<Z,3`S+C@U,"==(#T@)U-I96UR96%P)SL*)&-O
M;W)D:6YA=&5S6R=#86UE<F]O;B==6R<Q,"XT-3`Z,30N,C4P)UT@/2`G36%R
M;W5A+5-A;&%K)SL*)&-O;W)D:6YA=&5S6R=#86UE<F]O;B==6R<R+CDU,#HY
M+CDP,"==(#T@)TMR:6)I)SL*)&-O;W)D:6YA=&5S6R=#86UE<F]O;B==6R<S
M+C$U,#HQ,RXV,3<G72`]("=,;VUI92<["B1C;V]R9&EN871E<ULG0V%M97)O
M;VXG75LG,RXX,S,Z,3$N-3$W)UT@/2`G66%O=6YD92<["B1C;V]R9&EN871E
M<ULG0V%M97)O;VXG75LG,RXY-C<Z,3,N,C`P)UT@/2`G06)O;F<M36)A;F<G
M.PHD8V]O<F1I;F%T97-;)T-A;65R;V]N)UU;)S0N,#`P.CDN-S,S)UT@/2`G
M1&]U86QA($]B<RXG.PHD8V]O<F1I;F%T97-;)T-A;65R;V]N)UU;)S0N,#@S
M.CDN,S8W)UT@/2`G5&EK;R<["B1C;V]R9&EN871E<ULG0V%M97)O;VXG75LG
M-"XT-C<Z,30N,S8W)UT@/2`G0F%T;W5R:2<["B1C;V]R9&EN871E<ULG0V%M
M97)O;VXG75LG-"XW,S,Z,3$N,C4P)UT@/2`G0F%F:6$G.PHD8V]O<F1I;F%T
M97-;)T-A;65R;V]N)UU;)S0N.34P.CDN.3,S)UT@/2`G3FMO;F=S86UB82<[
M"B1C;V]R9&EN871E<ULG0V%M97)O;VXG75LG-2XU-3`Z,3(N,S8W)UT@/2`G
M66]K;R<["B1C;V]R9&EN871E<ULG0V%M97)O;VXG75LG-2XV,#`Z,30N,#8W
M)UT@/2`G0F5T87)E+4]Y82<["B1C;V]R9&EN871E<ULG0V%M97)O;VXG75LG
M-2XV-3`Z,3`N-S4P)UT@/2`G2V]U;F1J82<["B1C;V]R9&EN871E<ULG0V%M
M97)O;VXG75LG-2XW,3<Z.2XR.#,G72`]("=-86UF92<["B1C;V]R9&EN871E
M<ULG0V%M97)O;VXG75LG-BXP-3`Z,3`N,3$W)UT@/2`G0F%M96YD82<["B1C
M;V]R9&EN871E<ULG0V%M97)O;VXG75LG-BXU,S,Z,30N,S8W)UT@/2`G365I
M9V%N9V$G.PHD8V]O<F1I;F%T97-;)T-A;65R;V]N)UU;)S8N-S@S.C$Q+C@Q
M-R==(#T@)T)A;GEO)SL*)&-O;W)D:6YA=&5S6R=#86UE<F]O;B==6R<W+C,U
M,#HQ,RXU-C<G72`]("=.9V%O=6YD97)E)SL*)&-O;W)D:6YA=&5S6R=#86UE
M<F]O;B==6R<Y+C,S,SHQ,RXS.#,G72`]("='87)O=6$G.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T,2XX,S,Z+3@R+C0V-R==(#T@)U,N($4N(%-H;V%L
M($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES
M=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#(N,C4P.BTX,2XY,#`G
M72`]("=%<FEE874@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E
M;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T,BXR
M-C<Z+3@R+CDV-R==(#T@)U=I;F1S;W(L($]N="XG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<T,BXS,#`Z+3@R+C<P,"==(#T@)T)E;&QE(%)I=F5R)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#(N-38W.BTX,"XP-3`G72`]("=,
M;VYG(%!O:6YT($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT
M871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#(N.#4P
M.BTX,"XR-C<G72`]("=3:6UC;V4L($]N="XG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T,BXX-C<Z+3<Y+C(U,"==(#T@)U!O<G0@0V]L8F]R;F4@075T
M;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#(N.#8W.BTX,"XU-3`G72`]("=$96QH:2!#4RP@3VYT+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S0S+C`P,#HM.#(N,S$W)UT@/2`G4V%R
M;FEA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T,RXP,S,Z
M+3@Q+C$U,"==(#T@)TQO;F1O;BP@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0S+C$V-SHM-SDN.3,S)UT@/2`G2&%M:6QT;VX@06ER<&]R="<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0S+C(U,#HM-SDN,C$W)UT@/2`G
M4&]R="!796QL97(L($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M,RXS,#`Z+3<Y+C@P,"==(#T@)T)U<FQI;F=T;VX@4&EE<G,G.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T,RXT-C<Z+3@P+C,X,R==(#T@)U=A=&5R;&]O
M(%=E;&PG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T,RXV,3<Z+3<Y+C,U
M,"==(#T@)U1O<F]N=&\@2&5A9&QA;F0G.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T,RXV,S,Z+3<Y+C0P,"==(#T@)U1O<F]N=&\@27-L86YD($%I<G!O
M<G0@075T;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#,N-C8W.BTW.2XV,S,G72`]("=4;W)O;G1O(%!E87)S
M;VX@26YT7"=,+B!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#,N
M-S8W.BTX,2XW,3<G72`]("=';V1E<FEC:"!!=71O;6%T:6,@5V5A=&AE<B!2
M97!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#,N
M-S@S.BTW.2XT-C<G72`]("=4;W)O;G1O($%E<R!(<2<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0S+C@S,SHM-C8N,#@S)UT@/2`G66%R;6]U=&@L($XN
M(%,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#,N.#,S.BTW-RXQ-3`G
M72`]("=0;VEN="!0971R92P@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0S+CDS,SHM-C`N,#$W)UT@/2`G4V%B;&4@27-L86YD+"!.+B!3+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0S+CDU,#HM-S@N,38W)UT@/2`G
M0V]B;W5R9RP@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0S+CDX
M,SHM-C0N-C8W)UT@/2`G5V5S=&5R;B!(96%D+"!.+B!3+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0S+CDX,SHM.#`N-S4P)UT@/2`G36]U;G0@1F]R
M97-T+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#0N,3$W.BTW
M-RXU,S,G72`]("=4<F5N=&]N+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#0N,C$W.BTW-BXV,#`G72`]("=+:6YG<W1O;BP@3VYT+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S0T+C(S,SHM-S@N,S8W)UT@/2`G4&5T
M97)B;W)O=6=H($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M-"XR.#8Z+38V+C,T-R==(#T@)T)R:65R($ES;&%N9"P@3BX@4RXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T-"XS.#,Z+3<Y+C<X,R==(#T@)T)A<G)I
M92P@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0T+C0Q-SHM-S4N
M.#4P)UT@/2`G1W)E;F%D:65R($ES;&%N9"<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0T+C0S,SHM-C4N,C`P)UT@/2`G2V5J:6UK=6II:R`Q+"!.+B!3
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0T+C4P,#HM.#`N,C$W)UT@
M/2`G0V]L;&EN9W=O;V0@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y
M<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0T+C4S,SHM-SDN,C$W
M)UT@/2`G3&%G;V]N($-I='DG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M-"XV,S,Z+38S+C4P,"==(#T@)U-H96%R=V%T97(L($XN(%,N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-#0N-S`P.BTW-BXS,#`G72`]("=5<'!E<B!2
M:61E874@3&%K92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0T+C<S,SHM
M.#$N,C@S)UT@/2`G3VQI<&AA;G0@7"!/;G0G.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T-"XW-3`Z+3@Q+C$P,"==(#T@)U=I87)T;VXL($]N="XG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-"XX,3<Z+38R+C,S,R==(#T@)T)E
M879E;B!)<VQA;F0L($XN(%,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#0N.#4P.BTW.2XX-C<G72`]("="96%U<V]L96EL($ES;&%N9"!!=71O;6%T
M960@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T-"XX.#,Z+38S+C4P,"==(#T@)TAA;&EF87@@26YT97)N871I;VYA;"!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#0N.38W.BTW.2XS
M,#`G72`]("=-=7-K;VMA+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#0N.3@S.BTV-"XY,3<G72`]("='<F5E;G=O;V0L($XN(%,N)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N,#,S.BTX,"XS-C<G72`]("=797-T
M97)N($ES;&%N9"!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N
M=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U+C`U
M,#HM-S(N.#,S)UT@/2`G1G)E;&EG:'-B=7)G)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#4N,#8W.BTV-"XT.#,G72`]("=+96YT=FEL;&4L($XN(%,N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N,3$W.BTW-"XR.#,G72`]
M("=3="!!;FEC970G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-2XQ-C<Z
M+3<S+C8X,R==(#T@)U-A:6YT($-L;W1H:6QD92!!=71O;6%T960@4F5P;W)T
M:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-2XR,3<Z
M+38W+C(U,"==(#T@)U-T+B!3=&5P:&5N+"!.+B!"+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0U+C,P,#HM-S,N,S4P)UT@/2`G3%PG06-A9&EE)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N,S$W.BTW,BXR-3`G72`]("=-
M;VYT+4]R9F]R9"<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U+C,Q-SHM
M-S4N-C8W)UT@/2`G3W1T87=A($EN=%PG3"X@3VYT+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0U+C,S,SHM-C4N.#@S)UT@/2`G4V%I;G0@2F]H;BP@
M3BX@0BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-2XS,S,Z+3@Q+C<S
M,R==(#T@)T-O=F4@27-L86YD($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A
M;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#4N,S4P.BTV,"XY.#,G72`]("=(87)T($ES;&%N9"!-971E;W)O;&]G
M:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0U+C,V-SHM-C,N,C8W)UT@/2`G5')U<F\L
M($XN(%,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N,S8W.BTW,2XX
M,3<G72`]("=,96YN;WAV:6QL92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S0U+C0P,#HM-S$N.#@S)UT@/2`G4VAE<F)R;V]K92P@475E+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0U+C0Q-SHM-S,N.3,S)UT@/2`G36-G:6QL
M(%)A9&%R(%-I=&4G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-2XT,S,Z
M+3<S+CDS,R==(#T@)U-T92!!;FYE($1E($)E;&P@,2<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0U+C0V-SHM-S,N-S4P)UT@/2`G36]N=')E86P@+R!$
M;W)V86P@26YT97)N871I;VYA;"P@475E)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#4N-3`P.BTW,RXU.#,G72`]("=-8R!4879I<V@@075T;VUA=&5D
M(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#4N-3$W.BTW,RXT,3<G72`]("=386EN="!(=6)E<G0@06ER<&]R="<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S0U+C8S,SHM-S`N-34P)UT@/2`G36]N
M=')E86PM17-T)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N-C,S.BTX
M,BXY-C<G72`]("='<F5A="!$=6-K($ES;&%N9"<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S0U+C<Q-SHM-C`N,C,S)UT@/2`G1F]U<F-H=2!(96%D($UE
M=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N-S$W.BTW,RXS.#,G72`]
M("=687)E;FYE<R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U+C<V-SHM
M-C(N-C@S)UT@/2`G0V%R:6)O=2!0;VEN="!-971E;W)O;&]G:6-A;"!!97)O
M;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S0U+C@P,#HM.#`N-3,S)UT@/2`G0G)I='0L($]N="XG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-2XX,3<Z+3<S+C0S,R==(#T@)TQ<
M)T%S<V]M<'1I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-2XX,S,Z
M+38V+C0S,R==(#T@)T=A9V5T;W=N($-A;BU-:6PG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<T-2XX,S,Z+3<U+C8U,"==(#T@)TAI9V@@1F%L;',L(%%U
M92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-2XX-3`Z+38T+C(V-R==
M(#T@)T%M:&5R<W0L($XN(%,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#4N.#8W.BTV-BXU,S,G72`]("=&<F5D97)I8W1O;BP@3BX@0BXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T-2XX.#,Z+3@R+C4V-R==(#T@)T=O<F4@
M0F%Y+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N.34P.BTW
M-RXS,3<G72`]("=0971A=V%W82P@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0U+CDV-SHM.#$N-#@S)UT@/2`G2VEL;&%R;F5Y($UE=&5O<F]L
M;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N,#4P.BTW-"XR.#,G72`]("=3=&4@
M06=A=&AE($1E<R!-;VYT)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N
M,#8W.BTW-"XU,S,G72`]("=3="!*;W9I=&4@075T;VUA=&EC(%=E871H97(@
M4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0V
M+C$Q-SHM-C0N-C@S)UT@/2`G36]N8W1O;BP@3BX@0BXG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T-BXQ-C<Z+38P+C`U,"==(#T@)U-Y9&YE>2P@3BX@
M4RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-BXR,#`Z+3<P+C<X,R==
M(#T@)T)E875C979I;&QE)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N
M,C$W.BTW,BXV-3`G72`]("=.:6-O;&5T($%U=&]M871I8R!796%T:&5R(%)E
M<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-BXR
M.#,Z+38S+C$S,R==(#T@)T-H87)L;W1T971O=VXL(%`N($4N($DN)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N,C@S.BTW-BXP,#`G72`]("=-86YI
M=V%K:2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0V+C,Q-SHM-SDN-#8W
M)UT@/2`G3FEP:7-S:6YG)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N
M,S4P.BTW,BXU,3<G72`]("=4<F]I<R!2:79I97)E<R<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0V+C,U,#HM-SDN-#,S)UT@/2`G3F]R=&@@0F%Y+"!/
M;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N,S@S.BTW-2XY-C<G
M72`]("=-86YI=V%K:2P@475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S0V+C0S,SHM-C,N.#,S)UT@/2`G4W5M;65R<VED92!#86XM36EL)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N-#,S.BTW,2XY,S,G72`]("=6:6QL
M97)O>2!2861A<B!3:71E)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N
M-#4P.BTV,2XY-C<G72`]("=%87-T(%!O:6YT+"!0+B!%+B!))SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-#8N-#@S.BTX-"XU,#`G72`]("=3875L="!3
M=&4@36%R:64L($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-BXU
M-3`Z+38Q+C`U,"==(#T@)T=R86YD($5T86YG+"!.+B!3+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0V+C4X,SHM-S(N-3@S)UT@/2`G4VAA=VEN:6=A
M;B!#4RP@475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0V+C8Q-SHM
M.#`N.#`P)UT@/2`G4W5D8G5R>2P@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0V+C8U,#HM-3,N,#8W)UT@/2`G0V%P92!286-E+"!.9FQD)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N-C@S.BTW,2XY-3`G72`]("=$
M97-C:&%M8F%U;'1S+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#8N.#`P.BTW,2XS.#,G72`]("=1=65B96,L(%%U92<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0V+C@Q-SHM-C`N-C8W)UT@/2`G3F]R=&@@36]U;G1A
M:6XL($XN(%,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N.#,S.BTW
M,2XR,#`G72`]("="96%U<&]R="!#4RP@475E+B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S0V+CDP,#HM-S$N-3`P)UT@/2`G5F%L8V%R=&EE<B!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N.3`P.BTW,2XU,#`G
M72`]("=686QC87)T:65R)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N
M.3$W.BTU-2XS.#,G72`]("=3="X@3&%W<F5N8V4L($YF;&0N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-#<N,#`P.BTV-2XT-3`G72`]("=#:&%T:&%M
M($-A;BU-:6PG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-RXP,#`Z+3<P
M+C@Q-R==(#T@)TEL92!$7"=/<FQE86YS($%U=&]M871E9"!297!O<G1I;F<@
M4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0W+C`V-SHM-C0N
M.#`P)UT@/2`G4&]I;G0@17-C=6UI;F%C($UE=&5O<F]L;V=I8V%L($%E<F]N
M875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#<N,#8W.BTW,"XX,#`G72`]("=#87`@5&]U<FUE;G1E)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#<N,34P.BTV-RXX,S,G72`]("=3
M86EN="!,96]N87)D($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T-RXR,S,Z+38P+C$S,R==(#T@)U-A:6YT(%!A=6P@27-L86YD($UE=&5O
M<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#<N,C@S.BTW,"XV,S,G72`]("=#
M:&%R;&5V;VEX($-3+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#<N,S`P.BTU-"XP,#`G72`]("=!<F=E;G1I82P@3F9L9"<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0W+C,P,#HM-S$N,C8W)UT@/2`G4W1E($9O>2!#
M4RP@475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0W+C,S,SHM.#4N
M.#,S)UT@/2`G0V%R:6)O=2!)<VQA;F0L($]N="XG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<T-RXS-3`Z+3<P+C`S,R==(#T@)TQA(%!O8V%T:65R92<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0W+C,V-SHM-34N.#`P)UT@/2`G
M4V%G;VYA($ES;&%N9"!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E
M<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0W
M+C0Q-SHM-C$N-S@S)UT@/2`G26QE<R!$92!,82!-861E;&5I;F5Q=64N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#<N-#$W.BTV,2XX,#`G72`]("=)
M;&5S+41E+4QA+4UA9&5L96EN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#<N-#$W.BTW,BXX,#`G72`]("=,82!4=7%U92<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S0W+C4Q-CHM-3(N-S@U)UT@/2`G4W0N($IO:&Y<)W,@5V5S
M="!#1$$@0U,L($YF;&0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#<N
M-38W.BTU.2XQ-C<G72`]("=0;W)T+4%U>"U"87-Q=65S+"!.9FQD+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S0W+C4V-SHM-S$N,C,S)UT@/2`G4&%R
M8R!$97,@3&%U<F5N=&ED)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#<N
M-C$W.BTU,BXW,S,G72`]("=3="X@2F]H;EPG<RP@3F9L9"<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0W+C<P,#HM-SDN.#4P)UT@/2`G16%R;'1O;BP@
M3VYT+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0W+C@P,#HM-CDN-34P
M)UT@/2`G4FEV:65R92!$=2!,;W5P+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#<N.3$W.BTW-"XV,3<G72`]("=087)E;G0L(%%U92XG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-RXY-C<Z+3@T+C<X,R==(#T@)U=A
M=V$L($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-RXY.#,Z+38V
M+C,S,R==(#T@)T-H87)L;RP@3BX@0BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T."XP,3<Z+38T+C4P,"==(#T@)TUI<V-O=2!)<VQA;F0L($XN($(N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N,#$W.BTV-2XS,S,G72`]
M("=.97<@0V%R;&ES;&4Q)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N
M,#8W.BTW-RXW.#,G72`]("=686P@1%PG3W(L(%%U92XG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T."XP.#,Z+38Y+C4U,"==(#T@)TEL92!2;W5G92!-
M971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E
M;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0X+C(U,#HM-SDN,#,S)UT@
M/2`G4F]U>6XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XR-C<Z+3<P
M+C$Q-R==(#T@)U!U:6YT92!#;&%V96%U)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#@N,S`P.BTQ,C,N-3,S)UT@/2`G4F%C92!2;V-K<R!!=71O;6%T
M:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#@N,S`P.BTW,"XY,S,G72`]("=,82!"86EE+"!1=64N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N,S,S.BTW,2XP,#`G72`]("="
M86=O='9I;&QE+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N
M,S8W.BTX.2XQ,3<G72`]("=796QC;VUE($ES;&%N9"<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0X+C,V-SHM.#DN,S$W)UT@/2`G5&AU;F1E<B!"87DL
M($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XS.#,Z+3$R,RXY
M,3<G72`]("=3:&5R:6YG:&%M($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN
M9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XS.#,Z+3<P
M+C4S,R==(#T@)T-A<"!2;W5G92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S0X+C0Q-CHM-C@N.#DS)UT@/2`G26QE($)I8W%U971T92P@475E+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S0X+C0Q-SHM,3(S+C,Q-R==(#T@)U9I
M8W1O<FEA($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XT,3<Z+38T+C,Q-R==(#T@)T-A
M<"!$7"=%<W!O:7(L(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M."XT,3<Z+3<Q+C(Q-R==(#T@)TIO;G%U:65R92!!=71O;6%T960@4F5P;W)T
M:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XT,S,Z
M+3$R,RXT,S,G72`]("=%<W%U:6UA;'0@2&%R8F]U<BP@0BX@0RXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T."XT-3`Z+3$R,RXS,#`G72`]("=6:6-T
M;W)I82!5;FEV97)S:71Y)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N
M-#8W.BTV-RXT,S,G72`]("=!;7%U:2P@475E+B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S0X+C4Q-SHM-S(N,C8W)UT@/2`G4F]B97)V86PL(%%U92XG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XU,S,Z+34X+C4U,"==(#T@
M)U-T97!H96YV:6QL92P@3F9L9"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T."XU-3<Z+34S+CDW-"==(#T@)U1E<G)A($YO=F$@3F%T:6]N86P@4&%R
M:R!#4RP@3F9L9"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XU-C<Z
M+3@Q+C,V-R==(#T@)U1I;6UI;G,L($]N="XG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T."XU.#,Z+3$R,RXU.#,G72`]("=-86QA:&%T($%U=&]M871I
M8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T."XV,#`Z+38X+C(Q-R==(#T@)TUO;G0@2F]L:2P@475E+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0X+C8P,#HM.#8N,S`P)UT@/2`G
M4'5K87-K=V$G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XV,S,Z+3<Y
M+C0U,"==(#T@)U)O<75E;6%U<F4G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T."XV-3`Z+3$R,RXT,S,G72`]("=6:6-T;W)I82!);G0N($%I<G!O<G0L
M($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N-C8W.BTQ,C0N
M.#,S)UT@/2`G3FET:6YA="!,86ME($UE=&5O<F]L;V=I8V%L($%E<F]N875T
M:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#@N-C8W.BTU,RXQ,3<G72`]("=";VYA=FES=&$L($YF;&0N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N-S4P.BTY,2XV,3<G72`]("=!
M=&EK;VMA;B!!=71O;6%T960@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T."XW-C<Z+38T+C0X,R==(#T@)T=A<W!E+"!1
M=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N-S8W.BTW,2XW,3<G
M72`]("=-:7-T;V]K($%U=&]M871E9"!297!O<G1I;F<@4W1A=&EO;B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S0X+C<X,SHM,3(S+C`U,"==(#T@)U-A
M='5R;F$@27-L86YD($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S
M96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N
M.#,S.BTW,BXU-3`G72`]("=.;W)M86YD:6XG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T."XX.#,Z+3<Q+C`S,R==(#T@)T]N871C:&EW87DL(%%U92XG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XY,3<Z+3$R-2XU-3`G72`]
M("=!;7!H:71R:71E(%!O:6YT)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#@N.34P.BTU-"XU-C<G72`]("='86YD97(@26YT+B!!:7)P;W)T+"!.9FQD
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0X+CDV-SHM-38N,#8W)UT@
M/2`G0F%D9V5R+"!.9FQD)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN
M,#$W.BTQ,C(N-S@S)UT@/2`G5VAI=&4@4F]C:R!!=71O;6%T:6,@5V5A=&AE
M<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#DN,#,S.BTQ,3DN-#,S)UT@/2`G3W-O>6]O<R!!=71O;6%T:6,@5V5A=&AE
M<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#DN,#,S.BTQ,C(N,S8W)UT@/2`G06)B;W1S9F]R9"P@0BX@0RXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T.2XP,S,Z+3DP+C0V-R==(#T@)U5P<V%L
M82P@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C`S,SHM.3<N
M-38W)UT@/2`G1W)E=&YA+"!-86XN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#DN,#4P.BTQ,#4N-#@S)UT@/2`G0V]R;VYA8V@@4W!C)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-#DN,#4P.BTQ,C,N.#8W)UT@/2`G3F%N86EM
M;R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN,#8W.BTQ
M,#<N-3@S)UT@/2`G5F%L($UA<FEE(%-O=71H96%S="P@4V%S:R<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0Y+C`X,SHM,3$V+C4P,"==(#T@)T-R97-T
M;VX@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0Y+C`X,SHM,3(U+C<V-R==(#T@)U1O9FEN
M;R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN,#@S.BTV
M,2XW,#`G72`]("=(96%T:"!0;VEN="!-971E;W)O;&]G:6-A;"!!97)O;F%U
M=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0Y+C$Q-SHM,3$P+C0V-R==(#T@)T]N969O=7(@075T;VUA=&EC
M(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0Y+C$Q-SHM-C8N-C4P)UT@/2`G0V%P($-H870@0U,L(%%U92XG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XQ,S,Z+3$Q,BXP-3`G72`]
M("=-:6QK(%)I=F5R)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN,3,S
M.BTV."XR,#`G72`]("="86EE($-O;65A=2P@475E+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0Y+C$V-SHM,3`U+CDX,R==(#T@)U)O8VMG;&5N+"!3
M87-K+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C$X,SHM,3(S+C$V
M-R==(#T@)U9A;F-O=79E<B!);G1E<FYA=&EO;F%L($%I<BU0;W)T+"!"+B!#
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C$X,SHM.3@N,#@S)UT@
M/2`G36]R9&5N($-$02!#4RP@36%N+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0Y+C(P,#HM,3$S+C(X,R==(#T@)T-A<F1S=&]N($%U=&]M871E9"!2
M97!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y
M+C(P,#HM,3(R+C8X,R==(#T@)U`N($UE861O=W,@0V]A<W1A;"!3=&%T:6]N
M($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T.2XR,#`Z+3DX+CDP,"==(#T@)U!I;&]T($UO
M=6YD+"!-86XN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN,C$W.BTQ
M,#(N.38W)UT@/2`G17-T979A;BP@4V%S:RXG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T.2XR,3<Z+3$R,RXX,#`G72`]("=%;G1R86YC92!)<VQA;F0@
M075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0Y+C(Q-SHM-3<N-#`P)UT@/2`G1&5E<B!,86ME
M+"!.9FQD+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C(U,#HM,3(Q
M+C<V-R==(#T@)T%G87-S:7H@075T;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN,C4P.BTQ,C0N.#,S)UT@
M/2`G4&]R="!!;&)E<FYI+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0Y+C(U,#HM-C4N,S,S)UT@/2`G0V%P($UA9&5L96EN92!-971E;W)O
M;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C(V-SHM-30N.#@S)UT@/2`G0V]M
M9F]R="!#;W9E+"!.9FQD+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y
M+C(V-SHM-C@N,34P)UT@/2`G0F%I92!#;VUE874G.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<T.2XR.#,Z+3$P,"XY.#,G72`]("=-96QI=&$L($UA;B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C(X,SHM-S,N,S4P)UT@/2`G
M0VAA;6]U8VAO=6%N92!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES
M=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN,S`P.BTQ,3<N-C,S
M)UT@/2`G0V%S=&QE9V%R($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T.2XS,#`Z+3$R,RXQ,3<G72`]("=686YC;W5V97(@075T;VUA=&EC
M(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0Y+C,Q-SHM-C<N,S@S)UT@/2`G4&]I;G1E+41E<RU-;VYT<RP@
M475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C,U,#HM,3(S+C$X
M,R==(#T@)U<@5F%N8V]U=F5R($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN
M9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XS-3`Z+3$R
M-"XQ-C<G72`]("="86QL96YA<R!)<VQA;F0@075T;VUA=&EC(%=E871H97(@
M4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y
M+C,V-SHM,3(Q+C0X,R==(#T@)TAO<&4L($(N($,N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#DN,S@S.BTQ,C8N-34P)UT@/2`G17-T979A;B!0;VEN
M="P@0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XT,#`Z+3DX
M+C,Q-R==(#T@)T1E97)W;V]D(%)#4RP@36%N+B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S0Y+C0Q-SHM.#(N-#8W)UT@/2`G2V%P=7-K87-I;F<L($]N
M="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XT,S,Z+3$P."XY.#,G
M72`]("=%87-T96YD($-Y<')E<W,L(%-A<VLG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T.2XT-C<Z+3$Q.2XV,#`G72`]("=096YT:6-T;VXL($(N($,N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN-#8W.BTQ,C`N-3$W)UT@
M/2`G4')I;F-E=&]N($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T.2XT.#,Z+3$R,RXS,#`G72`]("=086T@4F]C:W,G.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T.2XT.#,Z+3$R-"XT,S,G72`]("=3:7-T97)S($ES
M;&%N9"!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN-3`P.BTQ,3<N,S`P)UT@/2`G3F5L
M<V]N($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T.2XU,#`Z+3DX+C`S,R==(#T@)T-A<FUA
M;B!5($]F($TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XU-C<Z+3$Q
M.2XV-3`G72`]("=3=6UM97)L86YD($%U=&]M871I8R!796%T:&5R(%)E<&]R
M=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XU-C<Z
M+34W+C@X,R==(#T@)U)O8VMY($AA<F)O=7(@0U,L($YF;&0N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-#DN-3@S.BTQ,30N-#$W)UT@/2`G5'5R=&QE
M($UO=6YT86EN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN-C$W.BTQ
M,34N-S@S)UT@/2`G0W)A;F)R;V]K+"!"+B!#+B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S0Y+C8S,SHM,3$Q+C0U,"==(#T@)T)O=R!)<VQA;F0G.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XV,S,Z+3$Q,BXX,#`G72`]("=,
M971H8G)I9&=E+"!!;'1A+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y
M+C8S,SHM,3$T+C0X,R==(#T@)T-R;W=S;F5S="<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S0Y+C8U,#HM,3`Y+C4Q-R==(#T@)T-Y<')E<W,@2&EL;',@
M4&%R:R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C8X,SHM-30N.#`P
M)UT@/2`G5'=I;&QI;F=A=&4@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L
M(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T.2XW,#`Z+3$P,RXX,#`G72`]("=797EB=7)N($%U=&]M871I8R!796%T
M:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T.2XW,#`Z+3$Q,BXW.#,G72`]("=,971H8G)I9&=E($%U=&]M871E9"!2
M97!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y
M+C<Q-SHM,3(T+CDP,"==(#T@)T-O;6]X+"!"+B!#+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0Y+C<Q-SHM.#@N,S,S)UT@/2`G2V%T871O=&$@27-L
M86YD)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN-S,S.BTQ,#4N.3,S
M)UT@/2`G07-S:6YI8F]I82!!:7)P;W)T($%U=&]M871E9"!297!O<G1I;F<@
M4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C<U,#HM,3$T
M+CDP,"==(#T@)U-P87)W;V]D($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN
M9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XW-3`Z+3@T
M+C$V-R==(#T@)TYA9V%G86UI+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#DN-S8W.BTW-"XU,S,G72`]("=#:&EB;W5G86UA=2U#:&%P86ES
M+"!1=64G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XW-C<Z+3<W+C@Q
M-R==(#T@)TUA=&%G86UI+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#DN-S@S.BTQ,C,N,38W)UT@/2`G4W%U86UI<V@@06ER<&]R="P@0BX@
M0R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C<X,SHM.#8N.3,S)UT@
M/2`G1V5R86QD=&]N+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#DN-S@S.BTY-"XS-C<G72`]("=+96YO<F$L($]N="XG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T.2XW.#,Z+3DY+C8S,R==(#T@)U-H:6QO)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN.#,S.BTQ,C0N-3`P)UT@/2`G4&]W
M96QL(%)I=F5R($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M.2XX,S,Z+38T+C,P,"==(#T@)U!O<G0@365N:65R+"!1=64N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-#DN.#@S.BTY-RXQ,S,G72`]("=7:6YN:7!E
M9R!4:&4@1F]R:W,L($UA;BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M.2XY,#`Z+3$P.2XT-C<G72`]("=-87!L96-R965K($%U=&]M871I8R!796%T
M:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T.2XY,#`Z+3<Q+C(U,"==(#T@)T-H=71E($1E<R!087-S97,G.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T.2XY,#`Z+3DW+C(S,R==(#T@)U=I;FYI
M<&5G($EN="X@06ER<&]R=&UA;BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T.2XY,#`Z+3DX+C(V-R==(#T@)U!O<G1A9V4@4V]U=&AP;W)T($$G.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XY,#`Z+3DY+C,U,"==(#T@)T-A
M<F)E<G)Y($UC9&,G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XY,3<Z
M+34U+C8V-R==(#T@)TQA(%-C:64L($YF;&0N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#DN.3$W.BTY.2XY-3`G72`]("="<F%N9&]N+"!-86XN)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN.38W.BTQ,3DN,S@S)UT@/2`G
M2V5L;W=N82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N
M,#$W.BTQ,3`N-S$W)UT@/2`G365D:6-I;F4@2&%T+"!!;'1A+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4P+C`Q-SHM,3$S+C8S,R==(#T@)T-L87)E
M<VAO;&T@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C`U,#HM,3$R+C$S,R==(#T@)U9A
M=7AH86QL($-D82<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C$Q-SHM
M,3(W+CDS,R==(#T@)U-O;&%N9&5R($ES;&%N9"!-971E;W)O;&]G:6-A;"!!
M97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4P+C$Q-SHM.3$N.3`P)UT@/2`G4VEO=7@@3&]O:V]U
M="P@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C$V-SHM-C`N
M,#8W)UT@/2`G0V%P92!7:&ET=&QE)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-3`N,38W.BTV-BXT,S,G72`]("=0;VEN=&4@3F]I<F4L(%%U92XG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XQ.#,Z+38Q+C@Q-R==(#T@)TYA
M=&%S:'%U86XL(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XQ
M.#,Z+3DV+C`V-R==(#T@)U!I;F%W82!!=71O;6%T:6,@5V5A=&AE<B!297!O
M<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N,C`P
M.BTQ,#0N-S`P)UT@/2`G0G)A='1S($QA:V4L(%-A<VLN)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-3`N,C$W.BTV-BXR-C<G72`]("=397!T+4EL97,L
M(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XR,C0Z+38T+C(P
M."==(#T@)TEL92!!=7@@4&5R<F]Q=65T<RP@475E+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4P+C(S,SHM,3$Y+C(X,R==(#T@)U9E<FYO;BP@0BX@
M0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XR,S,Z+3$R,2XU.#,G
M72`]("=,>71T;VXL($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-3`N,C,S.BTU-RXU.#,G72`]("=$86YI96Q<)W,@2&%R8F]U<BP@3F9L9"<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C(V-SHM,3`W+C<S,R==(#T@
M)U-W:69T($-U<G)E;G0@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y
M<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C(V-SHM,3$Q+C$X
M,R==(#T@)U-U9F9I96QD($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<U,"XR-C<Z+3$Q-RXX,3<G72`]("=.86MU<W`@075T;VUA=&EC(%=E
M871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S4P+C(V-SHM-C0N,C,S)UT@/2`G3&]N9W5E(%!O:6YT($1E($UI;F=A
M;BP@475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C(X,SHM,3`W
M+C8X,R==(#T@)U-W:69T($-U<G)E;G0L(%-A<VLN)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-3`N,C@S.BTV,RXV,3<G72`]("=(879R92!3="!0:65R
M<F4G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XS,#`Z+3$R,BXW,S,G
M72`]("=096UB97)T;VX@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y
M<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C,P,#HM.#DN,#,S
M)UT@/2`G07)M<W1R;VYG+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-3`N,S,S.BTQ,#4N-34P)UT@/2`G36]O<V4@2F%W+"!387-K+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C,X,SHM,3`R+C8X,R==(#T@)T)R
M;V%D=FEE=RP@4V%S:RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XT
M,#`Z+3$P-"XU.#,G72`]("=296=I;F$@56YI=F5R<VET>2<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S4P+C0P,#HM,3(U+C@V-R==(#T@)TAE;&UC:V5N
M($ES;&%N9"!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T
M:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C0S,SHM
M,3`T+C8V-R==(#T@)U)E9VEN82P@4V%S:RXG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U,"XT-3`Z+3$P,"XV,#`G72`]("=3:&]A;"!,86ME($%I<G!O
M<G0@075T;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-3`N-#8W.BTU.2XV,S,G72`]("=#:&5V97)Y+"!1=64N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N-34P.BTQ,3$N.#4P)UT@
M/2`G0G)O;VMS($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XV,#`Z+3$R,"XU,3<G72`]
M("=0<FEN8V5T;VX@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E
M;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C8Q-SHM.3<N,#,S)UT@
M/2`G1VEM;&D@26YD=7-T<FEA;"P@36%N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-3`N-C,Q.BTY-BXY.#(G72`]("=':6UL:2!(87)B;W5R($-3+"!-
M86XN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N-C,S.BTQ,C@N,3$W
M)UT@/2`G2&]L8F5R9RP@0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U,"XV-3`Z+3DY+CDS,R==(#T@)U=A<V%G86UI;F<L($UA;BXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U,"XV-C<Z+3<P+C4S,R==(#T@)TUA;F]U
M86YE+45S="!!=71O;6%T960@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<U,"XV.#,Z+3$R-RXS-C<G72`]("=0;W)T($AA
M<F1Y+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C<P,#HM
M,3$Y+C(X,R==(#T@)U-A;&UO;B!!<FT@075T;VUA=&EC(%=E871H97(@4F5P
M;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C<P
M,#HM,3(P+C0U,"==(#T@)TMA;6QO;W!S+"!"+B!#+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4P+C<P,#HM.38N-38W)UT@/2`G5FEC=&]R:6$@0F5A
M8V@G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XW,3<Z+34V+C$Q-R==
M(#T@)T5N9VQE92!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N
M=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C<S
M,SHM-S$N,#$W)UT@/2`G0F]N;F%R9"`Q+"!1=64N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-3`N-S@S.BTQ,C@N-#,S)UT@/2`G0V%P92!38V]T="!,
M:6=H="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C@Q-SHM,3(X+CDP
M,"==(#T@)U-A<G1I;F4@27-L86YD($UE=&5O<F]L;V=I8V%L($%E<F]N875T
M:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-3`N.3`P.BTQ,#DN-3`P)UT@/2`G3&5A9&5R($%I<G!O<G0@075T
M;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4P+CDS,SHM,3(W+C8S,R==(#T@)TAE<F)E<G0@27-L
M86YD($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@
M4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N.34P.BTQ,#<N
M,34P)UT@/2`G3'5C:WD@3&%K92!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I
M;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N.34P.BTQ
M,34N,3@S)UT@/2`G3F%K:7-K82!2:61G971O<"<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S4P+CDV-SHM,3$X+C$X,R==(#T@)U)E=F5L<W1O:V4L($(N
M($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N.3@S.BTQ,C<N-S,S
M)UT@/2`G4&EN92!)<VQA;F0@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L
M(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U,2XP-C<Z+3DS+C@P,"==(#T@)U)E9"!,86ME+"!/;G0N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-3$N,#@S.BTQ,30N,C$W)UT@/2`G0V]P(%5P
M<&5R)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N,#@S.BTQ,34N,#8W
M)UT@/2`G0F]W(%9A;&QE>2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q
M+C`X,SHM.3<N-34P)UT@/2`G1FES:&5R($)R86YC:"!-87)I;F4@079I871I
M;VX@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U,2XQ,#`Z+3$P,"XP-3`G72`]("=$875P:&EN($-O87-T86P@4W1A=&EO
M;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q+C$P,#HM,3`P+C`U,"==
M(#T@)T1A=7!H:6XL($UA;BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U
M,2XQ,3<Z+3$Q-"XP,3<G72`]("=#86QG87)Y($EN=&5R;F%T:6]N86PL($%L
M=&$N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N,3,S.BTQ,#8N-3@S
M)UT@/2`G16QB;W<@36%R:6YE($%V:6%T:6]N(%)E<&]R=&EN9R!3=&%T:6]N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N,34P.BTQ,C$N-3`P)UT@
M/2`G0VQI;G1O;BP@0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U
M,2XQ.#,Z+3$Q-2XU-C<G72`]("="86YF9BP@06QT82XG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<U,2XR-3`Z+3$R,RXP.#,G72`]("=":6<@0W)E96LG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,2XR-C<Z+3$P,BXT-C<G72`]
M("=9;W)K=&]N+"!387-K+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q
M+C(V-SHM.#`N-C4P)UT@/2`G36]O<V]N964L($]N="XG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<U,2XS-C<Z+34U+C8S,R==(#T@)U-T+B!!;G1H;VYY
M+"!.9FQD+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q+C0U,#HM,3$V
M+C,S,R==(#T@)UEO:&\@4&%R:R!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I
M;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N-#4P.BTU
M-RXQ.#,G72`]("=";&%N8R!386)L;VXL(%%U92XG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<U,2XT-3`Z+3DP+C(P,"==(#T@)U!I8VML92!,86ME+"!/
M;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N-#@S.BTQ,#<N,#4P
M)UT@/2`G3W5T;&]O:R!09G)A)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-3$N-3$W.BTQ,#DN,38W)UT@/2`G2VEN9&5R<VQE>2P@4V%S:RXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U,2XU-3`Z+3<Q+C$Q-R==(#T@)TQA8R!"
M96YO:70G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,2XU-C<Z+3$P-RXY
M,3<G72`]("=2;W-E=&]W;B!%87-T+"!387-K)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-3$N-C8W.BTQ,#4N-#`P)UT@/2`G5V%T<F]U<R!%87-T($%U
M=&]M871E9"!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S4Q+C8V-SHM,3$P+C(P,"==(#T@)T5S=&AE<B`Q)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-3$N-C8W.BTY."XW-3`G72`]("='>7!S=6UV
M:6QL92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q+C<P,#HM,3$S+C(Q
M-R==(#T@)U1H<F5E($AI;&QS)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-3$N-S4P.BTY.2XY,#`G72`]("="86-H96QO<G,@27-L86YD($%U=&]M871E
M9"!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S4Q+C<V-SHM,3`T+C(P,"==(#T@)U=Y;GEA<F0L(%-A<VLN)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-3$N-S8W.BTQ,30N-C@S)UT@/2`G4W5N9')E
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N.#8W.BTV,RXR.#,G72`]
M("=,86,@16]N+"!1=64G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,BXP
M-C<Z+3$Q,2XT-3`G72`]("=#;W)O;F%T:6]N($UA<FEN92!!=FEA=&EO;B!2
M97!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4R
M+C$Q-SHM,3`Q+C(S,R==(#T@)U-W86X@4FEV97(L($UA;BXG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<U,BXQ,3<Z+3$R-"XQ,S,G72`]("=0=6YT>FD@
M36]U;G1A:6XL($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N
M,3,S.BTQ,3DN,S`P)UT@/2`G0FQU92!2:79E<BP@0BX@0RXG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<U,BXQ-3`Z+3$P-BXU-3`G72`]("=387-K871O
M;VX@2V5R;F5N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N,38W.BTQ
M,#8N-C@S)UT@/2`G4V%S:V%T;V]N+"!387-K+B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S4R+C$X,SHM,3$S+CDP,"==(#T@)U)E9"!$965R+"!!;'1A
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4R+C$X,SHM,3(R+C`U,"==
M(#T@)U=I;&QI86US($QA:V4L($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-3(N,3@S.BTQ,C<N-#8W)UT@/2`G0V%T:&5D<F%L(%!O:6YT($UE
M=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N,C,S.BTX-RXX.#,G72`]
M("=,86YS9&]W;F4@2&]U<V4G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U
M,BXR-C<Z+3$R."XW,3<G72`]("=-8VEN;F5S($ES;&%N9"P@0BX@0RXG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,BXS,#`Z+34U+C@S,R==(#T@)TUA
M<GE<)W,@2&%R8F]U<BP@3F9L9"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U,BXS-3`Z+3DW+C`S,R==(#T@)T)E<F5N<R!2:79E<B!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N,S4P.BTY-RXP,S,G72`]("="
M97)E;G,@4FEV97(@0U,L($UA;BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U,BXS.#,Z+3$R-BXU.#,G72`]("="96QL82!#;V]L82!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N-#,S.BTQ,30N.3$W)UT@/2`G
M4F]C:WD@36]U;G1A:6X@2&]U<V4L($%L=&$G.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U,BXT-3`Z+3$Q,RXW-3`G72`]("=,86-O;6)E($-D82<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S4R+C8U,#HM-38N.#8W)UT@/2`G06QE
M>&ES(%)I=F5R($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT
M871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N-S8W
M.BTQ,#@N,C4P)UT@/2`G3F]R=&@@0F%T=&QE9F]R9"P@4V%S:RXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U,BXX,#`Z+3DW+C8Q-R==(#T@)T=E;W)G
M92!)<VQA;F0@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A
M=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,BXX,3<Z
M+3$P,BXS,3<G72`]("=(=61S;VX@0F%Y+"!387-K+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4R+C@Q-SHM,3`T+C8P,"==(#T@)TUE;&9O<G0@075T
M;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4R+C@X,SHM,3$X+C`V-R==(#T@)TIA<W!E<BP@06QT
M82XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,BXY,S,Z+3$Q."XS,3<G
M72`]("=*87-P97(@5V%R9&5N($%U=&]M871E9"!297!O<G1I;F<@4W1A=&EO
M;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4R+CDS,SHM-C8N.#8W)UT@
M/2`G5V%B=7-H($QA:V4L($YF;&0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-3,N,#,S.BTQ,#`N.3,S)UT@/2`G2'5N=&5R<R!0;VEN="!-87(G.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXP,S,Z+3$Q,BXX,3<G72`]("=#
M86UR;W-E)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N,#,S.BTQ,C(N
M-3$W)UT@/2`G475E<VYE;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-3,N,#4P.BTQ,CDN-C@S)UT@/2`G171H96QD82!"87DG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U,RXQ.#,Z+3DY+C(V-R==(#T@)T=R86YD
M(%)A<&ED<RP@36%N+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C(Q
M-SHM,3`U+C8X,R==(#T@)U!R:6YC92!!;&)E<G0L(%-A<VLN)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-3,N,C4P.BTQ,S$N.#$W)UT@/2`G4V%N9'-P
M:70L($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N,S`P.BTQ
M,3,N-3@S)UT@/2`G161M;VYT;VX@26YT97)N871I;VYA;"P@06QT82XG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXS,#`Z+3$Q,RXV,#`G72`]("=%
M9&UO;G1O;B!);G1E<FYA=&EO;F%L($-3+"!!;'1A+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4S+C,Q-SHM,3$P+C`V-R==(#T@)TQL;WED;6EN:7-T
M97(L($%L=&$N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N,S$W.BTQ
M,S(N-S4P)UT@/2`G2VEN9&%K=6X@4F]C:W,L($(N($,N)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-3,N,S$W.BTV,"XT,3<G72`]("=';V]S92P@3F9L
M9"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXS,S,Z+3$P-"XP,#`G
M72`]("=.:7!A=VEN+"!387-K+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S4S+C,V-SHM,3`W+C4U,"==(#T@)U-P:7)I='=O;V0@5V5S="P@4V%S:R<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C,X,SHM,3$X+C,S,R==(#T@
M)U=I;&QO=R!#<F5E:R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C0Q
M-SHM,3$S+C(P,"==(#T@)T5L;&5R<VQI92<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S4S+C0U,#HM,3$T+C0V-R==(#T@)TAI9VAV86QE)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-3,N-3`P.BTQ,S`N-C,S)UT@/2`G0F]N:6QL
M82!)<VQA;F0@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A
M=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXU,S,Z
M+3$Q-"XQ,#`G72`]("=%9&UO;G1O;B!3=&]N>2!0;&%I;B!!;'1A+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C4U,#HM-C0N,3`P)UT@/2`G0VAU
M<F-H:6QL($9A;&QS+"!.9FQD+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S4S+C4V-SHM,3$S+C4Q-R==(#T@)T5D;6]N=&]N($UU;FEC:7!A;"!!;'1A
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C4V-SHM,3$S+C4Q-R==
M(#T@)T5D;6]N=&]N($UU;FEC:7!A;"!#4C$P+"!!;'1A+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S4S+C4V-SHM-C0N,3`P)UT@/2`G0VAU<F-H:6QL
M($9A;&QS)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N-3@S.BTQ,38N
M-#8W)UT@/2`G161S;VXL($%L=&$N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-3,N-C$W.BTQ,3(N,#,S)UT@/2`G5F5G<F5V:6QL92!!=71O;6%T:6,@
M5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-3,N-C,S.BTW-RXW,#`G72`]("=,82!'<F%N9&4@4FEV:65R92P@
M475E)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N-C8W.BTQ,3,N-#8W
M)UT@/2`G161M;VYT;VX@3F%M86\@06QT82XG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U,RXV.#,Z+3$Q,BXX-C<G72`]("=%;&L@27-L86YD($YA=&EO
M;F%L(%!A<FLG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXV.#,Z+3$R
M-"XX,S,G72`]("=.96-H86MO(%)I=F5R)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-3,N-S`P.BTU-RXP,S,G72`]("=#87)T=W)I9VAT+"!.9FQD+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C<S,SHM,3`U+C(V-R==(#T@
M)T-A;F1L92!,86ME)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N-S4P
M.BTW,RXV-C<G72`]("=,82!'<F%N9&4@278L(%%U92XG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<U,RXW.#,Z+3$Q."XT,S,G72`]("=(96YD97)I8VMS
M;VX@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4S+C@S,SHM.#DN.#8W)UT@/2`G0FEG(%1R
M;W5T($QA:V4G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXX-3`Z+3DT
M+C8U,"==(#T@)TES;&%N9"!,86ME+"!-86XN)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-3,N.#@S.BTQ,C(N-C@S)UT@/2`G4')I;F-E($=E;W)G92P@
M0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXY,3<Z+3$P-BXP
M-C<G72`]("=787-K97-I=2!,86ME($%U=&]M871E9"!297!O<G1I;F<@4W1A
M=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+CDV-SHM,3`Q+C$P
M,"==(#T@)U1H92!087,L($UA;BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U,RXY-C<Z+3DW+C@S,R==(#T@)TYO<G=A>2!(;W5S92P@36%N+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S4T+C$S,SHM,3`X+C4Q-R==(#T@)TUE
M861O=R!,86ME+"!387-K+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4T
M+C$U,#HM,3$U+C<X,R==(#T@)U=H:71E8V]U<G0L($%L=&$N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-30N,34P.BTQ,34N-S@S)UT@/2`G5VAI=&5C
M;W5R="P@06QT82XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-"XQ-C<Z
M+3$S,"XS-C<G72`]("=(;VQL86YD(%)O8VL@075T;VUA=&EC(%=E871H97(@
M4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4T
M+C$V-SHM,3,Q+C8V-R==(#T@)U)O<V4@4W!I="!-971E;W)O;&]G:6-A;"!!
M97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4T+C(U,#HM,3,S+C$S,R==(#T@)TQA;F=A<F$L($(N
M($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-30N,S`P.BTQ,S`N-#,S
M)UT@/2`G4')I;F-E(%)U<&5R="P@0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U-"XS.#,Z+3$R-2XY-3`G72`]("="=7)N<R!,86ME)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-30N-#$W.BTQ,3`N,C@S)UT@/2`G0V]L
M9"!,86ME+"!!;'1A+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4T+C0V
M-SHM,3(X+C4X,R==(#T@)U1E<G)A8V4L($(N($,N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-30N-3@S.BTQ,S`N-S`P)UT@/2`G1W)E>2!)<VQE="!-
M971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E
M;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4T+C<U,#HM,3$P+C`U,"==
M(#T@)U!R:6UR;W-E($QA:V4G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U
M-"XW-C<Z+3$Q,BXP,3<G72`]("=,86,@3&$@0FEC:&4L($%L=&$N)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-30N-S@S.BTQ,3`N,#8W)UT@/2`G4')I
M;7)O<V4@3&%K92`R)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-30N.#`P
M.BTV-BXX,#`G72`]("=38VAE9F9E<G9I;&QE+"!1=64N)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-30N.#$W.BTQ,C<N,3@S)UT@/2`G4VUI=&AE<G,L
M($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-30N.3@S.BTX-2XT
M,S,G72`]("=096%W86YU8VL@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L
M(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U-2XQ-3`Z+3$P-2XR-C<G72`]("=,82!2;VYG92P@4V%S:RXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U-2XQ-3`Z+3$P-2XR-C<G72`]("=,82!2
M;VYG92P@4V%S:R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4U+C$X,SHM
M,3$X+C@X,R==(#T@)T=R86YD92!0<F%I<FEE+"!!;'1A+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S4U+C(P,#HM,3$Y+C0P,"==(#T@)T)E879E<FQO
M9&=E)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-34N,C@S.BTW-RXW-C<G
M72`]("=+=75J:G5A<F%P:6LL(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<U-2XS,#`Z+3$Q-"XW.#,G72`]("=3;&%V92!,86ME+"!!;'1A)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-34N,S`P.BTQ,C,N,3,S)UT@/2`G
M36%C:V5N>FEE+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4U
M+C,S,SHM-C,N,C$W)UT@/2`G0F]R9&5R+"!1=64N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-34N-#4P.BTV,"XR,S,G72`]("=(;W!E9&%L92!-971E
M;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4U+C8Y-3HM,3$Y+C(S-"==(#T@
M)U-P:7)I="!2:79E<B!!=71O(%-T871I;VXL($%L=&$G.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<U-2XX,#`Z+3DW+C@U,"==(#T@)U1H;VUP<V]N(%=E
M871H97(@3V9F:6-E+"!-86XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U
M-2XX,S,Z+3$P."XT,S,G72`]("="=69F86QO($YA<G)O=W,L(%-A<VLN)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-34N.3,S.BTQ,CDN.3@S)UT@/2`G
M4W1E=V%R="!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-38N
M,C,S.BTQ,3<N-#,S)UT@/2`G4&5A8V4@4FEV97(L($%L=&$N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-38N,C,S.BTQ,C`N-S,S)UT@/2`G1F]R="!3
M="!*;VAN+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4V+C,S
M,SHM,3`S+C(X,R==(#T@)U-O=71H96YD($%U=&]M871I8R!796%T:&5R(%)E
M<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-BXS
M-3`Z+3DT+C<P,"==(#T@)T=I;&QA;2P@36%N+B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S4V+C4S,SHM,3$U+C(V-R==(#T@)U)E9"!%87)T:"<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S4V+C4U,#HM-C$N-C@S)UT@/2`G3F%I
M;BP@3F9L9"<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4V+C8U,#HM,3$Q
M+C(Q-R==(#T@)T9O<G0@36--=7)R87D@0U,L($%L=&$N)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-38N-C4P.BTQ,3$N,C$W)UT@/2`G1F]R="!-8VUU
M<G)A>2P@06QT82XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-BXW,S,Z
M+3$S,2XV-C<G72`]("=)<VMU="!2:79E<B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S4V+C@V-SHM,3`Q+C`X,R==(#T@)TQY;FX@3&%K92P@36%N+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4W+C$S,SHM-C$N-#@S)UT@/2`G
M0V%P92!+:6=L87!A:70L($YF;&0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-3<N,C4P.BTQ,#4N-C$W)UT@/2`G2V5Y($QA:V4G.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<U-RXS-3`Z+3$P-RXQ,S,G72`]("=#<F5E($QA:V4@
M365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T
M96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-RXU,S,Z+3$Q,2XU-C<G
M72`]("=-:6QD<F5D($QA:V4G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U
M."XQ,#`Z+38X+C0Q-R==(#T@)TMU=6IJ=6%Q+"!1=64N)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-3@N,3@S.BTQ,#,N-S`P)UT@/2`G0V]L;&EN<R!"
M87D@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4X+C,S,SHM-C(N-3@S)UT@/2`G4V%G;&5K
M($)A>2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4X+C,X,SHM,3`Y+C4P
M,"==(#T@)T-L=69F($QA:V4L(%-A<VLN)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-3@N-#$W.BTQ,S`N,#`P)UT@/2`G1&5A<V4@3&%K92!"+B!#+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4X+C0Q-SHM,3,P+C`P,"==(#T@
M)T1E87-E($QA:V4@0V]A<W1A;"!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-3@N-#4P.BTW."XQ,3<G72`]("=);G5K:G5A:RP@475E)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3@N-3@S.BTQ,3@N-3`P)UT@/2`G
M4V]U<V$@0W)K($%V="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4X+C8Q
M-SHM,3$W+C$V-R==(#T@)TAI9V@@3&5V96PL($%L=&$G.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<U."XV,C(Z+3$Q,2XV-S(G72`]("=0<F%I<FEE(%)I
M=F5R+"!!;'1A)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3@N-C@S.BTQ
M,3,N.#@S)UT@/2`G1V%R9&5N(%)I=F5R($%U=&]M871I8R!796%T:&5R(%)E
M<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U."XW
M,S,Z+3DT+C`V-R==(#T@)T-H=7)C:&EL;"P@36%N+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4X+C<V-SHM,3$Q+C$Q-R==(#T@)T9O<G0@0VAI<&5W
M>6%N+"!!;'1A+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4X+C@S,SHM
M,3(R+C4X,R==(#T@)T9O<G0@3F5L<V]N+"!"+B!#+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4Y+C$S,SHM,3$S+C@P,"==(#T@)U=A=&5R=&]N(%!A
M<FL@1V%T92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Y+C(Q-SHM,3`Y
M+C<P,"==(#T@)T)E87)T;V]T:"!)<VQA;F0G.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U.2XR-3`Z+3$P-2XX,S,G72`]("=3=&]N>2!287!I9',@06ER
M<&]R="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Y+C4V-SHM,3`X+C0X
M,R==(#T@)U5R86YI=6T@0VET>2P@4V%S:RXG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U.2XY.#,Z+38T+C$V-R==(#T@)T-A<&4@2V%K:VEV:6%K)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C`N,#$W.BTQ,3$N.34P)UT@/2`G
M1F]R="!3;6ET:"P@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<V,"XQ,3<Z+3$R."XX,3<G72`]("=7871S;VX@3&%K92P@62X@5"XG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,"XQ-C<Z+3$S,BXW,S,G72`]("=4
M97-L:6XL(%DN(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C`N-#$W
M.BTV-"XX-3`G72`]("=+:6QL:6YE:R!-971E;W)O;&]G:6-A;"!!97)O;F%U
M=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S8P+C0S,SHM,3(Q+C(S,R==(#T@)U1R;W5T($QA:V4G.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<V,"XW,3<Z+3$S-2XP-C<G72`]("=7:&ET
M96AO<G-E+"!9+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8P+C<V
M-SHM,3,W+C4X,R==(#T@)TAA:6YE<R!*=6YC=&EO;B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S8P+C@S,SHM,3$U+C<X,R==(#T@)TAA>2!2:79E<BP@
M3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,2XP-3`Z+3$P
M.2XS,S,G72`]("=0;W=D97(@3&%K92<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S8Q+C`U,#HM-CDN-C,S)UT@/2`G475A<71A<2!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-C$N,3$W.BTQ,C(N.#4P)UT@/2`G3&EN
M9&)E<F<@3&%N9&EN9RP@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<V,2XQ,S,Z+3$P,"XY,#`G72`]("=%;FYA9&%I($QA:V4@365T96]R
M;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,2XS,3<Z+3$Q-RXV,#`G72`]("=&
M;W)T(%!R;W9I9&5N8V4G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,2XS
M-C<Z+3$S.2XP-3`G72`]("="=7)W87-H($%U=&]M871I8R!796%T:&5R(%)E
M<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,2XU
M.#,Z+38T+C8U,"==(#T@)U)E<V]L=71I;VX@27-L86YD+"!.+B!7+B!4+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8Q+C8S,SHM,3(U+C@P,"==(#T@
M)U9I<F=I;FEA($9A;&QS)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C$N
M-C8W.BTQ,#@N-#$W)UT@/2`G4&]R=&5R($QA:V4G.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<V,2XW-3`Z+3$R,2XR,S,G72`]("=&;W)T(%-I;7!S;VXL
M($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C$N.3$W.BTQ
M,3,N-S,S)UT@/2`G26YN97(@5VAA;&5B86-K<R<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S8Q+CDV-SHM,3(W+C(Q-R==(#T@)U)A8F)I="!+971T;&4@
M075T;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-C(N,3$W.BTQ,S8N,3@S)UT@/2`G0V%R;6%C:W,@0U,L(%DN
M(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C(N,C,S.BTQ,S,N,S4P
M)UT@/2`G1F%R;RP@62X@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V
M,BXT-C<Z+3$Q-"XT-3`G72`]("=996QL;W=K;FEF92P@3BX@5RX@5"XG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,BXW,#`Z+3DX+C,P,"==(#T@)UEA
M=&AK>65D($QA:V4@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E
M;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,BXW
M,3<Z+3$P.2XQ.#,G72`]("=&;W)T(%)E;&EA;F-E+"!.+B!7+B!4+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S8R+C@Q-SHM.3(N,3$W)UT@/2`G4F%N
M:VEN($EN;&5T+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S8S+C$U,#HM,3$W+C(V-R==(#T@)TQA8R!,82!-87)T<F4G.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<V,RXR,S,Z+3$P,2XW-C<G72`]("=$=6)A=VYT
M($QA:V4@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO
M;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,RXS,S,Z+38T
M+C$U,"==(#T@)T)R979O;W)T($ES;&%N9"<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S8S+C4X,SHM,3`U+C$U,"==(#T@)TAA;F)U<GD@4FEV97(@075T
M;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-C,N-C`P.BTQ,3,N.#8W)UT@/2`G3&]W97(@0V%R<"!,86ME+"!.
M+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8S+C8Q-SHM,3,U
M+C@V-R==(#T@)TUA>6\@06ER<&]R="<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S8S+C<U,#HM-C@N-34P)UT@/2`G27%A;'5I="P@3BX@5RX@5"XG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<V-"XP-3`Z+3$S.2XQ,S,G72`]("=$
M87=S;VXL(%DN(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C0N,3$W
M.BTQ,3<N,S8W)UT@/2`G4F%E($QA:V5S)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-C0N,C`P.BTX,RXS-C<G72`]("=#;W)A;"!(87)B;W5R+"!.+B!7
M+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8T+C(Q-SHM-S8N-3,S
M)UT@/2`G0V%P92!$;W)S970L($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-C0N,S`P.BTY-BXP.#,G72`]("="86ME<B!,86ME+"!.+B!7
M+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8T+C,X,SHM,3$U+C`Q
M-R==(#T@)TEN9&EA;B!2:79E<B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S8T+C<U,#HM,3(T+C(Q-R==(#T@)U-T($-H87)L97,@0W)E96LG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<V-"XY-3`Z+38S+C4X,R==(#T@)T-A<&4@
M365R8WDG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V-2XQ,#`Z+3$P,BXT
M,S,G72`]("=2;V)E<G1S;VX@3&%K92!!=71O;6%T960@4F5P;W)T:6YG(%-T
M871I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V-2XR,3<Z+3$R,RXT
M,S,G72`]("=$96QI;F4L($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-C4N,C@S.BTQ,C8N.#`P)UT@/2`G3F]R;6%N(%=E;&QS+"!.+B!7
M+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8U+C8Q-SHM,3$X+C$Q
M-R==(#T@)T-A;7-E;&P@4FEV97(L($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-C4N-S8W.BTQ,3$N,C,S)UT@/2`G3'5P:6XL($XN(%<N
M(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C4N.34P.BTQ,S`N-#8W
M)UT@/2`G4F%M<&%R="!2:79E<B!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I
M;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C8N,#`P.BTQ
M,3<N-S8W)UT@/2`G0VQU="!,86ME($%U=&]M871E9"!297!O<G1I;F<@4W1A
M=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8V+C`S,SHM.3$N.#,S
M)UT@/2`G0BP@4B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8V+C`X,SHM
M.38N-3`P)UT@/2`G0F%C:R!2:79E<B!-971E;W)O;&]G:6-A;"!!97)O;F%U
M=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S8V+C$U,#HM-C4N-S,S)UT@/2`G4&%N9VYI<G1U;F<G.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<V-BXU.#,Z+38Q+C8Q-R==(#T@)T-A<&4@
M1'EE<BP@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V-BXX
M-C<Z+3$S-"XR,#`G72`]("=3871A:"!2:79E<B!!=71O;6%T:6,@5V5A=&AE
M<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-C<N,#,S.BTQ,C8N,#@S)UT@/2`G0V]L=FEL;&4@3&%K92<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S8W+C`V-SHM,3(Q+C$P,"==(#T@)TAA;&1A;F4@
M4FEV97(@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S8W+C(P,#HM,3,P+C(Q-R==(#T@)TQI
M='1L92!#:&EC86=O)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C<N-3,S
M.BTV,RXW.#,G72`]("="<F]U9VAT;VX@27-L86YD)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-C<N-38W.BTQ,SDN.#,S)UT@/2`G3VQD($-R;W<@075T
M;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S8W+C<P,#HM,3`T+C0V-R==(#T@)T5L;&EC92!2:79E
M<B!!=71O;6%T960@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<V-RXX,3<Z+3$Q-2XQ,S,G72`]("=#;W!P97)M:6YE+"!.
M+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8X+C(U.#HM,3(R
M+C$P-"==(#T@)U%A=G9I:R!,86ME+"!.+B!7+B!4+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S8X+C,P,#HM,3,S+C0X,R==(#T@)TEN=79I:RP@3BX@
M5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V."XS,#`Z+3@U+C8V
M-R==(#T@)TUA8VMA<B!);FQE="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S8X+C,Q-SHM,3`P+C`X,R==(#T@)TAA="!)<VQA;F0L($XN(%<N(%0N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C@N-#,S.BTX.2XW,3<G72`]("=0
M96QL>2!"87DG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V."XT-C<Z+38V
M+C@P,"==(#T@)T-A<&4@2&]O<&5R+"!.+B!7+B!4+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S8X+C4P,#HM,3$S+C(Q-R==(#T@)TQA9'D@1G)A;FML
M:6X@4&]I;G0L($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-C@N-C4P.BTQ,#$N-S,S)UT@/2`G2F5N;GD@3&EN9"!)<VQA;F0@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8X+C8U,#HM-S$N,38W)UT@
M/2`G1&5W87(@3&%K97,L($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-C@N-S4P.BTQ,#DN,#8W)UT@/2`G0GER;VX@0F%Y($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V."XW-3`Z+3$S,RXU,#`G72`]
M("=4<F%I;"!686QL97DL($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-C@N-S@S.BTQ,30N.#,S)UT@/2`G0F5R;F%R9"!(87)B;W5R)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C@N-S@S.BTX,2XR-3`G72`]("=(
M86QL($)E86-H+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S8X+C@Q-SHM.3,N-#,S)UT@/2`G4VAE<&AE<F0@0F%Y+"!.+B!7+B!4+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8X+C@X,SHM-S4N,3,S)UT@/2`G
M3&]N9W-T869F($)L=69F+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S8X+CDP,#HM,3,S+CDS,R==(#T@)U-T;W)M($AI;&QS+"!.+B!7
M+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8X+CDS,SHM,3$V+CDQ
M-R==(#T@)T-A<&4@66]U;F<@06ER<&]R="<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S8X+CDU,#HM,3,W+C(Q-R==(#T@)U-H:6YG;&4@4&]I;G0L(%DN
M(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-CDN,3`P.BTQ,#4N,3$W
M)UT@/2`G0V%M8G)I9&=E($)A>2P@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<V.2XQ-3`Z+3$T,"XQ-3`G72`]("=)=G9A=FEK(%!A<FL@
M075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S8Y+C$X,SHM,3(R+C,U,"==(#T@)U1U:W1U="!.
M;V=A:70L($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-CDN
M,S4P.BTQ,C0N,#4P)UT@/2`G4&%U;&%T=6L@075T;VUA=&5D(%)E<&]R=&EN
M9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-CDN-#,S.BTQ
M,S,N,#,S)UT@/2`G5'5K=&]Y86MT=6L@075T;VUA=&5D(%)E<&]R=&EN9R!3
M=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-CDN-#,S.BTX.2XW
M,S,G72`]("=096QL>2!"87D@,2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S8Y+C0U,#HM,3,S+C`Q-R==(#T@)U1U:W1O>6%K='5K)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-CDN-38W.BTQ,S@N.3$W)UT@/2`G2&5R<V-H96P@
M27-L86YD($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<V.2XU.#,Z+3$T,"XQ.#,G72`]("=+
M;VUA:W5K($)E86-H($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<V.2XV,#`Z+3$S,"XY,#`G72`]("=,:79E<G!O;VP@0F%Y)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-CDN-C$W.BTQ-#`N,C`P)UT@/2`G2V]M86MU
M:R!"96%C:"P@62X@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V.2XV
M,S,Z+3$S-2XT,S,G72`]("=096QL>2!)<VQA;F0@075T;VUA=&EC(%=E871H
M97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S8Y+CDS,SHM,3(X+CDV-R==(#T@)TYI8VAO;'-O;B!096YI;G-U;"<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S<P+C$V-SHM,3(T+C<P,"==(#T@)T-A
M<&4@4&%R<GDL($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-S`N-#@S.BTV."XU,3<G72`]("=#;'ED92P@3BX@5RX@5"XG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<W,BXP,#`Z+3$R-2XR-C<G72`]("=386-H<R!(
M87)B;W5R+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S<R
M+C<P,#HM-S<N.38W)UT@/2`G4&]N9"!);FQE="P@3BX@5RX@5"XG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<W-"XQ,S,Z+3$Q.2XY.#,G72`]("=!=6QV
M:6L@3F%T:6]N86P@4&%R:R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S<T
M+C<Q-SHM.30N.3@S)UT@/2`G4F5S;VQU=&4L($XN(%<N(%0N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-S8N,C,S.BTQ,3DN,S,S)UT@/2`G36]U;&0@
M0F%Y+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S<X+C<X
M,SHM,3`S+C4U,"==(#T@)TES86-H<V5N($UE=&5O<F]L;V=I8V%L($%E<F]N
M875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-SDN.3@S.BTX-2XY,S,G72`]("=%=7)E:V$L($XN(%<N(%0N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG.#(N-3`P.BTV,BXS,S,G72`]
M("=!;&5R="P@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A<&4@5F5R9&4G
M75LG,38N-S,S.BTR,BXY-3`G72`]("=386PG.PHD8V]O<F1I;F%T97-;)T-A
M>6UA;B!)<VQA;F1S)UU;)S$Y+C(X,SHM.#$N,S4P)UT@/2`G3W=E;B!2;V)E
M<G1S($%I<G!O<G1G<F%N9"!#87EM86XG.PHD8V]O<F1I;F%T97-;)T-E;G1R
M86P@069R:6-A;B!297!U8FQI8R==6R<Q,"XR.#,Z,C(N-S@S)UT@/2`G0FER
M86\G.PHD8V]O<F1I;F%T97-;)T-E;G1R86P@069R:6-A;B!297!U8FQI8R==
M6R<T+C(U,#HQ-2XX,#`G72`]("="97)B97)A=&DG.PHD8V]O<F1I;F%T97-;
M)T-E;G1R86P@069R:6-A;B!297!U8FQI8R==6R<T+C0P,#HQ."XU,3<G72`]
M("="86YG=6DG.PHD8V]O<F1I;F%T97-;)T-E;G1R86P@069R:6-A;B!297!U
M8FQI8R==6R<T+C<S,SHR,BXX,S,G72`]("="86YG87-S;W4G.PHD8V]O<F1I
M;F%T97-;)T-E;G1R86P@069R:6-A;B!297!U8FQI8R==6R<U+C`U,#HR,2XR
M,#`G72`]("=!;&EN9&%O)SL*)&-O;W)D:6YA=&5S6R=#96YT<F%L($%F<FEC
M86X@4F5P=6)L:6,G75LG-2XR-C<Z,3<N-C,S)UT@/2`G0F]S<V5M8F5L92<[
M"B1C;V]R9&EN871E<ULG0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC)UU;)S4N
M-#`P.C(V+C4P,"==(#T@)T]B;R<["B1C;V]R9&EN871E<ULG0V5N=')A;"!!
M9G)I8V%N(%)E<'5B;&EC)UU;)S4N.#4P.C(P+C8U,"==(#T@)T)A;6)A<FDG
M.PHD8V]O<F1I;F%T97-;)T-E;G1R86P@069R:6-A;B!297!U8FQI8R==6R<U
M+CDV-SHQ-2XV,S,G72`]("=";W5A<B<["B1C;V]R9&EN871E<ULG0V5N=')A
M;"!!9G)I8V%N(%)E<'5B;&EC)UU;)S8N-#@S.C$W+C0S,R==(#T@)T)O<W-A
M;F=O82<["B1C;V]R9&EN871E<ULG0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC
M)UU;)S8N-3`P.C(S+C(V-R==(#T@)UEA;&EN9V$G.PHD8V]O<F1I;F%T97-;
M)T-E;G1R86P@069R:6-A;B!297!U8FQI8R==6R<V+C4S,SHR,2XY.#,G72`]
M("="<FEA)SL*)&-O;W)D:6YA=&5S6R=#96YT<F%L($%F<FEC86X@4F5P=6)L
M:6,G75LG."XT,#`Z,C`N-C4P)UT@/2`G3EPG1&5L92<["B1C;V]R9&EN871E
M<ULG0VAA9"==6R<Q,2XP,S,Z,C`N,C@S)UT@/2`G06TM5&EM86XG.PHD8V]O
M<F1I;F%T97-;)T-H860G75LG,3(N,3,S.C$U+C`S,R==(#T@)TYD:F%M96YA
M)SL*)&-O;W)D:6YA=&5S6R=#:&%D)UU;)S$R+C,X,SHQ-RXP-3`G72`]("="
M;VMO<F\G.PHD8V]O<F1I;F%T97-;)T-H860G75LG,3,N-#,S.C$T+C<S,R==
M(#T@)T)O;"U"97)I;2<["B1C;V]R9&EN871E<ULG0VAA9"==6R<Q,RXX-3`Z
M,C`N.#4P)UT@/2`G06)E8VAE)SL*)&-O;W)D:6YA=&5S6R=#:&%D)UU;)S$X
M+C`P,#HQ.2XQ-C<G72`]("=&87EA)SL*)&-O;W)D:6YA=&5S6R=#:&%D)UU;
M)S@N-C$W.C$V+C`V-R==(#T@)TUO=6YD;W4G.PHD8V]O<F1I;F%T97-;)T-H
M860G75LG.2XQ-3`Z,3@N,S@S)UT@/2`G4V%R:"<["B1C;V]R9&EN871E<ULG
M0VAA9"==6R<Y+C,V-SHQ-"XY,3<G72`]("=086QA)SL*)&-O;W)D:6YA=&5S
M6R=#:&EL92==6R<M,3@N,S,S.BTW,"XS,S,G72`]("=!<FEC82<["B1C;V]R
M9&EN871E<ULG0VAI;&4G75LG+3(P+C4S,SHM-S`N,3@S)UT@/2`G27%U:7%U
M92`O($1I96=O($%R86,G.PHD8V]O<F1I;F%T97-;)T-H:6QE)UU;)RTR,RXT
M,S,Z+3<P+C0S,R==(#T@)T%N=&]F86=A<W1A)SL*)&-O;W)D:6YA=&5S6R=#
M:&EL92==6R<M,C8N,S$W.BTW,"XV,3<G72`]("=#:&%N87)A;"<["B1C;V]R
M9&EN871E<ULG0VAI;&4G75LG+3(W+C$U,#HM,3`Y+C0Q-R==(#T@)TES;&$@
M1&4@4&%S8W5A)SL*)&-O;W)D:6YA=&5S6R=#:&EL92==6R<M,C<N,S`P.BTW
M,"XT,3<G72`]("=#;W!I87!O)SL*)&-O;W)D:6YA=&5S6R=#:&EL92==6R<M
M,C@N-C`P.BTW,"XW-C<G72`]("=686QL96YA<B<["B1C;V]R9&EN871E<ULG
M0VAI;&4G75LG+3(Y+CDP,#HM-S$N,C`P)UT@/2`G3&$@4V5R96YA)SL*)&-O
M;W)D:6YA=&5S6R=#:&EL92==6R<M,S(N-S@S.BTW,2XU,3<G72`]("=1=6EN
M=&5R;R!386YT:6%G;R<["B1C;V]R9&EN871E<ULG0VAI;&4G75LG+3,S+C,X
M,SHM-S`N-S@S)UT@/2`G4'5D86AU96PG.PHD8V]O<F1I;F%T97-;)T-H:6QE
M)UU;)RTS-"XY-C<Z+3<Q+C(S,R==(#T@)T-U<FEC;R<["B1C;V]R9&EN871E
M<ULG0VAI;&4G75LG+3,V+C4V-SHM-S(N,#,S)UT@/2`G0VAI;&QA;B<["B1C
M;V]R9&EN871E<ULG0VAI;&4G75LG+3,V+C<V-SHM-S,N,#4P)UT@/2`G0V]N
M8V5P8VEO;B<["B1C;V]R9&EN871E<ULG0VAI;&4G75LG+3,X+C<U,#HM-S(N
M-C,S)UT@/2`G5&5M=6-O)SL*)&-O;W)D:6YA=&5S6R=#:&EL92==6R<M,SDN
M-C$W.BTW,RXP.#,G72`]("=686QD:79I82<["B1C;V]R9&EN871E<ULG0VAI
M;&4G75LG+30Q+C0Q-SHM-S,N,#@S)UT@/2`G4'5E<G1O($UO;G1T)SL*)&-O
M;W)D:6YA=&5S6R=#:&EL92==6R<M-#4N-3@S.BTW,BXQ,3<G72`]("=#;WEH
M86EQ=64G.PHD8V]O<F1I;F%T97-;)T-H:6QE)UU;)RTT-2XY,3<Z+3<Q+C8X
M,R==(#T@)T)A;&UA8V5D82<["B1C;V]R9&EN871E<ULG0VAI;&4G75LG+30V
M+C4U,#HM-S$N-S`P)UT@/2`G0VAI;&4@0VAI8V\G.PHD8V]O<F1I;F%T97-;
M)T-H:6QE)UU;)RTT-RXR,S,Z+3<R+C4U,"==(#T@)T-O8VAR86YE)SL*)&-O
M;W)D:6YA=&5S6R=#:&EL92==6R<M-3,N,#`P.BTW,"XX-3`G72`]("=0=6YT
M82!!<F5N87,G.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S(P+C`S,SHQ,3`N
M,S4P)UT@/2`G2&%I:V]U)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<R,2XR
M,3<Z,3$P+C0P,"==(#T@)UIH86YJ:6%N9R<["B1C;V]R9&EN871E<ULG0VAI
M;F$G75LG,C(N-34P.C$Q-"XQ,#`G72`]("=3:&5N>FAE;B<["B1C;V]R9&EN
M871E<ULG0VAI;F$G75LG,C(N.#$W.C$P."XS-3`G72`]("=.86YN:6YG)SL*
M)&-O;W)D:6YA=&5S6R=#:&EN82==6R<R,RXQ-C<Z,3$S+C,S,R==(#T@)T=U
M86YG>FAO=2<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG,C,N-#`P.C$Q-BXV
M.#,G72`]("=3:&%N=&]U)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<R-"XT
M.#,Z,3$X+C`X,R==(#T@)UAI86UE;B<["B1C;V]R9&EN871E<ULG0VAI;F$G
M75LG,C4N,#$W.C$P,BXV.#,G72`]("=+=6YM:6YG)SL*)&-O;W)D:6YA=&5S
M6R=#:&EN82==6R<R-2XS,S,Z,3$P+C,P,"==(#T@)T=U:6QI;B<["B1C;V]R
M9&EN871E<ULG0VAI;F$G75LG,C4N.#4P.C$Q-"XY-3`G72`]("='86YZ:&]U
M)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<R-BXP.#,Z,3$Y+C(X,R==(#T@
M)T9U>FAO=2<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG,C8N-3@S.C$P-BXW
M,3<G72`]("='=6EY86YG)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<R."XR
M,#`Z,3$S+C`X,R==(#T@)T-H86YG<VAA)SL*)&-O;W)D:6YA=&5S6R=#:&EN
M82==6R<R."XV,#`Z,3$U+CDQ-R==(#T@)TYA;F-H86YG)SL*)&-O;W)D:6YA
M=&5S6R=#:&EN82==6R<R.2XU,3<Z,3`V+C0X,R==(#T@)T-H;VYG<6EN9R<[
M"B1C;V]R9&EN871E<ULG0VAI;F$G75LG,CDN-C8W.CDQ+C$S,R==(#T@)TQH
M87-A)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<S,"XR,S,Z,3(P+C$V-R==
M(#T@)TAA;F=Z:&]U)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<S,"XV,3<Z
M,3$T+C$S,R==(#T@)U=U:&%N)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<S
M,"XV-C<Z,3`T+C`Q-R==(#T@)T-H96YG9'4G.PHD8V]O<F1I;F%T97-;)T-H
M:6YA)UU;)S,Q+C$V-SHQ,C$N-#,S)UT@/2`G4VAA;F=H86D@+R!(;VYG<6EA
M;R<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG,S$N.#8W.C$Q-RXR,S,G72`]
M("=(969E:2<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG,S(N,#`P.C$Q."XX
M,#`G72`]("=.86YJ:6YG)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<S-"XS
M,#`Z,3`X+CDS,R==(#T@)UAI7"=!;B<["B1C;V]R9&EN871E<ULG0VAI;F$G
M75LG,S0N-S$W.C$Q,RXV-3`G72`]("=::&5N9WIH;W4G.PHD8V]O<F1I;F%T
M97-;)T-H:6YA)UU;)S,V+C`V-SHQ,C`N,S,S)UT@/2`G46EN9V1A;R<["B1C
M;V]R9&EN871E<ULG0VAI;F$G75LG,S8N-C`P.C$P.2XU,#`G72`]("=986X@
M06XG.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S,V+C8Q-SHQ,#$N-S8W)UT@
M/2`G6&EN:6YG)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<S-BXV.#,Z,3$V
M+CDX,R==(#T@)TII;F%N)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<S-RXQ
M,S,Z-SDN.3,S)UT@/2`G2&]T86XG.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;
M)S,W+C<X,SHQ,3(N-34P)UT@/2`G5&%I>75A;B<["B1C;V]R9&EN871E<ULG
M0VAI;F$G75LG,S@N-#@S.C$P-BXR,3<G72`]("=9:6YC:'5A;B<["B1C;V]R
M9&EN871E<ULG0VAI;F$G75LG,S@N.3`P.C$R,2XV,S,G72`]("=$86QI86XG
M.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S,Y+C0V-SHW-2XY.#,G72`]("=+
M87-H:2<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG,SDN-S8W.CDX+C0X,R==
M(#T@)TII=7%U86XG.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S,Y+CDS,SHQ
M,38N,C@S)UT@/2`G0F5I:FEN9R<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG
M-#`N.#$W.C$Q,2XV.#,G72`]("=(;VAH;W0G.PHD8V]O<F1I;F%T97-;)T-H
M:6YA)UU;)S0R+C@Q-SHY,RXU,3<G72`]("=(86UI)SL*)&-O;W)D:6YA=&5S
M6R=#:&EN82==6R<T,RXY,#`Z,3(U+C(Q-R==(#T@)T-H86YG8VAU;B<["B1C
M;V]R9&EN871E<ULG0VAI;F$G75LG-#,N.34P.C@Q+C,S,R==(#T@)UEI;FEN
M9R<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG-#<N,S@S.C$R,RXY,3<G72`]
M("=1:7%I:&%R)SL*)&-O;W)D:6YA=&5S6R=#:')I<W1M87,@27-L86YD)UU;
M)RTQ,"XT,S,Z,3`U+C8X,R==(#T@)T-H<FES=&UA<R!)<VQA;F0@065R;V1R
M;VUE)SL*)&-O;W)D:6YA=&5S6R=#:')I<W1M87,@27-L86YD)UU;)RTQ,BXQ
M.#,Z.38N.#$W)UT@/2`G0V]C;W,@27-L86YD($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)T-O;&]M8FEA)UU;)S`N-3`P.BTW-BXU,#`G72`]("=0=65R=&\@
M07-I<R<["B1C;V]R9&EN871E<ULG0V]L;VUB:6$G75LG,"XX,3<Z+3<W+C8S
M,R==(#T@)TEP:6%L97,@+R!386X@3'5I<R<["B1C;V]R9&EN871E<ULG0V]L
M;VUB:6$G75LG,2XQ,S,Z+3<P+C`U,"==(#T@)TUI='4G.PHD8V]O<F1I;F%T
M97-;)T-O;&]M8FEA)UU;)S$N-#$W.BTW-RXR-C<G72`]("=087-T;R`O($%N
M=&]N:6\@3F%R:6XG.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S$P+C0S
M,SHM-S,N,C4P)UT@/2`G5F%L;&5D=7!A<B`O($%L9F]N<V\@3&]P97HG.PHD
M8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S$P+C0U,#HM-S4N-3$W)UT@/2`G
M0V%R=&%G96YA("\@4F%F865L($YU;F5Z)SL*)&-O;W)D:6YA=&5S6R=#;VQO
M;6)I82==6R<Q,"XX.#,Z+3<T+C<X,R==(#T@)T)A<G)A;G%U:6QL82`O($5R
M;F5S=&]C;W)T:7-S;WHG.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S$Q
M+C$S,SHM-S0N,C,S)UT@/2`G4V%N=&$@36%R=&$@+R!3:6UO;B!";VQI=F%R
M)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<Q,2XU,S,Z+3<R+CDS,R==
M(#T@)U)I;VAA8VAA("\@06QM:7)A;G1E(%!A9&EL;&$G.PHD8V]O<F1I;F%T
M97-;)T-O;&]M8FEA)UU;)S$R+C4X,SHM.#$N-S$W)UT@/2`G4V%N($%N9')E
M<R!)<VQA("\@4V5S<75I8V5N=&5N87)I;R<["B1C;V]R9&EN871E<ULG0V]L
M;VUB:6$G75LG,3,N,S8W.BTX,2XS-3`G72`]("=0<F]V:61E;F-I82!)<VQA
M("\@16P@16UB<G5J;R<["B1C;V]R9&EN871E<ULG0V]L;VUB:6$G75LG,BXT
M-C<Z+3<V+C8P,"==(#T@)U!O<&%Y86X@+R!'=6EL;&5R;6\G.PHD8V]O<F1I
M;F%T97-;)T-O;&]M8FEA)UU;)S(N-38W.BTW,BXV,S,G72`]("=386X@2F]S
M92!$96P@1W5A=FEA<F4G.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S(N
M.38W.BTW-2XS,#`G72`]("=.96EV82`O($)E;FET;R!386QA<R<["B1C;V]R
M9&EN871E<ULG0V]L;VUB:6$G75LG,RXU-3`Z+3<V+C,X,R==(#T@)T-A;&D@
M+R!!;&9O;G-O($)O;FEL;&%A<F%G;VXG.PHD8V]O<F1I;F%T97-;)T-O;&]M
M8FEA)UU;)S,N.#4P.BTW-BXY-C<G72`]("="=65N879E;G1U<F$G.PHD8V]O
M<F1I;F%T97-;)T-O;&]M8FEA)UU;)RTT+C$V-SHM-CDN.34P)UT@/2`G3&5T
M:6-I82`O(%9A<W%U97H@0V]B;R<["B1C;V]R9&EN871E<ULG0V]L;VUB:6$G
M75LG-"XQ-C<Z+3<S+C8Q-R==(#T@)U9I;&QA=FEC96YC:6\@+R!686YG=6%R
M9&EA)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<T+C0S,SHM-S4N,34P
M)UT@/2`G26)A9W5E("\@4&5R86QE<R<["B1C;V]R9&EN871E<ULG0V]L;VUB
M:6$G75LG-"XU,#`Z+3<U+C<Q-R==(#T@)T%R;65N:6$@+R!%;"!%9&5N)SL*
M)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<T+C<Q-SHM-S0N,34P)UT@/2`G
M0F]G;W1A("\@16QD;W)A9&\G.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;
M)S0N.#$W.BTW-2XW,S,G72`]("=097)E:7)A("\@36%T96-A;F$G.PHD8V]O
M<F1I;F%T97-;)T-O;&]M8FEA)UU;)S4N-S$W.BTW-BXV,3<G72`]("=1=6EB
M9&\@+R!%;"!#87)A;F\G.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S8N
M,3,S.BTW-2XT,S,G72`]("=2:6]N96=R;R`O($HN($TN($-O<F1O=F$G.PHD
M8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S8N,38W.BTV-RXU,#`G72`]("=0
M=65R=&\@0V%R<F5N;R`O($$N($=U875Q=65A)SL*)&-O;W)D:6YA=&5S6R=#
M;VQO;6)I82==6R<V+C(Q-SHM-S4N-C`P)UT@/2`G365D96QL:6X@+R!/;&%Y
M82!(97)R97)A)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<W+C`Q-SHM
M-S,N.#`P)UT@/2`G0F%R<F%N8V%B97)M96IA("\@66%R:6=U:65S)SL*)&-O
M;W)D:6YA=&5S6R=#;VQO;6)I82==6R<W+C`V-SHM-S`N-S,S)UT@/2`G07)A
M=6-A("\@4V%N=&EA9V\@4&5R97HG.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA
M)UU;)S<N,3`P.BTW,RXR,#`G72`]("="=6-A<F%M86YG82`O(%!A;&]N96=R
M;R<["B1C;V]R9&EN871E<ULG0V]L;VUB:6$G75LG-RXX,3<Z+3<V+C<P,"==
M(#T@)T%P87)T861O("\@3&]S($-E9')O<R<["B1C;V]R9&EN871E<ULG0V]L
M;VUB:6$G75LG-RXY,S,Z+3<R+C4Q-R==(#T@)T-U8W5T82`O($-A;6EL;R!$
M87IA)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<X+C@Q-SHM-S4N.#4P
M)UT@/2`G36]N=&5R:6$@+R!,;W,@1V%R>F]N97,G.PHD8V]O<F1I;F%T97-;
M)T-O;6]R;W,G75LG+3$Q+C4S,SHT,RXR-C<G72`]("=(86AA>6$@26YT97)N
M871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#;VUO<F]S)UU;)RTQ
M,BXQ,3<Z-#0N-#,S)UT@/2`G3W5A;FD@06YJ;W5A;B<["B1C;V]R9&EN871E
M<ULG0V]M;W)O<R==6R<M,3(N.#`P.C0U+C(X,R==(#T@)T1Z86]U9'II("\@
M4&%M86YZ:2!-87EO='1E)SL*)&-O;W)D:6YA=&5S6R=#;VYG;R==6R<M,"XP
M,3<Z,34N-3@S)UT@/2`G36%K;W5A)SL*)&-O;W)D:6YA=&5S6R=#;VYG;R==
M6R<Q+C8Q-SHQ-BXP-3`G72`]("=/=65S<V\G.PHD8V]O<F1I;F%T97-;)T-O
M;F=O)UU;)S$N-C$W.C$X+C`V-R==(#T@)TEM<&9O;F1O)SL*)&-O;W)D:6YA
M=&5S6R=#;VYG;R==6R<M,2XX-C<Z,34N.#8W)UT@/2`G1V%M8F]M82<["B1C
M;V]R9&EN871E<ULG0V]N9V\G75LG,BXP-C<Z,30N,3,S)UT@/2`G4V]U86YK
M92<["B1C;V]R9&EN871E<ULG0V]N9V\G75LG+3(N-3,S.C$T+C<V-R==(#T@
M)T1J86UB86QA)SL*)&-O;W)D:6YA=&5S6R=#;VYG;R==6R<M,BXV,3<Z,38N
M,C$W)UT@/2`G35PG4&]U>6$G.PHD8V]O<F1I;F%T97-;)T-O;F=O)UU;)RTS
M+C0X,SHQ,BXV,3<G72`]("=-86MA8F%N82<["B1C;V]R9&EN871E<ULG0V]N
M9V\G75LG+3,N-C@S.C$S+C,U,"==(#T@)U-I8FET:2<["B1C;V]R9&EN871E
M<ULG0V]N9V\G75LG+3,N.3@S.C$S+CDQ-R==(#T@)TUO=7EO;F1Z:2<["B1C
M;V]R9&EN871E<ULG0V]N9V\G75LG+30N,C`P.C$R+C<P,"==(#T@)TQO=6)O
M;6\G.PHD8V]O<F1I;F%T97-;)T-O;F=O)UU;)RTT+C(U,#HQ-2XR-3`G72`]
M("="<F%Z>F%V:6QL92`O($UA>6$M36%Y82<["B1C;V]R9&EN871E<ULG0V]N
M9V\G75LG+30N.#$W.C$Q+CDP,"==(#T@)U!O:6YT92U.;VER92<["B1C;V]R
M9&EN871E<ULG0V]O:R!)<VQA;F1S)UU;)RTQ.2XP-C<Z+3$V.2XY,3<G72`]
M("=!;&]F:2`O($YI=64G.PHD8V]O<F1I;F%T97-;)T-O;VL@27-L86YD<R==
M6R<M,C$N,C`P.BTQ-3DN.#$W)UT@/2`G4F%R;W1O;F=A)SL*)&-O;W)D:6YA
M=&5S6R=#;W-T82!2:6-A)UU;)S$P+C`P,#HM.#,N,#4P)UT@/2`G4'5E<G1O
M($QI;6]N)SL*)&-O;W)D:6YA=&5S6R=#;W-T82!2:6-A)UU;)S$P+C`P,#HM
M.#0N,C$W)UT@/2`G2G5A;B!386YT86UA<FEA)SL*)&-O;W)D:6YA=&5S6R=#
M;W-T82!2:6-A)UU;)S$P+C$U,#HM.#4N-#4P)UT@/2`G3FEC;WEA)SL*)&-O
M;W)D:6YA=&5S6R=#;W-T82!2:6-A)UU;)S$P+C8Q-SHM.#4N-#,S)UT@/2`G
M3&EB97)I82<["B1C;V]R9&EN871E<ULG0V]S=&$@4FEC82==6R<X+CDU,#HM
M.#,N-#8W)UT@/2`G4&%L;6%R(%-U<B<["B1C;V]R9&EN871E<ULG0V]T92!$
M7"=)=F]I<F4G75LG-"XT,3<Z+3<N,S8W)UT@/2`G5&%B;W4G.PHD8V]O<F1I
M;F%T97-;)T-O=&4@1%PG279O:7)E)UU;)S0N-S4P.BTV+C8U,"==(#T@)U-A
M;B!0961R;R<["B1C;V]R9&EN871E<ULG0V]T92!$7"=)=F]I<F4G75LG-"XY
M-3`Z+38N,#@S)UT@/2`G4V%S<V%N9')A)SL*)&-O;W)D:6YA=&5S6R=#;W1E
M($1<)TEV;VER92==6R<U+C(U,#HM,RXY,S,G72`]("=!8FED:F%N)SL*)&-O
M;W)D:6YA=&5S6R=#;W1E($1<)TEV;VER92==6R<U+C,P,#HM,RXS,#`G72`]
M("=!9&EA:V4G.PHD8V]O<F1I;F%T97-;)T-O=&4@1%PG279O:7)E)UU;)S8N
M,3,S.BTU+CDU,"==(#T@)T=A9VYO82<["B1C;V]R9&EN871E<ULG0V]T92!$
M7"=)=F]I<F4G75LG-BXV-3`Z+30N-S`P)UT@/2`G1&EM8F]K<F\G.PHD8V]O
M<F1I;F%T97-;)T-O=&4@1%PG279O:7)E)UU;)S8N.#8W.BTV+C0V-R==(#T@
M)T1A;&]A)SL*)&-O;W)D:6YA=&5S6R=#;W1E($1<)TEV;VER92==6R<V+CDP
M,#HM-2XS-3`G72`]("=986UO=7-S;W5K<F\G.PHD8V]O<F1I;F%T97-;)T-O
M=&4@1%PG279O:7)E)UU;)S<N,S@S.BTW+C4Q-R==(#T@)TUA;B<["B1C;V]R
M9&EN871E<ULG0V]T92!$7"=)=F]I<F4G75LG-RXW,S,Z+34N,#8W)UT@/2`G
M0F]U86ME)SL*)&-O;W)D:6YA=&5S6R=#;W1E($1<)TEV;VER92==6R<X+C`U
M,#HM,BXW.#,G72`]("=";VYD;W5K;W4G.PHD8V]O<F1I;F%T97-;)T-O=&4@
M1%PG279O:7)E)UU;)SDN-#$W.BTU+C8Q-R==(#T@)TMO<FAO9V\G.PHD8V]O
M<F1I;F%T97-;)T-O=&4@1%PG279O:7)E)UU;)SDN-3`P.BTW+C4V-R==(#T@
M)T]D:65N;F4G.PHD8V]O<F1I;F%T97-;)T-R;V%T:6$G75LG-#(N-38W.C$X
M+C(V-R==(#T@)T1U8G)O=FYI:R`O($-I;&EP:2<["B1C;V]R9&EN871E<ULG
M0W)O871I82==6R<T,RXQ-C<Z,38N-#4P)UT@/2`G2'9A<B<["B1C;V]R9&EN
M871E<ULG0W)O871I82==6R<T,RXU,S,Z,38N,S`P)UT@/2`G4W!L:70@+R!2
M97-N:6LG.PHD8V]O<F1I;F%T97-;)T-R;V%T:6$G75LG-#0N,3`P.C$U+C,U
M,"==(#T@)UIA9&%R("\@6F5M=6YI:R<["B1C;V]R9&EN871E<ULG0W)O871I
M82==6R<T-2XP,S,Z,3@N.#`P)UT@/2`G3W-I:F5K("\@0V5P:6XG.PHD8V]O
M<F1I;F%T97-;)T-R;V%T:6$G75LG-#4N,38W.C$X+C`P,"==(#T@)U-L879O
M;G-K:2!"<F]D)SL*)&-O;W)D:6YA=&5S6R=#<F]A=&EA)UU;)S0U+C(Q-SHQ
M-"XU.#,G72`]("=2:6IE:V$@+R!/;6ES86QJ)SL*)&-O;W)D:6YA=&5S6R=#
M<F]A=&EA)UU;)S0U+C<S,SHQ-BXP-C<G72`]("=:86=R96(@+R!0;&5S;R<[
M"B1C;V]R9&EN871E<ULG0W)O871I82==6R<T-2XX,3<Z,38N,#,S)UT@/2`G
M6F%G<F5B("\@36%K<VEM:7(G.PHD8V]O<F1I;F%T97-;)T-R;V%T:6$G75LG
M-#4N.3`P.C$S+CDQ-R==(#T@)U!U;&$@065R;V1R;VUE)SL*)&-O;W)D:6YA
M=&5S6R=#<F]A=&EA)UU;)S0V+C,P,#HQ-BXS.#,G72`]("=687)A>F1I;B<[
M"B1C;V]R9&EN871E<ULG0W5B82==6R<Q.2XY,#`Z+3<U+C$S,R==(#T@)T=U
M86YT86YA;6\L($]R:65N=&4G.PHD8V]O<F1I;F%T97-;)T-U8F$G75LG,3DN
M.38W.BTW-2XX-3`G72`]("=386YT:6%G;R!$92!#=6)A+"!/<FEE;G1E)SL*
M)&-O;W)D:6YA=&5S6R=#=6)A)UU;)S(P+C`X,SHM-S4N,34P)UT@/2`G1W5A
M;G1A;F%M;RP@3W)I96YT92<["B1C;V]R9&EN871E<ULG0W5B82==6R<R,"XS
M,S,Z+3<W+C$Q-R==(#T@)TUA;GIA;FEL;&\L($]R:65N=&4G.PHD8V]O<F1I
M;F%T97-;)T-U8F$G75LG,C`N,S4P.BTW-"XU,#`G72`]("="87)A8V]A+"!/
M<FEE;G1E)SL*)&-O;W)D:6YA=&5S6R=#=6)A)UU;)S(P+CDU,#HM-S8N.34P
M)UT@/2`G3&%S(%1U;F%S+"!,87,@5'5N87,G.PHD8V]O<F1I;F%T97-;)T-U
M8F$G75LG,C$N-#$W.BTW-RXX-3`G72`]("=#86UA9W5E>2!!97)O<'5E<G1O
M)SL*)&-O;W)D:6YA=&5S6R=#=6)A)UU;)S(Q+C<X,SHM-S@N-S@S)UT@/2`G
M5F5N97IU96QA+"!#:65G;R!$92!!=FEL82<["B1C;V]R9&EN871E<ULG0W5B
M82==6R<R,2XX,S,Z+3@R+C<X,R==(#T@)TYU979A($=E<F]N82P@27-L82!$
M92!0:6YO<R<["B1C;V]R9&EN871E<ULG0W5B82==6R<R,BXQ-3`Z+3@P+C0P
M,"==(#T@)T-I96YF=65G;W,L($QA<R!6:6QL87,G.PHD8V]O<F1I;F%T97-;
M)T-U8F$G75LG,C(N-#$W.BTX,RXV.#,G72`]("=0:6YA<B!$96P@4FEO+"!0
M:6YA<B!$96P@4FEO)SL*)&-O;W)D:6YA=&5S6R=#=6)A)UU;)S(R+CDX,SHM
M.#(N-#`P)UT@/2`G065R;W!U97)T;R!*;W-E($UA<G1I+"!286YC:&\M0F]Y
M97)O<RP@2&%B86YA)SL*)&-O;W)D:6YA=&5S6R=#=6)A)UU;)S(S+C$S,SHM
M.#$N,C@S)UT@/2`G5F%R861E<F\L($UA=&%N>F%S)SL*)&-O;W)D:6YA=&5S
M6R=#>7!R=7,G75LG,S0N-3@S.C,R+CDX,R==(#T@)T%K<F]T:7)I)SL*)&-O
M;W)D:6YA=&5S6R=#>7!R=7,G75LG,S0N-S$W.C,R+C0X,R==(#T@)U!A<&AO
M<R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#>7!R=7,G75LG,S0N.#@S.C,S
M+C8S,R==(#T@)TQA<FYA8V$@06ER<&]R="<["B1C;V]R9&EN871E<ULG0WEP
M<G5S)UU;)S,U+C$U,#HS,RXT,#`G72`]("=!=&AA;&%S<V$G.PHD8V]O<F1I
M;F%T97-;)T-Z96-H(%)E<'5B;&EC)UU;)S0Y+C$U,#HQ-BXW,#`G72`]("="
M<FYO("\@5'5R86YY)SL*)&-O;W)D:6YA=&5S6R=#>F5C:"!297!U8FQI8R==
M6R<T.2XS,3<Z,3<N-38W)UT@/2`G2&]L97-O=B<["B1C;V]R9&EN871E<ULG
M0WIE8V@@4F5P=6)L:6,G75LG-#DN-C@S.C$X+C$Q-R==(#T@)T]S=')A=F$@
M+R!-;W-N;W8G.PHD8V]O<F1I;F%T97-;)T-Z96-H(%)E<'5B;&EC)UU;)S4P
M+C$P,#HQ-"XR-3`G72`]("=0<F%H82`O(%)U>GEN92<["B1C;V]R9&EN871E
M<ULG0WIE8V@@4F5P=6)L:6,G75LG-3`N,C`P.C$R+CDQ-R==(#T@)TMA<FQO
M=GD@5F%R>2<["B1C;V]R9&EN871E<ULG1&5N;6%R:R==6R<U-"XW,#`Z,3$N
M-#4P)UT@/2`G36%R:6)O($QU9G1H879N)SL*)&-O;W)D:6YA=&5S6R=$96YM
M87)K)UU;)S4T+CDV-SHY+C<X,R==(#T@)U-O96YD97)B;W)G($QU9G1H879N
M)SL*)&-O;W)D:6YA=&5S6R=$96YM87)K)UU;)S4U+C`Q-SHQ,"XU-C<G72`]
M("=3>61F>6YS($9L>79E<&QA9',G.PHD8V]O<F1I;F%T97-;)T1E;FUA<FLG
M75LG-34N,#8W.C$T+C<U,"==(#T@)U)O96YN92<["B1C;V]R9&EN871E<ULG
M1&5N;6%R:R==6R<U-2XP.#,Z,3$N-S@S)UT@/2`G079N;R!$86YI<V@@06ER
M($9O<F-E($)A<V4G.PHD8V]O<F1I;F%T97-;)T1E;FUA<FLG75LG-34N,C,S
M.CDN,C8W)UT@/2`G4VMR>61S=')U<"<["B1C;V]R9&EN871E<ULG1&5N;6%R
M:R==6R<U-2XT,S,Z.2XS,S,G72`]("=686UD<G5P)SL*)&-O;W)D:6YA=&5S
M6R=$96YM87)K)UU;)S4U+C0X,SHQ,"XS,S,G72`]("=/9&5N<V4@+R!"96QD
M<FEN9V4G.PHD8V]O<F1I;F%T97-;)T1E;FUA<FLG75LG-34N-3,S.C@N-38W
M)UT@/2`G17-B:F5R9R<["B1C;V]R9&EN871E<ULG1&5N;6%R:R==6R<U-2XU
M.#,Z,3(N,3,S)UT@/2`G2V]E8F5N:&%V;B`O(%)O<VMI;&1E)SL*)&-O;W)D
M:6YA=&5S6R=$96YM87)K)UU;)S4U+C8Q-SHQ,BXV-3`G72`]("=+;V5B96YH
M879N("\@2V%S=')U<"<["B1C;V]R9&EN871E<ULG1&5N;6%R:R==6R<U-2XW
M,#`Z.2XR,#`G72`]("=686YD96PG.PHD8V]O<F1I;F%T97-;)T1E;FUA<FLG
M75LG-34N-S,S.CDN,38W)UT@/2`G0FEL;'5N9"!,=69T:&%V;B<["B1C;V]R
M9&EN871E<ULG1&5N;6%R:R==6R<U-2XW-C<Z,3(N,S,S)UT@/2`G5F%E<FQO
M97-E)SL*)&-O;W)D:6YA=&5S6R=$96YM87)K)UU;)S4V+C`P,#HX+C,U,"==
M(#T@)U-T875N:6YG($QU9G1H879N)SL*)&-O;W)D:6YA=&5S6R=$96YM87)K
M)UU;)S4V+C,P,#HQ,"XV,3<G72`]("=4:7)S=')U<"<["B1C;V]R9&EN871E
M<ULG1&5N;6%R:R==6R<U-BXS,#`Z.2XQ,3<G72`]("=+87)U<"<["B1C;V]R
M9&EN871E<ULG1&5N;6%R:R==6R<U-BXT,#`Z."XT-3`G72`]("=,:6YD=&]R
M<"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=$96YM87)K)UU;)S4V+C4U,#HY
M+C$V-R==(#T@)U-K:79E($QU9G1H879N)SL*)&-O;W)D:6YA=&5S6R=$96YM
M87)K)UU;)S4V+C<P,#HQ,2XU-3`G72`]("=!;FAO;'0@27-L86YD($%U=&]M
M871E9"!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG1&5N;6%R
M:R==6R<U-BXW,3<Z,3`N,3$W)UT@/2`G2&%D<W5N9"<["B1C;V]R9&EN871E
M<ULG1&5N;6%R:R==6R<U-RXP-C<Z."XW,3<G72`]("=4:&ES=&5D($QU9G1H
M879N)SL*)&-O;W)D:6YA=&5S6R=$96YM87)K)UU;)S4W+C$P,#HY+C@U,"==
M(#T@)T%A;&)O<F<G.PHD8V]O<F1I;F%T97-;)T1E;FUA<FLG75LG-3<N-3`P
M.C$P+C(Q-R==(#T@)U-I;F1A;"!&;'EV97!L861S)SL*)&-O;W)D:6YA=&5S
M6R=$96YM87)K)UU;)S8R+C`V-SHM-RXR.#,G72`]("=3;V5R=F%A9R`O(%9A
M9V%R)SL*)&-O;W)D:6YA=&5S6R=$:FEB;W5T:2==6R<Q,2XU-3`Z-#,N,34P
M)UT@/2`G1&II8F]U=&DG.PHD8V]O<F1I;F%T97-;)T1O;6EN:6-A)UU;)S$U
M+C,P,#HM-C$N-#`P)UT@/2`G4F]S96%U)SL*)&-O;W)D:6YA=&5S6R=$;VUI
M;FEC82==6R<Q-2XU,S,Z+38Q+C,P,"==(#T@)TUE;'9I;&QE($AA;&P@06ER
M<&]R="<["B1C;V]R9&EN871E<ULG1&]M:6YI8V$G75LG,34N-3,S.BTV,2XT
M,#`G72`]("=#86YE9FEE;&0@06ER<&]R="<["B1C;V]R9&EN871E<ULG1&]M
M:6YI8V%N(%)E<'5B;&EC)UU;)S$X+C(P,#HM-S$N,3`P)UT@/2`G0F%R86AO
M;F$G.PHD8V]O<F1I;F%T97-;)T1O;6EN:6-A;B!297!U8FQI8R==6R<Q."XT
M,S,Z+38Y+C8V-R==(#T@)TQA<R!!;65R:6-A<R<["B1C;V]R9&EN871E<ULG
M1&]M:6YI8V%N(%)E<'5B;&EC)UU;)S$X+C0V-SHM-CDN.38W)UT@/2`G2&5R
M<F5R82<["B1C;V]R9&EN871E<ULG1&]M:6YI8V%N(%)E<'5B;&EC)UU;)S$X
M+C4V-SHM-C@N,S8W)UT@/2`G4'5N=&$@0V%N82<["B1C;V]R9&EN871E<ULG
M1&]M:6YI8V%N(%)E<'5B;&EC)UU;)S$Y+C0U,#HM-S`N-S`P)UT@/2`G4V%N
M=&EA9V\G.PHD8V]O<F1I;F%T97-;)T1O;6EN:6-A;B!297!U8FQI8R==6R<Q
M.2XW-3`Z+3<P+C4U,"==(#T@)U!U97)T;R!0;&%T82!);G1E<FYA=&EO;F%L
M)SL*)&-O;W)D:6YA=&5S6R=%87-T(%1I;6]R)UU;)RTX+C4P,#HQ,C8N-#`P
M)UT@/2`G0F%U8V%U)SL*)&-O;W)D:6YA=&5S6R=%87-T(%1I;6]R)UU;)RTX
M+C4V-SHQ,C4N-38W)UT@/2`G1&EL;&D@+R!$:6QL:2!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R=%87-T(%1I;6]R)UU;)RTY+C(P,#HQ,C0N,S8W)UT@/2`G
M3V4M0W5S<V4@+R!/92!#=7-S92<["B1C;V]R9&EN871E<ULG16-U861O<B==
M6R<M,"XQ-3`Z+3<X+C0X,R==(#T@)U%U:71O("\@36%R:7-C86P@4W5C<F4G
M.PHD8V]O<F1I;F%T97-;)T5C=6%D;W(G75LG,"XS-3`Z+3<X+C$S,R==(#T@
M)TEB87)R82`O($%T86AU86QP82<["B1C;V]R9&EN871E<ULG16-U861O<B==
M6R<M,"XU.#,Z+3@P+C0P,"==(#T@)T)A:&EA($1E($-A<F%Q=65Z)SL*)&-O
M;W)D:6YA=&5S6R=%8W5A9&]R)UU;)RTP+C<X,SHM-S4N-3$W)UT@/2`G5&EP
M=71I;FDG.PHD8V]O<F1I;F%T97-;)T5C=6%D;W(G75LG,"XX,3<Z+3<W+C<P
M,"==(#T@)U1U;&-A;B`O($5L(%)O<V%L)SL*)&-O;W)D:6YA=&5S6R=%8W5A
M9&]R)UU;)RTP+CDP,#HM.#DN-C`P)UT@/2`G4V%N($-R:7-T;V)A;"!'86QA
M<&%G;W,G.PHD8V]O<F1I;F%T97-;)T5C=6%D;W(G75LG+3`N.3$W.BTW."XV
M,3<G72`]("=,871A8W5N9V$G.PHD8V]O<F1I;F%T97-;)T5C=6%D;W(G75LG
M+3`N.34P.BTX,"XV.#,G72`]("=-86YT82<["B1C;V]R9&EN871E<ULG16-U
M861O<B==6R<P+CDV-SHM-SDN-C,S)UT@/2`G17-M97)A;&1A<RU486-H:6YA
M)SL*)&-O;W)D:6YA=&5S6R=%8W5A9&]R)UU;)RTQ+C(P,#HM-S@N-38W)UT@
M/2`G06UB871O("\@0VAA8VAO86XG.PHD8V]O<F1I;F%T97-;)T5C=6%D;W(G
M75LG+3$N-3`P.BTW."XP-3`G72`]("=087-T87IA("\@4FEO($%M87IO;F%S
M)SL*)&-O;W)D:6YA=&5S6R=%8W5A9&]R)UU;)RTR+C$U,#HM-SDN.#@S)UT@
M/2`G1W5A>6%Q=6EL("\@4VEM;VX@0F]L:79A<B<["B1C;V]R9&EN871E<ULG
M16-U861O<B==6R<M,BXR,#`Z+3@P+CDX,R==(#T@)U-A;&EN87,@+R!'96YE
M<F%L(%5L<&EA;F\@4&%E>B<["B1C;V]R9&EN871E<ULG16-U861O<B==6R<M
M,BXX.#,Z+3<X+CDX,R==(#T@)T-U96YC82`O($UA<FES8V%L($QA;6%R)SL*
M)&-O;W)D:6YA=&5S6R=%8W5A9&]R)UU;)RTS+C(U,#HM-SDN.38W)UT@/2`G
M36%C:&%L82`O($=E;F5R86P@32X@4V5R<F%N;R<["B1C;V]R9&EN871E<ULG
M16-U861O<B==6R<M-"XP,#`Z+3<Y+C,V-R==(#T@)T-A=&%M87EO("\@0V%M
M:6QO(%!O;F-E($5N<FEQ=65Z)SL*)&-O;W)D:6YA=&5S6R=%8W5A9&]R)UU;
M)RTT+C,V-SHM-SDN.3,S)UT@/2`G36%C87)A("\@2BX@32X@5F5L87-C;R!)
M+B<["B1C;V]R9&EN871E<ULG16=Y<'0G75LG,C,N.38W.C,R+C<X,R==(#T@
M)T%S<W=A;B<["B1C;V]R9&EN871E<ULG16=Y<'0G75LG,C4N-C8W.C,R+C<P
M,"==(#T@)TQU>&]R)SL*)&-O;W)D:6YA=&5S6R=%9WEP="==6R<R-RXP-3`Z
M,S$N,#$W)UT@/2`G07-Y=70G.PHD8V]O<F1I;F%T97-;)T5G>7!T)UU;)S(W
M+C$U,#HS,RXW,3<G72`]("=(=7)G=6%D82<["B1C;V]R9&EN871E<ULG16=Y
M<'0G75LG,C@N,C,S.C,R+C8Q-R==(#T@)T5L(%1O<B<["B1C;V]R9&EN871E
M<ULG16=Y<'0G75LG,S`N,3,S.C,Q+C0P,"==(#T@)T-A:7)O($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)T5G>7!T)UU;)S,Q+C`X,SHS,RXX,3<G72`]("=%
M;"!!<FES:"<["B1C;V]R9&EN871E<ULG16=Y<'0G75LG,S$N,C`P.C(Y+CDU
M,"==(#T@)T%L97AA;F1R:6$@+R!.;W5Z:&$G.PHD8V]O<F1I;F%T97-;)T5G
M>7!T)UU;)S,Q+C(V-SHS,BXS,#`G72`]("=0;W)T(%-A:60G.PHD8V]O<F1I
M;F%T97-;)T5G>7!T)UU;)S,Q+C,S,SHR-RXR,3<G72`]("=-97)S82!-871R
M=6@G.PHD8V]O<F1I;F%T97-;)T5L(%-A;'9A9&]R)UU;)S$S+C0S,SHM.#DN
M,#4P)UT@/2`G16P@4V%L=F%D;W(@26YT;"X@06ER<&]R="`O($-O;6%L87!A
M)SL*)&-O;W)D:6YA=&5S6R=%;"!386QV861O<B==6R<Q,RXT-3`Z+3@X+C$Q
M-R==(#T@)U-A;B!-:6=U96P@+R!%;"!087!A;&]N)SL*)&-O;W)D:6YA=&5S
M6R=%;"!386QV861O<B==6R<Q,RXU-C<Z+3@Y+C@S,R==(#T@)T%C86IU=&QA
M)SL*)&-O;W)D:6YA=&5S6R=%;"!386QV861O<B==6R<Q,RXW,#`Z+3@Y+C$Q
M-R==(#T@)U-A;B!386QV861O<B`O($EL;W!A;F=O)SL*)&-O;W)D:6YA=&5S
M6R=%;"!386QV861O<B==6R<Q,RXY.#,Z+3@Y+C4V-R==(#T@)U-A;G1A($%N
M82`O($5L(%!A;&UA<B<["B1C;V]R9&EN871E<ULG17%U871O<FEA;"!'=6EN
M96$G75LG,RXW-3`Z."XW-C<G72`]("=-86QA8F\O1F5R;F%N9&\@4&]O)SL*
M)&-O;W)D:6YA=&5S6R=%<W1O;FEA)UU;)S4X+CDX,SHR,BXX,3<G72`]("=+
M87)D;&$G.PHD8V]O<F1I;F%T97-;)T5S=&]N:6$G75LG-3DN,S@S.C(T+C4X
M,R==(#T@)U1A;&QI;FXG.PHD8V]O<F1I;F%T97-;)T5T:&EO<&EA)UU;)S$P
M+C,U,#HS-RXW,3<G72`]("=$96)R96UA<F-O<R<["B1C;V]R9&EN871E<ULG
M171H:6]P:6$G75LG,3$N,#@S.C,Y+C<Q-R==(#T@)T-O;6)O;&-H82<["B1C
M;V]R9&EN871E<ULG171H:6]P:6$G75LG,3$N-C`P.C,W+C0P,"==(#T@)T)A
M:&%R($1A<B<["B1C;V]R9&EN871E<ULG171H:6]P:6$G75LG,3(N-3,S.C,W
M+C0S,R==(#T@)T=O;F1A<B<["B1C;V]R9&EN871E<ULG171H:6]P:6$G75LG
M,3,N,#8W.C0R+C<Q-R==(#T@)T%S<V%B)SL*)&-O;W)D:6YA=&5S6R=%=&AI
M;W!I82==6R<Q,RXU,#`Z,SDN-#@S)UT@/2`G36%K86QE)SL*)&-O;W)D:6YA
M=&5S6R=%=&AI;W!I82==6R<Q-2XR.#,Z,S@N.3$W)UT@/2`G07-M87)A)SL*
M)&-O;W)D:6YA=&5S6R=%=&AI;W!I82==6R<Q-2XV,3<Z,SDN-#4P)UT@/2`G
M36%S<V%W82<["B1C;V]R9&EN871E<ULG171H:6]P:6$G75LG-2XQ,#`Z-#0N
M-3@S)UT@/2`G1V]D92<["B1C;V]R9&EN871E<ULG171H:6]P:6$G75LG-2XR
M.#,Z,SDN-S4P)UT@/2`G3F5G:&5L;&DG.PHD8V]O<F1I;F%T97-;)T5T:&EO
M<&EA)UU;)S8N,#8W.C,W+C8V-R==(#T@)T%R8F$@36EN8V@G.PHD8V]O<F1I
M;F%T97-;)T5T:&EO<&EA)UU;)S<N,#8W.C,X+C4P,"==(#T@)T%W87-S82<[
M"B1C;V]R9&EN871E<ULG171H:6]P:6$G75LG-RXV-C<Z,S8N.#,S)UT@/2`G
M2FEM;6$G.PHD8V]O<F1I;F%T97-;)T5T:&EO<&EA)UU;)S@N,38W.C,U+C4U
M,"==(#T@)T=O<F4G.PHD8V]O<F1I;F%T97-;)T5T:&EO<&EA)UU;)S@N-S,S
M.C,Y+C`P,"==(#T@)TAA<F%R($UE9&$G.PHD8V]O<F1I;F%T97-;)T5T:&EO
M<&EA)UU;)S@N.3@S.C,X+C@P,"==(#T@)T%D9&ES($%B86)A)SL*)&-O;W)D
M:6YA=&5S6R=%=&AI;W!I82==6R<Y+C,S,SHT,BXW,3<G72`]("=*:6=G:6=A
M)SL*)&-O;W)D:6YA=&5S6R=%=&AI;W!I82==6R<Y+C8P,#HT,2XX-C<G72`]
M("=$:7)E($1A=V$G.PHD8V]O<F1I;F%T97-;)T9A;&ML86YD($ES;&%N9',@
M*$UA;'9I;F%S*2==6R<M-3$N-C@S.BTU-RXW-C<G72`]("=3=&%N;&5Y($%I
M<G!O<G0G.PHD8V]O<F1I;F%T97-;)T9I:FDG75LG+3$R+C4P,#HQ-S<N,#4P
M)UT@/2`G4F]T=6UA)SL*)&-O;W)D:6YA=&5S6R=&:6II)UU;)RTQ-RXW-3`Z
M,3<W+C0U,"==(#T@)TYA;F1I)SL*)&-O;W)D:6YA=&5S6R=&:6II)UU;)RTQ
M."XP-3`Z,3<X+C4V-R==(#T@)TYA=7-O<FDG.PHD8V]O<F1I;F%T97-;)T9I
M:FDG75LG+3$X+C(S,SHM,3<X+C@P,"==(#T@)TQA:V5M8F$G.PHD8V]O<F1I
M;F%T97-;)T9I;FQA;F0G75LG-C`N,3$W.C$Y+CDP,"==(#T@)TUA<FEE:&%M
M;B`O($%L86YD($ES;&%N9"<["B1C;V]R9&EN871E<ULG1FEN;&%N9"==6R<V
M,"XR-3`Z,C4N,#4P)UT@/2`G2&5L<VEN:VDM36%L;6DG.PHD8V]O<F1I;F%T
M97-;)T9I;FQA;F0G75LG-C`N,S$W.C(T+CDV-R==(#T@)TAE;'-I;FMI+59A
M;G1A82<["B1C;V]R9&EN871E<ULG1FEN;&%N9"==6R<V,"XU,3<Z,C(N,C8W
M)UT@/2`G5'5R:W4G.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C`N.3`P
M.C(V+CDS,R==(#T@)U5T=&DG.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG
M-C$N,#0V.C(X+C$T.2==(#T@)TQA<'!E96YR86YT82<["B1C;V]R9&EN871E
M<ULG1FEN;&%N9"==6R<V,2XT,3<Z,C,N-3@S)UT@/2`G5&%M<&5R92`O(%!I
M<FMK86QA)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8Q+C0V-SHR,2XX
M,#`G72`]("=0;W)I)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8Q+C<S
M,SHR-RXS,#`G72`]("=-:6MK96QI)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD
M)UU;)S8Q+C@U,#HR-"XX,#`G72`]("=(86QL:2<["B1C;V]R9&EN871E<ULG
M1FEN;&%N9"==6R<V,2XY-3`Z,C@N.34P)UT@/2`G4V%V;VYL:6YN82<["B1C
M;V]R9&EN871E<ULG1FEN;&%N9"==6R<V,BXT,#`Z,C4N-C@S)UT@/2`G2GEV
M87-K>6QA)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8R+C4S,SHR-"XR
M,3<G72`]("=!:'1A<FDG.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C(N
M-C8W.C(Y+C8S,R==(#T@)TIO96YS=74G.PHD8V]O<F1I;F%T97-;)T9I;FQA
M;F0G75LG-C,N,#$W.C(W+C@P,"==(#T@)TMU;W!I;R<["B1C;V]R9&EN871E
M<ULG1FEN;&%N9"==6R<V,RXP-3`Z,C$N-S8W)UT@/2`G5F%A<V$G.PHD8V]O
M<F1I;F%T97-;)T9I;FQA;F0G75LG-C,N,#@S.C(U+C@V-R==(#T@)U9I:71A
M<V%A<FDG.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C,N,3`P.C(S+C`S
M,R==(#T@)TMA=6AA=F$G.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C,N
M-S$W.C(S+C$U,"==(#T@)TMR=75N=7!Y>2<["B1C;V]R9&EN871E<ULG1FEN
M;&%N9"==6R<V-"XR.#,Z,C<N-C@S)UT@/2`G2V%J86%N:2<["B1C;V]R9&EN
M871E<ULG1FEN;&%N9"==6R<V-"XY,#`Z,CDN,#$W)UT@/2`G4W5O;75S<V%L
M;6DG.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C0N.3,S.C(U+C,V-R==
M(#T@)T]U;'4G.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C4N,#,S.C(T
M+C@P,"==(#T@)TAA:6QU;W1O)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;
M)S8U+C,V-SHR-RXP,3<G72`]("=0=61A<VIA<G9I)SL*)&-O;W)D:6YA=&5S
M6R=&:6YL86YD)UU;)S8U+C<X,SHR-"XU.#,G72`]("=+96UI)SL*)&-O;W)D
M:6YA=&5S6R=&:6YL86YD)UU;)S8U+CDV-SHR.2XQ.#,G72`]("=+=75S86UO
M)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8V+C4V-SHR-2XX,S,G72`]
M("=2;W9A;FEE;6DG.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C8N.#`P
M.C(T+C`P,"==(#T@)U!E;&QO)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;
M)S8W+C,V-SHR-BXV-3`G72`]("=3;V1A;FMY;&$G.PHD8V]O<F1I;F%T97-;
M)T9I;FQA;F0G75LG-C@N-C$W.C(W+C0Q-R==(#T@)TEV86QO)SL*)&-O;W)D
M:6YA=&5S6R=&<F%N8V4G75LG+3$S+C(S,SHM,3<V+C$V-R==(#T@)TAI:&EF
M;R!);&4@5V%L;&ES)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG+3$T+C,Q
M-SHM,3<X+C$Q-R==(#T@)TUA;W!O;W!O($EL92!&=71U;F$G.PHD8V]O<F1I
M;F%T97-;)T9R86YC92==6R<T,2XU,#`Z.2XQ,#`G72`]("=&:6=A<FDG.PHD
M8V]O<F1I;F%T97-;)T9R86YC92==6R<T,2XY,3<Z."XX,#`G72`]("=!:F%C
M8VEO)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#$N.3$W.CDN-#`P)UT@
M/2`G4V]L96YZ87)A)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#(N-3,S
M.C@N.#`P)UT@/2`G0V%L=FDG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T
M,BXU-3`Z.2XT.#,G72`]("="87-T:6$G.PHD8V]O<F1I;F%T97-;)T9R86YC
M92==6R<T,BXW,S,Z,BXX-C<G72`]("=097)P:6=N86XG.PHD8V]O<F1I;F%T
M97-;)T9R86YC92==6R<T,RXP,#`Z,2XQ,#`G72`]("=3="U':7)O;G,G.PHD
M8V]O<F1I;F%T97-;)T9R86YC92==6R<T,RXQ,#`Z-BXQ-3`G72`]("=(>65R
M97,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T,RXQ.#,Z,"XP,#`G72`]
M("=487)B97,@+R!/<W-U;B<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0S
M+C(Q-SHR+C,Q-R==(#T@)T-A<F-A<W-O;FYE)SL*)&-O;W)D:6YA=&5S6R=&
M<F%N8V4G75LG-#,N,S@S.BTP+C0Q-R==(#T@)U!A=2<["B1C;V]R9&EN871E
M<ULG1G)A;F-E)UU;)S0S+C,X,SHV+C,X,R==(#T@)TQE($QU8R<["B1C;V]R
M9&EN871E<ULG1G)A;F-E)UU;)S0S+C0Q-SHV+C<U,"==(#T@)U-T+5)A<&AA
M96PG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T,RXT-3`Z-2XR,S,G72`]
M("=-87)S96EL;&4@+R!-87)I9VYA;F4G.PHD8V]O<F1I;F%T97-;)T9R86YC
M92==6R<T,RXT-C<Z+3$N-3,S)UT@/2`G0FEA<G)I='HG.PHD8V]O<F1I;F%T
M97-;)T9R86YC92==6R<T,RXU,#`Z-2XS-C<G72`]("=!:7@@3&5S($UI;&QE
M<R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0S+C4Q-SHT+CDS,R==(#T@
M)TES=')E<R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0S+C4S,SHQ+C,V
M-R==(#T@)U1O=6QO=7-E("\@1G)A;F-A>F%L)SL*)&-O;W)D:6YA=&5S6R=&
M<F%N8V4G75LG-#,N-34P.C8N.34P)UT@/2`G0V%N;F5S)SL*)&-O;W)D:6YA
M=&5S6R=&<F%N8V4G75LG-#,N-3@S.C,N.38W)UT@/2`G36]N='!E;&QI97(G
M.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T,RXV,#`Z-2XQ,#`G72`]("=3
M86QO;B<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0S+C8S,SHQ+C,V-R==
M(#T@)U1O=6QO=7-E("\@0FQA9VYA8R<["B1C;V]R9&EN871E<ULG1G)A;F-E
M)UU;)S0S+C8U,#HW+C(P,"==(#T@)TYI8V4G.PHD8V]O<F1I;F%T97-;)T9R
M86YC92==6R<T,RXV.#,Z,"XV,#`G72`]("=!=6-H)SL*)&-O;W)D:6YA=&5S
M6R=&<F%N8V4G75LG-#,N-C@S.BTQ+C`V-R==(#T@)T1A>"<["B1C;V]R9&EN
M871E<ULG1G)A;F-E)UU;)S0S+C<U,#HT+C0Q-R==(#T@)TYI;65S("\@1V%R
M;VYS)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#,N.#8W.C0N-#`P)UT@
M/2`G3FEM97,@+R!#;W5R8F5S<V%C)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G
M75LG-#,N.3$W.BTP+C4P,"==(#T@)TUO;G0M1&4M36%R<V%N)SL*)&-O;W)D
M:6YA=&5S6R=&<F%N8V4G75LG-#,N.3$W.C(N,3$W)UT@/2`G06QB:2<["B1C
M;V]R9&EN871E<ULG1G)A;F-E)UU;)S0T+C`V-SHV+C`P,"==(#T@)U-T+4%U
M8F%N+5-U<BU$=7)A;F-E)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#0N
M,3,S.C0N.#,S)UT@/2`G3W)A;F=E)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G
M75LG-#0N,3@S.C`N-C`P)UT@/2`G06=E;B<["B1C;V]R9&EN871E<ULG1G)A
M;F-E)UU;)S0T+C$X,SHR+C4Q-R==(#T@)T-A<W-A9VYE<RU"96=O;FAE<R<[
M"B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0T+C0P,#HR+C0X,R==(#T@)U)O
M9&5Z)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#0N-#,S.BTQ+C(U,"==
M(#T@)T)I<V-A<F]S<V4G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-"XU
M,S,Z+3$N,3,S)UT@/2`G0V%Z875X)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G
M75LG-#0N-3@S.C0N-S,S)UT@/2`G36]N=&5L:6UA<B<["B1C;V]R9&EN871E
M<ULG1G)A;F-E)UU;)S0T+C@Q-SHP+C4Q-R==(#T@)T)E<F=E<F%C)SL*)&-O
M;W)D:6YA=&5S6R=&<F%N8V4G75LG-#0N.#,S.BTP+C<P,"==(#T@)T)O<F1E
M875X("\@365R:6=N86,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-"XY
M,#`Z,BXT,3<G72`]("=!=7)I;&QA8R<["B1C;V]R9&EN871E<ULG1G)A;F-E
M)UU;)S0U+C`X,SHS+C<V-R==(#T@)TQE(%!U>2<["B1C;V]R9&EN871E<ULG
M1G)A;F-E)UU;)S0U+C$U,#HQ+C0V-R==(#T@)T)R:79E)SL*)&-O;W)D:6YA
M=&5S6R=&<F%N8V4G75LG-#4N,C`P.C`N.#$W)UT@/2`G4&5R:6=U975X)SL*
M)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#4N,S8W.C4N,S,S)UT@/2`G1W)E
M;F]B;&4@+R!3="X@1V5O:7)S)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG
M-#4N-3,S.C0N,S`P)UT@/2`G4W0M171I96YN92!";W5T:&5O;B<["B1C;V]R
M9&EN871E<ULG1G)A;F-E)UU;)S0U+C8U,#HU+C@X,R==(#T@)T-H86UB97)Y
M("\@06EX+4QE<RU"86EN<R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0U
M+C8V-SHM,"XS,3<G72`]("=#;V=N86,G.PHD8V]O<F1I;F%T97-;)T9R86YC
M92==6R<T-2XW,3<Z-"XY-3`G72`]("=,>6]N("\@0G)O;B<["B1C;V]R9&EN
M871E<ULG1G)A;F-E)UU;)S0U+C<S,SHU+C`X,R==(#T@)TQY;VX@+R!3871O
M;&%S)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#4N-S@S.C,N,38W)UT@
M/2`G0VQE<FUO;G0M1F5R<F%N9"<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;
M)S0U+C@V-SHQ+C$X,R==(#T@)TQI;6]G97,G.PHD8V]O<F1I;F%T97-;)T9R
M86YC92==6R<T-2XY.#,Z-2XS,S,G72`]("=!;6)E<FEE=2<["B1C;V]R9&EN
M871E<ULG1G)A;F-E)UU;)S0V+C$U,#HM,2XQ-3`G72`]("=,82!2;V-H96QL
M92<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0V+C$V-SHS+C0P,"==(#T@
M)U9I8VAY)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#8N,S`P.C0N.#`P
M)UT@/2`G36%C;VXG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-BXS,3<Z
M+3`N-#`P)UT@/2`G3FEO<G0G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T
M-BXT,3<Z-"XP,3<G72`]("=386EN="U986XG.PHD8V]O<F1I;F%T97-;)T9R
M86YC92==6R<T-BXU.#,Z,"XS,3<G72`]("=0;VET:65R<R<["B1C;V]R9&EN
M871E<ULG1G)A;F-E)UU;)S0V+C<P,#HM,2XS.#,G72`]("=,82!2;V-H92U3
M=7(M66]N)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#8N.#4P.C$N-S$W
M)UT@/2`G0VAA=&5A=7)O=7@G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T
M-RXP,#`Z,RXQ,#`G72`]("=.979E<G,G.PHD8V]O<F1I;F%T97-;)T9R86YC
M92==6R<T-RXP-C<Z,BXS-C<G72`]("=";W5R9V5S)SL*)&-O;W)D:6YA=&5S
M6R=&<F%N8V4G75LG-#<N,38W.BTQ+C8P,"==(#T@)TYA;G1E<R<["B1C;V]R
M9&EN871E<ULG1G)A;F-E)UU;)S0W+C(U,#HU+CDX,R==(#T@)T)E<V%N8V]N
M)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#<N,C8W.C4N,#@S)UT@/2`G
M1&EJ;VXG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-RXS,3<Z,2XV.#,G
M72`]("=2;VUO<F%N=&EN)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#<N
M,S$W.BTR+C$V-R==(#T@)U-T+4YA>F%I<F4G.PHD8V]O<F1I;F%T97-;)T9R
M86YC92==6R<T-RXT-3`Z,"XW,3<G72`]("=4;W5R<R<["B1C;V]R9&EN871E
M<ULG1G)A;F-E)UU;)S0W+C4P,#HM,"XU-C<G72`]("=!;F=E<G,G.PHD8V]O
M<F1I;F%T97-;)T9R86YC92==6R<T-RXV,#`Z-RXU,3<G72`]("="86QE+4UU
M;&AO=7-E)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#<N-C,S.C8N.#8W
M)UT@/2`G0F5L9F]R="<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0W+C<V
M-SHM,RXT-3`G72`]("=,86YN($)I:&]U92<["B1C;V]R9&EN871E<ULG1G)A
M;F-E)UU;)S0W+C<X,SHV+C,U,"==(#T@)TQU>&5U:6PG.PHD8V]O<F1I;F%T
M97-;)T9R86YC92==6R<T-RXX,#`Z,RXU-3`G72`]("=!=7AE<G)E)SL*)&-O
M;W)D:6YA=&5S6R=&<F%N8V4G75LG-#<N.#4P.C0N-34P)UT@/2`G0VAA=&EL
M;&]N+5-U<BU396EN92<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0W+CDQ
M-SHW+C0P,"==(#T@)T-O;&UA<B<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;
M)S0W+CDS,SHP+C(P,"==(#T@)TQE($UA;G,G.PHD8V]O<F1I;F%T97-;)T9R
M86YC92==6R<T-RXY-C<Z+30N,38W)UT@/2`G475I;7!E<B<["B1C;V]R9&EN
M871E<ULG1G)A;F-E)UU;)S0W+CDX,SHQ+C<U,"==(#T@)T]R;&5A;G,G.PHD
M8V]O<F1I;F%T97-;)T9R86YC92==6R<T."XP-3`Z,2XS.#,G72`]("=#:&%T
M96%U9'5N)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#@N,#8W.BTQ+C<S
M,R==(#T@)U)E;FYE<R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0X+C(X
M,SHM-"XT,S,G72`]("=,86YV96]C(%!O=6QM:6,G.PHD8V]O<F1I;F%T97-;
M)T9R86YC92==6R<T."XS,S,Z-"XP,3<G72`]("=4<F]Y97,G.PHD8V]O<F1I
M;F%T97-;)T9R86YC92==6R<T."XT-3`Z,"XQ,3<G72`]("=!;&5N8V]N)SL*
M)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#@N-#4P.BTT+C0Q-R==(#T@)T)R
M97-T)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#@N-#8W.C$N-3$W)UT@
M/2`G0VAA<G1R97,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T."XU,3<Z
M+30N,34P)UT@/2`G3&%N9&EV:7-I874G.PHD8V]O<F1I;F%T97-;)T9R86YC
M92==6R<T."XU,S,Z+3(N.#4P)UT@/2`G4V%I;G0M0G)I975C)SL*)&-O;W)D
M:6YA=&5S6R=&<F%N8V4G75LG-#@N-34P.C<N-C,S)UT@/2`G4W1R87-B;W5R
M9R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0X+C4X,SHM,BXP-C<G72`]
M("=$:6YA<F0G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T."XU.#,Z-2XY
M-C<G72`]("=.86YC>2`O($]C:&5Y)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G
M75LG-#@N-C$W.C(N-C@S)UT@/2`G365L=6XG.PHD8V]O<F1I;F%T97-;)T9R
M86YC92==6R<T."XV,S,Z-"XY,#`G72`]("=3="U$:7II97(G.PHD8V]O<F1I
M;F%T97-;)T9R86YC92==6R<T."XV.#,Z-BXR,3<G72`]("=.86YC>2`O($5S
M<V5Y)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#@N-S,S.C(N-#`P)UT@
M/2`G4&%R:7,M3W)L>2<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0X+C<V
M-SHQ+C$P,"==(#T@)U1O=7-S=7,@3&4@3F]B;&4G.PHD8V]O<F1I;F%T97-;
M)T9R86YC92==6R<T."XW-C<Z,BXR,#`G72`]("=6:6QL86-O=6)L87DG.PHD
M8V]O<F1I;F%T97-;)T9R86YC92==6R<T."XW.#,Z-2XT.#,G72`]("=4;W5L
M("\@4F]S:65R97,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T."XY-C<Z
M,BXT-3`G72`]("=087)I<R`O($QE($)O=7)G970G.PHD8V]O<F1I;F%T97-;
M)T9R86YC92==6R<T."XY.#,Z-BXR-3`G72`]("=-971Z+4YA;F-Y+4QO<G)A
M:6YE)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#DN,#$W.C$N,C$W)UT@
M/2`G179R975X)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#DN,#$W.C(N
M-3,S)UT@/2`G4&%R:7,M065R;W!O<G0@0VAA<FQE<R!$92!'875L;&4G.PHD
M8V]O<F1I;F%T97-;)T9R86YC92==6R<T.2XP.#,Z-BXQ,S,G72`]("=-971Z
M("\@1G)E<V-A='DG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T.2XQ.#,Z
M+3`N-#4P)UT@/2`G0V%E;B<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0Y
M+C(U,#HR+C4Q-R==(#T@)T-R96EL($9A9F(G.PHD8V]O<F1I;F%T97-;)T9R
M86YC92==6R<T.2XS,#`Z-"XP,S,G72`]("=296EM<R<["B1C;V]R9&EN871E
M<ULG1G)A;F-E)UU;)S0Y+C,X,SHQ+C$X,R==(#T@)U)O=65N)SL*)&-O;W)D
M:6YA=&5S6R=&<F%N8V4G75LG-#DN-#8W.C(N,3$W)UT@/2`G0F5A=79A:7,G
M.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T.2XU,3<Z,"XP-C<G72`]("=,
M82!(979E)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#DN-C4P.BTQ+C0V
M-R==(#T@)T-H97)B;W5R9R`O($UA=7!E<G1U<R<["B1C;V]R9&EN871E<ULG
M1G)A;F-E)UU;)S0Y+C<X,SHT+C8S,R==(#T@)T-H87)L979I;&QE)SL*)&-O
M;W)D:6YA=&5S6R=&<F%N8V4G75LG-#DN.#$W.C,N,C`P)UT@/2`G4V%I;G0M
M475E;G1I;B<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0Y+C@S,SHP+C8U
M,"==(#T@)U9I='1E9FQE=7(@+R!3="X@5F%L92<["B1C;V]R9&EN871E<ULG
M1G)A;F-E)UU;)S4P+C$S,SHQ+C@S,R==(#T@)T%B8F5V:6QL92<["B1C;V]R
M9&EN871E<ULG1G)A;F-E)UU;)S4P+C(Q-SHS+C$U,"==(#T@)T-A;6)R86DG
M.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<U,"XU,3<Z,2XV,3<G72`]("=,
M92!4;W5Q=65T)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-3`N-38W.C,N
M,3`P)UT@/2`G3&EL;&4G.PHD8V]O<F1I;F%T97-;)T9R96YC:"!'=6EA;F$G
M75LG-"XX,S,Z+34R+C,V-R==(#T@)T-A>65N;F4@+R!2;V-H86UB96%U)SL*
M)&-O;W)D:6YA=&5S6R=&<F5N8V@@1W5I86YA)UU;)S4N-3`P.BTU-"XP,S,G
M72`]("=386EN="U,875R96YT+41U+4UA<F]N:2<["B1C;V]R9&EN871E<ULG
M1G)E;F-H(%!O;'EN97-I82==6R<M,30N.38W.BTQ-#<N-C8W)UT@/2`G4F%N
M9VER;V$@+R!4=6%M;W1O($ES;&%N9"<["B1C;V]R9&EN871E<ULG1G)E;F-H
M(%!O;'EN97-I82==6R<M,38N-#4P.BTQ-3$N-S4P)UT@/2`G0F]R82U";W)A
M)SL*)&-O;W)D:6YA=&5S6R=&<F5N8V@@4&]L>6YE<VEA)UU;)RTQ-RXU-3`Z
M+3$T.2XV,3<G72`]("=486AI=&DM1F%A82<["B1C;V]R9&EN871E<ULG1G)E
M;F-H(%!O;'EN97-I82==6R<M,3@N,#8W.BTQ-#`N.34P)UT@/2`G2&%O)SL*
M)&-O;W)D:6YA=&5S6R=&<F5N8V@@4&]L>6YE<VEA)UU;)RTR,2XX,3<Z+3$S
M."XX,#`G72`]("=-=7)U<F]A)SL*)&-O;W)D:6YA=&5S6R=&<F5N8V@@4&]L
M>6YE<VEA)UU;)RTR,RXS-3`Z+3$T.2XT.#,G72`]("=4=6)U86DG.PHD8V]O
M<F1I;F%T97-;)T=A8F]N)UU;)S`N-#4P.CDN-#$W)UT@/2`G3&EB<F5V:6QL
M92<["B1C;V]R9&EN871E<ULG1V%B;VXG75LG,"XU-C<Z,3(N.#8W)UT@/2`G
M36%K;VMO=2<["B1C;V]R9&EN871E<ULG1V%B;VXG75LG+3`N-S`P.C@N-S4P
M)UT@/2`G4&]R="U'96YT:6PG.PHD8V]O<F1I;F%T97-;)T=A8F]N)UU;)RTP
M+C<Q-SHQ,"XR,S,G72`]("=,86UB87)E;F4G.PHD8V]O<F1I;F%T97-;)T=A
M8F]N)UU;)S`N-S@S.C$Q+C4S,R==(#T@)TUI='II8R<["B1C;V]R9&EN871E
M<ULG1V%B;VXG75LG+3`N.#,S.C$R+C<Q-R==(#T@)TQA<W1O=7)S=FEL;&4G
M.PHD8V]O<F1I;F%T97-;)T=A8F]N)UU;)S$N,#`P.CDN-C`P)UT@/2`G0V]C
M;V)E86-H)SL*)&-O;W)D:6YA=&5S6R='86)O;B==6R<Q+C`Q-SHQ,RXY,S,G
M72`]("=-96MA;6)O)SL*)&-O;W)D:6YA=&5S6R='86)O;B==6R<M,2XU,S,Z
M,3,N,C8W)UT@/2`G36]A;F1A)SL*)&-O;W)D:6YA=&5S6R='86)O;B==6R<M
M,2XX-C<Z,3$N,#$W)UT@/2`G36]U:6QA)SL*)&-O;W)D:6YA=&5S6R='86)O
M;B==6R<R+C`X,SHQ,2XT.#,G72`]("=":71A;2<["B1C;V]R9&EN871E<ULG
M1V%B;VXG75LG+3(N.#4P.C$Q+C`Q-R==(#T@)U1C:&EB86YG82<["B1C;V]R
M9&EN871E<ULG1V%B;VXG75LG+3,N-#$W.C$P+C8U,"==(#T@)TUA>75M8F$G
M.PHD8V]O<F1I;F%T97-;)T=A;6)I82==6R<Q,RXS-3`Z+3$V+C@P,"==(#T@
M)T)A;FIU;"`O(%EU;F1U;2<["B1C;V]R9&EN871E<ULG1V5O<F=I82==6R<T
M,2XV.#,Z-#0N.34P)UT@/2`G5&)I;&ES:2<["B1C;V]R9&EN871E<ULG1V5O
M<F=I82==6R<T,2XY,S,Z-#0N-3@S)UT@/2`G375H<F%N:2<["B1C;V]R9&EN
M871E<ULG1V5R;6%N>2==6R<T-RXV-C<Z.2XU,3<G72`]("=&<FEE9')I8VAS
M:&%F96XG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#<N-C@S.CDN,3@S
M)UT@/2`G2V]N<W1A;GHG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#<N
M.#,S.C$P+C@V-R==(#T@)T%L=&5N<W1A9'0G.PHD8V]O<F1I;F%T97-;)T=E
M<FUA;GDG75LG-#<N.38W.C@N-3$W)UT@/2`G1&]N875E<V-H:6YG96X@+R!6
M:6QL:6YG96XG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#<N.3@S.C$P
M+C(S,R==(#T@)TUE;6UI;F=E;B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==
M6R<T."XP-C<Z,3`N.3`P)UT@/2`G3&%N9'-B97)G)SL*)&-O;W)D:6YA=&5S
M6R='97)M86YY)UU;)S0X+C$S,SHQ,2XW,#`G72`]("=-=6YI8V@@+R!2:65M
M)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S0X+C$X,SHQ,"XX-C<G72`]
M("=,96-H9F5L9"<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T."XQ.#,Z
M.2XP,#`G72`]("=-97-S<W1E='1E;B<["B1C;V]R9&EN871E<ULG1V5R;6%N
M>2==6R<T."XR,#`Z,3$N,C8W)UT@/2`G1G5E<G-T96YF96QD8G)U8VLG.PHD
M8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#@N,C$W.CDN.3$W)UT@/2`G3&%U
M<&AE:6TG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#@N,S$W.C$Q+CDU
M,"==(#T@)T5R9&EN9R<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T."XT
M,S,Z,3`N.3,S)UT@/2`G075G<V)U<F<G.PHD8V]O<F1I;F%T97-;)T=E<FUA
M;GDG75LG-#@N-C@S.CDN,C$W)UT@/2`G4W1U='1G87)T+45C:'1E<F1I;F=E
M;B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T."XW,3<Z,3$N,C$W)UT@
M/2`G3F5U8G5R9R`O($1O;F%U)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;
M)S0X+C<Q-SHQ,2XU,S,G72`]("=);F=O;'-T861T)SL*)&-O;W)D:6YA=&5S
M6R='97)M86YY)UU;)S0Y+C(Q-SHQ,2XQ,#`G72`]("=2;W1H)SL*)&-O;W)D
M:6YA=&5S6R='97)M86YY)UU;)S0Y+C(Q-SHQ,2XX,S,G72`]("=(;VAE;F9E
M;',G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#DN,C$W.C<N,3$W)UT@
M/2`G4V%A<F)R=65C:V5N("\@16YS:&5I;2<["B1C;V]R9&EN871E<ULG1V5R
M;6%N>2==6R<T.2XS,3<Z,3`N-C,S)UT@/2`G06YS8F%C:"`O($MA='1E<F)A
M8V@G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#DN-#`P.C@N-C4P)UT@
M/2`G2&5I9&5L8F5R9R<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T.2XT
M,#`Z.2XY-C<G72`]("=.:65D97)S=&5T=&5N)SL*)&-O;W)D:6YA=&5S6R='
M97)M86YY)UU;)S0Y+C0S,SHQ,2XY,#`G72`]("=+=65M;65R<W)U8VLG.PHD
M8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#DN-#,S.C<N-C`P)UT@/2`G4F%M
M<W1E:6XG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#DN-#8W.C$P+C,X
M,R==(#T@)TEL;&5S:&5I;2<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T
M.2XT-S,Z."XU,38G72`]("="861E;B!7=7)T=&5M8F5R9RP@3F5U;W-T:&5I
M;2<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T.2XU,#`Z,3$N,#4P)UT@
M/2`G3G5E<FYB97)G)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S0Y+C4P
M,#HW+C@V-R==(#T@)U-E;6)A8V@@56YI=&5D(%-T871E<R!!:7(@1F]R8V4@
M3W!E<F%T960@0F%S92!);B!&;W)E:6=N($-O=6YT<GDG.PHD8V]O<F1I;F%T
M97-;)T=E<FUA;GDG75LG-#DN-38W.C@N-#8W)UT@/2`G0V]L96UA;B!-86YN
M:&5I;2<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T.2XV-3`Z.2XY-C<G
M72`]("=':65B96QS=&%D="<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T
M.2XW,#`Z,3$N.34P)UT@/2`G1W)A9F5N=V]E:'(G.PHD8V]O<F1I;F%T97-;
M)T=E<FUA;GDG75LG-#DN-S`P.C<N,S,S)UT@/2`G261A<BU/8F5R<W1E:6XG
M.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#DN-S4P.C$P+C(P,"==(#T@
M)TMI='II;F=E;B!5<V$@7"!!9B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==
M6R<T.2XX-3`Z-RXV,#`G72`]("=09F5R9'-F96QD)SL*)&-O;W)D:6YA=&5S
M6R='97)M86YY)UU;)S0Y+C@U,#HW+C@X,R==(#T@)T)A9"!+<F5U>FYA8V@G
M.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#DN.34P.C<N,C8W)UT@/2`G
M2&%H;B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T.2XY.#,Z,3$N-C,S
M)UT@/2`G0F%Y<F5U=&@G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#DN
M.3@S.C8N-S`P)UT@/2`G4W!A;F=D86AL96TG.PHD8V]O<F1I;F%T97-;)T=E
M<FUA;GDG75LG-3`N,#4P.C@N,S,S)UT@/2`G5VEE<V)A9&5N)SL*)&-O;W)D
M:6YA=&5S6R='97)M86YY)UU;)S4P+C`U,#HX+C8P,"==(#T@)T9R86YK9G5R
M="`O($TM1FQU9VAA9F5N)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4P
M+C$V-SHW+C`V-R==(#T@)T)U96-H96PG.PHD8V]O<F1I;F%T97-;)T=E<FUA
M;GDG75LG-3`N,38W.C@N.38W)UT@/2`G2&%N874G.PHD8V]O<F1I;F%T97-;
M)T=E<FUA;GDG75LG-3`N,S$W.C$Q+C@X,R==(#T@)TAO9B<["B1C;V]R9&EN
M871E<ULG1V5R;6%N>2==6R<U,"XS-C<Z-RXS,3<G72`]("=-96YD:6<G.PHD
M8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3`N.#$W.C8N,3@S)UT@/2`G06%C
M:&5N("\@365R>F)R=6-K)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4P
M+C@S,SHV+C8V-R==(#T@)TYO97)V96YI8V@G.PHD8V]O<F1I;F%T97-;)T=E
M<FUA;GDG75LG-3`N.#8W.C<N,38W)UT@/2`G2V]E;&X@+R!";VYN)SL*)&-O
M;W)D:6YA=&5S6R='97)M86YY)UU;)S4P+CDV-SHV+C`U,"==(#T@)T=E:6QE
M;FMI<F-H96XG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3`N.3@S.C$P
M+CDV-R==(#T@)T5R9G5R="U":6YD97)S;&5B96XG.PHD8V]O<F1I;F%T97-;
M)T=E<FUA;GDG75LG-3$N,3$W.CDN,C@S)UT@/2`G1G)I='IL87(G.PHD8V]O
M<F1I;F%T97-;)T=E<FUA;GDG75LG-3$N,3,S.C$S+C<U,"==(#T@)T1R97-D
M96XM2VQO='IS8VAE)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4Q+C(P
M,#HV+C$S,R==(#T@)T)R=65G9V5N)SL*)&-O;W)D:6YA=&5S6R='97)M86YY
M)UU;)S4Q+C,P,#HV+C<V-R==(#T@)T1U97-S96QD;W)F)SL*)&-O;W)D:6YA
M=&5S6R='97)M86YY)UU;)S4Q+C0P,#HV+CDV-R==(#T@)T5S<V5N)SL*)&-O
M;W)D:6YA=&5S6R='97)M86YY)UU;)S4Q+C0P,#HY+C,X,R==(#T@)TMA<W-E
M;"`O($-A;&1E;B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,2XT,3<Z
M,3(N,C,S)UT@/2`G3&5I<'II9RU38VAK975D:71Z)SL*)&-O;W)D:6YA=&5S
M6R='97)M86YY)UU;)S4Q+C4Q-SHW+C8Q-R==(#T@)T1O<G1M=6YD("\@5VEC
M:V5D92<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,2XV,#`Z-BXQ-3`G
M72`]("=,86%R8G)U8V@G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3$N
M-C$W.C@N-C$W)UT@/2`G4&%D97)B;W)N("\@3&EP<'-T861T)SL*)&-O;W)D
M:6YA=&5S6R='97)M86YY)UU;)S4Q+C8V-SHQ-"XV,S,G72`]("=0<F5S8VAE
M;B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,2XW,S,Z-BXR-C<G72`]
M("=+86QK87(G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3$N-S8W.C$S
M+C$X,R==(#T@)TAO;'ID;W)F)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;
M)S4Q+C<V-SHQ-"XS,#`G72`]("=#;W1T8G5S($9L=6=P;&%T>B<["B1C;V]R
M9&EN871E<ULG1V5R;6%N>2==6R<U,2XY,3<Z."XS,#`G72`]("='=65T97)S
M;&]H)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4R+C$S,SHW+C<P,"==
M(#T@)TUU96YS=&5R("\@3W-N86)R=65C:R<["B1C;V]R9&EN871E<ULG1V5R
M;6%N>2==6R<U,BXR.#,Z.2XP.#,G72`]("="=65C:V5B=7)G)SL*)&-O;W)D
M:6YA=&5S6R='97)M86YY)UU;)S4R+C,P,#HQ,"XT-3`G72`]("="<F%U;G-C
M:'=E:6<G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3(N,S`P.C<N,S@S
M)UT@/2`G4FAE:6YE+4)E;G1L86=E)SL*)&-O;W)D:6YA=&5S6R='97)M86YY
M)UU;)S4R+C,S,SHW+C4S,R==(#T@)TAO<'-T96XG.PHD8V]O<F1I;F%T97-;
M)T=E<FUA;GDG75LG-3(N,S@S.C$S+C4Q-R==(#T@)T)E<FQI;BU38VAO96YE
M9F5L9"<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,BXT-3`Z-RXQ-C<G
M72`]("=.;W)D:&]R;B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,BXT
M-3`Z.2XT,S,G72`]("=7=6YS=&]R9B<["B1C;V]R9&EN871E<ULG1V5R;6%N
M>2==6R<U,BXT-C<Z,3,N-#`P)UT@/2`G0F5R;&EN+51E;7!E;&AO9B<["B1C
M;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,BXT-C<Z.2XV.#,G72`]("=(86YN
M;W9E<B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,BXU-C<Z,3,N,S$W
M)UT@/2`G0F5R;&EN+51E9V5L)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;
M)S4R+C4X,SHX+C,U,"==(#T@)T1I97!H;VQZ)SL*)&-O;W)D:6YA=&5S6R='
M97)M86YY)UU;)S4R+C8P,#HQ,"XP,3<G72`]("=#96QL92<["B1C;V]R9&EN
M871E<ULG1V5R;6%N>2==6R<U,BXX,3<Z.2XY,S,G72`]("="97)G96XG.PHD
M8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3(N.3$W.C$P+C$X,R==(#T@)T9A
M<W-B97)G)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4S+C`U,#HX+C@P
M,"==(#T@)T)R96UE;B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,RXR
M,#`Z,3(N-3$W)UT@/2`G5VET='-T;V-K)SL*)&-O;W)D:6YA=&5S6R='97)M
M86YY)UU;)S4S+C0R-SHQ,2XW.#0G72`]("=-96-K;&5N8G5R9RU6;W)P;VUM
M97)N+"!087)C:&EM)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4S+C4S
M,SHW+C@X,R==(#T@)TIE=F5R)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;
M)S4S+C4S,SHY+C@S,R==(#T@)TAA;6)U<F<M1FEN:V5N=V5R9&5R)SL*)&-O
M;W)D:6YA=&5S6R='97)M86YY)UU;)S4S+C4U,#HW+C8V-R==(#T@)U=I='1M
M=6YD:&%V96XG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3,N-C`P.C$S
M+C,Q-R==(#T@)U1R;VQL96YH86=E;B<["B1C;V]R9&EN871E<ULG1V5R;6%N
M>2==6R<U,RXV,S,Z,3`N,#`P)UT@/2`G2&%M8G5R9RU&=6AL<V)U971T96PG
M.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3,N-S8W.C@N-C8W)UT@/2`G
M3F]R9&AO;'HG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3,N.#$W.C$P
M+C<P,"==(#T@)TQU96)E8VLM0FQA;FME;G-E92<["B1C;V]R9&EN871E<ULG
M1V5R;6%N>2==6R<U,RXY,3<Z,3(N,C@S)UT@/2`G3&%A9V4G.PHD8V]O<F1I
M;F%T97-;)T=E<FUA;GDG75LG-30N,#`P.CDN-3@S)UT@/2`G271Z96AO92<[
M"B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U-"XS,3<Z.2XU,S,G72`]("=(
M;VAN)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4T+C,X,SHQ,"XQ-3`G
M72`]("=+:65L+4AO;'1E;F%U)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;
M)S4T+C0V-SHY+C4Q-R==(#T@)U-C:&QE<W=I9RU*86=E;"<["B1C;V]R9&EN
M871E<ULG1V5R;6%N>2==6R<U-"XV,S,Z.2XS-3`G72`]("=%9V=E8F5K)SL*
M)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4T+C@S,SHY+C4P,"==(#T@)T=L
M=65C:W-B=7)G("\@365I97)W:6LG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG
M75LG-30N.3$W.C@N,S4P)UT@/2`G5V5S=&5R;&%N9"`O(%-Y;'0G.PHD8V]O
M<F1I;F%T97-;)T=H86YA)UU;)S$P+C`U,#HM,BXU,#`G72`]("=782<["B1C
M;V]R9&EN871E<ULG1VAA;F$G75LG,3`N.3`P.BTQ+C$P,"==(#T@)TYA=G)O
M;F=O)SL*)&-O;W)D:6YA=&5S6R=':&%N82==6R<T+C@V-SHM,BXR,S,G72`]
M("=!>&EM)SL*)&-O;W)D:6YA=&5S6R=':&%N82==6R<T+C@X,SHM,2XW-C<G
M72`]("=486MO<F%D:2<["B1C;V]R9&EN871E<ULG1VAA;F$G75LG-2XR,#`Z
M+3$N,#8W)UT@/2`G4V%L='!O;F0G.PHD8V]O<F1I;F%T97-;)T=H86YA)UU;
M)S4N-C`P.BTP+C$V-R==(#T@)T%C8W)A)SL*)&-O;W)D:6YA=&5S6R=':&%N
M82==6R<U+C8Q-SHP+C`P,"==(#T@)U1E;6$G.PHD8V]O<F1I;F%T97-;)T=H
M86YA)UU;)S4N-S@S.C`N-C,S)UT@/2`G061A)SL*)&-O;W)D:6YA=&5S6R='
M:&%N82==6R<U+CDS,SHM,"XY.#,G72`]("=!:VEM($]D82<["B1C;V]R9&EN
M871E<ULG1VAA;F$G75LG-BXP.#,Z+3`N,C4P)UT@/2`G2V]F;W)I9'5A)SL*
M)&-O;W)D:6YA=&5S6R=':&%N82==6R<V+C$P,#HP+C$Q-R==(#T@)T%K=7-E
M)SL*)&-O;W)D:6YA=&5S6R=':&%N82==6R<V+C(P,#HM,BXS,S,G72`]("=3
M969W:2!"96MW86DG.PHD8V]O<F1I;F%T97-;)T=H86YA)UU;)S8N-C`P.C`N
M-#8W)UT@/2`G2&\G.PHD8V]O<F1I;F%T97-;)T=H86YA)UU;)S8N-S$W.BTQ
M+C8P,"==(#T@)TMU;6%S:2<["B1C;V]R9&EN871E<ULG1VAA;F$G75LG-RXS
M,S,Z+3(N,S,S)UT@/2`G4W5N>6%N:2<["B1C;V]R9&EN871E<ULG1VAA;F$G
M75LG-RXW-3`Z+3(N,3`P)UT@/2`G5V5N8VAI)SL*)&-O;W)D:6YA=&5S6R='
M:&%N82==6R<Y+C`S,SHM,BXT.#,G72`]("=";VQE)SL*)&-O;W)D:6YA=&5S
M6R=':&%N82==6R<Y+C0U,#HM,"XP,3<G72`]("=996YD:2<["B1C;V]R9&EN
M871E<ULG1VAA;F$G75LG.2XU,#`Z+3`N.#4P)UT@/2`G5&%M86QE)SL*)&-O
M;W)D:6YA=&5S6R=':6)R86QT87(G75LG,S8N,34P.BTU+C,U,"==(#T@)T=I
M8G)A;'1A<B<["B1C;V]R9&EN871E<ULG1W)E96-E)UU;)S,U+C,S,SHR-2XQ
M.#,G72`]("=(97)A:VQI;VX@06ER<&]R="<["B1C;V]R9&EN871E<ULG1W)E
M96-E)UU;)S,U+C0Q-#HR-RXQ-#@G72`]("=+87)P871H;W,@06ER<&]R="<[
M"B1C;V]R9&EN871E<ULG1W)E96-E)UU;)S,U+C0X,SHR-"XQ,3<G72`]("=3
M;W5D82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG,S8N-#`P
M.C(X+C`X,R==(#T@)U)H;V1E<R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='
M<F5E8V4G75LG,S8N-S@S.C(W+C`V-R==(#T@)TMO<R!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R='<F5E8V4G75LG,S<N,#8W.C(R+C`Q-R==(#T@)TMA;&%M
M871A($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T=R965C92==6R<S-RXU,S,Z
M,C(N-#`P)UT@/2`G5')I<&]L:7,@06ER<&]R="<["B1C;V]R9&EN871E<ULG
M1W)E96-E)UU;)S,W+C<P,#HR-BXY,3<G72`]("=386UO<R!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG,S<N.3`P.C(S+C<S,R==(#T@)T%T
M:&EN86D@06ER<&]R="<["B1C;V]R9&EN871E<ULG1W)E96-E)UU;)S,W+CDQ
M-SHR,2XR.#,G72`]("=!;F1R879I9&$@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG1W)E96-E)UU;)S,X+C`V-SHR,RXU-3`G72`]("=%;&5F<VES($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)T=R965C92==6R<S."XQ,#`Z,C,N-S@S)UT@
M/2`G5&%T;VDG.PHD8V]O<F1I;F%T97-;)T=R965C92==6R<S."XQ,3<Z,C`N
M-3`P)UT@/2`G2V5F86QH;FEA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T=R
M965C92==6R<S."XQ-3`Z,C$N-#$W)UT@/2`G07)A>&]S($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)T=R965C92==6R<S."XS,3<Z,C,N-3,S)UT@/2`G5&%N
M86=R82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG,S@N,S,S
M.C(V+C$S,R==(#T@)T-H:6]S($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T=R
M965C92==6R<S."XV,3<Z,C`N-S8W)UT@/2`G06MT:6]N($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)T=R965C92==6R<S.2XP-C<Z,C8N-C`P)UT@/2`G37ET
M:6QI;FD@06ER<&]R="<["B1C;V]R9&EN871E<ULG1W)E96-E)UU;)S,Y+C(Q
M-SHR,BXX,#`G72`]("=!;F-H:6%L;W,@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG1W)E96-E)UU;)S,Y+C8Q-SHQ.2XY,3<G72`]("=+97)K>7)A($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)T=R965C92==6R<S.2XV,S,Z,C(N-#$W)UT@
M/2`G3&%R:7-S82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG
M,SDN.3$W.C(U+C(S,R==(#T@)TQI;6YO<R!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R='<F5E8V4G75LG-#`N,S`P.C(Q+C<X,R==(#T@)TMO>F%N:2!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG-#`N-#4P.C(Q+C(X,R==
M(#T@)TMA<W1O<FEA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T=R965C92==
M6R<T,"XU,3<Z,C(N.38W)UT@/2`G5&AE<W-A;&]N:6MI($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)T=R965C92==6R<T,"XX-3`Z,C4N.3$W)UT@/2`G06QE
M>&%N9')O=7!O;&D@06ER<&]R="<["B1C;V]R9&EN871E<ULG1W)E96-E)UU;
M)S0P+CDX,SHR-"XV,#`G72`]("=#:')Y<V]U<&]L:2!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R='<F5E;FQA;F0G75LG-3DN.3@S.BTT-2XR,#`G72`]("=!
M;F=I<V]Q)SL*)&-O;W)D:6YA=&5S6R='<F5E;FQA;F0G75LG-C`N,#4P.BTT
M,RXQ-C<G72`]("=0<FEN<R!#:')I<W1I86X@4W5N9"<["B1C;V]R9&EN871E
M<ULG1W)E96YL86YD)UU;)S8P+C<Q-SHM-#8N,#4P)UT@/2`G2G5L:6%N96AA
M86(G.PHD8V]O<F1I;F%T97-;)T=R965N;&%N9"==6R<V,2XQ-C<Z+30U+C0Q
M-R==(#T@)TYA<G-A<G-U87$G.PHD8V]O<F1I;F%T97-;)T=R965N;&%N9"==
M6R<V,2XR,S,Z+30X+C$P,"==(#T@)T=R;V5N;F5D86PG.PHD8V]O<F1I;F%T
M97-;)T=R965N;&%N9"==6R<V,BXP,#`Z+30Y+C8V-R==(#T@)T9R961E<FEK
M<VAA86(G.PHD8V]O<F1I;F%T97-;)T=R965N;&%N9"==6R<V-"XQ-C<Z+34Q
M+C<U,"==(#T@)T=O9'1H86%B("\@3G5U:R<["B1C;V]R9&EN871E<ULG1W)E
M96YL86YD)UU;)S8U+C4X,SHM,S<N,34P)UT@/2`G2W5L=7-U:R!,=69T:&%V
M;B<["B1C;V]R9&EN871E<ULG1W)E96YL86YD)UU;)S8U+C8P,#HM,S<N-C,S
M)UT@/2`G5&%S:6EL87$G.PHD8V]O<F1I;F%T97-;)T=R965N;&%N9"==6R<V
M-BXY,3<Z+34S+C8V-R==(#T@)TAO;'-T96EN<V)O<F<G.PHD8V]O<F1I;F%T
M97-;)T=R965N;&%N9"==6R<V-RXP,3<Z+34P+C<P,"==(#T@)U-D<B!3=')O
M96UF:F]R9"<["B1C;V]R9&EN871E<ULG1W)E96YL86YD)UU;)S8W+C<X,SHM
M,S(N,S`P)UT@/2`G07!U=&ET965Q)SL*)&-O;W)D:6YA=&5S6R='<F5E;FQA
M;F0G75LG-C@N-S`P.BTU,BXW-3`G72`]("=%9V5D97-M:6YD92<["B1C;V]R
M9&EN871E<ULG1W)E96YL86YD)UU;)S8Y+C(S,SHM-3$N,#8W)UT@/2`G2F%C
M;V)S:&%V;B!,=69T:&%V;B<["B1C;V]R9&EN871E<ULG1W)E96YL86YD)UU;
M)S<P+C0Q-SHM,C$N.38W)UT@/2`G0V%P92!4;V)I;B!!=71O;6%T960@4F5P
M;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T=R965N;&%N9"==6R<W
M,"XT.#,Z+3(Q+CDU,"==(#T@)U-C;W)E<V)Y<W5N9"<["B1C;V]R9&EN871E
M<ULG1W)E96YL86YD)UU;)S<P+C<U,#HM,C(N-C4P)UT@/2`G0V]N<W1A8FQE
M(%!Y;G0G.PHD8V]O<F1I;F%T97-;)T=R965N;&%N9"==6R<W-"XS,#`Z+3(P
M+C(Q-R==(#T@)T1A;F5B;W)G)SL*)&-O;W)D:6YA=&5S6R='<F5E;FQA;F0G
M75LG-S8N-3,S.BTV."XW-3`G72`]("=4:'5L92!!+B!"+B<["B1C;V]R9&EN
M871E<ULG1W)E96YL86YD)UU;)S<V+C<V-SHM,3@N-C8W)UT@/2`G1&%N;6%R
M:W-H879N)SL*)&-O;W)D:6YA=&5S6R='<F5N861A)UU;)S$R+C`P,#HM-C$N
M-S@S)UT@/2`G4&]I;G0@4V%L:6YE<R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S
M6R='=6%D96QO=7!E)UU;)S$V+C(V-SHM-C$N-3$W)UT@/2`G3&4@4F%I>F5T
M+"!'=6%D96QO=7!E)SL*)&-O;W)D:6YA=&5S6R='=6%D96QO=7!E)UU;)S$W
M+CDP,#HM-C(N.#4P)UT@/2`G1W5S=&%V:6$L(%-A:6YT($)A<G1H96QE;7DG
M.PHD8V]O<F1I;F%T97-;)T=U871E;6%L82==6R<Q,RXY,3<Z+3DP+C@Q-R==
M(#T@)U-A;B!*;W-E)SL*)&-O;W)D:6YA=&5S6R='=6%T96UA;&$G75LG,30N
M-3,S.BTY,2XV-C<G72`]("=2971A;&AU;&5U)SL*)&-O;W)D:6YA=&5S6R='
M=6%T96UA;&$G75LG,30N-3@S.BTY,"XU,3<G72`]("='=6%T96UA;&$@065R
M;W!U97)T;VQA($%U<F]R82<["B1C;V]R9&EN871E<ULG1W5A=&5M86QA)UU;
M)S$U+C,Q-SHM.3$N-#8W)UT@/2`G2'5E:'5E=&5N86YG;R<["B1C;V]R9&EN
M871E<ULG1W5A=&5M86QA)UU;)S$U+C0V-SHM.3`N,S$W)UT@/2`G0V]B86XG
M.PHD8V]O<F1I;F%T97-;)T=U871E;6%L82==6R<Q-2XW,3<Z+3@X+C8P,"==
M(#T@)U!U97)T;R!"87)R:6]S)SL*)&-O;W)D:6YA=&5S6R='=6%T96UA;&$G
M75LG,38N.3$W.BTX.2XX.#,G72`]("=&;&]R97,G.PHD8V]O<F1I;F%T97-;
M)T=U:6YE82==6R<Q,"XP,S,Z+3$P+C<U,"==(#T@)T9A<F%N86@@+R!"861A
M;&$G.PHD8V]O<F1I;F%T97-;)T=U:6YE82==6R<Q,"XP-3`Z+3$R+C@V-R==
M(#T@)TMI;F1I82<["B1C;V]R9&EN871E<ULG1W5I;F5A)UU;)S$P+C,X,SHM
M.2XS,#`G72`]("=+86YK86XG.PHD8V]O<F1I;F%T97-;)T=U:6YE82==6R<Q
M,"XY,S,Z+3$T+C,Q-R==(#T@)T)O:V4G.PHD8V]O<F1I;F%T97-;)T=U:6YE
M82==6R<Q,2XS,3<Z+3$R+C,P,"==(#T@)TQA8F4G.PHD8V]O<F1I;F%T97-;
M)T=U:6YE82==6R<Q,2XT,S,Z+3DN,38W)UT@/2`G4VEG=6ER:2<["B1C;V]R
M9&EN871E<ULG1W5I;F5A)UU;)S<N-S,S.BTX+C@S,R==(#T@)TY<)UIE<F5K
M;W)E)SL*)&-O;W)D:6YA=&5S6R='=6EN96$G75LG."XU,S,Z+3DN-#8W)UT@
M/2`G36%C96YT82<["B1C;V]R9&EN871E<ULG1W5I;F5A)UU;)SDN,3@S.BTQ
M,"XQ,#`G72`]("=+:7-S:61O=6=O=2<["B1C;V]R9&EN871E<ULG1W5I;F5A
M)UU;)SDN-38W.BTQ,RXV,3<G72`]("=#;VYA:W)Y("\@1V)E<W-I82<["B1C
M;V]R9&EN871E<ULG1W5I;F5A+4)I<W-A=2==6R<Q,2XX.#,Z+3$U+C8U,"==
M(#T@)T)I<W-A=2!!97)O<&]R="<["B1C;V]R9&EN871E<ULG1W5I;F5A+4)I
M<W-A=2==6R<Q,BXQ-C<Z+3$T+C8V-R==(#T@)T)A9F%T82<["B1C;V]R9&EN
M871E<ULG1W5Y86YA)UU;)S8N-3`P.BTU."XR-3`G72`]("=4:6UE:')I($%I
M<G!O<G0G.PHD8V]O<F1I;F%T97-;)T=U>6%N82==6R<V+C@P,#HM-3@N,34P
M)UT@/2`G1V5O<F=E=&]W;B<["B1C;V]R9&EN871E<ULG2&%I=&DG75LG,3@N
M-38W.BTW,BXS,#`G72`]("=0;W)T+4%U+5!R:6YC92`O($%E<F]P;W)T($EN
M=&5R;F%T:6]N86PG.PHD8V]O<F1I;F%T97-;)TAA:71I)UU;)S$Y+C<U,#HM
M-S(N,3@S)UT@/2`G0V%P+4AA:71I96XG.PHD8V]O<F1I;F%T97-;)TAO;F1U
M<F%S)UU;)S$S+C(V-SHM.#<N-C4P)UT@/2`G06UA<&%L82<["B1C;V]R9&EN
M871E<ULG2&]N9'5R87,G75LG,3,N,S`P.BTX-RXQ.#,G72`]("=#:&]L=71E
M8V$G.PHD8V]O<F1I;F%T97-;)TAO;F1U<F%S)UU;)S$T+C`U,#HM.#<N,C$W
M)UT@/2`G5&5G=6-I9V%L<&$G.PHD8V]O<F1I;F%T97-;)TAO;F1U<F%S)UU;
M)S$T+C,Q-SHM.#@N,34P)UT@/2`G3&$@17-P97)A;GIA)SL*)&-O;W)D:6YA
M=&5S6R=(;VYD=7)A<R==6R<Q-"XS.#,Z+3@W+C8Q-R==(#T@)T-O<F]N96P@
M16YR:7%U92!3;W1O($-A;F\@06ER($)A<V4G.PHD8V]O<F1I;F%T97-;)TAO
M;F1U<F%S)UU;)S$T+C<X,SHM.#@N-S@S)UT@/2`G4V%N=&$@4F]S82!$92!#
M;W!A;B<["B1C;V]R9&EN871E<ULG2&]N9'5R87,G75LG,30N.3`P.BTX-2XY
M,S,G72`]("=#871A8V%M87,G.PHD8V]O<F1I;F%T97-;)TAO;F1U<F%S)UU;
M)S$U+C$V-SHM.#<N,3$W)UT@/2`G66]R;R<["B1C;V]R9&EN871E<ULG2&]N
M9'5R87,G75LG,34N,C$W.BTX,RXX,#`G72`]("=0=65R=&\@3&5M<&ER82<[
M"B1C;V]R9&EN871E<ULG2&]N9'5R87,G75LG,34N-#4P.BTX-RXY,S,G72`]
M("=,82!-97-A(%-A;B!0961R;R!3=6QA)SL*)&-O;W)D:6YA=&5S6R=(;VYD
M=7)A<R==6R<Q-2XW,3<Z+3@W+C0X,R==(#T@)U1E;&$G.PHD8V]O<F1I;F%T
M97-;)TAO;F1U<F%S)UU;)S$U+C<S,SHM.#8N.#8W)UT@/2`G3&$@0V5I8F$@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG2&]N9'5R87,G75LG,38N,S$W.BTX
M-BXU,3<G72`]("=2;V%T86XG.PHD8V]O<F1I;F%T97-;)TAO;F1U<F%S)UU;
M)S$V+C0V-SHM.#8N,#8W)UT@/2`G1W5A;F%J82<["B1C;V]R9&EN871E<ULG
M2&]N9'5R87,G75LG,3<N-#`P.BTX,RXY,S,G72`]("=)<VQA<R!$96P@0VES
M;F4G.PHD8V]O<F1I;F%T97-;)TAO;F<@2V]N9R==6R<R,BXR,#`Z,3$T+C`Q
M-R==(#T@)T-H975N9R!#:&%U)SL*)&-O;W)D:6YA=&5S6R=(;VYG($MO;F<G
M75LG,C(N,S,S.C$Q-"XQ.#,G72`]("=(;VYG($MO;F<@26YT97(M3F%T:6]N
M86P@06ER<&]R="<["B1C;V]R9&EN871E<ULG2'5N9V%R>2==6R<T-BXQ,#`Z
M,3@N,C,S)UT@/2`G4&5C<R`O(%!O9V%N>2<["B1C;V]R9&EN871E<ULG2'5N
M9V%R>2==6R<T-BXR-3`Z,C`N,3`P)UT@/2`G4WIE9V5D)SL*)&-O;W)D:6YA
M=&5S6R=(=6YG87)Y)UU;)S0V+C,X,SHQ-RXX,S,G72`]("=+87!O<W9A<B<[
M"B1C;V]R9&EN871E<ULG2'5N9V%R>2==6R<T-BXV.#,Z,C$N,38W)UT@/2`G
M0F5K97-C<V%B82<["B1C;V]R9&EN871E<ULG2'5N9V%R>2==6R<T-BXY,3<Z
M,3@N,#4P)UT@/2`G4VEO9F]K)SL*)&-O;W)D:6YA=&5S6R=(=6YG87)Y)UU;
M)S0V+CDQ-SHQ.2XW-3`G72`]("=+96-S:V5M970G.PHD8V]O<F1I;F%T97-;
M)TAU;F=A<GDG75LG-#<N,3$W.C(P+C(S,R==(#T@)U-Z;VQN;VLG.PHD8V]O
M<F1I;F%T97-;)TAU;F=A<GDG75LG-#<N,C`P.C$W+C4P,"==(#T@)U!A<&$G
M.PHD8V]O<F1I;F%T97-;)TAU;F=A<GDG75LG-#<N,C8W.C$V+C8S,R==(#T@
M)U-Z;VUB871H96QY)SL*)&-O;W)D:6YA=&5S6R=(=6YG87)Y)UU;)S0W+C0S
M,SHQ.2XR-C<G72`]("="=61A<&5S="`O($9E<FEH96=Y)SL*)&-O;W)D:6YA
M=&5S6R=(=6YG87)Y)UU;)S0W+C0U,#HQ."XY-C<G72`]("="=61A;W)S)SL*
M)&-O;W)D:6YA=&5S6R=(=6YG87)Y)UU;)S0W+C0X,SHR,2XV,#`G72`]("=$
M96)R96-E;B<["B1C;V]R9&EN871E<ULG2'5N9V%R>2==6R<T-RXU,3<Z,3DN
M,#,S)UT@/2`G0G5D87!E<W0@365T($-E;G1E<B<["B1C;V]R9&EN871E<ULG
M2'5N9V%R>2==6R<T-RXY-C<Z,C$N.3@S)UT@/2`G3GEI<F5G>6AA>F$@+R!.
M87!K;W(G.PHD8V]O<F1I;F%T97-;)TAU;F=A<GDG75LG-#@N,#@S.C(P+C<V
M-R==(#T@)TUI<VMO;&,G.PHD8V]O<F1I;F%T97-;)TEC96QA;F0G75LG-C,N
M-#`P.BTR,"XR.#,G72`]("=697-T;6%N;F%E>6IA<B<["B1C;V]R9&EN871E
M<ULG26-E;&%N9"==6R<V,RXY-C<Z+3(R+C8P,"==(#T@)TME9FQA=FEK=7)F
M;'5G=F]L;'5R)SL*)&-O;W)D:6YA=&5S6R=)8V5L86YD)UU;)S8T+C$S,SHM
M,C$N.3`P)UT@/2`G4F5Y:VIA=FEK)SL*)&-O;W)D:6YA=&5S6R=)8V5L86YD
M)UU;)S8T+C,P,#HM,34N,C$W)UT@/2`G06MU<FYE<R<["B1C;V]R9&EN871E
M<ULG26-E;&%N9"==6R<V-2XP.#,Z+3(R+C<S,R==(#T@)U-T>6MK:7-H;VQM
M=7(G.PHD8V]O<F1I;F%T97-;)TEC96QA;F0G75LG-C4N,C@S.BTQ-"XT,#`G
M72`]("=%9VEL<W-T861I<B<["B1C;V]R9&EN871E<ULG26-E;&%N9"==6R<V
M-2XV.#,Z+3$X+C`X,R==(#T@)T%K=7)E>7)I)SL*)&-O;W)D:6YA=&5S6R=)
M8V5L86YD)UU;)S8U+C<P,#HM,30N.#$W)UT@/2`G4VMJ86QD=&AI;F=S<W1A
M9&ER)SL*)&-O;W)D:6YA=&5S6R=)8V5L86YD)UU;)S8V+C0U,#HM,34N.34P
M)UT@/2`G4F%U9F%R:&]F;B<["B1C;V]R9&EN871E<ULG26-E;&%N9"==6R<V
M-BXU,S,Z+3$X+C`Q-R==(#T@)T=R:6US97DG.PHD8V]O<F1I;F%T97-;)TEN
M9&EA)UU;)S$P+C<V-SHW."XW,3<G72`]("=4:7)U8VAC:&ER87!A;&QI)SL*
M)&-O;W)D:6YA=&5S6R=);F1I82==6R<Q,2XP,S,Z-S<N,#4P)UT@/2`G0V]I
M;6)A=&]R92`O(%!E96QA;65D=2<["B1C;V]R9&EN871E<ULG26YD:6$G75LG
M,3$N-C8W.CDR+C<Q-R==(#T@)U!O<G0@0FQA:7(G.PHD8V]O<F1I;F%T97-;
M)TEN9&EA)UU;)S$R+CDQ-SHW-"XX.#,G72`]("=-86YG86QO<F4@+R!"86IP
M92<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,3(N.3$W.C<Y+C$U,"==(#T@
M)U9E;&QO<F4G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S$S+C`P,#HX,"XQ
M.#,G72`]("=-861R87,@+R!-:6YA;6)A:VMA;2<["B1C;V]R9&EN871E<ULG
M26YD:6$G75LG,30N-#@S.C<X+C@S,R==(#T@)T-U9&1A<&%H)SL*)&-O;W)D
M:6YA=&5S6R=);F1I82==6R<Q-2XQ-3`Z-S8N.#4P)UT@/2`G0F5L;&%R>2<[
M"B1C;V]R9&EN871E<ULG26YD:6$G75LG,34N,S@S.C<S+C@Q-R==(#T@)T=O
M82`O($1A8F]L:6T@06ER<&]R="<["B1C;V]R9&EN871E<ULG26YD:6$G75LG
M,34N.#4P.C<T+C8Q-R==(#T@)T)E;&=A=6T@+R!386UB<F$G.PHD8V]O<F1I
M;F%T97-;)TEN9&EA)UU;)S$V+C4S,SHX,"XX,#`G72`]("=6:6IA>6%W861A
M("\@1V%N;F%V87)A;2<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,38N-S`P
M.C<T+C(S,R==(#T@)TMO;&AA<'5R)SL*)&-O;W)D:6YA=&5S6R=);F1I82==
M6R<Q-RXT-3`Z-S@N-#8W)UT@/2`G2'ED97)A8F%D($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)TEN9&EA)UU;)S$W+C8V-SHW-2XY,#`G72`]("=3:&]L87!U
M<B<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,3DN,3$W.C<R+C@U,"==(#T@
M)T)O;6)A>2`O(%-A;G1A8W)U>B<["B1C;V]R9&EN871E<ULG26YD:6$G75LG
M,3DN.#4P.C<U+C0P,"==(#T@)T%U<F%N9V%B860@0VAI:V%L=&AA;B!!97)O
M9')O;64G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(P+C(U,#HX-2XX,S,G
M72`]("=":'5B86YE<W=A<B<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,C`N
M-S`P.C<W+C`V-R==(#T@)T%K;VQA)SL*)&-O;W)D:6YA=&5S6R=);F1I82==
M6R<R,2XQ,#`Z-SDN,#4P)UT@/2`G3F%G<'5R(%-O;F5G86]N)SL*)&-O;W)D
M:6YA=&5S6R=);F1I82==6R<R,2XW-3`Z-S(N,C`P)UT@/2`G0FAA=6YA9V%R
M)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R,2XX,S,Z-S8N,S8W)UT@/2`G
M2VAA;F1W82<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,C$N.3$W.C@T+C`X
M,R==(#T@)TIH87)S=6=U9&$G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(R
M+C,P,#HW,"XW.#,G72`]("=286IK;W0G.PHD8V]O<F1I;F%T97-;)TEN9&EA
M)UU;)S(R+C8U,#HX."XT-3`G72`]("=#86QC=71T82`O($1U;2!$=6TG.PHD
M8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(R+C<Q-SHW-2XX,#`G72`]("=);F1O
M<F4G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(R+C@Q-SHX-BXQ.#,G72`]
M("=*86US:&5D<'5R)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R,RXP-C<Z
M-S(N-C,S)UT@/2`G06AM861A8F%D)SL*)&-O;W)D:6YA=&5S6R=);F1I82==
M6R<R,RXR,#`Z-SDN.34P)UT@/2`G2F%B86QP=7(G.PHD8V]O<F1I;F%T97-;
M)TEN9&EA)UU;)S(S+C(U,#HV.2XV-C<G72`]("=":'5J+5)U9')A;6%T82<[
M"B1C;V]R9&EN871E<ULG26YD:6$G75LG,C,N,C@S.C<W+C,U,"==(#T@)T)H
M;W!A;"`O($)A:7)A9V%R:"<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,C,N
M,S$W.C@U+C,Q-R==(#T@)TTN($\N(%)A;F-H:2<["B1C;V]R9&EN871E<ULG
M26YD:6$G75LG,C,N.#@S.CDQ+C(U,"==(#T@)T%G87)T86QA)SL*)&-O;W)D
M:6YA=&5S6R=);F1I82==6R<R-"XU-C<Z.#`N.#,S)UT@/2`G4V%T;F$G.PHD
M8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(T+C8Q-SHW,RXX.#,G72`]("=59&%I
M<'5R($1A8F]K)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R-"XW-3`Z.#0N
M.34P)UT@/2`G1V%Y82<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,C0N-S8W
M.CDS+CDP,"==(#T@)TEM<&AA;"!4=6QI:&%L)SL*)&-O;W)D:6YA=&5S6R=)
M;F1I82==6R<R-2XQ-3`Z-S4N.#4P)UT@/2`G2V]T82!!97)O9')O;64G.PHD
M8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(U+C0U,#HW."XU.#,G72`]("=*:&%N
M<VDG.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(U+C0U,#HX,2XW,S,G72`]
M("=!;&QA:&%B860@+R!"86UH<F%U;&DG.PHD8V]O<F1I;F%T97-;)TEN9&EA
M)UU;)S(U+C0U,#HX,BXX-C<G72`]("=687)A;F%S:2`O($)A8F%T<'5R)SL*
M)&-O;W)D:6YA=&5S6R=);F1I82==6R<R-2XV,#`Z.#4N,3`P)UT@/2`G4&%T
M;F$G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(V+C$P,#HY,2XU.#,G72`]
M("='875H871I)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R-BXR,S,Z-S@N
M,C4P)UT@/2`G1W=A;&EO<B<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,C8N
M,S`P.C<S+C`Q-R==(#T@)TIO9&AP=7(G.PHD8V]O<F1I;F%T97-;)TEN9&EA
M)UU;)S(V+C0P,#HX,"XT,#`G72`]("=+86YP=7(@+R!#:&%K97)I)SL*)&-O
M;W)D:6YA=&5S6R=);F1I82==6R<R-BXV,S,Z.#@N,S$W)UT@/2`G4VEL:6=U
M<FDG.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(V+C<U,#HX,"XX.#,G72`]
M("=,=6-K;F]W("\@06UA=7-I)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R
M-BXW-3`Z.#,N,S8W)UT@/2`G1V]R86MH<'5R)SL*)&-O;W)D:6YA=&5S6R=)
M;F1I82==6R<R-BXX,3<Z-S4N.#`P)UT@/2`G2F%I<'5R("\@4V%N9V%N97(G
M.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(W+C$U,#HW-RXY-C<G72`]("=!
M9W)A)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R-RXR,S,Z.30N,3$W)UT@
M/2`G3F]R=&@@3&%K:&EM<'5R)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R
M-RXT.#,Z.34N,#$W)UT@/2`G1&EB<G5G87)H("\@36]H86YB87)I)SL*)&-O
M;W)D:6YA=&5S6R=);F1I82==6R<R."XS-C<Z-SDN-#`P)UT@/2`G0F%R96EL
M;'DG.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(X+C4V-SHW-RXQ,3<G72`]
M("=.97<@1&5L:&D@+R!086QA;2<["B1C;V]R9&EN871E<ULG26YD:6$G75LG
M,C@N-3@S.C<W+C(P,"==(#T@)TYE=R!$96QH:2`O(%-A9F1A<FIU;F<G.PHD
M8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(Y+C$V-SHW-2XW,S,G72`]("=(:7-S
M87(G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S,Q+C(U,#HW-BXV-C<G72`]
M("=":6QA<W!U<B<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,S$N-C,S.C<T
M+C@V-R==(#T@)T%M<FET<V%R)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<X
M+C0V-SHW-BXY-3`G72`]("=4:&ER=79A;F%N=&AA<'5R86TG.PHD8V]O<F1I
M;F%T97-;)TEN9&EA)UU;)SDN,34P.CDR+C@Q-R==(#T@)T-A<B!.:6-O8F%R
M)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<Y+C@S,SHW."XP.#,G72`]("=-
M861U<F%I)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<Y+CDU,#HW-BXR-C<G
M72`]("=#;V-H:6X@+R!7:6QL:6YG9&]N)SL*)&-O;W)D:6YA=&5S6R=);F1O
M;F5S:6$G75LG,"XQ,3<Z,3$Q+C4S,R==(#T@)U-I;G1A;F<G.PHD8V]O<F1I
M;F%T97-;)TEN9&]N97-I82==6R<M,"XQ-3`Z,3`Y+C0P,"==(#T@)U!O;G1I
M86YA:R`O(%-U<&%D:6\G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<P
M+C0V-SHQ,#$N-#4P)UT@/2`G4&%K86YB87)U("\@4VEM<&%N9W1I9V$G.PHD
M8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<P+C0V-SHQ,#(N,S$W)UT@/2`G
M4F5N9V%T("\@2F%P=7)A)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG
M+3`N-#@S.C$P-"XU.#,G72`]("=3:6YG:V5P("\@1&%B;R<["B1C;V]R9&EN
M871E<ULG26YD;VYE<VEA)UU;)S`N-3$W.C$R,RXP-C<G72`]("=';W)O;G1A
M;&\@+R!*86QA;'5D9&EN)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG
M+3`N-C$W.C$Q-RXQ-3`G72`]("=386UA<FEN9&$@+R!496UI;F1U;F<G.PHD
M8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,"XV.#,Z,3$Y+C<S,R==(#T@
M)U!A;'4@+R!-=71I87)A)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG
M,"XW.#,Z,3(W+C,X,R==(#T@)U1E<FYA=&4@+R!"86)U;&QA:"<["B1C;V]R
M9&EN871E<ULG26YD;VYE<VEA)UU;)RTP+C@X,SHQ,#`N,S4P)UT@/2`G4&%D
M86YG("\@5&%B:6YG)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3`N
M.#@S.C$S-"XP-3`G72`]("=-86YO:W=A<FD@+R!296YD86YI)SL*)&-O;W)D
M:6YA=&5S6R=);F1O;F5S:6$G75LG+3`N.3`P.C$R,BXW.#,G72`]("=,=7=U
M:R`O($)U8G5N9R<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)S`N.3$W
M.C$P-"XU,S,G72`]("=486YJ=6YG<&EN86YG("\@2VEJ86YG)SL*)&-O;W)D
M:6YA=&5S6R=);F1O;F5S:6$G75LG+3`N.3,S.C$S,2XQ,3<G72`]("=3;W)O
M;F<@+R!*969M86XG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,"XY
M-3`Z,3$T+CDP,"==(#T@)TUU87)A=&5W92`O($)E<FEN9VEN)SL*)&-O;W)D
M:6YA=&5S6R=);F1O;F5S:6$G75LG+3$N,#`P.C$Q-"XP,#`G72`]("=086QA
M;F=K87)A>6$@+R!086YA<G5N9R<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA
M)UU;)S$N,#$W.C$R,"XX,#`G72`]("=4;VQI+51O;&D@+R!,86QO<R<["B1C
M;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)S$N,#@S.C$P.2XV-C<G72`]("=3
M:6YG:V%W86YG($EI)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG,2XQ
M,3<Z,3`T+C$Q-R==(#T@)T)A=&%N("A3=6UA=')A*2<["B1C;V]R9&EN871E
M<ULG26YD;VYE<VEA)UU;)RTQ+C$X,SHQ,S8N,3$W)UT@/2`G0FEA:R`O($UO
M:VUE<B<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTQ+C(V-SHQ,38N
M.3`P)UT@/2`G0F%L:6MP87!A;B`O(%-E<&EN9V=A;B<["B1C;V]R9&EN871E
M<ULG26YD;VYE<VEA)UU;)RTQ+C,X,SHQ,C`N-S,S)UT@/2`G4&]S;R`O($MA
M<VEG=6YC=2<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)S$N-3`P.CDW
M+C8S,R==(#T@)T=U;G5N9R!3:71O;&D@+R!":6YA:V$G.PHD8V]O<F1I;F%T
M97-;)TEN9&]N97-I82==6R<Q+C4S,SHQ,C0N.3$W)UT@/2`G365N861O("\@
M1'(N(%-A;2!2871U;&%N9VDG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==
M6R<Q+C4U,#HY."XX.#,G72`]("=3:6)O;&=A("\@4&EN86YG<V]R:2<["B1C
M;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTQ+C8Q-SHQ,C0N-34P)UT@/2`G
M3&%B=6AA("\@5&%L:6%B=2<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;
M)RTQ+C8S,SHQ,#,N-C4P)UT@/2`G2F%M8FD@+R!3=6QT86X@5&%H82<["B1C
M;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)S$N.#$W.C$R-RXX,S,G72`]("='
M86QE;&$@+R!'86UA<FUA;&%M=2<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA
M)UU;)RTQ+C@S,SHQ,S@N-S$W)UT@/2`G4V%R;6DG.PHD8V]O<F1I;F%T97-;
M)TEN9&]N97-I82==6R<M,2XX-3`Z,3`Y+CDV-R==(#T@)TME=&%P86YG("\@
M4F%H861I(%5S;6%M86XG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M
M,2XX-C<Z,3,V+C(S,R==(#T@)U-E<G5I("\@665N9&]S82<["B1C;V]R9&EN
M871E<ULG26YD;VYE<VEA)UU;)RTQ,"XQ-C<Z,3(S+C8V-R==(#T@)TMU<&%N
M9R`O($5L(%1A<FDG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,3`N
M-3`P.C$R,2XX,S,G72`]("=386)U("\@5&%R9&%M=2<["B1C;V]R9&EN871E
M<ULG26YD;VYE<VEA)UU;)RTQ,"XW,S,Z,3(S+C`V-R==(#T@)U)O=&4@+R!"
M86$G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,BXP.#,Z,3(V+C`P
M,"==(#T@)U-A;F%N82<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)S(N
M,3$W.C$Q-RXT-3`G72`]("=486YJ=6YG(%)E9&5P("\@0F5R874G.PHD8V]O
M<F1I;F%T97-;)TEN9&]N97-I82==6R<M,BXQ-C<Z,3`V+C$S,R==(#T@)U!A
M;F=K86QP:6YA;F<@+R!086YG:V%L<&EN86YG)SL*)&-O;W)D:6YA=&5S6R=)
M;F1O;F5S:6$G75LG+3(N-38W.C$T,"XT.#,G72`]("=*87EA<'5R82`O(%-E
M;G1A;FDG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,BXW,#`Z,3$P
M+C<P,"==(#T@)U!A;F=K86QA;B!"=6X@+R!)<VMA;F1A<B<["B1C;V]R9&EN
M871E<ULG26YD;VYE<VEA)UU;)RTR+C<U,#HQ,#<N-S4P)UT@/2`G5&%N:G5N
M9W!A;F1A;B`O($)U;'5H(%1U;6)A;F<G.PHD8V]O<F1I;F%T97-;)TEN9&]N
M97-I82==6R<M,BXW-C<Z,3`Q+C,V-R==(#T@)TME<FEN8VD@+R!$97!A=&D@
M4&%R8F\G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<R+C@U,#HQ,3<N
M,S,S)UT@/2`G5&%N:G5N9R!396QO<B<["B1C;V]R9&EN871E<ULG26YD;VYE
M<VEA)UU;)RTR+C@X,SHQ,S(N,C4P)UT@/2`G1F%K+49A:R`O(%1O<F5A)SL*
M)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3(N.3`P.C$P-"XW,#`G72`]
M("=086QE;6)A;F<@+R!486QA;F=B971U='4G.PHD8V]O<F1I;F%T97-;)TEN
M9&]N97-I82==6R<M,RXR-3`Z,3(W+C`X,R==(#T@)TYA;6QE82<["B1C;V]R
M9&EN871E<ULG26YD;VYE<VEA)UU;)S,N,S,S.C$Q-RXU-C<G72`]("=487)A
M:V%N("\@2G5W871A)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3,N
M,S,S.C$S-2XU,#`G72`]("=.86)I<F4G.PHD8V]O<F1I;F%T97-;)TEN9&]N
M97-I82==6R<M,RXS-3`Z,3(X+C@X,R==(#T@)T%M86AA:2<["B1C;V]R9&EN
M871E<ULG26YD;VYE<VEA)UU;)RTS+C0P,#HQ,38N,C$W)UT@/2`G2V]T86)A
M<G4G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,RXT,S,Z,3$T+C<U
M,"==(#T@)T)A;FIA<FUA<VEN("\@4WEA;7-U9&1I;B!.;V]R)SL*)&-O;W)D
M:6YA=&5S6R=);F1O;F5S:6$G75LG,RXU-C<Z.3@N-C@S)UT@/2`G365D86X@
M+R!0;VQO;FEA)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG,RXU.#,Z
M,3(U+C0V-R==(#T@)U1A:'5N82<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA
M)UU;)RTS+C8V-SHQ,S,N-S4P)UT@/2`G2V%I;6%N82`O(%5T87)O;2<["B1C
M;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTS+C<P,#HQ,C@N,#@S)UT@/2`G
M06UB;VX@+R!0871T:6UU<F$G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==
M6R<S+C<S,SHQ,34N-C@S)UT@/2`G3&]N9V)A=V%N("\@2G5V86D@4V5M87)I
M;F<G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,RXX.#,Z,3`R+C,S
M,R==(#T@)T)E;F=K=6QU("\@4&%D86YG:V5M:6QI;F<G.PHD8V]O<F1I;F%T
M97-;)TEN9&]N97-I82==6R<M,RXY,3<Z,3,V+C,V-R==(#T@)T5N87)O=&%L
M:2<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)S,N.34P.C$P."XS.#,G
M72`]("=286YA:2`O(%)A;F%I)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G
M75LG+30N,#8W.C$S."XY-3`G72`]("=786UE;F$@+R!786UE;F$G.PHD8V]O
M<F1I;F%T97-;)TEN9&]N97-I82==6R<M-"XQ,#`Z,3(R+C0S,R==(#T@)TME
M;F1A<FD@+R!7;VQT97)M;VXM1VEN<VED:2<["B1C;V]R9&EN871E<ULG26YD
M;VYE<VEA)UU;)S0N,C4P.CDV+C$Q-R==(#T@)TUE=6QA8F]H("\@0W5T($YY
M86L@1&AI96XG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M-"XT-3`Z
M,3`U+C$X,R==(#T@)TUE;F=G86QA("\@07-T<F$@2W-E=')A)SL*)&-O;W)D
M:6YA=&5S6R=);F1O;F5S:6$G75LG+30N-S$W.C$S-BXT,S,G72`]("=+;VMO
M;F%O("\@5&EM=6MA)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+34N
M,#8W.C$Q.2XU-3`G72`]("=5:G5N9R!086YD86YG("\@2&%S86YU9&1I;B<[
M"B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)S4N,C,S.CDW+C(P,"==(#T@
M)TQH;VMS975M87=E("\@36%L:6MU<W-A;&5H)SL*)&-O;W)D:6YA=&5S6R=)
M;F1O;F5S:6$G75LG+34N,C8W.C$P-2XQ.#,G72`]("=496QU:V)E='5N9R`O
M($)E<F%N=&DG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M-2XT-C<Z
M,3(R+C8Q-R==(#T@)T)A=2U"874@+R!"971O($%M8FER:2<["B1C;V]R9&EN
M871E<ULG26YD;VYE<VEA)UU;)S4N-3$W.CDU+C0Q-R==(#T@)T)A;F1A($%C
M96@@+R!";&%N9V)I;G1A;F<G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==
M6R<U+C@V-SHY-2XS,3<G72`]("=386)A;F<@+R!#=70@0F%U)SL*)&-O;W)D
M:6YA=&5S6R=);F1O;F5S:6$G75LG+38N,3`P.C$T,"XS,#`G72`]("=486YA
M:"!-97)A:"`O(%1A;F%H($UE<F%H)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S
M:6$G75LG+38N,3$W.C$P-BXV-3`G72`]("=*86MA<G1A("\@4V]E:V%R;F\M
M2&%T=&$G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M-BXR,S,Z,3`V
M+C8U,"==(#T@)T-U<G5G("\@0G5D:6%R=&\G.PHD8V]O<F1I;F%T97-;)TEN
M9&]N97-I82==6R<M-BXR-3`Z,3`V+CDP,"==(#T@)TIA:V%R=&$@2&%L:6T@
M4&5R9&%N86MU<W5M82<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTV
M+C4U,#HQ,#<N-C8W)UT@/2`G2V%L:6IA=&DG.PHD8V]O<F1I;F%T97-;)TEN
M9&]N97-I82==6R<M-BXY,#`Z,3`W+C4X,R==(#T@)T)A;F1U;F<@+R!(=7-E
M:6XG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M-BXY.#,Z,3$P+C,X
M,R==(#T@)U-E;6%R86YG("\@06AM861Y86YI)SL*)&-O;W)D:6YA=&5S6R=)
M;F1O;F5S:6$G75LG+3<N,C$W.C$Q,BXW,3<G72`]("=3=7)A8F%Y82`O(%!E
M<F%K)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3<N,C$W.C$Q,RXW
M,3<G72`]("=3=7)A8F%Y82<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;
M)RTW+C,S,SHQ,#@N,C4P)UT@/2`G5&%S:6MM86QA>6$@+R!#:6)E=7)E=6TG
M.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M-RXS-C<Z,3$R+C<V-R==
M(#T@)U-U<F%B87EA("\@2G5A;F1A)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S
M:6$G75LG+3<N-C$W.C$Q,2XU,3<G72`]("=-861I=6X@+R!)<W=A:'EU9&DG
M.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M-RXW,S,Z,3`Y+C`Q-R==
M(#T@)T-I;&%C87`G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M-RXW
M.#,Z,3$P+C0S,R==(#T@)TIO9WEA:V%R=&$@+R!!9&ES=6-I<'1O)SL*)&-O
M;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3<N.#8W.C$Q,"XY,3<G72`]("=3
M=7)A:V%R=&$@+R!!9&ES=6UA<FUO)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S
M:6$G75LG+3<N.38W.C$Q,BXW,#`G72`]("=-86QA;F<@+R!!8F1U;"!286AK
M;6%N<V%L96@G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M-RXY.#,Z
M,3,Q+C,P,"==(#T@)U-A=6UL86MI)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S
M:6$G75LG+3@N,C$W.C$R-"XU-C<G72`]("=!;&]R("\@36%L:2<["B1C;V]R
M9&EN871E<ULG26YD;VYE<VEA)UU;)RTX+C(V-SHQ,C(N.38W)UT@/2`G3&%R
M86YT=6MA)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3@N-#,S.C$Q
M-RXT,3<G72`]("=3=6UB87=A($)E<V%R("\@4W5M8F%W82!"97-A<B<["B1C
M;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTX+C0V-SHQ-#`N,S@S)UT@/2`G
M365R875K92`O($UO<&%H)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG
M+3@N-3,S.C$Q-BXP-C<G72`]("=!;7!E;F%N("\@4V5L87!A<F%N9R<["B1C
M;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTX+C4U,#HQ,3@N-S`P)UT@/2`G
M0FEM82<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTX+C8S,SHQ,C(N
M,C4P)UT@/2`G36%U;65R92`O(%=A:2!/=&DG.PHD8V]O<F1I;F%T97-;)TEN
M9&]N97-I82==6R<M."XW-3`Z,3$U+C$V-R==(#T@)T1E;G!A<V%R("\@3F=U
M<F%H+5)A:2<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTY+C8V-SHQ
M,C`N,S,S)UT@/2`G5V%I;F=A<'4@+R!-874@2&%U)SL*)&-O;W)D:6YA=&5S
M6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S(U+C0Q-SHV,"XW-3`G
M72`]("=#:&%H8F%H87(G.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@
M4F5P=6)L:6,@;V8G75LG,C8N-3@S.C4T+C@S,R==(#T@)T)A;F1A<B!,96YG
M96@G.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G
M75LG,C8N-C,S.C4W+C<V-R==(#T@)TIA<VLG.PHD8V]O<F1I;F%T97-;)TER
M86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,C<N,C`P.C8P+C<P,"==(#T@
M)TER86YS:&%H<B<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U
M8FQI8R!O9B==6R<R-RXR,3<Z-38N,S8W)UT@/2`G0F%N9&%R86)B87-S)SL*
M)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S(X
M+CDV-SHU,RXV.#,G72`]("=&87-A)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)
M<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S(X+CDX,SHU,"XX,S,G72`]("="=7-H
M96AR($-I=B`O($%F8B<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!2
M97!U8FQI8R!O9B==6R<R.2XQ,#`Z-3@N-#`P)UT@/2`G0F%M)SL*)&-O;W)D
M:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S(Y+C0V-SHV
M,"XX.#,G72`]("=:86AE9&%N)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA
M;6EC(%)E<'5B;&EC(&]F)UU;)S(Y+C4S,SHU,BXU.#,G72`]("=3:&ER87HG
M.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG
M,S`N,C4P.C4V+CDV-R==(#T@)TME<FUA;B<["B1C;V]R9&EN871E<ULG27)A
M;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S,"XS-C<Z-#@N,C4P)UT@/2`G
M06)A9&%N)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC
M(&]F)UU;)S,P+C0S,SHU,"XW-C<G72`]("='86-H(%-A<F%N($1U($=U;F)A
M9&%N)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F
M)UU;)S,P+C<V-SHT.2XV-C<G72`]("=/;6ED:65H)SL*)&-O;W)D:6YA=&5S
M6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,Q+C$X,SHU,BXV-C<G
M72`]("=!8F%D96@G.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P
M=6)L:6,@;V8G75LG,S$N,S,S.C0X+C8V-R==(#T@)T%H=V%Z)SL*)&-O;W)D
M:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,Q+C,S,SHV
M,2XT.#,G72`]("=:86)O;"<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI
M8R!297!U8FQI8R!O9B==6R<S,2XY,#`Z-30N-#`P)UT@/2`G66%Z9"<["B1C
M;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S,2XY
M.#,Z-#DN,C8W)UT@/2`G36%S:F5D+5-O;&5Y;6%N)SL*)&-O;W)D:6YA=&5S
M6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,R+C,S,SHU,"XX-3`G
M72`]("=3:&%H<F4M2V]R9"<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI
M8R!297!U8FQI8R!O9B==6R<S,BXT-C<Z-3$N-S$W)UT@/2`G17-F86AA;B<[
M"B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S
M,BXX-C<Z-3DN,C`P)UT@/2`G0FER:F%N9"<["B1C;V]R9&EN871E<ULG27)A
M;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S,RXV,#`Z-38N.3$W)UT@/2`G
M5&%B87,G.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@
M;V8G75LG,S,N.3@S.C4Q+C0U,"==(#T@)TMA<VAA;B<["B1C;V]R9&EN871E
M<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S-"XQ,#`Z-#DN-#`P
M)UT@/2`G07)A:R<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U
M8FQI8R!O9B==6R<S-"XR-C<Z-#<N,3$W)UT@/2`G2V5R;6%N<VAA:"<["B1C
M;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S-"XU
M,3<Z-#4N-3@S)UT@/2`G1VAA<W)E+5-H:7)I;B<["B1C;V]R9&EN871E<ULG
M27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S-2XR-C<Z-3DN,C$W)UT@
M/2`G5&]R8F%T+4AE>61A<FEE:"<["B1C;V]R9&EN871E<ULG27)A;BP@27-L
M86UI8R!297!U8FQI8R!O9B==6R<S-2XS,S,Z-#<N,#`P)UT@/2`G4V%N86YD
M86HG.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G
M75LG,S4N-34P.C4S+C,X,R==(#T@)U-E;6YA;B<["B1C;V]R9&EN871E<ULG
M27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S-2XV.#,Z-3$N,S4P)UT@
M/2`G5&5H<F%N+4UE:')A8F%D)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA
M;6EC(%)E<'5B;&EC(&]F)UU;)S,V+C(Q-SHU-RXV-C<G72`]("=386)Z979A
M<B<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==
M6R<S-BXR-3`Z-#8N,C8W)UT@/2`G4V%G:&5Z)SL*)&-O;W)D:6YA=&5S6R=)
M<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,V+C(U,#HU,"XP,#`G72`]
M("=':&%Z=FEN)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B
M;&EC(&]F)UU;)S,V+C(V-SHU.2XV,S,G72`]("=-87-H:&%D)SL*)&-O;W)D
M:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,V+C8X,SHT
M."XT.#,G72`]("=:86YJ86XG.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M
M:6,@4F5P=6)L:6,@;V8G75LG,S8N.#$W.C4T+C0V-R==(#T@)T=O<F=A;B<[
M"B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S
M-BXY,#`Z-3`N-C8W)UT@/2`G4F%M<V%R)SL*)&-O;W)D:6YA=&5S6R=)<F%N
M+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,W+C(P,#HT.2XV,S,G72`]("=2
M87-H="<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O
M9B==6R<S-RXT-C<Z-3<N,S,S)UT@/2`G0F]J;F]U<F0G.PHD8V]O<F1I;F%T
M97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,S<N-3,S.C0U+C`X
M,R==(#T@)T]R=6UI96@G.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@
M4F5P=6)L:6,@;V8G75LG,S@N,#@S.C0V+C(X,R==(#T@)U1A8G)I>B<["B1C
M;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S."XU
M-3`Z-#0N.38W)UT@/2`G2VAO>2<["B1C;V]R9&EN871E<ULG27)A<2==6R<S
M,"XT,3<Z-#<N-C4P)UT@/2`G4VAA:6)A:"`O($)A<W)A:"<["B1C;V]R9&EN
M871E<ULG27)A<2==6R<S,RXR,S,Z-#0N,C,S)UT@/2`G0F%G:&1A9"<["B1C
M;V]R9&EN871E<ULG27)A<2==6R<S-BXS,3<Z-#,N,34P)UT@/2`G36]S=6PG
M.PHD8V]O<F1I;F%T97-;)TER96QA;F0G75LG-3$N.#4P.BTX+C0X,R==(#T@
M)T-O<FL@06ER<&]R="<["B1C;V]R9&EN871E<ULG27)E;&%N9"==6R<U,BXW
M,#`Z+3@N.3$W)UT@/2`G4VAA;FYO;B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S
M6R=)<F5L86YD)UU;)S4S+C,P,#HM-BXT,S,G72`]("=#87-E;65N="!!97)O
M9')O;64G.PHD8V]O<F1I;F%T97-;)TER96QA;F0G75LG-3,N-#,S.BTV+C(U
M,"==(#T@)T1U8FQI;B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=)<W)A96PG
M75LG,CDN-34P.C,T+CDU,"==(#T@)T5I;&%T)SL*)&-O;W)D:6YA=&5S6R=)
M<W)A96PG75LG,S`N,#`P.C,T+C@S,R==(#T@)T]V9&$G.PHD8V]O<F1I;F%T
M97-;)TES<F%E;"==6R<S,2XR,S,Z,S0N-S@S)UT@/2`G0F5E<BU3:&5V82<[
M"B1C;V]R9&EN871E<ULG27-R865L)UU;)S,Q+C@V-SHS-2XR,3<G72`]("=*
M97)U<V%L96T@06ER<&]R="<["B1C;V]R9&EN871E<ULG27-R865L)UU;)S,R
M+C`P,#HS-"XY,#`G72`]("="96XM1W5R:6]N($EN=&5R;F%T:6]N86P@06ER
M<&]R="<["B1C;V]R9&EN871E<ULG27-R865L)UU;)S,R+C@P,#HS-2XP,S,G
M72`]("=39&4M2&%I9F$@2&%I9F$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;
M)S,U+C4P,#HQ,BXV,#`G72`]("=,86UP961U<V$G.PHD8V]O<F1I;F%T97-;
M)TET86QY)UU;)S,V+C8X,SHQ-2XQ,S,G72`]("=#;WIZ;R!3<&%D87)O)SL*
M)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S-BXX,3<Z,3$N.38W)UT@/2`G4&%N
M=&5L;&5R:6$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S,W+C`X,SHQ-"XR
M,3<G72`]("='96QA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S-RXT,#`Z
M,30N.3$W)UT@/2`G0V%T86YI82`O(%-I9V]N96QL82<["B1C;V]R9&EN871E
M<ULG271A;'DG75LG,S<N-#8W.C$U+C`U,"==(#T@)T-A=&%N:6$@+R!&;VYT
M86YA<F]S<V$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S,W+C4V-SHQ-"XR
M.#,G72`]("=%;FYA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S-RXY,3<Z
M,3(N-3`P)UT@/2`G5')A<&%N:2`O($)I<F=I)SL*)&-O;W)D:6YA=&5S6R=)
M=&%L>2==6R<S."XP-C<Z,34N-C4P)UT@/2`G4F5G9VEO($-A;&%B<FEA)SL*
M)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S."XQ,#`Z,3,N,S`P)UT@/2`G4&%L
M97)M;R!";V-C861I9F%L8V\G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S,X
M+C$X,SHQ,RXQ,#`G72`]("=086QE<FUO("\@4'5N=&$@4F%I<VDG.PHD8V]O
M<F1I;F%T97-;)TET86QY)UU;)S,X+C(P,#HQ-2XU-3`G72`]("=-97-S:6YA
M)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S."XW,#`Z,3,N,3@S)UT@/2`G
M57-T:6-A)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S."XY,#`Z,38N,C4P
M)UT@/2`G3&%M97II82!497)M92<["B1C;V]R9&EN871E<ULG271A;'DG75LG
M,SDN,#`P.C$W+C`V-R==(#T@)T-R;W1O;F4G.PHD8V]O<F1I;F%T97-;)TET
M86QY)UU;)S,Y+C$P,#HY+C4Q-R==(#T@)T-A<&\@0V%R8F]N87)A)SL*)&-O
M;W)D:6YA=&5S6R=)=&%L>2==6R<S.2XR-3`Z.2XP-C<G72`]("=#86=L:6%R
M:2`O($5L;6%S)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S.2XS,S,Z,38N
M-#`P)UT@/2`G36]N=&4@4V-U<F\G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;
M)S,Y+C,U,#HX+CDV-R==(#T@)T1E8VEM;VUA;FYU)SL*)&-O;W)D:6YA=&5S
M6R=)=&%L>2==6R<S.2XU,#`Z.2XV,S,G72`]("=#87!O(%,N($QO<F5N>F\G
M.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S,Y+C4X,SHQ-2XX.#,G72`]("="
M;VYI9F%T:2<["B1C;V]R9&EN871E<ULG271A;'DG75LG,SDN-C8W.CDN-#,S
M)UT@/2`G4&5R9&%S9&5F;V=U)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S
M.2XW-3`Z."XT-C<G72`]("=#87!O($9R87-C82<["B1C;V]R9&EN871E<ULG
M271A;'DG75LG,SDN.#$W.C$X+C,U,"==(#T@)U,N($UA<FEA($1I($QE=6-A
M)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S.2XY,S,Z.2XW,3<G72`]("=#
M87!O($)E;&QA=FES=&$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0P+C`Q
M-SHQ-2XR.#,G72`]("=#87!O(%!A;&EN=7)O)SL*)&-O;W)D:6YA=&5S6R=)
M=&%L>2==6R<T,"XP.#,Z,38N,#$W)UT@/2`G3&%T<F]N:6-O)SL*)&-O;W)D
M:6YA=&5S6R=)=&%L>2==6R<T,"XQ,3<Z.2XR-3`G72`]("=&;VYN:2<["B1C
M;V]R9&EN871E<ULG271A;'DG75LG-#`N,C,S.C$X+C$U,"==(#T@)TQE8V-E
M)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,"XT,S,Z,38N.#@S)UT@/2`G
M36%R:6YA($1I($=I;F]S82<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#`N
M-3$W.C$W+C0P,"==(#T@)T=R;W1T86=L:64G.PHD8V]O<F1I;F%T97-;)TET
M86QY)UU;)S0P+C4U,#HQ-"XR,#`G72`]("=#87!R:2<["B1C;V]R9&EN871E
M<ULG271A;'DG75LG-#`N-38W.C@N,38W)UT@/2`G0V%P;R!#86-C:6$G.PHD
M8V]O<F1I;F%T97-;)TET86QY)UU;)S0P+C8S,SHQ-2XX,#`G72`]("=0;W1E
M;GIA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,"XV,S,Z."XR.#,G72`]
M("=!;&=H97)O)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,"XV-3`Z,3<N
M.34P)UT@/2`G0G)I;F1I<VDG.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0P
M+C<V-SHQ-BXY,S,G72`]("=':6]I82!$96P@0V]L;&4G.PHD8V]O<F1I;F%T
M97-;)TET86QY)UU;)S0P+C@U,#HQ-"XS,#`G72`]("=.87!O;&D@+R!#87!O
M9&EC:&EN;R<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#`N.3`P.CDN-3$W
M)UT@/2`G3VQB:6$@+R!#;W-T82!3;65R86QD82<["B1C;V]R9&EN871E<ULG
M271A;'DG75LG-#`N.3$W.C$R+CDU,"==(#T@)U!O;GIA)SL*)&-O;W)D:6YA
M=&5S6R=)=&%L>2==6R<T,2XP-3`Z,30N,#8W)UT@/2`G1W)A>GIA;FES92<[
M"B1C;V]R9&EN871E<ULG271A;'DG75LG-#$N,#4P.C$U+C(S,R==(#T@)U1R
M979I8V\G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0Q+C$S,SHQ-BXW.#,G
M72`]("="87)I("\@4&%L97-E($UA8V-H:64G.PHD8V]O<F1I;F%T97-;)TET
M86QY)UU;)S0Q+C(Q-SHY+C0P,"==(#T@)T=U87)D:6%V96-C:&EA)SL*)&-O
M;W)D:6YA=&5S6R=)=&%L>2==6R<T,2XU,S,Z,34N-S$W)UT@/2`G06UE;F1O
M;&$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0Q+C4U,#HQ,BXY,#`G72`]
M("=,871I;F$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0Q+C4V-SHQ-"XV
M-3`G72`]("=#86UP;V)A<W-O)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T
M,2XV,S,Z,3,N,S`P)UT@/2`G1G)O<VEN;VYE)SL*)&-O;W)D:6YA=&5S6R=)
M=&%L>2==6R<T,2XV-3`Z,3(N-#4P)UT@/2`G4')A=&EC82!$:2!-87)E)SL*
M)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,2XW,#`Z,34N.34P)UT@/2`G36]N
M=&4@4RX@06YG96QO)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,2XW.#,Z
M,3(N-3@S)UT@/2`G4F]M82`O($-I86UP:6YO)SL*)&-O;W)D:6YA=&5S6R=)
M=&%L>2==6R<T,2XX,#`Z,3(N,C,S)UT@/2`G4F]M82!&:75M:6-I;F\G.PHD
M8V]O<F1I;F%T97-;)TET86QY)UU;)S0Q+CDU,#HQ,BXU,#`G72`]("=2;VUA
M("\@57)B92<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#(N,#`P.C$R+C<S
M,R==(#T@)T=U:61O;FEA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,BXP
M,#`Z,34N,#`P)UT@/2`G5&5R;6]L:2<["B1C;V]R9&EN871E<ULG271A;'DG
M75LG-#(N,#,S.C$Q+C@S,R==(#T@)T-I=FET879E8V-H:6$G.PHD8V]O<F1I
M;F%T97-;)TET86QY)UU;)S0R+C`X,SHQ,BXR,3<G72`]("=6:6=N82!$:2!6
M86QL92<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#(N,S@S.C$Q+C$V-R==
M(#T@)TUO;G1E($%R9V5N=&%R:6\G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;
M)S0R+C0Q-SHQ,BXX-3`G72`]("=2:65T:2<["B1C;V]R9&EN871E<ULG271A
M;'DG75LG-#(N-#,S.C$R+C`U,"==(#T@)U9I=&5R8F\G.PHD8V]O<F1I;F%T
M97-;)TET86QY)UU;)S0R+C0S,SHQ-"XR,#`G72`]("=097-C87)A)SL*)&-O
M;W)D:6YA=&5S6R=)=&%L>2==6R<T,BXT-C<Z,3(N.3@S)UT@/2`G36]N=&4@
M5&5R;6EN:6QL;R<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#(N-S,S.C$P
M+C0P,"==(#T@)TTN($-A;&%M:71A)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==
M6R<T,BXW-3`Z,3$N,#8W)UT@/2`G1W)O<W-E=&\G.PHD8V]O<F1I;F%T97-;
M)TET86QY)UU;)S0R+CDP,#HQ,2XW-C<G72`]("=2861I8V]F86YI)SL*)&-O
M;W)D:6YA=&5S6R=)=&%L>2==6R<T,RXP.#,Z,3(N-3`P)UT@/2`G4&5R=6=I
M82<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#,N-#`P.C$P+C@V-R==(#T@
M)U9O;'1E<G)A)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,RXT-C<Z,3$N
M.#4P)UT@/2`G07)E>GIO)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,RXU
M,3<Z,3(N-S,S)UT@/2`G1G)O;G1O;F4G.PHD8V]O<F1I;F%T97-;)TET86QY
M)UU;)S0S+C8Q-SHQ,RXS-C<G72`]("=&86QC;VYA<F$G.PHD8V]O<F1I;F%T
M97-;)TET86QY)UU;)S0S+C8X,SHQ,"XS.#,G72`]("=0:7-A("\@4RX@1VEU
M<W1O)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,RXX,#`Z,3$N,C`P)UT@
M/2`G1FER96YZ92`O(%!E<F5T;VQA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==
M6R<T,RXY-3`Z."XQ-C<G72`]("=#87!O($UE;&4G.PHD8V]O<F1I;F%T97-;
M)TET86QY)UU;)S0T+C`S,SHQ,BXV,3<G72`]("=2:6UI;FDG.PHD8V]O<F1I
M;F%T97-;)TET86QY)UU;)S0T+C`S,SHY+C@S,R==(#T@)TES;VQA($1I(%!A
M;&UA<FEA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-"XP-3`Z."XQ,3<G
M72`]("=!;&)E;F=A)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-"XP.#,Z
M.2XY.#,G72`]("=387)Z86YA("\@3'5N:2<["B1C;V]R9&EN871E<ULG271A
M;'DG75LG-#0N,C`P.C$P+C<P,"==(#T@)TUO;G1E($-I;6]N92<["B1C;V]R
M9&EN871E<ULG271A;'DG75LG-#0N,C`P.C$R+C`V-R==(#T@)T9O<FQI)SL*
M)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-"XR,3<Z,3(N,S`P)UT@/2`G0V5R
M=FEA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-"XR-3`Z-RXX,#`G72`]
M("=-;VYT92!-86QA;F]T=&4G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0T
M+C0Q-SHX+C@U,"==(#T@)T=E;F]V82`O(%-E<W1R:2<["B1C;V]R9&EN871E
M<ULG271A;'DG75LG-#0N-#,S.CDN.3,S)UT@/2`G4&%S<V\@1&5L;&$@0VES
M82<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#0N-#4P.C$R+C,P,"==(#T@
M)U!U;G1A($UA<FEN82<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#0N-3,S
M.C$Q+C,P,"==(#T@)T)O;&]G;F$@+R!";W)G;R!086YI9V%L92<["B1C;V]R
M9&EN871E<ULG271A;'DG75LG-#0N-C,S.C@N.3,S)UT@/2`G4&%S<V\@1&5I
M($=I;W9I)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-"XX,S,Z,3$N-C$W
M)UT@/2`G1F5R<F%R82<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#0N.3$W
M.CDN-S,S)UT@/2`G4&EA8V5N>F$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;
M)S0U+C`S,SHW+C<S,R==(#T@)U1O<FEN;R`O($)R:6,@1&5L;&$@0W)O8V4G
M.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0U+C(Q-SHW+C8U,"==(#T@)U1O
M<FEN;R`O($-A<V5L;&4G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0U+C,X
M,SHQ,"XX-C<G72`]("=697)O;F$@+R!6:6QL869R86YC82<["B1C;V]R9&EN
M871E<ULG271A;'DG75LG-#4N-#$W.C$P+C(X,R==(#T@)T)R97-C:6$@+R!'
M:&5D:2<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#4N-#,S.CDN,C@S)UT@
M/2`G36EL86YO("\@3&EN871E)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T
M-2XU,#`Z,3(N,S,S)UT@/2`G5F5N97II82`O(%1E<W-E<F$G.PHD8V]O<F1I
M;F%T97-;)TET86QY)UU;)S0U+C4Q-SHX+C8V-R==(#T@)TYO=F%R82`O($-A
M;65R:2<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#4N-38W.C$Q+C4Q-R==
M(#T@)U9I8V5N>F$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0U+C8Q-SHX
M+C<S,R==(#T@)TUI;&%N;R`O($UA;'!E;G-A)SL*)&-O;W)D:6YA=&5S6R=)
M=&%L>2==6R<T-2XV-3`Z,3(N,3@S)UT@/2`G5')E=FES;R`O(%,N($%N9V5L
M;R<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#4N-C4P.C$S+C<U,"==(#T@
M)U1R:65S=&4G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0U+C8V-SHY+C<P
M,"==(#T@)T)E<F=A;6\@+R!/<FEO($%L(%-E<FEO)SL*)&-O;W)D:6YA=&5S
M6R=)=&%L>2==6R<T-2XV.#,Z,3(N,3`P)UT@/2`G5')E=FES;R`O($ES=')A
M;F$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0U+C@Q-SHQ,RXT.#,G72`]
M("=2;VYC:&D@1&5I($QE9VEO;F%R:2<["B1C;V]R9&EN871E<ULG271A;'DG
M75LG-#4N.#8W.CDN,#8W)UT@/2`G36]N=&4@0FES8FEN;R<["B1C;V]R9&EN
M871E<ULG271A;'DG75LG-#4N.3,S.C<N-S`P)UT@/2`G4&EA;B!2;W-A)SL*
M)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-2XY.#,Z,3,N,#,S)UT@/2`G561I
M;F4@+R!2:79O;'1O)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-BXP,S,Z
M,3(N-C`P)UT@/2`G079I86YO)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T
M-BXP,S,Z,3(N-C$W)UT@/2`G079I86YO(%5S868G.PHD8V]O<F1I;F%T97-;
M)TET86QY)UU;)S0V+C`S,SHQ,RXQ.#,G72`]("=59&EN92`O($-A;7!O9F]R
M;6ED;R<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#8N,34P.C$Q+C`S,R==
M(#T@)U!A9V%N96QL82<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#8N,S`P
M.C$Q+C<X,R==(#T@)U!A<W-O(%)O;&QE)SL*)&-O;W)D:6YA=&5S6R=)=&%L
M>2==6R<T-BXT-C<Z,3$N,S,S)UT@/2`G0F]L>F%N;R<["B1C;V]R9&EN871E
M<ULG271A;'DG75LG-#8N-3`P.C$S+C4X,R==(#T@)U1A<G9I<VEO)SL*)&-O
M;W)D:6YA=&5S6R=)=&%L>2==6R<T-BXW,S,Z,3(N,C$W)UT@/2`G1&]B8FEA
M8V\G.PHD8V]O<F1I;F%T97-;)TIA;6%I8V$G75LG,3<N.3,S.BTW-BXW.#,G
M72`]("=+:6YG<W1O;B`O($YO<FUA;B!-86YL97DG.PHD8V]O<F1I;F%T97-;
M)TIA;6%I8V$G75LG,3@N-3`P.BTW-RXY,3<G72`]("=-;VYT96=O($)A>2`O
M(%-A;F=S=&5R)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<R-"XS,#`Z,34S
M+CDV-R==(#T@)TUI;F%M:71O<FES:&EM82<["B1C;V]R9&EN871E<ULG2F%P
M86XG75LG,C0N,S,S.C$R-"XQ-C<G72`]("=)<VAI9V%K:6II;6$G.PHD8V]O
M<F1I;F%T97-;)TIA<&%N)UU;)S(T+C0V-SHQ,C(N.3@S)UT@/2`G66]N86=U
M;FD@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,C0N-S@S.C$R
M-2XR.#,G72`]("=-:7EA:V]J:6UA)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==
M6R<R-"XW.#,Z,30Q+C,Q-R==(#T@)TEW;VII;6$G.PHD8V]O<F1I;F%T97-;
M)TIA<&%N)UU;)S(U+C@S,SHQ,S$N,C,S)UT@/2`G36EN86UI9&%I=&]J:6UA
M)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<R-BXQ.#,Z,3(W+C8U,"==(#T@
M)TYA:&$@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,C8N,C8W
M.C$R-RXW-3`G72`]("=&=71E;FUA($UA<FEN92!#;W)P<R!!:7(@1F%C:6QI
M='DG.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S(V+C,P,#HQ,C<N-S8W)UT@
M/2`G2&%M8GD@52X@4RX@07)M>2!!:7)F:65L9"<["B1C;V]R9&EN871E<ULG
M2F%P86XG75LG,C8N,S,S.C$R-BXX,#`G72`]("=+=6UE:FEM82<["B1C;V]R
M9&EN871E<ULG2F%P86XG75LG,C8N,S4P.C$R-RXW-C<G72`]("=+861E;F$@
M06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S(V+C<Q-SHQ,C<N-S@S)UT@
M/2`G265J:6UA($%U>&EL:6%R>2!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG
M75LG,C<N,#@S.C$T,BXQ.#,G72`]("=#:&EC:&EJ:6UA)SL*)&-O;W)D:6YA
M=&5S6R=*87!A;B==6R<R-RXT,S,Z,3(X+C<P,"==(#T@)T]K:6YO97)A8G4G
M.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S(W+C@S,SHQ,C@N.#@S)UT@/2`G
M5&]K=6YO<VAI;6$@27-L86YD)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<R
M."XT,S,Z,3(Y+C<Q-R==(#T@)T%M86UI($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)TIA<&%N)UU;)S,P+C,X,SHQ,S`N-C8W)UT@/2`G66%K=7-H:6UA)SL*
M)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S,"XU-3`Z,3,P+CDU,"==(#T@)U1A
M;F5G87-H:6UA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,Q
M+C,V-SHQ,S`N.#,S)UT@/2`G2V%N;WEA($%B)SL*)&-O;W)D:6YA=&5S6R=*
M87!A;B==6R<S,2XX,#`Z,3,P+C<Q-R==(#T@)TMA9V]S:&EM82!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S,2XX-C<Z,3,Q+C0U,"==(#T@
M)TUI>6%Z86MI($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,R
M+C`X,SHQ,S$N-#4P)UT@/2`G3GEU=&%B87)U($%B)SL*)&-O;W)D:6YA=&5S
M6R=*87!A;B==6R<S,BXV-C<Z,3(X+C@S,R==(#T@)T9U:W5E($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,R+C@S,SHQ,S`N.#4P)UT@/2`G
M2W5M86UO=&\@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S(N
M.3$W.C$R.2XY,3<G72`]("=.86=A<V%K:2!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R=*87!A;B==6R<S,RXQ,3<Z,3,Y+C<X,R==(#T@)TAA8VAI:F]J:6UA
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,S+C$U,#HQ,CDN
M-S$W)UT@/2`G4V%S96)O(%5S;B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG
M,S,N,S$W.C$S,"XT,3<G72`]("=-971A8F%R=2!!8B<["B1C;V]R9&EN871E
M<ULG2F%P86XG75LG,S,N-#@S.C$S,2XW,S,G72`]("=/:71A($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,S+C4S,SHQ,S,N-C8W)UT@/2`G
M2V]C:&D@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S,N-3@S
M.C$S,"XT-3`G72`]("=&=6MU;VMA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;
M)TIA<&%N)UU;)S,S+C8V-SHQ,S4N,S4P)UT@/2`G3F%N:VES:&ER86AA;6$@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S,N-C@S.C$S,2XP
M-3`G72`]("=4<W5I:VD@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,S
M+C<U,#HQ,CDN-S@S)UT@/2`G26MI($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;
M)TIA<&%N)UU;)S,S+C@Q-SHQ,S(N-S`P)UT@/2`G36%T<W5Y86UA($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,S+C@S,SHQ,S`N.34P)UT@
M/2`G2VET86MY=7-H=2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==
M6R<S,RXX.#,Z,3,P+C8U,"==(#T@)T%S:&EY82!!8B<["B1C;V]R9&EN871E
M<ULG2F%P86XG75LG,S,N.3,S.C$S,2XR.#,G72`]("=986UA9W5C:&D@56)E
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,T+C`P,#HQ,S0N
M-C,S)UT@/2`G2V]M871S=6II;6$@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N
M)UU;)S,T+C`S,SHQ,S$N-34P)UT@/2`G2&]F=2!!8B<["B1C;V]R9&EN871E
M<ULG2F%P86XG75LG,S0N,#4P.C$S,2XP-3`G72`]("=/>G5K:2!!8B<["B1C
M;V]R9&EN871E<ULG2F%P86XG75LG,S0N,#8W.C$S.2XU-C<G72`]("=-:7EA
M:V5J:6UA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,T+C$S
M,SHQ,S(N,C,S)UT@/2`G27=A:W5N:2!-87)I;F4@0V]R<',@06ER(%-T871I
M;VXG.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,T+C$S,SHQ,S0N-C$W)UT@
M/2`G5&]K=7-H:6UA($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-"XR
M,3<Z,3,T+C`Q-R==(#T@)U1A:V%M871S=2!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R=*87!A;B==6R<S-"XR.#,Z,3(Y+C,S,R==(#T@)U1S=7-H:6UA($%I
M<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,T+C0Q-SHQ,S4N,C4P
M)UT@/2`G2V%N<V%I($EN=&5R;F%T:6]N86P@06ER<&]R="<["B1C;V]R9&EN
M871E<ULG2F%P86XG75LG,S0N-#,S.C$S,BXY,3<G72`]("=(:7)O<VAI;6$@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S0N-3,S.C$S-BXV
M.#,G72`]("=!:V5N;R!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S0N
M-C`P.C$S-2XV,#`G72`]("=986\@06ER<&]R="<["B1C;V]R9&EN871E<ULG
M2F%P86XG75LG,S0N-C8W.C$S,2XX,#`G72`]("=)=V%M:2!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-"XW-3`Z,3,S+C@U,"==(#T@)T]K
M87EA;6$@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S0N-S4P
M.C$S-RXW,#`G72`]("=(86UA;6%T<W4@06(G.PHD8V]O<F1I;F%T97-;)TIA
M<&%N)UU;)S,T+C<X,SHQ,S4N-#4P)UT@/2`G3W-A:V$@26YT97)N871I;VYA
M;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-"XW.#,Z,3,Y
M+C,V-R==(#T@)T]S:&EM82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A
M;B==6R<S-"XX,3<Z,3,X+C,P,"==(#T@)U-H:7IU:&%M82!!8B<["B1C;V]R
M9&EN871E<ULG2F%P86XG75LG,S0N.3@S.C$S.2XX,S,G72`]("=4871E>6%M
M82!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S4N,C4P.C$S-BXY,S,G
M72`]("=.86=O>6$@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG
M,S4N,C@S.C$S.2XV-C<G72`]("=9;VMO<W5K82!&=V8G.PHD8V]O<F1I;F%T
M97-;)TIA<&%N)UU;)S,U+C,Q-SHQ,S@N.#8W)UT@/2`G1G5J:2!!8B<["B1C
M;V]R9&EN871E<ULG2F%P86XG75LG,S4N,S@S.C$S-BXX-C<G72`]("=':69U
M($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-2XT,#`Z,3,Y+CDQ-R==
M(#T@)TMI<V%R87IU($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-2XT
M,3<Z,3,R+CDP,"==(#T@)TEZ=6UO($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;
M)TIA<&%N)UU;)S,U+C0U,#HQ,SDN-#4P)UT@/2`G071S=6=I(%5N:71E9"!3
M=&%T97,@3F%V86P@06ER(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)TIA<&%N
M)UU;)S,U+C0X,SHQ,S,N,C4P)UT@/2`G36EH;R!!8B<["B1C;V]R9&EN871E
M<ULG2F%P86XG75LG,S4N-3$W.C$S.2XT,#`G72`]("=:86UA($%I<F9I96QD
M)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-2XU,S,Z,3,T+C$V-R==(#T@
M)U1O='1O<FD@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S4N
M-34P.C$S.2XW.#,G72`]("=4;VMY;R!);G1E<FYA=&EO;F%L($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,U+C8S,SHQ,SDN.#4P)UT@/2`G
M5&]K>6\@2&5L:7!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,U+C8V
M-SHQ,SDN-3,S)UT@/2`G0VAO9G4@06ER<&]R="<["B1C;V]R9&EN871E<ULG
M2F%P86XG75LG,S4N-C@S.C$S.2XW-C<G72`]("=4;VMY;R<["B1C;V]R9&EN
M871E<ULG2F%P86XG75LG,S4N-S`P.C$S.2XT,#`G72`]("=486-H:6MA=V$@
M06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,U+C<U,#HQ,SDN,S4P)UT@
M/2`G66]K;W1A($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-2XW-C<Z
M,30P+C,X,R==(#T@)TYE=R!4;VMY;R!);G1E<BU.871I;VYA;"!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-2XX,#`Z,30P+C`Q-R==(#T@
M)U-H:6UO9G5S82!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S4N.#,S
M.C$S.2XT,3<G72`]("=)<G5M82!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG
M75LG,S8N,#,S.C$T,"XR,#`G72`]("=+87-U;6EG875R82!!8B<["B1C;V]R
M9&EN871E<ULG2F%P86XG75LG,S8N,3,S.C$S-BXR,S,G72`]("=&=6MU:2!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-BXQ-C<Z,3,W+CDS
M,R==(#T@)TUA='-U;6]T;R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A
M;B==6R<S-BXQ.#,Z,3,S+C,S,R==(#T@)T]K:2!!:7)P;W)T)SL*)&-O;W)D
M:6YA=&5S6R=*87!A;B==6R<S-BXQ.#,Z,30P+C0Q-R==(#T@)TAY86MU<FD@
M06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,V+C,X,SHQ,S8N-#$W)UT@
M/2`G2V]M871S=2!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S8N-3$W
M.C$S.2XX-C<G72`]("=5='-U;F]M:7EA($%B)SL*)&-O;W)D:6YA=&5S6R=*
M87!A;B==6R<S-BXV-3`Z,3,W+C$X,R==(#T@)U1O>6%M82!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-RXR,S,Z,30P+C0S,R==(#T@)T9U
M:W5S:&EM82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-RXY
M-3`Z,3,Y+C$Q-R==(#T@)TYI:6=A=&$@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG2F%P86XG75LG,S@N,#4P.C$S."XT,3<G72`]("=3861O($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,X+C$S,SHQ-#`N.3$W)UT@/2`G
M4V5N9&%I($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,X+C(S
M,SHQ-#`N.3$W)UT@/2`G2V%S=6UI;F]M92!!8B<["B1C;V]R9&EN871E<ULG
M2F%P86XG75LG,S@N-#`P.C$T,2XR,3<G72`]("=-871S=7-H:6UA($%B)SL*
M)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S."XT,3<Z,30P+C,V-R==(#T@)UEA
M;6%G871A($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,Y+C0S
M,SHQ-#$N,3,S)UT@/2`G2&%N86UA:VD@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG2F%P86XG75LG,SDN-C$W.C$T,"XR,3<G72`]("=!:VET82!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<T,"XU-3`Z,30Q+C0V-R==(#T@
M)TAA8VAI;F]H92!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG-#`N-S`P
M.C$T,2XS.#,G72`]("=-:7-A=V$@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N
M)UU;)S0P+C<S,SHQ-#`N-S`P)UT@/2`G06]M;W)I($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)TIA<&%N)UU;)S0Q+C(S,SHQ-#$N,3,S)UT@/2`G3VUI;F%T
M;R!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG-#$N-S8W.C$T,"XX,3<G
M72`]("=(86MO9&%T92!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==
M6R<T,BXS,3<Z,30P+CDX,R==(#T@)TUU<F]R86XG.PHD8V]O<F1I;F%T97-;
M)TIA<&%N)UU;)S0R+C<S,SHQ-#,N,C$W)UT@/2`G3V)I:&ER;R!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<T,BXX,#`Z,30Q+C8V-R==(#T@
M)T-H:71O<V4@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S0R+C@Q-SHQ
M-#$N-C@S)UT@/2`G0VAI=&]S92!*87!A;F5S92!!:7(@4V5L9B!$969E;G-E
M($9O<F-E)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<T,BXY.#,Z,30T+C0P
M,"==(#T@)TMU<VAI<F\G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S0S+C`S
M,SHQ-#0N,C`P)UT@/2`G2W5S:&ER;R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S
M6R=*87!A;B==6R<T,RXQ,3<Z,30Q+C,X,R==(#T@)U-A<'!O<F\@06(G.PHD
M8V]O<F1I;F%T97-;)TIA<&%N)UU;)S0S+C4V-SHQ-#0N.38W)UT@/2`G3F%K
M87-H:6)E='-U($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S0S
M+C8V-SHQ-#(N-#4P)UT@/2`G07-A:&EK87=A($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)TIA<&%N)UU;)S0S+C@P,#HQ-#(N,S8W)UT@/2`G07-A:&EK87=A
M($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<T,RXX.#,Z,30T+C$V-R==
M(#T@)TUE;6%M8F5T<W4@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG
M75LG-#0N,C4P.C$T,RXU,S,G72`]("=-;VUB971S=2!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R=*87!A;B==6R<T-2XT,#`Z,30Q+C@P,"==(#T@)U=A:VMA
M;F%I($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIO<F1A;B==6R<R.2XV,S,Z
M,S4N,#$W)UT@/2`G07%A8F$@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F]R
M9&%N)UU;)S,P+C$V-SHS-2XW.#,G72`]("=-85PG06XG.PHD8V]O<F1I;F%T
M97-;)TIO<F1A;B==6R<S,2XV-C<Z,S4N.38W)UT@/2`G475E96X@06QI82!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*;W)D86XG75LG,S$N.3@S.C,U+CDX
M,R==(#T@)T%M;6%N($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIO<F1A;B==
M6R<S,BXR,#`Z,S<N,3,S)UT@/2`G2"TU7"=3869A=VDG.PHD8V]O<F1I;F%T
M97-;)TIO<F1A;B==6R<S,BXS-C<Z,S8N,C4P)UT@/2`G36%F<F%Q)SL*)&-O
M;W)D:6YA=&5S6R=*;W)D86XG75LG,S(N-3`P.C,X+C(P,"==(#T@)T@M-%PG
M27)W86ES:&5D)SL*)&-O;W)D:6YA=&5S6R=*;W)D86XG75LG,S(N-34P.C,U
M+C@U,"==(#T@)TER8FED)SL*)&-O;W)D:6YA=&5S6R=+87IA:VAS=&%N)UU;
M)S0R+C,Q-SHV.2XW,#`G72`]("=3:'EM:V5N="<["B1C;V]R9&EN871E<ULG
M2V%Z86MH<W1A;B==6R<T,RXR,S,Z-S8N.3,S)UT@/2`G06QM871Y)SL*)&-O
M;W)D:6YA=&5S6R=+87IA:VAS=&%N)UU;)S0T+C@U,#HV-2XU,#`G72`]("=+
M>GEL+4]R9&$G.PHD8V]O<F1I;F%T97-;)TMA>F%K:'-T86XG75LG-#8N-S@S
M.C8Q+C8U,"==(#T@)T%R86QS:V]E($UO<F4G.PHD8V]O<F1I;F%T97-;)TMA
M>F%K:'-T86XG75LG-3`N,C@S.C4W+C$U,"==(#T@)T%K=&IU8FEN<VLG.PHD
M8V]O<F1I;F%T97-;)TMA>F%K:'-T86XG75LG-3$N,C4P.C4Q+C(X,R==(#T@
M)U5R86QS:R<["B1C;V]R9&EN871E<ULG2V%Z86MS=&%N)UU;)S0Y+C@P,#HW
M,RXQ-3`G72`]("=+87)A9V%N9&$G.PHD8V]O<F1I;F%T97-;)TME;GEA)UU;
M)S`N,#@S.C,W+C8U,"==(#T@)TUE<G4G.PHD8V]O<F1I;F%T97-;)TME;GEA
M)UU;)RTP+C$P,#HS-"XW-3`G72`]("=+:7-U;74G.PHD8V]O<F1I;F%T97-;
M)TME;GEA)UU;)RTP+C(V-SHS-BXQ,#`G72`]("=.86MU<G4G.PHD8V]O<F1I
M;F%T97-;)TME;GEA)UU;)S`N,C@S.C,T+C<X,R==(#T@)TMA:V%M96=A)SL*
M)&-O;W)D:6YA=&5S6R=+96YY82==6R<M,"XS-C<Z,S4N,S4P)UT@/2`G2V5R
M:6-H;R<["B1C;V]R9&EN871E<ULG2V5N>6$G75LG+3`N-#8W.C,Y+C8S,R==
M(#T@)T=A<FES<V$G.PHD8V]O<F1I;F%T97-;)TME;GEA)UU;)RTP+C4P,#HS
M-BXY-C<G72`]("=.>65R:2<["B1C;V]R9&EN871E<ULG2V5N>6$G75LG+3`N
M-3`P.C,W+C0U,"==(#T@)T5M8G4G.PHD8V]O<F1I;F%T97-;)TME;GEA)UU;
M)S`N-3,S.C,U+C(X,R==(#T@)T5L9&]R970G.PHD8V]O<F1I;F%T97-;)TME
M;GEA)UU;)RTP+C8V-SHS-"XW.#,G72`]("=+:7-I:2<["B1C;V]R9&EN871E
M<ULG2V5N>6$G75LG,2XP,3<Z,S4N,#`P)UT@/2`G2VET86QE)SL*)&-O;W)D
M:6YA=&5S6R=+96YY82==6R<M,2XQ,S,Z,S4N.#,S)UT@/2`G3F%R;VLG.PHD
M8V]O<F1I;F%T97-;)TME;GEA)UU;)RTQ+C,P,#HS-BXW-3`G72`]("=.86ER
M;V)I("\@1&%G;W)E='1I)SL*)&-O;W)D:6YA=&5S6R=+96YY82==6R<M,2XS
M,3<Z,S8N.#$W)UT@/2`G3F%I<F]B:2`O(%=I;'-O;B<["B1C;V]R9&EN871E
M<ULG2V5N>6$G75LG+3$N,S$W.C,V+CDS,R==(#T@)TYA:7)O8FD@04-#+T9)
M0R]20T,O3454+T-/32\G.PHD8V]O<F1I;F%T97-;)TME;GEA)UU;)S$N-S4P
M.C0P+C`V-R==(#T@)U=A:FER)SL*)&-O;W)D:6YA=&5S6R=+96YY82==6R<M
M,BXR-C<Z-#`N.#,S)UT@/2`G3&%M=2<["B1C;V]R9&EN871E<ULG2V5N>6$G
M75LG+3(N,C@S.C,W+C@S,R==(#T@)TUA:VEN9'4G.PHD8V]O<F1I;F%T97-;
M)TME;GEA)UU;)S(N,S`P.C,W+CDP,"==(#T@)TUA<G-A8FET)SL*)&-O;W)D
M:6YA=&5S6R=+96YY82==6R<S+C$Q-SHS-2XV,3<G72`]("=,;V1W87(G.PHD
M8V]O<F1I;F%T97-;)TME;GEA)UU;)RTS+C(S,SHT,"XQ,#`G72`]("=-86QI
M;F1I)SL*)&-O;W)D:6YA=&5S6R=+96YY82==6R<M,RXT,#`Z,S@N-38W)UT@
M/2`G5F]I)SL*)&-O;W)D:6YA=&5S6R=+96YY82==6R<S+C4S,SHS.2XP-3`G
M72`]("=-;WEA;&4G.PHD8V]O<F1I;F%T97-;)TME;GEA)UU;)S,N.3,S.C0Q
M+C@V-R==(#T@)TUA;F1E<F$G.PHD8V]O<F1I;F%T97-;)TME;GEA)UU;)RTT
M+C`S,SHS.2XV,3<G72`]("=-;VUB87-A)SL*)&-O;W)D:6YA=&5S6R=+:7)I
M8F%T:2==6R<Q+C,U,#HQ-S(N.3$W)UT@/2`G5&%R87=A)SL*)&-O;W)D:6YA
M=&5S6R=+:7)I8F%T:2==6R<M,2XS-3`Z,3<V+C`P,"==(#T@)T)E<G4G.PHD
M8V]O<F1I;F%T97-;)TMI<FEB871I)UU;)RTR+C8V-SHQ-S8N.#,S)UT@/2`G
M07)O<F%E)SL*)&-O;W)D:6YA=&5S6R=+:7)I8F%T:2==6R<S+C`S,SHQ-S(N
M-S@S)UT@/2`G0G5T87)I=&%R:2<["B1C;V]R9&EN871E<ULG2V]R96$L($1E
M;6]C<F%T:6,@4&5O<&QE7"=S(%)E<'5B;&EC(&]F)UU;)S,Y+C`S,SHQ,C4N
M-S@S)UT@/2`G4'EO;F=Y86YG)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@1&5M
M;V-R871I8R!096]P;&5<)W,@4F5P=6)L:6,@;V8G75LG-#`N-C8W.C$R.2XR
M,#`G72`]("=+:6UC:&%E:R<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B
M;&EC(&]F)UU;)S,S+C(P,#HQ,C8N,C8W)UT@/2`G36]S=6QP;R!!8B<["B1C
M;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,S+C4P,#HQ,C8N
M-3`P)UT@/2`G0VAE:G4@26YT97)N871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D
M:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S0N.#,S.C$R-RXV,3<G
M72`]("=9;W-U($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!297!U
M8FQI8R!O9B==6R<S-2XP.#,Z,3(X+C`X,R==(#T@)U-A8VA<)T]N($%B)SL*
M)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S4N,3$W.C$R
M-BXX,3<G72`]("=+=V%N9VIU($%B)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@
M4F5P=6)L:6,@;V8G75LG,S4N,3@S.C$R."XY,S,G72`]("=0=7-A;B`O($MI
M;6AA92!);G1E<FYA=&EO;F%L($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TMO
M<F5A+"!297!U8FQI8R!O9B==6R<S-2XU-3`Z,3(Y+C,Q-R==(#T@)U5L<V%N
M)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S4N.#@S
M.C$R."XV,3<G72`]("=4865G=2<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E
M<'5B;&EC(&]F)UU;)S,U+CDP,#HQ,C@N-C4P)UT@/2`G5&%E9W4@06(G.PHD
M8V]O<F1I;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S-2XY,3<Z,3(V
M+C8Q-R==(#T@)TMU;G-A;B!!8B<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E
M<'5B;&EC(&]F)UU;)S,U+CDX,SHQ,CDN-#$W)UT@/2`G4&]H86YG($%B)SL*
M)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S8N,S`P.C$R
M-RXT,#`G72`]("=4865J;VXG.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!297!U
M8FQI8R!O9B==6R<S-BXS,S,Z,3(W+C,X,R==(#T@)U1A96IO;B!+;W(M069B
M)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S8N-#`P
M.C$R-RXU,#`G72`]("=3;VYG;74@06(G.PHD8V]O<F1I;F%T97-;)TMO<F5A
M+"!297!U8FQI8R!O9B==6R<S-BXU-3`Z,3(X+C<Q-R==(#T@)T%N9&]N9R<[
M"B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,V+C8S,SHQ
M,C@N,S4P)UT@/2`G665C:&]N($%B)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@
M4F5P=6)L:6,@;V8G75LG,S8N-S`P.C$R-RXU,#`G72`]("=#:&]N9VIU($%B
M)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S8N.3,S
M.C$R-BXT-3`G72`]("=-86YG:6QS86X@06(G.PHD8V]O<F1I;F%T97-;)TMO
M<F5A+"!297!U8FQI8R!O9B==6R<S-BXY,S,Z,3(W+C`P,"==(#T@)U!Y;VYG
M=&%E:R!!8B<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;
M)S,W+C`S,SHQ,C8N-S4P)UT@/2`G2V]O;BU.:2!286YG92<["B1C;V]R9&EN
M871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,W+C`S,SHQ,C<N.#@S)UT@
M/2`G2G5N9R!7;VX@4F]K+4%B)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P
M=6)L:6,@;V8G75LG,S<N,3`P.C$R-RXP,S,G72`]("=/<V%N($%B)SL*)&-O
M;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S<N,C4P.C$R-RXP
M,#`G72`]("=3=7=O;B!!8B<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B
M;&EC(&]F)UU;)S,W+C,S,SHQ,C<N.34P)UT@/2`G5V]N:G4G.PHD8V]O<F1I
M;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S-RXT,S,Z,3(W+C$Q-R==
M(#T@)U-E;W5L($4@06(G.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!297!U8FQI
M8R!O9B==6R<S-RXT,S,Z,3(W+CDU,"==(#T@)TAO96YG<V]N9R!!8B<["B1C
M;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,W+C0V-SHQ,C8N
M-#4P)UT@/2`G26YC:&5O;B!);G1E<FYA=&EO;F%L($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S-RXU,#`Z,3(V+CDS
M,R==(#T@)U-E;W5L("\@66]N9V1U;F=P7"=/(%)O:V%F(%=C)SL*)&-O;W)D
M:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S<N-3`P.C$R.2XQ,S,G
M72`]("=4;VYG:&%E(%)A9&%R(%-I=&4G.PHD8V]O<F1I;F%T97-;)TMO<F5A
M+"!297!U8FQI8R!O9B==6R<S-RXU-3`Z,3(V+C@P,"==(#T@)U-E;W5L("\@
M2VEM<%PG3R!);G1E<FYA=&EO;F%L($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;
M)TMO<F5A+"!297!U8FQI8R!O9B==6R<S-RXU-C<Z,3(V+CDV-R==(#T@)U-E
M;W5L)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S<N
M-S4P.C$R."XY-3`G72`]("=+86YG;G5N9R!!8B<["B1C;V]R9&EN871E<ULG
M2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,W+C@V-SHQ,C<N-S$W)UT@/2`G0VAU
M;F-H;VX@06(G.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==
M6R<S-RXY-C<Z,3(T+C8V-R==(#T@)U!A96YG;GEO;F=D;R!!8B<["B1C;V]R
M9&EN871E<ULG2W5W86ET)UU;)S(Y+C(Q-SHT-RXY.#,G72`]("=+=7=A:70@
M26YT97)N871I;VYA;&%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TQA;R!096]P
M;&5<)W,@1&5M;V-R871I8R!297!U8FQI8R==6R<Q-"XX,#`Z,3`V+C@S,R==
M(#T@)T%T=&]P974G.PHD8V]O<F1I;F%T97-;)TQA;R!096]P;&5<)W,@1&5M
M;V-R871I8R!297!U8FQI8R==6R<Q-2XQ,3<Z,3`U+C$V-R==(#T@)U!A:W-E
M)SL*)&-O;W)D:6YA=&5S6R=,86\@4&5O<&QE7"=S($1E;6]C<F%T:6,@4F5P
M=6)L:6,G75LG,34N-C@S.C$P-BXT,S,G72`]("=387)A=F%N92<["B1C;V]R
M9&EN871E<ULG3&%O(%!E;W!L95PG<R!$96UO8W)A=&EC(%)E<'5B;&EC)UU;
M)S$V+C4U,#HQ,#0N-C4P)UT@/2`G4V%V86YN86MH970G.PHD8V]O<F1I;F%T
M97-;)TQA;R!096]P;&5<)W,@1&5M;V-R871I8R!297!U8FQI8R==6R<Q-RXS
M.#,Z,3`T+C8U,"==(#T@)U1H86MH96LG.PHD8V]O<F1I;F%T97-;)TQA;R!0
M96]P;&5<)W,@1&5M;V-R871I8R!297!U8FQI8R==6R<Q-RXY-3`Z,3`R+C4V
M-R==(#T@)U9I96YT:6%N92<["B1C;V]R9&EN871E<ULG3&%O(%!E;W!L95PG
M<R!$96UO8W)A=&EC(%)E<'5B;&EC)UU;)S$Y+C(S,SHQ,#$N-S,S)UT@/2`G
M4V%Y86)O=7)Y)SL*)&-O;W)D:6YA=&5S6R=,86\@4&5O<&QE7"=S($1E;6]C
M<F%T:6,@4F5P=6)L:6,G75LG,3DN.#@S.C$P,BXQ,S,G72`]("=,=6%N9RU0
M<F%B86YG)SL*)&-O;W)D:6YA=&5S6R=,871V:6$G75LG-38N.38W.C(T+C`U
M,"==(#T@)U)I9V$G.PHD8V]O<F1I;F%T97-;)TQA='9I82==6R<U-RXT,#`Z
M,C$N-3,S)UT@/2`G5F5N='-P:6QS)SL*)&-O;W)D:6YA=&5S6R=,96)A;F]N
M)UU;)S,S+C@Q-SHS-2XT.#,G72`]("="97ER;W5T:"!!97)O<&]R="<["B1C
M;V]R9&EN871E<ULG3&5S;W1H;R==6R<M,CDN-#4P.C(W+C4U,"==(#T@)TUA
M<V5R=2U-:6$G.PHD8V]O<F1I;F%T97-;)TQI8F5R:6$G75LG-BXR-3`Z+3$P
M+C,U,"==(#T@)T=R86YD($)A<W-A+"!2;V)E<G1S($9I96QD)SL*)&-O;W)D
M:6YA=&5S6R=,:6)Y86X@07)A8B!*86UA:&ER:7EA)UU;)S(T+C(Q-SHR,RXS
M,#`G72`]("=+=69R82<["B1C;V]R9&EN871E<ULG3&EB>6%N($%R86(@2F%M
M86AI<FEY82==6R<R-2XQ,S,Z,3`N,34P)UT@/2`G1VAA="<["B1C;V]R9&EN
M871E<ULG3&EB>6%N($%R86(@2F%M86AI<FEY82==6R<R-RXP,3<Z,30N-#4P
M)UT@/2`G4V5B:&$G.PHD8V]O<F1I;F%T97-;)TQI8GEA;B!!<F%B($IA;6%H
M:7)I>6$G75LG,S`N,3,S.CDN-3`P)UT@/2`G1VAA9&%M97,G.PHD8V]O<F1I
M;F%T97-;)TQI8GEA;B!!<F%B($IA;6%H:7)I>6$G75LG,S(N,3`P.C(P+C(V
M-R==(#T@)T)E;FEN82<["B1C;V]R9&EN871E<ULG3&EB>6%N($%R86(@2F%M
M86AI<FEY82==6R<S,BXV-C<Z,3,N,34P)UT@/2`G5')I<&]L:2!);G1E<BU.
M871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=,:71H=6%N:6$G75LG
M-30N-C,S.C(U+C$P,"==(#T@)U9I;&YI=7,G.PHD8V]O<F1I;F%T97-;)TQU
M>&5M8F]U<F<G75LG-#DN-C$W.C8N,C$W)UT@/2`G3'5X96UB;W5R9R`O($QU
M>&5M8F]U<F<G.PHD8V]O<F1I;F%T97-;)TUA8V%U)UU;)S(R+C$V-SHQ,3,N
M-38W)UT@/2`G5&%I<&$G.PHD8V]O<F1I;F%T97-;)TUA8V5D;VYI82P@=&AE
M($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B==6R<T,2XQ,3<Z,C`N.#`P
M)UT@/2`G3VAR:60G.PHD8V]O<F1I;F%T97-;)TUA8V5D;VYI82P@=&AE($9O
M<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B==6R<T,2XY-C<Z,C$N-C4P)UT@
M/2`G4VMO<&IE+5!E=')O=F5C)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R
M)UU;)RTQ,BXS-3`Z-#DN,S`P)UT@/2`G1&EE9V\M4W5A<F5Z)SL*)&-O;W)D
M:6YA=&5S6R=-861A9V%S8V%R)UU;)RTQ,RXS,3<Z-#@N,S$W)UT@/2`G1F%S
M8V5N92!.;W-S:2U"92<["B1C;V]R9&EN871E<ULG36%D86=A<V-A<B==6R<M
M,3,N,S8W.C4P+C`P,"==(#T@)U9O:&5M87(G.PHD8V]O<F1I;F%T97-;)TUA
M9&%G87-C87(G75LG+3$T+C(X,SHU,"XQ-C<G72`]("=386UB879A)SL*)&-O
M;W)D:6YA=&5S6R=-861A9V%S8V%R)UU;)RTQ-"XV,S,Z-#<N-S8W)UT@/2`G
M06YA;&%L879A)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R)UU;)RTQ-"XV
M-3`Z-#DN-C$W)UT@/2`G06YD87!A)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S
M8V%R)UU;)RTQ-"XX.#,Z-3`N,C4P)UT@/2`G06YT86QA:&$G.PHD8V]O<F1I
M;F%T97-;)TUA9&%G87-C87(G75LG+3$U+C8V-SHT-BXS-3`G72`]("=-86IU
M;F=A)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R)UU;)RTQ-BXW-3`Z-#0N
M-#@S)UT@/2`G0F5S86QA;7!Y)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R
M)UU;)RTQ-RXP.#,Z-#DN.#$W)UT@/2`G4V%I;G1E+4UA<FEE($%E<F]D<F]M
M92<["B1C;V]R9&EN871E<ULG36%D86=A<V-A<B==6R<M,3@N,#4P.C0T+C`S
M,R==(#T@)TUA:6YT:7)A;F\G.PHD8V]O<F1I;F%T97-;)TUA9&%G87-C87(G
M75LG+3$X+C$Q-SHT.2XT,#`G72`]("=486UA=&%V92<["B1C;V]R9&EN871E
M<ULG36%D86=A<V-A<B==6R<M,3@N.#`P.C0W+C0X,R==(#T@)T%N=&%N86YA
M<FEV;R`O($EV871O)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R)UU;)RTQ
M.2XX,3<Z-#<N,#8W)UT@/2`G06YT<VER86)E)SL*)&-O;W)D:6YA=&5S6R=-
M861A9V%S8V%R)UU;)RTQ.2XX,S,Z-#@N.#`P)UT@/2`G36%H86YO<F\G.PHD
M8V]O<F1I;F%T97-;)TUA9&%G87-C87(G75LG+3(P+C(X,SHT-"XS,3<G72`]
M("=-;W)O;F1A=F$G.PHD8V]O<F1I;F%T97-;)TUA9&%G87-C87(G75LG+3(Q
M+C(P,#HT."XS-C<G72`]("=-86YA;FIA<GDG.PHD8V]O<F1I;F%T97-;)TUA
M9&%G87-C87(G75LG+3(Q+C0U,#HT-RXQ,#`G72`]("=&:6%N87)A;G1S;V$G
M.PHD8V]O<F1I;F%T97-;)TUA9&%G87-C87(G75LG+3(Q+C<U,#HT,RXS-C<G
M72`]("=-;W)O;6)E)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R)UU;)RTR
M,BXU-3`Z-#4N-#`P)UT@/2`G4F%N;VAI<F$G.PHD8V]O<F1I;F%T97-;)TUA
M9&%G87-C87(G75LG+3(R+C@P,#HT-RXX,S,G72`]("=&87)A9F%N9V%N82<[
M"B1C;V]R9&EN871E<ULG36%D86=A<V-A<B==6R<M,C,N,S@S.C0S+C<S,R==
M(#T@)U1U;&5A<B<["B1C;V]R9&EN871E<ULG36%D86=A<V-A<B==6R<M,C4N
M,#,S.C0V+CDU,"==(#T@)T9O<G0M1&%U<&AI;B<["B1C;V]R9&EN871E<ULG
M36%L87=I)UU;)RTQ,2XT-3`Z,S0N,#$W)UT@/2`G37IU>G4G.PHD8V]O<F1I
M;F%T97-;)TUA;&%W:2==6R<M,3$N.#@S.C,S+C8Q-R==(#T@)TUZ:6UB82<[
M"B1C;V]R9&EN871E<ULG36%L87=I)UU;)RTQ,BXY,3<Z,S0N,C8W)UT@/2`G
M3FMH;W1A($MO=&$G.PHD8V]O<F1I;F%T97-;)TUA;&%W:2==6R<M,3,N-S4P
M.C,T+C4X,R==(#T@)U-A;&EM82<["B1C;V]R9&EN871E<ULG36%L87=I)UU;
M)RTQ,RXW.#,Z,S,N-S8W)UT@/2`G3&EL;VYG=V4@26YT97)N871I;VYA;"!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=-86QA=VDG75LG+3$T+C`X,SHS-"XY
M,3<G72`]("=-;VYK97D@0F%Y)SL*)&-O;W)D:6YA=&5S6R=-86QA=VDG75LG
M+3$T+C,Q-SHS-"XR-C<G72`]("=$961Z82<["B1C;V]R9&EN871E<ULG36%L
M87=I)UU;)RTQ-"XT,S,Z,S4N,C4P)UT@/2`G36%N9V]C:&DG.PHD8V]O<F1I
M;F%T97-;)TUA;&%W:2==6R<M,34N-C@S.C,T+CDV-R==(#T@)T-H:6QE:V$G
M.PHD8V]O<F1I;F%T97-;)TUA;&%W:2==6R<M.2XW,#`Z,S,N,C8W)UT@/2`G
M0VAI=&EP82<["B1C;V]R9&EN871E<ULG36%L87=I)UU;)RTY+CDU,#HS,RXX
M.#,G72`]("=+87)O;F=A)SL*)&-O;W)D:6YA=&5S6R=-86QA>7-I82==6R<Q
M+C0X,SHQ,3`N,S,S)UT@/2`G2W5C:&EN9R<["B1C;V]R9&EN871E<ULG36%L
M87ES:6$G75LG,2XV,S,Z,3`S+C8V-R==(#T@)TIO:&]R92!":&%R=2`O(%-E
M;F%I)SL*)&-O;W)D:6YA=&5S6R=-86QA>7-I82==6R<R+C(V-SHQ,#(N,C4P
M)UT@/2`G36%L86-C82<["B1C;V]R9&EN871E<ULG36%L87ES:6$G75LG,BXS
M,S,Z,3$Q+C@S,R==(#T@)U-I8G4G.PHD8V]O<F1I;F%T97-;)TUA;&%Y<VEA
M)UU;)S,N,3$W.C$P,2XU-3`G72`]("=+=6%L82!,=6UP=7(@+R!3=6)A;F<G
M.PHD8V]O<F1I;F%T97-;)TUA;&%Y<VEA)UU;)S,N,C`P.C$Q,RXP,S,G72`]
M("=":6YT=6QU)SL*)&-O;W)D:6YA=&5S6R=-86QA>7-I82==6R<S+C8Q-SHQ
M,#,N,C$W)UT@/2`G2W5A;G1A;B<["B1C;V]R9&EN871E<ULG36%L87ES:6$G
M75LG-"XR,3<Z,3`P+C<P,"==(#T@)U-I=&EA=V%N)SL*)&-O;W)D:6YA=&5S
M6R=-86QA>7-I82==6R<T+C(V-SHQ,3<N.#@S)UT@/2`G5&%W874G.PHD8V]O
M<F1I;F%T97-;)TUA;&%Y<VEA)UU;)S0N,S,S.C$Q,RXY.#,G72`]("=-:7)I
M)SL*)&-O;W)D:6YA=&5S6R=-86QA>7-I82==6R<U+C,P,#HQ,#`N,C8W)UT@
M/2`G4&5N86YG("\@0F%Y86X@3&5P87,G.PHD8V]O<F1I;F%T97-;)TUA;&%Y
M<VEA)UU;)S4N,S`P.C$Q-2XR-3`G72`]("=,86)U86XG.PHD8V]O<F1I;F%T
M97-;)TUA;&%Y<VEA)UU;)S4N.3`P.C$Q."XP-C<G72`]("=386YD86MA;B<[
M"B1C;V]R9&EN871E<ULG36%L87ES:6$G75LG-2XY,S,Z,3$V+C`U,"==(#T@
M)TMO=&$@2VEN86)A;'4G.PHD8V]O<F1I;F%T97-;)TUA;&%Y<VEA)UU;)S8N
M,38W.C$P,BXR.#,G72`]("=+;W1A($)H87)U)SL*)&-O;W)D:6YA=&5S6R=-
M86QA>7-I82==6R<V+C,S,SHY.2XW,S,G72`]("=,86YG:V%W:2<["B1C;V]R
M9&EN871E<ULG36%L87ES:6$G75LG-BXY,3<Z,3$V+C@S,R==(#T@)TMU9&%T
M)SL*)&-O;W)D:6YA=&5S6R=-86QD:79E<R==6R<M,"XV.#,Z-S,N,34P)UT@
M/2`G1V%N)SL*)&-O;W)D:6YA=&5S6R=-86QD:79E<R==6R<T+C(P,#HW,RXU
M,S,G72`]("=-86QE)SL*)&-O;W)D:6YA=&5S6R=-86QI)UU;)S$Q+C,U,#HM
M-2XV.#,G72`]("=3:6MA<W-O)SL*)&-O;W)D:6YA=&5S6R=-86QI)UU;)S$Q
M+C0Q-SHM-RXU,#`G72`]("=";W5G;W5N:2<["B1C;V]R9&EN871E<ULG36%L
M:2==6R<Q,BXS.#,Z+34N-#8W)UT@/2`G2V]U=&EA;&$G.PHD8V]O<F1I;F%T
M97-;)TUA;&DG75LG,3(N-3,S.BTW+CDU,"==(#T@)T)A;6%K;R`O(%-E;F]U
M)SL*)&-O;W)D:6YA=&5S6R=-86QI)UU;)S$R+C@U,#HM,3$N,C,S)UT@/2`G
M2V5N:65B82<["B1C;V]R9&EN871E<ULG36%L:2==6R<Q,RXP-C<Z+3DN-#8W
M)UT@/2`G2VET82<["B1C;V]R9&EN871E<ULG36%L:2==6R<Q,RXS,S,Z+30N
M.#,S)UT@/2`G4V%N)SL*)&-O;W)D:6YA=&5S6R=-86QI)UU;)S$S+C0P,#HM
M-BXQ-3`G72`]("=396=O=2<["B1C;V]R9&EN871E<ULG36%L:2==6R<Q-"XT
M,S,Z+3$Q+C0S,R==(#T@)TMA>65S)SL*)&-O;W)D:6YA=&5S6R=-86QI)UU;
M)S$T+C4Q-SHM-"XQ,#`G72`]("=-;W!T:2<["B1C;V]R9&EN871E<ULG36%L
M:2==6R<Q-2XQ-C<Z+3<N,C@S)UT@/2`G3F%R82<["B1C;V]R9&EN871E<ULG
M36%L:2==6R<Q-2XR,S,Z+3DN,S4P)UT@/2`G3FEO<F\@1'4@4V%H96PG.PHD
M8V]O<F1I;F%T97-;)TUA;&DG75LG,34N,S,S.BTQ+C8X,R==(#T@)TAO;6)O
M<FDG.PHD8V]O<F1I;F%T97-;)TUA;&DG75LG,34N.#8W.C(N,C$W)UT@/2`G
M365N86MA)SL*)&-O;W)D:6YA=&5S6R=-86QI)UU;)S$V+C(V-SHM,"XP-3`G
M72`]("='86\G.PHD8V]O<F1I;F%T97-;)TUA;&DG75LG,38N-S$W.BTS+C`P
M,"==(#T@)U1O;6)O=6-T;W4G.PHD8V]O<F1I;F%T97-;)TUA;&DG75LG,3@N
M-#,S.C$N,S4P)UT@/2`G2VED86PG.PHD8V]O<F1I;F%T97-;)TUA;&DG75LG
M,C`N,C`P.C`N.3@S)UT@/2`G5&5S<V%L:70G.PHD8V]O<F1I;F%T97-;)TUA
M;'1A)UU;)S,U+C@U,#HQ-"XT.#,G72`]("=,=7%A)SL*)&-O;W)D:6YA=&5S
M6R=-87)S:&%L;"!)<VQA;F1S)UU;)S<N,#8W.C$W,2XR.#,G72`]("=-86IU
M<F\@071O;&PL($UA<G-H86QL($ES;&%N9',@26YT+B!!:7)P+B<["B1C;V]R
M9&EN871E<ULG36%R<VAA;&P@27-L86YD<R==6R<X+C<Q-SHQ-C<N-S,S)UT@
M/2`G2W=A:F%L96EN+"!"=6-H;VQZ($%!1BA+=V%J86QE:6X@2TU2*2A!5$],
M*2!!:7)P+B<["B1C;V]R9&EN871E<ULG36%R=&EN:7%U92==6R<Q-"XV,#`Z
M+38Q+C`P,"==(#T@)TQE($QA;65N=&EN)SL*)&-O;W)D:6YA=&5S6R=-875R
M:71A;FEA)UU;)S$V+C$U,#HM,3,N-3$W)UT@/2`G2V%E9&DG.PHD8V]O<F1I
M;F%T97-;)TUA=7)I=&%N:6$G75LG,38N-3`P.BTQ-2XX,3<G72`]("=2;W-S
M;R<["B1C;V]R9&EN871E<ULG36%U<FET86YI82==6R<Q-BXV,#`Z+3<N,C8W
M)UT@/2`G3F5M82<["B1C;V]R9&EN871E<ULG36%U<FET86YI82==6R<Q-BXV
M,S,Z+3$Q+C0P,"==(#T@)TMI9F9A)SL*)&-O;W)D:6YA=&5S6R=-875R:71A
M;FEA)UU;)S$V+C<P,#HM.2XV,#`G72`]("=!:6]U;B!%;"!!=')O=7-S)SL*
M)&-O;W)D:6YA=&5S6R=-875R:71A;FEA)UU;)S$W+C4S,SHM,30N-C@S)UT@
M/2`G0F]U=&EL:6UI="<["B1C;V]R9&EN871E<ULG36%U<FET86YI82==6R<Q
M."XQ,#`Z+3$U+CDU,"==(#T@)TYO=6%K8VAO='0G.PHD8V]O<F1I;F%T97-;
M)TUA=7)I=&%N:6$G75LG,3@N-38W.BTQ,2XT,S,G72`]("=4:61J:6MJ82<[
M"B1C;V]R9&EN871E<ULG36%U<FET86YI82==6R<Q.2XW-3`Z+3$T+C,V-R==
M(#T@)T%K:F]U:G0G.PHD8V]O<F1I;F%T97-;)TUA=7)I=&%N:6$G75LG,C`N
M-3$W.BTQ,RXP-C<G72`]("=!=&%R)SL*)&-O;W)D:6YA=&5S6R=-875R:71A
M;FEA)UU;)S(P+CDS,SHM,3<N,#,S)UT@/2`G3F]U861H:6)O=2<["B1C;V]R
M9&EN871E<ULG36%U<FET86YI82==6R<R-2XR,S,Z+3$Q+C8Q-R==(#T@)T)I
M<B!-;V=H<F5I;B<["B1C;V]R9&EN871E<ULG36%U<FET:75S)UU;)RTQ.2XV
M.#,Z-C,N-#$W)UT@/2`G4F]D<FEG=65S)SL*)&-O;W)D:6YA=&5S6R=-875R
M:71I=7,G75LG+3(P+C0S,SHU-RXV-C<G72`]("=0;&%I<V%N8V4@36%U<FET
M:75S)SL*)&-O;W)D:6YA=&5S6R=-97AI8V\G75LG,38N-S4P.BTY,RXQ,3<G
M72`]("=4=7AT;&$@1W5T:65R<F5Z+"!#:&ES+B<["B1C;V]R9&EN871E<ULG
M365X:6-O)UU;)S$X+C0X,SHM.#@N,S`P)UT@/2`G0VAE='5M86PL(%$N(%)O
M;R<["B1C;V]R9&EN871E<ULG365X:6-O)UU;)S$X+C@X,SHM.3DN,C,S)UT@
M/2`G0W5E<FYA=F%C82P@36]R+B<["B1C;V]R9&EN871E<ULG365X:6-O)UU;
M)S$Y+C`U,#HM.3@N,38W)UT@/2`G4'5E8FQA+"!0=64N)SL*)&-O;W)D:6YA
M=&5S6R=-97AI8V\G75LG,3DN,C8W.BTQ,#,N-3@S)UT@/2`G0V]L:6UA)SL*
M)&-O;W)D:6YA=&5S6R=-97AI8V\G75LG,3DN.#4P.BTY,"XU-3`G72`]("=#
M86UP96-H92P@0V%M<"XG.PHD8V]O<F1I;F%T97-;)TUE>&EC;R==6R<R,"XP
M.#,Z+3DX+C,V-R==(#T@)U1U;&%N8VEN9V\G.PHD8V]O<F1I;F%T97-;)TUE
M>&EC;R==6R<R,"XV,#`Z+3$P,"XS.#,G72`]("=1=65R971A<F\L(%%R;RXG
M.PHD8V]O<F1I;F%T97-;)TUE>&EC;R==6R<R,"XY,S,Z+3@Y+C8U,"==(#T@
M)TUE<FED82`O(&QI8R!-86YU96P@0W)E8V5N8VEO)SL*)&-O;W)D:6YA=&5S
M6R=-97AI8V\G75LG,C$N-3$W.BTQ,#0N.3`P)UT@/2`G5&5P:6,L($YA>2XG
M.PHD8V]O<F1I;F%T97-;)TUE>&EC;R==6R<R,2XX.#,Z+3$P,BXS,#`G72`]
M("=!9W5A<V-A;&EE;G1E<RP@06=S+B<["B1C;V]R9&EN871E<ULG365X:6-O
M)UU;)S(R+C$U,#HM,3`P+CDX,R==(#T@)U-A;B!,=6ES(%!O=&]S:2P@4RX@
M3"X@4"XG.PHD8V]O<F1I;F%T97-;)TUE>&EC;R==6R<R-"XX,3<Z+3$P-RXT
M,#`G72`]("=#=6QI86-A;BP@4VEN+B<["B1C;V]R9&EN871E<ULG365X:6-O
M)UU;)S(U+C0U,#HM,3`P+CDX,R==(#T@)U-A;'1I;&QO+"!#;V%H+B<["B1C
M;V]R9&EN871E<ULG365X:6-O)UU;)S(U+C4S,SHM,3`S+C0U,"==(#T@)U1O
M<G)E;VXL($-O86@N)SL*)&-O;W)D:6YA=&5S6R=-97AI8V\G75LG,C4N.#8W
M.BTQ,#`N,C,S)UT@/2`G065R;W`N($EN=&5R;F%C:6]N86P@36]N=&5R<F5Y
M+"!.+B!,+B<["B1C;V]R9&EN871E<ULG365X:6-O)UU;)S(V+C`Q-SHM,3$Q
M+C,U,"==(#T@)TQO<F5T;RP@0BX@0RX@4RXG.PHD8V]O<F1I;F%T97-;)TUE
M>&EC;R==6R<R-BXX.#,Z+3$P,2XT,3<G72`]("=-;VYC;&]V82P@0V]A:"XG
M.PHD8V]O<F1I;F%T97-;)TUE>&EC;R==6R<R-RXS,3<Z+3$Q,BXS,#`G72`]
M("=386YT82!2;W-A;&EA+"!"+B!#+B!3+B<["B1C;V]R9&EN871E<ULG365X
M:6-O)UU;)S(X+C<P,#HM,3`P+C4Q-R==(#T@)U!I961R87,@3F5G<F%S+"!#
M;V%H+B<["B1C;V]R9&EN871E<ULG365X:6-O)UU;)S(Y+C`V-SHM,3$P+CDU
M,"==(#T@)TAE<FUO<VEL;&\L(%-O;BXG.PHD8V]O<F1I;F%T97-;)TUI8W)O
M;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8G75LG-2XS-3`Z,38R+CDU,"==
M(#T@)TMO<W)A92!#87)O;&EN97,@+R!6)SL*)&-O;W)D:6YA=&5S6R=-:6-R
M;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F)UU;)S4N,S4P.C$V,BXY-3`G
M72`]("=+;W-R864@27-L86YD+"!+;W-R864@06ER<&]R="<["B1C;V]R9&EN
M871E<ULG36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B==6R<V+CDX
M,SHQ-3@N,C`P)UT@/2`G4&]H;G!E:2!)<VQA;F0L(%!O:&YP96D@26YT+B!!
M:7)P+B<["B1C;V]R9&EN871E<ULG36EC<F]N97-I82P@1F5D97)A=&5D(%-T
M871E<R!O9B==6R<W+C0V-SHQ-3$N.#4P)UT@/2`G5V5N;R!)<VQA;F0L($-H
M=75K($EN="X@06ER<"XG.PHD8V]O<F1I;F%T97-;)TUI8W)O;F5S:6$L($9E
M9&5R871E9"!3=&%T97,@;V8G75LG.2XT.#,Z,3,X+C`X,R==(#T@)UEA<"!)
M<VQA;F0L(%EA<"!);G0N($%I<G`N)SL*)&-O;W)D:6YA=&5S6R=-;VQD;W9A
M+"!297!U8FQI8R!O9B==6R<T-RXP,3<Z,C@N.3@S)UT@/2`G2VES:6YE=B<[
M"B1C;V]R9&EN871E<ULG36]R;V-C;R==6R<R."XT-3`Z+3$Q+C$U,"==(#T@
M)U1A;BU486XG.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G75LG,CDN,S8W.BTQ
M,"XQ.#,G72`]("=3:61I($EF;FDG.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G
M75LG,S`N,S,S.BTY+C0P,"==(#T@)T%G861I<B!!;"!-87-S:7)A)SL*)&-O
M;W)D:6YA=&5S6R=-;W)O8V-O)UU;)S,P+C,X,SHM.2XU-C<G72`]("=!9V%D
M:7(G.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G75LG,S`N.3,S.BTV+CDP,"==
M(#T@)T]U87)Z87IA=&4G.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G75LG,S$N
M-3$W.BTY+C<X,R==(#T@)T5S<V%O=6ER82<["B1C;V]R9&EN871E<ULG36]R
M;V-C;R==6R<S,2XV,3<Z+3@N,#,S)UT@/2`G36%R<F%K96-H)SL*)&-O;W)D
M:6YA=&5S6R=-;W)O8V-O)UU;)S,Q+CDS,SHM-"XT,#`G72`]("=%<G)A8VAI
M9&EA)SL*)&-O;W)D:6YA=&5S6R=-;W)O8V-O)UU;)S,R+C(X,SHM.2XR,S,G
M72`]("=3869I)SL*)&-O;W)D:6YA=&5S6R=-;W)O8V-O)UU;)S,S+C,V-SHM
M-RXU.#,G72`]("=.;W5A<W-E=7(G.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G
M75LG,S,N-3`P.BTU+C$V-R==(#T@)TEF<F%N92<["B1C;V]R9&EN871E<ULG
M36]R;V-C;R==6R<S,RXU-C<Z+3<N-C8W)UT@/2`G0V%S86)L86YC82<["B1C
M;V]R9&EN871E<ULG36]R;V-C;R==6R<S,RXX.#,Z+34N-3,S)UT@/2`G365K
M;F5S)SL*)&-O;W)D:6YA=&5S6R=-;W)O8V-O)UU;)S,S+CDS,SHM-"XY.#,G
M72`]("=&97,M4V%I<R<["B1C;V]R9&EN871E<ULG36]R;V-C;R==6R<S-"XP
M-3`Z+38N-S8W)UT@/2`G4F%B870M4V%L92<["B1C;V]R9&EN871E<ULG36]R
M;V-C;R==6R<S-"XR,3<Z+30N,#`P)UT@/2`G5&%Z82<["B1C;V]R9&EN871E
M<ULG36]R;V-C;R==6R<S-"XS,#`Z+38N-C`P)UT@/2`G2V5N:71R82<["B1C
M;V]R9&EN871E<ULG36]R;V-C;R==6R<S-"XW.#,Z+3$N.3,S)UT@/2`G3W5J
M9&$G.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G75LG,S4N,34P.BTR+CDQ-R==
M(#T@)TYA9&]R)SL*)&-O;W)D:6YA=&5S6R=-;W)O8V-O)UU;)S,U+C$X,SHM
M,RXX-3`G72`]("=!;"!(;V-E:6UA)SL*)&-O;W)D:6YA=&5S6R=-;W)O8V-O
M)UU;)S,U+C4X,SHM-2XS,S,G72`]("=4971U86X@+R!386YI82!286UE;"<[
M"B1C;V]R9&EN871E<ULG36]R;V-C;R==6R<S-2XW,S,Z+34N.3`P)UT@/2`G
M5&%N9V5R($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG36]Z86UB:7%U92==
M6R<M,3$N,S4P.C0P+C,V-R==(#T@)TUO8VEM8F]A($1A(%!R86EA)SL*)&-O
M;W)D:6YA=&5S6R=-;WIA;6)I<75E)UU;)RTQ,BXY.#,Z-#`N-3,S)UT@/2`G
M4&5M8F$G.PHD8V]O<F1I;F%T97-;)TUO>F%M8FEQ=64G75LG+3$S+C,P,#HS
M-2XR,S,G72`]("=,:6-H:6YG82<["B1C;V]R9&EN871E<ULG36]Z86UB:7%U
M92==6R<M,30N.#$W.C,V+C4S,R==(#T@)T-U86UB82<["B1C;V]R9&EN871E
M<ULG36]Z86UB:7%U92==6R<M,34N,#,S.C0P+C8V-R==(#T@)TQU;6)O)SL*
M)&-O;W)D:6YA=&5S6R=-;WIA;6)I<75E)UU;)RTQ-2XQ,#`Z,SDN,C@S)UT@
M/2`G3F%M<'5L82<["B1C;V]R9&EN871E<ULG36]Z86UB:7%U92==6R<M,38N
M,3@S.C,S+C4X,R==(#T@)U1E=&4G.PHD8V]O<F1I;F%T97-;)TUO>F%M8FEQ
M=64G75LG+3$W+C@X,SHS-BXX.#,G72`]("=1=65L:6UA;F4G.PHD8V]O<F1I
M;F%T97-;)TUO>F%M8FEQ=64G75LG+3$Y+C$Q-SHS,RXT-C<G72`]("=#:&EM
M;VEO)SL*)&-O;W)D:6YA=&5S6R=-;WIA;6)I<75E)UU;)RTQ.2XX,#`Z,S0N
M.3`P)UT@/2`G0F5I<F$G.PHD8V]O<F1I;F%T97-;)TUO>F%M8FEQ=64G75LG
M+3(R+C`P,#HS-2XS,3<G72`]("=6:6QA;F-U;&]S)SL*)&-O;W)D:6YA=&5S
M6R=-;WIA;6)I<75E)UU;)RTR,RXX-C<Z,S4N,S@S)UT@/2`G26YH86UB86YE
M)SL*)&-O;W)D:6YA=&5S6R=-;WIA;6)I<75E)UU;)RTR-2XP-3`Z,S,N-C,S
M)UT@/2`G6&%I(%AA:2<["B1C;V]R9&EN871E<ULG36]Z86UB:7%U92==6R<M
M,C4N.3$W.C,R+C4V-R==(#T@)TUA<'5T;R`O($UA=F%L86YE)SL*)&-O;W)D
M:6YA=&5S6R=->6%N;6%R)UU;)S$R+C0S,SHY."XV,#`G72`]("=-97)G=6DG
M.PHD8V]O<F1I;F%T97-;)TUY86YM87(G75LG,30N,3`P.CDX+C(Q-R==(#T@
M)T1A=V5I)SL*)&-O;W)D:6YA=&5S6R=->6%N;6%R)UU;)S$T+C$Q-SHY,RXS
M-C<G72`]("=#;V-O($ES;&%N9"<["B1C;V]R9&EN871E<ULG37EA;FUA<B==
M6R<Q-BXU,#`Z.3<N-C$W)UT@/2`G36]U;&UE:6XG.PHD8V]O<F1I;F%T97-;
M)TUY86YM87(G75LG,38N-S4P.CDW+C8V-R==(#T@)TAP82U!;B<["B1C;V]R
M9&EN871E<ULG37EA;FUA<B==6R<Q-BXW-C<Z.30N-S8W)UT@/2`G4&%T:&5I
M;B<["B1C;V]R9&EN871E<ULG37EA;FUA<B==6R<Q-BXW-C<Z.38N,38W)UT@
M/2`G66%N9V]N)SL*)&-O;W)D:6YA=&5S6R=->6%N;6%R)UU;)S$V+CDP,#HY
M-BXQ.#,G72`]("=-:6YG86QA9&]N)SL*)&-O;W)D:6YA=&5S6R=->6%N;6%R
M)UU;)S$X+C0V-SHY-"XS-3`G72`]("=386YD;W=A>2<["B1C;V]R9&EN871E
M<ULG37EA;FUA<B==6R<Q."XX,#`Z.34N,C$W)UT@/2`G4')O;64G.PHD8V]O
M<F1I;F%T97-;)TUY86YM87(G75LG,3DN-#$W.CDS+C4U,"==(#T@)TMY875K
M<'EU)SL*)&-O;W)D:6YA=&5S6R=->6%N;6%R)UU;)S(P+C$S,SHY,BXX.#,G
M72`]("=3:71T=V4G.PHD8V]O<F1I;F%T97-;)TUY86YM87(G75LG,C`N.#,S
M.CDU+C@S,R==(#T@)TUE:6MT:6QA)SL*)&-O;W)D:6YA=&5S6R=->6%N;6%R
M)UU;)S(Q+C,P,#HY.2XV,3<G72`]("=+96YG='5N9R<["B1C;V]R9&EN871E
M<ULG37EA;FUA<B==6R<R,2XY.#,Z.38N,3`P)UT@/2`G36%N9&%L87DG.PHD
M8V]O<F1I;F%T97-;)TUY86YM87(G75LG,C(N.3,S.CDW+C<U,"==(#T@)TQA
M<VAI;R<["B1C;V]R9&EN871E<ULG37EA;FUA<B==6R<R-"XR-C<Z.3<N,C`P
M)UT@/2`G0FAA;6\G.PHD8V]O<F1I;F%T97-;)TUY86YM87(G75LG,C0N.#8W
M.CDT+CDQ-R==(#T@)TAO;6%L:6XG.PHD8V]O<F1I;F%T97-;)TUY86YM87(G
M75LG,C4N,S8W.CDW+C0P,"==(#T@)TUY:71K>6EN82<["B1C;V]R9&EN871E
M<ULG37EA;FUA<B==6R<R-RXS,S,Z.3<N-#$W)UT@/2`G4'5T86\G.PHD8V]O
M<F1I;F%T97-;)TYA;6EB:6$G75LG+3$W+CDQ-SHQ.2XW-C<G72`]("=2=6YD
M=2<["B1C;V]R9&EN871E<ULG3F%M:6)I82==6R<M,3DN-C`P.C$X+C$Q-R==
M(#T@)T=R;V]T9F]N=&5I;B<["B1C;V]R9&EN871E<ULG3F%M:6)I82==6R<M
M,C(N-#8W.C$X+CDV-R==(#T@)T=O8F%B:7,G.PHD8V]O<F1I;F%T97-;)TYA
M;6EB:6$G75LG+3(R+C0X,SHQ-RXT-C<G72`]("=*+B!'+B!3=')I:F1O;2<[
M"B1C;V]R9&EN871E<ULG3F%M:6)I82==6R<M,C8N-3,S.C$X+C$Q-R==(#T@
M)TME971M86YS:&]O<"<["B1C;V]R9&EN871E<ULG3F%U<G4G75LG+3`N-3,S
M.C$V-BXY,3<G72`]("=.875R=2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=.
M97!A;"==6R<R-BXT.#,Z.#<N,C8W)UT@/2`G0FER871N86=A<B!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=.97!A;"==6R<R-RXQ-C<Z.#0N.3@S)UT@/2`G
M4VEM<F$@06ER<&]R="<["B1C;V]R9&EN871E<ULG3F5P86PG75LG,C<N,S4P
M.C@W+C8V-R==(#T@)U1A<&QE:G5N9R<["B1C;V]R9&EN871E<ULG3F5P86PG
M75LG,C<N-3$W.C@S+C0U,"==(#T@)T)H86ER87=A($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)TYE<&%L)UU;)S(W+C<P,#HX-2XS-C<G72`]("=+871H;6%N
M9'4@06ER<&]R="<["B1C;V]R9&EN871E<ULG3F5P86PG75LG,C@N,C$W.C@T
M+C`P,"==(#T@)U!O:VAA<F$@06ER<&]R="<["B1C;V]R9&EN871E<ULG3F5P
M86PG75LG,C@N-C`P.C@Q+C8Q-R==(#T@)U-U<FMH970G.PHD8V]O<F1I;F%T
M97-;)TYE<&%L)UU;)S(Y+C(X,SHX,BXQ-C<G72`]("=*=6UL82<["B1C;V]R
M9&EN871E<ULG3F5T:&5R;&%N9',@06YT:6QL97,G75LG,3(N,34P.BTV."XR
M.#,G72`]("=&;&%M:6YG;R!!:7)P;W)T+"!";VYA:7)E)SL*)&-O;W)D:6YA
M=&5S6R=.971H97)L86YD<R!!;G1I;&QE<R==6R<Q,BXR,#`Z+38X+CDV-R==
M(#T@)TAA=&\@06ER<&]R="P@0W5R86-A;R<["B1C;V]R9&EN871E<ULG3F5T
M:&5R;&%N9',@06YT:6QL97,G75LG,3<N-#@S.BTV,BXY.#,G72`]("=2;V]S
M979E;'0@06ER<&]R="!386EN="!%=7-T871I=7,G.PHD8V]O<F1I;F%T97-;
M)TYE=&AE<FQA;F1S($%N=&EL;&5S)UU;)S$X+C`U,#HM-C,N,3$W)UT@/2`G
M2G5L:6%N82!!:7)P;W)T+"!386EN="!-86%R=&5N)SL*)&-O;W)D:6YA=&5S
M6R=.971H97)L86YD<R==6R<U,"XY,3<Z-2XW.#,G72`]("=-86%S=')I8VAT
M($%I<G!O<G0@6G5I9"!,:6UB=7)G)SL*)&-O;W)D:6YA=&5S6R=.971H97)L
M86YD<R==6R<U,2XT-3`Z-"XS,S,G72`]("=7;V5N<V1R96-H="<["B1C;V]R
M9&EN871E<ULG3F5T:&5R;&%N9',G75LG-3$N-#4P.C4N-#$W)UT@/2`G16EN
M9&AO=F5N)SL*)&-O;W)D:6YA=&5S6R=.971H97)L86YD<R==6R<U,2XU-C<Z
M-"XY,S,G72`]("=':6QZ92U2:6IE;B<["B1C;V]R9&EN871E<ULG3F5T:&5R
M;&%N9',G75LG-3$N-C4P.C4N-S`P)UT@/2`G5F]L:V5L)SL*)&-O;W)D:6YA
M=&5S6R=.971H97)L86YD<R==6R<U,2XY-3`Z-"XT-3`G72`]("=2;W1T97)D
M86T@06ER<&]R="!:97-T:65N:&]V96XG.PHD8V]O<F1I;F%T97-;)TYE=&AE
M<FQA;F1S)UU;)S4R+C`V-SHU+C@X,R==(#T@)T1E96QE;B<["B1C;V]R9&EN
M871E<ULG3F5T:&5R;&%N9',G75LG-3(N,3`P.C4N,3@S)UT@/2`G1&4@0FEL
M="<["B1C;V]R9&EN871E<ULG3F5T:&5R;&%N9',G75LG-3(N,3,S.C4N,C@S
M)UT@/2`G4V]E<W1E<F)E<F<G.PHD8V]O<F1I;F%T97-;)TYE=&AE<FQA;F1S
M)UU;)S4R+C$X,SHT+C0Q-R==(#T@)U9A;&ME;F)U<F<G.PHD8V]O<F1I;F%T
M97-;)TYE=&AE<FQA;F1S)UU;)S4R+C(V-SHV+CDP,"==(#T@)U1W96YT:&4G
M.PHD8V]O<F1I;F%T97-;)TYE=&AE<FQA;F1S)UU;)S4R+C,P,#HT+C<V-R==
M(#T@)T%M<W1E<F1A;2!!:7)P;W)T(%-C:&EP:&]L)SL*)&-O;W)D:6YA=&5S
M6R=.971H97)L86YD<R==6R<U,BXT-3`Z-2XU,3<G72`]("=,96QY<W1A9"<[
M"B1C;V]R9&EN871E<ULG3F5T:&5R;&%N9',G75LG-3(N.3$W.C0N-S@S)UT@
M/2`G1&4@2V]O>2<["B1C;V]R9&EN871E<ULG3F5T:&5R;&%N9',G75LG-3,N
M,3,S.C8N-3@S)UT@/2`G1W)O;FEN9V5N($%I<G!O<G0@165L9&4G.PHD8V]O
M<F1I;F%T97-;)TYE=&AE<FQA;F1S)UU;)S4S+C(Q-SHU+C<V-R==(#T@)TQE
M975W87)D96XG.PHD8V]O<F1I;F%T97-;)TYE=&AE<FQA;F1S)UU;)S4S+C(U
M,#HT+CDQ-R==(#T@)U9L:65L86YD)SL*)&-O;W)D:6YA=&5S6R=.97<@0V%L
M961O;FEA)UU;)RTR,"XU-C<Z,38T+C(X,R==(#T@)TMO=6UA8R!.;&QE+4-A
M;&5D;VYI92<["B1C;V]R9&EN871E<ULG3F5W($-A;&5D;VYI82==6R<M,C`N
M-C4P.C$V-BXU.#,G72`]("=/=6QO=7`@26QE($]U=F5A)SL*)&-O;W)D:6YA
M=&5S6R=.97<@0V%L961O;FEA)UU;)RTR,"XW-C<Z,38W+C(S,R==(#T@)T]U
M86YA:&%M($EL92!,:69O=2<["B1C;V]R9&EN871E<ULG3F5W($-A;&5D;VYI
M82==6R<M,C$N-#@S.C$V."XP,S,G72`]("=,82!2;V-H92!);&4@36%R92<[
M"B1C;V]R9&EN871E<ULG3F5W($-A;&5D;VYI82==6R<M,C(N,#$W.C$V-BXR
M,3<G72`]("=,82!4;VYT;W5T82!.;&QE+4-A;&5D;VYI92<["B1C;V]R9&EN
M871E<ULG3F5W($-A;&5D;VYI82==6R<M,C(N,C8W.C$V-BXT-3`G72`]("=.
M;W5M96$@3FQL92U#86QE9&]N:64G.PHD8V]O<F1I;F%T97-;)TYE=R!#86QE
M9&]N:6$G75LG+3(R+C8P,#HQ-C<N-#4P)UT@/2`G36]U92!);&4@1&5S(%!I
M;G,G.PHD8V]O<F1I;F%T97-;)TYE=R!:96%L86YD)UU;)S$N.3@S.BTQ-3<N
M-#@S)UT@/2`G0VAR:7-T;6%S("\@0V%S<VED>2<["B1C;V]R9&EN871E<ULG
M3F5W(%IE86QA;F0G75LG+3(Y+C(U,#HM,3<W+CDQ-R==(#T@)U)A;W5L($ES
M;&%N9"P@2V5R;6%D96,@27-L86YD)SL*)&-O;W)D:6YA=&5S6R=.97<@6F5A
M;&%N9"==6R<S+C@U,#HM,34Y+C,V-R==(#T@)T9A;FYI;F<@27-L86YD)SL*
M)&-O;W)D:6YA=&5S6R=.97<@6F5A;&%N9"==6R<M,S8N-S@S.C$W-"XV,S,G
M72`]("=7:&5N=6%P86DG.PHD8V]O<F1I;F%T97-;)TYE=R!:96%L86YD)UU;
M)RTS-RXP,3<Z,3<T+C@P,"==(#T@)T%U8VML86YD($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)TYE=R!:96%L86YD)UU;)RTS-RXV-C<Z,3<V+C(P,"==(#T@
M)U1A=7)A;F=A($%E<F]D<F]M92!!=W,G.PHD8V]O<F1I;F%T97-;)TYE=R!:
M96%L86YD)UU;)RTS."XQ,3<Z,3<V+C,Q-R==(#T@)U)O=&]R=6$@065R;V1R
M;VUE)SL*)&-O;W)D:6YA=&5S6R=.97<@6F5A;&%N9"==6R<M,S@N-C8W.C$W
M-RXY.#,G72`]("=':7-B;W)N92!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;
M)TYE=R!:96%L86YD)UU;)RTS.2XP,3<Z,3<T+C$X,R==(#T@)TYE=R!0;'EM
M;W5T:"!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)TYE=R!:96%L86YD)UU;
M)RTT,"XR,#`Z,3<U+C,V-R==(#T@)T]H86ME82<["B1C;V]R9&EN871E<ULG
M3F5W(%IE86QA;F0G75LG+30P+CDP,#HQ-S0N.3@S)UT@/2`G4&%R87!A<F%U
M;74@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=.97<@6F5A;&%N9"==6R<M
M-#$N,S,S.C$W-"XX,#`G72`]("=796QL:6YG=&]N($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)TYE=R!:96%L86YD)UU;)RTT,BXT,3<Z,3<S+C<P,"==(#T@
M)TMA:6MO=7)A)SL*)&-O;W)D:6YA=&5S6R=.97<@6F5A;&%N9"==6R<M-#(N
M-S$W.C$W,"XY.#,G72`]("=(;VMI=&EK82!!97)O9')O;64G.PHD8V]O<F1I
M;F%T97-;)TYE=R!:96%L86YD)UU;)RTT,RXT.#,Z,3<R+C4U,"==(#T@)T-H
M<FES=&-H=7)C:"<["B1C;V]R9&EN871E<ULG3F5W(%IE86QA;F0G75LG+30S
M+CDU,#HM,3<V+C4V-R==(#T@)T-H871H86T@27-L86YD)SL*)&-O;W)D:6YA
M=&5S6R=.97<@6F5A;&%N9"==6R<M-#4N.3,S.C$W,"XR,#`G72`]("=$=6YE
M9&EN($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG3F5W(%IE86QA;F0G75LG
M+30V+C<P,#HQ-C@N-34P)UT@/2`G26YV97)C87)G:6QL($%E<F]D<F]M92<[
M"B1C;V]R9&EN871E<ULG3FEC87)A9W5A)UU;)S$Q+C0Q-SHM.#4N.#,S)UT@
M/2`G4FEV87,G.PHD8V]O<F1I;F%T97-;)TYI8V%R86=U82==6R<Q,BXP,#`Z
M+3@V+C<V-R==(#T@)T)L=65F:65L9',G.PHD8V]O<F1I;F%T97-;)TYI8V%R
M86=U82==6R<Q,BXQ,#`Z+3@U+C,V-R==(#T@)TIU:6=A;'!A)SL*)&-O;W)D
M:6YA=&5S6R=.:6-A<F%G=6$G75LG,3(N,34P.BTX-BXQ-C<G72`]("=-86YA
M9W5A($$N($,N(%-A;F1I;F\G.PHD8V]O<F1I;F%T97-;)TYI8V%R86=U82==
M6R<Q,BXV,S,Z+3@W+C$S,R==(#T@)T-H:6YA;F1E9V$G.PHD8V]O<F1I;F%T
M97-;)TYI8V%R86=U82==6R<Q,RXP.#,Z+3@U+CDX,R==(#T@)TII;F]T96=A
M)SL*)&-O;W)D:6YA=&5S6R=.:6-A<F%G=6$G75LG,30N,#4P.BTX,RXS-C<G
M72`]("=0=65R=&\@0V%B97IA<R<["B1C;V]R9&EN871E<ULG3FEG97(G75LG
M,3$N.#@S.C,N-#4P)UT@/2`G1V%Y82<["B1C;V]R9&EN871E<ULG3FEG97(G
M75LG,3,N,C,S.C$Q+CDX,R==(#T@)TUA:6YE+5-O<F]A)SL*)&-O;W)D:6YA
M=&5S6R=.:6=E<B==6R<Q,RXT,3<Z,3(N-S@S)UT@/2`G1&EF9F$G.PHD8V]O
M<F1I;F%T97-;)TYI9V5R)UU;)S$S+C0V-SHW+C`X,R==(#T@)TUA<F%D:2<[
M"B1C;V]R9&EN871E<ULG3FEG97(G75LG,3,N-#@S.C(N,38W)UT@/2`G3FEA
M;65Y+4%E<F\G.PHD8V]O<F1I;F%T97-;)TYI9V5R)UU;)S$S+C<X,SHX+CDX
M,R==(#T@)UII;F1E<B<["B1C;V]R9&EN871E<ULG3FEG97(G75LG,3,N.#`P
M.C4N,C4P)UT@/2`G0FER;FDM3EPG2V]N;FDG.PHD8V]O<F1I;F%T97-;)TYI
M9V5R)UU;)S$S+CDX,SHQ,"XS,#`G72`]("=';W5R92<["B1C;V]R9&EN871E
M<ULG3FEG97(G75LG,30N,C`P.C$N-#4P)UT@/2`G5&EL;&%B97)Y)SL*)&-O
M;W)D:6YA=&5S6R=.:6=E<B==6R<Q-"XY,#`Z-2XR-3`G72`]("=486AO=6$G
M.PHD8V]O<F1I;F%T97-;)TYI9V5R)UU;)S$V+CDV-SHW+CDX,R==(#T@)T%G
M861E>B<["B1C;V]R9&EN871E<ULG3FEG97(G75LG,3@N-C@S.C$R+CDQ-R==
M(#T@)T)I;&UA)SL*)&-O;W)D:6YA=&5S6R=.:6=E<FEA)UU;)S$P+C8P,#HW
M+C0U,"==(#T@)TMA9'5N82<["B1C;V]R9&EN871E<ULG3FEG97)I82==6R<Q
M,2XQ,S,Z-RXV.#,G72`]("=:87)I82<["B1C;V]R9&EN871E<ULG3FEG97)I
M82==6R<Q,2XX-3`Z,3,N,#@S)UT@/2`G36%I9'5G=7)I)SL*)&-O;W)D:6YA
M=&5S6R=.:6=E<FEA)UU;)S$R+C`U,#HX+C4S,R==(#T@)TMA;F\G.PHD8V]O
M<F1I;F%T97-;)TYI9V5R:6$G75LG,3(N,38W.C8N-S`P)UT@/2`G1W5S874G
M.PHD8V]O<F1I;F%T97-;)TYI9V5R:6$G75LG,3,N,#$W.C4N,C4P)UT@/2`G
M4V]K;W1O)SL*)&-O;W)D:6YA=&5S6R=.:6=E<FEA)UU;)S0N.#4P.C<N,#$W
M)UT@/2`G4&]R="!(87)C;W5R="<["B1C;V]R9&EN871E<ULG3FEG97)I82==
M6R<T+CDV-SHX+C,U,"==(#T@)T-A;&%B87(G.PHD8V]O<F1I;F%T97-;)TYI
M9V5R:6$G75LG-BXT-C<Z-RXU-3`G72`]("=%;G5G=2<["B1C;V]R9&EN871E
M<ULG3FEG97)I82==6R<V+C4X,SHS+C,S,R==(#T@)TQA9V]S("\@26ME:F$G
M.PHD8V]O<F1I;F%T97-;)TYI9V5R:6$G75LG-RXT,S,Z,RXY,#`G72`]("=)
M8F%D86XG.PHD8V]O<F1I;F%T97-;)TYI9V5R:6$G75LG-RXV.#,Z."XV,3<G
M72`]("=-86MU<F1I)SL*)&-O;W)D:6YA=&5S6R=.:6=E<FEA)UU;)S<N-S@S
M.C0N-#@S)UT@/2`G3W-H;V=B;R<["B1C;V]R9&EN871E<ULG3FEG97)I82==
M6R<X+C0X,SHT+C4X,R==(#T@)TEL;W)I;B<["B1C;V]R9&EN871E<ULG3FEG
M97)I82==6R<Y+C$P,#HV+C`Q-R==(#T@)T)I9&$G.PHD8V]O<F1I;F%T97-;
M)TYI9V5R:6$G75LG.2XR,S,Z,3(N-#8W)UT@/2`G66]L82<["B1C;V]R9&EN
M871E<ULG3FEG97)I82==6R<Y+C@V-SHX+CDP,"==(#T@)TIO<R<["B1C;V]R
M9&EN871E<ULG3F]R=V%Y)UU;)S4X+C$P,#HV+C8S,R==(#T@)TQI<W1A($9L
M>7!L87-S)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-3@N,C`P.C@N,#@S
M)UT@/2`G2W)I<W1I86YS86YD("\@2VIE=FEK)SL*)&-O;W)D:6YA=&5S6R=.
M;W)W87DG75LG-3@N.#@S.C4N-C,S)UT@/2`G4W1A=F%N9V5R("\@4V]L82<[
M"B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S4Y+C$X,SHY+C4V-R==(#T@)U-K
M:65N+4=E:71E<GEG9V5N)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-3DN
M,C`P.C$P+C(V-R==(#T@)U1O<G`G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==
M6R<U.2XS-3`Z-2XR,3<G72`]("=(875G97-U;F0@+R!+87)M;WDG.PHD8V]O
M<F1I;F%T97-;)TYO<G=A>2==6R<U.2XS.#,Z,3`N-S@S)UT@/2`G4GEG9V4G
M.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<U.2XY,#`Z,3`N-C,S)UT@/2`G
M3W-L;R`O($9O<FYE8G4G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V,"XR
M,#`Z,3$N,#@S)UT@/2`G3W-L;R`O($=A<F1E<FUO96XG.PHD8V]O<F1I;F%T
M97-;)TYO<G=A>2==6R<V,"XR.#,Z-2XR,S,G72`]("="97)G96X@+R!&;&5S
M;&%N9"<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8P+C8U,#HV+C4P,"==
M(#T@)U9O<W,M0F\G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V,2XP,#`Z
M.2XS,#`G72`]("=&86=E<FYE<R!,96ER:6XG.PHD8V]O<F1I;F%T97-;)TYO
M<G=A>2==6R<V,2XQ-3`Z-RXQ,S,G72`]("=3;V=N9&%L("\@2&%U:V%S96XG
M.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V,2XU.#,Z-2XP,S,G72`]("=&
M;&]R;R<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8Q+C@S,SHV+C$Q-R==
M(#T@)U-A;F1A;F4@+R!!;F1A)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG
M-C(N,3@S.C8N,#8W)UT@/2`G3W)S=&$M5F]L9&$@+R!(;W9D96XG.PHD8V]O
M<F1I;F%T97-;)TYO<G=A>2==6R<V,BXU-C<Z-BXQ,3<G72`]("=!;&5S=6YD
M("\@5FEG<F$G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V,BXU.#,Z,3$N
M,S4P)UT@/2`G4F]R;W,@3'5F=&AA=FXG.PHD8V]O<F1I;F%T97-;)TYO<G=A
M>2==6R<V,BXW-3`Z-RXR-C<G72`]("=-;VQD92`O($%R;R<["B1C;V]R9&EN
M871E<ULG3F]R=V%Y)UU;)S8S+C$Q-SHW+C@S,R==(#T@)TMR:7-T:6%N<W5N
M9"`O($MV97)N8F5R9V5T)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-C,N
M-#8W.C$P+CDS,R==(#T@)U1R;VYD:&5I;2`O(%9A97)N97,G.PHD8V]O<F1I
M;F%T97-;)TYO<G=A>2==6R<V,RXW,#`Z.2XV,#`G72`]("=/<FQA;F0@26EI
M)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-C0N-#8W.C$Q+C4X,R==(#T@
M)TYA;7-O<R!,=69T:&%V;B<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8T
M+C@S,SHQ,2XQ-3`G72`]("=2;W)V:6L@+R!2>75M)SL*)&-O;W)D:6YA=&5S
M6R=.;W)W87DG75LG-C4N-#8W.C$R+C(Q-R==(#T@)T)R;VYN;WES=6YD("\@
M0G)O;FYO>2<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8U+C@P,#HQ,RXQ
M,S,G72`]("=-;W-J;V5N($MJ865R<W1A9"<["B1C;V]R9&EN871E<ULG3F]R
M=V%Y)UU;)S8U+CDV-SHQ,BXT-C<G72`]("=386YD;F5S<VIO96X@+R!3=&]K
M:V$G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V-BXS-C<Z,30N,S`P)UT@
M/2`G36\@22!286YA("\@4F]S<W9O;&PG.PHD8V]O<F1I;F%T97-;)TYO<G=A
M>2==6R<V-RXR-C<Z,30N,S8W)UT@/2`G0F]D;R!6:2<["B1C;V]R9&EN871E
M<ULG3F]R=V%Y)UU;)S8W+C4Q-SHQ,BXQ,#`G72`]("=2;W-T($9L>7!L87-S
M)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-C@N,34P.C$S+C8Q-R==(#T@
M)TQE:VYE<R<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8X+C(U,#HQ-"XV
M-C<G72`]("=3=F]L=F%E<B`O($AE;&QE)SL*)&-O;W)D:6YA=&5S6R=.;W)W
M87DG75LG-C@N-#8W.C$W+C4P,"==(#T@)TYA<G9I:R!):6DG.PHD8V]O<F1I
M;F%T97-;)TYO<G=A>2==6R<V."XU,3<Z,38N-C@S)UT@/2`G179E;F5S)SL*
M)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-C@N-3@S.C$U+C`Q-R==(#T@)U-T
M;W)K;6%R:VYE<R`O(%-K86=E;B<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;
M)S8Y+C`P,#HR,RXP,S,G72`]("=+875T;VME:6YO)SL*)&-O;W)D:6YA=&5S
M6R=.;W)W87DG75LG-CDN,#8W.C$X+C4S,R==(#T@)T)A<F1U9F]S<R<["B1C
M;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8Y+C,P,#HQ-BXQ-3`G72`]("=!;F1O
M>6$G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V.2XV.#,Z,3@N.3$W)UT@
M/2`G5')O;7-O("\@3&%N9VYE<R<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;
M)S8Y+C<S,SHR.2XY,#`G72`]("=+:7)K96YE<R!,=69T:&%V;B<["B1C;V]R
M9&EN871E<ULG3F]R=V%Y)UU;)S8Y+C<X,SHR,"XY-C<G72`]("=3;W)K:F]S
M96XG.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V.2XY.#,Z,C,N,S8W)UT@
M/2`G06QT82!,=69T:&%V;B<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S<P
M+C`V-SHR-"XY.#,G72`]("="86YA:R<["B1C;V]R9&EN871E<ULG3F]R=V%Y
M)UU;)S<P+C`V-SHR.2XX-3`G72`]("=6861S;R<["B1C;V]R9&EN871E<ULG
M3F]R=V%Y)UU;)S<P+C,U,#HS,2XP-3`G72`]("=3=F%R=&YE<R<["B1C;V]R
M9&EN871E<ULG3F]R=V%Y)UU;)S<P+C8V-SHR,RXV-C<G72`]("=(86UM97)F
M97-T)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-S`N.#8W.C(Y+C`S,R==
M(#T@)T)E<FQE=F%G)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-S`N.3,S
M.BTX+C8V-R==(#T@)TIA;B!-87EE;B<["B1C;V]R9&EN871E<ULG3F]R=V%Y
M)UU;)S<Q+C`Q-SHR-2XY.#,G72`]("=(;VYN:6YG<W9A9R`O(%9A;&%N)SL*
M)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-S$N,#,S.C(W+C@S,R==(#T@)TUE
M:&%M;B<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S<T+C4Q-SHQ.2XP,3<G
M72`]("=":F]R;F]Y82<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S<V+C4P
M,#HR-2XP-C<G72`]("=(;W!E;B<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;
M)S<X+C(U,#HQ-2XT-C<G72`]("=3=F%L8F%R9"!,=69T:&%V;B<["B1C;V]R
M9&EN871E<ULG3F]R=V%Y)UU;)S<X+CDQ-SHQ,2XY,S,G72`]("=.>2U!;&5S
M=6YD($EI)SL*)&-O;W)D:6YA=&5S6R=/;6%N)UU;)S$W+C`S,SHU-"XP.#,G
M72`]("=386QA;&%H)SL*)&-O;W)D:6YA=&5S6R=/;6%N)UU;)S$W+C8V-SHU
M-"XP,S,G72`]("=4:'5M<F%I="<["B1C;V]R9&EN871E<ULG3VUA;B==6R<R
M,"XV-C<Z-3@N.3`P)UT@/2`G36%S:7)A:"<["B1C;V]R9&EN871E<ULG3VUA
M;B==6R<R,BXS-3`Z-38N-#@S)UT@/2`G1F%H=60G.PHD8V]O<F1I;F%T97-;
M)T]M86XG75LG,C(N-3,S.C4Y+C0X,R==(#T@)U-U<B<["B1C;V]R9&EN871E
M<ULG3VUA;B==6R<R,RXP-C<Z-3<N-C4P)UT@/2`G4V%I<2<["B1C;V]R9&EN
M871E<ULG3VUA;B==6R<R,RXU.#,Z-3@N,C@S)UT@/2`G4V5E8BP@26YT97)N
M871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=/;6%N)UU;)S(T+C(S
M,SHU-2XW.#,G72`]("="=7)A:6UI)SL*)&-O;W)D:6YA=&5S6R=/;6%N)UU;
M)S(T+C0V-SHU-BXV,S,G72`]("=3;VAA<B!-86II<R<["B1C;V]R9&EN871E
M<ULG3VUA;B==6R<R-BXR,3<Z-38N,C,S)UT@/2`G2VAA<W-A8B<["B1C;V]R
M9&EN871E<ULG4&%K:7-T86XG75LG,C0N.3`P.C8W+C$S,R==(#T@)TMA<F%C
M:&D@06ER<&]R="<["B1C;V]R9&EN871E<ULG4&%K:7-T86XG75LG,C4N,#8W
M.C8Q+C@P,"==(#T@)TII=V%N:2<["B1C;V]R9&EN871E<ULG4&%K:7-T86XG
M75LG,C4N,S@S.C8X+C0Q-R==(#T@)TAY9&5R86)A9"!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R=086MI<W1A;B==6R<R-BXR-3`Z-C@N,S8W)UT@/2`G3F%W
M86)S:&%H)SL*)&-O;W)D:6YA=&5S6R=086MI<W1A;B==6R<R-BXY-C<Z-C0N
M,3`P)UT@/2`G4&%N:F=U<B<["B1C;V]R9&EN871E<ULG4&%K:7-T86XG75LG
M,C@N,S`P.C8X+C0V-R==(#T@)TIA8V]B86)A9"<["B1C;V]R9&EN871E<ULG
M4&%K:7-T86XG75LG,CDN-34P.C8W+C@X,R==(#T@)U-I8FDG.PHD8V]O<F1I
M;F%T97-;)U!A:VES=&%N)UU;)S,P+C(P,#HW,2XT,S,G72`]("=-=6QT86XG
M.PHD8V]O<F1I;F%T97-;)U!A:VES=&%N)UU;)S,P+C(U,#HV-BXX.#,G72`]
M("=1=65T=&$@06ER<&]R="<["B1C;V]R9&EN871E<ULG4&%K:7-T86XG75LG
M,S$N-3$W.C<T+C0P,"==(#T@)TQA:&]R92!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R=086MI<W1A;B==6R<S,2XU-3`Z-S0N,S,S)UT@/2`G3&%H;W)E($-I
M='DG.PHD8V]O<F1I;F%T97-;)U!A:VES=&%N)UU;)S,Q+C@Q-SHW,"XY,3<G
M72`]("=$97)A($ES;6%I;"!+:&%N)SL*)&-O;W)D:6YA=&5S6R=086MI<W1A
M;B==6R<S,BXP-3`Z-S(N-C8W)UT@/2`G4V%R9V]D:&$G.PHD8V]O<F1I;F%T
M97-;)U!A:VES=&%N)UU;)S,R+C4U,#HW,2XU,3<G72`]("=-:6%N=V%L:2<[
M"B1C;V]R9&EN871E<ULG4&%K:7-T86XG75LG,S,N-C$W.C<S+C$P,"==(#T@
M)TES;&%M86)A9"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=086MI<W1A;B==
M6R<S-"XP,3<Z-S$N-3@S)UT@/2`G4&5S:&%W87(G.PHD8V]O<F1I;F%T97-;
M)U!A:VES=&%N)UU;)S,T+C`V-SHW,2XY.#,G72`]("=2:7-A;'!U<B<["B1C
M;V]R9&EN871E<ULG4&%L874G75LG-RXS-C<Z,3,T+C4S,R==(#T@)T)A8F5L
M=&AU87`@27-L86YD+"!"86)E;'1H=6%P+TMO<F]R($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)U!A;F%M82==6R<X+C`X,SHM.#`N.34P)UT@/2`G4V%N=&EA
M9V\G.PHD8V]O<F1I;F%T97-;)U!A;F%M82==6R<X+C0P,#HM.#(N-#$W)UT@
M/2`G1&%V:60G.PHD8V]O<F1I;F%T97-;)U!A;F%M82==6R<X+CDQ-SHM-SDN
M-C`P)UT@/2`G2&]W87)D($%I<B!&;W)C92!"87-E)SL*)&-O;W)D:6YA=&5S
M6R=086YA;6$G75LG.2XP-3`Z+3<Y+C,V-R==(#T@)U1O8W5M96XG.PHD8V]O
M<F1I;F%T97-;)U!A;F%M82==6R<Y+C,S,SHM-SDN.3@S)UT@/2`G1G0@4VAE
M<FUA;B!2;V-O8B<["B1C;V]R9&EN871E<ULG4&%P=6$@3F5W($=U:6YE82==
M6R<M,RXU-C<Z,30S+C8S,R==(#T@)U=E=V%K)SL*)&-O;W)D:6YA=&5S6R=0
M87!U82!.97<@1W5I;F5A)UU;)RTU+C(Q-SHQ-#4N-S@S)UT@/2`G36%D86YG
M)SL*)&-O;W)D:6YA=&5S6R=087!U82!.97<@1W5I;F5A)UU;)RTY+C0S,SHQ
M-#<N,C$W)UT@/2`G36]R97-B>2<["B1C;V]R9&EN871E<ULG4&%R86=U87DG
M75LG+3(P+C<Q-SHM-C$N.3$W)UT@/2`G3G5E=F$@07-U;F-I;VXG.PHD8V]O
M<F1I;F%T97-;)U!A<F%G=6%Y)UU;)RTR,BXP,3<Z+38P+C8P,"==(#T@)TUA
M<FES8V%L($5S=&EG87)R:6)I82<["B1C;V]R9&EN871E<ULG4&%R86=U87DG
M75LG+3(S+C0Q-SHM-3<N,S`P)UT@/2`G0V]N8V5P8VEO;B<["B1C;V]R9&EN
M871E<ULG4&%R86=U87DG75LG+3(U+C(V-SHM-3<N-C,S)UT@/2`G07-U;F-I
M;VX@+R!!97)O<'5E<G1O)SL*)&-O;W)D:6YA=&5S6R=087)A9W5A>2==6R<M
M,C<N,S$W.BTU-2XX,S,G72`]("=%;F-A<FYA8VEO;B<["B1C;V]R9&EN871E
M<ULG4&5R=2==6R<M,3`N-S,S.BTW,RXW.#,G72`]("=!=&%L87EA)SL*)&-O
M;W)D:6YA=&5S6R=097)U)UU;)RTQ,BXP,#`Z+3<W+C$Q-R==(#T@)TQI;6$M
M0V%L;&%O("\@065R;W`N($EN=&5R;F%C:6]N86P@2F]R9V5C:&%V97HG.PHD
M8V]O<F1I;F%T97-;)U!E<G4G75LG+3$R+C8S,SHM-CDN,C`P)UT@/2`G4'5E
M<G1O($UA;&1O;F%D;R<["B1C;V]R9&EN871E<ULG4&5R=2==6R<M,3,N,3,S
M.BTW-"XR,3<G72`]("=!>6%C=6-H;R<["B1C;V]R9&EN871E<ULG4&5R=2==
M6R<M,3,N-34P.BTW,2XY.#,G72`]("=#=7IC;R<["B1C;V]R9&EN871E<ULG
M4&5R=2==6R<M,3,N-S$W.BTW,RXS-3`G72`]("=!;F1A:'5A>6QA)SL*)&-O
M;W)D:6YA=&5S6R=097)U)UU;)RTQ,RXW-3`Z+3<V+C(X,R==(#T@)U!I<V-O
M)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTQ-2XS.#,Z+3<U+C$V-R==(#T@
M)U-A;B!*=6%N)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTQ-2XT.#,Z+3<P
M+C$U,"==(#T@)TIU;&EA8V$G.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG+3$V
M+C,Q-SHM-S$N-34P)UT@/2`G07)E<75I<&$G.PHD8V]O<F1I;F%T97-;)U!E
M<G4G75LG+3$X+C`V-SHM-S`N,S`P)UT@/2`G5&%C;F$G.PHD8V]O<F1I;F%T
M97-;)U!E<G4G75LG+3,N-34P.BTX,"XT,#`G72`]("=4=6UB97,G.PHD8V]O
M<F1I;F%T97-;)U!E<G4G75LG+3,N-S4P.BTW,RXR-3`G72`]("=)<75I=&]S
M)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTT+C4V-SHM.#$N,C4P)UT@/2`G
M5&%L87)A)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTU+C$X,SHM.#`N-C`P
M)UT@/2`G4&EU<F$G.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG+34N.3`P.BTW
M-BXP.#,G72`]("=9=7)I;6%G=6%S)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;
M)RTV+C`U,#HM-S<N,34P)UT@/2`G4FEO:F$G.PHD8V]O<F1I;F%T97-;)U!E
M<G4G75LG+38N,C$W.BTW-RXX,S,G72`]("=#:&%C:&%P;WEA<R<["B1C;V]R
M9&EN871E<ULG4&5R=2==6R<M-BXT-3`Z+3<V+C,X,R==(#T@)U1A<F%P;W1O
M)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTV+C<X,SHM-SDN.#,S)UT@/2`G
M0VAI8VQA>6\G.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG+3<N,3,S.BTW."XT
M-C<G72`]("=#86IA;6%R8V$G.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG+3<N
M,C$W.BTW-BXW,3<G72`]("=*=6%N:G5I)SL*)&-O;W)D:6YA=&5S6R=097)U
M)UU;)RTX+C$P,#HM-SDN,#,S)UT@/2`G5')U:FEL;&\G.PHD8V]O<F1I;F%T
M97-;)U!E<G4G75LG+3@N-#$W.BTW-"XV,#`G72`]("=0=6-A;&QP82<["B1C
M;V]R9&EN871E<ULG4&5R=2==6R<M.2XQ,S,Z+3<U+CDU,"==(#T@)U1I;F=O
M($UA<FEA)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTY+C$V-SHM-S@N-3$W
M)UT@/2`G0VAI;6)O=&4G.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG+3DN,S4P
M.BTW-RXV,#`G72`]("=!;G1A($AU87)A>B<["B1C;V]R9&EN871E<ULG4&5R
M=2==6R<M.2XY,#`Z+3<U+C<U,"==(#T@)TAU86YU8V\G.PHD8V]O<F1I;F%T
M97-;)U!H:6QI<'!I;F5S)UU;)S$P+C,P,#HQ,C,N.38W)UT@/2`G36%C=&%N
M)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Q,"XW,#`Z,3(R+C4V
M-R==(#T@)TEL;VEL;R<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG
M,3$N,#,S.C$R-BXW,S,G72`]("='=6EU86XG.PHD8V]O<F1I;F%T97-;)U!H
M:6QI<'!I;F5S)UU;)S$Q+C(U,#HQ,C4N,#`P)UT@/2`G5&%C;&]B86XG.PHD
M8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)S$Q+C4X,SHQ,C(N-S4P)UT@
M/2`G4F]X87,G.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)S$R+C,U
M,#HQ,C$N,#,S)UT@/2`G4V%N($IO<V4G.PHD8V]O<F1I;F%T97-;)U!H:6QI
M<'!I;F5S)UU;)S$R+C,V-SHQ,C,N-C$W)UT@/2`G36%S8F%T92<["B1C;V]R
M9&EN871E<ULG4&AI;&EP<&EN97,G75LG,3(N-#@S.C$R-"XV,S,G72`]("=#
M871A<FUA;B<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG,3(N-3@S
M.C$R,BXR-C<G72`]("=2;VUB;&]N)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P
M:6YE<R==6R<Q,RXQ,S,Z,3(S+C<S,R==(#T@)TQE9V%S<&DG.PHD8V]O<F1I
M;F%T97-;)U!H:6QI<'!I;F5S)UU;)S$S+C0Q-SHQ,C$N,3@S)UT@/2`G0V%L
M87!A;B<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG,3,N-3@S.C$R
M-"XR,S,G72`]("=6:7)A8R<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G
M75LG,30N,#@S.C$R,BXP,3<G72`]("=!;&%B870G.PHD8V]O<F1I;F%T97-;
M)U!H:6QI<'!I;F5S)UU;)S$T+C$S,SHQ,C(N.3@S)UT@/2`G1&%E="<["B1C
M;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG,30N-3`P.C$R,"XY,3<G72`]
M("=386YG;&5Y(%!O:6YT)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==
M6R<Q-"XU,3<Z,3(Q+C`P,"==(#T@)TYI;F]Y($%Q=6EN;R!);G1E<BU.871I
M;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Q
M-"XX,#`Z,3(P+C(V-R==(#T@)U-U8FEC($)A>2!796%T:&5R(%-T871I;VXG
M.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)S$U+C$V-SHQ,C`N-38W
M)UT@/2`G0VQA<FL@06(G.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;
M)S$U+C,S,SHQ,3DN.38W)UT@/2`G26)A)SL*)&-O;W)D:6YA=&5S6R=0:&EL
M:7!P:6YE<R==6R<Q-2XW-C<Z,3(Q+C4V-R==(#T@)T)A;&5R)SL*)&-O;W)D
M:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Q-BXT,3<Z,3(P+C8P,"==(#T@)T)A
M9W5I;R<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG,3<N-38W.C$R
M,"XS.#,G72`]("=6:6=A;B<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G
M75LG,3<N-C$W.C$R,2XW,S,G72`]("=4=6=U96=A<F%O)SL*)&-O;W)D:6YA
M=&5S6R=0:&EL:7!P:6YE<R==6R<Q."XQ.#,Z,3(P+C4S,R==(#T@)TQA;V%G
M)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Q."XS-C<Z,3(Q+C8S
M,R==(#T@)T%P87)R:2<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG
M,C`N-#4P.C$R,2XY-C<G72`]("="87-C;R<["B1C;V]R9&EN871E<ULG4&AI
M;&EP<&EN97,G75LG-BXQ,3<Z,3(U+C$X,R==(#T@)T=E;BX@4V%N=&]S)SL*
M)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<V+CDP,#HQ,C(N,#8W)UT@
M/2`G6F%M8F]A;F=A)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<W
M+C$Q-SHQ,C4N-C4P)UT@/2`G1&%V86\@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG4&AI;&EP<&EN97,G75LG-RXQ-C<Z,3(T+C(Q-R==(#T@)T-O=&]B871O
M)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<X+C$U,#HQ,C4N,#@S
M)UT@/2`G36%L87EB86QA>2<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G
M75LG."XT.#,Z,3(T+C8S,R==(#T@)T-A9V%Y86X@1&4@3W)O)SL*)&-O;W)D
M:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<X+C8P,#HQ,C,N,S4P)UT@/2`G1&EP
M;VQO9R<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG.2XS,#`Z,3(S
M+C,P,"==(#T@)T1U;6%G=65T92<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN
M97,G75LG.2XV,#`Z,3(S+C@U,"==(#T@)U1A9V)I;&%R86XG.PHD8V]O<F1I
M;F%T97-;)U!H:6QI<'!I;F5S)UU;)SDN-S4P.C$Q."XW,S,G72`]("=0=65R
M=&\@4')I;F-E<V$G.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)SDN
M.#`P.C$R-2XU,#`G72`]("=3=7)I9V%O)SL*)&-O;W)D:6YA=&5S6R=0:&EL
M:7!P:6YE<R==6R<Y+CDS,SHQ,C4N-3$W)UT@/2`G0G5T=6%N)SL*)&-O;W)D
M:6YA=&5S6R=0;VQA;F0G75LG-3`N,#@S.C$Y+C@P,"==(#T@)TMR86MO=R<[
M"B1C;V]R9&EN871E<ULG4&]L86YD)UU;)S4P+C$P,#HR,BXP-3`G72`]("=2
M>F5S>F]W+4IA<VEO;FMA)SL*)&-O;W)D:6YA=&5S6R=0;VQA;F0G75LG-3`N
M,C,S.C$Y+C`S,R==(#T@)TMA=&]W:6-E)SL*)&-O;W)D:6YA=&5S6R=0;VQA
M;F0G75LG-3$N,3`P.C$V+C@X,R==(#T@)U=R;V-L87<@26DG.PHD8V]O<F1I
M;F%T97-;)U!O;&%N9"==6R<U,2XY,S,Z,34N-3,S)UT@/2`G6FEE;&]N82!'
M;W)A)SL*)&-O;W)D:6YA=&5S6R=0;VQA;F0G75LG-3(N,38W.C(P+CDV-R==
M(#T@)U=A<G-Z87=A+4]K96-I92<["B1C;V]R9&EN871E<ULG4&]L86YD)UU;
M)S4R+C0Q-SHQ-BXX,S,G72`]("=0;WIN86XG.PHD8V]O<F1I;F%T97-;)U!O
M;&%N9"==6R<U,RXT,#`Z,30N-C$W)UT@/2`G4WIC>F5C:6XG.PHD8V]O<F1I
M;F%T97-;)U!O;&%N9"==6R<U-"XR,#`Z,38N,34P)UT@/2`G2V]S>F%L:6XG
M.PHD8V]O<F1I;F%T97-;)U!O;&%N9"==6R<U-"XS.#,Z,3@N-#8W)UT@/2`G
M1V1A;G-K+5)E8FEE8VAO=V\G.PHD8V]O<F1I;F%T97-;)U!O<G1U9V%L)UU;
M)S,R+C8X,SHM,38N-S8W)UT@/2`G1G5N8VAA;"`O(%,N($-A=&%R:6YA)SL*
M)&-O;W)D:6YA=&5S6R=0;W)T=6=A;"==6R<S,RXP-C<Z+3$V+C,U,"==(#T@
M)U!O<G1O(%-A;G1O)SL*)&-O;W)D:6YA=&5S6R=0;W)T=6=A;"==6R<S-BXY
M-C<Z+3(U+C$V-R==(#T@)U-A;G1A($UA<FEA($%C;W)E<R<["B1C;V]R9&EN
M871E<ULG4&]R='5G86PG75LG,S<N,#$W.BTW+CDV-R==(#T@)T9A<F\@+R!!
M97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)U!O<G1U9V%L)UU;)S,W+C<S,SHM
M,C4N-S`P)UT@/2`G4&]N=&$@1&5L9V%D82`O($YO<F1E;&$@06-O<F5S)SL*
M)&-O;W)D:6YA=&5S6R=0;W)T=6=A;"==6R<S."XP,3<Z+3<N.#8W)UT@/2`G
M0F5J82<["B1C;V]R9&EN871E<ULG4&]R='5G86PG75LG,S@N-3$W.BTR."XW
M,3<G72`]("=(;W)T82`O($-A<W1E;&\@0G)A;F-O($%C;W)E<R<["B1C;V]R
M9&EN871E<ULG4&]R='5G86PG75LG,S@N-S8W.BTR-RXQ,#`G72`]("=,86IE
M<R!!8V]R97,G.PHD8V]O<F1I;F%T97-;)U!O<G1U9V%L)UU;)S,X+C<V-SHM
M.2XQ,S,G72`]("=,:7-B;V$@+R!0;W)T96QA)SL*)&-O;W)D:6YA=&5S6R=0
M;W)T=6=A;"==6R<S.2XT-3`Z+3,Q+C$S,R==(#T@)T9L;W)E<R!!8V]R97,G
M.PHD8V]O<F1I;F%T97-;)U!O<G1U9V%L)UU;)S0Q+C(S,SHM."XV.#,G72`]
M("=0;W)T;R`O(%!E9')A<R!2=6)R87,G.PHD8V]O<F1I;F%T97-;)U!O<G1U
M9V%L)UU;)S0Q+C(V-SHM-RXW,3<G72`]("=6:6QA(%)E86PG.PHD8V]O<F1I
M;F%T97-;)U!O<G1U9V%L)UU;)S0Q+C@P,#HM-BXW,S,G72`]("="<F%G86YC
M82<["B1C;V]R9&EN871E<ULG46%T87(G75LG,C4N,C4P.C4Q+C4V-R==(#T@
M)T1O:&$@26YT97)N871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=2
M975N:6]N)UU;)RTR,"XX.#,Z-34N-3$W)UT@/2`G4V%I;G0M1&5N:7,@+R!'
M:6QL;W0G.PHD8V]O<F1I;F%T97-;)U)E=6YI;VXG75LG+3(Q+C,S,SHU-2XT
M.#,G72`]("=386EN="U0:65R<F4G.PHD8V]O<F1I;F%T97-;)U)O;6%N:6$G
M75LG-#0N,C,S.C(S+C@V-R==(#T@)T-R86EO=F$G.PHD8V]O<F1I;F%T97-;
M)U)O;6%N:6$G75LG-#0N,S,S.C(X+C0S,R==(#T@)TMO9V%L;FEC96%N=2<[
M"B1C;V]R9&EN871E<ULG4F]M86YI82==6R<T-"XU,#`Z,C8N,3,S)UT@/2`G
M0G5C=7)E<W1I("\@26UH)SL*)&-O;W)D:6YA=&5S6R=2;VUA;FEA)UU;)S0T
M+C4U,#HR-BXQ,#`G72`]("="=6-U<F5S=&D@3W1O<&5N:2<["B1C;V]R9&EN
M871E<ULG4F]M86YI82==6R<T-2XQ.#,Z,C@N.#$W)UT@/2`G5'5L8V5A)SL*
M)&-O;W)D:6YA=&5S6R=2;VUA;FEA)UU;)S0U+C0Q-SHR,BXR-3`G72`]("=#
M87)A;G-E8F5S)SL*)&-O;W)D:6YA=&5S6R=2;VUA;FEA)UU;)S0U+C<V-SHR
M,2XR-3`G72`]("=4:6UI<V]A<F$G.PHD8V]O<F1I;F%T97-;)U)O;6%N:6$G
M75LG-#4N.#`P.C(T+C$U,"==(#T@)U-I8FEU)SL*)&-O;W)D:6YA=&5S6R=2
M;VUA;FEA)UU;)S0V+C(P,#HR,2XT,#`G72`]("=!<F%D)SL*)&-O;W)D:6YA
M=&5S6R=2;VUA;FEA)UU;)S0V+C4S,SHR-"XU,S,G72`]("=4:7)G=2!-=7)E
M<R<["B1C;V]R9&EN871E<ULG4F]M86YI82==6R<T-BXU.#,Z,C8N.38W)UT@
M/2`G0F%C874G.PHD8V]O<F1I;F%T97-;)U)O;6%N:6$G75LG-#8N-S@S.C(S
M+C4V-R==(#T@)T-L=6HM3F%P;V-A)SL*)&-O;W)D:6YA=&5S6R=2;VUA;FEA
M)UU;)S0W+C`U,#HR,2XY,S,G72`]("=/<F%D96$G.PHD8V]O<F1I;F%T97-;
M)U)O;6%N:6$G75LG-#<N,38W.C(W+C8S,R==(#T@)TEA<VDG.PHD8V]O<F1I
M;F%T97-;)U)O;6%N:6$G75LG-#<N-C4P.C(V+C(U,"==(#T@)U-U8V5A=F$@
M+R!386QC96$G.PHD8V]O<F1I;F%T97-;)U)O;6%N:6$G75LG-#<N-C8W.C(S
M+C4X,R==(#T@)T)A:6$@36%R92<["B1C;V]R9&EN871E<ULG4F]M86YI82==
M6R<T-RXX,#`Z,C(N.#@S)UT@/2`G4V%T=2!-87)E)SL*)&-O;W)D:6YA=&5S
M6R=2=7-S:6%N($9E9&5R871I;VXG75LG-#,N,3$W.C$S,2XY,S,G72`]("=6
M;&%D:79O<W1O:R<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N
M)UU;)S0S+C0S,SHS.2XY,#`G72`]("=!9&QE<B<["B1C;V]R9&EN871E<ULG
M4G5S<VEA;B!&961E<F%T:6]N)UU;)S0T+C(S,SHT,RXP-C<G72`]("=-:6YE
M<F%L7"=.>64@5F]D>2<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T
M:6]N)UU;)S0U+C`S,SHS.2XQ-3`G72`]("=+<F%S;F]D87(G.PHD8V]O<F1I
M;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<T-BXS-C<Z-#0N,S,S)UT@
M/2`G16QI<W1A)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG
M75LG-#8N.34P.C$T,BXW,3<G72`]("=9=7IH;F\M4V%K:&%L:6YS:R<["B1C
M;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S0W+C(V-SHS.2XX
M,3<G72`]("=2;W-T;W8M3F$M1&]N=2<["B1C;V]R9&EN871E<ULG4G5S<VEA
M;B!&961E<F%T:6]N)UU;)S0X+C4Q-SHQ,S4N,38W)UT@/2`G2&%B87)O=G-K
M)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-#@N-S@S
M.C0T+C,V-R==(#T@)U9O;&=O9W)A9"<["B1C;V]R9&EN871E<ULG4G5S<VEA
M;B!&961E<F%T:6]N)UU;)S0Y+C0U,#HQ,S8N-38W)UT@/2`G5')O:6-K;V4G
M.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<U,2XV-3`Z
M,SDN,C4P)UT@/2`G5F]R;VYE>B<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&
M961E<F%T:6]N)UU;)S4Q+C@S,SHQ,#<N-C`P)UT@/2`G56QA;BU59&4G.PHD
M8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<U,BXP.#,Z,3$S
M+C0X,R==(#T@)T-H:71A)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R
M871I;VXG75LG-3(N,38W.C$P.2XW.#,G72`]("=(;W)I;G-K)SL*)&-O;W)D
M:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-3(N,C8W.C$P-"XS,3<G
M72`]("=)<FMU='-K)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I
M;VXG75LG-3(N.#$W.C$P-"XW-C<G72`]("=5<W1<)T]R9'EN<VMI:B<["B1C
M;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S4S+C`V-SHQ,S(N
M.3@S)UT@/2`G16MI;6-H86XG.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D
M97)A=&EO;B==6R<U,RXP.#,Z,34X+C4X,R==(#T@)U!E=')O<&%V;&]V<VLM
M2V%M8VAA='-K:6HG.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO
M;B==6R<U,RXQ,3<Z-#4N,#$W)UT@/2`G4&5N>F$G.PHD8V]O<F1I;F%T97-;
M)U)U<W-I86X@1F5D97)A=&EO;B==6R<U,RXR,#`Z-3`N,34P)UT@/2`G4V%M
M87)A)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-3,N
M,C4P.C,T+C,Q-R==(#T@)T)R:F%N<VLG.PHD8V]O<F1I;F%T97-;)U)U<W-I
M86X@1F5D97)A=&EO;B==6R<U,RXT,S,Z.#,N-3$W)UT@/2`G0F%R;F%U;"<[
M"B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S4T+C@X,SHY
M.2XP,S,G72`]("=.:7IH;F5U9&EN<VLG.PHD8V]O<F1I;F%T97-;)U)U<W-I
M86X@1F5D97)A=&EO;B==6R<U-2XP.#,Z.#(N.3`P)UT@/2`G3F]V;W-I8FER
M<VLG.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<U-BXS
M-3`Z,S`N-C$W)UT@/2`G5F5L:6MI92!,=6MI)SL*)&-O;W)D:6YA=&5S6R=2
M=7-S:6%N($9E9&5R871I;VXG75LG-38N.#,S.C$R-"XX-C<G72`]("=#=6Q<
M)TUA;B<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S4V
M+C@S,SHV,"XV,S,G72`]("=%:V%T97)I;F)U<F<G.PHD8V]O<F1I;F%T97-;
M)U)U<W-I86X@1F5D97)A=&EO;B==6R<U-BXY,#`Z,S4N.#@S)UT@/2`G5'9E
M<B<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S4W+C<V
M-SHQ,#@N,#8W)UT@/2`G2VER96YS:R<["B1C;V]R9&EN871E<ULG4G5S<VEA
M;B!&961E<F%T:6]N)UU;)S4W+C@U,#HQ,30N,C,S)UT@/2`G0F]D86IB;R<[
M"B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S4X+C0U,#HY
M,BXQ-3`G72`]("=%;FES96IS:R<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&
M961E<F%T:6]N)UU;)S4Y+C,Q-SHS.2XY,3<G72`]("=6;VQO9V1A)SL*)&-O
M;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-3DN-34P.C$U,"XW
M.#,G72`]("=-86=A9&%N)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R
M871I;VXG75LG-3DN.#@S.C0R+C<U,"==(#T@)U1O=%PG36$G.PHD8V]O<F1I
M;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<U.2XY-C<Z,S`N,S`P)UT@
M/2`G4W0N(%!E=&5R8G5R9R<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E
M<F%T:6]N)UU;)S8Q+C`Q-SHV.2XP,S,G72`]("=(86YT>2U-86YS:6IS:R<[
M"B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S8Q+C(S,SHT
M-BXW,3<G72`]("=+;W1L87,G.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D
M97)A=&EO;B==6R<V,2XR-3`Z-S,N-3`P)UT@/2`G4W5R9W5T)SL*)&-O;W)D
M:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-C$N-C@S.C4S+C8X,R==
M(#T@)U5S=%PG+2!+=6QO;2<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E
M<F%T:6]N)UU;)S8Q+C<Q-SHU,"XX,S,G72`]("=3>6MT>79K87(G.PHD8V]O
M<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<V,BXP,3<Z,3(Y+C<Q
M-R==(#T@)TIA:W5T<VLG.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A
M=&EO;B==6R<V-"XT,3<Z+3$W,RXR,S,G72`]("="=6AT82!0<F]V:61E;FIA
M)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-C0N-3`P
M.C0P+C<S,R==(#T@)T%R:&%N9V5L7"=3:R<["B1C;V]R9&EN871E<ULG4G5S
M<VEA;B!&961E<F%T:6]N)UU;)S8T+C<X,SHQ-S<N-38W)UT@/2`G06YA9'ER
M)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-C@N.38W
M.C,S+C`U,"==(#T@)TUU<FUA;G-K)SL*)&-O;W)D:6YA=&5S6R=2=V%N9&$G
M75LG+3$N-C8W.C(Y+C(U,"==(#T@)T=I<V5N>6DG.PHD8V]O<F1I;F%T97-;
M)U)W86YD82==6R<M,2XY-C<Z,S`N,3$W)UT@/2`G2VEG86QI)SL*)&-O;W)D
M:6YA=&5S6R=386EN="!(96QE;F$G75LG+3<N.38W.BTQ-"XT,#`G72`]("=7
M:61E($%W86ME($9I96QD($%S8V5N<VEO;B!)<VQA;F0G.PHD8V]O<F1I;F%T
M97-;)U-A:6YT($MI='1S(&%N9"!.979I<R==6R<Q-RXS,#`Z+38R+C8X,R==
M(#T@)T=O;&1E;B!2;V-K)SL*)&-O;W)D:6YA=&5S6R=386EN="!,=6-I82==
M6R<Q,RXW-3`Z+38P+CDU,"==(#T@)TAE=V%N;W)R82!);G1E<FYA=&EO;F%L
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U-A:6YT($QU8VEA)UU;)S$T+C`Q
M-SHM-C$N,#`P)UT@/2`G5FEG:64G.PHD8V]O<F1I;F%T97-;)U-A:6YT(%!I
M97)R92!A;F0@36EQ=65L;VXG75LG-#8N-S8W.BTU-BXQ-C<G72`]("=386EN
M="U0:65R<F4G.PHD8V]O<F1I;F%T97-;)U-A:6YT(%9I;F-E;G0@86YD('1H
M92!'<F5N861I;F5S)UU;)S$S+C$S,SHM-C$N,C`P)UT@/2`G07)N;W,@5F%L
M92<["B1C;V]R9&EN871E<ULG4V%M;V$G75LG+3$S+C@P,#HM,3<Q+C<X,R==
M(#T@)T%P:6$@+R!5<&]L=2!)<VQA;F0G.PHD8V]O<F1I;F%T97-;)U-A;6]A
M)UU;)RTQ,RXX,3<Z+3$W,BXP,#`G72`]("=&86QE;VQO($EN=&P@+R!!<&EA
M)SL*)&-O;W)D:6YA=&5S6R=386\@5&]M92!A;F0@4')I;F-I<&4G75LG,"XS
M.#,Z-BXW,3<G72`]("=3+B!4;VUE)SL*)&-O;W)D:6YA=&5S6R=386\@5&]M
M92!A;F0@4')I;F-I<&4G75LG,2XV-3`Z-RXT,3<G72`]("=0<FEN8VEP92<[
M"B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S$V+CDP,#HT,BXU.#,G
M72`]("=':7IA;B<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S$W
M+C0V-SHT-RXQ,3<G72`]("=3:&%R=7)A:"<["B1C;V]R9&EN871E<ULG4V%U
M9&D@07)A8FEA)UU;)S$W+C8Q-SHT-"XT,3<G72`]("=.86IR86XG.PHD8V]O
M<F1I;F%T97-;)U-A=61I($%R86)I82==6R<Q."XR,S,Z-#(N-C4P)UT@/2`G
M06)H82<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S$X+C,P,#HT
M,BXX,#`G72`]("=+:&%M:7,@375S:&%I="<["B1C;V]R9&EN871E<ULG4V%U
M9&D@07)A8FEA)UU;)S$Y+CDX,SHT,BXV,3<G72`]("=":7-H82<["B1C;V]R
M9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S(P+C,P,#HT,2XV,S,G72`]("=!
M;"!"86AA)SL*)&-O;W)D:6YA=&5S6R=3875D:2!!<F%B:6$G75LG,C`N-3`P
M.C0U+C(P,"==(#T@)U=A9&D@06P@1&%W87-S97(@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S(Q+C0S,SHS.2XW-C<G72`]("=-
M86MK86@G.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==6R<R,2XT.#,Z
M-#`N-34P)UT@/2`G5&%I9B<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA
M)UU;)S(Q+C4P,#HS.2XR,#`G72`]("=*961D86@G.PHD8V]O<F1I;F%T97-;
M)U-A=61I($%R86)I82==6R<R,2XW,#`Z,SDN,3@S)UT@/2`G2F5D9&%H($MI
M;F<@06)D=6P@07II>B!);G1E<FYA=&EO;F%L($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)U-A=61I($%R86)I82==6R<R-"XQ-3`Z,S@N,#8W)UT@/2`G665N
M8F\G.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==6R<R-"XU,#`Z-#0N
M,S4P)UT@/2`G1&%W861M:2<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA
M)UU;)S(T+C4U,#HS.2XW,#`G72`]("=-861I;F%H)SL*)&-O;W)D:6YA=&5S
M6R=3875D:2!!<F%B:6$G75LG,C0N-S$W.C0V+C<S,R==(#T@)U)I>6%D:"<[
M"B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S(T+CDS,SHT-BXW,3<G
M72`]("=+:6YG($MH86QE9"!);G1E<FYA=&EO;F%L($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)U-A=61I($%R86)I82==6R<R-2XS,#`Z-#DN-#@S)UT@/2`G
M06P@06AS82<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S(V+C(P
M,#HS-BXT-C<G72`]("=796IH)SL*)&-O;W)D:6YA=&5S6R=3875D:2!!<F%B
M:6$G75LG,C8N,C8W.C4P+C$U,"==(#T@)T1H86AR86XG.PHD8V]O<F1I;F%T
M97-;)U-A=61I($%R86)I82==6R<R-BXS,#`Z-#,N-S8W)UT@/2`G1V%S<VEM
M)SL*)&-O;W)D:6YA=&5S6R=3875D:2!!<F%B:6$G75LG,C8N-#8W.C0Y+C<X
M,R==(#T@)T1A;6UA;2U+:6YG($9A:&0@26YT97)N871I;VYA;"!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=3875D:2!!<F%B:6$G75LG,C<N-#,S.C0Q+C8X
M,R==(#T@)TAA:6PG.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==6R<R
M-RXY,#`Z-#4N-3,S)UT@/2`G2&%F<B!!;"U"871I;B<["B1C;V]R9&EN871E
M<ULG4V%U9&D@07)A8FEA)UU;)S(X+C,Q-SHT-BXQ,3<G72`]("=!;"!187ES
M=6UA:"<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S(X+C,V-SHS
M-BXV,#`G72`]("=486)U:R<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA
M)UU;)S(Y+C8Q-SHT,RXT.#,G72`]("=2869H82<["B1C;V]R9&EN871E<ULG
M4V%U9&D@07)A8FEA)UU;)S(Y+C<X,SHT,"XQ,#`G72`]("=!;"U*;W5F)SL*
M)&-O;W)D:6YA=&5S6R=3875D:2!!<F%B:6$G75LG,S`N.3`P.C0Q+C$S,R==
M(#T@)T%R87(G.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==6R<S,2XT
M,#`Z,S<N,C8W)UT@/2`G1W5R:6%T)SL*)&-O;W)D:6YA=&5S6R=3875D:2!!
M<F%B:6$G75LG,S$N-C@S.C,X+C<S,R==(#T@)U1U<F%I9B<["B1C;V]R9&EN
M871E<ULG4V5N96=A;"==6R<Q,BXT,#`Z+3$V+C<U,"==(#T@)T-A<"U3:VER
M<FEN9R<["B1C;V]R9&EN871E<ULG4V5N96=A;"==6R<Q,BXU-3`Z+3$V+C(V
M-R==(#T@)UII9W5I;F-H;W(G.PHD8V]O<F1I;F%T97-;)U-E;F5G86PG75LG
M,3(N-38W.BTQ,BXR,3<G72`]("=+961O=6=O=2<["B1C;V]R9&EN871E<ULG
M4V5N96=A;"==6R<Q,BXX.#,Z+3$T+CDV-R==(#T@)TMO;&1A)SL*)&-O;W)D
M:6YA=&5S6R=396YE9V%L)UU;)S$S+C<V-SHM,3,N-C@S)UT@/2`G5&%M8F%C
M;W5N9&$G.PHD8V]O<F1I;F%T97-;)U-E;F5G86PG75LG,30N,3,S.BTQ-BXP
M-C<G72`]("=+86]L86-K)SL*)&-O;W)D:6YA=&5S6R=396YE9V%L)UU;)S$T
M+C8U,#HM,38N,C,S)UT@/2`G1&EO=7)B96PG.PHD8V]O<F1I;F%T97-;)U-E
M;F5G86PG75LG,30N-S,S.BTQ-RXU,#`G72`]("=$86MA<B`O(%EO9F8G.PHD
M8V]O<F1I;F%T97-;)U-E;F5G86PG75LG,34N,S@S.BTQ-2XQ,3<G72`]("=,
M:6YG=65R92<["B1C;V]R9&EN871E<ULG4V5N96=A;"==6R<Q-2XV-3`Z+3$S
M+C(U,"==(#T@)TUA=&%M)SL*)&-O;W)D:6YA=&5S6R=396YE9V%L)UU;)S$V
M+C`U,#HM,38N-#4P)UT@/2`G4V%I;G0M3&]U:7,G.PHD8V]O<F1I;F%T97-;
M)U-E;F5G86PG75LG,38N-C4P.BTQ-"XY-C<G72`]("=0;V1O<B<["B1C;V]R
M9&EN871E<ULG4V5Y8VAE;&QE<R==6R<M-"XV-C<Z-34N-3$W)UT@/2`G4V5Y
M8VAE;&QE<R!);G1E<BU.871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S
M6R=397EC:&5L;&5S)UU;)RTT+C8X,SHU-2XU,S,G72`]("=397EC:&5L;&5S
M($EN=&5R;F%T:6]N86P@06ER<&]R="!287=I;G-O;F1E(%-T871I;VXG.PHD
M8V]O<F1I;F%T97-;)U-I97)R82!,96]N92==6R<X+C8Q-SHM,3,N,C`P)UT@
M/2`G3'5N9VDG.PHD8V]O<F1I;F%T97-;)U-I;F=A<&]R92==6R<Q+C,V-SHQ
M,#,N.3$W)UT@/2`G4VEN9V%P;W)E("\@4&%Y82!,96)A<B<["B1C;V]R9&EN
M871E<ULG4VEN9V%P;W)E)UU;)S$N,S8W.C$P,RXY.#,G72`]("=3:6YG87!O
M<F4@+R!#:&%N9VD@06ER<&]R="<["B1C;V]R9&EN871E<ULG4VQO=F%K:6$G
M75LG-#@N,C`P.C$W+C(P,"==(#T@)T)R871I<VQA=F$@279A;FMA)SL*)&-O
M;W)D:6YA=&5S6R=3;&]V86MI82==6R<T."XS,S,Z,3DN-S,S)UT@/2`G3'5C
M96YE8R<["B1C;V]R9&EN871E<ULG4VQO=F%K:6$G75LG-#@N-C$W.C$W+C@S
M,R==(#T@)U!I97-T86YY)SL*)&-O;W)D:6YA=&5S6R=3;&]V86MI82==6R<T
M."XV-3`Z,3DN,34P)UT@/2`G4VQI86,G.PHD8V]O<F1I;F%T97-;)U-L;W9A
M:VEA)UU;)S0X+C8V-SHR,2XR,3<G72`]("=+;W-I8V4G.PHD8V]O<F1I;F%T
M97-;)U-L;W9A:VEA)UU;)S0X+CDS,SHR,BXP,#`G72`]("=+86UE;FEC82!.
M860@0VER;V-H;W4G.PHD8V]O<F1I;F%T97-;)U-L;W9A:VEA)UU;)S0Y+C`V
M-SHR,"XR-3`G72`]("=0;W!R860@+R!4871R>2<["B1C;V]R9&EN871E<ULG
M4VQO=F5N:6$G75LG-#4N-#@S.C$S+C8Q-R==(#T@)U!O<G1O<F]Z("\@4V5C
M;W9L:F4G.PHD8V]O<F1I;F%T97-;)U-L;W9E;FEA)UU;)S0U+C4Q-SHQ,RXU
M-C<G72`]("=0;W)T;W)O>B<["B1C;V]R9&EN871E<ULG4VQO=F5N:6$G75LG
M-#8N,C$W.C$T+C0X,R==(#T@)TQJ=6)L:F%N82`O($)R;FEK)SL*)&-O;W)D
M:6YA=&5S6R=3;&]V96YI82==6R<T-BXR,3<Z,30N-#@S)UT@/2`G3&IU8FQJ
M86YA("\@0G)N:6LG.PHD8V]O<F1I;F%T97-;)U-L;W9E;FEA)UU;)S0V+C0X
M,SHQ-2XV.#,G72`]("=-87)I8F]R("\@4VQI=FYI8V$G.PHD8V]O<F1I;F%T
M97-;)U-L;W9E;FEA)UU;)S0V+C8U,#HQ-BXQ.#,G72`]("=-=7)S:V$@4V]B
M;W1A)SL*)&-O;W)D:6YA=&5S6R=3;VQO;6]N($ES;&%N9',G75LG+3$P+C<P
M,#HQ-C4N.#`P)UT@/2`G4V%N=&$@0W)U>B<["B1C;V]R9&EN871E<ULG4V]L
M;VUO;B!)<VQA;F1S)UU;)RTX+C,S,SHQ-3<N,C8W)UT@/2`G375N9&$G.PHD
M8V]O<F1I;F%T97-;)U-O;&]M;VX@27-L86YD<R==6R<M.2XT,3<Z,38P+C`U
M,"==(#T@)TAO;FEA<F$@+R!(96YD97)S;VXG.PHD8V]O<F1I;F%T97-;)U-O
M;6%L:6$G75LG,3`N-#$W.C0U+C`Q-R==(#T@)T)E<F)E<F$G.PHD8V]O<F1I
M;F%T97-;)U-O;6%L:6$G75LG,BXP,S,Z-#4N,S4P)UT@/2`G36]G861I<V-I
M;R<["B1C;V]R9&EN871E<ULG4V]M86QI82==6R<T+C<P,#HT-2XR,3<G72`]
M("="96QE="!596XG.PHD8V]O<F1I;F%T97-;)U-O;6%L:6$G75LG.2XU,#`Z
M-#0N,#@S)UT@/2`G2&%R9V5I<V$G.PHD8V]O<F1I;F%T97-;)U-O;6%L:6$G
M75LG.2XU,#`Z-#4N-38W)UT@/2`G0G5R86\G.PHD8V]O<F1I;F%T97-;)U-O
M=71H($%F<FEC82==6R<M,C,N-S(V.C(W+C8X."==(#T@)T5L;&ES<F%S)SL*
M)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3(S+C@V-SHR.2XT-3`G
M72`]("=0:65T97)S8G5R9R<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A
M)UU;)RTR,RXY,S,Z,S$N,34P)UT@/2`G4&AA;&%B;W)W82<["B1C;V]R9&EN
M871E<ULG4V]U=&@@069R:6-A)UU;)RTR-"XS-C<Z,S$N,#,S)UT@/2`G2&]E
M9'-P<G5I="<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTR-2XT
M,S,Z,S`N.3@S)UT@/2`G3F5L<W!R=6ET)SL*)&-O;W)D:6YA=&5S6R=3;W5T
M:"!!9G)I8V$G75LG+3(U+C<S,SHR."XQ.#,G72`]("=0<F5T;W)I82<["B1C
M;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTR-2XW.#,Z,C4N-3,S)UT@
M/2`G36UA8F%T:&\@06ER<&]R="<["B1C;V]R9&EN871E<ULG4V]U=&@@069R
M:6-A)UU;)RTR-2XX,S,Z,C@N,C$W)UT@/2`G5V%T97)K;&]O9B!,;6(G.PHD
M8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,C4N.3$W.C(X+C(Q-R==
M(#T@)U!R971O<FEA($ER96YE)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I
M8V$G75LG+3(V+C`V-SHS,"XQ,3<G72`]("=#87)O;&EN82<["B1C;V]R9&EN
M871E<ULG4V]U=&@@069R:6-A)UU;)RTR-BXQ,S,Z,C@N,C,S)UT@/2`G2F%N
M(%-M=71S)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3(V+C@V
M-SHR-BXW,3<G72`]("=+;&5R:W-D;W)P)SL*)&-O;W)D:6YA=&5S6R=3;W5T
M:"!!9G)I8V$G75LG+3(V+CDU,#HR-"XV,S,G72`]("=6<GEB=7)G)SL*)&-O
M;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3(W+C(V-SHR."XU,#`G72`]
M("=&<F%N:V9O<G0G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M
M,C@N,#`P.C(V+C8V-R==(#T@)U=E;&MO;2<["B1C;V]R9&EN871E<ULG4V]U
M=&@@069R:6-A)UU;)RTR."XR-3`Z,C@N,S,S)UT@/2`G0F5T:&QE:&5M($%I
M<G!O<G0G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,C@N-#`P
M.C(Q+C(V-R==(#T@)U5P:6YG=&]N)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!
M9G)I8V$G75LG+3(X+C4V-SHQ-BXU,S,G72`]("=!;&5X86YD97(@0F%Y)SL*
M)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3(X+C4V-SHR.2XW-C<G
M72`]("=,861Y<VUI=&@G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==
M6R<M,C@N.#`P.C(T+C<V-R==(#T@)TMI;6)E<FQE>2<["B1C;V]R9&EN871E
M<ULG4V]U=&@@069R:6-A)UU;)RTR."XX,#`Z,S(N,3`P)UT@/2`G4FEC:&%R
M9"!"87DG.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,CDN,3`P
M.C(V+C,P,"==(#T@)T)L;V5M9F]N=&5I;B!*+B!"+B!-+B!(97)T>F]G)SL*
M)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3(Y+C8V-SHQ-RXX-C<G
M72`]("=3<')I;F=B;VLG.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==
M6R<M,CDN.38W.C,P+CDU,"==(#T@)T1U<F)A;B!,;W5I<R!";W1H82<["B1C
M;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTS,"XV,S,Z,C,N.3$W)UT@
M/2`G1&4@06%R)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3,P
M+C8U,#HR-"XP,3<G72`]("=$92!!87(G.PHD8V]O<F1I;F%T97-;)U-O=71H
M($%F<FEC82==6R<M,S`N-S$W.C(V+C<Q-R==(#T@)T%L:7=A;"!.;W)T:"<[
M"B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTS,2XT-C<Z,3DN-S8W
M)UT@/2`G0V%L=FEN:6$G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==
M6R<M,S$N-#@S.C(U+C`S,R==(#T@)TUI9&1E;&)U<F<G.PHD8V]O<F1I;F%T
M97-;)U-O=71H($%F<FEC82==6R<M,S$N-3,S.C(X+C8V-R==(#T@)U5M=&%T
M82<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTS,2XV,S,Z,CDN
M-34P)UT@/2`G4&]R="!3="!*;VAN<R<["B1C;V]R9&EN871E<ULG4V]U=&@@
M069R:6-A)UU;)RTS,2XV-C<Z,3@N-3`P)UT@/2`G5G)E9&5N9&%L)SL*)&-O
M;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3,Q+CDP,#HR-BXX-C<G72`]
M("=1=65E;G-T;W=N)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG
M+3,Q+CDQ-SHR,2XU,3<G72`]("=&<F%S97)B=7)G)SL*)&-O;W)D:6YA=&5S
M6R=3;W5T:"!!9G)I8V$G75LG+3,R+C(U,#HR-"XU,S,G72`]("='<F%A9F8@
M4F5I;F5T)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3,R+C,U
M,#HR,BXU.#,G72`]("="96%U9F]R="!797-T)SL*)&-O;W)D:6YA=&5S6R=3
M;W5T:"!!9G)I8V$G75LG+3,R+CDV-SHQ."XQ-C<G72`]("=,86YG96)A86YW
M96<G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,S,N,#,S.C(W
M+C@S,R==(#T@)T5A<W0@3&]N9&]N)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!
M9G)I8V$G75LG+3,S+C4V-SHR,BXR,3<G72`]("=/=61T<VAO;W)N)SL*)&-O
M;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3,S+CDX,SHQ."XV,#`G72`]
M("=#87!E(%1O=VX@1"X@1BX@36%L86XG.PHD8V]O<F1I;F%T97-;)U-O=71H
M($%F<FEC82==6R<M,S,N.3@S.C(U+C8P,"==(#T@)U!O<G0@16QI>F%B971H
M)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3,T+C`P,#HR,BXS
M.#,G72`]("='96]R9V4@06ER<&]R="<["B1C;V]R9&EN871E<ULG4V]U=&@@
M069R:6-A)UU;)RTS-"XQ.#,Z,C(N,34P)UT@/2`G36]S<V5L($)A>2!#87!E
M(%-A:6YT($)L86EZ92<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;
M)RTS-RXP-3`Z+3$R+C,Q-R==(#T@)U1R:7-T86X@1&$@0W5N:&$G.PHD8V]O
M<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M-#`N,S4P.BTY+C@X,R==(#T@
M)T=O=6=H($ES;&%N9"<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;
M)RTT-BXX.#,Z,S<N.#8W)UT@/2`G36%R:6]N($ES;&%N9"<["B1C;V]R9&EN
M871E<ULG4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES
M;&%N9',G75LG+34Q+C@Q-SHM-3@N-#4P)UT@/2`G36]U;G0@4&QE87-A;G0@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG,C<N.#$W.BTQ-RXX
M.#,G72`]("=(:65R<F\@+R!!97)O<'5E<G1O)SL*)&-O;W)D:6YA=&5S6R=3
M<&%I;B==6R<R-RXY,S,Z+3$U+C,X,R==(#T@)TQA<R!086QM87,@1&4@1W)A
M;B!#86YA<FEA("\@1V%N9&\G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S(X
M+C`U,#HM,38N-38W)UT@/2`G5&5N97)I9F4@4W5R)SL*)&-O;W)D:6YA=&5S
M6R=3<&%I;B==6R<R."XT-3`Z+3$S+C@V-R==(#T@)T9U97)T979E;G1U<F$@
M+R!!97)O<'5E<G1O)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<R."XT-C<Z
M+3$V+C,Q-R==(#T@)U1E;F5R:69E("\@3&]S(%)O9&5O<R<["B1C;V]R9&EN
M871E<ULG4W!A:6XG75LG,C@N-C$W.BTQ-RXW-3`G72`]("=,82!086QM82`O
M($%E<F]P=65R=&\G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S(X+CDU,#HM
M,3,N-C`P)UT@/2`G3&%N>F%R;W1E("\@065R;W!U97)T;R<["B1C;V]R9&EN
M871E<ULG4W!A:6XG75LG,S4N,C@S.BTR+CDU,"==(#T@)TUE;&EL;&$G.PHD
M8V]O<F1I;F%T97-;)U-P86EN)UU;)S,V+C8U,#HM-BXS-3`G72`]("=2;W1A
M)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<S-BXV-C<Z+30N-#@S)UT@/2`G
M36%L86=A("\@065R;W!U97)T;R<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG
M,S8N-S4P.BTV+C`V-R==(#T@)TIE<F5Z($1E($QA($9R;VYT97)A865R;W!U
M97)T;R<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG,S8N.#4P.BTR+C,X,R==
M(#T@)T%L;65R:6$@+R!!97)O<'5E<G1O)SL*)&-O;W)D:6YA=&5S6R=3<&%I
M;B==6R<S-RXQ-3`Z+34N-C$W)UT@/2`G36]R;VX@1&4@3&$@1G)O;G1E<F$G
M.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S,W+C$X,SHM,RXW.#,G72`]("='
M<F%N861A("\@065R;W!U97)T;R<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG
M,S<N-#$W.BTU+CDP,"==(#T@)U-E=FEL;&$@+R!386X@4&%B;&\G.PHD8V]O
M<F1I;F%T97-;)U-P86EN)UU;)S,W+C<X,SHM,"XX,#`G72`]("=-=7)C:6$@
M+R!386X@2F%V:65R)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<S-RXX-3`Z
M+30N.#4P)UT@/2`G0V]R9&]B82`O($%E<F]P=65R=&\G.PHD8V]O<F1I;F%T
M97-;)U-P86EN)UU;)S,W+CDU,#HM,2XR,S,G72`]("=-=7)C:6$@+R!!;&-A
M;G1A<FEL;&$G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S,X+C(X,SHM,"XU
M-3`G72`]("=!;&EC86YT92`O($5L($%L=&5T)SL*)&-O;W)D:6YA=&5S6R=3
M<&%I;B==6R<S."XU,3<Z+34N,3$W)UT@/2`G2&EN;VIO<V$@1&5L($1U<75E
M)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<S."XX-C<Z,2XS.#,G72`]("=)
M8FEZ82`O($5S($-O9&]L82<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG,S@N
M.#@S.BTV+C@Q-R==(#T@)T)A9&%J;WH@+R!486QA=F5R82!,82!296%L)SL*
M)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<S."XY-3`Z+3$N.#4P)UT@/2`G06QB
M86-E=&4@+R!,;W,@3&QA;F]S)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<S
M.2XU,#`Z+3`N-#8W)UT@/2`G5F%L96YC:6$@+R!!97)O<'5E<G1O)SL*)&-O
M;W)D:6YA=&5S6R=3<&%I;B==6R<S.2XU-3`Z,BXW,S,G72`]("=086QM82!$
M92!-86QL;W)C82`O(%-O;B!386X@2G5A;B<["B1C;V]R9&EN871E<ULG4W!A
M:6XG75LG,SDN.#8W.C0N,C,S)UT@/2`G365N;W)C82`O($UA:&]N)SL*)&-O
M;W)D:6YA=&5S6R=3<&%I;B==6R<T,"XS,#`Z+3,N-S$W)UT@/2`G36%D<FED
M("\@1V5T869E)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T,"XS.#,Z+3,N
M-S@S)UT@/2`G36%D<FED("\@0W5A=')O(%9I96YT;W,G.PHD8V]O<F1I;F%T
M97-;)U-P86EN)UU;)S0P+C0U,#HM,RXU-3`G72`]("=-861R:60@+R!"87)A
M:F%S)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T,"XT.#,Z+3,N-#4P)UT@
M/2`G36%D<FED("\@5&]R<F5J;VXG.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;
M)S0P+C8U,#HM,RXW,S,G72`]("=-861R:2U#;VQM96YA<B<["B1C;V]R9&EN
M871E<ULG4W!A:6XG75LG-#`N.3,S.BTQ+C,P,"==(#T@)T-A;&%M;V-H82<[
M"B1C;V]R9&EN871E<ULG4W!A:6XG75LG-#`N.34P.BTU+C4P,"==(#T@)U-A
M;&%M86YC82`O($UA=&%C86XG.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S0Q
M+C$U,#HQ+C$V-R==(#T@)U)E=7,@+R!!97)O<'5E<G1O)SL*)&-O;W)D:6YA
M=&5S6R=3<&%I;B==6R<T,2XR.#,Z,BXP-C<G72`]("="87)C96QO;F$@+R!!
M97)O<'5E<G1O)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T,2XV-C<Z+3$N
M,#$W)UT@/2`G6F%R86=O>F$@+R!!97)O<'5E<G1O)SL*)&-O;W)D:6YA=&5S
M6R=3<&%I;B==6R<T,2XW,3<Z+30N.#4P)UT@/2`G5F%L;&%D;VQI9"`O(%9I
M;&QA;G5B;&$G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S0Q+CDP,#HR+C<V
M-R==(#T@)T=E<F]N82`O($-O<W1A($)R879A)SL*)&-O;W)D:6YA=&5S6R=3
M<&%I;B==6R<T,BXR,3<Z+3@N-C,S)UT@/2`G5FEG;R`O(%!E:6YA9&]R)SL*
M)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T,BXS-C<Z+3,N-C,S)UT@/2`G0G5R
M9V]S("\@5FEL;&%F<FEA)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T,BXT
M-3`Z+3(N,S,S)UT@/2`G3&]G<F]N;R`O($%G;VYC:6QL;R<["B1C;V]R9&EN
M871E<ULG4W!A:6XG75LG-#(N-3@S.BTU+C8U,"==(#T@)TQE;VX@+R!6:7)G
M96X@1&5L($-A;6EN;R<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG-#(N-S8W
M.BTQ+C8S,R==(#T@)U!A;7!L;VYA("\@3F]A:6XG.PHD8V]O<F1I;F%T97-;
M)U-P86EN)UU;)S0R+C@X,SHM,BXW,3<G72`]("=6:71O<FEA)SL*)&-O;W)D
M:6YA=&5S6R=3<&%I;B==6R<T,BXY,#`Z+3@N-#,S)UT@/2`G4V%N=&EA9V\@
M+R!,86)A8V]L;&$G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S0S+C,P,#HM
M,BXY,S,G72`]("=":6QB86\@+R!3;VYD:6-A)SL*)&-O;W)D:6YA=&5S6R=3
M<&%I;B==6R<T,RXS,#`Z+3@N,S@S)UT@/2`G3&$@0V]R=6YA("\@06QV961R
M;R<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG-#,N,S4P.BTQ+C@P,"==(#T@
M)U-A;B!396)A<W1I86X@+R!&=65N=&5R<F%B:6$G.PHD8V]O<F1I;F%T97-;
M)U-P86EN)UU;)S0S+C0S,SHM,RXX,3<G72`]("=386YT86YD97(@+R!087)A
M>6%S)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T,RXU-3`Z+38N,#,S)UT@
M/2`G07-T=7)I87,@+R!!=FEL97,G.PHD8V]O<F1I;F%T97-;)U-R:2!,86YK
M82==6R<V+C@Q-SHW.2XX.#,G72`]("=2871M86QA;F$G.PHD8V]O<F1I;F%T
M97-;)U-R:2!,86YK82==6R<W+C$V-SHW.2XX.#,G72`]("=+871U;F%Y86ME
M)SL*)&-O;W)D:6YA=&5S6R=3<FD@3&%N:V$G75LG-RXW,3<Z.#$N-S`P)UT@
M/2`G0F%T=&EC86QO82<["B1C;V]R9&EN871E<ULG4W)I($QA;FMA)UU;)S@N
M,S,S.C@P+C0Q-R==(#T@)T%N=7)A9&AA<'5R82<["B1C;V]R9&EN871E<ULG
M4W)I($QA;FMA)UU;)S@N-3@S.C@Q+C(U,"==(#T@)U1R:6YC;VUA;&5E)SL*
M)&-O;W)D:6YA=&5S6R=3=61A;B==6R<Q,2XP,#`Z,CDN-S$W)UT@/2`G2V%D
M=6=L:2<["B1C;V]R9&EN871E<ULG4W5D86XG75LG,3$N-S4P.C,R+C<X,R==
M(#T@)U)E;FLG.PHD8V]O<F1I;F%T97-;)U-U9&%N)UU;)S$Q+C<X,SHS-"XS
M.#,G72`]("=$86UA>FEN92<["B1C;V]R9&EN871E<ULG4W5D86XG75LG,3(N
M,#4P.C(T+C@X,R==(#T@)TYY86QA)SL*)&-O;W)D:6YA=&5S6R=3=61A;B==
M6R<Q,RXQ-C<Z,S`N,C,S)UT@/2`G16P@3V)E:60G.PHD8V]O<F1I;F%T97-;
M)U-U9&%N)UU;)S$S+C$V-SHS,BXV-C<G72`]("=+;W-T:2<["B1C;V]R9&EN
M871E<ULG4W5D86XG75LG,3,N-#@S.C(R+C0U,"==(#T@)T=E;F5I;F$G.PHD
M8V]O<F1I;F%T97-;)U-U9&%N)UU;)S$S+C4U,#HS,RXV,3<G72`]("=396YN
M87(G.PHD8V]O<F1I;F%T97-;)U-U9&%N)UU;)S$S+C8Q-SHR-2XS,S,G72`]
M("=%;"!&87-H97(G.PHD8V]O<F1I;F%T97-;)U-U9&%N)UU;)S$T+C`S,SHS
M-2XT,#`G72`]("='961A<F5F)SL*)&-O;W)D:6YA=&5S6R=3=61A;B==6R<Q
M-2XT-C<Z,S8N-#`P)UT@/2`G2V%S<V%L82<["B1C;V]R9&EN871E<ULG4W5D
M86XG75LG,34N-C`P.C,R+C4U,"==(#T@)TMH87)T;W5M)SL*)&-O;W)D:6YA
M=&5S6R=3=61A;B==6R<Q-RXW,#`Z,S,N.38W)UT@/2`G071B87)A)SL*)&-O
M;W)D:6YA=&5S6R=3=61A;B==6R<Q.2XQ-C<Z,S`N-#@S)UT@/2`G1&]N9V]L
M82<["B1C;V]R9&EN871E<ULG4W5D86XG75LG,3DN-3@S.C,W+C(Q-R==(#T@
M)U!O<G0@4W5D86XG.PHD8V]O<F1I;F%T97-;)U-U9&%N)UU;)S(Q+C@Q-SHS
M,2XT.#,G72`]("=7861I($AA;&9A)SL*)&-O;W)D:6YA=&5S6R=3=61A;B==
M6R<T+C@V-SHS,2XV,#`G72`]("=*=6)A)SL*)&-O;W)D:6YA=&5S6R=3=61A
M;B==6R<Y+C4U,#HS,2XV-3`G72`]("=-86QA:V%L)SL*)&-O;W)D:6YA=&5S
M6R=3=7)I;F%M92==6R<U+C0U,#HM-34N,C`P)UT@/2`G6F%N9&5R:6HG.PHD
M8V]O<F1I;F%T97-;)U-W87II;&%N9"==6R<M,C8N-3,S.C,Q+C,P,"==(#T@
M)TUA;GII;FD@+R!-871S87!A($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U-W
M961E;B==6R<U-2XU-3`Z,3,N,S8W)UT@/2`G36%L;6\@+R!3='5R=7`G.PHD
M8V]O<F1I;F%T97-;)U-W961E;B==6R<U-2XY,3<Z,30N,#@S)UT@/2`G2W)I
M<W1I86YS=&%D("\@179E<F]D)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG
M-38N,#@U.C$S+C(P-R==(#T@)TQJ=6YG8GEH960L($QJ=6YG8GEH960@*%-7
M12U!1D(I)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-38N,C8W.C$U+C(X
M,R==(#T@)U)O;FYE8GDG.PHD8V]O<F1I;F%T97-;)U-W961E;B==6R<U-BXS
M,#`Z,3(N.#4P)UT@/2`G06YG96QH;VQM)SL*)&-O;W)D:6YA=&5S6R=3=V5D
M96XG75LG-38N-C@S.C$R+C@S,R==(#T@)TAA;&US=&%D(%-W961I<V@@06ER
M($9O<F-E($)A<V4G.PHD8V]O<F1I;F%T97-;)U-W961E;B==6R<U-BXW,S,Z
M,38N,S`P)UT@/2`G2V%L;6%R)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG
M-38N.#4P.C$T+C@S,R==(#T@)U9A>&IO)SL*)&-O;W)D:6YA=&5S6R=3=V5D
M96XG75LG-3<N,S`P.C$T+C$S,R==(#T@)TAA9W-H=6QT)SL*)&-O;W)D:6YA
M=&5S6R=3=V5D96XG75LG-3<N-3$W.C$U+C@S,R==(#T@)TAU;'1S9G)E9"!3
M=V5D:7-H($%I<B!&;W)C92!"87-E)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG
M75LG-3<N-C8W.C$R+C,P,"==(#T@)T=O=&5B;W)G("\@3&%N9'9E='1E<B<[
M"B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S4W+C8V-SHQ."XS-3`G72`]("=6
M:7-B>2!&;'EG<&QA=',G.PHD8V]O<F1I;F%T97-;)U-W961E;B==6R<U-RXW
M-C<Z,30N,#@S)UT@/2`G2F]N:V]P:6YG($9L>6=P;&%T<R<["B1C;V]R9&EN
M871E<ULG4W=E9&5N)UU;)S4W+C<X,SHQ,2XX.#,G72`]("=';W1E8F]R9R`O
M(%-A=F4G.PHD8V]O<F1I;F%T97-;)U-W961E;B==6R<U."XT,#`Z,34N-3$W
M)UT@/2`G3&EN:V]P:6YG("\@36%L;65N)SL*)&-O;W)D:6YA=&5S6R=3=V5D
M96XG75LG-3@N-#,S.C$R+C<P,"==(#T@)U-A=&5N87,G.PHD8V]O<F1I;F%T
M97-;)U-W961E;B==6R<U."XT-3`Z,3,N.38W)UT@/2`G4VMO=F1E($9L>6=P
M;&%T<R<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S4X+C4X,SHQ-BXQ-3`G
M72`]("=.;W)R:V]P:6YG)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-3DN
M,S4P.C$W+CDU,"==(#T@)U-T;V-K:&]L;2`O($)R;VUM82<["B1C;V]R9&EN
M871E<ULG4W=E9&5N)UU;)S4Y+C,V-SHQ,RXT-C<G72`]("=+87)L<W1A9"!&
M;'EG<&QA=',G.PHD8V]O<F1I;F%T97-;)U-W961E;B==6R<U.2XU.#,Z,38N
M-C,S)UT@/2`G5F%S=&5R87,@+R!(87-S;&\G.PHD8V]O<F1I;F%T97-;)U-W
M961E;B==6R<U.2XV-3`Z,3<N.34P)UT@/2`G4W1O8VMH;VQM("\@07)L86YD
M82<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S4Y+C@X,SHQ-RXV,#`G72`]
M("=5<'!S86QA)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-C`N-#,S.C$U
M+C4Q-R==(#T@)T)O<FQA;F=E)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG
M-C`N-C`P.C$V+CDU,"==(#T@)T=A=FQE("\@4V%N9'9I:V5N($%I<B!&;W)C
M92!"87-E)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-C$N,C8W.C$W+C$P
M,"==(#T@)U-O9&5R:&%M;B<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S8R
M+C4S,SHQ-RXT-3`G72`]("=3=6YD<W9A;&PM2&%R;F]S86YD($9L>6=P;&%T
M<R<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S8S+C`U,#HQ-RXW-C<G72`]
M("=+<F%M9F]R<R!&;'EG<&QA=',G.PHD8V]O<F1I;F%T97-;)U-W961E;B==
M6R<V,RXQ.#,Z,30N-3`P)UT@/2`G3W-T97)S=6YD("\@1G)O<V]N)SL*)&-O
M;W)D:6YA=&5S6R=3=V5D96XG75LG-C,N-#`P.C$X+CDV-R==(#T@)T]R;G-K
M;VQD<W9I:R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-C,N
M.#`P.C(P+C(X,R==(#T@)U5M96$@1FQY9W!L871S)SL*)&-O;W)D:6YA=&5S
M6R=3=V5D96XG75LG-C0N-C,S.C(Q+C`X,R==(#T@)U-K96QL969T96$@06ER
M<&]R="<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S8T+CDV-SHQ-RXW,#`G
M72`]("='=6YN87)N)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-C4N-34P
M.C(R+C$S,R==(#T@)TQU;&5A("\@2V%L;&%X)SL*)&-O;W)D:6YA=&5S6R=3
M=V5D96XG75LG-C4N.#8W.C(P+C$S,R==(#T@)U9I9'-E;"<["B1C;V]R9&EN
M871E<ULG4W=E9&5N)UU;)S8V+C8S,SHQ.2XV-3`G72`]("=*;VMK;6]K:R<[
M"B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S8W+C$U,#HR,"XV-3`G72`]("='
M86QL:79A<F4G.PHD8V]O<F1I;F%T97-;)U-W961E;B==6R<V-RXX,3<Z,C`N
M,S,S)UT@/2`G2VER=6YA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U-W:71Z
M97)L86YD)UU;)S0V+C`P,#HX+CDV-R==(#T@)TQU9V%N;R<["B1C;V]R9&EN
M871E<ULG4W=I='IE<FQA;F0G75LG-#8N,C$W.C<N,S,S)UT@/2`G4VEO;B<[
M"B1C;V]R9&EN871E<ULG4W=I='IE<FQA;F0G75LG-#8N,C4P.C8N,3,S)UT@
M/2`G1V5N979E+4-O:6YT<FEN)SL*)&-O;W)D:6YA=&5S6R=3=VET>F5R;&%N
M9"==6R<T-BXU-3`Z-BXV,3<G72`]("=,875S86YN92<["B1C;V]R9&EN871E
M<ULG4W=I='IE<FQA;F0G75LG-#8N.#$W.C8N.34P)UT@/2`G4&%Y97)N92<[
M"B1C;V]R9&EN871E<ULG4W=I='IE<FQA;F0G75LG-#<N,#`P.C8N.34P)UT@
M/2`G3F5U8VAA=&5L)SL*)&-O;W)D:6YA=&5S6R=3=VET>F5R;&%N9"==6R<T
M-RXQ.#$Z-RXT,38G72`]("='<F5N8VAE;B<["B1C;V]R9&EN871E<ULG4W=I
M='IE<FQA;F0G75LG-#<N-#@S.C@N-3,S)UT@/2`G6G5R:6-H+4ML;W1E;B<[
M"B1C;V]R9&EN871E<ULG4W=I='IE<FQA;F0G75LG-#<N-#@U.CDN-38R)UT@
M/2`G4V%I;G0@1V%L;&5N+4%L=&5N<FAE:6XG.PHD8V]O<F1I;F%T97-;)U-Y
M<FEA;B!!<F%B(%)E<'5B;&EC)UU;)S,S+C0Q-SHS-BXU,3<G72`]("=$86UA
M<V-U<R!);G0N($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U-Y<FEA;B!!<F%B
M(%)E<'5B;&EC)UU;)S,T+C4U,#HS."XS,#`G72`]("=086QM>7)A)SL*)&-O
M;W)D:6YA=&5S6R=3>7)I86X@07)A8B!297!U8FQI8R==6R<S-2XS,3<Z-#`N
M,34P)UT@/2`G1&5I<B!%>GIO<B<["B1C;V]R9&EN871E<ULG4WER:6%N($%R
M86(@4F5P=6)L:6,G75LG,S4N-3,S.C,U+C<V-R==(#T@)TQA='1A:VEA)SL*
M)&-O;W)D:6YA=&5S6R=3>7)I86X@07)A8B!297!U8FQI8R==6R<S-BXQ.#,Z
M,S<N,C`P)UT@/2`G06QE<'!O($EN=&5R;F%T:6]N86P@06ER<&]R="<["B1C
M;V]R9&EN871E<ULG4WER:6%N($%R86(@4F5P=6)L:6,G75LG,S<N,#4P.C0Q
M+C(Q-R==(#T@)TMA;6ES:&QI)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG
M,C`N-C8W.C$Q-BXW,3<G72`]("=$;VYG<VAA)SL*)&-O;W)D:6YA=&5S6R=4
M86EW86XG75LG,C$N.3,S.C$R,"XX,S,G72`]("=(96YG8VAU;B<["B1C;V]R
M9&EN871E<ULG5&%I=V%N)UU;)S(R+C`S,SHQ,C$N-34P)UT@/2`G3&%N(%EU
M)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG,C(N-#$W.C$R,"XU-3`G72`]
M("=#:&EA(%1U;F<G.PHD8V]O<F1I;F%T97-;)U1A:7=A;B==6R<R,BXT-C<Z
M,3(P+C0S,R==(#T@)T1O;F=G86YG)SL*)&-O;W)D:6YA=&5S6R=486EW86XG
M75LG,C(N-3@S.C$R,"XS-3`G72`]("=+86]H<VEU;F<@26YT97)N871I;VYA
M;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG,C(N-C@S.C$R
M,"XT-C<G72`]("=0:6YG='5N9R!3;W5T:"!!:7(@1F]R8V4@0F%S92<["B1C
M;V]R9&EN871E<ULG5&%I=V%N)UU;)S(R+C<P,#HQ,C`N-#@S)UT@/2`G4&EN
M9W1U;F<@3F]R=&@@06ER($9O<F-E($)A<V4G.PHD8V]O<F1I;F%T97-;)U1A
M:7=A;B==6R<R,BXW.#,Z,3(P+C(V-R==(#T@)TMA;F=S:&%N(%1W+4%F8B<[
M"B1C;V]R9&EN871E<ULG5&%I=V%N)UU;)S(R+C@P,#HQ,C$N,3@S)UT@/2`G
M0VAI:&AA;F<@5'<M069B)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG,C(N
M.34P.C$R,"XR,#`G72`]("=486EN86X@5'<M069B)SL*)&-O;W)D:6YA=&5S
M6R=486EW86XG75LG,C,N,C8W.C$Q.2XV-C<G72`]("=$;VYG<VAI)SL*)&-O
M;W)D:6YA=&5S6R=486EW86XG75LG,C,N-#8W.C$R,"XS.#,G72`]("=#:&EA
M>6D@5'<M069B)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG,C,N-3@S.C$Q
M.2XV,3<G72`]("=-86MU;F<@06(G.PHD8V]O<F1I;F%T97-;)U1A:7=A;B==
M6R<R-"XP,S,Z,3(Q+C8Q-R==(#T@)TAU;&EE;B!!8B<["B1C;V]R9&EN871E
M<ULG5&%I=V%N)UU;)S(T+C$X,SHQ,C`N-C4P)UT@/2`G5&%I8VAU;F<@5'<M
M069B)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG,C0N,C8W.C$R,"XV,3<G
M72`]("=7=6-H:6$@3V)S97)V871O<GDG.PHD8V]O<F1I;F%T97-;)U1A:7=A
M;B==6R<R-"XT,S,Z,3$X+C,V-R==(#T@)T-H:6YM96T@+R!3:&%T;W4@06ER
M($9O<F-E($)A<V4G.PHD8V]O<F1I;F%T97-;)U1A:7=A;B==6R<R-"XW-3`Z
M,3(Q+C<V-R==(#T@)TEL86XG.PHD8V]O<F1I;F%T97-;)U1A:7=A;B==6R<R
M-"XX,3<Z,3(P+CDS,R==(#T@)TAS:6YC:'4@5'<M069B)SL*)&-O;W)D:6YA
M=&5S6R=486EW86XG75LG,C0N.3,S.C$R,2XS,#`G72`]("=082!+=65I("\@
M0F%K=6%I)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG,C4N,#8W.C$R,2XR
M,S,G72`]("=486]Y=6%N($%B(#T@-3@Y-C4P)SL*)&-O;W)D:6YA=&5S6R=4
M86EW86XG75LG,C4N,#8W.C$R,2XU-3`G72`]("=3=6YG<VAA;B`O(%1A:7!E
M:2<["B1C;V]R9&EN871E<ULG5&%I=V%N)UU;)S(U+C`X,SHQ,C$N,C$W)UT@
M/2`G0VAI86YG($MA:2!3:&5K)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG
M,C8N,38W.C$Q.2XY,S,G72`]("=-87IU)SL*)&-O;W)D:6YA=&5S6R=486II
M:VES=&%N)UU;)S,X+C4U,#HV."XW.#,G72`]("=$=7-H86YB92<["B1C;V]R
M9&EN871E<ULG5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B==6R<M,2XS
M,S,Z,S$N.#$W)UT@/2`G0G5K;V)A)SL*)&-O;W)D:6YA=&5S6R=486YZ86YI
M82P@56YI=&5D(%)E<'5B;&EC(&]F)UU;)RTQ+C4P,#HS,RXX,#`G72`]("=-
M=7-O;6$G.PHD8V]O<F1I;F%T97-;)U1A;GIA;FEA+"!5;FET960@4F5P=6)L
M:6,@;V8G75LG+3$P+C(V-SHT,"XQ.#,G72`]("=-='=A<F$G.PHD8V]O<F1I
M;F%T97-;)U1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8G75LG+3$P+C,U
M,#HS."XW-3`G72`]("=.86-H:6YG=V5A)SL*)&-O;W)D:6YA=&5S6R=486YZ
M86YI82P@56YI=&5D(%)E<'5B;&EC(&]F)UU;)RTQ,"XV.#,Z,S4N-3@S)UT@
M/2`G4V]N9V5A)SL*)&-O;W)D:6YA=&5S6R=486YZ86YI82P@56YI=&5D(%)E
M<'5B;&EC(&]F)UU;)RTR+C0V-SHS,BXY,3<G72`]("=-=V%N>F$G.PHD8V]O
M<F1I;F%T97-;)U1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8G75LG+3,N
M,S,S.C,V+C8Q-R==(#T@)T%R=7-H82<["B1C;V]R9&EN871E<ULG5&%N>F%N
M:6$L(%5N:71E9"!297!U8FQI8R!O9B==6R<M,RXS-3`Z,S<N,S,S)UT@/2`G
M36]S:&DG.PHD8V]O<F1I;F%T97-;)U1A;GIA;FEA+"!5;FET960@4F5P=6)L
M:6,@;V8G75LG+3,N-#$W.C,W+C`V-R==(#T@)TMI;&EM86YJ87)O($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)U1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@
M;V8G75LG+30N,#@S.C,W+C<Q-R==(#T@)U-A;64G.PHD8V]O<F1I;F%T97-;
M)U1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8G75LG+30N.#@S.C(Y+C8S
M,R==(#T@)TMI9V]M82<["B1C;V]R9&EN871E<ULG5&%N>F%N:6$L(%5N:71E
M9"!297!U8FQI8R!O9B==6R<M-"XX.#,Z,S@N,C@S)UT@/2`G36]M8F\G.PHD
M8V]O<F1I;F%T97-;)U1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8G75LG
M+34N,#@S.C,R+C@S,R==(#T@)U1A8F]R82!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R=486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F)UU;)RTU+C`X,SHS
M.2XP-C<G72`]("=486YG82<["B1C;V]R9&EN871E<ULG5&%N>F%N:6$L(%5N
M:71E9"!297!U8FQI8R!O9B==6R<M-2XR-3`Z,SDN.#$W)UT@/2`G4&5M8F$@
M+R!+87)U;64@06ER<&]R="<["B1C;V]R9&EN871E<ULG5&%N>F%N:6$L(%5N
M:71E9"!297!U8FQI8R!O9B==6R<M-BXQ-C<Z,S4N-S8W)UT@/2`G1&]D;VUA
M)SL*)&-O;W)D:6YA=&5S6R=486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F
M)UU;)RTV+C(Q-SHS.2XR,3<G72`]("=:86YZ:6)A<B`O($MI<V%U;FDG.PHD
M8V]O<F1I;F%T97-;)U1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8G75LG
M+38N.#,S.C,W+C8U,"==(#T@)TUO<F]G;W)O)SL*)&-O;W)D:6YA=&5S6R=4
M86YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F)UU;)RTV+C@V-SHS.2XR,#`G
M72`]("=$87(@17,@4V%L86%M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U1A
M;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8G75LG+3<N-C8W.C,U+C<U,"==
M(#T@)TER:6YG82<["B1C;V]R9&EN871E<ULG5&%N>F%N:6$L(%5N:71E9"!2
M97!U8FQI8R!O9B==6R<M."XY,S,Z,S,N-#8W)UT@/2`G36)E>6$G.PHD8V]O
M<F1I;F%T97-;)U1H86EL86YD)UU;)S$P+C0X,SHY.2XQ.#,G72`]("=#:'5M
M<&AO;B<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG,3$N.#,S.CDY+C@S
M,R==(#T@)U!R86-H=6%P($MH:7)I:VAA;B<["B1C;V]R9&EN871E<ULG5&AA
M:6QA;F0G75LG,3(N-3@S.CDY+CDU,"==(#T@)TAU82!(:6XG.PHD8V]O<F1I
M;F%T97-;)U1H86EL86YD)UU;)S$R+C8P,#HQ,#(N,3$W)UT@/2`G0VAA;G1H
M86)U<FDG.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S$R+C8S,SHQ,#$N
M,S4P)UT@/2`G4F%Y;VYG)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q
M,RXQ-3`Z,3`P+C`V-R==(#T@)U!H971C:&%B=7)I)SL*)&-O;W)D:6YA=&5S
M6R=4:&%I;&%N9"==6R<Q,RXS-C<Z,3`P+CDX,R==(#T@)T-H;VX@0G5R:2<[
M"B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG,3,N.3$W.C$P,"XV,#`G72`]
M("=$;VX@375A;F<G.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S$T+C`Q
M-SHY.2XU,S,G72`]("=+86YC:&%N86)U<FDG.PHD8V]O<F1I;F%T97-;)U1H
M86EL86YD)UU;)S$T+C`U,#HQ,#$N,S8W)UT@/2`G4')A8VAI;B!"=7)I)SL*
M)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q-"XY-C<Z,3`R+C`X,R==(#T@
M)TYA:VAO;B!2871C:&%S:6UA)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==
M6R<Q-2XR-3`Z,3`T+C@V-R==(#T@)U5B;VX@4F%T8VAA=&AA;FDG.PHD8V]O
M<F1I;F%T97-;)U1H86EL86YD)UU;)S$U+C@P,#HQ,#`N,38W)UT@/2`G3F%K
M:&]N(%-A=V%N)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q-2XX,#`Z
M,3`R+C`S,R==(#T@)T-H86EY87!H=6TG.PHD8V]O<F1I;F%T97-;)U1H86EL
M86YD)UU;)S$V+C`U,#HQ,#,N-C@S)UT@/2`G4F]I($5T)SL*)&-O;W)D:6YA
M=&5S6R=4:&%I;&%N9"==6R<Q-BXT,S,Z,3`R+C@S,R==(#T@)TMH;VX@2V%E
M;B<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG,38N-3,S.C$P-"XW,3<G
M72`]("=-=6MD86AA;B<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG,38N
M-C8W.CDX+C4U,"==(#T@)TUA92!3;W0G.PHD8V]O<F1I;F%T97-;)U1H86EL
M86YD)UU;)S$V+C<X,SHQ,#`N,C8W)UT@/2`G4&AI='-A;G5L;VLG.PHD8V]O
M<F1I;F%T97-;)U1H86EL86YD)UU;)S$V+C@X,SHY.2XQ-3`G72`]("=486LG
M.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S$W+C$U,#HQ,#0N,3,S)UT@
M/2`G4V%K;VX@3F%K:&]N)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q
M-RXS.#,Z,3`R+C@P,"==(#T@)U5D;VX@5&AA;FDG.PHD8V]O<F1I;F%T97-;
M)U1H86EL86YD)UU;)S$W+C0Q-SHQ,#0N-S@S)UT@/2`G3F%K:&]N(%!H86YO
M;2<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG,3<N-#4P.C$P,2XW,S,G
M72`]("=,;V5I)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q-RXV,3<Z
M,3`P+C$P,"==(#T@)U5T=&%R861I="<["B1C;V]R9&EN871E<ULG5&AA:6QA
M;F0G75LG,3<N.#8W.C$P,BXW,3<G72`]("=.;VYG($MH86DG.PHD8V]O<F1I
M;F%T97-;)U1H86EL86YD)UU;)S$X+C$V-SHQ,#`N,38W)UT@/2`G4&AR864G
M.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S$X+C$V-SHY-RXY,S,G72`]
M("=-864@4V%R:6%N9R<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG,3@N
M,C@S.CDY+C4Q-R==(#T@)TQA;7!A;F<G.PHD8V]O<F1I;F%T97-;)U1H86EL
M86YD)UU;)S$X+C<V-SHQ,#`N-S8W)UT@/2`G3F%N)SL*)&-O;W)D:6YA=&5S
M6R=4:&%I;&%N9"==6R<Q."XW.#,Z.3@N.3@S)UT@/2`G0VAI86YG($UA:2<[
M"B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG,3DN,S`P.CDW+C@S,R==(#T@
M)TUA92!(;VYG(%-O;B<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG,3DN
M.3$W.CDY+C@S,R==(#T@)T-H:6%N9R!286DG.PHD8V]O<F1I;F%T97-;)U1H
M86EL86YD)UU;)S8N-C4P.C$P,"XP.#,G72`]("=3871U;B<["B1C;V]R9&EN
M871E<ULG5&AA:6QA;F0G75LG-BXW.#,Z,3`Q+C$U,"==(#T@)U!A='1A;FDG
M.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S8N.3$W.C$P,"XT,S,G72`]
M("=(870@66%I)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<W+C(P,#HQ
M,#`N-C`P)UT@/2`G4V]N9VMH;&$G.PHD8V]O<F1I;F%T97-;)U1H86EL86YD
M)UU;)S<N-3$W.CDY+C8Q-R==(#T@)U1R86YG)SL*)&-O;W)D:6YA=&5S6R=4
M:&%I;&%N9"==6R<X+C$Q-SHY."XS,3<G72`]("=0:'5K970@06ER<&]R="<[
M"B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG."XT-C<Z.3DN.38W)UT@/2`G
M3F%K:&]N(%-I(%1H86UM87)A="<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G
M75LG.2XQ,3<Z.3DN,S4P)UT@/2`G4W5R870@5&AA;FDG.PHD8V]O<F1I;F%T
M97-;)U1H86EL86YD)UU;)SDN.3@S.CDX+C8Q-R==(#T@)U)A;F]N9R<["B1C
M;V]R9&EN871E<ULG5&]G;R==6R<Q,"XS-C<Z,"XT-C<G72`]("=-86YG;R<[
M"B1C;V]R9&EN871E<ULG5&]G;R==6R<V+C$V-SHQ+C(U,"==(#T@)TQO;64G
M.PHD8V]O<F1I;F%T97-;)U1O9V\G75LG-BXU.#,Z,2XU,#`G72`]("=486)L
M:6=B;R<["B1C;V]R9&EN871E<ULG5&]G;R==6R<W+C4X,SHQ+C$Q-R==(#T@
M)T%T86MP86UE)SL*)&-O;W)D:6YA=&5S6R=4;V=O)UU;)S@N.3@S.C$N,34P
M)UT@/2`G4V]K;V1E)SL*)&-O;W)D:6YA=&5S6R=4;V=O)UU;)SDN-S8W.C$N
M,3`P)UT@/2`G3FEA;71O=6=O=2<["B1C;V]R9&EN871E<ULG5&]N9V$G75LG
M+3$Y+C@P,#HM,3<T+C,U,"==(#T@)TAA87!A:2<["B1C;V]R9&EN871E<ULG
M5&]N9V$G75LG+3(Q+C(S,SHM,3<U+C$U,"==(#T@)T9U85PG06UO='4G.PHD
M8V]O<F1I;F%T97-;)U1R:6YI9&%D(&%N9"!4;V)A9V\G75LG,3`N-C$W.BTV
M,2XS-3`G72`]("=0:6%R8V\@26YT97)N871I;VYA;"!!:7)P;W)T+"!4<FEN
M:61A9"<["B1C;V]R9&EN871E<ULG5')I;FED860@86YD(%1O8F%G;R==6R<Q
M,2XQ-3`Z+38P+C@S,R==(#T@)T-R;W=N(%!O:6YT($%I<G!O<G0L(%1O8F%G
M;R<["B1C;V]R9&EN871E<ULG5'5N:7-I82==6R<S,2XV.#,Z.2XQ-C<G72`]
M("=%;"!";W)M82<["B1C;V]R9&EN871E<ULG5'5N:7-I82==6R<S,BXS,3<Z
M,3`N-#`P)UT@/2`G4F5M861A)SL*)&-O;W)D:6YA=&5S6R=4=6YI<VEA)UU;
M)S,S+C@V-SHQ,"XW-C<G72`]("=$:F5R8F$@365L;&ET82<["B1C;V]R9&EN
M871E<ULG5'5N:7-I82==6R<S,RXX.#,Z,3`N,3`P)UT@/2`G1V%B97,G.PHD
M8V]O<F1I;F%T97-;)U1U;FES:6$G75LG,S,N.3$W.C@N,3`P)UT@/2`G5&]Z
M975R)SL*)&-O;W)D:6YA=&5S6R=4=6YI<VEA)UU;)S,T+C0Q-SHX+C@Q-R==
M(#T@)T=A9G-A)SL*)&-O;W)D:6YA=&5S6R=4=6YI<VEA)UU;)S,T+C<Q-SHQ
M,"XV.#,G72`]("=39F%X($5L+4UA;W4G.PHD8V]O<F1I;F%T97-;)U1U;FES
M:6$G75LG,S4N-C8W.C$P+C$P,"==(#T@)TMA:7)O=6%N)SL*)&-O;W)D:6YA
M=&5S6R=4=6YI<VEA)UU;)S,U+C8V-SHQ,"XW-3`G72`]("=-;VYA<W1I<BU3
M:V%N97,G.PHD8V]O<F1I;F%T97-;)U1U;FES:6$G75LG,S8N-#@S.C@N.#`P
M)UT@/2`G2F5N9&]U8F$G.PHD8V]O<F1I;F%T97-;)U1U;FES:6$G75LG,S8N
M.#,S.C$P+C(S,R==(#T@)U1U;FES+4-A<G1H86=E)SL*)&-O;W)D:6YA=&5S
M6R=4=6YI<VEA)UU;)S,V+C@U,#HQ,2XP.#,G72`]("=+96QI8FEA)SL*)&-O
M;W)D:6YA=&5S6R=4=6YI<VEA)UU;)S,V+CDU,#HX+C<U,"==(#T@)U1A8F%R
M:V$G.PHD8V]O<F1I;F%T97-;)U1U;FES:6$G75LG,S<N,C4P.CDN.#`P)UT@
M/2`G0FEZ97)T92<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,V+C4X,SHS
M-BXQ-C<G72`]("=)<VME;F1E<G5N)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG
M75LG,S8N-S`P.C(X+C<X,R==(#T@)T1A;&%M86XG.PHD8V]O<F1I;F%T97-;
M)U1U<FME>2==6R<S-BXW,#`Z,S`N-S,S)UT@/2`G06YT86QY82<["B1C;V]R
M9&EN871E<ULG5'5R:V5Y)UU;)S,V+CDX,SHS-2XS,#`G72`]("=!9&%N82`O
M(%-A:VER<&%S82<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,W+C`P,#HS
M-2XT,3<G72`]("=!9&%N82`O($EN8VER;&EK)SL*)&-O;W)D:6YA=&5S6R=4
M=7)K97DG75LG,S<N,#,S.C(W+C0Q-R==(#T@)T)O9')U;2<["B1C;V]R9&EN
M871E<ULG5'5R:V5Y)UU;)S,W+C`X,SHS-RXS-C<G72`]("='87II86YT97`G
M.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<S-RXQ,S,Z,S@N-S8W)UT@/2`G
M57)F82<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,W+C<U,#HS,"XU-3`G
M72`]("=)<W!A<G1A)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG,S<N.#4P
M.C(W+C@U,"==(#T@)T%Y9&EN)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG
M,S<N.#8W.C0Q+C$V-R==(#T@)T)A=&UA;B<["B1C;V]R9&EN871E<ULG5'5R
M:V5Y)UU;)S,W+C@X,SHT,"XQ.#,G72`]("=$:7EA<F)A:VER)SL*)&-O;W)D
M:6YA=&5S6R=4=7)K97DG75LG,S<N.38W.C,R+C4U,"==(#T@)TMO;GEA)SL*
M)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG,S@N,C8W.C(W+C$U,"==(#T@)TEZ
M;6ER("\@061N86X@365N9&5R97,G.PHD8V]O<F1I;F%T97-;)U1U<FME>2==
M6R<S."XT,S,Z,S@N,#@S)UT@/2`G36%L871Y82`O($5R:&%C)SL*)&-O;W)D
M:6YA=&5S6R=4=7)K97DG75LG,S@N-#4P.C0S+C,Q-R==(#T@)U9A;B<["B1C
M;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,X+C4P,#HR-RXP,3<G72`]("=)>FUI
M<B`O($-I9VQI)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG,S@N-C`P.C,Y
M+C(X,R==(#T@)T5L87II9R<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,X
M+C8V-SHR.2XT,3<G72`]("=5<V%K)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG
M75LG,S@N-S4P.C,P+C4S,R==(#T@)T%F>6]N)SL*)&-O;W)D:6YA=&5S6R=4
M=7)K97DG75LG,S@N-S@S.C,U+C0X,R==(#T@)TMA>7-E<FD@+R!%<FMI;&5T
M)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG,S@N.3$W.C(W+C@U,"==(#T@
M)T%K:&ES87(G.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<S.2XV,3<Z,C<N
M.3$W)UT@/2`G0F%L:6ME<VER)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG
M,SDN-S,S.C,Y+C4P,"==(#T@)T5R>FEN8V%N)SL*)&-O;W)D:6YA=&5S6R=4
M=7)K97DG75LG,SDN-S4P.C,W+C`Q-R==(#T@)U-I=F%S)SL*)&-O;W)D:6YA
M=&5S6R=4=7)K97DG75LG,SDN-S@S.C,P+C4V-R==(#T@)T5S:VES96AI<B<[
M"B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,Y+CDQ-SHT,2XR-C<G72`]("=%
M<GIU<G5M)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG,SDN.34P.C,R+C8X
M,R==(#T@)T%N:V%R82`O($5T:6UE<V=U="<["B1C;V]R9&EN871E<ULG5'5R
M:V5Y)UU;)S0P+C`X,SHS,BXU-C<G72`]("=-=7)T960@5'5R+4%F8B<["B1C
M;V]R9&EN871E<ULG5'5R:V5Y)UU;)S0P+C$Q-SHS,BXY.#,G72`]("=!;FMA
M<F$@+R!%<V5N8F]G82<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S0P+C$S
M,SHR-BXT,#`G72`]("=#86YA:VMA;&4G.PHD8V]O<F1I;F%T97-;)U1U<FME
M>2==6R<T,"XQ.#,Z,CDN,#8W)UT@/2`G0G5R<V$G.PHD8V]O<F1I;F%T97-;
M)U1U<FME>2==6R<T,"XS,#`Z,S8N-38W)UT@/2`G5&]K870G.PHD8V]O<F1I
M;F%T97-;)U1U<FME>2==6R<T,"XS,3<Z,C<N.38W)UT@/2`G0F%N9&ER;6$G
M.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<T,"XV,#`Z-#,N,#@S)UT@/2`G
M2V%R<R<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S0P+C@U,#HS-2XU.#,G
M72`]("=-97)Z:69O;B<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S0P+CDV
M-SHR."XX,3<G72`]("=)<W1A;F)U;"`O($%T871U<FLG.PHD8V]O<F1I;F%T
M97-;)U1U<FME>2==6R<T,2XP,#`Z,SDN-S$W)UT@/2`G5')A8GIO;B<["B1C
M;V]R9&EN871E<ULG5'5R:V5Y)UU;)S0Q+C(V-SHS-BXS,#`G72`]("=386US
M=6XG.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<T,2XT-3`Z,S$N.#`P)UT@
M/2`G6F]N9W5L9&%K)SL*)&-O;W)D:6YA=&5S6R=4=79A;'4G75LG+34N-C8W
M.C$W-BXQ,S,G72`]("=.86YU;65A)SL*)&-O;W)D:6YA=&5S6R=4=79A;'4G
M75LG+3@N-3$W.C$W.2XR,3<G72`]("=&=6YA9G5T:2<["B1C;V]R9&EN871E
M<ULG56=A;F1A)UU;)S`N,#4P.C,R+C0U,"==(#T@)T5N=&5B8F4@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG56=A;F1A)UU;)S`N,3@S.C,P+C$P,"==(#T@
M)TMA<V5S92<["B1C;V]R9&EN871E<ULG56=A;F1A)UU;)S`N-#4P.C,S+C$X
M,R==(#T@)TII;FIA)SL*)&-O;W)D:6YA=&5S6R=59V%N9&$G75LG+3`N-C$W
M.C,P+C8U,"==(#T@)TUB87)A<F$G.PHD8V]O<F1I;F%T97-;)U5G86YD82==
M6R<P+C8X,SHS-"XQ-C<G72`]("=4;W)O<F\G.PHD8V]O<F1I;F%T97-;)U5G
M86YD82==6R<M,2XR-3`Z,CDN.3@S)UT@/2`G2V%B86QE)SL*)&-O;W)D:6YA
M=&5S6R=59V%N9&$G75LG,2XV.#,Z,S$N-S$W)UT@/2`G36%S:6YD:2<["B1C
M;V]R9&EN871E<ULG56=A;F1A)UU;)S$N-S$W.C,S+C8Q-R==(#T@)U-O<F]T
M:2<["B1C;V]R9&EN871E<ULG56=A;F1A)UU;)S(N-S4P.C,R+C,S,R==(#T@
M)T=U;'4G.PHD8V]O<F1I;F%T97-;)U5G86YD82==6R<S+C`U,#HS,"XY,3<G
M72`]("=!<G5A)SL*)&-O;W)D:6YA=&5S6R=5:W)A:6YE)UU;)S0T+C8X,SHS
M-"XQ,S,G72`]("=3:6UF97)O<&]L)SL*)&-O;W)D:6YA=&5S6R=5:W)A:6YE
M)UU;)S0V+C0S,SHS,"XW-C<G72`]("=/9&5S82<["B1C;V]R9&EN871E<ULG
M56MR86EN92==6R<T.2XX,3<Z,C,N.34P)UT@/2`G3%PG5FEV)SL*)&-O;W)D
M:6YA=&5S6R=5:W)A:6YE)UU;)S0Y+CDV-SHS-BXQ,S,G72`]("=+:&%R:VEV
M)SL*)&-O;W)D:6YA=&5S6R=5:W)A:6YE)UU;)S4P+C,S,SHS,"XY-C<G72`]
M("=";W)Y<W!I;"<["B1C;V]R9&EN871E<ULG56MR86EN92==6R<U,"XT,#`Z
M,S`N-38W)UT@/2`G2WEI=B<["B1C;V]R9&EN871E<ULG56MR86EN92==6R<U
M,"XU.#,Z,C8N,3,S)UT@/2`G4FEV;F4G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!!<F%B($5M:7)A=&5S)UU;)S(T+C(V-SHU-2XV,#`G72`]("=!;"!!:6X@
M26YT97)N871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M07)A8B!%;6ER871E<R==6R<R-"XT,S,Z-30N-#8W)UT@/2`G06)U($1H86)I
M($)A=&5E;B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@07)A8B!%
M;6ER871E<R==6R<R-"XT,S,Z-30N-C4P)UT@/2`G06)U($1H86)I($EN=&5R
M;F%T:6]N86P@06ER<&]R="<["B1C;V]R9&EN871E<ULG56YI=&5D($%R86(@
M16UI<F%T97,G75LG,C4N,3`P.C4V+C,S,R==(#T@)T9U:F%I<F%H)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@07)A8B!%;6ER871E<R==6R<R-2XR-3`Z-34N
M,S,S)UT@/2`G1'5B86D@26YT97)N871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@07)A8B!%;6ER871E<R==6R<R-2XS,S,Z-34N-3$W
M)UT@/2`G4VAA<FIA:"!);G1E<FYA=&EO;F%L($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!!<F%B($5M:7)A=&5S)UU;)S(U+C8Q-SHU-2XY,S,G
M72`]("=287,@06P@2VAA:6UA:"!);G1E<FYA=&EO;F%L($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S0Y+C(Q-SHM,BXR,#`G
M72`]("=*97)S97D@06ER<&]R="<["B1C;V]R9&EN871E<ULG56YI=&5D($MI
M;F=D;VTG75LG-#DN-#,S.BTR+C8P,"==(#T@)T=U97)N<V5Y($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S0Y+CDQ-SHM-BXS
M,#`G72`]("=38VEL;'DL(%-A:6YT($UA<GE<)U,G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!+:6YG9&]M)UU;)S4P+C`X,SHM-2XR-3`G72`]("=#=6QD<F]S
M92<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3`N,S4P.BTT
M+C$Q-R==(#T@)U!L>6UO=71H)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN
M9V1O;2==6R<U,"XT,S,Z+34N,#`P)UT@/2`G4V%I;G0@36%W9V%N)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,"XU-C<Z+3(N-#4P)UT@
M/2`G4&]R=&QA;F0@+R!2;F%S)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN
M9V1O;2==6R<U,"XW,S,Z+3,N-#$W)UT@/2`G17AE=&5R($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4P+C<X,SHM,2XX,S,G
M72`]("=";W5R;F5M;W5T:"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@2VEN9V1O;2==6R<U,"XX,S,Z+3`N,C@S)UT@/2`G4VAO<F5H86T@06ER
M<&]R="<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3`N.3`P
M.BTQ+C0P,"==(#T@)U-O=71H86UP=&]N("\@5V5A=&AE<B!#96YT<F4G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4Q+C`P,#HM,BXV,S,G
M72`]("=996]V:6QT;VXG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M
M)UU;)S4Q+C`X,SHM-"XQ-3`G72`]("=#:&EV96YO<B<["B1C;V]R9&EN871E
M<ULG56YI=&5D($MI;F=D;VTG75LG-3$N,34P.BTP+C$X,R==(#T@)TQO;F1O
M;B`O($=A='=I8VL@06ER<&]R="<["B1C;V]R9&EN871E<ULG56YI=&5D($MI
M;F=D;VTG75LG-3$N,34P.BTQ+C4V-R==(#T@)TUI9&1L92!786QL;W`G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4Q+C$V-SHM,2XW-3`G
M72`]("=";W-C;VUB92!$;W=N)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN
M9V1O;2==6R<U,2XR,S,Z+3`N.34P)UT@/2`G3V1I:&%M)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@2VEN9V1O;2==6R<U,2XR.#,Z+3`N-S8W)UT@/2`G1F%R
M;F)O<F]U9V@@36EL:71A<GDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG
M9&]M)UU;)S4Q+C(X,SHM,"XW-C<G72`]("=&87)N8F]R;W5G:"<["B1C;V]R
M9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3$N,S4P.C$N,S4P)UT@/2`G
M36%N<W1O;B<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3$N
M,S@S.BTP+C<X,R==(#T@)T)R86-K;F5L;"`O($)E875F;W)T(%!A<FLG.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4Q+C0P,#HM,RXS-3`G
M72`]("=#87)D:69F+5=A;&5S($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!+:6YG9&]M)UU;)S4Q+C0X,SHM,"XT-3`G72`]("=,;VYD;VX@+R!(
M96%T:')O=R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O
M;2==6R<U,2XU,#`Z+3$N.3@S)UT@/2`G3'EN96AA;2<["B1C;V]R9&EN871E
M<ULG56YI=&5D($MI;F=D;VTG75LG-3$N-3$W.BTP+C$Q-R==(#T@)TQO;F1O
M;B!796%T:&5R($-E;G1R92<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D
M;VTG75LG-3$N-34P.BTP+C0Q-R==(#T@)TYO<G1H;VQT)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@2VEN9V1O;2==6R<U,2XV,3<Z+3$N,#@S)UT@/2`G0F5N
M<V]N)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,2XV.#,Z
M+3$N-S@S)UT@/2`G1F%I<F9O<F0@4F]Y86P@06ER($9O<F-E($)A<V4G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4Q+C<Q-SHM-"XS-C<G
M72`]("=096UB<F5Y(%-A;F1S)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN
M9V1O;2==6R<U,2XW-3`Z+3$N-3@S)UT@/2`G0G)I>F4@3F]R=&]N)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,2XX.#,Z,"XR,S,G72`]
M("=3=&%N<W1E9"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN
M9V1O;2==6R<U,BXQ,3<Z,"XY-C<G72`]("=7871T:7-H86TG.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4R+C$S,SHM-"XU-C<G72`]("=!
M8F5R<&]R=&@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4R
M+C,S,SHP+C<V-R==(#T@)TAO;FEN9W1O;B!2;WEA;"!!:7(@1F]R8V4@0F%S
M92<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3(N,S4P.BTP
M+C$Q-R==(#T@)U=Y=&]N(%)O>6%L($%I<B!&;W)C92!"87-E)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,BXS-C<Z+3`N,C$W)UT@/2`G
M06QC;VYB=7)Y(%)O>6%L($%I<B!&;W)C92!"87-E)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@2VEN9V1O;2==6R<U,BXS-C<Z,"XT.#,G72`]("=-:6QD96YH
M86QL(%)O>6%L($%I<B!&;W)C92!"87-E)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@2VEN9V1O;2==6R<U,BXT,3<Z,"XU-C<G72`]("=,86ME;FAE871H(%)O
M>6%L($%I<B!&;W)C92!"87-E)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN
M9V1O;2==6R<U,BXT,S,Z,2XS-3`G72`]("=#;VQT:7-H86QL)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,BXT-3`Z+3$N-S,S)UT@/2`G
M0FER;6EN9VAA;2`O($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+
M:6YG9&]M)UU;)S4R+C8Q-SHM,"XT-C<G72`]("=7:71T97)I;F<G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4R+C8S,SHQ+C,P,"==(#T@
M)TYO<G=I8V@@5V5A=&AE<B!#96YT<F4G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!+:6YG9&]M)UU;)S4R+C8U,#HP+C4V-R==(#T@)TUA<FAA;2<["B1C;V]R
M9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3(N-S,S.BTP+C8U,"==(#T@
M)T-O='1E<VUO<F4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;
M)S4R+C@P,#HM,BXV-C<G72`]("=3:&%W8G5R>2<["B1C;V]R9&EN871E<ULG
M56YI=&5D($MI;F=D;VTG75LG-3(N.#8W.C`N,34P)UT@/2`G2&]L8F5A8V@G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4S+C`S,SHM,"XU
M,#`G72`]("=#<F%N=V5L;"<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D
M;VTG75LG-3,N,#@S.BTP+C$V-R==(#T@)T-O;FEN9W-B>2!2;WEA;"!!:7(@
M1F]R8V4@0F%S92<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG
M-3,N,#@S.C`N,C8W)UT@/2`G5V%I;F9L965T)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@2VEN9V1O;2==6R<U,RXQ-C<Z+3`N-3$W)UT@/2`G5V%D9&EN9W1O
M;B<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3,N,38W.BTR
M+CDX,R==(#T@)TAA=V%R9&5N)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN
M9V1O;2==6R<U,RXR-3`Z+30N-3,S)UT@/2`G5F%L;&5Y)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@2VEN9V1O;2==6R<U,RXS-3`Z+3(N,C@S)UT@/2`G36%N
M8VAE<W1E<B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O
M;2==6R<U,RXW-C<Z+3,N,#,S)UT@/2`G0FQA8VMP;V]L($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4S+C@S,SHM,2XR,#`G
M72`]("=#:'5R8V@@1F5N=&]N)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN
M9V1O;2==6R<U,RXX-C<Z+3`N-#,S)UT@/2`G3&5C;VYF:65L9"<["B1C;V]R
M9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-30N,#4P.BTQ+C(U,"==(#T@
M)TQI;G1O;BU/;BU/=7-E)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O
M;2==6R<U-"XP.#,Z+30N-C,S)UT@/2`G27-L92!/9B!-86X@+R!2;VYA;&1S
M=V%Y($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;
M)S4T+C$Q-SHM,RXR-3`G72`]("=786QN97D@27-L86YD)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@2VEN9V1O;2==6R<U-"XQ,S,Z+3$N-#$W)UT@/2`G1&ES
M9F]R=&@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4T+C,P
M,#HM,2XU,S,G72`]("=,965M:6YG)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M2VEN9V1O;2==6R<U-"XV,#`Z+34N.#@S)UT@/2`G0F5L9F%S="`O($AA<F)O
M=7(G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4T+C8U,#HM
M-BXR,3<G72`]("="96QF87-T("\@06QD97)G<F]V92!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U-"XX-3`Z+30N.34P)UT@
M/2`G5V5S="!&<F5U9V@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M
M)UU;)S4T+CDS,SHM,BXY-3`G72`]("=#87)L:7-L92<["B1C;V]R9&EN871E
M<ULG56YI=&5D($MI;F=D;VTG75LG-34N,#4P.BTR+C4U,"==(#T@)U-P861E
M861A;2<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-34N-#$W
M.BTQ+C8P,"==(#T@)T)O=6QM97(G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+
M:6YG9&]M)UU;)S4U+C0S,SHM-2XW,#`G72`]("=-86-H<FEH86YI<V@G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4U+C4P,#HM-"XU.#,G
M72`]("=0<F5S='=I8VL@06ER<&]R="<["B1C;V]R9&EN871E<ULG56YI=&5D
M($MI;F=D;VTG75LG-34N.#8W.BTT+C0S,R==(#T@)T=L87-G;W<@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-34N.34P.BTS
M+C,U,"==(#T@)T5D:6YB=7)G:"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@2VEN9V1O;2==6R<U-BXS.#,Z+3(N.#8W)UT@/2`G3&5U8VAA<G,G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4V+C4P,#HM-BXX
M.#,G72`]("=4:7)E92<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG
M75LG-3<N,C`P.BTR+C(Q-R==(#T@)T%B97)D965N("\@1'EC92<["B1C;V]R
M9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3<N-#8W.BTW+C,V-R==(#T@
M)T)E;F)E8W5L82<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG
M-3<N-3,S.BTT+C`U,"==(#T@)TEN=F5R;F5S<R`O($1A;&-R;W-S)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U-RXV-3`Z+3,N-38W)UT@
M/2`G2VEN;&]S<R<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG
M-3<N-S$W.BTS+C,Q-R==(#T@)TQO<W-I96UO=71H)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@2VEN9V1O;2==6R<U-RXX,3<Z+3,N.38W)UT@/2`G5&%I;B!2
M86YG92<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3@N,C$W
M.BTV+C,Q-R==(#T@)U-T;W)N;W=A>2<["B1C;V]R9&EN871E<ULG56YI=&5D
M($MI;F=D;VTG75LG-3@N-#4P.BTS+C`X,R==(#T@)U=I8VLG.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4X+CDU,#HM,BXY,#`G72`]("=+
M:7)K=V%L;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O
M;2==6R<U.2XX.#,Z+3$N,S`P)UT@/2`G4W5M8G5R9V@@0V%P92<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S
M)UU;)RTQ-"XS,S,Z+3$W,"XW,3<G72`]("=086=O(%!A9V\@+R!);G0N($%I
M<G!O<G0G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,@36EN;W(@3W5T
M;'EI;F<@27-L86YD<R==6R<Q-BXW,S,Z+3$V.2XU,S,G72`]("=*;VAN<W1O
M;B!)<VQA;F0L($IO:&YS=&]N($%T;VQL($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG,3,N-#@S.C$T-"XX,#`G72`]("=!9V%N
M82P@1W5A;2!);G1E<FYA=&EO;F%L($%I<G!O<G0L($=5)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S$S+C4X,SHQ-#0N.3,S)UT@/2`G06YD
M97)S96X@*$UA<FEA;F$@27,I+"!!;F1E<G-E;B!!:7(@1F]R8V4@0F%S92P@
M1U4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,3,N.3$W.C$T
M-"XX,S,G72`]("='=6%M+"!-87)I86YA($ES;&%N9"P@1U4G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,30N,3@S.C$T-2XR-3`G72`]("=2
M;W1A($ES;&%N9"`H3BX@36%R:6%N82!)<RDL(%)O=&$@26YT97)N871I;VYA
M;"!!:7)P;W)T+"!'52<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<Q-"XY.#,Z,30U+C8Q-R==(#T@)U1I;FEA;B!)<VQA;F0@*$XN($UA<FEA
M;F$@27,I+"!797-T(%1I;FEA;B!!:7)P;W)T+"!'52<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<Q-2XQ,3<Z,30U+C<S,R==(#T@)U-A:7!A
M;B!)<VQA;F0L(%-A:7!A;B!);G1E<FYA=&EO;F%L($%I<G!O<G0L($YO<G1H
M97)N($UA<FEA;F$@27-L86YD<R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<Q."XR-34Z+38U+C8T,R==(#T@)U)O;W-E=F5L="!2;V%D<RP@
M4F]O<V5V96QT(%)O861S($YA=F%L(%-T871I;VX@*$]F<W1I92!&:65L9"DL
M(%!2)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S$X+C4P,#HM
M-C<N,3,S)UT@/2`G07%U861I;&QA+"!2869A96P@2&5R;F%N9&5Z($%I<G!O
M<G0L(%!2)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S$Y+C$P
M,#HM,34U+C<U,"==(#T@)U-O=71H($MO;F$@+R!(87=A:6DL($A))SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S$Y+C(X,SHQ-C8N-C4P)UT@
M/2`G5V%K92!)<VQA;F0L(%=A:V4@27-L86YD($%R;7D@06ER9FEE;&0@06ER
M<&]R="P@1U4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,3DN
M-S(R.BTQ-34N,#4V)UT@/2`G2&EL;RP@2&EL;R!);G1E<FYA=&EO;F%L($%I
M<G!O<G0L($A))SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(P
M+C@Y,CHM,34V+C0S-R==(#T@)TMA:'5L=6DL($MA:'5L=6D@06ER<&]R="P@
M2$DG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,C$N,34P.BTQ
M-3<N,3`P)UT@/2`G36]L;VMA:2!!=71O;6%T:6,@365T96]R;VQO9VEC86P@
M3V)S97)V:6YG(%-Y<W1E;2P@2$DG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,C$N,S`X.BTQ-3@N,#8X)UT@/2`G3V%H=2P@2V%L865L;V$@
M06ER<&]R="P@2$DG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,C$N,S(X.BTQ-3<N.30S)UT@/2`G2&]N;VQU;'4L($AO;F]L=6QU($EN=&5R
M;F%T:6]N86P@06ER<&]R="P@2$DG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,C$N-#4T.BTQ-3<N-S8V)UT@/2`G2V%N96]H92P@36%R:6YE
M($-O<G!S($%I<B!3=&%T:6]N+"!(22<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<R,2XT.#,Z+3$U."XP,S,G72`]("=7:&5E;&5R($%I<B!&
M;W)C92!"87-E("\@3V%H=2P@2$DG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,C$N.3@T.BTQ-3DN,S0Q)UT@/2`G3&EH=64L($QI:'5E($%I
M<G!O<G0L($A))SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(R
M+C`S-CHM,34Y+C<X-B==(#T@)TME:V%H82P@4&%C:69I8R!-:7-S:6QE(%1E
M<W0@1F%C:6QI='D@0F%R:VEN9R!386YD<RP@2$DG.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,C0N-34T.BTX,2XW-30G72`]("=+97D@5V5S
M="P@2V5Y(%=E<W0@26YT97)N871I;VYA;"!!:7)P;W)T+"!&3"<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<R-2XW.3$Z+3@P+C,Q-B==(#T@
M)TUI86UI+"!-:6%M:2!);G1E<FYA=&EO;F%L($%I<G!O<G0L($9,)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(U+CDQ-#HM.3<N-#(S)UT@
M/2`G0G)O=VYS=FEL;&4L($)R;W=N<W9I;&QE("\@4V]U=&@@4&%D<F4@27-L
M86YD($EN=&5R;F%T:6]N86P@06ER<&]R="P@5%@G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,C8N-C@U.BTX,"XP.3DG72`]("=797-T(%!A
M;&T@0F5A8V@L(%!A;&T@0F5A8V@@26YT97)N871I;VYA;"!!:7)P;W)T+"!&
M3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<R-RXU-3`Z+3DY
M+C0V-R==(#T@)TQA<F5D;R!);G1E<FYA=&EO;F%L($%I<G!O<G0L(%18)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(W+C8U,#HM.#$N,S,S
M)UT@/2`G079O;B!087)K($=U;FYE<GD@4F%N9V4L($9,)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S(W+C<P,#HM.#(N-#`P)UT@/2`G5&%M
M<&$@0F%Y($%R96$L($9,)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S(W+C<W,SHM.3<N-3$S)UT@/2`G0V]R<'5S($-H<FES=&DL($-O<G!U
M<R!#:')I<W1I($EN=&5R;F%T:6]N86P@06ER<&]R="P@5%@G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,C<N.#4P.BTX,BXU,#`G72`]("=-
M86-D:6QL($%I<B!&;W)C92!"87-E+"!&;"XL($9,)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S(W+CDV,3HM.#(N-30P)UT@/2`G5&%M<&$L
M(%1A;7!A($EN=&5R;F%T:6]N86P@06ER<&]R="P@1DPG.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG,C@N,3`S.BTX,"XV-#8G72`]("=-96QB
M;W5R;F4L($UE;&)O=7)N92!);G1E<FYA=&EO;F%L($%I<G!O<G0L($9,)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(X+C(Q-SHM,3<W+C,V
M-R==(#T@)U-A;F0@27-L86YD+"!(96YD97)S;VX@1FEE;&0@06ER<&]R="P@
M2$DG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,C@N,C,S.BTX
M,"XV,#`G72`]("=#;V-O82`O(%!A=')I8VL@06ER($9O<F-E($)A<V4L($9,
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(X+C0Q-SHM.#$N
M,S(U)UT@/2`G3W)L86YD;RP@3W)L86YD;R!);G1E<FYA=&EO;F%L($%I<G!O
M<G0L($9,)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(X+C0V
M-SHM.#`N-34P)UT@/2`G0V%P92!+96YN961Y+"!&3"<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<R."XX-C,Z+3DV+CDS,"==(#T@)U9I8W1O
M<FEA+"!6:6-T;W)I82!296=I;VYA;"!!:7)P;W)T+"!46"<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<R.2XR-S`Z+3DT+C@V-"==(#T@)T=A
M;'9E<W1O;BP@4V-H;VQE<R!&:65L9"P@5%@G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,CDN,S,S.BTX.2XT,#`G72`]("=";V]T:'9I;&QE
M+"!,02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<R.2XS-S4Z
M+3$P,"XY,C0G72`]("=$96P@4FEO+"!$96P@4FEO($EN=&5R;F%T:6]N86P@
M06ER<&]R="P@5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,CDN-3,S.BTY."XT-C0G72`]("=386X@06YT;VYI;RP@4V%N($%N=&]N:6\@
M26YT97)N871I;VYA;"!!:7)P;W)T+"!46"<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<R.2XU-3`Z+3@S+C$P-2==(#T@)T-R;W-S($-I='DL
M($-R;W-S($-I='D@06ER<&]R="P@1DPG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,CDN-S(W.BTX-2XP,C4G72`]("=!<&%L86-H:6-O;&$L
M($%P86QA8VAI8V]L82P@1DPG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG,CDN.34Q.BTY-"XP,C$G72`]("="96%U;6]N="`O(%!O<G0@07)T
M:'5R+"!3;W5T:&5A<W0@5&5X87,@4F5G:6]N86P@06ER<&]R="P@5%@G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,CDN.3DR.BTY-2XS-C0G
M72`]("=(;W5S=&]N+"!(;W5S=&]N($EN=&5R8V]N=&EN96YT86P@06ER<&]R
M="P@5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,CDN.3DS
M.BTY,"XR-3$G72`]("=.97<@3W)L96%N<RP@3F5W($]R;&5A;G,@26YT97)N
M871I;VYA;"!!:7)P;W)T+"!,02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<S,"XP-C<Z+3@U+C4X,R==(#T@)U1Y;F1A;&P@06ER($9O<F-E
M($)A<V4L($9,)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,P
M+C$R-CHM.3,N,C(S)UT@/2`G3&%K92!#:&%R;&5S+"!,86ME($-H87)L97,@
M4F5G:6]N86P@06ER<&]R="P@3$$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,S`N,38W.BTQ,#(N-#$W)UT@/2`G4V%N9&5R<V]N+"!46"<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,"XS,S,Z+3@Y+C@Q
M-R==(#T@)U-L:61E;&PL($Q!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S,P+C,V-SHM,3`T+C`Q-R==(#T@)TUA<F9A+"!46"<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,"XS.3,Z+3@T+C,U,R==(#T@
M)U1A;&QA:&%S<V5E+"!486QL86AA<W-E92!296=I;VYA;"!!:7)P;W)T+"!&
M3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,"XT,3<Z+3@V
M+C8X,R==(#T@)TAU<FQB=7)T($9I96QD+"!&3"<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<S,"XT.#,Z+3@V+C4Q-R==(#T@)U9A;'!A<F%I
M<V\@+R!%9VQI;B!!:7(@1F]R8V4@0F%S92P@1DPG.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,S`N-#DT.BTX,2XV.3,G72`]("=*86-K<V]N
M=FEL;&4L($IA8VMS;VYV:6QL92!);G1E<FYA=&EO;F%L($%I<G!O<G0L($9,
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,P+C4Q,3HM.3DN
M-S8V)UT@/2`G2G5N8W1I;VXL($MI;6)L92!#;W5N='D@06ER<&]R="P@5%@G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S`N-C@X.BTX."XR
M-#8G72`]("=-;V)I;&4L($UO8FEL92!296=I;VYA;"!!:7)P;W)T+"!!3"<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,"XY-C<Z+3@S+C(P
M,"==(#T@)TUO;V1Y($%I<B!&;W)C92!"87-E+"!'02<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S,2XP,S,Z+3DS+C`S,R==(#T@)T9O<G0@
M4&]L:RP@3$$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S$N
M,3`P.BTY-RXS,S,G72`]("=&;W)T($AO;V0L(%18)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S,Q+C$S,SHM.3(N-38W)UT@/2`G0VQA:6)O
M<FYE(%)A;F=E+"!!:7)W87ES($9A8VEL:71I97,@4V5C=&]R+"!,02<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,2XR-3`Z+3@R+C0P,"==
M(#T@)U=A>6-R;W-S("\@5V%R92!#;W5N='DL($=A+"!'02<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<S,2XS,S4Z+3DR+C4U.2==(#T@)T%L
M97AA;F1R:6$L($%L97AA;F1R:6$@26YT97)N871I;VYA;"!!:7)P;W)T+"!,
M02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,2XS-3$Z+3$P
M,"XT.30G72`]("=386X@06YG96QO+"!-871H:7,@1FEE;&0L(%18)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Q+C4S-CHM.#0N,3DT)UT@
M/2`G06QB86YY+"!3;W5T:'=E<W0@1V5O<F=I82!296=I;VYA;"!!:7)P;W)T
M+"!'02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,2XU.#,Z
M+3$Q,"XS,S,G72`]("=&;W)T($AU86-H=6-A+"!!6B<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S,2XV,3<Z+3DW+C(R."==(#T@)U=A8V\L
M(%=A8V\@4F5G:6]N86P@06ER<&]R="P@5%@G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S$N.#$Q.BTQ,#8N,S<V)UT@/2`G16P@4&%S;RP@
M16P@4&%S;R!);G1E<FYA=&EO;F%L($%I<G!O<G0L(%18)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S,Q+C@S,3HM,3`T+C@P.2==(#T@)U!I
M;F4@4W!R:6YG<RP@1W5A9&%L=7!E($UO=6YT86EN<R!.871I;VYA;"!087)K
M+"!46"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,2XX-C<Z
M+3$P-BXW,#`G72`]("=386YT82!497)E<V$L($Y-)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S,Q+C@X,SHM.#$N-38W)UT@/2`G1G0N(%-T
M97=A<G0L($=!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Q
M+CDT.#HM,3`R+C(P.2==(#T@)TUI9&QA;F0L($UI9&QA;F0@26YT97)N871I
M;VYA;"!!:7)P;W)T+"!46"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S,BXQ,3DZ+3@Q+C(P,B==(#T@)U-A=F%N;F%H+"!3879A;FYA:"!)
M;G1E<FYA=&EO;F%L($%I<G!O<G0L($=!)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S,R+C$S,3HM,3$P+CDU-2==(#T@)U1U8W-O;BP@5'5C
M<V]N($EN=&5R;F%T:6]N86P@06ER<&]R="P@05HG.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,S(N,C$W.BTY."XQ.#,G72`]("=3=&5P:&5N
M=FEL;&4@+R!#;&%R:R!&:65L9"!-=6YI8VEP86PL(%1X+BP@5%@G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S(N,S`P.BTX-BXT,#8G72`]
M("=-;VYT9V]M97)Y+"!$86YN96QL>2!&:65L9"P@04PG.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG,S(N,S(P.BTY,"XP-S@G72`]("=*86-K
M<V]N+"!*86-K<V]N($EN=&5R;F%T:6]N86P@06ER<&]R="P@35,G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S(N,S,S.BTX-"XX,S,G72`]
M("=&;W)T($)E;FYI;F<L($=!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S,R+C,S.#HM.#@N-S0X)UT@/2`G365R:61I86XL($ME>2!&:65L
M9"P@35,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S(N,S@S
M.BTQ,#8N-#@S)UT@/2`G5VAI=&4@4V%N9',L($Y-)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S,R+C,Y,3HM.30N-S$T)UT@/2`G3&]N9W9I
M97<L($=R96=G($-O=6YT>2!!:7)P;W)T+"!46"<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<S,BXT,3`Z+3DY+C8X,B==(#T@)T%B:6QE;F4L
M($%B:6QE;F4@4F5G:6]N86P@06ER<&]R="P@5%@G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,S(N-#,S.BTQ,3(N-C@S)UT@/2`G1VEL82!"
M96YD(%4N(%,N($%R;7D@06ER9FEE;&0L($%:)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S,R+C0T-SHM.3,N.#(T)UT@/2`G4VAR979E<&]R
M="P@4VAR979E<&]R="!296=I;VYA;"!!:7)P;W)T+"!,02<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<S,BXV,S,Z+3$P."XQ-3`G72`]("=3
M:6QV97(@0VET>2`O($=R86YT+"!.32<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<S,BXV-3`Z+3$Q-"XV,#`G72`]("=9=6UA("\@675M82!)
M;G1E<FYA=&EO;F%L+"!!6B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S,BXV.#@Z+3@S+C8U-"==(#T@)TUA8V]N+"!-:61D;&4@1V5O<F=I
M82!296=I;VYA;"!!:7)P;W)T+"!'02<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<S,BXW,S0Z+3$Q-RXQ.#,G72`]("=386X@1&EE9V\L(%-A
M;B!$:65G;R!);G1E<FYA=&EO;F%L+4QI;F1B97)G:"!&:65L9"P@0T$G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S(N.#(U.BTQ,34N-C8Q
M)UT@/2`G16P@0V5N=')O+"!.879A;"!!:7(@1F%C:6QI='DL($-!)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,R+C@S,SHM.3<N,S`P)UT@
M/2`G1F]R="!7;W)T:"P@5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG,S(N.#4P.BTQ,#8N,3`P)UT@/2`G2&]L;&]M86X@06ER($9O<F-E
M($)A<V4L($Y-)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,R
M+C@V.#HM,3$W+C$T,R==(#T@)U-A;B!$:65G;RP@36ER86UA<B!-0T%3+TUI
M='-C:&5R($9I96QD($%I<G!O<G0L($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S,R+C@Y-SHM.3<N,#(R)UT@/2`G1&%L;&%S("\@1F]R
M="!7;W)T:"P@1&%L;&%S("\@1F]R="!7;W)T:"!);G1E<FYA=&EO;F%L($%I
M<G!O<G0L(%18)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,R
M+C@Y.3HM.#`N,#0Q)UT@/2`G0VAA<FQE<W1O;BP@0VAA<FQE<W1O;B!!:7(@
M1F]R8V4@0F%S92P@4T,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,S(N.3`P.BTX-RXR-3`G72`]("=#96YT<F5V:6QL92P@04PG.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S,N,C,U.BTQ,3DN-#4S)UT@
M/2`G4V%N($YI8VAO;&%S($ES;&%N9"P@0T$G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S,N,C,W.BTQ,#<N,C8X)UT@/2`G5')U=&@@3W(@
M0V]N<V5Q=65N8V5S+"!4<G5T:"!/<B!#;VYS97%U96YC97,@375N:6-I<&%L
M($%I<G!O<G0L($Y-)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S,S+C,P.#HM,3`T+C4P."==(#T@)U)O<W=E;&PL(%)O<W=E;&P@26YD=7-T
M<FEA;"!!:7(@0V5N=&5R($%I<G!O<G0L($Y-)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S,S+C,V-#HM.#$N.38S)UT@/2`G075G=7-T82P@
M0G5S:"!&:65L9"P@1T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,S,N-#`U.BTQ,3@N-#$V)UT@/2`G079A;&]N+"!#871A;&EN82!!:7)P
M;W)T+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,RXT
M,S0Z+3$Q,BXP-3$G72`]("=0:&]E;FEX+"!0:&]E;FEX(%-K>2!(87)B;W(@
M26YT97)N871I;VYA;"!!:7)P;W)T+"!!6B<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<S,RXU-C8Z+3@V+C<T-2==(#T@)T)I<FUI;F=H86TL
M($)I<FUI;F=H86T@26YT97)N871I;VYA;"!!:7)P;W)T+"!!3"<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,RXV,S`Z+3@T+C0T,B==(#T@
M)T%T;&%N=&$L($AA<G1S9FEE;&0@071L86YT82!);G1E<FYA=&EO;F%L($%I
M<G!O<G0L($=!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,S
M+C8V-SHM,3`Q+C@R,2==(#T@)TQU8F)O8VLL($QU8F)O8VL@26YT97)N871I
M;VYA;"!!:7)P;W)T+"!46"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S,RXV.#,Z+3<X+CDS,R==(#T@)TUY<G1L92!"96%C:"!!:7(@1F]R
M8V4@0F%S92P@4T,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,S,N.#$R.BTQ,3@N,30V)UT@/2`G3&]N9R!"96%C:"P@3&]N9R!"96%C:"!!
M:7)P;W)T+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S
M,RXX-3`Z+3@P+C0X,R==(#T@)U!O:6YS971T(%)A;F=E+"!3=6UP=&5R+"!3
M0R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,RXY,#`Z+3$P
M-BXT,#`G72`]("=.;W)T:')U<"!,86YD:6YG(%-T<FEP+"!.32<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,RXY,#`Z+3$Q-RXR-3`G72`]
M("=2:79E<G-I9&4@+R!-87)C:"!!:7(@1F]R8V4@0F%S92P@0T$G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S,N.3$W.BTX-"XU,3<G72`]
M("=-87)I971T82`O($1O8F)I;G,@06ER($9O<F-E($)A<V4L($=!)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,S+CDS.#HM,3$X+C,X.2==
M(#T@)TQO<R!!;F=E;&5S+"!,;W,@06YG96QE<R!);G1E<FYA=&EO;F%L($%I
M<G!O<G0L($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,S
M+CDT,CHM.#$N,3$X)UT@/2`G0V]L=6UB:6$L($-O;'5M8FEA($UE=')O<&]L
M:71A;B!!:7)P;W)T+"!30R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S,RXY-3$Z+3@S+C,R."==(#T@)T%T:&5N<RP@071H96YS($%I<G!O
M<G0L($=!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,S+CDV
M-SHM.#`N-#@S)UT@/2`G4VAA=R!!:7(@1F]R8V4@0F%S92P@4T,G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S,N.3<Y.BTY."XT.3,G72`]
M("=7:6-H:71A($9A;&QS+"!3:&5P<&%R9"!!:7(@1F]R8V4@0F%S92P@5%@G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S0N,#$W.BTQ,#8N
M.3`P)UT@/2`G4V]C;W)R;R!-=6YI8VEP86PL($Y-)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S,T+C$R-#HM,3$Y+C$R,B==(#T@)U!O:6YT
M($UU9W4L($YA=F%L($%I<B!787)F87)E($-E;G1E<BP@0T$G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S0N,C`P.BTQ,3@N,S8U)UT@/2`G
M0G5R8F%N:RP@0G5R8F%N:RU';&5N9&%L92U087-A9&5N82!!:7)P;W)T+"!#
M02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-"XR,S,Z+3$Q
M."XP-C<G72`]("=-;W5N="!7:6QS;VXL($-!)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S,T+C(V.#HM.#@N-S<P)UT@/2`G5'5P96QO+"!4
M=7!E;&\@4F5G:6]N86P@06ER<&]R="P@35,G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S0N,S`P.BTQ,#,N.#`P)UT@/2`G365L<F]S92!'
M=6YN97)Y(%)A;F=E+"!.32<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S-"XS-#@Z+3@U+C$V,2==(#T@)U)O;64L(%(N($(N(%)U<W-E;&P@
M06ER<&]R="P@1T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,S0N-3$W.BTY-BXY.#,G72`]("=3=6QP:'5R($UU;FEC:7!A;"P@3TLG.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S0N-C`P.BTY."XT,#`G
M72`]("=&;W)T(%-I;&PL($]+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S,T+C8S,#HM,3$X+C`X,2==(#T@)U!A;&UD86QE+"!086QM9&%L
M92!0<F]D=6-T:6]N($9L:6=H="!0;&%N="P@0T$G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,S0N-C0T.BTX-BXW.#8G72`]("=(=6YT<W9I
M;&QE+"!(=6YT<W9I;&QE($EN=&5R;F%T:6]N86P@+R!*;VYE<R!&:65L9"P@
M04PG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S0N-C4P.BTY
M.2XR-C<G72`]("=!;'1U<R!!:7(@1F]R8V4@0F%S92P@3TLG.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S0N-S,Y.BTY,BXR-S@G72`]("=,
M:71T;&4@4F]C:RP@2&5I9VAT<RP@05(G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S0N-S0T.BTQ,3@N-S(T)UT@/2`G4V%N9&)E<F<L($-!
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,T+C<U,#HM,3(P
M+C4V-R==(#T@)U9A;F1E;F)E<F<@06ER($9O<F-E($)A<V4L($-!)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,T+C<X,SHM-S8N.#@S)UT@
M/2`G3F5W<&]R="P@3D,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,S0N.#,S.BTY,BXR-3`G72`]("=.;W)T:"!,:71T;&4@4F]C:RP@3F]R
M=&@@3&ET=&QE(%)O8VL@06ER<&]R="P@05(G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S0N.#@T.BTX,BXR,C$G72`]("='<F5E<BP@1W)E
M96YV:6QL92U3<&%R=&%N8G5R9R!!:7)P;W)T+"!30R<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S-"XX.3@Z+3<V+C@X,2==(#T@)T-H97)R
M>2!0;VEN="P@36%R:6YE($-O<G!S($%I<B!3=&%T:6]N+"!.0R<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-"XX.3DZ+3$R,"XT-#DG72`]
M("=386YT82!-87)I82P@4V%N=&$@36%R:6$@4'5B;&EC($%I<G!O<G0L($-!
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,T+CDQ-SHM,3$W
M+CDP,"==(#T@)T5D=V%R9',@06ER($9O<F-E($)A<V4L($-!)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,U+C`R.#HM,3$P+C<R,2==(#T@
M)U=I;G-L;W<L(%=I;G-L;W<@375N:6-I<&%L($%I<G!O<G0L($%:)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,U+C`S,SHM.#4N,C`P)UT@
M/2`G0VAA='1A;F]O9V$L($QO=F5L;"!&:65L9"P@5$XG.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG,S4N,#0R.BTQ,#8N-C$U)UT@/2`G06QB
M=7%U97)Q=64L($%L8G5Q=65R<75E($EN=&5R;F%T:6]N86P@06ER<&]R="P@
M3DTG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S4N,#8Q.BTX
M.2XY.#4G72`]("=-96UP:&ES+"!-96UP:&ES($EN=&5R;F%T:6]N86P@06ER
M<&]R="P@5$XG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S4N
M,3,S.BTW."XY,S,G72`]("=&;W)T($)R86=G("\@4VEM;6]N<R!!<FUY($%I
M<F9I96QD+"!.0R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S
M-2XQ-3`Z+3<U+C,P,"==(#T@)T1I86UO;F0@4VAO86QS($-O87-T($=U87)D
M(%-T871I;VXL($Y#)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S,U+C$V-SHM-SDN,#,S)UT@/2`G4&]P92!!:7(@1F]R8V4@0F%S92P@3D,G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S4N,C$S.BTX,"XY
M-#DG72`]("=#:&%R;&]T=&4L($-H87)L;W1T92`O($1O=6=L87,@26YT97)N
M871I;VYA;"!!:7)P;W)T+"!.0R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<S-2XR,3<Z+3DW+C0U,"==(#T@)TYO<FUA;B`O($UA>"!797-T
M:&5I;65R+"!/2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S
M-2XR,C`Z+3$P,2XW,3<G72`]("=!;6%R:6QL;RP@06UA<FEL;&\@26YT97)N
M871I;VYA;"!!:7)P;W)T+"!46"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<S-2XR-3@Z+3$Q,RXY,S,G72`]("=+:6YG;6%N+"!+:6YG;6%N
M($%I<G!O<G0L($%:)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S,U+C(U.3HM.3,N,#DS)UT@/2`G4G5S<V5L;'9I;&QE+"!2=7-S96QL=FEL
M;&4@4F5G:6]N86P@06ER<&]R="P@05(G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S4N,C8W.BTQ,3<N-#,S)UT@/2`G0W5D9&QE8F%C:R!'
M=6YN97)Y(%)A;F=E+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S-2XR-C<Z+3<U+C4U,"==(#T@)T-A<&4@2&%T=&5R87,L($Y#)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,U+C(X,SHM,3$V+C8Q
M-R==(#T@)T)I8WEC;&4@3&%K92!5+B!3+B!!<FUY($%I<F9I96QD+"!#82P@
M0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S4N,S,T.BTY
M-"XS-C4G72`]("=&;W)T(%-M:71H+"!&;W)T(%-M:71H(%)E9VEO;F%L($%I
M<G!O<G0L($%2)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,U
M+C,X.3HM.3<N-C`P)UT@/2`G3VML86AO;6$@0VET>2P@5VEL;"!2;V=E<G,@
M5V]R;&0@06ER<&]R="P@3TLG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG,S4N-#`P.BTY-BXP,3<G72`]("=(96YR>65T=&$@375N:6-I<&%L
M+"!/2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-2XT,3<Z
M+3DW+C,X,R==(#T@)U1I;FME<B!!:7(@1F]R8V4@0F%S92P@3TLG.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S4N-#,R.BTX,BXU,S<G72`]
M("=!<VAE=FEL;&4L($%S:&5V:6QL92!296=I;VYA;"!!:7)P;W)T+"!.0R<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-2XT,S0Z+3$Q.2XP
M-3<G72`]("="86ME<G-F:65L9"P@365A9&]W<R!&:65L9"!!:7)P;W)T+"!#
M02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-2XV-3`Z+3$P
M.2XP-C<G72`]("=7:6YD;W<@4F]C:RP@5VEN9&]W(%)O8VL@06ER<&]R="P@
M05HG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S4N-C8V.BTQ
M,C$N,C@U)UT@/2`G4&]I;G0@4&EE9')A<R!";&%N8V$L($-!)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,U+C8V-SHM-S4N.3`P)UT@/2`G
M1&%R92!#;W5N='D@1W5N;F5R>2!286YG92P@3D,G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,S4N-C@V.BTQ,3<N-CDP)UT@/2`G0VAI;F$@
M3&%K92P@3F%V86P@06ER($9A8VEL:71Y+"!#02<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<S-2XX,3@Z+3@S+CDX-B==(#T@)TMN;WAV:6QL
M92P@36-':&5E(%1Y<V]N($%I<G!O<G0L(%1.)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S,U+C@W,3HM-S@N-S@V)UT@/2`G4F%L96EG:"`O
M($1U<FAA;2P@4F%L96EG:"U$=7)H86T@26YT97)N871I;VYA;"!!:7)P;W)T
M+"!.0R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-BXP-SDZ
M+3$Q-2XQ-34G72`]("=,87,@5F5G87,L($UC0V%R<F%N($EN=&5R;F%T:6]N
M86P@06ER<&]R="P@3E8G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,S8N,#DX.BTW.2XY-#0G72`]("='<F5E;G-B;W)O+"!0:65D;6]N="!4
M<FEA9"!);G1E<FYA=&EO;F%L($%I<G!O<G0L($Y#)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S,V+C$Q.3HM.#8N-C@Y)UT@/2`G3F%S:'9I
M;&QE+"!.87-H=FEL;&4@26YT97)N871I;VYA;"!!:7)P;W)T+"!43B<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-BXQ.3<Z+3DU+C@X-B==
M(#T@)U1U;'-A+"!4=6QS82!);G1E<FYA=&EO;F%L($%I<G!O<G0L($]+)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,V+C,P-#HM,3$Y+CDS
M."==(#T@)TQE;6]O<F4L($YA=F%L($%I<B!3=&%T:6]N+"!#02<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-BXS,S,Z+3$Q-RXQ,#`G72`]
M("=3=7!E<FEO<B!686QL97D@1W5N;F5R>2!286YG92P@0T$G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S8N-#,S.BTY-BXS.#,G72`]("=(
M;VUI;GD@375N:6-I<&%L+"!/2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<S-BXT,S<Z+3DY+C4R,2==(#T@)U=O;V1W87)D+"!797-T(%=O
M;V1W87)D($%I<G!O<G0L($]+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S,V+C0T.#HM,3`S+C$U,R==(#T@)T-L87ET;VXL($-L87ET;VX@
M375N:6-I<&%L($%I<G!A<FLL($Y-)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S,V+C4S,SHM,3$U+CDP,"==(#T@)TEN9&EA;B!3<')I;F=S
M($=U;FYE<GD@4F%N9V4L($Y6)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S,V+C8R,3HM,3$V+C`R."==(#T@)TUE<F-U<GDL($1E<V5R="!2
M;V-K($%I<G!O<G0L($Y6)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,V+C8V-SHM.#<N-3`P)UT@/2`G1F]R="!#86UP8F5L;"!5+B!3+B!!
M<FUY($%I<F9I96QD+"!+62<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S-BXW.#`Z+3$Q.2XW,3DG72`]("=&<F5S;F\L($9R97-N;R!!:7(@
M5&5R;6EN86PL($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S,V+CDP-#HM-S8N,3DR)UT@/2`G3F]R9F]L:RP@3F]R9F]L:R!);G1E<FYA
M=&EO;F%L($%I<G!O<G0L(%9!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S,V+CDR,3HM,3$Q+C0T."==(#T@)U!A9V4L(%!A9V4@375N:6-I
M<&%L($%I<G!O<G0L($%:)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,W+C`P,#HM,3`Q+C@X,R==(#T@)T5L:VAA<G0@+R!%;&MH87)T+4UO
M<G1O;B!#;W5N='D@06ER<&]R="P@2U,G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S<N,#4V.BTX."XW-S0G72`]("=0861U8V%H+"!"87)K
M;&5Y(%)E9VEO;F%L($%I<G!O<G0L($M9)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S,W+C`X,SHM-S8N,S4P)UT@/2`G3&%N9VQE>2!!:7(@
M1F]R8V4@0F%S92P@5D$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,S<N,C0P.BTY,RXS.3`G72`]("=3<')I;F=F:65L9"P@4W!R:6YG9FEE
M;&0@4F5G:6]N86P@06ER<&]R="P@34\G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S<N,C@T.BTY."XU-3,G72`]("=-961I8VEN92!,;V1G
M92P@365D:6-I;F4@3&]D9V4L($M3)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S,W+C,Q-SHM-SDN.3<T)UT@/2`G4F]A;F]K92P@4F]A;F]K
M92!296=I;VYA;"!!:7)P;W)T+"!602<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<S-RXS,C$Z+3<Y+C(P-R==(#T@)TQY;F-H8G5R9RP@3'EN
M8VAB=7)G(%)E9VEO;F%L($%I<G!O<G0L(%9!)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S,W+C,V-SHM,3(P+C4V-R==(#T@)TUE<F-E9"`O
M($-A<W1L92!!:7(@1F]R8V4@0F%S92P@0T$G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S<N,S<Q.BTQ,3@N,S4X)UT@/2`G0FES:&]P+"!"
M:7-H;W`@06ER<&]R="P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG,S<N-#`V.BTQ,C(N,#0X)UT@/2`G36]U;G1A:6X@5FEE=RP@36]F
M9F5T="!&:65L9"P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,S<N-#,Y.BTQ,#4N.#8Q)UT@/2`G06QA;6]S82P@4V%N($QU:7,@5F%L
M;&5Y(%)E9VEO;F%L($%I<G!O<G0L($-/)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S,W+C4Q,3HM-S<N,S(S)UT@/2`G4FEC:&UO;F0L(%)I
M8VAM;VYD($EN=&5R;F%T:6]N86P@06ER<&]R="P@5D$G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG,S<N-C$R.BTQ,30N-3(V)UT@/2`G0V%L
M:65N=&4L($Y6)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,W
M+C8R,#HM,3(R+C,V-2==(#T@)U-A;B!&<F%N8VES8V\L(%-A;B!&<F%N8VES
M8V\@26YT97)N871I;VYA;"!!:7)P;W)T+"!#02<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<S-RXV-#<Z+3DW+C0R.2==(#T@)U=I8VAI=&$L
M(%=I8VAI=&$@36ED+4-O;G1I;F5N="!!:7)P;W)T+"!+4R<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<S-RXW,#`Z+3$R,RXP,#`G72`]("=&
M87)A;&QO;B!)<VQA;F0L($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S,W+C<P,#HM.3@N-S4P)UT@/2`G4')A='0@375N:6-I<&%L+"!+
M4R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-RXW,3DZ+3$R
M,BXR,S4G72`]("=/86ML86YD+"!-971R;R!/86ML86YD($EN=&5R;F%T:6]N
M86P@06ER<&]R="P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,S<N-S<S.BTY.2XY-S`G72`]("=$;V1G92!#:71Y+"!$;V1G92!#:71Y
M(%)E9VEO;F%L($%I<G!O<G0L($M3)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S,W+C<X,SHM,3(R+C,Q-R==(#T@)T%L86UE9&$@3F%V86P@
M06ER(%-T871I;VXL($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,W+C<Y-3HM.#$N,3(U)UT@/2`G0F5C:VQE>2P@4F%L96EG:"!#;W5N
M='D@365M;W)I86P@06ER<&]R="P@5U8G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S<N.#DP.BTQ,C$N,C(T)UT@/2`G4W1O8VMT;VXL(%-T
M;V-K=&]N($UE=')O<&]L:71A;B!!:7)P;W)T+"!#02<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S-RXY,#`Z+3@U+CDV-R==(#T@)T9O<G0@
M2VYO>"P@2UDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S<N
M.30Q.BTW-2XT-C,G72`]("=786QL;W!S($ES;&%N9"P@5V%L;&]P<R!&;&EG
M:'0@1F%C:6QI='D@06ER<&]R="P@5D$G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S@N,#0Q.BTX-"XV,#8G72`]("=,97AI;F=T;VXL($)L
M=64@1W)A<W,@06ER<&]R="P@2UDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,S@N,#0S.BTX-RXU,C`G72`]("=%=F%N<W9I;&QE+"!%=F%N
M<W9I;&QE(%)E9VEO;F%L($%I<G!O<G0L($E.)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S,X+C$W-SHM.#4N-S,P)UT@/2`G3&]U:7-V:6QL
M92P@4W1A;F1I9F]R9"!&:65L9"P@2UDG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S@N,C8W.BTQ,C$N.34P)UT@/2`G1F%I<F9I96QD("\@
M5')A=FES($%I<B!&;W)C92!"87-E+"!#02<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<S."XR-SDZ+3<V+C0Q-"==(#T@)U!A='5X96YT(%)I
M=F5R+"!.879A;"!!:7(@4W1A=&EO;BP@340G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S@N,CDP.BTQ,#0N-#DX)UT@/2`G4'5E8FQO+"!0
M=65B;&\@365M;W)I86P@06ER<&]R="P@0T\G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S@N,S,S.BTW-2XP.#,G72`]("=/8V5A;B!#:71Y
M+"!-1"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S."XS-C4Z
M+3@R+C4U-2==(#T@)TAU;G1I;F=T;VXL(%1R:2U3=&%T92!!:7)P;W)T+"!7
M5B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S."XS-SDZ+3@Q
M+C4Y,2==(#T@)T-H87)L97-T;VXL(%EE86=E<B!!:7)P;W)T+"!75B<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S."XU,#<Z+3$R,2XT.34G
M72`]("=386-R86UE;G1O+"!386-R86UE;G1O($5X96-U=&EV92!!:7)P;W)T
M+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S."XV-#,Z
M+3@X+CDV-"==(#T@)U-A;&5M+"!386QE;2U,96-K<F]N92!!:7)P;W)T+"!)
M3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S."XW,#`Z+3$P
M-"XW-C<G72`]("=&;W)T($-A<G-O;BP@0T\G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S@N-S4R.BTY,"XS-S0G72`]("=3="X@3&]U:7,L
M($QA;6)E<G0M4W0N($QO=6ES($EN=&5R;F%T:6]N86P@06ER<&]R="P@34\G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S@N.#$V.BTQ,#0N
M-S$Q)UT@/2`G0V]L;W)A9&\@4W!R:6YG<RP@0VET>2!/9B!#;VQO<F%D;R!3
M<')I;F=S($UU;FEC:7!A;"!!:7)P;W)T+"!#3R<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<S."XX,3<Z+3<V+C@U,"==(#T@)T-A;7`@4W!R
M:6YG<R`O($%N9')E=W,@06ER($9O<F-E($)A<V4L($U$)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S,X+C@Q-SHM.3(N,C$X)UT@/2`G0V]L
M=6UB:6$L($-O;'5M8FEA(%)E9VEO;F%L($%I<G!O<G0L($U/)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,X+C@T.#HM-S<N,#,T)UT@/2`G
M5V%S:&EN9W1O;B!$0RP@4F5A9V%N($YA=&EO;F%L($%I<G!O<G0L(%9!)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,X+C@X-3HM-SDN.#4S
M)UT@/2`G16QK:6YS+"!%;&MI;G,M4F%N9&]L<&@@0V]U;G1Y+4IE;FYI;F=S
M(%)A;F1O;'!H($9I96QD+"!75B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<S."XY,S4Z+3<W+C0T."==(#T@)U=A<VAI;F=T;VX@1$,L(%=A
M<VAI;F=T;VXM1'5L;&5S($EN=&5R;F%T:6]N86P@06ER<&]R="P@5D$G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S@N.38W.BTQ,#0N.#$W
M)UT@/2`G06ER($9O<F-E($%C861E;7DL($-/)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S,Y+C`T,SHM.#0N-C<R)UT@/2`G0V]V:6YG=&]N
M("\@0VEN8VEN;F%T:2P@0VEN8VEN;F%T:2`O($YO<G1H97)N($ME;G1U8VMY
M($EN=&5R;F%T:6]N86P@06ER<&]R="P@2UDG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,SDN,#<S.BTY-2XV,C8G72`]("=4;W!E:V$L(%!H
M:6QI<"!":6QL87)D($UU;FEC:7!A;"!!:7)P;W)T+"!+4R<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<S.2XQ,#`Z+3DV+C<V-R==(#T@)T9O
M<G0@4FEL97DL($M3)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S,Y+C$S-#HM,3`X+C4S.2==(#T@)T=R86YD($IU;F-T:6]N+"!786QK97(@
M1FEE;&0L($-/)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Y
M+C$V-SHM-S8N-C@S)UT@/2`G0F%L=&EM;W)E+"!"86QT:6UO<F4M5V%S:&EN
M9W1O;B!);G1E<FYA=&EO;F%L($%I<G!O<G0L($U$)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S,Y+C(Y-3HM,3$T+C@T-2==(#T@)T5L>2P@
M16QY($%I<G!O<G0L($Y6)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,Y+C(Y-SHM.30N-S,Q)UT@/2`G2V%N<V%S($-I='DL($MA;G-A<R!#
M:71Y($EN=&5R;F%T:6]N86P@06ER<&]R="P@34\G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,SDN,S8W.BTQ,#$N-CDS)UT@/2`G1V]O9&QA
M;F0L(%)E;FYE<B!&:65L9"P@2U,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,SDN-#`P.BTQ,C,N.#$W)UT@/2`G1F]R="!"<F%G9RP@0T$G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,SDN-#8U.BTW-"XU
M.#<G72`]("=!=&QA;G1I8R!#:71Y+"!!=&QA;G1I8R!#:71Y($EN=&5R;F%T
M:6]N86P@06ER<&]R="P@3DHG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG,SDN-#@T.BTQ,3DN-S<Q)UT@/2`G4F5N;RP@4F5N;R!486AO92!)
M;G1E<FYA=&EO;F%L($%I<G!O<G0L($Y6)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S,Y+C4U,3HM.3<N-C4Q)UT@/2`G0V]N8V]R9&EA+"!"
M;&]S<V5R($UU;FEC:7!A;"!!:7)P;W)T+"!+4R<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<S.2XV,#DZ+3$Q,"XW-34G72`]("=0<FEC92P@
M0V%R8F]N($-O=6YT>2!!:7)P;W)T+"!55"<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<S.2XW,C4Z+3@V+C(X,B==(#T@)TEN9&EA;F%P;VQI
M<RP@26YD:6%N87!O;&ES($EN=&5R;F%T:6]N86P@06ER<&]R="P@24XG.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,SDN-S8W.BTW-"XQ,#`G
M72`]("="87)N96=A="!#;V%S="!'=6%R9"!3=&%T:6]N+"!.2B<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S.2XW-C@Z+3DT+CDP.2==(#T@
M)U-T+B!*;W-E<&@L(%)O<V5C<F%N<R!-96UO<FEA;"!!:7)P;W)T+"!-3R<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S.2XW.#,Z+3$P-"XX
M-C<G72`]("=$96YV97(@+R!3=&%P;&5T;VX@26YT97)N871I;VYA;"P@0V\N
M+"!#3R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S.2XX,S,Z
M+3$P-"XV-3<G72`]("=$96YV97(L($1E;G9E<B!);G1E<FYA=&EO;F%L($%I
M<G!O<G0L($-/)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Y
M+C@S,SHM.#0N,#4P)UT@/2`G1&%Y=&]N("\@5W)I9VAT+5!A='1E<G-O;B!!
M:7(@1F]R8V4@0F%S92P@3T@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG,SDN.#0U.BTX.2XV.#0G72`]("=3<')I;F=F:65L9"P@0V%P:71A
M;"!!:7)P;W)T+"!)3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<S.2XX-C@Z+3<U+C(S,2==(#T@)U!H:6QA9&5L<&AI82P@4&AI;&%D96QP
M:&EA($EN=&5R;F%T:6]N86P@06ER<&]R="P@4$$G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,SDN.3`V.BTX-"XR,3DG72`]("=$87ET;VXL
M($-O>"!$87ET;VX@26YT97)N871I;VYA;"!!:7)P;W)T+"!/2"<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S.2XY.34Z+3@R+C@W-B==(#T@
M)T-O;'5M8G5S+"!0;W)T($-O;'5M8G5S($EN=&5R;F%T:6]N86P@06ER<&]R
M="P@3T@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#`N,#,S
M.BTW-"XS,3<G72`]("=,86ME:'5R<W0@3F%V86P@06ER(%-T871I;VXL($Y*
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0P+C$U,3HM,3(R
M+C(U,B==(#T@)U)E9"!";'5F9BP@4F5D($)L=69F($UU;FEC:7!A;"!!:7)P
M;W)T+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,"XQ
M-C<Z+3$Q,BXY,S,G72`]("=$=6=W87D@4')O=FEN9R!'<F]U;F1S+"!55"<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,"XR-3`Z+3DS+C<Q
M-R==(#T@)U-P:6-K87)D+"!-3R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<T,"XS,#`Z+3$P.2XY.#,G72`]("=2;V]S979E;'0L(%54)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0P+C0Y,SHM,3`W+C4R
M-"==(#T@)T-R86EG+"!#<F%I9RU-;V9F870@06ER<&]R="P@0T\G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#`N-3`T.BTX,"XR-C8G72`]
M("=0:71T<V)U<F=H+"!0:71T<V)U<F=H($EN=&5R;F%T:6]N86P@06ER<&]R
M="P@4$$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#`N-3$U
M.BTQ,C(N,CDW)UT@/2`G4F5D9&EN9RP@4F5D9&EN9R!-=6YI8VEP86P@06ER
M<&]R="P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#`N
M-C,Y.BTW,RXW-C(G72`]("=.97<@66]R:RP@2V5N;F5D>2!);G1E<FYA=&EO
M;F%L($%I<G!O<G0L($Y9)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S0P+C8U,3HM-S4N-#0Y)UT@/2`G06QL96YT;W=N+"!,96AI9V@@5F%L
M;&5Y($EN=&5R;F%T:6]N86P@06ER<&]R="P@4$$G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG-#`N-C8W.BTX.2XV.#0G72`]("=096]R:6$L
M($=R96%T97(@4&5O<FEA(%)E9VEO;F%L($%I<G!O<G0L($E,)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0P+C8X,CHM-S0N,38Y)UT@/2`G
M3F5W87)K+"!.97=A<FL@26YT97)N871I;VYA;"!!:7)P;W)T+"!.2B<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,"XW,S,Z+3$Q-"XP,S,G
M72`]("=796YD;W9E<B`O($%I<B!&;W)C92!!=7AI;&QA<GD@1FEE;&0L(%54
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0P+C<W.#HM,3$Q
M+CDV.2==(#T@)U-A;'0@3&%K92!#:71Y+"!386QT($QA:V4@0VET>2!);G1E
M<FYA=&EO;F%L($%I<G!O<G0L(%54)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S0P+C<W.3HM-S,N.#@P)UT@/2`G3F5W(%EO<FLL($QA($=U
M87)D:6$@06ER<&]R="P@3EDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG-#`N.#`P.BTQ,C0N,38W)UT@/2`G175R96MA+"!#02<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,"XX,S$Z+3DV+C<V-"==(#T@
M)TQI;F-O;&XL($QI;F-O;&X@375N:6-I<&%L($%I<G!O<G0L($Y%)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0P+CDP,CHM,3$W+C@P-R==
M(#T@)U=I;FYE;75C8V$L(%=I;FYE;75C8V$@375N:6-I<&%L($%I<G!O<G0L
M($Y6)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0P+CDQ.#HM
M.#$N-#0S)UT@/2`G06MR;VXL($%K<F]N+4-A;G1O;B!296=I;VYA;"!!:7)P
M;W)T+"!/2"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,"XY
M-3@Z+3DX+C,Q,R==(#T@)T=R86YD($ES;&%N9"P@0V5N=')A;"!.96)R87-K
M82!296=I;VYA;"!!:7)P;W)T+"!.12<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<T,"XY-S@Z+3@U+C$Y-2==(#T@)T9O<G0@5V%Y;F4L($9O
M<G0@5V%Y;F4@26YT97)N871I;VYA;"!!:7)P;W)T+"!)3B<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<T,2XP.3DZ+3$P,BXY.#8G72`]("=3
M:61N97DL(%-I9&YE>2!-=6YI8VEP86P@06ER<&]R="P@3D4G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#$N,3$W.BTY-2XY,#`G72`]("=/
M;6%H82`O($]F9G5T="!!:7(@1F]R8V4@0F%S92P@3D4G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG-#$N,3(R.BTQ,#`N-C8X)UT@/2`G3F]R
M=&@@4&QA='1E+"!.;W)T:"!0;&%T=&4@4F5G:6]N86P@06ER<&]R="P@3D4G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#$N,34X.BTQ,#0N
M.#`W)UT@/2`G0VAE>65N;F4L($-H97EE;FYE($%I<G!O<G0L(%=9)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+C$U.#HM-S,N,3(Y)UT@
M/2`G0G)I9&=E<&]R="P@4VEK;W)S:WD@365M;W)I86P@06ER<&]R="P@0U0G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#$N,3DT.BTQ,3(N
M,#$V)UT@/2`G3V=D96XL($]G9&5N+4AI;F-K;&5Y($%I<G!O<G0L(%54)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+C(T,SHM-S8N.3(R
M)UT@/2`G5VEL;&EA;7-P;W)T+"!7:6QL:6%M<W!O<G0M3'EC;VUI;F<@0V]U
M;G1Y($%I<G!O<G0L(%!!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S0Q+C(U-#HM.#`N-C<T)UT@/2`G66]U;F=S=&]W;BP@66]U;F=S=&]W
M;BU787)R96X@4F5G:6]N86P@06ER<&]R="P@3T@G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG-#$N,S$P.BTY-2XX.3DG72`]("=/;6%H82P@
M17!P;&5Y($%I<F9I96QD+"!.12<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<T,2XS,3<Z+3DV+C,V-R==(#T@)U9A;&QE>2P@3D4G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#$N,S,Y.BTW-2XW,C<G72`]
M("=7:6QK97,M0F%R<F4@+2!38W)A;G1O;BP@5VEL:V5S+4)A<G)E("\@4V-R
M86YT;VX@26YT97)N871I;VYA;"!!:7)P;W)T+"!002<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<T,2XS-C<Z+3@X+C8X,R==(#T@)TUA<G-E
M:6QL97,@27-L86YD+"!)3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<T,2XT,#4Z+3@Q+C@U,R==(#T@)T-L979E;&%N9"P@0VQE=F5L86YD
M+4AO<&MI;G,@26YT97)N871I;VYA;"!!:7)P;W)T+"!/2"<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<T,2XT-3$Z+3DP+C4Q-2==(#T@)TUO
M;&EN92P@475A9"U#:71Y($%I<G!O<G0L($E,)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S0Q+C4S.#HM.3,N-C8V)UT@/2`G1&5S($UO:6YE
M<RP@1&5S($UO:6YE<R!);G1E<FYA=&EO;F%L($%I<G!O<G0L($E!)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+C4X.3HM.#,N.#`Q)UT@
M/2`G5&]L961O+"!4;VQE9&\@17AP<F5S<R!!:7)P;W)T+"!/2"<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,2XU.30Z+3$P.2XP-C4G72`]
M("=2;V-K(%-P<FEN9W,L(%)O8VL@4W!R:6YG<RU3=V5E='=A=&5R($-O=6YT
M>2!!:7)P;W)T+"!762<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<T,2XV-3`Z+3<P+C4Q-R==(#T@)T]T:7,@06ER($YA=&EO;F%L($=U87)D
M($)A<V4L($U!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q
M+C8V-SHM-CDN.38W)UT@/2`G0VAA=&AA;2P@34$G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG-#$N-S`Y.BTX-BXS,3DG72`]("=3;W5T:"!"
M96YD+"!3;W5T:"!"96YD(%)E9VEO;F%L($%I<G!O<G0L($E.)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+C<R-#HM-S$N-#(X)UT@/2`G
M4')O=FED96YC92P@5&AE;V1O<F4@1G)A;F-I<R!'<F5E;B!3=&%T92!!:7)P
M;W)T+"!222<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,2XW
M.#0Z+3@W+C<U-2==(#T@)T-H:6-A9V\L($-H:6-A9V\@36ED=V%Y($%I<G!O
M<G0L($E,)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+C@V
M-SHM,3`S+C4X-B==(#T@)U-C;W1T<V)L=69F+"!(96EL:6<@1FEE;&0L($Y%
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+C@X,SHM.3$N
M-S(T)UT@/2`G0V5D87(@4F%P:61S+"!#961A<B!287!I9',@375N:6-I<&%L
M($%I<G!O<G0L($E!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S0Q+CDS.#HM-S(N-C@S)UT@/2`G5VEN9'-O<B!,;V-K<RP@0G)A9&QE>2!)
M;G1E<FYA=&EO;F%L($%I<G!O<G0L($-4)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S0Q+CDX,#HM.#<N.3`T)UT@/2`G0VAI8V%G;RP@0VAI
M8V%G;RU/7"=(87)E($EN=&5R;F%T:6]N86P@06ER<&]R="P@24PG.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#$N.3@Q.BTY-RXT,S<G72`]
M("=.;W)F;VQK+"!3=&5F86X@365M;W)I86P@06ER<&]R="P@3D4G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#(N,#@P.BTX,"XQ.#,G72`]
M("=%<FEE+"!%<FEE($EN=&5R;F%T:6]N86P@06ER<&]R="P@4$$G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#(N,3DS.BTX.2XP.3,G72`]
M("=2;V-K9F]R9"P@1W)E871E<B!2;V-K9F]R9"!!:7)P;W)T+"!)3"<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,BXR,#`Z+3<R+C4S,R==
M(#T@)T-H:6-O<&5E($9A;&QS("\@5V5S=&]V97(@06ER($9O<F-E($)A<V4L
M($U!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0R+C(P.#HM
M-S4N.3@Q)UT@/2`G0FEN9VAA;71O;BP@0FEN9VAA;71O;B!296=I;VYA;"!!
M:7)P;W)T+"!.62<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T
M,BXR,S$Z+3@S+C,S,2==(#T@)T1E=')O:70L($1E=')O:70@365T<F]P;VQI
M=&%N(%=A>6YE($-O=6YT>2!!:7)P;W)T+"!-22<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<T,BXS-C$Z+3<Q+C`Q,2==(#T@)T)O<W1O;BP@
M3&]G86X@26YT97)N871I;VYA;"!!:7)P;W)T+"!-02<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<T,BXS.#$Z+3$R,BXX-S(G72`]("=-961F
M;W)D+"!2;V=U92!686QL97D@26YT97)N871I;VYA;"!!:7)P;W)T+"!/4B<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,BXS.3@Z+3DP+C<P
M-"==(#T@)T1U8G5Q=64L($1U8G5Q=64@4F5G:6]N86P@06ER<&]R="P@24$G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#(N-#`R.BTY-BXS
M.#0G72`]("=3:6]U>"!#:71Y+"!3:6]U>"!'871E=V%Y($%I<G!O<G0L($E!
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0R+C0V.#HM-S$N
M,CDT)UT@/2`G0F5D9F]R9"P@2&%N<V-O;2!&:65L9"P@34$G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#(N-34P.BTY-"XQ.#,G72`]("=&
M;W)T($1O9&=E+"!)02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<T,BXU-30Z+3DR+C0P,2==(#T@)U=A=&5R;&]O+"!7871E<FQO;R!-=6YI
M8VEP86P@06ER<&]R="P@24$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG-#(N-3<Y.BTQ,3`N,3`S)UT@/2`G0FEG(%!I;F5Y+"!":6<@4&EN
M97DM36%R8FQE=&]N($%I<G!O<G0L(%=9)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S0R+C<T-SHM-S,N-SDY)UT@/2`G06QB86YY+"!!;&)A
M;GD@0V]U;G1Y($%I<G!O<G0L($Y9)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S0R+C<X,#HM.#0N-3<Y)UT@/2`G3&%N<VEN9RP@0V%P:71A
M;"!#:71Y($%I<G!O<G0L($U))SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S0R+C<Y-#HM,3`U+C,X,B==(#T@)T1O=6=L87,L($-O;G9E<G-E
M($-O=6YT>2!!:7)P;W)T+"!762<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<T,BXX,34Z+3$P."XW,C@G72`]("=,86YD97(L(%=9)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0R+C@U.3HM,3`P+C4U,2==
M(#T@)U9A;&5N=&EN92P@36EL;&5R($9I96QD+"!.12<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<T,BXX.#$Z+3@U+C4R,R==(#T@)T=R86YD
M(%)A<&ED<RP@1V5R86QD(%(N($9O<F0@26YT97)N871I;VYA;"!!:7)P;W)T
M+"!-22<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,BXX.3@Z
M+3$P-BXT-S,G72`]("=#87-P97(L($YA=')O;F$@0V]U;G1Y($EN=&5R;F%T
M:6]N86P@06ER<&]R="P@5UDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG-#(N.3(P.BTQ,3(N-3<Q)UT@/2`G4&]C871E;&QO+"!0;V-A=&5L
M;&\@4F5G:6]N86P@06ER<&]R="P@240G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG-#(N.30Q.BTW."XW,S8G72`]("="=69F86QO+"!'<F5A
M=&5R($)U9F9A;&\@26YT97)N871I;VYA;"!!:7)P;W)T+"!.62<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,BXY-34Z+3@W+CDP-"==(#T@
M)TUI;'=A=6ME92P@1V5N97)A;"!-:71C:&5L;"!);G1E<FYA=&EO;F%L($%I
M<G!O<G0L(%=))SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0R
M+CDV-SHM.#,N-S0Y)UT@/2`G1FQI;G0L($)I<VAO<"!);G1E<FYA=&EO;F%L
M($%I<G!O<G0L($U))SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S0S+C`V,CHM,3`X+C0T-B==(#T@)U)I=F5R=&]N+"!2:79E<G1O;B!296=I
M;VYA;"!!:7)P;W)T+"!762<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<T,RXQ,#DZ+3<V+C$P,R==(#T@)U-Y<F%C=7-E+"!3>7)A8W5S92!(
M86YC;V-K($EN=&5R;F%T:6]N86P@06ER<&]R="P@3EDG.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG-#,N,3$W.BTW-RXV-S<G72`]("=2;V-H
M97-T97(L($=R96%T97(@4F]C:&5S=&5R($EN=&5R;F%T:6]N86P@06ER<&]R
M="P@3EDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#,N,30Q
M.BTX.2XS-#4G72`]("=-861I<V]N+"!$86YE($-O=6YT>2!296=I;VYA;"U4
M<G5A>"!&:65L9"P@5TDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG-#,N,3<Q.BTX-BXR,S<G72`]("=-=7-K96=O;BP@375S:V5G;VX@0V]U
M;G1Y($%I<G!O<G0L($U))SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S0S+C$Y-3HM-S$N-3`Q)UT@/2`G0V]N8V]R9"P@0V]N8V]R9"!-=6YI
M8VEP86P@06ER<&]R="P@3D@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG-#,N,SDQ.BTY.2XX-#,G72`]("=7:6YN97(L($)O8B!7:6QE>2!&
M:65L9"!!:7)P;W)T+"!31"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<T,RXU-C<Z+3$Q-BXR-#$G72`]("=";VES92P@0F]I<V4@06ER(%1E
M<FUI;F%L+"!)1"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T
M,RXU-S<Z+3DV+C<U-"==(#T@)U-I;W5X($9A;&QS+"!&;W-S($9I96QD+"!3
M1"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,RXU.34Z+3$Q
M."XY-38G72`]("="=7)N<RP@0G5R;G,@375N:6-I<&%L($%I<G!O<G0L($]2
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0S+C8T,CHM-S`N
M,S`T)UT@/2`G4&]R=&QA;F0L(%!O<G1L86YD($EN=&5R;F%T:6]N86P@2F5T
M<&]R="P@344G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#,N
M-S8W.BTY.2XS,3@G72`]("=#:&%M8F5R;&%I;BP@0VAA;6)E<FQA:6X@375N
M:6-I<&%L($%I<G!O<G0L(%-$)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S0S+C@W.3HM.3$N,C4W)UT@/2`G3&$@0W)O<W-E+"!,82!#<F]S
M<V4@375N:6-I<&%L($%I<G!O<G0L(%=))SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S0S+CDP,#HM-CDN.3,U)UT@/2`G0G)U;G-W:6-K+"!.
M879A;"!!:7(@4W1A=&EO;BP@344G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG-#,N.3`T.BTY,BXT.3(G72`]("=2;V-H97-T97(L(%)O8VAE
M<W1E<B!);G1E<FYA=&EO;F%L($%I<G!O<G0L($U.)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S0T+C`T-CHM,3`S+C`U-"==(#T@)U)A<&ED
M($-I='DL(%)A<&ED($-I='D@4F5G:6]N86P@06ER<&]R="P@4T0G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#0N,#4P.BTW-2XW,S,G72`]
M("=&;W)T($1R=6T@+R!7:&5E;&5R+5-A8VL@52X@4RX@07)M>2!!:7)F:65L
M9"P@3EDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#0N,3,S
M.BTQ,C,N,C$T)UT@/2`G175G96YE+"!-86AL;VX@4W=E970@1FEE;&0L($]2
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0T+C(V-SHM-S$N
M,S`P)UT@/2`G36]U;G0@5V%S:&EN9W1O;BP@3D@G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG-#0N,S,Y.BTQ,#4N-30R)UT@/2`G1VEL;&5T
M=&4L($=I;&QE='1E+4-A;7!B96QL($-O=6YT>2!!:7)P;W)T+"!762<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-"XS-3$Z+3@T+C8W-"==
M(#T@)TAO=6=H=&]N($QA:V4L(%)O<V-O;6UO;B!#;W5N='D@06ER<&]R="P@
M34DG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#0N,S@X.BTY
M."XR,C@G72`]("=(=7)O;BP@2'5R;VX@4F5G:6]N86P@06ER<&]R="P@4T0G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#0N-#$Y.BTW,BXP
M,3DG72`]("=386EN="!*;VAN<V)U<GDL(%94)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S0T+C0V.#HM-S,N,34P)UT@/2`G0G5R;&EN9W1O
M;BP@0G5R;&EN9W1O;B!);G1E<FYA=&EO;F%L($%I<G!O<G0L(%94)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0T+C0W.3HM.#@N,3,W)UT@
M/2`G1W)E96X@0F%Y+"!!=7-T:6X@4W1R875B96P@26YT97)N871I;VYA;"!!
M:7)P;W)T+"!722<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T
M-"XU,3<Z+3$P.2XP,3<G72`]("=#;V1Y+"!762<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<T-"XU,S,Z+3<P+C4S,R==(#T@)U)U;69O<F0L
M($U%)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0T+C4W-CHM
M-S$N,3<Y)UT@/2`G0F5R;&EN+"!"97)L:6X@375N:6-I<&%L($%I<G!O<G0L
M($Y()SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0T+C<V.3HM
M,3`V+CDV.2==(#T@)U-H97)I9&%N+"!3:&5R:61A;B!#;W5N='D@06ER<&]R
M="P@5UDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#0N.#,S
M.BTX-"XU-3`G72`]("='<F%Y:6YG($%I<B!&;W)C92!286YG92P@34DG.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#0N.#@S.BTY,RXR,CDG
M72`]("=-:6YN96%P;VQI<RP@36EN;F5A<&]L:7,M4W0N(%!A=6P@26YT97)N
M871I;VYA;"!!:7)P;W)T+"!-3B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<T-"XY,#@Z+3$R,BXY.34G72`]("=386QE;2P@36-.87)Y($9I
M96QD+"!/4B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-"XY
M,3<Z+38W+C`P,"==(#T@)T5A<W1P;W)T+"!-12<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<T-"XY,S,Z+3<R+C(P,"==(#T@)TYE=W!O<G0L
M(%94)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0U+C`W,CHM
M.#,N-38T)UT@/2`G06QP96YA+"!!;'!E;F$@0V]U;G1Y(%)E9VEO;F%L($%I
M<G!O<G0L($U))SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0U
M+C0T,SHM.3@N-#$S)UT@/2`G06)E<F1E96XL($%B97)D965N(%)E9VEO;F%L
M($%I<G!O<G0L(%-$)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S0U+C4T-3HM.30N,#4R)UT@/2`G4W0N($-L;W5D+"!3="X@0VQO=60@375N
M:6-I<&%L($%I<G!O<G0L($U.)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S0U+C4Y,3HM,3(R+C8P,"==(#T@)U!O<G1L86YD+"!0;W)T;&%N
M9"!);G1E<FYA=&EO;F%L($%I<G!O<G0L($]2)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S0U+C8Y.#HM,3$X+C@S-"==(#T@)U!E;F1L971O
M;BP@16%S=&5R;B!/<F5G;VX@4F5G:6]N86P@070@4&5N9&QE=&]N($%I<G!O
M<G0L($]2)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0U+C<U
M,#HM.#<N,#,S)UT@/2`G17-C86YA8F$L($U))SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S0U+C@P-SHM,3`X+C4T,B==(#T@)T)I;&QI;F=S
M+"!":6QL:6YG<R!,;V=A;B!);G1E<FYA=&EO;F%L($%I<G!O<G0L($U4)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0U+CDS,SHM.3`N-#4P
M)UT@/2`G4&%R:R!&86QL<RP@5TDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG-#8N,34W.BTQ,C,N.#@R)UT@/2`G07-T;W)I82P@07-T;W)I
M82!296=I;VYA;"!!:7)P;W)T+"!/4B<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<T-BXS-S4Z+3$Q-RXP,30G72`]("=,97=I<W1O;BP@3&5W
M:7-T;VXM3F5Z(%!E<F-E($-O=6YT>2!!:7)P;W)T+"!)1"<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<T-BXT,C@Z+3$P-2XX.#8G72`]("=-
M:6QE<R!#:71Y+"!&<F%N:R!7:6QE>2!&:65L9"!!:7)P;W)T+"!-5"<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-BXT-SDZ+3@T+C,U-R==
M(#T@)U-A=6QT(%-T92X@36%R:64L($U))SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S0V+C4S,SHM.#<N-34P)UT@/2`G36%R<75E='1E+"!-
M22<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-BXU-C0Z+3$R
M,"XU,S0G72`]("=986MI;6$L(%EA:VEM82!!:7(@5&5R;6EN86PL(%=!)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0V+C4V-SHM,3$Y+C8P
M,"==(#T@)TAA;F9O<F0L(%=!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S0V+C8P,#HM.30N,S$W)UT@/2`G4&5Q=6]T($QA:V4L($U.)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0V+C8P-CHM,3$Q+CDV
M-"==(#T@)TAE;&5N82P@2&5L96YA(%)E9VEO;F%L($%I<G!O<G0L($U4)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0V+C8X,SHM-C@N,#4P
M)UT@/2`G4')E<W%U92!)<VQE+"!-12<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<T-BXW.#(Z+3$P,"XW-3<G72`]("=":7-M87)C:RP@0FES
M;6%R8VL@375N:6-I<&%L($%I<G!O<G0L($Y$)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S0V+C@T,SHM.3(N,C(V)UT@/2`G1'5L=71H+"!$
M=6QU=&@@26YT97)N871I;VYA;"!!:7)P;W)T+"!-3B<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<T-BXX-C<Z+38X+C`Q,R==(#T@)T-A<FEB
M;W4L($-A<FEB;W4@375N:6-I<&%L($%I<G!O<G0L($U%)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S0V+CDR,3HM,3$T+C`Y,R==(#T@)TUI
M<W-O=6QA+"!-:7-S;W5L82!);G1E<FYA=&EO;F%L($%I<G!O<G0L($U4)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0V+CDR-3HM.38N.#$Q
M)UT@/2`G1F%R9V\L($AE8W1O<B!);G1E<FYA=&EO;F%L($%I<G!O<G0L($Y$
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0V+CDW,SHM,3(R
M+CDP,R==(#T@)T]L>6UP:6$L($]L>6UP:6$@06ER<&]R="P@5T$G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#<N,3$W.BTQ,C(N-34P)UT@
M/2`G1F]R="!,97=I<R`O($=R87D@52X@4RX@07)M>2!!:7)F:65L9"P@5T$G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#<N,34P.BTQ,C(N
M-#@S)UT@/2`G5&%C;VUA("\@36-#:&]R9"!!:7(@1F]R8V4@0F%S92P@5T$G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#<N,38X.BTX."XT
M.#DG72`]("=(86YC;V-K+"!(;W5G:'1O;B!#;W5N='D@365M;W)I86P@06ER
M<&]R="P@34DG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#<N
M-#0U.BTQ,C(N,S$T)UT@/2`G4V5A='1L92P@4V5A='1L92U486-O;6$@26YT
M97)N871I;VYA;"!!:7)P;W)T+"!702<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<T-RXT-S,Z+3$Q,2XS.#(G72`]("='<F5A="!&86QL<RP@
M1W)E870@1F%L;',@26YT97)N871I;VYA;"!!:7)P;W)T+"!-5"<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-RXU,#`Z+3DT+CDS,R==(#T@
M)T)E;6ED:FDL($U.)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S0W+C8R,3HM,3$W+C4R."==(#T@)U-P;VMA;F4L(%-P;VMA;F4@26YT97)N
M871I;VYA;"!!:7)P;W)T+"!702<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<T-RXW-3`Z+3$P,2XX,S,G72`]("=2;W-E9VQE;BP@3D0G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#<N.3,X.BTQ,C0N-34U
M)UT@/2`G475I;&QA>75T92P@475I;&QA>75T92!3=&%T92!!:7)P;W)T+"!7
M02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T."XQ,#`Z+3DX
M+C@V-R==(#T@)T1E=FEL<R!,86ME+"!.1"<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<T."XQ,S,Z+3$R,RXT,#`G72`]("=0;W)T($%N9V5L
M97,@0V]A<W0@1W5A<F0@06ER(%-T871I;VXL(%=!)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S0X+C$W-#HM,3`S+C8S-R==(#T@)U=I;&QI
M<W1O;BP@4VQO=6QI;B!&:65L9"!);G1E<FYA=&EO;F%L($%I<G!O<G0L($Y$
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0X+C(Q-#HM,3`V
M+C8R,2==(#T@)T=L87-G;W<L($=L87-G;W<@26YT97)N871I;VYA;"!!:7)P
M;W)T+"!-5"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T."XS
M,#0Z+3$Q-"XR-C0G72`]("=+86QI<W!E;&PL($=L86-I97(@4&%R:R!);G1E
M<FYA=&EO;F%L($%I<G!O<G0L($U4)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S0X+C4T,SHM,3`Y+C<V,R==(#T@)TAA=G)E+"!(879R92!#
M:71Y+4-O=6YT>2!!:7)P;W)T+"!-5"<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<T."XU-C(Z+3DS+C,Y."==(#T@)TEN=&5R;F%T:6]N86P@
M1F%L;',L($9A;&QS($EN=&5R;F%T:6]N86P@06ER<&]R="P@34XG.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#@N.3,S.BTY-2XS-3`G72`]
M("=787)R;V%D+"!-3B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<U,2XX.3`Z+3$W-BXV,C4G72`]("=!9&%K+"!.879A;"!!:7(@4W1A=&EO
M;BP@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-3(N-S$W
M.C$W-"XQ,3<G72`]("=3:&5M>6$L($5A<F5C:W-O;B!!<RP@04LG.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-3(N.34P.BTQ-C@N.#4P)UT@
M/2`G3FEK;VQS:VDL($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S4S+CDP,#HM,38V+C4U,"==(#T@)T1U=&-H($AA<F)O<BP@04LG.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-34N,#,S.BTQ,S$N-38W
M)UT@/2`G06YN971T92!)<VQA;F0L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S4U+C(R,3HM,38R+C<R."==(#T@)T-O;&0@0F%Y+"!#
M;VQD($)A>2!!:7)P;W)T+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<U-2XS-3,Z+3$S,2XW,C(G72`]("=+971C:&EK86XL($ME=&-H
M:6MA;B!);G1E<FYA=&EO;F%L($%I<G!O<G0L($%+)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S4U+C4X,SHM,3,S+C`X,R==(#T@)TML87=O
M8VLL($ML87=O8VL@06ER<&]R="P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG-38N-#@S.BTQ,S(N,S8W)UT@/2`G5W)A;F=E;&PL($%+
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S4V+C@Q-SHM,3,R
M+CDV-R==(#T@)U!E=&5R<V)U<F<L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S4V+CDU,#HM,34X+C8Q-R==(#T@)U!O<G0@2&5I9&5N
M+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<U-RXP-#@Z
M+3$S-2XS-C4G72`]("=3:71K82P@4VET:V$@06ER<&]R="P@04LG.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-3<N,34P.BTQ-S`N,C$W)UT@
M/2`G4V%I;G0@4&%U;"P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG-3<N-3`P.BTQ,S0N-3@S)UT@/2`G06YG;V]N+"!!2R<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<U-RXW-3`Z+3$U,BXU,#`G72`]
M("=+;V1I86LL($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S4X+C,U-CHM,3,T+C4V,R==(#T@)TIU;F5A=2P@2G5N96%U($EN=&5R;F%T
M:6]N86P@06ER<&]R="P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG-3@N-#$W.BTQ,S4N-S,S)UT@/2`G1W5S=&%V=7,L($%+)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S4X+C8U,#HM,38R+C`V-R==
M(#T@)T-A<&4@3F5W96YH86T@06ER=V%Y<R!&86-I;&ET:65S(%-E8W1O<BP@
M04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-3@N-C@T.BTQ
M-38N-C4T)UT@/2`G2VEN9R!386QM;VXL($MI;F<@4V%L;6]N($%I<G!O<G0L
M($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S4Y+C`U,#HM
M,34X+C4Q-R==(#T@)T1I;&QI;F=H86T@375N:6-I<&%L+"!!:RP@04LG.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-3DN-#,S.BTQ-#8N,S,S
M)UT@/2`G36ED9&QE=&]N($ES;&%N9"P@06LL($%+)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S4Y+C0V-SHM,3,U+C,P,"==(#T@)U-K86=W
M87DL($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S4Y+C4Q
M-SHM,3,Y+C8V-R==(#T@)UEA:W5T870L($%+)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S4Y+C8S,SHM,34Q+C4P,"==(#T@)TAO;65R("\@
M375N:6-I<&%L+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<U.2XW-3`Z+3$U-"XY,3<G72`]("=);&EA;6YA("\@26QI86UN82!!:7)P
M;W)T+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<U.2XX
M,#`Z+3$T-"XV,#`G72`]("=#87!E(%-A:6YT($5L:6%S+"!!2R<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V,"XP.#,Z+3$T,BXU,#`G72`]
M("=986MA=&%G82P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG-C`N,3$W.BTQ-#DN-#4P)UT@/2`G4V5W87)D+"!!2R<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<V,"XT.3(Z+3$T-2XT-S@G72`]("=#
M;W)D;W9A+"!-97)L92!++B`H375D:&]L92D@4VUI=&@@06ER<&]R="P@04LG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C`N-3@P.BTQ-3$N
M,C,Y)UT@/2`G2V5N86DL($ME;F%I($UU;FEC:7!A;"!!:7)P;W)T+"!!2R<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V,"XW.#,Z+3$V,2XX
M,S,G72`]("="971H96P@+R!"971H96P@06ER<&]R="P@04LG.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C$N,3`P.BTQ-34N-38W)UT@/2`G
M4W!A<G)E=F]H;B!!:7)W87ES($9A8VEL:71I97,@4V5C=&]R+"!!2R<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V,2XQ-S0Z+3$T.2XY.38G
M72`]("=!;F-H;W)A9V4L(%1E9"!3=&5V96YS($%N8VAO<F%G92!);G1E<FYA
M=&EO;F%L($%I<G!O<G0L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S8Q+C(U,#HM,30Y+C@P,"==(#T@)T%N8VAO<F%G92`O($5L;65N
M9&]R9B!!:7(@1F]R8V4@0F%S92P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG-C$N,C8W.BTQ-#DN-C4P)UT@/2`G1G0N(%)I8VAA<F1S
M;VX@+R!"<GEA;G0@52X@4RX@07)M>2!(96QI<&]R="P@06LL($%+)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8Q+C4X,SHM,34Y+C4S,R==
M(#T@)T%N:6%K+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<V,2XV,#`Z+3$T.2XP.#,G72`]("=086QM97(L($%+)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S8Q+C<X,SHM,38V+C`S,R==(#T@)T-A
M<&4@4F]M86YZ;V9F($%I<G=A>7,@1F%C:6QI=&EE<R!396-T;W(L($%+)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8Q+CDV-SHM,34Q+C$X
M,R==(#T@)U-K=V5N=&YA+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<V,BXQ,#`Z+3$U,BXW-3`G72`]("=0=6YT:6QL82P@04LG.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C(N,34P.BTQ-#4N-#4P
M)UT@/2`G1W5L:V%N82P@1W5L:V%N82!!:7)P;W)T+"!!2R<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<V,BXS,C$Z+3$U,"XP.30G72`]("=4
M86QK965T;F$L(%1A;&ME971N82!!:7)P;W)T+"!!2R<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<V,BXY-C,Z+3$T,2XY,S8G72`]("=.;W)T
M:'=A>2P@3F]R=&AW87D@06ER<&]R="P@04LG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-C(N.38W.BTQ-34N-C$W)UT@/2`G36-'<F%T:"P@
M36-'<F%T:"!!:7)P;W)T+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<V,RXW-C<Z+3$W,2XW,S,G72`]("='86UB96QL($%U=&]M871I
M8R!796%T:&5R($]B<V5R=FEN9R`O(%)E<&]R=&EN9R!3>7-T96TL($%+)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8S+C@X,SHM,38P+C@P
M,"==(#T@)U5N86QA:VQE970L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S8S+CDP,#HM,34R+C(V-R==(#T@)TUI;F-H=6UI;F$L($%+
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8T+C`P,#HM,30U
M+C<S,R==(#T@)T9O<G0@1W)E96QY("\@06QL96X@52X@4RX@07)M>2!!:7)F
M:65L9"P@06LL($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S8T+C4Q,CHM,38U+C0S-B==(#T@)TYO;64L($YO;64@06ER<&]R="P@04LG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C0N-34P.BTQ-#DN
M,#@S)UT@/2`G3F5N86YA("\@375N+BP@04LG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-C0N-C4P.BTQ-#<N,#8W)UT@/2`G1F%I<F)A;FMS
M("\@16EE;'-O;B!!:7(@1F]R8V4@0F%S92P@04LG.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG-C0N-S,S.BTQ-38N.3,S)UT@/2`G1V%L96YA
M($$N+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V-"XX
M,#0Z+3$T-RXX-S8G72`]("=&86ER8F%N:W,L($9A:7)B86YK<R!);G1E<FYA
M=&EO;F%L($%I<G!O<G0L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S8U+C$V-SHM,34R+C$P,"==(#T@)U1A;F%N82P@0V%L:&]U;B!-
M96UO<FEA;"!!:7)P;W)T+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<V-2XR-3`Z+3$V-BXX-C<G72`]("=0;W)T($-L87)E;F-E+"!!
M2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V-2XU-C<Z+3$V
M-RXY,3<G72`]("=4:6X@0VET>2!!:7)W87ES($9A8VEL:71I97,@4V5C=&]R
M+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V-2XY.#(Z
M+3$V,2XQ-3(G72`]("="=6-K;&%N9"P@0G5C:VQA;F0@06ER<&]R="P@04LG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C8N,#`P.BTQ-3,N
M-S`P)UT@/2`G26YD:6%N($UO=6YT86EN($%I<G=A>7,@1F%C:6QI=&EE<R!3
M96-T;W(L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8V
M+C4V-SHM,30U+C(V-R==(#T@)T9O<G0@675K;VXL($%+)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S8V+C@X-CHM,38R+C8P-"==(#T@)TMO
M='IE8G5E+"!7:65N($UE;6]R:6%L($%I<G!O<G0L($%+)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S8V+CDQ-SHM,34Q+C4Q-R==(#T@)T)E
M='1L97,L($)E='1L97,@06ER<&]R="P@04LG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-C<N,3`P.BTQ-3<N.#4P)UT@/2`G06UB;&5R+"!!
M;6)L97(@06ER<&]R="P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG-C@N.#@S.BTQ-C8N,3,S)UT@/2`G0V%P92!,:7-B=7)N92!!:7)W
M87ES($9A8VEL:71I97,@4V5C=&]R+"!!2R<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<V.2XS-C<Z+3$U,BXQ,S,G72`]("=5;6EA="P@04LG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-CDN.#$W.BTQ-C(N
M.3$W)UT@/2`G4&]I;G0@3&%Y+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<W,"XQ,S,Z+3$T,RXV,S,G72`]("="87)T97(@27-L86YD
M+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<W,"XR,3`Z
M+3$U,2XP,#8G72`]("=.=6EQ<W5T+"!.=6EQ<W5T($%I<G!O<G0L($%+)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S<P+C4P,#HM,30Y+C@X
M,R==(#T@)T]L:6MT;VL@1&ES=&%N="!%87)L>2!787)N:6YG+"!!2R<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<W,"XV,S,Z+3$U.2XX-3`G
M72`]("=786EN=W)I9VAT+"!786EN=W)I9VAT($%I<G!O<G0L($%+)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S<Q+C(X-#HM,34V+C<W."==
M(#T@)T)A<G)O=RP@4&]S="!2;V=E<G,@365M;W)I86P@06ER<&]R="P@04LG
M.PHD8V]O<F1I;F%T97-;)U5R=6=U87DG75LG+3,P+C,X,SHM-38N-3`P)UT@
M/2`G07)T:6=A<R<["B1C;V]R9&EN871E<ULG57)U9W5A>2==6R<M,S`N.#@S
M.BTU-2XU,S,G72`]("=2:79E<F$G.PHD8V]O<F1I;F%T97-;)U5R=6=U87DG
M75LG+3,Q+C,X,SHM-3<N.34P)UT@/2`G4V%L=&\G.PHD8V]O<F1I;F%T97-;
M)U5R=6=U87DG75LG+3,Q+C<P,#HM-34N.3@S)UT@/2`G5&%C=6%R96UB;R<[
M"B1C;V]R9&EN871E<ULG57)U9W5A>2==6R<M,S(N,S,S.BTU."XP,S,G72`]
M("=087ES86YD=2<["B1C;V]R9&EN871E<ULG57)U9W5A>2==6R<M,S(N,S8W
M.BTU-"XR,3<G72`]("=-96QO)SL*)&-O;W)D:6YA=&5S6R=5<G5G=6%Y)UU;
M)RTS,RXR,3<Z+34T+C,X,R==(#T@)U1R96EN=&$@62!4<F5S)SL*)&-O;W)D
M:6YA=&5S6R=5<G5G=6%Y)UU;)RTS,RXR-3`Z+34X+C`V-R==(#T@)TUE<F-E
M9&5S)SL*)&-O;W)D:6YA=&5S6R=5<G5G=6%Y)UU;)RTS,RXS-3`Z+34V+C4P
M,"==(#T@)T1U<F%Z;F\G.PHD8V]O<F1I;F%T97-;)U5R=6=U87DG75LG+3,T
M+C0U,#HM-3<N.#,S)UT@/2`G0V]L;VYI82<["B1C;V]R9&EN871E<ULG57)U
M9W5A>2==6R<M,S0N-S@S.BTU-BXR-3`G72`]("=-96QI;&QA)SL*)&-O;W)D
M:6YA=&5S6R=5<G5G=6%Y)UU;)RTS-"XX,S,Z+34V+C`P,"==(#T@)T-A<G)A
M<V-O)SL*)&-O;W)D:6YA=&5S6R=5>F)E:VES=&%N)UU;)S,W+C(S,SHV-RXR
M-C<G72`]("=497)M97HG.PHD8V]O<F1I;F%T97-;)U5Z8F5K:7-T86XG75LG
M,SDN-38W.C8V+CDU,"==(#T@)U-A;6%R:V%N9"<["B1C;V]R9&EN871E<ULG
M57IB96MI<W1A;B==6R<T,"XQ,3<Z-C<N.#,S)UT@/2`G1'II>F%K)SL*)&-O
M;W)D:6YA=&5S6R=5>F)E:VES=&%N)UU;)S0Q+C(V-SHV.2XR-C<G72`]("=4
M87-H:V5N="<["B1C;V]R9&EN871E<ULG57IB96MI<W1A;B==6R<T,2XW,S,Z
M-C0N-C$W)UT@/2`G5&%M9'DG.PHD8V]O<F1I;F%T97-;)U9A;G5A='4G75LG
M+3$S+C@U,#HQ-C<N-34P)UT@/2`G4V]L82!686YU82!,879A)SL*)&-O;W)D
M:6YA=&5S6R=686YU871U)UU;)RTQ-2XU,3<Z,38W+C(Q-R==(#T@)U!E:V]A
M($%I<G!O<G0@4V%N=&\G.PHD8V]O<F1I;F%T97-;)U9A;G5A='4G75LG+3$V
M+C0Q-SHQ-C<N.#`P)UT@/2`G3&%M87`@36%L96MU;&$G.PHD8V]O<F1I;F%T
M97-;)U9A;G5A='4G75LG+3$W+C<P,#HQ-C@N,S`P)UT@/2`G0F%U97)F:65L
M9"!%9F%T92<["B1C;V]R9&EN871E<ULG5F5N97IU96QA)UU;)S$P+C`V-SHM
M-CDN,S$W)UT@/2`G0F%R<75I<VEM971O)SL*)&-O;W)D:6YA=&5S6R=696YE
M>G5E;&$G75LG,3`N,3$W.BTV-"XV.#,G72`]("="87)C96QO;F$G.PHD8V]O
M<F1I;F%T97-;)U9E;F5Z=65L82==6R<Q,"XQ-C<Z+38W+CDS,R==(#T@)U9A
M;&5N8VEA)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG,3`N,C4P.BTV
M-RXV-3`G72`]("=-87)A8V%Y+4(N($$N(%-U8W)E)SL*)&-O;W)D:6YA=&5S
M6R=696YE>G5E;&$G75LG,3`N-#4P.BTV-"XQ.#,G72`]("=#=6UA;F$G.PHD
M8V]O<F1I;F%T97-;)U9E;F5Z=65L82==6R<Q,"XU,#`Z+38V+C@X,R==(#T@
M)T-A<F%C87,@+R!,82!#87)L;W1A)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E
M;&$G75LG,3`N-3`P.BTV."XP,#`G72`]("=0=&\N($-A8F5L;&\G.PHD8V]O
M<F1I;F%T97-;)U9E;F5Z=65L82==6R<Q,"XU-C<Z+3<Q+C<S,R==(#T@)TUA
M<F%C86EB;RU,82!#:&EN:71A)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G
M75LG,3`N-3@S.BTV,BXS,3<G72`]("='=6ER:6$G.PHD8V]O<F1I;F%T97-;
M)U9E;F5Z=65L82==6R<Q,"XV,#`Z+38V+CDX,R==(#T@)T-A<F%C87,@+R!-
M86EQ=65T:6$@065R;W`N($EN=&PN(%-I;6]N($)O;&EV87(G.PHD8V]O<F1I
M;F%T97-;)U9E;F5Z=65L82==6R<Q,2XT,3<Z+38Y+C8X,R==(#T@)T-O<F\G
M.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L82==6R<Q,2XX,#`Z+38V+C$X,R==
M(#T@)TQA($]R8VAI;&$G.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L82==6R<T
M+C8P,#HM-C$N,3$W)UT@/2`G4V%N=&$@16QE;F$@1&4@56%I<F5N)SL*)&-O
M;W)D:6YA=&5S6R=696YE>G5E;&$G75LG-2XV,#`Z+38W+C4P,"==(#T@)U!U
M97)T;R!!>6%C=6-H;R<["B1C;V]R9&EN871E<ULG5F5N97IU96QA)UU;)S<N
M,C,S.BTW,"XX,#`G72`]("='=6%S9'5A;&ET;R<["B1C;V]R9&EN871E<ULG
M5F5N97IU96QA)UU;)S<N,S`P.BTV,2XT-3`G72`]("=4=6UE<F5M;R<["B1C
M;V]R9&EN871E<ULG5F5N97IU96QA)UU;)S<N-3@S.BTW,BXP-C<G72`]("=3
M=&\N($1O;6EN9V\G.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L82==6R<W+C@U
M,#HM-S(N-#4P)UT@/2`G4V%N($%N=&]N:6\@1&5L(%1A8VAI<F$G.PHD8V]O
M<F1I;F%T97-;)U9E;F5Z=65L82==6R<W+CDP,#HM-C<N-#$W)UT@/2`G4V%N
M($9E<FYA;F1O($1E($%P=7)E)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G
M75LG."XQ-3`Z+38S+C4U,"==(#T@)T-I=61A9"!";VQI=F%R)SL*)&-O;W)D
M:6YA=&5S6R=696YE>G5E;&$G75LG."XV,#`Z+3<Q+C$X,R==(#T@)TUE<FED
M82<["B1C;V]R9&EN871E<ULG5F5N97IU96QA)UU;)S@N-C$W.BTW,"XR,3<G
M72`]("="87)I;F%S)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG."XY
M,S,Z+38W+C0Q-R==(#T@)T-A;&%B;WIO)SL*)&-O;W)D:6YA=&5S6R=696YE
M>G5E;&$G75LG.2XP,3<Z+38R+C8Q-R==(#T@)U1E;6)L861O<B<["B1C;V]R
M9&EN871E<ULG5F5N97IU96QA)UU;)SDN,#$W.BTV.2XW,S,G72`]("='=6%N
M87)E)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG.2XR,3<Z+38V+C`Q
M-R==(#T@)U9A;&QE($1E($QA(%!A<V-U82<["B1C;V]R9&EN871E<ULG5F5N
M97IU96QA)UU;)SDN,S4P.BTW,"XV,3<G72`]("=686QE<F$G.PHD8V]O<F1I
M;F%T97-;)U9E;F5Z=65L82==6R<Y+C4U,#HM-CDN,C,S)UT@/2`G06-A<FEG
M=6$G.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L82==6R<Y+C<U,#HM-C,N,3@S
M)UT@/2`G36%T=7)I;B<["B1C;V]R9&EN871E<ULG5F5N97IU96QA)UU;)SDN
M.#$W.BTW,"XY,S,G72`]("=-96YE($=R86YD92<["B1C;V]R9&EN871E<ULG
M5F5N97IU96QA)UU;)SDN.3$W.BTV-RXS,S,G72`]("=386X@2G5A;B!$92!,
M;W,@36]R<F]S)SL*)&-O;W)D:6YA=&5S6R=6:65T($YA;2==6R<Q,"XX,3<Z
M,3`V+C8V-R==(#T@)TAO($-H:2!-:6YH)SL*)&-O;W)D:6YA=&5S6R=6:65T
M($YA;2==6R<Q,BXR-3`Z,3`Y+C(P,"==(#T@)TYH82!4<F%N9R<["B1C;V]R
M9&EN871E<ULG5FEE="!.86TG75LG,3,N-S8W.C$P.2XR,3<G72`]("=1=7D@
M3FAO;B<["B1C;V]R9&EN871E<ULG5FEE="!.86TG75LG,3,N.3@S.C$P."XP
M,#`G72`]("=0;&5I:W4@0VET>2<["B1C;V]R9&EN871E<ULG5FEE="!.86TG
M75LG,38N,#,S.C$P."XQ.#,G72`]("=$82!.86YG)SL*)&-O;W)D:6YA=&5S
M6R=6:65T($YA;2==6R<Q-BXT,#`Z,3`W+C8X,R==(#T@)TAU92<["B1C;V]R
M9&EN871E<ULG5FEE="!.86TG75LG,3@N-S`P.C$P-2XV-C<G72`]("=6:6YH
M)SL*)&-O;W)D:6YA=&5S6R=6:65T($YA;2==6R<R,2XP,3<Z,3`U+C@P,"==
M(#T@)TAA($YO:2<["B1C;V]R9&EN871E<ULG5FER9VEN($ES;&%N9',L($)R
M:71I<V@G75LG,3@N-#4P.BTV-"XU,S,G72`]("="965F($ES;&%N9"P@5&]R
M=&]L82<["B1C;V]R9&EN871E<ULG5FER9VEN($ES;&%N9',L(%5N:71E9"!3
M=&%T97,G75LG,3<N-S`P.BTV-"XX,#`G72`]("=#:')I<W1I86YS=&5D+"!(
M96YR>2!%+B!2;VAL<V5N($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U9I<F=I
M;B!)<VQA;F1S+"!5;FET960@4W1A=&5S)UU;)S$X+C,S,SHM-C0N.3@S)UT@
M/2`G0VAA<FQO='1E($%M86QI92!3="X@5&AO;6%S+"!#>7)I;"!%+B!+:6YG
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U=E<W1E<FX@4V%H87)A)UU;)S(S
M+C<P,#HM,34N.#8W)UT@/2`G5FEL;&$@0VES;F5R;W,G.PHD8V]O<F1I;F%T
M97-;)UEE;65N)UU;)S$R+C8S,SHU,RXY,#`G72`]("=3;V-O=')A)SL*)&-O
M;W)D:6YA=&5S6R=996UE;B==6R<Q,BXV-C<Z-#4N,#,S)UT@/2`G061E;B<[
M"B1C;V]R9&EN871E<ULG665M96XG75LG,3,N,C4P.C0S+C(X,R==(#T@)TUO
M:VAA)SL*)&-O;W)D:6YA=&5S6R=996UE;B==6R<Q,RXR-3`Z-#0N,3,S)UT@
M/2`G36]K:&$G.PHD8V]O<F1I;F%T97-;)UEE;65N)UU;)S$S+C8X,SHT-"XQ
M,S,G72`]("=486EZ)SL*)&-O;W)D:6YA=&5S6R=996UE;B==6R<Q-"XU,3<Z
M-#8N.#4P)UT@/2`G071A<2<["B1C;V]R9&EN871E<ULG665M96XG75LG,30N
M-C4P.C0Y+C,X,R==(#T@)U)I>6%N)SL*)&-O;W)D:6YA=&5S6R=996UE;B==
M6R<Q-"XW-3`Z-#(N.3@S)UT@/2`G2&]D96ED86@G.PHD8V]O<F1I;F%T97-;
M)UEE;65N)UU;)S$U+C0S,SHT-2XS,S,G72`]("=-87)I8B<["B1C;V]R9&EN
M871E<ULG665M96XG75LG,34N-3$W.C0T+C$X,R==(#T@)U-A;F%<)T$G.PHD
M8V]O<F1I;F%T97-;)UEE;65N)UU;)S$V+C(P,#HT-"XW.#,G72`]("=!;"U(
M87IM)SL*)&-O;W)D:6YA=&5S6R=9=6=O<VQA=FEA)UU;)S0R+C,V-SHQ.2XR
M-3`G72`]("=0;V1G;W)I8V$@+R!';VQU8F]V8VDG.PHD8V]O<F1I;F%T97-;
M)UEU9V]S;&%V:6$G75LG-#(N-#`P.C$X+C<S,R==(#T@)U1I=F%T)SL*)&-O
M;W)D:6YA=&5S6R=9=6=O<VQA=FEA)UU;)S0R+C8U,#HR,2XQ-3`G72`]("=0
M<FES=&EN82<["B1C;V]R9&EN871E<ULG675G;W-L879I82==6R<T,RXS,S,Z
M,C$N.3`P)UT@/2`G3FES)SL*)&-O;W)D:6YA=&5S6R=9=6=O<VQA=FEA)UU;
M)S0S+C,U,#HQ-RXX,#`G72`]("=-;W-T87(G.PHD8V]O<F1I;F%T97-;)UEU
M9V]S;&%V:6$G75LG-#,N.#$W.C$X+C,S,R==(#T@)U-A<F%J979O("\@0G5T
M;6ER)SL*)&-O;W)D:6YA=&5S6R=9=6=O<VQA=FEA)UU;)S0T+C4U,#HQ."XW
M,#`G72`]("=4=7IL82<["B1C;V]R9&EN871E<ULG675G;W-L879I82==6R<T
M-"XW.#,Z,3<N,C$W)UT@/2`G0F%N:F$@3'5K82<["B1C;V]R9&EN871E<ULG
M675G;W-L879I82==6R<T-"XX,3<Z,34N.#@S)UT@/2`G0FEH86,G.PHD8V]O
M<F1I;F%T97-;)UEU9V]S;&%V:6$G75LG-#0N.#$W.C(P+C(X,R==(#T@)T)E
M;V=R860@+R!3=7)C:6XG.PHD8V]O<F1I;F%T97-;)UEU9V]S;&%V:6$G75LG
M-#4N,34P.C(Q+C,Q-R==(#T@)U9R<V%C)SL*)&-O;W)D:6YA=&5S6R=:86ER
M92==6R<P+C`U,#HQ."XR-C<G72`]("=-8F%N9&%K82<["B1C;V]R9&EN871E
M<ULG6F%I<F4G75LG,"XQ,S,Z,CDN,C8W)UT@/2`G0G5T96UB;R<["B1C;V]R
M9&EN871E<ULG6F%I<F4G75LG+3`N,C$W.C(P+C@U,"==(#T@)T)O96YD92<[
M"B1C;V]R9&EN871E<ULG6F%I<F4G75LG,"XU,3<Z,C4N,3@S)UT@/2`G2VES
M86YG86YI)SL*)&-O;W)D:6YA=&5S6R=:86ER92==6R<M,2XQ.#,Z,CDN-#4P
M)UT@/2`G4G5T<VAU<G4G.PHD8V]O<F1I;F%T97-;)UIA:7)E)UU;)RTQ+C8X
M,SHR.2XR,S,G72`]("=';VUA)SL*)&-O;W)D:6YA=&5S6R=:86ER92==6R<M
M,2XY-C<Z,3@N,C8W)UT@/2`G26YO;F=O)SL*)&-O;W)D:6YA=&5S6R=:86ER
M92==6R<M,3`N-S$W.C(U+C0U,"==(#T@)TMO;'=E>FDG.PHD8V]O<F1I;F%T
M97-;)UIA:7)E)UU;)RTQ,2XV-C<Z,C<N-#@S)UT@/2`G3'5B=6UB87-H:2U,
M=6%N;R<["B1C;V]R9&EN871E<ULG6F%I<F4G75LG+3(N.34P.C(U+CDQ-R==
M(#T@)TMI;F1U)SL*)&-O;W)D:6YA=&5S6R=:86ER92==6R<S+C(X,SHQ.2XW
M.#,G72`]("='96UE;F$G.PHD8V]O<F1I;F%T97-;)UIA:7)E)UU;)RTS+C,P
M,#HQ-RXS-3`G72`]("="86YD=6YD=2<["B1C;V]R9&EN871E<ULG6F%I<F4G
M75LG+3,N-#@S.C(S+C0V-R==(#T@)TQO9&IA)SL*)&-O;W)D:6YA=&5S6R=:
M86ER92==6R<M-"XS,S,Z,C`N-3@S)UT@/2`G26QE8F\G.PHD8V]O<F1I;F%T
M97-;)UIA:7)E)UU;)RTT+C,X,SHQ-2XT,S,G72`]("=+:6YS:&%S82`O($Y<
M)T1J:6QI)SL*)&-O;W)D:6YA=&5S6R=:86ER92==6R<M-"XY,3<Z,3<N,#8W
M)UT@/2`G2V5N9V4G.PHD8V]O<F1I;F%T97-;)UIA:7)E)UU;)RTT+CDV-SHR
M,RXT,S,G72`]("=,=7-A;6)O)SL*)&-O;W)D:6YA=&5S6R=:86ER92==6R<M
M-2XP,S,Z,3@N.#`P)UT@/2`G2VEK=VET)SL*)&-O;W)D:6YA=&5S6R=:86ER
M92==6R<M-2XS-3`Z,C<N,#`P)UT@/2`G2V]N9V]L;R<["B1C;V]R9&EN871E
M<ULG6F%I<F4G75LG+34N-3$W.C$S+C4X,R==(#T@)TEN9V$G.PHD8V]O<F1I
M;F%T97-;)UIA:7)E)UU;)RTU+C@P,#HQ,RXT,S,G72`]("=-871A9&DG.PHD
M8V]O<F1I;F%T97-;)UIA:7)E)UU;)RTU+C@X,SHR,BXT,3<G72`]("=+86YA
M;F=A)SL*)&-O;W)D:6YA=&5S6R=:86ER92==6R<M-2XX.#,Z,CDN,3@S)UT@
M/2`G2V%L96UI92<["B1C;V]R9&EN871E<ULG6F%I<F4G75LG+38N,#`P.C$R
M+C0Q-R==(#T@)TUO86YD82<["B1C;V]R9&EN871E<ULG6F%I<F4G75LG+38N
M,38W.C(S+C8Q-R==(#T@)TUB=6II+4UA>6DG.PHD8V]O<F1I;F%T97-;)UIA
M:7)E)UU;)RTV+C0Q-SHR,"XX-3`G72`]("=4<VAI:V%P82<["B1C;V]R9&EN
M871E<ULG6F%I<F4G75LG+3<N,C@S.C(W+C0S,R==(#T@)TUA;F]N;R<["B1C
M;V]R9&EN871E<ULG6F%I<F4G75LG+3@N-C,S.C(U+C(U,"==(#T@)TMA;6EN
M82`O($)A<V4G.PHD8V]O<F1I;F%T97-;)UIA;6)I82==6R<M,3`N,3$W.C,R
M+C8S,R==(#T@)TES;VMA)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3$P
M+C(Q-SHS,2XQ,S,G72`]("=+87-A;6$G.PHD8V]O<F1I;F%T97-;)UIA;6)I
M82==6R<M,3$N,3`P.C(X+C@U,"==(#T@)TUA;G-A)SL*)&-O;W)D:6YA=&5S
M6R=:86UB:6$G75LG+3$Q+C<U,#HR-"XT,S,G72`]("=-=VEN:6QU;F=A)SL*
M)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3$Q+CDP,#HS,2XT,S,G72`]("=-
M<&EK82<["B1C;V]R9&EN871E<ULG6F%M8FEA)UU;)RTQ,BXQ.#,Z,C8N,S@S
M)UT@/2`G4V]L=V5Z:2<["B1C;V]R9&EN871E<ULG6F%M8FEA)UU;)RTQ,BXR
M.#,Z,S,N,C`P)UT@/2`G3'5N9&%Z:2<["B1C;V]R9&EN871E<ULG6F%M8FEA
M)UU;)RTQ,RXP,#`Z,C@N-C4P)UT@/2`G3F1O;&$G.PHD8V]O<F1I;F%T97-;
M)UIA;6)I82==6R<M,3,N,C,S.C,P+C(Q-R==(#T@)U-E<F5N:F4G.PHD8V]O
M<F1I;F%T97-;)UIA;6)I82==6R<M,3,N-3,S.C(S+C$Q-R==(#T@)UIA;6)E
M>FDG.PHD8V]O<F1I;F%T97-;)UIA;6)I82==6R<M,3,N-3,S.C(U+C@U,"==
M(#T@)TMA<V5M<&$G.PHD8V]O<F1I;F%T97-;)UIA;6)I82==6R<M,3,N-34P
M.C,R+C4X,R==(#T@)T-H:7!A=&$G.PHD8V]O<F1I;F%T97-;)UIA;6)I82==
M6R<M,3,N-C`P.C(T+C(P,"==(#T@)TMA8F]M<&\G.PHD8V]O<F1I;F%T97-;
M)UIA;6)I82==6R<M,30N,C4P.C,Q+C(X,R==(#T@)U!E=&%U:V4G.PHD8V]O
M<F1I;F%T97-;)UIA;6)I82==6R<M,30N-#4P.C(X+C0V-R==(#T@)TMA8G=E
M)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3$T+C0U,#HR."XT-C<G72`]
M("=,=7-A:V$@0VET>2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G
M75LG+3$T+C@P,#HR-"XX,#`G72`]("=+86]M82<["B1C;V]R9&EN871E<ULG
M6F%M8FEA)UU;)RTQ-2XR-3`Z,C,N,34P)UT@/2`G36]N9W4G.PHD8V]O<F1I
M;F%T97-;)UIA;6)I82==6R<M,34N,S$W.C(X+C0U,"==(#T@)TQU<V%K82!)
M;G1E<FYA=&EO;F%L86ER<&]R="<["B1C;V]R9&EN871E<ULG6F%M8FEA)UU;
M)RTQ-BXQ,#`Z,C,N,C8W)UT@/2`G4V5N86YG82<["B1C;V]R9&EN871E<ULG
M6F%M8FEA)UU;)RTQ-BXX,S,Z,C<N,#8W)UT@/2`G0VAO;6$G.PHD8V]O<F1I
M;F%T97-;)UIA;6)I82==6R<M,3<N-#8W.C(T+C,P,"==(#T@)U-E<VAE:V4G
M.PHD8V]O<F1I;F%T97-;)UIA;6)I82==6R<M,3<N.#$W.C(U+C@Q-R==(#T@
M)TQI=FEN9W-T;VYE)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3@N.#4P
M.C,Q+C,S,R==(#T@)TUB86QA)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG
M+3DN.#`P.C(Y+C`X,R==(#T@)TMA=V%M8G=A)SL*)&-O;W)D:6YA=&5S6R=:
M:6UB86)W92==6R<M,38N-3$W.C(X+C@X,R==(#T@)TMA<FEB82<["B1C;V]R
M9&EN871E<ULG6FEM8F%B=V4G75LG+3$V+C@S,SHR.2XV,3<G72`]("=+87)O
M:2<["B1C;V]R9&EN871E<ULG6FEM8F%B=V4G75LG+3$W+C0Q-SHS,BXR,3<G
M72`]("=-=71O:V\G.PHD8V]O<F1I;F%T97-;)UII;6)A8G=E)UU;)RTQ-RXV
M,3<Z,C<N,S,S)UT@/2`G0FEN9V$G.PHD8V]O<F1I;F%T97-;)UII;6)A8G=E
M)UU;)RTQ-RXY,3<Z,S$N,3,S)UT@/2`G2&%R87)E($MU='-A9V$G.PHD8V]O
M<F1I;F%T97-;)UII;6)A8G=E)UU;)RTQ."XQ,#`Z,C4N.#4P)UT@/2`G5FEC
M=&]R:6$@1F%L;',G.PHD8V]O<F1I;F%T97-;)UII;6)A8G=E)UU;)RTQ."XR
M,3<Z,C@N.3,S)UT@/2`G1V]K=V4G.PHD8V]O<F1I;F%T97-;)UII;6)A8G=E
M)UU;)RTQ."XU,S,Z,S(N,3,S)UT@/2`G4G5S87!E)SL*)&-O;W)D:6YA=&5S
M6R=::6UB86)W92==6R<M,3@N-C,S.C(W+C`P,"==(#T@)TAW86YG92!.871I
M;VYA;"!087)K)SL*)&-O;W)D:6YA=&5S6R=::6UB86)W92==6R<M,3DN-#4P
M.C(Y+C@U,"==(#T@)T=W97)U)SL*)&-O;W)D:6YA=&5S6R=::6UB86)W92==
M6R<M,C`N,#$W.C(X+C8Q-R==(#T@)T)U;&%W87EO($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)UII;6)A8G=E)UU;)RTR,"XP-C<Z,S`N.#8W)UT@/2`G36%S
M=FEN9V\G.PHD8V]O<F1I;F%T97-;)UII;6)A8G=E)UU;)RTR,"XR,#`Z,S(N
M-C$W)UT@/2`G0VAI<&EN9V4G.PHD8V]O<F1I;F%T97-;)UII;6)A8G=E)UU;
M)RTR,2XP,3<Z,S$N-3@S)UT@/2`G0G5F9F%L;R!286YG92<["B1C;V]R9&EN
M871E<ULG6FEM8F%B=V4G75LG+3(R+C(Q-SHS,"XP,#`G72`]("="96ET8G)I
M9&=E)SL*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP````````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-C,P-0`Q,#4Q-30S,S<U,``P,C(V
M-#<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J(%1H92!)4T\M,S$V-B!C;W5N=')Y(&QI<W0N"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<"QV(#$N
M,RXQ,BXQ(#(P,#4O,3`O,3@@,3$Z,#$Z,3@@:F%N($5X<"`D"B`J"B`J($!P
M86-K86=E($AO<F1E7TY,4PH@*B\*"B1C;W5N=')I97,@/2!A<G)A>2@*("`@
M("=!1B<@/3X@7R@B069G:&%N:7-T86XB*2P*("`@("=!3"<@/3X@7R@B06QB
M86YI82(I+`H@("`@)T1:)R`]/B!?*")!;&=E<FEA(BDL"B`@("`G05,G(#T^
M(%\H(D%M97)I8V%N(%-A;6]A(BDL"B`@("`G040G(#T^(%\H(D%N9&]R<F$B
M*2P*("`@("=!3R<@/3X@7R@B06YG;VQA(BDL"B`@("`G04DG(#T^(%\H(D%N
M9W5I;&QA(BDL"B`@("`G05$G(#T^(%\H(D%N=&%R8W1I8V$B*2P*("`@("=!
M1R<@/3X@7R@B06YT:6=U82!A;F0@0F%R8G5D82(I+`H@("`@)T%2)R`]/B!?
M*")!<F=E;G1I;F$B*2P*("`@("=!32<@/3X@7R@B07)M96YI82(I+`H@("`@
M)T%7)R`]/B!?*")!<G5B82(I+`H@("`@)T%5)R`]/B!?*")!=7-T<F%L:6$B
M*2P*("`@("=!5"<@/3X@7R@B075S=')I82(I+`H@("`@)T%:)R`]/B!?*")!
M>F5R8F%I:F%N(BDL"B`@("`G0E,G(#T^(%\H(D)A:&%M87,B*2P*("`@("="
M2"<@/3X@7R@B0F%H<F%I;B(I+`H@("`@)T)$)R`]/B!?*")"86YG;&%D97-H
M(BDL"B`@("`G0D(G(#T^(%\H(D)A<F)A9&]S(BDL"B`@("`G0EDG(#T^(%\H
M(D)E;&%R=7,B*2P*("`@("="12<@/3X@7R@B0F5L9VEU;2(I+`H@("`@)T):
M)R`]/B!?*")"96QI>F4B*2P*("`@("="2B<@/3X@7R@B0F5N:6XB*2P*("`@
M("="32<@/3X@7R@B0F5R;75D82(I+`H@("`@)T)4)R`]/B!?*")":'5T86XB
M*2P*("`@("="3R<@/3X@7R@B0F]L:79I82(I+`H@("`@)T)!)R`]/B!?*")"
M;W-N:6$@86YD($AE<GIE9V]V:6YA(BDL"B`@("`G0E<G(#T^(%\H(D)O='-W
M86YA(BDL"B`@("`G0E8G(#T^(%\H(D)O=79E="!)<VQA;F0B*2P*("`@("="
M4B<@/3X@7R@B0G)A>FEL(BDL"B`@("`G24\G(#T^(%\H(D)R:71I<V@@26YD
M:6%N($]C96%N(%1E<G)I=&]R>2(I+`H@("`@)T).)R`]/B!?*")"<G5N96D@
M1&%R=7-S86QA;2(I+`H@("`@)T)')R`]/B!?*")"=6QG87)I82(I+`H@("`@
M)T)&)R`]/B!?*")"=7)K:6YA($9A<V\B*2P*("`@("="22<@/3X@7R@B0G5R
M=6YD:2(I+`H@("`@)TM()R`]/B!?*")#86UB;V1I82(I+`H@("`@)T--)R`]
M/B!?*")#86UE<F]O;B(I+`H@("`@)T-!)R`]/B!?*")#86YA9&$B*2P*("`@
M("=#5B<@/3X@7R@B0V%P92!697)D92(I+`H@("`@)TM9)R`]/B!?*")#87EM
M86X@27-L86YD<R(I+`H@("`@)T-&)R`]/B!?*")#96YT<F%L($%F<FEC86X@
M4F5P=6)L:6,B*2P*("`@("=41"<@/3X@7R@B0VAA9"(I+`H@("`@)T-,)R`]
M/B!?*")#:&EL92(I+`H@("`@)T-.)R`]/B!?*")#:&EN82(I+`H@("`@)T-8
M)R`]/B!?*")#:')I<W1M87,@27-L86YD(BDL"B`@("`G0T,G(#T^(%\H(D-O
M8V]S("A+965L:6YG*2!)<VQA;F1S(BDL"B`@("`G0T\G(#T^(%\H(D-O;&]M
M8FEA(BDL"B`@("`G2TTG(#T^(%\H(D-O;6]R;W,B*2P*("`@("=#1R<@/3X@
M7R@B0V]N9V\B*2P*("`@("=#1"<@/3X@7R@B0V]N9V\L(%1H92!$96UO8W)A
M=&EC(%)E<'5B;&EC(&]F('1H92(I+`H@("`@)T-+)R`]/B!?*")#;V]K($ES
M;&%N9',B*2P*("`@("=#4B<@/3X@7R@B0V]S=&$@4FEC82(I+`H@("`@)T-)
M)R`]/B!?*")#;W1E(&0G279O:7)E(BDL"B`@("`G2%(G(#T^(%\H(D-R;V%T
M:6$B*2P*("`@("=#52<@/3X@7R@B0W5B82(I+`H@("`@)T-9)R`]/B!?*")#
M>7!R=7,B*2P*("`@("=#6B<@/3X@7R@B0WIE8V@@4F5P=6)L:6,B*2P*("`@
M("=$2R<@/3X@7R@B1&5N;6%R:R(I+`H@("`@)T1*)R`]/B!?*")$:FEB;W5T
M:2(I+`H@("`@)T1-)R`]/B!?*")$;VUI;FEC82(I+`H@("`@)T1/)R`]/B!?
M*")$;VUI;FEC86X@4F5P=6)L:6,B*2P*("`@("=%0R<@/3X@7R@B16-U861O
M<B(I+`H@("`@)T5')R`]/B!?*")%9WEP="(I+`H@("`@)U-6)R`]/B!?*")%
M;"!386QV861O<B(I+`H@("`@)T=1)R`]/B!?*")%<75A=&]R:6%L($=U:6YE
M82(I+`H@("`@)T52)R`]/B!?*")%<FET<F5A(BDL"B`@("`G144G(#T^(%\H
M(D5S=&]N:6$B*2P*("`@("=%5"<@/3X@7R@B171H:6]P:6$B*2P*("`@("=&
M2R<@/3X@7R@B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(BDL"B`@("`G
M1D\G(#T^(%\H(D9A<F]E($ES;&%N9',B*2P*("`@("=&2B<@/3X@7R@B1FEJ
M:2(I+`H@("`@)T9))R`]/B!?*")&:6YL86YD(BDL"B`@("`G1E(G(#T^(%\H
M(D9R86YC92(I+`H@("`@)T=&)R`]/B!?*")&<F5N8V@@1W5I86YA(BDL"B`@
M("`G4$8G(#T^(%\H(D9R96YC:"!0;VQY;F5S:6$B*2P*("`@("=41B<@/3X@
M7R@B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(BDL"B`@("`G1T$G(#T^
M(%\H(D=A8F]N(BDL"B`@("`G1TTG(#T^(%\H(D=A;6)I82(I+`H@("`@)T=%
M)R`]/B!?*")'96]R9VEA(BDL"B`@("`G1$4G(#T^(%\H(D=E<FUA;GDB*2P*
M("`@("='2"<@/3X@7R@B1VAA;F$B*2P*("`@("='22<@/3X@7R@B1VEB<F%L
M=&%R(BDL"B`@("`G1U(G(#T^(%\H(D=R965C92(I+`H@("`@)T=,)R`]/B!?
M*")'<F5E;FQA;F0B*2P*("`@("='1"<@/3X@7R@B1W)E;F%D82(I+`H@("`@
M)T=0)R`]/B!?*")'=6%D96QO=7!E(BDL"B`@("`G1U4G(#T^(%\H(D=U86TB
M*2P*("`@("='5"<@/3X@7R@B1W5A=&5M86QA(BDL"B`@("`G1TXG(#T^(%\H
M(D=U:6YE82(I+`H@("`@)T=7)R`]/B!?*")'=6EN96$M0FES<V%U(BDL"B`@
M("`G1UDG(#T^(%\H(D=U>6%N82(I+`H@("`@)TA4)R`]/B!?*")(86ET:2(I
M+`H@("`@)TA-)R`]/B!?*")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES
M;&%N9',B*2P*("`@("=602<@/3X@7R@B2&]L>2!3964@*%9A=&EC86X@0VET
M>2!3=&%T92DB*2P*("`@("=(3B<@/3X@7R@B2&]N9'5R87,B*2P*("`@("=(
M2R<@/3X@7R@B2&]N9R!+;VYG(BDL"B`@("`G2%4G(#T^(%\H(DAU;F=A<GDB
M*2P*("`@("=)4R<@/3X@7R@B26-E;&%N9"(I+`H@("`@)TE.)R`]/B!?*"))
M;F1I82(I+`H@("`@)TE$)R`]/B!?*"));F1O;F5S:6$B*2P*("`@("=)4B<@
M/3X@7R@B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(I+`H@("`@)TE1)R`]
M/B!?*"))<F%Q(BDL"B`@("`G244G(#T^(%\H(DER96QA;F0B*2P*("`@("=)
M3"<@/3X@7R@B27-R865L(BDL"B`@("`G250G(#T^(%\H(DET86QY(BDL"B`@
M("`G2DTG(#T^(%\H(DIA;6%I8V$B*2P*("`@("=*4"<@/3X@7R@B2F%P86XB
M*2P*("`@("=*3R<@/3X@7R@B2F]R9&%N(BDL"B`@("`G2UHG(#T^(%\H(DMA
M>F%K:'-T86XB*2P*("`@("=+12<@/3X@7R@B2V5N>6$B*2P*("`@("=+22<@
M/3X@7R@B2VER:6)A=&DB*2P*("`@("=+4"<@/3X@7R@B2V]R96$L($1E;6]C
M<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B*2P*("`@("=+4B<@/3X@7R@B
M2V]R96$L(%)E<'5B;&EC(&]F(BDL"B`@("`G2U<G(#T^(%\H(DMU=V%I="(I
M+`H@("`@)TM')R`]/B!?*")+>7)G>7IS=&%N(BDL"B`@("`G3$$G(#T^(%\H
M(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(BDL"B`@("`G3%8G
M(#T^(%\H(DQA='9I82(I+`H@("`@)TQ")R`]/B!?*"),96)A;F]N(BDL"B`@
M("`G3%,G(#T^(%\H(DQE<V]T:&\B*2P*("`@("=,4B<@/3X@7R@B3&EB97)I
M82(I+`H@("`@)TQ9)R`]/B!?*"),:6)Y86X@07)A8B!*86UA:&ER:7EA(BDL
M"B`@("`G3$DG(#T^(%\H(DQI96-H=&5N<W1E:6XB*2P*("`@("=,5"<@/3X@
M7R@B3&ET:'5A;FEA(BDL"B`@("`G3%4G(#T^(%\H(DQU>&5M8F]U<F<B*2P*
M("`@("=-3R<@/3X@7R@B36%C86\B*2P*("`@("=-2R<@/3X@7R@B36%C961O
M;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(BDL"B`@("`G
M34<G(#T^(%\H(DUA9&%G87-C87(B*2P*("`@("=-5R<@/3X@7R@B36%L87=I
M(BDL"B`@("`G35DG(#T^(%\H(DUA;&%Y<VEA(BDL"B`@("`G358G(#T^(%\H
M(DUA;&1I=F5S(BDL"B`@("`G34PG(#T^(%\H(DUA;&DB*2P*("`@("=-5"<@
M/3X@7R@B36%L=&$B*2P*("`@("=-2"<@/3X@7R@B36%R<VAA;&P@27-L86YD
M<R(I+`H@("`@)TU1)R`]/B!?*")-87)T:6YI<75E(BDL"B`@("`G35(G(#T^
M(%\H(DUA=7)I=&%N:6$B*2P*("`@("=-52<@/3X@7R@B36%U<FET:75S(BDL
M"B`@("`G650G(#T^(%\H(DUA>6]T=&4B*2P*("`@("=-6"<@/3X@7R@B365X
M:6-O(BDL"B`@("`G1DTG(#T^(%\H(DUI8W)O;F5S:6$L($9E9&5R871E9"!3
M=&%T97,@;V8B*2P*("`@("=-1"<@/3X@7R@B36]L9&]V82P@4F5P=6)L:6,@
M;V8B*2P*("`@("=-0R<@/3X@7R@B36]N86-O(BDL"B`@("`G34XG(#T^(%\H
M(DUO;F=O;&EA(BDL"B`@("`G35,G(#T^(%\H(DUO;G1S97)R870B*2P*("`@
M("=-02<@/3X@7R@B36]R;V-C;R(I+`H@("`@)TU:)R`]/B!?*")-;WIA;6)I
M<75E(BDL"B`@("`G34TG(#T^(%\H(DUY86YM87(B*2P*("`@("=.02<@/3X@
M7R@B3F%M:6)I82(I+`H@("`@)TY2)R`]/B!?*").875R=2(I+`H@("`@)TY0
M)R`]/B!?*").97!A;"(I+`H@("`@)TY,)R`]/B!?*").971H97)L86YD<R(I
M+`H@("`@)T%.)R`]/B!?*").971H97)L86YD<R!!;G1I;&QE<R(I+`H@("`@
M)TY#)R`]/B!?*").97<@0V%L961O;FEA(BDL"B`@("`G3EHG(#T^(%\H(DYE
M=R!:96%L86YD(BDL"B`@("`G3DDG(#T^(%\H(DYI8V%R86=U82(I+`H@("`@
M)TY%)R`]/B!?*").:6=E<B(I+`H@("`@)TY')R`]/B!?*").:6=E<FEA(BDL
M"B`@("`G3E4G(#T^(%\H(DYI=64B*2P*("`@("=.1B<@/3X@7R@B3F]R9F]L
M:R!)<VQA;F0B*2P*("`@("=-4"<@/3X@7R@B3F]R=&AE<FX@36%R:6%N82!)
M<VQA;F1S(BDL"B`@("`G3D\G(#T^(%\H(DYO<G=A>2(I+`H@("`@)T]-)R`]
M/B!?*")/;6%N(BDL"B`@("`G4$LG(#T^(%\H(E!A:VES=&%N(BDL"B`@("`G
M4%<G(#T^(%\H(E!A;&%U(BDL"B`@("`G4%,G(#T^(%\H(E!A;&5S=&EN:6%N
M(%1E<G)I=&]R>2P@3V-C=7!I960B*2P*("`@("=002<@/3X@7R@B4&%N86UA
M(BDL"B`@("`G4$<G(#T^(%\H(E!A<'5A($YE=R!'=6EN96$B*2P*("`@("=0
M62<@/3X@7R@B4&%R86=U87DB*2P*("`@("=012<@/3X@7R@B4&5R=2(I+`H@
M("`@)U!()R`]/B!?*")0:&EL:7!P:6YE<R(I+`H@("`@)U!.)R`]/B!?*")0
M:71C86ER;B(I+`H@("`@)U!,)R`]/B!?*")0;VQA;F0B*2P*("`@("=05"<@
M/3X@7R@B4&]R='5G86PB*2P*("`@("=04B<@/3X@7R@B4'5E<G1O(%)I8V\B
M*2P*("`@("=102<@/3X@7R@B46%T87(B*2P*("`@("=212<@/3X@7R@B4F5U
M;FEO;B(I+`H@("`@)U)/)R`]/B!?*")2;VUA;FEA(BDL"B`@("`G4E4G(#T^
M(%\H(E)U<W-I86X@1F5D97)A=&EO;B(I+`H@("`@)U)7)R`]/B!?*")2=V%N
M9&$B*2P*("`@("=32"<@/3X@7R@B4V%I;G0@2&5L96YA(BDL"B`@("`G2TXG
M(#T^(%\H(E-A:6YT($MI='1S(&%N9"!.979I<R(I+`H@("`@)TQ#)R`]/B!?
M*")386EN="!,=6-I82(I+`H@("`@)U!-)R`]/B!?*")386EN="!0:65R<F4@
M86YD($UI<75E;&]N(BDL"B`@("`G5D,G(#T^(%\H(E-A:6YT(%9I;F-E;G0@
M86YD('1H92!'<F5N861I;F5S(BDL"B`@("`G5U,G(#T^(%\H(E-A;6]A(BDL
M"B`@("`G4TTG(#T^(%\H(E-A;B!-87)I;F\B*2P*("`@("=35"<@/3X@7R@B
M4V%O(%1O;64@86YD(%!R:6YC:7!E(BDL"B`@("`G4T$G(#T^(%\H(E-A=61I
M($%R86)I82(I+`H@("`@)U-.)R`]/B!?*")396YE9V%L(BDL"B`@("`G0U,G
M(#T^(%\H(E-E<F)I82!A;F0@36]N=&5N96=R;R(I+`H@("`@)U-#)R`]/B!?
M*")397EC:&5L;&5S(BDL"B`@("`G4TPG(#T^(%\H(E-I97)R82!,96]N92(I
M+`H@("`@)U-')R`]/B!?*")3:6YG87!O<F4B*2P*("`@("=32R<@/3X@7R@B
M4VQO=F%K:6$B*2P*("`@("=322<@/3X@7R@B4VQO=F5N:6$B*2P*("`@("=3
M0B<@/3X@7R@B4V]L;VUO;B!)<VQA;F1S(BDL"B`@("`G4T\G(#T^(%\H(E-O
M;6%L:6$B*2P*("`@("=:02<@/3X@7R@B4V]U=&@@069R:6-A(BDL"B`@("`G
M1U,G(#T^(%\H(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC
M:"!)<VQA;F1S(BDL"B`@("`G15,G(#T^(%\H(E-P86EN(BDL"B`@("`G3$LG
M(#T^(%\H(E-R:2!,86YK82(I+`H@("`@)U-$)R`]/B!?*")3=61A;B(I+`H@
M("`@)U-2)R`]/B!?*")3=7)I;F%M92(I+`H@("`@)U-*)R`]/B!?*")3=F%L
M8F%R9"!A;F0@2F%N($UA>65N(BDL"B`@("`G4UHG(#T^(%\H(E-W87II;&%N
M9"(I+`H@("`@)U-%)R`]/B!?*")3=V5D96XB*2P*("`@("=#2"<@/3X@7R@B
M4W=I='IE<FQA;F0B*2P*("`@("=362<@/3X@7R@B4WER:6%N($%R86(@4F5P
M=6)L:6,B*2P*("`@("=45R<@/3X@7R@B5&%I=V%N+"!0<F]V:6YC92!O9B!#
M:&EN82(I+`H@("`@)U1*)R`]/B!?*")486II:VES=&%N(BDL"B`@("`G5%HG
M(#T^(%\H(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B*2P*("`@("=4
M2"<@/3X@7R@B5&AA:6QA;F0B*2P*("`@("=43"<@/3X@7R@B5&EM;W(M3&5S
M=&4B*2P*("`@("=41R<@/3X@7R@B5&]G;R(I+`H@("`@)U1+)R`]/B!?*")4
M;VME;&%U(BDL"B`@("`G5$\G(#T^(%\H(E1O;F=A(BDL"B`@("`G5%0G(#T^
M(%\H(E1R:6YI9&%D(&%N9"!4;V)A9V\B*2P*("`@("=43B<@/3X@7R@B5'5N
M:7-I82(I+`H@("`@)U12)R`]/B!?*")4=7)K97DB*2P*("`@("=432<@/3X@
M7R@B5'5R:VUE;FES=&%N(BDL"B`@("`G5$,G(#T^(%\H(E1U<FMS(&%N9"!#
M86EC;W,@27-L86YD<R(I+`H@("`@)U16)R`]/B!?*")4=79A;'4B*2P*("`@
M("=51R<@/3X@7R@B56=A;F1A(BDL"B`@("`G54$G(#T^(%\H(E5K<F%I;F4B
M*2P*("`@("=!12<@/3X@7R@B56YI=&5D($%R86(@16UI<F%T97,B*2P*("`@
M("='0B<@/3X@7R@B56YI=&5D($MI;F=D;VTB*2P*("`@("=54R<@/3X@7R@B
M56YI=&5D(%-T871E<R(I+`H@("`@)U5-)R`]/B!?*")5;FET960@4W1A=&5S
M($UI;F]R($]U=&QY:6YG($ES;&%N9',B*2P*("`@("=562<@/3X@7R@B57)U
M9W5A>2(I+`H@("`@)U5:)R`]/B!?*")5>F)E:VES=&%N(BDL"B`@("`G5E4G
M(#T^(%\H(E9A;G5A='4B*2P*("`@("=612<@/3X@7R@B5F5N97IU96QA(BDL
M"B`@("`G5DXG(#T^(%\H(E9I970@3F%M(BDL"B`@("`G5D<G(#T^(%\H(E9I
M<F=I;B!)<VQA;F1S+"!"<FET:7-H(BDL"B`@("`G5DDG(#T^(%\H(E9I<F=I
M;B!)<VQA;F1S+"!5+E,N(BDL"B`@("`G5T8G(#T^(%\H(E=A;&QI<R!A;F0@
M1G5T=6YA(BDL"B`@("`G14@G(#T^(%\H(E=E<W1E<FX@4V%H87)A(BDL"B`@
M("`G644G(#T^(%\H(EEE;65N(BDL"B`@("`G6DTG(#T^(%\H(EIA;6)I82(I
M+`H@("`@)UI7)R`]/B!?*")::6UB86)W92(I*3L*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<```````````````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,Q-30S`#$P-3$U-#,S-S4P`#`R
M,38P,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@2&]R9&4@;W!T:6UI>F5D(&EN=&5R9F%C92!T;R!T
M:&4@36%X36EN9"!)4"!!9&1R97-S+3Y#;W5N=')Y"B`J(&QI<W1I;F<N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP+'8@,2XQ
M,"XQ,"XW(#(P,#8O,#8O,C<@,34Z,3DZ,3(@<VQU<V%R>B!%>'`@)`H@*@H@
M*B!"87-E9"!O;B!02%`@9V5O:7`N:6YC(&QI8G)A<GD@8GD@36%X36EN9"!,
M3$,Z"B`J("`@:'1T<#HO+W=W=RYM87AM:6YD+F-O;2]D;W=N;&]A9"]G96]I
M<"]A<&DO<&AP+PH@*@H@*B!/<FEG:6YA;&QY(&)A<V5D(&]N('!H<"!V97)S
M:6]N(&]F('1H92!G96]I<"!L:6)R87)Y('=R:71T96X@:6X@36%Y"B`J(#(P
M,#(@8GD@:FEM('=I;G-T96%D(#QJ:6UW0&%P86-H92YO<F<^"B`J"B`J($-O
M<'ER:6=H="`H0RD@,C`P,R!-87A-:6YD($Q,0PH@*B!#;W!Y<FEG:'0@,C`P
M,RTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R
M861O+F5D=3X*("H*("H@5&AI<R!L:6)R87)Y(&ES(&9R964@<V]F='=A<F4[
M('EO=2!C86X@<F5D:7-T<FEB=71E(&ET(&%N9"]O<@H@*B!M;V1I9GD@:70@
M=6YD97(@=&AE('1E<FUS(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@4'5B
M;&EC"B`J($QI8V5N<V4@87,@<'5B;&ES:&5D(&)Y('1H92!&<F5E(%-O9G1W
M87)E($9O=6YD871I;VX[(&5I=&AE<@H@*B!V97)S:6]N(#(N,2!O9B!T:&4@
M3&EC96YS92P@;W(@*&%T('EO=7(@;W!T:6]N*2!A;GD@;&%T97(@=F5R<VEO
M;BX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R
M>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@
M2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TY,4PH@*B\*"B\J($-O=6YT
M<GD@;&ES="X@*B\*)$=,3T)!3%-;)T=%3TE07T-/54Y44EE?0T]$15,G72`]
M(&%R<F%Y*`HG)RP@)T%0)RP@)T55)RP@)T%$)RP@)T%%)RP@)T%&)RP@)T%'
M)RP@)T%))RP@)T%,)RP@)T%-)RP@)T%.)RP@)T%/)RP@)T%1)RP*)T%2)RP@
M)T%3)RP@)T%4)RP@)T%5)RP@)T%7)RP@)T%:)RP@)T)!)RP@)T)")RP@)T)$
M)RP@)T)%)RP@)T)&)RP@)T)')RP@)T)()RP*)T)))RP@)T)*)RP@)T)-)RP@
M)T).)RP@)T)/)RP@)T)2)RP@)T)3)RP@)T)4)RP@)T)6)RP@)T)7)RP@)T)9
M)RP@)T):)RP@)T-!)RP*)T-#)RP@)T-$)RP@)T-&)RP@)T-')RP@)T-()RP@
M)T-))RP@)T-+)RP@)T-,)RP@)T--)RP@)T-.)RP@)T-/)RP@)T-2)RP@)T-5
M)RP*)T-6)RP@)T-8)RP@)T-9)RP@)T-:)RP@)T1%)RP@)T1*)RP@)T1+)RP@
M)T1-)RP@)T1/)RP@)T1:)RP@)T5#)RP@)T5%)RP@)T5')RP*)T5()RP@)T52
M)RP@)T53)RP@)T54)RP@)T9))RP@)T9*)RP@)T9+)RP@)T9-)RP@)T9/)RP@
M)T92)RP@)T98)RP@)T=!)RP@)U5+)RP*)T=$)RP@)T=%)RP@)T=&)RP@)T=(
M)RP@)T=))RP@)T=,)RP@)T=-)RP@)T=.)RP@)T=0)RP@)T=1)RP@)T=2)RP@
M)T=3)RP@)T=4)RP*)T=5)RP@)T=7)RP@)T=9)RP@)TA+)RP@)TA-)RP@)TA.
M)RP@)TA2)RP@)TA4)RP@)TA5)RP@)TE$)RP@)TE%)RP@)TE,)RP@)TE.)RP*
M)TE/)RP@)TE1)RP@)TE2)RP@)TE3)RP@)TE4)RP@)TI-)RP@)TI/)RP@)TI0
M)RP@)TM%)RP@)TM')RP@)TM()RP@)TM))RP@)TM-)RP*)TM.)RP@)TM0)RP@
M)TM2)RP@)TM7)RP@)TM9)RP@)TM:)RP@)TQ!)RP@)TQ")RP@)TQ#)RP@)TQ)
M)RP@)TQ+)RP@)TQ2)RP@)TQ3)RP*)TQ4)RP@)TQ5)RP@)TQ6)RP@)TQ9)RP@
M)TU!)RP@)TU#)RP@)TU$)RP@)TU')RP@)TU()RP@)TU+)RP@)TU,)RP@)TU-
M)RP@)TU.)RP*)TU/)RP@)TU0)RP@)TU1)RP@)TU2)RP@)TU3)RP@)TU4)RP@
M)TU5)RP@)TU6)RP@)TU7)RP@)TU8)RP@)TU9)RP@)TU:)RP@)TY!)RP*)TY#
M)RP@)TY%)RP@)TY&)RP@)TY')RP@)TY))RP@)TY,)RP@)TY/)RP@)TY0)RP@
M)TY2)RP@)TY5)RP@)TY:)RP@)T]-)RP@)U!!)RP*)U!%)RP@)U!&)RP@)U!'
M)RP@)U!()RP@)U!+)RP@)U!,)RP@)U!-)RP@)U!.)RP@)U!2)RP@)U!3)RP@
M)U!4)RP@)U!7)RP@)U!9)RP*)U%!)RP@)U)%)RP@)U)/)RP@)U)5)RP@)U)7
M)RP@)U-!)RP@)U-")RP@)U-#)RP@)U-$)RP@)U-%)RP@)U-')RP@)U-()RP@
M)U-))RP*)U-*)RP@)U-+)RP@)U-,)RP@)U--)RP@)U-.)RP@)U-/)RP@)U-2
M)RP@)U-4)RP@)U-6)RP@)U-9)RP@)U-:)RP@)U1#)RP@)U1$)RP*)U1&)RP@
M)U1')RP@)U1()RP@)U1*)RP@)U1+)RP@)U1-)RP@)U1.)RP@)U1/)RP@)U10
M)RP@)U12)RP@)U14)RP@)U16)RP@)U17)RP*)U1:)RP@)U5!)RP@)U5')RP@
M)U5-)RP@)U53)RP@)U59)RP@)U5:)RP@)U9!)RP@)U9#)RP@)U9%)RP@)U9'
M)RP@)U9))RP@)U9.)RP*)U95)RP@)U=&)RP@)U=3)RP@)UE%)RP@)UE4)RP@
M)UE5)RP@)UI!)RP@)UI-)RP@)UI2)RP@)UI7)RP@)T$Q)RP@)T$R)RP@)T\Q
M)PHI.PH*+RH@0V]U;G1R>2!.86UE<RX@*B\*)$=,3T)!3%-;)T=%3TE07T-/
M54Y44EE?3D%-15,G72`](&%R<F%Y*`HB(BP@7R@B07-I82]086-I9FEC(%)E
M9VEO;B(I+"!?*")%=7)O<&4B*2P@7R@B06YD;W)R82(I+`I?*")5;FET960@
M07)A8B!%;6ER871E<R(I+"!?*")!9F=H86YI<W1A;B(I+"!?*")!;G1I9W5A
M(&%N9"!"87)B=61A(BDL"E\H(D%N9W5I;&QA(BDL(%\H(D%L8F%N:6$B*2P@
M7R@B07)M96YI82(I+"!?*").971H97)L86YD<R!!;G1I;&QE<R(I+`I?*")!
M;F=O;&$B*2P@7R@B06YT87)C=&EC82(I+"!?*")!<F=E;G1I;F$B*2P@7R@B
M06UE<FEC86X@4V%M;V$B*2P*7R@B075S=')I82(I+"!?*")!=7-T<F%L:6$B
M*2P@7R@B07)U8F$B*2P@7R@B07IE<F)A:6IA;B(I+`I?*")";W-N:6$@86YD
M($AE<GIE9V]V:6YA(BDL(%\H(D)A<F)A9&]S(BDL(%\H(D)A;F=L861E<V@B
M*2P@7R@B0F5L9VEU;2(I+`I?*")"=7)K:6YA($9A<V\B*2P@7R@B0G5L9V%R
M:6$B*2P@7R@B0F%H<F%I;B(I+"!?*")"=7)U;F1I(BDL(%\H(D)E;FEN(BDL
M"E\H(D)E<FUU9&$B*2P@7R@B0G)U;F5I($1A<G5S<V%L86TB*2P@7R@B0F]L
M:79I82(I+"!?*")"<F%Z:6PB*2P@7R@B0F%H86UA<R(I+`I?*")":'5T86XB
M*2P@7R@B0F]U=F5T($ES;&%N9"(I+"!?*")";W1S=V%N82(I+"!?*")"96QA
M<G5S(BDL(%\H(D)E;&EZ92(I+`I?*")#86YA9&$B*2P@7R@B0V]C;W,@*$ME
M96QI;F<I($ES;&%N9',B*2P*7R@B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E
M<'5B;&EC(&]F('1H92(I+"!?*")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B
M*2P*7R@B0V]N9V\B*2P@7R@B4W=I='IE<FQA;F0B*2P@7R@B0V]T92!D)TEV
M;VER92(I+"!?*")#;V]K($ES;&%N9',B*2P*7R@B0VAI;&4B*2P@7R@B0V%M
M97)O;VXB*2P@7R@B0VAI;F$B*2P@7R@B0V]L;VUB:6$B*2P@7R@B0V]S=&$@
M4FEC82(I+`I?*")#=6)A(BDL(%\H(D-A<&4@5F5R9&4B*2P@7R@B0VAR:7-T
M;6%S($ES;&%N9"(I+"!?*")#>7!R=7,B*2P*7R@B0WIE8V@@4F5P=6)L:6,B
M*2P@7R@B1V5R;6%N>2(I+"!?*")$:FEB;W5T:2(I+"!?*")$96YM87)K(BDL
M(%\H(D1O;6EN:6-A(BDL"E\H(D1O;6EN:6-A;B!297!U8FQI8R(I+"!?*")!
M;&=E<FEA(BDL(%\H(D5C=6%D;W(B*2P@7R@B17-T;VYI82(I+"!?*")%9WEP
M="(I+`I?*")797-T97)N(%-A:&%R82(I+"!?*")%<FET<F5A(BDL(%\H(E-P
M86EN(BDL(%\H(D5T:&EO<&EA(BDL(%\H(D9I;FQA;F0B*2P*7R@B1FEJ:2(I
M+"!?*")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB*2P@7R@B36EC<F]N
M97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(I+`I?*")&87)O92!)<VQA;F1S
M(BDL(%\H(D9R86YC92(I+"!?*")&<F%N8V4L($UE=')O<&]L:71A;B(I+"!?
M*")'86)O;B(I+`I?*")5;FET960@2VEN9V1O;2(I+"!?*")'<F5N861A(BDL
M(%\H(D=E;W)G:6$B*2P@7R@B1G)E;F-H($=U:6%N82(I+`I?*")':&%N82(I
M+"!?*")':6)R86QT87(B*2P@7R@B1W)E96YL86YD(BDL(%\H(D=A;6)I82(I
M+"!?*")'=6EN96$B*2P*7R@B1W5A9&5L;W5P92(I+"!?*")%<75A=&]R:6%L
M($=U:6YE82(I+"!?*")'<F5E8V4B*2P*7R@B4V]U=&@@1V5O<F=I82!A;F0@
M=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B*2P@7R@B1W5A=&5M86QA(BDL
M(%\H(D=U86TB*2P*7R@B1W5I;F5A+4)I<W-A=2(I+"!?*")'=7EA;F$B*2P@
M7R@B2&]N9R!+;VYG(BDL"E\H(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@
M27-L86YD<R(I+"!?*")(;VYD=7)A<R(I+"!?*")#<F]A=&EA(BDL"E\H(DAA
M:71I(BDL(%\H(DAU;F=A<GDB*2P@7R@B26YD;VYE<VEA(BDL(%\H(DER96QA
M;F0B*2P@7R@B27-R865L(BDL"E\H(DEN9&EA(BDL(%\H(D)R:71I<V@@26YD
M:6%N($]C96%N(%1E<G)I=&]R>2(I+"!?*"))<F%Q(BDL"E\H(DER86XL($ES
M;&%M:6,@4F5P=6)L:6,@;V8B*2P@7R@B26-E;&%N9"(I+"!?*"))=&%L>2(I
M+"!?*")*86UA:6-A(BDL"E\H(DIO<F1A;B(I+"!?*")*87!A;B(I+"!?*")+
M96YY82(I+"!?*")+>7)G>7IS=&%N(BDL(%\H(D-A;6)O9&EA(BDL"E\H(DMI
M<FEB871I(BDL(%\H(D-O;6]R;W,B*2P@7R@B4V%I;G0@2VET=',@86YD($YE
M=FES(BDL"E\H(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC
M(&]F(BDL(%\H(DMO<F5A+"!297!U8FQI8R!O9B(I+`I?*")+=7=A:70B*2P@
M7R@B0V%Y;6%N($ES;&%N9',B*2P@7R@B2V%Z86MH<W1A;B(I+`I?*"),86\@
M4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(I+"!?*"),96)A;F]N(BDL
M(%\H(E-A:6YT($QU8VEA(BDL"E\H(DQI96-H=&5N<W1E:6XB*2P@7R@B4W)I
M($QA;FMA(BDL(%\H(DQI8F5R:6$B*2P@7R@B3&5S;W1H;R(I+`I?*"),:71H
M=6%N:6$B*2P@7R@B3'5X96UB;W5R9R(I+"!?*"),871V:6$B*2P@7R@B3&EB
M>6%N($%R86(@2F%M86AI<FEY82(I+`I?*")-;W)O8V-O(BDL(%\H(DUO;F%C
M;R(I+"!?*")-;VQD;W9A+"!297!U8FQI8R!O9B(I+"!?*")-861A9V%S8V%R
M(BDL"E\H(DUA<G-H86QL($ES;&%N9',B*2P@7R@B36%C961O;FEA+"!4:&4@
M1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(BDL"E\H(DUA;&DB*2P@7R@B
M37EA;FUA<B(I+"!?*")-;VYG;VQI82(I+"!?*")-86-A;R(I+`I?*").;W)T
M:&5R;B!-87)I86YA($ES;&%N9',B*2P@7R@B36%R=&EN:7%U92(I+"!?*")-
M875R:71A;FEA(BDL"E\H(DUO;G1S97)R870B*2P@7R@B36%L=&$B*2P@7R@B
M36%U<FET:75S(BDL(%\H(DUA;&1I=F5S(BDL(%\H(DUA;&%W:2(I+`I?*")-
M97AI8V\B*2P@7R@B36%L87ES:6$B*2P@7R@B36]Z86UB:7%U92(I+"!?*").
M86UI8FEA(BDL(%\H(DYE=R!#86QE9&]N:6$B*2P*7R@B3FEG97(B*2P@7R@B
M3F]R9F]L:R!)<VQA;F0B*2P@7R@B3FEG97)I82(I+"!?*").:6-A<F%G=6$B
M*2P*7R@B3F5T:&5R;&%N9',B*2P@7R@B3F]R=V%Y(BDL(%\H(DYE<&%L(BDL
M(%\H(DYA=7)U(BDL(%\H(DYI=64B*2P*7R@B3F5W(%IE86QA;F0B*2P@7R@B
M3VUA;B(I+"!?*")086YA;6$B*2P@7R@B4&5R=2(I+"!?*")&<F5N8V@@4&]L
M>6YE<VEA(BDL"E\H(E!A<'5A($YE=R!'=6EN96$B*2P@7R@B4&AI;&EP<&EN
M97,B*2P@7R@B4&%K:7-T86XB*2P@7R@B4&]L86YD(BDL"E\H(E-A:6YT(%!I
M97)R92!A;F0@36EQ=65L;VXB*2P@7R@B4&ET8V%I<FXB*2P@7R@B4'5E<G1O
M(%)I8V\B*2P*7R@B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(I
M+"!?*")0;W)T=6=A;"(I+"!?*")086QA=2(I+`I?*")087)A9W5A>2(I+"!?
M*")1871A<B(I+"!?*")2975N:6]N(BDL(%\H(E)O;6%N:6$B*2P*7R@B4G5S
M<VEA;B!&961E<F%T:6]N(BDL(%\H(E)W86YD82(I+"!?*")3875D:2!!<F%B
M:6$B*2P@7R@B4V]L;VUO;B!)<VQA;F1S(BDL"E\H(E-E>6-H96QL97,B*2P@
M7R@B4W5D86XB*2P@7R@B4W=E9&5N(BDL(%\H(E-I;F=A<&]R92(I+"!?*")3
M86EN="!(96QE;F$B*2P*7R@B4VQO=F5N:6$B*2P@7R@B4W9A;&)A<F0@86YD
M($IA;B!-87EE;B(I+"!?*")3;&]V86MI82(I+"!?*")3:65R<F$@3&5O;F4B
M*2P*7R@B4V%N($UA<FEN;R(I+"!?*")396YE9V%L(BDL(%\H(E-O;6%L:6$B
M*2P@7R@B4W5R:6YA;64B*2P*7R@B4V%O(%1O;64@86YD(%!R:6YC:7!E(BDL
M(%\H(D5L(%-A;'9A9&]R(BDL(%\H(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(BDL
M"E\H(E-W87II;&%N9"(I+"!?*")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B
M*2P@7R@B0VAA9"(I+`I?*")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B
M*2P@7R@B5&]G;R(I+"!?*")4:&%I;&%N9"(I+"!?*")486II:VES=&%N(BDL
M"E\H(E1O:V5L874B*2P@7R@B5'5R:VUE;FES=&%N(BDL(%\H(E1U;FES:6$B
M*2P@7R@B5&]N9V$B*2P@7R@B5&EM;W(M3&5S=&4B*2P*7R@B5'5R:V5Y(BDL
M(%\H(E1R:6YI9&%D(&%N9"!4;V)A9V\B*2P@7R@B5'5V86QU(BDL(%\H(E1A
M:7=A;B(I+`I?*")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(BDL(%\H
M(E5K<F%I;F4B*2P@7R@B56=A;F1A(BDL"E\H(E5N:71E9"!3=&%T97,@36EN
M;W(@3W5T;'EI;F<@27-L86YD<R(I+"!?*")5;FET960@4W1A=&5S(BDL(%\H
M(E5R=6=U87DB*2P*7R@B57IB96MI<W1A;B(I+"!?*")(;VQY(%-E92`H5F%T
M:6-A;B!#:71Y(%-T871E*2(I+`I?*")386EN="!6:6YC96YT(&%N9"!T:&4@
M1W)E;F%D:6YE<R(I+"!?*")696YE>G5E;&$B*2P*7R@B5FER9VEN($ES;&%N
M9',L($)R:71I<V@B*2P@7R@B5FER9VEN($ES;&%N9',L(%4N4RXB*2P@7R@B
M5FEE="!.86TB*2P*7R@B5F%N=6%T=2(I+"!?*")786QL:7,@86YD($9U='5N
M82(I+"!?*")386UO82(I+"!?*")996UE;B(I+"!?*")-87EO='1E(BDL"E\H
M(EEU9V]S;&%V:6$B*2P@7R@B4V]U=&@@069R:6-A(BDL(%\H(EIA;6)I82(I
M+"!?*"):86ER92(I+"!?*")::6UB86)W92(I+`I?*")!;F]N>6UO=7,@4')O
M>'DB*2P@7R@B4V%T96QL:71E(%!R;W9I9&5R(BDL(%\H(D]T:&5R(BD**3L*
M"F1E9FEN92@G1T5/25!?0T]53E1265]"14=)3B<L(#$V-S<V.38P*3L*9&5F
M:6YE*"=35%)50U154D5?24Y&3U]-05A?4TE:12<L(#(P*3L*9&5F:6YE*"=3
M5$%.1$%21%]214-/4D1?3$5.1U1()RP@,RD["@IC;&%S<R!.3%-?1V5O25`@
M>PH*("`@("\J*@H@("`@("H@5&AE(&QO8V%T:6]N(&]F('1H92!'96])4"!D
M871A8F%S92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]D871A9FEL93L*"B`@("`O*BH*("`@("`J(%1H92!O<&5N(&9I
M;&5H86YD;&4@=&\@=&AE($=E;TE0(&1A=&%B87-E+@H@("`@("H*("`@("`J
M($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1?9FEL96AA;F1L93L*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!R969E<F5N8V4@=&\@=&AE(&=L
M;V)A;"!.3%-?1V5O25`@;V)J96-T+"!O;FQY(&-R96%T:6YG(&ET"B`@("`@
M*B!I9B!I="!D;V5S;B=T(&%L<F5A9'D@97AI<W0N"B`@("`@*@H@("`@("H@
M5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.@H@("`@("H@("`D9V5O
M:7`@/2`F1V5O25`Z.G-I;F=L971O;B@D9&%T869I;&4I.PH@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&1A=&%F:6QE("!4:&4@;&]C871I;VX@;V8@
M=&AE($=E;TE0(&1A=&%B87-E+@H@("`@("H*("`@("`J($!R971U<FX@;V)J
M96-T($Y,4U]'96])4"`@5&AE($Y,4U]'96])4"!I;G-T86YC92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D9&%T869I;&4I"B`@("!["B`@
M("`@("`@<W1A=&EC("1I;G-T86YC93L*"B`@("`@("`@:68@*"%I<W-E="@D
M:6YS=&%N8V4I*2!["B`@("`@("`@("`@("1I;G-T86YC92`](&YE=R!.3%-?
M1V5O25`H)&1A=&%F:6QE*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M:6YS=&%N8V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@82!.3%-?
M1V5O25`@:6YS=&%N8V4@*$-O;G-T<G5C=&]R*2X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1D871A9FEL92`@5&AE(&QO8V%T:6]N(&]F('1H92!'
M96])4"!D871A8F%S92X*("`@("`J+PH@("`@9G5N8W1I;VX@3DQ37T=E;TE0
M*"1D871A9FEL92D*("`@('L*("`@("`@("`D=&AI<RT^7V1A=&%F:6QE(#T@
M)&1A=&%F:6QE.PH@("`@?0H*("`@("\J*@H@("`@("H@3W!E;B!T:&4@1V5O
M25`@9&%T86)A<V4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!&86QS92!O;B!E<G)O<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V]P96XH*0H@("`@>PH@("`@("`@("\J
M(%)E='5R;B!I9B!W92!A;')E861Y(&AA=F4@86X@;V)J96-T+B`J+PH@("`@
M("`@(&EF("@A96UP='DH)'1H:7,M/E]F:6QE:&%N9&QE*2D@>PH@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("\J(%)E='5R
M;B!I9B!N;R!D871A9FEL92!S<&5C:69I960N("HO"B`@("`@("`@:68@*&5M
M<'1Y*"1T:&ES+3Y?9&%T869I;&4I*2!["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?9FEL96AA;F1L92`]
M(&9O<&5N*"1T:&ES+3Y?9&%T869I;&4L("=R8B<I.PH*("`@("`@("`D9FEL
M97!O<R`](&9T96QL*"1T:&ES+3Y?9FEL96AA;F1L92D["B`@("`@("`@9G-E
M96LH)'1H:7,M/E]F:6QE:&%N9&QE+"`M,RP@4T5%2U]%3D0I.PH@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\(%-44E5#5%5215])3D9/7TU!6%]325I%.R`D
M:2LK*2!["B`@("`@("`@("`@("1D96QI;2`](&9R96%D*"1T:&ES+3Y?9FEL
M96AA;F1L92P@,RD["B`@("`@("`@("`@(&EF("@D9&5L:6T@/3T@*&-H<B@R
M-34I("X@8VAR*#(U-2D@+B!C:'(H,C4U*2DI('L*("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M9G-E96LH)'1H:7,M/E]F:6QE:&%N9&QE+"`M-"P@4T5%2U]#55(I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&9S965K*"1T:&ES+3Y?9FEL
M96AA;F1L92P@)&9I;&5P;W,L(%-%14M?4T54*3L*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C;W5N
M=')Y($E$(&9O<B!A(&AO<W1N86UE+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@(%1H92!H;W-T;F%M92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN=&5G97(@(%1H92!'96])4"!C;W5N=')Y($E$+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!C;W5N=')Y261">4YA;64H)&YA;64I"B`@("!["B`@("`@
M("`@:68@*"$D=&AI<RT^7V]P96XH*2D@>PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H@("`@("`@("1A9&1R(#T@9V5T:&]S=&)Y;F%M
M92@D;F%M92D["B`@("`@("`@:68@*"$D861D<B!\?"`H)&%D9'(@/3T@)&YA
M;64I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1T:&ES+3YC;W5N=')Y261">4%D9'(H)&%D9'(I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8V]U;G1R>2!A8F)R
M979I871I;VX@*#(M;&5T=&5R*2!F;W(@82!H;W-T;F%M92X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@:&]S=&YA;64N"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@8V]U;G1R>2!A8F)R979I
M871I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O=6YT<GE#;V1E0GE.86UE
M*"1N86UE*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V]P96XH*2D@>PH@
M("`@("`@("`@("`D8V]U;G1R>5]I9"`]("1T:&ES+3YC;W5N=')Y261">4YA
M;64H)&YA;64I.PH@("`@("`@("`@("!I9B`H)&-O=6YT<GE?:60@(3T](&9A
M;'-E*2!["B`@("`@("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;)T=%3TE0
M7T-/54Y44EE?0T]$15,G75LD8V]U;G1R>5]I9%T["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@8V]U;G1R>2!N86UE(&9O<B!A(&AO<W1N
M86UE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!H
M;W-T;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!C
M;W5N=')Y(&YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O=6YT<GE.86UE
M0GE.86UE*"1N86UE*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V]P96XH
M*2D@>PH@("`@("`@("`@("`D8V]U;G1R>5]I9"`]("1T:&ES+3YC;W5N=')Y
M261">4YA;64H)&YA;64I.PH@("`@("`@("`@("!I9B`H)&-O=6YT<GE?:60@
M(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;
M)T=%3TE07T-/54Y44EE?3D%-15,G75LD8V]U;G1R>5]I9%T["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8V]U;G1R>2!)1"!F;W(@86X@
M25`@061D<F5S<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A9&1R
M("!4:&4@25`@061D<F5S<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G
M97(@(%1H92!'96])4"!C;W5N=')Y($E$+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!C;W5N=')Y261">4%D9'(H)&%D9'(I"B`@("!["B`@("`@("`@:68@*"$D
M=&AI<RT^7V]P96XH*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H@("`@("`@("1I<&YU;2`](&EP,FQO;F<H)&%D9'(I.PH@("`@
M("`@(')E='5R;B`H)'1H:7,M/E]S965K0V]U;G1R>2@D:7!N=6TI("T@1T5/
M25!?0T]53E1265]"14=)3BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!C;W5N=')Y(&%B8G)E=FEA=&EO;B`H,BUL971T97(I(&9O<B!A
M;B!)4"!!9&1R97-S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%D
M9'(@(%1H92!)4"!!9&1R97-S+@H@("`@("H*("`@("`J($!R971U<FX@:6YT
M96=E<B`@5&AE(&-O=6YT<GD@86)B<F5V:6%T:6]N+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!C;W5N=')Y0V]D94)Y061D<B@D861D<BD*("`@('L*("`@("`@
M("!I9B`H)'1H:7,M/E]O<&5N*"DI('L*("`@("`@("`@("`@)&-O=6YT<GE?
M:60@/2`D=&AI<RT^8V]U;G1R>4ED0GE!9&1R*"1A9&1R*3L*("`@("`@("`@
M("`@:68@*"1C;W5N=')Y7VED("$]/2!F86QS92D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1'3$]"04Q36R='14])4%]#3U5.5%)97T-/1$53)UU;)&-O
M=6YT<GE?:61=.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E
M='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M(&-O=6YT<GD@;F%M92!F;W(@86X@25`@861D<F5S<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1A9&1R("!4:&4@25`@861D<F5S<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@8V]U;G1R>2!N86UE+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!C;W5N=')Y3F%M94)Y061D<B@D861D<BD*("`@
M('L*("`@("`@("!I9B`H)'1H:7,M/E]O<&5N*"DI('L*("`@("`@("`@("`@
M)&-O=6YT<GE?:60@/2`D=&AI<RT^8V]U;G1R>4ED0GE!9&1R*"1A9&1R*3L*
M("`@("`@("`@("`@:68@*"1C;W5N=')Y7VED("$]/2!F86QS92D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q36R='14])4%]#3U5.5%)97TY!
M3453)UU;)&-O=6YT<GE?:61=.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($9I
M;F1S(&$@8V]U;G1R>2!B>2!)4"!!9&1R97-S(&EN('1H92!'96])4"!D871A
M8F%S92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1I<&YU;2`@5&AE($E0($%D9')E<W,@=&\@
M<V5A<F-H(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@
M8V]U;G1R>2!)1"!O<B!F86QS92!I9B!N;W0@9F]U;F0N"B`@("`@*B`@("`@
M("`@("`@("`@("!2971U<FYS(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]S965K0V]U;G1R>2@D:7!N=6TI"B`@("!["B`@
M("`@("`@)&]F9G-E="`](#`["B`@("`@("`@9F]R("@D9&5P=&@@/2`S,3L@
M)&1E<'1H(#X](#`[("TM)&1E<'1H*2!["B`@("`@("`@("`@(&EF("AF<V5E
M:R@D=&AI<RT^7V9I;&5H86YD;&4L(#(@*B!35$%.1$%21%]214-/4D1?3$5.
M1U1(("H@)&]F9G-E="P@4T5%2U]3150I("$](#`I('L*("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=F<V5E:R!F86EL960G*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D8G5F(#T@9G)E860H)'1H:7,M
M/E]F:6QE:&%N9&QE+"`R("H@4U1!3D1!4D1?4D5#3U)$7TQ%3D=42"D["B`@
M("`@("`@("`@("1X(#T@87)R87DH,"P@,"D["B`@("`@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\(#([("LK)&DI('L*("`@("`@("`@("`@("`@(&9O<B`H
M)&H@/2`P.R`D:B`\(%-404Y$05)$7U)%0T]21%],14Y'5$@[("LK)&HI('L*
M("`@("`@("`@("`@("`@("`@("`D>%LD:5T@*ST@;W)D*"1B=69;4U1!3D1!
M4D1?4D5#3U)$7TQ%3D=42"`J("1I("L@)&I=*2`\/"`H)&H@*B`X*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M)&EP;G5M("8@*#$@/#P@)&1E<'1H*2D@>PH@("`@("`@("`@("`@("`@:68@
M*"1X6S%=(#X]($=%3TE07T-/54Y44EE?0D5'24XI('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)'A;,5T["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D;V9F<V5T(#T@)'A;,5T["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!I9B`H)'A;,%T@/CT@1T5/25!?0T]53E12
M65]"14=)3BD@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D>%LP73L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1O9F9S970@/2`D
M>%LP73L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O3DQ3+W1L9"YP:'``````
M````````````````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$V-S(U`#$P-3$U
M-#,S-S4P`#`R,30R-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@5&]P(&QE=F5L(&1O;6%I;B`H5$Q$
M*2!L:7-T(&9O<B!C;W5N=')Y(&-O9&5S+@H@*B!'96YE<F%T960@9G)O;2!)
M04Y!("A);G1E<FYE="!!<W-I9VYE9"!.=6UB97)S($%U=&AO<FET>2D@9&%T
M82!L;V-A=&5D"B`J(&%T(&AT='`Z+R]W=W<N:6%N82YO<F<O8V-T;&0O8V-T
M;&0M=VAO:7,N:'1M"B`J"B`J($9O<FUA=#H*("H@("`D=&QD6R=C;W5N=')Y
M8V]D92==(#T@)V-O=6YT<GEN86UE)SL*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP+'8@,2XU(#(P,#0O,#$O,#0@,#(Z,C0Z,#4@
M;61J=6MI8R!%>'`@)`H@*@H@*B!`<&%C:V%G92!(;W)D95].3%,*("HO"B1T
M;&0@/2!A<G)A>2@*("`@("=A8R<@/3X@7R@B07-C96YS:6]N($ES;&%N9"(I
M+`H@("`@)V%D)R`]/B!?*")!;F1O<G)A(BDL"B`@("`G864G(#T^(%\H(E5N
M:71E9"!!<F%B($5M:7)A=&5S(BDL"B`@("`G868G(#T^(%\H(D%F9VAA;FES
M=&%N(BDL"B`@("`G86<G(#T^(%\H(D%N=&EG=6$@86YD($)A<F)U9&$B*2P*
M("`@("=A:2<@/3X@7R@B06YG=6EL;&$B*2P*("`@("=A;"<@/3X@7R@B06QB
M86YI82(I+`H@("`@)V%M)R`]/B!?*")!<FUE;FEA(BDL"B`@("`G86XG(#T^
M(%\H(DYE=&AE<FQA;F1S($%N=&EL;&5S(BDL"B`@("`G86\G(#T^(%\H(D%N
M9V]L82(I+`H@("`@)V%Q)R`]/B!?*")!;G1A<F-T:6-A(BDL"B`@("`G87(G
M(#T^(%\H(D%R9V5N=&EN82(I+`H@("`@)V%S)R`]/B!?*")!;65R:6-A;B!3
M86UO82(I+`H@("`@)V%T)R`]/B!?*")!=7-T<FEA(BDL"B`@("`G874G(#T^
M(%\H(D%U<W1R86QI82(I+`H@("`@)V%W)R`]/B!?*")!<G5B82(I+`H@("`@
M)V%Z)R`]/B!?*")!>F5R8F%I:F%N(BDL"B`@("`G8F$G(#T^(%\H(D)O<VYI
M82!A;F0@2&5R>F5G;W9I;F$B*2P*("`@("=B8B<@/3X@7R@B0F%R8F%D;W,B
M*2P*("`@("=B9"<@/3X@7R@B0F%N9VQA9&5S:"(I+`H@("`@)V)E)R`]/B!?
M*")"96QG:75M(BDL"B`@("`G8F8G(#T^(%\H(D)U<FMI;F$@1F%S;R(I+`H@
M("`@)V)G)R`]/B!?*")"=6QG87)I82(I+`H@("`@)V)H)R`]/B!?*")"86AR
M86EN(BDL"B`@("`G8FDG(#T^(%\H(D)U<G5N9&DB*2P*("`@("=B:B<@/3X@
M7R@B0F5N:6XB*2P*("`@("=B;2<@/3X@7R@B0F5R;75D82(I+`H@("`@)V)N
M)R`]/B!?*")"<G5N96D@1&%R=7-S86QA;2(I+`H@("`@)V)O)R`]/B!?*")"
M;VQI=FEA(BDL"B`@("`G8G(G(#T^(%\H(D)R87II;"(I+`H@("`@)V)S)R`]
M/B!?*")"86AA;6%S(BDL"B`@("`G8G0G(#T^(%\H(D)H=71A;B(I+`H@("`@
M)V)V)R`]/B!?*")";W5V970@27-L86YD(BDL"B`@("`G8G<G(#T^(%\H(D)O
M='-W86YA(BDL"B`@("`G8GDG(#T^(%\H(D)E;&%R=7,B*2P*("`@("=B>B<@
M/3X@7R@B0F5L:7IE(BDL"B`@("`G8V$G(#T^(%\H(D-A;F%D82(I+`H@("`@
M)V-C)R`]/B!?*")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(I+`H@("`@)V-D
M)R`]/B!?*")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE
M(BDL"B`@("`G8V8G(#T^(%\H(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(I
M+`H@("`@)V-G)R`]/B!?*")#;VYG;R(I+`H@("`@)V-H)R`]/B!?*")3=VET
M>F5R;&%N9"(I+`H@("`@)V-I)R`]/B!?*")#;W1E(&0G279O:7)E(BDL"B`@
M("`G8VLG(#T^(%\H(D-O;VL@27-L86YD<R(I+`H@("`@)V-L)R`]/B!?*")#
M:&EL92(I+`H@("`@)V-M)R`]/B!?*")#86UE<F]O;B(I+`H@("`@)V-N)R`]
M/B!?*")#:&EN82(I+`H@("`@)V-O)R`]/B!?*")#;VQO;6)I82(I+`H@("`@
M)V-R)R`]/B!?*")#;W-T82!2:6-A(BDL"B`@("`G8W4G(#T^(%\H(D-U8F$B
M*2P*("`@("=C=B<@/3X@7R@B0V%P92!697)D92(I+`H@("`@)V-X)R`]/B!?
M*")#:')I<W1M87,@27-L86YD(BDL"B`@("`G8WDG(#T^(%\H(D-Y<')U<R(I
M+`H@("`@)V-Z)R`]/B!?*")#>F5C:"!297!U8FQI8R(I+`H@("`@)V1E)R`]
M/B!?*")'97)M86YY(BDL"B`@("`G9&HG(#T^(%\H(D1J:6)O=71I(BDL"B`@
M("`G9&LG(#T^(%\H(D1E;FUA<FLB*2P*("`@("=D;2<@/3X@7R@B1&]M:6YI
M8V$B*2P*("`@("=D;R<@/3X@7R@B1&]M:6YI8V%N(%)E<'5B;&EC(BDL"B`@
M("`G9'HG(#T^(%\H(D%L9V5R:6$B*2P*("`@("=E8R<@/3X@7R@B16-U861O
M<B(I+`H@("`@)V5E)R`]/B!?*")%<W1O;FEA(BDL"B`@("`G96<G(#T^(%\H
M(D5G>7!T(BDL"B`@("`G96@G(#T^(%\H(E=E<W1E<FX@4V%H87)A(BDL"B`@
M("`G97(G(#T^(%\H(D5R:71R96$B*2P*("`@("=E<R<@/3X@7R@B4W!A:6XB
M*2P*("`@("=E="<@/3X@7R@B171H:6]P:6$B*2P*("`@("=F:2<@/3X@7R@B
M1FEN;&%N9"(I+`H@("`@)V9J)R`]/B!?*")&:6II(BDL"B`@("`G9FLG(#T^
M(%\H(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(I+`H@("`@)V9M)R`]
M/B!?*")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F(BDL"B`@("`G
M9F\G(#T^(%\H(D9A<F]E($ES;&%N9',B*2P*("`@("=F<B<@/3X@7R@B1G)A
M;F-E(BDL"B`@("`G9V$G(#T^(%\H(D=A8F]N(BDL"B`@("`G9V0G(#T^(%\H
M(D=R96YA9&$B*2P*("`@("=G92<@/3X@7R@B1V5O<F=I82(I+`H@("`@)V=F
M)R`]/B!?*")&<F5N8V@@1W5I86YA(BDL"B`@("`G9V<G(#T^(%\H(D=U97)N
M<V5Y(BDL"B`@("`G9V@G(#T^(%\H(D=H86YA(BDL"B`@("`G9VDG(#T^(%\H
M(D=I8G)A;'1A<B(I+`H@("`@)V=L)R`]/B!?*")'<F5E;FQA;F0B*2P*("`@
M("=G;2<@/3X@7R@B1V%M8FEA(BDL"B`@("`G9VXG(#T^(%\H(D=U:6YE82(I
M+`H@("`@)V=P)R`]/B!?*")'=6%D96QO=7!E(BDL"B`@("`G9W$G(#T^(%\H
M(D5Q=6%T;W)I86P@1W5I;F5A(BDL"B`@("`G9W(G(#T^(%\H(D=R965C92(I
M+`H@("`@)V=S)R`]/B!?*")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@
M4V%N9'=I8V@@27-L86YD<R(I+`H@("`@)V=T)R`]/B!?*")'=6%T96UA;&$B
M*2P*("`@("=G=2<@/3X@7R@B1W5A;2(I+`H@("`@)V=W)R`]/B!?*")'=6EN
M96$M0FES<V%U(BDL"B`@("`G9WDG(#T^(%\H(D=U>6%N82(I+`H@("`@)VAK
M)R`]/B!?*")(;VYG($MO;F<B*2P*("`@("=H;2<@/3X@7R@B2&5A<F0@27-L
M86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(BDL"B`@("`G:&XG(#T^(%\H(DAO
M;F1U<F%S(BDL"B`@("`G:'(G(#T^(%\H(D-R;V%T:6$B*2P*("`@("=H="<@
M/3X@7R@B2&%I=&DB*2P*("`@("=H=2<@/3X@7R@B2'5N9V%R>2(I+`H@("`@
M)VED)R`]/B!?*"));F1O;F5S:6$B*2P*("`@("=I92<@/3X@7R@B27)E;&%N
M9"(I+`H@("`@)VEL)R`]/B!?*"))<W)A96PB*2P*("`@("=I;2<@/3X@7R@B
M27-L92!O9B!-86XB*2P*("`@("=I;B<@/3X@7R@B26YD:6$B*2P*("`@("=I
M;R<@/3X@7R@B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(BDL"B`@
M("`G:7$G(#T^(%\H(DER87$B*2P*("`@("=I<B<@/3X@7R@B27)A;BP@27-L
M86UI8R!297!U8FQI8R!O9B(I+`H@("`@)VES)R`]/B!?*"))8V5L86YD(BDL
M"B`@("`G:70G(#T^(%\H(DET86QY(BDL"B`@("`G:F4G(#T^(%\H(DIE<G-E
M>2(I+`H@("`@)VIM)R`]/B!?*")*86UA:6-A(BDL"B`@("`G:F\G(#T^(%\H
M(DIO<F1A;B(I+`H@("`@)VIP)R`]/B!?*")*87!A;B(I+`H@("`@)VME)R`]
M/B!?*")+96YY82(I+`H@("`@)VMG)R`]/B!?*")+>7)G>7IS=&%N(BDL"B`@
M("`G:V@G(#T^(%\H(D-A;6)O9&EA(BDL"B`@("`G:VDG(#T^(%\H(DMI<FEB
M871I(BDL"B`@("`G:VTG(#T^(%\H(D-O;6]R;W,B*2P*("`@("=K;B<@/3X@
M7R@B4V%I;G0@2VET=',@86YD($YE=FES(BDL"B`@("`G:W`G(#T^(%\H(DMO
M<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(BDL"B`@("`G
M:W(G(#T^(%\H(DMO<F5A+"!297!U8FQI8R!O9B(I+`H@("`@)VMW)R`]/B!?
M*")+=7=A:70B*2P*("`@("=K>2<@/3X@7R@B0V%Y;6%N($ES;&%N9',B*2P*
M("`@("=K>B<@/3X@7R@B2V%Z86MH<W1A;B(I+`H@("`@)VQA)R`]/B!?*"),
M86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(I+`H@("`@)VQB)R`]
M/B!?*"),96)A;F]N(BDL"B`@("`G;&,G(#T^(%\H(E-A:6YT($QU8VEA(BDL
M"B`@("`G;&DG(#T^(%\H(DQI96-H=&5N<W1E:6XB*2P*("`@("=L:R<@/3X@
M7R@B4W)I($QA;FMA(BDL"B`@("`G;'(G(#T^(%\H(DQI8F5R:6$B*2P*("`@
M("=L<R<@/3X@7R@B3&5S;W1H;R(I+`H@("`@)VQT)R`]/B!?*"),:71H=6%N
M:6$B*2P*("`@("=L=2<@/3X@7R@B3'5X96UB;W5R9R(I+`H@("`@)VQV)R`]
M/B!?*"),871V:6$B*2P*("`@("=L>2<@/3X@7R@B3&EB>6%N($%R86(@2F%M
M86AI<FEY82(I+`H@("`@)VUA)R`]/B!?*")-;W)O8V-O(BDL"B`@("`G;6,G
M(#T^(%\H(DUO;F%C;R(I+`H@("`@)VUD)R`]/B!?*")-;VQD;W9A+"!297!U
M8FQI8R!O9B(I+`H@("`@)VUG)R`]/B!?*")-861A9V%S8V%R(BDL"B`@("`G
M;6@G(#T^(%\H(DUA<G-H86QL($ES;&%N9',B*2P*("`@("=M:R<@/3X@7R@B
M36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(BDL
M"B`@("`G;6PG(#T^(%\H(DUA;&DB*2P*("`@("=M;2<@/3X@7R@B37EA;FUA
M<B(I+`H@("`@)VUN)R`]/B!?*")-;VYG;VQI82(I+`H@("`@)VUO)R`]/B!?
M*")-86-A;R(I+`H@("`@)VUP)R`]/B!?*").;W)T:&5R;B!-87)I86YA($ES
M;&%N9',B*2P*("`@("=M<2<@/3X@7R@B36%R=&EN:7%U92(I+`H@("`@)VUR
M)R`]/B!?*")-875R:71A;FEA(BDL"B`@("`G;7,G(#T^(%\H(DUO;G1S97)R
M870B*2P*("`@("=M="<@/3X@7R@B36%L=&$B*2P*("`@("=M=2<@/3X@7R@B
M36%U<FET:75S(BDL"B`@("`G;78G(#T^(%\H(DUA;&1I=F5S(BDL"B`@("`G
M;7<G(#T^(%\H(DUA;&%W:2(I+`H@("`@)VUX)R`]/B!?*")-97AI8V\B*2P*
M("`@("=M>2<@/3X@7R@B36%L87ES:6$B*2P*("`@("=M>B<@/3X@7R@B36]Z
M86UB:7%U92(I+`H@("`@)VYA)R`]/B!?*").86UI8FEA(BDL"B`@("`G;F,G
M(#T^(%\H(DYE=R!#86QE9&]N:6$B*2P*("`@("=N92<@/3X@7R@B3FEG97(B
M*2P*("`@("=N9B<@/3X@7R@B3F]R9F]L:R!)<VQA;F0B*2P*("`@("=N9R<@
M/3X@7R@B3FEG97)I82(I+`H@("`@)VYI)R`]/B!?*").:6-A<F%G=6$B*2P*
M("`@("=N;"<@/3X@7R@B3F5T:&5R;&%N9',B*2P*("`@("=N;R<@/3X@7R@B
M3F]R=V%Y(BDL"B`@("`G;G`G(#T^(%\H(DYE<&%L(BDL"B`@("`G;G(G(#T^
M(%\H(DYA=7)U(BDL"B`@("`G;G4G(#T^(%\H(DYI=64B*2P*("`@("=N>B<@
M/3X@7R@B3F5W(%IE86QA;F0B*2P*("`@("=O;2<@/3X@7R@B3VUA;B(I+`H@
M("`@)W!A)R`]/B!?*")086YA;6$B*2P*("`@("=P92<@/3X@7R@B4&5R=2(I
M+`H@("`@)W!F)R`]/B!?*")&<F5N8V@@4&]L>6YE<VEA(BDL"B`@("`G<&<G
M(#T^(%\H(E!A<'5A($YE=R!'=6EN96$B*2P*("`@("=P:"<@/3X@7R@B4&AI
M;&EP<&EN97,B*2P*("`@("=P:R<@/3X@7R@B4&%K:7-T86XB*2P*("`@("=P
M;"<@/3X@7R@B4&]L86YD(BDL"B`@("`G<&TG(#T^(%\H(E-A:6YT(%!I97)R
M92!A;F0@36EQ=65L;VXB*2P*("`@("=P;B<@/3X@7R@B4&ET8V%I<FXB*2P*
M("`@("=P<B<@/3X@7R@B4'5E<G1O(%)I8V\B*2P*("`@("=P<R<@/3X@7R@B
M4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(I+`H@("`@)W!T)R`]
M/B!?*")0;W)T=6=A;"(I+`H@("`@)W!W)R`]/B!?*")086QA=2(I+`H@("`@
M)W!Y)R`]/B!?*")087)A9W5A>2(I+`H@("`@)W%A)R`]/B!?*")1871A<B(I
M+`H@("`@)W)E)R`]/B!?*")2975N:6]N(BDL"B`@("`G<F\G(#T^(%\H(E)O
M;6%N:6$B*2P*("`@("=R=2<@/3X@7R@B4G5S<VEA;B!&961E<F%T:6]N(BDL
M"B`@("`G<G<G(#T^(%\H(E)W86YD82(I+`H@("`@)W-A)R`]/B!?*")3875D
M:2!!<F%B:6$B*2P*("`@("=S8B<@/3X@7R@B4V]L;VUO;B!)<VQA;F1S(BDL
M"B`@("`G<V,G(#T^(%\H(E-E>6-H96QL97,B*2P*("`@("=S9"<@/3X@7R@B
M4W5D86XB*2P*("`@("=S92<@/3X@7R@B4W=E9&5N(BDL"B`@("`G<V<G(#T^
M(%\H(E-I;F=A<&]R92(I+`H@("`@)W-H)R`]/B!?*")386EN="!(96QE;F$B
M*2P*("`@("=S:2<@/3X@7R@B4VQO=F5N:6$B*2P*("`@("=S:B<@/3X@7R@B
M4W9A;&)A<F0@86YD($IA;B!-87EE;B(I+`H@("`@)W-K)R`]/B!?*")3;&]V
M86MI82(I+`H@("`@)W-L)R`]/B!?*")3:65R<F$@3&5O;F4B*2P*("`@("=S
M;2<@/3X@7R@B4V%N($UA<FEN;R(I+`H@("`@)W-N)R`]/B!?*")396YE9V%L
M(BDL"B`@("`G<V\G(#T^(%\H(E-O;6%L:6$B*2P*("`@("=S<B<@/3X@7R@B
M4W5R:6YA;64B*2P*("`@("=S="<@/3X@7R@B4V%O(%1O;64@86YD(%!R:6YC
M:7!E(BDL"B`@("`G<W8G(#T^(%\H(D5L(%-A;'9A9&]R(BDL"B`@("`G<WDG
M(#T^(%\H(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(BDL"B`@("`G<WHG(#T^(%\H
M(E-W87II;&%N9"(I+`H@("`@)W1C)R`]/B!?*")4=7)K<R!A;F0@0V%I8V]S
M($ES;&%N9',B*2P*("`@("=T9"<@/3X@7R@B0VAA9"(I+`H@("`@)W1F)R`]
M/B!?*")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B*2P*("`@("=T9R<@
M/3X@7R@B5&]G;R(I+`H@("`@)W1H)R`]/B!?*")4:&%I;&%N9"(I+`H@("`@
M)W1J)R`]/B!?*")486II:VES=&%N(BDL"B`@("`G=&LG(#T^(%\H(E1O:V5L
M874B*2P*("`@("=T;2<@/3X@7R@B5'5R:VUE;FES=&%N(BDL"B`@("`G=&XG
M(#T^(%\H(E1U;FES:6$B*2P*("`@("=T;R<@/3X@7R@B5&]N9V$B*2P*("`@
M("=T<"<@/3X@7R@B5&EM;W(M3&5S=&4B*2P*("`@("=T<B<@/3X@7R@B5'5R
M:V5Y(BDL"B`@("`G='0G(#T^(%\H(E1R:6YI9&%D(&%N9"!4;V)A9V\B*2P*
M("`@("=T=B<@/3X@7R@B5'5V86QU(BDL"B`@("`G='<G(#T^(%\H(E1A:7=A
M;B(I+`H@("`@)W1Z)R`]/B!?*")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC
M(&]F(BDL"B`@("`G=6$G(#T^(%\H(E5K<F%I;F4B*2P*("`@("=U9R<@/3X@
M7R@B56=A;F1A(BDL"B`@("`G=6LG(#T^(%\H(E5N:71E9"!+:6YG9&]M(BDL
M"B`@("`G=6TG(#T^(%\H(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@
M27-L86YD<R(I+`H@("`@)W5S)R`]/B!?*")5;FET960@4W1A=&5S(BDL"B`@
M("`G=7DG(#T^(%\H(E5R=6=U87DB*2P*("`@("=U>B<@/3X@7R@B57IB96MI
M<W1A;B(I+`H@("`@)W9A)R`]/B!?*")(;VQY(%-E92`H5F%T:6-A;B!#:71Y
M(%-T871E*2(I+`H@("`@)W9C)R`]/B!?*")386EN="!6:6YC96YT(&%N9"!T
M:&4@1W)E;F%D:6YE<R(I+`H@("`@)W9E)R`]/B!?*")696YE>G5E;&$B*2P*
M("`@("=V9R<@/3X@7R@B5FER9VEN($ES;&%N9',L($)R:71I<V@B*2P*("`@
M("=V:2<@/3X@7R@B5FER9VEN($ES;&%N9',L(%4N4RXB*2P*("`@("=V;B<@
M/3X@7R@B5FEE="!.86TB*2P*("`@("=V=2<@/3X@7R@B5F%N=6%T=2(I+`H@
M("`@)W=F)R`]/B!?*")786QL:7,@86YD($9U='5N82(I+`H@("`@)W=S)R`]
M/B!?*")386UO82(I+`H@("`@)WEE)R`]/B!?*")996UE;B(I+`H@("`@)WET
M)R`]/B!?*")-87EO='1E(BDL"B`@("`G>74G(#T^(%\H(EEU9V]S;&%V:6$B
M*2P*("`@("=Z82<@/3X@7R@B4V]U=&@@069R:6-A(BDL"B`@("`G>FTG(#T^
M(%\H(EIA;6)I82(I+`H@("`@)WIW)R`]/B!?*")::6UB86)W92(I"BD["@``
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92].3%,N<&AP````````
M````````````````````````````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#`S-C0`,3`U
M,34T,S,W-3(`,#(P-C0P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B!4:&4@3DQ3.CH@8VQA<W,@<')O
M=FED97,@3F%T:79E($QA;F=U86=E(%-U<'!O<G0N(%1H:7,@:6YC;'5D97,@
M8V]M;6]N"B`J(&UE=&AO9',@9F]R(&AA;F1L:6YG(&QA;F=U86=E(&1E=&5C
M=&EO;B!A;F0@<V5L96-T:6]N+"!T:6UE>F]N97,L(&%N9`H@*B!H;W-T;F%M
M92T^8V]U;G1R>2!L;V]K=7!S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].
M3%,O3DQ3+G!H<"QV(#$N.#(N-"XQ,R`R,#`V+S`Q+S(T(#`W.C4P.C(V('-E
M;'-K>2!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!087)I
M<V4@/&IO;D!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU
M8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R
M,#`R+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0V]P
M>7)I9VAT(#(P,#,M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG
M=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!`875T:&]R("!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@2F%N
M(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@36EC:&%E
M;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`
M<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?3DQ3"B`J+PIC
M;&%S<R!.3%,@>PH*("`@("\J*@H@("`@("H@4V5L96-T<R!T:&4@;6]S="!P
M<F5F97)R960@;&%N9W5A9V4@9F]R('1H92!C=7)R96YT(&-L:65N="!S97-S
M:6]N+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<V5L96-T
M960@;&%N9W5A9V4@86)B<F5V:6%T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S96QE8W0H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D;FQS+"`D<')E9G,[
M"@H@("`@("`@("1L86YG(#T@571I;#HZ9V5T1F]R;41A=&$H)VYE=U]L86YG
M)RD["@H@("`@("`@("\J($9I<G-T+"!C:&5C:R!I9B!L86YG=6%G92!P<F5F
M(&ES(&QO8VME9"!A;F0L(&EF('-O+"!S970@:70@=&\@:71S"B`@("`@("`@
M("`@=F%L=64@*B\*("`@("`@("!I9B`H:7-S970H)'!R969S*2`F)B`D<')E
M9G,M/FES3&]C:V5D*"=L86YG=6%G92<I*2!["B`@("`@("`@("`@("1L86YG
M=6%G92`]("1P<F5F<RT^9V5T5F%L=64H)VQA;F=U86=E)RD["B`@("`@("`@
M+RH@0VAE8VL@:68@=&AE('5S97(@<V5L96-T960@82!L86YG=6%G92!F<F]M
M('1H92!L;V=I;B!S8W)E96X@*B\*("`@("`@("!](&5L<V5I9B`H(65M<'1Y
M*"1L86YG*2D@>PH@("`@("`@("`@("`D;&%N9W5A9V4@/2`D;&%N9SL*("`@
M("`@("`O*B!#:&5C:R!I9B!W92!H879E(&$@;&%N9W5A9V4@<V5T(&EN(&$@
M8V]O:VEE("HO"B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1?4T534TE/3ELG
M:&]R9&5?;&%N9W5A9V4G72DI('L*("`@("`@("`@("`@)&QA;F=U86=E(#T@
M)%]315-324].6R=H;W)D95]L86YG=6%G92==.PH@("`@("`@("\J(%5S92!S
M:71E+7=I9&4@9&5F875L="P@:68@;VYE(&ES(&1E9FEN960@*B\*("`@("`@
M("!](&5L<V5I9B`H(65M<'1Y*"1N;'-;)V1E9F%U;'1S)UU;)VQA;F=U86=E
M)UTI*2!["B`@("`@("`@("`@("1L86YG=6%G92`]("1N;'-;)V1E9F%U;'1S
M)UU;)VQA;F=U86=E)UT["B`@("`@("`@+RH@5')Y(&)R;W=S97(M86-C97!T
M960@;&%N9W5A9V5S+B`J+PH@("`@("`@('T@96QS96EF("@A96UP='DH)%]3
M15)615);)TA45%!?04-#15!47TQ!3D=504=%)UTI*2!["B`@("`@("`@("`@
M("\J(%1H92!B<F]W<V5R('-U<'!L:65S(&$@;&ES="P@<V\@<F5T=7)N('1H
M92!F:7)S="!V86QI9"!O;F4N("HO"B`@("`@("`@("`@("1B<F]W<V5R7VQA
M;F=S(#T@97AP;&]D92@G+"<L("1?4T525D526R=(5%107T%#0T505%],04Y'
M54%'12==*3L*("`@("`@("`@("`@9F]R96%C:"`H)&)R;W=S97)?;&%N9W,@
M87,@)&QA;F<I('L*("`@("`@("`@("`@("`@("\J(%-T<FEP('%U86QI='D@
M=F%L=64@9F]R(&QA;F=U86=E("HO"B`@("`@("`@("`@("`@("!I9B`H*"1P
M;W,@/2!S=')P;W,H)&QA;F<L("<[)RDI("$]/2!F86QS92D@>PH@("`@("`@
M("`@("`@("`@("`@("1L86YG(#T@<W5B<W1R*"1L86YG+"`P+"`D<&]S*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1L86YG(#T@3DQ3
M.CI?;6%P*'1R:6TH)&QA;F<I*3L*("`@("`@("`@("`@("`@(&EF("A.3%,Z
M.FES5F%L:60H)&QA;F<I*2!["B`@("`@("`@("`@("`@("`@("`@)&QA;F=U
M86=E(#T@)&QA;F<["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`O*B!);B!C87-E(&YO(&9U
M;&P@;6%T8V@L('-A=F4@8F5S="!G=65S<R!B87-E9"!O;B!P<F5F:7@@*B\*
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'!A<G1I86Q?;&%N9RD@)B8*
M("`@("`@("`@("`@("`@("`@("!.3%,Z.FES5F%L:60H3DQ3.CI?;6%P*'-U
M8G-T<B@D;&%N9RP@,"P@,BDI*2D@>PH@("`@("`@("`@("`@("`@("`@("1P
M87)T:6%L7VQA;F<@/2!.3%,Z.E]M87`H<W5B<W1R*"1L86YG+"`P+"`R*2D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(&EF("@A:7-S970H)&QA;F=U86=E*2D@>PH@("`@("`@("`@("!I
M9B`H:7-S970H)'!A<G1I86Q?;&%N9RDI('L*("`@("`@("`@("`@("`@("1L
M86YG=6%G92`]("1P87)T:6%L7VQA;F<["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`O*B!.;R!D:6-E(&%U=&\M9&5T96-T:6YG+"!D
M969A=6QT('1O(%53($5N9VQI<V@N("HO"B`@("`@("`@("`@("`@("`D;&%N
M9W5A9V4@/2`G96Y?55,G.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@8F%S96YA;64H)&QA;F=U86=E*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E=',@=&AE(&QA;F=U86=E+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&QA;F<@(%1H92!L86YG=6%G92!A8F)R979I871I;VXN
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$QA;F<H)&QA;F<@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&EN8VQU9&5?;VYC92!(3U)$15]"05-%("X@)R]C;VYF
M:6<O;FQS+G!H<"<["@H@("`@("`@(&EF("AE;7!T>2@D;&%N9RD@?'P@(4Y,
M4SHZ:7-686QI9"@D;&%N9RDI('L*("`@("`@("`@("`@)&QA;F<@/2!.3%,Z
M.G-E;&5C="@I.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1'3$]"
M04Q36R=L86YG=6%G92==*2D@>PH@("`@("`@("`@("!I9B`H)$=,3T)!3%-;
M)VQA;F=U86=E)UT@/3T@)&QA;F<I('L*("`@("`@("`@("`@("`@(')E='5R
M;CL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1'3$]"
M04Q36R=R96=I<W1R>2==+3YC;&5A<D-A8VAE*"D["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("1'3$]"04Q36R=L86YG=6%G92==(#T@)&QA
M;F<["B`@("`@("`@)%]315-324].6R=H;W)D95]L86YG=6%G92==(#T@)&QA
M;F<["@H@("`@("`@("\J($9I<G-T('1R>2!L86YG=6%G92!W:71H('1H92!C
M=7)R96YT(&-H87)S970N("HO"B`@("`@("`@)&QA;F=?8VAA<G-E="`]("1L
M86YG("X@)RXG("X@3DQ3.CIG971#:&%R<V5T*"D["B`@("`@("`@:68@*"1L
M86YG7V-H87)S970@(3T@<V5T;&]C86QE*$Q#7T%,3"P@)&QA;F=?8VAA<G-E
M="DI('L*("`@("`@("`@("`@+RH@3F5X="!T<GD@;&%N9W5A9V4@=VET:"!I
M=',@9&5F875L="!C:&%R<V5T+B`J+PH@("`@("`@("`@("!G;&]B86P@)&YL
M<SL*("`@("`@("`@("`@)&-H87)S970@/2`A96UP='DH)&YL<ULG8VAA<G-E
M=',G75LD;&%N9UTI(#\@)&YL<ULG8VAA<G-E=',G75LD;&%N9UT@.B`G25-/
M+3@X-3DM,2<["B`@("`@("`@("`@("1L86YG7V-H87)S970@/2`D;&%N9R`N
M("<N)R`N("1C:&%R<V5T.PH@("`@("`@("`@("!.3%,Z.E]C86-H961#:&%R
M<V5T*#`L("1C:&%R<V5T*3L*("`@("`@("`@("`@:68@*"1L86YG7V-H87)S
M970@(3T@<V5T;&]C86QE*$Q#7T%,3"P@)&QA;F=?8VAA<G-E="DI('L*("`@
M("`@("`@("`@("`@("\J($%T(&QA<W0@=')Y(&QA;F=U86=E('-O;&5L>2X@
M*B\*("`@("`@("`@("`@("`@("1L86YG7V-H87)S970@/2`D;&%N9SL*("`@
M("`@("`@("`@("`@('-E=&QO8V%L92A,0U]!3$PL("1L86YG7V-H87)S970I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@($!P=71E;G8H)TQ!
M3D<])R`N("1L86YG7V-H87)S970I.PH@("`@("`@($!P=71E;G8H)TQ!3D=5
M04=%/2<@+B`D;&%N9U]C:&%R<V5T*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E=',@=&AE(&=E='1E>'0@9&]M86EN+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&%P<"`@("`@("`@5&AE(&%P<&QI8V%T:6]N(&YA;64N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1D:7)E8W1O<GD@(%1H92!D:7)E8W1O<GD@
M=VAE<F4@=&AE(&%P<&QI8V%T:6]N)W,*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@3$-?34534T%'15,@9&ER96-T;W)Y(')E<VED97,N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C:&%R<V5T("`@(%1H92!C:&%R<V5T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!S971497AT9&]M86EN*"1A<'`L("1D:7)E
M8W1O<GDL("1C:&%R<V5T*0H@("`@>PH@("`@("`@(&)I;F1T97AT9&]M86EN
M*"1A<'`L("1D:7)E8W1O<GDI.PH@("`@("`@('1E>'1D;VUA:6XH)&%P<"D[
M"@H@("`@("`@("\J(%1H92!E>&ES=&5N8V4@;V8@=&AI<R!F=6YC=&EO;B!D
M97!E;F1S(&]N('1H92!P;&%T9F]R;2X@*B\*("`@("`@("!I9B`H9G5N8W1I
M;VY?97AI<W1S*"=B:6YD7W1E>'1D;VUA:6Y?8V]D97-E="<I*2!["B`@("`@
M("`@("`@($Y,4SHZ7V-A8VAE9$-H87)S970H,"P@8FEN9%]T97AT9&]M86EN
M7V-O9&5S970H)&%P<"P@)&-H87)S970I*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@A:&5A9&5R<U]S96YT*"DI('L*("`@("`@("`@("`@:&5A9&5R*"=#
M;VYT96YT+51Y<&4Z('1E>'0O:'1M;#L@8VAA<G-E=#TG("X@)&-H87)S970I
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@
M=VAE=&AE<B!T:&4@<W5P<&QI960@;&%N9W5A9V4@:7,@=F%L:60N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&%N9W5A9V4@(%1H92!A8F)R979I
M871E9"!N86UE(&]F('1H92!L86YG=6%G92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@:68@=&AE(&QA;F=U86=E(&ES('9A;&ED+"!F
M86QS92!I9B!I="=S(&YO=`H@("`@("H@("`@("`@("`@("`@("`@("!V86QI
M9"!O<B!U;FMN;W=N+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<U9A;&ED*"1L
M86YG=6%G92D*("`@('L*("`@("`@("!R971U<FX@(65M<'1Y*"1'3$]"04Q3
M6R=N;',G75LG;&%N9W5A9V5S)UU;)&QA;F=U86=E72D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!-87!S(&QA;F=U86=E<R!W:71H(&-O;6UO;B!T=V\M;&5T
M=&5R(&-O9&5S("AS=6-H(&%S(&YL*2!T;R!T:&4*("`@("`J(&9U;&P@9V5T
M=&5X="!C;V1E("AI;B!T:&ES(&-A<V4L(&YL7TY,*2X@4F5T=7)N<R!T:&4@
M;&%N9W5A9V4*("`@("`J('5N;6]D:69I960@:68@:70@:7-N)W0@86X@86QI
M87,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;&%N9W5A9V4@(%1H92!L86YG=6%G92!C;V1E
M('1O(&UA<"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&UA
M<'!E9"!L86YG=6%G92!C;V1E+@H@("`@("HO"@H@("`@9G5N8W1I;VX@7VUA
M<"@D;&%N9W5A9V4I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D
M92]3=')I;F<N<&AP)SL*"B`@("`@("`@)&%L:6%S97,@/2`F)$=,3T)!3%-;
M)VYL<R==6R=A;&EA<V5S)UT["@H@("`@("`@("\O(%1R86YS;&%T92!T:&4@
M)&QA;F=U86=E('1O(&=E="!B<F]A9&5R(&UA=&-H97,N"B`@("`@("`@+R\@
M*&5G+B!D92U$12!S:&]U;&0@;6%T8V@@9&5?1$4I"B`@("`@("`@)'1R86YS
M7VQA;F<@/2!S=')?<F5P;&%C92@G+2<L("=?)RP@)&QA;F=U86=E*3L*("`@
M("`@("`D;&%N9U]P87)T<R`](&5X<&QO9&4H)U\G+"`D=')A;G-?;&%N9RD[
M"B`@("`@("`@)'1R86YS7VQA;F<@/2!3=')I;F<Z.FQO=V5R*"1L86YG7W!A
M<G1S6S!=*3L*("`@("`@("!I9B`H:7-S970H)&QA;F=?<&%R='-;,5TI*2![
M"B`@("`@("`@("`@("1T<F%N<U]L86YG("X]("=?)R`N(%-T<FEN9SHZ=7!P
M97(H)&QA;F=?<&%R='-;,5TI.PH@("`@("`@('T*"B`@("`@("`@+R\@4V5E
M(&EF('=E(&=E="!A(&UA=&-H(&9O<B!T:&ES"B`@("`@("`@:68@*"%E;7!T
M>2@D86QI87-E<ULD=')A;G-?;&%N9UTI*2!["B`@("`@("`@("`@(')E='5R
M;B`D86QI87-E<ULD=')A;G-?;&%N9UT["B`@("`@("`@?0H*("`@("`@("`O
M+R!)9B!W92!G970@=&AA="!F87(@9&]W;BP@=&AE(&QA;F=U86=E(&-A;FYO
M="!B92!F;W5N9"X*("`@("`@("`O+R!2971U<FX@)'1R86YS7VQA;F<N"B`@
M("`@("`@<F5T=7)N("1T<F%N<U]L86YG.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@8VAA<G-E="!F;W(@=&AE(&-U<G)E;G0@;&%N9W5A
M9V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&]R:6=I;F%L("!)
M9B!T<G5E(')E='5R;G,@=&AE(&]R:6=I;F%L(&-H87)S970@;V8@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@('1R86YS;&%T:6]N+"!T
M:&4@86-T=6%L;'D@=7-E9"!O;F4@;W1H97)W:7-E+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@8VAA<F%C=&5R('-E="!T:&%T('-H;W5L
M9"!B92!U<V5D('=I=&@@=&AE(&-U<G)E;G0*("`@("`J("`@("`@("`@("`@
M("`@("!L;V-A;&4@<V5T=&EN9W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$-H87)S970H)&]R:6=I;F%L(#T@9F%L<V4I"B`@("!["B`@("`@("`@9VQO
M8F%L("1L86YG=6%G92P@)&YL<SL*"B`@("`@("`@+RH@1V5T(&-A8VAE9"!R
M97-U;'1S+B`J+PH@("`@("`@("1C86-H94ME>2`](&EN='9A;"@D;W)I9VEN
M86PI.PH@("`@("`@("1C:&%R<V5T(#T@3DQ3.CI?8V%C:&5D0VAA<G-E="@D
M8V%C:&5+97DI.PH@("`@("`@(&EF("@A:7-?;G5L;"@D8VAA<G-E="DI('L*
M("`@("`@("`@("`@<F5T=7)N("1C:&%R<V5T.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"1O<FEG:6YA;"D@>PH@("`@("`@("`@("`D8VAA<G-E="`](&5M
M<'1Y*"1N;'-;)V-H87)S971S)UU;)&QA;F=U86=E72D@/R`G25-/+3@X-3DM
M,2<@.B`D;FQS6R=C:&%R<V5T<R==6R1L86YG=6%G95T["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]"<F]W<V5R
M+G!H<"<["B`@("`@("`@("`@("1B<F]W<V5R(#T@)D)R;W=S97(Z.G-I;F=L
M971O;B@I.PH*("`@("`@("`@("`@:68@*"1B<F]W<V5R+3YH87-&96%T=7)E
M*"=U=&8G*2`F)@H@("`@("`@("`@("`@("`@*%5T:6PZ.F5X=&5N<VEO;D5X
M:7-T<R@G:6-O;G8G*2!\?`H@("`@("`@("`@("`@("`@(%5T:6PZ.F5X=&5N
M<VEO;D5X:7-T<R@G;6)S=')I;F<G*2DI('L*("`@("`@("`@("`@("`@("1C
M:&%R<V5T(#T@)U541BTX)SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@:68@*&ES7VYU;&PH)&-H87)S970I*2!["B`@("`@("`@("`@("1C
M:&%R<V5T(#T@3DQ3.CIG971%>'1E<FYA;$-H87)S970H*3L*("`@("`@("!]
M"@H@("`@("`@($Y,4SHZ7V-A8VAE9$-H87)S970H)&-A8VAE2V5Y+"`D8VAA
M<G-E="D["B`@("`@("`@<F5T=7)N("1C:&%R<V5T.PH@("`@?0H*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&-U<G)E;G0@8VAA<G-E="!O9B!T:&4@
M96YV:7)O;FUE;G0*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(&-H87)A8W1E<B!S970@=&AA="!S:&]U;&0@8F4@=7-E9"!W:71H('1H92!C
M=7)R96YT"B`@("`@*B`@("`@("`@("`@("`@("`@;&]C86QE('-E='1I;F=S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971%>'1E<FYA;$-H87)S970H*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D;&%N9W5A9V4L("1N;',["@H@("`@("`@
M("\J($=E="!C86-H960@<F5S=6QT<RX@*B\*("`@("`@("`D8VAA<G-E="`]
M($Y,4SHZ7V-A8VAE9$-H87)S970H,BD["B`@("`@("`@:68@*"%I<U]N=6QL
M*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("!R971U<FX@)&-H87)S970["B`@
M("`@("`@?0H*("`@("`@("`D;&%N9U]C:&%R<V5T(#T@<V5T;&]C86QE*$Q#
M7T%,3"P@,"D["B`@("`@("`@:68@*'-T<G!O<R@D;&%N9U]C:&%R<V5T+"`G
M.R<I(#T]/2!F86QS92`F)@H@("`@("`@("`@("!S=')P;W,H)&QA;F=?8VAA
M<G-E="P@)R\G*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@)&QA;F=?8VAA
M<G-E="`](&5X<&QO9&4H)RXG+"`D;&%N9U]C:&%R<V5T*3L*("`@("`@("`@
M("`@:68@*"AC;W5N="@D;&%N9U]C:&%R<V5T*2`]/2`R*2`F)B`A96UP='DH
M)&QA;F=?8VAA<G-E=%LQ72DI('L*("`@("`@("`@("`@("`@($Y,4SHZ7V-A
M8VAE9$-H87)S970H,BP@)&QA;F=?8VAA<G-E=%LQ72D["B`@("`@("`@("`@
M("`@("!R971U<FX@)&QA;F=?8VAA<G-E=%LQ73L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("@A96UP='DH)&YL<ULG8VAA<G-E
M=',G75LD;&%N9W5A9V5=*2D@/R`D;FQS6R=C:&%R<V5T<R==6R1L86YG=6%G
M95T@.B`G25-/+3@X-3DM,2<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S
M(&]R(')E='5R;G,@=&AE(&-H87)S970@=7-E9"!U;F1E<B!C97)T86EN(&-O
M;F1I=&EO;G,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&EN9&5X("`@5&AE($E$(&]F(&$@
M8V%C:&4@<VQO="X@,"!F;W(@=&AE(%5)(&-H87)S970L(#$*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@(&9O<B!T:&4@=')A;G-L871I;VX@8VAA
M<G-E="!A;F0@,B!F;W(@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("!E>'1E<FYA;"!C:&%R<V5T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M8VAA<G-E="`@268@<W!E8VEF:65D+"!T:&ES(&-H87)S970@=VEL;"!B92!S
M=&]R960@:6X@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!G
M:79E;B!C86-H92!S;&]T+B!/=&AE<G=I<V4@=&AE(&-O;G1E;G0@;V8@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!S<&5C:69I960@8V%C
M:&4@<VQO="!W:6QL(&)E(')E='5R;F5D+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?8V%C:&5D0VAA<G-E="@D:6YD97@L("1C:&%R<V5T(#T@;G5L;"D*("`@
M('L*("`@("`@("!S=&%T:6,@)&-A8VAE.PH*("`@("`@("!I9B`H(6ES<V5T
M*"1C86-H92DI('L*("`@("`@("`@("`@)&-A8VAE(#T@87)R87DH*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("@D8VAA<G-E="`]/2!N=6QL*2!["B`@("`@
M("`@("`@(')E='5R;B!I<W-E="@D8V%C:&5;)&EN9&5X72D@/R`D8V%C:&5;
M)&EN9&5X72`Z(&YU;&P["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&-A8VAE6R1I;F1E>%T@/2`D8VAA<G-E=#L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C:&%R<V5T('1O('5S92!F;W(@
M;W5T9V]I;F<@96UA:6QS+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@<')E9F5R<F5D(&-H87)S970@9F]R(&]U=&=O:6YG(&UA:6QS(&)A
M<V5D(&]N"B`@("`@*B`@("`@("`@("`@("`@("`@=&AE('5S97(G<R!P<F5F
M97)E;F-E<R!A;F0@=&AE(&-U<G)E;G0@;&%N9W5A9V4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$5M86EL0VAA<G-E="@I"B`@("!["B`@("`@("`@9VQO
M8F%L("1P<F5F<RP@)&QA;F=U86=E+"`D;FQS.PH*("`@("`@("`D8VAA<G-E
M="`]("1P<F5F<RT^9V5T5F%L=64H)W-E;F1I;F=?8VAA<G-E="<I.PH@("`@
M("`@(&EF("@A96UP='DH)&-H87)S970I*2!["B`@("`@("`@("`@(')E='5R
M;B`D8VAA<G-E=#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&ES<V5T*"1N
M;'-;)V5M86EL<R==6R1L86YG=6%G95TI(#\@)&YL<ULG96UA:6QS)UU;)&QA
M;F=U86=E72`Z"B`@("`@("`@("`@("`@("AI<W-E="@D;FQS6R=C:&%R<V5T
M<R==6R1L86YG=6%G95TI(#\@)&YL<ULG8VAA<G-E=',G75LD;&%N9W5A9V5=
M(#H@)TE33RTX.#4Y+3$G*3L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K
M('1O('-E92!I9B!C:&%R86-T97(@<V5T(&ES('9A;&ED(&9O<B!H=&UL<W!E
M8VEA;&-H87)S*"D@8V%L;',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D8VAA<G-E="`@5&AE(&-H87)A8W1E<B!S970@=&\@8VAE8VLN"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!)<R!C:&%R<V5T('9A;&ED(&9O
M<B!T:&4@8W5R<F5N="!S>7-T96T_"B`@("`@*B\*("`@(&9U;F-T:6]N(&-H
M96-K0VAA<G-E="@D8VAA<G-E="D*("`@('L*("`@("`@("!S=&%T:6,@)&-H
M96-K.PH*("`@("`@("!I9B`H:7-?;G5L;"@D8VAA<G-E="D@?'P@96UP='DH
M)&-H87)S970I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@(&EF("AI<W-E="@D8VAE8VM;)&-H87)S971=*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&-H96-K6R1C:&%R<V5T73L*("`@("`@("!]
M(&5L<V5I9B`H(6ES<V5T*"1C:&5C:RDI('L*("`@("`@("`@("`@)&-H96-K
M(#T@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@("1V86QI9"`]('1R=64[
M"@H@("`@("`@(&EN:5]S970H)W1R86-K7V5R<F]R<R<L(#$I.PH@("`@("`@
M($!H=&UL<W!E8VEA;&-H87)S*"<G+"!%3E1?0T]-4$%4+"`D8VAA<G-E="D[
M"B`@("`@("`@:68@*&ES<V5T*"1P:'!?97)R;W)M<V<I*2!["B`@("`@("`@
M("`@("1V86QI9"`](&9A;'-E.PH@("`@("`@('T*("`@("`@("!I;FE?<F5S
M=&]R92@G=')A8VM?97)R;W)S)RD["@H@("`@("`@("1C:&5C:ULD8VAA<G-E
M=%T@/2`D=F%L:60["@H@("`@("`@(')E='5R;B`D=F%L:60["B`@("!]"@H@
M("`O*BH*("`@("`J(%-E=',@=&AE(&-H87)S970N"B`@("`@*B!);B!G96YE
M<F%L+"!T:&4@87!P;&EE9"!C:&%R<V5T(&ES(&%U=&]M871I8V%L;'D@9&5T
M97)M:6YE9"!B>2!B<F]W<V5R"B`@("`@*B!L86YG=6%G92!A;F0@8G)O=W-E
M<B!C87!A8FEL:71I97,@86YD('1H97)E)W,@;F\@;F5E9"!T;R!M86YU86QL
M>2!C86QL"B`@("`@*B!S971#:&%R<V5T+B!(;W=E=F5R(&9O<B!H96%D;&5S
M<R`H4E!#*2!O<&5R871I;VYS('1H92!C:&%R<V5T(&UA>2!B90H@("`@("H@
M<V5T(&UA;G5A;&QY('1O(&5N<W5R92!C;W)R96-T(&-H87)A8W1E<B!C;VYV
M97)S:6]N(&EN('1H92!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&-H87)S970@($EF('-P96-I9FEE9"P@=&AI<R!C:&%R<V5T('=I
M;&P@8F4@<W1O<F5D(&EN('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@9VEV96X@8V%C:&4@<VQO="X*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D:6YD97@@("!4:&4@240@;V8@82!C86-H92!S;&]T+B`P(&9O
M<B!T:&4@54D@8VAA<G-E="P@,0H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@9F]R('1H92!T<F%N<VQA=&EO;B!C:&%R<V5T(&%N9"`R(&9O<B!T
M:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&5X=&5R;F%L(&-H
M87)S970N($1E9F%U;'1S('1O(#`Z('1H:7,@:7,@=&AE"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!C:&%R<V5T(')E='5R;F5D(&)Y(&=E=$-H
M87)S970@86YD('5S960@9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("!C;VYV97)S:6]N+@H@("`@("HO"@H@("`@9G5N8W1I;VX@<V5T0VAA
M<G-E="@D8VAA<G-E="PD:6YD97@@/2`P*0H@("`@>PH@("`@("`@($Y,4SHZ
M7V-A8VAE9$-H87)S970H)&EN9&5X+"`D8VAA<G-E="D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!3971S('1H92!C=7)R96YT('1I;65Z;VYE+"!I9B!A=F%I
M;&%B;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%1I;65:;VYE*"D*("`@
M('L*("`@("`@("!G;&]B86P@)'!R969S.PH*("`@("`@("`D='H@/2`D<')E
M9G,M/F=E=%9A;'5E*"=T:6UE>F]N92<I.PH@("`@("`@(&EF("@A96UP='DH
M)'1Z*2D@>PH@("`@("`@("`@("!`<'5T96YV*"=46CTG("X@)'1Z*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&QO8V%L92!I
M;F9O(')E='5R;F5D(&)Y(&QO8V%L96-O;G8H*2P@8G5T(&-A8VAE(&ET+"!T
M;PH@("`@("H@879O:60@<F5P96%T960@8V%L;',N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@5&AE(')E<W5L=',@;V8@;&]C86QE8V]N=B@I+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971,;V-A;&5);F9O*"D*("`@('L*("`@
M("`@("!S=&%T:6,@)&QC7VEN9F\["@H@("`@("`@(&EF("@A:7-S970H)&QC
M7VEN9F\I*2!["B`@("`@("`@("`@("1L8U]I;F9O(#T@;&]C86QE8V]N=B@I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1L8U]I;F9O.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1V5T('1H92!L86YG=6%G92!I;F9O(')E='5R;F5D
M(&)Y(&YL7VQA;F=I;F9O*"DL(&)U="!C86-H92!I="P@=&\*("`@("`J(&%V
M;VED(')E<&5A=&5D(&-A;&QS+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D
M92`S+C$*("`@("`J"B`@("`@*B!`<&%R86T@8V]N<W0@)&ET96T@(%1H92!L
M86YG:6YF;R!I=&5M('1O(')E='5R;BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!4:&4@<F5S=6QT<R!O9B!N;%]L86YG:6YF;R@I+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971,86YG26YF;R@D:71E;2D*("`@('L*("`@("`@
M("!S=&%T:6,@)&YL7VEN9F\@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H(6ES
M<V5T*"1N;%]I;F9O6R1I=&5M72DI('L*("`@("`@("`@("`@)&YL7VEN9F];
M)&ET96U=(#T@;FQ?;&%N9VEN9F\H)&ET96TI.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1N;%]I;F9O6R1I=&5M73L*("`@('T*"B`@("`O*BH*("`@
M("`J($=E="!C;W5N=')Y(&EN9F]R;6%T:6]N(&9R;VT@82!H;W-T;F%M92!O
M<B!)4"!A9&1R97-S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&AO
M<W0@(%1H92!H;W-T;F%M92!O<B!)4"!A9&1R97-S+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@($]N('-U8V-E<W,L(')E='5R;B!A;B!A<G)A>2!W
M:71H('1H92!F;VQL;W=I;F<@96YT<FEE<SH*("`@("`J("`@("`@("`@("`@
M("`@("=C;V1E)R`@/3X@($-O=6YT<GD@0V]D90H@("`@("H@("`@("`@("`@
M("`@("`@)VYA;64G("`]/B`@0V]U;G1R>2!.86UE"B`@("`@*B`@("`@("`@
M("`@("`@("!/;B!F86EL=7)E+"!R971U<FX@9F%L<V4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$-O=6YT<GE">4AO<W0H)&AO<W0I"B`@("!["B`@("`@
M("`@9VQO8F%L("1C;VYF.PH*("`@("`@("`O*B!,:7-T(&]F(&=E;F5R:6,@
M9&]M86EN<R!T:&%T('=E(&MN;W<@:7,@;F]T(&EN('1H92!C;W5N=')Y(%1,
M1`H@("`@("`@("`@(&QI<W0N(%-E93H@:'1T<#HO+W=W=RYI86YA+F]R9R]G
M=&QD+V=T;&0N:'1M("HO"B`@("`@("`@)&=E;F5R:6,@/2!A<G)A>2@*("`@
M("`@("`@("`@)V%E<F\G+"`G8FEZ)RP@)V-O;2<L("=C;V]P)RP@)V5D=2<L
M("=G;W8G+"`G:6YF;R<L("=I;G0G+"`G;6EL)RP*("`@("`@("`@("`@)VUU
M<V5U;2<L("=N86UE)RP@)VYE="<L("=O<F<G+"`G<')O)PH@("`@("`@("D[
M"@H@("`@("`@("1C:&5C:TAO<W0@/2`D:&]S=#L*("`@("`@("!I9B`H<')E
M9U]M871C:"@G+UY<9"M<+EQD*UPN7&0K7"Y<9"LD+R<L("1H;W-T*2D@>PH@
M("`@("`@("`@("`D8VAE8VM(;W-T(#T@0&=E=&AO<W1B>6%D9'(H)&AO<W0I
M.PH@("`@("`@('T*"B`@("`@("`@+RH@1V5T('1H92!43$0@;V8@=&AE(&AO
M<W1N86UE+B`J+PH@("`@("`@("1P;W,@/2!S=')R<&]S*"1C:&5C:TAO<W0L
M("<N)RD["B`@("`@("`@:68@*"1P;W,@/3T](&9A;'-E*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@)&1O;6%I;B`]
M(%-T<FEN9SHZ;&]W97(H<W5B<W1R*"1C:&5C:TAO<W0L("1P;W,@*R`Q*2D[
M"@H@("`@("`@("\J(%1R>2!L;V]K=7`@=FEA(%1,1"!F:7)S="X@*B\*("`@
M("`@("!I9B`H(6EN7V%R<F%Y*"1D;VUA:6XL("1G96YE<FEC*2D@>PH@("`@
M("`@("`@("!R97%U:7)E("=(;W)D92].3%,O=&QD+G!H<"<["B`@("`@("`@
M("`@(&EF("AI<W-E="@D=&QD6R1D;VUA:6Y=*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N(&%R<F%Y*"=C;V1E)R`]/B`D9&]M86EN+"`G;F%M92<@/3X@
M)'1L9%LD9&]M86EN72D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("\J(%1R>2!'96])4"!L;V]K=7`@;F5X="X@*B\*("`@("`@("!I9B`H
M(65M<'1Y*"1C;VYF6R=G96]I<"==6R=D871A9FEL92==*2D@>PH@("`@("`@
M("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TY,4R]'96])4"YP:'`G.PH@("`@
M("`@("`@("`D9V5O:7`@/2`F3DQ37T=E;TE0.CIS:6YG;&5T;VXH)&-O;F9;
M)V=E;VEP)UU;)V1A=&%F:6QE)UTI.PH@("`@("`@("`@("`D:60@/2`D9V5O
M:7`M/F-O=6YT<GE)9$)Y3F%M92@D8VAE8VM(;W-T*3L*("`@("`@("`@("`@
M:68@*"%E;7!T>2@D:60I*2!["B`@("`@("`@("`@("`@("!R971U<FX@87)R
M87DH)V-O9&4G(#T^(%-T<FEN9SHZ;&]W97(H)$=,3T)!3%-;)T=%3TE07T-/
M54Y44EE?0T]$15,G75LD:61=*2P@)VYA;64G(#T^("1'3$]"04Q36R='14])
M4%]#3U5.5%)97TY!3453)UU;)&ED72D["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@82!(;W)D92!I;6%G92!L:6YK('1O('1H92!C;W5N=')Y
M(&9L86<N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:&]S="`@5&AE
M(&AO<W1N86UE(&]R($E0(&%D9')E<W,N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!I;6%G92!54DPL(&]R('1H92!E;7!T>2!S=')I;F<@
M;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E;F5R871E1FQA9TEM
M86=E0GE(;W-T*"1H;W-T*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T
M<GD["@H@("`@("`@("1D871A(#T@3DQ3.CIG971#;W5N=')Y0GE(;W-T*"1H
M;W-T*3L*("`@("`@("!I9B`H)&1A=&$@(3T](&9A;'-E*2!["B`@("`@("`@
M("`@("1I;6<@/2`D9&%T85LG8V]D92==("X@)RYP;F<G.PH@("`@("`@("`@
M("!I9B`H9FEL95]E>&ES=',H)')E9VES=')Y+3YG970H)W1H96UE<V9S)RP@
M)VAO<F1E)RD@+B`G+V=R87!H:6-S+V9L86=S+R<@+B`D:6UG*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N($AO<F1E.CII;6<H)&EM9RP@)&1A=&%;)VYA
M;64G72P@87)R87DH)W1I=&QE)R`]/B`D9&%T85LG;F%M92==*2P@)')E9VES
M=')Y+3YG971);6%G941I<B@G:&]R9&4G*2`N("<O9FQA9W,G*3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B`G6R<@+B`D
M9&%T85LG;F%M92==("X@)UTG.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)R<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&5I=&AE<B!A('-P96-I9FEC(&]R(&%L;"!)4T\M,S$V-B!C;W5N=')Y
M(&YA;65S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-O9&4@(%1H
M92!)4T\@,S$V-B!C;W5N=')Y(&-O9&4N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@268@82!C;W5N=')Y(&-O9&4@:&%S(&)E96X@<F5Q=65S=&5D
M('=I;&P@<F5T=7)N('1H90H@("`@("H@("`@("`@("`@("`@("`@8V]R<F5S
M<&]N9&EN9R!C;W5N=')Y(&YA;64N($EF(&5M<'1Y('=I;&P@<F5T=7)N(&%N
M"B`@("`@*B`@("`@("`@("`@("`@("!A<G)A>2!O9B!A;&P@=&AE(&-O=6YT
M<GD@8V]D97,@86YD('1H96ER(&YA;65S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B`F9V5T0V]U;G1R>4E33R@D8V]D92`]("<G*0H@("`@>PH@("`@("`@('-T
M871I8R`D8V]U;G1R:65S(#T@87)R87DH*3L*("`@("`@("!I9B`H96UP='DH
M)&-O=6YT<FEE<RDI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D
M92].3%,O8V]U;G1R:65S+G!H<"<["B`@("`@("`@?0H@("`@("`@(&EF("AE
M;7!T>2@D8V]D92DI('L*("`@("`@("`@("`@<F5T=7)N("1C;W5N=')I97,[
M"B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1C;W5N=')I97-;)&-O9&5=*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&-O=6YT<FEE<ULD8V]D95T["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B\`````````
M```````````````````````````````````````````````````````````P
M,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<T
M-@`P,C(Q,34`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O3F]T
M:69I8V%T:6]N+T5V96YT+G!H<```````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R-3(T`#$P-3$U-#,S-S0V`#`R,S<Q,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@5&AE($YO=&EF
M:6-A=&EO;E]%=F5N=#HZ(&-L87-S('!R;W9I9&5S(&$@8V]N=&%I;F5R(&9O
M<B!P87-S:6YG"B`J(&UE<W-A9V5S('1O($YO=&EF:6-A=&EO;E],:7-T96YE
M<B!C;&%S<V5S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+T5V96YT+G!H<"QV(#$N-2XR+C4@,C`P-B\P,2\P
M,2`R,3HR.#HR.2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P
M-B!(86YS($QE;&QE;&ED(#QH86YS0'9E;'5M+FYE=#X*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($AA;G,@3&5L;&5L:60@/&AA;G-`=F5L=6TN;F5T
M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?3F]T
M:69I8V%T:6]N"B`J+PIC;&%S<R!.;W1I9FEC871I;VY?179E;G0@>PH*("`@
M("\J*@H@("`@("H@5&AE(&UE<W-A9V4@8F5I;F<@<&%S<V5D+@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@
M("!V87(@)%]M97-S86=E(#T@)R<["@H@("`@+RHJ"B`@("`@*B!)9B!P87-S
M960L('-E=',@=&AE(&UE<W-A9V4@9F]R('1H:7,@979E;G0N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;65S<V%G92`@5&AE('1E>'0@;65S<V%G
M92!F;W(@=&AI<R!E=F5N="X*("`@("`J+PH@("`@9G5N8W1I;VX@3F]T:69I
M8V%T:6]N7T5V96YT*"1M97-S86=E(#T@;G5L;"D*("`@('L*("`@("`@("!I
M9B`H(6ES7VYU;&PH)&UE<W-A9V4I*2!["B`@("`@("`@("`@("1T:&ES+3YS
M971-97-S86=E*"1M97-S86=E*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3971S('1H92!T97AT(&UE<W-A9V4@9F]R('1H:7,@979E;G0N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65S<V%G92`@5&AE('1E
M>'0@;65S<V%G92!T;R!D:7-P;&%Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!S
M971-97-S86=E*"1M97-S86=E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;65S
M<V%G92`]("1M97-S86=E.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T<R!T
M:&4@=&5X="!M97-S86=E(&9O<B!T:&ES(&5V96YT+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@=&5X="!M97-S86=E('1O(&1I<W!L87DN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$UE<W-A9V4H*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7VUE<W-A9V4["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O````
M````````````````````````````````````````````````````,#`P,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-#8`,#(S
M-S`R`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]A=61I;RYP:'``````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S0S
M-``Q,#4Q-30S,S<T-@`P,C4U,C``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+G!H<"<["@HO*BH*("H@5&AE($YO=&EF
M:6-A=&EO;E],:7-T96YE<E]A=61I;SHZ(&-L87-S('!R;W9I9&5S(&9U;F-T
M:6]N86QI='D@9F]R"B`J(&EN<V5R=&EN9R!E;6)E9&1E9"!A=61I;R!N;W1I
M9FEC871I;VYS(&9R;VT@=&AE('-T86-K(&EN=&\@=&AE('!A9V4N"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O875D:6\N<&AP+'8@,2XS+C(N,B`R,#`V+S`Q+S`Q(#(Q.C(X
M.C,P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($-R;VYO
M<WES+"!,3$,@/&AT='`Z+R]W=W<N8W)O;F]S>7,N8V]M+SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($IA<V]N($TN($9E;&EC92`\:F9E;&EC94!C
M<F]N;W-Y<RYC;VT^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G
M92!(;W)D95].;W1I9FEC871I;VX*("HO"F-L87-S($YO=&EF:6-A=&EO;E],
M:7-T96YE<E]A=61I;R!E>'1E;F1S($YO=&EF:6-A=&EO;E],:7-T96YE<B![
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("HO"B`@("!F=6YC
M=&EO;B!.;W1I9FEC871I;VY?3&ES=&5N97)?875D:6\H*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?:&%N9&QE<R`](&%R<F%Y*"=A=61I;R<@/3X@)R<I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@=6YI<75E(&ED96YT:69I
M97(@9F]R('1H:7,@;&ES=&5N97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%5N:7%U92!I9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3F%M
M92@I"B`@("!["B`@("`@("`@<F5T=7)N("=A=61I;R<["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!/=71P=71S('1H92!E;6)E9&1E9"!A=61I;R!C;V1E(&EF
M('1H97)E(&%R92!A;GD@;65S<V%G97,@;VX@=&AE"B`@("`@*B`G875D:6\G
M(&UE<W-A9V4@<W1A8VLN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D
M;65S<V%G95-T86-K("`@("!4:&4@<W1A8VL@;V8@;65S<V%G97,N"B`@("`@
M*B!`<&%R86T@87)R87D@)&]P=&EO;G,@($%N(&%R<F%Y(&]F(&]P=&EO;G,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&YO=&EF>2@F)&UE<W-A9V53=&%C:RP@
M)&]P=&EO;G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("AC;W5N="@D
M;65S<V%G95-T86-K*2D@>PH@("`@("`@("`@("!W:&EL92`H)&UE<W-A9V4@
M/2!A<G)A>5]S:&EF="@D;65S<V%G95-T86-K*2D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/F=E=$UE<W-A9V4H)&UE<W-A9V4I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@3W5T<'5T<R!O;F4@
M;65S<V%G92X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&UE<W-A9V4@
M($]N92!M97-S86=E(&AA<V@@9G)O;2!T:&4@<W1A8VLN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$UE<W-A9V4H)&UE<W-A9V4I"B`@("!["B`@("`@("`@
M)&5V96YT(#T@)'1H:7,M/F=E=$5V96YT*"1M97-S86=E*3L*("`@("`@("!E
M8VAO("<\96UB960@<W)C/2(G+"!H=&UL<W!E8VEA;&-H87)S*"1E=F5N="T^
M9V5T365S<V%G92@I*2P*("`@("`@("`@("`@("<B('=I9'1H/2(P(B!H96EG
M:'0](C`B(&%U=&]S=&%R=#TB=')U92(@+SXG.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92].;W1I9FEC871I;VXO
M3&ES=&5N97(O:F%V87-C<FEP="YP:'``````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0P,30`,3`U
M,34T,S,W-#8`,#(V-38P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+TYO=&EF
M:6-A=&EO;B],:7-T96YE<BYP:'`G.PH*+RHJ"B`J(%1H92!.;W1I9FEC871I
M;VY?3&ES=&5N97)?:F%V87-C<FEP=#HZ(&-L87-S('!R;W9I9&5S(&9U;F-T
M:6]N86QI='D@9F]R"B`J(&EN<V5R=&EN9R!J879A<V-R:7!T(&-O9&4@9G)O
M;2!T:&4@;65S<V%G92!S=&%C:R!I;G1O('1H92!P86=E+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+VIA=F%S8W)I<'0N<&AP+'8@,2XW+C$P+C8@,C`P-B\P,2\P,2`R,3HR
M.#HS,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!*86X@
M4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I
M;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TYO=&EF:6-A=&EO
M;@H@*B\*8VQA<W,@3F]T:69I8V%T:6]N7TQI<W1E;F5R7VIA=F%S8W)I<'0@
M97AT96YD<R!.;W1I9FEC871I;VY?3&ES=&5N97(@>PH*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T;W(*("`@("`J+PH@("`@9G5N8W1I;VX@3F]T:69I8V%T
M:6]N7TQI<W1E;F5R7VIA=F%S8W)I<'0H*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?:&%N9&QE<R`](&%R<F%Y*"=J879A<V-R:7!T)R`]/B`G)RD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@82!U;FEQ=64@:61E;G1I9FEE<B!F
M;W(@=&AI<R!L:7-T96YE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@56YI<75E(&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971.86UE*"D*
M("`@('L*("`@("`@("!R971U<FX@)VIA=F%S8W)I<'0G.PH@("`@?0H*("`@
M("\J*@H@("`@("H@3W5T<'5T<R!T:&4@:F%V87-C<FEP="!C;V1E(&EF('1H
M97)E(&%R92!A;GD@;65S<V%G97,@;VX@=&AE"B`@("`@*B`G:F%V87-C<FEP
M="<@;65S<V%G92!S=&%C:R!A;F0@:68@=&AE("=N;W1I9GE?:F%V87-C<FEP
M="<@;W!T:6]N(&ES('-E="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)B1M97-S86=E4W1A8VL@("`@(%1H92!S=&%C:R!O9B!M97-S86=E<RX*("`@
M("`J($!P87)A;2!A<G)A>2`D;W!T:6]N<R`@06X@87)R87D@;V8@;W!T:6]N
M<RX@3W!T:6]N<SH@)VYO<V-R:7!T)PH@("`@("HO"B`@("!F=6YC=&EO;B!N
M;W1I9GDH)B1M97-S86=E4W1A8VLL("1O<'1I;VYS(#T@87)R87DH*2D*("`@
M('L*("`@("`@("!I9B`H8V]U;G0H)&UE<W-A9V53=&%C:RDI('L*("`@("`@
M("`@("`@:68@*&5M<'1Y*"1O<'1I;VYS6R=N;W-C<FEP="==*2D@>PH@("`@
M("`@("`@("`@("`@96-H;R`G/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I
M<'0B/B<["B`@("`@("`@("`@("`@("!E8VAO(")<;CPA+2U<;B(["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@=VAI;&4@*"1M97-S86=E(#T@87)R87E?
M<VAI9G0H)&UE<W-A9V53=&%C:RDI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3YG971-97-S86=E*"1M97-S86=E*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!I9B`H96UP='DH)&]P=&EO;G-;)VYO<V-R:7!T)UTI*2!["B`@("`@
M("`@("`@("`@("!E8VAO("(O+RTM/EQN/"]S8W)I<'0^7&XB.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@3W5T<'5T
M<R!O;F4@;65S<V%G92X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&UE
M<W-A9V4@($]N92!M97-S86=E(&AA<V@@9G)O;2!T:&4@<W1A8VLN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$UE<W-A9V4H)&UE<W-A9V4I"B`@("!["B`@
M("`@("`@)&5V96YT(#T@)'1H:7,M/F=E=$5V96YT*"1M97-S86=E*3L*("`@
M("`@("!E8VAO("1E=F5N="T^9V5T365S<V%G92@I("X@(EQN(CL*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92].
M;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<```````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#4T-#4`,3`U,34T,S,W-#8`,#(U-C<R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@
M)TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP)SL*"B\J
M*@H@*B!4:&4@3F]T:69I8V%T:6]N7TQI<W1E;F5R7VUO8FEL93HZ(&-L87-S
M('!R;W9I9&5S(&9U;F-T:6]N86QI='D@9F]R"B`J(&1I<W!L87EI;F<@;65S
M<V%G97,@9G)O;2!T:&4@;65S<V%G92!S=&%C:R!O;B!M;V)I;&4@9&5V:6-E
M<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP+'8@,2XX+C$P+C@@,C`P-B\P
M,2\P,2`R,3HR.#HS,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M
M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@
M2&]R9&5?3F]T:69I8V%T:6]N"B`J+PIC;&%S<R!.;W1I9FEC871I;VY?3&ES
M=&5N97)?;6]B:6QE(&5X=&5N9',@3F]T:69I8V%T:6]N7TQI<W1E;F5R7W-T
M871U<R!["@H@("`@+RHJ"B`@("`@*B!4:&4@2&]R9&5?36]B:6QE.CH@;V)J
M96-T('1H870@<W1A='5S(&QI;F5S('-H;W5L9"!B92!A9&1E9"!T;RX*("`@
M("`J"B`@("`@*B!`=F%R($AO<F1E7TUO8FEL90H@("`@("HO"B`@("!V87(@
M)%]M;V)I;&4@/2!N=6QL.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*
M("`@("`J+PH@("`@9G5N8W1I;VX@3F]T:69I8V%T:6]N7TQI<W1E;F5R7VUO
M8FEL92@I"B`@("!["B`@("`@("`@)'1H:7,M/E]H86YD;&5S(#T@87)R87DH
M)VAO<F1E+F5R<F]R)R`@(#T^(%\H(D524B(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=H;W)D92YS=6-C97-S)R`]/B!?*")354-#15-3
M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAO<F1E+G=A
M<FYI;F<G(#T^(%\H(E=!4DXB*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G:&]R9&4N;65S<V%G92<@/3X@7R@B35-'(BDI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@07-S;V-I871E(&$@2&]R9&5?36]B:6QE.CH@;V)J
M96-T('=I=&@@=&AE(&QI<W1E;F5R+@H@("`@("H*("`@("`J($!P87)A;2!(
M;W)D95]-;V)I;&4@(%1H92!(;W)D95]-;V)I;&4Z.B!O8FIE8W0@=&\@<V5N
M9"!S=&%T=7,@;&EN97,@=&\N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$UO
M8FEL94]B:F5C="@F)&UO8FEL92D*("`@('L*("`@("`@("`D=&AI<RT^7VUO
M8FEL92`]("8D;6]B:6QE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M(&$@=6YI<75E(&ED96YT:69I97(@9F]R('1H:7,@;&ES=&5N97(N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%5N:7%U92!I9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T3F%M92@I"B`@("!["B`@("`@("`@<F5T=7)N("=M
M;V)I;&4G.PH@("`@?0H*("`@("\J*@H@("`@("H@3W5T<'5T<R!T:&4@<W1A
M='5S(&QI;F4@:68@=&AE<F4@87)E(&%N>2!M97-S86=E<R!O;B!T:&4@)VUO
M8FEL92<*("`@("`J(&UE<W-A9V4@<W1A8VLN"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("8D;65S<V%G95-T86-K("!4:&4@<W1A8VL@;V8@;65S<V%G
M97,N"B`@("`@*B!`<&%R86T@87)R87D@)&]P=&EO;G,@("`@("`@($%N(&%R
M<F%Y(&]F(&]P=&EO;G,N($]P=&EO;G,Z("=N;W-P86-E)PH@("`@("HO"B`@
M("!F=6YC=&EO;B!N;W1I9GDH)B1M97-S86=E4W1A8VLL("1O<'1I;VYS(#T@
M87)R87DH*2D*("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?;6]B:6QE*2![
M"B`@("`@("`@("`@('!A<F5N=#HZ3F]T:69I8V%T:6]N7TQI<W1E;F5R7W-T
M871U<R@I.PH@("`@("`@("`@("!R971U<FX@<&%R96YT.CIN;W1I9GDH)&UE
M<W-A9V53=&%C:RP@)&]P=&EO;G,I.PH@("`@("`@('T*"B`@("`@("`@:68@
M*&-O=6YT*"1M97-S86=E4W1A8VLI*2!["B`@("`@("`@("`@('=H:6QE("@D
M;65S<V%G92`](&%R<F%Y7W-H:69T*"1M97-S86=E4W1A8VLI*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^9V5T365S<V%G92@D;65S<V%G92D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'0@/2`F)'1H:7,M/E]M;V)I;&4M/F%D
M9"AN97<@2&]R9&5?36]B:6QE7W1E>'0H(EQN(BDI.PH@("`@("`@("`@("`D
M="T^<V5T*"=L:6YE8G)E86MS)RP@=')U92D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@3W5T<'5T<R!O;F4@;65S<V%G92X*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)&UE<W-A9V4@($]N92!M97-S86=E(&AA<V@@
M9G)O;2!T:&4@<W1A8VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$UE<W-A
M9V4H)&UE<W-A9V4I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^7VUO8FEL
M92D@>PH@("`@("`@("`@("!P87)E;G0Z.DYO=&EF:6-A=&EO;E],:7-T96YE
M<E]S=&%T=7,H*3L*("`@("`@("`@("`@<F5T=7)N('!A<F5N=#HZ9V5T365S
M<V%G92@D;65S<V%G92D["B`@("`@("`@?0H*("`@("`@("`D979E;G0@/2`D
M=&AI<RT^9V5T179E;G0H)&UE<W-A9V4I.PH@("`@("`@("1T:&ES+3Y?;6]B
M:6QE+3YA9&0H;F5W($AO<F1E7TUO8FEL95]T97AT*'-P<FEN=&8H7R@B)7,Z
M("5S(BDL("1T:&ES+3Y?:&%N9&QE<ULD;65S<V%G95LG='EP92==72P@<W1R
M:7!?=&%G<R@D979E;G0M/F=E=$UE<W-A9V4H*2DI*2D["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]S=&%T=7,N<&AP````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#4W,``Q,#4Q-30S
M,S<T-@`P,C4W-#0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+G!H<"<["@HO*BH*("H@5&AE($YO=&EF:6-A=&EO;E],
M:7-T96YE<E]S=&%T=7,Z.B!C;&%S<R!P<F]V:61E<R!F=6YC=&EO;F%L:71Y
M(&9O<@H@*B!D:7-P;&%Y:6YG(&UE<W-A9V5S(&9R;VT@=&AE(&UE<W-A9V4@
M<W1A8VL@87,@82!S=&%T=7,@;&EN92X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP+'8@,2XR.2XR+C4@,C`P-B\P,2\P,2`R,3HR.#HS,"!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`
M:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C
M:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,BXQ
M"B`J($!P86-K86=E($AO<F1E7TYO=&EF:6-A=&EO;@H@*B\*8VQA<W,@3F]T
M:69I8V%T:6]N7TQI<W1E;F5R7W-T871U<R!E>'1E;F1S($YO=&EF:6-A=&EO
M;E],:7-T96YE<B!["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@
M("HO"B`@("!F=6YC=&EO;B!.;W1I9FEC871I;VY?3&ES=&5N97)?<W1A='5S
M*"D*("`@('L*("`@("`@("`D=&AI<RT^7VAA;F1L97,@/2!A<G)A>2@G:&]R
M9&4N97)R;W(G("`@/3X@87)R87DH)V%L97)T<R]E<G)O<BYP;F<G+"!?*")%
M<G)O<B(I*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:&]R
M9&4N<W5C8V5S<R<@/3X@87)R87DH)V%L97)T<R]S=6-C97-S+G!N9R<L(%\H
M(E-U8V-E<W,B*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VAO<F1E+G=A<FYI;F<G(#T^(&%R<F%Y*"=A;&5R=',O=V%R;FEN9RYP;F<G
M+"!?*")787)N:6YG(BDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=H;W)D92YM97-S86=E)R`]/B!A<G)A>2@G86QE<G1S+VUE<W-A9V4N
M<&YG)RP@7R@B365S<V%G92(I*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FX@82!U;FEQ=64@:61E;G1I9FEE<B!F;W(@=&AI<R!L:7-T96YE<BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@56YI<75E(&ED+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971.86UE*"D*("`@('L*("`@("`@("!R971U
M<FX@)W-T871U<R<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/=71P=71S('1H
M92!S=&%T=7,@;&EN92!I9B!T:&5R92!A<F4@86YY(&UE<W-A9V5S(&]N('1H
M92`G<W1A='5S)PH@("`@("H@;65S<V%G92!S=&%C:RX*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)B1M97-S86=E4W1A8VL@(%1H92!S=&%C:R!O9B!M
M97-S86=E<RX*("`@("`J($!P87)A;2!A<G)A>2`D;W!T:6]N<R`@("`@("`@
M06X@87)R87D@;V8@;W!T:6]N<RX*("`@("`J+PH@("`@9G5N8W1I;VX@;F]T
M:69Y*"8D;65S<V%G95-T86-K+"`D;W!T:6]N<R`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@:68@*&-O=6YT*"1M97-S86=E4W1A8VLI*2!["B`@("`@("`@
M("`@('=H:6QE("@D;65S<V%G92`](&%R<F%Y7W-H:69T*"1M97-S86=E4W1A
M8VLI*2!["B`@("`@("`@("`@("`@("!E8VAO("1T:&ES+3YG971-97-S86=E
M*"1M97-S86=E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E8VAO("<\
M8G(@8VQA<W,](G-P86-E<B(@+SXG.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($]U='!U=',@;VYE(&UE<W-A9V4N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1M97-S86=E("!/;F4@;65S<V%G92!H87-H(&9R;VT@
M=&AE('-T86-K+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971-97-S86=E*"1M
M97-S86=E*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@
M("`@("1E=F5N="`]("1T:&ES+3YG971%=F5N="@D;65S<V%G92D["B`@("`@
M("`@)'1E>'0@/2`D979E;G0M/F=E=$UE<W-A9V4H*3L*"B`@("`@("`@:68@
M*"%I;E]A<G)A>2@G8V]N=&5N="YR87<G+"`D=&AI<RT^9V5T1FQA9W,H)&UE
M<W-A9V4I*2D@>PH@("`@("`@("`@("`D=&5X="`](&AT;6QS<&5C:6%L8VAA
M<G,H)'1E>'0I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("<\<"!C;&%S
M<STB;F]T:6-E(CXG("X@2&]R9&4Z.FEM9R@D=&AI<RT^7VAA;F1L97-;)&UE
M<W-A9V5;)W1Y<&4G75U;,%TL("1T:&ES+3Y?:&%N9&QE<ULD;65S<V%G95LG
M='EP92==75LQ72P@)R<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E
M)RDI("X@)R9N8G-P.R9N8G-P.R<@+B`D=&5X="`N("<\+W`^)SL*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TYO=&EF
M:6-A=&EO;B],:7-T96YE<BYP:'``````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-S8R,P`Q,#4Q-30S,S<T-@`P,C0T,C,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!.;W1I9FEC
M871I;VY?3&ES=&5N97(Z.B!C;&%S<R!P<F]V:61E<R!F=6YC=&EO;F%L:71Y
M(&9O<B!D:7-P;&%Y:6YG"B`J(&UE<W-A9V5S(&9R;VT@=&AE(&UE<W-A9V4@
M<W1A8VL@87,@82!S=&%T=7,@;&EN92X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<BYP:'`L=B`Q
M+C$V+C(N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C(Y(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#(N
M,0H@*B!`<&%C:V%G92!(;W)D95].;W1I9FEC871I;VX*("HO"F-L87-S($YO
M=&EF:6-A=&EO;E],:7-T96YE<B!["@H@("`@+RHJ"B`@("`@*B!!<G)A>2!O
M9B!M97-S86=E('1Y<&5S('1H870@=&AI<R!L:7-T96YE<B!H86YD;&5S+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?:&%N
M9&QE<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@
M("`@("HO"B`@("!F=6YC=&EO;B!.;W1I9FEC871I;VY?3&ES=&5N97(H*0H@
M("`@>PH@("`@?0H*("`@("\J*@H@("`@("H@1&]E<R!T:&ES(&QI<W1E;F5R
M(&AA;F1L92!A(&-E<G1A:6X@='EP92!O9B!M97-S86=E/PH@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'1Y<&4@(%1H92!M97-S86=E('1Y<&4@:6X@
M<75E<W1I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T
M:&5R('1H:7,@;&ES=&5N97(@:&%N9&QE<R!T:&4@='EP92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@:&%N9&QE<R@D='EP92D*("`@('L*("`@("`@("!R971U
M<FX@:7-S970H)'1H:7,M/E]H86YD;&5S6R1T>7!E72D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FX@82!U;FEQ=64@:61E;G1I9FEE<B!F;W(@=&AI
M<R!L:7-T96YE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@56YI
M<75E(&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971.86UE*"D*("`@('L*
M("`@("`@("!R971U<FX@9V5T7V-L87-S*"1T:&ES*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($]U='!U=',@=&AE('-T871U<R!L:6YE+"!S96YD<R!E;6%I
M;',L('!A9V5S+"!E=&,N+"!I9B!T:&5R90H@("`@("H@87)E(&%N>2!M97-S
M86=E<R!O;B!T:&ES(&QI<W1E;F5R)W,@;65S<V%G92!S=&%C:RX*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)B1M97-S86=E4W1A8VL@(%1H92!S=&%C
M:R!O9B!M97-S86=E<RX*("`@("`J($!P87)A;2!A<G)A>2`D;W!T:6]N<R`@
M("`@("`@06X@87)R87D@;V8@;W!T:6]N<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@;F]T:69Y*"8D;65S<V%G95-T86-K<RP@)&]P=&EO;G,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@?0H*("`@("\J*@H@("`@("H@4')O8V5S<V5S(&]N92!M
M97-S86=E(&9R;VT@=&AE(&UE<W-A9V4@<W1A8VLN"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1M97-S86=E("!/;F4@;65S<V%G92!H87-H(&9R;VT@
M=&AE('-T86-K+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971-97-S86=E*"1M
M97-S86=E*0H@("`@>PH@("`@?0H*("`@("\J*@H@("`@("H@56YS97)I86QI
M>F4@86X@979E;G0@9G)O;2!T:&4@;65S<V%G92!S=&%C:RP@8VAE8VMI;F<@
M=&\@<V5E(&EF('1H90H@("`@("H@87!P<F]P<FEA=&4@8VQA<W,@97AI<W1S
M(&%N9"!K;'5D9VEN9R!I="!I;G1O(&$@8F%S92!.;W1I9FEC871I;VY?179E
M;G0*("`@("`J(&]B:F5C="!I9B!N;W0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$5V96YT*"1M97-S86=E*0H@("`@>PH@("`@("`@("1O8B`](&9A;'-E
M.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&UE<W-A9V5;)V-L87-S)UTI
M*2!["B`@("`@("`@("`@("1O8B`]($!U;G-E<FEA;&EZ92@D;65S<V%G95LG
M979E;G0G72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]%=F5N="YP:'`G.PH@("`@
M("`@("`@("`D;V(@/2!`=6YS97)I86QI>F4H)&UE<W-A9V5;)V5V96YT)UTI
M.PH@("`@("`@("`@("!I9B`H(6UE=&AO9%]E>&ES=',H)&]B+"`G9V5T365S
M<V%G92<I*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&]B+3Y?;65S
M<V%G92DI('L*("`@("`@("`@("`@("`@("`@("`D;V(@/2`F;F5W($YO=&EF
M:6-A=&EO;E]%=F5N="@D;V(M/E]M97-S86=E*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@268@=V4G
M=F4@9F%I;&5D('1O(&-R96%T92!A('9A;&ED($YO=&EF:6-A=&EO;E]%=F5N
M="!O8FIE8W0*("`@("`@("`@*B`H;W(@<W5B8VQA<W,@;V)J96-T*2!S;R!F
M87(L(')E='5R;B!A(%!%05)?17)R;W(N("HO"B`@("`@("`@:68@*"%M971H
M;V1?97AI<W1S*"1O8BP@)V=E=$UE<W-A9V4G*2D@>PH@("`@("`@("`@("`D
M;V(@/2!014%2.CIR86ES945R<F]R*"=5;F%B;&4@=&\@9&5C;V1E(&UE<W-A
M9V4@979E;G0Z("<@+B`D;65S<V%G95LG979E;G0G72D["B`@("`@("`@?0H*
M("`@("`@("`O*B!3<&5C:6%L;'D@:&%N9&QE(%!%05)?17)R;W(@;V)J96-T
M<R!A;F0@861D('5S97)I;F9O(&EF"B`@("`@("`@("H@:70G<R!T:&5R92X@
M*B\*("`@("`@("!I9B`H;65T:&]D7V5X:7-T<R@D;V(L("=G9715<V5R26YF
M;R<I*2!["B`@("`@("`@("`@("1U<V5R:6YF;R`]("1O8BT^9V5T57-E<DEN
M9F\H*3L*("`@("`@("`@("`@:68@*"1U<V5R:6YF;RD@>PH@("`@("`@("`@
M("`@("`@:68@*&ES7V%R<F%Y*"1U<V5R:6YF;RDI('L*("`@("`@("`@("`@
M("`@("`@("`D=7-E<FEN9F\@/2!`:6UP;&]D92@G+"`G+"`D=7-E<FEN9F\I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&]B+3Y?;65S
M<V%G92`]("1O8BT^9V5T365S<V%G92@I("X@)R`Z("<@+B`D=7-E<FEN9F\[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;V([
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!5;G-E<FEA;&EZ92!A;B!A<G)A>2!O
M9B!E=F5N="!F;&%G<R!F<F]M('1H92!M97-S86=E('-T86-K+B`@268@=&AI
M<PH@("`@("H@979E;G0@:&%S(&YO(&9L86=S+"!O<B!T:&4@9FQA9W,@87)R
M87D@8V]U;&0@;F]T(&)E('5N<V5R:6%L:7IE9"P@86X*("`@("`J(&5M<'1Y
M(&%R<F%Y(&ES(')E='5R;F5D+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@($%N(&%R<F%Y(&]F(&9L86=S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971&;&%G<R@D;65S<V%G92D*("`@('L*("`@("`@("`O*B!)9B!T:&ES(&UE
M<W-A9V4@9&]E<VXG="!H879E(&%N>2!F;&%G<RP@<F5T=7)N(&%N(&5M<'1Y
M"B`@("`@("`@("H@87)R87DN("HO"B`@("`@("`@:68@*&5M<'1Y*"1M97-S
M86=E6R=F;&%G<R==*2D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH*3L*
M("`@("`@("!]"@H@("`@("`@("\J(%5N<V5R:6%L:7IE('1H92!F;&%G<R!A
M<G)A>2!F<F]M('1H92!M97-S86=E+B`J+PH@("`@("`@("1F;&%G<R`]($!U
M;G-E<FEA;&EZ92@D;65S<V%G95LG9FQA9W,G72D["@H@("`@("`@("\J($EF
M('=E(&-O=6QD;B=T('5N<V5R:6%L:7IE('1H92!F;&%G<R!A<G)A>2P@<F5T
M=7)N(&%N(&5M<'1Y"B`@("`@("`@("H@87)R87DN("HO"B`@("`@("`@:68@
M*"%I<U]A<G)A>2@D9FQA9W,I*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A
M>2@I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1F;&%G<SL*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+TYO=&EF:6-A=&EO;BYP:'``````````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`Q-S`S,@`Q,#4Q-30S,S<U,@`P,C(V,C8`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J(%1H92!.;W1I9FEC871I;VXZ.B!C;&%S<R!P<F]V:61E<R!A('-U
M8FIE8W0M;V)S97)V97(@<&%T=&5R;B!F;W(*("H@<F%I<VEN9R!A;F0@<VAO
M=VEN9R!M97-S86=E<R!O9B!D:69F97)E;G0@='EP97,@86YD('1O(&1I9F9E
M<F5N=`H@*B!L:7-T96YE<G,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXN<&AP+'8@,2XT-BXR+C$Q(#(P,#8O
M,#$O,3@@,34Z,3DZ,#$@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`Q
M+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO
M<F<^"B`J($!S:6YC92`@($AO<F1E(#(N,0H@*B!`<&%C:V%G92!(;W)D95].
M;W1I9FEC871I;VX*("HO"F-L87-S($YO=&EF:6-A=&EO;B!["@H@("`@+RHJ
M"B`@("`@*B!(87-H(&-O;G1A:6YI;F<@86QL(&%T=&%C:&5D(&QI<W1E;F5R
M(&]B:F5C=',N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]L:7-T96YE<G,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@
M5&AE(&YA;64@;V8@=&AE('-E<W-I;VX@=F%R:6%B;&4@=VAE<F4@=V4@<W1O
M<F4@=&AE(&UE<W-A9V5S+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7W-T86-K(#T@)VAO<F1E365S<V%G95-T86-K<R<[
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<F5F97)E;F-E('1O('1H92!G
M;&]B86P@3F]T:69I8V%T:6]N(&]B:F5C="P@;VYL>0H@("`@("H@8W)E871I
M;F<@:70@:68@:70@9&]E<VXG="!A;')E861Y(&5X:7-T+@H@("`@("H*("`@
M("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH*("`@("`J("`@
M)&YO=&EF:6-A=&EO;B`]("9.;W1I9FEC871I;VXZ.G-I;F=L971O;B@I"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1A8VL@(%1H92!N86UE(&]F
M('1H92!M97-S86=E('-T86-K('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N($YO=&EF:6-A=&EO;B`@5&AE($AO<F1E($YO=&EF:6-A=&EO;B!I;G-T
M86YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D<W1A8VL@
M/2`G:&]R9&5-97-S86=E4W1A8VMS)RD*("`@('L*("`@("`@("!S=&%T:6,@
M)&YO=&EF:6-A=&EO;B`](&%R<F%Y*"D["@H@("`@("`@(&EF("@A:7-S970H
M)&YO=&EF:6-A=&EO;ELD<W1A8VM=*2D@>PH@("`@("`@("`@("`D;F]T:69I
M8V%T:6]N6R1S=&%C:UT@/2!N97<@3F]T:69I8V%T:6]N*"1S=&%C:RD["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&YO=&EF:6-A=&EO;ELD<W1A8VM=
M.PH@("`@?0H*("`@("\J*@H@("`@("H@26YI=&EA;&EZ92!T:&4@;F]T:69I
M8V%T:6]N('-Y<W1E;2P@<V5T('5P(&%N>2!N965D960@<V5S<VEO;@H@("`@
M("H@=F%R:6%B;&5S+"!E=&,N(%-H;W5L9"!N979E<B!B92!C86QL960@97AC
M97!T(&)Y"B`@("`@*B`F3F]T:69I8V%T:6]N.CIS:6YG;&5T;VXH*3L*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=&%C:R`@5&AE(&YA;64@;V8@
M=&AE(&UE<W-A9V4@<W1A8VL@=&\@=7-E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!.;W1I9FEC871I;VXH)'-T86-K(#T@)VAO<F1E365S<V%G95-T86-K<R<I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]S=&%C:R`]("1S=&%C:SL*"B`@("`@
M("`@+RH@36%K92!S=7)E('1H92!M97-S86=E('-T86-K(&ES(')E9VES=&5R
M960@:6X@=&AE('-E<W-I;VXL"B`@("`@("`@("H@86YD(&]B=&%I;B!A(&=L
M;V)A;"US8V]P92!R969E<F5N8V4@=&\@:70N("HO"B`@("`@("`@:68@*"%I
M<W-E="@D7U-%4U-)3TY;)'1H:7,M/E]S=&%C:UTI*2!["B`@("`@("`@("`@
M("1?4T534TE/3ELD=&AI<RT^7W-T86-K72`](&%R<F%Y*"D["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5G:7-T97)S(&$@;&ES=&5N97(@
M=VET:"!T:&4@;F]T:69I8V%T:6]N(&]B:F5C="!A;F0@:6YC;'5D97,*("`@
M("`J('1H92!N96-E<W-A<GD@;&EB<F%R>2!F:6QE(&1Y;F%M:6-A;&QY+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1R:79E<B`@5&AE(&YA;64@
M;V8@=&AE(&QI<W1E;F5R('1O(&%T=&%C:"X@5&AE<V4@;F%M97,*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@;75S="!B92!U;FEQ=64[(&9U<G1H
M97(@;&ES=&5N97)S('=I=&@@=&AE('-A;64*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@;F%M92!W:6QL(&)E(&EG;F]R960N"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I
M=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S(&$@;&ES=&5N97(@9')I
M=F5R(&UI9VAT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&YE960N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;&%S<R`@(%1H92!C;&%S<R!N86UE
M(&9R;VT@=VAI8V@@=&AE(&1R:79E<B!W87,*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@:6YS=&%N=&EA=&5D(&EF(&YO="!T:&4@9&5F875L="!O
M;F4N($EF(&=I=F5N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@('EO
M=2!H879E('1O(&EN8VQU9&4@=&AE(&QI8G)A<GD@9FEL92!C;VYT86EN:6YG
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@('1H:7,@8VQA<W,@>6]U
M<G-E;&8N(%1H:7,@:7,@=7-E9G5L(&EF('EO=2!W86YT"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@('1H92!L:7-T96YE<B!D<FEV97(@=&\@8F4@
M;W9E<G)I9&5N(&)Y(&%N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M(&%P<&QI8V%T:6]N)W,@:6UP;&5M96YT871I;VXN"B`@("`@*B\*("`@(&9U
M;F-T:6]N("9A='1A8V@H)&QI<W1E;F5R+"`D<&%R86US(#T@87)R87DH*2P@
M)&-L87-S(#T@;G5L;"D*("`@('L*("`@("`@("`D;&ES=&5N97(@/2!B87-E
M;F%M92@D;&ES=&5N97(I.PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]L
M:7-T96YE<G-;)&QI<W1E;F5R72DI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?;&ES=&5N97)S6R1L:7-T96YE<ET["B`@("`@("`@?0H*("`@("`@
M("!I9B`H:7-?;G5L;"@D8VQA<W,I*2!["B`@("`@("`@("`@($!R97%U:7)E
M7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B\G("X@)&QI<W1E;F5R("X@)RYP:'`G.PH@("`@("`@("`@("`D8VQA
M<W,@/2`G3F]T:69I8V%T:6]N7TQI<W1E;F5R7R<@+B`D;&ES=&5N97(["B`@
M("`@("`@?0H@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7VQI<W1E;F5R<ULD;&ES=&5N97)=(#T@)FYE
M=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@("`@(&EF("@A:7-S970H)%]3
M15-324].6R1T:&ES+3Y?<W1A8VM=6R1L:7-T96YE<ETI*2!["B`@("`@("`@
M("`@("`@("`D7U-%4U-)3TY;)'1H:7,M/E]S=&%C:UU;)&QI<W1E;F5R72`]
M(&%R<F%Y*"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?;&ES=&5N97)S6R1L:7-T96YE<ET["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9B@G
M3F]T:69I8V%T:6]N(&QI<W1E;F5R("5S(&YO="!F;W5N9"XG+"`D;&ES=&5N
M97(I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F4@
M82!L:7-T96YE<B!F<F]M('1H92!N;W1I9FEC871I;VX@;&ES="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1L:7-T;F5R("!4:&4@;F%M92!O9B!T
M:&4@;&ES=&5N97(@=&\@9&5T86-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!D
M971A8V@H)&QI<W1E;F5R*0H@("`@>PH@("`@("`@("1L:7-T96YE<B`](&)A
M<V5N86UE*"1L:7-T96YE<BD["B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7VQI<W1E;F5R<ULD;&ES=&5N97)=*2D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*"=.;W1I9FEC871I;VX@;&ES=&5N
M97(@)7,@;F]T(&9O=6YD+B<L("1L:7-T96YE<BDI.PH@("`@("`@('T*"B`@
M("`@("`@)&QI<W0@/2`D=&AI<RT^7VQI<W1E;F5R<ULD;&ES=&5N97)=.PH@
M("`@("`@('5N<V5T*"1T:&ES+3Y?;&ES=&5N97)S6R1L:7-T96YE<ETI.PH@
M("`@("`@('5N<V5T*"1?4T534TE/3ELD=&AI<RT^7W-T86-K75LD;&ES="T^
M9V5T3F%M92@I72D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!9&0@86X@979E;G0@=&\@=&AE($AO<F1E(&UE<W-A9V4@
M<W1A8VLN"B`@("`@*@H@("`@("H@5&AE(&5V96YT('1Y<&4@<&%R86UE=&5R
M('-H;W5L9"!B96=I;B!W:71H("=H;W)D92XG('5N;&5S<R!T:&4*("`@("`J
M(&%P<&QI8V%T:6]N(&1E9FEN97,@:71S(&]W;B!.;W1I9FEC871I;VY?3&ES
M=&5N97(@<W5B8VQA<W,@=&AA=`H@("`@("H@:&%N9&QE<R!A9&1I=&EO;F%L
M(&-O9&5S+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D979E;G0@("!.
M;W1I9FEC871I;VY?179E;G0@;V)J96-T(&]R(&UE<W-A9V4@<W1R:6YG+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)'1Y<&4@(%1H92!T>7!E(&]F(&UE<W-A
M9V4Z("=H;W)D92YE<G)O<B<L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@)VAO<F1E+G=A<FYI;F<G+"`G:&]R9&4N<W5C8V5S<R<L(&]R"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@)VAO<F1E+FUE<W-A9V4G+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1F;&%G<R`@($%R<F%Y(&]F(&]P=&EO;F%L(&9L
M86=S('1H870@=VEL;"!B92!P87-S960@=&\@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@<F5G:7-T97)E9"!L:7-T96YE<G,N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('!U<V@H)&5V96YT+"`D='EP92`](&YU;&PL("1F;&%G
M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1E=F5N="P@
M)TYO=&EF:6-A=&EO;E]%=F5N="<I("8F"B`@("`@("`@("`@("%I<U]A*"1E
M=F5N="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`O*B!4<F%N<W!A
M<F5N=&QY(&-R96%T92!A($YO=&EF:6-A=&EO;E]%=F5N="!O8FIE8W0@86YD
M"B`@("`@("`@("`@("`J('-E="!T:&4@;65S<V%G92!A='1R:6)U=&4N("HO
M"B`@("`@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N
M("<O3F]T:69I8V%T:6]N+T5V96YT+G!H<"<["B`@("`@("`@("`@("1E=F5N
M="`]("9N97<@3F]T:69I8V%T:6]N7T5V96YT*"1E=F5N="D["B`@("`@("`@
M?0H@("`@("`@(&EF("AI<U]A*"1E=F5N="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1T>7!E*2D@>PH@("`@("`@("`@("`@
M("`@)'1Y<&4@/2`G:&]R9&4N97)R;W(G.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1E=F5N="P@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@?0H@("`@("`@(&EF
M("@A:7-S970H)'1Y<&4I*2!["B`@("`@("`@("`@("1T>7!E(#T@)VAO<F1E
M+FUE<W-A9V4G.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)'1H:7,M
M/E]L:7-T96YE<G,@87,@)&QI<W1E;F5R*2!["B`@("`@("`@("`@(&EF("@D
M;&ES=&5N97(M/FAA;F1L97,H)'1Y<&4I*2!["B`@("`@("`@("`@("`@("`D
M7U-%4U-)3TY;)'1H:7,M/E]S=&%C:UU;)&QI<W1E;F5R+3YG971.86UE*"E=
M6UT@/0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=T>7!E)R`]/B`D='EP
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`G8VQA<W,G(#T^(&=E=%]C
M;&%S<R@D979E;G0I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("=E=F5N
M="<@/3X@<V5R:6%L:7IE*"1E=F5N="DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V9L86=S)R`]/B!S97)I86QI>F4H)&9L86=S*2D["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!087-S97,@
M=&AE(&UE<W-A9V4@<W1A8VL@=&\@86QL(&QI<W1E;F5R<R!A;F0@87-K<R!T
M:&5M('1O"B`@("`@*B!H86YD;&4@=&AE:7(@;65S<V%G97,N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1O<'1I;VYS("!!;B!A<G)A>2!C;VYT86EN
M:6YG(&1I<W!L87D@;W!T:6]N<R!F;W(@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@(&QI<W1E;F5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M;F]T:69Y*"1O<'1I;VYS(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H
M(6ES<V5T*"1O<'1I;VYS6R=L:7-T96YE<G,G72DI('L*("`@("`@("`@("`@
M)&]P=&EO;G-;)VQI<W1E;F5R<R==(#T@87)R87E?:V5Y<R@D=&AI<RT^7VQI
M<W1E;F5R<RD["B`@("`@("`@?2!E;'-E:68@*"%I<U]A<G)A>2@D;W!T:6]N
M<ULG;&ES=&5N97)S)UTI*2!["B`@("`@("`@("`@("1O<'1I;VYS6R=L:7-T
M96YE<G,G72`](&%R<F%Y*"1O<'1I;VYS6R=L:7-T96YE<G,G72D["B`@("`@
M("`@?0H@("`@("`@(&9O<F5A8V@@*"1O<'1I;VYS6R=L:7-T96YE<G,G72!A
M<R`D;&ES=&5N97(I('L*("`@("`@("`@("`@)'1H:7,M/E]L:7-T96YE<G-;
M)&QI<W1E;F5R72T^;F]T:69Y*"1?4T534TE/3ELD=&AI<RT^7W-T86-K75LD
M=&AI<RT^7VQI<W1E;F5R<ULD;&ES=&5N97)=+3YG971.86UE*"E=+"`D;W!T
M:6]N<RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M('1H92!N=6UB97(@;V8@;F]T:69I8V%T:6]N(&UE<W-A9V5S(&EN('1H92!S
M=&%C:RX*("`@("`J"B`@("`@*B!`875T:&]R($1A=FED(%5L979I=&-H(#QD
M879I9'5`979E<GED;G,N;F5T/@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&UY7VQI<W1E;F5R("!4:&4@;F%M92!O9B!T:&4@;&ES=&5N97(N"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@;G5M8F5R(&]F(&UE
M<W-A9V5S(&EN('1H92!S=&%C:RX*("`@("`J+PH@("`@9G5N8W1I;VX@8V]U
M;G0H)&UY7VQI<W1E;F5R(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?
M;G5L;"@D;7E?;&ES=&5N97(I*2!["B`@("`@("`@("`@("1C;W5N="`](#`[
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?;&ES=&5N97)S(&%S("1L
M:7-T96YE<BD@>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1?4T534TE/
M3ELD=&AI<RT^7W-T86-K75LD;&ES=&5N97(M/F=E=$YA;64H*5TI*2!["B`@
M("`@("`@("`@("`@("`@("`@)&-O=6YT("L](&-O=6YT*"1?4T534TE/3ELD
M=&AI<RT^7W-T86-K75LD;&ES=&5N97(M/F=E=$YA;64H*5TI.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D
M8V]U;G0["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N($!C
M;W5N="@D7U-%4U-)3TY;)'1H:7,M/E]S=&%C:UU;)'1H:7,M/E]L:7-T96YE
M<G-;)&UY7VQI<W1E;F5R72T^9V5T3F%M92@I72D["B`@("`@("`@?0H@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]097)M<R\`````````
M````````````````````````````````````````````````````````````
M````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U
M,34T,S,W-#8`,#(P-34U`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+U!E<FUS+V1A=&%T<F5E+G!H<```````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`V-C<W-0`Q,#4Q-30S,S<T-@`P,C,Q,#0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*"G)E<75I<F5?
M;VYC92`G2&]R9&4O1&%T851R964N<&AP)SL*"B\J*@H@*B!4:&4@4&5R;7-?
M9&%T871R964Z.B!C;&%S<R!P<F]V:61E<R!A($1A=&%4<F5E(&1R:79E<B!F
M;W(@=&AE($AO<F1E"B`J('!E<FUI<W-I;VYS('-Y<W1E;2X*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP+'8@,2XV
M+C(N,3(@,C`P-B\P-R\R,"`Q.#HU,#HP-2!C:'5C:R!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IA;B!38VAN96ED97(@
M/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@
M2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R
M9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U!E<FUS"B`J+PIC;&%S<R!097)M
M<U]D871A=')E92!E>'1E;F1S(%!E<FUS('L*"B`@("`O*BH*("`@("`J(%!O
M:6YT97(@=&\@82!$871A5')E92!I;G-T86YC92!T;R!M86YA9V4@=&AE(&1I
M9F9E<F5N=`H@("`@("H@<&5R;6ES<VEO;G,N"B`@("`@*@H@("`@("H@0'9A
M<B!$871A5')E90H@("`@("HO"B`@("!V87(@)%]D871A=')E93L*"B`@("`O
M*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!0
M97)M<U]D871A=')E92@I"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*
M("`@("`@("!I9B`H96UP='DH)&-O;F9;)V1A=&%T<F5E)UU;)V1R:79E<B==
M*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH)UEO=2!M=7-T(&-O;F9I
M9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E('1H92!097)M<R!$871A
M5')E92!D<FEV97(N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]
M"@H@("`@("`@("1D<FEV97(@/2`D8V]N9ELG9&%T871R964G75LG9')I=F5R
M)UT["B`@("`@("`@)'1H:7,M/E]D871A=')E92`]("9$871A5')E93HZ<VEN
M9VQE=&]N*"1D<FEV97(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y7VUE<F=E*$AO<F1E.CIG971$<FEV
M97)#;VYF:6<H)V1A=&%T<F5E)RP@)&1R:79E<BDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"=G<F]U<"<@/3X@)VAO<F1E+G!E<FUS)RDI*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&%V86EL86)L92!P97)M:7-S:6]N
M<R!F;W(@82!G:79E;B!L979E;"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1N86UE("!4:&4@<&5R;6ES<VEO;B=S(&YA;64N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@;V8@879A:6QA8FQE('!E<FUI
M<W-I;VYS(&%N9"!T:&5I<B!T:71L97,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$%V86EL86)L92@D;F%M92D*("`@('L*("`@("`@("!I9B`H)&YA;64@
M/3T@1$%40512145?4D]/5"D@>PH@("`@("`@("`@("`D;F%M92`]("<G.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@<&%R96YT.CIG971!=F%I;&%B;&4H
M)&YA;64I.PH@("`@?0H*("`@("\J*@H@("`@("H@1VEV96X@82!P97)M:7-S
M:6]N(&YA;64L(')E='5R;G,@=&AE('1I=&QE(&9O<B!T:&%T('!E<FUI<W-I
M;VX@8GD*("`@("`J(&QO;VMI;F<@:70@=7`@:6X@=&AE(&%P<&QI8V%T:6]N
M<R=S('!E<FUI<W-I;VX@87!I+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&YA;64@(%1H92!P97)M:7-S:6]N<R=S(&YA;64N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!T:71L92!F;W(@=&AE('!E<FUI<W-I
M;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1I=&QE*"1N86UE*0H@("`@
M>PH@("`@("`@(&EF("@D;F%M92`]/2!$051!5%)%15]23T]4*2!["B`@("`@
M("`@("`@(')E='5R;B!?*")!;&P@4&5R;6ES<VEO;G,B*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N('!A<F5N=#HZ9V5T5&ET;&4H)&YA;64I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&YE=R!P97)M:7-S:6]N<R!O
M8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE
M('!E<FUI<W-I;VXG<R!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@1&%T
M851R965/8FIE8W1?4&5R;6ES<VEO;G,@($$@;F5W('!E<FUI<W-I;VYS(&]B
M:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@)FYE=U!E<FUI<W-I;VXH)&YA
M;64I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1N86UE*2D@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4&5R;6ES<VEO;B!N86UE
M<R!M=7-T(&)E(&YO;BUE;7!T>2<I.PH@("`@("`@('T*"B`@("`@("`@)'1Y
M<&4@/2`G;6%T<FEX)SL*("`@("`@("`D<&%R86US(#T@;G5L;#L*("`@("`@
M("!I9B`H)'!O<R`]('-T<G!O<R@D;F%M92P@)SHG*2D@>PH@("`@("`@("`@
M("`D:6YF;R`]("1T:&ES+3YG971!<'!L:6-A=&EO;E!E<FUI<W-I;VYS*'-U
M8G-T<B@D;F%M92P@,"P@)'!O<RDI.PH@("`@("`@("`@("!I9B`H(6ES7V$H
M)&EN9F\L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D:6YF;ULG='EP92==*2`F)B!I<W-E="@D:6YF;ULG='EP92==6R1N
M86UE72DI('L*("`@("`@("`@("`@("`@("`@("`D='EP92`]("1I;F9O6R=T
M>7!E)UU;)&YA;65=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1I;F9O6R=P87)A;7,G72D@)B8@:7-S970H)&EN9F];
M)W!A<F%M<R==6R1N86UE72DI('L*("`@("`@("`@("`@("`@("`@("`D<&%R
M86US(#T@)&EN9F];)W!A<F%M<R==6R1N86UE73L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D<&5R;2`]("9N
M97<@1&%T851R965/8FIE8W1?4&5R;6ES<VEO;B@D;F%M92P@)'1Y<&4L("1P
M87)A;7,I.PH@("`@("`@("1P97)M+3YS971$871A5')E92@D=&AI<RT^7V1A
M=&%T<F5E*3L*"B`@("`@("`@<F5T=7)N("1P97)M.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!A($1A=&%4<F5E3V)J96-T7U!E<FUI<W-I;VX@
M;V)J96-T(&-O<G)E<W!O;F1I;F<@=&\@=&AE"B`@("`@*B!N86UE9"!P97)M
M:7-S:6]N+"!W:71H('1H92!U<V5R<R!A;F0@;W1H97(@9&%T82!R971R:65V
M960*("`@("`J(&%P<')O<')I871E;'DN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F%M92`@5&AE(&YA;64@;V8@=&AE('!E<FUI<W-I;VX@=&\@
M<F5T<FEE=F4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971097)M:7-S:6]N
M*"1N86UE*0H@("`@>PH@("`@("`@("\J($-A8VAE(&]F('!R979I;W5S;'D@
M<F5T<FEE=F5D('!E<FUI<W-I;VYS+B`J+PH@("`@("`@('-T871I8R`D<&5R
M;7-#86-H92`](&%R<F%Y*"D["@H@("`@("`@(&EF("AI<W-E="@D<&5R;7-#
M86-H95LD;F%M95TI*2!["B`@("`@("`@("`@(')E='5R;B`D<&5R;7-#86-H
M95LD;F%M95T["B`@("`@("`@?0H*("`@("`@("`D<&5R;7-#86-H95LD;F%M
M95T@/2`D=&AI<RT^7V1A=&%T<F5E+3YG971/8FIE8W0H)&YA;64L("=$871A
M5')E94]B:F5C=%]097)M:7-S:6]N)RD["B`@("`@("`@<F5T=7)N("1P97)M
M<T-A8VAE6R1N86UE73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M82!$871A5')E94]B:F5C=%]097)M:7-S:6]N(&]B:F5C="!C;W)R97-P;VYD
M:6YG('1O('1H92!G:79E;@H@("`@("H@=6YI<75E($E$+"!W:71H('1H92!U
M<V5R<R!A;F0@;W1H97(@9&%T82!R971R:65V960@87!P<F]P<FEA=&5L>2X*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8VED("!4:&4@=6YI<75E
M($E$(&]F('1H92!P97)M:7-S:6]N('1O(')E=')I979E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B`F9V5T4&5R;6ES<VEO;D)Y260H)&-I9"D*("`@('L*("`@
M("`@("!I9B`H)&-I9"`]/2!$051!5%)%15]23T]4*2!["B`@("`@("`@("`@
M("1O8FIE8W0@/2`F)'1H:7,M/FYE=U!E<FUI<W-I;VXH1$%40512145?4D]/
M5"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&]B:F5C="`]("8D
M=&AI<RT^7V1A=&%T<F5E+3YG971/8FIE8W1">4ED*"1C:60L("=$871A5')E
M94]B:F5C=%]097)M:7-S:6]N)RD["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D;V)J96-T.PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A('!E<FUI
M<W-I;VX@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X@5&AE('!E<FUI<W-I
M;VX@;75S="!F:7)S=`H@("`@("H@8F4@8W)E871E9"!W:71H(%!E<FTZ.FYE
M=U!E<FUI<W-I;VXH*2P@86YD(&AA=F4@86YY(&EN:71I86P@=7-E<G,*("`@
M("`J(&%D9&5D('1O(&ET+"!B969O<F4@=&AI<R!F=6YC=&EO;B!I<R!C86QL
M960N"B`@("`@*@H@("`@("H@0'!A<F%M($1A=&%4<F5E3V)J96-T7U!E<FUI
M<W-I;VX@)'!E<FT@(%1H92!N97<@<&5R;2!O8FIE8W0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&%D9%!E<FUI<W-I;VXH)B1P97)M*0H@("`@>PH@("`@("`@
M(&EF("@A:7-?82@D<&5R;2P@)T1A=&%4<F5E3V)J96-T7U!E<FUI<W-I;VXG
M*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4&5R
M;6ES<VEO;G,@;75S="!B92!$871A5')E94]B:F5C=%]097)M:7-S:6]N(&]B
M:F5C=',@;W(@97AT96YD('1H870@8VQA<W,N)RD["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)'1H:7,M/E]D871A=')E92T^861D*"1P97)M*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@82!P97)M:7-S:6]N(&9R;VT@
M=&AE('!E<FUI<W-I;VYS('-Y<W1E;2!P97)M86YE;G1L>2X*("`@("`J"B`@
M("`@*B!`<&%R86T@1&%T851R965/8FIE8W1?4&5R;6ES<VEO;B`D<&5R;2`@
M5&AE('!E<FUI<W-I;VX@=&\@<F5M;W9E+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&9O<F-E("`@("`@("`@("`@("`@("`@($9O<F-E('1O(')E;6]V92!E
M=F5R>2!C:&EL9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E4&5R;6ES
M<VEO;B@F)'!E<FTL("1F;W)C92`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF
M("@A:7-?82@D<&5R;2P@)T1A=&%4<F5E3V)J96-T7U!E<FUI<W-I;VXG*2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4&5R;6ES
M<VEO;G,@;75S="!B92!$871A5')E94]B:F5C=%]097)M:7-S:6]N(&]B:F5C
M=',@;W(@97AT96YD('1H870@8VQA<W,N)RD["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)'1H:7,M/E]D871A=')E92T^<F5M;W9E*"1P97)M+3YG971.
M86UE*"DL("1F;W)C92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD<R!O
M=70@=VAA="!R:6=H=',@=&AE(&=I=F5N('5S97(@:&%S('1O('1H:7,@;V)J
M96-T+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D<&5R;6ES<VEO;B`@
M5&AE(&9U;&P@<&5R;6ES<VEO;B!N86UE(&]F('1H92!O8FIE8W0@=&\*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@8VAE8VL@=&AE('!E<FUI
M<W-I;VYS(&]F+"!O<B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@1&%T851R965/8FIE8W1?4&5R;6ES<VEO;B!O8FIE8W0N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1U<V5R("`@("`@(%1H92!U<V5R('1O(&-H96-K
M(&9O<BX@1&5F875L=',@=&\@=&AE(&-U<G)E;G0*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=7-E<BX*("`@("`J($!P87)A;2!S=')I;F<@
M)&-R96%T;W(@("`@5&AE('5S97(@=VAO(&-R96%T960@=&AE(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!!(&)I=&UA<VL@;V8@<&5R
M;6ES<VEO;G,L(&$@<&5R;6ES<VEO;B!V86QU92P@;W(@86X@87)R87D*("`@
M("`J("`@("`@("`@("`@("`@(&]F('!E<FUI<W-I;VX@=F%L=65S('1H92!U
M<V5R(&AA<RP@9&5P96YD:6YG(&]N('1H90H@("`@("H@("`@("`@("`@("`@
M("`@<&5R;6ES<VEO;B!T>7!E(&%N9"!W:&5T:&5R('1H92!P97)M:7-S:6]N
M('9A;'5E(&ES"B`@("`@*B`@("`@("`@("`@("`@("!A;6)I9W5O=7,N($9A
M;'-E(&EF('1H97)E(&ES(&YO('-U8V@@<&5R;7-I<W-I;VXN"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%!E<FUI<W-I;VYS*"1P97)M:7-S:6]N+"`D=7-E
M<B`](&YU;&PL("1C<F5A=&]R(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H
M(6ES7V$H)'!E<FUI<W-I;VXL("=$871A5')E94]B:F5C=%]097)M:7-S:6]N
M)RDI('L*("`@("`@("`@("`@)'!E<FUI<W-I;VX@/2`F)'1H:7,M/F=E=%!E
M<FUI<W-I;VXH)'!E<FUI<W-I;VXI.PH@("`@("`@("`@("!I9B`H:7-?82@D
M<&5R;6ES<VEO;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M2&]R9&4Z.FQO9TUE<W-A9V4H)'!E<FUI<W-I;VXL(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H
M)'5S97(@/3T](&YU;&PI('L*("`@("`@("`@("`@)'5S97(@/2!!=71H.CIG
M971!=71H*"D["B`@("`@("`@?0H*("`@("`@("`O+R!)9B!T:&ES(&ES(&$@
M9W5E<W0@=7-E<BP@;VYL>2!C:&5C:R!G=65S="!P97)M:7-S:6]N<RX*("`@
M("`@("!I9B`H96UP='DH)'5S97(I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<&5R;6ES<VEO;BT^9V5T1W5E<W1097)M:7-S:6]N<R@I.PH@("`@("`@('T*
M"B`@("`@("`@+R\@268@)&-R96%T;W(@=V%S('-P96-I9FEE9"P@8VAE8VL@
M8W)E871O<B!P97)M:7-S:6]N<RX*("`@("`@("!I9B`H)&-R96%T;W(@(3T]
M(&YU;&PI('L*("`@("`@("`@("`@+R\@268@=&AE('5S97(@:7,@=&AE(&-R
M96%T;W(@;V8@=&AE(&5V96YT('-E92!I9B!T:&5R90H@("`@("`@("`@("`O
M+R!A<F4@8W)E871O<B!P97)M:7-S:6]N<RX*("`@("`@("`@("`@:68@*'-T
M<FQE;B@D=7-E<BD@)B8@)'5S97(@/3T]("1C<F5A=&]R("8F"B`@("`@("`@
M("`@("`@("`H)'!E<FUS(#T@)'!E<FUI<W-I;VXM/F=E=$-R96%T;W)097)M
M:7-S:6]N<R@I*2`A/3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1P97)M<SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@
M0VAE8VL@=7-E<BUL979E;"!P97)M:7-S:6]N<RX*("`@("`@("`D=7-E<G!E
M<FUS(#T@)'!E<FUI<W-I;VXM/F=E=%5S97)097)M:7-S:6]N<R@I.PH@("`@
M("`@(&EF("AI<W-E="@D=7-E<G!E<FUS6R1U<V5R72DI('L*("`@("`@("`@
M("`@<F5T=7)N("1U<V5R<&5R;7-;)'5S97)=.PH@("`@("`@('T*"B`@("`@
M("`@+R\@268@;F\@=7-E<B!P97)M:7-S:6]N<R!A<F4@9F]U;F0L('1R>2!G
M<F]U<"!P97)M:7-S:6]N<RX*("`@("`@("!I9B`H:7-S970H)'!E<FUI<W-I
M;VXM/F1A=&%;)V=R;W5P<R==*2`F)@H@("`@("`@("`@("!I<U]A<G)A>2@D
M<&5R;6ES<VEO;BT^9&%T85LG9W)O=7!S)UTI("8F"B`@("`@("`@("`@(&-O
M=6YT*"1P97)M:7-S:6]N+3YD871A6R=G<F]U<',G72DI('L*("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E("=(;W)D92]'<F]U<"YP:'`G.PH@("`@("`@("`@
M("`D9W)O=7!S(#T@)D=R;W5P.CIS:6YG;&5T;VXH*3L*"B`@("`@("`@("`@
M("1C;VUP;W-I=&5?<&5R;2`](&YU;&P["B`@("`@("`@("`@("1T>7!E(#T@
M)'!E<FUI<W-I;VXM/F=E="@G='EP92<I.PH@("`@("`@("`@("!F;W)E86-H
M("@D<&5R;6ES<VEO;BT^9&%T85LG9W)O=7!S)UT@87,@)&=R;W5P(#T^("1P
M97)M*2!["B`@("`@("`@("`@("`@("!I9B`H)&=R;W5P<RT^=7-E<DES26Y'
M<F]U<"@D=7-E<BP@)&=R;W5P*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF
M("@D8V]M<&]S:71E7W!E<FT@/3T](&YU;&PI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&-O;7!O<VET95]P97)M(#T@)'1Y<&4@/3T@)VUA=')I>"<@
M/R`P(#H@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1T>7!E(#T]("=M871R:7@G*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1C;VUP;W-I=&5?<&5R;2!\/2`D<&5R;3L*("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D8V]M<&]S:71E7W!E<FU;72`]("1P97)M.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@:68@*"1C;VUP;W-I=&5?<&5R;2`A/3T@;G5L;"D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1C;VUP;W-I=&5?<&5R;3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@268@=&AE<F4@87)E(&1E9F%U
M;'0@<&5R;6ES<VEO;G,L(')E='5R;B!T:&5M+@H@("`@("`@(&EF("@H)'!E
M<FUS(#T@)'!E<FUI<W-I;VXM/F=E=$1E9F%U;'1097)M:7-S:6]N<R@I*2`A
M/3T@;G5L;"D@>PH@("`@("`@("`@("!R971U<FX@)'!E<FUS.PH@("`@("`@
M('T*"B`@("`@("`@+R\@3W1H97)W:7-E+"!D96YY(&%L;"!P97)M:7-S:6]N
M<R!T;R!T:&4@;V)J96-T+@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('5N:7%U92!I9&5N=&EF:65R
M(&]F('1H:7,@<&5R;6ES<VEO;BX*("`@("`J"B`@("`@*B!`<&%R86T@1&%T
M851R965/8FIE8W1?4&5R;6ES<VEO;B`D<&5R;6ES<VEO;B`@5&AE('!E<FUI
M<W-I;VX@;V)J96-T('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@9V5T('1H92!)1"!O9BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!U;FEQ=64@:60N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%!E<FUI<W-I;VY)9"@D<&5R;6ES<VEO;BD*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]D871A=')E92T^9V5T260H
M)'!E<FUI<W-I;VXM/F=E=$YA;64H*2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!&:6YD<R!O=70@:68@=&AE('5S97(@:&%S('1H92!S<&5C:69I960@<FEG
M:'1S('1O('1H92!G:79E;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<&5R;6ES<VEO;B`@5&AE('!E<FUI<W-I;VX@=&\@8VAE8VLN
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R("`@("`@("!4:&4@=7-E<B!T
M;R!C:&5C:R!F;W(N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<&5R;2`@("`@
M("!4:&4@<&5R;6ES<VEO;B!L979E;"!T:&%T(&YE961S('1O(&)E(&-H96-K
M960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<BX*("`@
M("`J($!P87)A;2!S=')I;F<@)&-R96%T;W(@("`@(%1H92!C<F5A=&]R(&]F
M('1H92!E=F5N=`H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U
M92!I9B!T:&4@=7-E<B!H87,@=&AE('-P96-I9FEE9"!P97)M:7-S:6]N<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@:&%S4&5R;6ES<VEO;B@D<&5R;6ES<VEO
M;BP@)'5S97(L("1P97)M+"`D8W)E871O<B`](&YU;&PI"B`@("!["B`@("`@
M("`@<F5T=7)N("@D=&AI<RT^9V5T4&5R;6ES<VEO;G,H)'!E<FUI<W-I;VXL
M("1U<V5R+"`D8W)E871O<BD@)B`D<&5R;2D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#:&5C:W,@:68@82!P97)M:7-S:6]N(&5X:7-T<R!I;B!T:&4@<WES
M=&5M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!E<FUI<W-I;VX@
M(%1H92!P97)M:7-S:6]N('1O(&-H96-K+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@<&5R;6ES<VEO;B!E>&ES=',N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&5X:7-T<R@D<&5R;6ES<VEO;BD*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]D871A=')E92T^97AI<W1S*"1P97)M
M:7-S:6]N*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!L:7-T
M(&]F('!A<F5N="!P97)M:7-S:6]N<RX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1C:&EL9"`@5&AE(&YA;64@;V8@=&AE(&-H:6QD('1O(')E=')I
M979E('!A<F5N=',@9F]R+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M($$@:&%S:"!W:71H(&%L;"!P87)E;G1S(&EN(&$@=')E92!F;W)M870N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<F5N=',H)&-H:6QD*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7V1A=&%T<F5E+3YG971087)E;G1S*"1C
M:&EL9"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%L;"!P97)M
M:7-S:6]N<R!O9B!T:&4@<WES=&5M(&EN(&$@=')E92!F;W)M870N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!H87-H('=I=&@@86QL('!E<FUI
M<W-I;VYS(&EN(&$@=')E92!F;W)M870N"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9G9714<F5E*"D*("`@('L*("`@("`@("`D=')E92`]("1T:&ES+3Y?9&%T
M871R964M/F=E="A$051!5%)%15]&3U)-051?1DQ!5"P@1$%40512145?4D]/
M5"P@=')U92D["B`@("`@("`@<F5T=7)N("1T<F5E.PH@("`@?0H*?0H*+RHJ
M"B`J($5X=&5N<VEO;B!O9B!T:&4@1&%T851R965/8FIE8W0@8VQA<W,@9F]R
M('-T;W)I;F<@4&5R;6ES<VEO;B!I;F9O<FUA=&EO;B!I;@H@*B!T:&4@1&%T
M851R964@9')I=F5R+B!)9B!Y;W4@=V%N="!T;R!S=&]R92!S<&5C:6%L:7IE
M9"!097)M:7-S:6]N"B`J(&EN9F]R;6%T:6]N+"!Y;W4@<VAO=6QD(&5X=&5N
M9"!T:&ES(&-L87-S(&EN<W1E860@;V8@97AT96YD:6YG"B`J($1A=&%4<F5E
M3V)J96-T(&1I<F5C=&QY+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U
M8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E
M<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,BXQ"B`J($!P
M86-K86=E($AO<F1E7U!E<FUS"B`J+PIC;&%S<R!$871A5')E94]B:F5C=%]0
M97)M:7-S:6]N(&5X=&5N9',@1&%T851R965/8FIE8W0@>PH*("`@("\J*@H@
M("`@("H@5&AE($1A=&%4<F5E3V)J96-T7U!E<FUI<W-I;VX@8V]N<W1R=6-T
M;W(N($IU<W0@;6%K97,@<W5R92!T;R!C86QL('1H90H@("`@("H@<&%R96YT
M(&-O;G-T<G5C=&]R('-O('1H870@=&AE('!E<FTG<R!N86UE(&ES('-E="!P
M<F]P97)L>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@
M5&AE(&YA;64@;V8@=&AE('!E<FTN"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M>7!E("`@5&AE('!E<FUI<W-I;VX@='EP92X*("`@("`J($!P87)A;2!A<G)A
M>2`D<&%R86US("!!(&AA<V@@=VET:"!A;GD@<&%R86UE=&5R<R!T:&%T('1H
M92!P97)M:7-S:6]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@='EP
M92!N965D<RX*("`@("`J+PH@("`@9G5N8W1I;VX@1&%T851R965/8FIE8W1?
M4&5R;6ES<VEO;B@D;F%M92P@)'1Y<&4@/2`G;6%T<FEX)RP@)'!A<F%M<R`]
M(&YU;&PI"B`@("!["B`@("`@("`@<&%R96YT.CI$871A5')E94]B:F5C="@D
M;F%M92D["B`@("`@("`@)'1H:7,M/F1A=&%;)W1Y<&4G72`]("1T>7!E.PH@
M("`@("`@(&EF("AI<U]A<G)A>2@D<&%R86US*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^9&%T85LG<&%R86US)UT@/2`D<&%R86US.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($=E=',@;VYE(&]F('1H92!A='1R:6)U=&5S
M(&]F('1H92!O8FIE8W0L(&]R(&YU;&P@:68@:70@:7-N)W0@9&5F:6YE9"X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A='1R:6)U=&4@(%1H92!A
M='1R:6)U=&4@=&\@9V5T+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1H92!V86QU92!O9B!T:&4@871T<FEB=71E+"!O<B!N=6QL+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G970H)&%T=')I8G5T92D*("`@('L*("`@("`@("`D
M=F%L=64@/2!P87)E;G0Z.F=E="@D871T<FEB=71E*3L*("`@("`@("!I9B`H
M)'9A;'5E(#T]/2!N=6QL("8F("1A='1R:6)U=&4@/3T@)W1Y<&4G*2!["B`@
M("`@("`@("`@("1V86QU92`]("=M871R:7@G.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)'9A;'5E.PH@("`@?0H*("`@("\J*@H@("`@("H@57!D871E
M<R!T:&4@<&5R;6ES<VEO;G,@8F%S960@;VX@9&%T82!P87-S960@:6X@=&AE
M(&%R<F%Y+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&5R;7,@($%N
M(&%R<F%Y(&-O;G1A:6YI;F<@=&AE('!E<FUI<W-I;VYS('=H:6-H(&%R92!T
M;R!B90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@=7!D871E9"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@=7!D871E4&5R;6ES<VEO;G,H)'!E<FUS*0H@
M("`@>PH@("`@("`@("1T>7!E(#T@)'1H:7,M/F=E="@G='EP92<I.PH*("`@
M("`@("!I9B`H)'1Y<&4@/3T@)VUA=')I>"<I('L*("`@("`@("`@("`@+RH@
M07)R87D@;V8@<&5R;6ES<VEO;B!T>7!E<R!T;R!I=&5R871E('1H<F]U9V@N
M("HO"B`@("`@("`@("`@("1P97)M7W1Y<&5S(#T@4&5R;7,Z.F=E=%!E<FUS
M07)R87DH*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1P97)M<R!A
M<R`D<&5R;5]C;&%S<R`]/B`D<&5R;5]V86QU97,I('L*("`@("`@("`@("`@
M<W=I=&-H("@D<&5R;5]C;&%S<RD@>PH@("`@("`@("`@("!C87-E("=D969A
M=6QT)SH*("`@("`@("`@("`@8V%S92`G9W5E<W0G.@H@("`@("`@("`@("!C
M87-E("=C<F5A=&]R)SH*("`@("`@("`@("`@("`@(&EF("@D='EP92`]/2`G
M;6%T<FEX)RD@>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1P97)M
M7W1Y<&5S(&%S("1V86P@/3X@)&QA8F5L*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@A96UP='DH)'!E<FU?=F%L=65S6R1V86Q=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%!E<FTH)'!E<FU?
M8VQA<W,L("1V86PL(&9A;'-E*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU
M;G-E=%!E<FTH)'!E<FU?8VQA<W,L("1V86PL(&9A;'-E*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T@96QS96EF("@A96UP='DH)'!E<FU?=F%L=65S*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971097)M*"1P97)M7V-L87-S
M+"`D<&5R;5]V86QU97,L(&9A;'-E*3L*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5N<V5T4&5R;2@D<&5R
M;5]C;&%S<RP@;G5L;"P@9F%L<V4I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=U)SH*("`@
M("`@("`@("`@8V%S92`G9R<Z"B`@("`@("`@("`@("`@("`D<&5R;4ED(#T@
M87)R87DH)V-L87-S)R`]/B`D<&5R;5]C;&%S<R`]/2`G=2<@/R`G=7-E<G,G
M(#H@)V=R;W5P<R<I.PH@("`@("`@("`@("`@("`@+RH@1FEG=7)E(&]U="!W
M:&%T(&YA;65S('1H870@87)E('-T;W)E9"!I;B!T:&ES('!E<FUI<W-I;VX*
M("`@("`@("`@("`@("`@("`J(&-L87-S(&AA=F4@;F]T(&)E96X@<W5B;6ET
M=&5D(&9O<B!A;B!U<&1A=&4L(&EE+B!H879E(&)E96X*("`@("`@("`@("`@
M("`@("`J(')E;6]V960@96YT:7)E;'DN("HO"B`@("`@("`@("`@("`@("`D
M8W5R<F5N=%]N86UE<R`](&ES<V5T*"1T:&ES+3YD871A6R1P97)M261;)V-L
M87-S)UU=*0H@("`@("`@("`@("`@("`@("`@(#\@87)R87E?:V5Y<R@D=&AI
M<RT^9&%T85LD<&5R;4ED6R=C;&%S<R==72D*("`@("`@("`@("`@("`@("`@
M("`Z(&%R<F%Y*"D["B`@("`@("`@("`@("`@("`D=7!D871E9%]N86UE<R`]
M(&%R<F%Y7VME>7,H)'!E<FU?=F%L=65S*3L*("`@("`@("`@("`@("`@("1R
M96UO=F5D7VYA;65S(#T@87)R87E?9&EF9B@D8W5R<F5N=%]N86UE<RP@)'5P
M9&%T961?;F%M97,I.PH*("`@("`@("`@("`@("`@("\J(%)E;6]V92!A;GD@
M;F%M97,@=&AA="!H879E(&)E96X@8V]M<&QE=&5L>2!U;G-E="X@*B\*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1R96UO=F5D7VYA;65S(&%S("1N86UE
M*2!["B`@("`@("`@("`@("`@("`@("`@=6YS970H)'1H:7,M/F1A=&%;)'!E
M<FU)9%LG8VQA<W,G75U;)&YA;65=*3L*("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("`O*B!)9B!N;W1H:6YG('1O(&%C='5A;&QY('5P9&%T
M92!F:6YI<V@@=VET:"!T:&ES(&-A<V4N("HO"B`@("`@("`@("`@("`@("!I
M9B`H)'!E<FU?=F%L=65S(#T]/2!N=6QL*2!["B`@("`@("`@("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@+RH@3&]O<"!T:')O=6=H('1H92!N86UE<R!A;F0@=7!D871E('!E<FUI
M<W-I;VYS(&9O<B!E86-H+B`J+PH@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)'!E<FU?=F%L=65S(&%S("1N86UE(#T^("1N86UE7W9A;'5E<RD@>PH@("`@
M("`@("`@("`@("`@("`@("1P97)M261;)VYA;64G72`]("1N86UE.PH*("`@
M("`@("`@("`@("`@("`@("!I9B`H)'1Y<&4@/3T@)VUA=')I>"<I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!E<FU?='EP97,@87,@
M)'9A;"`]/B`D;&%B96PI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@A96UP='DH)&YA;65?=F%L=65S6R1V86Q=*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971097)M*"1P97)M260L
M("1V86PL(&9A;'-E*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G5N<V5T4&5R;2@D<&5R;4ED+"`D=F%L+"!F86QS92D["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1N86UE7W9A
M;'5E<RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%!E
M<FTH)'!E<FU)9"P@)&YA;65?=F%L=65S+"!F86QS92D["B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G5N<V5T4&5R;2@D<&5R;4ED+"!N=6QL+"!F86QS92D["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@1DE8344Z(&YE961S(&1O8W,*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T4&5R;2@D<&5R;4ED+"`D<&5R;6ES<VEO;BP@)'5P9&%T92`]
M('1R=64I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1P97)M260I*2![
M"B`@("`@("`@("`@(&EF("AE;7!T>2@D<&5R;4ED6R=N86UE)UTI*2!["B`@
M("`@("`@("`@("`@("!R971U<FX["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*"1T:&ES+3YG970H)W1Y<&4G*2`]/2`G;6%T<FEX)R`F)@H@("`@
M("`@("`@("`@("`@:7-S970H)'1H:7,M/F1A=&%;)'!E<FU)9%LG8VQA<W,G
M75U;)'!E<FU)9%LG;F%M92==72DI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3YD871A6R1P97)M261;)V-L87-S)UU=6R1P97)M261;)VYA;64G75T@?#T@
M)'!E<FUI<W-I;VX["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^9&%T85LD<&5R;4ED6R=C;&%S<R==75LD<&5R;4ED6R=N
M86UE)UU=(#T@)'!E<FUI<W-I;VX["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/F=E="@G='EP92<I(#T]
M("=M871R:7@G("8F"B`@("`@("`@("`@("`@("!I<W-E="@D=&AI<RT^9&%T
M85LD<&5R;4ED72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3YD871A6R1P
M97)M261=('P]("1P97)M:7-S:6]N.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/F1A=&%;)'!E<FU)9%T@/2`D<&5R;6ES
M<VEO;CL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1U
M<&1A=&4I('L*("`@("`@("`@("`@)'1H:7,M/G-A=F4H*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&25A-13H@;F5E9',@9&]C<PH@("`@
M("HO"B`@("!F=6YC=&EO;B!U;G-E=%!E<FTH)'!E<FU)9"P@)'!E<FUI<W-I
M;VXL("1U<&1A=&4@/2!T<G5E*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A
M>2@D<&5R;4ED*2D@>PH@("`@("`@("`@("!I9B`H96UP='DH)'!E<FU)9%LG
M;F%M92==*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&EF("@D=&AI<RT^9V5T*"=T>7!E)RD@/3T@)VUA
M=')I>"<I('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^9&%T
M85LD<&5R;4ED6R=C;&%S<R==75LD<&5R;4ED6R=N86UE)UU=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YD871A6R1P97)M261;)V-L87-S)UU=
M6R1P97)M261;)VYA;64G75T@)CT@?B1P97)M:7-S:6]N.PH@("`@("`@("`@
M("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^9&%T85LD<&5R;4ED6R=C;&%S
M<R==75LD<&5R;4ED6R=N86UE)UU=*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("!U;G-E="@D=&AI<RT^9&%T85LD<&5R;4ED6R=C;&%S<R==75LD<&5R
M;4ED6R=N86UE)UU=*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1U<&1A=&4I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G-A=F4H*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!U;G-E="@D=&AI<RT^9&%T85LD<&5R;4ED6R=C;&%S<R==75LD
M<&5R;4ED6R=N86UE)UU=*3L*("`@("`@("`@("`@("`@(&EF("@D=7!D871E
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-A=F4H*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(&EF("@D=&AI<RT^9V5T*"=T>7!E)RD@/3T@)VUA=')I>"<I
M('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^9&%T85LD<&5R
M;4ED72DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9&%T85LD<&5R
M;4ED72`F/2!^)'!E<FUI<W-I;VX["B`@("`@("`@("`@("`@("`@("`@:68@
M*"1U<&1A=&4I('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-A
M=F4H*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!U;G-E="@D
M=&AI<RT^9&%T85LD<&5R;4ED72D["B`@("`@("`@("`@("`@("!I9B`H)'5P
M9&%T92D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS879E*"D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!'<F%N=',@82!U<V5R(&%D9&ET:6]N86P@<&5R
M;6ES<VEO;G,@=&\@=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=7-E<B`@("`@("`@("!4:&4@=7-E<B!T;R!G<F%N="!A9&1I
M=&EO;F%L('!E<FUI<W-I;VYS"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('1O+@H@("`@("H@0'!A<F%M(&-O;G-T86YT("1P97)M:7-S
M:6]N("!4:&4@<&5R;6ES<VEO;B`H4$5235-?1$5,151%+"!E=&,N*2!T;R!A
M9&0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D=7!D871E("`@("`@(%=H971H
M97(@=&\@875T;VUA=&EC86QL>2!U<&1A=&4@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&)A8VME;F0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%D9%5S97)097)M:7-S:6]N*"1U<V5R+"`D<&5R;6ES<VEO;BP@
M)'5P9&%T92`]('1R=64I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1U<V5R
M*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@("`@(&EF
M("@D=&AI<RT^9V5T*"=T>7!E)RD@/3T@)VUA=')I>"<@)B8*("`@("`@("`@
M("`@:7-S970H)'1H:7,M/F1A=&%;)W5S97)S)UU;)'5S97)=*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^9&%T85LG=7-E<G,G75LD=7-E<ET@?#T@)'!E<FUI
M<W-I;VX["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/F1A
M=&%;)W5S97)S)UU;)'5S97)=(#T@)'!E<FUI<W-I;VX["B`@("`@("`@?0H*
M("`@("`@("!I9B`H)'5P9&%T92D@>PH@("`@("`@("`@("`D=&AI<RT^<V%V
M92@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=R86YT<R!G
M=65S=',@861D:71I;VYA;"!P97)M:7-S:6]N<R!T;R!T:&ES(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<&%R86T@8V]N<W1A;G0@)'!E<FUI<W-I;VX@(%1H
M92!P97)M:7-S:6]N("A015)-4U]$14Q%5$4L(&5T8RXI('1O(&%D9"X*("`@
M("`J($!P87)A;2!B;V]L96%N("1U<&1A=&4@("`@("`@5VAE=&AE<B!T;R!A
M=71O;6%T:6-A;&QY('5P9&%T92!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8F%C:V5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M861D1W5E<W1097)M:7-S:6]N*"1P97)M:7-S:6]N+"`D=7!D871E(#T@=')U
M92D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/F=E="@G='EP92<I(#T]("=M
M871R:7@G("8F"B`@("`@("`@("`@(&ES<V5T*"1T:&ES+3YD871A6R=G=65S
M="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^9&%T85LG9W5E<W0G72!\/2`D
M<&5R;6ES<VEO;CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI
M<RT^9&%T85LG9W5E<W0G72`]("1P97)M:7-S:6]N.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"1U<&1A=&4I('L*("`@("`@("`@("`@)'1H:7,M/G-A=F4H
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'<F%N=',@8W)E
M871O<G,@861D:71I;VYA;"!P97)M:7-S:6]N<R!T;R!T:&ES(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<&%R86T@8V]N<W1A;G0@)'!E<FUI<W-I;VX@(%1H
M92!P97)M:7-S:6]N("A015)-4U]$14Q%5$4L(&5T8RXI('1O(&%D9"X*("`@
M("`J($!P87)A;2!B;V]L96%N("1U<&1A=&4@("`@("`@5VAE=&AE<B!T;R!A
M=71O;6%T:6-A;&QY('5P9&%T92!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8F%C:V5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M861D0W)E871O<E!E<FUI<W-I;VXH)'!E<FUI<W-I;VXL("1U<&1A=&4@/2!T
M<G5E*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^9V5T*"=T>7!E)RD@/3T@
M)VUA=')I>"<@)B8*("`@("`@("`@("`@:7-S970H)'1H:7,M/F1A=&%;)V-R
M96%T;W(G72DI('L*("`@("`@("`@("`@)'1H:7,M/F1A=&%;)V-R96%T;W(G
M72!\/2`D<&5R;6ES<VEO;CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D=&AI<RT^9&%T85LG8W)E871O<B==(#T@)'!E<FUI<W-I;VX["B`@("`@
M("`@?0H*("`@("`@("!I9B`H)'5P9&%T92D@>PH@("`@("`@("`@("`D=&AI
M<RT^<V%V92@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=R
M86YT<R!A9&1I=&EO;F%L(&1E9F%U;'0@<&5R;6ES<VEO;G,@=&\@=&AI<R!O
M8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&-O;G-T86YT("1P97)M:7-S
M:6]N("!4:&4@<&5R;6ES<VEO;B`H4$5235-?1$5,151%+"!E=&,N*2!T;R!A
M9&0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D=7!D871E("`@("`@(%=H971H
M97(@=&\@875T;VUA=&EC86QL>2!U<&1A=&4@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&)A8VME;F0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%D9$1E9F%U;'1097)M:7-S:6]N*"1P97)M:7-S:6]N+"`D=7!D
M871E(#T@=')U92D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/F=E="@G='EP
M92<I(#T]("=M871R:7@G("8F"B`@("`@("`@("`@(&ES<V5T*"1T:&ES+3YD
M871A6R=D969A=6QT)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YD871A6R=D
M969A=6QT)UT@?#T@)'!E<FUI<W-I;VX["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'1H:7,M/F1A=&%;)V1E9F%U;'0G72`]("1P97)M:7-S:6]N
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"1U<&1A=&4I('L*("`@("`@("`@
M("`@)'1H:7,M/G-A=F4H*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!'<F%N=',@82!G<F]U<"!A9&1I=&EO;F%L('!E<FUI<W-I;VYS('1O
M('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1G
M<F]U<$ED("`@("`@5&AE(&ED(&]F('1H92!G<F]U<"!T;R!G<F%N="!A9&1I
M=&EO;F%L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('!E
M<FUI<W-I;VYS('1O+@H@("`@("H@0'!A<F%M(&-O;G-T86YT("1P97)M:7-S
M:6]N("!4:&4@<&5R;6ES<VEO;B`H4$5235-?1$5,151%+"!E=&,N*2!T;R!A
M9&0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D=7!D871E("`@("`@(%=H971H
M97(@=&\@875T;VUA=&EC86QL>2!U<&1A=&4@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&)A8VME;F0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%D9$=R;W5P4&5R;6ES<VEO;B@D9W)O=7!)9"P@)'!E<FUI<W-I
M;VXL("1U<&1A=&4@/2!T<G5E*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D
M9W)O=7!)9"DI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"1T:&ES+3YG970H)W1Y<&4G*2`]/2`G;6%T<FEX)R`F)@H@
M("`@("`@("`@("!I<W-E="@D=&AI<RT^9&%T85LG9W)O=7!S)UU;)&=R;W5P
M261=*2D@>PH@("`@("`@("`@("`D=&AI<RT^9&%T85LG9W)O=7!S)UU;)&=R
M;W5P261=('P]("1P97)M:7-S:6]N.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1T:&ES+3YD871A6R=G<F]U<',G75LD9W)O=7!)9%T@/2`D<&5R
M;6ES<VEO;CL*("`@("`@("!]"@H@("`@("`@(&EF("@D=7!D871E*2!["B`@
M("`@("`@("`@("1T:&ES+3YS879E*"D["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@4F5M;W9E<R!A('!E<FUI<W-I;VX@=&AA="!A('5S97(@
M8W5R<F5N=&QY(&AA<R!O;B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1U<V5R("`@("`@("`@(%1H92!U<V5R('1O(')E;6]V
M92!T:&4@<&5R;6ES<VEO;B!F<F]M+@H@("`@("H@0'!A<F%M(&-O;G-T86YT
M("1P97)M:7-S:6]N("!4:&4@<&5R;6ES<VEO;B`H4$5235-?1$5,151%+"!E
M=&,N*2!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R
M96UO=F4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D=7!D871E("`@("`@(%=H
M971H97(@=&\@875T;VUA=&EC86QL>2!U<&1A=&4@=&AE"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&)A8VME;F0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')E;6]V955S97)097)M:7-S:6]N*"1U<V5R+"`D<&5R;6ES
M<VEO;BP@)'5P9&%T92`]('1R=64I"B`@("!["B`@("`@("`@:68@*&5M<'1Y
M*"1U<V5R*2!\?"`A:7-S970H)'1H:7,M/F1A=&%;)W5S97)S)UU;)'5S97)=
M*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!I
M9B`H)'1H:7,M/F=E="@G='EP92<I(#T]("=M871R:7@G*2!["B`@("`@("`@
M("`@("1T:&ES+3YD871A6R=U<V5R<R==6R1U<V5R72`F/2!^)'!E<FUI<W-I
M;VX["B`@("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^9&%T85LG=7-E<G,G
M75LD=7-E<ETI*2!["B`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^9&%T
M85LG=7-E<G,G75LD=7-E<ETI.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@=6YS970H)'1H:7,M/F1A=&%;)W5S97)S)UU;
M)'5S97)=*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D=7!D871E*2!["B`@
M("`@("`@("`@("1T:&ES+3YS879E*"D["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@4F5M;W9E<R!A('!E<FUI<W-I;VX@=&AA="!G=65S=',@
M8W5R<F5N=&QY(&AA=F4@;VX@=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&-O;G-T86YT("1P97)M:7-S:6]N("!4:&4@<&5R;6ES<VEO;B`H
M4$5235-?1$5,151%+"!E=&,N*2!T;PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!R96UO=F4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M=7!D871E("`@("`@(%=H971H97(@=&\@875T;VUA=&EC86QL>2!U<&1A=&4@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)A8VME
M;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V94=U97-T4&5R;6ES<VEO
M;B@D<&5R;6ES<VEO;BP@)'5P9&%T92`]('1R=64I"B`@("!["B`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^9&%T85LG9W5E<W0G72DI('L*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3YG970H
M)W1Y<&4G*2`]/2`G;6%T<FEX)RD@>PH@("`@("`@("`@("`D=&AI<RT^9&%T
M85LG9W5E<W0G72`F/2!^)'!E<FUI<W-I;VX["B`@("`@("`@("`@(&EF("@D
M=7!D871E*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V%V92@I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@=6YS970H
M)'1H:7,M/F1A=&%;)V=U97-T)UTI.PH@("`@("`@("`@("!I9B`H)'5P9&%T
M92D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-A=F4H*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@
M82!P97)M:7-S:6]N('1H870@8W)E871O<G,@8W5R<F5N=&QY(&AA=F4@;VX@
M=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&-O;G-T86YT("1P
M97)M:7-S:6]N("!4:&4@<&5R;6ES<VEO;B`H4$5235-?1$5,151%+"!E=&,N
M*2!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R96UO
M=F4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D=7!D871E("`@("`@(%=H971H
M97(@=&\@875T;VUA=&EC86QL>2!U<&1A=&4@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&)A8VME;F0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(')E;6]V94-R96%T;W)097)M:7-S:6]N*"1P97)M:7-S:6]N+"`D
M=7!D871E(#T@=')U92D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3YD871A6R=C<F5A=&]R)UTI*2!["B`@("`@("`@("`@(')E='5R;CL*("`@
M("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^9V5T*"=T>7!E)RD@/3T@)VUA
M=')I>"<I('L*("`@("`@("`@("`@)'1H:7,M/F1A=&%;)V-R96%T;W(G72`F
M/2!^)'!E<FUI<W-I;VX["B`@("`@("`@("`@(&EF("@D=7!D871E*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^<V%V92@I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@=6YS970H)'1H:7,M/F1A=&%;
M)V-R96%T;W(G72D["B`@("`@("`@("`@(&EF("@D=7!D871E*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^<V%V92@I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!A(&1E9F%U;'0@
M<&5R;6ES<VEO;B!O;B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R
M86T@8V]N<W1A;G0@)'!E<FUI<W-I;VX@(%1H92!P97)M:7-S:6]N("A015)-
M4U]$14Q%5$4L(&5T8RXI('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(')E;6]V92X*("`@("`J($!P87)A;2!B;V]L96%N("1U<&1A
M=&4@("`@("`@5VAE=&AE<B!T;R!A=71O;6%T:6-A;&QY('5P9&%T92!T:&4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8F%C:V5N9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E1&5F875L=%!E<FUI<W-I;VXH
M)'!E<FUI<W-I;VXL("1U<&1A=&4@/2!T<G5E*0H@("`@>PH@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/F1A=&%;)V1E9F%U;'0G72DI('L*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3YG970H
M)W1Y<&4G*2`]/2`G;6%T<FEX)RD@>PH@("`@("`@("`@("`D=&AI<RT^9&%T
M85LG9&5F875L="==("8]('XD<&5R;6ES<VEO;CL*("`@("`@("`@("`@:68@
M*"1U<&1A=&4I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS879E*"D["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!U;G-E
M="@D=&AI<RT^9&%T85LG9&5F875L="==*3L*("`@("`@("`@("`@:68@*"1U
M<&1A=&4I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS879E*"D["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO
M=F5S(&$@<&5R;6ES<VEO;B!T:&%T(&$@9W)O=7`@8W5R<F5N=&QY(&AA<R!O
M;B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M9W)O=7!)9"`@("`@(%1H92!I9"!O9B!T:&4@9W)O=7`@=&\@<F5M;W9E('1H
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!P97)M:7-S
M:6]N(&9R;VTN"B`@("`@*B!`<&%R86T@8V]N<W1A;G0@)'!E<FUI<W-I;VX@
M(%1H92!P97)M:7-S:6]N("A015)-4U]$14Q%5$4L(&5T8RXI('1O"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E;6]V92X*("`@("`J
M($!P87)A;2!B;V]L96%N("1U<&1A=&4@("`@("`@5VAE=&AE<B!T;R!A=71O
M;6%T:6-A;&QY('5P9&%T92!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8F%C:V5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M
M;W9E1W)O=7!097)M:7-S:6]N*"1G<F]U<$ED+"`D<&5R;6ES<VEO;BP@)'5P
M9&%T92`]('1R=64I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1G<F]U<$ED
M*2!\?"`A:7-S970H)'1H:7,M/F1A=&%;)V=R;W5P<R==6R1G<F]U<$ED72DI
M('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"1T:&ES+3YG970H)W1Y<&4G*2`]/2`G;6%T<FEX)RD@>PH@("`@("`@("`@
M("`D=&AI<RT^9&%T85LG9W)O=7!S)UU;)&=R;W5P261=("8]('XD<&5R;6ES
M<VEO;CL*("`@("`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3YD871A6R=G<F]U
M<',G75LD9W)O=7!)9%TI*2!["B`@("`@("`@("`@("`@("!U;G-E="@D=&AI
M<RT^9&%T85LG9W)O=7!S)UU;)&=R;W5P261=*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H)'5P9&%T92D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/G-A=F4H*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@('5N<V5T*"1T:&ES+3YD871A6R=G<F]U<',G75LD9W)O=7!)
M9%TI.PH@("`@("`@("`@("!I9B`H)'5P9&%T92D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/G-A=F4H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@87)R87D@;V8@86QL('5S
M97(@<&5R;6ES<VEO;G,@;VX@=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)'!E<FT@($QI<W0@;VYL>2!U<V5R<R!W:71H('1H
M:7,@<&5R;6ES<VEO;B!L979E;"X*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!$969A=6QT<R!T;R!A;&P@=7-E<G,N"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@06QL('5S97(@<&5R;6ES<VEO;G,@9F]R('1H:7,@;V)J
M96-T+"!I;F1E>&5D(&)Y('5S97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%5S97)097)M:7-S:6]N<R@D<&5R;2`](&YU;&PI"B`@("!["B`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^9&%T85LG=7-E<G,G72D@?'P@(6ES7V%R<F%Y
M*"1T:&ES+3YD871A6R=U<V5R<R==*2D@>PH@("`@("`@("`@("!R971U<FX@
M87)R87DH*3L*("`@("`@("!](&5L<V5I9B`H(21P97)M*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^9&%T85LG=7-E<G,G73L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D=7-E<G,@/2!A<G)A>2@I.PH@("`@("`@("`@
M("!F;W)E86-H("@D=&AI<RT^9&%T85LG=7-E<G,G72!A<R`D=7-E<B`]/B`D
M=7!E<FTI('L*("`@("`@("`@("`@("`@(&EF("@D=7!E<FT@)B`D<&5R;2D@
M>PH@("`@("`@("`@("`@("`@("`@("1U<V5R<ULD=7-E<ET@/2`D=7!E<FT[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@
M<F5T=7)N("1U<V5R<SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!G=65S="!P97)M:7-S:6]N<R!O;B!T:&ES(&]B:F5C
M="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!G=65S="!P
M97)M:7-S:6]N<R!O;B!T:&ES(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T1W5E<W1097)M:7-S:6]N<R@I"B`@("!["B`@("`@("`@<F5T=7)N
M("%E;7!T>2@D=&AI<RT^9&%T85LG9W5E<W0G72D@/PH@("`@("`@("`@("`D
M=&AI<RT^9&%T85LG9W5E<W0G72`Z"B`@("`@("`@("`@(&YU;&P["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C<F5A=&]R('!E<FUI<W-I
M;VYS(&]N('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@:6YT
M96=E<B`@5&AE(&-R96%T;W(@<&5R;6ES<VEO;G,@;VX@=&AI<R!O8FIE8W0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-R96%T;W)097)M:7-S:6]N<R@I
M"B`@("!["B`@("`@("`@<F5T=7)N("%E;7!T>2@D=&AI<RT^9&%T85LG8W)E
M871O<B==*2`_"B`@("`@("`@("`@("1T:&ES+3YD871A6R=C<F5A=&]R)UT@
M.@H@("`@("`@("`@("!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@9&5F875L="!P97)M:7-S:6]N<R!O;B!T:&ES(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!D969A=6QT('!E
M<FUI<W-I;VYS(&]N('1H:7,@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971$969A=6QT4&5R;6ES<VEO;G,H*0H@("`@>PH@("`@("`@(')E='5R
M;B`A96UP='DH)'1H:7,M/F1A=&%;)V1E9F%U;'0G72D@/PH@("`@("`@("`@
M("`D=&AI<RT^9&%T85LG9&5F875L="==(#H*("`@("`@("`@("`@;G5L;#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@87)R87D@;V8@86QL
M(&=R;W5P('!E<FUI<W-I;VYS(&]N('1H:7,@;V)J96-T+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1P97)M("!,:7-T(&]N;'D@=7-E<G,@=VET
M:"!T:&ES('!E<FUI<W-I;VX@;&5V96PN"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@1&5F875L=',@=&\@86QL('5S97)S+@H@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@($%L;"!G<F]U<"!P97)M:7-S:6]N<R!F;W(@=&AI
M<R!O8FIE8W0L(&EN9&5X960@8GD@9W)O=7`N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$=R;W5P4&5R;6ES<VEO;G,H)'!E<FT@/2!N=6QL*0H@("`@>PH@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/F1A=&%;)V=R;W5P<R==*2!\?`H@
M("`@("`@("`@("`A:7-?87)R87DH)'1H:7,M/F1A=&%;)V=R;W5P<R==*2D@
M>PH@("`@("`@("`@("!R971U<FX@87)R87DH*3L*("`@("`@("!](&5L<V5I
M9B`H(21P97)M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9&%T85LG
M9W)O=7!S)UT["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&=R;W5P
M<R`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YD871A
M6R=G<F]U<',G72!A<R`D9W)O=7`@/3X@)&=P97)M*2!["B`@("`@("`@("`@
M("`@("!I9B`H)&=P97)M("8@)'!E<FTI('L*("`@("`@("`@("`@("`@("`@
M("`D9W)O=7!S6R1G<F]U<%T@/2`D9W!E<FT["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1G<F]U<',["B`@
M("`@("`@?0H@("`@?0H*?0H````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]097)M<R]522YP:'``````````````````````````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P-#4R-#,`,3`U,34T,S,W-#8`,#(Q-C$S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!4:&4@4&5R;7-?54DZ.B!C;&%S<R!P<F]V:61E<R!522!M971H;V1S
M(&9O<B!T:&4@2&]R9&4@<&5R;6ES<VEO;G,*("H@<WES=&5M+@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`L=B`Q+C(W+C(N
M."`R,#`V+S`Q+S`Q(#(Q.C(X.C,Q(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#(N,0H@*B!`
M<&%C:V%G92!(;W)D95]097)M<PH@*B\*8VQA<W,@4&5R;7-?54D@>PH*("`@
M("\J*@H@("`@("H@5&AE(%!E<FUS(&]B:F5C="!W92=R92!D:7-P;&%Y:6YG
M(%5)('-T=69F(&9O<BX*("`@("`J"B`@("`@*B!`=F%R(%!E<FUS"B`@("`@
M*B\*("`@('9A<B`D7W!E<FUS.PH*("`@("\J*@H@("`@("H@5&AE($AO<F1E
M7T9O<FT@;V)J96-T('1H870@=VEL;"!B92!U<V5D(&9O<B!D:7-P;&%Y:6YG
M('1H92!E9&ET(&9O<FTN"B`@("`@*@H@("`@("H@0'9A<B!(;W)D95]&;W)M
M"B`@("`@*B\*("`@('9A<B`D7V9O<FT@/2!N=6QL.PH*("`@("\J*@H@("`@
M("H@5&AE(%9A<FEA8FQE<R!O8FIE8W0@=7-E9"!I;B!(;W)D95]&;W)M+@H@
M("`@("H*("`@("`J($!V87(@5F%R:6%B;&5S"B`@("`@*B\*("`@('9A<B`D
M7W9A<G,@/2!N=6QL.PH*("`@("\J*@H@("`@("H@5&AE('!E<FUI<W-I;VX@
M='EP92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)%]T>7!E(#T@)VUA=')I>"<["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U
M8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@4&5R;7,@)'!E<FUS("!4:&4@
M4&5R;7,@;V)J96-T('1O(&1I<W!L87D@54D@<W1U9F8@9F]R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!097)M<U]522@F)'!E<FUS*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?<&5R;7,@/2`F)'!E<FUS.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N(&$@2&]R9&5?5')E92!R97!R97-E;G1A=&EO;B!O9B!T:&4@
M<&5R;6ES<VEO;G,@=')E92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&AT;6P@<VAO=VEN9R!T:&4@<&5R;6ES<VEO;G,@87,@82!(;W)D
M95]4<F5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97)4<F5E*"1C=7)R
M96YT(#T@1$%40512145?4D]/5"D*("`@('L*("`@("`@("!G;&]B86P@)')E
M9VES=')Y.PH*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U1R964N<&AP
M)SL*"B`@("`@("`@+RH@1V5T('1H92!P97)M<R!T<F5E+B`J+PH@("`@("`@
M("1N;V1E<R`]("8D=&AI<RT^7W!E<FUS+3YG9714<F5E*"D["@H@("`@("`@
M("1I8V]N9&ER(#T@87)R87DH)VEC;VYD:7(G(#T^("1'3$]"04Q36R=R96=I
M<W1R>2==+3YG971);6%G941I<B@I*3L*("`@("`@("`D<&5R;7-?;F]D92`]
M("1I8V]N9&ER("L@87)R87DH)VEC;VXG(#T^("=P97)M<RYP;F<G*3L*("`@
M("`@("`D861D(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`G*3L*("`@("`@("`D961I="`]($AO<F1E.CIA<'!L
M:6-A=&EO;E5R;"@G861M:6XO<&5R;7,O961I="YP:'`G*3L*("`@("`@("`D
M9&5L971E(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=A9&UI;B]P97)M<R]D
M96QE=&4N<&AP)RD["B`@("`@("`@)&5D:71?:6UG(#T@2&]R9&4Z.FEM9R@G
M961I="YP;F<G+"!?*")%9&ET(%!E<FUI<W-I;VXB*2D["B`@("`@("`@)&1E
M;&5T95]I;6<@/2!(;W)D93HZ:6UG*"=D96QE=&4N<&YG)RP@7R@B1&5L971E
M(%!E<FUI<W-I;VXB*2D["@H@("`@("`@("\J(%-E="!U<"!T:&4@=')E92X@
M*B\*("`@("`@("`D=')E92`]("9(;W)D95]4<F5E.CIS:6YG;&5T;VXH)W!E
M<FUS7W5I)RP@)VIA=F%S8W)I<'0G*3L*("`@("`@("`D=')E92T^<V5T3W!T
M:6]N*&%R<F%Y*"=A;'1E<FYA=&4G(#T^('1R=64L("=H:61E2&5A9&5R<R<@
M/3X@=')U92DI.PH@("`@("`@("1T<F5E+3YS971(96%D97(H87)R87DH87)R
M87DH)W=I9'1H)R`]/B`G-3`E)RDI*3L*"B`@("`@("`@9F]R96%C:"`H)&YO
M9&5S(&%S("1P97)M7VED(#T^("1N;V1E*2!["B`@("`@("`@("`@("1N;V1E
M7V-L87-S(#T@*"1C=7)R96YT(#T]("1P97)M7VED*2`_(&%R<F%Y*"=C;&%S
M<R<@/3X@)W-E;&5C=&5D)RD@.B!A<G)A>2@I.PH@("`@("`@("`@("!I9B`H
M)'!E<FU?:60@/3T@1$%40512145?4D]/5"D@>PH@("`@("`@("`@("`@("`@
M)&%D9%]I;6<@/2!(;W)D93HZ:6UG*"=P97)M<RYP;F<G+"!?*")!9&0@3F5W
M(%!E<FUI<W-I;VXB*2D["B`@("`@("`@("`@("`@("`D861D7VQI;FL@/2!(
M;W)D93HZ;&EN:RA5=&EL.CIA9&1087)A;65T97(H)&%D9"P@)W!E<FU?:60G
M+"`D<&5R;5]I9"DL(%\H(D%D9"!.97<@4&5R;6ES<VEO;B(I*2`N("1A9&1?
M:6UG("X@)SPO83XG.PH@("`@("`@("`@("`@("`@)&)A<V5?;F]D95]P87)A
M;7,@/2`D:6-O;F1I<B`K(&%R<F%Y*"=I8V]N)R`]/B`G861M:6YI<W1R871I
M;VXN<&YG)RD["@H@("`@("`@("`@("`@("`@)'1R964M/F%D9$YO9&4H)'!E
M<FU?:60L(&YU;&PL(%\H(D%L;"!097)M:7-S:6]N<R(I+"`P+"!T<G5E+"`D
M8F%S95]N;V1E7W!A<F%M<R`K("1N;V1E7V-L87-S+"!A<G)A>2@D861D7VQI
M;FLI*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1P
M87)E;G1?:60@/2`D=&AI<RT^7W!E<FUS+3Y?9&%T871R964M/F=E=%!A<F5N
M="@D;F]D92D["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D<&%R96YT7VED
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@2&]R9&4Z
M.F9A=&%L*"1P87)E;G1?:60L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)&%D9%]I;6<@/2!(;W)D
M93HZ:6UG*"=P97)M<RYP;F<G+"!?*")!9&0@0VAI;&0@4&5R;6ES<VEO;B(I
M*3L*("`@("`@("`@("`@("`@("1A9&1?;&EN:R`]($AO<F1E.CIL:6YK*%5T
M:6PZ.F%D9%!A<F%M971E<B@D861D+"`G<&5R;5]I9"<L("1P97)M7VED*2P@
M7R@B061D($-H:6QD(%!E<FUI<W-I;VXB*2D@+B`D861D7VEM9R`N("<\+V$^
M)SL*("`@("`@("`@("`@("`@("1E9&ET7VQI;FL@/2!(;W)D93HZ;&EN:RA5
M=&EL.CIA9&1087)A;65T97(H)&5D:70L("=P97)M7VED)RP@)'!E<FU?:60I
M+"!?*")%9&ET(%!E<FUI<W-I;VXB*2D@+B`D961I=%]I;6<@+B`G/"]A/B<[
M"B`@("`@("`@("`@("`@("`D9&5L971E7VQI;FL@/2!(;W)D93HZ;&EN:RA5
M=&EL.CIA9&1087)A;65T97(H)&1E;&5T92P@)W!E<FU?:60G+"`D<&5R;5]I
M9"DL(%\H(D1E;&5T92!097)M:7-S:6]N(BDI("X@)&1E;&5T95]I;6<@+B`G
M/"]A/B<["B`@("`@("`@("`@("`@("`D<&5R;7-?97AT<F$@/2!A<G)A>2@D
M861D7VQI;FLL("1E9&ET7VQI;FLL("1D96QE=&5?;&EN:RD["B`@("`@("`@
M("`@("`@("`D;F%M92`]("1T:&ES+3Y?<&5R;7,M/F=E=%1I=&QE*"1N;V1E
M*3L*"B`@("`@("`@("`@("`@("`D=')E92T^861D3F]D92@D<&5R;5]I9"P@
M)'!A<F5N=%]I9"P@)&YA;64L('-U8G-T<E]C;W5N="@D;F]D92P@)SHG*2`K
M(#$L(&9A;'-E+"`D<&5R;7-?;F]D92`K("1N;V1E7V-L87-S+"`D<&5R;7-?
M97AT<F$I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=')E
M92T^<V]R="@G;&%B96PG*3L*"B`@("`@("`@<F5T=7)N("1T<F5E+3YR96YD
M97)4<F5E*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@86X@97AI<W1I
M;F<@9F]R;2!O8FIE8W0@=&\@=7-E(&9O<B!T:&4@961I="!F;W)M+@H@("`@
M("H*("`@("`J($!P87)A;2!(;W)D95]&;W)M("1F;W)M("!!;B!E>&ES=&EN
M9R!(;W)D95]&;W)M(&]B:F5C="!T;R!U<V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-E=$9O<FTH)B1F;W)M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9F]R
M;2`]("8D9F]R;3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!A;B!E>&ES
M=&EN9R!V87)S(&]B:F5C="!T;R!U<V4@9F]R('1H92!E9&ET(&9O<FTN"B`@
M("`@*@H@("`@("H@0'!A<F%M(%9A<FEA8FQE<R`D=F%R<R`@06X@97AI<W1I
M;F<@5F%R:6%B;&5S(&]B:F5C="!T;R!U<V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-E=%9A<G,H)B1V87)S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=F%R
M<R`]("8D=F%R<SL*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!A(&9O
M<FT@=&\@861D(&$@<&5R;6ES<VEO;BX*("`@("`J"B`@("`@*B!`<&%R86T@
M4&5R;7,@)'!E<FUI<W-I;VX*("`@("`J($!P87)A;2!S=')I;F<@)&9O<F-E
M7V-H;VEC92`@268@=&AE('!E<FUI<W-I;VX@=&\@8F4@861D960@8V%N(&)E
M(&]N92!O9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!M
M86YY+"!S971T:6YG('1H:7,@=VEL;"!F;W)C92!T:&4@8VAO:6-E('1O"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]N92!P87)T:6-U
M;&%R+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971U<$%D9$9O<FTH)'!E<FUI
M<W-I;VXL("1F;W)C95]C:&]I8V4@/2!N=6QL*0H@("`@>PH@("`@("`@("\J
M($EN:71I86QI<V4@9F]R;2!I9B!R97%U:7)E9"X@*B\*("`@("`@("`D=&AI
M<RT^7V9O<FU);FET*"D["@H@("`@("`@("1T:&ES+3Y?9F]R;2T^<V5T5&ET
M;&4H<W!R:6YT9BA?*")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<
M(B(I+"`D=&AI<RT^7W!E<FUS+3YG9714:71L92@D<&5R;6ES<VEO;BT^9V5T
M3F%M92@I*2DI.PH@("`@("`@("1T:&ES+3Y?9F]R;2T^<V5T0G5T=&]N<RA?
M*")!9&0B*2P@=')U92D["B`@("`@("`@)'1H:7,M/E]V87)S+3YS970H)W!E
M<FU?:60G+"`D=&AI<RT^7W!E<FUS+3YG971097)M:7-S:6]N260H)'!E<FUI
M<W-I;VXI*3L*("`@("`@("`D=&AI<RT^7V9O<FTM/F%D9$AI9&1E;B@G)RP@
M)W!E<FU?:60G+"`G=&5X="<L(&9A;'-E*3L*"B`@("`@("`@+RH@4V5T('5P
M('1H92!A8W1U86P@8VAI;&0@861D:6YG(&9I96QD+B`J+PH@("`@("`@("1C
M:&EL9%]P97)M<R`]("1T:&ES+3Y?<&5R;7,M/F=E=$%V86EL86)L92@D<&5R
M;6ES<VEO;BT^9V5T3F%M92@I*3L*("`@("`@("!I9B`H)&-H:6QD7W!E<FUS
M(#T]/2!F86QS92D@>PH@("`@("`@("`@("`O*B!&86QS92P@<V\@;F\@8VAI
M;&1S(&%R92!T;R!B92!A9&1E9"!B96QO=R!T:&ES(&QE=F5L+B`J+PH@("`@
M("`@("`@("`D=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE*%\H(E!E<FUI<W-I
M;VXB*2P@)V-H:6QD)RP@)VEN=F%L:60G+"!T<G5E+"!F86QS92P@;G5L;"P@
M87)R87DH7R@B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R
M;6ES<VEO;BXB*2DI.PH@("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D8VAI
M;&1?<&5R;7,I*2!["B`@("`@("`@("`@(&EF("@A96UP='DH)&9O<F-E7V-H
M;VEC92DI('L*("`@("`@("`@("`@("`@("\J($-H;VEC92!A<G)A>2!A=F%I
M;&%B;&4L(&)U="!C:&]I8V4@8F5I;F<@9F]R8V5D+B`J+PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]V87)S+3YS970H)V-H:6QD)RP@)&9O<F-E7V-H;VEC
M92D["B`@("`@("`@("`@("`@("`D=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE
M*%\H(E!E<FUI<W-I;VYS(BDL("=C:&EL9"<L("=E;G5M)RP@=')U92P@=')U
M92P@;G5L;"P@87)R87DH)&-H:6QD7W!E<FUS*2D["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`O*B!#:&]I8V4@87)R87D@879A:6QA
M8FQE+"!S;R!S970@=7`@96YU;2!F:65L9"X@*B\*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?9F]R;2T^861D5F%R:6%B;&4H7R@B4&5R;6ES<VEO;G,B*2P@
M)V-H:6QD)RP@)V5N=6TG+"!T<G5E+"!F86QS92P@;G5L;"P@87)R87DH)&-H
M:6QD7W!E<FUS*2D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!&=6YC=&EO;B!T;R!V86QI9&%T92!A;GD@861D(&9O
M<FT@:6YP=70N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@16ET:&5R
M(&9A;'-E(&EF('1H92!F;W)M(&1O97,@;F]T('9A;&ED871E(&-O<G)E8W1L
M>2!O<@H@("`@("H@("`@("`@("`@("`@("`@86X@87)R87D@=VET:"!A;&P@
M=&AE(&9O<FT@=F%L=65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!V86QI9&%T
M94%D9$9O<FTH)B1I;F9O*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/E]F
M;W)M+3YV86QI9&%T92@D=&AI<RT^7W9A<G,I*2!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?9F]R;2T^
M9V5T26YF;R@D=&AI<RT^7W9A<G,L("1I;F9O*3L*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!A('!E<FUI<W-I
M;VX@961I=&EN9R!F;W)M+@H@("`@("H*("`@("`J($!P87)A;2!$871A5')E
M94]B:F5C=%]097)M:7-S:6]N("1P97)M:7-S:6]N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E='5P161I=$9O<FTH)'!E<FUI<W-I;VXI"B`@("!["B`@("`@
M("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@+RH@26YI=&EA;&ES92!F
M;W)M(&EF(')E<75I<F5D+B`J+PH@("`@("`@("1T:&ES+3Y?9F]R;4EN:70H
M*3L*"B`@("`@("`@)'1H:7,M/E]F;W)M+3YS971"=71T;VYS*%\H(E5P9&%T
M92(I+"!T<G5E*3L*("`@("`@("`D<&5R;5]I9"`]("1T:&ES+3Y?<&5R;7,M
M/F=E=%!E<FUI<W-I;VY)9"@D<&5R;6ES<VEO;BD["B`@("`@("`@)'1H:7,M
M/E]F;W)M+3YA9&1(:61D96XH)R<L("=P97)M7VED)RP@)W1E>'0G+"!F86QS
M92D["@H@("`@("`@("\J($=E="!P97)M:7-S:6]N(&-O;F9I9W5R871I;VXN
M("HO"B`@("`@("`@)'1H:7,M/E]T>7!E(#T@)'!E<FUI<W-I;VXM/F=E="@G
M='EP92<I.PH@("`@("`@("1P87)A;7,@/2`D<&5R;6ES<VEO;BT^9V5T*"=P
M87)A;7,G*3L*"B`@("`@("`@+RH@1&5F875L="!P97)M:7-S:6]N<RX@*B\*
M("`@("`@("`D<&5R;5]V86P@/2`D<&5R;6ES<VEO;BT^9V5T1&5F875L=%!E
M<FUI<W-I;VYS*"D["B`@("`@("`@)'1H:7,M/E]F;W)M+3YS971396-T:6]N
M*"=D969A=6QT)RP@7R@B06QL($%U=&AE;G1I8V%T960@57-E<G,B*2P@2&]R
M9&4Z.FEM9R@G<&5R;7,N<&YG)RP@)R<L("<G+"`D<F5G:7-T<GDM/F=E=$EM
M86=E1&ER*"=H;W)D92<I*2P@9F%L<V4I.PH*("`@("`@("`O*B!792!-55-4
M('5S92`G9&5F;'0G(&9O<B!T:&4@=F%R:6%B;&4@;F%M92!B96-A=7-E("=D
M969A=6QT)R!I<R!A"B`@("`@("`@("H@<F5S97)V960@=V]R9"!I;B!*879A
M4V-R:7!T+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W1Y<&4@/3T@)VUA=')I
M>"<I('L*("`@("`@("`@("`@+RH@4V5T('5P('1H92!C;VQU;6YS(&9O<B!T
M:&4@<&5R;6ES<VEO;G,@;6%T<FEX+B`J+PH@("`@("`@("`@("`D8V]L<R`]
M(%!E<FUS.CIG971097)M<T%R<F%Y*"D["@H@("`@("`@("`@("`O*B!$969I
M;F4@82!S:6YG;&4@;6%T<FEX(')O=R!F;W(@9&5F875L="!P97)M<RX@*B\*
M("`@("`@("`@("`@)&UA=')I>"`](&%R<F%Y*"D["B`@("`@("`@("`@("1M
M871R:7A;,%T@/2!097)M<SHZ:6YT96=E<E1O07)R87DH)'!E<FU?=F%L*3L*
M("`@("`@("`@("`@)'1H:7,M/E]F;W)M+3YA9&1687)I86)L92@G)RP@)V1E
M9FQT)RP@)VUA=')I>"<L(&9A;'-E+"!F86QS92P@;G5L;"P@87)R87DH)&-O
M;',L(&%R<F%Y*#`@/3X@)R<I+"`D;6%T<FEX*2D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'9A<B`]("8D=&AI<RT^7V9O<FTM/F%D9%9A<FEA
M8FQE*"<G+"`G9&5F;'0G+"`D=&AI<RT^7W1Y<&4L(&9A;'-E+"!F86QS92P@
M;G5L;"P@)'!A<F%M<RD["B`@("`@("`@("`@("1V87(M/G-E=$1E9F%U;'0H
M)'!E<FU?=F%L*3L*("`@("`@("!]"@H@("`@("`@("\J($=U97-T('!E<FUI
M<W-I;VYS+B`J+PH@("`@("`@("1P97)M7W9A;"`]("1P97)M:7-S:6]N+3YG
M971'=65S=%!E<FUI<W-I;VYS*"D["B`@("`@("`@)'1H:7,M/E]F;W)M+3YS
M971396-T:6]N*"=G=65S="<L(%\H(D=U97-T(%!E<FUI<W-I;VYS(BDL("<G
M+"!F86QS92D["@H@("`@("`@(&EF("@D=&AI<RT^7W1Y<&4@/3T@)VUA=')I
M>"<I('L*("`@("`@("`@("`@+RH@1&5F:6YE(&$@<VEN9VQE(&UA=')I>"!R
M;W<@9F]R(&=U97-T('!E<FUS+B`J+PH@("`@("`@("`@("`D;6%T<FEX(#T@
M87)R87DH*3L*("`@("`@("`@("`@)&UA=')I>%LP72`](%!E<FUS.CII;G1E
M9V5R5&]!<G)A>2@D<&5R;5]V86PI.PH@("`@("`@("`@("`D=&AI<RT^7V9O
M<FTM/F%D9%9A<FEA8FQE*"<G+"`G9W5E<W0G+"`G;6%T<FEX)RP@9F%L<V4L
M(&9A;'-E+"!N=6QL+"!A<G)A>2@D8V]L<RP@87)R87DH,"`]/B`G)RDL("1M
M871R:7@I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=F%R(#T@
M)B1T:&ES+3Y?9F]R;2T^861D5F%R:6%B;&4H)R<L("=G=65S="<L("1T:&ES
M+3Y?='EP92P@9F%L<V4L(&9A;'-E+"!N=6QL+"`D<&%R86US*3L*("`@("`@
M("`@("`@)'9A<BT^<V5T1&5F875L="@D<&5R;5]V86PI.PH@("`@("`@('T*
M"B`@("`@("`@+RH@3V)J96-T(&-R96%T;W(@<&5R;6ES<VEO;G,N("HO"B`@
M("`@("`@)'!E<FU?=F%L(#T@)'!E<FUI<W-I;VXM/F=E=$-R96%T;W)097)M
M:7-S:6]N<R@I.PH@("`@("`@("1T:&ES+3Y?9F]R;2T^<V5T4V5C=&EO;B@G
M8W)E871O<B<L(%\H(D-R96%T;W(@4&5R;6ES<VEO;G,B*2P@2&]R9&4Z.FEM
M9R@G=7-E<BYP;F<G+"`G)RP@)R<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H
M)VAO<F1E)RDI+"!F86QS92D["@H@("`@("`@(&EF("@D=&AI<RT^7W1Y<&4@
M/3T@)VUA=')I>"<I('L*("`@("`@("`@("`@+RH@1&5F:6YE(&$@<VEN9VQE
M(&UA=')I>"!R;W<@9F]R(&-R96%T;W(@<&5R;7,N("HO"B`@("`@("`@("`@
M("1M871R:7@@/2!A<G)A>2@I.PH@("`@("`@("`@("`D;6%T<FEX6S!=(#T@
M4&5R;7,Z.FEN=&5G97)4;T%R<F%Y*"1P97)M7W9A;"D["B`@("`@("`@("`@
M("1T:&ES+3Y?9F]R;2T^861D5F%R:6%B;&4H)R<L("=C<F5A=&]R)RP@)VUA
M=')I>"<L(&9A;'-E+"!F86QS92P@;G5L;"P@87)R87DH)&-O;',L(&%R<F%Y
M*#`@/3X@)R<I+"`D;6%T<FEX*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'9A<B`]("8D=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE*"<G+"`G
M8W)E871O<B<L("1T:&ES+3Y?='EP92P@9F%L<V4L(&9A;'-E+"!N=6QL+"`D
M<&%R86US*3L*("`@("`@("`@("`@)'9A<BT^<V5T1&5F875L="@D<&5R;5]V
M86PI.PH@("`@("`@('T*"B`@("`@("`@+RH@57-E<G,@<&5R;6ES<VEO;G,N
M("HO"B`@("`@("`@)'!E<FU?=F%L(#T@)'!E<FUI<W-I;VXM/F=E=%5S97)0
M97)M:7-S:6]N<R@I.PH@("`@("`@("1T:&ES+3Y?9F]R;2T^<V5T4V5C=&EO
M;B@G=7-E<G,G+"!?*"));F1I=FED=6%L(%5S97)S(BDL($AO<F1E.CII;6<H
M)W5S97(N<&YG)RP@)R<L("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H
M;W)D92<I*2P@9F%L<V4I.PH@("`@("`@("1A=71H(#T@)D%U=&@Z.G-I;F=L
M971O;B@D1TQ/0D%,4ULG8V]N9B==6R=A=71H)UU;)V1R:79E<B==*3L*("`@
M("`@("!I9B`H)&%U=&@M/FAA<T-A<&%B:6QI='DH)VQI<W0G*2D@>PH@("`@
M("`@("`@("`O*B!4:&4@875T:"!D<FEV97(@:&%S(&QI<W0@8V%P86)I;&ET
M:65S('-O('-E="!U<"!A;B!A<G)A>2!W:&EC:`H@("`@("`@("`@("`@*B!T
M:&4@;6%T<FEX(&9I96QD('1Y<&4@=VEL;"!R96-O9VYI<V4@=&\@<V5T('5P
M(&%N(&5N=6T@8F]X(&9O<@H@("`@("`@("`@("`@*B!A9&1I;F<@;F5W('5S
M97)S('1O('1H92!P97)M:7-S:6]N<R!M871R:7@N("HO"B`@("`@("`@("`@
M("1N97=?=7-E<G,@/2!A<G)A>2@I.PH@("`@("`@("`@("`D=7-E<E]L:7-T
M(#T@)&%U=&@M/FQI<W15<V5R<R@I.PH@("`@("`@("`@("!I9B`H:7-?82@D
M=7-E<E]L:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D
M;F5W7W5S97)S(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@('-O<G0H)'5S97)?;&ES="D["B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D=7-E<E]L:7-T(&%S("1U<V5R*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D<&5R;5]V86Q;)'5S97)=*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D;F5W7W5S97)S6R1U<V5R72`]("1U<V5R.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J($YO(&QI
M<W0@8V%P86)I;&ET:65S+"!S971T:6YG('1O('1R=64@<V\@=&AA="!T:&4@
M;6%T<FEX(&9I96QD"B`@("`@("`@("`@("`J('1Y<&4@=VEL;"!O9F9E<B!A
M('1E>'0@:6YP=70@8F]X(&9O<B!A9&1I;F<@;F5W('5S97)S+B`J+PH@("`@
M("`@("`@("`D;F5W7W5S97)S(#T@=')U93L*("`@("`@("!]"@H@("`@("`@
M(&EF("@D=&AI<RT^7W1Y<&4@/3T@)VUA=')I>"<I('L*("`@("`@("`@("`@
M+RH@4V5T('5P('1H92!M871R:7@@87)R87DL(&)R96%K:6YG('5P(&5A8V@@
M<&5R;6ES<VEO;B!I;G1E9V5R"B`@("`@("`@("`@("`J(&EN=&\@86X@87)R
M87DN("!4:&4@:V5Y<R!O9B!T:&ES(&%R<F%Y('=I;&P@8F4@=&AE(')O=PH@
M("`@("`@("`@("`@*B!H96%D97)S+B`J+PH@("`@("`@("`@("`D<F]W<R`]
M(&%R<F%Y*"D["B`@("`@("`@("`@("1M871R:7@@/2!A<G)A>2@I.PH@("`@
M("`@("`@("!F;W)E86-H("@D<&5R;5]V86P@87,@)'5?:60@/3X@)'5?<&5R
M;7,I('L*("`@("`@("`@("`@("`@("1R;W=S6R1U7VED72`]("1U7VED.PH@
M("`@("`@("`@("`@("`@)&UA=')I>%LD=5]I9%T@/2!097)M<SHZ:6YT96=E
M<E1O07)R87DH)'5?<&5R;7,I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1T:&ES+3Y?9F]R;2T^861D5F%R:6%B;&4H)R<L("=U)RP@)VUA=')I>"<L
M(&9A;'-E+"!F86QS92P@;G5L;"P@87)R87DH)&-O;',L("1R;W=S+"`D;6%T
M<FEX+"`D;F5W7W5S97)S*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@:68@*"1N97=?=7-E<G,I('L*("`@("`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2@D;F5W7W5S97)S*2D@>PH@("`@("`@("`@("`@("`@("`@("1U7VX@
M/2!5=&EL.CIG971&;W)M1&%T82@G=5]N)RD["B`@("`@("`@("`@("`@("`@
M("`@)'5?;B`](&5M<'1Y*"1U7VY;)W4G72D@/R!N=6QL(#H@)'5?;ELG=2==
M.PH@("`@("`@("`@("`@("`@("`@("1U<V5R7VAT;6P@/2`G/'-E;&5C="!N
M86UE/2)U7VY;=5TB/CQO<'1I;VX^)R`N(%\H(BTM('-E;&5C="`M+2(I("X@
M)SPO;W!T:6]N/B<["B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&YE
M=U]U<V5R<R!A<R`D;F5W7W5S97(I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'5S97)?:'1M;"`N/2`G/&]P=&EO;B!V86QU93TB)R`N("1N97=?=7-E
M<B`N("<B)SL*("`@("`@("`@("`@("`@("`@("`@("`@)'5S97)?:'1M;"`N
M/2`D=5]N(#T]("1N97=?=7-E<B`_("<@<V5L96-T960](G-E;&5C=&5D(B<@
M.B`G)SL*("`@("`@("`@("`@("`@("`@("`@("`@)'5S97)?:'1M;"`N/2`G
M/B<@+B!H=&UL<W!E8VEA;&-H87)S*"1N97=?=7-E<BD@+B`G/"]O<'1I;VX^
M)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M)'5S97)?:'1M;"`N/2`G/"]S96QE8W0^)SL*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)'5S97)?:'1M;"`]("<\:6YP
M=70@='EP93TB=&5X="(@;F%M93TB=5]N6W5=(B`O/B<["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^7V9O<FTM/F%D9%9A<FEA
M8FQE*"1U<V5R7VAT;6PL("=U7VY;=ETG+"`D=&AI<RT^7W1Y<&4L(&9A;'-E
M+"!F86QS92P@;G5L;"P@)'!A<F%M<RD["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@9F]R96%C:"`H)'!E<FU?=F%L(&%S("1U7VED(#T^("1U7W!E<FUS
M*2!["B`@("`@("`@("`@("`@("`D=F%R(#T@)B1T:&ES+3Y?9F]R;2T^861D
M5F%R:6%B;&4H)'5?:60L("=U7W9;)R`N("1U7VED("X@)UTG+"`D=&AI<RT^
M7W1Y<&4L(&9A;'-E+"!F86QS92P@;G5L;"P@)'!A<F%M<RD["B`@("`@("`@
M("`@("`@("`D=F%R+3YS971$969A=6QT*"1U7W!E<FUS*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@1W)O=7!S('!E<FUI<W-I;VYS
M+B`J+PH@("`@("`@("1P97)M7W9A;"`]("1P97)M:7-S:6]N+3YG971'<F]U
M<%!E<FUI<W-I;VYS*"D["B`@("`@("`@)'1H:7,M/E]F;W)M+3YS971396-T
M:6]N*"=G<F]U<',G+"!?*")'<F]U<',B*2P@2&]R9&4Z.FEM9R@G9W)O=7`N
M<&YG)RP@)R<L("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I
M*2P@9F%L<V4I.PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O1W)O=7`N
M<&AP)SL*("`@("`@("`D9W)O=7!S(#T@)D=R;W5P.CIS:6YG;&5T;VXH*3L*
M("`@("`@("`D9W)O=7!?;&ES="`]("1G<F]U<',M/FQI<W1'<F]U<',H*3L*
M("`@("`@("!I9B`H(65M<'1Y*"1G<F]U<%]L:7-T*2D@>PH@("`@("`@("`@
M("`O*B!4:&5R92!I<R!A;B!A=F%I;&%B;&4@;&ES="!O9B!G<F]U<',@<V\@
M<V5T('5P(&%N(&%R<F%Y('=H:6-H"B`@("`@("`@("`@("`J('1H92!M871R
M:7@@9FEE;&0@='EP92!W:6QL(')E8V]G;FES92!T;R!S970@=7`@86X@96YU
M;2!B;W@@9F]R"B`@("`@("`@("`@("`J(&%D9&EN9R!N97<@9W)O=7!S('1O
M('1H92!P97)M:7-S:6]N<R!M871R:7@N("HO"B`@("`@("`@("`@("1N97=?
M9W)O=7!S(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R96%C:"`H)&=R;W5P
M7VQI<W0@87,@)&=R;W5P260@/3X@)&=R;W5P*2!["B`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1P97)M7W9A;%LD9W)O=7!)9%TI*2!["B`@("`@("`@
M("`@("`@("`@("`@)&YE=U]G<F]U<'-;)&=R;W5P261=(#T@)&=R;W5P.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@+RH@1&\@;F]T(&]F9F5R(&$@=&5X="!B;W@@=&\@
M861D(&YE=R!G<F]U<',N("HO"B`@("`@("`@("`@("1N97=?9W)O=7!S(#T@
M9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/E]T>7!E(#T]
M("=M871R:7@G*2!["B`@("`@("`@("`@("\J(%-E="!U<"!T:&4@;6%T<FEX
M(&%R<F%Y+"!B<F5A:R!U<"!E86-H('!E<FUI<W-I;VX@:6YT96=E<B!I;G1O
M"B`@("`@("`@("`@("`J(&%N(&%R<F%Y+B!4:&4@:V5Y<R!O9B!T:&ES(&%R
M<F%Y('=I;&P@8F4@=&AE(')O=R!H96%D97)S+B`J+PH@("`@("`@("`@("`D
M<F]W<R`](&%R<F%Y*"D["B`@("`@("`@("`@("1M871R:7@@/2!A<G)A>2@I
M.PH@("`@("`@("`@("!F;W)E86-H("@D<&5R;5]V86P@87,@)&=?:60@/3X@
M)&=?<&5R;7,I('L*("`@("`@("`@("`@("`@("1R;W=S6R1G7VED72`](&ES
M<V5T*"1G<F]U<%]L:7-T6R1G7VED72D@/R`D9W)O=7!?;&ES=%LD9U]I9%T@
M.B`D9U]I9#L*("`@("`@("`@("`@("`@("1M871R:7A;)&=?:61=(#T@4&5R
M;7,Z.FEN=&5G97)4;T%R<F%Y*"1G7W!E<FUS*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE*"<G+"`G9R<L
M("=M871R:7@G+"!F86QS92P@9F%L<V4L(&YU;&PL(&%R<F%Y*"1C;VQS+"`D
M<F]W<RP@)&UA=')I>"P@)&YE=U]G<F]U<',I*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!I9B`H)&YE=U]G<F]U<',I('L*("`@("`@("`@("`@
M("`@(&EF("AI<U]A<G)A>2@D;F5W7V=R;W5P<RDI('L*("`@("`@("`@("`@
M("`@("`@("`D9U]N(#T@571I;#HZ9V5T1F]R;41A=&$H)V=?;B<I.PH@("`@
M("`@("`@("`@("`@("`@("1G7VX@/2!E;7!T>2@D9U]N6R=G)UTI(#\@;G5L
M;"`Z("1G7VY;)V<G73L*("`@("`@("`@("`@("`@("`@("`D9W)O=7!?:'1M
M;"`]("<\<V5L96-T(&YA;64](F=?;EMG72(^/&]P=&EO;CXG("X@7R@B+2T@
M<V5L96-T("TM(BD@+B`G/"]O<'1I;VX^)SL*("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D;F5W7V=R;W5P<R!A<R`D9W)O=7!)9"`]/B`D9W)O=7`I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&=R;W5P7VAT;6P@+CT@)SQO
M<'1I;VX@=F%L=64](B<@+B`D9W)O=7!)9"`N("<B)SL*("`@("`@("`@("`@
M("`@("`@("`@("`@)&=R;W5P7VAT;6P@+CT@)&=?;B`]/2`D9W)O=7!)9"`_
M("<@<V5L96-T960](G-E;&5C=&5D(B<@.B`G)SL*("`@("`@("`@("`@("`@
M("`@("`@("`@)&=R;W5P7VAT;6P@+CT@)SXG("X@:'1M;'-P96-I86QC:&%R
M<R@D9W)O=7`I("X@)SPO;W!T:6]N/B<["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("1G<F]U<%]H=&UL("X]("<\+W-E;&5C
M=#XG.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D9W)O=7!?:'1M;"`]("<\:6YP=70@='EP93TB=&5X="(@;F%M93TB
M9U]N6V==(B`O/B<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE*"1G<F]U<%]H=&UL+"`G9U]N
M6W9=)RP@)'1H:7,M/E]T>7!E+"!F86QS92P@9F%L<V4L(&YU;&PL("1P87)A
M;7,I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<F5A8V@@*"1P97)M
M7W9A;"!A<R`D9U]I9"`]/B`D9U]P97)M<RD@>PH@("`@("`@("`@("`@("`@
M)'9A<B`]("8D=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE*&ES<V5T*"1G<F]U
M<%]L:7-T6R1G7VED72D@/R`D9W)O=7!?;&ES=%LD9U]I9%T@.B`D9U]I9"P@
M)V=?=ELG("X@)&=?:60@+B`G72<L("1T:&ES+3Y?='EP92P@9F%L<V4L(&9A
M;'-E+"!N=6QL+"`D<&%R86US*3L*("`@("`@("`@("`@("`@("1V87(M/G-E
M=$1E9F%U;'0H)&=?<&5R;7,I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`O*B!3970@9F]R;2!T:71L92X@*B\*("`@("`@("`D=&AI<RT^
M7V9O<FTM/G-E=%1I=&QE*'-P<FEN=&8H7R@B161I="!P97)M:7-S:6]N<R!F
M;W(@7"(E<UPB(BDL("1T:&ES+3Y?<&5R;7,M/F=E=%1I=&QE*"1P97)M:7-S
M:6]N+3YG971.86UE*"DI*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC
M=&EO;B!T;R!V86QI9&%T92!A;GD@961I="!F;W)M(&EN<'5T+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@($5I=&AE<B!F86QS92!I9B!T:&4@9F]R
M;2!D;V5S(&YO="!V86QI9&%T92!C;W)R96-T;'D@;W(*("`@("`J("`@("`@
M("`@("`@("`@(&%N(&%R<F%Y('=I=&@@86QL('1H92!F;W)M('9A;'5E<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@=F%L:61A=&5%9&ET1F]R;2@F)&EN9F\I
M"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^7V9O<FTM/G9A;&ED871E*"1T
M:&ES+3Y?=F%R<RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/E]F;W)M+3YG971);F9O*"1T:&ES+3Y?
M=F%R<RP@)&EN9F\I.PH*("`@("`@("!I9B`H)'1H:7,M/E]T>7!E(#T]("=M
M871R:7@G*2!["B`@("`@("`@("`@("\J($-O;&QA<'-E('1H92!A<G)A>2!F
M;W(@9&5F875L="]G=65S="]C<F5A=&]R+B`J+PH@("`@("`@("`@("`D:6YF
M;ULG9&5F;'0G72`](&ES<V5T*"1I;F9O6R=D969L="==6S!=*2`_("1I;F9O
M6R=D969L="==6S!=(#H@;G5L;#L*("`@("`@("`@("`@)&EN9F];)V=U97-T
M)UT@("`](&ES<V5T*"1I;F9O6R=G=65S="==6S!=*2`_("1I;F9O6R=G=65S
M="==6S!=(#H@;G5L;#L*("`@("`@("`@("`@)&EN9F];)V-R96%T;W(G72`]
M(&ES<V5T*"1I;F9O6R=C<F5A=&]R)UU;,%TI(#\@)&EN9F];)V-R96%T;W(G
M75LP72`Z(&YU;&P["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'5?
M;B`]("1T:&ES+3Y?=F%R<RT^9V5T*"=U7VXG*3L*("`@("`@("`@("`@)&EN
M9F];)W4G72`](&%R<F%Y*"1U7VY;)W4G72`]/B`D:6YF;ULG=5]N)UU;)W8G
M72D["B`@("`@("`@("`@('5N<V5T*"1I;F9O6R=U7VXG72D["B`@("`@("`@
M("`@(&EF("AI<W-E="@D:6YF;ULG=5]V)UTI*2!["B`@("`@("`@("`@("`@
M("`D:6YF;ULG=2==(#T@87)R87E?;65R9V4H)&EN9F];)W4G72P@)&EN9F];
M)W5?=B==*3L*("`@("`@("`@("`@("`@('5N<V5T*"1I;F9O6R=U7W8G72D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&=?;B`]("1T:&ES+3Y?=F%R
M<RT^9V5T*"=G7VXG*3L*("`@("`@("`@("`@)&EN9F];)V<G72`](&%R<F%Y
M*"1G7VY;)V<G72`]/B`D:6YF;ULG9U]N)UU;)W8G72D["B`@("`@("`@("`@
M('5N<V5T*"1I;F9O6R=G7VXG72D["B`@("`@("`@("`@(&EF("AI<W-E="@D
M:6YF;ULG9U]V)UTI*2!["B`@("`@("`@("`@("`@("`D:6YF;ULG9R==(#T@
M87)R87E?;65R9V4H)&EN9F];)V<G72P@)&EN9F];)V=?=B==*3L*("`@("`@
M("`@("`@("`@('5N<V5T*"1I;F9O6R=G7W8G72D["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@)&EN9F];)V1E9F%U;'0G72`]("1I;F9O6R=D
M969L="==.PH@("`@("`@('5N<V5T*"1I;F9O6R=D969L="==*3L*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@
M82!P97)M:7-S:6]N(&1E;&5T:6YG(&9O<FTN"B`@("`@*@H@("`@("H@0'!A
M<F%M(&]B:F5C="`D<&5R;6ES<VEO;@H@("`@("HO"B`@("!F=6YC=&EO;B!S
M971U<$1E;&5T949O<FTH)'!E<FUI<W-I;VXI"B`@("!["B`@("`@("`@+RH@
M26YI=&EA;&ES92!F;W)M(&EF(')E<75I<F5D+B`J+PH@("`@("`@("1T:&ES
M+3Y?9F]R;4EN:70H*3L*"B`@("`@("`@)'1H:7,M/E]F;W)M+3YS9714:71L
M92AS<')I;G1F*%\H(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(BDL
M("1T:&ES+3Y?<&5R;7,M/F=E=%1I=&QE*"1P97)M:7-S:6]N+3YG971.86UE
M*"DI*2D["B`@("`@("`@)'1H:7,M/E]F;W)M+3YS971"=71T;VYS*&%R<F%Y
M*%\H(D1E;&5T92(I+"!?*")$;R!N;W0@9&5L971E(BDI*3L*("`@("`@("`D
M=&AI<RT^7V9O<FTM/F%D9$AI9&1E;B@G)RP@)W!E<FU?:60G+"`G=&5X="<L
M(&9A;'-E*3L*("`@("`@("`D=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE*'-P
M<FEN=&8H7R@B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N
M>2!S=6(M<&5R;6ES<VEO;G,_(BDL("1T:&ES+3Y?<&5R;7,M/F=E=%1I=&QE
M*"1P97)M:7-S:6]N+3YG971.86UE*"DI*2P@)W!R;VUP="<L("=D97-C<FEP
M=&EO;B<L(&9A;'-E*3L*"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC=&EO
M;B!T;R!V86QI9&%T92!A;GD@9&5L971E(&9O<FT@:6YP=70N"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@268@=&AE(&1E;&5T92!B=71T;VX@8V]N
M9FER;6%T:6]N(&AA<R!B965N('!R97-S960@<F5T=7)N"B`@("`@*B`@("`@
M("`@("`@("`@("!T<G5E+"!I9B!A;GD@;W1H97(@<W5B;6ET(&)U='1O;B!H
M87,@8F5E;B!P<F5S<V5D(')E='5R;@H@("`@("H@("`@("`@("`@("`@("`@
M9F%L<V4N($EF(&9O<FT@9&ED(&YO="!V86QI9&%T92!R971U<FX@;G5L;"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@=F%L:61A=&5$96QE=&5&;W)M*"8D:6YF
M;RD*("`@('L*("`@("`@("`D9F]R;5]S=6)M:70@/2`D=&AI<RT^7W9A<G,M
M/F=E="@G<W5B;6ET8G5T=&]N)RD["@H@("`@("`@(&EF("@D9F]R;5]S=6)M
M:70@/3T@7R@B1&5L971E(BDI('L*("`@("`@("`@("`@:68@*"1T:&ES+3Y?
M9F]R;2T^=F%L:61A=&4H)'1H:7,M/E]V87)S*2D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]F;W)M+3YG971);F9O*"1T:&ES+3Y?=F%R<RP@)&EN9F\I
M.PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1F;W)M7W-U8FUI="DI('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YD97)S('1H92!E
M9&ET(&9O<FTN"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<D9O<FTH)&9O
M<FU?<V-R:7!T(#T@)V5D:70N<&AP)RD*("`@('L*("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP)SL*("`@("`@("`D<F5N
M9&5R97(@/2`F;F5W($AO<F1E7T9O<FU?4F5N9&5R97(H*3L*("`@("`@("`D
M=&AI<RT^7V9O<FTM/G)E;F1E<D%C=&EV92@D<F5N9&5R97(L("1T:&ES+3Y?
M=F%R<RP@)&9O<FU?<V-R:7!T+"`G<&]S="<I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0W)E871E<R!A;GD@9F]R;2!O8FIE8W1S(&EF('1H97D@:&%V92!N
M;W0@8F5E;B!I;FET:6%L:7-E9"!Y970N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]F;W)M26YI="@I"B`@
M("!["B`@("`@("`@:68@*&ES7VYU;&PH)'1H:7,M/E]V87)S*2D@>PH@("`@
M("`@("`@("`O*B!.;R!E>&ES=&EN9R!V87)S('-E="P@9V5T('1H96T@;F]W
M+B`J+PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U9A<FEA8FQE
M<RYP:'`G.PH@("`@("`@("`@("`D=&AI<RT^7W9A<G,@/2`F5F%R:6%B;&5S
M.CIG971$969A=6QT5F%R:6%B;&5S*"D["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(6ES7V$H)'1H:7,M/E]F;W)M+"`G2&]R9&5?1F]R;2<I*2!["B`@("`@
M("`@("`@("\J($YO(&5X:7-T:6YG('9A;&ED(&9O<FT@;V)J96-T('-E="!S
M;R!S970@=7`@82!N97<@;VYE+B`J+PH@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)TAO<F1E+T9O<FTN<&AP)SL*("`@("`@("`@("`@)'1H:7,M/E]F;W)M
M(#T@)DAO<F1E7T9O<FTZ.G-I;F=L971O;B@G)RP@)'1H:7,M/E]V87)S*3L*
M("`@("`@("!]"B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]0
M97)M<RYP:'``````````````````````````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,S$R,C4`,3`U,34T,S,W-3(`,#(Q,C8V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@HO*BH@17AI<W1E;F-E
M(&]F(&]B:F5C="!I<R!K;F]W;B`M(&]B:F5C="!I<R!S:&]W;B!T;R!U<V5R
M+B`J+PID969I;F4H)U!%4DU37U-(3U<G+"`R*3L*"B\J*B!#;VYT96YT<R!O
M9B!T:&4@;V)J96-T(&-A;B!B92!R96%D+B`J+PID969I;F4H)U!%4DU37U)%
M040G+"`T*3L*"B\J*B!#;VYT96YT<R!O9B!T:&4@;V)J96-T(&-A;B!B92!E
M9&ET960N("HO"F1E9FEN92@G4$5235-?141)5"<L(#@I.PH*+RHJ(%1H92!O
M8FIE8W0@8V%N(&)E(&1E;&5T960N("HO"F1E9FEN92@G4$5235-?1$5,151%
M)RP@,38I.PH*+RHJ"B`J($$@8FET;6%S:R!O9B!A;&P@<&]S<VEB;&4@<&5R
M;6ES<VEO;B!V86QU97,N(%5S969U;"!F;W(*("H@<F5M;W9E6'AX4&5R;6ES
M<VEO;B@I+"!U;G-E=%!E<FTH*2P@971C+@H@*B\*9&5F:6YE*"=015)-4U]!
M3$PG+"!015)-4U]32$]7('P@4$5235-?4D5!1"!\(%!%4DU37T5$250@?"!0
M15)-4U]$14Q%5$4I.PH*+RHJ"B`J(%1H92!097)M<SHZ(&-L87-S('!R;W9I
M9&5S('1H92!(;W)D92!P97)M:7-S:6]N<R!S>7-T96TN"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<"QV(#$N.#`N,3`N.2`R,#`V
M+S`U+S`U(#`T.C`X.C4Y('-E;'-K>2!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P,2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D
M92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@2F%N(%-C:&YE
M:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,BXQ"B`J
M($!P86-K86=E($AO<F1E7U!E<FUS"B`J+PIC;&%S<R!097)M<R!["@H@("`@
M+RHJ"B`@("`@*B!#86-H97,@:6YF;W)M871I;VX@86)O=70@87!P;&EC871I
M;VX@<&5R;6ES<VEO;G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)%]A<'!L:6-A=&EO;E!E<FUI<W-I;VYS.PH*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@879A:6QA8FQE('!E<FUI<W-I;VYS(&9O
M<B!A(&=I=F5N(&QE=F5L+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&YA;64@(%1H92!P97)M:7-S:6]N)W,@;F%M92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B!A=F%I;&%B;&4@<&5R;6ES<VEO
M;G,@86YD('1H96ER('1I=&QE<R!O<@H@("`@("H@("`@("`@("`@("`@("`@
M9F%L<V4@:68@;F]T('-U8B!P97)M:7-S:6]N<R!E>&ES="!F;W(@=&AI<R!L
M979E;"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T079A:6QA8FQE*"1N86UE
M*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@(&EF
M("AE;7!T>2@D;F%M92DI('L*("`@("`@("`@("`@+RH@3F\@;F%M92!P87-S
M960L('-O('1O<"!L979E;"!P97)M:7-S:6]N<R!A<F4@<F5Q=65S=&5D+B!4
M:&5S90H@("`@("`@("`@("`@*B!C86X@;VYL>2!B92!A<'!L:6-A=&EO;G,N
M("HO"B`@("`@("`@("`@("1A<'!S(#T@)')E9VES=')Y+3YL:7-T07!P<RAA
M<G)A>2@G;F]T;V]L8F%R)RP@)V%C=&EV92<L("=H:61D96XG*2P@=')U92D[
M"B`@("`@("`@("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H)&%P<',I(&%S("1A
M<'`I('L*("`@("`@("`@("`@("`@("1A<'!S6R1A<'!=(#T@)')E9VES=')Y
M+3YG970H)VYA;64G+"`D87!P*2`N("<@*"<@+B`D87!P("X@)RDG.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&%S;W)T*"1A<'!S*3L*("`@("`@("`@
M("`@<F5T=7)N("1A<'!S.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("\J($YA;64@:&%S(&)E96X@<&%S<V5D+"!E>'!L;V1E('1H92!N86UE('1O
M(&=E="!A;&P@=&AE(&QE=F5L<R!I;@H@("`@("`@("`@("`@*B!P97)M:7-S
M:6]N(&)E:6YG(')E<75I<W1E9"P@=VET:"!T:&4@87!P(&%S('1H92!F:7)S
M="!L979E;"X@*B\*("`@("`@("`@("`@)&QE=F5L<R`](&%R<F%Y*"D["B`@
M("`@("`@("`@("1L979E;',@/2!E>'!L;V1E*"<Z)RP@)&YA;64I.PH*("`@
M("`@("`@("`@+RH@1FER<W0@;&5V96P@:7,@86QW87ES(&%P<"X@*B\*("`@
M("`@("`@("`@)&%P<"`]("1L979E;'-;,%T["@H@("`@("`@("`@("`O*B!2
M971U<FX@96UP='D@:68@;F\@87!P(&1E9FEN960@05!)(&UE=&AO9"!F;W(@
M<')O=FED:6YG"B`@("`@("`@("`@("`J('!E<FUI<W-I;VX@:6YF;W)M871I
M;VXN("HO"B`@("`@("`@("`@(&EF("@A)')E9VES=')Y+3YH87--971H;V0H
M)W!E<FUS)RP@)&%P<"DI('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@0V%L;"!T:&4@87!P
M)W,@<&5R;6ES<VEO;B!F=6YC=&EO;B!T;R!R971U<FX@=&AE('!E<FUI<W-I
M;VYS"B`@("`@("`@("`@("`J('-P96-I9FEC('1O('1H:7,@87!P+B`J+PH@
M("`@("`@("`@("`D<&5R;7,@/2`D=&AI<RT^9V5T07!P;&EC871I;VY097)M
M:7-S:6]N<R@D87!P*3L*("`@("`@("`@("`@:68@*&ES7V$H)'!E<FUS+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'!E<FUS
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO
M<F1E+T%R<F%Y+G!H<"<["B`@("`@("`@("`@("\J($=E="!T:&4@<&%R="!O
M9B!T:&4@87!P)W,@<&5R;6ES<VEO;G,@8F%S960@;VX@=&AE('!E<FUI<W-I
M;VX*("`@("`@("`@("`@("H@;F%M92!R97%U97-T960N("HO"B`@("`@("`@
M("`@("1C:&EL9')E;B`]($AO<F1E7T%R<F%Y.CIG971%;&5M96YT*"1P97)M
M<ULG=')E92==+"`D;&5V96QS*3L*("`@("`@("`@("`@:68@*"1C:&EL9')E
M;B`]/3T@9F%L<V4@?'P*("`@("`@("`@("`@("`@("%I<U]A<G)A>2@D8VAI
M;&1R96XI('Q\"B`@("`@("`@("`@("`@("`A8V]U;G0H)&-H:6QD<F5N*2D@
M>PH@("`@("`@("`@("`@("`@+RH@3F\@87)R87D@;V8@8VAI;&1R96X@879A
M:6QA8FQE(&9O<B!T:&ES('!E<FUI<W-I;VX@;F%M92X@*B\*("`@("`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@)'!E<FUS7VQI<W0@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H
M("@D8VAI;&1R96X@87,@)'!E<FU?:V5Y(#T^("1P97)M7W9A;"D@>PH@("`@
M("`@("`@("`@("`@)'!E<FUS7VQI<W1;)'!E<FU?:V5Y72`]("1P97)M<ULG
M=&ET;&4G75LD;F%M92`N("<Z)R`N("1P97)M7VME>5T["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@<F5T=7)N("1P97)M<U]L:7-T.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('-H;W)T(&YA;64@
M;V8@86X@;V)J96-T+"!T:&4@;&%S="!P;W)T:6]N(&]F('1H92!F=6QL(&YA
M;64N"B`@("`@*@H@("`@("H@0'-T871I8PH@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&YA;64@(%1H92!N86UE(&]F('1H92!O8FIE8W0N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!O8FIE8W0G<R!S:&]R="!N
M86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9713:&]R=$YA;64H)&YA;64I
M"B`@("!["B`@("`@("`@+RH@268@=&AE<F4@87)E('-E=F5R86P@8V]M<&]N
M96YT<R!T;R!T:&4@;F%M92P@97AP;&]D92!A;F0*("`@("`@("`@*B!G970@
M=&AE(&QA<W0@;VYE+"!O=&AE<G=I<V4@:G5S="!R971U<FX@=&AE(&YA;64N
M("HO"B`@("`@("`@:68@*'-T<G!O<R@D;F%M92P@)SHG*2`A/3T@9F%L<V4I
M('L*("`@("`@("`@("`@)'1M<"`](&5X<&QO9&4H)SHG+"`D;F%M92D["B`@
M("`@("`@("`@(')E='5R;B!A<G)A>5]P;W`H)'1M<"D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N("1N86UE.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($=I=F5N(&$@<&5R;6ES<VEO;B!N86UE+"!R
M971U<FYS('1H92!T:71L92!F;W(@=&AA="!P97)M:7-S:6]N(&)Y"B`@("`@
M*B!L;V]K:6YG(&ET('5P(&EN('1H92!A<'!L:6-A=&EO;G,G<R!P97)M:7-S
M:6]N(&%P:2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4
M:&4@<&5R;6ES<VEO;G,G<R!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@=&ET;&4@9F]R('1H92!P97)M:7-S:6]N+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G9714:71L92@D;F%M92D*("`@('L*("`@("`@("!G
M;&]B86P@)')E9VES=')Y.PH*("`@("`@("`D;&5V96QS(#T@97AP;&]D92@G
M.B<L("1N86UE*3L*("`@("`@("!I9B`H8V]U;G0H)&QE=F5L<RD@/3T@,2D@
M>PH@("`@("`@("`@("!R971U<FX@)')E9VES=')Y+3YG970H)VYA;64G+"`D
M;F%M92D@+B`G("@G("X@)&YA;64@+B`G*2<["B`@("`@("`@?0H@("`@("`@
M("1P97)M(#T@87)R87E?<&]P*"1L979E;',I.PH*("`@("`@("`O*B!&:7)S
M="!L979E;"!I<R!A;'=A>7,@87!P+B`J+PH@("`@("`@("1A<'`@/2`D;&5V
M96QS6S!=.PH*("`@("`@("`O*B!2971U<FX@96UP='D@:68@;F\@87!P(&1E
M9FEN960@05!)(&UE=&AO9"!F;W(@<')O=FED:6YG('!E<FUI<W-I;VX*("`@
M("`@("`@*B!I;F9O<FUA=&EO;BX@*B\*("`@("`@("!I9B`H(21R96=I<W1R
M>2T^:&%S365T:&]D*"=P97)M<R<L("1A<'`I*2!["B`@("`@("`@("`@(')E
M='5R;B!097)M<SHZ9V5T4VAO<G1.86UE*"1N86UE*3L*("`@("`@("!]"@H@
M("`@("`@("1A<'!?<&5R;7,@/2`D=&AI<RT^9V5T07!P;&EC871I;VY097)M
M:7-S:6]N<R@D87!P*3L*"B`@("`@("`@<F5T=7)N(&ES<V5T*"1A<'!?<&5R
M;7-;)W1I=&QE)UU;)&YA;65=*0H@("`@("`@("`@("`_("1A<'!?<&5R;7-;
M)W1I=&QE)UU;)&YA;65=("X@)R`H)R`N($1A=&%4<F5E.CIG9713:&]R=$YA
M;64H)&YA;64I("X@)RDG"B`@("`@("`@("`@(#H@1&%T851R964Z.F=E=%-H
M;W)T3F%M92@D;F%M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&EN9F]R;6%T:6]N(&%B;W5T('!E<FUI<W-I;VYS(&EM<&QE;65N=&5D(&)Y
M(&%N(&%P<&QI8V%T:6]N+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S
M+C$*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@($%N(&%P<&QI
M8V%T:6]N(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@2&%S
M:"!W:71H('!E<FUI<W-I;VYS(&EN9F]R;6%T:6]N+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971!<'!L:6-A=&EO;E!E<FUI<W-I;VYS*"1A<'`I"B`@("![
M"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V%P<&QI8V%T:6]N4&5R;6ES
M<VEO;G-;)&%P<%TI*2!["B`@("`@("`@("`@("1T:&ES+3Y?87!P;&EC871I
M;VY097)M:7-S:6]N<ULD87!P72`]("1'3$]"04Q36R=R96=I<W1R>2==+3YC
M86QL0GE086-K86=E*"1A<'`L("=P97)M<R<I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?87!P;&EC871I;VY097)M:7-S:6]N<ULD87!P
M73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!N97<@<&5R;6ES
M<VEO;G,@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA
M;64@(%1H92!P97)M:7-S:6]N)W,@;F%M92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(%!E<FUI<W-I;VYS("!!(&YE=R!P97)M:7-S:6]N<R!O8FIE8W0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9N97=097)M:7-S:6]N*"1N86UE*0H@("`@
M>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H92!A9&UI
M;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M
M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N
M<RXB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@4&5R;6ES
M<VEO;B!O8FIE8W0@8V]R<F5S<&]N9&EN9R!T;R!T:&4@;F%M960@<&5R;6ES
M<VEO;BP*("`@("`J('=I=&@@=&AE('5S97)S(&%N9"!O=&AE<B!D871A(')E
M=')I979E9"!A<'!R;W!R:6%T96QY+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@(%1H92!N86UE(&]F('1H92!P97)M:7-S:6]N('1O(')E
M=')I979E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T4&5R;6ES<VEO;B@D
M;F%M92D*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M
M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@
M4&5R;6ES<VEO;G,N(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!A(%!E<FUI<W-I;VX@;V)J96-T(&-O<G)E<W!O;F1I;F<@=&\@=&AE(&=I
M=F5N('5N:7%U92!)1"P@=VET:`H@("`@("H@=&AE('5S97)S(&%N9"!O=&AE
M<B!D871A(')E=')I979E9"!A<'!R;W!R:6%T96QY+@H@("`@("H*("`@("`J
M($!P87)A;2!I;G1E9V5R("1C:60@(%1H92!U;FEQ=64@240@;V8@=&AE('!E
M<FUI<W-I;VX@=&\@<F5T<FEE=F4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G
M971097)M:7-S:6]N0GE)9"@D8VED*0H@("`@>PH@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*%\H(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O
M(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF
M('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RXB*2D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!9&1S(&$@<&5R;6ES<VEO;B!T;R!T:&4@<&5R;6ES<VEO
M;G,@<WES=&5M+B!4:&4@<&5R;6ES<VEO;B!M=7-T(&9I<G-T"B`@("`@*B!B
M92!C<F5A=&5D('=I=&@@4&5R;3HZ;F5W4&5R;6ES<VEO;B@I+"!A;F0@:&%V
M92!A;GD@:6YI=&EA;"!U<V5R<PH@("`@("H@861D960@=&\@:70L(&)E9F]R
M92!T:&ES(&9U;F-T:6]N(&ES(&-A;&QE9"X*("`@("`J"B`@("`@*B!`<&%R
M86T@4&5R;6ES<VEO;B`D<&5R;2`@5&AE(&YE=R!P97)M(&]B:F5C="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@861D4&5R;6ES<VEO;B@F)'!E<FTI"B`@("![
M"B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B5&AE(&%D;6EN
M:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI
M<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS
M+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@82!P97)M:7-S
M:6]N(&9R;VT@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2!P97)M86YE;G1L>2X*
M("`@("`J"B`@("`@*B!`<&%R86T@4&5R;6ES<VEO;B`D<&5R;2`@5&AE('!E
M<FUI<W-I;VX@=&\@<F5M;W9E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&9O
M<F-E("`@($9O<F-E('1O(')E;6]V92!E=F5R>2!C:&EL9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F5M;W9E4&5R;6ES<VEO;B@F)'!E<FTL("1F;W)C92`]
M(&9A;'-E*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E
M<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S
M92!097)M:7-S:6]N<RXB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD
M<R!O=70@=VAA="!R:6=H=',@=&AE(&=I=F5N('5S97(@:&%S('1O('1H:7,@
M;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D<&5R;6ES<VEO
M;B`@5&AE(&9U;&P@<&5R;6ES<VEO;B!N86UE(&]F('1H92!O8FIE8W0@=&\*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@8VAE8VL@=&AE('!E
M<FUI<W-I;VYS(&]F+"!O<B!T:&4@4&5R;6ES<VEO;@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("!O8FIE8W0N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1U<V5R("`@("`@(%1H92!U<V5R('1O(&-H96-K(&9O<BX@1&5F875L
M=',@=&\@=&AE(&-U<G)E;G0*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=7-E<BX*("`@("`J($!P87)A;2!S=')I;F<@)&-R96%T;W(@("`@
M5&AE('5S97(@=VAO(&-R96%T960@=&AE(&5V96YT+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@($$@8FET;6%S:R!O9B!P97)M:7-S:6]N<R!T:&4@
M=7-E<B!H87,L(&9A;'-E(&EF('1H97)E"B`@("`@*B`@("`@("`@("`@("`@
M("!A<F4@;F]N92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&5R;6ES<VEO
M;G,H)'!E<FUI<W-I;VXL("1U<V5R(#T@;G5L;"P@)&-R96%T;W(@/2!N=6QL
M*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H
M92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N
M="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M
M:7-S:6]N<RXB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!U;FEQ=64@:61E;G1I9FEE<B!O9B!T:&ES('!E<FUI<W-I;VXN"B`@("`@
M*@H@("`@("H@0'!A<F%M(%!E<FUI<W-I;VX@)'!E<FUI<W-I;VX@(%1H92!P
M97)M:7-S:6]N(&]B:F5C="!T;R!G970@=&AE($E$(&]F+@H@("`@("H*("`@
M("`J($!R971U<FX@:6YT96=E<B`@5&AE('5N:7%U92!I9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T4&5R;6ES<VEO;DED*"1P97)M:7-S:6]N*0H@("`@
M>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H92!A9&UI
M;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M
M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N
M<RXB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD<R!O=70@:68@=&AE
M('5S97(@:&%S('1H92!S<&5C:69I960@<FEG:'1S('1O('1H92!G:79E;B!O
M8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'!E<FUI<W-I
M;VX@(%1H92!P97)M:7-S:6]N('1O(&-H96-K+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`@)'5S97(@("`@("`@(%1H92!U<V5R('1O(&-H96-K(&9O<BX*("`@
M("`J($!P87)A;2!I;G1E9V5R("1P97)M("`@("`@("!4:&4@<&5R;6ES<VEO
M;B!L979E;"!N965D960@9F]R(&%C8V5S<RX*("`@("`J($!P87)A;2!S=')I
M;F<@("1C<F5A=&]R("`@("!4:&4@8W)E871O<B!O9B!T:&4@979E;G0*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE('5S97(@
M:&%S('1H92!S<&5C:69I960@<&5R;6ES<VEO;G,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&AA<U!E<FUI<W-I;VXH)'!E<FUI<W-I;VXL("1U<V5R+"`D<&5R
M;2P@)&-R96%T;W(@/2!N=6QL*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS
M93L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!I9B!A('!E<FUI<W-I
M;VX@97AI<W1S(&EN('1H92!S>7-T96TN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<&5R;6ES<VEO;B`@5&AE('!E<FUI<W-I;VX@=&\@8VAE8VLN
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!P
M97)M:7-S:6]N(&5X:7-T<RX*("`@("`J+PH@("`@9G5N8W1I;VX@97AI<W1S
M*"1P97)M:7-S:6]N*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!L:7-T(&]F('!A<F5N="!P
M97)M:7-S:6]N<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:&EL
M9"`@5&AE(&YA;64@;V8@=&AE(&-H:6QD('1O(')E=')I979E('!A<F5N=',@
M9F]R+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($$@:&%S:"!W:71H
M(&%L;"!P87)E;G1S(&EN(&$@=')E92!F;W)M870N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%!A<F5N=',H)&-H:6QD*0H@("`@>PH@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(E1H92!A9&UI;FES=')A=&]R(&YE961S
M('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD
M(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RXB*2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&%L;"!P97)M:7-S:6]N<R!O9B!T:&4@
M<WES=&5M(&EN(&$@=')E92!F;W)M870N"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@02!H87-H('=I=&@@86QL('!E<FUI<W-I;VYS(&EN(&$@=')E
M92!F;W)M870N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1R964H*0H@("`@
M>PH@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A;B!H87-H(&]F('1H92!A=F%I;&%B;&4@<&5R;6ES<VEO
M;G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&%V86EL86)L
M92!P97)M:7-S:6]N<R!A<R!A(&AA<V@N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=%!E<FUS07)R87DH*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2A0
M15)-4U]32$]7(#T^(%\H(E-H;W<B*2P*("`@("`@("`@("`@("`@("`@("`@
M4$5235-?4D5!1"`]/B!?*")296%D(BDL"B`@("`@("`@("`@("`@("`@("`@
M(%!%4DU37T5$250@/3X@7R@B161I="(I+`H@("`@("`@("`@("`@("`@("`@
M("!015)-4U]$14Q%5$4@/3X@7R@B1&5L971E(BDI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1VEV96X@86X@:6YT96=E<B!V86QU92!O9B!P97)M:7-S:6]N
M<R!R971U<FYS(&%N(&%R<F%Y"B`@("`@*B!R97!R97-E;G1A=&EO;B!O9B!T
M:&4@:6YT96=E<BX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:6YT
M("!4:&4@:6YT96=E<B!R97!R97-E;G1A=&EO;B!O9B!P97)M:7-S:6]N<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@:6YT96=E<E1O07)R87DH)&EN="D*("`@
M('L*("`@("`@("!S=&%T:6,@)&%R<F%Y(#T@87)R87DH*3L*("`@("`@("!I
M9B`H:7-S970H)&%R<F%Y6R1I;G1=*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&%R<F%Y6R1I;G1=.PH@("`@("`@('T*"B`@("`@("`@)&%R<F%Y6R1I;G1=
M(#T@87)R87DH*3L*"B`@("`@("`@+RH@1V5T('1H92!A=F%I;&%B;&4@<&5R
M;7,@87)R87DN("HO"B`@("`@("`@)'!E<FUS(#T@4&5R;7,Z.F=E=%!E<FUS
M07)R87DH*3L*"B`@("`@("`@+RH@3&]O<"!T:')O=6=H(&5A8V@@<&5R;2!A
M;F0@8VAE8VL@:68@:71S('9A;'5E(&ES(&EN8VQU9&5D(&EN('1H90H@("`@
M("`@("`J(&EN=&5G97(@<F5P<F5S96YT871I;VXN("HO"B`@("`@("`@9F]R
M96%C:"`H)'!E<FUS(&%S("1V86P@/3X@)&QA8F5L*2!["B`@("`@("`@("`@
M(&EF("@D:6YT("8@)'9A;"D@>PH@("`@("`@("`@("`@("`@)&%R<F%Y6R1I
M;G1=6R1V86Q=(#T@=')U93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1A<G)A>5LD:6YT73L*("`@('T*"B`@("`O*BH*("`@
M("`J($%T=&5M<'1S('1O(')E='5R;B!A(&-O;F-R971E(%!E<FUS(&EN<W1A
M;F-E(&)A<V5D(&]N("1D<FEV97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9')I=F5R("!4:&4@='EP92!O9B!T:&4@8V]N8W)E=&4@4&5R;7,@
M<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@=&\@<F5T
M=7)N+B`@5&AE(&-L87-S(&YA;64@:7,@8F%S960@;VX@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@('!E<FUS(&1R:79E<B`H)&1R:79E<BDN
M("!4:&4@8V]D92!I<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!D
M>6YA;6EC86QL>2!I;F-L=61E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(%!E
M<FUS?&)O;VQE86X@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E(%!E<FUS
M(&EN<W1A;F-E+"!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!F
M86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O
M<GDH)&1R:79E<B`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH
M)&1R:79E<BDI('L*("`@("`@("`@("`@)'!E<FUS(#T@)FYE=R!097)M<R@I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EN8VQU9&5?;VYC92`G
M2&]R9&4O4&5R;7,O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@("`@
M("1C;&%S<R`]("=097)M<U\G("X@)&1R:79E<CL*("`@("`@("`@("`@:68@
M*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("`@("`D<&5R
M;7,@/2`F;F5W("1C;&%S<R@I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)'!E<FUS(#T@9F%L<V4["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D<&5R;7,["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E<F5N8V4@=&\@82!C
M;VYC<F5T92!097)M<R!I;G-T86YC92X*("`@("`J($ET('=I;&P@;VYL>2!C
M<F5A=&4@82!N97<@:6YS=&%N8V4@:68@;F\@4&5R;7,@:6YS=&%N8V4*("`@
M("`J(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!M971H
M;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R(#T@)E!E<FUS.CIS:6YG;&5T
M;VXH*0H@("`@("H*("`@("`J($!R971U<FX@4&5R;7-\8F]O;&5A;B`@5&AE
M(&-O;F-R971E(%!E<FT@<F5F97)E;F-E+"!O<B!F86QS92!O;B!E<G)O<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@I"B`@("!["B`@("`@
M("`@<W1A=&EC("1P97)M.PH*("`@("`@("!I9B`H(6ES<V5T*"1P97)M*2D@
M>PH@("`@("`@("`@("`D<&5R;2`]("9097)M<SHZ9F%C=&]R>2@A96UP='DH
M)$=,3T)!3%-;)V-O;F8G75LG9&%T871R964G75LG9')I=F5R)UTI(#\@)V1A
M=&%T<F5E)R`Z(&YU;&PI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P
M97)M.PH@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]0<F5F<R\`````````````````````````````````````````
M````````````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-#<`,#(P-30W`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E
M<BYP:'`````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-#`W-``Q,#4Q-30S,S<T
M-P`P,C0S,S8`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J($-L87-S(&9O<B!H86YD;&EN9R!A(&QI<W0@
M;V8@8V%T96=O<FEE<R!S=&]R960@:6X@82!U<V5R)W,*("H@<')E9F5R96YC
M97,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`L=B`Q+C$Q+C$P+C4@,C`P-B\P,2\P,2`R,3HR.#HS
M,B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!#:'5C:R!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?4')E9G,*
M("HO"F-L87-S(%!R969S7T-A=&5G;W)Y36%N86=E<B!["@H@("`@+RHJ"B`@
M("`@*B!'970@86QL(&-A=&5G;W)I97,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E="@I"B`@("!["B`@("`@("`@9VQO8F%L("1P<F5F<SL*"B`@("`@("`@
M)'-T<FEN9R`]("1P<F5F<RT^9V5T5F%L=64H)V-A=&5G;W)I97,G*3L*("`@
M("`@("!I9B`H96UP='DH)'-T<FEN9RDI('L*("`@("`@("`@("`@<F5T=7)N
M(&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("`D8V%T96=O<FEE<R`](&5X
M<&QO9&4H)WPG+"`D<W1R:6YG*3L*("`@("`@("!A<V]R="@D8V%T96=O<FEE
M<RD["@H@("`@("`@(')E='5R;B`D8V%T96=O<FEE<SL*("`@('T*"B`@("!F
M=6YC=&EO;B!G971396QE8W0H)&ED+"`D8W5R<F5N="`](&YU;&PI"B`@("![
M"B`@("`@("`@9VQO8F%L("1P<F5F<SL*"B`@("`@("`@)&AT;6P@/2`G/'-E
M;&5C="!I9#TB)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&ED*2`N("<B(&YA;64]
M(B<@+B!H=&UL<W!E8VEA;&-H87)S*"1I9"D@+B`G(CXG.PH*("`@("`@("`D
M8V%T96=O<FEE<R`](%!R969S7T-A=&5G;W)Y36%N86=E<CHZ9V5T*"D["B`@
M("`@("`@:68@*"%I;E]A<G)A>2@D8W5R<F5N="P@)&-A=&5G;W)I97,I("8F
M("%E;7!T>2@D8W5R<F5N="DI('L*("`@("`@("`@("`@)&AT;6P@+CT@)SQO
M<'1I;VX@=F%L=64](BIN97<J)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&-U<G)E
M;G0I("X@)R(^)R`N('-P<FEN=&8H7R@B57-E($-U<G)E;G0Z("5S(BDL(&AT
M;6QS<&5C:6%L8VAA<G,H)&-U<G)E;G0I*2`N("<\+V]P=&EO;CXG("X*("`@
M("`@("`@("`@("`@("<\;W!T:6]N('9A;'5E/2(B/BTM+2T\+V]P=&EO;CXG
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"$D<')E9G,M/FES3&]C:V5D*"=C
M871E9V]R:65S)RDI('L*("`@("`@("`@("`@)&AT;6P@+CT@)SQO<'1I;VX@
M=F%L=64](BIN97<J(CXG("X@7R@B3F5W($-A=&5G;W)Y(BD@+B`B/"]O<'1I
M;VX^7&XB("X*("`@("`@("`@("`@("`@("<\;W!T:6]N('9A;'5E/2(B/BTM
M+2T\+V]P=&EO;CXG.PH@("`@("`@('T*"B`@("`@("`@+R\@06QW87ES(&%D
M9"!A;B!5;F9I;&5D(&]P=&EO;BX*("`@("`@("`D:'1M;"`N/2`G/&]P=&EO
M;B!V86QU93TB(B<@+@H@("`@("`@("`@("`H96UP='DH)&-U<G)E;G0I(#\@
M)R!S96QE8W1E9#TB<V5L96-T960B/B<@.B`G/B<I("X*("`@("`@("`@("`@
M:'1M;'-P96-I86QC:&%R<RA?*")5;F9I;&5D(BDI("X@)SPO;W!T:6]N/B<[
M"@H@("`@("`@(&9O<F5A8V@@*"1C871E9V]R:65S(&%S("1N86UE*2!["B`@
M("`@("`@("`@("1H=&UL("X]("<\;W!T:6]N('9A;'5E/2(G("X@:'1M;'-P
M96-I86QC:&%R<R@D;F%M92D@+B`G(B<@+@H@("`@("`@("`@("`@("`@*"1N
M86UE(#T]/2`D8W5R<F5N="`_("<@<V5L96-T960](G-E;&5C=&5D(CXG(#H@
M)SXG*2`N"B`@("`@("`@("`@("`@("!H=&UL<W!E8VEA;&-H87)S*"1N86UE
M*2`N("<\+V]P=&EO;CXG.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1H
M=&UL("X@)SPO<V5L96-T/B<["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T2F%V
M85-C<FEP="@D9F]R;6YA;64L("1E;&5M96YT;F%M92D*("`@('L*("`@("`@
M("`D<')O;7!T(#T@861D<VQA<VAE<RA?*")0;&5A<V4@='EP92!T:&4@;F5W
M(&-A=&5G;W)Y(&YA;64Z(BDI.PH@("`@("`@("1E<G)O<B`](&%D9'-L87-H
M97,H7R@B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(I*3L*
M"B`@("`@("`@<F5T=7)N(#P\/$I!5D%30U))4%0*"CQS8W)I<'0@='EP93TB
M=&5X="]J879A<V-R:7!T(CX*/"$M+0IF=6YC=&EO;B!C:&5C:T-A=&5G;W)Y
M*"D*>PH@("`@:68@*&1O8W5M96YT+B1F;W)M;F%M92XD96QE;65N=&YA;64N
M=F%L=64@/3T@)RIN97<J)RD@>PH@("`@("`@('9A<B!C871E9V]R>2`]('=I
M;F1O=RYP<F]M<'0H)R1P<F]M<'0G+"`G)RD["B`@("`@("`@:68@*&-A=&5G
M;W)Y("$](&YU;&P@)B8@8V%T96=O<GD@(3T@)R<I('L*("`@("`@("`@("`@
M9&]C=6UE;G0N)&9O<FUN86UE+FYE=U]C871E9V]R>2YV86QU92`](&-A=&5G
M;W)Y.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('=I;F1O=RYA;&5R
M="@G)&5R<F]R)RD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"B`@("!](&5L<V4@:68@*&1O8W5M96YT+B1F;W)M;F%M92XD96QE;65N
M=&YA;64N=F%L=64N:6YD97A/9B@G*FYE=RHG*2`A/2`M,2D@>PH@("`@("`@
M(&1O8W5M96YT+B1F;W)M;F%M92YN97=?8V%T96=O<GDN=F%L=64@/2!D;V-U
M;65N="XD9F]R;6YA;64N)&5L96UE;G1N86UE+G9A;'5E+G-U8G-T<B@U+"!D
M;V-U;65N="XD9F]R;6YA;64N)&5L96UE;G1N86UE+G9A;'5E+FQE;F=T:"D[
M"B`@("!]"@H@("`@<F5T=7)N('1R=64["GT*+R\M+3X*/"]S8W)I<'0^"DI!
M5D%30U))4%0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@82!N97<@8V%T
M96=O<GDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V%T96=O<GD@
M(%1H92!N86UE(&]F('1H92!C871E9V]R>2!T;R!A9&0N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@1F%L<V4@;VX@9F%I;'5R92P@;W(@=&AE(&YE
M=R!C871E9V]R>2=S(&YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9"@D
M8V%T96=O<GDI"B`@("!["B`@("`@("`@9VQO8F%L("1P<F5F<SL*"B`@("`@
M("`@:68@*"1P<F5F<RT^:7-,;V-K960H)V-A=&5G;W)I97,G*2!\?"!E;7!T
M>2@D8V%T96=O<GDI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@("1C871E9V]R:65S(#T@4')E9G-?0V%T96=O<GE-
M86YA9V5R.CIG970H*3L*("`@("`@("!I9B`H:6Y?87)R87DH)&-A=&5G;W)Y
M+"`D8V%T96=O<FEE<RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@)&-A=&5G;W)I97-;72`]("1C871E9V]R>3L*
M("`@("`@("`D<')E9G,M/G-E=%9A;'5E*"=C871E9V]R:65S)RP@:6UP;&]D
M92@G?"<L("1C871E9V]R:65S*2D["@H@("`@("`@(')E='5R;B`D8V%T96=O
M<GD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&4@82!C871E9V]R>2X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C871E9V]R>2`@5&AE(&-A
M=&5G;W)Y('1O(')E;6]V92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5M;W9E*"1C871E9V]R>2D*("`@('L*("`@("`@
M("!G;&]B86P@)'!R969S.PH*("`@("`@("!I9B`H)'!R969S+3YI<TQO8VME
M9"@G8V%T96=O<FEE<R<I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"@H@("`@("`@("1C871E9V]R:65S(#T@4')E9G-?0V%T96=O
M<GE-86YA9V5R.CIG970H*3L*"B`@("`@("`@)&ME>2`](&%R<F%Y7W-E87)C
M:"@D8V%T96=O<GDL("1C871E9V]R:65S*3L*("`@("`@("!I9B`H)&ME>2`]
M/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N("1K97D["B`@("`@("`@
M?0H*("`@("`@("!U;G-E="@D8V%T96=O<FEE<ULD:V5Y72D["B`@("`@("`@
M)'!R969S+3YS971686QU92@G8V%T96=O<FEE<R<L(&EM<&QO9&4H)WPG+"`D
M8V%T96=O<FEE<RDI.PH*("`@("`@("`O+R!296UO=F4@86YY(&-O;&]R('-E
M='1I;F=S(&9O<B`D8V%T96=O<GDN"B`@("`@("`@)&-O;&]R<R`](%!R969S
M7T-A=&5G;W)Y36%N86=E<CHZ8V]L;W)S*"D["B`@("`@("`@=6YS970H)&-O
M;&]R<ULD8V%T96=O<GE=*3L*("`@("`@("!0<F5F<U]#871E9V]R>4UA;F%G
M97(Z.G-E=$-O;&]R<R@D8V]L;W)S*3L*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C;VQO<B!F;W(@
M96%C:"!O9B!T:&4@=7-E<B=S(&-A=&5G;W)I97,N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@02!L:7-T(&]F(&-O;&]R<RP@:V5Y(&ES('1H92!C
M871E9V]R>2!N86UE+"!V86QU92!I<R!T:&4*("`@("`J("`@("`@("`@("`@
M("`@($A434P@8V]L;W(@8V]D92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]L
M;W)S*"D*("`@('L*("`@("`@("!G;&]B86P@)'!R969S.PH*("`@("`@("`O
M*B!$969A=6QT('9A;'5E<R!T:&%T(&-A;B!B92!O=F5R<FED9&5N(&)U="!M
M=7-T(&%L=V%Y<R!B90H@("`@("`@("`J('!R97-E;G0N("HO"B`@("`@("`@
M)&-O;&]R<ULG7V1E9F%U;'1?)UT@/2`G(T9&1D9&1B<["B`@("`@("`@)&-O
M;&]R<ULG7W5N9FEL961?)UT@/2`G(T1$1$1$1"<["@H@("`@("`@("1P86ER
M<R`](&5X<&QO9&4H)WPG+"`D<')E9G,M/F=E=%9A;'5E*"=C871E9V]R>5]C
M;VQO<G,G*2D["B`@("`@("`@9F]R96%C:"`H)'!A:7)S(&%S("1P86ER*2![
M"B`@("`@("`@("`@(&EF("@A96UP='DH)'!A:7(I*2!["B`@("`@("`@("`@
M("`@("!L:7-T*"1C871E9V]R>2P@)&-O;&]R*2`](&5X<&QO9&4H)SHG+"`D
M<&%I<BD["B`@("`@("`@("`@("`@("`D8V]L;W)S6R1C871E9V]R>5T@/2`D
M8V]L;W(["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1C;VQO
M<G-;)R==(#T@)&-O;&]R<ULG7W5N9FEL961?)UT["@H@("`@("`@(')E='5R
M;B`D8V]L;W)S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M9F]R96=R;W5N9"!C;VQO<B!F;W(@96%C:"!O9B!T:&4@=7-E<B=S(&-A=&5G
M;W)I97,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!L:7-T(&]F
M(&-O;&]R<RP@:V5Y(&ES('1H92!C871E9V]R>2!N86UE+"!V86QU92!I<R!T
M:&4*("`@("`J("`@("`@("`@("`@("`@($A434P@8V]L;W(@8V]D92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9F=#;VQO<G,H*0H@("`@>PH@("`@("`@(')E
M<75I<F5?;VYC92`G2&]R9&4O26UA9V4N<&AP)SL*"B`@("`@("`@)&-O;&]R
M<R`](%!R969S7T-A=&5G;W)Y36%N86=E<CHZ8V]L;W)S*"D["B`@("`@("`@
M)&9G8V]L;W)S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D8V]L;W)S
M(&%S("1N86UE(#T^("1C;VQO<BD@>PH@("`@("`@("`@("`D9F=C;VQO<G-;
M)&YA;65=(#T@2&]R9&5?26UA9V4Z.F)R:6=H=&YE<W,H)&-O;&]R*2`\(#$R
M."`_("<C9C9F-F8V)R`Z("<C,#`P)SL*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D9F=C;VQO<G,["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T0V]L;W(H
M)&-A=&5G;W)Y+"`D8V]L;W(I"B`@("!["B`@("`@("`@)&-O;&]R<R`](%!R
M969S7T-A=&5G;W)Y36%N86=E<CHZ8V]L;W)S*"D["B`@("`@("`@)&-O;&]R
M<ULD8V%T96=O<GE=(#T@)&-O;&]R.PH@("`@("`@(%!R969S7T-A=&5G;W)Y
M36%N86=E<CHZ<V5T0V]L;W)S*"1C;VQO<G,I.PH@("`@?0H*("`@(&9U;F-T
M:6]N('-E=$-O;&]R<R@D8V]L;W)S*0H@("`@>PH@("`@("`@(&=L;V)A;"`D
M<')E9G,["@H@("`@("`@("1P86ER<R`](&%R<F%Y*"D["B`@("`@("`@9F]R
M96%C:"`H)&-O;&]R<R!A<R`D8V%T96=O<GD@/3X@)&-O;&]R*2!["B`@("`@
M("`@("`@(&EF("@A96UP='DH)&-A=&5G;W)Y*2D@>PH@("`@("`@("`@("`@
M("`@)'!A:7)S6UT@/2`B)&-A=&5G;W)Y.B1C;VQO<B(["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("1P<F5F<RT^<V5T5F%L=64H)V-A=&5G
M;W)Y7V-O;&]R<R<L(&EM<&QO9&4H)WPG+"`D<&%I<G,I*3L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]0<F5F<R]I
M;7-P+G!H<```````````````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`W
M-S``,3`U,34T,S,W-#<`,#(R,C,U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!0<F5F97)E;F-E('-T
M;W)A9V4@:6UP;&5M96YT871I;VX@9F]R(&%N($E-4U`@<V5R=F5R+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]I;7-P+G!H<"QV(#$N
M,2XQ,"XQ,2`R,#`V+S`R+S(X(#`U.C4Y.C$Y('-L=7-A<GH@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!-:6-H865L(%)U8FEN<VMY(#QM<G5B
M:6YS:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-
M:6-H865L(%)U8FEN<VMY(#QM<G5B:6YS:T!H;W)D92YO<F<^"B`J($!P86-K
M86=E($AO<F1E7U!R969S"B`J+PIC;&%S<R!0<F5F<U]I;7-P(&5X=&5N9',@
M4')E9G,@>PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(@9G5N8W1I;VXN
M"B`@("`@*B`D<&%R86US(&UU<W0@8V]N=&%I;CH*("`@("`J("=A=71H7VUE
M=&AO9"<L("=S97)V97(G+"`G<&]R="<*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("`D=7-E<B`@("`@57-E<FYA;64@;V8@8W5R<F5N="!U<V5R+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)'!A<W-W;W)D(%!A<W-W;W)D(&9O<B!C
M=7)R96YT('5S97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V-O<&4@("`@
M5&AE('-C;W!E(&9O<B!T:&5S92!P<F5F97)E;F-E<RX*("`@("`J($!P87)A
M;2!A<G)A>2`@("1P87)A;7,@("!4:&4@<&%R86UE=&5R<R!N965D960@9F]R
M('1H:7,@;V)J96-T+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&-A8VAI;F<@
M($%R92!W92!U<VEN9R!S97-S:6]N(&-A8VAE/PH@("`@("HO"B`@("!F=6YC
M=&EO;B!0<F5F<U]I;7-P*"1U<V5R+"`D<&%S<W=O<F0@/2`G)RP@)'-C;W!E
M(#T@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;7,@/2!N=6QL
M+"`D8V%C:&EN9R`]('1R=64I"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF
M.PH*("`@("`@("!P87)E;G0Z.E!R969S*"D["B`@("`@("`@<F5Q=6ER95]O
M;F-E("=.970O24U34"YP:'`G.PH*("`@("`@("`D=&AI<RT^7W-C;W!E(#T@
M)'-C;W!E.PH@("`@("`@("1T:&ES+3Y?8V%C:&EN9R`]("1C86-H:6YG.PH@
M("`@("`@("1T:&ES+3Y?=7-E<B`]("1U<V5R.PH@("`@("`@("1T:&ES+3YP
M87)A;7,@/2`D<&%R86US.PH*("`@("`@("!I9B`H<')E9U]M871C:"@G+RA>
M+BHI0"\G+"`D=7-E<BP@)&UA=&-H97,I*2!["B`@("`@("`@("`@("1T:&ES
M+3YP87)A;7-;)W5S97)N86UE)UT@/2`D;6%T8VAE<ULQ73L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^<&%R86US6R=U<V5R;F%M92==
M(#T@)'5S97(["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YP87)A;7-;)W!A
M<W-W;W)D)UT@/2`D<&%S<W=O<F0["B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3YP87)A;7-;)W-O8VME="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^<&%R
M86US6R=S;V-K970G72`]("1P87)A;7-;)W-O8VME="==("X@)VEM<W!?)R`N
M("1T:&ES+3YP87)A;7-;)W5S97)N86UE)UT@+B`G+G-C:R<["B`@("`@("`@
M?0H@("`@("`@("1T:&ES+3Y?:6US<"`]("9.971?24U34#HZ<VEN9VQE=&]N
M*"=/<'1I;VYS)RP@)'1H:7,M/G!A<F%M<RD["B`@("`@("`@)')E<W5L="`]
M("1T:&ES+3Y?:6US<"T^:6YI="@I.PH@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L
M*"1R97-U;'0L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@
M("`@("1T:&ES+3Y?:6US<"T^<V5T3&]G9V5R*"1C;VYF6R=L;V<G72D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V97,@=&AE(')E<75E<W1E9"!S
M970@;V8@<')E9F5R96YC97,@9G)O;2!T:&4@24U34"!S97)V97(N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@
M4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5T<FEE=F4H*0H@("`@>PH@("`@("`@("\J($=E="!T:&4@9&5F
M875L=',N("HO"B`@("`@("`@<&%R96YT.CIR971R:65V92@I.PH*("`@("`@
M("`O*B!'970@=&AE('-H87)E9"!P<F5F<R!A;F0@<F5M;W9E('1H92!S8V]P
M92!V86QU92!F<F]M('1H90H@("`@("`@("`J('-T<FEN9RX@*B\*("`@("`@
M("`D9VQO8F%L7W!R969S(#T@)'1H:7,M/E]I;7-P+3YG970H)VAO<F1E+BHG
M*3L*("`@("`@("!I9B`H:7-?82@D9VQO8F%L7W!R969S+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D9VQO8F%L7W!R969S.PH@("`@
M("`@('T*"B`@("`@("`@9F]R96%C:"`H)&=L;V)A;%]P<F5F<R!A<R`D:V5Y
M(#T^("1V86PI('L*("`@("`@("`@("`@)&YE=TME>2`]('-T<E]R97!L86-E
M*"=H;W)D92XG+"`G)RP@)&ME>2D["B`@("`@("`@("`@(&EF("@D=F%L(#T]
M("<M)RD@>PH@("`@("`@("`@("`@("`@)'9A;"`]("1T:&ES+3YG971$969A
M=6QT*"1N97=+97DI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/E]P<F5F<ULD;F5W2V5Y72DI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3YS971686QU92@D;F5W2V5Y+"`D=F%L*3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3YA9&0H)&YE=TME
M>2P@)'9A;"P@7U!2149?4TA!4D5$*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@+RH@1&]N)W0@9F]R9V5T('1O(&-L96%N(&ET+B`J+PH@("`@("`@
M("`@("`D=&AI<RT^<V5T1&ER='DH)&YE=TME>2P@9F%L<V4I.PH@("`@("`@
M('T*"B`@("`@("`@+RH@3F]W('1H92!A<'`@<W!E8VEF:6,@<')E9G,N("HO
M"B`@("`@("`@)&QO8V%L7W!R969S(#T@)'1H:7,M/E]I;7-P+3YG970H)'1H
M:7,M/E]S8V]P92`N("<N*B<I.PH@("`@("`@(&EF("AI<U]A*"1L;V-A;%]P
M<F5F<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&QO
M8V%L7W!R969S.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)&QO8V%L
M7W!R969S(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`D;F5W2V5Y
M(#T@<W1R7W)E<&QA8V4H)'1H:7,M/E]S8V]P92`N("<N)RP@)R<L("1K97DI
M.PH@("`@("`@("`@("!I9B`H)'9A;"`]/2`G+2<I('L*("`@("`@("`@("`@
M("`@("1V86P@/2`D=&AI<RT^9V5T1&5F875L="@D;F5W2V5Y*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P<F5F<ULD
M;F5W2V5Y72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3YS971686QU92@D
M;F5W2V5Y+"`D=F%L*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1T:&ES+3YA9&0H)&YE=TME>2P@)'9A;"P@,"D["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("\J($-L96%N('1H92!P<F5F+B`J+PH@("`@
M("`@("`@("`D=&AI<RT^<V5T1&ER='DH)&YE=TME>2P@9F%L<V4I.PH@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/E]C86QL2&]O:W,H*3L*("`@("`@("`D
M=&AI<RT^8V%C:&55<&1A=&4H*3L*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-T;W)E<R!A;&P@9&ER='D@<')E9G,@=&\@
M24U34"!S97)V97(N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U
M92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@<W1O<F4H*0H@("`@>PH@("`@("`@
M("1D:7)T>5]P<F5F<R`]("1T:&ES+3Y?9&ER='E0<F5F<R@I.PH@("`@("`@
M(&EF("@A8V]U;G0H)&1I<G1Y7W!R969S*2D@>PH@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1D:7)T>5]P
M<F5F<R!A<R`D;F%M92D@>PH@("`@("`@("`@("`D<V-O<&4@/2`D=&AI<RT^
M9V5T4V-O<&4H)&YA;64I.PH@("`@("`@("`@("`D=F%L=64@/2`D=&AI<RT^
M9V5T5F%L=64H)&YA;64I.PH@("`@("`@("`@("!I9B`H96UP='DH)'9A;'5E
M*2D@>PH@("`@("`@("`@("`@("`@)'9A;'5E(#T@)RTG.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YS970H
M)'-C;W!E("X@)RXG("X@)&YA;64L("1V86QU92D["B`@("`@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@("1'3$]"04Q36R=N;W1I9FEC871I;VXG72T^<'5S:"@B5&AE<F4@=V%S
M(&$@<')O8FQE;2!S879I;F<@=&AE('!R969R96YC97,B*3L*("`@("`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`O*B!#;&5A;B!T:&4@<')E9B!S:6YC92!I="!W87,@:G5S="!S879E
M9"X@*B\*("`@("`@("`@("`@)'1H:7,M/G-E=$1I<G1Y*"1N86UE+"!F86QS
M92D["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YC86-H955P9&%T92@I.PH@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*?0H``````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U!R969S+VMO;&%B+G!H<```
M````````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S,V-P`Q,#4Q-30S
M,S<T-@`P,C(S-C``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O4')E9G,O;&1A
M<"YP:'`G.PH*+RHJ"B`J($MO;&%B(&EM<&QE;65N=&%T:6]N(&]F('1H92!(
M;W)D92!P<F5F97)E;F-E('-Y<W1E;2X@1&5R:79E<R!F<F]M('1H90H@*B!0
M<F5F<U]L9&%P($Q$05`@875T:&5N=&EC871I;VX@;V)J96-T+"!A;F0@<VEM
M<&QY('!R;W9I9&5S('!A<F%M971E<G,@=&\@:70*("H@8F%S960@;VX@=&AE
M(&=L;V)A;"!+;VQA8B!C;VYF:6=U<F%T:6]N+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]K;VQA8BYP:'`L=B`Q+C$N,3`N."`R,#`V
M+S`V+S(Q(#(P.C`Y.C`W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M-"TR,#`V(%-T=6%R="!":6YG92`\<RYB:6YG94!C;V1E9G5S:6]N+F-O+GIA
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@4W1U87)T($)I;F=E(#QS
M+F)I;F=E0&-O9&5F=7-I;VXN8V\N>F$^"B`J($!S:6YC92`@($AO<F1E(#$N
M,PH@*B!`<&%C:V%G92!(;W)D95]0<F5F<PH@*B\*8VQA<W,@4')E9G-?:V]L
M86(@97AT96YD<R!0<F5F<U]L9&%P('L*"B`@("`O*BH*("`@("`J($-O;G-T
M<G5C=',@82!N97<@2V]L86(@<')E9F5R96YC97,@;V)J96-T+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'5S97(@("`@("!4:&4@=7-E<B!W:&\@
M;W=N<R!T:&5S92!P<F5F97)E;F-E<RX*("`@("`J($!P87)A;2!S=')I;F<@
M)'!A<W-W;W)D("!4:&4@<&%S<W=O<F0@87-S;V-I871E9"!W:71H("1U<V5R
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V-O<&4@("`@(%1H92!C=7)R96YT
M(&%P<&QI8V%T:6]N('-C;W!E+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@("`@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R
M<RX*("`@("`J($!P87)A;2!B;V]L96%N("1C86-H:6YG("!3:&]U;&0@8V%C
M:&EN9R!B92!U<V5D/PH@("`@("HO"B`@("!F=6YC=&EO;B!0<F5F<U]K;VQA
M8B@D=7-E<BP@)'!A<W-W;W)D+"`D<V-O<&4@/2`G)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@I+"`D8V%C:&EN9R`](&9A
M;'-E*0H@("`@>PH@("`@("`@("1P87)A;7-;)VAO<W1S<&5C)UT@/2`D1TQ/
M0D%,4ULG8V]N9B==6R=K;VQA8B==6R=L9&%P)UU;)W-E<G9E<B==.PH@("`@
M("`@("1P87)A;7-;)W!O<G0G72`]("1'3$]"04Q36R=C;VYF)UU;)VMO;&%B
M)UU;)VQD87`G75LG<&]R="==.PH@("`@("`@("1P87)A;7-;)W9E<G-I;VXG
M72`]("<S)SL*("`@("`@("`D<&%R86US6R=B87-E9&XG72`]("1'3$]"04Q3
M6R=C;VYF)UU;)VMO;&%B)UU;)VQD87`G75LG8F%S961N)UT["B`@("`@("`@
M)'!A<F%M<ULG9F5T8VAD;B==(#T@=')U93L*("`@("`@("`D<&%R86US6R=S
M96%R8VAD;B==(#T@)$=,3T)!3%-;)V-O;F8G75LG:V]L86(G75LG;&1A<"==
M6R=P:'!D;B==.PH@("`@("`@("1P87)A;7-;)W-E87)C:'!A<W,G72`]("1'
M3$]"04Q36R=C;VYF)UU;)VMO;&%B)UU;)VQD87`G75LG<&AP<'<G73L*("`@
M("`@("`D<&%R86US6R=U:60G72`](&%R<F%Y*"=M86EL)RP@)W5I9"<I.PH*
M("`@("`@("!P87)E;G0Z.E!R969S7VQD87`H)'5S97(L("1P87-S=V]R9"P@
M)'-C;W!E+"`D<&%R86US+"`D8V%C:&EN9RD["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]0<F5F<R]L9&%P+G!H<```````````
M````````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-3`Q,#,`,3`U,34T,S,W-#8`
M,#(R,3<V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@HO*BH*("H@2&]R9&5?4W1R:6YG(&-L87-S+@H@*B\*<F5Q
M=6ER95]O;F-E("=(;W)D92]3=')I;F<N<&AP)SL*"B\J*@H@*B!0<F5F97)E
M;F-E<R!S=&]R86=E(&EM<&QE;65N=&%T:6]N(&9O<B!02%`G<R!,1$%0(&5X
M=&5N=&EO;BX*("H*("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@
M("=B87-E9&XG("`@(%1H92!B87-E($1.(&9O<B!T:&4@3$1!4"!S97)V97(N
M"B`J("`@)VAO<W1S<&5C)R`@5&AE(&AO<W1N86UE(&]F('1H92!,1$%0('-E
M<G9E<BX*("H@("`G=6ED)R`@("`@("!4:&4@=7-E<FYA;64@<V5A<F-H(&ME
M>2X\+W!R93X*("H*("H@3W!T:6]N86P@<&%R86UE=&5R<SH\<')E/@H@*B`@
M("=P87-S=V]R9"<@("=R;V]T9&XG<R!P87-S=V]R9"!F;W(@8FEN9"!A=71H
M96YT:6-A=&EO;BX*("H@("`G<&]R="<@("`@("!4:&4@<&]R="!O9B!T:&4@
M3$1!4"!S97)V97(N"B`J("`@("`@("`@("`@("`@1$5&055,5#H@,S@Y"B`J
M("`@)W)O;W1D;B<@("`@5&AE($1.(&]F('1H92!R;V]T("AA9&UI;FES=')A
M=&EV92D@86-C;W5N="!T;R!B:6YD(&9O<@H@*B`@("`@("`@("`@("`@('=R
M:71E(&]P97)A=&EO;G,N"B`J("`@)W5S97)N86UE)R`@5$]$3PH@*B`@("=V
M97)S:6]N)R`@(%1H92!V97)S:6]N(&]F('1H92!,1$%0('!R;W1O8V]L('1O
M('5S92X*("H@("`@("`@("`@("`@("!$149!54Q4.B!.3TY%("AS>7-T96T@
M9&5F875L="!W:6QL(&)E('5S960I/"]P<F4^"B`J"B`J($Y/5$4Z('!A<F%M
M971E<B`G=7-E<FYA;64G(&AA<R!B965N(&1E<')E8V%T960N(%5S92`G<F]O
M=&1N)RX*("H*("H*("H@268@<V5T=&EN9R!U<"!A<R!T:&4@2&]R9&4@<')E
M9F5R96YC92!H86YD;&5R(&EN(&-O;F8N<&AP+"!T:&4@9F]L;&]W:6YG"B`J
M(&ES(&%N(&5X86UP;&4@8V]N9FEG=7)A=&EO;BX*("H@5&AE('-C:&5M87,@
M;F5E9&5D(&9O<B!L9&%P(&%R92!I;B!H;W)D92]S8W)I<'1S+VQD87`N"B`J
M"B`J(#QP<F4^"B`J("`@)&-O;F9;)W!R969S)UU;)V1R:79E<B==(#T@)VQD
M87`G.PH@*B`@("1C;VYF6R=P<F5F<R==6R=P87)A;7,G75LG:&]S='-P96,G
M72`]("=L;V-A;&AO<W0G.PH@*B`@("1C;VYF6R=P<F5F<R==6R=P87)A;7,G
M75LG<&]R="==(#T@)S,X.2<["B`J("`@)&-O;F9;)W!R969S)UU;)W!A<F%M
M<R==6R=B87-E9&XG72`]("=D8SUE>&%M<&QE+&1C/6]R9R<["B`J("`@)&-O
M;F9;)W!R969S)UU;)W!A<F%M<R==6R=U:60G72`]("=M86EL)SL*("H@/"]P
M<F4^"B`J"B`J(%1H92!F;VQL;W=I;F<@:7,@=F%L:60@8G5T('=O=6QD(&]N
M;'D@8F4@;F5C97-S87)Y(&EF('5S97)S"B`J(&1O($Y/5"!H879E('!E<FUI
M<W-I;VX@=&\@;6]D:69Y('1H96ER(&]W;B!,1$%0(&%C8V]U;G1S+@H@*@H@
M*B`\<')E/@H@*B`@("1C;VYF6R=P<F5F<R==6R=P87)A;7,G75LG<F]O=&1N
M)UT@/2`G8VX]36%N86=E<BQD8SUE>&%M<&QE+&1C/6]R9R<["B`J("`@)&-O
M;F9;)W!R969S)UU;)W!A<F%M<R==6R=P87-S=V]R9"==(#T@)W!A<W-W;W)D
M)SL*("H@/"]P<F4^"B`J"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U!R969S
M+U!R969S+VQD87`N<&AP+'8@,2XX-2XQ,"XR,"`R,#`V+S`V+S(Q(#(P.C`W
M.C4U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!0
M87)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(
M;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?4')E9G,*("HO"F-L87-S(%!R
M969S7VQD87`@97AT96YD<R!0<F5F<R!["@H@("`@+RHJ"B`@("`@*B!(87-H
M(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R86US(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("`J($AA;F1L92!F;W(@=&AE(&-U<G)E;G0@
M3$1!4"!C;VYN96-T:6]N+@H@("`@("H*("`@("`J($!V87(@<F5S;W5R8V4*
M("`@("`J+PH@("`@=F%R("1?8V]N;F5C=&EO;CL*"B`@("`O*BH*("`@("`J
M($)O;VQE86X@:6YD:6-A=&EN9R!W:&5T:&5R(&]R(&YO="!W92=R92!C;VYN
M96-T960@=&\@=&AE($Q$05`@<V5R=F5R+@H@("`@("H*("`@("`J($!V87(@
M8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]C;VYN96-T960@/2!F86QS93L*
M"B`@("`O*BH*("`@("`J(%-T<FEN9R!H;VQD:6YG('1H92!U<V5R)W,@1$XN
M"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?
M9&X@/2`G)SL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@3$1!
M4"!P<F5F97)E;F-E<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=7-E<B`@("`@(%1H92!U<V5R('=H;R!O=VYS('1H97-E('!R969E
M<F5N8V5S+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%S<W=O<F0@(%1H92!P
M87-S=V]R9"!A<W-O8VEA=&5D('=I=&@@)'5S97(N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1S8V]P92`@("`@5&AE(&-U<G)E;G0@87!P;&EC871I;VX@<V-O
M<&4N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@("`@02!H87-H(&-O
M;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&-A8VAI;F<@(%-H;W5L9"!C86-H:6YG(&)E('5S960_"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%!R969S7VQD87`H)'5S97(L("1P87-S=V]R
M9"P@)'-C;W!E(#T@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("1P87)A
M;7,@/2!A<G)A>2@I+"`D8V%C:&EN9R`](&9A;'-E*0H@("`@>PH@("`@("`@
M(&EF("@A571I;#HZ97AT96YS:6]N17AI<W1S*"=L9&%P)RDI('L*("`@("`@
M("`@("`@2&]R9&4Z.F9A=&%L*%!%05(Z.G)A:7-E17)R;W(H7R@B4')E9G-?
M;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(I*2P@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3Y?=7-E<B`]("1U<V5R.PH@("`@("`@("1T:&ES+3Y?<V-O<&4@/2`D<V-O
M<&4["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@("`@
M("1T:&ES+3Y?8V%C:&EN9R`]("1C86-H:6YG.PH*("`@("`@("`O*B!)9B!A
M('9A;&ED('-E<G9E<B!P;W)T(&AA<R!N;W0@8F5E;B!S<&5C:69I960L('-E
M="!T:&4@9&5F875L="X@*B\*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?
M<&%R86US6R=P;W)T)UTI('Q\("%I<U]I;G0H)'1H:7,M/E]P87)A;7-;)W!O
M<G0G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!O<G0G72`]
M(#,X.3L*("`@("`@("!]"@H@("`@("`@("\J($EF("1P87)A;7-;)W)O;W1D
M;B==(&ES(&5M<'1Y+"!A=71H96YT:6-A=&4@87,@=&AE(&-U<G)E;G0@=7-E
M<BX*("`@("`@("`@("!.;W1E.B!4:&ES(&%S<W5M97,@=&AE('5S97(@:7,@
M86QL;W=E9"!T;R!M;V1I9GD@=&AE:7(@;W=N($Q$05`*("`@("`@("`@("`@
M("`@("!E;G1R>2X@*B\*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A
M;7-;)W5S97)N86UE)UTI("8F"B`@("`@("`@("`@(&5M<'1Y*"1T:&ES+3Y?
M<&%R86US6R=R;V]T9&XG72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W5S97)N86UE)UT@/2`D=7-E<CL*("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W!A<W-W;W)D)UT@/2`D<&%S<W=O<F0["B`@("`@("`@?0H*("`@
M("`@("!P87)E;G0Z.E!R969S*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/
M<&5N<R!A(&-O;FYE8W1I;VX@=&\@=&AE($Q$05`@<V5R=F5R+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN96-T*"D*
M("`@('L*("`@("`@("`O*B!2971U<FX@:68@86QR96%D>2!C;VYN96-T960N
M("HO"B`@("`@("`@:68@*"1T:&ES+3Y?8V]N;F5C=&5D*2!["B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@2&]R9&4Z.F%S
M<V5R=$1R:79E<D-O;F9I9R@D=&AI<RT^7W!A<F%M<RP@)W!R969S)RP*("`@
M("`@("`@("`@87)R87DH)VAO<W1S<&5C)RP@)V)A<V5D;B<L("=U:60G+"`G
M<&%S<W=O<F0G*2P*("`@("`@("`@("`@)W!R969E<F5N8V5S($Q$05`G*3L*
M"B`@("`@("`@+RH@06QL;W<@9F]R(&UU;'1I<&QE('5I9"!S96%R8V@@9FEE
M;&1S("HO"B`@("`@("`@:68@*"%I<U]A<G)A>2@D=&AI<RT^7W!A<F%M<ULG
M=6ED)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=U:60G72`]
M(&%R<F%Y*"1T:&ES+3Y?<&%R86US6R=U:60G72D["B`@("`@("`@?0H*("`@
M("`@("`O*B!#;VYN96-T('1O('1H92!,1$%0('-E<G9E<B!A;F]N>6UO=7-L
M>2X@*B\*("`@("`@("`D8V]N;B`](&QD87!?8V]N;F5C="@D=&AI<RT^7W!A
M<F%M<ULG:&]S='-P96,G72P@)'1H:7,M/E]P87)A;7-;)W!O<G0G72D["B`@
M("`@("`@:68@*"$D8V]N;BD@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92@*("`@("`@("`@("`@("`@('-P<FEN=&8H)T9A:6QE9"!T;R!O<&5N
M(&%N($Q$05`@8V]N;F5C=&EO;B!T;R`E<RXG+`H@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72DL"B`@("`@("`@
M("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!3970@=&AE($Q$05`@
M<')O=&]C;VP@=F5R<VEO;BX@*B\*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]P87)A;7-;)W9E<G-I;VXG72DI('L*("`@("`@("`@("`@:68@*"%L9&%P
M7W-E=%]O<'1I;VXH)&-O;FXL($Q$05!?3U!47U!23U1/0T],7U9%4E-)3TXL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=V97)S:6]N)UTI*2!["B`@("`@("`@("`@("`@("!(;W)D93HZ;&]G
M365S<V%G92@*("`@("`@("`@("`@("`@("`@("!S<')I;G1F*"=3970@3$1!
M4"!P<F]T;V-O;"!V97)S:6]N('1O("5D(&9A:6QE9#H@6R5D72`E<R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=F5R
M<VEO;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@;&1A<%]E<G)N
M;R@D=&AI<RT^7V-O;FYE8W1I;VXI+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@;&1A<%]E<G)O<B@D=&AI<RT^7V-O;FYE8W1I;VXI*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($EF(&YE8V5S<V%R
M>2P@8FEN9"!T;R!T:&4@3$1!4"!S97)V97(@87,@=&AE('5S97(@=VET:"!S
M96%R8V@*("`@("`@("`@*B!P97)M:7-S:6]N<RX@*B\*("`@("`@("!I9B`H
M(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=S96%R8VAD;B==*2D@>PH@("`@("`@
M("`@("`D8FEN9"`]($!L9&%P7V)I;F0H)&-O;FXL("1T:&ES+3Y?<&%R86US
M6R=S96%R8VAD;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)W-E87)C:'!A<W,G72D["B`@("`@("`@("`@(&EF
M("@A)&)I;F0I('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*'-P<FEN=&8H)T)I;F0@=&\@<V5R=F5R("5S.B5D('=I=&@@1$X@
M)7,@9F%I;&5D.B!;)61=("5S)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VAO<W1S
M<&5C)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P;W)T)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=S96%R8VAD;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!L9&%P7V5R<FYO*"1T:&ES+3Y?8V]N
M;F5C=&EO;BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&QD87!?97)R;W(H)'1H:7,M/E]C;VYN96-T:6]N*2DI
M.PH@("`@("`@("`@("!]"@E]"@H@("`@("`@("\J(%)E9VES=&5R(&]U<B!C
M86QL8F%C:R!F=6YC=&EO;B!T;R!H86YD;&4@<F5F97)R86QS+B`J+PH@("`@
M("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)VQD87!?<V5T7W)E8FEN9%]P<F]C
M)RD@)B8*("`@("`@("`@("`@(6QD87!?<V5T7W)E8FEN9%]P<F]C*"1C;VYN
M+"!A<G)A>2@D=&AI<RP@)U]R96)I;F10<F]C)RDI*2!["B`@("`@("`@("`@
M($AO<F1E.CIL;V=-97-S86=E*`H@("`@("`@("`@("`@("`@<W!R:6YT9B@G
M4V5T(')E8FEN9"!P<F]C(&9A:6QE9#H@6R5D72`E<R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@(&QD87!?97)R;F\H)'1H:7,M/E]C;VYN96-T:6]N*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@;&1A<%]E<G)O<B@D=&AI<RT^7V-O
M;FYE8W1I;VXI*2P*("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@("\J(%-T;W)E('1H92!C;VYN96-T:6]N(&AA;F1L92!A="!T:&4@:6YS
M=&%N8V4@;&5V96PN("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T:6]N(#T@
M)&-O;FX["B`@("`@("`@)'1H:7,M/E]C;VYN96-T960@/2!T<G5E.PH*("`@
M("`@("!I9B`H(21T:&ES+3Y?<&%R86US6R=F971C:&1N)UTI('L*("`@("`@
M("`@("`@+RH@1&5F:6YE('1H92!$3B!O9B!T:&4@8W5R<F5N="!U<V5R+B`J
M+PH@("`@("`@("`@("`D=&AI<RT^7V1N(#T@<W!R:6YT9B@G)7,])7,L)7,G
M+"`D=&AI<RT^7W!A<F%M<ULG=6ED)UU;,%TL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?=7-E<BP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V)A<V5D;B==*3L*
M"B`@("`@("`@("`@("\J($%N9"!T:&4@1$X@;V8@=&AE(&%U=&AE;G1I8V%T
M:6YG('5S97(@*&UA>2!B92!T:&4@<V%M92!A<R!A8F]V92DN("HO"B`@("`@
M("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)W)O;W1D;B==*2D@
M>PH@("`@("`@("`@("`@("`@)&)I;F1?9&X@/2`D=&AI<RT^7W!A<F%M<ULG
M<F]O=&1N)UT["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D8FEN9%]D;B`]('-P<FEN=&8H)R5S/25S+"5S)RP@)'1H:7,M/E]P87)A
M;7-;)W5I9"==6S!=+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M92==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=B87-E9&XG
M72D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($)I;F0@=&\@=&AE
M($Q$05`@<V5R=F5R(&%S('1H92!A=71H96YT:6-A=&EN9R!U<V5R+B`J+PH@
M("`@("`@("`@("`D8FEN9"`]($!L9&%P7V)I;F0H)'1H:7,M/E]C;VYN96-T
M:6]N+"`D8FEN9%]D;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=P87-S=V]R9"==*3L*("`@("`@("`@("`@:68@
M*"$D8FEN9"D@>PH@("`@("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H
M"B`@("`@("`@("`@("`@("`@("`@<W!R:6YT9B@G0FEN9"!T;R!S97)V97(@
M)7,Z)60@=VET:"!$3B`E<R!F86EL960Z(%LE9%T@)7,G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M<&]R="==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&)I;F1?9&XL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!L9&%P7V5R<FYO*"1T:&ES
M+3Y?8V]N;F5C=&EO;BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!L
M9&%P7V5R<F]R*"1T:&ES+3Y?8V]N;F5C=&EO;BDI+`H@("`@("`@("`@("`@
M("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("\J(%-E87)C:"!F;W(@=&AE('5S97(G<R!F=6QL($1.+B`J+PH@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?<&%R86US6R=U:60G72!A<R`D=6ED7V9I96QD
M*2!["B`@("`@("`@("`@("1S96%R8V@@/2!L9&%P7W-E87)C:"@D=&AI<RT^
M7V-O;FYE8W1I;VXL("1T:&ES+3Y?<&%R86US6R=B87-E9&XG72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1U:61?9FEE;&0@+B`G/2<@
M+B`D=&AI<RT^7W5S97(L(&%R<F%Y*"=D;B<I*3L*("`@("`@("`@("`@:68@
M*"1S96%R8V@I('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2!L9&%P7V=E
M=%]E;G1R:65S*"1T:&ES+3Y?8V]N;F5C=&EO;BP@)'-E87)C:"D["B`@("`@
M("`@("`@("`@("!I9B`H)')E<W5L="`F)B`D<F5S=6QT6R=C;W5N="==(#X@
M,"D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&X@/2`D<F5S=6QT
M6S!=6R=D;B==.PH@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7W!A
M<F%M<ULG9F5T8VAD;B==*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\O
M(%)E+6)I;F0@87,@=&AE('5S97(N"B`@("`@("`@("`@("`@("`@("`@("`@
M("1B:6YD(#T@0&QD87!?8FEN9"@D=&AI<RT^7V-O;FYE8W1I;VXL("1T:&ES
M+3Y?9&XL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72D["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!(;W)D93HZ;&]G365S<V%G92@*("`@("`@("`@("`@<W!R:6YT9B@G
M1F%I;&5D('1O(')E=')I979E('5S97)<)W,@1$XZ(%LE9%T@)7,G+`H@("`@
M("`@("`@("`@("`@("`@(&QD87!?97)R;F\H)'1H:7,M/E]C;VYN96-T:6]N
M*2P*("`@("`@("`@("`@("`@("`@("!L9&%P7V5R<F]R*"1T:&ES+3Y?8V]N
M;F5C=&EO;BDI+`H@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH*
M("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M:7-C;VYN96-T(&9R;VT@=&AE($Q$05`@<V5R=F5R(&%N9"!C;&5A;B!U<"!T
M:&4@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S
M<RP@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V1I
M<V-O;FYE8W0H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V-O;FYE8W1E
M9"D@>PH@("`@("`@("`@("`D=&AI<RT^7V1N(#T@)R<["B`@("`@("`@("`@
M("1T:&ES+3Y?8V]N;F5C=&5D(#T@9F%L<V4["B`@("`@("`@("`@(')E='5R
M;B!L9&%P7V-L;W-E*"1T:&ES+3Y?8V]N;F5C=&EO;BD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@0V%L;&)A8VL@9G5N8W1I;VX@9F]R($Q$05`@
M<F5F97)R86QS+B`@5&AI<R!F=6YC=&EO;B!I<R!C86QL960@=VAE;B!A;@H@
M("`@("H@3$1!4"!O<&5R871I;VX@<F5T=7)N<R!A(')E9F5R<F%L('1O(&%N
M(&%L=&5R;F%T92!S97)V97(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("`Q(&]N(&5R<F]R
M+"`P(&]N('-U8V-E<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R96)I;F10
M<F]C*"1C;VYN+"`D=VAO*0H@("`@>PH@("`@("`@("\J(%-T<FEP(&]U="!T
M:&4@:&]S=&YA;64@=V4G<F4@8F5I;F<@<F5D:7)E8W1E9"!T;RX@*B\*("`@
M("`@("`D=VAO(#T@<')E9U]R97!L86-E*&%R<F%Y*"=\7BXJ.B\O?"<L("=\
M.EQD*B1\)RDL("<G+"`D=VAO*3L*"B`@("`@("`@+RH@1FEG=7)E(&]U="!T
M:&4@1$X@;V8@=&AE(&%U=&AE;G1I8V%T:6YG('5S97(N("HO"B`@("`@("`@
M:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG<F]O=&1N)UTI*2!["B`@("`@
M("`@("`@("1B:6YD7V1N(#T@)'1H:7,M/E]P87)A;7-;)W)O;W1D;B==.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1B:6YD7V1N(#T@<W!R:6YT
M9B@G)7,])7,L)7,G+"`D=&AI<RT^7W!A<F%M<ULG=6ED)UU;,%TL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E
M<FYA;64G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=B87-E9&XG72D["B`@("`@("`@?0H*("`@("`@("`O*B!-
M86ME('-U<F4@=&AE('-E<G9E<B!W92=R92!B96EN9R!R961I<F5C=&5D('1O
M(&ES(&EN(&]U<B!L:7-T(&]F"B`@("`@("`@("`@=F%L:60@<V5R=F5R<RX@
M*B\*("`@("`@("!I9B`H<W1R<&]S*"1T:&ES+3Y?<&%R86US6R=H;W-T<W!E
M8R==+"`D=VAO*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H"B`@("`@("`@("`@("`@("!S<')I;G1F*"=2969E<G)A;"!T
M87)G970@)7,@9F]R($1.("5S(&ES(&YO="!I;B!T:&4@875T:&]R:7IE9"!S
M97)V97(@;&ES="$G+"`D=VAO+"`D8FEN9%]D;BDL"B`@("`@("`@("`@("`@
M("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!R971U<FX@,3L*
M("`@("`@("!]"@H@("`@("`@("\J($)I;F0@=&\@=&AE(&YE=R!S97)V97(N
M("HO"B`@("`@("`@)&)I;F0@/2!`;&1A<%]B:6YD*"1C;VYN+"`D8FEN9%]D
M;BP@)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI.PH@("`@("`@(&EF("@A
M)&)I;F0I('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H"B`@("`@
M("`@("`@("`@("!S<')I;G1F*"=296)I;F0@=&\@<V5R=F5R("5S.B5D('=I
M=&@@1$X@)7,@9F%I;&5D.B!;)61=("5S)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P;W)T)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("1B:6YD7V1N+`H@("`@("`@("`@("`@("`@("`@
M("`@("!L9&%P7V5R<FYO*"1T:&ES+3Y?8V]N;F5C=&EO;BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@(&QD87!?97)R;W(H)'1H:7,M/E]C;VYN96-T:6]N
M*2DL"B`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N(#`["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971R:65V97,@=&AE(')E<75E<W1E9"!S970@;V8@<')E9F5R96YC97,@
M9G)O;2!T:&4@=7-E<B=S($Q$05`@96YT<GDN"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5T<FEE
M=F4H*0H@("`@>PH@("`@("`@("\J($%T=&5M<'0@=&\@<'5L;"!T:&4@=F%L
M=65S(&9R;VT@=&AE('-E<W-I;VX@8V%C:&4@9FER<W0N("HO"B`@("`@("`@
M:68@*"1T:&ES+3YC86-H94QO;VMU<"@I*2!["B`@("`@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@+RH@3&]A9"!D969A=6QT<R!T
M;R!M86ME('-U<F4@=V4@:&%V92!A;&P@<')E9F5R96YC97,N("HO"B`@("`@
M("`@<&%R96YT.CIR971R:65V92@I.PH*("`@("`@("`O*B!-86ME('-U<F4@
M=V4@87)E(&-O;FYE8W1E9"X@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H
M*3L*"B`@("`@("`@+RH@3VYL>2!F971C:"!T:&4@9FEE;&1S(&9O<B!T:&4@
M871T<FEB=71E<R!W92!N965D+B`J+PH@("`@("`@("1A='1R<R`](&%R<F%Y
M*"=H;W)D95!R969S)RD["B`@("`@("`@:68@*'-T<F-M<"@D=&AI<RT^7W-C
M;W!E+"`G:&]R9&4G*2`A/2`P*2!["B`@("`@("`@("`@("1A='1R<UM=(#T@
M)'1H:7,M/E]S8V]P92`N("=0<F5F<R<["B`@("`@("`@?0H*("`@("`@("`O
M*B!396%R8V@@9F]R('1H92!M=6QT:2UV86QU960@9FEE;&0@8V]N=&%I;FEN
M9R!T:&4@87)R87D@;V8*("`@("`@("`@("!P<F5F97)E;F-E<RX@*B\*("`@
M("`@("!F;W)E86-H("@D=&AI<RT^7W!A<F%M<ULG=6ED)UT@87,@)'5I9%]F
M:65L9"D@>PH@("`@("`@("`@("`D<V5A<F-H(#T@;&1A<%]S96%R8V@H)'1H
M:7,M/E]C;VYN96-T:6]N+"`D=&AI<RT^7W!A<F%M<ULG8F%S961N)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=6ED7V9I96QD("X@
M)STG("X@)'1H:7,M/E]U<V5R+"`D871T<G,I.PH@("`@("`@("`@("!I9B`H
M)'-E87)C:"D@>PH@("`@("`@("`@("`@("`@)')E<W5L="`](&QD87!?9V5T
M7V5N=')I97,H)'1H:7,M/E]C;VYN96-T:6]N+"`D<V5A<F-H*3L*("`@("`@
M("`@("`@("`@(&EF("@D<F5S=6QT("8F("1R97-U;'1;)V-O=6YT)UT@/B`P
M*2!["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E
M="@D<F5S=6QT*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G
M1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!P<F5F97)E;F-E<R!S97)V97(N
M)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("\J
M(&QD87!?9V5T7V5N=')I97,H*2!C;VYV97)T<R!A='1R:6)U=&4@:6YD97AE
M<R!T;R!L;W=E<F-A<V4N("HO"B`@("`@("`@)&9I96QD(#T@4W1R:6YG.CIL
M;W=E<B@D=&AI<RT^7W-C;W!E("X@)W!R969S)RD["@H@("`@("`@(&EF("AI
M<W-E="@D<F5S=6QT*2D@>PH@("`@("`@("`@("`O*B!3970@=&AE(')E<75E
M<W1E9"!V86QU97,@:6X@=&AE("1T:&ES+3Y?<')E9G,@:&%S:"!B87-E9"!O
M;@H@("`@("`@("`@("`@("!T:&4@8V]N=&5N=',@;V8@=&AE($Q$05`@<F5S
M=6QT+@H*("`@("`@("`@("`@("`@4')E9F5R96YC97,@87)E('-T;W)E9"!A
M<R!C;VQO;BUS97!A<F%T960@;F%M93IV86QU92!P86ER<RX*("`@("`@("`@
M("`@("`@16%C:"!P86ER(&ES('-T;W)E9"!A<R!I=',@;W=N(&%T=')I8G5T
M92!O9F8@;V8@=&AE(&UU;'1I+0H@("`@("`@("`@("`@("!V86QU92!A='1R
M:6)U=&4@;F%M960@:6XZ("1T:&ES+3Y?<V-O<&4@+B`G4')E9G,G"@H@("`@
M("`@("`@("`@("!.;W1E('1H870@4')E9G,Z.G-E=%9A;'5E*"D@8V%N)W0@
M8F4@=7-E9"!H97)E(&)E8V%U<V4@;V8@=&AE"B`@("`@("`@("`@("`@(&-H
M96-K(&9O<B!T:&4@(F-H86YG96%B;&4B(&)I="X@(%=E('=A;G0@=&\@;W9E
M<G)I9&4@=&AA=`H@("`@("`@("`@("`@("!C:&5C:R!W:&5N('!O<'5L871I
M;F<@=&AE("1T:&ES+3Y?<')E9G,@:&%S:"!F<F]M('1H92!,1$%0"B`@("`@
M("`@("`@("`@('-E<G9E<BX*("`@("`@("`@("`@("HO"@H@("`@("`@("`@
M("`D<')E9G,@/2!A<G)A>2@I.PH*("`@("`@("`@("`@+RH@268@:&]R9&50
M<F5F<R!E>&ES=',L(&UE<F=E('1H96T@87,@=&AE(&)A<V4@;V8@=&AE('!R
M969S+B`J+PH@("`@("`@("`@("!I9B`H:7-S970H)')E<W5L=%LP75LG:&]R
M9&5P<F5F<R==*2D@>PH@("`@("`@("`@("`@("`@)'!R969S(#T@87)R87E?
M;65R9V4H)'!R969S+"`D<F5S=6QT6S!=6R=H;W)D97!R969S)UTI.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O*B!)9B!T:&ES('-C;W!E)W,@<')E
M9G,@87)E(&%V86EL86)L92P@;65R9V4@=&AE;2!A<R!W:6QL+B`@1VEV90H@
M("`@("`@("`@("`@*B!T:&5M(&$@:&EG:&5R('!R96-E9&5N8V4@=&AA;B!H
M;W)D95!R969S+B`J+PH@("`@("`@("`@("!I9B`H<W1R8VUP*"1T:&ES+3Y?
M<V-O<&4L("=H;W)D92<I("$](#`I('L*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D<F5S=6QT6S!=6R1F:65L9%TI*2!["B`@("`@("`@("`@("`@("`@
M("`@)'!R969S(#T@87)R87E?;65R9V4H)'!R969S+"`D<F5S=6QT6S!=6R1F
M:65L9%TI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!F;W)E86-H("@D<')E9G,@87,@)'!R969S='(I('L*("`@("`@
M("`@("`@("`@("\J($EF('1H92!S=')I;F<@9&]E<VXG="!C;VYT86EN(&$@
M8V]L;VX@9&5L:6UI=&5R+"!S:VEP(&ET+B`J+PH@("`@("`@("`@("`@("`@
M:68@*'-U8G-T<E]C;W5N="@D<')E9G-T<BP@)SHG*2`]/2`P*2!["B`@("`@
M("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@+RH@4W!L:70@=&AE('-T<FEN9R!I;G1O(&ET<R!N
M86UE.G9A;'5E(&-O;7!O;F5N=',N("HO"B`@("`@("`@("`@("`@("!L:7-T
M*"1P<F5F+"`D=F%L*2`]('-P;&ET*"<Z)RP@)'!R969S='(L(#(I.PH*("`@
M("`@("`@("`@("`@("\J(%)E=')I979E('1H:7,@<')E9F5R96YC92X@*B\*
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!R969S6R1P<F5F
M72DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=%9A;'5E*"1P
M<F5F+"!B87-E-C1?9&5C;V1E*"1V86PI+"!F86QS92D["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E=$1E9F%U;'0H)'!R968L(&9A;'-E*3L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/F%D9"@D<')E9BP@8F%S938T7V1E8V]D92@D=F%L*2P@7U!2149?4TA!
M4D5$*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@+RH@0V%L;"!H;V]K<RX@*B\*("`@("`@("`@("`@)'1H:7,M/E]C
M86QL2&]O:W,H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!(;W)D
M93HZ;&]G365S<V%G92@G3F\@<')E9F5R96YC97,@=V5R92!R971R:65V960N
M)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@('T*"B`@("`@("`@+RH@57!D871E('1H92!S97-S:6]N(&-A8VAE
M+B`J+PH@("`@("`@("1T:&ES+3YC86-H955P9&%T92@I.PH*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-T;W)E<R!P<F5F
M97)E;F-E<R!T;R!T:&4@3$1!4"!S97)V97(N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<W1O<F4H
M*0H@("`@>PH@("`@("`@("1U<&1A=&5D(#T@=')U93L*"B`@("`@("`@+RH@
M0VAE8VL@9F]R(&%N>2`B9&ER='DB('!R969E<F5N8V5S+B!)9B!N;R`B9&ER
M='DB"B`@("`@("`@("H@<')E9F5R96YC97,@87)E(&9O=6YD+"!T:&5R92=S
M(&YO(&YE960@=&\@=7!D871E('1H92!,1$%0"B`@("`@("`@("H@<V5R=F5R
M+B!%>&ET('-U8V-E<W-F=6QL>2X@*B\*("`@("`@("`D9&ER='E?<')E9G,@
M/2`D=&AI<RT^7V1I<G1Y4')E9G,H*3L*("`@("`@("!I9B`H(6-O=6YT*"1D
M:7)T>5]P<F5F<RDI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@
M("`@?0H*("`@("`@("`O*B!-86ME('-U<F4@=V4@87)E(&-O;FYE8W1E9"X@
M*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I
M;&0@82!H87-H(&]F('1H92!P<F5F97)E;F-E<R!A;F0@=&AE:7(@=F%L=65S
M('1H870@;F5E9`H@("`@("`@("`J('1O(&)E('-T;W)E9"!I;B!T:&4@3$1!
M4"!S97)V97(N($)E8V%U<V4@=V4@:&%V92!T;R!U<&1A=&4*("`@("`@("`@
M*B!A;&P@;V8@=&AE('9A;'5E<R!O9B!A(&UU;'1I+79A;'5E(&5N=')Y('=H
M;VQE<V%L92P@=V4*("`@("`@("`@*B!C86XG="!J=7-T('!I8VL@;W5T('1H
M92!D:7)T>2!P<F5F97)E;F-E<SL@=V4@;75S="!U<&1A=&4*("`@("`@("`@
M*B!E=F5R>71H:6YG+B`J+PH@("`@("`@("1N97=?=F%L=65S(#T@87)R87DH
M*3L*("`@("`@("!F;W)E86-H("AA<G)A>5]K97ES*"1T:&ES+3Y?<')E9G,I
M(&%S("1P<F5F*2!["B`@("`@("`@("`@("\O($1O;B=T('-T;W)E(&QO8VME
M9"!P<F5F97)E;F-E<RX*("`@("`@("`@("`@:68@*"$D=&AI<RT^:7-,;V-K
M960H)'!R968I*2!["B`@("`@("`@("`@("`@("`D96YT<GD@/2`D<')E9B`N
M("<Z)R`N(&)A<V4V-%]E;F-O9&4H)'1H:7,M/F=E=%9A;'5E*"1P<F5F*2D[
M"B`@("`@("`@("`@("`@("`D9FEE;&0@/2`D=&AI<RT^9V5T4V-O<&4H)'!R
M968I("X@)U!R969S)SL*("`@("`@("`@("`@("`@("1N97=?=F%L=65S6R1F
M:65L9%U;72`]("1E;G1R>3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@+RH@16YT<FEE<R!M=7-T(&AA=F4@=&AE(&]B:F5C=&-L87-S97,@
M)W1O<"<@86YD("=H;W)D97!E<G-O;B<*("`@("`@("`@*B!T;R!S=6-C97-S
M9G5L;'D@<W1O<F4@3$1!4"!P<F5F<RX@0VAE8VL@9F]R(&)O=&@@;V8@=&AE
M;2P*("`@("`@("`@*B!A;F0@861D('1H96T@:68@;F5C97-S87)Y+B`J+PH@
M("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%R86US6R=U:60G72!A<R`D=6ED
M7V9I96QD*2!["B`@("`@("`@("`@("1S96%R8V@@/2!L9&%P7W-E87)C:"@D
M=&AI<RT^7V-O;FYE8W1I;VXL("1T:&ES+3Y?<&%R86US6R=B87-E9&XG72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1U:61?9FEE;&0@
M+B`G/2<@+B`D=&AI<RT^7W5S97(L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@G;V)J96-T8VQA<W,G*2D["B`@("`@("`@("`@
M(&EF("@D<V5A<F-H*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@;&1A
M<%]G971?96YT<FEE<R@D=&AI<RT^7V-O;FYE8W1I;VXL("1S96%R8V@I.PH@
M("`@("`@("`@("`@("`@:68@*"1R97-U;'0@)B8@)')E<W5L=%LG8V]U;G0G
M72`^(#`I('L*("`@("`@("`@("`@("`@("`@("`D=&]P(#T@9F%L<V4["B`@
M("`@("`@("`@("`@("`@("`@)&AO<F1E<&5R<V]N(#T@9F%L<V4["@H@("`@
M("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1R97-U;'1;,%U;
M)V]B:F5C=&-L87-S)UU;)V-O=6YT)UT[("1I*RLI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"1R97-U;'1;,%U;)V]B:F5C=&-L87-S)UU;)&E=
M(#T]("=T;W`G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&]P
M(#T@=')U93L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1R
M97-U;'1;,%U;)V]B:F5C=&-L87-S)UU;)&E=(#T]("=H;W)D95!E<G-O;B<I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1H;W)D97!E<G-O;B`]
M('1R=64["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@("\J($%D9"!A;GD@;6ES
M<VEN9R!O8FIE8W1C;&%S<V5S+B`J+PH@("`@("`@("`@("`@("`@("`@(&EF
M("@A)'1O<"D@>PH@("`@("`@("`@("`@("`@("`@("`@("!L9&%P7VUO9%]A
M9&0H)'1H:7,M/E]C;VYN96-T:6]N+"`D=&AI<RT^7V1N+"!A<G)A>2@G;V)J
M96-T8VQA<W,G(#T^("=T;W`G*2D["B`@("`@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("`@("!I9B`H(21H;W)D97!E<G-O;BD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("!L9&%P7VUO9%]A9&0H)'1H:7,M/E]C;VYN
M96-T:6]N+"`D=&AI<RT^7V1N+"!A<G)A>2@G;V)J96-T8VQA<W,G(#T^("=H
M;W)D95!E<G-O;B<I*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%-E;F0@=&AE(&AA<V@@
M=&\@=&AE($Q$05`@<V5R=F5R+B`J+PH@("`@("`@(&EF("AL9&%P7VUO9%]R
M97!L86-E*"1T:&ES+3Y?8V]N;F5C=&EO;BP@)'1H:7,M/E]D;BP@)&YE=U]V
M86QU97,I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1D:7)T>5]P<F5F<R!A
M<R`D<')E9BD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$1I<G1Y*"1P
M<F5F+"!F86QS92D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@*("`@("`@("`@("`@("`@
M<W!R:6YT9B@G56YA8FQE('1O(&UO9&EF>2!P<F5F97)E;F-E<SH@6R5D72`E
M<R<L"B`@("`@("`@("`@("`@("`@("`@("`@(&QD87!?97)R;F\H)'1H:7,M
M/E]C;VYN96-T:6]N*2P*("`@("`@("`@("`@("`@("`@("`@("`@;&1A<%]E
M<G)O<B@D=&AI<RT^7V-O;FYE8W1I;VXI*2P*("`@("`@("`@("`@("`@(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@("1U<&1A=&5D(#T@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("`O*B!!='1E;7!T('1O(&-A8VAE('1H
M92!P<F5F97)E;F-E<R!I;B!T:&4@<V5S<VEO;BX@*B\*("`@("`@("`D=&AI
M<RT^8V%C:&55<&1A=&4H*3L*"B`@("`@("`@<F5T=7)N("1U<&1A=&5D.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0VQE87)S(&%L;"!P<F5F97)E;F-E<R!F
M<F]M('1H92!,1$%0(&)A8VME;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L
M96%R*"D*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@87)E(&-O;FYE
M8W1E9"X@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@
M)&%T=')S(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/FQI<W1!<'!S*&%R<F%Y
M*"=I;F%C=&EV92<L("=A8W1I=F4G+"`G:&ED9&5N)RP@)VYO=&]O;&)A<B<L
M("=A9&UI;B<I*3L*("`@("`@("!F;W)E86-H("@D871T<G,@87,@)&ME>2`]
M/B`D=F%L*2!["B`@("`@("`@("`@("1A='1R<ULD:V5Y72`]("1V86P@+B`G
M4')E9G,G.PH@("`@("`@('T*"B`@("`@("`@)'-E87)C:"`](&QD87!?<F5A
M9"@D=&AI<RT^7V-O;FYE8W1I;VXL("1T:&ES+3Y?9&XL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G;V)J96-T0VQA<W,]:&]R9&5097)S;VXG+"`D
M871T<G,L(#$I.PH*("`@("`@("!I9B`H)'-E87)C:"D@>PH@("`@("`@("`@
M("`D<F5S=6QT(#T@;&1A<%]G971?96YT<FEE<R@D=&AI<RT^7V-O;FYE8W1I
M;VXL("1S96%R8V@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@($AO
M<F1E.CIL;V=-97-S86=E*"=&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('!R
M969E<F5N8V5S('-E<G9E<BXG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@('T*"B`@("`@("`@)&%T=')S(#T@87)R87DH*3L*("`@("`@("!I9B`H
M)')E<W5L="D@>PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D<F5S
M=6QT6S!=6R=C;W5N="==.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D871T
M<G-;)')E<W5L=%LP75LD:5U=(#T@87)R87DH*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H(6QD87!?;6]D7V1E;"@D=&AI<RT^7V-O;FYE8W1I
M;VXL("1T:&ES+3Y?9&XL("1A='1R<RDI('L*("`@("`@("`@("`@("`@($AO
M<F1E.CIL;V=-97-S86=E*`H@("`@("`@("`@("`@("`@("`@('-P<FEN=&8H
M)U5N86)L92!T;R!C;&5A<B!P<F5F97)E;F-E<SH@6R5D72`E<R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!L9&%P7V5R<FYO*"1T:&ES+3Y?8V]N
M;F5C=&EO;BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!L9&%P7V5R
M<F]R*"1T:&ES+3Y?8V]N;F5C=&EO;BDI+`H@("`@("`@("`@("`@("`@("`@
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@*("`@("`@
M("`@("`@("`@('-P<FEN=&8H)U5N86)L92!T;R!C;&5A<B!P<F5F97)E;F-E
M<SH@6R5D72`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@(&QD87!?97)R
M;F\H)'1H:7,M/E]C;VYN96-T:6]N*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@;&1A<%]E<G)O<B@D=&AI<RT^7V-O;FYE8W1I;VXI*2P*("`@("`@("`@
M("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@
M("`D=&AI<RT^8VQE86YU<"AT<G5E*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%!E<F9O<FT@8VQE86YU<"!O<&5R871I;VYS+@H@("`@("H*("`@("`J($!P
M87)A;2!B;V]L96%N("1A;&P@($-L96%N=7`@86QL($AO<F1E('!R969E<F5N
M8V5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;&5A;G5P*"1A;&P@/2!F86QS
M92D*("`@('L*("`@("`@("`O*B!#;&]S92!T:&4@3$1!4"!C;VYN96-T:6]N
M+B`J+PH@("`@("`@("1T:&ES+3Y?9&ES8V]N;F5C="@I.PH*("`@("`@("!P
M87)E;G0Z.F-L96%N=7`H)&%L;"D["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]0<F5F<R]S97-S:6]N+G!H<```````````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<Q,3<`,3`U,34T,S,W-#<`,#(R-S4Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!0<F5F97)E;F-E<R!S=&]R86=E(&EM<&QE;65N=&%T:6]N
M(&9O<B!02%`G<R!S97-S:6]N(&EM<&QE;65N=&%T:6]N+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H<"QV(#$N,S(N
M,3(N-R`R,#`V+S`U+S$Q(#$W.C$S.C(S(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`:&]R
M9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,N-`H@*B!`<&%C:V%G92!(
M;W)D95]0<F5F<PH@*B\*8VQA<W,@4')E9G-?<V5S<VEO;B!E>'1E;F1S(%!R
M969S('L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@<V5S<VEO
M;B!P<F5F97)E;F-E<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=7-E<B`@("`@(%1H92!U<V5R('=H;R!O=VYS('1H97-E('!R969E
M<F5N8V5S+B`H56YU<V5D*0H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%S<W=O
M<F0@(%1H92!P87-S=V]R9"!A<W-O8VEA=&5D('=I=&@@)'5S97(N("A5;G5S
M960I"B`@("`@*B!`<&%R86T@<W1R:6YG("1S8V]P92`@("`@5&AE(&-U<G)E
M;G0@<')E9F5R96YC97,@<V-O<&4N"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@("`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T
M97)S+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`H56YU<V5D
M*0H@("`@("H@0'!A<F%M(&)O;VQE86X@)&-A8VAI;F<@(%-H;W5L9"!C86-H
M:6YG(&)E('5S960_("A5;G5S960I"B`@("`@*@H@("`@("HO"B`@("!F=6YC
M=&EO;B!0<F5F<U]S97-S:6]N*"1U<V5R+"`D<&%S<W=O<F0@/2`G)RP@)'-C
M;W!E(#T@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;7,@
M/2!N=6QL+"`D8V%C:&EN9R`]('1R=64I"B`@("!["B`@("`@("`@:68@*"%5
M=&EL.CIE>'1E;G-I;VY%>&ES=',H)W-E<W-I;VXG*2D@>PH@("`@("`@("`@
M("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I<V5%<G)O<BA?*")0<F5F<U]S97-S
M:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(BDL
M(%]?1DE,15]?+"!?7TQ)3D5?7RDI.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/E]S8V]P92`]("1S8V]P93L*"B`@("`@("`@<&%R96YT.CI0<F5F<R@I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S('1H92!R97%U97-T
M960@<V5T(&]F('!R969E<F5N8V5S(&9R;VT@=&AE(&-U<G)E;G0@<V5S<VEO
M;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E
M<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!R971R:65V92@I"B`@("!["B`@("`@("`@+RH@3&]A
M9"!D969A=6QT<R!T;R!M86ME('-U<F4@=V4@:&%V92!A;&P@<')E9F5R96YC
M97,N("HO"B`@("`@("`@<&%R96YT.CIR971R:65V92@I.PH*("`@("`@("`D
M9VQO8F%L7W!R969S(#T@87)R87DH*3L*("`@("`@("`D;&]C86Q?<')E9G,@
M/2!A<G)A>2@I.PH*("`@("`@("`O*B!2971R:65V92!G;&]B86P@86YD(&QO
M8V%L('!R969E<F5N8V5S(&9R;VT@=&AE('-E<W-I;VX@=F%R:6%B;&4N("HO
M"B`@("`@("`@:68@*&ES<V5T*"1?4T534TE/3ELG:&]R9&5?<')E9G,G75LG
M:&]R9&4G72DI('L*("`@("`@("`@("`@)&=L;V)A;%]P<F5F<R`]("1?4T53
M4TE/3ELG:&]R9&5?<')E9G,G75LG:&]R9&4G73L*("`@("`@("!]"B`@("`@
M("`@:68@*&ES<V5T*"1?4T534TE/3ELG:&]R9&5?<')E9G,G75LD=&AI<RT^
M7W-C;W!E72DI('L*("`@("`@("`@("`@)&QO8V%L7W!R969S(#T@)%]315-3
M24].6R=H;W)D95]P<F5F<R==6R1T:&ES+3Y?<V-O<&5=.PH@("`@("`@('T*
M"B`@("`@("`@+RH@4F5T<FEE=F4@86YD('-T;W)E('1H92!L;V-A;"!A;F0@
M9VQO8F%L('!R969E<F5N8V5S+B`J+PH@("`@("`@("1T:&ES+3Y?<')E9G,@
M/2!A<G)A>5]M97)G92@D=&AI<RT^7W!R969S+"`D9VQO8F%L7W!R969S+"`D
M;&]C86Q?<')E9G,I.PH*("`@("`@("`O*B!#86QL(&AO;VMS+B`J+PH@("`@
M("`@(&EF("@A:7-S970H)%]315-324].6R=H;W)D95]P<F5F<R==*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7V-A;&Q(;V]K<R@I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R
M97,@<')E9F5R96YC97,@:6X@=&AE(&-U<G)E;G0@<V5S<VEO;BX*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)'!R969S("!!;B!A<G)A>2!L:7-T:6YG
M('1H92!P<F5F97)E;F-E<R!T;R!B92!S=&]R960N($EF"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("!N;W0@<W!E8VEF:65D+"!S=&]R92!A;&P@=&AE
M('!R969E<F5N8V5S(&QI<W1E9"!I;@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@=&AE("1P<F5F<R!H87-H+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-T;W)E*"1P<F5F
M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@+RH@0W)E871E(&%N9"!R96=I
M<W1E<B!T:&4@<')E9F5R96YC97,@87)R87DL(&EF(&YE8V5S<V%R>2X@*B\*
M("`@("`@("!I9B`H(6ES<V5T*"1?4T534TE/3ELG:&]R9&5?<')E9G,G72DI
M('L*("`@("`@("`@("`@)%]315-324].6R=H;W)D95]P<F5F<R==(#T@87)R
M87DH*3L*("`@("`@("!]"@H@("`@("`@("\J($-O<'D@=&AE(&-U<G)E;G0@
M<')E9F5R96YC97,@:6YT;R!T:&4@<V5S<VEO;B!V87)I86)L92X@*B\*("`@
M("`@("!F;W)E86-H("@D=&AI<RT^7W!R969S(&%S("1N86UE(#T^("1P<F5F
M*2!["B`@("`@("`@("`@("1S8V]P92`]("1T:&ES+3YG97138V]P92@D;F%M
M92D["B`@("`@("`@("`@("1?4T534TE/3ELG:&]R9&5?<')E9G,G75LD<V-O
M<&5=6R1N86UE72`]("1P<F5F.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!097)F;W)M(&-L96%N=7`@
M;W!E<F%T:6]N<RX*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D86QL
M("!#;&5A;G5P(&%L;"!(;W)D92!P<F5F97)E;F-E<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@8VQE86YU<"@D86QL(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M+RH@4&5R9F]R;2!A($AO<F1E+7=I9&4@8VQE86YU<#\@*B\*("`@("`@("!I
M9B`H)&%L;"D@>PH@("`@("`@("`@("!U;G-E="@D7U-%4U-)3TY;)VAO<F1E
M7W!R969S)UTI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('5N<V5T
M*"1?4T534TE/3ELG:&]R9&5?<')E9G,G75LD=&AI<RT^7W-C;W!E72D["B`@
M("`@("`@("`@("1?4T534TE/3ELG:&]R9&5?<')E9G,G75LG7V9I;&QE9"==
M(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!P87)E;G0Z.F-L96%N=7`H
M)&%L;"D["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]0<F5F<R]S<6PN
M<&AP````````````````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S(Q-S,`
M,3`U,34T,S,W-#8`,#(R,#8T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!`<&%C:V%G92!(;W)D95]0
M<F5F<PH@*B\*"B\J*@H@*B!014%2($1"(&QA>65R+@H@*B\*<F5Q=6ER95]O
M;F-E("=$0BYP:'`G.PH*+RHJ"B`J($AO<F1E7U-T<FEN9R!C;&%S<RX*("HO
M"G)E<75I<F5?;VYC92`G2&]R9&4O4W1R:6YG+G!H<"<["@HO*BH*("H@4')E
M9F5R96YC97,@<W1O<F%G92!I;7!L96UE;G1A=&EO;B!F;W(@4$A0)W,@4$5!
M4B!D871A8F%S90H@*B!A8G-T<F%C=&EO;B!L87EE<BX*("H*("H@4F5Q=6ER
M960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=P:'!T>7!E)R`@(%1H92!D871A
M8F%S92!T>7!E("AI92X@)W!G<W%L)RP@)VUY<W%L)RP@971C+BDN"B`J("`@
M)V-H87)S970G("`@5&AE(&1A=&%B87-E)W,@:6YT97)N86P@8VAA<G-E="X\
M+W!R93X*("H*("H@3W!T:6]N86P@<&%R86UE=&5R<SH\<')E/@H@*B`@("=T
M86)L92<@("`@(%1H92!N86UE(&]F('1H92!P<F5F97)E;F-E<R!T86)L92!I
M;B`G9&%T86)A<V4G+@H@*B`@("`@("`@("`@("`@($1%1D%53%0Z("=H;W)D
M95]P<F5F<R<\+W!R93X*("H*("H@4F5Q=6ER960@8GD@<V]M92!D871A8F%S
M92!I;7!L96UE;G1A=&EO;G,Z/'!R93X*("H@("`G:&]S='-P96,G("!4:&4@
M:&]S=&YA;64@;V8@=&AE(&1A=&%B87-E('-E<G9E<BX*("H@("`G<')O=&]C
M;VPG("!4:&4@8V]M;75N:6-A=&EO;B!P<F]T;V-O;"`H)W1C<"<L("=U;FEX
M)RP@971C+BDN"B`J("`@)V1A=&%B87-E)R`@5&AE(&YA;64@;V8@=&AE(&1A
M=&%B87-E+@H@*B`@("=U<V5R;F%M92<@(%1H92!U<V5R;F%M92!W:71H('=H
M:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+@H@*B`@("=P87-S=V]R
M9"<@(%1H92!P87-S=V]R9"!A<W-O8VEA=&5D('=I=&@@)W5S97)N86UE)RX*
M("H@("`G;W!T:6]N<R<@("!!9&1I=&EO;F%L(&]P=&EO;G,@=&\@<&%S<R!T
M;R!T:&4@9&%T86)A<V4N"B`J("`@)W!O<G0G("`@("`@5&AE('!O<G0@;VX@
M=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@)W1T>2<@
M("`@("`@5&AE(%1462!O;B!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A
M8F%S92X\+W!R93X*("H*("H@5&AE('1A8FQE('-T<G5C='5R92!F;W(@=&AE
M(%!R969S('-Y<W1E;2!I<R!I;@H@*B!S8W)I<'1S+W-Q;"]H;W)D95]P<F5F
M<RYS<6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U!R969S+U!R969S+W-Q
M;"YP:'`L=B`Q+CDQ+C$P+C(P(#(P,#8O,#0O,3`@,34Z-3@Z,30@8VAU8VL@
M17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ
M;VY`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F]N
M(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS
M"B`J($!P86-K86=E($AO<F1E7U!R969S"B`J+PIC;&%S<R!0<F5F<U]S<6P@
M97AT96YD<R!0<F5F<R!["@H@("`@+RHJ"B`@("`@*B!(87-H(&-O;G1A:6YI
M;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R86US(#T@87)R87DH*3L*"B`@
M("`O*BH*("`@("`J($AA;F1L92!F;W(@=&AE(&-U<G)E;G0@9&%T86)A<V4@
M8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`=F%R($1""B`@("`@*B\*("`@
M('9A<B`D7V1B.PH*("`@("\J*@H@("`@("H@0F]O;&5A;B!I;F1I8V%T:6YG
M('=H971H97(@;W(@;F]T('=E)W)E(&-O;FYE8W1E9"!T;R!T:&4@4U%,('-E
M<G9E<BX*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@
M=F%R("1?8V]N;F5C=&5D(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!#;VYS
M=')U8W1S(&$@;F5W(%-13"!P<F5F97)E;F-E<R!O8FIE8W0N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@("`@(%1H92!U<V5R('=H;R!O
M=VYS('1H97-E('!R969E<F5N8V5S+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<&%S<W=O<F0@(%1H92!P87-S=V]R9"!A<W-O8VEA=&5D('=I=&@@)'5S97(N
M("A5;G5S960I"B`@("`@*B!`<&%R86T@<W1R:6YG("1S8V]P92`@("`@5&AE
M(&-U<G)E;G0@<')E9F5R96YC97,@<V-O<&4N"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R`@("`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P
M87)A;65T97)S+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&-A8VAI;F<@(%-H
M;W5L9"!C86-H:6YG(&)E('5S960_"B`@("`@*B\*("`@(&9U;F-T:6]N(%!R
M969S7W-Q;"@D=7-E<BP@)'!A<W-W;W)D(#T@)R<L("1S8V]P92`]("<G+`H@
M("`@("`@("`@("`@("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@I+"`D8V%C
M:&EN9R`](&9A;'-E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=7-E<B`]("1U
M<V5R.PH@("`@("`@("1T:&ES+3Y?<V-O<&4@/2`D<V-O<&4["B`@("`@("`@
M)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@("`@("1T:&ES+3Y?8V%C
M:&EN9R`]("1C86-H:6YG.PH*("`@("`@("!P87)E;G0Z.E!R969S*"D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C:&%R<V5T('5S960@
M8GD@=&AE(&-O;F-R971E('!R969E<F5N8V4@8F%C:V5N9"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('!R969E<F5N8V4@8F%C:V5N9"=S
M(&-H87)S970N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-H87)S970H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S('1H92!R97%U97-T
M960@<V5T(&]F('!R969E<F5N8V5S(&9R;VT@=&AE('5S97(G<R!D871A8F%S
M90H@("`@("H@96YT<GDN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M<F5F<R`@06X@87)R87D@;&ES=&EN9R!T:&4@<')E9F5R96YC97,@=&\@<F5T
M<FEE=F4N($EF"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!N;W0@<W!E
M8VEF:65D+"!R971R:65V92!A;&P@;V8@=&AE('!R969E<F5N8V5S"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("!L:7-T960@:6X@=&AE("1P<F5F<R!H
M87-H+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C
M8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(')E=')I979E*"1P<F5F<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@+RH@071T96UP="!T;R!P=6QL('1H92!V86QU97,@9G)O
M;2!T:&4@<V5S<VEO;B!C86-H92!F:7)S="X@*B\*("`@("`@("!I9B`H)'1H
M:7,M/F-A8VAE3&]O:W5P*"DI('L*("`@("`@("`@("`@<F5T=7)N('1R=64[
M"B`@("`@("`@?0H*("`@("`@("`O*B!,;V%D(&1E9F%U;'1S('1O(&UA:V4@
M<W5R92!W92!H879E(&%L;"!P<F5F97)E;F-E<RX@*B\*("`@("`@("!P87)E
M;G0Z.G)E=')I979E*"D["@H@("`@("`@("\J($UA:V4@<W5R92!W92=R92!C
M;VYN96-T960N("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@
M("`@("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@("`@)'%U97)Y
M(#T@)U-%3$5#5"!P<F5F7W-C;W!E+"!P<F5F7VYA;64L('!R969?=F%L=64@
M1E)/32`G.PH@("`@("`@("1Q=65R>2`N/2`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G72`N("<@)SL*("`@("`@("`D<75E<GD@+CT@)U=(15)%('!R969?=6ED
M(#T@/R<["B`@("`@("`@)'%U97)Y("X]("<@04Y$("AP<F5F7W-C;W!E(#T@
M/R<["B`@("`@("`@)'%U97)Y("X]("(@3U(@<')E9E]S8V]P92`]("=H;W)D
M92<I($]21$52($)9('!R969?<V-O<&4B.PH*("`@("`@("`D=F%L=65S(#T@
M87)R87DH)'1H:7,M/E]U<V5R+"`D=&AI<RT^7W-C;W!E*3L*"B`@("`@("`@
M2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G4U%,(%%U97)Y(&)Y(%!R969S
M7W-Q;#HZ<F5T<FEE=F4H*3H@)7,G+"`D<75E<GDI+"!?7T9)3$5?7RP@7U],
M24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@+RH@17AE8W5T92!T
M:&4@<75E<GDN("HO"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U
M97)Y*"1Q=65R>2P@)'9A;'5E<RD["@H@("`@("`@(&EF("AI<W-E="@D<F5S
M=6QT*2`F)B`A:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("1R;W<@/2`D<F5S=6QT+3YF971C:%)O=RA$0E]&151#2$U/1$5?
M05-33T,I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F]W+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D<F]W
M+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@
M("`@("`@("!R971U<FX["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J
M(%-E="!T:&4@<F5Q=65S=&5D('9A;'5E<R!I;B!T:&4@)'1H:7,M/E]P<F5F
M<R!H87-H"B`@("`@("`@("`@("`J(&)A<V5D(&]N('1H92!C;VYT96YT<R!O
M9B!T:&4@4U%,(')E<W5L="X*("`@("`@("`@("`@("H*("`@("`@("`@("`@
M("H@3F]T92!T:&%T(%!R969S.CIS971686QU92@I(&-A;B=T(&)E('5S960@
M:&5R92!B96-A=7-E"B`@("`@("`@("`@("`J(&]F('1H92!C:&5C:R!F;W(@
M=&AE(")C:&%N9V5A8FQE(B!B:70N(%=E('=A;G0@=&\*("`@("`@("`@("`@
M("H@;W9E<G)I9&4@=&AA="!C:&5C:R!W:&5N('!O<'5L871I;F<@=&AE("1T
M:&ES+3Y?<')E9G,*("`@("`@("`@("`@("H@:&%S:"!F<F]M('1H92!344P@
M<V5R=F5R+B`J+PH@("`@("`@("`@("!W:&EL92`H)')O=R`F)B`A:7-?82@D
M<F]W+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D;F%M92`]
M('1R:6TH)')O=ULG<')E9E]N86UE)UTI.PH@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?<')E9G-;)&YA;65=*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<V5T5F%L=64H)&YA;64L("1R;W=;)W!R969?=F%L
M=64G72P@9F%L<V4L(&9A;'-E*3L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T1&ER='DH)&YA;64L(&9A;'-E*3L*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F%D9"@D;F%M92P@
M)')O=ULG<')E9E]V86QU92==+"`D<F]W6R=P<F5F7W-C;W!E)UT@/3T@)VAO
M<F1E)R`_(%]04D5&7U-(05)%1"`Z(#`I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)')O=R`]("1R97-U;'0M/F9E=&-H4F]W*$1"7T9%
M5$-(34]$15]!4U-/0RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J
M($-A;&P@:&]O:W,N("HO"B`@("`@("`@("`@("1T:&ES+3Y?8V%L;$AO;VMS
M*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE
M<W-A9V4H)TYO('!R969E<F5N8V5S('=E<F4@<F5T<FEE=F5D+B<L(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("!R
M971U<FX["B`@("`@("`@?0H*("`@("`@("`O*B!5<&1A=&4@=&AE('-E<W-I
M;VX@8V%C:&4N("HO"B`@("`@("`@)'1H:7,M/F-A8VAE57!D871E*"D["@H@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1O
M<F5S('!R969E<F5N8V5S('1O(%-13"!S97)V97(N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<W1O
M<F4H*0H@("`@>PH@("`@("`@("\J($-H96-K(&9O<B!A;GD@(F1I<G1Y(B!P
M<F5F97)E;F-E<RX@268@;F\@(F1I<G1Y(@H@("`@("`@("`J('!R969E<F5N
M8V5S(&%R92!F;W5N9"P@=&AE<F4G<R!N;R!N965D('1O('5P9&%T92!T:&4@
M4U%,"B`@("`@("`@("H@<V5R=F5R+B!%>&ET('-U8V-E<W-F=6QL>2X@*B\*
M("`@("`@("`D9&ER='E?<')E9G,@/2`D=&AI<RT^7V1I<G1Y4')E9G,H*3L*
M("`@("`@("!I9B`H(6-O=6YT*"1D:7)T>5]P<F5F<RDI('L*("`@("`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`O*B!-86ME('-U
M<F4@=V4G<F4@8V]N;F5C=&5D+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C
M="@I.PH*("`@("`@("`O*B!,;V]P('1H<F]U9V@@=&AE(")D:7)T>2(@<')E
M9F5R96YC97,N("!)9B!A(')O=R!A;')E861Y"B`@("`@("`@("H@97AI<W1S
M(&9O<B!T:&ES('!R969E<F5N8V4L(&%T=&5M<'0@=&\@=7!D871E(&ET+@H@
M("`@("`@("`J($]T:&5R=VES92P@:6YS97)T(&$@;F5W(')O=RX@*B\*("`@
M("`@("!F;W)E86-H("@D9&ER='E?<')E9G,@87,@)&YA;64I('L*("`@("`@
M("`@("`@+R\@1&]N)W0@<W1O<F4@;&]C:V5D('!R969E<F5N8V5S+@H@("`@
M("`@("`@("!I9B`H)'1H:7,M/FES3&]C:V5D*"1N86UE*2D@>PH@("`@("`@
M("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1S8V]P92`]("1T:&ES+3YG97138V]P92@D;F%M92D["@H@("`@("`@("`@
M("`O*B!$;V5S(&%N(&5N=')Y(&%L<F5A9'D@97AI<W0@9F]R('1H:7,@<')E
M9F5R96YC93\@*B\*("`@("`@("`@("`@)'%U97)Y(#T@)U-%3$5#5"`Q($92
M3TT@)SL*("`@("`@("`@("`@)'%U97)Y("X]("1T:&ES+3Y?<&%R86US6R=T
M86)L92==("X@)R`G.PH@("`@("`@("`@("`D<75E<GD@+CT@)U=(15)%('!R
M969?=6ED(#T@/R<["B`@("`@("`@("`@("1Q=65R>2`N/2`G($%.1"!P<F5F
M7VYA;64@/2`_)SL*("`@("`@("`@("`@)'%U97)Y("X]("<@04Y$("AP<F5F
M7W-C;W!E(#T@/R<["B`@("`@("`@("`@("1Q=65R>2`N/2`B($]2('!R969?
M<V-O<&4@/2`G:&]R9&4G*2(["@H@("`@("`@("`@("`D=F%L=65S(#T@87)R
M87DH)'1H:7,M/E]U<V5R+"`D;F%M92P@)'-C;W!E*3L*"B`@("`@("`@("`@
M("\J($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@("`@("`@("`D8VAE8VL@
M/2`D=&AI<RT^7V1B+3YG971/;F4H)'%U97)Y+"`D=F%L=65S*3L*"B`@("`@
M("`@("`@("\J(%)E='5R;B!A;B!E<G)O<B!I9B!T:&4@<75E<GD@9F%I;',N
M("HO"B`@("`@("`@("`@(&EF("AI<U]A*"1C:&5C:RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T9A:6QE
M9"!R971R:65V:6YG('!R969S(&9O<B`G("X@)'1H:7,M/E]U<V5R+"!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")&86EL960@<F5T<FEE=FEN
M9R!P<F5F97)E;F-E<RXB*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("\J($ES('1H97)E(&%N(&5X:7-T:6YG(')O=R!F;W(@=&AI<R!P<F5F97)E
M;F-E/R`J+PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1C:&5C:RDI('L*("`@
M("`@("`@("`@("`@("\J(%5P9&%T92!T:&4@97AI<W1I;F<@<F]W+B`J+PH@
M("`@("`@("`@("`@("`@)'%U97)Y(#T@)U501$%412`G("X@)'1H:7,M/E]P
M87)A;7-;)W1A8FQE)UT@+B`G("<["B`@("`@("`@("`@("`@("`D<75E<GD@
M+CT@)U-%5"!P<F5F7W9A;'5E(#T@/R<["B`@("`@("`@("`@("`@("`D<75E
M<GD@+CT@)R!72$5212!P<F5F7W5I9"`](#\G.PH@("`@("`@("`@("`@("`@
M)'%U97)Y("X]("<@04Y$('!R969?;F%M92`](#\G.PH@("`@("`@("`@("`@
M("`@)'%U97)Y("X]("<@04Y$('!R969?<V-O<&4@/2`_)SL*"B`@("`@("`@
M("`@("`@("`D=F%L=65S(#T@87)R87DH*'-T<FEN9RDD=&AI<RT^9V5T5F%L
M=64H)&YA;64L(&9A;'-E*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W5S97(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&YA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'-C;W!E*3L*"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D
M8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*"B`@("`@("`@("`@("`@("`O
M*B!2971U<FX@86X@97)R;W(@:68@=&AE('5P9&%T92!F86EL<RX@*B\*("`@
M("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@("`@("!(;W)D93HZ9F%T86PH)')E<W5L="P@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\J($EN<V5R="!A(&YE
M=R!R;W<N("HO"B`@("`@("`@("`@("`@("`D<75E<GD@(#T@)TE.4T525"!)
M3E1/("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N("<@)SL*("`@("`@
M("`@("`@("`@("1Q=65R>2`N/2`G*'!R969?=6ED+"!P<F5F7W-C;W!E+"!P
M<F5F7VYA;64L('!R969?=F%L=64I(%9!3%5%4R<["B`@("`@("`@("`@("`@
M("`D<75E<GD@+CT@)R@_+"`_+"`_+"`_*2<["@H@("`@("`@("`@("`@("`@
M)'9A;'5E<R`](&%R<F%Y*"1T:&ES+3Y?=7-E<BP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<V-O<&4L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&YA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@*'-T<FEN9RDD=&AI<RT^9V5T5F%L=64H)&YA;64L(&9A;'-E*2D[
M"@H@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y
M*"1Q=65R>2P@)'9A;'5E<RD["@H@("`@("`@("`@("`@("`@+RH@4F5T=7)N
M(&%N(&5R<F]R(&EF('1H92!I;G-E<G0@9F%I;',N("HO"B`@("`@("`@("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*"1R97-U;'0L(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("\J($UA<FL@=&AI<R!P<F5F97)E;F-E(&%S(")C;&5A
M;B(@;F]W+B`J+PH@("`@("`@("`@("`D=&AI<RT^<V5T1&ER='DH)&YA;64L
M(&9A;'-E*3L*("`@("`@("!]"@H@("`@("`@("\J(%5P9&%T92!T:&4@<V5S
M<VEO;B!C86-H92X@*B\*("`@("`@("`D=&AI<RT^8V%C:&55<&1A=&4H*3L*
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!0
M97)F;W)M(&-L96%N=7`@;W!E<F%T:6]N<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D86QL("!#;&5A;G5P(&%L;"!(;W)D92!P<F5F97)E;F-E
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@8VQE86YU<"@D86QL(#T@9F%L<V4I
M"B`@("!["B`@("`@("`@+RH@0VQO<V4@=&AE(&1A=&%B87-E(&-O;FYE8W1I
M;VXN("HO"B`@("`@("`@)'1H:7,M/E]D:7-C;VYN96-T*"D["@H@("`@("`@
M('!A<F5N=#HZ8VQE86YU<"@D86QL*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($-L96%R<R!A;&P@<')E9F5R96YC97,@9G)O;2!T:&4@8F%C:V5N9"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@8VQE87(H*0H@("`@>PH@("`@("`@("\J($UA
M:V4@<W5R92!W92=R92!C;VYN96-T960N("HO"B`@("`@("`@)'1H:7,M/E]C
M;VYN96-T*"D["@H@("`@("`@("\J($)U:6QD('1H92!344P@<75E<GDN("HO
M"B`@("`@("`@)'%U97)Y(#T@)T1%3$5412!&4D]-("<@+B`D=&AI<RT^7W!A
M<F%M<ULG=&%B;&4G73L*("`@("`@("`D<75E<GD@+CT@)R!72$5212!P<F5F
M7W5I9"`](#\G.PH*("`@("`@("`D=F%L=65S(#T@87)R87DH)'1H:7,M/E]U
M<V5R*3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G4U%,
M(%%U97)Y(&)Y(%!R969S7W-Q;#HZ8VQE87(H*3H@)7,G+"`D<75E<GDI+"!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@
M+RH@17AE8W5T92!T:&4@<75E<GDN("HO"B`@("`@("`@)')E<W5L="`]("1T
M:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["@H@("`@("`@("\J
M($-L96%N=7`N("HO"B`@("`@("`@<&%R96YT.CIC;&5A<B@I.PH*("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E
M<G1S(&$@=F%L=64@9G)O;2!T:&4@9')I=F5R)W,@8VAA<G-E="!T;R!T:&4@
M<W!E8VEF:65D(&-H87)S970N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D
M("1V86QU92`@("`@02!V86QU92!T;R!C;VYV97)T+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8VAA<G-E="`@5&AE(&-H87)S970@=&\@8V]N=F5R="!T;RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@8V]N=F5R=&5D('9A
M;'5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYV97)T1G)O;41R:79E<B@D
M=F%L=64L("1C:&%R<V5T*0H@("`@>PH@("`@("`@('-T871I8R`D8V]N=F5R
M=&5D(#T@87)R87DH*3L*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1V86QU92DI
M('L*("`@("`@("`@("`@<F5T=7)N(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H
M)'9A;'5E+"`D=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==+"`D8VAA<G-E="D[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?8F]O;"@D=F%L=64I*2!["B`@
M("`@("`@("`@(')E='5R;B`D=F%L=64["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(6ES<V5T*"1C;VYV97)T961;)&-H87)S971=6R1V86QU95TI*2!["B`@
M("`@("`@("`@("1C;VYV97)T961;)&-H87)S971=6R1V86QU95T@/2!3=')I
M;F<Z.F-O;G9E<G1#:&%R<V5T*"1V86QU92P@)'1H:7,M/E]P87)A;7-;)V-H
M87)S970G72P@)&-H87)S970I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1C;VYV97)T961;)&-H87)S971=6R1V86QU95T["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#;VYV97)T<R!A('9A;'5E(&9R;VT@=&AE('-P96-I9FEE9"!C
M:&%R<V5T('1O('1H92!D<FEV97(G<R!C:&%R<V5T+@H@("`@("H*("`@("`J
M($!P87)A;2!M:7AE9"`D=F%L=64@($$@=F%L=64@=&\@8V]N=F5R="X*("`@
M("`J($!P87)A;2!S=')I;F<@)&-H87)S970@(%1H92!C:&%R<V5T('1O(&-O
M;G9E<G0@9G)O;2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@
M8V]N=F5R=&5D('9A;'5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYV97)T
M5&]$<FEV97(H)'9A;'5E+"`D8VAA<G-E="D*("`@('L*("`@("`@("!R971U
M<FX@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D=F%L=64L("1C:&%R<V5T+"`D
M=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($%T=&5M<'1S('1O(&]P96X@82!P97)S:7-T96YT(&-O;FYE8W1I;VX@
M=&\@=&AE(%-13"!S97)V97(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C
M97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H*0H@("`@>PH@("`@("`@("\J($-H
M96-K('1O('-E92!I9B!W92!A<F4@86QR96%D>2!C;VYN96-T960N("HO"B`@
M("`@("`@:68@*"1T:&ES+3Y?8V]N;F5C=&5D*2!["B`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@2&]R9&4Z.F%S<V5R=$1R
M:79E<D-O;F9I9R@D=&AI<RT^7W!A<F%M<RP@)W!R969S)RP*("`@("`@("`@
M("`@87)R87DH)W!H<'1Y<&4G+"`G8VAA<G-E="<I+`H@("`@("`@("`@("`G
M<')E9F5R96YC97,@4U%,)RD["@H@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]P87)A;7-;)V1A=&%B87-E)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=D871A8F%S92==(#T@)R<["B`@("`@("`@?0H@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UTI*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M92==(#T@)R<["B`@("`@
M("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)W!A<W-W
M;W)D)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P87-S=V]R
M9"==(#T@)R<["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]P87)A;7-;)VAO<W1S<&5C)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=H;W-T<W!E8R==(#T@)R<["B`@("`@("`@?0H@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==(#T@)VAO<F1E7W!R969S)SL*
M("`@("`@("!]"@H@("`@("`@("\J($-O;FYE8W0@=&\@=&AE(%-13"!S97)V
M97(@=7-I;F<@=&AE('-U<'!L:65D('!A<F%M971E<G,N("HO"B`@("`@("`@
M)'1H:7,M/E]D8B`]("9$0CHZ8V]N;F5C="@D=&AI<RT^7W!A<F%M<RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=P97)S:7-T
M96YT)R`]/B`A96UP='DH)'1H:7,M/E]P87)A;7-;)W!E<G-I<W1E;G0G72DI
M*3L*("`@("`@("!I9B`H:7-?82@D=&AI<RT^7V1B+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"@D=&AI<RT^7V1B+"!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@+R\@4V5T($1"
M('!O<G1A8FEL:71Y(&]P=&EO;G,N"B`@("`@("`@<W=I=&-H("@D=&AI<RT^
M7V1B+3YP:'!T>7!E*2!["B`@("`@("`@8V%S92`G;7-S<6PG.@H@("`@("`@
M("`@("`D=&AI<RT^7V1B+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@1$)?
M4$]25$%"24Q)5%E?3$]715)#05-%('P@1$)?4$]25$%"24Q)5%E?15)23U)3
M('P@1$)?4$]25$%"24Q)5%E?4E1224TI.PH@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`D=&AI<RT^7V1B+3YS971/
M<'1I;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?3$]715)#05-%
M('P@1$)?4$]25$%"24Q)5%E?15)23U)3*3L*("`@("`@("!]"@H@("`@("`@
M("1T:&ES+3Y?8V]N;F5C=&5D(#T@=')U93L*"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$:7-C;VYN96-T(&9R;VT@=&AE
M(%-13"!S97)V97(@86YD(&-L96%N('5P('1H92!C;VYN96-T:6]N+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9&ES8V]N;F5C="@I"B`@("!["B`@
M("`@("`@:68@*"1T:&ES+3Y?8V]N;F5C=&5D*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?8V]N;F5C=&5D(#T@9F%L<V4["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7V1B+3YD:7-C;VYN96-T*"D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U!R969S+U5)+G!H<```````````````````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`S-#4U-@`Q,#4Q-30S,S<T-@`P,C$V,3$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J($-L87-S(&9O<B!A=71O+6=E;F5R871I;F<@=&AE('!R969E
M<F5N8V5S('5S97(@:6YT97)F86-E(&%N9`H@*B!P<F]C97-S:6YG('1H92!F
M;W)M<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP+'8@,2XV,RXR+C$U(#(P,#8O,#$O,3(@,C(Z,C4Z,30@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@
M2&]R9&4@,BXQ"B`J($!P86-K86=E($AO<F1E7U!R969S"B`J+PIC;&%S<R!0
M<F5F<U]522!["@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F4@=VAE=&AE<B!O
M<B!N;W0@82!P<F5F97)E;F-E<R!G<F]U<"!I<R!E9&ET86)L92X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1G<F]U<"`@5&AE('!R969E<F5N8V5S
M(&=R;W5P('1O(&-H96-K+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&=R;W5P(&ES(&5D:71A8FQE+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G<F]U<$ES161I=&%B;&4H)&=R;W5P*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D<')E9G,L("1P<F5F1W)O=7!S.PH*("`@("`@
M("!S=&%T:6,@)')E<W5L=',@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H(6ES
M<V5T*"1R97-U;'1S6R1G<F]U<%TI*2!["B`@("`@("`@("`@(&EF("@A96UP
M='DH)'!R969'<F]U<'-;)&=R;W5P75LG=7)L)UTI*2!["B`@("`@("`@("`@
M("`@("`D<F5S=6QT<ULD9W)O=7!=(#T@=')U93L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1R97-U;'1S6R1G<F]U<%T@/2!F86QS
M93L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<')E9D=R;W5P<ULD9W)O
M=7!=6R=M96UB97)S)UTI*2!["B`@("`@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)'!R969'<F]U<'-;)&=R;W5P75LG;65M8F5R<R==(&%S("1P<F5F*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A)'!R969S+3YI<TQO8VME
M9"@D<')E9BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97-U
M;'1S6R1G<F]U<%T@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT<ULD9W)O
M=7!=.PH@("`@?0H*("`@("\J*@H@("`@("H@2&%N9&QE(&$@<')E9F5R96YC
M97,@9F]R;2!S=6)M:7-S:6]N(&EF('1H97)E(&ES(&]N92P@=7!D871I;F<*
M("`@("`J(&%N>2!P<F5F97)E;F-E<R!W:&EC:"!H879E(&)E96X@8VAA;F=E
M9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1G<F]U<"`@5&AE('!R
M969E<F5N8V5S(&=R;W5P('1H870@=V%S(&5D:71E9"X*("`@("`J($!P87)A
M;2!O8FIE8W0@)'-A=F4@("!4:&4@;V)J96-T('=H97)E('1H92!C:&%N9V5D
M('9A;'5E<R!A<F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!S879E
M9"X@375S="!I;7!L96UE;G0@<V5T5F%L=64H<W1R:6YG+"!S=')I;F<I+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!P<F5F97)E
M;F-E<R!H879E(&)E96X@=7!D871E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M:&%N9&QE1F]R;2@F)&=R;W5P+"`F)'-A=F4I"B`@("!["B`@("`@("`@9VQO
M8F%L("1P<F5F<RP@)'!R969'<F]U<',L("1?<')E9G,L("1N;W1I9FEC871I
M;VXL("1R96=I<W1R>3L*"B`@("`@("`@)'5P9&%T960@/2!F86QS93L*"B`@
M("`@("`@+RH@4G5N('1H<F]U9V@@=&AE(&%C=&EO;B!H86YD;&5R<R`J+PH@
M("`@("`@(&EF("A5=&EL.CIG9710;W-T*"=A8W1I;VY)1"<I(#T]("=U<&1A
M=&5?<')E9G,G*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D9W)O=7`I("8F
M(%!R969S7U5).CIG<F]U<$ES161I=&%B;&4H)&=R;W5P*2D@>PH@("`@("`@
M("`@("`@("`@)'5P9&%T960@/2!F86QS93L*"B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D<')E9D=R;W5P<ULD9W)O=7!=6R=M96UB97)S)UT@87,@)'!R
M968I('L*("`@("`@("`@("`@("`@("`@("!I9B`H(21P<F5F<RT^:7-,;V-K
M960H)'!R968I('Q\"B`@("`@("`@("`@("`@("`@("`@("`@("@D7W!R969S
M6R1P<F5F75LG='EP92==(#T]("=S<&5C:6%L)RDI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@<W=I=&-H("@D7W!R969S6R1P<F5F75LG='EP92==*2![
M"@H@("`@("`@("`@("`@("`@("`@("`@("`O*B!4:&5S92!E:71H97(@87)E
M;B=T('-E="!O<B!A<F4@<V5T(&EN(&]T:&5R"B`@("`@("`@("`@("`@("`@
M("`@("`@("`J('!A<G1S(&]F('1H92!522X@*B\*("`@("`@("`@("`@("`@
M("`@("`@("`@8V%S92`G:6UP;&EC:70G.@H@("`@("`@("`@("`@("`@("`@
M("`@("!C87-E("=L:6YK)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G<V5L96-T
M)SH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G=&5X="<Z"B`@("`@
M("`@("`@("`@("`@("`@("`@(&-A<V4@)W1E>'1A<F5A)SH*("`@("`@("`@
M("`@("`@("`@("`@("`@8V%S92`G<&%S<W=O<F0G.@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'5P9&%T960@/2`D=7!D871E9"!\("1S879E+3YS
M971686QU92@D<')E9BP@571I;#HZ9V5T4&]S="@D<')E9BDI.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@
M("`@("`@("!C87-E("=E;G5M)SH*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1V86P@/2!5=&EL.CIG9710;W-T*"1P<F5F*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D7W!R969S6R1P<F5F75LG96YU
M;2==6R1V86Q=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1U<&1A=&5D(#T@)'5P9&%T960@?"`D<V%V92T^<V5T5F%L=64H)'!R968L
M("1V86PI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*%\H(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB*2P@
M)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)VUU;'1I96YU;2<Z"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=F%L<R`](%5T:6PZ.F=E=%!O<W0H)'!R968I
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-E="`](&%R<F%Y*"D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YV86QI9"`](&9A;'-E
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1V
M86QS*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1V86QS(&%S("1V86PI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1?<')E9G-;)'!R969=6R=E;G5M)UU;
M)'9A;%TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<V5T6UT@/2`D=F%L.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&EN=F%L:60@/2!T<G5E.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1I;G9A;&ED
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YO=&EF:6-A
M=&EO;BT^<'5S:"A?*")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N
M(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=7!D871E9"`]("1U<&1A=&5D('P@)'-A=F4M/G-E=%9A;'5E*"1P<F5F+"!`
M<V5R:6%L:7IE*"1S970I*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@("`@("`@("`@("`@8V%S92`G;G5M8F5R)SH*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1N=6T@/2!5=&EL.CIG9710;W-T*"1P<F5F*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI;G1V86PH)&YU;2D@
M(3T@)&YU;2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N
M;W1I9FEC871I;VXM/G!U<V@H7R@B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M
M8F5R+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS96EF("@D;G5M(#T](#`I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(E1H:7,@
M;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(I+"`G:&]R9&4N97)R;W(G
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'5P9&%T960@/2`D=7!D871E
M9"!\("1S879E+3YS971686QU92@D<')E9BP@)&YU;2D["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)V-H96-K
M8F]X)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V86P@/2!5=&EL
M.CIG9710;W-T*"1P<F5F*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1U<&1A=&5D(#T@)'5P9&%T960@?"`D<V%V92T^<V5T5F%L=64H)'!R968L
M(&ES<V5T*"1V86PI(#\@,2`Z(#`I.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@("`@("`@("!C87-E("=S
M<&5C:6%L)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\J($-O9&4@
M9F]R('-P96-I86P@96QE;65N=',@;75S="!B90H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("H@=W)I='1E;B!S<&5C:69I8V%L;'D@9F]R(&5A8V@*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`J(&%P<&QI8V%T:6]N+B`J
M+PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X
M:7-T<R@G:&%N9&QE7R<@+B`D<')E9BDI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=7!D871E9"`]("1U<&1A=&5D('P@8V%L;%]U<V5R
M7V9U;F,H)VAA;F1L95\G("X@)'!R968L("1U<&1A=&5D*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@(&EF("@D=7!D871E9"D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AF
M=6YC=&EO;E]E>&ES=',H)W!R969S7V-A;&QB86-K)RDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@<')E9G-?8V%L;&)A8VLH*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*&ES7V$H)'!R969S
M+"`G4')E9G-?<V5S<VEO;B<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1N;W1I9FEC871I;VXM/G!U<V@H7R@B66]U<B!O<'1I;VYS(&AA=F4@8F5E
M;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(I
M+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U
M<V@H7R@B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(I+"`G:&]R
M9&4N<W5C8V5S<R<I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`D9W)O=7`@/2!N=6QL.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'5P9&%T
M960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T92!T:&4@54D@9F]R
M('1H92!P<F5F97)E;F-E<R!I;G1E<F9A8V4L(&5I=&AE<B!F;W(@80H@("`@
M("H@<W!E8VEF:6,@9W)O=7`L(&]R('1H92!G<F]U<"!S96QE8W1I;VX@:6YT
M97)F86-E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&=R;W5P("!4
M:&4@9W)O=7`@=&\@9V5N97)A=&4@=&AE(%5)(&9O<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5N97)A=&5522@D9W)O=7`@/2!N=6QL*0H@("`@>PH@("`@
M("`@(&=L;V)A;"`D8G)O=W-E<BP@)&-O;F8L("1P<F5F<RP@)'!R969'<F]U
M<',L("1?<')E9G,L("1R96=I<W1R>2P@)&%P<#L*"B`@("`@("`@+RH@0VAE
M8VL@:68@86YY(&]P=&EO;G,@87)E(&%C='5A;&QY(&%V86EL86)L92X@*B\*
M("`@("`@("!I9B`H:7-?;G5L;"@D<')E9D=R;W5P<RDI('L*("`@("`@("`@
M("`@)$=,3T)!3%-;)VYO=&EF:6-A=&EO;B==+3YP=7-H*%\H(E1H97)E(&%R
M92!N;R!O<'1I;VYS(&%V86EL86)L92XB*2P@)VAO<F1E+FUE<W-A9V4G*3L*
M("`@("`@("!]"@H@("`@("`@("\J(%-H;W<@=&AE(&AE861E<BX@*B\*("`@
M("`@("!0<F5F<U]523HZ9V5N97)A=&5(96%D97(H)&=R;W5P*3L*"B`@("`@
M("`@+RH@07-S:6=N('9A<FEA8FQE<R!T;R!H;VQD('-E;&5C="!L:7-T<RX@
M*B\*("`@("`@("!I9B`H(21P<F5F<RT^:7-,;V-K960H)VQA;F=U86=E)RDI
M('L*("`@("`@("`@("`@)$=,3T)!3%-;)VQA;F=U86=E7V]P=&EO;G,G72`]
M("1'3$]"04Q36R=N;',G75LG;&%N9W5A9V5S)UT["B`@("`@("`@("`@(&%R
M<F%Y7W5N<VAI9G0H)$=,3T)!3%-;)VQA;F=U86=E7V]P=&EO;G,G72P@7R@B
M1&5F875L="(I*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)&=R
M;W5P*2`F)B!0<F5F<U]523HZ9W)O=7!)<T5D:71A8FQE*"1G<F]U<"DI('L*
M("`@("`@("`@("`@9F]R96%C:"`H)'!R969'<F]U<'-;)&=R;W5P75LG;65M
M8F5R<R==(&%S("1P<F5F*2!["B`@("`@("`@("`@("`@("!I9B`H(21P<F5F
M<RT^:7-,;V-K960H)'!R968I*2!["B`@("`@("`@("`@("`@("`@("`@+RH@
M1V5T('1H92!H96QP(&QI;FLN("HO"B`@("`@("`@("`@("`@("`@("`@:68@
M*"%E;7!T>2@D7W!R969S6R1P<F5F75LG:&5L<"==*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D:&5L<&QI;FL@/2!(96QP.CIL:6YK*"%E;7!T>2@D
M7W!R969S6R1P<F5F75LG<VAA<F5D)UTI(#\@)VAO<F1E)R`Z("1R96=I<W1R
M>2T^9V5T07!P*"DL("1?<')E9G-;)'!R969=6R=H96QP)UTI.PH@("`@("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1H96QP;&EN:R`](&YU;&P["B`@("`@("`@("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@("`@("`@("!S=VET8V@@*"1?<')E9G-;)'!R969=6R=T>7!E
M)UTI('L*("`@("`@("`@("`@("`@("`@("!C87-E("=I;7!L:6-I="<Z"B`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@
M("`@("!C87-E("=S<&5C:6%L)SH*("`@("`@("`@("`@("`@("`@("`@("`@
M<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@(65M<'1Y*"1?
M<')E9G-;)'!R969=6R=S:&%R960G72D@/R`G:&]R9&4G(#H@)')E9VES=')Y
M+3YG971!<'`H*2D@+B`B+W!R969S+R1P<F5F+FEN8R(["B`@("`@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@("`@("!D969A
M=6QT.@H@("`@("`@("`@("`@("`@("`@("`@("!R97%U:7)E("1R96=I<W1R
M>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N("<O<')E9G,O)R`N("1?
M<')E9G-;)'!R969=6R=T>7!E)UT@+B`G+FEN8R<["B`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!R97%U:7)E
M("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N("<O<')E
M9G,O96YD+FEN8R<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-P
M86X@/2`Q,#`["B`@("`@("`@("`@("1C;VQU;6YS(#T@87)R87DH*3L*("`@
M("`@("`@("`@:68@*&ES7V%R<F%Y*"1P<F5F1W)O=7!S*2D@>PH@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)'!R969'<F]U<',@87,@)&=R;W5P(#T^("1G
M=F%L<RD@>PH@("`@("`@("`@("`@("`@("`@(&EF("A0<F5F<U]523HZ9W)O
M=7!)<T5D:71A8FQE*"1G<F]U<"DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&-O;"`]("1G=F%L<ULG8V]L=6UN)UT["B`@("`@("`@("`@("`@("`@
M("`@("`@('5N<V5T*"1G=F%L<ULG8V]L=6UN)UTI.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D8V]L=6UN<ULD8V]L75LD9W)O=7!=(#T@)&=V86QS.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&EF("AC;W5N="@D8V]L=6UN<RDI('L*("`@("`@("`@("`@
M("`@("`@("`D<W!A;B`](')O=6YD*#$P,"`O(&-O=6YT*"1C;VQU;6YS*2D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(')E<75I<F4@)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L("=H;W)D92<I
M("X@)R]P<F5F<R]O=F5R=FEE=RYI;F,G.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($=E;F5R871E<R!T:&4@=&AE(&9U;&P@:&5A9&5R(&]F
M(&$@<')E9F5R96YC92!S8W)E96X@:6YC;'5D:6YG"B`@("`@*B!M96YU(&%N
M9"!N879I9V%T:6]N(&)A<G,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9W)O=7`@(%1H92!G<F]U<"!T;R!G96YE<F%T92!T:&4@:&5A9&5R(&9O
M<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5N97)A=&5(96%D97(H)&=R;W5P
M(#T@;G5L;"D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y+"`D<')E
M9D=R;W5P<RP@)&%P<"P@)'!E<FUS+"`D<')E9G,L("1N;W1I9FEC871I;VX[
M"@H@("`@("`@("1T:71L92`](%\H(E5S97(@3W!T:6]N<R(I.PH@("`@("`@
M(&EF("@D9W)O=7`@/3T@)VED96YT:71I97,G("8F("$D<')E9G,M/FES3&]C
M:V5D*"=D969A=6QT7VED96YT:71Y)RDI('L*("`@("`@("`@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"@G;F5W0VAO:6-E*"DG+"`G:F%V87-C<FEP="<I.PH@
M("`@("`@('T*("`@("`@("!R97%U:7)E("1R96=I<W1R>2T^9V5T*"=T96UP
M;&%T97,G+"`D87!P*2`N("<O8V]M;6]N+6AE861E<BYI;F,G.PH@("`@("`@
M(&EF("AI<U]C86QL86)L92AA<G)A>2@D87!P+"`G9V5T365N=2<I*2D@>PH@
M("`@("`@("`@("`D;65N=2`](&-A;&Q?=7-E<E]F=6YC*&%R<F%Y*"1A<'`L
M("=G971-96YU)RDI.PH@("`@("`@("`@("!R97%U:7)E("1R96=I<W1R>2T^
M9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N("<O;65N=2]M96YU+FEN8R<[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@57-E(&$@9&5F875L
M="!M96YU+B`J+PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TUE
M;G4N<&AP)SL*("`@("`@("`@("`@)&UE;G4@/2`F;F5W($UE;G4H*3L*("`@
M("`@("`@("`@<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@
M)VAO<F1E)RD@+B`G+VUE;G4O;65N=2YI;F,G.PH@("`@("`@('T*"B`@("`@
M("`@:68@*&ES7V-A;&QA8FQE*&%R<F%Y*"1A<'`L("=S=&%T=7,G*2DI('L*
M("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F,H87)R87DH)&%P<"P@)W-T871U
M<R<I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D1TQ/0D%,4ULG
M;F]T:69I8V%T:6]N)UTM/FYO=&EF>2AA<G)A>2@G;&ES=&5N97)S)R`]/B`G
M<W1A='5S)RDI.PH@("`@("`@('T*"B`@("`@("`@+RH@1V5T(&QI<W0@;V8@
M86-C97-S:6)L92!A<'!L:6-A=&EO;G,N("HO"B`@("`@("`@)&%P<',@/2!A
M<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1R96=I<W1R>2T^87!P;&EC871I
M;VYS(&%S("1A<'!L:6-A=&EO;B`]/B`D<&%R86US*2!["B`@("`@("`@("`@
M("\O($UA:V4@<W5R92!T:&4@87!P(&ES(&EN<W1A;&QE9"!A;F0@:&%S(&$@
M<')E9G,@9FEL92X*("`@("`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D<F5G
M:7-T<GDM/F=E="@G9FEL97)O;W0G+"`D87!P;&EC871I;VXI("X@)R]C;VYF
M:6<O<')E9G,N<&AP)RDI('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)'!A<F%M<ULG<W1A='5S
M)UT@/3T@)VAE861I;F<G('Q\"B`@("`@("`@("`@("`@("`D<&%R86US6R=S
M=&%T=7,G72`]/2`G8FQO8VLG*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@0VAE8VL@:68@=&AE
M(&-U<G)E;G0@=7-E<B!H87,@<&5R;6ES<V]N('1O('-E92!T:&ES"B`@("`@
M("`@("`@("`J(&%P<&QI8V%T:6]N+"!A;F0@:68@=&AE(&%P<&QI8V%T:6]N
M(&ES(&%C=&EV92X*("`@("`@("`@("`@("H@061M:6YI<W1R871O<G,@86QW
M87ES('-E92!A;&P@87!P;&EC871I;VYS+B`J+PH@("`@("`@("`@("!I9B`H
M*$%U=&@Z.FES061M:6XH*2`F)B`D<&%R86US6R=S=&%T=7,G72`A/2`G:6YA
M8W1I=F4G*2!\?`H@("`@("`@("`@("`@("`@*"1R96=I<W1R>2T^:&%S4&5R
M;6ES<VEO;B@D87!P;&EC871I;VXI("8F"B`@("`@("`@("`@("`@("`@*"1P
M87)A;7-;)W-T871U<R==(#T]("=A8W1I=F4G('Q\("1P87)A;7-;)W-T871U
M<R==(#T]("=N;W1O;VQB87(G*2DI('L*("`@("`@("`@("`@("`@("1A<'!S
M6R1A<'!L:6-A=&EO;ET@/2!?*"1P87)A;7-;)VYA;64G72D["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@87-O<G0H)&%P<',I.PH*("`@("`@
M("`O*B!3:&]W('1H92!C=7)R96YT(&%P<&QI8V%T:6]N(&%N9"!A(&9O<FT@
M9F]R('-W:71C:&EN9PH@("`@("`@("`J(&%P<&QI8V%T:6]N<RX@*B\*("`@
M("`@("!R97%U:7)E("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R
M9&4G*2`N("<O<')E9G,O87!P+FEN8R<["@H@("`@("`@("\J($EF('1H97)E
M)W,@;VYL>2!O;F4@<')E9D=R;W5P+"!J=7-T('-H;W<@:70N("HO"B`@("`@
M("`@:68@*&5M<'1Y*"1G<F]U<"D@)B8@8V]U;G0H)'!R969'<F]U<',I(#T]
M(#$I('L*("`@("`@("`@("`@)&=R;W5P(#T@87)R87E?:V5Y<R@D<')E9D=R
M;W5P<RD["B`@("`@("`@("`@("1G<F]U<"`](&%R<F%Y7W!O<"@D9W)O=7`I
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D9W)O=7`I("8F(%!R
M969S7U5).CIG<F]U<$ES161I=&%B;&4H)&=R;W5P*2D@>PH@("`@("`@("`@
M("!R97%U:7)E("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G
M*2`N("<O<')E9G,O8F5G:6XN:6YC)SL*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'96YE<F%T92!T:&4@8V]N=&5N="!O9B!T:&4@=&ET;&4@
M8F%R(&YA=FEG871I;VX@8V5L;"`H<')E=FEO=7,@?"!N97AT"B`@("`@*B!O
M<'1I;VX@9W)O=7`I+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&=R
M;W5P("!#=7)R96YT(&]P=&EO;B!G<F]U<"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5N97)A=&5.879I9V%T:6]N0V5L;"@D9W)O=7`I"B`@("!["B`@("`@
M("`@9VQO8F%L("1P<F5F1W)O=7!S+"`D<F5G:7-T<GDL("1A<'`["@H@("`@
M("`@("\O(%-E87)C:"!F;W(@<')E=FEO=7,@86YD(&YE>'0@9W)O=7!S+@H@
M("`@("`@("1P<F5V:6]U<R`](&YU;&P["B`@("`@("`@)&YE>'0@/2!N=6QL
M.PH@("`@("`@("1L87-T(#T@;G5L;#L*("`@("`@("`D9FER<W0@/2!N=6QL
M.PH@("`@("`@("1F;W5N9"`](&9A;'-E.PH@("`@("`@("1F:6YI<V@@/2!F
M86QS93L*("`@("`@("!F;W)E86-H("@D<')E9D=R;W5P<R!A<R`D<&=R;W5P
M(#T^("1G=F%L*2!["B`@("`@("`@("`@(&EF("A0<F5F<U]523HZ9W)O=7!)
M<T5D:71A8FQE*"1P9W)O=7`I*2!["B`@("`@("`@("`@("`@("!I9B`H(21F
M:7)S="D@>PH@("`@("`@("`@("`@("`@("`@("1F:7)S="`]("1P9W)O=7`[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(21F;W5N
M9"D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D<&=R;W5P(#T]("1G<F]U
M<"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<')E=FEO=7,@/2`D;&%S
M=#L*("`@("`@("`@("`@("`@("`@("`@("`@)&9O=6YD(#T@=')U93L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("@A)&9I;FES:"D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D9FEN:7-H(#T@=')U93L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&YE>'0@/2`D<&=R;W5P.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1L87-T(#T@
M)'!G<F]U<#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H
M(21P<F5V:6]U<RD@>PH@("`@("`@("`@("`D<')E=FEO=7,@/2`D;&%S=#L*
M("`@("`@("!]"B`@("`@("`@:68@*"$D;F5X="D@>PH@("`@("`@("`@("`D
M;F5X="`]("1F:7)S=#L*("`@("`@("!]"@H@("`@("`@("\J($1O;B=T(&QO
M;W`@:68@=&AE<F4G<R!O;FQY(&]N92!G<F]U<"X@*B\*("`@("`@("!I9B`H
M)&YE>'0@/3T@)'!R979I;W5S*2!["B`@("`@("`@("`@(')E='5R;CL*("`@
M("`@("!]"@H@("`@("`@(&5C:&\@)SQU;#X\;&D^)SL*("`@("`@("!I9B`H
M(65M<'1Y*"1P<F5F1W)O=7!S6R1P<F5V:6]U<UU;)W5R;"==*2D@>PH@("`@
M("`@("`@("!E8VAO($AO<F1E.CIL:6YK*$AO<F1E.CIA<'!L:6-A=&EO;E5R
M;"@D<')E9D=R;W5P<ULD<')E=FEO=7-=6R=U<FPG72DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@7R@B4')E=FEO=7,@;W!T:6]N<R(I*3L*("`@
M("`@("`@("`@96-H;R`G)FQT.R9L=#L@)R`N("1P<F5F1W)O=7!S6R1P<F5V
M:6]U<UU;)VQA8F5L)UT["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M96-H;R!(;W)D93HZ;&EN:RA5=&EL.CIA9&1087)A;65T97(H2&]R9&4Z.G5R
M;"@D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]S97)V
M:6-E<R]P<F5F<RYP:'`G*2P@87)R87DH)V=R;W5P)R`]/B`D<')E=FEO=7,L
M("=A<'`G(#T^("1A<'`I*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!?*")0<F5V:6]U<R!O<'1I;VYS(BDI.PH@("`@("`@("`@("!E8VAO("<F
M;'0[)FQT.R`G("X@)'!R969'<F]U<'-;)'!R979I;W5S75LG;&%B96PG73L*
M("`@("`@("!]"B`@("`@("`@96-H;R`G/"]A/B9N8G-P.WPF;F)S<#LG.PH@
M("`@("`@(&EF("@A96UP='DH)'!R969'<F]U<'-;)&YE>'1=6R=U<FPG72DI
M('L*("`@("`@("`@("`@96-H;R!(;W)D93HZ;&EN:RA(;W)D93HZ87!P;&EC
M871I;VY5<FPH)'!R969'<F]U<'-;)&YE>'1=6R=U<FPG72DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@7R@B3F5X="!O<'1I;VYS(BDI.PH@("`@
M("`@("`@("!E8VAO("1P<F5F1W)O=7!S6R1N97AT75LG;&%B96PG72`N("<@
M)F=T.R9G=#LG.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&5C:&\@
M2&]R9&4Z.FQI;FLH571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIU<FPH)')E
M9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<V5R=FEC97,O
M<')E9G,N<&AP)RDL(&%R<F%Y*"=G<F]U<"<@/3X@)&YE>'0L("=A<'`G(#T^
M("1A<'`I*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?*").97AT
M(&]P=&EO;G,B*2D["B`@("`@("`@("`@(&5C:&\@)'!R969'<F]U<'-;)&YE
M>'1=6R=L86)E;"==("X@)R`F9W0[)F=T.R<["B`@("`@("`@?0H@("`@("`@
M(&5C:&\@)SPO83X\+VQI/CPO=6P^)SL*("`@('T*"B`@("`O*BH*("`@("`J
M($=E="!T:&4@9&5F875L="!A<'!L:6-A=&EO;B!T;R!S:&]W('!R969E<F5N
M8V5S(&9O<BX@1&5F875L=',*("`@("`J('1O("=H;W)D92<N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$1E9F%U;'1!<'`H*0H@("`@>PH@("`@("`@("1A
M<'!L:6-A=&EO;G,@/2`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^;&ES=$%P<',H
M;G5L;"P@=')U92P@4$5235-?4D5!1"D["B`@("`@("`@<F5T=7)N(&ES<V5T
M*"1A<'!L:6-A=&EO;G-;)VAO<F1E)UTI(#\@)VAO<F1E)R`Z(&%R<F%Y7W-H
M:69T*"1A<'!L:6-A=&EO;G,I.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U!R969S+G!H<```````
M````````````````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`V,#<P-@`Q,#4Q
M-30S,S<U,@`P,C$R-C4`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"B\J*@H@*B!0<F5F97)E;F-E(&ES(&%D;6EN
M:7-T<F%T:79E;'D@;&]C:V5D+@H@*B\*9&5F:6YE*"=?4%)%1E],3T-+140G
M+"`Q*3L*"B\J*@H@*B!0<F5F97)E;F-E(&ES('-H87)E9"!A;6]N9W-T(&%P
M<&QI8V%T:6]N<RX*("HO"F1E9FEN92@G7U!2149?4TA!4D5$)RP@,BD["@HO
M*BH*("H@4')E9F5R96YC92!V86QU92!H87,@8F5E;B!C:&%N9V5D+@H@*B\*
M9&5F:6YE*"=?4%)%1E]$25)462<L(#0I.PH*+RHJ"B`J(%!R969E<F5N8V4@
M=F%L=64@:7,@=&AE(&%P<&QI8V%T:6]N(&1E9F%U;'0N"B`J+PID969I;F4H
M)U]04D5&7T1%1D%53%0G+"`X*3L*"B\J*@H@*B!4:&4@4')E9G,Z.B!C;&%S
M<R!P<F]V:61E<R!A(&-O;6UO;B!A8G-T<F%C=&5D(&EN=&5R9F%C92!I;G1O
M('1H90H@*B!V87)I;W5S('!R969E<F5N8V5S('-T;W)A9V4@;65D:75M<RX@
M($ET(&%L<V\@:6YC;'5D97,@86QL(&]F('1H90H@*B!F=6YC=&EO;G,@9F]R
M(')E=')I979I;F<L('-T;W)I;F<L(&%N9"!C:&5C:VEN9R!P<F5F97)E;F-E
M('9A;'5E<RX*("H*("H@5$]$3SH@9&]C=6UE;G0@=&AE(&9O<FUA="!O9B!T
M:&4@)%]P<F5F<R!H87-H(&AE<F4*("H*("H@)%]P<F5F<ULJ<')E9B!N86UE
M*ET@/2!A<G)A>2@*("H@("`@("=V86QU92<@(#T^("I$969A=6QT('9A;'5E
M*BP*("H@("`@("=L;V-K960G(#T^("IB;V]L96%N*BP*("H@("`@("=S:&%R
M960G(#T^("IB;V]L96%N*BP*("H@("`@("=T>7!E)R`@(#T^("=C:&5C:V)O
M>"<*("H@("`@("`@("`@("`@("`@("=T97AT)PH@*B`@("`@("`@("`@("`@
M("`@)W!A<W-W;W)D)PH@*B`@("`@("`@("`@("`@("`@)W1E>'1A<F5A)PH@
M*B`@("`@("`@("`@("`@("`@)W-E;&5C="<*("H@("`@("`@("`@("`@("`@
M("=N=6UB97(G"B`J("`@("`@("`@("`@("`@("`G:6UP;&EC:70G"B`J("`@
M("`@("`@("`@("`@("`G<W!E8VEA;"<*("H@("`@("`@("`@("`@("`@("=L
M:6YK)R`M(%1H97)E(&UU<W0@8F4@82!F:65L9"!N86UE9"!E:71H97(@)W5R
M;"<*("H@("`@("`@("`@("`@("`@("`@("`@("`@("AI;G1E<FYA;"!A<'!L
M:6-A=&EO;B!L:6YK*2!O<B`G>'5R;"<*("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("AE>'1E<FYA;"!A<'!L:6-A=&EO;B!L:6YK*2!I9B!T:&ES('1Y
M<&4@:7,@=7-E9"X*("H@("`@("`@("`@("`@("`@("=E;G5M)PH@*B`@("`@
M)V5N=6TG("`@/3X@5$]$3RP*("H@("`@("=D97-C)R`@(#T^(%\H*D1E<V-R
M:7!T:6]N('-T<FEN9RHI+`H@*B`@("`@)VAE;'`G("`@/3X@*DYA;64@;V8@
M=&AE(&5N=')Y(&EN('1H92!834P@:&5L<"!F:6QE*@H@*B`I.PH@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`L=B`Q+C$S-RXQ,"XR
M-R`R,#`V+S`W+S`S(#$W.C,X.C$Q(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!H;W)D
M92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D
M95]0<F5F<PH@*B\*8VQA<W,@4')E9G,@>PH*("`@("\J*@H@("`@("H@2&%S
M:"!H;VQD:6YG(&%L;"!O9B!T:&4@=7-E<B=S('!R969E<F5N8V5S+B!%86-H
M('!R969E<F5N8V4@:7,*("`@("`J(&ET<V5L9B!A(&AA<V@L('-O('1H:7,@
M=VEL;"!U;'1I;6%T96QY(&)E(&UU;'1I+61I;65N<VEO;F%L+@H@("`@("H*
M("`@("`J(%LJ<')E9B!N86UE*ET@/3X@07)R87DH"B`@("`@*B`@("`@6V1=
M("`]/B`@*F1E9F%U;'0@=F%L=64J"B`@("`@*B`@("`@6VU=("`]/B`@*G!R
M968@;6%S:RH*("`@("`J("`@("!;=ET@(#T^("`J<')E9B!V86QU92H*("`@
M("`J("D*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!R969S(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("`J(%-T<FEN9R!C;VYT86EN:6YG('1H92!N
M86UE(&]F('1H:7,@<V-O<&4N(%1H:7,@:7,@=7-E9"!T;PH@("`@("H@;6%I
M;G1A:6X@=&AE(&%P<&QI8V%T:6]N('-C;W!E(&)E='=E96X@<V5T<R!O9B!P
M<F5F97)E;F-E<RX@0GD*("`@("`J(&1E9F%U;'0L(&%L;"!P<F5F97)E;F-E
M<R!B96QO;F<@=&\@=&AE(")G;&]B86PB("A(;W)D92D@<V-O<&4N"B`@("`@
M*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<V-O<&4@
M/2`G:&]R9&4G.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&-O;G1A:6YI;F<@
M=&AE(&-U<G)E;G0@=7-E<FYA;64N(%1H:7,@:6YD:6-A=&5S('1H92!O=VYE
M<B!O9B!T:&4*("`@("`J('!R969E<F5N8V5S+@H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W5S97(@/2`G)SL*"B`@("`O
M*BH*("`@("`J($)O;VQE86X@:6YD:6-A=&EN9R!W:&5T:&5R('!R969E<F5N
M8V4@8V%C:&EN9R!S:&]U;&0@8F4@=7-E9"X*("`@("`J"B`@("`@*B!`=F%R
M(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?8V%C:&EN9R`](&9A;'-E.PH*
M("`@("\J*@H@("`@("H@2&%S:"!H;VQD:6YG('!R969E<F5N8V5S('=I=&@@
M:&]O:R!F=6YC=&EO;G,@9&5F:6YE9"X*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7VAO;VMS(#T@87)R87DH*3L*"B`@("`O
M*BH*("`@("`J($AA=F4@=V4@<G5N(&AO;VL@9G5N8W1I;VYS('EE=#\*("`@
M("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?:&]O
M:W-#86QL960@/2!N=6QL.PH*("`@("\J*@H@("`@("H@1&5F875L="!C;VYS
M=')U8W1O<B`H;75S="!B92!C86QL960@9G)O;2!E86-H(&5X=&5N9&EN9R!C
M;&%S<R!I;B!T:&5I<@H@("`@("H@8V]N<W1R=6-T;W)S('9I82!P87)E;G0Z
M.E!R969S*"DI+@H@("`@("HO"B`@("!F=6YC=&EO;B!0<F5F<R@I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]S:'5T9&]W;B@I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@8VAA<G-E="!U<V5D(&)Y('1H92!C;VYC<F5T
M92!P<F5F97)E;F-E(&)A8VME;F0N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!P<F5F97)E;F-E(&)A8VME;F0G<R!C:&%R<V5T+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971#:&%R<V5T*"D*("`@('L*("`@("`@("!R
M971U<FX@3DQ3.CIG971#:&%R<V5T*"D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!5<&1A=&5S('1H92!S97-S:6]N+6)A<V5D('!R969E<F5N8V5S(&-A8VAE
M("AI9B!A=F%I;&%B;&4I+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'!R968@(%1H92!P<F5F97)E;F-E('1O('5P9&%T92X@($EF(&5M<'1Y+"!W
M:6QL('5P9&%T90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@=&AE(&5N
M=&ER92!C86-H92!W:71H('1H92!C=7)R96YT('-E="!O9B!P<F5F<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@8V%C:&55<&1A=&4H)'!R968@/2!N=6QL*0H@
M("`@>PH@("`@("`@("\J(%)E='5R;B!I;6UE9&EA=&5L>2!I9B!C86-H:6YG
M(&ES(&1I<V%B;&5D+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/E]C86-H:6YG
M*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@(&EF
M("AI<W-E="@D7U-%4U-)3TY;)W!R969S7V-A8VAE)UTI*2!["B`@("`@("`@
M("`@(&EF("AI<U]N=6QL*"1P<F5F*2D@>PH@("`@("`@("`@("`@("`@)'!R
M969S(#T@)'1H:7,M/E]P<F5F<SL*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1P<F5F<R`](&%R<F%Y*"1P<F5F(#T^("1T:&ES+3Y?
M<')E9G-;)'!R969=*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@
M4&QA8V4@96%C:"!P<F5F97)E;F-E(&EN('1H92!C86-H92!A8V-O<F1I;F<@
M=&\@:71S"B`@("`@("`@("`@("`J('-C;W!E+B`J+PH@("`@("`@("`@("!F
M;W)E86-H("@D<')E9G,@87,@)&YA;64@/3X@)'!R968I('L*("`@("`@("`@
M("`@("`@("1?4T534TE/3ELG<')E9G-?8V%C:&4G75LD=&AI<RT^9V5T4V-O
M<&4H)&YA;64I75LD;F%M95T@/2`D<')E9CL*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%1R:65S('1O(&9I;F0@=&AE
M(')E<75E<W1E9"!P<F5F97)E;F-E<R!I;B!T:&4@8V%C:&4N($EF('1H97D@
M97AI<W0L"B`@("`@*B!U<&1A=&4@=&AE("1P<F5F<R!H87-H('=I=&@@=&AE
M(&-A8VAE9"!V86QU97,N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&-A8VAE3&]O:W5P*"D*("`@('L*("`@("`@("`O*B!2
M971U<FX@:6UM961I871E;'D@:68@8V%C:&EN9R!I<R!D:7-A8FQE9"X@*B\*
M("`@("`@("!I9B`H(21T:&ES+3Y?8V%C:&EN9RD@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)%]3
M15-324].6R=P<F5F<U]C86-H92==6R=H;W)D92==*2`F)@H@("`@("`@("`@
M("!I<W-E="@D7U-%4U-)3TY;)W!R969S7V-A8VAE)UU;)'1H:7,M/E]S8V]P
M95TI*2!["@H@("`@("`@("`@("`O*B!297-T;W)E(&=L;V)A;"!P<F5F97)E
M;F-E<RX@*B\*("`@("`@("`@("`@)'1H:7,M/E]P<F5F<R`](&%R<F%Y7VUE
M<F=E*"1T:&ES+3Y?<')E9G,L("1?4T534TE/3ELG<')E9G-?8V%C:&4G75LG
M:&]R9&4G72P@)%]315-324].6R=P<F5F<U]C86-H92==6R1T:&ES+3Y?<V-O
M<&5=*3L*"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@061D
M<R!A(&YE=R!P<F5F97)E;F-E(&5N=')Y('1O('1H92`D<')E9G,@:&%S:"X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<F5F("`@5&AE(&YA;64@
M;V8@=&AE('!R969E<F5N8V4@=&\@861D+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=F%L("`@(%1H92!I;FET:6%L('9A;'5E(&]F('1H92!P<F5F97)E;F-E
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UA<VL@(%1H92!I;FET:6%L(&)I
M=&UA<VL@;V8@=&AE('!R969E<F5N8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%D9"@D<')E9BP@)'9A;"`]("<G+"`D;6%S:R`](#`I"B`@("!["B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?<')E9G,I*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?<')E9G-;)'!R969=(#T@87)R87DH)W8G(#T^("1V86PL("=M
M)R`]/B`D;6%S:RP@)V0G(#T^("1V86PI.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E;6]V97,@82!P<F5F97)E;F-E(&5N=')Y(&9R;VT@
M=&AE("1P<F5F<R!H87-H+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'!R968@(%1H92!N86UE(&]F('1H92!P<F5F97)E;F-E('1O(')E;6]V92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E*"1P<F5F*0H@("`@>PH@("`@
M("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^7W!R969S*2D@>PH@("`@("`@("`@
M("`D<V-O<&4@/2`D=&AI<RT^9V5T4V-O<&4H)'!R968I.PH@("`@("`@("`@
M("!U;G-E="@D=&AI<RT^7W!R969S6R1P<F5F72D["B`@("`@("`@("`@('5N
M<V5T*"1?4T534TE/3ELG<')E9G-?8V%C:&4G75LD<V-O<&5=6R1P<F5F72D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@9VEV
M96X@<')E9F5R96YC97,@*"1P<F5F*2!T;R!T:&4@<W!E8VEF:65D('9A;'5E
M"B`@("`@*B`H)'9A;"DL(&EF('1H92!P<F5F97)E;F-E(&ES(&UO9&EF:6%B
M;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E9B`@("`@(%1H
M92!N86UE(&]F('1H92!P<F5F97)E;F-E('1O(&UO9&EF>2X*("`@("`J($!P
M87)A;2!S=')I;F<@)'9A;"`@("`@("!4:&4@;F5W('9A;'5E(&9O<B!T:&ES
M('!R969E<F5N8V4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8V]N=F5R="`@
M268@=')U92!T:&4@<')E9F5R96YC92!V86QU92!G971S(&-O;G9E<G1E9`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&9R;VT@=&AE(&-U<G)E
M;G0@8VAA<G-E="!T;R!T:&4@8F%C:V5N9"=S"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@8VAA<G-E="X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%1R=64@:68@=&AE('9A;'5E('=A<R!S=6-C97-S9G5L;'D@
M<V5T+"!F86QS92!O;B!A"B`@("`@*B`@("`@("`@("`@("`@("`@(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%9A;'5E*"1P<F5F+"`D=F%L
M+"`D8V]N=F5R="`]('1R=64I"B`@("!["B`@("`@("`@+RH@17AI="!E87)L
M>2!I9B!T:&ES('!R969E<F5N8V4@:7,@;&]C:V5D(&]R(&1O97-N)W0@97AI
M<W0N("HO"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!R969S6R1P<F5F
M72D@?'P@)'1H:7,M/FES3&]C:V5D*"1P<F5F*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M
M/E]S971686QU92@D<')E9BP@)'9A;"P@=')U92P@)&-O;G9E<G0I.PH@("`@
M?0H*("`@(&9U;F-T:6]N(%]?<V5T*"1N86UE+"`D=F%L=64I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3YS971686QU92@D;F%M92P@)'9A;'5E*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(&=I=F5N('!R969E<F5N
M8V5S("@D<')E9BD@=&\@=&AE('-P96-I9FEE9"!V86QU90H@("`@("H@*"1V
M86PI+"!W:&5T:&5R(&]R(&YO="!T:&4@<')E9F5R96YC92!I<R!U<V5R+6UO
M9&EF:6%B;&4L('5N<V5T"B`@("`@*B!T:&4@9&5F875L="!B:70L(&%N9"!S
M970@=&AE(&1I<G1Y(&)I="X*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E
M8W1E9`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1P<F5F("`@("!4
M:&4@;F%M92!O9B!T:&4@<')E9F5R96YC92!T;R!M;V1I9GDN"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D=F%L("`@("`@5&AE(&YE=R!V86QU92!F;W(@=&AI
M<R!P<F5F97)E;F-E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&1I<G1Y("`@
M(%1R=64@:68@=V4@<VAO=6QD(&UA<FL@=&AE(&YE=R!V86QU92!A<PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@(&1I<G1Y("AC:&%N9V5D*2X*
M("`@("`J($!P87)A;2!B;V]L96%N("1C;VYV97)T("!)9B!T<G5E('1H92!P
M<F5F97)E;F-E('9A;'5E(&=E=',@8V]N=F5R=&5D"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@9G)O;2!T:&4@8W5R<F5N="!C:&%R<V5T('1O
M('1H92!B86-K96YD)W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("!C:&%R<V5T+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U
M92!I9B!T:&4@=F%L=64@=V%S('-U8V-E<W-F=6QL>2!S970L(&9A;'-E(&]N
M(&$*("`@("`J("`@("`@("`@("`@("`@("`@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7W-E=%9A;'5E*"1P<F5F+"`D=F%L+"`D9&ER='D@/2!T
M<G5E+"`D8V]N=F5R="`]('1R=64I"B`@("!["B`@("`@("`@9VQO8F%L("1C
M;VYF.PH*("`@("`@("!I9B`H)&-O;G9E<G0I('L*("`@("`@("`@("`@)'9A
M;"`]("1T:&ES+3YC;VYV97)T5&]$<FEV97(H)'9A;"P@3DQ3.CIG971#:&%R
M<V5T*"DI.PH@("`@("`@('T*"B`@("`@("`@+RH@268@=&AE('!R969E<F5N
M8V4G<R!V86QU92!I<R!A;')E861Y(&5Q=6%L('1O("1V86PL(&1O;B=T"B`@
M("`@("`@("H@8F]T:&5R(&-H86YG:6YG(&ET+B!#:&%N9VEN9R!I="!W;W5L
M9"!S970@=&AE(")D:7)T>2(@8FET+`H@("`@("`@("`J(&-A=7-I;F<@86X@
M=6YN96-E<W-A<GD@=7!D871E(&QA=&5R(&]N(&EN('1H92!S=&]R86=E"B`@
M("`@("`@("H@<F]U=&EN92X@*B\*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]P<F5F<ULD<')E9ETI("8F"B`@("`@("`@("`@("@H)'1H:7,M/E]P<F5F
M<ULD<')E9EU;)W8G72`]/2`D=F%L*2`F)@H@("`@("`@("`@("`@(21T:&ES
M+3YI<T1E9F%U;'0H)'!R968I*2D@>PH@("`@("`@("`@("!R971U<FX@=')U
M93L*("`@("`@("!]"@H@("`@("`@("\J($-H96-K('1O('-E92!I9B!T:&4@
M=F%L=64@97AC965D<R!T:&4@86QL;W=A8FQE('-T;W)A9V4*("`@("`@("`@
M*B!L:6UI="X@*B\*("`@("`@("!I9B`H:7-S970H)&-O;F9;)W!R969S)UU;
M)VUA>'-I>F4G72DI('L*("`@("`@("`@("`@:68@*'-T<FQE;B@D=F%L*2`^
M("1C;VYF6R=P<F5F<R==6R=M87AS:7IE)UTI('L*("`@("`@("`@("`@("`@
M(&=L;V)A;"`D;F]T:69I8V%T:6]N.PH@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1N;W1I9FEC871I;VXI*2!["B`@("`@("`@("`@("`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E1H92!P<F5F97)E;F-E(%PB
M)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E
M961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(I+"`D<')E9BDL("=H
M;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+RH@07-S:6=N('1H92!N97<@=F%L=64L('5N<V5T('1H92`B
M9&5F875L="(@8FET+"!A;F0@<V5T('1H90H@("`@("`@("`@(")D:7)T>2(@
M8FET+B`J+PH@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!R969S6R1P<F5F
M75LG;2==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!R969S6R1P<F5F75LG
M;2==(#T@,#L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]P<F5F<ULD<')E
M9EU;)W8G72`]("1V86P["B`@("`@("`@)'1H:7,M/G-E=$1E9F%U;'0H)'!R
M968L(&9A;'-E*3L*("`@("`@("!I9B`H)&1I<G1Y*2!["B`@("`@("`@("`@
M("1T:&ES+3YS971$:7)T>2@D<')E9BP@=')U92D["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^8V%C:&55<&1A=&4H)'!R968I.PH*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('9A
M;'5E(&]F('1H92!R97%U97-T960@<')E9F5R96YC92X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1P<F5F("`@("`@5&AE(&YA;64@;V8@=&AE('!R
M969E<F5N8V4@=&\@<F5T<FEE=F4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M8V]N=F5R="`@268@=')U92!T:&4@<')E9F5R96YC92!V86QU92!G971S(&-O
M;G9E<G1E9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&9R;VT@
M=&AE(&)A8VME;F0G<R!C:&%R<V5T('1O('1H92!C=7)R96YT"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@8VAA<G-E="X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE('9A;'5E(&]F('1H92!P<F5F97)E;F-E
M+"!N=6QL(&EF(&ET(&1O97-N)W0@97AI<W0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=%9A;'5E*"1P<F5F+"`D8V]N=F5R="`]('1R=64I"B`@("!["B`@
M("`@("`@<W1A=&EC("1C:&%R<V5T.PH@("`@("`@(&EF("@A:7-S970H)&-H
M87)S970I*2!["B`@("`@("`@("`@("1C:&%R<V5T(#T@3DQ3.CIG971#:&%R
M<V5T*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@*&ES<V5T*"1T:&ES
M+3Y?<')E9G-;)'!R969=6R=V)UTI*2`_"B`@("`@("`@("`@("@D8V]N=F5R
M="`_"B`@("`@("`@("`@("`D=&AI<RT^8V]N=F5R=$9R;VU$<FEV97(H)'1H
M:7,M/E]P<F5F<ULD<')E9EU;)W8G72P@)&-H87)S970I(#H*("`@("`@("`@
M("`@("1T:&ES+3Y?<')E9G-;)'!R969=6R=V)UTI(#H*("`@("`@("`@("`@
M;G5L;#L*("`@('T*"B`@("!F=6YC=&EO;B!?7V=E="@D;F%M92D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/F=E=%9A;'5E*"1N86UE*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($UO9&EF:65S('1H92`B;&]C:V5D(B!B:70@9F]R
M('1H92!G:79E;B!P<F5F97)E;F-E+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'!R968@("!4:&4@;F%M92!O9B!T:&4@<')E9F5R96YC92!T;R!M
M;V1I9GDN"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8F]O;"`@5&AE(&YE=R!B
M;V]L96%N('9A;'5E(&9O<B!T:&4@(FQO8VME9"(@8FET+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!S971,;V-K960H)'!R968L("1B;V]L*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?<V5T36%S:R@D<')E9BP@)&)O;VPL(%]04D5&7TQ/0TM%
M1"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!S=&%T92!O
M9B!T:&4@(FQO8VME9"(@8FET(&9O<B!T:&4@9VEV96X@<')E9F5R96YC92X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<F5F("!4:&4@;F%M92!O
M9B!T:&4@<')E9F5R96YC92!T;R!C:&5C:RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1H92!B;V]L96%N('-T871E(&]F("1P<F5F)W,@(FQO
M8VME9"(@8FET+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<TQO8VME9"@D<')E
M9BD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]G971-87-K*"1P<F5F
M+"!?4%)%1E],3T-+140I.PH@("`@?0H*("`@("\J*@H@("`@("H@36]D:69I
M97,@=&AE(")S:&%R960B(&)I="!F;W(@=&AE(&=I=F5N('!R969E<F5N8V4N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E9B`@(%1H92!N86UE
M(&]F('1H92!P<F5F97)E;F-E('1O(&UO9&EF>2X*("`@("`J($!P87)A;2!B
M;V]L96%N("1B;V]L("!4:&4@;F5W(&)O;VQE86X@=F%L=64@9F]R('1H92`B
M<VAA<F5D(B!B:70N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%-H87)E9"@D
M<')E9BP@)&)O;VPI"B`@("!["B`@("`@("`@)'1H:7,M/E]S971-87-K*"1P
M<F5F+"`D8F]O;"P@7U!2149?4TA!4D5$*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE('-T871E(&]F('1H92`B<VAA<F5D(B!B:70@9F]R
M('1H92!G:79E;B!P<F5F97)E;F-E+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'!R968@(%1H92!N86UE(&]F('1H92!P<F5F97)E;F-E('1O(&-H
M96-K+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5&AE(&)O;VQE
M86X@<W1A=&4@;V8@)'!R968G<R`B<VAA<F5D(B!B:70N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&ES4VAA<F5D*"1P<F5F*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7V=E=$UA<VLH)'!R968L(%]04D5&7U-(05)%1"D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!-;V1I9FEE<R!T:&4@(F1I<G1Y(B!B:70@9F]R
M('1H92!G:79E;B!P<F5F97)E;F-E+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'!R968@("`@("!4:&4@;F%M92!O9B!T:&4@<')E9F5R96YC92!T
M;R!M;V1I9GDN"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8F]O;"`@("`@5&AE
M(&YE=R!B;V]L96%N('9A;'5E(&9O<B!T:&4@(F1I<G1Y(B!B:70N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=$1I<G1Y*"1P<F5F+"`D8F]O;"D*("`@('L*
M("`@("`@("`D=&AI<RT^7W-E=$UA<VLH)'!R968L("1B;V]L+"!?4%)%1E]$
M25)462D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!S=&%T
M92!O9B!T:&4@(F1I<G1Y(B!B:70@9F]R('1H92!G:79E;B!P<F5F97)E;F-E
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!R968@(%1H92!N86UE
M(&]F('1H92!P<F5F97)E;F-E('1O(&-H96-K+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@5&AE(&)O;VQE86X@<W1A=&4@;V8@)'!R968G<R`B
M9&ER='DB(&)I="X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-$:7)T>2@D<')E
M9BD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]G971-87-K*"1P<F5F
M+"!?4%)%1E]$25)462D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!-;V1I9FEE
M<R!T:&4@(F1E9F%U;'0B(&)I="!F;W(@=&AE(&=I=F5N('!R969E<F5N8V4N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E9B`@(%1H92!N86UE
M(&]F('1H92!P<F5F97)E;F-E('1O(&UO9&EF>2X*("`@("`J($!P87)A;2!B
M;V]L96%N("1B;V]L("!4:&4@;F5W(&)O;VQE86X@=F%L=64@9F]R('1H92`B
M9&5F875L="(@8FET+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971$969A=6QT
M*"1P<F5F+"`D8F]O;"D*("`@('L*("`@("`@("`D=&AI<RT^7W-E=$UA<VLH
M)'!R968L("1B;V]L+"!?4%)%1E]$149!54Q4*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE(&1E9F%U;'0@=F%L=64@;V8@=&AE(&=I=F5N
M('!R969E<F5N8V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E
M9B`@5&AE(&YA;64@;V8@=&AE('!R969E<F5N8V4@=&\@9V5T('1H92!D969A
M=6QT(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@("`@("!4
M:&4@<')E9F5R96YC92=S(&1E9F%U;'0@=F%L=64N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$1E9F%U;'0H)'!R968I"B`@("!["B`@("`@("`@<F5T=7)N
M("%E;7!T>2@D=&AI<RT^7W!R969S6R1P<F5F75LG9"==*2`_"B`@("`@("`@
M("`@("1T:&ES+3Y?<')E9G-;)'!R969=6R=D)UT@.@H@("`@("`@("`@("`G
M)SL*("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@:68@=&AE(&-U
M<G)E;G0@<')E9F5R96YC92!V86QU92!I<R!T:&4@9&5F875L=`H@("`@("H@
M=F%L=64@9G)O;2!P<F5F<RYP:'`@;W(@82!U<V5R(&1E9FEN960@=F%L=64*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<F5F("!4:&4@;F%M92!O
M9B!T:&4@<')E9F5R96YC92!T;R!C:&5C:RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@:68@=&AE('!R969E<F5N8V4@:7,@=&AE(&%P
M<&QI8V%T:6]N(&1E9F%U;'0*("`@("`J("`@("`@("`@("`@("`@("`@=F%L
M=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES1&5F875L="@D<')E9BD*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/E]G971-87-K*"1P<F5F+"!?4%)%
M1E]$149!54Q4*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE('9A
M;'5E(&9O<B!A(&=I=F5N(&UA<VLN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E9B`@(%1H
M92!N86UE(&]F('1H92!P<F5F97)E;F-E('1O(&UO9&EF>2X*("`@("`J($!P
M87)A;2!B;V]L96%N("1B;V]L("!4:&4@;F5W(&)O;VQE86X@=F%L=64@9F]R
M('1H92`B9&5F875L="(@8FET+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UA
M<VL@(%1H92!M87-K('1O(&%D9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E
M=$UA<VLH)'!R968L("1B;V]L+"`D;6%S:RD*("`@('L*("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/E]P<F5F<ULD<')E9ETI*2!["B`@("`@("`@("`@(&EF
M("@D8F]O;"`A/2`D=&AI<RT^7V=E=$UA<VLH)'!R968L("1M87-K*2D@>PH@
M("`@("`@("`@("`@("`@:68@*"1B;V]L*2!["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P<F5F<ULD<')E9EU;)VTG72!\/2`D;6%S:SL*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P<F5F<ULD<')E9EU;)VTG72`F/2!^)&UA<VL["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!'971S('1H92!B;V]L96%N('-T871E(&9O<B!A(&=I=F5N(&UA<VLN
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<')E9B`@(%1H92!N86UE(&]F('1H92!P<F5F97)E
M;F-E('1O(&UO9&EF>2X*("`@("`J($!P87)A;2!I;G1E9V5R("1M87-K("!4
M:&4@;6%S:R!T;R!G970N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!4:&4@8F]O;&5A;B!S=&%T92!F;W(@=&AE(&=I=F5N(&UA<VLN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]G971-87-K*"1P<F5F+"`D;6%S:RD*("`@('L*
M("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/E]P<F5F<ULD<')E9EU;)VTG
M72D@/R`H)'1H:7,M/E]P<F5F<ULD<')E9EU;)VTG72`F("1M87-K*2`Z(&9A
M;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!W:&5T:&5R
M('1H92!C=7)R96YT('!R969E<F5N8V4@:7,@96UP='DN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<')E9B`@5&AE(&YA;64@;V8@=&AE('!R969E
M<F5N8V4@=&\@8VAE8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!4<G5E(&EF('1H92!P<F5F97)E;F-E(&ES(&5M<'1Y+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!I<T5M<'1Y*"1P<F5F*0H@("`@>PH@("`@("`@(')E='5R
M;B!E;7!T>2@D=&AI<RT^7W!R969S6R1P<F5F75LG=B==*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE('-C;W!E(&]F('1H92!G:79E;B!P
M<F5F97)E;F-E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!R968@
M(%1H92!N86UE(&]F('1H92!P<F5F97)E;F-E('1O(&5X86UI;F4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!S8V]P92!O9B!T:&4@)'!R
M968N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-C;W!E*"1P<F5F*0H@("`@
M>PH@("`@("`@(&EF("@D=&AI<RT^:7-3:&%R960H)'!R968I*2!["B`@("`@
M("`@("`@(')E='5R;B`G:&]R9&4G.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7W-C;W!E.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;B!A(&QI<W0@;V8@(F1I<G1Y(B!P<F5F
M97)E;F-E<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@;&ES="!O9B`B9&ER='DB('!R
M969E<F5N8V5S(&EN("1T:&ES+3Y?<')E9G,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]D:7)T>5!R969S*"D*("`@('L*("`@("`@("`D9&ER='E?<')E9G,@
M/2!A<G)A>2@I.PH*("`@("`@("!F;W)E86-H("AA<G)A>5]K97ES*"1T:&ES
M+3Y?<')E9G,I(&%S("1P<F5F*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^
M:7-$:7)T>2@D<')E9BDI('L*("`@("`@("`@("`@("`@("1D:7)T>5]P<F5F
M<UM=(#T@)'!R968["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D9&ER='E?<')E9G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971R:65V97,@=&AE(&1E9F%U;'0@<')E9F5R96YC97,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')E=')I979E*"D*("`@('L*("`@("`@("`O*B!,;V%D(&1E
M9F%U;'1S('1O(&UA:V4@<W5R92!W92!H879E(&%L;"!P<F5F97)E;F-E<RX@
M*B\*("`@("`@("`D=&AI<RT^7W-E=$1E9F%U;'1S*"=H;W)D92<I.PH@("`@
M("`@("1T:&ES+3Y?<V5T1&5F875L=',H)'1H:7,M/E]S8V]P92D["@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!F
M=6YC=&EO;B!W:6QL(&)E(')U;B!A="!T:&4@96YD(&]F(&5V97)Y(')E<75E
M<W0@87,@82!S:'5T9&]W;@H@("`@("H@9G5N8W1I;VX@*')E9VES=&5R960@
M8GD@=&AE(%!R969S.CH@8V]N<W1R=6-T;W(I+B`@06QL('!R969S('=I=&@@
M=&AE"B`@("`@*B!D:7)T>2!B:70@<V5T('=I;&P@8F4@<V%V960@=&\@=&AE
M('-T;W)A9V4@8F%C:V5N9"!A="!T:&ES('1I;64[('1H=7,L"B`@("`@*B!T
M:&5R92!I<R!N;R!N965D('1O(&UA;G5A;&QY(&-A;&P@)'!R969S+3YS=&]R
M92@I(&5V97)Y('1I;64@80H@("`@("H@<')E9F5R96YC92!I<R!C:&%N9V5D
M+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("HO"B`@("!F=6YC=&EO
M;B!S=&]R92@I"B`@("!["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!4:&ES(&9U;F-T:6]N('!R;W9I9&5S(&-O;6UO;B!C
M;&5A;G5P(&9U;F-T:6]N<R!F;W(@86QL(&]F('1H92!D<FEV97(*("`@("`J
M(&EM<&QE;65N=&%T:6]N<RX*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D86QL("!#;&5A;B!U<"!A;&P@2&]R9&4@<')E9F5R96YC97,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-L96%N=7`H)&%L;"`](&9A;'-E*0H@("`@>PH@
M("`@("`@("\J(%)E;6]V92!T:&ES('-C;W!E(&9R;VT@=&AE('!R969E<F5N
M8V5S(&-A8VAE+"!I9B!I=`H@("`@("`@("`@(&5X:7-T<RX@*B\*("`@("`@
M("!I9B`H:7-S970H)%]315-324].6R=P<F5F<U]C86-H92==6R1T:&ES+3Y?
M<V-O<&5=*2D@>PH@("`@("`@("`@("!U;G-E="@D7U-%4U-)3TY;)W!R969S
M7V-A8VAE)UU;)'1H:7,M/E]S8V]P95TI.PH@("`@("`@('T*"B`@("`@("`@
M+RH@4&5R9F]R;2!A($AO<F1E+7=I9&4@8VQE86YU<#\@*B\*("`@("`@("!I
M9B`H)&%L;"D@>PH@("`@("`@("`@("`O*B!$97-T<F]Y('1H92!C;VYT96YT
M<R!O9B!T:&4@<')E9F5R96YC97,@:&%S:"X@*B\*("`@("`@("`@("`@)'1H
M:7,M/E]P<F5F<R`](&%R<F%Y*"D["@H@("`@("`@("`@("`O*B!$97-T<F]Y
M('1H92!C;VYT96YT<R!O9B!T:&4@<')E9F5R96YC97,@8V%C:&4N("HO"B`@
M("`@("`@("`@(&EF("AI<W-E="@D7U-%4U-)3TY;)W!R969S7V-A8VAE)UTI
M*2!["B`@("`@("`@("`@("`@("!U;G-E="@D7U-%4U-)3TY;)W!R969S7V-A
M8VAE)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@0VQE87)S(&%L;"!P<F5F97)E;F-E<R!F<F]M('1H92!B86-K
M96YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;&5A<B@I"B`@("!["B`@("`@
M("`@)'1H:7,M/F-L96%N=7`H=')U92D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#;VYV97)T<R!A('9A;'5E(&9R;VT@=&AE(&1R:79E<B=S(&-H87)S970@
M=&\@=&AE('-P96-I9FEE9"!C:&%R<V5T+@H@("`@("H*("`@("`J($!P87)A
M;2!M:7AE9"`D=F%L=64@("`@($$@=F%L=64@=&\@8V]N=F5R="X*("`@("`J
M($!P87)A;2!S=')I;F<@)&-H87)S970@(%1H92!C:&%R<V5T('1O(&-O;G9E
M<G0@=&\N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&-O;G9E
M<G1E9"!V86QU92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]N=F5R=$9R;VU$
M<FEV97(H)'9A;'5E+"`D8VAA<G-E="D*("`@('L*("`@("`@("!R971U<FX@
M)'9A;'5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@82!V86QU
M92!F<F]M('1H92!S<&5C:69I960@8VAA<G-E="!T;R!T:&4@9')I=F5R)W,@
M8VAA<G-E="X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)'9A;'5E("!!
M('9A;'5E('1O(&-O;G9E<G0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:&%R
M<V5T("!4:&4@8VAA<G-E="!T;R!C;VYV97)T(&9R;VTN"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5&AE(&-O;G9E<G1E9"!V86QU92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@8V]N=F5R=%1O1')I=F5R*"1V86QU92P@)&-H87)S
M970I"B`@("!["B`@("`@("`@<F5T=7)N("1V86QU93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%!O<'5L871E<R!T:&4@)'!R969S(&AA<V@@=VET:"!N97<@
M96YT<FEE<R!A;F0@97AT97)N86QL>2!D969I;F5D"B`@("`@*B!D969A=6QT
M('9A;'5E<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@(%1H
M92!A<'!L:6-A=&EO;B!T;R!L;V%D(&1E9F%U;'1S(&9O<BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@7W-E=$1E9F%U;'1S*"1A<'`I"B`@("!["B`@("`@("`@
M9VQO8F%L("1R96=I<W1R>3L*("`@("`@("`D9FEL96YA;64@/2`D<F5G:7-T
M<GDM/F=E="@G9FEL97)O;W0G+"`D87!P*2`N("<O8V]N9FEG+W!R969S+G!H
M<"<["@H@("`@("`@("\J($5N<W5R92!T:&%T('1H92!D969A=6QT<R!F<F]M
M('1H:7,@9FEL92!A<F4@;VYL>2!R96%D(&]N8V4N"B`@("`@("`@("`@06QS
M;RP@;6%K92!S=7)E('=E(&-A;B!R96%D('1H:7,@9FEL92X@*B\*("`@("`@
M("!I9B`H(4!I<U]R96%D86)L92@D9FEL96YA;64I*2!["B`@("`@("`@("`@
M(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("\J(%)E860@=&AE(&-O;F9I
M9W5R871I;VX@9FEL92X@5&AE("1?<')E9G,@87)R87DL('=H:6-H('=I;&P@
M8F4*("`@("`@("`@("!I;B!L;V-A;"!S8V]P92P@:7,@87-S=6UE9"!T;R!H
M;VQD('1H92!D969A=6QT('9A;'5E<RX@*B\*("`@("`@("!I;F-L=61E("1F
M:6QE;F%M93L*("`@("`@("!F;W)E86-H("@D7W!R969S(&%S("1P<F5F(#T^
M("1P=F%L<RD@>PH@("`@("`@("`@("!I9B`H:7-S970H)'!V86QS6R=V86QU
M92==*2`F)@H@("`@("`@("`@("`@("`@:7-S970H)'!V86QS6R=L;V-K960G
M72D@)B8*("`@("`@("`@("`@("`@(&ES<V5T*"1P=F%L<ULG<VAA<F5D)UTI
M("8F"B`@("`@("`@("`@("`@("`H)'!V86QS6R=T>7!E)UT@(3T@)VQI;FLG
M*2`F)@H@("`@("`@("`@("`@("`@*"1P=F%L<ULG='EP92==("$]("=S<&5C
M:6%L)RDI('L*("`@("`@("`@("`@("`@("1P<F5F(#T@<W1R7W)E<&QA8V4H
M)RXG+"`G7R<L("1P<F5F*3L*("`@("`@("`@("`@("`@("1M87-K(#T@,#L*
M("`@("`@("`@("`@("`@(&EF("@D<'9A;'-;)VQO8VME9"==*2!["B`@("`@
M("`@("`@("`@("`@("`@)&UA<VL@?#T@7U!2149?3$]#2T5$.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1P=F%L<ULG<VAA<F5D
M)UT@?'P@)&%P<"`]/2`G:&]R9&4G*2!["B`@("`@("`@("`@("`@("`@("`@
M)&UA<VL@?#T@7U!2149?4TA!4D5$.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@)&UA<VL@)CT@?E]04D5&7T1)4E19.PH@("`@("`@("`@
M("`@("`@)&UA<VL@?#T@7U!2149?1$5&055,5#L*"B`@("`@("`@("`@("`@
M("`D=&AI<RT^861D*"1P<F5F+"`D<'9A;'-;)W9A;'5E)UTL("1M87-K*3L*
M("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'!V86QS6R=H;V]K)UTI*2![
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S971(;V]K*"1P<F5F*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@+RH@57!D871E('1H92!P<F5F97)E;F-E<R!C86-H92!W:71H('1H
M92!D969A=6QT<RX@*B\*("`@("`@("`D=&AI<RT^8V%C:&55<&1A=&4H*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%!E<F9O<FUS('-H=71D;W=N(&%C=&EV
M:71I97,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]S:'5T9&]W;B@I"B`@("!["B`@("`@("`@<F5G:7-T
M97)?<VAU=&1O=VY?9G5N8W1I;VXH87)R87DH)B1T:&ES+"`G<W1O<F4G*2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@)'!R968@=&\@=&AE(&QI<W0@
M;V8@<')E9F5R96YC97,@=VET:"!H;V]K(&9U;F-T:6]N<RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P<F5F("!4:&4@<')E9F5R96YC92!W:71H
M(&$@:&]O:RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E=$AO;VLH)'!R968I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]H;V]K<UM=(#T@)'!R968["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!9G1E<B!P<F5F97)E;F-E<R!H879E(&)E96X@
M;&]A9&5D+"!S970@86YY(&QO8VME9"!O<B!E;7!T>0H@("`@("H@<')E9F5R
M96YC97,@=&AA="!H879E(&AO;VMS('1O('1H92!R97-U;'0@;V8@=&AE(&AO
M;VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C86QL2&]O:W,H*0H@("`@>PH@
M("`@("`@(&EF("@A:7-?;G5L;"@D=&AI<RT^7VAO;VMS0V%L;&5D*2D@>PH@
M("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^
M7VAO;VMS0V%L;&5D(#T@=')U93L*"B`@("`@("`@:68@*"%C;W5N="@D=&AI
M<RT^7VAO;VMS*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*
M("`@("`@("!G;&]B86P@)')E9VES=')Y.PH@("`@("`@(&EN8VQU9&5?;VYC
M92`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G+"`G:&]R9&4G*2`N("<O8V]N
M9FEG+VAO;VMS+G!H<"<["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]H;V]K
M<R!A<R`D<')E9BD@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/FES3&]C:V5D
M*"1P<F5F*2!\?`H@("`@("`@("`@("`@("`@(21T:&ES+3YG971686QU92@D
M<')E9BD@?'P*("`@("`@("`@("`@("`@("1T:&ES+3YI<T1E9F%U;'0H)'!R
M968I*2!["B`@("`@("`@("`@("`@("`D9G5N8R`]("=?<')E9G-?:&]O:U\G
M("X@)'!R968["B`@("`@("`@("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S
M*"1F=6YC*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T5F%L
M=64H)'!R968L("1F=6YC*"1T:&ES+3Y?=7-E<BDI.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@4')E9G,@:6YS
M=&%N8V4@8F%S960@;VX@)&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M;6EX960@)&1R:79E<B`@("`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@4')E9G,@
M<W5B8VQA<W,@=&\@<F5T=7)N+@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@($EF("1D<FEV97(@:7,@86X@87)R87DL('1H96X@=V4@=VEL;"!L
M;V]K(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@)&1R:79E
M<ELP72]L:6(O4')E9G,O(&9O<B!T:&4@<W5B8VQA<W,*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D9')I
M=F5R6S%=+G!H<"X*("`@("`J($!P87)A;2!S=')I;F<@)'-C;W!E("`@("!4
M:&4@<V-O<&4@9F]R('1H:7,@<V5T(&]F('!R969E<F5N8V5S+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=7-E<B`@("`@(%1H92!N86UE(&]F('1H92!U<V5R
M('=H;R!O=VYS('1H:7,@<V5T(&]F"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@<')E9F5R96YC97,N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P
M87-S=V]R9"`@5&AE('!A<W-W;W)D(&%S<V]C:6%T960@=VET:"`D=7-E<BX*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@("!!(&AA<V@@8V]N=&%I
M;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@;W(@8V]N;F5C=&EO;B!P87)A;65T97)S
M(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J($!P87)A;2!B;V]L96%N
M("1C86-H:6YG("!3:&]U;&0@8V%C:&EN9R!B92!U<V5D/PH@("`@("H*("`@
M("`J($!R971U<FX@4')E9G,@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E
M(%!R969S(&EN<W1A;F-E+"!O<B!F86QS92!O;@H@("`@("H@("`@("`@("`@
M("`@("`@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D
M<FEV97(L("1S8V]P92`]("=H;W)D92<L("1U<V5R(#T@)R<L("1P87-S=V]R
M9"`]("<G+`H@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<R`](&YU;&PL
M("1C86-H:6YG(#T@=')U92D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH
M)&1R:79E<BDI('L*("`@("`@("`@("`@)&%P<"`]("1D<FEV97);,%T["B`@
M("`@("`@("`@("1D<FEV97(@/2`D9')I=F5R6S%=.PH@("`@("`@('T*"B`@
M("`@("`@+RH@071T96UP="!T;R!R96=I<W1E<B`H8V%C:&4I('1H92`D<')E
M9G,@:&%S:"!I;B!S97-S:6]N('-T;W)A9V4N("HO"B`@("`@("`@:68@*"1C
M86-H:6YG*2!["B`@("`@("`@("`@(&EF("@A:7-S970H)%]315-324].6R=P
M<F5F<U]C86-H92==*2D@>PH@("`@("`@("`@("`@("`@)%]315-324].6R=P
M<F5F<U]C86-H92==(#T@87)R87DH*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@)&1R:79E<B`](&)A<V5N86UE*"1D<FEV97(I.PH@("`@
M("`@(&EF("AE;7!T>2@D9')I=F5R*2!\?"`D9')I=F5R(#T]("=N;VYE)RD@
M>PH@("`@("`@("`@("`D9')I=F5R(#T@)W-E<W-I;VXG.PH@("`@("`@('T*
M"B`@("`@("`@:68@*&ES7VYU;&PH)'!A<F%M<RDI('L*("`@("`@("`@("`@
M)'!A<F%M<R`]($AO<F1E.CIG971$<FEV97)#;VYF:6<H)W!R969S)RP@)&1R
M:79E<BD["B`@("`@("`@?0H*("`@("`@("`O*B!)9B`D<&%R86US6R=U<V5R
M7VAO;VLG72!I<R!D969I;F5D+"!U<V4@:70@=&\@<F5T<FEE=F4@=&AE('9A
M;'5E('1O"B`@("`@("`@("H@=7-E(&9O<B!T:&4@=7-E<FYA;64@*"1T:&ES
M+3Y?=7-E<BDN($]T:&5R=VES92P@:G5S="!U<V4@=&AE('9A;'5E"B`@("`@
M("`@("H@<&%S<V5D(&EN('1H92`D=7-E<B!P87)A;65T97(N("HO"B`@("`@
M("`@:68@*"%E;7!T>2@D<&%R86US6R=U<V5R7VAO;VLG72D@)B8*("`@("`@
M("`@("`@9G5N8W1I;VY?97AI<W1S*"1P87)A;7-;)W5S97)?:&]O:R==*2D@
M>PH@("`@("`@("`@("`D=7-E<B`](&-A;&Q?=7-E<E]F=6YC*"1P87)A;7-;
M)W5S97)?:&]O:R==+"`D=7-E<BD["B`@("`@("`@?0H*("`@("`@("!I9B`H
M(65M<'1Y*"1A<'`I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`D1TQ/
M0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]L
M:6(O4')E9G,O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?2!E;'-E
M:68@*&9I;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I("X@)R]0<F5F<R\G
M("X@)&1R:79E<B`N("<N<&AP)RDI('L*("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]0<F5F<R\G("X@)&1R:79E<B`N
M("<N<&AP)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I;F-L=61E
M7V]N8V4@)TAO<F1E+U!R969S+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@
M("`@('T*"B`@("`@("`@)&-L87-S(#T@)U!R969S7R<@+B`D9')I=F5R.PH@
M("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@
M("`D<')E9G,@/2`F;F5W("1C;&%S<R@D=7-E<BP@)'!A<W-W;W)D+"`D<V-O
M<&4L("1P87)A;7,L("1C86-H:6YG*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D<')E9G,@/2!014%2.CIR86ES945R<F]R*"=#;&%S<R!D969I
M;FET:6]N(&]F("<@+B`D8VQA<W,@+B`G(&YO="!F;W5N9"XG*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D<')E9G,["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E<F5N8V4@=&\@82!C;VYC
M<F5T92!0<F5F<R!I;G-T86YC92!B87-E9"!O;@H@("`@("H@)&1R:79E<BX@
M270@=VEL;"!O;FQY(&-R96%T92!A(&YE=R!I;G-T86YC92!I9B!N;R!0<F5F
M<R!I;G-T86YC90H@("`@("H@=VET:"!T:&4@<V%M92!P87)A;65T97)S(&-U
M<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@
M=7-E9"!I9B!M=6QT:7!L92!P<F5F97)E;F-E('-O=7)C97,@*&%N9"P@=&AU
M<RP*("`@("`J(&UU;'1I<&QE(%!R969S(&EN<W1A;F-E<RD@87)E(')E<75I
M<F5D+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME
M9"!A<SH@)'9A<B`]("90<F5F<SHZ<VEN9VQE=&]N*"D*("`@("`J"B`@("`@
M*B!`<&%R86T@;6EX960@)&1R:79E<B`@("`@5&AE('1Y<&4@;V8@8V]N8W)E
M=&4@4')E9G,@<W5B8VQA<W,@=&\@<F5T=7)N+@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@($EF("1D<FEV97(@:7,@86X@87)R87DL('1H96X@
M=V4@=VEL;"!L;V]K(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&1R:79E<ELP72]L:6(O4')E9G,O(&9O<B!T:&4@<W5B8VQA<W,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("!I;7!L96UE;G1A=&EO;B!N
M86UE9"`D9')I=F5R6S%=+G!H<"X*("`@("`J($!P87)A;2!S=')I;F<@)'-C
M;W!E("`@("!4:&4@<V-O<&4@9F]R('1H:7,@<V5T(&]F('!R969E<F5N8V5S
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@("`@(%1H92!N86UE(&]F
M('1H92!U<V5R('=H;R!O=VYS('1H:7,@<V5T(&]F"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@<')E9F5R96YC97,N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P87-S=V]R9"`@5&AE('!A<W-W;W)D(&%S<V]C:6%T960@=VET
M:"`D=7-E<BX*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@("!!(&AA
M<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@;W(@8V]N;F5C=&EO;B!P
M87)A;65T97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J($!P87)A
M;2!B;V]L96%N("1C86-H:6YG("!3:&]U;&0@8V%C:&EN9R!B92!U<V5D/PH@
M("`@("H*("`@("`J($!R971U<FX@4')E9G,@(%1H92!C;VYC<F5T92!0<F5F
M<R!R969E<F5N8V4L(&]R(&9A;'-E(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(L("1S8V]P92`]("=H;W)D
M92<L("1U<V5R(#T@)R<L("1P87-S=V]R9"`]("<G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`D<&%R86US(#T@;G5L;"P@)&-A8VAI;F<@/2!T<G5E*0H@
M("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N8V5S(#T@87)R87DH*3L*"B`@
M("`@("`@:68@*&ES7VYU;&PH)'!A<F%M<RDI('L*("`@("`@("`@("`@)'!A
M<F%M<R`]($AO<F1E.CIG971$<FEV97)#;VYF:6<H)W!R969S)RP@)&1R:79E
M<BD["B`@("`@("`@?0H*("`@("`@("`D<VEG;F%T=7)E(#T@<V5R:6%L:7IE
M*&%R<F%Y*"1D<FEV97(L("1U<V5R+"`D<&%R86US*2D["B`@("`@("`@:68@
M*"%I<W-E="@D:6YS=&%N8V5S6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@
M("`D:6YS=&%N8V5S6R1S:6=N871U<F5=(#T@)E!R969S.CIF86-T;W)Y*"1D
M<FEV97(L("1S8V]P92P@)'5S97(L("1P87-S=V]R9"P@)'!A<F%M<RP@)&-A
M8VAI;F<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;
M)'-I9VYA='5R95T["B`@("!]"@I]"@``````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]296=I<W1R>2YP:'``````````
M````````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,3$W,C,`,3`U,34T,S,W
M-3(`,#(R,#$R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"@HO*BH@1&\@;F]T('-T87)T(&$@<V5S<VEO;BX@*B\*
M9&5F:6YE*"=(3U)$15]315-324].7TY/3D4G+"`Q*3L*"B\J*B!$;R!N;W0@
M=W)I=&4@8VAA;F=E<R!T;R!S97-S:6]N+B`J+PID969I;F4H)TA/4D1%7U-%
M4U-)3TY?4D5!1$].3%DG+"`R*3L*"B\J*@H@*B!4:&4@4F5G:7-T<GDZ.B!C
M;&%S<R!P<F]V:61E<R!A('-E="!O9B!M971H;V1S(&9O<B!C;VUM=6YI8V%T
M:6]N"B`J(&)E='=E96X@2&]R9&4@87!P;&EC871I;VYS(&%N9"!K965P:6YG
M('1R86-K(&]F(&%P<&QI8V%T:6]N"B`J(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VXN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E
M9VES=')Y+G!H<"QV(#$N,C0S+C(N,C(@,C`P-B\P-2\P-"`R,CHS-3HR-B!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P
M-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,3DY
M.2TR,#`V($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0&AO
M<F1E+F]R9SX*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`
M<F5C;VEL+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E
M($AO<F1E7T9R86UE=V]R:PH@*B\*8VQA<W,@4F5G:7-T<GD@>PH*("`@("\J
M*@H@("`@("H@2&%S:"!S=&]R:6YG(&%L;"!O9B!T:&4@:VYO=VX@<V5R=FEC
M97,@86YD(&-A;&QB86-K<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D7V%P:4-A8VAE(#T@87)R87DH*3L*"B`@("`O*BH*
M("`@("`J($AA<V@@<W1O<FEN9R!A;&P@:VYO=VX@9&%T82!T>7!E<RX*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W1Y<&5#
M86-H92`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!(87-H('-T;W)I;F<@
M86QL(&]F('1H92!R96=I<W1E<F5D(&EN=&5R9F%C97,@=&AA="!A<'!L:6-A
M=&EO;G,*("`@("`J('!R;W9I9&4N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]I;G1E<F9A8V5S(#T@87)R87DH*3L*"B`@
M("`O*BH*("`@("`J($AA<V@@<W1O<FEN9R!I;F9O<FUA=&EO;B!O;B!E86-H
M(')E9VES=')Y+6%W87)E(&%P<&QI8V%T:6]N+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1A<'!L:6-A=&EO;G,@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@4W1A8VL@;V8@:6XM=7-E(&%P<&QI8V%T
M:6]N<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7V%P<%-T86-K(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%%U:6-K
M('!O:6YT97(@=&\@=&AE(&-U<G)E;G0@87!P;&EC871I;VXN"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8W5R<F5N=$%P
M<"`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!#86-H92!O9B`D<')E9G,@;V)J
M96-T<PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1?<')E9G-#86-H92`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#86-H
M92!O9B!A<'!L:6-A=&EO;B!C;VYF:6=U<F%T:6]N<RX*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V-O;F9#86-H92`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!!<F4@=V4@=7-I;F<@<F5G:7-T<GD@
M8V%C:&EN9S\*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;@H@("`@("HO
M"B`@("!V87(@)%]U<V5C86-H92`](&9A;'-E.PH*("`@("\J*@H@("`@("H@
M57!D871E('1H97-E(&-A8VAE(&5N=')I97,@;VX@<VAU=&1O=VXN"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W5P9&%T
M96-A8VAE(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%5P9&%T92!T:&5S
M92!M=&EM92!E;G1R:65S(&]N('-H=71D;W=N+@H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>0H@("`@("HO"B`@("!V87(@)%]U<&1A=&5M=&EM92`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!$;VXG="!U<&1A=&4@8V%C:&4@870@
M96YD(&]F(')E<75E<W0_"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X*
M("`@("`J+PH@("`@=F%R("1?;F]C86-H92`](&9A;'-E.PH*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!A(')E9F5R96YC92!T;R!T:&4@9VQO8F%L(%)E9VES
M=')Y(&]B:F5C="P@;VYL>0H@("`@("H@8W)E871I;F<@:70@:68@:70@9&]E
M<VXG="!A;')E861Y(&5X:7-T+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D
M(&UU<W0@8F4@:6YV;VME9"!A<SH@)')E9VES=')Y(#T@)E)E9VES=')Y.CIS
M:6YG;&5T;VXH*0H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1S97-S
M:6]N7V9L86=S("!!;GD@<V5S<VEO;B!F;&%G<RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(%)E9VES=')Y("!4:&4@2&]R9&4@4F5G:7-T<GD@:6YS=&%N8V4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)'-E<W-I;VY?9FQA
M9W,@/2`P*0H@("`@>PH@("`@("`@('-T871I8R`D<F5G:7-T<GD["@H@("`@
M("`@(&EF("@A:7-S970H)')E9VES=')Y*2D@>PH@("`@("`@("`@("`D<F5G
M:7-T<GD@/2!N97<@4F5G:7-T<GDH)'-E<W-I;VY?9FQA9W,I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1R96=I<W1R>3L*("`@('T*"B`@("`O*BH*
M("`@("`J($-R96%T92!A(&YE=R!R96=I<W1R>2!I;G-T86YC92X@4VAO=6QD
M(&YE=F5R(&)E(&-A;&QE9"!E>&-E<'0*("`@("`J(&)Y("9296=I<W1R>3HZ
M<VEN9VQE=&]N*"DN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'-E
M<W-I;VY?9FQA9W,@($%N>2!S97-S:6]N(&9L86=S+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!296=I<W1R
M>2@D<V5S<VEO;E]F;&%G<R`](#`I"B`@("!["B`@("`@("`@+RH@26UP;W)T
M(&%N9"!G;&]B86P@2&]R9&4G<R!C;VYF:6=U<F%T:6]N('9A;'5E<RX@*B\*
M("`@("`@("`D=&AI<RT^:6UP;W)T0V]N9FEG*"=H;W)D92<I.PH*("`@("`@
M("`O*B!3=&%R="!A('-E<W-I;VXN("HO"B`@("`@("`@:68@*"1S97-S:6]N
M7V9L86=S("8@2$]21$5?4T534TE/3E].3TY%*2!["B`@("`@("`@("`@("\J
M($YE=F5R('-T87)T(&$@<V5S<VEO;B!I9B!T:&4@<V5S<VEO;B!F;&%G<R!I
M;F-L=61E"B`@("`@("`@("`@("`@($A/4D1%7U-%4U-)3TY?3D].12X@*B\*
M("`@("`@("`@("`@)%]315-324].(#T@87)R87DH*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!(;W)D93HZ<V5T=7!397-S:6]N2&%N9&QE<B@I
M.PH@("`@("`@("`@("!`<V5S<VEO;E]S=&%R="@I.PH@("`@("`@("`@("!I
M9B`H)'-E<W-I;VY?9FQA9W,@)B!(3U)$15]315-324].7U)%041/3DQ9*2![
M"B`@("`@("`@("`@("`@("`O*B!#;&]S92!T:&4@<V5S<VEO;B!I;6UE9&EA
M=&5L>2!S;R!N;R!C:&%N9V5S(&-A;B!B90H@("`@("`@("`@("`@("`@("`@
M;6%D92!B=70@=F%L=65S(&%R92!S=&EL;"!A=F%I;&%B;&4N("HO"B`@("`@
M("`@("`@("`@("!`<V5S<VEO;E]W<FET95]C;&]S92@I.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]U<V5C86-H92`]
M('1R=64["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($EN
M:71I86QI>F4@=&AE(&QO8V%L:7IA=&EO;B!R;W5T:6YE<R!A;F0@=F%R:6%B
M;&5S+B`J+PH@("`@("`@($Y,4SHZ<V5T3&%N9R@I.PH@("`@("`@($Y,4SHZ
M<V5T5&5X=&1O;6%I;B@G:&]R9&4G+"!(3U)$15]"05-%("X@)R]L;V-A;&4G
M+"!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@4W1R:6YG.CIS971$969A
M=6QT0VAA<G-E="A.3%,Z.F=E=$-H87)S970H*2D["@H@("`@("`@("1R96=?
M;71I;64@/2!F:6QE;71I;64H2$]21$5?0D%312`N("<O8V]N9FEG+W)E9VES
M=')Y+G!H<"<I.PH*("`@("`@("`O*B!,;V%D(')E9VES=')Y(&EN9F]R;6%T
M:6]N(&9R;VT@=&AE('-E<W-I;VXL(&EF(&%V86EL86)L92X@*B\*("`@("`@
M("!I9B`H(65M<'1Y*"1?4T534TE/3ELG7W)E9VES=')Y8V%C:&4G72D@)B8*
M("`@("`@("`@("`@*"1?4T534TE/3ELG7W)E9VES=')Y;71I;64G75LG<F5G
M:7-T<GDN<&AP)UT@/3T@)')E9U]M=&EM92DI('L*("`@("`@("`@("`@9F]R
M96%C:"`H)%]315-324].6R=?<F5G:7-T<GEC86-H92==(&%S("1K97D@/3X@
M)'9A;"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/B1K97D@/2`D=F%L.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@
M4F5A9"!T:&4@<F5G:7-T<GD@8V]N9FEG=7)A=&EO;B!F:6QE+B`J+PH@("`@
M("`@("`@("!R97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O8V]N9FEG+W)E
M9VES=')Y+G!H<"<["@H@("`@("`@("`@("`O*B!3=&]P('-Y<W1E;2!I9B!(
M;W)D92!I<R!I;F%C=&EV92X@*B\*("`@("`@("`@("`@:68@*"1T:&ES+3YA
M<'!L:6-A=&EO;G-;)VAO<F1E)UU;)W-T871U<R==(#T]("=I;F%C=&EV92<I
M('L*("`@("`@("`@("`@("`@($AO<F1E.CIF871A;"A?*")4:&ES('-Y<W1E
M;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(BDL(%]?1DE,15]?+"!?7TQ)
M3D5?7RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J(%-C86X@9F]R
M(&%L;"!!4$ES('!R;W9I9&5D(&)Y(&5A8V@@87!P+"!A;F0@<V5T(&]T:&5R
M"B`@("`@("`@("`@("`J(&-O;6UO;B!D969A=6QT<R!L:6ME('1E;7!L871E
M<R!A;F0@9W)A<&AI8W,N("HO"B`@("`@("`@("`@("1A<'!,:7-T(#T@87)R
M87E?:V5Y<R@D=&AI<RT^87!P;&EC871I;VYS*3L*("`@("`@("`@("`@9F]R
M96%C:"`H)&%P<$QI<W0@87,@)&%P<$YA;64I('L*("`@("`@("`@("`@("`@
M("1A<'`@/2`F)'1H:7,M/F%P<&QI8V%T:6]N<ULD87!P3F%M95T["B`@("`@
M("`@("`@("`@("!I9B`H*"1A<'!;)W-T871U<R==(#T]("=H96%D:6YG)RD@
M?'P*("`@("`@("`@("`@("`@("`@("`H)&%P<%LG<W1A='5S)UT@/3T@)VEN
M86-T:79E)RD@?'P*("`@("`@("`@("`@("`@("`@("`H)&%P<%LG<W1A='5S
M)UT@/3T@)V%D;6EN)R`F)B`A075T:#HZ:7-!9&UI;B@I*2D@>PH@("`@("`@
M("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1A<'!;)W!R;W9I9&5S)UTI*2!["B`@
M("`@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1A<'!;)W!R;W9I9&5S
M)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1A<'!;
M)W!R;W9I9&5S)UT@87,@)&EN=&5R9F%C92D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]I;G1E<F9A8V5S6R1I;G1E<F9A8V5=(#T@
M)&%P<$YA;64["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7VEN=&5R9F%C97-;)&%P<%LG<')O=FED97,G75T@/2`D87!P3F%M
M93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1A<'!;)W1E;7!L871E<R==*2`F
M)B!I<W-E="@D87!P6R=F:6QE<F]O="==*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1A<'!;)W1E;7!L871E<R==(#T@)&%P<%LG9FEL97)O;W0G72`N("<O
M=&5M<&QA=&5S)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&EF("@A:7-S970H)&%P<%LG:G-U<FDG72D@)B8@:7-S970H)&%P<%LG=V5B
M<F]O="==*2D@>PH@("`@("`@("`@("`@("`@("`@("1A<'!;)VIS=7)I)UT@
M/2`D87!P6R=W96)R;V]T)UT@+B`G+VIS)SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&%P<%LG:G-F<R==*2`F)B!I
M<W-E="@D87!P6R=F:6QE<F]O="==*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1A<'!;)VIS9G,G72`]("1A<'!;)V9I;&5R;V]T)UT@+B`G+VIS)SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&%P
M<%LG=&AE;65S=7)I)UTI("8F(&ES<V5T*"1A<'!;)W=E8G)O;W0G72DI('L*
M("`@("`@("`@("`@("`@("`@("`D87!P6R=T:&5M97-U<FDG72`]("1A<'!;
M)W=E8G)O;W0G72`N("<O=&AE;65S)SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&EF("@A:7-S970H)&%P<%LG=&AE;65S9G,G72D@)B8@
M:7-S970H)&%P<%LG9FEL97)O;W0G72DI('L*("`@("`@("`@("`@("`@("`@
M("`D87!P6R=T:&5M97-F<R==(#T@)&%P<%LG9FEL97)O;W0G72`N("<O=&AE
M;65S)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@+RH@0VQE87(@;W5T('1H92!!4$D@)B!4>7!E(&-A8VAE<RP@:68@
M=&AE>2!E>&ES=',N("HO"B`@("`@("`@("`@("1T:&ES+3Y?87!I0V%C:&4@
M/2`D=&AI<RT^7W1Y<&5#86-H92`](&%R<F%Y*"D["@H@("`@("`@("`@("`D
M=&AI<RT^7V-A8VAE5F%R<RAA<G)A>2@G87!P;&EC871I;VYS)RP@)U]I;G1E
M<F9A8V5S)RP@)U]A<&E#86-H92<L("=?='EP94-A8VAE)RDL(&%R<F%Y*"=R
M96=I<W1R>2YP:'`G(#T^("1R96=?;71I;64I*3L*("`@("`@("!]"@H@("`@
M("`@("\J($-R96%T92!T:&4@9VQO8F%L(%!E<FUS(&]B:F5C="X@*B\*("`@
M("`@("`D1TQ/0D%,4ULG<&5R;7,G72`]("9097)M<SHZ<VEN9VQE=&]N*"D[
M"@H@("`@("`@("\J($%T=&%C:"!J879A<V-R:7!T(&YO=&EF:6-A=&EO;B!L
M:7-T96YE<BX@*B\*("`@("`@("`D;F]T:69I8V%T:6]N(#T@)DYO=&EF:6-A
M=&EO;CHZ<VEN9VQE=&]N*"D["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^871T
M86-H*"=J879A<V-R:7!T)RD["@H@("`@("`@("\J(%)E9VES=&5R(&%C8V5S
M<R!K97D@;&]G9V5R(&9O<B!T<F%N<VQA=&]R<RX@*B\*("`@("`@("!I9B`H
M0"1'3$]"04Q36R=C;VYF)UU;)VQO9U]A8V-E<W-K97ES)UTI('L*("`@("`@
M("`@("`@<F5G:7-T97)?<VAU=&1O=VY?9G5N8W1I;VXH8W)E871E7V9U;F-T
M:6]N*"<G+"`G2&]R9&4Z.F=E=$%C8V5S<TME>2AN=6QL+"!N=6QL+"!T<G5E
M*3LG*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@061D(&$@
M;&ES="!O9B!V87)I86)L92!N86UE<R!A;F0@;6]D:69I8V%T:6]N('1I;65S
M('1O(&)E(&-A8VAE9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'9A<G,@("`@02!L:7-T(&]F
M('9A<FEA8FQE(&YA;65S('1O(&)E(&-A8VAE9"X*("`@("`J($!P87)A;2!A
M<G)A>2`D;71I;65S("!!(&QI<W0@;V8@9FEL92!M;V1I9FEC86EO;B!T:6UE
M<R!T;R!B92!C86-H960N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C86-H959A
M<G,H)'9A<G,@/2!A<G)A>2@I+"`D;71I;65S(#T@87)R87DH*2D*("`@('L*
M("`@("`@("!S=&%T:6,@)')E9V-A8VAE<VAU=&1O=VX@/2!F86QS93L*"B`@
M("`@("`@:68@*"1T:&ES+3Y?=7-E8V%C:&4I('L*("`@("`@("`@("`@)'1H
M:7,M/E]U<&1A=&5C86-H92`](&%R<F%Y7VUE<F=E*"1T:&ES+3Y?=7!D871E
M8V%C:&4L("1V87)S*3L*("`@("`@("`@("`@)'1H:7,M/E]U<&1A=&5M=&EM
M92`](&%R<F%Y7VUE<F=E*"1T:&ES+3Y?=7!D871E;71I;64L("1M=&EM97,I
M.PH@("`@("`@("`@("!I9B`H(21R96=C86-H97-H=71D;W=N*2!["B`@("`@
M("`@("`@("`@("!R96=I<W1E<E]S:'5T9&]W;E]F=6YC=&EO;BAA<G)A>2@F
M)'1H:7,L("=?<VAU=&1O=VYC86-H92<I*3L*("`@("`@("`@("`@("`@("1R
M96=C86-H97-H=71D;W=N(#T@=')U93L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%-T;W)E<R!C86-H96%B;&4@;65M
M8F5R('9A<FEA8FQE<R!I;B!T:&4@<V5S<VEO;B!A="!S:'5T9&]W;BX*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W-H=71D;W=N8V%C:&4H*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D
M7U-%4U-)3TXI("8F($%U=&@Z.F=E=$%U=&@H*2`F)B`A)'1H:7,M/E]N;V-A
M8VAE*2!["B`@("`@("`@("`@(&EF("@A:7-S970H)%]315-324].6R=?<F5G
M:7-T<GEC86-H92==*2D@>PH@("`@("`@("`@("`@("`@)%]315-324].6R=?
M<F5G:7-T<GEC86-H92==(#T@87)R87DH*3L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@9F]R96%C:"`H87)R87E?=6YI<75E*"1T:&ES+3Y?=7!D871E
M8V%C:&4I(&%S("1V86PI('L*("`@("`@("`@("`@("`@("1?4T534TE/3ELG
M7W)E9VES=')Y8V%C:&4G75LD=F%L72`]("1T:&ES+3XD=F%L.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!I9B`H(6ES<V5T*"1?4T534TE/3ELG7W)E
M9VES=')Y;71I;64G72DI('L*("`@("`@("`@("`@("`@("1?4T534TE/3ELG
M7W)E9VES=')Y;71I;64G72`](&%R<F%Y*"D["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@(&9O<F5A8V@@*&%R<F%Y7W5N:7%U92@D=&AI<RT^7W5P9&%T
M96UT:6UE*2!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@("1?
M4T534TE/3ELG7W)E9VES=')Y;71I;64G75LD:V5Y72`]("1V86P["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&5A
M<B!T:&4@<F5G:7-T<GD@8V%C:&4N"B`@("`@*@H@("`@("H@0'-I;F-E($AO
M<F1E(#,N,0H@("`@("HO"B`@("!F=6YC=&EO;B!C;&5A<D-A8VAE*"D*("`@
M('L*("`@("`@("!U;G-E="@D7U-%4U-)3TY;)U]R96=I<W1R>6-A8VAE)UTI
M.PH@("`@("`@("1T:&ES+3Y?;F]C86-H92`]('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!&:6QL<R!T:&4@<F5G:7-T<GDG<R!!4$D@8V%C:&4@=VET
M:"!T:&4@879A:6QA8FQE('-E<G9I8V5S+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?9FEL;$%024-A8VAE
M*"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?87!I0V%C:&4I
M*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("1S
M=&%T=7,@/2!A<G)A>2@G86-T:79E)RP@)VYO=&]O;&)A<B<L("=H:61D96XG
M*3L*("`@("`@("!I9B`H075T:#HZ:7-!9&UI;B@I*2!["B`@("`@("`@("`@
M("1S=&%T=7-;72`]("=A9&UI;B<["B`@("`@("`@?0H@("`@("`@("1A<'!S
M(#T@)'1H:7,M/FQI<W1!<'!S*"1S=&%T=7,I.PH@("`@("`@(&9O<F5A8V@@
M*"1A<'!S(&%S("1A<'`I('L*("`@("`@("`@("`@)%]S97)V:6-E<R`]("1?
M='EP97,@/2!N=6QL.PH@("`@("`@("`@("`D87!I(#T@)'1H:7,M/F=E="@G
M9FEL97)O;W0G+"`D87!P*2`N("<O;&EB+V%P:2YP:'`G.PH@("`@("`@("`@
M("!I9B`H:7-?<F5A9&%B;&4H)&%P:2DI('L*("`@("`@("`@("`@("`@(&EN
M8VQU9&5?;VYC92`D87!I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("@A:7-S970H)%]S97)V:6-E<RDI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?87!I0V%C:&5;)&%P<%T@/2!A<G)A>2@I.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A<&E#86-H95LD87!P72`]
M("1?<V5R=FEC97,["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES
M<V5T*"1?='EP97,I*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D7W1Y
M<&5S(&%S("1T>7!E(#T^("1P87)A;7,I('L*("`@("`@("`@("`@("`@("`@
M("`O*B!0<F5F:7@@;F]N+4AO<F1E('1Y<&5S('=I=&@@=&AE(&%P<&QI8V%T
M:6]N"B`@("`@("`@("`@("`@("`@("`@("H@;F%M92X@*B\*("`@("`@("`@
M("`@("`@("`@("`D<')E9FEX(#T@)&%P<"`]/2`G:&]R9&4G(#\@)R<@.B`B
M)'MA<'!]7R(["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T>7!E0V%C
M:&5;)'!R969I>"`N("1T>7!E72`]("1P87)A;7,["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?
M8V%C:&5687)S*&%R<F%Y*"=?87!I0V%C:&4G+"`G7W1Y<&5#86-H92<I*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!A(&QI<W0@;V8@=&AE(&EN
M<W1A;&QE9"!A;F0@<F5G:7-T97)E9"!A<'!L:6-A=&EO;G,N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("`@)&9I;'1E<B`@("`@($%N(&%R<F%Y(&]F
M('1H92!S=&%T=7-E<R!T:&%T('-H;W5L9"!B90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(')E='5R;F5D+B!$969A=6QT<R!T;R!N;VXM
M:&ED9&5N+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%S<V]C("`@("`@($%S
M<V]C:6%T:79E(&%R<F%Y('=I=&@@87!P(&YA;65S(&%S(&ME>7,N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D<&5R;6ES<VEO;B`@5&AE('!E<FUI<W-I;VX@
M;&5V96P@=&\@8VAE8VL@9F]R(&EN('1H90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&QI<W0N($1E9F%U;'1S('1O(%!%4DU37U-(3U<N
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@3&ES="!O9B!A<'!S(')E
M9VES=&5R960@=VET:"!(;W)D92X@268@;F\*("`@("`J("`@("`@("`@("`@
M("`@(&%P<&QI8V%T:6]N<R!A<F4@9&5F:6YE9"!R971U<FYS(&%N(&5M<'1Y
M(&%R<F%Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T07!P<R@D9FEL=&5R
M(#T@;G5L;"P@)&%S<V]C(#T@9F%L<V4L("1P97)M:7-S:6]N(#T@4$5235-?
M4TA/5RD*("`@('L*("`@("`@("`D87!P<R`](&%R<F%Y*"D["B`@("`@("`@
M:68@*&ES7VYU;&PH)&9I;'1E<BDI('L*("`@("`@("`@("`@)&9I;'1E<B`]
M(&%R<F%Y*"=N;W1O;VQB87(G+"`G86-T:79E)RD["B`@("`@("`@?0H*("`@
M("`@("!F;W)E86-H("@D=&AI<RT^87!P;&EC871I;VYS(&%S("1A<'`@/3X@
M)'!A<F%M<RD@>PH@("`@("`@("`@("!I9B`H:6Y?87)R87DH)'!A<F%M<ULG
M<W1A='5S)UTL("1F:6QT97(I("8F"B`@("`@("`@("`@("`@("`H9&5F:6YE
M9"@G05542%](04Y$3$52)RD@?'P@)'1H:7,M/FAA<U!E<FUI<W-I;VXH)&%P
M<"P@)'!E<FUI<W-I;VXI*2D@>PH@("`@("`@("`@("`@("`@)&%S<V]C(#\@
M)&%P<'-;)&%P<%T@/2`D87!P(#H@)&%P<'-;72`]("1A<'`["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D87!P<SL*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@86QL(&%V86EL86)L92!R96=I<W1R
M>2!!4$ES+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!!4$D@
M;&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$%027,H*0H@("`@>PH@
M("`@("`@('-T871I8R`D87!I<R`](&%R<F%Y*"D["B`@("`@("`@:68@*"1A
M<&ES*2!["B`@("`@("`@("`@(')E='5R;B`D87!I<SL*("`@("`@("!]"@H@
M("`@("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H)'1H:7,M/E]I;G1E<F9A8V5S
M*2!A<R`D:6YT97)F86-E*2!["B`@("`@("`@("`@($!L:7-T*"1A<&DL("D@
M/2!E>'!L;V1E*"<O)RP@)&EN=&5R9F%C92D["B`@("`@("`@("`@("1A<&ES
M6UT@/2`D87!I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R<F%Y7W5N
M:7%U92@D87!I<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%L
M;"!O9B!T:&4@879A:6QA8FQE(')E9VES=')Y(&UE=&AO9',L(&]R(&%L=&5R
M;F%T96QY"B`@("`@*B!O;FQY('1H;W-E(&9O<B!A('-P96-I9FEE9"!!4$DN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!I("!$969I;F5S('1H
M92!!4$D@9F]R('=H:6-H('1H92!M971H;V1S('-H86QL(&)E"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@(')E='5R;F5D+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@(%1H92!M971H;V0@;&ES="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@;&ES=$UE=&AO9',H)&%P:2`](&YU;&PI"B`@("!["B`@("`@("`@
M)&UE=&AO9',@/2!A<G)A>2@I.PH*("`@("`@("`D=&AI<RT^7V9I;&Q!4$E#
M86-H92@I.PH*("`@("`@("!F;W)E86-H("AA<G)A>5]K97ES*"1T:&ES+3YA
M<'!L:6-A=&EO;G,I(&%S("1A<'`I('L*("`@("`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3YA<'!L:6-A=&EO;G-;)&%P<%U;)W!R;W9I9&5S)UTI*2!["B`@
M("`@("`@("`@("`@("`D<')O=FED97,@/2`D=&AI<RT^87!P;&EC871I;VYS
M6R1A<'!=6R=P<F]V:61E<R==.PH@("`@("`@("`@("`@("`@:68@*"%I<U]A
M<G)A>2@D<')O=FED97,I*2!["B`@("`@("`@("`@("`@("`@("`@)'!R;W9I
M9&5S(#T@87)R87DH)'!R;W9I9&5S*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1P<F]V:61E<R`]
M(&%R<F%Y*"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&9O<F5A8V@@
M*"1P<F]V:61E<R!A<R`D;65T:&]D*2!["B`@("`@("`@("`@("`@("!I9B`H
M<W1R<&]S*"1M971H;V0L("<O)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@
M("`@("`@("`@:68@*&ES7VYU;&PH)&%P:2D@?'P*("`@("`@("`@("`@("`@
M("`@("`@("`@*'-U8G-T<B@D;65T:&]D+"`P+"!S=')L96XH)&%P:2DI(#T]
M("1A<&DI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1M971H;V1S6UT@
M/2`D;65T:&]D.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T@96QS96EF("AI<U]N=6QL*"1A<&DI('Q\("@D;65T:&]D(#T]("1A
M<&DI*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M87!I0V%C:&5;)&%P<%TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*&%R<F%Y7VME>7,H)'1H:7,M/E]A<&E#86-H95LD87!P72D@87,@
M)'-E<G9I8V4I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M971H
M;V1S6UT@/2`D;65T:&]D("X@)R\G("X@)'-E<G9I8V4["B`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!A<G)A>5]U;FEQ=64H)&UE=&AO9',I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!A;&P@;V8@=&AE(&%V86EL86)L92!R96=I<W1R>2!D
M871A('1Y<&5S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!D
M871A('1Y<&4@;&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=%1Y<&5S
M*"D*("`@('L*("`@("`@("`D=&AI<RT^7V9I;&Q!4$E#86-H92@I.PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7W1Y<&5#86-H93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@82!M971H;V0G<R!S:6=N871U<F4N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;65T:&]D("!4:&4@9G5L;"!N86UE(&]F
M('1H92!M971H;V0@=&\@8VAE8VL@9F]R+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@($$@='=O(&1I;65N<VEO;F%L(&%R<F%Y+B!4:&4@9FER<W0@
M96QE;65N="!C;VYT86EN<R!A;@H@("`@("H@("`@("`@("`@("`@("`@87)R
M87D@=VET:"!T:&4@<&%R86UE=&5R(&YA;65S+"!T:&4@<V5C;VYD(&]N92!T
M:&4@<F5T=7)N"B`@("`@*B`@("`@("`@("`@("`@("!T>7!E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G9713:6=N871U<F4H)&UE=&AO9"D*("`@('L*("`@
M("`@("!I9B`H(2@D87!P(#T@)'1H:7,M/FAA<TUE=&AO9"@D;65T:&]D*2DI
M('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/E]F:6QL05!)0V%C:&4H*3L*"B`@("`@("`@0&QI<W0H+"`D9G5N8W1I
M;VXI(#T@97AP;&]D92@G+R<L("1M971H;V0I.PH@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7V%P:4-A8VAE6R1A<'!=6R1F=6YC=&EO;EU;)W1Y<&4G72D@
M)B8*("`@("`@("`@("`@:7-S970H)'1H:7,M/E]A<&E#86-H95LD87!P75LD
M9G5N8W1I;VY=6R=A<F=S)UTI*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A
M>2@D=&AI<RT^7V%P:4-A8VAE6R1A<'!=6R1F=6YC=&EO;EU;)V%R9W,G72P@
M)'1H:7,M/E]A<&E#86-H95LD87!P75LD9G5N8W1I;VY=6R=T>7!E)UTI.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN92!I9B!A
M;B!I;G1E<F9A8V4@:7,@:6UP;&5M96YT960@8GD@86X@86-T:79E(&%P<&QI
M8V%T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&EN=&5R9F%C
M92`@5&AE(&EN=&5R9F%C92!T;R!C:&5C:R!F;W(N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@5&AE(&%P<&QI8V%T:6]N(&EM<&QE;65N=&EN9R`D
M:6YT97)F86-E(&EF('=E(&AA=F4@:70L"B`@("`@*B`@("`@("`@("`@("`@
M("!F86QS92!I9B!T:&4@:6YT97)F86-E(&ES(&YO="!I;7!L96UE;G1E9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@:&%S26YT97)F86-E*"1I;G1E<F9A8V4I
M"B`@("!["B`@("`@("`@<F5T=7)N("%E;7!T>2@D=&AI<RT^7VEN=&5R9F%C
M97-;)&EN=&5R9F%C95TI(#\*("`@("`@("`@("`@)'1H:7,M/E]I;G1E<F9A
M8V5S6R1I;G1E<F9A8V5=(#H*("`@("`@("`@("`@9F%L<V4["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!$971E<FUI;F4@:68@82!M971H;V0@:&%S(&)E96X@
M<F5G:7-T97)E9"!W:71H('1H92!R96=I<W1R>2X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1M971H;V0@(%1H92!F=6QL(&YA;64@;V8@=&AE(&UE
M=&AO9"!T;R!C:&5C:R!F;W(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@
M("`@($]N;'D@8VAE8VL@=&AI<R!A<'!L:6-A=&EO;BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!4:&4@87!P;&EC871I;VX@:6UP;&5M96YT:6YG
M("1M971H;V0@:68@=V4@:&%V92!I="P*("`@("`J("`@("`@("`@("`@("`@
M(&9A;'-E(&EF('1H92!M971H;V0@9&]E<VXG="!E>&ES="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@:&%S365T:&]D*"1M971H;V0L("1A<'`@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1A<'`I*2!["B`@("`@("`@("`@
M($!L:7-T*"1I;G1E<F9A8V4L("1C86QL*2`](&5X<&QO9&4H)R\G+"`D;65T
M:&]D*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7VEN=&5R9F%C
M97-;)&UE=&AO9%TI*2!["B`@("`@("`@("`@("`@("`D87!P(#T@)'1H:7,M
M/E]I;G1E<F9A8V5S6R1M971H;V1=.PH@("`@("`@("`@("!](&5L<V5I9B`H
M(65M<'1Y*"1T:&ES+3Y?:6YT97)F86-E<ULD:6YT97)F86-E72DI('L*("`@
M("`@("`@("`@("`@("1A<'`@/2`D=&AI<RT^7VEN=&5R9F%C97-;)&EN=&5R
M9F%C95T["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D8V%L;"`]("1M971H;V0["B`@("`@("`@?0H*("`@("`@
M("`D=&AI<RT^7V9I;&Q!4$E#86-H92@I.PH*("`@("`@("!R971U<FX@(65M
M<'1Y*"1T:&ES+3Y?87!I0V%C:&5;)&%P<%U;)&-A;&Q=*2`_("1A<'`@.B!F
M86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@:&]O:R!C
M;W)R97-P;VYD:6YG('1O('1H92!D969A=6QT('!A8VMA9V4@=&AA=`H@("`@
M("H@<')O=FED97,@=&AE(&9U;F-T:6]N86QI='D@<F5Q=65S=&5D(&)Y('1H
M92`D;65T:&]D"B`@("`@*B!P87)A;65T97(N("1M971H;V0@:7,@82!S=')I
M;F<@8V]N<VES=&EN9R!O9@H@("`@("H@(G!A8VMA9V5T>7!E+VUE=&AO9&YA
M;64B+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UE=&AO9"`@5&AE
M(&UE=&AO9"!T;R!C86QL+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A<F=S("`@
M("!!<F=U;65N=',@=&\@=&AE(&UE=&AO9"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N("!43T1/"B`@("`@*B`@("`@("`@("!2971U<FYS(%!%05)?17)R;W(@
M;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-A;&PH)&UE=&AO9"P@
M)&%R9W,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@($!L:7-T*"1I;G1E<F9A
M8V4L("1C86QL*2`](&5X<&QO9&4H)R\G+"`D;65T:&]D*3L*"B`@("`@("`@
M:68@*"%E;7!T>2@D=&AI<RT^7VEN=&5R9F%C97-;)&UE=&AO9%TI*2!["B`@
M("`@("`@("`@("1A<'`@/2`D=&AI<RT^7VEN=&5R9F%C97-;)&UE=&AO9%T[
M"B`@("`@("`@?2!E;'-E:68@*"%E;7!T>2@D=&AI<RT^7VEN=&5R9F%C97-;
M)&EN=&5R9F%C95TI*2!["B`@("`@("`@("`@("1A<'`@/2`D=&AI<RT^7VEN
M=&5R9F%C97-;)&EN=&5R9F%C95T["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U1H92!M971H;V0@(B<@
M+B`D;65T:&]D("X@)R(@:7,@;F]T(&1E9FEN960@:6X@=&AE($AO<F1E(%)E
M9VES=')Y+B<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3YC
M86QL0GE086-K86=E*"1A<'`L("1C86QL+"`D87)G<RD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!/=71P=70@=&AE(&AO;VL@8V]R<F5S<&]N9&EN9R!T;R!T
M:&4@<W!E8VEF:6,@<&%C:V%G92!N86UE9"X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1A<'`@("!4:&4@87!P;&EC871I;VX@8F5I;F<@8V%L;&5D
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V%L;"`@5&AE(&UE=&AO9"!T;R!C
M86QL+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A<F=S("`@07)G=6UE;G1S('1O
M('1H92!M971H;V0N"B`@("`@*@H@("`@("H@0')E='5R;B`@5$]$3PH@("`@
M("H@("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!C86QL0GE086-K86=E*"1A<'`L("1C86QL+"`D
M87)G<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@+RH@3F]T93H@8V%L;&EN
M9R!H87--971H;V0H*2!M86ME<R!S=7)E('1H870@=V4G=F4@8V%C:&5D"B`@
M("`@("`@("H@)&%P<"=S('-E<G9I8V5S(&%N9"!I;F-L=61E9"!T:&4@05!)
M(&9I;&4L('-O('=E(&1O;B=T('1R>0H@("`@("`@("`J('1O(&1O(&ET(&%G
M86EN(&5X<&QI8VET;'D@:6X@=&AI<R!M971H;V0N("HO"B`@("`@("`@:68@
M*"$D=&AI<RT^:&%S365T:&]D*"1C86QL+"`D87!P*2D@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*"=4:&4@;65T:&]D
M("(E<R(@:7,@;F]T(&1E9FEN960@:6X@=&AE($%022!F;W(@)7,N)RP@)&-A
M;&PL("1A<'`I*3L*("`@("`@("!]"@H@("`@("`@("\J($QO860@=&AE($%0
M22!N;W<N("HO"B`@("`@("`@:68@*"%E;7!T>2@D7U-%4U-)3TY;)U]R96=I
M<W1R>6-A8VAE)UU;)U]A<&E#86-H92==*2D@>PH@("`@("`@("`@("`D87!I
M(#T@)'1H:7,M/F=E="@G9FEL97)O;W0G+"`D87!P*2`N("<O;&EB+V%P:2YP
M:'`G.PH@("`@("`@("`@("!I9B`H:7-?<F5A9&%B;&4H)&%P:2DI('L*("`@
M("`@("`@("`@("`@(&EN8VQU9&5?;VYC92`D87!I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O*B!-86ME('-U<F4@=&AA="!T:&4@9G5N
M8W1I;VX@86-T=6%L;'D@97AI<W1S+B`J+PH@("`@("`@("1F=6YC=&EO;B`]
M("=?)R`N("1A<'`@+B`G7R<@+B`D8V%L;#L*("`@("`@("!I9B`H(69U;F-T
M:6]N7V5X:7-T<R@D9G5N8W1I;VXI*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=4:&4@9G5N8W1I;VX@:6UP;&5M96YT:6YG("<@
M+B`D8V%L;"`N("<@*"<@+B`D9G5N8W1I;VX@+B`G*2!I<R!N;W0@9&5F:6YE
M9"!I;B`G("X@)&%P<"`N("=<)W,@05!)+B<I.PH@("`@("`@('T*"B`@("`@
M("`@)&-H96-K4&5R;7,@/2!I<W-E="@D=&AI<RT^7V%P:4-A8VAE6R1A<'!=
M6R1C86QL75LG8VAE8VMP97)M<R==*2`_"B`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V%P:4-A8VAE6R1A<'!=6R1C86QL75LG8VAE8VMP97)M<R==
M(#H@=')U93L*"B`@("`@("`@+RH@4W=I=&-H(&%P<&QI8V%T:6]N(&-O;G1E
M>'1S(&YO=RP@:68@;F5C97-S87)Y+"!B969O<F4*("`@("`@("`@*B!I;F-L
M=61I;F<@86YY(&9I;&5S('=H:6-H(&UI9VAT(&1O(&ET(&9O<B!U<RX@4F5T
M=7)N(&%N"B`@("`@("`@("H@97)R;W(@:6UM961I871E;'D@:68@<'5S:$%P
M<"@I(&9A:6QS+B`J+PH@("`@("`@("1P=7-H960@/2`D=&AI<RT^<'5S:$%P
M<"@D87!P+"`D8VAE8VM097)M<RD["B`@("`@("`@:68@*&ES7V$H)'!U<VAE
M9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'!U<VAE
M9#L*("`@("`@("!]"@H@("`@("`@("1R97,@/2!C86QL7W5S97)?9G5N8U]A
M<G)A>2@D9G5N8W1I;VXL("1A<F=S*3L*"B`@("`@("`@+RH@268@=V4@8VAA
M;F=E9"!A<'!L:6-A=&EO;B!C;VYT97AT(&EN('1H92!C;W5R<V4@;V8@=&AI
M<PH@("`@("`@("`J(&-A;&PL('5N9&\@=&AA="!C:&%N9V4@;F]W+B`J+PH@
M("`@("`@(&EF("@D<'5S:&5D(#T]/2!T<G5E*2!["B`@("`@("`@("`@("1T
M:&ES+3YP;W!!<'`H*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!H;V]K(&-O<G)E
M<W!O;F1I;F<@=&\@=&AE(&1E9F%U;'0@<&%C:V%G92!T:&%T"B`@("`@*B!P
M<F]V:61E<R!T:&4@9G5N8W1I;VYA;&ET>2!R97%U97-T960@8GD@=&AE("1M
M971H;V0*("`@("`J('!A<F%M971E<BX@)&UE=&AO9"!I<R!A('-T<FEN9R!C
M;VYS:7-T:6YG(&]F"B`@("`@*B`B<&%C:V%G971Y<&4O;65T:&]D;F%M92(N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65T:&]D("!4:&4@;65T
M:&]D('1O(&QI;FL@=&\N"B`@("`@*B!`<&%R86T@87)R87D@)&%R9W,@("`@
M($%R9W5M96YT<R!T;R!T:&4@;65T:&]D+@H@("`@("H@0'!A<F%M(&UI>&5D
M("1E>'1R82`@("!%>'1R82P@;F]N+7-T86YD87)D(&%R9W5M96YT<R!T;R!T
M:&4@;65T:&]D+@H@("`@("H*("`@("`J($!R971U<FX@(%1/1$\*("`@("`J
M("`@("`@("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@;&EN:R@D;65T:&]D+"`D87)G<R`](&%R<F%Y*"DL
M("1E>'1R82`]("<G*0H@("`@>PH@("`@("`@($!L:7-T*"1I;G1E<F9A8V4L
M("1C86QL*2`](&5X<&QO9&4H)R\G+"`D;65T:&]D*3L*"B`@("`@("`@:68@
M*"%E;7!T>2@D=&AI<RT^7VEN=&5R9F%C97-;)&UE=&AO9%TI*2!["B`@("`@
M("`@("`@("1A<'`@/2`D=&AI<RT^7VEN=&5R9F%C97-;)&UE=&AO9%T["B`@
M("`@("`@?2!E;'-E:68@*"%E;7!T>2@D=&AI<RT^7VEN=&5R9F%C97-;)&EN
M=&5R9F%C95TI*2!["B`@("`@("`@("`@("1A<'`@/2`D=&AI<RT^7VEN=&5R
M9F%C97-;)&EN=&5R9F%C95T["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U1H92!M971H;V0@(B<@+B`D
M;65T:&]D("X@)R(@:7,@;F]T(&1E9FEN960@:6X@=&AE($AO<F1E(%)E9VES
M=')Y+B<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3YL:6YK
M0GE086-K86=E*"1A<'`L("1C86QL+"`D87)G<RP@)&5X=')A*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($]U='!U="!T:&4@:&]O:R!C;W)R97-P;VYD:6YG
M('1O('1H92!S<&5C:69I8R!P86-K86=E(&YA;65D+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&%P<"`@(%1H92!A<'!L:6-A=&EO;B!B96EN9R!C
M86QL960N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C86QL("!4:&4@;65T:&]D
M('1O(&QI;FL@=&\N"B`@("`@*B!`<&%R86T@87)R87D@)&%R9W,@("!!<F=U
M;65N=',@=&\@=&AE(&UE=&AO9"X*("`@("`J($!P87)A;2!M:7AE9"`D97AT
M<F$@($5X=')A+"!N;VXM<W1A;F1A<F0@87)G=6UE;G1S('1O('1H92!M971H
M;V0N"B`@("`@*@H@("`@("H@0')E='5R;B`@5$]$3PH@("`@("H@("`@("`@
M("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!L:6YK0GE086-K86=E*"1A<'`L("1C86QL+"`D87)G<R`](&%R
M<F%Y*"DL("1E>'1R82`]("<G*0H@("`@>PH@("`@("`@("\J($YO=&4Z(&-A
M;&QI;F<@:&%S365T:&]D(&UA:V5S('-U<F4@=&AA="!W92=V92!C86-H960@
M)&%P<"=S"B`@("`@("`@("H@<V5R=FEC97,@86YD(&EN8VQU9&5D('1H92!!
M4$D@9FEL92P@<V\@=V4@9&]N)W0@=')Y('1O(&1O"B`@("`@("`@("H@:70@
M:70@86=A:6X@97AP;&EC:71L>2!I;B!T:&ES(&UE=&AO9"X@*B\*("`@("`@
M("!I9B`H(21T:&ES+3YH87--971H;V0H)&-A;&PL("1A<'`I*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=4:&4@;65T:&]D("(G
M("X@)&-A;&P@+B`G(B!I<R!N;W0@9&5F:6YE9"!I;B`G("X@)&%P<"`N("=<
M)W,@05!)+B<I.PH@("`@("`@('T*"B`@("`@("`@+RH@36%K92!S=7)E('1H
M92!L:6YK(&ES(&1E9FEN960N("HO"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES
M+3Y?87!I0V%C:&5;)&%P<%U;)&-A;&Q=6R=L:6YK)UTI*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=4:&4@;&EN:R`G("X@)&-A
M;&P@+B`G(&ES(&YO="!D969I;F5D(&EN("<@+B`D87!P("X@)UPG<R!!4$DN
M)RD["B`@("`@("`@?0H*("`@("`@("`O*B!);FET:6%L(&QI;FL@=F%L=64N
M("HO"B`@("`@("`@)&QI;FL@/2`D=&AI<RT^7V%P:4-A8VAE6R1A<'!=6R1C
M86QL75LG;&EN:R==.PH*("`@("`@("`O*B!&:6QL(&EN(&AT;6PM96YC;V1E
M9"!A<F=U;65N=',N("HO"B`@("`@("`@9F]R96%C:"`H)&%R9W,@87,@)&ME
M>2`]/B`D=F%L*2!["B`@("`@("`@("`@("1L:6YK(#T@<W1R7W)E<&QA8V4H
M)R4G("X@)&ME>2`N("<E)RP@:'1M;&5N=&ET:65S*"1V86PI+"`D;&EN:RD[
M"B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^87!P;&EC871I
M;VYS6R1A<'!=6R=W96)R;V]T)UTI*2!["B`@("`@("`@("`@("1L:6YK(#T@
M<W1R7W)E<&QA8V4H)R5A<'!L:6-A=&EO;B4G+"`D=&AI<RT^9V5T*"=W96)R
M;V]T)RP@)&%P<"DL("1L:6YK*3L*("`@("`@("!]"@H@("`@("`@("\J(%)E
M<&QA8V4@:'1M;&5N8V]D960@87)G=6UE;G1S('1H870@:&%V96XG="!B965N
M('-P96-I9FEE9"!W:71H"B`@("`@("`@("`@86X@96UP='D@<W1R:6YG("AT
M:&ES(&ES('=H97)E('1H92!D969A=6QT('=O=6QD(&)E('-U8G-T:71U=&5D
M"B`@("`@("`@("`@:6X@82!S=')I8W1E<B!R96=I<W1R>2!I;7!L96UE;G1A
M=&EO;BDN("HO"B`@("`@("`@)&QI;FL@/2!P<F5G7W)E<&QA8V4H)WPE+BLE
M?%4G+"`G)RP@)&QI;FLI.PH*("`@("`@("`O*B!&:6QL(&EN('5R;&5N8V]D
M960@87)G=6UE;G1S+B`J+PH@("`@("`@(&9O<F5A8V@@*"1A<F=S(&%S("1K
M97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`D;&EN:R`]('-T<E]R97!L86-E
M*"=\)R`N(%-T<FEN9SHZ;&]W97(H)&ME>2D@+B`G?"<L('5R;&5N8V]D92@D
M=F%L*2P@)&QI;FLI.PH@("`@("`@('T*"B`@("`@("`@+RH@07!P96YD(&%N
M>2!E>'1R82P@;F]N+7-T86YD87)D(&%R9W5M96YT<RX@*B\*("`@("`@("!I
M9B`H:7-?87)R87DH)&5X=')A*2D@>PH@("`@("`@("`@("`D97AT<F%?87)G
M<R`]("<G.PH@("`@("`@("`@("!F;W)E86-H("@D97AT<F$@87,@)&ME>2`]
M/B`D=F%L*2!["B`@("`@("`@("`@("`@("`D97AT<F%?87)G<R`N+2`G)B<@
M+B!U<FQE;F-O9&4H)&ME>2D@+B`G/2<@+B!U<FQE;F-O9&4H)'9A;"D["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D97AT
M<F%?87)G<R`]("1E>'1R83L*("`@("`@("!]"B`@("`@("`@)&QI;FL@/2!S
M=')?<F5P;&%C92@G?&5X=')A?"<L("1E>'1R85]A<F=S+"`D;&EN:RD["@H@
M("`@("`@("\J(%)E<&QA8V4@:'1M;"UE;F-O9&5D(&%R9W5M96YT<R!T:&%T
M(&AA=F5N)W0@8F5E;B!S<&5C:69I960@=VET:`H@("`@("`@("`@(&%N(&5M
M<'1Y('-T<FEN9R`H=&AI<R!I<R!W:&5R92!T:&4@9&5F875L="!W;W5L9"!B
M92!S=6)S=&ET=71E9`H@("`@("`@("`@(&EN(&$@<W1R:6-T97(@<F5G:7-T
M<GD@:6UP;&5M96YT871I;VXI+B`J+PH@("`@("`@("1L:6YK(#T@<')E9U]R
M97!L86-E*"=\7'PN*UQ\?%4G+"`G)RP@)&QI;FLI.PH*("`@("`@("!R971U
M<FX@)&QI;FL["B`@("!]"@H@("`@+RHJ"B`@("`@*B!297!L86-E(&%N>2`E
M87!P;&EC871I;VXE('-T<FEN9W,@=VET:"!T:&4@9FEL97-Y<W1E;2!P871H
M('1O('1H90H@("`@("H@87!P;&EC871I;VXN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<&%T:"`@5&AE(&%P<&QI8V%T:6]N('-T<FEN9RX*("`@
M("`J($!P87)A;2!S=')I;F<@)&%P<"`@(%1H92!A<'!L:6-A=&EO;B!B96EN
M9R!C86QL960N"B`@("`@*@H@("`@("H@0')E='5R;B`@5$]$3PH@("`@("H@
M("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!A<'!L:6-A=&EO;D9I;&50871H*"1P871H+"`D87!P
M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D87!P*2D@>PH@
M("`@("`@("`@("`D87!P(#T@)'1H:7,M/E]C=7)R96YT07!P.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^87!P;&EC871I;VYS6R1A
M<'!=*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS
M<')I;G1F*%\H(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R
M9&4@4F5G:7-T<GDN(BDL("1A<'`I*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!S=')?<F5P;&%C92@G)6%P<&QI8V%T:6]N)2<L("1T:&ES+3YA<'!L
M:6-A=&EO;G-;)&%P<%U;)V9I;&5R;V]T)UTL("1P871H*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E<&QA8V4@86YY("5A<'!L:6-A=&EO;B4@<W1R:6YG
M<R!W:71H('1H92!W96(@<&%T:"!T;R!T:&4@87!P;&EC871I;VXN"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE(&%P<&QI8V%T:6]N
M('-T<FEN9RX*("`@("`J($!P87)A;2!S=')I;F<@)&%P<"`@(%1H92!A<'!L
M:6-A=&EO;B!B96EN9R!C86QL960N"B`@("`@*@H@("`@("H@0')E='5R;B`@
M5$]$3PH@("`@("H@("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!A<'!L:6-A=&EO;E=E8E!A=&@H
M)'!A=&@L("1A<'`@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H
M)&%P<"DI('L*("`@("`@("`@("`@)&%P<"`]("1T:&ES+3Y?8W5R<F5N=$%P
M<#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!S=')?<F5P;&%C92@G)6%P
M<&QI8V%T:6]N)2<L("1T:&ES+3YA<'!L:6-A=&EO;G-;)&%P<%U;)W=E8G)O
M;W0G72P@)'!A=&@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!C
M=7)R96YT(&%P<&QI8V%T:6]N+"!A9&1I;F<@:70@=&\@=&AE('1O<"!O9B!T
M:&4@2&]R9&4*("`@("`J(&%P<&QI8V%T:6]N('-T86-K+B!)9B!T:&ES(&ES
M('1H92!F:7)S="!A<'!L:6-A=&EO;B!T;R!B90H@("`@("H@<'5S:&5D+"!R
M971R:65V92!S97-S:6]N(&EN9F]R;6%T:6]N(&%S('=E;&PN"B`@("`@*@H@
M("`@("H@<'5S:$%P<"@I(&%L<V\@<F5A9',@=&AE(&%P<&QI8V%T:6]N)W,@
M8V]N9FEG=7)A=&EO;B!F:6QE(&%N9`H@("`@("H@<V5T<R!U<"!I=',@9VQO
M8F%L("1C;VYF(&AA<V@N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@
M)&%P<"`@("`@("`@(%1H92!N86UE(&]F('1H92!A<'!L:6-A=&EO;B!T;R!P
M=7-H+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&-H96-K4&5R;7,@($UA:V4@
M<W5R92!T:&%T('1H92!C=7)R96YT('5S97(@:&%S"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<&5R;6ES<VEO;G,@=&\@=&AE(&%P<&QI
M8V%T:6]N(&)E:6YG(&QO861E9`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@($1E9F%U;'1S('1O('1R=64N(%-H;W5L9"!/3DQ9(&)E(&1I
M<V%B;&5D(&)Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<WES=&5M('-C<FEP=',@*&-R;VX@:F]B<RP@971C+BD@86YD('-C<FEP=',*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&%T(&AA;F1L
M92!L;V=I;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H
M97(@;W(@;F]T('1H92!?87!P4W1A8VL@=V%S(&UO9&EF:65D+@H@("`@("H@
M("`@("`@("`@("`@("`@("!2971U<FX@4$5!4E]%<G)O<B!O;B!E<G)O<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@<'5S:$%P<"@D87!P+"`D8VAE8VM097)M
M<R`]('1R=64I"B`@("!["B`@("`@("`@:68@*"1A<'`@/3T@)'1H:7,M/E]C
M=7)R96YT07!P*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@("\J($)A:6P@;W5T(&EF(&%P<&QI8V%T:6]N(&ES(&YO
M="!P<F5S96YT(&]R(&EN86-T:79E+B`J+PH@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/F%P<&QI8V%T:6]N<ULD87!P72D@?'P*("`@("`@("`@("`@)'1H
M:7,M/F%P<&QI8V%T:6]N<ULD87!P75LG<W1A='5S)UT@/3T@)VEN86-T:79E
M)R!\?`H@("`@("`@("`@("`H)'1H:7,M/F%P<&QI8V%T:6]N<ULD87!P75LG
M<W1A='5S)UT@/3T@)V%D;6EN)R`F)B`A075T:#HZ:7-!9&UI;B@I*2D@>PH@
M("`@("`@("`@("!(;W)D93HZ9F%T86PH)&%P<"`N("<@:7,@;F]T(&%C=&EV
M871E9"<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@
M("`O*B!)9B!P97)M:7-S:6]N<R!C:&5C:VEN9R!I<R!R97%U97-T960L(')E
M='5R;B!A;B!E<G)O<B!I9@H@("`@("`@("`J('1H92!C=7)R96YT('5S97(@
M9&]E<R!N;W0@:&%V92!R96%D('!E<FUS('1O('1H90H@("`@("`@("`J(&%P
M<&QI8V%T:6]N(&)E:6YG(&QO861E9"X@5V4@86QL;W<@86-C97-S.@H@("`@
M("`@("`J"B`@("`@("`@("H@("T@5&\@86QL(&%D;6EN<RX*("`@("`@("`@
M*B`@+2!4;R!A;&P@875T:&5N=&EC871E9"!U<V5R<R!I9B!N;R!P97)M:7-S
M:6]N(&ES('-E="!O;B`D87!P+@H@("`@("`@("`J("`M(%1O(&%N>6]N92!W
M:&\@:7,@86QL;W=E9"!B>2!A;B!E>'!L:6-I="!!0TP@;VX@)&%P<"X@*B\*
M("`@("`@("!I9B`H)&-H96-K4&5R;7,@)B8@(21T:&ES+3YH87-097)M:7-S
M:6]N*"1A<'`I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P
M<FEN=&8H)U5S97(@)7,@9&]E<R!N;W0@:&%V92!214%$('!E<FUI<W-I;VX@
M9F]R("5S)RP@075T:#HZ9V5T075T:"@I+"`D87!P*2P@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B57-E<B`E<R!I<R!N;W0@875T
M:&]R:7-E9"!F;W(@)7,N(BDL($%U=&@Z.F=E=$%U=&@H*2P@)'1H:7,M/F%P
M<&QI8V%T:6]N<ULD87!P75LG;F%M92==*2P@)W!E<FUI<W-I;VY?9&5N:65D
M)RD["B`@("`@("`@?0H*("`@("`@("`O*B!);7!O<G0@=&AI<R!A<'!L:6-A
M=&EO;B=S(&-O;F9I9W5R871I;VX@=F%L=65S+B`J+PH@("`@("`@("1S=6-C
M97-S(#T@)'1H:7,M/FEM<&]R=$-O;F9I9R@D87!P*3L*("`@("`@("!I9B`H
M:7-?82@D<W5C8V5S<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'-U8V-E<W,["B`@("`@("`@?0H*("`@("`@("`O*B!,;V%D('!R
M969E<F5N8V5S(&%F=&5R('1H92!C;VYF:6=U<F%T:6]N(&AA<R!B965N(&QO
M861E9"!T;PH@("`@("`@("`J(&UA:V4@<W5R92!T:&4@<')E9G,@9FEL92!H
M87,@86QL('1H92!I;F9O<FUA=&EO;B!I="!N965D<RX@*B\*("`@("`@("`D
M=&AI<RT^;&]A9%!R969S*"1A<'`I.PH*("`@("`@("`O*B!297-E="!T:&4@
M;&%N9W5A9V4@:6X@8V%S92!T:&5R92!I<R!A(&1I9F9E<F5N="!O;F4*("`@
M("`@("`@*B!S96QE8W1E9"!I;B!T:&4@<')E9F5R96YC97,N("HO"B`@("`@
M("`@)&QA;F=U86=E(#T@)R<["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M<')E9G-#86-H95LD87!P72D@)B8*("`@("`@("`@("`@:7-S970H)'1H:7,M
M/E]P<F5F<T-A8VAE6R1A<'!=+3Y?<')E9G-;)VQA;F=U86=E)UTI*2!["B`@
M("`@("`@("`@("1L86YG=6%G92`]("1T:&ES+3Y?<')E9G-#86-H95LD87!P
M72T^9V5T5F%L=64H)VQA;F=U86=E)RD["B`@("`@("`@?0H@("`@("`@($Y,
M4SHZ<V5T3&%N9R@D;&%N9W5A9V4I.PH@("`@("`@($Y,4SHZ<V5T5&5X=&1O
M;6%I;B@D87!P+"`D=&AI<RT^87!P;&EC871I;VYS6R1A<'!=6R=F:6QE<F]O
M="==("X@)R]L;V-A;&4G+"!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@
M4W1R:6YG.CIS971$969A=6QT0VAA<G-E="A.3%,Z.F=E=$-H87)S970H*2D[
M"@H@("`@("`@("\J($]N8V4@=V4@:VYO=R!E=F5R>71H:6YG('-U8V-E961E
M9"!A;F0@:7,@:6X@82!C;VYS:7-T96YT"B`@("`@("`@("H@<W1A=&4@86=A
M:6XL('!U<V@@=&AE(&YE=R!A<'!L:6-A=&EO;B!O;G1O('1H92!S=&%C:RX@
M*B\*("`@("`@("`D=&AI<RT^7V%P<%-T86-K6UT@/2`D87!P.PH@("`@("`@
M("1T:&ES+3Y?8W5R<F5N=$%P<"`]("1A<'`["@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E('1H92!C=7)R96YT
M(&%P<"!F<F]M('1H92!A<'!L:6-A=&EO;B!S=&%C:RP@<V5T=&EN9R!T:&4@
M8W5R<F5N=`H@("`@("H@87!P('1O('=H:6-H979E<B!A<'`@=V%S(&-U<G)E
M;G0@8F5F;W)E('1H:7,@;VYE('1O;VL@;W9E<BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&YA;64@;V8@=&AE(&%P<&QI8V%T:6]N('1H
M870@=V%S('!O<'!E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<&]P07!P*"D*
M("`@('L*("`@("`@("`O*B!0;W`@=&AE(&-U<G)E;G0@87!P;&EC871I;VX@
M;V9F(&]F('1H92!S=&%C:RX@*B\*("`@("`@("`D<')E=FEO=7,@/2!A<G)A
M>5]P;W`H)'1H:7,M/E]A<'!3=&%C:RD["@H@("`@("`@("\J($EM<&]R="!T
M:&4@;F5W(&%C=&EV92!A<'!L:6-A=&EO;B=S(&-O;F9I9W5R871I;VX@=F%L
M=65S"B`@("`@("`@("H@86YD('-E="!T:&4@9V5T=&5X="!D;VUA:6X@86YD
M('1H92!P<F5F97)R960@;&%N9W5A9V4N("HO"B`@("`@("`@)'1H:7,M/E]C
M=7)R96YT07!P(#T@8V]U;G0H)'1H:7,M/E]A<'!3=&%C:RD@/R!E;F0H)'1H
M:7,M/E]A<'!3=&%C:RD@.B!N=6QL.PH@("`@("`@(&EF("@D=&AI<RT^7V-U
M<G)E;G1!<'`I('L*("`@("`@("`@("`@)'1H:7,M/FEM<&]R=$-O;F9I9R@D
M=&AI<RT^7V-U<G)E;G1!<'`I.PH@("`@("`@("`@("`D=&AI<RT^;&]A9%!R
M969S*"1T:&ES+3Y?8W5R<F5N=$%P<"D["B`@("`@("`@("`@("1L86YG=6%G
M92`]("1'3$]"04Q36R=P<F5F<R==+3YG971686QU92@G;&%N9W5A9V4G*3L*
M("`@("`@("`@("`@:68@*&ES<V5T*"1L86YG=6%G92DI('L*("`@("`@("`@
M("`@("`@($Y,4SHZ<V5T3&%N9R@D;&%N9W5A9V4I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@($Y,4SHZ<V5T5&5X=&1O;6%I;B@D=&AI<RT^7V-U<G)E
M;G1!<'`L("1T:&ES+3YA<'!L:6-A=&EO;G-;)'1H:7,M/E]C=7)R96YT07!P
M75LG9FEL97)O;W0G72`N("<O;&]C86QE)RP@3DQ3.CIG971#:&%R<V5T*"DI
M.PH@("`@("`@("`@("!3=')I;F<Z.G-E=$1E9F%U;'1#:&%R<V5T*$Y,4SHZ
M9V5T0VAA<G-E="@I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<')E
M=FEO=7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&-U<G)E
M;G0@87!P;&EC871I;VX@+2!T:&4@87!P(&%T('1H92!T;W`@;V8@=&AE(&%P
M<&QI8V%T:6]N"B`@("`@*B!S=&%C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE(&-U<G)E;G0@87!P;&EC871I;VXN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$%P<"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?8W5R<F5N=$%P<#L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K('!E
M<FUI<W-I;VYS(&]N(&%N(&%P<&QI8V%T:6]N+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@86-C97-S(&ES(&%L;&]W
M960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA<U!E<FUI<W-I;VXH)&%P<"P@
M)'!E<FUI<W-I;VX@/2!015)-4U]214%$*0H@("`@>PH@("`@("`@(')E='5R
M;B!!=71H.CII<T%D;6EN*"D@?'P*("`@("`@("`@("`@*"1'3$]"04Q36R=P
M97)M<R==+3YE>&ES=',H)&%P<"D*("`@("`@("`@("`@(#\@)$=,3T)!3%-;
M)W!E<FUS)UTM/FAA<U!E<FUI<W-I;VXH)&%P<"P@075T:#HZ9V5T075T:"@I
M+"`D<&5R;6ES<VEO;BD*("`@("`@("`@("`@(#H@*&)O;VPI075T:#HZ9V5T
M075T:"@I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E861S('1H92!C;VYF
M:6=U<F%T:6]N('9A;'5E<R!F;W(@=&AE(&=I=F5N(&%P<&QI8V%T:6]N(&%N
M9"!I;7!O<G1S"B`@("`@*B!T:&5M(&EN=&\@=&AE(&=L;V)A;"`D8V]N9B!V
M87)I86)L92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@(%1H
M92!N86UE(&]F('1H92!A<'!L:6-A=&EO;BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@4$5!4E]%<G)O<B!O;B!E
M<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@:6UP;W)T0V]N9FEG*"1A<'`I
M"B`@("!["B`@("`@("`@+RH@1&]N)W0@;6%K92!C;VYF:6<@9FEL97,@9VQO
M8F%L("1R96=I<W1R>2!T:&5M<V5L=F5S+B`J+PH@("`@("`@(&=L;V)A;"`D
M<F5G:7-T<GD["@H@("`@("`@("\J($-A8VAE(&-O;F9I9R!V86QU97,@<V\@
M=&AA="!W92!D;VXG="!R92UR96%D(&9I;&5S(&]N(&5V97)Y"B`@("`@("`@
M("H@<&]P07!P*"D@8V%L;"X@*B\*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?8V]N9D-A8VAE6R1A<'!=*2D@>PH@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?8V]N9D-A8VAE6R=H;W)D92==*2D@>PH@("`@("`@("`@("`@
M("`@)&-O;F8@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@;V)?<W1A<G0H
M*3L*("`@("`@("`@("`@("`@("1S=6-C97-S(#T@:6YC;'5D92!(3U)$15]"
M05-%("X@)R]C;VYF:6<O8V]N9BYP:'`G.PH@("`@("`@("`@("`@("`@)&5R
M<F]R<R`](&]B7V=E=%]C;VYT96YT<R@I.PH@("`@("`@("`@("`@("`@;V)?
M96YD7V-L96%N*"D["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1E<G)O
M<G,I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)T9A:6QE9"!T;R!I;7!O<G0@2&]R9&4@8V]N9FEG=7)A=&EO;CH@
M)R`N('-T<FEP7W1A9W,H)&5R<F]R<RDI.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@:68@*"$D<W5C8V5S<RD@>PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=&86EL960@=&\@:6UP
M;W)T($AO<F1E(&-O;F9I9W5R871I;VXN)RD["B`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@+RH@26YI=&EA;"!(;W)D92UW:61E('-E='1I
M;F=S+B`J+PH*("`@("`@("`@("`@("`@("\J(%-E="!T:&4@97)R;W(@<F5P
M;W)T:6YG(&QE=F5L(&EN(&%C8V]R9&%N8V4@=VET:`H@("`@("`@("`@("`@
M("`@("H@=&AE(&-O;F9I9R!S971T:6YG<RX@*B\*("`@("`@("`@("`@("`@
M(&5R<F]R7W)E<&]R=&EN9R@D8V]N9ELG9&5B=6=?;&5V96PG72D["@H@("`@
M("`@("`@("`@("`@+RH@4V5T('1H92!M87AI;75M(&5X96-U=&EO;B!T:6UE
M(&EN(&%C8V]R9&%N8V4@=VET:`H@("`@("`@("`@("`@("`@("H@=&AE(&-O
M;F9I9R!S971T:6YG<RX@*B\*("`@("`@("`@("`@("`@($!S971?=&EM95]L
M:6UI="@D8V]N9ELG;6%X7V5X96-?=&EM92==*3L*"B`@("`@("`@("`@("`@
M("`O*B!3970@=&AE('5M87-K(&%C8V]R9&EN9R!T;R!C;VYF:6<@<V5T=&EN
M9W,N("HO"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&-O;F9;)W5M87-K
M)UTI*2!["B`@("`@("`@("`@("`@("`@("`@=6UA<VLH)&-O;F9;)W5M87-K
M)UTI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)&-O;F8@/2`D=&AI<RT^7V-O;F9#86-H95LG:&]R
M9&4G73L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1A<'`@(3T]
M("=H;W)D92<I('L*("`@("`@("`@("`@("`@(&]B7W-T87)T*"D["B`@("`@
M("`@("`@("`@("`D<W5C8V5S<R`](&EN8VQU9&4@)'1H:7,M/F%P<&QI8V%T
M:6]N<ULD87!P75LG9FEL97)O;W0G72`N("<O8V]N9FEG+V-O;F8N<&AP)SL*
M("`@("`@("`@("`@("`@("1E<G)O<G,@/2!O8E]G971?8V]N=&5N=',H*3L*
M("`@("`@("`@("`@("`@(&]B7V5N9%]C;&5A;B@I.PH@("`@("`@("`@("`@
M("`@:68@*"%E;7!T>2@D97)R;W)S*2D@>PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*"=&86EL960@=&\@:6UP;W)T(&%P
M<&QI8V%T:6]N(&-O;F9I9W5R871I;VX@9F]R("<@+B`D87!P("X@)SH@)R`N
M('-T<FEP7W1A9W,H)&5R<F]R<RDI.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@:68@*"$D<W5C8V5S<RD@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=&86EL960@=&\@:6UP;W)T
M(&%P<&QI8V%T:6]N(&-O;F9I9W5R871I;VX@9F]R("<@+B`D87!P*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H
M:7,M/E]C86-H959A<G,H87)R87DH)U]C;VYF0V%C:&4G*2D["@H@("`@("`@
M("`@("`D=&AI<RT^7V-O;F9#86-H95LD87!P72`]("8D8V]N9CL*("`@("`@
M("!]"@H@("`@("`@("1'3$]"04Q36R=C;VYF)UT@/2`F)'1H:7,M/E]C;VYF
M0V%C:&5;)&%P<%T["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!,;V%D<R!T:&4@<')E9F5R96YC97,@9F]R('1H92!C=7)R
M96YT('5S97(@9F]R('1H92!C=7)R96YT(&%P<&QI8V%T:6]N"B`@("`@*B!A
M;F0@:6UP;W)T<R!T:&5M(&EN=&\@=&AE(&=L;V)A;"`D<')E9G,@=F%R:6%B
M;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P("!4:&4@;F%M
M92!O9B!T:&4@87!P;&EC871I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO
M8610<F5F<R@D87!P(#T@;G5L;"D*("`@('L*("`@("`@("!S=&%T:6,@)'!R
M969S7V1E9F%U;'0@/2!F86QS93L*"B`@("`@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92]0<F5F<RYP:'`G.PH*("`@("`@("!I9B`H)&%P<"`]/3T@;G5L;"D@
M>PH@("`@("`@("`@("`D87!P(#T@)'1H:7,M/E]C=7)R96YT07!P.PH@("`@
M("`@('T*"B`@("`@("`@+RH@268@=&AE<F4@:7,@;F\@;&]G9V5D(&EN('5S
M97(L(')E='5R;B!A;B!E;7!T>2!0<F5F<SHZ"B`@("`@("`@("H@;V)J96-T
M('=I=&@@:G5S="!D969A=6QT('!R969E<F5N8V5S+B`J+PH@("`@("`@(&EF
M("@A075T:#HZ9V5T075T:"@I*2!["B`@("`@("`@("`@("1P<F5F<R`]("90
M<F5F<SHZ9F%C=&]R>2@G<V5S<VEO;B<L("1A<'`L("<G+"`G)RP@;G5L;"P@
M9F%L<V4I.PH@("`@("`@("`@("`D<')E9G,M/G)E=')I979E*"D["B`@("`@
M("`@("`@("1T:&ES+3Y?<')E9G-#86-H95LD87!P72`]("8D<')E9G,["B`@
M("`@("`@("`@("1'3$]"04Q36R=P<F5F<R==(#T@)B1T:&ES+3Y?<')E9G-#
M86-H95LD87!P73L*("`@("`@("`@("`@)'!R969S7V1E9F%U;'0@/2!T<G5E
M.PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`O*B!#
M86-H92!P<F5F<R!O8FIE8W1S('-O('1H870@=V4@9&]N)W0@<F4M;&]A9"!T
M:&5M(&]N(&5V97)Y"B`@("`@("`@("H@<&]P07!P*"D@8V%L;"X@*B\*("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<')E9G-#86-H95LD87!P72D@?'P*
M("`@("`@("`@("`@(65M<'1Y*"1P<F5F<U]D969A=6QT*2D@>PH@("`@("`@
M("`@("`D<')E9G,@/2`F4')E9G,Z.F9A8W1O<GDH)$=,3T)!3%-;)V-O;F8G
M75LG<')E9G,G75LG9')I=F5R)UTL("1A<'`L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!!=71H.CIG971!=71H*"DL($%U=&@Z.F=E
M=$-R961E;G1I86PH)W!A<W-W;W)D)RDI.PH@("`@("`@("`@("`D<')E9G,M
M/G)E=')I979E*"D["B`@("`@("`@("`@("1T:&ES+3Y?<')E9G-#86-H95LD
M87!P72`]("8D<')E9G,["B`@("`@("`@?0H*("`@("`@("`D1TQ/0D%,4ULG
M<')E9G,G72`]("8D=&AI<RT^7W!R969S0V%C:&5;)&%P<%T["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!5;FQO860@<')E9F5R96YC97,@9G)O;2!A;B!A<'!L
M:6-A=&EO;B!O<B`H:68@;F\@87!P;&EC871I;VX@:7,*("`@("`J('-P96-I
M9FEE9"D@9G)O;2!!3$P@87!P;&EC871I;VYS+B!5<V5F=6P@=VAE;B!A('5S
M97(@:&%S(&QO9V=E9`H@("`@("H@;W5T(&)U="!Y;W4@;F5E9"!T;R!C;VYT
M:6YU92!O;B!T:&4@<V%M92!P86=E+"!E=&,N"B`@("`@*@H@("`@("H@069T
M97(@=6YL;V%D:6YG+"!I9B!T:&5R92!I<R!A;B!A<'!L:6-A=&EO;B!O;B!T
M:&4@87!P('-T86-K('1O"B`@("`@*B!L;V%D('!R969E<F5N8V5S(&9R;VTL
M('1H96X@=V4@<F5L;V%D(&$@9G)E<V@@<V5T+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&%P<"`@5&AE(&%P<&QI8V%T:6]N('1O('5N;&]A9"!P
M<F5F<F5N8V5S(&9O<BX@268@;G5L;"P*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@04Q,('!R969E<F5N8V5S(&%R92!R97-E="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@=6YL;V%D4')E9G,H)&%P<"`](&YU;&PI"B`@("!["B`@("`@
M("`@:68@*"1A<'`@/3T](&YU;&PI('L*("`@("`@("`@("`@)'1H:7,M/E]P
M<F5F<T-A8VAE(#T@87)R87DH*3L*("`@("`@("!](&5L<V5I9B`H:7-S970H
M)'1H:7,M/E]P<F5F<T-A8VAE6R1A<'!=*2D@>PH@("`@("`@("`@("!U;G-E
M="@D=&AI<RT^7W!R969S0V%C:&5;)&%P<%TI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@(&EF("@D
M=&AI<RT^7V-U<G)E;G1!<'`I('L*("`@("`@("`@("`@)'1H:7,M/FQO8610
M<F5F<R@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!T:&4@<F5Q=65S=&5D(&-O;F9I9W5R871I;VX@<&%R86UE=&5R(&9O<B!T
M:&4@<W!E8VEF:65D"B`@("`@*B!A<'!L:6-A=&EO;BX@268@;F\@87!P;&EC
M871I;VX@:7,@<W!E8VEF:65D+"!T:&4@=F%L=64@;V8*("`@("`J("1T:&ES
M+3Y?8W5R<F5N=$%P<"`H=&AE(&-U<G)E;G0@87!P;&EC871I;VXI(&ES('5S
M960N($AO=V5V97(L"B`@("`@*B!I9B!T:&4@<&%R86UE=&5R(&ES(&YO="!P
M<F5S96YT(&9O<B!T:&%T(&%P<&QI8V%T:6]N+"!T:&4*("`@("`J($AO<F1E
M+7=I9&4@=F%L=64@:7,@=7-E9"!I;G-T96%D+B!)9B!T:&%T(&ES(&YO="!P
M<F5S96YT+"!W90H@("`@("H@<F5T=7)N(&YU;&PN"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<&%R86UE=&5R("!4:&4@8V]N9FEG=7)A=&EO;B!V
M86QU92!T;R!R971R:65V92X*("`@("`J($!P87)A;2!S=')I;F<@)&%P<"`@
M("`@("`@5&AE(&%P<&QI8V%T:6]N('1O(&=E="!T:&4@=F%L=64@9F]R+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5Q=65S=&5D('!A
M<F%M971E<BP@;W(@;G5L;"!I9B!I="!I<R!N;W0@<V5T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G970H)'!A<F%M971E<BP@)&%P<"`](&YU;&PI"B`@("![
M"B`@("`@("`@:68@*&ES7VYU;&PH)&%P<"DI('L*("`@("`@("`@("`@)&%P
M<"`]("1T:&ES+3Y?8W5R<F5N=$%P<#L*("`@("`@("!]"@H@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^87!P;&EC871I;VYS6R1A<'!=6R1P87)A;65T97)=
M*2D@>PH@("`@("`@("`@("`D<'9A;"`]("1T:&ES+3YA<'!L:6-A=&EO;G-;
M)&%P<%U;)'!A<F%M971E<ET["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@:68@*"1P87)A;65T97(@/3T@)VEC;VXG*2!["B`@("`@("`@("`@("`@
M("`D<'9A;"`]("1T:&ES+3Y?9V5T26-O;B@D87!P*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1P=F%L(#T@:7-S970H)'1H:7,M
M/F%P<&QI8V%T:6]N<ULG:&]R9&4G75LD<&%R86UE=&5R72D@/R`D=&AI<RT^
M87!P;&EC871I;VYS6R=H;W)D92==6R1P87)A;65T97)=(#H@;G5L;#L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1P87)A;65T97(@
M/3T@)VYA;64G*2!["B`@("`@("`@("`@(')E='5R;B!?*"1P=F%L*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'!V86P["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1G5N8W1I;VX@=&\@=V]R:R!O
M=70@86X@87!P;&EC871I;VXG<R!G<F%P:&EC<R!54DDL('1A:VEN9R!I;G1O
M(&%C8V]U;G0*("`@("`J(&%N>2!T:&5M97,@9&ER96-T;W)I97,@=&AA="!M
M87D@8F4@<V5T('5P+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%P
M<"`@5&AE(&%P<&QI8V%T:6]N(&9O<B!W:&EC:"!T;R!G970@=&AE(&EM86=E
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&1I<F5C=&]R>2X@268@8FQA
M;FL@=VEL;"!D969A=6QT('1O(&-U<G)E;G0*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@87!P;&EC871I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!I;6%G92!D:7)E8W1O<GD@=7)I('!A=&@N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$EM86=E1&ER*"1A<'`@/2!N=6QL*0H@("`@>PH@
M("`@("`@(&EF("AE;7!T>2@D87!P*2D@>PH@("`@("`@("`@("`D87!P(#T@
M)'1H:7,M/E]C=7)R96YT07!P.PH@("`@("`@('T*"B`@("`@("`@<W1A=&EC
M("1I;6=?9&ER(#T@87)R87DH*3L*("`@("`@("!I9B`H:7-S970H)&EM9U]D
M:7);)&%P<%TI*2!["B`@("`@("`@("`@(')E='5R;B`D:6UG7V1I<ELD87!P
M73L*("`@("`@("!]"@H@("`@("`@("\J(%1H:7,@:7,@=&AE(&1E9F%U;'0@
M;&]C871I;VX@9F]R('1H92!G<F%P:&EC<RX@*B\*("`@("`@("`D:6UG7V1I
M<ELD87!P72`]("1T:&ES+3YG970H)W1H96UE<W5R:2<L("1A<'`I("X@)R]G
M<F%P:&EC<R<["@H@("`@("`@('-T871I8R`D=&AE;65?:6-O;G,["@H@("`@
M("`@("\J($9I9W5R92!O=70@:68@=&AI<R!I<R!G;VEN9R!T;R!B92!O=F5R
M<FED9&5N(&)Y(&%N>2!T:&5M90H@("`@("`@("`J('-E='1I;F=S+B`J+PH@
M("`@("`@(&EF("AI<W-E="@D1TQ/0D%,4ULG<')E9G,G72D@)B8*("`@("`@
M("`@("`@*"1T:&5M92`]("1'3$]"04Q36R=P<F5F<R==+3YG971686QU92@G
M=&AE;64G*2D@)B8*("`@("`@("`@("`@*&ES<V5T*"1T:&5M95]I8V]N<RD@
M?'P*("`@("`@("`@("`@("@H0&EN8VQU9&4@)'1H:7,M/F=E="@G=&AE;65S
M9G,G+"`G:&]R9&4G*2`N("<O)R`N("1T:&5M92`N("<O:6YF;RYP:'`G*2`F
M)@H@("`@("`@("`@("`@(&ES<V5T*"1T:&5M95]I8V]N<RDI*2`F)@H@("`@
M("`@("`@("!I;E]A<G)A>2@D87!P+"`D=&AE;65?:6-O;G,I*2!["B`@("`@
M("`@("`@("1I;6=?9&ER6R1A<'!=(#T@)'1H:7,M/F=E="@G=&AE;65S=7)I
M)RP@)&%P<"D@+B`G+R<@+B`D=&AE;64@+B`G+V=R87!H:6-S)SL*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D:6UG7V1I<ELD87!P73L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE('!A=&@@=&\@86X@87!P;&EC871I
M;VXG<R!I8V]N+"!R97-P96-T:6YG('=H971H97(@=&AE"B`@("`@*B!C=7)R
M96YT('1H96UE(&AA<R!I=',@;W=N(&EC;VYS+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%P
M<"`@5&AE(&%P<&QI8V%T:6]N(&9O<B!W:&EC:"!T;R!G970@=&AE(&EC;VXN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971)8V]N*"1A<'`I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3YG971);6%G941I<B@D87!P*2`N("<O)R`N
M("1A<'`@+B`G+G!N9R<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!1=65R>2!T
M:&4@:6YI=&EA;"!P86=E(&9O<B!A;B!A<'!L:6-A=&EO;B`M('1H92!W96)R
M;V]T+"!I9B!T:&5R92!I<R!N;PH@("`@("H@:6YI=&EA;%]P86=E('-E="P@
M86YD('1H92!I;FET:6%L7W!A9V4L(&EF(&ET(&ES('-E="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1A<'`@(%1H92!N86UE(&]F('1H92!A<'!L
M:6-A=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@55),('!O
M:6YT:6YG('1O('1H92!I;FET86P@<&%G92!O9B!T:&4@87!P;&EC871I;VXN
M"B`@("`@*B`@("`@("`@("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N
M(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971);FET:6%L4&%G92@D
M87!P(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D87!P*2D@
M>PH@("`@("`@("`@("`D87!P(#T@)'1H:7,M/E]C=7)R96YT07!P.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^87!P;&EC871I;VYS
M6R1A<'!=*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BAS<')I;G1F*%\H(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@
M2&]R9&4@4F5G:7-T<GDN(BDL("1A<'`I*3L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1T:&ES+3YA<'!L:6-A=&EO;G-;)&%P<%U;)W=E8G)O;W0G72`N
M("<O)R`N("AI<W-E="@D=&AI<RT^87!P;&EC871I;VYS6R1A<'!=6R=I;FET
M:6%L7W!A9V4G72D@/R`D=&AI<RT^87!P;&EC871I;VYS6R1A<'!=6R=I;FET
M:6%L7W!A9V4G72`Z("<G*3L*("`@('T*"B`@("`O*BH*("`@("`J($!S:6YC
M92!(;W)D92`S+C$*("`@("`J+PH@("`@9G5N8W1I;VX@7U]G970H)&%P:2D*
M("`@('L*("`@("`@("!I9B`H:6Y?87)R87DH)&%P:2P@)'1H:7,M/FQI<W1!
M4$ES*"DI*2!["B`@("`@("`@("`@(')E='5R;B!N97<@4F5G:7-T<GE#86QL
M97(H)'1H:7,L("1A<&DI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($-L;VYE('-H;W5L9"!N979E<B!B92!C86QL960@;VX@4F5G:7-T<GD@
M;V)J96-T<RX@268@:70@:7,L(&1I92X*("`@("`J"B`@("`@*B!`<VEN8V4@
M2&]R9&4@,RXQ"B`@("`@*B\*("`@(&9U;F-T:6]N(%]?8VQO;F4H*0H@("`@
M>PH@("`@("`@($AO<F1E.CIF871A;"@G4F5G:7-T<GD@;V)J96-T<R!S:&]U
M;&0@;F5V97(@8F4@8VQO;F5D+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("!]"@I]"@HO*BH*("H@0'!A8VMA9V4@2&]R9&5?1G)A;65W;W)K"B`J($!S
M:6YC92!(;W)D92`S+C$*("HO"F-L87-S(%)E9VES=')Y0V%L;&5R('L*"B`@
M("!V87(@)')E9VES=')Y.PH@("`@=F%R("1A<&D["@H@("`@9G5N8W1I;VX@
M7U]C;VYS=')U8W0H)')E9VES=')Y+"`D87!I*0H@("`@>PH@("`@("`@("1T
M:&ES+3YR96=I<W1R>2`]("1R96=I<W1R>3L*("`@("`@("`D=&AI<RT^87!I
M(#T@)&%P:3L*("`@('T*"B`@("!F=6YC=&EO;B!?7V-A;&PH)&UE=&AO9"P@
M)&%R9W,I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YR96=I<W1R>2T^
M8V%L;"@D=&AI<RT^87!I("X@)R\G("X@)&UE=&AO9"P@)&%R9W,I.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]24$,O
M````````````````````````````````````````````````````````````
M````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`U,34T,S,W-3``,#(P,3`V`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+U)00R]R97-T+G!H<```````````````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P-S0Q,P`Q,#4Q-30S,S<U,``P,C$V,#$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J(%1H92!(;W)D95]24$-?<F5S="!C;&%S<R!P<F]V:61E<R!A(%)%
M4U0@:6UP;&5M96YT871I;VX@;V8@=&AE($AO<F1E(%)00PH@*B!S>7-T96TN
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`L=B`Q
M+C8N,BXR(#(P,#8O,#4O,#0@,3(Z,C0Z,30@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="!2869A96P@5F%R96QA(%!E="`\<F%F865L+G9A<F5L82YP971`
M=7-C+F5S/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@4F%F865L(%9A
M<F5L82`\<F%F865L+G9A<F5L82YP971`=7-C+F5S/@H@*B!`<VEN8V4@("!(
M;W)D92`S+C$*("H@0'!A8VMA9V4@2&]R9&5?4E!#"B`J+PIC;&%S<R!(;W)D
M95]24$-?<F5S="!E>'1E;F1S($AO<F1E7U)00R!["@H@("`@+RHJ"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]C;VYT96YT5'EP92`]
M("=T97AT+VAT;6PG.PH*("`@("\J*@H@("`@("H@0VAE8VL@875T:&5N=&EC
M871I;VXN($1I9F9E<F5N="!B86-K96YD<R!M87D@:&%N9&QE"B`@("`@*B!A
M=71H96YT:6-A=&EO;B!I;B!D:69F97)E;G0@=V%Y<RX@5&AE(&)A<V4@8VQA
M<W,@:6UP;&5M96YT871I;VX*("`@("`J(&-H96-K<R!F;W(@2%144"!!=71H
M96YT:6-A=&EO;B!A9V%I;G-T('1H92!(;W)D92!A=71H('-E='5P+@H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@4F5T=7)N<R!T<G5E(&EF(&%U
M=&AE;G1I8V%T:6]N(&ES('-U8V-E<W-F=6PN"B`@("`@*B`@("`@("`@("`@
M("`@("`@(%-H;W5L9"!S96YD(&%P<')O<')I871E(")N;W0@875T:&]R:7IE
M9"(@:&5A9&5R<PH@("`@("H@("`@("`@("`@("`@("`@("!O<B!O=&AE<B!R
M97-P;VYS92!C;V1E<R]B;V1Y(&EF(&%U=&@@9F%I;',L"B`@("`@*B`@("`@
M("`@("`@("`@("`@(&%N9"!T86ME(&-A<F4@;V8@97AI=&EN9RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@875T:&]R:7IE*"D*("`@('L*("`@("`@("!I9B`H
M(21T:&ES+3Y?875T:&]R:7IE*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@("`@('T*"B`@("`@("`@:68@*$%U=&@Z.F=E=$%U=&@H*2D@>PH@
M("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!P87)E;G0Z.F%U=&AO<FEZ92@I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1V5T+B!A;&P@=&AE($=%5"!I;G!U="!D871A+B!4:&4@)V-A;&PG('!A
M<F%M(&ES(&5X=')A8W1E9"!F<F]M('1H90H@("`@("H@87)R87D@86YD('1R
M96%T960@<V5P87)A=&5L>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("`H;65T:&]D(&YA;64L(&%R<F%Y(&]F('!A<F%M971E<G,I"B`@("`@*@H@
M("`@("H@5$]$3SH@9&5S97)I86QI>FEN9R!O9B!C;VUP;&5X(&1A=&$@='EP
M97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$EN<'5T*"D*("`@('L*("`@
M("`@("`D=&AI<RT^7V-O;G1E;G14>7!E(#T@571I;#HZ9V5T1V5T*"=R97-T
M0V]N=&5N=%1Y<&4G+"`G=&5X="]H=&UL)RD["@H@("`@"21G971$871A(#T@
M571I;#HZ9&ES<&5L36%G:6-1=6]T97,H)%]'150I.PH@("`@"75N<V5T*"1G
M971$871A6R=R97-T0V%L;"==*3L*("`@(`EU;G-E="@D9V5T1&%T85LG<F5S
M=$-O;G1E;G14>7!E)UTI.PH*("`@(`ER971U<FX@87)R87DH)VUE=&AO9"<@
M/3X@571I;#HZ9V5T1V5T*"=R97-T0V%L;"<I+`H@("`@"2`@("`@("`@("`@
M("`G<&%R86US)R`]/B`D9V5T1&%T82D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!396YD<R!A;B!24$,@<F5Q=65S="!T;R!T:&4@<V5R=F5R(&%N9"!R971U
M<FYS('1H92!R97-U;'0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@
M5&AE(')A=R!R97%U97-T('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4:&4@<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R(&]R(&%N(%!%
M05(@97)R;W(@;V)J96-T(&]N"B`@("`@*B`@("`@("`@("`@("`@("!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971297-P;VYS92@D<F5Q=65S
M="D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`D
M;65T:&]D(#T@<W1R7W)E<&QA8V4H)RXG+"`G+R<L("1R97%U97-T6R=M971H
M;V0G72D["@H@("`@("`@(&EF("@A)')E9VES=')Y+3YH87--971H;V0H)&UE
M=&AO9"DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M<W!R:6YT9BA?*")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z
M("5S(BDL("1M971H;V0I*3L*("`@("`@("!]"@H@("`@("`@("\J($QO;VL@
M870@=&AE(&UE=&AO9"!S:6=N871U<F4@<V\@=&AA="!P87)A;65T97)S(&%R
M92!A<W-I9VYE9"!B>0H@("`@("`@("`J(&YA;64L(&EN<W1E860@;V8@<F5L
M>6EN9R!O;B!T:&4@;W)D97(@;V8@1T54('!A<F%M971E<G,@=&\@;6%T8V@*
M("`@("`@("`@*B!T:&4@;W)D97(@9&5F:6YE9"!I;B!T:&4@05!)(&UE=&AO
M9"X@*B\*("`@("`@("`D<VEG;F%T=7)E(#T@)')E9VES=')Y+3YG9713:6=N
M871U<F4H)&UE=&AO9"D["B`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"D["B`@
M("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D<VEG;F%T=7)E6S!=*2!A<R`D
M<&%R86TI('L*("`@("`@("`@("`@)'!A<F%M<ULD<&%R86U=(#T@:7-S970H
M)')E<75E<W1;)W!A<F%M<R==6R1P87)A;5TI(#\@)')E<75E<W1;)W!A<F%M
M<R==6R1P87)A;5T@.B!N=6QL.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L
M="`]("1R96=I<W1R>2T^8V%L;"@D;65T:&]D+"`D<&%R86US*3L*("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@+RH@5&AE
M(')E<W5L="!I<R!R971U<FYE9"!D97!E;F1I;F<@;VX@=&AE(')E<75E<W1E
M9"!C;VYT96YT('1Y<&4N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?8V]N=&5N
M=%1Y<&4@/3T@)W1E>'0O:'1M;"<I('L*("`@("`@("`@("`@<F5T=7)N("<\
M:'1M;#X\8F]D>3XG("X@<')I;G1?<B@D<F5S=6QT+"!T<G5E*2`N("<\+V)O
M9'D^/"]H=&UL/B<["B`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?8V]N=&5N
M=%1Y<&4@/3T@)W1E>'0O<&QA:6XG*2!["B`@("`@("`@("`@(')E='5R;B!P
M<FEN=%]R*"1R97-U;'0L('1R=64I.PH@("`@("`@('T@96QS96EF("@D=&AI
M<RT^7V-O;G1E;G14>7!E(#T]("=A<'!L:6-A=&EO;B]X+6AT='!D+7!H<"<I
M('L*("`@("`@("`@("`@<F5T=7)N('-E<FEA;&EZ92@D<F5S=6QT*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE($-O;G1E;G0M
M5'EP92!O9B!T:&4@<F5S<&]N<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!-24U%($-O;G1E;G0M5'EP92!O9B!T:&4@4E!#(')E<W!O
M;G-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971297-P;VYS94-O;G1E;G14
M>7!E*"D*("`@('L*("`@("`@("!S=VET8V@@*"1T:&ES+3Y?8V]N=&5N=%1Y
M<&4I('L*("`@("`@("!C87-E("=A<'!L:6-A=&EO;B]X+6AT='!D+7!H<"<Z
M"B`@("`@("`@("`@(')E='5R;B`G=&5X="]P;&%I;B<["B`@("`@("`@9&5F
M875L=#H*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V]N=&5N=%1Y<&4[
M"B`@("`@("`@?0H@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U)00R]S;V%P+G!H<```
M````````````````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-3$U-P`Q,#4Q
M-30S,S<U,``P,C$U-S(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]24$-?<V]A<"!C
M;&%S<R!P<F]V:61E<R!A;B!33T%0(&EM<&QE;65N=&%T:6]N(&]F('1H90H@
M*B!(;W)D92!24$,@<WES=&5M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]2
M4$,O4E!#+W-O87`N<&AP+'8@,2XQ,RXQ,"XW(#(P,#8O,#$O,#$@,C$Z,C@Z
M,S,@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@2F%N(%-C
M:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC
M92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]24$,*("HO"F-L87-S
M($AO<F1E7U)00U]S;V%P(&5X=&5N9',@2&]R9&5?4E!#('L*"B`@("`O*BH*
M("`@("`J(%)E<V]U<F-E(&AA;F1L97(@9F]R('1H92!24$,@<V5R=F5R+@H@
M("`@("H*("`@("`J($!V87(@;V)J96-T"B`@("`@*B\*("`@('9A<B`D7W-E
M<G9E<CL*"B`@("`O*BH*("`@("`J($AA<V@@:&]L9&EN9R!A;&P@;65T:&]D
M<R<@<VEG;F%T=7)E<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7U]D:7-P871C:%]M87`@/2!A<G)A>2@I.PH*("`@("\J
M*@H@("`@("H@4T]!4"!S97)V97(@8V]N<W1R=6-T;W(*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?
M4E!#7W-O87`H)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"1P
M87)A;7,@/3T@)W=S9&PG('Q\("1P87)A;7,@/3T@)V1I<V-O)RD@>PH@("`@
M("`@("`@("`D=&AI<RT^7V%U=&AO<FEZ92`](&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@<&%R96YT.CI(;W)D95]24$,H*3L*"B`@("`@("`@9VQO8F%L
M("1R96=I<W1R>3L*"B`@("`@("`@<F5Q=6ER95]O;F-E("=33T%0+U-E<G9E
M<BYP:'`G.PH@("`@("`@("1T:&ES+3Y?<V5R=F5R(#T@)FYE=R!33T%07U-E
M<G9E<B@I.PH@("`@("`@("1T:&ES+3Y?<V5R=F5R+3Y?875T;U]T<F%N<VQA
M=&EO;B`]('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6QL<R!A(&AA
M<V@@=&AA="!I<R!U<V5D(&)Y('1H92!33T%0('-E<G9E<B!W:71H('1H92!S
M:6=N871U<F5S(&]F"B`@("`@*B!A;&P@879A:6QA8FQE(&UE=&AO9',N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]S971U<$1I<W!A=&-H36%P*"D*("`@('L*
M("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`D;65T:&]D<R`]
M("1R96=I<W1R>2T^;&ES=$UE=&AO9',H*3L*("`@("`@("!F;W)E86-H("@D
M;65T:&]D<R!A<R`D;65T:&]D*2!["B`@("`@("`@("`@("1S:6=N871U<F4@
M/2`D<F5G:7-T<GDM/F=E=%-I9VYA='5R92@D;65T:&]D*3L*("`@("`@("`@
M("`@:68@*"%I<U]A<G)A>2@D<VEG;F%T=7)E*2D@>PH@("`@("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&UE=&AO
M9"`]('-T<E]R97!L86-E*"<O)RP@)RXG+"`D;65T:&]D*3L*("`@("`@("`@
M("`@)'1H:7,M/E]?9&ES<&%T8VA?;6%P6R1M971H;V1=(#T@87)R87DH"B`@
M("`@("`@("`@("`@("`G:6XG(#T^("1S:6=N871U<F5;,%TL"B`@("`@("`@
M("`@("`@("`G;W5T)R`]/B!A<G)A>2@G;W5T<'5T)R`]/B`D<VEG;F%T=7)E
M6S%=*0H@("`@("`@("`@("`I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/E]?='EP961E9B`]("1R96=I<W1R>2T^;&ES=%1Y<&5S*"D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!S:6=N871U<F4@;V8@82!M971H
M;V0N"B`@("`@*B!);G1E<FYA;&QY('5S960@8GD@=&AE(%-/05`@<V5R=F5R
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UE=&AO9"`@02!M971H
M;V0@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A
M>2!D97-C<FEB:6YG('1H92!M971H;V0G<R!S:6=N871U<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]?9&ES<&%T8V@H)&UE=&AO9"D*("`@('L*("`@("`@
M("!G;&]B86P@)')E9VES=')Y.PH@("`@("`@("1M971H;V0@/2!S=')?<F5P
M;&%C92@G+B<L("<O)RP@)&UE=&AO9"D["@H@("`@("`@("1S:6=N871U<F4@
M/2`D<F5G:7-T<GDM/F=E=%-I9VYA='5R92@D;65T:&]D*3L*("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1S:6=N871U<F4I*2!["B`@("`@("`@("`@(')E='5R
M;B!N=6QL.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"=I;B<@
M/3X@)'-I9VYA='5R95LP72P*("`@("`@("`@("`@("`@("`@("`@)V]U="<@
M/3X@87)R87DH)V]U='!U="<@/3X@)'-I9VYA='5R95LQ72DI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@5VEL;"!B92!R96=I<W1E<F5D(&%S('1H92!H86YD
M;&5R(&9O<B!A;&P@;65T:&]D<R!C86QL960@:6X@=&AE"B`@("`@*B!33T%0
M('-E<G9E<B!A;F0@=VEL;"!C86QL('1H92!A<'!R;W!R:6%T92!F=6YC=&EO
M;B!T:')O=6=H('1H92!R96=I<W1R>2X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M971H;V0@
M("`@5&AE(&YA;64@;V8@=&AE(&UE=&AO9"!C86QL960@8GD@=&AE(%)00R!R
M97%U97-T+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("`@(%1H92!P
M87-S960@<&%R86UE=&5R<RX*("`@("`J($!P87)A;2!M:7AE9"`D9&%T82`@
M("`@("!5;FMN;W=N+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@("`@
M("`@("`@("!4:&4@<F5S=6QT(&]F('1H92!C86QL960@<F5G:7-T<GD@;65T
M:&]D+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9&ES<&%T8VAE<B@D;65T:&]D
M+"`D<&%R86US*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["B`@
M("`@("`@)&UE=&AO9"`]('-T<E]R97!L86-E*"<N)RP@)R\G+"`D;65T:&]D
M*3L*"B`@("`@("`@:68@*"$D<F5G:7-T<GDM/FAA<TUE=&AO9"@D;65T:&]D
M*2D@>PH@("`@("`@("`@("!R971U<FX@<W!R:6YT9BA?*")-971H;V0@7"(E
M<UPB(&ES(&YO="!D969I;F5D(BDL("1M971H;V0I.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/E]S97)V97(M/F)I;F174T1,*$AO<F1E.CIU<FPH)')E
M9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<G!C+G!H<#]W
M<V1L)RP@=')U92P@9F%L<V4I*3L*("`@("`@("!R971U<FX@)')E9VES=')Y
M+3YC86QL*"1M971H;V0L("1P87)A;7,I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@5&%K97,@86X@4E!#(')E<75E<W0@86YD(')E='5R;G,@=&AE(')E<W5L
M="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("!4:&4@<F%W(')E<75E
M<W0@<W1R:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`@4W1R:6YG('-P96-I
M9GEI;F<@=VAA="!K:6YD(&]F(&1A=&$@=&\@<F5T=7)N+B!$969A=6QT<PH@
M("`@("H@("`@("`@("`@("`@("`@=&\@4T]!4"!R97%U97-T+B!0;W-S:6)L
M92!O=&AE<B!V86QU97,Z(")W9'-L(B!A;F0*("`@("`J("`@("`@("`@("`@
M("`@(")D:7-C;R(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!834P@96YC;V1E9"!R97-P;VYS92!F<F]M('1H92!S97)V97(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%)E<W!O;G-E*"1R97%U97-T+"`D<&%R86US
M(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7W-E<G9E<BT^861D3V)J
M96-T36%P*"1T:&ES+"`G=7)N.FAO<F1E)RD["@H@("`@("`@(&EF("@A)'!A
M<F%M<RD@>PH@("`@("`@("`@("`D=&AI<RT^7W-E<G9E<BT^<V5T0V%L;$AA
M;F1L97(H87)R87DH)'1H:7,L("=?9&ES<&%T8VAE<B<I*3L*("`@("`@("`@
M("`@+RH@5V4@8V%N)W0@=7-E(%5T:6PZ.F)U9F9E<D]U='!U="@I(&AE<F4@
M9F]R('-O;64@<F5A<V]N+B`J+PH@("`@("`@("`@("!O8E]S=&%R="@I.PH@
M("`@("`@("`@("`D=&AI<RT^7W-E<G9E<BT^<V5R=FEC92@D<F5Q=65S="D[
M"B`@("`@("`@("`@("1O=71P=70@/2!O8E]G971?8V]N=&5N=',H*3L*("`@
M("`@("`@("`@;V)?96YD7V-L96%N*"D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5Q=6ER95]O;F-E("=33T%0+T1I<V-O+G!H<"<["B`@("`@
M("`@("`@("1D:7-C;R`](&YE=R!33T%07T1)4T-/7U-E<G9E<B@D=&AI<RT^
M7W-E<G9E<BP@)VAO<F1E)RD["B`@("`@("`@("`@(&EF("@D<&%R86US(#T]
M("=W<V1L)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]S971U<$1I<W!A
M=&-H36%P*"D["B`@("`@("`@("`@("`@("`D;W5T<'5T(#T@)&1I<V-O+3YG
M97174T1,*"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D;W5T<'5T(#T@)&1I<V-O+3YG971$25-#3R@I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&]U='!U=#L*("`@('T*"B`@
M("`O*BH*("`@("`J($)U:6QD<R!A;B!33T%0(')E<75E<W0@86YD('-E;F1S
M(&ET('1O('1H92!33T%0('-E<G9E<BX*("`@("`J"B`@("`@*B!4:&ES('-T
M871I8V%L;'D@8V%L;&5D(&UE=&AO9"!I<R!A8W1U86QL>2!T:&4@4T]!4"!C
M;&EE;G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7)L("`@("!4
M:&4@<&%T:"!T;R!T:&4@4T]!4"!S97)V97(@;VX@=&AE(&-A;&QE9"!H;W-T
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65T:&]D("!4:&4@;65T:&]D('1O
M(&-A;&PN"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@($$@:&%S:"!C
M;VYT86EN:6YG(&%N>2!N96-E<W-A<GD@<&%R86UE=&5R<R!F;W(*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&UE=&AO9"!C86QL+@H@("`@
M("H@0'!A<F%M("1O<'1I;VYS("!/<'1I;VYA;"!A<W-O8VEA=&EV92!A<G)A
M>2!O9B!P87)A;65T97)S('=H:6-H(&-A;B!B93H*("`@("`J("`@("`@("`@
M("`@("`@("`@=7-E<B`@("`@("`@("`@("`@("`M($)A<VEC($%U=&@@=7-E
M<FYA;64*("`@("`J("`@("`@("`@("`@("`@("`@<&%S<R`@("`@("`@("`@
M("`@("`M($)A<VEC($%U=&@@<&%S<W=O<F0*("`@("`J("`@("`@("`@("`@
M("`@("`@<')O>'E?:&]S="`@("`@("`@("`M(%!R;WAY('-E<G9E<B!H;W-T
M"B`@("`@*B`@("`@("`@("`@("`@("`@('!R;WAY7W!O<G0@("`@("`@("`@
M+2!0<F]X>2!S97)V97(@<&]R=`H@("`@("H@("`@("`@("`@("`@("`@("!P
M<F]X>5]U<V5R("`@("`@("`@("T@4')O>'D@875T:"!U<V5R;F%M90H@("`@
M("H@("`@("`@("`@("`@("`@("!P<F]X>5]P87-S("`@("`@("`@("T@4')O
M>'D@875T:"!P87-S=V]R9`H@("`@("H@("`@("`@("`@("`@("`@("!T:6UE
M;W5T("`@("`@("`@("`@("T@0V]N;F5C=&EO;B!T:6UE;W5T(&EN('-E8V]N
M9',N"B`@("`@*B`@("`@("`@("`@("`@("`@(&%L;&]W4F5D:7)E8W1S("`@
M("`@+2!7:&5T:&5R('1O(&9O;&QO=R!R961I<F5C=',@;W(@;F]T"B`@("`@
M*B`@("`@("`@("`@("`@("`@(&UA>%)E9&ER96-T<R`@("`@("`@+2!-87@@
M;G5M8F5R(&]F(')E9&ER96-T<R!T;R!F;VQL;W<*("`@("`J("`@("`@("`@
M("`@("`@("`@;F%M97-P86-E"B`@("`@*B`@("`@("`@("`@("`@("`@('-O
M87!A8W1I;VX*("`@("`J("`@("`@("`@("`@("`@("`@9G)O;2`@("`@("`@
M("`@("`@("`M(%--5%`L(&9R;VT@861D<F5S<PH@("`@("H@("`@("`@("`@
M("`@("`@("!T<F%N<V9E<BUE;F-O9&EN9R`@("T@4TU44"P@<V5T<R!T:&4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<@:&5A9&5R"B`@("`@*B`@("`@
M("`@("`@("`@("`@('-U8FIE8W0@("`@("`@("`@("`@+2!33510+"!S=6)J
M96-T(&AE861E<@H@("`@("H@("`@("`@("`@("`@("`@("!H96%D97)S("`@
M("`@("`@("`@("T@4TU44"P@87)R87DM:&%S:"!O9B!E>'1R82!S;71P"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!H
M96%D97)S"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@("`@("`@("`@
M(%1H92!R971U<FYE9"!R97-U;'0@9G)O;2!T:&4@;65T:&]D(&]R(&$@4$5!
M4@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R97%U97-T*"1U
M<FPL("1M971H;V0L("1P87)A;7,@/2!N=6QL+"`D;W!T:6]N<R`](&%R<F%Y
M*"DI"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG=&EM96]U
M="==*2D@>PH@("`@("`@("`@("`D;W!T:6]N<ULG=&EM96]U="==(#T@-3L*
M("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG86QL;W=2
M961I<F5C=',G72DI('L*("`@("`@("`@("`@)&]P=&EO;G-;)V%L;&]W4F5D
M:7)E8W1S)UT@/2!T<G5E.PH@("`@("`@("`@("`D;W!T:6]N<ULG;6%X4F5D
M:7)E8W1S)UT@("`](#,["B`@("`@("`@?0H*("`@("`@("!R97%U:7)E7V]N
M8V4@)U-/05`O0VQI96YT+G!H<"<["B`@("`@("`@)'-O87`@/2`F;F5W(%-/
M05!?0VQI96YT*"1U<FPL(&9A;'-E+"!F86QS92P@)&]P=&EO;G,I.PH@("`@
M("`@(')E='5R;B`D<V]A<"T^8V%L;"@D;65T:&]D+"`D<&%R86US+"`D;W!T
M:6]N<ULG;F%M97-P86-E)UTI.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U)00R]S>6YC;6PN<&AP````````````````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-S8T-@`Q,#4Q-30S,S<U,``P,C(Q-#(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*"G)E<75I<F5?;VYC92`G4WEN8TU,+G!H<"<["G)E<75I<F5?;VYC92`G
M4WEN8TU,+U-T871E+G!H<"<["G)E<75I<F5?;VYC92`G4WEN8TU,+T-O;6UA
M;F0O4W1A='5S+G!H<"<["@HO*BH*("H@5&AE($AO<F1E7U)00U]S>6YC;6P@
M8VQA<W,@<')O=FED97,@82!3>6YC34P@:6UP;&5M96YT871I;VX@;V8@=&AE
M($AO<F1E"B`J(%)00R!S>7-T96TN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+U)00R]24$,O<WEN8VUL+G!H<"QV(#$N,3@N,3`N-R`R,#`V+S`U+S`Q(#$R
M.C`U.C$S(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@
M,C`P,RTR,#`V($%N=&AO;GD@36EL;',@/&%M:6QL<T!P>7)A;6ED-BYC;VT^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@06YT:&]N>2!-:6QL<R`\
M86UI;&QS0'!Y<F%M:60V+F-O;3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J
M($!P86-K86=E($AO<F1E7U)00PH@*B\*8VQA<W,@2&]R9&5?4E!#7W-Y;F-M
M;"!E>'1E;F1S($AO<F1E7U)00R!["@H@("`@+RHJ"B`@("`@*B!/=71P=70@
M0V]N=&5N=$AA;F1L97(@=7-E9"!T;R!O=71P=70@6$U,(&5V96YT<RX*("`@
M("`J"B`@("`@*B!`=F%R(&]B:F5C=`H@("`@("HO"B`@("!V87(@)%]O=71P
M=70["@H@("`@+RHJ"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@
M=F%R("1?>&UL4W1A8VL@/2`P.PH*("`@("\J*@H@("`@("H@1&5B=6<@9&ER
M96-T;W)Y+"!I9B!S970@=VEL;"!S=&]R92!C;W!I97,@;V8@86QL('!A8VME
M=',N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?9&5B=6=$:7(@/2`G+W1M<"]S>6YC)SL*"B`@("`O*BH*("`@("`J($1E
M9F%U;'0@8VAA<F%C=&5R('-E="X@($]N;'D@<W5P<&]R=',@551&+3@H05-#
M24D_*2X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)%]C:&%R<V5T(#T@)U541BTX)SL*"B`@("`O*BH*("`@("`J(%-Y;F--
M3"!H86YD;&5S(&%U=&AE;G1I8V%T:6]N(&EN=&5R;F%L;'DL('-O(&)Y<&%S
M<R!T:&4@4E!#(&9R86UE=V]R:PH@("`@("H@875T:"!C:&5C:R!B>2!J=7-T
M(')E='5R;FEN9R!T<G5E(&AE<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%U
M=&AO<FEZ92@I"B`@("!["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!396YD<R!A;B!24$,@<F5Q=65S="!T;R!T:&4@<V5R
M=F5R(&%N9"!R971U<FYS('1H92!R97-U;'0N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<F5Q=65S="`@5&AE(')A=R!R97%U97-T('-T<FEN9RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(%A-3"!E;F-O9&5D
M(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4F5S<&]N<V4H)')E<75E<W0I"B`@("!["B`@("`@("`@+RH@0V%T
M8V@@86YY(&5R<F]R<R]W87)N:6YG<R]N;W1I8V5S('1H870@;6%Y(&=E="!T
M:')O=VX@=VAI;&4*("`@("`@("`@*B!P<F]C97-S:6YG+B!$;VXG="!W86YT
M('1O(&QE="!A;GET:&EN9R!G;R!T;R!T:&4@8VQI96YT('1H870G<R!N;W0*
M("`@("`@("`@*B!P87)T(&]F('1H92!V86QI9"!R97-P;VYS92X@*B\*("`@
M("`@("!O8E]S=&%R="@I.PH*("`@("`@("`O*B!697)Y('5S969U;"!F;W(@
M9&5B=6=G:6YG+B!,;V=S(%="6$U,('!A8VME=',@=&\*("`@("`@("`@*B`D
M=&AI<RT^7V1E8G5G1&ER+B`J+PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M
M/E]D96)U9T1I<BD@)B8@:7-?9&ER*"1T:&ES+3Y?9&5B=6=$:7(I*2!["B`@
M("`@("`@("`@("1P86-K971.=6T@/2!`:6YT=F%L*&9I;&5?9V5T7V-O;G1E
M;G1S*"1T:&ES+3Y?9&5B=6=$:7(@+B`G+W-Y;F-M;"YP86-K971N=6TG*2D[
M"B`@("`@("`@("`@(&EF("@A:7-S970H)'!A8VME=$YU;2DI('L*("`@("`@
M("`@("`@("`@("1P86-K971.=6T@/2`P.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D9B`]($!F;W!E;B@D=&AI<RT^7V1E8G5G1&ER("X@)R]S>6YC
M;6Q?8VQI96YT7R<@+B`D<&%C:V5T3G5M("X@)RYX;6PG+"`G=V(G*3L*("`@
M("`@("`@("`@:68@*"1F*2!["B`@("`@("`@("`@("`@("!F=W)I=&4H)&8L
M("1R97%U97-T*3L*("`@("`@("`@("`@("`@(&9C;&]S92@D9BD["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E<75I<F5?;VYC92`G6$U,
M+U="6$U,+T-O;G1E;G1(86YD;&5R+G!H<"<["B`@("`@("`@)'1H:7,M/E]O
M=71P=70@/2`F;F5W(%A-3%]70EA-3%]#;VYT96YT2&%N9&QE<B@I.PH*("`@
M("`@("`D=&AI<RT^7W!A<G-E*"1R97%U97-T*3L*("`@("`@("`D<F5S<&]N
M<V4@/2`D=&AI<RT^7V]U='!U="T^9V5T3W5T<'5T*"D["@H@("`@("`@("\J
M(%9E<GD@=7-E9G5L(&9O<B!D96)U9V=I;F<N("HO"B`@("`@("`@:68@*"%E
M;7!T>2@D=&AI<RT^7V1E8G5G1&ER*2`F)B!I<U]D:7(H)'1H:7,M/E]D96)U
M9T1I<BDI('L*("`@("`@("`@("`@)&8@/2!`9F]P96XH)'1H:7,M/E]D96)U
M9T1I<B`N("<O<WEN8VUL7W-E<G9E<E\G("X@)'!A8VME=$YU;2`N("<N>&UL
M)RP@)W=B)RD["B`@("`@("`@("`@(&EF("@D9BD@>PH@("`@("`@("`@("`@
M("`@9G=R:71E*"1F+"`D<F5S<&]N<V4I.PH@("`@("`@("`@("`@("`@9F-L
M;W-E*"1F*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&9P(#T@0&9O
M<&5N*"1T:&ES+3Y?9&5B=6=$:7(@+B`G+W-Y;F-M;"YP86-K971N=6TG+"`G
M=R<I.PH@("`@("`@("`@("!I9B`H)&9P*2!["B`@("`@("`@("`@("`@("!F
M=W)I=&4H)&9P+"`K*R1P86-K971.=6TI.PH@("`@("`@("`@("`@("`@9F-L
M;W-E*"1F<"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J
M($-L96%R('1H92!O=71P=70@8G5F9F5R('1H870@=V4@<W1A<G1E9"!A8F]V
M92P@86YD(&QO9R!A;GET:&EN9PH@("`@("`@("`J('1H870@8V%M92!U<"!F
M;W(@;&%T97(@9&5B=6=G:6YG+B`J+PH@("`@("`@("1E<G)O<DQO9V=I;F<@
M/2!O8E]G971?8VQE86XH*3L*("`@("`@("!I9B`H(65M<'1Y*"1E<G)O<DQO
M9V=I;F<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=3>6YC
M34PZ(&-A=6=H="!O=71P=70])R`N"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-T<E]R97!L86-E*")<;B(L("<@)RP@)&5R<F]R3&]G9VEN9RDL
M(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1R97-P;VYS93L*("`@('T*"B`@("!F=6YC
M=&EO;B!?<&%R<V4H)'AM;"D*("`@('L*("`@("`@("`O*B!T<GD@=&\@97AT
M<F%C="!C:&%R<V5T(&9R;VT@6$U,('1E>'0@*B\*("`@("`@("!I9BAP<F5G
M7VUA=&-H*"<O7EQS*CQ</WAM;%M>/ETJ96YC;V1I;F=<<RH]7',J(BA;7B)=
M*BDB+VDG+`H@("`@("`@("`@("`@("`@)'AM;"P@)&TI*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?8VAA<G-E="`]("1M6S%=.PH@("`@("`@('T*("`@("`@
M("!.3%,Z.G-E=$-H87)S970H)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("!3
M=')I;F<Z.G-E=$1E9F%U;'1#:&%R<V5T*"1T:&ES+3Y?8VAA<G-E="D["@H@
M("`@("`@("\J($-R96%T92!T:&4@6$U,('!A<G-E<B!A;F0@<V5T(&UE=&AO
M9"!R969E<F5N8V5S+B`J+PH@("`@("`@("1T:&ES+3Y?<&%R<V5R(#T@>&UL
M7W!A<G-E<E]C<F5A=&5?;G,H)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("!X
M;6Q?<V5T7V]B:F5C="@D=&AI<RT^7W!A<G-E<BP@)'1H:7,I.PH@("`@("`@
M('AM;%]P87)S97)?<V5T7V]P=&EO;B@D=&AI<RT^7W!A<G-E<BP@6$U,7T]0
M5$E/3E]#05-%7T9/3$1)3D<L(&9A;'-E*3L*("`@("`@("!X;6Q?<V5T7V5L
M96UE;G1?:&%N9&QE<B@D=&AI<RT^7W!A<G-E<BP@)U]S=&%R=$5L96UE;G0G
M+"`G7V5N9$5L96UE;G0G*3L*("`@("`@("!X;6Q?<V5T7V-H87)A8W1E<E]D
M871A7VAA;F1L97(H)'1H:7,M/E]P87)S97(L("=?8VAA<F%C=&5R<R<I.PH@
M("`@("`@('AM;%]S971?<')O8V5S<VEN9U]I;G-T<G5C=&EO;E]H86YD;&5R
M*"1T:&ES+3Y?<&%R<V5R+"`G)RD["B`@("`@("`@>&UL7W-E=%]E>'1E<FYA
M;%]E;G1I='E?<F5F7VAA;F1L97(H)'1H:7,M/E]P87)S97(L("<G*3L*"B`@
M("`@("`@:68@*"%X;6Q?<&%R<V4H)'1H:7,M/E]P87)S97(L("1X;6PI*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAS<')I;G1F
M*"=834P@97)R;W(Z("5S(&%T(&QI;F4@)60G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!X;6Q?97)R;W)?<W1R:6YG
M*'AM;%]G971?97)R;W)?8V]D92@D=&AI<RT^7W!A<G-E<BDI+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!X;6Q?9V5T
M7V-U<G)E;G1?;&EN95]N=6UB97(H)'1H:7,M/E]P87)S97(I*2D["B`@("`@
M("`@?0H*("`@("`@("!X;6Q?<&%R<V5R7V9R964H)'1H:7,M/E]P87)S97(I
M.PH@("`@?0H*("`@(&9U;F-T:6]N(%]S=&%R=$5L96UE;G0H)'!A<G-E<BP@
M)'1A9RP@)&%T=')I8G5T97,I"B`@("!["B`@("`@("`@;&ES="@D=7)I+"`D
M;F%M92D@/2`D=&AI<RT^7W-P;&ET55))*"1T86<I.PH*("`@("`@("`D=&AI
M<RT^<W1A<G1%;&5M96YT*"1U<FDL("1N86UE+"`D871T<FEB=71E<RD["B`@
M("!]"@H@("`@9G5N8W1I;VX@7V-H87)A8W1E<G,H)'!A<G-E<BP@)&-H87)S
M*0H@("`@>PH@("`@("`@("1T:&ES+3YC:&%R86-T97)S*"1C:&%R<RD["B`@
M("!]"@H@("`@9G5N8W1I;VX@7V5N9$5L96UE;G0H)'!A<G-E<BP@)'1A9RD*
M("`@('L*("`@("`@("!L:7-T*"1U<FDL("1N86UE*2`]("1T:&ES+3Y?<W!L
M:7154DDH)'1A9RD["@H@("`@("`@("1T:&ES+3YE;F1%;&5M96YT*"1U<FDL
M("1N86UE*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<W!L:7154DDH)'1A9RD*
M("`@('L*("`@("`@("`D<&%R=',@/2!E>'!L;V1E*"<Z)RP@)'1A9RD["B`@
M("`@("`@)&YA;64@/2!A<G)A>5]P;W`H)'!A<G1S*3L*("`@("`@("`D=7)I
M(#T@:6UP;&]D92@G.B<L("1P87)T<RD["B`@("`@("`@<F5T=7)N(&%R<F%Y
M*"1U<FDL("1N86UE*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE($-O;G1E;G0M5'EP92!O9B!T:&4@<F5S<&]N<V4N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!-24U%($-O;G1E;G0M5'EP92!O9B!T
M:&4@4E!#(')E<W!O;G-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971297-P
M;VYS94-O;G1E;G14>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)V%P<&QI
M8V%T:6]N+W9N9"YS>6YC;6PK>&UL)SL*("`@('T*"B`@("!F=6YC=&EO;B!S
M=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD*("`@('L*("`@
M("`@("`D=&AI<RT^7WAM;%-T86-K*RL["@H@("`@("`@('-W:71C:"`H)'1H
M:7,M/E]X;6Q3=&%C:RD@>PH@("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@
M+R\@/%-Y;F--3#X*("`@("`@("`@("`@+R\@1&5F:6YE9"!I;B!3>6YC34P@
M4F5P<F5S96YT871I;VX@4')O=&]C;VPL('9E<G-I;VX@,2XQ(#4N,BXQ"B`@
M("`@("`@("`@("1T:&ES+3Y?;W5T<'5T+3YS=&%R=$5L96UE;G0H)'5R:2P@
M)&5L96UE;G0L("1A='1R<RD["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E(#(Z"B`@("`@("`@("`@("\O($5I=&AE<B`\4WEN8TU,/CQ3>6YC
M2&1R/B!O<B`\4WEN8TU,/CQ3>6YC0F]D>3X*("`@("`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7V-O;G1E;G1(86YD;&5R*2D@>PH@("`@("`@("`@("`@
M("`@+R\@268@;F]T(&1E9FEN960@=&AE;B!C<F5A=&4@4WEN8TAD<BX*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8V]N=&5N=$AA;F1L97(@/2`F;F5W(%-Y
M;F--3%]3>6YC;6Q(9'(H*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]N
M=&5N=$AA;F1L97(M/G-E=$]U='!U="@D=&AI<RT^7V]U='!U="D["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?8V]N=&5N=$AA;F1L97(M
M/G-T87)T16QE;65N="@D=7)I+"`D96QE;65N="P@)&%T=')S*3L*("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7V-O;G1E;G1(86YD;&5R*2D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]C;VYT96YT2&%N9&QE<BT^<W1A<G1%;&5M96YT*"1U
M<FDL("1E;&5M96YT+"`D871T<G,I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!E;F1%
M;&5M96YT*"1U<FDL("1E;&5M96YT*0H@("`@>PH@("`@("`@('-W:71C:"`H
M)'1H:7,M/E]X;6Q3=&%C:RD@>PH@("`@("`@(&-A<V4@,3H*("`@("`@("`@
M("`@+R\@/"]3>6YC34P^"B`@("`@("`@("`@("\O($1E9FEN960@:6X@4WEN
M8TU,(%)E<')E<V5N=&%T:6]N(%!R;W1O8V]L+"!V97)S:6]N(#$N,2`U+C(N
M,0H@("`@("`@("`@("`D=&AI<RT^7V]U='!U="T^96YD16QE;65N="@D=7)I
M+"`D96QE;65N="D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M(#(Z"B`@("`@("`@("`@("\O($5I=&AE<B`\+U-Y;F-(9'(^/"]3>6YC34P^
M(&]R(#PO4WEN8T)O9'D^/"]3>6YC34P^"B`@("`@("`@("`@(&EF("@D96QE
M;65N="`]/2`G4WEN8TAD<B<I('L*("`@("`@("`@("`@("`@("\O(%1H96X@
M=V4@9V5T('1H92!S=&%T92!F<F]M(%-Y;F--3$AD<BP@86YD(&-R96%T92!A
M(&YE=PH@("`@("`@("`@("`@("`@+R\@4WEN8TU,0F]D>2X*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?8V]N=&5N=$AA;F1L97(M/F5N9$5L96UE;G0H)'5R
M:2P@)&5L96UE;G0I.PH*("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?
M8V]N=&5N=$AA;F1L97(I.PH*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]N
M=&5N=$AA;F1L97(@/2`F;F5W(%-Y;F--3%]3>6YC;6Q";V1Y*"D["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7V-O;G1E;G1(86YD;&5R+3YS971/=71P=70H
M)'1H:7,M/E]O=71P=70I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@+R\@3F\@;&]N9V5R('5S960N"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V-O;G1E;G1(86YD;&5R+3YE;F1%;&5M96YT*"1U<FDL("1E;&5M
M96YT*3L*("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?8V]N=&5N=$AA
M;F1L97(I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("!D969A=6QT.@H@("`@("`@("`@("`O+R`\+RH^/"]3>6YC2&1R/CPO
M4WEN8TU,/B!O<B`\+RH^/"]3>6YC0F]D>3X\+U-Y;F--3#X*("`@("`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?8V]N=&5N=$AA;F1L97(I*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7V-O;G1E;G1(86YD;&5R+3YE;F1%;&5M96YT
M*"1U<FDL("1E;&5M96YT*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-H
M87)S*2D@>PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^7V-H87)S*3L*("`@
M("`@("!]"@H@("`@("`@("1T:&ES+3Y?>&UL4W1A8VLM+3L*("`@('T*"B`@
M("!F=6YC=&EO;B!C:&%R86-T97)S*"1S='(I"B`@("!["B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?8V]N=&5N=$AA;F1L97(I*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?8V]N=&5N=$AA;F1L97(M/F-H87)A8W1E<G,H)'-T<BD["B`@
M("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(')A:7-E17)R;W(H)'-T<BD*
M("`@('L*("`@("`@("!R971U<FX@2&]R9&4Z.FQO9TUE<W-A9V4H)'-T<BP@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]24$,O<WEN8VUL
M7W=B>&UL+G!H<```````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8W,#<`
M,3`U,34T,S,W-3``,#(S,S0W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+W-Y;F-M;"YP:'`G.PIR97%U:7)E7V]N8V4@)UA-3"]7
M0EA-3"]$96-O9&5R+G!H<"<["G)E<75I<F5?;VYC92`G6$U,+U="6$U,+T5N
M8V]D97(N<&AP)SL*"B\J*@H@*B!4:&4@2&]R9&5?4E!#7W-Y;F-M;%]W8GAM
M;"!C;&%S<R!P<F]V:61E<R!A(%-Y;F--3"!I;7!L96UE;G1A=&EO;B!O9B!T
M:&4*("H@2&]R9&4@4E!#('-Y<W1E;2!U<VEN9R!70EA-3"!E;F-O9&EN9RX*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4E!#+U)00R]S>6YC;6Q?=V)X;6PN
M<&AP+'8@,2XQ,2XQ,"XV(#(P,#8O,#$O,#$@,C$Z,C@Z,S,@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@06YT:&]N
M>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*B!`875T:&]R("!!;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N
M8V]M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?
M4E!#"B`J+PIC;&%S<R!(;W)D95]24$-?<WEN8VUL7W=B>&UL(&5X=&5N9',@
M2&]R9&5?4E!#7W-Y;F-M;"!["@H@("`@+RHJ"B`@("`@*B!396YD<R!A;B!2
M4$,@<F5Q=65S="!T;R!T:&4@<V5R=F5R(&%N9"!R971U<FYS('1H92!R97-U
M;'0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5Q=65S="`@5&AE
M(')A=R!R97%U97-T('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(%="6$U,(&5N8V]D960@<F5S<&]N<V4@9G)O;2!T:&4@<V5R
M=F5R("AB:6YA<GDI+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971297-P;VYS
M92@D<F5Q=65S="D*("`@('L*("`@("`@("`O*B!#871C:"!A;GD@97)R;W)S
M+W=A<FYI;F=S+VYO=&EC97,@=&AA="!M87D@9V5T('1H<F]W;B!W:&EL90H@
M("`@("`@("`J('!R;V-E<W-I;F<N($1O;B=T('=A;G0@=&\@;&5T(&%N>71H
M:6YG(&=O('1O('1H92!C;&EE;G0@=&AA="=S(&YO=`H@("`@("`@("`J('!A
M<G0@;V8@=&AE('9A;&ED(')E<W!O;G-E+B`J+PH@("`@("`@(&]B7W-T87)T
M*"D["@H@("`@("`@("\J(%9E<GD@=7-E9G5L(&9O<B!D96)U9V=I;F<N($QO
M9W,@5T)834P@<&%C:V5T<R!T;PH@("`@("`@("`J("1T:&ES+3Y?9&5B=6=$
M:7(N("HO"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7V1E8G5G1&ER*2`F
M)B!I<U]D:7(H)'1H:7,M/E]D96)U9T1I<BDI('L*("`@("`@("`@("`@)'!A
M8VME=$YU;2`]($!I;G1V86PH9FEL95]G971?8V]N=&5N=',H)'1H:7,M/E]D
M96)U9T1I<B`N("<O<WEN8VUL+G!A8VME=&YU;2<I*3L*("`@("`@("`@("`@
M:68@*"%I<W-E="@D<&%C:V5T3G5M*2D@>PH@("`@("`@("`@("`@("`@)'!A
M8VME=$YU;2`](#`["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1F<"`]
M(&9O<&5N*"1T:&ES+3Y?9&5B=6=$:7(@+B`G+W-Y;F-M;%]C;&EE;G1?)R`N
M("1P86-K971.=6T@+B`G+G=B>&UL)RP@)W=B)RD["B`@("`@("`@("`@(&9W
M<FET92@D9G`L("1R97%U97-T*3L*("`@("`@("`@("`@9F-L;W-E*"1F<"D[
M"B`@("`@("`@?0H*"B`@("`@("`@)&1E8V]D97(@/2`F;F5W(%A-3%]70EA-
M3%]$96-O9&5R*"D["B`@("`@("`@)'1H:7,M/E]O=71P=70@/2`F;F5W(%A-
M3%]70EA-3%]%;F-O9&5R*"D["@H@("`@("`@("1D96-O9&5R+3YS971#;VYT
M96YT2&%N9&QE<B@D=&AI<RD["@H@("`@("`@("1R(#T@)&1E8V]D97(M/F1E
M8V]D92@D<F5Q=65S="D["B`@("`@("`@:68@*&ES7V$H)'(L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-Y;F--
M3#H@)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R+3YG971-
M97-S86=E*"DL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*
M("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?;W5T<'5T+3YS971697)S:6]N
M*"1D96-O9&5R+3YG971697)S:6]N*"DI.PH@("`@("`@("1T:&ES+3Y?;W5T
M<'5T+3YS971#:&%R<V5T*"1D96-O9&5R+3YG971#:&%R<V5T4W1R*"DI.PH@
M("`@("`@("1R97-P;VYS92`]("1T:&ES+3Y?;W5T<'5T+3YG971/=71P=70H
M*3L*"B`@("`@("`@:68@*&ES7V$H)')E<W!O;G-E+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-P;VYS92P@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@
M("`D<F5S<&]N<V4@/2`D<F5S<&]N<V4M/F=E=$UE<W-A9V4H*3L*("`@("`@
M("!]"@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]D96)U9T1I<BD@)B8@
M:7-?9&ER*"1T:&ES+3Y?9&5B=6=$:7(I*2!["B`@("`@("`@("`@("1F<"`]
M(&9O<&5N*"1T:&ES+3Y?9&5B=6=$:7(@+B`G+W-Y;F-M;%]S97)V97)?)R`N
M("1P86-K971.=6T@+B`G+G=B>&UL)RP@)W=B)RD["B`@("`@("`@("`@(&9W
M<FET92@D9G`L("1R97-P;VYS92D["B`@("`@("`@("`@(&9C;&]S92@D9G`I
M.PH*("`@("`@("`@("`@)&9P(#T@0&9O<&5N*"1T:&ES+3Y?9&5B=6=$:7(@
M+B`G+W-Y;F-M;"YP86-K971N=6TG+"`G=R<I.PH@("`@("`@("`@("!I9B`H
M)&9P*2!["B`@("`@("`@("`@("`@("!F=W)I=&4H)&9P+"`K*R1P86-K971.
M=6TI.PH@("`@("`@("`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@("`@("`@
M('T*"B`@("`@("`@?0H*("`@("`@("`O*B!#;&5A<B!T:&4@;W5T<'5T(&)U
M9F9E<B!T:&%T('=E('-T87)T960@86)O=F4L(&%N9"!L;V<@86YY=&AI;F<*
M("`@("`@("`@*B!T:&%T(&-A;64@=7`@9F]R(&QA=&5R(&1E8G5G9VEN9RX@
M*B\*("`@("`@("`D97)R;W),;V=G:6YG(#T@;V)?9V5T7V-L96%N*"D["B`@
M("`@("`@:68@*"%E;7!T>2@D97)R;W),;V=G:6YG*2D@>PH@("`@("`@("`@
M("!(;W)D93HZ;&]G365S<V%G92@G4WEN8TU,.B!C875G:'0@;W5T<'5T/2<@
M+B`D97)R;W),;V=G:6YG+`H@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D<F5S<&]N<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!#;VYT96YT+51Y<&4@;V8@=&AE(')E<W!O;G-E+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@34E-12!#;VYT96YT+51Y<&4@;V8@=&AE
M(%)00R!R97-P;VYS92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F5S<&]N
M<V5#;VYT96YT5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=A<'!L:6-A
M=&EO;B]V;F0N<WEN8VUL*W=B>&UL)SL*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4E!#+W=E8F1A
M=BYP:'``````````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$U-C0U
M`#$P-3$U-#,S-S4P`#`R,C$P,@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H*:6YC;'5D95]O;F-E("=(5%10+U=E
M8D1!5B]397)V97(N<&AP)SL*"B\J*@H@*B!4:&4@2&]R9&5?4E!#7W=E8F1A
M=B!C;&%S<R!P<F]V:61E<R!A(%=E8D1!5B!I;7!L96UE;G1A=&EO;B!O9B!T
M:&4*("H@2&]R9&4@4E!#('-Y<W1E;2X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO4E!#+U)00R]W96)D878N<&AP+'8@,2XQ+C$R+C8@,C`P-B\P,2\P,2`R
M,3HR.#HS,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?
M4E!#"B`J+PIC;&%S<R!(;W)D95]24$-?=V5B9&%V(&5X=&5N9',@2&]R9&5?
M4E!#('L*"B`@("`O*BH*("`@("`J(%)E<V]U<F-E(&AA;F1L97(@9F]R('1H
M92!796)$058@<V5R=F5R+@H@("`@("H*("`@("`J($!V87(@2%144%]796)$
M059?4V5R=F5R7TAO<F1E"B`@("`@*B\*("`@('9A<B`D7W-E<G9E<CL*"B`@
M("`O*BH*("`@("`J(%=E8D1A=B!S97)V97(@8V]N<W1R=6-T;W(N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N
M($AO<F1E7U)00U]W96)D878H*0H@("`@>PH@("`@("`@('!A<F5N=#HZ2&]R
M9&5?4E!#*"D["@H@("`@("`@("1T:&ES+3Y?<V5R=F5R(#T@)FYE=R!(5%10
M7U=E8D1!5E]397)V97)?2&]R9&4H*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E;F1S(&%N(%)00R!R97%U97-T('1O('1H92!S97)V97(@86YD(')E='5R
M;G,@=&AE(')E<W5L="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("!4
M:&4@<F%W(')E<75E<W0@<W1R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@6$U,(&5N8V]D960@<F5S<&]N<V4@9G)O;2!T:&4@<V5R
M=F5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971297-P;VYS92@D<F5Q=65S
M="D*("`@('L*("`@("`@("`D=&AI<RT^7W-E<G9E<BT^4V5R=F5297%U97-T
M*"D["B`@("`@("`@97AI=#L*("`@('T*"B`@("`O*BH*("`@("`J(%=E8D1!
M5B!H86YD;&5S(&%U=&AE;G1I8V%T:6]N(&EN=&5R;F%L;'DL('-O(&)Y<&%S
M<R!T:&4*("`@("`J('-Y<W1E;2UL979E;"!A=71H(&-H96-K(&)Y(&IU<W0@
M<F5T=7)N:6YG('1R=64@:&5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@875T
M:&]R:7IE*"D*("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"GT*
M"B\J*@H@*B!(;W)D92!E>'1E;G-I;VX@;V8@=&AE(&)A<V4@2%144%]796)$
M059?4V5R=F5R(&-L87-S+@H@*@H@*B!`<&%C:V%G92!(;W)D95]24$,*("HO
M"F-L87-S($A45%!?5V5B1$%67U-E<G9E<E](;W)D92!E>'1E;F1S($A45%!?
M5V5B1$%67U-E<G9E<B!["@H@("`@+RHJ"B`@("`@*B!296%L;2!S=')I;F<@
M=&\@8F4@=7-E9"!I;B!A=71H96YT:69I8V%T:6]N('!O<'5P<PH@("`@("H*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D:'1T<%]A=71H
M7W)E86QM(#T@)TAO<F1E(%=E8D1!5B<["@H@("`@+RHJ"B`@("`@*B!3=')I
M;F<@=&\@8F4@=7-E9"!I;B`B6"U$878M4&]W97)E9"U">2(@:&5A9&5R"B`@
M("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1D879?
M<&]W97)E9%]B>2`]("=(;W)D92!796)$058@4V5R=F5R)SL*"B`@("`O*BH*
M("`@("`J($=%5"!I;7!L96UE;G1A=&EO;BX*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)&]P=&EO;G,@($%R<F%Y(&]F(&EN<'5T(&%N9"!O=71P=70@
M<&%R86UE=&5R<RX*("`@("`J(#QB<CX\<W1R;VYG/FEN<'5T/"]S=')O;F<^
M/'5L/@H@("`@("H@/&QI/B!P871H("T*("`@("`J(#PO=6P^"B`@("`@*B`\
M8G(^/'-T<F]N9SYO=71P=70\+W-T<F]N9SX\=6P^"B`@("`@*B`\;&D^('-I
M>F4@+0H@("`@("H@/"]U;#X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G
M97(@($A45%`M4W1A='5S8V]D92X*("`@("`J+PH@("`@9G5N8W1I;VX@1T54
M*"8D;W!T:6]N<RD*("`@('L*("`@("`@("!I9B`H)&]P=&EO;G-;)W!A=&@G
M72`]/2`G+R<I('L*("`@("`@("`@("`@)&]P=&EO;G-;)VUI;65T>7!E)UT@
M/2`G:'1T<&0O=6YI>"UD:7)E8W1O<GDG.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1O<'1I;VYS(#T@)'1H:7,M/E]L:7-T*"1O<'1I;VYS6R=P
M871H)UTL(#`I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!0550@;65T:&]D(&AA;F1L97(*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)B1O<'1I;VYS("!087)A;65T97(@<&%S
M<VEN9R!A<G)A>2X*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S
M=6-C97-S+@H@("`@("HO"B`@("!F=6YC=&EO;B!0550H)B1O<'1I;VYS*0H@
M("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4%)/4$9)3D0@;65T:&]D(&AA;F1L97(*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)&]P=&EO;G,@($=E;F5R86P@<&%R86UE=&5R('!A<W-I;F<@
M87)R87DN"B`@("`@*B!`<&%R86T@87)R87D@)B1F:6QE<R`@4F5T=7)N(&%R
M<F%Y(&9O<B!F:6QE('!R;W!E<G1I97,N"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@(%1R=64@;VX@<W5C8V5S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@4%)/
M4$9)3D0H)&]P=&EO;G,L("8D9FEL97,I"B`@("!["B`@("`@("`@)&QI<W0@
M/2`D=&AI<RT^7VQI<W0H)&]P=&EO;G-;)W!A=&@G72P@)&]P=&EO;G-;)V1E
M<'1H)UTI.PH@("`@("`@(&EF("@D;&ES="`]/3T@9F%L<V4I('L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("`D9FEL97-;
M)V9I;&5S)UT@/2`D;&ES=#L*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("!F=6YC=&EO;B!?;&ES="@D<&%T:"P@)&1E<'1H*0H@("`@>PH@("`@
M("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@("1L:7-T(#T@87)R87DH
M"B`@("`@("`@("`@(&%R<F%Y*"=P871H)R`]/B`D=&AI<RT^<&%T:"P*("`@
M("`@("`@("`@("`@("=P<F]P<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/FUK<')O<"@G9&ES<&QA>6YA;64G+"`D=&AI<RT^<&%T
M:"DL"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUK<')O<"@G8W)E871I
M;VYD871E)RP@=&EM92@I*2P*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M;6MP<F]P*"=G971L87-T;6]D:69I960G+"!T:6UE*"DI+`H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YM:W!R;W`H)W)E<V]U<F-E='EP92<L("=C;VQL
M96-T:6]N)RDL"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUK<')O<"@G
M9V5T8V]N=&5N='1Y<&4G+"`G:'1T<&0O=6YI>"UD:7)E8W1O<GDG*2P*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^;6MP<F]P*"=G971C;VYT96YT;&5N
M9W1H)RP@,"DI*2D["B`@("`@("`@:68@*"1P871H(#T]("<O)RD@>PH@("`@
M("`@("`@("`D87!P<R`]("1R96=I<W1R>2T^;&ES=$%P<',H;G5L;"P@9F%L
M<V4L(%!%4DU37U)%040I.PH@("`@("`@("`@("!I9B`H:7-?82@D87!P<RP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<F5A8V@@*"1A<'!S(&%S
M("1A<'`I('L*("`@("`@("`@("`@("`@(&EF("@D<F5G:7-T<GDM/FAA<TUE
M=&AO9"@G8G)O=W-E)RP@)&%P<"DI('L*("`@("`@("`@("`@("`@("`@("`D
M<')O<',@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/FUK<')O<"@G9&ES<&QA>6YA;64G+"!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T
M*"1R96=I<W1R>2T^9V5T*"=N86UE)RP@)&%P<"DL($Y,4SHZ9V5T0VAA<G-E
M="@I+"`G551&+3@G*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YM:W!R;W`H)V-R96%T:6]N9&%T92<L('1I;64H*2DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YM:W!R;W`H)V=E=&QA<W1M;V1I9FEE9"<L
M('1I;64H*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM:W!R
M;W`H)W)E<V]U<F-E='EP92<L("=C;VQL96-T:6]N)RDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YM:W!R;W`H)V=E=&-O;G1E;G1T>7!E)RP@
M)VAT='!D+W5N:7@M9&ER96-T;W)Y)RDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YM:W!R;W`H)V=E=&-O;G1E;G1L96YG=&@G+"`P*2D["B`@
M("`@("`@("`@("`@("`@("`@)&ET96T@/2!A<G)A>2@G<&%T:"<@/3X@)'1H
M:7,M/G!A=&@@+B`G+R<@+B`D87!P+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W!R;W!S)R`]/B`D<')O<',I.PH@("`@("`@("`@("`@
M("`@("`@("1L:7-T6UT@/2`D:71E;3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("AS
M=6)S='(H)'!A=&@L(#`L(#$I(#T]("<O)RD@>PH@("`@("`@("`@("`@("`@
M)'!A=&@@/2!S=6)S='(H)'!A=&@L(#$I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1P:65C97,@/2!E>'!L;V1E*"<O)RP@)'!A=&@I.PH@("`@("`@
M("`@("`D:71E;7,@/2`D<F5G:7-T<GDM/F-A;&Q">5!A8VMA9V4H)'!I96-E
M<ULP72P@)V)R;W=S92<L(&%R<F%Y*"=P871H)R`]/B`D<&%T:"P@)W!R;W!E
M<G1I97,G(#T^(&%R<F%Y*"=N86UE)RP@)V)R;W=S96%B;&4G+"`G8V]N=&5N
M='1Y<&4G+"`G8V]N=&5N=&QE;F=T:"<L("=C<F5A=&5D)RP@)VUO9&EF:65D
M)RDI*3L*("`@("`@("`@("`@:68@*&ES7V$H)&ET96US+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2AR97-E="@D:71E;7,I
M*2D@>PH@("`@("`@("`@("`@("`@+RH@5V4@<F5T=7)N(&%N(&]B:F5C="=S
M(&-O;G1E;G0N("HO"B`@("`@("`@("`@("`@("!R971U<FX@)&ET96US.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<F5A8V@@*"1I=&5M<R!A<R`D
M<W5B7W!A=&@@/3X@)&DI('L*("`@("`@("`@("`@("`@("1P<F]P<R`](&%R
M<F%Y*`H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM:W!R;W`H)V1I<W!L
M87EN86UE)RP@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D:5LG;F%M92==+"!.
M3%,Z.F=E=$-H87)S970H*2P@)U541BTX)RDI+`H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YM:W!R;W`H)V-R96%T:6]N9&%T92<L(&5M<'1Y*"1I6R=C
M<F5A=&5D)UTI(#\@,"`Z("1I6R=C<F5A=&5D)UTI+`H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YM:W!R;W`H)V=E=&QA<W1M;V1I9FEE9"<L(&5M<'1Y
M*"1I6R=M;V1I9FEE9"==*2`_(#`@.B`D:5LG;6]D:69I960G72DL"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/FUK<')O<"@G<F5S;W5R8V5T>7!E)RP@
M)&E;)V)R;W=S96%B;&4G72`_("=C;VQL96-T:6]N)R`Z("<G*2P*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^;6MP<F]P*"=G971C;VYT96YT='EP92<L
M("1I6R=B<F]W<V5A8FQE)UT@/R`G:'1T<&0O=6YI>"UD:7)E8W1O<GDG(#H@
M*&5M<'1Y*"1I6R=C;VYT96YT='EP92==*2`_("=A<'!L:6-A=&EO;B]O8W1E
M="US=')E86TG(#H@)&E;)V-O;G1E;G1T>7!E)UTI*2P*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^;6MP<F]P*"=G971C;VYT96YT;&5N9W1H)RP@96UP
M='DH)&E;)V-O;G1E;G1L96YG=&@G72D@/R`P(#H@)&E;)V-O;G1E;G1L96YG
M=&@G72DI.PH@("`@("`@("`@("`@("`@)&ET96T@/2!A<G)A>2@G<&%T:"<@
M/3X@)R\G("X@)'-U8E]P871H+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G<')O<',G(#T^("1P<F]P<RD["B`@("`@("`@("`@("`@("`D;&ES
M=%M=(#T@)&ET96T["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(&EF("@D9&5P=&@I('L*("`@("`@("`@("`@:68@*"1D97!T:"`]/2`Q*2![
M"B`@("`@("`@("`@("`@("`D9&5P=&@@/2`P.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1L:7-T(&%S("1A<'`@/3X@)&ET96TI('L*
M("`@("`@("`@("`@("`@("\O7VQI<W0H)'!A=&@@+B`G+R<@+B`D:71E;2P@
M)&1E<'1H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1L:7-T.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VL@875T:&5N
M=&EC871I;VXN(%=E(&%L=V%Y<R!R971U<FX@=')U92!H97)E('-I;F-E('=E
M"B`@("`@*B!H86YD;&4@<&5R;6ES<VEO;G,@8F%S960@;VX@=&AE(')E<V]U
M<F-E('1H870G<R!R97%U97-T960L(&)U=`H@("`@("H@=V4@9&\@<F5C;W)D
M('1H92!A=71H96YT:6-A=&5D('5S97(@9F]R(&QA=&5R('5S92X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("`@("`@075T:&5N=&EC871I
M;VX@='EP92P@92YG+B`B8F%S:6,B(&]R(")D:6=E<W0B"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1U<V5R;F%M92`@5')A;G-M:71T960@=7-E<FYA;64N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P87-S=V]R9"`@5')A;G-M:71T960@<&%S
M<W=O<F0N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!!=71H96YT
M:6-A=&EO;B!S=&%T=7,N($%L=V%Y<R!T<G5E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!C:&5C:U]A=71H*"1T>7!E+"`D=7-E<FYA;64L("1P87-S=V]R9"D*
M("`@('L*("`@("`@("`D875T:"`]("9!=71H.CIS:6YG;&5T;VXH)$=,3T)!
M3%-;)V-O;F8G75LG875T:"==6R=D<FEV97(G72D["B`@("`@("`@<F5T=7)N
M("1A=71H+3YA=71H96YT:6-A=&4H)'5S97)N86UE+"!A<G)A>2@G<&%S<W=O
M<F0G(#T^("1P87-S=V]R9"DI.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'``````````````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$S,3$V`#$P-3$U-#,S-S4P`#`R
M,C$R-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@5&AE($AO<F1E7U)00U]X;6QR<&,@8VQA<W,@<')O
M=FED97,@86X@6$U,4E!#(&EM<&QE;65N=&%T:6]N(&]F('1H90H@*B!(;W)D
M92!24$,@<WES=&5M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]24$,O4E!#
M+WAM;')P8RYP:'`L=B`Q+CDN,3`N."`R,#`V+S`W+S`Q(#`T.C4T.C$V(&-H
M=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@2F%N(%-C:&YE
M:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@
M($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]24$,*("HO"F-L87-S($AO
M<F1E7U)00U]X;6QR<&,@97AT96YD<R!(;W)D95]24$,@>PH*("`@("\J*@H@
M("`@("H@4F5S;W5R8V4@:&%N9&QE<B!F;W(@=&AE(%A-3%)00R!S97)V97(N
M"B`@("`@*@H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@
M)%]S97)V97(["@H@("`@+RHJ"B`@("`@*B!834Q24$,@<V5R=F5R(&-O;G-T
M<G5C=&]R"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@(&9U;F-T:6]N($AO<F1E7U)00U]X;6QR<&,H*0H@("`@>PH@("`@("`@
M('!A<F5N=#HZ2&]R9&5?4E!#*"D["@H@("`@("`@("1T:&ES+3Y?<V5R=F5R
M(#T@>&UL<G!C7W-E<G9E<E]C<F5A=&4H*3L*"B`@("`@("`@9F]R96%C:"`H
M)$=,3T)!3%-;)W)E9VES=')Y)UTM/FQI<W1-971H;V1S*"D@87,@)&UE=&AO
M9"D@>PH@("`@("`@("`@("!X;6QR<&-?<V5R=F5R7W)E9VES=&5R7VUE=&AO
M9"@D=&AI<RT^7W-E<G9E<BP@<W1R7W)E<&QA8V4H)R\G+"`G+B<L("1M971H
M;V0I+"!A<G)A>2@G2&]R9&5?4E!#7WAM;')P8R<L("=?9&ES<&%T8VAE<B<I
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&5A;G,@=7`@
M=&AE(%)00R!S97)V97(N"B`@("`@*B\*("`@(&9U;F-T:6]N('-H=71D;W=N
M*"D*("`@('L*("`@("`@("!X;6QR<&-?<V5R=F5R7V1E<W1R;WDH)'1H:7,M
M/E]S97)V97(I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5N9',@86X@4E!#
M(')E<75E<W0@=&\@=&AE('-E<G9E<B!A;F0@<F5T=7)N<R!T:&4@<F5S=6QT
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@(%1H92!R87<@<F5Q=65S
M="!S=')I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!8
M34P@96YC;V1E9"!R97-P;VYS92!F<F]M('1H92!S97)V97(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%)E<W!O;G-E*"1R97%U97-T*0H@("`@>PH@("`@
M("`@("1R97-P;VYS92`](&YU;&P["B`@("`@("`@<F5T=7)N('AM;')P8U]S
M97)V97)?8V%L;%]M971H;V0H)'1H:7,M/E]S97)V97(L("1R97%U97-T+"`D
M<F5S<&]N<V4I.PH@("`@?0H*("`@("\J*@H@("`@("H@5VEL;"!B92!R96=I
M<W1E<F5D(&%S('1H92!H86YD;&5R(&9O<B!A;&P@879A:6QA8FQE(&UE=&AO
M9',*("`@("`J(&%N9"!W:6QL(&-A;&P@=&AE(&%P<')O<')I871E(&9U;F-T
M:6]N('1H<F]U9V@@=&AE(')E9VES=')Y+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UE=&AO
M9"`@5&AE(&YA;64@;V8@=&AE(&UE=&AO9"!C86QL960@8GD@=&AE(%)00R!R
M97%U97-T+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("!4:&4@<&%S
M<V5D('!A<F%M971E<G,N"B`@("`@*B!`<&%R86T@;6EX960@)&1A=&$@("`@
M(%5N:VYO=VXN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(')E
M<W5L="!O9B!T:&4@8V%L;&5D(')E9VES=')Y(&UE=&AO9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V1I<W!A=&-H97(H)&UE=&AO9"P@)'!A<F%M<RP@)&1A
M=&$I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@
M)&UE=&AO9"`]('-T<E]R97!L86-E*"<N)RP@)R\G+"`D;65T:&]D*3L*("`@
M("`@("!I9B`H(21R96=I<W1R>2T^:&%S365T:&]D*"1M971H;V0I*2!["B`@
M("`@("`@("`@(')E='5R;B!S<')I;G1F*%\H(DUE=&AO9"!<(B5S7"(@:7,@
M;F]T(&1E9FEN960B*2P@)&UE=&AO9"D["B`@("`@("`@?0H*("`@("`@("`D
M<F5S=6QT(#T@)')E9VES=')Y+3YC86QL*"1M971H;V0L("1P87)A;7,I.PH@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@)')E<W5L="`](&%R<F%Y*"=F875L=$-O9&4G(#T^("AI;G0I
M)')E<W5L="T^9V5T0V]D92@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V9A=6QT4W1R:6YG)R`]/B`D<F5S=6QT+3YG971-97-S86=E*"DI.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!"=6EL9',@86X@6$U,4E!#(')E<75E<W0@86YD('-E;F1S
M(&ET('1O('1H92!834Q24$,@<V5R=F5R+@H@("`@("H*("`@("`J(%1H:7,@
M<W1A=&EC86QL>2!C86QL960@;65T:&]D(&ES(&%C='5A;&QY('1H92!834Q2
M4$,@8VQI96YT+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5R;"`@
M("`@5&AE('!A=&@@=&\@=&AE(%A-3%)00R!S97)V97(@;VX@=&AE(&-A;&QE
M9"!H;W-T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65T:&]D("!4:&4@;65T
M:&]D('1O(&-A;&PN"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@($$@
M:&%S:"!C;VYT86EN:6YG(&%N>2!N96-E<W-A<GD@<&%R86UE=&5R<R!F;W(*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&UE=&AO9"!C86QL
M+@H@("`@("H@0'!A<F%M("1O<'1I;VYS("!/<'1I;VYA;"!A<W-O8VEA=&EV
M92!A<G)A>2!O9B!P87)A;65T97)S('=H:6-H(&-A;B!B93H*("`@("`J("`@
M("`@("`@("`@("`@("`@=7-E<B`@("`@("`@("`@+2!"87-I8R!!=71H('5S
M97)N86UE"B`@("`@*B`@("`@("`@("`@("`@("`@('!A<W,@("`@("`@("`@
M("T@0F%S:6,@075T:"!P87-S=V]R9`H@("`@("H@("`@("`@("`@("`@("`@
M("!P<F]X>5]H;W-T("`@("`M(%!R;WAY('-E<G9E<B!H;W-T"B`@("`@*B`@
M("`@("`@("`@("`@("`@('!R;WAY7W!O<G0@("`@("T@4')O>'D@<V5R=F5R
M('!O<G0*("`@("`J("`@("`@("`@("`@("`@("`@<')O>'E?=7-E<B`@("`@
M+2!0<F]X>2!A=71H('5S97)N86UE"B`@("`@*B`@("`@("`@("`@("`@("`@
M('!R;WAY7W!A<W,@("`@("T@4')O>'D@875T:"!P87-S=V]R9`H@("`@("H@
M("`@("`@("`@("`@("`@("!T:6UE;W5T("`@("`@("`M($-O;FYE8W1I;VX@
M=&EM96]U="!I;B!S96-O;F1S+@H@("`@("H@("`@("`@("`@("`@("`@("!A
M;&QO=U)E9&ER96-T<R`M(%=H971H97(@=&\@9F]L;&]W(')E9&ER96-T<R!O
M<B!N;W0*("`@("`J("`@("`@("`@("`@("`@("`@;6%X4F5D:7)E8W1S("`@
M+2!-87@@;G5M8F5R(&]F(')E9&ER96-T<R!T;R!F;VQL;W<*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("`@("`@("`@("`@5&AE(')E='5R;F5D(')E
M<W5L="!F<F]M('1H92!M971H;V0@;W(@82!014%2"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@97)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E<75E<W0H)'5R;"P@)&UE=&AO9"P@)'!A
M<F%M<R`](&YU;&PL("1O<'1I;VYS(#T@87)R87DH*2D*("`@('L*("`@("`@
M("`D;W!T:6]N<ULG;65T:&]D)UT@/2`G4$]35"<["B`@("`@("`@)&QA;F=U
M86=E(#T@:7-S970H)$=,3T)!3%-;)VQA;F=U86=E)UTI(#\@)$=,3T)!3%-;
M)VQA;F=U86=E)UT@.@H@("`@("`@("`@("`@("`@("`@("AI<W-E="@D7U-%
M4E9%4ELG3$%.1R==*2`_("1?4T525D526R=,04Y')UT@.B`G)RD["@H@("`@
M("`@(&EF("@A:7-S970H)&]P=&EO;G-;)W1I;65O=70G72DI('L*("`@("`@
M("`@("`@)&]P=&EO;G-;)W1I;65O=70G72`](#4["B`@("`@("`@?0H@("`@
M("`@(&EF("@A:7-S970H)&]P=&EO;G-;)V%L;&]W4F5D:7)E8W1S)UTI*2![
M"B`@("`@("`@("`@("1O<'1I;VYS6R=A;&QO=U)E9&ER96-T<R==(#T@=')U
M93L*("`@("`@("`@("`@)&]P=&EO;G-;)VUA>%)E9&ER96-T<R==(#T@,SL*
M("`@("`@("!]"@H@("`@("`@(')E<75I<F5?;VYC92`G2%144"]297%U97-T
M+G!H<"<["@H@("`@("`@("1H='1P(#T@)FYE=R!(5%107U)E<75E<W0H)'5R
M;"P@)&]P=&EO;G,I.PH@("`@("`@(&EF("@A96UP='DH)&QA;F=U86=E*2D@
M>PH@("`@("`@("`@("`D:'1T<"T^861D2&5A9&5R*"=!8V-E<'0M3&%N9W5A
M9V4G+"`D;&%N9W5A9V4I.PH@("`@("`@('T*("`@("`@("`D:'1T<"T^861D
M2&5A9&5R*"=5<V5R+4%G96YT)RP@)TAO<F1E(%)00R!C;&EE;G0G*3L*("`@
M("`@("`D:'1T<"T^861D2&5A9&5R*"=#;VYT96YT+51Y<&4G+"`G=&5X="]X
M;6PG*3L*("`@("`@("`D:'1T<"T^861D4F%W4&]S=$1A=&$H>&UL<G!C7V5N
M8V]D95]R97%U97-T*"1M971H;V0L("1P87)A;7,I*3L*"B`@("`@("`@)')E
M<W5L="`]("1H='1P+3YS96YD4F5Q=65S="@I.PH@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@?2!E;'-E:68@*"1H='1P+3YG971297-P;VYS
M94-O9&4H*2`A/2`R,#`I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H7R@B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T
M=7)N960@97)R;W)C;V1E.B`B*2`N("1H='1P+3YG971297-P;VYS94-O9&4H
M*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D
M:'1T<"T^9V5T4F5S<&]N<V5";V1Y*"DL("<\/WAM;"<I(#T]/2!F86QS92D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;R!V
M86QI9"!834P@9&%T82!R971U<FYE9"(I+"`G:&]R9&4N97)R;W(G+"!N=6QL
M+"!N=6QL+"`D:'1T<"T^9V5T4F5S<&]N<V5";V1Y*"DI.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1R97-P;VYS92`]($!X;6QR<&-?9&5C;V1E
M*'-U8G-T<B@D:'1T<"T^9V5T4F5S<&]N<V5";V1Y*"DL('-T<G!O<R@D:'1T
M<"T^9V5T4F5S<&]N<V5";V1Y*"DL("<\/WAM;"<I*2D["B`@("`@("`@("`@
M(&EF("AI<U]A<G)A>2@D<F5S<&]N<V4I("8F(&ES<V5T*"1R97-P;VYS95LG
M9F%U;'13=')I;F<G72DI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"1R97-P;VYS95LG9F%U;'13=')I;F<G72P@)VAO<F1E
M+F5R<F]R)RD["B`@("`@("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D<F5S
M<&]N<V4I("8F(&ES<V5T*"1R97-P;VYS95LP72D@)B8*("`@("`@("`@("`@
M("`@("`@("`@(&ES7V%R<F%Y*"1R97-P;VYS95LP72D@)B8@:7-S970H)')E
M<W!O;G-E6S!=6R=F875L=%-T<FEN9R==*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)')E<W!O;G-E6S!=6R=F875L=%-T
M<FEN9R==+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!R971U<FX@)')E<W!O;G-E.PH@("`@("`@('T*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]24$,N<&AP````````````````````````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C`Q,#,`,3`U,34T,S,W-3(`,#(P-C$U
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!4:&4@2&]R9&5?4E!#.CH@8VQA<W,@<')O=FED97,@82!S
M970@;V8@<V5R=F5R(&%N9"!C;&EE;G0@;65T:&]D<R!F;W(*("H@4E!#(&-O
M;6UU;FEC871I;VXN"B`J"B`J(%1/1$\Z"B`J("T@26YT<F]S<&5C=&EO;B!D
M;V-U;65N=&%T:6]N(&%N9"!M971H;V0@<VEG;F%T=7)E<RX*("H*("H@15A!
M35!,13H*("H@/&-O9&4^"B`J("1R97-P;VYS92`]($AO<F1E7U)00SHZ<F5Q
M=65S="@G>&UL<G!C)RP*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=H='1P.B\O;&]C86QH;W-T.C@P+VAO<F1E+W)P8RYP:'`G"B`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8V]N=&%C=',N<V5A<F-H
M)RP*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*&%R
M<F%Y*"=J86XG*2P@87)R87DH)VQO8V%L<W%L)RDL"B`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G;F%M92<L("=E;6%I
M;"<I*2P*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=U<V5R)R`]/B!!=71H.CIG971!=71H*"DL"B`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<&%S<R<@/3X@075T:#HZ9V5T0W)E
M9&5N=&EA;"@G<&%S<W=O<F0G*2DI.PH@*B`\+V-O9&4^"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+U)00R]24$,N<&AP+'8@,2XW+C$P+C@@,C`P-B\P,2\P
M,2`R,3HR.#HS,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P
M-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*
M("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U)00PH@
M*B\*8VQA<W,@2&]R9&5?4E!#('L*"B`@("`O*BH*("`@("`J(%=H971H97(@
M=V4@;F5E9"!A;B!A=71H;W)I>F5D('5S97(@;W(@;F]T+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B!`=F%R(&)O;VQE86X*("`@
M("`J+PH@("`@=F%R("1?875T:&]R:7IE(#T@=')U93L*"B`@("`O*BH*("`@
M("`J(%)00R!S97)V97(@8V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J($!R971U<FX@;V)J96-T("`@06X@4E!#('-E
M<G9E<B!I;G-T86YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?4E!#
M*"D*("`@('L*("`@("`@("!R96=I<W1E<E]S:'5T9&]W;E]F=6YC=&EO;BAA
M<G)A>2@D=&AI<RP@)W-H=71D;W=N)RDI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0VQE86YS('5P('1H92!24$,@<V5R=F5R+@H@("`@("H*("`@("`J($!A
M8G-T<F%C=`H@("`@("HO"B`@("!F=6YC=&EO;B!S:'5T9&]W;B@I"B`@("![
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:R!A=71H96YT:6-A=&EO;BX@
M1&EF9F5R96YT(&)A8VME;F1S(&UA>2!H86YD;&4*("`@("`J(&%U=&AE;G1I
M8V%T:6]N(&EN(&1I9F9E<F5N="!W87ES+B!4:&4@8F%S92!C;&%S<R!I;7!L
M96UE;G1A=&EO;@H@("`@("H@8VAE8VMS(&9O<B!(5%10($%U=&AE;G1I8V%T
M:6]N(&%G86EN<W0@=&AE($AO<F1E(&%U=&@@<V5T=7`N"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!2971U<FYS('1R=64@:68@875T:&5N=&EC
M871I;VX@:7,@<W5C8V5S<V9U;"X*("`@("`J("`@("`@("`@("`@("`@("`@
M4VAO=6QD('-E;F0@87!P<F]P<FEA=&4@(FYO="!A=71H;W)I>F5D(B!H96%D
M97)S"B`@("`@*B`@("`@("`@("`@("`@("`@(&]R(&]T:&5R(')E<W!O;G-E
M(&-O9&5S+V)O9'D@:68@875T:"!F86EL<RP*("`@("`J("`@("`@("`@("`@
M("`@("`@86YD('1A:V4@8V%R92!O9B!E>&ET:6YG+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!A=71H;W)I>F4H*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M
M/E]A=71H;W)I>F4I('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@
M("`@?0H*("`@("`@("`D875T:"`]("9!=71H.CIS:6YG;&5T;VXH)$=,3T)!
M3%-;)V-O;F8G75LG875T:"==6R=D<FEV97(G72D["@H@("`@("`@(&EF("AI
M<W-E="@D7U-%4E9%4ELG4$A07T%55$A?55-%4B==*2D@>PH@("`@("`@("`@
M("`D=7-E<B`]("1?4T525D526R=02%!?05542%]54T52)UT["B`@("`@("`@
M("`@("1P87-S(#T@)%]315)615);)U!(4%]!551(7U!7)UT["B`@("`@("`@
M?0H*("`@("`@("!I9B`H(6ES<V5T*"1U<V5R*0H@("`@("`@("`@("!\?"`A
M)&%U=&@M/F%U=&AE;G1I8V%T92@D=7-E<BP@87)R87DH)W!A<W-W;W)D)R`]
M/B`D<&%S<RDI*2!["B`@("`@("`@("`@(&AE861E<B@G5U=7+4%U=&AE;G1I
M8V%T93H@0F%S:6,@<F5A;&T](DAO<F1E(%)00R(G*3L*("`@("`@("`@("`@
M:&5A9&5R*"=(5%10+S$N,"`T,#$@56YA=71H;W)I>F5D)RD["B`@("`@("`@
M("`@(&5C:&\@)S0P,2!5;F%U=&AO<FEZ960G.PH@("`@("`@("`@("!E>&ET
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'970@=&AE(')E<75E<W0@8F]D>2!I;G!U="X@1&EF9F5R
M96YT(%)00R!B86-K96YD<R!C86X@;W9E<G)I9&4*("`@("`J('1H:7,@=&\@
M<F5T=7)N(&%N(&]P96X@<W1R96%M('1O('!H<#HO+W-T9&EN+"!F;W(@:6YS
M=&%N8V4@+0H@("`@("H@=VAA=&5V97(@:7,@96%S:65S="!T;R!H86YD;&4@
M:6X@=&AE(&=E=%)E<W!O;G-E*"D@;65T:&]D+@H@("`@("H*("`@("`J(%1H
M92!B87-E(&-L87-S(&EM<&QE;65N=&%T:6]N(&QO;VMS(&9O<B`D2%144%]2
M05=?4$]35%]$051!(&%N9`H@("`@("H@<F5T=7)N<R!T:&%T(&EF(&ET)W,@
M879A:6QA8FQE.R!O=&AE<G=I<V4L(&ET(')E='5R;G,@=&AE"B`@("`@*B!C
M;VYT96YT<R!O9B!P:'`Z+R]S=&1I;BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4:&4@:6YP=70@+2!A('-T<FEN9R`H9&5F875L="DL(&$@9FEL
M96AA;F1L92P@971C+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971);G!U="@I
M"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1'3$]"04Q36R=(5%107U)!5U]0
M3U-47T1!5$$G72DI('L*("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q36R=(
M5%107U)!5U]03U-47T1!5$$G73L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@:6UP;&]D92@B7')<;B(L(&9I;&4H)W!H<#HO+VEN<'5T
M)RDI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E;F1S(&%N
M(%)00R!R97%U97-T('1O('1H92!S97)V97(@86YD(')E='5R;G,@=&AE(')E
M<W5L="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("!4:&4@<F%W(')E
M<75E<W0@<W1R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@6$U,(&5N8V]D960@<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971297-P;VYS92@D<F5Q=65S="D*("`@('L*
M("`@("`@("!R971U<FX@7R@B;F]T(&EM<&QE;65N=&5D(BD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!'970@=&AE($-O;G1E;G0M5'EP92!O9B!T:&4@<F5S
M<&]N<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!-24U%
M($-O;G1E;G0M5'EP92!O9B!T:&4@4E!#(')E<W!O;G-E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971297-P;VYS94-O;G1E;G14>7!E*"D*("`@('L*("`@
M("`@("!R971U<FX@)W1E>'0O>&UL)SL*("`@('T*"B`@("`O*BH*("`@("`J
M($)U:6QD<R!A;B!24$,@<F5Q=65S="!A;F0@<V5N9',@:70@=&\@=&AE(%)0
M0R!S97)V97(N"B`@("`@*@H@("`@("H@5&AI<R!S=&%T:6-A;&QY(&-A;&QE
M9"!M971H;V0@:7,@86-T=6%L;'D@=&AE(%)00R!C;&EE;G0N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9')I=F5R("`@(%1H92!P<F]T;V-O;"!D
M<FEV97(@=&\@=7-E+B!#=7)R96YT;'D@)W-O87`G"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@86YD("=X;6QR<&,G(&%R92!A=F%I;&%B;&4N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<FP@("`@("`@5&AE('!A=&@@=&\@
M=&AE(%)00R!S97)V97(@;VX@=&AE(&-A;&QE9"!H;W-T+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;65T:&]D("`@(%1H92!M971H;V0@=&\@8V%L;"X*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@("!!(&AA<V@@8V]N=&%I;FEN
M9R!A;GD@;F5C97-S87)Y('!A<F%M971E<G,@9F]R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@=&AE(&UE=&AO9"!C86QL+@H@("`@("H@0'!A
M<F%M("1O<'1I;VYS("`@("`@("`@($%S<V]C:6%T:79E(&%R<F%Y(&]F('!A
M<F%M971E<G,@9&5P96YD:6YG(&]N"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@=&AE('-E;&5C=&5D('!R;W1O8V]L(&1R:79E<BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("`@("`@("`@("`@5&AE(')E='5R;F5D
M(')E<W5L="!F<F]M('1H92!M971H;V0@;W(@82!014%2"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@97)R;W(@;V)J96-T(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E<75E<W0H)&1R:79E<BP@)'5R;"P@
M)&UE=&AO9"P@)'!A<F%M<R`](&YU;&PL("1O<'1I;VYS(#T@87)R87DH*2D*
M("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)&1R:79E<BDI('L*("`@("`@
M("`@("`@;&ES="@D87!P+"`D9')I=F5R*2`]("1D<FEV97(["B`@("`@("`@
M?0H*("`@("`@("`D9')I=F5R(#T@8F%S96YA;64H)&1R:79E<BD["@H@("`@
M("`@(&EF("@A96UP='DH)&%P<"DI('L*("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E("1A<'`@+B`G+VQI8B]24$,O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@
M("`@("`@?2!E;'-E:68@*$!F:6QE7V5X:7-T<RAD:7)N86UE*%]?1DE,15]?
M*2`N("<O4E!#+R<@+B`D9')I=F5R("X@)RYP:'`G*2D@>PH@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+U)00R\G("X@
M)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!`:6YC;'5D95]O;F-E("=(;W)D92]24$,O)R`N("1D<FEV97(@+B`G+G!H
M<"<["B`@("`@("`@?0H@("`@("`@("1C;&%S<R`]("=(;W)D95]24$-?)R`N
M("1D<FEV97(["B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2![
M"B`@("`@("`@("`@(')E='5R;B!C86QL7W5S97)?9G5N8RAA<G)A>2@D8VQA
M<W,L("=R97%U97-T)RDL("1U<FPL("1M971H;V0L("1P87)A;7,L("1O<'1I
M;VYS*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)U!%05(N<&AP)SL*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)T-L87-S(&1E9FEN:71I;VX@;V8@)R`N("1C;&%S<R`N("<@;F]T
M(&9O=6YD+B<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%T
M=&5M<'1S('1O(')E='5R;B!A(&-O;F-R971E(%)00R!S97)V97(@:6YS=&%N
M8V4@8F%S960@;VX*("`@("`J("1D<FEV97(N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&UI>&5D("1D<FEV97(@(%1H92!T>7!E(&]F(&-O;F-R971E(%)00R!S
M=6)C;&%S<R!T;R!R971U<FXN($EF"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@)&1R:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL(&QO;VL@
M:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`D9')I=F5R6S!=+VQI
M8B]24$,O(&9O<B!T:&4@<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D9')I=F5R6S%=+G!H<"X*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN
M9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S(&$@<W5B
M8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E
M7U)00R`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@2&]R9&5?4E!#('-E
M<G9E<B!I;G-T86YC92P*("`@("`J("`@("`@("`@("`@("`@("`@("!O<B!A
M(%!%05)?17)R;W(@;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9F86-T;W)Y*"1D<FEV97(L("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@
M("`@(&EF("AI<U]A<G)A>2@D9')I=F5R*2D@>PH@("`@("`@("`@("!L:7-T
M*"1A<'`L("1D<FEV97(I(#T@)&1R:79E<CL*("`@("`@("!]"@H@("`@("`@
M("1D<FEV97(@/2!B87-E;F%M92@D9')I=F5R*3L*"B`@("`@("`@:68@*"%E
M;7!T>2@D87!P*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)&%P<"`N
M("<O;&EB+U)00R\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L
M<V5I9B`H0&9I;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I("X@)R]24$,O
M)R`N("1D<FEV97(@+B`G+G!H<"<I*2!["B`@("`@("`@("`@(')E<75I<F5?
M;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O4E!#+R<@+B`D9')I=F5R("X@
M)RYP:'`G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@($!I;F-L=61E
M7V]N8V4@)TAO<F1E+U)00R\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@
M("!]"B`@("`@("`@)&-L87-S(#T@)TAO<F1E7U)00U\G("X@)&1R:79E<CL*
M("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@
M("`@)')P8R`]("9N97<@)&-L87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4BYP:'`G.PH@("`@
M("`@("`@("`D<G!C(#T@4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@9&5F:6YI
M=&EO;B!O9B`G("X@)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)')P8SL*("`@('T*"B`@("`O*BH*("`@("`J
M($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E
M(%)00R!S97)V97(*("`@("`J(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(N
M($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N8V4*("`@("`J(&EF
M(&YO(%)00R!S97)V97(@:6YS=&%N8V4@=VET:"!T:&4@<V%M92!P87)A;65T
M97)S(&-U<G)E;G1L>0H@("`@("H@97AI<W1S+@H@("`@("H*("`@("`J(%1H
M:7,@<VAO=6QD(&)E('5S960@:68@;75L=&EP;&4@4E!#('-E<G9E<G,@*&%N
M9"!T:'5S+"!M=6QT:7!L92!24$,*("`@("`J('-E<G9E<B!I;G-T86YC97,I
M(&%R92!R97%U:7)E9"X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T
M(&)E(&EN=F]K960@87,Z("1V87(@/2`F2&]R9&5?4E!#.CIS:6YG;&5T;VXH
M*0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1R:79E<B`@5&AE('1Y
M<&4@;V8@8V]N8W)E=&4@4E!#('-U8F-L87-S('1O(')E='5R;BX*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86US("`@02!H87-H(&-O;G1A:6YI;F<@86YY
M(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("!C;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S
M<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?4E!#
M("!4:&4@8V]N8W)E=&4@2&]R9&5?4E!#('-E<G9E<B!R969E<F5N8V4L(&]R
M(&$*("`@("`J("`@("`@("`@("`@("`@("`@("!014%27T5R<F]R(&]N(&%N
M(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV
M97(L("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@('-T871I8R`D:6YS
M=&%N8V5S.PH*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97,I*2!["B`@
M("`@("`@("`@("1I;G-T86YC97,@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@
M("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92AA<G)A>2@D9')I=F5R+"`D
M<&%R86US*2D["B`@("`@("`@:68@*"%A<G)A>5]K97E?97AI<W1S*"1S:6=N
M871U<F4L("1I;G-T86YC97,I*2!["B`@("`@("`@("`@("1I;G-T86YC97-;
M)'-I9VYA='5R95T@/2`F2&]R9&5?4E!#.CIF86-T;W)Y*"1D<FEV97(L("1P
M87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;
M)'-I9VYA='5R95T["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]38VAE9'5L97(O````````````````````````````````````
M````````````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-3$`,#(Q-#`Q`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U-C:&5D=6QE<B]C<F]N+G!H<```
M```````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R-C0R,``Q,#4Q-30S,S<U
M,0`P,C,P-3<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O4V-H961U;&5R+G!H
M<"<["G)E<75I<F5?;VYC92`G2&]R9&4O4W1R:6YG+G!H<"<["@HO*BH*("H@
M2&]R9&5?4V-H961U;&5R7V-R;VXZ.B!3;W)T(&]F(&$@8W)O;B!R97!L86-E
M;65N="!I;B!A(%!(4"!C;&D*("H@<V-R:7!T+@H@*@H@*B!$871E(%-Y;G1A
M>"!%>&%M<&QE<RX*("H*("H@4F5M96UB97(Z"B`J("`@+2!7:&ET97-P86-E
M("AS<&%C92P@=&%B+"!N97=L:6YE*2!D96QI;6ET960@9FEE;&1S"B`J("`@
M+2!3:6YG;&4@=F%L=65S+"!S971S+"!R86YG97,L('=I;&1C87)D<PH@*@H@
M*B!314-/3D0@("!-24Y55$4@("`@("`@("`@("`@($A/55(@("`@("`@($1!
M62`@("`@34].5$@*("H@*B`@("`@("`@*B`@("`@("`@("`@("`@("`@("`J
M("`@("`@("`@("`J("`@("`@("H@("`@("`@*&5V97)Y('-E8V]N9"D*("H@
M,"PS,"`@("`@*B`@("`@("`@("`@("`@("`@("`J("`@("`@("`@("`J("`@
M("`@("H@("`@("`@*&5V97)Y(#,P('-E8V]N9',I"B`J(#`@("`@("`@(#`L
M,3`L,C`L,S`L-#`L-3`@("`@*B`@("`@("`@("`@*B`@("`@("`J("`@("`@
M("AE=F5R>2`Q,"!M:6YU=&5S*0H@*B`P("`@("`@("`P("`@("`@("`@("`@
M("`@("`@("H@("`@("`@("`@("H@("`@("`@*B`@("`@("`H8F5G:6YN:6YG
M(&]F(&5V97)Y(&AO=7(I"B`J(#`@("`@("`@(#`@("`@("`@("`@("`@("`@
M("`@,"PV+#$R+#$X("`@*B`@("`@("`J("`@("`@("AA="!M:61N:6=H="P@
M-F%M+"!N;V]N+"`V<&TI"B`J(#`@("`@("`@(#`@("`@("`@("`@("`@("`@
M("`@,"`@("`@("`@("`@,2TW)D9R:2`J("`@("`@("AM:61N:6=H="P@9FER
M<W0@1G)I(&]F('1H92!M;VYT:"D*("H@,"`@("`@("`@,"`@("`@("`@("`@
M("`@("`@("`P("`@("`@("`@("`Q+3<A1G)I("H@("`@("`@*&UI9&YI9VAT
M+"!F:7)S="!-;VXM5&AU+%-A="U3=6X@;V8@=&AE(&UO;G1H*0H@*@H@*@H@
M*B!%>&%M<&QE('5S86=E.@H@*@H@*B!`<V5T7W1I;65?;&EM:70H,"D["B`J
M(')E<75I<F5?;VYC92`G2&]R9&4O4V-H961U;&5R+G!H<"<["B`J("1C<F]N
M(#T@)DAO<F1E7U-C:&5D=6QE<CHZ<VEN9VQE=&]N*"=C<F]N)RD["B`J"B`J
M("\O(%)U;B!T:&ES(&-O;6UA;F0@979E<GD@-2!M:6YU=&5S+@H@*B`D8W)O
M;BT^861D5&%S:R@G<&5R;"!S;VUE<V-R:7!T+G!L)RP@)S`@,"PU+#$P+#$U
M+#(P+#(U+#,P+#,U+#0P+#0U+#4P+#4U("H@*B`J)RD["B`J"B`J("\O(%)U
M;B!T:&ES(&-O;6UA;F0@;6ED;FEG:'0@;V8@=&AE(&9I<G-T($9R:61A>2!O
M9B!O9&0@;G5M8F5R960@;6]N=&AS+@H@*B`D8W)O;BT^861D5&%S:R@G<&AP
M("UQ('-O;65S8W)I<'0N<&AP)RP@)S`@,"`P(#$M-R9&<FD@,2PS+#4L-RPY
M+#$Q)RD["B`J"B`J("\O($%L<V\@<G5N('1H:7,@8V]M;6%N9"!M:61N:6=H
M="!O9B!T:&4@<V5C;VYD(%1H=7)S9&%Y(&%N9"!3871U<F1A>2!O9B!T:&4@
M979E;B!N=6UB97)E9"!M;VYT:',N"B`J("1C<F]N+3YA9&1487-K*"=P:'`@
M+7$@<V]M97-C<FEP="YP:'`G+"`G,"`P(#`@."TQ-294:'4L."TQ-293870@
M,BPT+#8L."PQ,"PQ,B<I.PH@*@H@*B`D8W)O;BT^<G5N*"D["B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+U-C:&5D=6QE<B]38VAE9'5L97(O8W)O;BYP:'`L
M=B`Q+C$S+C$P+C,@,C`P-2\Q,"\Q."`Q,3HP,3HR-B!J86X@17AP("0*("H*
M("H@0&%U=&AO<B`@4GEA;B!&;'EN;B`\<GEA;D!R>6%N9FQY;FXN8V]M/@H@
M*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*
M("H@0'!A8VMA9V4@2&]R9&5?4V-H961U;&5R"B`J+PIC;&%S<R!(;W)D95]3
M8VAE9'5L97)?8W)O;B!E>'1E;F1S($AO<F1E7U-C:&5D=6QE<B!["@H@("`@
M=F%R("1?=&%S:W,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@179E<GD@
M=&EM92!A('1A<VL@:7,@861D960@:70@=VEL;"!G970@82!F<F5S:"!U:60@
M979E;B!I9@H@("`@("H@:6UM961I871E;'D@<F5M;W9E9"X*("`@("`J+PH@
M("`@=F%R("1?8V]U;G1E<B`](#$["@H@("`@9G5N8W1I;VX@861D5&%S:R@D
M8VUD+"`D<G5L97,I"B`@("!["B`@("`@("`@)&1S(#T@)FYE=R!(;W)D95]3
M8VAE9'5L97)?8W)O;D1A=&4H)')U;&5S*3L*"B`@("`@("`@)'1H:7,M/E]C
M;W5N=&5R*RL["@H@("`@("`@("1T:&ES+3Y?=&%S:W-;72`]"B`@("`@("`@
M("`@(&%R<F%Y*`H@("`@("`@("`@("`@("`@)W5I9"<@/3X@)'1H:7,M/E]C
M;W5N=&5R+`H@("`@("`@("`@("`@("`@)W)U;&5S)R`]/B`D9',L"B`@("`@
M("`@("`@("`@("`G8VUD)R`]/B`D8VUD"B`@("`@("`@("`@("D["@H@("`@
M("`@(')E='5R;B`D=&AI<RT^7V-O=6YT97(["B`@("!]"@H@("`@9G5N8W1I
M;VX@<F5M;W9E5&%S:R@D=6ED*0H@("`@>PH@("`@("`@("1C;W5N="`](&-O
M=6YT*"1T:&ES+3Y?=&%S:W,I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M("1C;W5N=#L@)&DK*RD@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]T87-K
M<ULG=6ED)UT@/3T@)'5I9"D@>PH@("`@("`@("`@("`@("`@)&9O=6YD(#T@
M)&D["B`@("`@("`@("`@("`@("!A<G)A>5]S<&QI8V4H)'1H:7,M/E]T87-K
M<RP@)&DI.PH@("`@("`@("`@("`@("`@<F5T=7)N("1I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@,#L*("`@('T*"B`@("!F
M=6YC=&EO;B!R=6XH*0H@("`@>PH@("`@("`@(&EF("@A8V]U;G0H)'1H:7,M
M/E]T87-K<RDI('L*("`@("`@("`@("`@97AI="@B8W)O;F0Z($YO=&AI;F<@
M=&\@<V-H961U;&4[(&5X:71I;F<N7&XB*3L*("`@("`@("!]"@H@("`@("`@
M('=H:6QE("AT<G5E*2!["B`@("`@("`@("`@("1T(#T@=&EM92@I.PH*("`@
M("`@("`@("`@+R\@0VAE8VL@96%C:"!T87-K+@H@("`@("`@("`@("!F;W)E
M86-H("@D=&AI<RT^7W1A<VMS(&%S("1T87-K*2!["B`@("`@("`@("`@("`@
M("!I9B`H)'1A<VM;)W)U;&5S)UTM/FYO=TUA=&-H97,H*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YR=6YC;60H)'1A<VLI.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!786ET('5N
M=&EL('1H92!N97AT('-E8V]N9"X*("`@("`@("`@("`@=VAI;&4@*'1I;64H
M*2`]/2`D="D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-L965P*#$P,#`P
M,"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I
M;VX@<G5N8VUD*"8D=&%S:RD*("`@('L*("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92@G2&]R9&5?4V-H961U;&5R7T-R;VXZ.G)U;F-M9"@I.B`G("X@)'1A
M<VM;)V-M9"==("X@)R!R=6X@8GD@)R`N("1T87-K6R=U:60G72P@7U]&24Q%
M7U\L(%]?3$E.15]?+"!014%27TQ/1U])3D9/*3L*("`@("`@("!R971U<FX@
M<VAE;&Q?97AE8R@D=&%S:ULG8VUD)UTI.PH@("`@?0H*?0H*+RHJ"B`J($!P
M86-K86=E($AO<F1E7U-C:&5D=6QE<@H@*B\*8VQA<W,@2&]R9&5?4V-H961U
M;&5R7V-R;VY$871E('L*"B`@("!V87(@)&QE9V%L1&%Y<R`](&%R<F%Y*"=-
M3TXG+"`G5%5%)RP@)U=%1"<L("=42%4G+"`G1E)))RP@)U-!5"<L("=354XG
M*3L*"B`@("!V87(@)'-E8SL*("`@('9A<B`D;6EN.PH@("`@=F%R("1H;W5R
M.PH@("`@=F%R("1D87D["B`@("!V87(@)&UO;G1H.PH*("`@(&9U;F-T:6]N
M($AO<F1E7U-C:&5D=6QE<E]C<F]N1&%T92@D<F%W*0H@("`@>PH@("`@("`@
M("1T:&ES+3YP87)S92A3=')I;F<Z.G5P<&5R*"1R87<I*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!N;W=-871C:&5S*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/G-C:&5D=6QE9$%T*'1I;64H*2D["B`@("!]"@H@("`@9G5N8W1I
M;VX@<V-H961U;&5D070H)'1S(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H
M)'1S(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1T<R`]('1I;64H*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("@D=&AI<RT^;6]N=&A-871C:&5S*"1T
M<RD@)B8*("`@("`@("`@("`@("`@("1T:&ES+3YM;VYT:$UA=&-H97,H)'1S
M*2`F)@H@("`@("`@("`@("`@("`@)'1H:7,M/F1A>4UA=&-H97,H)'1S*2`F
M)@H@("`@("`@("`@("`@("`@)'1H:7,M/FAO=7)-871C:&5S*"1T<RD@)B8*
M("`@("`@("`@("`@("`@("1T:&ES+3YM:6Y-871C:&5S*"1T<RD@)B8*("`@
M("`@("`@("`@("`@("1T:&ES+3YS96--871C:&5S*"1T<RDI.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&UO;G1H36%T8VAE<R@D=',I"B`@("!["B`@("`@("`@
M:68@*"1T:&ES+3YM;VYT:"`]/2`G*B<I('L*("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@?0H*("`@("`@("`D8W5R<F5N=&UO;G1H(#T@)RTG
M("X@9&%T92@G;B<L("1T<RD@+B`G+2<["@H@("`@("`@(')E='5R;B`H8F]O
M;"ES=')P;W,H)'1H:7,M/FUO;G1H+"`D8W5R<F5N=&UO;G1H*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!D87E-871C:&5S*"1T<RD*("`@('L*("`@("`@("!I
M9B`H(65M<'1Y*"1T:&ES+3YD87E;)W9A;'5E)UTI("8F("1T:&ES+3YD87E;
M)W9A;'5E)UT@/3T@)RHG*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@('T*"B`@("`@("`@)&-U<G)E;G1D87EN=6T@/2`G+2<@+B!D871E
M*"=J)RP@)'1S*2`N("<M)SL*("`@("`@("`D8W5R<F5N=&1A>71X="`](%-T
M<FEN9SHZ=7!P97(H9&%T92@G1"<I*3L*"B`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/F1A>2!A<R`D9&%Y*2!["B`@("`@("`@("`@(&EF("A`<W1R<&]S*"1D
M87E;)VYO="==+"`D8W5R<F5N=&1A>71X="D@/3T](&9A;'-E*2!["B`@("`@
M("`@("`@("`@("`D=C$@/2`H0'-T<G!O<R@D9&%Y6R=V86QU92==+"`D8W5R
M<F5N=&1A>6YU;2D@(3T](&9A;'-E*3L*("`@("`@("`@("`@("`@("1V,B`]
M("A`<W1R<&]S*"1D87E;)V%N9"==+"`D8W5R<F5N=&1A>71X="D@(3T](&9A
M;'-E*3L*"B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1D87E;)V%N9"==
M*2`F)B`H)'8Q("8F("1V,BDI('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("`@("`@("`@('T@96QS96EF("AE;7!T>2@D9&%Y
M6R=A;F0G72D@)B8@)'8Q*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("!F=6YC=&EO
M;B!H;W5R36%T8VAE<R@D=',I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YH
M;W5R(#T]("<J)RD@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("!]"@H@("`@("`@("1C=7)R96YT:&]U<B`]("<M)R`N(&1A=&4H)T<G+"`D
M=',I("X@)RTG.PH*("`@("`@("!R971U<FX@*'-T<G!O<R@D=&AI<RT^:&]U
M<BP@)&-U<G)E;G1H;W5R*2`A/3T@9F%L<V4I.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&UI;DUA=&-H97,H)'1S*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^
M;6EN(#T]("<J)RD@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("!]"@H@("`@("`@("1C=7)R96YT;6EN(#T@)RTG("X@:6YT=F%L*&1A=&4H
M)VDG+"`D=',I*2`N("<M)SL*"B`@("`@("`@<F5T=7)N("AS=')P;W,H)'1H
M:7,M/FUI;BP@)&-U<G)E;G1M:6XI("$]/2!F86QS92D["B`@("!]"@H@("`@
M9G5N8W1I;VX@<V5C36%T8VAE<R@D=',I"B`@("!["B`@("`@("`@:68@*"1T
M:&ES+3YS96,@/3T@)RHG*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@('T*"B`@("`@("`@)&-U<G)E;G1S96,@/2`G+2<@+B!I;G1V86PH
M9&%T92@G<R<L("1T<RDI("X@)RTG.PH*("`@("`@("!R971U<FX@*'-T<G!O
M<R@D=&AI<RT^<V5C+"`D8W5R<F5N='-E8RD@(3T](&9A;'-E*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!P87)S92@D<W1R*0H@("`@>PH@("`@("`@("1S(#T@
M87)R87DH*3L*"B`@("`@("`@;&ES="@D<ULG<V5C)UTL("1S6R=M:6XG72P@
M)'-;)VAO=7(G72P@)'-;)V1A>2==+"`D<ULG;6]N=&@G72D@/2!P<F5G7W-P
M;&ET*"=\6UQN7'0@72M\)RP@)'-T<BD["@H@("`@("`@(&9O<F5A8V@@*"1S
M(&%S("1K(#T^("1V*2!["B`@("`@("`@("`@(&EF("AS=')P;W,H)'8L("<J
M)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D<ULD:UT@/2!A<G)A
M>2@G*B<I.PH@("`@("`@("`@("!](&5L<V5I9B`H(21T:&ES+3YG96YE<F%L
M;'E$96-E;G13>6YT87@H)'8I*2!["B`@("`@("`@("`@("`@("!D:64H(DEL
M;&5G86P@<WEN=&%X(&EN("<D=B=<;B(I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)'-;)&M=(#T@97AP;&]D92@G+"<L("1S6R1K
M72D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D<ULG
M<V5C)UU;,%T@/3T@)RHG*2!["B`@("`@("`@("`@("1T:&ES+3YS96,@/2`G
M*B<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@<VEZ96]F*"1S6R=S96,G72D[("1I*RLI('L*("`@("`@("`@("`@
M("`@(&EF("@D=&AI<RT^:7-286YG92@D<ULG<V5C)UU;)&E=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1S6R=S96,G75LD:5T@/2`D=&AI<RT^97AP86YD
M4F%N9V4H)'1H:7,M/G)A;F=E5F%L<R@D<ULG<V5C)UU;)&E=*2D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M
M/G-E8R`]("<M)R`N(&IO:6XH)RTG+"`D<ULG<V5C)UTI("X@)RTG.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"1S6R=M:6XG75LP72`]/2`G*B<I('L*("`@
M("`@("`@("`@)'1H:7,M/FUI;B`]("<J)SL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'-;)VUI;B==
M*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YI<U)A;F=E
M*"1S6R=M:6XG75LD:5TI*2!["B`@("`@("`@("`@("`@("`@("`@)'-;)VUI
M;B==6R1I72`]("1T:&ES+3YE>'!A;F1286YG92@D=&AI<RT^<F%N9V5686QS
M*"1S6R=M:6XG75LD:5TI*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D=&AI<RT^;6EN(#T@)RTG("X@:F]I;B@G+2<L
M("1S6R=M:6XG72D@+B`G+2<["B`@("`@("`@?0H*("`@("`@("!I9B`H)'-;
M)VAO=7(G75LP72`]/2`G*B<I('L*("`@("`@("`@("`@)'1H:7,M/FAO=7(@
M/2`G*B<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@9F]R("@D:2`]
M(#`[("1I(#P@<VEZ96]F*"1S6R=H;W5R)UTI.R`D:2LK*2!["B`@("`@("`@
M("`@("`@("!I9B`H)'1H:7,M/FES4F%N9V4H)'-;)VAO=7(G75LD:5TI*2![
M"B`@("`@("`@("`@("`@("`@("`@)'-;)VAO=7(G75LD:5T@/2`D=&AI<RT^
M97AP86YD4F%N9V4H)'1H:7,M/G)A;F=E5F%L<R@D<ULG:&]U<B==6R1I72DI
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1T:&ES+3YH;W5R(#T@)RTG("X@:F]I;B@G+2<L("1S6R=H;W5R)UTI("X@
M)RTG.PH@("`@("`@('T*"B`@("`@("`@:68@*"1S6R=D87DG75LP72`]/2`G
M*B<I('L*("`@("`@("`@("`@)'1H:7,M/F1A>2`]("<J)SL*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H
M)'-;)V1A>2==*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)'1M<"`](&%R
M<F%Y*"D["B`@("`@("`@("`@("`@("!I9B`H*"1C:&%R(#T@)'1H:7,M/FES
M0V]N9"@D<ULG9&%Y)UU;)&E=*2D@(3T](&9A;'-E*2!["B`@("`@("`@("`@
M("`@("`@("`@:68@*"1C:&%R(#T]("<F)RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("!L:7-T*"1T;7!;)W9A;'5E)UTL("1T;7!;)V%N9"==*2`](&5X
M<&QO9&4H)&-H87(L("1S6R=D87DG75LD:5TI.PH@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H)'1H:7,M/FES4F%N9V4H)'1M<%LG86YD)UTI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&UP6R=A;F0G72`]("1T:&ES
M+3YE>'!A;F1286YG92@D=&AI<RT^<F%N9V5686QS*"1T;7!;)V%N9"==*2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("!L:7-T*"1T;7!;
M)W9A;'5E)UTL("1T;7!;)VYO="==*2`](&5X<&QO9&4H)&-H87(L("1S6R=D
M87DG75LD:5TI.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M
M/FES4F%N9V4H)'1M<%LG;F]T)UTI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&UP6R=N;W0G72`]("1T:&ES+3YE>'!A;F1286YG92@D=&AI
M<RT^<F%N9V5686QS*"1T;7!;)VYO="==*2D["B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T;7`@/2!A<G)A>2@G
M=F%L=64G(#T^("1S6R=D87DG75LD:5TI.PH@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("1S6R=D87DG75LD:5T@/2`D=&UP.PH*("`@("`@
M("`@("`@("`@(&EF("@D=&AI<RT^:7-286YG92@D<ULG9&%Y)UU;)&E=6R=V
M86QU92==*2D@>PH@("`@("`@("`@("`@("`@("`@("1S6R=D87DG75LD:5U;
M)W9A;'5E)UT@/2`D=&AI<RT^97AP86YD4F%N9V4H)'1H:7,M/G)A;F=E5F%L
M<R@D<ULG9&%Y)UU;)&E=6R=V86QU92==*2D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3YD87D@/2`D<ULG
M9&%Y)UT["B`@("`@("`@?0H*("`@("`@("!I9B`H)'-;)VUO;G1H)UU;,%T@
M/3T@)RHG*2!["B`@("`@("`@("`@("1T:&ES+3YM;VYT:"`]("<J)SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S
M:7IE;V8H)'-;)VUO;G1H)UTI.R`D:2LK*2!["B`@("`@("`@("`@("`@("!I
M9B`H)'1H:7,M/FES4F%N9V4H)'-;)VUO;G1H)UU;)&E=*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1S6R=M;VYT:"==6R1I72`]("1T:&ES+3YE>'!A;F12
M86YG92@D=&AI<RT^<F%N9V5686QS*"1S6R=M;VYT:"==6R1I72DI.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES
M+3YM;VYT:"`]("<M)R`N(&IO:6XH)RTG+"`D<ULG;6]N=&@G72D@+B`G+2<[
M"B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&ES0V]N9"@D<RD*("`@
M('L*("`@("`@("!I9B`H<W1R<&]S*"1S+"`G)B<I("$]/2!F86QS92D@>PH@
M("`@("`@("`@("!R971U<FX@)R8G.PH@("`@("`@('T@96QS96EF("AS=')P
M;W,H)',L("<A)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B`G
M(2<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!I<U)A;F=E*"1S*0H@
M("`@>PH@("`@("`@(')E='5R;B!P<F5G7VUA=&-H*"<O7EQW*UPM7'<K+R<L
M("1S*3L*("`@('T*"B`@("!F=6YC=&EO;B!I<T-O;F1286YG92@D<RD*("`@
M('L*("`@("`@("!R971U<FX@*&ES0V]N9"@D<RD@)B8@:7-286YG92@D<RDI
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES0V]N9%9A;"@D<RD*("`@('L*("`@
M("`@("!R971U<FX@*&ES0V]N9"@D<RD@)B8@(6ES4F%N9V4H)',I*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!R86YG959A;',H)',I"B`@("!["B`@("`@("`@
M<F5T=7)N(&5X<&QO9&4H)RTG+"`D<RD["B`@("!]"@H@("`@9G5N8W1I;VX@
M97AP86YD4F%N9V4H)&PL("1H(#T@)R<I"B`@("!["B`@("`@("`@+R\@17AP
M86YD(')A;F=E(&9R;VT@,2TU("T^("<M,2TR+3,M-"TU+2<N"B`@("`@("`@
M:68@*&ES7V%R<F%Y*"1L*2D@>PH@("`@("`@("`@("`D:"`]("1L6S%=.PH@
M("`@("`@("`@("`D;"`]("1L6S!=.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"1T:&ES+3YI<T1I9VET*"1L*2D@>PH@("`@("`@("`@("!I9B`H(21T:&ES
M+3YI<T1I9VET*"1H*2D@>PH@("`@("`@("`@("`@("`@9&EE*"));G9A;&ED
M('9A;'5E("<D:"<@:6X@<F%N9V4@)R1L+21H)R(I.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`O+R!#=7)R96YT;'D@=&AE<F4@:7,@;F\@<&]S<VEB
M;&4@<F5A<V]N('1O(&YE960@=&\@9&\@80H@("`@("`@("`@("`O+R!R86YG
M92!B97EO;F0@,"TU.2!F;W(@86YY=&AI;F<N"B`@("`@("`@("`@(&EF("@D
M;"`\(#`I('L*("`@("`@("`@("`@("`@("1L(#T@,#L*("`@("`@("`@("`@
M?2!E;'-E:68@*"1L(#X@-3DI('L*("`@("`@("`@("`@("`@("1L(#T@-3D[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D:"`\(#`I('L*("`@
M("`@("`@("`@("`@("1H(#T@,#L*("`@("`@("`@("`@?2!E;'-E:68@*"1H
M(#X@-3DI('L*("`@("`@("`@("`@("`@("1H(#T@-3D["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@(&EF("@D;"`^("1H*2!["B`@("`@("`@("`@("`@
M("`D=&UP(#T@)&P["B`@("`@("`@("`@("`@("`D;"`]("1H.PH@("`@("`@
M("`@("`@("`@)&@@/2`D=&UP.PH@("`@("`@("`@("`@("`@=6YS970H)'1M
M<"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O($9O<B!S;VUE(')E
M87-O;B!R86YG92@I(&1O97-N)W0@=V]R:R!W+V\@=&AE(&5X<&QI8VET"B`@
M("`@("`@("`@("\O(&EN='9A;"@I(&-A;&QS+@H@("`@("`@("`@("!R971U
M<FX@)RTG("X@:F]I;B@G+2<L(')A;F=E*&EN='9A;"@D;"DL(&EN='9A;"@D
M:"DI*2`N("<M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!)
M;G9A;&ED+@H@("`@("`@("`@("!D:64H(DEN=F%L:60@=F%L=64@)R1L)R!I
M;B!R86YG92`G)&PM)&@G(BD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T
M:6]N(&1A>59A;'5E*"1S*0H@("`@>PH@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\(&-O=6YT*"1T:&ES+3YL96=A;$1A>7,I.R`D:2LK*2!["B`@("`@("`@
M("`@(&EF("@D=&AI<RT^;&5G86Q$87ES6R1I72`]/2`D<RD@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@+3$["B`@("!]"@H@("`@9G5N8W1I;VX@:7-$:6=I
M="@D<RD*("`@('L*("`@("`@("!R971U<FX@<')E9U]M871C:"@G+UY<9"LD
M+R<L("1S*3L*("`@('T*"B`@("!F=6YC=&EO;B!I<T%L<&AA*"1S*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^:7-,96=A;$1A>2@D<RD["B`@("!]
M"@H@("`@9G5N8W1I;VX@:7-,96=A;$1A>2@D<RD*("`@('L*("`@("`@("!R
M971U<FX@:6Y?87)R87DH)',L("1T:&ES+3YL96=A;$1A>7,I.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&=E;F5R86QL>41E8V5N=%-Y;G1A>"@D<RD*("`@('L*
M("`@("`@("!R971U<FX@*"1S(#T]("<J)R!\?`H@("`@("`@("`@("`@("`@
M<')E9U]M871C:"@G+UY<9"LH+5QD*RD_*%LA)EU;02U:7"I=*R@M6T$M6EPJ
M72LI/RD_*"Q<9"LH+5QD*RD_*%LA)EU;02U:7"I=*R@M6T$M6EPJ72LI/RD_
M*2HD+R<L("1S*2D["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U-C:&5D=6QE<BYP:'``````
M````````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-34R-P`Q,#4Q-30S
M,S<U,0`P,C(Q,C0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4N<&AP)SL*<F5Q
M=6ER95]O;F-E("=61E,N<&AP)SL*"B\J*@H@*B!(;W)D95]38VAE9'5L97(*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4V-H961U;&5R+U-C:&5D=6QE<BYP
M:'`L=B`Q+C(S+C$P+C@@,C`P-2\Q,B\P,2`Q-3HR-SHR,R!C:'5C:R!%>'`@
M)`H@*@H@*B!`<&%C:V%G92!(;W)D95]38VAE9'5L97(*("HO"F-L87-S($AO
M<F1E7U-C:&5D=6QE<B!["@H@("`@+RHJ"B`@("`@*B!.86UE(&]F('1H92!S
M;&5E<"!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)%]S;&5E<#L*"B`@("`O*BH*("`@("`J($%D:G5S=&UE
M;G0@9F%C=&]R('1O('-L965P(&EN(&UI8W)O<V5C;VYD<RX*("`@("`J"B`@
M("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?<VQE97!?861J
M.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@
M1FEG=7)E<R!O=70@:&]W('=E(&-A;B!B97-T('-L965P('=I=&@@;6EC<F]S
M96-O;F0@<')E8VES:6]N"B`@("`@*B!B87-E9"!O;B!W:&%T('!L871F;W)M
M('=E)W)E(')U;FYI;F<@;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E
M7U-C:&5D=6QE<B@I"B`@("!["B`@("`@("`@:68@*'-U8G-T<BA02%!?3U,L
M(#`L(#,I(#T]("=724XG*2!["B`@("`@("`@("`@("1T:&ES+3Y?<VQE97`@
M/2`G<VQE97`G.PH@("`@("`@("`@("`D=&AI<RT^7W-L965P7V%D:B`](#$P
M,#`P,#`["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]S
M;&5E<"`]("=U<VQE97`G.PH@("`@("`@("`@("`D=&AI<RT^7W-L965P7V%D
M:B`](#$["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@36%I;B!L
M;V]P+V%C=&EO;B!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`86)S=')A8W0*
M("`@("`J+PH@("`@9G5N8W1I;VX@<G5N*"D*("`@('L*("`@('T*"B`@("`O
M*BH*("`@("`J(%!R97-E<G9E('1H92!I;G1E<FYA;"!S=&%T92!O9B!T:&4@
M<V-H961U;&5R(&]B:F5C="!T:&%T('=E(&%R90H@("`@("H@<&%S<V5D+"!A
M;F0@<V%V92!I="!T;R!T:&4@2&]R9&4@5D93(&)A8VME;F0N($AO<F1E7U-C
M:&5D=6QE<@H@("`@("H@;V)J96-T<R!S:&]U;&0@9&5F:6YE(%]?<VQE97`H
M*2!A;F0@7U]W86ME=7`H*2!S97)I86QI>F%T:6]N"B`@("`@*B!C86QL8F%C
M:W,@9F]R(&%N>71H:6YG('1H870@;F5E9',@=&\@8F4@9&]N92!A="!O8FIE
M8W0*("`@("`J('-E<FEA;&EZ871I;VX@;W(@9&5S97)I86QI>F%T:6]N("T@
M:&%N9&QI;F<@9&%T86)A<V4*("`@("`J(&-O;FYE8W1I;VYS+"!E=&,N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&ED("!!;B!I9"!T;R!U;FEQ
M=65L>2!I9&5N=&EF>2!T:&ES('-C:&5D=6QE<B!F<F]M"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@(&]T:&5R<R!O9B!T:&4@<V%M92!C;&%S<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5R:6%L:7IE*"1I9"`]("<G*0H@("`@>PH@
M("`@("`@("1V9G,@/2`F5D93.CIS:6YG;&5T;VXH)$=,3T)!3%-;)V-O;F8G
M75LG=F9S)UU;)W1Y<&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@($AO<F1E.CIG971$<FEV97)#;VYF:6<H)W9F<R<L("1'3$]"04Q36R=C
M;VYF)UU;)W9F<R==6R=T>7!E)UTI*3L*("`@("`@("!I9B`H:7-?82@D=F9S
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S
M86=E*"1V9G,L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M)')E<W5L="`]("1V9G,M/G=R:71E1&%T82@G+FAO<F1E+W-C:&5D=6QE<B<L
M(%-T<FEN9SHZ;&]W97(H9V5T7V-L87-S*"1T:&ES*2D@+B`D:60L('-E<FEA
M;&EZ92@D=&AI<RDL('1R=64I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)')E<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I
M.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E<W1O<F4@
M82!(;W)D95]38VAE9'5L97(@;V)J96-T(&9R;VT@=&AE(&-A8VAE+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@("1C;&%S<R`@("`@5&AE(&YA;64@
M;V8@=&AE($AO<F1E7U-C:&5D=6QE<B!O8FIE8W0@=&\@<F5S=&]R92X*("`@
M("`J($!P87)A;2!S=')I;F<@("1I9"`@("`@("`@06X@:60@=&\@=6YI<75E
M;'D@:61E;G1I9GD@=&AI<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("!S8VAE9'5L97(@9G)O;2!O=&AE<G,@;V8@=&AE('-A;64@8VQA<W,N
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D875T;W-A=F4@($%U=&]M871I8V%L
M;'D@<W1O<F4@*'-E<FEA;&EZ92D@=&AE(')E='5R;F5D"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&]B:F5C="!A="!S8W)I<'0@<VAU=&1O
M=VXN"B`@("`@*@H@("`@("H@0'-E92!(;W)D95]38VAE9'5L97(Z.G-E<FEA
M;&EZ92@I"B`@("`@*B\*("`@(&9U;F-T:6]N("9U;G-E<FEA;&EZ92@D8VQA
M<W,L("1I9"`]("<G+"`D875T;W-A=F4@/2!T<G5E*0H@("`@>PH@("`@("`@
M("\O($YE960@82!L;W=E<F-A<V4@=F5R<VEO;B!O9B!T:&4@8VQA<W-N86UE
M+"!A;F0@82!D969A=6QT"B`@("`@("`@+R\@:6YS=&%N8V4@;V8@=&AE('-C
M:&5D=6QE<B!O8FIE8W0@:6X@8V%S92!W92!C86XG="!R971R:65V90H@("`@
M("`@("\O(&]N92X*("`@("`@("`D8VQA<W,@/2!S=')T;VQO=V5R*"1C;&%S
M<RD["B`@("`@("`@)'-C:&5D=6QE<B`]("9N97<@)&-L87-S.PH*("`@("`@
M("`D=F9S(#T@)E9&4SHZ<VEN9VQE=&]N*"1'3$]"04Q36R=C;VYF)UU;)W9F
M<R==6R=T>7!E)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!(
M;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=V9G,G+"`D1TQ/0D%,4ULG8V]N9B==
M6R=V9G,G75LG='EP92==*2D["B`@("`@("`@:68@*&ES7V$H)'9F<RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D
M=F9S+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&1A=&$@/2`D=F9S+3YR96%D*"<N
M:&]R9&4O<V-H961U;&5R)RP@)&-L87-S("X@)&ED*3L*("`@("`@("`@("`@
M:68@*&ES7V$H)&1A=&$L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*"1D871A+"!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7TE.1D\I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)'-C:&5D=6QE<B`]($!U;G-E<FEA;&EZ92@D9&%T82D[
M"B`@("`@("`@("`@("`@("!I9B`H(21S8VAE9'5L97(I('L*("`@("`@("`@
M("`@("`@("`@("`D<V-H961U;&5R(#T@)FYE=R`D8VQA<W,["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF
M("@D875T;W-A=F4I('L*("`@("`@("`@("`@<F5G:7-T97)?<VAU=&1O=VY?
M9G5N8W1I;VXH87)R87DH)B1S8VAE9'5L97(L("=S97)I86QI>F4G*2D["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)'-C:&5D=6QE<CL*("`@('T*"B`@
M("`O*BH*("`@("`J(%!L871F;W)M+6EN9&5P96YD86YT('-L965P("1M<V5C
M(&UI8W)O<V5C;VYD<RX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M;7-E8R`@36EC<F]S96-O;F1S('1O('-L965P+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!S;&5E<"@D;7-E8RD*("`@('L*("`@("`@("!C86QL7W5S97)?9G5N
M8R@D=&AI<RT^7W-L965P+"`D;7-E8R`O("1T:&ES+3Y?<VQE97!?861J*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(&-O
M;F-R971E($AO<F1E7U-C:&5D=6QE<B!I;G-T86YC92!B87-E9"!O;B`D9')I
M=F5R+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@
M='EP92!O9B!C;VYC<F5T92!(;W)D95]38VAE9'5L97(@<W5B8VQA<W,@=&\*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!R971U<FXN($EF("1D<FEV
M97(@:7,@86X@87)R87DL('1H96X@=V4@=VEL;"!L;V]K"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@:6X@)&1R:79E<ELP72]L:6(O2&]R9&5?4V-H
M961U;&5R+R!F;W(@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M<W5B8VQA<W,@:6UP;&5M96YT871I;VX@;F%M960@)&1R:79E<ELQ72YP:'`N
M"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI
M;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U
M8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D
M95]38VAE9'5L97(@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E($AO<F1E
M7U-C:&5D=6QE<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&EN
M<W1A;F-E+"!O<B!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@)F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<R`](&YU;&PI"B`@("![
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1D<FEV97(I*2!["B`@("`@("`@("`@
M("1A<'`@/2`D9')I=F5R6S!=.PH@("`@("`@("`@("`D9')I=F5R(#T@)&1R
M:79E<ELQ73L*("`@("`@("!]"@H@("`@("`@("1D<FEV97(@/2!B87-E;F%M
M92@D9')I=F5R*3L*"B`@("`@("`@:68@*&5M<'1Y*"1D<FEV97(I('Q\("AS
M=')C;7`H)&1R:79E<BP@)VYO;F4G*2`]/2`P*2D@>PH@("`@("`@("`@("`D
M<V-H961U;&5R(#T@)FYE=R!(;W)D95]38VAE9'5L97(H*3L*("`@("`@("`@
M("`@<F5T=7)N("1S8VAE9'5L97(["B`@("`@("`@?0H*("`@("`@("!I9B`H
M(65M<'1Y*"1A<'`I*2!["B`@("`@("`@("`@(&EN8VQU9&5?;VYC92`D1TQ/
M0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]L
M:6(O4V-H961U;&5R+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T@
M96QS96EF("A`9FEL95]E>&ES=',H9&ER;F%M92A?7T9)3$5?7RD@+B`G+U-C
M:&5D=6QE<B\G("X@)&1R:79E<B`N("<N<&AP)RDI('L*("`@("`@("`@("`@
M:6YC;'5D95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]38VAE9'5L97(O
M)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@+R\@57-E(&EN8VQU9&5?;VYC92!H97)E('1O(&%V;VED(&$@9F%T
M86P@97)R;W(@:68@=&AE"B`@("`@("`@("`@("\O(&-L87-S(&ES;B=T(&9O
M=6YD+@H@("`@("`@("`@("!`:6YC;'5D95]O;F-E("=(;W)D92]38VAE9'5L
M97(O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?0H@("`@("`@("1C
M;&%S<R`]("=(;W)D95]38VAE9'5L97)?)R`N("1D<FEV97(["B`@("`@("`@
M:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1S8VAE
M9'5L97(@/2`F;F5W("1C;&%S<R@D<&%R86US*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D<V-H961U;&5R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G
M0VQA<W,@9&5F:6YI=&EO;B!O9B`G("X@)&-L87-S("X@)R!N;W0@9F]U;F0N
M)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'-C:&5D=6QE<CL*("`@
M('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R
M96YC92!T;R!A(&-O;F-R971E($AO<F1E7U-C:&5D=6QE<@H@("`@("H@:6YS
M=&%N8V4@8F%S960@;VX@)&1R:79E<BX@270@=VEL;"!O;FQY(&-R96%T92!A
M(&YE=R!I;G-T86YC90H@("`@("H@:68@;F\@2&]R9&5?4V-H961U;&5R(&EN
M<W1A;F-E('=I=&@@=&AE('-A;64@<&%R86UE=&5R<PH@("`@("H@8W5R<F5N
M=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES('-H;W5L9"!B92!U<V5D
M(&EF(&UU;'1I<&QE('-C:&5D=6QE<G,@*&%N9"P@=&AU<RP@;75L=&EP;&4*
M("`@("`J($AO<F1E7U-C:&5D=6QE<B!I;G-T86YC97,I(&%R92!R97%U:7)E
M9"X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@
M87,Z("1V87(@/2`F2&]R9&5?4V-H961U;&5R.CIS:6YG;&5T;VXH*0H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&1R:79E<B`@5&AE('1Y<&4@;V8@
M8V]N8W)E=&4@2&]R9&5?4V-H961U;&5R('-U8F-L87-S('1O"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;BX*("`@("`J($!P87)A;2!A
M<G)A>2`D<&%R86US("`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N
M86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("!C;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N
M965D+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?4V-H961U;&5R("!4
M:&4@8V]N8W)E=&4@2&]R9&5?4V-H961U;&5R(')E9F5R96YC92P@;W(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("!F86QS92!O;B!A;B!E<G)O
M<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D9')I=F5R+"`D
M<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E
M<R`](&%R<F%Y*"D["@H@("`@("`@("1S:6=N871U<F4@/2!S97)I86QI>F4H
M87)R87DH)&1R:79E<BP@)'!A<F%M<RDI.PH@("`@("`@(&EF("@A:7-S970H
M)&EN<W1A;F-E<ULD<VEG;F%T=7)E72DI('L*("`@("`@("`@("`@)&EN<W1A
M;F-E<ULD<VEG;F%T=7)E72`]("9(;W)D95]38VAE9'5L97(Z.F9A8W1O<GDH
M)&1R:79E<BP@)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&EN<W1A;F-E<ULD<VEG;F%T=7)E73L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+U-E8W)E="YP:'``````````````````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`Q,S(R,``Q,#4Q-30S,S<U,0`P,C$T,3<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J(%1H92!396-R970Z.B!C;&%S<R!P<F]V:61E<R!A;B!!4$D@9F]R
M(&5N8W)Y<'1I;F<@86YD(&1E8W)Y<'1I;F<*("H@<VUA;&P@<&EE8V5S(&]F
M(&1A=&$@=VET:"!T:&4@=7-E(&]F(&$@<VAA<F5D(&ME>2X*("H*("H@5&AE
M(%-E8W)E=#HZ(&9U;F-T:6]N<R!U<V4@=&AE($AO<F1E($-I<&AE<CHZ(&-L
M87-S(&EF(&UC<GEP="!I<R!N;W0*("H@879A:6QA8FQE+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]396-R970O4V5C<F5T+G!H<"QV(#$N-#4N,3`N-R`R
M,#`V+S`S+S`R(#`U.C(U.C$P('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I
M9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@
M0'!A8VMA9V4@2&]R9&5?4V5C<F5T"B`J+PIC;&%S<R!396-R970@>PH*("`@
M("\J*@H@("`@("H@5&%K92!A('-M86QL('!I96-E(&]F(&1A=&$@86YD(&5N
M8W)Y<'0@:70@=VET:"!A(&ME>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1K97D@("`@("!4:&4@:V5Y('1O('5S92!F;W(@96YC<GEP=&EO;BX*
M("`@("`J($!P87)A;2!S=')I;F<@)&UE<W-A9V4@(%1H92!P;&%I;G1E>'0@
M;65S<V%G92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-I
M<&AE<G1E>'0@;65S<V%G92X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&4H
M)&ME>2P@)&UE<W-A9V4I"B`@("!["B`@("`@("`@:68@*%5T:6PZ.F5X=&5N
M<VEO;D5X:7-T<R@G;6-R>7!T)RDI('L*("`@("`@("`@("`@)'1D(#T@0&UC
M<GEP=%]M;V1U;&5?;W!E;BA-0U)94%1?1T]35"P@)R<L($U#4EE05%]-3T1%
M7T5#0BP@)R<I.PH@("`@("`@("`@("!I9B`H)'1D*2!["B`@("`@("`@("`@
M("`@("`D:78@/2!`;6-R>7!T7V-R96%T95]I=BAM8W)Y<'1?96YC7V=E=%]I
M=E]S:7IE*"1T9"DL($U#4EE05%]204Y$*3L*("`@("`@("`@("`@("`@($!M
M8W)Y<'1?9V5N97)I8U]I;FET*"1T9"P@)&ME>2P@)&EV*3L*("`@("`@("`@
M("`@("`@("1E;F-R>7!T961?9&%T82`]($!M8W)Y<'1?9V5N97)I8R@D=&0L
M("1M97-S86=E*3L*("`@("`@("`@("`@("`@($!M8W)Y<'1?9V5N97)I8U]D
M96EN:70H)'1D*3L*"B`@("`@("`@("`@("`@("!R971U<FX@)&5N8W)Y<'1E
M9%]D871A.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!S=&%T
M:6,@)&-I<&AE<D-A8VAE(#T@87)R87DH*3L*("`@("`@("`D8V%C:&5)9'@@
M/2!M9#4H)&ME>2D["@H@("`@("`@(&EF("@A:7-S970H)&-I<&AE<D-A8VAE
M6R1C86-H94ED>%TI*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O0VEP:&5R+G!H<"<["@H@("`@("`@("`@("`D8VEP:&5R0V%C:&5;)&-A
M8VAE261X72`]("9(;W)D95]#:7!H97(Z.F9A8W1O<GDH)V)L;W=F:7-H)RD[
M"B`@("`@("`@("`@("1C:7!H97)#86-H95LD8V%C:&5)9'A=+3YS971";&]C
M:TUO9&4H)V]F8C8T)RD["B`@("`@("`@("`@("1C:7!H97)#86-H95LD8V%C
M:&5)9'A=+3YS971+97DH)&ME>2D["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&-I<&AE<D-A8VAE6R1C86-H94ED>%TM/F5N8W)Y<'0H)&UE<W-A9V4I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5C<GEP="!A(&UE<W-A9V4@96YC
M<GEP=&5D('=I=&@@4V5C<F5T.CIW<FET92@I+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&ME>2`@("`@(%1H92!K97D@=&\@=7-E(&9O<B!D96-R
M>7!T:6]N+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65S<V%G92`@5&AE(&-I
M<&AE<G1E>'0@;65S<V%G92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE('!L86EN=&5X="!M97-S86=E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!R96%D*"1K97DL("1C:7!H97)T97AT*0H@("`@>PH@("`@("`@(&EF("A5
M=&EL.CIE>'1E;G-I;VY%>&ES=',H)VUC<GEP="<I*2!["B`@("`@("`@("`@
M("1T9"`]($!M8W)Y<'1?;6]D=6QE7V]P96XH34-265!47T=/4U0L("<G+"!-
M0U)94%1?34]$15]%0T(L("<G*3L*("`@("`@("`@("`@:68@*"1T9"D@>PH@
M("`@("`@("`@("`@("`@)&EV(#T@0&UC<GEP=%]C<F5A=&5?:78H;6-R>7!T
M7V5N8U]G971?:79?<VEZ92@D=&0I+"!-0U)94%1?4D%.1"D["B`@("`@("`@
M("`@("`@("!`;6-R>7!T7V=E;F5R:6-?:6YI="@D=&0L("1K97DL("1I=BD[
M"B`@("`@("`@("`@("`@("`D9&5C<GEP=&5D7V1A=&$@/2!`;61E8W)Y<'1?
M9V5N97)I8R@D=&0L("1C:7!H97)T97AT*3L*("`@("`@("`@("`@("`@($!M
M8W)Y<'1?9V5N97)I8U]D96EN:70H)'1D*3L*"B`@("`@("`@("`@("`@("`O
M+R!3=')I<"!P861D:6YG(&-H87)A8W1E<G,N"B`@("`@("`@("`@("`@("!R
M971U<FX@<G1R:6TH)&1E8W)Y<'1E9%]D871A+"`B7#`B*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<W1A=&EC("1C:7!H97)#86-H93L*
M("`@("`@("`D8V%C:&5)9'@@/2!M9#4H)&ME>2D["@H@("`@("`@(&EF("@A
M:7-?87)R87DH)&-I<&AE<D-A8VAE*2!\?"`A:7-S970H)&-I<&AE<D-A8VAE
M6R1C86-H94ED>%TI*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O0VEP:&5R+G!H<"<["@H@("`@("`@("`@("`D8VEP:&5R0V%C:&5;)&-A
M8VAE261X72`]("9(;W)D95]#:7!H97(Z.F9A8W1O<GDH)V)L;W=F:7-H)RD[
M"B`@("`@("`@("`@("1C:7!H97)#86-H95LD8V%C:&5)9'A=+3YS971";&]C
M:TUO9&4H)V]F8C8T)RD["B`@("`@("`@("`@("1C:7!H97)#86-H95LD8V%C
M:&5)9'A=+3YS971+97DH)&ME>2D["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&-I<&AE<D-A8VAE6R1C86-H94ED>%TM/F1E8W)Y<'0H)&-I<&AE<G1E
M>'0I.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A=&4@82!S96-R970@
M:V5Y("AF;W(@96YC<GEP=&EO;BDL(&5I=&AE<B!U<VEN9R!A(')A;F1O;0H@
M("`@("H@;60U('-T<FEN9R!A;F0@<W1O<FEN9R!I="!I;B!A(&-O;VMI92!I
M9B!T:&4@=7-E<B!H87,@8V]O:VEE<PH@("`@("H@96YA8FQE9"P@;W(@;75N
M9VEN9R!S;VUE(&MN;W=N('9A;'5E<R!I9B!T:&5Y(&1O;B=T+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&ME>6YA;64@(%1H92!N86UE(&]F('1H
M92!K97D@=&\@<V5T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@<V5C<F5T(&ME>2!T:&%T(&AA<R!B965N(&=E;F5R871E9"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T2V5Y*"1K97EN86UE(#T@)V=E;F5R:6,G*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@)'1I;65O=70@
M/2`D8V]N9ELG<V5S<VEO;B==6R=T:6UE;W5T)UT@/R!T:6UE*"D@*R`D8V]N
M9ELG<V5S<VEO;B==6R=T:6UE;W5T)UT@.B`P.PH*("`@("`@("!I9B`H:7-S
M970H)%]#3T]+245;)&-O;F9;)W-E<W-I;VXG75LG;F%M92==72DI('L*("`@
M("`@("`@("`@:68@*&ES<V5T*"1?0T]/2TE%6R1K97EN86UE("X@)U]K97DG
M72DI('L*("`@("`@("`@("`@("`@("1K97D@/2`D7T-/3TM)15LD:V5Y;F%M
M92`N("=?:V5Y)UT["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D:V5Y(#T@;60U*&UT7W)A;F0H*2D["B`@("`@("`@("`@("`@("`D
M7T-/3TM)15LD:V5Y;F%M92`N("=?:V5Y)UT@/2`D:V5Y.PH@("`@("`@("`@
M("`@("`@0'-E=&-O;VMI92@D:V5Y;F%M92`N("=?:V5Y)RP@)&ME>2P@)'1I
M;65O=70L("1C;VYF6R=C;V]K:64G75LG<&%T:"==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D8V]N9ELG8V]O:VEE)UU;)V1O;6%I;B==+"`D8V]N
M9ELG=7-E7W-S;"==(#T](#$@/R`Q(#H@,"D["B`@("`@("`@("`@('T*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:V5Y(#T@<V5S<VEO;E]I9"@I
M.PH@("`@("`@("`@("!`<V5T8V]O:VEE*"1K97EN86UE("X@)U]K97DG+"`D
M:V5Y+"`D=&EM96]U="P@)&-O;F9;)V-O;VMI92==6R=P871H)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@)&-O;F9;)V-O;VMI92==6R=D;VUA:6XG72P@
M)&-O;F9;)W5S95]S<VPG72`]/2`Q(#\@,2`Z(#`I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1K97D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FX@82!S96-R970@:V5Y+"!E:71H97(@9G)O;2!A(&-O;VMI92P@;W(@:68@
M=&AE(&-O;VMI90H@("`@("H@:7-N)W0@=&AE<F4L(&%S<W5M92!W92!A<F4@
M=7-I;F<@82!M=6YG960@=F5R<VEO;B!O9B!A(&MN;W=N"B`@("`@*B!B87-E
M('9A;'5E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ME>6YA;64@
M(%1H92!N86UE(&]F('1H92!K97D@=&\@9V5T+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@<V5C<F5T(&ME>2X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T2V5Y*"1K97EN86UE(#T@)V=E;F5R:6,G*0H@("`@>PH@("`@
M("`@('-T871I8R`D:V5Y8V%C:&4@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H
M(6ES<V5T*"1K97EC86-H95LD:V5Y;F%M95TI*2!["B`@("`@("`@("`@(&EF
M("AI<W-E="@D7T-/3TM)15LD:V5Y;F%M92`N("=?:V5Y)UTI*2!["B`@("`@
M("`@("`@("`@("`D:V5Y8V%C:&5;)&ME>6YA;65=(#T@)%]#3T]+245;)&ME
M>6YA;64@+B`G7VME>2==.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@9VQO8F%L("1C;VYF.PH@("`@("`@("`@("`@("`@)&ME>6-A
M8VAE6R1K97EN86UE72`]('-E<W-I;VY?:60H*3L*("`@("`@("`@("`@("`@
M($!S971C;V]K:64H)&ME>6YA;64@+B`G7VME>2<L("1K97EC86-H95LD:V5Y
M;F%M95TL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VYF6R=S97-S
M:6]N)UU;)W1I;65O=70G72`_('1I;64H*2`K("1C;VYF6R=S97-S:6]N)UU;
M)W1I;65O=70G72`Z(#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1C
M;VYF6R=C;V]K:64G75LG<&%T:"==+"`D8V]N9ELG8V]O:VEE)UU;)V1O;6%I
M;B==+"`D8V]N9ELG=7-E7W-S;"==(#T](#$@/R`Q(#H@,"D["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:V5Y8V%C:&5;)&ME
M>6YA;65=.PH@("`@?0H*("`@("\J*@H@("`@("H@0VQE87)S(&$@<V5C<F5T
M(&ME>2!E;G1R>2!F<F]M('1H92!C=7)R96YT(&-O;VMI92X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1K97EN86UE("!4:&4@;F%M92!O9B!T:&4@
M:V5Y('1O(&-L96%R+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M5')U92!I9B!K97D@97AI<W1E9"P@9F%L<V4@:68@;F]T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!C;&5A<DME>2@D:V5Y;F%M92`]("=G96YE<FEC)RD*("`@
M('L*("`@("`@("!I9B`H:7-S970H)%]#3T]+245;)$=,3T)!3%-;)V-O;F8G
M75LG<V5S<VEO;B==6R=N86UE)UU=*2`F)@H@("`@("`@("`@("!I<W-E="@D
M7T-/3TM)15LD:V5Y;F%M92`N("=?:V5Y)UTI*2!["B`@("`@("`@("`@('5N
M<V5T*"1?0T]/2TE%6R1K97EN86UE("X@)U]K97DG72D["B`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O4V5R:6%L:7IE+G!H<```````````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#(R,3$W`#$P-3$U-#,S-S4Q`#`R,C$R-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`H*9&5F
M:6YE*"=315))04Q)6D5?54Y+3D]73B<L("TQ*3L*9&5F:6YE*"=315))04Q)
M6D5?3D].12<L(#`I.PID969I;F4H)U-%4DE!3$E:15]71$18)RP@,2D["F1E
M9FEN92@G4T5224%,25I%7T):25`G+"`R*3L*9&5F:6YE*"=315))04Q)6D5?
M24U!4#@G+"`S*3L*9&5F:6YE*"=315))04Q)6D5?24U!4%541C<G+"`T*3L*
M9&5F:6YE*"=315))04Q)6D5?24U!4%541C@G+"`U*3L*9&5F:6YE*"=315))
M04Q)6D5?0D%324,G+"`V*3L*9&5F:6YE*"=315))04Q)6D5?1UI?1$5&3$%4
M12<L(#<I.PID969I;F4H)U-%4DE!3$E:15]'6E]#3TU04D534R<L(#@I.PID
M969I;F4H)U-%4DE!3$E:15]'6E]%3D-/1"<L(#DI.PID969I;F4H)U-%4DE!
M3$E:15]"05-%-C0G+"`Q,"D["F1E9FEN92@G4T5224%,25I%7U-13%A-3"<L
M(#$Q*3L*9&5F:6YE*"=315))04Q)6D5?4D%7)RP@,3(I.PID969I;F4H)U-%
M4DE!3$E:15]54DPG+"`Q,RD["F1E9FEN92@G4T5224%,25I%7U541C<G+"`Q
M-"D["@HO*BH@57-E(%-%4DE!3$E:15]55$8W(&%N9"!315))04Q)6D5?0D%3
M24,@<W1A8VME9"X@("HO"F1E9FEN92@G4T5224%,25I%7U541C=?0D%324,G
M+"`Q-2D["@H*+RHJ"B`J(%1H92!397)I86QI>F4Z.B!C;&%S<R!P<F]V:61E
M<R!V87)I;W5S(&UE=&AO9',@;V8@96YC87!S=6QA=&EN9R!D871A+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]397)I86QI>F4O4V5R:6%L:7IE+G!H<"QV
M(#$N,C4N,3`N.2`R,#`V+S`Q+S`Q(#(Q.C(X.C,T(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,2TR,#`V(%-T97!H86YE($AU=&AE<B`\<VAU=&AE
M<D!B:6=F;V]T+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!3
M=&5P:&%N92!(=71H97(@/'-H=71H97)`8FEG9F]O="YC;VT^"B`J($!S:6YC
M92`@($AO<F1E(#(N,`H@*B!`<&%C:V%G92!(;W)D95]397)I86QI>F4*("HO
M"F-L87-S($AO<F1E7U-E<FEA;&EZ92!["@H@("`@+RHJ"B`@("`@*B!397)I
M86QI>F4@82!V86QU92X*("`@("`J"B`@("`@*B!3964@=&AE(&QI<W0@;V8@
M8V]N<W1A;G1S(&%T('1H92!T;W`@;V8@=&AE(&9I;&4@9F]R('1H92!S97)I
M86QI>FEN9PH@("`@("H@=&5C:&YI<75E<R!T:&%T(&-A;B!B92!U<V5D+@H@
M("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9&%T82`@("!4:&4@9&%T82!T
M;R!B92!S97)I86QI>F5D+@H@("`@("H@0'!A<F%M(&UI>&5D("1M;V1E("`@
M(%1H92!M;V1E(&]F('-E<FEA;&EZ871I;VXN($-A;B!B92!E:71H97(@82!S
M:6YG;&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!M;V1E(&]R(&%R
M<F%Y(&]F(&UO9&5S+B`@268@87)R87DL('=I;&P@8F4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!S97)I86QI>F5D(&EN('1H92!O<F1E<B!P<F]V
M:61E9"X*("`@("`J($!P87)A;2!M:7AE9"`D<&%R86US("!!;GD@861D:71I
M;VYA;"!P87)A;65T97)S('1H92!S97)I86QI>F%T:6]N(&UE=&AO9`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@(')E<75I<F5S+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@<V5R:6%L:7IE9"!D871A+@H@("`@
M("H@("`@("`@("`@("`@("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O;B!E<G)O
M<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5R:6%L:7IE*"1D871A+"`D;6]D
M92`](&%R<F%Y*%-%4DE!3$E:15]"05-)0RDL("1P87)A;7,@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)&UO9&4I*2!["B`@("`@("`@
M("`@("1M;V1E(#T@87)R87DH)&UO9&4I.PH@("`@("`@('T*"B`@("`@("`@
M+RH@4F5T=7)N(&YO=R!I9B!N;R!D871A+B`J+PH@("`@("`@(&EF("AE;7!T
M>2@D9&%T82D@)B8@(6ES7V%R<F%Y*"1D871A*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&1A=&$["B`@("`@("`@?0H*("`@("`@("`O*B!087)S92!T:')O
M=6=H('1H92!L:7-T(&]F('-E<FEA;&EZ:6YG(&UO9&5S+B`J+PH@("`@("`@
M(&9O<F5A8V@@*"1M;V1E(&%S("1V86PI('L*("`@("`@("`@("`@+RH@0VAE
M8VL@=&\@;6%K92!S=7)E('1H92!M;V1E(&ES('-U<'!O<G1E9"X@*B\*("`@
M("`@("`@("`@:68@*"%(;W)D95]397)I86QI>F4Z.FAA<T-A<&%B:6QI='DH
M)'9A;"DI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"=5;G-U<'!O<G1E9"!S97)I86QI>F%T:6]N('1Y<&4G*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!(;W)D95]397)I86QI>F4Z.E]S97)I86QI
M>F4H)&1A=&$L("1V86PL("1P87)A;7,I.PH@("`@("`@("`@("!I9B`H:7-?
M82@D9&%T82P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J(%-E<FEA;&EZ92!D871A+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!M:7AE9"`F)&1A=&$@("`@("`@("`@("!4:&4@9&%T82!T;R!B92!S
M97)I86QI>F5D+@H@("`@("H@0'!A<F%M(&UI>&5D("1M;V1E("`@("`@("`@
M("`@(%1H92!M;V1E(&]F('-E<FEA;&EZ871I;VXN($-A;B!B90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&5I=&AE<B!A('-I;F=L
M92!M;V1E(&]R(&%R<F%Y(&]F(&UO9&5S+@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@($EF(&%R<F%Y+"!W:6QL(&)E('-E<FEA;&EZ
M960@:6X@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@;W)D97(@<')O=FED960N"B`@("`@*B!`<&%R86T@;6EX960@)'!A<F%M
M<R`@06YY(&%D9&ET:6]N86P@<&%R86UE=&5R<R!T:&4@<V5R:6%L:7IA=&EO
M;B!M971H;V0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!R97%U:7)E
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E<FEA;&EZ92@F)&1A=&$L("1M
M;V1E+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("!S=VET8V@@*"1M
M;V1E*2!["B`@("`@("`@8V%S92!315))04Q)6D5?3D].13H*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&-A<V4@4T5224%,25I%7T):25`Z"B`@("`@
M("`@("`@("1D871A(#T@8GIC;VUP<F5S<R@D9&%T82P@.2P@,S`I.PH@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!315))04Q)6D5?5T1$6#H*
M("`@("`@("`@("`@)&1A=&$@/2!W9&1X7W-E<FEA;&EZ95]V86QU92@D9&%T
M82D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%-%4DE!3$E:
M15])34%0.#H*("`@("`@("`@("`@)&1A=&$@/2!I;6%P7SAB:70H)&1A=&$I
M.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!315))04Q)6D5?
M24U!4%541C<Z"B`@("`@("`@("`@("1D871A(#T@:6UA<%]U=&8W7V5N8V]D
M92@D9&%T82D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%-%
M4DE!3$E:15])34%0551&.#H*("`@("`@("`@("`@)&1A=&$@/2!I;6%P7W5T
M9C@H)&1A=&$I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!3
M15))04Q)6D5?1UI?1$5&3$%413H*("`@("`@("`@("`@)&1A=&$@/2!G>F1E
M9FQA=&4H)&1A=&$L(#DI.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M8V%S92!315))04Q)6D5?0D%324,Z"B`@("`@("`@("`@("1D871A(#T@<V5R
M:6%L:7IE*"1D871A*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@4T5224%,25I%7T=:7T-/35!215-3.@H@("`@("`@("`@("`D9&%T82`]
M(&=Z8V]M<')E<W,H)&1A=&$L(#DI.PH@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@8V%S92!315))04Q)6D5?0D%3138T.@H@("`@("`@("`@("`D9&%T
M82`](&)A<V4V-%]E;F-O9&4H)&1A=&$I.PH@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@8V%S92!315))04Q)6D5?1UI?14Y#3T0Z"B`@("`@("`@("`@
M("1D871A(#T@9WIE;F-O9&4H)&1A=&$L(#DI.PH@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@8V%S92!315))04Q)6D5?4D%7.@H@("`@("`@("`@("`D
M9&%T82`](')A=W5R;&5N8V]D92@D9&%T82D["B`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("!C87-E(%-%4DE!3$E:15]54DPZ"B`@("`@("`@("`@("1D
M871A(#T@=7)L96YC;V1E*"1D871A*3L*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&-A<V4@4T5224%,25I%7U-13%A-3#H*("`@("`@("`@("`@<F5Q
M=6ER95]O;F-E("=$0BYP:'`G.PH@("`@("`@("`@("`D<W%L,GAM;"`]("9N
M97<@>&UL7W-Q;#)X;6PH*3L*("`@("`@("`@("`@)&1A=&$@/2`D<W%L,GAM
M;"T^9V5T6$U,*"1D871A*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@4T5224%,25I%7U541C<Z"B`@("`@("`@("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O4W1R:6YG+G!H<"<["B`@("`@("`@("`@("1D871A(#T@4W1R
M:6YG.CIC;VYV97)T0VAA<G-E="@D9&%T82P@)'!A<F%M<RP@)W5T9BTW)RD[
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%-%4DE!3$E:15]5
M5$8W7T)!4TE#.@H@("`@("`@("`@("!(;W)D95]397)I86QI>F4Z.E]S97)I
M86QI>F4H)&1A=&$L(%-%4DE!3$E:15]55$8W+"`D<&%R86US*3L*("`@("`@
M("`@("`@2&]R9&5?4V5R:6%L:7IE.CI?<V5R:6%L:7IE*"1D871A+"!315))
M04Q)6D5?0D%324,L("1P87)A;7,I.PH@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!5;G-E<FEA;&EZ92!A('9A
M;'5E+@H@("`@("H*("`@("`J(%-E92!T:&4@;&ES="!O9B!C;VYS=&%N=',@
M870@=&AE('1O<"!O9B!T:&4@9FEL92!F;W(@=&AE('-E<FEA;&EZ:6YG"B`@
M("`@*B!T96-H;FEQ=65S('1H870@8V%N(&)E('5S960N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&UI>&5D("1D871A("`@("`@("`@("`@(%1H92!D871A('1O
M(&)E('5N<V5R:6%L:7IE9"X*("`@("`J($!P87)A;2!M:7AE9"`D;6]D92`@
M("!4:&4@;6]D92!O9B!U;G-E<FEA;&EZ871I;VXN("!#86X@8F4@96ET:&5R
M(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!S:6YG;&4@;6]D92!O
M<B!A<G)A>2!O9B!M;V1E<RX@($EF(&%R<F%Y+"!W:6QL(&)E"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@=6YS97)I86QI>F5D(&EN('1H92!O<F1E
M<B!P<F]V:61E9"X*("`@("`J($!P87)A;2!M:7AE9"`D<&%R86US("!!;GD@
M861D:71I;VYA;"!P87)A;65T97)S('1H92!U;G-E<FEA;&EZ871I;VX*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!M971H;V0@<F5Q=6ER97,N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!U;G-E<FEA;&EZ960@
M9&%T82X*("`@("`J("`@("`@("`@("`@("`@("!2971U<FYS(%!%05)?17)R
M;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N('5N<V5R:6%L:7IE
M*"1D871A+"`D;6]D92`](%-%4DE!3$E:15]"05-)0RP@)'!A<F%M<R`](&YU
M;&PI"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D;6]D92DI('L*("`@
M("`@("`@("`@)&UO9&4@/2!A<G)A>2@D;6]D92D["B`@("`@("`@?0H*("`@
M("`@("`O*B!2971U<FX@;F]W(&EF(&YO(&1A=&$N("HO"B`@("`@("`@:68@
M*&5M<'1Y*"1D871A*2D@>PH@("`@("`@("`@("!R971U<FX@)&1A=&$["B`@
M("`@("`@?0H*("`@("`@("`O*B!087)S92!T:')O=6=H('1H92!L:7-T(&]F
M('5N<V5R:6%L:7II;F<@;6]D97,N("HO"B`@("`@("`@9F]R96%C:"`H)&UO
M9&4@87,@)'9A;"D@>PH@("`@("`@("`@("`O*B!#:&5C:R!T;R!M86ME('-U
M<F4@=&AE(&UO9&4@:7,@<W5P<&]R=&5D+B`J+PH@("`@("`@("`@("!I9B`H
M(4AO<F1E7U-E<FEA;&EZ93HZ:&%S0V%P86)I;&ET>2@D=F%L*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U5N<W5P<&]R
M=&5D('5N<V5R:6%L:7IA=&EO;B!T>7!E)RD["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@2&]R9&5?4V5R:6%L:7IE.CI?=6YS97)I86QI>F4H)&1A=&$L
M("1V86PL("1P87)A;7,I.PH@("`@("`@("`@("!I9B`H:7-?82@D9&%T82P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9&%T83L*("`@
M('T*"B`@("`O*BH*("`@("`J(%5N<V5R:6%L:7IE(&1A=&$N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&UI
M>&5D("8D9&%T82`@(%1H92!D871A('1O(&)E('5N<V5R:6%L:7IE9"X*("`@
M("`J($!P87)A;2!M:7AE9"`D;6]D92`@("!4:&4@;6]D92!O9B!U;G-E<FEA
M;&EZ871I;VXN($-A;B!B92!E:71H97(@80H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@('-I;F=L92!M;V1E(&]R(&%R<F%Y(&]F(&UO9&5S+B`@268@
M87)R87DL('=I;&P@8F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!U
M;G-E<FEA;&EZ960@:6X@=&AE(&]R9&5R('!R;W9I9&5D+@H@("`@("H@0'!A
M<F%M(&UI>&5D("1P87)A;7,@($%N>2!A9&1I=&EO;F%L('!A<F%M971E<G,@
M=&AE('5N<V5R:6%L:7IA=&EO;@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&UE=&AO9"!R97%U:7)E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W5N
M<V5R:6%L:7IE*"8D9&%T82P@)&UO9&4L("1P87)A;7,@/2!N=6QL*0H@("`@
M>PH@("`@("`@('-W:71C:"`H)&UO9&4I('L*("`@("`@("!C87-E(%-%4DE!
M3$E:15].3TY%.@H@("`@("`@(&-A<V4@4T5224%,25I%7U-13%A-3#H*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@4T5224%,25I%7U)!5SH*
M("`@("`@("`@("`@)&1A=&$@/2!R87=U<FQD96-O9&4H)&1A=&$I.PH@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!315))04Q)6D5?55),.@H@
M("`@("`@("`@("`D9&%T82`]('5R;&1E8V]D92@D9&%T82D["B`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("!C87-E(%-%4DE!3$E:15]71$18.@H@("`@
M("`@("`@("`D9&%T82`]('=D9'A?9&5S97)I86QI>F4H)&1A=&$I.PH@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!315))04Q)6D5?0EI)4#H*
M("`@("`@("`@("`@)&1A=&$@/2!B>F1E8V]M<')E<W,H)&1A=&$L(&9A;'-E
M*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@4T5224%,25I%
M7TE-05!55$8W.@H@("`@("`@("`@("`D9&%T82`](&EM87!?=71F-U]D96-O
M9&4H)&1A=&$I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!3
M15))04Q)6D5?0D%324,Z"B`@("`@("`@("`@("1D871A(#T@0'5N<V5R:6%L
M:7IE*"1D871A*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@
M4T5224%,25I%7T=:7T1%1DQ!5$4Z"B`@("`@("`@("`@("1D871A(#T@9WII
M;F9L871E*"1D871A*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@4T5224%,25I%7T)!4T4V-#H*("`@("`@("`@("`@)&1A=&$@/2!B87-E
M-C1?9&5C;V1E*"1D871A*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@4T5224%,25I%7T=:7T-/35!215-3.@H@("`@("`@("`@("`D9&%T
M82`](&=Z=6YC;VUP<F5S<R@D9&%T82D["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!C87-E(%-%4DE!3$E:15]55$8W.@H@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+U-T<FEN9RYP:'`G.PH@("`@("`@("`@("`D9&%T
M82`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&1A=&$L("=U=&8M-R<L("1P
M87)A;7,I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!315))
M04Q)6D5?551&-U]"05-)0SH*("`@("`@("`@("`@2&]R9&5?4V5R:6%L:7IE
M.CI?=6YS97)I86QI>F4H)&1A=&$L(%-%4DE!3$E:15]"05-)0RP@)'!A<F%M
M<RD["B`@("`@("`@("`@($AO<F1E7U-E<FEA;&EZ93HZ7W5N<V5R:6%L:7IE
M*"1D871A+"!315))04Q)6D5?551&-RP@)'!A<F%M<RD["B`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K
M('=H971H97(@;W(@;F]T(&$@<V5R:6%L:7IA=&EO;B!M971H;V0@:7,@<W5P
M<&]R=&5D+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1M;V1E("!4
M:&4@<V5R:6%L:7IA=&EO;B!M971H;V0N"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&EF('-U<'!O<G1E9"P@9F%L<V4@:68@;F]T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!H87-#87!A8FEL:71Y*"1M;V1E*0H@("`@
M>PH@("`@("`@('-W:71C:"`H)&UO9&4I('L*("`@("`@("!C87-E(%-%4DE!
M3$E:15]"6DE0.@H@("`@("`@("`@("!R971U<FX@571I;#HZ97AT96YS:6]N
M17AI<W1S*"=B>C(G*3L*"B`@("`@("`@8V%S92!315))04Q)6D5?5T1$6#H*
M("`@("`@("`@("`@<F5T=7)N(%5T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G=V1D
M>"<I.PH*("`@("`@("!C87-E(%-%4DE!3$E:15])34%0551&-SH*("`@("`@
M("!C87-E(%-%4DE!3$E:15])34%0551&.#H*("`@("`@("!C87-E(%-%4DE!
M3$E:15])34%0.#H*("`@("`@("`@("`@<F5T=7)N(%5T:6PZ.F5X=&5N<VEO
M;D5X:7-T<R@G:6UA<"<I.PH*("`@("`@("!C87-E(%-%4DE!3$E:15]'6E]$
M149,051%.@H@("`@("`@(&-A<V4@4T5224%,25I%7T=:7T-/35!215-3.@H@
M("`@("`@(&-A<V4@4T5224%,25I%7T=:7T5.0T]$.@H@("`@("`@("`@("!R
M971U<FX@571I;#HZ97AT96YS:6]N17AI<W1S*"=Z;&EB)RD["@H@("`@("`@
M(&-A<V4@4T5224%,25I%7U-13%A-3#H*("`@("`@("`@("`@<F5T=7)N($!I
M;F-L=61E7V]N8V4@)UA-3"]S<6PR>&UL+G!H<"<["@H@("`@("`@(&-A<V4@
M4T5224%,25I%7TY/3D4Z"B`@("`@("`@8V%S92!315))04Q)6D5?0D%324,Z
M"B`@("`@("`@8V%S92!315))04Q)6D5?0D%3138T.@H@("`@("`@(&-A<V4@
M4T5224%,25I%7U)!5SH*("`@("`@("!C87-E(%-%4DE!3$E:15]54DPZ"B`@
M("`@("`@8V%S92!315))04Q)6D5?551&-SH*("`@("`@("!C87-E(%-%4DE!
M3$E:15]55$8W7T)!4TE#.@H@("`@("`@("`@("!R971U<FX@=')U93L*"B`@
M("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U-E<W-I;VY(86YD
M;&5R+P``````````````````````````````````````````````````````
M```````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#4Q-30S,S<T-@`P,C(T,3``(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O4V5S<VEO;DAA;F1L97(O9&)M+G!H<```````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`V-#(S`#$P-3$U-#,S-S0V`#`R,S8W,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M4V5S<VEO;DAA;F1L97(Z.B!I;7!L96UE;G1A=&EO;B!F;W(@1$)-(&9I;&5S
M+@H@*B!.3U1%.B!4:&4@4$A0($1"32!F=6YC=&EO;G,@87)E(&1E<')E8V%T
M960N"B`J"B`J($YO(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!P87)A;65T
M97)S(&YE961E9"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4V5S<VEO;DAA
M;F1L97(O4V5S<VEO;DAA;F1L97(O9&)M+G!H<"QV(#$N.2XQ,BXW(#(P,#8O
M,#$O,#$@,C$Z,C@Z,S0@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R
M+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E
M($AO<F1E7U-E<W-I;VY(86YD;&5R"B`J+PIC;&%S<R!397-S:6]N2&%N9&QE
M<E]D8FT@97AT96YD<R!397-S:6]N2&%N9&QE<B!["@H@("`@+RHJ"B`@("`@
M*B!/=7(@<&]I;G1E<B!T;R!T:&4@1$)-(&9I;&4L(&EF(&]P96XN"B`@("`@
M*@H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@)%]D8FT[
M"@H@("`@+RHJ"B`@("`@*B!/<&5N('1H92!397-S:6]N2&%N9&QE<B!B86-K
M96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-A=F5?<&%T:"`@
M("`@5&AE('!A=&@@=&\@=&AE('-E<W-I;VX@;V)J96-T+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<V5S<VEO;E]N86UE("!4:&4@;F%M92!O9B!T:&4@<V5S
M<VEO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@
M<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!O<&5N*"1S879E7W!A=&@L("1S97-S:6]N7VYA;64I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]D8FT@/2!`9&)M;W!E;B@B)'-A=F5?<&%T:"\D<V5S<VEO
M;E]N86UE(BP@)V,G*3L*("`@("`@("!R971U<FX@)'1H:7,M/E]D8FT["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#;&]S92!T:&4@4V5S<VEO;DAA;F1L97(@
M8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@
M;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!C;&]S92@I"B`@("!["B`@("`@("`@<F5T=7)N($!D8FUC;&]S92@D
M=&AI<RT^7V1B;2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296%D('1H92!D
M871A(&9O<B!A('!A<G1I8W5L87(@<V5S<VEO;B!I9&5N=&EF:65R(&9R;VT@
M=&AE"B`@("`@*B!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@<V5S<VEO;B!I9&5N=&EF:65R
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<V5S<VEO;B!D
M871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D*"1I9"D*("`@('L*("`@
M("`@("!I9B`H)&1A=&$@/2!D8FUF971C:"@D=&AI<RT^7V1B;2P@)&ED*2D@
M>PH@("`@("`@("`@("!R971U<FX@8F%S938T7V1E8V]D92AS=6)S='(H)&1A
M=&$L('-T<G!O<R@D9&%T82P@)WPG*2`K(#$I*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@5W)I=&4@<V5S<VEO;B!D871A('1O('1H92!397-S:6]N
M2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&ED("`@("`@("`@("`@5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*("`@("`J
M($!P87)A;2!S=')I;F<@)'-E<W-I;VY?9&%T82`@5&AE('-E<W-I;VX@9&%T
M82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C
M8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W
M<FET92@D:60L("1S97-S:6]N7V1A=&$I"B`@("!["B`@("`@("`@<F5T=7)N
M($!D8FUR97!L86-E*"1T:&ES+3Y?9&)M+"`D:60L('1I;64H*2`N("=\)R`N
M(&)A<V4V-%]E;F-O9&4H)'-E<W-I;VY?9&%T82DI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1&5S=')O>2!T:&4@9&%T82!F;W(@82!P87)T:6-U;&%R('-E
M<W-I;VX@:61E;G1I9FEE<B!I;B!T:&4*("`@("`J(%-E<W-I;VY(86YD;&5R
M(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H
M92!S97-S:6]N(&ED96YT:69I97(N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9&5S=')O>2@D:60I"B`@("!["B`@("`@("`@
M:68@*"$H0&1B;61E;&5T92@D=&AI<RT^7V1B;2P@)&ED*2DI('L*("`@("`@
M("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T9A:6QE9"!T;R!D96QE=&4@<V5S
M<VEO;B`H:60@/2`G("X@)&ED("X@)RDG+"!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1V%R8F%G92!C;VQL96-T('-T86QE('-E<W-I;VYS(&9R;VT@=&AE
M(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&UA>&QI9F5T:6UE("!4:&4@;6%X:6UU;2!A9V4@;V8@82!S
M97-S:6]N+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O
M;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=C*"1M87AL:69E=&EM92`](#,P,"D*("`@('L*("`@("`@("`D97AP
M:7)E9"`]('1I;64H*2`M("1M87AL:69E=&EM93L*("`@("`@("`D:60@/2!D
M8FUF:7)S=&ME>2@D=&AI<RT^7V1B;2D["@H@("`@("`@('=H:6QE("@D:60I
M('L*("`@("`@("`@("`@:68@*"1D871A(#T@9&)M9F5T8V@H)'1H:7,M/E]D
M8FTL("1I9"DI('L*("`@("`@("`@("`@("`@("1A9V4@/2!S=6)S='(H)'1M
M<"P@,"P@<W1R<&]S*"1D871A+"`G?"<I*3L*("`@("`@("`@("`@("`@(&EF
M("@D97AP:7)E9"`^("1A9V4I('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^9&5S=')O>2@D:60I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D:60@/2!D8FUN97AT:V5Y*"1T:&ES+3Y?9&)M
M+"`D:60I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+U-E<W-I;VY(86YD;&5R+VQD87`N<&AP````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`Q,#`V-P`Q,#4Q-30S,S<T-@`P,C0P-#4`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M(%-E<W-I;VY(86YD;&5R(&EM<&QE;65N=&%T:6]N(&9O<B!,1$%0(&1I<F5C
M=&]R:65S+@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@
M)V9O;R<@("`@("`@5&AE(&9O;RX*("H*("H@3W!T:6]N86P@<&%R86UE=&5R
M<SH\<')E/@H@*B`@("=H;W-T<W!E8R<@(%1H92!H;W-T;F%M92!O9B!T:&4@
M;&1A<"!S97)V97(N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+VQD87`N<&AP+'8@,2XR+C(N,B`R,#`U
M+S$P+S$X(#$Q.C`Q.C(W(&IA;B!%>'`@)`H@*@H@*B!4:&ES(&-O9&4@:7,@
M861A<'1E9"!F<F]M('1H92!C;VUM96YT<R!A=`H@*B!H='1P.B\O=W=W+G!H
M<"YN970O<V5S<VEO;BUS970M<V%V92UH86YD;&5R+@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0'-I;F-E("`@2&]R9&4@,RXQ"B`J($!P86-K86=E($AO<F1E7U-E
M<W-I;VY(86YD;&5R"B`J+PIC;&%S<R!397-S:6]N2&%N9&QE<E]L9&%P(&5X
M=&5N9',@4V5S<VEO;DAA;F1L97(@>PH*("`@("\J*@H@("`@("H@2&%N9&QE
M(&9O<B!T:&4@8W5R<F5N="!D871A8F%S92!C;VYN96-T:6]N+@H@("`@("H*
M("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1?8V]N;CL*
M"B`@("`O*BH*("`@("`J($]P96X@=&AE(%-E<W-I;VY(86YD;&5R(&)A8VME
M;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V%V95]P871H("`@
M("!4:&4@<&%T:"!T;R!T:&4@<V5S<VEO;B!O8FIE8W0N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1S97-S:6]N7VYA;64@(%1H92!N86UE(&]F('1H92!S97-S
M:6]N+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S
M=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&]P96XH)'-A=F5?<&%T:"P@)'-E<W-I;VY?;F%M92D*("`@('L*("`@("`@
M("`D=&AI<RT^7V-O;FX@/2!`;&1A<%]C;VYN96-T*"1T:&ES+3Y?<&%R86US
M6R=H;W-T<W!E8R==+"`D=&AI<RT^7W!A<F%M<ULG<&]R="==*3L*("`@("`@
M("!R971U<FX@0&QD87!?8FEN9"@D=&AI<RT^7V-O;FXL("1T:&ES+3Y?<&%R
M86US6R=D;B==+"`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#;&]S92!T:&4@4V5S<VEO;DAA;F1L97(@8F%C
M:V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@
M<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!C;&]S92@I"B`@("!["B`@("`@("`@<F5T=7)N($!L9&%P7V-L;W-E*"1T
M:&ES+3Y?8V]N;BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296%D('1H92!D
M871A(&9O<B!A('!A<G1I8W5L87(@<V5S<VEO;B!I9&5N=&EF:65R(&9R;VT@
M=&AE"B`@("`@*B!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@<V5S<VEO;B!I9&5N=&EF:65R
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<V5S<VEO;B!D
M871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D*"1I9"D*("`@('L*("`@
M("`@("`D<W(@/2!`;&1A<%]S96%R8V@H)'1H:7,M/E]C;VYN+"`D=&AI<RT^
M7W!A<F%M<ULG9&XG72P@(BAC;CTD:60I(BD["B`@("`@("`@)&EN9F\@/2!`
M;&1A<%]G971?96YT<FEE<R@D=&AI<RT^7V-O;FXL("1S<BD["B`@("`@("`@
M:68@*"1I;F9O6R=C;W5N="==(#X@,"D@>PH@("`@("`@("`@("!R971U<FX@
M)&EN9F];,%U;)W-E<W-I;VXG75LP73L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@5W)I=&4@<V5S<VEO;B!D871A('1O('1H92!397-S:6]N2&%N9&QE
M<B!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("`@
M("`@("`@("`@5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*("`@("`J($!P87)A
M;2!S=')I;F<@)'-E<W-I;VY?9&%T82`@5&AE('-E<W-I;VX@9&%T82X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@
M9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET92@D
M:60L("1S97-S:6]N7V1A=&$I"B`@("!["B`@("`@("`@)'5P9&%T92`](&%R
M<F%Y*"=O8FIE8W1#;&%S<R<@/3X@87)R87DH)W!H<'-E<W-I;VXG+"`G=&]P
M)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("=S97-S:6]N)R`]/B`D<V5S
M<VEO;E]D871A*3L*("`@("`@("`D9&X@/2`B8VX])&ED+"(@+B`D=&AI<RT^
M7W!A<F%M<ULG9&XG73L*("`@("`@("!`;&1A<%]D96QE=&4H)'1H:7,M/E]C
M;VYN+"`D9&XI.PH@("`@("`@(')E='5R;B!`;&1A<%]A9&0H)'1H:7,M/E]C
M;VYN+"`D9&XL("1U<&1A=&4I.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5S
M=')O>2!T:&4@9&%T82!F;W(@82!P87)T:6-U;&%R('-E<W-I;VX@:61E;G1I
M9FEE<B!I;B!T:&4*("`@("`J(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!S97-S:6]N(&ED
M96YT:69I97(N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9&5S=')O>2@D:60I"B`@("!["B`@("`@("`@)&1N(#T@(F-N/21I
M9"PB("X@)'1H:7,M/E]P87)A;7-;)V1N)UT["B`@("`@("`@<F5T=7)N($!L
M9&%P7V1E;&5T92@D=&AI<RT^7V-O;FXL("1D;BD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'87)B86=E(&-O;&QE8W0@<W1A;&4@<V5S<VEO;G,@9G)O;2!T
M:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D;6%X;&EF971I;64@(%1H92!M87AI;75M(&%G92!O9B!A
M('-E<W-I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V,H)&UA>&QI9F5T:6UE(#T@,S`P*0H@("`@>PH@("`@("`@("1S
M<B`]($!L9&%P7W-E87)C:"@D=&AI<RT^7V-O;FXL("1T:&ES+3Y?<&%R86US
M6R=D;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`G*&]B:F5C=$-L
M87-S/7!H<'-E<W-I;VXI)RP@87)R87DH)RLG+"`G8VXG*2D["B`@("`@("`@
M)&EN9F\@/2!`;&1A<%]G971?96YT<FEE<R@D=&AI<RT^7V-O;FXL("1S<BD[
M"B`@("`@("`@:68@*"1I;F9O6R=C;W5N="==(#X@,"D@>PH@("`@("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"`D:6YF;ULG8V]U;G0G73L@)&DK*RD@>PH@
M("`@("`@("`@("`@("`@)&ED(#T@)&EN9F];)&E=6R=C;B==6S!=.PH@("`@
M("`@("`@("`@("`@)&1N(#T@(F-N/21I9"PB("X@)'1H:7,M/E]P87)A;7-;
M)V1N)UT["B`@("`@("`@("`@("`@("`D;&1A<'-T86UP(#T@)&EN9F];)&E=
M6R=M;V1I9GET:6UE<W1A;7`G75LP73L*("`@("`@("`@("`@("`@("1Y96%R
M(#T@<W5B<W1R*"1L9&%P<W1A;7`L(#`L(#0I.PH@("`@("`@("`@("`@("`@
M)&UO;G1H(#T@<W5B<W1R*"1L9&%P<W1A;7`L(#0L(#(I.PH@("`@("`@("`@
M("`@("`@)&1A>2`]('-U8G-T<B@D;&1A<'-T86UP+"`V+"`R*3L*("`@("`@
M("`@("`@("`@("1H;W5R(#T@<W5B<W1R*"1L9&%P<W1A;7`L(#@L(#(I.PH@
M("`@("`@("`@("`@("`@)&UI;G5T92`]('-U8G-T<B@D;&1A<'-T86UP+"`Q
M,"P@,BD["B`@("`@("`@("`@("`@("`D;6]D:69I960@/2!G;6UK=&EM92@D
M:&]U<BP@)&UI;G5T92P@,"P@)&UO;G1H+"`D9&%Y+"`D>65A<BD["B`@("`@
M("`@("`@("`@("!I9B`H=&EM92@I("T@)&UO9&EF:65D(#X]("1M87AL:69E
M=&EM92D@>PH@("`@("`@("`@("`@("`@("`@($!L9&%P7V1E;&5T92@D=&AI
M<RT^7V-O;FXL("1D;BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4V5S
M<VEO;DAA;F1L97(O;65M8V%C:&4N<&AP````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#$V,C$V`#$P-3$U-#,S-S0V`#`R-#8W,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@4V5S<VEO;DAA
M;F1L97(Z.B!I;7!L96UE;G1A=&EO;B!F;W(@;65M8V%C:&4N"B`J(&UE;6-A
M8VAE('=E8G-I=&4Z(&AT='`Z+R]W=W<N9&%N9V$N8V]M+VUE;6-A8VAE9"\*
M("H*("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=H;W-T<W!E
M8R<@(%1H92!H;W-T;F%M92!O9B!T:&4@;65M8V%C:&4@<V5R=F5R+@H@*B`@
M("=P;W)T)R`@("`@(%1H92!P;W)T(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@
M=&AE(&UE;6-A8VAE('-E<G9E<BX\+W!R93X*("H*("H@3W!T:6]N86P@<&%R
M86UE=&5R<SH\<')E/@H@*B`@("=P97)S:7-T96YT)R`@57-E('!E<G-I<W1E
M;G0@1$(@8V]N;F5C=&EO;G,_("AB;V]L96%N*0H@*B`@("=C;VUP<F5S<VEO
M;B<@57-E(&-O;7!R97-S:6]N('=H96X@<W1O<FEN9R!S97-S:6]N<RX\+W!R
M93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S
M<VEO;DAA;F1L97(O;65M8V%C:&4N<&AP+'8@,2XQ+C(N,2`R,#`V+S`U+S`R
M(#$W.C(W.C0Y(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P
M,#8@4F]N9RU%;B!&86X@/')A9F%N0&EN9F]R+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@(%)O;F<M16X@1F%N(#QR869A;D!I;F9O<BYO<F<^
M"B`J($!S:6YC92`@($AO<F1E(#,N,0H@*B!`<&%C:V%G92!(;W)D95]397-S
M:6]N2&%N9&QE<@H@*B\*8VQA<W,@4V5S<VEO;DAA;F1L97)?;65M8V%C:&4@
M97AT96YD<R!397-S:6]N2&%N9&QE<B!["@H@("`@+RHJ"B`@("`@*B!#=7)R
M96YT(&UE;6-A8VAE(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!O
M8FIE8W0*("`@("`J+PH@("`@=F%R("1?9&(["@H@("`@+RHJ"B`@("`@*B!"
M;V]L96%N(&EN9&EC871I;F<@=VAE=&AE<B!O<B!N;W0@=V4G<F4@8V]N;F5C
M=&5D('1O('1H90H@("`@("H@;65M8V%C:&4@<V5R=F5R+@H@("`@("H*("`@
M("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]C;VYN96-T960@
M/2!F86QS93L*"B`@("`O*BH*("`@("`J($QO8VL@:&%N9&QE+@H@("`@("H*
M("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1?9G`["@H@
M("`@+RHJ"B`@("`@*B!#;&]S92!T:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N
M9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C
M8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C
M;&]S92@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?8V]N;F5C=&5D*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?8V]N;F5C=&5D(#T@9F%L<V4["B`@("`@
M("`@("`@($!M96UC86-H95]C;&]S92@D=&AI<RT^7V1B*3L*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3Y?=6YL;V-K4V5S<VEO;B@I.PH@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5A9"!T:&4@9&%T
M82!F;W(@82!P87)T:6-U;&%R('-E<W-I;VX@:61E;G1I9FEE<B!F<F]M('1H
M90H@("`@("H@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('-E<W-I;VX@9&%T
M82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9"@D:60I"B`@("!["B`@("`@
M("`@+RH@3V)T86EN('-E<W-I;VX@;&]C:RX@*B\*("`@("`@("`D=&AI<RT^
M7VQO8VM397-S:6]N*"1I9"D["@H@("`@("`@("\J($UA:V4@<W5R92!W92!H
M879E(&$@=F%L:60@;65M8V%C:&4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D
M=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@)')E<W5L="`]($!M96UC86-H
M95]G970H)'1H:7,M/E]D8BP@)&ED*3L*("`@("`@("!I9B`H(21R97-U;'0I
M('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T5R<F]R(')E=')I
M979I;F<@<V5S<VEO;B!D871A("AI9"`]("<@+B`D:60@+B`G*2<L(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@)'1H
M:7,M/E]U;FQO8VM397-S:6]N*"D["B`@("`@("`@("`@($!U;FQI;FLH)'1H
M:7,M/E]P87)A;7-;)VQO8VM?9&ER)UT@+B`G+VQO8VM?)R`N("1I9"D["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@($AO
M<F1E.CIL;V=-97-S86=E*"=296%D('-E<W-I;VX@9&%T82`H:60@/2`G("X@
M)&ED("X@)RDG+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'
M*3L*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%=R:71E('-E<W-I;VX@9&%T82!T;R!T:&4@4V5S<VEO;DAA;F1L97(@
M8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@("`@
M("`@("`@(%1H92!S97-S:6]N(&ED96YT:69I97(N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1S97-S:6]N7V1A=&$@(%1H92!S97-S:6]N(&1A=&$N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A
M;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&4H)&ED
M+"`D<V5S<VEO;E]D871A*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W
M92!H879E(&$@=F%L:60@;65M8V%C:&4@8V]N;F5C=&EO;BX@*B\*("`@("`@
M("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@)&QI9F5T:6UE(#T@:6YI
M7V=E="@G<V5S<VEO;BYG8U]M87AL:69E=&EM92<I.PH@("`@("`@("1F;&%G
M<R`]("1T:&ES+3Y?<&%R86US6R=C;VUP<F5S<VEO;B==(#\@345-0T%#2$5?
M0T]-4%)%4U-%1"`Z(#`["B`@("`@("`@)')E<W5L="`]($!M96UC86-H95]S
M970H)'1H:7,M/E]D8BP@)&ED+"`D<V5S<VEO;E]D871A+"`D9FQA9W,L("1L
M:69E=&EM92D["@H@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@
M("!(;W)D93HZ;&]G365S<V%G92@G17)R;W(@=W)I=&EN9R!S97-S:6]N(&1A
M=&$@*&ED(#T@)R`N("1I9"`N("<I)RP@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=7<F]T92!S97-S:6]N
M(&1A=&$@*&ED(#T@)R`N("1I9"`N("<I)RP@7U]&24Q%7U\L(%]?3$E.15]?
M+"!014%27TQ/1U]$14)51RD["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1&5S=')O>2!T:&4@9&%T82!F;W(@82!P87)T
M:6-U;&%R('-E<W-I;VX@:61E;G1I9FEE<B!I;B!T:&4*("`@("`J(%-E<W-I
M;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D:60@(%1H92!S97-S:6]N(&ED96YT:69I97(N"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R
M=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5S=')O>2@D:60I"B`@("![
M"B`@("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V86QI9"!M96UC86-H
M92!C;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*
M("`@("`@("`D<F5S=6QT(#T@0&UE;6-A8VAE7V1E;&5T92@D=&AI<RT^7V1B
M+"`D:60I.PH*("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@
M2&]R9&4Z.FQO9TUE<W-A9V4H)T9A:6QE9"!T;R!D96QE=&4@<V5S<VEO;B`H
M:60@/2`G("X@)&ED("X@)RDG+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T1E;&5T960@<V5S<VEO;B!D
M871A("AI9"`]("<@+B`D:60@+B`G*2<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`D=&AI<RT^7W5N;&]C:U-E<W-I
M;VXH*3L*("`@("`@("!`=6YL:6YK*"1T:&ES+3Y?<&%R86US6R=L;V-K7V1I
M<B==("X@)R]L;V-K7R<@+B`D:60I.PH@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1V%R8F%G92!C;VQL96-T('-T86QE('-E
M<W-I;VYS(&9R;VT@=&AE(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UA>&QI9F5T:6UE("!4:&4@;6%X
M:6UU;2!A9V4@;V8@82!S97-S:6]N+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=C*"1M87AL:69E=&EM92`](#,P,"D*("`@
M('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M($%T=&5M<'1S('1O(&]P96X@82!C;VYN96-T:6]N('1O('1H92!M96UC86-H
M92!S97)V97(H<RDN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN96-T*"D*("`@('L*("`@("`@("!I
M9B`H)'1H:7,M/E]C;VYN96-T960I('L*("`@("`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H)T%L<F5A9'D@8V]N;F5C=&5D('1O(&$@;65M8V%C:&4@<V5R
M=F5R(&9O<B!M96UC86-H92!397-S:6]N2&%N9&QE<B<@+"!?7T9)3$5?7RP@
M7U],24Y%7U\L4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("!R971U<FX[
M"B`@("`@("`@?0H*("`@("`@("!(;W)D93HZ87-S97)T1')I=F5R0V]N9FEG
M*"1T:&ES+3Y?<&%R86US+"`G<V5S<VEO;FAA;F1L97(G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)VAO<W1S<&5C)RP@)W!O
M<G0G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S97-S
M:6]N(&AA;F1L97(@;65M8V%C:&4G*3L*"B`@("`@("`@:68@*&5M<'1Y*"1T
M:&ES+3Y?<&%R86US6R=P97)S:7-T96YT)UTI*2!["B`@("`@("`@("`@("1C
M;VYN96-T7W!E<G-I<W1E;G0@/2!F86QS93L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D8V]N;F5C=%]P97)S:7-T96YT(#T@=')U93L*("`@("`@
M("!]"B`@("`@("`@)&-O;B`](&YE=R!-96UC86-H93L*"B`@("`@("`@9F]R
M("@D:2`](#`L("1N(#T@8V]U;G0H)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C
M)UTI.R`D:2`\("1N.R`K*R1I*2!["B`@("`@("`@("`@(&EF("@A0"1C;VXM
M/F%D9%-E<G9E<B@D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G75LD:5TL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG<&]R="==6R1I72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1C;VYN96-T7W!E<G-I<W1E;G0I*2!["B`@("`@("`@("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92@G0V]U;&0@;F]T(&%D9"!;)R`N("1T:&ES+3Y?
M<&%R86US6R=H;W-T<W!E8R==6R1I72`N("<Z)R`N("1T:&ES+3Y?<&%R86US
M6R=P;W)T)UU;)&E=("X@)UT@87,@;65M8V%C:&4@<V5R=F5R(&9O<B!M96UC
M86-H92!397-S:6]N2&%N9&QE<B<@+"!?7T9)3$5?7RP@7U],24Y%7U\L4$5!
M4E],3T=?15)2*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*"=!9&1E9"!;)R`N("1T:&ES+3Y?<&%R
M86US6R=H;W-T<W!E8R==6R1I72`N("<Z)R`N("1T:&ES+3Y?<&%R86US6R=P
M;W)T)UU;)&E=("X@)UT@87,@;65M8V%C:&4@<V5R=F5R(&9O<B!M96UC86-H
M92!397-S:6]N2&%N9&QE<B<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?1$5"54<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VYN96-T960@
M/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!#
M:&5C:R!I9B!A;GD@;V8@=&AE('!O;VQE9"!C;VYN96-T:6]N<R!W;W)K<RX@
M*B\*("`@("`@("!I9B`H)&-O;BT^9V5T5F5R<VEO;B@I*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?9&(@/2`D8V]N.PH@("`@("`@("`@("`D=&AI<RT^7V-O
M;FYE8W1E9"`]('1R=64["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E
M*"=#;VYN96-T960@=&\@82!M96UC86-H92!S97)V97(@9F]R(&UE;6-A8VAE
M(%-E<W-I;VY(86YD;&5R)R`L(%]?1DE,15]?+"!?7TQ)3D5?7RQ014%27TQ/
M1U]$14)51RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M
M/E]C;VYN96-T960@/2!F86QS93L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE
M<W-A9V4H)T-O=6QD(&YO="!C;VYN96-T('1O(&%N>2!M96UC86-H92!S97)V
M97(@9F]R(&UE;6-A8VAE(%-E<W-I;VY(86YD;&5R)R`L(%]?1DE,15]?+"!?
M7TQ)3D5?7RQ014%27TQ/1U]%4E(I.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO
M;B!?;&]C:U-E<W-I;VXH)&ED*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9G`@
M/2!`9F]P96XH)'1H:7,M/E]P87)A;7-;)VQO8VM?9&ER)UT@+B`G+VQO8VM?
M)R`N("1I9"P@)W<K)RD["B`@("`@("`@:68@*"$D=&AI<RT^7V9P*2!["B`@
M("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=#;W5L9"!N;W0@;W!E;B!S
M97-S:6]N(&QO8VL@9F]R("<@+B`D:60L(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*("`@("`@("!I9B`H(4!F;&]C:R@D=&AI<RT^7V9P+"!,3T-+7T58
M*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G0V]U;&0@;F]T
M(&QO8VL@<V5S<VEO;B`G("X@)&ED+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%
M05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]U;FQO
M8VM397-S:6]N*"D*("`@('L*("`@("`@("!I9B`H:7-?<F5S;W5R8V4H)'1H
M:7,M/E]F<"DI('L*("`@("`@("`@("`@:68@*"%`9FQO8VLH)'1H:7,M/E]F
M<"P@3$]#2U]53BDI('L*("`@("`@("`@("`@("`@($AO<F1E.CIL;V=-97-S
M86=E*"=#;W5L9"!N;W0@=6YL;V-K('-E<W-I;VXG+"!?7T9)3$5?7RP@7U],
M24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@0&9C;&]S92@D=&AI<RT^7V9P*3L*("`@("`@("!]"B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]3
M97-S:6]N2&%N9&QE<B]M>7-Q;"YP:'``````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,C0R-#``,3`U,34T,S,W-#8`,#(T,C<P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!397-S:6]N
M2&%N9&QE<CHZ(&EM<&QE;65N=&%T:6]N(&9O<B!->5-13"`H;F%T:79E*2X*
M("H*("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=H;W-T<W!E
M8R<@("`M(%1H92!H;W-T;F%M92!O9B!T:&4@9&%T86)A<V4@<V5R=F5R+@H@
M*B`@("=P<F]T;V-O;"<@("`M(%1H92!C;VUM=6YI8V%T:6]N('!R;W1O8V]L
M("@G=&-P)RP@)W5N:7@G+"!E=&,N*2X*("H@("`G=7-E<FYA;64G("`@+2!4
M:&4@=7-E<FYA;64@=VET:"!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A
M8F%S92X*("H@("`G<&%S<W=O<F0G("`@+2!4:&4@<&%S<W=O<F0@87-S;V-I
M871E9"!W:71H("=U<V5R;F%M92<N"B`J("`@)V1A=&%B87-E)R`@("T@5&AE
M(&YA;64@;V8@=&AE(&1A=&%B87-E+@H@*B`@("=T86)L92<@("`@("`M(%1H
M92!N86UE(&]F('1H92!S97-S:6]N9&%T82!T86)L92!I;B`G9&%T86)A<V4G
M+@H@*B`@("=R;W=L;V-K:6YG)R`M(%=H971H97(@=&\@=7-E(')O=RUL979E
M;"!L;V-K:6YG(&%N9"!T<F%N<V%C=&EO;G,@*$EN;F]$0BD*("H@("`@("`@
M("`@("`@("`@("!O<B!T86)L92UL979E;"!L;V-K:6YG("A->4E304TI+CPO
M<')E/@H@*@H@*B!297%U:7)E9"!F;W(@<V]M92!C;VYF:6=U<F%T:6]N<SH\
M<')E/@H@*B`@("=P;W)T)R`@5&AE('!O<G0@;VX@=VAI8V@@=&\@8V]N;F5C
M="!T;R!T:&4@9&%T86)A<V4N/"]P<F4^"B`J"B`J($]P=&EO;F%L('!A<F%M
M971E<G,Z/'!R93X*("H@("`G<&5R<VES=&5N="<@(%5S92!P97)S:7-T96YT
M($1"(&-O;FYE8W1I;VYS/R`H8F]O;&5A;BD\+W!R93X*("H*("H@5&AE('1A
M8FQE('-T<G5C='5R92!F;W(@=&AE(%-E<W-I;VY(86YD;&5R(&-A;B!B92!F
M;W5N9"!I;@H@*B!H;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]S97-S:6]N:&%N
M9&QE<BYS<6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-E<W-I;VY(86YD
M;&5R+U-E<W-I;VY(86YD;&5R+VUY<W%L+G!H<"QV(#$N,38N,3(N,30@,C`P
M-B\P,R\R.2`Q.3HP-CHT-B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#(M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ
M/@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P-B!*86X@4V-H;F5I9&5R
M(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M36EK92!#;V-H<F%M92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0&%U
M=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E
M("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U-E<W-I;VY(86YD;&5R
M"B`J+PIC;&%S<R!397-S:6]N2&%N9&QE<E]M>7-Q;"!E>'1E;F1S(%-E<W-I
M;VY(86YD;&5R('L*"B`@("`O*BH*("`@("`J($AA;F1L92!F;W(@=&AE(&-U
M<G)E;G0@9&%T86)A<V4@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`=F%R
M(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D7V1B.PH*("`@("\J*@H@("`@
M("H@07)E('=E(&-O;FYE8W1E9"!T;R!T:&4@4U%,('-E<G9E<BX*("`@("`J
M"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?8V]N;F5C
M=&5D(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!#;&]S92!T:&4@4V5S<VEO
M;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!C;&]S92@I"B`@("!["B`@("`@("`@+RH@1&ES8V]N
M;F5C="!F<F]M(&1A=&%B87-E+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7V-O
M;FYE8W1E9"D@>PH@("`@("`@("`@("`D=&AI<RT^7V-O;FYE8W1E9"`](&9A
M;'-E.PH@("`@("`@("`@("!R971U<FX@0&UY<W%L7V-L;W-E*"1T:&ES+3Y?
M9&(I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!296%D('1H92!D871A(&9O<B!A('!A<G1I8W5L87(@
M<V5S<VEO;B!I9&5N=&EF:65R(&9R;VT@=&AE"B`@("`@*B!397-S:6]N2&%N
M9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED
M("!4:&4@<V5S<VEO;B!I9&5N=&EF:65R+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@<V5S<VEO;B!D871A+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R96%D*"1I9"D*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@
M:&%V92!A('9A;&ED(&1A=&%B87-E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@
M)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J(%-E<W-I;VX@=&EM96]U
M="P@9&]N)W0@<F5L>2!O;B!G87)B86=E(&-O;&QE8W1I;VXN("HO"B`@("`@
M("`@)'1I;65O=70@/2!T:6UE*"D@+2!I;FE?9V5T*"=S97-S:6]N+F=C7VUA
M>&QI9F5T:6UE)RD["@H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)U-%3$5#
M5"!S97-S:6]N7V1A=&$@1E)/32`E<R!72$5212!S97-S:6]N7VED(#T@)7,G
M("X*("`@("`@("`@("`@("`@("`@("`@("`@("<@04Y$('-E<W-I;VY?;&%S
M=&UO9&EF:65D(#X@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W%U;W1E*"1I9"DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&EM96]U="D["@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A
M;7-;)W)O=VQO8VMI;F<G72DI('L*("`@("`@("`@("`@+RH@4W1A<G0@82!T
M<F%N<V%C=&EO;BX@*B\*("`@("`@("`@("`@)')E<W5L="`]($!M>7-Q;%]Q
M=65R>2@G4U1!4E0@5%)!3E-!0U1)3TXG+"`D=&AI<RT^7V1B*3L*("`@("`@
M("`@("`@)'%U97)Y("X]("<@1D]2(%501$%412<["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)')E<W5L="`]($!M>7-Q;%]Q=65R>2@G3$]#2R!4
M04),15,@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==("X@)R!74DE412<L
M("1T:&ES+3Y?9&(I.PH@("`@("`@('T*("`@("`@("!I9B`H(21R97-U;'0I
M('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*"B`@("`@("`@
M+RH@3&]G('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X@*B\*("`@
M("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@475E<GD@8GD@
M4V5S<VEO;DAA;F1L97)?;7ES<6PZ.G)E860H*3H@<75E<GD@/2`B)7,B)RP@
M)'%U97)Y*2P*("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@
M7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@)')E<W5L="`]
M($!M>7-Q;%]Q=65R>2@D<75E<GDL("1T:&ES+3Y?9&(I.PH@("`@("`@(&EF
M("@A)')E<W5L="D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G
M17)R;W(@<F5T<FEE=FEN9R!S97-S:6]N(&1A=&$@*&ED(#T@)R`N("1I9"`N
M("<I)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L
M(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@
M)R<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@0&UY<W%L7W)E<W5L="@D
M<F5S=6QT+"`P+"`P*3L*("`@('T*"B`@("`O*BH*("`@("`J(%=R:71E('-E
M<W-I;VX@9&%T82!T;R!T:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@("`@("`@("`@(%1H92!S
M97-S:6]N(&ED96YT:69I97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97-S
M:6]N7V1A=&$@(%1H92!S97-S:6]N(&1A=&$N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&4H)&ED+"`D<V5S<VEO;E]D
M871A*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W92!H879E(&$@=F%L
M:60@9&%T86)A<V4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D=&AI<RT^7V-O
M;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*
M("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=215!,04-%($E.5$\@)7,@*'-E
M<W-I;VY?:60L('-E<W-I;VY?9&%T82P@<V5S<VEO;E]L87-T;6]D:69I960I
M)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`G(%9!3%5%4R`H)7,L("5S
M+"`E<RDG+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W%U;W1E*"1I9"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W%U;W1E*"1S97-S:6]N7V1A=&$I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@=&EM92@I*3L*"B`@("`@("`@)')E<W5L="`]($!M>7-Q;%]Q=65R>2@D
M<75E<GDL("1T:&ES+3Y?9&(I.PH@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^
M7W!A<F%M<ULG<F]W;&]C:VEN9R==*2D@>PH@("`@("`@("`@("!`;7ES<6Q?
M<75E<GDH)U5.3$]#2R!404),15,@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L
M92==+"`D=&AI<RT^7V1B*3L*("`@("`@("!]"B`@("`@("`@:68@*"$D<F5S
M=6QT*2!["B`@("`@("`@("`@($!M>7-Q;%]Q=65R>2@G4D],3$)!0TLG+"`D
M=&AI<RT^7V1B*3L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T5R
M<F]R('=R:71I;F<@<V5S<VEO;B!D871A)RP@7U]&24Q%7U\L(%]?3$E.15]?
M+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H*("`@("`@("!`;7ES<6Q?<75E<GDH)T-/34U)5"<L("1T:&ES
M+3Y?9&(I.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*
M("`@("`J($1E<W1R;WD@=&AE(&1A=&$@9F]R(&$@<&%R=&EC=6QA<B!S97-S
M:6]N(&ED96YT:69I97(@:6X@=&AE"B`@("`@*B!397-S:6]N2&%N9&QE<B!B
M86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@
M<V5S<VEO;B!I9&5N=&EF:65R+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&1E<W1R;WDH)&ED*0H@("`@>PH@("`@("`@("\J
M($UA:V4@<W5R92!W92!H879E(&$@=F%L:60@9&%T86)A<V4@8V]N;F5C=&EO
M;BX@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@
M0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`D<75E<GD@/2!S<')I
M;G1F*"=$14Q%5$4@1E)/32`E<R!72$5212!S97-S:6]N7VED(#T@)7,G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE
M)UTL("1T:&ES+3Y?<75O=&4H)&ED*2D["@H@("`@("`@("\J($QO9R!T:&4@
M<75E<GD@870@82!$14)51R!L;V<@;&5V96PN("HO"B`@("`@("`@2&]R9&4Z
M.FQO9TUE<W-A9V4H<W!R:6YT9B@G4U%,(%%U97)Y(&)Y(%-E<W-I;VY(86YD
M;&5R7VUY<W%L.CID97-T<F]Y*"DZ('%U97)Y(#T@(B5S(B<L("1Q=65R>2DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?
M+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("\J($5X96-U=&4@=&AE('%U
M97)Y+B`J+PH@("`@("`@("1R97-U;'0@/2!`;7ES<6Q?<75E<GDH)'%U97)Y
M+"`D=&AI<RT^7V1B*3L*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A
M;7-;)W)O=VQO8VMI;F<G72DI('L*("`@("`@("`@("`@0&UY<W%L7W%U97)Y
M*"=53DQ/0TL@5$%"3$53("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P@
M)'1H:7,M/E]D8BD["B`@("`@("`@?0H@("`@("`@(&EF("@A)')E<W5L="D@
M>PH@("`@("`@("`@("!`;7ES<6Q?<75E<GDH)U)/3$Q"04-+)RP@)'1H:7,M
M/E]D8BD["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=&86EL960@
M=&\@9&5L971E('-E<W-I;VX@*&ED(#T@)R`N("1I9"`N("<I)RP@7U]&24Q%
M7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!`;7ES<6Q?<75E<GDH)T-/
M34U)5"<L("1T:&ES+3Y?9&(I.PH*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J($=A<F)A9V4@8V]L;&5C="!S=&%L92!S97-S
M:6]N<R!F<F]M('1H92!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*
M("`@("`J($!P87)A;2!I;G1E9V5R("1M87AL:69E=&EM92`@5&AE(&UA>&EM
M=6T@86=E(&]F(&$@<V5S<VEO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G8R@D;6%X;&EF971I;64@/2`S,#`I"B`@("![
M"B`@("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V86QI9"!D871A8F%S
M92!C;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*
M("`@("`@("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y+B`J+PH@("`@("`@("1Q
M=65R>2`]('-P<FEN=&8H)T1%3$5412!&4D]-("5S(%=(15)%('-E<W-I;VY?
M;&%S=&UO9&EF:65D(#P@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL("AI;G0I*'1I;64H*2`M("1M87AL
M:69E=&EM92DI.PH*("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T(&$@1$5"
M54<@;&]G(&QE=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P
M<FEN=&8H)U-13"!1=65R>2!B>2!397-S:6]N2&%N9&QE<E]M>7-Q;#HZ9V,H
M*3H@<75E<GD@/2`B)7,B)RP@)'%U97)Y*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*
M"B`@("`@("`@+RH@17AE8W5T92!T:&4@<75E<GDN("HO"B`@("`@("`@)')E
M<W5L="`]($!M>7-Q;%]Q=65R>2@D<75E<GDL("1T:&ES+3Y?9&(I.PH@("`@
M("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92@G17)R;W(@9V%R8F%G92!C;VQL96-T:6YG(&]L9"!S97-S:6]N<R<L
M(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N($!M
M>7-Q;%]A9F9E8W1E9%]R;W=S*"1T:&ES+3Y?9&(I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1V5T(&$@;&ES="!O9B!T:&4@=F%L:60@<V5S<VEO;B!I9&5N
M=&EF:65R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&QI<W0@
M;V8@=F%L:60@<V5S<VEO;B!I9&5N=&EF:65R<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4V5S<VEO;DE$<R@I"B`@("!["B`@("`@("`@+RH@36%K92!S
M=7)E('=E(&AA=F4@82!V86QI9"!D871A8F%S92!C;VYN96-T:6]N+B`J+PH@
M("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`O*B!397-S:6]N
M('1I;65O=70L(&1O;B=T(')E;'D@;VX@9V%R8F%G92!C;VQL96-T:6]N("HO
M"B`@("`@("`@)'1I;65O=70@/2!T:6UE*"D@+2!I;FE?9V5T*"=S97-S:6]N
M+F=C7VUA>&QI9F5T:6UE)RD["@H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H
M)U-%3$5#5"!S97-S:6]N7VED($923TT@)7,G("X*("`@("`@("`@("`@("`@
M("`@("`@("`@("<@5TA%4D4@<V5S<VEO;E]L87-T;6]D:69I960@/B`E<R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("1T:6UE;W5T*3L*"B`@
M("`@("`@+RH@3&]G('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X@
M*B\*("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@475E
M<GD@8GD@4V5S<VEO;DAA;F1L97)?;7ES<6PZ.F=E=%-E<W-I;VY)1',H*3H@
M<75E<GD@/2`B)7,B)RP@)'%U97)Y*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@
M("`@("`@)')E<W5L="`]($!M>7-Q;%]Q=65R>2@D<75E<GDL("1T:&ES+3Y?
M9&(I.PH@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!(;W)D
M93HZ;&]G365S<V%G92@G17)R;W(@9V5T=&EN9R!S97-S:6]N($E$<R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@)'-E<W-I;VYS(#T@87)R87DH*3L*"B`@("`@
M("`@=VAI;&4@*"1R;W<@/2!M>7-Q;%]F971C:%]R;W<H)')E<W5L="DI"B`@
M("`@("`@("`@("1S97-S:6]N<UM=(#T@)')O=ULP73L*"B`@("`@("`@<F5T
M=7)N("1S97-S:6]N<SL*("`@('T*"B`@("`O*BH*("`@("`J($5S8V%P92!A
M(&UY<W%L('-T<FEN9RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU92`@5&AE('-T<FEN
M9R!T;R!Q=6]T92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M('%U;W1E9"!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]Q=6]T92@D
M=F%L=64I"B`@("!["B`@("`@("`@<W=I=&-H("AS=')T;VQO=V5R*&=E='1Y
M<&4H)'9A;'5E*2DI('L*("`@("`@("!C87-E("=N=6QL)SH*("`@("`@("`@
M("`@<F5T=7)N("=.54Q,)SL*"B`@("`@("`@8V%S92`G:6YT96=E<B<Z"B`@
M("`@("`@("`@(')E='5R;B`D=F%L=64["@H@("`@("`@(&-A<V4@)W-T<FEN
M9R<Z"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N("(G(B`N
M($!M>7-Q;%]R96%L7V5S8V%P95]S=')I;F<H)'9A;'5E+"`D=&AI<RT^7V1B
M*2`N("(G(CL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E
M;7!T<R!T;R!O<&5N(&$@8V]N;F5C=&EO;B!T;R!T:&4@4U%,('-E<G9E<BX*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V-O;FYE8W0H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V-O
M;FYE8W1E9"D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@
M("`@("!(;W)D93HZ87-S97)T1')I=F5R0V]N9FEG*"1T:&ES+3Y?<&%R86US
M+"`G<V5S<VEO;FAA;F1L97(G+`H@("`@("`@("`@("!A<G)A>2@G:&]S='-P
M96,G+"`G=7-E<FYA;64G+"`G9&%T86)A<V4G*2P*("`@("`@("`@("`@)W-E
M<W-I;VX@:&%N9&QE<B!->5-13"<I.PH*("`@("`@("!I9B`H96UP='DH)'1H
M:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=P87-S=V]R9"==(#T@)R<["B`@("`@("`@?0H*("`@("`@
M("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==(#T@)VAO<F1E7W-E<W-I
M;VYH86YD;&5R)SL*("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D=&AI
M<RT^7W!A<F%M<ULG<&5R<VES=&5N="==*2D@>PH@("`@("`@("`@("`D8V]N
M;F5C="`]("=M>7-Q;%]C;VYN96-T)SL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D8V]N;F5C="`]("=M>7-Q;%]P8V]N;F5C="<["B`@("`@("`@
M?0H*("`@("`@("!I9B`H(21T:&ES+3Y?9&(@/2!`)&-O;FYE8W0H)'1H:7,M
M/E]P87)A;7-;)VAO<W1S<&5C)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M92==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG<&%S<W=O<F0G72DI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%!%
M05(Z.G)A:7-E17)R;W(H)T-O=6QD(&YO="!C;VYN96-T('1O(&1A=&%B87-E
M(&9O<B!344P@4V5S<VEO;DAA;F1L97(N)RDL(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("`@("`@?0H*("`@("`@("!I9B`H(4!M>7-Q;%]S96QE8W1?9&(H
M)'1H:7,M/E]P87)A;7-;)V1A=&%B87-E)UTL("1T:&ES+3Y?9&(I*2!["B`@
M("`@("`@("`@($AO<F1E.CIF871A;"A014%2.CIR86ES945R<F]R*'-P<FEN
M=&8H)T-O=6QD(&YO="!C;VYN96-T('1O('1A8FQE("5S(&9O<B!344P@4V5S
M<VEO;DAA;F1L97(N)RP@)'1H:7,M/E]P87)A;7-;)V1A=&%B87-E)UTI+"!?
M7T9)3$5?7RP@7U],24Y%7U\I*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3Y?8V]N;F5C=&5D(#T@=')U93L*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,S4R,@`Q,#4Q-30S,S<T-@`P,C0P-C(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J(%-E<W-I;VY(86YD;&5R(&EM<&QE;65N=&%T:6]N(&9O<B!02%`G
M<R!B=6EL="UI;B!S97-S:6]N(&AA;F1L97(N"B`J"B`J(%)E<75I<F5D('!A
M<F%M971E<G,Z/'!R93X*("H@("!.;VYE+CPO<')E/@H@*@H@*B!/<'1I;VYA
M;"!P87)A;65T97)S.CQP<F4^"B`J("`@3F]N92X\+W!R93X*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O
M;F]N92YP:'`L=B`Q+C,N,BXT(#(P,#8O,#$O,#$@,C$Z,C@Z,S0@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@36%T="!396QS:WD@/'-E
M;'-K>4!C;VQU;6)I82YE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!-871T(%-E;'-K>2`\<V5L<VMY0&-O;'5M8FEA+F5D=3X*("H@0'-I;F-E
M("`@2&]R9&4@,RXQ"B`J($!P86-K86=E($AO<F1E7U-E<W-I;VY(86YD;&5R
M"B`J+PIC;&%S<R!397-S:6]N2&%N9&QE<E]N;VYE(&5X=&5N9',@4V5S<VEO
M;DAA;F1L97(@>PH*("`@("\J*@H@("`@("H@4F5A9"!T:&4@9&%T82!F;W(@
M82!P87)T:6-U;&%R('-E<W-I;VX@:61E;G1I9FEE<B!F<F]M('1H90H@("`@
M("H@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1I9"`@5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('-E<W-I;VX@9&%T82X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F5A9"@D:60I"B`@("!["B`@("`@("`@)&9I
M;&4@/2!S97-S:6]N7W-A=F5?<&%T:"@I("X@1$E214-43U)97U-%4$%2051/
M4B`N("=S97-S7R<@+B`D:60["@H@("`@("`@("1S97-S:6]N7V1A=&$@/2!`
M9FEL95]G971?8V]N=&5N=',H)&9I;&4I.PH@("`@("`@(&EF("@D<V5S<VEO
M;E]D871A(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B*2`N("1F:6QE
M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<V5S<VEO;E]D871A.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@;&ES="!O9B!T:&4@=F%L:60@
M<V5S<VEO;B!I9&5N=&EF:65R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!!(&QI<W0@;V8@=F%L:60@<V5S<VEO;B!I9&5N=&EF:65R<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T4V5S<VEO;DE$<R@I"B`@("!["B`@("`@
M("`@)'-E<W-I;VYS(#T@87)R87DH*3L*"B`@("`@("`@)'!A=&@@/2!S97-S
M:6]N7W-A=F5?<&%T:"@I.PH@("`@("`@("1D(#T@9&ER*&5M<'1Y*"1P871H
M*2`_(%5T:6PZ.F=E=%1E;7!$:7(H*2`Z("1P871H*3L*"B`@("`@("`@=VAI
M;&4@*&9A;'-E("$]/2`H)&5N=')Y(#T@)&0M/G)E860H*2DI('L*("`@("`@
M("`@("`@+RH@36%K92!S=7)E('=E)W)E(&1E86QI;F<@=VET:"!F:6QE<R!T
M:&%T('-T87)T('=I=&@*("`@("`@("`@("`@("H@<V5S<U\N("HO"B`@("`@
M("`@("`@(&EF("AI<U]F:6QE*"1D+3YP871H("X@1$E214-43U)97U-%4$%2
M051/4B`N("1E;G1R>2D@)B8*("`@("`@("`@("`@("`@("%S=')N8VUP*"1E
M;G1R>2P@)W-E<W-?)RP@<W1R;&5N*"=S97-S7R<I*2D@>PH@("`@("`@("`@
M("`@("`@)'-E<W-I;VYS6UT@/2!S=6)S='(H)&5N=')Y+"!S=')L96XH)W-E
M<W-?)RDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'-E<W-I;VYS.PH@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]397-S:6]N2&%N9&QE<B]O8VDX+G!H<```````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,C0P,S(`,3`U,34T,S,W-#8`,#(S-S8T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B!397-S:6]N2&%N9&QE<CHZ(&EM<&QE;65N=&%T:6]N(&9O<B!/<F%C;&4@
M.&D@*&YA=&EV92DN"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z/'!R93X*
M("H@("`G:&]S='-P96,G("!4:&4@:&]S=&YA;64@;V8@=&AE(&1A=&%B87-E
M('-E<G9E<BX*("H@("`G<')O=&]C;VPG("!4:&4@8V]M;75N:6-A=&EO;B!P
M<F]T;V-O;"`H)W1C<"<L("=U;FEX)RP@971C+BDN"B`J("`@)W5S97)N86UE
M)R`@5&AE('5S97)N86UE('=I=&@@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@
M9&%T86)A<V4N"B`J("`@)W!A<W-W;W)D)R`@5&AE('!A<W-W;W)D(&%S<V]C
M:6%T960@=VET:"`G=7-E<FYA;64G+@H@*B`@("=D871A8F%S92<@(%1H92!N
M86UE(&]F('1H92!D871A8F%S92X*("H@("`G=&%B;&4G("`@("!4:&4@;F%M
M92!O9B!T:&4@<V5S<VEO;F1A=&$@=&%B;&4@:6X@)V1A=&%B87-E)RX\+W!R
M93X*("H*("H@4F5Q=6ER960@9F]R('-O;64@8V]N9FEG=7)A=&EO;G,Z/'!R
M93X*("H@("`G<&]R="<@(%1H92!P;W)T(&]N('=H:6-H('1O(&-O;FYE8W0@
M=&\@=&AE(&1A=&%B87-E+CPO<')E/@H@*@H@*B!/<'1I;VYA;"!P87)A;65T
M97)S.CQP<F4^"B`J("`@)W!E<G-I<W1E;G0G("!5<V4@<&5R<VES=&5N="!$
M0B!C;VYN96-T:6]N<S\@*&)O;VQE86XI/"]P<F4^"B`J"B`J(%1H92!T86)L
M92!S=')U8W1U<F4@9F]R('1H92!397-S:6]N2&%N9&QE<B!C86X@8F4@9F]U
M;F0@:6X*("H@:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?<V5S<VEO;FAA;F1L
M97(N;V-I."YS<6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+V]C:3@N<&AP+'8@,2XX+C0N,3$@,C`P
M-B\P,B\Q,"`Q.#HT-CHU,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#,M,C`P-B!,:6%M($AO96ME;F=A(#QL:6%M<D!U;6EC:"YE9'4^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!,:6%M($AO96ME;F=A(#QL:6%M<D!U
M;6EC:"YE9'4^"B`J($!S:6YC92`@($AO<F1E(#(N,@H@*B!`<&%C:V%G92!(
M;W)D95]397-S:6]N2&%N9&QE<@H@*B\*8VQA<W,@4V5S<VEO;DAA;F1L97)?
M;V-I."!E>'1E;F1S(%-E<W-I;VY(86YD;&5R('L*"B`@("`O*BH*("`@("`J
M($AA;F1L92!F;W(@=&AE(&-U<G)E;G0@9&%T86)A<V4@8V]N;F5C=&EO;BX*
M("`@("`J"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D
M7V1B.PH*("`@("\J*@H@("`@("H@07)E('=E(&-O;FYE8W1E9"!T;R!T:&4@
M4U%,('-E<G9E<BX*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J
M+PH@("`@=F%R("1?8V]N;F5C=&5D(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@
M*B!#;&]S92!T:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@
M;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;&]S92@I"B`@("![
M"B`@("`@("`@:68@*"1T:&ES+3Y?8V]N;F5C=&5D*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?8V]N;F5C=&5D(#T@9F%L<V4["B`@("`@("`@("`@(')E='5R
M;B!/0TE,;V=/9F8H)'1H:7,M/E]D8BD["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E860@=&AE(&1A
M=&$@9F]R(&$@<&%R=&EC=6QA<B!S97-S:6]N(&ED96YT:69I97(@9G)O;2!T
M:&4*("`@("`J(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!S97-S:6]N(&ED96YT:69I97(N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!S97-S:6]N(&1A
M=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E860H)&ED*0H@("`@>PH@("`@
M("`@("\J($UA:V4@<W5R92!W92!H879E(&$@=F%L:60@9&%T86)A<V4@8V]N
M;F5C=&EO;BX@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@
M("`@)'-E;&5C=%]Q=65R>2`]('-P<FEN=&8H)U-%3$5#5"!S97-S:6]N7V1A
M=&$@1E)/32`E<R!72$5212!S97-S:6]N7VED(#T@)7,@1D]2(%501$%412<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W1A8FQE)UTL("1T:&ES+3Y?<75O=&4H)&ED*2D["@H@("`@("`@("\J
M($QO9R!T:&4@<75E<GD@870@82!$14)51R!L;V<@;&5V96PN("HO"B`@("`@
M("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G4U%,(%%U97)Y(&)Y(%-E
M<W-I;VY(86YD;&5R7V]C:3@Z.G)E860H*3H@<75E<GD@/2`B)7,B)RP@)'-E
M;&5C=%]Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%
M7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("\J($5X
M96-U=&4@<75E<GD@*B\*("`@("`@("`D<V5L96-T7W-T871E;65N="`]($]#
M25!A<G-E*"1T:&ES+3Y?9&(L("1S96QE8W1?<75E<GDI.PH@("`@("`@($]#
M245X96-U=&4H)'-E;&5C=%]S=&%T96UE;G0I.PH@("`@("`@(&EF("@A3T-)
M1F5T8VA);G1O*"1S96QE8W1?<W1A=&5M96YT+"`D<F5S=6QT*2D@>PH@("`@
M("`@("`@("`D:6YS97)T7W%U97)Y(#T@<W!R:6YT9B@G24Y315)4($E.5$\@
M)7,@*'-E<W-I;VY?:60L('-E<W-I;VY?;&%S=&UO9&EF:65D+"!S97-S:6]N
M7V1A=&$I(%9!3%5%4R`H)7,L("5S+"!%35!465]"3$]"*"DI(%)%5%523DE.
M1R!S97-S:6]N7V1A=&$@24Y43R`Z8FQO8B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W%U
M;W1E*"1I9"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<75O=&4H=&EM92@I*2D["B`@("`@("`@("`@("1I;G-E<G1?
M<W1A=&5M96YT(#T@3T-)4&%R<V4H)'1H:7,M/E]D8BP@)&EN<V5R=%]Q=65R
M>2D["B`@("`@("`@("`@("1L;V(@/2!/0TE.97=$97-C<FEP=&]R*"1T:&ES
M+3Y?9&(I.PH@("`@("`@("`@("!/0TE":6YD0GE.86UE*"1I;G-E<G1?<W1A
M=&5M96YT+"`G.F)L;V(G+"`D;&]B+"`M,2P@4U%,5%]"3$]"*3L*("`@("`@
M("`@("`@3T-)17AE8W5T92@D:6YS97)T7W-T871E;65N="P@3T-)7T1%1D%5
M3%0I.PH@("`@("`@("`@("!I9B`H)'-E<W-I;VY?9&%T82D@>PH@("`@("`@
M("`@("`@("`@)&QO8BT^<V%V92@D<V5S<VEO;E]D871A*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D<F5S=6QT(#T@3T-)0V]M;6ET*"1T:&ES+3Y?
M9&(I.PH@("`@("`@("`@("!/0TE&<F5E4W1A=&5M96YT*"1I;G-E<G1?<W1A
M=&5M96YT*3L*("`@("`@("`@("`@3T-)17AE8W5T92@D<V5L96-T7W-T871E
M;65N="D["B`@("`@("`@("`@($]#249E=&-H26YT;R@D<V5L96-T7W-T871E
M;65N="P@)')E<W5L="D["B`@("`@("`@?0H@("`@("`@("1V86QU92`]("1R
M97-U;'1;,%TM/FQO860H*3L*("`@("`@("!/0TE&<F5E4W1A=&5M96YT*"1S
M96QE8W1?<W1A=&5M96YT*3L*("`@("`@("!R971U<FXH)'9A;'5E*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%=R:71E('-E<W-I;VX@9&%T82!T;R!T:&4@
M4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1I9"`@("`@("`@("`@(%1H92!S97-S:6]N(&ED96YT:69I97(N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97-S:6]N7V1A=&$@(%1H92!S97-S
M:6]N(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@=W)I=&4H)&ED+"`D<V5S<VEO;E]D871A*0H@("`@>PH@("`@("`@
M("\J($UA:V4@<W5R92!W92!H879E(&$@=F%L:60@9&%T86)A<V4@8V]N;F5C
M=&EO;BX@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@
M+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`D<75E<GD@/2!S
M<')I;G1F*"=54$1!5$4@)7,@4T54('-E<W-I;VY?;&%S=&UO9&EF:65D(#T@
M)7,L('-E<W-I;VY?9&%T82`]($5-4%197T),3T(H*2!72$5212!S97-S:6]N
M7VED(#T@)7,@4D5455).24Y'('-E<W-I;VY?9&%T82!)3E1/(#IB;&]B)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L
M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]Q=6]T92AT
M:6UE*"DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]Q=6]T
M92@D:60I*3L*"B`@("`@("`@+RH@3&]G('1H92!Q=65R>2!A="!A($1%0E5'
M(&QO9R!L979E;"X@*B\*("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I
M;G1F*"=344P@475E<GD@8GD@4V5S<VEO;DAA;F1L97)?;V-I.#HZ=W)I=&4H
M*3H@<75E<GD@/2`B)7,B)RP@)'%U97)Y*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*
M"B`@("`@("`@+RH@17AE8W5T92!Q=65R>2`J+PH@("`@("`@("1S=&%T96UE
M;G0@/2!/0TE087)S92@D=&AI<RT^7V1B+"`D<75E<GDI.PH@("`@("`@("1L
M;V(@/2!/0TE.97=$97-C<FEP=&]R*"1T:&ES+3Y?9&(I.PH@("`@("`@($]#
M24)I;F1">4YA;64H)'-T871E;65N="P@)SIB;&]B)RP@)&QO8BP@+3$L(%-1
M3%1?0DQ/0BD["B`@("`@("`@3T-)17AE8W5T92@D<W1A=&5M96YT+"!/0TE?
M1$5&055,5"D["B`@("`@("`@:68@*"1S97-S:6]N7V1A=&$I('L*("`@("`@
M("`@("`@)&QO8BT^<V%V92@D<V5S<VEO;E]D871A*3L*("`@("`@("!]"B`@
M("`@("`@)')E<W5L="`]($]#24-O;6UI="@D=&AI<RT^7V1B*3L*("`@("`@
M("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)T5R<F]R('=R:71I;F<@<V5S<VEO;B!D871A)RP@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J($1E<W1R;WD@=&AE(&1A=&$@9F]R(&$@<&%R=&EC=6QA
M<B!S97-S:6]N(&ED96YT:69I97(@:6X@=&AE"B`@("`@*B!397-S:6]N2&%N
M9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED
M("!4:&4@<V5S<VEO;B!I9&5N=&EF:65R+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E<W1R;WDH)&ED*0H@("`@>PH@("`@
M("`@("\J($UA:V4@<W5R92!W92!H879E(&$@=F%L:60@9&%T86)A<V4@8V]N
M;F5C=&EO;BX@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@
M("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`D<75E<GD@
M/2!S<')I;G1F*"`G1$5,151%($923TT@)7,@5TA%4D4@<V5S<VEO;E]I9"`]
M("5S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG=&%B;&4G72P@)'1H:7,M/E]Q=6]T92@D:60I*3L*"B`@("`@("`@+RH@
M3&]G('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X@*B\*("`@("`@
M("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@475E<GD@8GD@4V5S
M<VEO;DAA;F1L97)?;V-I.#HZ9&5S=')O>2@I.B!Q=65R>2`]("(E<R(G+"`D
M<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`O*B!%>&5C=71E
M('1H92!Q=65R>2X@*B\*("`@("`@("`D<W1A=&5M96YT(#T@3T-)4&%R<V4H
M)'1H:7,M/E]D8BP@)'%U97)Y*3L*("`@("`@("`D<F5S=6QT(#T@3T-)17AE
M8W5T92@D<W1A=&5M96YT*3L*("`@("`@("!I9B`H(21R97-U;'0I('L*("`@
M("`@("`@("`@3T-)1G)E95-T871E;65N="@D<W1A=&5M96YT*3L*("`@("`@
M("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T9A:6QE9"!T;R!D96QE=&4@<V5S
M<VEO;B`H:60@/2`G("X@)&ED("X@)RDG+"!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@($]#249R9653=&%T96UE;G0H)'-T871E;65N="D[
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M87)B86=E(&-O;&QE8W0@<W1A;&4@<V5S<VEO;G,@9G)O;2!T:&4@4V5S<VEO
M;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D;6%X;&EF971I;64@(%1H92!M87AI;75M(&%G92!O9B!A('-E<W-I;VXN
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E
M<W,L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V,H
M)&UA>&QI9F5T:6UE(#T@,2D*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@
M=V4@:&%V92!A('9A;&ED(&1A=&%B87-E(&-O;FYE8W1I;VXN("HO"B`@("`@
M("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J($)U:6QD('1H92!3
M44P@<75E<GDN("HO"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G1$5,151%
M($923TT@)7,@5TA%4D4@<V5S<VEO;E]L87-T;6]D:69I960@/"`E<R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G
M72P@)'1H:7,M/E]Q=6]T92AT:6UE*"D@+2`D;6%X;&EF971I;64I*3L*"B`@
M("`@("`@+RH@3&]G('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X@
M*B\*("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@475E
M<GD@8GD@4V5S<VEO;DAA;F1L97)?;V-I.#HZ9V,H*3H@<75E<GD@/2`B)7,B
M)RP@)'%U97)Y*2P*("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@+RH@17AE
M8W5T92!T:&4@<75E<GDN("HO"B`@("`@("`@)'-T871E;65N="`]($]#25!A
M<G-E*"1T:&ES+3Y?9&(L("1Q=65R>2D["B`@("`@("`@)')E<W5L="`]($]#
M245X96-U=&4H)'-T871E;65N="D["B`@("`@("`@:68@*"$D<F5S=6QT*2![
M"B`@("`@("`@("`@($]#249R9653=&%T96UE;G0H)'-T871E;65N="D["B`@
M("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=%<G)O<B!G87)B86=E(&-O
M;&QE8W1I;F<@;VQD('-E<W-I;VYS)RP@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("!/0TE&<F5E4W1A=&5M96YT*"1S=&%T96UE;G0I.PH@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T
M(&$@;&ES="!O9B!T:&4@=F%L:60@<V5S<VEO;B!I9&5N=&EF:65R<RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&QI<W0@;V8@=F%L:60@<V5S
M<VEO;B!I9&5N=&EF:65R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4V5S
M<VEO;DE$<R@I"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@
M82!V86QI9"!D871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES
M+3Y?8V]N;F5C="@I.PH*("`@("`@("`O*B!397-S:6]N('1I;65O=70L(&1O
M;B=T(')E;'D@;VX@9V%R8F%G92!C;VQL96-T:6]N("HO"B`@("`@("`@)'1I
M;65O=70@/2!T:6UE*"D@+2!I;FE?9V5T*"=S97-S:6]N+F=C7VUA>&QI9F5T
M:6UE)RD["@H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)U-%3$5#5"!S97-S
M:6]N7VED($923TT@)7,G("X*("`@("`@("`@("`@("`@("`@("`@("`@("<@
M5TA%4D4@<V5S<VEO;E]L87-T;6]D:69I960@/B`E<R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:6UE;W5T*3L*"B`@("`@("`@+RH@3&]G
M('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X@*B\*("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@475E<GD@8GD@4V5S<VEO
M;DAA;F1L97)?;V-I.#HZ9V5T4V5S<VEO;DE$<R@I.B!Q=65R>2`]("(E<R(G
M+"`D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`O*B!%>&5C
M=71E('%U97)Y("HO"B`@("`@("`@)'-T871E;65N="`]($]#25!A<G-E*"1T
M:&ES+3Y?9&(L("1Q=65R>2D["B`@("`@("`@3T-)17AE8W5T92@D<W1A=&5M
M96YT*3L*"B`@("`@("`@)'-E<W-I;VYS(#T@87)R87DH*3L*("`@("`@("!W
M:&EL92`H3T-)1F5T8VA);G1O*"1S=&%T96UE;G0L("1R;W<I*2!["B`@("`@
M("`@("`@("1S97-S:6]N<UM=(#T@)')O=ULP73L*("`@("`@("!]"@H@("`@
M("`@($]#249R9653=&%T96UE;G0H)'-T871E;65N="D["B`@("`@("`@<F5T
M=7)N("1S97-S:6]N<SL*("`@('T*"B`@("`O*BH*("`@("`J($5S8V%P92!A
M('-T<FEN9R!F;W(@:6YS97)T:6]N+B!3=&]L96X@9G)O;2!014%2.CI$0BX*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'9A;'5E("!4:&4@<W1R:6YG('1O('%U;W1E+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@<75O=&5D('-T<FEN9RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W%U;W1E*"1V86QU92D*("`@('L*("`@("`@("!R
M971U<FX@*"1V86QU92`]/3T@;G5L;"D@/R`G3E5,3"<@.B`B)R(@+B!S=')?
M<F5P;&%C92@B)R(L("(G)R(L("1V86QU92D@+B`B)R(["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!O<&5N(&$@8V]N;F5C=&EO;B!T;R!T
M:&4@4U%,('-E<G9E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H*0H@("`@>PH@("`@("`@
M(&EF("@D=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@("`@("!R971U<FX[
M"B`@("`@("`@?0H*("`@("`@("!(;W)D93HZ87-S97)T1')I=F5R0V]N9FEG
M*"1T:&ES+3Y?<&%R86US+"`G<V5S<VEO;FAA;F1L97(G+`H@("`@("`@("`@
M("!A<G)A>2@G:&]S='-P96,G+"`G=7-E<FYA;64G+"`G<&%S<W=O<F0G*2P*
M("`@("`@("`@("`@)W-E<W-I;VX@:&%N9&QE<B!/<F%C;&4G*3L*"B`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DI('L*("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@/2`G:&]R9&5?<V5S
M<VEO;FAA;F1L97(G.PH@("`@("`@('T*"B`@("`@("`@:68@*&9U;F-T:6]N
M7V5X:7-T<R@G;V-I7V-O;FYE8W0G*2D@>PH@("`@("`@("`@("!I9B`H96UP
M='DH)'1H:7,M/E]P87)A;7-;)W!E<G-I<W1E;G0G72DI('L*("`@("`@("`@
M("`@("`@("1C;VYN96-T(#T@)V]C:5]C;VYN96-T)SL*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1C;VYN96-T(#T@)V]C:5]P8V]N
M;F5C="<["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)W!E<G-I<W1E;G0G72DI
M('L*("`@("`@("`@("`@("`@("1C;VYN96-T(#T@)T]#24QO9V]N)SL*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1C;VYN96-T(#T@
M)T]#25!,;V=O;B<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(&EF("@A:7-?<F5S;W5R8V4H)'1H:7,M/E]D8B`]($`D8V]N;F5C="@D=&AI
M<RT^7W!A<F%M<ULG=7-E<FYA;64G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!A
M<W-W;W)D)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==*2DI('L*
M("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%!%05(Z.G)A:7-E17)R;W(H)T-O
M=6QD(&YO="!C;VYN96-T('1O(&1A=&%B87-E(&9O<B!344P@4V5S<VEO;DAA
M;F1L97(N)RDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^7V-O;FYE8W1E9"`]('1R=64["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+W!G<W%L+G!H
M<``````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R-S8U,0`Q,#4Q-30S,S<T-@`P
M,C0R-C(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%!O<W1G<F5344P@4V5S<VEO;B!(86YD;&5R(&9O
M<B!02%`@*&YA=&EV92DN"B`J"B`J($-O<'ER:6=H="`R,#`P+3(P,#8@2F]N
M(%!A<FES92`\:F]N0&-S:"YR:70N961U/BX@($%L;"!R:6=H=',@<F5S97)V
M960N"B`J"B`J("!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A
M;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@(&UO9&EF:6-A
M=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I
M;F<@8V]N9&ET:6]N<PH@*B`@87)E(&UE=#H*("H@(#$N(%)E9&ES=')I8G5T
M:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P
M>7)I9VAT"B`J("`@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS
M(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J("`R+B!2961I<W1R
M:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B
M;W9E(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N
M9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN('1H90H@
M*B`@("`@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R
M;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BX*("H*("H@(%1(25,@4T]&
M5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($%55$A/4B!!3D0@0T].5%))0E54
M3U)3(&!@05,@25,G)R!!3D0*("H@($%.62!%6%!215-3($]2($E-4$Q)140@
M5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4($Q)34E4140@5$\L(%1(
M10H@*B`@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!
M3D0@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/4T4*("H@($%212!$
M25-#3$%)345$+B`@24X@3D\@159%3E0@4TA!3$P@5$A%($%55$A/4B!/4B!#
M3TY44DE"551/4E,@0D4@3$E!0DQ%"B`J("!&3U(@04Y9($1)4D5#5"P@24Y$
M25)%0U0L($E.0TE$14Y404PL(%-014-)04PL($5814U03$%262P@3U(@0T].
M4T51545.5$E!3`H@*B`@1$%-04=%4R`H24Y#3%5$24Y'+"!"550@3D]4($Q)
M34E4140@5$\L(%!23T-54D5-14Y4($]&(%-50E-425155$4@1T]/1%,*("H@
M($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@1$%402P@3U(@4%)/1DE44SL@
M3U(@0E5324Y%4U,@24Y415)255!424].*0H@*B`@2$]7159%4B!#0553140@
M04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E.($-/
M3E1204-4+"!35%))0U0*("H@($Q)04))3$E462P@3U(@5$]25"`H24Y#3%5$
M24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E.($%.62!7
M05D*("H@($]55"!/1B!42$4@55-%($]&(%1(25,@4T]&5%=!4D4L($5614X@
M248@041625-%1"!/1B!42$4@4$]34TE"24Q)5%D@3T8*("H@(%-50T@@1$%-
M04=%+@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@)V1A
M=&%B87-E)R`@5&AE(&YA;64@;V8@=&AE(&1A=&%B87-E+@H@*B`@("=P87-S
M=V]R9"<@(%1H92!P87-S=V]R9"!A<W-O8VEA=&5D('=I=&@@)W5S97)N86UE
M)RX*("H@("`G<')O=&]C;VPG("!4:&4@8V]M;75N:6-A=&EO;B!P<F]T;V-O
M;"`H)W1C<"<L("=U;FEX)RDN"B`J("`@)W5S97)N86UE)R`@5&AE('5S97)N
M86UE('=I=&@@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J
M"B`J(%)E<75I<F5D(&9O<B!S;VUE(&-O;F9I9W5R871I;VYS("AI+F4N("=P
M<F]T;V-O;"<@/2`G=&-P)RDZ/'!R93X*("H@("`G:&]S='-P96,G("!4:&4@
M:&]S=&YA;64@;V8@=&AE(&1A=&%B87-E('-E<G9E<BX*("H@("`G<&]R="<@
M("`@("!4:&4@<&]R="!O;B!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A
M8F%S92X\+W!R93X*("H*("H@3W!T:6]N86P@<&%R86UE=&5R<SH\<')E/@H@
M*B`@("=P97)S:7-T96YT)R`@57-E('!E<G-I<W1E;G0@1$(@8V]N;F5C=&EO
M;G,_("AB;V]L96%N*0H@*B`@("`@("`@("`@("`@("`@1&5F875L=#H@3D\*
M("H@("`G=&%B;&4G("`@("`@(%1H92!N86UE(&]F('1H92!S97-S:6]N9&%T
M82!T86)L92!I;B`G9&%T86)A<V4G+@H@*B`@("`@("`@("`@("`@("`@1&5F
M875L=#H@)VAO<F1E7W-E<W-I;VYH86YD;&5R)SPO<')E/@H@*@H@*B!4:&4@
M=&%B;&4@<W1R=6-T=7)E(&9O<B!T:&4@4V5S<VEO;DAA;F1L97(@8V%N(&)E
M(&9O=6YD(&EN"B`J(&AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W-E<W-I;VYH
M86YD;&5R+G!G<W%L+G-Q;"X*("H*("H@0V]N=')I8G5T;W)S.CQP<F4^"B`J
M("!*87-O;B!#87)L<V]N("`@("`@("`@("!2971U<FX@86X@96UP='D@<W1R
M:6YG(&]N(&9A:6QE9"!R96%D<PH@*B`@<&%T0'!C<')O9W)A;6UE<BYC;VT@
M("`@4&5R9F]R;2!U<&1A=&4@:6X@82!S:6YG;&4@=')A;G-A8W1I;VX*("H@
M($IO;F%T:&%N($-R;VUP=&]N("`@("`@($QO8VL@<F]W(&9O<B!L:69E(&]F
M('-E<W-I;VX\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O<&=S<6PN<&AP+'8@,2XQ,BXQ,"XQ
M-2`R,#`V+S`S+S(S(#$X.C`P.C$W(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R
M("!*;VX@4&%R:7-E(#QJ;VY`8W-H+G)I="YE9'4^"B`J($!S:6YC92`@($AO
M<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]397-S:6]N2&%N9&QE<@H@*B\*
M8VQA<W,@4V5S<VEO;DAA;F1L97)?<&=S<6P@97AT96YD<R!397-S:6]N2&%N
M9&QE<B!["@H@("`@+RHJ"B`@("`@*B!(86YD;&4@9F]R('1H92!C=7)R96YT
M(&1A=&%B87-E(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!R97-O
M=7)C90H@("`@("HO"B`@("!V87(@)%]D8CL*"B`@("`O*BH*("`@("`J($%R
M92!W92!C;VYN96-T960@=&\@=&AE(%-13"!S97)V97(N"B`@("`@*@H@("`@
M("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V-O;FYE8W1E9"`]
M(&9A;'-E.PH*("`@("\J*@H@("`@("H@0VQO<V4@=&AE(%-E<W-I;VY(86YD
M;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@8VQO<V4H*0H@("`@>PH@("`@("`@("\J($1I<V-O;FYE8W0@
M9G)O;2!D871A8F%S92X@*B\*("`@("`@("!I9B`H)'1H:7,M/E]C;VYN96-T
M960I('L*("`@("`@("`@("`@)'1H:7,M/E]C;VYN96-T960@/2!F86QS93L*
M("`@("`@("`@("`@<F5T=7)N($!P9U]C;&]S92@D=&AI<RT^7V1B*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5A9"!T:&4@9&%T82!F;W(@82!P87)T:6-U;&%R('-E<W-I;VX@
M:61E;G1I9FEE<B!F<F]M('1H90H@("`@("H@4V5S<VEO;DAA;F1L97(@8F%C
M:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE('-E
M<W-I;VX@:61E;G1I9FEE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE('-E<W-I;VX@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A
M9"@D:60I"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V
M86QI9"!D871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?
M8V]N;F5C="@I.PH*("`@("`@("!`<&=?<75E<GDH)'1H:7,M/E]D8BP@)T)%
M1TE..R<I.PH*("`@("`@("`D=&EM96]U="`]('1I;64H*2`M(&EN:5]G970H
M)W-E<W-I;VXN9V-?;6%X;&EF971I;64G*3L*("`@("`@("`D<75E<GD@/2!S
M<')I;G1F*"=314Q%0U0@<V5S<VEO;E]D871A($923TT@)7,@5TA%4D4@)R`N
M"B`@("`@("`@("`@("`@("`@("`@("`@("`G<V5S<VEO;E]I9"`]("5S($%.
M1"!S97-S:6]N7VQA<W1M;V1I9FEE9"`^/2`E<R`G("X*("`@("`@("`@("`@
M("`@("`@("`@("`@("=&3U(@55!$051%.R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YQ=6]T92@D:60I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1I;65O=70I.PH*("`@("`@("`O*B!,;V<@=&AE('%U
M97)Y(&%T(&$@1$5"54<@;&]G(&QE=F5L+B`J+PH@("`@("`@($AO<F1E.CIL
M;V=-97-S86=E*'-P<FEN=&8H)U-13"!1=65R>2!B>2!397-S:6]N2&%N9&QE
M<E]P9W-Q;#HZ)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<F5A9"@I.B!Q=65R>2`]("(E<R(G+"`D<75E<GDI+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?
M1$5"54<I.PH*("`@("`@("`D<F5S=6QT(#T@0'!G7W%U97)Y*"1T:&ES+3Y?
M9&(L("1Q=65R>2D["B`@("`@("`@)&1A=&$@/2!P9U]F971C:%]R97-U;'0H
M)')E<W5L="P@,"P@)W-E<W-I;VY?9&%T82<I.PH@("`@("`@('!G7V9R965?
M<F5S=6QT*"1R97-U;'0I.PH*("`@("`@("!R971U<FX@<&%C:R@G2"HG+"`D
M9&%T82D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!7<FET92!S97-S:6]N(&1A
M=&$@=&\@=&AE(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D:60@("`@("`@("`@("!4:&4@<V5S<VEO;B!I
M9&5N=&EF:65R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5S<VEO;E]D871A
M("!4:&4@<V5S<VEO;B!D871A+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('=R:71E*"1I9"P@)'-E<W-I;VY?9&%T82D*("`@
M('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@:&%V92!A('9A;&ED(&1A=&%B
M87-E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D[
M"@H@("`@("`@("1T:6UE;W5T(#T@=&EM92@I("T@:6YI7V=E="@G<V5S<VEO
M;BYG8U]M87AL:69E=&EM92<I.PH@("`@("`@("1Q=65R>2`]('-P<FEN=&8H
M)U-%3$5#5"!S97-S:6]N7V1A=&$@1E)/32`E<R!72$5212`G("X*("`@("`@
M("`@("`@("`@("`@("`@("`@("=S97-S:6]N7VED(#T@)7,@04Y$('-E<W-I
M;VY?;&%S=&UO9&EF:65D(#X]("5S("<@+@H@("`@("`@("`@("`@("`@("`@
M("`@("`@)T9/4B!54$1!5$4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^<75O=&4H)&ED*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:6UE;W5T*3L*("`@("`@("`D<F5S=6QT(#T@0'!G7W%U97)Y*"1T
M:&ES+3Y?9&(L("1Q=65R>2D["B`@("`@("`@)')O=W,@/2!P9U]N=6U?<F]W
M<R@D<F5S=6QT*3L*("`@("`@("!P9U]F<F5E7W)E<W5L="@D<F5S=6QT*3L*
M"B`@("`@("`@:68@*"1R;W=S(#T](#`I('L*("`@("`@("`@("`@)'%U97)Y
M(#T@<W!R:6YT9B@G24Y315)4($E.5$\@)7,@*'-E<W-I;VY?:60L("<@+@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S97-S:6]N7VQA<W1M;V1I
M9FEE9"P@<V5S<VEO;E]D871A*2`G("X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G5D%,5453("@E<RP@)7,L("5S*3LG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YQ=6]T92@D:60I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('1I;64H*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<75O=&4H8FEN,FAE>"@D<V5S
M<VEO;E]D871A*2DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1Q
M=65R>2`]('-P<FEN=&8H)U501$%412`E<R!3150@<V5S<VEO;E]L87-T;6]D
M:69I960@/2`E<RP@)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W-E<W-I;VY?9&%T82`]("5S(%=(15)%('-E<W-I;VY?:60@/2`E<SLG+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T
M86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1I;64H*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<75O=&4H8FEN
M,FAE>"@D<V5S<VEO;E]D871A*2DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G%U;W1E*"1I9"DI.PH@("`@("`@('T*"B`@("`@("`@
M+RH@3&]G('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X@*B\*("`@
M("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@475E<GD@8GD@
M4V5S<VEO;DAA;F1L97)?<&=S<6PZ.B<@+@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W=R:71E*"DZ('%U97)Y(#T@(B5S(B<L("1Q=65R
M>2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("1R97-U;'0@/2!`<&=?
M<75E<GDH)'1H:7,M/E]D8BP@)'%U97)Y*3L*("`@("`@("!I9B`H(21R97-U
M;'0I('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T5R<F]R('=R
M:71I;F<@<V5S<VEO;B!D871A.B`G("X@<&=?;&%S=%]E<G)O<B@D=&AI<RT^
M7V1B*2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@("1R;W=S
M(#T@<&=?869F96-T961?<F]W<R@D<F5S=6QT*3L*("`@("`@("!P9U]F<F5E
M7W)E<W5L="@D<F5S=6QT*3L*"B`@("`@("`@0'!G7W%U97)Y*"1T:&ES+3Y?
M9&(L("=#3TU-250[)RD["@H@("`@("`@(&EF("@D<F]W<R`A/2`Q*2!["B`@
M("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=%<G)O<B!W<FET:6YG('-E
M<W-I;VX@9&%T82<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$97-T<F]Y('1H92!D871A(&9O<B!A
M('!A<G1I8W5L87(@<V5S<VEO;B!I9&5N=&EF:65R(&EN('1H90H@("`@("H@
M4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1I9"`@5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@
M;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D97-T<F]Y*"1I9"D*
M("`@('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@:&%V92!A('9A;&ED(&1A
M=&%B87-E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T
M*"D["@H@("`@("`@("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@
M("`@)'%U97)Y(#T@<W!R:6YT9B@G1$5,151%($923TT@)7,@5TA%4D4@<V5S
M<VEO;E]I9"`]("5S.R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG=&%B;&4G72P@)'1H:7,M/G%U;W1E*"1I9"DI.PH*("`@
M("`@("`O*B!,;V<@=&AE('%U97)Y(&%T(&$@1$5"54<@;&]G(&QE=F5L+B`J
M+PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H)U-13"!1=65R
M>2!B>2!397-S:6]N2&%N9&QE<E]P9W-Q;#HZ)R`N"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G9&5S=')O>2@I.B!Q=65R>2`]("(E<R(G
M+"`D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`O*B!%>&5C
M=71E('1H92!Q=65R>2X@*B\*("`@("`@("`D<F5S=6QT(#T@0'!G7W%U97)Y
M*"1T:&ES+3Y?9&(L("1Q=65R>2D["@H@("`@("`@($!P9U]Q=65R>2@D=&AI
M<RT^7V1B+"`G0T]-34E4.R<I.PH*("`@("`@("!I9B`H(21R97-U;'0I('L*
M("`@("`@("`@("`@<&=?9G)E95]R97-U;'0H)')E<W5L="D["B`@("`@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*"=&86EL960@=&\@9&5L971E('-E<W-I
M;VX@*&ED(#T@)R`N("1I9"`N("<I)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!P
M9U]F<F5E7W)E<W5L="@D<F5S=6QT*3L*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("`O*BH*("`@("`J($=A<F)A9V4@8V]L;&5C="!S=&%L92!S
M97-S:6]N<R!F<F]M('1H92!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@
M("H*("`@("`J($!P87)A;2!I;G1E9V5R("1M87AL:69E=&EM92`@5&AE(&UA
M>&EM=6T@86=E(&]F(&$@<V5S<VEO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G8R@D;6%X;&EF971I;64@/2`S,#`I"B`@
M("!["B`@("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V86QI9"!D871A
M8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I
M.PH*("`@("`@("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y+B`J+PH@("`@("`@
M("1Q=65R>2`]('-P<FEN=&8H)T1%3$5412!&4D]-("5S(%=(15)%('-E<W-I
M;VY?;&%S=&UO9&EF:65D(#P@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^<75O=&4H=&EM92@I("T@)&UA>&QI9F5T:6UE*2D[
M"@H@("`@("`@("\J($QO9R!T:&4@<75E<GD@870@82!$14)51R!L;V<@;&5V
M96PN("HO"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G4U%,
M(%%U97)Y(&)Y(%-E<W-I;VY(86YD;&5R7W!G<W%L.CHG("X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=G8R@I.B!Q=65R>2`]("(E<R(G
M+"`D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`O*B!%>&5C
M=71E('1H92!Q=65R>2X@*B\*("`@("`@("`D<F5S=6QT(#T@0'!G7W%U97)Y
M*"1T:&ES+3Y?9&(L("1Q=65R>2D["B`@("`@("`@:68@*"$D<F5S=6QT*2![
M"B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=%<G)O<B!G87)B86=E
M(&-O;&QE8W1I;F<@;VQD('-E<W-I;VYS)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I
M.PH@("`@("`@('T*"B`@("`@("`@<&=?9G)E95]R97-U;'0H)')E<W5L="D[
M"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!%<V-A<&4@82!S=')I;F<@9F]R(&EN<V5R=&EO;B!I;G1O('1H92!D871A
M8F%S92X*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'9A;'5E("!4:&4@<W1R:6YG('1O('%U;W1E+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<75O=&5D('-T<FEN9RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@<75O=&4H)'9A;'5E*0H@("`@>PH@("`@
M("`@(')E='5R;B`B)R(@+B!A9&1S;&%S:&5S*"1V86QU92D@+B`B)R(["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F('1H92!V86QI9"!S
M97-S:6]N(&ED96YT:69I97)S+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@($$@;&ES="!O9B!V86QI9"!S97-S:6]N(&ED96YT:69I97)S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971397-S:6]N241S*"D*("`@('L*("`@("`@
M("`O*B!-86ME('-U<F4@=V4@:&%V92!A('9A;&ED(&1A=&%B87-E(&-O;FYE
M8W1I;VXN("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@
M("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@("`@)'%U97)Y(#T@
M)U-%3$5#5"!S97-S:6]N7VED($923TT@)R`N("1T:&ES+3Y?<&%R86US6R=T
M86)L92==.PH*("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T(&$@1$5"54<@
M;&]G(&QE=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN
M=&8H)U-13"!1=65R>2!B>2!397-S:6]N2&%N9&QE<E]P9W-Q;#HZ)R`N"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9V5T4V5S<VEO;DE$
M<R@I.B!Q=65R>2`]("(E<R(G+"`D<75E<GDI+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I
M.PH*("`@("`@("`O*B!%>&5C=71E('1H92!Q=65R>2X@*B\*("`@("`@("`D
M<F5S=6QT(#T@0'!G7W%U97)Y*"1T:&ES+3Y?9&(L("1Q=65R>2D["B`@("`@
M("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@('!G7V9R965?<F5S=6QT
M*"1R97-U;'0I.PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G17)R
M;W(@9V5T=&EN9R!S97-S:6]N($E$<R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M)'-E<W-I;VYS(#T@87)R87DH*3L*("`@("`@("!W:&EL92`H)')O=R`]('!G
M7V9E=&-H7W)O=R@D<F5S=6QT*2D@>PH@("`@("`@("`@("`D<V5S<VEO;G-;
M72`]("1R;W=;,%T["B`@("`@("`@?0H*("`@("`@("!P9U]F<F5E7W)E<W5L
M="@D<F5S=6QT*3L*"B`@("`@("`@<F5T=7)N("1S97-S:6]N<SL*("`@('T*
M"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(&]P96X@82!C;VYN96-T:6]N
M('1O('1H92!344P@<V5R=F5R+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!O;B!S=6-C97-S.R!E>&ET<R`H2&]R9&4Z.F9A=&%L*"DI
M(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I"B`@
M("!["B`@("`@("`@:68@*"$D=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@
M("`@("!(;W)D93HZ87-S97)T1')I=F5R0V]N9FEG*"1T:&ES+3Y?<&%R86US
M+"`G<V5S<VEO;FAA;F1L97(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"=H;W-T<W!E8R<L("=U<V5R;F%M92<L("=D
M871A8F%S92<L("=P87-S=V]R9"<I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=S97-S:6]N(&AA;F1L97(@<&=S<6PG*3L*"B`@
M("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DI
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==(#T@
M)VAO<F1E7W-E<W-I;VYH86YD;&5R)SL*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)&-O;FYE8W0@/2!E;7!T>2@D=&AI<RT^7W!A<F%M<ULG<&5R<VES
M=&5N="==*2`_"B`@("`@("`@("`@("`@("`G<&=?8V]N;F5C="<@.B=P9U]P
M8V]N;F5C="<["@H@("`@("`@("`@("`D<&%R86US='(@/2`G)SL*("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=P<F]T;V-O;"==*2`F
M)@H@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!R;W1O8V]L)UT@
M/3T@)W1C<"<I('L*("`@("`@("`@("`@("`@("1P87)A;7-T<B`N/2`G(&AO
M<W0])R`N("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==.PH@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=P;W)T)UTI*2!["B`@
M("`@("`@("`@("`@("`@("`@)'!A<F%M<W1R("X]("<@<&]R=#TG("X@)'1H
M:7,M/E]P87)A;7-;)W!O<G0G73L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D<&%R86US='(@+CT@)R!D8FYA;64])R`N
M("1T:&ES+3Y?<&%R86US6R=D871A8F%S92==("X*("`@("`@("`@("`@("`@
M("<@=7-E<CTG("X@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UT@+@H@("`@
M("`@("`@("`@("`@)R!P87-S=V]R9#TG("X@)'1H:7,M/E]P87)A;7-;)W!A
M<W-W;W)D)UT["@H@("`@("`@("`@("!I9B`H(21T:&ES+3Y?9&(@/2!`)&-O
M;FYE8W0H)'!A<F%M<W1R*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7V-O;FYE
M8W1E9"`]('1R=64["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4V5S
M<VEO;DAA;F1L97(O<V%P9&(N<&AP````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`V,S`W`#$P-3$U-#,S-S0V`#`R-#(R,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E(&1I
M<FYA;64H7U]&24Q%7U\I("X@)R]S<6PN<&AP)SL*"B\J*@H@*B!397-S:6]N
M2&%N9&QE<B!I;7!L96UE;G1A=&EO;B!F;W(@4$A0)W,@4$5!4B!D871A8F%S
M92!A8G-T<F%C=&EO;B!L87EE<BX*("H*("H@268@>6]U(&%C8V5S<R!Y;W5R
M(&1A=&%B87-E('1H<F]U9V@@3T1"0RP@>6]U('=I;&P@86QM;W-T(&-E<G1A
M:6YL>2!N965D"B`J('1O(&-H86YG92!02%`G<R!D969A=6QT('9A;'5E(&9O
M<B!O9&)C+F1E9F%U;'1L<FP@*'1H:7,@:7,@82!P:'`N:6YI"B`J('-E='1I
M;F<I+B!4:&4@9&5F875L="!I<R`T,#DV+"!W:&EC:"!I<R!T;V\@<VUA;&P@
M*'EO=7(@<V5S<VEO;B!D871A('=I;&P*("H@8F4@8VAO<'!E9"!O9F8I+"!A
M;F0@<V5T=&EN9R!I="!T;R`P($1/15,@3D]4('=O<FL@+2!T:&%T(&1O97-N
M)W0@;65A;B!N;PH@*B!L:6UI="P@9F]R('-O;64@<F5A<V]N+B!O9&)C+F1E
M9F%U;'1L<FP@/2`S,C<V."!S965M<R!T;R!W;W)K('!R971T>2!W96QL"B`J
M("AU<VEN9R!-4U-13"TR,#`P*2X*("H*("H@4F5Q=6ER960@<&%R86UE=&5R
M<SH\<')E/@H@*B`@("=H;W-T<W!E8R<@(%1H92!H;W-T;F%M92!O9B!T:&4@
M9&%T86)A<V4@<V5R=F5R+@H@*B`@("=P<F]T;V-O;"<@(%1H92!C;VUM=6YI
M8V%T:6]N('!R;W1O8V]L("@G=&-P)RP@)W5N:7@G+"!E=&,N*2X*("H@("`G
M=7-E<FYA;64G("!4:&4@=7-E<FYA;64@=VET:"!W:&EC:"!T;R!C;VYN96-T
M('1O('1H92!D871A8F%S92X*("H@("`G<&%S<W=O<F0G("!4:&4@<&%S<W=O
M<F0@87-S;V-I871E9"!W:71H("=U<V5R;F%M92<N"B`J("`@)V1A=&%B87-E
M)R`@5&AE(&YA;64@;V8@=&AE(&1A=&%B87-E+CPO<')E/@H@*@H@*B!/<'1I
M;VYA;"!P87)A;65T97)S.CQP<F4^"B`J("`@)W1A8FQE)R`@("`@5&AE(&YA
M;64@;V8@=&AE('-E<W-I;VYD871A('1A8FQE(&EN("=D871A8F%S92<N("!$
M969A=6QT(&ES"B`J("`@("`@("`@("`@("`@)VAO<F1E7W-E<W-I;VYH86YD
M;&5R)RX\+W!R93X*("H*("H@5&AE('1A8FQE('-T<G5C='5R92!F;W(@=&AE
M(%-E<W-I;VY(86YD;&5R(&-A;B!B92!F;W5N9"!I;@H@*B!H;W)D92]S8W)I
M<'1S+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE<BYS87!D8BYS<6PN"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+W-A<&1B+G!H<"QV(#$N,3,N,3(N."`R,#`V+S`Q+S`Q(#(Q.C(X.C,T
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI:V4@0V]C
M:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL
M+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?4V5S<VEO;DAA;F1L97(*("HO"F-L87-S(%-E<W-I;VY(86YD;&5R7W-A
M<&1B(&5X=&5N9',@4V5S<VEO;DAA;F1L97)?<W%L('L*"B`@("`O*BH*("`@
M("`J($-O;G-T<G5C=',@82!N97<@4U%,(%-E<W-I;VY(86YD;&5R(&]B:F5C
M="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H
M(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!397-S:6]N2&%N9&QE<E]S87!D8B@D<&%R86US(#T@87)R
M87DH*2D*("`@('L*("`@("`@("`D<&%R86US6R=P:'!T>7!E)UT@/2`G;V1B
M8R<["B`@("`@("`@<&%R96YT.CI397-S:6]N2&%N9&QE<E]S<6PH)'!A<F%M
M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296%D('1H92!D871A(&9O<B!A
M('!A<G1I8W5L87(@<V5S<VEO;B!I9&5N=&EF:65R(&9R;VT@=&AE"B`@("`@
M*B!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&ED("!4:&4@<V5S<VEO;B!I9&5N=&EF:65R+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<V5S<VEO;B!D871A+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R96%D*"1I9"D*("`@('L*("`@("`@("`O*B!-
M86ME('-U<F4@=V4@:&%V92!A('9A;&ED(&1A=&%B87-E(&-O;FYE8W1I;VXN
M("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J($)E
M9VEN(&$@=')A;G-A8W1I;VXN("HO"B`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?9&(M/F%U=&]C;VUM:70H9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H)')E<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H*("`@
M("`@("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y+B`J+PH@("`@("`@("1Q=65R
M>2`]('-P<FEN=&8H)U-%3$5#5"!S97-S:6]N7V1A=&$@1E)/32`E<R!72$52
M12!S97-S:6]N7VED(#T@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V1B+3YQ=6]T92@D:60I*3L*"B`@("`@("`@+RH@3&]G
M('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X@*B\*("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@475E<GD@8GD@4V5S<VEO
M;DAA;F1L97)?<W%L.CIR96%D*"DZ('%U97)Y(#T@(B5S(B<L("1Q=65R>2DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?
M+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("\J($5X96-U=&4@=&AE('%U
M97)Y("HO"B`@("`@("`@)')E<W5L="`](&]D8F-?97AE8R@D=&AI<RT^7V1B
M+3YC;VYN96-T:6]N+"`D<75E<GDI.PH@("`@("`@(&]D8F-?;&]N9W)E861L
M96XH)')E<W5L="P@,3`T.#4W-BD["@H@("`@("`@("\J($9E=&-H('1H92!V
M86QU92`J+PH@("`@("`@(&]D8F-?9F5T8VA?<F]W*"1R97-U;'0L(#`I.PH@
M("`@("`@("1D871A(#T@;V1B8U]R97-U;'0H)')E<W5L="P@)W-E<W-I;VY?
M9&%T82<I.PH*("`@("`@("`O*B!#;&5A;B!U<"`J+PH@("`@("`@(&]D8F-?
M9G)E95]R97-U;'0H)')E<W5L="D["@H@("`@("`@(')E='5R;B`D9&%T83L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U-E
M<W-I;VY(86YD;&5R+W-Q;"YP:'``````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`R,S<P,0`Q,#4Q-30S,S<T-@`P,C,W,C,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%-E<W-I;VY(
M86YD;&5R(&EM<&QE;65N=&%T:6]N(&9O<B!02%`G<R!014%2(&1A=&%B87-E
M(&%B<W1R86-T:6]N(&QA>65R+@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S
M.CQP<F4^"B`J("`@)W!H<'1Y<&4G("`@5&AE(&1A=&%B87-E('1Y<&4@*&4N
M9RX@)W!G<W%L)RP@)VUY<W%L)RP@971C+BDN/"]P<F4^"B`J"B`J(%)E<75I
M<F5D(&)Y('-O;64@9&%T86)A<V4@:6UP;&5M96YT871I;VYS.CQP<F4^"B`J
M("`@)VAO<W1S<&5C)R`@5&AE(&AO<W1N86UE(&]F('1H92!D871A8F%S92!S
M97)V97(N"B`J("`@)W!R;W1O8V]L)R`@5&AE(&-O;6UU;FEC871I;VX@<')O
M=&]C;VP@*"=T8W`G+"`G=6YI>"<L(&5T8RXI+@H@*B`@("=D871A8F%S92<@
M(%1H92!N86UE(&]F('1H92!D871A8F%S92X*("H@("`G=7-E<FYA;64G("!4
M:&4@=7-E<FYA;64@=VET:"!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A
M8F%S92X*("H@("`G<&%S<W=O<F0G("!4:&4@<&%S<W=O<F0@87-S;V-I871E
M9"!W:71H("=U<V5R;F%M92<N"B`J("`@)V]P=&EO;G,G("`@061D:71I;VYA
M;"!O<'1I;VYS('1O('!A<W,@=&\@=&AE(&1A=&%B87-E+@H@*B`@("=T='DG
M("`@("`@(%1H92!45%D@;VX@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T
M86)A<V4N"B`J("`@)W!O<G0G("`@("`@5&AE('!O<G0@;VX@=VAI8V@@=&\@
M8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N/"]P<F4^"B`J"B`J($]P=&EO;F%L
M('!A<F%M971E<G,Z/'!R93X*("H@("`G<&5R<VES=&5N="<@(%5S92!P97)S
M:7-T96YT($1"(&-O;FYE8W1I;VYS/R`H8F]O;&5A;BD*("H@("`G=&%B;&4G
M("`@("`@(%1H92!N86UE(&]F('1H92!S97-S:6]N9&%T82!T86)L92!I;B`G
M9&%T86)A<V4G+B`@1&5F875L=`H@*B`@("`@("`@("`@("`@("`@:7,@)VAO
M<F1E7W-E<W-I;VYH86YD;&5R)RX\+W!R93X*("H*("H@5&AE('1A8FQE('-T
M<G5C='5R92!F;W(@=&AE(%-E<W-I;VY(86YD;&5R(&-A;B!B92!F;W5N9"!I
M;@H@*B!H;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE<BYS
M<6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E
M<W-I;VY(86YD;&5R+W-Q;"YP:'`L=B`Q+C(R+C$P+C$S(#(P,#8O,#$O,#$@
M,C$Z,C@Z,S0@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@
M36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A
M9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C
M:V%G92!(;W)D95]397-S:6]N2&%N9&QE<@H@*B\*8VQA<W,@4V5S<VEO;DAA
M;F1L97)?<W%L(&5X=&5N9',@4V5S<VEO;DAA;F1L97(@>PH*("`@("\J*@H@
M("`@("H@2&%N9&QE(&9O<B!T:&4@8W5R<F5N="!D871A8F%S92!C;VYN96-T
M:6]N+@H@("`@("H*("`@("`J($!V87(@1$(*("`@("`J+PH@("`@=F%R("1?
M9&(["@H@("`@+RHJ"B`@("`@*B!";V]L96%N(&EN9&EC871I;F<@=VAE=&AE
M<B!O<B!N;W0@=V4G<F4@8V]N;F5C=&5D('1O('1H92!344P@<V5R=F5R+@H@
M("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]C
M;VYN96-T960@/2!F86QS93L*"B`@("`O*BH*("`@("`J($-L;W-E('1H92!3
M97-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@("`@("`O*B!$
M:7-C;VYN96-T(&9R;VT@9&%T86)A<V4N("HO"B`@("`@("`@:68@*"1T:&ES
M+3Y?8V]N;F5C=&5D*2!["B`@("`@("`@("`@("\J($-L;W-E(&%N>2!O<&5N
M('1R86YS86-T:6]N<RX@*B\*("`@("`@("`@("`@)'1H:7,M/E]D8BT^8V]M
M;6ET*"D["B`@("`@("`@("`@("1T:&ES+3Y?9&(M/F%U=&]#;VUM:70H=')U
M92D["@H@("`@("`@("`@("`D=&AI<RT^7V-O;FYE8W1E9"`](&9A;'-E.PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D8BT^9&ES8V]N;F5C="@I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!296%D('1H92!D871A(&9O<B!A('!A<G1I8W5L87(@<V5S<VEO
M;B!I9&5N=&EF:65R(&9R;VT@=&AE"B`@("`@*B!397-S:6]N2&%N9&QE<B!B
M86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@
M<V5S<VEO;B!I9&5N=&EF:65R+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@<V5S<VEO;B!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M96%D*"1I9"D*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@:&%V92!A
M('9A;&ED(&1A=&%B87-E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'1H:7,M
M/E]C;VYN96-T*"D["@H@("`@("`@("\J($)E9VEN(&$@=')A;G-A8W1I;VXN
M("HO"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/F%U=&]C;VUM:70H
M9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E<W5L="P@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@
M("!R971U<FX@)R<["B`@("`@("`@?0H*("`@("`@("`O*B!%>&5C=71E('1H
M92!Q=65R>2X@*B\*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-13"YP
M:'`G.PH@("`@("`@("1R97-U;'0@/2!(;W)D95]344PZ.G)E861";&]B*"1T
M:&ES+3Y?9&(L("1T:&ES+3Y?<&%R86US6R=T86)L92==+"`G<V5S<VEO;E]D
M871A)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G<V5S<VEO;E]I9"<@/3X@)&ED*2D["@H@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z
M.FQO9TUE<W-A9V4H)')E<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*("`@("`J
M(%=R:71E('-E<W-I;VX@9&%T82!T;R!T:&4@4V5S<VEO;DAA;F1L97(@8F%C
M:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@("`@("`@
M("`@(%1H92!S97-S:6]N(&ED96YT:69I97(N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1S97-S:6]N7V1A=&$@(%1H92!S97-S:6]N(&1A=&$N"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E
M(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&4H)&ED+"`D
M<V5S<VEO;E]D871A*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W92!H
M879E(&$@=F%L:60@9&%T86)A<V4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D
M=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q
M=65R>2X@*B\*("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=314Q%0U0@<V5S
M<VEO;E]I9"!&4D]-("5S(%=(15)%('-E<W-I;VY?:60@/2`_)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==*3L*
M("`@("`@("`D=F%L=65S(#T@87)R87DH)&ED*3L*"B`@("`@("`@+RH@3&]G
M('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X@*B\*("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@475E<GD@8GD@4V5S<VEO
M;DAA;F1L97)?<W%L.CIW<FET92@I.B!Q=65R>2`]("(E<R(G+"`D<75E<GDI
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`O*B!%>&5C=71E('1H92!Q
M=65R>2X@*B\*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^9V5T3VYE
M*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G
M92@D<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD[
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O4U%,+G!H<"<["B`@("`@("`@:68@*"1R
M97-U;'0I('L*("`@("`@("`@("`@)')E<W5L="`]($AO<F1E7U-13#HZ=7!D
M871E0FQO8B@D=&AI<RT^7V1B+"`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P@
M)W-E<W-I;VY?9&%T82<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'-E<W-I;VY?9&%T82P@87)R87DH)W-E<W-I;VY?
M:60G(#T^("1I9"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)W-E<W-I;VY?;&%S=&UO9&EF:65D)R`]/B!T
M:6UE*"DI*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S=6QT
M(#T@2&]R9&5?4U%,.CII;G-E<G1";&]B*"1T:&ES+3Y?9&(L("1T:&ES+3Y?
M<&%R86US6R=T86)L92==+"`G<V5S<VEO;E]D871A)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<V5S<VEO;E]D871A
M+"!A<G)A>2@G<V5S<VEO;E]I9"<@/3X@)&ED+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=S97-S:6]N7VQA<W1M;V1I9FEE9"<@/3X@=&EM92@I*2D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?9&(M/G)O;&QB86-K*"D["B`@("`@
M("`@("`@("1T:&ES+3Y?9&(M/F%U=&]#;VUM:70H=')U92D["B`@("`@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-U;'0L(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/F-O
M;6UI="@I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@)'1H:7,M/E]D8BT^875T;T-O;6UI="AT<G5E
M*3L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E<W5L="P@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V1B+3YA
M=71O0V]M;6ET*'1R=64I.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1&5S=')O>2!T:&4@9&%T82!F;W(@82!P87)T:6-U
M;&%R('-E<W-I;VX@:61E;G1I9FEE<B!I;B!T:&4*("`@("`J(%-E<W-I;VY(
M86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M:60@(%1H92!S97-S:6]N(&ED96YT:69I97(N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5S=')O>2@D:60I"B`@("!["B`@
M("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V86QI9"!D871A8F%S92!C
M;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@
M("`@("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y+B`J+PH@("`@("`@("1Q=65R
M>2`]('-P<FEN=&8H)T1%3$5412!&4D]-("5S(%=(15)%('-E<W-I;VY?:60@
M/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=T86)L92==*3L*("`@("`@("`D=F%L=65S(#T@87)R87DH)&ED*3L*"B`@
M("`@("`@+RH@3&]G('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X@
M*B\*("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@475E
M<GD@8GD@4V5S<VEO;DAA;F1L97)?<W%L.CID97-T<F]Y*"DZ('%U97)Y(#T@
M(B5S(B<L("1Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("\J
M($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H)')E<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^8V]M;6ET*"D[
M"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D<F5S=6QT+"!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1V%R8F%G92!C;VQL96-T('-T86QE('-E<W-I
M;VYS(&9R;VT@=&AE(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&UA>&QI9F5T:6UE("!4:&4@;6%X:6UU
M;2!A9V4@;V8@82!S97-S:6]N+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=C*"1M87AL:69E=&EM92`](#,P,"D*("`@('L*
M("`@("`@("`O*B!-86ME('-U<F4@=V4@:&%V92!A('9A;&ED(&1A=&%B87-E
M(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@
M("`@("`@("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@("`@)'%U
M97)Y(#T@<W!R:6YT9B@G1$5,151%($923TT@)7,@5TA%4D4@<V5S<VEO;E]L
M87-T;6]D:69I960@/"`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=T86)L92==*3L*("`@("`@("`D=F%L=65S(#T@87)R
M87DH=&EM92@I("T@)&UA>&QI9F5T:6UE*3L*"B`@("`@("`@+RH@3&]G('1H
M92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E;"X@*B\*("`@("`@("!(;W)D
M93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@475E<GD@8GD@4V5S<VEO;DAA
M;F1L97)?<W%L.CIG8R@I.B!Q=65R>2`]("(E<R(G+"`D<75E<GDI+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?1$5"54<I.PH*("`@("`@("`O*B!%>&5C=71E('1H92!Q=65R>2X@
M*B\*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y
M+"`D=F%L=65S*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-U
M;'0L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F('1H
M92!V86QI9"!S97-S:6]N(&ED96YT:69I97)S+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@($$@;&ES="!O9B!V86QI9"!S97-S:6]N(&ED96YT:69I
M97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971397-S:6]N241S*"D*("`@
M('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@:&%V92!A('9A;&ED(&1A=&%B
M87-E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D[
M"@H@("`@("`@("1T:6UE;W5T(#T@=&EM92@I("T@:6YI7V=E="@G<V5S<VEO
M;BYG8U]M87AL:69E=&EM92<I.PH*("`@("`@("`O*B!"=6EL9"!T:&4@4U%,
M('%U97)Y+B`J+PH@("`@("`@("1Q=65R>2`]("=314Q%0U0@<V5S<VEO;E]I
M9"!&4D]-("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@("`@("`@
M("`@("`@("`@)R!72$5212!S97-S:6]N7VQA<W1M;V1I9FEE9"`^(#\G.PH@
M("`@("`@("1V86QU97,@/2!A<G)A>2@D=&EM96]U="D["@H@("`@("`@("\J
M($QO9R!T:&4@<75E<GD@870@82!$14)51R!L;V<@;&5V96PN("HO"B`@("`@
M("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G4U%,(%%U97)Y(&)Y(%-E
M<W-I;VY(86YD;&5R7W-Q;#HZ9V5T4V5S<VEO;DE$<R@I.B!Q=65R>2`]("(E
M<R(G+"`D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`O*B!%
M>&5C=71E('1H92!Q=65R>2X@*B\*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/E]D8BT^9V5T0V]L*"1Q=65R>2P@,"P@)'9A;'5E<RD["B`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92@D<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\J
M*@H@("`@("H@071T96UP=',@=&\@;W!E;B!A(&-O;FYE8W1I;VX@=&\@=&AE
M(%-13"!S97)V97(N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&]N('-U8V-E<W,[(&5X:71S("A(;W)D93HZ9F%T86PH*2D@;VX@97)R
M;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN96-T*"D*("`@('L*("`@
M("`@("!I9B`H(21T:&ES+3Y?8V]N;F5C=&5D*2!["B`@("`@("`@("`@($AO
M<F1E.CIA<W-E<G1$<FEV97)#;VYF:6<H)'1H:7,M/E]P87)A;7,L("=S97-S
M:6]N:&%N9&QE<B<L"B`@("`@("`@("`@("`@("!A<G)A>2@G<&AP='EP92<I
M+`H@("`@("`@("`@("`@("`@)W-E<W-I;VX@:&%N9&QE<B!344PG*3L*"B`@
M("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)V1A=&%B87-E
M)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG9&%T86)A
M<V4G72`]("<G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UTI*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;64G72`]("<G.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;
M)VAO<W1S<&5C)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG:&]S='-P96,G72`]("<G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==(#T@)VAO<F1E7W-E
M<W-I;VYH86YD;&5R)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@
M0V]N;F5C="!T;R!T:&4@4U%,('-E<G9E<B!U<VEN9R!T:&4@<W5P<&QI960*
M("`@("`@("`@("`@("H@<&%R86UE=&5R<RX@*B\*("`@("`@("`@("`@:6YC
M;'5D95]O;F-E("=$0BYP:'`G.PH@("`@("`@("`@("`D=&AI<RT^7V1B(#T@
M)D1".CIC;VYN96-T*"1T:&ES+3Y?<&%R86US+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=P97)S:7-T96YT)R`]/B`A
M96UP='DH)'1H:7,M/E]P87)A;7-;)W!E<G-I<W1E;G0G72DI*3L*("`@("`@
M("`@("`@:68@*&ES7V$H)'1H:7,M/E]D8BP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*"1T:&ES+3Y?9&(L(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T
M:&ES+3Y?9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)404))
M3$E465],3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%4E)/4E,I.PH*("`@
M("`@("`@("`@)'1H:7,M/E]C;VYN96-T960@/2!T<G5E.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U-E<W-I
M;VY(86YD;&5R+G!H<```````````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q
M-S<Q,@`Q,#4Q-30S,S<U,@`P,C,Q,C8`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%-E<W-I;VY(86YD
M;&5R.CH@9&5F:6YE<R!A;B!!4$D@9F]R(&EM<&QE;65N=&EN9R!C=7-T;VT@
M<V5S<VEO;@H@*B!H86YD;&5R<R!F;W(@4$A0+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`L=B`Q
M+C$S+C$P+C$Q(#(P,#8O,#<O,30@,#@Z-30Z-3D@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`R+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F
M=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI
M:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC
M92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]397-S:6]N2&%N9&QE
M<@H@*B\*8VQA<W,@4V5S<VEO;DAA;F1L97(@>PH*("`@("\J*@H@("`@("H@
M2&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<R`]
M(&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W(%-E
M<W-I;VY(86YD;&5R(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A
M;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!397-S:6]N2&%N9&QE<B@D
M<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W!A<F%M
M<R`]("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T
M;R!R971U<FX@82!C;VYC<F5T92!397-S:6]N2&%N9&QE<B!I;G-T86YC92!B
M87-E9"!O;@H@("`@("H@)&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1D<FEV97(@(%1H92!T>7!E(&]F(&-O;F-R971E(%-E<W-I;VY(
M86YD;&5R('-U8F-L87-S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@(')E='5R;BX*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@02!H
M87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O
M<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T:6]N('!A
M<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E(%-E
M<W-I;VY(86YD;&5R(&EN<W1A;F-E+"!O<@H@("`@("H@("`@("`@("`@("`@
M("`@9F%L<V4@;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F
M86-T;W)Y*"1D<FEV97(L("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@
M(&EF("AI<U]A<G)A>2@D9')I=F5R*2D@>PH@("`@("`@("`@("`D87!P(#T@
M)&1R:79E<ELP73L*("`@("`@("`@("`@)&1R:79E<B`]("1D<FEV97);,5T[
M"B`@("`@("`@?0H*("`@("`@("`D9')I=F5R(#T@8F%S96YA;64H)&1R:79E
M<BD["B`@("`@("`@:68@*"1D<FEV97(@/3T@)VUE;6-A8VAE9"<I('L*("`@
M("`@("`@("`@+R\@5')A<"!F;W(@;VQD(&1R:79E<B!N86UE+@H@("`@("`@
M("`@("`D9')I=F5R(#T@)VUE;6-A8VAE)SL*("`@("`@("!]"@H@("`@("`@
M("1C;&%S<R`]("=397-S:6]N2&%N9&QE<E\G("X@)&1R:79E<CL*("`@("`@
M("!I9B`H(6-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@(&EF
M("@A96UP='DH)&%P<"DI('L*("`@("`@("`@("`@("`@(&EN8VQU9&5?;VYC
M92`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=F:6QE<F]O="<L("1A<'`I
M("X@)R]L:6(O4V5S<VEO;DAA;F1L97(O)R`N("1D<FEV97(@+B`G+G!H<"<[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I;F-L=61E
M7V]N8V4@)TAO<F1E+U-E<W-I;VY(86YD;&5R+R<@+B`D9')I=F5R("X@)RYP
M:'`G.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H8VQA
M<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@:68@*&ES7VYU;&PH
M)'!A<F%M<RDI('L*("`@("`@("`@("`@("`@(&EN8VQU9&5?;VYC92`G2&]R
M9&4N<&AP)SL*("`@("`@("`@("`@("`@("1P87)A;7,@/2!(;W)D93HZ9V5T
M1')I=F5R0V]N9FEG*"=S97-S:6]N:&%N9&QE<B<L("1D<FEV97(I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1H86YD;&5R(#T@;F5W("1C;&%S<R@D
M<&%R86US*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:&%N9&QE
M<B`](%!%05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I;VX@;V8@)R`N
M("1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1H86YD;&5R.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP
M=',@=&\@<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@4V5S<VEO
M;DAA;F1L97(*("`@("`J(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(N($ET
M('=I;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N8V4*("`@("`J(&EF(&YO
M(%-E<W-I;VY(86YD;&5R(&EN<W1A;F-E('=I=&@@=&AE('-A;64@<&%R86UE
M=&5R<PH@("`@("H@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4
M:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z("1V87(@/2`F4V5S<VEO
M;DAA;F1L97(Z.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9')I=F5R("!3964@4V5S<VEO;DAA;F1L97(Z.F9A8W1O<GDH*2X*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@4V5E(%-E<W-I;VY(86YD
M;&5R.CIF86-T;W)Y*"DN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M5&AE(&-R96%T960@8V]N8W)E=&4@4V5S<VEO;DAA;F1L97(@:6YS=&%N8V4L
M(&]R(&9A;'-E"B`@("`@*B`@("`@("`@("`@("`@("!O;B!E<G)O<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D9')I=F5R+"`D<&%R86US
M(#T@;G5L;"D*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<R`](&%R
M<F%Y*"D["@H@("`@("`@("1S:6=N871U<F4@/2!S97)I86QI>F4H87)R87DH
M)&1R:79E<BP@)'!A<F%M<RDI.PH@("`@("`@(&EF("AE;7!T>2@D:6YS=&%N
M8V5S6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S
M:6=N871U<F5=(#T@)E-E<W-I;VY(86YD;&5R.CIF86-T;W)Y*"1D<FEV97(L
M("1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC
M97-;)'-I9VYA='5R95T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/<&5N('1H
M92!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!A8G-T
M<F%C=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-A=F5?<&%T:"`@
M("`@5&AE('!A=&@@=&\@=&AE('-E<W-I;VX@;V)J96-T+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<V5S<VEO;E]N86UE("!4:&4@;F%M92!O9B!T:&4@<V5S
M<VEO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@
M<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!O<&5N*"1S879E7W!A=&@L("1S97-S:6]N7VYA;64I"B`@("!["B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&]S92!T
M:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`86)S
M=')A8W0*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@
M<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!C;&]S92@I"B`@("!["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!296%D('1H92!D871A(&9O<B!A('!A<G1I8W5L87(@
M<V5S<VEO;B!I9&5N=&EF:65R(&9R;VT@=&AE"B`@("`@*B!397-S:6]N2&%N
M9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@<V5S<VEO;B!I9&5N=&EF
M:65R+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<V5S<VEO
M;B!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D*"1I9"D*("`@('L*
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@<W5P<&]R
M=&5D+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%=R:71E('-E<W-I;VX@
M9&%T82!T;R!T:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@
M("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I
M9"`@("`@("`@("`@(%1H92!S97-S:6]N(&ED96YT:69I97(N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1S97-S:6]N7V1A=&$@(%1H92!S97-S:6]N(&1A=&$N
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E
M<W,L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I
M=&4H)&ED+"`D<V5S<VEO;E]D871A*0H@("`@>PH@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*%\H(DYO="!S=7!P;W)T960N(BDI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1&5S=')O>2!T:&4@9&%T82!F;W(@82!P87)T:6-U
M;&%R('-E<W-I;VX@:61E;G1I9FEE<B!I;B!T:&4*("`@("`J(%-E<W-I;VY(
M86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!S97-S:6]N(&ED96YT
M:69I97(N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N
M('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9&5S=')O>2@D:60I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H7R@B3F]T('-U<'!O<G1E9"XB*2D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'87)B86=E(&-O;&QE8W0@<W1A;&4@<V5S<VEO;G,@9G)O;2!T
M:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`86)S
M=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;6%X;&EF971I
M;64@(%1H92!M87AI;75M(&%G92!O9B!A('-E<W-I;VXN"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]T
M:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V,H)&UA>&QI9F5T:6UE
M(#T@,S`P*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(DYO="!S=7!P;W)T960N(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1&5T97)M:6YE<R!I9B!A('-E<W-I;VX@8F5L;VYG<R!T;R!A;B!A=71H96YT
M:6-A=&5D('5S97(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5S<VEO;E]D871A("!4:&4@
M<V5S<VEO;B!D871A(&ET<V5L9BX*("`@("`J($!P87)A;2!B;V]L96%N("1R
M971U<FY?=7-E<B`@268@=')U92P@<F5T=7)N('1H92!U<V5R('-E<W-I;VX@
M9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86Y\<W1R:6YG("!4
M<G5E(&]R('1H92!U<V5R)W,@<V5S<VEO;B!D871A(&EF('1H92!S97-S:6]N
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!B96QO;F=S('1O(&%N
M(&%U=&AE;G1I8V%T960@=7-E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@7VES
M075T:&5N=&EC871E9"@D<V5S<VEO;E]D871A+"`D<F5T=7)N7V1A=&$@/2!F
M86QS92D*("`@('L*("`@("`@("!I9B`H96UP='DH)'-E<W-I;VY?9&%T82DI
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@=VAI;&4@*"1S97-S:6]N7V1A=&$I('L*("`@("`@("`@("`@)'9A<G,@
M/2!E>'!L;V1E*"=\)RP@)'-E<W-I;VY?9&%T82P@,BD["B`@("`@("`@("`@
M("1D871A(#T@=6YS97)I86QI>F4H)'9A<G-;,5TI.PH@("`@("`@("`@("!I
M9B`H)'9A<G-;,%T@/3T@)U]?875T:"<I('L*("`@("`@("`@("`@("`@(&EF
M("AE;7!T>2@D9&%T82DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1D871A6R=A=71H96YT:6-A=&5D)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1R971U<FY?9&%T82`_("1D871A(#H@=')U93L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<V5S<VEO;E]D871A(#T@
M<W5B<W1R*"1S97-S:6]N7V1A=&$L('-T<FQE;B@D=F%R<ULP72D@*R!S=')L
M96XH<V5R:6%L:7IE*"1D871A*2D@*R`Q*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F('1H92!V86QI9"!S97-S:6]N
M(&ED96YT:69I97)S+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@($$@;&ES="!O9B!V86QI9"!S97-S:6]N
M(&ED96YT:69I97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971397-S:6]N
M241S*"D*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*").;W0@<W5P<&]R=&5D+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E
M=&5R;6EN92!T:&4@;G5M8F5R(&]F(&-U<G)E;G1L>2!L;V=G960@:6X@=7-E
M<G,N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!!(&-O=6YT(&]F
M(&QO9V=E9"!I;B!U<V5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@8V]U;G1!
M=71H96YT:6-A=&5D57-E<G,H*0H@("`@>PH@("`@("`@("1C;W5N="`](#`[
M"@H@("`@("`@("1S97-S:6]N<R`]("1T:&ES+3YG971397-S:6]N241S*"D[
M"B`@("`@("`@:68@*&ES7V$H)'-E<W-I;VYS+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D<V5S<VEO;G,["B`@("`@("`@?0H*("`@
M("`@("!F;W)E86-H("@D<V5S<VEO;G,@87,@)&ED*2!["B`@("`@("`@("`@
M("1D871A(#T@)'1H:7,M/G)E860H)&ED*3L*("`@("`@("`@("`@:68@*"%I
M<U]A*"1D871A+"`G4$5!4E]%<G)O<B<I("8F"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7VES075T:&5N=&EC871E9"@D9&%T82DI('L*("`@("`@("`@("`@
M("`@("1C;W5N="LK.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&-O=6YT.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!A(&QI<W0@;V8@8W5R<F5N=&QY(&QO9V=E9"!I;B!U<V5R<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&QI<W0@;V8@;&]G9V5D(&EN('5S
M97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T075T:&5N=&EC871E9%5S
M97)S*"1D871E(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'5S97)S(#T@87)R
M87DH*3L*"B`@("`@("`@)'-E<W-I;VYS(#T@)'1H:7,M/F=E=%-E<W-I;VY)
M1',H*3L*("`@("`@("!I9B`H:7-?82@D<V5S<VEO;G,L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1S97-S:6]N<SL*("`@("`@("!]
M"@H@("`@("`@(&9O<F5A8V@@*"1S97-S:6]N<R!A<R`D:60I('L*("`@("`@
M("`@("`@)&1A=&$@/2`D=&AI<RT^<F5A9"@D:60I.PH@("`@("`@("`@("!I
M9B`H:7-?82@D9&%T82P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1D871A
M(#T@)'1H:7,M/E]I<T%U=&AE;G1I8V%T960H)&1A=&$L('1R=64I.PH@("`@
M("`@("`@("!I9B`H)&1A=&$@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@
M("`D=7-E<B`]("1D871A6R=U<V5R260G73L*("`@("`@("`@("`@("`@(&EF
M("@D9&%T92D@>PH@("`@("`@("`@("`@("`@("`@("1U<V5R(#T@9&%T92@G
M<B<L("1D871A6R=T:6UE<W1A;7`G72D@+B`G("`G("X@)'5S97(["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=7-E<G-;72`]("1U<V5R
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'5S
M97)S.PH@("`@?0H*?0H`````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B](;W)D92]397-S:6]N3V)J96-T<RYP:'``````````````````
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,34U,C8`,3`U,34T,S,W-3(`,#(S,30S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!4:&4@2&]R9&5?4V5S<VEO;D]B:F5C=',Z.B!C;&%S<R!P<F]V
M:61E<R!A('=A>2!F;W(@<W1O<FEN9R!D871A"B`J("AU<W5A;&QY+"!B=70@
M;F]T(&YE8V5S<V%R:6QY+"!O8FIE8W1S*2!I;B!T:&4@8W5R<F5N="!U<V5R
M)W,*("H@<V5S<VEO;BX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4V5S<VEO
M;D]B:F5C=',O4V5S<VEO;D]B:F5C=',N<&AP+'8@,2XV+C$R+C@@,C`P-B\P
M,2\P,2`R,3HR.#HS-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M
M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W5Q"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E
M($AO<F1E7U-E<W-I;VY/8FIE8W1S"B`J+PIC;&%S<R!(;W)D95]397-S:6]N
M3V)J96-T<R!["@H@("`@+RHJ"B`@("`@*B!4:&4@;&ES="!O9B!O:61S('1O
M('!R=6YE(&%T('1H92!E;F0@;V8@82!R97%U97-T+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<')U;F5,:7-T(#T@;G5L
M;#L*"B`@("`O*BH*("`@("`J(%1H92!N86UE(&]F('1H92!S=&]R92X*("`@
M("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]N86UE
M(#T@)VAO<F1E7W-E<W-I;VY?;V)J96-T<R<["@H@("`@+RHJ"B`@("`@*B!!
M;&QO=R!S=&]R92@I('1O(&]V97)W<FET92!C=7)R96YT(&]B:F5C=',_"B`@
M("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V]V
M97)W<FET92`](&9A;'-E.PH*("`@("\J*@H@("`@("H@5&AE(&UA>&EM=6T@
M;G5M8F5R(&]F(&]B:F5C=',@=&AA="!T:&4@<W1O<F4@<VAO=6QD(&AO;&0N
M"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D
M7W-I>F4@/2`R,#L*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!R969E<F5N
M8V4@=&\@=&AE(&=L;V)A;"!(;W)D95]397-S:6]N3V)J96-T<R!O8FIE8W0L
M"B`@("`@*B!O;FQY(&-R96%T:6YG(&ET(&EF(&ET(&1O97-N)W0@86QR96%D
M>2!E>&ES="X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN
M=F]K960@87,Z"B`@("`@*B`@("1O8FIE8W1S=&]R92`]("9(;W)D95]397-S
M:6]N3V)J96-T<SHZ<VEN9VQE=&]N*"D["B`@("`@*@H@("`@("H@0')E='5R
M;B!(;W)D95]397-S:6]N3V)J96-T<R`@5&AE($AO<F1E7U-E<W-I;VY/8FIE
M8W1S(&EN<W1A;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N
M*"D*("`@('L*("`@("`@("!S=&%T:6,@)&]B:F5C=#L*"B`@("`@("`@:68@
M*"%I<W-E="@D;V)J96-T*2D@>PH@("`@("`@("`@("`D;V)J96-T(#T@;F5W
M($AO<F1E7U-E<W-I;VY/8FIE8W1S*"D["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&]B:F5C=#L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=&]R+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!4:&4@
M<&%R86UE=&5R(&%R<F%Y+@H@("`@("H@/'!R93X*("`@("`J($]P=&EO;F%L
M(%!A<F%M971E<G,Z"B`@("`@*B`G;F%M92<@("TM("!4:&4@;F%M92!O9B!T
M:&4@<V5S<VEO;B!V87)I86)L92!T;R!S=&]R92!T:&4@;V)J96-T<R!I;BX*
M("`@("`J("=S:7IE)R`@+2T@(%1H92!M87AI;75M('-I>F4@;V8@=&AE("AN
M;VXM<')U;F%B;&4I(&]B:F5C="!S=&]R92X*("`@("`J(#PO<')E/@H@("`@
M("HO"B`@("!F=6YC=&EO;B!(;W)D95]397-S:6]N3V)J96-T<R@D<&%R86US
M(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG
M;F%M92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VYA;64@/2`D<&%R86US
M6R=N86UE)UT["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)'!A<F%M
M<ULG<VEZ92==*2`F)B!I<U]I;G0H)'!A<F%M<ULG<VEZ92==*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7W-I>F4@/2`D<&%R86US6R=S:7IE)UT["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5W)A<'!E<B!A<F]U;F0@<W1O
M<F4@=&AA="!W:6QL(')E='5R;B!T:&4@;VED(&EN<W1E860N"B`@("`@*@H@
M("`@("H@0'-E92!S=&]R90H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D
M9&%T82`@("`@5&AE(&1A=&$@=&\@<W1O<F4@:6X@=&AE('-E<W-I;VX@<W1O
M<F4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<')U;F4@($EF(&9A;'-E+"!T
M:&ES(&]B:F5C="!W:6QL(&YO="!B92!P<G5N960@9G)O;2!T:&4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@<W1O<F4@:68@=&AE(&UA>&EM=6T@
M<W1O<F4@<VEZ92!I<R!E>&-E961E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE($U$-2!S=')I;F<@<F5P<F5S96YT:6YG('1H92!O8FIE
M8W0G<R!)1"X*("`@("`J+PH@("`@9G5N8W1I;VX@<W1O<F5/:60H)&1A=&$L
M("1P<G5N92`]('1R=64I"B`@("!["B`@("`@("`@)&]I9"`]("1T:&ES+3YO
M:60H)&1A=&$I.PH@("`@("`@("1T:&ES+3YS=&]R92@D;VED+"`D9&%T82P@
M)'!R=6YE*3L*("`@("`@("!R971U<FX@)&]I9#L*("`@('T*"B`@("`O*BH*
M("`@("`J($%T=&5M<'1S('1O('-T;W)E(&%N(&]B:F5C="!I;B!T:&4@<V5S
M<VEO;B!S=&]R92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O:60@
M("`@($]B:F5C="!)1"!U<V5D(&%S('1H92!S=&]R86=E(&ME>2X*("`@("`J
M($!P87)A;2!M:7AE9"`D9&%T82`@("`@5&AE(&1A=&$@=&\@<W1O<F4@:6X@
M=&AE('-E<W-I;VX@<W1O<F4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<')U
M;F4@($EF(&9A;'-E+"!T:&ES(&]B:F5C="!W:6QL(&YO="!B92!P<G5N960@
M9G)O;2!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@<W1O<F4@
M:68@=&AE(&UA>&EM=6T@<W1O<F4@<VEZ92!I<R!E>&-E961E9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L
M<V4@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<W1O<F4H)&]I
M9"P@)&1A=&$L("1P<G5N92`]('1R=64I"B`@("!["B`@("`@("`@+RH@4V5T
M('5P(&]B:F5C="!N;W<N("HO"B`@("`@("`@)&1A=&%/8FIE8W0@/2!A<G)A
M>2@I.PH@("`@("`@("1D871A3V)J96-T6R=D871A)UT@/2!S97)I86QI>F4H
M)&1A=&$I.PH@("`@("`@("1D871A3V)J96-T6R=P<G5N92==(#T@)'!R=6YE
M.PH*("`@("`@("!I9B`H(6ES<V5T*"1?4T534TE/3ELD=&AI<RT^7VYA;65=
M*2D@>PH@("`@("`@("`@("`D7U-%4U-)3TY;)'1H:7,M/E]N86UE72`](&%R
M<F%Y*"D["B`@("`@("`@("`@("1?4T534TE/3ELD=&AI<RT^7VYA;65=6R=?
M7W!R=6YE)UT@/2`P.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3Y?
M;W9E<G=R:71E('Q\("%I<W-E="@D7U-%4U-)3TY;)'1H:7,M/E]N86UE75LD
M;VED72DI('L*("`@("`@("`@("`@)%]315-324].6R1T:&ES+3Y?;F%M95U;
M)&]I9%T@/2`D9&%T84]B:F5C=#L*("`@("`@("`@("`@:68@*"1P<G5N92D@
M>PH@("`@("`@("`@("`@("`@)%]315-324].6R1T:&ES+3Y?;F%M95U;)U]?
M<')U;F4G72LK.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M*B!#:&5C:R!F;W(@<')U;F%B;&4@3VED<RX@*B\*("`@("`@("`D=&AI<RT^
M7W!R=6YE3VED<R@I.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J($]V97)W<FET97,@82!C=7)R96YT(&5L96UE;G0@:6X@
M=&AE(&]B:F5C="!S=&]R92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1O:60@("`@($]B:F5C="!)1"!U<V5D(&%S('1H92!S=&]R86=E(&ME>2X*
M("`@("`J($!P87)A;2!M:7AE9"`D9&%T82`@("`@5&AE(&1A=&$@=&\@<W1O
M<F4@:6X@=&AE('-E<W-I;VX@<W1O<F4N"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D<')U;F4@($EF(&9A;'-E+"!T:&ES(&]B:F5C="!W:6QL(&YO="!B92!P
M<G5N960@9G)O;2!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M<W1O<F4@:68@=&AE(&UA>&EM=6T@<W1O<F4@<VEZ92!I<R!E>&-E961E9"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S
M<RP@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@;W9E
M<G=R:71E*"1O:60L("1D871A+"`D<')U;F4@/2!T<G5E*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?;W9E<G=R:71E(#T@=')U93L*("`@("`@("`D<W5C8V5S
M<R`]("1T:&ES+3YS=&]R92@D;VED+"`D9&%T82P@)'!R=6YE*3L*("`@("`@
M("`D=&AI<RT^7V]V97)W<FET92`](&9A;'-E.PH@("`@("`@(')E='5R;B`D
M<W5C8V5S<SL*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E
M=')I=F4@86X@;V)J96-T(&9R;VT@=&AE('-T;W)E+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&]I9"`@($]B:F5C="!)1"!T;R!Q=65R>2X*("`@
M("`J($!P87)A;2!E;G5M("1T>7!E("`@($Y/5"!54T5$"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D=F%L("!.3U0@55-%1`H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%1H92!R97%U97-T960@;V)J96-T+"!O<B!F86QS92!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<75E<GDH)&]I9"P@)'1Y
M<&4@/2!N=6QL+"`D=F%L(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES
M<V5T*"1?4T534TE/3ELD=&AI<RT^7VYA;65=*2!\?`H@("`@("`@("`@("`H
M:7-?;G5L;"@D;VED*2!\?"`A:7-S970H)%]315-324].6R1T:&ES+3Y?;F%M
M95U;)&]I9%TI*2D@>PH@("`@("`@("`@("`D;V)J96-T(#T@9F%L<V4["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&]B:F5C="`]('5N<V5R:6%L
M:7IE*"1?4T534TE/3ELD=&AI<RT^7VYA;65=6R1O:61=6R=D871A)UTI.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)&]B:F5C=#L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E=',@=&AE('!R=6YE(&9L86<@;VX@82!S=&]R92!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VED("`@("!4:&4@
M;V)J96-T($E$+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'!R=6YE("!4<G5E
M('1O(&%L;&]W('!R=6YI;F<L(&9A;'-E(&9O<B!N;R!P<G5N:6YG+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S9710<G5N949L86<H)&]I9"P@)'!R=6YE*0H@
M("`@>PH@("`@("`@(&EF("AI<W-E="@D7U-%4U-)3TY;)'1H:7,M/E]N86UE
M75LD;VED72D@)B8*("`@("`@("`@("`@*"1?4T534TE/3ELD=&AI<RT^7VYA
M;65=6R1O:61=6R=P<G5N92==("$]("1P<G5N92DI('L*("`@("`@("`@("`@
M)%]315-324].6R1T:&ES+3Y?;F%M95U;)&]I9%U;)W!R=6YE)UT@/2`D<')U
M;F4["B`@("`@("`@("`@(&EF("@D<')U;F4I('L*("`@("`@("`@("`@("`@
M("1?4T534TE/3ELD=&AI<RT^7VYA;65=6R=?7W!R=6YE)UTK*SL*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1?4T534TE/3ELD=&AI
M<RT^7VYA;65=6R=?7W!R=6YE)UTM+3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E<R!A;B!/240@9F]R
M(&%N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1A=&$@
M(%1H92!D871A('1O('-T;W)E(&EN('1H92!S=&]R92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`D;VED("!!;B!O8FIE8W0@240@=&\@=7-E(&%S
M('1H92!S=&]R86=E(&ME>2X*("`@("`J+PH@("`@9G5N8W1I;VX@;VED*"1D
M871A*0H@("`@>PH@("`@("`@(')E='5R;B!M9#4H<V5R:6%L:7IE*"1D871A
M*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T92!T:&4@;&ES="!O
M9B!P<G5N86)L92!O:61S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!F=6YC=&EO;B!?<')U;F5/:61S*"D*("`@('L*("`@
M("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7W!R=6YE3&ES="D@)B8*("`@("`@
M("`@("`@:7-S970H)%]315-324].6R1T:&ES+3Y?;F%M95U;)U]?<')U;F4G
M72D@)B8*("`@("`@("`@("`@*"1?4T534TE/3ELD=&AI<RT^7VYA;65=6R=?
M7W!R=6YE)UT@/B`D=&AI<RT^7W-I>F4I*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?<')U;F5,:7-T(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R96%C:"`H
M)%]315-324].6R1T:&ES+3Y?;F%M95T@87,@)&ME>2`]/B`D=F%L*2!["B`@
M("`@("`@("`@("`@("!I9B`H)'9A;%LG<')U;F4G72D@>PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<')U;F5,:7-T6UT@/2`D:V5Y.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(')E9VES=&5R
M7W-H=71D;W=N7V9U;F-T:6]N*&%R<F%Y*"8D=&AI<RP@)U]P<G5N92<I*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!0<G5N92!O;&0@<W1O
M<F4@96YT<FEE<R!A="!R97%U97-T('-H=71D;W=N+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?<')U;F4H
M*0H@("`@>PH@("`@("`@("1P<G5N94]I9',@/2!A<G)A>5]S;&EC92@D=&AI
M<RT^7W!R=6YE3&ES="P@,"P@)%]315-324].6R1T:&ES+3Y?;F%M95U;)U]?
M<')U;F4G72`M("1T:&ES+3Y?<VEZ92D["B`@("`@("`@9F]R96%C:"`H)'!R
M=6YE3VED<R!A<R`D=F%L*2!["B`@("`@("`@("`@('5N<V5T*"1?4T534TE/
M3ELD=&AI<RT^7VYA;65=6R1V86Q=*3L*("`@("`@("!]"B`@("`@("`@)%]3
M15-324].6R1T:&ES+3Y?;F%M95U;)U]?<')U;F4G72`M/2!C;W5N="@D<')U
M;F5/:61S*3L*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]3
M:&%R92YP:'``````````````````````````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P-S4Q,#,`,3`U,34T,S,W-3(`,#(Q,C0U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@
M)TAO<F1E+T1A=&%4<F5E+G!H<"<["@HO*BH*("H@2&]R9&5?4VAA<F4Z.B!P
M<F]V:61E<R!A;B!I;G1E<F9A8V4@=&\@86QL('-H87)E<R!A('5S97(@;6EG
M:'0@:&%V92X@($ET<PH@*B!M971H;V1S('1A:V4@8V%R92!O9B!A;GD@<VET
M92US<&5C:69I8R!R97-T<FEC=&EO;G,@8V]N9FEG=7)E9"!I;B!I;B!T:&4*
M("H@87!P;&EC871I;VXG<R!P<F5F<RYP:'`@86YD(&-O;F8N<&AP(&9I;&5S
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]3:&%R92]3:&%R92YP:'`L=B`Q
M+C$Q,2XR+C(P(#(P,#8O,#4O,#0@,3,Z,C4Z,CD@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`R+3(P,#8@2F]E;"!686YD86P@/&IV86YD86Q`:6YF
M;W1E8VLN<6,N8V$^"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@26YF;W1E8VL@
M26YT97)N970@/'=E8FUA<W1E<D!I;F9O=&5C:RYQ8RYC83X*("H@0V]P>7)I
M9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IO96P@5F%N9&%L(#QJ
M=F%N9&%L0&EN9F]T96-K+G%C+F-A/@H@*B!`875T:&]R("!-:6ME($-O8VAR
M86UE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`875T:&]R("!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R
M9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U-H87)E"B`J+PIC;&%S<R!(;W)D
M95]3:&%R92!["@H@("`@+RHJ"B`@("`@*B!0;VEN=&5R('1O(&$@1&%T851R
M964@:6YS=&%N8V4@=&\@;6%N86=E+W-T;W)E('-H87)E<PH@("`@("H*("`@
M("`J($!V87(@1&%T851R964*("`@("`J+PH@("`@=F%R("1?9&%T871R964[
M"@H@("`@+RHJ"B`@("`@*B!4:&4@87!P;&EC871I;VX@=V4G<F4@;6%N86=I
M;F<@<VAA<F5S(&9O<BX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)%]A<'`["@H@("`@+RHJ"B`@("`@*B!4:&4@<W5B8VQA
M<W,@;V8@1&%T851R965/8FIE8W0@=&\@:6YS=&%N=&EA=&4@<VAA<F5S(&%S
M+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M7W-H87)E3V)J96-T(#T@)T1A=&%4<F5E3V)J96-T7U-H87)E)SL*"B`@("`O
M*BH*("`@("`J($$@8V%C:&4@;V8@86QL('-H87)E<R!T:&%T(&AA=F4@8F5E
M;B!R971R:65V960L('-O('=E(&1O;B=T(&AI="!T:&4*("`@("`J(&)A8VME
M;F0@86=A:6X@86YD(&%G86EN(&9O<B!T:&5M+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?8V%C:&4@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@0V%C:&4@=7-E9"!F;W(@;&ES=%-H87)E<R@I+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?;&ES
M=&-A8VAE(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($$@;&ES="!O9B!O
M8FIE8W1S('1H870@=V4G<F4@8W5R<F5N=&QY('-O<G1I;F<L(&9O<B!R969E
M<F5N8V4@9'5R:6YG('1H90H@("`@("H@<V]R=&EN9R!A;&=O<FET:&TN"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]S;W)T
M3&ES=#L*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E
M9F5R96YC92!T;R!A(&-O;F-R971E($AO<F1E7U-H87)E(&EN<W1A;F-E+B!)
M=`H@("`@("H@=VEL;"!O;FQY(&-R96%T92!A(&YE=R!I;G-T86YC92!I9B!N
M;R!(;W)D95]3:&%R92!I;G-T86YC92!C=7)R96YT;'D*("`@("`J(&5X:7-T
M<RX*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@
M87,Z"B`@("`@*B`@(#QC;V1E/B1V87(@/2`F2&]R9&5?4VAA<F4Z.G-I;F=L
M971O;B@D87!P*3L\+V-O9&4^"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D87!P("!4:&4@87!P;&EC871I;VYS('1H870@=&AE('-H87)E<R!R96QA
M=&5S('1O+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?4VAA<F4@(%1H
M92!C;VYC<F5T92!3:&%R92!R969E<F5N8V4L(&]R(&9A;'-E(&]N(&%N(&5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1A<'`I"B`@
M("!["B`@("`@("`@<W1A=&EC("1S:&%R97,["@H@("`@("`@(&EF("@A:7-S
M970H)'-H87)E<ULD87!P72DI('L*("`@("`@("`@("`@)'-H87)E<ULD87!P
M72`](&YE=R!(;W)D95]3:&%R92@D87!P*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D<VAA<F5S6R1A<'!=.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P
M("!4:&4@87!P;&EC871I;VX@=&AA="!T:&4@<VAA<F5S(&)E;&]N9R!T;RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?4VAA<F4H)&%P<"D*("`@('L*
M("`@("`@("!G;&]B86P@)&-O;F8L("1R96=I<W1R>3L*"B`@("`@("`@:68@
M*&5M<'1Y*"1C;VYF6R=D871A=')E92==6R=D<FEV97(G72DI('L*("`@("`@
M("`@("`@2&]R9&4Z.F9A=&%L*"=9;W4@;75S="!C;VYF:6=U<F4@82!$871A
M5')E92!B86-K96YD('1O('5S92!3:&%R97,N)RP@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("!]"@H@("`@("`@("1D<FEV97(@/2`D8V]N9ELG9&%T
M871R964G75LG9')I=F5R)UT["B`@("`@("`@)'1H:7,M/E]A<'`@/2`D87!P
M.PH@("`@("`@("1T:&ES+3Y?9&%T871R964@/2`F1&%T851R964Z.G-I;F=L
M971O;B@*("`@("`@("`@("`@)&1R:79E<BP*("`@("`@("`@("`@87)R87E?
M;65R9V4H2&]R9&4Z.F=E=$1R:79E<D-O;F9I9R@G9&%T871R964G+"`D9')I
M=F5R*2P@87)R87DH)V=R;W5P)R`]/B`G:&]R9&4N<VAA<F5S+B<@+B`D87!P
M*2D*("`@("`@("`I.PH*("`@("`@("!(;W)D93HZ8V%L;$AO;VLH)U]H;W)D
M95]H;V]K7W-H87)E7VEN:70G+"!A<G)A>2@D=&AI<RP@)&%P<"DI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@1&%T851R964@:6YS=&%N
M8V4@=7-E9"!T;R!M86YA9V4@=&AI<R!S:&%R92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N($1A=&%4<F5E("!4:&ES('-H87)E)W,@1&%T851R964@:6YS=&%N
M8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971$871A5')E92@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T871R964["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&$@1&%T851R965/8FIE8W1?4VAA<F4@;V)J
M96-T(&-O<G)E<W!O;F1I;F<@=&\@=&AE(&=I=F5N('-H87)E"B`@("`@*B!N
M86UE+"!W:71H('1H92!D971A:6QS(')E=')I979E9"!A<'!R;W!R:6%T96QY
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE
M(&]F('1H92!S:&%R92!T;R!R971R:65V92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N($1A=&%4<F5E3V)J96-T7U-H87)E("!4:&4@<F5Q=65S=&5D('-H87)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T4VAA<F4H)&YA;64I"B`@("![
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8V%C:&5;)&YA;65=*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]C86-H95LD;F%M95T["B`@("`@
M("`@?0H*("`@("`@("`D=&AI<RT^7V-A8VAE6R1N86UE72`]("8D=&AI<RT^
M7V1A=&%T<F5E+3YG971/8FIE8W0H)&YA;64L("1T:&ES+3Y?<VAA<F5/8FIE
M8W0I.PH@("`@("`@(&EF("@A:7-?82@D=&AI<RT^7V-A8VAE6R1N86UE72P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V-A8VAE6R1N
M86UE72T^<V5T4VAA<F5/8B@D=&AI<RD["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)'1H:7,M/E]C86-H95LD;F%M95T["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS(&$@1&%T851R965/8FIE8W1?4VAA<F4@;V)J96-T(&-O
M<G)E<W!O;F1I;F<@=&\@=&AE(&=I=F5N('5N:7%U90H@("`@("H@240L('=I
M=&@@=&AE(&1E=&%I;',@<F5T<FEE=F5D(&%P<')O<')I871E;'DN"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VED("!4:&4@:60@;V8@=&AE('-H
M87)E('1O(')E=')I979E+@H@("`@("H*("`@("`J($!R971U<FX@1&%T851R
M965/8FIE8W1?4VAA<F4@(%1H92!R97%U97-T960@<VAA<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N("9G9713:&%R94)Y260H)&-I9"D*("`@('L*("`@("`@
M("`D<VAA<F4@/2`D=&AI<RT^7V1A=&%T<F5E+3YG971/8FIE8W1">4ED*"1C
M:60L("1T:&ES+3Y?<VAA<F5/8FIE8W0I.PH@("`@("`@(&EF("@A:7-?82@D
M<VAA<F4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)'-H87)E+3YS
M9713:&%R94]B*"1T:&ES*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1S
M:&%R93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@87)R87D@
M;V8@1&%T851R965/8FIE8W1?4VAA<F4@;V)J96-T<R!C;W)R97-P;VYD:6YG
M('1O('1H90H@("`@("H@9VEV96X@<V5T(&]F('5N:7%U92!)1',L('=I=&@@
M=&AE(&1E=&%I;',@<F5T<FEE=F5D(&%P<')O<')I871E;'DN"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1C:61S("!4:&4@87)R87D@;V8@:61S('1O
M(')E=')I979E+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!R
M97%U97-T960@<VAA<F5S+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T4VAA
M<F5S*"1C:61S*0H@("`@>PH@("`@("`@("1S:&%R97,@/2`D=&AI<RT^7V1A
M=&%T<F5E+3YG971/8FIE8W1S*"1C:61S+"`D=&AI<RT^7W-H87)E3V)J96-T
M*3L*("`@("`@("!I9B`H:7-?82@D<VAA<F5S+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D<VAA<F5S.PH@("`@("`@('T*"B`@("`@
M("`@)&ME>7,@/2!A<G)A>5]K97ES*"1S:&%R97,I.PH@("`@("`@(&9O<F5A
M8V@@*"1K97ES(&%S("1K97DI('L*("`@("`@("`@("`@:68@*&ES7V$H)'-H
M87)E<ULD:V5Y72P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1S:&%R97-;)&ME>5T["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1T:&ES+3Y?8V%C:&5;)&ME>5T@/2`F)'-H87)E<ULD:V5Y73L*("`@
M("`@("`@("`@)'-H87)E<ULD:V5Y72T^<V5T4VAA<F5/8B@D=&AI<RD["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)'-H87)E<SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@82!N97<@<VAA<F4@;V)J96-T+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!S:&%R92=S(&YA;64N
M"B`@("`@*@H@("`@("H@0')E='5R;B!$871A5')E94]B:F5C=%]3:&%R92`@
M02!N97<@<VAA<F4@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B`F;F5W
M4VAA<F4H)&YA;64I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1N86UE*2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4VAA<F4@
M;F%M97,@;75S="!B92!N;VXM96UP='DG*3L*("`@("`@("!]"B`@("`@("`@
M)'-H87)E(#T@)FYE=R`D=&AI<RT^7W-H87)E3V)J96-T*"1N86UE*3L*("`@
M("`@("`D<VAA<F4M/G-E=$1A=&%4<F5E*"1T:&ES+3Y?9&%T871R964I.PH@
M("`@("`@("1S:&%R92T^<V5T4VAA<F5/8B@D=&AI<RD["B`@("`@("`@)'-H
M87)E+3YS970H)V]W;F5R)RP@075T:#HZ9V5T075T:"@I*3L*"B`@("`@("`@
M<F5T=7)N("1S:&%R93L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@82!S
M:&%R92!T;R!T:&4@<VAA<F5S('-Y<W1E;2X@5&AE('-H87)E(&UU<W0@9FER
M<W0@8F4@8W)E871E9"!W:71H"B`@("`@*B!(;W)D95]3:&%R93HZ;F5W4VAA
M<F4H*2P@86YD(&AA=F4@86YY(&EN:71I86P@9&5T86EL<R!A9&1E9"!T;R!I
M="P*("`@("`J(&)E9F]R92!T:&ES(&9U;F-T:6]N(&ES(&-A;&QE9"X*("`@
M("`J"B`@("`@*B!`<&%R86T@1&%T851R965/8FIE8W1?4VAA<F4@)'-H87)E
M("!4:&4@;F5W('-H87)E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86Y\4$5!4E]%<G)O<B`@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!A9&13:&%R92@D<VAA<F4I"B`@("!["B`@
M("`@("`@:68@*"%I<U]A*"1S:&%R92P@)T1A=&%4<F5E3V)J96-T7U-H87)E
M)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U-H
M87)E<R!M=7-T(&)E($1A=&%4<F5E3V)J96-T7U-H87)E(&]B:F5C=',@;W(@
M97AT96YD('1H870@8VQA<W,N)RD["B`@("`@("`@?0H*("`@("`@("`D<&5R
M;2`]("8D1TQ/0D%,4ULG<&5R;7,G72T^;F5W4&5R;6ES<VEO;B@D<VAA<F4M
M/F=E=$YA;64H*2D["B`@("`@("`@:68@*&ES7V$H)'!E<FTL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1P97)M.PH@("`@("`@('T*
M"B`@("`@("`@+RH@1VEV92!T:&4@;W=N97(@9G5L;"!A8V-E<W,@*B\*("`@
M("`@("`D<&5R;2T^861D57-E<E!E<FUI<W-I;VXH)'-H87)E+3YG970H)V]W
M;F5R)RDL(%!%4DU37U-(3U<L(&9A;'-E*3L*("`@("`@("`D<&5R;2T^861D
M57-E<E!E<FUI<W-I;VXH)'-H87)E+3YG970H)V]W;F5R)RDL(%!%4DU37U)%
M040L(&9A;'-E*3L*("`@("`@("`D<&5R;2T^861D57-E<E!E<FUI<W-I;VXH
M)'-H87)E+3YG970H)V]W;F5R)RDL(%!%4DU37T5$250L(&9A;'-E*3L*("`@
M("`@("`D<&5R;2T^861D57-E<E!E<FUI<W-I;VXH)'-H87)E+3YG970H)V]W
M;F5R)RDL(%!%4DU37T1%3$5412P@9F%L<V4I.PH*("`@("`@("`D<VAA<F4M
M/G-E=%!E<FUI<W-I;VXH)'!E<FTL(&9A;'-E*3L*"B`@("`@("`@)')E<W5L
M="`]($AO<F1E.CIC86QL2&]O:R@G7VAO<F1E7VAO;VM?<VAA<F5?861D)RP@
M87)R87DH)'-H87)E*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=H;W)D92<L(&9A;'-E*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T871R964M
M/F%D9"@D<VAA<F4I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!A
M('-H87)E(&9R;VT@=&AE('-H87)E<R!S>7-T96T@<&5R;6%N96YT;'DN"B`@
M("`@*@H@("`@("H@0'!A<F%M($1A=&%4<F5E3V)J96-T7U-H87)E("1S:&%R
M92`@5&AE('-H87)E('1O(')E;6]V92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86Y\4$5!4E]%<G)O<B`@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F53:&%R92@D<VAA<F4I"B`@("![
M"B`@("`@("`@:68@*"%I<U]A*"1S:&%R92P@)T1A=&%4<F5E3V)J96-T7U-H
M87)E)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)U-H87)E<R!M=7-T(&)E($1A=&%4<F5E3V)J96-T7U-H87)E(&]B:F5C=',@
M;W(@97AT96YD('1H870@8VQA<W,N)RD["B`@("`@("`@?0H*("`@("`@("`D
M<F5S=6QT(#T@2&]R9&4Z.F-A;&Q(;V]K*"=?:&]R9&5?:&]O:U]S:&%R95]R
M96UO=F4G+"!A<G)A>2@D<VAA<F4I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VAO<F1E)RP@9F%L<V4I.PH@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]D
M871A=')E92T^<F5M;W9E*"1S:&%R92D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#:&5C:W,@=&\@<V5E(&EF(&$@<VAA<F4@:&%S(&%N>2!C:&EL9"!S:&%R
M97,N"B`@("`@*@H@("`@("H@0'!A<F%M($1A=&%4<F5E3V)J96-T7U-H87)E
M("1S:&%R92`@5&AE('-H87)E('1O(&-H96-K(&9O<B!C:&EL9')E;BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE('-P96-I
M9FEE9"!S:&%R92!H87,@8VAI;&0@<VAA<F5S+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!H87-#:&EL9')E;B@D<VAA<F4I"B`@("!["B`@("`@("`@:68@*"%I
M<U]A*"1S:&%R92P@)T1A=&%4<F5E3V)J96-T7U-H87)E)RDI('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U-H87)E<R!M=7-T(&)E
M($1A=&%4<F5E3V)J96-T7U-H87)E(&]B:F5C=',@;W(@97AT96YD('1H870@
M8VQA<W,N)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@*&)O;VPI)'1H
M:7,M/E]D871A=')E92T^9V5T3G5M8F5R3V9#:&EL9')E;B@D<VAA<F4I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('-H87)E)W,@9&ER96-T
M('!A<F5N="!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<VAA<F4@($=E="!T:&4@<&%R96YT(&]F('1H:7,@<VAA<F4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!$871A5')E94]B:F5C=%]3:&%R92`@5&AE('!A<F5N
M="!S:&%R92P@:68@:70@97AI<W1S+@H@("`@("HO"B`@("!F=6YC=&EO;B`F
M9V5T4&%R96YT*"1C:&EL9"D*("`@('L*("`@("`@("`D:60@/2`D=&AI<RT^
M7V1A=&%T<F5E+3YG971087)E;G0H)&-H:6QD*3L*("`@("`@("!I9B`H:7-?
M82@D:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I
M9#L*("`@("`@("!]"@H@("`@("`@(&EF("@A)&ED('Q\("@D:60@/3T@1$%4
M0512145?4D]/5"DI('L*("`@("`@("`@("`@)&5R<F]R(#T@4$5!4CHZ<F%I
M<V5%<G)O<B@G4&%R96YT(&1O97,@;F]T(&5X:7-T+B<I.PH@("`@("`@("`@
M("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T
M:&ES+3YG9713:&%R94)Y260H)&ED*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE($E$(&]F(&$@<VAA<F4N"B`@("`@*@H@("`@("H@0'!A
M<F%M($1A=&%4<F5E3V)J96-T7U-H87)E("!4:&4@<VAA<F4@=&\@<F5T=7)N
M('1H92!)1"!O9BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H
M92!S:&%R92=S($E$(&]R(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T4VAA<F5)9"@D<VAA<F4I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?9&%T871R964M/F=E=$ED*"1S:&%R92T^9V5T
M3F%M92@I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%5T:6QI='D@9G5N8W1I
M;VX@=&\@8F4@=7-E9"!W:71H('5A<V]R="@I(&9O<B!S;W)T:6YG(&%R<F%Y
M<R!O9@H@("`@("H@2&]R9&5?4VAA<F4@;V)J96-T<RX*("`@("`J($5X86UP
M;&4Z/&-O9&4^"B`@("`@*B!U87-O<G0H)&QI<W0L(&%R<F%Y*"=(;W)D95]3
M:&%R92<L("=?<V]R=%-H87)E<R<I*3L*("`@("`J(#PO8V]D93X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@
M7W-O<G13:&%R97,H)&$L("1B*0H@("`@>PH@("`@("`@("1A4&%R=',@/2!E
M>'!L;V1E*"<Z)RP@)&$M/F=E=$YA;64H*2D["B`@("`@("`@)&)087)T<R`]
M(&5X<&QO9&4H)SHG+"`D8BT^9V5T3F%M92@I*3L*"B`@("`@("`@)&UI;B`]
M(&UI;BAC;W5N="@D85!A<G1S*2P@8V]U;G0H)&)087)T<RDI.PH@("`@("`@
M("1I9$$@/2`G)SL*("`@("`@("`D:61"(#T@)R<["B`@("`@("`@9F]R("@D
M:2`](#`[("1I(#P@)&UI;CL@)&DK*RD@>PH@("`@("`@("`@("!I9B`H)&ED
M02D@>PH@("`@("`@("`@("`@("`@)&ED02`N/2`G.B<["B`@("`@("`@("`@
M("`@("`D:61"("X]("<Z)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M:61!("X]("1A4&%R='-;)&E=.PH@("`@("`@("`@("`D:61"("X]("1B4&%R
M='-;)&E=.PH*("`@("`@("`@("`@:68@*"1I9$$@(3T@)&ED0BD@>PH@("`@
M("`@("`@("`@("`@)&-U<D$@/2!I<W-E="@D=&AI<RT^7W-O<G1,:7-T6R1I
M9$%=*2`_("1T:&ES+3Y?<V]R=$QI<W1;)&ED05TM/F=E="@G;F%M92<I(#H@
M)R<["B`@("`@("`@("`@("`@("`D8W5R0B`](&ES<V5T*"1T:&ES+3Y?<V]R
M=$QI<W1;)&ED0ETI(#\@)'1H:7,M/E]S;W)T3&ES=%LD:61"72T^9V5T*"=N
M86UE)RD@.B`G)SL*("`@("`@("`@("`@("`@(')E='5R;B!S=')N871C87-E
M8VUP*"1C=7)!+"`D8W5R0BD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!C;W5N="@D85!A<G1S*2`^(&-O=6YT*"1B4&%R=',I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS(&EF(&$@<VAA<F4@97AI
M<W1S(&EN('1H92!S>7-T96TN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<VAA<F4@(%1H92!S:&%R92!T;R!C:&5C:RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE('-H87)E(&5X:7-T<RP@9F%L
M<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>&ES=',H)'-H
M87)E*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1A=&%T<F5E+3YE
M>&ES=',H)'-H87)E*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE(&-O=6YT(&]F(&%L;"!S:&%R97,@=&AA="`D=7-E<FED(&AA<R!A8V-E
M<W,@=&\N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'5S97)I9"`@
M("`@(%1H92!U<V5R:60@;V8@=&AE('5S97(@=&\@8VAE8VL@86-C97-S(&9O
M<BX*("`@("`J($!P87)A;2!I;G1E9V5R("1P97)M("`@("`@("!4:&4@;&5V
M96P@;V8@<&5R;6ES<VEO;G,@<F5Q=6ER960N"B`@("`@*B!`<&%R86T@;6EX
M960@("`D871T<FEB=71E<R`@4F5S=')I8W0@=&AE('-H87)E<R!C;W5N=&5D
M('1O('1H;W-E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M;6%T8VAI;F<@)&%T=')I8G5T97,N($%N(&%R<F%Y(&]F"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@871T<FEB=71E+W9A;'5E<R!P86ER
M<R!O<B!A('-H87)E(&]W;F5R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@=7-E<FYA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<&%R
M96YT("`@("`@5&AE('!A<F5N="!S:&%R92!T;R!S=&%R="!S96%R8VAI;F<@
M870N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D86QL3&5V96QS("`@4F5T=7)N
M(&%L;"!L979E;',L(&]R(&IU<W0@=&AE(&1I<F5C=`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&-H:6QD<F5N(&]F("1P87)E;G0_($1E
M9F%U;'1S('1O(&%L;"!L979E;',N"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G1E9V5R("!.=6UB97(@;V8@<VAA<F5S('1H92!U<V5R(&AA<R!A8V-E<W,@
M=&\N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O=6YT4VAA<F5S*"1U<V5R:60L
M("1P97)M(#T@4$5235-?4TA/5RP@)&%T=')I8G5T97,@/2!N=6QL+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!A<F5N="`]($1!5$%44D5%7U)/3U0L
M("1A;&Q,979E;',@/2!T<G5E*0H@("`@>PH@("`@("`@("1K97D@/2!S97)I
M86QI>F4H87)R87DH)'1H:7,M/E]A<'`L("1U<V5R:60L("1P97)M+"`D871T
M<FEB=71E<RP@)'!A<F5N="P@)&%L;$QE=F5L<RP@)V-O=6YT)RDI.PH@("`@
M("`@(&EF("AE;7!T>2@D=&AI<RT^7VQI<W1C86-H95LD:V5Y72DI('L*("`@
M("`@("`@("`@)&-R:71E<FEA(#T@)'1H:7,M/F=E=%-H87)E0W)I=&5R:6$H
M)'5S97)I9"P@)'!E<FTL("1A='1R:6)U=&5S*3L*("`@("`@("`@("`@)'1H
M:7,M/E]L:7-T8V%C:&5;)&ME>5T@/2`D=&AI<RT^7V1A=&%T<F5E+3YC;W5N
M=$)Y071T<FEB=71E<R@D8W)I=&5R:6$L("1P87)E;G0L("1A;&Q,979E;',L
M("=I9"<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;&ES
M=&-A8VAE6R1K97E=.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A
M;B!A<G)A>2!O9B!A;&P@<VAA<F5S('1H870@)'5S97)I9"!H87,@86-C97-S
M('1O+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1U<V5R:60@("`@
M("`@5&AE('5S97)I9"!O9B!T:&4@=7-E<B!T;R!C:&5C:R!A8V-E<W,@9F]R
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'!E<FT@("`@("`@("!4:&4@;&5V
M96P@;V8@<&5R;6ES<VEO;G,@<F5Q=6ER960N"B`@("`@*B!`<&%R86T@;6EX
M960@("`D871T<FEB=71E<R`@(%)E<W1R:6-T('1H92!S:&%R97,@8V]U;G1E
M9"!T;R!T:&]S90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!M871C:&EN9R`D871T<FEB=71E<RX@06X@87)R87D@;V8*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@871T<FEB=71E+W9A;'5E<R!P
M86ER<R!O<B!A('-H87)E(&]W;F5R"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('5S97)N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`@
M)'!A<F5N="`@("`@("!4:&4@<&%R96YT('-H87)E('1O('-T87)T('-E87)C
M:&EN9R!A="X*("`@("`J($!P87)A;2!B;V]L96%N("1A;&Q,979E;',@("`@
M4F5T=7)N(&%L;"!L979E;',L(&]R(&IU<W0@=&AE(&1I<F5C=`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C:&EL9')E;B!O9B`D<&%R
M96YT/R!$969A=6QT<R!T;R!A;&P*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@;&5V96QS+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&9R
M;VT@("`@("`@("!4:&4@<VAA<F4@=&\@<W1A<G0@;&ES=&EN9R!A="X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1C;W5N="`@("`@("`@5&AE(&YU;6)E<B!O
M9B!S:&%R97,@=&\@<F5T=7)N+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-O
M<G1B>5]N86UE("!!='1R:6)U=&4@;F%M92!T;R!U<V4@9F]R('-O<G1I;F<N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V]R=&)Y7VME>2`@($%T=')I8G5T
M92!K97D@=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&1I<F5C=&EO;B`@("!3;W)T(&1I<F5C=&EO;CH*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`P("T@87-C96YD:6YG"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,2`M(&1E<V-E;F1I
M;F<*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@<VAA<F5S('1H
M92!U<V5R(&AA<R!A8V-E<W,@=&\N"B`@("`@*B\*("`@(&9U;F-T:6]N("9L
M:7-T4VAA<F5S*"1U<V5R:60L("1P97)M(#T@4$5235-?4TA/5RP@)&%T=')I
M8G5T97,@/2!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F5N
M="`]($1!5$%44D5%7U)/3U0L("1A;&Q,979E;',@/2!T<G5E+"`D9G)O;2`]
M(#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`D8V]U;G0@/2`P+"`D<V]R
M=&)Y7VYA;64@/2!N=6QL+"`D<V]R=&)Y7VME>2`](&YU;&PL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`D9&ER96-T:6]N(#T@,"D*("`@('L*("`@("`@
M("`D:V5Y(#T@<V5R:6%L:7IE*&%R<F%Y*"1T:&ES+3Y?87!P+"`D=7-E<FED
M+"`D<&5R;2P@)&%T=')I8G5T97,L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&%R96YT+"`D86QL3&5V96QS+"`D9G)O;2P@)&-O=6YT+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-O<G1B>5]N86UE+"`D
M<V]R=&)Y7VME>2P@)&1I<F5C=&EO;BDI.PH@("`@("`@(&EF("AE;7!T>2@D
M=&AI<RT^7VQI<W1C86-H95LD:V5Y72DI('L*("`@("`@("`@("`@)&-R:71E
M<FEA(#T@)'1H:7,M/F=E=%-H87)E0W)I=&5R:6$H)'5S97)I9"P@)'!E<FTL
M("1A='1R:6)U=&5S*3L*("`@("`@("`@("`@)'-H87)E;&ES="`]("1T:&ES
M+3Y?9&%T871R964M/F=E=$)Y071T<FEB=71E<R@*("`@("`@("`@("`@("`@
M("1C<FET97)I82P@)'!A<F5N="P@)&%L;$QE=F5L<RP@)VED)RP@)&9R;VTL
M("1C;W5N="P*("`@("`@("`@("`@("`@("1S;W)T8GE?;F%M92P@)'-O<G1B
M>5]K97DL("1D:7)E8W1I;VXI.PH@("`@("`@("`@("!I9B`H:7-?82@D<VAA
M<F5L:7-T+"`G4$5!4E]%<G)O<B<I('Q\("%C;W5N="@D<VAA<F5L:7-T*2D@
M>PH@("`@("`@("`@("`@("`@+RH@268@=V4@9V]T(&)A8VL@86X@97)R;W(@
M;W(@86X@96UP='D@87)R87DL('!A<W,@:70@8F%C:R!T;PH@("`@("`@("`@
M("`@("`@("H@=&AE(&-A;&QE<BX@*B\*("`@("`@("`@("`@("`@(')E='5R
M;B`D<VAA<F5L:7-T.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!-
M86ME('-U<F4@9V5T4VAA<F5S*"D@9&ED;B=T(')E='5R;B!A;B!E<G)O<BX@
M*B\*("`@("`@("`@("`@)'-H87)E<R`]("8D=&AI<RT^9V5T4VAA<F5S*&%R
M<F%Y7VME>7,H)'-H87)E;&ES="DI.PH@("`@("`@("`@("!I9B`H:7-?82@D
M<VAA<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)'-H87)E<SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M
M/E]L:7-T8V%C:&5;)&ME>5T@/2`F)'-H87)E<SL*("`@("`@("`@("`@)'1H
M:7,M/E]S;W)T3&ES="`]("1T:&ES+3Y?;&ES=&-A8VAE6R1K97E=.PH@("`@
M("`@("`@("!U87-O<G0H)'1H:7,M/E]L:7-T8V%C:&5;)&ME>5TL(&%R<F%Y
M*"1T:&ES+"`G7W-O<G13:&%R97,G*2D["B`@("`@("`@("`@("1T:&ES+3Y?
M<V]R=$QI<W0@/2!N=6QL.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]
M($AO<F1E.CIC86QL2&]O:R@G7VAO<F1E7VAO;VM?<VAA<F5?;&ES="<L(&%R
M<F%Y*"1U<V5R:60L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<&5R;2P@)&%T=')I8G5T97,L("1T:&ES+3Y?;&ES=&-A8VAE6R1K97E=
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=H;W)D92<L
M(&9A;'-E*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;&ES=&-A8VAE6R1K97E=.PH@("`@
M?0H*("`@("\J*@H@("`@("H@3&ES=',@*F%L;"H@<VAA<F5S(&9O<B!T:&4@
M8W5R<F5N="!A<'`O<VAA<F4L(')E9V%R9&QE<W,@;V8*("`@("`J('!E<FUI
M<W-I;VYS+B!4:&ES(&ES(&9O<B!A9&UI;B!F=6YC=&EO;F%L:71Y(&%N9"!S
M8W)I<'1I;F<@=&]O;',L(&%N9`H@("`@("H@<VAO=6QD;B=T(&)E(&-A;&QE
M9"!F<F]M('5S97(M;&5V96P@8V]D92$*("`@("`J"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D<&%R96YT("!3=&%R="!T:&4@;&ES=&EN9R!A="!A(&-E<G1A
M:6X@<&]I;G0@:6X@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!T<F5E+B!$969A=6QT<R!T;R!$051!5%)%15]23T]4+"!T:&4@<F]O="X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;&P@<VAA<F5S(&9O<B!T
M:&4@8W5R<F5N="!A<'`O<VAA<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI
M<W1!;&Q3:&%R97,H)'!A<F5N="`]($1!5$%44D5%7U)/3U0I"B`@("!["B`@
M("`@("`@)'-H87)E;&ES="`]("1T:&ES+3Y?9&%T871R964M/F=E="A$051!
M5%)%15]&3U)-051?1DQ!5"P@)'!A<F5N="P@=')U92D["B`@("`@("`@:68@
M*&ES7V$H)'-H87)E;&ES="P@)U!%05)?17)R;W(G*2!\?"`A8V]U;G0H)'-H
M87)E;&ES="DI('L*("`@("`@("`@("`@+R\@268@=V4@9V]T(&)A8VL@86X@
M97)R;W(@;W(@86X@96UP='D@87)R87DL(&IU<W0@<F5T=7)N(&ET+@H@("`@
M("`@("`@("!R971U<FX@)'-H87)E;&ES=#L*("`@("`@("!]"B`@("`@("`@
M=6YS970H)'-H87)E;&ES=%LD<&%R96YT72D["@H@("`@("`@("1S:&%R97,@
M/2`F)'1H:7,M/F=E=%-H87)E<RAA<G)A>5]K97ES*"1S:&%R96QI<W0I*3L*
M("`@("`@("!I9B`H:7-?82@D<VAA<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<VAA<F5S.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/E]S;W)T3&ES="`]("1S:&%R97,["B`@("`@("`@=6%S;W)T*"1S
M:&%R97,L(&%R<F%Y*"1T:&ES+"`G7W-O<G13:&%R97,G*2D["B`@("`@("`@
M)'1H:7,M/E]S;W)T3&ES="`](&YU;&P["@H@("`@("`@(')E='5R;B`D<VAA
M<F5S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!A<G)A>2!O
M9B!C<FET97)I82!F;W(@<75E<GEI;F<@<VAA<F5S+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@("1U<V5R:60@("`@("!4:&4@=7-E<FED(&]F('1H
M92!U<V5R('1O(&-H96-K(&%C8V5S<R!F;W(N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D<&5R;2`@("`@("`@5&AE(&QE=F5L(&]F('!E<FUI<W-I;VYS(')E
M<75I<F5D+@H@("`@("H@0'!A<F%M(&UI>&5D("`@)&%T=')I8G5T97,@(%)E
M<W1R:6-T('1H92!S:&%R97,@<F5T=7)N960@=&\@=&AO<V4@=VAO"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:&%V92!T:&5S92!A='1R
M:6)U=&4@=F%L=65S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H
M92!C<FET97)I82!T<F5E(&9O<B!F971C:&EN9R!T:&ES('5S97(G<R!S:&%R
M97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-H87)E0W)I=&5R:6$H)'5S
M97)I9"P@)'!E<FT@/2!015)-4U]32$]7+"`D871T<FEB=71E<R`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D=7-E<FED*2D@>PH@("`@("`@
M("`@("`D8W)I=&5R:6$@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=/4B<@
M/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@+R\@*&]W;F5R(#T]("1U
M<V5R:60I"B`@("`@("`@("`@("`@("`@("`@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@("`@("=!3D0G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)V9I96QD)R`]/B`G;F%M92<L("=O<"<@/3X@
M)STG+"`G=&5S="<@/3X@)V]W;F5R)RDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@G9FEE;&0G(#T^("=V86QU92<L("=O<"<@/3X@)STG
M+"`G=&5S="<@/3X@)'5S97)I9"DI*2P*"B`@("`@("`@("`@("`@("`@("`@
M+R\@*&YA;64@/3T@<&5R;5]U<V5R<R!A;F0@:V5Y(#T]("1U<V5R:60@86YD
M('9A;"`F("1P97)M*0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@("`@("`G04Y$)R`]/B!A<G)A>2@*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=F:65L9"<@/3X@)VYA;64G+"`G
M;W`G(#T^("<])RP@)W1E<W0G(#T^("=P97)M7W5S97)S)RDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9FEE;&0G(#T^("=K97DG+"`G
M;W`G(#T^("<])RP@)W1E<W0G(#T^("1U<V5R:60I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)V9I96QD)R`]/B`G=F%L=64G+"`G;W`G
M(#T^("<F)RP@)W1E<W0G(#T^("1P97)M*2DI+`H*("`@("`@("`@("`@("`@
M("`@("`O+R`H;F%M92`]/2!P97)M7V-R96%T;W(@86YD('9A;"`F("1P97)M
M*0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("`@("`G04Y$)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=F:65L9"<@/3X@)VYA;64G+"`G;W`G(#T^("<])RP@
M)W1E<W0G(#T^("=P97)M7V-R96%T;W(G*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*"=F:65L9"<@/3X@)W9A;'5E)RP@)V]P)R`]/B`G
M)B<L("=T97-T)R`]/B`D<&5R;2DI*2P*"B`@("`@("`@("`@("`@("`@("`@
M+R\@*&YA;64@/3T@<&5R;5]D969A=6QT(&%N9"!V86P@)B`D<&5R;2D*("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@
M("`@)T%.1"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@G9FEE;&0G(#T^("=N86UE)RP@)V]P)R`]/B`G/2<L("=T97-T
M)R`]/B`G<&5R;5]D969A=6QT)RDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@G9FEE;&0G(#T^("=V86QU92<L("=O<"<@/3X@)R8G+"`G
M=&5S="<@/3X@)'!E<FTI*2DI*3L*"B`@("`@("`@("`@("\O($EF('1H92!U
M<V5R(&AA<R!A;GD@9W)O=7`@;65M8F5R<VAI<',L(&-H96-K(&9O<B!T:&]S
M92!A;'-O+@H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T=R;W5P
M+G!H<"<["B`@("`@("`@("`@("1G<F]U<"`]("9'<F]U<#HZ<VEN9VQE=&]N
M*"D["B`@("`@("`@("`@("1G<F]U<',@/2`D9W)O=7`M/F=E=$=R;W5P365M
M8F5R<VAI<',H)'5S97)I9"P@=')U92D["B`@("`@("`@("`@(&EF("@A:7-?
M82@D9W)O=7!S+"`G4$5!4E]%<G)O<B<I("8F(&-O=6YT*"1G<F]U<',I*2![
M"B`@("`@("`@("`@("`@("`O+R`H;F%M92`]/2!P97)M7V=R;W5P<R!A;F0@
M:V5Y(&EN("@D9W)O=7!S*2!A;F0@=F%L("8@)'!E<FTI"B`@("`@("`@("`@
M("`@("`D8W)I=&5R:6%;)T]2)UU;72`](&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("=!3D0G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@G9FEE;&0G(#T^("=N86UE)RP@)V]P)R`]/B`G/2<L("=T97-T
M)R`]/B`G<&5R;5]G<F]U<',G*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)V9I96QD)R`]/B`G:V5Y)RP@)V]P)R`]/B`G24XG+"`G=&5S="<@
M/3X@87)R87E?:V5Y<R@D9W)O=7!S*2DL"B`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"=F:65L9"<@/3X@)W9A;'5E)RP@)V]P)R`]/B`G)B<L("=T
M97-T)R`]/B`D<&5R;2DI*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1C<FET97)I82`](&%R<F%Y*`H@("`@("`@("`@
M("`@("`@)T%.1"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=F:65L9"<@/3X@)VYA;64G+"`G;W`G(#T^("<])RP@)W1E<W0G(#T^
M("=P97)M7V=U97-T)RDL"B`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=F
M:65L9"<@/3X@)W9A;'5E)RP@)V]P)R`]/B`G)B<L("=T97-T)R`]/B`D<&5R
M;2DI*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]A<G)A>2@D871T<FEB
M=71E<RDI('L*("`@("`@("`@("`@+R\@0G5I;&0@871T<FEB=71E+VME>2!F
M:6QT97(N"B`@("`@("`@("`@(&9O<F5A8V@@*"1A='1R:6)U=&5S(&%S("1K
M97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("`D8W)I=&5R:6$@/2!A
M<G)A>2@*("`@("`@("`@("`@("`@("`@("`G04Y$)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@("`@("`@("`@("`@)&-R:71E<FEA+`H@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=*3TE.)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G04Y$)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)V9I96QD)R`]/B`G;F%M92<L("=O<"<@/3X@
M)STG+"`G=&5S="<@/3X@)&ME>2DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"=F:65L9"<@/3X@)W9A;'5E)RP@)V]P)R`]
M/B`G/2<L("=T97-T)R`]/B`D=F%L=64I*2DI*2D["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1A='1R:6)U=&5S*2D@>PH@("`@
M("`@("`@("`O+R!297-T<FEC="!T;R!S:&%R97,@;W=N960@8GD@=&AE('5S
M97(@<W!E8VEF:65D(&EN('1H90H@("`@("`@("`@("`O+R`D871T<FEB=71E
M<R!S=')I;F<N"B`@("`@("`@("`@("1C<FET97)I82`](&%R<F%Y*`H@("`@
M("`@("`@("`@("`@)T%.1"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@)&-R:71E<FEA+`H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@("`@("`G2D])3B<@/3X@87)R87DH"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9FEE;&0G(#T^("=N86UE)RP@
M)V]P)R`]/B`G/2<L("=T97-T)R`]/B`G;W=N97(G*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"=F:65L9"<@/3X@)W9A;'5E)RP@)V]P
M)R`]/B`G/2<L("=T97-T)R`]/B`D871T<FEB=71E<RDI*2DI.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1C<FET97)I83L*("`@('T*"B`@("`O*BH*
M("`@("`J(%1/1$\*("`@("`J"B`@("`@*B!`<V5E(%!E<FUS.CIG971097)M
M:7-S:6]N<PH@("`@("H*("`@("`J($!P87)A;2!43T1/"B`@("`@*B!`<&%R
M86T@5$]$3PH@("`@("H*("`@("`J($!R971U<FX@5$]$3PH@("`@("HO"B`@
M("!F=6YC=&EO;B!G971097)M:7-S:6]N<R@D<VAA<F4L("1U<V5R(#T@;G5L
M;"D*("`@('L*("`@("`@("!I9B`H(6ES7V$H)'-H87)E+"`G1&%T851R965/
M8FIE8W1?4VAA<F4G*2D@>PH@("`@("`@("`@("`D<VAA<F4@/2`F)'1H:7,M
M/F=E=%-H87)E*"1S:&%R92D["B`@("`@("`@?0H*("`@("`@("`D<&5R;2`]
M("8D<VAA<F4M/F=E=%!E<FUI<W-I;VXH*3L*("`@("`@("!R971U<FX@)$=,
M3T)!3%-;)W!E<FUS)UTM/F=E=%!E<FUI<W-I;VYS*"1P97)M+"`D=7-E<BD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!)9&5N=&ET>2!F
M;W(@82!P87)T:6-U;&%R('-H87)E(&]W;F5R+@H@("`@("H*("`@("`J($!P
M87)A;2!M:7AE9"`D<VAA<F4@(%1H92!S:&%R92!T;R!F971C:"!T:&4@261E
M;G1I='D@9F]R("T@96ET:&5R('1H90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@<W1R:6YG(&YA;64L(&]R('1H92!$871A5')E94]B:F5C=%]3:&%R
M92!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!P
M<F5F97)E;F-E)W,@=F%L=64N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971)
M9&5N=&ET>4)Y4VAA<F4H)'-H87)E*0H@("`@>PH@("`@("`@(&EF("@A:7-?
M82@D<VAA<F4L("=$871A5')E94]B:F5C=%]3:&%R92<I*2!["B`@("`@("`@
M("`@("1S:&%R92`]("1T:&ES+3YG9713:&%R92@D<VAA<F4I.PH@("`@("`@
M("`@("!I9B`H:7-?82@D<VAA<F4L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TED96YT:71Y+G!H<"<[
M"B`@("`@("`@)&]W;F5R(#T@)'-H87)E+3YG970H)V]W;F5R)RD["B`@("`@
M("`@<F5T=7)N("1R970@/2`F261E;G1I='DZ.G-I;F=L971O;B@G;F]N92<L
M("1O=VYE<BD["B`@("!]"@I]"@HO*BH*("H@17AT96YS:6]N(&]F('1H92!$
M871A5')E94]B:F5C="!C;&%S<R!F;W(@<W1O<FEN9R!3:&%R92!I;F9O<FUA
M=&EO;B!I;B!T:&4*("H@1&%T851R964@9')I=F5R+B!)9B!Y;W4@=V%N="!T
M;R!S=&]R92!S<&5C:6%L:7IE9"!3:&%R92!I;F9O<FUA=&EO;BP@>6]U"B`J
M('-H;W5L9"!E>'1E;F0@=&AI<R!C;&%S<R!I;G-T96%D(&]F(&5X=&5N9&EN
M9R!$871A5')E94]B:F5C="!D:7)E8W1L>2X*("H*("H@0&%U=&AO<B`@36EK
M92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E
M("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U-H87)E"B`J+PIC;&%S
M<R!$871A5')E94]B:F5C=%]3:&%R92!E>'1E;F1S($1A=&%4<F5E3V)J96-T
M('L*"B`@("`O*BH*("`@("`J(%1H92!(;W)D95]3:&%R92!O8FIE8W0@=VAI
M8V@@=&AI<R!S:&%R92!C86UE(&9R;VT@+2!N965D960@9F]R"B`@("`@*B!U
M<&1A=&EN9R!D871A(&EN('1H92!B86-K96YD('1O(&UA:V4@8VAA;F=E<R!S
M=&EC:RP@971C+@H@("`@("H*("`@("`J($!V87(@2&]R9&5?4VAA<F4*("`@
M("`J+PH@("`@=F%R("1?<VAA<F5/8CL*"B`@("`O*BH*("`@("`J(%1H92!$
M871A5')E94]B:F5C=%]3:&%R92!C;VYS=')U8W1O<BX@2G5S="!M86ME<R!S
M=7)E('1O(&-A;&P@=&AE('!A<F5N=`H@("`@("H@8V]N<W1R=6-T;W(@<V\@
M=&AA="!T:&4@<VAA<F4G<R!N86UE(&ES('-E="!P<F]P97)L>2X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE(&ED(&]F('1H92!S:&%R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@1&%T851R965/8FIE8W1?4VAA<F4H
M)&ED*0H@("`@>PH@("`@("`@('!A<F5N=#HZ1&%T851R965/8FIE8W0H)&ED
M*3L*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^9&%T82DI('L*("`@("`@
M("`@("`@)'1H:7,M/F1A=&$@/2!A<G)A>2@I.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($%S<V]C:6%T97,@82!3:&%R92!O8FIE8W0@=VET
M:"!T:&ES('-H87)E+@H@("`@("H*("`@("`J($!P87)A;2!(;W)D95]3:&%R
M92`D<VAA<F5/8B`@5&AE(%-H87)E(&]B:F5C="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T4VAA<F5/8B@F)'-H87)E3V(I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]S:&%R94]B(#T@)B1S:&%R94]B.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&ES('-H87)E)W,@<&%R96YT(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<F5T=7)N($1A=&%4<F5E3V)J96-T7U-H87)E("!4:&4@<&%R
M96YT('-H87)E+"!I9B!I="!E>&ES=',N"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9G971087)E;G0H*0H@("`@>PH@("`@("`@("1P87)E;G0@/2`D=&AI<RT^
M7W-H87)E3V(M/F=E=%!A<F5N="@D=&AI<RD["B`@("`@("`@<F5T=7)N("1P
M87)E;G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!':79E<R!A('5S97(@82!C
M97)T86EN('!R:79I;&5G92!F;W(@=&AI<R!S:&%R92X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1U<V5R:60@("`@("`@5&AE('5S97)I9"!O9B!T
M:&4@=7-E<BX*("`@("`J($!P87)A;2!I;G1E9V5R("1P97)M:7-S:6]N("!!
M(%!%4DU37RH@8V]N<W1A;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9%5S
M97)097)M:7-S:6]N*"1U<V5R:60L("1P97)M:7-S:6]N*0H@("`@>PH@("`@
M("`@("1P97)M(#T@)B1T:&ES+3YG971097)M:7-S:6]N*"D["B`@("`@("`@
M)'!E<FTM/F%D9%5S97)097)M:7-S:6]N*"1U<V5R:60L("1P97)M:7-S:6]N
M+"!F86QS92D["B`@("`@("`@)'1H:7,M/G-E=%!E<FUI<W-I;VXH)'!E<FTI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!A(&-E<G1A:6X@<')I
M=FEL96=E(&9O<B!A('5S97(@9G)O;2!T:&ES('-H87)E+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'5S97)I9"`@("`@("!4:&4@=7-E<FED(&]F
M('1H92!U<V5R+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'!E<FUI<W-I;VX@
M($$@4$5235-?*B!C;VYS=&%N="X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M
M;W9E57-E<E!E<FUI<W-I;VXH)'5S97)I9"P@)'!E<FUI<W-I;VXI"B`@("![
M"B`@("`@("`@)'!E<FT@/2`F)'1H:7,M/F=E=%!E<FUI<W-I;VXH*3L*("`@
M("`@("`D<&5R;2T^<F5M;W9E57-E<E!E<FUI<W-I;VXH)'5S97)I9"P@)'!E
M<FUI<W-I;VXL(&9A;'-E*3L*("`@("`@("`D=&AI<RT^<V5T4&5R;6ES<VEO
M;B@D<&5R;2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!':79E<R!A(&=R;W5P
M(&-E<G1A:6X@<')I=FEL96=E<R!F;W(@=&AI<R!S:&%R92X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1G<F]U<"`@("`@("`@5&AE(&=R;W5P('1O
M(&%D9"!P97)M:7-S:6]N<R!F;W(N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M<&5R;6ES<VEO;B`@02!015)-4U\J(&-O;G-T86YT+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!A9&1'<F]U<%!E<FUI<W-I;VXH)&=R;W5P+"`D<&5R;6ES<VEO
M;BD*("`@('L*("`@("`@("`D<&5R;2`]("8D=&AI<RT^9V5T4&5R;6ES<VEO
M;B@I.PH@("`@("`@("1P97)M+3YA9&1'<F]U<%!E<FUI<W-I;VXH)&=R;W5P
M+"`D<&5R;6ES<VEO;BP@9F%L<V4I.PH@("`@("`@("1T:&ES+3YS971097)M
M:7-S:6]N*"1P97)M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@
M82!C97)T86EN('!R:79I;&5G92!F<F]M(&$@9W)O=7`N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9W)O=7`@("`@("`@("!4:&4@9W)O=7`@=&\@
M<F5M;W9E('!E<FUI<W-I;VYS(&9R;VTN"B`@("`@*B!`<&%R86T@8V]N<W1A
M;G0@)'!E<FUI<W-I;VX@($$@4$5235-?*B!C;VYS=&%N="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F5M;W9E1W)O=7!097)M:7-S:6]N*"1G<F]U<"P@)'!E
M<FUI<W-I;VXI"B`@("!["B`@("`@("`@)'!E<FT@/2`F)'1H:7,M/F=E=%!E
M<FUI<W-I;VXH*3L*("`@("`@("`D<&5R;2T^<F5M;W9E1W)O=7!097)M:7-S
M:6]N*"1G<F]U<"P@)'!E<FUI<W-I;VXL(&9A;'-E*3L*("`@("`@("`D=&AI
M<RT^<V5T4&5R;6ES<VEO;B@D<&5R;2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#:&5C:W,@=&\@<V5E(&EF(&$@=7-E<B!H87,@82!G:79E;B!P97)M:7-S
M:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97)I9"`@("`@
M("!4:&4@=7-E<FED(&]F('1H92!U<V5R+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'!E<FUI<W-I;VX@($$@4$5235-?*B!C;VYS=&%N="!T;R!T97-T(&9O
M<BX*("`@("`J($!P87)A;2!S=')I;F<@)&-R96%T;W(@("`@("!4:&4@8W)E
M871O<B!O9B!T:&4@979E;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N("!7:&5T:&5R(&]R(&YO="`D=7-E<FED(&AA<R`D<&5R;6ES<VEO;BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@:&%S4&5R;6ES<VEO;B@D=7-E<FED+"`D
M<&5R;6ES<VEO;BP@)&-R96%T;W(@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF
M("@D=7-E<FED(#T]("1T:&ES+3YG970H)V]W;F5R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)$=,
M3T)!3%-;)W!E<FUS)UTM/FAA<U!E<FUI<W-I;VXH)'1H:7,M/F=E=%!E<FUI
M<W-I;VXH*2P@)'5S97)I9"P@)'!E<FUI<W-I;VXL("1C<F5A=&]R*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@82!U<V5R(&9R;VT@=&AI<R!S
M:&%R92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R:60@(%1H
M92!U<V5R:60@;V8@=&AE('5S97(@=&\@<F5M;W9E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!R96UO=F55<V5R*"1U<V5R:60I"B`@("!["B`@("`@("`@+RH@
M4F5M;W9E(&%L;"`D=7-E<FED)W,@<&5R;6ES<VEO;G,N("HO"B`@("`@("`@
M)'!E<FT@/2`F)'1H:7,M/F=E=%!E<FUI<W-I;VXH*3L*("`@("`@("`D<&5R
M;2T^<F5M;W9E57-E<E!E<FUI<W-I;VXH)'5S97)I9"P@4$5235-?4TA/5RP@
M9F%L<V4I.PH@("`@("`@("1P97)M+3YR96UO=F55<V5R4&5R;6ES<VEO;B@D
M=7-E<FED+"!015)-4U]214%$+"!F86QS92D["B`@("`@("`@)'!E<FTM/G)E
M;6]V955S97)097)M:7-S:6]N*"1U<V5R:60L(%!%4DU37T5$250L(&9A;'-E
M*3L*("`@("`@("`D<&5R;2T^<F5M;W9E57-E<E!E<FUI<W-I;VXH)'5S97)I
M9"P@4$5235-?1$5,151%+"!F86QS92D["B`@("`@("`@<F5T=7)N("1T:&ES
M+3YS971097)M:7-S:6]N*"1P97)M*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E;6]V97,@82!G<F]U<"!F<F]M('1H:7,@<VAA<F4N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&=R;W5P260@(%1H92!G<F]U<"!T;R!R96UO
M=F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V94=R;W5P*"1G<F]U<$ED
M*0H@("`@>PH@("`@("`@("\J(%)E;6]V92!A;&P@)&=R;W5P260G<R!P97)M
M:7-S:6]N<RX@*B\*("`@("`@("`D<&5R;2`]("8D=&AI<RT^9V5T4&5R;6ES
M<VEO;B@I.PH@("`@("`@("1P97)M+3YR96UO=F5'<F]U<%!E<FUI<W-I;VXH
M)&=R;W5P260L(%!%4DU37U-(3U<L(&9A;'-E*3L*("`@("`@("`D<&5R;2T^
M<F5M;W9E1W)O=7!097)M:7-S:6]N*"1G<F]U<$ED+"!015)-4U]214%$+"!F
M86QS92D["B`@("`@("`@)'!E<FTM/G)E;6]V94=R;W5P4&5R;6ES<VEO;B@D
M9W)O=7!)9"P@4$5235-?141)5"P@9F%L<V4I.PH@("`@("`@("1P97)M+3YR
M96UO=F5'<F]U<%!E<FUI<W-I;VXH)&=R;W5P260L(%!%4DU37T1%3$5412P@
M9F%L<V4I.PH@("`@("`@(')E='5R;B`D=&AI<RT^<V5T4&5R;6ES<VEO;B@D
M<&5R;2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%R<F%Y
M(&-O;G1A:6YI;F<@86QL('1H92!U<V5R:61S(&]F('1H92!U<V5R<R!W:71H
M(&%C8V5S<R!T;PH@("`@("H@=&AI<R!S:&%R92X*("`@("`J"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D<&5R;5]L979E;"`@3&ES="!O;FQY('5S97)S('=I
M=&@@=&AI<R!P97)M:7-S:6]N(&QE=F5L+@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@($1E9F%U;'1S('1O(&%L;"!U<V5R<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@=7-E<G,@=VET:"!A8V-E<W,@
M=&\@=&AI<R!S:&%R92X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=%5S97)S
M*"1P97)M7VQE=F5L(#T@;G5L;"D*("`@('L*("`@("`@("`D<&5R;2`]("8D
M=&AI<RT^9V5T4&5R;6ES<VEO;B@I.PH@("`@("`@(')E='5R;B!A<G)A>5]K
M97ES*"1P97)M+3YG9715<V5R4&5R;6ES<VEO;G,H)'!E<FU?;&5V96PI*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@87)R87D@8V]N=&%I
M;FEN9R!A;&P@=&AE(&=R;W5P:61S(&]F('1H92!G<F]U<',@=VET:"!A8V-E
M<W,*("`@("`J('1O('1H:7,@<VAA<F4N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'!E<FU?;&5V96P@($QI<W0@;VYL>2!U<V5R<R!W:71H('1H
M:7,@<&5R;6ES<VEO;B!L979E;"X*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!$969A=6QT<R!T;R!A;&P@=7-E<G,N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@5&AE($E$<R!O9B!T:&4@9W)O=7!S('=I=&@@
M86-C97-S('1O('1H:7,@<VAA<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI
M<W1'<F]U<',H)'!E<FU?;&5V96P@/2!N=6QL*0H@("`@>PH@("`@("`@("1P
M97)M(#T@)B1T:&ES+3YG971097)M:7-S:6]N*"D["B`@("`@("`@<F5T=7)N
M(&%R<F%Y7VME>7,H)'!E<FTM/F=E=$=R;W5P4&5R;6ES<VEO;G,H)'!E<FU?
M;&5V96PI*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1/1$\*("`@("`J"B`@
M("`@*B!`<&%R86T@5$]$3PH@("`@("H@0'!A<F%M(&)O;VQE86X@)'5P9&%T
M92`@5$]$3PH@("`@("H*("`@("`J($!R971U<FX@5$]$3PH@("`@("HO"B`@
M("!F=6YC=&EO;B!S971097)M:7-S:6]N*"8D<&5R;2P@)'5P9&%T92`]('1R
M=64I"B`@("!["B`@("`@("`@)'1H:7,M/F1A=&%;)W!E<FTG72`]("1P97)M
M+3YG971$871A*"D["B`@("`@("`@:68@*"1U<&1A=&4I('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YS879E*"D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@5$]$3PH@("`@("H*
M("`@("`J($!R971U<FX@5$]$3PH@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T
M4&5R;6ES<VEO;B@I"B`@("!["B`@("`@("`@)'!E<FT@/2`F;F5W($1A=&%4
M<F5E3V)J96-T7U!E<FUI<W-I;VXH)'1H:7,M/F=E=$YA;64H*2D["B`@("`@
M("`@)'!E<FTM/F1A=&$@/2!I<W-E="@D=&AI<RT^9&%T85LG<&5R;2==*2`_
M("1T:&ES+3YD871A6R=P97)M)UT@.B!A<G)A>2@I.PH*("`@("`@("!R971U
M<FX@)'!E<FT["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&;W)C97,@86QL(&-H
M:6QD<F5N(&]F('1H:7,@<VAA<F4@=&\@:6YH97)I="!T:&4@<&5R;6ES<VEO
M;G,@<V5T(&]N('1H:7,*("`@("`J('-H87)E+@H@("`@("H*("`@("`J($!R
M971U<FX@5$]$3PH@("`@("HO"B`@("!F=6YC=&EO;B!I;FAE<FET4&5R;6ES
M<VEO;G,H*0H@("`@>PH@("`@("`@("1P97)M(#T@)B1T:&ES+3YG971097)M
M:7-S:6]N*"D["B`@("`@("`@)&-H:6QD<F5N(#T@)'1H:7,M/E]S:&%R94]B
M+3YL:7-T06QL4VAA<F5S*"1T:&ES+3YG971.86UE*"DI.PH@("`@("`@(&EF
M("AI<U]A*"1C:&EL9')E;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&-H:6QD<F5N.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C
M:"`H)&-H:6QD<F5N(&%S("1C:&EL9"D@>PH@("`@("`@("`@("`D8VAI;&0M
M/G-E=%!E<FUI<W-I;VXH)'!E<FTI.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3879E<R!A;GD@8VAA
M;F=E<R!T;R!T:&ES(&]B:F5C="!T;R!T:&4@8F%C:V5N9"!P97)M86YE;G1L
M>2X@3F5W(&]B:F5C=',*("`@("`J(&%R92!A9&1E9"!I;G-T96%D+@H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B!\(%!%05)?17)R;W(@(%!%05)?
M17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V%V92@I
M"B`@("!["B`@("`@("`@)')E<W5L="`]($AO<F1E.CIC86QL2&]O:R@G7VAO
M<F1E7VAO;VM?<VAA<F5?;6]D:69Y)RP@87)R87DH)'1H:7,I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAO<F1E)RP@9F%L<V4I.PH@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@<&%R96YT.CIS879E*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!-
M87!S('1H:7,@;V)J96-T)W,@871T<FEB=71E<R!F<F]M('1H92!D871A(&%R
M<F%Y(&EN=&\@82!F;W)M870@=&AA="!W90H@("`@("H@8V%N('-T;W)E(&EN
M('1H92!A='1R:6)U=&5S('-T;W)A9V4@8F%C:V5N9"X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R;W1E8W1E9`H@("`@("H*("`@("`J($!P87)A;2!B;V]L
M96%N("1P97)M<V]N;'D@($]N;'D@<')O8V5S<R!P97)M:7-S:6]N<S\@3&5T
M<R!S=6)C;&%S<V5S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!O=F5R<FED92!P87)T(&]F('1H:7,@;65T:&]D('=H:6QE(&AA;F1L:6YG
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&5I<B!A9&1I
M=&EO;F%L(&%T=')I8G5T97,@<V5P97)A=&5L>2X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!4:&4@871T<FEB=71E<R!A<G)A>2X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7W1O071T<FEB=71E<R@D<&5R;7-O;FQY(#T@9F%L<V4I
M"B`@("!["B`@("`@("`@+R\@1&5F875L="!T;R!N;R!A='1R:6)U=&5S+@H@
M("`@("`@("1A='1R:6)U=&5S(#T@87)R87DH*3L*"B`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/F1A=&$@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@
M("`@:68@*"1K97D@/3T@)W!E<FTG*2!["B`@("`@("`@("`@("`@("!F;W)E
M86-H("@D=F%L=64@87,@)'1Y<&4@/3X@)'!E<FUS*2!["B`@("`@("`@("`@
M("`@("`@("`@:68@*&ES7V%R<F%Y*"1P97)M<RDI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)'!E<FUS(&%S("1M96UB97(@/3X@)'!E
M<FTI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A='1R:6)U=&5S
M6UT@/2!A<G)A>2@G;F%M92<@/3X@)W!E<FU?)R`N("1T>7!E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=K
M97DG(#T^("1M96UB97(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W9A;'5E)R`]/B`D<&5R;2D["B`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D871T<FEB=71E<UM=(#T@
M87)R87DH)VYA;64G(#T^("=P97)M7R<@+B`D='EP92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=K97DG(#T^("<G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W9A;'5E)R`]/B`D<&5R;7,I.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E:68@*"$D<&5R
M;7-O;FQY*2!["B`@("`@("`@("`@("`@("`D871T<FEB=71E<UM=(#T@87)R
M87DH)VYA;64G(#T^("1K97DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VME>2<@/3X@)R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W9A;'5E)R`]/B`D=F%L=64I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&%T=')I8G5T97,[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!486ME<R!I;B!A(&QI<W0@;V8@871T
M<FEB=71E<R!F<F]M('1H92!B86-K96YD(&%N9"!M87!S(&ET('1O(&]U<@H@
M("`@("H@:6YT97)N86P@9&%T82!A<G)A>2X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R;W1E8W1E9`H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D871T
M<FEB=71E<R`@(%1H92!L:7-T(&]F(&%T=')I8G5T97,@9G)O;2!T:&4@8F%C
M:V5N9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@*&%T=')I
M8G5T92!N86UE+"!K97DL(&%N9"!V86QU92DN"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D<&5R;7-O;FQY("!/;FQY('!R;V-E<W,@<&5R;6ES<VEO;G,_($QE
M=',@<W5B8VQA<W-E<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@;W9E<G)I9&4@<&%R="!O9B!T:&ES(&UE=&AO9"!W:&EL92!H86YD;&EN
M9PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE:7(@861D
M:71I;VYA;"!A='1R:6)U=&5S('-E<&5R871E;'DN"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]F<F]M071T<FEB=71E<R@D871T<FEB=71E<RP@)'!E<FUS;VYL
M>2`](&9A;'-E*0H@("`@>PH@("`@("`@("\O($EN:71I86QI>F4@9&%T82!A
M<G)A>2X*("`@("`@("`D=&AI<RT^9&%T85LG<&5R;2==(#T@87)R87DH*3L*
M"B`@("`@("`@9F]R96%C:"`H)&%T=')I8G5T97,@87,@)&%T='(I('L*("`@
M("`@("`@("`@:68@*'-U8G-T<B@D871T<ELG;F%M92==+"`P+"`T*2`]/2`G
M<&5R;2<I('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&%T=');)VME
M>2==*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YD871A6R=P97)M
M)UU;<W5B<W1R*"1A='1R6R=N86UE)UTL(#4I75LD871T<ELG:V5Y)UU=(#T@
M)&%T=');)W9A;'5E)UT["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YD871A6R=P97)M)UU;<W5B<W1R*"1A
M='1R6R=N86UE)UTL(#4I72`]("1A='1R6R=V86QU92==.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!](&5L<V5I9B`H(21P97)M<V]N;'DI('L*
M("`@("`@("`@("`@("`@("1T:&ES+3YD871A6R1A='1R6R=N86UE)UU=(#T@
M)&%T=');)W9A;'5E)UT["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]344PO````````
M````````````````````````````````````````````````````````````
M````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`U,34T,S,W-3``,#(P,3(Q`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+U-13"]!='1R:6)U=&5S+G!H<```````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`S,#,R-0`Q,#4Q-30S,S<U,``P,C(W-C,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M(%1H:7,@8VQA<W,@<')O=FED97,@871T<FEB=71E<R!M971H;V1S(&9O<B!A
M;GD@97AI<W1I;F<@4U%,(&-L87-S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]344PO4U%,+T%T=')I8G5T97,N<&AP+'8@,2XQ-"XQ,"XY(#(P,#8O,#$O
M,#$@,C$Z,C@Z,S,@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P
M,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#(N,@H@*B!`<&%C:V%G92!(
M;W)D95]344P*("HO"F-L87-S($AO<F1E7U-13%]!='1R:6)U=&5S('L*"B`@
M("`O*BH*("`@("`J(%1H92!014%2.CI$0B!O8FIE8W0@=&\@<G5N('%U97)I
M97,@=VET:"X*("`@("`J"B`@("`@*B!`=F%R($1""B`@("`@*B\*("`@('9A
M<B`D7V1B.PH*("`@("\J*@H@("`@("H@4&%R86UE=&5R<R!T;R!U<V4@=VAE
M;B!G96YE<F%T:6YG('%U97)I97,Z"B`@("`@*B`@(&ED7V-O;'5M;B`@("`@
M("`M(%1H92!P<FEM87)Y(&ED(&-O;'5M;B!T;R!U<V4@:6X@:F]I;G,N"B`@
M("`@*B`@('!R:6UA<GE?=&%B;&4@("`M(%1H92!M86EN('1A8FQE(&YA;64N
M"B`@("`@*B`@(&%T=')I8G5T95]T86)L92`M(%1H92!T86)L92!T:&%T('1H
M92!A='1R:6)U=&5S(&%R92!S=&]R960@:6XN"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@5&AE(&YU;6)E<B!O9B!C;W!I97,@;V8@=&AE(&%T
M=')I8G5T97,@=&%B;&4@=&AA="!W92!N965D('1O(&IO:6X@;VX@:6X*("`@
M("`J('1H92!C=7)R96YT('%U97)Y+@H@("`@("H*("`@("`J($!V87(@:6YT
M96=E<@H@("`@("HO"B`@("!V87(@)%]T86)L95]C;W5N="`](#$["@H@("`@
M+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M1$(@)&1B:"`@("`@("`@02!014%2.CI$0B!O8FIE8W0N"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@5&AE(&ED(&-O;'5M;BP@=&%B;&4@;F%M97,L
M(&5T8RX*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?4U%,7T%T=')I8G5T
M97,H)&1B:"P@)'!A<F%M<RD*("`@('L*("`@("`@("`D=&AI<RT^7V1B(#T@
M)&1B:#L*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%L;"!A='1R:6)U=&5S(&9O<B!A
M(&=I=F5N(&ED(&]R(&UU;'1I<&QE(&ED<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B!\(&%R<F%Y("1I9"`@5&AE(&ED('1O(&9E=&-H(&]R(&%N
M(&%R<F%Y(&]F(&ED<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!
M(&AA<V@@;V8@871T<FEB=71E<RP@;W(@82!M=6QT:2UL979E;"!H87-H"B`@
M("`@*B`@("`@("`@("`@("`@("!O9B!I9',@/3X@=&AE:7(@871T<FEB=71E
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T071T<FEB=71E<R@D:60I"B`@
M("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1I9"DI('L*("`@("`@("`@("`@
M)'%U97)Y(#T@<W!R:6YT9B@G4T5,14-4("4Q)',L(&%T=')I8G5T95]N86UE
M(&%S(&YA;64L(&%T=')I8G5T95]K97D@87,@(FME>2(L(&%T=')I8G5T95]V
M86QU92!A<R!V86QU92!&4D]-("4R)',@5TA%4D4@)3$D<R!)3B`H)3,D<RDG
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=I9%]C;VQU;6XG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG871T<FEB=71E7W1A8FQE)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:6UP;&]D92@G+"`G+"`D:60I*3L*"B`@("`@
M("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@2&]R9&5?
M4U%,7T%T=')I8G5T97,Z.F=E=$%T=')I8G5T97,H*3H@)R`N("1Q=65R>2P@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@
M("`@("1R;W=S(#T@)'1H:7,M/E]D8BT^9V5T06QL*"1Q=65R>2P@1$)?1D54
M0TA-3T1%7T%34T]#*3L*("`@("`@("`@("`@:68@*&ES7V$H)')O=W,L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F]W<SL*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&ED7V-O;'5M;B`]("1T:&ES
M+3Y?<&%R86US6R=I9%]C;VQU;6XG73L*("`@("`@("`@("`@)&1A=&$@/2!A
M<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D<F]W<R!A<R`D<F]W*2![
M"B`@("`@("`@("`@("`@("!I9B`H96UP='DH)&1A=&%;)')O=ULD:61?8V]L
M=6UN75TI*2!["B`@("`@("`@("`@("`@("`@("`@)&1A=&%;)')O=ULD:61?
M8V]L=6UN75T@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@)&1A=&%;)')O=ULD:61?8V]L=6UN75U;72`](&%R<F%Y*"=N
M86UE)R`@/3X@)')O=ULG;F%M92==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=K97DG("`@/3X@)')O=ULG:V5Y
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W9A;'5E)R`]/B`D<F]W6R=V86QU92==*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!R971U<FX@)&1A=&$["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G4T5,14-4("4Q)',L(&%T
M=')I8G5T95]N86UE(&%S(&YA;64L(&%T=')I8G5T95]K97D@87,@(FME>2(L
M(&%T=')I8G5T95]V86QU92!A<R!V86QU92!&4D]-("4R)',@5TA%4D4@)3$D
M<R`]("4S)',G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=I9%]C;VQU;6XG72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG871T<FEB=71E7W1A8FQE)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*&EN="DD:60I.PH@("`@("`@
M("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($AO<F1E7U-1
M3%]!='1R:6)U=&5S.CIG971!='1R:6)U=&5S*"DZ("<@+B`D<75E<GDL(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]D8BT^9V5T06QL*"1Q=65R>2P@1$)?1D540TA-
M3T1%7T%34T]#*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FX@82!S970@;V8@:61S(&)A<V5D(&]N(&$@<V5T(&]F(&%T=')I8G5T
M92!C<FET97)I82X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&-R:71E
M<FEA("!4:&4@87)R87D@;V8@8W)I=&5R:6$N($5X86UP;&4Z"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`D8W)I=&5R:6%;)T]2)UT@/2!A<G)A
M>2@*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@G9FEE;&0G(#T^("=N86UE)RP*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;W`G("`@(#T^("<]
M)RP*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G=&5S="<@(#T^("=F;V\G*2P*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9FEE;&0G(#T^("=N
M86UE)RP*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G;W`G("`@(#T^("<])RP*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&5S="<@(#T^("=B
M87(G*2D["B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@5&AI<R!W
M;W5L9"!R971U<FX@86QL(&ED<R!F;W(@=VAI8V@@=&AE(&9I96QD"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@871T<FEB=71E7VYA;64@:7,@
M96ET:&5R("=F;V\G(&]R("=B87(G+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971">4%T=')I8G5T97,H)&-R:71E<FEA*0H@("`@>PH@("`@("`@(&EF("@A
M8V]U;G0H)&-R:71E<FEA*2D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH
M*3L*("`@("`@("!]"@H@("`@("`@("\J($)U:6QD('1H92!Q=65R>2X@*B\*
M("`@("`@("`D=&AI<RT^7W1A8FQE7V-O=6YT(#T@,3L*("`@("`@("`D<75E
M<GD@/2`G)SL*("`@("`@("!F;W)E86-H("@D8W)I=&5R:6$@87,@)&ME>2`]
M/B`D=F%L<RD@>PH@("`@("`@("`@("!I9B`H)&ME>2`]/2`G3U(G('Q\("1K
M97D@/3T@)T%.1"<I('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'%U
M97)Y*2D@>PH@("`@("`@("`@("`@("`@("`@("1Q=65R>2`N/2`G("<@+B`D
M:V5Y("X@)R`G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)'%U97)Y("X]("<H)R`N("1T:&ES+3Y?8G5I;&1!='1R:6)U=&51=65R>2@D
M:V5Y+"`D=F%L<RD@+B`G*2<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("\J($)U:6QD('1H92!&4D]-+TI/24X@8VQA=7-E<RX@*B\*("`@
M("`@("`D:F]I;G,@/2!A<G)A>2@I.PH@("`@("`@("1P86ER<R`](&%R<F%Y
M*"D["B`@("`@("`@9F]R("@D:2`](#$[("1I(#P]("1T:&ES+3Y?=&%B;&5?
M8V]U;G0[("1I*RLI('L*("`@("`@("`@("`@)&IO:6YS6UT@/2!S<')I;G1F
M*"=,1494($I/24X@)3$D<R!A)3(D<R!/3B!A)3(D<RXE,R1S(#T@;2XE,R1S
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=A='1R:6)U=&5?=&%B;&4G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)VED7V-O;'5M;B==*3L*"B`@("`@("`@("`@("1P
M86ER<UM=(#T@)T%.1"!A,2YA='1R:6)U=&5?;F%M92`](&$G("X@)&D@+B`G
M+F%T=')I8G5T95]N86UE)SL*("`@("`@("!]"B`@("`@("`@)&IO:6YS(#T@
M:6UP;&]D92@G("<L("1J;VEN<RD["B`@("`@("`@)'!A:7)S(#T@:6UP;&]D
M92@G("<L("1P86ER<RD["@H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)U-%
M3$5#5"!$25-424Y#5"!A,2XE<R!&4D]-("5S(&T@)7,@5TA%4D4@)7,@)7,G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VED
M7V-O;'5M;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W!R:6UA<GE?=&%B;&4G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("1J;VEN<RP*("`@("`@("`@("`@("`@("`@("`@("`@("1Q=65R>2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("1P86ER<RD["@H@("`@("`@($AO
M<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@2&]R9&5?4U%,7T%T=')I
M8G5T97,Z.F=E=$)Y071T<FEB=71E<R@I.B`G("X@)'%U97)Y+"!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?9&(M/F=E=$-O;"@D<75E<GDI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1VEV96X@82!N97<@871T<FEB=71E('-E="!A;F0@86X@:60L(&EN
M<V5R="!E86-H(&EN=&\@=&AE($1"+B!)9@H@("`@("H@86YY=&AI;F<@9F%I
M;',@:6X@:&5R92P@<F]L;&)A8VL@=&AE('1R86YS86-T:6]N+"!R971U<FX@
M=&AE(')E;&5V86YT"B`@("`@*B!E<G)O<B!A;F0@8F%I;"!O=70N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&ED("`@("`@("!4:&4@:60@;V8@
M=&AE(')E8V]R9"!F;W(@=VAI8V@@871T<FEB=71E<R!A<F4*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8F5I;F<@:6YS97)T960N"B`@("`@
M*B!`<&%R86T@87)R87D@)&%T=')I8G5T97,@($%N(&AA<V@@8V]N=&%I;FEN
M9R!T:&4@871T<FEB=71E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@:6YS97)T
M071T<FEB=71E<R@D:60L("1A='1R:6)U=&5S*0H@("`@>PH@("`@("`@(&9O
M<F5A8V@@*"1A='1R:6)U=&5S(&%S("1A='1R*2!["B`@("`@("`@("`@("1Q
M=65R>2`]("=)3E-%4E0@24Y43R`G("X@)'1H:7,M/E]P87)A;7-;)V%T=')I
M8G5T95]T86)L92==("X*("`@("`@("`@("`@("`@("`@("`@)R`H)R`N("1T
M:&ES+3Y?<&%R86US6R=I9%]C;VQU;6XG72`N("<L(&%T=')I8G5T95]N86UE
M+"<@+@H@("`@("`@("`@("`@("`@("`@("`G(&%T=')I8G5T95]K97DL(&%T
M=')I8G5T95]V86QU92D@5D%,5453("@_+"`_+"`_+"`_*2<["B`@("`@("`@
M("`@("1V86QU97,@/2!A<G)A>2@H:6YT*21I9"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1A='1R6R=N86UE)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D871T<ELG:V5Y)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D871T<ELG=F%L=64G72D["@H@("`@("`@("`@("!(;W)D93HZ
M;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($AO<F1E7U-13%]!='1R:6)U=&5S
M.CII;G-E<G1!='1R:6)U=&5S*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9&(M/G)O;&QB86-K*"D["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V1B+3YA=71O0V]M;6ET*'1R=64I.PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("\J($-O;6UI="!T:&4@=')A;G-A8W1I;VXL(&%N9"!T
M=7)N(&%U=&]C;VUM:70@8F%C:R!O;BX@*B\*("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/E]D8BT^8V]M;6ET*"D["B`@("`@("`@)'1H:7,M/E]D8BT^875T
M;T-O;6UI="AT<G5E*3L*("`@('T*"B`@("`O*BH*("`@("`J($=I=F5N(&%N
M(&ED+"!D96QE=&4@86QL(&%T=')I8G5T97,@9F]R('1H870@:60@9G)O;2!T
M:&4*("`@("`J(&%T=')I8G5T97,@=&%B;&4N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&ED("!4:&4@:60@;V8@=&AE(')E8V]R9"!F;W(@=VAI
M8V@@871T<FEB=71E<R!A<F4@8F5I;F<*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@9&5L971E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E071T
M<FEB=71E<R@D:60I"B`@("!["B`@("`@("`@+RH@1&5L971E(&%T=')I8G5T
M97,N("HO"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G1$5,151%($923TT@
M)7,@5TA%4D4@)7,@/2`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG871T<FEB=71E7W1A8FQE)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG:61?8V]L=6UN)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`H:6YT*21I9"D["@H@("`@("`@($AO
M<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@2&]R9&5?4U%,7T%T=')I
M8G5T97,Z.F1E;&5T94%T=')I8G5T97,H*3H@)R`N("1Q=65R>2P@7U]&24Q%
M7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1VEV96X@86X@:60L('5P9&%T92!A;&P@
M871T<FEB=71E<R!F;W(@=&AA="!I9"!I;B!T:&4@871T<FEB=71E<R!T86)L
M90H@("`@("H@=VET:"!T:&4@;F5W(&%T=')I8G5T97,N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&ED("`@("`@("!4:&4@:60@;V8@=&AE(')E
M8V]R9"!F;W(@=VAI8V@@871T<FEB=71E<R!A<F4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8F5I;F<@9&5L971E9"X*("`@("`J($!P87)A
M;2!A<G)A>2`D871T<FEB=71E<R`@06X@:&%S:"!C;VYT86EN:6YG('1H92!A
M='1R:6)U=&5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!U<&1A=&5!='1R:6)U
M=&5S*"1I9"P@)&%T=')I8G5T97,I"B`@("!["B`@("`@("`@+RH@1&5L971E
M('1H92!O;&0@871T<FEB=71E<RX@*B\*("`@("`@("`D<F5S=6QT(#T@)'1H
M:7,M/F1E;&5T94%T=')I8G5T97,H)&ED*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@+RH@26YS97)T('1H92!N97<@
M871T<FEB=71E('-E="X@*B\*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/FEN
M<V5R=$%T=')I8G5T97,H)&ED+"`D871T<FEB=71E<RD["B`@("`@("`@<F5T
M=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9"!A('!I
M96-E(&]F(&%N(&%T=')I8G5T92!Q=65R>2X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1G;'5E("`@("!4:&4@9VQU92!T;R!J;VEN('1H92!C<FET
M97)I82`H3U(O04Y$*2X*("`@("`J($!P87)A;2!A<G)A>2`D8W)I=&5R:6$@
M(%1H92!A<G)A>2!O9B!C<FET97)I82X*("`@("`J($!P87)A;2!B;V]L96%N
M("1J;VEN("`@(%-H;W5L9"!W92!J;VEN(&]N(&$@8VQE86X@871T<FEB=71E
M<R!T86)L93\*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@06X@4U%,
M(&9R86=M96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8G5I;&1!='1R:6)U
M=&51=65R>2@D9VQU92P@)&-R:71E<FEA+"`D:F]I;B`](&9A;'-E*0H@("`@
M>PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O4U%,+G!H<"<["@H@("`@
M("`@("\J($EN:71I86QI>F4@=&AE(&-L875S92!T:&%T('=E)W)E(&)U:6QD
M:6YG+B`J+PH@("`@("`@("1C;&%U<V4@/2`G)SL*"B`@("`@("`@+RH@1V5T
M('1H92!T86)L92!A;&EA<R!T;R!U<V4@9F]R('1H:7,@<V5T(&]F(&-R:71E
M<FEA+B`J+PH@("`@("`@(&EF("@D:F]I;BD@>PH@("`@("`@("`@("`D86QI
M87,@/2`D=&AI<RT^7V=E=$%L:6%S*'1R=64I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1A;&EA<R`]("1T:&ES+3Y?9V5T06QI87,H*3L*("`@
M("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1C<FET97)I82!A<R`D:V5Y(#T^
M("1V86QS*2!["B`@("`@("`@("`@(&EF("@A96UP='DH)'9A;'-;)T]2)UTI
M('Q\("%E;7!T>2@D=F%L<ULG04Y$)UTI*2!["B`@("`@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1C;&%U<V4I*2!["B`@("`@("`@("`@("`@("`@("`@)&-L
M875S92`N/2`G("<@+B`D9VQU92`N("<@)SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1C;&%U<V4@+CT@)R@G("X@)'1H:7,M/E]B=6EL
M9$%T=')I8G5T95%U97)Y*"1G;'5E+"`D=F%L<RD@+B`G*2<["B`@("`@("`@
M("`@('T@96QS96EF("@A96UP='DH)'9A;'-;)TI/24XG72DI('L*("`@("`@
M("`@("`@("`@(&EF("@A96UP='DH)&-L875S92DI('L*("`@("`@("`@("`@
M("`@("`@("`D8VQA=7-E("X]("<@)R`N("1G;'5E("X@)R`G.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&-L875S92`N/2`D=&AI<RT^
M7V)U:6QD071T<FEB=71E475E<GDH)&=L=64L("1V86QS6R=*3TE.)UTL('1R
M=64I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1V86QS6R=F:65L9"==*2D@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("@A96UP='DH)&-L875S92DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&-L875S92`N/2`G("<@+B`D9VQU92`N("<@)SL*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&-L875S92`N/2!(;W)D
M95]344PZ.F)U:6QD0VQA=7-E*"1T:&ES+3Y?9&(L("1A;&EA<R`N("<N871T
M<FEB=71E7R<@+B`D=F%L<ULG9FEE;&0G72P@)'9A;'-;)V]P)UTL("1V86QS
M6R=T97-T)UTI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D=F%L<R!A<R`D=&5S="D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1C;&%U<V4I*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D8VQA=7-E("X]("<@)R`N("1K97D@
M+B`G("<["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`@("`@)&-L875S92`N/2!(;W)D95]344PZ.F)U:6QD0VQA=7-E
M*"1T:&ES+3Y?9&(L("1A;&EA<R`N("<N871T<FEB=71E7R<@+B`D=&5S=%LG
M9FEE;&0G72P@)'1E<W1;)V]P)UTL("1T97-T6R=T97-T)UTI.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C;&%U<V4["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!'970@86X@86QI87,@=&\@86X@871T<FEB=71E<R!T
M86)L92P@:6YC<F5M96YT:6YG(&ET(&EF"B`@("`@*B!N96-E<W-A<GDN"B`@
M("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&EN8W)E;65N="`@26YC<F5M
M96YT('1H92!A;&EA<R!C;W5N=#\@1&5F875L=',@=&\@9F%L<V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]G971!;&EA<R@D:6YC<F5M96YT(#T@9F%L<V4I
M"B`@("!["B`@("`@("`@<W1A=&EC("1S965N("`](&%R<F%Y*"D["@H@("`@
M("`@(&EF("@D:6YC<F5M96YT("8F("%E;7!T>2@D<V5E;ELD=&AI<RT^7W1A
M8FQE7V-O=6YT72DI('L*("`@("`@("`@("`@)'1H:7,M/E]T86)L95]C;W5N
M="LK.PH@("`@("`@('T*"B`@("`@("`@)'-E96Y;)'1H:7,M/E]T86)L95]C
M;W5N=%T@/2!T<G5E.PH@("`@("`@(')E='5R;B`G82<@+B`D=&AI<RT^7W1A
M8FQE7V-O=6YT.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@
M<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@4U%,($%T=')I8G5T
M97,*("`@("`J(&EN<W1A;F-E(&)A<V5D(&]N('!A<F%M971E<G,@<&%S<V5D
M+B!)="!W:6QL(&]N;'D@8W)E871E(&$@;F5W"B`@("`@*B!I;G-T86YC92!I
M9B!N;R!!='1R:6)U=&5S(&EN<W1A;F-E('=I=&@@=&AE('-A;64@<&%R86UE
M=&5R<PH@("`@("H@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4
M:&ES('-H;W5L9"!B92!U<V5D(&EF(&UU;'1I<&QE(%-13"!A='1R:6)U=&4@
M=&%B;&5S(&%R90H@("`@("H@<F5Q=6ER960N"B`@("`@*@H@("`@("H@5&AI
M<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R(#T*("`@("`J("9(
M;W)D95]344Q?071T<FEB=71E<SHZ<VEN9VQE=&]N*"D*("`@("`J"B`@("`@
M*B!`<&%R86T@1$(@)&1B:"`@("`@("`@06X@;V)J96-T('!O:6YT:6YG('1O
M(&$@4U%,(&1A=&%B87-E(&AA;F1L92X*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@4&%R86UE=&5R<R!F;W(@=&AE(&%T=')I8G5T97,@
M=&%B;&4L(&-O;G-I<W1I;F<*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!O9B!T:&4@9F]L;&]W:6YG(&ME>7,Z"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@)W!R:6UA<GE?=&%B;&4G("`@+2!T:&4@;6%I;B!344P@=&%B
M;&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`G871T<FEB=71E7W1A
M8FQE)R`M('1H92!S96-O;F0@=&%B;&4@8V]N=&%I;FEN9PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&%T
M=')I8G5T97,@=&\@=&AE(&UA:6X*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('1A8FQE+@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("=I9%]C;VQU;6XG("`@("`@("T@=&AE(&YA;64@
M;V8@=&AE(&-O;'5M;B!W:71H"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!T:&4@240@;W(@:V5Y(&9I96QD+@H@
M("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D8F@L("1P87)A;7,I
M"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC97,["@H@("`@("`@(&EF
M("@A:7-S970H)&EN<W1A;F-E<RDI('L*("`@("`@("`@("`@)&EN<W1A;F-E
M<R`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("`D<VEG;F%T=7)E(#T@
M<V5R:6%L:7IE*"1P87)A;7,I.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A
M;F-E<ULD<VEG;F%T=7)E72DI('L*("`@("`@("`@("`@)&EN<W1A;F-E<ULD
M<VEG;F%T=7)E72`]("9N97<@2&]R9&5?4U%,7T%T=')I8G5T97,H)&1B:"P@
M)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E
M<ULD<VEG;F%T=7)E73L*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]3
M44PO2V5Y=V]R9',N<&AP````````````````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,30U,S(`,3`U,34T,S,W-3``,#(R-#0V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&ES(&-L
M87-S('!R;W9I9&5S(&$@<&%R<V5R('=H:6-H(&-A;B!C;VYS=')U8W0@86X@
M4U%,(%=(15)%"B`J(&-L875S92!F<F]M(&$@1V]O9VQE+6QI:V4@<V5A<F-H
M(&5X<')E<W-I;VXN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-13"]344PO
M2V5Y=V]R9',N<&AP+'8@,2XR+C$P+C0@,C`P-B\P,2\P,2`R,3HR.#HS,R!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!#<F]N;W-Y<RP@
M3$Q#(#QH='1P.B\O=W=W+F-R;VYO<WES+F-O;2\^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@5&AE(&5X<')E<W-I;VX@<F5C;V=N:7IE<R!B;V]L96%N(")!3D0B
M+"`B3U(B+"!A;F0@(DY/5"(@*'!R;W9I9&EN9PH@*B!N;R!O<&5R871O<B!B
M971W965N(&ME>7=O<F1S(&EM<&QI97,@(D%.1"(I+"!L:6ME('-O.@H@*@H@
M*B`@(&-A="!A;F0@9&]G"B`J("`@8V%T(&]R(&1O9PH@*B`@(&-A="!A;F0@
M;F]T(&1O9PH@*@H@*B!)9B!N;R!O<&5R871O<B!A<'!E87)S(&)E='=E96X@
M:V5Y=V]R9',@;W(@<75O=&5D('-T<FEN9W,L(")!3D0B(&ES"B`J(&%S<W5M
M960N("!!(&-O;6UA(&-A;B!B92!U<V5D(&EN<W1E860@;V8@(D]2(CH*("H*
M("H@("!C870@9&]G"B`J("`@8V%T+"!D;V<*("H@("!C870@;F]T(&1O9PH@
M*@H@*B!4:&4@<&%R<V5R(')E8V]G;FEZ97,@<&%R96YT:&5S97,L('-O(&-O
M;7!L97@@97AP<F5S<VEO;G,@8V%N(&)E"B`J(&-R96%T960Z"B`J"B`J("`@
M8V%T(&%N9"!N;W0@*&1O9R!O<B!P=7!P>2D*("H*("H@475O=&5D('-T<FEN
M9W,@87)E(&%L<V\@<F5C;V=N:7IE9"P@86YD(&%R92!T86ME;B!A<R!L:71E
M<F%L"B`J(&ME>7=O<F1S.@H@*@H@*B`@(")C870@86YD(&1O9R(*("H*("H@
M4&%R<VEN9R!I<R!D97-I9VYE9"!T;R!B92!A<R!F=7IZ>2!A<R!P;W-S:6)L
M92P@<V\@:70@<VAO=6QD;B=T"B`J(&5R<F]R('5N;&5S<R!P96]P;&4@<V5A
M<F-H(&9O<B`B04Y$(BP@(D]2(BP@;W(@(DY/5"(@=VET:&]U=`H@*B!Q=6]T
M:6YG(&ET(&]R('5S92!U;F)A;&%N8V5D('!A<F5N=&AE<V5S+@H@*@H@*B!`
M875T:&]R("!*87-O;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M
M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?4U%,
M"B`J+PIC;&%S<R!(;W)D95]344Q?2V5Y=V]R9',@>PH*("`@("\J*@H@("`@
M("H@4&%R<V4@82!K97EW;W)D(&5X<')E<W-I;VXN"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8V]L=6UN("`@("`@("!4:&ES(&ES('1H92!344P@
M9FEE;&0@;F%M92!T:&4@<F5S=6QT:6YG"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&5X<')E<W-I;VX@<VAO=6QD('1E<W0@86=A:6YS
M="X*("`@("`J($!P87)A;2!S=')I;F<@)&5X<'(@("`@("`@("`@5&AI<R!I
M<R!T:&4@:V5Y=V]R9"!E>'!R97-S:6]N('=E('=A;G0@=&\*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<&%R<V4N"B`@("`@*B!`<F5T
M=7)N(&UI>&5D('1H92!Q=65R>2!E>'!R97-S:6]N(&]R(&$@4$5!4E]%<G)O
M<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!P87)S92@D8V]L
M=6UN+"`D97AP<BD*("`@('L*("`@("`@("`O*B!&:7)S="!P87-S("T@<V-A
M;B!T:&4@<W1R:6YG(&9O<B!T;VME;G,N("!"87)E('=O<F1S(&%R90H@("`@
M("`@("`J('1O:V5N<RP@;W(@=&AE('5S97(@8V%N('%U;W1E('-T<FEN9W,@
M=&\@:&%V92!E;6)E9&1E9`H@("`@("`@("`J('-P86-E<RP@:V5Y=V]R9',L
M(&]R('!A<F5N=&AE<V5S+B`@4&%R96YT:&5S97,@8V%N(&)E('5S960*("`@
M("`@("`@*B!F;W(@9W)O=7!I;F<@8F]O;&5A;B!O<&5R871O<G,L(&%N9"!T
M:&4@8F]O;&5A;B!O<&5R871O<G,*("`@("`@("`@*B!!3D0L($]2+"!A;F0@
M3D]4(&%R92!A;&P@<F5C;V=N:7IE9"X*("`@("`@("`@*@H@("`@("`@("`J
M(%1H92!T;VME;G,@87)E(')E='5R;F5D(&EN('1H92`D=&]K96YS(&%R<F%Y
M("TM(&%N(&%R<F%Y(&]F"B`@("`@("`@("H@<W1R:6YG<RX@($5A8V@@<W1R
M:6YG(&EN('1H92!A<G)A>2!S=&%R=',@=VET:"!E:71H97(@82!@(2<*("`@
M("`@("`@*B!O<B!A(&`])RX@(&`])R!I<R!A(&)A<F4@=V]R9"!O<B!Q=6]T
M960@<W1R:6YG('=E(&%R90H@("`@("`@("`J('-E87)C:&EN9R!F;W(L(&%N
M9"!@(2<@:6YD:6-A=&5S(&$@8F]O;&5A;B!O<&5R871O<B!O<@H@("`@("`@
M("`J('!A<F5N=&AE<VES+B`@02!T;VME;B!T:&%T('-T87)T<R!W:71H(&$@
M)RXG("!I;F1I8V%T97,@80H@("`@("`@("`J(%!O<W1G<F5344P@=V]R9"!B
M;W5N9&%R>2!S96%R8V@N("HO"B`@("`@("`@)'1O:V5N<R`](&%R<F%Y*"D[
M"B`@("`@("`@=VAI;&4@*"%E;7!T>2@D97AP<BDI('L*("`@("`@("`@("`@
M)&5X<'(@/2!P<F5G7W)E<&QA8V4H(B]>7',K+R(L("(B+"`D97AP<BD["B`@
M("`@("`@("`@(&EF("AE;7!T>2@D97AP<BDI('L*("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AS=6)S='(H
M)&5X<'(L,"PQ*2`]/2`G*"<I('L*("`@("`@("`@("`@("`@("1E>'!R(#T@
M<W5B<W1R*"1E>'!R+"`Q*3L*("`@("`@("`@("`@("`@("1T;VME;B`]("<A
M*"<["B`@("`@("`@("`@('T@96QS96EF("AS=6)S='(H)&5X<'(L(#`L(#$I
M(#T]("<I)RD@>PH@("`@("`@("`@("`@("`@)&5X<'(@/2!S=6)S='(H)&5X
M<'(L(#$I.PH@("`@("`@("`@("`@("`@)'1O:V5N(#T@)R$I)SL*("`@("`@
M("`@("`@?2!E;'-E:68@*'-U8G-T<B@D97AP<BP@,"P@,2D@/3T@)RPG*2![
M"B`@("`@("`@("`@("`@("`D97AP<B`]('-U8G-T<B@D97AP<BP@,2D["B`@
M("`@("`@("`@("`@("`D=&]K96X@/2`G(4]2)SL*("`@("`@("`@("`@?2!E
M;'-E:68@*'!R96=?;6%T8V@H(B]>*$%.1'Q/4GQ.3U0I*%M>82UZ72XJ*3\D
M+VDB+"`D97AP<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&UA=&-H97,I*2!["B`@("`@("`@("`@("`@("`D=&]K96X@/2`G(2<@+B!S
M=')T;W5P<&5R*"1M871C:&5S6S%=*3L*("`@("`@("`@("`@("`@("1E>'!R
M(#T@<W5B<W1R*"1E>'!R+"!S=')L96XH)&UA=&-H97-;,5TI*3L*("`@("`@
M("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H(B]>7"(H*%M>7")=?%Q<6S`M
M-UTK?%Q<6UAX75LP+3EA+69!+49=*WQ<7%M>6'@P+3==*2HI7"(O(BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5X<'(L("1M871C:&5S
M*2D@>PH@("`@("`@("`@("`@("`@)'1O:V5N(#T@)STG("X@<W1R:7!C<VQA
M<VAE<R@D;6%T8VAE<ULQ72D["B`@("`@("`@("`@("`@("`D97AP<B`]('-U
M8G-T<B@D97AP<BP@<W1R;&5N*"1M871C:&5S6S!=*2D["B`@("`@("`@("`@
M('T@96QS96EF("AP<F5G7VUA=&-H*"(O7EM>7%QS7%PH7%PI+%TK+R(L("1E
M>'!R+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@("`@("1T;VME;B`]("<]
M)R`N("1M871C:&5S6S!=.PH@("`@("`@("`@("`@("`@)&5X<'(@/2!S=6)S
M='(H)&5X<'(L<W1R;&5N*"1T;VME;BDM,2D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(BDI.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&EF("@D=&]K96X@/3T@)R%!3D0G*2!["B`@("`@
M("`@("`@("`@("`O*B`A04Y$(&ES(&EM<&QI960@8GD@8V]N8V%T96YA=&EO
M;BX@*B\*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1T;VME;G-;72`]("1T;VME;CL*("`@("`@("!]"@H@
M("`@("`@("\J($-A;&P@=&AE(&5X<')E<W-I;VX@<&%R<V5R+B`J+PH@("`@
M("`@(')E='5R;B!(;W)D95]344Q?2V5Y=V]R9',Z.E]P87)S94ME>7=O<F1S
M,2@D8V]L=6UN+"`D=&]K96YS*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<&%R
M<V5+97EW;W)D<S$H)&-O;'5M;BP@)B1T;VME;G,I"B`@("!["B`@("`@("`@
M:68@*&-O=6YT*"1T;VME;G,I(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B16UP='D@<V5A<F-H('1E<FUS(BDI.PH@
M("`@("`@('T*("`@("`@("`D;&AS(#T@2&]R9&5?4U%,7TME>7=O<F1S.CI?
M<&%R<V5+97EW;W)D<S(H)&-O;'5M;BP@)'1O:V5N<RD["B`@("`@("`@:68@
M*&ES7V$H)&QH<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)&QH<SL*("`@("`@("!]"B`@("`@("`@:68@*&-O=6YT*"1T;VME;G,I
M(#T](#`@?'P@)'1O:V5N<ULP72`A/2`G(4]2)RD@>PH@("`@("`@("`@("!R
M971U<FX@)&QH<SL*("`@("`@("!]"B`@("`@("`@87)R87E?<VAI9G0H)'1O
M:V5N<RD["B`@("`@("`@)')H<R`]($AO<F1E7U-13%]+97EW;W)D<SHZ7W!A
M<G-E2V5Y=V]R9',Q*"1C;VQU;6XL("1T;VME;G,I.PH@("`@("`@(&EF("AI
M<U]A*"1R:',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1R:',["B`@("`@("`@?0H@("`@("`@(')E='5R;B`B*"`D;&AS($]2("1R
M:',@*2(["B`@("!]"@H@("`@9G5N8W1I;VX@7W!A<G-E2V5Y=V]R9',R*"1C
M;VQU;6XL("8D=&]K96YS*0H@("`@>PH@("`@("`@("1L:',@/2!(;W)D95]3
M44Q?2V5Y=V]R9',Z.E]P87)S94ME>7=O<F1S,R@D8V]L=6UN+"`D=&]K96YS
M*3L*("`@("`@("!I9B`H:7-?82@D;&AS+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D;&AS.PH@("`@("`@('T*("`@("`@("!I9B`H
M<VEZ96]F*"1T;VME;G,I(#T](#`@?'P@)'1O:V5N<ULP72`]/2`G(2DG('Q\
M("1T;VME;G-;,%T@/3T@)R%/4B<I('L*("`@("`@("`@("`@<F5T=7)N("1L
M:',["B`@("`@("`@?0H@("`@("`@("1R:',@/2!(;W)D95]344Q?2V5Y=V]R
M9',Z.E]P87)S94ME>7=O<F1S,B@D8V]L=6UN+"`D=&]K96YS*3L*("`@("`@
M("!I9B`H:7-?82@D<FAS+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<FAS.PH@("`@("`@('T*("`@("`@("!R971U<FX@(B@@)&QH
M<R!!3D0@)')H<R`I(CL*("`@('T*"B`@("!F=6YC=&EO;B!?<&%R<V5+97EW
M;W)D<S,H)&-O;'5M;BP@)B1T;VME;G,I"B`@("!["B`@("`@("`@:68@*"1T
M;VME;G-;,%T@/3T@)R%.3U0G*2!["B`@("`@("`@("`@(&%R<F%Y7W-H:69T
M*"1T;VME;G,I.PH@("`@("`@("`@("`D;&AS(#T@2&]R9&5?4U%,7TME>7=O
M<F1S.CI?<&%R<V5+97EW;W)D<S0H)&-O;'5M;BP@)'1O:V5N<RD["B`@("`@
M("`@("`@(&EF("AI<U]A*"1L:',L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D;&AS.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(')E='5R;B`B*"!.3U0@)&QH<R`I(CL*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N($AO<F1E7U-13%]+97EW;W)D<SHZ7W!A<G-E2V5Y=V]R9',T*"1C
M;VQU;6XL("1T;VME;G,I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]P87)S94ME
M>7=O<F1S-"@D8V]L=6UN+"`F)'1O:V5N<RD*("`@('L*("`@("`@("!I9B`H
M("1T;VME;G-;,%T@/3T@)R$H)R`I('L*("`@("`@("`@("`@87)R87E?<VAI
M9G0H)'1O:V5N<RD["B`@("`@("`@("`@("1L:',@/2!(;W)D95]344Q?2V5Y
M=V]R9',Z.E]P87)S94ME>7=O<F1S,2@D8V]L=6UN+"`D=&]K96YS*3L*("`@
M("`@("`@("`@:68@*&ES7V$H)&QH<RP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1L:',["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*'-I>F5O9B@D=&]K96YS*2`]/2`P('Q\("1T;VME;G-;,%T@
M(3T@)R$I)RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H7R@B17AP96-T960@)RDG(BDI.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&%R<F%Y7W-H:69T*"1T;VME;G,I.PH@("`@("`@("`@("!R971U
M<FX@)&QH<SL*("`@("`@("!]"B`@("`@("`@:68@*'-U8G-T<B@D=&]K96YS
M6S!=+"`P+"`Q*2`A/2`G/2<@)B8*("`@("`@("`@("`@<W5B<W1R*"1T;VME
M;G-;,%TL(#`L(#(I("$]("<]+B<I('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E
M9"!S96%R8V@@=&5R;2(I*3L*("`@("`@("!]"B`@("`@("`@)'9A;"`]('-T
M<G1O;&]W97(H<W5B<W1R*&%R<F%Y7W-H:69T*"1T;VME;G,I+"`Q*2D["B`@
M("`@("`@)'9A;"`](&%D9'-L87-H97,H97)E9U]R97!L86-E*"(H6UQ<)5TI
M(BP@(EQ<7%PQ(BP@)'9A;"DI.PH@("`@("`@(')E='5R;B`B*"!,3U=%4B@D
M8V]L=6UN*2!,24M%("<E)'9A;"4G("DB.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O4U%,+G!H<```````````````````````````````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#,T,S<W`#$P-3$U-#,S-S4R`#`R,#8U,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@5&AI<R!I<R!A('5T:6QI='D@8VQA<W,L(&5V97)Y(&UE=&AO9"!I
M<R!S=&%T:6,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-13"]344PN<&AP
M+'8@,2XS,"XR+C$W(#(P,#8O,#0O,3D@,#,Z-#DZ-#D@8F5N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@2F%N(%-C:&YE
M:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@
M268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U
M=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E
M("`@2&]R9&4@,BXR"B`J($!P86-K86=E($AO<F1E7U-13`H@*B\*8VQA<W,@
M2&]R9&5?4U%,('L*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!B;V]L96%N
M(&5X<')E<W-I;VX@=7-I;F<@=&AE('-P96-I9FEE9"!O<&5R871O<BX@57-E
M<PH@("`@("H@9&%T86)A<V4M<W!E8VEF:6,@8V%S=&EN9RP@:68@;F5C97-S
M87)Y+@H@("`@("H*("`@("`J($!P87)A;2!$0B`D9&)H("`@("`@("!4:&4@
M4$5!4CHZ1$(@9&%T86)A<V4@;V)J96-T+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;&AS("`@(%1H92!C;VQU;6X@;W(@97AP<F5S<VEO;B!T;R!T97-T+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;W`@("`@(%1H92!O<&5R871O<BX*("`@
M("`J($!P87)A;2!S=')I;F<@)')H<R`@("!4:&4@8V]M<&%R:7-O;B!V86QU
M92X*("`@("`J($!P87)A;2!B;V]L96%N("1B:6YD("!)9B!T<G5E+"!T:&4@
M;65T:&]D(')E='5R;G,@=&AE('%U97)Y(&%N9"!A(&QI<W0*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!O9B!V86QU97,@<W5I=&%B;&4@9F]R(&)I
M;F1I;F<@87,@86X@87)R87DN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!344P@=&5S="!F<F%G;65N="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@8G5I;&1#;&%U<V4H)B1D8F@L("1L:',L("1O<"P@)')H<RP@)&)I;F0@
M/2!F86QS92D*("`@('L*("`@("`@("!S=VET8V@@*"1O<"D@>PH@("`@("`@
M(&-A<V4@)WPG.@H@("`@("`@(&-A<V4@)R8G.@H@("`@("`@("`@("!S=VET
M8V@@*"1D8F@M/G!H<'1Y<&4I('L*("`@("`@("`@("`@8V%S92`G<&=S<6PG
M.@H@("`@("`@("`@("`@("`@+R\@3VYL>2!09U-13"`W+C,K('5N9&5R<W1A
M;F1S(%-13#DY("=324U)3$%2(%1/)SL@=7-E"B`@("`@("`@("`@("`@("`O
M+R!^(&9O<B!G<F5A=&5R(&)A8VMW87)D<R!C;VUP871I8FEL:71Y+@H@("`@
M("`@("`@("`@("`@)'%U97)Y(#T@)T-!4T4@5TA%3B!#05-4*"5S($%3(%9!
M4D-(05(I('X@7"=>+3];,"TY72LD7"<@5$A%3B`H0T%35"@E<R!!4R!)3E1%
M1T52*2`E<R`E<RD@/#X@,"!%3%-%($9!3%-%($5.1"<["B`@("`@("`@("`@
M("`@("!I9B`H)&)I;F0I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M87)R87DH<W!R:6YT9BA(;W)D95]344PZ.F5S8V%P95!R97!A<F4H)'%U97)Y
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!(
M;W)D95]344PZ.F5S8V%P95!R97!A<F4H)&QH<RDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@2&]R9&5?4U%,.CIE<V-A<&50
M<F5P87)E*"1L:',I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@($AO<F1E7U-13#HZ97-C87!E4')E<&%R92@D;W`I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<_)RDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"AI;G0I)')H
M<RDI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@<W!R:6YT9B@D<75E<GDL("1L:',L("1L:',L("1O<"P@
M*&EN="DD<FAS*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@(&-A
M<V4@)V]C:3@G.@H@("`@("`@("`@("`@("`@+R\@3W)A8VQE('5S97,@)B!F
M;W(@=F%R:6%B;&5S+B!792!N965D('1O('5S92!T:&4@8FET86YD"B`@("`@
M("`@("`@("`@("`O+R!F=6YC=&EO;B!T:&%T(&ES(&%V86EL86)L92P@8G5T
M(&UA>2!B92!U;G-U<'!O<G1E9"X*("`@("`@("`@("`@("`@("1Q=65R>2`]
M("=B:71A;F0H)7,L("5S*2`]("5S)SL*("`@("`@("`@("`@("`@(&EF("@D
M8FEN9"D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2AS<')I
M;G1F*$AO<F1E7U-13#HZ97-C87!E4')E<&%R92@D<75E<GDI+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($AO<F1E7U-13#HZ
M97-C87!E4')E<&%R92@D;&AS*2P@)S\G+"`G/R<I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@H:6YT*21R:',L("AI;G0I)')H
M<RDI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@<W!R:6YT9B@D<75E<GDL("1L:',L("AI;G0I)')H<RP@
M*&EN="DD<FAS*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@(&-A
M<V4@)VUS<W%L)SH*("`@("`@("`@("`@("`@("\O($U34U%,(&UU<W0@:&%V
M92!A('9A;&ED(&)O;VQE86X@97AP<F5S<VEO;@H@("`@("`@("`@("`@("`@
M)'%U97)Y(#T@)RA#05-%(%=(14X@25-.54U%4DE#*"5S*2`](#$@5$A%3B`H
M)7,@)B`E<RD@14Q312`E<R!%3D0I(#T@)7,G.PH@("`@("`@("`@("`@("`@
M:68@*"1B:6YD*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y
M*'-P<FEN=&8H2&]R9&5?4U%,.CIE<V-A<&50<F5P87)E*"1Q=65R>2DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@2&]R9&5?
M4U%,.CIE<V-A<&50<F5P87)E*"1L:',I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@($AO<F1E7U-13#HZ97-C87!E4')E<&%R
M92@D;&AS*2P@)S\G+"`G/R<L("<_)RDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"AI;G0I)')H<RP@*&EN="DD<FAS("T@,2P@
M*&EN="DD<FAS*2D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!S<')I;G1F*"1Q=65R>2P@)&QH<RP@)&QH
M<RP@*&EN="DD<FAS+"`H:6YT*21R:',@+2`Q+"`H:6YT*21R:',I.PH@("`@
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@8V%S92`G;V1B8R<Z"B`@("`@
M("`@("`@("`@("`O+R!/1$)#(&UU<W0@:&%V92!A('9A;&ED(&)O;VQE86X@
M97AP<F5S<VEO;@H@("`@("`@("`@("`@("`@)'%U97)Y(#T@)R@E<R`F("5S
M*2`]("5S)SL*("`@("`@("`@("`@("`@(&EF("@D8FEN9"D@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!A<G)A>2AS<')I;G1F*$AO<F1E7U-13#HZ
M97-C87!E4')E<&%R92@D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@($AO<F1E7U-13#HZ97-C87!E4')E<&%R92@D
M;&AS*2P@)S\G+"`G/R<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@H:6YT*21R:',L("AI;G0I)')H<RDI.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@<W!R
M:6YT9B@D<75E<GDL("1L:',L("AI;G0I)')H<RP@*&EN="DD<FAS*3L*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@
M("`@("`@("!I9B`H)&)I;F0I('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@87)R87DH)&QH<R`N("<@)R`N($AO<F1E7U-13#HZ97-C87!E4')E<&%R
M92@D;W`I("X@)R`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH*&EN="DD<FAS*2D["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D;&AS("X@)R`G("X@)&]P
M("X@)R`G("X@*&EN="DD<FAS.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"@H@("`@("`@(&-A<V4@)WXG.@H@("`@("`@("`@("!I9B`H)&1B
M:"T^<&AP='EP92`]/2`G;7ES<6PG*2!["B`@("`@("`@("`@("`@("`D;W`@
M/2`G4D5'15A0)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&)I
M;F0I('L*("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2@D;&AS("X@)R`G
M("X@)&]P("X@)R`_)RP@87)R87DH)')H<RDI.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1L:',@+B`G("<@+B`D;W`@
M+B`G("<@+B`D<FAS.PH@("`@("`@("`@("!]"@H@("`@("`@(&-A<V4@)TE.
M)SH*("`@("`@("`@("`@:68@*"1B:6YD*2!["B`@("`@("`@("`@("`@("!I
M9B`H:7-?87)R87DH)')H<RDI('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@87)R87DH)&QH<R`N("<@24X@*#\G("X@<W1R7W)E<&5A="@G+"`_)RP@
M8V]U;G0H)')H<RD@+2`Q*2`N("<I)RP@)')H<RD["B`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("\O(%=E(&YE960@=&\@
M8FEN9"!E86-H(&UE;6)E<B!O9B!T:&4@24X@8VQA=7-E"B`@("`@("`@("`@
M("`@("`@("`@+R\@<V5P87)A=&5L>2!T;R!E;G-U<F4@<')O<&5R('%U;W1I
M;F<N"B`@("`@("`@("`@("`@("`@("`@:68@*'-U8G-T<B@D<FAS+"`P+"`Q
M*2`]/2`G*"<I('L*("`@("`@("`@("`@("`@("`@("`@("`@)')H<R`]('-U
M8G-T<B@D<FAS+"`Q*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@:68@*'-U8G-T<B@D<FAS+"`M,2D@/3T@)RDG*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1R:',@/2!S=6)S='(H)')H<RP@,"P@
M+3$I.PH@("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@
M("`@)&ED<R`]('!R96=?<W!L:70H)R]<<RHL7',J+R<L("1R:',I.PH*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@87)R87DH)&QH<R`N("<@24X@*#\G
M("X@<W1R7W)E<&5A="@G+"`_)RP@8V]U;G0H)&ED<RD@+2`Q*2`N("<I)RP@
M)&ED<RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)')H<RDI('L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)&QH<R`N("<@24X@)R`N(&EM<&QO9&4H
M)RP@)RP@)')H<RD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D;&AS("X@)R!)3B`G("X@)')H<SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("!C87-E("=,
M24M%)SH*("`@("`@("`@("`@:68@*"1D8F@M/G!H<'1Y<&4@/3T@)W!G<W%L
M)RD@>PH@("`@("`@("`@("`@("`@)'%U97)Y(#T@)R5S($E,24M%("5S)SL*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1Q=65R>2`]
M("=,3U=%4B@E<RD@3$E+12!,3U=%4B@E<RDG.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&EF("@D8FEN9"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(&%R<F%Y*'-P<FEN=&8H)'%U97)Y+"!(;W)D95]344PZ.F5S8V%P95!R97!A
M<F4H)&QH<RDL("<_)RDL(&%R<F%Y*"<E)R`N("1R:',@+B`G)2<I*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!S<')I
M;G1F*"1Q=65R>2P@)&QH<RP@)&1B:"T^<75O=&4H)R4G("X@)')H<R`N("<E
M)RDI.PH@("`@("`@("`@("!]"@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@
M("`@(&EF("@D8FEN9"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y
M*"1L:',@+B`G("<@+B!(;W)D95]344PZ.F5S8V%P95!R97!A<F4H)&]P*2`N
M("<@/R<L(&%R<F%Y*"1R:',I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D;&AS("X@)R`G("X@)&]P("X@)R`G("X@
M)&1B:"T^<75O=&4H)')H<RD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!%<V-A<&5S(&%L;"!C:&%R86-T97)S(&EN
M(&$@<W1R:6YG('1H870@87)E('!L86-E:&]L9&5R<R!F;W(@=&AE"B`@("`@
M*B!P<F5P87)E+V5X96-U=&4@;65T:&]D<R!O9B!T:&4@1$(@<&%C:V%G92X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1Q=65R>2`@02!S=')I;F<@
M=&\@97-C87!E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M8V]R<F5C=&QY(&5S8V%P960@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!E<V-A<&50<F5P87)E*"1Q=65R>2D*("`@('L*("`@("`@("!R971U<FX@
M<')E9U]R97!L86-E*"<O6S\A)ETO)RP@)UQ<7%PD,"<L("1Q=65R>2D["B`@
M("!]"@H@("`@9G5N8W1I;VX@<F5A9$)L;V(H)B1D8F@L("1T86)L92P@)&9I
M96QD+"`D8W)I=&5R:6$I"B`@("!["B`@("`@("`@:68@*"%C;W5N="@D8W)I
M=&5R:6$I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=9;W4@;75S="!S<&5C:69Y('1H92!F971C:"!C<FET97)I82<I.PH@("`@
M("`@('T*"B`@("`@("`@)'=H97)E(#T@)R<["@H@("`@("`@('-W:71C:"`H
M)&1B:"T^9&)S>6YT87@I('L*("`@("`@("!C87-E("=O8VDX)SH*("`@("`@
M("`@("`@9F]R96%C:"`H)&-R:71E<FEA(&%S("1K97D@/3X@)'9A;'5E*2![
M"B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1W:&5R92DI('L*("`@("`@
M("`@("`@("`@("`@("`D=VAE<F4@+CT@)R!!3D0@)SL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D=F%L=64I*2!["B`@
M("`@("`@("`@("`@("`@("`@)'=H97)E("X]("1K97D@+B`G($E3($Y53$PG
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D=VAE<F4@+CT@)&ME>2`N("<@/2`G("X@)&1B:"T^<75O=&4H)'9A;'5E
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@)'-T871E;65N="`]($]#25!A<G-E*"1D8F@M/F-O;FYE8W1I;VXL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S<')I;G1F*"=314Q%
M0U0@)7,@1E)/32`E<R!72$5212`E<R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1F:65L9"P@)'1A8FQE+"`D=VAE<F4I
M*3L*("`@("`@("`@("`@3T-)17AE8W5T92@D<W1A=&5M96YT*3L*("`@("`@
M("`@("`@:68@*$]#249E=&-H26YT;R@D<W1A=&5M96YT+"`D;&]B*2D@>PH@
M("`@("`@("`@("`@("`@)')E<W5L="`]("1L;V);,%TM/FQO860H*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2!0
M14%2.CIR86ES945R<F]R*"=5;F%B;&4@=&\@;&]A9"!344P@1&%T82<I.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@($]#249R9653=&%T96UE;G0H)'-T
M871E;65N="D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT
M.@H@("`@("`@("`@("!F;W)E86-H("@D8W)I=&5R:6$@87,@)&ME>2`]/B`D
M=F%L=64I('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'=H97)E*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1W:&5R92`N/2`G($%.1"`G.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'=H97)E("X]("1K97D@
M+B`G(#T@)R`N("1D8F@M/G%U;W1E*"1V86QU92D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)')E<W5L="`]("1D8F@M/F=E=$]N92AS<')I;G1F*"=3
M14Q%0U0@)7,@1E)/32`E<R!72$5212`E<R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEE;&0L("1T86)L92P@)'=H
M97)E*2D["@H@("`@("`@("`@("!S=VET8V@@*"1D8F@M/F1B<WEN=&%X*2![
M"B`@("`@("`@("`@(&-A<V4@)W!G<W%L)SH*("`@("`@("`@("`@("`@("1R
M97-U;'0@/2!P86-K*"=()R`N('-T<FQE;B@D<F5S=6QT*2P@)')E<W5L="D[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@9G5N8W1I
M;VX@:6YS97)T0FQO8B@F)&1B:"P@)'1A8FQE+"`D9FEE;&0L("1D871A+"`D
M871T<FEB=71E<RD*("`@('L*("`@("`@("`D9FEE;&1S(#T@87)R87DH*3L*
M("`@("`@("`D=F%L=65S(#T@87)R87DH*3L*"B`@("`@("`@<W=I=&-H("@D
M9&)H+3YD8G-Y;G1A>"D@>PH@("`@("`@(&-A<V4@)V]C:3@G.@H@("`@("`@
M("`@("!F;W)E86-H("@D871T<FEB=71E<R!A<R`D:V5Y(#T^("1V86QU92D@
M>PH@("`@("`@("`@("`@("`@)&9I96QD<UM=(#T@)&ME>3L*("`@("`@("`@
M("`@("`@("1V86QU97-;72`]("1D8F@M/G%U;W1E*"1V86QU92D["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1S=&%T96UE;G0@/2!/0TE087)S92@D
M9&)H+3YC;VYN96-T:6]N+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<W!R:6YT9B@G24Y315)4($E.5$\@)7,@*"5S+"`E<RDG("X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R!604Q5
M15,@*"5S+"!%35!465]"3$]"*"DI(%)%5%523DE.1R`E<R!)3E1/(#IB;&]B
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1A8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I;7!L;V1E*"<L("<L("1F:65L9',I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEE;&0L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EM<&QO9&4H)RP@)RP@
M)'9A;'5E<RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1F:65L9"DI.PH*("`@("`@("`@("`@)&QO8B`]($]#24YE=T1E
M<V-R:7!T;W(H)&1B:"T^8V]N;F5C=&EO;BD["B`@("`@("`@("`@($]#24)I
M;F1">4YA;64H)'-T871E;65N="P@)SIB;&]B)RP@)&QO8BP@+3$L(%-13%1?
M0DQ/0BD["B`@("`@("`@("`@($]#245X96-U=&4H)'-T871E;65N="P@3T-)
M7T1%1D%53%0I.PH@("`@("`@("`@("`D;&]B+3YS879E*"1D871A*3L*("`@
M("`@("`@("`@)')E<W5L="`]($]#24-O;6UI="@D9&)H+3YC;VYN96-T:6]N
M*3L*("`@("`@("`@("`@)&QO8BT^9G)E92@I.PH@("`@("`@("`@("!/0TE&
M<F5E4W1A=&5M96YT*"1S=&%T96UE;G0I.PH@("`@("`@("`@("!R971U<FX@
M)')E<W5L="`_('1R=64@.B!014%2.CIR86ES945R<F]R*"=5;FMN;W=N($5R
M<F]R)RD["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(&9O<F5A8V@@
M*"1A='1R:6)U=&5S(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@
M("`@("`D9FEE;&1S6UT@/2`D:V5Y.PH@("`@("`@("`@("`@("`@)'9A;'5E
M<UM=(#T@)'9A;'5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<75E
M<GD@/2!S<')I;G1F*"=)3E-%4E0@24Y43R`E<R`H)7,L("5S*2!604Q515,@
M*"5S*2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1A8FQE+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EM<&QO9&4H)RP@)RP@)&9I
M96QD<RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I96QD+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("<_)R`N('-T<E]R97!E870H
M)RP@/R<L(&-O=6YT*"1V86QU97,I*2D["B`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@('T*"B`@("`@("`@<W=I=&-H("@D9&)H+3YD8G-Y;G1A>"D@>PH@
M("`@("`@(&-A<V4@)VUS<W%L)SH*("`@("`@("!C87-E("=P9W-Q;"<Z"B`@
M("`@("`@("`@("1V86QU97-;72`](&)I;C)H97@H)&1A=&$I.PH@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@)'9A
M;'5E<UM=(#T@)&1A=&$["B`@("`@("`@?0H*("`@("`@("`O*B!,;V<@=&AE
M('%U97)Y(&%T(&$@1$5"54<@;&]G(&QE=F5L+B`J+PH@("`@("`@($AO<F1E
M.CIL;V=-97-S86=E*'-P<FEN=&8H)U-13"!1=65R>2!B>2!(;W)D95]344PZ
M.FEN<V5R=$)L;V(H*3H@<75E<GD@/2`B)7,B)RP@)'%U97)Y*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T1%0E5'*3L*"B`@("`@("`@+RH@17AE8W5T92!T:&4@<75E<GDN("HO
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A
M;'5E<RD["B`@("!]"@H@("`@9G5N8W1I;VX@=7!D871E0FQO8B@F)&1B:"P@
M)'1A8FQE+"`D9FEE;&0L("1D871A+"`D=VAE<F4L("1A;'-O=7!D871E*0H@
M("`@>PH@("`@("`@("1F:65L9',@/2!A<G)A>2@I.PH@("`@("`@("1V86QU
M97,@/2!A<G)A>2@I.PH*("`@("`@("!S=VET8V@@*"1D8F@M/F1B<WEN=&%X
M*2!["B`@("`@("`@8V%S92`G;V-I."<Z"B`@("`@("`@("`@("1W:&5R97-T
M<FEN9R`]("<G.PH@("`@("`@("`@("!F;W)E86-H("@D=VAE<F4@87,@)&ME
M>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'=H
M97)E<W1R:6YG*2D@>PH@("`@("`@("`@("`@("`@("`@("1W:&5R97-T<FEN
M9R`N/2`G($%.1"`G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)'=H97)E<W1R:6YG("X]("1K97D@+B`G(#T@)R`N("1D8F@M/G%U;W1E
M*"1V86QU92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1S=&%T96UE
M;G0@/2!/0TE087)S92@D9&)H+3YC;VYN96-T:6]N+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<W!R:6YT9B@G4T5,14-4("5S($923TT@
M)7,@5TA%4D4@)7,@1D]2(%501$%412<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1F:65L9"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1A8FQE+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=VAE<F5S=')I;F<I
M*3L*"B`@("`@("`@("`@($]#245X96-U=&4H)'-T871E;65N="P@3T-)7T1%
M1D%53%0I.PH@("`@("`@("`@("!/0TE&971C:$EN=&\H)'-T871E;65N="P@
M)&QO8BD["B`@("`@("`@("`@("1L;V);,%TM/G-A=F4H)&1A=&$I.PH@("`@
M("`@("`@("`D<F5S=6QT(#T@3T-)0V]M;6ET*"1D8F@M/F-O;FYE8W1I;VXI
M.PH@("`@("`@("`@("`D;&]B6S!=+3YF<F5E*"D["B`@("`@("`@("`@($]#
M249R9653=&%T96UE;G0H)'-T871E;65N="D["B`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT(#\@=')U92`Z(%!%05(Z.G)A:7-E17)R;W(H)U5N:VYO=VX@
M17)R;W(G*3L*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@)'5P9&%T
M97-T<FEN9R`]("<G.PH@("`@("`@("`@("`D=F%L=65S(#T@87)R87DH*3L*
M("`@("`@("`@("`@9F]R96%C:"`H)&%L<V]U<&1A=&4@87,@)&ME>2`]/B`D
M=F%L=64I('L*("`@("`@("`@("`@("`@("1U<&1A=&5S=')I;F<@+CT@)&ME
M>2`N("<@/2`_+"`G.PH@("`@("`@("`@("`@("`@)'9A;'5E<UM=(#T@)'9A
M;'5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1U<&1A=&5S=')I;F<@
M+CT@)&9I96QD("X@)R`](#\G.PH@("`@("`@("`@("!S=VET8V@@*"1D8F@M
M/F1B<WEN=&%X*2!["B`@("`@("`@("`@(&-A<V4@)VUS<W%L)SH*("`@("`@
M("`@("`@8V%S92`G<&=S<6PG.@H@("`@("`@("`@("`@("`@)'9A;'5E<UM=
M(#T@8FEN,FAE>"@D9&%T82D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`D=F%L=65S6UT@
M/2`D9&%T83L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'=H97)E<W1R
M:6YG(#T@)R<["B`@("`@("`@("`@(&9O<F5A8V@@*"1W:&5R92!A<R`D:V5Y
M(#T^("1V86QU92D@>PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D=VAE
M<F5S=')I;F<I*2!["B`@("`@("`@("`@("`@("`@("`@)'=H97)E<W1R:6YG
M("X]("<@04Y$("<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D=VAE<F5S=')I;F<@+CT@)&ME>2`N("<@/2`_)SL*("`@("`@("`@("`@
M("`@("1V86QU97-;72`]("1V86QU93L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G55!$051%("5S(%-%5"`E<R!72$52
M12`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1A8FQE+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1U<&1A=&5S=')I;F<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=H97)E<W1R:6YG*3L*("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("`O*B!,;V<@=&AE
M('%U97)Y(&%T(&$@1$5"54<@;&]G(&QE=F5L+B`J+PH@("`@("`@($AO<F1E
M.CIL;V=-97-S86=E*'-P<FEN=&8H)U-13"!1=65R>2!B>2!(;W)D95]344PZ
M.G5P9&%T94)L;V(H*3H@<75E<GD@/2`B)7,B)RP@)'%U97)Y*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T1%0E5'*3L*"B`@("`@("`@+RH@17AE8W5T92!T:&4@<75E<GDN("HO
M"B`@("`@("`@<F5T=7)N("1D8F@M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9"!A;B!344P@4T54(&-L875S
M92X*("`@("`J"B`@("`@*B!4:&ES(&9U;F-T:6]N('1A:V5S(&%N(&%R<F%Y
M(&EN('1H92!F;W)M(&-O;'5M;B`]/B!V86QU92!A;F0@<F5T=7)N<PH@("`@
M("H@86X@4U%,(%-%5"!C;&%U<V4@*'=I=&AO=70@=&AE(%-%5"!K97EW;W)D
M*2!W:71H('1H92!V86QU97,@<')O<&5R;'D*("`@("`J('%U;W1E9"X@($9O
M<B!E>&%M<&QE+"!T:&4@9F]L;&]W:6YG.@H@("`@("H*("`@("`J("`@("`@
M87)R87DH)V9O;R<@/3X@,2P*("`@("`J("`@("`@("`@("`@)V)A<B<@/3X@
M)VAE;&QO)RD*("`@("`J"B`@("`@*B!W;W5L9"!R97-U;'0@:6X@=&AE(&9R
M86=M96YT.@H@("`@("H*("`@("`J("`@("`@9F]O(#T@,2P@8F%R(#T@)VAE
M;&QO)PH@("`@("H*("`@("`J($!P87)A;2!$0B`D9&)H("`@("`@("!4:&4@
M4$5!4CHZ1$(@9&%T86)A<V4@;V)J96-T+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1V86QU97,@(%1H92!A<G)A>2!O9B!C;VQU;6X@/3X@=F%L=64@<&%I<G,N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!344P@4T54(&9R
M86=M96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!U<&1A=&5686QU97,H)B1D
M8F@L("1V86QU97,I"B`@("!["B`@("`@("`@)')E="`](&%R<F%Y*"D["B`@
M("`@("`@9F]R96%C:"`H)'9A;'5E<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@
M("`@("`@("`@("`D<F5T6UT@/2`D:V5Y("X@)R`]("<@+B`H)'9A;'5E(#T]
M/2!N=6QL(#\@)TY53$PG(#H@)&1B:"T^<75O=&4H)'9A;'5E*2D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!I;7!L;V1E*"<L("<L("1R970I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@0G5I;&0@86X@4U%,($E.4T525"]604Q515,@
M8VQA=7-E+@H@("`@("H*("`@("`J(%1H:7,@9G5N8W1I;VX@=&%K97,@86X@
M87)R87D@:6X@=&AE(&9O<FT@8V]L=6UN(#T^('9A;'5E(&%N9"!R971U<FYS
M"B`@("`@*B!A;B!344P@9G)A9VUE;G0@<W!E8VEF>6EN9R!T:&4@8V]L=6UN
M(&YA;65S(&%N9"!I;G-E<G0@=F%L=65S+"!W:71H"B`@("`@*B!T:&4@=F%L
M=65S('!R;W!E<FQY('%U;W1E9"X@($9O<B!E>&%M<&QE+"!T:&4@9F]L;&]W
M:6YG.@H@("`@("H*("`@("`J("`@("`@87)R87DH)V9O;R<@/3X@,2P*("`@
M("`J("`@("`@("`@("`@)V)A<B<@/3X@)VAE;&QO)RD*("`@("`J"B`@("`@
M*B!W;W5L9"!R97-U;'0@:6X@=&AE(&9R86=M96YT.@H@("`@("H*("`@("`J
M("`@("`@*"!F;V\L(&)A<B`I(%9!3%5%4R`H(#$L("=H96QL;R<@*0H@("`@
M("H*("`@("`J($!P87)A;2!$0B`D9&)H("`@("`@("!4:&4@4$5!4CHZ1$(@
M9&%T86)A<V4@;V)J96-T+@H@("`@("H@0'!A<F%M(&%R<F%Y("1V86QU97,@
M(%1H92!A<G)A>2!O9B!C;VQU;6X@/3X@=F%L=64@<&%I<G,N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!344P@9G)A9VUE;G0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&EN<V5R=%9A;'5E<R@F)&1B:"P@)'9A;'5E<RD*
M("`@('L*("`@("`@("`D8V]L=6UN<R`](&%R<F%Y*"D["B`@("`@("`@)'9A
M;',@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1V86QU97,@87,@)&ME
M>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@)&-O;'5M;G-;72`]("1K97D[
M"B`@("`@("`@("`@("1V86QS6UT@/2`D=F%L=64@/3T](&YU;&P@/R`G3E5,
M3"<@.B`D9&)H+3YQ=6]T92@D=F%L=64I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)R@@)R`N(&EM<&QO9&4H)RP@)RP@)&-O;'5M;G,I("X@)R`I(%9!
M3%5%4R`H("<@+B!I;7!L;V1E*"<L("<L("1V86QS*2`N("<@*2<["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4W1R:6YG+G!H<```````````
M````````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0T-S$V`#$P-3$U-#,S
M-S4R`#`R,30U-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`H*)$=,3T)!3%-;)U](3U)$15]35%))3D=?0TA!4E-%
M5"==(#T@)VES;RTX.#4Y+3$G.PH*+RHJ"B`J(%1H92!3=')I;F<Z.B!C;&%S
M<R!P<F]V:61E<R!S=&%T:6,@;65T:&]D<R!F;W(@8VAA<G-E="!A;F0@;&]C
M86QE('-A9F4*("H@<W1R:6YG(&UA;FEP=6QA=&EO;BX*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO571I;"]3=')I;F<N<&AP+'8@,2XT,RXV+C$S(#(P,#8O
M,#,O,3,@,#DZ-#8Z,#<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S
M+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO
M<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]5
M=&EL"B`J+PIC;&%S<R!3=')I;F<@>PH*("`@("\J*@H@("`@("H@0V%C:&5S
M('1H92!R97-U;'0@;V8@97AT96YS:6]N7VQO861E9"@I(&-A;&QS+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&5X="`@5&AE(&5X=&5N<VEO;B!N
M86UE+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@27,@=&AE(&5X
M=&5N<VEO;B!L;V%D960_"B`@("`@*@H@("`@("H@0'-E92!5=&EL.CIE>'1E
M;G-I;VY%>&ES=',H*0H@("`@("HO"B`@("!F=6YC=&EO;B!E>'1E;G-I;VY%
M>&ES=',H)&5X="D*("`@('L*("`@("`@("!S=&%T:6,@)&-A8VAE(#T@87)R
M87DH*3L*"B`@("`@("`@:68@*"%I<W-E="@D8V%C:&5;)&5X=%TI*2!["B`@
M("`@("`@("`@("1C86-H95LD97AT72`](&5X=&5N<VEO;E]L;V%D960H)&5X
M="D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-A8VAE6R1E>'1=.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!A(&1E9F%U;'0@8VAA<G-E="!T
M:&%T('1H92!3=')I;F<Z.B!M971H;V1S('=I;&P@=7-E(&EF(&YO;F4@:7,*
M("`@("`J(&5X<&QI8VET96QY('-P96-I9FEE9"X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1C:&%R<V5T("!4:&4@8VAA<G-E="!T;R!U<V4@87,@
M=&AE(&1E9F%U;'0@;VYE+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971$969A
M=6QT0VAA<G-E="@D8VAA<G-E="D*("`@('L*("`@("`@("`D1TQ/0D%,4ULG
M7TA/4D1%7U-44DE.1U]#2$%24T54)UT@/2`D8VAA<G-E=#L*("`@("`@("!I
M9B`H4W1R:6YG.CIE>'1E;G-I;VY%>&ES=',H)VUB<W1R:6YG)RD@)B8*("`@
M("`@("`@("`@9G5N8W1I;VY?97AI<W1S*"=M8E]R96=E>%]E;F-O9&EN9R<I
M*2!["B`@("`@("`@("`@($!M8E]R96=E>%]E;F-O9&EN9R@D8VAA<G-E="D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@82!S
M=')I;F<@9G)O;2!O;F4@8VAA<G-E="!T;R!A;F]T:&5R+@H@("`@("H*("`@
M("`J(%=O<FMS(&]N;'D@:68@96ET:&5R('1H92!I8V]N=B!O<B!T:&4@;6)S
M=')I;F<@97AT96YS:6]N"B`@("`@*B!A<F4@<')E<V5N="!A;F0@8F5S="!I
M9B!B;W1H(&%R92!A=F%I;&%B;&4N"B`@("`@*B!4:&4@;W)I9VEN86P@<W1R
M:6YG(&ES(')E='5R;F5D(&EF(&-O;G9E<G-I;VX@9F%I;&5D(&]R(&YO;F4*
M("`@("`J(&]F('1H92!E>'1E;G-I;VYS('=E<F4@879A:6QA8FQE+@H@("`@
M("H*("`@("`J($!P87)A;2!M:7AE9"`D:6YP=70@(%1H92!D871A('1O(&)E
M(&-O;G9E<G1E9"X@268@)&EN<'5T(&ES(&%N(&%N(&%R<F%Y+`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@=&AE(&%R<F%Y)W,@=F%L=65S(&=E="!C
M;VYV97)T960@<F5C=7)S:79E;'DN"B`@("`@*B!`<&%R86T@<W1R:6YG("1F
M<F]M("!4:&4@<W1R:6YG)W,@8W5R<F5N="!C:&%R<V5T+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=&\@("`@5&AE(&-H87)S970@=&\@8V]N=F5R="!T:&4@
M<W1R:6YG('1O+B!)9B!N;W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M('-P96-I9FEE9"P@=&AE(&=L;V)A;"!V87)I86)L90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@)%](3U)$15]35%))3D=?0TA!4E-%5"!W:6QL(&)E
M('5S960N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C;VYV
M97)T960@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYV97)T0VAA
M<G-E="@D:6YP=70L("1F<F]M+"`D=&\@/2!N=6QL*0H@("`@>PH@("`@("`@
M("\J($=E="!T:&4@=7-E<B=S(&1E9F%U;'0@8VAA<F%C=&5R('-E="!I9B!N
M;VYE('!A<W-E9"!I;BX@*B\*("`@("`@("!I9B`H:7-?;G5L;"@D=&\I*2![
M"B`@("`@("`@("`@("1T;R`]("1'3$]"04Q36R=?2$]21$5?4U1224Y'7T-(
M05)3150G73L*("`@("`@("!]"@H@("`@("`@("\J($EF('1H92!F<F]M(&%N
M9"!T;R!C:&%R86-T97(@<V5T<R!A<F4@:61E;G1I8V%L+"!R971U<FX@;F]W
M+B`J+PH@("`@("`@("1F<F]M(#T@4W1R:6YG.CIL;W=E<B@D9G)O;2D["B`@
M("`@("`@)'1O(#T@4W1R:6YG.CIL;W=E<B@D=&\I.PH@("`@("`@(&EF("@D
M9G)O;2`]/2`D=&\I('L*("`@("`@("`@("`@<F5T=7)N("1I;G!U=#L*("`@
M("`@("!]"@H@("`@("`@(&EF("AI<U]A<G)A>2@D:6YP=70I*2!["B`@("`@
M("`@("`@("1T;7`@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D
M:6YP=70@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("`D=&UP
M6U-T<FEN9SHZ7V-O;G9E<G1#:&%R<V5T*"1K97DL("1F<F]M+"`D=&\I72`]
M(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'9A;"P@)&9R;VTL("1T;RD["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1T;7`["B`@("`@("`@
M?0H@("`@("`@(&EF("AI<U]O8FIE8W0H)&EN<'5T*2D@>PH@("`@("`@("`@
M("`D=F%R<R`](&=E=%]O8FIE8W1?=F%R<R@D:6YP=70I.PH@("`@("`@("`@
M("!F;W)E86-H("@D=F%R<R!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@
M("`@("`@("1I;G!U="T^)&ME>2`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H
M)'9A;"P@)&9R;VTL("1T;RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M<F5T=7)N("1I;G!U=#L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?<W1R
M:6YG*"1I;G!U="DI('L*("`@("`@("`@("`@<F5T=7)N("1I;G!U=#L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!3=')I;F<Z.E]C;VYV97)T0VAA<G-E
M="@D:6YP=70L("1F<F]M+"`D=&\I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M26YT97)N86P@9G5N8W1I;VX@=7-E9"!T;R!D;R!C:&%R<V5T(&-O;G9E<G-I
M;VXN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M(&UI>&5D("1I;G!U="`@4V5E(%-T<FEN9SHZ8V]N=F5R=$-H
M87)S970H*2X*("`@("`J($!P87)A;2!S=')I;F<@)&9R;VT@(%-E92!3=')I
M;F<Z.F-O;G9E<G1#:&%R<V5T*"DN"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M;R`@("!3964@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@I+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]N=F5R=&5D('-T<FEN9RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V-O;G9E<G1#:&%R<V5T*"1I;G!U="P@)&9R
M;VTL("1T;RD*("`@('L*("`@("`@("`D;W5T<'5T(#T@)R<["@H@("`@("`@
M("\J(%5S92!U=&8X7UME;GQD95UC;V1E*"D@:68@<&]S<VEB;&4N("HO"B`@
M("`@("`@)&9R;VU?8VAE8VL@/2`H*"1F<F]M(#T]("=I<V\M.#@U.2TQ)RD@
M?'P@*"1F<F]M(#T]("=U<RUA<V-I:2<I*3L*("`@("`@("!I9B`H)&9R;VU?
M8VAE8VL@)B8@*"1T;R`]/2`G=71F+3@G*2D@>PH@("`@("`@("`@("!R971U
M<FX@=71F.%]E;F-O9&4H)&EN<'5T*3L*("`@("`@("!]"@H@("`@("`@("1T
M;U]C:&5C:R`]("@H)'1O(#T]("=I<V\M.#@U.2TQ)RD@?'P@*"1T;R`]/2`G
M=7,M87-C:6DG*2D["B`@("`@("`@:68@*"@D9G)O;2`]/2`G=71F+3@G*2`F
M)B`D=&]?8VAE8VLI('L*("`@("`@("`@("`@<F5T=7)N('5T9CA?9&5C;V1E
M*"1I;G!U="D["B`@("`@("`@?0H*("`@("`@("`O*B!&:7)S="!T<GD@:6-O
M;G8@=VET:"!T<F%N<VQI=&5R871I;VXN("HO"B`@("`@("`@:68@*"@D9G)O
M;2`A/2`G=71F-RUI;6%P)RD@)B8*("`@("`@("`@("`@*"1T;R`A/2`G=71F
M-RUI;6%P)RD@)B8*("`@("`@("`@("`@4W1R:6YG.CIE>'1E;G-I;VY%>&ES
M=',H)VEC;VYV)RDI('L*("`@("`@("`@("`@+RH@5V4@;F5E9"!T;R!T86-K
M(&%N(&5X=')A(&-H87)A8W1E<B!T96UP;W)A<FEL>2!B96-A=7-E"B`@("`@
M("`@("`@("`J(&]F(&$@8G5G(&EN(&EC;VYV*"D@:68@=&AE(&QA<W0@8VAA
M<F%C=&5R(&ES(&YO="!A(#<*("`@("`@("`@("`@("H@8FET($%30TE)(&-H
M87)A8W1E<BX@*B\*("`@("`@("`@("`@:6YI7W-E="@G=')A8VM?97)R;W)S
M)RP@,2D["B`@("`@("`@("`@("1O=71P=70@/2!`:6-O;G8H)&9R;VTL("1T
M;R`N("<O+U1204Y33$E4)RP@)&EN<'5T("X@)W@G*3L*("`@("`@("`@("`@
M)&]U='!U="`]("AI<W-E="@D<&AP7V5R<F]R;7-G*2D@/R!F86QS92`Z("!3
M=')I;F<Z.G-U8G-T<B@D;W5T<'5T+"`P+"`M,2P@)'1O*3L*("`@("`@("`@
M("`@:6YI7W)E<W1O<F4H)W1R86-K7V5R<F]R<R<I.PH@("`@("`@('T*"B`@
M("`@("`@+RH@3F5X="!T<GD@;6)S=')I;F<N("HO"B`@("`@("`@:68@*"$D
M;W5T<'5T("8F(%-T<FEN9SHZ97AT96YS:6]N17AI<W1S*"=M8G-T<FEN9R<I
M*2!["B`@("`@("`@("`@("1O=71P=70@/2!`;6)?8V]N=F5R=%]E;F-O9&EN
M9R@D:6YP=70L("1T;RP@)&9R;VTI.PH@("`@("`@('T*"B`@("`@("`@+RH@
M070@;&%S="!T<GD@:6UA<%]U=&8W7UME;GQD95UC;V1E(&EF(&%P<')O<')I
M871E+B`J+PH@("`@("`@(&EF("@A)&]U='!U="`F)B!3=')I;F<Z.F5X=&5N
M<VEO;D5X:7-T<R@G:6UA<"<I*2!["B`@("`@("`@("`@(&EF("@D9G)O;5]C
M:&5C:R`F)B`H)'1O(#T]("=U=&8W+6EM87`G*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N($!I;6%P7W5T9C=?96YC;V1E*"1I;G!U="D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*"@D9G)O;2`]/2`G=71F-RUI;6%P)RD@
M)B8@)'1O7V-H96-K*2!["B`@("`@("`@("`@("`@("!R971U<FX@0&EM87!?
M=71F-U]D96-O9&4H)&EN<'5T*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("@A)&]U='!U="D@/R`D:6YP=70@.B`D;W5T<'5T
M.PH@("`@?0H*("`@("\J*@H@("`@("H@36%K97,@82!S=')I;F<@;&]W97)C
M87-E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1S=')I;F<@("!4
M:&4@<W1R:6YG('1O(&)E(&-O;G9E<G1E9"X*("`@("`J($!P87)A;2!B;V]L
M96%N("1L;V-A;&4@("!)9B!T<G5E('1H92!S=')I;F<@=VEL;"!B92!C;VYV
M97)T960@8F%S960@;VX@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@(&=I=F5N(&-H87)S970L(&QO8V%L92!I;F1E<&5N9&5N="!E;'-E+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)&-H87)S970@($EF("1L;V-A;&4@:7,@
M=')U92P@=&AE(&-H87)S970@=&\@=7-E('=H96X*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("!C;VYV97)T:6YG+B!)9B!N;W0@<')O=FED960@
M=&AE(&-U<G)E;G0@8VAA<G-E="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE('-T<FEN9R!W:71H(&QO=V5R8V%S92!C:&%R86-T97)S"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&QO=V5R*"1S=')I;F<L("1L;V-A;&4@/2!F
M86QS92P@)&-H87)S970@/2!N=6QL*0H@("`@>PH@("`@("`@('-T871I8R`D
M;&]W97)S.PH*("`@("`@("!I9B`H)&QO8V%L92D@>PH@("`@("`@("`@("`O
M*B!4:&4@97AI<W1E;F-E(&]F(&UB7W-T<G1O;&]W97(H*2!D97!E;F1S(&]N
M('1H92!P;&%T9F]R;2X@*B\*("`@("`@("`@("`@:68@*%-T<FEN9SHZ97AT
M96YS:6]N17AI<W1S*"=M8G-T<FEN9R<I("8F"B`@("`@("`@("`@("`@("!F
M=6YC=&EO;E]E>&ES=',H)VUB7W-T<G1O;&]W97(G*2D@>PH@("`@("`@("`@
M("`@("`@:68@*&ES7VYU;&PH)&-H87)S970I*2!["B`@("`@("`@("`@("`@
M("`@("`@)&-H87)S970@/2`D1TQ/0D%,4ULG7TA/4D1%7U-44DE.1U]#2$%2
M4T54)UT["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<F5T
M(#T@0&UB7W-T<G1O;&]W97(H)'-T<FEN9RP@)&-H87)S970I.PH@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D<F5T*2D@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D<F5T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@("`@(')E='5R;B!S=')T;VQO=V5R*"1S=')I;F<I.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"%I<W-E="@D;&]W97)S*2D@>PH@("`@
M("`@("`@("`D;&]W97)S(#T@87)R87DH*3L*("`@("`@("!]"B`@("`@("`@
M:68@*"%I<W-E="@D;&]W97)S6R1S=')I;F==*2D@>PH@("`@("`@("`@("`D
M;&%N9W5A9V4@/2!S971L;V-A;&4H3$-?0U194$4L(#`I.PH@("`@("`@("`@
M("!S971L;V-A;&4H3$-?0U194$4L("=E;E]54R<I.PH@("`@("`@("`@("`D
M;&]W97)S6R1S=')I;F==(#T@<W1R=&]L;W=E<B@D<W1R:6YG*3L*("`@("`@
M("`@("`@<V5T;&]C86QE*$Q#7T-465!%+"`D;&%N9W5A9V4I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1L;W=E<G-;)'-T<FEN9UT["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!-86ME<R!A('-T<FEN9R!U<'!E<F-A<V4N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-T<FEN9R`@(%1H92!S=')I;F<@
M=&\@8F4@8V]N=F5R=&5D+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&QO8V%L
M92`@($EF('1R=64@=&AE('-T<FEN9R!W:6QL(&)E(&-O;G9E<G1E9"!B87-E
M9"!O;B!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@9VEV96X@
M8VAA<G-E="P@;&]C86QE(&EN9&5P96YD96YT(&5L<V4N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("`D8VAA<G-E="`@268@)&QO8V%L92!I<R!T<G5E+"!T:&4@
M8VAA<G-E="!T;R!U<V4@=VAE;@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@(&-O;G9E<G1I;F<N($EF(&YO="!P<F]V:61E9"!T:&4@8W5R<F5N
M="!C:&%R<V5T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M<W1R:6YG('=I=&@@=7!P97)C87-E(&-H87)A8W1E<G,*("`@("`J+PH@("`@
M9G5N8W1I;VX@=7!P97(H)'-T<FEN9RP@)&QO8V%L92`](&9A;'-E+"`D8VAA
M<G-E="`](&YU;&PI"B`@("!["B`@("`@("`@<W1A=&EC("1U<'!E<G,["@H@
M("`@("`@(&EF("@D;&]C86QE*2!["B`@("`@("`@("`@("\J(%1H92!E>&ES
M=&5N8V4@;V8@;6)?<W1R=&]U<'!E<B@I(&1E<&5N9',@;VX@=&AE"B`@("`@
M("`@("`@("`J('!L871F;W)M+B`J+PH@("`@("`@("`@("!I9B`H9G5N8W1I
M;VY?97AI<W1S*"=M8E]S=')T;W5P<&5R)RDI('L*("`@("`@("`@("`@("`@
M(&EF("AI<U]N=6QL*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1C:&%R<V5T(#T@)$=,3T)!3%-;)U](3U)$15]35%))3D=?0TA!4E-%5"==
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)')E="`]($!M
M8E]S=')T;W5P<&5R*"1S=')I;F<L("1C:&%R<V5T*3L*("`@("`@("`@("`@
M("`@(&EF("@A96UP='DH)')E="DI('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)')E=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!R971U<FX@<W1R=&]U<'!E<B@D<W1R:6YG*3L*("`@("`@
M("!]"@H@("`@("`@(&EF("@A:7-S970H)'5P<&5R<RDI('L*("`@("`@("`@
M("`@)'5P<&5R<R`](&%R<F%Y*"D["B`@("`@("`@?0H@("`@("`@(&EF("@A
M:7-S970H)'5P<&5R<ULD<W1R:6YG72DI('L*("`@("`@("`@("`@)&QA;F=U
M86=E(#T@<V5T;&]C86QE*$Q#7T-465!%+"`P*3L*("`@("`@("`@("`@<V5T
M;&]C86QE*$Q#7T-465!%+"`G96Y?55,G*3L*("`@("`@("`@("`@)'5P<&5R
M<ULD<W1R:6YG72`]('-T<G1O=7!P97(H)'-T<FEN9RD["B`@("`@("`@("`@
M('-E=&QO8V%L92A,0U]#5%E012P@)&QA;F=U86=E*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=7!P97)S6R1S=')I;F==.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!A('-T<FEN9R!W:71H('1H92!F:7)S="!L971T
M97(@8V%P:71A;&EZ960@:68@:70@:7,*("`@("`J(&%L<&AA8F5T:6,N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-T<FEN9R`@(%1H92!S=')I
M;F<@=&\@8F4@8V%P:71A;&EZ960N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M;&]C86QE("`@268@=')U92!T:&4@<W1R:6YG('=I;&P@8F4@8V]N=F5R=&5D
M(&)A<V5D(&]N(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!G
M:79E;B!C:&%R<V5T+"!L;V-A;&4@:6YD97!E;F1E;G0@96QS92X*("`@("`J
M($!P87)A;2!S=')I;F<@("1C:&%R<V5T("!4:&4@8VAA<G-E="!T;R!U<V4L
M(&1E9F%U;'1S('1O(&-U<G)E;G0@8VAA<G-E="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&-A<&ET86QI>F5D('-T<FEN9RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@=6-F:7)S="@D<W1R:6YG+"`D;&]C86QE(#T@9F%L
M<V4L("1C:&%R<V5T(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H)&QO8V%L
M92D@>PH@("`@("`@("`@("`D9FER<W0@/2!3=')I;F<Z.G-U8G-T<B@D<W1R
M:6YG+"`P+"`Q+"`D8VAA<G-E="D["B`@("`@("`@("`@(&EF("A3=')I;F<Z
M.FES06QP:&$H)&9I<G-T+"`D8VAA<G-E="DI('L*("`@("`@("`@("`@("`@
M("1S=')I;F<@/2!3=')I;F<Z.G5P<&5R*"1F:7)S="P@=')U92P@)&-H87)S
M970I("X@4W1R:6YG.CIS=6)S='(H)'-T<FEN9RP@,2P@;G5L;"P@)&-H87)S
M970I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'-T<FEN9R`](%-T<FEN9SHZ=7!P97(H<W5B<W1R*"1S=')I;F<L(#`L
M(#$I+"!F86QS92D@+B!S=6)S='(H)'-T<FEN9RP@,2D["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D<W1R:6YG.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!P87)T(&]F(&$@<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'-T<FEN9R`@(%1H92!S=')I;F<@=&\@8F4@8V]N=F5R=&5D
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'-T87)T("`@5&AE('!A<G0G<R!S
M=&%R="!P;W-I=&EO;BP@>F5R;R!B87-E9"X*("`@("`J($!P87)A;2!I;G1E
M9V5R("1L96YG=&@@(%1H92!P87)T)W,@;&5N9W1H+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8VAA<G-E="`@5&AE(&-H87)S970@=&\@=7-E('=H96X@8V%L
M8W5L871I;F<@=&AE('!A<G0G<PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@<&]S:71I;VX@86YD(&QE;F=T:"P@9&5F875L=',@=&\@8W5R<F5N
M=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@8VAA<G-E="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('-T<FEN9R=S('!A<G0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-U8G-T<B@D<W1R:6YG+"`D<W1A<G0L
M("1L96YG=&@@/2!N=6QL+"`D8VAA<G-E="`](&YU;&PI"B`@("!["B`@("`@
M("`@:68@*%-T<FEN9SHZ97AT96YS:6]N17AI<W1S*"=M8G-T<FEN9R<I*2![
M"B`@("`@("`@("`@(&EF("AI<U]N=6QL*"1C:&%R<V5T*2D@>PH@("`@("`@
M("`@("`@("`@)&-H87)S970@/2`D1TQ/0D%,4ULG7TA/4D1%7U-44DE.1U]#
M2$%24T54)UT["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES7VYU
M;&PH)&QE;F=T:"DI('L*("`@("`@("`@("`@("`@("1L96YG=&@@/2!3=')I
M;F<Z.FQE;F=T:"@D<W1R:6YG+"`D8VAA<G-E="D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)')E="`]($!M8E]S=6)S='(H)'-T<FEN9RP@)'-T87)T
M+"`D;&5N9W1H+"`D8VAA<G-E="D["B`@("`@("`@("`@(&EF("@A96UP='DH
M)')E="DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5T.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("AI<U]N=6QL*"1L96YG=&@I
M*2!["B`@("`@("`@("`@("1L96YG=&@@/2!3=')I;F<Z.FQE;F=T:"@D<W1R
M:6YG*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('-U8G-T<B@D<W1R:6YG
M+"`D<W1A<G0L("1L96YG=&@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@8VAA<F%C=&5R("AN;W0@8GET92D@;&5N9W1H(&]F(&$@<W1R
M:6YG+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T<FEN9R`@5&AE
M('-T<FEN9R!T;R!R971U<FX@=&AE(&QE;F=T:"!O9BX*("`@("`J($!P87)A
M;2!S=')I;F<@)&-H87)S970@5&AE(&-H87)S970@=&\@=7-E('=H96X@8V%L
M8W5L871I;F<@=&AE('-T<FEN9R=S"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@(&QE;F=T:"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE('-T<FEN9R=S('!A<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QE;F=T
M:"@D<W1R:6YG+"`D8VAA<G-E="`](&YU;&PI"B`@("!["B`@("`@("`@:68@
M*&ES7VYU;&PH)&-H87)S970I*2!["B`@("`@("`@("`@("1C:&%R<V5T(#T@
M)$=,3T)!3%-;)U](3U)$15]35%))3D=?0TA!4E-%5"==.PH@("`@("`@('T*
M("`@("`@("`D8VAA<G-E="`](%-T<FEN9SHZ;&]W97(H)&-H87)S970I.PH@
M("`@("`@(&EF("@D8VAA<G-E="`]/2`G=71F+3@G('Q\("1C:&%R<V5T(#T]
M("=U=&8X)RD@>PH@("`@("`@("`@("!R971U<FX@<W1R;&5N*'5T9CA?9&5C
M;V1E*"1S=')I;F<I*3L*("`@("`@("!]"B`@("`@("`@:68@*%-T<FEN9SHZ
M97AT96YS:6]N17AI<W1S*"=M8G-T<FEN9R<I*2!["B`@("`@("`@("`@("1R
M970@/2!`;6)?<W1R;&5N*"1S=')I;F<L("1C:&%R<V5T*3L*("`@("`@("`@
M("`@:68@*"%E;7!T>2@D<F5T*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1R970["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M('-T<FQE;B@D<W1R:6YG*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE(&YU;65R:6,@<&]S:71I;VX@;V8@=&AE(&9I<G-T(&]C8W5R<F5N
M8V4@;V8@)&YE961L90H@("`@("H@:6X@=&AE("1H87ES=&%C:R!S=')I;F<N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:&%Y<W1A8VL@(%1H92!S
M=')I;F<@=&\@<V5A<F-H('1H<F]U9V@N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N965D;&4@("`@5&AE('-T<FEN9R!T;R!S96%R8V@@9F]R+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&]F9G-E="`@($%L;&]W<R!T;R!S<&5C:69Y('=H
M:6-H(&-H87)A8W1E<B!I;B!H87ES=&%C:PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@('1O('-T87)T('-E87)C:&EN9RX*("`@("`J($!P87)A
M;2!S=')I;F<@)&-H87)S970@("!4:&4@8VAA<G-E="!T;R!U<V4@=VAE;B!S
M96%R8VAI;F<@9F]R('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("1N965D;&4@<W1R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@:6YT
M96=E<B`@5&AE('!O<VET:6]N(&]F(&9I<G-T(&]C8W5R<F5N8V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('!O<R@D:&%Y<W1A8VLL("1N965D;&4L("1O9F9S
M970@/2`P+"`D8VAA<G-E="`](&YU;&PI"B`@("!["B`@("`@("`@:68@*%-T
M<FEN9SHZ97AT96YS:6]N17AI<W1S*"=M8G-T<FEN9R<I*2!["B`@("`@("`@
M("`@(&EF("AI<U]N=6QL*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("`@("`@
M)&-H87)S970@/2`D1TQ/0D%,4ULG7TA/4D1%7U-44DE.1U]#2$%24T54)UT[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:6YI7W-E="@G=')A8VM?97)R
M;W)S)RP@,2D["B`@("`@("`@("`@("1R970@/2!`;6)?<W1R<&]S*"1H87ES
M=&%C:RP@)&YE961L92P@)&]F9G-E="P@)&-H87)S970I.PH@("`@("`@("`@
M("!I;FE?<F5S=&]R92@G=')A8VM?97)R;W)S)RD["B`@("`@("`@("`@(&EF
M("@A:7-S970H)'!H<%]E<G)O<FUS9RDI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5T.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E
M='5R;B!S=')P;W,H)&AA>7-T86-K+"`D;F5E9&QE+"`D;V9F<V5T*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!S=')I;F<@<&%D9&5D('1O
M(&$@8V5R=&%I;B!L96YG=&@@=VET:"!A;F]T:&5R('-T<FEN9RX*("`@("`J
M"B`@("`@*B!4:&ES(&UE=&AO9"!B96AA=F5S(&5X86-T;'D@;&EK92!S=')?
M<&%D(&)U="!I<R!M=6QT:6)Y=&4@<V%F92X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1I;G!U="`@("!4:&4@<W1R:6YG('1O(&)E('!A9&1E9"X*
M("`@("`J($!P87)A;2!I;G1E9V5R("1L96YG=&@@(%1H92!L96YG=&@@;V8@
M=&AE(')E<W5L=&EN9R!S=')I;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P
M860@("`@("!4:&4@<W1R:6YG('1O('!A9"!T:&4@:6YP=70@<W1R:6YG('=I
M=&@N($UU<W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&)E(&EN
M('1H92!S86UE(&-H87)S970@;&EK92!T:&4@:6YP=70@<W1R:6YG+@H@("`@
M("H@0'!A<F%M(&-O;G-T("1T>7!E("`@("`@5&AE('!A9&1I;F<@='EP92X@
M3VYE(&]F(%-44E]0041?3$5&5"P*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@(%-44E]0041?4DE'2%0L(&]R(%-44E]0041?0D]42"X*("`@("`J
M($!P87)A;2!S=')I;F<@)&-H87)S970@(%1H92!C:&%R<V5T(&]F('1H92!I
M;G!U="!A;F0@=&AE('!A9&1I;F<*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@('-T<FEN9W,N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!P861D960@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!P860H
M)&EN<'5T+"`D;&5N9W1H+"`D<&%D(#T@)R`G+"`D='EP92`](%-44E]0041?
M4DE'2%0L"B`@("`@("`@("`@("`@("`@)&-H87)S970@/2!N=6QL*0H@("`@
M>PH@("`@("`@("1M8E]L96YG=&@@/2!3=')I;F<Z.FQE;F=T:"@D:6YP=70L
M("1C:&%R<V5T*3L*("`@("`@("`D<V)?;&5N9W1H(#T@<W1R;&5N*"1I;G!U
M="D["B`@("`@("`@)'!A9%]L96YG=&@@/2!3=')I;F<Z.FQE;F=T:"@D<&%D
M+"`D8VAA<G-E="D["@H@("`@("`@("\J(%)E='5R;B!I9B!W92!A;')E861Y
M(&AA=F4@=&AE(&QE;F=T:"X@*B\*("`@("`@("!I9B`H)&UB7VQE;F=T:"`^
M/2`D;&5N9W1H*2!["B`@("`@("`@("`@(')E='5R;B`D:6YP=70["B`@("`@
M("`@?0H*("`@("`@("`O*B!3:&]R=&-U="!F;W(@<VEN9VQE(&)Y=&4@<W1R
M:6YG<RX@*B\*("`@("`@("!I9B`H)&UB7VQE;F=T:"`]/2`D<V)?;&5N9W1H
M("8F("1P861?;&5N9W1H(#T]('-T<FQE;B@D<&%D*2D@>PH@("`@("`@("`@
M("!R971U<FX@<W1R7W!A9"@D:6YP=70L("1L96YG=&@L("1P860L("1T>7!E
M*3L*("`@("`@("!]"@H@("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@
M("!C87-E(%-44E]0041?3$5&5#H*("`@("`@("`@("`@)&QE9G0@/2`D;&5N
M9W1H("T@)&UB7VQE;F=T:#L*("`@("`@("`@("`@)&]U='!U="`](%-T<FEN
M9SHZ<W5B<W1R*'-T<E]R97!E870H)'!A9"P@8V5I;"@D;&5F="`O("1P861?
M;&5N9W1H*2DL(#`L("1L969T+"`D8VAA<G-E="D@+B`D:6YP=70["B`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@4U127U!!1%]"3U1(.@H@("`@
M("`@("`@("`D;&5F="`](&9L;V]R*"@D;&5N9W1H("T@)&UB7VQE;F=T:"D@
M+R`R*3L*("`@("`@("`@("`@)')I9VAT(#T@8V5I;"@H)&QE;F=T:"`M("1M
M8E]L96YG=&@I("\@,BD["B`@("`@("`@("`@("1O=71P=70@/2!3=')I;F<Z
M.G-U8G-T<BAS=')?<F5P96%T*"1P860L(&-E:6PH)&QE9G0@+R`D<&%D7VQE
M;F=T:"DI+"`P+"`D;&5F="P@)&-H87)S970I("X*("`@("`@("`@("`@("`@
M("1I;G!U="`N"B`@("`@("`@("`@("`@("!3=')I;F<Z.G-U8G-T<BAS=')?
M<F5P96%T*"1P860L(&-E:6PH)')I9VAT("\@)'!A9%]L96YG=&@I*2P@,"P@
M)')I9VAT+"`D8VAA<G-E="D["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M(&-A<V4@4U127U!!1%]224=(5#H*("`@("`@("`@("`@)')I9VAT(#T@)&QE
M;F=T:"`M("1M8E]L96YG=&@["B`@("`@("`@("`@("1O=71P=70@/2`D:6YP
M=70@+B!3=')I;F<Z.G-U8G-T<BAS=')?<F5P96%T*"1P860L(&-E:6PH)')I
M9VAT("\@)'!A9%]L96YG=&@I*2P@,"P@)')I9VAT+"`D8VAA<G-E="D["B`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O
M=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!7<F%P<R!T:&4@=&5X="!O
M9B!A(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0'1O9&\@36%K92!M=6QT:6)Y
M=&4M<V%V92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@
M("`@("!3=')I;F<@8V]N=&%I;FEN9R!T:&4@=&5X="!T;R!W<F%P+@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&QE;F=T:"`@("`@5W)A<"`D=&5X="!A="!T
M:&ES(&YU;6)E<B!O9B!C:&%R86-T97)S+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D8G)E86M?8VAA<B`@0VAA<F%C=&5R*',I('1O('5S92!W:&5N(&)R96%K
M:6YG(&QI;F5S+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VAA<G-E="`@("`@
M0VAA<F%C=&5R('-E="!T;R!U<V4@=VAE;B!B<F5A:VEN9R!L:6YE<RX*("`@
M("`J($!P87)A;2!B;V]L96%N("1Q=6]T92`@("`@($EG;F]R92!L:6YE<R!T
M:&%T(&%R92!W<F%P<&5D('=I=&@@=&AE("<^)PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8VAA<F%C=&5R("A21D,@,C8T-BD_($EF('1R
M=64L('=E(&1O;B=T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!R96UO=F4@86YY('!A9&1I;F<@=VAI=&5S<&%C92!A="!T:&4@96YD(&]F
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@<W1R:6YG
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!3=')I;F<@8V]N=&%I
M;FEN9R!T:&4@=W)A<'!E9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!W
M<F%P*"1T97AT+"`D;&5N9W1H(#T@.#`L("1B<F5A:U]C:&%R(#T@(EQN(BP@
M)&-H87)S970@/2!N=6QL+`H@("`@("`@("`@("`@("`@("`D<75O=&4@/2!F
M86QS92D*("`@('L*("`@("`@("`D<&%R86=R87!H<R`](&%R<F%Y*"D["@H@
M("`@("`@(&9O<F5A8V@@*'!R96=?<W!L:70H)R]<<C]<;B\G+"`D=&5X="D@
M87,@)&EN<'5T*2!["B`@("`@("`@("`@(&EF("@D<75O=&4@)B8@*'-T<G!O
M<R@D:6YP=70L("<^)RD@/3T](#`I*2!["B`@("`@("`@("`@("`@("`D;&EN
M92`]("1I;G!U=#L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("\J(%=E(&YE960@=&\@:&%N9&QE('1H92!5<V5N970M<W1Y;&4@<VEG
M;F%T=7)E(&QI;F4*("`@("`@("`@("`@("`@("`J('-E<&%R871E;'D[('-I
M;F-E('1H92!S<&%C92!A9G1E<B!T:&4@='=O(&1A<VAE<R!I<PH@("`@("`@
M("`@("`@("`@("H@4D5154E2140L('=E(&1O;B=T('=A;G0@=&\@=')I;2!T
M:&4@;&EN92X@*B\*("`@("`@("`@("`@("`@(&EF("@D:6YP=70@(3T@)RTM
M("<I('L*("`@("`@("`@("`@("`@("`@("`D:6YP=70@/2!R=')I;2@D:6YP
M=70I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&QI;F4@
M/2!W;W)D=W)A<"@D:6YP=70L("1L96YG=&@L("1B<F5A:U]C:&%R*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)'!A<F%G<F%P:'-;72`]("1L:6YE
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&EM<&QO9&4H)&)R96%K7V-H
M87(L("1P87)A9W)A<&AS*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=')U92!I9B!T:&4@979E<GD@8VAA<F%C=&5R(&EN('1H92!P87)A;65T
M97(@:7,@86X*("`@("`J(&%L<&AA8F5T:6,@8VAA<F%C=&5R+B!4:&ES(&UE
M=&AO9"!D;V5S;B=T('=O<FL@=VET:"!A;GD@8VAA<G-E=`H@("`@("H@;W1H
M97(@=&AA;B!T:&4@8W5R<F5N="!C:&%R<V5T('EE="X*("`@("`J"B`@("`@
M*B!`<&%R86T@)'-T<FEN9R`@(%1H92!S=')I;F<@=&\@=&5S="X*("`@("`J
M($!P87)A;2`D8VAA<G-E="`@5&AE(&-H87)S970@=&\@=7-E('=H96X@=&5S
M=&EN9R!T:&4@<W1R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5')U92!I9B!T:&4@<&%R86UE=&5R('=A<R!A;'!H86)E=&EC(&]N;'DN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES06QP:&$H)'-T<FEN9RP@)&-H87)S
M970@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("A3=')I;F<Z.F5X=&5N<VEO
M;D5X:7-T<R@G;6)S=')I;F<G*2D@>PH@("`@("`@("`@("`D;VQD7V-H87)S
M970@/2!M8E]R96=E>%]E;F-O9&EN9R@I.PH@("`@("`@("`@("!I9B`H)&-H
M87)S970@(3T@)&]L9%]C:&%R<V5T*2!["B`@("`@("`@("`@("`@("!`;6)?
M<F5G97A?96YC;V1I;F<H)&-H87)S970I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1A;'!H82`]("%M8E]E<F5G7VUA=&-H*"=;7ELZ86QP:&$Z75TG
M+"`D<W1R:6YG*3L*("`@("`@("`@("`@:68@*"1C:&%R<V5T("$]("1O;&1?
M8VAA<G-E="D@>PH@("`@("`@("`@("`@("`@0&UB7W)E9V5X7V5N8V]D:6YG
M*"1O;&1?8VAA<G-E="D["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T
M=7)N("1A;'!H83L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!C='EP95]A
M;'!H82@D<W1R:6YG*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=')U92!I9B!E=F5R>2!C:&%R86-T97(@:6X@=&AE('!A<F%M971E<B!I<R!A
M(&QO=V5R8V%S90H@("`@("H@;&5T=&5R(&EN('1H92!C=7)R96YT(&QO8V%L
M92X*("`@("`J"B`@("`@*B!`<&%R86T@)'-T<FEN9R`@(%1H92!S=')I;F<@
M=&\@=&5S="X*("`@("`J($!P87)A;2`D8VAA<G-E="`@5&AE(&-H87)S970@
M=&\@=7-E('=H96X@=&5S=&EN9R!T:&4@<W1R:6YG+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@<&%R86UE=&5R('=A<R!L
M;W=E<F-A<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES3&]W97(H)'-T<FEN
M9RP@)&-H87)S970@/2!N=6QL*0H@("`@>PH@("`@("`@(')E='5R;B`H*%-T
M<FEN9SHZ;&]W97(H)'-T<FEN9RP@=')U92P@)&-H87)S970I(#T]/2`D<W1R
M:6YG*2`F)@H@("`@("`@("`@("`@("`@4W1R:6YG.CII<T%L<&AA*"1S=')I
M;F<L("1C:&%R<V5T*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1R=64@:68@979E<GD@8VAA<F%C=&5R(&EN('1H92!P87)A;65T97(@:7,@
M86X*("`@("`J('5P<&5R8V%S92!L971T97(@:6X@=&AE(&-U<G)E;G0@;&]C
M86QE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T<FEN9R`@(%1H
M92!S=')I;F<@=&\@=&5S="X*("`@("`J($!P87)A;2!S=')I;F<@)&-H87)S
M970@(%1H92!C:&%R<V5T('1O('5S92!W:&5N('1E<W1I;F<@=&AE('-T<FEN
M9RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE
M('!A<F%M971E<B!W87,@=7!P97)C87-E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!I<U5P<&5R*"1S=')I;F<L("1C:&%R<V5T(#T@;G5L;"D*("`@('L*("`@
M("`@("!R971U<FX@*"A3=')I;F<Z.G5P<&5R*"1S=')I;F<L('1R=64L("1C
M:&%R<V5T*2`]/3T@)'-T<FEN9RD@)B8*("`@("`@("`@("`@("`@(%-T<FEN
M9SHZ:7-!;'!H82@D<W1R:6YG+"`D8VAA<G-E="DI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4&5R9F]R;7,@82!M=6QT:6)Y=&4@<V%F92!R96=E>"!M871C
M:"!S96%R8V@@;VX@=&AE('1E>'0@<')O=FED960N"B`@("`@*@H@("`@("H@
M0'-I;F-E($AO<F1E(#,N,0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'1E>'0@("`@(%1H92!T97AT('1O('-E87)C:"X*("`@("`J($!P87)A;2!A
M<G)A>2`D<F5G97@@("`@(%1H92!R96=U;&%R(&5X<')E<W-I;VYS('1O('5S
M92P@=VET:&]U="!P97)L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!R96=E>"!D96QI;6ET97)S("AE+F<N("<O)R!O<B`G?"<I+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8VAA<G-E="`@5&AE(&-H87)A8W1E<B!S970@;V8@
M=&AE('1E>'0N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&UA
M=&-H97,@87)R87D@9G)O;2!T:&4@9FER<W0@<F5G97@@=&AA="!M871C:&5S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96=E>$UA=&-H*"1T97AT+"`D<F5G
M97@L("1C:&%R<V5T(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y
M*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("`D<F5G97@@/2!3=')I;F<Z.F-O
M;G9E<G1#:&%R<V5T*"1R96=E>"P@)&-H87)S970L("=U=&8M."<I.PH@("`@
M("`@("`@("`D=&5X="`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'1E>'0L
M("1C:&%R<V5T+"`G=71F+3@G*3L*("`@("`@("!]"@H@("`@("`@("1M871C
M:&5S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D<F5G97@@87,@)'9A
M;"D@>PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+R<@+B`D=F%L("X@
M)R]U)RP@)'1E>'0L("1M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP
M='DH)&-H87)S970I*2!["B`@("`@("`@("`@("1M871C:&5S(#T@4W1R:6YG
M.CIC;VYV97)T0VAA<G-E="@D;6%T8VAE<RP@)W5T9BTX)RP@)&-H87)S970I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1M871C:&5S.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E
M;7!L871E+G!H<```````````````````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`U,C4V-P`Q,#4Q-30S,S<U,@`P,C$W-C<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J($AO<F1E(%1E
M;7!L871E('-Y<W1E;2X@061A<'1E9"!F<F]M(&)496UP;&%T92!B>2!"<FEA
M;B!,;WII97(*("H@/&)R:6%N0&UA<W-A<W-I+FYE=#XN"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<"QV(#$N,S@N,3`N
M,3`@,C`P-B\P-B\Q,R`P,SHU-#HP,R!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@
M*B!`<&%C:V%G92!(;W)D95]496UP;&%T90H@*B\*8VQA<W,@2&]R9&5?5&5M
M<&QA=&4@>PH*("`@("\J*@H@("`@("H@3W!T:6]N('9A;'5E<RX*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V]P=&EO;G,@
M/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@1&ER96-T;W)Y('1H870@=&5M
M<&QA=&5S('-H;W5L9"!B92!R96%D(&9R;VTN"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8F%S97!A=&@@/2`G)SL*"B`@
M("`O*BH*("`@("`J(%)E<V5T('1E;7!L871E('9A<FEA8FQE<R!A9G1E<B!P
M87)S:6YG/PH@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@
M("!V87(@)%]R97-E=%9A<G,@/2!T<G5E.PH*("`@("\J*@H@("`@("H@5&%G
M("AS8V%L87(I('9A;'5E<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D7W-C86QA<G,@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@3&]O<"!T86<@=F%L=65S+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?87)R87ES(#T@87)R87DH*3L*"B`@("`O
M*BH*("`@("`J($-L;V]P('1A9R!V86QU97,N"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]C87)R87ES(#T@87)R87DH*3L*
M"B`@("`O*BH*("`@("`J($EF('1A9R!V86QU97,N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]I9G,@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@3F%M92!O9B!C86-H960@=&5M<&QA=&4@9FEL92X*
M("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]T
M96UP;&%T949I;&4@/2!N=6QL.PH*("`@("\J*@H@("`@("H@0V%C:&5D('-O
M=7)C92!O9B!T96UP;&%T92!F:6QE+@H@("`@("H*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D7W1E;7!L871E(#T@;G5L;#L*"B`@("`O
M*BH*("`@("`J($-O;G-T<G5C=&]R+B!#86X@<V5T('1H92!T96UP;&%T92!B
M87-E('!A=&@@86YD('=H971H97(@;W(@;F]T"B`@("`@*B!T;R!D<F]P('1E
M;7!L871E('9A<FEA8FQE<R!A9G1E<B!A('!A<G-I;F<@82!T96UP;&%T92X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8F%S97!A=&@@("!4:&4@
M9&ER96-T;W)Y('=H97)E('1E;7!L871E<R!A<F4@<F5A9"!F<F]M+@H@("`@
M("H@0'!A<F%M(&)O;VQE86X@)')E<V5T5F%R<R`@1')O<"!T96UP;&%T92!V
M87)S(&%F=&5R('!A<G-I;F<@82!T96UP;&%T93\*("`@("`J+PH@("`@9G5N
M8W1I;VX@2&]R9&5?5&5M<&QA=&4H)&)A<V5P871H(#T@;G5L;"P@)')E<V5T
M5F%R<R`]('1R=64I"B`@("!["B`@("`@("`@:68@*"%I<U]N=6QL*"1B87-E
M<&%T:"DI('L*("`@("`@("`@("`@)'1H:7,M/E]B87-E<&%T:"`]("1B87-E
M<&%T:#L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]R97-E=%9A<G,@/2`H
M8F]O;"DD<F5S971687)S.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!A
M;B!O<'1I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;W!T:6]N
M("!4:&4@;W!T:6]N(&YA;64N"B`@("`@*B!`<&%R86T@;6EX960@("1V86P@
M("`@(%1H92!O<'1I;VXG<R!V86QU92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T3W!T:6]N*"1O<'1I;VXL("1V86PI"B`@("!["B`@("`@("`@)'1H:7,M
M/E]O<'1I;VYS6R1O<'1I;VY=(#T@)'9A;#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E="!T:&4@=&5M<&QA=&4@8V]N=&5N=',@=&\@82!S=')I;F<N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5M<&QA=&4@(%1H92!T96UP
M;&%T92!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971496UP;&%T92@D
M=&5M<&QA=&4I"B`@("!["B`@("`@("`@)'1H:7,M/E]T96UP;&%T92`]("1T
M96UP;&%T93L*("`@("`@("`D=&AI<RT^7W1E;7!L871E1FEL92`]("=S=')I
M;F<G.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!O<'1I;VXG
M<R!V86QU92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O<'1I;VX@
M(%1H92!O<'1I;VX@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4:&4@;W!T:6]N)W,@=F%L=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$]P=&EO;B@D;W!T:6]N*0H@("`@>PH@("`@("`@(')E='5R;B!I<W-E="@D
M=&AI<RT^7V]P=&EO;G-;)&]P=&EO;ETI(#\@)'1H:7,M/E]O<'1I;VYS6R1O
M<'1I;VY=(#H@;G5L;#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@82!T
M86<L(&QO;W`L(&]R(&EF('9A<FEA8FQE+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F=\87)R87D@)'1A9R`@($5I=&AE<B!T:&4@=&%G(&YA;64@;W(@
M82!H87-H('=I=&@@=&%G(&YA;65S"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<R!K97ES(&%N9"!T86<@=F%L=65S(&%S('9A;'5E<RX*
M("`@("`J($!P87)A;2!M:7AE9"`@("`@("`@)'9A<B`@(%1H92!V86QU92!T
M;R!R97!L86-E('1H92!T86<@=VET:"X*("`@("`J($!P87)A;2!B;V]L96%N
M("`@("`@)&ES268@($ES('1H:7,@9F]R(&%N(#QI9CH^('1A9S\@*$1E9F%U
M;'0Z(&YO*2X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T*"1T86<L("1V87(L
M("1I<TEF(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1T
M86<I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1T86<@87,@)'1486<@/3X@
M)'1687(I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS970H)'1486<L("1T
M5F%R+"`D:7-)9BD["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H
M:7-?87)R87DH)'9A<BD@?'P@:7-?;V)J96-T*"1V87(I*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?87)R87ES6R1T86==(#T@)'9A<CL*("`@("`@("`@("`@
M:68@*"1I<TEF*2!["B`@("`@("`@("`@("`@("`O+R!*=7-T('-T;W)E('1H
M92!S86UE('9A<FEA8FQE('1H870@=V4@<W1O<F5D(&EN"B`@("`@("`@("`@
M("`@("`O+R`D=&AI<RT^7V%R<F%Y<R`M(&EF('=E(&1O;B=T(&UO9&EF>2!I
M="P@4$A0)W,*("`@("`@("`@("`@("`@("\O(')E9F5R96YC92!C;W5N=&EN
M9R!E;G-U<F5S('=E)W)E(&YO="!U<VEN9R!A;GD*("`@("`@("`@("`@("`@
M("\O(&%D9&ET:6]N86P@;65M;W)Y(&AE<F4N"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7VEF<ULD=&%G72`]("1V87(["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7W-C86QA<G-;)'1A9UT@
M/2`D=F%R.PH@("`@("`@("`@("!I9B`H)&ES268I('L*("`@("`@("`@("`@
M("`@("\O($IU<W0@<W1O<F4@=&AE('-A;64@=F%R:6%B;&4@=&AA="!W92!S
M=&]R960@:6X*("`@("`@("`@("`@("`@("\O("1T:&ES+3Y?<V-A;&%R<R`M
M(&EF('=E(&1O;B=T(&UO9&EF>2!I="P@4$A0)W,*("`@("`@("`@("`@("`@
M("\O(')E9F5R96YC92!C;W5N=&EN9R!E;G-U<F5S('=E)W)E(&YO="!U<VEN
M9R!A;GD*("`@("`@("`@("`@("`@("\O(&%D9&ET:6]N86P@;65M;W)Y(&AE
M<F4N"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEF<ULD=&%G72`]("1V87([
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!V86QU92!O9B!A('1A9R!O<B!L;V]P+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'1A9R`@5&AE('1A9R!N86UE+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!T86<@=F%L=64@;W(@;G5L
M;"!I9B!T:&4@=&%G(&AA<VXG="!B965N('-E="!Y970N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E="@D=&%G*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7V%R<F%Y<ULD=&%G72DI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?87)R87ES6R1T86==.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/E]S8V%L87)S6R1T86==*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]S8V%L87)S6R1T86==.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@;G5L;#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=F%L=65S
M(&9O<B!A(&-L;V]P+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1A
M9R`@(%1H92!N86UE(&]F('1H92!C;&]O<"X*("`@("`J($!P87)A;2!A<G)A
M>2`D87)R87D@(%1H92!V86QU97,@9F]R('1H92!C;&]O<"X*("`@("`J($!P
M87)A;2!A<G)A>2`D8V%S97,@(%1H92!C87-E<R`H=&5S="!V86QU97,I(&9O
M<B!T:&4@8VQO;W!S+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971#;&]O<"@D
M=&%G+"`D87)R87DL("1C87-E<RD*("`@('L*("`@("`@("`D=&AI<RT^7V-A
M<G)A>7-;)'1A9UT@/2!A<G)A>2@*("`@("`@("`@("`@)V%R<F%Y)R`]/B`D
M87)R87DL"B`@("`@("`@("`@("=C87-E<R<@/3X@)&-A<V5S"B`@("`@("`@
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E<V5T<R!T:&4@=&5M<&QA=&4@
M=F%R:6%B;&5S+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1S8V%L
M87)S("!297-E="!S8V%L87(@*&)A<VEC('1A9RD@=F%R:6%B;&5S/PH@("`@
M("H@0'!A<F%M(&)O;VQE86X@)&%R<F%Y<R`@(%)E<V5T(&QO;W`@=F%R:6%B
M;&5S/PH@("`@("H@0'!A<F%M(&)O;VQE86X@)&-A<G)A>7,@(%)E<V5T(&-L
M;V]P('9A<FEA8FQE<S\*("`@("`J($!P87)A;2!B;V]L96%N("1I9G,@("`@
M("!297-E="!I9B!V87)I86)L97,_"B`@("`@*B\*("`@(&9U;F-T:6]N(')E
M<V5T5F%R<R@D<V-A;&%R<RP@)&%R<F%Y<RP@)&-A<G)A>7,L("1I9G,I"B`@
M("!["B`@("`@("`@:68@*"1S8V%L87)S(#T]/2!T<G5E*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?<V-A;&%R<R`](&%R<F%Y*"D["B`@("`@("`@?0H@("`@
M("`@(&EF("@D87)R87ES(#T]/2!T<G5E*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?87)R87ES(#T@87)R87DH*3L*("`@("`@("!]"B`@("`@("`@:68@*"1C
M87)R87ES(#T]/2!T<G5E*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V%R<F%Y
M<R`](&%R<F%Y*"D["B`@("`@("`@?0H@("`@("`@(&EF("@D:69S(#T]/2!T
M<G5E*2!["B`@("`@("`@("`@("1T:&ES+3Y?:69S(#T@87)R87DH*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V92!L:7-T(&]F
M(&)L;V-K<R!P<F5S96YT(&EN('1H92!T96UP;&%T92!S;W5R8V4N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL96YA;64@(%1H92!F:6QE('1O
M(&9E=&-H('1H92!T96UP;&%T92!F<F]M+@H@("`@("H@0')E='5R;B!M:7AE
M9"`@06X@87)R87D@;V8@87!P;&EC871I;VYS+"!O<B!014%27T5R<F]R(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1";&]C:W,H*0H@
M("`@>PH@("`@("`@("1B;&]C:W,@/2!A<G)A>2@I.PH@("`@("`@(&EF("AP
M<F5G7VUA=&-H7V%L;"@G/&)L;V-K.BA;82UZ02U:,"TY7UTK.EMA+7I!+5HP
M+3E?72LI/B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M=&5M<&QA=&4L("1M871C:&5S+"!04D5'7U-%5%]/4D1%4BDI('L*("`@("`@
M("`@("`@9F]R96%C:"`H)&UA=&-H97,@87,@)&UA=&-H*2!["B`@("`@("`@
M("`@("`@("`D8FQO8VMS6UT@/2`D;6%T8VA;,5T["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D8FQO8VMS.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1F5T8VAE<R!A('1E;7!L871E(&9R;VT@=&AE('-P96-I
M9FEE9"!F:6QE(&%N9"!R971U<FX@=&AE('!A<G-E9`H@("`@("H@8V]N=&5N
M=',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL96YA;64@(%1H
M92!F:6QE('1O(&9E=&-H('1H92!T96UP;&%T92!F<F]M+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@<&%R<V5D('1E;7!L871E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!F971C:"@D9FEL96YA;64I"B`@("!["B`@("`@
M("`@)&-O;G1E;G1S(#T@)'1H:7,M/E]G971496UP;&%T92@D9FEL96YA;64I
M.PH@("`@("`@(&EF("AI<U]A*"1C;VYT96YT<RP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&-O;G1E;G1S.PH@("`@("`@('T*"B`@
M("`@("`@+R\@4&%R<V4@86YD(')E='5R;B!T:&4@8V]N=&5N=',N"B`@("`@
M("`@<F5T=7)N("1T:&ES+3YP87)S92@D8V]N=&5N=',I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4&%R<V5S(&%L;"!V87)I86)L97,O=&%G<R!I;B!T:&4@
M=&5M<&QA=&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N
M=',@(%1H92!U;G!A<G-E9"!T96UP;&%T92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE('!A<G-E9"!T96UP;&%T92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<&%R<V4H)&-O;G1E;G1S(#T@;G5L;"D*("`@('L*("`@("`@
M("!I9B`H(21C;VYT96YT<RD@>PH@("`@("`@("`@("`D8V]N=&5N=',@/2`D
M=&AI<RT^7W1E;7!L871E.PH@("`@("`@('T*"B`@("`@("`@+R\@4')O8V5S
M<R!I9G,N"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7VEF<RDI('L*("`@
M("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]I9G,@87,@)'1A9R`]/B`D=F%L
M=64I('L*("`@("`@("`@("`@("`@("1C;VYT96YT<R`]("1T:&ES+3Y?<&%R
M<V5)9B@D=&%G+"`D8V]N=&5N=',I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("`O+R!0<F]C97-S('1A9W,N"B`@("`@("`@)'-E87)C:"`]
M(&%R<F%Y*"D["B`@("`@("`@)')E<&QA8V4@/2!A<G)A>2@I.PH@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?<V-A;&%R<R!A<R`D:V5Y(#T^("1V86QU92D@
M>PH@("`@("`@("`@("`D<V5A<F-H6UT@/2`D=&AI<RT^7V=E=%1A9R@D:V5Y
M*3L*("`@("`@("`@("`@)')E<&QA8V5;72`]("1V86QU93L*("`@("`@("!]
M"B`@("`@("`@:68@*&-O=6YT*"1S96%R8V@I*2!["B`@("`@("`@("`@("1C
M;VYT96YT<R`]('-T<E]R97!L86-E*"1S96%R8V@L("1R97!L86-E+"`D8V]N
M=&5N=',I.PH@("`@("`@('T*"B`@("`@("`@+R\@4')O8V5S<R!L;V]P<R!A
M;F0@87)R87ES+@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?87)R87ES(&%S
M("1K97D@/3X@)&%R<F%Y*2!["B`@("`@("`@("`@("1C;VYT96YT<R`]("1T
M:&ES+3Y?<&%R<V5,;V]P*"1K97DL("1A<G)A>2P@)&-O;G1E;G1S*3L*("`@
M("`@("!]"@H@("`@("`@("\O(%!R;V-E<W,@8VQO;W!S+@H@("`@("`@(&9O
M<F5A8V@@*"1T:&ES+3Y?8V%R<F%Y<R!A<R`D:V5Y(#T^("1A<G)A>2D@>PH@
M("`@("`@("`@("`D8V]N=&5N=',@/2`D=&AI<RT^7W!A<G-E0VQO;W`H)&ME
M>2P@)&%R<F%Y+"`D8V]N=&5N=',I.PH@("`@("`@('T*"B`@("`@("`@+R\@
M4&%R<V4@9V5T=&5X="!T86=S+"!I9B!T:&4@;W!T:6]N(&ES(&5N86)L960N
M"B`@("`@("`@:68@*"1T:&ES+3YG971/<'1I;VXH)V=E='1E>'0G*2D@>PH@
M("`@("`@("`@("`D8V]N=&5N=',@/2`D=&AI<RT^7W!A<G-E1V5T=&5X="@D
M8V]N=&5N=',I.PH@("`@("`@('T*"B`@("`@("`@+R\@4&%R<V4@96UB961D
M960@8FQO8VMS"B`@("`@("`@:68@*"1T:&ES+3YG971/<'1I;VXH)V)L;V-K
M<R<I*2!["B`@("`@("`@("`@("1C;VYT96YT<R`]("1T:&ES+3Y?<&%R<V5"
M;&]C:W,H)&-O;G1E;G1S*3L*("`@("`@("!]"@H@("`@("`@("\O(%)E<V5T
M('1E;7!L871E(&1A=&$@=6YL97-S('=E)W)E('-U<'!O<V5D('1O(&ME97`@
M:70*("`@("`@("`O+R!A<F]U;F0N"B`@("`@("`@:68@*"1T:&ES+3Y?<F5S
M971687)S*2!["B`@("`@("`@("`@("1T:&ES+3YR97-E=%9A<G,H9F%L<V4L
M('1R=64L('1R=64L(&9A;'-E*3L*("`@("`@("!]"@H@("`@("`@("\O(%)E
M='5R;B!P87)S960@=&5M<&QA=&4N"B`@("`@("`@<F5T=7)N("1C;VYT96YT
M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@9G5L;"!S=&%R="!A
M;F0@96YD('1A9W,@9F]R(&$@;F%M960@=&%G+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1A
M9PH@("`@("H@0'!A<F%M('-T<FEN9R`D9&ER96-T:79E("!4:&4@:VEN9"!O
M9B!T86<@+2!T86<L(&EF+"!L;V]P+"!C;&]O<"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("`G8B<@/3X@4W1A<G0@=&%G+@H@("`@("H@("`@("`@
M("`@("`@("`@)V4G(#T^($5N9"!T86<N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]G971486=S*"1T86<L("1D:7)E8W1I=F4I"B`@("!["B`@("`@("`@<F5T
M=7)N(&%R<F%Y*"=B)R`]/B`G/"<@+B`D9&ER96-T:79E("X@)SHG("X@)'1A
M9R`N("<^)RP*("`@("`@("`@("`@("`@("`@("`@)V4G(#T^("<\+R<@+B`D
M9&ER96-T:79E("X@)SHG("X@)'1A9R`N("<^)RD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!&;W)M871S(&$@<V-A;&%R('1A9R`H9&5F875L="!F;W)M870@
M:7,@/'1A9SIN86UE/BDN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&%G("!4:&4@;F%M92!O
M9B!T:&4@=&%G+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M9G5L;"!T86<@=VET:"!T:&4@8W5R<F5N="!S=&%R="]E;F0@9&5L:6UI=&5R
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=%1A9R@D=&%G*0H@("`@>PH@
M("`@("`@(')E='5R;B`G/'1A9SHG("X@)'1A9R`N("<@+SXG.PH@("`@?0H*
M("`@("\J*@H@("`@("H@17AT<F%C=',@82!P;W)T:6]N(&]F(&$@=&5M<&QA
M=&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1T("`@("`@("`@("!4:&4@=&%G('1O(&5X=')A
M8W0N($AA<V@@9F]R;6%T(&ES.@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T6R=B)UT@+2!4:&4@<W1A<G0@=&%G"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1;)V4G72`M(%1H92!E;F0@=&%G
M"B`@("`@*B!`<&%R86T@<W1R:6YG("8D8V]N=&5N=',@(%1H92!T96UP;&%T
M92!T;R!E>'1R86-T(&9R;VTN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G9713
M=&%T96UE;G0H)'0L("8D8V]N=&5N=',I"B`@("!["B`@("`@("`@+R\@3&]C
M871E('1H92!S=&%T96UE;G0N"B`@("`@("`@)'!O<R`]('-T<G!O<R@D8V]N
M=&5N=',L("1T6R=B)UTI.PH@("`@("`@(&EF("@D<&]S(#T]/2!F86QS92D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("`D=&%G7VQE;F=T:"`]('-T<FQE;B@D=%LG8B==*3L*("`@("`@("`D9G!O
M<R`]("1P;W,@*R`D=&%G7VQE;F=T:#L*("`@("`@("`D;'!O<R`]('-T<G!O
M<R@D8V]N=&5N=',L("1T6R=E)UTI.PH@("`@("`@("1L96YG=&@@/2`D;'!O
M<R`M("1F<&]S.PH*("`@("`@("`O+R!%>'1R86-T("8@<F5T=7)N('1H92!S
M=&%T96UE;G0N"B`@("`@("`@<F5T=7)N('-U8G-T<B@D8V]N=&5N=',L("1F
M<&]S+"`D;&5N9W1H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%!A<G-E<R!G
M971T97AT('1A9W,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]N
M=&5N=',@(%1H92!U;G!A<G-E9"!C;VYT96YT(&]F('1H92!F:6QE+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<&%R<V5D(&-O;G1E;G1S
M(&]F('1H92!G971T97AT(&)L;V-K<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M7W!A<G-E1V5T=&5X="@D8V]N=&5N=',I"B`@("!["B`@("`@("`@+R\@1V5T
M('1H92!T86=S("8@;&]O<"X*("`@("`@("`D="`](&%R<F%Y*"=B)R`]/B`G
M/&=E='1E>'0^)RP*("`@("`@("`@("`@("`@("`@("=E)R`]/B`G/"]G971T
M97AT/B<I.PH@("`@("`@('=H:6QE("@D=&5X="`]("1T:&ES+3Y?9V5T4W1A
M=&5M96YT*"1T+"`D8V]N=&5N=',I*2!["B`@("`@("`@("`@("1C;VYT96YT
M<R`]('-T<E]R97!L86-E*"1T6R=B)UT@+B`D=&5X="`N("1T6R=E)UTL(%\H
M)'1E>'0I+"`D8V]N=&5N=',I.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)&-O;G1E;G1S.PH@("`@?0H*("`@("\J*@H@("`@("H@4&%R<V5S(&)L;V-K
M('1A9W,N"B`@("`@*@H@("`@("H@2&5R92!W92!P87)S92!B;&]C:R!T86=S
M(&EN('1H92!F;W)M.@H@("`@("H*("`@("`J("`\8FQO8VLZ87!P.FYA;64^
M"B`@("`@*B`@(#QP87)A;3IF;V\^9F]O('!A<F%M971E<B=S('9A;'5E/"]P
M87)A;3IF;V\^"B`@("`@*B`@(#QP87)A;3IB87(^8F%R('!A<F%M971E<B=S
M('9A;'5E/"]P87)A;3IB87(^"B`@("`@*B`@(#QS97)I86PZ8F%Z/G,Z,C$Z
M(F)A>B!P87)A;65T97(G<R!V86QU92([/"]S97)I86PZ8F%Z/@H@("`@("H@
M(#PO8FQO8VLZ87!P.FYA;64^"B`@("`@*@H@("`@("H@+BXN(&%N9"!R97!L
M86-E('1H96T@=VET:"!R96YD97)E9"!A<'!L:6-A=&EO;B!B;&]C:W,N"B`@
M("`@*@H@("`@("H@0FQO8VL@<&%R86UE=&5R<R!A<F4@<')O=FED960@=VET
M:"!T:&4@;F5S=&5D(")P87)A;3IF;V\B(&%N9`H@("`@("H@(G-E<FEA;#IF
M;V\B('1A9W,N("!4:&4@<V5R:6%L+7-T>6QE('1A9W,@=&%K92!A('-E<FEA
M;&EZ960@4$A0"B`@("`@*B!V86QU92P@<V\@>6]U(&-A;B!U<V4@:70@=&\@
M<')O=FED92!A<G)A>2P@8F]O;&5A;BP@86YD(&-O;7!L97@*("`@("`J('1Y
M<&4@<&%R86UE=&5R<RX@(%1H92!P87)A;2US='EL92!T86=S('!R;W9I9&4@
M<W1R:6YG('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N=',@(%1H
M92!U;G!A<G-E9"!C;VYT96YT<R!O9B!T:&4@9FEL92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE('!A<G-E9"!C;VYT96YT<R!O9B!T:&4@
M9FEL92X*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E0FQO8VMS*"1C;VYT
M96YT<RD*("`@('L*("`@("`@("!R971U<FX@<')E9U]R97!L86-E*"<A/&)L
M;V-K.BA;82UZ02U:7S`M.5TK*3HH6V$M>D$M6E\P+3E=*RD^*"XJ/RDG("X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("<\+V)L;V-K.BA;82UZ02U:
M7S`M.5TK*3HH6V$M>D$M6E\P+3E=*RD^(7-E)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(")<)'1H:7,M/E]P87)S94)L;V-K*"=<7#$G+"`G7%PR
M)RP@)UQ<,R<I(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VYT
M96YT<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!(86YD;&4@=&AE(&-O;G1E
M;G1S(&]F(&]N92!B;&]C:R!T86<N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S94)L;V-K*"1A<'`L
M("1N86UE+"`D8V]N=&5N=',I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92]";&]C:RYP:'`G.PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`G.PH*("`@("`@("`O+R!5;F1O('!R
M96=?<F5P;&%C92@I(&5N8V]D:6YG('-T<F%N9V5N97-S+@H@("`@("`@("1C
M;VYT96YT<R`]('-T<E]R97!L86-E*"=<7"(G+"`G(B<L("1C;VYT96YT<RD[
M"@H@("`@("`@("\O($9I;F0@8FQO8VLG<R!P87)A;65T97)S+@H@("`@("`@
M("1P87)A;7,@/2!A<G)A>2@I.PH@("`@("`@(&EF("AP<F5G7VUA=&-H7V%L
M;"@G(3QP87)A;3HH6V$M>D$M6E\P+3E=*RD^*"XJ/RDG("X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)SPO<&%R86TZ*%MA+7I!+5I?,"TY72LI/B%S
M)RP@)&-O;G1E;G1S+"`D;6%T8VAE<RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@4%)%1U]3151?3U)$15(I*2!["B`@("`@("`@("`@(&9O<F5A8V@@
M*"1M871C:&5S(&%S("1M871C:"D@>PH@("`@("`@("`@("`@("`@)'!A<F%M
M<ULD;6%T8VA;,5U=(#T@:'1M;%]E;G1I='E?9&5C;V1E*"1M871C:%LR72D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*'!R96=?;6%T
M8VA?86QL*"<A/'-E<FEA;#HH6V$M>D$M6E\P+3E=*RD^*"XJ/RDG("X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)SPO<V5R:6%L.BA;82UZ02U:7S`M
M.5TK*3XA<R<L("1C;VYT96YT<RP@)&UA=&-H97,L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%!214=?4T547T]21$52*2D@>PH@("`@("`@("`@("!F
M;W)E86-H("@D;6%T8VAE<R!A<R`D;6%T8V@I('L*("`@("`@("`@("`@("`@
M("1P87)A;7-;)&UA=&-H6S%=72`]('5N<V5R:6%L:7IE*&AT;6Q?96YT:71Y
M7V1E8V]D92@D;6%T8VA;,ETI*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+R\@0V]N<W1R=6-T('1H92!B;&]C:RX*("`@("`@("`D8FQO
M8VL@/2`F2&]R9&5?0FQO8VM?0V]L;&5C=&EO;CHZ9V5T0FQO8VLH)&%P<"P@
M)&YA;64L("1P87)A;7,I.PH@("`@("`@(&EF("AI<U]A*"1B;&]C:RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@)SQS=')O;F<^
M)R`N('-P<FEN=&8H7R@B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&)L;V-K+3YG
M971-97-S86=E*"DI("X@)SPO<W1R;VYG/B<["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)')E<W5L="`]("1B;&]C:RT^9V5T0V]N=&5N="@I.PH@
M("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)SQS=')O;F<^)R`N('-P<FEN
M=&8H7R@B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5S=6QT+3YG971-
M97-S86=E*"DI("X@)SPO<W1R;VYG/B<["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4&%R<V5S(&$@9VEV96X@:68@<W1A=&5M96YT+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'1A9R`@("`@("!4:&4@;F%M92!O9B!T:&4@:68@8FQO8VL@=&\@<&%R
M<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT96YT<R`@5&AE('5N<&%R
M<V5D(&-O;G1E;G1S(&]F('1H92!I9B!B;&]C:RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE('!A<G-E9"!C;VYT96YT<R!O9B!T:&4@:68@
M8FQO8VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S94EF*"1T86<L("1C
M;VYT96YT<RP@)&ME>2`](&YU;&PI"B`@("!["B`@("`@("`@+R\@1V5T('1H
M92!T86=S("8@:68@<W1A=&5M96YT+@H@("`@("`@("1T(#T@)'1H:7,M/E]G
M971486=S*"1T86<L("=I9B<I.PH@("`@("`@("1E="`]("1T:&ES+3Y?9V5T
M5&%G<R@D=&%G+"`G96QS92<I.PH*("`@("`@("`O+R!E>'!L;V1E('1H92!T
M86<L('-O('=E(&AA=F4@=&AE(&-O<G)E8W0@:V5Y<R!F;W(@=&AE(&%R<F%Y
M"B`@("`@("`@:68@*&ES<V5T*"1K97DI*2!["B`@("`@("`@("`@(&QI<W0H
M)'1G+"`D:RD@/2!E>'!L;V1E*"<N)RP@)'1A9RD["B`@("`@("`@?0H@("`@
M("`@('=H:6QE("@H)&EF(#T@)'1H:7,M/E]G9713=&%T96UE;G0H)'0L("1C
M;VYT96YT<RDI("$]/2!F86QS92D@>PH@("`@("`@("`@("`O+R!#:&5C:R!F
M;W(@96QS92!S=&%T96UE;G0N"B`@("`@("`@("`@(&EF("@D96QS92`]("1T
M:&ES+3Y?9V5T4W1A=&5M96YT*"1E="P@)&EF*2D@>PH@("`@("`@("`@("`@
M("`@+R\@4')O8V5S<R!T:&4@:68@<W1A=&5M96YT+@H@("`@("`@("`@("`@
M("`@:68@*"AI<W-E="@D:V5Y*2`F)B`D=&AI<RT^7VEF<ULD=&==6R1K97E=
M6R1K72D@?'P*("`@("`@("`@("`@("`@("`@("`H:7-S970H)'1H:7,M/E]I
M9G-;)'1A9UTI("8F("1T:&ES+3Y?:69S6R1T86==*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1R97!L86-E(#T@<W1R7W)E<&QA8V4H)&5T6R=B)UT@+B`D
M96QS92`N("1E=%LG92==+"`G)RP@)&EF*3L*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)')E<&QA8V4@/2`D96QS93L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("\O(%!R;V-E<W,@=&AE(&EF('-T871E;65N="X*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D:V5Y*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1R97!L86-E(#T@)'1H:7,M/E]I9G-;)'1G75LD:V5Y75LD:UT@/R`D
M:68@.B!N=6QL.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`D<F5P;&%C92`]("1T:&ES+3Y?:69S6R1T86==(#\@)&EF
M(#H@;G5L;#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@+R\@4&%R<V4@=&AE('1E;7!L871E+@H@("`@("`@("`@("`D
M8V]N=&5N=',@/2!S=')?<F5P;&%C92@D=%LG8B==("X@)&EF("X@)'1;)V4G
M72P@)')E<&QA8V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1C;VYT96YT<RD["B`@("`@("`@?0H*("`@("`@("`O+R!2971U<FX@
M<&%R<V5D('1E;7!L871E+@H@("`@("`@(')E='5R;B`D8V]N=&5N=',["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!087)S97,@=&AE(&=I=F5N(&%R<F%Y(&9O
M<B!A;GD@;&]O<',@;W(@;W1H97(@=7-E<R!O9B!T:&4@87)R87DN"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=&%G("`@("`@(%1H92!N86UE(&]F('1H92!L;V]P('1O('!A
M<G-E+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D87)R87D@("`@(%1H92!V86QU
M97,@9F]R('1H92!L;V]P+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N
M=',@(%1H92!U;G!A<G-E9"!C;VYT96YT<R!O9B!T:&4@;&]O<"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('!A<G-E9"!C;VYT96YT<R!O
M9B!T:&4@;&]O<"X*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E3&]O<"@D
M=&%G+"`D87)R87DL("1C;VYT96YT<RD*("`@('L*("`@("`@("`O+R!'970@
M=&AE('1A9W,@)B!L;V]P+@H@("`@("`@("1T(#T@)'1H:7,M/E]G971486=S
M*"1T86<L("=L;V]P)RD["B`@("`@("`@)&QO;W`@/2`D=&AI<RT^7V=E=%-T
M871E;65N="@D="P@)&-O;G1E;G1S*3L*"B`@("`@("`@+R\@4V5E(&EF('=E
M(&AA=F4@82!D:79I9&5R+@H@("`@("`@("1L(#T@)'1H:7,M/E]G971486=S
M*"1T86<L("=D:79I9&5R)RD["B`@("`@("`@)&1I=FED97(@/2`D=&AI<RT^
M7V=E=%-T871E;65N="@D;"P@)&QO;W`I.PH@("`@("`@("1C;VYT96YT<R`]
M('-T<E]R97!L86-E*"1L6R=B)UT@+B`D9&EV:61E<B`N("1L6R=E)UTL("<G
M+"`D8V]N=&5N=',I.PH*("`@("`@("`O+R!0<F]C97-S('1H92!A<G)A>2X*
M("`@("`@("!D;R!["B`@("`@("`@("`@("1P87)S960@/2`G)SL*("`@("`@
M("`@("`@)&9I<G-T(#T@=')U93L*("`@("`@("`@("`@9F]R96%C:"`H)&%R
M<F%Y(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("!I9B`H
M:7-?87)R87DH)'9A;'5E*2!\?"!I<U]O8FIE8W0H)'9A;'5E*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1I(#T@)&QO;W`["B`@("`@("`@("`@("`@("`@
M("`@:68@*&ES7VYU;65R:6,H)&ME>2DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)'9A;'5E(&%S("1K97DR(#T^("1V86QU93(I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?87)R87DH)'9A
M;'5E,BD@)B8@(6ES7V]B:F5C="@D=F%L=64R*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O(%)E<&QA8V4@87-S;V-I871I=F4@87)R
M87D@=&%G<RX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D86%?
M=&%G(#T@)'1A9R`N("<N)R`N("1K97DR.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1I(#T@<W1R7W)E<&QA8V4H)'1H:7,M/E]G971486<H
M)&%A7W1A9RDL("1V86QU93(L("1I*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<&]S(#T@<W1R<&]S*"1T86<L("<N)RD["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"@D<&]S("$]/2!F86QS92D@
M)B8*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(65M<'1Y
M*"1T:&ES+3Y?:69S6W-U8G-T<B@D=&%G+"`P+"`D<&]S*5TI*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:69S6R1A
M85]T86==(#T@)'9A;'5E,CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&D@/2`D=&AI<RT^7W!A<G-E268H)&%A7W1A9RP@)&DI.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D=&AI
M<RT^7VEF<ULD86%?=&%G72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!#:&5C:R!T;R!S
M964@:68@:70G<R!A(&YE<W1E9"!L;V]P+@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1I(#T@)'1H:7,M/E]P87)S94QO;W`H)'1A9R`N("<N
M)R`N("1K97DR+"`D=F%L=64R+"`D:2D["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&D@/2!S=')?<F5P
M;&%C92@D=&AI<RT^7V=E=%1A9R@D=&%G*2P@)&ME>2P@)&DI.PH@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*&ES7W-T<FEN9R@D:V5Y*2`F)B`A:7-?87)R
M87DH)'9A;'5E*2`F)B`A:7-?;V)J96-T*"1V86QU92DI('L*("`@("`@("`@
M("`@("`@("`@("`D8V]N=&5N=',@/2!S=')?<F5P;&%C92@D=&AI<RT^7V=E
M=%1A9R@D=&%G("X@)RXG("X@)&ME>2DL("1V86QU92P@)&-O;G1E;G1S*3L*
M("`@("`@("`@("`@("`@('T@96QS96EF("@A:7-?87)R87DH)'9A;'5E*2`F
M)B`A:7-?;V)J96-T*"1V86QU92DI('L*("`@("`@("`@("`@("`@("`@("`D
M:2`]('-T<E]R97!L86-E*"1T:&ES+3Y?9V5T5&%G*"1T86<@+B`G)RDL("1V
M86QU92P@)&QO;W`I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D:2`](&YU;&P["B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@+R\@4&%R<V4@8V]N9&ET:6]N<R!I;B!T:&4@87)R
M87DN"B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?:69S6R1T
M86==6R1K97E=*2`F)B!I<U]A<G)A>2@D=&AI<RT^7VEF<ULD=&%G75LD:V5Y
M72D@)B8@)'1H:7,M/E]I9G-;)'1A9UU;)&ME>5TI('L*("`@("`@("`@("`@
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7VEF<ULD=&%G75LD:V5Y72!A<R`D
M8U1A9R`]/B`D8U9A;'5E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1I
M(#T@)'1H:7,M/E]P87)S94EF*"1T86<@+B`G+B<@+B`D8U1A9RP@)&DL("1K
M97DI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("`@("`O+R!!9&0@=&AE('!A<G-E9"!I=&5R871I;VXN
M"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&DI*2!["B`@("`@("`@("`@
M("`@("`@("`@+R\@268@:70G<R!N;W0@=&AE(&9I<G-T('1I;64@=&AR;W5G
M:"P@<')E9FEX('1H90H@("`@("`@("`@("`@("`@("`@("\O(&QO;W`@9&EV
M:61E<BP@:68@=&AE<F4@:7,@;VYE+@H@("`@("`@("`@("`@("`@("`@(&EF
M("@A)&9I<G-T*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1I(#T@)&1I
M=FED97(@+B`D:3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@)'!A<G-E9"`N/2!R=')I;2@D:2D["B`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@+R\@3F\@;&]N9V5R('1H92!F:7)S="!T
M:6UE('1H<F]U9V@N"B`@("`@("`@("`@("`@("`D9FER<W0@/2!F86QS93L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@4F5P;&%C92!T:&4@<&%R
M<V5D('!I96-E<R!O9B!T:&4@=&5M<&QA=&4N"B`@("`@("`@("`@("1C;VYT
M96YT<R`]('-T<E]R97!L86-E*"1T6R=B)UT@+B`D;&]O<"`N("1T6R=E)UTL
M("1P87)S960L("1C;VYT96YT<RD["B`@("`@("`@?2!W:&EL92`H)&QO;W`@
M/2`D=&AI<RT^7V=E=%-T871E;65N="@D="P@)&-O;G1E;G1S*2D["@H@("`@
M("`@(')E='5R;B`D8V]N=&5N=',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!0
M87)S97,@=&AE(&=I=F5N(&-A<V4@;&]O<"`H8VQO;W`I+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'1A9R`@("`@("!4:&4@;F%M92!O9B!T:&4@8VQO;W`@=&\@<&%R<V4N
M"B`@("`@*B!`<&%R86T@87)R87D@("1A<G)A>2`@("`@5&AE('9A;'5E<R!F
M;W(@=&AE(&-L;V]P+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N=',@
M(%1H92!U;G!A<G-E9"!C;VYT96YT<R!O9B!T:&4@8VQO;W`N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!P87)S960@8V]N=&5N=',@;V8@
M=&AE(&-L;V]P+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5#;&]O<"@D
M=&%G+"`D87)R87DL("1C;VYT96YT<RD*("`@('L*("`@("`@("`O+R!'970@
M=&AE('1A9W,@)B!C;&]O<"X*("`@("`@("`D="`]("1T:&ES+3Y?9V5T5&%G
M<R@D=&%G+"`G8VQO;W`G*3L*"B`@("`@("`@=VAI;&4@*"1L;V]P(#T@)'1H
M:7,M/E]G9713=&%T96UE;G0H)'0L("1C;VYT96YT<RDI('L*("`@("`@("`@
M("`@+R\@4V5T('5P('1H92!C87-E<RX*("`@("`@("`@("`@)&%R<F%Y6R=C
M87-E<R==6UT@/2`G9&5F875L="<["B`@("`@("`@("`@("1C87-E7V-O;G1E
M;G0@/2!A<G)A>2@I.PH*("`@("`@("`@("`@+R\@1V5T('1H92!C87-E('-T
M<FEN9W,N"B`@("`@("`@("`@(&9O<F5A8V@@*"1A<G)A>5LG8V%S97,G72!A
M<R`D8V%S92D@>PH@("`@("`@("`@("`@("`@)&-T86=S6R1C87-E72`]("1T
M:&ES+3Y?9V5T5&%G<R@D8V%S92P@)V-A<V4G*3L*("`@("`@("`@("`@("`@
M("1C87-E7V-O;G1E;G1;)&-A<V5=(#T@)'1H:7,M/E]G9713=&%T96UE;G0H
M)&-T86=S6R1C87-E72P@)&QO;W`I.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`O+R!0<F]C97-S('1H92!C;&]O<"X*("`@("`@("`@("`@)'!A<G-E
M9"`]("<G.PH@("`@("`@("`@("!F;W)E86-H("@D87)R87E;)V%R<F%Y)UT@
M87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@("`@(&EF("AI<U]N
M=6UE<FEC*"1K97DI("8F("AI<U]A<G)A>2@D=F%L=64I('Q\(&ES7V]B:F5C
M="@D=F%L=64I*2D@>PH@("`@("`@("`@("`@("`@("`@("\O(%-E="!U<"!T
M:&4@8V%S97,N"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1V86QU
M95LG8V%S92==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N
M=%]C87-E(#T@)'9A;'5E6R=C87-E)UT["B`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?8V%S
M92`]("=D969A=6QT)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@=6YS970H)'9A;'5E6R=C87-E)UTI.PH@("`@("`@("`@
M("`@("`@("`@("1I(#T@)&-A<V5?8V]N=&5N=%LD8W5R<F5N=%]C87-E73L*
M"B`@("`@("`@("`@("`@("`@("`@+R\@3&]O<"!T:')O=6=H(&5A8V@@=F%L
M=64N"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E(&%S("1K
M97DR(#T^("1V86QU93(I('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&ES7V%R<F%Y*"1V86QU93(I('Q\(&ES7V]B:F5C="@D=F%L=64R*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&D@/2`D=&AI<RT^7W!A<G-E
M3&]O<"@D=&%G("X@)RXG("X@)&ME>3(L("1V86QU93(L("1I*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1I(#T@<W1R7W)E<&QA8V4H)'1H:7,M/E]G971486<H)'1A
M9R`N("<N)R`N("1K97DR*2P@)'9A;'5E,BP@)&DI.PH@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@("\O($%D9"!T:&4@<&%R<V5D(&ET
M97)A=&EO;BX*("`@("`@("`@("`@("`@("1P87)S960@+CT@<G1R:6TH)&DI
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!087)S92!T:&4@8VQO
M;W`N"B`@("`@("`@("`@("1C;VYT96YT<R`]('-T<E]R97!L86-E*"1T6R=B
M)UT@+B`D;&]O<"`N("1T6R=E)UTL("1P87)S960L("1C;VYT96YT<RD["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&-O;G1E;G1S.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1F5T8V@@=&AE(&-O;G1E;G1S(&]F(&$@=&5M<&QA=&4@
M:6YT;R`D=&AI<RT^7W1E;7!L871E.R!C86-H90H@("`@("H@=&AE(&9I;&5N
M86UE(&EN("1T:&ES+3Y?=&5M<&QA=&5&:6QE+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I
M;&5N86UE("!,;V-A=&EO;B!O9B!T96UP;&%T92!F:6QE(&]N(&1I<VLN"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!L;V%D960@=&5M<&QA
M=&4@8V]N=&5N="X*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=%1E;7!L871E
M*"1F:6QE;F%M92`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"%I<U]N=6QL
M*"1F:6QE;F%M92D@)B8@*"1F:6QE;F%M92`A/2`D=&AI<RT^7W1E;7!L871E
M1FEL92DI('L*("`@("`@("`@("`@)'1H:7,M/E]T96UP;&%T92`](&YU;&P[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES7VYU;&PH)'1H:7,M/E]T96UP
M;&%T92DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&5M<&QA=&4[
M"B`@("`@("`@?0H*("`@("`@("`O+R!'970@=&AE(&-O;G1E;G1S(&]F('1H
M92!F:6QE+@H@("`@("`@("1F:6QE(#T@)'1H:7,M/E]B87-E<&%T:"`N("1F
M:6QE;F%M93L*("`@("`@("`D8V]N=&5N=',@/2!`9FEL95]G971?8V]N=&5N
M=',H)&9I;&4I.PH@("`@("`@(&EF("@D8V]N=&5N=',@/3T](&9A;'-E*2![
M"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4BYP:'`G.PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E1E;7!L
M871E(%PB)7-<(B!N;W0@9F]U;F0N(BDL("1F:6QE*2D["B`@("`@("`@?0H*
M("`@("`@("`D=&AI<RT^7W1E;7!L871E(#T@)&-O;G1E;G1S.PH@("`@("`@
M("1T:&ES+3Y?=&5M<&QA=&5&:6QE(#T@)&9I;&5N86UE.PH*("`@("`@("!R
M971U<FX@)'1H:7,M/E]T96UP;&%T93L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]497AT+P``````````````````
M````````````````````````````````````````````````````````````
M,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W
M-3``,#(P-#`V`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E
M>'0O1FEL=&5R+P``````````````````````````````````````````````
M```````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#4Q-30S,S<U,``P,C$V,S,`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O5&5X="]&:6QT97(O8F)C;V1E+G!H<```````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q,#<S`#$P-3$U-#,S-S4P`#`R,S4V-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`H*<F5Q=6ER95]O;F-E("=(;W)D92YP:'`G.PH*+RHJ"B`J(%1H92!497AT
M7T9I;'1E<E]B8F-O9&4Z.B!C;&%S<R!F:6YD<R!B8F-O9&4M<W1Y;&4@;6%R
M:W5P("AS964@8F5L;W<I(&EN(&$*("H@8FQO8VL@;V8@=&5X="!A;F0@='5R
M;G,@:70@:6YT;R!(5$U,+@H@*@H@*B!087)A;65T97)S.@H@*B`\<')E/@H@
M*B!E;G1I=&EE<R`M+2!)9B!T<G5E(&)E9F]R92!R97!L86-I;F<@8F)C;V1E
M('=I=&@@2%1-3"!T86=S+"!A;GD@2%1-3`H@*B`@("`@("`@("`@("!E;G1I
M=&EE<R!W:6QL(&)E(')E<&QA8V5D+@H@*B`\+W!R93X*("H*("H@4W5P<&]R
M=&5D(&)B8V]D93H*("H@/'!R93X*("H@("`@(%MB74)O;&0@5&5X=%LO8ET*
M("H@("`@(%MI74ET86QI8W,@5&5X=%LO:5T*("H@("`@(%MU755N9&5R;&EN
M960@5&5X=%LO=5T*("H@("`@(%MQ=6]T95U1=6]T960@5&5X=%LO<75O=&5=
M"B`J("`@("!;8V5N=&5R74-E;G1E<F5D(%1E>'1;+V-E;G1E<ET*("H*("H@
M("`@($QI<W0@;V8@:71E;7,*("H@("`@(%ML:7-T70H@*B`@("`@6RI=($ET
M96T@;VYE"B`J("`@("!;*ET@271E;2!T=V\*("H@("`@(%LO;&ES=%T*("H*
M("H@("`@($YU;6)E<F5D(&QI<W0*("H@("`@(%MN=6UL:7-T70H@*B`@("`@
M6RI=($ET96T@;VYE"B`J("`@("!;*ET@271E;2!T=V\*("H@("`@(%LO;G5M
M;&ES=%T*("H*("H@("`@(%MU<FQ=:'1T<#HO+W=W=RYH;W)D92YO<F=;+W5R
M;%T@+3X@3&EN:R!T;R!T:&4@861D<F5S<R!U<VEN9R!T:&4*("H@("`@("`@
M("!A9&1R97-S(&ET<V5L9B!F;W(@=&AE('1E>'0N("!9;W4@8V%N('-P96-I
M9GD@=&AE('!R;W1O8V]L.B!H='1P(&]R"B`J("`@("`@("`@:'1T<',@86YD
M('1H92!P;W)T+@H@*B`@("`@6W5R;%UW=W<N:&]R9&4N;W)G6R]U<FQ=("T^
M($QI;FL@=&\@=&AE(&%D9')E<W,@=7-I;F<@=&AE(&%D9')E<W,*("H@("`@
M("`@("!I='-E;&8@9F]R('1H92!T97AT+B`@66]U(&-A;B!S<&5C:69Y('1H
M92!P;W)T+B`@5&AE('!R;W1O8V]L(&ES(&)Y"B`J("`@("`@("`@9&5F875L
M="!H='1P+@H@*B`@("`@6W5R;#UH='1P.B\O=W=W+FAO<F1E+F]R9UU,:6YK
M('1O($AO<F1E6R]U<FQ=("T^($QI;FL@=&\@=&AE(&%D9')E<W,*("H@("`@
M("`@("!U<VEN9R`B3&EN:R!T;R!(;W)D92(@9F]R('1H92!T97AT+B`@66]U
M(&-A;B!S<&5C:69Y('1H92!P<F]T;V-O;#H*("H@("`@("`@("!H='1P(&]R
M(&AT='!S(&%N9"!T:&4@<&]R="X*("H@("`@(%MU<FP]=W=W+FAO<F1E+F]R
M9UU,:6YK('1O($AO<F1E6R]U<FQ=("T^($QI;FL@=&\@=&AE(&%D9')E<W,@
M=7-I;F<*("H@("`@("`@("`B3&EN:R!T;R!(;W)D92(@9F]R('1H92!T97AT
M+B`@66]U(&-A;B!S<&5C:69Y('1H92!P;W)T+B`@5&AE"B`J("`@("`@("`@
M<')O=&]C;VP@:7,@8GD@9&5F875L="!H='1P"B`J("`@("!;96UA:6Q=8W!E
M9')I;F%C:4!Y86AO;RYE<ULO96UA:6Q=("T^('-E=',@82!M86EL=&\@;&EN
M:RX*("H@("`@(%ME;6%I;#UC<&5D<FEN86-I0'EA:&]O+F5S74UA:6P@=&\@
M0V%R;&]S6R]E;6%I;%T@+3X@4V5T<R!A(&UA:6QT;R!L:6YK"B`J("`@("`@
M("`@86YD('1H92!T97AT(&ES(")-86EL('1O($-A<FQO<R(N"B`J(#PO<')E
M/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O
M8F)C;V1E+G!H<"QV(#$N."XQ,"XU(#(P,#8O,#$O,#$@,C$Z,C@Z,S@@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@0V%R;&]S(%!E9')I
M;F%C:2`\8W!E9')I;F%C:4!Y86AO;RYE<SX*("H*("H@16UA:6P@=F%L:61A
M=&EO;B!B87-E9"!O;B!#:'5C:R!(86=E;F)U8V@G<PH@*B!-86EL7U)&0S@R
M,CHZ:7-686QI9$EN971!9&1R97-S+@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@0V%R;&]S(%!E9')I;F%C:2`\8W!E9')I;F%C:4!Y86AO;RYE<SX*
M("H@0'!A8VMA9V4@2&]R9&5?5&5X=`H@*B\*8VQA<W,@5&5X=%]&:6QT97)?
M8F)C;V1E(&5X=&5N9',@5&5X=%]&:6QT97(@>PH*("`@("\J*@H@("`@("H@
M1FEL=&5R('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@G96YT:71I97,G(#T^
M(&9A;'-E*3L*"B`@("`O*BH*("`@("`J($5X96-U=&5S(&%N>2!C;V1E(&YE
M8V5S<V%R>2!B969O<F4@87!P;'EI;F<@=&AE(&9I;'1E<B!P871T97)N<RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!B
M969O<F4@=&AE(&9I;'1E<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(&UO9&EF:65D('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('!R95!R;V-E<W,H)'1E>'0I"B`@("!["B`@("`):68@*"1T:&ES+3Y?<&%R
M86US6R=E;G1I=&EE<R==*2!["B`@("`@("`@("`@("1T97AT(#T@0&AT;6QS
M<&5C:6%L8VAA<G,H)'1E>'0I.PH@("`@"7T*"B`@("`@("`@<F5T=7)N("1T
M97AT.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&AA<V@@=VET
M:"!R97!L86-E('!A='1E<FYS+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@(%!A='1E<FYS(&AA<V@N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A
M='1E<FYS*"D*("`@('L*("`@(`DD<F5P;&%C92`](&%R<F%Y*`H@("`@"2`@
M("`G6VE=)R`]/B`G/&5M/B<L("=;+VE=)R`]/B`G/"]E;3XG+`H@("`@("`@
M("`@("`G6W5=)R`]/B`G/'4^)RP@)ULO=5TG(#T^("<\+W4^)RP*("`@("`@
M("`@("`@)UMB72<@/3X@)SQS=')O;F<^)RP@)ULO8ETG(#T^("<\+W-T<F]N
M9SXG+`H@("`@("`@("`@("`G6V-E;G1E<ETG(#T^("<\8V5N=&5R/B<L("=;
M+V-E;G1E<ETG(#T^("<\+V-E;G1E<CXG+`H@("`@("`@("`@("`G6W%U;W1E
M72<@/3X@)SQB;&]C:W%U;W1E/B<L("=;+W%U;W1E72<@/3X@)SPO8FQO8VMQ
M=6]T93XG+`H@("`@("`@("`@("`G6VQI<W1=)R`]/B`G/'5L/B<L("=;+VQI
M<W1=)R`]/B`G/"]U;#XG+`H@("`@("`@("`@("`G6VYU;6QI<W1=)R`]/B`G
M/&]L/B<L("=;+VYU;6QI<W1=)R`]/B`G/"]O;#XG+`H@("`@("`@("`@("`G
M6RI=)R`]/B`G/&QI/B<I.PH*("`@("`@("`O*B!7:&5N(&-H96-K:6YG(%52
M3',@=V4@=F%L:61A=&4@<&%R="!O9B!T:&5M+"!B=70@:70@:7,@=7`*("`@
M("`@("`@*B!T;R!T:&4@=7-E<B!T;R!W<FET92!T:&5M(&-O<G)E8W1L>2`H
M:6X@<&%R=&EC=6QA<B!T:&4*("`@("`@("`@*B!Q=65R>2!S=')I;F<I+B!#
M;VYC97)N:6YG(&UA:6QS('=E('5S92!T:&4@<F5G=6QA<@H@("`@("`@("`J
M(&5X<')E<W-I;VX@:6X@36%I;%]21D,X,C(G<R!I<U9A;&ED26YE=$%D9')E
M<W,H*2!F=6YC=&EO;BP*("`@("`@("`@*B!S;&EG:'1L>2!M;V1I9FEE9"X@
M*B\*("`@("`@("`D<F5G97AP(#T@87)R87DH"B`@("`@("`@("`@("(C7%MU
M<FQ<72@H:'1T<'QH='1P<RDZ+R\H6V$M>D$M6EQD75M<=RU=*BDH7"Y;82UZ
M02U:7&1=6UQW+5TJ*2LH.BA<9"LI*3\H+RA;7CP^72LI*2HI7%LO=7)L7%TC
M52(@/3X*("`@("`@("`@("`@2&]R9&4Z.FQI;FLH(B0Q(BP@(B0Q(BD@+B`B
M)#$\+V$^(BP*"B`@("`@("`@("`@("(C7%MU<FQ</2@H:'1T<'QH='1P<RDZ
M+R\H6V$M>D$M6EQD75M<=RU=*BDH7"Y;82UZ02U:7&1=6UQW+5TJ*2LH.BA<
M9"LI*3\H+RA;7CP^72LI*2HI7%TH6UX\/ETK*5Q;+W5R;%Q=(U4B(#T^"B`@
M("`@("`@("`@($AO<F1E.CIL:6YK*"(D,2(L("(D,2(I("X@(B0Y/"]A/B(L
M"@H@("`@("`@("`@("`B(UQ;=7)L7%TH*%MA+7I!+5I<9%U;7'<M72HI*%PN
M6V$M>D$M6EQD75M<=RU=*BDK*#HH7&0K*2D_*"\H6UX\/ETK*2DJ*5Q;+W5R
M;%Q=(U4B(#T^"B`@("`@("`@("`@($AO<F1E.CIL:6YK*")H='1P.B\O)#$B
M+"`B:'1T<#HO+R0Q(BD@+B`B)#$\+V$^(BP*"B`@("`@("`@("`@("(C7%MU
M<FQ</2@H6V$M>D$M6EQD75M<=RU=*BDH7"Y;82UZ02U:7&1=6UQW+5TJ*2LH
M.BA<9"LI*3\H+RA;7CP^72LI*2HI7%TH6UX\/ETK*5Q;+W5R;%Q=(U4B(#T^
M"B`@("`@("`@("`@($AO<F1E.CIL:6YK*")H='1P.B\O)#$B+"`B:'1T<#HO
M+R0Q(BD@+B`B)#@\+V$^(BP*"B`@("`@("`@("`@("(C7%ME;6%I;%Q=*"A;
M*BLA+B9<(R1\7"=<7"5<+S`M.6$M>D$M6EY?8'M]/3]^.BU=*RE`*"A;,"TY
M82UZ02U:+5TK7"XI*ULP+3EA+7I!+5I=>S(L-'TI*5Q;+V5M86EL7%TC52(@
M/3X*("`@("`@("`@("`@2&]R9&4Z.FQI;FLH(FUA:6QT;SHD,2(L(")M86EL
M=&\Z)#$B*2`N("(D,3PO83XB+`H*("`@("`@("`@("`@(B-<6V5M86EL7#TH
M*%LJ*R$N)EPC)'Q<)UQ<)5PO,"TY82UZ02U:7E]@>WT]/WXZ+5TK*4`H*%LP
M+3EA+7I!+5HM72M<+BDK6S`M.6$M>D$M6EU[,BPT?2DI7%TH6UX\/ETK*5Q;
M+V5M86EL7%TC52(@/3X*("`@("`@("`@("`@2&]R9&4Z.FQI;FLH(FUA:6QT
M;SHD,2(L(")M86EL=&\Z)#$B*2`N("(D-3PO83XB"B`@("`@("`@*3L*"B`@
M("`@("`@<F5T=7)N(&%R<F%Y*"=R97!L86-E)R`]/B`D<F5P;&%C92P@)W)E
M9V5X<"<@/3X@)')E9V5X<"D["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V-L96%N87-C:6DN
M<&AP```````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3$V,P`Q,#4Q-30S,S<U,``P
M,C0T-#0`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%)E;6]V97,@<V]M92!C;VUM;VX@96YT:71I97,@
M86YD(&AI9V@M87-C:6D@;W(@;W1H97)W:7-E(&YO;G-T86YD87)D"B`J(&-H
M87)A8W1E<G,@8V]M;6]N(&EN('1E>'0@<&%S=&5D(&9R;VT@36EC<F]S;V9T
M(%=O<F0@:6YT;R!A(&)R;W=S97(N"B`J"B`J(%1H:7,@9G5N8W1I;VX@<VAO
M=6QD($Y/5"!B92!U<V5D(&]N(&YO;BU!4T-)22!T97AT.R!I="!M87D@86YD
M('!R;V)A8FQY"B`J('=I;&P@8G5T8VAE<B!O=&AE<B!C:&%R86-T97(@<V5T
M<R!I;F1E<V-R:6UI;F%T96QY+B`@57-E(&ET(&]N;'D@=&\@8VQE86X*("H@
M55,M05-#24D@*#<M8FET*2!T97AT('=H:6-H('EO=2!S=7-P96-T("AO<B!K
M;F]W*2!M87D@:&%V92!I;G9A;&ED(&]R"B`J(&YO;BUP<FEN=&EN9R!C:&%R
M86-T97)S(&EN(&ET+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]497AT7T9I
M;'1E<B]&:6QT97(O8VQE86YA<V-I:2YP:'`L=B`Q+C,N,BXT(#(P,#8O,#$O
M,#$@,C$Z,C@Z,S@@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P
M,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^
M"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]497AT
M"B`J+PIC;&%S<R!497AT7T9I;'1E<E]C;&5A;F%S8VEI(&5X=&5N9',@5&5X
M=%]&:6QT97(@>PH*("`@("\J*@H@("`@("H@17AE8W5T97,@86YY(&-O9&4@
M;F5C97-S87)Y(&)E9F]R92!A<'!L>6EN9R!T:&4@9FEL=&5R('!A='1E<FYS
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT
M(&)E9F]R92!T:&4@9FEL=&5R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@;6]D:69I960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<')E4')O8V5S<R@D=&5X="D*("`@('L*("`@("`@("!I9B`H<')E9U]M
M871C:"@G+WPH6UXC72HI(RXJ+R<L("1T97AT+"`D<F5G<RDI('L*("`@("`@
M("`@("`@)'1E>'0@/2`D<F5G<ULQ73L*"B`@("`@("`@("`@(&EF("@A96UP
M='DH)'1E>'0I*2!["B`@("`@("`@("`@("`@("`D=&5X="`]("1T97AT("X@
M(EQN(CL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1T97AT.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&AA<V@@
M=VET:"!R97!L86-E('!A='1E<FYS+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@(%!A='1E<FYS(&AA<V@N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%!A='1E<FYS*"D*("`@('L*("`@("`@("`O*B!296UO=F4@8V]N=')O;"!C
M:&%R86-T97)S+B`J+PH@("`@("`@("1R96=E>'`@/2!A<G)A>2@G+UM<>#`P
M+5QX,69=*R\G(#T^("<G*3L*"B`@("`@("`@+RH@5&AE(">2)R!E;G1R>2!M
M87D@;&]O:R!W<F]N9RP@9&5P96YD:6YG(&]N('EO=7(@961I=&]R+`H@("`@
M("`@("`J(&)U="!I="=S(&YO="`M('1H870G<R!N;W0@<F5A;&QY(&$@<VEN
M9VQE('%U;W1E+B`J+PH@("`@("`@("1R97!L86-E(#T@87)R87DH8VAR*#$U
M,"D@/3X@)RTG+`H@("`@("`@("`@("`@("`@("`@("`@("`@8VAR*#$V-RD@
M/3X@)RHG+`H@("`@("`@("`@("`@("`@("`@("`@("`@)X&W)R`]/B`G*B<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`GA2<@/3X@)RXN+B<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`GD2<@/3X@(B<B+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)Y(G(#T^("(G(BP*("`@("`@("`@("`@("`@("`@("`@
M("`@(">3)R`]/B`G(B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`GE"<@
M/3X@)R(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)Y4G(#T^("<J)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@(">6)R`]/B`G+2<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`GER<@/3X@)RTG+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@)Y\G(#T^("<J)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("<F(S8Q-#<Y.R<@/3X@)RXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M)R8C-C$U-S([)R`]/B`G*B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G
M)B,V,34Y-#LG(#T^("<J)RP*("`@("`@("`@("`@("`@("`@("`@("`@("<F
M(S8Q-C0P.R<@/3X@)RTG+`H@("`@("`@("`@("`@("`@("`@("`@("`@)R8C
M-C$V,C,[)R`]/B`G+2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G)B,V
M,38P-SLG(#T^("<J)RP*("`@("`@("`@("`@("`@("`@("`@("`@("<F(S8Q
M-34S.R<@/3X@)RHG+`H@("`@("`@("`@("`@("`@("`@("`@("`@)R8C-C$U
M-3@[)R`]/B`G*B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G)B,X,C(V
M.R<@/3X@)RHG+`H@("`@("`@("`@("`@("`@("`@("`@("`@)R8C.38U.#LG
M(#T^("<^)RP*("`@("`@("`@("`@("`@("`@("`@("`@("D["@H@("`@("`@
M(')E='5R;B!A<G)A>2@G<F5G97AP)R`]/B`D<F5G97AP+"`G<F5P;&%C92<@
M/3X@)')E<&QA8V4I.PH@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O5&5X="]&:6QT97(O9&EM<VEG;F%T=7)E+G!H<```````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,S8S`#$P-3$U-#,S-S4P`#`R-3`T,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M1&ES<&QA>7,@;65S<V%G92!S:6=N871U<F5S(&UA<FME9"!B>2!A("<M+2`G
M(&EN('1H92!S='EL92!O9B!T:&4*("H@0U-3(&-L87-S(")S:6=N871U<F4B
M+B!#;&%S<R!N86UE<R!I;G-I9&4@=&AE('-I9VYA='5R92!A<F4*("H@<')E
M9FEX960@=VET:"`B<VEG;F%T=7)E+2(N"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]D:6US:6=N871U<F4N<&AP+'8@,2XR
M+C$P+C8@,C`P-B\P."\Q-R`Q,CHR.3HU-2!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#0M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\
M:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K
M86=E($AO<F1E7U1E>'0*("HO"F-L87-S(%1E>'1?1FEL=&5R7V1I;7-I9VYA
M='5R92!E>'1E;F1S(%1E>'1?1FEL=&5R('L*"B`@("`O*BH*("`@("`J($5X
M96-U=&5S(&%N>2!C;V1E(&YE8V5S<V%R87D@869T97(@87!P;'EI;F<@=&AE
M(&9I;'1E<@H@("`@("H@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@869T97(@=&AE(&9I;'1E<FEN9RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&UO9&EF:65D('1E
M>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N('!O<W10<F]C97-S*"1T97AT*0H@
M("`@>PH@("`@("`@("1P87)T<R`]('!R96=?<W!L:70H)WPH7&XM+5QS*B@\
M8G(@+SXI/UQR/UQN*7PG+"`D=&5X="P@,BP@4%)%1U]34$Q)5%]$14Q)35]#
M05!455)%*3L*("`@("`@("!I9B`H8V]U;G0H)'!A<G1S*2`^(#,I('L*("`@
M("`@("`@("`@)'1E>'0@/2!A<G)A>5]S:&EF="@D<&%R=',I.PH@("`@("`@
M("`@("`D=&5X="`N/2`G/'-P86X@8VQA<W,](G-I9VYA='5R92(^)R`N("1P
M87)T<ULP73L*("`@("`@("`@("`@)'1E>'0@+CT@<')E9U]R97!L86-E*"=\
M8VQA<W,](BA;7B)=*RDB?"<L("=C;&%S<STB<VEG;F%T=7)E+5PQ(B<L("1P
M87)T<ULR72D["B`@("`@("`@("`@("1T97AT("X]("<\+W-P86X^)SL*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D=&5X=#L*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]497AT+T9I;'1E<B]E;6%I
M;',N<&AP````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`T,#``,3`U,34T
M,S,W-3``,#(S-C$Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!4:&4@5&5X=%]&:6QT97)?96UA:6QS
M.CH@8VQA<W,@9FEN9',@96UA:6P@861D<F5S<V5S(&EN(&$@8FQO8VL@;V8@
M=&5X="!A;F0*("H@='5R;G,@=&AE;2!I;G1O(&QI;FMS+@H@*@H@*B!087)A
M;65T97)S.@H@*B`\<')E/@H@*B!A;'=A>7-?;6%I;'1O("TM($EF('1R=64L
M(&$@;6%I;'1O.B!L:6YK(&ES(&=E;F5R871E9"!A;'=A>7,N("!/;FQY(&EF
M(&YO"B`J("`@("`@("`@("`@("`@("`@;6%I;"]C;VUP;W-E(')E9VES=')Y
M($%022!M971H;V0@97AI<W1S(&]T:&5R=VES92X*("H@8VQA<W,@("`@("`@
M("`M+2!#4U,@8VQA<W,@;V8@=&AE(&=E;F5R871E9"`\83X@=&%G+B`@1&5F
M875L=',@=&\@;F]N92X*("H@/"]P<F4^"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP+'8@,2XQ-2XQ,"XX
M(#(P,#8O,#(O,3<@,C`Z,#4Z-#D@8VAU8VL@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#,M,C`P-B!4>6QE<B!#;VQB97)T(#QT>6QE<BUH;W)D96UL0&-O
M;&)E<G1S+G5S/@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IA;B!38VAN96ED
M97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M(%1Y;&5R($-O;&)E<G0@/'1Y;&5R+6AO<F1E;6Q`8V]L8F5R=',N=7,^"B`J
M($!A=71H;W(@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'!A
M8VMA9V4@2&]R9&5?5&5X=`H@*B\*8VQA<W,@5&5X=%]&:6QT97)?96UA:6QS
M(&5X=&5N9',@5&5X=%]&:6QT97(@>PH*("`@("\J*@H@("`@("H@1FEL=&5R
M('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@G86QW87ES7VUA:6QT;R<@/3X@
M9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`G8VQA<W,G(#T^("<G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@)V-A<&ET86Q?=&%G<R<@/3X@
M9F%L<V4I.PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&AA<V@@=VET:"!R
M97!L86-E('!A='1E<FYS+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M(%!A='1E<FYS(&AA<V@N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A='1E
M<FYS*"D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@
M("`D8VQA<W,@/2!E;7!T>2@D=&AI<RT^7W!A<F%M<ULG8VQA<W,G72D@/R`G
M)R`Z("<@8VQA<W,](B<@+B`D=&AI<RT^7W!A<F%M<ULG8VQA<W,G72`N("<B
M)SL*("`@("`@("`D=&%G(#T@)'1H:7,M/E]P87)A;7-;)V-A<&ET86Q?=&%G
M<R==(#\@)T$G(#H@)V$G.PH*("`@("`@("`D<F5G97AP(#T@/#P\14]2"B`@
M("`@("`@("`@("\*("`@("`@("`@("`@(R!697)S:6]N(#$Z(&UA:6QT;SH@
M;&EN:W,@=VET:"!A;GD@=F%L:60@96UA:6P@8VAA<F%C=&5R<RX*("`@("`@
M("`@("`@(R!0871T97)N(#$Z($]U=&QO;VL@<&%R96YT:&5S:7IE<R!I;B!S
M<6%R92!B<F%C:V5T<PH@("`@("`@("`@("`H7%M<<RHI/PH@("`@("`@("`@
M("`C(%!A='1E<FX@,CH@;6%I;'1O.B!P<F]T;V-O;"!P<F5F:7@*("`@("`@
M("`@("`@*&UA:6QT;SI<<S\I"B`@("`@("`@("`@(",@4&%T=&5R;B`S.B!E
M;6%I;"!A9&1R97-S"B`@("`@("`@("`@("A;7EQS7#\B/%TJ*0H@("`@("`@
M("`@("`C(%!A='1E<FX@-"!T;R`V.B!/<'1I;VYA;"!P87)A;65T97)S"B`@
M("`@("`@("`@("@H7#\I*%M>7',B/%TJ6UQW*R,_7"\F/5TI*3\*("`@("`@
M("`@("`@(R!0871T97)N(#<Z($-L;W-I;F<@3W5T;&]O:R!S<75A<F4@8G)A
M8VME=`H@("`@("`@("`@("`H*#\H,2E<<RI<72DI"@H@("`@("`@("`@("!\
M"B`@("`@("`@("`@(",@5F5R<VEO;B`R(%!A='1E<FX@.#H@<VEM<&QE(&5M
M86EL(&%D9')E<W-E<RX*("`@("`@("`@("`@*%QB6UQW+2LN/5TK0%LM02U:
M,"TY+ETJ6T$M6C`M.5TI"B`@("`@("`@("`@(",@4&%T=&5R;B`Y('1O(#$Q
M.B!/<'1I;VYA;"!P87)A;65T97)S"B`@("`@("`@("`@("@H7#\I*%M>7',B
M/%TJ6UQW*R,_7"\F/5TI*3\*"B`@("`@("`@("`@("]E:7@*14]2.PH*("`@
M("`@("!I9B`H:7-?82@D<F5G:7-T<GDL("=296=I<W1R>2<I("8F"B`@("`@
M("`@("`@("1R96=I<W1R>2T^:&%S365T:&]D*"=M86EL+V-O;7!O<V4G*2`F
M)@H@("`@("`@("`@("`A)'1H:7,M/E]P87)A;7-;)V%L=V%Y<U]M86EL=&\G
M72D@>PH@("`@("`@("`@("`O*B!)9B!W92!H879E(&$@;6%I;"]C;VUP;W-E
M(')E9VES=')Y(&UE=&AO9"P@=7-E(&ET+B`J+PH@("`@("`@("`@("`D<F5P
M;&%C96UE;G0@/2`G5&5X=%]&:6QT97)?96UA:6QS.CIC86QL8F%C:RA<)R<@
M+B`D=&%G("X*("`@("`@("`@("`@("`@("=<)RP@7"<G("X@)&-L87-S("X@
M)UPG+"!<)R0Q7"<L(%PG)#)<)RP@7"<D,UPG+"!<)R0T7"<L(%PG)#9<)RP@
M7"<D-UPG+"!<)R0X7"<L(%PG)#E<)RP@7"<D,3%<)RDG.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("\J($]T:&5R=VES92P@9V5N97)A=&4@82!S
M=&%N9&%R9"!M86EL=&\Z(&%N9"!L970@=&AE"B`@("`@("`@("`@("`J(&)R
M;W=S97(@:&%N9&QE(&ET+B`J+PH@("`@("`@("`@("`D<F5P;&%C96UE;G0@
M/2`\/#Q%3U`*("`@("`@("`@("`@("`@("<D."<@/3T]("<G(#\*"B`@("`@
M("`@("`@("`@("`G)#$D,CPD=&%G)&-L87-S(&AR968](FUA:6QT;SHD,R0T
M(B!T:71L93TB)R`N('-P<FEN=&8H7R@B3F5W($UE<W-A9V4@=&\@)7,B*2P@
M:'1M;'-P96-I86QC:&%R<R@G)#,G*2D@+@H@("`@("`@("`@("`@("`@)R(^
M)#,D-#PO)'1A9SXD-R<@.@H*("`@("`@("`@("`@("`@("<\)'1A9R1C;&%S
M<R!H<F5F/2)M86EL=&\Z)#@D.2(@=&ET;&4](B<@+B!S<')I;G1F*%\H(DYE
M=R!-97-S86=E('1O("5S(BDL(&AT;6QS<&5C:6%L8VAA<G,H)R0X)RDI("X*
M("`@("`@("`@("`@("`@("<B/B0X)#D\+R1T86<^)PI%3U`["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@87)R87DH)W)E9V5X<"<@/3X@87)R87DH)')E
M9V5X<"`]/B`D<F5P;&%C96UE;G0I*3L*("`@('T*"B`@("!F=6YC=&EO;B!C
M86QL8F%C:R@D=&%G+"`D8VQA<W,L("1B<F%C:V5T,2P@)'!R;W1O8V]L+"`D
M96UA:6PL("1A<F=S7VQO;F<L"B`@("`@("`@("`@("`@("`@("`@("`D87)G
M<RP@)&)R86-K970R+"`D96UA:6PR+"`D87)G<U]L;VYG,BP@)&%R9W,R*0H@
M("`@>PH@("`@("`@(&EF("@A96UP='DH)&5M86EL,BDI('L*("`@("`@("`@
M("`@)&%R9W,@/2`D87)G<S(["B`@("`@("`@("`@("1E;6%I;"`]("1E;6%I
M;#(["B`@("`@("`@("`@("1A<F=S7VQO;F<@/2`D87)G<U]L;VYG,CL*("`@
M("`@("!]"B`@("`@("`@)&5X=')A(#T@8V%L;%]U<V5R7V9U;F,H8W)E871E
M7V9U;F-T:6]N*"<D82<L("<D<#UA<G)A>2@I.V9O<F5A8V@H)&$@87,@)&(I
M>R1B/65X<&QO9&4H(CTB+"1B+#(I.R1P6R1B6S!=73U`)&);,5T[?7)E='5R
M;B`D<#LG*2P@97AP;&]D92@G)B<L("1A<F=S*2D["B`@("`@("`@)'5R;"`]
M("1'3$]"04Q36R=R96=I<W1R>2==+3YC86QL*"=M86EL+V-O;7!O<V4G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2AA<G)A>2@G=&\G(#T^("1E;6%I;"DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1E>'1R82DI.PH@("`@("`@("1U<FP@
M/2!S=')?<F5P;&%C92@G)F%M<#LG+"`G)B<L("1U<FPI.PH@("`@("`@(&EF
M("AS=6)S='(H)'5R;"P@,"P@,3$I(#T]("=J879A<V-R:7!T.B<I('L*("`@
M("`@("`@("`@)&AR968@/2`G(R<["B`@("`@("`@("`@("1O;F-L:6-K(#T@
M)R!O;F-L:6-K/2(G("X@<W5B<W1R*"1U<FPL(#$Q*2`N("<B)SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D:')E9B`]("1U<FP["B`@("`@("`@
M("`@("1O;F-L:6-K(#T@)R<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&)R86-K970Q("X@)'!R;W1O8V]L("X@)SPG("X@)'1A9R`N("1C;&%S<R`N
M("<@:')E9CTB)R`N"B`@("`@("`@("`@("1H<F5F("X@)R(@=&ET;&4](B<@
M+B!S<')I;G1F*%\H(DYE=R!-97-S86=E('1O("5S(BDL(&AT;6QS<&5C:6%L
M8VAA<G,H)&5M86EL*2D@+B`G(B<@+@H@("`@("`@("`@("`D;VYC;&EC:R`N
M("<^)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&5M86EL*2`N("1A<F=S7VQO;F<@
M+B`G/"\G("X@)'1A9R`N("<^)R`N("1B<F%C:V5T,CL*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M;W1I8V]N<RYP:'``
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,#0W-@`Q,#4Q-30S,S<U,``P,C0S
M-30`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4N<&AP)SL*"B\J*@H@*B!4:&4@
M5&5X=%]&:6QT97)?96UO=&EC;VYS.CH@8VQA<W,@9FEN9',@96UO=&EC;VX@
M<W1R:6YG<R`H(#HI+"!E=&,N*2!I;B!A"B`J(&)L;V-K(&]F('1E>'0@86YD
M('1U<FYS('1H96T@:6YT;R!I;6%G92!L:6YK<RX*("H*("H@4&%R86UE=&5R
M<SH*("H@/'!R93X*("H@96YT:71I97,@+2T@268@=')U92!T:&4@:'1M;"!E
M;G1I='D@=F5R<VEO;G,@;V8@=&AE('!A='1E<FYS('=I;&P@8F4@=7-E9"X*
M("H@/"]P<F4^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]E;6]T:6-O;G,N<&AP+'8@,2XQ-RXQ,"XQ,"`R,#`V+S`W+S(T
M(#`T.C0X.C$W('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M
M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O
M;3X*("H@0'!A8VMA9V4@2&]R9&5?5&5X=`H@*B\*8VQA<W,@5&5X=%]&:6QT
M97)?96UO=&EC;VYS(&5X=&5N9',@5&5X=%]&:6QT97(@>PH*("`@("\J*@H@
M("`@("H@1FEL=&5R('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@G96YT:71I
M97,G(#T^(&9A;'-E*3L*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!H87-H
M('=I=&@@<F5P;&%C92!P871T97)N<RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!0871T97)N<R!H87-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9710871T97)N<R@I"B`@("!["B`@("`@("`@)')E9V5X<"`](&%R<F%Y*"D[
M"B`@("`@("`@)&EC;VYP871H(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E
M=$EM86=E1&ER*"=H;W)D92<I("X@)R]E;6]T:6-O;G,G.PH*("`@("`@("`O
M*B!,;V]P('1H<F]U9V@@<&]S<VEB;&4@<W1R:6YG(&5M;W1I8V]N<R!A;F0@
M8V]N=F5R="!T;R!G<F%P:&EC<RX@*B\*("`@("`@("!F;W)E86-H("@D=&AI
M<RT^9V5T26-O;G,H*2!A<R`D<W1R:6YG(#T^("1I8V]N*2!["B`@("`@("`@
M("`@("1B96=?<&%T=&5R;B`]("<H7GQ<<RDG.PH@("`@("`@("`@("`D96YD
M7W!A='1E<FX@/2`G*#\]7',I)SL*("`@("`@("`@("`@:68@*"1T:&ES+3Y?
M<&%R86US6R=E;G1I=&EE<R==*2!["B`@("`@("`@("`@("`@("`D<W1R:6YG
M(#T@:'1M;'-P96-I86QC:&%R<R@D<W1R:6YG*3L*("`@("`@("`@("`@("`@
M("1B96=?<&%T=&5R;B`]("<H7GQ<<WP\8G(@+SY\)FYB<W`[*2<["B`@("`@
M("`@("`@("`@("`D96YD7W!A='1E<FX@/2`G*#\]7'-\/&)R("\^?"9N8G-P
M.RDG.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!#:&5C:R!F;W(@
M82!S;6EL97D@96ET:&5R(&EM;65D:6%T96QY(&%T('1H92!S=&%R="!O9B!A
M(&QI;F4@;W(*("`@("`@("`@("`@("H@9F]L;&]W:6YG(&$@<W!A8V4N(%5S
M92![?2!A<R!T:&4@<')E9R!D96QI;6ET97)S(&%S('1H:7,@:7,@;F]T"B`@
M("`@("`@("`@("`J(&9O=6YD(&EN(&%N>2!S;6EL97DN("HO"B`@("`@("`@
M("`@("1R96=E>'!;)WLG("X@)&)E9U]P871T97)N("X@<')E9U]Q=6]T92@D
M<W1R:6YG*2`N("1E;F1?<&%T=&5R;B`N("=])UT@/2`G7%PQ)R`N($AO<F1E
M.CII;6<H)&EC;VX@+B`G+G!N9R<L("1S=')I;F<L(&%R<F%Y*"=A;&EG;B<@
M/3X@)VUI9&1L92<L("=T:71L92<@/3X@)'-T<FEN9RDL("1I8V]N<&%T:"D@
M+B`H*"1T:&ES+3Y?<&%R86US6R=E;G1I=&EE<R==*2`_("=<7#(G(#H@)R<I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"=R96=E>'`G(#T^
M("1R96=E>'`I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&AA
M<V@@=VET:"!E;6]T:6-O;G,@86YD(&YA;65S+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@(%!A='1E<FYS(&AA<V@N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$EC;VYS*"D*("`@('L*("`@("`@("`O*B!,:7-T(&-O;7!L97@@
M<W1R:6YG<R!B969O<F4@<VEM<&QE<B!O;F5S+"!O=&AE<G=I<V4@9F]R(&5X
M86UP;&4@.B@H"B`@("`@("`@("H@=V]U;&0@8F4@;6%T8VAE9"!A9V%I;G-T
M(#HH(&)E9F]R92`Z*"@@:7,@9F]U;F0N("HO"B`@("`@("`@<F5T=7)N(&%R
M<F%Y*`H@("`@("`@("`@("`G.B\G(#T^("=F<G5S=')A=&5D)RP@)SHM+R<@
M/3X@)V9R=7-T<F%T960G+`H@("`@("`@("`@("`O+R`G.BH^)R`]/B`G8FQU
M<V@G+`H@("`@("`@("`@("`G.F4G(#T^("=D:7-A<'!O:6YT960G+`H@("`@
M("`@("`@("`G/3HI)"<@/3X@)VUR="<L"B`@("`@("`@("`@("<C?"<@/3X@
M)VAA;F=O=F5R)RP@)R,M?"<@/3X@)VAA;F=O=F5R)RP*("`@("`@("`@("`@
M)SHM0"<@/3X@)W-H;W5T)RP*("`@("`@("`@("`@)SHH*"<@/3X@)V)I9V9R
M;W=N)RP@)SI#)R`]/B`G8FEG9G)O=VXG+`H@("`@("`@("`@("`G.E,G(#T^
M("=D87IE9"<L("<Z+5,G(#T^("=D87IE9"<L"B`@("`@("`@("`@("=80"<@
M/3X@)V%N9W)Y)RP*("`@("`@("`@("`@)U@H)R`]/B`G;6%D)RP*("`@("`@
M("`@("`@+R\@)SXZ*2<@/3X@)V1E=FEL)RP@)SXZ+2DG(#T^("=D979I;"<L
M"B`@("`@("`@("`@("\O("<^.G`G(#T^("=D979I;'1O;F=U92<L("<^.BUP
M)R`]/B`G9&5V:6QT;VYG=64G+`H@("`@("`@("`@("`O+R`G/CIP)R`]/B`G
M<F%S<&)E<G)Y)RP@)SXZ4"<@/3X@)W)A<W!B97)R>2<L"B`@("`@("`@("`@
M("\O("<F*2<@/3X@)W!U;FLG+`H@("`@("`@("`@("`O+R`G)G`G(#T^("=P
M=6YK=&]N9W5E)RP*("`@("`@("`@("`@+R\@)STF*2<@/3X@)W!U;FMM;VAA
M=VLG+`H@("`@("`@("`@("`G.ETG(#T^("=G<FEN)RP*("`@("`@("`@("`@
M)R-;)R`]/B`G:'5R="<L("<C*"<@/3X@)VAU<G0G+"`G(RU;)R`]/B`G:'5R
M="<L("<C+2@G(#T^("=H=7)T)RP*("`@("`@("`@("`@)SI/)R`]/B`G96UB
M87)R87-S960G+"`G.BU/)R`]/B`G96UB87)R87-S960G+`H@("`@("`@("`@
M("`G.ELG(#T^("=S860G+`H@("`@("`@("`@("`O+R`G/CI`)R`]/B`G96YR
M86=E9"<L"B`@("`@("`@("`@("\O("<Z)B<@/3X@)V%N;F]Y960G+`H@("`@
M("`@("`@("`G/2@G(#T^("=W;W)R:65D)RP@)STM*"<@/3X@)W=O<G)I960G
M+`H@("`@("`@("`@("`G.GP])R`]/B`G=F%M<&ER92<L"B`@("`@("`@("`@
M("<Z+2@G(#T^("=F<F]W;B<L"B`@("`@("`@("`@("<Z1"<@/3X@)V)I9V=R
M:6XG+`H@("`@("`@("`@("`G."DG(#T^("=C;V]L)RP*("`@("`@("`@("`@
M+R\@26X@16YG;&ES:"P@.%!-(&]C8W5R<R!S=69F:6-I96YT;'D@;V9T96X@
M=&\@<W!E8VEF:6-A;&QY"B`@("`@("`@("`@("\O('-E87)C:"!F;W(@86YD
M(&5X8VQU9&4*("`@("`@("`@("`@)SAP*#\\(5M-;5U<<RLI)R`]/B`G8V]O
M;'1O;F=U92<L("\O("<XWB<@/3X@)V-O;VQT;VYG=64G+`H@("`@("`@("`@
M("`G.$0G(#T^("=C;V]L9W)I;B<L"B`@("`@("`@("`@("<Z<"<@/3X@)W1O
M;F=U96]U="<L("<Z4"<@/3X@)W1O;F=U96]U="<L("\O("<ZWB<@/3X@)W1O
M;F=U96]U="<L"B`@("`@("`@("`@("<_.B@G(#T^("=C;VYF=7-E9"<L("<E
M+2@G(#T^("=C;VYF=7-E9"<L"B`@("`@("`@("`@("\O("<Z*28G(#T^("=L
M;W9E)RP*("`@("`@("`@("`@)T\[+2DG(#T^("=A;F=E;'=I;FLG+`H@("`@
M("`@("`@("`G.UTG(#T^("=W:6YK9W)I;B<L"B`@("`@("`@("`@("<[<"<@
M/3X@)W=I;FMT;VYG=64G+"`G.U`G(#T^("=W:6YK=&]N9W5E)RP@+R\@)SO>
M)R`]/B`G=VEN:W1O;F=U92<L"B`@("`@("`@("`@("<Z?"<@/3X@)VEN9&EF
M9F5R96YT)RP@)SHM?"<@/3X@)VEN9&EF9F5R96YT)RP*("`@("`@("`@("`@
M)R%\)R`]/B`G=&ER960G+"`G(2U))R`]/B`G=&ER960G+`H@("`@("`@("`@
M("`G?$DG(#T^("=A<VQE97`G+"`G?"U))R`]/B`G87-L965P)RP*("`@("`@
M("`@("`@)T\Z*2<@/3X@)V%N9V5L)RP@)T\Z+2DG(#T^("=A;F=E;"<L"B`@
M("`@("`@("`@("=/.RDG(#T^("=A;F=E;'=I;FLG+`H@("`@("`@("`@("`G
M.RTI)R`]/B`G=VEN:R<L"B`@("`@("`@("`@("<Z(RDG(#T^("=C;&]W;B<L
M("<Z;RDG(#T^("=C;&]W;B<L"B`@("`@("`@("`@("<Z*2<@/3X@)W-M:6QE
M)RP*("`@("`@("`@("`@)SLI)R`]/B`G=VEN:R<L"B`@("`@("`@("`@("<Z
M+2DG(#T^("=S;6EL92<L"B`@("`@("`@("`@("<Z0"<@/3X@)W-H;W5T)RP*
M("`@("`@("`@("`@)SHH)R`]/B`G9G)O=VXG+`H@("`@("`@("D["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O5&5X="]&:6QT97(O96YV:7)O;FUE;G0N<&AP````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`Q-S`W`#$P-3$U-#,S-S4P`#`R-#<Q-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@4F5P;&%C97,@;V-C=7)E;F-E<R!O9B`E5D%2)2!W:71H(%9!4BP@:68@
M5D%2(&5X:7-T<R!I;B!T:&4@=V5B<V5R=F5R)W,*("H@96YV:7)O;FUE;G0N
M("!)9VYO<F5S(&%L;"!T97AT(&%F=&5R(&$@)R,G(&-H87)A8W1E<B`H<VAE
M;&PM<W1Y;&4*("H@8V]M;65N=',I+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]497AT7T9I;'1E<B]&:6QT97(O96YV:7)O;FUE;G0N<&AP+'8@,2XS+C$P
M+C0@,C`P-B\P,2\P,2`R,3HR.#HS."!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#0M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N
M0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E
M($AO<F1E7U1E>'0*("HO"F-L87-S(%1E>'1?1FEL=&5R7V5N=FER;VYM96YT
M(&5X=&5N9',@5&5X=%]&:6QT97(@>PH*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!A(&AA<V@@=VET:"!R97!L86-E('!A='1E<FYS+@H@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@(%!A='1E<FYS(&AA<V@N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%!A='1E<FYS*"D*("`@('L*("`@("`@("`D<F5G97AP(#T@
M87)R87DH)R]>(RXJ)%QN+VTG(#T^("<G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`G+UXH6UXC72HI(RXJ)"]M)R`]/B`G)#$G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`G+R4H6T$M6F$M>E]=*RDE+V4G(#T^("=G971E;G8H(B0Q
M(BDG*3L*("`@("`@("!R971U<FX@87)R87DH)W)E9V5X<"<@/3X@)')E9V5X
M<"D["B`@("!]"@I]````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O5&5X="]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H
M<````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#$V,3<Q`#$P-3$U-#,S-S4P`#`R-34V,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`H*<F5Q=6ER95]O;F-E("=(;W)D92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO
M<F1E+U-T<FEN9RYP:'`G.PH*+RHJ"B`J($AI9VAL:6=H=',@<75O=&5D(&UE
M<W-A9V5S('=I=&@@9&EF9F5R96YT(&-O;&]R<R!F;W(@=&AE(&1I9F9E<F5N
M="!Q=6]T:6YG"B`J(&QE=F5L<RX*("H*("H@0U-3(&-L87-S(&YA;65S(&-A
M;&QE9"`B<75O=&5D,2(@+BXN(")Q=6]T961[)&-S<TQE=F5L<WTB(&UU<W0@
M8F4@<')E<V5N="X*("H@5&AE('1E>'0@=&\@8F4@<&%S<V5D(&EN(&UU<W0@
M:&%V92!A;')E861Y(&)E96X@<&%S<V5D('1H<F]U9V@*("H@:'1M;'-P96-I
M86QC:&%R<R@I+@H@*@H@*B!087)A;65T97)S.@H@*B`\<')E/@H@*B`G8VET
M96)L;V-K)R`@+2T@1&ES<&QA>2!C:71E(&)L;V-K<S\@1&5F875L=',@=&\@
M=')U92X*("H@)V-S<TQE=F5L<R<@("TM($YU;6)E<B!O9B!D969I;F5D($-3
M4R!C;&%S<R!N86UE<RX@1&5F875L=',@=&\@-2X*("H@)VAI9&5";&]C:W,G
M("TM($AI9&4@<75O=&5D('1E>'0@8FQO8VMS(&)Y(&1E9F%U;'0_($1E9F%U
M;'1S('1O(&9A;'-E+@H@*B`\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`L=B`Q
M+C8N."XQ-B`R,#`V+S`X+S$V(#$V.C4V.C`P('-L=7-A<GH@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A
M<GI`8W5R96-A;G1I+F]R9SX*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!*86X@
M4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&-U<F5C86YT:2YO
M<F<^"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^
M"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]497AT
M"B`J+PIC;&%S<R!497AT7T9I;'1E<E]H:6=H;&EG:'1Q=6]T97,@97AT96YD
M<R!497AT7T9I;'1E<B!["@H@("`@+RHJ"B`@("`@*B!&:6QT97(@<&%R86UE
M=&5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7W!A<F%M<R`](&%R<F%Y*`H@("`@("`@("=C:71E8FQO8VLG(#T^('1R
M=64L"B`@("`@("`@)V-S<TQE=F5L<R<@/3X@-2P*("`@("`@("`G:&ED94)L
M;V-K<R<@/3X@9F%L<V4*("`@("D["@H@("`@+RHJ"B`@("`@*B!%>&5C=71E
M<R!A;GD@8V]D92!N96-E<W-A<F%Y(&)E9F]R92!A<'!L>6EN9R!T:&4@9FEL
M=&5R('!A='1E<FYS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E
M>'0@(%1H92!T97AT(&)E9F]R92!T:&4@9FEL=&5R:6YG+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@;6]D:69I960@=&5X="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<')E4')O8V5S<R@D=&5X="D*("`@('L*("`@("`@
M("`O*B!486-K(&$@;F5W;&EN92!O;G1O('1H92!B96=I;FYI;F<@;V8@=&AE
M('-T<FEN9R!S;R!T:&%T('=E"B`@("`@("`@("H@8V]R<F5C=&QY(&AI9VAL
M:6=H="!W:&5N('1H92!F:7)S="!C:&%R86-T97(@:6X@=&AE('-T<FEN9R!I
M<R!A"B`@("`@("`@("H@<75O=&4@8VAA<F%C=&5R+B`J+PH@("`@("`@(')E
M='5R;B`B7&XD=&5X="(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&$@:&%S:"!W:71H(')E<&QA8V4@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@4&%T=&5R;G,@:&%S:"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4&%T=&5R;G,H*0H@("`@>PH@("`@("`@("\J(%)E;6]V92!E
M>'1R82!S<&%C97,@8F5F;W)E('%U;W1E9"!T97AT(&%S('1H92!#4U,@9F]R
M;6%T=&EN9R!W:6QL"B`@("`@("`@("H@875T;VUA=&EC86QL>2!A9&0@82!B
M:70@;V8@<W!A8V4@9F]R('5S+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W!A
M<F%M<ULG8VET96)L;V-K)UTI('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y
M*"=R96=E>'`G(#T^(&%R<F%Y*"(O/&)R(%PO/EQS*EQN7',J/&)R(%PO/EQS
M*EQN7',J*"@F9W0[7',_*2LI+VTB(#T^("(\8G(@+SY<;EQ<,2(I*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@17AE8W5T97,@86YY(&-O9&4@;F5C97-S87)A>2!A9G1E<B!A
M<'!L>6EN9R!T:&4@9FEL=&5R('!A='1E<FYS+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT(&%F=&5R('1H92!F:6QT97)I
M;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!M;V1I9FEE
M9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!P;W-T4')O8V5S<R@D=&5X
M="D*("`@('L*("`@("`@("`O*B!)<R!T:&5R92!A(&)L86YK(&QI;F4H<RD@
M8F5F;W)E('1H92!C=7)R96YT(&QI;F4_("HO"B`@("`@("`@)&)L86YK;&EN
M92`](&9A;'-E.PH*("`@("`@("`O*B!5<V4@8VET92!B;&]C:W,@=&\@9&ES
M<&QA>2!T:&4@9&EF9F5R96YT('%U;W1I;F<@;&5V96QS/R`J+PH@("`@("`@
M("1C8B`]("1T:&ES+3Y?<&%R86US6R=C:71E8FQO8VLG73L*"B`@("`@("`@
M+RH@0VET92!L979E;"!B969O<F4@<&%R<VEN9R!T:&4@8W5R<F5N="!L:6YE
M+B`J+PH@("`@("`@("1Q;&5V96P@/2`P.PH*("`@("`@("`O*B!'96YE<F%T
M960@;W5T<'5T+B`J+PH@("`@("`@("1T97AT7V]U="`]("<G.PH*("`@("`@
M("`O*B!!9&0@<VAO=R]H:61E('1O9V=L97,@9F]R('=H;VQE('%U;W1E(&)L
M;V-K<RX@*B\*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C95]C86QL8F%C
M:R@G+RA<;BDH*"`J*"9G=#M<<S\I*R@_(2`_)F=T.RDN*C\I*%QN?"0I*#\A
M("HH)F=T.R`_*2LI*2]S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@D=&AI<RP@)U]A9&11=6]T951O9V=L97,G*2P@
M)'1E>'0I.PH*("`@("`@("`O*B!087)S92!T97AT(&QI;F4@8GD@;&EN92X@
M*B\*("`@("`@("!F;W)E86-H("AE>'!L;V1E*")<;B(L("1T97AT*2!A<R`D
M;&EN92D@>PH@("`@("`@("`@("`O*B!#:71E(&QE=F5L(&]F(&-U<G)E;G0@
M;&EN92X@*B\*("`@("`@("`@("`@)&-L979E;"`]("1C;&]S96QE=F5L(#T@
M,#L*("`@("`@("`@("`@)&UA=&-H97,@/2!A<G)A>2@I.PH@("`@("`@("`@
M("`O*B!$;R!W92!H879E(&$@8VET871I;VX@;&EN93\@*B\*("`@("`@("`@
M("`@:68@*'!R96=?;6%T8V@H)R]>7',J*"@F9W0[7',_*2LI+VTG+"`D;&EN
M92P@)&UA=&-H97,I*2!["B`@("`@("`@("`@("`@("`O*B!#;W5N="!N=6UB
M97(@;V8@/B!C:&%R86-T97)S(#T^(&-I=&4@;&5V96P@*B\*("`@("`@("`@
M("`@("`@("1C;&5V96P@/2`D8VQO<V5L979E;"`](&-O=6YT*'!R96=?<W!L
M:70H)R\F9W0[7',_+R<L("1M871C:&5S6S%=*2D@+2`Q.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!I9B`H)&-B("8F(&ES<V5T*"1M871C:&5S6S%=
M*2D@>PH@("`@("`@("`@("`@("`@+RH@4W1R:7`@86QL(#X@8VAA<F%C=&5R
M<RX@*B\*("`@("`@("`@("`@("`@("1L:6YE(#T@<W5B<W1R*"1L:6YE+"!3
M=')I;F<Z.FQE;F=T:"@D;6%T8VAE<ULQ72DI.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`O*B!)<R!T:&ES(&-I=&4@;&5V96P@;&]W97(@=&AA;B!T
M:&4@8W5R<F5N="!L979E;#\@*B\*("`@("`@("`@("`@:68@*"1C;&5V96P@
M/"`D<6QE=F5L*2!["B`@("`@("`@("`@("`@("`O*B!3=')I<"!M;W)E('1H
M86X@;VYE(&)L86YK(&QI;F4@:6X@9G)O;G0@;V8@=&AE(&-I=&4*("`@("`@
M("`@("`@("`@("`J(&)L;V-K<RX@*B\*("`@("`@("`@("`@("`@(&EF("@D
M8FQA;FML:6YE*2!["B`@("`@("`@("`@("`@("`@("`@=VAI;&4@*"@D8G)?
M<W1R(#T@<W5B<W1R*"1T97AT7V]U="P@+3<I*2`]/2`B/&)R("\^7&XB*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T97AT7V]U="`]('-U8G-T<B@D
M=&5X=%]O=70L(#`L("TW*3L*("`@("`@("`@("`@("`@("`@("!].PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@+RH@061D('%U;W1E(&)L
M;V-K(&5N9"!T86=S(&9O<B!E86-H(&-I=&4@;&5V96PN("HO"B`@("`@("`@
M("`@("`@("!F;W(@*"1I(#T@)&-L979E;#L@)&D@/"`D<6QE=F5L.R`D:2LK
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1E>'1?;W5T("X]("@D8V(I(#\@
M)SPO9&EV/B<@.B`G/"]F;VYT/B<["B`@("`@("`@("`@("`@("`@("`@+2TD
M8VQO<V5L979E;#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("\J(%-T<FEP('1R86EL:6YG(&QI;F4@8G)E86L@:68@=7-I;F<@8VET92!B
M;&]C:W,L('=E(&%L<F5A9'D*("`@("`@("`@("`@("`@("`J(&AA=F4@82!D
M:78@=&%G+B`J+PH@("`@("`@("`@("`@("`@:68@*"1C8B`F)B!P<F5G7VUA
M=&-H*"<O7#QB<B!<+SXD+R<L("1L:6YE*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1L:6YE(#T@<W5B<W1R*"1L:6YE+"`P+"`M-BD["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("\J($ES('1H:7,@8VET92!L979E;"!H:6=H
M97(@=&AA;B!T:&4@8W5R<F5N="!L979E;#\@*B\*("`@("`@("`@("`@?2!E
M;'-E:68@*"1C;&5V96P@/B`D<6QE=F5L*2!["B`@("`@("`@("`@("`@("`O
M*B!3=')I<"!M;W)E('1H86X@;VYE(&)L86YK(&QI;F4@:6X@9G)O;G0@;V8@
M=&AE(&-I=&4*("`@("`@("`@("`@("`@("`J(&)L;V-K<RX@*B\*("`@("`@
M("`@("`@("`@(&EF("@D8FQA;FML:6YE*2!["B`@("`@("`@("`@("`@("`@
M("`@=VAI;&4@*"@D8G)?<W1R(#T@<W5B<W1R*"1T97AT7V]U="P@+3<I*2`]
M/2`B/&)R("\^7&XB*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T97AT
M7V]U="`]('-U8G-T<B@D=&5X=%]O=70L(#`L("TW*3L*("`@("`@("`@("`@
M("`@("`@("!].PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M9F]R("@D:2`]("1Q;&5V96P[("1I(#P@)&-L979E;#L@)&DK*RD@>PH@("`@
M("`@("`@("`@("`@("`@("\J($%D9"!Q=6]T92!B;&]C:R!S=&%R="!T86=S
M(&9O<B!E86-H(&-I=&4@;&5V96PN("HO"B`@("`@("`@("`@("`@("`@("`@
M)'1E>'1?;W5T("X]("@D8V(I(#\@)SQD:78@8VQA<W,](F-I=&%T:6]N("<@
M.B`G/&9O;G0@8VQA<W,](B<["B`@("`@("`@("`@("`@("`@("`@)'1E>'1?
M;W5T("X]("=Q=6]T960G("X@*"@D:2`E("1T:&ES+3Y?<&%R86US6R=C<W-,
M979E;',G72D@*R`Q*2`N("<B/B<["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("\J($-O=6YT(&)L86YK(&QI;F5S+B`J
M+PH@("`@("`@("`@("`D8FQA;FML:6YE(#T@*"1L:6YE(#T]("<\8G(@+SXG
M*3L*"B`@("`@("`@("`@("1T97AT7V]U="`N/2`D;&EN92`N(")<;B(["B`@
M("`@("`@("`@("1Q;&5V96P@/2`D8VQE=F5L.PH@("`@("`@('T*"B`@("`@
M("`@+RH@36%K92!S=7)E(&%L;"!D:78O9F]N="!T86=S(&%R92!C;&]S960N
M("HO"B`@("`@("`@:68@*"1C;&]S96QE=F5L(#X@,"D@>PH@("`@("`@("`@
M("`D=&5X=%]O=70@/2!P<F5G7W)E<&QA8V4H)R\\7"]D:78^)"\G+"!S=')?
M<F5P96%T*"@D8V(I(#\@)SPO9&EV/B<@.B`G/"]F;VYT/B<L("1C;&]S96QE
M=F5L*2`N("<\+V1I=CXG+"`D=&5X=%]O=70I.PH@("`@("`@('T*"B`@("`@
M("`@+RH@4F5M;W9E('1H92!L96%D:6YG(&YE=VQI;F4@=V4@861D960@86)O
M=F4L(&EF(&ET)W,@<W1I;&P@=&AE<F4N("HO"B`@("`@("`@:68@*"1T97AT
M7V]U=%LP72`]/2`B7&XB*2!["B`@("`@("`@("`@("1T97AT7V]U="`]('-U
M8G-T<B@D=&5X=%]O=70L(#$I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1T97AT7V]U=#L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@;&EN:W,@
M=&\@<VAO=R!A;F0@:&ED92!Q=6]T960@8FQO8VMS+"!H:61I;F<@=&AE;2!B
M>2!D969A=6QT(&EF"B`@("`@*B!T:&4@)VAI9&5";&]C:W,G('!A<F%M971E
M<B!I<R!T<G5E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D;6%T8VAE<R`@5&AE(&UA=&-H97,@
M9G)O;2!T:&4@<F5G97AP+@H@("`@("HO"B`@("!F=6YC=&EO;B!?861D475O
M=&54;V=G;&5S*"1M871C:&5S*0H@("`@>PH@("`@("`@('-T871I8R`D:2`]
M(#`["@H@("`@("`@("\J($1O;B=T('1O9V=L92!S;6%L;"!B;&]C:W,[(&1O
M97-N)W0@<')O=FED92!A(%5)(&)E;F5F:70@86YD(&QO;VMS"B`@("`@("`@
M("H@86YN;WEI;F<N("HO"B`@("`@("`@)&QI;F5S(#T@<W5B<W1R7V-O=6YT
M*"1M871C:&5S6S!=+"`B7&XB*3L*("`@("`@("!I9B`H)&QI;F5S(#P@."D@
M>PH@("`@("`@("`@("!R971U<FX@)&UA=&-H97-;,%T["B`@("`@("`@?0H*
M("`@("`@("!(;W)D93HZ861D4V-R:7!T1FEL92@G:&ED96%B;&4N:G,G+"`G
M:&]R9&4G+"!T<G5E*3L*("`@("`@("!(;W)D93HZ861D4V-R:7!T1FEL92@G
M<75O=&5";&]C:W,N:G,G+"`G:&]R9&4G*3L*"B`@("`@("`@)'1E>'0@/2`G
M)SL*("`@("`@("!I9B`H)'1H:7,M/E]P87)A;7-;)V-I=&5B;&]C:R==*2![
M"B`@("`@("`@("`@("1T97AT(#T@)SQB<B`O/B<["B`@("`@("`@?3L*("`@
M("`@("`D=&5X="`N/2`G/&1I=B!I9#TB<71?)R`N("1I("X@)R(^)R`N"B`@
M("`@("`@("`@($AO<F1E.CIL:6YK*"<C)RP@)R<L("=W:61G970@=&]G9VQE
M<75O=&4G+"`G)RP@)W1O9V=L95%U;W1E0FQO8VLH7"<G("X@)&D@+B`G7"<L
M(%PG)R`N("1L:6YE<R`N("=<)RD[(')E='5R;B!F86QS93LG+"`G)RP@)R<L
M(&%R<F%Y*"=S='EL92<@/3X@)V9O;G0M<VEZ93HW,"4G*2D@+@H@("`@("`@
M("`@("`H)'1H:7,M/E]P87)A;7-;)VAI9&5";&]C:W,G72`_('-P<FEN=&8H
M7R@B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB*2P@)&QI;F5S*2`Z
M(%\H(EM(:61E(%%U;W1E9"!497AT72(I*2`N"B`@("`@("`@("`@("<\+V$^
M/"]D:78^/&1I=B!I9#TB<6)?)R`N("1I("X@)R(G("X@*"1T:&ES+3Y?<&%R
M86US6R=H:61E0FQO8VMS)UT@/R`G('-T>6QE/2)D:7-P;&%Y.FYO;F4[(B<@
M.B`G)RD@+B`G/B<@+B`D;6%T8VAE<ULP72`N("<\+V1I=CXG.PH*("`@("`@
M("`D:2LK.PH*("`@("`@("!R971U<FX@)'1E>'0["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]497AT+T9I;'1E<B]H=&UL,G1E>'0N<&AP````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,38Q,S``,3`U,34T,S,W-3``,#(T,S`P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+U-T<FEN9RYP:'`G.PH*+RHJ"B`J
M(%1A:V5S($A434P@86YD(&-O;G9E<G1S(&ET('1O(&9O<FUA='1E9"P@<&QA
M:6X@=&5X="X*("H*("H@4&%R86UE=&5R<SH*("H@/'!R93X*("H@8VAA<G-E
M="`M+2!4:&4@8VAA<G-E="!T;R!U<V4@9F]R(&AT;6Q?96YT:71Y7V1E8V]D
M92@I(&-A;&QS+@H@*B!W:61T:"`@("TM(%1H92!W<F%P<&EN9R!W:61T:"X*
M("H@=W)A<"`@("`M+2!7:&5T:&5R('1O('=R87`@=&AE('1E>'0@;W(@;F]T
M+@H@*B`\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]&:6QT
M97(O1FEL=&5R+VAT;6PR=&5X="YP:'`L=B`Q+C0N,3`N,3(@,C`P-B\P,2\P
M,2`R,3HR.#HS."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P
M-B!*;VX@06)E<FYA=&AY(#QJ;VY`8VAU9V=N=71T+F-O;3X*("H@3W)I9VEN
M86P@<V]U<F-E.B!H='1P.B\O=W=W+F-H=6=G;G5T="YC;VTO:'1M;#)T97AT
M+G!H<`H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IA;B!38VAN96ED97(@/&IA
M;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I
M9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*;VX@
M06)E<FYA=&AY(#QJ;VY`8VAU9V=N=71T+F-O;3X*("H@0&%U=&AO<B`@2F%N
M(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@
M,RXP"B`J($!P86-K86=E($AO<F1E7U1E>'0*("HO"F-L87-S(%1E>'1?1FEL
M=&5R7VAT;6PR=&5X="!E>'1E;F1S(%1E>'1?1FEL=&5R('L*"B`@("`O*BH*
M("`@("`J($9I;'1E<B!P87)A;65T97)S+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R86US(#T@87)R87DH)V-H87)S
M970G(#T^(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`G=VED=&@G
M(#T^(#<P+`H@("`@("`@("`@("`@("`@("`@("`@("`@)W=R87`G(#T^('1R
M=64I.PH*("`@("\J*@H@("`@("H@17AE8W5T97,@86YY(&-O9&4@;F5C97-S
M87)A>2!B969O<F4@87!P;'EI;F<@=&AE(&9I;'1E<B!P871T97)N<RX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!B969O
M<F4@=&AE(&9I;'1E<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&UO9&EF:65D('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N('!R
M95!R;V-E<W,H)'1E>'0I"B`@("!["B`@("`@("`@9VQO8F%L("1?:'1M;#)T
M97AT7W-T871E.PH*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7W!A<F%M
M<ULG8VAA<G-E="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M8VAA<G-E="==(#T@:7-S970H)$=,3T)!3%-;)U](3U)$15]35%))3D=?0TA!
M4E-%5"==*2`_("1'3$]"04Q36R=?2$]21$5?4U1224Y'7T-(05)3150G72`Z
M("=)4T\M.#@U.2TQ)SL*("`@("`@("!]"@H@("`@("`@("1?:'1M;#)T97AT
M7W-T871E6R=L:6YK3&ES="==(#T@)R<["B`@("`@("`@)%]H=&UL,G1E>'1?
M<W1A=&5;)VQI;FM#;W5N="==(#T@,#L*"B`@("`@("`@<F5T=7)N('1R:6TH
M)'1E>'0I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&AA<V@@
M=VET:"!R97!L86-E('!A='1E<FYS+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@(%!A='1E<FYS(&AA<V@N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%!A='1E<FYS*"D*("`@('L*("`@("`@("`D<F5G97AP(#T@87)R87DH"B`@
M("`@("`@("`@("\O($YO;BUL96=A;"!C87)R:6%G92!R971U<FXN"B`@("`@
M("`@("`@("<O7'(O)R`]/B`G)RP*"B`@("`@("`@("`@("\O($QE861I;F<@
M86YD('1R86EL:6YG('=H:71E<W!A8V4N"B`@("`@("`@("`@("<O7EQS*B@N
M*C\I7',J)"]M)R`]/B`G7#$G+`H*("`@("`@("`@("`@+R\@3F]R;6%L:7IE
M(#QB<CXN"B`@("`@("`@("`@("<O/&)R6UX^72H^*%M>7&Y=*2]I)R`]/B`B
M/&)R/EQN7%PQ(BP*"B`@("`@("`@("`@("\O($YE=VQI;F5S(&%N9"!T86)S
M+@H@("`@("`@("`@("`G+UM<;EQT72LO)R`]/B`G("<L"@H@("`@("`@("`@
M("`O+R`\<V-R:7!T/G,@+2T@=VAI8V@@<W1R:7!?=&%G<R@I('-U<'!O<V5D
M;'D@:&%S('!R;V)L96US('=I=&@N"B`@("`@("`@("`@("<O/'-C<FEP=%M>
M/ETJ/BXJ/SQ<+W-C<FEP=#XO:2<@/3X@)R<L"@H@("`@("`@("`@("`O+R`\
M<W1Y;&4^<R`M+2!W:&EC:"!S=')I<%]T86=S*"D@<W5P<&]S961L>2!H87,@
M<')O8FQE;7,@=VET:"X*("`@("`@("`@("`@)R\\<W1Y;&5;7CY=*CXN*C\\
M7"]S='EL93XO:2<@/3X@)R<L"@H@("`@("`@("`@("`O+R!#;VUM96YT<R`M
M+2!W:&EC:"!S=')I<%]T86=S*"D@;6EG:'0@:&%V92!A('!R;V)L96T@=VET
M:"X*("`@("`@("`@("`@+R\@+R\G+SPA+2T@+BH@+2T^+R<@/3X@)R<L"@H@
M("`@("`@("`@("`O+R!H,2`M(&@S"B`@("`@("`@("`@("<O/&A;,3(S75M>
M/ETJ/B@N*S\I/%PO:%LQ,C-=/B`_+VEE)R`]/B`G<W1R=&]U<'!E<B@B7&Y<
M;B(@+B!<)UPQ7"<@+B`B7&Y<;B(I)RP*"B`@("`@("`@("`@("\O(&@T("T@
M:#8*("`@("`@("`@("`@)R\\:%LT-39=6UX^72H^*"XK/RD\7"]H6S0U-ET^
M(#\O:64G(#T^("=U8W=O<F1S*")<;EQN(B`N(%PG7#%<)R`N(")<;EQN(BDG
M+`H*("`@("`@("`@("`@+R\@/'`^"B`@("`@("`@("`@("<O/'!;7CY=*CX@
M/R]I)R`]/B`B7&Y<;B`@(BP*"B`@("`@("`@("`@("\O(#QB<CX*("`@("`@
M("`@("`@)R\\8G);7CY=*CX@/R]I)R`]/B`B7&XB+`H*("`@("`@("`@("`@
M+R\@/&(^"B`@("`@("`@("`@("<O/&);7CY=*CXH+BL_*3Q<+V(^+VEE)R`]
M/B`G<W1R=&]U<'!E<BA<)UPQ7"<I)RP*"B`@("`@("`@("`@("\O(#QS=')O
M;F<^"B`@("`@("`@("`@("<O/'-T<F]N9UM>/ETJ/B@N*S\I/%PO<W1R;VYG
M/B]I92<@/3X@)W-T<G1O=7!P97(H7"=<,5PG*2<L"B`@("`@("`@("`@("<O
M/'-P86Y<7',K<W1Y;&4](F9O;G0M=V5I9VAT.EQ<<RIB;VQD+BHB/B@N*S\I
M/%PO<W!A;CXO:64G(#T^("=S=')T;W5P<&5R*%PG7#%<)RDG+`H*("`@("`@
M("`@("`@+R\@/&D^"B`@("`@("`@("`@("<O/&E;7CY=*CXH+BL_*3Q<+VD^
M+VDG(#T^("<O7%PQ+R<L"@H@("`@("`@("`@("`O+R`\96T^"B`@("`@("`@
M("`@("<O/&5M6UX^72H^*"XK/RD\7"]E;3XO:2<@/3X@)R]<7#$O)RP*"B`@
M("`@("`@("`@("\O(#QU/@H@("`@("`@("`@("`G+SQU6UX^72H^*"XK/RD\
M7"]U/B]I)R`]/B`G7UQ<,5\G+`H*("`@("`@("`@("`@+R\@/'5L/B\\;VP^
M(&%N9"`\+W5L/B\\+V]L/@H@("`@("`@("`@("`G+R@\*'5\;REL6UX^72H^
M?"`_/%PO*'5\;REL/BD@/R]I)R`]/B`B7&Y<;B(L"@H@("`@("`@("`@("`O
M+R`\;&D^"B`@("`@("`@("`@("<O(#\\;&E;7CY=*CXO:2<@/3X@(EQN("`J
M("(L"@H@("`@("`@("`@("`O+R`\82!H<F5F/2(B/@H@("`@("`@("`@("`G
M+SQA(&AR968](BA;7B)=*RDB6UX^72H^*"XK/RD\7"]A/B]I92<@/3X@)U1E
M>'1?1FEL=&5R7VAT;6PR=&5X=#HZ7V)U:6QD3&EN:TQI<W0H)$=,3T)!3%-;
M(E]H=&UL,G1E>'1?<W1A=&4B75LB;&EN:T-O=6YT(ETL(%PG7#%<)RP@7"=<
M,EPG*2<L"@H@("`@("`@("`@("`O+R`\:'(^"B`@("`@("`@("`@("<O/&AR
M6UX^72H^(#\O:2<@/3X@(EQN+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+5QN
M(BP*"B`@("`@("`@("`@("\O(#QT86)L93X@86YD(#PO=&%B;&4^"B`@("`@
M("`@("`@("<O*#QT86)L95M>/ETJ/GP@/SQ<+W1A8FQE/BD@/R]I)R`]/B`B
M7&Y<;B(L"@H@("`@("`@("`@("`O+R`\='(^"B`@("`@("`@("`@("<O(#\\
M=');7CY=*CX@/R]I)R`]/B`B7&Y<="(L"@H@("`@("`@("`@("`O+R`\=&0^
M(&%N9"`\+W1D/@H@("`@("`@("`@("`G+R`_/'1D6UX^72H^*"XK/RD\7"]T
M9#X@/R]I)R`]/B`G7#$G("X@(EQT7'0B+`H@("`@("`@("`@("`G+UQT7'0\
M7"]T<CXO:2<@/3X@)R<L"@H@("`@("`@("`@("`O+R!E;G1I=&EE<PH@("`@
M("`@("`@("`G+R9N8G-P.R]I)R`]/B`G("<L"B`@("`@("`@("`@("<O)G1R
M861E.R]I)R`]/B`G*'1M*2<L"B`@("`@("`@("`@("<O)B,H7&0K*3LO92<@
M/3X@)U-T<FEN9SHZ8V]N=F5R=$-H87)S970H5&5X=%]&:6QT97)?:'1M;#)T
M97AT.CI?:6YT,G5T9C@H7"=<,5PG*2P@(E541BTX(BP@(B<@+B`D=&AI<RT^
M7W!A<F%M<ULG8VAA<G-E="==("X@)R(I)RP*"B`@("`@("`@("`@("\O(%-O
M;64@;6%I;&5R<R`H92YG+B!(;W1M86EL*2!U<V4@=&AE(&9O;&QO=VEN9R!D
M:78@=&%G(&%S(&$@=V%Y"B`@("`@("`@("`@("\O('1O(&1E9FEN92!A(&)L
M;V-K(&]F('1E>'0N"B`@("`@("`@("`@("<O/&1I=B!C;&%S<SUR=&4^*"XK
M/RD\7"]D:78^(#\O:2<@/3X@)UPQ)R`N(")<;B(*("`@("`@("`I.PH*("`@
M("`@("!R971U<FX@87)R87DH)W)E9V5X<"<@/3X@)')E9V5X<"D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!%>&5C=71E<R!A;GD@8V]D92!N96-E<W-A<F%Y
M(&%F=&5R(&%P<&QY:6YG('1H92!F:6QT97(*("`@("`J('!A='1E<FYS+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT(&%F
M=&5R('1H92!F:6QT97)I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!M;V1I9FEE9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!P
M;W-T4')O8V5S<R@D=&5X="D*("`@('L*("`@("`@("!G;&]B86P@)%]H=&UL
M,G1E>'1?<W1A=&4["@H@("`@("`@("\J(%-T<FEP(&%N>2!O=&AE<B!(5$U,
M('1A9W,N("HO"B`@("`@("`@)'1E>'0@/2!S=')I<%]T86=S*"1T97AT*3L*
M"B`@("`@("`@+RH@0V]N=F5R="!H=&UL(&5N=&ET:65S+B`J+PH@("`@("`@
M("1T97AT(#T@0&AT;6Q?96YT:71Y7V1E8V]D92@D=&5X="P@14Y47U%53U1%
M4RP@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72D["@H@("`@("`@("\J($)R
M:6YG(&1O=VX@;G5M8F5R(&]F(&5M<'1Y(&QI;F5S('1O(#(@;6%X+B`J+PH@
M("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"(O7&Y;6SIS<&%C93I=72M<
M;B\B+"`B7&Y<;B(L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P
M;&%C92@B+UM<;EU[,RQ]+R(L(")<;EQN(BP@)'1E>'0I.PH*("`@("`@("`O
M*B!7<F%P('1H92!T97AT('1O(&$@<F5A9&%B;&4@9F]R;6%T+B`J+PH@("`@
M("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG=W)A<"==*2!["B`@("`@("`@("`@
M("1T97AT(#T@=V]R9'=R87`H)'1E>'0L("1T:&ES+3Y?<&%R86US6R=W:61T
M:"==*3L*("`@("`@("!]"@H@("`@("`@("\J($%D9"!L:6YK(&QI<W0N("HO
M"B`@("`@("`@:68@*"%E;7!T>2@D7VAT;6PR=&5X=%]S=&%T95LG;&EN:TQI
M<W0G72DI('L*("`@("`@("`@("`@)'1E>'0@+CT@(EQN7&XB("X@7R@B3&EN
M:W,B*2`N("(Z7&XB("X@<W1R7W)E<&5A="@G+2<L(%-T<FEN9SHZ;&5N9W1H
M*%\H(DQI;FMS(BDI("L@,2D@+B`B7&XB("X@)%]H=&UL,G1E>'1?<W1A=&5;
M)VQI;FM,:7-T)UT["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1E>'0[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!55$8M."!C:&%R
M86-T97(@<V5Q=65N8V4@;V8@82!5;FEC;V1E('9A;'5E+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1N=6T@($$@56YI8V]D92!V86QU92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(%541BTX('-T<FEN9RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@7VEN=#)U=&8X*"1N=6TI"B`@("!["B`@
M("`@("`@:68@*"1N=6T@/"`Q,C@I('L*("`@("`@("`@("`@<F5T=7)N(&-H
M<B@D;G5M*3L*("`@("`@("!]"B`@("`@("`@:68@*"1N=6T@/"`R,#0X*2![
M"B`@("`@("`@("`@(')E='5R;B!C:'(H*"1N=6T@/CX@-BD@*R`Q.3(I("X@
M8VAR*"@D;G5M("8@-C,I("L@,3(X*3L*("`@("`@("!]"B`@("`@("`@:68@
M*"1N=6T@/"`V-34S-BD@>PH@("`@("`@("`@("!R971U<FX@8VAR*"@D;G5M
M(#X^(#$R*2`K(#(R-"D@+B!C:'(H*"@D;G5M(#X^(#8I("8@-C,I("L@,3(X
M*2`N"B`@("`@("`@("`@("`@("!C:'(H*"1N=6T@)B`V,RD@*R`Q,C@I.PH@
M("`@("`@('T*("`@("`@("!I9B`H)&YU;2`\(#(P.3<Q-3(I('L*("`@("`@
M("`@("`@<F5T=7)N(&-H<B@H)&YU;2`^/B`Q."D@*R`R-#`I("X@8VAR*"@H
M)&YU;2`^/B`Q,BD@)B`V,RD@*R`Q,C@I("X*("`@("`@("`@("`@("`@(&-H
M<B@H*"1N=6T@/CX@-BD@)B`V,RD@*R`Q,C@I("X@8VAR*"@D;G5M("8@-C,I
M("L@,3(X*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("<G.PH@("`@?0H*
M("`@("\J*@H@("`@("H@2&5L<&5R(&9U;F-T:6]N(&-A;&QE9"!B>2!P<F5G
M7W)E<&QA8V4H*2!O;B!L:6YK(')E<&QA8V5M96YT+@H@("`@("H*("`@("`J
M($UA:6YT86EN<R!A;B!I;G1E<FYA;"!L:7-T(&]F(&QI;FMS('1O(&)E(&1I
M<W!L87EE9"!A="!T:&4@96YD"B`@("`@*B!O9B!T:&4@=&5X="P@=VET:"!N
M=6UE<FEC(&EN9&EC97,@=&\@=&AE(&]R:6=I;F%L('!O:6YT(&EN('1H90H@
M("`@("H@=&5X="!T:&5Y(&%P<&5A<F5D+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1L:6YK
M7V-O=6YT("!#;W5N=&5R('1R86-K:6YG(&-U<G)E;G0@;&EN:R!N=6UB97(N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("`D;&EN:R`@("`@("`@55),(&]F('1H
M92!L:6YK+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&1I<W!L87D@("`@(%!A
M<G0@;V8@=&AE('1E>'0@=&\@87-S;V-I871E(&YU;6)E<B!W:71H+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;&EN:R!R97!L86-E;65N
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@7V)U:6QD3&EN:TQI<W0H)&QI;FM?
M8V]U;G0L("1L:6YK+"`D9&ES<&QA>2D*("`@('L*("`@("`@("!G;&]B86P@
M)%]H=&UL,G1E>'1?<W1A=&4["@H@("`@("`@("1?:'1M;#)T97AT7W-T871E
M6R=L:6YK0V]U;G0G72LK.PH@("`@("`@("1?:'1M;#)T97AT7W-T871E6R=L
M:6YK3&ES="==("X]("=;)R`N("1?:'1M;#)T97AT7W-T871E6R=L:6YK0V]U
M;G0G72`N(")=("1L:6YK7&XB.PH@("`@("`@(')E='5R;B`D9&ES<&QA>2`N
M("=;)R`N("1?:'1M;#)T97AT7W-T871E6R=L:6YK0V]U;G0G72`N("==)SL*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VQI;FMU<FQS+G!H<```
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3(Q-@`Q,#4Q-30S,S<U,``P,C0R
M,3,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J(%1H92!497AT7T9I;'1E<E]L:6YK=7)L<SHZ(&-L87-S
M('1U<FYS(&%L;"!54DQS(&EN('1H92!T97AT(&EN=&\@:'EP97)L:6YK<RX*
M("H*("H@4&%R86UE=&5R<SH*("H@/'!R93X*("H@=&%R9V5T("`@+2T@5&AE
M(&QI;FL@=&%R9V5T+B`@1&5F875L=',@=&\@7V)L86YK+@H@*B!C;&%S<R`@
M("`M+2!4:&4@0U-3(&-L87-S(&]F('1H92!G96YE<F%T960@;&EN:W,N("!$
M969A=6QT<R!T;R!N;VYE+@H@*B!N;V9O;&QO=R`M+2!7:&5T:&5R('1O('-E
M="!T:&4@)W)E;#TB;F]F;VQL;W<B)R!A='1R:6)U=&4@;VX@;&EN:W,N"B`J
M(&-A<&ET86P@("TM(&=E;F5R871E('5P<&5R8V%S92`\03X@=&%G<R!S;R!Y
M;W4@8V%N(&MN;W<@=VAI8V@@=&%G<R!Y;W4@:G5S=`H@*B`@("`@("`@("`@
M("!G96YE<F%T960N("!$969A=6QT<R!T;R!F86QS92X*("H@8V%L;&)A8VL@
M+2T@06X@;W!T:6]N86P@8V%L;&)A8VL@9G5N8W1I;VX@=&AA="!T:&4@55),
M(&ES('!A<W-E9"!T:')O=6=H"B`J("`@("`@("`@("`@(&)E9F]R92!B96EN
M9R!S970@87,@=&AE(&AR968@871T<FEB=71E+B`@375S="!B92!A('-T<FEN
M9R!W:71H"B`J("`@("`@("`@("`@('1H92!F=6YC=&EO;B!N86UE+"!T:&4@
M9G5N8W1I;VX@;75S="!T86ME('1H92!O<FEG:6YA;"!A<R!T:&4*("H@("`@
M("`@("`@("`@9FER<W0@86YD(&]N;'D@<&%R86UE=&5R+@H@*B`\+W!R93X*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VQI
M;FMU<FQS+G!H<"QV(#$N,3$N,3`N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C,X(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V(%1Y;&5R($-O;&)E
M<G0@/'1Y;&5R+6AO<F1E;6Q`8V]L8F5R=',N=7,^"B`J($-O<'ER:6=H="`R
M,#`T+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@(%1Y;&5R($-O;&)E<G0@/'1Y;&5R+6AO
M<F1E;6Q`8V]L8F5R=',N=7,^"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@
M/&IA;D!H;W)D92YO<F<^"B`J($!P86-K86=E($AO<F1E7U1E>'0*("HO"F-L
M87-S(%1E>'1?1FEL=&5R7VQI;FMU<FQS(&5X=&5N9',@5&5X=%]&:6QT97(@
M>PH*("`@("\J*@H@("`@("H@1FEL=&5R('!A<F%M971E<G,N"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A
M<G)A>2@G=&%R9V5T)R`]/B`G7V)L86YK)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("=C;&%S<R<@/3X@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`G;F]F;VQL;W<G(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@)V-A<&ET86PG(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@)V-A;&QB86-K)R`]/B!N=6QL*3L*"B`@("`O*BH*("`@("`J($5X96-U
M=&5S(&%N>2!C;V1E(&YE8V5S<V%R>2!B969O<F4@87!P;'EI;F<@=&AE(&9I
M;'1E<B!P871T97)N<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M97AT("!4:&4@=&5X="!B969O<F4@=&AE(&9I;'1E<FEN9RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&UO9&EF:65D('1E>'0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('!R95!R;V-E<W,H)'1E>'0I"B`@("!["B`@("`@
M("`@:68@*"1T:&ES+3Y?<&%R86US6R=C87!I=&%L)UTI('L*("`@("`@("`@
M("`@)'1E>'0@/2!S=')?<F5P;&%C92AA<G)A>2@G/"]!/B<L("<\02<I+"!A
M<G)A>2@G/"]A/B<L("<\82<I+"`D=&5X="D["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)'1E>'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&$@:&%S:"!W:71H(')E<&QA8V4@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@4&%T=&5R;G,@:&%S:"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4&%T=&5R;G,H*0H@("`@>PH@("`@("`@("1A(#T@)'1H:7,M
M/E]P87)A;7-;)V-A<&ET86PG72`_("=!)R`Z("=A)SL*"B`@("`@("`@)&-L
M87-S(#T@)'1H:7,M/E]P87)A;7-;)V-L87-S)UT["B`@("`@("`@:68@*"%E
M;7!T>2@D8VQA<W,I*2!["B`@("`@("`@("`@("1C;&%S<R`]("<@8VQA<W,]
M(B<@+B`D8VQA<W,@+B`G(B<["B`@("`@("`@?0H@("`@("`@("1N;V9O;&QO
M=R`]("1T:&ES+3Y?<&%R86US6R=N;V9O;&QO=R==(#\@)R!R96P](FYO9F]L
M;&]W(B<@.B`G)SL*"B`@("`@("`@)'5R;"`]("1T:&ES+3Y?<&%R86US6R=C
M86QL8F%C:R==(#\@)UPG("X@)R`N("1T:&ES+3Y?<&%R86US6R=C86QL8F%C
M:R==("X@)RA<)R0P7"<I("X@7"<G(#H@)R0P)SL*"B`@("`@("`@)')E9V5X
M<"`](&%R<F%Y*"=\*%QW*RDZ+R\H6UY<<R(\72I;7'<K(S\O)CU=*7QE)R`]
M/@H@("`@("`@("`@("`@("`@("`@("`@("`G7"<\)R`N("1A("X@)R!H<F5F
M/2(G("X@)'5R;"`N("<B)R`N("1N;V9O;&QO=R`N("<@=&%R9V5T/2)?8FQA
M;FLB)R`N("1C;&%S<R`N("<^)#`\+R<@+B`D82`N("<^7"<G*3L*"B`@("`@
M("`@<F5T=7)N(&%R<F%Y*"=R96=E>'`G(#T^("1R96=E>'`I.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O5&5X="]&:6QT97(O<G-T+G!H<```````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`Q-S4V`#$P-3$U-#,S-S4P`#`R,S$V-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`H*<F5Q=6ER95]O
M;F-E("=497AT+W)E4U0N<&AP)SL*<F5Q=6ER95]O;F-E("=497AT+W)E4U0O
M1F]R;6%T=&5R+G!H<"<["@HO*BH*("H@5&AE(%1E>'1?1FEL=&5R7W)S=#HZ
M(&-L87-S(&-O;G9E<G1S(')E4W1R=6-T=7)E9%1E>'0@=&\@2%1-3"X*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+W)S="YP
M:'`L=B`Q+CDN,3`N-"`R,#`V+S`Q+S`Q(#(Q.C(X.C,X(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($IA<V]N($TN($9E;&EC92`\:F9E
M;&EC94!C<F]N;W-Y<RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!*87-O;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@*B!`
M<&%C:V%G92!(;W)D95]497AT"B`J+PIC;&%S<R!497AT7T9I;'1E<E]R<W0@
M97AT96YD<R!497AT7T9I;'1E<B!["@H@("`@+RHJ"B`@("`@*B!%>&5C=71E
M<R!A;GD@8V]D92!N96-E<W-A<F%Y(&%F=&5R(&%P<&QY:6YG('1H92!F:6QT
M97(*("`@("`J('!A='1E<FYS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'1E>'0@(%1H92!T97AT(&%F=&5R('1H92!F:6QT97)I;F<N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!M;V1I9FEE9"!T97AT+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!P;W-T4')O8V5S<R@D=&5X="D*("`@('L*
M("`@("`@("`D9&]C=6UE;G0@/2`F5&5X=%]R95-4.CIP87)S92@D=&5X="D[
M"B`@("`@("`@)&9O<FUA='1E<B`]("9497AT7W)E4U1?1F]R;6%T=&5R.CIF
M86-T;W)Y*"=H=&UL)RD["B`@("`@("`@<F5T=7)N("1F;W)M871T97(M/F9O
M<FUA="@D9&]C=6UE;G0L($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@('T*"GT*
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O5&5X="]&:6QT97(O<VEM<&QE;6%R:W5P+G!H<```````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R,3$U`#$P-3$U-#,S-S4P`#`R-3`U-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@2&EG:&QI9VAT<R!S:6UP;&4@;6%R:W5P(&%S('5S960@:6X@96UA:6QS
M(&]R('5S96YE="!P;W-T:6YG<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M5&5X=%]&:6QT97(O1FEL=&5R+W-I;7!L96UA<FMU<"YP:'`L=B`Q+C$N,3`N
M-2`R,#`V+S`W+S(T(#$U.C4T.C4T('-L=7-A<GH@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#0M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\
M:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K
M86=E($AO<F1E7U1E>'0*("HO"F-L87-S(%1E>'1?1FEL=&5R7W-I;7!L96UA
M<FMU<"!E>'1E;F1S(%1E>'1?1FEL=&5R('L*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@82!H87-H('=I=&@@<F5P;&%C92!P871T97)N<RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!0871T97)N<R!H87-H+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G9710871T97)N<R@I"B`@("!["B`@("`@("`@)')E9V5X
M<"`](&%R<F%Y*`H@("`@("`@("`@("`O+R!";VQD+@H@("`@("`@("`@("`G
M+RA>?%QS?"9N8G-P.WP\8G(@7"\^*2A<*EM>*EQS72M<*BDH7'-\)FYB<W`[
M?#QB<GQ<+BDO:2<@/3X@)UPQ/'-T<F]N9SY<,CPO<W1R;VYG/EPS)RP*"B`@
M("`@("`@("`@("\O(%5N9&5R;&EN92X*("`@("`@("`@("`@)R\H7GQ<<WPF
M;F)S<#M\/&)R(%PO/BDH7UM>7UQS72M?*2A<<WPF;F)S<#M\/&)R?%PN*2]I
M)R`]/B`G7#$\=3Y<,CPO=3Y<,R<L"@H@("`@("`@("`@("`O+R!)=&%L:6,N
M"B`@("`@("`@("`@("<[*%Y\7'-\)FYB<W!<.WP\8G(@+SXI*"];7B]<<UTK
M+RDH7'-\)FYB<W!<.WP\8G)\7"XI.VDG(#T^("=<,3QE;3Y<,CPO96T^7#,G
M*3L*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"=R96=E>'`G(#T^("1R96=E>'`I
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]497AT+T9I;'1E<B]S
M<&%C93)H=&UL+G!H<```````````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0R,C<`,3`U
M,34T,S,W-3``,#(T-#$S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B!4:&4@<W!A8V4R:'1M;"!F:6QT
M97(@8V]N=F5R=',@:&]R:7IO;G1A;"!W:&ET97-P86-E('1O($A434P@8V]D
M92X*("H*("H@4&%R86UE=&5R<SH*("H@/'!R93X*("H@96YC;V1E("`@("`M
M+2!(5$U,(&5N8V]D92!T:&4@=&5X=#\@($1E9F%U;'1S('1O(&9A;'-E+@H@
M*B!C:&%R<V5T("`@("TM($-H87)S970@;V8@=&AE('1E>'0N("!$969A=6QT
M<R!T;R!)4T\M.#@U.2TQ+@H@*B!E;F-O9&5?86QL("TM(%)E<&QA8V4@86QL
M('-P86-E<R!W:71H("9N8G-P.S\@($1E9F%U;'1S('1O(&9A;'-E+@H@*B`\
M+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL
M=&5R+W-P86-E,FAT;6PN<&AP+'8@,2XQ+C$P+C4@,C`P-B\P,2\P,2`R,3HR
M.#HS."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#$@36%T:&EE=2!!
M<FYO;&0@/&%R;E]M871`8VQU8BUI;G1E<FYE="YF<CX*("H@0V]P>7)I9VAT
M(#(P,#0M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO
M<F1E+F]R9SX*("H@0&%U=&AO<B`@36%T:&EE=2!!<FYO;&0@/&%R;E]M871`
M8VQU8BUI;G1E<FYE="YF<CX*("H@0'!A8VMA9V4@2&]R9&5?5&5X=`H@*B\*
M8VQA<W,@5&5X=%]&:6QT97)?<W!A8V4R:'1M;"!E>'1E;F1S(%1E>'1?1FEL
M=&5R('L*"B`@("`O*BH*("`@("`J($9I;'1E<B!P87)A;65T97)S+@H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R86US
M(#T@87)R87DH)V5N8V]D92<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`G8VAA<G-E="<@/3X@)TE33RTX.#4Y+3$G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@)V5N8V]D95]A;&PG(#T^(&9A;'-E*3L*"B`@("`O
M*BH*("`@("`J($5X96-U=&5S(&%N>2!C;V1E(&YE8V5S<V%R>2!B969O<F4@
M87!P;'EI;F<@=&AE(&9I;'1E<B!P871T97)N<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!B969O<F4@=&AE(&9I;'1E
M<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&UO9&EF
M:65D('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N('!R95!R;V-E<W,H)'1E
M>'0I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?<&%R86US6R=E;F-O9&4G
M72D@>PH@("`@("`@("`@("`D=&5X="`]($!H=&UL<W!E8VEA;&-H87)S*"1T
M97AT+"!%3E1?0T]-4$%4+"`D=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==*3L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T97AT.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!A(&AA<V@@=VET:"!R97!L86-E('!A='1E<FYS
M+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%!A='1E<FYS(&AA<V@N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A='1E<FYS*"D*("`@('L*("`@
M("`@("`D<F5P;&%C92`](&%R<F%Y*")<="(@/3X@)R9N8G-P.R`F;F)S<#L@
M)FYB<W`[("9N8G-P.R`G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)R`@
M)R`]/B`G)FYB<W`[("<I.PH@("`@("`@(')E='5R;B!A<G)A>2@G<F5P;&%C
M92<@/3X@)')E<&QA8V4I.PH@("`@?0H*("`@("\J*@H@("`@("H@17AE8W5T
M97,@86YY(&-O9&4@;F5C97-S87)A>2!A9G1E<B!A<'!L>6EN9R!T:&4@9FEL
M=&5R('!A='1E<FYS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E
M>'0@(%1H92!T97AT(&%F=&5R('1H92!F:6QT97)I;F<N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!M;V1I9FEE9"!T97AT+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!P;W-T4')O8V5S<R@D=&5X="D*("`@('L*("`@("`@
M("`D=&5X="`]('-T<E]R97!L86-E*"<@("<L("<@)FYB<W`[)RP@)'1E>'0I
M.PH@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG96YC;V1E7V%L;"==*2![
M"B`@("`@("`@("`@("1T97AT(#T@<W1R7W)E<&QA8V4H)R`G+"`G)FYB<W`[
M)RP@)'1E>'0I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1E>'0["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]4
M97AT+T9I;'1E<B]T86)S,G-P86-E<RYP:'``````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(U,#,`,3`U,34T,S,W-3``,#(T-34V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@5&5X
M=%]&:6QT97)?=&%B<S)S<&%C97,Z.B!C;VYV97)T<R!T86)S(&EN=&\@<W!A
M8V5S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O=&%B<S)S<&%C97,N<&AP+'8@,2XS+C$P+C8@,C`P-B\P,2\P,2`R,3HR
M.#HS."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*B!`<&%C:V%G92!(;W)D95]497AT"B`J+PIC;&%S<R!497AT7T9I;'1E
M<E]T86)S,G-P86-E<R!E>'1E;F1S(%1E>'1?1FEL=&5R('L*"B`@("`O*BH*
M("`@("`J($9I;'1E<B!P87)A;65T97)S+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R86US(#T@87)R87DH)W1A8G-T
M;W`G(#T^(#@L("=B<F5A:V-H87(G(#T^(")<;B(I.PH*("`@("\J*@H@("`@
M("H@17AE8W5T97,@86YY(&-O9&4@;F5C97-S87)Y(&)E9F]R92!A<'!L>6EN
M9R!T:&4@9FEL=&5R('!A='1E<FYS+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'1E>'0@(%1H92!T97AT(&)E9F]R92!T:&4@9FEL=&5R:6YG+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;6]D:69I960@=&5X
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@<')E4')O8V5S<R@D=&5X="D*("`@
M('L*("`@("`@("`D;&EN97,@/2!E>'!L;V1E*"1T:&ES+3Y?<&%R86US6R=B
M<F5A:V-H87(G72P@)'1E>'0I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M(&-O=6YT*"1L:6YE<RD[("1I*RLI('L*("`@("`@("`@("`@=VAI;&4@*"@D
M<&]S(#T@<W1R<&]S*"1L:6YE<ULD:5TL(")<="(I*2`A/3T@9F%L<V4I('L*
M("`@("`@("`@("`@("`@("1N7W-P86-E(#T@)'1H:7,M/E]P87)A;7-;)W1A
M8G-T;W`G72`M("@D<&]S("4@)'1H:7,M/E]P87)A;7-;)W1A8G-T;W`G72D[
M"B`@("`@("`@("`@("`@("`D;F5W7W-T<B`]('-T<E]R97!E870H)R`G+"`D
M;E]S<&%C92D["B`@("`@("`@("`@("`@("`D;&EN97-;)&E=(#T@<W5B<W1R
M7W)E<&QA8V4H)&QI;F5S6R1I72P@)&YE=U]S='(L("1P;W,L(#$I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!I;7!L;V1E*")<
M;B(L("1L:6YE<RD["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+W1E>'0R:'1M;"YP
M:'`````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,C0V-P`Q,#4Q-30S,S<U,``P
M,C0S,3$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4N<&AP)SL*"B\J*@H@*B!4
M=7)N('1E>'0@:6YT;R!(5$U,('=I=&@@=F%R>6EN9R!L979E;',@;V8@<&%R
M<VEN9RX@($9O<B!N;R!H=&UL"B`J('=H871S;V5V97(L('5S92!H=&UL<W!E
M8VEA;&-H87)S*"D@:6YS=&5A9"X*("H*("H@4&%R86UE=&5R<SH*("H@/'!R
M93X*("H@<&%R<V5L979E;"`M+2!4:&4@<&%R<V5L979E;"!O9B!T:&4@;W5T
M<'5T+B!3964@=&AE(&QI<W0@;V8@8V]N<W1A;G1S(&)E;&]W+@H@*B!C:&%R
M<V5T("`@("TM(%1H92!C:&%R<V5T('1O('5S92!F;W(@:'1M;'-P96-I86QC
M:&%R<R@I(&-A;&QS+@H@*B!C;&%S<R`@("`@("TM(%1H92!#4U,@8VQA<W,@
M;F%M92!F;W(@=&AE(&QI;FMS+@H@*B!N;V9O;&QO=R`@("TM(%=H971H97(@
M=&\@<V5T('1H92`G<F5L/2)N;V9O;&QO=R(G(&%T=')I8G5T92!O;B!L:6YK
M<RX*("H@8V%L;&)A8VL@("`M+2!!;B!O<'1I;VYA;"!C86QL8F%C:R!F=6YC
M=&EO;B!T:&%T('1H92!54DP@:7,@<&%S<V5D('1H<F]U9V@*("H@("`@("`@
M("`@("`@("!B969O<F4@8F5I;F<@<V5T(&%S('1H92!H<F5F(&%T=')I8G5T
M92X@($UU<W0@8F4@82!S=')I;F<@=VET:`H@*B`@("`@("`@("`@("`@('1H
M92!F=6YC=&EO;B!N86UE+"!T:&4@9G5N8W1I;VX@;75S="!T86ME('1H92!O
M<FEG:6YA;"!A<R!T:&4*("H@("`@("`@("`@("`@("!F:7)S="!A;F0@;VYL
M>2!P87)A;65T97(N"B`J(#PO<')E/@H@*@H@*B`\<')E/@H@*B!,:7-T(&]F
M('9A;&ED(&-O;G-T86YT<R!F;W(@=&AE('!A<G-E(&QE=F5L.@H@*B`M+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H@*B!4
M15A47TA434Q?4$%34U1(4E4@("`@("`@(#T@($YO(&%C=&EO;BX@4&%S<RUT
M:')O=6=H+B!);F-L=61E9"!F;W(*("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!C;VUP;&5T96YE<W,N"B`J(%1%6%1?2%1-3%]364Y405@@("`@
M("`@("`@/2`@06QL;W<@9G5L;"!H=&UL+"!A;'-O(&1O(&QI;F4M8G)E86MS
M+`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EN+6QI;FEN9RP@
M<WEN=&%X+7!A<G-I;F<N"B`J(%1%6%1?2%1-3%]-24-23R`@("`@("`@("`@
M/2`@36EC<F\@:'1M;"`H;VYL>2!L:6YE+6)R96%K<RP@:6XM;&EN92!L:6YK
M:6YG*2X*("H@5$585%](5$U,7TU)0U)/7TQ)3DM54DP@("`]("!-:6-R;R!H
M=&UL("AO;FQY(&QI;F4M8G)E86MS+"!I;BUL:6YE(&QI;FMI;F<*("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!O9B!54DQ3<SL@;F\@96UA:6P@
M861D<F5S<V5S(&%R92!L:6YK960I+@H@*B!415A47TA434Q?3D](5$U,("`@
M("`@("`@(#T@($YO(&AT;6P@*&%L;"!S=')I<'!E9"P@;VYL>2!L:6YE+6)R
M96%K<RD*("H@5$585%](5$U,7TY/2%1-3%].3T)214%+("`]("!.;R!H=&UL
M('=H871S;V5V97(L(&YO(&QI;F4@8G)E86MS(&%D9&5D+@H@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@($EN8VQU9&5D(&9O<B!C;VUP;&5T96YE
M<W,N"B`J(#PO<')E/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]497AT7T9I
M;'1E<B]&:6QT97(O=&5X=#)H=&UL+G!H<"QV(#$N-"XR+C8@,C`P-B\P,B\Q
M-R`R,#HP-3HT.2!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR
M,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y
M<FEG:'0@,C`P-"TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\
M:F%N0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@2&]R9&5?5&5X=`H@*B\*8VQA
M<W,@5&5X=%]&:6QT97)?=&5X=#)H=&UL(&5X=&5N9',@5&5X=%]&:6QT97(@
M>PH*("`@("\J*@H@("`@("H@1FEL=&5R('!A<F%M971E<G,N"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A
M<G)A>2@G8VAA<G-E="<@/3X@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("=C;&%S<R<@/3X@)V9I>&5D)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("=N;V9O;&QO=R<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`G8V%L;&)A8VLG(#T^("=(;W)D93HZ97AT97)N86Q5<FPG*3L*"B`@
M("`O*BH*("`@("`J($5X96-U=&5S(&%N>2!C;V1E(&YE8V5S<V%R>2!B969O
M<F4@87!P;'EI;F<@=&AE(&9I;'1E<B!P871T97)N<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!B969O<F4@=&AE(&9I
M;'1E<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&UO
M9&EF:65D('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N('!R95!R;V-E<W,H
M)'1E>'0I"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)'1H:7,M/E]P87)A
M;7-;)V-H87)S970G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)V-H87)S970G72`](&ES<V5T*"1'3$]"04Q36R=?2$]21$5?4U1224Y'7T-(
M05)3150G72D@/R`D1TQ/0D%,4ULG7TA/4D1%7U-44DE.1U]#2$%24T54)UT@
M.B`G25-/+3@X-3DM,2<["B`@("`@("`@?0H*("`@("`@("`O*B!!8F]R="!O
M=70@;VX@<VEM<&QE(&-A<V5S+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W!A
M<F%M<ULG<&%R<V5L979E;"==(#T](%1%6%1?2%1-3%]005-35$A252D@>PH@
M("`@("`@("`@("!R971U<FX@)'1E>'0["B`@("`@("`@?0H@("`@("`@(&EF
M("@D=&AI<RT^7W!A<F%M<ULG<&%R<V5L979E;"==(#T](%1%6%1?2%1-3%].
M3TA434Q?3D]"4D5!2RD@>PH@("`@("`@("`@("!R971U<FX@0&AT;6QS<&5C
M:6%L8VAA<G,H)'1E>'0L($5.5%]#3TU0050L("1T:&ES+3Y?<&%R86US6R=C
M:&%R<V5T)UTI.PH@("`@("`@('T*"B`@("`@("`@+RH@1&\@:6XM;&EN:6YG
M(&]F(&AT='`Z+R]X>'@N>'AX('1O(&QI;FLL('AX>$!X>'@N>'AX('1O(&5M
M86EL+"!P87)T"B`@("`@("`@("H@;VYE+B`J+PH@("`@("`@(&EF("@D=&AI
M<RT^7W!A<F%M<ULG<&%R<V5L979E;"==(#P@5$585%](5$U,7TY/2%1-3"D@
M>PH@("`@("`@("`@("`O*B!-86ME('-U<F4@=&AA="!T:&4@;W)I9VEN86P@
M;65S<V%G92!D;V5S;B=T(&-O;G1A:6X@86YY(&-A<&ET86P*("`@("`@("`@
M("`@("H@/"]!/B!T86=S(&]R(&]P96X@/$$^('1A9W,@+"!S;R!W92!C86X@
M87-S=6UE('=E(&=E;F5R871E9`H@("`@("`@("`@("`@*B!T:&5M+B`J+PH@
M("`@("`@("`@("`D=&5X="`]('-T<E]R97!L86-E*&%R<F%Y*"<\+T$^)RP@
M)SQ!)RDL(&%R<F%Y*"<\+V$^)RP@)SQA)RDL("1T97AT*3L*("`@("`@("`@
M("`@)&9I;'1E<E]A<G)A>2`](&%R<F%Y*"=L:6YK=7)L<R<I.PH@("`@("`@
M("`@("`D9FEL=&5R7W!A<F%M<R`](&%R<F%Y*&%R<F%Y*"=C86QL8F%C:R<@
M/3X@)'1H:7,M/E]P87)A;7-;)V-A;&QB86-K)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYO9F]L;&]W)R`]/B`D=&AI
M<RT^7W!A<F%M<ULG;F]F;VQL;W<G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G8V%P:71A;"<@/3X@=')U92DI.PH@("`@
M("`@("`@("!I9B`H)'1H:7,M/E]P87)A;7-;)W!A<G-E;&5V96PG72`\(%1%
M6%1?2%1-3%]-24-23U],24Y+55),*2!["B`@("`@("`@("`@("`@("`D9FEL
M=&5R7V%R<F%Y6UT@/2`G96UA:6QS)SL*("`@("`@("`@("`@("`@("1F:6QT
M97)?<&%R86US6UT@/2!A<G)A>2@G8V%P:71A;%]T86=S)R`]/B!T<G5E*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&5X="`](%1E>'1?1FEL=&5R
M.CIF:6QT97(H)'1E>'0L("1F:6QT97)?87)R87DL("1F:6QT97)?<&%R86US
M*3L*("`@("`@("!]"@H@("`@("`@("\J($9O<B!L979E;"!415A47TA434Q?
M34E#4D\L(%1%6%1?2%1-3%].3TA434PL('-T87)T('=I=&@*("`@("`@("`@
M*B!H=&UL<W!E8VEA;&-H87)S*"DN("HO"B`@("`@("`@)'1E>'0@/2!`:'1M
M;'-P96-I86QC:&%R<R@D=&5X="P@14Y47T-/35!!5"P@)'1H:7,M/E]P87)A
M;7-;)V-H87)S970G72D["@H@("`@("`@("\J($1O(&EN+6QI;FEN9R!O9B!H
M='1P.B\O>'AX+GAX>"!T;R!L:6YK+"!X>'A`>'AX+GAX>"!T;R!E;6%I;"P@
M<&%R=`H@("`@("`@("`J('1W;RX@*B\*("`@("`@("!I9B`H)'1H:7,M/E]P
M87)A;7-;)W!A<G-E;&5V96PG72`\(%1%6%1?2%1-3%].3TA434PI('L*("`@
M("`@("`@("`@)'-Y;G1A>"`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)R9L
M=#M!(&AR968])G%U;W0[)R`]/B`G/&$G("X@*&5M<'1Y*"1T:&ES+3Y?<&%R
M86US6R=C;&%S<R==*2`_("<G(#H@)R!C;&%S<STB)R`N("1T:&ES+3Y?<&%R
M86US6R=C;&%S<R==("X@)R(G*2`N("<@:')E9CTB)RP*("`@("`@("`@("`@
M("`@("<F<75O=#L@<F5L/29Q=6]T.R<@/3X@)R(@<F5L/2(G+`H@("`@("`@
M("`@("`@("`@)R9Q=6]T.R!T:71L93TF<75O=#LG(#T^("<B('1I=&QE/2(G
M+`H@("`@("`@("`@("`@("`@)R9Q=6]T.R!T87)G970])G%U;W0[7V)L86YK
M)G%U;W0[)F=T.R<@(#T^("<B('1A<F=E=#TB7V)L86YK(CXG+`H@("`@("`@
M("`@("`@("`@)R9Q=6]T.R!O;F-L:6-K/29Q=6]T.R<@/3X@)R(@;VYC;&EC
M:STB)RP*("`@("`@("`@("`@("`@("=<)RD[)G%U;W0[)F=T.R<@/3X@)UPG
M*3LB/B<L"B`@("`@("`@("`@("`@("`G)G%U;W0[)F=T.R<@/3X@("<B/B<L
M"B`@("`@("`@("`@("`@("`O*B!/;FQY(')E8V]N=F5R="!C87!I=&%L("]!
M('1A9W,@+2!T:&4@;VYE<R!W92!G96YE<F%T960N("HO"B`@("`@("`@("`@
M("`@("`G)FQT.R]!)F=T.R<@/3X@)SPO83XG"B`@("`@("`@("`@("`@("`I
M.PH*("`@("`@("`@("`@)'1E>'0@/2!S=')?<F5P;&%C92AA<G)A>5]K97ES
M*"1S>6YT87@I+"`D<WEN=&%X+"`D=&5X="D["B`@("`@("`@("`@("1T97AT
M(#T@5&5X=%]&:6QT97(Z.F9I;'1E<B@D=&5X="P@)W-P86-E,FAT;6PG*3L*
M("`@("`@("!]"@H@("`@("`@("\J($1O('1H92!B;&%N:RUL:6YE("TM+3X@
M/&)R("\^('-U8G-T:71U=&EO;BX@($5V97)Y8F]D>2!G971S('1H:7,["B`@
M("`@("`@("H@:68@>6]U(&1O;B=T('=A;G0@979E;B!T:&%T+"!J=7-T('-A
M=F4@=&AE(&AT;6QS<&5C:6%L8VAA<G,H*0H@("`@("`@("`J('9E<G-I;VX@
M;V8@=&AE(&EN<'5T+B`J+PH@("`@("`@("1T97AT(#T@;FPR8G(H)'1E>'0I
M.PH*("`@("`@("!R971U<FX@)'1E>'0["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+U1E>'0O1FEL=&5R+W=O<F1S+G!H<```````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,S$Q,0`Q,#4Q-30S,S<U,``P,C,T-S8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J($9I;'1E
M<G,@=&AE(&=I=F5N('1E>'0@8F%S960@;VX@=&AE('=O<F1S(&9O=6YD(&EN
M(&$@=V]R9"!L:7-T"B`J(&9I;&4N"B`J"B`J(%!A<F%M971E<G,Z"B`J(#QP
M<F4^"B`J('=O<F1S7V9I;&4@("TM($9I;&5N86UE(&-O;G1A:6YI;F<@=&AE
M('=O<F1S('1O(')E<&QA8V4N"B`J(')E<&QA8V5M96YT("TM(%1H92!R97!L
M86-E;65N="!S=')I;F<N("!$969A=6QT<R!T;R`B*BHJ*BHB+@H@*B`\+W!R
M93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+W=O<F1S+G!H<"QV(#$N,BXQ,"XU(#(P,#8O,#$O,#$@,C$Z,C@Z,S@@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@2F%N(%-C:&YE:61E
M<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO
M<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]497AT"B`J+PIC;&%S<R!497AT
M7T9I;'1E<E]W;W)D<R!E>'1E;F1S(%1E>'1?1FEL=&5R('L*"B`@("`O*BH*
M("`@("`J($9I;'1E<B!P87)A;65T97)S+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R86US(#T@87)R87DH)W)E<&QA
M8V5M96YT)R`]/B`G*BHJ*BHG*3L*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M82!H87-H('=I=&@@<F5P;&%C92!P871T97)N<RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!0871T97)N<R!H87-H+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G9710871T97)N<R@I"B`@("!["B`@("`@("`@)')E9V5X<"`](&%R
M<F%Y*"D["@H@("`@("`@(&EF("A`:7-?<F5A9&%B;&4H)'1H:7,M/E]P87)A
M;7-;)W=O<F1S7V9I;&4G72DI('L*("`@("`@("`@("`@+RH@4F5A9"!T:&4@
M9FEL92!A;F0@:71E<F%T92!T:')O=6=H('1H92!L:6YE<RX@*B\*("`@("`@
M("`@("`@)&QI;F5S(#T@9FEL92@D=&AI<RT^7W!A<F%M<ULG=V]R9'-?9FEL
M92==*3L*("`@("`@("`@("`@9F]R96%C:"`H)&QI;F5S(&%S("1L:6YE*2![
M"B`@("`@("`@("`@("`@("`O*B!3=')I<"!W:&ET97-P86-E(&%N9"!C;VUM
M96YT<RX@*B\*("`@("`@("`@("`@("`@("1L:6YE(#T@=')I;2@D;&EN92D[
M"B`@("`@("`@("`@("`@("`D;&EN92`]('!R96=?<F5P;&%C92@G?",N*B1\
M)RP@)R<L("1L:6YE*3L*"B`@("`@("`@("`@("`@("`O*B!&:6QT97(@=&AE
M('1E>'0N("HO"B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1L:6YE*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1R96=E>'!;(B\H7&(H7'<J*21L:6YE
M7&)\7&(D;&EN92A<=RHI7&(I+VDB72`]("1T:&ES+3Y?<&%R86US6R=R97!L
M86-E;65N="==.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@87)R87DH)W)E9V5X<"<@/3X@)')E
M9V5X<"D["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]497AT
M+T9I;'1E<B]X<W,N<&AP````````````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,3<V,C4`,3`U,34T,S,W-3``,#(S,3<T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!4:&ES(&9I;'1E
M<B!A='1E;7!T<R!T;R!M86ME($A434P@<V%F92!F;W(@=FEE=VEN9RX@250@
M25,@3D]4(%!%4D9%0U0N($EF"B`J('EO=2!E;F%B;&4@2%1-3"!V:65W:6YG
M+"!Y;W4@87)E(&]P96YI;F<@82!S96-U<FET>2!H;VQE+B!7:71H('1H92!C
M=7)R96YT"B`J('-T871E(&]F('1H92!W96(L($D@8F5L:65V92!T:&%T('1H
M92!B97-T('=E(&-A;B!D;R!I<R!T;R!M86ME('-U<F4@=&AA=`H@*B!P96]P
M;&4@*DM.3U<J($A434P@:7,@82!S96-U<FET>2!H;VQE+"!C;&5A;B!U<"!W
M:&%T('=E(&-A;BP@86YD(&QE879E(&ET"B`J(&%T('1H870N"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]X<W,N<&AP+'8@
M,2XQ+C(N,R`R,#`V+S`R+S`Y(#$V.C0P.C0Q(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P-"TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO
M<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R
M(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C$*("H@0'!A
M8VMA9V4@2&]R9&5?5&5X=`H@*B\*8VQA<W,@5&5X=%]&:6QT97)?>'-S(&5X
M=&5N9',@5&5X=%]&:6QT97(@>PH*("`@("\J*@H@("`@("H@1FEL=&5R('!A
M<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]P87)A;7,@/2!A<G)A>2@G8F]D>5]O;FQY)R`]/B!T<G5E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)W)E<&QA8V4G(#T^("=84U-#;&5A
M;F5D)RP*("`@("`@("`@("`@("`@("`@("`@("`@("=S=')I<%]S='EL97,G
M(#T^('1R=64I.PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&AA<V@@=VET
M:"!R97!L86-E('!A='1E<FYS+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@(%!A='1E<FYS(&AA<V@N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A
M='1E<FYS*"D*("`@('L*("`@("`@("`D<&%T=&5R;G,@/2!A<G)A>2@I.PH*
M("`@("`@("`O*B!296UO=F5S($A434P@8V]M;65N=',@*&EN8VQU9&EN9R!S
M;VUE('-C<FEP=',@)B!S='EL97,I+B`J+PH@("`@("`@(&EF("@D=&AI<RT^
M7W!A<F%M<ULG<W1R:7!?<W1Y;&5S)UTI('L*("`@("`@("`@("`@)'!A='1E
M<FYS6R<O/"$M+2XJ/RTM/B]S)UT@/2`G)SL*("`@("`@("!]"@H@("`@("`@
M("\J($-H86YG92!S<&%C92!E;G1I=&EE<R!T;R!S<&%C92!C:&%R86-T97)S
M+B`J+PH@("`@("`@("1P871T97)N<ULG+R8C*'@P*C(P?#`J,S(I.S\O:2==
M(#T@)R`G.PH*("`@("`@("`O*B!.=6ME(&YO;BUP<FEN=&%B;&4@8VAA<F%C
M=&5R<R`H82!P;&%Y(&EN('1H<F5E(&%C=',I+B`J+PH*("`@("`@("`O*B!2
M=6QE(#$I+B!296UO=F4@86QL(&-O;G1R;VP@8VAA<F%C=&5R<RX@*B\*("`@
M("`@("`O+R1D871A(#T@<')E9U]R97!L86-E*"<O6UQX,#`M7'@P.%QX,&4M
M7'@Q9ETO)RP@)R<L("1D871A*3L*"B`@("`@("`@+RH@4G5L92`Q*2X@268@
M=V4@:&%V92!A('-E;6EC;VQO;BP@:70@:7,@9&5T97)M:6YI<W1I8V%L;'D@
M9&5T96-T86)L90H@("`@("`@("`J(&%N9"!F:7AA8FQE+"!W:71H;W5T(&EN
M=')O9'5C:6YG(&-O;&QA=&5R86P@9&%M86=E+B`J+PH@("`@("`@("1P871T
M97)N<ULG+R8C>#\P*BA;.4$M1%U\,5LP+3-=*3LO:2==(#T@)R9N8G-P.R<[
M"@H@("`@("`@("\J(%)U;&4@,BDN($AE>"!N=6UB97)S("AU<W5A;&QY(&AA
M=FEN9R!A;B!X('!R969I>"D@87)E(&%L<V\*("`@("`@("`@*B!D971E<FUI
M;FES=&EC+"!E=F5N(&EF('=E(&1O;B=T(&AA=F4@=&AE('-E;6DN($YO=&4@
M=&AA="!S;VUE"B`@("`@("`@("H@8G)O=W-E<G,@=VEL;"!T<F5A="`F(V$@
M;W(@)B,P82!A<R!A(&AE>"!N=6UB97(@979E;B!W:71H;W5T('1H92!X"B`@
M("`@("`@("H@<')E9FEX.R!H96YC92`O>#\O('=H:6-H('=I;&P@8V]V97(@
M=&AO<V4@8V%S97,@:6X@=&AI<R!R=6QE+B`J+PH@("`@("`@("1P871T97)N
M<ULG+R8C>#\P*ELY02U$72A;7C`M.4$M1EU\)"DO:2==(#T@)R9N8G-P7%PQ
M)SL*"B`@("`@("`@+RH@4G5L92`S*2X@1&5C:6UA;"!N=6UB97)S('=I=&AO
M=70@=')A:6QI;F<@<V5M:6-O;&]N<RX@5&AE('!R;V)L96T*("`@("`@("`@
M*B!I<R!T:&%T('-O;64@8G)O=W-E<G,@=VEL;"!I;G1E<G!R970@)B,Q,&$@
M87,@(EQN82(L('-O;64@87,*("`@("`@("`@*B`B)B-X,3!A(B!S;R!W92!H
M879E('1O(&-L96%N('1H92`F(S$P('1O(&)E('-A9F4@9F]R('1H92`B7&YA
M(B!C87-E"B`@("`@("`@("H@870@=&AE(&5X<&5N<V4@;V8@;6%N9VQI;F<@
M82!V86QI9"!E;G1I='D@:6X@;W1H97(@8V%S97,N("A3;VQU=&EO;@H@("`@
M("`@("`J(&9O<B!V86QI9"!(5$U,(&%U=&AO<G,Z(&%L=V%Y<R!U<V4@=&AE
M('-E;6EC;VQO;BXI("HO"B`@("`@("`@)'!A='1E<FYS6R<O)B,P*B@Y?#%;
M,"TS72DH6UXP+3E=?"0I+VDG72`]("<F;F)S<%Q<,B<["@H@("`@("`@("\J
M(%)E;6]V92!O=F5R;'D@;&]N9R!N=6UE<FEC(&5N=&ET:65S+B`J+PH@("`@
M("`@("1P871T97)N<ULG+R8C>#\P*ELP+3E!+49=>S8L?3L_+VDG72`]("<F
M;F)S<#LG.PH*("`@("`@("`O*B!296UO=F4@979E<GET:&EN9R!O=71S:61E
M(&]F(&%N9"!I;F-L=61I;F<@=&AE(#QB;V1Y/B!T86<N("HO"B`@("`@("`@
M:68@*"1T:&ES+3Y?<&%R86US6R=B;V1Y7V]N;'DG72D@>PH@("`@("`@("`@
M("`D<&%T=&5R;G-;)R\N*CQB;V1Y6UX^72H^+W-I)UT@/2`G)SL*("`@("`@
M("`@("`@)'!A='1E<FYS6R<O/%PO8F]D>3XN*B]S:2==(#T@)R<["B`@("`@
M("`@?0H*("`@("`@("`O*B!'970@86QL(&%T=')I8G5T93TB:F%V87-C<FEP
M=#IF;V\H*2(@=&%G<RX@5&AI<R!I<R!E<W-E;G1I86QL>2!T:&4*("`@("`@
M("`@*B!R96=E>"`O*#U\=7)L7"@I*"(_*5M>/ETJ<V-R:7!T.B\@8G5T(&5X
M<&%N9&5D('1O(&-A=&-H(&-A;6]U9FQA9V4*("`@("`@("`@*B!W:71H('-P
M86-E<R!A;F0@96YT:71I97,N("HO"B`@("`@("`@)'!R96<@/2`G+R@H)B,P
M*C8Q.S]\)B-X,"HS1#L_?#TI?"<@+@H@("`@("`@("`@("`@("`@)R@H=7PF
M(S`J.#4[/WPF(W@P*C4U.S]\)B,P*C$Q-SL_?"8C>#`J-S4[/RE<<RHG("X*
M("`@("`@("`@("`@("`@("<H<GPF(S`J.#([/WPF(W@P*C4R.S]\)B,P*C$Q
M-#L_?"8C>#`J-S([/RE<<RHG("X*("`@("`@("`@("`@("`@("<H;'PF(S`J
M-S8[/WPF(W@P*C1C.S]\)B,P*C$P.#L_?"8C>#`J-F,[/RE<<RHG("X*("`@
M("`@("`@("`@("`@("<H7"@I*2E<<RHG("X*("`@("`@("`@("`@("`@("<H
M)B,P*C,T.S]\)B-X,"HR,CL_?")\)B,P*C,Y.S]\)B-X,"HR-SL_?%PG*3\G
M("X*("`@("`@("`@("`@("`@("=;7CY=*EQS*B<@+@H@("`@("`@("`@("`@
M("`@)RAS?"8C,"HX,SL_?"8C>#`J-3,[/WPF(S`J,3$U.S]\)B-X,"HW,SL_
M*5QS*B<@+@H@("`@("`@("`@("`@("`@)RAC?"8C,"HV-SL_?"8C>#`J-#,[
M/WPF(S`J.3D[/WPF(W@P*C8S.S\I7',J)R`N"B`@("`@("`@("`@("`@("`G
M*')\)B,P*C@R.S]\)B-X,"HU,CL_?"8C,"HQ,30[/WPF(W@P*C<R.S\I7',J
M)R`N"B`@("`@("`@("`@("`@("`G*&E\)B,P*C<S.S]\)B-X,"HT.3L_?"8C
M,"HQ,#4[/WPF(W@P*C8Y.S\I7',J)R`N"B`@("`@("`@("`@("`@("`G*'!\
M)B,P*C@P.S]\)B-X,"HU,#L_?"8C,"HQ,3([/WPF(W@P*C<P.S\I7',J)R`N
M"B`@("`@("`@("`@("`@("`G*'1\)B,P*C@T.S]\)B-X,"HU-#L_?"8C,"HQ
M,38[/WPF(W@P*C<T.S\I7',J)R`N"B`@("`@("`@("`@("`@("`G*#I\)B,P
M*C4X.S]\)B-X,"HS83L_*2]I)SL*("`@("`@("`D<&%T=&5R;G-;)'!R96==
M(#T@)UPQ7#@G("X@)'1H:7,M/E]P87)A;7-;)W)E<&QA8V4G73L*"B`@("`@
M("`@+RH@1V5T(&%L;"!O;CQF;V\^/2)B87(H*2(N($Y%5D52(&%L;&]W('1H
M97-E+B`J+PH@("`@("`@("1P871T97)N<ULG+RA;7',B7"==*R<@+@H@("`@
M("`@("`@("`@("`@("`G*&]\)B,P*C<Y.S]\)B,P*C1F.S]\)B,P*C$Q,3L_
M?"8C,"HV9CL_*2<@+@H@("`@("`@("`@("`@("`@("`G*&Y\)B,P*C<X.S]\
M)B,P*C1E.S]\)B,P*C$Q,#L_?"8C,"HV93L_*2<@+@H@("`@("`@("`@("`@
M("`@("`G7'<K*5QS*CTO:2==(#T@)UPQ)R`N("1T:&ES+3Y?<&%R86US6R=R
M97!L86-E)UT@+B`G/2<["@H@("`@("`@("\J(%)E;6]V92!A;&P@<V-R:7!T
M<R!S:6YC92!T:&5Y(&UI9VAT(&EN=')O9'5C92!G87)B86=E(&EF('1H97D@
M87)E"B`@("`@("`@("H@;F]T('%U;W1E9"!P<F]P97)L>2X@*B\*("`@("`@
M("`D<&%T=&5R;G-;)WP\<V-R:7!T6UX^72H^+BH_/"]S8W)I<'0^?&ES)UT@
M/2`G/"<@+B`D=&AI<RT^7W!A<F%M<ULG<F5P;&%C92==("X@)U]S8W)I<'0@
M+SXG.PH*("`@("`@("`O*B!'970@86QL('1A9W,@=&AA="!M:6=H="!C875S
M92!T<F]U8FQE("T@/&]B:F5C=#XL(#QE;6)E9#XL(#QB87-E/BP*("`@("`@
M("`@*B!E=&,N($UE=&$@<F5F<F5S:&5S(&%N9"!I9G)A;65S+"!T;V\N("HO
M"B`@("`@("`@)&UA;&EC:6]U<R`](&%R<F%Y*`H@("`@("`@("`@("`G+SPH
M6UX^82UZ72HI)R`N"B`@("`@("`@("`@("<H<WPF(S`J.#,[/WPF(W@P*C4S
M.S]\)B,P*C$Q-3L_?"8C>#`J-S,[/RE<<RHG("X*("`@("`@("`@("`@)RAC
M?"8C,"HV-SL_?"8C>#`J-#,[/WPF(S`J.3D[/WPF(W@P*C8S.S\I7',J)R`N
M"B`@("`@("`@("`@("<H<GPF(S`J.#([/WPF(W@P*C4R.S]\)B,P*C$Q-#L_
M?"8C>#`J-S([/RE<<RHG("X*("`@("`@("`@("`@)RAI?"8C,"HW,SL_?"8C
M>#`J-#D[/WPF(S`J,3`U.S]\)B-X,"HV.3L_*5QS*B<@+@H@("`@("`@("`@
M("`G*'!\)B,P*C@P.S]\)B-X,"HU,#L_?"8C,"HQ,3([/WPF(W@P*C<P.S\I
M7',J)R`N"B`@("`@("`@("`@("<H='PF(S`J.#0[/WPF(W@P*C4T.S]\)B,P
M*C$Q-CL_?"8C>#`J-S0[/RE<<RHO:2<L"@H@("`@("`@("`@("`G+SPH6UX^
M82UZ72HI)R`N"B`@("`@("`@("`@("<H97PF(S`J-CD[/WPF(S`J-#4[/WPF
M(S`J,3`Q.S]\)B,P*C8U.S\I7',J)R`N"B`@("`@("`@("`@("<H;7PF(S`J
M-S<[/WPF(S`J-&0[/WPF(S`J,3`Y.S]\)B,P*C9D.S\I7',J)R`N"B`@("`@
M("`@("`@("<H8GPF(S`J-C8[/WPF(S`J-#([/WPF(S`J.3@[/WPF(S`J-C([
M/RE<<RHG("X*("`@("`@("`@("`@)RAE?"8C,"HV.3L_?"8C,"HT-3L_?"8C
M,"HQ,#$[/WPF(S`J-C4[/RE<<RHG("X*("`@("`@("`@("`@)RAD?"8C,"HV
M.#L_?"8C,"HT-#L_?"8C,"HQ,#`[/WPF(S`J-C0[/RE<<RHO:2<L"@H@("`@
M("`@("`@("`G+SPH6UX^82UZ72HI)R`N"B`@("`@("`@("`@("<H>'PF(S`J
M.#@[/WPF(S`J-3@[/WPF(S`J,3(P.S]\)B,P*C<X.S\I7',J)R`N"B`@("`@
M("`@("`@("<H;7PF(S`J-S<[/WPF(S`J-&0[/WPF(S`J,3`Y.S]\)B,P*C9D
M.S\I7',J)R`N"B`@("`@("`@("`@("<H;'PF(S`J-S8[/WPF(W@P*C1C.S]\
M)B,P*C$P.#L_?"8C>#`J-F,[/RE<<RHO:2<L"@H@("`@("`@("`@("`G+SPH
M6UX^82UZ72HI)R`N"B`@("`@("`@("`@("<H8GPF(S`J-C8[/WPF(S`J-#([
M/WPF(S`J.3@[/WPF(S`J-C([/RE<<RHG("X*("`@("`@("`@("`@)RAA?"8C
M,"HV-3L_?"8C,"HT,3L_?"8C,"HY-SL_?"8C,"HV,3L_*5QS*B<@+@H@("`@
M("`@("`@("`G*'-\)B,P*C@S.S]\)B-X,"HU,SL_?"8C,"HQ,34[/WPF(W@P
M*C<S.S\I7',J)R`N"B`@("`@("`@("`@("<H97PF(S`J-CD[/WPF(S`J-#4[
M/WPF(S`J,3`Q.S]\)B,P*C8U.S\I7',J)R`N"B`@("`@("`@("`@("=;7FQI
M;F5=+VDG+`H*("`@("`@("`@("`@)R\\*%M>/F$M>ETJ*2<@+@H@("`@("`@
M("`@("`G*&U\)B,P*C<W.S]\)B,P*C1D.S]\)B,P*C$P.3L_?"8C,"HV9#L_
M*5QS*B<@+@H@("`@("`@("`@("`G*&5\)B,P*C8Y.S]\)B,P*C0U.S]\)B,P
M*C$P,3L_?"8C,"HV-3L_*5QS*B<@+@H@("`@("`@("`@("`G*'1\)B,P*C@T
M.S]\)B-X,"HU-#L_?"8C,"HQ,38[/WPF(W@P*C<T.S\I7',J)R`N"B`@("`@
M("`@("`@("<H87PF(S`J-C4[/WPF(S`J-#$[/WPF(S`J.3<[/WPF(S`J-C$[
M/RE<<RHO:2<L"@H@("`@("`@("`@("`G+SPH6UX^82UZ72HI)R`N"B`@("`@
M("`@("`@("<H:GPF(S`J-S0[/WPF(S`J-&$[/WPF(S`J,3`V.S]\)B,P*C9A
M.S\I7',J)R`N"B`@("`@("`@("`@("<H87PF(S`J-C4[/WPF(S`J-#$[/WPF
M(S`J.3<[/WPF(S`J-C$[/RE<<RHG("X*("`@("`@("`@("`@)RAV?"8C,"HX
M-CL_?"8C,"HU-CL_?"8C,"HQ,3@[/WPF(S`J-S8[/RE<<RHG("X*("`@("`@
M("`@("`@)RAA?"8C,"HV-3L_?"8C,"HT,3L_?"8C,"HY-SL_?"8C,"HV,3L_
M*5QS*B]I)RP*"B`@("`@("`@("`@("<O/"A;7CYA+7I=*BDG("X*("`@("`@
M("`@("`@)RAO?"8C,"HW.3L_?"8C,"HT9CL_?"8C,"HQ,3$[/WPF(S`J-F8[
M/RE<<RHG("X*("`@("`@("`@("`@)RAB?"8C,"HV-CL_?"8C,"HT,CL_?"8C
M,"HY.#L_?"8C,"HV,CL_*5QS*B<@+@H@("`@("`@("`@("`G*&I\)B,P*C<T
M.S]\)B,P*C1A.S]\)B,P*C$P-CL_?"8C,"HV83L_*5QS*B<@+@H@("`@("`@
M("`@("`G*&5\)B,P*C8Y.S]\)B,P*C0U.S]\)B,P*C$P,3L_?"8C,"HV-3L_
M*5QS*B<@+@H@("`@("`@("`@("`G*&-\)B,P*C8W.S]\)B-X,"HT,SL_?"8C
M,"HY.3L_?"8C>#`J-C,[/RE<<RHG("X*("`@("`@("`@("`@)RAT?"8C,"HX
M-#L_?"8C>#`J-30[/WPF(S`J,3$V.S]\)B-X,"HW-#L_*5QS*B]I)RP*"B`@
M("`@("`@("`@("<O/"A;7CYA+7I=*BDG("X*("`@("`@("`@("`@)RAI?"8C
M,"HW,SL_?"8C>#`J-#D[/WPF(S`J,3`U.S]\)B-X,"HV.3L_*5QS*B<@+@H@
M("`@("`@("`@("`G*&9\)B,P*C<P.S]\)B,P*C0V.S]\)B,P*C$P,CL_?"8C
M,"HV-CL_*5QS*B<@+@H@("`@("`@("`@("`G*')\)B,P*C@R.S]\)B-X,"HU
M,CL_?"8C,"HQ,30[/WPF(W@P*C<R.S\I7',J)R`N"B`@("`@("`@("`@("<H
M87PF(S`J-C4[/WPF(S`J-#$[/WPF(S`J.3<[/WPF(S`J-C$[/RE<<RHG("X*
M("`@("`@("`@("`@)RAM?"8C,"HW-SL_?"8C,"HT9#L_?"8C,"HQ,#D[/WPF
M(S`J-F0[/RE<<RHG("X*("`@("`@("`@("`@)RAE?"8C,"HV.3L_?"8C,"HT
M-3L_?"8C,"HQ,#$[/WPF(S`J-C4[/RE<<RHO:2<I.PH*("`@("`@("!F;W)E
M86-H("@D;6%L:6-I;W5S(&%S("1P871T97)N*2!["B`@("`@("`@("`@("1P
M871T97)N<ULD<&%T=&5R;ET@/2`G/"<@+B`D=&AI<RT^7W!A<F%M<ULG<F5P
M;&%C92==("X@)U]T86<G.PH@("`@("`@('T*"B`@("`@("`@+RH@0V]M;65N
M="!O=70@<W1Y;&4O;&EN:R!T86=S+B`J+PH@("`@("`@(&EF("@D=&AI<RT^
M7W!A<F%M<ULG<W1R:7!?<W1Y;&5S)UTI('L*("`@("`@("`@("`@)'!A='1E
M<FYS6R<O7',K<W1Y;&5<<RH]+VDG72`]("<@)R`N("1T:&ES+3Y?<&%R86US
M6R=R97!L86-E)UT@+B`G/2<["B`@("`@("`@("`@("1P871T97)N<ULG?#QS
M='EL95M>/ETJ/B@_.EQS*CQ<(2TM*2I\:2==(#T@)SPA+2TG.PH@("`@("`@
M("`@("`D<&%T=&5R;G-;)WPH/SHM+3Y<<RHI*CPO<W1Y;&4^?&DG72`]("<M
M+3XG.PH@("`@("`@("`@("`D<&%T=&5R;G-;)WPH/&QI;FM;7CY=*CXI?&DG
M72`]("<\(2TM("0Q("TM/B<["B`@("`@("`@?0H*("`@("`@("`O*B!!(&9E
M=R!O=&AE<B!M871C:&5S+B`J+PH@("`@("`@("1P871T97)N<ULG?#PH6UX^
M72HI)GLN*GTH6UX^72HI/GPG72`]("<\)GL[?5PS/B<["B`@("`@("`@)'!A
M='1E<FYS6R=\/"A;7CY=*BEM;V-H83HH6UX^72HI/GQI)UT@/2`G/%PQ)R`N
M("1T:&ES+3Y?<&%R86US6R=R97!L86-E)UT@+B`G.EPR/B<["B`@("`@("`@
M)'!A='1E<FYS6R=\/"A;7CY=*BEB:6YD:6YG.BA;7CY=*BD^?&DG72`]("<\
M7#$G("X@)'1H:7,M/E]P87)A;7-;)W)E<&QA8V4G72`N("<Z7#(^)SL*"B`@
M("`@("`@<F5T=7)N(&%R<F%Y*"=R96=E>'`G(#T^("1P871T97)N<RD["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O5&5X="]&:6QT97(N<&AP````````````````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q-30U`#$P-3$U-#,S-S4P`#`R,C,U,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`H*<F5Q=6ER95]O;F-E("=014%2+G!H<"<["@ID969I;F4H)U1%6%1?2%1-
M3%]005-35$A252<L(#`I.PID969I;F4H)U1%6%1?2%1-3%]364Y405@G+"`Q
M*3L*9&5F:6YE*"=415A47TA434Q?34E#4D\G+"`R*3L*9&5F:6YE*"=415A4
M7TA434Q?34E#4D]?3$E.2U523"<L(#,I.PID969I;F4H)U1%6%1?2%1-3%].
M3TA434PG+"`T*3L*9&5F:6YE*"=415A47TA434Q?3D](5$U,7TY/0E)%04LG
M+"`U*3L*"B\J*@H@*B!497AT7T9I;'1E<CHZ(&ES(&$@<&%R96YT(&-L87-S
M(&9O<B!D969I;FEN9R!S=&%C:V%B;&4@=&5X="!F:6QT97)S+@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(N<&AP+'8@,2XQ
M-2XR+CD@,C`P-B\P-2\Q,2`Q.3HT.3HQ-"!C:'5C:R!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IA;B!38VAN96ED97(@
M/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@
M2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R
M9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U1E>'0*("HO"F-L87-S(%1E>'1?
M1FEL=&5R('L*"B`@("`O*BH*("`@("`J($9I;'1E<B!P87)A;65T97)S+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R
M86US(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@<&%R86UE
M=&5R<R!T:&%T('1H92!F:6QT97(@:6YS=&%N8V4@;F5E9',N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%1E>'1?1FEL=&5R*"1P87)A;7,@/2!A<G)A>2@I*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@87)R87E?;65R9V4H)'1H
M:7,M/E]P87)A;7,L("1P87)A;7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M07!P;&EE<R!A('-E="!O9B!P871T97)N<R!T;R!A(&)L;V-K(&]F('1E>'0N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@("`@5&AE('1E
M>'0@=&\@9FEL=&5R+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P871T97)N<R`@
M5&AE(&%R<F%Y(&]F('!A='1E<FYS('1O(&9I;'1E<B!W:71H+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=')A;G-F;W)M960@=&5X="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9FEL=&5R*"1T97AT+"`D9FEL=&5R<R`]
M(&%R<F%Y*"DL("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF
M("@A:7-?87)R87DH)&9I;'1E<G,I*2!["B`@("`@("`@("`@("1F:6QT97)S
M(#T@87)R87DH)&9I;'1E<G,I.PH@("`@("`@("`@("`D<&%R86US(#T@87)R
M87DH)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D9FEL
M=&5R<R!A<R`D;G5M(#T^("1F:6QT97(I('L*("`@("`@("`@("`@)&9I;'1E
M<D]B(#T@5&5X=%]&:6QT97(Z.F9A8W1O<GDH)&9I;'1E<BP@:7-S970H)'!A
M<F%M<ULD;G5M72D@/R`D<&%R86US6R1N=6U=(#H@87)R87DH*2D["B`@("`@
M("`@("`@(&EF("AI<U]A*"1F:6QT97)/8BP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1F:6QT97)/8BT^9V5T365S<V%G92@I
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1P871T97)N<R`]("1F:6QT
M97)/8BT^9V5T4&%T=&5R;G,H*3L*"B`@("`@("`@("`@("\J(%!R92UP<F]C
M97-S:6YG+B`J+PH@("`@("`@("`@("`D=&5X="`]("1F:6QT97)/8BT^<')E
M4')O8V5S<R@D=&5X="D["@H@("`@("`@("`@("`O*B!S=')?<F5P;&%C92@I
M('-I;7!L92!P871T97)N<RX@*B\*("`@("`@("`@("`@:68@*&ES<V5T*"1P
M871T97)N<ULG<F5P;&%C92==*2D@>PH@("`@("`@("`@("`@("`@)&9R;VT@
M/2!A<G)A>5]K97ES*"1P871T97)N<ULG<F5P;&%C92==*3L*("`@("`@("`@
M("`@("`@("1T;R`](&%R<F%Y7W9A;'5E<R@D<&%T=&5R;G-;)W)E<&QA8V4G
M72D["B`@("`@("`@("`@("`@("`D=&5X="`]('-T<E]R97!L86-E*"1F<F]M
M+"`D=&\L("1T97AT*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@
M<')E9U]R97!L86-E(&-O;7!L97@@<&%T=&5R;G,N("HO"B`@("`@("`@("`@
M(&EF("AI<W-E="@D<&%T=&5R;G-;)W)E9V5X<"==*2D@>PH@("`@("`@("`@
M("`@("`@)&9R;VT@/2!A<G)A>5]K97ES*"1P871T97)N<ULG<F5G97AP)UTI
M.PH@("`@("`@("`@("`@("`@)'1O(#T@87)R87E?=F%L=65S*"1P871T97)N
M<ULG<F5G97AP)UTI.PH@("`@("`@("`@("`@("`@)'1E>'0@/2!P<F5G7W)E
M<&QA8V4H)&9R;VTL("1T;RP@)'1E>'0I.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`O*B!0;W-T+7!R;V-E<W-I;F<N("HO"B`@("`@("`@("`@("1T
M97AT(#T@)&9I;'1E<D]B+3YP;W-T4')O8V5S<R@D=&5X="D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'1E>'0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!%>&5C=71E<R!A;GD@8V]D92!N96-E<W-A<F%Y(&)E9F]R92!A<'!L>6EN
M9R!T:&4@9FEL=&5R"B`@("`@*B!P871T97)N<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!B969O<F4@=&AE(&9I;'1E
M<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&UO9&EF
M:65D('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N('!R95!R;V-E<W,H)'1E
M>'0I"B`@("!["B`@("`@("`@<F5T=7)N("1T97AT.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!A(&AA<V@@=VET:"!R97!L86-E('!A='1E<FYS
M+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%!A='1E<FYS(&AA<V@N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A='1E<FYS*"D*("`@('L*("`@
M("`@("!R971U<FX@87)R87DH*3L*("`@('T*"B`@("`O*BH*("`@("`J($5X
M96-U=&5S(&%N>2!C;V1E(&YE8V5S<V%R87D@869T97(@87!P;'EI;F<@=&AE
M(&9I;'1E<@H@("`@("H@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@869T97(@=&AE(&9I;'1E<FEN9RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&UO9&EF:65D('1E
M>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N('!O<W10<F]C97-S*"1T97AT*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&5X=#L*("`@('T*"B`@("`O*BH*("`@
M("`J($%T=&5M<'1S('1O(')E='5R;B!A(&-O;F-R971E(%1E>'1?9FEL=&5R
M(&EN<W1A;F-E(&)A<V5D(&]N"B`@("`@*B`D9')I=F5R+@H@("`@("H*("`@
M("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T
M92!497AT7T9I;'1E<B!S=6)C;&%S<R!T;PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;BX@5&AI<R!I<R!B87-E9"!O;B!T:&4@9FEL=&5R
M(&1R:79E<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("@D9')I=F5R
M*2X@5&AE(&-O9&4@:7,@9'EN86UI8V%L;'D@:6YC;'5D960N($EF"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@)&1R:79E<B!I<R!A;B!A<G)A>2P@
M=&AE;B!W92!W:6QL(&QO;VL@:6X*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`D9')I=F5R6S!=(&9O<B!T:&4@<W5B8VQA<W,@:6UP;&5M96YT871I
M;VX@;F%M960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`D9')I=F5R
M6S%=+G!H<"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@
M8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R<R!A('-U8F-L87-S
M(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!497AT7T9I;'1E
M<B`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@5&5X=%]&:6QT97(@:6YS
M=&%N8V4L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!O<B!F86QS92!O
M;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)&1R
M:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*&ES
M7V%R<F%Y*"1D<FEV97(I*2!["B`@("`@("`@("`@(&QI<W0H)&1I<BP@)&1R
M:79E<BD@/2`D9')I=F5R.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T
M>2@D9&ER*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)&1I<B`N("<O
M)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?2!E;'-E:68@*$!F:6QE
M7V5X:7-T<RAD:7)N86UE*%]?1DE,15]?*2`N("<O1FEL=&5R+R<@+B`D9')I
M=F5R("X@)RYP:'`G*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+T9I;'1E<B\G("X@)&1R:79E<B`N("<N<&AP
M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!`:6YC;'5D95]O;F-E
M("=(;W)D92]497AT+T9I;'1E<B\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@
M("`@("!]"@H@("`@("`@("1C;&%S<R`]("=497AT7T9I;'1E<E\G("X@)&1R
M:79E<CL*("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@
M("`@("`@("`@)&9I;'1E<B`]("9N97<@)&-L87-S*"1P87)A;7,I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1F:6QT97(@/2!014%2.CIR86ES
M945R<F]R*"=#;&%S<R!D969I;FET:6]N(&]F("<@+B`D8VQA<W,@+B`G(&YO
M="!F;W5N9"XG*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9FEL=&5R
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0N<&AP````````````````````
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C<T-P`Q,#4Q-30S,S<U,@`P
M,C$Q,S,`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%1H92!497AT.CH@8VQA<W,@<')O=FED97,@8V]M
M;6]N(&UE=&AO9',@9F]R(&UA;FEP=6QA=&EN9R!T97AT+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R](;W)D92](;W)D92]497AT+G!H<"QV(#$N,BXQ,"XU
M(#(P,#8O,#$O,#$@,C$Z,C@Z,C`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!H;W)D92YO
M<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]4
M97AT"B`J+PIC;&%S<R!497AT('L*"B`@("`O*BH*("`@("`J($-O;G9E<G0@
M82!L:6YE(&]F('1E>'0@=&\@9&ES<&QA>2!P<F]P97)L>2!I;B!(5$U,+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!S=')I;F<@
M;V8@=&5X="!T;R!C;VYV97)T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@2%1-3"UC;VUP;&EA;G0@8V]N=F5R=&5D('1E>'0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&AT;6Q3<&%C97,H)'1E>'0@/2`G)RD*("`@('L*
M("`@("`@("!S=&%T:6,@)&-H87)S970["B`@("`@("`@:68@*"%I<W-E="@D
M8VAA<G-E="DI('L*("`@("`@("`@("`@)&-H87)S970@/2!.3%,Z.F=E=$-H
M87)S970H*3L*("`@("`@("!]"@H@("`@("`@("1T97AT(#T@0&AT;6QS<&5C
M:6%L8VAA<G,H)'1E>'0L($5.5%]#3TU0050L("1C:&%R<V5T*3L*("`@("`@
M("`D=&5X="`]('-T<E]R97!L86-E*")<="(L("<F;F)S<#L@)FYB<W`[("9N
M8G-P.R`F;F)S<#L@)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<W1R7W)E
M<&QA8V4H)R`@)RP@)R9N8G-P.R`G+"`D=&5X="D["B`@("`@("`@)'1E>'0@
M/2!S=')?<F5P;&%C92@G("`G+"`G("9N8G-P.R<L("1T97AT*3L*"B`@("`@
M("`@<F5T=7)N("1T97AT.PH@("`@?0H*("`@("\J*@H@("`@("H@4V%M92!A
M<R!H=&UL4W!A8V5S*"D@8G5T(&-O;G9E<G1S(&%L;"!S<&%C97,@=&\@)FYB
M<W`["B`@("`@*@H@("`@("H@0'-E92!H=&UL4W!A8V5S*"D*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@<W1R:6YG(&]F('1E>'0@
M=&\@8V]N=F5R="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M($A434PM8V]M<&QI86YT(&-O;G9E<G1E9"!T97AT+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!H=&UL06QL4W!A8V5S*"1T97AT(#T@)R<I"B`@("!["B`@("`@
M("`@)'1E>'0@/2!497AT.CIH=&UL4W!A8V5S*"1T97AT*3L*("`@("`@("`D
M=&5X="`]('-T<E]R97!L86-E*"<@)RP@)R9N8G-P.R<L("1T97AT*3L*"B`@
M("`@("`@<F5T=7)N("1T97AT.PH@("`@?0H*?0H`````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M5&]K96XO````````````````````````````````````````````````````
M`````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-3$U-#,S-S0W`#`R,#4U,``@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]4;VME;B]F:6QE+G!H<```````````````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`V-#0`,3`U,34T,S,W-#<`,#(R,C`U
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!4;VME;B!T<F%C:VEN9R!I;7!L96UE;G1A=&EO;B!F;W(@
M;&]C86P@9FEL97,N"B`J"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*
M("H@("`G=&]K96Y?9&ER)R`@5&AE(&1I<F5C=&]R>2!W:&5R92!T;R!K965P
M('1O:V5N(&9I;&5S+@H@*B`@("=T:6UE;W5T)R`@("!4:&4@<&5R:6]D("AI
M;B!S96-O;F1S*2!A9G1E<B!W:&EC:"!A;B!I9"!I<R!P=7)G960N"B`J("`@
M("`@("`@("`@("`@($1E9F%U;'1S('1O(#@V-#`P("AI+F4N(#(T(&AO=7)S
M*2X\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&]K96XO5&]K96XO
M9FEL92YP:'`L=B`Q+C$Y+C8N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C,Y(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($UA>"!+86QI:V$@/&UA
M>$!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-87@@
M2V%L:6MA(#QM87A`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*
M("H@0'!A8VMA9V4@2&]R9&5?5&]K96X*("HO"F-L87-S($AO<F1E7U1O:V5N
M7V9I;&4@97AT96YD<R!(;W)D95]4;VME;B!["@H@("`@+RHJ"B`@("`@*B!(
M86YD;&4@9F]R('1H92!O<&5N(&9I;&4@9&5S8W)I<'1O<BX*("`@("`J"B`@
M("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D7V9D(#T@9F%L
M<V4["@H@("`@+RHJ"B`@("`@*B!";V]L96%N(&EN9&EC871I;F<@=VAE=&AE
M<B!O<B!N;W0@=V4@:&%V92!A;B!O<&5N(&9I;&4@9&5S8W)I<'1O<BX*("`@
M("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?8V]N
M;F5C=&5D(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@82!N97<@
M9FEL92!B87-E9"!T;VME;BUT<F%C:VEN9R!C;VYT86EN97(N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG
M('-T;W)A9V4@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R
M9&5?5&]K96Y?9FEL92@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@
M("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["@H@("`@("`@("\J($-H;V]S
M92!T:&4@9&ER96-T;W)Y('1O('-A=F4@=&AE('-T=6(@9FEL97,N("HO"B`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG=&]K96Y?9&ER)UTI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T;VME;E]D:7(G72`]
M(%5T:6PZ.F=E=%1E;7!$:7(H*3L*("`@("`@("!]"@H@("`@("`@("\J(%-E
M="!T:6UE;W5T('1O(#(T(&AO=7)S(&EF(&YO="!S<&5C:69I960N("HO"B`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG=&EM96]U="==*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&EM96]U="==(#T@.#8T
M,#`["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E<R!A
M;&P@97AP:7)E9"!C;VYN96-T:6]N(&ED)W,@9G)O;2!T:&4@4U%,('-E<G9E
M<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@5')U92!O;B!S=6-C
M97-S+"!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('!U<F=E*"D*("`@('L*("`@("`@("`O+R!-86ME('-U
M<F4@=V4@:&%V92!N;R!O<&5N(&9I;&4@9&5S8W)I<'1O<G,@8F5F;W)E('5N
M;&EN:VEN9PH@("`@("`@("\O(&9I;&5S+@H@("`@("`@(&EF("@A)'1H:7,M
M/E]D:7-C;VYN96-T*"DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)U5N86)L92!T;R!C;&]S92!F:6QE(&1E<V-R:7!T;W)S)RD[
M"B`@("`@("`@?0H*("`@("`@("`O*B!"=6EL9"!S='5B(&9I;&4@;&ES="X@
M*B\*("`@("`@("!I9B`H(2@D9&ER(#T@;W!E;F1I<B@D=&AI<RT^7W!A<F%M
M<ULG=&]K96Y?9&ER)UTI*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G56YA8FQE('1O(&]P96X@=&]K96X@9&ER96-T;W)Y)RD[
M"B`@("`@("`@?0H*("`@("`@("`O*B!&:6YD(&5X<&ER960@<W1U8B!F:6QE
M<R`J+PH@("`@("`@('=H:6QE("@H)&1I<D5N=')Y(#T@<F5A9&1I<B@D9&ER
M*2D@(3T@)R<I('L*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)WQ>8V]N
M;E]<=WLX?21\)RP@)&1I<D5N=')Y*2`F)B`H=&EM92@I("T@9FEL96UT:6UE
M*"1T:&ES+3Y?<&%R86US6R=T;VME;E]D:7(G72`N("<O)R`N("1D:7)%;G1R
M>2D@/CT@)'1H:7,M/E]P87)A;7-;)W1I;65O=70G72DI('L*("`@("`@("`@
M("`@("`@(&EF("@A0'5N;&EN:R@D=&AI<RT^7W!A<F%M<ULG=&]K96Y?9&ER
M)UT@+B`G+R<@+B`D9&ER16YT<GDI*2!["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U5N86)L92!T;R!P=7)G92!T;VME
M;B!F:6QE+B<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!C;&]S961I<B@D9&ER*3L*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!E>&ES=',H)'1O:V5N240I
M"B`@("!["B`@("`@("`@:68@*&ES7V$H*"1R97-U;'0@/2`D=&AI<RT^7V-O
M;FYE8W0H)'1O:V5N240I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("\J($9I;F0@
M86QR96%D>2!U<V5D($E$<RX@*B\*("`@("`@("`D9FEL94-O;G1E;G1S(#T@
M0&9I;&4H)'1H:7,M/E]P87)A;7-;)W1O:V5N7V1I<B==("X@)R]C;VYN7R<@
M+B`D=&AI<RT^96YC;V1E4F5M;W1E061D<F5S<R@I*3L*("`@("`@("!I9B`H
M)&9I;&5#;VYT96YT<RD@>PH@("`@("`@("`@("`D:4UA>"`](&-O=6YT*"1F
M:6QE0V]N=&5N=',I.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D
M:4UA>#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@:68@*&-H;W`H)&9I;&5#
M;VYT96YT<ULD:5TI(#T]("1T;VME;DE$*2!["B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@
M("!F=6YC=&EO;B!A9&0H)'1O:V5N240I"B`@("!["B`@("`@("`@:68@*&ES
M7V$H*"1R97-U;'0@/2`D=&AI<RT^7V-O;FYE8W0H)'1O:V5N240I*2P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("!]"@H@("`@("`@("\J(%=R:71E('1H92!E;G1R>2X@*B\*("`@("`@
M("!F=W)I=&4H)'1H:7,M/E]F9"P@(B1T;VME;DE$7&XB*3L*"B`@("`@("`@
M+RH@4F5T=7)N(&%N(&5R<F]R(&EF('1H92!U<&1A=&4@9F%I;',L('1O;RX@
M*B\*("`@("`@("!I9B`H(21T:&ES+3Y?9&ES8V]N;F5C="@I*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=&86EL960@=&\@8VQO
M<V4@=&]K96X@9FEL92!C;&5A;FQY+B<I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/<&5N<R!A(&9I
M;&4@9&5S8W)I<'1O<B!T;R!A(&YE=R!O<B!E>&ES=&EN9R!F:6QE+@H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!A
M(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]C;VYN96-T*"1T;VME;DE$*0H@("`@>PH@("`@("`@(&EF("@A
M)'1H:7,M/E]C;VYN96-T960I('L*"B`@("`@("`@("`@("\O($]P96X@82!F
M:6QE(&1E<V-R:7!T;W(@=&\@=&AE('1O:V5N('-T=6(@9FEL92X*("`@("`@
M("`@("`@)'1H:7,M/E]F9"`]($!F;W!E;B@D=&AI<RT^7W!A<F%M<ULG=&]K
M96Y?9&ER)UT@+B`G+V-O;FY?)R`N("1T:&ES+3YE;F-O9&5296UO=&5!9&1R
M97-S*"DL("=A)RD["B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]F9"D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QE
M9"!T;R!O<&5N('1O:V5N(&9I;&4N)RD["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1T:&ES+3Y?8V]N;F5C=&5D(#T@=')U93L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0VQO
M<V5S('1H92!F:6QE(&1E<V-R:7!T;W(N"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D:7-C;VYN96-T*"D*("`@('L*("`@
M("`@("!I9B`H)'1H:7,M/E]C;VYN96-T960I('L*("`@("`@("`@("`@)'1H
M:7,M/E]C;VYN96-T960@/2!F86QS93L*("`@("`@("`@("`@<F5T=7)N(&9C
M;&]S92@D=&AI<RT^7V9D*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+U1O:V5N+W-Q;"YP:'``````````````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`Q-#(T,``Q,#4Q-30S,S<T-P`P,C(P-C$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M(%1O:V5N('1R86-K:6YG(&EM<&QE;65N=&%T:6]N(&9O<B!02%`G<R!014%2
M(&1A=&%B87-E(&%B<W1R86-T:6]N(&QA>65R+@H@*@H@*B!297%U:7)E9"!P
M87)A;65T97)S.CQP<F4^"B`J("`@)W!H<'1Y<&4G("`@5&AE(&1A=&%B87-E
M('1Y<&4@*&EE+B`G<&=S<6PG+"`G;7ES<6PG+"!E=&,N*2X\+W!R93X*("H*
M("H@4F5Q=6ER960@8GD@<V]M92!D871A8F%S92!I;7!L96UE;G1A=&EO;G,Z
M/'!R93X*("H@("`G9&%T86)A<V4G("!4:&4@;F%M92!O9B!T:&4@9&%T86)A
M<V4N"B`J("`@)VAO<W1S<&5C)R`@5&AE(&AO<W1N86UE(&]F('1H92!D871A
M8F%S92!S97)V97(N"B`J("`@)W5S97)N86UE)R`@5&AE('5S97)N86UE('=I
M=&@@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@)W!A
M<W-W;W)D)R`@5&AE('!A<W-W;W)D(&%S<V]C:6%T960@=VET:"`G=7-E<FYA
M;64G+@H@*B`@("=O<'1I;VYS)R`@($%D9&ET:6]N86P@;W!T:6]N<R!T;R!P
M87-S('1O('1H92!D871A8F%S92X*("H@("`G='1Y)R`@("`@("!4:&4@5%19
M(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+@H@*B`@("=P
M;W)T)R`@("`@(%1H92!P;W)T(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE
M(&1A=&%B87-E+CPO<')E/@H@*@H@*B!/<'1I;VYA;"!P87)A;65T97)S.CQP
M<F4^"B`J("`@)W1A8FQE)R`@("`@5&AE(&YA;64@;V8@=&AE('1O:V5N<R!T
M86)L92!I;B`G9&%T86)A<V4G+@H@*B`@("`@("`@("`@("`@($1E9F%U;'1S
M('1O("=H;W)D95]T;VME;G,G+@H@*B`@("=T:6UE;W5T)R`@(%1H92!P97)I
M;V0@*&EN('-E8V]N9',I(&%F=&5R('=H:6-H(&%N(&ED(&ES('!U<F=E9"X*
M("H@("`@("`@("`@("`@("!$969A=6QT<R!T;R`X-C0P,"`H:2YE+B`R-"!H
M;W5R<RDN/"]P<F4^"B`J"B`J(%1H92!T86)L92!S=')U8W1U<F4@9F]R('1H
M92!T;VME;G,@:7,@87,@9F]L;&]W<SH*("H*("H@/'!R93X*("H@0U)%051%
M(%1!0DQ%(&AO<F1E7W1O:V5N<R`H"B`J("`@("!T;VME;E]A9&1R97-S("`@
M(%9!4D-(05(H,3`P*2!.3U0@3E5,3"P*("H@("`@('1O:V5N7VED("`@("`@
M("`@5D%20TA!4B@S,BD@3D]4($Y53$PL"B`J("`@("!T;VME;E]T:6UE<W1A
M;7`@($))1TE.5"!.3U0@3E5,3"P*("H*("H@("`@(%!224U!4ED@2T59("AT
M;VME;E]A9&1R97-S+"!T;VME;E]I9"D*("H@*3L*("H@/"]P<F4^"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+U1O:V5N+U1O:V5N+W-Q;"YP:'`L=B`Q+C(S
M+C8N,3(@,C`P-B\P,2\Q."`Q.3HT,#HU,2!B96X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#$Y.3DM,C`P-B!-87@@2V%L:6MA(#QM87A`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36%X($MA;&EK82`\;6%X0&AO
M<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO
M<F1E7U1O:V5N"B`J+PIC;&%S<R!(;W)D95]4;VME;E]S<6P@97AT96YD<R!(
M;W)D95]4;VME;B!["@H@("`@+RHJ"B`@("`@*B!(86YD;&4@9F]R('1H92!C
M=7)R96YT(&1A=&%B87-E(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0'9A
M<B!$0@H@("`@("HO"B`@("!V87(@)%]D8B`]("<G.PH*("`@("\J*@H@("`@
M("H@0F]O;&5A;B!I;F1I8V%T:6YG('=H971H97(@;W(@;F]T('=E)W)E(&-O
M;FYE8W1E9"!T;R!T:&4@4U%,"B`@("`@*B!S97)V97(N"B`@("`@*@H@("`@
M("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V-O;FYE8W1E9"`]
M(&9A;'-E.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!344P@
M8V]N;F5C=&EO;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE
M=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?5&]K96Y?<W%L*"1P
M87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%R86US
M(#T@)'!A<F%M<SL*"B`@("`@("`@+RH@4V5T('1I;65O=70@=&\@,C0@:&]U
M<G,@:68@;F]T('-P96-I9FEE9"X@*B\*("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?<&%R86US6R=T:6UE;W5T)UTI*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=T:6UE;W5T)UT@/2`X-C0P,#L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&%L;"!E>'!I<F5D(&-O;FYE8W1I
M;VX@:60G<R!F<F]M('1H92!344P@<V5R=F5R+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!A(%!%05)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('!U<F=E
M*"D*("`@('L*("`@("`@("!I9B`H:7-?82@H)')E<W5L="`]("1T:&ES+3Y?
M8V]N;F5C="@I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("\J($)U:6QD(%-13"!Q
M=65R>2X@*B\*("`@("`@("`D<75E<GD@/2`G1$5,151%($923TT@)R`N("1T
M:&ES+3Y?<&%R86US6R=T86)L92==("X@)R!72$5212`G.PH@("`@("`@("1Q
M=65R>2`N/2`G=&]K96Y?=&EM97-T86UP(#P@/R<["@H@("`@("`@("1V86QU
M97,@/2!A<G)A>2AT:6UE*"D@+2`D=&AI<RT^7W!A<F%M<ULG=&EM96]U="==
M*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R
M>2P@)'9A;'5E<RD["@H@("`@("`@("\J(%)E='5R;B!A;B!E<G)O<B!I9B!T
M:&4@=7!D871E(&9A:6QS+"!T;V\N("HO"B`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&5X:7-T<R@D=&]K96Y)1"D*("`@('L*("`@("`@("!I
M9B`H:7-?82@H)')E<W5L="`]("1T:&ES+3Y?8V]N;F5C="@I*2P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("`O*B!"=6EL9"!344P@<75E<GDN("HO"B`@("`@("`@)'%U
M97)Y("`]("=314Q%0U0@=&]K96Y?:60@1E)/32`G("X@)'1H:7,M/E]P87)A
M;7-;)W1A8FQE)UT["B`@("`@("`@)'%U97)Y("X]("<@5TA%4D4@=&]K96Y?
M861D<F5S<R`](#\G.PH@("`@("`@("1Q=65R>2`N/2`G($%.1"!T;VME;E]I
M9"`](#\G.PH*("`@("`@("`D=F%L=65S(#T@87)R87DH)'1H:7,M/F5N8V]D
M95)E;6]T94%D9')E<W,H*2P@)'1O:V5N240I.PH*("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/E]D8BT^9V5T3VYE*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N("%E;7!T>2@D<F5S=6QT*3L*("`@("`@("!]"B`@("!]"@H@
M("`@9G5N8W1I;VX@861D*"1T;VME;DE$*0H@("`@>PH@("`@("`@(&EF("AI
M<U]A*"@D<F5S=6QT(#T@)'1H:7,M/E]C;VYN96-T*"DI+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*
M"B`@("`@("`@+RH@0G5I;&0@4U%,('%U97)Y+B`J+PH@("`@("`@("1Q=65R
M>2`@/2`G24Y315)4($E.5$\@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==
M("X@)R`H=&]K96Y?861D<F5S<RP@=&]K96Y?:60L('1O:V5N7W1I;65S=&%M
M<"D@)SL*("`@("`@("`D<75E<GD@+CT@)U9!3%5%4R`H/RP@/RP@/RDG.PH*
M("`@("`@("`D=F%L=65S(#T@87)R87DH)'1H:7,M/F5N8V]D95)E;6]T94%D
M9')E<W,H*2P@)'1O:V5N240L('1I;64H*2D["@H@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($]P96YS(&$@8V]N;F5C=&EO
M;B!T;R!T:&4@4U%,('-E<G9E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@82!014%27T5R<F]R(&]B:F5C="!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I"B`@
M("!["B`@("`@("`@:68@*"1T:&ES+3Y?8V]N;F5C=&5D*2!["B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]
M(%5T:6PZ.F%S<V5R=$1R:79E<D-O;F9I9R@D=&AI<RT^7W!A<F%M<RP@87)R
M87DH)W!H<'1Y<&4G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=T;VME;B!344PG+"!A<G)A>2@G9')I=F5R)R`]/B`G
M=&]K96XG*2D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]
M"@H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)V1A=&%B87-E
M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=D871A8F%S92==
M(#T@)R<["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P
M87)A;7-;)W5S97)N86UE)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=U<V5R;F%M92==(#T@)R<["B`@("`@("`@?0H@("`@("`@(&EF("@A
M:7-S970H)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=P87-S=V]R9"==(#T@)R<["B`@("`@("`@
M?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C
M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==
M(#T@)R<["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P
M87)A;7-;)W1A8FQE)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=T86)L92==(#T@)VAO<F1E7W1O:V5N<R<["B`@("`@("`@?0H*("`@("`@
M("`O*B!#;VYN96-T('1O('1H92!344P@<V5R=F5R('5S:6YG('1H92!S=7!P
M;&EE9"!P87)A;65T97)S+B`J+PH@("`@("`@(')E<75I<F5?;VYC92`G1$(N
M<&AP)SL*("`@("`@("`D=&AI<RT^7V1B(#T@)D1".CIC;VYN96-T*"1T:&ES
M+3Y?<&%R86US+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)W!E<G-I<W1E;G0G(#T^("%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG
M<&5R<VES=&5N="==*2DI.PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?9&(L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M9&(["B`@("`@("`@?0H*("`@("`@("`O+R!3970@1$(@<&]R=&%B:6QI='D@
M;W!T:6]N<RX*("`@("`@("!S=VET8V@@*"1T:&ES+3Y?9&(M/G!H<'1Y<&4I
M('L*("`@("`@("!C87-E("=M<W-Q;"<Z"B`@("`@("`@("`@("1T:&ES+3Y?
M9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)404))3$E465],
M3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%4E)/4E,@?"!$0E]03U)404))
M3$E465]25%))32D["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&1E9F%U
M;'0Z"B`@("`@("`@("`@("1T:&ES+3Y?9&(M/G-E=$]P=&EO;B@G<&]R=&%B
M:6QI='DG+"!$0E]03U)404))3$E465],3U=%4D-!4T4@?"!$0E]03U)404))
M3$E465]%4E)/4E,I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]C;VYN
M96-T960@/2!T<G5E.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J($1I<V-O;FYE8W0@9G)O;2!T:&4@4U%,('-E<G9E<B!A
M;F0@8VQE86X@=7`@=&AE(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&$@4$5!4E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V1I<V-O
M;FYE8W0H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V-O;FYE8W1E9"D@
M>PH@("`@("`@("`@("`D=&AI<RT^7V-O;FYE8W1E9"`](&9A;'-E.PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]D8BT^9&ES8V]N;F5C="@I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]4;VME;BYP:'``````````````````````
M````````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3,U,#$`,3`U,34T,S,W-3(`,#(Q
M,C4U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"@IR97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*"B\J*@H@*B!4:&4@
M2&]R9&5?5&]K96XZ.B!C;&%S<R!P<F]V:61E<R!A(&-O;6UO;B!A8G-T<F%C
M=&5D(&EN=&5R9F%C92!I;G1O('1H90H@*B!V87)I;W5S('1O:V5N(&=E;F5R
M871I;VX@;65D:75M<RX@270@86QS;R!I;F-L=61E<R!A;&P@;V8@=&AE"B`J
M(&9U;F-T:6]N<R!F;W(@<F5T<FEE=FEN9RP@<W1O<FEN9RP@86YD(&-H96-K
M:6YG('1O:V5N<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&]K96XO5&]K
M96XN<&AP+'8@,2XS,RXV+C@@,C`P-B\P-"\Q.2`R,3HQ-#HP-2!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!-87@@2V%L:6MA(#QM87A`
M:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N
M8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@36%X($MA;&EK82`\;6%X0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@
M($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]4;VME;@H@*B\*8VQA<W,@
M2&]R9&5?5&]K96X@>PH*("`@("\J*@H@("`@("H@2&%S:"!O9B!P87)A;65T
M97)S(&YE8V5S<V%R>2!T;R!U<V4@=&AE(&-H;W-E;B!B86-K96YD+@H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R86US
M(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I
M;FEN9R!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]4
M;VME;B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@('T*"B`@("!F=6YC
M=&EO;B!E;F-O9&5296UO=&5!9&1R97-S*"D*("`@('L*("`@("`@("!I9B`H
M:7-S970H)%]315)615);)U)%34]415]!1$12)UTI*2!["B`@("`@("`@("`@
M(')E='5R;B!B87-E-C1?96YC;V1E*"1?4T525D526R=214U/5$5?041$4B==
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A=&5S(&$@8V]N
M;F5C=&EO;B!I9"!A;F0@<F5T=7)N<R!I="X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1S965D("!!('5N:7%U92!)1"!T;R!B92!I;F-L=61E9"!I
M;B!T:&4@=&]K96XL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!I9B!I
M="!N965D<R!T;R!B92!M;W)E('5N:7%U92!T:&%N('1I;64@*&EN('-E8V]N
M9',I"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!A;F0@=&AE(')E;6]T
M92!)4"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H92!G96YE
M<F%T960@:60@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!G96YE<F%T
M94ED*"1S965D(#T@)R<I"B`@("!["B`@("`@("`@<F5T=7)N(&UD-2AT:6UE
M*"D@+B`G75LG("X@)'-E960@+B`G75LG("X@2&]R9&5?5&]K96XZ.F5N8V]D
M95)E;6]T94%D9')E<W,H*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C
M:W,@:68@=&AE(&=I=F5N('1O:V5N(&AA<R!B965N('!R979I;W5S;'D@=7-E
M9"X@1FER<W0*("`@("`J('!U<F=E<R!A;&P@97AP:7)E9"!T;VME;G,N(%1H
M96X@<F5T<FEE=F5S(&-U<G)E;G0@=&]K96YS(&9O<@H@("`@("H@=&AE(&=I
M=F5N(&EP(&%D9')E<W,N($EF('1H92!S<&5C:69I960@=&]K96X@=V%S(&YO
M="!F;W5N9"P*("`@("`J(&%D9',@:70N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=&]K96X@(%1H92!V86QU92!O9B!T:&4@=&]K96X@=&\@8VAE
M8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("`@("`@(%1R=64@
M:68@=&AE('1O:V5N(&AA<R!N;W0@8F5E;B!U<V5D+`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@=F5R:69Y*"1T;VME;BD*("`@('L*("`@("`@("`D=&AI<RT^
M<'5R9V4H*3L*("`@("`@("`D97AI<W1S(#T@)'1H:7,M/F5X:7-T<R@D=&]K
M96XI.PH@("`@("`@(&EF("AI<U]A*"1E>&ES=',L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1E>&ES=',["B`@("`@("`@?2!E;'-E
M:68@*"1E>&ES=',I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^861D*"1T
M;VME;BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!I
M<R!A;B!A8G-T<F%C="!M971H;V0@=&AA="!S:&]U;&0@8F4@;W9E<G)I9&1E
M;B!B>2!A"B`@("`@*B!S=6)C;&%S<R!I;7!L96UE;G1A=&EO;BX@5&AE(&)A
M<V4@:6UP;&5M96YT871I;VX@86QL;W=S(&%L;`H@("`@("H@=&]K96X@=F%L
M=65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>&ES=',H*0H@("`@>PH@("`@
M("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@
M:7,@86X@86)S=')A8W0@;65T:&]D('1H870@<VAO=6QD(&)E(&]V97)R:61D
M96X@8GD@80H@("`@("H@<W5B8VQA<W,@:6UP;&5M96YT871I;VXN(%1H92!B
M87-E(&EM<&QE;65N=&%T:6]N(&%L;&]W<R!A;&P*("`@("`J('1O:V5N('9A
M;'5E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@861D*"D*("`@('L*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@:7,@
M86X@86)S=')A8W0@;65T:&]D('1H870@<VAO=6QD(&)E(&]V97)R:61D96X@
M8GD@80H@("`@("H@<W5B8VQA<W,@:6UP;&5M96YT871I;VXN(%1H92!B87-E
M(&EM<&QE;65N=&%T:6]N(&%L;&]W<R!A;&P*("`@("`J('1O:V5N('9A;'5E
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<'5R9V4H*0H@("`@>PH@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@
M=&\@<F5T=7)N(&$@8V]N8W)E=&4@2&]R9&5?5&]K96X@:6YS=&%N8V4@8F%S
M960@;VX@)&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1R
M:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?5&]K96X@<W5B8VQA
M<W,@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!R971U<FXN($EF
M("1D<FEV97(@:7,@86X@87)R87DL('1H96X@=V4@=VEL;"!L;V]K"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@:6X@)&1R:79E<ELP72]L:6(O5&]K
M96XO(&9O<B!T:&4@<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D9')I=F5R6S%=+G!H<"X*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!A
M;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S(&$@<W5B8VQA
M<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7U1O
M:V5N("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T92!(;W)D95]4;VME;B!I
M;G-T86YC92P@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&9A;'-E
M(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D9')I
M=F5R+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H:7-?
M87)R87DH)&1R:79E<BDI('L*("`@("`@("`@("`@;&ES="@D87!P+"`D9')I
M=F5R*2`]("1D<FEV97(["B`@("`@("`@?0H*("`@("`@("`D9')I=F5R(#T@
M8F%S96YA;64H)&1R:79E<BD["@H@("`@("`@(&EF("@A96UP='DH)&%P<"DI
M('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("1A<'`@+B`G+VQI8B]4;VME
M;B\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V5I9B`H0&9I
M;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I("X@)R]4;VME;B\G("X@)&1R
M:79E<B`N("<N<&AP)RDI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E(&1I
M<FYA;64H7U]&24Q%7U\I("X@)R]4;VME;B\G("X@)&1R:79E<B`N("<N<&AP
M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!`:6YC;'5D95]O;F-E
M("=(;W)D92]4;VME;B\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!]
M"@H@("`@("`@("1C;&%S<R`]("=(;W)D95]4;VME;E\G("X@)&1R:79E<CL*
M("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@
M("`@)'1O:V5N(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'1O:V5N(#T@)FYE=R!(;W)D95]4;VME;B@D
M<&%R86US*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&]K96X["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E
M<F5N8V4@=&\@82!C;VYC<F5T92!(;W)D95]4;VME;B!I;G-T86YC92!B87-E
M9`H@("`@("H@;VX@)&1R:79E<BX*("`@("`J"B`@("`@*B!)="!W:6QL(&]N
M;'D@8W)E871E(&$@;F5W(&EN<W1A;F-E(&EF(&YO($AO<F1E7U1O:V5N(&EN
M<W1A;F-E('=I=&@@=&AE"B`@("`@*B!S86UE('!A<F%M971E<G,@8W5R<F5N
M=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES('-H;W5L9"!B92!U<V5D
M(&EF(&UU;'1I<&QE('1Y<&5S(&]F('1O:V5N(&=E;F5R871O<G,@*&%N9"P@
M=&AU<RP*("`@("`J(&UU;'1I<&QE($AO<F1E7U1O:V5N(&EN<W1A;F-E<RD@
M87)E(')E<75I<F5D+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@
M8F4@:6YV;VME9"!A<SH*("`@("`J(#QC;V1E/B1V87(@/2`F2&]R9&5?5&]K
M96XZ.G-I;F=L971O;B@I.SPO8V]D93X*("`@("`J"B`@("`@*B!`<&%R86T@
M;6EX960@)&1R:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?5&]K
M96X@<W5B8VQA<W,@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FXN($EF("1D<FEV97(@:7,@86X@87)R87DL('1H96X@=V4@=VEL;"!L
M;V]K"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:6X@)&1R:79E<ELP
M72]L:6(O5&]K96XO(&9O<B!T:&4@<W5B8VQA<W,*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D9')I=F5R6S%=
M+G!H<"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N
M=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S
M(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M($AO<F1E7U1O:V5N("!4:&4@8V]N8W)E=&4@2&]R9&5?5&]K96X@<F5F97)E
M;F-E+"!O<B!F86QS92!O;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)&1R:79E
M<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<W1A=&EC("1I
M;G-T86YC97,["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S*2D@>PH@
M("`@("`@("`@("`D:6YS=&%N8V5S(#T@87)R87DH*3L*("`@("`@("!]"@H@
M("`@("`@("1S:6=N871U<F4@/2!S97)I86QI>F4H87)R87DH)&1R:79E<BP@
M)'!A<F%M<RDI.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<ULD<VEG
M;F%T=7)E72DI('L*("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E
M72`]("9(;W)D95]4;VME;CHZ9F%C=&]R>2@D9')I=F5R+"`D<&%R86US*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YS=&%N8V5S6R1S:6=N871U
M<F5=.PH@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U1R964O````````````````````````````````
M```````````````````````````````````````````````P,#`P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U,``P,C`S-C$`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5')E92]H=&UL+G!H
M<```````````````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0R,3(U`#$P
M-3$U-#,S-S4P`#`R,C`T,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@5&AE($AO<F1E7U1R965?:'1M
M;#HZ(&-L87-S(&5X=&5N9',@=&AE($AO<F1E7U1R964@8VQA<W,@=&\@<')O
M=FED90H@*B!(5$U,('-P96-I9FEC(')E;F1E<FEN9R!F=6YC=&EO;G,N"B`J
M"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O
M8FQO+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+U1R964O5')E92]H=&UL+G!H<"QV(#$N-3$N,BXQ,B`R,#`V+S`Q+S$U(#$V
M.C,S.C(Y(&-H=6-K($5X<"`D"B`J"B`J($!A=71H;W(@($UA<FMO($1J=6MI
M8R`\;6%R:V]`;V)L;RYC;VT^"B`J($!P86-K86=E($AO<F1E7U1R964*("H@
M0'-I;F-E("`@2&]R9&4@,RXP"B`J+PIC;&%S<R!(;W)D95]4<F5E7VAT;6P@
M97AT96YD<R!(;W)D95]4<F5E('L*"B`@("`O*BH*("`@("`J($EM86=E(&1I
M<F5C=&]R>2!L;V-A=&EO;BX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)%]I;6=?9&ER(#T@)R<["@H@("`@+RHJ"B`@("`@
M*B!$969A=6QT('1R964@9W)A<&AI8R!F;W(@82!L:6YE+@H@("`@("H*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VEM9U]L:6YE(#T@
M)VQI;F4N<&YG)SL*"B`@("`O*BH*("`@("`J($1E9F%U;'0@=')E92!G<F%P
M:&EC(&9O<B!A(&)L86YK+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7VEM9U]B;&%N:R`]("=B;&%N:RYP;F<G.PH*("`@
M("\J*@H@("`@("H@1&5F875L="!T<F5E(&=R87!H:6,@9F]R(&$@:F]I;BX*
M("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]I
M;6=?:F]I;B`]("=J;VEN+G!N9R<["@H@("`@+RHJ"B`@("`@*B!$969A=6QT
M('1R964@9W)A<&AI8R!F;W(@82!B;W1T;VT@:F]I;BX*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]I;6=?:F]I;E]B;W1T
M;VT@/2`G:F]I;F)O='1O;2YP;F<G.PH*("`@("\J*@H@("`@("H@1&5F875L
M="!T<F5E(&=R87!H:6,@9F]R(&$@<&QU<RX*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]I;6=?<&QU<R`]("=P;'5S+G!N
M9R<["@H@("`@+RHJ"B`@("`@*B!$969A=6QT('1R964@9W)A<&AI8R!F;W(@
M82!B;W1T;VT@<&QU<RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)%]I;6=?<&QU<U]B;W1T;VT@/2`G<&QU<V)O='1O;2YP
M;F<G.PH*("`@("\J*@H@("`@("H@1&5F875L="!T<F5E(&=R87!H:6,@9F]R
M(&$@<&QU<R!O;FQY+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D7VEM9U]P;'5S7V]N;'D@/2`G<&QU<V]N;'DN<&YG)SL*
M"B`@("`O*BH*("`@("`J($1E9F%U;'0@=')E92!G<F%P:&EC(&9O<B!A(&UI
M;G5S+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D7VEM9U]M:6YU<R`]("=M:6YU<RYP;F<G.PH*("`@("\J*@H@("`@("H@
M1&5F875L="!T<F5E(&=R87!H:6,@9F]R(&$@8F]T=&]M(&UI;G5S+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VEM9U]M
M:6YU<U]B;W1T;VT@/2`G;6EN=7-B;W1T;VTN<&YG)SL*"B`@("`O*BH*("`@
M("`J($1E9F%U;'0@=')E92!G<F%P:&EC(&9O<B!A(&UI;G5S(&]N;'DN"B`@
M("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?:6UG
M7VUI;G5S7V]N;'D@/2`G;6EN=7-O;FQY+G!N9R<["@H@("`@+RHJ"B`@("`@
M*B!$969A=6QT('1R964@9W)A<&AI8R!F;W(@82!N=6QL(&]N;'DN"B`@("`@
M*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?:6UG7VYU
M;&Q?;VYL>2`]("=N=6QL;VYL>2YP;F<G.PH*("`@("\J*@H@("`@("H@1&5F
M875L="!T<F5E(&=R87!H:6,@9F]R(&$@9F]L9&5R+@H@("`@("H*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VEM9U]F;VQD97(@/2`G
M9F]L9&5R+G!N9R<["@H@("`@+RHJ"B`@("`@*B!$969A=6QT('1R964@9W)A
M<&AI8R!F;W(@86X@;W!E;B!F;VQD97(N"B`@("`@*@H@("`@("H@0'9A<B!S
M=')I;F<*("`@("`J+PH@("`@=F%R("1?:6UG7V9O;&1E<E]O<&5N(#T@)V9O
M;&1E<F]P96XN<&YG)SL*"B`@("`O*BH*("`@("`J($1E9F%U;'0@=')E92!G
M<F%P:&EC(&9O<B!A(&QE868N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1?:6UG7VQE868@/2`G;&5A9BYP;F<G.PH*("`@
M("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1?;F]D97,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H@5$]$3PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1?;F]D95]P;W,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@5$]$
M3PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M9')O<&QI;F4@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0W5R<F5N="!V
M86QU92!O9B!T:&4@86QT('1A9R!C;W5N="X*("`@("`J"B`@("`@*B!`=F%R
M(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?86QT7V-O=6YT(#T@,#L*"B`@
M("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*B\*("`@(&9U;F-T:6]N
M($AO<F1E7U1R965?:'1M;"@D=')E95]N86UE+"`D<&%R86US*0H@("`@>PH@
M("`@("`@('!A<F5N=#HZ2&]R9&5?5')E92@D=')E95]N86UE+"`D<&%R86US
M*3L*"B`@("`@("`@)'1H:7,M/E]I;6=?9&ER(#T@)$=,3T)!3%-;)W)E9VES
M=')Y)UTM/F=E=$EM86=E1&ER*"=H;W)D92<I("X@)R]T<F5E)SL*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('1R964N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&)O;VQE86X@)'-T871I8R`@268@=')U92!T:&4@=')E92!N
M;V1E<R!C86XG="!B92!E>'!A;F1E9"!A;F0*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@(&-O;&QA<'-E9"!A;F0@=&AE('1R964@9V5T<R!R96YD
M97)E9"!E>'!A;F1E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE($A434P@8V]D92!O9B!T:&4@<F5N9&5R960@=')E92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T5')E92@D<W1A=&EC(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]S=&%T:6,@/2`D<W1A=&EC.PH@("`@("`@("1T:&ES
M+3Y?8G5I;&1);F1E;G1S*"1T:&ES+3Y?<F]O=%]N;V1E<RD["@H@("`@("`@
M("1T<F5E(#T@)'1H:7,M/E]B=6EL9$AE861E<B@I.PH@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3Y?<F]O=%]N;V1E<R!A<R`D;F]D95]I9"D@>PH@("`@("`@
M("`@("`D=')E92`N/2`D=&AI<RT^7V)U:6QD5')E92@D;F]D95]I9"D["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D=')E93L*("`@('T*"B`@("`O*BH*
M("`@("`J($-H96-K('1H92!C=7)R96YT(&5N=FER;VYM96YT('1O('-E92!I
M9B!W92!C86X@<F5N9&5R('1H92!(5$U,"B`@("`@*B!T<F5E+B!(5$U,(&ES
M(&%L=V%Y<R!R96YD97)A8FQE+"!A="!L96%S="!U;G1I;"!W92!A9&0@80H@
M("`@("H@<&AP+6=T:R!T<F5E(&)A8VME;F0L(&EN('=H:6-H(&-A<V4@=&AI
M<R!I;7!L96UE;G1A=&EO;B!W:6QL"B`@("`@*B!A8W1U86QL>2!N965D(&$@
M8F]D>2X*("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&ES(%1R964Z.B!B86-K
M96YD('=I;&P@9G5N8W1I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES4W5P
M<&]R=&5D*"D*("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@:G5S="!T:&4@2E,@;F]D92!D969I;FET
M:6]N<R!A<R!A('-T<FEN9RX@5&AI<R!I<R!A"B`@("`@*B!N;RUO<"!F;W(@
M=&AE($A434P@<F5N9&5R97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E
M<DYO9&5$969I;FET:6]N<R@I"B`@("!["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!(5$U,(&-O9&4@9F]R(&$@:&5A9&5R(')O=RP@:68@
M;F5C97-S87)Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@2%1-3"!C;V1E(&]F('1H
M92!H96%D97(@<F]W(&]R(&%N(&5M<'1Y('-T<FEN9RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V)U:6QD2&5A9&5R*"D*("`@('L*("`@("`@("!I9B`H(6-O
M=6YT*"1T:&ES+3Y?:&5A9&5R*2D@>PH@("`@("`@("`@("!R971U<FX@)R<[
M"B`@("`@("`@?0H*("`@("`@("`D:'1M;"`]("<\9&EV)SL*("`@("`@("`O
M*B!)9B!U<VEN9R!A;'1E<FYA=&EN9R!R;W<@<VAA9&EN9RP@=V]R:R!O=70@
M8V]R<F5C=`H@("`@("`@("`J('-H861E+B`J+PH@("`@("`@(&EF("@D=&AI
M<RT^9V5T3W!T:6]N*"=A;'1E<FYA=&4G*2D@>PH@("`@("`@("`@("`D:'1M
M;"`N/2`G(&-L87-S/2)I=&5M)R`N("1T:&ES+3Y?86QT7V-O=6YT("X@)R(G
M.PH@("`@("`@("`@("`D=&AI<RT^7V%L=%]C;W5N="`](#$@+2`D=&AI<RT^
M7V%L=%]C;W5N=#L*("`@("`@("!]"B`@("`@("`@)&AT;6P@+CT@)SXG.PH*
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7VAE861E<B!A<R`D:&5A9&5R*2![
M"B`@("`@("`@("`@("1H=&UL("X]("<\9&EV(&-L87-S/2)L969T1FQO870G
M.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1H96%D97);)V-L87-S)UTI*2![
M"B`@("`@("`@("`@("`@("`D:'1M;"`N/2`G("<@+B`D:&5A9&5R6R=C;&%S
M<R==.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1H=&UL("X]("<B)SL*
M"B`@("`@("`@("`@("1S='EL92`]("<G.PH@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1H96%D97);)W=I9'1H)UTI*2!["B`@("`@("`@("`@("`@("`D<W1Y
M;&4@+CT@)W=I9'1H.B<@+B`D:&5A9&5R6R=W:61T:"==("X@)SLG.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&EF("@A96UP='DH)&AE861E<ELG86QI
M9VXG72DI('L*("`@("`@("`@("`@("`@("1S='EL92`N/2`G=&5X="UA;&EG
M;CHG("X@)&AE861E<ELG86QI9VXG72`N("<[)SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1S='EL92DI('L*("`@("`@("`@("`@
M("`@("1H=&UL("X]("<@<W1Y;&4](B<@+B`D<W1Y;&4@+B`G(B<["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)&AT;6P@+CT@)SXG.PH@("`@("`@("`@
M("`D:'1M;"`N/2!E;7!T>2@D:&5A9&5R6R=H=&UL)UTI(#\@)R9N8G-P.R<@
M.B`D:&5A9&5R6R=H=&UL)UT["B`@("`@("`@("`@("1H=&UL("X]("<\+V1I
M=CXG.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1H=&UL("X@)SPO9&EV
M/B<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296-U<G-I=F4@9G5N8W1I;VX@
M=&\@=V%L:R!T:')O=6=H('1H92!T<F5E(&%R<F%Y(&%N9"!B=6EL9"!T:&4@
M;W5T<'5T+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&YO9&5?:60@(%1H92!.;V1E($E$+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=')E92!R96YD97)I
M;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]B=6EL9%1R964H)&YO9&5?:60I
M"B`@("!["B`@("`@("`@)&]U='!U="`]("1T:&ES+3Y?8G5I;&1,:6YE*"1N
M;V1E7VED*3L*"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;F]D97-;)&YO
M9&5?:61=6R=C:&EL9')E;B==*2`F)@H@("`@("`@("`@("`D=&AI<RT^7VYO
M9&5S6R1N;V1E7VED75LG97AP86YD960G72D@>PH@("`@("`@("`@("`D;G5M
M7W-U8FYO9&5S(#T@8V]U;G0H)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)V-H
M:6QD<F5N)UTI.PH@("`@("`@("`@("!F;W(@*"1C(#T@,#L@)&,@/"`D;G5M
M7W-U8FYO9&5S.R`D8RLK*2!["B`@("`@("`@("`@("`@("`D8VAI;&1?;F]D
M95]I9"`]("1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=C:&EL9')E;B==6R1C
M73L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;F]D95]P;W-;)&-H:6QD7VYO
M9&5?:61=(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;F]D
M95]P;W-;)&-H:6QD7VYO9&5?:61=6R=P;W,G72`]("1C("L@,3L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?;F]D95]P;W-;)&-H:6QD7VYO9&5?:61=6R=C
M;W5N="==(#T@)&YU;5]S=6)N;V1E<SL*("`@("`@("`@("`@("`@("1O=71P
M=70@+CT@)'1H:7,M/E]B=6EL9%1R964H)&-H:6QD7VYO9&5?:60I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&]U='!U=#L*
M("`@('T*"B`@("`O*BH*("`@("`J($9U;F-T:6]N('1O(&-R96%T92!A('-I
M;F=L92!L:6YE(&]F('1H92!T<F5E+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YO9&5?:60@
M(%1H92!.;V1E($E$+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@<F5N9&5R960@;&EN92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V)U:6QD
M3&EN92@D;F]D95]I9"D*("`@('L*("`@("`@("`D8VQA<W-.86UE(#T@)W1R
M9652;W<G.PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]N;V1E<ULD;F]D
M95]I9%U;)V-L87-S)UTI*2!["B`@("`@("`@("`@("1C;&%S<TYA;64@+CT@
M)R`G("X@)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)V-L87-S)UT["B`@("`@
M("`@?0H@("`@("`@("\J($EF('5S:6YG(&%L=&5R;F%T:6YG(')O=R!S:&%D
M:6YG+"!W;W)K(&]U="!C;W)R96-T"B`@("`@("`@("H@<VAA9&4N("HO"B`@
M("`@("`@:68@*"1T:&ES+3YG971/<'1I;VXH)V%L=&5R;F%T92<I*2!["B`@
M("`@("`@("`@("1C;&%S<TYA;64@+CT@)R!I=&5M)R`N("1T:&ES+3Y?86QT
M7V-O=6YT.PH@("`@("`@("`@("`D=&AI<RT^7V%L=%]C;W5N="`](#$@+2`D
M=&AI<RT^7V%L=%]C;W5N=#L*("`@("`@("!]"@H@("`@("`@("1L:6YE(#T@
M)SQD:78@8VQA<W,](B<@+B`D8VQA<W-.86UE("X@)R(^)SL*"B`@("`@("`@
M+RH@268@=V4@:&%V92!H96%D97)S+"!T<F%C:R!W:&EC:"!L;V=I8V%L(")C
M;VQU;6XB('=E)W)E(&EN"B`@("`@("`@("H@9F]R(&%N>2!G:79E;B!C96QL
M(&]F(&-O;G1E;G0N("HO"B`@("`@("`@)&-O;'5M;B`](#`["@H@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG97AT<F$G75M(
M3U)$15]44D5%7T585%)!7TQ%1E1=*2D@>PH@("`@("`@("`@("`D97AT<F$@
M/2`D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG97AT<F$G75M(3U)$15]44D5%
M7T585%)!7TQ%1E1=.PH@("`@("`@("`@("`D8TUA>"`](&-O=6YT*"1E>'1R
M82D["B`@("`@("`@("`@(&9O<B`H)&,@/2`P.R`D8R`\("1C36%X.R`D8RLK
M*2!["B`@("`@("`@("`@("`@("`D<W1Y;&4@/2`G)SL*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7VAE861E<ELD8V]L=6UN75LG=VED=&@G
M72DI('L*("`@("`@("`@("`@("`@("`@("`D<W1Y;&4@+CT@)W=I9'1H.B<@
M+B`D=&AI<RT^7VAE861E<ELD8V]L=6UN75LG=VED=&@G72`N("<[)SL*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D;&EN92`N/2`G/&1I
M=B!C;&%S<STB;&5F=$9L;V%T(B<["B`@("`@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1S='EL92DI('L*("`@("`@("`@("`@("`@("`@("`D;&EN92`N/2`G
M('-T>6QE/2(G("X@)'-T>6QE("X@)R(G.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)&QI;F4@+CT@)SXG("X@)&5X=')A6R1C72`N("<\
M+V1I=CXG.PH*("`@("`@("`@("`@("`@("1C;VQU;6XK*SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@)'-T>6QE(#T@)R<["B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?:&5A9&5R6R1C;VQU;6Y=6R=W:61T:"==*2D@
M>PH@("`@("`@("`@("`D<W1Y;&4@+CT@)W=I9'1H.B<@+B`D=&AI<RT^7VAE
M861E<ELD8V]L=6UN75LG=VED=&@G72`N("<[)SL*("`@("`@("!]"B`@("`@
M("`@)&QI;F4@+CT@)SQD:78@8VQA<W,](FQE9G1&;&]A="(G.PH@("`@("`@
M(&EF("@A96UP='DH)'-T>6QE*2D@>PH@("`@("`@("`@("`D;&EN92`N/2`G
M('-T>6QE/2(G("X@)'-T>6QE("X@)R(G.PH@("`@("`@('T*("`@("`@("`D
M;&EN92`N/2`G/B<["@H@("`@("`@(&EF("@D=&AI<RT^9V5T3W!T:6]N*"=M
M=6QT:6QI;F4G*2D@>PH@("`@("`@("`@("`D;&EN92`N/2`G/'1A8FQE(&-E
M;&QS<&%C:6YG/2(P(CX\='(^/'1D/B<["B`@("`@("`@?0H*("`@("`@("!F
M;W(@*"1I(#T@)'1H:7,M/E]S=&%T:6,@/R`Q(#H@,#L@)&D@/"`D=&AI<RT^
M7VYO9&5S6R1N;V1E7VED75LG:6YD96YT)UT[("1I*RLI('L*("`@("`@("`@
M("`@)&QI;F4@+CT@)SQI;6<@<W)C/2(G("X@)'1H:7,M/E]I;6=?9&ER("X@
M)R\G.PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]D<F]P;&EN95LD:5T@)B8@
M)'1H:7,M/F=E=$]P=&EO;B@G;&EN97,G+"!F86QS92P@=')U92DI('L*("`@
M("`@("`@("`@("`@("1L:6YE("X]("1T:&ES+3Y?:6UG7VQI;F4@+B`G(B`G
M"B`@("`@("`@("`@("`@("`@("`@+B`G86QT/2)\)FYB<W`[)FYB<W`[)FYB
M<W`[(B`G.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)&QI;F4@+CT@)'1H:7,M/E]I;6=?8FQA;FL@+B`G(B`G"B`@("`@("`@("`@
M("`@("`@("`@+B`G86QT/2(F;F)S<#LF;F)S<#LF;F)S<#LB("<["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)&QI;F4@+CT@)VAE:6=H=#TB,C`B('=I
M9'1H/2(R,"(@<W1Y;&4](G9E<G1I8V%L+6%L:6=N.FUI9&1L92(@+SXG.PH@
M("`@("`@('T*("`@("`@("`D;&EN92`N/2`D=&AI<RT^7W-E=$YO9&54;V=G
M;&4H)&YO9&5?:60I("X@)'1H:7,M/E]S971.;V1E26-O;B@D;F]D95]I9"D[
M"B`@("`@("`@:68@*"1T:&ES+3YG971/<'1I;VXH)VUU;'1I;&EN92<I*2![
M"B`@("`@("`@("`@("1L:6YE("X]("<\+W1D/CQT9#XG.PH@("`@("`@('T*
M("`@("`@("`D;&EN92`N/2`D=&AI<RT^7W-E=$QA8F5L*"1N;V1E7VED*3L*
M"B`@("`@("`@:68@*"1T:&ES+3YG971/<'1I;VXH)VUU;'1I;&EN92<I*2![
M"B`@("`@("`@("`@("1L:6YE("X]("<\+W1D/CPO='(^/"]T86)L93XG.PH@
M("`@("`@('T*"B`@("`@("`@)&QI;F4@+CT@)SPO9&EV/B<["B`@("`@("`@
M)&-O;'5M;BLK.PH*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]N;V1E<ULD
M;F]D95]I9%U;)V5X=')A)UU;2$]21$5?5%)%15]%6%1205]224=(5%TI*2![
M"B`@("`@("`@("`@("1E>'1R82`]("1T:&ES+3Y?;F]D97-;)&YO9&5?:61=
M6R=E>'1R82==6TA/4D1%7U12145?15A44D%?4DE'2%1=.PH@("`@("`@("`@
M("`D8TUA>"`](&-O=6YT*"1E>'1R82D["B`@("`@("`@("`@(&9O<B`H)&,@
M/2`P.R`D8R`\("1C36%X.R`D8RLK*2!["B`@("`@("`@("`@("`@("`D<W1Y
M;&4@/2`G)SL*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VAE
M861E<ELD8V]L=6UN75LG=VED=&@G72DI('L*("`@("`@("`@("`@("`@("`@
M("`D<W1Y;&4@+CT@)W=I9'1H.B<@+B`D=&AI<RT^7VAE861E<ELD8V]L=6UN
M75LG=VED=&@G72`N("<[)SL*("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("`D;&EN92`N/2`G/&1I=B!C;&%S<STB;&5F=$9L;V%T(B<["B`@
M("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1S='EL92DI('L*("`@("`@("`@
M("`@("`@("`@("`D;&EN92`N/2`G('-T>6QE/2(G("X@)'-T>6QE("X@)R(G
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&QI;F4@+CT@
M)SXG("X@)&5X=')A6R1C72`N("<\+V1I=CXG.PH*("`@("`@("`@("`@("`@
M("1C;VQU;6XK*SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1L:6YE("X@(CPO9&EV/EQN(CL*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E=',@=&AE(&QA8F5L(&]N('1H92!T<F5E(&QI;F4N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;F]D95]I9"`@5&AE($YO9&4@240N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!L86)E;"!F;W(@=&AE('1R964@;&EN92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7W-E=$QA8F5L*"1N;V1E7VED*0H@("`@>PH@
M("`@("`@("1N(#T@)'1H:7,M/E]N;V1E<ULD;F]D95]I9%T["@H@("`@("`@
M("1O=71P=70@/2`G/'-P86XG.PH@("`@("`@(&EF("@A96UP='DH)&Y;)V]N
M8VQI8VLG72DI('L*("`@("`@("`@("`@)&]U='!U="`N/2`G(&]N8VQI8VL]
M(B<@+B`D;ELG;VYC;&EC:R==("X@)R(G.PH@("`@("`@('T*("`@("`@("`D
M;W5T<'5T("X]("<^)SL*"B`@("`@("`@)&QA8F5L(#T@)&Y;)VQA8F5L)UT[
M"B`@("`@("`@:68@*"%E;7!T>2@D;ELG=7)L)UTI*2!["B`@("`@("`@("`@
M("1T87)G970@/2`G)SL*("`@("`@("`@("`@:68@*"%E;7!T>2@D;ELG=&%R
M9V5T)UTI*2!["B`@("`@("`@("`@("`@("`D=&%R9V5T(#T@)R!T87)G970]
M(B<@+B`D;ELG=&%R9V5T)UT@+B`G(B<["B`@("`@("`@("`@('T@96QS96EF
M("@D=&%R9V5T(#T@)'1H:7,M/F=E=$]P=&EO;B@G=&%R9V5T)RDI('L*("`@
M("`@("`@("`@("`@("1T87)G970@/2`G('1A<F=E=#TB)R`N("1T87)G970@
M+B`G(B<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&]U='!U="`N/2`G
M/&$G("X@*"%E;7!T>2@D;ELG=7)L8VQA<W,G72D@/R`G(&-L87-S/2(G("X@
M)&Y;)W5R;&-L87-S)UT@+B`G(B<@.B`G)RD@+B`G(&AR968](B<@+B`D;ELG
M=7)L)UT@+B`G(B<@+B`D=&%R9V5T("X@)SXG("X@)&QA8F5L("X@)SPO83XG
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1O=71P=70@+CT@)&QA
M8F5L.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O=71P=70@+B`G/"]S
M<&%N/B<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!N;V1E('1O
M9V=L92!O;B!T:&4@=')E92!L:6YE+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YO9&5?:60@
M(%1H92!.;V1E($E$+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@;F]D92!T;V=G;&4@9F]R('1H92!T<F5E(&QI;F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]S971.;V1E5&]G9VQE*"1N;V1E7VED*0H@("`@>PH@("`@
M("`@("1L:6YK7W-T87)T(#T@)R<["@H@("`@("`@(&EF("@H)'1H:7,M/E]N
M;V1E<ULD;F]D95]I9%U;)VEN9&5N="==(#T](#`I("8F"B`@("`@("`@("`@
M(&ES<V5T*"1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=C:&EL9')E;B==*2D@
M>PH@("`@("`@("`@("`O*B!4;W`@;&5V96P@;F]D92!W:71H(&-H:6QD<F5N
M+B`J+PH@("`@("`@("`@("`D=&AI<RT^7V1R;W!L:6YE6S!=(#T@9F%L<V4[
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^7W-T871I8RD@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("<G.PH@("`@("`@("`@("!](&5L<V5I9B`H(21T:&ES
M+3YG971/<'1I;VXH)VQI;F5S)RP@9F%L<V4L('1R=64I*2!["B`@("`@("`@
M("`@("`@("`D:6UG(#T@)'1H:7,M/E]I;6=?8FQA;FL["B`@("`@("`@("`@
M("`@("`D86QT(#T@)R9N8G-P.R9N8G-P.R9N8G-P.R<["B`@("`@("`@("`@
M('T@96QS96EF("@D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG97AP86YD960G
M72D@>PH@("`@("`@("`@("`@("`@)&EM9R`]("1T:&ES+3Y?:6UG7VUI;G5S
M7V]N;'D["B`@("`@("`@("`@("`@("`D86QT(#T@)RTG.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&EM9R`]("1T:&ES+3Y?:6UG
M7W!L=7-?;VYL>3L*("`@("`@("`@("`@("`@("1A;'0@/2`G*R<["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@:68@*"$D=&AI<RT^7W-T871I8RD@>PH@
M("`@("`@("`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<BA(;W)D
M93HZ<V5L9E5R;"@I+"!(3U)$15]44D5%7U1/1T=,12`N("1T:&ES+3Y?:6YS
M=&%N8V4L("1N;V1E7VED*3L*("`@("`@("`@("`@("`@("1L:6YK7W-T87)T
M(#T@2&]R9&4Z.FQI;FLH)'5R;"D["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V5I9B`H*"1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=I;F1E;G0G72`A
M/2`P*2`F)@H@("`@("`@("`@("`A:7-S970H)'1H:7,M/E]N;V1E<ULD;F]D
M95]I9%U;)V-H:6QD<F5N)UTI*2!["B`@("`@("`@("`@("\J($YO9&4@=VET
M:&]U="!C:&EL9')E;BX@*B\*("`@("`@("`@("`@:68@*"1T:&ES+3Y?;F]D
M95]P;W-;)&YO9&5?:61=6R=P;W,G72`\("1T:&ES+3Y?;F]D95]P;W-;)&YO
M9&5?:61=6R=C;W5N="==*2!["B`@("`@("`@("`@("`@("`O*B!.;W0@;&%S
M="!N;V1E+B`J+PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YG971/<'1I
M;VXH)VQI;F5S)RP@9F%L<V4L('1R=64I*2!["B`@("`@("`@("`@("`@("`@
M("`@)&EM9R`]("1T:&ES+3Y?:6UG7VIO:6X["B`@("`@("`@("`@("`@("`@
M("`@)&%L="`]("=\+2<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("1I;6<@/2`D=&AI<RT^7VEM9U]B;&%N:SL*("`@
M("`@("`@("`@("`@("`@("`D86QT(#T@)R9N8G-P.R9N8G-P.R9N8G-P.R<[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^7V1R
M;W!L:6YE6R1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=I;F1E;G0G75T@/2!T
M<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+RH@
M3&%S="!N;V1E+B`J+PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YG971/
M<'1I;VXH)VQI;F5S)RP@9F%L<V4L('1R=64I*2!["B`@("`@("`@("`@("`@
M("`@("`@)&EM9R`]("1T:&ES+3Y?:6UG7VIO:6Y?8F]T=&]M.PH@("`@("`@
M("`@("`@("`@("`@("1A;'0@/2`G8"TG.PH@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D:6UG(#T@)'1H:7,M/E]I;6=?
M8FQA;FL["B`@("`@("`@("`@("`@("`@("`@)&%L="`]("<F;F)S<#LF;F)S
M<#LF;F)S<#LG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]D<F]P;&EN95LD=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG:6YD
M96YT)UU=(#T@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I
M9B`H:7-S970H)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)V-H:6QD<F5N)UTI
M*2!["B`@("`@("`@("`@("\J($YO9&4@=VET:"!C:&EL9')E;BX@*B\*("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?;F]D95]P;W-;)&YO9&5?:61=6R=P;W,G
M72`\("1T:&ES+3Y?;F]D95]P;W-;)&YO9&5?:61=6R=C;W5N="==*2!["B`@
M("`@("`@("`@("`@("`O*B!.;W0@;&%S="!N;V1E+B`J+PH@("`@("`@("`@
M("`@("`@:68@*"$D=&AI<RT^9V5T3W!T:6]N*"=L:6YE<R<L(&9A;'-E+"!T
M<G5E*2D@>PH@("`@("`@("`@("`@("`@("`@("1I;6<@/2`D=&AI<RT^7VEM
M9U]B;&%N:SL*("`@("`@("`@("`@("`@("`@("`D86QT(#T@)R9N8G-P.R9N
M8G-P.R9N8G-P.R<["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'1H:7,M
M/E]S=&%T:6,I('L*("`@("`@("`@("`@("`@("`@("`D:6UG(#T@)'1H:7,M
M/E]I;6=?:F]I;CL*("`@("`@("`@("`@("`@("`@("`D86QT(#T@)WPM)SL*
M("`@("`@("`@("`@("`@('T@96QS96EF("@D=&AI<RT^7VYO9&5S6R1N;V1E
M7VED75LG97AP86YD960G72D@>PH@("`@("`@("`@("`@("`@("`@("1I;6<@
M/2`D=&AI<RT^7VEM9U]M:6YU<SL*("`@("`@("`@("`@("`@("`@("`D86QT
M(#T@)RTG.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D:6UG(#T@)'1H:7,M/E]I;6=?<&QU<SL*("`@("`@("`@("`@
M("`@("`@("`D86QT(#T@)RLG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]D<F]P;&EN95LD=&AI<RT^7VYO9&5S6R1N;V1E
M7VED75LG:6YD96YT)UU=(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("\J($QA<W0@;F]D92X@*B\*("`@("`@("`@("`@
M("`@(&EF("@A)'1H:7,M/F=E=$]P=&EO;B@G;&EN97,G+"!F86QS92P@=')U
M92DI('L*("`@("`@("`@("`@("`@("`@("`D:6UG(#T@)'1H:7,M/E]I;6=?
M8FQA;FL["B`@("`@("`@("`@("`@("`@("`@)&%L="`]("<F;F)S<#LF;F)S
M<#LF;F)S<#LG.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?
M<W1A=&EC*2!["B`@("`@("`@("`@("`@("`@("`@)&EM9R`]("1T:&ES+3Y?
M:6UG7VIO:6Y?8F]T=&]M.PH@("`@("`@("`@("`@("`@("`@("1A;'0@/2`G
M8"TG.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?;F]D97-;
M)&YO9&5?:61=6R=E>'!A;F1E9"==*2!["B`@("`@("`@("`@("`@("`@("`@
M)&EM9R`]("1T:&ES+3Y?:6UG7VUI;G5S7V)O='1O;3L*("`@("`@("`@("`@
M("`@("`@("`D86QT(#T@)RTG.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`D:6UG(#T@)'1H:7,M/E]I;6=?<&QU<U]B
M;W1T;VT["B`@("`@("`@("`@("`@("`@("`@)&%L="`]("<K)SL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3Y?9')O<&QI;F5;
M)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)VEN9&5N="==72`](&9A;'-E.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]S=&%T:6,I
M('L*("`@("`@("`@("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H
M2&]R9&4Z.G-E;&95<FPH*2P@2$]21$5?5%)%15]43T='3$4@+B`D=&AI<RT^
M7VEN<W1A;F-E+"`D;F]D95]I9"D["B`@("`@("`@("`@("`@("`D;&EN:U]S
M=&%R="`]($AO<F1E.CIL:6YK*"1U<FPI.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@5&]P(&QE=F5L(&YO9&4@=VET
M:"!N;R!C:&EL9')E;BX@*B\*("`@("`@("`@("`@:68@*"1T:&ES+3Y?<W1A
M=&EC*2!["B`@("`@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*"1T:&ES+3YG971/<'1I;VXH)VQI;F5S)RP@
M9F%L<V4L('1R=64I*2!["B`@("`@("`@("`@("`@("`D:6UG(#T@)'1H:7,M
M/E]I;6=?;G5L;%]O;FQY.PH@("`@("`@("`@("`@("`@)&%L="`]("<F;F)S
M<#LF;F)S<#LG.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)&EM9R`]("1T:&ES+3Y?:6UG7V)L86YK.PH@("`@("`@("`@("`@("`@
M)&%L="`]("<F;F)S<#LF;F)S<#LF;F)S<#LG.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1T:&ES+3Y?9')O<&QI;F5;,%T@/2!F86QS93L*("`@("`@
M("!]"@H@("`@("`@("1L:6YK7V5N9"`]("@D;&EN:U]S=&%R="D@/R`G/"]A
M/B<@.B`G)SL*"B`@("`@("`@)&EM9R`]("1L:6YK7W-T87)T("X@)SQI;6<@
M<W)C/2(G("X@)'1H:7,M/E]I;6=?9&ER("X@)R\G("X@)&EM9R`N("<B)PH@
M("`@("`@("`@("`N("AI<W-E="@D86QT*2`_("<@86QT/2(G("X@)&%L="`N
M("<B)R`Z("<G*0H@("`@("`@("`@("`N("<@:&5I9VAT/2(R,"(@=VED=&@]
M(C(P(B!S='EL93TB=F5R=&EC86PM86QI9VXZ;6ED9&QE(B!B;W)D97(](C`B
M("\^)PH@("`@("`@("`@("`N("1L:6YK7V5N9#L*"B`@("`@("`@<F5T=7)N
M("1I;6<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!I8V]N(&9O
M<B!T:&4@;F]D92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N;V1E7VED("!4:&4@3F]D92!)
M1"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&YO9&4@:6-O
M;B!F;W(@=&AE('1R964@;&EN92X*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E
M=$YO9&5)8V]N*"1N;V1E7VED*0H@("`@>PH@("`@("`@("1I;6=?9&ER(#T@
M:7-S970H)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)VEC;VYD:7(G72D@/R`D
M=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG:6-O;F1I<B==(#H@)'1H:7,M/E]I
M;6=?9&ER.PH@("`@("`@(&EF("@D:6UG7V1I<BD@>PH@("`@("`@("`@("`D
M:6UG7V1I<B`N/2`G+R<["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)VEC;VXG72DI('L*("`@("`@("`@
M("`@:68@*&5M<'1Y*"1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=I8V]N)UTI
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@+RH@3F]D92!H87,@82!U<V5R(&1E9FEN960@:6-O;BX@
M*B\*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;F]D97-;)&YO9&5?
M:61=6R=I8V]N;W!E;B==*2`F)@H@("`@("`@("`@("`@("`@)'1H:7,M/E]N
M;V1E<ULD;F]D95]I9%U;)V5X<&%N9&5D)UTI('L*("`@("`@("`@("`@("`@
M("1I;6<@/2`D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG:6-O;F]P96XG73L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1I;6<@/2`D
M=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG:6-O;B==.PH@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@57-E('-T86YD87)D
M(&EC;VX@<V5T+B`J+PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]N
M;V1E<ULD;F]D95]I9%U;)V-H:6QD<F5N)UTI*2!["B`@("`@("`@("`@("`@
M("`O*B!.;V1E('=I=&@@8VAI;&1R96XN("HO"B`@("`@("`@("`@("`@("`D
M:6UG(#T@*"1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=E>'!A;F1E9"==*2`_
M("1T:&ES+3Y?:6UG7V9O;&1E<E]O<&5N(#H@)'1H:7,M/E]I;6=?9F]L9&5R
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+RH@3&5A
M9B!N;V1E("AN;R!C:&EL9')E;BDN("HO"B`@("`@("`@("`@("`@("`D:6UG
M(#T@)'1H:7,M/E]I;6=?;&5A9CL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@)&EM9W1X="`]("<\:6UG('-R8STB)R`N("1I;6=?9&ER("X@
M)&EM9R`N("<B)SL*"B`@("`@("`@+RH@1&]E<R!T:&4@;F]D92!H879E('5S
M97(@9&5F:6YE9"!A;'0@=&5X=#\@*B\*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]N;V1E<ULD;F]D95]I9%U;)VEC;VYA;'0G72DI('L*("`@("`@("`@
M("`@)&EM9W1X="`N/2`G(&%L=#TB)R`N(&AT;6QS<&5C:6%L8VAA<G,H)'1H
M:7,M/E]N;V1E<ULD;F]D95]I9%U;)VEC;VYA;'0G72D@+B`G(B<["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&EM9W1X="`N("<@+SXG.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O5')E92]J879A<V-R:7!T+G!H<```````````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#$S,30W`#$P-3$U-#,S-S4P`#`R,S(T-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@5&AE($AO<F1E7U1R965?:F%V87-C<FEP=#HZ(&-L87-S(&5X
M=&5N9',@=&AE($AO<F1E7U1R964@8VQA<W,@=&\@<')O=FED90H@*B!J879A
M<V-R:7!T('-P96-I9FEC(')E;F1E<FEN9R!F=6YC=&EO;G,N"B`J"B`J($-O
M<'ER:6=H="`R,#`S+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O
M;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1R964O
M5')E92]J879A<V-R:7!T+G!H<"QV(#$N,S0N,BXY(#(P,#8O,#$O,#$@,C$Z
M,C@Z-#`@:F%N($5X<"`D"B`J"B`J($!A=71H;W(@($UA<FMO($1J=6MI8R`\
M;6%R:V]`;V)L;RYC;VT^"B`J($!P86-K86=E($AO<F1E7U1R964*("H@0'-I
M;F-E("`@2&]R9&4@,RXP"B`J+PIC;&%S<R!(;W)D95]4<F5E7VIA=F%S8W)I
M<'0@97AT96YD<R!(;W)D95]4<F5E('L*"B`@("`O*BH*("`@("`J(%1H92!N
M86UE(&]F('1H92!S;W5R8V4@9F]R('1H92!T<F5E(&1A=&$N"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<V]U<F-E7VYA
M;64@/2!N=6QL.PH*("`@("\J*@H@("`@("H@5&AE(&YA;64@;V8@=&AE('1A
M<F=E="!E;&5M96YT('1O(&]U='!U="!T:&4@:F%V87-C<FEP="!T<F5E+@H@
M("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V]P
M=&EO;G-?;F%M92`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!4:&4@;F%M92!O
M9B!T:&4@=&%R9V5T(&5L96UE;G0@=&\@;W5T<'5T('1H92!J879A<V-R:7!T
M('1R964N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?=&%R9V5T7VYA;64@/2!N=6QL.PH*("`@("\J*@H@("`@("H@0V]N
M<W1R=6-T;W(*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?5')E95]J879A
M<V-R:7!T*"1T<F5E7VYA;64L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@('!A<F5N=#HZ2&]R9&5?5')E92@D=')E95]N86UE+"`D<&%R86US
M*3L*"B`@("`@("`@:68@*"%I<W-E="@D1TQ/0D%,4ULG8G)O=W-E<B==*2D@
M>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T)R;W=S97(N<&AP
M)SL*("`@("`@("`@("`@)$=,3T)!3%-;)V)R;W=S97(G72`]("9"<F]W<V5R
M.CIS:6YG;&5T;VXH*3L*("`@("`@("!]"@H@("`@("`@("\J($-H96-K(&9O
M<B!A(&IA=F%S8W)I<'0@<V5S<VEO;B!S=&%T92X@*B\*("`@("`@("!I9B`H
M)'1H:7,M/E]U<V5S97-S:6]N("8F"B`@("`@("`@("`@(&ES<V5T*"1?0T]/
M2TE%6R1T:&ES+3Y?:6YS=&%N8V4@+B`G7V5X<&%N9&5D)UTI*2!["B`@("`@
M("`@("`@("\J(%)E;6]V92`B97AP(B!P<F5F:7@@9G)O;2!C;V]K:64@=F%L
M=64N("HO"B`@("`@("`@("`@("1N;V1E<R`](&5X<&QO9&4H)RPG+"!S=6)S
M='(H)%]#3T]+245;)'1H:7,M/E]I;G-T86YC92`N("=?97AP86YD960G72P@
M,RDI.PH*("`@("`@("`@("`@+RH@36%K92!S=7)E('1H97)E(&%R92!N;R!P
M<F5V:6]U<R!N;V1E<R!S=&]R960@:6X@=&AE"B`@("`@("`@("`@("`J('-E
M<W-I;VXN("HO"B`@("`@("`@("`@("1?4T534TE/3ELG:&]R9&5?=')E92==
M6R1T:&ES+3Y?:6YS=&%N8V5=6R=E>'!A;F1E9"==(#T@87)R87DH*3L*"B`@
M("`@("`@("`@("\J(%-A=F4@;F]D97,@=&\@=&AE('-E<W-I;VXN("HO"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1N;V1E<R!A<R`D:60I('L*("`@("`@("`@
M("`@("`@("1?4T534TE/3ELG:&]R9&5?=')E92==6R1T:&ES+3Y?:6YS=&%N
M8V5=6R=E>'!A;F1E9"==6R1I9%T@/2!T<G5E.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=')E
M92X*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<W1A=&EC("!)9B!T
M<G5E('1H92!T<F5E(&YO9&5S(&-A;B=T(&)E(&5X<&%N9&5D(&%N9`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@8V]L;&%P<V5D(&%N9"!T:&4@
M=')E92!G971S(')E;F1E<F5D(&5X<&%N9&5D+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@2%1-3"!C;V1E(&]F('1H92!R96YD97)E9"!T
M<F5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714<F5E*"1S=&%T:6,@/2!F
M86QS92D*("`@('L*("`@("`@("`D=&AI<RT^7W-T871I8R`]("1S=&%T:6,[
M"B`@("`@("`@)'1H:7,M/E]S;W5R8V5?;F%M92`]("=N7R<@+B`D=&AI<RT^
M7VEN<W1A;F-E.PH@("`@("`@("1T:&ES+3Y?:&5A9&5R7VYA;64@/2`G:%\G
M("X@)'1H:7,M/E]I;G-T86YC93L*("`@("`@("`D=&AI<RT^7V]P=&EO;G-?
M;F%M92`]("=O7R<@+B`D=&AI<RT^7VEN<W1A;F-E.PH@("`@("`@("1T:&ES
M+3Y?=&%R9V5T7VYA;64@/2`G=%\G("X@)'1H:7,M/E]I;G-T86YC93L*("`@
M("`@("`D=&AI<RT^7V)U:6QD26YD96YT<R@D=&AI<RT^7W)O;W1?;F]D97,I
M.PH*("`@("`@("`D=')E92`]("1T:&ES+3Y?9V5T5')E95-O=7)C92@I("X*
M("`@("`@("`@("`@("<\9&EV(&ED/2(G("X@)'1H:7,M/E]T87)G971?;F%M
M92`N("<B/CPO9&EV/B<@+@H@("`@("`@("`@("`@)'1H:7,M/E]G9714<F5E
M26YI="@I.PH*("`@("`@("!(;W)D93HZ861D4V-R:7!T1FEL92@G=')E92YJ
M<R<L("=H;W)D92<I.PH@("`@("`@(')E='5R;B`D=')E93L*("`@('T*"B`@
M("`O*BH*("`@("`J($-H96-K('1H92!C=7)R96YT(&5N=FER;VYM96YT('1O
M('-E92!I9B!W92!C86X@<F5N9&5R('1H92!(5$U,"B`@("`@*B!T<F5E+B!7
M92!C:&5C:R!F;W(@1$]-('-U<'!O<G0@:6X@=&AE(&)R;W=S97(N"B`@("`@
M*@H@("`@("H@0'-T871I8PH@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5VAE=&AE<B!O<B!N;W0@=&AI<R!4<F5E.CH@8F%C:V5N9"!W:6QL(&9U
M;F-T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<U-U<'!O<G1E9"@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1'3$]"04Q36R=B<F]W<V5R)UTM/FAA<T9E
M871U<F4H)V1O;2<I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!J
M=7-T('1H92!*4R!N;V1E(&1E9FEN:71I;VYS(&%S(&$@<W1R:6YG+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@2F%V87-C<FEP="!N;V1E
M(&%R<F%Y(&1E9FEN:71I;VYS+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD
M97).;V1E1&5F:6YI=&EO;G,H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8G5I
M;&1);F1E;G1S*"1T:&ES+3Y?<F]O=%]N;V1E<RD["@H@("`@("`@("1N;V1E
M2G,@/2`G)SL*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VYO9&5S(&%S("1N
M;V1E7VED(#T^("1N;V1E*2!["B`@("`@("`@("`@("1N;V1E2G,@+CT@)'1H
M:7,M/E]G971*<T%R<F%Y16QE;65N="AS<')I;G1F*"<E<UM<)R5S7"==)RP@
M)VY?)R`N("1T:&ES+3Y?:6YS=&%N8V4L("1N;V1E7VED*2P@)&YO9&4I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1N;V1E2G,@+B`D=&AI<RT^7VEN
M<W1A;F-E("X@)RYR96YD97)4<F5E*')O;W1?;F]D97,I.R<["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!/=71P=71S('1H92!D871A(&9O<B!T:&4@=')E92!A
M<R!A(&IA=F%S8W)I<'0@87)R87DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G9714<F5E4V]U<F-E*"D*
M("`@('L*("`@("`@("!G;&]B86P@)&)R;W=S97(["@H@("`@("`@("1J<R`@
M/2`G/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/B<@+B`B7&XB.PH@
M("`@("`@("1J<R`N/2`G=F%R(&5X=')A0V]L<TQE9G0@/2`G("X@)'1H:7,M
M/E]E>'1R85]C;VQS7VQE9G0@+B`B.UQN(CL*("`@("`@("`D:G,@+CT@)W9A
M<B!E>'1R84-O;'-2:6=H="`]("<@+B`D=&AI<RT^7V5X=')A7V-O;'-?<FEG
M:'0@+B`B.UQN(CL*("`@("`@("`D:G,@+CT@)W9A<B`G("X@)'1H:7,M/E]S
M;W5R8V5?;F%M92`N("<@/2!N97<@07)R87DH*3LG("X@(EQN(CL*"B`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/E]N;V1E<R!A<R`D;F]D95]I9"`]/B`D;F]D
M92D@>PH@("`@("`@("`@("`D:G,@+CT@)'1H:7,M/E]G971*<T%R<F%Y16QE
M;65N="AS<')I;G1F*"<E<UM<)R5S7"==)RP@)'1H:7,M/E]S;W5R8V5?;F%M
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D8G)O=W-E<BT^97-C87!E2E-#;V1E*&%D9'-L87-H97,H
M)&YO9&5?:60I*2DL("1N;V1E*3L*("`@("`@("!]"B`@("`@("`@)&IS("X]
M("1T:&ES+3Y?9V5T2G-!<G)A>45L96UE;G0H)'1H:7,M/E]H96%D97)?;F%M
M92P@)'1H:7,M/E]H96%D97(I.PH@("`@("`@("1J<R`N/2`D=&AI<RT^7V=E
M=$IS07)R87E%;&5M96YT*"1T:&ES+3Y?;W!T:6]N<U]N86UE+"`D=&AI<RT^
M7V]P=&EO;G,I.PH@("`@("`@("1J<R`N/2`G/"]S8W)I<'0^)R`N(")<;B([
M"@H@("`@("`@(')E='5R;B`D:G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/
M=71P=71S('1H92!J879A<V-R:7!T('1O(&EN:71I86QI<V4@=&AE('1R964N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]G9714<F5E26YI="@I"B`@("!["B`@("`@("`@)&IS("`]("<\
M<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^)R`N(")<;B(["B`@("`@
M("`@)&IS("X]('-P<FEN=&8H)R4Q)',@/2!N97<@2&]R9&5?5')E92A<)R4Q
M)'-<)RD[)R`N(")<;B(L"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]I;G-T86YC92D["@H@("`@("`@("1J<R`N/2`D=&AI<RT^7V=E=$IS07)R
M87E%;&5M96YT*"=R;V]T7VYO9&5S)RP@)'1H:7,M/E]R;V]T7VYO9&5S*3L*
M"B`@("`@("`@)&IS("X]('-P<FEN=&8H(B5S+G)E;F1E<E1R964H<F]O=%]N
M;V1E<RP@)7,I.UQN/"]S8W)I<'0^7&XB+`H@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?:6YS=&%N8V4L"B`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]S=&%T:6,@/R`G=')U92<@.B`G9F%L<V4G*3L*"B`@("`@("`@
M<F5T=7)N("1J<SL*("`@('T*"B`@("!F=6YC=&EO;B!?9V5T2G-!<G)A>45L
M96UE;G0H)'9A<BP@)'9A;'5E*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A
M>2@D=F%L=64I*2!["B`@("`@("`@("`@("1J<R`]("1V87(@+B`G(#T@;F5W
M($%R<F%Y*"D[)R`N(")<;B(["B`@("`@("`@("`@(&9O<F5A8V@@*"1V86QU
M92!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@(&EF("AI<U]N
M=6UE<FEC*"1K97DI*2!["B`@("`@("`@("`@("`@("`@("`@)&YE=U9A<B`]
M("1V87(@+B`G6R<@+B`D:V5Y("X@)UTG.PH@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D;F5W5F%R(#T@)'9A<B`N("=;
M7"<G("X@)&ME>2`N("=<)UTG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@)&IS("X]("1T:&ES+3Y?9V5T2G-!<G)A>45L96UE;G0H)&YE
M=U9A<BP@)'9A;"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N
M("1J<SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'9A
M<B`N("(@/2`G(B`N(&%D9'-L87-H97,H)'9A;'5E*2`N("(G.UQN(CL*("`@
M("`@("!]"B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]4<F5E+W-E;&5C="YP:'``````````````````````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#8V,#$`,3`U,34T,S,W-3``,#(R,S4T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!4:&4@2&]R9&5?5')E95]S96QE8W0Z.B!C;&%S<R!E>'1E;F1S('1H
M92!(;W)D95]4<F5E(&-L87-S('1O('!R;W9I9&4*("H@/&]P=&EO;CX@=&%G
M(')E;F1E<FEN9RX*("H*("H@0V]P>7)I9VAT(#(P,#4M,C`P-B!"96X@0VAA
M=F5T(#QB96Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO5')E92]4<F5E+W-E;&5C="YP:'`L=B`Q+C(N,BXW(#(P
M,#8O,#$O,#$@,C$Z,C@Z-#`@:F%N($5X<"`D"B`J"B`J($!A=71H;W(@($)E
M;B!#:&%V970@/&)E;D!H;W)D92YO<F<^"B`J($!P86-K86=E($AO<F1E7U1R
M964*("H@0'-I;F-E("`@2&]R9&4@,RXQ"B`J+PIC;&%S<R!(;W)D95]4<F5E
M7W-E;&5C="!E>'1E;F1S($AO<F1E7U1R964@>PH*("`@("\J*@H@("`@("H@
M5$]$3PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1?;F]D97,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7U1R965?<V5L96-T*"1T
M<F5E7VYA;64L("1P87)A;7,I"B`@("!["B`@("`@("`@<&%R96YT.CI(;W)D
M95]4<F5E*"1T<F5E7VYA;64L("1P87)A;7,I.PH@("`@("`@("1T:&ES+3Y?
M<W1A=&EC(#T@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE('1R964N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!(
M5$U,(&-O9&4@;V8@=&AE(')E;F1E<F5D('1R964N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%1R964H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8G5I;&1)
M;F1E;G1S*"1T:&ES+3Y?<F]O=%]N;V1E<RD["@H@("`@("`@("1T<F5E(#T@
M)R<["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]R;V]T7VYO9&5S(&%S("1N
M;V1E7VED*2!["B`@("`@("`@("`@("1T<F5E("X]("1T:&ES+3Y?8G5I;&14
M<F5E*"1N;V1E7VED*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T<F5E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS('1H92!C=7)R96YT(&5N
M=FER;VYM96YT('1O('-E92!I9B!W92!C86X@<F5N9&5R('1H92!(5$U,('1R
M964N"B`@("`@*B!(5$U,(&ES(&%L=V%Y<R!R96YD97)A8FQE+"!A="!L96%S
M="!U;G1I;"!W92!A9&0@82!P:'`M9W1K('1R964*("`@("`J(&)A8VME;F0L
M(&EN('=H:6-H(&-A<V4@=&AI<R!I;7!L96UE;G1A=&EO;B!W:6QL(&%C='5A
M;&QY(&YE960@82!B;V1Y+@H@("`@("H*("`@("`J($!S=&%T:6,*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H:7,@
M5')E93HZ(&)A8VME;F0@=VEL;"!F=6YC=&EO;BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@:7-3=7!P;W)T960H*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!J=7-T('1H92!*4R!N
M;V1E(&1E9FEN:71I;VYS(&%S(&$@<W1R:6YG+B!4:&ES(&ES(&$@;F\M;W`@
M9F]R"B`@("`@*B!T:&4@<V5L96-T(')E;F1E<F5R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!R96YD97).;V1E1&5F:6YI=&EO;G,H*0H@("`@>PH@("`@?0H*
M("`@("\J*@H@("`@("H@061D<R!A9&1I=&EO;F%L('!A<F%M971E<G,@=&\@
M82!N;V1E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("`@("!4
M:&4@=6YI<75E(&YO9&4@:60N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M
M<R`@06YY(&]T:&5R('!A<F%M971E<G,@=&\@<V5T+@H@("`@("H@/'!R93X*
M("`@("`J('-E;&5C=&5D("TM("!7:&5T:&5R('1H:7,@;F]D92!I<R!S96QE
M8W1E9`H@("`@("H@/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$YO
M9&5087)A;7,H)&ED+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@
M("!I9B`H(6ES7V%R<F%Y*"1P87)A;7,I*2!["B`@("`@("`@("`@("1P87)A
M;7,@/2!A<G)A>2@D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@("1A;&QO
M=V5D(#T@87)R87DH)W-E;&5C=&5D)RD["@H@("`@("`@(&9O<F5A8V@@*"1P
M87)A;7,@87,@)'!A<F%M7VED(#T^("1P87)A;5]V86PI('L*("`@("`@("`@
M("`@+RH@4V5T(&]N;'D@86QL;W=E9"!A;F0@;F]N+6YU;&P@<&%R86US+B`J
M+PH@("`@("`@("`@("!I9B`H:6Y?87)R87DH)'!A<F%M7VED+"`D86QL;W=E
M9"D@)B8@(6ES7VYU;&PH)'!A<F%M7W9A;"DI('L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;F]D97-;)&ED75LD<&%R86U?:61=(#T@)'!A<F%M7W9A;#L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E8W5R<VEV92!F=6YC=&EO;B!T;R!W86QK('1H<F]U9V@@=&AE('1R964@
M87)R87D@86YD(&)U:6QD('1H92!O=71P=70N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F]D
M95]I9"`@5&AE($YO9&4@240N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!T<F5E(')E;F1E<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V)U:6QD5')E92@D;F]D95]I9"D*("`@('L*("`@("`@("`D<V5L96-T960@
M/2`D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG<V5L96-T960G72`_("<@<V5L
M96-T960](G-E;&5C=&5D(B<@.B`G)SL*"B`@("`@("`@)&]U='!U="`]("<\
M;W!T:6]N('9A;'5E/2(G("X@:'1M;'-P96-I86QC:&%R<R@D;F]D95]I9"D@
M+B`G(B<@+B`D<V5L96-T960@+B`G/B<@+@H@("`@("`@("`@("!S=')?<F5P
M96%T*"<F;F)S<#LF;F)S<#LG+"`H:6YT*21T:&ES+3Y?;F]D97-;)&YO9&5?
M:61=6R=I;F1E;G0G72D@+B!H=&UL<W!E8VEA;&-H87)S*"1T:&ES+3Y?;F]D
M97-;)&YO9&5?:61=6R=L86)E;"==*2`N"B`@("`@("`@("`@("<\+V]P=&EO
M;CXG.PH*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]N;V1E<ULD;F]D95]I
M9%U;)V-H:6QD<F5N)UTI("8F"B`@("`@("`@("`@("1T:&ES+3Y?;F]D97-;
M)&YO9&5?:61=6R=E>'!A;F1E9"==*2!["B`@("`@("`@("`@("1N=6U?<W5B
M;F]D97,@/2!C;W5N="@D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG8VAI;&1R
M96XG72D["B`@("`@("`@("`@(&9O<B`H)&,@/2`P.R`D8R`\("1N=6U?<W5B
M;F]D97,[("1C*RLI('L*("`@("`@("`@("`@("`@("1C:&EL9%]N;V1E7VED
M(#T@)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)V-H:6QD<F5N)UU;)&-=.PH@
M("`@("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^7V)U:6QD5')E92@D
M8VAI;&1?;F]D95]I9"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D;W5T<'5T.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O5')E92YP:'``````````````````````````````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#,V-C<S`#$P-3$U-#,S-S4Q`#`R,3$Q,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M+RHJ"B`J($1I<W!L87D@97AT<F$@8V]L=6UN<R!T;R!T:&4@;&5F="!O9B!T
M:&4@;6%I;B!T<F5E+@H@*B\*9&5F:6YE*"=(3U)$15]44D5%7T585%)!7TQ%
M1E0G+"`P*3L*"B\J*@H@*B!$:7-P;&%Y(&5X=')A(&-O;'5M;G,@=&\@=&AE
M(')I9VAT(&]F('1H92!M86EN('1R964N"B`J+PID969I;F4H)TA/4D1%7U12
M145?15A44D%?4DE'2%0G+"`Q*3L*"B\J*@H@*B!4:&4@<')E8V5D:6YG('1E
M>'0L(&)E9F]R92!T:&4@2&]R9&5?5')E92!I;G-T86YC92!N86UE+"!U<V5D
M(&9O<@H@*B!C;VQL87!S92]E>'!A;F0@<W5B;6ES<VEO;G,N"B`J+PID969I
M;F4H)TA/4D1%7U12145?5$]'1TQ%)RP@)VAT7W1O9V=L95\G*3L*"B\J*@H@
M*B!4:&4@2&]R9&5?5')E93HZ(&-L87-S('!R;W9I9&5S(&$@=')E92!V:65W
M(&]F(&AI97)A<F-H:6-A;"!I;F9O<FUA=&EO;BX@270*("H@86QL;W=S(&9O
M<B!E>'!A;F1I;F<O8V]L;&%P<VEN9R!O9B!B<F%N8VAE<R!A;F0@;6%I;G1A
M:6YS('1H96ER('-T871E+B!)=`H@*B!C86X@=V]R:R!T;V=E=&AE<B!W:71H
M('1H92!(;W)D95]4<F5E(&IA=F%S8W)I<'0@8VQA<W,@=&\@86-H:65V92!T
M:&ES(&EN"B`J($1(5$U,(&]N('-U<'!O<G1E9"!B<F]W<V5R<RX*("H*("H@
M0V]P>7)I9VAT(#(P,#,M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N
M8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5')E
M92]4<F5E+G!H<"QV(#$N-#8N-BXQ,2`R,#`V+S`Q+S`Q(#(Q.C(X.C0P(&IA
M;B!%>'`@)`H@*@H@*B!`875T:&]R("!-87)K;R!$:G5K:6,@/&UA<FMO0&]B
M;&\N8V]M/@H@*B!`<&%C:V%G92!(;W)D95]4<F5E"B`J($!S:6YC92`@($AO
M<F1E(#,N,`H@*B\*8VQA<W,@2&]R9&5?5')E92!["@H@("`@+RHJ"B`@("`@
M*B!4:&4@;F%M92!O9B!T:&ES(&EN<W1A;F-E+@H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VEN<W1A;F-E(#T@;G5L;#L*
M"B`@("`O*BH*("`@("`J($AA<V@@=VET:"!H96%D97(@:6YF;W)M871I;VXN
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]H
M96%D97(@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@06X@87)R87D@8V]N
M=&%I;FEN9R!A;&P@=&AE('1R964@;F]D97,N"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]N;V1E<R`](&%R<F%Y*"D["@H@
M("`@+RHJ"B`@("`@*B!4:&4@=&]P+6QE=F5L(&YO9&5S(&EN('1H92!T<F5E
M+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M<F]O=%]N;V1E<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!+965P(&-O
M=6YT(&]F(&AO=R!M86YY(&5X=')A(&-O;'5M;G,@=&AE<F4@87)E(&]N('1H
M92!L969T('-I9&4*("`@("`J(&]F('1H92!N;V1E+@H@("`@("H*("`@("`J
M($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]E>'1R85]C;VQS7VQE
M9G0@/2`P.PH*("`@("\J*@H@("`@("H@2V5E<"!C;W5N="!O9B!H;W<@;6%N
M>2!E>'1R82!C;VQU;6YS('1H97)E(&%R92!O;B!T:&4@<FEG:'0@<VED90H@
M("`@("H@;V8@=&AE(&YO9&4N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R
M"B`@("`@*B\*("`@('9A<B`D7V5X=')A7V-O;'-?<FEG:'0@/2`P.PH*("`@
M("\J*@H@("`@("H@3W!T:6]N('9A;'5E<RX*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V]P=&EO;G,@/2!A<G)A>2@G;&EN
M97,G(#T^('1R=64I.PH*("`@("\J*@H@("`@("H@4W1O<F5S('1H92!S;W)T
M:6YG(&-R:71E<FEA('1E;7!O<F%R:6QY+@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W-O<G1#<FET97)I83L*"B`@("`O
M*BH*("`@("`J(%5S92!S97-S:6]N('1O('-T;W)E(&-A8VAE9"!4<F5E(&1A
M=&$_"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A
M<B`D7W5S97-E<W-I;VX@/2!T<G5E.PH*("`@("\J*@H@("`@("H@4VAO=6QD
M('1H92!T<F5E(&)E(')E;F1E<F5D('-T871I8V%L;'D_"B`@("`@*@H@("`@
M("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7W-T871I8R`](&9A
M;'-E.PH*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@<F5F
M97)E;F-E('1O(&$@8V]N8W)E=&4@2&]R9&5?5')E90H@("`@("H@:6YS=&%N
M8V4@8F%S960@;VX@)&YA;64@86YD("1R96YD97)E<BX@270@=VEL;"!O;FQY
M(&-R96%T92!A"B`@("`@*B!N97<@:6YS=&%N8V4@:68@;F\@2&]R9&5?5')E
M92!I;G-T86YC92!W:71H('1H92!S86UE('!A<F%M971E<G,*("`@("`J(&-U
M<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S
M="!B92!I;G9O:V5D(&%S.@H@("`@("H@("`D=F%R(#T@)DAO<F1E7U1R964Z
M.G-I;F=L971O;B@D;F%M95LL("1R96YD97)E<ETI.PH@("`@("H*("`@("`J
M($!S=&%T:6,*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@("1N86UE("`@
M("`@0'-E92!(;W)D95]4<F5E.CIF86-T;W)Y+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<F5N9&5R97(@($!S964@2&]R9&5?5')E93HZ9F%C=&]R>2X*("`@
M("`J($!P87)A;2!A<G)A>2`@)'!A<F%M<R`@("!`<V5E($AO<F1E7U1R964Z
M.F9A8W1O<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]4<F5E("!4
M:&4@8V]N8W)E=&4@2&]R9&5?5')E92!R969E<F5N8V4L(&]R(%!%05)?17)R
M;W(@;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@97)R;W(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)&YA;64L("1R96YD97)E<BP@
M)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T
M86YC97,@/2!A<G)A>2@I.PH*("`@("`@("`D:60@/2`D;F%M92`N("<Z)R`N
M("1R96YD97)E<B`N("<Z)R`N('-E<FEA;&EZ92@D<&%R86US*3L*("`@("`@
M("!I9B`H(6ES<V5T*"1I;G-T86YC97-;)&ED72DI('L*("`@("`@("`@("`@
M)&EN<W1A;F-E<ULD:61=(#T@)DAO<F1E7U1R964Z.F9A8W1O<GDH)&YA;64L
M("1R96YD97)E<BP@)'!A<F%M<RD["B`@("`@("`@("`@(&EF("@A)&EN<W1A
M;F-E<ULD:61=+3YI<U-U<'!O<G1E9"@I*2!["B`@("`@("`@("`@("`@("`D
M<F5N9&5R97(@/2!(;W)D95]4<F5E.CIF86QL8F%C:R@D<F5N9&5R97(I.PH@
M("`@("`@("`@("`@("`@:68@*&ES7V$H)')E;F1E<F5R+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R96YD97)E<CL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(')E='5R;B!(;W)D
M95]4<F5E.CIS:6YG;&5T;VXH)&YA;64L("1R96YD97)E<BP@)'!A<F%M<RD[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YS
M=&%N8V5S6R1I9%T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T
M;R!R971U<FX@82!C;VYC<F5T92!(;W)D95]4<F5E(&EN<W1A;F-E+@H@("`@
M("H*("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("`@("`@5&AE(&YA;64@;V8@=&AI<R!T<F5E(&EN<W1A;F-E+@H@
M("`@("H@0'!A<F%M(&UI>&5D("`D<F5N9&5R97(@(%1H92!T>7!E(&]F(&-O
M;F-R971E($AO<F1E7U1R964@<W5B8VQA<W,@=&\*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FXN(%1H:7,@:7,@8F%S960@;VX@=&AE
M(')E;F1E<FEN9R!D<FEV97(*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`H)')E;F1E<F5R*2X@5&AE(&-O9&4@:7,@9'EN86UI8V%L;'D@:6YC
M;'5D960N"B`@("`@*B!`<&%R86T@87)R87D@("1P87)A;7,@("`@06YY(&%D
M9&ET:6]N86P@<&%R86UE=&5R<R!T:&4@8V]N<W1R=6-T;W(*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("!N965D<RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N($AO<F1E7U1R964@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E
M($AO<F1E7U1R964@:6YS=&%N8V4L(&]R"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9F86-T;W)Y*"1N86UE+"`D<F5N9&5R97(L("1P87)A;7,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@("\J(%)E<75I<F4@=&AE(')E;F1E<F5R(&QI
M8BX@*B\*("`@("`@("!I;F-L=61E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@
M+B`G+U1R964O)R`N("1R96YD97)E<B`N("<N<&AP)SL*"B`@("`@("`@)&-L
M87-S(#T@)TAO<F1E7U1R965?)R`N("1R96YD97)E<CL*("`@("`@("!I9B`H
M8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)'1R964@/2`F
M;F5W("1C;&%S<R@D;F%M92P@)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'1R964@/2!014%2.CIR86ES945R<F]R*'-P<FEN=&8H
M7R@B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(I+"`D<F5N9&5R
M97(I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=')E93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%1R>2!T;R!F86QL(&)A8VL@=&\@82!S:6UP;&5R
M(')E;F1E<F5R+@H@("`@("H*("`@("`J($!P87)A;B!S=')I;F<@)')E;F1E
M<F5R("!4:&4@<F5N9&5R97(@=&AA="!W92!C86XG="!H86YD;&4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@?"!014%27T5R<F]R("!4:&4@;F5X
M="!B97-T(')E;F1E<F5R+"!O<B!A;B!E<G)O<@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B!W92=V92!R=6X@;W5T(&]F(')E;F1E
M<F5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9F%L;&)A8VLH)')E;F1E<F5R
M*0H@("`@>PH@("`@("`@('-W:71C:"`H)')E;F1E<F5R*2!["B`@("`@("`@
M8V%S92`G:F%V87-C<FEP="<Z"B`@("`@("`@("`@(')E='5R;B`G:'1M;"<[
M"@H@("`@("`@(&-A<V4@)VAT;6PG.@H@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@G;W5T(&]F(')E;F1E<F5R<R<I.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@5&AE(&YA;64@;V8@=&AI<R!T
M<F5E(&EN<W1A;F-E+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D<&%R86US("!!
M9&1I=&EO;F%L('!A<F%M971E<G,N"B`@("`@*B`\<')E/@H@("`@("H@)VYO
M<V5S<VEO;B<@("TM("`H8F]O;&5A;BD@268@=')U92P@9&\@;F]T('-T;W)E
M('1R964@9&%T82!I;B!S97-S:6]N+@H@("`@("H@/"]P<F4^"B`@("`@*B\*
M("`@(&9U;F-T:6]N($AO<F1E7U1R964H)&YA;64L("1P87)A;7,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:6YS=&%N8V4@/2`D;F%M93L*
M("`@("`@("`D=&AI<RT^7W5S97-E<W-I;VX@/2!E;7!T>2@D<&%R86US6R=N
M;W-E<W-I;VXG72D["@H@("`@("`@("\J(%-E="!U<"!T:&4@<V5S<VEO;B!F
M;W(@;&%T97(@=&\@<V%V92!T<F5E('-T871E<RX@*B\*("`@("`@("!I9B`H
M)'1H:7,M/E]U<V5S97-S:6]N("8F"B`@("`@("`@("`@("%I<W-E="@D7U-%
M4U-)3TY;)VAO<F1E7W1R964G75LD=&AI<RT^7VEN<W1A;F-E72DI('L*("`@
M("`@("`@("`@)%]315-324].6R=H;W)D95]T<F5E)UU;)'1H:7,M/E]I;G-T
M86YC95T@/2!A<G)A>2@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E;F1E<G,@=&AE('1R964N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)'-T871I8R`@268@=')U92!T:&4@=')E92!N;V1E<R!C86XG="!B
M92!E>'!A;F1E9"!A;F0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M(&-O;&QA<'-E9"!A;F0@=&AE('1R964@9V5T<R!R96YD97)E9"!E>'!A;F1E
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R5')E92@D<W1A=&EC(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@96-H;R`D=&AI<RT^9V5T5')E92@D<W1A
M=&EC*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@86X@;W!T:6]N+@H@
M("`@("H@079A:6QA8FQE(&]P=&EO;G,Z"B`@("`@*B`\<')E/@H@("`@("H@
M("!A;'1E<FYA=&4@("`@+2T@($%L=&5R;F%T92!S:&%D:6YG(&EN('1H92!T
M86)L93\@*&)O;VQE86XI"B`@("`@*B`@(&AI9&5(96%D97)S("`M+2`@1&]N
M)W0@<F5N9&5R(&%N>2!(5$U,(&9O<B!T:&4@:&5A9&5R(')O=RP@:G5S="!U
M<V4@=&AE('=I9'1H<RX*("`@("`J("`@8VQA<W,@("`@("`@("TM("!4:&4@
M8VQA<W,@=&\@=7-E(&9O<B!T:&4@=&%B;&4N("AS=')I;F<I"B`@("`@*B`@
M(&QI;F5S("`@("`@("`M+2`@4VAO=R!T<F5E(&QI;F5S/R`H8F]O;&5A;BD*
M("`@("`J("`@;75L=&EL:6YE("`@("TM("!$;R!T:&4@;F]D92!L86)E;',@
M8V]N=&%I;B!L:6YE8G)E86MS/R`H8F]O;&5A;BD*("`@("`J(#PO<')E/@H@
M("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D;W!T:6]N("!4:&4@;W!T:6]N
M(&YA;64@+6]R+2!A;B!A<G)A>2!O9B!O<'1I;VX@;F%M92]V86QU90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@('!A:7)S+@H@("`@("H@0'!A<F%M
M(&UI>&5D("1V86P@("`@(%1H92!O<'1I;VXG<R!V86QU92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5T3W!T:6]N*"1O<'1I;VYS+"`D=F%L=64@/2!N=6QL
M*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)&]P=&EO;G,I*2!["B`@
M("`@("`@("`@("1O<'1I;VYS(#T@87)R87DH)&]P=&EO;G,@/3X@)'9A;'5E
M*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1O<'1I;VYS(&%S("1O
M<'1I;VX@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W!T:6]N
M<ULD;W!T:6]N72`]("1V86QU93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'971S(&%N(&]P=&EO;B=S('9A;'5E+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&]P=&EO;B`@(%1H92!N86UE(&]F('1H92!O<'1I
M;VX@=&\@9F5T8V@N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D:'1M;"`@("!4
M<G5E(&]R(&9A;'-E('=H971H97(@=&\@9F]R;6%T('1H92!R971U<FX@=F%L
M=64*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&EN(&AT;6PN($1E
M9F%U;'1S('1O(&9A;'-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&5F875L
M="`@02!D969A=6QT('9A;'5E('1O('5S92!I;B!C87-E(&YO;F4@:7,@<V5T
M(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@=&AE(')E<75E
M<W1E9"!O<'1I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE
M(&]P=&EO;B=S('9A;'5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971/<'1I
M;VXH)&]P=&EO;BP@)&AT;6P@/2!F86QS92P@)&1E9F%U;'0@/2!N=6QL*0H@
M("`@>PH@("`@("`@("1V86QU92`](&YU;&P["@H@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]O<'1I;VYS6R1O<'1I;VY=*2`F)B`A:7-?;G5L;"@D9&5F
M875L="DI('L*("`@("`@("`@("`@+RH@4F5Q=65S=&5D(&]P=&EO;B!H87,@
M;F]T(&)E96X@8G5T('1H97)E(&ES(&$*("`@("`@("`@("`@("H@9&5F875L
M="X@*B\*("`@("`@("`@("`@)'9A;'5E(#T@)&1E9F%U;'0["B`@("`@("`@
M?2!E;'-E:68@*&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULD;W!T:6]N72DI('L*
M("`@("`@("`@("`@+RH@4F5Q=65S=&5D(&]P=&EO;B!H87,@8F5E;B!S970L
M(&=E="!I=',@=F%L=64N("HO"B`@("`@("`@("`@("1V86QU92`]("1T:&ES
M+3Y?;W!T:6]N<ULD;W!T:6]N73L*("`@("`@("!]"@H@("`@("`@(&EF("@D
M:'1M;"`F)B`A:7-?;G5L;"@D=F%L=64I*2!["B`@("`@("`@("`@("\J($9O
M<FUA="!V86QU92!F;W(@:'1M;"!O=71P=70N("HO"B`@("`@("`@("`@("1V
M86QU92`]('-P<FEN=&8H)R`E<STB)7,B)RP@)&]P=&EO;BP@)'9A;'5E*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=F%L=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!9&1S(&$@;F]D92!T;R!T:&4@;F]D92!T<F5E(&%R<F%Y
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1I9"`@("`@("`@("`@
M5&AE('5N:7%U92!N;V1E(&ED+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'!A
M<F5N="`@("`@("!4:&4@<&%R96YT)W,@=6YI<75E(&YO9&4@:60N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("`D;&%B96P@("`@("`@(%1H92!T97AT(&QA8F5L
M(&9O<B!T:&4@;F]D92X*("`@("`J($!P87)A;2!S=')I;F<@("1I;F1E;G0@
M("`@("`@1&5P<F5C871E9"P@=&AI<R!I<R!C86QC=6QA=&5D(&%U=&]M871I
M8V%L;'D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8F%S
M960@;VX@=&AE('!A<F5N="!N;V1E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)&5X<&%N9&5D("`@("!)<R!T:&ES(&QE=F5L(&5X<&%N9&5D(&]R(&YO="X*
M("`@("`J($!P87)A;2!A<G)A>2`@("1P87)A;7,@("`@("`@06YY(&]T:&5R
M('!A<F%M971E<G,@=&\@<V5T("A`<V5E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%D9$YO9&5087)A;7,H*2!F;W(@9G5L;"!D971A
M:6QS*2X*("`@("`J($!P87)A;2!A<G)A>2`@("1E>'1R85]R:6=H="`@06YY
M(&]T:&5R(&-O;'5M;G,@=&\@9&ES<&QA>2!T;R!T:&4@<FEG:'0@;V8*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE('1R964N"B`@
M("`@*B!`<&%R86T@87)R87D@("`D97AT<F%?;&5F="`@($%N>2!O=&AE<B!C
M;VQU;6YS('1O(&1I<W!L87D@=&\@=&AE(&QE9G0@;V8*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=&AE('1R964N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&%D9$YO9&4H)&ED+"`D<&%R96YT+"`D;&%B96PL("1I;F1E
M;G0L("1E>'!A;F1E9"`]('1R=64L"B`@("`@("`@("`@("`@("`@("`@("1P
M87)A;7,@/2!A<G)A>2@I+"`D97AT<F%?<FEG:'0@/2!A<G)A>2@I+`H@("`@
M("`@("`@("`@("`@("`@("`D97AT<F%?;&5F="`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@)'1H:7,M/E]N;V1E<ULD:61=6R=L86)E;"==(#T@)&QA8F5L
M.PH*("`@("`@("!I9B`H)'1H:7,M/E]U<V5S97-S:6]N*2!["B`@("`@("`@
M("`@("1S97-S:6]N7W-T871E(#T@)%]315-324].6R=H;W)D95]T<F5E)UU;
M)'1H:7,M/E]I;G-T86YC95T["B`@("`@("`@("`@("1T;V=G;&5?:60@/2!5
M=&EL.CIG971&;W)M1&%T82A(3U)$15]44D5%7U1/1T=,12`N("1T:&ES+3Y?
M:6YS=&%N8V4I.PH@("`@("`@("`@("!I9B`H)&ED(#T]("1T;V=G;&5?:60I
M('L*("`@("`@("`@("`@("`@("\J(%=E(&AA=F4@82!U<FP@=&]G9VQE(')E
M<75E<W0@9F]R('1H:7,@;F]D92X@*B\*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D<V5S<VEO;E]S=&%T95LG97AP86YD960G75LD:61=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("\J(%5S92!S97-S:6]N('-T871E(&EF(&ET(&ES
M('-E="X@*B\*("`@("`@("`@("`@("`@("`@("`D97AP86YD960@/2`H(21S
M97-S:6]N7W-T871E6R=E>'!A;F1E9"==6R1I9%TI.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O*B!/=&AE<G=I<V4@
M=7-E('=H870@=V%S('!A<W-E9"!T:')O=6=H('1H90H@("`@("`@("`@("`@
M("`@("`@("`J(&9U;F-T:6]N+B`J+PH@("`@("`@("`@("`@("`@("`@("1E
M>'!A;F1E9"`]("@A)&5X<&%N9&5D*3L*("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("`O*B!3879E('1H:7,@<W1A=&4@=&\@<V5S<VEO;BX@
M*B\*("`@("`@("`@("`@("`@("1?4T534TE/3ELG:&]R9&5?=')E92==6R1T
M:&ES+3Y?:6YS=&%N8V5=6R=E>'!A;F1E9"==6R1I9%T@/2`D97AP86YD960[
M"B`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D<V5S<VEO;E]S=&%T95LG
M97AP86YD960G75LD:61=*2D@>PH@("`@("`@("`@("`@("`@+RH@268@=V4@
M:&%V92!A('-A=F5D('-E<W-I;VX@<W1A=&4@=7-E(&ET+B`J+PH@("`@("`@
M("`@("`@("`@)&5X<&%N9&5D(#T@)'-E<W-I;VY?<W1A=&5;)V5X<&%N9&5D
M)UU;)&ED73L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/E]N;V1E<ULD:61=6R=E>'!A;F1E9"==(#T@)&5X<&%N9&5D.PH*("`@
M("`@("`O*B!)9B!A;GD@<&%R86US(&EN8VQU9&5D(&AE<F4@861D('1H96T@
M;F]W+B`J+PH@("`@("`@(&EF("@A96UP='DH)'!A<F%M<RDI('L*("`@("`@
M("`@("`@)'1H:7,M/F%D9$YO9&5087)A;7,H)&ED+"`D<&%R86US*3L*("`@
M("`@("!]"@H@("`@("`@("\J($EF(&%N>2!E>'1R82!C;VQU;6YS(&EN8VQU
M9&5D(&AE<F4@861D('1H96T@;F]W+B`J+PH@("`@("`@(&EF("@A96UP='DH
M)&5X=')A7W)I9VAT*2D@>PH@("`@("`@("`@("`D=&AI<RT^861D3F]D945X
M=')A*"1I9"P@2$]21$5?5%)%15]%6%1205]224=(5"P@)&5X=')A7W)I9VAT
M*3L*("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D97AT<F%?;&5F="DI
M('L*("`@("`@("`@("`@)'1H:7,M/F%D9$YO9&5%>'1R82@D:60L($A/4D1%
M7U12145?15A44D%?3$5&5"P@)&5X=')A7VQE9G0I.PH@("`@("`@('T*"B`@
M("`@("`@:68@*&ES7VYU;&PH)'!A<F5N="DI('L*("`@("`@("`@("`@:68@
M*"%I;E]A<G)A>2@D:60L("1T:&ES+3Y?<F]O=%]N;V1E<RDI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<F]O=%]N;V1E<UM=(#T@)&ED.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*&5M<'1Y
M*"1T:&ES+3Y?;F]D97-;)'!A<F5N=%U;)V-H:6QD<F5N)UTI*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7VYO9&5S6R1P87)E;G1=6R=C:&EL9')E;B==
M(#T@87)R87DH*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(6EN
M7V%R<F%Y*"1I9"P@)'1H:7,M/E]N;V1E<ULD<&%R96YT75LG8VAI;&1R96XG
M72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;F]D97-;)'!A<F5N=%U;
M)V-H:6QD<F5N)UU;72`]("1I9#L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($%D9',@861D:71I;VYA;"!P87)A;65T
M97)S('1O(&$@;F]D92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I
M9"`@("`@5&AE('5N:7%U92!N;V1E(&ED+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@($%N>2!O=&AE<B!P87)A;65T97)S('1O('-E="X*("`@("`J
M(#QP<F4^"B`@("`@*B!C;&%S<R`@("`@+2T@($-34R!C;&%S<R!T;R!U<V4@
M=VET:"!T:&ES(&YO9&4*("`@("`J(&EC;VX@("`@("`M+2`@26-O;B!T;R!D
M:7-P;&%Y(&YE>'0@;F]D90H@("`@("H@:6-O;F%L="`@("TM("!!;'0@=&5X
M="!T;R!U<V4@9F]R('1H92!I8V]N"B`@("`@*B!I8V]N9&ER("`@+2T@($EC
M;VX@9&ER96-T;W)Y"B`@("`@*B!I8V]N;W!E;B`@+2T@($EC;VX@=&\@:6YD
M:6-A=&4@=&AI<R!N;V1E(&%S(&5X<&%N9&5D"B`@("`@*B!O;F-L:6-K("`@
M+2T@($]N8VQI8VL@979E;G0@871T86-H960@=&\@=&AI<R!N;V1E"B`@("`@
M*B!U<FP@("`@("`@+2T@(%523"!T;R!L:6YK('1H92!N;V1E('1O"B`@("`@
M*B!U<FQC;&%S<R`@+2T@($-34R!C;&%S<R!F;W(@=&AE(&YO9&4G<R!54DP*
M("`@("`J('1A<F=E="`@("`M+2`@5&%R9V5T(&9O<B!T:&4@)W5R;"<@;&EN
M:PH@("`@("H@/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$YO9&50
M87)A;7,H)&ED+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1P87)A;7,I*2!["B`@("`@("`@("`@("1P87)A;7,@
M/2!A<G)A>2@D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@("1A;&QO=V5D
M(#T@87)R87DH"B`@("`@("`@("`@("=C;&%S<R<L("=I8V]N)RP@)VEC;VYA
M;'0G+"`G:6-O;F1I<B<L("=I8V]N;W!E;B<L"B`@("`@("`@("`@("=O;F-L
M:6-K)RP@)W5R;"<L("=U<FQC;&%S<R<L("=T87)G970G+`H@("`@("`@("D[
M"@H@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)'!A<F%M7VED(#T^("1P
M87)A;5]V86PI('L*("`@("`@("`@("`@+RH@4V5T(&]N;'D@86QL;W=E9"!A
M;F0@;F]N+6YU;&P@<&%R86US+B`J+PH@("`@("`@("`@("!I9B`H:6Y?87)R
M87DH)'!A<F%M7VED+"`D86QL;W=E9"D@)B8@(6ES7VYU;&PH)'!A<F%M7W9A
M;"DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;F]D97-;)&ED75LD<&%R
M86U?:61=(#T@)'!A<F%M7W9A;#L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($%D9',@97AT<F$@8V]L=6UN<R!T;R!B
M92!D:7-P;&%Y960@=&\@=&AE('-I9&4@;V8@=&AE(&YO9&4N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&UI>&5D("`@)&ED("`@("!4:&4@=6YI<75E(&YO9&4@
M:60N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<VED92`@(%=H:6-H('-I9&4@
M=&\@<&QA8V4@=&AE(&5X=')A(&-O;'5M;G,@;VXN"B`@("`@*B!`<&%R86T@
M87)R87D@("`D97AT<F$@($5X=')A(&-O;'5M;G,@=&\@9&ES<&QA>2X*("`@
M("`J+PH@("`@9G5N8W1I;VX@861D3F]D945X=')A*"1I9"P@)'-I9&4L("1E
M>'1R82D*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1E>'1R82DI('L*
M("`@("`@("`@("`@)&5X=')A(#T@87)R87DH)&5X=')A*3L*("`@("`@("!]
M"@H@("`@("`@("1C;VQ?8V]U;G0@/2!C;W5N="@D97AT<F$I.PH*("`@("`@
M("!S=VET8V@@*"1S:61E*2!["B`@("`@("`@8V%S92!(3U)$15]44D5%7T58
M5%)!7TQ%1E0Z"B`@("`@("`@("`@("1T:&ES+3Y?;F]D97-;)&ED75LG97AT
M<F$G75M(3U)$15]44D5%7T585%)!7TQ%1E1=(#T@)&5X=')A.PH@("`@("`@
M("`@("!I9B`H)&-O;%]C;W5N="`^("1T:&ES+3Y?97AT<F%?8V]L<U]L969T
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V5X=')A7V-O;'-?;&5F="`]
M("1C;VQ?8V]U;G0["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&-A<V4@2$]21$5?5%)%15]%6%1205]224=(5#H*("`@("`@
M("`@("`@)'1H:7,M/E]N;V1E<ULD:61=6R=E>'1R82==6TA/4D1%7U12145?
M15A44D%?4DE'2%1=(#T@)&5X=')A.PH@("`@("`@("`@("!I9B`H)&-O;%]C
M;W5N="`^("1T:&ES+3Y?97AT<F%?8V]L<U]R:6=H="D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]E>'1R85]C;VQS7W)I9VAT(#T@)&-O;%]C;W5N=#L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!3;W)T<R!T:&4@=')E92!B>2!T:&4@<W!E
M8VEF:65D(&YO9&4@<')O<&5R='DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8W)I=&5R:6$@(%1H92!N;V1E('!R;W!E<G1Y('1O('-O<G0@8GDN
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:60@("`@("`@57-E9"!I;G1E<FYA
M;&QY(&9O<B!R96-U<G-I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N('-O<G0H
M)&-R:71E<FEA+"`D:60@/2`M,2D*("`@('L*("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?;F]D97-;)&ED75LG8VAI;&1R96XG72DI('L*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@:68@*"1C<FET97)I82`]
M/2`G:V5Y)RD@>PH@("`@("`@("`@("!K<V]R="@D=&AI<RT^7VYO9&5S6R1I
M9%U;)V-H:6QD<F5N)UTI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1T:&ES+3Y?<V]R=$-R:71E<FEA(#T@)&-R:71E<FEA.PH@("`@("`@("`@
M("!U<V]R="@D=&AI<RT^7VYO9&5S6R1I9%U;)V-H:6QD<F5N)UTL(&%R<F%Y
M*"1T:&ES+"`G7W-O<G0G*2D["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H
M("@D=&AI<RT^7VYO9&5S6R1I9%U;)V-H:6QD<F5N)UT@87,@)&-H:6QD*2![
M"B`@("`@("`@("`@("1T:&ES+3YS;W)T*"1C<FET97)I82P@)&-H:6QD*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!(96QP97(@;65T:&]D
M(&9O<B!S;W)T*"D@=&\@8V]M<&%R92!T=V\@=')E92!E;&5M96YT<RX*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W-O<G0H)&$L("1B*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]N;V1E<ULD85U;)'1H:7,M/E]S;W)T0W)I=&5R:6%=*2D@>PH@("`@
M("`@("`@("!R971U<FX@,3L*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7VYO9&5S6R1B75LD=&AI<RT^7W-O<G1#<FET97)I85TI*2![
M"B`@("`@("`@("`@(')E='5R;B`M,3L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N('-T<F-O;&PH)'1H:7,M/E]N;V1E<ULD85U;)'1H:7,M/E]S;W)T0W)I
M=&5R:6%=+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;F]D97-;
M)&)=6R1T:&ES+3Y?<V]R=$-R:71E<FEA72D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('=H971H97(@=&AE('-P96-I9FEE9"!N;V1E(&ES(&-U
M<G)E;G1L>2!E>'!A;F1E9"X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@
M)&ED("!4:&4@=6YI<75E(&YO9&4@:60N"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&EF('1H92!S<&5C:69I960@;F]D92!I<R!E>'!A
M;F1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-%>'!A;F1E9"@D:60I"B`@
M("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;F]D97-;)&ED72DI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?;F]D97-;)&ED75LG97AP86YD
M960G73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@061D<R!C;VQU;6X@:&5A9&5R<R!T;R!T:&4@=')E
M92!T86)L92X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&AE861E<B`@
M06X@87)R87D@8V]N=&%I;FEN9R!H87-H97,@=VET:"!H96%D97(*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!I;F9O<FUA=&EO;BX@5&AE(&9O;&QO
M=VEN9R!K97ES(&%R92!A;&QO=V5D.@H@("`@("H@/'!R93X*("`@("`J(&AT
M;6P@("TM(%1H92!(5$U,(&-O;G1E;G0@;V8@=&AE(&AE861E<B!C96QL"B`@
M("`@*B!W:61T:"`M+2!4:&4@=VED=&@@;V8@=&AE(&AE861E<B!C96QL"B`@
M("`@*B!A;&EG;B`M+2!4:&4@86QI9VYM96YT(&EN<VED92!T:&4@:&5A9&5R
M(&-E;&P*("`@("`J(&-L87-S("TM(%1H92!#4U,@8VQA<W,@;V8@=&AE(&AE
M861E<B!C96QL"B`@("`@*B`\+W!R93X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T2&5A9&5R*"1H96%D97(I"B`@("!["B`@("`@("`@)'1H:7,M/E]H96%D
M97(@/2`D:&5A9&5R.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!I
M;F1E;G0@;&5V96P@9F]R(&5A8V@@;F]D92!I;B!T:&4@=')E92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V)U:6QD26YD96YT<R@D;F]D97,L("1I;F1E;G0@
M/2`P*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1N;V1E<R!A<R`D:60I('L*
M("`@("`@("`@("`@)'1H:7,M/E]N;V1E<ULD:61=6R=I;F1E;G0G72`]("1I
M;F1E;G0["B`@("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]N;V1E<ULD
M:61=6R=C:&EL9')E;B==*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]B
M=6EL9$EN9&5N=',H)'1H:7,M/E]N;V1E<ULD:61=6R=C:&EL9')E;B==+"`D
M:6YD96YT("L@,2D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U5)+P``````````````````````````````````
M```````````````````````````````````````````````P,#`P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U,0`P,C`P,#``
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O54DO3&%N9W5A9V4N
M<&AP````````````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,C0P`#$P
M-3$U-#,S-S4Q`#`R,C(S,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@5&AE($AO<F1E7U5)7TQA;F=U
M86=E.CH@8VQA<W,@<')O=FED97,@82!W:61G970@9F]R(&-H86YG:6YG('1H
M90H@*B!C=7)R96YT;'D@<V5L96-T960@;&%N9W5A9V4N"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+U5)+U5)+TQA;F=U86=E+G!H<"QV(#$N-2XQ,"XW(#(P
M,#8O,#8O,C`@,#DZ,#@Z-#4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`S+3(P,#8@2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R;VYO<WES+F-O
M;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!S:6YC92`@($AO<F1E7U5)(#`N,"XQ
M"B`J($!P86-K86=E($AO<F1E7U5)"B`J+PIC;&%S<R!(;W)D95]525],86YG
M=6%G92!["@H@("`@+RHJ"B`@("`@*B!296YD97(@=&AE(&QA;F=U86=E('-E
M;&5C=&EO;BX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D9F]R;2`@4F5T=7)N('1H92!S96QE8W1I;VX@
M8F]X(&%S(&%N(&-O;7!L971E('-T86YD86QO;F4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!F;W)M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@2%1-3"!S96QE8W1I;VX@8F]X+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R96YD97(H*0H@("`@>PH@("`@("`@("1H=&UL(#T@)R<["B`@("`@
M("`@:68@*"$D1TQ/0D%,4ULG<')E9G,G72T^:7-,;V-K960H)VQA;F=U86=E
M)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)VQA;F=U
M86=E+FIS)RP@)VAO<F1E)RD["B`@("`@("`@("`@("1?4T534TE/3ELG:&]R
M9&5?;&%N9W5A9V4G72`]($Y,4SHZ<V5L96-T*"D["B`@("`@("`@("`@("1H
M=&UL(#T@<W!R:6YT9B@G/&9O<FT@;F%M93TB;&%N9W5A9V4B(&%C=&EO;CTB
M)7,B/B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!(;W)D93HZ=7)L
M*"1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G
M*2`N("<O<V5R=FEC97,O;&%N9W5A9V4N<&AP)RP@9F%L<V4L("TQ*2D["B`@
M("`@("`@("`@("1H=&UL("X]("<\:6YP=70@='EP93TB:&ED9&5N(B!N86UE
M/2)U<FPB('9A;'5E/2(G("X@0&AT;6QS<&5C:6%L8VAA<G,H2&]R9&4Z.G-E
M;&95<FPH9F%L<V4L(&9A;'-E+"!T<G5E*2D@+B`G(B`O/B<["B`@("`@("`@
M("`@("1H=&UL("X]("<\<V5L96-T(&YA;64](FYE=U]L86YG(B!O;F-H86YG
M93TB9&]C=6UE;G0N;&%N9W5A9V4N<W5B;6ET*"DB/B<["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1'3$]"04Q36R=N;',G75LG;&%N9W5A9V5S)UT@87,@)&ME
M>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("`D<V5L(#T@*"1K97D@/3T@
M)%]315-324].6R=H;W)D95]L86YG=6%G92==*2`_("<@<V5L96-T960](G-E
M;&5C=&5D(B<@.B`G)SL*("`@("`@("`@("`@("`@("1H=&UL("X]("(\;W!T
M:6]N('9A;'5E/5PB)&ME>5PB)'-E;#XD=F%L/"]O<'1I;VX^(CL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D:'1M;"`N/2`G/"]S96QE8W0^/"]F;W)M
M/B<["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D:'1M;#L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U5)+U!A9V5R+G!H<```````
M````````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S4V-@`Q,#4Q-30S
M,S<U,0`P,C$U-C4`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?
M*2`N("<O5VED9V5T+G!H<"<["@HO*BH*("H@5&AE($AO<F1E7U5)7U!A9V5R
M.CH@<')O=FED97,@;&EN:W,@=&\@:6YD:79I9'5A;"!P86=E<RX*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP+'8@,2XW+C$P+C@@
M,C`P-B\P-B\R,"`P.3HP.#HR-B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#0M,C`P-B!*;V5L(%9A;F1A;"`\:G9A;F1A;$!I;F9O=&5C:RYQ8RYC
M83X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($)E;B!#:&%V970@/&)E
M;D!C:&%V970N;F5T/@H@*B!`875T:&]R("!*;V5L(%9A;F1A;"`\:G9A;F1A
M;$!I;F9O=&5C:RYQ8RYC83X*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E7U5)(#`N,"XQ
M"B`J($!P86-K86=E($AO<F1E7U5)"B`J+PIC;&%S<R!(;W)D95]525]086=E
M<B!E>'1E;F1S($AO<F1E7U5)7U=I9&=E="!["@H@("`@9G5N8W1I;VX@2&]R
M9&5?54E?4&%G97(H)&YA;64L("8D=F%R<RP@)&-O;F9I9RD*("`@('L*("`@
M("`@("!I9B`H(6ES<V5T*"1C;VYF:6=;)W!A9V5?;&EM:70G72DI('L*("`@
M("`@("`@("`@)&-O;F9I9ULG<&%G95]L:6UI="==(#T@,3`["B`@("`@("`@
M?0H@("`@("`@(&EF("@A:7-S970H)&-O;F9I9ULG<&5R<&%G92==*2D@>PH@
M("`@("`@("`@("`D8V]N9FEG6R=P97)P86=E)UT@/2`Q,#`["B`@("`@("`@
M?0H@("`@("`@('!A<F5N=#HZ2&]R9&5?54E?5VED9V5T*"1N86UE+"`D=F%R
M<RP@)&-O;F9I9RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YD97(@=&AE
M('!A9V5R+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!(5$U,(&-O
M9&4@8V]N=&%I;FEN9R!A(&-E;G1E<F5D('1A8FQE('=I=&@@=&AE('!A9V5R
M"B`@("`@*B`@("`@(&QI;FMS+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD
M97(H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<')E9G,L("1R96=I<W1R>2P@
M)&-O;F8["@H@("`@("`@("1N=6T@/2`D=&AI<RT^7V-O;F9I9ULG;G5M)UT[
M"B`@("`@("`@)'5R;"`]("1T:&ES+3Y?8V]N9FEG6R=U<FPG73L*("`@("`@
M("`D<&%G95]L:6UI="`]("1T:&ES+3Y?8V]N9FEG6R=P86=E7VQI;6ET)UT[
M"B`@("`@("`@)'!E<G!A9V4@/2`D=&AI<RT^7V-O;F9I9ULG<&5R<&%G92==
M.PH*("`@("`@("`D8W5R<F5N=%]P86=E(#T@)'1H:7,M/E]V87)S+3YG970H
M)'1H:7,M/E]N86UE*3L*"B`@("`@("`@+R\@1FEG=7)E(&]U="!H;W<@;6%N
M>2!P86=E<R!T:&5R92!W:6QL(&)E+@H@("`@("`@("1P86=E<R`]("@D;G5M
M("\@)'!E<G!A9V4I.PH@("`@("`@(&EF("AI<U]I;G1E9V5R*"1P86=E<RDI
M('L*("`@("`@("`@("`@)'!A9V5S+2T["B`@("`@("`@?0H@("`@("`@("1P
M86=E<R`]("AI;G0I)'!A9V5S.PH*("`@("`@("`O+R!2971U<FX@;F]T:&EN
M9R!I9B!T:&5R92!I<R!O;FQY(&]N92!P86=E+@H@("`@("`@(&EF("@D<&%G
M97,@/3T@,"!\?"`D;G5M(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N("<G
M.PH@("`@("`@('T*"B`@("`@("`@)&AT;6P@/2`G/&1I=B!C;&%S<STB<&%G
M97(B/B<["@H@("`@("`@("\O($-R96%T92!T:&4@)SP\(%!R978G(&QI;FL@
M:68@=V4@87)E(&YO="!O;B!T:&4@9FER<W0@<&%G92X*("`@("`@("`D;&EN
M:R`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`D=&AI<RT^7VYA;64L("1C
M=7)R96YT7W!A9V4@+2`Q*3L*("`@("`@("`D;&EN:R`]("1T:&ES+3Y?861D
M4')E<V5R=F5D*"1L:6YK*3L*("`@("`@("!I9B`H)&-U<G)E;G1?<&%G92`^
M(#`I('L*("`@("`@("`@("`@)&AT;6P@+CT@2&]R9&4Z.FQI;FLH2&]R9&4Z
M.F%P<&QI8V%T:6]N57)L*"1L:6YK*2P@)R<L("=P<F5V)RD@+B!H=&UL<W!E
M8VEA;&-H87)S*%\H(CQ0<F5V:6]U<R(I*2`N("<\+V$^)SL*("`@("`@("!]
M"@H@("`@("`@("\O($9I9W5R92!O=70@=&AE('1O<"`F(&)O='1O;2!D:7-P
M;&%Y(&QI;6ET<RX*("`@("`@("`D8F]T=&]M(#T@;6%X*#`L("1C=7)R96YT
M7W!A9V4@+2`H)'!A9V5?;&EM:70@+R`R*2`K(#$I.PH@("`@("`@("1T;W`@
M/2`D8F]T=&]M("L@)'!A9V5?;&EM:70@+2`Q.PH@("`@("`@(&EF("@D=&]P
M("T@,2`^("1P86=E<RD@>PH@("`@("`@("`@("`D8F]T=&]M("T]("@D=&]P
M("T@,2D@+2`D<&%G97,["B`@("`@("`@("`@("1T;W`@/2`D<&%G97,@*R`Q
M.PH@("`@("`@('T*"B`@("`@("`@+R\@0W)E871E(&)O='1O;2`G6W@M>5TG
M(&QI;FL@:68@;F5C97-S87)Y+@H@("`@("`@("1L:6YK(#T@)'1H:7,M/E]A
M9&10<F5S97)V960H571I;#HZ861D4&%R86UE=&5R*"1U<FPL("1T:&ES+3Y?
M;F%M92P@)&)O='1O;2`M(#$I*3L*("`@("`@("!I9B`H)&)O='1O;2`^(#`I
M('L*("`@("`@("`@("`@)&AT;6P@+CT@)R`G("X@2&]R9&4Z.FQI;FLH2&]R
M9&4Z.F%P<&QI8V%T:6]N57)L*"1L:6YK*2P@)R<L("=P<F5V4F%N9V4G*2`N
M("=;)R`N("@D8F]T=&]M(#T](#$@/R`D8F]T=&]M(#H@)S$M)R`N("1B;W1T
M;VTI("X@)UT\+V$^)SL*("`@("`@("!]"@H@("`@("`@("\O($-R96%T92!L
M:6YK<R!T;R!I;F1I=FED=6%L('!A9V5S(&)E='=E96X@;&EM:71S+@H@("`@
M("`@(&9O<B`H)&D@/2`D8F]T=&]M.R`D:2`\/2`D=&]P("8F("1I(#P]("1P
M86=E<SL@*RLD:2D@>PH@("`@("`@("`@("!I9B`H)&D@/3T@)&-U<G)E;G1?
M<&%G92D@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@)R`\<W1R;VYG/B@G
M("X@*"1I("L@,2D@+B`G*3PO<W1R;VYG/B<["B`@("`@("`@("`@('T@96QS
M96EF("@D:2`^/2`P("8F("1I(#P]("1P86=E<RD@>PH@("`@("`@("`@("`@
M("`@)&QI;FL@/2`D=&AI<RT^7V%D9%!R97-E<G9E9"A5=&EL.CIA9&1087)A
M;65T97(H)'5R;"P@)'1H:7,M/E]N86UE+"`D:2DI.PH@("`@("`@("`@("`@
M("`@)&AT;6P@+CT@)R`G("X@2&]R9&4Z.FQI;FLH2&]R9&4Z.F%P<&QI8V%T
M:6]N57)L*"1L:6YK*2D@+B`H)&D@*R`Q*2`N("<\+V$^)SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@0W)E871E('1O<"`G6W@M>5TG
M(&QI;FL@:68@;F5C97-S87)Y+@H@("`@("`@(&EF("@D=&]P(#P@)'!A9V5S
M*2!["B`@("`@("`@("`@("1L:6YK(#T@)'1H:7,M/E]A9&10<F5S97)V960H
M571I;#HZ861D4&%R86UE=&5R*"1U<FPL("1T:&ES+3Y?;F%M92P@)'1O<"`K
M(#$I*3L*("`@("`@("`@("`@)&AT;6P@+CT@)R`G("X@2&]R9&4Z.FQI;FLH
M2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"1L:6YK*2P@)R<L("=N97AT4F%N9V4G
M*2`N("=;)R`N"B`@("`@("`@("`@("`@("`H)'1O<"`K(#(@/3T@)'!A9V5S
M("L@,2`_("1P86=E<R`K(#$@.B`H)'1O<"`K(#(I("X@)RTG("X@*"1P86=E
M<R`K(#$I*2`N("==/"]A/B<["B`@("`@("`@?0H*("`@("`@("`O+R!#<F5A
M=&4@=&AE("=.97AT/CXG(&QI;FL@:68@=V4@87)E(&YO="!O;B!T:&4@;&%S
M="!P86=E+@H@("`@("`@(&EF("@D8W5R<F5N=%]P86=E(#P@)'!A9V5S*2![
M"B`@("`@("`@("`@("1L:6YK(#T@)'1H:7,M/E]A9&10<F5S97)V960H571I
M;#HZ861D4&%R86UE=&5R*"1U<FPL("1T:&ES+3Y?;F%M92P@)&-U<G)E;G1?
M<&%G92`K(#$I*3L*("`@("`@("`@("`@)&AT;6P@+CT@)R`G("X@2&]R9&4Z
M.FQI;FLH2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"1L:6YK*2P@)R<L("=N97AT
M)RD@+B!H=&UL<W!E8VEA;&-H87)S*%\H(DYE>'0^(BDI("X@)SPO83XG.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1H=&UL("X@)SPO9&EV/B<["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+U5)+U1A8G,N<&AP````````````````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-C8R,``Q,#4Q-30S,S<U,0`P,C$T,#8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC
M92!D:7)N86UE*%]?1DE,15]?*2`N("<O5VED9V5T+G!H<"<["@HO*BH*("H@
M5&AE($AO<F1E7U5)7U1A8G,Z.B!C;&%S<R!M86YA9V5S(&%N9"!R96YD97)S
M(&$@=&%B+6QI:V4@:6YT97)F86-E+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]522]522]486)S+G!H<"QV(#$N,C<N-BXQ,"`R,#`V+S`V+S(P(#`Y.C`X
M.C0U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`S(%)O8F5R
M="!%+B!#;WEL92`\<F]B97)T96-O>6QE0&AO=&UA:6PN8V]M/@H@*B!#;W!Y
M<FEG:'0@,C`P,RTR,#`V($IA<V]N($TN($9E;&EC92`\:F9E;&EC94!C<F]N
M;W-Y<RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`<VEN8V4@("!(;W)D95]5
M22`P+C`N,0H@*B!`<&%C:V%G92!(;W)D95]520H@*B\*8VQA<W,@2&]R9&5?
M54E?5&%B<R!E>'1E;F1S($AO<F1E7U5)7U=I9&=E="!["@H@("`@+RHJ"B`@
M("`@*B!4:&4@87)R87D@;V8@=&%B<RX*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7W1A8G,@/2!A<G)A>2@I.PH*("`@("\J
M*@H@("`@("H@061D(&$@=&%B('1O('1H92!I;G1E<F9A8V4N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=&ET;&4@("`@5&AE('1E>'0@=VAI8V@@
M87!P96%R<R!O;B!T:&4@=&%B+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&EN
M:R`@("`@5&AE('1A<F=E="!P86=E+@H@("`@("H@0'!A<F%M(&UI>&5D("`D
M<&%R86US("`@16ET:&5R(&$@<W1R:6YG('9A;'5E('1O('-E="!T:&4@=&%B
M('9A<FEA8FQE('1O+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M;W(@82!H87-H(&]F('!A<F%M971E<G,N($EF(&%N(&%R<F%Y+"!T:&4@=&%B
M('9A<FEA8FQE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!C86X@
M8F4@<V5T(&)Y('1H92`G=&%B;F%M92<@:V5Y+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!A9&1486(H)'1I=&QE+"`D;&EN:RP@)'!A<F%M<R`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D<&%R86US*2D@>PH@("`@
M("`@("`@("`D<&%R86US(#T@87)R87DH)W1A8FYA;64G(#T^("1P87)A;7,I
M.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7W1A8G-;72`](&%R<F%Y7VUE
M<F=E*&%R<F%Y*"=T:71L92<@/3X@)'1I=&QE+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI;FLG(#T^("1L:6YK+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1A
M8FYA;64G(#T^(&YU;&PI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!A<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R
M:65V92!T:&4@=&ET;&4@;V8@=&AE('1A8B!W:71H('1H92!S<&5C:69I960@
M;F%M92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T86)N86UE("!4
M:&4@;F%M92!O9B!T:&4@=&%B+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@=&%B)W,@=&ET;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%1I=&QE1G)O;4%C=&EO;B@D=&%B;F%M92D*("`@('L*("`@("`@("!F;W)E
M86-H("@D=&AI<RT^7W1A8G,@87,@)'1A8BD@>PH@("`@("`@("`@("!I9B`H
M)'1A8ELG=&%B;F%M92==(#T]("1T86)N86UE*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)'1A8ELG=&ET;&4G73L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!296YD97)S('1H92!T86)S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&%C=&EV95]T86(@($EF('-P96-I9FEE9"P@=&AE(&YA;64@;V8@=&AE
M(&%C=&EV92!T86(N($EF"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!N;W0L('1H92!A8W1I=F4@=&%B(&ES(&1E=&5R;6EN960*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%U=&]M871I8V%L;'DN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@D86-T:79E7W1A8B`](&YU;&PI
M"B`@("!["B`@("`@("`@)&AT;6P@/2`B/&1I=B!C;&%S<SU<(G1A8G-E=%PB
M/CQU;#Y<;B(["@H@("`@("`@("1F:7)S="`]('1R=64["B`@("`@("`@)&%C
M=&EV92`]("1?4T525D526R=02%!?4T5,1B==("X@)'1H:7,M/E]V87)S+3YG
M970H)'1H:7,M/E]N86UE*3L*"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]T
M86)S(&%S("1T86(I('L*("`@("`@("`@("`@)&QI;FL@/2`D=&AI<RT^7V%D
M9%!R97-E<G9E9"@D=&%B6R=L:6YK)UTI.PH@("`@("`@("`@("!I9B`H(6ES
M7VYU;&PH)'1H:7,M/E]N86UE*2`F)B`A:7-?;G5L;"@D=&%B6R=T86)N86UE
M)UTI*2!["B`@("`@("`@("`@("`@("`D;&EN:R`](%5T:6PZ.F%D9%!A<F%M
M971E<B@D;&EN:RP@)'1H:7,M/E]N86UE+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1A8ELG=&%B;F%M92==*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)&-L87-S(#T@)R<["B`@("`@("`@
M("`@(&EF("@H(6ES7VYU;&PH)&%C=&EV95]T86(I("8F("1A8W1I=F5?=&%B
M(#T]("1T86);)W1A8FYA;64G72D@?'P*("`@("`@("`@("`@("`@("@D86-T
M:79E(#T]("1T86);)VQI;FLG72`N("1T86);)W1A8FYA;64G72DI('L*("`@
M("`@("`@("`@("`@("1C;&%S<R`]("<@8VQA<W,](F%C=&EV951A8B(G.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T86);)W1A
M<F=E="==*2D@>PH@("`@("`@("`@("`@("`@)'1A8ELG=&%R9V5T)UT@/2`G
M)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%I<W-E="@D=&%B
M6R=O;F-L:6-K)UTI*2!["B`@("`@("`@("`@("`@("`D=&%B6R=O;F-L:6-K
M)UT@/2`G)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&%C8V5S<VME
M>2`]($AO<F1E.CIG971!8V-E<W-+97DH)'1A8ELG=&ET;&4G72D["@H@("`@
M("`@("`@("`D:'1M;"`N/2`G/&QI)R`N("1C;&%S<R`N("<^)R`N"B`@("`@
M("`@("`@("`@("!(;W)D93HZ;&EN:R@D;&EN:RP@)R<L("<G+"`D=&%B6R=T
M87)G970G72P@)'1A8ELG;VYC;&EC:R==+"!N=6QL+"`D86-C97-S:V5Y*2`N
M"B`@("`@("`@("`@("`@("!(;W)D93HZ:&EG:&QI9VAT06-C97-S2V5Y*'-T
M<E]R97!L86-E*"<@)RP@)R9N8G-P.R<L("1T86);)W1I=&QE)UTI+"`D86-C
M97-S:V5Y*2`N"B`@("`@("`@("`@("`@("`B/"]A/B`\+VQI/EQN(CL*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D:'1M;"`N("(\+W5L/CPO9&EV/CQB
M<B!C;&%S<SU<(F-L96%R7"(@+SY<;B(["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]522]687)296YD97)E<B\`````````````````````````````````````
M````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`U,34T,S,W-3$`,#(R,C$W`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#(P,34V-0`Q,#4Q-30S,S<U,0`P,C,W
M,#4`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]525]687)296YD97)E<E]H=&UL.CH@
M8VQA<W,@<F5N9&5R<R!V87)I86)L97,@=&\@2%1-3"X*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`L=B`Q+CDX
M+C(N,C@@,C`P-B\P."\Q-B`Q,CHQ-SHR,B!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#,M,C`P-B!*87-O;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O
M;F]S>7,N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@3$E#14Y3
M12!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN"B`J"B`J($!S:6YC
M92`@($AO<F1E7U5)(#`N,"XQ"B`J($!P86-K86=E($AO<F1E7U5)"B`J+PIC
M;&%S<R!(;W)D95]525]687)296YD97)E<E]H=&UL(&5X=&5N9',@2&]R9&5?
M54E?5F%R4F5N9&5R97(@>PH*("`@('9A<B`D7V]N3&]A9$I3(#T@87)R87DH
M*3L*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71$969A=6QT*"8D9F]R
M;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("!R971U<FX@)SQS=')O
M;F<^5V%R;FEN9SH\+W-T<F]N9SX@56YK;F]W;B!V87)I86)L92!T>7!E("<@
M+@H@("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG9714>7!E
M3F%M92@I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]N=6UB97(H)B1F;W)M+"`F
M)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V86QU92`]("1V87(M/F=E
M=%9A;'5E*"1V87)S*3L*("`@("`@("!I9B`H:7-S970H)'9A<BT^='EP92T^
M7V9R86-T:6]N*2D@>PH@("`@("`@("`@("`D=F%L=64@/2!S<')I;G1F*"<E
M,#$N)R`N("1V87(M/G1Y<&4M/E]F<F%C=&EO;B`N("=F)RP@)'9A;'5E*3L*
M("`@("`@("!]"B`@("`@("`@)&QI;F9O(#T@3DQ3.CIG971,;V-A;&5);F9O
M*"D["B`@("`@("`@+RH@3VYL>2!I9B!T:&5R92!I<R!A(&UO;E]D96-I;6%L
M7W!O:6YT(&1O('1H90H@("`@("`@("`J('-U8G-T:71U=&EO;BX@*B\*("`@
M("`@("!I9B`H(65M<'1Y*"1L:6YF;ULG;6]N7V1E8VEM86Q?<&]I;G0G72DI
M('L*("`@("`@("`@("`@)'9A;'5E(#T@<W1R7W)E<&QA8V4H)RXG+"`D;&EN
M9F];)VUO;E]D96-I;6%L7W!O:6YT)UTL("1V86QU92D["B`@("`@("`@?0H@
M("`@("`@("1V87)N86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T
M5F%R3F%M92@I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@
M("`@(')E='5R;B!S<')I;G1F*"<\:6YP=70@='EP93TB=&5X="(@<VEZ93TB
M-2(@;F%M93TB)7,B(&ED/2(E<R(@=F%L=64](B5S(B5S("\^)RP*("`@("`@
M("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@
M("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64L
M"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971!8W1I;VY38W)I
M<'1S*"1F;W)M+"`D=F%R*0H@("`@("`@("`@("`@("`I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]R96YD97)687));G!U=%]I;G0H)B1F;W)M+"`F)'9A<BP@
M)B1V87)S*0H@("`@>PH@("`@("`@("1V87)N86UE(#T@0&AT;6QS<&5C:6%L
M8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%3E1?455/5$53+"`D=&AI<RT^
M7V-H87)S970I.PH@("`@("`@(')E='5R;B!S<')I;G1F*"<\:6YP=70@='EP
M93TB=&5X="(@<VEZ93TB-2(@;F%M93TB)7,B(&ED/2(E<R(@=F%L=64](B5S
M(B5S("\^)RP*("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@
M("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@
M("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971686QU92@D=F%R
M<RDL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DL"B`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D
M=F%R*0H@("`@("`@("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R
M96YD97)687));G!U=%]O8W1A;"@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@
M("!["B`@("`@("`@)'9A<FYA;64@/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R
M+3YG971687).86UE*"DL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D[
M"B`@("`@("`@<F5T=7)N('-P<FEN=&8H)SQI;G!U="!T>7!E/2)T97AT(B!S
M:7IE/2(U(B!N86UE/2(E<R(@:60](B5S(B!V86QU93TB)7,B)7,@+SXG+`H@
M("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@
M("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@('-P
M<FEN=&8H)S`E;R<L(&]C=&1E8R@D=F%R+3YG971686QU92@D=F%R<RDI*2P*
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP
M=',H)&9O<FTL("1V87(I"B`@("`@("`@("`@("`@("D["B`@("!]"@H@("`@
M9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7VEN=&QI<W0H)B1F;W)M+"`F)'9A
M<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V87)N86UE(#T@0&AT;6QS<&5C
M:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%3E1?455/5$53+"`D=&AI
M<RT^7V-H87)S970I.PH@("`@("`@(')E='5R;B!S<')I;G1F*"<\:6YP=70@
M='EP93TB=&5X="(@;F%M93TB)7,B(&ED/2(E<R(@=F%L=64](B5S(B5S("\^
M)RP*("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@
M("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@
M("!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971686QU92@D=F%R<RDL($5.
M5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DL"B`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*0H@
M("`@("`@("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)6
M87));G!U=%]T97AT*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@
M("`@("`D;6%X;&5N9W1H(#T@)'9A<BT^='EP92T^9V5T36%X3&5N9W1H*"D[
M"B`@("`@("`@)'9A<FYA;64@/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG
M971687).86UE*"DL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@
M("`@("`@<F5T=7)N('-P<FEN=&8H)SQI;G!U="!T>7!E/2)T97AT(B!N86UE
M/2(E<R(@:60](B5S(B!S:7IE/2(E<R(@=F%L=64](B5S(B`E<R5S)7,@+SXG
M+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@
M("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@
M("1V87(M/G1Y<&4M/F=E=%-I>F4H*2P*("`@("`@("`@("`@("`@("`@("`@
M("!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971686QU92@D=F%R<RDL($5.
M5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DL"B`@("`@("`@("`@("`@("`@
M("`@("`@)'9A<BT^:7-$:7-A8FQE9"@I(#\@)R!D:7-A8FQE9#TB9&ES86)L
M960B("<@.B`G)RP*("`@("`@("`@("`@("`@("`@("`@("!E;7!T>2@D;6%X
M;&5N9W1H*2`_("<G(#H@)R!M87AL96YG=&@](B<@+B`D;6%X;&5N9W1H("X@
M)R(G+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N
M4V-R:7!T<R@D9F]R;2P@)'9A<BD*("`@("`@("`@("`@("`@*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?=V5A=&AE<F1O=&-O;2@F
M)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<F5N9&5R5F%R26YP=71?=&5X="@D9F]R;2P@)'9A<BP@)'9A<G,I
M.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]S=')I;F=L
M:7-T*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D=F%R
M;F%M92`]($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA;64H*2P@
M14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("!R971U<FX@
M<W!R:6YT9B@G/&EN<'5T('1Y<&4](G1E>'0B('-I>F4](C8P(B!N86UE/2(E
M<R(@:60](B5S(B!V86QU93TB)7,B)7,@+SXG+`H@("`@("`@("`@("`@("`@
M("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N
M86UE+`H@("`@("`@("`@("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S
M*"1V87(M/F=E=%9A;'5E*"1V87)S*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C
M:&%R<V5T*2P*("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C
M=&EO;E-C<FEP=',H)&9O<FTL("1V87(I"B`@("`@("`@("`@("`@("D["B`@
M("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7V-E;&QP:&]N92@F
M)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A<FYA;64@
M/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971687).86UE*"DL($5.5%]1
M54]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@<F5T=7)N('-P<FEN
M=&8H)SQI;G!U="!T>7!E/2)T97AT(B!N86UE/2(E<R(@:60](B5S(B!S:7IE
M/2(Q-2(@=F%L=64](B5S(B`E<R5S("\^)RP*("`@("`@("`@("`@("`@("`@
M("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M
M92P*("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D
M=F%R+3YG971686QU92@D=F%R<RDL($5.5%]154]415,L("1T:&ES+3Y?8VAA
M<G-E="DL"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<BT^:7-$:7-A8FQE
M9"@I(#\@)R!D:7-A8FQE9#TB9&ES86)L960B("<@.B`G)RP*("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL
M("1V87(I"B`@("`@("`@("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@
M7W)E;F1E<E9A<DEN<'5T7VEP861D<F5S<R@F)&9O<FTL("8D=F%R+"`F)'9A
M<G,I"B`@("!["B`@("`@("`@)'9A<FYA;64@/2!`:'1M;'-P96-I86QC:&%R
M<R@D=F%R+3YG971687).86UE*"DL($5.5%]154]415,L("1T:&ES+3Y?8VAA
M<G-E="D["B`@("`@("`@<F5T=7)N('-P<FEN=&8H)SQI;G!U="!T>7!E/2)T
M97AT(B!N86UE/2(E<R(@:60](B5S(B!S:7IE/2(Q-B(@=F%L=64](B5S(B`E
M<R5S("\^)RP*("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@
M("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@
M("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971686QU92@D=F%R
M<RDL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DL"B`@("`@("`@("`@
M("`@("`@("`@("`@)'9A<BT^:7-$:7-A8FQE9"@I(#\@)R!D:7-A8FQE9#TB
M9&ES86)L960B("<@.B`G)RP*("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V87(I"B`@("`@("`@("`@
M("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7V9I
M;&4H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V87)N
M86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%
M3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@(')E='5R;B!S
M<')I;G1F*"<\:6YP=70@='EP93TB9FEL92(@<VEZ93TB,S`B(&YA;64](B5S
M(B!I9#TB)7,B)7,@+SXG+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N
M86UE+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R
M;2P@)'9A<BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@0'1O9&\@4VAO=R!I
M;6%G92!D:6UE;G-I;VYS(&EN('1H92!W:61T:"]H96EG:'0@8F]X97,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]I;6%G92@F)&9O
M<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A<FYA;64@/2!H
M=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA;64H*2D["B`@("`@("`@
M)&EM86=E(#T@)'9A<BT^9V5T5F%L=64H)'9A<G,I.PH*("`@("`@("`O*B!#
M:&5C:R!I9B!E>&ES=&EN9R!I;6%G92!D871A(&ES(&)E:6YG(&QO861E9"X@
M*B\*("`@("`@("`D=F%R+3YT>7!E+3Y?;&]A9$EM86=E1&%T82@D:6UA9V4I
M.PH*("`@("`@("!(;W)D93HZ861D4V-R:7!T1FEL92@G:6UA9V4N:G,G+"`G
M:&]R9&4G+"!T<G5E*3L*("`@("`@("`D9W)A<&AI8W-?9&ER(#T@)$=,3T)!
M3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER*"=H;W)D92<I.PH@("`@("`@
M("1I;6=?9&ER(#T@)&=R87!H:6-S7V1I<B`N("<O:6UA9V4G.PH*("`@("`@
M("`D:'1M;"`]("<G.PH*("`@("`@("`O*B!#:&5C:R!I9B!T:&5R92!I<R!E
M>&ES=&EN9R!I;6<@:6YF;W)M871I;VX@<W1O<F5D+B`J+PH@("`@("`@(&EF
M("AI<W-E="@D:6UA9V5;)VEM9R==*2D@>PH@("`@("`@("`@("`O*B!(:61D
M96X@=&%G('1O('-T;W)E('1H92!P<F5V:65W(&EM86=E(&9I;&5N86UE+B`J
M+PH@("`@("`@("`@("`D:'1M;"`]('-P<FEN=&8H)SQI;G!U="!T>7!E/2)H
M:61D96XB(&YA;64](B5S(B!I9#TB)7,B('9A;'5E/2(E<R(@+SXG+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64@+B`G6VEM9UTG+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64@+B`G6VEM9UTG
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA
M<G,H)&EM86=E6R=I;6<G72P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T
M*2D["B`@("`@("`@("`@("\J(%5N<V5R:6%L:7IE('1H92!I;6<@:6YF;W)M
M871I;VX@=&\@9V5T('1H92!F=6QL(&%R<F%Y+B`J+PH@("`@("`@("`@("`D
M:6UA9V5;)VEM9R==(#T@0'5N<V5R:6%L:7IE*"1I;6%G95LG:6UG)UTI.PH@
M("`@("`@('T*"B`@("`@("`@+RH@3W5T<'5T('1H92!I;G!U="!T86<N("HO
M"B`@("`@("`@:68@*&5M<'1Y*"1I;6%G95LG:6UG)UTI*2!["B`@("`@("`@
M("`@("1J<R`](")V87(@<"`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"<B
M("X@)'9A<FYA;64@+B`B6W!R979I97==)RD[(&\@/2`G7%Q<7"<[(&$@/2`G
M+R<[('1M<"`]("<G("L@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)R(@+B`D
M=F%R;F%M92`N(");;F5W72<I+G9A;'5E.R!I9B`H=&UP*2![('=H:6QE("AT
M;7`N:6YD97A/9BAO*2`^("TQ*2![('!O<R`]('1M<"YI;F1E>$]F*&\I.R!T
M;7`@/2`G)R`K("AT;7`N<W5B<W1R:6YG*#`L('!O<RD@*R!A("L@=&UP+G-U
M8G-T<FEN9R@H<&]S("L@;RYL96YG=&@I+"!T;7`N;&5N9W1H*2D[?3L@<"YS
M<F,@/2`G9FEL93HO+R\G("L@=&UP.R!P+F%L="`]("<B("X@861D<VQA<VAE
M<RA?*"))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H
M92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D
M(&)Y('EO=7(@8G)O=W-E<BXB*2D@+B`B)SL@?3LB.PH@("`@("`@("`@("`D
M8G)O=W-E<B`]("9"<F]W<V5R.CIS:6YG;&5T;VXH*3L*("`@("`@("`@("`@
M:68@*"1B<F]W<V5R+3YI<T)R;W=S97(H)VUS:64G*2D@>PH@("`@("`@("`@
M("`@("`@)&AT;6P@+CT@<W!R:6YT9B@G/&EN<'5T('1Y<&4](F9I;&4B('-I
M>F4](C,P(B!N86UE/2(E<R(@:60](B5S(B!O;F-H86YG93TB)7,B("\^)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64@+B`G
M6VYE=UTG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%R
M;F%M92`N("=;;F5W72<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1J<RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D:'1M;"`N/2!S<')I;G1F*"<\:6YP=70@='EP93TB9FEL92(@<VEZ93TB
M,S`B(&YA;64](B5S(B!I9#TB)7,B(&]N8VQI8VL](G=I;F1O=RYS9714:6UE
M;W5T*%PG9&]C=6UE;G0N9V5T16QE;65N=$)Y260H7%Q<)R5S7%Q<)RDN8FQU
M<B@I.UPG+"`U*3LB(&]N8FQU<CTB)7,B("\^)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'9A<FYA;64@+B`G6VYE=UTG+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92`N("=;;F5W72<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE("X@
M)UMN97==)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&IS
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1H=&UL("X]('-P<FEN=&8H)SQI;G!U="!T>7!E/2)F:6QE(B!S:7IE/2(S
M,"(@;F%M93TB)7,B(&ED/2(E<R(@+SXG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1V87)N86UE("X@)UMN97==)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=F%R;F%M92`N("=;;F5W72<I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@3W5T<'5T('1H92!B=71T;VX@=&\@=7!L;V%D+W)E<V5T
M('1H92!I;6%G92X@*B\*("`@("`@("!I9B`H)'9A<BT^='EP92T^7W-H;W=?
M=7!L;V%D*2!["B`@("`@("`@("`@("1H=&UL("X]("<F;F)S<#LG.PH@("`@
M("`@("`@("`D:'1M;"`N/2!S<')I;G1F*"<\:6YP=70@8VQA<W,](F)U='1O
M;B(@;F%M93TB)7,B(&ED/2(E<R(@='EP93TB<W5B;6ET(B!V86QU93TB)7,B
M("\^("<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U]D;U\G("X@
M)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U]D;U\G
M("X@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7R@B
M57!L;V%D(BDI.PH@("`@("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1I;6%G
M95LG:6UG)UTI*2!["B`@("`@("`@("`@("\J($YO(&EM86=E(&EN9F]R;6%T
M:6]N('-T;W)E9"!Y970L('-H;W<@82!B;&%N:R!P<F5V:65W+B`J+PH@("`@
M("`@("`@("`D:'1M;"`N/2!(;W)D93HZ:6UG*"=T<F5E+V)L86YK+G!N9R<L
M(%\H(E!R979I97<B*2P@)W=I9'1H/2(U,"(@:&5I9VAT/2(T,"(@:60](B<@
M+B`D=F%R;F%M92`N("=;<')E=FEE=UTB)RP@)&=R87!H:6-S7V1I<BD["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@26UA9V4@:6YF;W)M871I
M;VX@<W1O<F5D+"!S:&]W('!R979I97<L(&%D9"!B=71T;VYS(&9O<B!I;6%G
M90H@("`@("`@("`@("`@*B!M86YI<'5L871I;VXN("HO"B`@("`@("`@("`@
M("1H=&UL("X]("<\8G(@+SXG.PH@("`@("`@("`@("`D:6UG(#T@2&]R9&4Z
M.G5R;"@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@)VAO
M<F1E)RD@+B`G+W-E<G9I8V5S+VEM86=E<R]V:65W+G!H<"<I.PH@("`@("`@
M("`@("!I9B`H:7-S970H)&EM86=E6R=I;6<G75LG=F9S7VED)UTI*2!["B`@
M("`@("`@("`@("`@("`O*B!#86QL:6YG(&%N(&EM86=E(&9R;VT@5D93+B`J
M+PH@("`@("`@("`@("`@("`@)&EM9R`](%5T:6PZ.F%D9%!A<F%M971E<B@D
M:6UG+"!A<G)A>2@G9B<@/3X@)&EM86=E6R=I;6<G75LG=F9S7VED)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=S)R`]/B`G=F9S)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W`G(#T^("1I;6%G95LG
M:6UG)UU;)W9F<U]P871H)UTI*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("\J($-A;&QI;F<@86X@:6UA9V4@9G)O;2!A('1M<"!D
M:7)E8W1O<GD@*'5P;&]A9',I+B`J+PH@("`@("`@("`@("`@("`@)&EM9R`]
M(%5T:6PZ.F%D9%!A<F%M971E<B@D:6UG+"`G9B<L("1I;6%G95LG:6UG)UU;
M)V9I;&4G72D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J(%)E<V5T
M+B`J+PH@("`@("`@("`@("`D:'1M;"`N/2!(;W)D93HZ;&EN:R@G(R<L(%\H
M(E)E<V5T(BDL("<G+"`G)RP@)W-H;W=);6%G92A<)R<@+B`D:6UG("X@)UPG
M+"!<)U]P7R<@+B`D=F%R;F%M92`N("=<)RP@=')U92D[)RD@+B!(;W)D93HZ
M:6UG*"=R969R97-H+G!N9R<L(%\H(E)E<V5T(BDL("=A;&EG;CTB;6ED9&QE
M(B<L("1I;6=?9&ER*2`N("<\+V$^)SL*"B`@("`@("`@("`@("\J(%)O=&%T
M92`R-S`N("HO"B`@("`@("`@("`@("1H=&UL("X]($AO<F1E.CIL:6YK*"<C
M)RP@7R@B4F]T871E($QE9G0B*2P@)R<L("<G+"`G<VAO=TEM86=E*%PG)R`N
M(%5T:6PZ.F%D9%!A<F%M971E<B@D:6UG+"!A<G)A>2@G82<@/3X@)W)O=&%T
M92<L("=V)R`]/B`G,C<P)RDI("X@)UPG+"!<)U]P7R<@+B`D=F%R;F%M92`N
M("=<)RP@=')U92D[)RD@+B!(;W)D93HZ:6UG*"=R;W1A=&4M,C<P+G!N9R<L
M(%\H(E)O=&%T92!,969T(BDL("=A;&EG;CTB;6ED9&QE(B<L("1I;6=?9&ER
M*2`N("<\+V$^)SL*"B`@("`@("`@("`@("\J(%)O=&%T92`Q.#`N("HO"B`@
M("`@("`@("`@("1H=&UL("X]($AO<F1E.CIL:6YK*"<C)RP@7R@B4F]T871E
M(#$X,"(I+"`G)RP@)R<L("=S:&]W26UA9V4H7"<G("X@571I;#HZ861D4&%R
M86UE=&5R*"1I;6<L(&%R<F%Y*"=A)R`]/B`G<F]T871E)RP@)W8G(#T^("<Q
M.#`G*2D@+B`G7"<L(%PG7W!?)R`N("1V87)N86UE("X@)UPG+"!T<G5E*3LG
M*2`N($AO<F1E.CII;6<H)W)O=&%T92TQ.#`N<&YG)RP@7R@B4F]T871E(#$X
M,"(I+"`G86QI9VX](FUI9&1L92(G+"`D:6UG7V1I<BD@+B`G/"]A/B<["@H@
M("`@("`@("`@("`O*B!2;W1A=&4@.3`N("HO"B`@("`@("`@("`@("1H=&UL
M("X]($AO<F1E.CIL:6YK*"<C)RP@7R@B4F]T871E(%)I9VAT(BDL("<G+"`G
M)RP@)W-H;W=);6%G92A<)R<@+B!5=&EL.CIA9&1087)A;65T97(H)&EM9RP@
M87)R87DH)V$G(#T^("=R;W1A=&4G+"`G=B<@/3X@)SDP)RDI("X@)UPG+"!<
M)U]P7R<@+B`D=F%R;F%M92`N("=<)RP@=')U92D[)RD@+B!(;W)D93HZ:6UG
M*"=R;W1A=&4M.3`N<&YG)RP@7R@B4F]T871E(%)I9VAT(BDL("=A;&EG;CTB
M;6ED9&QE(B<L("1I;6=?9&ER*2`N("<\+V$^)SL*"B`@("`@("`@("`@("\J
M($9L:7`@:6UA9V4N("HO"B`@("`@("`@("`@("1H=&UL("X]($AO<F1E.CIL
M:6YK*"<C)RP@7R@B1FQI<"(I+"`G)RP@)R<L("=S:&]W26UA9V4H7"<G("X@
M571I;#HZ861D4&%R86UE=&5R*"1I;6<L("=A)RP@)V9L:7`G*2`N("=<)RP@
M7"=?<%\G("X@)'9A<FYA;64@+B`G7"<L('1R=64I.R<I("X@2&]R9&4Z.FEM
M9R@G9FQI<"YP;F<G+"!?*")&;&EP(BDL("=A;&EG;CTB;6ED9&QE(B<L("1I
M;6=?9&ER*2`N("<\+V$^)SL*"B`@("`@("`@("`@("\J($UI<G)O<B!I;6%G
M92X@*B\*("`@("`@("`@("`@)&AT;6P@+CT@2&]R9&4Z.FQI;FLH)R,G+"!?
M*")-:7)R;W(B*2P@)R<L("<G+"`G<VAO=TEM86=E*%PG)R`N(%5T:6PZ.F%D
M9%!A<F%M971E<B@D:6UG+"`G82<L("=M:7)R;W(G*2`N("=<)RP@7"=?<%\G
M("X@)'9A<FYA;64@+B`G7"<L('1R=64I.R<I("X@2&]R9&4Z.FEM9R@G;6ER
M<F]R+G!N9R<L(%\H(DUI<G)O<B(I+"`G86QI9VX](FUI9&1L92(G+"`D:6UG
M7V1I<BD@+B`G/"]A/B<["@H@("`@("`@("`@("`O*B!!<'!L>2!G<F%Y<V-A
M;&4N("HO"B`@("`@("`@("`@("1H=&UL("X]($AO<F1E.CIL:6YK*"<C)RP@
M7R@B1W)A>7-C86QE(BDL("<G+"`G)RP@)W-H;W=);6%G92A<)R<@+B!5=&EL
M.CIA9&1087)A;65T97(H)&EM9RP@)V$G+"`G9W)A>7-C86QE)RD@+B`G7"<L
M(%PG7W!?)R`N("1V87)N86UE("X@)UPG+"!T<G5E*3LG*2`N($AO<F1E.CII
M;6<H)V=R87ES8V%L92YP;F<G+"!?*")'<F%Y<V-A;&4B*2P@)V%L:6=N/2)M
M:61D;&4B)RP@)&EM9U]D:7(I("X@)SPO83XG.PH*("`@("`@("`@("`@+RH@
M4F5S:7IE('=I9'1H+B`J+PH@("`@("`@("`@("`D:'1M;"`N/2!S<')I;G1F
M*"<E<SQI;G!U="!T>7!E/2)T97AT(B!S:7IE/2(T(B!O;F-H86YG93TB<W)C
M/6=E=%)E<VEZ95-R8RA<)R5S7"<L(%PG)7-<)RD[<VAO=TEM86=E*'-R8RP@
M7"=?<%\E<UPG+"!T<G5E*3LB("5S("\^)RP*("`@("`@("`@("`@("`@("`@
M(%\H(G<Z(BDL"B`@("`@("`@("`@("`@("`@("!5=&EL.CIA9&1087)A;65T
M97(H)&EM9RP@)V$G+"`G<F5S:7IE)RDL"B`@("`@("`@("`@("`@("`@("`D
M=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]G96Y)1"@G7W=?)R`N("1V87)N86UE*2D[
M"@H@("`@("`@("`@("`O*B!297-I>F4@:&5I9VAT+B`J+PH@("`@("`@("`@
M("`D:'1M;"`N/2!S<')I;G1F*"<E<SQI;G!U="!T>7!E/2)T97AT(B!S:7IE
M/2(T(B!O;F-H86YG93TB<W)C/6=E=%)E<VEZ95-R8RA<)R5S7"<L(%PG)7-<
M)RD[<VAO=TEM86=E*'-R8RP@7"=?<%\E<UPG+"!T<G5E*3LB("5S("\^)RP*
M("`@("`@("`@("`@("`@("`@(%\H(F@Z(BDL"B`@("`@("`@("`@("`@("`@
M("!5=&EL.CIA9&1087)A;65T97(H)&EM9RP@)V$G+"`G<F5S:7IE)RDL"B`@
M("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@
M("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G96Y)1"@G
M7VA?)R`N("1V87)N86UE*2D["@H@("`@("`@("`@("`O*B!!<'!L>2!F:7AE
M9"!R871I;R!R97-I>F4N("HO"B`@("`@("`@("`@("1H=&UL("X]($AO<F1E
M.CIL:6YK*"<C)RP@7R@B1FEX(')A=&EO(BDL("<G+"`G)RP@)W-R8SUG9712
M97-I>F53<F,H7"<G("X@571I;#HZ861D4&%R86UE=&5R*"1I;6<L("=A)RP@
M)W)E<VEZ92<I("X@)UPG+"!<)R<@+B`D=F%R;F%M92`N("=<)RP@7"<Q7"<I
M.W-H;W=);6%G92AS<F,L(%PG7W!?)R`N("1V87)N86UE("X@)UPG+"!T<G5E
M*3LG*2`N($AO<F1E.CII;6<H)W)A=&EO+G!N9R<L(%\H(D9I>"!R871I;R(I
M+"`G86QI9VX](FUI9&1L92(G+"`D:6UG7V1I<BD@+B`G/"]A/B<["@H@("`@
M("`@("`@("`O*B!+965P(&%L<V\@;W)I9VEN86P@:68@:70@:&%S(&)E96X@
M<F5Q=65S=&5D+B`J+PH@("`@("`@("`@("!I9B`H)'9A<BT^='EP92T^7W-H
M;W=?:V5E<&]R:6<I('L*("`@("`@("`@("`@("`@("1H=&UL("X]('-P<FEN
M=&8H)SQI;G!U="!T>7!E/2)C:&5C:V)O>"(@8VQA<W,](F-H96-K8F]X(B!N
M86UE/2(E<R(@:60](B5S(B5S("\^)7,G("X@(EQN(BP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64@+B`G6VME97!?;W)I9UTG
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92`N
M("=;:V5E<%]O<FEG72<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("%E;7!T>2@D:6UA9V5;)VME97!?;W)I9R==*2`_("<@8VAE8VME9#TB
M8VAE8VME9"(G(#H@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(%\H(DME97`@;W)I9VEN86P_(BDI.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`O*B!4:&4@<')E=FEE=R!I;6%G92!E;&5M96YT+B`J+PH@("`@
M("`@("`@("`D:'1M;"`N/2`G/&)R("\^/&EM9R!S<F,](B<@+B`D:6UG("X@
M)R(@)R`N("1T:&ES+3Y?9V5N240H)U]P7R<@+B`D=F%R;F%M92D@+B`B/EQN
M(CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:'1M;#L*("`@('T*"B`@
M("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?;&]N9W1E>'0H)B1F;W)M+"`F
M)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8G)O=W-E<CL*
M"B`@("`@("`@)'9A<FYA;64@/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG
M971687).86UE*"DL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@
M("`@("`@)&AT;6P@/2!S<')I;G1F*"<\=&5X=&%R96$@:60](B5S(B!N86UE
M/2(E<R(@8V]L<STB)7,B(')O=W,](B5S(B5S)7,^)7,\+W1E>'1A<F5A/B<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@
M("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@
M("`@*&EN="DD=F%R+3YT>7!E+3YG971#;VQS*"DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("AI;G0I)'9A<BT^='EP92T^9V5T4F]W<R@I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O
M<FTL("1V87(I+`H@("`@("`@("`@("`@("`@("`@("`@("`D=F%R+3YI<T1I
M<V%B;&5D*"D@/R`G(&1I<V%B;&5D/2)D:7-A8FQE9"(G(#H@)R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E
M=%9A;'5E*"1V87)S*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2D[
M"@H@("`@("`@(&EF("@D=F%R+3YT>7!E+3YH87-(96QP97(H)W)T92<I("8F
M("1B<F]W<V5R+3YH87-&96%T=7)E*"=R=&4G*2D@>PH@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+T5D:71O<BYP:'`G.PH@("`@("`@("`@("`D
M961I=&]R(#T@)DAO<F1E7T5D:71O<CHZ<VEN9VQE=&]N*"=H=&UL87)E82<L
M(&%R<F%Y*"=I9"<@/3X@)'9A<FYA;64I*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@D=F%R+3YT>7!E+3YH87-(96QP97(H*2`F)B`D8G)O=W-E<BT^:&%S
M1F5A='5R92@G:F%V87-C<FEP="<I*2!["B`@("`@("`@("`@("1H=&UL("X]
M("<\8G(@+SX\=&%B;&4@8V5L;'-P86-I;F<](C`B/CQT<CX\=&0^)SL*("`@
M("`@("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)V]P96Y?:'1M;%]H96QP
M97(N:G,G+"`G:&]R9&4G*3L*("`@("`@("`@("`@)&EM9TED(#T@)'1H:7,M
M/E]G96Y)1"@D=F%R+3YG971687).86UE*"DL(&9A;'-E*2`N("=E:&5L<&5R
M)SL*("`@("`@("`@("`@:68@*"1V87(M/G1Y<&4M/FAA<TAE;'!E<B@G96UO
M=&EC;VYS)RDI('L*("`@("`@("`@("`@("`@("1H=&UL("X]($AO<F1E.CIL
M:6YK*"<C)RP@7R@B16UO=&EC;VYS(BDL("<G+"`G)RP@)V]P96Y(=&UL2&5L
M<&5R*%PG96UO=&EC;VYS7"<L(%PG)R`N("1V87(M/F=E=%9A<DYA;64H*2`N
M("=<)RD[(')E='5R;B!F86QS93LG*2`N($AO<F1E.CII;6<H)W-M:6QE+G!N
M9R<L(%\H(D5M;W1I8V]N<R(I+"`G:60](B<@+B`D:6UG260@+B`G(B!A;&EG
M;CTB;6ED9&QE(B<L("1'3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G941I
M<B@G:&]R9&4G*2`N("<O96UO=&EC;VYS)RD@+B`G/"]A/B<["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&AT;6P@+CT@)SPO=&0^/"]T<CX\='(^/'1D
M/CQD:78@)R`N("1T:&ES+3Y?9V5N240H)VAT;6QH96QP97)?)R`N("1V87(M
M/F=E=%9A<DYA;64H*2D@+B`G(&-L87-S/2)C;VYT<F]L(CX\+V1I=CX\+W1D
M/CPO='(^/"]T86)L93XG("X@(EQN(CL*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D:'1M;#L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP
M=71?8V]U;G1E9'1E>'0H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@
M("`@("`@("1V87)N86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T
M5F%R3F%M92@I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@
M("`@(')E='5R;B!S<')I;G1F*"<\=&5X=&%R96$@;F%M93TB)7,B(&ED/2(E
M<R(@8V]L<STB)7,B(')O=W,](B5S(B5S)7,^)7,\+W1E>'1A<F5A/B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@
M("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@*&EN
M="DD=F%R+3YT>7!E+3YG971#;VQS*"DL"B`@("`@("`@("`@("`@("`@("`@
M("`@*&EN="DD=F%R+3YT>7!E+3YG9712;W=S*"DL"B`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R
M*2P*("`@("`@("`@("`@("`@("`@("`@("`D=F%R+3YI<T1I<V%B;&5D*"D@
M/R`G(&1I<V%B;&5D/2)D:7-A8FQE9"(G(#H@)R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%L=64H)'9A
M<G,I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?861D<F5S<R@F)&9O<FTL("8D
M=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A<FYA;64@/2!`:'1M;'-P
M96-I86QC:&%R<R@D=F%R+3YG971687).86UE*"DL($5.5%]154]415,L("1T
M:&ES+3Y?8VAA<G-E="D["B`@("`@("`@<F5T=7)N('-P<FEN=&8H)SQT97AT
M87)E82!N86UE/2(E<R(@:60](B5S(B!C;VQS/2(E<R(@<F]W<STB)7,B)7,E
M<SXE<SPO=&5X=&%R96$^)RP*("`@("`@("`@("`@("`@("`@("`@("`D=F%R
M;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@
M("`@("`@("`@("`@("`@("`H:6YT*21V87(M/G1Y<&4M/F=E=$-O;',H*2P*
M("`@("`@("`@("`@("`@("`@("`@("`H:6YT*21V87(M/G1Y<&4M/F=E=%)O
M=W,H*2P*("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO
M;E-C<FEP=',H)&9O<FTL("1V87(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("1V87(M/FES1&ES86)L960H*2`_("<@9&ES86)L960](F1I<V%B;&5D(B<@
M.B`G)RP*("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R
M<R@D=F%R+3YG971686QU92@D=F%R<RDL($5.5%]154]415,L("1T:&ES+3Y?
M8VAA<G-E="DI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687));G!U
M=%]D871E*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D
M=F%R;F%M92`]($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA;64H
M*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("!R971U
M<FX@<W!R:6YT9B@G/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](B5S(B!I9#TB
M)7,B('9A;'5E/2(E<R(E<R`O/B<L"B`@("`@("`@("`@("`@("`@("`@("`@
M)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@
M("`@("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^
M9V5T5F%L=64H)'9A<G,I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I
M+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R
M:7!T<R@D9F]R;2P@)'9A<BDI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD
M97)687));G!U=%]T:6UE*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*
M("`@("`@("`D=F%R;F%M92`]($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E
M=%9A<DYA;64H*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@
M("`@("!R971U<FX@<W!R:6YT9B@G/&EN<'5T('1Y<&4](G1E>'0B('-I>F4]
M(C4B(&YA;64](B5S(B!I9#TB)7,B('9A;'5E/2(E<R(E<R`O/B<L"B`@("`@
M("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@
M("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@0&AT;6QS
M<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%L=64H)'9A<G,I+"!%3E1?455/5$53
M+"`D=&AI<RT^7V-H87)S970I+`H@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BDI.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]H;W5R;6EN=71E<V5C;VYD
M*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D=F%R;F%M
M92`]($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA;64H*2P@14Y4
M7U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("`D=&EM92`]("1V
M87(M/G1Y<&4M/F=E=%1I;65087)T<R@D=F%R+3YG971686QU92@D=F%R<RDI
M.PH*("`@("`@("`O*B!/=71P=70@:&]U<G,N("HO"B`@("`@("`@)&AO=7)S
M(#T@87)R87DH)R<@/3X@7R@B:&@B*2D["B`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P](#(S.R`D:2LK*2!["B`@("`@("`@("`@("1H;W5R<ULD:5T@/2`D
M:3L*("`@("`@("!]"B`@("`@("`@)&AT;6P@/2!S<')I;G1F*"<\<V5L96-T
M(&YA;64](B5S6VAO=7)=(B!I9#TB)7-;:&]U<ETB)7,^)7,\+W-E;&5C=#XG
M+`H@("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@
M("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5L96-T3W!T:6]N<R@D
M:&]U<G,L("@D=&EM95LG:&]U<B==(#T]/2`G)RD@/R`G)R`Z("1T:6UE6R=H
M;W5R)UTI*3L*"B`@("`@("`@+RH@3W5T<'5T(&UI;G5T97,N("HO"B`@("`@
M("`@)&UI;G5T97,@/2!A<G)A>2@G)R`]/B!?*")M;2(I*3L*("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/#T@-3D[("1I*RLI('L*("`@("`@("`@("`@)&T@
M/2!S<')I;G1F*"<E,#)D)RP@)&DI.PH@("`@("`@("`@("`D;6EN=71E<ULD
M;5T@/2`D;3L*("`@("`@("!]"B`@("`@("`@)&AT;6P@+CT@<W!R:6YT9B@G
M/'-E;&5C="!N86UE/2(E<UMM:6YU=&5=(B!I9#TB)7-;;6EN=71E72(E<SXE
M<SPO<V5L96-T/B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F
M;W)M+"`D=F%R*2P*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<V5L96-T3W!T:6]N<R@D;6EN=71E<RP@*"1T:6UE6R=M:6YU=&4G72`]/3T@
M)R<I(#\@)R<@.B!S<')I;G1F*"<E,#)D)RP@)'1I;65;)VUI;G5T92==*2DI
M.PH*("`@("`@("`O*B!2971U<FX@:68@<V5C;VYD<R!A<F4@;F]T(')E<75I
M<F5D+B`J+PH@("`@("`@(&EF("@A)'9A<BT^='EP92T^7W-H;W=?<V5C;VYD
M<RD@>PH@("`@("`@("`@("!R971U<FX@)&AT;6P["B`@("`@("`@?0H*("`@
M("`@("`O*B!/=71P=70@<V5C;VYD<RX@*B\*("`@("`@("`D<V5C;VYD<R`]
M(&%R<F%Y*"<G(#T^(%\H(G-S(BDI.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\/2`U.3L@)&DK*RD@>PH@("`@("`@("`@("`D<V5C;VYD<ULD:5T@/2!S
M<')I;G1F*"<E,#)D)RP@)&DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)&AT;6P@+B!S<')I;G1F*"<\<V5L96-T(&YA;64](B5S6W-E8V]N9%TB(&ED
M/2(E<UMS96-O;F1=(B5S/B5S/"]S96QE8W0^)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V87(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S96QE
M8W1/<'1I;VYS*"1S96-O;F1S+"`H)'1I;65;)W-E8V]N9"==(#T]/2`G)RD@
M/R`G)R`Z('-P<FEN=&8H)R4P,F0G+"`D=&EM95LG<V5C;VYD)UTI*2D["B`@
M("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7VUO;G1H>65A<B@F
M)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)&1A=&5S(#T@
M87)R87DH*3L*("`@("`@("`D9&%T97-;)VUO;G1H)UT@/2!A<G)A>2@G)R`]
M/B!?*")-32(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$@
M/3X@7R@B2F%N=6%R>2(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#(@/3X@7R@B1F5B<G5A<GDB*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`S(#T^(%\H(DUA<F-H(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@-"`]/B!?*")!<')I;"(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#4@/3X@7R@B36%Y(BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@-B`]/B!?*")*=6YE(BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@-R`]/B!?*")*=6QY(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@."`]/B!?*")!=6=U<W0B*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Y(#T^(%\H(E-E<'1E
M;6)E<B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$P(#T^
M(%\H(D]C=&]B97(B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`Q,2`]/B!?*").;W9E;6)E<B(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#$R(#T^(%\H(D1E8V5M8F5R(BDI.PH@("`@("`@("1D871E
M<ULG>65A<B==(#T@87)R87DH)R<@/3X@7R@B65E962(I*3L*("`@("`@("!I
M9B`H)'9A<BT^='EP92T^7W-T87)T7WEE87(@/B`D=F%R+3YT>7!E+3Y?96YD
M7WEE87(I('L*("`@("`@("`@("`@9F]R("@D:2`]("1V87(M/G1Y<&4M/E]S
M=&%R=%]Y96%R.R`D:2`^/2`D=F%R+3YT>7!E+3Y?96YD7WEE87([("1I+2TI
M('L*("`@("`@("`@("`@("`@("1D871E<ULG>65A<B==6R1I72`]("1I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@9F]R
M("@D:2`]("1V87(M/G1Y<&4M/E]S=&%R=%]Y96%R.R`D:2`\/2`D=F%R+3YT
M>7!E+3Y?96YD7WEE87([("1I*RLI('L*("`@("`@("`@("`@("`@("1D871E
M<ULG>65A<B==6R1I72`]("1I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!S<')I;G1F*"<\<V5L96-T(&YA;64](B5S(B!I9#TB
M)7,B)7,^)7,\+W-E;&5C=#XG+`H@("`@("`@("`@("`@("`@("`@("`@("1V
M87(M/G1Y<&4M/F=E=$UO;G1H5F%R*"1V87(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("1V87(M/G1Y<&4M/F=E=$UO;G1H5F%R*"1V87(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R
M;2P@)'9A<BDL"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S96QE
M8W1/<'1I;VYS*"1D871E<ULG;6]N=&@G72P@)'9A<G,M/F=E="@D=F%R+3YT
M>7!E+3YG971-;VYT:%9A<B@D=F%R*2DI*2`N"B`@("`@("`@("`@('-P<FEN
M=&8H)SQS96QE8W0@;F%M93TB)7,B(&ED/2(E<R(E<SXE<SPO<V5L96-T/B<L
M"B`@("`@("`@("`@("`@("`@("`@)'9A<BT^='EP92T^9V5T665A<E9A<B@D
M=F%R*2P*("`@("`@("`@("`@("`@("`@("`D=F%R+3YT>7!E+3YG971996%R
M5F%R*"1V87(I+`H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T
M:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BDL"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]S96QE8W1/<'1I;VYS*"1D871E<ULG>65A<B==+"`D=F%R<RT^
M9V5T*"1V87(M/G1Y<&4M/F=E=%EE87)687(H)'9A<BDI*2D["B`@("!]"@H@
M("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7VUO;G1H9&%Y>65A<B@F)&9O
M<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)&1A=&5S(#T@87)R
M87DH*3L*("`@("`@("`D9&%T97-;)VUO;G1H)UT@/2!A<G)A>2@G)R`@(#T^
M(%\H(DU-(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)S$G
M("`]/B!?*")*86YU87)Y(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)S(G("`]/B!?*")&96)R=6%R>2(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("<S)R`@/3X@7R@B36%R8V@B*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G-"<@(#T^(%\H(D%P<FEL(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)S4G("`]/B!?*")-87DB
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G-B<@(#T^(%\H
M(DIU;F4B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G-R<@
M(#T^(%\H(DIU;'DB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G."<@(#T^(%\H(D%U9W5S="(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("<Y)R`@/3X@7R@B4V5P=&5M8F5R(BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)S$P)R`]/B!?*")/8W1O8F5R(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)S$Q)R`]/B!?*").;W9E
M;6)E<B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<Q,B<@
M/3X@7R@B1&5C96UB97(B*2D["B`@("`@("`@)&1A=&5S6R=D87DG72`](&%R
M<F%Y*"<G(#T^(%\H(D1$(BDI.PH@("`@("`@(&9O<B`H)&D@/2`Q.R`D:2`\
M/2`S,3L@)&DK*RD@>PH@("`@("`@("`@("`D9&%T97-;)V1A>2==6R1I72`]
M("1I.PH@("`@("`@('T*("`@("`@("`D9&%T97-;)WEE87(G72`](&%R<F%Y
M*"<G(#T^(%\H(EE965DB*2D["B`@("`@("`@:68@*"1V87(M/G1Y<&4M/E]S
M=&%R=%]Y96%R(#X@)'9A<BT^='EP92T^7V5N9%]Y96%R*2!["B`@("`@("`@
M("`@(&9O<B`H)&D@/2`D=F%R+3YT>7!E+3Y?<W1A<G1?>65A<CL@)&D@/CT@
M)'9A<BT^='EP92T^7V5N9%]Y96%R.R`D:2TM*2!["B`@("`@("`@("`@("`@
M("`D9&%T97-;)WEE87(G75LD:5T@/2`D:3L*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(&9O<B`H)&D@/2`D=F%R+3YT>7!E
M+3Y?<W1A<G1?>65A<CL@)&D@/#T@)'9A<BT^='EP92T^7V5N9%]Y96%R.R`D
M:2LK*2!["B`@("`@("`@("`@("`@("`D9&%T97-;)WEE87(G75LD:5T@/2`D
M:3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D9&%T92`]("1V
M87(M/G1Y<&4M/F=E=$1A=&5087)T<R@D=F%R+3YG971686QU92@D=F%R<RDI
M.PH*("`@("`@("`O+R!43T1/.B!U<V4@3DQ3('1O(&=E="!T:&4@;W)D97(@
M<FEG:'0@9F]R('1H92!297-T($]F(%1H90H@("`@("`@("\O(%=O<FQD+@H@
M("`@("`@("1H=&UL(#T@)R<["B`@("`@("`@)&1A=&5?<&%R=',@/2!A<G)A
M>2@G;6]N=&@G+"`G9&%Y)RP@)WEE87(G*3L*("`@("`@("!F;W)E86-H("@D
M9&%T95]P87)T<R!A<R`D<&%R="D@>PH@("`@("`@("`@("`D=F%R;F%M92`]
M($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA;64H*2`N("=;)R`N
M("1P87)T("X@)UTG+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@
M("`@("`@("`@("`D:'1M;"`N/2!S<')I;G1F*"<\<V5L96-T(&YA;64](B5S
M(B!I9#TB)7,B)7,^)7,\+W-E;&5C=#XG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S96QE8W1/<'1I;VYS*"1D
M871E<ULD<&%R=%TL("1D871E6R1P87)T72DI.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"1V87(M/G1Y<&4M/E]P:6-K97(@)B8@)$=,3T)!3%-;)V)R;W=S
M97(G72T^:&%S1F5A='5R92@G:F%V87-C<FEP="<I*2!["B`@("`@("`@("`@
M($AO<F1E.CIA9&138W)I<'1&:6QE*"=O<&5N7V-A;&5N9&%R+FIS)RP@)VAO
M<F1E)RD["B`@("`@("`@("`@("1I;6=)9"`]("1T:&ES+3Y?9V5N240H)'9A
M<BT^9V5T5F%R3F%M92@I+"!F86QS92D@+B`G9V]T;R<["B`@("`@("`@("`@
M("1H=&UL("X]("<\9&EV(&ED/2)G;W1O(B!C;&%S<STB:&5A9&5R8F]X(B!S
M='EL93TB<&]S:71I;VXZ86)S;VQU=&4[=FES:6)I;&ET>3IH:61D96X[<&%D
M9&EN9SHP(CX\+V1I=CXG("X*("`@("`@("`@("`@("`@($AO<F1E.CIL:6YK
M*"<C)RP@7R@B4V5L96-T(&$@9&%T92(I+"`G)RP@)R<L("=O<&5N0V%L96YD
M87(H7"<G("X@)&EM9TED("X@)UPG+"!<)R<@+B`D=F%R+3YG971687).86UE
M*"D@+B`G7"<I.R!R971U<FX@9F%L<V4[)RD@+B!(;W)D93HZ:6UG*"=C86QE
M;F1A<BYP;F<G+"!?*")#86QE;F1A<B(I+"`G:60](B<@+B`D:6UG260@+B`G
M(B!A;&EG;CTB;6ED9&QE(B<L("1'3$]"04Q36R=R96=I<W1R>2==+3YG971)
M;6%G941I<B@G:&]R9&4G*2D@+B`B/"]A/EQN(CL*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D:'1M;#L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R
M5F%R26YP=71?8V]L;W)P:6-K97(H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GDL("1B<F]W<V5R.PH*("`@
M("`@("`D=F%R;F%M92`]($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A
M<DYA;64H*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@
M("`D:'1M;"`]("<\=&%B;&4@8V5L;'-P86-I;F<](C`B/CQT<CX\=&0^)R`N
M"B`@("`@("`@("`@("<\:6YP=70@='EP93TB=&5X="(@<VEZ93TB,3`B(&UA
M>&QE;F=T:#TB-R(@;F%M93TB)R`N"B`@("`@("`@("`@("1V87)N86UE("X@
M)R(@:60](B<@+B`D=F%R;F%M92`N"B`@("`@("`@("`@("<B('9A;'5E/2(G
M("X@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%L=64H)'9A<G,I+"!%
M3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I("X@)R(@+SX\+W1D/B<["B`@
M("`@("`@:68@*"1B<F]W<V5R+3YH87-&96%T=7)E*"=J879A<V-R:7!T)RDI
M('L*("`@("`@("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)V]P96Y?8V]L
M;W)P:6-K97(N:G,G+"`G:&]R9&4G+"!T<G5E*3L*("`@("`@("`@("`@)&AT
M;6P@+CT@)SQT9"!W:61T:#TB,C`B(&ED/2)C;VQO<F1E;6]?)R`N("1V87)N
M86UE("X@)R(@<W1Y;&4](F)A8VMG<F]U;F0Z)R`N($!H=&UL<W!E8VEA;&-H
M87)S*"1V87(M/F=E=%9A;'5E*"1V87)S*2P@14Y47U%53U1%4RP@)'1H:7,M
M/E]C:&%R<V5T*2`N("<B/B`\+W1D/B<@+@H@("`@("`@("`@("`@("`@)SQT
M9#XG("X@2&]R9&4Z.FQI;FLH)R,G+"!?*")#;VQO<B!0:6-K97(B*2P@)W=I
M9&=E="<L("<G+"`G;W!E;D-O;&]R4&EC:V5R*%PG)R`N("1V87)N86UE("X@
M)UPG*3L@<F5T=7)N(&9A;'-E.R<I("X@2&]R9&4Z.FEM9R@G8V]L;W)P:6-K
M97(N<&YG)RP@7R@B0V]L;W(@4&EC:V5R(BDL("=H96EG:'0](C$V(B<L("1R
M96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI("X@)SPO83X\+W1D/B<@
M+@H@("`@("`@("`@("`@("`@)SQT9#X\9&EV(&ED/2)C;VQO<G!I8VME<E\G
M("X@)'9A<FYA;64@+B`G(B!C;&%S<STB8V]N=')O;"(^/"]D:78^/"]T9#XG
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&AT;6P@+B`G/"]T<CX\+W1A
M8FQE/B<["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7W-O
M<G1E<B@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@9VQO
M8F%L("1R96=I<W1R>3L*"B`@("`@("`@)'9A<FYA;64@/2!`:'1M;'-P96-I
M86QC:&%R<R@D=F%R+3YG971687).86UE*"DL($5.5%]154]415,L("1T:&ES
M+3Y?8VAA<G-E="D["B`@("`@("`@)&EN<W1A;F-E(#T@)'9A<BT^='EP92T^
M7VEN<W1A;F-E.PH*("`@("`@("!(;W)D93HZ861D4V-R:7!T1FEL92@G<V]R
M=&5R+FIS)RP@)VAO<F1E)RP@=')U92D["@H@("`@("`@(')E='5R;B`G/&EN
M<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB)R`N("1V87)N86UE("X*("`@("`@
M("`@("`@)UMA<G)A>5TB('9A;'5E/2(B("<@+B`D=&AI<RT^7V=E;DE$*"1V
M87)N86UE("X@)UMA<G)A>5TG*2`N("<O/B<@+@H@("`@("`@("`@("`G/'-E
M;&5C="!C;&%S<STB;&5F=$9L;V%T(B!M=6QT:7!L93TB;75L=&EP;&4B('-I
M>F4](B<@+@H@("`@("`@("`@("`H:6YT*21V87(M/G1Y<&4M/F=E=%-I>F4H
M*2`N("<B(&YA;64](B<@+B`D=F%R;F%M92`N"B`@("`@("`@("`@("=;;&ES
M=%TB(&]N8VAA;F=E/2(G("X@)&EN<W1A;F-E("X@)RYD97-E;&5C=$AE861E
M<B@I.R(@)R`N"B`@("`@("`@("`@("1T:&ES+3Y?9V5N240H)'9A<FYA;64@
M+B`G6VQI<W1=)RD@+B`G/B<@+@H@("`@("`@("`@("`D=F%R+3YT>7!E+3YG
M971/<'1I;VYS*"1V87(M/F=E=%9A;'5E*"1V87)S*2D@+B`G/"]S96QE8W0^
M/&1I=B!C;&%S<STB;&5F=$9L;V%T(CXG("X*("`@("`@("`@("`@2&]R9&4Z
M.FQI;FLH)R,G+"!?*")-;W9E('5P(BDL("<G+"`G)RP@)&EN<W1A;F-E("X@
M)RYM;W9E0V]L=6UN57`H*3L@<F5T=7)N(&9A;'-E.R<I("X@2&]R9&4Z.FEM
M9R@G;F%V+W5P+G!N9R<L(%\H(DUO=F4@=7`B*2P@)R<L("1R96=I<W1R>2T^
M9V5T26UA9V5$:7(H)VAO<F1E)RDI("X@)SPO83X\8G(@+SXG("X*("`@("`@
M("`@("`@2&]R9&4Z.FQI;FLH)R,G+"!?*")-;W9E('5P(BDL("<G+"`G)RP@
M)&EN<W1A;F-E("X@)RYM;W9E0V]L=6UN1&]W;B@I.R!R971U<FX@9F%L<V4[
M)RD@+B!(;W)D93HZ:6UG*"=N878O9&]W;BYP;F<G+"!?*")-;W9E(&1O=VXB
M*2P@)R<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI("X@)SPO
M83X\+V1I=CXG("X*("`@("`@("`@("`@)SQS8W)I<'0@='EP93TB=&5X="]J
M879A<V-R:7!T(CXG("X@(EQN(B`N"B`@("`@("`@("`@('-P<FEN=&8H)R4Q
M)',@/2!N97<@2&]R9&5?1F]R;5]3;W)T97(H7"<E,21S7"<L(%PG)3(D<UPG
M+"!<)R4S)'-<)RD[)R`N(")<;B(L"B`@("`@("`@("`@("`@("`@("`@)&EN
M<W1A;F-E+"`D=F%R;F%M92P@)'9A<BT^='EP92T^9V5T2&5A9&5R*"DI("X*
M("`@("`@("`@("`@<W!R:6YT9B@B)7,N<V5T2&ED9&5N*"D[7&X\+W-C<FEP
M=#Y<;B(L("1I;G-T86YC92D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E
M<E9A<DEN<'5T7V%S<VEG;B@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("![
M"B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@2&]R9&4Z.F%D
M9%-C<FEP=$9I;&4H)V9O<FU?87-S:6=N+FIS)RP@)VAO<F1E)RP@=')U92D[
M"@H@("`@("`@("1N86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T
M5F%R3F%M92@I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@
M("`@("1F;F%M92`]("1F;W)M+3YG971.86UE*"D@+B`G+B<@+B`D=F%R+3YG
M971687).86UE*"D["B`@("`@("`@)'-I>F4@/2`D=F%R+3YT>7!E+3YG9713
M:7IE*"D["B`@("`@("`@)'=I9'1H(#T@)'9A<BT^='EP92T^9V5T5VED=&@H
M*3L*("`@("`@("`D;&AD<B`]("AB;V]L*21V87(M/G1Y<&4M/F=E=$AE861E
M<B@P*3L*("`@("`@("`D<FAD<B`]("AB;V]L*21V87(M/G1Y<&4M/F=E=$AE
M861E<B@Q*3L*("`@("`@("`D=&AI<RT^7V%D9$]N3&]A9$IA=F%S8W)I<'0H
M)TAO<F1E7T9O<FU?07-S:6=N+G-E=$9I96QD*%PG)R`N("1F;F%M92`N("=<
M)RD[)RD["@H@("`@("`@(')E='5R;B`G/'1A8FQE/CQT<CX\=&0^)R`N"B`@
M("`@("`@("`@("<\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2(G("X@)&YA
M;64@+B`G7U]V86QU97,B("\^)R`N"B`@("`@("`@("`@('-P<FEN=&8H)SQS
M96QE8W0@;F%M93TB)7-?7VQE9G0B(&UU;'1I<&QE/2)M=6QT:7!L92(@<VEZ
M93TB)60B('-T>6QE/2)W:61T:#HE<R(E<SXG+`H@("`@("`@("`@("`@("`@
M("`@("1N86UE+"`D<VEZ92P@)'=I9'1H+`H@("`@("`@("`@("`@("`@("`@
M("1L:&1R(#\@)R!O;F-H86YG93TB2&]R9&5?1F]R;5]!<W-I9VXN9&5S96QE
M8W1(96%D97)S*%PG)R`N("1F;F%M92`N("=<)RP@,"D[(B<@.B`G)RD@+@H@
M("`@("`@("`@("`D=F%R+3YT>7!E+3YG971/<'1I;VYS*#`L("1F;F%M92D@
M+@H@("`@("`@("`@("`G/"]S96QE8W0^/"]T9#X\=&0^)R`N"B`@("`@("`@
M("`@("<\82!H<F5F/2(B(&]N8VQI8VL](DAO<F1E7T9O<FU?07-S:6=N+FUO
M=F4H7"<G("X@)&9N86UE("X*("`@("`@("`@("`@)UPG+"`P*3L@<F5T=7)N
M(&9A;'-E.R(^)R`N"B`@("`@("`@("`@($AO<F1E.CII;6<H)W)H86YD+G!N
M9R<L(%\H(D%D9"!C;VQU;6XB*2P@;G5L;"P@)')E9VES=')Y+3YG971);6%G
M941I<B@G:&]R9&4G*2D@+@H@("`@("`@("`@("`G/"]A/CQB<B`O/CQA(&AR
M968](B(@;VYC;&EC:STB2&]R9&5?1F]R;5]!<W-I9VXN;6]V92A<)R<@+@H@
M("`@("`@("`@("`D9FYA;64@+B`G7"<L(#$I.R!R971U<FX@9F%L<V4[(CXG
M("X*("`@("`@("`@("`@2&]R9&4Z.FEM9R@G;&AA;F0N<&YG)RP@7R@B4F5M
M;W9E(&-O;'5M;B(I+"!N=6QL+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H
M;W)D92<I*2`N"B`@("`@("`@("`@("<\+V$^/"]T9#X\=&0^)R`N"B`@("`@
M("`@("`@('-P<FEN=&8H)SQS96QE8W0@;F%M93TB)7-?7W)I9VAT(B!M=6QT
M:7!L93TB;75L=&EP;&4B('-I>F4](B5D(B!S='EL93TB=VED=&@Z)7,B)7,^
M)RP*("`@("`@("`@("`@("`@("`@("`D;F%M92P@)'-I>F4L("1W:61T:"P*
M("`@("`@("`@("`@("`@("`@("`D<FAD<B`_("<@;VYC:&%N9V4](DAO<F1E
M7T9O<FU?07-S:6=N+F1E<V5L96-T2&5A9&5R<RA<)R<@+B`D9FYA;64@+B`G
M7"<L(#$I.R(G(#H@)R<I("X*("`@("`@("`@("`@)'9A<BT^='EP92T^9V5T
M3W!T:6]N<R@Q+"`D9FYA;64I("X*("`@("`@("`@("`@)SPO<V5L96-T/CPO
M=&0^/"]T<CX\+W1A8FQE/B<["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E
M<E9A<DEN<'5T7VEN=F%L:60H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W)E;F1E<E9A<D1I<W!L87E?:6YV
M86QI9"@D9F]R;2P@)'9A<BP@)'9A<G,I.PH@("`@?0H*("`@(&9U;F-T:6]N
M(%]R96YD97)687));G!U=%]E;G5M*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*
M("`@('L*("`@("`@("`D=F%L=65S(#T@)'9A<BT^9V5T5F%L=65S*"D["B`@
M("`@("`@)'!R;VUP="`]("1V87(M/G1Y<&4M/F=E=%!R;VUP="@I.PH@("`@
M("`@("1H=&UL8VAA<G,@/2`D=F%R+3YG971/<'1I;VXH)VAT;6QC:&%R<R<I
M.PH@("`@("`@(&EF("@A96UP='DH)'!R;VUP="DI('L*("`@("`@("`@("`@
M)'!R;VUP="`]("<\;W!T:6]N('9A;'5E/2(B/B<@+B`H)&AT;6QC:&%R<R`_
M("1P<F]M<'0@.B!`:'1M;'-P96-I86QC:&%R<R@D<')O;7!T+"!%3E1?455/
M5$53+"`D=&AI<RT^7V-H87)S970I*2`N("<\+V]P=&EO;CXG.PH@("`@("`@
M('T*("`@("`@("`D=F%R;F%M92`]($!H=&UL<W!E8VEA;&-H87)S*"1V87(M
M/F=E=%9A<DYA;64H*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*
M("`@("`@("!R971U<FX@<W!R:6YT9B@G/'-E;&5C="!N86UE/2(E<R(@:60]
M(B5S(B`E<SXE<R5S/"]S96QE8W0^)RP*("`@("`@("`@("`@("`@("`@("`@
M("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP
M=',H)&9O<FTL("1V87(I+`H@("`@("`@("`@("`@("`@("`@("`@("1P<F]M
M<'0L"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S96QE8W1/<'1I
M;VYS*"1V86QU97,L("1V87(M/F=E=%9A;'5E*"1V87)S*2P@)&AT;6QC:&%R
M<RDI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]M;&5N
M=6TH)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V87)N
M86UE(#T@)'9A<BT^9V5T5F%R3F%M92@I.PH@("`@("`@("1H=F%R;F%M92`]
M($!H=&UL<W!E8VEA;&-H87)S*"1V87)N86UE+"!%3E1?455/5$53+"`D=&AI
M<RT^7V-H87)S970I.PH@("`@("`@("1V86QU97,@/2`D=F%R+3YG971686QU
M97,H*3L*("`@("`@("`D<')O;7!T<R`]("1V87(M/G1Y<&4M/F=E=%!R;VUP
M=',H*3L*("`@("`@("`D<V5L96-T960@/2`D=F%R+3YG971686QU92@D=F%R
M<RD["B`@("`@("`@+RH@268@<&%S<VEN9R!A(&YO;BUA<G)A>2!V86QU92!N
M965D('1O(&=E="!T:&4@:V5Y<RX@*B\*("`@("`@("!I9B`H(6ES7V%R<F%Y
M*"1S96QE8W1E9"DI('L*("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E<R!A
M<R`D:V5Y7S$@/3X@)'9A;'5E<U\R*2!["B`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)'9A;'5E<U\R6R1S96QE8W1E9%TI*2!["B`@("`@("`@("`@("`@
M("`@("`@)'-E;&5C=&5D(#T@87)R87DH)S$G(#T^("1K97E?,2P@)S(G(#T^
M("1S96QE8W1E9"D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("\J($AI9&1E;B!T86<@=&\@<W1O<F4@=&AE(&-U<G)E;G0@9FER<W0@;&5V
M96PN("HO"B`@("`@("`@)&AT;6P@/2!S<')I;G1F*"<\:6YP=70@='EP93TB
M:&ED9&5N(B!N86UE/2(E<UMO;&1=(B!V86QU93TB)7,B("5S("\^)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@)&AV87)N86UE+`H@("`@("`@("`@("`@
M("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D<V5L96-T961;)S$G72P@
M14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]G96Y)1"@D=F%R;F%M92`N("=;;VQD72<I*3L*
M"B`@("`@("`@+RH@1FER<W0@;&5V96PN("HO"B`@("`@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92]!<G)A>2YP:'`G.PH@("`@("`@("1V86QU97-?,2`]($AO
M<F1E7T%R<F%Y.CIV86QU97-4;TME>7,H87)R87E?:V5Y<R@D=F%L=65S*2D[
M"B`@("`@("`@)&AT;6P@+CT@<W!R:6YT9B@G/'-E;&5C="`E<R!N86UE/2(E
M<ULQ72(@;VYC:&%N9V4](B5S(B5S/B<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V=E;DE$*"1V87)N86UE("X@)ULQ72<I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@)&AV87)N86UE+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@)VEF("AT:&ES+G9A;'5E*2![(&1O8W5M96YT+B<@+B`D9F]R
M;2T^9V5T3F%M92@I("X@)RYF;W)M;F%M92YV86QU93U<)UPG.R<@+B`G9&]C
M=6UE;G0N)R`N("1F;W)M+3YG971.86UE*"D@+B`G+G-U8FUI="@I('TG+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@*"1V87(M/FAA<T%C=&EO;B@I(#\@
M)R`G("X@)'1H:7,M/E]G96Y!8W1I;VY38W)I<'0H)&9O<FTL("1V87(M/E]A
M8W1I;VXL("1V87)N86UE*2`Z("<G*2D["B`@("`@("`@:68@*"%E;7!T>2@D
M<')O;7!T<RDI('L*("`@("`@("`@("`@)&AT;6P@+CT@)SQO<'1I;VX@=F%L
M=64](B(^)R`N($!H=&UL<W!E8VEA;&-H87)S*"1P<F]M<'1S6S!=+"!%3E1?
M455/5$53+"`D=&AI<RT^7V-H87)S970I("X@)SPO;W!T:6]N/B<["B`@("`@
M("`@?0H@("`@("`@("1H=&UL("X]("1T:&ES+3Y?<V5L96-T3W!T:6]N<R@D
M=F%L=65S7S$L("1S96QE8W1E9%LG,2==*3L*("`@("`@("`D:'1M;"`N/2`G
M/"]S96QE8W0^)SL*"B`@("`@("`@+RH@4V5C;VYD(&QE=F5L+B`J+PH@("`@
M("`@("1H=&UL("X]('-P<FEN=&8H)SQS96QE8W0@)7,@;F%M93TB)7-;,ETB
M)7,^)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5N240H
M)'9A<FYA;64@+B`G6S)=)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`D
M:'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`H)'9A<BT^:&%S
M06-T:6]N*"D@/R`G("<@+B`D=&AI<RT^7V=E;D%C=&EO;E-C<FEP="@D9F]R
M;2P@)'9A<BT^7V%C=&EO;BP@)'9A<FYA;64I(#H@)R<I*3L*("`@("`@("!I
M9B`H(65M<'1Y*"1P<F]M<'1S*2D@>PH@("`@("`@("`@("`D:'1M;"`N/2`G
M/&]P=&EO;B!V86QU93TB(CXG("X@0&AT;6QS<&5C:6%L8VAA<G,H)'!R;VUP
M='-;,5TL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D@+B`G/"]O<'1I
M;VX^)SL*("`@("`@("!]"B`@("`@("`@)'9A;'5E<U\R(#T@87)R87DH*3L*
M("`@("`@("!I9B`H(65M<'1Y*"1S96QE8W1E9%LG,2==*2D@>PH@("`@("`@
M("`@("`D=F%L=65S7S(@/2`F)'9A;'5E<ULD<V5L96-T961;)S$G75T["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D:'1M;"`N("1T:&ES+3Y?<V5L96-T
M3W!T:6]N<R@D=F%L=65S7S(L("1S96QE8W1E9%LG,B==*2`N("<\+W-E;&5C
M=#XG.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]M=6QT
M:65N=6TH)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V
M86QU97,@/2`D=F%R+3YG971686QU97,H*3L*("`@("`@("`D<V5L96-T960@
M/2`D=F%R<RT^9V5T17AI<W1S*"1V87(M/F=E=%9A<DYA;64H*2P@)'=A<W-E
M="D["B`@("`@("`@:68@*"$D=V%S<V5T*2!["B`@("`@("`@("`@("1S96QE
M8W1E9"`]("1V87(M/F=E=$1E9F%U;'0H*3L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N('-P<FEN=&8H)SQS96QE8W0@;75L=&EP;&4](FUU;'1I<&QE(B!S
M:7IE/2(E<R(@;F%M93TB)7-;72(@)7,^)7,\+W-E;&5C=#XG+`H@("`@("`@
M("`@("`@("`@("`@("`@("AI;G0I)'9A<BT^='EP92T^<VEZ92P*("`@("`@
M("`@("`@("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG9716
M87).86UE*"DL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DL"B`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F
M;W)M+"`D=F%R*2P*("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VUU
M;'1I4V5L96-T3W!T:6]N<R@D=F%L=65S+"`D<V5L96-T960I*2`N"B`@("`@
M("`@("`@("(\8G(@+SY<;B(@+B!?*")4;R!S96QE8W0@;75L=&EP;&4@:71E
M;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA
M8RD@:V5Y('=H:6QE(&-L:6-K:6YG+B(I("X@(EQN(CL*("`@('T*"B`@("!F
M=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?<F%D:6\H)B1F;W)M+"`F)'9A<BP@
M)B1V87)S*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W)A9&EO0G5T
M=&]N<R@D=F%R+3YG971687).86UE*"DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1V87(M/F=E=%9A;'5E<R@I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%R+3YG971686QU92@D=F%R
M<RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BDI.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]R96YD97)687));G!U=%]S970H)B1F;W)M+"`F)'9A<BP@
M)B1V87)S*0H@("`@>PH@("`@("`@("1H=&UL(#T@)'1H:7,M/E]C:&5C:T)O
M>&5S*"1V87(M/F=E=%9A<DYA;64H*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=F%R+3YG971686QU97,H*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=F%R+3YG971686QU92@D=F%R<RDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G
M971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*2D["@H@("`@("`@(&EF("@D
M=F%R+3YT>7!E+3Y?8VAE8VM!;&PI('L*("`@("`@("`@("`@)&9O<FU?;F%M
M92`]("1F;W)M+3YG971.86UE*"D["B`@("`@("`@("`@("1V87)?;F%M92`]
M("1V87(M/F=E=%9A<DYA;64H*2`N("=;72<["B`@("`@("`@("`@("1F=6YC
M=&EO;E]N86UE(#T@)W-E;&5C="<@("X@)&9O<FU?;F%M92`N("1V87(M/F=E
M=%9A<DYA;64H*3L*("`@("`@("`@("`@)&5N86)L92`](%\H(E-E;&5C="!A
M;&PB*3L*("`@("`@("`@("`@)&1I<V%B;&4@/2!?*")396QE8W0@;F]N92(I
M.PH@("`@("`@("`@("`D:6YV97)T(#T@7R@B26YV97)T('-E;&5C=&EO;B(I
M.PH@("`@("`@("`@("`D:'1M;"`N/2`\/#Q%3U0*/'-C<FEP="!T>7!E/2)T
M97AT+VIA=F%S8W)I<'0B/@IF=6YC=&EO;B`D9G5N8W1I;VY?;F%M92@I"GL*
M("`@(&9O<B`H=F%R(&D@/2`P.R!I(#P@9&]C=6UE;G0N)&9O<FU?;F%M92YE
M;&5M96YT<RYL96YG=&@[(&DK*RD@>PH@("`@("`@(&8@/2!D;V-U;65N="XD
M9F]R;5]N86UE+F5L96UE;G1S6VE=.PH@("`@("`@(&EF("AF+FYA;64@(3T@
M)R1V87)?;F%M92<I('L*("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@
M?0H@("`@("`@(&EF("AA<F=U;65N=',N;&5N9W1H*2!["B`@("`@("`@("`@
M(&8N8VAE8VME9"`](&%R9W5M96YT<ULP73L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!F+F-H96-K960@/2`A9BYC:&5C:V5D.PH@("`@("`@('T*
M("`@('T*?0H\+W-C<FEP=#X*/&$@:')E9CTB(R(@;VYC;&EC:STB)&9U;F-T
M:6]N7VYA;64H=')U92D[(')E='5R;B!F86QS93LB/B1E;F%B;&4\+V$^+`H\
M82!H<F5F/2(C(B!O;F-L:6-K/2(D9G5N8W1I;VY?;F%M92AF86QS92D[(')E
M='5R;B!F86QS93LB/B1D:7-A8FQE/"]A/BP*/&$@:')E9CTB(R(@;VYC;&EC
M:STB)&9U;F-T:6]N7VYA;64H*3L@<F5T=7)N(&9A;'-E.R(^)&EN=F5R=#PO
M83X*14]4.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1H=&UL.PH@("`@
M?0H*("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]L:6YK*"8D9F]R;2P@
M)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]R
M96YD97)687)$:7-P;&%Y7VQI;FLH)&9O<FTL("1V87(L("1V87)S*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?:'1M;"@F)&9O<FTL
M("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<F5N9&5R5F%R1&ES<&QA>5]H=&UL*"1F;W)M+"`D=F%R+"`D=F%R<RD["B`@
M("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7V5M86EL*"8D9F]R
M;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("!R971U<FX@<W!R:6YT
M9B@G/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](B5S(B!I9#TB)7,B('9A;'5E
M/2(E<R(E<R`O/B<L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<BT^9V5T
M5F%R3F%M92@I+`H@("`@("`@("`@("`@("`@("`@("`@("1V87(M/F=E=%9A
M<DYA;64H*2P*("`@("`@("`@("`@("`@("`@("`@("`D=F%R+3YG971686QU
M92@D=F%R<RDL"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971!
M8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*2D["B`@("!]"@H@("`@9G5N8W1I
M;VX@7W)E;F1E<E9A<DEN<'5T7VUA=')I>"@F)&9O<FTL("8D=F%R+"`F)'9A
M<G,I"B`@("!["B`@("`@("`@)'9A<FYA;64@("`]("1V87(M/F=E=%9A<DYA
M;64H*3L*("`@("`@("`D=F%R7V%R<F%Y(#T@)'9A<BT^9V5T5F%L=64H)'9A
M<G,I.PH@("`@("`@("1C;VQS("`@("`@/2`D=F%R+3YT>7!E+3YG971#;VQS
M*"D["B`@("`@("`@)')O=W,@("`@("`]("1V87(M/G1Y<&4M/F=E=%)O=W,H
M*3L*("`@("`@("`D;6%T<FEX("`@(#T@)'9A<BT^='EP92T^9V5T36%T<FEX
M*"D["B`@("`@("`@)&YE=U]I;G!U="`]("1V87(M/G1Y<&4M/F=E=$YE=TEN
M<'5T*"D["@H@("`@("`@("1H=&UL(#T@)SQT86)L92!C96QL<W!A8VEN9STB
M,"(^/'1R/B<["@H@("`@("`@("1H=&UL("X]("<\=&0@86QI9VX](G)I9VAT
M(B!W:61T:#TB,C`E(CX\+W1D/B<["B`@("`@("`@9F]R96%C:"`H)&-O;',@
M87,@)&-O;%]T:71L92D@>PH@("`@("`@("`@("`D:'1M;"`N/2!S<')I;G1F
M*"<\=&0@86QI9VX](F-E;G1E<B(@=VED=&@](C$E)2(^)7,\+W1D/B<L("1C
M;VQ?=&ET;&4I.PH@("`@("`@('T*("`@("`@("`D:'1M;"`N/2`G/'1D(&%L
M:6=N/2)R:6=H="(@=VED=&@](C8P)2(^/"]T9#X\+W1R/B<["@H@("`@("`@
M("\J($]F9F5R(&$@;F5W(')O=R!O9B!D871A('1O(&)E(&%D9&5D('1O('1H
M92!M871R:7@_("HO"B`@("`@("`@:68@*"1N97=?:6YP=70I('L*("`@("`@
M("`@("`@)&AT;6P@+CT@)SQT<CX\=&0^)SL*("`@("`@("`@("`@:68@*&ES
M7V%R<F%Y*"1N97=?:6YP=70I*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N
M/2!S<')I;G1F*"<\<V5L96-T("5S(&YA;64](B5S6VY=6W)=(CX\;W!T:6]N
M('9A;'5E/2(B/B5S/"]O<'1I;VX^)7,\+W-E;&5C=#X\8G(@+SXG+`H@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5N240H)'9A<FYA;64@+B`G
M6VY=6W)=)RDL"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@
M("`@("`@("`@("`@("`@("`@("`@7R@B+2T@<V5L96-T("TM(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S96QE8W1/<'1I;VYS*"1N97=?
M:6YP=70L("1V87)?87)R87E;)VXG75LG<B==*2D["B`@("`@("`@("`@('T@
M96QS96EF("@D;F5W7VEN<'5T(#T]('1R=64I('L*("`@("`@("`@("`@("`@
M("1H=&UL("X]('-P<FEN=&8H)SQI;G!U="`E<R!T>7!E/2)T97AT(B!N86UE
M/2(E<UMN75MR72(@=F%L=64](B5S(B`O/B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]G96Y)1"@D=F%R;F%M92`N("=;;EU;<ETG*2P*("`@
M("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@
M("`@("`@("`D=F%R7V%R<F%Y6R=N)UU;)W(G72D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&AT;6P@+CT@)R`\+W1D/B<["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1C;VQS(&%S("1C;VQ?:60@/3X@)&-O;%]T:71L92D@>PH@("`@
M("`@("`@("`@("`@)&AT;6P@+CT@<W!R:6YT9B@G/'1D(&%L:6=N/2)C96YT
M97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@8VQA<W,](F-H96-K8F]X(B!N
M86UE/2(E<UMN75MV75LE<UTB("\^/"]T9#XG+"`D=F%R;F%M92P@)&-O;%]I
M9"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&AT;6P@+CT@)SQT9#X@
M/"]T9#X\+W1R/B<["B`@("`@("`@?0H*("`@("`@("`O*B!,;V]P('1H<F]U
M9V@@=&AE(')O=W,@86YD(&-R96%T92!C:&5C:V)O>&5S(&9O<B!E86-H(&-O
M;'5M;BX@*B\*("`@("`@("!F;W)E86-H("@D<F]W<R!A<R`D<F]W7VED(#T^
M("1R;W=?=&ET;&4I('L*("`@("`@("`@("`@)&AT;6P@+CT@<W!R:6YT9B@G
M/'1R/CQT9#XE<SPO=&0^)RP@)')O=U]T:71L92D["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1C;VQS(&%S("1C;VQ?:60@/3X@)&-O;%]T:71L92D@>PH@("`@
M("`@("`@("`@("`@)&AT;6P@+CT@<W!R:6YT9B@G/'1D(&%L:6=N/2)C96YT
M97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@8VQA<W,](F-H96-K8F]X(B!N
M86UE/2(E<UMR75LE<UU;)7-=(B5S("\^/"]T9#XG+"`D=F%R;F%M92P@)')O
M=U]I9"P@)&-O;%]I9"P@*"%E;7!T>2@D;6%T<FEX6R1R;W=?:61=6R1C;VQ?
M:61=*2`_("<@8VAE8VME9#TB8VAE8VME9"(G(#H@)R<I*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D:'1M;"`N/2`G/'1D/B`\+W1D/CPO='(^)SL*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:'1M;"`N("<\+W1A8FQE/B<[
M"B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7W!A<W-W;W)D
M*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D=F%R;F%M
M92`]($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA;64H*2P@14Y4
M7U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("!R971U<FX@<W!R
M:6YT9B@G/&EN<'5T('1Y<&4](G!A<W-W;W)D(B!N86UE/2(E<R(@:60](B5S
M(B!V86QU93TB)7,B)7,@+SXG+`H@("`@("`@("`@("`@("`@("`@("`@("1V
M87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@
M("`@("`@("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E
M=%9A;'5E*"1V87)S*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2P*
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP
M=',H)&9O<FTL("1V87(I*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R
M5F%R26YP=71?96UA:6QC;VYF:7)M*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*
M("`@('L*("`@("`@("`D96UA:6P@/2`D=F%R+3YG971686QU92@D=F%R<RD[
M"B`@("`@("`@)'9A<FYA;64@/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG
M971687).86UE*"DL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@
M("`@("`@<F5T=7)N('-P<FEN=&8H)SQI;G!U="!T>7!E/2)T97AT(B!N86UE
M/2(E<UMO<FEG:6YA;%TB(&ED/2(E<UMO<FEG:6YA;%TB('9A;'5E/2(E<R(E
M<R`O/B<L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@
M("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@
M("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)&5M86EL6R=O<FEG:6YA;"==+"!%
M3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I+`H@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BDI
M("X*("`@("`@("`@("`@)R`G("X@<W!R:6YT9B@G/&EN<'5T('1Y<&4](G1E
M>'0B(&YA;64](B5S6V-O;F9I<FU=(B!I9#TB)7-;8V]N9FER;5TB('9A;'5E
M/2(E<R(E<R`O/B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA
M;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)&5M86EL
M6R=C;VYF:7)M)UTL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971!8W1I;VY38W)I
M<'1S*"1F;W)M+"`D=F%R*2D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E
M<E9A<DEN<'5T7W!A<W-W;W)D8V]N9FER;2@F)&9O<FTL("8D=F%R+"`F)'9A
M<G,I"B`@("!["B`@("`@("`@)'!A<W-W;W)D(#T@)'9A<BT^9V5T5F%L=64H
M)'9A<G,I.PH@("`@("`@("1V87)N86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H
M)'9A<BT^9V5T5F%R3F%M92@I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S
M970I.PH@("`@("`@(')E='5R;B!S<')I;G1F*"<\:6YP=70@='EP93TB<&%S
M<W=O<F0B(&YA;64](B5S6V]R:6=I;F%L72(@:60](B5S6V]R:6=I;F%L72(@
M=F%L=64](B5S(B5S("\^)RP*("`@("`@("`@("`@("`@("`@("`@("`D=F%R
M;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@
M("`@("`@("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D<&%S<W=O<F1;
M)V]R:6=I;F%L)UTL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DL"B`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S
M*"1F;W)M+"`D=F%R*2D@+@H@("`@("`@("`@("`G("<@+B!S<')I;G1F*"<\
M:6YP=70@='EP93TB<&%S<W=O<F0B(&YA;64](B5S6V-O;F9I<FU=(B!I9#TB
M)7-;8V]N9FER;5TB('9A;'5E/2(E<R(E<R`O/B<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@0&AT;6QS
M<&5C:6%L8VAA<G,H)'!A<W-W;W)D6R=C;VYF:7)M)UTL($5.5%]154]415,L
M("1T:&ES+3Y?8VAA<G-E="DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*2D["B`@("!]
M"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7V)O;VQE86XH)B1F;W)M
M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V87)N86UE(#T@0&AT
M;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%3E1?455/5$53
M+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@("1H=&UL(#T@)SQI;G!U="!T
M>7!E/2)C:&5C:V)O>"(@8VQA<W,](F-H96-K8F]X(B!N86UE/2(G("X@("1V
M87)N86UE("X@)R(G("X*("`@("`@("`@("`@)R!I9#TB)R`N("1V87)N86UE
M("X@)R(G("X@*"1V87(M/F=E=%9A;'5E*"1V87)S*2`_("<@8VAE8VME9#TB
M8VAE8VME9"(G(#H@)R<I.PH@("`@("`@(&EF("@D=F%R+3YH87-!8W1I;VXH
M*2D@>PH@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7V=E;D%C=&EO;E-C
M<FEP="@D9F]R;2P@)'9A<BT^7V%C=&EO;BP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A<BT^9V5T5F%R3F%M92@I
M*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1H=&UL("X@)R`O/B<["B`@
M("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7V-R961I=&-A<F0H
M)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V87)N86UE
M(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%3E1?
M455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@("1H=&UL(#T@)SQI
M;G!U="!T>7!E/2)T97AT(B!N86UE/2(G("X@)'9A<FYA;64@+B`G(B!I9#TB
M)R`N("1V87)N86UE("X@)R(@=F%L=64](B<@+@H@("`@("`@("`@("!`:'1M
M;'-P96-I86QC:&%R<R@D=F%R+3YG971686QU92@D=F%R<RDL($5.5%]154]4
M15,L("1T:&ES+3Y?8VAA<G-E="D@+B`G(B<["B`@("`@("`@:68@*"1V87(M
M/FAA<T%C=&EO;B@I*2!["B`@("`@("`@("`@("1H=&UL("X]("1T:&ES+3Y?
M9V5N06-T:6]N4V-R:7!T*"1F;W)M+"`D=F%R+3Y?86-T:6]N+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%R+3YG
M971687).86UE*"DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&AT;6P@
M+B`G("\^)SL*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?
M;V)R;W=S97(H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@
M("1V87)N86UE(#T@)'9A<BT^9V5T5F%R3F%M92@I.PH@("`@("`@("1V87)V
M86QU92`]("1V87)S+3YG970H)'9A<FYA;64I.PH@("`@("`@("1F:65L9$ED
M(#T@)'1H:7,M/E]G96Y)1"AM9#4H=6YI<6ED*')A;F0H*2P@=')U92DI+"!F
M86QS92D@+B`G:60G.PH@("`@("`@("1H=&UL(#T@)PH@("`@("`@("`@("`\
M<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"B`@("`@("`@("`@('9A
M<B!O8G)O=W-E<E=I;F1O=TYA;64["B`@("`@("`@("`@(&9U;F-T:6]N(&]B
M<F]W<V5R0V%L;&)A8VLH;F%M92P@;VED*0H@("`@("`@("`@("!["B`@("`@
M("`@("`@("`@("!I9B`H;F%M92`]/2!O8G)O=W-E<E=I;F1O=TYA;64I('L*
M("`@("`@("`@("`@("`@("`@("!D;V-U;65N="YG971%;&5M96YT0GE)9"A<
M)R<@+B`D9FEE;&1)9"`N("=<)RDN=F%L=64@/2!O:60["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@(DEN=F%L:60@=VEN9&]W
M(&YA;64@<W5P<&QI960B.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@("`@(#PO<V-R:7!T/@H@("`@("`@("`@("`G.PH@("`@
M("`@("1H=&UL("X]('-P<FEN=&8H)SQI;G!U="!T>7!E/2)H:61D96XB(&YA
M;64](B5S(B!I9#TB)7,B)7,@=F%L=64](B5S(CXG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<FYA;64L($5.5%]1
M54]415,L("1T:&ES+3Y?8VAA<G-E="DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`D9FEE;&1)9"P*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D=F%R=F%L=64L($5.
M5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DI.PH@("`@("`@(&EF("@A96UP
M='DH)'9A<G9A;'5E*2D@>PH@("`@("`@("`@("`D:'1M;"`N/2`D=F%R=F%L
M=64["B`@("`@("`@?0H*("`@("`@("!I9B`H)$=,3T)!3%-;)V)R;W=S97(G
M72T^:&%S1F5A='5R92@G:F%V87-C<FEP="<I*2!["B`@("`@("`@("`@($AO
M<F1E.CIA9&138W)I<'1&:6QE*"=P;W!U<"YJ<R<L("=H;W)D92<L('1R=64I
M.PH@("`@("`@("`@("`D:6UG260@/2`D=&AI<RT^7V=E;DE$*"1V87)N86UE
M+"!F86QS92D@+B`G9V]T;R<["B`@("`@("`@("`@("1H=&UL("X]("<\9&EV
M(&ED/2)G;W1O(B!C;&%S<STB:&5A9&5R8F]X(B!S='EL93TB<&]S:71I;VXZ
M86)S;VQU=&4[=FES:6)I;&ET>3IH:61D96X[<&%D9&EN9SHP(CX\+V1I=CXG
M("X*("`@("`@("`@("`@("`@($AO<F1E.CIL:6YK*"<C)RP@7R@B4V5L96-T
M(&%N(&]B:F5C="(I+"`G)RP@)R<L("=O8G)O=W-E<E=I;F1O=R`]('!O<'5P
M*%PG)R`N("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G
M:&]R9&4G*2`N("<O<V5R=FEC97,O;V)R;W=S97(O)R`N("=<)RD[(&]B<F]W
M<V5R5VEN9&]W3F%M92`](&]B<F]W<V5R5VEN9&]W+FYA;64[(')E='5R;B!F
M86QS93LG*2`N($AO<F1E.CII;6<H)W1R964O;&5A9BYP;F<G+"!?*")/8FIE
M8W0B*2P@)VED/2(G("X@)&EM9TED("X@)R(@86QI9VX](FUI9&1L92(G+"`D
M1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H)VAO<F1E)RDI("X@
M(CPO83Y<;B(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&AT;6P["B`@
M("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7V1B;&]O:W5P*"8D
M9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]R96YD97)687));G!U=%]E;G5M*"1F;W)M+"`D=F%R+"`D=F%R<RD[
M"B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7V9I9VQE="@F
M)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A<FYA;64@
M/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971687).86UE*"DL($5.5%]1
M54]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@<F5T=7)N('-P<FEN
M=&8H)SQI;G!U="!T>7!E/2)T97AT(B!N86UE/2(E<R(@:60](B5S(B!S:7IE
M/2(E<R(@=F%L=64](B5S(B`O/B<L"B`@("`@("`@("`@("`@("`@("`@("`@
M)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@
M("`@("`@("`@("`@("`@("`@("`@<W1R;&5N*"1V87(M/G1Y<&4M/F=E=%1E
M>'0H*2DL"B`@("`@("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA
M<G,H)'9A<BT^9V5T5F%L=64H)'9A<G,I+"!%3E1?455/5$53+"`D=&AI<RT^
M7V-H87)S970I*2`N"B`@("`@("`@("`@("<\8G(@+SXG("X@7R@B16YT97(@
M=&AE(&QE='1E<G,@8F5L;W<Z(BD@+B`G/&)R("\^)R`N"B`@("`@("`@("`@
M("1T:&ES+3Y?<F5N9&5R5F%R1&ES<&QA>5]F:6=L970H)&9O<FTL("1V87(L
M("1V87)S*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA
M>41E9F%U;'0H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@
M(')E='5R;B!N;#)B<BA`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971686QU
M92@D=F%R<RDL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DI.PH@("`@
M?0H*("`@(&9U;F-T:6]N(%]R96YD97)687)$:7-P;&%Y7VAT;6PH)B1F;W)M
M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("\O(%-I;F-E('1H:7,@
M:7,@86X@2%1-3"!T>7!E('=E(&5X<&QI8VET;'D@9&]N)W0@97-C87!E"B`@
M("`@("`@+R\@:70N(%5S97(@8F5W87)E+@H@("`@("`@(')E='5R;B`D=F%R
M+3YG971686QU92@D=F%R<RD["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E
M<E9A<D1I<W!L87E?96UA:6PH)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@
M>PH@("`@("`@("1D:7-P;&%Y7V5M86EL(#T@)&5M86EL(#T@)'9A<BT^9V5T
M5F%L=64H)'9A<G,I.PH*("`@("`@("!I9B`H)'9A<BT^='EP92T^7W-T<FEP
M7V1O;6%I;B`F)B!S=')P;W,H)&5M86EL+"`G0"<I("$]/2!F86QS92D@>PH@
M("`@("`@("`@("`D9&ES<&QA>5]E;6%I;"`]('-T<E]R97!L86-E*&%R<F%Y
M*"=`)RP@)RXG*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@G("AA="D@)RP@)R`H9&]T*2`G*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D96UA:6PI.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"1V87(M/G1Y<&4M/E]L:6YK7V-O;7!O<V4I
M('L*("`@("`@("`@("`@)&5M86EL7W9A;"`]('1R:6TH)&5M86EL*3L*"B`@
M("`@("`@("`@("\O($9O<FUA="!T:&4@861D<F5S<R!A8V-O<F1I;F<@=&\@
M4D9#.#(R+@H@("`@("`@("`@("`D;6%I;&)O>%]H;W-T(#T@97AP;&]D92@G
M0"<L("1E;6%I;%]V86PI.PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1M86EL
M8F]X7VAO<W1;,5TI*2!["B`@("`@("`@("`@("`@("`D;6%I;&)O>%]H;W-T
M6S%=(#T@)R<["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1N86UE(#T@
M;G5L;#L*("`@("`@("`@("`@:68@*"1V87(M/G1Y<&4M/E]L:6YK7VYA;64I
M('L*("`@("`@("`@("`@("`@("1N86UE(#T@)'9A<BT^='EP92T^7VQI;FM?
M;F%M93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92]-24U%+G!H<"<["B`@("`@("`@("`@("1A9&1R97-S(#T@34E-
M13HZ<F9C.#(R5W)I=&5!9&1R97-S*"1M86EL8F]X7VAO<W1;,%TL("1M86EL
M8F]X7VAO<W1;,5TL("1N86UE*3L*"B`@("`@("`@("`@("\O($=E="!R:60@
M;V8@=&AE('1R86EL:6YG($`@*'=H96X@;F\@:&]S="!I<R!I;F-L=61E9"!I
M;@H@("`@("`@("`@("`O+R!T:&4@96UA:6P@861D<F5S<RDN"B`@("`@("`@
M("`@("1A9&1R97-S(#T@<W1R7W)E<&QA8V4H)T`^)RP@)SXG+"`D861D<F5S
M<RD["B`@("`@("`@("`@("1M86EL7VQI;FL@/2`D1TQ/0D%,4ULG<F5G:7-T
M<GDG72T^8V%L;"@G;6%I;"]C;VUP;W-E)RP@87)R87DH87)R87DH)W1O)R`]
M/B!A9&1S;&%S:&5S*"1A9&1R97-S*2DI*3L*("`@("`@("`@("`@:68@*&ES
M7V$H)&UA:6Q?;&EN:RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@)&UA:6Q?;&EN:R`]("=M86EL=&\Z)R`N('5R;&5N8V]D92@D861D<F5S
M<RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(')E='5R;B!(;W)D93HZ
M;&EN:R@D;6%I;%]L:6YK+"`D96UA:6Q?=F%L*2`N($!H=&UL<W!E8VEA;&-H
M87)S*"1D:7-P;&%Y7V5M86EL+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S
M970I("X@)SPO83XG.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B!N;#)B<BA`:'1M;'-P96-I86QC:&%R<R@D9&ES<&QA>5]E;6%I;"P@
M14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2D["B`@("`@("`@?0H@("`@
M?0H*("`@(&9U;F-T:6]N(%]R96YD97)687)$:7-P;&%Y7W!A<W-W;W)D*"8D
M9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("!R971U<FX@)RHJ
M*BHJ*BHJ)SL*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA
M>5]P87-S=V]R9&-O;F9I<FTH)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@
M>PH@("`@("`@(')E='5R;B`G*BHJ*BHJ*BHG.PH@("`@?0H*("`@(&9U;F-T
M:6]N(%]R96YD97)687)$:7-P;&%Y7V]C=&%L*"8D9F]R;2P@)B1V87(L("8D
M=F%R<RD*("`@('L*("`@("`@("!R971U<FX@<W!R:6YT9B@G,"5O)RP@;V-T
M9&5C*"1V87(M/F=E=%9A;'5E*"1V87)S*2DI.PH@("`@?0H*("`@(&9U;F-T
M:6]N(%]R96YD97)687)$:7-P;&%Y7V)O;VQE86XH)B1F;W)M+"`F)'9A<BP@
M)B1V87)S*0H@("`@>PH@("`@("`@(')E='5R;B`D=F%R+3YG971686QU92@D
M=F%R<RD@/R!?*")997,B*2`Z(%\H(DYO(BD["B`@("!]"@H@("`@9G5N8W1I
M;VX@7W)E;F1E<E9A<D1I<W!L87E?96YU;2@F)&9O<FTL("8D=F%R+"`F)'9A
M<G,I"B`@("!["B`@("`@("`@)'9A;'5E<R`]("1V87(M/F=E=%9A;'5E<R@I
M.PH@("`@("`@("1V86QU92`]("1V87(M/F=E=%9A;'5E*"1V87)S*3L*("`@
M("`@("!I9B`H8V]U;G0H)'9A;'5E<RD@/3T@,"D@>PH@("`@("`@("`@("!R
M971U<FX@7R@B3F\@=F%L=65S(BD["B`@("`@("`@?2!E;'-E:68@*&ES<V5T
M*"1V86QU97-;)'9A;'5E72D@)B8@)'9A;'5E("$]("<G*2!["B`@("`@("`@
M("`@(')E='5R;B!`:'1M;'-P96-I86QC:&%R<R@D=F%L=65S6R1V86QU95TL
M($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@?0H@("`@
M?0H*("`@(&9U;F-T:6]N(%]R96YD97)687)$:7-P;&%Y7W)A9&EO*"8D9F]R
M;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D=F%L=65S(#T@)'9A
M<BT^9V5T5F%L=65S*"D["B`@("`@("`@:68@*&-O=6YT*"1V86QU97,I(#T]
M(#`I('L*("`@("`@("`@("`@<F5T=7)N(%\H(DYO('9A;'5E<R(I.PH@("`@
M("`@('T@96QS96EF("AI<W-E="@D=F%L=65S6R1V87(M/F=E=%9A;'5E*"1V
M87)S*5TI*2!["B`@("`@("`@("`@(')E='5R;B!`:'1M;'-P96-I86QC:&%R
M<R@D=F%L=65S6R1V87(M/F=E=%9A;'5E*"1V87)S*5TL($5.5%]154]415,L
M("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T
M:6]N(%]R96YD97)687)$:7-P;&%Y7VUU;'1I96YU;2@F)&9O<FTL("8D=F%R
M+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A;'5E<R`]("1V87(M/F=E=%9A
M;'5E<R@I.PH@("`@("`@("1O;B`]("1V87(M/F=E=%9A;'5E*"1V87)S*3L*
M("`@("`@("!I9B`H(6-O=6YT*"1V86QU97,I('Q\("%C;W5N="@D;VXI*2![
M"B`@("`@("`@("`@(')E='5R;B!?*").;R!V86QU97,B*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D9&ES<&QA>2`](&%R<F%Y*"D["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1V86QU97,@87,@)'9A;'5E(#T^("1N86UE*2![
M"B`@("`@("`@("`@("`@("!I9B`H:6Y?87)R87DH)'9A;'5E+"`D;VXI*2![
M"B`@("`@("`@("`@("`@("`@("`@)&1I<W!L87E;72`]("1N86UE.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R
M;B!`:'1M;'-P96-I86QC:&%R<RAI;7!L;V1E*"<L("<L("1D:7-P;&%Y*2P@
M14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("!]"B`@("!]
M"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<D1I<W!L87E?<V5T*"8D9F]R;2P@
M)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D=F%L=65S(#T@)'9A<BT^
M9V5T5F%L=65S*"D["B`@("`@("`@)&]N(#T@)'9A<BT^9V5T5F%L=64H)'9A
M<G,I.PH@("`@("`@(&EF("@A8V]U;G0H)'9A;'5E<RD@?'P@(6-O=6YT*"1O
M;BDI('L*("`@("`@("`@("`@<F5T=7)N(%\H(DYO('9A;'5E<R(I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1D:7-P;&%Y(#T@87)R87DH*3L*
M("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E<R!A<R`D=F%L=64@/3X@)&YA
M;64I('L*("`@("`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D=F%L=64L("1O
M;BDI('L*("`@("`@("`@("`@("`@("`@("`D9&ES<&QA>5M=(#T@)&YA;64[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@
M<F5T=7)N($!H=&UL<W!E8VEA;&-H87)S*&EM<&QO9&4H)RP@)RP@)&1I<W!L
M87DI+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@('T*
M("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA>5]I;6%G92@F
M)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)&EM9U]P87)A
M;7,@/2`D=F%R+3YG971686QU92@D=F%R<RD["B`@("`@("`@)&EM9U]U<FP@
M/2!(;W)D93HZ=7)L*"1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O
M;W0G+"`G:&]R9&4G*2`N("<O<V5R=FEC97,O:6UA9V5S+W9I97<N<&AP)RD[
M"B`@("`@("`@)&EM9U]U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)&EM9U]U
M<FPL("1I;6=?<&%R86US*3L*"B`@("`@("`@<F5T=7)N($AO<F1E.CII;6<H
M)&EM9U]U<FPL(&ES<V5T*"1I;6=?<&%R86US6R=F)UTI(#\@)&EM9U]P87)A
M;7-;)V8G72`Z("<G+"`G)RP@)R<I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R
M96YD97)687)$:7-P;&%Y7V-E;&QP:&]N92@F)&9O<FTL("8D=F%R+"`F)'9A
M<G,I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@
M)&YU;6)E<B`]("1V87(M/F=E=%9A;'5E*"1V87)S*3L*("`@("`@("`D:'1M
M;"`]($!H=&UL<W!E8VEA;&-H87)S*"1N=6UB97(L($5.5%]154]415,L("1T
M:&ES+3Y?8VAA<G-E="D["@H@("`@("`@(&EF("@D;G5M8F5R("8F("1R96=I
M<W1R>2T^:&%S365T:&]D*"=S;7,O8V]M<&]S92<I*2!["B`@("`@("`@("`@
M("1U<FP@/2`D<F5G:7-T<GDM/FQI;FLH)W-M<R]C;VUP;W-E)RP@87)R87DH
M)W1O)R`]/B`D;G5M8F5R*2D["B`@("`@("`@("`@("1H=&UL("X]("<@)R`N
M($AO<F1E.CIL:6YK*"1U<FPL(%\H(E-E;F0@4TU3(BDI("X@2&]R9&4Z.FEM
M9R@G;6]B:6QE+G!N9R<L(%\H(E-E;F0@4TU3(BDL("<G+"`D<F5G:7-T<GDM
M/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N("<\+V$^)SL*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D:'1M;#L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N
M9&5R5F%R1&ES<&QA>5]A9&1R97-S*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*
M("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`D861D
M<F5S<R`]("1V87(M/F=E=%9A;'5E*"1V87)S*3L*("`@("`@("`D875S7W-T
M871E7W)E9V5X(#T@)R@_.D%#5'Q.4U=\3E1\44Q$?%-!?%1!4WQ624-\5T$I
M)SL*"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R\H*#\Z05M"3%U\0EM!0D1(
M3$Y24U1=/WQ#6T%"1DA-3U)45E==?$1;041%1TA,3E1977Q%6T-(3EA=/WQ&
M6TM977Q'6TQ565T_?$A;041'4%)355A=?$E;1TU05EU\2D5\2UM!5%=977Q,
M6T%$14Q.4U5=/WQ-6T5+3%T_?$Y;14=.4%)773]\3UM,6%U\4%M!14A,3U)=
M?%);1TA-77Q36T%%1TM,34Y/4%)35%=973]\5%M!1$9.45)35UU\54)\5UM!
M0T1&3E)35ET_?%E/?%I%*5QD*#\Z7&1\6T$M6ETI/R!<9%M!+5I=>S)]*2\G
M+"`D861D<F5S<RP@)'!O<W1C;V1E*2D@>PH@("`@("`@("`@("`O*B!52R!P
M;W-T8V]D92!D971E8W1E9"X@*B\*("`@("`@("`@("`@+RH@375L=&EM87`N
M8V\N=6L@9V5N97)A=&5D(&UA<"`J+PH@("`@("`@("`@("`D;6%P=7)L(#T@
M)VAT='`Z+R]W=W<N;75L=&EM87`N8V]M+VUA<"]B<F]W<V4N8V=I/W!C/2<@
M+B!U<FQE;F-O9&4H)'!O<W1C;V1E6S%=*3L*("`@("`@("`@("`@)&1E<V,@
M/2!?*")-=6QT:6UA<"!52R!M87`B*3L*("`@("`@("`@("`@)&EC;VX@/2`G
M;6%P+G!N9R<["B`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)R]<8B<@
M+B`D875S7W-T871E7W)E9V5X("X@)UQB+R<L("1A9&1R97-S*2D@>PH@("`@
M("`@("`@("`O*B!!=7-T<F%L:6%N('-T871E(&1E=&5C=&5D+B`J+PH@("`@
M("`@("`@("`O*B!7:&5R96ES+F-O;2YA=2!G96YE<F%T960@;6%P("HO"B`@
M("`@("`@("`@("1M87!U<FP@/2`G:'1T<#HO+W=W=RYW:&5R96ES+F-O;2YA
M=2]W:&5R96ES+VUA<'!I;F<O9V5O8V]D94%D9')E<W,N9&\_)SL*("`@("`@
M("`@("`@)&1E<V,@/2!?*")7:&5R96ES($%U<W1R86QI82!M87`B*3L*("`@
M("`@("`@("`@)&EC;VX@/2`G;6%P+G!N9R<["B`@("`@("`@("`@("\J(%-P
M;&ET(&]U="!T:&4@861D<F5S<RP@;&EN92UB>2UL:6YE+B`J+PH@("`@("`@
M("`@("`D861D<F5S<TQI;F5S(#T@97AP;&]D92@B7&XB+"`D861D<F5S<RD[
M"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1A9&1R97-S
M3&EN97,I.R`D:2LK*2!["B`@("`@("`@("`@("`@("`O*B!3964@:68@:70G
M<R!T:&4@<W1R965T(&YU;6)E<B`F(&YA;64N("HO"B`@("`@("`@("`@("`@
M("!I9B`H<')E9U]M871C:"@G+RA<9"M<<RI<+UQS*BD_*%QD*WQ<9"M;82UZ
M02U:72E<<RLH6V$M>D$M6B!=*BDO)RP@)&%D9')E<W-,:6YE<ULD:5TL("1L
M:6YE4&%R=',I*2!["B`@("`@("`@("`@("`@("`@("`@)&UA<'5R;"`N/2`G
M)G-T<F5E=$YU;6)E<CTG("X@=7)L96YC;V1E*"1L:6YE4&%R='-;,ETI("X@
M)R9S=')E971.86UE/2<@+B!U<FQE;F-O9&4H)&QI;F5087)T<ULS72D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`O*B!,;V]K(&9O<B`B
M4W5B=7)B+"!3=&%T92(N("HO"B`@("`@("`@("`@("`@("!I9B`H<')E9U]M
M871C:"@G+RA;82UZ02U:(%TJ*2P_7',K)R`N("1A=7-?<W1A=&5?<F5G97@@
M+B`G+R<L("1A9&1R97-S3&EN97-;)&E=+"`D;&EN95!A<G1S*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1M87!U<FP@+CT@)R9S=6)U<F(])R`N('5R;&5N
M8V]D92@D;&EN95!A<G1S6S%=*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("\J($QO;VL@9F]R(")3=&%T92`\-"!D:6=I="!P;W-T8V]D
M93XB+B`J+PH@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R\H)R`N
M("1A=7-?<W1A=&5?<F5G97@@+B`G*5QS*RA<9'LT?2DO)RP@)&%D9')E<W-,
M:6YE<ULD:5TL("1L:6YE4&%R=',I*2!["B`@("`@("`@("`@("`@("`@("`@
M)&UA<'5R;"`N/2`G)G-T871E/2<@+B!U<FQE;F-O9&4H)&QI;F5087)T<ULQ
M72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V5I9B`H<')E9U]M871C:"@G+R@N*BE<;B@N*BE<<RHL7',J*%QW*RE<
M+C]<<RLH7&0K?%MA+7I!+5I=7&1;82UZ02U:75QS/UQD6V$M>D$M6EU<9"DO
M)RP@)&%D9')E<W,L("1A9&1R97-S4&%R=',I*2!["B`@("`@("`@("`@("\J
M($%M97)I8V%N+T-A;F%D:6%N(&%D9')E<W,@<W1Y;&4N("HO"B`@("`@("`@
M("`@("\J($UA<'%U97-T(&=E;F5R871E9"!M87`@*B\*("`@("`@("`@("`@
M)&UA<'5R;"`]("=H='1P.B\O=W=W+FUA<'%U97-T+F-O;2]M87!S+VUA<"YA
M9'`_<VEZ93UB:6<F>F]O;3TW)SL*("`@("`@("`@("`@)&1E<V,@/2!?*")-
M87!1=65S="!M87`B*3L*("`@("`@("`@("`@)&EC;VX@/2`G;6%P+G!N9R<[
M"B`@("`@("`@("`@("1C;W5N=')Y(#T@;G5L;#L*("`@("`@("`@("`@:68@
M*"%E;7!T>2@D861D<F5S<U!A<G1S6S1=*2`F)B!P<F5G7VUA=&-H*"=\6V$M
M>D$M6EU<9%MA+7I!+5I=7',_7&1;82UZ02U:75QD?"<L("1A9&1R97-S4&%R
M='-;-%TI*2!["B`@("`@("`@("`@("`@("`D8V]U;G1R>2`]("=#02<["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%E;7!T>2@D861D<F5S<U!A
M<G1S6S%=*2D@>PH@("`@("`@("`@("`@("`@)&UA<'5R;"`N/2`G)F%D9')E
M<W,])R`N('5R;&5N8V]D92@D861D<F5S<U!A<G1S6S%=*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H(65M<'1Y*"1A9&1R97-S4&%R='-;,ETI
M*2!["B`@("`@("`@("`@("`@("`D;6%P=7)L("X]("<F8VET>3TG("X@=7)L
M96YC;V1E*"1A9&1R97-S4&%R='-;,ETI.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("@A96UP='DH)&%D9')E<W-087)T<ULS72DI('L*("`@("`@
M("`@("`@("`@("1M87!U<FP@+CT@)R9S=&%T93TG("X@=7)L96YC;V1E*"1A
M9&1R97-S4&%R='-;,UTI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("@A96UP='DH)&%D9')E<W-087)T<ULT72DI('L*("`@("`@("`@("`@("`@
M(&EF("@D8V]U;G1R>2`]/2`G0T$G*2!["B`@("`@("`@("`@("`@("`@("`@
M)&UA<'5R;"`N/2`G)F-O=6YT<GD]0T$G.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)&UA<'5R;"`N/2`G)GII<&-O9&4])R`N('5R;&5N
M8V]D92@D861D<F5S<U!A<G1S6S1=*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@+RH@66%H;V\A(&=E;F5R871E9"!M87`N("HO"B`@("`@("`@("`@
M("1M87!U<FPR(#T@)VAT='`Z+R]U<RYR9"YY86AO;RYC;VTO;6%P<R]H;VUE
M+W-U8FUI=%]A+RHM:'1T<#HO+VUA<',N>6%H;V\N8V]M+VUA<',_<W)C:'1Y
M<&4]829G971M87`]1V5T*TUA<"8G.PH@("`@("`@("`@("`D9&5S8S(@/2!?
M*")986AO;R$@;6%P(BD["B`@("`@("`@("`@("1I8V]N,B`]("=M87`N<&YG
M)SL*("`@("`@("`@("`@:68@*"%E;7!T>2@D861D<F5S<U!A<G1S6S%=*2D@
M>PH@("`@("`@("`@("`@("`@)&UA<'5R;#(@+CT@)R9A9&1R/2<@+B!U<FQE
M;F-O9&4H)&%D9')E<W-087)T<ULQ72D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@+RH@1VEV92!P<F5C961E;F-E('1O('II<&-O9&4@;W9E<B!C:71Y
M+W-T871E("HO"B`@("`@("`@("`@(&EF("AE;7!T>2@D861D<F5S<U!A<G1S
M6S1=*2`F)B`A96UP='DH)&%D9')E<W-087)T<ULR72D@)B8@(65M<'1Y*"1A
M9&1R97-S4&%R='-;,UTI*2!["B`@("`@("`@("`@("`@("`D;6%P=7)L,B`N
M/2`G)F-S>CTG("X@=7)L96YC;V1E*"1A9&1R97-S4&%R='-;,ET@+B`G("<@
M+B`D861D<F5S<U!A<G1S6S-=*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1A9&1R97-S4&%R='-;-%TI*2!["B`@("`@("`@("`@
M("`@("!I9B`H<')E9U]M871C:"@G?"A;82UZ02U:75QD6V$M>D$M6ETI7',_
M*%QD6V$M>D$M6EU<9"E\)RP@)&%D9')E<W-087)T<ULT72P@)'!C4&%R=',I
M*2!["B`@("`@("`@("`@("`@("`@("`@)&UA<'5R;#(@+CT@)R9C;W5N=')Y
M/6-A)SL*("`@("`@("`@("`@("`@("`@("`O*B!M86ME('-U<F4@=&AE('!O
M<W1A;"UC;V1E(&AA<R!A('-P86-E("HO"B`@("`@("`@("`@("`@("`@("`@
M)&%D9')E<W-087)T<ULT72`]("1P8U!A<G1S6S%=("X@)R`G("X@)'!C4&%R
M='-;,ET["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D;6%P
M=7)L,B`N/2`G)F-S>CTG("X@=7)L96YC;V1E*"1A9&1R97-S4&%R='-;-%TI
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!';V]G;&4@9V5N97)A
M=&5D(&UA<"X@*B\*("`@("`@("`@("`@)&UA<'5R;#,@/2`G:'1T<#HO+VUA
M<',N9V]O9VQE+F-O;2]M87!S/W$])R`N('5R;&5N8V]D92@D861D<F5S<U!A
M<G1S6S!=*2`N("<F:&P]96XG.PH@("`@("`@("`@("`D9&5S8S,@/2!?*")'
M;V]G;&4@36%P<R(I.PH@("`@("`@("`@("`D:6-O;C,@/2`G;6%P+G!N9R<[
M"@H@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"<O*"XJ/RE<<C]<;BA;
M02U:77LQ+#-]*2TH7&1[-7TI7',K*"XJ*2]I)RP@)&%D9')E<W,L("1A9&1R
M97-S4&%R=',I*2!["B`@("`@("`@("`@("\J($5U<F]P96%N(&%D9')E<W,@
M<W1Y;&4N("HO"B`@("`@("`@("`@(&EN8VQU9&4@)TAO<F1E+TY,4R]C87)S
M:6=N<RYP:'`G.PH@("`@("`@("`@("`D8V]U;G1R>2`](&%R<F%Y7W-E87)C
M:"A3=')I;F<Z.G5P<&5R*"1A9&1R97-S4&%R='-;,ETI+"`D8V%R<VEG;G,I
M.PH*("`@("`@("`@("`@+RH@36%P,C0@9V5N97)A=&5D(&UA<"X@*B\*("`@
M("`@("`@("`@:68@*&EN7V%R<F%Y*"1C;W5N=')Y+"!A<G)A>2@G86PG+"`G
M860G+"`G86TG+"`G87HG+"`G8F4G+"`G8F$G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=B9R<L("=D92<L("=D:R<L("=E
M92<L("=F;R<L("=F:2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V9R)RP@)V=E)RP@)V=R)RP@)V=B)RP@)VEE)RP@)VES
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M:70G+"`G:'(G+"`G;'8G+"`G;&DG+"`G;'0G+"`G;'4G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M="<L("=M:R<L("=M
M9"<L("=M8R<L("=N;"<L("=N;R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W!L)RP@)W!T)RP@)W)O)RP@)W)U)RP@)W-E
M)RP@)V-H)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G8W,G+"`G<VLG+"`G<VDG+"`G97,G+"`G8WHG+"`G='(G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U82<L("=H
M=2<L("=B>2<L("=C>2<L("=A="<I*2D@>PH@("`@("`@("`@("`@("`@:68@
M*&EN7V%R<F%Y*"1C;W5N=')Y+"!A<G)A>2@G870G+"`G8F4G+"`G8V@G+"`G
M9&4G+"`G9&LG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G97,G+"`G9FDG+"`G9G(G+"`G:70G+"`G;FPG+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;F\G
M+"`G<V4G*2DI('L*("`@("`@("`@("`@("`@("`@("`D;6ER<F]R(#T@)&-O
M=6YT<GD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1M:7)R;W(@/2`G=6LG.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@)&UA<'5R;"`]("=H='1P.B\O=W=W+B<@+B`D;6ER<F]R
M("X@)RYM87`R-"YC;VTO<V]U<F-E+V%D9')E<W,O=C(N,"XP+V-N=%]N879?
M;6%P;&5T+G!H<#]C:60]=F%L:61A=&5A9&1R)F-O=6YT<GD])R`N("1C;W5N
M=')Y.PH@("`@("`@("`@("`@("`@)&1E<V,@/2!?*")-87`R-"!M87`B*3L*
M("`@("`@("`@("`@("`@("1I8V]N(#T@)VUA<%]E=2YP;F<G.PH@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D861D<F5S<U!A<G1S6S%=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1M87!U<FP@+CT@)R9S=')E970])R`N('5R;&5N
M8V]D92@D861D<F5S<U!A<G1S6S%=*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&EF("@A96UP='DH)&%D9')E<W-087)T<ULS72DI('L*
M("`@("`@("`@("`@("`@("`@("`D;6%P=7)L("X]("<F>FEP/2<@+B!U<FQE
M;F-O9&4H)&%D9')E<W-087)T<ULS72D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1A9&1R97-S4&%R='-;-%TI*2![
M"B`@("`@("`@("`@("`@("`@("`@)&UA<'5R;"`N/2`G)F-I='D])R`N('5R
M;&5N8V]D92@D861D<F5S<U!A<G1S6S1=*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@36%P<75E<W0@9V5N97)A
M=&5D(&UA<"X@*B\*("`@("`@("`@("`@)&UA<'5R;#(@/2`G:'1T<#HO+W=W
M=RYM87!Q=65S="YC;VTO;6%P<R]M87`N861P/V-O=6YT<GD])R`N(%-T<FEN
M9SHZ=7!P97(H)&-O=6YT<GDI.PH@("`@("`@("`@("`D9&5S8S(@/2!?*")-
M87!1=65S="!M87`B*3L*("`@("`@("`@("`@)&EC;VXR(#T@)VUA<%]E=2YP
M;F<G.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1A9&1R97-S4&%R='-;,5TI
M*2!["B`@("`@("`@("`@("`@("`D;6%P=7)L,B`N/2`G)F%D9')E<W,])R`N
M('5R;&5N8V]D92@D861D<F5S<U!A<G1S6S%=*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1A9&1R97-S4&%R='-;,UTI*2!["B`@
M("`@("`@("`@("`@("`D;6%P=7)L,B`N/2`G)GII<&-O9&4])R`N('5R;&5N
M8V]D92@D861D<F5S<U!A<G1S6S-=*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1A9&1R97-S4&%R='-;-%TI*2!["B`@("`@("`@
M("`@("`@("`D;6%P=7)L,B`N/2`G)F-I='D])R`N('5R;&5N8V]D92@D861D
M<F5S<U!A<G1S6S1=*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@)&AT;6P@/2!N;#)B<BA`:'1M;'-P96-I86QC:&%R<R@D861D<F5S<RP@
M14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2D["B`@("`@("`@:68@*"%E
M;7!T>2@D;6%P=7)L*2D@>PH@("`@("`@("`@("`D:'1M;"`N/2`G)FYB<W`[
M)FYB<W`[)R`N($AO<F1E.CIL:6YK*$AO<F1E.CIE>'1E<FYA;%5R;"@D;6%P
M=7)L*2P@)&1E<V,L(&YU;&PL("=?8FQA;FLG*2`N($AO<F1E.CII;6<H)&EC
M;VXL("1D97-C+"`G86QI9VX](FUI9&1L92(G+"`D<F5G:7-T<GDM/F=E=$EM
M86=E1&ER*"=H;W)D92<I*2`N("<\+V$^)SL*("`@("`@("!]"B`@("`@("`@
M:68@*"%E;7!T>2@D;6%P=7)L,BDI('L*("`@("`@("`@("`@)&AT;6P@+CT@
M)R9N8G-P.R<@+B!(;W)D93HZ;&EN:RA(;W)D93HZ97AT97)N86Q5<FPH)&UA
M<'5R;#(I+"`D9&5S8S(L(&YU;&PL("=?8FQA;FLG*2`N($AO<F1E.CII;6<H
M)&EC;VXR+"`D9&5S8S(L("=A;&EG;CTB;6ED9&QE(B<L("1R96=I<W1R>2T^
M9V5T26UA9V5$:7(H)VAO<F1E)RDI("X@)SPO83XG.PH@("`@("`@('T*("`@
M("`@("!I9B`H(65M<'1Y*"1M87!U<FPS*2D@>PH@("`@("`@("`@("`D:'1M
M;"`N/2`G)FYB<W`[)R`N($AO<F1E.CIL:6YK*$AO<F1E.CIE>'1E<FYA;%5R
M;"@D;6%P=7)L,RDL("1D97-C,RP@;G5L;"P@)U]B;&%N:R<I("X@2&]R9&4Z
M.FEM9R@D:6-O;C,L("1D97-C,RP@)V%L:6=N/2)M:61D;&4B)RP@)')E9VES
M=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D@+B`G/"]A/B<["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&AT;6P["B`@("!]"@H@("`@9G5N8W1I;VX@
M7W)E;F1E<E9A<D1I<W!L87E?9&%T92@F)&9O<FTL("8D=F%R+"`F)'9A<G,I
M"B`@("!["B`@("`@("`@<F5T=7)N(&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^
M='EP92T^9V5T1F]R;6%T=&5D5&EM92@D=F%R+3YG971686QU92@D=F%R<RDI
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA>5]H;W5R
M;6EN=71E<V5C;VYD*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@
M("`@("`D=&EM92`]("1V87(M/G1Y<&4M/F=E=%1I;65087)T<R@D=F%R+3YG
M971686QU92@D=F%R<RDI.PH@("`@("`@(&EF("@A)'9A<BT^='EP92T^7W-H
M;W=?<V5C;VYD<RD@>PH@("`@("`@("`@("!R971U<FX@*&EN="DD=&EM95LG
M:&]U<B==("X@)SHG("X@<W!R:6YT9B@G)3`R9"<L("AI;G0I)'1I;65;)VUI
M;G5T92==*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M*&EN="DD=&EM95LG:&]U<B==("X@)SHG("X@<W!R:6YT9B@G)3`R9"<L("AI
M;G0I)'1I;65;)VUI;G5T92==*2`N("<Z)R`N('-P<FEN=&8H)R4P,F0G+"`H
M:6YT*21T:6UE6R=S96-O;F0G72D["B`@("`@("`@?0H@("`@?0H*("`@(&9U
M;F-T:6]N(%]R96YD97)687)$:7-P;&%Y7VUO;G1H>65A<B@F)&9O<FTL("8D
M=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@<F5T=7)N("AI;G0I)'9A<G,M
M/F=E="@D=F%R+3YG971687).86UE*"D@+B`G6VUO;G1H72<I("X@)RP@)R`N
M("AI;G0I)'9A<G,M/F=E="@D=F%R+3YG971687).86UE*"D@+B`G6WEE87)=
M)RD["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<D1I<W!L87E?;6]N
M=&AD87EY96%R*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@
M("`D9&%T92`]("1V87(M/F=E=%9A;'5E*"1V87)S*3L*("`@("`@("!I9B`H
M*&ES7V%R<F%Y*"1D871E*2`F)B`A96UP='DH)&1A=&5;)WEE87(G72D@)B8*
M("`@("`@("`@("`@("%E;7!T>2@D9&%T95LG;6]N=&@G72D@)B8@(65M<'1Y
M*"1D871E6R=D87DG72DI"B`@("`@("`@("`@('Q\("@A:7-?87)R87DH)&1A
M=&4I("8F("%E;7!T>2@D9&%T92DI*2!["B`@("`@("`@("`@(')E='5R;B`D
M=F%R+3YT>7!E+3YF;W)M871$871E*"1D871E*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("<G.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687)$
M:7-P;&%Y7VEN=F%L:60H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@
M("`@("`@(')E='5R;B`G/'-P86X@8VQA<W,](F9O<FTM97)R;W(B/B<@+B!`
M:'1M;'-P96-I86QC:&%R<R@D=F%R+3YT>7!E+3YM97-S86=E+"!%3E1?455/
M5$53+"`D=&AI<RT^7V-H87)S970I("X@)SPO<W!A;CXG.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]R96YD97)687)$:7-P;&%Y7VQI;FLH)B1F;W)M+"`F)'9A
M<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V86QU97,@/2`D=F%R+3YT>7!E
M+3YV86QU97,["B`@("`@("`@:68@*"%I<W-E="@D=F%L=65S6S!=*2D@>PH@
M("`@("`@("`@("`D=F%L=65S(#T@87)R87DH)'9A;'5E<RD["B`@("`@("`@
M?0H*("`@("`@("`D8V]U;G0@/2!C;W5N="@D=F%L=65S*3L*("`@("`@("`D
M:'1M;"`]("<G.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C;W5N=#L@
M)&DK*RD@>PH@("`@("`@("`@("!I9B`H96UP='DH)'9A;'5E<ULD:5U;)W5R
M;"==*2!\?"!E;7!T>2@D=F%L=65S6R1I75LG=&5X="==*2D@>PH@("`@("`@
M("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*"%I<W-E="@D=F%L=65S6R1I75LG=&%R9V5T)UTI*2!["B`@("`@("`@
M("`@("`@("`D=F%L=65S6R1I75LG=&%R9V5T)UT@/2`G)SL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1V86QU97-;)&E=6R=O;F-L
M:6-K)UTI*2!["B`@("`@("`@("`@("`@("`D=F%L=65S6R1I75LG;VYC;&EC
M:R==(#T@)R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%I<W-E
M="@D=F%L=65S6R1I75LG=&ET;&4G72DI('L*("`@("`@("`@("`@("`@("1V
M86QU97-;)&E=6R=T:71L92==(#T@)R<["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*"%I<W-E="@D=F%L=65S6R1I75LG86-C97-S:V5Y)UTI*2![
M"B`@("`@("`@("`@("`@("`D=F%L=65S6R1I75LG86-C97-S:V5Y)UT@/2`G
M)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&D@/B`P*2!["B`@
M("`@("`@("`@("`@("`D:'1M;"`N/2`G('P@)SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D:'1M;"`N/2!(;W)D93HZ;&EN:R@D=F%L=65S6R1I75LG
M=7)L)UTL("1V86QU97-;)&E=6R=T97AT)UTL("=W:61G970G+"`D=F%L=65S
M6R1I75LG=&%R9V5T)UTL("1V86QU97-;)&E=6R=O;F-L:6-K)UTL("1V86QU
M97-;)&E=6R=T:71L92==+"`D=F%L=65S6R1I75LG86-C97-S:V5Y)UTI("X@
M0&AT;6QS<&5C:6%L8VAA<G,H)'9A;'5E<ULD:5U;)W1E>'0G72P@14Y47U%5
M3U1%4RP@)'1H:7,M/E]C:&%R<V5T*2`N("<\+V$^)SL*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D:'1M;#L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N
M9&5R5F%R1&ES<&QA>5]D8FQO;VMU<"@F)&9O<FTL("8D=F%R+"`F)'9A<G,I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F5N9&5R5F%R1&ES<&QA
M>5]E;G5M*"1F;W)M+"`D=F%R+"`D=F%R<RD["B`@("!]"@H@("`@9G5N8W1I
M;VX@7W)E;F1E<E9A<D1I<W!L87E?9FEG;&5T*"8D9F]R;2P@)B1V87(L("8D
M=F%R<RD*("`@('L*("`@("`@("!S=&%T:6,@)&9I9VQE=#L*"B`@("`@("`@
M:68@*"%I<W-E="@D9FEG;&5T*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)U1E>'0O1FEG;&5T+G!H<"<["B`@("`@("`@("`@("1F:6=L970@/2`F
M;F5W(%1E>'1?1FEG;&5T*"D["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT
M(#T@)&9I9VQE="T^;&]A9$9O;G0H)'9A<BT^='EP92T^9V5T1F]N="@I*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT+3YG971-97-S86=E*"D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)SQP<F4^)R`N("1F:6=L970M/FQI;F5%
M8VAO*"1V87(M/G1Y<&4M/F=E=%1E>'0H*2D@+B`G/"]P<F4^)SL*("`@('T*
M"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?<V5L96-T1FEL97,H)B1F
M;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("\J($YE961E9"!F
M;W(@9V]L;&5M(&IS(&-A;&QS("HO"B`@("`@("`@)'9A<FYA;64@/2!`:'1M
M;'-P96-I86QC:&%R<R@D=F%R+3YG971687).86UE*"DL($5.5%]154]415,L
M("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@)&AT;6P@/2!S<')I;G1F*"<\
M:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2(E<R(@:60](B5S(B!V86QU93TB
M)7,B("\^)RP*("`@("`@("`@("`@("`@("`@("`@("`@)W-E;&5C=&QI<W1?
M<V5L96-T:60G+`H@("`@("`@("`@("`@("`@("`@("`@("`G<V5L96-T;&ES
M=%]S96QE8W1I9"<L"B`@("`@("`@("`@("`@("`@("`@("`@("1V87(M/G1Y
M<&4M/E]S96QE8W1I9"D@+@H@("`@("`@("`@("!S<')I;G1F*"<\:6YP=70@
M='EP93TB:&ED9&5N(B!N86UE/2(E<R(@:60](B5S(B`O/B<L("=A8W1I;VY)
M1"<L("=A8W1I;VY)1"<I("X*"B`@("`@("`@("`@("\J($9O<FT@9FEE;&0N
M("HO"B`@("`@("`@("`@('-P<FEN=&8H)SQI;G!U="!T>7!E/2)H:61D96XB
M(&YA;64](B5S(B!I9#TB)7,B('9A;'5E/2(E<R(@+SXG+`H@("`@("`@("`@
M("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("1V87)N
M86UE+`H@("`@("`@("`@("`@("`@("`@("1V87(M/G1Y<&4M/E]S96QE8W1I
M9"D["@H@("`@("`@("\J($]P96X@=VEN9&]W(&QI;FLN("HO"B`@("`@("`@
M)'!A<F%M(#T@87)R87DH)'9A<BT^='EP92T^7VQI;FM?=&5X="P*("`@("`@
M("`@("`@("`@("`@("`@("`D=F%R+3YT>7!E+3Y?;&EN:U]S='EL92P*("`@
M("`@("`@("`@("`@("`@("`@("`D9F]R;2T^9V5T3F%M92@I+`H@("`@("`@
M("`@("`@("`@("`@("`@("1V87(M/G1Y<&4M/E]I8V]N+`H@("`@("`@("`@
M("`@("`@("`@("`@("1V87(M/G1Y<&4M/E]S96QE8W1I9"D["B`@("`@("`@
M)&AT;6P@+CT@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F-A;&PH)V9I;&5S+W-E
M;&5C=&QI<W1,:6YK)RP@)'!A<F%M*2`N("(\8G(@+SY<;B(["@H@("`@("`@
M(&EF("@D=F%R+3YT>7!E+3Y?<V5L96-T:60I('L*("`@("`@("`@("`@)'!A
M<F%M(#T@87)R87DH)'9A<BT^='EP92T^7W-E;&5C=&ED*3L*("`@("`@("`@
M("`@)&9I;&5S(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F-A;&PH)V9I;&5S
M+W-E;&5C=&QI<W1297-U;'1S)RP@)'!A<F%M*3L*("`@("`@("`@("`@:68@
M*"1F:6QE<RD@>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&9I;&5S(&%S
M("1I9"`]/B`D9FEL92D@>PH@("`@("`@("`@("`@("`@("`@("1D:7(@/2!K
M97DH)&9I;&4I.PH@("`@("`@("`@("`@("`@("`@("1F:6QE;F%M92`](&-U
M<G)E;G0H)&9I;&4I.PH@("`@("`@("`@("`@("`@("`@("1H=&UL("X]("@D
M:60@*R`Q*2`N("<N("<["B`@("`@("`@("`@("`@("`@("`@:68@*"%E;7!T
M>2@D9&ER*2`F)B`H)&1I<B`A/2`G+B<I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1F:6QE;F%M92`]("1D:7(@+B`G+R<@+B`D9FEL96YA;64["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1H=&UL
M("X]($!H=&UL<W!E8VEA;&-H87)S*"1F:6QE;F%M92P@14Y47U%53U1%4RP@
M)'1H:7,M/E]C:&%R<V5T*2`N("(\8G(@+SY<;B(["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M:'1M;#L*("`@('T*"B`@("!F=6YC=&EO;B!?<V5L96-T3W!T:6]N<R@F)'9A
M;'5E<RP@)'-E;&5C=&5D5F%L=64@/2!F86QS92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1H=&UL8VAA<G,@/2!F86QS92D*("`@('L*("`@("`@
M("`D<F5S=6QT(#T@)R<["B`@("`@("`@)'-E;"`](&9A;'-E.PH@("`@("`@
M(&9O<F5A8V@@*"1V86QU97,@87,@)'9A;'5E(#T^("1D:7-P;&%Y*2!["B`@
M("`@("`@("`@(&EF("@A:7-?;G5L;"@D<V5L96-T961686QU92D@)B8@(21S
M96P@)B8*("`@("`@("`@("`@("`@("1V86QU92`]/2`D<V5L96-T961686QU
M92`F)@H@("`@("`@("`@("`@("`@<W1R;&5N*"1V86QU92D@/3T@<W1R;&5N
M*"1S96QE8W1E9%9A;'5E*2D@>PH@("`@("`@("`@("`@("`@)'-E;&5C=&5D
M(#T@)R!S96QE8W1E9#TB<V5L96-T960B)SL*("`@("`@("`@("`@("`@("1S
M96P@/2!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)'-E;&5C=&5D(#T@)R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)')E<W5L="`N/2`G(#QO<'1I;VX@=F%L=64](B<["B`@("`@("`@("`@("1R
M97-U;'0@+CT@)&AT;6QC:&%R<PH@("`@("`@("`@("`@("`@/R`D=F%L=64*
M("`@("`@("`@("`@("`@(#H@0&AT;6QS<&5C:6%L8VAA<G,H)'9A;'5E+"!%
M3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@("`@("`D<F5S
M=6QT("X]("<B)R`N("1S96QE8W1E9"`N("<^)SL*("`@("`@("`@("`@)')E
M<W5L="`N/2`D:'1M;&-H87)S"B`@("`@("`@("`@("`@("`_("1D:7-P;&%Y
M"B`@("`@("`@("`@("`@("`Z($!H=&UL<W!E8VEA;&-H87)S*"1D:7-P;&%Y
M+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@("`@("`D
M<F5S=6QT("X]("(\+V]P=&EO;CY<;B(["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@('T*"B`@("!F=6YC=&EO;B!?;75L=&E396QE
M8W1/<'1I;VYS*"8D=F%L=65S+"`D<V5L96-T961686QU97,I"B`@("!["B`@
M("`@("`@)')E<W5L="`]("<G.PH@("`@("`@("1S96P@/2!F86QS93L*("`@
M("`@("!F;W)E86-H("@D=F%L=65S(&%S("1V86QU92`]/B`D9&ES<&QA>2D@
M>PH@("`@("`@("`@("!I9B`H0&EN7V%R<F%Y*"1V86QU92P@)'-E;&5C=&5D
M5F%L=65S*2D@>PH@("`@("`@("`@("`@("`@)'-E;&5C=&5D(#T@)R!S96QE
M8W1E9#TB<V5L96-T960B)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1S96QE8W1E9"`]("<G.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1R97-U;'0@+CT@(B`\;W!T:6]N('9A;'5E/5PB(B`N($!H=&UL
M<W!E8VEA;&-H87)S*"1V86QU92P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R
M<V5T*2`N(")<(B1S96QE8W1E9#XB("X@0&AT;6QS<&5C:6%L8VAA<G,H)&1I
M<W!L87DL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D@+B`B/"]O<'1I
M;VX^7&XB.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("!]"@H@("`@9G5N8W1I;VX@7V-H96-K0F]X97,H)&YA;64L("1V86QU97,L
M("1C:&5C:V5D5F%L=65S+"`D86-T:6]N<R`]("<G*0H@("`@>PH@("`@("`@
M("1R97-U;'0@/2`G)SL*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1C:&5C:V5D
M5F%L=65S*2D@>PH@("`@("`@("`@("`D8VAE8VME9%9A;'5E<R`](&%R<F%Y
M*"D["B`@("`@("`@?0H@("`@("`@("1I(#T@,#L*("`@("`@("!F;W)E86-H
M("@D=F%L=65S(&%S("1V86QU92`]/B`D9&ES<&QA>2D@>PH@("`@("`@("`@
M("`D8VAE8VME9"`]("AI;E]A<G)A>2@D=F%L=64L("1C:&5C:V5D5F%L=65S
M*2D@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G.PH@("`@("`@("`@("`D
M<F5S=6QT("X]('-P<FEN=&8H)SQI;G!U="!I9#TB)7,E<R(@='EP93TB8VAE
M8VMB;W@B(&-L87-S/2)C:&5C:V)O>"(@;F%M93TB)7-;72(@=F%L=64](B5S
M(B5S)7,@+SX\;&%B96P@9F]R/2(E<R5S(CXF;F)S<#LE<SPO;&%B96P^/&)R
M("\^)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($!H=&UL<W!E
M8VEA;&-H87)S*"1N86UE+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D;F%M
M92P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1V86QU92P@
M14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1C:&5C:V5D+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&%C=&EO;G,L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D;F%M92P@14Y47U%53U1%4RP@
M)'1H:7,M/E]C:&%R<V5T*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@0&AT;6QS
M<&5C:6%L8VAA<G,H)&1I<W!L87DL($5.5%]154]415,L("1T:&ES+3Y?8VAA
M<G-E="DI.PH@("`@("`@("`@("`D:2LK.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@9G5N8W1I;VX@7W)A9&EO0G5T
M=&]N<R@D;F%M92P@)'9A;'5E<RP@)&-H96-K961686QU92`](&YU;&PL("1A
M8W1I;VYS(#T@)R<I"B`@("!["B`@("`@("`@)')E<W5L="`]("<G.PH@("`@
M("`@("1I(#T@,#L*("`@("`@("!F;W)E86-H("@D=F%L=65S(&%S("1V86QU
M92`]/B`D9&ES<&QA>2D@>PH@("`@("`@("`@("`D8VAE8VME9"`]("@A:7-?
M;G5L;"@D8VAE8VME9%9A;'5E*2`F)B`D=F%L=64@/3T@)&-H96-K961686QU
M92D@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G.PH@("`@("`@("`@("`D
M<F5S=6QT("X]('-P<FEN=&8H)SQI;G!U="!I9#TB)7,E<R(@='EP93TB<F%D
M:6\B(&-L87-S/2)C:&5C:V)O>"(@;F%M93TB)7,B('9A;'5E/2(E<R(E<R5S
M("\^/&QA8F5L(&9O<CTB)7,E<R(^)FYB<W`[)7,\+VQA8F5L/CQB<B`O/B<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P96-I86QC
M:&%R<R@D;F%M92P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)&YA;64L($5.
M5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D=F%L=64L($5.5%]1
M54]415,L("1T:&ES+3Y?8VAA<G-E="DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D8VAE8VME9"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1A8W1I;VYS+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@0&AT;6QS<&5C:6%L8VAA<G,H)&YA;64L($5.5%]154]415,L("1T:&ES
M+3Y?8VAA<G-E="DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M:2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($!H=&UL<W!E8VEA
M;&-H87)S*"1D:7-P;&%Y+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I
M*3L*("`@("`@("`@("`@)&DK*SL*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@?0H*("`@(&9U;F-T:6]N(%]G96Y)1"@D;F%M92P@
M)&9U;&QT86<@/2!T<G5E*0H@("`@>PH@("`@("`@("1N86UE(#T@0&AT;6QS
M<&5C:6%L8VAA<G,H)&YA;64L($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E
M="D["B`@("`@("`@<F5T=7)N("1F=6QL=&%G(#\@)VED/2(G("X@)&YA;64@
M+B`G(B<@.B`D;F%M93L*("`@('T*"B`@("!F=6YC=&EO;B!?9V5N06-T:6]N
M4V-R:7!T*"8D9F]R;2P@)&%C=&EO;BP@)'9A<FYA;64I"B`@("!["B`@("`@
M("`@)&AT;6P@/2`G)SL*("`@("`@("`D=')I9V=E<G,@/2`D86-T:6]N+3YG
M9714<FEG9V5R*"D["B`@("`@("`@:68@*"%I<U]A<G)A>2@D=')I9V=E<G,I
M*2!["B`@("`@("`@("`@("1T<FEG9V5R<R`](&%R<F%Y*"1T<FEG9V5R<RD[
M"B`@("`@("`@?0H@("`@("`@("1J<R`]("1A8W1I;VXM/F=E=$%C=&EO;E-C
M<FEP="@D9F]R;2P@)'1H:7,L("1V87)N86UE*3L*("`@("`@("!F;W)E86-H
M("@D=')I9V=E<G,@87,@)'1R:6=G97(I('L*("`@("`@("`@("`@:68@*"1T
M<FEG9V5R(#T]("=O;FQO860G*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7V%D9$]N3&]A9$IA=F%S8W)I<'0H)&IS*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1H=&UL("X]("<@)R`N("1T<FEG9V5R("X@
M)STB)R`N("1J<R`N("<B)SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("!R971U<FX@)&AT;6P["B`@("!]"@H@("`@9G5N8W1I;VX@7V=E=$%C
M=&EO;E-C<FEP=',H)B1F;W)M+"`F)'9A<BD*("`@('L*("`@("`@("`D86-T
M:6]N<R`]("<G.PH@("`@("`@(&EF("@D=F%R+3YH87-!8W1I;VXH*2D@>PH@
M("`@("`@("`@("`D=F%R;F%M92`]("1V87(M/F=E=%9A<DYA;64H*3L*("`@
M("`@("`@("`@)&%C=&EO;B`])B`D=F%R+3Y?86-T:6]N.PH@("`@("`@("`@
M("`D=')I9V=E<G,@/2`D86-T:6]N+3YG9714<FEG9V5R*"D["B`@("`@("`@
M("`@(&EF("@A:7-?87)R87DH)'1R:6=G97)S*2D@>PH@("`@("`@("`@("`@
M("`@)'1R:6=G97)S(#T@87)R87DH)'1R:6=G97)S*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D:G,@/2`D86-T:6]N+3YG971!8W1I;VY38W)I<'0H
M)&9O<FTL("1T:&ES+"`D=F%R;F%M92D["B`@("`@("`@("`@(&9O<F5A8V@@
M*"1T<FEG9V5R<R!A<R`D=')I9V=E<BD@>PH@("`@("`@("`@("`@("`@:68@
M*"1T<FEG9V5R(#T]("=O;FQO860G*2!["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]A9&1/;DQO861*879A<V-R:7!T*"1J<RD["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1A8W1I;VYS("X]
M("<@)R`N("1T<FEG9V5R("X@)STB)R`N("1J<R`N("<B)SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U
M<FX@)&%C=&EO;G,["B`@("!]"@H@("`@9G5N8W1I;VX@7V%D9$]N3&]A9$IA
M=F%S8W)I<'0H)'-C<FEP="D*("`@('L*("`@("`@("`D=&AI<RT^7V]N3&]A
M9$I36UT@/2`D<V-R:7!T.PH@("`@?0H*("`@(&9U;F-T:6]N(')E;F1E<D5N
M9"@I"B`@("!["B`@("`@("`@:68@*&-O=6YT*"1T:&ES+3Y?;VY,;V%D2E,I
M*2!["B`@("`@("`@("`@(')E='5R;B`B/'-C<FEP="!T>7!E/5PB=&5X="]J
M879A<V-R:7!T7"(^(B`N"B`@("`@("`@("`@("`@("`B/"$M+5QN(B`N("!I
M;7!L;V1E*")<;B(L("1T:&ES+3Y?;VY,;V%D2E,I("X@(EQN+R\@+2T^7&XB
M("X*("`@("`@("`@("`@("`@("(\+W-C<FEP=#XB.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("!]"B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]522]6
M87)296YD97)E<B]T86)L97-E=%]H=&UL+G!H<```````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#8P-#0`,3`U,34T,S,W-3$`,#(U-38S`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP)SL*"B\J*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]T86)L97-E=%]H=&UL+G!H
M<"QV(#$N,RXR+C$@,C`P-2\Q,"\Q."`Q,3HP,3HS-B!J86X@17AP("0*("H*
M("H@0'!A8VMA9V4@2&]R9&5?54D*("H@0'-I;F-E("`@2&]R9&4@,RXQ"B`J
M+PIC;&%S<R!(;W)D95]525]687)296YD97)E<E]T86)L97-E=%]H=&UL(&5X
M=&5N9',@2&]R9&5?54E?5F%R4F5N9&5R97)?:'1M;"!["@H@("`@9G5N8W1I
M;VX@7W)E;F1E<E9A<DEN<'5T7W1A8FQE<V5T*"8D9F]R;2P@)B1V87(L("8D
M=F%R<RD*("`@('L*("`@("`@("`D:&5A9&5R(#T@)'9A<BT^='EP92T^9V5T
M2&5A9&5R*"D["B`@("`@("`@)&YA;64@("`]("1V87(M/F=E=%9A<DYA;64H
M*3L*("`@("`@("`D=F%L=65S(#T@)'9A<BT^9V5T5F%L=65S*"D["B`@("`@
M("`@)&-H96-K961686QU97,@/2`D=F%R+3YG971686QU92@D=F%R<RD["B`@
M("`@("`@)&%C=&EO;G,@/2`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O
M<FTL("1V87(I.PH*("`@("`@("`D:'1M;"`]("<\=&%B;&4@=VED=&@](C$P
M,"4B(&-L87-S/2)I=&5M(B!C96QL<W!A8VEN9STB,2(^/'1R(&-L87-S/2)S
M96QE8W1E9"(^)R`N"B`@("`@("`@("`@("<\=&@@8VQA<W,](G=I9&=E="(@
M86QI9VX](G)I9VAT(B!W:61T:#TB,24B/B9N8G-P.SPO=&@^)SL*("`@("`@
M("!F;W)E86-H("@D:&5A9&5R(&%S("1C;VQ?=&ET;&4I('L*("`@("`@("`@
M("`@)&AT;6P@+CT@<W!R:6YT9B@G/'1H(&%L:6=N/2)L969T(B!C;&%S<STB
M=VED9V5T(CXE<SPO=&@^)RP@)&-O;%]T:71L92D["B`@("`@("`@?0H@("`@
M("`@("1H=&UL("X]("<\+W1R/B<["@H@("`@("`@(&EF("@A:7-?87)R87DH
M)&-H96-K961686QU97,I*2!["B`@("`@("`@("`@("1C:&5C:V5D5F%L=65S
M(#T@87)R87DH*3L*("`@("`@("!]"B`@("`@("`@)&D@/2`P.PH@("`@("`@
M(&9O<F5A8V@@*"1V86QU97,@87,@)'9A;'5E(#T^("1D:7-P;&%Y<RD@>PH@
M("`@("`@("`@("`D8VQA<W,@/2`G:71E;2<@+B`H)&D@*R`Q*2`E(#(["B`@
M("`@("`@("`@("1C:&5C:V5D(#T@*&EN7V%R<F%Y*"1V86QU92P@)&-H96-K
M961686QU97,I*2`_("<@8VAE8VME9#TB8VAE8VME9"(G(#H@)R<["B`@("`@
M("`@("`@("1H=&UL("X]('-P<FEN=&8H)SQT<B!C;&%S<STB)7,B/B<L("1C
M;&%S<RD@+@H@("`@("`@("`@("`@("`@<W!R:6YT9B@G/'1D(&%L:6=N/2)C
M96YT97(B/CQI;G!U="!I9#TB)7,E<R(@='EP93TB8VAE8VMB;W@B(&YA;64]
M(B5S6UTB('9A;'5E/2(E<R(E<R5S("\^/"]T9#XG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`D;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@)&DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("1N86UE+`H@("`@("`@("`@("`@
M("`@("`@("`@("`D=F%L=64L"B`@("`@("`@("`@("`@("`@("`@("`@("1C
M:&5C:V5D+`H@("`@("`@("`@("`@("`@("`@("`@("`D86-T:6]N<RD["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1D:7-P;&%Y<R!A<R`D8V]L*2!["B`@("`@
M("`@("`@("`@("`D:'1M;"`N/2!S<')I;G1F*"<\=&0@86QI9VX](FQE9G0B
M/B9N8G-P.R5S/"]T9#XG+"`D8V]L*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D:'1M;"`N/2`G/"]T<CXG.PH@("`@("`@("`@("`D:2LK.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1H=&UL("X@)SPO=&%B;&4^)SL*("`@
M('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA>5]T86)L97-E="@F
M)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)&AE861E<B`]
M("1V87(M/G1Y<&4M/F=E=$AE861E<B@I.PH@("`@("`@("1N86UE("`@/2`D
M=F%R+3YG971687).86UE*"D["B`@("`@("`@)'9A;'5E<R`]("1V87(M/F=E
M=%9A;'5E<R@I.PH@("`@("`@("1C:&5C:V5D5F%L=65S(#T@)'9A<BT^9V5T
M5F%L=64H)'9A<G,I.PH@("`@("`@("1A8W1I;VYS(#T@)'1H:7,M/E]G971!
M8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*3L*"B`@("`@("`@)&AT;6P@/2`G
M/'1A8FQE('=I9'1H/2(Q,#`E(B!C96QL<W!A8VEN9STB,2(^/'1R(&-L87-S
M/2)S96QE8W1E9"(^)R`N"B`@("`@("`@("`@("<\=&@@8VQA<W,](G=I9&=E
M="(@86QI9VX](G)I9VAT(B!W:61T:#TB,24B/B9N8G-P.SPO=&@^)SL*("`@
M("`@("!F;W)E86-H("@D:&5A9&5R(&%S("1C;VQ?=&ET;&4I('L*("`@("`@
M("`@("`@)&AT;6P@+CT@<W!R:6YT9B@G/'1H(&%L:6=N/2)L969T(B!C;&%S
M<STB=VED9V5T(CXE<SPO=&@^)RP@)&-O;%]T:71L92D["B`@("`@("`@?0H@
M("`@("`@("1H=&UL("X]("<\+W1R/B<["@H@("`@("`@(&EF("@A:7-?87)R
M87DH)&-H96-K961686QU97,I*2!["B`@("`@("`@("`@("1C:&5C:V5D5F%L
M=65S(#T@87)R87DH*3L*("`@("`@("!]"B`@("`@("`@)&D@/2`P.PH@("`@
M("`@(&9O<F5A8V@@*"1V86QU97,@87,@)'9A;'5E(#T^("1D:7-P;&%Y<RD@
M>PH@("`@("`@("`@("`D8VQA<W,@("`]("=I=&5M)R`N("@D:2`K(#$I("4@
M,CL*("`@("`@("`@("`@)&-H96-K960@/2`H:6Y?87)R87DH)'9A;'5E+"`D
M8VAE8VME9%9A;'5E<RDI(#\@)UL@/'-T<F]N9SX\9F]N="!C;VQO<CUG<F5E
M;CY6/"]F;VYT/CPO<W1R;VYG/B!=)R`Z("=;(#QS=')O;F<^/&9O;G0@8V]L
M;W(]<F5D/E@\+V9O;G0^/"]S=')O;F<^(%TG.PH@("`@("`@("`@("`D:'1M
M;"`N/2!S<')I;G1F*"<\='(@8VQA<W,](B5S(CXG+"`D8VQA<W,I("X*("`@
M("`@("`@("`@("`@('-P<FEN=&8H)SQT9"!A;&EG;CTB8V5N=&5R(CXE<SPO
M=&0^)RP@)&-H96-K960I.PH@("`@("`@("`@("!F;W)E86-H("@D9&ES<&QA
M>7,@87,@)&-O;"D@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@<W!R:6YT
M9B@G/'1D(&%L:6=N/2)L969T(CXF;F)S<#LE<SPO=&0^)RP@)&-O;"D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&AT;6P@+CT@)SPO='(^)SL*("`@
M("`@("`@("`@)&DK*SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:'1M
M;"`N("<\+W1A8FQE/B<["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(N<&AP````````````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#$P,C(Q`#$P-3$U-#,S-S4Q`#`R,C<R-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@5&AE($AO<F1E
M7U5)7U9A<E)E;F1E<F5R.CH@8VQA<W,@<')O=FED97,@8F%S92!F=6YC=&EO
M;F%L:71Y(&9O<@H@*B!O=&AE<B!(;W)D92!522!E;&5M96YT<RX*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(N<&AP+'8@,2XQ
M,BXQ,"XQ,"`R,#`V+S`V+S(P(#`Y.C`X.C0U(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,RTR,#`V($IA<V]N($TN($9E;&EC92`\:F9E;&EC94!C
M<F]N;W-Y<RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`<VEN8V4@("!(;W)D
M95]522`P+C`N,0H@*B!`<&%C:V%G92!(;W)D95]520H@*B\*8VQA<W,@2&]R
M9&5?54E?5F%R4F5N9&5R97(@>PH*("`@("\J*@H@("`@("H@4&%R86UE=&5R
M<R!W:&EC:"!C:&%N9V4@=&AI<R!R96YD97)E<B=S(&)E:&%V:6]R+@H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R86US
M.PH*("`@("\J*@H@("`@("H@0VAA<G-E="!T;R!U<V4@9F]R(&]U='!U="X*
M("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]C
M:&%R<V5T.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!R96YD
M97)E<BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@5&AE
M(&YA;64@;V8@=&AE('9A<FEA8FQE('=H:6-H('=I;&P@=')A8VL@=&AI<R!5
M20H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('=I9&=E="=S('-T871E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]525]687)296YD97)E<B@D
M<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W!A<F%M
M<R`]("1P87)A;7,["B`@("`@("`@)'1H:7,M/E]C:&%R<V5T(#T@3DQ3.CIG
M971#:&%R<V5T*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S
M(&$@;F5W($AO<F1E7U5)7U9A<E)E;F1E<F5R.CH@:6YS=&%N8V4N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&UI>&5D("1D<FEV97(@(%1H:7,@:7,@=&AE(')E
M;F1E<F5R('-U8F-L87-S('=E('=I;&P@:6YS=&%N=&EA=&4N"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@268@86X@87)R87D@:7,@<&%S<V5D+"!T
M:&4@9FER<W0@96QE;65N="!I<R!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!L:6)R87)Y('!A=&@@86YD('1H92!S96-O;F0@96QE;65N="!I
M<R!T:&4@9')I=F5R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@;F%M
M92X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!087)A;65T97)S('-P
M96-I9FEC('1O('1H92!S=6)C;&%S<RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M($AO<F1E7U5)7U9A<E)E;F1E<F5R("!!($AO<F1E7U5)7U9A<E)E;F1E<F5R
M.CH@<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EN<W1A;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D
M9')I=F5R+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H
M:7-?87)R87DH)&1R:79E<BDI('L*("`@("`@("`@("`@)&%P<"`]("1D<FEV
M97);,%T["B`@("`@("`@("`@("1D<FEV97(@/2`D9')I=F5R6S%=.PH@("`@
M("`@('T*"B`@("`@("`@)&1R:79E<B`](&)A<V5N86UE*"1D<FEV97(I.PH*
M("`@("`@("!I9B`H(65M<'1Y*"1A<'`I*2!["B`@("`@("`@("`@(')E<75I
M<F5?;VYC92`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=F:6QE<F]O="<L
M("1A<'`I("X@)R]L:6(O54DO5F%R4F5N9&5R97(O)R`N("1D<FEV97(@+B`G
M+G!H<"<["B`@("`@("`@?2!E;'-E:68@*$!F:6QE7V5X:7-T<RAD:7)N86UE
M*%]?1DE,15]?*2`N("<O5F%R4F5N9&5R97(O)R`N("1D<FEV97(@+B`G+G!H
M<"<I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,
M15]?*2`N("<O5F%R4F5N9&5R97(O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@0&EN8VQU9&5?;VYC92`G2&]R
M9&4O54DO5F%R4F5N9&5R97(O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@
M("`@?0H*("`@("`@("`D8VQA<W,@/2`G2&]R9&5?54E?5F%R4F5N9&5R97)?
M)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I
M*2!["B`@("`@("`@("`@("1V<B`]("9N97<@)&-L87-S*"1P87)A;7,I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1V<B`](%!%05(Z.G)A:7-E
M17)R;W(H)T-L87-S(&1E9FEN:71I;VX@;V8@)R`N("1C;&%S<R`N("<@;F]T
M(&9O=6YD+B<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1V<CL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!(;W)D95]525]687)296YD
M97)E<CHZ(&EN<W1A;F-E+"!C;VYS=')U8W1I;F<@;VYE('=I=&@@=&AE"B`@
M("`@*B!S<&5C:69I960@<&%R86UE=&5R<R!I9B!N96-E<W-A<GDN"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9')I=F5R("!4:&ES(&ES('1H92!R
M96YD97)E<B!S=6)C;&%S<R!W92!W:6QL"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@(&EN<W1A;G1I871E+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@("!087)A;65T97)S('-P96-I9FEC('1O('1H92!S=6)C;&%S<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7U5)7U9A<E)E;F1E<F5R("!!
M($AO<F1E7U5)7U9A<E)E;F1E<F5R.CH@<W5B8VQA<W,*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EN<W1A;F-E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(L("1P87)A;7,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@('-T871I8R`D8V%C:&4["@H@("`@("`@(&EF
M("AI<U]N=6QL*"1D<FEV97(I*2!["B`@("`@("`@("`@("1C;&%S<R`]("=(
M;W)D95]525]687)296YD97)E<B<["B`@("`@("`@?0H@("`@("`@("1K97D@
M/2!S97)I86QI>F4H87)R87D@*"1D<FEV97(L("1P87)A;7,I*3L*("`@("`@
M("!I9B`H(6ES<V5T*"1C86-H95LD:V5Y72DI('L*("`@("`@("`@("`@)&-A
M8VAE6R1K97E=(#T@)DAO<F1E7U5)7U9A<E)E;F1E<F5R.CIF86-T;W)Y*"1D
M<FEV97(L("1P87)A;7,I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&-A
M8VAE6R1K97E=.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5N9&5R<R!A('9A
M<FEA8FQE+@H@("`@("H*("`@("`J($!P87)A;2!(;W)D95]&;W)M("8D9F]R
M;2`@("`@("`@("`@4F5F97)E;F-E('1O(&$@2&]R9&5?1F]R;2!I;G-T86YC
M92P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M;W(@;G5L;"!I9B!N;VYE(&ES(&%V86EL86)L92X*("`@("`J($!P87)A;2!(
M;W)D95]&;W)M7U9A<FEA8FQE("8D=F%R("`@4F5F97)E;F-E('1O(&$@2&]R
M9&5?1F]R;5]687)I86)L92X*("`@("`J($!P87)A;2!687)I86)L97,@)B1V
M87)S("`@("`@("`@("`@02!687)I86)L97,@:6YS=&%N8V4N"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D:7-);G!U="`@("`@("`@("`@(%=H971H97(@=&AI
M<R!I<R!A;B!I;G!U="!F:65L9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N
M9&5R*"8D9F]R;2P@)B1V87(L("8D=F%R<RP@)&ES26YP=70@/2!F86QS92D*
M("`@('L*("`@("`@("!I9B`H)&ES26YP=70I('L*("`@("`@("`@("`@)'-T
M871E(#T@)TEN<'5T)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M<W1A=&4@/2`G1&ES<&QA>2<["B`@("`@("`@?0H@("`@("`@("1M971H;V0@
M/2`B7W)E;F1E<E9A<B1[<W1A=&5]7R(@+B`D=F%R+3YT>7!E+3YG9714>7!E
M3F%M92@I.PH@("`@("`@(&EF("@A0&UE=&AO9%]E>&ES=',H)'1H:7,L("1M
M971H;V0I*2!["B`@("`@("`@("`@("1M971H;V0@/2`B7W)E;F1E<E9A<B1[
M<W1A=&5]1&5F875L="(["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI
M<RT^)&UE=&AO9"@D9F]R;2P@)'9A<BP@)'9A<G,I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1FEN:7-H97,@<F5N9&5R:6YG(&%F=&5R(&%L;"!F:65L9',@
M87)E(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R16YD*"D*
M("`@('L*("`@("`@("!R971U<FX@)R<["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]522]7:61G970N<&AP
M````````````````````````````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0S-3(`,3`U
M,34T,S,W-3$`,#(Q-S0P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?54E?5VED9V5T
M.CH@8VQA<W,@<')O=FED97,@8F%S92!F=6YC=&EO;F%L:71Y(&9O<B!O=&AE
M<B!(;W)D90H@*B!522!E;&5M96YT<RX*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO54DO54DO5VED9V5T+G!H<"QV(#$N-RXQ,"XX(#(P,#8O,#8O,C`@,#DZ
M,#@Z-#4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@2F%S
M;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R;VYO<WES+F-O;3X*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!S:6YC92`@($AO<F1E7U5)(#`N,"XQ"B`J($!P86-K86=E
M($AO<F1E7U5)"B`J+PIC;&%S<R!(;W)D95]525]7:61G970@>PH*("`@("\J
M*@H@("`@("H@06YY('9A<FEA8FQE<R!T:&%T('-H;W5L9"!B92!P<F5S97)V
M960@:6X@86QL(&]F('1H92!W:61G970G<PH@("`@("H@;&EN:W,N"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P<F5S97)V
M92`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@;F%M92!O9B!T:&ES
M('=I9&=E="X@(%1H:7,@:7,@=7-E9"!A<R!T:&4@8F%S96YA;64@9F]R('9A
M<FEA8FQE<PH@("`@("H@=V4@86-C97-S(&%N9"!M86YI<'5L871E+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VYA;64[
M"@H@("`@+RHJ"B`@("`@*B!!(')E9F5R96YC92!T;R!A(%9A<FEA8FQE<SHZ
M(&]B:F5C="!T:&ES('=I9&=E="!W:6QL('5S92!A;F0*("`@("`J(&UA;FEP
M=6QA=&4N"B`@("`@*@H@("`@("H@0'9A<B!687)I86)L97,*("`@("`J+PH@
M("`@=F%R("1?=F%R<SL*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F(&YA
M;64@/3X@=F%L=64@<&%I<G,@=VAI8V@@8V]N9FEG=7)E(&AO=R!T:&ES('=I
M9&=E=`H@("`@("H@8F5H879E<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D7V-O;F9I9SL*"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C="!A(&YE=R!522!7:61G970@:6YT97)F86-E+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("!4:&4@;F%M92!O9B!T:&4@
M=F%R:6%B;&4@=VAI8V@@=VEL;"!T<F%C:R!T:&ES"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@54D@=VED9V5T)W,@<W1A=&4N"B`@("`@*B!`
M<&%R86T@5F%R:6%B;&5S("8D=F%R<R`@02!687)I86)L97,Z.B!O8FIE8W0N
M"B`@("`@*B!`<&%R86T@87)R87D@)&-O;F9I9R`@("`@5&AE('=I9&=E="=S
M(&-O;F9I9W5R871I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7U5)
M7U=I9&=E="@D;F%M92P@)B1V87)S+"`D8V]N9FEG(#T@87)R87DH*2D*("`@
M('L*("`@("`@("`D=&AI<RT^7VYA;64@/2`D;F%M93L*("`@("`@("`D=&AI
M<RT^7W9A<G,@/2`F)'9A<G,["B`@("`@("`@)'1H:7,M/E]C;VYF:6<@/2`D
M8V]N9FEG.PH@("`@?0H*("`@("\J*@H@("`@("H@26YS=')U8W0@2&]R9&5?
M54E?5VED9V5T.CH@=&\@<')E<V5R=F4@82!V87)I86)L92X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1V87(@("!4:&4@;F%M92!O9B!T:&4@=F%R
M:6%B;&4@=&\@<')E<V5R=F4N"B`@("`@*B!`<&%R86T@;6EX960@)'9A;'5E
M("!4:&4@=F%L=64@;V8@=&AE('9A<FEA8FQE('1O('!R97-E<G9E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!P<F5S97)V92@D=F%R+"`D=F%L=64I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]P<F5S97)V95LD=F%R72`]("1V86QU93L*("`@
M('T*"B`@("`O*BH*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@
M("!F=6YC=&EO;B!?861D4')E<V5R=F5D*"1L:6YK*0H@("`@>PH@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?<')E<V5R=F4@87,@)'9A<DYA;64@/3X@)'9A
M<E9A;'5E*2!["B`@("`@("`@("`@("1L:6YK(#T@571I;#HZ861D4&%R86UE
M=&5R*"1L:6YK+"`D=F%R3F%M92P@)'9A<E9A;'5E*3L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1L:6YK.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5N
M9&5R('1H92!W:61G970N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@
M*@H@("`@("H@0'!A<F%M(&UI>&5D("1D871A("!4:&4@=VED9V5T)W,@<W1A
M=&4@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"D@>WT*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]5
M=&EL+G!H<```````````````````````````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P-C<R-C$`,3`U,34T,S,W-3$`,#(Q,3(U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@HO*BH*("H@17)R;W(@
M8V]D92!F;W(@82!M:7-S:6YG(&1R:79E<B!C;VYF:6=U<F%T:6]N+@H@*B\*
M9&5F:6YE*"=(3U)$15]%4E)/4E]$4DE615)?0T].1DE'7TU)4U-)3D<G+"`Q
M*3L*"B\J*@H@*B!%<G)O<B!C;V1E(&9O<B!A;B!I;F-O;7!L971E(&1R:79E
M<B!C;VYF:6=U<F%T:6]N+@H@*B\*9&5F:6YE*"=(3U)$15]%4E)/4E]$4DE6
M15)?0T].1DE')RP@,BD["@HO*BH*("H@5&AE(%5T:6PZ.B!C;&%S<R!P<F]V
M:61E<R!G96YE<F%L;'D@=7-E9G5L(&UE=&AO9',@;V8@9&EF9F5R96YT(&MI
M;F1S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP+'8@
M,2XS.#0N-BXQ-R`R,#`V+S`U+S`U(#$V.C`R.C$R(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@
M/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@
M2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@
M,RXP"B`J($!P86-K86=E($AO<F1E7U5T:6P*("HO"F-L87-S(%5T:6P@>PH*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!O8FIE8W0G<R!C;&]N92X*("`@
M("`J"B`@("`@*B!`<&%R86T@;V)J96-T("8D;V)J("!4:&4@;V)J96-T('1O
M(&-L;VYE+@H@("`@("H*("`@("`J($!R971U<FX@;V)J96-T("!4:&4@8VQO
M;F5D(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@)F-L;VYE3V)J96-T
M*"8D;V)J*0H@("`@>PH@("`@("`@("\J($-L;VYI;F<@9&]E<R`J;F]T*B!C
M=7)R96YT;'D@=V]R:R!I9B!U<VEN9R!02%`@-2X*("`@("`@("`@*B!4:&ES
M(&ES(&$@:VYO=VX@4$A0(&ES<W5E.B!H='1P.B\O8G5G<RYP:'`N;F5T+V)U
M9RYP:'`_:60],C<R-C@*("`@("`@("`@*B!4:&5R969O<F4L('=O<FL@87)O
M=6YD('1H:7,@:7-S=64@8GD@=7-I;F<@=&AE(%!(4"`T"B`@("`@("`@("H@
M<V5R:6%L:7IE+W5N<V5R:6%L:7IE(&-L;VYE(&AA8VLN("HO"B`@("`@("`@
M+RH*("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*'IE;F1?=F5R<VEO;B@I
M+"`G,B<L("<^)RDI('L*("`@("`@("`@("`@<F5T=7)N(&-L;VYE*"1O8FHI
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1N97=/8FH@/2`D;V)J
M.PH@("`@("`@("`@("!R971U<FX@)&YE=T]B:CL*("`@("`@("!]"B`@("`@
M("`@*B\*("`@("`@("`D<F5T(#T@=6YS97)I86QI>F4H<V5R:6%L:7IE*"1O
M8FHI*3L*("`@("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("`O*BH*("`@
M("`J($)U9F9E<G,@=&AE(&]U='!U="!F<F]M(&$@9G5N8W1I;VX@8V%L;"P@
M;&EK92!R96%D9FEL92@I(&]R"B`@("`@*B!H:6=H;&EG:'1?<W1R:6YG*"DL
M('1H870@<')I;G1S('1H92!O=71P=70@9&ER96-T;'DL('-O('1H870@:6YS
M=&5A9"!I=`H@("`@("H@8V%N(&)E(')E='5R;F5D(&%S(&$@<W1R:6YG(&%N
M9"!U<V5D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9U;F-T:6]N
M("!4:&4@9G5N8W1I;VX@=&\@<G5N+@H@("`@("H@0'!A<F%M(&UI>&5D("1A
M<F<Q("`@("`@($9I<G-T(&%R9W5M96YT('1O("1F=6YC=&EO;B@I+@H@("`@
M("H@0'!A<F%M(&UI>&5D("1A<F<R("`@("`@(%-E8V]N9"!A<F=U;65N="!T
M;R`D9G5N8W1I;VXH*2X*("`@("`J($!P87)A;2!M:7AE9"`D87)G+BXN("`@
M("`N+BX*("`@("`J($!P87)A;2!M:7AE9"`D87)G3B`@("`@("!.=&@@87)G
M=6UE;G0@=&\@)&9U;F-T:6]N*"DN"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!O=71P=70@;V8@=&AE(&9U;F-T:6]N+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!B=69F97)/=71P=70H*0H@("`@>PH@("`@("`@(&EF("AF
M=6YC7VYU;5]A<F=S*"D@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H@("`@("`@("1I;F-L=61E(#T@9F%L<V4["B`@("`@
M("`@)&%R9W,@/2!F=6YC7V=E=%]A<F=S*"D["B`@("`@("`@)&9U;F-T:6]N
M(#T@87)R87E?<VAI9G0H)&%R9W,I.PH@("`@("`@(&EF("AI<U]A<G)A>2@D
M9G5N8W1I;VXI*2!["B`@("`@("`@("`@(&EF("@A:7-?8V%L;&%B;&4H)&9U
M;F-T:6]N*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*"@D9G5N8W1I;VX@/3T@)VEN
M8VQU9&4G*2!\?`H@("`@("`@("`@("`@("`@("`H)&9U;F-T:6]N(#T]("=I
M;F-L=61E7V]N8V4G*2!\?`H@("`@("`@("`@("`@("`@("`H)&9U;F-T:6]N
M(#T]("=R97%U:7)E)RD@?'P*("`@("`@("`@("`@("`@("`@*"1F=6YC=&EO
M;B`]/2`G<F5Q=6ER95]O;F-E)RDI('L*("`@("`@("`@("`@)&EN8VQU9&4@
M/2!T<G5E.PH@("`@("`@('T@96QS96EF("@A9G5N8W1I;VY?97AI<W1S*"1F
M=6YC=&EO;BDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*"B`@("`@("`@;V)?<W1A<G0H*3L*("`@("`@("!I9B`H)&EN8VQU9&4I
M('L*("`@("`@("`@("`@)&9I;&4@/2!I;7!L;V1E*"<L)RP@)&%R9W,I.PH@
M("`@("`@("`@("!S=VET8V@@*"1F=6YC=&EO;BD@>PH@("`@("`@("`@("!C
M87-E("=I;F-L=61E)SH*("`@("`@("`@("`@("`@(&EN8VQU9&4@)&9I;&4[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VEN
M8VQU9&5?;VYC92<Z"B`@("`@("`@("`@("`@("!I;F-L=61E7V]N8V4@)&9I
M;&4["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@
M)W)E<75I<F4G.@H@("`@("`@("`@("`@("`@<F5Q=6ER92`D9FEL93L*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G<F5Q=6ER
M95]O;F-E)SH*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`D9FEL93L*
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F-?87)R87DH)&9U
M;F-T:6]N+"`D87)G<RD["B`@("`@("`@?0H@("`@("`@("1O=71P=70@/2!O
M8E]G971?8V]N=&5N=',H*3L*("`@("`@("!O8E]E;F1?8VQE86XH*3L*"B`@
M("`@("`@<F5T=7)N("1O=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M:&5C:W,@=&\@<V5E(&EF(&$@=F%L=64@:&%S(&)E96X@<V5T(&)Y('1H92!S
M8W)I<'0@86YD(&YO="!B>2!'150L"B`@("`@*B!03U-4+"!O<B!C;V]K:64@
M:6YP=70N(%1H92!V86QU92!B96EN9R!C:&5C:V5D($U54U0@8F4@:6X@=&AE
M(&=L;V)A;`H@("`@("H@<V-O<&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=F%R;F%M92`@5&AE('9A<FEA8FQE(&YA;64@=&\@8VAE8VLN"B`@
M("`@*B!`<&%R86T@;6EX960@)&1E9F%U;'0@("!$969A=6QT('9A;'5E(&EF
M('1H92!V87)I86)L92!I<VXG="!P<F5S96YT"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!O<B!W87,@<W!E8VEF:65D(&)Y('1H92!U<V5R+B!$
M969A=6QT<R!T;R!N=6QL+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@0'-I;F-E($AO<F1E(#,N,0H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@("1D969A=6QT(&EF('1H92!V87(@:7,@:6X@=7-E<B!I;G!U="!O<B!N
M;W0@<')E<V5N="P*("`@("`J("`@("`@("`@("`@("`@('1H92!V87)I86)L
M92!V86QU92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&YO;DEN
M<'5T5F%R*"1V87)N86UE+"`D9&5F875L="`](&YU;&PI"B`@("!["B`@("`@
M("`@:68@*&ES<V5T*"1?1T546R1V87)N86UE72D@?'P*("`@("`@("`@("`@
M:7-S970H)%]03U-46R1V87)N86UE72D@?'P*("`@("`@("`@("`@:7-S970H
M)%]#3T]+245;)'9A<FYA;65=*2D@>PH@("`@("`@("`@("!R971U<FX@)&1E
M9F%U;'0["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&ES
M<V5T*"1'3$]"04Q36R1V87)N86UE72D@/R`D1TQ/0D%,4ULD=F%R;F%M95T@
M.B`D9&5F875L=#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!
M9&1S(&$@;F%M93UV86QU92!P86ER('1O('1H92!E;F0@;V8@86X@55),+"!T
M86MI;F<@8V%R92!O9B!W:&5T:&5R"B`@("`@*B!T:&5R92!A<F4@97AI<W1I
M;F<@<&%R86UE=&5R<R!A;F0@=VAE=&AE<B!T;R!U<V4@/RP@)B!O<B`F86UP
M.R!A<R!T:&4*("`@("`J(&=L=64N("!!;&P@9&%T82!W:6QL(&)E('5R;&5N
M8V]D960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7)L("`@("`@
M(%1H92!54DP@=&\@;6]D:69Y"B`@("`@*B!`<&%R86T@;6EX960@)'!A<F%M
M971E<B`@16ET:&5R('1H92!N86UE/79A;'5E('!A:7(@=&\@861D"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@*$1%4%)%0T%4140I("UO<BT*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@;F%M92!V86QU
M92`M;W(M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@86X@87)R
M87D@;V8@;F%M92]V86QU92!P86ER<RX*("`@("`J($!P87)A;2!S=')I;F<@
M)'9A;'5E("`@("!)9B!S<&5C:69I960L('1H92!V86QU92!P87)T("@D<&%R
M86UE=&5R(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE
M;B!A<W-U;65D('1O(&IU<W0@8F4@=&AE('!A<F%M971E<B!N86UE*2X*("`@
M("`J($!P87)A;2!B;V]L96%N("1E;F-O9&4@("!)9B!T<G5E+"!A;F0@=V4@
M9&]N)W0@:&%V92!A<F=U;65N="!S97!A<F%T;W)S"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@>65T+"!T:&4@87)G=6UE;G0@<V5P87)A=&]R
M(&=E=',@96YC;V1E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(&UO9&EF:65D(%523"X*("`@("`J+PH@("`@9G5N8W1I;VX@861D4&%R
M86UE=&5R*"1U<FPL("1P87)A;65T97(L("1V86QU92`](&YU;&PL("1E;F-O
M9&4@/2!T<G5E*0H@("`@>PH@("`@("`@('-T871I8R`D=')A;G-L871I;VY?
M=&%B;&4["@H@("`@("`@(&EF("@A:7-S970H)'1R86YS;&%T:6]N7W1A8FQE
M*2D@>PH@("`@("`@("`@("`D=')A;G-L871I;VY?=&%B;&4@/2!A<G)A>5]F
M;&EP*&=E=%]H=&UL7W1R86YS;&%T:6]N7W1A8FQE*$A434Q?14Y4251)15,I
M*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1P87)A;65T97(I*2![
M"B`@("`@("`@("`@(')E='5R;B`D=7)L.PH@("`@("`@('T*"B`@("`@("`@
M+RH@36%K92!S=7)E('1O(&AA=F4@86X@87)R87DN("HO"B`@("`@("`@:68@
M*"%I<U]A<G)A>2@D<&%R86UE=&5R*2D@>PH@("`@("`@("`@("`D861D(#T@
M87)R87DH)'!A<F%M971E<B`]/B`D=F%L=64I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1A9&0@/2`D<&%R86UE=&5R.PH@("`@("`@('T*"B`@
M("`@("`@)&%R9R`]("1E;F-O9&4@/R`G)F%M<#LG(#H@)R8G.PH@("`@("`@
M(&EF("@H)'!O<R`]('-T<G!O<R@D=7)L+"`G/R<I*2`]/3T@9F%L<V4I('L*
M("`@("`@("`@("`@)&=L=64@/2`G/R<["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@+RH@0VAE8VL@:68@=&AE(&%R9W5M96YT('-E<&%R871O<B!H
M87,@8F5E;B!A;')E861Y"B`@("`@("`@("`@("`J(&AT;6QE;G1I=&EE<RUI
M>F5D(&EN('1H92!54DPN("HO"B`@("`@("`@("`@("1Q=65R>2`]('-U8G-T
M<B@D=7)L+"`D<&]S("L@,2D["B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H
M*"<O/2XJ/R9A;7`[+BH_/2\G+"`D<75E<GDI*2!["B`@("`@("`@("`@("`@
M("`D87)G(#T@)R9A;7`[)SL*("`@("`@("`@("`@("`@("1Q=65R>2`]('-T
M<G1R*"1Q=65R>2P@)'1R86YS;&%T:6]N7W1A8FQE*3L*("`@("`@("`@("`@
M?2!E;'-E:68@*'!R96=?;6%T8V@H)R\]+BH_)BXJ/STO)RP@)'%U97)Y*2D@
M>PH@("`@("`@("`@("`@("`@)&%R9R`]("<F)SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D<&%I<G,@/2!E>'!L;V1E*"1A<F<L("1Q=65R>2D["B`@
M("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E
M86-H("@D<&%I<G,@87,@)'!A:7(I('L*("`@("`@("`@("`@("`@("1P86ER
M(#T@97AP;&]D92@G/2<L("1P86ER+"`R*3L*("`@("`@("`@("`@("`@("1P
M87)A;7-;)'!A:7);,%U=(#T@8V]U;G0H)'!A:7(I(#T](#(@/R`D<&%I<ELQ
M72`Z("<G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1G;'5E(#T@)&%R
M9SL*("`@("`@("!]"@H@("`@("`@("1U<FQ?<&%R86US(#T@87)R87DH*3L*
M("`@("`@("!F;W)E86-H("@D861D(&%S("1P87)A;65T97(@/3X@)'9A;'5E
M*2!["B`@("`@("`@("`@(&EF("@A:7-S970H)'!A<F%M<ULD<&%R86UE=&5R
M72DI('L*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=F%L=64I*2![
M"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E(&%S("1V86PI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)'5R;%]P87)A;7-;72`]('5R
M;&5N8V]D92@D<&%R86UE=&5R*2`N("=;73TG("X@=7)L96YC;V1E*"1V86PI
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)'5R;%]P87)A;7-;72`]('5R;&5N
M8V]D92@D<&%R86UE=&5R*2`N("<])R`N('5R;&5N8V]D92@D=F%L=64I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!I9B`H8V]U;G0H)'5R;%]P87)A;7,I*2!["B`@("`@("`@("`@(')E
M='5R;B`D=7)L("X@)&=L=64@+B!I;7!L;V1E*"1A<F<L("1U<FQ?<&%R86US
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'5R;#L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(&YA;64]
M=F%L=64@<&%I<G,@9G)O;2!A(%523"X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1U<FP@("`@5&AE(%523"!T;R!M;V1I9GDN"B`@("`@*B!`<&%R
M86T@;6EX960@)')E;6]V92`@16ET:&5R(&$@<VEN9VQE('!A<F%M971E<B!T
M;R!R96UO=F4@;W(@86X@87)R87D*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!O9B!P87)A;65T97)S('1O(')E;6]V92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&UO9&EF:65D(%523"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5M;W9E4&%R86UE=&5R*"1U<FPL("1R96UO=F4I"B`@("![
M"B`@("`@("`@<W1A=&EC("1T<F%N<VQA=&EO;E]T86)L93L*"B`@("`@("`@
M:68@*"%I<W-E="@D=')A;G-L871I;VY?=&%B;&4I*2!["B`@("`@("`@("`@
M("1T<F%N<VQA=&EO;E]T86)L92`](&%R<F%Y7V9L:7`H9V5T7VAT;6Q?=')A
M;G-L871I;VY?=&%B;&4H2%1-3%]%3E1)5$E%4RDI.PH@("`@("`@('T*("`@
M("`@("!I9B`H(6ES7V%R<F%Y*"1R96UO=F4I*2!["B`@("`@("`@("`@("1R
M96UO=F4@/2!A<G)A>2@D<F5M;W9E*3L*("`@("`@("!]"@H@("`@("`@("\J
M(%)E='5R;B!I;6UE9&EA=&5L>2!I9B!T:&5R92!A<F4@;F\@<&%R86UE=&5R
M<R!T;R!R96UO=F4N("HO"B`@("`@("`@:68@*"@D<&]S(#T@<W1R<&]S*"1U
M<FPL("<_)RDI(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@)'5R
M;#L*("`@("`@("!]"@H@("`@("`@("1E;G1I=&EE<R`](&9A;'-E.PH@("`@
M("`@(&QI<W0H)'5R;"P@)'%U97)Y*2`](&5X<&QO9&4H)S\G+"`D=7)L+"`R
M*3L*"B`@("`@("`@+RH@0VAE8VL@:68@=&AE(&%R9W5M96YT('-E<&%R871O
M<B!H87,@8F5E;B!A;')E861Y"B`@("`@("`@("H@:'1M;&5N=&ET:65S+6EZ
M960@:6X@=&AE(%523"X@*B\*("`@("`@("!I9B`H<')E9U]M871C:"@G+STN
M*C\F86UP.RXJ/STO)RP@)'%U97)Y*2D@>PH@("`@("`@("`@("`D96YT:71I
M97,@/2!T<G5E.PH@("`@("`@("`@("`D<75E<GD@/2!S=')T<B@D<75E<GDL
M("1T<F%N<VQA=&EO;E]T86)L92D["B`@("`@("`@?0H*("`@("`@("`O*B!'
M970@=&AE(&QI<W0@;V8@<&%R86UE=&5R<RX@*B\*("`@("`@("`D<&%I<G,@
M/2!E>'!L;V1E*"<F)RP@)'%U97)Y*3L*("`@("`@("`D<&%R86US(#T@87)R
M87DH*3L*("`@("`@("!F;W)E86-H("@D<&%I<G,@87,@)'!A:7(I('L*("`@
M("`@("`@("`@)'!A:7(@/2!E>'!L;V1E*"<])RP@)'!A:7(L(#(I.PH@("`@
M("`@("`@("`D<&%R86US6R1P86ER6S!=72`](&-O=6YT*"1P86ER*2`]/2`R
M(#\@)'!A:7);,5T@.B`G)SL*("`@("`@("!]"@H@("`@("`@("\J(%)E;6]V
M92!T:&4@<&%R86UE=&5R<RX@*B\*("`@("`@("!F;W)E86-H("@D<F5M;W9E
M(&%S("1P87)A;2D@>PH@("`@("`@("`@("!U;G-E="@D<&%R86US6R1P87)A
M;5TI.PH@("`@("`@('T*"B`@("`@("`@:68@*"%C;W5N="@D<&%R86US*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'5R;#L*("`@("`@("!]"@H@("`@("`@
M("\J($9L871T96X@87)R87ES+@H@("`@("`@("`J($9)6$U%.B!S:&]U;&0@
M:&%N9&QE(&UO<F4@=&AA;B!O;F4@87)R87D@;&5V96P@<V]M96AO=RX@*B\*
M("`@("`@("`D861D(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D<&%R
M86US(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("!I9B`H:7-?87)R
M87DH)'9A;"DI('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V86P@87,@
M)'8I('L*("`@("`@("`@("`@("`@("`@("`D861D6UT@/2`D:V5Y("X@)UM=
M/2<@+B`D=CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1A9&1;72`]("1K97D@+B`G/2<@+B`D=F%L
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<75E<GD@/2!I
M;7!L;V1E*"<F)RP@)&%D9"D["B`@("`@("`@:68@*"1E;G1I=&EE<RD@>PH@
M("`@("`@("`@("`D<75E<GD@/2!H=&UL96YT:71I97,H)'%U97)Y*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D=7)L("X@)S\G("X@)'%U97)Y.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('5R;"!W:71H('1H92`G
M;F]C86-H92<@<&%R86UE=&5R(&%D9&5D+"!I9B!T:&4@8G)O=W-E<B!I<PH@
M("`@("H@8G5G9WD@86YD(&-A8VAE<R!O;&0@55),<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1U<FP@(%1H92!54DP@=&\@;6]D:69Y+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5Q=65S=&5D(%5222X*
M("`@("`J+PH@("`@9G5N8W1I;VX@;F]C86-H955R;"@D=7)L*0H@("`@>PH@
M("`@("`@('-T871I8R`D<F%N9%]N=6T["@H@("`@("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O0G)O=W-E<BYP:'`G.PH@("`@("`@("1B<F]W<V5R(#T@)D)R
M;W=S97(Z.G-I;F=L971O;B@I.PH*("`@("`@("`O*B!792!M87D@;F5E9"!T
M;R!S970@82!D=6UM>2!P87)A;65T97(@)VYO8V%C:&4G('-I;F-E('-O;64*
M("`@("`@("`@*B!B<F]W<V5R<R!D;R!N;W0@86QW87ES(&AO;F]R('1H92`G
M;F\M8V%C:&4G(&AE861E<BX@*B\*("`@("`@("!I9B`H)&)R;W=S97(M/FAA
M<U%U:7)K*"=C86-H95]S86UE7W5R;"<I*2!["B`@("`@("`@("`@(&EF("@A
M:7-S970H)')A;F1?;G5M*2D@>PH@("`@("`@("`@("`@("`@)')A;F1?;G5M
M(#T@8F%S95]C;VYV97)T*&UI8W)O=&EM92@I+"`Q,"P@,S8I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(')E='5R;B!5=&EL.CIA9&1087)A;65T97(H
M)'5R;"P@)VYO8V%C:&4G+"`D<F%N9%]N=6TI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B`D=7)L.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@82!H:61D96X@9F]R;2!I;G!U="!C;VYT
M86EN:6YG('1H92!S97-S:6]N(&YA;64@86YD(&ED+@H@("`@("H*("`@("`J
M($!P87)A;2!B;V]L96%N("1A<'!E;F1?<V5S<VEO;B`@,"`](&]N;'D@:68@
M;F5E9&5D+"`Q(#T@86QW87ES+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@:&ED9&5N(&9O<FT@:6YP=70L(&EF(&YE961E9"]R97%U97-T
M960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&9O<FU);G!U="@D87!P96YD7W-E
M<W-I;VX@/2`P*0H@("`@>PH@("`@("`@(&EF("@D87!P96YD7W-E<W-I;VX@
M/3T@,2!\?`H@("`@("`@("`@("`A:7-S970H)%]#3T]+245;<V5S<VEO;E]N
M86UE*"E=*2D@>PH@("`@("`@("`@("!R971U<FX@)SQI;G!U="!T>7!E/2)H
M:61D96XB(&YA;64](B<@+B!H=&UL<W!E8VEA;&-H87)S*'-E<W-I;VY?;F%M
M92@I*2`N("<B('9A;'5E/2(G("X@:'1M;'-P96-I86QC:&%R<RAS97-S:6]N
M7VED*"DI("X@(EPB("\^7&XB.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B`G)SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!0<FEN=',@82!H:61D96X@9F]R;2!I;G!U="!C;VYT86EN:6YG('1H92!S
M97-S:6]N(&YA;64@86YD(&ED+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L
M96%N("1A<'!E;F1?<V5S<VEO;B`@,"`](&]N;'D@:68@;F5E9&5D+"`Q(#T@
M86QW87ES+@H@("`@("HO"B`@("!F=6YC=&EO;B!P9F]R;4EN<'5T*"1A<'!E
M;F1?<V5S<VEO;B`](#`I"B`@("!["B`@("`@("`@96-H;R!5=&EL.CIF;W)M
M26YP=70H)&%P<&5N9%]S97-S:6]N*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($EF(&UA9VEC7W%U;W1E<U]G<&,@:7,@:6X@=7-E+"!R=6X@<W1R:7!S;&%S
M:&5S*"D@;VX@)'9A<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("8D
M=F%R("!4:&4@<W1R:6YG('1O('5N+7%U;W1E+"!I9B!N96-E<W-A<GDN"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@("1V87(L(&UI;G5S(&%N>2!M
M86=I8R!Q=6]T97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1I<W!E;$UA9VEC
M475O=&5S*"8D=F%R*0H@("`@>PH@("`@("`@('-T871I8R`D;6%G:6-?<75O
M=&5S.PH*("`@("`@("!I9B`H(6ES<V5T*"1M86=I8U]Q=6]T97,I*2!["B`@
M("`@("`@("`@("1M86=I8U]Q=6]T97,@/2!G971?;6%G:6-?<75O=&5S7V=P
M8R@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1M86=I8U]Q=6]T97,I('L*
M("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D=F%R*2D@>PH@("`@("`@("`@
M("`@("`@)'9A<B`]('-T<FEP<VQA<VAE<R@D=F%R*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@(&%R<F%Y7W=A;&LH)'9A<BP@87)R
M87DH)U5T:6PG+"`G9&ES<&5L36%G:6-1=6]T97,G*2D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=F%R.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1V5T<R!A(&9O<FT@=F%R:6%B;&4@9G)O;2!'150@;W(@
M4$]35"!D871A+"!S=')I<'!E9"!O9B!M86=I8R!Q=6]T97,@:68*("`@("`J
M(&YE8V5S<V%R>2X@268@=&AE('9A<FEA8FQE(&ES('-O;65H;W<@<V5T(&EN
M(&)O=&@@=&AE($=%5"!D871A(&%N9"!T:&4*("`@("`J(%!/4U0@9&%T82P@
M=&AE('9A;'5E(&9R;VT@=&AE(%!/4U0@9&%T82!W:6QL(&)E(')E='5R;F5D
M(&%N9"!T:&4@1T54"B`@("`@*B!V86QU92!W:6QL(&)E(&EG;F]R960N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%R("`@("`@5&AE(&YA;64@
M;V8@=&AE(&9O<FT@=F%R:6%B;&4@=&\@;&]O:R!F;W(N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1D969A=6QT("!4:&4@=F%L=64@=&\@<F5T=7)N(&EF('1H
M92!V87)I86)L92!I<R!N;W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@('1H97)E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M8VQE86YE9"!F;W)M('9A<FEA8FQE+"!O<B`D9&5F875L="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T1F]R;41A=&$H)'9A<BP@)&1E9F%U;'0@/2!N=6QL
M*0H@("`@>PH@("`@("`@(')E='5R;B`H*"1V86P@/2!5=&EL.CIG9710;W-T
M*"1V87(I*2`A/3T@;G5L;"D*("`@("`@("`@("`@/R`D=F%L(#H@571I;#HZ
M9V5T1V5T*"1V87(L("1D969A=6QT*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($=E=',@82!F;W)M('9A<FEA8FQE(&9R;VT@1T54(&1A=&$L('-T<FEP<&5D
M(&]F(&UA9VEC('%U;W1E<R!I9@H@("`@("H@;F5C97-S87)Y+B!4:&ES(&9U
M;F-T:6]N('=I;&P@3D]4(')E='5R;B!A(%!/4U0@=F%R:6%B;&4N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%R("`@("`@5&AE(&YA;64@;V8@
M=&AE(&9O<FT@=F%R:6%B;&4@=&\@;&]O:R!F;W(N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1D969A=6QT("!4:&4@=F%L=64@=&\@<F5T=7)N(&EF('1H92!V
M87)I86)L92!I<R!N;W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M('1H97)E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8VQE
M86YE9"!F;W)M('9A<FEA8FQE+"!O<B`D9&5F875L="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T1V5T*"1V87(L("1D969A=6QT(#T@;G5L;"D*("`@('L*
M("`@("`@("!R971U<FX@*&ES<V5T*"1?1T546R1V87)=*2D*("`@("`@("`@
M("`@/R!5=&EL.CID:7-P96Q-86=I8U%U;W1E<R@D7T=%5%LD=F%R72D*("`@
M("`@("`@("`@.B`D9&5F875L=#L*("`@('T*"B`@("`O*BH*("`@("`J($=E
M=',@82!F;W)M('9A<FEA8FQE(&9R;VT@4$]35"!D871A+"!S=')I<'!E9"!O
M9B!M86=I8R!Q=6]T97,@:68*("`@("`J(&YE8V5S<V%R>2X@5&AI<R!F=6YC
M=&EO;B!W:6QL($Y/5"!R971U<FX@82!'150@=F%R:6%B;&4N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=F%R("`@("`@5&AE(&YA;64@;V8@=&AE
M(&9O<FT@=F%R:6%B;&4@=&\@;&]O:R!F;W(N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1D969A=6QT("!4:&4@=F%L=64@=&\@<F5T=7)N(&EF('1H92!V87)I
M86)L92!I<R!N;W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('1H
M97)E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8VQE86YE
M9"!F;W)M('9A<FEA8FQE+"!O<B`D9&5F875L="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4&]S="@D=F%R+"`D9&5F875L="`](&YU;&PI"B`@("!["B`@
M("`@("`@<F5T=7)N("AI<W-E="@D7U!/4U1;)'9A<ETI*0H@("`@("`@("`@
M("`_(%5T:6PZ.F1I<W!E;$UA9VEC475O=&5S*"1?4$]35%LD=F%R72D*("`@
M("`@("`@("`@.B`D9&5F875L=#L*("`@('T*"B`@("`O*BH*("`@("`J($1E
M=&5R;6EN97,@=&AE(&QO8V%T:6]N(&]F('1H92!S>7-T96T@=&5M<&]R87)Y
M(&1I<F5C=&]R>2X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@02!D
M:7)E8W1O<GD@;F%M92!W:&EC:"!C86X@8F4@=7-E9"!F;W(@=&5M<"!F:6QE
M<RX*("`@("`J("`@("`@("`@("`@("`@("!2971U<FYS(&9A;'-E(&EF(&]N
M92!C;W5L9"!N;W0@8F4@9F]U;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%1E;7!$:7(H*0H@("`@>PH@("`@("`@("\J($9I<G-T+"!T<GD@4$A0)W,@
M=7!L;V%D7W1M<%]D:7(@9&ER96-T:79E+B`J+PH@("`@("`@("1T;7`@/2!I
M;FE?9V5T*"=U<&QO861?=&UP7V1I<B<I.PH*("`@("`@("`O*B!/=&AE<G=I
M<V4L('1R>2!T;R!D971E<FUI;F4@=&AE(%1-4$1)4B!E;G9I<F]N;65N=`H@
M("`@("`@("`J('9A<FEA8FQE+B`J+PH@("`@("`@(&EF("AE;7!T>2@D=&UP
M*2D@>PH@("`@("`@("`@("`D=&UP(#T@9V5T96YV*"=435!$25(G*3L*("`@
M("`@("!]"@H@("`@("`@("\J($EF('=E('-T:6QL(&-A;FYO="!D971E<FUI
M;F4@82!V86QU92P@=&AE;B!C>6-L92!T:')O=6=H(&$*("`@("`@("`@*B!L
M:7-T(&]F('!R97-E="!P;W-S:6)I;&ET:65S+B`J+PH@("`@("`@("1T;7!?
M;&]C871I;VYS(#T@87)R87DH)R]T;7`G+"`G+W9A<B]T;7`G+"`G8SI<5U54
M96UP)RP@)V,Z7'1E;7`G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V,Z7'=I;F1O=W-<=&5M<"<L("=C.EQW:6YN=%QT96UP)RD["B`@("`@
M("`@=VAI;&4@*&5M<'1Y*"1T;7`I("8F(&-O=6YT*"1T;7!?;&]C871I;VYS
M*2D@>PH@("`@("`@("`@("`D=&UP7V-H96-K(#T@87)R87E?<VAI9G0H)'1M
M<%]L;V-A=&EO;G,I.PH@("`@("`@("`@("!I9B`H0&ES7V1I<B@D=&UP7V-H
M96-K*2D@>PH@("`@("`@("`@("`@("`@)'1M<"`]("1T;7!?8VAE8VL["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($EF(&ET(&ES('-T
M:6QL(&5M<'1Y+"!W92!H879E(&9A:6QE9"P@<V\@<F5T=7)N(&9A;'-E.PH@
M("`@("`@("`J(&]T:&5R=VES92!R971U<FX@=&AE(&1I<F5C=&]R>2!D971E
M<FUI;F5D+B`J+PH@("`@("`@(')E='5R;B!E;7!T>2@D=&UP*2`_(&9A;'-E
M(#H@)'1M<#L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!T96UP
M;W)A<GD@9FEL96YA;64@9F]R('1H92!L:69E=&EM92!O9B!T:&4@<V-R:7!T
M+"!A;F0*("`@("`J("AO<'1I;VYA;&QY*2!R96=I<W1E<B!I="!T;R!B92!D
M96QE=&5D(&%T(')E<75E<W0@<VAU=&1O=VXN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<')E9FEX("`@4')E9FEX('1O(&UA:V4@=&AE('1E;7!O
M<F%R>2!N86UE(&UO<F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M(')E8V]G;FEZ86)L92X*("`@("`J($!P87)A;2!B;V]L96%N("1D96QE=&4@
M($1E;&5T92!T:&4@9FEL92!A="!T:&4@96YD(&]F('1H92!R97%U97-T/PH@
M("`@("H@0'!A<F%M('-T<FEN9R`D9&ER("`@("`@1&ER96-T;W)Y('1O(&-R
M96%T92!T:&4@=&5M<&]R87)Y(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D<V5C=7)E("!)9B!D96QE=&EN9R!F:6QE+"!S:&]U;&0@=V4@<V5C
M=7)E;'D@9&5L971E('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@9FEL93\*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%)E='5R
M;G,@=&AE(&9U;&P@<&%T:"UN86UE('1O('1H92!T96UP;W)A<GD@9FEL92X*
M("`@("`J("`@("`@("`@("`@("`@("`@4F5T=7)N<R!F86QS92!I9B!A('1E
M;7`@9FEL92!C;W5L9"!N;W0@8F4@8W)E871E9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T5&5M<$9I;&4H)'!R969I>"`]("<G+"`D9&5L971E(#T@=')U
M92P@)&1I<B`]("<G+"`D<V5C=7)E(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M:68@*&5M<'1Y*"1D:7(I('Q\("%I<U]D:7(H)&1I<BDI('L*("`@("`@("`@
M("`@)'1M<%]D:7(@/2!5=&EL.CIG971496UP1&ER*"D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'1M<%]D:7(@/2`D9&ER.PH@("`@("`@('T*
M"B`@("`@("`@:68@*&5M<'1Y*"1T;7!?9&ER*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D=&UP7V9I;&4@/2!T
M96UP;F%M*"1T;7!?9&ER+"`D<')E9FEX*3L*"B`@("`@("`@+RH@268@=&AE
M(&9I;&4@=V%S(&-R96%T960L('1H96X@<F5G:7-T97(@:70@9F]R(&1E;&5T
M:6]N(&%N9"!R971U<FX@*B\*("`@("`@("!I9B`H96UP='DH)'1M<%]F:6QE
M*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@:68@*"1D96QE=&4I('L*("`@("`@("`@("`@("`@
M(%5T:6PZ.F1E;&5T94%T4VAU=&1O=VXH)'1M<%]F:6QE+"!T<G5E+"`D<V5C
M=7)E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)'1M<%]F
M:6QE.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@
M82!T96UP;W)A<GD@9&ER96-T;W)Y(&EN('1H92!S>7-T96TG<R!T96UP;W)A
M<GD@9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1D
M96QE=&4@("!$96QE=&4@=&AE('1E;7!O<F%R>2!D:7)E8W1O<GD@870@=&AE
M(&5N9"!O9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('1H92!R
M97%U97-T/PH@("`@("H@0'!A<F%M('-T<FEN9R`D=&5M<%]D:7(@(%5S92!T
M:&ES('1E;7!O<F%R>2!D:7)E8W1O<GD@87,@=&AE(&1I<F5C=&]R>0H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@('=H97)E('1H92!T96UP;W)A
M<GD@9&ER96-T;W)Y('=I;&P@8F4@8W)E871E9"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE('!A=&AN86UE('1O('1H92!N97<@=&5M<&]R
M87)Y(&1I<F5C=&]R>2X*("`@("`J("`@("`@("`@("`@("`@("!2971U<FYS
M(&9A;'-E(&EF(&1I<F5C=&]R>2!N;W0@8W)E871E9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@8W)E871E5&5M<$1I<B@D9&5L971E(#T@=')U92P@)'1E;7!?
M9&ER(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=&5M<%]D
M:7(I*2!["B`@("`@("`@("`@("1T96UP7V1I<B`](%5T:6PZ.F=E=%1E;7!$
M:7(H*3L*("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D=&5M<%]D:7(I
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@("\J($=E="!T:&4@9FER<W0@."!C:&%R86-T97)S(&]F(&$@<F%N9&]M
M('-T<FEN9R!T;R!U<V4@87,@82!T96UP;W)A<GD*("`@("`@("`@("!D:7)E
M8W1O<GD@;F%M92X@*B\*("`@("`@("!D;R!["B`@("`@("`@("`@("1T96UP
M7V1I<B`N/2`G+R<@+B!S=6)S='(H8F%S95]C;VYV97)T*&UT7W)A;F0H*2`N
M(&UI8W)O=&EM92@I+"`Q,"P@,S8I+"`P+"`X*3L*("`@("`@("!]('=H:6QE
M("AF:6QE7V5X:7-T<R@D=&5M<%]D:7(I*3L*"B`@("`@("`@)&]L9%]U;6%S
M:R`]('5M87-K*#`P,#`I.PH@("`@("`@(&EF("@A;6MD:7(H)'1E;7!?9&ER
M+"`P-S`P*2D@>PH@("`@("`@("`@("`D=&5M<%]D:7(@/2!F86QS93L*("`@
M("`@("!](&5L<V5I9B`H)&1E;&5T92D@>PH@("`@("`@("`@("!5=&EL.CID
M96QE=&5!=%-H=71D;W=N*"1T96UP7V1I<BD["B`@("`@("`@?0H@("`@("`@
M('5M87-K*"1O;&1?=6UA<VLI.PH*("`@("`@("!R971U<FX@)'1E;7!?9&ER
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8V%N;VYI8V%L
M('!A=&@@;V8@=&AE('-T<FEN9RX@($QI:V4@4$A0)W,@8G5I;'0M:6X*("`@
M("`J(')E86QP871H*"D@97AC97!T('1H92!D:7)E8W1O<GD@;F5E9"!N;W0@
M97AI<W0@;VX@=&AE(&QO8V%L('-E<G9E<BX*("`@("`J"B`@("`@*B!!;&=O
M<FET:&EM(&QO;W-E;'D@8F%S960@;VX@8V]D92!F<F]M('1H92!097)L($9I
M;&4Z.E-P96,Z.E5N:7@@;6]D=6QE"B`@("`@*B`H=F5R<VEO;B`Q+C4I+@H@
M("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C`N-0H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'!A=&@@($$@9FEL92!P871H+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@8V%N;VYI8V%L:7IE9"!F:6QE('!A
M=&@N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E86Q0871H*"1P871H*0H@("`@
M>PH@("`@("`@("\J(%-T86YD87)D:7IE(&]N(%5.25@@9&ER96-T;W)Y('-E
M<&%R871O<G,N("HO"B`@("`@("`@:68@*'-U8G-T<BA02%!?3U,L(#`L(#,I
M(#T]("=724XG*2!["B`@("`@("`@("`@("1P871H(#T@<W1R7W)E<&QA8V4H
M)UQ<)RP@)R\G+"`D<&%T:"D["B`@("`@("`@?0H*("`@("`@("`O*B!X>"\O
M+R]X>"`M/B!X>"]X>`H@("`@("`@("`J('AX+RXO+B]X>"`M/B!X>"]X>"`J
M+PH@("`@("`@("1P871H(#T@<')E9U]R97!L86-E*&%R<F%Y*")\+RM\(BP@
M(D`H+UPN*2LH+WQ<6B@_(5QN*2E`(BDL(&%R<F%Y*"<O)RP@)R\G*2P@)'!A
M=&@I.PH*("`@("`@("`O*B`N+WAX("T^('AX("HO"B`@("`@("`@:68@*"1P
M871H("$]("<N+R<I('L*("`@("`@("`@("`@)'!A=&@@/2!P<F5G7W)E<&QA
M8V4H(GQ>*%PN+RDK?"(L("<G+"`D<&%T:"D["B`@("`@("`@?0H*("`@("`@
M("`O*B`O+BXO+BXO>'@@+3X@>'@@*B\*("`@("`@("`D<&%T:"`]('!R96=?
M<F5P;&%C92@B?%XO*%PN7"XO/RDK?"(L("<O)RP@)'!A=&@I.PH*("`@("`@
M("`O*B!X>"\@+3X@>'@@*B\*("`@("`@("!I9B`H)'!A=&@@(3T@)R\G*2![
M"B`@("`@("`@("`@("1P871H(#T@<')E9U]R97!L86-E*")\+UQ:*#\A7&XI
M?"(L("<G+"`D<&%T:"D["B`@("`@("`@?0H*("`@("`@("`O*B`O>'@O+BX@
M+3X@+R`J+PH@("`@("`@('=H:6QE("AS=')P;W,H)'!A=&@L("<O+BXG*2`A
M/3T@9F%L<V4I('L*("`@("`@("`@("`@)'!A=&@@/2!P<F5G7W)E<&QA8V4H
M(GPO6UXO72LO7"Y<+GPB+"`G)RP@)'!A=&@I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N(&5M<'1Y*"1P871H*2`_("<O)R`Z("1P871H.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5M;W9E<R!G:79E;B!E;&5M96YT<R!A="!R97%U
M97-T('-H=71D;W=N+@H@("`@("H*("`@("`J($EF(&-A;&QE9"!W:71H(&$@
M9FEL96YA;64@=VEL;"!D96QE=&4@=&AA="!F:6QE(&%T(')E<75E<W0@<VAU
M=&1O=VX[(&EF"B`@("`@*B!C86QL960@=VET:"!A(&1I<F5C=&]R>2!W:6QL
M(')E;6]V92!T:&%T(&1I<F5C=&]R>2!A;F0@86QL(&9I;&5S(&EN('1H870*
M("`@("`J(&1I<F5C=&]R>2!A="!R97%U97-T('-H=71D;W=N+@H@("`@("H*
M("`@("`J($EF(&-A;&QE9"!W:71H(&YO(&%R9W5M96YT<RP@<F5T=7)N(&%L
M;"!E;&5M96YT<R!T;R!B92!D96QE=&5D("AT:&ES"B`@("`@*B!S:&]U;&0@
M;VYL>2!B92!D;VYE(&)Y(%5T:6PZ.E]D96QE=&5!=%-H=71D;W=N*2X*("`@
M("`J"B`@("`@*B!4:&4@9FER<W0@=&EM92!I="!I<R!C86QL960L(&ET(&EN
M:71I86QI>F5S('1H92!A<G)A>2!A;F0@<F5G:7-T97)S"B`@("`@*B!5=&EL
M.CI?9&5L971E0713:'5T9&]W;B@I(&%S(&$@<VAU=&1O=VX@9G5N8W1I;VX@
M+2!N;R!N965D('1O(&1O('-O"B`@("`@*B!M86YU86QL>2X*("`@("`J"B`@
M("`@*B!4:&4@<V5C;VYD('!A<F%M971E<B!A;&QO=W,@=&AE('5N<F5G:7-T
M97)I;F<@;V8@<')E=FEO=7-L>2!R96=I<W1E<F5D"B`@("`@*B!E;&5M96YT
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE;F%M92`@(%1H
M92!F:6QE;F%M92!T;R!B92!D96QE=&5D(&%T('1H92!E;F0@;V8@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(')E<75E<W0N"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D<F5G:7-T97(@($EF('1R=64L('1H96X@<F5G
M:7-T97(@=&AE(&5L96UE;G0@9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&1E;&5T:6]N+"!O=&AE<G=I<V4L('5N<F5G:7-T97(@:70N
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<V5C=7)E("`@($EF(&1E;&5T:6YG
M(&9I;&4L('-H;W5L9"!W92!S96-U<F5L>2!D96QE=&4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&AE(&9I;&4_"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&1E;&5T94%T4VAU=&1O=VXH)&9I;&5N86UE(#T@9F%L<V4L("1R
M96=I<W1E<B`]('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1S96-U<F4@/2!F86QS92D*("`@('L*("`@("`@("!S=&%T:6,@)&1I<G,L
M("1F:6QE<RP@)'-E8W5R961E;#L*"B`@("`@("`@+RH@26YI=&EA;&EZ871I
M;VX@;V8@=F%R:6%B;&5S(&%N9"!S:'5T9&]W;B!F=6YC=&EO;G,N("HO"B`@
M("`@("`@:68@*&ES7VYU;&PH)&1I<G,I*2!["B`@("`@("`@("`@("1D:7)S
M(#T@87)R87DH*3L*("`@("`@("`@("`@)&9I;&5S(#T@87)R87DH*3L*("`@
M("`@("`@("`@)'-E8W5R961E;"`](&%R<F%Y*"D["B`@("`@("`@("`@(')E
M9VES=&5R7W-H=71D;W=N7V9U;F-T:6]N*&%R<F%Y*"=5=&EL)RP@)U]D96QE
M=&5!=%-H=71D;W=N)RDI.PH@("`@("`@('T*"B`@("`@("`@:68@*"1F:6QE
M;F%M92D@>PH@("`@("`@("`@("!I9B`H)')E9VES=&5R*2!["B`@("`@("`@
M("`@("`@("!I9B`H0&ES7V1I<B@D9FEL96YA;64I*2!["B`@("`@("`@("`@
M("`@("`@("`@)&1I<G-;)&9I;&5N86UE72`]('1R=64["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE<ULD9FEL
M96YA;65=(#T@=')U93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&EF("@D<V5C=7)E*2!["B`@("`@("`@("`@("`@("`@("`@)'-E8W5R
M961E;%LD9FEL96YA;65=(#T@=')U93L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@('5N<V5T*"1D:7)S
M6R1F:6QE;F%M95TI.PH@("`@("`@("`@("`@("`@=6YS970H)&9I;&5S6R1F
M:6QE;F%M95TI.PH@("`@("`@("`@("`@("`@=6YS970H)'-E8W5R961E;%LD
M9FEL96YA;65=*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B!A<G)A>2@D9&ER<RP@)&9I;&5S+"`D<V5C=7)E
M9&5L*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S
M(')E9VES=&5R960@9FEL97,@870@<F5Q=65S="!S:'5T9&]W;BX*("`@("`J
M"B`@("`@*B!4:&ES(&9U;F-T:6]N('-H;W5L9"!N979E<B!B92!C86QL960@
M;6%N=6%L;'D[(&ET(&ES(')E9VES=&5R960@87,@80H@("`@("H@<VAU=&1O
M=VX@9G5N8W1I;VX@8GD@571I;#HZ9&5L971E0713:'5T9&]W;B@I(&%N9"!C
M86QL960@875T;VUA=&EC86QL>0H@("`@("H@870@=&AE(&5N9"!O9B!T:&4@
M<F5Q=65S="X@270@=VEL;"!R971R:65V92!T:&4@;&ES="!O9B!F;VQD97)S
M(&%N9`H@("`@("H@9FEL97,@=&\@9&5L971E(&9R;VT@571I;#HZ9&5L971E
M0713:'5T9&]W;B@I)W,@<W1A=&EC(&%R<F%Y+"!A;F0@=&AE;@H@("`@("H@
M:71E<F%T92!T:')O=6=H+"!D96QE=&EN9R!F;VQD97)S(')E8W5R<VEV96QY
M+@H@("`@("H*("`@("`J($-O;G1A:6YS(&-O9&4@9G)O;2!G<&=?9G5N8W1I
M;VYS+G!H<"X*("`@("`J($-O<'ER:6=H="`H8RD@,C`P,BTR,#`S($)R879E
M<F]C:R!696YT=7)E<PH@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!F=6YC=&EO;B!?9&5L971E0713:'5T9&]W;B@I"B`@("![
M"B`@("`@("`@)')E9VES=&5R960@/2!5=&EL.CID96QE=&5!=%-H=71D;W=N
M*"D["B`@("`@("`@)&1I<G,@/2`D<F5G:7-T97)E9%LP73L*("`@("`@("`D
M9FEL97,@/2`D<F5G:7-T97)E9%LQ73L*("`@("`@("`D<V5C=7)E(#T@)')E
M9VES=&5R961;,ET["@H@("`@("`@(&9O<F5A8V@@*"1F:6QE<R!A<R`D9FEL
M92`]/B`D=F%L*2!["B`@("`@("`@("`@("\J($1E;&5T92!F:6QE<R`J+PH@
M("`@("`@("`@("!I9B`H)'9A;"`F)B!`9FEL95]E>&ES=',H)&9I;&4I*2![
M"B`@("`@("`@("`@("`@("`O*B!3:&]U;&0@=V4@<V5C=7)E;'D@9&5L971E
M('1H92!F:6QE(&)Y(&]V97)W<FET:6YG('1H90H@("`@("`@("`@("`@("`@
M("`@9&%T82!W:71H(&$@<F%N9&]M('-T<FEN9S\@*B\*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D<V5C=7)E6R1F:6QE72DI('L*("`@("`@("`@("`@
M("`@("`@("`D<F%N9&]M7W-T<B`]("<G.PH@("`@("`@("`@("`@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\(&9I;&5S:7IE*"1F:6QE*3L@)&DK*RD@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D<F%N9&]M7W-T<B`N/2!C:'(H;71?
M<F%N9"@P+"`R-34I*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@)&9P(#T@9F]P96XH)&9I;&4L("=R*R<I.PH@("`@("`@
M("`@("`@("`@("`@(&9W<FET92@D9G`L("1R86YD;VU?<W1R*3L*("`@("`@
M("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@($!U;FQI;FLH)&9I;&4I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D9&ER<R!A<R`D9&ER(#T^
M("1V86PI('L*("`@("`@("`@("`@+RH@1&5L971E(&1I<F5C=&]R:65S("HO
M"B`@("`@("`@("`@(&EF("@D=F%L("8F($!F:6QE7V5X:7-T<R@D9&ER*2D@
M>PH@("`@("`@("`@("`@("`@+RH@36%K92!S=7)E(&1I<F5C=&]R>2!I<R!E
M;7!T>2X@*B\*("`@("`@("`@("`@("`@("1D:7)?8VQA<W,@/2!D:7(H)&1I
M<BD["B`@("`@("`@("`@("`@("!W:&EL92`H9F%L<V4@(3T]("@D96YT<GD@
M/2`D9&ER7V-L87-S+3YR96%D*"DI*2!["B`@("`@("`@("`@("`@("`@("`@
M:68@*"1E;G1R>2`A/2`G+B<@)B8@)&5N=')Y("$]("<N+B<I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@0'5N;&EN:R@D9&ER("X@)R\G("X@)&5N=')Y
M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D9&ER7V-L87-S+3YC;&]S92@I.PH@("`@("`@("`@
M("`@("`@0')M9&ER*"1D:7(I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@3W5T<'5T<R!J879A<V-R:7!T(&-O9&4@
M=&\@8VQO<V4@=&AE(&-U<G)E;G0@=VEN9&]W+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&-O9&4@($%N>2!A9&1T:6]N86P@:F%V87-C<FEP="!C
M;V1E('1O(')U;B!B969O<F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M(&-L;W-I;F<@=&AE('=I;F1O=RX*("`@("`J+PH@("`@9G5N8W1I;VX@8VQO
M<V57:6YD;W=*4R@D8V]D92`]("<G*0H@("`@>PH@("`@("`@(&5C:&\@)SQS
M8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CXG("X@)&-O9&4@+@H@("`@
M("`@("`@("`G=VEN9&]W+F-L;W-E*"D[/"]S8W)I<'0^)SL*("`@('T*"B`@
M("`O*BH*("`@("`J($-A8VAE<R!T:&4@<F5S=6QT(&]F(&5X=&5N<VEO;E]L
M;V%D960H*2!C86QL<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1E>'0@(%1H92!E>'1E;G-I
M;VX@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@($ES('1H
M92!E>'1E;G-I;VX@;&]A9&5D/PH@("`@("HO"B`@("!F=6YC=&EO;B!E>'1E
M;G-I;VY%>&ES=',H)&5X="D*("`@('L*("`@("`@("!S=&%T:6,@)&-A8VAE
M(#T@87)R87DH*3L*"B`@("`@("`@:68@*"%I<W-E="@D8V%C:&5;)&5X=%TI
M*2!["B`@("`@("`@("`@("1C86-H95LD97AT72`](&5X=&5N<VEO;E]L;V%D
M960H)&5X="D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-A8VAE6R1E
M>'1=.PH@("`@?0H*("`@("\J*@H@("`@("H@5')I97,@=&\@;&]A9"!A(%!(
M4"!E>'1E;G-I;VXL(&)E:&%V:6YG(&-O<G)E8W1L>2!F;W(@86QL(&]P97)A
M=&EN9PH@("`@("H@<WES=&5M<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1E>'0@(%1H92!E>'1E;G-I;VX@=&\@;&]A9"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE(&5X=&5N<VEO;B!I<R!N
M;W<@;&]A9&5D+"!F86QS92!I9B!N;W0N"B`@("`@*B`@("`@("`@("`@("`@
M("`@(%1R=64@8V%N(&UE86X@=&AA="!T:&4@97AT96YS:6]N('=A<R!A;')E
M861Y(&QO861E9"P*("`@("`J("`@("`@("`@("`@("`@("`@3U(@=V%S(&QO
M861E9"!D>6YA;6EC86QL>2X*("`@("`J+PH@("`@9G5N8W1I;VX@;&]A9$5X
M=&5N<VEO;B@D97AT*0H@("`@>PH@("`@("`@("\J($EF("1E>'0@:7,@86QR
M96%D>2!L;V%D960L(&]U<B!W;W)K(&ES(&1O;F4N("HO"B`@("`@("`@:68@
M*%5T:6PZ.F5X=&5N<VEO;D5X:7-T<R@D97AT*2D@>PH@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("\J(%-E92!I9B!W92!C
M86X@8V%L;"!D;"@I(&%T(&%L;"P@8GD@=&AE(&-U<G)E;G0@:6YI('-E='1I
M;F=S+B`J+PH@("`@("`@(&EF("@H:6YI7V=E="@G96YA8FQE7V1L)RD@(3T@
M,2D@?'P@*&EN:5]G970H)W-A9F5?;6]D92<I(#T](#$I*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("AS=6)S
M='(H4$A07T]3+"`P+"`S*2`]/2`G5TE.)RD@>PH@("`@("`@("`@("`D<W5F
M9FEX(#T@)V1L;"<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<W=I
M=&-H("A02%!?3U,I('L*("`@("`@("`@("`@8V%S92`G2%`M55@G.@H@("`@
M("`@("`@("`@("`@)'-U9F9I>"`]("=S;"<["B`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)T%)6"<Z"B`@("`@("`@("`@("`@
M("`D<W5F9FEX(#T@)V$G.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!C87-E("=/4U@G.@H@("`@("`@("`@("`@("`@)'-U9F9I>"`]
M("=B=6YD;&4G.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("!D969A=6QT.@H@("`@("`@("`@("`@("`@)'-U9F9I>"`]("=S;R<["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!`9&PH)&5X
M="`N("<N)R`N("1S=69F:7@I('Q\($!D;"@G<&AP7R<@+B`D97AT("X@)RXG
M("X@)'-U9F9I>"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@
M86QL(&YE8V5S<V%R>2!P87)A;65T97)S(&9O<B!A(&1R:79E<B=S(&-O;F9I
M9W5R871I;VX@87)E('-E=`H@("`@("H@86YD(')E='5R;G,@82!014%27T5R
M<F]R(&EF('-O;65T:&EN9R!I<R!M:7-S:6YG+@H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R86US("`@5&AE(&-O;F9I9W5R871I;VX@87)R87D@
M=VET:"!A;&P@<&%R86UE=&5R<RX*("`@("`J($!P87)A;2!A<G)A>2`D9FEE
M;&1S("`@06X@87)R87D@=VET:"!M86YD871O<GD@<&%R86UE=&5R(&YA;65S
M(&9O<B!T:&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&1R:79E
M<BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@5&AE(&-L96%R('1E
M>'0@;F%M92!O9B!T:&4@9')I=F5R+B!)9B!N;W0*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@<W!E8VEF:65D+"!T:&4@87!P;&EC871I;VX@;F%M
M92!W:6QL(&)E('5S960N"B`@("`@*B!`<&%R86T@87)R87D@)&EN9F\@("`@
M($$@:&%S:"!C;VYT86EN:6YG(&1E=&%I;&5D(&EN9F]R;6%T:6]N(&%B;W5T
M('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!D<FEV97(N(%=I
M;&P@8F4@<&%S<V5D(&%S('1H92!U<V5R26YF;R!T;R!T:&4*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@4$5!4E]%<G)O<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@87-S97)T1')I=F5R0V]N9FEG*"1P87)A;7,L("1F:65L9',L
M("1N86UE+"`D:6YF;R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)&EN9F\@
M/2!A<G)A>5]M97)G92@D:6YF;RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"=P87)A;7,G(#T^("1P87)A;7,L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G9FEE;&1S)R`]/B`D9FEE;&1S+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^("1N86UE
M*2D["@H@("`@("`@(&EF("@A:7-?87)R87DH)'!A<F%M<RD@?'P@(6-O=6YT
M*"1P87)A;7,I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4BYP
M:'`G.PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ=&AR;W=%<G)O<BAS<')I
M;G1F*%\H(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B`E<RXB*2P@)&YA;64I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!(3U)$15]%4E)/4E]$4DE615)?0T].1DE'7TU)4U-)3D<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O*3L*
M("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1F:65L9',@87,@)&9I96QD
M*2!["B`@("`@("`@("`@(&EF("@A:7-S970H)'!A<F%M<ULD9FEE;&1=*2D@
M>PH@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+G!H<"<["B`@
M("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ=&AR;W=%<G)O<BAS<')I;G1F
M*%\H(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R
M871I;VXN(BDL("1F:65L9"P@)&YA;64I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@2$]21$5?15)23U)?1%))5D527T-/3D9)
M1RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I
M;F9O*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@82!F;W)M870@<W1R:6YG('1O(&)E('5S960@8GD@
M<W1R9G1I;64H*2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F;W)M
M870@($$@9F]R;6%T('-T<FEN9R!A<R!U<V5D(&)Y(&1A=&4H*2X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@02!F;W)M870@<W1R:6YG(&%S('-I
M;6EL87(@87,@<&]S<VEB;&4@=&\@)&9O<FUA="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9&%T93)S=')F=&EM92@D9F]R;6%T*0H@("`@>PH@("`@("`@("1D
M871E4WEM8F]L<R`](&%R<F%Y*"=A)RP@)T$G+"`G9"<L("=$)RP@)T8G+"`G
M9R<L("=')RP@)V@G+"`G2"<L("=I)RP@)VHG+"`G;"<L("=M)RP@)TTG+"`G
M;B<L("=R)RP@)W,G+"`G5"<L("=W)RP@)U<G+"`G>2<L("=9)RP@)WHG+"`G
M;2]D+UDG+"`G32<L(")<;B(L("=G.FD@82<L("='.FDG+"`B7'0B+"`G2#II
M.G,G+"`G)2<I.PH@("`@("`@("1S=')F=&EM95-Y;6)O;',@/2!A<G)A>2@G
M)7`G+"`G)7`G+"`G)60G+"`G)6$G+"`G)4(G+"`G)4DG+"`G)4@G+"`G)4DG
M+"`G)4@G+"`G)4TG+"`G)64G+"`G)4$G+"`G)6TG+"`G)6(G+"`G)6TG+"`G
M)6$L("5E("5B("59("54("5:)RP@)R53)RP@)R5:)RP@)R5W)RP@)R56)RP@
M)R5Y)RP@)R59)RP@)R5J)RP@)R5$)RP@)R5H)RP@)R5N)RP@)R5R)RP@)R52
M)RP@)R5T)RP@)R54)RP@)R4E)RD["@H@("`@("`@("1R97-U;'0@/2`G)SL*
M("`@("`@("!F;W(@*"1P;W,@/2`P.R`D<&]S(#P@<W1R;&5N*"1F;W)M870I
M.RD@>PH@("`@("`@("`@("!F;W(@*"1S>6UB;VP@/2`P.R`D<WEM8F]L(#P@
M8V]U;G0H)&1A=&53>6UB;VQS*3L@)'-Y;6)O;"LK*2!["B`@("`@("`@("`@
M("`@("!I9B`H<W1R<&]S*"1F;W)M870L("1D871E4WEM8F]L<ULD<WEM8F]L
M72P@)'!O<RD@/3T]("1P;W,I('L*("`@("`@("`@("`@("`@("`@("`D<F5S
M=6QT("X]("1S=')F=&EM95-Y;6)O;'-;)'-Y;6)O;%T["B`@("`@("`@("`@
M("`@("`@("`@)'!O<R`K/2!S=')L96XH)&1A=&53>6UB;VQS6R1S>6UB;VQ=
M*3L*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU92`R.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1R97-U;'0@+CT@
M<W5B<W1R*"1F;W)M870L("1P;W,L(#$I.PH@("`@("`@("`@("`D<&]S*RL[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@82!F;W)M870@<W1R:6YG('1O(&)E('5S
M960@8GD@9&%T92@I+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9O
M<FUA="`@02!F;W)M870@<W1R:6YG(&%S('5S960@8GD@<W1R9G1I;64H*2X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@02!F;W)M870@<W1R:6YG
M(&%S('-I;6EL87(@87,@<&]S<VEB;&4@=&\@)&9O<FUA="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<W1R9G1I;64R9&%T92@D9F]R;6%T*0H@("`@>PH@("`@
M("`@("1D871E4WEM8F]L<R`](&%R<F%Y*"=A)RP@)T$G+"`G9"<L("=$)RP@
M)T8G+"`G9R<L("=')RP@)V@G+"`G2"<L("=I)RP@)VHG+"`G;"<L("=M)RP@
M)TTG+"`G;B<L("=R)RP@)W,G+"`G5"<L("=W)RP@)U<G+"`G>2<L("=9)RP@
M)WHG+"`G;2]D+UDG+"`G32<L(")<;B(L("=G.FD@82<L("='.FDG+"`B7'0B
M+"`G2#II.G,G+"`G)2<I.PH@("`@("`@("1S=')F=&EM95-Y;6)O;',@/2!A
M<G)A>2@G)7`G+"`G)7`G+"`G)60G+"`G)6$G+"`G)4(G+"`G)4DG+"`G)4@G
M+"`G)4DG+"`G)4@G+"`G)4TG+"`G)64G+"`G)4$G+"`G)6TG+"`G)6(G+"`G
M)6TG+"`G)6$L("5E("5B("59("54("5:)RP@)R53)RP@)R5:)RP@)R5W)RP@
M)R56)RP@)R5Y)RP@)R59)RP@)R5J)RP@)R5$)RP@)R5H)RP@)R5N)RP@)R5R
M)RP@)R52)RP@)R5T)RP@)R54)RP@)R4E)RD["@H@("`@("`@(')E='5R;B!S
M=')?<F5P;&%C92@D<W1R9G1I;653>6UB;VQS+"`D9&%T95-Y;6)O;',L("1F
M;W)M870I.PH@("`@?0H*?0H*:68@*"%F=6YC=&EO;E]E>&ES=',H)U\G*2D@
M>PH@("`@9G5N8W1I;VX@7R@D<W1R:6YG*0H@("`@>PH@("`@("`@(')E='5R
M;B`D<W1R:6YG.PH@("`@?0H*("`@(&9U;F-T:6]N(&)I;F1T97AT9&]M86EN
M*"D*("`@('L*("`@('T*"B`@("!F=6YC=&EO;B!T97AT9&]M86EN*"D*("`@
M('L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]687)I86)L97,N<&AP````````````
M````````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,34U-C0`,3`U,34T,S,W-3(`
M,#(R,3(P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+U5T:6PN<&AP)SL*<F5Q
M=6ER95]O;F-E("=(;W)D92]!<G)A>2YP:'`G.PH*+RHJ"B`J(%9A<FEA8FQE
M<SHZ(&-L87-S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]5=&EL+U9A<FEA
M8FQE<RYP:'`L=B`Q+C@N,3`N-B`R,#`V+S`S+S(X(#$R.C,Q.C$R(&IA;B!%
M>'`@)`H@*@H@*B!`875T:&]R("!2;V)E<G0@12X@0V]Y;&4@/')O8F5R=&5C
M;WEL94!H;W1M86EL+F-O;3X*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J($!P86-K86=E($AO<F1E7U5T:6P*("HO
M"F-L87-S(%9A<FEA8FQE<R!["@H@("`@=F%R("1?=F%R<SL*("`@('9A<B`D
M7V5X<&5C=&5D5F%R:6%B;&5S(#T@87)R87DH*3L*"B`@("!F=6YC=&EO;B!6
M87)I86)L97,H)'9A<G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("AI
M<U]N=6QL*"1V87)S*2D@>PH@("`@("`@("`@("`D=F%R<R`](%5T:6PZ.F1I
M<W!E;$UA9VEC475O=&5S*"1?4D5154535"D["B`@("`@("`@?0H@("`@("`@
M(&EF("AI<W-E="@D=F%R<ULG7V9O<FUV87)S)UTI*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?97AP96-T961687)I86)L97,@/2!`=6YS97)I86QI>F4H)'9A
M<G-;)U]F;W)M=F%R<R==*3L*("`@("`@("`@("`@=6YS970H)'9A<G-;)U]F
M;W)M=F%R<R==*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]V87)S(#T@
M)'9A<G,["B`@("!]"@H@("`@9G5N8W1I;VX@)F=E=$1E9F%U;'1687)I86)L
M97,H*0H@("`@>PH@("`@("`@("1V87)S(#T@)FYE=R!687)I86)L97,H571I
M;#HZ9&ES<&5L36%G:6-1=6]T97,H)%]215%515-4*2D["B`@("`@("`@<F5T
M=7)N("1V87)S.PH@("`@?0H*("`@(&9U;F-T:6]N(&5X:7-T<R@D=F%R;F%M
M92D*("`@('L*("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]E>'!E8W1E9%9A
M<FEA8FQE<RD@)B8*("`@("`@("`@("`@)'1H:7,M/E]E>&ES=',H)'1H:7,M
M/E]E>'!E8W1E9%9A<FEA8FQE<RP@)'9A<FYA;64L(&9A;'-E*2D@>PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?97AI<W1S*"1T:&ES+3Y?=F%R<RP@)'9A<FYA;64L(&9A;'-E
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!G970H)'9A<FYA;64I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]G971%>&ES=',H)'1H:7,M/E]V87)S+"`D=F%R;F%M
M92P@)'9A;'5E*3L*("`@("`@("!R971U<FX@)'9A;'5E.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=$5X:7-T<R@D=F%R;F%M92P@)B1E>&ES=',I"B`@("![
M"B`@("`@("`@)&5X:7-T<R`]("1T:&ES+3Y?9V5T17AI<W1S*"1T:&ES+3Y?
M=F%R<RP@)'9A<FYA;64L("1V86QU92D["B`@("`@("`@<F5T=7)N("1V86QU
M93L*("`@('T*"B`@("!F=6YC=&EO;B!S970H)'9A<FYA;64L("1V86QU92D*
M("`@('L*("`@("`@("`D:V5Y<R`](&%R<F%Y*"D["B`@("`@("`@:68@*"%(
M;W)D95]!<G)A>3HZ9V5T07)R87E087)T<R@D=F%R;F%M92P@)&)A<V4L("1K
M97ES*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W9A<G-;)'9A<FYA;65=(#T@
M)'9A;'5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&%R<F%Y7W5N
M<VAI9G0H)&ME>7,L("1B87-E*3L*("`@("`@("`@("`@)'!L86-E(#T@)B1T
M:&ES+3Y?=F%R<SL*"B`@("`@("`@("`@('=H:6QE("AC;W5N="@D:V5Y<RDI
M('L*("`@("`@("`@("`@("`@("1K97D@/2!A<G)A>5]S:&EF="@D:V5Y<RD[
M"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1P;&%C95LD:V5Y72DI('L*
M("`@("`@("`@("`@("`@("`@("`D<&QA8V5;)&ME>5T@/2!A<G)A>2@I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'!L86-E(#T@)B1P
M;&%C95LD:V5Y73L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'!L86-E
M(#T@)'9A;'5E.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!M97)G
M92@D=F%R<RD*("`@('L*("`@("`@("!F;W)E86-H("@D=F%R<R!A<R`D=F%R
M;F%M92`]/B`D=F%L=64I('L*("`@("`@("`@("`@)'1H:7,M/G-E="@D=F%R
M;F%M92P@)'9A;'5E*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@
M861D*"1V87)N86UE+"`D=F%L=64I"B`@("!["B`@("`@("`@:68@*"1T:&ES
M+3YE>&ES=',H)'9A<FYA;64I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]V87)S6R1V87)N86UE72`]
M("1V86QU93L*("`@('T*"B`@("!F=6YC=&EO;B!R96UO=F4H)'9A<FYA;64I
M"B`@("!["B`@("`@("`@2&]R9&5?07)R87DZ.F=E=$%R<F%Y4&%R=',H)'9A
M<FYA;64L("1B87-E+"`D:V5Y<RD["B`@("`@("`@:68@*"%I<U]N=6QL*"1B
M87-E*2D@>PH@("`@("`@("`@("`D<'1R(#T@)B1T:&ES+3Y?=F%R<ULD8F%S
M95T["B`@("`@("`@("`@("1E;F0@/2!C;W5N="@D:V5Y<RD@+2`Q.PH@("`@
M("`@("`@("!F;W)E86-H("@D:V5Y<R!A<R`D:V5Y(#T^("1V86PI('L*("`@
M("`@("`@("`@("`@(&EF("@A:7-S970H)'!T<ELD=F%L72DI('L*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&EF("@D96YD(#T]("1K97DI('L*("`@("`@("`@("`@("`@
M("`@("!A<G)A>5]S<&QI8V4H)'!T<BP@87)R87E?<V5A<F-H*"1V86PL(&%R
M<F%Y7VME>7,H)'!T<BDI+"`Q*3L*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@)'!T<B`]("8D<'1R6R1V86Q=.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@=6YS970H)'1H:7,M/E]V87)S6R1V87)N86UE72D["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1FEN9"!O=70@=VAE=&AE
M<B!O<B!N;W0@)'9A<FYA;64@=V%S('-E="!I;B`D87)R87DN"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("`@)&%R<F%Y("`@("`@("`@("`@("`@("`@(%1H92!A<G)A>2!T;R!S
M96%R8V@@:6X@*'5S=6%L;'D*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!E:71H97(@)'1H:7,M/E]V87)S(&]R"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]E>'!E8W1E9%9A<FEA8FQE<RDN"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`D=F%R;F%M92`@("`@("`@("`@("`@("`@5&AE(&YA;64@;V8@=&AE
M('9A<FEA8FQE('1O(&QO;VL*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!F;W(N"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D8VAE8VM%>'!E8W1E9%9A<FEA8FQE<R`@268@=V4@9&]N)W0@9FEN9"`D
M=F%R;F%M92P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!S:&]U;&0@=V4@8VAE8VL*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V5X<&5C=&5D
M5F%R:6%B;&5S('1O('-E90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF('-H;W5L9"!H879E(&5X:7-T960@*&QI
M:V4@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&-H96-K8F]X(&]R('-E;&5C="!M=6QT:7!L92DN"B`@("`@*@H@
M("`@("H@0')E='5R;B`@5VAE=&AE<B!O<B!N;W0@=&AE('9A<FEA8FQE('=A
M<R!S970@*&]R+"!I9B!W92=V92!C:&5C:V5D"B`@("`@*B`@("`@("`@("`D
M=&AI<RT^7V5X<&5C=&5D5F%R:6%B;&5S+"!S:&]U;&0@:&%V92!B965N('-E
M="DN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]E>&ES=',H)&%R<F%Y+"`D=F%R
M;F%M92P@)&-H96-K17AP96-T961687)I86)L97,@/2!T<G5E*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7V=E=$5X:7-T<R@D87)R87DL("1V87)N
M86UE+"`D=F%L=64L("1C:&5C:T5X<&5C=&5D5F%R:6%B;&5S*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($9E=&-H('1H92!R97%U97-T960@=F%R:6%B;&4@
M*"1V87)N86UE*2!I;G1O("1V86QU92P@86YD(')E='5R;@H@("`@("H@=VAE
M=&AE<B!O<B!N;W0@=&AE('9A<FEA8FQE('=A<R!S970@:6X@)&%R<F%Y+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`@("1A<G)A>2`@("`@("`@("`@("`@("`@("!4:&4@87)R
M87D@=&\@<V5A<F-H(&EN("AU<W5A;&QY"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@96ET:&5R("1T:&ES+3Y?=F%R
M<R!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?97AP96-T961687)I86)L97,I+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`@)'9A<FYA;64@("`@("`@("`@("`@("`@(%1H92!N86UE
M(&]F('1H92!V87)I86)L92!T;R!L;V]K"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R+@H@("`@("H@0'!A<F%M
M(&UI>&5D("`F)'9A;'5E("`@("`@("`@("`@("`@("`@("1V87)N86UE)W,@
M=F%L=64@9V5T<R!A<W-I9VYE9`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('1O+@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H:7,@=F%R:6%B;&4N"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D8VAE8VM%>'!E8W1E9%9A<FEA8FQE<R`@
M268@=V4@9&]N)W0@9FEN9"`D=F%R;F%M92P*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S:&]U;&0@=V4@8VAE8VL*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V5X<&5C=&5D5F%R:6%B;&5S('1O('-E90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF(&ET('-H
M;W5L9"!H879E(&5X:7-T960@*&QI:V4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A(&-H96-K8F]X(&]R('-E;&5C
M="!M=6QT:7!L92DN"B`@("`@*@H@("`@("H@0')E='5R;B`@5VAE=&AE<B!O
M<B!N;W0@=&AE('9A<FEA8FQE('=A<R!S970@*&]R+"!I9B!W92=V92!C:&5C
M:V5D"B`@("`@*B`@("`@("`@("`D=&AI<RT^7V5X<&5C=&5D5F%R:6%B;&5S
M+"!S:&]U;&0@:&%V92!B965N('-E="DN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]G971%>&ES=',H)&%R<F%Y+"`D=F%R;F%M92P@)B1V86QU92P@)&-H96-K
M17AP96-T961687)I86)L97,@/2!T<G5E*0H@("`@>PH@("`@("`@(&EF("A(
M;W)D95]!<G)A>3HZ9V5T07)R87E087)T<R@D=F%R;F%M92P@)&)A<V4L("1K
M97ES*2D@>PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1A<G)A>5LD8F%S95TI
M*2!["B`@("`@("`@("`@("`@("`D=F%L=64@/2!N=6QL.PH@("`@("`@("`@
M("`@("`@+R\@268@=V4G<F4@<W5P<&]S960@=&\@8VAE8VL@)'1H:7,M/E]E
M>'!E8W1E9%9A<FEA8FQE<RP@9&\@<V\L"B`@("`@("`@("`@("`@("`O+R!B
M=70@;6%K92!S=7)E(&YO="!T;R!C:&5C:R!I="!A9V%I;BX*("`@("`@("`@
M("`@("`@(')E='5R;B`D8VAE8VM%>'!E8W1E9%9A<FEA8FQE<R`_("1T:&ES
M+3Y?97AI<W1S*"1T:&ES+3Y?97AP96-T961687)I86)L97,L("1V87)N86UE
M+"!F86QS92D@.B!F86QS93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1S96%R8VAS<&%C92`]("8D87)R87E;)&)A<V5=.PH@("`@
M("`@("`@("`@("`@=VAI;&4@*&-O=6YT*"1K97ES*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1K97D@/2!A<G)A>5]S:&EF="@D:V5Y<RD["B`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D<V5A<F-H<W!A8V5;)&ME>5TI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`](&YU;&P["B`@("`@
M("`@("`@("`@("`@("`@("`@("\O($EF('=E)W)E('-U<'!O<V5D('1O(&-H
M96-K"B`@("`@("`@("`@("`@("`@("`@("`@("\O("1T:&ES+3Y?97AP96-T
M961687)I86)L97,L(&1O('-O+"!B=70@;6%K90H@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!S=7)E(&YO="!T;R!C:&5C:R!I="!A9V%I;BX*("`@("`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1C:&5C:T5X<&5C=&5D5F%R:6%B
M;&5S(#\@)'1H:7,M/E]E>&ES=',H)'1H:7,M/E]E>'!E8W1E9%9A<FEA8FQE
M<RP@)'9A<FYA;64L(&9A;'-E*2`Z(&9A;'-E.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`D<V5A<F-H<W!A8V4@/2`F)'-E
M87)C:'-P86-E6R1K97E=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)'9A;'5E(#T@)'-E87)C:'-P86-E.PH@("`@("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D=F%L=64@/2!I<W-E="@D87)R87E;)'9A<FYA;65=*2`_
M("1A<G)A>5LD=F%R;F%M95T@.B!N=6QL.PH@("`@("`@("`@("!I9B`H(6ES
M7VYU;&PH)'9A;'5E*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[
M"B`@("`@("`@("`@('T@96QS96EF("@D8VAE8VM%>'!E8W1E9%9A<FEA8FQE
M<RD@>PH@("`@("`@("`@("`@("`@+R\@268@=V4G<F4@<W5P<&]S960@=&\@
M8VAE8VL*("`@("`@("`@("`@("`@("\O("1T:&ES+3Y?97AP96-T961687)I
M86)L97,L(&1O('-O+"!B=70@;6%K92!S=7)E(&YO=`H@("`@("`@("`@("`@
M("`@+R\@=&\@8VAE8VL@:70@86=A:6XN"B`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]E>&ES=',H)'1H:7,M/E]E>'!E8W1E9%9A<FEA8FQE<RP@
M)'9A<FYA;64L(&9A;'-E*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]60R\`````````````````````````````````````````````
M````````````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-3``,#$W-S<R`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U9#+V-V<RYP:'``````````````
M```````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$P,C(U-0`Q,#4Q-30S,S<U
M,``P,C$S,#,`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N
M("<O<F-S+G!H<"<["@HO*BH*("H@5D-?8W9S(&EM<&QE;65N=&%T:6]N+@H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,"TR,#`V($%N:6P@36%D:&%V87!E9&1Y+"`\
M86YI;$!R96-O:6PN;W)G/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]60R]6
M0R]C=G,N<&AP+'8@,2XS,BXR+C(T(#(P,#8O,#4O,3(@,#0Z-#<Z,#@@8VAU
M8VL@17AP("0*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N
M:6Q`<F5C;VEL+F]R9SX*("H@0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#7V-V
M<R!E>'1E;F1S(%9#7W)C<R!["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O
M<BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY('!A
M<F%M971E<B!T:&4@8VQA<W,@97AP96-T<RX*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`\<')E/@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M($-U<G)E;G0@<&%R86UE=&5R<SH*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`G<V]U<F-E<F]O="<Z(%1H92!S;W5R8V4@<F]O="!F;W(@=&AI<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5P
M;W-I=&]R>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("=P871H<R<Z
M($AA<V@@=VET:"!T:&4@;&]C871I;VYS(&]F(&%L;`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&YE8V5S<V%R>2!B:6YA<FEE<SH@
M)W)C<V1I9F8G+"`G<FQO9R<L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V-V<W!S)RP@)V-V<W!S7VAO;64G(&%N9"!T:&4@=&5M
M<`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('!A=&@Z
M("=T96UP)PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(#PO<')E/@H@
M("`@("HO"B`@("!F=6YC=&EO;B!60U]C=G,H)'!A<F%M<RD*("`@('L*("`@
M("`@("`D=&AI<RT^7W-O=7)C97)O;W0@/2`D<&%R86US6R=S;W5R8V5R;V]T
M)UT["B`@("`@("`@)'1H:7,M/E]P871H<R`]("1P87)A;7-;)W!A=&AS)UT[
M"B`@("!]"@H@("`@9G5N8W1I;VX@:7-&:6QE*"1W:&5R92D*("`@('L*("`@
M("`@("!R971U<FX@0&ES7V9I;&4H)'=H97)E("X@)RQV)RD["B`@("!]"@H@
M("`@9G5N8W1I;VX@)G%U97)Y1&ER*"1W:&5R92D*("`@('L*("`@("`@("`D
M9&ER(#T@;F5W(%9#7T1I<F5C=&]R>5]C=G,H)'1H:7,L("1W:&5R92D["B`@
M("`@("`@<F5T=7)N("1D:7(["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T0VAE
M8VMO=70H)&9I;&4L("1R978I"B`@("!["B`@("`@("`@<F5T=7)N(%9#7T-H
M96-K;W5T7V-V<SHZ9V5T*"1T:&ES+"`D9FEL92T^<75E<GE&=6QL4&%T:"@I
M+"`D<F5V*3L*("`@('T*"B`@("!F=6YC=&EO;B!G971$:69F*"1F:6QE+"`D
M<F5V,2P@)')E=C(L("1T>7!E(#T@)V-O;G1E>'0G+"`D;G5M(#T@,RP@)'=S
M(#T@=')U92D*("`@('L*("`@("`@("!R971U<FX@5D-?1&EF9E]C=G,Z.F=E
M="@D=&AI<RP@)&9I;&4L("1R978Q+"`D<F5V,BP@)'1Y<&4L("1N=6TL("1W
M<RD["B`@("!]"@H@("`@9G5N8W1I;VX@)F=E=$9I;&5/8FIE8W0H)&9I;&5N
M86UE+"`D8V%C:&4@/2!N=6QL+"`D<75I8VML;V<@/2!F86QS92D*("`@('L*
M("`@("`@("!I9B`H<W5B<W1R*"1F:6QE;F%M92P@,"P@,2D@(3T@)R\G*2![
M"B`@("`@("`@("`@("1F:6QE;F%M92`]("<O)R`N("1F:6QE;F%M93L*("`@
M("`@("!]"B`@("`@("`@)&9O(#T@)E9#7T9I;&5?8W9S.CIG971&:6QE3V)J
M96-T*"1T:&ES+"`D=&AI<RT^<V]U<F-E<F]O="@I("X@)&9I;&5N86UE+"`D
M8V%C:&4L("1Q=6EC:VQO9RD["B`@("`@("`@<F5T=7)N("1F;SL*("`@('T*
M"B`@("!F=6YC=&EO;B`F9V5T06YN;W1A=&5/8FIE8W0H)&9I;&5N86UE*0H@
M("`@>PH@("`@("`@("1B;&%M92`](&YE=R!60U]!;FYO=&%T95]C=G,H)'1H
M:7,L("1F:6QE;F%M92P@571I;#HZ9V5T5&5M<$9I;&4H)W9C)RP@=')U92P@
M)'1H:7,M/E]P871H<ULG=&5M<"==*2D["B`@("`@("`@<F5T=7)N("1B;&%M
M93L*("`@('T*"B`@("!F=6YC=&EO;B`F9V5T4&%T8VAS971/8FIE8W0H)&9I
M;&5N86UE+"`D8V%C:&4@/2!N=6QL*0H@("`@>PH@("`@("`@("1P;R`]("96
M0U]0871C:'-E=%]C=G,Z.F=E=%!A=&-H<V5T3V)J96-T*"1T:&ES+"`D=&AI
M<RT^<V]U<F-E<F]O="@I("X@)R\G("X@)&9I;&5N86UE+"`D8V%C:&4I.PH@
M("`@("`@(')E='5R;B`D<&\["B`@("!]"@I]"@HO*BH*("H@5D-?8W9S(&%N
M;F]T871E(&-L87-S+@H@*@H@*B!!;FEL($UA9&AA=F%P961D>2P@/&%N:6Q`
M<F5C;VEL+F]R9SX*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@
M/&%N:6Q`<F5C;VEL+F]R9SX*("H@0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#
M7T%N;F]T871E7V-V<R!["@H@("`@=F%R("1F:6QE.PH@("`@=F%R("1R97`[
M"B`@("!V87(@)'1M<&9I;&4["@H@("`@9G5N8W1I;VX@5D-?06YN;W1A=&5?
M8W9S*"1R97`L("1F:6QE+"`D=&UP9FEL92D*("`@('L*("`@("`@("`D=&AI
M<RT^<F5P(#T@)')E<#L*("`@("`@("`D=&AI<RT^9FEL92`]("1F:6QE.PH@
M("`@("`@("1T:&ES+3YT;7!F:6QE(#T@)'1M<&9I;&4["B`@("!]"@H@("`@
M9G5N8W1I;VX@9&]!;FYO=&%T92@D<F5V*0H@("`@>PH@("`@("`@("\J($UA
M:V4@<W5R92!T:&%T('1H92!F:6QE('9A;'5E<R!F;W(@=&AI<R!O8FIE8W0@
M:7,@=F%L:60N("HO"B`@("`@("`@:68@*&ES7V$H)'1H:7,M/F9I;&4L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@+RH@36%K92!S=7)E('1H870@=&AE(&-V<W)E<"!P
M87)A;65T97(@:7,@=F%L:60N("HO"B`@("`@("`@:68@*&ES7V$H)'1H:7,M
M/G)E<"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H(59#7U)E=FES:6]N.CIV86QI
M9"@D<F5V*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("`D=VAE<F4@/2`D=&AI<RT^9FEL92T^<75E<GE-;V1U;&50
M871H*"D["B`@("`@("`@)'-O=7)C97)O;W0@/2`D=&AI<RT^<F5P+3YS;W5R
M8V5R;V]T*"D["@H@("`@("`@("1P:7!E(#T@<&]P96XH)'1H:7,M/G)E<"T^
M9V5T4&%T:"@G8W9S)RD@+B`G("UN('-E<G9E<B`^("<@+B`D=&AI<RT^=&UP
M9FEL92P@5D-?5TE.1$]74R`_("=W8B<@.B`G=R<I.PH*("`@("`@("`D;W5T
M(#T@87)R87DH*3L*("`@("`@("`D;W5T6UT@/2`B4F]O="`D<V]U<F-E<F]O
M="(["B`@("`@("`@)&]U=%M=(#T@)U9A;&ED+7)E<W!O;G-E<R!O:R!E<G)O
M<B!686QI9"UR97%U97-T<R!#:&5C:V5D+6EN(%5P9&%T960@365R9V5D(%)E
M;6]V960@32!%)SL*("`@("`@("`D;W5T6UT@/2`G57-E56YC:&%N9V5D)SL*
M("`@("`@("`D;W5T6UT@/2`G07)G=6UE;G0@+7(G.PH@("`@("`@("1O=71;
M72`](")!<F=U;65N="`D<F5V(CL*("`@("`@("`D;W5T6UT@/2`B07)G=6UE
M;G0@)'=H97)E(CL*("`@("`@("`D9&ER<R`](&5X<&QO9&4H)R\G+"!D:7)N
M86UE*"1W:&5R92DI.PH@("`@("`@('=H:6QE("AC;W5N="@D9&ER<RDI('L*
M("`@("`@("`@("`@)&]U=%M=(#T@)T1I<F5C=&]R>2`G("X@:6UP;&]D92@G
M+R<L("1D:7)S*3L*("`@("`@("`@("`@)&]U=%M=(#T@(B1S;W5R8V5R;V]T
M+R(@+B!I;7!L;V1E*"<O)RP@)&1I<G,I.PH@("`@("`@("`@("!A<G)A>5]P
M;W`H)&1I<G,I.PH@("`@("`@('T*("`@("`@("`D;W5T6UT@/2`G1&ER96-T
M;W)Y("XG.PH@("`@("`@("1O=71;72`]("1S;W5R8V5R;V]T.PH@("`@("`@
M("1O=71;72`]("=A;FYO=&%T92<["@H@("`@("`@(&9O<F5A8V@@*"1O=70@
M87,@)&QI;F4I('L*("`@("`@("`@("`@9G=R:71E*"1P:7!E+"`B)&QI;F5<
M;B(I.PH@("`@("`@('T*("`@("`@("!P8VQO<V4H)'!I<&4I.PH*("`@("`@
M("!I9B`H(2@D9FP@/2!F;W!E;B@D=&AI<RT^=&UP9FEL92P@5D-?5TE.1$]7
M4R`_("=R8B<@.B`G<B<I*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("`D;&EN97,@/2!A<G)A>2@I.PH@("`@("`@
M("1L:6YE(#T@9F=E=',H)&9L+"`T,#DV*3L*"B`@("`@("`@+R\@5VEN9&]W
M<R!V97)S:6]N<R!O9B!C=G,@86QW87ES(')E='5R;B`D=VAE<F4@=VET:"!F
M;W)W87)D<R!S;&%S:&5S+@H@("`@("`@(&EF("A60U]724Y$3U=3*2!["B`@
M("`@("`@("`@("1W:&5R92`]('-T<E]R97!L86-E*$1)4D5#5$]265]315!!
M4D%43U(L("<O)RP@)'=H97)E*3L*("`@("`@("!]"@H@("`@("`@('=H:6QE
M("@D;&EN92`F)B`A<')E9U]M871C:"@B?%Y%7',K06YN;W1A=&EO;G,@9F]R
M("1W:&5R97PB+"`D;&EN92DI('L*("`@("`@("`@("`@)&QI;F4@/2!F9V5T
M<R@D9FPL(#0P.38I.PH@("`@("`@('T*"B`@("`@("`@:68@*"$D;&EN92D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G56YA8FQE
M('1O(&%N;F]T871E.R!S97)V97(@<V%I9#H@)R`N("1L:6YE*3L*("`@("`@
M("!]"@H@("`@("`@("1L:6YE;F\@/2`Q.PH@("`@("`@('=H:6QE("@D;&EN
M92`](&9G971S*"1F;"P@-#`Y-BDI('L*("`@("`@("`@("`@:68@*'!R96=?
M;6%T8V@H)R]>35QS*RA;7&1<+ETK*5QS*UPH*"XK*5QS*RA<9"LM7'<K+5QD
M*RE<*3HN*"XJ*20O)RP@)&QI;F4L("1R96=S*2D@>PH@("`@("`@("`@("`@
M("`@)&5N=')Y(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("1E;G1R>5LG
M<F5V)UT@("`@/2`D<F5G<ULQ73L*("`@("`@("`@("`@("`@("1E;G1R>5LG
M875T:&]R)UT@/2!T<FEM*"1R96=S6S)=*3L*("`@("`@("`@("`@("`@("1E
M;G1R>5LG9&%T92==("`@/2`D<F5G<ULS73L*("`@("`@("`@("`@("`@("1E
M;G1R>5LG;&EN92==("`@/2`D<F5G<ULT73L*("`@("`@("`@("`@("`@("1E
M;G1R>5LG;&EN96YO)UT@/2`D;&EN96YO*RL["B`@("`@("`@("`@("`@("`D
M;&EN97-;72`]("1E;G1R>3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@9F-L;W-E*"1F;"D["B`@("`@("`@<F5T=7)N("1L:6YE<SL*("`@
M('T*"GT*"B\J*@H@*B!60U]C=G,@8VAE8VMO=70@8VQA<W,N"B`J"B`J(%-E
M92!T:&4@4D5!1$U%(&9I;&4@=&AA="!C86UE('=I=&@@=&AI<R!L:6)R87)Y
M(&9O<B!M;W)E"B`J(&EN9F]R;6%T:6]N+"!A;F0@<F5A9"!T:&4@:6YL:6YE
M(&1O8W5M96YT871I;VXN"B`J"B`J($%N:6P@36%D:&%V87!E9&1Y+"`\86YI
M;$!R96-O:6PN;W)G/@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P961D
M>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`<&%C:V%G92!60PH@*B\*8VQA<W,@
M5D-?0VAE8VMO=71?8W9S('L*"B`@("`O*BH*("`@("`J(%-T871I8R!F=6YC
M=&EO;B!W:&EC:"!R971U<FYS(&$@9FEL92!P;VEN=&EN9R!T;R!T:&4@:&5A
M9"!O9B!T:&4*("`@("`J(')E<75E<W1E9"!R979I<VEO;B!O9B!A;B!20U,@
M9FEL92X*("`@("`J"B`@("`@*B!`<&%R86T@5D-?8W9S("1R97`@("`@("`@
M02!R97!O<VET;W)Y(&]B:F5C=`H@("`@("H@0'!A<F%M('-T<FEN9R`D9G5L
M;&YA;64@($9U;&QY('%U86QI9FEE9"!P871H;F%M92!O9B!T:&4@9&5S:7)E
M9"!20U,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!F:6QE('1O
M(&-H96-K;W5T"B`@("`@*B!`<&%R86T@<W1R:6YG("1R978@("`@("`@4D-3
M(')E=FES:6]N(&YU;6)E<B!T;R!C:&5C:R!O=70*("`@("`J"B`@("`@*B!`
M<F5T=7)N(')E<V]U<F-E?&]B:F5C="`@16ET:&5R(&$@4$5!4E]%<G)O<B!O
M8FIE8W0L(&]R(&$@<W1R96%M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@<&]I;G1E<B!T;R!T:&4@:&5A9"!O9B!T:&4@8VAE8VMO=70*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T*"1R97`L("1F=6QL;F%M92P@)')E=BD*
M("`@('L*("`@("`@("!I9B`H(59#7U)E=FES:6]N.CIV86QI9"@D<F5V*2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G26YV86QI
M9"!R979I<VEO;B!N=6UB97(G*3L*("`@("`@("!]"@H@("`@("`@(&EF("A6
M0U]724Y$3U=3*2!["B`@("`@("`@("`@("1M;V1E(#T@)W)B)SL*("`@("`@
M("`@("`@)'%?;F%M92`]("<B)R`N(&5S8V%P97-H96QL8VUD*'-T<E]R97!L
M86-E*"=<7"<L("<O)RP@)&9U;&QN86UE*2D@+B`G(B<["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&UO9&4@/2`G<B<["B`@("`@("`@("`@("1Q
M7VYA;64@/2!E<V-A<&5S:&5L;&%R9R@D9G5L;&YA;64I.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"$H)%)#4R`]('!O<&5N*"1R97`M/F=E=%!A=&@H)V-O
M)RD@+B`B("UP)')E=B`D<5]N86UE(#(^)C$B+"`D;6]D92DI*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=#;W5L9&Y<)W0@<&5R
M9F]R;2!C:&5C:V]U="!O9B!T:&4@<F5Q=65S=&5D(&9I;&4G*3L*("`@("`@
M("!]"@H@("`@("`@("\J($9I<G-T(&QI;F4@9G)O;2!C;R!S:&]U;&0@8F4@
M;V8@=&AE(&9O<FT@.@H@("`@("`@("`J("]P871H+W1O+V9I;&5N86UE+'8@
M("TM/B`@<W1A;F1A<F0@;W5T"B`@("`@("`@("H@86YD('=E(&-H96-K('1H
M870@=&AI<R!I<R!T:&4@8V%S92!A;F0@97)R;W(@;W1H97)W:7-E"B`@("`@
M("`@("HO"@H@("`@("`@("1C;R`](&9G971S*"120U,L(#$P,C0I.PH@("`@
M("`@(&EF("@A<')E9U]M871C:"@G+UXH6UQ3(%TK*2QV7',K+2T^7',K<W0H
M86YD87(I/V0@/V]U="AP=70I/UQS*B0O)RP@)&-O+"`D<F5G<RD@?'P@)')E
M9W-;,5TN)RQV)R`A/2`D9G5L;&YA;64I('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)U5N97AP96-T960@;W5T<'5T(&9R;VT@8VAE
M8VMO=70Z("<@+B`D8V\I.PH@("`@("`@('T*"B`@("`@("`@+RH@3F5X="!L
M:6YE(&9R;VT@8V\@:7,@;V8@=&AE(&9O<FTZ"B`@("`@("`@("H@<F5V:7-I
M;VX@,2XR+C,*("`@("`@("`@*B!43T1/.B!C;VUP87)E('1H:7,@=&\@)')E
M=B!F;W(@8V]N<VES=&5N8WDL(&%T;2!W92!J=7-T"B`@("`@("`@("H@("`@
M("`@9&ES8V%R9"!T:&4@=F%L=64@=&\@;6]V92!I;G!U="!P;VEN=&5R(&%L
M;VYG("T@879S;0H@("`@("`@("`J+PH@("`@("`@("1C;R`](&9G971S*"12
M0U,L(#$P,C0I.PH*("`@("`@("!R971U<FX@)%)#4SL*("`@('T*"GT*"B\J
M*@H@*B!60U]C=G,@9&EF9B!C;&%S<RX*("H*("H@0V]P>7)I9VAT($%N:6P@
M36%D:&%V87!E9&1Y+"`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!`875T:&]R
M("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`<&%C
M:V%G92!60PH@*B\*8VQA<W,@5D-?1&EF9E]C=G,@>PH*("`@("\J*@H@("`@
M("H@3V)T86EN('1H92!D:69F97)E;F-E<R!B971W965N('1W;R!R979I<VEO
M;G,@;V8@82!F:6QE+@H@("`@("H*("`@("`J($!P87)A;2!60U]C=G,@)')E
M<"`@("`@("`@02!R97!O<VET;W)Y(&]B:F5C="X*("`@("`J($!P87)A;2!6
M0U]&:6QE7V-V<R`D9FEL92`@5&AE(&1E<VER960@9FEL92X*("`@("`J($!P
M87)A;2!S=')I;F<@)')E=C$@("`@("`@3W)I9VEN86P@<F5V:7-I;VX@;G5M
M8F5R('1O(&-O;7!A<F4@9G)O;2X*("`@("`J($!P87)A;2!S=')I;F<@)')E
M=C(@("`@("`@3F5W(')E=FES:6]N(&YU;6)E<B!T;R!C;VUP87)E(&%G86EN
M<W0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("`@("`@(%1H92!T>7!E
M(&]F(&1I9F8@*&4N9RX@)W5N:69I960G*2X*("`@("`J($!P87)A;2!I;G1E
M9V5R("1N=6T@("`@("`@3G5M8F5R(&]F(&QI;F5S('1O(&)E('5S960@:6X@
M8V]N=&5X="!A;F0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=6YI9FEE9"!D:69F<RX*("`@("`J($!P87)A;2!B;V]L96%N("1W<R`@("`@
M("`@4VAO=R!W:&ET97-P86-E(&EN('1H92!D:69F/PH@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG?&)O;VQE86X@($9A;'-E(&]N(&9A:6QU<F4L(&]R
M(&$@<W1R:6YG(&-O;G1A:6YI;F<@=&AE"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("!D:69F(&]N('-U8V-E<W,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E="@D<F5P+"`D9FEL92P@)')E=C$L("1R978R+"`D='EP92`]("=C
M;VYT97AT)RP@)&YU;2`](#,L"B`@("`@("`@("`@("`@("`@)'=S(#T@=')U
M92D*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@=&AA="!T:&4@9FEL92!P
M87)A;65T97(@:7,@=F%L:60N("HO"B`@("`@("`@:68@*&ES7V$H)&9I;&4L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@+RH@0VAE8VL@=&AA="!T:&4@<F5V:7-I;VX@
M;G5M8F5R<R!A<F4@=F%L:60N("HO"B`@("`@("`@)')E=C$@/2!60U]2979I
M<VEO;CHZ=F%L:60H)')E=C$I(#\@)')E=C$@.B`G,2XQ)SL*("`@("`@("`D
M<F5V,B`](%9#7U)E=FES:6]N.CIV86QI9"@D<F5V,2D@/R`D<F5V,B`Z("<Q
M+C$G.PH*("`@("`@("`D9G5L;$YA;64@/2`D9FEL92T^<75E<GE&=6QL4&%T
M:"@I.PH@("`@("`@("1D:69F(#T@87)R87DH*3L*("`@("`@("`D;W!T:6]N
M<R`]("<M:VL@)SL*("`@("`@("!I9B`H(21W<RD@>PH@("`@("`@("`@("`D
M;W!T<R`]("<@+6)"("<["B`@("`@("`@("`@("1O<'1I;VYS("X]("1O<'1S
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1O<'1S(#T@)R<["B`@
M("`@("`@?0H@("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@("!C87-E
M("=C;VYT97AT)SH*("`@("`@("`@("`@)&]P=&EO;G,@/2`D;W!T<R`N("<M
M<"`M+6-O;G1E>'0])R`N("AI;G0I)&YU;3L*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&-A<V4@)W5N:69I960G.@H@("`@("`@("`@("`D;W!T:6]N
M<R`]("1O<'1S("X@)RUP("TM=6YI9FEE9#TG("X@*&EN="DD;G5M.PH@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G8V]L=6UN)SH*("`@("`@
M("`@("`@)&]P=&EO;G,@/2`D;W!T<R`N("<M+7-I9&4M8GDM<VED92`M+7=I
M9'1H/3$R,"<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=E
M9"<Z"B`@("`@("`@("`@("1O<'1I;VYS(#T@)&]P=',@+B`G+64G.PH@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@("\O(%=I;F1O=W,@
M=F5R<VEO;G,@;V8@8W9S(&%L=V%Y<R!R971U<FX@)'=H97)E('=I=&@@9F]R
M=V%R9',@<VQA<VAE<RX*("`@("`@("!I9B`H5D-?5TE.1$]74RD@>PH@("`@
M("`@("`@("`D9G5L;$YA;64@/2!S=')?<F5P;&%C92A$25)%0U1/4EE?4T50
M05)!5$]2+"`G+R<L("1F=6QL3F%M92D["B`@("`@("`@?0H*("`@("`@("`O
M+R!43T1/.B!A9&0@;W!T:6]N<R!F;W(@)&AR(&]P=&EO;G,@+2!H;W=E=F5R
M('1H97-E(&UA>2!N;W0@8F4*("`@("`@("`O+R!C;VUP871I8FQE('=I=&@@
M<V]M92!D:69F<RX*("`@("`@("`D8V]M;6%N9"`]("1R97`M/F=E=%!A=&@H
M)W)C<V1I9F8G*2`N("(@)&]P=&EO;G,@+7(D<F5V,2`M<B1R978R(%PB(B`N
M(&5S8V%P97-H96QL8VUD*"1F=6QL3F%M92D@+B`G(B`R/B8Q)SL*("`@("`@
M("!I9B`H5D-?5TE.1$]74RD@>PH@("`@("`@("`@("`D8V]M;6%N9"`N/2`G
M(#P@(B<@+B!?7T9)3$5?7R`N("<B)SL*("`@("`@("!]"@H@("`@("`@(&5X
M96,H)&-O;6UA;F0L("1D:69F+"`D<F5T=F%L*3L*("`@("`@("!R971U<FX@
M*"1R971V86P@/B`P*2`_("1D:69F(#H@87)R87DH*3L*("`@('T*"GT*"B\J
M*@H@*B!60U]C=G,@9&ER96-T;W)Y(&-L87-S+@H@*@H@*B!#;W!Y<FEG:'0@
M06YI;"!-861H879A<&5D9'DL(#QA;FEL0')E8V]I;"YO<F<^"B`J"B`J($!A
M=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J
M($!P86-K86=E(%9#"B`J+PIC;&%S<R!60U]$:7)E8W1O<GE?8W9S('L*"B`@
M("!V87(@)')E<#L*("`@('9A<B`D9&ER3F%M93L*("`@('9A<B`D9FEL97,[
M"B`@("!V87(@)&%T=&EC1FEL97,["B`@("!V87(@)&UE<F=E9$9I;&5S.PH@
M("`@=F%R("1D:7)S.PH@("`@=F%R("1P87)E;G0["B`@("!V87(@)&UO9'5L
M94YA;64["B`@("!V87(@)'-O<G1$:7(["@H@("`@+RHJ"B`@("`@*B!#<F5A
M=&5S(&$@0U93($1I<F5C=&]R>2!O8FIE8W0@=&\@<W1O<F4@:6YF;W)M871I
M;VX*("`@("`J(&%B;W5T('1H92!F:6QE<R!I;B!A('-I;F=L92!D:7)E8W1O
M<GD@:6X@=&AE(')E<&]S:71O<GDN"B`@("`@*@H@("`@("H@0'!A<F%M(%9#
M7V-V<R`D<F5P("`@("`@("`@("!!(')E<&]S:71O<GD@;V)J96-T"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1D;B`@("`@("`@("`@(%!A=&@@=&\@=&AE(&1I
M<F5C=&]R>2X*("`@("`J($!P87)A;2!60U]$:7)E8W1O<GE?8W9S("1P;B`@
M5&AE('!A<F5N="!60U]$:7)E8W1O<GD@=&\@=&AI<R!O;F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%9#7T1I<F5C=&]R>5]C=G,H)')E<"P@)&1N+"`D<&X@
M/2`G)RD*("`@('L*("`@("`@("`D=&AI<RT^<F5P(#T@)')E<#L*("`@("`@
M("`D=&AI<RT^<&%R96YT(#T@)'!N.PH@("`@("`@("1T:&ES+3YM;V1U;&5.
M86UE(#T@)&1N.PH@("`@("`@("1T:&ES+3YD:7).86UE(#T@)')E<"T^<V]U
M<F-E<F]O="@I("X@(B\D9&XB.PH@("`@("`@("1T:&ES+3YF:6QE<R`](&%R
M<F%Y*"D["B`@("`@("`@)'1H:7,M/F1I<G,@/2!A<G)A>2@I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N(&9U;&QY('%U86QI9FEE9"!P871H;F%M
M92!T;R!T:&ES(&1I<F5C=&]R>2!W:71H(&YO"B`@("`@*B!T<F%I;&EN9R`O
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!0871H;F%M92!O9B!T
M:&ES(&1I<F5C=&]R>0H@("`@("HO"B`@("!F=6YC=&EO;B!Q=65R>41I<B@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YD:7).86UE.PH@("`@?0H*
M("`@(&9U;F-T:6]N("9Q=65R>41I<DQI<W0H*0H@("`@>PH@("`@("`@(')E
M<V5T*"1T:&ES+3YD:7)S*3L*("`@("`@("!R971U<FX@)'1H:7,M/F1I<G,[
M"B`@("!]"@H@("`@9G5N8W1I;VX@)G%U97)Y1FEL94QI<W0H)'-H;W=A='1I
M8R`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@D<VAO=V%T=&EC("8F(&ES
M<V5T*"1T:&ES+3YM97)G961&:6QE<RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YM97)G961&:6QE<SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/F9I;&5S.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%1E;&P@=&AE(&]B:F5C="!T;R!O<&5N(&%N9"!B<F]W
M<V4@:71S(&-U<G)E;G0@9&ER96-T;W)Y+"!A;F0*("`@("`J(')E=')I979E
M(&$@;&ES="!O9B!A;&P@=&AE(&]B:F5C=',@:6X@=&AE<F4N("!)="!T:&5N
M('!O<'5L871E<PH@("`@("H@=&AE(&9I;&4O9&ER96-T;W)Y('-T86-K(&%N
M9"!M86ME<R!I="!A=F%I;&%B;&4@9F]R(')E=')I979A;"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86Y\;V)J96-T("!014%27T5R<F]R(&]B:F5C
M="!O;B!A;B!E<G)O<BP@=')U92!O;B!S=6-C97-S+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!B<F]W<V5$:7(H)&-A8VAE(#T@;G5L;"P@)'%U:6-K;&]G(#T@
M=')U92P@)'-H;W=A='1I8R`](&9A;'-E*0H@("`@>PH@("`@("`@("\J($UA
M:V4@<W5R92!W92!A<F4@=')Y:6YG('1O(&QI<W0@82!D:7)E8W1O<GD@*B\*
M("`@("`@("!I9B`H(4!I<U]D:7(H)'1H:7,M/F1I<DYA;64I*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=5;F%B;&4@=&\@9FEN
M9"!D:7)E8W1O<GD@)R`N("1T:&ES+3YD:7).86UE*3L*("`@("`@("!]"@H@
M("`@("`@("\J($]P96X@=&AE(&1I<F5C=&]R>2!F;W(@<F5A9&EN9R!I=',@
M8V]N=&5N=',@*B\*("`@("`@("!I9B`H(2@D1$E2(#T@0&]P96YD:7(H)'1H
M:7,M/F1I<DYA;64I*2D@>PH@("`@("`@("`@("`D97)R;7-G(#T@*"%E;7!T
M>2@D<&AP7V5R<F]R;7-G*2D@/R`D<&AP7V5R<F]R;7-G(#H@)U!E<FUI<W-I
M;VX@9&5N:65D)SL*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)&5R<FUS9RD["B`@("`@("`@?0H*("`@("`@("`O*B!#<F5A=&4@='=O
M(&%R<F%Y<R`M(&]N92!O9B!A;&P@=&AE(&9I;&5S+"!A;F0@=&AE(&]T:&5R
M(&]F"B`@("`@("`@("H@86QL('1H92!D:7)E8W1O<FEE<RX@*B\*("`@("`@
M("!W:&EL92`H*"1N86UE(#T@<F5A9&1I<B@D1$E2*2D@(3T](&9A;'-E*2![
M"B`@("`@("`@("`@(&EF("@D;F%M92`]/2`G+B<@?'P@)&YA;64@/3T@)RXN
M)RD@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("1P871H(#T@)'1H:7,M/F1I<DYA;64@+B`G+R<@+B`D
M;F%M93L*("`@("`@("`@("`@:68@*$!I<U]D:7(H)'!A=&@I*2!["B`@("`@
M("`@("`@("`@("`O*B!3:VEP($%T=&EC(&1I<F5C=&]R>2X@*B\*("`@("`@
M("`@("`@("`@(&EF("@D;F%M92`A/2`G071T:6,G*2!["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/F1I<G-;72`]("1N86UE.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!](&5L<V5I9B`H0&ES7V9I;&4H)'!A=&@I("8F
M('-U8G-T<B@D;F%M92P@+3(I(#T]("<L=B<I('L*("`@("`@("`@("`@("`@
M("\J(%-P87=N(&$@;F5W(&9I;&4@;V)J96-T('1O(')E<')E<V5N="!T:&ES
M(&9I;&4N("HO"B`@("`@("`@("`@("`@("`D9FP@/2`D=&AI<RT^<F5P+3YG
M971&:6QE3V)J96-T*'-U8G-T<B@D<&%T:"P@<W1R;&5N*"1T:&ES+3YR97`M
M/G-O=7)C97)O;W0H*2DL("TR*2P@)&-A8VAE+"`D<75I8VML;V<I.PH@("`@
M("`@("`@("`@("`@:68@*&ES7V$H)&9L+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1F;#L*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F9I;&5S6UT@
M/2`D9FP["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("\J($-L;W-E('1H92!F:6QE:&%N9&QE.R!W92=V92!N
M;W<@9V]T(&$@;&ES="!O9B!D:7)S(&%N9`H@("`@("`@("`J(&9I;&5S+B`J
M+PH@("`@("`@(&-L;W-E9&ER*"1$25(I.PH*("`@("`@("`O*B!)9B!W92!W
M86YT('1O(&UE<F=E('1H92!A='1I8RP@861D(&ET(&EN(&AE<F4N("HO"B`@
M("`@("`@:68@*"1S:&]W871T:6,I('L*("`@("`@("`@("`@)&%T=&EC1&ER
M(#T@;F5W(%9#7T1I<F5C=&]R>5]C=G,H)'1H:7,M/G)E<"P@)'1H:7,M/FUO
M9'5L94YA;64@+B`G+T%T=&EC)RP@)'1H:7,I.PH@("`@("`@("`@("!I9B`H
M(6ES7V$H)&%T=&EC1&ER+3YB<F]W<V5$:7(H)&-A8VAE+"`D<75I8VML;V<I
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^871T
M:6-&:6QE<R`]("1A='1I8T1I<BT^<75E<GE&:6QE3&ES="@I.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/FUE<F=E9$9I;&5S(#T@87)R87E?;65R9V4H)'1H
M:7,M/F9I;&5S+"`D=&AI<RT^871T:6-&:6QE<RD["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4V]R="!T:&4@8V]N=&5N=',@;V8@=&AE(&1I<F5C=&]R>2!I
M;B!A(&=I=F5N(&9A<VAI;VX@86YD"B`@("`@*B!O<F1E<BX*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D:&]W("!/9B!T:&4@9F]R;2!60U]33U)4
M7RH@=VAE<F4@*B!C86X@8F4Z"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("!.3TY%+"!.04U%+"!!1T4L(%)%5B!F;W(@<V]R=&EN9R!B>2!N86UE+"!A
M9V4@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@(')E=FES:6]N+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&1I<B`@3V8@=&AE(&9O<FT@5D-?4T]2
M5%\J('=H97)E("H@8V%N(&)E.@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@05-#14Y$24Y'+"!$15-#14Y$24Y'(&9O<B!T:&4@;W)D97(@;V8@=&AE
M('-O<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%P<&QY4V]R="@D:&]W(#T@
M5D-?4T]25%].3TY%+"`D9&ER(#T@5D-?4T]25%]!4T-%3D1)3D<I"B`@("![
M"B`@("`@("`@+R\@06QW87ES('-O<G0@9&ER96-T;W)I97,@8GD@;F%M92X*
M("`@("`@("!N871C87-E<V]R="@D=&AI<RT^9&ER<RD["@H@("`@("`@("1T
M:&ES+3YD;T9I;&53;W)T*"1T:&ES+3YF:6QE<RP@)&AO=RP@)&1I<BD["B`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3YA='1I8T9I;&5S*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^9&]&:6QE4V]R="@D=&AI<RT^871T:6-&:6QE<RP@)&AO
M=RP@)&1I<BD["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M;65R9V5D1FEL97,I*2!["B`@("`@("`@("`@("1T:&ES+3YD;T9I;&53;W)T
M*"1T:&ES+3YM97)G961&:6QE<RP@)&AO=RP@)&1I<BD["B`@("`@("`@?0H@
M("`@?0H*("`@(&9U;F-T:6]N(&1O1FEL95-O<G0H)B1F:6QE3&ES="P@)&AO
M=R`](%9#7U-/4E1?3D].12P@)&1I<B`](%9#7U-/4E1?05-#14Y$24Y'*0H@
M("`@>PH@("`@("`@("1T:&ES+3YS;W)T1&ER(#T@)&1I<CL*"B`@("`@("`@
M<W=I=&-H("@D:&]W*2!["B`@("`@("`@8V%S92!60U]33U)47T%'13H*("`@
M("`@("`@("`@=7-O<G0H)&9I;&5,:7-T+"!A<G)A>2@D=&AI<RP@)V9I;&5!
M9V53;W)T)RDI.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!6
M0U]33U)47TY!344Z"B`@("`@("`@("`@('5S;W)T*"1F:6QE3&ES="P@87)R
M87DH)'1H:7,L("=F:6QE3F%M95-O<G0G*2D["B`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("!C87-E(%9#7U-/4E1?05542$]2.@H@("`@("`@("`@("!U
M<V]R="@D9FEL94QI<W0L(&%R<F%Y*"1T:&ES+"`G9FEL94%U=&AO<E-O<G0G
M*2D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%9#7U-/4E1?
M4D56.@H@("`@("`@("`@("!U<V]R="@D9FEL94QI<W0L(&%R<F%Y*"1T:&ES
M+"`G9FEL95)E=E-O<G0G*2D["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M('T*"B`@("`@("`@=6YS970H)'1H:7,M/G-O<G1$:7(I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V]R="!F=6YC=&EO;B!F;W(@9FEL92!A9V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&9I;&5!9V53;W)T*"1A+"`D8BD*("`@('L*("`@
M("`@("`D86$@/2`D82T^<75E<GE,87-T3&]G*"D["B`@("`@("`@)&)B(#T@
M)&(M/G%U97)Y3&%S=$QO9R@I.PH@("`@("`@(&EF("@D86$M/G%U97)Y1&%T
M92@I(#T]("1B8BT^<75E<GE$871E*"DI('L*("`@("`@("`@("`@<F5T=7)N
M(#`["B`@("`@("`@?2!E;'-E:68@*"1T:&ES+3YS;W)T1&ER(#T](%9#7U-/
M4E1?05-#14Y$24Y'*2!["B`@("`@("`@("`@(')E='5R;B`H)&%A+3YQ=65R
M>41A=&4H*2`\("1B8BT^<75E<GE$871E*"DI(#\@,2`Z("TQ.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`H)&)B+3YQ=65R>41A=&4H
M*2`\("1A82T^<75E<GE$871E*"DI(#\@,2`Z("TQ.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J(%-O<G0@9G5N8W1I;VX@8GD@875T:&]R(&YA
M;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&9I;&5!=71H;W)3;W)T*"1A+"`D
M8BD*("`@('L*("`@("`@("`D86$@/2`D82T^<75E<GE,87-T3&]G*"D["B`@
M("`@("`@)&)B(#T@)&(M/G%U97)Y3&%S=$QO9R@I.PH@("`@("`@(&EF("@D
M86$M/G%U97)Y075T:&]R*"D@/3T@)&)B+3YQ=65R>4%U=&AO<B@I*2!["B`@
M("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T@96QS96EF("@D=&AI<RT^
M<V]R=$1I<B`]/2!60U]33U)47T%30T5.1$E.1RD@>PH@("`@("`@("`@("!R
M971U<FX@*"1A82T^<75E<GE!=71H;W(H*2`^("1B8BT^<75E<GE!=71H;W(H
M*2D@/R`Q(#H@+3$["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N("@D8F(M/G%U97)Y075T:&]R*"D@/B`D86$M/G%U97)Y075T:&]R*"DI
M(#\@,2`Z("TQ.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-O
M<G0@9G5N8W1I;VX@9F]R(&9I;&5N86UE+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!F:6QE3F%M95-O<G0H)&$L("1B*0H@("`@>PH@("`@("`@(&EF("@D=&AI
M<RT^<V]R=$1I<B`]/2!60U]33U)47T%30T5.1$E.1RD@>PH@("`@("`@("`@
M("!R971U<FX@<W1R8V%S96-M<"@D82T^;F%M92P@)&(M/FYA;64I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!S=')C87-E8VUP*"1B
M+3YN86UE+"`D82T^;F%M92D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@4V]R="!F=6YC=&EO;B!F;W(@<F5V:7-I;VXN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&9I;&529793;W)T*"1A+"`D8BD*("`@('L*("`@("`@("!I
M9B`H)'1H:7,M/G-O<G1$:7(@/3T@5D-?4T]25%]!4T-%3D1)3D<I('L*("`@
M("`@("`@("`@<F5T=7)N(%9#7U)E=FES:6]N.CIC;7`H)&$M/G%U97)Y2&5A
M9"@I+"`D8BT^<75E<GE(96%D*"DI.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B!60U]2979I<VEO;CHZ8VUP*"1B+3YQ=65R>4AE860H
M*2P@)&$M/G%U97)Y2&5A9"@I*3L*("`@("`@("!]"B`@("!]"@I]"@HO*BH*
M("H@5D-?8W9S(&9I;&4@8VQA<W,N"B`J"B`J($-O<'ER:6=H="!!;FEL($UA
M9&AA=F%P961D>2P@/&%N:6Q`<F5C;VEL+F]R9SX*("H*("H@0&%U=&AO<B`@
M06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@0'!A8VMA
M9V4@5D,*("HO"F-L87-S(%9#7T9I;&5?8W9S(&5X=&5N9',@5D-?1FEL92![
M"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@82!R97!O<VET;W)Y(&9I;&4@;V)J
M96-T+"!A;F0@9VEV92!I="!I;F9O<FUA=&EO;B!A8F]U=`H@("`@("H@=VAA
M="!I=',@<&%R96YT(&1I<F5C=&]R>2!A;F0@<F5P;W-I=&]R>2!O8FIE8W1S
M(&%R92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F;"`@1G5L;"!P
M871H('1O('1H:7,@9FEL92X*("`@("`J+PH@("`@9G5N8W1I;VX@5D-?1FEL
M95]C=G,H)&9L+"`D<75I8VML;V<@/2!F86QS92D*("`@('L*("`@("`@("`D
M9FP@+CT@)RQV)SL*("`@("`@("`D=&AI<RT^;F%M92`](&)A<V5N86UE*"1F
M;"D["B`@("`@("`@)'1H:7,M/F1I<B`](&1I<FYA;64H)&9L*3L*("`@("`@
M("`D=&AI<RT^;&]G<R`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/G%U:6-K
M;&]G(#T@)'%U:6-K;&]G.PH@("`@("`@("1T:&ES+3YR979S(#T@87)R87DH
M*3L*("`@("`@("`D=&AI<RT^8G)A;F-H97,@/2!A<G)A>2@I.PH@("`@?0H*
M("`@(&9U;F-T:6]N("9G971&:6QE3V)J96-T*"1R97`L("1F:6QE;F%M92P@
M)&-A8VAE(#T@;G5L;"P@)'%U:6-K;&]G(#T@9F%L<V4I"B`@("!["B`@("`@
M("`@+RH@5&AE('9E<G-I;VX@;V8@=&AE(&-A8VAE9"!D871A+B!);F-R96UE
M;G0@=&AI<R!W:&5N979E<B!T:&4*("`@("`@("`@*B!I;G1E<FYA;"!S=&]R
M86=E(&9O<FUA="!C:&%N9V5S+"!S=6-H('1H870@=V4@;75S=`H@("`@("`@
M("`J(&EN=F%L:61A=&4@<')I;W(@8V%C:&5D(&1A=&$N("HO"B`@("`@("`@
M)&-A8VAE5F5R<VEO;B`](#(["B`@("`@("`@)&-A8VAE260@/2`D<F5P+3YS
M;W5R8V5R;V]T*"D@+B`G7VXG("X@)&9I;&5N86UE("X@)U]F)R`N("AI;G0I
M)'%U:6-K;&]G("X@)U]V)R`N("1C86-H959E<G-I;VX["@H@("`@("`@("1C
M=&EM92`]('1I;64H*2`M($!F:6QE;71I;64H)&9I;&5N86UE("X@)RQV)RD[
M"B`@("`@("`@:68@*"1C86-H92`F)@H@("`@("`@("`@("`D8V%C:&4M/F5X
M:7-T<R@D8V%C:&5)9"P@)&-T:6UE*2D@>PH@("`@("`@("`@("`D9FEL94]B
M(#T@=6YS97)I86QI>F4H)&-A8VAE+3YG970H)&-A8VAE260L("1C=&EM92DI
M.PH@("`@("`@("`@("`D9FEL94]B+3YS971297!O<VET;W)Y*"1R97`I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F:6QE3V(@/2!N97<@5D-?
M1FEL95]C=G,H)&9I;&5N86UE+"`D<75I8VML;V<I.PH@("`@("`@("`@("`D
M9FEL94]B+3YS971297!O<VET;W)Y*"1R97`I.PH@("`@("`@("`@("!I9B`H
M:7-?82@H)')E<W5L="`]("1F:6QE3V(M/F=E=$)R;W=S94EN9F\H*2DL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1F:6QE3V(M/F%P<&QY4V]R
M="A60U]33U)47T%'12D["@H@("`@("`@("`@("!I9B`H)&-A8VAE*2!["B`@
M("`@("`@("`@("`@("`D8V%C:&4M/G-E="@D8V%C:&5)9"P@<V5R:6%L:7IE
M*"1F:6QE3V(I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1F:6QE3V(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!)9B!T:&ES
M(&9I;&4@:7,@<')E<V5N="!I;B!A;B!!='1I8R!D:7)E8W1O<GDL('1H:7,@
M:6YD:6-A=&5S"B`@("`@*B!I="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%1R=64@:68@9FEL92!I<R!I;B!T:&4@071T:6,L(&%N9"!F86QS
M92!O=&AE<G=I<V4*("`@("`J+PH@("`@9G5N8W1I;VX@:7-!='1I8T9I;&4H
M*0H@("`@>PH@("`@("`@(')E='5R;B!S=6)S='(H)'1H:7,M/F1I<BP@+34I
M(#T]("=!='1I8R<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!N86UE(&]F('1H92!C=7)R96YT(&9I;&4@87,@:6X@=&AE(')E<&]S:71O
M<GD*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@1FEL96YA;64@*'=I
M=&AO=70@=&AE('!A=&@I"B`@("`@*B\*("`@(&9U;F-T:6]N('%U97)Y4F5P
M;W-I=&]R>4YA;64H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;F%M
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@;F%M92!O9B!T:&4@
M8W5R<F5N="!F:6QE('=I=&AO=70@=&AE(')E<&]S:71O<GD*("`@("`J(&5X
M=&5N<VEO;G,@*'5S=6%L;'D@+'8I"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@($9I;&5N86UE('=I=&AO=70@<F5P;W-I=&]R>2!E>'1E;G-I;VX*
M("`@("`J+PH@("`@9G5N8W1I;VX@<75E<GE.86UE*"D*("`@('L*("`@("`@
M("!R971U<FX@<')E9U]R97!L86-E*"<O+'8D+R<L("<G+"`D=&AI<RT^;F%M
M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&QA<W0@<F5V
M:7-I;VX@;V8@=&AE(&-U<G)E;G0@9FEL92!O;B!T:&4@2$5!1"!B<F%N8V@*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9WQO8FIE8W0@($QA<W0@<F5V
M:7-I;VX@;V8@=&AE(&-U<G)E;G0@9FEL92!O<B!014%27T5R<F]R"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('%U97)Y4F5V:7-I;VXH*0H@("`@>PH@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/G)E=G-;,%TI*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=.;R!R979I<VEO;G,G*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YR979S6S!=.PH@("`@?0H*("`@(&9U
M;F-T:6]N('%U97)Y4')E=FEO=7-2979I<VEO;B@D<F5V*0H@("`@>PH@("`@
M("`@(')E='5R;B!60U]2979I<VEO;CHZ<')E=B@D<F5V*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!T:&4@2$5!1"`H;6]S="!R96-E;G0I(')E
M=FES:6]N(&YU;6)E<B!F;W(@=&AI<R!F:6QE+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!(14%$(')E=FES:6]N(&YU;6)E<@H@("`@("HO"B`@
M("!F=6YC=&EO;B!Q=65R>4AE860H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^:&5A9#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@
M;&%S="!60U]L;V<@;V)J96-T(&EN('1H92!F:6QE+@H@("`@("H*("`@("`J
M($!R971U<FX@5D-?;&]G(&]F('1H92!L87-T(&5N=')Y(&EN('1H92!F:6QE
M"B`@("`@*B\*("`@(&9U;F-T:6]N('%U97)Y3&%S=$QO9R@I"B`@("!["B`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^<F5V<ULP72D@?'P@(6ES<V5T*"1T
M:&ES+3YL;V=S6R1T:&ES+3YR979S6S!=72DI('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)TYO(')E=FES:6]N<R<I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)'1H:7,M/FQO9W-;)'1H:7,M/G)E=G-;,%U=
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4V]R="!T:&4@;&ES="!O9B!60U]L
M;V<@;V)J96-T<R!T:&%T('1H:7,@9FEL92!C;VYT86EN<RX*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D:&]W("!60U]33U)47U)%5B`H<V]R="!B
M>2!R979I<VEO;BDL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!60U]3
M3U)47TY!344@*'-O<G0@8GD@875T:&]R(&YA;64I+`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@5D-?4T]25%]!1T4@*'-O<G0@8GD@8V]M;6ET(&1A
M=&4I"B`@("`@*B\*("`@(&9U;F-T:6]N(&%P<&QY4V]R="@D:&]W(#T@5D-?
M4T]25%]2158I"B`@("!["B`@("`@("`@<W=I=&-H("@D:&]W*2!["B`@("`@
M("`@8V%S92!60U]33U)47TY!344Z"B`@("`@("`@("`@("1F=6YC(#T@)TYA
M;64G.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!60U]33U)4
M7T%'13H*("`@("`@("`@("`@)&9U;F,@/2`G06=E)SL*("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@(&-A<V4@5D-?4T]25%]2158Z"B`@("`@("`@9&5F
M875L=#H*("`@("`@("`@("`@)&9U;F,@/2`G4F5V:7-I;VXG.PH@("`@("`@
M('T*"B`@("`@("`@=6%S;W)T*"1T:&ES+3YL;V=S+"!A<G)A>2@D=&AI<RP@
M(G-O<G1">21F=6YC(BDI.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@5&AE('-O<G1">2HH*2!F=6YC=&EO;G,@87)E(&EN
M=&5R;F%L;'D@=7-E9"!B>2!A<'!L>5-O<G0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-O<G1">5)E=FES:6]N*"1A+"`D8BD*("`@('L*("`@("`@("!R971U
M<FX@5D-?4F5V:7-I;VXZ.F-M<"@D8BT^<F5V+"`D82T^<F5V*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!S;W)T0GE!9V4H)&$L("1B*0H@("`@>PH@("`@("`@
M(')E='5R;B`D8BT^9&%T92`M("1A+3YD871E.PH@("`@?0H*("`@(&9U;F-T
M:6]N('-O<G1">4YA;64H)&$L("1B*0H@("`@>PH@("`@("`@(')E='5R;B!S
M=')C;7`H)&$M/F%U=&AO<BP@)&(M/F%U=&AO<BD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!0;W!U;&%T92!T:&4@;V)J96-T('=I=&@@:6YF;W)M871I;VX@
M86)O=70@=&AE(')E=FES:6]N<R!L;V=S(&%N9"!D871E<PH@("`@("H@;V8@
M=&AE(&9I;&4N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N?&]B:F5C
M="`@4$5!4E]%<G)O<B!O8FIE8W0@;VX@97)R;W(L(&]R('1R=64@;VX@<W5C
M8V5S<PH@("`@("HO"B`@("!F=6YC=&EO;B!G971"<F]W<V5);F9O*"D*("`@
M('L*("`@("`@("`O*B!#:&5C:R!T:&%T('=E(&%R92!A8W1U86QL>2!I;B!T
M:&4@9FEL97-Y<W1E;2X@*B\*("`@("`@("`D9FEL92`]("1T:&ES+3YQ=65R
M>49U;&Q0871H*"D["B`@("`@("`@:68@*"%I<U]F:6QE*"1F:6QE*2D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1FEL92!.;W0@
M1F]U;F0Z("<@+B`D9FEL92D["B`@("`@("`@?0H*("`@("`@("`O*B!#86QL
M('1H92!20U,@<FQO9R!C;VUM86YD('1O(')E=')I979E('1H92!F:6QE"B`@
M("`@("`@("H@:6YF;W)M871I;VXN("HO"B`@("`@("`@)&9L86<@/2`D=&AI
M<RT^<75I8VML;V<@/R`G("UR("<@.B`G("<["B`@("`@("`@)'%?9FEL92`]
M(%9#7U=)3D1/5U,@/R`G(B<@+B!E<V-A<&5S:&5L;&-M9"@D9FEL92D@+B`G
M(B<@.B!E<V-A<&5S:&5L;&%R9R@D9FEL92D["@H@("`@("`@("1C;60@/2`D
M=&AI<RT^<F5P+3YG9710871H*"=R;&]G)RD@+B`D9FQA9R`N("1Q7V9I;&4[
M"B`@("`@("`@97AE8R@D8VUD+"`D<F5T=7)N7V%R<F%Y+"`D<F5T=F%L*3L*
M"B`@("`@("`@:68@*"1R971V86PI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T;R!S<&%W;B!R;&]G('1O(')E=')I
M979E(&9I;&4@;&]G(&EN9F]R;6%T:6]N(&9O<B`G("X@)&9I;&4I.PH@("`@
M("`@('T*"B`@("`@("`@)&%C8W5M(#T@87)R87DH*3L*("`@("`@("`D<WEM
M<F5V(#T@87)R87DH*3L*("`@("`@("`D<F5V<WEM(#T@87)R87DH*3L*("`@
M("`@("`D<W1A=&4@/2`G:6YI="<["B`@("`@("`@9F]R96%C:"`H)')E='5R
M;E]A<G)A>2!A<R`D;&EN92D@>PH@("`@("`@("`@("!S=VET8V@@*"1S=&%T
M92D@>PH@("`@("`@("`@("!C87-E("=I;FET)SH*("`@("`@("`@("`@("`@
M(&EF("@A<W1R;F-M<"@G:&5A9#H@)RP@)&QI;F4L(#8I*2!["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/FAE860@/2!S=6)S='(H)&QI;F4L(#8I.PH@
M("`@("`@("`@("`@("`@?2!E;'-E:68@*"%S=')N8VUP*"=B<F%N8V@Z)RP@
M)&QI;F4L(#<I*2!["B`@("`@("`@("`@("`@("`@("`@)'-T871E(#T@)W)E
M=B<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@(&-A<V4@)W)E=B<Z"B`@("`@("`@("`@("`@("!I9B`H
M(7-T<FYC;7`H)RTM+2TM+2TM+2TG+"`D;&EN92P@,3`I*2!["B`@("`@("`@
M("`@("`@("`@("`@)'-T871E(#T@)VEN9F\G.PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YS>6UR978@/2`D<WEM<F5V.PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YR979S>6T@/2`D<F5V<WEM.PH@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*'!R96=?;6%T8V@H(B]>7',K*%M>.ETK*3I<<RLH6UQD7"Y=
M*RDO(BP@)&QI;F4L("1R96=S*2D@>PH@("`@("`@("`@("`@("`@("`@("\O
M($-H96-K('1O('-E92!I9B!T:&ES(&ES(&$@8G)A;F-H"B`@("`@("`@("`@
M("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>*%QD*RA<+EQD*RDK*5PN,%PN
M*%QD*RDD+R<L)')E9W-;,ETI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1B<F%N8VA2978@/2!60U]2979I<VEO;CHZ=&]"<F%N8V@H)')E9W-;,ETI
M.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YB
M<F%N8VAE<ULD8G)A;F-H4F5V72DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YB<F%N8VAE<ULD8G)A;F-H4F5V72`]("1R96=S6S%=
M.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)'-Y;7)E=ELD
M<F5G<ULQ75T@/2`D<F5G<ULR73L*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*&5M<'1Y*"1R979S>6U;)')E9W-;,EU=*2D@)')E=G-Y;5LD<F5G<ULR
M75T]87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`@("`@)')E=G-Y;5LD
M<F5G<ULR75U;72`]("1R96=S6S%=.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`G:6YF;R<Z"B`@("`@("`@("`@("`@("!I9B`H<W1R
M;F-M<"@G/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T])RP@)&QI;F4L
M(#,P*2`F)@H@("`@("`@("`@("`@("`@("`@('-T<F-M<"@G+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2<L("1L:6YE*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1A8V-U;5M=(#T@)&QI;F4["B`@("`@("`@("`@("`@("!](&5L
M<V5I9B`H8V]U;G0H)&%C8W5M*2D@>PH@("`@("`@("`@("`@("`@("`@("\O
M('-P87=N(&$@;F5W(%9#7VQO9R!O8FIE8W0@86YD(&%D9"!I="!T;R!T:&4@
M;&]G<R!H87-H"B`@("`@("`@("`@("`@("`@("`@)&QO9R`](&YE=R!60U],
M;V=?8W9S*"1T:&ES*3L*("`@("`@("`@("`@("`@("`@("`D97)R(#T@)&QO
M9RT^<')O8V5S<TQO9R@D86-C=6TI.PH@("`@("`@("`@("`@("`@("`@("\O
M(%1/1$\Z(&5R<F]R(&-H96-K<R`M(&%V<VT*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^;&]G<ULD;&]G+3YQ=65R>5)E=FES:6]N*"E=(#T@)&QO9SL*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<F5V<UM=(#T@)&QO9RT^<75E
M<GE2979I<VEO;B@I.PH@("`@("`@("`@("`@("`@("`@("1A8V-U;2`](&%R
M<F%Y*"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&9U;&QY('%U
M86QI9FEE9"!F:6QE;F%M92!O9B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`<F5T=7)N($9U;&QY('%U86QI9FEE9"!F:6QE;F%M92!O9B!T:&ES(&]B
M:F5C=`H@("`@("HO"B`@("!F=6YC=&EO;B!Q=65R>49U;&Q0871H*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/F1I<B`N("<O)R`N("1T:&ES+3YN
M86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!N86UE(&]F
M('1H:7,@9FEL92!R96QA=&EV92!T;R!I=',@<V]U<F-E<F]O="X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@4&%T:&YA;64@<F5L871I=F4@=&\@
M=&AE('-O=7)C97)O;W0N"B`@("`@*B\*("`@(&9U;F-T:6]N('%U97)Y36]D
M=6QE4&%T:"@I"B`@("!["B`@("`@("`@<F5T=7)N('!R96=?<F5P;&%C92@G
M?%XG+B`D=&AI<RT^<F5P+3YS;W5R8V5R;V]T*"D@+B`G+S\H+BHI+'8D?"<L
M("=<,2<L("1T:&ES+3YQ=65R>49U;&Q0871H*"DI.PH@("`@?0H*?0H*+RHJ
M"B`J(%9#7V-V<R!L;V<@8VQA<W,N"B`J"B`J($!A=71H;W(@($%N:6P@36%D
M:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!P86-K86=E(%9#"B`J
M+PIC;&%S<R!60U],;V=?8W9S('L*"B`@("!V87(@)')E<#L*("`@('9A<B`D
M9FEL93L*("`@('9A<B`D=&%G<SL*("`@('9A<B`D<F5V.PH@("`@=F%R("1D
M871E.PH@("`@=F%R("1L;V<["B`@("!V87(@)&%U=&AO<CL*("`@('9A<B`D
M<W1A=&4["B`@("!V87(@)&QI;F5S.PH@("`@=F%R("1B<F%N8VAE<SL*"B`@
M("`O*BH*("`@("`J"B`@("`@*B\*("`@(&9U;F-T:6]N(%9#7TQO9U]C=G,H
M)&9L*0H@("`@>PH@("`@("`@("1T:&ES+3YF:6QE(#T@)&9L.PH@("`@("`@
M("1T:&ES+3YB<F%N8VAE<R`](&%R<F%Y*"D["B`@("!]"@H@("`@9G5N8W1I
M;VX@<')O8V5S<TQO9R@D<F%W*0H@("`@>PH@("`@("`@("\J($EN:71I86QI
M<V4@82!S:6UP;&4@<W1A=&4@;6%C:&EN92!T;R!P87)S92!T:&4@;W5T<'5T
M(&]F(')L;V<@*B\*("`@("`@("`D<W1A=&4@/2`G:6YI="<["B`@("`@("`@
M=VAI;&4@*"%E;7!T>2@D<F%W*2`F)B`D<W1A=&4@(3T@)V1O;F4G*2!["B`@
M("`@("`@("`@('-W:71C:"`H)'-T871E*2!["B`@("`@("`@("`@("\J($9O
M=6YD(&9I;&5N86UE+"!N;W<@;&]O:VEN9R!F;W(@=&AE(')E=FES:6]N(&YU
M;6)E<B`J+PH@("`@("`@("`@("!C87-E("=I;FET)SH*("`@("`@("`@("`@
M("`@("1L:6YE(#T@87)R87E?<VAI9G0H)')A=RD["B`@("`@("`@("`@("`@
M("!I9B`H<')E9U]M871C:"@B+W)E=FES:6]N("@N*RDD+R(L("1L:6YE+"`D
M<&%R=',I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G)E=B`]("1P
M87)T<ULQ73L*("`@("`@("`@("`@("`@("`@("`D<W1A=&4@/2`G9&%T92<[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@("\J($9O=6YD(')E=FES:6]N(&%N9"!F:6QE;F%M92P@;F]W
M(&QO;VMI;F<@9F]R(&1A=&4@*B\*("`@("`@("`@("`@8V%S92`G9&%T92<Z
M"B`@("`@("`@("`@("`@("`D;&EN92`](&%R<F%Y7W-H:69T*"1R87<I.PH@
M("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H(GQ>9&%T93I<<RLH7&0K
M*5LM+UTH7&0K*5LM+UTH7&0K*5QS*RA<9"LI.BA<9"LI.BA<9"LI+BH_.UQS
M*V%U=&AO<CI<<RLH+BLI.UQS*W-T871E.EQS*RA<4RLI.RA<<RML:6YE<SI<
M<RLH6S`M.5QS*RU=*RDI/WPB+"`D;&EN92P@)'!A<G1S*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YD871E(#T@9VUM:W1I;64H)'!A<G1S6S1=
M+"`D<&%R='-;-5TL("1P87)T<ULV72P@)'!A<G1S6S)=+"`D<&%R='-;,UTL
M("1P87)T<ULQ72D["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F%U=&AO
M<B`]("1P87)T<ULW73L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<W1A
M=&4@/2`D<&%R='-;.%T["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQI
M;F5S(#T@:7-S970H)'!A<G1S6S$P72D@/R`D<&%R='-;,3!=(#H@)R<["B`@
M("`@("`@("`@("`@("`@("`@)'-T871E(#T@)V)R86YC:&5S)SL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@+RH@3&]O:R!F;W(@82!B<F%N8V@@<&]I;G0@:&5R92`M(&9O<FUA="!I
M<R`G8G)A;F-H97,Z("!X+GDN>CL@(&$N8BYC.R<@*B\*("`@("`@("`@("`@
M8V%S92`G8G)A;F-H97,G.@H@("`@("`@("`@("`@("`@+RH@268@=V4@9FEN
M9"!A(&)R86YC:"!T86<L('!R;V-E<W,@86YD('!O<"!I="P*("`@("`@("`@
M("`@("`@("`@(&]T:&5R=VES92!L96%V92!I;G!U="!S=')E86T@=6YT;W5C
M:&5D("HO"B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1R87<I("8F('!R
M96=?;6%T8V@H(B]>8G)A;F-H97,Z7',K*"XJ*2\B+"`D<F%W6S!=+"`D8G(I
M*2!["B`@("`@("`@("`@("`@("`@("`@+RH@1V5T('1H92!L:7-T(&]F(&)R
M86YC:&5S(&9R;VT@=&AE('-T<FEN9RP@86YD"B`@("`@("`@("`@("`@("`@
M("`@("H@<'5S:"!V86QI9"!R979I<VEO;G,@:6YT;R!T:&4@8G)A;F-H97,@
M87)R87D@*B\*("`@("`@("`@("`@("`@("`@("`D8G)S(#T@<')E9U]S<&QI
M="@G+SM<<RHO)RP@)&)R6S%=*3L*("`@("`@("`@("`@("`@("`@("!F;W)E
M86-H("@D8G)S(&%S("1B<G!O:6YT*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("A60U]2979I<VEO;CHZ=F%L:60H)&)R<&]I;G0I*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8G)A;F-H97-;72`]("1B
M<G!O:6YT.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W-H:69T*"1R
M87<I.PH*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D<W1A
M=&4@/2`G9&]N92<["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@07-S=6UE('1H92!R97-T(&]F
M('1H92!L:6YE<R!A<F4@=&AE(&QO9R!M97-S86=E("HO"B`@("`@("`@)'1H
M:7,M/FQO9R`](&EM<&QO9&4H(EQN(BP@)')A=RD["B`@("`@("`@)'1H:7,M
M/G1A9W,@/2!`)'1H:7,M/F9I;&4M/G)E=G-Y;5LD=&AI<RT^<F5V73L*("`@
M("`@("!I9B`H96UP='DH)'1H:7,M/G1A9W,I*2!["B`@("`@("`@("`@("1T
M:&ES+3YT86=S(#T@87)R87DH*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N
M8W1I;VX@<75E<GE$871E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/F1A=&4["B`@("!]"@H@("`@9G5N8W1I;VX@<75E<GE2979I<VEO;B@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YR978["B`@("!]"@H@("`@9G5N
M8W1I;VX@<75E<GE!=71H;W(H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^875T:&]R.PH@("`@?0H*("`@(&9U;F-T:6]N('%U97)Y3&]G*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/FQO9SL*("`@('T*"B`@("!F=6YC
M=&EO;B!Q=65R>4-H86YG961,:6YE<R@I"B`@("!["B`@("`@("`@<F5T=7)N
M(&ES<V5T*"1T:&ES+3YL:6YE<RD@/R`H)'1H:7,M/FQI;F5S*2`Z("<G.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1VEV96X@82!B<F%N8V@@<F5V:7-I;VX@
M;G5M8F5R+"!T:&ES(&9U;F-T:6]N(')E;6%P<R!I=`H@("`@("H@86-C;W)D
M:6YG;'DL(&%N9"!P97)F;W)M<R!A(&QO;VMU<"!O;B!T:&4@9FEL92!O8FIE
M8W0@=&\*("`@("`J(')E='5R;B!T:&4@<WEM8F]L:6,@;F%M92AS*2!O9B!T
M:&%T(&)R86YC:"!I;B!T:&4@=')E92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!(87-H(&]F('-Y;6)O;&EC(&YA;65S(#T^(&)R86YC:"!N=6UB
M97)S"B`@("`@*B\*("`@(&9U;F-T:6]N('%U97)Y4WEM8F]L:6-"<F%N8VAE
M<R@I"B`@("!["B`@("`@("`@)'-Y;4)R86YC:&5S(#T@87)R87DH*3L*("`@
M("`@("!F;W)E86-H("@D=&AI<RT^8G)A;F-H97,@87,@)&)R86YC:"D@>PH@
M("`@("`@("`@("`D<&%R=',@/2!E>'!L;V1E*"<N)RP@)&)R86YC:"D["B`@
M("`@("`@("`@("1L87-T(#T@87)R87E?<&]P*"1P87)T<RD["B`@("`@("`@
M("`@("1P87)T<UM=(#T@)S`G.PH@("`@("`@("`@("`D<&%R='-;72`]("1L
M87-T.PH@("`@("`@("`@("`D<F5V(#T@:6UP;&]D92@G+B<L("1P87)T<RD[
M"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^9FEL92T^8G)A;F-H97-;
M)&)R86YC:%TI*2!["B`@("`@("`@("`@("`@("`D<WEM0G)A;F-H97-;)'1H
M:7,M/F9I;&4M/F)R86YC:&5S6R1B<F%N8VA=72`]("1B<F%N8V@["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1S>6U"<F%N8VAE
M<SL*("`@('T*"GT*"B\J*@H@*B!60U]C=G,@4&%T8VAS970@8VQA<W,N"B`J
M"B`J($-O<'ER:6=H="!!;FEL($UA9&AA=F%P961D>2P@/&%N:6Q`<F5C;VEL
M+F]R9SX*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`
M<F5C;VEL+F]R9SX*("H@0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#7U!A=&-H
M<V5T7V-V<R!E>'1E;F1S(%9#7U!A=&-H<V5T('L*"B`@("!V87(@)%]D:7([
M"B`@("!V87(@)%]N86UE.PH*("`@("\J*@H@("`@("H@0W)E871E(&$@<&%T
M8VAS970@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I
M;&4@(%1H92!F:6QE;F%M92!T;R!G970@<&%T8VAS971S(&9O<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@5D-?4&%T8VAS971?8W9S*"1F:6QE*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?;F%M92`](&)A<V5N86UE*"1F:6QE*3L*("`@("`@
M("`D=&AI<RT^7V1I<B`](&1I<FYA;64H)&9I;&4I.PH@("`@?0H*("`@(&9U
M;F-T:6]N("9G9710871C:'-E=$]B:F5C="@D<F5P+"`D9FEL96YA;64L("1C
M86-H92`](&YU;&PI"B`@("!["B`@("`@("`@+RH@5&AE('9E<G-I;VX@;V8@
M=&AE(&-A8VAE9"!D871A+B!);F-R96UE;G0@=&AI<R!W:&5N979E<B!T:&4*
M("`@("`@("`@*B!I;G1E<FYA;"!S=&]R86=E(&9O<FUA="!C:&%N9V5S+"!S
M=6-H('1H870@=V4@;75S=`H@("`@("`@("`J(&EN=F%L:61A=&4@<')I;W(@
M8V%C:&5D(&1A=&$N("HO"B`@("`@("`@)&-A8VAE5F5R<VEO;B`](#$["B`@
M("`@("`@)&-A8VAE260@/2`D<F5P+3YS;W5R8V5R;V]T*"D@+B`G7VXG("X@
M)&9I;&5N86UE("X@)U]F7W8G("X@)&-A8VAE5F5R<VEO;CL*"B`@("`@("`@
M)&-T:6UE(#T@=&EM92@I("T@0&9I;&5M=&EM92@D9FEL96YA;64@+B`G+'8G
M*3L*("`@("`@("!I9B`H)&-A8VAE("8F"B`@("`@("`@("`@("1C86-H92T^
M97AI<W1S*"1C86-H94ED+"`D8W1I;64I*2!["B`@("`@("`@("`@("1P<T]B
M(#T@=6YS97)I86QI>F4H)&-A8VAE+3YG970H)&-A8VAE260L("1C=&EM92DI
M.PH@("`@("`@("`@("`D<'-/8BT^<V5T4F5P;W-I=&]R>2@D<F5P*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<'-/8B`](&YE=R!60U]0871C
M:'-E=%]C=G,H)&9I;&5N86UE*3L*("`@("`@("`@("`@)'!S3V(M/G-E=%)E
M<&]S:71O<GDH)')E<"D["B`@("`@("`@("`@(&EF("AI<U]A*"@D<F5S=6QT
M(#T@)'!S3V(M/F=E=%!A=&-H<V5T<R@I*2P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&EF("@D8V%C:&4I('L*("`@("`@("`@("`@("`@("1C
M86-H92T^<V5T*"1C86-H94ED+"!S97)I86QI>F4H)'!S3V(I*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P<T]B.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4&]P=6QA=&4@=&AE(&]B:F5C="!W:71H(&EN
M9F]R;6%T:6]N(&%B;W5T('1H92!P871C:'-E=',@=&AA=`H@("`@("H@=&AI
M<R!F:6QE(&ES(&EN=F]L=F5D(&EN+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;GQO8FIE8W0@(%!%05)?17)R;W(@;V)J96-T(&]N(&5R<F]R+"!O
M<B!T<G5E(&]N('-U8V-E<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A
M=&-H<V5T<R@I"B`@("!["B`@("`@("`@+RH@0VAE8VL@=&AA="!W92!A<F4@
M86-T=6%L;'D@:6X@=&AE(&9I;&5S>7-T96TN("HO"B`@("`@("`@:68@*"%I
M<U]F:6QE*"1T:&ES+3YG971&=6QL4&%T:"@I("X@)RQV)RDI('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9I;&4@3F]T($9O=6YD
M)RD["B`@("`@("`@?0H*("`@("`@("`O*B!#86QL(&-V<W!S('1O(')E=')I
M979E(&%L;"!P871C:'-E=',@9F]R('1H:7,@9FEL92X@*B\*("`@("`@("`D
M<5]R;V]T(#T@)'1H:7,M/E]R97`M/G-O=7)C97)O;W0H*3L*("`@("`@("`D
M<5]R;V]T(#T@5D-?5TE.1$]74R`_("<B)R`N(&5S8V%P97-H96QL8VUD*"1Q
M7W)O;W0I("X@)R(G(#H@97-C87!E<VAE;&QA<F<H)'%?<F]O="D["@H@("`@
M("`@("1C=G-P<U]H;VUE(#T@)'1H:7,M/E]R97`M/F=E=%!A=&@H)V-V<W!S
M7VAO;64G*3L*("`@("`@("`D2$]-12`]("%E;7!T>2@D8W9S<'-?:&]M92D@
M/PH@("`@("`@("`@("`G2$]-13TG("X@)&-V<W!S7VAO;64@+B`G("<@.@H@
M("`@("`@("`@("`G)SL*"B`@("`@("`@)&-M9"`]("1(3TU%("X@)'1H:7,M
M/E]R97`M/F=E=%!A=&@H)V-V<W!S)RD@+B`G("UU("TM8W9S+61I<F5C="`M
M+7)O;W0@)R`N("1Q7W)O;W0@+B`G("UF("<@+B!E<V-A<&5S:&5L;&%R9R@D
M=&AI<RT^7VYA;64I("X@)R`G("X@97-C87!E<VAE;&QA<F<H)'1H:7,M/E]D
M:7(I.PH@("`@("`@(&5X96,H)&-M9"P@)')E='5R;E]A<G)A>2P@)')E='9A
M;"D["B`@("`@("`@:68@*"1R971V86PI('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T;R!S<&%W;B!C=G-P<R!T;R!R
M971R:65V92!P871C:'-E="!I;F9O<FUA=&EO;B<I.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/E]P871C:'-E=',@/2!A<G)A>2@I.PH@("`@("`@("1S
M=&%T92`]("=B96=I;B<["B`@("`@("`@9F]R96%C:"`H)')E='5R;E]A<G)A
M>2!A<R`D;&EN92D@>PH@("`@("`@("`@("`D;&EN92`]('1R:6TH)&QI;F4I
M.PH@("`@("`@("`@("!I9B`H)&QI;F4@/3T@)RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2<I('L*("`@("`@("`@("`@("`@("1S=&%T92`]("=B96=I;B<["B`@
M("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@<W=I=&-H("@D<W1A=&4I('L*("`@("`@("`@("`@8V%S92`G8F5G
M:6XG.@H@("`@("`@("`@("`@("`@)&ED(#T@<W1R7W)E<&QA8V4H)U!A=&-H
M4V5T("<L("<G+"`D;&EN92D["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M=&-H<V5T<ULD:61=(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("1S=&%T
M92`]("=I;F9O)SL*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@8V%S92`G:6YF;R<Z"B`@("`@("`@("`@("`@("`D:6YF;R`](&5X<&QO
M9&4H)SHG+"`D;&EN92P@,BD["B`@("`@("`@("`@("`@("!S=VET8V@@*"1I
M;F9O6S!=*2!["B`@("`@("`@("`@("`@("!C87-E("=$871E)SH*("`@("`@
M("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G?"A<9'LT?2DO*%QD>S)]
M*2\H7&1[,GTI("A<9'LR?2DZ*%QD>S)]*3HH7&1[,GTI?"<L("1I;F9O6S%=
M+"`D9&%T92DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M871C:'-E='-;)&ED75LG9&%T92==(#T@9VUM:W1I;64H)&1A=&5;-%TL("1D
M871E6S5=+"`D9&%T95LV72P@)&1A=&5;,ETL("1D871E6S-=+"`D9&%T95LQ
M72D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)T%U=&AO<B<Z"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P871C:'-E='-;)&ED75LG875T:&]R
M)UT@/2!T<FEM*"1I;F9O6S%=*3L*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@("`@("!C87-E("="<F%N8V@G.@H@("`@("`@("`@
M("`@("`@("`@(&EF("AT<FEM*"1I;F9O6S%=*2`A/2`G2$5!1"<I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P871C:'-E='-;)&ED75LG
M8G)A;F-H)UT@/2!T<FEM*"1I;F9O6S%=*3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@
M("`@8V%S92`G5&%G)SH*("`@("`@("`@("`@("`@("`@("!I9B`H=')I;2@D
M:6YF;ULQ72D@(3T@)RAN;VYE*2<I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P871C:'-E='-;)&ED75LG=&%G)UT@/2!T<FEM*"1I;F9O
M6S%=*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G3&]G)SH*("`@("`@
M("`@("`@("`@("`@("`D<W1A=&4@/2`G;&]G)SL*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A=&-H<V5T<ULD:61=6R=L;V<G72`]("<G.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=L;V<G.@H@
M("`@("`@("`@("`@("`@:68@*"1L:6YE(#T]("=-96UB97)S.B<I('L*("`@
M("`@("`@("`@("`@("`@("`D<W1A=&4@/2`G;65M8F5R<R<["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P871C:'-E='-;)&ED75LG;&]G)UT@/2!T
M<FEM*"1T:&ES+3Y?<&%T8VAS971S6R1I9%U;)VQO9R==*3L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A=&-H<V5T<ULD:61=6R=M96UB97)S)UT@
M/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A=&-H<V5T<ULD:61=6R=L;V<G72`N/2`D
M;&EN92`N(")<;B(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VUE;6)E<G,G.@H@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D;&EN92DI('L*("`@("`@("`@("`@("`@
M("`@("`D<&%R=',@/2!E>'!L;V1E*"<Z)RP@)&QI;F4I.PH@("`@("`@("`@
M("`@("`@("`@("1R979S(#T@97AP;&]D92@G+3XG+"`D<&%R='-;,5TI.PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%T8VAS971S6R1I9%U;)VUE
M;6)E<G,G75M=(#T@87)R87DH)V9I;&4G(#T^("1P87)T<ULP72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=F<F]M)R`]/B`D<F5V<ULP72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=T;R<@/3X@)')E=G-;,5TI.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N('1H92!F=6QL>2!Q=6%L:69I960@9FEL96YA;64@;V8@=&AI<R!O
M8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($9U;&QY('%U
M86QI9FEE9"!F:6QE;F%M92!O9B!T:&ES(&]B:F5C=`H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971&=6QL4&%T:"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?9&ER("X@)R\G("X@)'1H:7,M/E]N86UE.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]60R]R8W,N<&AP````````````````````````````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,38R,S8`,3`U,34T,S,W-3``,#(Q,S`R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!60U]R8W,@:6UP;&5M96YT871I;VXN"B`J"B`J($-O<'ER:6=H="`R
M,#`T+3(P,#8@2F5F9B!38VAW96YT;F5R(#QJ969F<F5Y+G-C:'=E;G1N97)`
M;&UC;RYC;VT^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U9#+U9#+W)C<RYP
M:'`L=B`Q+C,N."XU(#(P,#8O,#$O,#$@,C$Z,C@Z-#(@:F%N($5X<"`D"B`J
M"B`J($!A=71H;W(@($IE9F8@4V-H=V5N=&YE<B`\:F5F9G)E>2YS8VAW96YT
M;F5R0&QM8V\N8V]M/@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#7W)C
M<R!E>'1E;F1S(%9#('L*"B`@("`O*BH*("`@("`J($-H96-K<R!A;B!20U,@
M9FEL92!I;B!W:71H(&$@<W!E8VEF:65D(&-H86YG92!L;V<N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9FEL97!A=&@@("`@3&]C871I;VX@;V8@
M9FEL92!T;R!C:&5C:R!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&UE<W-A
M9V4@("`@($QO9R!O9B!C:&%N9V5S('-I;F-E(&QA<W0@=F5R<VEO;BX*("`@
M("`J($!P87)A;2!S=')I;F<@)'5S97(@("`@("`@(%1H92!U<V5R(&YA;64@
M=&\@=7-E(&9O<B!T:&4@8VAE8VL@:6XN"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D;F5W0FEN87)Y("!$;V5S('1H92!C:&%N9V4@:6YV;VQV92!B:6YA<GD@
M9&%T83\*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9WQO8FIE8W0@(%1H
M92!N97<@<F5V:7-I;VX@;G5M8F5R(&]N('-U8V-E<W,L(&]R(&$*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8VDH)&9I;&5P871H+"`D
M;65S<V%G92P@)'5S97(@/2!N=6QL+"`D;F5W0FEN87)Y(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@:68@*"1U<V5R*2!["B`@("`@("`@("`@('!U=&5N=B@G
M3$]'3D%-13TG("X@)'5S97(I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@('!U=&5N=B@G3$]'3D%-13UG=65S="<I.PH@("`@("`@('T*"B`@("`@
M("`@)%$@/2!60U]724Y$3U=3(#\@)R(G(#H@(B<B(#L*"B`@("`@("`@)&-I
M7V-M9"`]("1T:&ES+3YG9710871H*"=C:2<I("X@)R`G("X@)%$@+B`D9FEL
M97!A=&@@+B`D42XG(#(^)C$G.PH@("`@("`@("1R8W-?8VUD(#T@)'1H:7,M
M/F=E=%!A=&@H)W)C<R<I("X@)R`M:2`M:V(@)R`N("11("X@)&9I;&5P871H
M("X@)%$N)R`R/B8Q)SL*("`@("`@("`D;W5T<'5T(#T@)R<["@H@("`@("`@
M("1M97-S86=E7VQI;F5S(#T@97AP;&]D92@B7&XB+"`D;65S<V%G92D["@H@
M("`@("`@("1P:7!E7V1E9B`](&%R<F%Y*#`@/3X@87)R87DH(G!I<&4B+"`G
M<B<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@(#$@/3X@87)R87DH(G!I
M<&4B+"`G=R<I*3L*"B`@("`@("`@:68@*"1N97=":6YA<GDI('L*("`@("`@
M("`@("`@)'!R;V-E<W,@/2!P<F]C7V]P96XH)')C<U]C;60L("1P:7!E7V1E
M9BP@)'!I<&5S*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<')O
M8V5S<R`]('!R;V-?;W!E;B@D8VE?8VUD+"`D<&EP95]D968L("1P:7!E<RD[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?<F5S;W5R8V4H)'!R;V-E<W,I
M*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1M97-S86=E7VQI;F5S(&%S("1L
M:6YE*2!["B`@("`@("`@("`@("`@("!I9B`H)&QI;F4@/3T@)RY<;B<I('L*
M("`@("`@("`@("`@("`@("`@("`D;&EN92`]("<N(%QN)SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&9W<FET92@D<&EP97-;,%TL("1L
M:6YE*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@9G=R:71E*"1P:7!E
M<ULP72P@(EQN+EQN(BD["B`@("`@("`@("`@(&9C;&]S92@D<&EP97-;,%TI
M.PH*("`@("`@("`@("`@=VAI;&4@*"%F96]F*"1P:7!E<ULQ72DI('L*("`@
M("`@("`@("`@("`@("1O=71P=70@+CT@9G)E860H)'!I<&5S6S%=+"`X,3DR
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!F8VQO<V4H)'!I<&5S6S%=
M*3L*("`@("`@("`@("`@<')O8U]C;&]S92@D<')O8V5S<RD["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)T9A:6QE9"!T;R!O<&5N('!I<&4@:6X@8VDH*2<I.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"1N97=":6YA<GDI('L*("`@("`@("`@("`@97AE8R@D8VE?
M8VUD("X@)R`R/B8Q)RP@)')E='5R;E]A<G)A>2P@)')E='9A;"D["@H@("`@
M("`@("`@("!I9B`H)')E='9A;"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H(E5N86)L92!T;R!S<&%W;B!C:2!O;B`D9FEL
M97!A=&@@9G)O;2!C:2@I(BD["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D<F5T=7)N7V%R<F%Y(&%S("1L:6YE*2![
M"B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D;&EN93L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M)')E=E]S=&%R="`]('-T<G!O<R@D;W5T<'5T+"`G;F5W(')E=FES:6]N.B`G
M*3L*"B`@("`@("`@+R\@268@;F\@;F5W(')E=FES:6]N+"!S964@:68@=&AI
M<R!I<R!A;B!I;FET:6%L(&-H96-K:6XN"B`@("`@("`@:68@*"1R979?<W1A
M<G0@/3T](&9A;'-E*2!["B`@("`@("`@("`@("1R979?<W1A<G0@/2!S=')P
M;W,H)&]U='!U="P@)VEN:71I86P@<F5V:7-I;VXZ("<I.PH@("`@("`@("`@
M("`D<F5V7V5N9"`]('-T<G!O<R@D;W5T<'5T+"`G("<L("1R979?<W1A<G0I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R979?96YD(#T@<W1R
M<&]S*"1O=71P=70L("<[)RP@)')E=E]S=&%R="D["B`@("`@("`@?0H*("`@
M("`@("!I9B`H)')E=E]S=&%R="`A/3T@9F%L<V4@)B8@)')E=E]E;F0@(3T]
M(&9A;'-E*2!["B`@("`@("`@("`@("1R979?<W1A<G0@*ST@,30["B`@("`@
M("`@("`@(')E='5R;B!S=6)S='(H)&]U='!U="P@)')E=E]S=&%R="P@)')E
M=E]E;F0@+2`D<F5V7W-T87)T*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!U;FQO8VLH)&9I;&5P871H*3L*("`@("`@("`@("`@)'1E;7!?<&]S
M(#T@<W1R<&]S*"1O=71P=70L("=F:6QE(&ES('5N8VAA;F=E9"<I.PH@("`@
M("`@("`@("!I9B`H)'1E;7!?<&]S("$]/2!F86QS92D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-H96-K+6EN($9A:6QU
M<F4Z("<@+B!B87-E;F%M92@D9FEL97!A=&@I("X@)R!H87,@;F]T(&)E96X@
M;6]D:69I960G*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")&86EL960@=&\@8VAE8VMI
M;B`D9FEL97!A=&@L("1C:5]C;60L("1O=71P=70B*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!T:&4@
M;&]C:W,@;VX@82!#5E,O4D-3(&9I;&4N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9FEL97!A=&@@("`@3&]C871I;VX@;V8@9FEL92X*("`@("`J
M($!P87)A;2!S=')I;F<@)B1L;V-K961?8GD@(%)E='5R;G,@=&AE('5S97)N
M86UE(&AO;&1I;F<@=&AE(&QO8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N?&]B:F5C="`@5')U92!O;B!S=6-C97-S+"!O<B!A(%!%05)?17)R
M;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-,;V-K960H
M)&9I;&5P871H+"`F)&QO8VME9%]B>2D*("`@('L*("`@("`@("`D<FQO9U]C
M;60@(#T@)'1H:7,M/F=E=%!A=&@H)W)L;V<G*3L*("`@("`@("`D<FQO9U]F
M;&%G(#T@)R`M3"`G.PH*("`@("`@("`D42`](%9#7U=)3D1/5U,@/R`G(B<@
M.B`B)R(["@H@("`@("`@("1C;60@/2`D<FQO9U]C;60@+B`D<FQO9U]F;&%G
M("X@)%$@+B`D9FEL97!A=&@@+B`D43L*"B`@("`@("`@97AE8R@D8VUD+B<@
M,CXF,2<L("1R971U<FY?87)R87DL("1R971V86PI.PH*("`@("`@("!I9B`H
M)')E='9A;"D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@B56YA8FQE('1O('-P87=N(')L;V<@;VX@)&9I;&5P871H(&9R;VT@:7-,
M;V-K960H*2(I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1O=71P
M=70@/2`G)SL*"B`@("`@("`@("`@(&9O<F5A8V@@*"1R971U<FY?87)R87D@
M87,@)&QI;F4I('L*("`@("`@("`@("`@("`@("1O=71P=70@+CT@)&QI;F4[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1S=&%R=%]N86UE(#T@<W1R
M<&]S*"1O=71P=70L("=L;V-K960@8GDZ("<I.PH@("`@("`@("`@("`D96YD
M7VYA;64@/2!S=')P;W,H)&]U='!U="P@)SLG+"`D<W1A<G1?;F%M92D["@H@
M("`@("`@("`@("!I9B`H)'-T87)T7VYA;64@(3T](&9A;'-E("8F("1E;F1?
M;F%M92`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1S=&%R=%]N86UE
M("L](#$Q.PH@("`@("`@("`@("`@("`@)&QO8VME9%]B>2`]('-U8G-T<B@D
M;W5T<'5T+"`D<W1A<G1?;F%M92P@)&5N9%]N86UE("T@)'-T87)T7VYA;64I
M.PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T@
M(&5L<V5I9B`H<W1R;&5N*"1O=71P=70I(#T](#`I('L*("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=&86EL=7)E(')U
M;FYI;F<@<FQO9R!I;B!I<TQO8VME9"@I)RD["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!,;V-K<R!A($-64R]20U,@
M9FEL92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE<&%T:"`@
M3&]C871I;VX@;V8@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)'5S97(@
M("`@("!5<V5R(&YA;64@=&\@;&]C:R!T:&4@9FEL92!W:71H"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N?&]B:F5C="`@5')U92!O;B!S=6-C97-S
M+"!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@;&]C:R@D9FEL97!A=&@L("1U<V5R(#T@;G5L;"D*("`@('L*("`@
M("`@("`O+R!'970@=7-E<FYA;64@9F]R(%)#4R!T86<N"B`@("`@("`@:68@
M*"1U<V5R*2!["B`@("`@("`@("`@('!U=&5N=B@G3$]'3D%-13TG("X@)'5S
M97(I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('!U=&5N=B@G3$]'
M3D%-13UG=65S="<I.PH@("`@("`@('T*"B`@("`@("`@)')C<U]C;60@/2`D
M=&AI<RT^9V5T4&%T:"@G<F-S)RD["B`@("`@("`@)')C<U]F;&%G(#T@)R`M
M;"`G.PH*("`@("`@("`D42`](%9#7U=)3D1/5U,@/R`G(B<@.B`B)R(@.PH@
M("`@("`@("1C;60@/2`D<F-S7V-M9"`N("1R8W-?9FQA9R`N("11("X@)&9I
M;&5P871H("X@)%$["B`@("`@("`@97AE8R@D8VUD+B<@,CXF,2<L("1R971U
M<FY?87)R87DL("1R971V86PI.PH*("`@("`@("!I9B`H)')E='9A;"D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1F%I;&5D('1O
M('-P87=N(')C<R`H(B<@+B`D8VUD("X@)R(I(&]N("(G("X@)&9I;&5P871H
M("X@)R(@*')E='5R;F5D("<@+B`D<F5T=F%L("X@)RDG*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D;W5T<'5T(#T@)R<["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1R971U<FY?87)R87D@87,@)&QI;F4I('L*("`@("`@("`@
M("`@("`@("1O=71P=70@+CT@)&QI;F4["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1L;V-K961?<&]S(#T@<W1R<&]S*"1O=71P=70L("=L;V-K960G
M*3L*("`@("`@("`@("`@:68@*"1L;V-K961?<&]S("$]/2!F86QS92D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G
M1F%I;&5D('1O(&QO8VL@(B<@+B`D9FEL97!A=&@@+B`G(B`H4F%N("(G("X@
M)&-M9"`N("<B+"!G;W0@<F5T=7)N(&-O9&4@)R`N("1R971V86P@+B`G+"!O
M=71P=70Z("<@+B`D;W5T<'5T("X@)RDG*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%5N;&]C:W,@82!#5E,O4D-3
M(&9I;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL97!A=&@@
M($QO8V%T:6]N(&]F(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R
M("`@("`@57-E<B!N86UE('1O('5N;&]C:R!T:&4@9FEL92!W:71H"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N?&]B:F5C="`@5')U92!O;B!S=6-C
M97-S+"!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@=6YL;V-K*"1F:6QE<&%T:"P@)'5S97(@/2!N=6QL*0H@("`@
M>PH@("`@("`@("\O($=E="!U<V5R;F%M92!F;W(@4D-3('1A9RX*("`@("`@
M("!I9B`H)'5S97(I('L*("`@("`@("`@("`@<'5T96YV*"=,3T=.04U%/2<@
M+B`D=7-E<BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<'5T96YV
M*"=,3T=.04U%/6=U97-T)RD["B`@("`@("`@?0H*("`@("`@("`D<F-S7V-M
M9"`]("1T:&ES+3YG9710871H*"=R8W,G*3L*("`@("`@("`D<F-S7V9L86<@
M/2`G("UU("<["@H@("`@("`@("11(#T@5D-?5TE.1$]74R`_("<B)R`Z("(G
M(B`["B`@("`@("`@)&-M9"`]("1R8W-?8VUD("X@)')C<U]F;&%G("X@)%$@
M+B`D9FEL97!A=&@@+B`D43L*("`@("`@("!E>&5C*"1C;60@+B`G(#(^)C$G
M+"`D<F5T=7)N7V%R<F%Y+"`D<F5T=F%L*3L*"B`@("`@("`@:68@*"1R971V
M86PI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9A
M:6QE9"!T;R!S<&%W;B!R8W,@*"(G("X@)&-M9"`N("<B*2!O;B`B)R`N("1F
M:6QE<&%T:"`N("<B("AR971U<FYE9"`G("X@)')E='9A;"`N("<I)RD["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&]U='!U="`]("<G.PH*("`@
M("`@("`@("`@9F]R96%C:"`H)')E='5R;E]A<G)A>2!A<R`D;&EN92D@>PH@
M("`@("`@("`@("`@("`@)&]U='!U="`N/2`D;&EN93L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@)'5N;&]C:V5D7W!O<R`]('-T<G!O<R@D;W5T<'5T
M+"`G=6YL;V-K960G*3L*"B`@("`@("`@("`@(&EF("@D=6YL;V-K961?<&]S
M("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O+R!!;')E861Y
M('5N;&]C:V5D+@H@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+U9#+W-V;BYP:'``````````````````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`V,#4S-P`Q,#4Q-30S,S<U,``P,C$S,C0`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J(%9#7W-V;B!I;7!L96UE;G1A=&EO;BX*("H*("H@0V]P>7)I9VAT
M(#(P,#`M,C`P-B!!;FEL($UA9&AA=F%P961D>2P@/&%N:6Q`<F5C;VEL+F]R
M9SX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5D,O5D,O<W9N+G!H<"QV(#$N
M,C@N-"XQ."`R,#`V+S`U+S$R(#`T.C0W.C`X(&-H=6-K($5X<"`D"B`J"B`J
M($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^
M"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!60PH@*B\*8VQA
M<W,@5D-?<W9N(&5X=&5N9',@5D,@>PH*("`@("\J*@H@("`@("H@0V]N<W1R
M=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N
M>2!P87)A;65T97(@=&AE(&-L87-S(&5X<&5C=',N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@0W5R<F5N="!P87)A;65T97)S.@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("=S;W5R8V5R;V]T)SH@5&AE('-O=7)C92!R
M;V]T(&9O<B!T:&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!R97!O<VET;W)Y"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@)W!A=&AS)SH@2&%S:"!W:71H('1H92!L;V-A=&EO;G,@;V8@86QL
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;F5C97-S
M87)Y(&)I;F%R:65S.B`G<W9N)RP@)V1I9F8G"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%9#7W-V;B@D<&%R86US*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V]U
M<F-E<F]O="`]("1P87)A;7-;)W-O=7)C97)O;W0G73L*("`@("`@("`D=&AI
M<RT^7W!A=&AS(#T@)'!A<F%M<ULG<&%T:',G73L*("`@('T*"B`@("!F=6YC
M=&EO;B!I<T9I;&4H)'=H97)E*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@(&9U;F-T:6]N("9Q=65R>41I<B@D=VAE<F4I"B`@("![
M"B`@("`@("`@)&1I<B`](&YE=R!60U]$:7)E8W1O<GE?<W9N*"1T:&ES+"`D
M=VAE<F4I.PH@("`@("`@(')E='5R;B`D9&ER.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&=E=$-H96-K;W5T*"1F:6QE+"`D<F5V*0H@("`@>PH@("`@("`@(')E
M='5R;B!60U]#:&5C:V]U=%]S=FXZ.F=E="@D=&AI<RP@)&9I;&4M/G%U97)Y
M1G5L;%!A=&@H*2P@)')E=BD["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T1&EF
M9B@D9FEL92P@)')E=C$L("1R978R+"`D='EP92`]("=C;VYT97AT)RP@)&YU
M;2`](#,L("1W<R`]('1R=64I"B`@("!["B`@("`@("`@<F5T=7)N(%9#7T1I
M9F9?<W9N.CIG970H)'1H:7,L("1F:6QE+"`D<F5V,2P@)')E=C(L("1T>7!E
M+"`D;G5M+"`D=W,I.PH@("`@?0H*("`@(&9U;F-T:6]N("9G971&:6QE3V)J
M96-T*"1F:6QE;F%M92P@)&-A8VAE(#T@;G5L;"P@)'%U:6-K;&]G(#T@9F%L
M<V4I"B`@("!["B`@("`@("`@)&9O(#T@)E9#7T9I;&5?<W9N.CIG971&:6QE
M3V)J96-T*"1T:&ES+"`D9FEL96YA;64L("1C86-H92P@)'%U:6-K;&]G*3L*
M("`@("`@("!R971U<FX@)&9O.PH@("`@?0H*("`@(&9U;F-T:6]N("9G971!
M;FYO=&%T94]B:F5C="@D9FEL96YA;64I"B`@("!["B`@("`@("`@)&)L86UE
M(#T@;F5W(%9#7T%N;F]T871E7W-V;B@D=&AI<RP@)&9I;&5N86UE*3L*("`@
M("`@("!R971U<FX@)&)L86UE.PH@("`@?0H*("`@(&9U;F-T:6]N("9G9710
M871C:'-E=$]B:F5C="@D9FEL96YA;64L("1C86-H92`](&YU;&PI"B`@("![
M"B`@("`@("`@)'!O(#T@)E9#7U!A=&-H<V5T7W-V;CHZ9V5T4&%T8VAS971/
M8FIE8W0H)'1H:7,L("1F:6QE;F%M92P@)&-A8VAE*3L*("`@("`@("!R971U
M<FX@)'!O.PH@("`@?0H*?0H*+RHJ"B`J(%9#7W-V;B!A;FYO=&%T92!C;&%S
M<RX*("H*("H@06YI;"!-861H879A<&5D9'DL(#QA;FEL0')E8V]I;"YO<F<^
M"B`J"B`J($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I
M;"YO<F<^"B`J($!P86-K86=E(%9#"B`J+PIC;&%S<R!60U]!;FYO=&%T95]S
M=FX@>PH*("`@('9A<B`D9FEL93L*("`@('9A<B`D4U9..PH@("`@=F%R("1T
M;7!F:6QE.PH*("`@(&9U;F-T:6]N(%9#7T%N;F]T871E7W-V;B@D<F5P+"`D
M9FEL92D*("`@('L*("`@("`@("`D=&AI<RT^4U9.(#T@)')E<#L*("`@("`@
M("`D=&AI<RT^9FEL92`]("1F:6QE.PH@("`@?0H*("`@(&9U;F-T:6]N(&1O
M06YN;W1A=&4H)')E=BD*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@=&AA
M="!T:&4@9FEL92!V86QU97,@9F]R('1H:7,@;V)J96-T(&ES('9A;&ED+B`J
M+PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3YF:6QE+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@(&EF("@A5D-?4F5V:7-I;VXZ.G9A;&ED*"1R978I*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("11(#T@5D-?
M5TE.1$]74R`_("<B)R`Z("(G(CL*("`@("`@("`D8V]M;6%N9"`]("1T:&ES
M+3Y35DXM/F=E=%!A=&@H)W-V;B<I("X@)R!A;FYO=&%T92`M<B`Q.B<@+B`D
M<F5V("X@)R`G("X@)%$@+B!S=')?<F5P;&%C92@D42P@)UQ<)R`N("11+"`D
M=&AI<RT^9FEL92T^<75E<GE&=6QL4&%T:"@I*2`N("11("X@)R`R/B8Q)SL*
M("`@("`@("`D<&EP92`]('!O<&5N*"1C;VUM86YD+"`G<B<I.PH@("`@("`@
M(&EF("@A)'!I<&4I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)T9A:6QE9"!T;R!E>&5C=71E('-V;B!A;FYO=&%T93H@)R`N("1C
M;VUM86YD*3L*("`@("`@("!]"@H@("`@("`@("1L:6YE<R`](&%R<F%Y*"D[
M"B`@("`@("`@)&QI;F5N;R`](#$["B`@("`@("`@=VAI;&4@*"%F96]F*"1P
M:7!E*2D@>PH@("`@("`@("`@("`D;&EN92`](&9G971S*"1P:7!E+"`T,#DV
M*3L*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>7',K*%QD*RE<<RLH
M6UQW7"Y=*RE<<R@N*BDD+R<L("1L:6YE+"`D<F5G<RDI('L*("`@("`@("`@
M("`@("`@("1E;G1R>2`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`D96YT
M<GE;)W)E=B==("`@(#T@)')E9W-;,5T["B`@("`@("`@("`@("`@("`D96YT
M<GE;)V%U=&AO<B==(#T@=')I;2@D<F5G<ULR72D["B`@("`@("`@("`@("`@
M("`D96YT<GE;)V1A=&4G72`@(#T@)R<["B`@("`@("`@("`@("`@("`D96YT
M<GE;)VQI;F4G72`@(#T@)')E9W-;,UT["B`@("`@("`@("`@("`@("`D96YT
M<GE;)VQI;F5N;R==(#T@)&QI;F5N;RLK.PH@("`@("`@("`@("`@("`@)&QI
M;F5S6UT@/2`D96YT<GD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@('!C;&]S92@D<&EP92D["B`@("`@("`@<F5T=7)N("1L:6YE<SL*("`@
M('T*"GT*"B\J*@H@*B!60U]S=FX@8VAE8VMO=70@8VQA<W,N"B`J"B`J($%N
M:6P@36%D:&%V87!E9&1Y+"`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!`875T
M:&]R("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`
M<&%C:V%G92!60PH@*B\*8VQA<W,@5D-?0VAE8VMO=71?<W9N('L*"B`@("`O
M*BH*("`@("`J(%-T871I8R!F=6YC=&EO;B!W:&EC:"!R971U<FYS(&$@9FEL
M92!P;VEN=&EN9R!T;R!T:&4@:&5A9"!O9B!T:&4@<F5Q=65S=&5D"B`@("`@
M*B!R979I<VEO;B!O9B!A;B!20U,@9FEL92X*("`@("`J($!P87)A;2!F=6QL
M;F%M92!&=6QL>2!Q=6%L:69I960@<&%T:&YA;64@;V8@=&AE(&1E<VER960@
M4D-3(&9I;&4@=&\@8VAE8VMO=70*("`@("`J($!P87)A;2!R978@4D-3(')E
M=FES:6]N(&YU;6)E<B!T;R!C:&5C:R!O=70*("`@("`J($!R971U<FX@16ET
M:&5R(&$@4$5!4E]%<G)O<B!O8FIE8W0L(&]R(&$@<W1R96%M('!O:6YT97(@
M=&\@=&AE(&AE860@;V8@=&AE(&-H96-K;W5T"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E="@D<F5P+"`D9G5L;&YA;64L("1R978I"B`@("!["B`@("`@("`@
M:68@*"%60U]2979I<VEO;CHZ=F%L:60H)')E=BDI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TEN=F%L:60@<F5V:7-I;VX@;G5M
M8F5R)RD["B`@("`@("`@?0H*("`@("`@("!I9B`H5D-?5TE.1$]74RD@>PH@
M("`@("`@("`@("`D42`]("<B)SL*("`@("`@("`@("`@)&UO9&4@/2`G<F(G
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("11(#T@(B<B.PH@("`@
M("`@("`@("`D;6]D92`]("=R)SL*("`@("`@("!]"@H@("`@("`@(&EF("@A
M*"120U,@/2!P;W!E;B@D<F5P+3YG9710871H*"=S=FXG*2`N("<@8V%T("UR
M("<@+B`D<F5V("X@)R`G("X@)%$@+B!S=')?<F5P;&%C92@D42P@)UQ<)R`N
M("11+"`D9G5L;&YA;64I("X@)%$@+B`G(#(^)C$G+"`D;6]D92DI*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=#;W5L9&Y<)W0@
M<&5R9F]R;2!C:&5C:V]U="!O9B!T:&4@<F5Q=65S=&5D(&9I;&4G*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D4D-3.PH@("`@?0H*?0H*+RHJ"B`J
M(%9#7W-V;B!D:69F(&-L87-S+@H@*@H@*B!#;W!Y<FEG:'0@06YI;"!-861H
M879A<&5D9'DL(#QA;FEL0')E8V]I;"YO<F<^"B`J"B`J($!A=71H;W(@($%N
M:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!P86-K86=E
M(%9#"B`J+PIC;&%S<R!60U]$:69F7W-V;B!["@H@("`@+RHJ"B`@("`@*B!/
M8G1A:6X@=&AE(&1I9F9E<F5N8V5S(&)E='=E96X@='=O(')E=FES:6]N<R!O
M9B!A(&9I;&4N"B`@("`@*@H@("`@("H@0'!A<F%M(%9#7W-V;B`D<F5P("`@
M("`@("!!(')E<&]S:71O<GD@;V)J96-T+@H@("`@("H@0'!A<F%M(%9#7T9I
M;&5?<W9N("1F:6QE("!4:&4@9&5S:7)E9"!F:6QE+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<F5V,2`@("`@("!/<FEG:6YA;"!R979I<VEO;B!N=6UB97(@
M=&\@8V]M<&%R92!F<F]M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5V,B`@
M("`@("!.97<@<F5V:7-I;VX@;G5M8F5R('1O(&-O;7!A<F4@86=A:6YS="X*
M("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@("`@("`@5&AE('1Y<&4@;V8@
M9&EF9B`H92YG+B`G=6YI9FEE9"<I+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&YU;2`@("`@("!.=6UB97(@;V8@;&EN97,@=&\@8F4@=7-E9"!I;B!C;VYT
M97AT(&%N9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!U;FEF
M:65D(&1I9F9S+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'=S("`@("`@("!3
M:&]W('=H:71E<W!A8V4@:6X@=&AE(&1I9F8_"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F=\8F]O;&5A;B`@1F%L<V4@;VX@9F%I;'5R92P@;W(@82!S
M=')I;F<@8V]N=&%I;FEN9R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@(&1I9F8@;VX@<W5C8V5S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T*"1R97`L("1F:6QE+"`D<F5V,2P@)')E=C(L("1T>7!E(#T@)V-O;G1E
M>'0G+"`D;G5M(#T@,RP*("`@("`@("`@("`@("`@("`D=W,@/2!T<G5E*0H@
M("`@>PH@("`@("`@("\J($UA:V4@<W5R92!T:&%T('1H92!F:6QE('!A<F%M
M971E<B!I<R!V86QI9"`J+PH@("`@("`@(&EF("AI<U]A*"1F:6QE+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@("\J($-H96-K('1H870@=&AE(')E=FES:6]N(&YU;6)E
M<G,@87)E('9A;&ED("HO"B`@("`@("`@)')E=C$@/2!60U]2979I<VEO;CHZ
M=F%L:60H)')E=C$I(#\@)')E=C$@.B`P.PH@("`@("`@("1R978R(#T@5D-?
M4F5V:7-I;VXZ.G9A;&ED*"1R978Q*2`_("1R978R(#H@,#L*"B`@("`@("`@
M)&9U;&Q.86UE(#T@)&9I;&4M/G%U97)Y1G5L;%!A=&@H*3L*("`@("`@("`D
M9&EF9B`](&%R<F%Y*"D["B`@("`@("`@)&]P=&EO;G,@/2`G)SL*("`@("`@
M("!I9B`H(21W<RD@>PH@("`@("`@("`@("`D;W!T:6]N<R`N/2`G("UB0B`G
M.PH@("`@("`@('T*"B`@("`@("`@<W=I=&-H("@D='EP92D@>PH@("`@("`@
M(&-A<V4@)V-O;G1E>'0G.@H@("`@("`@("`@("`D;W!T:6]N<R`N/2`G+2UC
M;VYT97AT/2<@+B`H:6YT*21N=6T["B`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("!C87-E("=U;FEF:65D)SH*("`@("`@("`@("`@)&]P=&EO;G,@+CT@
M)RTM=6YI9FEE9#TG("X@*&EN="DD;G5M.PH@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@8V%S92`G8V]L=6UN)SH*("`@("`@("`@("`@)&]P=&EO;G,@
M+CT@)RTM<VED92UB>2US:61E("TM=VED=&@],3(P)SL*("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@(&-A<V4@)V5D)SH*("`@("`@("`@("`@)&]P=&EO
M;G,@+CT@)RUE)SL*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@
M("`@("`O+R!43T1/.B!A9&0@;W!T:6]N<R!F;W(@)&AR(&]P=&EO;G,@+2!H
M;W=E=F5R('1H97-E(&UA>2!N;W0*("`@("`@("`O+R!B92!C;VUP871I8FQE
M('=I=&@@<V]M92!D:69F<RX*("`@("`@("`D42`](%9#7U=)3D1/5U,@/R`G
M(B<@.B`B)R(["B`@("`@("`@)&-O;6UA;F0@/2`D<F5P+3YG9710871H*"=S
M=FXG*2`N("(@9&EF9B`M+61I9F8M8VUD("(@+B`D<F5P+3YG9710871H*"=D
M:69F)RD@+B`B("UR("1R978Q.B1R978R("UX("(@+B`D42`N("1O<'1I;VYS
M("X@)%$@+B`G("<@+B`D9FEL92T^<75E<GE&=6QL4&%T:"@I("X@)R`R/B8Q
M)SL*"B`@("`@("`@97AE8R@D8V]M;6%N9"P@)&1I9F8L("1R971V86PI.PH@
M("`@("`@(')E='5R;B`D9&EF9CL*("`@('T*"GT*"B\J*@H@*B!60U]S=FX@
M9&ER96-T;W)Y(&-L87-S+@H@*@H@*B!#;W!Y<FEG:'0@06YI;"!-861H879A
M<&5D9'DL(#QA;FEL0')E8V]I;"YO<F<^"B`J"B`J($!A=71H;W(@($%N:6P@
M36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!P86-K86=E(%9#
M"B`J+PIC;&%S<R!60U]$:7)E8W1O<GE?<W9N('L*"B`@("!V87(@)')E<#L*
M("`@('9A<B`D9&ER3F%M93L*("`@('9A<B`D9FEL97,["B`@("!V87(@)&%T
M=&EC1FEL97,["B`@("!V87(@)&UE<F=E9$9I;&5S.PH@("`@=F%R("1D:7)S
M.PH@("`@=F%R("1P87)E;G0["B`@("!V87(@)&UO9'5L94YA;64["@H@("`@
M+RHJ"B`@("`@*B!#<F5A=&4@82!35DX@1&ER96-T;W)Y(&]B:F5C="!T;R!S
M=&]R92!I;F9O<FUA=&EO;B!A8F]U="!T:&4*("`@("`J(&9I;&5S(&EN(&$@
M<VEN9VQE(&1I<F5C=&]R>2!I;B!T:&4@<F5P;W-I=&]R>0H@("`@("H*("`@
M("`J($!P87)A;2!60U]297!O<VET;W)Y7W-V;B`D<G`@(%1H92!60U]297!O
M<VET;W)Y(&]B:F5C="!T:&ES(&1I<F5C=&]R>0H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:7,@<&%R="!O9BX*("`@("`J($!P87)A
M;2!S=')I;F<@)&1N("`@("`@("`@("`@(%!A=&@@=&\@=&AE(&1I<F5C=&]R
M>2X*("`@("`J($!P87)A;2!60U]$:7)E8W1O<GE?<W9N("1P;B`@(%1H92!P
M87)E;G0@5D-?1&ER96-T;W)Y('1O('1H:7,@;VYE+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!60U]$:7)E8W1O<GE?<W9N*"1R97`L("1D;BP@)'!N(#T@)R<I
M"B`@("!["B`@("`@("`@)'1H:7,M/G)E<"`]("1R97`["B`@("`@("`@)'1H
M:7,M/G!A<F5N="`]("1P;CL*("`@("`@("`D=&AI<RT^;6]D=6QE3F%M92`]
M("1D;CL*("`@("`@("`D=&AI<RT^9&ER3F%M92`]("(O)&1N(CL*("`@("`@
M("`D=&AI<RT^9FEL97,@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3YD:7)S
M(#T@87)R87DH*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!F=6QL
M>2!Q=6%L:69I960@<&%T:&YA;64@=&\@=&AI<R!D:7)E8W1O<GD@=VET:"!N
M;PH@("`@("H@=')A:6QI;F<@+RX*("`@("`J"B`@("`@*B!`<F5T=7)N(%!A
M=&AN86UE(&]F('1H:7,@9&ER96-T;W)Y"B`@("`@*B\*("`@(&9U;F-T:6]N
M('%U97)Y1&ER*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F1I<DYA
M;64["B`@("!]"@H@("`@9G5N8W1I;VX@)G%U97)Y1&ER3&ES="@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YD:7)S.PH@("`@?0H*("`@(&9U;F-T
M:6]N("9Q=65R>49I;&5,:7-T*"1S:&]W871T:6,@/2!F86QS92D*("`@('L*
M("`@("`@("!I9B`H)'-H;W=A='1I8R`F)B!I<W-E="@D=&AI<RT^;65R9V5D
M1FEL97,I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;65R9V5D1FEL
M97,["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YF:6QE<SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!496QL
M('1H92!O8FIE8W0@=&\@;W!E;B!A;F0@8G)O=W-E(&ET<R!C=7)R96YT(&1I
M<F5C=&]R>2P@86YD"B`@("`@*B!R971R:65V92!A(&QI<W0@;V8@86QL('1H
M92!O8FIE8W1S(&EN('1H97)E+B`@270@=&AE;B!P;W!U;&%T97,*("`@("`J
M('1H92!F:6QE+V1I<F5C=&]R>2!S=&%C:R!A;F0@;6%K97,@:70@879A:6QA
M8FQE(&9O<B!R971R:65V86PN"B`@("`@*@H@("`@("H@0')E='5R;B!014%2
M7T5R<F]R(&]B:F5C="!O;B!A;B!E<G)O<BP@,2!O;B!S=6-C97-S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!B<F]W<V5$:7(H)&-A8VAE(#T@;G5L;"P@)'%U
M:6-K;&]G(#T@=')U92P@)'-H;W=A='1I8R`](&9A;'-E*0H@("`@>PH@("`@
M("`@("11(#T@5D-?5TE.1$]74R`_("<B)R`Z("(G(B`["B`@("`@("`@)&-M
M9"`]("1T:&ES+3YR97`M/F=E=%!A=&@H)W-V;B<I("X@)R!L<R`G("X@)%$@
M+B!S=')?<F5P;&%C92@D42P@)UQ<)R`N("11+"`D=&AI<RT^<F5P+3YS;W5R
M8V5R;V]T*"D@+B`D=&AI<RT^<75E<GE$:7(H*2D@+B`D42`N("<@,CXF,2<[
M"B`@("`@("`@)&1I<B`]('!O<&5N*"1C;60L("=R)RD["B`@("`@("`@:68@
M*"$D9&ER*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=&86EL960@=&\@97AE8W5T92!S=FX@;',Z("<@+B`D8VUD*3L*("`@("`@
M("!]"@H@("`@("`@("\J($-R96%T92!T=V\@87)R87ES("T@;VYE(&]F(&%L
M;"!T:&4@9FEL97,L(&%N9"!T:&4@;W1H97(@;V8*("`@("`@("`@*B!A;&P@
M=&AE(&1I<G,N("HO"B`@("`@("`@)&5R<F]R<R`](&%R<F%Y*"D["B`@("`@
M("`@=VAI;&4@*"%F96]F*"1D:7(I*2!["B`@("`@("`@("`@("1L:6YE(#T@
M8VAO<"AF9V5T<R@D9&ER+"`Q,#(T*2D["B`@("`@("`@("`@(&EF("@A<W1R
M;&5N*"1L:6YE*2D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@(&EF("AS=6)S='(H)&QI;F4L(#`L(#0I
M(#T]("=S=FXZ)RD@>PH@("`@("`@("`@("`@("`@)&5R<F]R<UM=(#T@)&QI
M;F4["B`@("`@("`@("`@('T@96QS96EF("AS=6)S='(H)&QI;F4L("TQ*2`]
M/2`G+R<I('L*("`@("`@("`@("`@("`@("1T:&ES+3YD:7)S6UT@/2!S=6)S
M='(H)&QI;F4L(#`L("TQ*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1F;"`]("1T:&ES+3YR97`M/F=E=$9I;&5/8FIE8W0H)'1H
M:7,M/G%U97)Y1&ER*"D@+B`B+R1L:6YE(BP@)&-A8VAE+"`D<75I8VML;V<I
M.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)&9L+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1F;#L*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F9I
M;&5S6UT@/2`D9FP["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@('!C;&]S92@D9&ER*3L*"B`@("`@("`@:68@
M*"1E<G)O<G,I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H:6UP;&]D92@B7&XB+"`D97)R;W)S*2D["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-O<G0@=&AE
M(&-O;G1E;G1S(&]F('1H92!D:7)E8W1O<GD@:6X@82!G:79E;B!F87-H:6]N
M(&%N9`H@("`@("H@;W)D97(N"B`@("`@*@H@("`@("H@0'!A<F%M("1H;W<@
M3V8@=&AE(&9O<FT@5D-?4T]25%\J('=H97)E("H@8V%N(&)E.@H@("`@("H@
M("`@("`@("`@("`@3D].12P@3D%-12P@04=%+"!2158@9F]R('-O<G1I;F<@
M8GD@;F%M92P@86=E(&]R(')E=FES:6]N+@H@("`@("H@0'!A<F%M("1D:7(@
M3V8@=&AE(&9O<FT@5D-?4T]25%\J('=H97)E("H@8V%N(&)E.@H@("`@("H@
M("`@("`@("`@("`@05-#14Y$24Y'+"!$15-#14Y$24Y'(&9O<B!T:&4@;W)D
M97(@;V8@=&AE('-O<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%P<&QY4V]R
M="@D:&]W(#T@5D-?4T]25%].3TY%+"`D9&ER(#T@5D-?4T]25%]!4T-%3D1)
M3D<I"B`@("!["B`@("`@("`@+RH@5$]$3SH@=&AI<R!C;V1E(&QO;VMS('9E
M<GD@:6YE9F9I8VEE;G0A(&]P=&EM:7-E+BXN("T*("`@("`@("`@*B!A=G-M
M+B`J+PH*("`@("`@("`O+R!!<W-U;64@8GD@;F%M92!F;W(@=&AE(&UO;65N
M="X*("`@("`@("!N871C87-E<V]R="@D=&AI<RT^9&ER<RD["B`@("`@("`@
M)'1H:7,M/F1O1FEL95-O<G0H)'1H:7,M/F9I;&5S+"`D:&]W+"`D9&ER*3L*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/F%T=&EC1FEL97,I*2!["B`@("`@
M("`@("`@("1T:&ES+3YD;T9I;&53;W)T*"1T:&ES+3YA='1I8T9I;&5S+"`D
M:&]W+"`D9&ER*3L*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3YM97)G961&:6QE<RDI('L*("`@("`@("`@("`@)'1H:7,M/F1O1FEL95-O
M<G0H)'1H:7,M/FUE<F=E9$9I;&5S+"`D:&]W+"`D9&ER*3L*("`@("`@("!]
M"B`@("`@("`@:68@*"1D:7(@/3T@5D-?4T]25%]$15-#14Y$24Y'*2!["B`@
M("`@("`@("`@("1T:&ES+3YD:7)S(#T@87)R87E?<F5V97)S92@D=&AI<RT^
M9&ER<RD["B`@("`@("`@("`@("1T:&ES+3YF:6QE<R`](&%R<F%Y7W)E=F5R
M<V4H)'1H:7,M/F9I;&5S*3L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3YM97)G961&:6QE<RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YM97)G
M961&:6QE<R`](&%R<F%Y7W)E=F5R<V4H)'1H:7,M/FUE<F=E9$9I;&5S*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!D
M;T9I;&53;W)T*"8D9FEL94QI<W0L("1H;W<@/2!60U]33U)47TY/3D4L("1D
M:7(@/2!60U]33U)47T%30T5.1$E.1RD*("`@('L*("`@("`@("!S=VET8V@@
M*"1H;W<I('L*("`@("`@("!C87-E(%9#7U-/4E1?04=%.@H@("`@("`@("`@
M("!U<V]R="@D9FEL94QI<W0L(&%R<F%Y*"1T:&ES+"`G9FEL94%G95-O<G0G
M*2D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%9#7U-/4E1?
M3D%-13H*("`@("`@("`@("`@=7-O<G0H)&9I;&5,:7-T+"!A<G)A>2@D=&AI
M<RP@)V9I;&5.86UE4V]R="<I*3L*("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@(&-A<V4@5D-?4T]25%]!551(3U(Z"B`@("`@("`@("`@('5S;W)T*"1F
M:6QE3&ES="P@87)R87DH)'1H:7,L("=F:6QE075T:&]R4V]R="<I*3L*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@5D-?4T]25%]2158Z"B`@
M("`@("`@("`@('5S;W)T*"1F:6QE3&ES="P@87)R87DH)'1H:7,L("=F:6QE
M4F5V4V]R="<I*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@
M5D-?4T]25%].3TY%.@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-O<G0@9G5N
M8W1I;VX@9F]R(&%S8V5N9&EN9R!A9V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&9I;&5!9V53;W)T*"1A+"`D8BD*("`@('L*("`@("`@("`D86$@/2`D82T^
M<75E<GE,87-T3&]G*"D["B`@("`@("`@)&)B(#T@)&(M/G%U97)Y3&%S=$QO
M9R@I.PH@("`@("`@(&EF("@D86$M/G%U97)Y1&%T92@I(#T]("1B8BT^<75E
M<GE$871E*"DI('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N("@D86$M/G%U97)Y1&%T92@I(#P@
M)&)B+3YQ=65R>41A=&4H*2D@/R`Q(#H@+3$["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@4V]R="!F=6YC=&EO;B!B>2!A=71H;W(@;F%M92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9FEL94%U=&AO<E-O<G0H)&$L("1B*0H@
M("`@>PH@("`@("`@("1A82`]("1A+3YQ=65R>4QA<W1,;V<H*3L*("`@("`@
M("`D8F(@/2`D8BT^<75E<GE,87-T3&]G*"D["B`@("`@("`@:68@*"1A82T^
M<75E<GE!=71H;W(H*2`]/2`D8F(M/G%U97)Y075T:&]R*"DI('L*("`@("`@
M("`@("`@<F5T=7)N(#`["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N("@D86$M/G%U97)Y075T:&]R*"D@/B`D8F(M/G%U97)Y075T:&]R
M*"DI(#\@,2`Z("TQ.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%-O<G0@9G5N8W1I;VX@9F]R(&%S8V5N9&EN9R!F:6QE;F%M92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9FEL94YA;653;W)T*"1A+"`D8BD*("`@('L*("`@
M("`@("!R971U<FX@<W1R8V%S96-M<"@D82T^;F%M92P@)&(M/FYA;64I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V]R="!F=6YC=&EO;B!F;W(@87-C96YD
M:6YG(')E=FES:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!F:6QE4F5V4V]R
M="@D82P@)&(I"B`@("!["B`@("`@("`@<F5T=7)N(%9#7U)E=FES:6]N.CIC
M;7`H)&$M/G%U97)Y2&5A9"@I+"`D8BT^<75E<GE(96%D*"DI.PH@("`@?0H*
M?0H*+RHJ"B`J(%9#7W-V;B!F:6QE(&-L87-S+@H@*@H@*B!#;W!Y<FEG:'0@
M06YI;"!-861H879A<&5D9'DL(#QA;FEL0')E8V]I;"YO<F<^"B`J"B`J($!A
M=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J
M($!P86-K86=E(%9#"B`J+PIC;&%S<R!60U]&:6QE7W-V;B!E>'1E;F1S(%9#
M7T9I;&4@>PH*("`@("\J*@H@("`@("H@0W)E871E(&$@<F5P;W-I=&]R>2!F
M:6QE(&]B:F5C="P@86YD(&=I=F4@:70@:6YF;W)M871I;VX@86)O=70*("`@
M("`J('=H870@:71S('!A<F5N="!D:7)E8W1O<GD@86YD(')E<&]S:71O<GD@
M;V)J96-T<R!A<F4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FP@
M($9U;&P@<&%T:"!T;R!T:&ES(&9I;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%9#7T9I;&5?<W9N*"1R97`L("1F;"P@)'%U:6-K;&]G(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@)'1H:7,M/G)E<"`]("1R97`["B`@("`@("`@)'1H:7,M
M/FYA;64@/2!B87-E;F%M92@D9FPI.PH@("`@("`@("1T:&ES+3YD:7(@/2!D
M:7)N86UE*"1F;"D["B`@("`@("`@)'1H:7,M/FQO9W,@/2!A<G)A>2@I.PH@
M("`@("`@("1T:&ES+3YQ=6EC:VQO9R`]("1Q=6EC:VQO9SL*("`@("`@("`D
M=&AI<RT^<F5V<R`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/G)E=G-Y;2`]
M(&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/G-Y;7)E=B`](&%R<F%Y*"D["B`@
M("`@("`@)'1H:7,M/F)R86YC:&5S(#T@87)R87DH*3L*("`@('T*"B`@("!F
M=6YC=&EO;B`F9V5T1FEL94]B:F5C="@D<F5P+"`D9FEL96YA;64L("1C86-H
M92`](&YU;&PL("1Q=6EC:VQO9R`](&9A;'-E*0H@("`@>PH@("`@("`@("\J
M(%1H92!V97)S:6]N(&]F('1H92!C86-H960@9&%T82X@26YC<F5M96YT('1H
M:7,@=VAE;F5V97(@=&AE"B`@("`@("`@("H@:6YT97)N86P@<W1O<F%G92!F
M;W)M870@8VAA;F=E<RP@<W5C:"!T:&%T('=E(&UU<W0*("`@("`@("`@*B!I
M;G9A;&ED871E('!R:6]R(&-A8VAE9"!D871A+B`J+PH@("`@("`@("1C86-H
M959E<G-I;VX@/2`R.PH@("`@("`@("1C86-H94ED(#T@)')E<"T^<V]U<F-E
M<F]O="@I("X@)U]N)R`N("1F:6QE;F%M92`N("=?9B<@+B`H:6YT*21Q=6EC
M:VQO9R`N("=?=B<@+B`D8V%C:&5697)S:6]N.PH*("`@("`@("!I9B`H)&-A
M8VAE("8F"B`@("`@("`@("`@("\O(%1H92!F:6QE(&ES(&-A8VAE9"!F;W(@
M;VYE(&AO=7(@;F\@;6%T=&5R('=H870L(&)E8V%U<V4*("`@("`@("`@("`@
M+R\@=&AE<F4@:7,@;F\@=V%Y('1O(&1E=&5R;6EN92!W:71H(%-U8G9E<G-I
M;VX@=&AE('1I;64*("`@("`@("`@("`@+R\@=&AE(&9I;&4@;&%S="!C:&%N
M9V5D+@H@("`@("`@("`@("`D8V%C:&4M/F5X:7-T<R@D8V%C:&5)9"P@,S8P
M,"DI('L*("`@("`@("`@("`@)&9I;&5/8B`]('5N<V5R:6%L:7IE*"1C86-H
M92T^9V5T*"1C86-H94ED+"`S-C`P*2D["B`@("`@("`@("`@("1F:6QE3V(M
M/G-E=%)E<&]S:71O<GDH)')E<"D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&9I;&5/8B`](&YE=R!60U]&:6QE7W-V;B@D<F5P+"`D9FEL96YA
M;64L("1Q=6EC:VQO9RD["B`@("`@("`@("`@("1F:6QE3V(M/G-E=%)E<&]S
M:71O<GDH)')E<"D["B`@("`@("`@("`@(&EF("AI<U]A*"@D<F5S=6QT(#T@
M)&9I;&5/8BT^9V5T0G)O=W-E26YF;R@I*2P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&9I;&5/8BT^87!P;'E3;W)T*%9#7U-/4E1?04=%*3L*
M"B`@("`@("`@("`@(&EF("@D8V%C:&4I('L*("`@("`@("`@("`@("`@("1C
M86-H92T^<V5T*"1C86-H94ED+"!S97)I86QI>F4H)&9I;&5/8BDI.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&9I;&5/8CL*
M("`@('T*"B`@("`O*BH*("`@("`J($EF('1H:7,@9FEL92!I<R!P<F5S96YT
M(&EN(&%N($%T=&EC(&1I<F5C=&]R>2P@=&AI<R!I;F1I8V%T97,*("`@("`J
M(&ET+@H@("`@("H*("`@("`J($!R971U<FX@=')U92!I9B!F:6QE(&ES(&EN
M('1H92!!='1I8RP@86YD(&9A;'-E(&]T:&5R=VES90H@("`@("HO"B`@("!F
M=6YC=&EO;B!I<T%T=&EC1FEL92@I"B`@("!["B`@("`@("`@+R\@3F]T(&EM
M<&QE;65N=&5D('EE=`H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&YA;64@;V8@=&AE(&-U<G)E;G0@
M9FEL92!A<R!I;B!T:&4@<F5P;W-I=&]R>0H@("`@("H*("`@("`J($!R971U
M<FX@1FEL96YA;64@*'=I=&AO=70@=&AE('!A=&@I"B`@("`@*B\*("`@(&9U
M;F-T:6]N('%U97)Y4F5P;W-I=&]R>4YA;64H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^;F%M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@;F%M92!O9B!T:&4@8W5R<F5N="!F:6QE('=I=&AO=70@=&AE(')E<&]S
M:71O<GD*("`@("`J(&5X=&5N<VEO;G,@*'5S=6%L;'D@+'8I"B`@("`@*@H@
M("`@("H@0')E='5R;B!&:6QE;F%M92!W:71H;W5T(')E<&]S:71O<GD@97AT
M96YS:6]N"B`@("`@*B\*("`@(&9U;F-T:6]N('%U97)Y3F%M92@I"B`@("![
M"B`@("`@("!R971U<FX@<')E9U]R97!L86-E*"<O+'8D+R<L("<G+"`D=&AI
M<RT^;F%M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&QA
M<W0@<F5V:7-I;VX@;V8@=&AE(&-U<G)E;G0@9FEL92!O;B!T:&4@2$5!1"!B
M<F%N8V@*("`@("`J"B`@("`@*B!`<F5T=7)N($QA<W0@<F5V:7-I;VX@;V8@
M=&AE(&-U<G)E;G0@9FEL90H@("`@("HO"B`@("!F=6YC=&EO;B!Q=65R>5)E
M=FES:6]N*"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YR979S
M6S!=*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G
M3F\@<F5V:7-I;VYS)RD["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI
M<RT^<F5V<ULP73L*("`@('T*"B`@("!F=6YC=&EO;B!Q=65R>5!R979I;W5S
M4F5V:7-I;VXH)')E=BD*("`@('L*("`@("`@("`D;&%S="`](&9A;'-E.PH@
M("`@("`@(&9O<F5A8V@@*"1T:&ES+3YR979S(&%S("1E;G1R>2D@>PH@("`@
M("`@("`@("!I9B`H)&QA<W0I"B`@("`@("`@("`@("`@("!R971U<FX@)&5N
M=')Y.PH@("`@("`@("`@("!I9B`H)&5N=')Y(#T]("1R978I"B`@("`@("`@
M("`@("`@("`D;&%S="`]('1R=64["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE($A%
M040@*&UO<W0@<F5C96YT*2!R979I<VEO;B!N=6UB97(@9F]R('1H:7,@9FEL
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N($A%040@<F5V:7-I;VX@;G5M8F5R
M"B`@("`@*B\*("`@(&9U;F-T:6]N('%U97)Y2&5A9"@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3YQ=65R>5)E=FES:6]N*"D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FX@=&AE(&QA<W0@5D-?3&]G(&]B:F5C="!I;B!T
M:&4@9FEL92X*("`@("`J"B`@("`@*B!`<F5T=7)N(%9#7TQO9R!O9B!T:&4@
M;&%S="!E;G1R>2!I;B!T:&4@9FEL90H@("`@("HO"B`@("!F=6YC=&EO;B!Q
M=65R>4QA<W1,;V<H*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/G)E=G-;,%TI('Q\("%I<W-E="@D=&AI<RT^;&]G<ULD=&AI<RT^<F5V<ULP
M75TI*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=.
M;R!R979I<VEO;G,G*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES
M+3YL;V=S6R1T:&ES+3YR979S6S!=73L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-O<G0@=&AE(&QI<W0@;V8@5D-?3&]G(&]B:F5C=',@=&AA="!T:&ES(&9I
M;&4@8V]N=&%I;G,N"B`@("`@*@H@("`@("H@0'!A<F%M(&AO=R!60U]33U)4
M7U)%5B`H<V]R="!B>2!R979I<VEO;BDL"B`@("`@*B`@("`@("`@("`@(%9#
M7U-/4E1?3D%-12`H<V]R="!B>2!A=71H;W(@;F%M92DL"B`@("`@*B`@("`@
M("`@("`@(%9#7U-/4E1?04=%("AS;W)T(&)Y(&-O;6UI="!D871E*0H@("`@
M("HO"B`@("!F=6YC=&EO;B!A<'!L>5-O<G0H)&AO=R`](%9#7U-/4E1?4D56
M*0H@("`@>PH@("`@("`@('-W:71C:"`H)&AO=RD@>PH@("`@("`@(&-A<V4@
M5D-?4T]25%]2158Z"B`@("`@("`@("`@("1F=6YC(#T@)U)E=FES:6]N)SL*
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S92!60U]33U)47TY!344Z
M"B`@("`@("`@("`@("1F=6YC(#T@)TYA;64G.PH@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("!C87-E(%9#7U-/4E1?04=%.@H@("`@("`@("`@("`D9G5N
M8R`]("=!9V4G.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!D969A=6QT
M.@H@("`@("`@("`@("`D9G5N8R`]("=2979I<VEO;B<["B`@("`@("`@?0H@
M("`@("`@('5A<V]R="@D=&AI<RT^;&]G<RP@87)R87DH)'1H:7,L(")S;W)T
M0GDD9G5N8R(I*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%1H92!S;W)T0GDJ*"D@9G5N8W1I;VYS(&%R92!I;G1E<FYA
M;&QY('5S960@8GD@87!P;'E3;W)T+@H@("`@("HO"B`@("!F=6YC=&EO;B!S
M;W)T0GE2979I<VEO;B@D82P@)&(I"B`@("!["B`@("`@("`@<F5T=7)N(%9#
M7U)E=FES:6]N.CIC;7`H)&(M/G)E=BP@)&$M/G)E=BD["B`@("!]"@H@("`@
M9G5N8W1I;VX@<V]R=$)Y06=E*"1A+"`D8BD*("`@('L*("`@("`@("!R971U
M<FX@)&(M/F1A=&4@+2`D82T^9&%T93L*("`@('T*"B`@("!F=6YC=&EO;B!S
M;W)T0GE.86UE*"1A+"`D8BD*("`@('L*("`@("`@("!R971U<FX@<W1R8VUP
M*"1A+3YA=71H;W(L("1B+3YA=71H;W(I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4&]P=6QA=&4@=&AE(&]B:F5C="!W:71H(&EN9F]R;6%T:6]N(&%B;W5T
M('1H92!R979I<VEO;G,@;&]G<PH@("`@("H@86YD(&1A=&5S(&]F('1H92!F
M:6QE+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@8F]O;&5A;B`@("`@
M("`@("`@(%1R=64@;VX@<W5C8V5S<RP*("`@("`J("`@("`@("`@("`@("`@
M4$5!4E]%<G)O<B`@("`@("`@($]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971"<F]W<V5);F9O*"D*("`@('L*("`@("`@("`O*B!4:&ES(&1O
M97-N)W0@=V]R:SL@;F5E9"!T;R!F:6YD(&%N;W1H97(@=V%Y('1O('-I;7!L
M>0H@("`@("`@("`J(')E<75E<W0@=&AE(&UO<W0@<F5C96YT(')E=FES:6]N
M.@H@("`@("`@("`J"B`@("`@("`@("H@)&9L86<@/2`D=&AI<RT^<75I8VML
M;V<@/R`G+7(@2$5!1"`G(#H@)R<[("HO"B`@("`@("`@)&9L86<@/2`G)SL*
M("`@("`@("`D42`](%9#7U=)3D1/5U,@/R`G(B<@.B`B)R(["B`@("`@("`@
M)&-M9"`]("1T:&ES+3YR97`M/F=E=%!A=&@H)W-V;B<I("X@)R!L;V<@+78@
M)R`N("1F;&%G("X@)%$@+B!S=')?<F5P;&%C92@D42P@)UQ<)R`N("11+"`D
M=&AI<RT^<75E<GE&=6QL4&%T:"@I*2`N("11("X@)R`R/B8Q)SL*("`@("`@
M("`D<&EP92`]('!O<&5N*"1C;60L("=R)RD["B`@("`@("`@:68@*"$D<&EP
M92D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1F%I
M;&5D('1O(&5X96-U=&4@<W9N(&QO9SH@)R`N("1C;60I.PH@("`@("`@('T*
M"B`@("`@("`@9F=E=',H)'!I<&4I.PH@("`@("`@('=H:6QE("@A9F5O9B@D
M<&EP92DI('L*("`@("`@("`@("`@)&QO9R`](&YE=R!60U],;V=?<W9N*"1T
M:&ES+3YR97`L("1T:&ES*3L*("`@("`@("`@("`@)&5R<B`]("1L;V<M/G!R
M;V-E<W-,;V<H)'!I<&4I.PH@("`@("`@("`@("!I9B`H)&5R<BD@>PH@("`@
M("`@("`@("`@("`@)')E=B`]("1L;V<M/G%U97)Y4F5V:7-I;VXH*3L*("`@
M("`@("`@("`@("`@("1T:&ES+3YL;V=S6R1R979=(#T@)&QO9SL*("`@("`@
M("`@("`@("`@("1T:&ES+3YR979S6UT@/2`D<F5V.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!I9B`H)'1H:7,M/G%U:6-K;&]G*2!["B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<&-L;W-E*"1P:7!E*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@9G5L;'D@<75A;&EF:65D(&9I
M;&5N86UE(&]F('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@
M1G5L;'D@<75A;&EF:65D(&9I;&5N86UE(&]F('1H:7,@;V)J96-T"B`@("`@
M*B\*("`@(&9U;F-T:6]N('%U97)Y1G5L;%!A=&@H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^<F5P+3YS;W5R8V5R;V]T*"D@+B`G+R<@+B`D=&AI
M<RT^<75E<GE-;V1U;&50871H*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FX@=&AE(&YA;64@;V8@=&AI<R!F:6QE(')E;&%T:79E('1O(&ET<R!S
M;W5R8V5R;V]T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!0871H
M;F%M92!R96QA=&EV92!T;R!T:&4@<V]U<F-E<F]O="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<75E<GE-;V1U;&50871H*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/F1I<B`N("<O)R`N("1T:&ES+3YN86UE.PH@("`@?0H*?0H*
M+RHJ"B`J(%9#7W-V;B!L;V<@8VQA<W,N"B`J"B`J($%N:6P@36%D:&%V87!E
M9&1Y+"`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!`875T:&]R("!!;FEL($UA
M9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`<&%C:V%G92!60PH@
M*B\*8VQA<W,@5D-?3&]G7W-V;B!["@H@("`@=F%R("1R97`["B`@("!V87(@
M)&5R<CL*("`@('9A<B`D9FEL93L*("`@('9A<B`D9FEL97,["B`@("!V87(@
M)'1A9W,["B`@("!V87(@)')E=CL*("`@('9A<B`D9&%T93L*("`@('9A<B`D
M;&]G.PH@("`@=F%R("1A=71H;W(["B`@("!V87(@)'-T871E.PH@("`@=F%R
M("1L:6YE<SL*("`@('9A<B`D8G)A;F-H97,["@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@5D-?3&]G7W-V;B@D
M<F5P+"`D9FPI"B`@("!["B`@("`@("`@)'1H:7,M/G)E<"`]("1R97`["B`@
M("`@("`@)'1H:7,M/F9I;&4@/2`D9FP["B`@("`@("`@)'1H:7,M/F)R86YC
M:&5S(#T@87)R87DH*3L*("`@('T*"B`@("!F=6YC=&EO;B!P<F]C97-S3&]G
M*"1P:7!E*0H@("`@>PH@("`@("`@("1L:6YE(#T@9F=E=',H)'!I<&4I.PH*
M("`@("`@("!I9B`H9F5O9B@D<&EP92DI('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>
M<BA;,"TY72HI(%Q\("@N*C\I(%Q\("@N*BD@7"@N*EPI(%Q\("A;,"TY72HI
M(&QI;F5S/R0O)RP@)&QI;F4L("1M871C:&5S*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^<F5V(#T@)&UA=&-H97-;,5T["B`@("`@("`@("`@("1T:&ES+3YA
M=71H;W(@/2`D;6%T8VAE<ULR73L*("`@("`@("`@("`@)'1H:7,M/F1A=&4@
M/2!S=')T;W1I;64H)&UA=&-H97-;,UTI.PH@("`@("`@("`@("`D<VEZ92`]
M("1M871C:&5S6S1=.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T
M:&ES+3YE<G(@/2`D;&EN93L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@9F=E=',H)'!I<&4I.PH*("`@("`@("`D=&AI
M<RT^9FEL97,@/2!A<G)A>2@I.PH@("`@("`@('=H:6QE("@H)&QI;F4@/2!T
M<FEM*&9G971S*"1P:7!E*2DI("$]("<G*2!["B`@("`@("`@("`@("1T:&ES
M+3YF:6QE<UM=(#T@)&QI;F4["B`@("`@("`@?0H*("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@(3T@)'-I>F4[("LK)&DI('L*("`@("`@("`@("`@)'1H:7,M
M/FQO9R`]("1T:&ES+3YL;V<@+B!C:&]P*&9G971S*"1P:7!E*2D@+B`B7&XB
M.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/FQO9R`](&-H;W`H)'1H:7,M
M/FQO9RD["B`@("`@("`@9F=E=',H)'!I<&4I.PH*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!Q=65R>41A=&4H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^9&%T93L*("`@('T*"B`@("!F=6YC=&EO
M;B!Q=65R>5)E=FES:6]N*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/G)E=CL*("`@('T*"B`@("!F=6YC=&EO;B!Q=65R>4%U=&AO<B@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YA=71H;W(["B`@("!]"@H@("`@9G5N
M8W1I;VX@<75E<GE,;V<H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M;&]G.PH@("`@?0H*("`@(&9U;F-T:6]N('%U97)Y0VAA;F=E9$QI;F5S*"D*
M("`@('L*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/FQI;F5S*2`_("@D
M=&AI<RT^;&EN97,I(#H@)R<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!':79E
M;B!A(&)R86YC:"!R979I<VEO;B!N=6UB97(L('1H:7,@9G5N8W1I;VX@<F5M
M87!S(&ET"B`@("`@*B!A8V-O<F1I;F=L>2P@86YD('!E<F9O<FUS(&$@;&]O
M:W5P(&]N('1H92!F:6QE(&]B:F5C="!T;PH@("`@("H@<F5T=7)N('1H92!S
M>6UB;VQI8R!N86UE*',I(&]F('1H870@8G)A;F-H(&EN('1H92!T<F5E+@H@
M("`@("H*("`@("`J($!R971U<FX@:&%S:"!O9B!S>6UB;VQI8R!N86UE<R`]
M/B!B<F%N8V@@;G5M8F5R<PH@("`@("HO"B`@("!F=6YC=&EO;B!Q=65R>5-Y
M;6)O;&EC0G)A;F-H97,H*0H@("`@>PH@("`@("`@("1S>6U"<F%N8VAE<R`]
M(&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/F)R86YC:&5S(&%S
M("1B<F%N8V@I('L*("`@("`@("`@("`@)'!A<G1S(#T@97AP;&]D92@G+B<L
M("1B<F%N8V@I.PH@("`@("`@("`@("`D;&%S="`](&%R<F%Y7W!O<"@D<&%R
M=',I.PH@("`@("`@("`@("`D<&%R='-;72`]("<P)SL*("`@("`@("`@("`@
M)'!A<G1S6UT@/2`D;&%S=#L*("`@("`@("`@("`@)')E=B`](&EM<&QO9&4H
M)RXG+"`D<&%R=',I.PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/F9I
M;&4M/F)R86YC:&5S6R1B<F%N8VA=*2D@>PH@("`@("`@("`@("`@("`@)'-Y
M;4)R86YC:&5S6R1T:&ES+3YF:6QE+3YB<F%N8VAE<ULD8G)A;F-H75T@/2`D
M8G)A;F-H.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D<WEM0G)A;F-H97,["B`@("!]"@I]"@HO*BH*("H@5D-?<W9N(%!A=&-H
M<V5T(&-L87-S+@H@*@H@*B!#;W!Y<FEG:'0@06YI;"!-861H879A<&5D9'DL
M(#QA;FEL0')E8V]I;"YO<F<^"B`J"B`J($!A=71H;W(@($%N:6P@36%D:&%V
M87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!P86-K86=E(%9#"B`J+PIC
M;&%S<R!60U]0871C:'-E=%]S=FX@97AT96YD<R!60U]0871C:'-E="!["@H@
M("`@=F%R("1?9FEL93L*"B`@("`O*BH*("`@("`J($-R96%T92!A('!A=&-H
M<V5T(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE
M("!4:&4@9FEL96YA;64@=&\@9V5T('!A=&-H<V5T<R!F;W(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%9#7U!A=&-H<V5T7W-V;B@D9FEL92D*("`@('L*("`@
M("`@("`D=&AI<RT^7V9I;&4@/2`D9FEL93L*("`@('T*"B`@("!F=6YC=&EO
M;B`F9V5T4&%T8VAS971/8FIE8W0H)')E<"P@)&9I;&5N86UE+"`D8V%C:&4@
M/2!N=6QL*0H@("`@>PH@("`@("`@("\J(%1H92!V97)S:6]N(&]F('1H92!C
M86-H960@9&%T82X@26YC<F5M96YT('1H:7,@=VAE;F5V97(@=&AE"B`@("`@
M("`@("H@:6YT97)N86P@<W1O<F%G92!F;W)M870@8VAA;F=E<RP@<W5C:"!T
M:&%T('=E(&UU<W0*("`@("`@("`@*B!I;G9A;&ED871E('!R:6]R(&-A8VAE
M9"!D871A+B`J+PH@("`@("`@("1C86-H959E<G-I;VX@/2`Q.PH@("`@("`@
M("1C86-H94ED(#T@)')E<"T^<V]U<F-E<F]O="@I("X@)U]N)R`N("1F:6QE
M;F%M92`N("=?9E]V)R`N("1C86-H959E<G-I;VX["@H@("`@("`@(&EF("@D
M8V%C:&4@)B8*("`@("`@("`@("`@+R\@5&AE(&9I;&4@:7,@8V%C:&5D(&9O
M<B!O;F4@:&]U<B!N;R!M871T97(@=VAA="P@8F5C875S90H@("`@("`@("`@
M("`O+R!T:&5R92!I<R!N;R!W87D@=&\@9&5T97)M:6YE('=I=&@@<W9N('1H
M92!T:6UE('1H92!F:6QE"B`@("`@("`@("`@("\O(&QA<W0@8VAA;F=E9"X*
M("`@("`@("`@("`@)&-A8VAE+3YE>&ES=',H)&-A8VAE260L(#,V,#`I*2![
M"B`@("`@("`@("`@("1P<T]B(#T@=6YS97)I86QI>F4H)&-A8VAE+3YG970H
M)&-A8VAE260L(#,V,#`I*3L*("`@("`@("`@("`@)'!S3V(M/G-E=%)E<&]S
M:71O<GDH)')E<"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'!S
M3V(@/2!N97<@5D-?4&%T8VAS971?<W9N*"1F:6QE;F%M92D["B`@("`@("`@
M("`@("1P<T]B+3YS971297!O<VET;W)Y*"1R97`I.PH@("`@("`@("`@("!I
M9B`H:7-?82@H)')E<W5L="`]("1P<T]B+3YG9710871C:'-E=',H*2DL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&-A8VAE*2!["B`@
M("`@("`@("`@("`@("`D8V%C:&4M/G-E="@D8V%C:&5)9"P@<V5R:6%L:7IE
M*"1P<T]B*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D<'-/8CL*("`@('T*"B`@("`O*BH*("`@("`J(%!O<'5L871E('1H
M92!O8FIE8W0@=VET:"!I;F9O<FUA=&EO;B!A8F]U="!T:&4@<&%T8VAS971S
M('1H870*("`@("`J('1H:7,@9FEL92!I<R!I;G9O;'9E9"!I;BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!014%27T5R<F]R(&]B:F5C="!O;B!E
M<G)O<BP@;W(@=')U92!O;B!S=6-C97-S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G9710871C:'-E=',H*0H@("`@>PH@("`@("`@("1F:6QE3V(@/2!N97<@
M5D-?1FEL95]S=FXH)'1H:7,M/E]R97`L("1T:&ES+3Y?9FEL92D["B`@("`@
M("`@:68@*&ES7V$H*"1R97-U;'0@/2`D9FEL94]B+3YG971"<F]W<V5);F9O
M*"DI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]P871C:'-E=',@/2!A
M<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1F:6QE3V(M/FQO9W,@87,@)')E
M=B`]/B`D;&]G*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%T8VAS971S6R1R
M979=(#T@87)R87DH*3L*("`@("`@("`@("`@)'1H:7,M/E]P871C:'-E='-;
M)')E=EU;)V1A=&4G72`]("1L;V<M/G%U97)Y1&%T92@I.PH@("`@("`@("`@
M("`D=&AI<RT^7W!A=&-H<V5T<ULD<F5V75LG875T:&]R)UT@/2`D;&]G+3YQ
M=65R>4%U=&AO<B@I.PH@("`@("`@("`@("`D=&AI<RT^7W!A=&-H<V5T<ULD
M<F5V75LG8G)A;F-H)UT@/2`G)SL*("`@("`@("`@("`@)'1H:7,M/E]P871C
M:'-E='-;)')E=EU;)W1A9R==(#T@)R<["B`@("`@("`@("`@("1T:&ES+3Y?
M<&%T8VAS971S6R1R979=6R=L;V<G72`]("1L;V<M/G%U97)Y3&]G*"D["B`@
M("`@("`@("`@("1T:&ES+3Y?<&%T8VAS971S6R1R979=6R=M96UB97)S)UT@
M/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D;&]G+3YF:6QE<R!A
M<R`D9FEL92D@>PH@("`@("`@("`@("`@("`@)&%C=&EO;B`]('-U8G-T<B@D
M9FEL92P@,"P@,2D["B`@("`@("`@("`@("`@("`D9FEL92`]('!R96=?<F5P
M;&%C92@G+RXJ/UQS*"XJ/RDH7'-\)"DN*B\G+"`G7%PQ)RP@)&9I;&4I.PH@
M("`@("`@("`@("`@("`@)'1O(#T@)')E=CL*("`@("`@("`@("`@("`@(&EF
M("@D86-T:6]N(#T]("=!)RD@>PH@("`@("`@("`@("`@("`@("`@("1F<F]M
M(#T@)TE.251)04PG.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1A8W1I
M;VX@/3T@)T0G*2!["B`@("`@("`@("`@("`@("`@("`@)&9R;VT@/2`D=&\[
M"B`@("`@("`@("`@("`@("`@("`@)'1O(#T@)RA$14%$*2<["B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("\O(%1H:7,@
M=&5C:&YI8V%L;'D@:7-N)W0@=&AE('!R979I;W5S(')E=FES:6]N+`H@("`@
M("`@("`@("`@("`@("`@("\O(&)U="!I="!W;W)K<R!F;W(@9&EF9FEN9R!P
M=7)P;W-E<RX*("`@("`@("`@("`@("`@("`@("`D9G)O;2`]("1T;R`M(#$[
M"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M871C:'-E='-;)')E=EU;)VUE;6)E<G,G75M=(#T@87)R87DH)V9I;&4G(#T^
M("1F:6QE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V9R;VTG(#T^("1F<F]M+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W1O)R`]/B`D=&\I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]60RYP:'``````````````````````````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,S0U,#<`,3`U,34T,S,W-3(`,#(P-3$V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B!3;W)T:6YG(&]P=&EO;G,*("HO"F1E9FEN92@G5D-?4T]25%].3TY%)RP@
M,"D[("`@("`@("`O+R!D;VXG="!S;W)T"F1E9FEN92@G5D-?4T]25%]!1T4G
M+"`Q*3L@("`@("`@("`O+R!S;W)T(&)Y(&%G90ID969I;F4H)U9#7U-/4E1?
M3D%-12<L(#(I.R`@("`@("`@+R\@<V]R="!B>2!F:6QE;F%M90ID969I;F4H
M)U9#7U-/4E1?4D56)RP@,RD[("`@("`@("`@+R\@<V]R="!B>2!R979I<VEO
M;B!N=6UB97(*9&5F:6YE*"=60U]33U)47T%55$A/4B<L(#0I.R`@("`@("\O
M('-O<G0@8GD@875T:&]R(&YA;64*"F1E9FEN92@G5D-?4T]25%]!4T-%3D1)
M3D<G+"`P*3L@("`O+R!A<V-E;F1I;F<@;W)D97(*9&5F:6YE*"=60U]33U)4
M7T1%4T-%3D1)3D<G+"`Q*3L@("\O(&1E<V-E;F1I;F<@;W)D97(*"F1E9FEN
M92@G5D-?5TE.1$]74R<L('-U8G-T<BA02%!?3U,L(#`L(#,I(#T]("=724XG
M*3L*"B\J*@H@*B!697)S:6]N($-O;G1R;VP@9V5N97)A;&EZ960@;&EB<F%R
M>2X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5D,O5D,N<&AP+'8@,2XQ,BXX
M+C$R(#(P,#8O,#4O,S$@,3<Z,#8Z,S<@<V5L<VMY($5X<"`D"B`J"B`J($!P
M86-K86=E(%9#"B`J+PIC;&%S<R!60R!["@H@("`@+RHJ"B`@("`@*B!4:&4@
M<V]U<F-E(')O;W0@;V8@=&AE(')E<&]S:71O<GDN"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<F]T96-T960*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7W-O=7)C97)O;W0["@H@("`@+RHJ"B`@("`@*B!(87-H('=I
M=&@@=&AE(&QO8V%T:6]N<R!O9B!A;&P@;F5C97-S87)Y(&)I;F%R:65S+@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P871H<R`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!(87-H(&-A8VAI;F<@=&AE('!A<G-E
M9"!U<V5R<R!F:6QE+@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)%]U<V5R<SL*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@<V]U<F-E
M(')O;W0@9F]R('1H:7,@<F5P;W-I=&]R>2P@=VET:"!N;R!T<F%I;&EN9R`O
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%-O=7)C92!R;V]T(&9O
M<B!T:&ES(')E<&]S:71O<GDN"B`@("`@*B\*("`@(&9U;F-T:6]N('-O=7)C
M97)O;W0H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W-O=7)C97)O
M;W0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!L;V-A=&EO
M;B!O9B!T:&4@<W!E8VEF:65D(&)I;F%R>2X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1B:6YA<GD@($%N(&5X=&5R;F%L('!R;V=R86T@;F%M92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86Y\<W1R:6YG("!4:&4@;&]C
M871I;VX@;V8@=&AE(&5X=&5R;F%L('!R;V=R86T@;W(@9F%L<V4@:68*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@(&ET('=A<VXG="!S<&5C:69I
M960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A=&@H)&)I;F%R>2D*("`@
M('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P871H<ULD8FEN87)Y72DI
M('L*("`@("`@("`@("`@:68@*%9#7U=)3D1/5U,I('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7W!A=&AS6R1B:6YA<GE=.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&ES7V5X96-U=&%B
M;&4H)'1H:7,M/E]P871H<ULD8FEN87)Y72D@/R`D=&AI<RT^7W!A=&AS6R1B
M:6YA<GE=(#H@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%!A<G-E
M('1H92!U<V5R<R!F:6QE+"!I9B!P<F5S96YT(&EN('1H92!S;W5R8V4@<F]O
M="P@86YD(')E='5R;@H@("`@("H@82!H87-H(&-O;G1A:6YI;F<@=&AE(')E
M<75I<VET92!I;F9O<FUA=&EO;BP@:V5Y960@;VX@=&AE"B`@("`@*B!U<V5R
M;F%M92P@86YD('=I=&@@=&AE("=D97-C)RPG;F%M92<L(&%N9"`G;6%I;"<@
M=F%L=65S(&EN<VED92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86Y\
M87)R87D@($9A;'-E(&EF('1H92!F:6QE(&ES(&YO="!P<F5S96YT+"!O=&AE
M<G=I<V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]U
M<V5R<R!P;W!U;&%T960@=VET:"!T:&4@9&%T80H@("`@("HO"B`@("!F=6YC
M=&EO;B!G9715<V5R<R@D=7-E<G-F:6QE*0H@("`@>PH@("`@("`@("\J($-H
M96-K('1H870@=V4@:&%V96XG="!A;')E861Y('!A<G-E9"!U<V5R<RX@*B\*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]U<V5R<RD@)B8@:7-?87)R87DH
M)'1H:7,M/E]U<V5R<RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M=7-E<G,["B`@("`@("`@?0H*("`@("`@("!I9B`H(4!I<U]F:6QE*"1U<V5R
M<V9I;&4I('Q\("$H)&9L(#T@0&9O<&5N*"1U<V5R<V9I;&4L(%9#7U=)3D1/
M5U,@/R`G<F(G(#H@)W(G*2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]U<V5R<R`](&%R<F%Y*"D[
M"@H@("`@("`@("\J($1I<V-A<F0@=&AE(&9I<G-T(&QI;F4L('-I;F-E(&ET
M)VQL(&)E('1H92!H96%D97(@:6YF;RX@*B\*("`@("`@("!F9V5T<R@D9FPL
M(#0P.38I.PH*("`@("`@("`O*B!087)S92!T:&4@<F5S="!O9B!T:&4@;&EN
M97,@:6YT;R!A(&AA<V@L(&ME>65D(&]N"B`@("`@("`@("H@=7-E<FYA;64N
M("HO"B`@("`@("`@=VAI;&4@*"1L:6YE(#T@9F=E=',H)&9L+"`T,#DV*2D@
M>PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UY<<RHD+R<L("1L:6YE
M*2D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"<O7BA<=RLI7',K*"XK*5QS
M*RA;7'=<+EPM7%]=*T!;7'=<+EPM7%]=*RE<<RLH+BHI)"\G+"`D;&EN92P@
M)')E9W,I*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]U<V5R<ULD<F5G<ULQ75U;)VYA
M;64G72`]('1R:6TH)')E9W-;,ETI.PH@("`@("`@("`@("`D=&AI<RT^7W5S
M97)S6R1R96=S6S%=75LG;6%I;"==(#T@=')I;2@D<F5G<ULS72D["B`@("`@
M("`@("`@("1T:&ES+3Y?=7-E<G-;)')E9W-;,5U=6R=D97-C)UT@/2!T<FEM
M*"1R96=S6S1=*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^
M7W5S97)S.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T
M=7)N(&$@8V]N8W)E=&4@5D,@:6YS=&%N8V4@8F%S960@;VX@)&1R:79E<BX*
M("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1R:79E<B`@5&AE('1Y<&4@
M;V8@8V]N8W)E=&4@5D,@<W5B8VQA<W,@=&\@<F5T=7)N+@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(%1H92!C;V1E(&ES(&1Y;F%M:6-A;&QY(&EN
M8VQU9&5D+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C
M;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!O<B`@<&%R86UE=&5R<R!A('-U8F-L
M87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!60R`@5&AE
M(&YE=VQY(&-R96%T960@8V]N8W)E=&4@5D,@:6YS=&%N8V4L(&]R(%!%05)?
M17)R;W(@;VX*("`@("`J("`@("`@("`@("`@(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D<FEV97(L("1P87)A;7,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@(&EN8VQU9&5?;VYC92`G5D,O)R`N("1D<FEV
M97(@+B`G+G!H<"<["B`@("`@("`@)&-L87-S(#T@)U9#7R<@+B`D9')I=F5R
M.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@
M("`@("`D=F,@/2!N97<@)&-L87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1V8R`](%!%05(Z.G)A:7-E17)R;W(H)&-L87-S
M("X@)R!N;W0@9F]U;F0N)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)'9C.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N
M(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@5D,@:6YS=&%N8V4@8F%S960*
M("`@("`J(&]N("1D<FEV97(N($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@
M:6YS=&%N8V4@:68@;F\@5D,*("`@("`J(&EN<W1A;F-E('=I=&@@=&AE('-A
M;64@<&%R86UE=&5R<R!C=7)R96YT;'D@97AI<W1S+@H@("`@("H*("`@("`J
M(%1H:7,@<VAO=6QD(&)E('5S960@:68@;75L=&EP;&4@='EP97,@;V8@9FEL
M92!B86-K96YD<R`H86YD+`H@("`@("H@=&AU<RP@;75L=&EP;&4@5D,@:6YS
M=&%N8V5S*2!A<F4@<F5Q=6ER960N"B`@("`@*@H@("`@("H@5&AI<R!M971H
M;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R(#T@)E9#.CIS:6YG;&5T;VXH
M*0H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP
M92!O9B!C;VYC<F5T92!60R!S=6)C;&%S<R!T;R!R971U<FXN"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@5&AE(&-O9&4@:7,@9'EN86UI8V%L;'D@
M:6YC;'5D960N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H
M(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@(&]R('!A<F%M971E<G,@82!S=6)C
M;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@5D,@(%1H
M92!C;VYC<F5T92!60R!R969E<F5N8V4L(&]R(%!%05)?17)R;W(@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D9')I=F5R
M+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!S=&%T:6,@)&EN
M<W1A;F-E<SL*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97,I*2!["B`@
M("`@("`@("`@("1I;G-T86YC97,@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@
M("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92AA<G)A>2@D9')I=F5R+"`D
M<&%R86US*2D["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1S:6=N
M871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U<F5=
M(#T@5D,Z.F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<RD["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E73L*("`@('T*
M"GT*"B\J*@H@*B!`<&%C:V%G92!60PH@*B\*8VQA<W,@5D-?1&EF9B!["@H@
M("`@+RHJ"B`@("`@*B!/8G1A:6X@82!T<F5E(&-O;G1A:6YI;F<@:6YF;W)M
M871I;VX@86)O=70@=&AE(&-H86YG97,@8F5T=V5E;@H@("`@("H@='=O(')E
M=FES:6]N<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)')A=R`@06X@
M87)R87D@;V8@;&EN97,@;V8@=&AE(')A=R!U;FEF:65D(&1I9F8L"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@;F]R;6%L;'D@;V)T86EN960@=&AR;W5G
M:"!60U]$:69F.CIG970H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M"B`@("`@*@H@("`@("H@0'1O9&\@9&]C=6UE;G0@=&AI<R!T:&]R;W5G:&QY
M+"!A<R!T:&4@9F]R;6%T(&ES(&$@8FET(&-O;7!L97@N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&AU;6%N4F5A9&%B;&4H)')A=RD*("`@('L*("`@("`@("`D
M<F5T(#T@87)R87DH*3L*"B`@("`@("`@+RH@2&]L9"!T:&4@;&5F="!A;F0@
M<FEG:'0@8V]L=6UN<R!O9B!L:6YE<R!F;W(@8VAA;F=E"B`@("`@("`@("H@
M8FQO8VMS+B`J+PH@("`@("`@("1C;VQS(#T@87)R87DH87)R87DH*2P@87)R
M87DH*2D["B`@("`@("`@)'-T871E(#T@)V5M<'1Y)SL*"B`@("`@("`@+RH@
M271E<F%T92!T:')O=6=H(&5V97)Y(&QI;F4@;V8@=&AE(&1I9F8N("HO"B`@
M("`@("`@9F]R96%C:"`H)')A=R!A<R`D;&EN92D@>PH@("`@("`@("`@("`O
M*B!,;V]K(&9O<B!A(&AE861E<B!W:&EC:"!I;F1I8V%T97,@=&AE('-T87)T
M(&]F(&$@9&EF9@H@("`@("`@("`@("`@*B!C:'5N:RX@*B\*("`@("`@("`@
M("`@:68@*'!R96=?;6%T8V@H)R]>0$`@7"TH6S`M.5TK*2XJ7"LH6S`M.5TK
M*2XJ0$`H+BHI+R<L("1L:6YE+"`D<F5G<RDI('L*("`@("`@("`@("`@("`@
M("\J(%!U<V@@86YY('!R979I;W5S(&AE861E<B!I;F9O<FUA=&EO;B!T;R!T
M:&4@<F5T=7)N"B`@("`@("`@("`@("`@("`@*B!S=&%C:RX@*B\*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D9&%T82DI('L*("`@("`@("`@("`@("`@
M("`@("`D<F5T6UT@/2`D9&%T83L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1D871A(#T@87)R87DH)W1Y<&4G(#T^("=H96%D97(G+"`G
M;VQD;&EN92<@/3X@)')E9W-;,5TL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=N97=L:6YE)R`]/B`D<F5G<ULR72P@)V-O;G1E;G1S)SX@87)R
M87DH*2D["B`@("`@("`@("`@("`@("`D9&%T85LG9G5N8W1I;VXG72`](&ES
M<V5T*"1R96=S6S-=*2`_("1R96=S6S-=(#H@)R<["B`@("`@("`@("`@("`@
M("`D<W1A=&4@/2`G9'5M<"<["B`@("`@("`@("`@('T@96QS96EF("@D<W1A
M=&4@(3T@)V5M<'1Y)RD@>PH@("`@("`@("`@("`@("`@+RH@5V4@87)E(&EN
M(&$@8VAU;FLL('-O('-P;&ET(&]U="!T:&4@86-T:6]N("@K+RTI"B`@("`@
M("`@("`@("`@("`@*B!A;F0@=&AE(&QI;F4N("HO"B`@("`@("`@("`@("`@
M("!P<F5G7VUA=&-H*"<O7BA;7"M<+2!=*2@N*BDO)RP@)&QI;F4L("1R96=S
M*3L*("`@("`@("`@("`@("`@(&EF("AC;W5N="@D<F5G<RD@/B`R*2!["B`@
M("`@("`@("`@("`@("`@("`@)&%C=&EO;B`]("1R96=S6S%=.PH@("`@("`@
M("`@("`@("`@("`@("1C;VYT96YT(#T@)')E9W-;,ET["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1A8W1I;VX@/2`G
M("<["B`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`G)SL*("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H)&%C=&EO;B`]/2`G
M*R<I('L*("`@("`@("`@("`@("`@("`@("`O*B!4:&ES(&ES(&IU<W0@86X@
M861D:71I;VX@;&EN92X@*B\*("`@("`@("`@("`@("`@("`@("!I9B`H)'-T
M871E(#T]("=D=6UP)R!\?"`D<W1A=&4@/3T@)V%D9"<I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@+RH@4W1A<G0@861D:6YG('1O('1H92!A9&1I=&EO
M;B!S=&%C:RX@*B\*("`@("`@("`@("`@("`@("`@("`@("`@)&-O;'-;,%U;
M72`]("1C;VYT96YT.PH@("`@("`@("`@("`@("`@("`@("`@("`D<W1A=&4@
M/2`G861D)SL*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`O*B!4:&ES(&ES(&EN<VED92!A(&-H86YG92!B
M;&]C:RP@<V\@<W1A<G0*("`@("`@("`@("`@("`@("`@("`@("`@("H@86-C
M=6UU;&%T:6YG(&QI;F5S+B`J+PH@("`@("`@("`@("`@("`@("`@("`@("`D
M<W1A=&4@/2`G8VAA;F=E)SL*("`@("`@("`@("`@("`@("`@("`@("`@)&-O
M;'-;,5U;72`]("1C;VYT96YT.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T@96QS96EF("@D86-T:6]N(#T]("<M)RD@>PH@("`@
M("`@("`@("`@("`@("`@("\J(%1H:7,@:7,@82!R96UO=F%L(&QI;F4N("HO
M"B`@("`@("`@("`@("`@("`@("`@)'-T871E(#T@)W)E;6]V92<["B`@("`@
M("`@("`@("`@("`@("`@)&-O;'-;,%U;72`]("1C;VYT96YT.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O*B!!;B!E
M;7!T>2!B;&]C:R!W:71H(&YO(&%C=&EO;BX@*B\*("`@("`@("`@("`@("`@
M("`@("!S=VET8V@@*"1S=&%T92D@>PH@("`@("`@("`@("`@("`@("`@(&-A
M<V4@)V%D9"<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1D871A6R=C;VYT
M96YT<R==6UT@/2!A<G)A>2@G='EP92<@/3X@)V%D9"<L("=L:6YE<R<@/3X@
M)&-O;'-;,%TI.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@("`@("`@("`@8V%S92`G<F5M;W9E)SH*("`@("`@("`@("`@
M("`@("`@("`@("`@+RH@5V4@:&%V92!S;VUE(')E;6]V86P@;&EN97,@<&5N
M9&EN9R!I;B!O=7(*("`@("`@("`@("`@("`@("`@("`@("`@("H@<W1A8VLL
M('-O(&9L=7-H('1H96TN("HO"B`@("`@("`@("`@("`@("`@("`@("`@("1D
M871A6R=C;VYT96YT<R==6UT@/2!A<G)A>2@G='EP92<@/3X@)W)E;6]V92<L
M("=L:6YE<R<@/3X@)&-O;'-;,%TI.PH@("`@("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@("`@("`@("`@8V%S92`G8VAA;F=E)SH*
M("`@("`@("`@("`@("`@("`@("`@("`@+RH@5V4@:&%V92!B;W1H(')E;6]V
M92!A;F0@861D:71I;VX@;&EN97,L('-O"B`@("`@("`@("`@("`@("`@("`@
M("`@("`J('1H:7,@:7,@82!C:&%N9V4@8FQO8VLN("HO"B`@("`@("`@("`@
M("`@("`@("`@("`@("1D871A6R=C;VYT96YT<R==6UT@/2!A<G)A>2@G='EP
M92<@/3X@)V-H86YG92<L("=O;&0G(#T^("1C;VQS6S!=+"`G;F5W)R`]/B`D
M8V]L<ULQ72D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D8V]L<R`]
M(&%R<F%Y*&%R<F%Y*"DL(&%R<F%Y*"DI.PH@("`@("`@("`@("`@("`@("`@
M("1D871A6R=C;VYT96YT<R==6UT@/2!A<G)A>2@G='EP92<@/3X@)V5M<'1Y
M)RP@)VQI;F4G(#T^("1C;VYT96YT*3L*("`@("`@("`@("`@("`@("`@("`D
M<W1A=&4@/2`G9'5M<"<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("\J($IU<W0@9FQU<V@@86YY(')E;6%I
M;FEN9R!E;G1R:65S(&EN('1H92!C;VQU;6YS('-T86-K+B`J+PH@("`@("`@
M('-W:71C:"`H)'-T871E*2!["B`@("`@("`@8V%S92`G861D)SH*("`@("`@
M("`@("`@)&1A=&%;)V-O;G1E;G1S)UU;72`](&%R<F%Y*"=T>7!E)R`]/B`G
M861D)RP@)VQI;F5S)R`]/B`D8V]L<ULP72D["B`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("!C87-E("=R96UO=F4G.@H@("`@("`@("`@("`O*B!792!H
M879E('-O;64@<F5M;W9A;"!L:6YE<R!P96YD:6YG(&EN(&]U<B!S=&%C:RP@
M<V\*("`@("`@("`@("`@("H@9FQU<V@@=&AE;2X@*B\*("`@("`@("`@("`@
M)&1A=&%;)V-O;G1E;G1S)UU;72`](&%R<F%Y*"=T>7!E)R`]/B`G<F5M;W9E
M)RP@)VQI;F5S)R`]/B`D8V]L<ULP72D["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!C87-E("=C:&%N9V4G.@H@("`@("`@("`@("`O*B!792!H879E
M(&)O=&@@<F5M;W9E(&%N9"!A9&1I=&EO;B!L:6YE<RP@<V\@=&AI<R!I<R!A
M"B`@("`@("`@("`@("`J(&-H86YG92!B;&]C:RX@*B\*("`@("`@("`@("`@
M)&1A=&%;)V-O;G1E;G1S)UU;72`](&%R<F%Y*"=T>7!E)R`]/B`G8VAA;F=E
M)RP@)V]L9"<@/3X@)&-O;'-;,%TL("=N97<G(#T^("1C;VQS6S%=*3L*("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H
M)&1A=&$I*2!["B`@("`@("`@("`@("1R971;72`]("1D871A.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1R970["B`@("!]"@I]"@HO*BH*("H@0'!A
M8VMA9V4@5D,*("HO"F-L87-S(%9#7T9I;&4@>PH*("`@('9A<B`D<F5P.PH@
M("`@=F%R("1D:7(["B`@("!V87(@)&YA;64["B`@("!V87(@)&QO9W,["B`@
M("!V87(@)')E=G,["B`@("!V87(@)&AE860["B`@("!V87(@)'%U:6-K;&]G
M.PH@("`@=F%R("1S>6UR978["B`@("!V87(@)')E=G-Y;3L*("`@('9A<B`D
M8G)A;F-H97,["@H@("`@9G5N8W1I;VX@<V5T4F5P;W-I=&]R>2@D<F5P*0H@
M("`@>PH@("`@("`@("1T:&ES+3YR97`@/2`D<F5P.PH@("`@?0H*?0H*+RHJ
M"B`J(%9#('!A=&-H<V5T(&-L87-S+@H@*@H@*B!`<&%C:V%G92!60PH@*B\*
M8VQA<W,@5D-?4&%T8VAS970@>PH*("`@('9A<B`D7W)E<#L*("`@('9A<B`D
M7W!A=&-H<V5T<R`](&%R<F%Y*"D["@H@("`@9G5N8W1I;VX@<V5T4F5P;W-I
M=&]R>2@D<F5P*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<F5P(#T@)')E<#L*
M("`@('T*"GT*"B\J*@H@*B!60R!R979I<VEO;G,@8VQA<W,N"B`J"B`J($-O
M<'ER:6=H="!!;FEL($UA9&AA=F%P961D>2P@/&%N:6Q`<F5C;VEL+F]R9SX*
M("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL
M+F]R9SX*("H@0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#7U)E=FES:6]N('L*
M"B`@("`O*BH*("`@("`J(%9A;&ED871I;VX@9G5N8W1I;VX@=&\@96YS=7)E
M('1H870@82!R979I<VEO;B!N=6UB97(@:7,@;V8@=&AE"B`@("`@*B!R:6=H
M="!F;W)M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'9A;"`@5F%L
M=64@=&\@8VAE8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&EF(&ET(&ES(&$@<F5V:7-I;VX@;G5M8F5R"B`@("`@*B\*("`@(&9U
M;F-T:6]N('9A;&ED*"1V86PI"B`@("!["B`@("`@("`@<F5T=7)N("1V86P@
M)B8@<')E9U]M871C:"@G+UY;7&1<+ETK)"\G+"`D=F%L*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($=I=F5N(&$@<F5V:7-I;VX@;G5M8F5R+"!R96UO=F4@
M82!G:79E;B!N=6UB97(@;V8@<&]R=&EO;G,@9G)O;0H@("`@("H@:70N($9O
M<B!E>&%M<&QE+"!I9B!W92!R96UO=F4@,B!P;W)T:6]N<R!O9B`Q+C(N,RXT
M+"!W92!A<F4*("`@("`J(&QE9G0@=VET:"`Q+C(N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=F%L("`@("`@26YP=70@<F5V:7-I;VX*("`@("`J
M($!P87)A;2!I;G1E9V5R("1A;6]U;G0@($YU;6)E<B!O9B!P;W)T:6]N<R!T
M;R!S=')I<`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!3=')I<'!E
M9"!R979I<VEO;B!N=6UB97(*("`@("`J+PH@("`@9G5N8W1I;VX@<W1R:7`H
M)'9A;"P@)&%M;W5N="D*("`@('L*("`@("`@("!I9B`H(59#7U)E=FES:6]N
M.CIV86QI9"@D=F%L*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H@("`@("`@("1P;W,@/2`P.PH@("`@("`@('=H:6QE("@D86UO
M=6YT+2T@/B`P("8F("@D<&]S(#T@<W1R<G!O<R@D=F%L+"`G+B<I*2`A/3T@
M9F%L<V4I('L*("`@("`@("`@("`@)'9A;"`]('-U8G-T<B@D=F%L+"`P+"`D
M<&]S*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1P;W,@(3T](&9A;'-E
M(#\@)'9A;"`Z(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AE('-I
M>F4@;V8@82!R979I<VEO;B!N=6UB97(@:7,@=&AE(&YU;6)E<B!O9B!P;W)T
M:6]N<R!I="!H87,N"B`@("`@*B!&;W(@97AA;7!L92P@,2PR+C,N-"!I<R!O
M9B!S:7IE(#0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%L("!2
M979I<VEO;B!N=6UB97(@=&\@9&5T97)M:6YE('-I>F4@;V8*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN=&5G97(@(%-I>F4@;V8@<F5V:7-I;VX@;G5M8F5R
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-I>F5O9B@D=F%L*0H@("`@>PH@("`@
M("`@(&EF("@A5D-?4F5V:7-I;VXZ.G9A;&ED*"1V86PI*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`H
M<W5B<W1R7V-O=6YT*"1V86PL("<N)RD@*R`Q*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($=I=F5N(&$@=F%L:60@<F5V:7-I;VX@;G5M8F5R+"!T:&ES('=I
M;&P@<F5T=7)N('1H92!R979I<VEO;@H@("`@("H@;G5M8F5R(&9R;VT@=VAI
M8V@@:70@8G)A;F-H960N($EF(&ET(&-A;FYO="!B92!D971E<FUI;F5D+"!T
M:&5N"B`@("`@*B!F86QS92!I<R!R971U<FYE9"X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1V86P@(%)E=FES:6]N(&YU;6)E<BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9WQB;V]L96%N("!"<F%N8V@@<&]I;G0@<F5V
M:7-I;VXL(&]R(&9A;'-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!B<F%N8VA0
M;VEN="@D=F%L*0H@("`@>PH@("`@("`@("\J($-H96-K(&EF('=E(&AA=F4@
M82!V86QI9"!R979I<VEO;B!N=6UB97(@*B\*("`@("`@("!I9B`H(59#7U)E
M=FES:6]N.CIV86QI9"@D=F%L*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!I=',@;VX@=&AE('1R=6YK
M+"!O<B!I<R!A;B!O9&0@<VEZ92P@<F5T(&9A;'-E("HO"B`@("`@("`@:68@
M*%9#7U)E=FES:6]N.CIS:7IE;V8H)'9A;"D@/"`S('Q\("A60U]2979I<VEO
M;CHZ<VEZ96]F*"1V86PI("4@,BDI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@4W1R:7`@;V9F('1W;R!R979I
M<VEO;B!P;W)T:6]N<RP@86YD(')E='5R;B!I="`J+PH@("`@("`@(')E='5R
M;B!60U]2979I<VEO;CHZ<W1R:7`H)'9A;"P@,BD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!':79E;B!T=V\@4U9.(')E=FES:6]N(&YU;6)E<G,L('1H:7,@
M9FEG=7)E<R!O=70@=VAI8V@@;VYE(&ES"B`@("`@*B!G<F5A=&5R('1H86X@
M=&AE(&]T:&5R(&)Y('-T97!P:6YG(&%L;VYG('1H92!D96-I;6%L('!O:6YT
M<PH@("`@("H@=6YT:6P@82!D:69F97)E;F-E(&ES(&9O=6YD+"!A="!W:&EC
M:"!P;VEN="!A('-I9VX@8V]M<&%R:7-O;@H@("`@("H@;V8@=&AE('1W;R!I
M<R!R971U<FYE9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1R978Q
M("!097)I;V0@9&5L:6UI=&5D(')E=FES:6]N(&YU;6)E<@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<F5V,B`@4V5C;VYD('!E<FEO9"!D96QI;6ET960@<F5V
M:7-I;VX@;G5M8F5R"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("`Q
M(&EF('1H92!F:7)S="!I<R!G<F5A=&5R+"`M,2!I9B!T:&4@<V5C;VYD(&EF
M(&=R96%T97(L"B`@("`@*B`@("`@("`@("`@("`@("`@(&%N9"`P(&EF('1H
M97D@87)E(&5Q=6%L"B`@("`@*B\*("`@(&9U;F-T:6]N(&-M<"@D<F5V,2P@
M)')E=C(I"B`@("!["B`@("`@("`@<F5T=7)N('9E<G-I;VY?8V]M<&%R92@D
M<F5V,2P@)')E=C(I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H
M92!L;V=I8V%L(')E=FES:6]N(&)E9F]R92!T:&ES(&]N92X@3F]R;6%L;'DL
M('1H:7,*("`@("`J('=I;&P@8F4@=&AE(')E=FES:6]N(&UI;G5S(&]N92P@
M8G5T(&EN('1H92!C87-E(&]F(&$@;F5W"B`@("`@*B!B<F%N8V@L('=E('-T
M<FEP(&]F9B!T:&4@;&%S="!T=V\@9&5C:6UA;"!P;&%C97,@=&\@<F5T=7)N
M('1H90H@("`@("H@;W)I9VEN86P@8G)A;F-H('!O:6YT+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)')E=B`@4F5V:7-I;VX@;G5M8F5R('1O(&1E
M8W)E;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9WQB;V]L96%N
M("!2979I<VEO;B!N=6UB97(L(&]R(&9A;'-E(&EF(&YO;F4@8V]U;&0@8F4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&1E=&5R;6EN960N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('!R978H)')E=BD*("`@('L*("`@("`@("`D
M;&%S=%]D;W0@/2!S=')R<&]S*"1R978L("<N)RD["B`@("`@("`@)'9A;"`]
M('-U8G-T<B@D<F5V+"`K*R1L87-T7V1O="D["@H@("`@("`@(&EF("@M+21V
M86P@/B`P*2!["B`@("`@("`@("`@(')E='5R;B!S=6)S='(H)')E=BP@,"P@
M)&QA<W1?9&]T*2`N("1V86P["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&QA<W1?9&]T+2T["B`@("`@("`@("`@('=H:6QE("@M+21L87-T7V1O
M="D@>PH@("`@("`@("`@("`@("`@:68@*"1R979;)&QA<W1?9&]T72`]/2`G
M+B<I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@('-U8G-T<B@D<F5V
M+"`P+"`D;&%S=%]D;W0I.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1R
M979;)&QA<W1?9&]T72`]/2!N=6QL*2!["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1VEV96X@82!R979I
M<VEO;B!N=6UB97(@;V8@=&AE(&9O<FT@>"YY+C`N>BP@=&AI<R!R96UA<',@
M:70*("`@("`J(&EN=&\@=&AE(&%P<')O<')I871E(&)R86YC:"!N=6UB97(L
M('=H:6-H(&ES('@N>2YZ"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<F5V("!%=F5N+61I9VET(')E=FES:6]N(&YU;6)E<B!O9B!A(&)R86YC:`H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!/9&0M9&EG:70@0G)A;F-H
M(&YU;6)E<@H@("`@("HO"B`@("!F=6YC=&EO;B!T;T)R86YC:"@D<F5V*0H@
M("`@>PH@("`@("`@("\J($-H96-K(&EF('=E(&AA=F4@82!V86QI9"!R979I
M<VEO;B!N=6UB97(@*B\*("`@("`@("!I9B`H(59#7U)E=FES:6]N.CIV86QI
M9"@D<F5V*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("!I9B`H*"1E;F0@/2!S=')R<&]S*"1R978L("<N)RDI(#T]
M/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("`D<F5V6R1E;F1=(#T@,#L*("`@("`@("!I9B`H*"1E;F0R
M(#T@<W1R<G!O<R@D<F5V+"`G+B<I*2`]/3T@9F%L<V4I('L*("`@("`@("`@
M("`@<F5T=7)N('-U8G-T<B@D<F5V+"`K*R1E;F0I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('-U8G-T<E]R97!L86-E*"1R978L("<N)RP@)&5N9#(L
M("@D96YD+21E;F0R*S$I*3L*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92YP:'``````````````````````````
M````````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q-34R,#(`,3`U,34T,S,W-3(`
M,#(P,C`R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@II;F-L=61E7V]N8V4@)TQO9RYP:'`G.PII;F-L=61E7V]N
M8V4@)TAO<F1E+U5T:6PN<&AP)SL*"B\J*@H@*B!4:&4@2&]R9&4Z.B!C;&%S
M<R!P<F]V:61E<R!T:&4@9G5N8W1I;VYA;&ET>2!S:&%R960@8GD@86QL($AO
M<F1E"B`J(&%P<&QI8V%T:6]N<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP+'8@,2XT.#DN,BXU-"`R,#`V+S`W+S,Q(#`X.C0Y
M.C0W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,3DY
M.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*
M("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7T9R86UE
M=V]R:PH@*B\*8VQA<W,@2&]R9&4@>PH*("`@("\J*@H@("`@("H@3&]G<R!A
M(&UE<W-A9V4@=&\@=&AE(&=L;V)A;"!(;W)D92!L;V<@8F%C:V5N9"X*("`@
M("`J"B`@("`@*B!`<&%R86T@;6EX960@)&UE<W-A9V4@("`@($5I=&AE<B!A
M('-T<FEN9R!O<B!A(%!%05)?17)R;W(@;V)J96-T+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9FEL92`@("`@("!7:&%T(&9I;&4@=V%S('1H92!L;V<@9G5N
M8W1I;VX@8V%L;&5D(&9R;VT*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@*&4N9RX@7U]&24Q%7U\I/PH@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&QI;F4@("`@("!7:&%T(&QI;F4@=V%S('1H92!L;V<@9G5N8W1I;VX@8V%L
M;&5D(&9R;VT*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@*&4N
M9RX@7U],24Y%7U\I/PH@("`@("H@0'!A<F%M(&EN=&5G97(@)'!R:6]R:71Y
M("!4:&4@<')I;W)I='D@;V8@=&AE(&UE<W-A9V4N($]N92!O9CH*("`@("`J
M(#QP<F4^"B`@("`@*B!014%27TQ/1U]%34521PH@("`@("H@4$5!4E],3T=?
M04Q%4E0*("`@("`J(%!%05)?3$]'7T-2250*("`@("`J(%!%05)?3$]'7T52
M4@H@("`@("H@4$5!4E],3T=?5T%23DE.1PH@("`@("H@4$5!4E],3T=?3D]4
M24-%"B`@("`@*B!014%27TQ/1U])3D9/"B`@("`@*B!014%27TQ/1U]$14)5
M1PH@("`@("H@/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO9TUE<W-A
M9V4H)&UE<W-A9V4L("1F:6QE+"`D;&EN92P@)'!R:6]R:71Y(#T@4$5!4E],
M3T=?24Y&3RD*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@
M(&EF("@A)&-O;F9;)VQO9R==6R=E;F%B;&5D)UTI('L*("`@("`@("`@("`@
M<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@:68@*"1P<FEO<FET>2`^("1C
M;VYF6R=L;V<G75LG<')I;W)I='DG72D@>PH@("`@("`@("`@("!R971U<FX[
M"B`@("`@("`@?0H*("`@("`@("`D;&]G9V5R(#T@)DAO<F1E.CIG971,;V=G
M97(H*3L*("`@("`@("!I9B`H(6ES7V$H)&QO9V=E<BP@)TQO9R<I*2!["B`@
M("`@("`@("`@($AO<F1E.CIF871A;"A014%2.CIR86ES945R<F]R*"=!;B!E
M<G)O<B!H87,@;V-C=7)R960N($9U<G1H97)M;W)E+"!(;W)D92!E;F-O=6YT
M97)E9"!A;B!E<G)O<B!A='1E;7!T:6YG('1O(&QO9R!T:&ES(&5R<F]R+B!0
M;&5A<V4@8VAE8VL@>6]U<B!(;W)D92!L;V=G:6YG(&-O;F9I9W5R871I;VX@
M:6X@:&]R9&4O8V]N9FEG+V-O;F8N<&AP+B<I+"!?7T9)3$5?7RP@7U],24Y%
M7U\L(&9A;'-E*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]A*"1M97-S
M86=E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1U<V5R:6YF;R`]
M("1M97-S86=E+3YG9715<V5R26YF;R@I.PH@("`@("`@("`@("`D;65S<V%G
M92`]("1M97-S86=E+3YG971-97-S86=E*"D["B`@("`@("`@("`@(&EF("@A
M96UP='DH)'5S97)I;F9O*2D@>PH@("`@("`@("`@("`@("`@:68@*&ES7V%R
M<F%Y*"1U<V5R:6YF;RDI('L*("`@("`@("`@("`@("`@("`@("`D=7-E<FEN
M9F\@/2!`:6UP;&]D92@G+"`G+"`D=7-E<FEN9F\I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)&UE<W-A9V4@+CT@)SH@)R`N("1U<V5R
M:6YF;SL*("`@("`@("`@("`@?0H@("`@("`@('T@96QS96EF("AI<U]C86QL
M86)L92AA<G)A>2@D;65S<V%G92P@)V=E=$UE<W-A9V4G*2DI('L*("`@("`@
M("`@("`@)&UE<W-A9V4@/2`D;65S<V%G92T^9V5T365S<V%G92@I.PH@("`@
M("`@('T*"B`@("`@("`@)&%P<"`](&ES<V5T*"1'3$]"04Q36R=R96=I<W1R
M>2==*2`_("1'3$]"04Q36R=R96=I<W1R>2==+3YG971!<'`H*2`Z("=H;W)D
M92<["B`@("`@("`@)&UE<W-A9V4@/2`G6R<@+B`D87!P("X@)UT@)R`N("1M
M97-S86=E("X@)R!;;VX@;&EN92`G("X@)&QI;F4@+B`G(&]F("(G("X@)&9I
M;&4@+B`G(ETG.PH*("`@("`@("`O*B!-86ME('-U<F4@=&\@;&]G(&EN('1H
M92!S>7-T96TG<R!L;V-A;&4N("HO"B`@("`@("`@)&QO8V%L92`]('-E=&QO
M8V%L92A,0U]424U%+"`P*3L*("`@("`@("!S971L;V-A;&4H3$-?5$E-12P@
M)T,G*3L*"B`@("`@("`@)&QO9V=E<BT^;&]G*"1M97-S86=E+"`D<')I;W)I
M='DI.PH*("`@("`@("`O*B!297-T;W)E(&]R:6=I;F%L(&QO8V%L92X@*B\*
M("`@("`@("!S971L;V-A;&4H3$-?5$E-12P@)&QO8V%L92D["@H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("HO"B`@("!F=6YC
M=&EO;B`F9V5T3&]G9V5R*"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8[
M"@H@("`@("`@(&EF("AE;7!T>2@D8V]N9ELG;&]G)UU;)V5N86)L960G72DI
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@<W1A=&EC("1L;V=C:&5C:SL*("`@("`@("!I9B`H(6ES<V5T*"1L;V=C
M:&5C:RDI('L*("`@("`@("`@("`@+R\@5')Y('1O(&UA:V4@<W5R92!T:&%T
M('=E(&-A;B!L;V<@;65S<V%G97,@<V]M96AO=RX*("`@("`@("`@("`@:68@
M*&5M<'1Y*"1C;VYF6R=L;V<G72D@?'P*("`@("`@("`@("`@("`@(&5M<'1Y
M*"1C;VYF6R=L;V<G75LG='EP92==*2!\?`H@("`@("`@("`@("`@("`@96UP
M='DH)&-O;F9;)VQO9R==6R=N86UE)UTI('Q\"B`@("`@("`@("`@("`@("!E
M;7!T>2@D8V]N9ELG;&]G)UU;)VED96YT)UTI('Q\"B`@("`@("`@("`@("`@
M("`A:7-S970H)&-O;F9;)VQO9R==6R=P87)A;7,G72DI('L*("`@("`@("`@
M("`@("`@($AO<F1E.CIF871A;"A014%2.CIR86ES945R<F]R*"=(;W)D92!I
M<R!N;W0@8V]R<F5C=&QY(&-O;F9I9W5R960@=&\@;&]G(&5R<F]R(&UE<W-A
M9V5S+B!9;W4@;75S="!C;VYF:6=U<F4@870@;&5A<W0@82!T97AT(&9I;&4@
M;&]G(&EN(&AO<F1E+V-O;F9I9R]C;VYF+G!H<"XG*2P@7U]&24Q%7U\L(%]?
M3$E.15]?+"!F86QS92D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&QO
M9V-H96-K(#T@=')U93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;&]G
M9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"1C;VYF6R=L;V<G75LG='EP92==+"`D
M8V]N9ELG;&]G)UU;)VYA;64G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D8V]N9ELG;&]G)UU;)VED96YT)UTL("1C;VYF
M6R=L;V<G75LG<&%R86US)UTI.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5S
M=')O>7,@86YY(&5X:7-T:6YG('-E<W-I;VX@;VX@;&]G:6X@86YD(&UA:V4@
M<W5R92!T;R!U<V4@82!N97<*("`@("`J('-E<W-I;VX@240L('1O(&%V;VED
M('-E<W-I;VX@9FEX871I;VX@:7-S=65S+B!3:&]U;&0@8F4@8V%L;&5D(&)E
M9F]R90H@("`@("H@8VAE8VMI;F<@82!L;V=I;BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T0VQE86Y397-S:6]N*"D*("`@('L*("`@("`@("`O+R!-86ME
M('-U<F4@=&\@9F]R8V4@82!C;VUP;&5T96QY(&YE=R!S97-S:6]N($E$(&%N
M9"!C;&5A<@H@("`@("`@("\O(&%L;"!S97-S:6]N(&1A=&$N"B`@("`@("`@
M:68@*'9E<G-I;VY?8V]M<&%R92AP:'!V97)S:6]N*"DL("<T+C,N,R<I("$]
M/2`M,2D@>PH@("`@("`@("`@("!S97-S:6]N7W)E9V5N97)A=&5?:60H*3L*
M("`@("`@("`@("`@<V5S<VEO;E]U;G-E="@I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@($!S97-S:6]N7V1E<W1R;WDH*3L*("`@("`@("`@("`@
M:68@*%5T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G<&]S:7@G*2D@>PH@("`@("`@
M("`@("`@("`@)&YE=U]S97-S:6]N7VED(#T@;60U*&UI8W)O=&EM92@I("X@
M<&]S:7A?9V5T<&ED*"DI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)&YE=U]S97-S:6]N7VED(#T@;60U*'5N:7%I9"AM=%]R86YD
M*"DL('1R=64I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!S97-S:6]N
M7VED*"1N97=?<V5S<VEO;E]I9"D["@H@("`@("`@("`@("`O+R!297-T87)T
M('1H92!S97-S:6]N+"!I;F-L=61I;F<@<V5T=&EN9R!U<"!T:&4@<V5S<VEO
M;@H@("`@("`@("`@("`O+R!H86YD;&5R+@H@("`@("`@("`@("!(;W)D93HZ
M<V5T=7!397-S:6]N2&%N9&QE<B@I.PH@("`@("`@("`@("!`<V5S<VEO;E]S
M=&%R="@I.PH@("`@("`@('T*"B`@("`@("`@+RH@4F5S970@8V]O:VEE('1I
M;65O=71S+"!I9B!N96-E<W-A<GDN("HO"B`@("`@("`@:68@*"%E;7!T>2@D
M1TQ/0D%,4ULG8V]N9B==6R=S97-S:6]N)UU;)W1I;65O=70G72DI('L*("`@
M("`@("`@("`@)&%P<"`]("1'3$]"04Q36R=R96=I<W1R>2==+3YG971!<'`H
M*3L*("`@("`@("`@("`@:68@*%-E8W)E=#HZ8VQE87)+97DH)&%P<"DI('L*
M("`@("`@("`@("`@("`@(%-E8W)E=#HZ<V5T2V5Y*"1A<'`I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(%-E8W)E=#HZ<V5T2V5Y*"=A=71H)RD["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@06)O<G1S('=I=&@@82!F
M871A;"!E<G)O<BP@9&ES<&QA>6EN9R!D96)U9R!I;F9O<FUA=&EO;B!T;R!T
M:&4@=7-E<BX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&5R<F]R("`@
M02!014%27T5R<F]R(&]B:F5C="!W:71H(&1E8G5G(&EN9F]R;6%T:6]N(&]R
M(&%N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@97)R;W(@;65S<V%G
M92X*("`@("`J($!P87)A;2!I;G1E9V5R("1F:6QE("!4:&4@9FEL92!I;B!W
M:&EC:"!T:&4@97)R;W(@;V-C=7)E9"X*("`@("`J($!P87)A;2!I;G1E9V5R
M("1L:6YE("!4:&4@;&EN92!O;B!W:&EC:"!T:&4@97)R;W(@;V-C=7)E9"X*
M("`@("`J($!P87)A;2!B;V]L96%N("1L;V<@("!,;V<@=&AI<R!M97-S86=E
M('9I82!(;W)D93HZ;&]G365S<V%G92@I/PH@("`@("HO"B`@("!F=6YC=&EO
M;B!F871A;"@D97)R;W(L("1F:6QE+"`D;&EN92P@)&QO9R`]('1R=64I"B`@
M("!["B`@("`@("`@0&EN8VQU9&5?;VYC92`G2&]R9&4O075T:"YP:'`G.PH@
M("`@("`@($!I;F-L=61E7V]N8V4@)TAO<F1E+T-,22YP:'`G.PH*("`@("`@
M("`D861M:6X@/2!C;&%S<U]E>&ES=',H)T%U=&@G*2`F)B!!=71H.CII<T%D
M;6EN*"D["B`@("`@("`@)&-L:2`](&-L87-S7V5X:7-T<R@G2&]R9&5?0TQ)
M)RD@)B8@2&]R9&5?0TQ).CIR=6YN:6YG1G)O;4-,22@I.PH*("`@("`@("`D
M97)R;W)T97AT(#T@)SQH,3XG("X@7R@B02!F871A;"!E<G)O<B!H87,@;V-C
M=7)R960B*2`N("<\+V@Q/B<["B`@("`@("`@:68@*&ES7V$H)&5R<F]R+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1I;F9O(#T@87)R87E?;65R
M9V4H87)R87DH)V9I;&4G(#T^("=C;VYF+G!H<"<L("=V87)I86)L92<@/3X@
M)R1C;VYF)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)&5R<F]R+3YG9715<V5R26YF;R@I*2D["@H@("`@("`@("`@("!S=VET
M8V@@*"1E<G)O<BT^9V5T0V]D92@I*2!["B`@("`@("`@("`@(&-A<V4@2$]2
M1$5?15)23U)?1%))5D527T-/3D9)1U]-25-324Y'.@H@("`@("`@("`@("`@
M("`@)&UE<W-A9V4@/2!S<')I;G1F*%\H(DYO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB*2P@)&EN9F];)VYA;64G72D@
M+B`G/&)R("\^)R`N"B`@("`@("`@("`@("`@("`@("`@<W!R:6YT9BA?*")4
M:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)W)E9VES
M=')Y)UTM/F=E="@G9FEL97)O;W0G*2`N("<O8V]N9FEG+R<@+B`D:6YF;ULG
M9FEL92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W!R:6YT9B@B
M)7-;)R5S)UU;)W!A<F%M<R==(BP@)&EN9F];)W9A<FEA8FQE)UTL("1I;F9O
M6R=D<FEV97(G72DI.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("!C87-E($A/4D1%7T524D]27T12259%4E]#3TY&24<Z"B`@("`@("`@
M("`@("`@("`D;65S<V%G92`]('-P<FEN=&8H7R@B4F5Q=6ER960@7"(E<UPB
M(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB*2P@)&EN9F];
M)V9I96QD)UTL("1I;F9O6R=N86UE)UTI("X@)SQB<B`O/B<@+@H@("`@("`@
M("`@("`@("`@("`@('-P<FEN=&8H7R@B5&AE(&9I;&4@)7,@<VAO=6QD(&-O
M;G1A:6X@82`E<R!S971T:6YG+B(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G9FEL97)O;W0G*2`N
M("<O8V]N9FEG+R<@+B`D:6YF;ULG9FEL92==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<W!R:6YT9B@B)7-;)R5S)UU;)W!A<F%M<R==6R<E<R==
M(BP@)&EN9F];)W9A<FEA8FQE)UTL("1I;F9O6R=D<FEV97(G72P@)&EN9F];
M)V9I96QD)UTI*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@9&5F875L=#H*("`@("`@("`@("`@("`@("1M97-S86=E(#T@)&5R<F]R
M+3YG971-97-S86=E*"D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)&5R<F]R=&5X="`N/2`G/&@S/B<@+B!H
M=&UL<W!E8VEA;&-H87)S*"1M97-S86=E*2`N("<\+V@S/B<["B`@("`@("`@
M?2!E;'-E:68@*&ES7V]B:F5C="@D97)R;W(I("8F(&UE=&AO9%]E>&ES=',H
M)&5R<F]R+"`G9V5T365S<V%G92<I*2!["B`@("`@("`@("`@("1E<G)O<G1E
M>'0@+CT@)SQH,SXG("X@:'1M;'-P96-I86QC:&%R<R@D97)R;W(M/F=E=$UE
M<W-A9V4H*2D@+B`G/"]H,SXG.PH@("`@("`@('T@96QS96EF("AI<U]S=')I
M;F<H)&5R<F]R*2D@>PH@("`@("`@("`@("`D97)R;W)T97AT("X]("<\:#,^
M)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&5R<F]R*2`N("<\+V@S/B<["B`@("`@
M("`@?0H*("`@("`@("!I9B`H)&%D;6EN*2!["B`@("`@("`@("`@("1E<G)O
M<G1E>'0@+CT@)SQP/CQC;V1E/B<@+B!S<')I;G1F*%\H(EML:6YE("5S(&]F
M("5S72(I+"`D;&EN92P@)&9I;&4I("X@)SPO8V]D93X\+W`^)SL*("`@("`@
M("`@("`@:68@*&ES7V]B:F5C="@D97)R;W(I*2!["B`@("`@("`@("`@("`@
M("`D97)R;W)T97AT("X]("<\:#,^)R`N(%\H(D1E=&%I;',@*&%L<V\@:6X@
M2&]R9&4G<R!L;V=F:6QE*3HB*2`N("<\+V@S/B<["B`@("`@("`@("`@("`@
M("`D97)R;W)T97AT("X]("<\<#X\<')E/B<@+B!H=&UL<W!E8VEA;&-H87)S
M*%5T:6PZ.F)U9F9E<D]U='!U="@G=F%R7V1U;7`G+"`D97)R;W(I*2`N("<\
M+W!R93X\+W`^)SL*("`@("`@("`@("`@?0H@("`@("`@('T@96QS96EF("@D
M;&]G*2!["B`@("`@("`@("`@("1E<G)O<G1E>'0@+CT@)SQH,SXG("X@7R@B
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BXB*2`N("<\+V@S/B<["B`@("`@("`@?0H*("`@("`@("`O+R!,;V<@=&AE
M(&5R<F]R('9I82!(;W)D93HZ;&]G365S<V%G92@I(&EF(')E<75E<W1E9"X*
M("`@("`@("!I9B`H)&QO9RD@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92@D97)R;W(L("1F:6QE+"`D;&EN92P@4$5!4E],3T=?14U%4D<I.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"1C;&DI('L*("`@("`@("`@("`@96-H
M;R!S=')I<%]T86=S*'-T<E]R97!L86-E*&%R<F%Y*"<\8G(@+SXG+"`G/'`^
M)RP@)SPO<#XG+"`G/&@Q/B<L("<\+V@Q/B<L("<\:#,^)RP@)SPO:#,^)RDL
M(")<;B(L("1E<G)O<G1E>'0I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!E8VAO(#P\/"!(5$U,"CQH=&UL/@H\:&5A9#X\=&ET;&4^2&]R9&4@
M.CH@1F%T86P@17)R;W(\+W1I=&QE/CPO:&5A9#X*/&)O9'D@<W1Y;&4](F)A
M8VMG<F]U;F0Z(V9F9CL@8V]L;W(Z(S`P,"(^)&5R<F]R=&5X=#PO8F]D>3X*
M/"]H=&UL/@I(5$U,.PH@("`@("`@('T*("`@("`@("!E>&ET.PH@("`@?0H*
M("`@("\J*@H@("`@("H@061D<R!T:&4@:F%V87-C<FEP="!C;V1E('1O('1H
M92!O=71P=70@*&EF(&]U='!U="!H87,@86QR96%D>2!S=&%R=&5D*0H@("`@
M("H@;W(@=&\@=&AE(&QI<W0@;V8@<V-R:7!T(&9I;&5S('1O(&EN8VQU9&4@
M=FEA(&EN8VQU9&538W)I<'1&:6QE<R@I+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&9I;&4@("`@(%1H92!F=6QL(&IA=F%S8W)I<'0@9FEL92!N
M86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P("`@("`@5&AE(&%P<&QI
M8V%T:6]N(&YA;64N($1E9F%U;'1S('1O('1H92!C=7)R96YT"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!A<'!L:6-A=&EO;BX*("`@("`J($!P
M87)A;2!B;V]L96%N("1D:7)E8W0@($EN8VQU9&4@=&AE(&9I;&4@9&ER96-T
M;'D@=VET:&]U="!P87-S:6YG(&ET"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!T:')O=6=H(&IA=F%S8W)I<'0N<&AP/PH@("`@("HO"B`@("!F
M=6YC=&EO;B!A9&138W)I<'1&:6QE*"1F:6QE+"`D87!P(#T@;G5L;"P@)&1I
M<F5C="`](&9A;'-E*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD[
M"B`@("`@("`@<W1A=&EC("1I;F-L=61E9"`](&%R<F%Y*"D["@H@("`@("`@
M(&EF("AE;7!T>2@D87!P*2D@>PH@("`@("`@("`@("`D87!P(#T@)')E9VES
M=')Y+3YG971!<'`H*3L*("`@("`@("!]"@H@("`@("`@("\O(%-K:7`@86YY
M(&IS(&9I;&5S('1H870@:&%V92!S:6YC92!B965N(&1E<')E8V%T960N"B`@
M("`@("`@)&EG;F]R961?9FEL97,@/2!A<G)A>2@G:&]R9&4G(#T^(&%R<F%Y
M*"=T;V]L=&EP+FIS)R`]/B`Q*2D["B`@("`@("`@:68@*"%E;7!T>2@D:6=N
M;W)E9%]F:6QE<ULD87!P75LD9FEL95TI*2!["B`@("`@("`@("`@(')E='5R
M;CL*("`@("`@("!]"@H@("`@("`@("\O($1O;B=T(&EN8VQU9&4@<V-R:7!T
M<R!M=6QT:7!L92!T:6UE<RX*("`@("`@("!I9B`H(65M<'1Y*"1I;F-L=61E
M9%LD87!P75LD9FEL95TI*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@
M("!]"B`@("`@("`@)&EN8VQU9&5D6R1A<'!=6R1F:6QE72`]('1R=64["@H@
M("`@("`@("\O($5X<&QI8VET;'D@8VAE8VL@9F]R(&$@;F]N+5!(4"!V97)S
M:6]N(&]F('1H92!S8W)I<'0N"B`@("`@("`@:68@*"$D9&ER96-T("8F(&9I
M;&5?97AI<W1S*"1F:6QE>S!](#T]("<O)R`_("1R96=I<W1R>2T^9V5T*"=F
M:6QE<F]O="<L("1A<'`I("X@)&9I;&4@.B`D<F5G:7-T<GDM/F=E="@G:G-F
M<R<L("1A<'`I("X@)R\G("X@)&9I;&4I*2!["B`@("`@("`@("`@("1D:7)E
M8W0@/2!T<G5E.PH@("`@("`@('T*"B`@("`@("`@+R\@268@:&5A9&5R<R!H
M879E(&%L<F5A9'D@8F5E;B!S96YT+"!W92!N965D('1O(&]U='!U="!A"B`@
M("`@("`@+R\@/'-C<FEP=#X@=&%G(&1I<F5C=&QY+@H@("`@("`@(&EF("AO
M8E]G971?;&5N9W1H*"D@?'P@:&5A9&5R<U]S96YT*"DI('L*("`@("`@("`@
M("`@:68@*"1D:7)E8W0I('L*("`@("`@("`@("`@("`@("1U<FP@/2!(;W)D
M93HZ=7)L*"1F:6QE>S!](#T]("<O)R`_("1R96=I<W1R>2T^9V5T*"=W96)R
M;V]T)RP@)&%P<"D@+B`D9FEL92`Z("1R96=I<W1R>2T^9V5T*"=J<W5R:2<L
M("1A<'`I("X@)R\G("X@)&9I;&4I.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)'5R;"`]($AO<F1E.CIU<FPH)')E9VES=')Y+3YG
M970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<V5R=FEC97,O:F%V87-C<FEP
M="YP:'`G*3L*("`@("`@("`@("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A
M;65T97(H)'5R;"P@87)R87DH)V9I;&4G(#T^("1F:6QE+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M87!P)R`@/3X@)&%P<"DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5C
M:&\@)SQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(B!S<F,](B<@+B`D
M=7)L("X@)R(^/"]S8W)I<'0^)R`N(")<;B(["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@9VQO8F%L("1?:&]R9&5?<V-R:7!T7V9I;&5S.PH@("`@
M("`@("`@("`D7VAO<F1E7W-C<FEP=%]F:6QE<ULD87!P75M=(#T@87)R87DH
M)&9I;&4L("1D:7)E8W0I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($EN8VQU9&5S(&IA=F%S8W)I<'0@9FEL97,@=&AA="!W97)E(&YE961E
M9"!B969O<F4@86YY(&AE861E<G,@=V5R92!S96YT+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!I;F-L=61E4V-R:7!T1FEL97,H*0H@("`@>PH@("`@("`@(&=L
M;V)A;"`D7VAO<F1E7W-C<FEP=%]F:6QE<RP@)')E9VES=')Y.PH*("`@("`@
M("`O*B!)9B!T:&5R92!I<R!N;R!J879A<V-R:7!T(&%V86EL86)L92P@=&AE
M<F4G<R!N;R!P;VEN="!I;B!I;F-L=61I;F<*("`@("`@("`@*B!T:&4@<F5S
M="!O9B!T:&4@9FEL97,N("HO"B`@("`@("`@:68@*"$D1TQ/0D%,4ULG8G)O
M=W-E<B==+3YH87-&96%T=7)E*"=J879A<V-R:7!T)RDI('L*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@+RH@061D(&=E;F5R86P@
M54D@:G,@;&EB<F%R>2X@*B\*("`@("`@("!(;W)D93HZ861D4V-R:7!T1FEL
M92@G:&]R9&4N:G,G+"`G:&]R9&4G+"!T<G5E*3L*("`@("`@("!I9B`H)$=,
M3T)!3%-;)V)R;W=S97(G72T^:&%S475I<FLH)W=I;F1O=V5D7V-O;G1R;VQS
M)RDI('L*("`@("`@("`@("`@+RH@1FEX97,@9F]R($E%('1H870@8V%N)W0@
M96%S:6QY(&)E(&1O;F4@=VET:&]U="!B<F]W<V5R"B`@("`@("`@("`@("`J
M(&1E=&5C=&EO;BX@*B\*("`@("`@("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I
M;&4H)VAO<F1E+FEE+FIS)RP@)VAO<F1E)RP@=')U92D["B`@("`@("`@?0H*
M("`@("`@("!I9B`H(65M<'1Y*"1?:&]R9&5?<V-R:7!T7V9I;&5S*2D@>PH@
M("`@("`@("`@("`D8F%S95]U<FP@/2!(;W)D93HZ=7)L*"1R96=I<W1R>2T^
M9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G+W-E<G9I8V5S+VIA=F%S8W)I
M<'0N<&AP)RD["B`@("`@("`@("`@(&9O<F5A8V@@*"1?:&]R9&5?<V-R:7!T
M7V9I;&5S(&%S("1A<'`@/3X@)&9I;&5S*2!["B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D9FEL97,@87,@)&9I;&4I('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1F:6QE6S%=*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=7)L(#T@)&9I;&5;,%U[,'T@/3T@)R\G(#\@)')E9VES=')Y+3YG
M970H)W=E8G)O;W0G+"`D87!P*2`N("1F:6QE6S!=(#H@)')E9VES=')Y+3YG
M970H)VIS=7)I)RP@)&%P<"D@+B`G+R<@+B`D9FEL95LP73L*("`@("`@("`@
M("`@("`@("`@("`@("`@96-H;R`G/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S
M8W)I<'0B('-R8STB)R`N($AO<F1E.CIU<FPH)'5R;"D@+B`B7"(^/"]S8W)I
M<'0^7&XB.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)&)A
M<V5?=7)L+"!A<G)A>2@G9FEL92<@/3X@)&9I;&5;,%TL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G87!P)R`@/3X@)&%P<"DI.PH@("`@("`@("`@("`@("`@
M("`@("`@("!E8VAO("<\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(@
M<W)C/2(G("X@)'5R;"`N(")<(CX\+W-C<FEP=#Y<;B(["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@26YC;'5D97,@:F%V87-C
M<FEP="!F:6QE<R!T:&%T('=E<F4@;F5E9&5D(&)E9F]R92!A;GD@:&5A9&5R
M<R!W97)E('-E;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN;&EN95-C<FEP
M=$9I;&5S*"D*("`@('L*("`@("`@("!G;&]B86P@)%]H;W)D95]S8W)I<'1?
M9FEL97,L("1R96=I<W1R>3L*"B`@("`@("`@:68@*"%E;7!T>2@D7VAO<F1E
M7W-C<FEP=%]F:6QE<RDI('L*("`@("`@("`@("`@)&IS5W)A<'!E<B`]("1R
M96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("=H;W)D92<I("X@)R]S97)V:6-E
M<R]J879A<V-R:7!T+G!H<"<["B`@("`@("`@("`@(&9O<F5A8V@@*"1?:&]R
M9&5?<V-R:7!T7V9I;&5S(&%S("1A<'`@/3X@)&9I;&5S*2!["B`@("`@("`@
M("`@("`@("!F;W)E86-H("@D9FEL97,@87,@)&9I;&4I('L*("`@("`@("`@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1F:6QE6S%=*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!`<F5A9&9I;&4H)&9I;&5;,%U[,'T@/3T@)R\G(#\@
M)')E9VES=')Y+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`D9FEL95LP72`Z
M("1R96=I<W1R>2T^9V5T*"=J<V9S)RP@)&%P<"D@+B`G+R<@+B`D9FEL95LP
M72D["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&9I;&4@/2`D9FEL95LP73L*("`@("`@("`@("`@("`@
M("`@("`@("`@<F5Q=6ER92`D:G-7<F%P<&5R.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!I9B!L:6YK('-H;W5L
M9"!B92!S:&]W;B!A;F0@<F5T=7)N('1H92!N97-C97-S87)Y(&-O9&4N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'1Y<&4@("`@("!4>7!E(&]F
M(&QI;FL@=&\@9&ES<&QA>0H@("`@("H@0'!A<F%M('-T<FEN9R`@)&%P<"`@
M("`@("!4:&4@;F%M92!O9B!T:&4@8W5R<F5N="!(;W)D92!A<'!L:6-A=&EO
M;BX*("`@("`J($!P87)A;2!B;V]L96%N("1O=F5R<FED92`@3W9E<G)I9&4@
M2&]R9&4@<V5T=&EN9W,_"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<F5F97)R
M97(@($EN8VQU9&4@=&AE(&-U<G)E;G0@<&%G92!A<R!T:&4@<F5F97)R97(@
M*'5R;#TI/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@2%1-
M3"!T;R!C<F5A=&4@=&AE(&QI;FLN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%-E<G9I8V5,:6YK*"1T>7!E+"`D87!P+"`D;W9E<G)I9&4@/2!F86QS92P@
M)')E9F5R<F5R(#T@=')U92D*("`@('L*("`@("`@("!I9B`H(4AO<F1E.CIS
M:&]W4V5R=FEC92@D='EP92D@)B8@(21O=F5R<FED92D@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!S=VET8V@@*"1T
M>7!E*2!["B`@("`@("`@8V%S92`G:&5L<"<Z"B`@("`@("`@("`@(&EF("@D
M1TQ/0D%,4ULG8G)O=W-E<B==+3YH87-&96%T=7)E*"=J879A<V-R:7!T)RDI
M('L*("`@("`@("`@("`@("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"=P;W!U
M<"YJ<R<L("=H;W)D92<L('1R=64I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1U<FP@/2!(;W)D93HZ=7)L*"1'3$]"04Q36R=R96=I<W1R>2==+3YG
M970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<V5R=FEC97,O:&5L<"\G+"!T
M<G5E*3L*("`@("`@("`@("`@<F5T=7)N(%5T:6PZ.F%D9%!A<F%M971E<B@D
M=7)L+"`G;6]D=6QE)RP@)&%P<"D["@H@("`@("`@(&-A<V4@)W!R;V)L96TG
M.@H@("`@("`@("`@("!R971U<FX@2&]R9&4Z.G5R;"@D1TQ/0D%,4ULG<F5G
M:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G+W-E<G9I8V5S
M+W!R;V)L96TN<&AP/W)E='5R;E]U<FP])R`N('5R;&5N8V]D92A(;W)D93HZ
M<V5L9E5R;"AT<G5E+"!T<G5E+"!T<G5E*2DI.PH*("`@("`@("!C87-E("=L
M;V=O=70G.@H@("`@("`@("`@("!R971U<FX@2&]R9&4Z.G5R;"A!=71H.CIA
M9&1,;V=O=71087)A;65T97)S*"1'3$]"04Q36R=R96=I<W1R>2==+3YG970H
M)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O;&]G:6XN<&AP)RP@05542%]214%3
M3TY?3$]'3U54*2D["@H@("`@("`@(&-A<V4@)VQO9VEN)SH*("`@("`@("`@
M("`@<F5T=7)N($%U=&@Z.F=E=$QO9VEN4V-R965N*"<G+"`D<F5F97)R97(@
M/R!(;W)D93HZ<V5L9E5R;"AT<G5E*2`Z(&YU;&PI.PH*("`@("`@("!C87-E
M("=O<'1I;VYS)SH*("`@("`@("`@("`@9VQO8F%L("1C;VYF.PH@("`@("`@
M("`@("!I9B`H*"1C;VYF6R=P<F5F<R==6R=D<FEV97(G72`A/2`G)RD@)B8@
M*"1C;VYF6R=P<F5F<R==6R=D<FEV97(G72`A/2`G;F]N92<I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@2&]R9&4Z.G5R;"@D1TQ/0D%,4ULG<F5G:7-T
M<GDG72T^9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G+W-E<G9I8V5S+W!R
M969S+G!H<#]A<'`])R`N("1A<'`I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@5&AE
M('1Y<&4@;V8@;&EN:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@:68@=&AE(&QI;FL@:7,@=&\@8F4@<VAO=VXN"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-H;W=397)V:6-E*"1T>7!E*0H@("`@>PH@("`@("`@(&=L
M;V)A;"`D8V]N9CL*"B`@("`@("`@:68@*&5M<'1Y*"1C;VYF6R=M96YU)UU;
M)VQI;FMS)UU;)'1Y<&5=*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("!S=VET8V@@*"1C;VYF6R=M96YU)UU;)VQI
M;FMS)UU;)'1Y<&5=*2!["B`@("`@("`@8V%S92`G86QL)SH*("`@("`@("`@
M("`@<F5T=7)N('1R=64["@H@("`@("`@(&-A<V4@)VYE=F5R)SH*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH*("`@("`@("!C87-E("=A=71H96YT:6-A
M=&5D)SH*("`@("`@("`@("`@<F5T=7)N("AB;V]L*4%U=&@Z.F=E=$%U=&@H
M*3L*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M(&1R:79E<B!P87)A;65T97)S(&9O<B!T:&4@<W!E8VEF:65D(&)A8VME;F0N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1B86-K96YD("!4:&4@8F%C
M:V5N9"!S>7-T96T@*&4N9RX@)W!R969S)RP@)V-A=&5G;W)I97,G+`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`G8V]N=&%C=',G*2!B96EN9R!U
M<V5D+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!4:&4@=7-E9"!C
M;VYF:6=U<F%T:6]N(&%R<F%Y('=I;&P@8F4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@)&-O;F9;)&)A8VME;F1=+B!)9B!A;B!A<G)A>2!G971S
M('!A<W-E9"P@:70@=VEL;`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("!B92`D8V]N9ELD:V5Y,5U;)&ME>3)=+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D='EP92`@("!4:&4@='EP92!O9B!D<FEV97(N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@5&AE(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T1')I=F5R0V]N9FEG*"1B86-K96YD+"`D
M='EP92`]("=S<6PG*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@
M("`@("`@)&,@/2!N=6QL.PH@("`@("`@(&EF("AI<U]A<G)A>2@D8F%C:V5N
M9"DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]!<G)A>2YP
M:'`G.PH@("`@("`@("`@("`D8R`]($AO<F1E7T%R<F%Y.CIG971%;&5M96YT
M*"1C;VYF+"`D8F%C:V5N9"D["B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1C
M;VYF6R1B86-K96YD72DI('L*("`@("`@("`@("`@)&,@/2`D8V]N9ELD8F%C
M:V5N9%T["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-?;G5L;"@D8RD@)B8@
M:7-S970H)&-;)W!A<F%M<R==*2D@>PH@("`@("`@("`@("!I9B`H:7-S970H
M)&-O;F9;)'1Y<&5=*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y
M7VUE<F=E*"1C;VYF6R1T>7!E72P@)&-;)W!A<F%M<R==*3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B`D8ULG<&%R86US
M)UT["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!I
M<W-E="@D8V]N9ELD='EP95TI(#\@)&-O;F9;)'1Y<&5=(#H@87)R87DH*3L*
M("`@('T*"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!61E,@9')I=F5R
M('!A<F%M971E<G,@9F]R('1H92!S<&5C:69I960@8F%C:V5N9"X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@5D93('-Y<W1E;2!N
M86UE("AE+F<N("=I;6%G97,G+"`G9&]C=6UE;G1S)RD*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@(&)E:6YG('5S960N"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@02!H87-H('=I=&@@=&AE(%9&4R!P87)A;65T97)S.R!T
M:&4@5D93(&1R:79E<B!I;B`G='EP92<*("`@("`J("`@("`@("`@("`@("`@
M(&%N9"!T:&4@8V]N;F5C=&EO;B!P87)A;65T97)S(&EN("=P87)A;7,G+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G97161E-#;VYF:6<H)&YA;64I"B`@("![
M"B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("!I9B`H(6ES<V5T*"1C
M;VYF6R1N86UE75LG='EP92==*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C
M:V5N9"XB*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H)&-O;F9;)&YA;65=
M6R=T>7!E)UT@/3T@)VAO<F1E)RD@>PH@("`@("`@("`@("`D=F9S(#T@)&-O
M;F9;)W9F<R==.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1V9G,@
M/2`D8V]N9ELD;F%M95T["B`@("`@("`@?0H*("`@("`@("!I9B`H)'9F<ULG
M='EP92==(#T]("=S<6PG*2!["B`@("`@("`@("`@("1V9G-;)W!A<F%M<R==
M(#T@2&]R9&4Z.F=E=$1R:79E<D-O;F9I9R@D;F%M92P@)W-Q;"<I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1V9G,["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#:&5C:W,@:68@86QL(&YE8V5S<V%R>2!P87)A;65T97)S(&9O<B!A
M(&1R:79E<B!C;VYF:6=U<F%T:6]N"B`@("`@*B!A<F4@<V5T(&%N9"!T:')O
M=W,@82!F871A;"!E<G)O<B!W:71H(&$@9&5T86EL960@97AP;&%I;F%T:6]N
M"B`@("`@*B!H;W<@=&\@9FEX('1H:7,L(&EF('-O;65T:&EN9R!I<R!M:7-S
M:6YG+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@("!4
M:&4@8V]N9FEG=7)A=&EO;B!A<G)A>2!W:71H(&%L;"!P87)A;65T97)S+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9')I=F5R("`@(%1H92!K97D@;F%M92`H
M:6X@=&AE(&-O;F9I9W5R871I;VX@87)R87DI(&]F"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@=&AE(&1R:79E<BX*("`@("`J($!P87)A;2!A
M<G)A>2`D9FEE;&1S("`@("!!;B!A<G)A>2!W:71H(&UA;F1A=&]R>2!P87)A
M;65T97(@;F%M97,@9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@=&AI<R!D<FEV97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@
M("`@5&AE(&-L96%R('1E>'0@;F%M92!O9B!T:&4@9')I=F5R+B!)9B!N;W0*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!S<&5C:69I960L('1H
M92!A<'!L:6-A=&EO;B!N86UE('=I;&P@8F4@=7-E9"X*("`@("`J($!P87)A
M;2!S=')I;F<@)&9I;&4@("`@("!4:&4@8V]N9FEG=7)A=&EO;B!F:6QE('1H
M870@<VAO=6QD(&-O;G1A:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("!T:&5S92!S971T:6YG<RX*("`@("`J($!P87)A;2!S=')I;F<@)'9A
M<FEA8FQE("!4:&4@;F%M92!O9B!T:&4@8V]N9FEG=7)A=&EO;B!V87)I86)L
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@87-S97)T1')I=F5R0V]N9FEG*"1P
M87)A;7,L("1D<FEV97(L("1F:65L9',L("1N86UE(#T@;G5L;"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEL92`]("=C;VYF+G!H<"<L
M("1V87)I86)L92`]("<D8V]N9B<I"B`@("!["B`@("`@("`@9VQO8F%L("1R
M96=I<W1R>3L*"B`@("`@("`@+R\@1&]N)W0@9V5N97)A=&4@82!F871A;"!E
M<G)O<B!I9B!W92!F86EL(&1U<FEN9R!O<B!B969O<F4*("`@("`@("`O+R!2
M96=I<W1R>2!I;G-T86YT:6%T:6]N+@H@("`@("`@(&EF("AI<U]N=6QL*"1N
M86UE*2D@>PH@("`@("`@("`@("`D;F%M92`](&ES<V5T*"1R96=I<W1R>2D@
M/R`D<F5G:7-T<GDM/F=E=$%P<"@I(#H@)UMU;FMN;W=N72<["B`@("`@("`@
M?0H@("`@("`@("1F:6QE<F]O="`](&ES<V5T*"1R96=I<W1R>2D@/R`D<F5G
M:7-T<GDM/F=E="@G9FEL97)O;W0G*2`Z("<G.PH*("`@("`@("!I9B`H(6ES
M7V%R<F%Y*"1P87)A;7,I('Q\("%C;W5N="@D<&%R86US*2D@>PH@("`@("`@
M("`@("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I<V5%<G)O<B@*("`@("`@("`@
M("`@("`@('-P<FEN=&8H7R@B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R("5S+B(I+"`D;F%M92D@+B`B7&Y<;B(@+@H@("`@
M("`@("`@("`@("`@<W!R:6YT9BA?*")4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!S;VUE("5S('-E='1I;F=S+B(I+`H@("`@("`@("`@("`@("`@("`@
M("1F:6QE<F]O="`N("<O8V]N9FEG+R<@+B`D9FEL92P*("`@("`@("`@("`@
M("`@("`@("!S<')I;G1F*"(E<ULG)7,G75LG<&%R86US)UTB+"`D=F%R:6%B
M;&4L("1D<FEV97(I*2DL"B`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)&9I96QD<R!A
M<R`D9FEE;&0I('L*("`@("`@("`@("`@:68@*"%I<W-E="@D<&%R86US6R1F
M:65L9%TI*2!["B`@("`@("`@("`@("`@("!(;W)D93HZ9F%T86PH4$5!4CHZ
M<F%I<V5%<G)O<B@*("`@("`@("`@("`@("`@("`@("!S<')I;G1F*%\H(E)E
M<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I
M;VXN(BDL("1F:65L9"P@)&YA;64I("X@(EQN7&XB("X*("`@("`@("`@("`@
M("`@("`@("!S<')I;G1F*%\H(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN
M(&$@)7,@<V5T=&EN9RXB*2P*("`@("`@("`@("`@("`@("`@("`@("`@)&9I
M;&5R;V]T("X@)R]C;VYF:6<O)R`N("1F:6QE+`H@("`@("`@("`@("`@("`@
M("`@("`@("!S<')I;G1F*"(E<ULG)7,G75LG<&%R86US)UU;)R5S)UTB+"`D
M=F%R:6%B;&4L("1D<FEV97(L("1F:65L9"DI*2P*("`@("`@("`@("`@("`@
M("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('-E<W-I;VXM
M:60M:69I960@=F5R<VEO;B!O9B`D=7)I+@H@("`@("H@268@82!F=6QL(%52
M3"!I<R!R97%U97-T960L(&%L;"!P87)A;65T97(@<V5P87)A=&]R<R!G970@
M8V]N=F5R=&5D('1O"B`@("`@*B`B)B(L(&]T:&5R=VES92!T;R`B)F%M<#LB
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5R:2`@("`@("`@("`@
M("`@5&AE(%5222!T;R!B92!M;V1I9FEE9"X*("`@("`J($!P87)A;2!B;V]L
M96%N("1F=6QL("`@("`@("`@("`@1V5N97)A=&4@82!F=6QL("AH='1P.B\O
M<V5R=F5R+W!A=&@O*0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!54DPN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D87!P96YD7W-E
M<W-I;VX@(#`@/2!O;FQY(&EF(&YE961E9"P@,2`](&%L=V%Y<RP@+3$@/0H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N979E<BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(%523"!W:71H('1H
M92!S97-S:6]N(&ED(&%P<&5N9&5D("AI9B!N965D960I+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!U<FPH)'5R:2P@)&9U;&P@/2!F86QS92P@)&%P<&5N9%]S
M97-S:6]N(#T@,"P@)&9O<F-E7W-S;"`](&9A;'-E*0H@("`@>PH@("`@("`@
M(&EF("@D9F]R8V5?<W-L*2!["B`@("`@("`@("`@("1F=6QL(#T@=')U93L*
M("`@("`@("!]"@H@("`@("`@(&EF("@D9G5L;"D@>PH@("`@("`@("`@("!G
M;&]B86P@)&-O;F8L("1R96=I<W1R>2P@)&)R;W=S97(["@H@("`@("`@("`@
M("`O*B!3=&]R92!C;VYN96-T:6]N('!A<F%M971E<G,@:6X@;&]C86P@=F%R
M:6%B;&5S+B`J+PH@("`@("`@("`@("`D<V5R=F5R7VYA;64@/2`D8V]N9ELG
M<V5R=F5R)UU;)VYA;64G73L*("`@("`@("`@("`@)'-E<G9E<E]P;W)T(#T@
M)&-O;F9;)W-E<G9E<B==6R=P;W)T)UT["@H@("`@("`@("`@("`D<')O=&]C
M;VP@/2`G:'1T<"<["B`@("`@("`@("`@(&EF("@D8V]N9ELG=7-E7W-S;"==
M(#T](#$I('L*("`@("`@("`@("`@("`@("1P<F]T;V-O;"`]("=H='1P<R<[
M"B`@("`@("`@("`@('T@96QS96EF("@D8V]N9ELG=7-E7W-S;"==(#T](#(@
M)B8*("`@("`@("`@("`@("`@("`@("`@("1B<F]W<V5R+3YU<VEN9U-33$-O
M;FYE8W1I;VXH*2D@>PH@("`@("`@("`@("`@("`@)'!R;W1O8V]L(#T@)VAT
M='!S)SL*("`@("`@("`@("`@?2!E;'-E:68@*"1C;VYF6R=U<V5?<W-L)UT@
M/3T@,RD@>PH@("`@("`@("`@("`@("`@)'-E<G9E<E]P;W)T(#T@)R<["B`@
M("`@("`@("`@("`@("!I9B`H)&9O<F-E7W-S;"D@>PH@("`@("`@("`@("`@
M("`@("`@("1P<F]T;V-O;"`]("=H='1P<R<["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($EF('5S:6YG(&YO;BUS
M=&%N9&%R9"!P;W)T<RP@861D('1H92!P;W)T('1O('1H92!54DPN("HO"B`@
M("`@("`@("`@(&EF("@A96UP='DH)'-E<G9E<E]P;W)T*2`F)@H@("`@("`@
M("`@("`@("`@*"@H)'!R;W1O8V]L(#T]("=H='1P)RD@)B8@*"1S97)V97)?
M<&]R="`A/2`X,"DI('Q\"B`@("`@("`@("`@("`@("`@*"@D<')O=&]C;VP@
M/3T@)VAT='!S)RD@)B8@*"1S97)V97)?<&]R="`A/2`T-#,I*2DI('L*("`@
M("`@("`@("`@("`@("1S97)V97)?;F%M92`N/2`G.B<@+B`D<V5R=F5R7W!O
M<G0["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J(%-T;W)E('1H92!W
M96)R;V]T(&EN(&$@;&]C86P@=F%R:6%B;&4N("HO"B`@("`@("`@("`@("1W
M96)R;V]T(#T@)')E9VES=')Y+3YG970H)W=E8G)O;W0G*3L*"B`@("`@("`@
M("`@("1U<FP@/2`D<')O=&]C;VP@+B`G.B\O)R`N("1S97)V97)?;F%M93L*
M("`@("`@("`@("`@:68@*'-U8G-T<B@D=7)I+"`P+"`Q*2`A/2`G+R<I('L*
M("`@("`@("`@("`@("`@(&EF("AS=6)S='(H)'=E8G)O;W0L("TQ*2`]/2`G
M+R<I('L*("`@("`@("`@("`@("`@("`@("`D=7)L("X]("1W96)R;V]T("X@
M)'5R:3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@)'5R;"`N/2`D=V5B<F]O="`N("<O)R`N("1U<FD["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D=7)L("X]("1U<FD["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=7)L(#T@)'5R:3L*("`@("`@("!]"@H@("`@("`@
M(&EF("AE;7!T>2@D1TQ/0D%,4ULG8V]N9B==6R=S97-S:6]N)UU;)W5S95]O
M;FQY7V-O;VMI97,G72D@)B8*("`@("`@("`@("`@*"@D87!P96YD7W-E<W-I
M;VX@/3T@,2D@?'P*("`@("`@("`@("`@("@H)&%P<&5N9%]S97-S:6]N(#T]
M(#`I("8F"B`@("`@("`@("`@("`@(6ES<V5T*"1?0T]/2TE%6W-E<W-I;VY?
M;F%M92@I72DI*2D@>PH@("`@("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R
M86UE=&5R*"1U<FPL('-E<W-I;VY?;F%M92@I+"!S97-S:6]N7VED*"DI.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"1F=6QL*2!["B`@("`@("`@("`@("\J
M(%=E(&YE960@=&\@<G5N('1H92!R97!L86-E('1W:6-E+"!B96-A=7-E('=E
M(&]N;'D@8V%T8V@@979E<GD*("`@("`@("`@("`@("H@<V5C;VYD(&UA=&-H
M+B`J+PH@("`@("`@("`@("!R971U<FX@<')E9U]R97!L86-E*&%R<F%Y*"<O
M*#T_+BH_*29A;7`[*"XJ/STI+R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)R\H/3\N*C\I)F%M<#LH+BH_/2DO)RDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)R0Q)B0R)RP@)'5R;"D["B`@
M("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)R\]+BHF86UP.RXJ/2\G+"`D
M=7)L*2D@>PH@("`@("`@("`@("!R971U<FX@)'5R;#L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R971U<FX@:'1M;&5N=&ET:65S*"1U<FPI.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!S97-S
M:6]N+6ED+6EF:65D('9E<G-I;VX@;V8@)'5R:2P@=7-I;F<@=&AE(&-U<G)E
M;G0*("`@("`J(&%P<&QI8V%T:6]N)W,@=V5B<F]O="!S971T:6YG+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'5R:2`@("`@("`@("`@("`@5&AE
M(%5222!T;R!B92!M;V1I9FEE9"X*("`@("`J($!P87)A;2!B;V]L96%N("1F
M=6QL("`@("`@("`@("`@1V5N97)A=&4@82!F=6QL("AH='1P.B\O<V5R=F5R
M+W!A=&@O*0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!54DPN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D87!P96YD7W-E<W-I;VX@
M(#`@/2!O;FQY(&EF(&YE961E9"P@,2`](&%L=V%Y<RP@+3$@/0H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N979E<BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('5R;"!W:71H('1H92!S97-S
M:6]N(&ED(&%P<&5N9&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!A<'!L:6-A
M=&EO;E5R;"@D=7)I+"`D9G5L;"`](&9A;'-E+"`D87!P96YD7W-E<W-I;VX@
M/2`P*0H@("`@>PH@("`@("`@(&EF("@D9G5L;"D@>PH@("`@("`@("`@("!R
M971U<FX@2&]R9&4Z.G5R;"@D=7)I+"`D9G5L;"P@)&%P<&5N9%]S97-S:6]N
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("AS=6)S='(H)'5R:2P@,"P@,2D@
M(3T@)R\G*2!["B`@("`@("`@("`@("1W96)R;V]T(#T@)$=,3T)!3%-;)W)E
M9VES=')Y)UTM/F=E="@G=V5B<F]O="<I.PH@("`@("`@("`@("!I9B`H<W5B
M<W1R*"1W96)R;V]T+"`M,2D@(3T@)R\G*2!["B`@("`@("`@("`@("`@("`D
M=V5B<F]O="`N/2`G+R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'5R
M:2`]("1W96)R;V]T("X@)'5R:3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!(;W)D93HZ=7)L*"1U<FDL("1F=6QL+"`D87!P96YD7W-E<W-I;VXI.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!E>'1E<FYA;"!L:6YK
M('!A<W-E9"!T:')O=6=H('1H92!D97)E9F5R<F5R('1O('-T<FEP('-E<W-I
M;VX*("`@("`J($E$<R!F<F]M('1H92!R969E<G)E<BX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1U<FP@("!4:&4@97AT97)N86P@55),('1O(&QI
M;FL@=&\N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D=&%G("!)9B!T<G5E+"!A
M(&-O;7!L971E(#QA/B!T86<@:7,@<F5T=7)N960L(&]N;'D@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("!U<FP@;W1H97)W:7-E+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]R<F5C="!L:6YK('1O('1H
M92!D97)E9F5R<F5R('-C<FEP="X*("`@("`J+PH@("`@9G5N8W1I;VX@97AT
M97)N86Q5<FPH)'5R;"P@)'1A9R`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF
M("AI<W-E="@D7T-/3TM)15MS97-S:6]N7VYA;64H*5TI*2!["B`@("`@("`@
M("`@("1E>'0@/2`D=7)L.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1E>'0@/2!(;W)D93HZ=7)L*"1'3$]"04Q36R=R96=I<W1R>2==+3YG970H
M)W=E8G)O;W0G+"`G:&]R9&4G*2`N"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("<O<V5R=FEC97,O9V\N<&AP)RP@=')U92P@+3$I.PH*("`@("`@
M("`@("`@+RH@5V4@;75S="!M86ME('-U<F4@=&AE<F4@87)E(&YO("9A;7`G
M<R!I;B!T:&4@55),+B`J+PH@("`@("`@("`@("`D=7)L(#T@<')E9U]R97!L
M86-E*&%R<F%Y*"<O*#T_+BH_*29A;7`[*"XJ/STI+R<L("<O*#T_+BH_*29A
M;7`[*"XJ/STI+R<I+"`G)#$F)#(G+"`D=7)L*3L*("`@("`@("`@("`@)&5X
M="`](%5T:6PZ.F%D9%!A<F%M971E<B@D97AT+"`G=7)L)RP@)'5R;"D["B`@
M("`@("`@?0H@("`@("`@(&EF("@D=&%G*2!["B`@("`@("`@("`@("1E>'0@
M/2!(;W)D93HZ;&EN:R@D97AT+"`D=7)L+"`G)RP@)U]B;&%N:R<I.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)&5X=#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@82!54DP@=&\@8F4@=7-E9"!F;W(@9&]W;FQO861I;F<L
M('1H870@=&%K97,@:6YT;R!A8V-O=6YT(&%N>0H@("`@("H@<W!E8VEA;"!B
M<F]W<V5R('%U:7)K<R`H:2YE+B!)12=S(&)R;VME;B!F:6QE;F%M92!H86YD
M;&EN9RDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL96YA;64@
M(%1H92!F:6QE;F%M92!O9B!T:&4@9&]W;FQO860@9&%T82X*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R86US("`@("!!;GD@861D:71I;VYA;"!P87)A;65T
M97)S(&YE961E9"X*("`@("`J($!P87)A;2!S=')I;F<@)'5R;"`@("`@("!4
M:&4@55),('1O(&%L=&5R+B!)9B!N;VYE('!A<W-E9"!I;BP@=VEL;"!U<V4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@9FEL92`G=FEE
M=RYP:'`G(&QO8V%T960@:6X@=&AE(&-U<G)E;G0*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("!M;V1U;&4G<R!B87-E(&1I<F5C=&]R>2X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&1O=VYL;V%D(%523"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9&]W;FQO8615<FPH)&9I;&5N86UE+"`D
M<&%R86US(#T@87)R87DH*2P@)'5R;"`](&YU;&PI"B`@("!["B`@("`@("`@
M9VQO8F%L("1B<F]W<V5R.PH*("`@("`@("`D:&]R9&5?=7)L(#T@9F%L<V4[
M"@H@("`@("`@(&EF("AI<U]N=6QL*"1U<FPI*2!["B`@("`@("`@("`@(&=L
M;V)A;"`D<F5G:7-T<GD["B`@("`@("`@("`@("1U<FP@/2!5=&EL.CIA9&10
M87)A;65T97(H2&]R9&4Z.G5R;"@D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L
M("=H;W)D92<I("X@)R]S97)V:6-E<R]D;W=N;&]A9"\G*2P@)VUO9'5L92<L
M("1R96=I<W1R>2T^9V5T07!P*"DI.PH@("`@("`@("`@("`D:&]R9&5?=7)L
M(#T@=')U93L*("`@("`@("!]"@H@("`@("`@("\J($%D9"!P87)A;65T97)S
M+B`J+PH@("`@("`@(&EF("@A:7-?;G5L;"@D<&%R86US*2D@>PH@("`@("`@
M("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL("1P87)A;7,I
M.PH@("`@("`@('T*"B`@("`@("`@+RH@268@=V4@87)E('5S:6YG('1H92!D
M969A=6QT($AO<F1E(&1O=VYL;V%D(&QI;FLL(&%D9"!T:&4*("`@("`@("`@
M*B!F:6QE;F%M92!T;R!T:&4@96YD(&]F('1H92!54DPN($%L=&AO=6=H(&YO
M="!N96-E<W-A<GD@9F]R"B`@("`@("`@("H@;6%N>2!B<F]W<V5R<RP@=&AI
M<R!S:&]U;&0@86QL;W<@979E<GD@8G)O=W-E<B!T;R!D;W=N;&]A9`H@("`@
M("`@("`J(&-O<G)E8W1L>2X@*B\*("`@("`@("!I9B`H)&AO<F1E7W5R;"D@
M>PH@("`@("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL
M("=F;B<L("<O)R`N(')A=W5R;&5N8V]D92@D9FEL96YA;64I*3L*("`@("`@
M("!](&5L<V5I9B`H)&)R;W=S97(M/FAA<U%U:7)K*"=B<F5A:U]D:7-P;W-I
M=&EO;E]F:6QE;F%M92<I*2!["B`@("`@("`@("`@("\J(%-O;64@8G)O=W-E
M<G,@=VEL;"!O;FQY(&]B=&%I;B!T:&4@9FEL96YA;64@8V]R<F5C=&QY"B`@
M("`@("`@("`@("`J(&EF('1H92!E>'1E;G-I;VX@:7,@=&AE(&QA<W0@87)G
M=6UE;G0@:6X@=&AE('%U97)Y"B`@("`@("`@("`@("`J('-T<FEN9R!A;F0@
M<F5S="!O9B!T:&4@9FEL96YA;64@87!P96%R<R!I;B!T:&4*("`@("`@("`@
M("`@("H@4$%42%])3D9/(&5L96UE;G0N("HO"B`@("`@("`@("`@("1F:6QE
M;F%M92`](')A=W5R;&5N8V]D92@D9FEL96YA;64I.PH*("`@("`@("`@("`@
M+RH@1V5T('1H92!W96)S97)V97(@240N("HO"B`@("`@("`@("`@("1S97)V
M97(@/2!(;W)D93HZ=V5B4V5R=F5R240H*3L*"B`@("`@("`@("`@("\J($=E
M="!T:&4@;F%M92!A;F0@97AT96YS:6]N(&]F('1H92!F:6QE+B`@07!A8VAE
M(#(@9&]E<PH@("`@("`@("`@("`@*B!.3U0@<W5P<&]R="!0051(7TE.1D\@
M:6YF;W)M871I;VX@8F5I;F<@<&%S<V5D('1O('1H90H@("`@("`@("`@("`@
M*B!02%`@;6]D=6QE(&)Y(&1E9F%U;'0L('-O(&1I<V%B;&4@=&AA=`H@("`@
M("`@("`@("`@*B!F=6YC=&EO;F%L:71Y+B`J+PH@("`@("`@("`@("!I9B`H
M*"1S97)V97(@(3T@)V%P86-H93(G*2D@>PH@("`@("`@("`@("`@("`@:68@
M*"@D<&]S(#T@<W1R<G!O<R@D9FEL96YA;64L("<N)RDI*2!["B`@("`@("`@
M("`@("`@("`@("`@)&YA;64@/2`G+R<@+B!P<F5G7W)E<&QA8V4H)R]<+B\G
M+"`G)3)%)RP@<W5B<W1R*"1F:6QE;F%M92P@,"P@)'!O<RDI.PH@("`@("`@
M("`@("`@("`@("`@("1E>'0@/2!S=6)S='(H)&9I;&5N86UE+"`D<&]S*3L*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)&YA;64@/2`G+R<@+B`D9FEL96YA;64["B`@("`@("`@("`@("`@("`@("`@
M)&5X="`]("<G.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@
M("\J($5N=&5R('1H92!0051(7TE.1D\@:6YF;W)M871I;VXN("HO"B`@("`@
M("`@("`@("`@("!I9B`H*"1P;W,@/2!S=')P;W,H)'5R;"P@)S\G*2DI('L*
M("`@("`@("`@("`@("`@("`@("`D=7)L(#T@<W5B<W1R*"1U<FPL(#`L("1P
M;W,I("X@)&YA;64@+B!S=6)S='(H)'5R;"P@)'!O<RD["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1U<FP@+CT@)&YA
M;64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("\J($%P<&5N9"!T:&4@97AT96YS:6]N+"!I9B!I="!E>&ES=',N("HO
M"B`@("`@("`@("`@(&EF("@H)'-E<G9E<B`]/2`G87!A8VAE,B<I('Q\("%E
M;7!T>2@D97AT*2D@>PH@("`@("`@("`@("`@("`@)'5R;"`](%5T:6PZ.F%D
M9%!A<F%M971E<B@D=7)L+"`G9FY?97AT)RP@)R\G("X@)&9I;&5N86UE*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1U<FP[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%N8VAO<B!T86<@
M=VET:"!T:&4@<F5L979A;G0@<&%R86UE=&5R<PH@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'5R;"`@("`@("`@5&AE(&9U;&P@55),('1O(&)E(&QI
M;FME9"!T;RX*("`@("`J($!P87)A;2!S=')I;F<@)'1I=&QE("`@("`@5&AE
M(&QI;FL@=&ET;&4O9&5S8W)I<'1I;VXN"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1C;&%S<R`@("`@(%1H92!#4U,@8VQA<W,@;V8@=&AE(&QI;FLN"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T87)G970@("`@(%1H92!W:6YD;W<@=&%R9V5T
M('1O('!O:6YT('1O+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VYC;&EC:R`@
M("!*879A4V-R:7!T(&%C=&EO;B!F;W(@=&AE("=O;F-L:6-K)R!E=F5N="X*
M("`@("`J($!P87)A;2!S=')I;F<@)'1I=&QE,B`@("`@5&AE(&QI;FL@=&ET
M;&4@*'1O;VQT:7`I("AD97!R96-A=&5D("T@:G5S=`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("!U<V4@)'1I=&QE*2X*("`@("`J($!P87)A
M;2!S=')I;F<@)&%C8V5S<VME>2`@5&AE(&%C8V5S<R!K97D@=&\@=7-E+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1A='1R:6)U=&5S("!!;GD@;W1H97(@;F%M
M92]V86QU92!P86ER<R!T;R!A9&0@=&\@=&AE(#QA/@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("!T86<N"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D97-C87!E("`@(%=H971H97(@=&\@97-C87!E('-P96-I86P@8VAA<F%C
M=&5R<R!I;B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=&ET;&4@871T<FEB=71E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@9G5L;"`\82!H<F5F/B!T86<N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&QI;FLH)'5R;"P@)'1I=&QE(#T@)R<L("1C;&%S<R`]("<G+"`D=&%R9V5T
M(#T@)R<L("1O;F-L:6-K(#T@)R<L"B`@("`@("`@("`@("`@("`@("1T:71L
M93(@/2`G)RP@)&%C8V5S<VME>2`]("<G+"`D871T<FEB=71E<R`](&%R<F%Y
M*"DL"B`@("`@("`@("`@("`@("`@("1E<V-A<&4@/2!T<G5E*0H@("`@>PH@
M("`@("`@('-T871I8R`D8VAA<G-E=#L*("`@("`@("!I9B`H(6ES<V5T*"1C
M:&%R<V5T*2D@>PH@("`@("`@("`@("`D8VAA<G-E="`]($Y,4SHZ9V5T0VAA
M<G-E="@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D=&ET;&4R
M*2D@>PH@("`@("`@("`@("`D=&ET;&4@/2`D=&ET;&4R.PH@("`@("`@('T*
M"B`@("`@("`@)')E="`]("(\82!H<F5F/5PB)'5R;%PB(CL*("`@("`@("!I
M9B`H(65M<'1Y*"1O;F-L:6-K*2D@>PH@("`@("`@("`@("`D<F5T("X]("(@
M;VYC;&EC:SU<(B1O;F-L:6-K7"(B.PH@("`@("`@('T*("`@("`@("!I9B`H
M(65M<'1Y*"1C;&%S<RDI('L*("`@("`@("`@("`@)')E="`N/2`B(&-L87-S
M/5PB)&-L87-S7"(B.PH@("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1T
M87)G970I*2!["B`@("`@("`@("`@("1R970@+CT@(B!T87)G970]7"(D=&%R
M9V5T7"(B.PH@("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1T:71L92DI
M('L*("`@("`@("`@("`@:68@*"1E<V-A<&4I('L*("`@("`@("`@("`@("`@
M("1T:71L92`](&YL,F)R*$!H=&UL<W!E8VEA;&-H87)S*$!H=&UL<W!E8VEA
M;&-H87)S*"1T:71L92P@14Y47U%53U1%4RP@)&-H87)S970I+"!%3E1?455/
M5$53+"`D8VAA<G-E="DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1R
M970@+CT@)R!T:71L93TB)R`N("1T:71L92`N("<B)SL*("`@("`@("!]"B`@
M("`@("`@:68@*"%E;7!T>2@D86-C97-S:V5Y*2D@>PH@("`@("`@("`@("`D
M<F5T("X]("<@86-C97-S:V5Y/2(G("X@:'1M;'-P96-I86QC:&%R<R@D86-C
M97-S:V5Y*2`N("<B)SL*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1A
M='1R:6)U=&5S(&%S("1N86UE(#T^("1V86QU92D@>PH@("`@("`@("`@("`D
M<F5T("X]("<@)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&YA;64I("X@)STB)R`N
M(&AT;6QS<&5C:6%L8VAA<G,H)'9A;'5E*2`N("<B)SL*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`B)')E=#XB.PH@("`@?0H*("`@("\J*@H@("`@("H@
M57-E<R!$3TT@5&]O;'1I<',@=&\@9&ES<&QA>2!T:&4@)W1I=&QE)R!A='1R
M:6)U=&4@9F]R"B`@("`@*B!(;W)D93HZ;&EN:R@I(&-A;&QS+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'5R;"`@("`@("`@5&AE(&9U;&P@55),
M('1O(&)E(&QI;FME9"!T;PH@("`@("H@0'!A<F%M('-T<FEN9R`D<W1A='5S
M("`@("!4:&4@2F%V85-C<FEP="!M;W5S92UO=F5R('-T<FEN9PH@("`@("H@
M0'!A<F%M('-T<FEN9R`D8VQA<W,@("`@("!4:&4@0U-3(&-L87-S(&]F('1H
M92!L:6YK"B`@("`@*B!`<&%R86T@<W1R:6YG("1T87)G970@("`@(%1H92!W
M:6YD;W<@=&%R9V5T('1O('!O:6YT('1O+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;VYC;&EC:R`@("!*879A4V-R:7!T(&%C=&EO;B!F;W(@=&AE("=O;F-L
M:6-K)R!E=F5N="X*("`@("`J($!P87)A;2!S=')I;F<@)'1I=&QE("`@("`@
M5&AE(&QI;FL@=&ET;&4@*'1O;VQT:7`I+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D86-C97-S:V5Y("!4:&4@86-C97-S(&ME>2!T;R!U<V4N"B`@("`@*B!`
M<&%R86T@87)R87D@("1A='1R:6)U=&5S($%N>2!O=&AE<B!N86UE+W9A;'5E
M('!A:7)S('1O(&%D9"!T;R!T:&4@/&$^"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@('1A9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&9U;&P@/&$@:')E9CX@=&%G+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!L:6YK5&]O;'1I<"@D=7)L+"`D<W1A='5S(#T@)R<L("1C;&%S<R`]("<G
M+"`D=&%R9V5T(#T@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`D;VYC
M;&EC:R`]("<G+"`D=&ET;&4@/2`G)RP@)&%C8V5S<VME>2`]("<G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@)&%T=')I8G5T97,@/2!A<G)A>2@I*0H@
M("`@>PH@("`@("`@('-T871I8R`D8VAA<G-E=#L*("`@("`@("!I9B`H(6ES
M<V5T*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("`D8VAA<G-E="`]($Y,4SHZ
M9V5T0VAA<G-E="@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D
M=&ET;&4I*2!["B`@("`@("`@("`@("1T:71L92`]("<F;'0[<')E)F=T.R<@
M+B!P<F5G7W)E<&QA8V4H87)R87DH)R]<;B\G+"`G+R@H/SPA/&)R*5QS>S$L
M?2@_/"%<+SXI*2]E;2<L("<O/&)R(%PO/CQB<B!<+SXO)RP@)R\\8G(@7"\^
M+R<I+"!A<G)A>2@G)RP@)W-T<E]R97!E870H(B9N8G-P.R(L('-T<FQE;B@B
M)#$B*2DG+"`G)FQT.V)R("\F9W0[("9L=#MB<B`O)F=T.R<L("<F;'0[8G(@
M+R9G=#LG*2P@;FPR8G(H0&AT;6QS<&5C:6%L8VAA<G,H0&AT;6QS<&5C:6%L
M8VAA<G,H)'1I=&QE+"!%3E1?455/5$53+"`D8VAA<G-E="DL($5.5%]154]4
M15,L("1C:&%R<V5T*2DI("X@)R9L=#LO<')E)F=T.R<["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!(;W)D93HZ;&EN:R@D=7)L+"`D=&ET;&4L("1C;&%S
M<RP@)'1A<F=E="P@)&]N8VQI8VLL(&YU;&PL("1A8V-E<W-K97DL("1A='1R
M:6)U=&5S+"!F86QS92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&%N(&%N8VAO<B!S97%U96YC92!W:71H('1H92!R96QE=F%N="!P87)A;65T
M97)S(&9O<B!A('=I9&=E=`H@("`@("H@=VET:"!A8V-E<W-K97D@86YD('1E
M>'0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("`D=7)L("`@("`@5&AE(&9U;&P@55),('1O(&)E
M(&QI;FME9"!T;RX*("`@("`J($!P87)A;2!S=')I;F<@("1T:71L92`@("!4
M:&4@;&EN:R!T:71L92]D97-C<FEP=&EO;BX*("`@("`J($!P87)A;2!S=')I
M;F<@("1C;&%S<R`@("!4:&4@0U-3(&-L87-S(&]F('1H92!L:6YK"B`@("`@
M*B!`<&%R86T@<W1R:6YG("`D=&%R9V5T("`@5&AE('=I;F1O=R!T87)G970@
M=&\@<&]I;G0@=&\N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D;VYC;&EC:R`@
M2F%V85-C<FEP="!A8W1I;VX@9F]R('1H92`G;VYC;&EC:R<@979E;G0N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("`D=&ET;&4R("`@5&AE(&QI;FL@=&ET;&4@
M*'1O;VQT:7`I("AD97!R96-A=&5D("T@:G5S="!U<V4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&ET;&4I+@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)&YO8VAE8VL@($1O;B=T(&-H96-K(&EF('1H92!A8V-E<W,@:V5Y
M(&%L<F5A9'D@:&%S(&)E96X*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("!U<V5D+B!$969A=6QT<R!T;R!F86QS92`H/2!C:&5C:RDN"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!F=6QL(#QA(&AR968^5&ET
M;&4\+V$^('-E<75E;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W:61G970H
M)'5R;"P@)'1I=&QE(#T@)R<L("1C;&%S<R`]("=W:61G970G+"`D=&%R9V5T
M(#T@)R<L"B`@("`@("`@("`@("`@("`@("`@)&]N8VQI8VL@/2`G)RP@)'1I
M=&QE,B`]("<G+"`D;F]C:&5C:R`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF
M("@A96UP='DH)'1I=&QE,BDI('L*("`@("`@("`@("`@)'1I=&QE(#T@)'1I
M=&QE,CL*("`@("`@("!]"@H@("`@("`@("1A:R`]($AO<F1E.CIG971!8V-E
M<W-+97DH)'1I=&QE+"`D;F]C:&5C:RD["@H@("`@("`@(')E='5R;B!(;W)D
M93HZ;&EN:R@D=7)L+"`G)RP@)&-L87-S+"`D=&%R9V5T+"`D;VYC;&EC:RP@
M)R<L("1A:RD@+B!(;W)D93HZ:&EG:&QI9VAT06-C97-S2V5Y*"1T:71L92P@
M)&%K*2`N("<\+V$^)SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M82!S97-S:6]N+6ED+6EF:65D('9E<G-I;VX@;V8@)%-#4DE05%].04U%(')E
M<W`N("102%!?4T5,1BX*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M<V-R:7!T7W!A<F%M<R!);F-L=61E('-C<FEP="!P87)A;65T97)S(&QI:V4@
M455%4EE?4U1224Y'(&%N9"!0051(7TE.1D\_"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D;F]C86-H92`@("`@("!);F-L=61E(&$@;F]C86-H92!P87)A;65T
M97(@:6X@=&AE(%523#\*("`@("`J($!P87)A;2!B;V]L96%N("1F=6QL("`@
M("`@("`@(%)E='5R;B!A(&9U;&P@55),/PH@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@<F5Q=65S=&5D(%5222X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5L9E5R;"@D<V-R:7!T7W!A<F%M<R`](&9A;'-E+"`D;F]C86-H
M92`]('1R=64L("1F=6QL(#T@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@
M("1F;W)C95]S<VP@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H<W5B<W1R
M*'!H<%]S87!I7VYA;64H*2P@,"P@,RD@/3T@)V-G:2<I('L*("`@("`@("`@
M("`@+R\@5VAE;B!U<VEN9R!#1TD@4$A0+"!30U))4%1?3D%-12!M87D@8V]N
M=&%I;B!T:&4@<&%T:"!T;PH@("`@("`@("`@("`O+R!T:&4@4$A0(&)I;F%R
M>2!I;G-T96%D(&]F('1H92!S8W)I<'0@8F5I;F<@<G5N.R!U<V4*("`@("`@
M("`@("`@+R\@4$A07U-%3$8@:6YS=&5A9"X*("`@("`@("`@("`@)'5R;"`]
M("1?4T525D526R=02%!?4T5,1B==.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1U<FP@/2!I<W-E="@D7U-%4E9%4ELG4T-225!47TY!344G72D@
M/PH@("`@("`@("`@("`@("`@)%]315)615);)U-#4DE05%].04U%)UT@.@H@
M("`@("`@("`@("`@("`@)%]315)615);)U!(4%]314Q&)UT["B`@("`@("`@
M?0H*("`@("`@("!I9B`H)'-C<FEP=%]P87)A;7,I('L*("`@("`@("`@("`@
M:68@*"%E;7!T>2@D7U-%4E9%4ELG4$%42%])3D9/)UTI*2!["B`@("`@("`@
M("`@("`@("`D=7)L("X]("1?4T525D526R=0051(7TE.1D\G73L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H(65M<'1Y*"1?4T525D526R=15452
M65]35%))3D<G72DI('L*("`@("`@("`@("`@("`@("1U<FP@+CT@)S\G("X@
M)%]315)615);)U%515)97U-44DE.1R==.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`D=7)L(#T@2&]R9&4Z.G5R;"@D=7)L+"`D9G5L;"P@
M,"P@)&9O<F-E7W-S;"D["@H@("`@("`@(&EF("@D;F]C86-H92D@>PH@("`@
M("`@("`@("!R971U<FX@571I;#HZ;F]C86-H955R;"@D=7)L*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'5R;#L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@8V]R<F5C=&QY
M+7!A=&AE9"!L:6YK('1O(&%N(&EM86=E+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'-R8R`@(%1H92!I;6%G92!F:6QE+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D86QT("`@5&5X="!D97-C<FEB:6YG('1H92!I;6%G92X*("`@
M("`J($!P87)A;2!M:7AE9"`@)&%T='(@($%N>2!A9&1I=&EO;F%L(&%T=')I
M8G5T97,@9F]R('1H92!I;6%G92!T86<N($-A;B!B90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@82!P<F4M8G5I;'0@<W1R:6YG(&]R(&%N(&%R<F%Y
M(&]F(&ME>2]V86QU92!P86ER<PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@=&AA="!W:6QL(&)E(&%S<V5M8FQE9"!A;F0@:'1M;"UE;F-O9&5D+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9&ER("`@5&AE(')O;W0@9W)A<&AI8W,@
M9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M9G5L;"!I;6%G92!T86<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EM9R@D<W)C
M+"`D86QT(#T@)R<L("1A='1R(#T@)R<L("1D:7(@/2!N=6QL*0H@("`@>PH@
M("`@("`@('-T871I8R`D8VAA<G-E=#L*("`@("`@("!I9B`H(6ES<V5T*"1C
M:&%R<V5T*2D@>PH@("`@("`@("`@("`D8VAA<G-E="`]($Y,4SHZ9V5T0VAA
M<G-E="@I.PH@("`@("`@('T*"B`@("`@("`@+RH@268@8G)O=W-E<B!D;V5S
M(&YO="!S=7!P;W)T(&EM86=E<RP@<VEM<&QY(')E='5R;B!T:&4@04Q4('1E
M>'0N("HO"B`@("`@("`@:68@*"$D1TQ/0D%,4ULG8G)O=W-E<B==+3YH87-&
M96%T=7)E*"=I;6%G97,G*2D@>PH@("`@("`@("`@("!R971U<FX@0&AT;6QS
M<&5C:6%L8VAA<G,H)&%L="P@14Y47T-/35!!5"P@)&-H87)S970I.PH@("`@
M("`@('T*"B`@("`@("`@+RH@268@;F\@9&ER96-T;W)Y(&AA<R!B965N('-P
M96-I9FEE9"P@9V5T(&ET(&9R;VT@=&AE(')E9VES=')Y+B`J+PH@("`@("`@
M(&EF("@D9&ER(#T]/2!N=6QL*2!["B`@("`@("`@("`@(&=L;V)A;"`D<F5G
M:7-T<GD["B`@("`@("`@("`@("1D:7(@/2`D<F5G:7-T<GDM/F=E=$EM86=E
M1&ER*"D["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!A(&1I<F5C=&]R>2!H
M87,@8F5E;B!P<F]V:61E9"P@<')E<&5N9"!I="!T;R!T:&4@:6UA9V4@<V]U
M<F-E+B`J+PH@("`@("`@(&EF("@A96UP='DH)&1I<BDI('L*("`@("`@("`@
M("`@)'-R8R`]("1D:7(@+B`G+R<@+B`D<W)C.PH@("`@("`@('T*"B`@("`@
M("`@+RH@0G5I;&0@86QL(&]F('1H92!T86<@871T<FEB=71E<RX@*B\*("`@
M("`@("`D871T<FEB=71E<R`](&%R<F%Y*"=S<F,G(#T^("1S<F,L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G86QT)R`]/B`D86QT*3L*("`@("`@
M("!I9B`H:7-?87)R87DH)&%T='(I*2!["B`@("`@("`@("`@("1A='1R:6)U
M=&5S(#T@87)R87E?;65R9V4H)&%T=')I8G5T97,L("1A='1R*3L*("`@("`@
M("!]"B`@("`@("`@:68@*&5M<'1Y*"1A='1R:6)U=&5S6R=T:71L92==*2D@
M>PH@("`@("`@("`@("`D871T<FEB=71E<ULG=&ET;&4G72`]("<G.PH@("`@
M("`@('T*"B`@("`@("`@)&EM9R`]("<\:6UG)SL*("`@("`@("!F;W)E86-H
M("@D871T<FEB=71E<R!A<R`D871T<FEB=71E(#T^("1V86QU92D@>PH@("`@
M("`@("`@("`D:6UG("X]("<@)R`N("1A='1R:6)U=&4@+B`G/2(G("X@*"1A
M='1R:6)U=&4@/3T@)W-R8R<@/R`D=F%L=64@.B!`:'1M;'-P96-I86QC:&%R
M<R@D=F%L=64L($5.5%]#3TU0050L("1C:&%R<V5T*2D@+B`G(B<["B`@("`@
M("`@?0H*("`@("`@("`O*B!)9B!T:&4@=7-E<B!S=7!P;&EE9"!A('!R92UB
M=6EL="!S=')I;F<@;V8@871T<FEB=71E<RP@861D('1H870N("HO"B`@("`@
M("`@:68@*&ES7W-T<FEN9R@D871T<BD@)B8@(65M<'1Y*"1A='1R*2D@>PH@
M("`@("`@("`@("`D:6UG("X]("<@)R`N("1A='1R.PH@("`@("`@('T*"B`@
M("`@("`@+RH@4F5T=7)N('1H92!C;&]S960@:6UA9V4@=&%G+B`J+PH@("`@
M("`@(')E='5R;B`D:6UG("X@)R`O/B<["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!$971E<FUI;F5S('1H92!L;V-A=&EO;B!O9B!T:&4@<WES=&5M('1E;7!O
M<F%R>2!D:7)E8W1O<GDN($EF(&$@<W!E8VEF:6,*("`@("`J('-E='1I;F<@
M8V%N;F]T(&)E(&9O=6YD+"!I="!D969A=6QT<R!T;R`O=&UP+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!!(&1I<F5C=&]R>2!N86UE('1H870@
M8V%N(&)E('5S960@9F]R('1E;7`@9FEL97,N"B`@("`@*B`@("`@("`@("`@
M("`@("`@4F5T=7)N<R!F86QS92!I9B!O;F4@8V]U;&0@;F]T(&)E(&9O=6YD
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971496UP1&ER*"D*("`@('L*("`@
M("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@("\J($EF(&]N92!H87,@8F5E
M;B!S<&5C:69I8V%L;'D@<V5T+"!T:&5N('5S92!T:&%T("HO"B`@("`@("`@
M:68@*"%E;7!T>2@D8V]N9ELG=&UP9&ER)UTI*2!["B`@("`@("`@("`@("1T
M;7`@/2`D8V]N9ELG=&UP9&ER)UT["B`@("`@("`@?0H*("`@("`@("`O*B!.
M97AT+"!T<GD@571I;#HZ9V5T5&5M<$1I<B@I+B`J+PH@("`@("`@(&EF("AE
M;7!T>2@D=&UP*2D@>PH@("`@("`@("`@("`D=&UP(#T@571I;#HZ9V5T5&5M
M<$1I<B@I.PH@("`@("`@('T*"B`@("`@("`@+RH@268@:70@:7,@<W1I;&P@
M96UP='DL('=E(&AA=F4@9F%I;&5D+"!S;R!R971U<FX@9F%L<V4["B`@("`@
M("`@("H@;W1H97)W:7-E(')E='5R;B!T:&4@9&ER96-T;W)Y(&1E=&5R;6EN
M960N("HO"B`@("`@("`@<F5T=7)N(&5M<'1Y*"1T;7`I(#\@9F%L<V4@.B`D
M=&UP.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A('1E;7!O<F%R
M>2!F:6QE;F%M92!F;W(@=&AE(&QI9F5T:6UE(&]F('1H92!S8W)I<'0L(&%N
M9`H@("`@("H@*&]P=&EO;F%L;'DI(')E9VES=&5R<R!I="!T;R!B92!D96QE
M=&5D(&%T(')E<75E<W0@<VAU=&1O=VXN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<')E9FEX("`@4')E9FEX('1O(&UA:V4@=&AE('1E;7!O<F%R
M>2!N86UE(&UO<F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(')E
M8V]G;FEZ86)L92X*("`@("`J($!P87)A;2!B;V]L96%N("1D96QE=&4@($1E
M;&5T92!T:&4@9FEL92!A="!T:&4@96YD(&]F('1H92!R97%U97-T/PH@("`@
M("H@0'!A<F%M('-T<FEN9R`D9&ER("`@("`@1&ER96-T;W)Y('1O(&-R96%T
M92!T:&4@=&5M<&]R87)Y(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D<V5C=7)E("!)9B!D96QE=&EN9R!F:6QE+"!S:&]U;&0@=V4@<V5C=7)E
M;'D@9&5L971E('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M9FEL93\*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%)E='5R;G,@
M=&AE(&9U;&P@<&%T:"UN86UE('1O('1H92!T96UP;W)A<GD@9FEL92!O<@H@
M("`@("H@("`@("`@("`@("`@("`@("!F86QS92!I9B!A('1E;7!O<F%R>2!F
M:6QE(&-O=6QD(&YO="!B92!C<F5A=&5D+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971496UP1FEL92@D<')E9FEX(#T@)TAO<F1E)RP@)&1E;&5T92`]('1R
M=64L("1D:7(@/2`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1S96-U
M<F4@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H96UP='DH)&1I<BD@?'P@
M(6ES7V1I<B@D9&ER*2D@>PH@("`@("`@("`@("`D9&ER(#T@2&]R9&4Z.F=E
M=%1E;7!$:7(H*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!5=&EL.CIG
M971496UP1FEL92@D<')E9FEX+"`D9&5L971E+"`D9&ER+"`D<V5C=7)E*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-T87)T<R!O=71P=70@8V]M<')E<W-I
M;VXL(&EF(')E<75E<W1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]M<')E
M<W-/=71P=70H*0H@("`@>PH@("`@("`@('-T871I8R`D<W1A<G1E9#L*"B`@
M("`@("`@:68@*&ES<V5T*"1S=&%R=&5D*2D@>PH@("`@("`@("`@("!R971U
M<FX["B`@("`@("`@?0H*("`@("`@("`O*B!#;VUP<F5S<R!O=71P=70@:68@
M<F5Q=65S=&5D(&%N9"!P;W-S:6)L92X@*B\*("`@("`@("!I9B`H)$=,3T)!
M3%-;)V-O;F8G75LG8V]M<')E<W-?<&%G97,G72`F)@H@("`@("`@("`@("`A
M)$=,3T)!3%-;)V)R;W=S97(G72T^:&%S475I<FLH)V)U9V=Y7V-O;7!R97-S
M:6]N)RD@)B8*("`@("`@("`@("`@(2AB;V]L*6EN:5]G970H)WIL:6(N;W5T
M<'5T7V-O;7!R97-S:6]N)RD@)B8*("`@("`@("`@("`@(2AB;V]L*6EN:5]G
M970H)WIE;F1?86-C96QE<F%T;W(N8V]M<')E<W-?86QL)RD@)B8*("`@("`@
M("`@("`@:6YI7V=E="@G;W5T<'5T7VAA;F1L97(G*2`A/2`G;V)?9WIH86YD
M;&5R)RD@>PH@("`@("`@("`@("!I9B`H;V)?9V5T7VQE=F5L*"DI('L*("`@
M("`@("`@("`@("`@(&]B7V5N9%]C;&5A;B@I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&]B7W-T87)T*"=O8E]G>FAA;F1L97(G*3L*("`@("`@("!]
M"@H@("`@("`@("1S=&%R=&5D(#T@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J($1E=&5R;6EN97,@:68@;W5T<'5T(&-O;7!R97-S:6]N(&-A;B!B92!U
M<V5D+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!O
M=71P=70@8V]M<')E<W-I;VX@8V%N(&)E('5S960L(&9A;'-E(&EF(&YO="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@86QL;W=/=71P=71#;VUP<F5S<VEO;B@I
M"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]"<F]W<V5R+G!H
M<"<["B`@("`@("`@)&)R;W=S97(@/2`F0G)O=W-E<CHZ<VEN9VQE=&]N*"D[
M"@H@("`@("`@("\J(%1U<FX@;V9F(&-O;7!R97-S:6]N(&9O<B!B=6=G>2!B
M<F]W<V5R<RX@*B\*("`@("`@("!I9B`H)&)R;W=S97(M/FAA<U%U:7)K*"=B
M=6=G>5]C;VUP<F5S<VEO;B<I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`H:6YI7V=E="@G>FQI8BYO
M=71P=71?8V]M<')E<W-I;VXG*2`]/2`G)R`F)@H@("`@("`@("`@("`@("`@
M:6YI7V=E="@G>F5N9%]A8V-E;&5R871O<BYC;VUP<F5S<U]A;&PG*2`]/2`G
M)R`F)@H@("`@("`@("`@("`@("`@:6YI7V=E="@G;W5T<'5T7VAA;F1L97(G
M*2`A/2`G;V)?9WIH86YD;&5R)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!796(@<V5R=F5R(&)E:6YG('5S960N"B`@("`@*B!02%`@
M<W1R:6YG(&QI<W0@8G5I;'0@9G)O;2!T:&4@4$A0("=C;VYF:6=U<F4G('-C
M<FEP="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@02!W96(@<V5R
M=F5R(&ED96YT:69I8V%T:6]N('-T<FEN9RX*("`@("`J(#QP<F4^"B`@("`@
M*B`G86]L<V5R=F5R)R`]($%/3"!397)V97(*("`@("`J("=A<&%C:&4Q)R`@
M(#T@07!A8VAE(#$N>`H@("`@("H@)V%P86-H93(G("`@/2!!<&%C:&4@,BYX
M"B`@("`@*B`G8V%U9&EU;2<@("`]($-A=61I=6T*("`@("`J("=C9VDG("`@
M("`@(#T@56YK;F]W;B!S97)V97(@+2!02%`@8G5I;'0@87,@0T=)('!R;V=R
M86T*("`@("`J("=C;&DG("`@("`@(#T@0V]M;6%N9"!,:6YE($EN=&5R9F%C
M92!B=6EL9`H@("`@("H@)V5M8F5D)R`@("`@/2!%;6)E9&1E9"!02%`*("`@
M("`J("=I<V%P:2<@("`@(#T@6F5U<R!)4T%020H@("`@("H@)VUI;'1E<B<@
M("`@/2!-:6QT97(*("`@("`J("=N<V%P:2<@("`@(#T@3E-!4$D*("`@("`J
M("=P:'1T<&0G("`@(#T@4$A45%!$"B`@("`@*B`G<&DS=V5B)R`@("`](%!I
M,U=E8@H@("`@("H@)W)O>&5N)R`@("`@/2!2;WAE;B]0:6ME"B`@("`@*B`G
M<V5R=FQE="<@("`](%-E<G9L970*("`@("`J("=T:'1T<&0G("`@(#T@=&AT
M='!D"B`@("`@*B`G='5X)R`@("`@("`](%1U>`H@("`@("H@)W=E8FIA;65S
M)R`@/2!796)J86UE<PH@("`@("H@/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T
M:6]N('=E8E-E<G9E<DE$*"D*("`@('L*("`@("`@("`D<V5R=F5R(#T@<&AP
M7W-A<&E?;F%M92@I.PH*("`@("`@("!I9B`H)'-E<G9E<B`]/2`G87!A8VAE
M)RD@>PH@("`@("`@("`@("!R971U<FX@)V%P86-H93$G.PH@("`@("`@('T@
M96QS96EF("@H)'-E<G9E<B`]/2`G87!A8VAE,F9I;'1E<B<I('Q\"B`@("`@
M("`@("`@("`@("`@("@D<V5R=F5R(#T]("=A<&%C:&4R:&%N9&QE<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`G87!A8VAE,B<["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<F5T=7)N("1S97)V97(["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@/&QI;FL^('1A9W,@9F]R
M('1H92!#4U,@<W1Y;&5S:&5E=',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9WQA<G)A>2`D87!P("!4:&4@2&]R9&4@87!P;&EC871I;VXH<RDN"B`@
M("`@*B!`<&%R86T@;6EX960@)'1H96UE("`@("`@(%1H92!T:&5M92!T;R!U
M<V4[('-P96-I9GD@86X@96UP='D@=F%L=64@=&\*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<F5T<FEE=F4@=&AE('1H96UE(&9R;VT@=7-E
M<B!P<F5F97)E;F-E<RP@86YD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&9A;'-E(&9O<B!N;R!T:&5M92X*("`@("`J($!P87)A;2!B;V]L
M96%N("1I;FAE<FET("`@26YH97)I="!(;W)D92UW:61E($-34S\*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@/&QI;FL^('1A9W,@9F]R($-34R!S
M='EL97-H965T<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<W1Y;&5S:&5E=$QI
M;FLH)&%P<',@/2!N=6QL+"`D=&AE;64@/2`G)RP@)&EN:&5R:70@/2!T<G5E
M*0H@("`@>PH@("`@("`@(&EF("@D=&AE;64@/3T]("<G("8F(&ES<V5T*"1'
M3$]"04Q36R=P<F5F<R==*2D@>PH@("`@("`@("`@("`D=&AE;64@/2`D1TQ/
M0D%,4ULG<')E9G,G72T^9V5T5F%L=64H)W1H96UE)RD["B`@("`@("`@?0H*
M("`@("`@("`D<G1L(#T@:7-S970H)$=,3T)!3%-;)VYL<R==6R=R=&PG75LD
M1TQ/0D%,4ULG;&%N9W5A9V4G75TI.PH@("`@("`@("1C<W,@/2!A<G)A>2@I
M.PH*("`@("`@("`D=&AE;65S7V9S(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM
M/F=E="@G=&AE;65S9G,G+"`G:&]R9&4G*3L*("`@("`@("!I9B`H)&EN:&5R
M:70I('L*("`@("`@("`@("`@)'1H96UE<U]U<FD@/2!(;W)D93HZ=7)L*"1'
M3$]"04Q36R=R96=I<W1R>2==+3YG970H)W1H96UE<W5R:2<L("=H;W)D92<I
M+"!F86QS92P@+3$I.PH@("`@("`@("`@("`D8W-S6UT@/2`D=&AE;65S7W5R
M:2`N("<O<V-R965N+F-S<R<["B`@("`@("`@("`@(&EF("@A96UP='DH)'1H
M96UE*2`F)@H@("`@("`@("`@("`@("`@9FEL95]E>&ES=',H)'1H96UE<U]F
M<R`N("<O)R`N("1T:&5M92`N("<O<V-R965N+F-S<R<I*2!["B`@("`@("`@
M("`@("`@("`D8W-S6UT@/2`D=&AE;65S7W5R:2`N("<O)R`N("1T:&5M92`N
M("<O<V-R965N+F-S<R<["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF
M("@D<G1L*2!["B`@("`@("`@("`@("`@("`D8W-S6UT@/2`D=&AE;65S7W5R
M:2`N("<O<G1L+F-S<R<["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1T
M:&5M92D@)B8*("`@("`@("`@("`@("`@("`@("!F:6QE7V5X:7-T<R@D=&AE
M;65S7V9S("X@)R\G("X@)'1H96UE("X@)R]R=&PN8W-S)RDI('L*("`@("`@
M("`@("`@("`@("`@("`D8W-S6UT@/2`D=&AE;65S7W5R:2`N("<O)R`N("1T
M:&5M92`N("<O<G1L+F-S<R<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)&%P<',I*2![
M"B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&%P<',I*2!["B`@("`@("`@
M("`@("`@("`D87!P<R`](&%R<F%Y*"1A<'!S*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@9F]R96%C:"`H)&%P<',@87,@)&%P<"D@>PH@("`@("`@
M("`@("`@("`@:68@*"1I;FAE<FET("8F("1A<'`@/3T@)VAO<F1E)RD@>PH@
M("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@("1T:&5M97-?9G,@/2`D1TQ/0D%,4ULG<F5G
M:7-T<GDG72T^9V5T*"=T:&5M97-F<R<L("1A<'`I.PH@("`@("`@("`@("`@
M("`@)'1H96UE<U]U<FD@/2!(;W)D93HZ=7)L*"1'3$]"04Q36R=R96=I<W1R
M>2==+3YG970H)W1H96UE<W5R:2<L("1A<'`I+"!F86QS92P@+3$I.PH@("`@
M("`@("`@("`@("`@:68@*&9I;&5?97AI<W1S*"1T:&5M97-?9G,@+B`G+W-C
M<F5E;BYC<W,G*2D@>PH@("`@("`@("`@("`@("`@("`@("1C<W-;72`]("1T
M:&5M97-?=7)I("X@)R]S8W)E96XN8W-S)SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'1H96UE*2`F)@H@("`@("`@
M("`@("`@("`@("`@(&9I;&5?97AI<W1S*"1T:&5M97-?9G,@+B`G+R<@+B`D
M=&AE;64@+B`G+W-C<F5E;BYC<W,G*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1C<W-;72`]("1T:&5M97-?=7)I("X@)R\G("X@)'1H96UE("X@)R]S8W)E
M96XN8W-S)SL*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I
M9B`H)')T;"D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AF:6QE7V5X:7-T
M<R@D=&AE;65S7V9S("X@)R]R=&PN8W-S)RDI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&-S<UM=(#T@)'1H96UE<U]U<FD@+B`G+W)T;"YC<W,G.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1T:&5M92D@)B8*("`@("`@("`@("`@("`@("`@("`@("`@9FEL
M95]E>&ES=',H)'1H96UE<U]F<R`N("<O)R`N("1T:&5M92`N("<O<G1L+F-S
M<R<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1C<W-;72`]("1T:&5M
M97-?=7)I("X@)R\G("X@)'1H96UE("X@)R]R=&PN8W-S)SL*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("1H=&UL(#T@)R<["B`@("`@("`@9F]R96%C
M:"`H)&-S<R!A<R`D8W-S7VQI;FLI('L*("`@("`@("`@("`@)&AT;6P@+CT@
M)SQL:6YK(&AR968](B<@+B`D8W-S7VQI;FL@+B`G(B!R96P](G-T>6QE<VAE
M970B('1Y<&4](G1E>'0O8W-S(B`O/B<@+B`B7&XB.PH@("`@("`@('T*"B`@
M("`@("`@+RH@3&]A9"!)12!03D<@=')A;G-P87)E;F-Y(&-O9&4@:68@;F5E
M9&5D+B`J+PH@("`@("`@(&EF("@D1TQ/0D%,4ULG8G)O=W-E<B==+3YH87-1
M=6ER:R@G<&YG7W1R86YS<&%R96YC>2<I("8F"B`@("`@("`@("`@("1'3$]"
M04Q36R=P<F5F<R==+3YG971686QU92@G86QP:&%?9FEL=&5R)RDI('L*("`@
M("`@("`@("`@)'5R;"`]($AO<F1E.CIU<FPH)$=,3T)!3%-;)W)E9VES=')Y
M)UTM/F=E="@G:G-U<FDG+"`G:&]R9&4G*2`N("<O86QP:&%);6%G94QO861E
M<BYP:'`G+"!T<G5E+"`M,2D["B`@("`@("`@("`@("1H=&UL("X]("<\<W1Y
M;&4@='EP93TB=&5X="]C<W,B/B!I;6<@>R!B96AA=FEO<CH@=7)L*"(G("X@
M)'5R;"`N("<B*3L@?2`\+W-T>6QE/B<["B`@("`@("`@?0H*("`@("`@("`O
M*B!,;V%D(&)R;W=S97(@<W!E8VEF:6,@<W1Y;&5S:&5E=',@:68@;F5E9&5D
M+B`J+PH@("`@("`@(&EF("@D1TQ/0D%,4ULG8G)O=W-E<B==+3YI<T)R;W=S
M97(H)VUS:64G*2`F)B`D1TQ/0D%,4ULG8G)O=W-E<B==+3YG971-86IO<B@I
M(#P@-RD@>PH@("`@("`@("`@("`D:'1M;"`N/2`G/&QI;FL@:')E9CTB)R`N
M("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W1H96UE<W5R:2<L("=H;W)D
M92<I("X@)R]I939?;W)?;&5S<RYC<W,B(')E;#TB<W1Y;&5S:&5E="(@='EP
M93TB=&5X="]C<W,B("\^)R`N(")<;B(["B`@("`@("`@("`@(&EF("@D1TQ/
M0D%,4ULG8G)O=W-E<B==+3YG9710;&%T9F]R;2@I(#T]("=M86,G*2!["B`@
M("`@("`@("`@("`@("`D:'1M;"`N/2`G/&QI;FL@:')E9CTB)R`N("1'3$]"
M04Q36R=R96=I<W1R>2==+3YG970H)W1H96UE<W5R:2<L("=H;W)D92<I("X@
M)R]I935M86,N8W-S(B!R96P](G-T>6QE<VAE970B('1Y<&4](G1E>'0O8W-S
M(B`O/B<@+B`B7&XB.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@
M(&EF("@D1TQ/0D%,4ULG8G)O=W-E<B==+3YI<T)R;W=S97(H)V]P97)A)RDI
M('L*("`@("`@("`@("`@)&AT;6P@+CT@)SQL:6YK(&AR968](B<@+B`D1TQ/
M0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=T:&5M97-U<FDG+"`G:&]R9&4G*2`N
M("<O;W!E<F$N8W-S(B!R96P](G-T>6QE<VAE970B('1Y<&4](G1E>'0O8W-S
M(B`O/B<@+B`B7&XB.PH@("`@("`@('T*("`@("`@("!I9B`H)$=,3T)!3%-;
M)V)R;W=S97(G72T^:7-"<F]W<V5R*"=M;WII;&QA)RD@)B8*("`@("`@("`@
M("`@)$=,3T)!3%-;)V)R;W=S97(G72T^9V5T36%J;W(H*2`^/2`U("8F"B`@
M("`@("`@("`@('!R96=?;6%T8V@H)R]R=CHH+BHI7"DO)RP@)$=,3T)!3%-;
M)V)R;W=S97(G72T^9V5T06=E;G13=')I;F<H*2P@)')E=FES:6]N*2`F)@H@
M("`@("`@("`@("`D<F5V:7-I;VY;,5T@/#T@,2XT*2!["B`@("`@("`@("`@
M("1H=&UL("X]("<\;&EN:R!H<F5F/2(G("X@)$=,3T)!3%-;)W)E9VES=')Y
M)UTM/F=E="@G=&AE;65S=7)I)RP@)VAO<F1E)RD@+B`G+VUO>C$T+F-S<R(@
M<F5L/2)S='EL97-H965T(B!T>7!E/2)T97AT+V-S<R(@+SXG("X@(EQN(CL*
M("`@("`@("!]"B`@("`@("`@:68@*'-T<G!O<RAS=')T;VQO=V5R*"1'3$]"
M04Q36R=B<F]W<V5R)UTM/F=E=$%G96YT4W1R:6YG*"DI+"`G<V%F87)I)RD@
M(3T](&9A;'-E*2!["B`@("`@("`@("`@("1H=&UL("X]("<\;&EN:R!H<F5F
M/2(G("X@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=&AE;65S=7)I)RP@
M)VAO<F1E)RD@+B`G+W-A9F%R:2YC<W,B(')E;#TB<W1Y;&5S:&5E="(@='EP
M93TB=&5X="]C<W,B("\^)R`N(")<;B(["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&AT;6P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S(&$@8W5S
M=&]M('-E<W-I;VX@:&%N9&QE<B!U<"P@:68@=&AE<F4@:7,@;VYE+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S971U<%-E<W-I;VY(86YD;&5R*"D*("`@('L*
M("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@(&EN:5]S970H)W5R;%]R
M97=R:71E<BYT86=S)RP@,"D["B`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG
M<V5S<VEO;B==6R=U<V5?;VYL>5]C;V]K:65S)UTI*2!["B`@("`@("`@("`@
M(&EN:5]S970H)W-E<W-I;VXN=7-E7V]N;'E?8V]O:VEE<R<L(#$I.PH@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=C;V]K:64G75LG9&]M86EN)UTI
M("8F"B`@("`@("`@("`@("`@("!S=')P;W,H)&-O;F9;)W-E<G9E<B==6R=N
M86UE)UTL("<N)RD@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("!(;W)D
M93HZ;&]G365S<V%G92@G4V5S<VEO;B!C;V]K:65S('=I;&P@;F]T('=O<FL@
M=VET:&]U="!A($911$X@86YD('=I=&@@82!N;VXM96UP='D@8V]O:VEE(&1O
M;6%I;BXG+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7U=!4DY)3D<I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@('-E<W-I;VY?<V5T
M7V-O;VMI95]P87)A;7,H)&-O;F9;)W-E<W-I;VXG75LG=&EM96]U="==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;F9;)V-O;VMI
M92==6R=P871H)UTL("1C;VYF6R=C;V]K:64G75LG9&]M86EN)UTL("1C;VYF
M6R=U<V5?<W-L)UT@/3T@,2`_(#$@.B`P*3L*("`@("`@("!S97-S:6]N7V-A
M8VAE7VQI;6ET97(H)&-O;F9;)W-E<W-I;VXG75LG8V%C:&5?;&EM:71E<B==
M*3L*("`@("`@("!S97-S:6]N7VYA;64H=7)L96YC;V1E*"1C;VYF6R=S97-S
M:6]N)UU;)VYA;64G72DI.PH*("`@("`@("`D='EP92`]("%E;7!T>2@D8V]N
M9ELG<V5S<VEO;FAA;F1L97(G75LG='EP92==*2`_("1C;VYF6R=S97-S:6]N
M:&%N9&QE<B==6R=T>7!E)UT@.B`G;F]N92<["@H@("`@("`@(&EF("@D='EP
M92`]/2`G97AT97)N86PG*2!["B`@("`@("`@("`@("1C86QL<R`]("1C;VYF
M6R=S97-S:6]N:&%N9&QE<B==6R=P87)A;7,G73L*("`@("`@("`@("`@<V5S
M<VEO;E]S971?<V%V95]H86YD;&5R*"1C86QL<ULG;W!E;B==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-A;&QS6R=C;&]S92==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-A;&QS
M6R=R96%D)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D8V%L;'-;)W=R:71E)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D8V%L;'-;)V1E<W1R;WDG72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1C86QL<ULG9V,G72D["B`@("`@("`@
M?2!E;'-E:68@*"1T>7!E("$]("=N;VYE)RD@>PH@("`@("`@("`@("!G;&]B
M86P@)%]S97-S:6]N7VAA;F1L97(["B`@("`@("`@("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP)SL*("`@("`@("`@("`@)%]S
M97-S:6]N7VAA;F1L97(@/2`F4V5S<VEO;DAA;F1L97(Z.G-I;F=L971O;B@D
M8V]N9ELG<V5S<VEO;FAA;F1L97(G75LG='EP92==*3L*("`@("`@("`@("`@
M:68@*"%E;7!T>2@D7W-E<W-I;VY?:&%N9&QE<BD@)B8*("`@("`@("`@("`@
M("`@("%I<U]A*"1?<V5S<VEO;E]H86YD;&5R+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("!I;FE?<V5T*"=S97-S:6]N+G-A=F5?:&%N9&QE
M<B<L("=U<V5R)RD["B`@("`@("`@("`@("`@("!S97-S:6]N7W-E=%]S879E
M7VAA;F1L97(H87)R87DH)B1?<V5S<VEO;E]H86YD;&5R+"`G;W!E;B<I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"8D7W-E<W-I;VY?:&%N9&QE<BP@)V-L;W-E)RDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)B1?<V5S<VEO;E]H
M86YD;&5R+"`G<F5A9"<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"8D7W-E<W-I;VY?:&%N9&QE<BP@)W=R:71E
M)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)B1?<V5S<VEO;E]H86YD;&5R+"`G9&5S=')O>2<I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"8D7W-E
M<W-I;VY?:&%N9&QE<BP@)V=C)RDI.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%!%05(Z.G)A:7-E17)R;W(H
M)TAO<F1E(&ES('5N86)L92!T;R!C;W)R96-T;'D@<W1A<G0@=&AE(&-U<W1O
M;2!S97-S:6]N(&AA;F1L97(N)RDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@9F%L
M<V4I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!A;B!U;BUU<V5D(&%C8V5S<R!K97D@9G)O;2!T:&4@
M;&%B96P@9VEV96XN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&%B
M96P@("`@(%1H92!L86)E;"!T;R!C:&]O<V4@86X@86-C97-S(&ME>2!F<F]M
M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&YO8VAE8VL@($1O;B=T(&-H96-K
M(&EF('1H92!A8V-E<W,@:V5Y(&%L<F5A9'D@:&%S(&)E96X*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("!U<V5D/PH@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!!('-I;F=L92!L;W=E<B!C87-E(&-H87)A8W1E<B!A
M8V-E<W,@:V5Y(&]R(&5M<'1Y"B`@("`@*B`@("`@("`@("`@("`@("`@<W1R
M:6YG(&EF(&YO;F4@8V%N(&)E(&9O=6YD"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$%C8V5S<TME>2@D;&%B96PL("1N;V-H96-K(#T@9F%L<V4L("1S:'5T
M9&]W;B`](&9A;'-E*0H@("`@>PH@("`@("`@("\J(%1H92!A8V-E<W,@:V5Y
M<R!A;')E861Y('5S960@:6X@=&AI<R!P86=E("HO"B`@("`@("`@<W1A=&EC
M("1?=7-E9"`](&%R<F%Y*"D["@H@("`@("`@("\J(%1H92!L86)E;',@86QR
M96%D>2!U<V5D(&EN('1H:7,@<&%G92`J+PH@("`@("`@('-T871I8R`D7VQA
M8F5L<R`](&%R<F%Y*"D["@H@("`@("`@("\J(%-H=71D;W=N(&-A;&P@9F]R
M('1R86YS;&%T;W)S/R`J+PH@("`@("`@(&EF("@D<VAU=&1O=VXI('L*("`@
M("`@("`@("`@:68@*"%C;W5N="@D7VQA8F5L<RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;CL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<V-R:7!T
M(#T@8F%S96YA;64H)%]315)615);)U!(4%]314Q&)UTI.PH@("`@("`@("`@
M("`D;&%B96QS(#T@87)R87E?:V5Y<R@D7VQA8F5L<RD["B`@("`@("`@("`@
M('-O<G0H)&QA8F5L<RD["B`@("`@("`@("`@("1U<V5D(#T@87)R87E?:V5Y
M<R@D7W5S960I.PH@("`@("`@("`@("!S;W)T*"1U<V5D*3L*("`@("`@("`@
M("`@)')E;6%I;FEN9R`]('-T<E]R97!L86-E*"1U<V5D+"!A<G)A>2@I+"`G
M86)C9&5F9VAI:FML;6YO<'%R<W1U=G=X>7HG*3L*("`@("`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H)T%C8V5S<R!K97D@:6YF;W)M871I;VX@9F]R("<@
M+B`D<V-R:7!T+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92@G57-E9"!L86)E;',Z("<@+B!I;7!L;V1E*"<L
M)RP@)&QA8F5L<RDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@
M($AO<F1E.CIL;V=-97-S86=E*"=5<V5D(&ME>7,Z("<@+B!I;7!L;V1E*"<G
M+"`D=7-E9"DL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@($AO
M<F1E.CIL;V=-97-S86=E*"=&<F5E(&ME>7,Z("<@+B`D<F5M86EN:6YG+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!R971U<FX["B`@("`@
M("`@?0H*("`@("`@("`O*B!5<V4@86-C97-S(&ME>7,@870@86QL/R`J+PH@
M("`@("`@('-T871I8R`D;F]T<W5P<&]R=&5D.PH@("`@("`@(&EF("@A:7-S
M970H)&YO='-U<'!O<G1E9"DI('L*("`@("`@("`@("`@)&YO='-U<'!O<G1E
M9"`]("$D1TQ/0D%,4ULG8G)O=W-E<B==+3YH87-&96%T=7)E*"=A8V-E<W-K
M97DG*2!\?`H@("`@("`@("`@("`@("`@(21'3$]"04Q36R=P<F5F<R==+3YG
M971686QU92@G=VED9V5T7V%C8V5S<VME>2<I.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"1N;W1S=7!P;W)T960@?'P@(7!R96=?;6%T8V@H)R]?*%M!+5IA
M+7I=*2\G+"`D;&%B96PL("1M871C:"DI('L*("`@("`@("`@("`@<F5T=7)N
M("<G.PH@("`@("`@('T*("`@("`@("`D:V5Y(#T@)&UA=&-H6S%=.PH*("`@
M("`@("`O*B!(87,@=&AI<R!K97D@86QR96%D>2!B965N('5S960_("HO"B`@
M("`@("`@:68@*&ES<V5T*"1?=7-E9%MS=')T;VQO=V5R*"1K97DI72D@)B8*
M("`@("`@("`@("`@(2@D;F]C:&5C:R`F)B!I<W-E="@D7VQA8F5L<ULD;&%B
M96Q=*2DI('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*"B`@
M("`@("`@+RH@4V%V92!K97D@86YD(&QA8F5L+B`J+PH@("`@("`@("1?=7-E
M9%MS=')T;VQO=V5R*"1K97DI72`]('1R=64["B`@("`@("`@)%]L86)E;'-;
M)&QA8F5L72`]('1R=64["@H@("`@("`@(')E='5R;B`D:V5Y.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4W1R:7!S(&%N(&%C8V5S<R!K97D@9G)O;2!A(&QA
M8F5L+@H@("`@("H@1F]R(&UU;'1I8GET92!C:&%R<V5T('-T<FEN9W,@=&AE
M(&%C8V5S<R!K97D@9V5T<R!R96UO=F5D(&-O;7!L971E;'DL"B`@("`@*B!O
M=&AE<G=I<V4@;VYL>2!T:&4@=6YD97)S8V]R92!G971S(')E;6]V960N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&%B96P@(%1H92!L86)E;"!C
M;VYT86EN:6YG(&%N(&%C8V5S<R!K97DN"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!L86)E;"!W:71H('1H92!A8V-E<W,@:V5Y(&)E:6YG
M('-T<FEP<&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!S=')I<$%C8V5S<TME
M>2@D;&%B96PI"B`@("!["B`@("`@("`@:6YC;'5D95]O;F-E($A/4D1%7T)!
M4T4@+B`G+V-O;F9I9R]N;',N<&AP)SL*("`@("`@("`D;75L=&EB>71E(#T@
M:7-S970H)$=,3T)!3%-;)VYL<R==6R=M=6QT:6)Y=&4G75M.3%,Z.F=E=$-H
M87)S970H=')U92E=*3L*"B`@("`@("`@<F5T=7)N('!R96=?<F5P;&%C92@G
M+U\H6T$M6F$M>ETI+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;75L=&EB>71E("8F('!R96=?;6%T8V@H)R];7'@X,"U<>&9F72\G+"`D;&%B
M96PI(#\@)R<@.B`G7#$G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&QA8F5L*3L*("`@('T*"B`@("`O*BH*("`@("`J($AI9VAL:6=H=',@86X@
M86-C97-S(&ME>2!I;B!A(&QA8F5L+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&QA8F5L("`@("`@5&AE(&QA8F5L('1O('1O(&AI9VAL:6=H="!T
M:&4@86-C97-S(&ME>2!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&%C8V5S
M<TME>2`@5&AE(&%C8V5S<R!K97D@=&\@:&EG:&QI9VAT+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@2%1-3"!V97)S:6]N(&]F('1H92!L
M86)E;"!W:71H('1H92!A8V-E<W,@:V5Y"B`@("`@*B`@("`@("`@("`@("`@
M("`@:&EG:&QI9VAT960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AI9VAL:6=H
M=$%C8V5S<TME>2@D;&%B96PL("1A8V-E<W-+97DI"B`@("!["B`@("`@("`@
M)'-T<FEP<&5D7VQA8F5L(#T@2&]R9&4Z.G-T<FEP06-C97-S:V5Y*"1L86)E
M;"D["@H@("`@("`@(&EF("AE;7!T>2@D86-C97-S2V5Y*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'-T<FEP<&5D7VQA8F5L.PH@("`@("`@('T*"B`@("`@
M("`@:68@*&ES<V5T*"1'3$]"04Q36R=N;',G75LG;75L=&EB>71E)UU;3DQ3
M.CIG971#:&%R<V5T*'1R=64I72DI('L*("`@("`@("`@("`@<F5T=7)N("1S
M=')I<'!E9%]L86)E;"`N("<H)R`N("<\<W!A;B!C;&%S<STB86-C97-S2V5Y
M(CXG("X*("`@("`@("`@("`@("`@('-T<G1O=7!P97(H)&%C8V5S<TME>2D@
M+B`G/"]S<&%N/B<@+B`G*2<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N('-T<E]R97!L86-E*"=?)R`N("1A8V-E<W-+97DL("<\<W!A
M;B!C;&%S<STB86-C97-S2V5Y(CXG("X@)&%C8V5S<TME>2`N("<\+W-P86X^
M)RP@)&QA8F5L*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!A<'!R;W!R:6%T92`B86-C97-S:V5Y(B!A;F0@(G1I=&QE
M(B!A='1R:6)U=&5S(&9O<B!A;B!(5$U,"B`@("`@*B!T86<@86YD('1H92!G
M:79E;B!L86)E;"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1L86)E
M;"`@("`@5&AE('1I=&QE(&]F(&%N($A434P@96QE;65N=`H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&YO8VAE8VL@($1O;B=T(&-H96-K(&EF('1H92!A8V-E
M<W,@:V5Y(&%L<F5A9'D@:&%S(&)E96X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("!U<V5D/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@=&ET;&4L(&%N9"!I9B!A<'!R;W!R:6%T92P@=&AE(&%C8V5S<VME
M>2!A='1R:6)U=&5S"B`@("`@*B`@("`@("`@("`@("`@("`@9F]R('1H92!E
M;&5M96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!8V-E<W-+97E!;F14
M:71L92@D;&%B96PL("1N;V-H96-K(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M)&%K(#T@2&]R9&4Z.F=E=$%C8V5S<TME>2@D;&%B96PL("1N;V-H96-K*3L*
M("`@("`@("`D871T<FEB=71E<R`]("=T:71L93TB)R`N($AO<F1E.CIS=')I
M<$%C8V5S<TME>2@D;&%B96PI.PH@("`@("`@(&EF("@A96UP='DH)&%K*2D@
M>PH@("`@("`@("`@("`D871T<FEB=71E<R`N/2!S<')I;G1F*%\H(B`H06-C
M97-S:V5Y("5S*2(I+"`D86LI.PH@("`@("`@("`@("`D871T<FEB=71E<R`N
M/2`G(B!A8V-E<W-K97D](B<@+B`D86L["B`@("`@("`@?0H@("`@("`@("1A
M='1R:6)U=&5S("X]("<B)SL*("`@("`@("!R971U<FX@)&%T=')I8G5T97,[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@;&%B96P@96QE;65N
M="!I;F-L=61I;F<@86X@86-C97-S(&ME>2!F;W(@=7-A9V4@:6X@8V]N:G5C
M=&EO;@H@("`@("H@=VET:"!A(&9O<FT@9FEE;&0N(%5S97(@<')E9F5R96YC
M97,@<F5G87)D:6YG(&%C8V5S<R!K97ES(&%R92!R97-P96-T960N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R("`@(%1H92!F;W)M(&9I96QD
M)W,@:60@871T<FEB=71E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&%B96P@
M(%1H92!L86)E;"!T97AT+@H@("`@("H@0'!A<F%M('-T<FEN9R`D86L@("`@
M(%1H92!A8V-E<W,@:V5Y('1O('5S92X@268@;G5L;"!A(&YE=R!A8V-E<W,@
M:V5Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@=VEL;"!B92!G96YE
M<F%T960N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!H=&UL
M(&-O9&4@9F]R('1H92!L86)E;"!E;&5M96YT+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!L86)E;"@D9F]R+"`D;&%B96PL("1A:R`](&YU;&PI"B`@("!["B`@
M("`@("`@9VQO8F%L("1P<F5F<SL*"B`@("`@("`@:68@*&ES7VYU;&PH)&%K
M*2D@>PH@("`@("`@("`@("`D86L@/2!(;W)D93HZ9V5T06-C97-S:V5Y*"1L
M86)E;"P@,2D["B`@("`@("`@?0H@("`@("`@("1L86)E;"`]($AO<F1E.CIH
M:6=H;&EG:'1!8V-E<W-+97DH)&QA8F5L+"`D86LI.PH*("`@("`@("!R971U
M<FX@<W!R:6YT9B@G/&QA8F5L(&9O<CTB)7,B)7,^)7,\+VQA8F5L/B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@)&9O<BP*("`@("`@("`@("`@("`@("`@
M("`@("`A96UP='DH)&%K*2`_("<@86-C97-S:V5Y/2(G("X@)&%K("X@)R(G
M(#H@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@)&QA8F5L*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E9&ER96-T<R!T;R!T:&4@;6%I;B!(;W)D92!L
M;V=I;B!P86=E(&]N(&%U=&AE;G1I8V%T:6]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%U=&AE;G1I8V%T:6]N1F%I;'5R95)E9&ER96-T*"D*
M("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T-,22YP:'`G.PH@
M("`@("`@(&EF("A(;W)D95]#3$DZ.G)U;FYI;F=&<F]M0TQ)*"DI('L*("`@
M("`@("`@("`@)&-L:2`]("9(;W)D95]#3$DZ.G-I;F=L971O;B@I.PH@("`@
M("`@("`@("`D8VQI+3YF871A;"A?*")9;W4@87)E(&YO="!A=71H96YT:6-A
M=&5D+B(I*3L*("`@("`@("!]"@H@("`@("`@("1U<FP@/2`D1TQ/0D%,4ULG
M<F5G:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G+VQO9VEN
M+G!H<"<["B`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L
M+"!A<G)A>2@G=7)L)R`]/B!(;W)D93HZ<V5L9E5R;"AT<G5E*2P@)VYO<VED
M96)A<B<@/3X@,2DL(&YU;&PL(&9A;'-E*3L*("`@("`@("`D=7)L(#T@075T
M:#HZ861D3&]G;W5T4&%R86UE=&5R<R@D=7)L*3L*("`@("`@("!H96%D97(H
M)TQO8V%T:6]N.B`G("X@2&]R9&4Z.G5R;"@D=7)L+"!T<G5E*2D["B`@("`@
M("`@97AI=#L*("`@('T*"B`@("`O*BH*("`@("`J(%!R;W9I9&5S(&$@<W1A
M;F1A<F1I<V5D(&9U;F-T:6]N('1O(&-A;&P@82!(;W)D92!H;V]K+"!C:&5C
M:VEN9R!W:&5T:&5R"B`@("`@*B!A(&AO;VL@8V]N9FEG(&9I;&4@97AI<W1S
M(&%N9"!W:&5T:&5R('1H92!F=6YC=&EO;B!I='-E;&8@97AI<W1S+B!)9@H@
M("`@("H@=&AE<V4@='=O(&-O;F1I=&EO;G,@87)E(&YO="!S871I<V9I960@
M:70@=VEL;"!R971U<FX@=&AE('-P96-I9FEE9`H@("`@("H@=F%L=64@*&)Y
M(&1E9F%U;'0@82!014%2(&5R<F]R*2X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1H;V]K("!4:&4@9G5N8W1I;VX@=&\@8V%L;"X*("`@("`J($!P
M87)A;2!A<G)A>2`@)&%R9W,@($%N(&%R<F%Y(&]F(&%N>2!A<F=U;65N=',@
M=&\@<&%S<R!T;R!T:&4@:&]O:PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@9G5N8W1I;VXN"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@("!)9B!S
M<&5C:69I960@;&]O:R!F;W(@:&]O:W,@:6X@=&AE(&-O;F9I9R!D:7)E8W1O
M<GD*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&]F('1H:7,@87!P+@H@
M("`@("H@0'!A<F%M(&UI>&5D("1E<G)O<B`@5VAA="!T;R!R971U<FX@:68@
M)&%P<"]C;VYF:6<O:&]O:W,N<&AP(&]R("1H;V]K"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("!D;V5S(&YO="!E>&ES="X@268@=&AI<R!I<R!T:&4@
M<W1R:6YG("=014%27T5R<F]R)PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@82!014%2(&5R<F]R(&]B:F5C="!I<R!R971U<FYE9"!I;G-T96%D+"!D
M971A:6QI;F<*("`@("`J("`@("`@("`@("`@("`@("`@("`@('1H92!F86EL
M=7)E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($5I=&AE<B!T:&4@
M<F5S=6QT<R!O9B!T:&4@:&]O:R!O<B!014%2(&5R<F]R(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-A;&Q(;V]K*"1H;V]K+"`D87)G<R`]
M(&%R<F%Y*"DL("1A<'`@/2`G:&]R9&4G+"`D97)R;W(@/2`G4$5!4E]%<G)O
M<B<I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*("`@("`@("!S
M=&%T:6,@)&AO;VMS7VQO861E9#L*"B`@("`@("`@:68@*"%I<W-E="@D:&]O
M:W-?;&]A9&5D*2D@>PH@("`@("`@("`@("!I9B`H9FEL95]E>&ES=',H)')E
M9VES=')Y+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G+V-O;F9I9R]H;V]K
M<RYP:'`G*2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("1R96=I
M<W1R>2T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]C;VYF:6<O:&]O:W,N
M<&AP)SL*("`@("`@("`@("`@("`@("1H;V]K<U]L;V%D960@/2!T<G5E.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&AO;VMS7VQO
M861E9"`](&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@
M(&EF("@D:&]O:W-?;&]A9&5D("8F(&9U;F-T:6]N7V5X:7-T<R@D:&]O:RDI
M('L*("`@("`@("`@("`@<F5T=7)N(&-A;&Q?=7-E<E]F=6YC7V%R<F%Y*"1H
M;V]K+"`D87)G<RD["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?<W1R:6YG
M*"1E<G)O<BD@)B8@<W1R8VUP*"1E<G)O<BP@)U!%05)?17)R;W(G*2`]/2`P
M*2!["B`@("`@("`@("`@("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H<W!R
M:6YT9B@G2&]O:R`E<R!I;B!A<'!L:6-A=&EO;B`E<R!N;W0@8V%L;&5D+B<L
M("1H;V]K+"`D87!P*2D["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E
M*"1E<G)O<BP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<W!E8VEF:65D('!E<FUI<W-I;VX@
M9F]R('1H92!C=7)R96YT('5S97(N"B`@("`@*@H@("`@("H@0'-I;F-E($AO
M<F1E(#,N,0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!E<FUI<W-I
M;VX@($$@<&5R;6ES<VEO;BP@8W5R<F5N=&QY(&]N;'D@)VUA>%]B;&]C:W,G
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!V86QU92!O9B!T
M:&4@<W!E8VEF:65D('!E<FUI<W-I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&AA<U!E<FUI<W-I;VXH)'!E<FUI<W-I;VXI"B`@("!["B`@("`@("`@9VQO
M8F%L("1P97)M<SL*"B`@("`@("`@:68@*"$D<&5R;7,M/F5X:7-T<R@G:&]R
M9&4Z)R`N("1P97)M:7-S:6]N*2D@>PH@("`@("`@("`@("!R971U<FX@=')U
M93L*("`@("`@("!]"@H@("`@("`@("1A;&QO=V5D(#T@)'!E<FUS+3YG9710
M97)M:7-S:6]N<R@G:&]R9&4Z)R`N("1P97)M:7-S:6]N*3L*("`@("`@("!I
M9B`H:7-?87)R87DH)&%L;&]W960I*2!["B`@("`@("`@("`@('-W:71C:"`H
M)'!E<FUI<W-I;VXI('L*("`@("`@("`@("`@8V%S92`G;6%X7V)L;V-K<R<Z
M"B`@("`@("`@("`@("`@("`D86QL;W=E9"`](&%R<F%Y7W)E9'5C92@D86QL
M;W=E9"P@8W)E871E7V9U;F-T:6]N*"<D82P@)&(G+"`G<F5T=7)N(&UA>"@D
M82P@)&(I.R<I+"`P*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&%L;&]W960["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B].970O````````````````````````````````````
M````````````````````````````````````````````````````,#`P,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-3(`,#$W
M,34Q`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TYE="])35-0+P``````
M````````````````````````````````````````````````````````````
M```````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#4Q-30S,S<U,@`P,3<W,C$`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O3F5T+TE-4U`O075T:"\`````````````````````````````````````
M`````````````````````````````````````#`P,#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S4R`#`R,#8R,@`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B].970O24U34"]!=71H+V-R86U?;60U+G!H
M<```````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<R,#(`,3`U,34T,S,W
M-3(`,#(S,#(S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&4@3F5T7TE-4U!?075T:%]C<F%M7VUD
M-2!C;&%S<R!F;W(@24U34"!A=71H96YT:6-A=&EO;BX*("H*("H@4F5Q=6ER
M960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=U<V5R;F%M92<@(%5S97)N86UE
M('1O(&QO9V]N('1O($E-4U`@<V5R=F5R(&%S+@H@*B`@("=P87-S=V]R9"<@
M(%!A<W-W;W)D(&9O<B!C=7)R96YT('5S97(N"B`J("`@)W-E<G9E<B<@("`@
M5&AE(&AO<W1N86UE(&]F('1H92!)35-0('-E<G9E<BX*("H@("`G<&]R="<@
M("`@("!4:&4@<&]R="!O9B!T:&4@24U34"!S97)V97(N/"]P<F4^"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T:"]C<F%M7VUD
M-2YP:'`L=B`Q+C8N,3`N.2`R,#`V+S`Q+S`Q(#(Q.C(X.C(X(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA96P@4G5B:6YS:WD@
M/&UR=6)I;G-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($UI8VAA96P@4G5B:6YS:WD@/&UR=6)I;G-K0&AO<F1E+F]R9SX*("H@
M0'!A8VMA9V4@3F5T7TE-4U`*("HO"F-L87-S($YE=%])35-07T%U=&A?8W)A
M;5]M9#4@97AT96YD<R!.971?24U34%]!=71H('L*"B`@("`O*BH*("`@("`J
M(%!R:79A=&4@875T:&5N=&EC871I;VX@9G5N8W1I;VXN("!0<F]V:61E<R!A
M8W1U86P*("`@("`J(&%U=&AE;G1I8V%T:6]N(&-O9&4N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@(&UI>&5D("1P87)A
M;7,@2&%S:"!O9B!)35-0('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"!.971?24U34"!O8FIE8W0@8V]N;F5C=&5D('1O('-E<G9E
M<B!I9B!S=6-C97-S9G5L+`H@("`@("H@("`@("`@("`@("`@("!014%27T5R
M<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9?875T:&5N
M=&EC871E*"1P87)A;7,I"B`@("!["B`@("`@("`@)&EM<W`@/2`F3F5T7TE-
M4U`Z.G-I;F=L971O;B@G;F]N92<L("1P87)A;7,I.PH@("`@("`@("1R97-U
M;'0@/2`D:6US<"T^:6YI="@I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@?0H*("`@("`@("`D=7-E<DED(#T@)'!A<F%M<ULG=7-E<FYA
M;64G73L*("`@("`@("`D8W)E9&5N=&EA;',@/2`D<&%R86US6R=P87-S=V]R
M9"==.PH@("`@("`@("1R97-U;'0@/2`D:6US<"T^:6US<%-E;F0H)T%55$A%
M3E1)0T%412!#4D%-+4U$-2<I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@?0H*("`@("`@("`O*B!'970@<F5S<&]N<V4@86YD(&1E8V]D
M92!I="X@3F]T92!T:&%T('=E(')E;6]V92!T:&4@,7-T(#(*("`@("`@("`@
M*B!C:&%R86-T97)S(&9R;VT@=&AE(')E<W!O;G-E('1O(&=E="!R:60@;V8@
M=&AE("<K)PH@("`@("`@("`J(&-O;G1I;G5A=&EO;B!C:&%R86-T97(@86YD
M('1H92!S<&%C92!T:&%T(&ES('-E;G0@87,@<&%R=`H@("`@("`@("`J(&]F
M('1H92!#4D%-+4U$-2!R97-P;VYS92`H870@;&5A<W0@;VX@8WER=7,M:6US
M<&0I+B`J+PH@("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D:6US<"T^:6US
M<%)E8V5I=F4H*3L*("`@("`@("!I9B`H:7-?82@D<V5R=F5R7W)E<W!O;G-E
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<V5R=F5R
M7W)E<W!O;G-E.PH@("`@("`@('T*"B`@("`@("`@)'-E<G9E<E]R97-P;VYS
M92`](&)A<V4V-%]D96-O9&4H=')I;2AS=6)S='(H)'-E<G9E<E]R97-P;VYS
M92P@,BDI*3L*"B`@("`@("`@+RH@0G5I;&0@86YD(&)A<V4V-"!E;F-O9&4@
M=&AE(')E<W!O;G-E('1O('1H92!C:&%L;&%N9V4N("HO"B`@("`@("`@)')E
M<W!O;G-E7W1O7W-E;F0@/2`D=7-E<DED("X@)R`G("X@)'1H:7,M/E]H;6%C
M*"1C<F5D96YT:6%L<RP@)'-E<G9E<E]R97-P;VYS92D["B`@("`@("`@)&-O
M;6UA;F1?<W1R:6YG(#T@8F%S938T7V5N8V]D92@D<F5S<&]N<V5?=&]?<V5N
M9"D["@H@("`@("`@("\J(%-E;F0@=&AE(')E<W!O;G-E+B`J+PH@("`@("`@
M("1R97-U;'0@/2`D:6US<"T^:6US<%-E;F0H)&-O;6UA;F1?<W1R:6YG+"!F
M86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@
M("`@("`@("1R97-U;'0@/2`D:6US<"T^:6US<%)E8V5I=F4H*3L*("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@:68@*"1R
M97-U;'0@(3T@)T]+)RD@>PH@("`@("`@("`@("!R971U<FX@)&EM<W`M/FEM
M<W!%<G)O<B@G3&]G:6X@=&\@24U34"!H;W-T(&9A:6QE9"XG+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B`D:6US<#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M1D,@,C$P-"!(34%#(&EM<&QE;65N=&%T:6]N+B!%;&EM:6YA=&5S('1H92!R
M96QI86YC92!O;B!M:&%S:"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J($!P87)A;2`@<W1R:6YG("`D:V5Y("`@(%1H92!(34%#(&ME
M>2X*("`@("`J($!P87)A;2`@<W1R:6YG("`D9&%T82`@(%1H92!D871A('1O
M(&AA<V@@=VET:"!T:&4@:V5Y+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@340U($A-04,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]H;6%C
M*"1K97DL("1D871A*0H@("`@>PH@("`@("`@("\J($)Y=&4@;&5N9W1H(&9O
M<B!M9#4N("HO"B`@("`@("`@)&(@/2`V-#L*"B`@("`@("`@:68@*'-T<FQE
M;B@D:V5Y*2`^("1B*2!["B`@("`@("`@("`@("1K97D@/2!P86-K*"=(*B<L
M(&UD-2@D:V5Y*2D["B`@("`@("`@?0H*("`@("`@("`D:V5Y(#T@<W1R7W!A
M9"@D:V5Y+"`D8BP@8VAR*#!X,#`I*3L*("`@("`@("`D:7!A9"`]('-T<E]P
M860H)R<L("1B+"!C:'(H,'@S-BDI.PH@("`@("`@("1O<&%D(#T@<W1R7W!A
M9"@G)RP@)&(L(&-H<B@P>#5C*2D["B`@("`@("`@)&M?:7!A9"`]("1K97D@
M7B`D:7!A9#L*("`@("`@("`D:U]O<&%D(#T@)&ME>2!>("1O<&%D.PH@("`@
M("`@(')E='5R;B!M9#4H)&M?;W!A9"`N('!A8VLH)T@J)RP@;60U*"1K7VEP
M860@+B`D9&%T82DI*3L*("`@('T*"B`@("`O*BH*("`@("`J($9O<F-E(&$@
M;&]G;W5T(&-O;6UA;F0@=&\@=&AE(&EM<W`@<W1R96%M+@H@("`@("H*("`@
M("`J+PH@("`@9G5N8W1I;VX@;&]G;W5T*"D*("`@('L*("`@("`@("`D=&AI
M<RT^7VEM<W`M/FQO9V]U="@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N('1H92!D<FEV97(@='EP90H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG('1H92!T>7!E(&]F('1H:7,@24U34%]!=71H(&1R:79E<@H@("`@("HO
M"B`@("`@9G5N8W1I;VX@9V5T1')I=F5R5'EP92@I"B`@("`@>PH@("`@("`@
M("!R971U<FX@)V-R86U?;60U)SL*("`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B].970O24U3
M4"]!=71H+VEM=&5S="YP:'``````````````````````````````````````
M````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#8V,C4`,3`U,34T,S,W-3(`,#(R-C4T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@3F5T
M7TE-4U!?075T:%]I;71E<W0@8VQA<W,@9F]R($E-4U`@875T:&5N=&EC871I
M;VXN"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z/'!R93X*("H@("`G=7-E
M<FYA;64G("`@("`@("!5<V5R;F%M92!T;R!L;V=O;B!T;R!)35-0('-E<G9E
M<B!A<RX*("H@("`G<&%S<W=O<F0G("`@("`@("!087-S=V]R9"!F;W(@8W5R
M<F5N="!U<V5R+@H@*B`@("=S97)V97(G("`@("`@("`@(%1H92!H;W-T;F%M
M92!O9B!T:&4@24U34"!S97)V97(N"B`J("`@)W!O<G0G("`@("`@("`@("`@
M5&AE('!O<G0@;V8@=&AE($E-4U`@<V5R=F5R+@H@*B`@("=S;V-K970G("`@
M("`@("`@(%1H92!N86UE9"!S;V-K970@=&\@=7-E(&9O<B!C;VYN96-T:6]N
M"B`J("`@)V-O;6UA;F0G("`@("`@("`@4&%T:"!T;R!T:&4@:6UT97-T(&-O
M;6UA;F0@;VX@;&]C86QH;W-T"B`J("`@)V%U=&A?;65C:&%N:7-M)R`@075T
M:&5N=&EC871I;VX@;65T:&]D('1O('5S92!W:71H(&EM=&5S=#PO<')E/@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].971?24U34"])35-0+T%U=&@O:6UT
M97-T+G!H<"QV(#$N,3(N,BXT(#(P,#8O,#$O,#$@,C$Z,C@Z,C@@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@("`@("!,:6%M($AO96ME
M;F=A(#QL:6%M<D!U;6EC:"YE9'4^"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@
M36EC:&%E;"!2=6)I;G-K>2`\;7)U8FEN<VM`:&]R9&4N;W)G/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@3&EA;2!(;V5K96YG82`\;&EA;7)`=6UI
M8V@N961U/@H@*B!`875T:&]R("!-:6-H865L(%)U8FEN<VMY(#QM<G5B:6YS
M:T!H;W)D92YO<F<^"B`J($!P86-K86=E($YE=%])35-0"B`J+PIC;&%S<R!.
M971?24U34%]!=71H7VEM=&5S="!E>'1E;F1S($YE=%])35-07T%U=&@@>PH*
M("`@("\J*@H@("`@("H@4')I=F%T92!A=71H96YT:6-A=&EO;B!F=6YC=&EO
M;BX@(%!R;W9I9&5S(&%C='5A;`H@("`@("H@875T:&5N=&EC871I;VX@8V]D
M92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A
M;2`@;6EX960@("1P87)A;7,@2&%S:"!O9B!)35-0('!A<F%M971E<G,N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@3F5T7TE-4U`@;V)J96-T(&-O
M;FYE8W1E9"!T;R!S97)V97(@:68@<W5C8V5S<V9U;"P*("`@("`J("`@("`@
M("`@("`@("`@(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@)E]A=71H96YT:6-A=&4H)'!A<F%M<RD*("`@('L*("`@("`@
M("`D:6US<"`]("9.971?24U34#HZ<VEN9VQE=&]N*"=N;VYE)RP@)'!A<F%M
M<RD["B`@("`@("`@)&-O;6UA;F0@/2`G)SL*("`@("`@("`D97)R;W)?<F5T
M=7)N(#T@)R<["@H@("`@("`@(&EF("AS=')T;VQO=V5R*"1P87)A;7-;)V%U
M=&A?;65C:&%N:7-M)UTI(#T]("=G<W-A<&DG("8F"B`@("`@("`@("`@(&ES
M<V5T*"1?4T525D526R=+4D(U0T-.04U%)UTI*2!["B`@("`@("`@("`@("`@
M("`D8V]M;6%N9"`N/2`G2U)"-4-#3D%-13TG("X@)%]315)615);)TM20C5#
M0TY!344G73L*("`@("`@("!]"@H@("`@("`@("1C;VUM86YD("X]("<@)R`@
M("`N("1P87)A;7-;)V-O;6UA;F0G72X*("`@("`@("`@("`@("`@("`@("`G
M("UM("<@+B`D<&%R86US6R=A=71H7VUE8VAA;FES;2==("X*("`@("`@("`@
M("`@("`@("`@("`G("UU("<@+B!E<V-A<&5S:&5L;&%R9R@D<&%R86US6R=U
M<V5R;F%M92==*2`N"B`@("`@("`@("`@("`@("`@("`@)R`M82`G("X@97-C
M87!E<VAE;&QA<F<H)'!A<F%M<ULG=7-E<FYA;64G72D@+@H@("`@("`@("`@
M("`@("`@("`@("<@+7<@)R`N(&5S8V%P97-H96QL87)G*"1P87)A;7-;)W!A
M<W-W;W)D)UTI+@H@("`@("`@("`@("`@("`@("`@("<@+7`@)R`N("1P87)A
M;7-;)W!O<G0G72`N"B`@("`@("`@("`@("`@("`@("`@)R`M6"`G("X@)'!A
M<F%M<ULG<V]C:V5T)UT@+@H@("`@("`@("`@("`@("`@("`@("<@)R`@("`N
M("1P87)A;7-;)W-E<G9E<B==.PH*("`@("`@("`D8V]N;E]A='1E;7!T<R`]
M(#`["B`@("`@("`@=VAI;&4@*"1C;VYN7V%T=&5M<'1S*RL@/"`T*2!["B`@
M("`@("`@("`@("1A='1E;7!T<R`](#`["B`@("`@("`@("`@(&EF("@A9FEL
M95]E>&ES=',H)'!A<F%M<ULG<V]C:V5T)UTI*2!["B`@("`@("`@("`@("`@
M("!E>&5C*"1C;VUM86YD("X@)R`^("]D978O;G5L;"`R/B8Q)RD["B`@("`@
M("`@("`@("`@("!S;&5E<"@Q*3L*("`@("`@("`@("`@("`@('=H:6QE("@A
M9FEL95]E>&ES=',H)'!A<F%M<ULG<V]C:V5T)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@=7-L965P*#(P,#`P,"D["B`@("`@("`@("`@("`@("`@("`@
M:68@*"1A='1E;7!T<RLK(#X@-2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D97)R;W)?<F5T=7)N(#T@)SH@3F\@<V]C:V5T(&%F=&5R(#$P('-E8V]N
M9',@;V8@=')Y:6YG(2<["B`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I
M;G5E(#(["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1F<"`]($!F<V]C:V]P96XH
M)'!A<F%M<ULG<V]C:V5T)UTL(#`L("1E<G)O<E]N=6UB97(L("1E<G)O<E]S
M=')I;F<L(#,P*3L*("`@("`@("`@("`@)&5R<F]R7W)E='5R;B`]("1E<G)O
M<E]S=')I;F<["B`@("`@("`@("`@(&EF("@D9G`I(&)R96%K.PH@("`@("`@
M("`@("!U;FQI;FLH)'!A<F%M<ULG<V]C:V5T)UTI.PH*("`@("`@("!]"B`@
M("`@("`@+R]&86EL=7)E/PH@("`@("`@(&EF("@A96UP='DH)&5R<F]R7W)E
M='5R;BDI('L*("`@("`@("`@("`@<F5T=7)N("1I;7-P+3YI;7-P17)R;W(H
M)T-O;FYE8W1I;VX@=&\@24U34"!H;W-T(&9A:6QE9"XG("X@)SH@)R`N("1E
M<G)O<E]R971U<FXL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@
M("`@("`@("\O4W5C8V5S<PH@("`@("`@("1I;7-P+3Y?<W1R96%M(#T@)&9P
M.PH@("`@("`@(')E='5R;B`D:6US<#L*("`@('T*"B`@("`O*BH*("`@("`J
M($9O<F-E(&$@;&]G;W5T(&-O;6UA;F0@=&\@=&AE(&EM<W`@<W1R96%M+@H@
M("`@("H*("`@("`J+PH@("`@9G5N8W1I;VX@;&]G;W5T*"D*("`@('L*("`@
M("`@("`D=&AI<RT^7VEM<W`M/FQO9V]U="@I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@9')I=F5R('1Y<&4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!T>7!E(&]F('1H:7,@24U34%]!=71H(&1R
M:79E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1')I=F5R5'EP92@I"B`@
M("!["B`@("`@("`@<F5T=7)N("=I;71E<W0G.PH@("`@?0I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O3F5T+TE-
M4U`O075T:"]P;&%I;G1E>'0N<&AP````````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`W-#(Q`#$P-3$U-#,S-S4R`#`R,S,T-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@5&AE($YE
M=%])35-07T%U=&A?<&QA:6YT97AT(&-L87-S(&9O<B!)35-0(&%U=&AE;G1I
M8V%T:6]N+@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@
M)W5S97)N86UE)R`@57-E<FYA;64@=&\@;&]G;VX@=&\@24U34"!S97)V97(@
M87,N"B`J("`@)W!A<W-W;W)D)R`@4&%S<W=O<F0@9F]R(&-U<G)E;G0@=7-E
M<BX*("H@("`G<V5R=F5R)R`@("!4:&4@:&]S=&YA;64@;V8@=&AE($E-4U`@
M<V5R=F5R+@H@*B`@("=P;W)T)R`@("`@(%1H92!P;W)T(&]F('1H92!)35-0
M('-E<G9E<BX\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO3F5T7TE-
M4U`O24U34"]!=71H+W!L86EN=&5X="YP:'`L=B`Q+C<N,3`N,3$@,C`P-B\P
M,2\P,2`R,3HR.#HR."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M
M,C`P-B!-:6-H865L(%)U8FEN<VMY(#QM<G5B:6YS:T!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L(%)U8FEN<VMY(#QM
M<G5B:6YS:T!H;W)D92YO<F<^"B`J($!P86-K86=E($YE=%])35-0"B`J+PIC
M;&%S<R!.971?24U34%]!=71H7W!L86EN=&5X="!E>'1E;F1S($YE=%])35-0
M7T%U=&@@>PH*("`@("\J*@H@("`@("H@4')I=F%T92!A=71H96YT:6-A=&EO
M;B!F=6YC=&EO;BX@(%!R;W9I9&5S(&%C='5A;`H@("`@("H@875T:&5N=&EC
M871I;VX@8V]D92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J($!P87)A;2`@;6EX960@("1P87)A;7,@2&%S:"!O9B!)35-0('!A<F%M
M971E<G,N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@3F5T7TE-4U`@
M;V)J96-T(&-O;FYE8W1E9"!T;R!S97)V97(@:68@<W5C8V5S<V9U;"P*("`@
M("`J("`@("`@("`@("`@("`@(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@)E]A=71H96YT:6-A=&4H)'!A<F%M<RD*("`@
M('L*("`@("`@("`D:6US<"`]("9.971?24U34#HZ<VEN9VQE=&]N*"=N;VYE
M)RP@)'!A<F%M<RD["B`@("`@("`@)')E<W5L="`]("1I;7-P+3YI;FET*"D[
M"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@
M("`D=7-E<DED(#T@)'!A<F%M<ULG=7-E<FYA;64G73L*("`@("`@("`@)&-R
M961E;G1I86QS(#T@)'!A<F%M<ULG<&%S<W=O<F0G73L*"B`@("`@("`@+RH@
M4W1A<G0@=&AE(&-O;6UA;F0N("HO"B`@("`@("`@)')E<W5L="`]("1I;7-P
M+3YI;7-P4V5N9"@G3$]'24X@)RP@=')U92P@9F%L<V4I.PH@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`O*B!5<V5R;F%M
M92!A<R!A('M]/R`J+PH@("`@("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?3553
M5%]54T5?3$E415)!3"P@)'5S97))9"DI('L*("`@("`@("`@("`@)&)I57-E
M<B`]('-P<FEN=&8H)WLE9'TG+"!S=')L96XH)'5S97))9"DI.PH@("`@("`@
M("`@("`D<F5S=6QT(#T@)&EM<W`M/FEM<W!396YD*"1B:55S97(L(&9A;'-E
M+"!T<G5E*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<
M*R\B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EM<W`M/FEM<W!2
M96-E:79E*"DI*2!["@H@("`@("`@("`@("`@("`@<F5T=7)N("1I;7-P+3YI
M;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!E>'!E8W1E9"!C;VUM86YD(&-O
M;G1I;G5A=&EO;B!R97-P;VYS92!F<F]M($E-4U`@<V5R=F5R+B<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D
M<F5S=6QT(#T@)&EM<W`M/FEM<W!396YD*"1U<V5R260@+B`G("<L(&9A;'-E
M+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]
M"@H@("`@("`@("\J($1O;B=T('=A;G0@=&\@;&]G('1H92!P87-S=V]R9"$@
M*B\*("`@("`@("`D;&]G5F%L=64@/2`D:6US<"T^;&]G16YA8FQE9#L*("`@
M("`@("`D:6US<"T^;&]G16YA8FQE9"`](&9A;'-E.PH*("`@("`@("`O*B!0
M87-S(&%S('M]/R`J+PH@("`@("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?3553
M5%]54T5?3$E415)!3"P@)&-R961E;G1I86QS*2D@>PH@("`@("`@("`@("`D
M8FE087-S(#T@<W!R:6YT9B@G>R5D?2<L('-T<FQE;B@D8W)E9&5N=&EA;',I
M*3L*("`@("`@("`@("`@)')E<W5L="`]("1I;7-P+3YI;7-P4V5N9"@D8FE0
M87-S+"!F86QS92P@=')U92D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(7!R96=?
M;6%T8V@H(B]>7"LO(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I
M;7-P+3YI;7-P4F5C96EV92@I*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1I;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!E>'!E8W1E9"!C
M;VUM86YD(&-O;G1I;G5A=&EO;B!R97-P;VYS92!F<F]M($E-4U`@<V5R=F5R
M+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`D<F5S=6QT(#T@)&EM<W`M/FEM<W!396YD*"1C<F5D96YT:6%L
M<RP@9F%L<V4L('1R=64I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@?0H*("`@("`@("`O*B!297-T;W)E('1H92!L;V=G:6YG(&)O;VQE
M86XN("HO"B`@("`@("`@)&EM<W`M/FQO9T5N86)L960@/2`D;&]G5F%L=64[
M"@H@("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D:6US<"T^:6US<%)E8V5I
M=F4H*3L*("`@("`@("!I9B`H:7-?82@D<V5R=F5R7W)E<W!O;G-E+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<V5R=F5R7W)E<W!O
M;G-E.PH@("`@("`@('T*"B`@("`@("`@:68@*"1S97)V97)?<F5S<&]N<V4@
M(3T@)T]+)RD@>PH@("`@("`@("`@("!R971U<FX@)&EM<W`M/FEM<W!%<G)O
M<B@G3&]G:6X@=&\@24U34"!H;W-T(&9A:6QE9"XG+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;7-P.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1F]R8V4@82!L;V=O=70@8V]M;6%N9"!T;R!T
M:&4@:6US<"!S=')E86TN"B`@("`@*@H@("`@("HO"B`@("!F=6YC=&EO;B!L
M;V=O=70H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:6US<"T^;&]G;W5T*"D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&1R:79E<B!T>7!E
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@=&AE('1Y<&4@;V8@=&AI
M<R!)35-07T%U=&@@9')I=F5R"B`@("`@*B\*("`@("!F=6YC=&EO;B!G971$
M<FEV97)4>7!E*"D*("`@("!["B`@("`@("`@(')E='5R;B`G<&QA:6YT97AT
M)SL*("`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O3F5T+TE-4U`O075T:"YP:'``````````````````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q,#4W`#$P-3$U-#,S-S4R`#`R,3,S
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*<F5Q=6ER95]O;F-E("=.970O24U34"YP:'`G.PH*+RHJ"B`J(%1H
M92!.971?24U34%]!=71H(&-L87-S(&%B<W1R86-T(&-L87-S(&9O<B!)35-0
M(&%U=&AE;G1I8V%T:6]N+@H@*@H@*B!297%U:7)E9"!087)A;65T97)S.CQP
M<F4^"B`J("`@)W5S97)N86UE)R`@57-E<FYA;64@=&\@;&]G;VX@=&\@24U3
M4"!S97)V97(@87,N"B`J("`@)W!A<W-W;W)D)R`@4&%S<W=O<F0@9F]R(&-U
M<G)E;G0@=7-E<BX*("H@("`G<V5R=F5R)R`@("!4:&4@:&]S=&YA;64@;V8@
M=&AE($E-4U`@<V5R=F5R+@H@*B`@("=P;W)T)R`@("`@(%1H92!P;W)T(&]F
M('1H92!)35-0('-E<G9E<BX\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO3F5T7TE-4U`O24U34"]!=71H+G!H<"QV(#$N."XQ,"XQ,2`R,#`V+S`Q
M+S`Q(#(Q.C(X.C(W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR
M,#`V($UI8VAA96P@4G5B:6YS:WD@/&UR=6)I;G-K0&AO<F1E+F]R9SX*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4G5B:6YS:WD@/&UR
M=6)I;G-K0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@3F5T7TE-4U`*("HO"F-L
M87-S($YE=%])35-07T%U=&@@>PH@("`@+RHJ"B`@("`@*B!#;&%S<R!V87)I
M86)L92!T;R!H;VQD('1H92!R97-U;'1I;F<@3F5T7TE-4U`@;V)J96-T"B`@
M("`@*@H@("`@("H@0'9A<B!.971?24U34`H@("`@("HO"B`@("!V87(@)%]I
M;7-P.PH*("`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(&QO9VEN('1O($E-
M4U`@<V5R=F5R+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M("`@("`@("`@4&%R86UE=&5R<R!F;W(@3F5T7TE-4U`*("`@("`J($!P87)A
M;2!B;V]L96%N("1L;V=I;B`@("`@("`@4VAO=6QD('=E(')E;6%I;B!L;V=G
M960@:6X@869T97(@875T:#\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("`@("`@("`@("`@("`@(%)E='5R;G,@82!.971?24U34"!O8FIE8W0@8V]N
M;F5C=&5D('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('1H92!)35-0('-E<G9E<B!I9B!L;V=I;B!I<R!T<G5E(&%N9`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=6-C97-S9G5L+B`@4F5T
M=7)N<R!B;V]L96%N('1R=64@:68*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<W5C8V5S<V9U;"!A;F0@;&]G:6X@:7,@9F%L<V4N(%)E
M='5R;G,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!
M4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F875T
M:&5N=&EC871E*"1P87)A;7,L("1L;V=I;B`]('1R=64I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]I;7-P(#T@)B1T:&ES+3Y?875T:&5N=&EC871E*"1P87)A
M;7,I.PH*("`@("`@("!I9B`H:7-?82@D=&AI<RT^7VEM<W`L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<#L*("`@
M("`@("!]"@H@("`@("`@(&EF("@A)&QO9VEN*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?:6US<"T^;&]G;W5T*"D["B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<#L*("`@
M('T*"B`@("`O*BH*("`@("`J(%!R:79A=&4@875T:&5N=&EC871I;VX@9G5N
M8W1I;VXN(%!R;W9I9&5S(&%C='5A;"!A=71H96YT:6-A=&EO;@H@("`@("H@
M8V]D92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P
M87)A;2`@87)R87D@("`D<&%R86US("`@("`@4&%R86UE=&5R<R!F;W(@3F5T
M7TE-4U!?075T:"!D<FEV97(N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@("`@("`@("`@("`@("!2971U<FYS($YE=%])35-0(&]B:F5C="!C;VYN
M96-T960@=&\@<V5R=F5R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF('-U8V-E<W-F=6PL(%!%05)?17)R;W(@;VX@9F%I;'5R92X*
M("`@("`J($!A8G-T<F%C=`H@("`@("HO"B`@("!F=6YC=&EO;B`F7V%U=&AE
M;G1I8V%T92@D<&%R86US*0H@("`@>PH*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE('1Y<&4@;V8@=&AI<R!D<FEV97(N"B`@("`@*@H@("`@
M("H@0&%B<W1R86-T"B`@("`@*B!`<F5T=7)N('-T<FEN9R!4>7!E(&]F($E-
M4U!?075T:"!D<FEV97(@:6YS=&%N8V4*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T1')I=F5R5'EP92@I"B`@("!["@H@("`@?0H*("`@("\J*@H@("`@("H@
M1F]R8V4@82!L;V=O=70@9G)O;2!T:&4@=6YD97)L>6EN9R!)35-0('-T<F5A
M;2X*("`@("`J"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO9V]U="@I"B`@("![
M"@H@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@
M8V]N8W)E=&4@3F5T7TE-4U!?075T:"!I;G-T86YC92!B87-E9"!O;B`D9')I
M=F5R"B`@("`@*B!-=7-T(&)E(&-A;&QE9"!A<R`F3F5T7TE-4U!?075T:#HZ
M9F%C=&]R>2@I"B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<@)&1R:79E
M<B!4>7!E(&]F($YE=%])35-07T%U=&@@<W5B8VQA<W,@=&\@<F5T=7)N+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!C<F5A=&5D($YE=%])
M35-07T%U=&@@<W5B8VQA<W,@;W(@4$5!4E]%<G)O<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@)F9A8W1O<GDH)&1R:79E<BD*("`@('L*("`@("`@("`D9')I
M=F5R(#T@8F%S96YA;64H)&1R:79E<BD["@H@("`@("`@(&EF("AE;7!T>2@D
M9')I=F5R*2!\?"`H<W1R8VUP*"1D<FEV97(L("=N;VYE)RD@/3T@,"DI('L*
M("`@("`@("`@("`@)&%U=&@@/2`F;F5W($E-4U!?075T:"@I.PH@("`@("`@
M("`@("!R971U<FX@)&%U=&@["B`@("`@("`@?0H*("`@("`@("!I9B`H9FEL
M95]E>&ES=',H9&ER;F%M92A?7T9)3$5?7RD@+B`G+T%U=&@O)R`N("1D<FEV
M97(@+B`G+G!H<"<I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92!D:7)N
M86UE*%]?1DE,15]?*2`N("<O075T:"\G("X@)&1R:79E<B`N("<N<&AP)SL*
M("`@("`@("!]"@H@("`@("`@("1C;&%S<R`]("=.971?24U34%]!=71H7R<@
M+B`D9')I=F5R.PH*("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI
M('L*("`@("`@("`@("`@)&%U=&@@/2`F;F5W("1C;&%S<R@I.PH@("`@("`@
M("`@("!R971U<FX@)&%U=&@["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@2&]R9&4Z.F9A=&%L*%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5
M;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB*2P@)&-L87-S
M*2DL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@3F5T
M7TE-4U!?075T:"!I;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@("`@("H@
M5VEL;"!O;FQY(&-R96%T92!A(&YE=R!O8FIE8W0@:68@;VYE('=I=&@@=&AE
M('-A;64@<&%R86UE=&5R<R!A;')E861Y"B`@("`@*B!D;V5S(&YO="!E>&ES
M="X*("`@("`J($UU<W0@8F4@8V%L;&5D(&QI:V4Z("1V87(@/2`F3F5T7TE-
M4U!?075T:#HZ<VEN9VQE=&]N*"=D<FEV97)?='EP92<I.PH@("`@("H*("`@
M("`J($!P87)A;2`@<W1R:6YG("1D<FEV97(@5'EP92!O9B!)35-07T%U=&@@
M<W5B8VQA<W,@=&\@<F5T=7)N+@H@("`@("H*("`@("`J($!R971U<FX@;V)J
M96-T(%)E9F5R96YC92!T;R!)35-07T%U=&@@<W5B8VQA<W,N"B`@("`@*B\*
M("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)&1R:79E<BD*("`@('L*("`@("`@
M("!S=&%T:6,@)&EN<W1A;F-E<SL*("`@("`@("`O*B!#:&5C:R!F;W(@86YY
M(&EM=&5S="!D<FEV97(@:6YS=&%N8V5S(&%N9"!K:6QL('1H96TN"B`@("`@
M("`@("`@3W1H97)W:7-E+"!T:&4@<V]C:V5T('=I;&P@:&%N9R!B971W965N
M(')E<75E<W1S(&9R;VT*("`@("`@("`@("!S97!E<F%T92!D<FEV97)S("AA
M;B!!=71H(')E<75E<W0@86YD(&%N($]P=&EO;G,@<F5Q=65S="DN*B\*("`@
M("`@("!I9B`H:7-?87)R87DH)&EN<W1A;F-E<RDI('L*("`@("`@("`@("`@
M9F]R96%C:"`H)&EN<W1A;F-E<R!A<R`D;V)J*2!["B`@("`@("`@("`@("`@
M("!I9B`H)&]B:BT^9V5T1')I=F5R5'EP92@I(#T]("=I;71E<W0G*2!["B`@
M("`@("`@("`@("`@("`@("`@)&]B:BT^;&]G;W5T*"D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"%I
M<W-E="@D:6YS=&%N8V5S*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S(#T@
M87)R87DH*3L*("`@("`@("!]"@H@("`@("`@("1S:6=N871U<F4@/2!S97)I
M86QI>F4H87)R87DH)&1R:79E<BDI.PH@("`@("`@(&EF("@A:7-S970H)&EN
M<W1A;F-E<ULD<VEG;F%T=7)E72DI('L*("`@("`@("`@("`@)&EN<W1A;F-E
M<ULD<VEG;F%T=7)E72`]("9.971?24U34%]!=71H.CIF86-T;W)Y*"1D<FEV
M97(I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I
M9VYA='5R95T["B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TYE="])35-0+T)O;VLN<&AP````````````
M```````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$U,C`S-0`Q,#4Q-30S,S<U
M,@`P,C$S,S(`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"G)E<75I<F5?;VYC92`G3F5T+TE-4U`O075T:"YP:'`G
M.PH*+RHJ"B`J(%-T<FEN9R!O9B!S=7!P;W)T960@04-,(')I9VAT<RX*("HO
M"F1E9FEN92@G24U34%]!0TQ?4DE'2%13)RP@)VQR=V-D82<I.PH*+RHJ"B`J
M($YE=%])35-07T)O;VL@0VQA<W,@+2!P<F]V:61E<R!A<&D@9F]R(&1E86QI
M;F<@=VET:"!)35-0"B`J(&%D9')E<W,@8F]O:W,N"B`J"B`J(%)E<75I<F5D
M('!A<F%M971E<G,Z/'!R93X*("H@("`G=7-E<FYA;64G("`@("!5<V5R;F%M
M92!T;R!L;V=O;B!T;R!)35-0('-E<G9E<B!A<RX*("H@("`G<&%S<W=O<F0G
M("`@("!087-S=V]R9"!F;W(@8W5R<F5N="!U<V5R+@H@*B`@("=A=71H7VUE
M=&AO9"<@(%1H92!A=71H96YT:6-A=&EO;B!M971H;V0@=&\@=7-E('1O(&QO
M9VEN+@H@*B`@("=S97)V97(G("`@("`@(%1H92!H;W-T;F%M92!O9B!T:&4@
M24U34"!S97)V97(N"B`J("`@)W!O<G0G("`@("`@("`@5&AE('!O<G0@;V8@
M=&AE($E-4U`@<V5R=F5R+CPO<')E/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R].971?24U34"])35-0+T)O;VLN<&AP+'8@,2XQ-BXR+C(R(#(P,#8O,#$O
M,#$@,C$Z,C@Z,C@@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P
M,#8@36EC:&%E;"!2=6)I;G-K>2`\;7)U8FEN<VM`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!2=6)I;G-K>2`\;7)U
M8FEN<VM`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!.971?24U34`H@*B\*8VQA
M<W,@3F5T7TE-4U!?0F]O:R!["@H@("`@+RHJ"B`@("`@*B!3;W)T(&]R9&5R
M+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M<V]R="`]("=A<V-E;F0G.PH*("`@("\J*@H@("`@("H@3F5T7TE-4U`@;V)J
M96-T+@H@("`@("H*("`@("`J($!V87(@3F5T7TE-4U`*("`@("`J+PH@("`@
M=F%R("1?:6US<#L*"B`@("`O*BH*("`@("`J(%!A<F%M971E<B!L:7-T+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R
M86US.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(@9G5N8W1I;VXN"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@2&%S:"!C;VYT86EN
M:6YG($E-4U`@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@3F5T
M7TE-4U!?0F]O:R@D<&%R86US*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%R
M86US(#T@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J($EN:71I86QI
M>F%T:6]N(&9U;F-T:6]N('1O(&)E(&-A;&QE9"!A9G1E<B!O8FIE8W0@:7,@
M<F5T=7)N960N"B`@("`@*B!4:&ES(&%L;&]W<R!E<G)O<G,@=&\@;V-C=7(@
M86YD(&YO="!B<F5A:R!T:&4@<V-R:7!T+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!014%27T5R<F]R(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN:70H*0H@("`@>PH@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/E]I;7-P*2D@>PH@("`@("`@("`@("`D875T
M:"`]("9.971?24U34%]!=71H.CIS:6YG;&5T;VXH)'1H:7,M/E]P87)A;7-;
M)V%U=&A?;65T:&]D)UTI.PH@("`@("`@("`@("`D=&AI<RT^7VEM<W`@/2`D
M875T:"T^875T:&5N=&EC871E*"1T:&ES+3Y?<&%R86US*3L*("`@("`@("!]
M"@H@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?:6US<"P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P.PH@("`@("`@
M('T*("`@("`@("`D=&AI<RT^7VEM<W`M/G=R:71E5&],;V<H)TYE=%])35-0
M7T)O;VL@:6YI=&EA;&EZ960N)RP@7U]&24Q%7U\L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I
M.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!A;B!A<G)A>2!C;VYT86EN:6YG('1H92!N86UE<R!O9B!A;&P@
M=&AE(&%D9')E<W,@8F]O:W,*("`@("`J(&%V86EL86)L92!T;R!T:&4@;&]G
M9V5D(&EN('5S97(N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!!<G)A
M>2!O9B!A9&1R97-S(&)O;VL@;F%M97,@;W(@4$5!4E]%<G)O<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T061D<F5S<T)O;VM,:7-T*"D*("`@('L*("`@
M("`@("`D8V]M;6%N9%]S=')I;F<@/2`G041$4D534T)/3TL@*B<["@H@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1C;VUM86YD
M7W-T<FEN9RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L="PG4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R
M<F]R*"=#;VYN96-T:6]N('1O($E-4U`@:&]S="!F86EL960N)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L
M(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("\J($ET97)A=&4@=&AR
M;W5G:"!T:&4@<F5S<&]N<V4@86YD('!O<'5L871E(&%N(&%R<F%Y(&]F"B`@
M("`@("`@("H@861D<F5S<R!B;V]K(&YA;65S+B`J+PH@("`@("`@("1S97)V
M97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["B`@
M("`@("`@:68@*&ES7V$H)'-E<G9E<E]R97-P;VYS92P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'-E<G9E<E]R97-P;VYS93L*("`@
M("`@("!]"B`@("`@("`@)&%B;V]K<R`](&%R<F%Y*"D["@H@("`@("`@('=H
M:6QE("AP<F5G7VUA=&-H*"(O7EPJ($%$1%)%4U-"3T]++R(L("1S97)V97)?
M<F5S<&]N<V4I*2!["B`@("`@("`@("`@("\J($EF('1H:7,@:7,@86X@041$
M4D534T)/3TL@<F5S<&]N<V4L('1H96X@=&AI<R!W:6QL(&5X<&QO9&4@87,@
M<V\Z"B`@("`@("`@("`@("`J(%LP72!A;F0@6S%=(&-A;B!B92!D:7-C87)D
M960*("`@("`@("`@("`@("H@6S)=(#T@871T<FEB=71E<PH@("`@("`@("`@
M("`@*B!;,UT@/2!D96QI;6ET97(*("`@("`@("`@("`@("H@6S1=(#T@861D
M<F5S<R!B;V]K(&YA;64*("`@("`@("`@("`@("HO"@H@("`@("`@("`@("`O
M*B!&:7)S="P@8VAE8VL@9F]R(&$@>WT@*B\*("`@("`@("`@("`@:68@*'!R
M96=?;6%T8V@H24U34%]/0U1%5%]#3U5.5"P@)'-E<G9E<E]R97-P;VYS92P@
M)'1E;7!!<G)A>2DI('L*("`@("`@("`@("`@("`@("1A8F]O:W-;72`]("1T
M:&ES+3Y?:6US<"T^<F5C96EV95-T<FEN9TQI=&5R86PH)'1E;7!!<G)A>5LR
M72D["B`@("`@("`@("`@("`@("`O*B!'970@=&AE($-23$8@870@96YD(&]F
M($%$1%)%4U-"3T]+(')E<W!O;G-E"B`@("`@("`@("`@("`@("`@*B!T:&%T
M('1H92![?2!D;V5S(&YO="!I;F-L=61E+B`J+PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]I;7-P+3YR96-E:79E4W1R:6YG3&ET97)A;"@R*3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1P87)T<R`](&5X<&QO
M9&4H)R`G+"`D<V5R=F5R7W)E<W!O;G-E*3L*("`@("`@("`@("`@("`@("1N
M=6U087)T<R`](&-O=6YT*"1P87)T<RD["B`@("`@("`@("`@("`@("`D;F%M
M92`]("1P87)T<ULT73L*("`@("`@("`@("`@("`@("1F:7)S=$-H87(@/2!S
M=6)S='(H)&YA;64L(#`L(#$I.PH@("`@("`@("`@("`@("`@:68@*"1F:7)S
M=$-H87(@/3TB7"(B*2!["B`@("`@("`@("`@("`@("`@("`@)&YA;64@/2!L
M=')I;2@D;F%M92P@(EPB(BD["B`@("`@("`@("`@("`@("`@("`@9F]R("@D
M:2`](#4[("1I(#P@)&YU;5!A<G1S.R`D:2LK*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1N86UE("X]("<@)R`N("1P87)T<ULD:5T["B`@("`@("`@
M("`@("`@("`@("`@("`@("1L87-T0VAA<B`]('-U8G-T<B@D<&%R='-;)&E=
M+"!S=')L96XH)'!A<G1S6R1I72D@+2`Q+"`Q*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"1L87-T0VAA<B`]/2`B7"(B*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D;F%M92`](')T<FEM*"1N86UE+"`B7"(B*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&%B;V]K<UM=(#T@)&YA;64[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]
M("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*3L*("`@("`@("!]"@H@("`@
M("`@(&EF("@D<V5R=F5R7W)E<W!O;G-E("$]("=/2R<I('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@;F]T(')E
M8V5I=F4@=&AE(&5X<&5C=&5D(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BXG
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3Y?:6US<"T^=W)I=&54;TQO9R@G041$4D534T)/3TL@8V]M;6%N9"!/2RXG
M+"!?7T9)3$5?7RP@7U],24Y%7U\L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!014%27TQ/1U])3D9/*3L*("`@("`@("!R971U<FX@)&%B
M;V]K<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@87)R87D@
M8V]N=&%I;FEN9R!T:&4@;F%M97,@=&AA="!M871C:"`D<V5A<F-H"B`@("`@
M*B!C<FET97)A(&EN('1H92!A9&1R97-S(&)O;VL@;F%M960@)&%B;V]K+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%B;V]K("!!9&1R97-S(&)O
M;VL@;F%M92!T;R!S96%R8V@N"B`@("`@*B!`<&%R86T@87)R87D@)'-E87)C
M:"`@4V5A<F-H(&-R:71E<FEA(&EN('1H92!F;W)M(&]F"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`G9FEE;&1.86UE)R`]/B`G<V5A<F-H5&5R;2<@
M*&UA>2!I;F-L=61E("H@=VEL9"!C87)D*2X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D($%R<F%Y(&]F(&YA;65S(&]F('1H92!E;G1R:65S('1H870@
M;6%T8V@@;W(@4$5!4E]%<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5A
M<F-H*"1A8F]O:RP@)'-E87)C:"D*("`@('L*("`@("`@("`O+TEF(&YO(&9I
M96QD(#T^('9A;'5E('!A:7)S+"!A<W-U;64@=V4@87)E('-E87)C:&EN9R!N
M86UE+@H@("`@("`@("1C<FET97)I82`](&%R<F%Y*"D["B`@("`@("`@:68@
M*"%I<U]A<G)A>2@D<V5A<F-H*2D@>PH@("`@("`@("`@("`D8W)I=&5R:6%;
M)VYA;64G72`]("1S96%R8V@["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&-R:71E<FEA(#T@)'-E87)C:#L*("`@("`@("!]"@H@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"=314%20TA!1$1215-3
M("<L('1R=64L(&9A;'-E*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@("`@('T*"B`@("`@("`@+R\@1&\@=V4@;F5E9"!T;R!S96YD('1H92!A
M8F]O:R!N86UE(&%S('M](#\*("`@("`@("!I9B`H<')E9U]M871C:"A)35-0
M7TU54U1?55-%7TQ)5$5204PL("1A8F]O:RDI('L*("`@("`@("`@("`@)&)I
M0F]O:R`]('-P<FEN=&8H(GLE9'TB+"!S=')L96XH)&%B;V]K*2D["@H@("`@
M("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D8FE"
M;V]K+"!F86QS92P@=')U92D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH@("`@("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP@)')E<W5L="DI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO
M="!R96-E:79E(&5X<&5C=&5D(&-O;6UA;F0@8V]N=&EN=6%T:6]N(')E<W!O
M;G-E(&9R;VT@24U34"!S97)V97(N)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RQ?7TQ)3D5?7RD[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O4W1A<G0@<&%R
M<VEN9R!T:&4@<V5A<F-H(&%R<F%Y+@H@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^7VEM<W`M/FEM<W!396YD*"(D86)O;VLB+"!F86QS92P@9F%L<V4I.PH@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`D
M8V]U;G0@/2!C;W5N="@D8W)I=&5R:6$I.PH@("`@("`@("1C=7)R96YT(#T@
M,3L*("`@("`@("!F;W)E86-H("@D8W)I=&5R:6$@87,@)'-E87)C:%]F:65L
M9"`]/B`D<V5A<F-H*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M7VEM<W`M/FEM<W!396YD*"(@)'-E87)C:%]F:65L9"`B+"!F86QS92P@9F%L
M<V4I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@+R\@2&]W(&%B;W5T('1H92!S96%R8V@@
M=&5R;2!A<R!A('M]+@H@("`@("`@("`@("!I9B`H<')E9U]M871C:"A)35-0
M7TU54U1?55-%7TQ)5$5204PL("1S96%R8V@I*2!["B`@("`@("`@("`@("`@
M("`D8FE396%R8V@@/2!S<')I;G1F*")[)61](BP@<W1R;&5N*"1S96%R8V@I
M*3L*"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI
M;7-P4V5N9"@D8FE396%R8V@L(&9A;'-E+"!T<G5E*3L*("`@("`@("`@("`@
M("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM
M<W!296-E:79E*"D["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I
M9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP@)')E<W5L="DI('L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I
M9"!N;W0@<F5C96EV92!E>'!E8W1E9"!C;VUM86YD(&-O;G1I;G5A=&EO;B!R
M97-P;VYS92!F<F]M($E-4U`@<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)'-E87)C:"P@9F%L
M<V4L("1C=7)R96YT(#T]("1C;W5N="D["B`@("`@("`@("`@("`@("`D8W5R
M<F5N="LK.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@+R\@3VYL>2!S96YD('1H92!#<DQF(&EF('1H:7,@
M:7,@=&AE(&QA<W0@9FEE;&0O<V5A<F-H(&%T;VTN"B`@("`@("`@("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@G(B<@+B`D<V5A
M<F-H("X@)R(G+"!F86QS92P@)&-U<G)E;G0@/3T@)&-O=6YT*3L*("`@("`@
M("`@("`@("`@("1C=7)R96YT*RL["B`@("`@("`@("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("\O($=E="!T:&4@<F5S<&]N<V4N
M"B`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]("1T:&ES+3Y?:6US<"T^:6US
M<%)E8V5I=F4H*3L*("`@("`@("`D86)O;VM.86UE<R`]($%R<F%Y*"D["@H@
M("`@("`@('=H:6QE("AP<F5G7VUA=&-H*"(O7EPJ(%-%05)#2$%$1%)%4U,O
M(BP@)'-E<G9E<E]R97-P;VYS92DI('L*("`@("`@("`@("`@)&-H;W!P961?
M<F5S<&]N<V4@/0H@("`@("`@("`@("`@("`@<')E9U]R97!L86-E*"(O7EPJ
M(%-%05)#2$%$1%)%4U,O(BP@)R<L("1S97)V97)?<F5S<&]N<V4I.PH*("`@
M("`@("`@("`@+R\@1V5T(')I9"!O9B!A;GD@;&EN9V5R:6YG('%U;W1E<RX*
M("`@("`@("`@("`@)&-H;W!P961?<F5S<&]N<V4@/2!P<F5G7W)E<&QA8V4H
M(B]<(B\B+"`G)RP@)&-H;W!P961?<F5S<&]N<V4I.PH*("`@("`@("`@("`@
M+R\@4F5M;W9E(&%N>2!L:6YG97)I;F<@=VAI=&4@<W!A8V4@:6X@9G)O;G0@
M;VYL>2X*("`@("`@("`@("`@)'1E;7`@/2!L=')I;2@D8VAO<'!E9%]R97-P
M;VYS92D["@H@("`@("`@("`@("!I9B`H<')E9U]M871C:"@B+RA[*2A;,"TY
M77LQ+'TI*%Q])"DO(BP@)'1E;7`L("1T96UP07)R87DI*2!["B`@("`@("`@
M("`@("`@("`D9&%T85-I>F4@/2`D=&5M<$%R<F%Y6S)=.PH@("`@("`@("`@
M("`@("`@)'1E;7`@/2`D=&AI<RT^7VEM<W`M/G)E8V5I=F53=')I;F=,:71E
M<F%L*"1D871A4VEZ92D["@H@("`@("`@("`@("`@("`@+RH@1V5T('1H92!#
M4DQ&('-I;F-E('M](&1O97,@;F]T(&EN8VQU9&4@:70N("HO"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7VEM<W`M/G)E8V5I=F53=')I;F=,:71E<F%L*#(I
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D86)O;VM.86UE<UM=(#T@
M)'1E;7`["@H@("`@("`@("`@("`O+R!'970@=&AE(&YE>'0@<F5S<&]N<V4@
M;&EN92!F<F]M('1H92!S97)V97(N"B`@("`@("`@("`@("1S97)V97)?<F5S
M<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["B`@("`@("`@
M?0H*("`@("`@("`O+R!3:&]U;&0@8VAE8VL@9F]R($]+(&]R($)!1"!H97)E
M(&IU<W0@=&\@8F4@8V5R=&%I;BX*("`@("`@("!S=VET8V@@*"1S97)V97)?
M<F5S<&]N<V4I('L*("`@("`@("!C87-E("="040G.@H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)U1H92!)35-0('-E<G9E
M<B!D:60@;F]T('5N9&5R<W1A;F0@>6]U<B!R97%U97-T+B<@+B`@(CH@)&-O
M;6UA;F1?=&5X="(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@("!C87-E
M("=.3R<Z"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%
M<G)O<B@G24U34"!S97)V97(@:7,@=6YA8FQE('1O('!E<F9O<FT@>6]U<B!R
M97%U97-T+B<@+B`B.B`B("X@)'1H:7,M/E]I;7-P+3YL87-T4F%W17)R;W(L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@+RH@5&AI
M<R!A;&QO=W,@9F]R(&YO(')E<W5L=',@*B\*("`@("`@("!I9B`H8V]U;G0H
M)&%B;V]K3F%M97,I(#P@,2D@>PH@("`@("`@("`@("!R971U<FX@)&%B;V]K
M3F%M97,["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7VEM<W`M/G=R:71E
M5&],;V<H)U-%05)#2$%$1%)%4U,@8V]M;6%N9"!/2R<L(%]?1DE,15]?+"!?
M7TQ)3D5?7RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!
M4E],3T=?24Y&3RD["@H@("`@("`@("\O($1E=&5R;6EN92!T:&4@<V]R="!D
M:7)E8W1I;VX@86YD('!E<F9O<FT@=&AE('-O<G0N"B`@("`@("`@<W=I=&-H
M("@D=&AI<RT^<V]R="D@>PH@("`@("`@(&-A<V4@)V%S8V5N9"<Z"B`@("`@
M("`@("`@('-O<G0H)&%B;V]K3F%M97,I.PH@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@8V%S92`G9&5S8V5N9"<Z"B`@("`@("`@("`@(')S;W)T*"1A
M8F]O:TYA;65S*3L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&%B;V]K3F%M97,["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&%N(&%S<V]C:6%T:79E(&%R<F%Y(&]F(&$@<VEN9VQE(&%D
M9')E<W,@8F]O:R!E;G1R>2X*("`@("`J($YO=&4@=&AA="!T:&5R92!W:6QL
M(&%L=V%Y<R!B92!A("=N86UE)R!F:65L9"X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1A8F]O:R`@("`@("!.86UE(&]F('1H92!A9&1R97-S(&)O
M;VL@=&\@<V5A<F-H+@H@("`@("H@0'!A<F%M('-T<FEN9R`D96YT<GE.86UE
M("`G;F%M92<@871T<FEB=71E(&]F('1H92!E;G1R>2!T;R!R971R:65V90H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@07)R87D@8V]N=&%I;FEN9R!E
M;G1R>2!O<B!014%27T5R<F]R(&]N(&9A:6QU<F4@+R!N;R!M871C:"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T16YT<GDH)&%B;V]K+"`D96YT<GE.86UE
M*0H@("`@>PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!3
M96YD*"=&151#2$%$1%)%4U,@)RP@=')U92P@9F%L<V4I.PH@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("!I9B`H<')E9U]M
M871C:"A)35-07TU54U1?55-%7TQ)5$5204PL("1A8F]O:RDI('L*("`@("`@
M("`@("`@)&)I0F]O:R`]('-P<FEN=&8H(GLE9'TB+"!S=')L96XH)&%B;V]K
M*2D["@H@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P
M4V5N9"@D8FE";V]K+"!F86QS92P@=')U92D["B`@("`@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I
M9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*2DI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED
M(&YO="!R96-E:79E(&5X<&5C=&5D(&-O;6UA;F0@8V]N=&EN=6%T:6]N(')E
M<W!O;G-E(&9R;VT@24U34"!S97)V97(N)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@B)&%B;V]K("(L(&9A;'-E+"!F
M86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@
M("`@("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?35535%]54T5?3$E415)!3"P@
M)&5N=')Y3F%M92DI('L*("`@("`@("`@("`@)&)I3F%M92`]('-P<FEN=&8H
M(GLE9'TB+"!S=')L96XH)&5N=')Y3F%M92DI.PH*("`@("`@("`@("`@)')E
M<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)&)I3F%M92P@9F%L<V4L
M('1R=64I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"(O7EPK
M+R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VEM<W`M
M/FEM<W!296-E:79E*"DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!E>'!E8W1E
M9"!C;VUM86YD(&-O;G1I;G5A=&EO;B!R97-P;VYS92!F<F]M($E-4U`@<V5R
M=F5R+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H
M)&5N=')Y3F%M92P@9F%L<V4L('1R=64I.PH@("`@("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD
M*")<(B1E;G1R>4YA;65<(B(L(&9A;'-E+"!T<G5E*3L*("`@("`@("`@("`@
M:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM
M<W!296-E:79E*"D["@H@("`@("`@('-W:71C:"`H)'-E<G9E<E]R97-P;VYS
M92D@>PH@("`@("`@(&-A<V4@)T)!1"<Z"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G5&AE($E-4U`@<V5R=F5R(&1I9"!N
M;W0@=6YD97)S=&%N9"!Y;W5R(')E<75E<W0N)RP@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("!C87-E("=.3R<Z"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G3F\@96YT<GD@:6X@=&AI<R!A9&1R
M97-S(&)O;VL@;6%T8VAE<R!Y;W5R('%U97)Y+B<L(%]?1DE,15]?+"!?7TQ)
M3D5?7RD["B`@("`@("`@?0H*("`@("`@("`O+R!'970@=&AE(&1A=&$@:6X@
M86X@87-S;V-I871I=F4@87)R87DN"B`@("`@("`@)&5N=')Y(#T@)'1H:7,M
M/E]P87)S949E=&-H061D<F5S<U)E<W!O;G-E*"1S97)V97)?<F5S<&]N<V4I
M.PH*("`@("`@("`O+T=E="!T:&4@;F5X="!S97)V97(@<F5S<&]N<V4@+2T@
M=&AI<R`J<VAO=6QD*B!B92!T:&4@3TL@<F5S<&]N<V4N"B`@("`@("`@)'-E
M<G9E<E]R97-P;VYS92`]("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*3L*
M"B`@("`@("`@:68@*"1S97)V97)?<F5S<&]N<V4@(3T@)T]+)RD@>PH@("`@
M("`@("`@("`O+R!5;F5X<&5C=&5D(')E<W!O;G-E('1H<F]W(&5R<F]R(&)U
M="!S=&EL;"!C;VYT:6YU92!O;BX*("`@("`@("`@("`@)'1H:7,M/E]I;7-P
M+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!T:&4@97AP96-T960@<F5S
M<&]N<V4@9G)O;2!T:&4@<V5R=F5R+B<L7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?:6US<"T^=W)I=&54;TQO9R@G
M1D540TA!1$1215-3(&-O;7!L971E9"!/2R<L(%]?1DE,15]?+"!?7TQ)3D5?
M7RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?3$]'
M7TE.1D\I.PH@("`@("`@(')E='5R;B`D96YT<GD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#<F5A=&5S(&$@;F5W(&%D9')E<W,@8F]O:RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1A8F]O:TYA;64@1E5,3%D@455!3$E&245$
M(&YA;64@<W5C:"`G:F1O92YC;&EE;G1S)R!E=&,N+BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D(%1R=64@;VX@<W5C8V5S<R`O(%!%05)?17)R;W(@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E061D<F5S
M<T)O;VLH)&%B;V]K3F%M92D*("`@('L*("`@("`@("`D8V]M;6%N9%]T97AT
M(#T@)T-214%414%$1%)%4U-"3T]+("<["@H@("`@("`@(&EF("AP<F5G7VUA
M=&-H*$E-4U!?35535%]54T5?3$E415)!3"P@)&%B;V]K3F%M92DI('L*("`@
M("`@("`@("`@)&)I0F]O:R`]('-P<FEN=&8H(GLE9'TB+"!S=')L96XH)&%B
M;V]K3F%M92DI.PH*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US
M<"T^:6US<%-E;F0H)&-O;6UA;F1?=&5X="`N("1B:4)O;VLL('1R=64L('1R
M=64I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"(O7EPK+R(L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM
M<W!296-E:79E*"DI*2!["@H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@97AP96-T960@
M8V]M;6%N9"!C;VYT:6YU871I;VX@<F5S<&]N<V4@9G)O;2!)35-0('-E<G9E
M<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI
M;7-P4V5N9"@D86)O;VM.86UE+"!F86QS92P@=')U92D["B`@("`@("`@("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D8V]M;6%N9%]T
M97AT("X@)&%B;V]K3F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=')U92P@=')U92D["B`@("`@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`D<V5R=F5R7W)E<W!O;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P
M4F5C96EV92@I.PH@("`@("`@(&EF("AI<U]A*"1S97)V97)?<F5S<&]N<V4L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1S97)V97)?
M<F5S<&]N<V4["B`@("`@("`@?0H*("`@("`@("!S=VET8V@@*"1S97)V97)?
M<F5S<&]N<V4I('L*("`@("`@("!C87-E("=/2R<Z"B`@("`@("`@("`@("1T
M:&ES+3Y?:6US<"T^=W)I=&54;TQO9R@G0U)%051%041$4D534T)/3TL@8V]M
M<&QE=&5D($]+)RP@7U]&24Q%7U\L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!?7TQ)3D5?7RP@4$5!4E],3T=?24Y&3RD["B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH*("`@("`@("!C87-E("=.3R<Z"B`@("`@
M("`@("`@("\O($-O=6QD(&YO="!C<F5A=&4@86)O;VLN"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G24U34"!S97)V97(@
M:7,@=6YA8FQE('1O('!E<F9O<FT@>6]U<B!R97%U97-T+B<L(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["@H@("`@("`@(&-A<V4@)T)!1"<Z"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G5&AE($E-4U`@<V5R
M=F5R(&1I9"!N;W0@=6YD97)S=&%N9"!Y;W5R(')E<75E<W0N)RP@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@
M+R\@4V]M971H:6YG('5N97AP96-T960N"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E:79E('1H92!E
M>'!E8W1E9"!R97-P;VYS92!F<F]M('1H92!S97)V97(N)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5L
M971E<R!A;B!A9&1R97-S(&)O;VL@8V]M<&QE=&5L>2$*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1A8F]O:TYA;64@3F%M92!O9B!A9&1R97-S(&)O
M;VL@=&\@9&5L971E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@=')U
M92!O;B!S=6-C97-S("\@4$5!4E]%<G)O<B!O;B!F86EL=7)E"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&1E;&5T94%D9')E<W-";V]K*"1A8F]O:TYA;64I"B`@
M("!["B`@("`@("`@)&-O;6UA;F1?=&5X="`]("=$14Q%5$5!1$1215-30D]/
M2R`G.PH*("`@("`@("`O+R!#:&5C:R!N965D(&9O<B![?2X*("`@("`@("!I
M9B`H<')E9U]M871C:"A)35-07TU54U1?55-%7TQ)5$5204PL("1A8F]O:TYA
M;64I*2!["B`@("`@("`@("`@("1B:4)O;VL@/2!S<')I;G1F*")[)61](BP@
M<W1R;&5N*"1A8F]O:TYA;64I*3L*"B`@("`@("`@("`@("1R97-U;'0@/2`D
M=&AI<RT^7VEM<W`M/FEM<W!396YD*"1C;VUM86YD7W1E>'0@+B`D8FE";V]K
M+"!T<G5E+"!T<G5E*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@A<')E9U]M871C
M:"@B+UY<*R\B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]I;7-P+3YI;7-P4F5C96EV92@I*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@
M97AP96-T960@8V]M;6%N9"!C;VYT:6YU871I;VX@<F5S<&]N<V4@9G)O;2!)
M35-0('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/E]I;7-P+3YI;7-P4V5N9"@D86)O;VM.86UE+"!F86QS92P@=')U92D["B`@
M("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H
M)&-O;6UA;F1?=&5X="`N("1A8F]O:TYA;64L('1R=64L('1R=64I.PH@("`@
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]("1T:&ES+3Y?
M:6US<"T^:6US<%)E8V5I=F4H*3L*("`@("`@("!I9B`H:7-?82@D<V5R=F5R
M7W)E<W!O;G-E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<V5R=F5R7W)E<W!O;G-E.PH@("`@("`@('T*"B`@("`@("`@<W=I=&-H
M("@D<V5R=F5R7W)E<W!O;G-E*2!["B`@("`@("`@8V%S92`G3TLG.@H@("`@
M("`@("`@("`D=&AI<RT^7VEM<W`M/G=R:71E5&],;V<H)T1%3$5414%$1%)%
M4U-"3T]+(&-O;7!L971E9"!/2R<L(%]?1DE,15]?+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@7U],24Y%7U\L(%!%05)?3$]'7TE.
M1D\I.PH@("`@("`@("`@("!R971U<FX@=')U93L*"B`@("`@("`@8V%S92`G
M3D\G.@H@("`@("`@("`@("`O+R!#;W5L9"!N;W0@1$5,151%(&%B;V]K+@H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)TE-
M4U`@<V5R=F5R(&ES('5N86)L92!T;R!P97)F;W)M('EO=7(@<F5Q=65S="XG
M+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@("!C87-E("="040G.@H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)U1H
M92!)35-0('-E<G9E<B!D:60@;F]T('5N9&5R<W1A;F0@>6]U<B!R97%U97-T
M+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["@H@("`@("`@(&1E9F%U;'0Z"B`@
M("`@("`@("`@("\O(%-O;65T:&EN9R!U;F5X<&5C=&5D+@H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C
M96EV92!T:&4@97AP96-T960@<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R+B<L
M(%]?1DE,15]?+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@7U],24Y%7U\I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E;F%M97,@86X@861D<F5S<R!B;V]K+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&%B;V]K3VQD3F%M92!/;&0@;F%M92X*("`@("`J
M($!P87)A;2!S=')I;F<@)&%B;V]K3F5W3F%M92!.97<@861D<F5S<R!B;V]K
M(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!4<G5E("\@4$5!
M4E]%<G)O<@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YA;65!9&1R97-S0F]O
M:R@D86)O;VM/;&1.86UE+"`D86)O;VM.97=.86UE*0H@("`@>PH@("`@("`@
M("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"=214Y!345!1$12
M15-30D]/2R`G+"!T<G5E+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("!]"@H@("`@("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?
M35535%]54T5?3$E415)!3"P@)&%B;V]K3VQD3F%M92DI('L*("`@("`@("`@
M("`@)&)I3VQD3F%M92`]('-P<FEN=&8H(GLE9'TB+"!S=')L96XH)&%B;V]K
M3VQD3F%M92DI.PH*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US
M<"T^:6US<%-E;F0H)&)I3VQD3F%M92P@9F%L<V4L('1R=64I.PH@("`@("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH@("`@("`@
M('T*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H
M(B1A8F]O:T]L9$YA;64@(BP@9F%L<V4L(&9A;'-E*3L*("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@:68@*'!R96=?;6%T
M8V@H24U34%]-55-47U5315],251%4D%,+"`D86)O;VM.97=.86UE*2D@>PH@
M("`@("`@("`@("`D8FE.97=.86UE(#T@<W!R:6YT9B@B>R5D?2(L('-T<FQE
M;B@D86)O;VM.97=.86UE*2D["@H@("`@("`@("`@("`D<F5S=6QT(#T@)'1H
M:7,M/E]I;7-P+3YI;7-P4V5N9"@D8FE.97=.86UE+"!F86QS92P@=')U92D[
M"B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*3L*
M("`@("`@("!]"@H@("`@("`@("\O($-23$8@<VEN8V4@;&%S="!P87)T+@H@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1A8F]O
M:TYE=TYA;64L(&9A;'-E+"!T<G5E*3L*("`@("`@("!I9B`H:7-?82@D<F5S
M=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@('T*"B`@("`@("`@+R\@1V5T('-E<G9E<B!R97-P;VYS
M92X*("`@("`@("`D<V5R=F5R7W)E<W!O;G-E(#T@)'1H:7,M/E]I;7-P+3YI
M;7-P4F5C96EV92@I.PH*("`@("`@("!S=VET8V@@*"1S97)V97)?<F5S<&]N
M<V4I('L*("`@("`@("!C87-E("=.3R<Z"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G24U34"!S97)V97(@:7,@=6YA8FQE
M('1O('!E<F9O<FT@>6]U<B!R97%U97-T+B<L(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["@H@("`@("`@(&-A<V4@)T)!1"<Z"B`@("`@("`@("`@("\O(%-Y;G1A
M>"!P<F]B;&5M+@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI
M;7-P17)R;W(H)U1H92!)35-0('-E<G9E<B!D:60@;F]T('5N9&5R<W1A;F0@
M>6]U<B!R97%U97-T+B<I.PH*("`@("`@("!C87-E("=/2R<Z"B`@("`@("`@
M("`@("1T:&ES+3Y?:6US<"T^=W)I=&54;TQO9R@B061D<F5S<R!B;V]K("1A
M8F]O:T]L9$YA;64@<W5C8V5S<V9U;&QY"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8VAA;F=E9"!T;R`D86)O;VM.97=.86UE(BP@
M7U]&24Q%7U\L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@7U],24Y%7U\L(%!%05)?3$]'7TE.1D\I.PH@("`@("`@("`@("!R971U
M<FX@=')U93L*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@=&AE
M(&5X<&5C=&5D(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BXG+"!?7T9)3$5?
M7RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%]?3$E.15]?*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!
M9&1S(&%N(&%D9')E<W,@8F]O:R!E;G1R>2!T;R!A;B!A9&1R97-S(&)O;VLN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D86)O;VL@("`@($YA;64@
M;V8@861D<F5S<R!B;V]K('1O(&%D9"!E;G1R>2!T;RX*("`@("`J($!P87)A
M;2!A<G)A>2`D96YT<GE);F9O("!!9&1R97-S(&)O;VL@96YT<GD@:6YF;W)M
M871I;VX@+0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('1H97)E
M($U54U0@8F4@82!F:65L9"`G;F%M92<@8V]N=&%I;FEN9R!T:&4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("!E;G1R>2!N86UE+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@5')U92!O;B!S=6-C97-S("\@4$5!4E]%
M<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1%;G1R
M>2@D86)O;VLL("1E;G1R>4EN9F\I"B`@("!["B`@("`@("`@)&-O;6UA;F1?
M=&5X="`]("<G.PH*("`@("`@("!I9B`H9V5T5'EP92@D96YT<GE);F9O*2`A
M/2`G87)R87DG*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M
M/FEM<W!%<G)O<BA)35-07T)!1%]!4D=5345.5"P@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("!]"@H@("`@("`@("\O($QO8VL@=&AE(&5N=')Y(&EF
M(&ET(&%L<F5A9'D@97AI<W1S+@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M;&]C:T5N=')Y*"1A8F]O:RP@)&5N=')Y26YF;ULG;F%M92==*3L*("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)U-43U)%041$4D534R`G+"!T
M<G5E+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("!]"@H@("`@("`@("\O(%1A:V4@8V%R92!O9B!T:&4@;F%M92X*("`@("`@
M("`D96YT<GE.86UE(#T@)&5N=')Y26YF;ULG;F%M92==.PH*("`@("`@("`O
M+R![?2!F;W(@8F]O:R!N86UE/PH@("`@("`@(&EF("AP<F5G7VUA=&-H*$E-
M4U!?35535%]54T5?3$E415)!3"P@)&%B;V]K*2D@>PH@("`@("`@("`@("`D
M8FE";V]K(#T@<W!R:6YT9B@B>R5D?2(L('-T<FQE;B@D86)O;VLI*3L*"B`@
M("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1B
M:4)O;VLL(&9A;'-E+"!T<G5E*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?
M:6US<"T^:6US<%)E8V5I=F4H*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3Y?:6US<"T^:6US<%-E;F0H(B1A8F]O:R`B+"!F86QS92P@9F%L<V4I.PH*
M("`@("`@("`O+R!$;R!W92!N965D('M](&9O<B!E;G1R>2!N86UE(&%S('=E
M;&P_"B`@("`@("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%
M4D%,+"`D96YT<GE.86UE*2D@>PH@("`@("`@("`@("`D8FEN86UE(#T@<W!R
M:6YT9B@B>R5D?2(L('-T<FQE;B@D96YT<GE.86UE*2D["B`@("`@("`@("`@
M("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)&)I;F%M92P@9F%L<V4L('1R=64I
M.PH@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["B`@
M("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)&5N=')Y3F%M92P@
M9F%L<V4L(&9A;'-E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M=&AI<RT^7VEM<W`M/FEM<W!396YD*")<(B1E;G1R>4YA;65<(B`B+"!F86QS
M92P@9F%L<V4I.PH@("`@("`@('T*"B`@("`@("`@=VAI;&4@*&QI<W0H)&ME
M>2P@)'9A;'5E*2`](&5A8V@H)&5N=')Y26YF;RDI('L*("`@("`@("`@("`@
M+R\@1&\@;F]T('-E;G0@=&AE(&ME>2!N86UE("=N86UE)RX*("`@("`@("`@
M("`@:68@*"1K97D@(3T@)VYA;64G*2!["B`@("`@("`@("`@("`@("`O+R!0
M<F]T96-T(&9R;VT@97AT<F%N96]U<R!W:&ET92!S<&%C90H@("`@("`@("`@
M("`@("`@)'9A;'5E(#T@=')I;2@D=F%L=64I.PH*("`@("`@("`@("`@("`@
M("\O($9O<B!S;VUE(')E87-O;BP@=&%B<R!S965M('1O(&)R96%K('1H:7,N
M"B`@("`@("`@("`@("`@("`D=F%L=64@/2!P<F5G7W)E<&QA8V4H(B]<="\B
M+"`B7&Y<<B(L("1V86QU92D["@H@("`@("`@("`@("`@("`@+R\@0VAE8VL@
M=&\@<V5E(&EF('=E(&YE960@>WT*("`@("`@("`@("`@("`@(&EF("AP<F5G
M7VUA=&-H*$E-4U!?35535%]54T5?3$E415)!3"P@)'9A;'5E*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1C;VUM86YD7W1E>'0@+CT@)&ME>2`N('-P<FEN
M=&8H(B![)61](BP@<W1R;&5N*"1V86QU92DI.PH*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1C;VUM86YD7W1E>'0L(&9A
M;'-E+"!T<G5E*3L*("`@("`@("`@("`@("`@("`@("`D<V5R=F5R7W)E<W!O
M;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH@("`@("`@("`@
M("`@("`@("`@("1C;VUM86YD7W1E>'0@/2`G)SL@+R]#;&5A<B!T:&4@8V]M
M;6%N9%]T97AT(&)U9F9E<@H*("`@("`@("`@("`@("`@("`@("!I9B`H(7!R
M96=?;6%T8V@H(B]>7"LO(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'-E<G9E<E]R97-P;VYS92DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@
M;F]T(')E8V5I=F4@=&AE(&5X<&5C=&5D(')E<W!O;G-E(&9R;VT@=&AE('-E
M<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@("\O(%-E;F0@
M=&AE('-T<FEN9R!O9B!O8W1E=',@86YD(&)E('-U<F4@3D]4('1O"B`@("`@
M("`@("`@("`@("`@("`@+R\@96YD('=I=&@@0U),1BX*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1V86QU92P@9F%L<V4L
M(&9A;'-E*3L*"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("\O($EF('=E(&%R92!H97)E+"!T:&5N('=E(&1O(&YO="!N
M965D('1O('-E;F0@80H@("`@("`@("`@("`@("`@("`@("\O('M]+@H@("`@
M("`@("`@("`@("`@("`@("1V86QU92`](")<(B(@+B`D=F%L=64@+B`B7"(B
M.PH@("`@("`@("`@("`@("`@("`@("1C;VUM86YD7W1E>'0@+CT@)&ME>2`N
M("<@)R`N("1V86QU92`N("<@)SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@4V5N9"!A;GET:&EN9R!T
M:&%T(&ES(&QE9G0@;V8@=&AE(&-O;6UA;F0N"B`@("`@("`@)'1H:7,M/E]I
M;7-P+3YI;7-P4V5N9"@D8V]M;6%N9%]T97AT+"!F86QS92P@=')U92D["B`@
M("`@("`@)'-E<G9E<E]R97-P;VYS92`]("1T:&ES+3Y?:6US<"T^:6US<%)E
M8V5I=F4H*3L*"B`@("`@("`@<W=I=&-H("@D<V5R=F5R7W)E<W!O;G-E*2![
M"B`@("`@("`@8V%S92`G3D\G.@H@("`@("`@("`@("`O+U-O<G)Y+BXN8V%N
M;F]T(&1O(&ET+@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI
M;7-P17)R;W(H)TE-4U`@<V5R=F5R(&ES('5N86)L92!T;R!P97)F;W)M('EO
M=7(@<F5Q=65S="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@("!C
M87-E("="040G.@H@("`@("`@("`@("`O+U-O<G)Y+BXN9&ED(&YO="!U;F1E
M<G-T86YD('EO=0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI
M;7-P17)R;W(H)U1H92!)35-0('-E<G9E<B!D:60@;F]T('5N9&5R<W1A;F0@
M>6]U<B!R97%U97-T+B<L(%]?1DE,15]?+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@7U],24Y%7U\I.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"1S97)V97)?<F5S<&]N<V4@(3T@)T]+)RD@>PH@("`@
M("`@("`@("`O+R!#>7)U<RU)35-0('-E<G9E<B!S96YD<R!A($9%5$-(041$
M4D534R!297-P;VYS92!H97)E+@H@("`@("`@("`@("`O+R!$;R!O=&AE<G,_
M("`@("!4:&ES('=A<R!N;W0@:6X@=&AE(%)&0RX*("`@("`@("`@("`@)&1U
M;6UY7V%R<F%Y(#T*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5&971C
M:$%D9')E<W-297-P;VYS92@D<V5R=F5R7W)E<W!O;G-E*3L*"B`@("`@("`@
M("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E
M:79E*"D["@H@("`@("`@("`@("!S=VET8V@@*"1S97)V97)?<F5S<&]N<V4I
M('L*("`@("`@("`@("`@8V%S92`G3D\G.@H@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=)35-0('-E<G9E<B!I<R!U
M;F%B;&4@=&\@<&5R9F]R;2!Y;W5R(')E<75E<W0N)RP@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@("`@("`@("`@8V%S92`G0D%$)SH*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G5&AE($E-4U`@
M<V5R=F5R(&1I9"!N;W0@=6YD97)S=&%N9"!Y;W5R(')E<75E<W0N)RP@7U]&
M24Q%7U\L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@7U],24Y%7U\I.PH@("`@("`@("`@("!C87-E("=/2R<Z"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/G=R:71E5&],;V<H)U-43U)%
M041$4D534R!#;VUP;&5T960@<W5C8V5S<V9U;&QY+B<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U])3D9/*3L*"B`@("`@("`@("`@("`@("`O+W=E('=E
M<F4@<W5C8V5S<V9U;"XN+G-O(')E;&5A<V4@=&AE(&QO8VL@;VX@=&AE(&5N
M=')Y"B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YU;FQO8VM%;G1R>2@D
M86)O;VLL("1E;G1R>4EN9F];)VYA;64G72DI('L*("`@("`@("`@("`@("`@
M("`@("`O+V-O=6QD(&YO="!R96QE87-E(&QO8VL*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)U1H870@861D
M<F5S<R!B;V]K(&5N=')Y(&ES(&QO8VME9"!O<B!R96%D(&]N;'D@9F]R('1H
M92!C=7)R96YT('5S97(N)RP@7U]&24Q%7U\L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?3$E.15]?*3L*
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!R971U<FX@=')U
M93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($1E;&5T97,@86X@86)O;VL@96YT<GDN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D86)O;VL@("`@($YA;64@;V8@861D<F5S<R!B;V]K(&-O
M;G1A:6YI;F<@96YT<GDN"B`@("`@*B!`<&%R86T@<W1R:6YG("1B;V]K16YT
M<GD@3F%M92!O9B!E;G1R>2!T;R!D96QE=&4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"!4<G5E(&]N('-U8V-E<W,@+R!014%27T5R<F]R(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T945N=')Y*"1A8F]O
M:RP@)&)O;VM%;G1R>2D*("`@('L*("`@("`@("`O+R!3=&%R="!T:&4@8V]M
M;6%N9"X*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N
M9"@G1$5,151%041$4D534R`G+"!T<G5E+"!F86QS92D["B`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("\O($YE960@>WT@
M9F]R(&)O;VL@;F%M93\*("`@("`@("!I9B`H<')E9U]M871C:"A)35-07TU5
M4U1?55-%7TQ)5$5204PL("1A8F]O:RDI('L*("`@("`@("`@("`@)&)I0F]O
M:R`]('-P<FEN=&8H(GLE9'TB+"!S=')L96XH)&%B;V]K*2D["@H@("`@("`@
M("`@("`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1B:4)O;VLL(&9A;'-E+"!T
M<G5E*3L*"B`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<*R\B+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P
M4F5C96EV92@I*2D@>PH*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E:79E(&5X<&5C=&5D(&-O
M;6UA;F0@8V]N=&EN=6%T:6]N(')E<W!O;G-E(&9R;VT@24U34"!S97)V97(N
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"@H@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@B)&%B;V]K
M("(L(&9A;'-E+"!F86QS92D["@H@("`@("`@("\O2&]W(&)O=70@9F]R('1H
M92!E;G1R>2!N86UE/PH@("`@("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?3553
M5%]54T5?3$E415)!3"P@)&)O;VM%;G1R>2DI('L*("`@("`@("`@("`@)&)I
M16YT<GD@/2!S<')I;G1F*")[)61](BP@<W1R;&5N*"1B;V]K16YT<GDI*3L*
M"B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)&)I16YT<GDL
M(&9A;'-E+"!T<G5E*3L*"B`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@B
M+UY<*R\B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I
M;7-P+3YI;7-P4F5C96EV92@I*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@97AP
M96-T960@8V]M;6%N9"!C;VYT:6YU871I;VX@<F5S<&]N<V4@9G)O;2!)35-0
M('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@
M('T*"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&)O;VM%;G1R>2`]
M("1T:&ES+3Y?:6US<"T^<75O=&53<&%C9613=')I;F<H)&)O;VM%;G1R>2D[
M"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1B
M;V]K16YT<GDL(&9A;'-E+"!T<G5E*3L*("`@("`@("`D<V5R=F5R7W)E<W!O
M;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH*("`@("`@("!S
M=VET8V@@*"1S97)V97)?<F5S<&]N<V4I('L*("`@("`@("!C87-E("=.3R<Z
M"B`@("`@("`@("`@("\O4V]R<GDN+F-A;FYO="!D;R!I=`H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)TE-4U`@<V5R=F5R
M(&ES('5N86)L92!T;R!P97)F;W)M('EO=7(@<F5Q=65S="XG+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@(&-A<V4@)T)!1"<Z"B`@("`@("`@("`@
M("\O1&\@;F]T(&MN;W<@=VAA="!Y;W5R('1A;&MI;F<@86)O=70*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=4:&4@24U3
M4"!S97)V97(@9&ED(&YO="!U;F1E<G-T86YD('EO=7(@<F5Q=65S="XG+"!?
M7T9)3$5?7RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%]?3$E.15]?*3L*("`@("`@("!C87-E("=/2R<Z"B`@("`@("`@
M("`@("1T:&ES+3Y?:6US<"T^=W)I=&54;TQO9R@G1$5,151%($-O;7!L971E
M9"!S=6-C97-S9G5L;'DN)RP@7U]&24Q%7U\L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!?7TQ)3D5?7RP@4$5!4E],3T=?24Y&3RD[
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($%T=&5M<'1S('1O(&%C<75I<F4@82!S96UA<&AO<F4@
M;VX@=&AE(&%D9')E<W,@8F]O:R!E;G1R>2X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1A8F]O:R`@("`@061D<F5S<R!B;V]K(&YA;64*("`@("`J
M($!P87)A;2!S=')I;F<@)&)O;VM%;G1R>2!.86UE(&]F(&5N=')Y('1O(&QO
M8VL*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D('1R=64@;W(@87)R87D@
M;VX@<W5C8V5S<R!A;F0@4$5!4E]%<G)O<B!O;B!F86EL=7)E"B`@("`@*B`@
M("`@("`@("`@("`@("AS97)V97(@9&5P96YD:6YG*0H@("`@("HO"B`@("!F
M=6YC=&EO;B!L;V-K16YT<GDH)&%B;V]K+"`D8F]O:T5N=')Y*0H@("`@>PH@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"=,3T-+
M($%$1%)%4U-"3T]+("<L('1R=64L(&9A;'-E*3L*("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@+R\@1&\@=V4@;F5E9"!A
M('-T<FEN9R!L:71E<F%L/PH@("`@("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?
M35535%]54T5?3$E415)!3"P@)&%B;V]K*2D@>PH@("`@("`@("`@("`D8FE"
M;V]K(#T@<W!R:6YT9B@B>R5D?2(L('-T<FQE;B@D86)O;VLI*3L*"B`@("`@
M("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)&)I0F]O:RP@9F%L<V4L
M('1R=64I.PH*("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"(O7EPK+R(L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM
M<W!296-E:79E*"DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]I;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!E>'!E8W1E9"!C
M;VUM86YD(&-O;G1I;G5A=&EO;B!R97-P;VYS92!F<F]M($E-4U`@<V5R=F5R
M+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@B)&%B;V]K
M("(L(&9A;'-E+"!F86QS92D["@H@("`@("`@("\O(%=H870@86)O=70@=&AE
M(&5N=')Y(&YA;64_"B`@("`@("`@:68@*'!R96=?;6%T8V@H24U34%]-55-4
M7U5315],251%4D%,+"`D8F]O:T5N=')Y*2D@>PH@("`@("`@("`@("`D8FE%
M;G1R>2`]('-P<FEN=&8H(GLE9'TB+"!S=')L96XH)&)O;VM%;G1R>2DI.PH*
M("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D8FE%;G1R>2P@
M9F%L<V4L('1R=64I.PH*("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"(O
M7EPK+R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VEM
M<W`M/FEM<W!296-E:79E*"DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!E>'!E
M8W1E9"!C;VUM86YD(&-O;G1I;G5A=&EO;B!R97-P;VYS92!F<F]M($E-4U`@
M<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D8F]O:T5N
M=')Y+"!F86QS92P@=')U92D["@H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1B;V]K16YT<GD@/2`D=&AI<RT^7VEM<W`M/G%U;W1E4W!A8V5D4W1R
M:6YG*"1B;V]K16YT<GDI.PH@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM
M<W!396YD*"(D8F]O:T5N=')Y(BP@9F%L<V4L('1R=64I.PH@("`@("`@('T*
M"B`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]("1T:&ES+3Y?:6US<"T^:6US
M<%)E8V5I=F4H*3L*"B`@("`@("`@9&\@>PH*("`@("`@("`@("`@<W=I=&-H
M("@D<V5R=F5R7W)E<W!O;G-E*2!["@H@("`@("`@("`@("!C87-E("=.3R<Z
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R
M;W(H)U1H870@861D<F5S<R!B;V]K(&5N=')Y(&ES(&QO8VME9"!O<B!R96%D
M(&]N;'D@9F]R('1H92!C=7)R96YT('5S97(N)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@("`@("!C87-E("="040G.@H@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=4:&4@24U34"!S
M97)V97(@9&ED(&YO="!U;F1E<G-T86YD('EO=7(@<F5Q=65S="XG+"!?7T9)
M3$5?7RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("\O0VAE8VL@=&\@<V5E(&EF('1H:7,@:7,@82!&151#2$%$1%)%4U,@<F5S
M;VYS90H@("`@("`@("`@("`D9'5M;7D@/2`D=&AI<RT^7W!A<G-E1F5T8VA!
M9&1R97-S4F5S<&]N<V4H)'-E<G9E<E]R97-P;VYS92D["@H@("`@("`@("`@
M("!I9B`H)&1U;6UY*2!["B`@("`@("`@("`@("`@("`D<V5R=F5R7W)E<W!O
M;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH@("`@("`@("`@
M("!]"@H@("`@("`@('T@=VAI;&4@*"1S97)V97)?<F5S<&]N<V4@(3T@)T]+
M)RD["@H@("`@("`@("1T:&ES+3Y?:6US<"T^=W)I=&54;TQO9R@B3$]#2R!!
M1$1215-30D]/2R!O;B`D86)O;VL@)&)O;VM%;G1R>2!/2R(L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?24Y&3RD["@H@("`@("`@("\O(%)E='5R;B!E:71H97(@=')U
M92!O<B!T:&4@1D540TA!1$1215-3(')E<W!O;G-E(&EF(&ET(&5X:7-T<RX*
M("`@("`@("!I9B`H(21D=6UM>2D@>PH@("`@("`@("`@("!R971U<FX@=')U
M93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)&1U;6UY
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%5N;&]C:W,@82!P
M<F5V:6]U<VQY(&QO8VME9"!A9&1R97-S(&)O;VLN"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D86)O;VL@("`@($YA;64@;V8@861D<F5S<R!B;V]K
M(&-O;G1A:6YI;F<@;&]C:V5D(&5N=')Y+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D8F]O:T5N=')Y($YA;64@;V8@96YT<GD@=&\@=6YL;V-K+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@5')U92!O;B!S=6-C97-S+"!014%27T5R
M<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('5N;&]C:T5N
M=')Y*"1A8F]O:RP@)&)O;VM%;G1R>2D*("`@('L*("`@("`@("`O+R!3=&%R
M="!S96YD:6YG(&-O;6UA;F0N"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?
M:6US<"T^:6US<%-E;F0H)U5.3$]#2R!!1$1215-30D]/2R`G+"!T<G5E+"!F
M86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@
M("`@("`@("\O('M](&9O<B!B;V]K(&YA;64_"B`@("`@("`@:68@*'!R96=?
M;6%T8V@H24U34%]-55-47U5315],251%4D%,+"`D86)O;VLI*2!["B`@("`@
M("`@("`@("1B:4)O;VL@/2!S<')I;G1F*")[)61](BP@<W1R;&5N*"1A8F]O
M:RDI.PH*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D8FE"
M;V]K+"!F86QS92P@=')U92D["@H@("`@("`@("`@("!I9B`H(7!R96=?;6%T
M8V@H(B]>7"LO(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?:6US<"T^:6US<%)E8V5I=F4H*2DI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E:79E
M(&5X<&5C=&5D(&-O;6UA;F0@8V]N=&EN=6%T:6]N(')E<W!O;G-E(&9R;VT@
M24U34"!S97)V97(N)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@
M("`@("!]"@H@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P
M4V5N9"@B)&%B;V]K("(L(&9A;'-E+"!F86QS92D["@H@("`@("`@("\O2&]W
M(&)O=70@9F]R(&5N=')Y(&YA;64_"B`@("`@("`@:68@*'!R96=?;6%T8V@H
M24U34%]-55-47U5315],251%4D%,+"`D8F]O:T5N=')Y*2D@>PH@("`@("`@
M("`@("`D8FE%;G1R>3US<')I;G1F*")[)61](BP@<W1R;&5N*"1B;V]K16YT
M<GDI*3L*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D8FE%
M;G1R>2P@9F%L<V4L('1R=64I.PH*("`@("`@("`@("`@:68@*"%P<F5G7VUA
M=&-H*"(O7EPK+R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7VEM<W`M/FEM<W!296-E:79E*"DI*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV
M92!E>'!E8W1E9"!C;VUM86YD(&-O;G1I;G5A=&EO;B!R97-P;VYS92!F<F]M
M($E-4U`@<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D
M8F]O:T5N=')Y+"!F86QS92P@=')U92D["@H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1B;V]K16YT<GD@/2`D=&AI<RT^7VEM<W`M/G%U;W1E4W!A
M8V5D4W1R:6YG*"1B;V]K16YT<GDI.PH@("`@("`@("`@("`D=&AI<RT^7VEM
M<W`M/FEM<W!396YD*"(D8F]O:T5N=')Y(BP@9F%L<V4L('1R=64I.PH@("`@
M("`@('T*"B`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P
M4F5C96EV92@I.PH*("`@("`@("!S=VET8V@@*"1R97-P;VYS92D@>PH@("`@
M("`@(&-A<V4@)TY/)SH*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US
M<"T^:6US<$5R<F]R*"=)35-0('-E<G9E<B!I<R!U;F%B;&4@=&\@<&5R9F]R
M;2!Y;W5R(')E<75E<W0N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@
M("`@8V%S92`G0D%$)SH*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US
M<"T^:6US<$5R<F]R*"=4:&4@24U34"!S97)V97(@9&ED(&YO="!U;F1E<G-T
M86YD('EO=7(@<F5Q=65S="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@
M("`@("!C87-E("=/2R<Z"B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^=W)I
M=&54;TQO9R@B54Y,3T-+($%$1%)%4U-"3T]+(&]N("1A8F]O:R`D8F]O:T5N
M=')Y($]+(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?24Y&3RD["B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($%C8V5S<R!#;VYT<F]L($QI<W0@*$%#3"D@($UE=&AO9',N"B`@("`@
M*@H@("`@("H@5&AE(&9O;&QO=VEN9R!C:&%R86-T97)S(&%R92!R96-O9VYI
M>F5D($%#3"!C:&%R86-T97)S.B!L<G=C9&$*("`@("`J(&P@+2`B;&]O:W5P
M(B`@*'-E92!T:&4@;F%M92!A;F0@97AI<W1E;F-E(&]F('1H92!A9&1R97-S
M(&)O;VLI"B`@("`@*B!R("T@(G)E860B("`@("AS96%R8V@@86YD(')E=')I
M979E(&%D9')E<W-E<R!F<F]M(&%D9')E<W,@8F]O:RD*("`@("`J('<@+2`B
M=W)I=&4B("`@*&-R96%T92]E9&ET(&YE=R!A9&1R97-S(&)O;VL@96YT<FEE
M<R`M(&YO="!D96QE=&4I"B`@("`@*B!C("T@(F-R96%T92(@("AC<F5A=&4@
M;F5W(&%D9')E<W,@8F]O:W,@=6YD97(@=&AE(&-U<G)E;G0@861D<F5S<R!B
M;V]K*0H@("`@("H@9"`M(")D96QE=&4B("`H9&5L971E(&5N=')I97,@;W(@
M96YT:7)E(&)O;VLI"B`@("`@*B!A("T@(F%D;6EN(B`@("AS970@04-,(&QI
M<W1S(&9O<B!T:&ES(&%D9')E<W,@8F]O:R`M('5S=6%L;'D@;VYL>0H@("`@
M("H@("`@("`@("`@("`@("!A;&QO=V5D(&9O<B!T:&4@;W=N97(@;V8@=&AE
M(&%D9')E<W,@8F]O:RD*("`@("`J"B`@("`@*B!E>&%M<&QE<SH*("`@("`J
M("`B;'(B('=O=6QD(&)E(')E860@;VYL>2!F;W(@=&AA="!U<V5R"B`@("`@
M*B`@(FQR=R(@=V]U;&0@8F4@<F5A9"]W<FET90H@("`@("HO"@H@("`@+RHJ
M"B`@("`@*B!3971S(&%N($%C8V5S<R!#;VYT<F]L($QI<W0@9F]R(&%N(&%B
M;V]K+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%B;V]K($YA;64@
M;V8@861D<F5S<R!B;V]K+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:61E;G0@
M3F%M92!O9B!U<V5R(&9O<B!T:&ES(&%C;"X*("`@("`J($!P87)A;2!S=')I
M;F<@)&%C;"`@(&%C;"!F;W(@=&AI<R!U<V5R+V)O;VLN"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"!4<G5E(&]N('-U8V-E<W,@+R!014%27T5R<F]R
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$%#3"@D86)O
M;VLL("1I9&5N="P@)&%C;"D*("`@('L*("`@("`@("`O+R!697)I9GD@=&AA
M="`D86-L(&QO;VMS(&=O;V0N"B`@("`@("`@:68@*'!R96=?;6%T8V@H(B];
M7B(@+B!)35-07T%#3%]224=(5%,@+B`B72\B+"`D86-L*2D@>PH@("`@("`@
M("`@("`O+V5R<F]R+BXN86-L(&QI<W0@8V]N=&%I;F5D('5N<F5C;V=I;GIE
M9"!O<'1I;VYS"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM
M<W!%<G)O<BA)35-07T)!1%]!4D=5345.5"P@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("!]"@H@("`@("`@("\O($)E9VEN('-E;F1I;F<@8V]M;6%N
M9"X*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@G
M4T5404-,($%$1%)%4U-"3T]+("<L('1R=64L(&9A;'-E*3L*("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@+R\@>WT@9F]R
M(&)O;VL@;F%M93\*("`@("`@("!I9B`H<')E9U]M871C:"A)35-07TU54U1?
M55-%7TQ)5$5204PL("1A8F]O:RDI('L*("`@("`@("`@("`@)&)I0F]O:R`]
M('-P<FEN=&8H(GLE9'TB+"!S=')L96XH)&%B;V]K*2D["B`@("`@("`@("`@
M("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)&)I0F]O:RP@9F%L<V4L('1R=64I
M.PH*("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"(O7EPK+R(L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!296-E
M:79E*"DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P
M+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!E>'!E8W1E9"!C;VUM86YD
M(&-O;G1I;G5A=&EO;B!R97-P;VYS92!F<F]M($E-4U`@<V5R=F5R+B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@?0H*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H(B1A8F]O:R`B+"!F
M86QS92P@9F%L<V4I.PH*("`@("`@("`O+R![?2!F;W(@:61E;G0_"B`@("`@
M("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,+"`D:61E
M;G0I*2!["B`@("`@("`@("`@("1B:4ED96YT(#T@<W!R:6YT9B@B>R5D?2(L
M('-T<FQE;B@D:61E;G0I*3L*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI
M;7-P4V5N9"@D8FE)9&5N="P@9F%L<V4L('1R=64I.PH*("`@("`@("`@("`@
M:68@*"%P<F5G7VUA=&-H*"(O7EPK+R(L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"DI*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I
M9"!N;W0@<F5C96EV92!E>'!E8W1E9"!C;VUM86YD(&-O;G1I;G5A=&EO;B!R
M97-P;VYS92!F<F]M($E-4U`@<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("`@("`@?0H*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3Y?:6US<"T^:6US<%-E;F0H(B1I9&5N="`B+"!F86QS92P@9F%L<V4I.PH*
M("`@("`@("`O+R!.;W<@9FEN:7-H('5P('=I=&@@=&AE(&%C='5A;"!!0TPN
M"B`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D86-L+"!F86QS92P@
M=')U92D["B`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P
M4F5C96EV92@I.PH*("`@("`@("!S=VET8V@@*"1R97-P;VYS92D@>PH@("`@
M("`@(&-A<V4@)TY/)SH*("`@("`@("`@("`@+R\@0V]U;&0@;F]T('-E="!!
M0TPN"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O
M<B@G24U34"!S97)V97(@:7,@=6YA8FQE('1O('!E<F9O<FT@>6]U<B!R97%U
M97-T+B<L7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@8V%S92`G0D%$
M)SH*("`@("`@("`@("`@+R\@0F%D('-Y;G1A>"X*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=4:&4@24U34"!S97)V97(@
M9&ED(&YO="!U;F1E<G-T86YD('EO=7(@<F5Q=65S="XG+%]?1DE,15]?+"!?
M7TQ)3D5?7RD["@H@("`@("`@(&-A<V4@)T]+)SH*("`@("`@("`@("`@)'1H
M:7,M/E]I;7-P+3YW<FET951O3&]G*")!0TP@<V5T(&9O<B`D:61E;G0@;VX@
M)&%B;V]K(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@
M("`@("`@<F5T=7)N('1R=64["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@
M("`@("\O($1O(&YO="!K;F]W('=H>2!W92!W;W5L9"!M86ME(&ET(&1O=VX@
M:&5R92X*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R
M<F]R*"=$:60@;F]T(')E8V5I=F4@=&AE(&5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@=&AE('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V97,@86X@861D<F5S<R!B
M;V]K)W,@04-,+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%B;V]K
M($YA;64@;V8@861D<F5S<R!B;V]K('1O(')E=')I979E(&%C;"!F;W(N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!A<G)A>2!C;VYT86EN:6YG(&%C
M;"!F;W(@979E<GD@=7-E<B!W:71H(&%C8V5S<R!T;PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("!A9&1R97-S(&)O;VL@;W(@4$5!4E]%<G)O<B!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!0TPH)&%B;V]K*0H@
M("`@>PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD
M*"='151!0TP@041$4D534T)/3TL@)RP@=')U92P@9F%L<V4I.PH@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`O+R![?2!F
M;W(@8F]O:R!N86UE/PH@("`@("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?3553
M5%]54T5?3$E415)!3"P@)&%B;V]K*2D@>PH@("`@("`@("`@("`D8FE.86UE
M(#T@<W!R:6YT9B@B>R5D?2(L('-T<FQE;B@D86)O;VLI*3L*("`@("`@("`@
M("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D8FE.86UE+"!F86QS92P@=')U
M92D["@H@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%)E
M8V5I=F4H*2DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM
M<W`M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E:79E(&5X<&5C=&5D(&-O;6UA
M;F0@8V]N=&EN=6%T:6]N(')E<W!O;G-E(&9R;VT@24U34"!S97)V97(N)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1A8F]O:RP@9F%L
M<V4L('1R=64I.PH*("`@("`@("`O+R!'970@<F5S=6QT<RX*("`@("`@("`D
M<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["@H@("`@
M("`@('-W:71C:"`H)')E<W!O;G-E*2!["B`@("`@("`@8V%S92`G3D\G.@H@
M("`@("`@("`@("`O+R!#;W5L9"!N;W0@8V]M<&QE=&4_"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G24U34"!S97)V97(@
M:7,@=6YA8FQE('1O('!E<F9O<FT@>6]U<B!R97%U97-T+B<L(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["@H@("`@("`@(&-A<V4@)T)!1"<Z"B`@("`@("`@("`@
M("\O($1O(&YO="!K;F]W('=H870@>6]U('-A:60A"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G5&AE($E-4U`@<V5R=F5R
M(&1I9"!N;W0@=6YD97)S=&%N9"!Y;W5R(')E<75E<W0N)RP@7U]&24Q%7U\L
M(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("\O($EF('=E(&%R92!H
M97)E+"!W92!N965D('1O(')E8V5I=F4@=&AE("H@04-,(%)E<W!O;G-E<RX*
M("`@("`@("!D;R!["B`@("`@("`@("`@("\J($=E="!A;B!A<G)A>2!O9B!R
M97-P;VYS97,N"B`@("`@("`@("`@("`J(%1H92!;,UT@96QE;65N="!S:&]U
M;&0@8F4@=&AE(&%D9')E<W,@8F]O:R!N86UE"B`@("`@("`@("`@("`J(%LT
M72!A;F0@6S5=('=I;&P@8F4@=7-E<B]G<F]U<"!N86UE(&%N9"!P97)M:7-S
M:6]N<R`J+PH*("`@("`@("`@("`@+R]T:&4@8F]O:R!N86UE(&UI9VAT(&)E
M(&$@;&ET97)A;`H@("`@("`@("`@("!I9B`H<')E9U]M871C:"A)35-07T]#
M5$547T-/54Y4+"`D<F5S<&]N<V4L("1T96UP07)R87DI*2!["B`@("`@("`@
M("`@("`@("`D9&%T82`]("1T:&ES+3Y?:6US<"T^<F5C96EV95-T<FEN9TQI
M=&5R86PH)'1E;7!!<G)A>5LR72D["B`@("`@("`@("`@("`@("`O+T=E="!T
M:&4@<F5S=`H@("`@("`@("`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/E]I
M;7-P+3YI;7-P4F5C96EV92@I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D<&%R=',@/2!E>'!L;V1E*"<@)RP@)')E<W!O;G-E*3L*"B`@("`@("`@
M("`@("\O(%!U<V@@=&AE(&%R<F%Y(&EF(&)O;VL@=V%S(&$@;&ET97)A;`H@
M("`@("`@("`@("!I9B`H)&1A=&$I('L*("`@("`@("`@("`@("`@(&%R<F%Y
M7W5N<VAI9G0H)'!A<G1S+"`G("<L("<@)RP@)R`G+"`G("<I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("\O($%D9')E<W,@8F]O:R!N86UE('%U;W1E
M9#\*("`@("`@("`@("`@)&YU;5!A<G1S(#T@8V]U;G0H)'!A<G1S*3L*("`@
M("`@("`@("`@)&YA;64@/2`D<&%R='-;,UT["B`@("`@("`@("`@("1F:7)S
M=$%#3$ED>"`](#0["B`@("`@("`@("`@("1F:7)S=$-H87(@/2!S=6)S='(H
M)&YA;64L(#`L(#$I.PH@("`@("`@("`@("!I9B`H)&9I<G-T0VAA<B`]/2`B
M7"(B*2!["B`@("`@("`@("`@("`@("!F;W(@*"1I(#T@-#L@)&D@/"`D;G5M
M4&%R=',[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`D;&%S=$-H87(@
M/2!S=6)S='(H)'!A<G1S6R1I72P@<W1R;&5N*"1P87)T<ULD:5TI("T@,2P@
M,2D["B`@("`@("`@("`@("`@("`@("`@)&9I<G-T04-,261X*RL["B`@("`@
M("`@("`@("`@("`@("`@:68@*"1L87-T0VAA<B`]/2`B7"(B*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@9F]R("@D:2`]("1F:7)S=$%#3$ED>#L@)&D@/"!C;W5N="@D<&%R=',I
M.R`D:2`K/2`R*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT<ULD<&%R='-;
M)&E=72`]("1P87)T<ULD:2LQ73L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@)')E<W!O;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH*
M("`@("`@("!]('=H:6QE("AP<F5G7VUA=&-H*"(O7EPJ($%#3"!!1$1215-3
M0D]/2R\B+"`D<F5S<&]N<V4I*3L*"B`@("`@("`@+R\@2&]P969U;&QY('=E
M(&-A;B!R96-E:79E(&%N($]+(')E<W!O;G-E(&AE<F4*("`@("`@("!I9B`H
M)')E<W!O;G-E("$]("=/2R<I('L*("`@("`@("`@("`@+R\@4V]M92!W96ER
M9"!P<F]B;&5M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM
M<W!%<G)O<B@G1&ED(&YO="!R96-E:79E('1H92!E>'!E8W1E9"!R97-P;VYS
M92!F<F]M('1H92!S97)V97(N)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@?0H*("`@("`@("`D=&AI<RT^7VEM<W`M/G=R:71E5&],;V<H(D=%5$%#
M3"!O;B`D86)O;VL@8V]M<&QE=&5D+B(L(%]?1DE,15]?+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!?7TQ)3D5?7RP@4$5!4E],3T=?24Y&
M3RD["B`@("`@("`@<F5T=7)N("1R97-U;'1S.PH*("`@('T*"B`@("`O*BH*
M("`@("`J($1E;&5T97,@86X@04-,(&5N=')Y(&9O<B!A;B!A9&1R97-S(&)O
M;VLN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D86)O;VL@3F%M92!O
M9B!T:&4@861D<F5S<R!B;V]K+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:61E
M;G0@3F%M92!O9B!E;G1R>2!T;R!R96UO=F4@86-L(&9O<BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D('1R=64@;VX@<W5C8V5S<RP@4$5!4E]%<G)O
M<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&5!0TPH
M)&%B;V]K+"`D:61E;G0I"B`@("!["B`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?:6US<"T^:6US<%-E;F0H)T1%3$5414%#3"!!1$1215-30D]/2R`G+"!T
M<G5E+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("!]"@H@("`@("`@("\O($1O('=E(&YE960@;&ET97)A;"!F;W(@861D<F5S
M<R!B;V]K(&YA;64_"B`@("`@("`@:68@*'!R96=?;6%T8V@H24U34%]-55-4
M7U5315],251%4D%,+"`D86)O;VLI*2!["B`@("`@("`@("`@("1B:4)O;VL@
M/2!S<')I;G1F*")[)61](BP@<W1R;&5N*"1A8F]O:RDI.PH@("`@("`@("`@
M("`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1B:4)O;VLL(&9A;'-E+"!T<G5E
M*3L*"B`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<*R\B+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4F5C
M96EV92@I*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US
M<"T^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@97AP96-T960@8V]M;6%N
M9"!C;VYT:6YU871I;VX@<F5S<&]N<V4@9G)O;2!)35-0('-E<G9E<BXG+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*"B`@("`@("`@
M?0H*("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"(D86)O;VL@(BP@
M9F%L<V4L(&9A;'-E*3L*"B`@("`@("`@+R\@3&ET97)A;"!F;W(@:61E;G0@
M;F%M93\*("`@("`@("!I9B`H<')E9U]M871C:"A)35-07TU54U1?55-%7TQ)
M5$5204PL("1I9&5N="DI('L*("`@("`@("`@("`@)&)I261E;G0@/2!S<')I
M;G1F*")[)61](BP@<W1R;&5N*"1I9&5N="DI.PH@("`@("`@("`@("`D=&AI
M<RT^7VEM<W`M/FEM<W!396YD*"1B:4ED96YT+"!F86QS92P@=')U92D["@H@
M("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H
M*2DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM
M<W!%<G)O<B@G1&ED(&YO="!R96-E:79E(&5X<&5C=&5D(&-O;6UA;F0@8V]N
M=&EN=6%T:6]N(')E<W!O;G-E(&9R;VT@24U34"!S97)V97(N)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M=&AI<RT^7VEM<W`M/FEM<W!396YD*"1I9&5N="P@9F%L<V4L('1R=64I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US
M<%-E;F0H(EPB)&ED96YT7"(B+"!F86QS92P@=')U92D["B`@("`@("`@?0H*
M("`@("`@("`O+R!'970@<F5S=6QT<RX*("`@("`@("`D<V5R=F5R7W)E<W!O
M;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH*("`@("`@("!S
M=VET8V@@*"1S97)V97)?<F5S<&]N<V4I('L*("`@("`@("!C87-E("=.3R<Z
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G
M24U34"!S97)V97(@:7,@=6YA8FQE('1O('!E<F9O<FT@>6]U<B!R97%U97-T
M+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["@H@("`@("`@(&-A<V4@)T)!1"<Z
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G
M5&AE($E-4U`@<V5R=F5R(&1I9"!N;W0@=6YD97)S=&%N9"!Y;W5R(')E<75E
M<W0N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@8V%S92`G3TLG
M.@H@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/G=R:71E5&],;V<H(D1%3$54
M140@04-,(&9O<B`D:61E;G0@;VX@)&%B;V]K(BP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%
M05)?3$]'7TE.1D\I.PH@("`@("`@("`@("!R971U<FX@=')U93L*"B`@("`@
M("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^
M:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@=&AE(&5X<&5C=&5D(')E<W!O
M;G-E(&9R;VT@=&AE('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N($%#3"!S
M=')I;F<@8V]N=&%I;FEN9R!T:&4@<FEG:'1S(&9O<B!T:&4@8W5R<F5N="!U
M<V5R"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D86)O;VL@3F%M92!O
M9B!A9&1R97-S(&)O;VL@=&\@<F5T<FEE=F4@86-L+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@86-L(&]F(&-U<G)E;G0@=7-E<B!O<B!014%27T5R
M<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&UY4FEG:'1S
M*"1A8F]O:RD*("`@('L*("`@("`@("`D9&%T82`]("<G.PH@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"=-65))1TA44R!!1$12
M15-30D]/2R`G+"!T<G5E+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("!]"@H@("`@("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?
M35535%]54T5?3$E415)!3"P@)&%B;V]K*2D@>PH@("`@("`@("`@("`D8FE"
M;V]K(#T@<W!R:6YT9B@B>R5D?2(L('-T<FQE;B@D86)O;VLI*3L*("`@("`@
M("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D8FE";V]K+"!F86QS92P@
M=')U92D["@H@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US
M<%)E8V5I=F4H*2DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E:79E(&5X<&5C=&5D(&-O
M;6UA;F0@8V]N=&EN=6%T:6]N(')E<W!O;G-E(&9R;VT@24U34"!S97)V97(N
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"@H@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D86)O;VLL
M(&9A;'-E+"!T<G5E*3L*("`@("`@("`D<V5R=F5R7W)E<W!O;G-E(#T@)'1H
M:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH*("`@("`@("!S=VET8V@@*"1S
M97)V97)?<F5S<&]N<V4I('L*("`@("`@("!C87-E("=.3R<Z"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G24U34"!S97)V
M97(@:7,@=6YA8FQE('1O('!E<F9O<FT@>6]U<B!R97%U97-T+B<L(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["@H@("`@("`@(&-A<V4@)T)!1"<Z"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G5&AE($E-4U`@
M<V5R=F5R(&1I9"!N;W0@=6YD97)S=&%N9"!Y;W5R(')E<75E<W0N)RP@7U]&
M24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A<')E
M9U]M871C:"@B+UY<*B!-65))1TA44R!!1$1215-30D]/2R\B+"`D<V5R=F5R
M7W)E<W!O;G-E*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P
M+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!T:&4@97AP96-T960@<F5S
M<&]N<V4@9G)O;2!T:&4@<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@('T*"B`@("`@("`@+R\@>WT@9F]R('1H92!A8F]O:R!N86UE/PH@
M("`@("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?3T-4151?0T]53E0L("1S97)V
M97)?<F5S<&]N<V4L("1T96UP07)R87DI*2!["B`@("`@("`@("`@("1D871A
M(#T@)'1H:7,M/E]I;7-P+3YR96-E:79E4W1R:6YG3&ET97)A;"@D=&5M<$%R
M<F%Y6S)=*3L*("`@("`@("`@("`@+R\@1V5T('1H92!R97-T+@H@("`@("`@
M("`@("`D<V5R=F5R7W)E<W!O;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C
M96EV92@I.PH@("`@("`@('T*"B`@("`@("`@)'!A<G1S(#T@97AP;&]D92@G
M("<L("1S97)V97)?<F5S<&]N<V4I.PH*("`@("`@("`O+R!0=7-H('1H92!A
M<G)A>2!I9B!W92!H860@82![?0H@("`@("`@(&EF("@D9&%T82D@>PH@("`@
M("`@("`@("!A<G)A>5]U;G-H:69T*"1P87)T<RP@)R`G+"`G("<L("<@)RP@
M)R`G*3L*("`@("`@("!]"@H@("`@("`@("\O(%%U;W1E9"!A9&1R97-S(&)O
M;VL@;F%M93\*("`@("`@("`D;G5M4&%R=',@/2!C;W5N="@D<&%R=',I.PH@
M("`@("`@("1N86UE(#T@)'!A<G1S6S-=.PH@("`@("`@("1F:7)S=$%#3$ED
M>"`](#0["B`@("`@("`@)&9I<G-T0VAA<B`]('-U8G-T<B@D;F%M92P@,"P@
M,2D["B`@("`@("`@:68@*"1F:7)S=$-H87(@/3T@(EPB(BD@>PH@("`@("`@
M("`@("!F;W(@*"1I(#T@-#L@)&D@/"`D;G5M4&%R=',[("1I*RLI('L*("`@
M("`@("`@("`@("`@("1L87-T0VAA<B`]('-U8G-T<B@D<&%R='-;)&E=+"!S
M=')L96XH)'!A<G1S6R1I72D@+2`Q+"`Q*3L*("`@("`@("`@("`@("`@("1F
M:7)S=$%#3$ED>"LK.PH@("`@("`@("`@("`@("`@:68@*"1L87-T0VAA<B`]
M/2`B7"(B*2!["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1A
M8VP@/2`D<&%R='-;)&9I<G-T04-,261X73L*("`@("`@("`D<V5R=F5R7W)E
M<W!O;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH*("`@("`@
M("!I9B`H)'-E<G9E<E]R97-P;VYS92`A/2`G3TLG*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E
M:79E('1H92!E>'!E8W1E9"!R97-P;VYS92!F<F]M('1H92!S97)V97(N)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'1H:7,M/E]I;7-P+3YW<FET951O3&]G*")-65))1TA44R!O;B`D86)O
M;VL@8V]M<&QE=&5D+B(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U])3D9/*3L*
M("`@("`@("`@("`@<F5T=7)N("1A8VP["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T<R!T:&4@;&]G(&EN9F]R;6%T:6]N(&EN('1H92!.
M971?24U34"!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M("!A<G)A>2`@
M3&]G('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M5')U92!O;B!S=6-C97-S(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T3&]G9V5R*"1P87)A;7,I"B`@("!["B`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?:6US<"DI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?:6US<"T^<V5T3&]G9V5R*"1P87)A;7,I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(BDI
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%!A<G-E<R!A($E-
M4U`@9F5T8VAA9&1R97-S(')E<W!O;G-E('1E>'0@<W1R:6YG(&EN=&\*("`@
M("`J(&ME>2UV86QU92!P86ER<PH@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H@0'!A<F%M("!S=')I;F<@("1S97)V97)?<F5S<&]N<V4@
M5&AE(')A=R!F971C:&%D9')E<W,@<F5S<&]N<V4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@($%D9')E<W,@8F]O:R!E;G1R>2!I;F9O<FUA=&EO
M;B!A<R!K97D]/G9A;'5E('!A:7)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M<&%R<V5&971C:$%D9')E<W-297-P;VYS92@D<V5R=F5R7W)E<W!O;G-E*0H@
M("`@>PH@("`@("`@("1A8F]O:R`]("<G.PH*("`@("`@("!I9B`H(7!R96=?
M;6%T8V@H(B]>7"H@1D540TA!1$1215-3("\B+"`D<V5R=F5R7W)E<W!O;G-E
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/G=R:71E5&],;V<H)UM%
M4E)/4ET@1&ED(&YO="!R96-E:79E(&$@1D540TA!1$1215-3(')E<W!O;G-E
M(&9R;VT@<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["@H@
M("`@("`@("`@("`D=&AI<RT^7VEM<W`M/F5X:71#;V1E(#T@)T1I9"!N;W0@
M<F5C96EV92!T:&4@97AP96-T960@<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R
M+B<["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@("\J($Y/5$53"B`@("`@("`@("H@4&%R<V4@;W5T('1H92!S97)V97(@
M<F5S<&]N<V4@<W1R:6YG"B`@("`@("`@("H*("`@("`@("`@*B!!9G1E<B!C
M:&]P:6YG(&]F9B!T:&4@<V5R=F5R(&-O;6UA;F0@<F5S<&]N<V4@=&%G<R!A
M;F0*("`@("`@("`@*B!E>'!L;V1E*"DG:6YG('1H92!S97)V97)?<F5S<&]N
M<V4@<W1R:6YG"B`@("`@("`@("H@=&AE("1P87)T<R!A<G)A>2!C;VYT86EN
M<R!T:&4@8VAU;FMS(&]F('1H92!S97)V97(@<F5T=7)N960@9&%T82X*("`@
M("`@("`@*@H@("`@("`@("`J(%1H92!P<F5D:69I;F5D("=N86UE)R!F:65L
M9"!S=&%R=',@:6X@)'!A<G1S6S%=+@H@("`@("`@("`J(%1H92!S97)V97(@
M<VAO=6QD(')E='5R;B!A;GD@<VEN9VQE(&ET96T@;V8@9&%T80H@("`@("`@
M("`J('1H870@8V]N=&%I;G,@<W!A8V5S('=I=&AI;B!I="!A<R!A(&1O=6)L
M92!Q=6]T960@<W1R:6YG+@H@("`@("`@("`J(%-O('=E(&-A;B!I;G1E<G!R
M970@=&AE(&5X:7-T96YC92!O9B!A(&1O=6)L92!Q=6]T92!A="!T:&4@8F5G
M:6YN:6YG"B`@("`@("`@("H@;V8@82!C:'5N:R!T;R!M96%N('1H870@=&AE
M(&YE>'0@8VAU;FLH<RD@87)E('!A<G0@;V8*("`@("`@("`@*B!T:&4@<V%M
M92!V86QU92X@($$@9&]U8FQE('%U;W1E(&%T('1H92!E;F0@;V8@82!C:'5N
M:R!S:6=N:69I97,@=&AE"B`@("`@("`@("H@96YD(&]F('1H870@=F%L=64@
M86YD('1H92!C:'5N:R!F;VQL;W=I;F<@=&AA="!C86X@8F4@:6YT97)P<F5T
M960*("`@("`@("`@*B!A<R!A(&ME>2!N86UE+@H@("`@("`@("`J"B`@("`@
M("`@("H@5V4@86QS;R!N965D('1O('=A=&-H(&9O<B!T:&4@<V5R=F5R(')E
M='5R;FEN9R!A('M](')E<W!O;G-E(&9O<B!T:&4*("`@("`@("`@*B!V86QU
M92!O9B!T:&4@:V5Y(&%S('=E;&PN("HO"@H@("`@("`@("\O(%=A<R!T:&4@
M861D<F5S<R!B;V]K(&YA;64@82`@>WT_"B`@("`@("`@:68@*'!R96=?;6%T
M8V@H(B\H7EPJ($9%5$-(041$4D534R`I*'LI*%LP+3E=>S$L?2DH7'TD*2\B
M+`H@("`@("`@("`@("`@("`@("`@("`@("1S97)V97)?<F5S<&]N<V4L("1T
M96UP07)R87DI*2!["B`@("`@("`@("`@("1A8F]O:R`]("1T:&ES+3Y?:6US
M<"T^<F5C96EV95-T<FEN9TQI=&5R86PH)'1E;7!!<G)A>5LS72D["B`@("`@
M("`@("`@("1C:&]P<&5D7W)E<W!O;G-E(#T@=')I;2@D=&AI<RT^7VEM<W`M
M/FEM<W!296-E:79E*"DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("\O(%1A:V4@;V9F('1H92!S='5F9B!F<F]M('1H92!B96=I;FYI;F<@;V8@
M=&AE(')E<W!O;G-E"B`@("`@("`@("`@("1C:&]P<&5D7W)E<W!O;G-E(#T@
M=')I;2AP<F5G7W)E<&QA8V4H(B]>7"H@1D540TA!1$1215-3("\B+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("<G+"`D<V5R=F5R7W)E<W!O;G-E*2D["B`@("`@("`@?0H*("`@("`@("`D
M<&%R=',@/2!E>'!L;V1E*"<@)RP@)&-H;W!P961?<F5S<&]N<V4I.PH@("`@
M("`@("\J($EF(&%D9')E<R!B;V]K('=A<R!S96YT(&%S(&$@>WT@=&AE;B!W
M92!M=7-T("=P=7-H)R!A(&)L86YK"B`@("`@("`@("H@=F%L=64@=&\@=&AE
M('-T87)T(&]F('1H:7,@87)R87D@<V\@=&AE(')E<W0@;V8@=&AE(')O=71I
M;F4*("`@("`@("`@*B!W:6QL('=O<FL@=VET:"!T:&4@8V]R<F5C="!I;F1E
M>&5S+B`J+PH@("`@("`@("!I9B`H(65M<'1Y*"1A8F]O:RDI('L*("`@("`@
M("`@("`@87)R87E?=6YS:&EF="@D<&%R=',L("<@)RD["B`@("`@("`@?0H*
M("`@("`@("`O+R!787,@=&AE(&%D9')E<W,@8F]O:R!N86UE('%U;W1E9#\*
M("`@("`@("`D;G5M3V9087)T<R`](&-O=6YT*"1P87)T<RD["B`@("`@("`@
M)&YA;64@/2`D<&%R='-;,%T["B`@("`@("`@)&9I<G-T3F%M94ED>"`](#$[
M"B`@("`@("`@)&9I<G-T0VAA<B`]('-U8G-T<B@D;F%M92P@,"P@,2D["B`@
M("`@("`@:68@*"1F:7)S=$-H87(@/3TB7"(B*2!["B`@("`@("`@("`@(&9O
M<B`H)&D@/2`Q.R`D:2`\("1N=6U/9E!A<G1S.R`D:2LK*2!["B`@("`@("`@
M("`@("`@("`D;&%S=$-H87(@/2!S=6)S='(H)'!A<G1S6R1I72P@<W1R;&5N
M*"1P87)T<ULD:5TI("T@,2P@,2D["B`@("`@("`@("`@("`@("`D9FER<W1.
M86UE261X*RL["B`@("`@("`@("`@("`@("!I9B`H)&QA<W1#:&%R(#T](")<
M(B(I('L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@3F]W
M('-T87)T('=O<FMI;F<@;VX@=&AE(&5N=')Y(&YA;64*("`@("`@("`D;F%M
M92`]("1P87)T<ULD9FER<W1.86UE261X73L*("`@("`@("`D9FER<W1#:&%R
M(#T@<W5B<W1R*"1N86UE+#`L,2D["@H@("`@("`@("\O($-H96-K('1O('-E
M92!I9B!T:&4@9FER<W0@8VAA<B!O9B!T:&4@;F%M92!S=')I;F<@:7,@82!D
M;W5B;&4@<75O=&4*("`@("`@("`O+R!S;R!W92!K;F]W(&EF('=E(&AA=F4@
M=&\@97AT<F%C="!M;W)E(&]F('1H92!N86UE+@H@("`@("`@(&EF("@D9FER
M<W1#:&%R(#T](")<(B(I('L*("`@("`@("`@("`@)&YA;64@/2!L=')I;2@D
M;F%M92P@(EPB(BD["B`@("`@("`@("`@(&9O<B`H)&D@/2`D9FER<W1.86UE
M261X("L@,3L@)&D@/"`D;G5M3V9087)T<SL@)&DK*RD@>PH@("`@("`@("`@
M("`@("`@)&YA;64@+CT@("<@)R`N("1P87)T<ULD:5T["B`@("`@("`@("`@
M("`@("`D;&%S=$-H87(@/2!S=6)S='(H)'!A<G1S6R1I72P@<W1R;&5N*"1P
M87)T<ULD:5TI("T@,2PQ*3L*("`@("`@("`@("`@("`@(&EF("@D;&%S=$-H
M87(@/3T@(EPB(BD@>PH@("`@("`@("`@("`@("`@("`@("1N86UE(#T@<G1R
M:6TH)&YA;64L(")<(B(I.PH@("`@("`@("`@("`@("`@("`@("1N97AT2V5Y
M(#T@)&D@*R`Q.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("\O($-H96-K(&9O
M<B![?0H@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"<O7'LH7&0K*5Q]
M+R<L("1N86UE+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@)&YA;64@/2`D
M=&AI<RT^7VEM<W`M/G)E8V5I=F53=')I;F=,:71E<F%L*"1M871C:&5S6S%=
M*3L*("`@("`@("`@("`@)')E<W!O;G-E/21T:&ES+3Y?:6US<"T^:6US<%)E
M8V5I=F4H*3L*("`@("`@("`@("`@)'!A<G1S(#T@97AP;&]D92@G("<L("1R
M97-P;VYS92D["B`@("`@("`@("`@("1N=6U/9E!A<G1S(#T@8V]U;G0H)'!A
M<G1S*3L*("`@("`@("`@("`@)&YE>'1+97D@/2`P.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("\O($EF(&]N;'D@;VYE(&-H=6YK(&9O<B`G;F%M
M92<@=&AE;B!W92!J=7-T(&AA=F4@=&\@<&]I;G0*("`@("`@("`@("`@+R\@
M=&\@=&AE(&YE>'0@8VAU;FL@:6X@=&AE(&%R<F%Y+BXN=VAI8V@@=VEL;"!H
M;W!E9G5L;'D*("`@("`@("`@("`@+R\@8F4@)S(G"B`@("`@("`@("`@("1N
M97AT2V5Y(#T@)&9I<G-T3F%M94ED>"`K(#$["B`@("`@("`@?0H*("`@("`@
M("`D;&%S=$-H87(@/2`G)SL*("`@("`@("`D96YT<GE;)VYA;64G72`]("1N
M86UE.PH*("`@("`@("`O+R!3=&%R="!P87)S:6YG('1H92!R97-T(&]F('1H
M92!R97-P;VYS92X*("`@("`@("!F;W(@*"1I(#T@)&YE>'1+97D[("1I(#P@
M)&YU;4]F4&%R=',[("1I("L](#(I('L*("`@("`@("`@("`@)&ME>2`]("1P
M87)T<ULD:5T["B`@("`@("`@("`@("\J($-H96-K(&9O<B![?2`J+PH@("`@
M("`@("`@("!I9B`H0'!R96=?;6%T8V@H24U34%]/0U1%5%]#3U5.5"P@)'!A
M<G1S6R1I*S%=+"`D=&5M<$%R<F%Y*2D@>PH@("`@("`@("`@("`@("`@)'-E
M<G9E<E]D871A(#T@)'1H:7,M/E]I;7-P+3YR96-E:79E4W1R:6YG3&ET97)A
M;"@D=&5M<$%R<F%Y6S)=*3L*("`@("`@("`@("`@("`@("1E;G1R>5LD:V5Y
M72`]("1S97)V97)?9&%T83L*"B`@("`@("`@("`@("`@("`O*B!296%D(&%N
M>2!R96UA:6YI;F<@9&%T82!F<F]M('1H92!S=')E86T@86YD(')E<V5T"B`@
M("`@("`@("`@("`@("`@*B!T:&4@8V]U;G1E<B!V87)I86)L97,@<V\@=&AE
M(&QO;W`@=VEL;"!C;VYT:6YU90H@("`@("`@("`@("`@("`@("H@8V]R<F5C
M=&QY+B!.;W1E('=E('-E="`D:2`@=&\@+3(@8F5C875S92!I="!W:6QL"B`@
M("`@("`@("`@("`@("`@*B!B92!I;F-R96UE;G1E9"!B>2`R(&)E9F]R92!T
M:&4@;&]O<"!W:6QL(')U;B!A9V%I;B`J+PH@("`@("`@("`@("`@("`@)'!A
M<G1S(#T@)'1H:7,M/E]I;7-P+3YG971397)V97)297-P;VYS94-H=6YK<R@I
M.PH@("`@("`@("`@("`@("`@)&D@/2`M,CL*("`@("`@("`@("`@("`@("1N
M=6U/9E!A<G1S(#T@8V]U;G0H)'!A<G1S*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("\O($YO="!A('-T<FEN9R!L:71E<F%L(')E
M<W!O;G-E"B`@("`@("`@("`@("`@("!`)&5N=')Y6R1K97E=(#T@)'!A<G1S
M6R1I("L@,5T["B`@("`@("`@("`@("`@("`@+R\@0VAE8VL@=&\@<V5E(&EF
M('1H92!V86QU92!S=&%R=&5D('=I=&@@82!D;W5B;&4*("`@("`@("`@("`@
M("`@("`O+R!Q=6]T92X@(%=E(&%L<V\@;F5E9"!T;R!C:&5C:R!I9B!T:&4@
M;&%S="!C:&%R(&ES(&$*("`@("`@("`@("`@("`@("`O+R!Q=6]T92!T;R!M
M86ME('-U<F4@=V4@4D5!3$Q9(&AA=F4@=&\@8VAE8VL@=&AE(&YE>'0*("`@
M("`@("`@("`@("`@("`O+R!E;&5M96YT<R!F;W(@82!C;&]S:6YG('%U;W1E
M+@H@("`@("`@("`@("`@("`@:68@*"A`<W5B<W1R*"1P87)T<ULD:2`K(#%=
M+"`P+"`Q*2`]/2`G(B<I("8F"B`@("`@("`@("`@("`@("`@("`@*'-U8G-T
M<B@D<&%R='-;)&D@*R`Q72P*("`@("`@("`@("`@("`@("`@("`@<W1R;&5N
M*"1P87)T<ULD:2`K(#%=*2`M(#$L(#$I("$]("<B)RDI('L*"B`@("`@("`@
M("`@("`@("`@("`@9&\@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;F5X
M=$5L96UE;G0@/2`D<&%R='-;)&DK,ET["@H@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!787,@=&AI<R!E;&5M96YT('1H92!L87-T(&]N93\*("`@("`@
M("`@("`@("`@("`@("`@("`@)&QA<W1#:&%R(#T@<W5B<W1R*"1N97AT16QE
M;65N="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('-T<FQE;B@D;F5X=$5L96UE;G0I("T@,2P@,2D["B`@("`@("`@("`@
M("`@("`@("`@("`@("1E;G1R>5LD:V5Y72`N/2`G("<@+B`D;F5X=$5L96UE
M;G0["@H@("`@("`@("`@("`@("`@("`@("`@("`O+R!.3U<L('=E(&-A;B!C
M:&5C:R!T:&4@;&%S=$-H87(N"B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@D;&%S=$-H87(@/3T@)R(G*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9&]N92`]('1R=64["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D:2LK.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@0VAE8VL@=&\@<V5E(&EF('1H
M92!N97AT(&5L96UE;G0@:7,@=&AE"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!L87-T(&]N92X@268@<V\L('1H92!D;R!L;V]P('=I;&P@=&5R
M;6EN871E+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1O;F4@/2!F
M86QS93L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1L87-T0VAA<B`]
M('-U8G-T<B@D<&%R='-;)&DK,UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@<W1R;&5N*"1P87)T<ULD:2LS72D@
M+2`Q+#$I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&DK*SL*("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@
M=VAI;&4@*"1L87-T0VAA<B`A/2`G(B<I.PH*("`@("`@("`@("`@("`@("`@
M("`O+R!$;R!W92!N965D('1O(&%D9"!T:&4@9FEN86P@96QE;65N="P@;W(@
M=V5R90H@("`@("`@("`@("`@("`@("`@("\O('1H97)E(&]N;'D@='=O('1O
M=&%L/PH@("`@("`@("`@("`@("`@("`@(&EF("@A)&1O;F4I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&YE>'1%;&5M96YT(#T@)'!A<G1S6R1I*S)=
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D96YT<GE;)&ME>5T@+CT@)R`G
M("X@)&YE>'1%;&5M96YT.PH@("`@("`@("`@("`@("`@("`@("`@("`D:2LK
M.PH@("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@
M+R\@4F5M;W9E('1H92!Q=6]T97,@<V5N="!B86-K('1O('5S(&9R;VT@=&AE
M('-E<G9E<BX*("`@("`@("`@("`@("`@("`@("!I9B`H<W5B<W1R*"1E;G1R
M>5LD:V5Y72P@,"P@,2D@/3T@)R(G*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1E;G1R>5LD:V5Y72`]('-U8G-T<B@D96YT<GE;)&ME>5TL(#$L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S
M=')L96XH)&5N=')Y6R1K97E=*2`M(#(I.PH@("`@("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`@("`@:68@*'-U8G-T<B@D96YT<GE;)&ME
M>5TL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=')L96XH)&5N
M=')Y6R1K97E=*2`M(#$L(#$I(#T]("<B)RD@>PH*("`@("`@("`@("`@("`@
M("`@("`@("`@)&5N=')Y6R1K97E=(#T@<W5B<W1R*"1E;G1R>5LD:V5Y72P@
M,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('-T<FQE;B@D96YT<GE;)&ME>5TI("T@,BD["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D96YT<GD["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TYE="])35-0+T]P=&EO;G,N<&AP````````````````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-34V,@`Q,#4Q-30S,S<U,@`P,C(P-S8`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*"G)E<75I<F5?;VYC92`G3F5T+TE-4U`O075T:"YP:'`G.PH*+RHJ"B`J
M($YE=%])35-07T]P=&EO;G,@0VQA<W,@+2!P<F]V:61E<R!A;B!I;G1E<F9A
M8V4@=&\@24U34"!S97)V97(M8F%S960*("H@;W!T:6]N<R!S=&]R86=E+@H@
M*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@)W5S97)N86UE
M)R`@("`@57-E<FYA;64@=&\@;&]G;VX@=&\@24U34"!S97)V97(@87,N"B`J
M("`@)W!A<W-W;W)D)R`@("`@4&%S<W=O<F0@9F]R(&-U<G)E;G0@=7-E<BX*
M("H@("`G875T:%]M971H;V0G("!4:&4@875T:&5N=&EC871I;VX@;65T:&]D
M('1O('5S92!T;R!L;V=I;BX*("H@("`G<V5R=F5R)R`@("`@("!4:&4@:&]S
M=&YA;64@;V8@=&AE($E-4U`@<V5R=F5R+@H@*B`@("=P;W)T)R`@("`@("`@
M(%1H92!P;W)T(&]F('1H92!)35-0('-E<G9E<BX\+W!R93X*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]/<'1I;VYS+G!H<"QV(#$N
M,RXR+C$V(#(P,#8O,#$O,#$@,C$Z,C@Z,C@@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`R,#`T+3(P,#8@36EC:&%E;"!2=6)I;G-K>2`\;7)U8FEN<VM`
M:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E
M;"!2=6)I;G-K>2`\;7)U8FEN<VM`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!.
M971?24U34`H@*B\*8VQA<W,@3F5T7TE-4U!?3W!T:6]N<R!["@H@("`@+RHJ
M"B`@("`@*B!.971?24U34"!O8FIE8W0N"B`@("`@*@H@("`@("H@0'9A<B!.
M971?24U34`H@("`@("HO"B`@("!V87(@)%]I;7-P.PH*("`@("\J*@H@("`@
M("H@4&%R86UE=&5R(&QI<W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]P87)A;7,["@H@("`@+RHJ"B`@("`@*B!#;VYS
M=')U8W1O<B!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@2&%S:"!C;VYT86EN:6YG($E-4U`@<&%R86UE=&5R<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@3F5T7TE-4U!?3W!T:6]N<R@D<&%R86US*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*("`@('T*
M"B`@("`O*BH*("`@("`J($EN:71I86QI>F%T:6]N(&9U;F-T:6]N('1O(&)E
M(&-A;&QE9"!A9G1E<B!O8FIE8W0@:7,@<F5T=7)N960N"B`@("`@*B!4:&ES
M(&%L;&]W<R!E<G)O<G,@=&\@;V-C=7(@86YD(&YO="!B<F5A:R!T:&4@<V-R
M:7!T+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C
M8V5S<R!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&EN:70H*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]I
M;7-P*2D@>PH@("`@("`@("`@("`D875T:"`]("9.971?24U34%]!=71H.CIS
M:6YG;&5T;VXH)'1H:7,M/E]P87)A;7-;)V%U=&A?;65T:&]D)UTI.PH@("`@
M("`@("`@("`D=&AI<RT^7VEM<W`@/2`D875T:"T^875T:&5N=&EC871E*"1T
M:&ES+3Y?<&%R86US*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]A*"1T
M:&ES+3Y?:6US<"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]I;7-P.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7VEM
M<W`M/G=R:71E5&],;V<H)TYE=%])35-07T]P=&EO;G,@:6YI=&EA;&EZ960N
M)RP@7U]&24Q%7U\L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC=&EO;B!S96YD<R!A($=%
M5"!C;VUM86YD('1O($E-4U`@<V5R=F5R(&%N9"!R971R:65V97,@=F%L=65S
M+@H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG("1O<'1I;VY.86UE($YA
M;64@;V8@;W!T:6]N('1O(')E=')I979E+B!!8V-E<'1S("<J)PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87,@=VEL9"!C87)D+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@($%S<V]C:6%T:79E(&%R<F%Y(&-O
M;G1A:6YI;F<@;W!T:6]N/3YV86QU92!P86ER<R!O<@H@("`@("H@("`@("`@
M("`@("`@("`@4$5!4E]%<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M*"1O<'1I;VY.86UE*0H@("`@>PH@("`@("`@("1O<'1I;VYS(#T@87)R87DH
M*3L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@B
M1T54("1O<'1I;VY.86UE(BP@=')U92P@=')U92D["B`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("1S97)V97)?<F5S<&]N
M<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["B`@("`@("`@:68@
M*&ES7V$H)'-E<G9E<E]R97-P;VYS92P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'-E<G9E<E]R97-P;VYS93L*("`@("`@("!]"@H@
M("`@("`@('=H:6QE("AP<F5G7VUA=&-H*"(O7EPJ($]05$E/3B\B+"`D<V5R
M=F5R7W)E<W!O;G-E*2D@>PH@("`@("`@("`@("`O*B!&:7)S="P@8VAE8VL@
M9F]R(&$@>WTN("HO"B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?
M3T-4151?0T]53E0L("1S97)V97)?<F5S<&]N<V4L("1T96UP07)R87DI*2![
M"B`@("`@("`@("`@("`@("`D=&5M<"`](&5X<&QO9&4H)R`G+"`D<V5R=F5R
M7W)E<W!O;G-E*3L*("`@("`@("`@("`@("`@("1O<'1I;VYS6R1T96UP6S)=
M72`]("1T:&ES+3Y?:6US<"T^<F5C96EV95-T<FEN9TQI=&5R86PH)'1E;7!!
M<G)A>5LR72D["B`@("`@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!2
M96-E:79E*"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D=&5M<"`](&5X<&QO9&4H)R`G+"`D<V5R=F5R7W)E<W!O;G-E*3L*("`@
M("`@("`@("`@("`@("1O<'1I;VYS6R1T96UP6S)=72`]('1R:6TH)'1E;7!;
M,UTI.PH@("`@("`@("`@("`@("`@)&D@/2`S.PH@("`@("`@("`@("`@("`@
M)&QA<W1#:&%R(#T@(B(["B`@("`@("`@("`@("`@("`D;F5X=$5L96UE;G0@
M/2!T<FEM*"1T96UP6S-=*3L*"B`@("`@("`@("`@("`@("`O*B!787,@=&AE
M('9A;'5E('%U;W1E9"!A;F0@<W!A8V5D/R`J+PH@("`@("`@("`@("`@("`@
M:68@*"AS=6)S='(H)&YE>'1%;&5M96YT+#`L,2D@/3T@)R(G*2`F)@H@("`@
M("`@("`@("`@("`@("`@("AS=6)S='(H)&YE>'1%;&5M96YT+'-T<FQE;B@D
M;F5X=$5L96UE;G0I("T@,2P@,2D@(3T@)R(G*2D@>PH@("`@("`@("`@("`@
M("`@("`@(&1O('L*("`@("`@("`@("`@("`@("`@("`@("`@)&YE>'1%;&5M
M96YT(#T@)'1E;7!;)&DK,5T["B`@("`@("`@("`@("`@("`@("`@("`@("1L
M87-T0VAA<B`]('-U8G-T<B@D;F5X=$5L96UE;G0L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=')L96XH)&YE>'1%;&5M
M96YT*2`M(#$L(#$I.PH@("`@("`@("`@("`@("`@("`@("`@("`D;W!T:6]N
M<ULD=&5M<%LR75T@+CT@)R`G("X@)&YE>'1%;&5M96YT.PH@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H)&QA<W1#:&%R(#T]("<B)RD@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&1O;F4@/2!T<G5E.PH@("`@("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1O;F4@/2!F86QS93L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1L87-T0VAA<B`]('-U8G-T<B@D=&5M<%LD:2LR72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=')L96XH
M)'1E;7!;)&DK,ETI("T@,2P@,2D["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D:2LK.PH@("`@("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@("`@('T@=VAI;&4@*"1L87-T0VAA<B`A/2`G(B<I.PH*("`@
M("`@("`@("`@("`@("`@("!I9B`H(21D;VYE*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1N97AT16QE;65N="`]("1T96UP6R1I*S%=.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D;W!T:6]N<ULD=&5M<%LR75T@+CT@)R`G("X@
M)&YE>'1%;&5M96YT.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<V5R=F5R7W)E
M<W!O;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH@("`@("`@
M("`@("!I9B`H:7-?82@D<V5R=F5R7W)E<W!O;G-E+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'-E<G9E<E]R97-P;VYS93L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1S97)V97)?
M<F5S<&]N<V4@(3T@)T]+)RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]I;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!T:&4@97AP96-T
M960@<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R+B<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]I;7-P+3YW<FET951O
M3&]G*"='150@8V]M;6%N9"!/2RXG+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%
M05)?3$]'7T1%0E5'*3L*("`@("`@("!R971U<FX@)&]P=&EO;G,["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!&=6YC=&EO;B!S971S(&%N(&]P=&EO;B!V86QU
M92!O;B!T:&4@24U34"!S97)V97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;W!T:6]N3F%M92`@3F%M92!O9B!O<'1I;VX@=&\@<V5T+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;W!T:6]N5F%L=64@5F%L=64@=&\@87-S:6=N
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@5')U92!O<B!014%27T5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!S970H)&]P=&EO;DYA;64L("1O
M<'1I;VY686QU92D*("`@('L*("`@("`@("`O*B!396YD('1H92!B96=I;FYI
M;F<@;V8@=&AE(&-O;6UA;F0N("HO"B`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?:6US<"T^:6US<%-E;F0H(E-%5"`D;W!T:6]N3F%M92`B+"!T<G5E+"!F
M86QS92D["@H@("`@("`@("\J(%-E;F0@)&]P=&EO;E9A;'5E(&%S(&$@;&ET
M97)A;"![?3\@*B\*("`@("`@("!I9B`H<')E9U]M871C:"A)35-07TU54U1?
M55-%7TQ)5$5204PL("1O<'1I;VY686QU92DI('L*("`@("`@("`@("`@)&)I
M5F%L=64@/2!S<')I;G1F*")[)61](BP@<W1R;&5N*"1O<'1I;VY686QU92DI
M.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N
M9"@D8FE686QU92P@9F%L<V4L('1R=64I.PH@("`@("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@
M*"%P<F5G7VUA=&-H*"(O7EPK+R(L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"DI*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I9"!N
M;W0@<F5C96EV92!E>'!E8W1E9"!C;VUM86YD(&-O;G1I;G5A=&EO;B!R97-P
M;VYS92!F<F]M($E-4U`@<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@3F]W('-E
M;F0@=&AE(')E<W0@;V8@=&AE(&-O;6UA;F0N("HO"B`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)&]P=&EO;E9A;'5E+"!F86QS
M92P@=')U92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]
M"@H@("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM
M<W!296-E:79E*"D["@H@("`@("`@(&EF("AI<U]A*"1S97)V97)?<F5S<&]N
M<V4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1S97)V
M97)?<F5S<&]N<V4["B`@("`@("`@?2!E;'-E:68@*"1S97)V97)?<F5S<&]N
M<V4@(3T@)T]+)RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P
M+3YI;7-P17)R;W(H)U1H92!O<'1I;VX@8V]U;&0@;F]T(&)E('-E="!O;B!T
M:&4@24U34"!S97)V97(N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3Y?:6US<"T^=W)I=&54;TQO9R@G4T54(&-O
M;6UA;F0@3TLN)RP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)5
M1RD["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3971S('1H92!L;V<@:6YF;W)M871I;VX@:6X@=&AE($YE=%])35-0(&]B
M:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@5&AE
M(&QO9R!P87)A;65T97)S+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1R=64@;VX@<W5C8V5S<R!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=$QO9V=E<B@D<&%R86US*0H@("`@>PH@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7VEM<W`I*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7VEM<W`M/G-E=$QO9V=E<B@D<&%R86US*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI
M;7-P17)R;W(H)U1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ
M960N)RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&QO9V]U="@I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]I;7-P+3YL;V=O=70H*3L*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TYE="])
M35-0+U5T:6QS+G!H<```````````````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`Q,#8Q,0`Q,#4Q-30S,S<U,@`P,C$U,S$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J($YE=%])
M35-07U5T:6QS.CH*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO3F5T7TE-4U`O
M24U34"]5=&EL<RYP:'`L=B`Q+C,N,3`N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C(X
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA96P@
M4G5B:6YS:WD@/&UR=6)I;G-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($UI8VAA96P@4G5B:6YS:WD@/&UR=6)I;G-K0&AO<F1E
M+F]R9SX*("H@0'!A8VMA9V4@3F5T7TE-4U`*("HO"F-L87-S($YE=%])35-0
M7U5T:6QS('L*"B`@("`O*BH*("`@("`J(%5T:6QI='D@9G5N8W1I;VX@=&\@
M<F5T<FEE=F4@=&AE(&YA;65S(&]F(&%L;"!T:&4@861D<F5S<R!B;V]K<PH@
M("`@("H@=&AA="!T:&4@=7-E<B!H87,@86-C97-S('1O+"!A;&]N9R!W:71H
M('1H92!A8VP@9F]R('1H;W-E"B`@("`@*B!B;V]K<RX@($9O<B!I;F9O<FUA
M=&EO;B!A8F]U="!T:&4@)'-E<G9E<DEN9F\@87)R87D@<V5E"B`@("`@*B!T
M=7)B82]C;VYF:6<O<V]U<F-E<RYP:'`@87,@=&AI<R!I<R!T:&4@8V9G4V]U
M<F-E<UM=(&5N=')Y(&9O<@H@("`@("H@=&AE(&%D9')E<W,@8F]O:W,N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1S97)V97));F9O("!);F9O<FUA
M=&EO;B!A8F]U="!T:&4@<V5R=F5R"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%N9"!T:&4@8W5R<F5N="!U<V5R+@H@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@($EN9F]R;6%T:6]N(&%B;W5T(&%L;"!T:&4@861D
M<F5S<R!B;V]K<R!O<B!014%27T5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971!;&Q";V]K<R@D<V5R=F5R26YF;RD*("`@('L*("`@("`@("!R97%U
M:7)E7V]N8V4@)TYE="])35-0+G!H<"<["B`@("`@("`@)&9O=6YD1&5F875L
M="`](&9A;'-E.PH@("`@("`@("1R97-U;'1S(#T@87)R87DH*3L*("`@("`@
M("`D:6US<"`]("9.971?24U34#HZ<VEN9VQE=&]N*"=";V]K)RP@)'-E<G9E
M<DEN9F];)W!A<F%M<R==*3L*("`@("`@("`D<F5S=6QT(#T@)&EM<W`M/FEN
M:70H*3L*"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@
M("`@("`@("1B;V]K<R`]("1I;7-P+3YG971!9&1R97-S0F]O:TQI<W0H*3L*
M("`@("`@("!I9B`H:7-?82@D8F]O:W,L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1B;V]K<SL*("`@("`@("!]"@H@("`@("`@("1B
M0V]U;G0@/2!C;W5N="@D8F]O:W,I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\("1B0V]U;G0[("1I*RLI('L*("`@("`@("`@("`@)&YE=T)O;VL@/2`D
M<V5R=F5R26YF;SL*("`@("`@("`@("`@:68@*"1B;V]K<ULD:5T@(3T@)'-E
M<G9E<DEN9F];)W!A<F%M<R==6R=U<V5R;F%M92==*2!["B`@("`@("`@("`@
M("`@("`D;F5W0F]O:ULG=&ET;&4G72`]("=)35-07R<@+B`D8F]O:W-;)&E=
M.PH@("`@("`@("`@("`@("`@)&YE=T)O;VM;)W!A<F%M<R==6R=N86UE)UT@
M/2`D8F]O:W-;)&E=.PH@("`@("`@("`@("`@("`@)&YE=T)O;VM;)W!A<F%M
M<R==6R=I<U]R;V]T)UT@/2!F86QS93L*("`@("`@("`@("`@("`@("1N97="
M;V]K6R=P87)A;7,G75LG;7E?<FEG:'1S)UT@/2`D:6US<"T^;7E2:6=H=',H
M)&)O;VMS6R1I72D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D9F]U;F1$969A=6QT(#T@=')U93L*("`@("`@("`@("`@("`@("1N
M97=";V]K6R=P87)A;7,G75LG;7E?<FEG:'1S)UT@/2`D:6US<"T^;7E2:6=H
M=',H)&)O;VMS6R1I72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E
M<W5L='-;72`]("1N97=";V]K.PH@("`@("`@('T*("`@("`@("`O*B!)9B!T
M:&5R92!I<R!N;R!D969A=6QT(&%D9')E<W,@8F]O:R`H;F%M960@=7-E<FYA
M;64I('1H96X@=V4@<VAO=6QD(&-R96%T92!O;F4N("HO"B`@("`@("`@:68@
M*"$D9F]U;F1$969A=6QT*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D:6US
M<"T^8W)E871E061D<F5S<T)O;VLH)'-E<G9E<DEN9F];)W!A<F%M<R==6R=U
M<V5R;F%M92==*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)TQO9VEN('1O($E-4U`@:&]S="!F86EL960N)R`N"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G.B!$969A=6QT
M(&%D9')E<W,@8F]O:R!I<R!M:7-S:6YG(&%N9"!C;W5L9"!N;W0@8F4@8W)E
M871E9"XG*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U
M<FX@)')E<W5L=',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5=&EL:71Y(&9U
M;F-T:6]N('1O(&UA:V4@:70@96%S:65R(&9O<B!C;&EE;G0@87!P;&EC871I
M;VYS('1O(&1E;&5T90H@("`@("H@861D<F5S<R!B;V]K<R!W:71H;W5T(&AA
M=FEN9R!T;R!C<F5A=&4@:6US<"!D<FEV97)S+B`@5&AE("1S;W5R8V4@87)R
M87D*("`@("`J(&ES(&$@:&]R9&4O='5R8F$@<W1Y;&4@)&-F9U-O=7)C97,@
M96YT<GD@9F]R('1H92!A9&1R97-S(&)O;VL@8F5I;F<*("`@("`J(&1E;&5T
M960N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1S;W5R8V4@($EN9F]R
M;6%T:6]N(&%B;W5T('1H92!A9&1R97-S(&)O;VL@8F5I;F<@9&5L971E9"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@
M;W(@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!D96QE=&5";V]K*"1S;W5R8V4I"B`@("!["B`@("`@("`@<F5Q=6ER95]O
M;F-E("=.970O24U34"YP:'`G.PH@("`@("`@("1I;7-P(#T@)DYE=%])35-0
M.CIS:6YG;&5T;VXH)T)O;VLG+"`D<V]U<F-E6R=P87)A;7,G72D["B`@("`@
M("`@)')E<W5L="`]("1I;7-P+3YI;FET*"D["B`@("`@("`@:68@*&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@)')E<W5L="`]("1I;7-P+3YD
M96QE=&5!9&1R97-S0F]O:R@D<V]U<F-E6R=P87)A;7,G75LG;F%M92==*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%5T:6QI='D@9G5N
M8W1I;VX@=&\@:&5L<"!C;&EE;G1S(&-R96%T92!N97<@861D<F5S<R!B;V]K
M<R!W:71H;W5T(&AA=FEN9PH@("`@("H@=&\@8W)E871E(&%N(&EM<W`@9')I
M=F5R(&EN<W1A;F-E(&9I<G-T+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`D<V]U<F-E("`@($EN9F]R;6%T:6]N(&%B;W5T('1H92!U<V5R)W,@9&5F
M875L="!)35-0"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!A9&1R
M97-S(&)O;VLN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=.86UE("!4:&4@
M;F%M92!O9B!T:&4@;F5W(&%D9')E<W,@8F]O:RX@($YO=&4@=&AA="!T:&ES
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!I<R!A=71O;6%T:6-A
M;&QY('%U86QI9FEE9"!W:71H('1H92!U<V5R)W,@;F%M90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@<V\@<VAO=6QD(&YO="!B92!P87-S960@
M87,@82!F=6QL>2!Q=6%L:69I960@24U34`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@861D<F5S<R!B;V]K(&YA;64N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@=')U92!O;B!S=6-C97-S(&]R(%!%05)?17)R;W(@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@(&9U;F-T:6]N(&-R96%T94)O;VLH
M)'-O=7)C92P@)&YE=TYA;64I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E
M("=.970O24U34"YP:'`G.PH@("`@("`@("1I;7-P(#T@)DYE=%])35-0.CIS
M:6YG;&5T;VXH)T)O;VLG+"`D<V]U<F-E6R=P87)A;7,G72D["B`@("`@("`@
M)')E<W5L="`]("1I;7-P+3YI;FET*"D["B`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("!]"B`@("`@("`@)&YA;64@/2`D<V]U<F-E6R=P87)A
M;7,G75LG=7-E<FYA;64G72`N("<N)R`N("1N97=.86UE.PH@("`@("`@("1R
M97-U;'0@/2`D:6US<"T^8W)E871E061D<F5S<T)O;VLH)&YA;64I.PH@("`@
M("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O3F5T+TE-4U`N<&AP````
M````````````````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,U,30W
M`#$P-3$U-#,S-S4R`#`R,#0T-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H*:6YC;'5D95]O;F-E("=,;V<N<&AP
M)SL*"B\O($-O;G-T86YT($1E9FEN:71I;VYS"F1E9FEN92@G24U34%]/0U1%
M5%]#3U5.5"<L("(O*'LI*%LP+3E=>S$L?2DH7'TD*2\B*3L*9&5F:6YE*"=)
M35-07TU54U1?55-%7TQ)5$5204PG+"`B+UM<5UTO:2(I.PH*+RHJ"B`J(%1H
M92!.971?24U34"!C;&%S<R!P<F]V:61E<R!A(&-O;6UO;B!I;G1E<F9A8V4@
M=&\@86X@24U34"!S97)V97(@+@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S
M.CQP<F4^"B`J("`@)W-E<G9E<B<@($AO<W1N86UE(&]F($E-4U`@<V5R=F5R
M+@H@*B`@("=P;W)T)R`@("!0;W)T(&]F($E-4U`@<V5R=F5R+CPO<')E/@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].971?24U34"])35-0+G!H<"QV(#$N
M,3,N,3`N,3D@,C`P-B\P,B\Q,"`P-#HU.#HR-B!S96QS:WD@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6-H865L(%)U8FEN<VMY(#QM<G5B
M:6YS:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-
M:6-H865L(%)U8FEN<VMY(#QM<G5B:6YS:T!H;W)D92YO<F<^"B`J($!P86-K
M86=E($YE=%])35-0"B`J+PIC;&%S<R!.971?24U34"!["@H@("`@+RHJ"B`@
M("`@*B!3=')I;F<@8V]N=&%I;FEN9R!N86UE+TE0(&%D9')E<W,@;V8@24U3
M4"!H;W-T+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D:6US<%]S97)V97(@("`@("`@("`@("`@("`@/2`G;&]C86QH;W-T
M)SL*"B`@("`O*BH*("`@("`J(%-T<FEN9R!C;VYT86EN:6YG('!O<G0@9F]R
M($E-4U`@<V5R=F5R+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D:6US<%]P;W)T("`@("`@("`@("`@("`@("`@/2`G-#`V
M)SL*"B`@("`O*BH*("`@("`J($)O;VQE86X@=&\@<V5T(&EF('=E('-H;W5L
M9"!W<FET92!T;R!A(&QO9RP@:68@;VYE(&ES('-E="!U<"X*("`@("`J"B`@
M("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1L;V=%;F%B;&5D
M("`@("`@("`@("`@("`@("`]('1R=64["@H@("`@+RHJ"B`@("`@*B!3=')I
M;F<@8G5F9F5R(&-O;G1A:6YI;F<@=&AE(&QA<W0@<F%W($Y/(&]R($)!1"!R
M97-P;VYS92!F<F]M('1H90H@("`@("H@<V5R=F5R+@H@("`@("H*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D;&%S=%)A=T5R<F]R("`@
M("`@("`@("`@("`]("<G.PH*("`@("\O(%!R:79A=&4@1&5C;&%R871I;VYS
M"B`@("!V87(@)%]C;VUM86YD4')E9FEX("`@("`@("`@("`@(#T@)T$G.PH@
M("`@=F%R("1?8V]M;6%N9$-O=6YT("`@("`@("`@("`@("`](#$["B`@("!V
M87(@)%]T86<@("`@("`@("`@("`@("`@("`@("`@(#T@)R<["B`@("!V87(@
M)%]S=')E86T@("`@("`@("`@("`@("`@("`@(#T@;G5L;#L*("`@('9A<B`D
M7VQA<W1#;VUM86YD5&%G("`@("`@("`@("`@/2`G=6YD969I;F5D)SL*("`@
M('9A<B`D7VQO9V=E<B`@("`@("`@("`@("`@("`@("`@/2!N=6QL.PH@("`@
M=F%R("1?;&]G4V5T("`@("`@("`@("`@("`@("`@("`](&YU;&P["B`@("!V
M87(@)%]L;V=,979E;"`@("`@("`@("`@("`@("`@(#T@4$5!4E],3T=?24Y&
M3SL*("`@('9A<B`D7VQO9T)U9F9E<B`@("`@("`@("`@("`@("`@(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R(&9U;F-T:6]N+@H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US($AA<V@@8V]N=&%I
M;FEN9R!S97)V97(@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M3F5T7TE-4U`H)'!A<F%M<RD*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH
M)'!A<F%M<RD@)B8@(65M<'1Y*"1P87)A;7-;)W-E<G9E<B==*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^:6US<%]S97)V97(@/2`D<&%R86US6R=S97)V97(G
M73L*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]A<G)A>2@D<&%R86US*2`F
M)B`A96UP='DH)'!A<F%M<ULG<&]R="==*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^:6US<%]P;W)T(#T@)'!A<F%M<ULG<&]R="==.PH@("`@("`@('T*"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!);FET:6%L:7IA=&EO;B!F=6YC=&EO;B!T
M;R!B92!C86QL960@869T97(@;V)J96-T(&ES(')E='5R;F5D+B`@5&AI<PH@
M("`@("H@86QL;W=S(&5R<F]R<R!T;R!O8V-U<B!A;F0@;F]T(&)R96%K('1H
M92!S8W)I<'0N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O
M;B!S=6-C97-S(%!%05)?17)R;W(@;VX@8V]N;F5C=&EO;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!I;FET*"D*("`@('L*("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/FEM<W!/<&5N*"D["@H@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YW<FET951O3&]G*"=)
M;FET:6%L:7II;F<@3F5T7TE-4U`@;V)J96-T+B<L(%]?1DE,15]?+"!?7TQ)
M3D5?7RP*("`@("`@("`@("`@("`@("`@("`@("`@("!014%27TQ/1U])3D9/
M*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M($QO9W,@;W5T(&]F('1H92!S97)V97(@86YD(&-L;W-E<R!T:&4@24U34"!S
M=')E86T*("`@("`J+PH@("`@9G5N8W1I;VX@;&]G;W5T*"D*("`@('L*("`@
M("`@("`D=&AI<RT^=W)I=&54;TQO9R@G0VQO<VEN9R!)35-0($-O;FYE8W1I
M;VXN)RP@7U]&24Q%7U\L(%]?3$E.15]?+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@(%!%05)?3$]'7TE.1D\I.PH@("`@("`@("1C;VUM86YD7W-T<FEN
M9R`]("=,3T=/550G.PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^:6US<%-E
M;F0H)&-O;6UA;F1?<W1R:6YG*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(&9C;&]S92@D=&AI<RT^
M7W-T<F5A;2D["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(&9C;&]S92@D=&AI<RT^7W-T<F5A;2D[
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE(')A=R!C87!A8FEL:71Y(')E<W!O
M;G-E(&9R;VT@=&AE('-E<G9E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(')A=R!C87!A8FEL:71Y(')E<W!O;G-E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!C87!A8FEL:71Y*"D*("`@('L*("`@("`@("`D8V]M;6%N
M9%]S=')I;F<@/2`G0T%004))3$E462<["B`@("`@("`@)')E<W5L="`]("1T
M:&ES+3YI;7-P4V5N9"@D8V]M;6%N9%]S=')I;F<I.PH@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1R97-U;'0["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-E
M<G9E<E]R97-P;VYS92`]("1T:&ES+3YI;7-P4F5C96EV92@I.PH@("`@("`@
M("`@("!I9B`H<')E9U]M871C:"@B+UY<*B!#05!!0DE,2519+R(L("1S97)V
M97)?<F5S<&]N<V4I*2!["B`@("`@("`@("`@("`@("`D8V%P86)I;&ET>2`]
M('!R96=?<F5P;&%C92@B+UY<*B!#05!!0DE,2519+R(L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)RP@)'-E<G9E<E]R
M97-P;VYS92D["@H@("`@("`@("`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]
M("1T:&ES+3YI;7-P4F5C96EV92@I.R`O+T]+"@H@("`@("`@("`@("`@("`@
M:68@*"$D<V5R=F5R7W)E<W!O;G-E(#T]("=/2R<I('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E
M:79E('1H92!E>'!E8W1E9"!R97-P;VYS92!F<F]M('1H92!S97)V97(N)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W)I=&54;TQO9R@G0T%004))
M3$E462!C;VUP;&5T960@3TLG+"!?7T9)3$5?7RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!?7TQ)3D5?7RP@4$5!4E],3T=?24Y&
M3RD["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1C87!A8FEL:71Y.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@;W!E;B!A;B!)35-0('-O
M8VME="!W:71H('1H92!S97)V97(N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@5')U92!O;B!S=6-C97-S(%!%05)?17)R;W(@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@:6US<$]P96XH*0H@("`@>PH@("`@("`@
M("1F<"`]($!F<V]C:V]P96XH)'1H:7,M/FEM<W!?<V5R=F5R+"`D=&AI<RT^
M:6US<%]P;W)T*3L*("`@("`@("!I9B`H(21F<"D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/FEM<W!%<G)O<B@G0V]N;F5C=&EO;B!T;R!)35-0(&AO
M<W0@9F%I;&5D+B<L(%]?1DE,15]?+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@("`@("1T
M:&ES+3Y?<W1R96%M(#T@)&9P.PH@("`@("`@("1S97)V97)?<F5S<&]N<V4@
M/2`D=&AI<RT^:6US<%)E8V5I=F4H*3L*("`@("`@("!I9B`H(7!R96=?;6%T
M8V@H(B]>7"H@3TLO(BP@)'-E<G9E<E]R97-P;VYS92DI('L*("`@("`@("`@
M("`@9F-L;W-E*"1F<"D["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^:6US
M<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@=&AE(&5X<&5C=&5D(')E<W!O;G-E
M(&9R;VT@=&AE('-E<G9E<BXG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J($%T=&5M<'1S('1O('-E;F0@82!C;VUM86YD('1O('1H92!S97)V97(N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&-O;6UA;F1497AT(%1E
M>'0@=&\@<V5N9"!T;R!T:&4@<V5R=F5R+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&EN8VQU9&5486<@($1E=&5R;6EN97,@:68@8V]M;6%N9"!T86<@:7,@
M<')E<&5N9&5D+@H@("`@("H@0'!A<F%M(&)O;VQE86X@("1S96YD0U),1B`@
M($1E=&5R;6EN97,@:68@0U),1B!I<R!A<'!E;F1E9"X*("`@("`J($!R971U
M<FX@;6EX960@("!4<G5E(&]N('-U8V-E<W,@4$5!4E]%<G)O<B!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!I;7-P4V5N9"@D8V]M;6%N9%1E
M>'0L("1I;F-L=61E5&%G/71R=64L("1S96YD0U),1CUT<G5E*0H@("`@>PH@
M("`@("`@("1C;VUM86YD7W1E>'0@/2`G)SL*"B`@("`@("`@:68@*"$D=&AI
M<RT^7W-T<F5A;2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FEM<W!%
M<G)O<B@G0V]N;F5C=&EO;B!T;R!)35-0(&AO<W0@9F%I;&5D+B<L(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("!I9B`H)&EN8VQU
M9&5486<I('L*("`@("`@("`@("`@)'1H:7,M/E]T86<@/2`D=&AI<RT^7V=E
M=$YE>'1#;VUM86YD5&%G*"D["B`@("`@("`@("`@("1C;VUM86YD7W1E>'0@
M/2`B)'1H:7,M/E]T86<@(CL*("`@("`@("!]"@H@("`@("`@("1C;VUM86YD
M7W1E>'0@+CT@)&-O;6UA;F1497AT.PH*("`@("`@("!I9B`H)'-E;F1#4DQ&
M*2!["B`@("`@("`@("`@("1C;VUM86YD7W1E>'0@+CT@(EQR7&XB.PH@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/G=R:71E5&],;V<H)U1O.B`G("X@)&-O
M;6UA;F1?=&5X="P@7U]&24Q%7U\L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@:68@*"%F
M<'5T<R@D=&AI<RT^7W-T<F5A;2P@)&-O;6UA;F1?=&5X="DI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YI;7-P17)R;W(H)T-O;FYE8W1I;VX@=&\@
M24U34"!H;W-T(&9A:6QE9"XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E8V5I=F5S(&$@<VEN9VQE($-2
M3$8@=&5R;6EN871E9"!S97)V97(@<F5S<&]N<V4@<W1R:6YG"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`G3D\G+"`G0D%$)RP@)T]+)RP@<F%W(')E
M<W!O;G-E(&]R(%!%05)?17)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EM
M<W!296-E:79E*"D*("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?<W1R96%M
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^:6US<$5R<F]R*"=#;VYN
M96-T:6]N('1O($E-4U`@:&]S="!F86EL960N)RP@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("!]"B`@("`@("`@)')E<W5L="`](&9G971S*"1T:&ES
M+3Y?<W1R96%M+"`U,3(I.PH@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E
M:79E('1H92!E>'!E8W1E9"!R97-P;VYS92!F<F]M('1H92!S97)V97(N)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L
M(%]?3$E.15]?*3L*("`@("`@("!]"B`@("`@("`@)&UE=&$@/2!S=')E86U?
M9V5T7VUE=&%?9&%T82@D=&AI<RT^7W-T<F5A;2D["B`@("`@("`@:68@*"1M
M971A6R=T:6UE9%]O=70G72D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/FEM<W!%<G)O<B@G0V]N;F5C=&EO;B!T;R!)35-0(&AO<W0@9F%I;&5D+B<@
M+B`G.B!#;VYN96-T:6]N('1I;65D(&]U="$G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@('T*"B`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]('1R:6TH)')E<W5L
M="D["B`@("`@("`@)'1H:7,M/G=R:71E5&],;V<H)T9R;VTZ("<@+B`D<V5R
M=F5R7W)E<W!O;G-E+"!?7T9)3$5?7RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`O*B!0
M87)S92!O=70@=&AE(')E<W!O;G-E.@H@("`@("`@("`J($9I<G-T(&UA:V4@
M<W5R92!T:&%T('1H:7,@:7,@;F]T(&9O<B!A('!R979I;W5S(&-O;6UA;F0N
M"B`@("`@("`@("H@268@:70@:7,L(&ET(&UE86YS('=E(&1I9"!N;W0@<F5A
M9"!A;&P@=&AE('-E<G9E<B!R97-P;VYS97,@9G)O;0H@("`@("`@("`J('1H
M92!L87-T(&-O;6UA;F0N+BYR96%D('1H96T@;F]W+"!B=70@=&AR;W<@86X@
M97)R;W(N("HO"B`@("`@("`@=VAI;&4@*'!R96=?;6%T8V@H(B]>(B`N("1T
M:&ES+3Y?;&%S=$-O;6UA;F1486<*("`@("`@("`@("`@("`@("`@("`@("`@
M("`N(B\B+"`D<V5R=F5R7W)E<W!O;G-E*2D@>PH@("`@("`@("`@("`D<V5R
M=F5R7W)E<W!O;G-E(#T*("`@("`@("`@("`@("`@('1R:6TH9F=E=',H)'1H
M:7,M/E]S=')E86TL(#4Q,BDI.PH@("`@("`@("`@("`D=&AI<RT^:6US<$5R
M<F]R*"=$:60@;F]T(')E8V5I=F4@=&AE(&5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@=&AE('-E<G9E<BXG("X@(CH@)'-E<G9E<E]R97-P;VYS92(L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("!]"@H@("`@("`@("1C=7)R96YT5&%G(#T@)'1H:7,M/E]T86<[
M"B`@("`@("`@:68@*'!R96=?;6%T8V@H(B]>(B`N("1C=7)R96YT5&%G("X@
M(B!.3R\B+"`D<V5R=F5R7W)E<W!O;G-E*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^;&%S=%)A=T5R<F]R(#T@)'-E<G9E<E]R97-P;VYS93L*("`@("`@("`@
M("`@<F5T=7)N("=.3R<["B`@("`@("`@?0H*("`@("`@("!I9B`H<')E9U]M
M871C:"@B+UXB("X@)&-U<G)E;G1486<@+B`B($)!1"\B+"`D<V5R=F5R7W)E
M<W!O;G-E*2D@>PH@("`@("`@("`@("`D=&AI<RT^:6US<$5R<F]R*"=4:&4@
M24U34"!S97)V97(@9&ED(&YO="!U;F1E<G-T86YD('EO=7(@<F5Q=65S="XG
M+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("`D=&AI<RT^;&%S
M=%)A=T5R<F]R(#T@)'-E<G9E<E]R97-P;VYS93L*("`@("`@("`@("`@<F5T
M=7)N("="040G.PH@("`@("`@('T*"B`@("`@("`@:68@*'!R96=?;6%T8V@H
M(B]>(B`N("1C=7)R96YT5&%G("X@(B!/2R\B+"`D<V5R=F5R7W)E<W!O;G-E
M*2D@>PH@("`@("`@("`@("!R971U<FX@)T]+)SL*("`@("`@("!]"@H@("`@
M("`@("\J($EF(&ET('=A<R!N;W0@82`G3D\G+"`G0D%$)R!O<B`G3TLG(')E
M<W!O;G-E+`H@("`@("`@("`J('1H96X@:70G<R!U<"!T;R!T:&4@8V%L;&EN
M9R!F=6YC=&EO;B!T;R!D96-I9&4*("`@("`@("`@*B!W:&%T('1O(&1O('=I
M=&@@:70N("HO"B`@("`@("`@<F5T=7)N("1S97)V97)?<F5S<&]N<V4["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V97,@0U),1B!T97)M:6YA=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R(&%N9"!S<&QI=',@:70@:6YT;PH@("`@
M("H@86X@87)R87D@9&5L:6UI=&5D(&)Y(&$@/'-P86-E/BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y(')E<W5L="!F<F]M(&5X<&QO9&4H*2X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T4V5R=F5R4F5S<&]N<V5#:'5N:W,H*0H@
M("`@>PH@("`@("`@("1S97)V97)?<F5S<&]N<V4@/0H@("`@("`@("`@("!T
M<FEM*&9G971S*"1T:&ES+3Y?<W1R96%M+"`U,3(I*3L*("`@("`@("`D8VAU
M;FMS(#T@97AP;&]D92@G("<L("1S97)V97)?<F5S<&]N<V4I.PH@("`@("`@
M(')E='5R;B`D8VAU;FMS.PH@("`@?0H*("`@("\J"B`@("`@*B!296-E:79E
M<R!F:7AE9"!N=6UB97(@;V8@8GET97,@9G)O;2!)35-0('-O8VME="X@57-E
M9"!W:&5N"B`@("`@*B!S97)V97(@<F5T=7)N<R!A('-T<FEN9R!L:71E<F%L
M+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1L96YG=&@@($YU;6)E
M<B!O9B!B>71E<R!T;R!R96%D(&9R;VT@<V]C:V5T+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!497AT(&]F('-T<FEN9R!L:71E<F%L+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R96-E:79E4W1R:6YG3&ET97)A;"@D;&5N9W1H
M*0H@("`@>PH@("`@("`@("1T96UP(#T@=')I;2AF<F5A9"@D=&AI<RT^7W-T
M<F5A;2P@)&QE;F=T:"DI.PH@("`@("`@("1T:&ES+3YW<FET951O3&]G*"=&
M<F]M>WTZ("<@+B`D=&5M<"P@7U]&24Q%7U\L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("!R
M971U<FX@)'1E;7`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!);F-R96UE;G1S
M('1H92!)35-0(&-O;6UA;F0@=&%G('1O:V5N+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H@0')E='5R;B!S=')I;F<@3F5X="!C;VUM
M86YD('1A9RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$YE>'1#;VUM86YD
M5&%G*"D*("`@('L*("`@("`@("`D=&AI<RT^7VQA<W1#;VUM86YD5&%G(#T@
M)'1H:7,M/E]T86<@/R`D=&AI<RT^7W1A9R`Z("=U;F1E9FEN960G.PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7V-O;6UA;F10<F5F:7@@+B!S<')I;G1F*"<E
M,#1D)RP@)'1H:7,M/E]C;VUM86YD0V]U;G0K*RD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$971E<FUI;F5S(&EF(&$@<W1R:6YG(&YE961S('1O(&)E('%U
M;W1E9"!B969O<F4@<V5N9&EN9R!T;R!T:&4@<V5R=F5R+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'-T<FEN9R`@4W1R:6YG('1O(&)E('1E<W1E
M9"X*("`@("`J($!R971U<FX@<W1R:6YG($]R:6=I;F%L('-T<FEN9R!Q=6]T
M960@:68@;F5E9&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!Q=6]T95-P86-E
M9%-T<FEN9R@D<W1R:6YG*0H@("`@>PH@("`@("`@(&EF("AS=')P;W,H)'-T
M<FEN9RP@)R`G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N("<B
M)R`N("1S=')I;F<@+B`G(B<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N("1S=')I;F<["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@4F%I<V5S(&%N($E-4U`@97)R;W(N("!"87-I8V%L;'DL(&]N;'D@
M=W)I=&5S"B`@("`@*B!E<G)O<B!O=70@=&\@=&AE(&AO<F1E(&QO9V9I;&4@
M86YD(')E='5R;G,@4$5!4E]%<G)O<@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&5R<B`@("!%:71H97(@4$5!4E]%<G)O<B!O8FIE8W0@;W(@=&5X
M="!T;R!W<FET92!T;R!L;V<N"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE
M("`@1FEL92!N86UE('=H97)E(&5R<F]R(&]C8W5R960N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D;&EN92`@3&EN92!N=6UB97(@=VAE<F4@97)R;W(@;V-C
M=7)E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@:6US<$5R<F]R*"1E<G(@/2`G
M)RP@)&9I;&4]7U]&24Q%7U\L("1L:6YE/5]?3$E.15]?*0H@("`@>PH@("`@
M("`@(&EF("AI<U]A*"1E<G(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@)&QO9U]T97AT(#T@)&5R<BT^9V5T365S<V%G92@I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1L;V=?=&5X="`]("1E<G(["B`@("`@("`@
M?0H*("`@("`@("`D=&AI<RT^=W)I=&54;TQO9R@D;&]G7W1E>'0L("1F:6QE
M+"`D;&EN92P@4$5!4E],3T=?15)2*3L*("`@("`@("!I9B`H:7-?82@D97)R
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D97)R.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*"1E<G(I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%=R:71E<R!A(&UE<W-A9V4@=&\@=&AE($E-4U`@;&]G9FEL92X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1M97-S86=E("!497AT('1O('=R:71E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET951O3&]G*"1M97-S86=E+"`D
M9FEL92`](%]?1DE,15]?+`H@("`@("`@("`@("`@("`@("`@("`@("`D;&EN
M92`](%]?3$E.15]?+"`D<')I;W)I='D@/2!014%27TQ/1U])3D9/*0H@("`@
M>PH@("`@("`@(&EF("@H)'1H:7,M/FQO9T5N86)L960I("8F("@D=&AI<RT^
M7VQO9U-E="DI('L*("`@("`@("`@("`@:68@*"1P<FEO<FET>2`^("1T:&ES
M+3Y?;&]G3&5V96PI('L*("`@("`@("`@("`@("`@(')E='5R;CL*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)&QO9TUE<W-A9V4@/2`G6VEM<W!=("<@
M+B`D;65S<V%G92`N("<@6V]N(&QI;F4@)R`N("1L:6YE("X@)R!O9B`B)R`N
M("1F:6QE("X@)R)=)SL*("`@("`@("`@("`@)'1H:7,M/E]L;V=G97(M/FQO
M9R@D;&]G365S<V%G92P@)'!R:6]R:71Y*3L*("`@("`@("!](&5L<V5I9B`H
M*"$D=&AI<RT^7VQO9U-E="D@)B8@*"1T:&ES+3YL;V=%;F%B;&5D*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7VQO9T)U9F9E<EM=(#T@87)R87DH)VUE<W-A
M9V4G("`]/B`D;65S<V%G92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=P<FEO<FET>2<@/3X@)'!R:6]R:71Y+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9I;&4G("`@("`]
M/B`D9FEL92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=L:6YE)R`@("`@/3X@)&QI;F4*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@0W)E871E<R!A(&YE=R!,;V<@;V)J96-T(&)A<V5D(&]N("1P
M87)A;7,*("`@("`J"B`@("`@*B!`<&%R86T@(&%R<F%Y("`D<&%R86US($QO
M9R!O8FIE8W0@<&%R86UE=&5R<RX*("`@("`J($!R971U<FX@;6EX960@(%1R
M=64@;VX@<W5C8V5S<R!O<B!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=$QO9V=E<B@D<&%R86US*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?;&]G3&5V96P@/2`D<&%R86US6R=P<FEO<FET>2==.PH@
M("`@("`@("1L;V=G97(@/2`F3&]G.CIS:6YG;&5T;VXH)'!A<F%M<ULG='EP
M92==+"`D<&%R86US6R=N86UE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<&%R86US6R=I9&5N="==+"`D<&%R86US6R=P87)A;7,G
M72D["B`@("`@("`@)'1H:7,M/E]L;V=3970@/2!T<G5E.PH*("`@("`@("!I
M9B`H:7-?82@D;&]G9V5R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("1T:&ES+3YL;V=%;F%B;&5D(#T@9F%L<V4["B`@("`@("`@("`@(')E='5R
M;B`D;&]G9V5R.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES
M+3Y?;&]G9V5R(#T@)B1L;V=G97(["B`@("`@("`@("`@("1T:&ES+3YL;V=%
M;F%B;&5D(#T@=')U93L*("`@("`@("`@("`@)'1H:7,M/E]W<FET94QO9T)U
M9F9E<B@I.PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!7<FET97,@;W5T(&-O;G1E;G1S(&]F("1?
M;&]G0G5F9F5R('1O(&QO9R!F:6QE+B`@06QL;W=S(&UE<W-A9V5S"B`@("`@
M*B!T;R!B92!L;V=G960@9'5R:6YG(&EN:71I86QI>F%T:6]N(&]F(&]B:F5C
M="!B969O<F4@3&]G(&]B:F5C="!I<PH@("`@("H@:6YS=&%N=&EA=&5D+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC
M=&EO;B!?=W)I=&5,;V="=69F97(H*0H@("`@>PH@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\(&-O=6YT*"1T:&ES+3Y?;&]G0G5F9F5R*3L@)&DK*RD@>PH@
M("`@("`@("`@("`D=&AI<RT^=W)I=&54;TQO9R@D=&AI<RT^7VQO9T)U9F9E
M<ELD:5U;)VUE<W-A9V4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]L;V="=69F97);)&E=6R=F:6QE)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;&]G0G5F9F5R6R1I75LG;&EN
M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VQO
M9T)U9F9E<ELD:5U;)W!R:6]R:71Y)UTI.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($%T=&5M<'1S('1O(&-R96%T92!A($YE=%])35-0(&]B
M:F5C="!B87-E9"!O;B`D9')I=F5R+@H@("`@("H@375S="!B92!C86QL960@
M87,@)&EM<W`@/2`F3F5T7TE-4U`Z.F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M
M<RD["B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<@)&1R:79E<B!4>7!E
M(&]F($YE=%])35-0(&]B:F5C="!T;R!R971U<FXN"B`@("`@*B!`<&%R86T@
M(&UI>&5D("`D<&%R86US("!!;GD@<&%R86UE=&5R<R!N965D960@8GD@=&AE
M($YE=%])35-0(&]B:F5C="X*("`@("`J($!R971U<FX@;6EX960@(%1H92!R
M97%U97-T960@3F5T7TE-4U`@;V)J96-T(&]R(%!%05)?17)R;W(@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)&1R:79E<BP@
M)'!A<F%M<RD*("`@('L*("`@("`@("`D9')I=F5R(#T@8F%S96YA;64H)&1R
M:79E<BD["B`@("`@("`@:68@*&5M<'1Y*"1D<FEV97(I('Q\("1D<FEV97(@
M/3T@)VYO;F4G*2!["B`@("`@("`@("`@("1I;7-P(#T@)FYE=R!.971?24U3
M4"@D<&%R86US*3L*("`@("`@("`@("`@<F5T=7)N("1I;7-P.PH@("`@("`@
M('T*"B`@("`@("`@:6YC;'5D95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R])35-0+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@("1C;&%S<R`]
M("=.971?24U34%\G("X@)&1R:79E<CL*("`@("`@("!I9B`H8VQA<W-?97AI
M<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)&EM<W`@/2`F;F5W("1C;&%S
M<R@D<&%R86US*3L*("`@("`@("`@("`@<F5T=7)N("1I;7-P.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@($AO<F1E.CIF871A;"A014%2.CIR86ES
M945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I
M;VX@;V8@)7,N(BDL("1C;&%S<RDI+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E
M='5R;B!A($YE=%])35-0(&]B:F5C="!B87-E9"!O;B`D9')I=F5R+B`@3VYL
M>0H@("`@("H@8W)E871E<R!A(&YE=R!O8FIE8W0@:68@;VYE('=I=&@@=&AE
M('-A;64@<&%R86UE=&5R<R!A;')E861Y"B`@("`@*B!D;V5S;B=T(&5X:7-T
M+@H@("`@("H@375S="!B92!C86QL960@87,@)&EM<W`@/2`F3F5T7TE-4U`Z
M.G-I;F=L971O;B@D9')I=F5R+"`D<&%R86US*3L*("`@("`J"B`@("`@*B!`
M<&%R86T@('-T<FEN9R`D9')I=F5R(%1Y<&4@;V8@3F5T7TE-4U`@;V)J96-T
M('1O(')E='5R;BX*("`@("`J($!P87)A;2`@;6EX960@("1P87)A;7,@06YY
M('!A<F%M971E<G,@;F5E9&5D(&)Y('1H92!.971?24U34"!O8FIE8W0N"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!2969E<F5N8V4@=&\@=&AE($YE=%])35-0
M(&]B:F5C="!O<B!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9S:6YG;&5T;VXH)&1R:79E<BP@)'!A<F%M<RD*("`@('L*
M("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<SL*("`@("`@("!I9B`H(6ES<V5T
M*"1I;G-T86YC97,I*2!["B`@("`@("`@("`@("1I;G-T86YC97,@/2!A<G)A
M>2@I.PH@("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ
M92AA<G)A>2@D9')I=F5R+"`D<&%R86US*2D["B`@("`@("`@:68@*"%I<W-E
M="@D:6YS=&%N8V5S6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS
M=&%N8V5S6R1S:6=N871U<F5=(#T@)DYE=%])35-0.CIF86-T;W)Y*"1D<FEV
M97(L("1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T
M86YC97-;)'-I9VYA='5R95T["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B].970O4TU3+P``````````````````````````
M````````````````````````````````````````````````````````,#`P
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-3(`
M,#$W-C$S`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<```````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S
M,3$R-P`Q,#4Q-30S,S<U,@`P,C,T-S8`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J($YE=%]335-?8VQI
M8VMA=&5L;%]H='1P($-L87-S(&EM<&QE;65N=',@=&AE($A45%`@05!)(&9O
M<B!A8V-E<W-I;F<@=&AE"B`J($-L:6-K871E;&P@*'=W=RYC;&EC:V%T96QL
M+F-O;2D@4TU3(&=A=&5W87DN"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@
M36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`L=B`Q+C$S+C$P+CD@,C`P-B\P."\P-R`P,#HT,CHS,"!C:'5C
M:R!%>'`@)`H@*@H@*B!`875T:&]R($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L
M;RYC;VT^"B`J($!P86-K86=E($YE=%]335,*("HO"F-L87-S($YE=%]335-?
M8VQI8VMA=&5L;%]H='1P(&5X=&5N9',@3F5T7U--4R!["@H@("`@=F%R("1?
M<V5S<VEO;E]I9"`](&YU;&P["B`@("!V87(@)%]B87-E7W5R;"`]("=H='1P
M.B\O87!I+F-L:6-K871E;&PN8V]M+VAT='`O)SL*"B`@("`O*BH*("`@("`J
M($%N(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@9')I=F5R
M(&-A;B!R97!O<G0@=VAI8V@@;W!E<F%T:6]N<PH@("`@("H@:70@<W5P<&]R
M=',@86YD('=H:6-H(&ET(&1O97-N)W0N(%!O<W-I8FQE('9A;'5E<R!A<F4Z
M/'!R93X*("`@("`J("`@875T:"`@("`@("`@+2!4:&4@9V%T97=A>2!R97%U
M:7)E(&%U=&AE;G1I8V%T:6]N(&)E9F]R92!S96YD:6YG.PH@("`@("H@("!B
M871C:"`@("`@("`M($)A=&-H('-E;F1I;F<@:7,@<W5P<&]R=&5D.PH@("`@
M("H@("!M=6QT:2`@("`@("`M(%-E;F1I;F<@;V8@;65S<V%G97,@=&\@;75L
M=&EP;&4@<F5C:7!I96YT<R!I<R!S=7!P;W)T960["B`@("`@*B`@(')E8V5I
M=F4@("`@("T@5VAE=&AE<B!T:&ES(&1R:79E<B!I<R!C87!A8FQE(&]F(')E
M8V5I=FEN9R!335,["B`@("`@*B`@(&-R961I="`@("`@("T@27,@=7-E(&]F
M('1H92!G871E=V%Y(&)A<V5D(&]N(&-R961I=',["B`@("`@*B`@(&%D9')E
M<W-B;V]K("T@07)E(&=A=&5W87D@861D<F5S<V)O;VMS('-U<'!O<G1E9#L*
M("`@("`J("`@;&ES=',@("`@("`@+2!'871E=V%Y('-U<'!O<G0@9F]R(&1I
M<W1R:6)U=&EO;B!L:7-T<RX*("`@("`J(#PO<')E/@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1C87!A8FEL:71I97,@/2!A
M<G)A>2@G875T:"<@("`@("`@(#T^('1R=64L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=B871C:"<@("`@("`@/3X@,3`P+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G;75L=&DG("`@("`@(#T^('1R=64L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R96-E:79E)R`@("`@/3X@
M9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C<F5D:70G
M("`@("`@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V%D9')E<W-B;V]K)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VQI<W1S)R`@("`@("`]/B!F86QS92D["@H@("`@+RHJ"B`@
M("`@*B!!=71H96YT:6-A=&4@870@=&AE(&=A=&5W87D@86YD('-E="!A('-E
M<W-I;VX@:60@:68@<W5C8V5S<V9U;"X@0V%C:&EN9PH@("`@("H@:7,@=7-E
M9"!T;R!M:6YI;6ES92!T:&4@:'1T<"!C86QL<R!F;W(@<W5B<V5Q=65N="!M
M97-S86=E<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@4$5!
M4B!%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?875T
M:&5N=&EC871E*"D*("`@('L*("`@("`@("`O*B!792!H879E(&%L<F5A9'D@
M875T:&5N=&EC871E9"!S;R!R971U<FX@=')U92X@*B\*("`@("`@("!I9B`H
M(65M<'1Y*"1T:&ES+3Y?<V5S<VEO;E]I9"DI('L*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`O*B!3970@=7`@=&AE(&AT
M='`@875T:&5N=&EC871I;VX@=7)L+B`J+PH@("`@("`@("1U<FP@/2!S<')I
M;G1F*"=A=71H/W5S97(])7,F<&%S<W=O<F0])7,F87!I7VED/25S)RP*("`@
M("`@("`@("`@("`@("`@("`@("!U<FQE;F-O9&4H)'1H:7,M/E]P87)A;7-;
M)W5S97(G72DL"B`@("`@("`@("`@("`@("`@("`@("`@=7)L96YC;V1E*"1T
M:&ES+3Y?<&%R86US6R=P87-S=V]R9"==*2P*("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG87!I7VED)UTI.PH*("`@("`@("`O*B!$
M;R!T:&4@2%144"!A=71H96YT:6-A=&EO;B!A;F0@9V5T('1H92!R97-P;VYS
M92X@*B\*("`@("`@("`D<F5S<&]N<V4@/2!.971?4TU37V-L:6-K871E;&Q?
M:'1T<#HZ7V-A;&Q54DPH)'5R;"D["B`@("`@("`@:68@*&ES7V$H)')E<W!O
M;G-E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*'-P<FEN=&8H7R@B075T:&5N=&EC871I;VX@9F%I;&5D
M+B`E<R(I+"`D<F5S<&]N<V4M/F=E=$UE<W-A9V4H*2DI.PH@("`@("`@('T*
M"B`@("`@("`@+RH@4W!L:70@=7`@=&AE(')E<W!O;G-E+B`J+PH@("`@("`@
M("1R97-P;VYS92`](&5X<&QO9&4H)SHG+"`D<F5S<&]N<V4I.PH@("`@("`@
M(&EF("@D<F5S<&]N<V5;,%T@/3T@)T]+)RD@>PH@("`@("`@("`@("`D=&AI
M<RT^7W-E<W-I;VY?:60@/2!T<FEM*"1R97-P;VYS95LQ72D["B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^9V5T17)R;W(H)')E<W!O;G-E6S%=+"!?*")!=71H
M96YT:6-A=&EO;B!F86EL960N("5S(BDI.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%1H:7,@9G5N8W1I;VX@9&]E<R!T:&4@86-T=6%L('-E
M;F1I;F<@;V8@=&AE(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1M97-S86=E("!4
M:&4@87)R87D@8V]N=&%I;FEN9R!T:&4@;65S<V%G92!A;F0@:71S('-E;F0*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R<RX*("`@
M("`J($!P87)A;2!S=')I;F<@)'1O("`@("`@5&AE(&1E<W1I;F%T:6]N('-T
M<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!W
M:71H('1H92!S=6-C97-S('-T871U<R!A;F0@861D:71I;VYA;`H@("`@("H@
M("`@("`@("`@("`@("`@:6YF;W)M871I;VXN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]S96YD*"8D;65S<V%G92P@)'1O*0H@("`@>PH@("`@("`@("\J(%-E
M="!U<"!T:&4@:'1T<"!S96YD:6YG('5R;"X@*B\*("`@("`@("`D=7)L(#T@
M<W!R:6YT9B@G<V5N9&US9S]S97-S:6]N7VED/25S)G1E>'0])7,G+`H@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5S<VEO;E]I9"P*("`@("`@
M("`@("`@("`@("`@("`@("!U<FQE;F-O9&4H)&UE<W-A9V5;)W1E>'0G72DI
M.PH*("`@("`@("`D<F5Q7V9E870@/2`P.PH@("`@("`@(&EF("@A96UP='DH
M)&UE<W-A9V5;)W-E;F1?<&%R86US)UU;)V9R;VTG72DI('L*("`@("`@("`@
M("`@+RH@268@<V]U<F-E(&9R;VT@:7,@<V5T+"!R97%U:7)E(&ET(&9O<B!T
M<F%N<VET(&=A=&5W87ES(&%N9"!A<'!E;F0*("`@("`@("`@("`@("`@=&\@
M=7)L+B`J+PH@("`@("`@("`@("`D<F5Q7V9E870@/2L@,38["B`@("`@("`@
M("`@("1U<FP@+CT@)R9F<F]M/2<@+B!U<FQE;F-O9&4H)&UE<W-A9V5;)W-E
M;F1?<&%R86US)UU;)V9R;VTG72D["B`@("`@("`@?0H@("`@("`@(&EF("@A
M96UP='DH)&UE<W-A9V5;)W-E;F1?<&%R86US)UU;)VUS9U]T>7!E)UTI("8F
M"B`@("`@("`@("`@("1M97-S86=E6R=S96YD7W!A<F%M<R==6R=M<V=?='EP
M92==(#T]("=335-?1DQ!4T@G*2!["B`@("`@("`@("`@("\J($EF(&UE<W-A
M9V4@='EP92!I<R!F;&%S:"P@<F5Q=6ER92!I="!F;W(@=')A;G-I="!G871E
M=V%Y<RX@*B\*("`@("`@("`@("`@)')E<5]F96%T(#TK(#4Q,CL*("`@("`@
M("`@("`@)'5R;"`N/2`G)FUS9U]T>7!E/2<@+B`D;65S<V%G95LG<V5N9%]P
M87)A;7,G75LG;7-G7W1Y<&4G73L*("`@("`@("!]"B`@("`@("`@:68@*"%E
M;7!T>2@D<F5Q7V9E870I*2!["B`@("`@("`@("`@("\J($EF(&9E871U<F5S
M(&AA=F4@8F5E;B!R97%U:7)E9"P@861D('1O('5R;"X@*B\*("`@("`@("`@
M("`@)'5R;"`N/2`G)G)E<5]F96%T/2<@+B`D<F5Q7V9E870["B`@("`@("`@
M?0H*("`@("`@("`O*B!!<'!E;F0@=&AE(')E8VEP:65N=',@;V8@=&AI<R!M
M97-S86=E(&%N9"!C86QL('1H92!U<FPN("HO"B`@("`@("`@9F]R96%C:"`H
M)'1O(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("!I9B`H<')E9U]M
M871C:"@G+UXN*C\\/UPK/RA<9'LW+'TI*#Y\)"DO)RP@)'9A;"P@)&UA=&-H
M97,I*2!["B`@("`@("`@("`@("`@("`D=&];)&ME>5T@/2`D;6%T8VAE<ULQ
M73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\J($9)
M6$U%.B!3:6QE;G1L>2!D<F]P(&)A9"!R96-I<&EE;G1S+B!4:&ES('-H;W5L
M9"!B92!L;V=G960*("`@("`@("`@("`@("`@("`J(&%N9"]O<B!R97!O<G1E
M9"X@*B\*("`@("`@("`@("`@("`@('5N<V5T*"1T;ULD:V5Y72D["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("`@("`@)'1O(#T@:6UP;&]D92@G+"<L
M("1T;RD["B`@("`@("`@)'5R;"`N/2`G)G1O/2<@+B`D=&\["B`@("`@("`@
M)')E<W!O;G-E(#T@=')I;2@D=&AI<RT^7V-A;&Q54DPH)'5R;"DI.PH*("`@
M("`@("`O*B!59VQY('!A<G-I;F<@;V8@=&AE(')E<W!O;G-E+"!B=70@=&AA
M="=S(&AO=R!I="!C;VUE<R!B86-K+B`J+PH@("`@("`@("1L:6YE<R`](&5X
M<&QO9&4H(EQN(BP@)')E<W!O;G-E*3L*("`@("`@("`D<F5S<&]N<V4@/2!A
M<G)A>2@I.PH*("`@("`@("!I9B`H8V]U;G0H)&QI;F5S*2`^(#$I('L*("`@
M("`@("`@("`@9F]R96%C:"`H)&QI;F5S(&%S("1L:6YE*2!["B`@("`@("`@
M("`@("`@("`D<&%R=',@/2!E>'!L;V1E*"=4;SHG+"`D;&EN92D["B`@("`@
M("`@("`@("`@("`D<F5C:7!I96YT(#T@=')I;2@D<&%R='-;,5TI.PH@("`@
M("`@("`@("`@("`@)&]U=&-O;64@/2!E>'!L;V1E*"<Z)RP@)'!A<G1S6S!=
M*3L*("`@("`@("`@("`@("`@("1R97-P;VYS95LD<F5C:7!I96YT72`](&%R
M<F%Y*"@D;W5T8V]M95LP72`]/2`G240G(#\@,2`Z(#`I+"`D;W5T8V]M95LQ
M72D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`O*B!3:6YG;&4@<F5C:7!I96YT+B`J+PH@("`@("`@("`@("`D;W5T8V]M
M92`](&5X<&QO9&4H)SHG+"`D;&EN97-;,%TI.PH@("`@("`@("`@("`D<F5S
M<&]N<V5;)'1O72`](&%R<F%Y*"@D;W5T8V]M95LP72`]/2`G240G(#\@,2`Z
M(#`I+"`D;W5T8V]M95LQ72D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)')E<W!O;G-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M8W5R<F5N="!C<F5D:70@8F%L86YC92!O;B!T:&4@9V%T97=A>2X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN=&5G97(@(%1H92!C<F5D:70@8F%L86YC92!A=F%I;&%B;&4@;VX@=&AE
M(&=A=&5W87DN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971"86QA;F-E*"D*
M("`@('L*("`@("`@("`O*B!3970@=7`@=&AE('5R;"!A;F0@8V%L;"!I="X@
M*B\*("`@("`@("`D=7)L(#T@<W!R:6YT9B@G9V5T8F%L86YC93]S97-S:6]N
M7VED/25S)RP*("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-E<W-I
M;VY?:60I.PH@("`@("`@("1R97-P;VYS92`]('1R:6TH)'1H:7,M/E]C86QL
M55),*"1U<FPI*3L*"B`@("`@("`@+RH@5')Y('-P;&ET=&EN9R!U<"!T:&4@
M<F5S<&]N<V4N("HO"B`@("`@("`@)&QI;F5S(#T@97AP;&]D92@G/2<L("1R
M97-P;VYS92D["@H@("`@("`@("\J(%-P;&ET('5P('1H92!R97-P;VYS92X@
M*B\*("`@("`@("`D<F5S<&]N<V4@/2!E>'!L;V1E*"<Z)RP@)')E<W!O;G-E
M*3L*("`@("`@("!I9B`H)')E<W!O;G-E6S!=(#T]("=#<F5D:70G*2!["B`@
M("`@("`@("`@(')E='5R;B!T<FEM*"1R97-P;VYS95LQ72D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG971%<G)O<B@D
M<F5S<&]N<V5;,5TL(%\H(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(I
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!)9&5N=&EF:65S
M('1H:7,@9V%T97=A>2!D<FEV97(@86YD(')E='5R;G,@82!B<FEE9B!D97-C
M<FEP=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!O
M9B!D<FEV97(@:6YF;RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T26YF;R@I
M"B`@("!["B`@("`@("`@)&EN9F];)VYA;64G72`](%\H(D-L:6-K871E;&P@
M=FEA($A45%`B*3L*("`@("`@("`D:6YF;ULG9&5S8R==(#T@7R@B5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@
M0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$DB*3L*"B`@("`@("`@<F5T=7)N("1I;F9O.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<F5Q=6ER960@<&%R
M86UE=&5R<R!F;W(@=&AI<R!G871E=V%Y(&1R:79E<BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!O9B!R97%U:7)E9"!P87)A;65T97)S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971087)A;7,H*0H@("`@>PH@("`@
M("`@("1P87)A;7,@/2!A<G)A>2@I.PH@("`@("`@("1P87)A;7-;)W5S97(G
M72`@("`@/2!A<G)A>2@G;&%B96PG(#T^(%\H(E5S97)N86UE(BDL("=T>7!E
M)R`]/B`G=&5X="<I.PH@("`@("`@("1P87)A;7-;)W!A<W-W;W)D)UT@/2!A
M<G)A>2@G;&%B96PG(#T^(%\H(E!A<W-W;W)D(BDL("=T>7!E)R`]/B`G=&5X
M="<I.PH@("`@("`@("1P87)A;7-;)V%P:5]I9"==("`@/2!A<G)A>2@G;&%B
M96PG(#T^(%\H(D%022!)1"(I+"`G='EP92<@/3X@)W1E>'0G*3L*"B`@("`@
M("`@<F5T=7)N("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!P87)A;65T97)S('1H870@8V%N(&)E('-E="!A<R!D969A=6QT
M(&9O<B!S96YD:6YG(&UE<W-A9V5S"B`@("`@*B!U<VEN9R!T:&ES(&=A=&5W
M87D@9')I=F5R(&%N9"!D:7-P;&%Y960@=VAE;B!S96YD:6YG(&UE<W-A9V5S
M+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%R<F%Y(&]F('!A<F%M
M971E<G,@=&AA="!C86X@8F4@<V5T(&%S(&1E9F%U;'0N"B`@("`@*B!`=&]D
M;R`@4V5T('5P(&)A=&-H(&9I96QD<R]P87)A;7,L('=O=6QD(&)E(&YI8V4@
M=&\@:&%V92!R:6YG=&]N92]L;V=O"B`@("`@*B`@("`@("`@<W5P<&]R="!T
M;V\L('%U975E(&-H;VEC92P@=6YI8V]D92!C:&]I8V4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$1E9F%U;'1396YD4&%R86US*"D*("`@('L*("`@("`@
M("`D<&%R86US(#T@87)R87DH*3L*("`@("`@("`D<&%R86US6R=F<F]M)UT@
M/2!A<G)A>2@*("`@("`@("`@("`@)VQA8F5L)R`]/B!?*")3;W5R8V4@861D
M<F5S<R(I+`H@("`@("`@("`@("`G='EP92<@/3X@)W1E>'0G*3L*"B`@("`@
M("`@)'!A<F%M<ULG9&5L:79?=&EM92==(#T@87)R87DH"B`@("`@("`@("`@
M("=L86)E;"<@/3X@7R@B1&5L:79E<GD@=&EM92(I+`H@("`@("`@("`@("`G
M='EP92<@/3X@)V5N=6TG+`H@("`@("`@("`@("`G<&%R86US)R`]/B!A<G)A
M>2AA<G)A>2@G;F]W)R`]/B!?*")I;6UE9&EA=&4B*2P@)W5S97(G(#T^(%\H
M(G5S97(@<V5L96-T(BDI*2D["@H@("`@("`@("1T>7!E<R`](&%R<F%Y*"=3
M35-?5$585"<@/3X@)U--4U]415A4)RP@)U--4U]&3$%32"<@/3X@)U--4U]&
M3$%32"<I.PH@("`@("`@("1P87)A;7-;)VUS9U]T>7!E)UT@/2!A<G)A>2@*
M("`@("`@("`@("`@)VQA8F5L)R`]/B!?*")-97-S86=E('1Y<&4B*2P*("`@
M("`@("`@("`@)W1Y<&4G(#T^("=M=6QT:65N=6TG+`H@("`@("`@("`@("`G
M<&%R86US)R`]/B!A<G)A>2@D='EP97,I*3L*"B`@("`@("`@<F5T=7)N("1P
M87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!P87)A
M;65T97)S(&9O<B!S96YD:6YG(&UE<W-A9V5S('5S:6YG('1H:7,@9V%T97=A
M>2!D<FEV97(L"B`@("`@*B!D:7-P;&%Y960@=VAE;B!S96YD:6YG(&UE<W-A
M9V5S+B!4:&5S92!A<F4@9FEL=&5R960@;W5T('5S:6YG('1H90H@("`@("H@
M9&5F875L="!V86QU97,@<V5T(&9O<B!T:&4@9V%T97=A>2X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!O9B!R97%U:7)E9"!P87)A;65T
M97)S+@H@("`@("H@0'1O9&\@(%=O=6QD(&)E(&YI8V4@=&\@=7-E(&$@=&EM
M92]D871E('-E='5P(')A=&AE<B!T:&%N(&UI;G5T97,@9G)O;0H@("`@("H@
M("`@("`@(&YO=R!F;W(@=&AE(&1E;&EV97)Y('1I;64N(%5P;&]A9"!F:65L
M9"!F;W(@<FEN9W1O;F5S+VQO9V]S/PH@("`@("HO"B`@("!F=6YC=&EO;B!G
M971396YD4&%R86US*"1P87)A;7,I"B`@("!["B`@("`@("`@:68@*&5M<'1Y
M*"1P87)A;7-;)V9R;VTG72DI('L*("`@("`@("`@("`@)'!A<F%M<ULG9G)O
M;2==(#T@87)R87DH"B`@("`@("`@("`@("`@("`G;&%B96PG(#T^(%\H(E-O
M=7)C92!A9&1R97-S(BDL"B`@("`@("`@("`@("`@("`G='EP92<@/3X@)W1E
M>'0G*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D<&%R86US6R=D96QI=E]T
M:6UE)UT@/3T@)W5S97(G*2!["B`@("`@("`@("`@("1P87)A;7-;)V1E;&EV
M7W1I;64G72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)VQA8F5L)R`]/B!?
M*")$96QI=F5R>2!T:6UE(BDL"B`@("`@("`@("`@("`@("`G='EP92<@/3X@
M)VEN="<L"B`@("`@("`@("`@("`@("`G9&5S8R<@/3X@7R@B5F%L=64@:6X@
M;6EN=71E<R!F<F]M(&YO=RXB*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M8V]U;G0H)'!A<F%M<ULG;7-G7W1Y<&4G72D@/B`Q*2!["B`@("`@("`@("`@
M("1P87)A;7-;)VUS9U]T>7!E)UT@/2!A<G)A>2@*("`@("`@("`@("`@("`@
M("=L86)E;"<@/3X@7R@B365S<V%G92!T>7!E(BDL"B`@("`@("`@("`@("`@
M("`G='EP92<@/3X@)V5N=6TG+`H@("`@("`@("`@("`@("`@)W!A<F%M<R<@
M/3X@87)R87DH)'!A<F%M<ULG;7-G7W1Y<&4G72DI.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1P87)A;7-;)VUS9U]T>7!E)UT@/2`D<&%R86US
M6R=M<V=?='EP92==6S!=.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P
M87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<W1R:6YG
M(')E<')E<V5N=&%T:6]N(&]F(&%N(&5R<F]R(&-O9&4N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&5R<F]R("!4:&4@97)R;W(@8V]D92!T;R!L
M;V]K('5P+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@("!!;B!E>&ES
M=&EN9R!E<G)O<B!T97AT('1O('5S92!T;R!R86ES92!A"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@(%!%05(@17)R;W(N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@02!T97AT=6%L(&UE<W-A9V4@8V]R<F5S<&]N9&EN
M9R!T;R!T:&4@97)R;W(@8V]D92!O<B!A"B`@("`@*B`@("`@("`@("`@("`@
M("!014%2($5R<F]R(&EF('!A<W-E9"!A;B!E>&ES=&EN9R!E<G)O<B!T97AT
M+@H@("`@("H*("`@("`J($!T;V1O("!#:&5C:R!W:&EC:"!O9B!T:&5S92!A
M<F4@86-T=6%L;'D@<F5Q=6ER960@86YD('1R:6T@9&]W;B!T:&4*("`@("`J
M("`@("`@("!L:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971%<G)O<B@D
M97)R;W(L("1E<G)O<E]T97AT(#T@)R<I"B`@("!["B`@("`@("`@+RH@36%K
M92!S=7)E('=E(&=E="!O;FQY('1H92!N=6UB97(@870@=&AE('-T87)T(&]F
M(&%N(&5R<F]R+B`J+PH@("`@("`@(&QI<W0H)&5R<F]R*2`](&5X<&QO9&4H
M)RPG+"`D97)R;W(I.PH@("`@("`@("1E<G)O<B`]('1R:6TH)&5R<F]R*3L*
M"B`@("`@("`@+RH@06X@87)R87D@;V8@97)R;W(@8V]D97,@<F5T=7)N960@
M8GD@=&AE(&=A=&5W87DN("HO"B`@("`@("`@)&5R<F]R<R`](&%R<F%Y*"<P
M,#$G(#T^(%\H(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`G,#`R)R`]/B!?*")5;FMN;W=N('5S97)N86UE(&]R
M('!A<W-W;W)D+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`G,#`S)R`]
M/B!?*")397-S:6]N($E$(&5X<&ER960N(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("<P,#0G(#T^(%\H(D%C8V]U;G0@9G)O>F5N+B(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G,#`U)R`]/B!?*")-:7-S:6YG('-E<W-I;VX@
M240N(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("<P,#<G(#T^(%\H(DE0
M(&QO8VMD;W=N('9I;VQA=&EO;BXB*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@)S$P,2<@/3X@7R@B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N
M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("<Q,#(G(#T^(%\H(DEN=F%L
M:60@541(+B`H57-E<B!$871A($AE861E<BDN(BDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("<Q,#,G(#T^(%\H(E5N:VYO=VX@87!I;7-G:60@*$%022!-
M97-S86=E($E$*2XB*2P*("`@("`@("`@("`@("`@("`@("`@("`@)S$P-"<@
M/3X@7R@B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`G,3`U)R`]/B!?*"));G9A;&ED
M(&1E<W1I;F%T:6]N(&%D9')E<W,N(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("<Q,#8G(#T^(%\H(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("<Q,#<G(#T^(%\H(D5M<'1Y(&UE<W-A
M9V4N(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("<Q,#@G(#T^(%\H(DEN
M=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("<Q,#DG(#T^(%\H(DUI<W-I;F<@;65S<V%G92!)1"XB*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@)S$Q,"<@/3X@7R@B17)R;W(@=VET:"!E
M;6%I;"!M97-S86=E+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`G,3$Q
M)R`]/B!?*"));G9A;&ED('!R;W1O8V]L+B(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`G,3$R)R`]/B!?*"));G9A;&ED(&US9U]T>7!E+B(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`G,3$S)R`]/B!?*")-87@@;65S<V%G92!P
M87)T<R!E>&-E961E9"XB*2P*("`@("`@("`@("`@("`@("`@("`@("`@)S$Q
M-"<@/3X@7R@B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU
M;6)E<BXB*2P*("`@("`@("`@("`@("`@("`@("`@("`@)S$Q-2<@/3X@7R@B
M365S<V%G92!E>'!I<F5D+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`G
M,3$V)R`]/B!?*"));G9A;&ED('5N:6-O9&4@9&%T82XB*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@)S(P,2<@/3X@7R@B26YV86QI9"!B871C:"!)1"XB
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@)S(P,B<@/3X@7R@B3F\@8F%T
M8V@@=&5M<&QA=&4N(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("<S,#$G
M(#T^(%\H(DYO(&-R961I="!L969T+B(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`G,S`R)R`]/B!?*")-87@@86QL;W=E9"!C<F5D:70N(BDI.PH*("`@
M("`@("!I9B`H96UP='DH)&5R<F]R7W1E>'0I*2!["B`@("`@("`@("`@(')E
M='5R;B`D97)R;W)S6R1E<G)O<ET["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9B@D97)R;W)?
M=&5X="P@)&5R<F]R<ULD97)R;W)=*2D["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@1&\@=&AE(&AT='`@8V%L;"!U<VEN9R!A('5R;"!P87-S
M960@=&\@=&AE(&9U;F-T:6]N+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5R;"`@5&AE('5R
M;"!T;R!C86QL+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!R
M97-P;VYS92!O;B!S=6-C97-S(&]R(%!%05(@17)R;W(@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V-A;&Q54DPH)'5R;"D*("`@('L*("`@
M("`@("`D;W!T:6]N<ULG;65T:&]D)UT@/2`G1T54)SL*("`@("`@("`D;W!T
M:6]N<ULG=&EM96]U="==(#T@-3L*("`@("`@("`D;W!T:6]N<ULG86QL;W=2
M961I<F5C=',G72`]('1R=64["@H@("`@("`@(&EF("@A0&EN8VQU9&5?;VYC
M92`G2%144"]297%U97-T+G!H<"<I('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]2
M97%U97-T+B(I*3L*("`@("`@("!]"B`@("`@("`@)&AT='`@/2`F;F5W($A4
M5%!?4F5Q=65S="@D=&AI<RT^7V)A<V5?=7)L("X@)'5R;"P@)&]P=&EO;G,I
M.PH@("`@("`@($`D:'1T<"T^<V5N9%)E<75E<W0H*3L*("`@("`@("!I9B`H
M)&AT='`M/F=E=%)E<W!O;G-E0V]D92@I("$](#(P,"D@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-O=6QD(&YO
M="!O<&5N("5S+B(I+"`D=7)L*2D["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&AT='`M/F=E=%)E<W!O;G-E0F]D>2@I.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TYE
M="]335,O9V5N97)I8U]S;71P+G!H<```````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`Q,C8T,@`Q,#4Q-30S,S<U,@`P,C,P,3``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J($=E
M;F5R:6,@92UM86EL(&)A<V5D(%--4R!D<FEV97(*("H*("H@0V]P>7)I9VAT
M(#(P,#4M,C`P-B!796)3<')O8VME=',L($Q,0PH@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@5&AI<R!D<FEV97(@:6YT97)F86-E<R!W:71H('1H92!E;6%I;"UT;RUS
M;7,@9V%T97=A>7,@<')O=FED960@8GD@;6%N>0H@*B!C87)R:65R<RP@<&%R
M=&EC=6QA<FQY('1H;W-E(&)A<V5D(&EN('1H92!5+E,N"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`L=B`Q
M+C@N,BXT(#(P,#8O,#<O,3,@,#@Z-3<Z-#4@:F%N($5X<"`D"B`J"B`J($!C
M871E9V]R>2`@($YE='=O<FMI;F<*("H@0'!A8VMA9V4@("`@3F5T7U--4PH@
M*B!`875T:&]R("`@("!)86X@175R92`\:65U<F5`<&AP+FYE=#X*("H@0'-I
M;F-E("`@("`@2&]R9&4@,RXQ"B`J($!S:6YC92`@("`@($YE=%]335,@,"XP
M+C(*("HO"F-L87-S($YE=%]335-?9V5N97)I8U]S;71P(&5X=&5N9',@3F5T
M7U--4R!["@H@("`@+RHJ"B`@("`@*B!#87!A8FEL:71I97,@;V8@=&AI<R!D
M<FEV97(N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)&-A<&%B:6QI=&EE<R`](&%R<F%Y*`H@("`@("`@("=A=71H)R`@("`@
M("`@/3X@9F%L<V4L"B`@("`@("`@)V)A=&-H)R`@("`@("`]/B!F86QS92P*
M("`@("`@("`G;75L=&DG("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=R96-E
M:79E)R`@("`@/3X@9F%L<V4L"B`@("`@("`@)V-R961I="<@("`@("`]/B!F
M86QS92P*("`@("`@("`G861D<F5S<V)O;VLG(#T^(&9A;'-E+`H@("`@("`@
M("=L:7-T<R<@("`@("`@/3X@9F%L<V4*("`@("D["@H@("`@+RHJ"B`@("`@
M*B!$<FEV97(@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A
M<B`D7W!A<F%M<R`](&%R<F%Y*`H@("`@("`@("=C87)R:65R)R`@("`@/3X@
M;G5L;"P*("`@("`@("`G;6%I;$)A8VME;F0G(#T^("=M86EL)RP*("`@("`@
M("`G;6%I;%!A<F%M<R<@(#T^(&%R<F%Y*"DL"B`@("`@("`@)VUA:6Q(96%D
M97)S)R`]/B!A<G)A>2@I"B`@("`I.PH*("`@("\J*@H@("`@("H@0V%R<FEE
M<B!E;6%I;"!M87`N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]C87)R
M:65R<R`](&%R<F%Y*`H@("`@("`@("\J(%4N4RX@8V%R<FEE<G,N("HO"B`@
M("`@("`@)V%T="<@("`@("`@("`@/3X@)R5S0&UM;V1E+F-O;2<L"B`@("`@
M("`@)V-I;F=U;&%R)R`@("`@/3X@)R5S0&UM;V1E+F-O;2<L"B`@("`@("`@
M)W9E<FEZ;VXG("`@("`@/3X@)R5S0'9T97AT+F-O;2<L"B`@("`@("`@)V)O
M;W-T)R`@("`@("`@/3X@)R5S0&UY8F]O<W1M;V)I;&4N8V]M)RP*("`@("`@
M("`G8V5L;'5L87)O;F4G("`]/B`G)7-`;7EC96QL;VYE+FYE="<L"B`@("`@
M("`@)V-I;F-Y8F5L;"<@("`@/3X@)R5S0&=O8V)W+F-O;2<L"B`@("`@("`@
M)W-P<FEN="<@("`@("`@/3X@)R5S0&UE<W-A9VEN9RYS<')I;G1P8W,N8V]M
M)RP*("`@("`@("`G=&UO8FEL95]U<R<@("`]/B`G)7-`=&UO;6%I;"YC;VTG
M+`H@("`@("`@("=S=6YC;VTG("`@("`@(#T^("<E<T!T;7,N<W5N8V]M+F-O
M;2<L"B`@("`@("`@)V%I<F-E;"<@("`@("`@/3X@)R5S0&%I<G-M<RYC;VTG
M+`H@("`@("`@("=A:7)T96PG("`@("`@(#T^("<E<T!A:7)T96QM86EL+F-O
M;2<L"B`@("`@("`@)V)P;&UO8FEL92<@("`@/3X@)R5S0&)P;&UO8FEL92YC
M;VTG+`H@("`@("`@("=B96QL;6]B:6QI='DG(#T^("<E<T!T>'0N8F5L;&UO
M8FEL:71Y+F-A)RP*("`@("`@("`G8FQU96=R87-S)R`@("`]/B`G)7-`<VUS
M+F)L=65C96QL+F-O;2<L"B`@("`@("`@)V-E;&QF;W)C92<@("`@/3X@)R5S
M0&-E;&9O<F-E+F-O;2<L"B`@("`@("`@)V-E;&QU;&%R;VYE)R`@/3X@)R5S
M0&UY8V5L;&]N92YN970G+`H@("`@("`@("\J($=E<FUA;B!C87)R:65R<RX@
M*B\*("`@("`@("`G97!L=7,G("`@("`@(#T^("<E<T!S;7-M86EL+F5P;'5S
M+F1E)RP*("`@("`@("`G=&UO8FEL95]D92<@(#T^("<E<T!T+6UO8FEL92US
M;7,N9&4G+`H@("`@("`@("=V;V1A9F]N95]D92<@/3X@)R5S0'9O9&%F;VYE
M+7-M<RYD92<L"B`@("`I.PH*("`@("\J*@H@("`@("H@261E;G1I9FEE<R!T
M:&ES(&1R:79E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!$<FEV
M97(@:6YF;RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T26YF;R@I"B`@("![
M"B`@("`@("`@<F5T=7)N(&%R<F%Y*`H@("`@("`@("`@("`G;F%M92<@/3X@
M7R@B16UA:6PM=&\M4TU3($=A=&5W87DB*2P*("`@("`@("`@("`@)V1E<V,G
M(#T^(%\H(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I
M97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(I"B`@("`@("`@*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@<F5Q=6ER960@<&%R86UE
M=&5R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!O9B!R
M97%U:7)E9"!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9710
M87)A;7,H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@*("`@("`@("`@
M("`@)V-A<G)I97(G("`@("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(D-A<G)I
M97(B*2P@)W1Y<&4G(#T^("=T97AT)RDL"B`@("`@("`@("`@("=M86EL0F%C
M:V5N9"<@/3X@87)R87DH)VQA8F5L)R`]/B!?*")014%2.CI-86EL(&)A8VME
M;F0B*2P@)W1Y<&4G(#T^("=T97AT)RD*("`@("`@("`I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5N9',@=&AE(&UE<W-A9V4N"B`@("`@*@H@("`@("H@
M66]U(&UA>2!A;'-O('-P96-I9GD@=&AE(&-A<G)I97(@=VET:"!T:&4@)V-A
M<G)I97(G(&ME>2!O9B!T:&4@;65S<V%G90H@("`@("H@=&\@879O:60@8W)E
M871I;F<@82!N97<@:6YS=&%N8V4@9F]R(&5A8V@@8V%R<FEE<BP@;W(@9FED
M9&QI;F<@=VET:"!T:&4*("`@("`J('!A<F%M971E<G,N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1M97-S86=E("!-97-S86=E('1O('-E;F0N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T;R`@("`@($1E<W1I;F%T:6]N('!H;VYE(&YU;6)E<BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!W:71H('1H92!S=6-C
M97-S('-T871U<R!A;F0@861D:71I;VYA;`H@("`@("H@("`@("`@("`@("`@
M("`@:6YF;W)M871I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S96YD*"8D
M;65S<V%G92P@)'1O*0H@("`@>PH@("`@("`@("1R97-P;VYS92`](&%R<F%Y
M*"D["B`@("`@("`@)&1E<W1E;6%I;"`]("1T:&ES+3Y?9V5T1&5S="@D=&\I
M.PH@("`@("`@(')E<75I<F5?;VYC92`G36%I;"YP:'`G.PH@("`@("`@("1M
M(#T@36%I;#HZ9F%C=&]R>2@D=&AI<RT^7W!A<F%M<ULG;6%I;$)A8VME;F0G
M72P@)'1H:7,M/E]P87)A;7-;)VUA:6Q087)A;7,G72D["@H@("`@("`@(&EF
M("AI<W-E="@D;65S<V%G95LG8V%R<FEE<B==*2D@>PH@("`@("`@("`@("`D
M9&5S="`]("1T:&ES+3Y?9V5T1&5S="@D=&\L("1M97-S86=E6R=C87)R:65R
M)UTI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1D97-T(#T@)'1H
M:7,M/E]G971$97-T*"1T;RD["B`@("`@("`@?0H*("`@("`@("`D<F5S(#TF
M("1M+3YS96YD*"1D97-T+"`D=&AI<RT^7W!A<F%M<ULG;6%I;$AE861E<G,G
M72P@)&UE<W-A9V5;)W1E>'0G72D["B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)')E<RDI('L*("`@("`@("`@("`@)')E<W!O;G-E6R1T;UT@/2!A<G)A
M>2@P+"`D<F5S+3YG971-97-S86=E*"DI.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1R97-P;VYS95LD=&]=(#T@87)R87DH,2P@;G5L;"D["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W!O;G-E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!D97-T:6YA=&EO;B!E+6UA:6P@861D<F5S
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P:&]N92`@4&AO;F4@
M;G5M8F5R('1O('-E;F0@=&\N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@($1E<W1I;F%T:6]N(&%D9')E<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]G971$97-T*"1P:&]N92P@)&-A<G)I97(@/2!N=6QL*0H@("`@>PH@("`@
M("`@("1C87)R:65R(#T@:7-?;G5L;"@D8V%R<FEE<BD@/R`D=&AI<RT^7W!A
M<F%M<ULG8V%R<FEE<B==(#H@)&-A<G)I97(["B`@("`@("`@<F5T=7)N('-P
M<FEN=&8H)'1H:7,M/E]C87)R:65R<ULD8V%R<FEE<ETL"B`@("`@("`@("`@
M("`@("`@("`@("`@<')E9U]R97!L86-E*"<O6UXP+3E=+R<L("<G+"`D<&AO
M;F4I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&%D9')E
M<W,@=&5M<&QA=&4@9F]R(&$@8V%R<FEE<BX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1C87)R:65R("!#87)R:65R(&YA;64N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@061D<F5S<R!T96UP;&%T92!O<B!F86QS92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T061D<F5S<U1E;7!L871E*"1C87)R
M:65R*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]C87)R:65R
M<ULD8V%R<FEE<ETI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V%R<FEE<G-;)&-A<G)I
M97)=.PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A(&-A<G)I97(@=&\@
M=&AE(&QI<W0N"B`@("`@*@H@("`@("H@061D<F5S<R!T96UP;&%T97,@;F5E
M9"!T;R!B92!I;B!T:&4@9F]R;2!O9B!A;B!E;6%I;"!A9&1R97-S+"!W:71H
M(&$*("`@("`J("<E<R<@<F5P<F5S96YT:6YG('1H92!P;&%C92!W:&5R92!T
M:&4@9&5S=&EN871I;VX@<&AO;F4@;G5M8F5R(&=O97,N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;F%M92`@0V%R<FEE<B!N86UE+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D861D<B`@061D<F5S<R!T96UP;&%T92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@861D0V%R<FEE<B@D;F%M92P@)&%D9'(I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]C87)R:65R<ULD;F%M95T@/2`D861D<CL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!L:7-T(&]F('!A<F%M971E
M<G,@<W!E8VEF:6,@9F]R('1H:7,@9')I=F5R+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@1&5F875L="!S96YD:6YG('!A<F%M971E<G,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$1E9F%U;'1396YD4&%R86US*"D*("`@('L*
M("`@("`@("!R971U<FX@87)R87DH*3L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`V,C4S,0`Q,#4Q-30S
M,S<U,@`P,C,R-C8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J($YE=%]335-?<VUS,F5M86EL7VAT='`@
M0VQA<W,@:6UP;&5M96YT<R!T:&4@2%144"!!4$D@9F]R(&%C8V5S<VEN9R!T
M:&4*("H@<VUS,F5M86EL("AW=W<N<VUS,F5M86EL+F-O;2D@4TU3(&=A=&5W
M87DN"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36%R:V\@1&IU:VEC(#QM
M87)K;T!O8FQO+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@
M9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<"QV(#$N,C,N
M,3`N,3`@,C`P-B\P,2\P,2`R,3HR.#HR.2!J86X@17AP("0*("H*("H@0&%U
M=&AO<B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`<&%C:V%G
M92!.971?4TU3"B`J+PIC;&%S<R!.971?4TU37W-M<S)E;6%I;%]H='1P(&5X
M=&5N9',@3F5T7U--4R!["@H@("`@=F%R("1?8F%S95]U<FP@/2`G:&]R9&4N
M<VUS,F5M86EL+F-O;2]H;W)D92\G.PH*("`@("\J*@H@("`@("H@06X@87)R
M87D@;V8@8V%P86)I;&ET:65S+"!S;R!T:&%T('1H92!D<FEV97(@8V%N(')E
M<&]R="!W:&EC:`H@("`@("H@;W!E<F%T:6]N<R!I="!S=7!P;W)T<R!A;F0@
M=VAI8V@@:70@9&]E<VXG="X@4&]S<VEB;&4@=F%L=65S(&%R93H\<')E/@H@
M("`@("H@("!A=71H("`@("`@("`M(%1H92!G871E=V%Y(')E<75I<F5S(&%U
M=&AE;G1I8V%T:6]N(&)E9F]R92!S96YD:6YG.PH@("`@("H@("!B871C:"`@
M("`@("`M($)A=&-H('-E;F1I;F<@:7,@<W5P<&]R=&5D.PH@("`@("H@("!M
M=6QT:2`@("`@("`M(%-E;F1I;F<@;V8@;65S<V%G97,@=&\@;75L=&EP;&4@
M<F5C:7!I96YT<R!I<R!S=7!P;W)T960["B`@("`@*B`@(')E8V5I=F4@("`@
M("T@5VAE=&AE<B!T:&ES(&1R:79E<B!I<R!C87!A8FQE(&]F(')E8V5I=FEN
M9R!335,["B`@("`@*B`@(&-R961I="`@("`@("T@27,@=7-E(&]F('1H92!G
M871E=V%Y(&)A<V5D(&]N(&-R961I=',["B`@("`@*B`@(&%D9')E<W-B;V]K
M("T@07)E(&=A=&5W87D@861D<F5S<V)O;VMS('-U<'!O<G1E9#L*("`@("`J
M("`@;&ES=',@("`@("`@+2!'871E=V%Y('-U<'!O<G0@9F]R(&1I<W1R:6)U
M=&EO;B!L:7-T<RX*("`@("`J(#PO<')E/@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1C87!A8FEL:71I97,@/2!A<G)A>2@G
M875T:"<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G8F%T8V@G("`@("`@(#T^(#$P,"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VUU;'1I)R`@("`@("`]/B!T<G5E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<F5C96EV92<@("`@(#T^(&9A;'-E
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8W)E9&ET)R`@("`@
M(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A9&1R
M97-S8F]O:R<@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VQI<W1S)R`@("`@("`]/B!T<G5E*3L*"B`@("`O*BH*("`@("`J(%1H
M:7,@9G5N8W1I;VX@9&]E<R!T:&4@86-T=6%L('-E;F1I;F<@;V8@=&AE(&UE
M<W-A9V4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1M97-S86=E("!4:&4@87)R87D@8V]N=&%I
M;FEN9R!T:&4@;65S<V%G92!A;F0@:71S('-E;F0*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@<&%R86UE=&5R<RX*("`@("`J($!P87)A;2!S=')I
M;F<@)'1O("`@("`@5&AE(&1E<W1I;F%T:6]N('-T<FEN9RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!W:71H('1H92!S=6-C97-S
M('-T871U<R!A;F0@861D:71I;VYA;`H@("`@("H@("`@("`@("`@("`@("`@
M:6YF;W)M871I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S96YD*"8D;65S
M<V%G92P@)'1O*0H@("`@>PH@("`@("`@("\J(%-E="!U<"!T:&4@<V5N9&EN
M9R!U<FPN("HO"B`@("`@("`@)'5R;"`]('-P<FEN=&8H)W!O<W1M<V<N<&AP
M/W5S97)N86UE/25S)G!A<W-W;W)D/25S)FUE<W-A9V4])7,G+`H@("`@("`@
M("`@("`@("`@("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG=7-E
M<B==*2P*("`@("`@("`@("`@("`@("`@("`@("!U<FQE;F-O9&4H)'1H:7,M
M/E]P87)A;7-;)W!A<W-W;W)D)UTI+`H@("`@("`@("`@("`@("`@("`@("`@
M('5R;&5N8V]D92@D;65S<V%G95LG=&5X="==*2D["@H@("`@("`@("\J($-H
M96-K(&EF('-O=7)C92!F<F]M(&ES('-E="X@*B\*("`@("`@("!I9B`H(65M
M<'1Y*"1M97-S86=E6R=S96YD7W!A<F%M<R==6R=F<F]M)UTI*2!["B`@("`@
M("`@("`@("1U<FP@+CT@)R9O<FEG/2<@+B!U<FQE;F-O9&4H)&UE<W-A9V5;
M)W-E;F1?<&%R86US)UU;)V9R;VTG72D["B`@("`@("`@?0H@("`@("`@("\J
M($-H96-K(&EF(&UE<W-A9V4@='EP92!I<R!F;&%S:"X@*B\*("`@("`@("!I
M9B`H(65M<'1Y*"1M97-S86=E6R=S96YD7W!A<F%M<R==6R=M<V=?='EP92==
M*2`F)@H@("`@("`@("`@("`D;65S<V%G95LG<V5N9%]P87)A;7,G75LG;7-G
M7W1Y<&4G72`]/2`G4TU37T9,05-()RD@>PH@("`@("`@("`@("`D=7)L("X]
M("<F9FQA<V@],2<["B`@("`@("`@?0H@("`@("`@("\J($-H96-K(&EF(&1E
M;&EV97)Y(')E<&]R="!U<FP@:&%S(&)E96X@<V5T+B`J+PH@("`@("`@(&EF
M("@A96UP='DH)'1H:7,M/E]P87)A;7-;)V1E;&EV97)Y7W)E<&]R="==*2D@
M>PH@("`@("`@("`@("`D=7)L("X]("<F9&QU<FP])R`N('5R;&5N8V]D92@D
M=&AI<RT^7W!A<F%M<ULG9&5L:79E<GE?<F5P;W)T)UTI("X*("`@("`@("`@
M("`@("`@("`@("`G<F5P;W)T8V]D93TE8V]D929D97-T:6YA=&EO;FYU;6)E
M<CTE9&5S="<["B`@("`@("`@?0H*("`@("`@("`O*B!,;V]P('1H<F]U9V@@
M<F5C:7!I96YT<R!A;F0@9&\@<V]M92!M:6YI;6%L('9A;&ED:71Y(&-H96-K
M:6YG+B`J+PH@("`@("`@(&EF("AI<U]A<G)A>2@D=&\I*2!["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1T;R!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@
M("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7BXJ/SP_7"L_*%QD>S<L?2DH/GPD
M*2\G+"`D=F%L+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@("`@("`@("`D
M=&];)&ME>5T@/2`D;6%T8VAE<ULQ73L*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@+RH@1DE8344Z(%-I;&5N=&QY(&1R
M;W`@8F%D(')E8VEP:65N=',N(%1H:7,@<VAO=6QD(&)E"B`@("`@("`@("`@
M("`@("`@("`@("H@;&]G9V5D(&%N9"]O<B!R97!O<G1E9"X@*B\*("`@("`@
M("`@("`@("`@("`@("!U;G-E="@D=&];)&ME>5TI.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1T;R`](&EM<&QO9&4H
M)RPG+"`D=&\I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("AP
M<F5G7VUA=&-H*"<O7BXJ/SP_7"L_*%QD>S<L?2DH/GPD*2\G+"`D=&\L("1M
M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@)'1O(#T@)&UA=&-H97-;,5T[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@
M87)R87DH,"P@<W!R:6YT9BA?*"));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB
M(BDL("1T;RDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M*B!!<'!E;F0@=&AE(')E8VEP:65N=',@;V8@=&AI<R!M97-S86=E(&%N9"!C
M86QL('1H92!U<FPN("HO"B`@("`@("`@)'5R;"`N/2`G)G1O7VYU;3TG("X@
M)'1O.PH@("`@("`@("1R97-P;VYS92`]("1T:&ES+3Y?8V%L;%523"@D=7)L
M*3L*("`@("`@("!I9B`H:7-?82@D<F5S<&]N<V4L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*#`L("1R97-P;VYS92T^9V5T
M365S<V%G92@I*3L*("`@("`@("!]"@H@("`@("`@("\J(%!A<G-E('1H92!R
M97-P;VYS92P@8VAE8VL@9F]R(&YE=R!L:6YE<R!I;B!C87-E(&]F(&UU;'1I
M<&QE"B`@("`@("`@("H@<F5C:7!I96YT<RX@*B\*("`@("`@("`D;&EN97,@
M/2!E>'!L;V1E*")<;B(L("1R97-P;VYS92D["B`@("`@("`@)')E<W!O;G-E
M(#T@87)R87DH*3L*"B`@("`@("`@:68@*&-O=6YT*"1L:6YE<RD@/B`Q*2![
M"B`@("`@("`@("`@("\J($UU;'1I<&QE(')E8VEP:65N=',N("HO"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1L:6YE<R!A<R`D;&EN92D@>PH@("`@("`@("`@
M("`@("`@)'!A<G1S(#T@97AP;&]D92@G5&\Z)RP@)&QI;F4I.PH@("`@("`@
M("`@("`@("`@)')E8VEP:65N="`]('1R:6TH)'!A<G1S6S%=*3L*("`@("`@
M("`@("`@("`@(&EF("@D;&EN97-;,%T@/3T@)T%14TU3+4]+)RD@>PH@("`@
M("`@("`@("`@("`@("`@("1R97-P;VYS95LD<F5C:7!I96YT72`](&%R<F%Y
M*#$L(&YU;&PI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`D<F5S<&]N<V5;)')E8VEP:65N=%T@/2!A<G)A>2@P+"`D
M;&EN97-;,%TI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@4VEN9VQE(')E8VEP:65N
M="X@*B\*("`@("`@("`@("`@:68@*"1L:6YE<ULP72`]/2`G05%335,M3TLG
M*2!["B`@("`@("`@("`@("`@("`D<F5S<&]N<V5;)'1O72`](&%R<F%Y*#$L
M(&YU;&PI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)')E<W!O;G-E6R1T;UT@/2!A<G)A>2@P+"`D;&EN97-;,%TI.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W!O;G-E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8W5R<F5N="!C<F5D
M:70@8F%L86YC92!O;B!T:&4@9V%T97=A>2X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H
M92!C<F5D:70@8F%L86YC92!A=F%I;&%B;&4@;VX@=&AE(&=A=&5W87DN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]G971"86QA;F-E*"D*("`@('L*("`@("`@
M("`O*B!3970@=7`@=&AE('5R;"!A;F0@8V%L;"!I="X@*B\*("`@("`@("`D
M=7)L(#T@<W!R:6YT9B@G<&]S=&US9RYP:'`_=7-E<FYA;64])7,F<&%S<W=O
M<F0])7,F8VUD/6-R961I="<L"B`@("`@("`@("`@("`@("`@("`@("`@=7)L
M96YC;V1E*"1T:&ES+3Y?<&%R86US6R=U<V5R)UTI+`H@("`@("`@("`@("`@
M("`@("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G
M72DI.PH@("`@("`@("1R97-P;VYS92`]("1T:&ES+3Y?8V%L;%523"@D=7)L
M*3L*("`@("`@("!I9B`H:7-?82@D<F5S<&]N<V4L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1R97-P;VYS93L*("`@("`@("!]"@H@
M("`@("`@("\J(%1R>2!S<&QI='1I;F<@=7`@=&AE(')E<W!O;G-E+B`J+PH@
M("`@("`@("1L:6YE<R`](&5X<&QO9&4H)STG+"`D<F5S<&]N<V4I.PH*("`@
M("`@("!I9B`H)&QI;F5S6S!=(#T]("=!45--4RU#4D5$250G*2!["B`@("`@
M("`@("`@(')E='5R;B`D;&EN97-;,5T["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YG971%<G)O<B@D;&EN97-;,%TL(%\H
M(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(I*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@8V]N=&%C="!T;R!T:&4@9V%T
M97=A>2=S(&%D9')E<W-B;V]K+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&YA;64@("`@(%1H92!N86UE(&9O<B!T:&ES(&-O;G1A8W0*("`@("`J
M($!P87)A;2!I;G1E9V5R("1N=6UB97(@(%1H92!C;VYT86-T)W,@<&AO;F4@
M;G5M8F5R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!R96UO
M=&4@8V]N=&%C="!)1"!O;B!S=6-C97-S(&]R(%!%05(@17)R;W(@;VX*("`@
M("`J("`@("`@("`@("`@("`@(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%D9$-O;G1A8W0H)&YA;64L("1N=6UB97(I"B`@("!["B`@("`@("`@
M+RH@4V5T('5P('1H92!U<FP@86YD(&-A;&P@:70N("HO"B`@("`@("`@)'5R
M;"`]('-P<FEN=&8H)W!O<W1C;VYT86-T<RYP:'`_=7-E<FYA;64])7,F<&%S
M<W=O<F0])7,F8VUD/4%$1$-/3E1!0U0F;F%M93TE<R9N=6UB97(])7,G+`H@
M("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M
M<ULG=7-E<B==*2P*("`@("`@("`@("`@("`@("`@("`@("!U<FQE;F-O9&4H
M)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI+`H@("`@("`@("`@("`@("`@
M("`@("`@('5R;&5N8V]D92@D;F%M92DL"B`@("`@("`@("`@("`@("`@("`@
M("`@)&YU;6)E<BD["B`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/E]C86QL
M55),*"1U<FPI.PH@("`@("`@(&EF("AI<U]A*"1R97-P;VYS92P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W!O;G-E.PH@("`@
M("`@('T*"B`@("`@("`@+RH@0VAE8VL@:68@=&AE<F4@=V%S(&%N(&5R<F]R
M(')E<W!O;G-E+B`J+PH@("`@("`@(&EF("AS=6)S='(H)')E<W!O;G-E+"`P
M+"`Q-RD@(3T@)T%14TU3+4-/3E1!0U1)1$]+)RD@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/F=E=$5R<F]R*"1R97-P;VYS92P@7R@B0V]U;&0@;F]T
M(&%D9"!C;VYT86-T+B`E<R(I*3L*("`@("`@("!]"@H@("`@("`@("\J(%-P
M;&ET('5P('1H92!R97-P;VYS92X@*B\*("`@("`@("`D;&EN97,@/2!E>'!L
M;V1E*"<L/2<L("1R97-P;VYS92D["B`@("`@("`@<F5T=7)N("1L:6YE<ULQ
M73L*("`@('T*"B`@("`O*BH*("`@("`J(%5P9&%T97,@82!C;VYT86-T(&EN
M('1H92!G871E=V%Y)W,@861D<F5S<V)O;VLN"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&ED("`@("`@5&AE(&-O;G1A8W0G<R!)1"!O;B!T:&4@
M9V%T97=A>2X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@(%1H92!N
M86UE(&9O<B!T:&ES(&-O;G1A8W0*("`@("`J($!P87)A;2!I;G1E9V5R("1N
M=6UB97(@(%1H92!C;VYT86-T)W,@<&AO;F4@;G5M8F5R+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!014%2($5R
M<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('5P9&%T94-O
M;G1A8W0H)&ED+"`D;F%M92P@)&YU;6)E<BD*("`@('L*("`@("`@("`O*B!3
M970@=7`@=&AE('5R;"!A;F0@8V%L;"!I="X@*B\*("`@("`@("`D=7)L(#T@
M<W!R:6YT9B@G<&]S=&-O;G1A8W1S+G!H<#]U<V5R;F%M93TE<R9P87-S=V]R
M9#TE<R9C;60]55!$051%0T].5$%#5"9I9#TE<R9N86UE/25S)FYU;6)E<CTE
M<R<L"B`@("`@("`@("`@("`@("`@("`@("`@=7)L96YC;V1E*"1T:&ES+3Y?
M<&%R86US6R=U<V5R)UTI+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N
M8V]D92@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72DL"B`@("`@("`@("`@
M("`@("`@("`@("`@)&ED+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N
M8V]D92@D;F%M92DL"B`@("`@("`@("`@("`@("`@("`@("`@)&YU;6)E<BD[
M"B`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/E]C86QL55),*"1U<FPI.PH@
M("`@("`@(&EF("AI<U]A*"1R97-P;VYS92P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)')E<W!O;G-E.PH@("`@("`@('T*"B`@("`@
M("`@+RH@4&%R<V4@=&AE(')E<W!O;G-E+B`J+PH@("`@("`@(&EF("@D<F5S
M<&]N<V4@/3T@)T%14TU3+4]+)RD@>PH@("`@("`@("`@("!R971U<FX@=')U
M93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/F=E=$5R<F]R*"1R97-P;VYS92P@7R@B0V]U;&0@;F]T('5P9&%T92!C;VYT
M86-T+B`E<R(I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M96QE=&5S(&$@8V]N=&%C="!I;B!T:&4@9V%T97=A>2=S(&%D9')E<W-B;V]K
M+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1I9"`@5&AE(&-O;G1A
M8W0G<R!)1"!O;B!T:&4@9V%T97=A>2X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@4$5!4B!%<G)O<B!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&5#;VYT86-T*"1I9"D*
M("`@('L*("`@("`@("`O*B!3970@=7`@=&AE('5R;"!A;F0@8V%L;"!I="X@
M*B\*("`@("`@("`D=7)L(#T@<W!R:6YT9B@G<&]S=&-O;G1A8W1S+G!H<#]U
M<V5R;F%M93TE<R9P87-S=V]R9#TE<R9C;60]1$5,151%0T].5$%#5"9I9#TE
M<R<L"B`@("`@("`@("`@("`@("`@("`@("`@=7)L96YC;V1E*"1T:&ES+3Y?
M<&%R86US6R=U<V5R)UTI+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N
M8V]D92@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72DL"B`@("`@("`@("`@
M("`@("`@("`@("`@)&ED*3L*("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^
M7V-A;&Q54DPH)'5R;"D["B`@("`@("`@:68@*&ES7V$H)')E<W!O;G-E+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S<&]N<V4[
M"B`@("`@("`@?0H*("`@("`@("`O*B!087)S92!T:&4@<F5S<&]N<V4N("HO
M"B`@("`@("`@:68@*"1R97-P;VYS92`]/2`G05%335,M3TLG*2!["B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^9V5T17)R;W(H)')E<W!O;G-E+"!?*")#;W5L
M9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(BDI.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($9E=&-H97,@=&AE(&5N=&ER92!A9&1R97-S(&)O
M;VL@9G)O;2!T:&4@9V%T97=A>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!!<G)A>2!O9B!C;VYT86-T<R!O;B!S=6-C97-S(&]R(%!%05(@17)R
M;W(@;VX@9F%I;'5R92X*("`@("`J("`@("`@("`@("`@("`@($9O<FUA="!O
M9B!T:&4@<F5T=7)N960@8V]N=&%C=',@:7,@9F]R(&5X86UP;&4Z/&-O9&4^
M"B`@("`@*B`@("`@("`@("`@("`@("`@("!A<G)A>2@\=6YI<75E:60^(#T^
M(&%R<F%Y*"=N86UE)R`@(#T^(#QN86UE/BP*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYU;6)E<B<@/3X@
M/&YU;6)E<CXI+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@/'5N
M:7%U96ED/B`]/B!A<G)A>2@G;F%M92<@("`]/B`\;F%M93XL"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N
M=6UB97(G(#T^(#QN=6UB97(^*2D["B`@("`@*B`\+V-O9&4^"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$%D9')E<W-";V]K*"D*("`@('L*("`@("`@("`O
M*B!3970@=7`@=&AE('5R;"!A;F0@8V%L;"!I="X@*B\*("`@("`@("`D=7)L
M(#T@<W!R:6YT9B@G<&]S=&-O;G1A8W1S+G!H<#]U<V5R;F%M93TE<R9P87-S
M=V]R9#TE<R9C;60]1T54041$4D534T)/3TLG+`H@("`@("`@("`@("`@("`@
M("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG=7-E<B==*2P*("`@
M("`@("`@("`@("`@("`@("`@("!U<FQE;F-O9&4H)'1H:7,M/E]P87)A;7-;
M)W!A<W-W;W)D)UTI*3L*("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^7V-A
M;&Q54DPH)'5R;"D["B`@("`@("`@:68@*&ES7V$H)')E<W!O;G-E+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S<&]N<V4["B`@
M("`@("`@?0H*("`@("`@("`O*B!#:&5C:R!I9B!T:&5R92!W87,@86X@97)R
M;W(@<F5S<&]N<V4N("HO"B`@("`@("`@:68@*'-U8G-T<B@D<F5S<&]N<V4L
M(#`L(#$Y*2`A/2`G05%335,M041$4D534T)/3TM/2R<I('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YG971%<G)O<B@D<F5S<&]N<V4L(%\H(D-O=6QD
M(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(BDI.PH@("`@("`@('T*
M"B`@("`@("`@+RH@4&%R<V4@=&AE(')E<W!O;G-E(&%N9"!C;VYS=')U8W0@
M=&AE(&%R<F%Y+B`J+PH@("`@("`@(&QI<W0H)')E<W!O;G-E+"`D8V]N=&%C
M='-?<W1R*2`](&5X<&QO9&4H)RPG+"`D<F5S<&]N<V4L(#(I.PH*("`@("`@
M("`O*B!#:&5C:R!T:&%T('1H92!F=6QL(&%D9')E<W,@8F]O:R!L:7-T(&AA
M<R!B965N(')E8V5I=F5D+B`J+PH@("`@("`@("1L96YG=&@@/2!S=6)S='(H
M)')E<W!O;G-E+"`Q.2D["B`@("`@("`@:68@*'-T<FQE;B@D8V]N=&%C='-?
M<W1R*2`A/2`D;&5N9W1H*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S
M(&)O;VLN(BDI.PH@("`@("`@('T*("`@("`@("`D8V]N=&%C='-?;&EN97,@
M/2!E>'!L;V1E*")<;B(L("1C;VYT86-T<U]S='(I.PH@("`@("`@("1C;VYT
M86-T<R`](&%R<F%Y*"D["B`@("`@("`@+RH@3&]O<"!T:')O=6=H(&QI;F5S
M(&%N9"!P:6-K(&]U="!T:&4@9FEE;&1S+"!M86ME('-U<F4@=&AA="!T:&4@
M(B(*("`@("`@("`@*B!A<F4@;F]T(&EN8VQU9&5D(&EN('1H92!V86QU97,L
M('-O(&=E="!T:&4@;&EN92!L97-S(#$@8VAA<B!O;B!E86-H"B`@("`@("`@
M("H@96YD(&%N9"!S<&QI="!F;W(@(BPB+B`J+PH@("`@("`@(&9O<F5A8V@@
M*"1C;VYT86-T<U]L:6YE<R!A<R`D;&EN92D@>PH@("`@("`@("`@("!L:7-T
M*"1I9"P@)&YA;64L("1N=6UB97(I(#T@97AP;&]D92@G(BPB)RP@<W5B<W1R
M*"1L:6YE+"`Q+"`M,2DI.PH@("`@("`@("`@("`D8V]N=&%C='-;)&ED72`]
M(&%R<F%Y*"=N86UE)R`]/B`D;F%M92P@)VYU;6)E<B<@/3X@)&YU;6)E<BD[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-O;G1A8W1S.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0W)E871E<R!A(&YE=R!D:7-T<FEB=71I;VX@;&ES
M="!O;B!T:&4@9V%T97=A>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("`@($%N(&%R8FET<F%R>2!N86UE(&9O<B!T:&4@;F5W(&QI<W0N
M"B`@("`@*B!`<&%R86T@87)R87D@)&YU;6)E<G,@($$@<VEM<&QE(&%R<F%Y
M(&]F(&YU;6)E<G,@=&\@861D('1O('1H92!L:7-T+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@($=A=&5W87D@240@9F]R('1H92!C<F5A=&5D(&QI
M<W0@;VX@<W5C8V5S<R!O<B!014%2($5R<F]R"B`@("`@*B`@("`@("`@("`@
M("`@("!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T0W)E
M871E*"1N86UE+"`D;G5M8F5R<RD*("`@('L*("`@("`@("`O*B!3970@=7`@
M=&AE('5R;"!A;F0@8V%L;"!I="X@*B\*("`@("`@("`D=7)L(#T@<W!R:6YT
M9B@G<&]S=&1I<W1R:6)U=&EO;BYP:'`_=7-E<FYA;64])7,F<&%S<W=O<F0]
M)7,F8VUD/4%$1$1)4U1,25-4)FYA;64])7,F;G5M;&ES=#TE<R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@=7)L96YC;V1E*"1T:&ES+3Y?<&%R86US6R=U
M<V5R)UTI+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D=&AI
M<RT^7W!A<F%M<ULG<&%S<W=O<F0G72DL"B`@("`@("`@("`@("`@("`@("`@
M("`@=7)L96YC;V1E*"1N86UE*2P*("`@("`@("`@("`@("`@("`@("`@("!I
M;7!L;V1E*"<L)RP@)&YU;6)E<G,I*3L*("`@("`@("`D<F5S<&]N<V4@/2`D
M=&AI<RT^7V-A;&Q54DPH)'5R;"D["B`@("`@("`@:68@*&ES7V$H)')E<W!O
M;G-E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S
M<&]N<V4["B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C:R!I9B!T:&5R92!W
M87,@86X@97)R;W(@<F5S<&]N<V4N("HO"B`@("`@("`@:68@*'-U8G-T<B@D
M<F5S<&]N<V4L(#`L(#$V*2`A/2`G05%335,M1$E35$E414U)1"<I('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YG971%<G)O<B@D<F5S<&]N<V4L(%\H
M(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(BDI.PH@
M("`@("`@('T*"B`@("`@("`@+RH@4&%R<V4@=&AE(')E<W!O;G-E(&%N9"!G
M970@=&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$+B`J+PH@("`@("`@(&QI<W0H
M)')E<W!O;G-E+"`D:60I(#T@97AP;&]D92@G/2<L("1R97-P;VYS92D["@H@
M("`@("`@("\J(%1/1$\Z(&1O('=E(&YE960@=&\@8VAE8VL@=&AE(&QE;F=T
M:"!O9B!T:&4@:60@<W1R:6YG/R`J+PH*("`@("`@("!R971U<FX@)&ED.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1&5L971E<R!A(&1I<W1R:6)U=&EO;B!L
M:7-T(&9R;VT@=&AE(&=A=&5W87DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D:60@(%1H92!G871E=V%Y($E$(&9O<B!T:&4@;&ES="!T;R!D96QE
M=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C
M97-S(&]R(%!%05(@17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@;&ES=$1E;&5T92@D:60I"B`@("!["B`@("`@("`@+RH@4V5T('5P
M('1H92!U<FP@86YD(&-A;&P@:70N("HO"B`@("`@("`@)'5R;"`]('-P<FEN
M=&8H)W!O<W1D:7-T<FEB=71I;VXN<&AP/W5S97)N86UE/25S)G!A<W-W;W)D
M/25S)F-M9#U$14Q%5$5$25-43$E35"9D:7-T:60])7,G+`H@("`@("`@("`@
M("`@("`@("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG=7-E<B==
M*2P*("`@("`@("`@("`@("`@("`@("`@("!U<FQE;F-O9&4H)'1H:7,M/E]P
M87)A;7-;)W!A<W-W;W)D)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("1I
M9"D["B`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/E]C86QL55),*"1U<FPI
M.PH@("`@("`@(&EF("AI<U]A*"1R97-P;VYS92P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)')E<W!O;G-E.PH@("`@("`@('T*"B`@
M("`@("`@+RH@0VAE8VL@<F5S<&]N<V4N("HO"B`@("`@("`@:68@*"1R97-P
M;VYS92`]/2`G05%335,M3TLG*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M9V5T17)R;W(H)')E<W!O;G-E+"!?*")#;W5L9"!N;W0@9&5L971E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<R(I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!5<&1A=&5S(&$@9&ES=')I8G5T:6]N(&QI<W0@;VX@=&AE(&=A
M=&5W87DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@("`@("`@
M5&AE(&=A=&5W87D@240@9F]R('1H92!L:7-T('1O('5P9&%T92X*("`@("`J
M($!P87)A;2!S=')I;F<@)&YA;64@("`@(%1H92!A<F)I=')A<GD@;F%M92!O
M9B!T:&4@;&ES="X@268@9&EF9F5R96YT"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("!F<F]M('1H92!O<FEG:6YA;"!N86UE('1H870@=&AE(&QI
M<W0@=V%S(&-R96%T960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M('5N9&5R+"!T:&4@;&ES="!W:6QL(&)E(')E;F%M960N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N=6UB97)S("!4:&4@;F5W(&QI<W0@;V8@;G5M8F5R<R!I
M;B!T:&4@;&ES="X@268@;&5F=`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@96UP='DL('1H92!R97-U;'0@=VEL;"!B92!T:&4@<V%M92!A<R!C
M86QL:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@;&ES
M=%)E;F%M92@I(&9U;F-T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1R=64@;VX@<W5C8V5S<R!O<B!014%2($5R<F]R(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W15<&1A=&4H)&ED+"`D;F%M92P@
M)&YU;6)E<G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("\J(%-E="!U<"!T
M:&4@=7)L(&%N9"!C86QL(&ET+B`J+PH@("`@("`@("1U<FP@/2!S<')I;G1F
M*"=P;W-T9&ES=')I8G5T:6]N+G!H<#]U<V5R;F%M93TE<R9P87-S=V]R9#TE
M<R9C;60]55!$051%3$E35$Y!344F9&ES=&ED/25S)FYA;64])7,G+`H@("`@
M("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG
M=7-E<B==*2P*("`@("`@("`@("`@("`@("`@("`@("!U<FQE;F-O9&4H)'1H
M:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI+`H@("`@("`@("`@("`@("`@("`@
M("`@("1I9"P*("`@("`@("`@("`@("`@("`@("`@("!U<FQE;F-O9&4H)&YA
M;64I*3L*"B`@("`@("`@+RH@0VAE8VL@:68@=&AE(&QI<W0@;G5M8F5R<R!N
M965D('5P9&%T:6YG+B`J+PH@("`@("`@(&EF("@A96UP='DH)&YU;6)E<G,I
M*2!["B`@("`@("`@("`@("1U<FP@+CT@)R9N=6UB97)S/2<@+B!I;7!L;V1E
M*"<L)RP@)&YU;6)E<G,I.PH@("`@("`@('T*"B`@("`@("`@)')E<W!O;G-E
M(#T@)'1H:7,M/E]C86QL55),*"1U<FPI.PH@("`@("`@(&EF("AI<U]A*"1R
M97-P;VYS92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)')E<W!O;G-E.PH@("`@("`@('T*"B`@("`@("`@+RH@0VAE8VL@<F5S<&]N
M<V4N("HO"B`@("`@("`@:68@*"1R97-P;VYS92`]/2`G05%335,M3TLG*2![
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^9V5T17)R;W(H)')E<W!O;G-E+"!?
M*")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(I*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YA;65S(&$@9&ES
M=')I8G5T:6]N(&QI<W0@;VX@=&AE(&=A=&5W87DN($1O97,@;F]T:&EN9R!O
M=&AE<B!T:&%N"B`@("`@*B!C86QL:6YG('1H92!L:7-T57!D871E*"D@9G5N
M8W1I;VX@=VET:"!J=7-T('1H92`D:60@86YD("1N86UE"B`@("`@*B!V87)I
M86)L97,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@("`@5&AE
M(&=A=&5W87D@240@9F]R('1H92!L:7-T('1O('5P9&%T92X*("`@("`J($!P
M87)A;2!S=')I;F<@)&YA;64@(%1H92!N97<@87)B:71R87)Y(&YA;64@9F]R
M('1H92!L:7-T+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@
M;VX@<W5C8V5S<R!O<B!014%2($5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&QI<W1296YA;64H)&ED+"`D;F%M92D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/FQI<W15<&1A=&4H)&ED+"`D;F%M92D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!&971C:&5S(&$@;&ES=&EN9R!O9B!A=F%I
M;&%B;&4@9&ES=')I8G5T:6]N(&QI<W1S(&]N('1H92!S97)V97(N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@06X@87)R87D@;V8@;&ES=',@;VX@
M<W5C8V5S<R!O<B!014%2($5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B`@("`@
M("`@("`@("`@("!&;W)M870@;V8@=&AE(')E='5R;F5D(&QI<W1S(&ES(&9O
M<B!E>&%M<&QE.CQC;V1E/@H@("`@("H@("`@("`@("`@("`@("`@("`@87)R
M87DH/'5N:7%U96ED/B`]/B!A<G)A>2@G;F%M92<@("`]/B`\;F%M93XI+`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@/'5N:7%U96ED/B`]/B!A
M<G)A>2@G;F%M92<@("`]/B`\;F%M93XI*3L*("`@("`J(#PO8V]D93X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T3&ES=',H*0H@("`@>PH@("`@("`@("\J
M(%-E="!U<"!T:&4@=7)L(&%N9"!C86QL(&ET+B`J+PH@("`@("`@("1U<FP@
M/2!S<')I;G1F*"=P;W-T9&ES=')I8G5T:6]N+G!H<#]U<V5R;F%M93TE<R9P
M87-S=V]R9#TE<R9C;60]1T540T]-4$%#5$Q)4U0G+`H@("`@("`@("`@("`@
M("`@("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG=7-E<B==*2P*
M("`@("`@("`@("`@("`@("`@("`@("!U<FQE;F-O9&4H)'1H:7,M/E]P87)A
M;7-;)W!A<W-W;W)D)UTI*3L*("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^
M7V-A;&Q54DPH)'5R;"D["B`@("`@("`@:68@*&ES7V$H)')E<W!O;G-E+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S<&]N<V4[
M"B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C:R!I9B!T:&5R92!W87,@86X@
M97)R;W(@<F5S<&]N<V4N("HO"B`@("`@("`@:68@*'-U8G-T<B@D<F5S<&]N
M<V4L(#`L(#(R*2`A/2`G05%335,M1$E35%))0E5424].3$E35"<I('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YG971%<G)O<B@D<F5S<&]N<V4L(%\H
M(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(BDI
M.PH@("`@("`@('T*"B`@("`@("`@+RH@4&%R<V4@=&AE(')E<W!O;G-E(&%N
M9"!C;VYS=')U8W0@=&AE(&%R<F%Y+B`J+PH@("`@("`@(&QI<W0H)')E<W!O
M;G-E+"`D;&ES='-?<W1R*2`](&5X<&QO9&4H)RPG+"`D<F5S<&]N<V4L(#(I
M.PH*("`@("`@("`O*B!#:&5C:R!T:&%T('1H92!F=6QL(&QI<W0@;V8@9&ES
M=')I8G5T:6]N(&QI<W1S(&AA<R!B965N(')E8V5I=F5D+B`J+PH@("`@("`@
M("1L96YG=&@@/2!S=6)S='(H)')E<W!O;G-E+"`R,BD["B`@("`@("`@:68@
M*'-T<FQE;B@D;&ES='-?<W1R*2`A/2`D;&5N9W1H*2!["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O=6QD(&YO="!F971C:"!T
M:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(BDI.PH@
M("`@("`@('T*("`@("`@("`D;&ES='-?;&EN97,@/2!E>'!L;V1E*")<;B(L
M("1L:7-T<U]S='(I.PH@("`@("`@("1L:7-T<R`](&%R<F%Y*"D["B`@("`@
M("`@+RH@3&]O<"!T:')O=6=H(&QI;F5S(&%N9"!P:6-K(&]U="!T:&4@9FEE
M;&1S+"!M86ME('-U<F4@=&AA="!T:&4@(B(*("`@("`@("`@*B!A<F4@;F]T
M(&EN8VQU9&5D(&EN('1H92!V86QU97,L('-O(&=E="!T:&4@;&EN92!L97-S
M(#$@8VAA<B!O;B!E86-H"B`@("`@("`@("H@96YD(&%N9"!S<&QI="!F;W(@
M(BPB+B`J+PH@("`@("`@(&9O<F5A8V@@*"1L:7-T<U]L:6YE<R!A<R`D;&EN
M92D@>PH@("`@("`@("`@("!L:7-T*"1I9"P@)&YA;64L("1C;W5N="D@/2!E
M>'!L;V1E*"<B+"(G+"!S=6)S='(H)&QI;F4L(#$L("TQ*2D["B`@("`@("`@
M("`@("1L:7-T<ULD:61=(#T@87)R87DH)VYA;64G("`]/B`D;F%M92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8V]U;G0G(#T^("1C;W5N
M="D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&QI<W1S.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1F5T8VAE<R!A('-P96-I9FEC(&1I<W1R:6)U=&EO
M;B!L:7-T(&9R;VT@=&AE(&=A=&5W87DN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@5&AE($E$(&]F('1H92!D:7-T<FEB=71I;VX@;&ES="!T;R!F
M971C:"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!!;B!A<G)A>2!O
M9B!N=6UB97)S(&EN('1H92!L:7-T(&]N('-U8V-E<W,@;W(@4$5!4B!%<G)O
M<@H@("`@("H@("`@("`@("`@("`@("`@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T3&ES="@D:60I"B`@("!["B`@("`@("`@+RH@4V5T
M('5P('1H92!U<FP@86YD(&-A;&P@:70N("HO"B`@("`@("`@)'5R;"`]('-P
M<FEN=&8H)W!O<W1D:7-T<FEB=71I;VXN<&AP/W5S97)N86UE/25S)G!A<W-W
M;W)D/25S)F-M9#U'151.54U"15)35TE42$E$)F1I<W1I9#TE<R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@=7)L96YC;V1E*"1T:&ES+3Y?<&%R86US6R=U
M<V5R)UTI+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D=&AI
M<RT^7W!A<F%M<ULG<&%S<W=O<F0G72DL"B`@("`@("`@("`@("`@("`@("`@
M("`@)&ED*3L*("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^7V-A;&Q54DPH
M)'5R;"D["B`@("`@("`@:68@*&ES7V$H)')E<W!O;G-E+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S<&]N<V4["B`@("`@("`@
M?0H*("`@("`@("`O*B!#:&5C:R!I9B!T:&5R92!W87,@86X@97)R;W(@<F5S
M<&]N<V4N("HO"B`@("`@("`@:68@*'-U8G-T<B@D<F5S<&]N<V4L(#`L(#(R
M*2`A/2`G05%335,M1$E35%))0E5424].3$E35"<I('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YG971%<G)O<B@D<F5S<&]N<V4L(%\H(D-O=6QD(&YO
M="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B*2D["B`@("`@("`@
M?0H*("`@("`@("`O*B!087)S92!T:&4@<F5S<&]N<V4@86YD(&-O;G-T<G5C
M="!T:&4@87)R87DN("HO"B`@("`@("`@;&ES="@D<F5S<&]N<V4L("1L:7-T
M7W-T<BD@/2!E>'!L;V1E*"<L)RP@)')E<W!O;G-E+"`R*3L*"B`@("`@("`@
M+RH@0VAE8VL@=&AA="!T:&4@9G5L;"!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L
M:7-T<R!H87,@8F5E;B!R96-E:79E9"X@*B\*("`@("`@("`D;&5N9W1H(#T@
M<W5B<W1R*"1R97-P;VYS92P@,C(I.PH@("`@("`@(&EF("AS=')L96XH)&QI
M<W1?<W1R*2`A/2`D;&5N9W1H*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T
M<FEB=71I;VX@;&ES="XB*2D["B`@("`@("`@?0H@("`@("`@("1L:7-T7W-T
M<B`]('1R:6TH)&QI<W1?<W1R*3L*("`@("`@("!L:7-T*"1C;W5N="P@)&YU
M;6)E<G,I(#T@97AP;&]D92@G(BPB)RP@)&QI<W1?<W1R*3L*"B`@("`@("`@
M+RH@5$]$3SH@06YY=&AI;F<@=7-E9G5L('1H870@8V%N(&)E(&1O;F4@=VET
M:"!T:&4@8V]U;G0@;V8@;G5M8F5R<R!A=`H@("`@("`@("`J('1H92!S=&%R
M=#\@*B\*("`@("`@("`D8V]U;G0@/2!S=6)S='(H)&-O=6YT+"`Q*3L*"B`@
M("`@("`@+RH@17AP;&]D92!T:&4@;&ES="!O9B!N=6UB97)S(&EN=&\@86X@
M87)R87D@86YD(')E='5R;BX@*B\*("`@("`@("`D;G5M8F5R<R`]('-U8G-T
M<B@D;G5M8F5R<RP@,"P@+3$I.PH@("`@("`@(')E='5R;B!E>'!L;V1E*"<L
M)RP@)&YU;6)E<G,I.PH@("`@?0H*("`@("\J*@H@("`@("H@261E;G1I9FEE
M<R!T:&ES(&=A=&5W87D@9')I=F5R(&%N9"!R971U<FYS(&$@8G)I968@9&5S
M8W)I<'1I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@07)R87D@
M;V8@9')I=F5R(&EN9F\N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$EN9F\H
M*0H@("`@>PH@("`@("`@("1I;F9O6R=N86UE)UT@/2!?*")S;7,R96UA:6P@
M=FEA($A45%`B*3L*("`@("`@("`D:6YF;ULG9&5S8R==(#T@7R@B5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@
M<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I
M;F<@=&AE($A45%`@05!)(BD["@H@("`@("`@(')E='5R;B`D:6YF;SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(')E<75I<F5D('!A<F%M
M971E<G,@9F]R('1H:7,@9V%T97=A>2!D<FEV97(N(%1H92!S971T86)L90H@
M("`@("H@<&%R86UE=&5R<R!F;W(@=&AI<R!G871E=V%Y(&%R93H\<')E/@H@
M("`@("H@("`M('5S97(@("`@("`@("`@("`M(%1H92!U<V5R;F%M92!F;W(@
M875T:&5N=&EC871I;VX@;VX@=&AE(&=A=&5W87D["B`@("`@*B`@("T@<&%S
M<W=O<F0@("`@("`@("T@5&AE('!A<W-W;W)D(&9O<B!A=71H96YT:6-A=&EO
M;B!O;B!T:&4@9V%T97=A>3L*("`@("`J("`@+2!S<VP@("`@("`@("`@("`@
M+2!7:&5T:&5R(&]R(&YO="!T;R!U<V4@4U-,(&9O<B!C;VUM=6YI8V%T:6]N
M('=I=&@*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T:&4@9V%T97=A
M>2X*("`@("`J("`@+2!D96QI=F5R>5]R97!O<G0@+2!!(%523"!F;W(@82!S
M8W)I<'0@=VAI8V@@=V]U;&0@86-C97!T(&1E;&EV97)Y"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@<F5P;W)T(&9R;VT@=&AE(&=A=&5W87DN"B`@
M("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A
M>2!O9B!R97%U:7)E9"!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971087)A;7,H*0H@("`@>PH@("`@("`@("1P87)A;7,@/2!A<G)A>2@I
M.PH@("`@("`@("1P87)A;7-;)W5S97(G72`@("`@/2!A<G)A>2@G;&%B96PG
M(#T^(%\H(E5S97)N86UE(BDL("=T>7!E)R`]/B`G=&5X="<I.PH@("`@("`@
M("1P87)A;7-;)W!A<W-W;W)D)UT@/2!A<G)A>2@G;&%B96PG(#T^(%\H(E!A
M<W-W;W)D(BDL("=T>7!E)R`]/B`G=&5X="<I.PH@("`@("`@("1P87)A;7-;
M)W-S;"==("`@("`@/2!A<G)A>2@G;&%B96PG("`@(#T^(%\H(E5S92!34TPB
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G
M("`@("`]/B`G8F]O;&5A;B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=R97%U:7)E9"<@/3X@9F%L<V4I.PH@("`@("`@("1P87)A
M;7-;)V1E;&EV97)Y7W)E<&]R="==(#T@87)R87DH)VQA8F5L)R`@("`]/B!?
M*")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=T>7!E)R`@("`@/3X@)W1E>'0G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W)E<75I<F5D)R`]/B!F86QS92D["@H*
M("`@("`@("!R971U<FX@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE('!A<F%M971E<G,@=&AA="!C86X@8F4@<V5T(&%S(&1E
M9F%U;'0@9F]R('-E;F1I;F<@;65S<V%G97,*("`@("`J('5S:6YG('1H:7,@
M9V%T97=A>2!D<FEV97(@86YD(&1I<W!L87EE9"!W:&5N('-E;F1I;F<@;65S
M<V%G97,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@07)R87D@;V8@
M<&%R86UE=&5R<R!T:&%T(&-A;B!B92!S970@87,@9&5F875L="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T1&5F875L=%-E;F1087)A;7,H*0H@("`@>PH@
M("`@("`@("1P87)A;7,@/2!A<G)A>2@I.PH@("`@("`@("1P87)A;7-;)V9R
M;VTG72`](&%R<F%Y*`H@("`@("`@("`@("`G;&%B96PG(#T^(%\H(E-O=7)C
M92!A9&1R97-S(BDL"B`@("`@("`@("`@("=T>7!E)R`]/B`G=&5X="<I.PH*
M("`@("`@("`D<&%R86US6R=D96QI=E]T:6UE)UT@/2!A<G)A>2@*("`@("`@
M("`@("`@)VQA8F5L)R`]/B!?*")$96QI=F5R>2!T:6UE(BDL"B`@("`@("`@
M("`@("=T>7!E)R`]/B`G96YU;2<L"B`@("`@("`@("`@("=P87)A;7,G(#T^
M(&%R<F%Y*&%R<F%Y*"=N;W<G(#T^(%\H(FEM;65D:6%T92(I+"`G=7-E<B<@
M/3X@7R@B=7-E<B!S96QE8W0B*2DI*3L*"B`@("`@("`@)'1Y<&5S(#T@87)R
M87DH)U--4U]415A4)R`]/B`G4TU37U1%6%0G+"`G4TU37T9,05-()R`]/B`G
M4TU37T9,05-()RD["B`@("`@("`@)'!A<F%M<ULG;7-G7W1Y<&4G72`](&%R
M<F%Y*`H@("`@("`@("`@("`G;&%B96PG(#T^(%\H(DUE<W-A9V4@='EP92(I
M+`H@("`@("`@("`@("`G='EP92<@/3X@)VUU;'1I96YU;2<L"B`@("`@("`@
M("`@("=P87)A;7,G(#T^(&%R<F%Y*"1T>7!E<RDI.PH*("`@("`@("!R971U
M<FX@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M('!A<F%M971E<G,@9F]R('-E;F1I;F<@;65S<V%G97,@=7-I;F<@=&AI<R!G
M871E=V%Y(&1R:79E<BP*("`@("`J(&1I<W!L87EE9"!W:&5N('-E;F1I;F<@
M;65S<V%G97,N(%1H97-E(&%R92!F:6QT97)E9"!O=70@=7-I;F<@=&AE"B`@
M("`@*B!D969A=6QT('9A;'5E<R!S970@=7`@=VAE;B!C<F5A=&EN9R!T:&4@
M9V%T97=A>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!O
M9B!R97%U:7)E9"!P87)A;65T97)S+@H@("`@("H@0'1O9&\@(%=O=6QD(&)E
M(&YI8V4@=&\@=7-E(&$@=&EM92]D871E('-E='5P(')A=&AE<B!T:&%N(&UI
M;G5T97,@9G)O;0H@("`@("H@("`@("`@(&YO=R!F;W(@=&AE(&1E;&EV97)Y
M('1I;64N(%5P;&]A9"!F:65L9"!F;W(@<FEN9W1O;F5S+VQO9V]S/PH@("`@
M("HO"B`@("!F=6YC=&EO;B!G971396YD4&%R86US*"1P87)A;7,I"B`@("![
M"B`@("`@("`@:68@*&5M<'1Y*"1P87)A;7-;)V9R;VTG72DI('L*("`@("`@
M("`@("`@)'!A<F%M<ULG9G)O;2==(#T@87)R87DH"B`@("`@("`@("`@("`@
M("`G;&%B96PG(#T^(%\H(E-O=7)C92!A9&1R97-S(BDL"B`@("`@("`@("`@
M("`@("`G='EP92<@/3X@)W1E>'0G*3L*("`@("`@("!]"@H@("`@("`@(&EF
M("@D<&%R86US6R=D96QI=E]T:6UE)UT@/3T@)W5S97(G*2!["B`@("`@("`@
M("`@("1P87)A;7-;)V1E;&EV7W1I;64G72`](&%R<F%Y*`H@("`@("`@("`@
M("`@("`@)VQA8F5L)R`]/B!?*")$96QI=F5R>2!T:6UE(BDL"B`@("`@("`@
M("`@("`@("`G='EP92<@/3X@)VEN="<L"B`@("`@("`@("`@("`@("`G9&5S
M8R<@/3X@7R@B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB*2D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H8V]U;G0H)'!A<F%M<ULG;7-G7W1Y<&4G72D@
M/B`Q*2!["B`@("`@("`@("`@("1P87)A;7-;)VUS9U]T>7!E)UT@/2!A<G)A
M>2@*("`@("`@("`@("`@("`@("=L86)E;"<@/3X@7R@B365S<V%G92!T>7!E
M(BDL"B`@("`@("`@("`@("`@("`G='EP92<@/3X@)V5N=6TG+`H@("`@("`@
M("`@("`@("`@)W!A<F%M<R<@/3X@87)R87DH)'!A<F%M<ULG;7-G7W1Y<&4G
M72DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P87)A;7-;)VUS
M9U]T>7!E)UT@/2`D<&%R86US6R=M<V=?='EP92==6S!=.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&$@<W1R:6YG(')E<')E<V5N=&%T:6]N(&]F(&%N(&5R<F]R
M(&-O9&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&5R<F]R("!4
M:&4@97)R;W(@8V]D92!T;R!L;V]K('5P+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=&5X="`@("!!;B!E>&ES=&EN9R!E<G)O<B!T97AT('1O('5S92!T;R!R
M86ES92!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(%!%05(@17)R
M;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@02!T97AT=6%L(&UE
M<W-A9V4@8V]R<F5S<&]N9&EN9R!T;R!T:&4@97)R;W(@8V]D92!O<B!A"B`@
M("`@*B`@("`@("`@("`@("`@("!014%2($5R<F]R(&EF('!A<W-E9"!A;B!E
M>&ES=&EN9R!E<G)O<B!T97AT+@H@("`@("H*("`@("`J($!T;V1O("!#:&5C
M:R!W:&EC:"!O9B!T:&5S92!A<F4@86-T=6%L;'D@<F5Q=6ER960@86YD('1R
M:6T@9&]W;B!T:&4*("`@("`J("`@("`@("!L:7-T+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971%<G)O<B@D97)R;W(L("1E<G)O<E]T97AT(#T@)R<I"B`@
M("!["B`@("`@("`@)&5R<F]R(#T@=')I;2@D97)R;W(I.PH*("`@("`@("`O
M*B!!;B!A<G)A>2!O9B!E<G)O<B!C;V1E<R!R971U<FYE9"!B>2!T:&4@9V%T
M97=A>2X@*B\*("`@("`@("`D97)R;W)S(#T@87)R87DH"B`@("`@("`@("`@
M("=!45--4RU.3T%55$A$151!24Q3)R`@("`@("`@/3X@7R@B3F\@=7-E<FYA
M;64@86YD+V]R('!A<W-W;W)D('-E;G0N(BDL"B`@("`@("`@("`@("=!45--
M4RU!551(15)23U(G("`@("`@("`@("`@/3X@7R@B26YC;W)R96-T('5S97)N
M86UE(&%N9"]O<B!P87-S=V]R9"XB*2P*("`@("`@("`@("`@)T%14TU3+4Y/
M35-')R`@("`@("`@("`@("`@("`]/B!?*").;R!M97-S86=E('-U<'!L:65D
M+B(I+`H@("`@("`@("`@("`G05%335,M3D]$15-4)R`@("`@("`@("`@("`@
M(#T^(%\H(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(I+`H@("`@("`@("`@
M("`G05%335,M3D]#4D5$250G("`@("`@("`@("`@(#T^(%\H(DEN<W5F9FEC
M:65N="!C<F5D:70N(BDL"B`@("`@("`@("`@("=!45--4RU.3TY!345355!0
M3$E%1"<@("`@("`@/3X@7R@B3F\@;F%M92!S<&5C:69I960N(BDL"B`@("`@
M("`@("`@("=!45--4RU.3TY534)%4E-54%!,245$)R`@("`@/3X@7R@B3F\@
M;G5M8F5R('-P96-I9FEE9"XB*2P*("`@("`@("`@("`@)T%14TU3+4%$1%)%
M4U-"3T]+15)23U(G("`@("`]/B!?*")4:&5R92!W87,@86X@97)R;W(@<&5R
M9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@
M4&QE87-E('1R>2!A9V%I;B!L871E<BXB*2P*("`@("`@("`@("`@)T%14TU3
M+4-/3E1!0U1)1$524D]2)R`@("`@("`]/B!?*")4:&4@8V]N=&%C="!)1"!N
M=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO
M="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N(BDL"B`@("`@("`@("`@("=!45--
M4RU#3TY404-455!$051%15)23U(G("`@/3X@7R@B5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@
M86=A:6X@;&%T97(N(BDL"B`@("`@("`@("`@("=!45--4RU$25-4241%4E)/
M4B<@("`@("`@("`@/3X@7R@B5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A
M<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U
M;F0@:6X@=&AE(&1A=&%B87-E+B(I+`H@("`@("`@("`@("`G05%335,M3D]$
M25-43$E35%-54%!,245$)R`@(#T^(%\H(E1H92!D:7-T<FEB=71I;VX@;&ES
M="!W87,@;F]T('-P96-I9FEE9"XB*2P*("`@("`@("`@("`@)T%14TU3+4E.
M4U5&1DE#245.5$-2141)5%,G("`]/B!?*"));G-U9F9I8VEE;G0@8W)E9&ET
M('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(I+`H@("`@("`@
M("`@("`G05%335,M3D].54U"15),25-44U504$Q)140G(#T^(%\H(DYU;6)E
M<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N
M(&QI<W0N(BDL"B`@("`@("`@("`@("=!45--4RU$25-43$E35%501$%41452
M4D]2)R`@/3X@7R@B5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D
M:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB*2D[
M"@H@("`@("`@(&EF("AE;7!T>2@D97)R;W)?=&5X="DI('L*("`@("`@("`@
M("`@<F5T=7)N("1E<G)O<G-;)&5R<F]R73L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*"1E
M<G)O<E]T97AT+"`D97)R;W)S6R1E<G)O<ETI*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$;R!T:&4@:'1T<"!C86QL('5S:6YG(&$@=7)L
M('!A<W-E9"!T;R!T:&4@9G5N8W1I;VXN"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7)L("!4
M:&4@=7)L('1O(&-A;&PN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M5&AE(')E<W!O;G-E(&]N('-U8V-E<W,@;W(@4$5!4B!%<G)O<B!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V%L;%523"@D=7)L*0H@("`@
M>PH@("`@("`@("1O<'1I;VYS6R=M971H;V0G72`]("=03U-4)SL*("`@("`@
M("`D;W!T:6]N<ULG=&EM96]U="==(#T@-3L*("`@("`@("`D;W!T:6]N<ULG
M86QL;W=2961I<F5C=',G72`]('1R=64["@H@("`@("`@("1U<FP@/2`H96UP
M='DH)'1H:7,M/E]P87)A;7-;)W-S;"==*2`_("=H='1P.B\O)R`Z("=H='1P
M<SHO+R<I("X@)'1H:7,M/E]B87-E7W5R;"`N("1U<FP["@H@("`@("`@(&EF
M("@A0&EN8VQU9&5?;VYC92`G2%144"]297%U97-T+G!H<"<I('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B36ES<VEN9R!014%2
M('!A8VMA9V4@2%144%]297%U97-T+B(I*3L*("`@("`@("!]"B`@("`@("`@
M)&AT='`@/2`F;F5W($A45%!?4F5Q=65S="@D=7)L+"`D;W!T:6]N<RD["B`@
M("`@("`@0"1H='1P+3YS96YD4F5Q=65S="@I.PH@("`@("`@(&EF("@D:'1T
M<"T^9V5T4F5S<&]N<V5#;V1E*"D@(3T@,C`P*2!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B0V]U;&0@;F]T(&]P
M96X@)7,N(BDL("1U<FPI*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M:'1T<"T^9V5T4F5S<&]N<V5";V1Y*"D["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP````````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#$R,3,P`#$P-3$U-#,S-S4R`#`R-#(S,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@3F5T7U--4U]V;V1A9F]N96ET86QY7W-M='`@0VQA<W,@:6UP;&5M
M96YT<R!T:&4@4TU44"!!4$D@9F]R(&%C8V5S<VEN9R!T:&4*("H@5F]D869O
M;F4@271A;'D@4TU3(&=A=&5W87DN(%5S92!O9B!T:&ES(&=A=&5W87D@<F5Q
M=6ER97,@86X@96UA:6P@86-C;W5N=`H@*B!W:71H(%9O9&%F;VYE($ET86QY
M("AW=W<N,3DP+FET*2X*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-87)K
M;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!#;W!Y<FEG:'0@,C`P,RTR
M,#`V($UA='1E;R!:86UB96QL:2`\;6UZ86UB94!H;W1M86EL+F-O;3X*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`L=B`Q+C$Q+C$P+C@@,C`P-B\P,2\P
M,2`R,3HR.#HR.2!J86X@17AP("0*("H*("H@0&%U=&AO<B!-87)K;R!$:G5K
M:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`875T:&]R($UA='1E;R!:86UB96QL
M:2`\;6UZ86UB94!H;W1M86EL+F-O;3X*("H@0'!A8VMA9V4@3F5T7U--4PH@
M*B\*8VQA<W,@3F5T7U--4U]V;V1A9F]N96ET86QY7W-M='`@97AT96YD<R!.
M971?4TU3('L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F(&-A<&%B:6QI
M=&EE<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A;B!R97!O<G0@=VAI8V@@;W!E
M<F%T:6]N<PH@("`@("H@:70@<W5P<&]R=',@86YD('=H:6-H(&ET(&1O97-N
M)W0N(%!O<W-I8FQE('9A;'5E<R!A<F4Z/'!R93X*("`@("`J("`@875T:"`@
M("`@("`@+2!4:&4@9V%T97=A>2!R97%U:7)E(&%U=&AE;G1I8V%T:6]N(&)E
M9F]R92!S96YD:6YG.PH@("`@("H@("!B871C:"`@("`@("`M($)A=&-H('-E
M;F1I;F<@:7,@<W5P<&]R=&5D.PH@("`@("H@("!M=6QT:2`@("`@("`M(%-E
M;F1I;F<@;V8@;65S<V%G97,@=&\@;75L=&EP;&4@<F5C:7!I96YT<R!I<R!S
M=7!P;W)T960["B`@("`@*B`@(')E8V5I=F4@("`@("T@5VAE=&AE<B!T:&ES
M(&1R:79E<B!I<R!C87!A8FQE(&]F(')E8V5I=FEN9R!335,["B`@("`@*B`@
M(&-R961I="`@("`@("T@27,@=7-E(&]F('1H92!G871E=V%Y(&)A<V5D(&]N
M(&-R961I=',["B`@("`@*B`@(&%D9')E<W-B;V]K("T@07)E(&=A=&5W87D@
M861D<F5S<V)O;VMS('-U<'!O<G1E9#L*("`@("`J("`@;&ES=',@("`@("`@
M+2!'871E=V%Y('-U<'!O<G0@9F]R(&1I<W1R:6)U=&EO;B!L:7-T<RX*("`@
M("`J(#PO<')E/@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1C87!A8FEL:71I97,@/2!A<G)A>2@G875T:"<@("`@("`@(#T^
M(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8F%T8V@G
M("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G;75L=&DG("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<F5C96EV92<@("`@(#T^(&9A;'-E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G8W)E9&ET)R`@("`@(#T^(&9A;'-E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G861D<F5S<V)O;VLG(#T^
M(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;&ES=',G
M("`@("`@(#T^(&9A;'-E*3L*"B`@("`O*BH*("`@("`J(%1H:7,@9G5N8W1I
M;VX@9&]E<R!T:&4@86-T=6%L('-E;F1I;F<@;V8@=&AE(&UE<W-A9V4N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1M97-S86=E("!4:&4@87)R87D@8V]N=&%I;FEN9R!T:&4@
M;65S<V%G92!A;F0@:71S('-E;F0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@<&%R86UE=&5R<RX*("`@("`J($!P87)A;2!S=')I;F<@)'1O("`@
M("`@5&AE(&1E<W1I;F%T:6]N('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!!;B!A<G)A>2!W:71H('1H92!S=6-C97-S('-T871U<R!A
M;F0@861D:71I;VYA;`H@("`@("H@("`@("`@("`@("`@("`@:6YF;W)M871I
M;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S96YD*"8D;65S<V%G92P@)'1O
M*0H@("`@>PH@("`@("`@(&EF("@A0&EN8VQU9&5?;VYC92`G36%I;"YP:'`G
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DUI
M<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(BDI.PH@("`@("`@
M('T*("`@("`@("`D;6%I;&5R(#T@36%I;#HZ9F%C=&]R>2@G;6%I;"<I.PH*
M("`@("`@("`O*B!3:6YC92!T:&ES(&]N;'D@=V]R:W,@9F]R($ET86QI86X@
M;G5M8F5R<RP@=&AI<R!I<R!H87)D8V]D960N("HO"B`@("`@("`@:68@*'!R
M96=?;6%T8V@H)R]>+BH_/#\H7"L_,SDI/RA<9'LQ,'TI/C\O)RP@)'1O+"`D
M;6%T8VAE<RDI('L*("`@("`@("`@("`@)&AE861E<G-;)T9R;VTG72`]("1T
M:&ES+3Y?<&%R86US6R=U<V5R)UT["B`@("`@("`@("`@("1T;R`]("1M871C
M:&5S6S)=("X@)T!S;7,N=F]D869O;F4N:70G.PH@("`@("`@("`@("`D<F5S
M=6QT(#T@)&UA:6QE<BT^<V5N9"@D=&\L("1H96%D97)S+"`D;65S<V%G95LG
M=&5X="==*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*#`L("1R
M97-U;'0M/F=E=$UE<W-A9V4H*2D["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("!R971U<FX@87)R87DH,2P@;G5L;"D["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@87)R
M87DH,"P@7R@B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE
M(&YU;6)E<B(I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!)
M9&5N=&EF:65S('1H:7,@9V%T97=A>2!D<FEV97(@86YD(')E='5R;G,@82!B
M<FEE9B!D97-C<FEP=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!!<G)A>2!O9B!D<FEV97(@:6YF;RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T26YF;R@I"B`@("!["B`@("`@("`@)&EN9F];)VYA;64G72`](%\H(E9O
M9&%F;VYE($ET86QY('9I82!33510(BD["B`@("`@("`@)&EN9F];)V1E<V,G
M72`](%\H(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W87DL
M(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA
M:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y
M,"YI="DN(BD["@H@("`@("`@(')E='5R;B`D:6YF;SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(')E<75I<F5D('!A<F%M971E<G,@9F]R
M('1H:7,@9V%T97=A>2!D<FEV97(N"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@07)R87D@;V8@<F5Q=6ER960@<&%R86UE=&5R<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T4&%R86US*"D*("`@('L*("`@("`@("`D<&%R86US
M(#T@87)R87DH*3L*("`@("`@("`D<&%R86US6R=U<V5R)UT@("`@("`@/2!A
M<G)A>2@G;&%B96PG("`]/B!?*")5<V5R;F%M92(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@(#T^("=T97AT)RD[
M"@H@("`@("`@(')E='5R;B`D<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@<&%R86UE=&5R<R!T:&%T(&-A;B!B92!S970@87,@
M9&5F875L="!F;W(@<V5N9&EN9R!M97-S86=E<PH@("`@("H@=7-I;F<@=&AI
M<R!G871E=V%Y(&1R:79E<B!A;F0@9&ES<&QA>65D('=H96X@<V5N9&EN9R!M
M97-S86=E<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!O
M9B!P87)A;65T97)S('1H870@8V%N(&)E('-E="!A<R!D969A=6QT+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971$969A=6QT4V5N9%!A<F%M<R@I"B`@("![
M"B`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!P87)A;65T97)S(&9O<B!S96YD:6YG(&UE<W-A9V5S
M('5S:6YG('1H:7,@9V%T97=A>2!D<FEV97(L"B`@("`@*B!D:7-P;&%Y960@
M=VAE;B!S96YD:6YG(&UE<W-A9V5S+B!4:&5S92!A<F4@9FEL=&5R960@;W5T
M('5S:6YG('1H90H@("`@("H@9&5F875L="!V86QU97,@<V5T('5P('=H96X@
M8W)E871I;F<@=&AE(&=A=&5W87DN"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@07)R87D@;V8@<F5Q=6ER960@<&%R86UE=&5R<RX*("`@("`J($!T
M;V1O("!7;W5L9"!B92!N:6-E('1O('5S92!A('1I;64O9&%T92!S971U<"!R
M871H97(@=&AA;B!M:6YU=&5S(&9R;VT*("`@("`J("`@("`@("!N;W<@9F]R
M('1H92!D96QI=F5R>2!T:6UE+B!5<&QO860@9FEE;&0@9F]R(')I;F=T;VYE
M<R]L;V=O<S\*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4V5N9%!A<F%M<R@D
M<&%R86US*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!A('-T<FEN9R!R97!R97-E;G1A=&EO
M;B!O9B!A;B!E<G)O<B!C;V1E+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E
M9V5R("1E<G)O<B`@5&AE(&5R<F]R(&-O9&4@=&\@;&]O:R!U<"X*("`@("`J
M($!P87)A;2!S=')I;F<@)'1E>'0@("`@06X@97AI<W1I;F<@97)R;W(@=&5X
M="!T;R!U<V4@=&\@<F%I<V4@80H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("!014%2($5R<F]R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M($$@=&5X='5A;"!M97-S86=E(&-O<G)E<W!O;F1I;F<@=&\@=&AE(&5R<F]R
M(&-O9&4@;W(@80H@("`@("H@("`@("`@("`@("`@("`@4$5!4B!%<G)O<B!I
M9B!P87-S960@86X@97AI<W1I;F<@97)R;W(@=&5X="X*("`@("`J"B`@("`@
M*B!`=&]D;R`@0VAE8VL@=VAI8V@@;V8@=&AE<V4@87)E(&%C='5A;&QY(')E
M<75I<F5D(&%N9"!T<FEM(&1O=VX@=&AE"B`@("`@*B`@("`@("`@;&ES="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T17)R;W(H)&5R<F]R+"`D97)R;W)?
M=&5X="`]("<G*0H@("`@>PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O3F5T+U--4R]W:6Y?:'1T
M<"YP:'``````````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(R,S$W
M`#$P-3$U-#,S-S4R`#`R,C$V-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@3F5T7U--4U]W:6Y?:'1T
M<"!#;&%S<R!I;7!L96UE;G1S('1H92!(5%10($%022!F;W(@86-C97-S:6YG
M('1H92!724X*("H@*'=W=RYW:6YP;&,N8V]M*2!335,@9V%T97=A>2X*("H*
M("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B
M;&\N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T
M"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP+'8@,2XY+C(N,B`R,#`V+S`Q+S`Q
M(#(Q.C(X.C(Y(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R($UA<FMO($1J=6MI
M8R`\;6%R:V]`;V)L;RYC;VT^"B`J($!P86-K86=E($YE=%]335,*("HO"F-L
M87-S($YE=%]335-?=VEN7VAT='`@97AT96YD<R!.971?4TU3('L*"B`@("!V
M87(@)%]B87-E7W5R;"`]("=G871E=V%Y,RYG;S)M;V)I;&4N;F5T.C$P,#,P
M+V=A=&5W87DO=C,O9V%T97=A>2YA<W!X)SL*"B`@("`O*BH*("`@("`J($%N
M(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A
M;B!R97!O<G0@=VAI8V@@;W!E<F%T:6]N<PH@("`@("H@:70@<W5P<&]R=',@
M86YD('=H:6-H(&ET(&1O97-N)W0N(%!O<W-I8FQE('9A;'5E<R!A<F4Z/'!R
M93X*("`@("`J("`@875T:"`@("`@("`@+2!4:&4@9V%T97=A>2!R97%U:7)E
M<R!A=71H96YT:6-A=&EO;B!B969O<F4@<V5N9&EN9SL*("`@("`J("`@8F%T
M8V@@("`@("`@+2!"871C:"!S96YD:6YG(&ES('-U<'!O<G1E9#L*("`@("`J
M("`@;75L=&D@("`@("`@+2!396YD:6YG(&]F(&UE<W-A9V5S('1O(&UU;'1I
M<&QE(')E8VEP:65N=',@:7,@<W5P<&]R=&5D.PH@("`@("H@("!R96-E:79E
M("`@("`M(%=H971H97(@=&AI<R!D<FEV97(@:7,@8V%P86)L92!O9B!R96-E
M:79I;F<@4TU3.PH@("`@("H@("!C<F5D:70@("`@("`M($ES('5S92!O9B!T
M:&4@9V%T97=A>2!B87-E9"!O;B!C<F5D:71S.PH@("`@("H@("!A9&1R97-S
M8F]O:R`M($%R92!G871E=V%Y(&%D9')E<W-B;V]K<R!S=7!P;W)T960["B`@
M("`@*B`@(&QI<W1S("`@("`@("T@1V%T97=A>2!S=7!P;W)T(&9O<B!D:7-T
M<FEB=71I;VX@;&ES=',N"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D8V%P86)I;&ET:65S(#T@87)R
M87DH)V%U=&@G("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V)A=&-H)R`@("`@("`]/B`Q,#`L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=M=6QT:2<@("`@("`@/3X@=')U92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E8V5I=F4G("`@("`]/B!F
M86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-R961I="<@
M("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V%D9')E<W-B;V]K)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VQI<W1S)R`@("`@("`]/B!F86QS92D["@H@("`@+RHJ"B`@
M("`@*B!4:&ES(&9U;F-T:6]N(&1O97,@=&AE(&%C='5A;"!S96YD:6YG(&]F
M('1H92!M97-S86=E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D;65S<V%G92`@5&AE(&%R<F%Y
M(&-O;G1A:6YI;F<@=&AE(&UE<W-A9V4@86YD(&ET<R!S96YD"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E<G,N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1T;R`@("`@(%1H92!D97-T:6YA=&EO;B!S=')I;F<N"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@=VET:"!T:&4@
M<W5C8V5S<R!S=&%T=7,@86YD(&%D9&ET:6]N86P*("`@("`J("`@("`@("`@
M("`@("`@(&EN9F]R;6%T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5N
M9"@F)&UE<W-A9V4L("1T;RD*("`@('L*("`@("`@("`O*B!3=&%R="!T:&4@
M6$U,+B`J+PH@("`@("`@("1X;6P@/2`G/%--4TU%4U-!1T4^/%1%6%0^)R`N
M("1M97-S86=E6R=T97AT)UT@+B`G/"]415A4/B<["@H@("`@("`@("\J($-H
M96-K(&EF('-O=7)C92!F<F]M(&ES('-E="X@*B\*("`@("`@("!I9B`H(65M
M<'1Y*"1M97-S86=E6R=S96YD7W!A<F%M<R==6R=F<F]M)UTI*2!["B`@("`@
M("`@("`@("1X;6P@+CT@)SQ33U520T5?041$4CXG("X@)&UE<W-A9V5;)W-E
M;F1?<&%R86US)UU;)V9R;VTG72`N("<\+U-/55)#15]!1$12/B<["B`@("`@
M("`@?0H*("`@("`@("`O*B!,;V]P('1H<F]U9V@@<F5C:7!I96YT<R!A;F0@
M9&\@<V]M92!M:6YI;6%L('9A;&ED:71Y(&-H96-K:6YG+B`J+PH@("`@("`@
M(&EF("AI<U]A<G)A>2@D=&\I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1T
M;R!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@(&EF("AP<F5G
M7VUA=&-H*"<O7BXJ/SP_*%PK/UQD>S<L?2DH/GPD*2\G+"`D=F%L+"`D;6%T
M8VAE<RDI('L*("`@("`@("`@("`@("`@("`@("`D=&];)&ME>5T@/2`D;6%T
M8VAE<ULQ73L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@+RH@268@82!R96-I<&EE;G0@:7,@:6YV86QI9"!S=&]P(&%L
M;"!F=7)T:&5R('-E;F1I;F<N("HO"B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N(&%R<F%Y*#`L('-P<FEN=&8H7R@B26YV86QI9"!R96-I<&EE;G0Z(%PB
M)7-<(B(I+"`D=F%L*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1T;R`](&EM<&QO9&4H)SPO1$535$E.051)3TY?
M041$4CX\1$535$E.051)3TY?041$4CXG+"`D=&\I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7BXJ/SP_*%PK/UQD
M>S<L?2DH/GPD*2\G+"`D=&\L("1M871C:&5S*2D@>PH@("`@("`@("`@("`@
M("`@)'1O(#T@)&UA=&-H97-;,5T["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("!R971U<FX@87)R87DH,"P@<W!R:6YT9BA?*"));G9A
M;&ED(')E8VEP:65N=#H@7"(E<UPB(BDL("1T;RDI.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@("1X;6P@+CT@)SQ$15-424Y!5$E/3E]!1$12
M/B<@+B`D=&\@+B`G/"]$15-424Y!5$E/3E]!1$12/B<["@H@("`@("`@("\J
M(%1/1$\Z(%-H;W5L9"!W92!H879E('-O;65T:&EN9R!M;W)E(&EN=&5L;&EG
M96YT/R!#;W5L9"!A8W1U86QL>0H@("`@("`@("`J(&)E('!A<G0@;V8@<V5N
M9"!P87)A;65T97)S+B`J+PH@("`@("`@("1X;6P@+CT@)SQ44D%.4T%#5$E/
M3DE$/B<@+B!T:6UE*"D@+B`G/"]44D%.4T%#5$E/3DE$/B<["@H@("`@("`@
M("\J(%1/1$\Z($%D9"!S;VUE(&5X=')A('1A9W,L(&IU<W0@=&%C:V5D(&]N
M(&9O<B!N;W<N("HO"B`@("`@("`@)'AM;"`N/2`G/%194$5)1#XR/"]465!%
M240^/%-%4E9)0T5)1#XQ/"]315)624-%240^/"]335--15-304=%/B<["@H@
M("`@("`@("\J(%-E;F0@=&AI<R!M97-S86=E+B`J+PH@("`@("`@("1R97-P
M;VYS92`]("1T:&ES+3Y?<&]S="@D>&UL*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S<&]N<V4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M(&%R<F%Y*#`L("1R97-P;VYS92T^9V5T365S<V%G92@I*3L*("`@("`@("!]
M"@H@("`@("`@("\J(%!A<G-E('1H92!R97-P;VYS92P@8VAE8VL@9F]R(&YE
M=R!L:6YE<R!I;B!C87-E(&]F(&UU;'1I<&QE"B`@("`@("`@("H@<F5C:7!I
M96YT<RX@*B\*("`@("`@("`D;&EN97,@/2!E>'!L;V1E*")<;B(L("1R97-P
M;VYS92D["B`@("`@("`@)')E<W!O;G-E(#T@87)R87DH*3L*"B`@("`@("`@
M:68@*&-O=6YT*"1L:6YE<RD@/B`Q*2!["B`@("`@("`@("`@("\J($UU;'1I
M<&QE(')E8VEP:65N=',N("HO"B`@("`@("`@("`@(&9O<F5A8V@@*"1L:6YE
M<R!A<R`D;&EN92D@>PH@("`@("`@("`@("`@("`@)'!A<G1S(#T@97AP;&]D
M92@G5&\Z)RP@)&QI;F4I.PH@("`@("`@("`@("`@("`@)')E8VEP:65N="`]
M('1R:6TH)'!A<G1S6S%=*3L*("`@("`@("`@("`@("`@(&EF("@D;&EN97-;
M,%T@/3T@)T%14TU3+4]+)RD@>PH@("`@("`@("`@("`@("`@("`@("1R97-P
M;VYS95LD<F5C:7!I96YT72`](&%R<F%Y*#$L(&YU;&PI.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<F5S<&]N<V5;
M)')E8VEP:65N=%T@/2!A<G)A>2@P+"`D;&EN97-;,%TI.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@+RH@4VEN9VQE(')E8VEP:65N="X@*B\*("`@("`@("`@("`@:68@
M*"1L:6YE<ULP72`]/2`G05%335,M3TLG*2!["B`@("`@("`@("`@("`@("`D
M<F5S<&]N<V5;)'1O72`](&%R<F%Y*#$L(&YU;&PI.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)')E<W!O;G-E6R1T;UT@/2!A<G)A
M>2@P+"`D;&EN97-;,%TI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)')E<W!O;G-E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M261E;G1I9FEE<R!T:&ES(&=A=&5W87D@9')I=F5R(&%N9"!R971U<FYS(&$@
M8G)I968@9&5S8W)I<'1I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>2`@07)R87D@;V8@9')I=F5R(&EN9F\N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$EN9F\H*0H@("`@>PH@("`@("`@("1I;F9O6R=N86UE)UT@/2!?*")7
M24X@=FEA($A45%`B*3L*("`@("`@("`D:6YF;ULG9&5S8R==(#T@7R@B5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T
M:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE
M($A45%`@05!)(BD["@H@("`@("`@(')E='5R;B`D:6YF;SL*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE(')E<75I<F5D('!A<F%M971E<G,@
M9F]R('1H:7,@9V%T97=A>2!D<FEV97(N(%1H92!S971T86)L90H@("`@("H@
M<&%R86UE=&5R<R!F;W(@=&AI<R!G871E=V%Y(&%R93H*("`@("`J("`@+2!U
M<V5R("`@("`@("`@("`@+2!4:&4@=7-E<FYA;64@9F]R(&%U=&AE;G1I8V%T
M:6]N(&]N('1H92!G871E=V%Y.PH@("`@("H@("`M('!A<W-W;W)D("`@("`@
M("`M(%1H92!P87-S=V]R9"!F;W(@875T:&5N=&EC871I;VX@;VX@=&AE(&=A
M=&5W87D["B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@07)R87D@;V8@
M<F5Q=6ER960@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M4&%R86US*"D*("`@('L*("`@("`@("`D<&%R86US(#T@87)R87DH*3L*("`@
M("`@("`D<&%R86US6R=U<V5R)UT@("`@(#T@87)R87DH)VQA8F5L)R`]/B!?
M*")5<V5R;F%M92(I+"`G='EP92<@/3X@)W1E>'0G*3L*("`@("`@("`D<&%R
M86US6R=P87-S=V]R9"==(#T@87)R87DH)VQA8F5L)R`]/B!?*")087-S=V]R
M9"(I+"`G='EP92<@/3X@)W1E>'0G*3L*"B`@("`@("`@<F5T=7)N("1P87)A
M;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!P87)A;65T
M97)S('1H870@8V%N(&)E('-E="!A<R!D969A=6QT(&9O<B!S96YD:6YG(&UE
M<W-A9V5S"B`@("`@*B!U<VEN9R!T:&ES(&=A=&5W87D@9')I=F5R(&%N9"!D
M:7-P;&%Y960@=VAE;B!S96YD:6YG(&UE<W-A9V5S+@H@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@($%R<F%Y(&]F('!A<F%M971E<G,@=&AA="!C86X@
M8F4@<V5T(&%S(&1E9F%U;'0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1E
M9F%U;'1396YD4&%R86US*"D*("`@('L*("`@("`@("`D<&%R86US(#T@87)R
M87DH*3L*("`@("`@("`D<&%R86US6R=F<F]M)UT@/2!A<G)A>2@*("`@("`@
M("`@("`@)VQA8F5L)R`]/B!?*")3;W5R8V4@861D<F5S<R(I+`H@("`@("`@
M("`@("`G='EP92<@/3X@)W1E>'0G*3L*"B`@("`@("`@)'!A<F%M<ULG8V]S
M=%]I9"==(#T@87)R87DH"B`@("`@("`@("`@("=L86)E;"<@/3X@7R@B0V]S
M="!)1"(I+`H@("`@("`@("`@("`G='EP92<@/3X@)VEN="<I.PH*("`@("`@
M("!R971U<FX@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE('!A<F%M971E<G,@9F]R('-E;F1I;F<@;65S<V%G97,@=7-I;F<@
M=&AI<R!G871E=V%Y(&1R:79E<BP*("`@("`J(&1I<W!L87EE9"!W:&5N('-E
M;F1I;F<@;65S<V%G97,N(%1H97-E(&%R92!F:6QT97)E9"!O=70@=7-I;F<@
M=&AE"B`@("`@*B!D969A=6QT('9A;'5E<R!S970@=7`@=VAE;B!C<F5A=&EN
M9R!T:&4@9V%T97=A>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!
M<G)A>2!O9B!R97%U:7)E9"!P87)A;65T97)S+@H@("`@("H@0'1O9&\@(%=O
M=6QD(&)E(&YI8V4@=&\@=7-E(&$@=&EM92]D871E('-E='5P(')A=&AE<B!T
M:&%N(&UI;G5T97,@9G)O;0H@("`@("H@("`@("`@(&YO=R!F;W(@=&AE(&1E
M;&EV97)Y('1I;64N(%5P;&]A9"!F:65L9"!F;W(@<FEN9W1O;F5S+VQO9V]S
M/PH@("`@("HO"B`@("!F=6YC=&EO;B!G971396YD4&%R86US*"1P87)A;7,I
M"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1P87)A;7-;)V9R;VTG72DI('L*
M("`@("`@("`@("`@)'!A<F%M<ULG9G)O;2==(#T@87)R87DH"B`@("`@("`@
M("`@("`@("`G;&%B96PG(#T^(%\H(E-O=7)C92!A9&1R97-S(BDL"B`@("`@
M("`@("`@("`@("`G='EP92<@/3X@)W1E>'0G*3L*("`@("`@("!]"@H@("`@
M("`@(&EF("AE;7!T>2@D<&%R86US6R=C;W-T7VED)UTI*2!["B`@("`@("`@
M("`@("1P87)A;7-;)V1E;&EV7W1I;64G72`](&%R<F%Y*`H@("`@("`@("`@
M("`@("`@)VQA8F5L)R`]/B!?*")#;W-T($E$(BDL"B`@("`@("`@("`@("`@
M("`G='EP92<@/3X@)VEN="<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<W1R
M:6YG(')E<')E<V5N=&%T:6]N(&]F(&%N(&5R<F]R(&-O9&4N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&5R<F]R("!4:&4@97)R;W(@8V]D92!T
M;R!L;V]K('5P+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@("!!;B!E
M>&ES=&EN9R!E<G)O<B!T97AT('1O('5S92!T;R!R86ES92!A"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@(%!%05(@17)R;W(N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@02!T97AT=6%L(&UE<W-A9V4@8V]R<F5S<&]N
M9&EN9R!T;R!T:&4@97)R;W(@8V]D92!O<B!A"B`@("`@*B`@("`@("`@("`@
M("`@("!014%2($5R<F]R(&EF('!A<W-E9"!A;B!E>&ES=&EN9R!E<G)O<B!T
M97AT+@H@("`@("H*("`@("`J($!T;V1O("!#:&5C:R!W:&EC:"!O9B!T:&5S
M92!A<F4@86-T=6%L;'D@<F5Q=6ER960@86YD('1R:6T@9&]W;B!T:&4*("`@
M("`J("`@("`@("!L:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971%<G)O
M<B@D97)R;W(L("1E<G)O<E]T97AT(#T@)R<I"B`@("!["B`@("`@("`@)&5R
M<F]R(#T@=')I;2@D97)R;W(I.PH*("`@("`@("`O*B!!;B!A<G)A>2!O9B!E
M<G)O<B!C;V1E<R!R971U<FYE9"!B>2!T:&4@9V%T97=A>2X@*B\*("`@("`@
M("`D97)R;W)S(#T@87)R87DH"B`@("`@("`@("`@("=!45--4RU.3T%55$A$
M151!24Q3)R`@("`@("`@/3X@7R@B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W
M;W)D('-E;G0N(BDL"B`@("`@("`@("`@("=!45--4RU$25-43$E35%501$%4
M14524D]2)R`@/3X@7R@B5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H
M92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB
M*2D["@H@("`@("`@(&EF("AE;7!T>2@D97)R;W)?=&5X="DI('L*("`@("`@
M("`@("`@<F5T=7)N("1E<G)O<G-;)&5R<F]R73L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F
M*"1E<G)O<E]T97AT+"`D97)R;W)S6R1E<G)O<ETI*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!$;R!T:&4@:'1T<"!C86QL('5S:6YG(&$@
M=7)L('!A<W-E9"!T;R!T:&4@9G5N8W1I;VXN"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D>&UL
M("!4:&4@6$U,(&EN9F]R;6%T:6]N('!A<W-E9"!T;R!T:&4@9V%T97=A>2X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@<F5S<&]N<V4@;VX@
M<W5C8V5S<R!O<B!014%2($5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]P;W-T*"1X;6PI"B`@("!["B`@("`@("`@)&]P=&EO;G-;
M)VUE=&AO9"==(#T@)U!/4U0G.PH@("`@("`@("1O<'1I;VYS6R=T:6UE;W5T
M)UT@/2`U.PH@("`@("`@("1O<'1I;VYS6R=A;&QO=U)E9&ER96-T<R==(#T@
M=')U93L*"B`@("`@("`@+RH@5W)A<"!T:&4@>&UL('=I=&@@=&AE('-T86YD
M87)D('1A9W,N("HO"B`@("`@("`@)'AM;"`]("<\/WAM;"!V97)S:6]N/2(Q
M+C`B('-T86YD86QO;F4](FYO(C\^/"%$3T-465!%(%=)3E]$14Q)5D5265\R
M7U--4R!365-414T@(G=I;F)O=6YD7VUE<W-A9V5S7W8Q+F1T9"(^/%=)3E]$
M14Q)5D5265\R7U--4SXG("X@)'AM;"`N("<\+U=)3E]$14Q)5D5265\R7U--
M4SXG.PH*("`@("`@("!I9B`H(4!I;F-L=61E7V]N8V4@)TA45%`O4F5Q=65S
M="YP:'`G*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB*2D["B`@
M("`@("`@?0H@("`@("`@("1H='1P(#T@)FYE=R!(5%107U)E<75E<W0H)'1H
M:7,M/E]B87-E7W5R;"P@)&]P=&EO;G,I.PH*("`@("`@("`O*B!!9&0@=&AE
M(&%U=&AE;G1I8V%T:6]N('9A;'5E<R!T;R!03U-4+B`J+PH@("`@("`@("1H
M='1P+3YA9&10;W-T1&%T82@G57-E<B<L("1T:&ES+3Y?<&%R86US6R=U<V5R
M)UTI.PH@("`@("`@("1H='1P+3YA9&10;W-T1&%T82@G4&%S<W=O<F0G+"`D
M=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72D["@H@("`@("`@("\J($%D9"!T
M:&4@6$U,(&%N9"!S96YD('1H92!R97%U97-T+B`J+PH@("`@("`@("1H='1P
M+3YA9&10;W-T1&%T82@G5TE.7UA-3"<L("1X;6PI.PH@("`@("`@($`D:'1T
M<"T^<V5N9%)E<75E<W0H*3L*("`@("`@("!I9B`H)&AT='`M/F=E=%)E<W!O
M;G-E0V]D92@I("$](#(P,"D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-O=6QD(&YO="!O<&5N("5S+B(I+"`D
M=&AI<RT^7V)A<V5?=7)L*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&AT='`M/F=E=%)E<W!O;G-E0F]D>2@I.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TYE="]335,N<&AP````````````````````````````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`R-3(Q-``Q,#4Q-30S,S<U,@`P,C`S,S``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PH*+RHJ"B`J($YE=%]335,@
M0VQA<W,*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-87)K;R!$:G5K:6,@
M/&UA<FMO0&]B;&\N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO3F5T7U--4R]335,N<&AP+'8@,2XQ,"XQ,"XQ,"`R,#`V+S`Q
M+S`Q(#(Q.C(X.C(X(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R("!-87)K;R!$
M:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`<&%C:V%G92!.971?4TU3"B`J
M+PIC;&%S<R!.971?4TU3('L*"B`@("`O*BH*("`@("`J($$@:&%S:"!C;VYT
M86EN:6YG(&%N>2!P87)A;65T97)S(&9O<B!T:&4@8W5R<F5N="!G871E=V%Y
M(&1R:79E<BX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D7W!A<F%M<R`](&%R<F%Y*"D["@H@("`@=F%R("1?875T:"`](&YU
M;&P["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@<&%R86UE=&5R<R!N965D960@
M9F]R('1H:7,@9V%T97=A>2!D<FEV97(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M($YE=%]335,H)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M
M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!A(&QI<W0@;V8@879A:6QA8FQE(&=A=&5W87D@9')I=F5R<RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B!A=F%I;&%B
M;&4@9')I=F5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1')I=F5R<R@I
M"B`@("!["B`@("`@("`@<W1A=&EC("1D<FEV97)S(#T@87)R87DH*3L*("`@
M("`@("!I9B`H(65M<'1Y*"1D<FEV97)S*2D@>PH@("`@("`@("`@("!R971U
M<FX@)&1R:79E<G,["B`@("`@("`@?0H*("`@("`@("`D9')I=F5R<R`](&%R
M<F%Y*"D["@H@("`@("`@(&EF("@D9')I=F5R7V1I<B`](&]P96YD:7(H9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+U--4R\G*2D@>PH@("`@("`@("`@("!W:&EL
M92`H9F%L<V4@(3T]("@D9FEL92`](')E861D:7(H)&1R:79E<E]D:7(I*2D@
M>PH@("`@("`@("`@("`@("`@+RH@2&ED92!D;W0@9FEL97,@86YD(&YO;B`N
M<&AP(&9I;&5S+B`J+PH@("`@("`@("`@("`@("`@:68@*'-U8G-T<B@D9FEL
M92P@,"P@,2D@(3T@)RXG("8F('-U8G-T<B@D9FEL92P@+30I(#T]("<N<&AP
M)RD@>PH@("`@("`@("`@("`@("`@("`@("1D<FEV97(@/2!S=6)S='(H)&9I
M;&4L(#`L("TT*3L*("`@("`@("`@("`@("`@("`@("`D9')I=F5R7VEN9F\@
M/2!.971?4TU3.CIG971'871E=V%Y26YF;R@D9')I=F5R*3L*("`@("`@("`@
M("`@("`@("`@("`D9')I=F5R<ULD9')I=F5R72`]("1D<FEV97)?:6YF;ULG
M;F%M92==.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&-L;W-E9&ER*"1D<FEV97)?9&ER*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D9')I=F5R<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@:6YF;W)M871I;VX@;VX@82!G871E=V%Y+"!S=6-H(&%S(&YA;64@
M86YD(&$@8G)I968@9&5S8W)I<'1I;VXL"B`@("`@*B!F<F]M('1H92!D<FEV
M97(@<W5B8VQA<W,@9V5T26YF;R@I(&9U;F-T:6]N+@H@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@($%N(&%R<F%Y(&]F(&5X=')A(&EN9F]R;6%T:6]N
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971'871E=V%Y26YF;R@D9V%T97=A
M>2D*("`@('L*("`@("`@("!S=&%T:6,@)&EN9F\@/2!A<G)A>2@I.PH@("`@
M("`@(&EF("AI<W-E="@D:6YF;ULD9V%T97=A>5TI*2!["B`@("`@("`@("`@
M(')E='5R;B`D:6YF;ULD9V%T97=A>5T["B`@("`@("`@?0H*("`@("`@("!R
M97%U:7)E7V]N8V4@)TYE="]335,O)R`N("1G871E=V%Y("X@)RYP:'`G.PH@
M("`@("`@("1C;&%S<R`]("=.971?4TU37R<@+B`D9V%T97=A>3L*("`@("`@
M("`D:6YF;ULD9V%T97=A>5T@/2!C86QL7W5S97)?9G5N8RAA<G)A>2@D8VQA
M<W,L("=G971);F9O)RDI.PH*("`@("`@("!R971U<FX@)&EN9F];)&=A=&5W
M87E=.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!P87)A;65T97)S
M(&9O<B!A(&=A=&5W87D@9G)O;2!T:&4@9')I=F5R('-U8F-L87-S(&=E=%!A
M<F%M<R@I"B`@("`@*B!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("!4:&4@;F%M92!O9B!T:&4@9V%T97=A>2!D<FEV97(@9F]R('=H
M:6-H('1O(')E='5R;B!T:&4*("`@("`J("`@("`@("`@("`@("`@('!A<F%M
M971E<G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@
M;V8@97AT<F$@:6YF;W)M871I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$=A=&5W87E087)A;7,H)&=A=&5W87DI"B`@("!["B`@("`@("`@<W1A=&EC
M("1P87)A;7,@/2!A<G)A>2@I.PH@("`@("`@(&EF("AI<W-E="@D<&%R86US
M6R1G871E=V%Y72DI('L*("`@("`@("`@("`@<F5T=7)N("1P87)A;7-;)&=A
M=&5W87E=.PH@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E("=.970O
M4TU3+R<@+B`D9V%T97=A>2`N("<N<&AP)SL*("`@("`@("`D8VQA<W,@/2`G
M3F5T7U--4U\G("X@)&=A=&5W87D["B`@("`@("`@)'!A<F%M<ULD9V%T97=A
M>5T@/2!C86QL7W5S97)?9G5N8RAA<G)A>2@D8VQA<W,L("=G971087)A;7,G
M*2D["@H@("`@("`@(')E='5R;B`D<&%R86US6R1G871E=V%Y73L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@<V5N9"!P87)A;65T97)S(&9O<B!A
M(&=A=&5W87D@9G)O;2!T:&4@9')I=F5R('-U8F-L87-S"B`@("`@*B!G971$
M969A=6QT4V5N9%!A<F%M<R@I9G5N8W1I;VXN(%1H97-E(&%R92!P87)A;65T
M97)S('=H:6-H(&%R92!A=F%I;&%B;&4*("`@("`J('1O('1H92!U<V5R(&1U
M<FEN9R!S96YD:6YG+"!S=6-H(&%S('-E='1I;F<@82!T:6UE(&9O<B!D96QI
M=F5R>2P@;W(@='EP90H@("`@("H@;V8@4TU3("AN;W)M86P@=&5X="!O<B!F
M;&%S:"DL(&]R('-O=7)C92!A9&1R97-S+"!E=&,N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`@5&AE(&YA;64@;V8@=&AE(&=A=&5W87D@9')I=F5R
M(&9O<B!W:&EC:"!T;R!R971U<FX@=&AE"B`@("`@*B`@("`@("`@("`@("`@
M("!S96YD('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>2`@06X@87)R87D@;V8@879A:6QA8FQE('-E;F0@<&%R86UE=&5R<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T1&5F875L=%-E;F1087)A;7,H)&=A=&5W
M87DI"B`@("!["B`@("`@("`@<W1A=&EC("1P87)A;7,@/2!A<G)A>2@I.PH@
M("`@("`@(&EF("AI<W-E="@D<&%R86US6R1G871E=V%Y72DI('L*("`@("`@
M("`@("`@<F5T=7)N("1P87)A;7-;)&=A=&5W87E=.PH@("`@("`@('T*"B`@
M("`@("`@<F5Q=6ER95]O;F-E("=.970O4TU3+R<@+B`D9V%T97=A>2`N("<N
M<&AP)SL*("`@("`@("`D8VQA<W,@/2`G3F5T7U--4U\G("X@)&=A=&5W87D[
M"B`@("`@("`@)'!A<F%M<ULD9V%T97=A>5T@/2!C86QL7W5S97)?9G5N8RAA
M<G)A>2@D8VQA<W,L("=G971$969A=6QT4V5N9%!A<F%M<R<I*3L*"B`@("`@
M("`@<F5T=7)N("1P87)A;7-;)&=A=&5W87E=.PH@("`@?0H*("`@("\J*@H@
M("`@("H@475E<GD@=&AE(&-U<G)E;G0@1V%T97=A>2!O8FIE8W0@=&\@9FEN
M9"!O=70@:68@:70@<W5P<&]R=',@=&AE(&=I=F5N"B`@("`@*B!C87!A8FEL
M:71Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-A<&%B:6QI='D@
M(%1H92!C87!A8FEL:71Y('1O('1E<W0@9F]R+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%=H971H97(@;W(@;F]T('1H92!C87!A8FEL:71Y(&ES
M('-U<'!O<G1E9"!O<B!A;GD@;W1H97(*("`@("`J("`@("`@("`@("`@("`@
M('9A;'5E('1H870@=&AE(&-A<&%B:6QI='D@=VES:&5S('1O(')E<&]R="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@:&%S0V%P86)I;&ET>2@D8V%P86)I;&ET
M>2D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3YC87!A8FEL:71I
M97-;)&-A<&%B:6QI='E=*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/F-A<&%B:6QI=&EE<ULD8V%P86)I;&ET>5T["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($%U=&AE;G1I
M8V%T97,@86=A:6YS="!T:&4@9V%T97=A>2!I9B!R97%U:7)E9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@4$5!
M4B!%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A=71H
M96YT:6-A=&4H*0H@("`@>PH@("`@("`@("\J($1O(&%U=&AE;G1I8V%T:6]N
M(&9O<B!T:&ES(&=A=&5W87D@:68@9')I=F5R(')E<75I<F5S(&ET+B`J+PH@
M("`@("`@(&EF("@D=&AI<RT^:&%S0V%P86)I;&ET>2@G875T:"<I*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?875T:"`]("1T:&ES+3Y?875T:&5N=&EC871E
M*"D["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V%U=&@["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4V5N9',@82!M97-S86=E('1O(&]N92!O<B!M;W)E(')E8VEP:65N=',N($AA
M;F1S(&]F9B!T:&4@86-T=6%L('-E;F1I;F<*("`@("`J('1O('1H92!G871E
M=V%Y(&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&UE<W-A
M9V4@(%1H92!M97-S86=E('1O(&)E('-E;G0L('=H:6-H(&ES(&-O;7!O<V5D
M(&]F.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`\<')E/@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@(&ED("`@+2!!('5N:7%U92!)
M1"!F;W(@=&AE(&UE<W-A9V4["B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@=&\@("`M($%N(&%R<F%Y(&]F(')E8VEP:65N=',["B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@=&5X="`M(%1H92!T97AT(&]F('1H
M92!M97-S86=E.PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`\+W!R
M93X*("`@("`J"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O
M;B!S=6-C97-S(&]R(%!%05(@17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5N9"@F)&UE<W-A9V4I"B`@("!["B`@("`@("`@+RH@
M075T:&5N=&EC871E+B`J+PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3YA=71H
M96YT:6-A=&4H*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]A=71H.PH@("`@("`@('T*"B`@("`@("`@+RH@36%K92!S
M=7)E('1H92!R96-I<&EE;G1S(&%R92!I;B!A;B!A<G)A>2X@*B\*("`@("`@
M("!I9B`H(6ES7V%R<F%Y*"1M97-S86=E6R=T;R==*2D@>PH@("`@("`@("`@
M("`D;65S<V%G95LG=&\G72`](&%R<F%Y*"1M97-S86=E6R=T;R==*3L*("`@
M("`@("!]"@H@("`@("`@("\J($%R<F%Y('1O('-T;W)E(&5A8V@@<V5N9"X@
M*B\*("`@("`@("`D<V5N9',@/2!A<G)A>2@I.PH*("`@("`@("`O*B!)9B!G
M871E=V%Y('-U<'!O<G1S(&)A=&-H('-E;F1I;F<L('!R969E<F5N8V4@:7,@
M9VEV96X@=&\@=&AI<PH@("`@("`@("`J(&UE=&AO9"X@*B\*("`@("`@("!I
M9B`H)&UA>%]P97)?8F%T8V@@/2`D=&AI<RT^:&%S0V%P86)I;&ET>2@G8F%T
M8V@G*2D@>PH@("`@("`@("`@("`O*B!3<&QI="!U<"!T:&4@<F5C:7!I96YT
M<R!I;B!T:&4@;6%X(')E8VEP:65N=',@<&5R(&)A=&-H(&%S"B`@("`@("`@
M("`@("`J('-U<'!O<G1E9"!B>2!G871E=V%Y+B`J+PH@("`@("`@("`@("`D
M:4UA>"`](&-O=6YT*"1M97-S86=E6R=T;R==*3L*("`@("`@("`@("`@)&)A
M=&-H97,@/2!C96EL*"1I36%X("\@)&UA>%]P97)?8F%T8V@I.PH*("`@("`@
M("`@("`@+RH@3&]O<"!T:')O=6=H('1H92!B871C:&5S(&%N9"!C;VUP;W-E
M(&UE<W-A9V5S('1O(&)E('-E;G0N("HO"B`@("`@("`@("`@(&9O<B`H)&(@
M/2`P.R`D8B`\("1B871C:&5S.R`D8BLK*2!["B`@("`@("`@("`@("`@("`D
M<F5C:7!I96YT<R`](&%R<F%Y7W-L:6-E*"1M97-S86=E6R=T;R==+"`H)&(@
M*B`D;6%X7W!E<E]B871C:"DL("1M87A?<&5R7V)A=&-H*3L*("`@("`@("`@
M("`@("`@("1R97-P;VYS92`]("1T:&ES+3Y?<V5N9"@D;65S<V%G92P@)')E
M8VEP:65N=',I.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)')E8VEP:65N
M=',@87,@)')E8VEP:65N="D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D
M<F5S<&]N<V5;)')E8VEP:65N=%U;,%T@/3T@,2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`O*B!-97-S86=E('=A<R!S96YT+"!S=&]R92!R96UO=&4@
M:60N("HO"B`@("`@("`@("`@("`@("`@("`@("`@("1R96UO=&5?:60@/2`D
M<F5S<&]N<V5;)')E8VEP:65N=%U;,5T["B`@("`@("`@("`@("`@("`@("`@
M("`@("1E<G)O<B`](&YU;&P["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`@("`@+RH@365S<V%G92!F86EL960L
M('-T;W)E(&5R<F]R(&-O9&4N("HO"B`@("`@("`@("`@("`@("`@("`@("`@
M("1R96UO=&5?:60@/2!N=6QL.PH@("`@("`@("`@("`@("`@("`@("`@("`D
M97)R;W(@/2`D<F5S<&]N<V5;)')E8VEP:65N=%U;,5T["B`@("`@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("`O*B!3=&]R92!T:&4@
M<V5N9',N("HO"B`@("`@("`@("`@("`@("`@("`@)'-E;F1S6UT@/2!A<G)A
M>2@G;65S<V%G95]I9"<@/3X@)&UE<W-A9V5;)VED)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5M;W1E7VED)R`@/3X@)')E
M;6]T95]I9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=R96-I<&EE;G0G("`]/B`D<F5C:7!I96YT+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V5R<F]R)R`@("`@(#T^("1E<G)O<BD[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`O*B!.;R!B871C:"!S96YD:6YG(&%V86EL86)L
M92P@:G5S="!L;V]P('1H<F]U9V@@86QL(')E8VEP:65N=',*("`@("`@("`@
M("`@("H@86YD('-E;F0@82!M97-S86=E(&9O<B!E86-H(&]N92X@*B\*("`@
M("`@("`@("`@9F]R96%C:"`H)&UE<W-A9V5;)W1O)UT@87,@)')E8VEP:65N
M="D@>PH@("`@("`@("`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/E]S96YD
M*"1M97-S86=E+"`D<F5C:7!I96YT*3L*("`@("`@("`@("`@("`@(&EF("@D
M<F5S<&]N<V5;,%T@/3T@,2D@>PH@("`@("`@("`@("`@("`@("`@("\J($UE
M<W-A9V4@=V%S('-E;G0L('-T;W)E(')E;6]T92!I9"!I9B!A;GDN("HO"B`@
M("`@("`@("`@("`@("`@("`@)')E;6]T95]I9"`]("AI<W-E="@D<F5S<&]N
M<V5;,5TI(#\@)')E<W!O;G-E6S%=(#H@;G5L;"D["B`@("`@("`@("`@("`@
M("`@("`@)&5R<F]R(#T@;G5L;#L*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@+RH@365S<V%G92!F86EL960L('-T;W)E
M(&5R<F]R(&-O9&4N("HO"B`@("`@("`@("`@("`@("`@("`@)')E;6]T95]I
M9"`](&YU;&P["B`@("`@("`@("`@("`@("`@("`@)&5R<F]R(#T@)')E<W!O
M;G-E6S%=.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\J
M(%-T;W)E('1H92!S96YD<RX@*B\*("`@("`@("`@("`@("`@("1S96YD<UM=
M(#T@87)R87DH)VUE<W-A9V5?:60G(#T^("1M97-S86=E6R=I9"==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5M;W1E7VED)R`@/3X@
M)')E;6]T95]I9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W)E8VEP:65N="<@(#T^("1R96-I<&EE;G0L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=E<G)O<B<@("`@("`]/B`D97)R;W(I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'-E;F1S.PH@
M("`@?0H*("`@("\J*@H@("`@("H@268@=&AE(&-U<G)E;G0@9')I=F5R(&AA
M<R!A(&-R961I="!C87!A8FEL:71Y+"!Q=65R:65S('1H92!G871E=V%Y(&9O
M<@H@("`@("H@82!C<F5D:70@8F%L86YC92!A;F0@<F5T=7)N<R!T:&4@=F%L
M=64N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!686QU92!I;F1I
M8V%T:6YG(&%V86EL86)L92!C<F5D:70@;W(@;G5L;"!I9B!N;W0*("`@("`J
M("`@("`@("`@("`@("`@("`@<W5P<&]R=&5D+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971"86QA;F-E*"D*("`@('L*("`@("`@("`O*B!!=71H96YT:6-A
M=&4N("HO"B`@("`@("`@:68@*&ES7V$H)'1H:7,M/F%U=&AE;G1I8V%T92@I
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7V%U=&@["B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C:R!B86QA;F-E+B`J
M+PH@("`@("`@(&EF("@D=&AI<RT^:&%S0V%P86)I;&ET>2@G8W)E9&ET)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9V5T0F%L86YC92@I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R
M;B!A(&-O;F-R971E($=A=&5W87D@:6YS=&%N8V4@8F%S960@;VX@)&1R:79E
M<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D<FEV97(@(%1H92!T
M>7!E(&]F(&-O;F-R971E($=A=&5W87D@<W5B8VQA<W,@=&\@<F5T=7)N+@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("!4:&ES(&ES(&)A<V5D(&]N
M('1H92!G871E=V%Y(&1R:79E<B`H)&1R:79E<BDN"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@(%1H92!C;V1E(&ES(&1Y;F%M:6-A;&QY(&EN8VQU
M9&5D+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("!!(&AA<V@@8V]N
M=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R
M<R!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R
M;B!.971?4TU3("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T92!'871E=V%Y
M(&EN<W1A;F-E(&]R(&9A;'-E(&]N"B`@("`@*B`@("`@("`@("`@("`@("`@
M(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D9')I
M=F5R+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I;F-L=61E
M7V]N8V4@)TYE="]335,O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@
M)&-L87-S(#T@)TYE=%]335-?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L
M87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1S;7,@/2`F;F5W
M("1C;&%S<R@D<&%R86US*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D<VUS(#T@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-L87-S(&1E
M9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(I+"`D9')I=F5R*2D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'-M<SL*("`@('T*"B`@("`O*BH*("`@
M("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R
M971E($YE=%]335,@:6YS=&%N8V4@8F%S960@;VX*("`@("`J("1D<FEV97(N
M"B`@("`@*@H@("`@("H@270@=VEL;"!O;FQY(&-R96%T92!A(&YE=R!I;G-T
M86YC92!I9B!N;R!.971?4TU3(&EN<W1A;F-E('=I=&@@=&AE('-A;64*("`@
M("`J('!A<F%M971E<G,@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@
M*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z("1V87(@/2`F3F5T
M7U--4SHZ<VEN9VQE=&]N*"D*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1D<FEV97(@(%1H92!T>7!E(&]F(&-O;F-R971E($YE=%]335,@<W5B8VQA
M<W,@=&\@<F5T=7)N+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!4
M:&4@:7,@8F%S960@;VX@=&AE(&=A=&5W87D@9')I=F5R("@D9')I=F5R*2X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@5&AE(&-O9&4@:7,@9'EN
M86UI8V%L;'D@:6YC;'5D960N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O
M;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C
M;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!C<F5A=&5D(&-O;F-R
M971E($YE=%]335,@:6YS=&%N8V4L(&]R(&9A;'-E(&]N(&5R<F]R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(L("1P87)A;7,@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N8V5S.PH@
M("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<RDI('L*("`@("`@("`@("`@
M)&EN<W1A;F-E<R`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("`D<VEG
M;F%T=7)E(#T@<V5R:6%L:7IE*&%R<F%Y*"1D<FEV97(L("1P87)A;7,I*3L*
M("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97-;)'-I9VYA='5R95TI*2![
M"B`@("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@/2`F3F5T7U--
M4SHZ9F%C=&]R>2@D9')I=F5R+"`D<&%R86US*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]P<F5F
M<RYP:'``````````````````````````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,3$T,S``,3`U,34T,S,W-3(`,#(P,C4R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R
M9&4Z(&AO<F1E+VQI8B]P<F5F<RYP:'`L=B`Q+C$Y+C0N,3`@,C`P-B\P,2\P
M,2`R,3HR.3HP-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P
M-B!#:&%R;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#
M;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("HO"@IF=6YC=&EO;B!H86YD;&5?<VAO=W-U;6UA
M<GES96QE8W0H)'5P9&%T960I"GL*("`@(&=L;V)A;"`D<')E9G,["@H@("`@
M)'-H;W=?<W5M;6%R:65S(#T@571I;#HZ9V5T1F]R;41A=&$H)W-H;W=?<W5M
M;6%R:65S)RD["B`@("!I9B`H(6ES7VYU;&PH)'-H;W=?<W5M;6%R:65S*2D@
M>PH@("`@("`@("1P<F5F<RT^<V5T5F%L=64H)W-H;W=?<W5M;6%R:65S)RP@
M)'-H;W=?<W5M;6%R:65S*3L*("`@("`@("`D=7!D871E9"`]('1R=64["B`@
M("!]"@H@("`@<F5T=7)N("1U<&1A=&5D.PI]"@IF=6YC=&EO;B!H86YD;&5?
M=&AE;65S96QE8W0H)'5P9&%T960I"GL*("`@(&=L;V)A;"`D<')E9G,["@H@
M("`@)'1H96UE(#T@571I;#HZ9V5T1F]R;41A=&$H)W1H96UE)RD["B`@("!I
M9B`H(6ES7VYU;&PH)'1H96UE*2D@>PH@("`@("`@("1P<F5F<RT^<V5T5F%L
M=64H)W1H96UE)RP@)'1H96UE*3L*("`@("`@("`D=7!D871E9"`]('1R=64[
M"B`@("!]"@H@("`@<F5T=7)N("1U<&1A=&5D.PI]"@IF=6YC=&EO;B!H86YD
M;&5?8V%T96=O<GEM86YA9V5M96YT*"1U<&1A=&5D*0I["B`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`G.PH@("`@
M)&--86YA9V5R(#T@)FYE=R!0<F5F<U]#871E9V]R>4UA;F%G97(H*3L*"B`@
M("`O*B!!;'=A>7,@<V%V92!C;VQO<G,@;V8@86QL(&-A=&5G;W)I97,N("HO
M"B`@("`D8V]L;W)S(#T@87)R87DH*3L*("`@("1C871E9V]R:65S(#T@)&--
M86YA9V5R+3YG970H*3L*("`@(&9O<F5A8V@@*"1C871E9V]R:65S(&%S("1C
M871E9V]R>2D@>PH@("`@("`@(&EF("@D8V]L;W(@/2!5=&EL.CIG971&;W)M
M1&%T82@G8V]L;W)?)R`N(&)A<V4V-%]E;F-O9&4H)&-A=&5G;W)Y*2DI('L*
M("`@("`@("`@("`@)&-O;&]R<ULD8V%T96=O<GE=(#T@)&-O;&]R.PH@("`@
M("`@('T*("`@('T*("`@(&EF("@D8V]L;W(@/2!5=&EL.CIG971&;W)M1&%T
M82@G8V]L;W)?)R`N(&)A<V4V-%]E;F-O9&4H)U]D969A=6QT7R<I*2D@>PH@
M("`@("`@("1C;VQO<G-;)U]D969A=6QT7R==(#T@)&-O;&]R.PH@("`@?0H@
M("`@:68@*"1C;VQO<B`](%5T:6PZ.F=E=$9O<FU$871A*"=C;VQO<E\G("X@
M8F%S938T7V5N8V]D92@G7W5N9FEL961?)RDI*2!["B`@("`@("`@)&-O;&]R
M<ULG7W5N9FEL961?)UT@/2`D8V]L;W(["B`@("!]"B`@("`D8TUA;F%G97(M
M/G-E=$-O;&]R<R@D8V]L;W)S*3L*"B`@("`D86-T:6]N(#T@571I;#HZ9V5T
M1F]R;41A=&$H)V-!8W1I;VXG*3L*("`@("1C871E9V]R>2`](%5T:6PZ.F=E
M=$9O<FU$871A*"=C871E9V]R>2<I.PH*("`@('-W:71C:"`H)&%C=&EO;BD@
M>PH@("`@8V%S92`G861D)SH*("`@("`@("`D8TUA;F%G97(M/F%D9"@D8V%T
M96=O<GDI.PH@("`@("`@(&)R96%K.PH*("`@(&-A<V4@)W)E;6]V92<Z"B`@
M("`@("`@)&--86YA9V5R+3YR96UO=F4H)&-A=&5G;W)Y*3L*("`@("`@("!B
M<F5A:SL*"B`@("!D969A=6QT.@H@("`@("`@("\J(%-A=F4@8G5T=&]N+B`J
M+PH@("`@("`@("1U<&1A=&5D(#T@=')U93L*("`@('T*"B`@("!R971U<FX@
M)'5P9&%T960["GT*"B\J*@H@*B!$;R!A;GET:&EN9R!T:&%T('=E(&YE960@
M=&\@9&\@87,@82!R97-U;'0@;V8@8V5R=&%I;B!P<F5F97)E;F-E<PH@*B!C
M:&%N9VEN9RX*("HO"F9U;F-T:6]N('!R969S7V-A;&QB86-K*"D*>PH@("`@
M9VQO8F%L("1P<F5F<RP@)')E9VES=')Y+"`D;F]T:69I8V%T:6]N+"`D;FQS
M.PH*("`@(&EF("@D<')E9G,M/FES1&ER='DH)VQA;F=U86=E)RD@?'P*("`@
M("`@("`D<')E9G,M/FES1&ER='DH)W-H;W=?<VED96)A<B<I*2!["B`@("`@
M("`@:68@*"1P<F5F<RT^:7-$:7)T>2@G;&%N9W5A9V4G*2D@>PH@("`@("`@
M("`@("!.3%,Z.G-E=$QA;F<H)'!R969S+3YG971686QU92@G;&%N9W5A9V4G
M*2D["B`@("`@("`@("`@($Y,4SHZ<V5T5&5X=&1O;6%I;B@D<F5G:7-T<GDM
M/F=E=$%P<"@I+"`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G*2`N("<O;&]C
M86QE)RP@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@("`@("!3=')I;F<Z
M.G-E=$1E9F%U;'1#:&%R<V5T*$Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@
M("!]"@H@("`@("`@("1U<FP@/2`D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L
M("=H;W)D92<I.PH@("`@("`@(&EF("AS=6)S='(H)'5R;"P@+3$I("$]("<O
M)RD@>PH@("`@("`@("`@("`D=7)L("X]("<O)SL*("`@("`@("!]"B`@("`@
M("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L("X@)VEN9&5X+G!H
M<"<L("=U<FPG+"!(;W)D93HZ<V5L9E5R;"AT<G5E*2D["B`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"@G:68@*'=I;F1O=RYP87)E;G0N9G)A;65S*2!W
M:6YD;W<N<&%R96YT+F9R86UE<RYL;V-A=&EO;B`](%PG)R`N(&%D9'-L87-H
M97,H2&]R9&4Z.G5R;"@D=7)L+"!T<G5E*2D@+B`G7"<[)RP@)VIA=F%S8W)I
M<'0G*3L*("`@('T*"B`@("!I9B`H)'!R969S+3YI<T1I<G1Y*"=S:61E8F%R
M7W=I9'1H)RDI('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*"=I9B`H
M=VEN9&]W+G!A<F5N="`F)B!W:6YD;W<N<&%R96YT+F1O8W5M96YT+F=E=$5L
M96UE;G1">4ED*%PG:&9<)RD@)B8@=VEN9&]W+G!A<F5N="YH;W)D95]M96YU
M("8F('=I;F1O=RYP87)E;G0N:&]R9&5?;65N=2YE>'!A;F1E9%-I9&5B87(N
M<VAO=VXH*2D@=VEN9&]W+G!A<F5N="YD;V-U;65N="YG971%;&5M96YT0GE)
M9"A<)VAF7"<I+F-O;',@/2!W:6YD;W<N<&%R96YT+FAO<F1E7VUE;G4N<G1L
M(#\@7"<J+"<@+B`D<')E9G,M/F=E=%9A;'5E*"=S:61E8F%R7W=I9'1H)RD@
M+B`G7"<@.B!<)R<@+B`D<')E9G,M/F=E=%9A;'5E*"=S:61E8F%R7W=I9'1H
M)RD@+B`G+"I<)SLG+"`G:F%V87-C<FEP="<I.PH@("`@?0H*("`@(&EF("@D
M<')E9G,M/FES1&ER='DH)W1H96UE)RD@?'P*("`@("`@("`D<')E9G,M/FES
M1&ER='DH)VUE;G5?=FEE=R<I('Q\"B`@("`@("`@)'!R969S+3YI<T1I<G1Y
M*"=M96YU7W)E9G)E<VA?=&EM92<I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO
M;BT^<'5S:"@G:68@*'=I;F1O=RYP87)E;G0N9G)A;65S+FAO<F1E7VUE;G4I
M('=I;F1O=RYP87)E;G0N9G)A;65S+FAO<F1E7VUE;G4N;&]C871I;VXN<F5L
M;V%D*"D[)RP@)VIA=F%S8W)I<'0G*3L*("`@('T*?0H*+RH@07-S:6=N('9A
M<FEA8FQE<R!F;W(@<V5L96-T(&QI<W1S+B`J+PII9B`H(21P<F5F<RT^:7-,
M;V-K960H)W1I;65Z;VYE)RDI('L*("`@("1T:6UE>F]N95]O<'1I;VYS(#T@
M)'1Z.PH@("`@87)R87E?=6YS:&EF="@D=&EM97IO;F5?;W!T:6]N<RP@7R@B
M1&5F875L="(I*3L*?0II9B`H(21P<F5F<RT^:7-,;V-K960H)VEN:71I86Q?
M87!P;&EC871I;VXG*2D@>PH@("`@9VQO8F%L("1P97)M<SL*"B`@("`D:6YI
M=&EA;%]A<'!L:6-A=&EO;E]O<'1I;VYS(#T@87)R87DH*3L*("`@("1A<'!S
M(#T@)')E9VES=')Y+3YL:7-T07!P<RAA<G)A>2@G86-T:79E)RDI.PH@("`@
M9F]R96%C:"`H)&%P<',@87,@)&$I('L*("`@("`@("!I9B`H9FEL95]E>&ES
M=',H)')E9VES=')Y+3YG970H)V9I;&5R;V]T)RP@)&$I*2`F)@H@("`@("`@
M("`@("`H*"1P97)M<RT^97AI<W1S*"1A*2`F)B`H)'!E<FUS+3YH87-097)M
M:7-S:6]N*"1A+"!!=71H.CIG971!=71H*"DL(%!%4DU37U)%040I('Q\($%U
M=&@Z.FES061M:6XH*2DI('Q\"B`@("`@("`@("`@("`A)'!E<FUS+3YE>&ES
M=',H)&$I*2D@>PH@("`@("`@("`@("`D:6YI=&EA;%]A<'!L:6-A=&EO;E]O
M<'1I;VYS6R1A72`]("1R96=I<W1R>2T^9V5T*"=N86UE)RP@)&$I.PH@("`@
M("`@('T*("`@('T*("`@(&%S;W)T*"1I;FET:6%L7V%P<&QI8V%T:6]N7V]P
M=&EO;G,I.PI]"FEF("@A)'!R969S+3YI<TQO8VME9"@G=&AE;64G*2D@>PH@
M("`@)'1H96UE7V]P=&EO;G,@/2!A<G)A>2@I.PH@("`@)'1H96UE7V)A<V4@
M/2`D<F5G:7-T<GDM/F=E="@G=&AE;65S9G,G+"`G:&]R9&4G*3L*("`@("1D
M:"`]($!O<&5N9&ER*"1T:&5M95]B87-E*3L*("`@(&EF("@A)&1H*2!["B`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@B5&AE;64@9&ER96-T;W)Y(&-A
M;B=T(&)E(&]P96YE9"(L("=H;W)D92YE<G)O<B<I.PH@("`@?2!E;'-E('L*
M("`@("`@("!W:&EL92`H*"1D:7(@/2!R96%D9&ER*"1D:"DI("$]/2!F86QS
M92D@>PH@("`@("`@("`@("!I9B`H)&1I<B`]/2`G+B<@?'P@)&1I<B`]/2`G
M+BXG('Q\("$@:7-?9&ER*"1T:&5M95]B87-E+B<O)RXD9&ER*2D@>PH@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1T:&5M95]N86UE(#T@;G5L;#L*("`@("`@("`@("`@0&EN8VQU9&4@
M)'1H96UE7V)A<V4@+B`G+R<@+B`D9&ER("X@)R]I;F9O+G!H<"<["B`@("`@
M("`@("`@(&EF("@A96UP='DH)'1H96UE7VYA;64I*2!["B`@("`@("`@("`@
M("`@("`D=&AE;65?;W!T:6]N<ULD9&ER72`]("1T:&5M95]N86UE.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@(&%S;W)T*"1T:&5M95]O
M<'1I;VYS*3L*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O4WEN8TU,+P``````````````````````````````````````````````
M`````````````````````````````````````#`P,#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S0T`#`Q-S4W,0`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO0F%C:V5N9"YP:'``````````
M````````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-3<T-30`,3`U,34T,S,W
M-#0`,#(Q-C4P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!3>6YC34P@0F%C:V5N9"!F;W(@=&AE($AO
M<F1E($%P<&QI8V%T:6]N(&9R86UE=V]R:RX*("H*("H@5&AE(&)A8VME;F0@
M<')O=FED97,@=&AE(&9O;&QO=VEN9R!F=6YC=&EO;F%L:71Y.@H@*@H@*B`Q
M*2!H86YD;&EN9R!O9B!T:&4@86-T=6%L(&1A=&$L(&DN92X*("H@("`@82D@
M861D+W)E<&QA8V4O9&5L971E(&5N=')I97,@=&\@86YD(')E=')I979E(&5N
M=')I97,@9G)O;2!T:&4*("H@("`@("`@8F%C:V5N9`H@*B`@("!B*2!R971R
M:65V92!H:7-T;W)Y('1O(&9I;F0@;W5T('=H870@96YT<FEE<R!H879E(&)E
M96X@8VAA;F=E9`H@*B`R*2!M86YA9VEN9R!O9B!T:&4@;6%P(&)E='=E96X@
M8VQI96YD($E$<R!A;F0@<V5R=F5R($E$<PH@*B`S*2!S=&]R92!I;F9O<FUA
M=&EO;B!A8F]U="!S>6YC(&%N8VAO<G,@*'1I;65S=&%M<',I(&]F('!R979I
M;W5S"B`J("`@('-U8V-E<W-F=6QS('-Y;F,@<V5S<VEO;G,*("H@-"D@<V5S
M<VEO;B!H86YD;&EN9R`H;F]T('EE="P@<W1I;&P@=&\@8F4@9&]N92D*("H@
M-2D@875T:&]R:7-A=&EO;B`H;F]T('EE="P@<W1I;&P@=&\@8F4@9&]N92D*
M("H@-BD@;&]G9VEN9PH@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($MA<G-T
M96X@1F]U<FUO;G0@/&MA<G-T96Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4WEN8TU,+U-Y;F--3"]"86-K96YD
M+G!H<"QV(#$N."XR+C@@,C`P-B\P-R\Q."`Q,CHP,#HU-B!J86X@17AP("0*
M("H*("H@0&%U=&AO<B`@2V%R<W1E;B!&;W5R;6]N="`\:V%R<W1E;D!H;W)D
M92YO<F<^"B`J($!P86-K86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7T)A
M8VME;F1?2&]R9&4@>PH*("`@("\J*@H@("`@("H@06X@87)R87D@87,@=F%L
M=64@:6YD:6-A=&5S('1H870@9F]R('1H:7,@8VQI96YT(&-A=&5G;W)Y(&YO
M"B`@("`@*B!S97)V97(@8V%T96=O<GD@:7,@9&5F:6YE9"!Y970N(%1H92!A
M<G)A>2!C;VYT96YT(&ES('1H90H@("`@("H@<W5M;6%R>2!T97AT(&]F('1H
M92!L87-T(&5N8V]U;G1E<F5D(&-L:65N="!E;G1R>2!T:&%T('5S960*("`@
M("`J('1H:7,@8V%T96=O<GDN"B`@("`@*@H@("`@("H@("!K97DZ("`@8VQI
M96YT0V%T96=O<GD*("`@("`J("`@=F%L=64Z('-E<G9E<D-A=&5G;W)Y"B`@
M("`@*B\*("`@('9A<B`D7V-A=&5G;W)I97--87`["@H@("`@+RHJ"B`@("`@
M*B!397)V97(@8V%T96=O<FEE<R!M:7-S:6YG(&]N('1H92!C;&EE;G0N"B`@
M("`@*@H@("`@("H@("!K97DZ("`@<V5R=F5R0V%T96=O<GD*("`@("`J("`@
M=F%L=64Z('-U;6UA<GD@;V8@;&%S="!E;G1R>2!W:71H('1H:7,@8V%T96=O
M<GD*("`@("`J+PH@("`@=F%R("1?;6ES<VEN9U-E<G9E<D-A=&5G;W)I97,[
M"@H@("`@=F%R("1?9&%T871R964["@H@("`@+RHJ"B`@("`@*B!#86-H92!F
M;W(@1&%T871R964@=F%L=65S"B`@("`@*B\*("`@("`*("`@('9A<B`D7V-A
M8VAE.PH@("`@"B`@("!F=6YC=&EO;B!3>6YC34Q?0F%C:V5N9%](;W)D92@I
M"B`@("!["B`@("`@("`@)&1R:79E<B`]("1'3$]"04Q36R=C;VYF)UU;)V1A
M=&%T<F5E)UU;)V1R:79E<B==.PH@("`@("`@("1P87)A;7,@/2!(;W)D93HZ
M9V5T1')I=F5R0V]N9FEG*"=D871A=')E92<L("1D<FEV97(I.PH@("`@("`@
M("1P87)A;7,@/2!A<G)A>5]M97)G92@D<&%R86US+"!A<G)A>2@G9W)O=7`G
M(#T^("=S>6YC;6PG*2D["@H@("`@("`@("1T:&ES+3Y?9&%T871R964@/28@
M1&%T851R964Z.G-I;F=L971O;B@D9')I=F5R+"`D<&%R86US*3L*("`@("`@
M("`D=&AI<RT^7V-A8VAE(#T@87)R87DH*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E=')I979E<R!A;B!E;G1R>2!F<F]M('1H92!B86-K96YD+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&%B87-E("`@1&%T86)A<V4@
M=&\@<V-A;BX@:2YE+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("!C86QE;F1A<B]T87-K<R]C;VYT86-T<R]N;W1E<PH@("`@("H@0'!A<F%M
M('-T<FEN9R`D<W5I9"`@("`@("!397)V97(@=6YI<75E(&ED(&]F('1H92!E
M;G1R>3H@9F]R(&AO<F1E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@('1H:7,@:7,@=&AE(&=U:60N"B`@("`@*B!`<&%R86T@<W1R:6YG(&-O
M;G1E;G14>7!E($-O;G1E;G0M5'EP93H@=&AE(&UI;64@='EP92!I;B!W:&EC
M:"!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@9G5N8W1I
M;VX@<VAA;&P@<F5T=7)N('1H92!D871A"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@("`@("`@("`@("!!('-T<FEN9R!W:71H('1H92!D871A(&5N
M=')Y(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&]R(&$@
M4$5!4E]%<G)O<B!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E=')I
M979E16YT<GDH)&1A=&%B87-E+"`D<W5I9"P@)&-O;G1E;G14>7!E*0H@("`@
M>PH@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^8V%L;"@D
M9&%T86)A<V4@+B`G+V5X<&]R="<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=G=6ED)R`]/B`D<W5I9"P@)V-O
M;G1E;G14>7!E)R`]/B`D8V]N=&5N=%1Y<&4I*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($=E="!E;G1R:65S('1H870@:&%V92!B965N(&UO9&EF:65D(&EN
M('1H92!S97)V97(@9&%T86)A<V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<WEN8TED96YT:69I97(@($ED96YT:69I97,@=&AE(&-L:65N="!D
M979I8V4@=&\@86QL;W<@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@=7-E<B!T;R!S>6YC('=I=&@@9&EF9F5R96YT(&1E=FEC
M97,N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@3F]R
M;6%L;'D@=&AE(%-O=7)C955222!F<F]M('1H90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%-Y;F-(96%D97(*("`@("`J($!P87)A
M;2!S=')I;F<@)&1A=&%B87-E("`@("`@("!$871A8F%S92!T;R!S8V%N+B!I
M+F4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V%L
M96YD87(O=&%S:W,O8V]N=&%C=',O;F]T97,*("`@("`J($!P87)A;2!I;G1E
M9V5R("1F<F]M7W1S("`@("`@("!3=&%R="!T:6UE<W1A;7`N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D=&]?=',@("`@("`@("`@17AC;'5S:79E(&5N9"!T
M:6UE<W1A;7`N($YO="!Y970*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I;7!L96UE;G1E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!014%27T5R<F]R(&]R(&%S<V]C(&%R<F%Y(&]F(&-H86YG97,@
M=VET:"!K97D]<W5I9"P*("`@("`J("`@("`@("`@("`@("`@('9A;'5E/6-U
M:60N($EF(&YO(&-U:60@8V%N(&)E(&9O=6YD(&9O<B!A('-U:60L('9A;'5E
M(&ES"B`@("`@*B`@("`@("`@("`@("`@("!N=6QL+B!4:&5N(&$@4WEN8R!!
M9&0@8V]M;6%N9"!H87,@=&\@8F4@8W)E871E9"!T;R!A9&0*("`@("`J("`@
M("`@("`@("`@("`@('1H:7,@96YT<GD@:6X@=&AE(&-L:65N="!D871A8F%S
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4V5R=F5R36]D:69I8V%T:6]N
M<R@D<WEN8TED96YT:69I97(L("1D871A8F%S92P@)&9R;VU?=',L("1T;U]T
M<RD*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("!I
M9B`H)&9R;VU?=',@/3T@,"D@>PH@("`@("`@("`@("`O+R!#;VUP;&5T92!S
M>6YC.B!E=F5R>71H:6YG(&ES('-E;G0@9'5R:6YG"B`@("`@("`@("`@("\O
M(&=E=%-E<G9E<D%D9&ET:6]N<RX@3F\@;F5E9"!T;R!S96YD(&UO9&EF:6-A
M=&EO;G,N"B`@("`@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@("`@('T*
M"B`@("`@("`@+R\@1V5T(&-H86YG97,N"B`@("`@("`@)&-H86YG97,@/2`D
M<F5G:7-T<GDM/F-A;&PH)&1A=&%B87-E+B`G+VQI<W1">2<L(&%R<F%Y*"=A
M8W1I;VXG(#T^("=M;V1I9GDG+"`G=&EM97-T86UP)R`]/B`D9G)O;5]T<RDI
M.PH@("`@("`@(&EF("AI<U]A*"1C:&%N9V5S+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("1T:&ES+3YL;V=-97-S86=E*")3>6YC34PZ("1D871A
M8F%S92]L:7-T0GD@9F%I;&5D(&9O<B!M;V1I9GDZ(@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`N("1C:&%N9V5S+3YG971-97-S86=E*"DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?5T%23DE.1RD["B`@("`@("`@("`@(')E='5R;B!A<G)A
M>2@I.PH@("`@("`@('T*"B`@("`@("`@)'(@/2!A<G)A>2@I.PH*("`@("`@
M("!F;W)E86-H("@D8VAA;F=E<R!A<R`D<W5I9"D@>PH@("`@("`@("`@("`D
M<W5I9%]T<R`]("1R96=I<W1R>2T^8V%L;"@D9&%T86)A<V4@+B`G+V=E=$%C
M=&EO;E1I;65S=&%M<"<L(&%R<F%Y*"1S=6ED+"`G;6]D:69Y)RDI.PH@("`@
M("`@("`@("`D<WEN8U]T<R`]("1T:&ES+3YG971#:&%N9V544R@D<WEN8TED
M96YT:69I97(L("1D871A8F%S92P@)'-U:60I.PH@("`@("`@("`@("!I9B`H
M)'-Y;F-?=',@)B8@)'-Y;F-?=',@/CT@)'-U:61?=',I('L*("`@("`@("`@
M("`@("`@("\O($-H86YG92!W87,@9&]N92!B>2!U<R!U<&]N(')E<75E<W0@
M;V8@8VQI96YT+@H@("`@("`@("`@("`@("`@+R\@1&]N)W0@;6ER<F]R('1H
M870@8F%C:R!T;R!T:&4@8VQI96YT+@H@("`@("`@("`@("`@("`@)'1H:7,M
M/FQO9TUE<W-A9V4H(F-H86YG93H@)'-U:60@:6=N;W)E9"P@8V%M92!F<F]M
M(&-L:65N="(L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I
M.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&-U:60@/2`D=&AI<RT^9V5T0W5I9"@D<WEN8TED96YT:69I
M97(L("1D871A8F%S92P@)'-U:60I.PH@("`@("`@("`@("!I9B`H(21C=6ED
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G365S<V%G92@B56YA8FQE
M('1O(&-R96%T92!C:&%N9V4@9F]R("1S=6ED.B!C;&EE;G0M:60@;F]T(&9O
M=6YD(&EN(&UA<"X@5')Y:6YG(&%D9"!I;G-T96%D+B(L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%
M05)?3$]'7U=!4DY)3D<I.PH@("`@("`@("`@("`@("`@)');)'-U:61=(#T@
M;G5L;#L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R
M6R1S=6ED72`]("1C=6ED.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)'(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@96YT
M<FEE<R!T:&%T(&AA=F4@8F5E;B!D96QE=&5D(&9R;VT@=&AE('-E<G9E<B!D
M871A8F%S92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A8F%S
M92`@1&%T86)A<V4@=&\@<V-A;BX@:2YE+@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@(&-A;&5N9&%R+W1A<VMS+V-O;G1A8W1S+VYO=&5S"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D9G)O;5]T<PH@("`@("H@0'!A<F%M(&EN
M=&5G97(@)'1O7W1S("`@($5X8VQU<VEV90H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@(%!%05)?17)R;W(@;W(@87-S;V,@87)R87D@;V8@9&5L971I
M;VYS('=I=&@@:V5Y/7-U:60L"B`@("`@*B`@("`@("`@("`@("`@("!V86QU
M93UC=6ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971397)V97)$96QE=&EO
M;G,H)'-Y;F-)9&5N=&EF:65R+"`D9&%T86)A<V4L("1F<F]M7W1S+"`D=&]?
M=',I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@
M:68@*"1F<F]M7W1S(#T](#`I('L*("`@("`@("`@("`@+R\@0V]M<&QE=&4@
M<WEN8SH@979E<GET:&EN9R!I<R!S96YT(&1U<FEN9PH@("`@("`@("`@("`O
M+R!G971397)V97)!9&1I=&EO;G,N("!.;R!N965D('1O('-E;F0@9&5L971I
M;VYS+@H@("`@("`@("`@("!R971U<FX@87)R87DH*3L*("`@("`@("!]"@H@
M("`@("`@("\O($=E="!D96QE=&EO;G,N"B`@("`@("`@)&1E;&5T97,@/2`D
M<F5G:7-T<GDM/F-A;&PH)&1A=&%B87-E+B`G+VQI<W1">2<L(&%R<F%Y*"=A
M8W1I;VXG(#T^("=D96QE=&4G+"`G=&EM97-T86UP)R`]/B`D9G)O;5]T<RDI
M.PH*("`@("`@("!I9B`H:7-?82@D9&5L971E<RP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^;&]G365S<V%G92@B4WEN8TU,.B`D9&%T
M86)A<V4O;&ES=$)Y(&9A:6QE9"!F;W(@9&5L971E.B(*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+B`D9&5L971E<RT^9V5T365S<V%G92@I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7U=!4DY)3D<I.PH@("`@("`@("`@("!R971U<FX@87)R
M87DH*3L*("`@("`@("!]"@H@("`@("`@("1R(#T@87)R87DH*3L*"B`@("`@
M("`@9F]R96%C:"`H)&1E;&5T97,@87,@)'-U:60I('L*("`@("`@("`@("`@
M)'-U:61?=',@/2`D<F5G:7-T<GDM/F-A;&PH)&1A=&%B87-E+B`G+V=E=$%C
M=&EO;E1I;65S=&%M<"<L(&%R<F%Y*"1S=6ED+"`G9&5L971E)RDI.PH@("`@
M("`@("`@("`D<WEN8U]T<R`]("1T:&ES+3YG971#:&%N9V544R@D<WEN8TED
M96YT:69I97(L("1D871A8F%S92P@)'-U:60I.PH@("`@("`@("`@("!I9B`H
M)'-Y;F-?=',@)B8@)'-Y;F-?=',@/CT@)'-U:61?=',I('L*("`@("`@("`@
M("`@("`@("\O($-H86YG92!W87,@9&]N92!B>2!U<R!U<&]N(')E<75E<W0@
M;V8@8VQI96YT+@H@("`@("`@("`@("`@("`@+R\@1&]N)W0@;6ER<F]R('1H
M870@8F%C:R!T;R!T:&4@8VQI96YT+@H@("`@("`@("`@("`@("`@)'1H:7,M
M/FQO9TUE<W-A9V4H(E-Y;F--3#H@9&5L971E("1S=6ED(&EG;F]R960L(&-A
M;64@9G)O;2!C;&EE;G0B+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T1%0E5'*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1C=6ED(#T@)'1H:7,M/F=E=$-U:60H)'-Y;F-)
M9&5N=&EF:65R+"`D9&%T86)A<V4L("1S=6ED*3L*("`@("`@("`@("`@:68@
M*"$D8W5I9"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/FQO9TUE<W-A9V4H
M(E5N86)L92!T;R!C<F5A=&4@9&5L971E(&9O<B`D<W5I9#H@;&]C:60@;F]T
M(&9O=6YD(&EN(&UA<"(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7U=!4DY)3D<I.PH@
M("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1R6R1S=6ED72`]("1C=6ED.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1R.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&5N=')I97,@
M=&AA="!H879E(&)E96X@861D960@=&\@=&AE('-E<G9E<B!D871A8F%S92X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A8F%S92`@1&%T86)A
M<V4@=&\@<V-A;BX@:2YE+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@(&-A;&5N9&%R+W1A<VMS+V-O;G1A8W1S+VYO=&5S"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D9G)O;5]T<PH@("`@("H@0'!A<F%M(&EN=&5G97(@)'1O
M7W1S("`@($5X8VQU<VEV90H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M(%!%05)?17)R;W(@;W(@87-S;V,@87)R87D@;V8@9&5L971I;VYS('=I=&@@
M:V5Y/7-U:60L"B`@("`@*B`@("`@("`@("`@("`@("!V86QU93TP+B`H87)R
M87D@<W1Y;&4@:7,@8VAO<V5N('1O(&UA=&-H(&-H86YG92`F(&1E;"D*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T4V5R=F5R061D:71I;VYS*"1S>6YC261E
M;G1I9FEE<BP@)&1A=&%B87-E+"`D9G)O;5]T<RP@)'1O7W1S*0H@("`@>PH@
M("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@(&EF("@D9G)O;5]T
M<R`]/2`P*2!["B`@("`@("`@("`@("\O(%)E='5R;B!A;&P@9&(@96YT<FEE
M<R!D:7)E8W1L>2!R871H97(@=&AA;B!B;W1H97(*("`@("`@("`@("`@+R\@
M:&ES=&]R>3H*("`@("`@("`@("`@)&%D9',@/2`D<F5G:7-T<GDM/F-A;&PH
M)&1A=&%B87-E+B`G+VQI<W0G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D861D<R`]("1R96=I<W1R>2T^8V%L;"@D9&%T86)A<V4N("<O;&ES
M=$)Y)RP@87)R87DH)V%C=&EO;B<@/3X@)V%D9"<L("=T:6UE<W1A;7`G(#T^
M("1F<F]M7W1S*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?82@D861D
M<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D=&AI<RT^;&]G365S
M<V%G92@B4WEN8TU,.B`D9&%T86)A<V4O;&ES=$)Y(&9A:6QE9"!F;W(@861D
M.B(*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D861D<RT^9V5T
M365S<V%G92@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7U=!4DY)3D<I.PH@("`@("`@("`@
M("!R971U<FX@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YL
M;V=-97-S86=E*"=A9&0@;6]D:69I8V%T:6]N<R!R971R:65V960N(&-O=6YT
M/2<*("`@("`@("`@("`@("`@("`@("`@("`@("`N(&-O=6YT*"1A9&1S*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@)'(@/2!A<G)A>2@I.PH*("`@
M("`@("!F;W)E86-H("@D861D<R!A<R`D<W5I9"D@>PH@("`@("`@("`@("`D
M<W5I9%]T<R`]("1R96=I<W1R>2T^8V%L;"@D9&%T86)A<V4@+B`G+V=E=$%C
M=&EO;E1I;65S=&%M<"<L(&%R<F%Y*"1S=6ED+"`G861D)RDI.PH@("`@("`@
M("`@("`D<WEN8U]T<R`]("1T:&ES+3YG971#:&%N9V544R@D<WEN8TED96YT
M:69I97(L("1D871A8F%S92P@)'-U:60I.PH@("`@("`@("`@("!I9B`H)'-Y
M;F-?=',@)B8@)'-Y;F-?=',@/CT@)'-U:61?=',I('L*("`@("`@("`@("`@
M("`@("\O($-H86YG92!W87,@9&]N92!B>2!U<R!U<&]N(')E<75E<W0@;V8@
M8VQI96YT+@H@("`@("`@("`@("`@("`@+R\@1&]N)W0@;6ER<F]R('1H870@
M8F%C:R!T;R!T:&4@8VQI96YT+@H@("`@("`@("`@("`@("`@)'1H:7,M/FQO
M9TUE<W-A9V4H(F%D9#H@)'-U:60@:6=N;W)E9"P@8V%M92!F<F]M(&-L:65N
M="(L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1C=6ED(#T@)'1H:7,M/F=E=$-U:60H)'-Y;F-)9&5N=&EF:65R+"`D
M9&%T86)A<V4L("1S=6ED*3L*"B`@("`@("`@("`@(&EF("@D8W5I9"`F)B`D
M9G)O;5]T<R`]/2`P*2!["B`@("`@("`@("`@("`@("`O+R!&;W(@<VQO=R!S
M>6YC("AT<R`](#`I+"!D;R!N;W0@861D(&1A=&$@9F]R('=H:6-H"B`@("`@
M("`@("`@("`@("`O+R!W92!H879E(&$@;&]C:60@86=A:6XN(%1H:7,@:7,@
M82!H975R:7-T:6,@=&\*("`@("`@("`@("`@("`@("\O(&%V;VED(&1U<&QI
M8V%T:6]N(&]F(&5N=')I97,N"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G
M365S<V%G92@B<VMI<'!I;F<@861D(&]F(&=U:60@)'-U:60@87,@=&AE<F4@
M86QR96%D>2!I<R!A(&-U:60@)&-U:60B+"!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1R6R1S=6ED72`](#`["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'(["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!9&1S(&%N(&5N=')Y(&EN=&\@=&AE('-E<G9E<B!D871A8F%S92X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A8F%S92`@("`@1&%T86)A
M<V4@=VAE<F4@=&\@861D+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&-A;&5N9&%R+W1A<VMS+V-O;G1A8W1S+VYO=&5S"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1C;VYT96YT("`@("`@5&AE(&%C='5A;"!D871A"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C;VYT96YT5'EP92`@36EM971Y<&4@;V8@
M)&-O;G1E;G0*("`@("`J($!P87)A;2!S=')I;F<@)&-U:60@("`@("`@("!#
M;&EE;G0@240@;V8@=&AI<R!E;G1R>2`H9F]R(&UA<"D*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!014%27T5R<F]R(&]R('-U:60@*$AO<F1E(&=U
M:60I(&]F(&YE=R!E;G1R>0H@("`@("HO"B`@("!F=6YC=&EO;B!I;7!O<G1%
M;G1R>2@D<WEN8TED96YT:69I97(L("1D871A8F%S92P@)&-O;G1E;G0L("1C
M;VYT96YT5'EP92P@)&-U:60I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I
M<W1R>3L*"B`@("`@("`@)'1A<VMS86YD8V%L96YD87)C;VUB:6YE9"`](&9A
M;'-E.PH*("`@("`@("`O+R!#:&5C:W,@:68@=&AE(&-L:65N="!S96YD<R!U
M<R!A('9T;V1O(&EN(&$@8V%L96YD87(@<WEN8SH*("`@("`@("!I9B`H)&1A
M=&%B87-E(#T]("=C86QE;F1A<B<*("`@("`@("`@("`@("8F('!R96=?;6%T
M8V@H)R\H7')<;GQ<<GQ<;BE"14=)3EM>.ETJ.E943T1/+R<L(")<;B(@+B`D
M8V]N=&5N="DI('L*("`@("`@("`@("`@)'-E<G9E<F1A=&%B87-E(#T@)W1A
M<VMS)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<V5R=F5R9&%T
M86)A<V4@/2`D9&%T86)A<V4["B`@("`@("`@?0H*("`@("`@("`D<W5I9"`]
M("1R96=I<W1R>2T^8V%L;"@D<V5R=F5R9&%T86)A<V4@+B`G+VEM<&]R="<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)&-O;G1E
M;G0L("1C;VYT96YT5'EP92DI.PH*("`@("`@("`D=&AI<RT^;&]G365S<V%G
M92@B861D('1O('-E<G9E<B!D8B`D<V5R=F5R9&%T86)A<V4@8W5I9"`D8W5I
M9"`M/B!S=6ED("1S=6ED(BP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U]$14)51RD["@H@("`@("`@(&EF("@A:7-?82@D<W5I9"P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`D=',@/2`D<F5G:7-T<GDM/F-A;&PH)'-E
M<G9E<F1A=&%B87-E+B`G+V=E=$%C=&EO;E1I;65S=&%M<"<L(&%R<F%Y*"1S
M=6ED+"`G861D)RDI.PH@("`@("`@("`@("!I9B`H(21T<RD@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/FQO9TUE<W-A9V4H)U5N86)L92!T;R!F:6YD(&%D
M9"UT<R!F;W(@)R`N("1S=6ED("X@)R!A="`G("X@)'1S+"!?7T9)3$5?7RP@
M7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'1H:7,M/F-R96%T955I9$UA<"@D<WEN8TED96YT:69I97(L("1D
M871A8F%S92P@)&-U:60L("1S=6ED+"`D=',I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1S=6ED.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E
M<R!A;B!E;G1R>2!F<F]M('1H92!S97)V97(@9&%T86)A<V4N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9&%T86)A<V4@($1A=&%B87-E('=H97)E
M('1O(&%D9"X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!C86QE
M;F1A<B]T87-K<R]C;VYT86-T<R]N;W1E<PH@("`@("H@0'!A<F%M('-T<FEN
M9R`D8W5I9"`@("`@($-L:65N="!)1"!O9B!T:&4@96YT<GD*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!014%27T5R<F]R(&]R('-U:60@*$AO<F1E
M(&=U:60I(&]F(&1E;&5T960@96YT<GDN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&1E;&5T945N=')Y*"1S>6YC261E;G1I9FEE<BP@)&1A=&%B87-E+"`D8W5I
M9"D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`O
M+R!&:6YD('-E<G9E<B!)1"!F;W(@=&AI<R!E;G1R>3H*("`@("`@("`D<W5I
M9"`]("1T:&ES+3YG9713=6ED*"1S>6YC261E;G1I9FEE<BP@)&1A=&%B87-E
M+"`D8W5I9"D["B`@("`@("`@:68@*"%I<U]A*"1S=6ED+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("1R96=I<W1R>2T^8V%L;"@D9&%T86)A<V4N
M("<O9&5L971E)RP@87)R87DH)'-U:60I*3L*("`@("`@("`@("`@)'1S(#T@
M)')E9VES=')Y+3YC86QL*"1D871A8F%S92`N("<O9V5T06-T:6]N5&EM97-T
M86UP)RP@87)R87DH)'-U:60L("=D96QE=&4G*2D["B`@("`@("`@("`@("\O
M(%=E(&-A;B=T(')E;6]V92!T:&4@;6%P<&EN9R!E;G1R>2!A<R!W92!N965D
M('1O(&ME97`*("`@("`@("`@("`@+R\@=&AE('1I;65S=&%M<"!I;F9O<FUA
M=&EO;BX*("`@("`@("`@("`@)'1H:7,M/F-R96%T955I9$UA<"@D<WEN8TED
M96YT:69I97(L("1D871A8F%S92P@)&-U:60L("1S=6ED+"`D=',I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1S=6ED.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5P;&%C97,@86X@96YT<GD@:6X@=&AE('-E<G9E<B!D871A8F%S
M92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A8F%S92`@("`@
M1&%T86)A<V4@=VAE<F4@=&\@<F5P;&%C92X*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!C86QE;F1A<B]T87-K<R]C;VYT86-T<R]N;W1E
M<PH@("`@("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N="`@("`@(%1H92!A8W1U
M86P@9&%T80H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N=%1Y<&4@($UI
M;65T>7!E(&]F("1C;VYT96YT"B`@("`@*B!`<&%R86T@<W1R:6YG("1C=6ED
M("`@("`@("`@0VQI96YT($E$(&]F('1H:7,@96YT<GD*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!014%27T5R<F]R(&]R('-U:60@*$AO<F1E(&=U
M:60I(&]F(&UO9&EF:65D(&5N=')Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M97!L86-E16YT<GDH)'-Y;F-)9&5N=&EF:65R+"`D9&%T86)A<V4L("1C;VYT
M96YT+"`D8V]N=&5N=%1Y<&4L("1C=6ED*0H@("`@>PH@("`@("`@(&=L;V)A
M;"`D<F5G:7-T<GD["@H@("`@("`@("\O($-H96-K<R!I9B!T:&4@8VQI96YT
M('-E;F1S('5S(&$@=G1O9&\@:6X@82!C86QE;F1A<B!S>6YC.@H@("`@("`@
M(&EF("@D9&%T86)A<V4@/3T@)V-A;&5N9&%R)PH@("`@("`@("`@("`@)B8@
M<')E9U]M871C:"@G+RA<<EQN?%QR?%QN*4)%1TE.6UXZ72HZ5E1/1$\O)RP@
M(EQN(B`N("1C;VYT96YT*2D@>PH@("`@("`@("`@("`D<V5R=F5R9&%T86)A
M<V4@/2`G=&%S:W,G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S
M97)V97)D871A8F%S92`]("1D871A8F%S93L*("`@("`@("!]"@H@("`@("`@
M("1S=6ED(#T@)'1H:7,M/F=E=%-U:60H)'-Y;F-)9&5N=&EF:65R+"`D9&%T
M86)A<V4L("1C=6ED*3L*"B`@("`@("`@)'1H:7,M/FQO9TUE<W-A9V4H(G)E
M<&QA8V4@:6X@9&(@)'-E<G9E<F1A=&%B87-E(&-U:60@)&-U:60@<W5I9"`D
M<W5I9"(L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*
M("`@("`@("!I9B`H)'-U:60I('L*("`@("`@("`@("`@+R\@16YT<GD@97AI
M<W1S.B!R97!L86-E(&-U<G)E;G0@;VYE+@H@("`@("`@("`@("`D;VL@/2`D
M<F5G:7-T<GDM/F-A;&PH)'-E<G9E<F1A=&%B87-E("X@)R]R97!L86-E)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1S=6ED
M+"`D8V]N=&5N="P@)&-O;G1E;G14>7!E*2D["B`@("`@("`@("`@(&EF("AI
M<U]A*"1O:RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1O:SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=',@/2`D<F5G
M:7-T<GDM/F-A;&PH)'-E<G9E<F1A=&%B87-E("X@)R]G971!8W1I;VY4:6UE
M<W1A;7`G+"!A<G)A>2@D<W5I9"P@)VUO9&EF>2<I*3L*("`@("`@("`@("`@
M)'1H:7,M/F-R96%T955I9$UA<"@D<WEN8TED96YT:69I97(L("1D871A8F%S
M92P@)&-U:60L("1S=6ED+"`D=',I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=.;R!M87`@96YT<GD@
M9F]U;F0G*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<W5I9#L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E=')I979E<R!I;F9O<FUA=&EO;B!A8F]U
M="!T:&4@<')E=FEO=7,@<WEN8R!I9B!A;GDN(%)E='5R;G,*("`@("`J(&9A
M;'-E(&EF(&YO(&EN9F\@9F]U;F0@;W(@82!$871E5')E94]B:F5C="!W:71H
M(&%T(&QE87-T('1H90H@("`@("H@9F]L;&]W:6YG(&%T=')I8G5T97,Z"B`@
M("`@*@H@("`@("H@0VQI96YT06YC:&]R.B!T:&4@8VQI96YT<R!.97AT($%N
M8VAO<B!O9B!T:&4@<')E=FEO=7,@<WEN8RX*("`@("`J(%-E<G9E<D%N8VAO
M<CH@=&AE(%-E<G9E<B!.97AT($%N8VAO<B!O9B!T:&4@<')E=FEO=7,@<WEN
M8RX*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=%-Y;F-3=6UM87)Y*"1S>6YC
M261E;G1I9FEE<BP@)'1Y<&4I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?9V5T3V(H)'-Y;F-)9&5N=&EF:65R("X@)SIS=6UM87)Y.B<@+B`D='EP
M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9G1E<B!A('-U8V-E<W-F=6P@
M<WEN8RP@=&AE(&-L:65N="!A;F0@<V5R=F5R)W,@3F5X="!!;F-H;W)S"B`@
M("`@*B!A<F4@=W)I='1E;B!T;R!T:&4@9&%T86)A<V4@<V\@=&AE>2!C86X@
M8F4@=7-E9"!T;R!N96=O=&EA=&4*("`@("`J('5P8V]M:6YG('-Y;F-S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!W<FET95-Y;F-3=6UM87)Y*"1S>6YC261E
M;G1I9FEE<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-L:65N
M=$%N8VAO<DYE>'0L("1S97)V97)!;F-H;W).97AT*0H@("`@>PH@("`@("`@
M(&EF("@A:7-S970H)'-E<G9E<D%N8VAO<DYE>'0I('Q\("%I<U]A<G)A>2@D
M<V5R=F5R06YC:&]R3F5X="DI('L*("`@("`@("`@("`@)'1H:7,M/FQO9TUE
M<W-A9V4H)U-Y;F--3"!I;G1E<FYA;"!E<G)O<CH@;F\@86YC:&]R('!R;W9I
M9&5D("<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G:6X@=W)I
M=&53>6YC4W5M;6%R>2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@
M("`@9&EE*"=3>6YC34P@:6YT97)N86P@97)R;W(Z(&YO(&%N8VAO<B!P<F]V
M:61E9"!I;B!W<FET95-Y;F-3=6UM87)Y)RD["B`@("`@("`@?0H*("`@("`@
M("!F;W)E86-H("AA<G)A>5]K97ES*"1S97)V97)!;F-H;W).97AT*2!A<R`D
M='EP92D@>PH@("`@("`@("`@("`D<R`]("1S>6YC261E;G1I9FEE<B`N("<Z
M<W5M;6%R>3HG("X@)'1Y<&4["@H@("`@("`@("`@("`O+R!3970@)&QO8VED
M+@H@("`@("`@("`@("`D:6YF;R`]("9N97<@1&%T851R965/8FIE8W0H)',I
M.PH@("`@("`@("`@("`D:6YF;RT^<V5T*"=#;&EE;G1!;F-H;W(G+"`D8VQI
M96YT06YC:&]R3F5X="D["B`@("`@("`@("`@("1I;F9O+3YS970H)U-E<G9E
M<D%N8VAO<B<L("1S97)V97)!;F-H;W).97AT*3L*("`@("`@("`@("`@)'(@
M/2`D=&AI<RT^7V1A=&%T<F5E+3YA9&0H)&EN9F\I.PH@("`@("`@("`@("!I
M9B`H:7-?82@D<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M+R\@3V)J96-T(&%L<F5A9'D@97AI<W1S.B!U<&1A=&4@:6YS=&5A9"X*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9&%T871R964M/G5P9&%T941A=&$H)&EN
M9F\I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?8V%C:&5;
M)&EN9F\M/F=E=$YA;64H*5T@/2`D:6YF;SL*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#<F5A=&4@82!M87`@96YT<FEE<R!T;R!M87`@8F5T
M=V5E;B!S97)V97(@86YD(&-L:65N="!)1',N"B`@("`@*@H@("`@("H@4'5T
M<R!A(&=I=F5N(&-L:65N="`D8W5I9"!A;F0@2&]R9&4@<V5R=F5R("1S=6ED
M('!A:7(@:6YT;R!T:&4*("`@("`J(&UA<"!T86)L92!T;R!A;&QO=R!M87!P
M:6YG(&)E='=E96X@=&AE(&-L:65N="=S(&%N9"!S97)V97(G<PH@("`@("H@
M241S+B`@06-T=6%L;'D@=&AE<F4@87)E('1W;R!M87!S.B!F<F]M('1H92!S
M=6ED('1O('1H92!C=6ED"B`@("`@*B!A;F0@=FEC92!V97)S82X*("`@("`J
M($EF(&%N(&5N=')Y(&%L<F5A9'D@97AI<W1S+"!I="!I<R!O=F5R=W)I='1E
M;BX*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E56ED36%P*"1S>6YC261E
M;G1I9FEE<BP@)'1Y<&4L("1C=6ED+"`D<W5I9"P@)'1S/3`I"B`@("!["B`@
M("`@("`@+R\@4V5T("1C=6ED+@H@("`@("`@("1G:60@/2`F;F5W($1A=&%4
M<F5E3V)J96-T*"1S>6YC261E;G1I9FEE<B`N("<Z)R`N("1T>7!E"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G.G-U:60R8W5I9#HG
M("X@)'-U:60I.PH@("`@("`@("1G:60M/G-E="@G9&%T87-T;W)E)RP@)'1Y
M<&4I.PH@("`@("`@("1G:60M/G-E="@G8W5I9"<L("1C=6ED*3L*("`@("`@
M("`D9VED+3YS970H)W1S)RP@)'1S*3L*"B`@("`@("`@)'(@/2`D=&AI<RT^
M7V1A=&%T<F5E+3YA9&0H)&=I9"D["B`@("`@("`@:68@*&ES7V$H)'(L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@+R\@3V)J96-T(&%L<F5A9'D@
M97AI<W1S.B!U<&1A=&4@:6YS=&5A9"X*("`@("`@("`@("`@)'(@/2`D=&AI
M<RT^7V1A=&%T<F5E+3YU<&1A=&5$871A*"1G:60I.PH@("`@("`@('T*("`@
M("`@("`D=&AI<RT^7V-A8VAE6R1G:60M/F=E=$YA;64H*5T@/2`D9VED.PH@
M("`@("`@("1T:&ES+3YD:65/;D5R<F]R*"1R+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH*("`@("`@("`O+R!3970@)&=L;V)A;'5I9`H@("`@("`@("1L:60@
M/2`F;F5W($1A=&%4<F5E3V)J96-T*"1S>6YC261E;G1I9FEE<B`N("<Z)R`N
M("1T>7!E"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G
M.F-U:60R<W5I9#HG("X@)&-U:60I.PH@("`@("`@("1L:60M/G-E="@G<W5I
M9"<L("1S=6ED*3L*("`@("`@("`D<B`]("1T:&ES+3Y?9&%T871R964M/F%D
M9"@D;&ED*3L*("`@("`@("!I9B`H:7-?82@D<BP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`O+R!/8FIE8W0@86QR96%D>2!E>&ES=',Z('5P9&%T
M92!I;G-T96%D+@H@("`@("`@("`@("`D<B`]("1T:&ES+3Y?9&%T871R964M
M/G5P9&%T941A=&$H)&QI9"D["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?
M8V%C:&5;)&QI9"T^9V5T3F%M92@I72`]("1L:60["B`@("`@("`@)'1H:7,M
M/F1I94]N17)R;W(H)'(L(%]?1DE,15]?+"!?7TQ)3D5?7RD["@H@("`@("`@
M("\O($EF('1A<VMS(&%N9"!E=F5N=',@87)E(&AA;F1L960@870@;VYC92P@
M=V4@;F5E9"!T;R!S=&]R90H@("`@("`@("\O('1H92!M87`@96YT<GD@:6X@
M8F]T:"!D871A8F%S97,Z"B`@("`@("`@)'-E<W-I;VX@/28@)%]315-324].
M6R=3>6YC34PN<W1A=&4G73L*("`@("`@("`D9&5V:6-E(#TF("1S97-S:6]N
M+3YG971$979I8V4H*3L*"B`@("`@("`@:68@*"1D979I8V4M/FAA;F1L951A
M<VMS26Y#86QE;F1A<B@I"B`@("`@("`@("`@("8F("@D='EP92`]/2`G=&%S
M:W,G('Q\("1T>7!E(#T]("=C86QE;F1A<B<I("D@>PH@("`@("`@("`@("`D
M='EP92`]("1T>7!E(#T]("=T87-K<R<@/R`G8V%L96YD87(G(#H@)W1A<VMS
M)R`[("\O('1H92!O=&AE<B!O;F4*"B`@("`@("`@("`@("\O(%-E="`D8W5I
M9"X*("`@("`@("`@("`@)&=I9"`]("9N97<@1&%T851R965/8FIE8W0H)'-Y
M;F-)9&5N=&EF:65R("X@)SHG("X@)'1Y<&4*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+B`G.G-U:60R8W5I9#HG("X@)'-U:60I
M.PH@("`@("`@("`@("`D9VED+3YS970H)V1A=&%S=&]R92<L("1T>7!E*3L*
M("`@("`@("`@("`@)&=I9"T^<V5T*"=C=6ED)RP@)&-U:60I.PH@("`@("`@
M("`@("`D9VED+3YS970H)W1S)RP@)'1S*3L*"B`@("`@("`@("`@("1R(#T@
M)'1H:7,M/E]D871A=')E92T^861D*"1G:60I.PH@("`@("`@("`@("!I9B`H
M:7-?82@D<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@+R\@
M3V)J96-T(&%L<F5A9'D@97AI<W1S.B!U<&1A=&4@:6YS=&5A9"X*("`@("`@
M("`@("`@("`@("1R(#T@)'1H:7,M/E]D871A=')E92T^=7!D871E1&%T82@D
M9VED*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V-A8VAE
M6R1G:60M/F=E=$YA;64H*5T@/2`D9VED.PH@("`@("`@("`@("`D=&AI<RT^
M9&EE3VY%<G)O<B@D<BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@
M("`@("\O(%-E="`D9VQO8F%L=6ED"B`@("`@("`@("`@("1L:60@/2`F;F5W
M($1A=&%4<F5E3V)J96-T*"1S>6YC261E;G1I9FEE<B`N("<Z)R`N("1T>7!E
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)SIC
M=6ED,G-U:60Z)R`N("1C=6ED*3L*("`@("`@("`@("`@)&QI9"T^<V5T*"=S
M=6ED)RP@)'-U:60I.PH@("`@("`@("`@("`D<B`]("1T:&ES+3Y?9&%T871R
M964M/F%D9"@D;&ED*3L*("`@("`@("`@("`@:68@*&ES7V$H)'(L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("\O($]B:F5C="!A;')E861Y
M(&5X:7-T<SH@=7!D871E(&EN<W1E860N"B`@("`@("`@("`@("`@("`D<B`]
M("1T:&ES+3Y?9&%T871R964M/G5P9&%T941A=&$H)&QI9"D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)'1H:7,M/E]C86-H95LD;&ED+3YG971.86UE
M*"E=(#T@)&QI9#L*("`@("`@("`@("`@)'1H:7,M/F1I94]N17)R;W(H)'(L
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@=&EM97-T86UP("AI9B!S970I(&]F('1H
M92!L87-T(&-H86YG92!T;R!T:&4*("`@("`J(&]B:CIG=6ED+"!T:&%T('=A
M<R!C875S960@8GD@=&AE(&-L:65N="X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!4:&ES(&ES('-T;W)E9"!T;PH@("`@
M("H@879O:60@;6ER<F]R:6YG('1H97-E(&-H86YG97,@8F%C:R!T;R!T:&4@
M8VQI96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#:&%N9V544R@D<WEN
M8TED96YT:69I97(L("1D871A8F%S92P@)'-U:60I"B`@("!["B`@("`@("`@
M)&=I9"`])B`D=&AI<RT^7V=E=$]B*"1S>6YC261E;G1I9FEE<B`N("<Z)R`N
M("1D871A8F%S92`N("<Z<W5I9#)C=6ED.B<@+B`D<W5I9"D["B`@("`@("`@
M:68@*&ES7V$H)&=I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&=I9"T^
M9V5T*"=T<R<I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S('1H
M92!(;W)D92!S97)V97(@9W5I9"`H;&EK90H@("`@("H@:W)O;F]L:71H.C!D
M,6(T,35F8S$R-&0S-#(W-S(R93DU9C!E.3(V8C<U*2!F;W(@82!G:79E;B!C
M;&EE;G0*("`@("`J(&-U:60N(%)E='5R;G,@9F%L<V4@:68@;F\@<W5C:"!I
M9"!I<R!S=&]R960@>65T+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($]P<&]S:71E(&]F(&=E=$QO8TED('=H:6-H(')E
M='5R;G,@=&AE(&QO8VED(&9O<B!A(&=I=F5N(&=U:60N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%-U:60H)'-Y;F-)9&5N=&EF:65R+"`D='EP92P@)&-U
M:60I"B`@("!["B`@("`@("`@)&QI9"`])B`D=&AI<RT^7V=E=$]B*"1S>6YC
M261E;G1I9FEE<B`N("<Z)R`N("1T>7!E("X@)SIC=6ED,G-U:60Z)R`N("1C
M=6ED*3L*("`@("`@("!I9B`H:7-?82@D;&ED+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D;&ED+3YG970H)W-U:60G*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($-O;G9E<G1S(&$@<W5I9"!S97)V97(@:60@*&DN92X@2&]R9&4@1U5)
M1"D@=&\@82!C=6ED(&-L:65N="!)1`H@("`@("H@87,@=7-E9"!B>2!T:&4@
M<WEN8R!C;&EE;G0@*&QI:V4@,3(I(')E='5R;G,@9F%L<V4@:68@;F\@<W5C
M:`H@("`@("H@:60@:7,@<W1O<F5D('EE="X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0W5I9"@D<WEN
M8TED96YT:69I97(L("1D871A8F%S92P@)'-U:60I"B`@("!["B`@("`@("`@
M)&=I9"`])B`D=&AI<RT^7V=E=$]B*"1S>6YC261E;G1I9FEE<B`N("<Z)R`N
M("1D871A8F%S92`@+B`G.G-U:60R8W5I9#HG("X@)'-U:60I.PH@("`@("`@
M(&EF("AI<U]A*"1G:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1G:60M
M/F=E="@G8W5I9"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@3&]G<R!A(&UE
M<W-A9V4@:6X@=&AE(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI
M>&5D("1M97-S86=E("`@("!%:71H97(@82!S=')I;F<@;W(@82!014%27T5R
M<F]R(&]B:F5C="X*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&4@("`@("`@
M5VAA="!F:6QE('=A<R!T:&4@;&]G(&9U;F-T:6]N(&-A;&QE9"!F<F]M"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("AE+F<N(%]?1DE,15]?
M*3\*("`@("`J($!P87)A;2!I;G1E9V5R("1L:6YE("`@("`@5VAA="!L:6YE
M('=A<R!T:&4@;&]G(&9U;F-T:6]N(&-A;&QE9"!F<F]M"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("AE+F<N(%]?3$E.15]?*3\*("`@("`J
M($!P87)A;2!I;G1E9V5R("1P<FEO<FET>2`@5&AE('!R:6]R:71Y(&]F('1H
M92!M97-S86=E+B!/;F4@;V8Z"B`@("`@*B`\<')E/@H@("`@("H@4$5!4E],
M3T=?14U%4D<*("`@("`J(%!%05)?3$]'7T%,15)4"B`@("`@*B!014%27TQ/
M1U]#4DE4"B`@("`@*B!014%27TQ/1U]%4E(*("`@("`J(%!%05)?3$]'7U=!
M4DY)3D<*("`@("`J(%!%05)?3$]'7TY/5$E#10H@("`@("H@4$5!4E],3T=?
M24Y&3PH@("`@("H@4$5!4E],3T=?1$5"54<*("`@("`J(#PO<')E/@H@("`@
M("HO"B`@("!F=6YC=&EO;B!L;V=-97-S86=E*"1M97-S86=E+"`D9FEL92`]
M(%]?1DE,15]?+"`D;&EN92`](%]?3$E.15]?+`H@("`@("`@("`@("`@("`@
M("`@("`@("`D<')I;W)I='D@/2!014%27TQ/1U])3D9/*0H@("`@>PH@("`@
M("`@(&EF("AI<U]S=')I;F<H)&UE<W-A9V4I*2!["B`@("`@("`@("`@("1M
M97-S86=E(#T@(E-Y;F--3#H@(B`N("1M97-S86=E.PH@("`@("`@('T*("`@
M("`@("!(;W)D93HZ;&]G365S<V%G92@D;65S<V%G92P@)&9I;&4L("1L:6YE
M+"`D<')I;W)I='DI.PH@("`@?0H*("`@(&9U;F-T:6]N(&UA<$-L:65N=$-A
M=&5G;W)Y,E-E<G9E<B@D8VQI96YT0V%T96=O<GDL("1S=6UM87)Y("`]("=U
M;FMN;W=N)RD@>PH*("`@("`@("!I9B`H96UP='DH)&-L:65N=$-A=&5G;W)Y
M*2D@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H@("`@("`@
M("1T:&ES+3Y?;&]A9$-A=&5G;W)I97--87`H*3L*"B`@("`@("`@:68@*"%E
M;7!T>2@D=&AI<RT^7V-A=&5G;W)I97--87!;)&-L:65N=$-A=&5G;W)Y72D@
M)B8*("`@("`@("`@("`@(6ES7V%R<F%Y*"1T:&ES+3Y?8V%T96=O<FEE<TUA
M<%LD8VQI96YT0V%T96=O<GE=*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]C871E9V]R:65S36%P6R1C;&EE;G1#871E9V]R>5T["B`@("`@("`@
M?0H*("`@("`@("`O*B!S=&]R92!T:&4@8VQI96YT0V%T96=O<GD@87,@;&%C
M:VEN9R!A(&UA<"X@*B\*("`@("`@("`D=&AI<RT^7V-A=&5G;W)I97--87!;
M)&-L:65N=$-A=&5G;W)Y72`](&%R<F%Y*"1S=6UM87)Y*3L*("`@("`@("`D
M=&AI<RT^7W-T;W)E0V%T96=O<FEE<TUA<"@I.PH@("`@("`@(')E='5R;B`D
M8VQI96YT0V%T96=O<GD["B`@("!]"@H@("`@9G5N8W1I;VX@;6%P4V5R=F5R
M0V%T96=O<GDR0VQI96YT*"1S97)V97)#871E9V]R>2P@)'-U;6UA<GD@/2`G
M=6YK;F]W;B<I('L*"B`@("`@("`@:68@*&5M<'1Y*"1S97)V97)#871E9V]R
M>2DI('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*"B`@("`@
M("`@)'1H:7,M/E]L;V%D0V%T96=O<FEE<TUA<"@I.PH*("`@("`@("`D8R`]
M(&%R<F%Y7W-E87)C:"@D<V5R=F5R0V%T96=O<GDL("1T:&ES+3Y?8V%T96=O
M<FEE<TUA<"D["B`@("`@("`@:68@*"%E;7!T>2@D8RD@)B8@(6ES7V%R<F%Y
M*"1C*2D@>PH@("`@("`@("`@("!R971U<FX@)&,["B`@("`@("`@?0H*("`@
M("`@("`O*B!3=&]R92!T:&4@<V5R=F5R0V%T96=O<GD@87,@;&%C:VEN9R!A
M(&UA<"X@*B\*("`@("`@("`D=&AI<RT^7VUI<W-I;F=397)V97)#871E9V]R
M:65S6R1S97)V97)#871E9V]R>5T@/2`D<W5M;6%R>3L*("`@("`@("`D=&AI
M<RT^7W-T;W)E0V%T96=O<FEE<TUA<"@I.PH*("`@("`@("!R971U<FX@)'-E
M<G9E<D-A=&5G;W)Y.PH@("`@?0H*("`@(&9U;F-T:6]N(%]L;V%D0V%T96=O
M<FEE<TUA<"@I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?
M8V%T96=O<FEE<TUA<"DI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@
M('T*"B`@("`@("`@)&UA<"`])B`D=&AI<RT^7V=E=$]B*"1?4T534TE/3ELG
M4WEN8TU,+G-T871E)UTM/F=E=%-Y;F-)9&5N=&EF:65R*"D@+B`G.F-A=&5G
M;W)I97,G*3L*("`@("`@("!I9B`H:7-?82@D;6%P+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V%T96=O<FEE<TUA<"`](&%R<F%Y
M*"D["B`@("`@("`@("`@("1T:&ES+3Y?;6ES<VEN9U-E<G9E<D-A=&5G;W)I
M97,@/2!A<G)A>2@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T
M:&ES+3Y?8V%T96=O<FEE<TUA<"`]("1M87`M/F=E="@G;6%P)RD["B`@("`@
M("`@("`@("1T:&ES+3Y?;6ES<VEN9U-E<G9E<D-A=&5G;W)I97,@/2`D;6%P
M+3YG970H)VUI<W-I;F=397)V97)#871E9V]R:65S)RD["B`@("`@("`@?0H@
M("`@?0H*("`@(&9U;F-T:6]N(%]S=&]R94-A=&5G;W)I97--87`H*0H@("`@
M>PH@("`@("`@(&EF("@A:7-?87)R87DH)'1H:7,M/E]C871E9V]R:65S36%P
M*2D@>PH@("`@("`@("`@("!R971U<FX[("\O(&YO=&AI;F<@=&\@9&\*("`@
M("`@("!]"@H@("`@("`@("1M87`@/2`F;F5W($1A=&%4<F5E3V)J96-T*"1?
M4T534TE/3ELG4WEN8TU,+G-T871E)UTM/F=E=%-Y;F-)9&5N=&EF:65R*"D*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("<Z8V%T96=O
M<FEE<R<I.PH@("`@("`@("1M87`M/G-E="@G;6%P)RP@)'1H:7,M/E]C871E
M9V]R:65S36%P*3L*("`@("`@("`D;6%P+3YS970H)VUI<W-I;F=397)V97)#
M871E9V]R:65S)RP@)'1H:7,M/E]M:7-S:6YG4V5R=F5R0V%T96=O<FEE<RD[
M"@H@("`@("`@("1R(#T@)'1H:7,M/E]D871A=')E92T^861D*"1M87`I.PH@
M("`@("`@(&EF("AI<U]A*"1R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("\O($]B:F5C="!A;')E861Y(&5X:7-T<SH@=7!D871E(&EN<W1E860N
M"B`@("`@("`@("`@("1R(#T@)'1H:7,M/E]D871A=')E92T^=7!D871E1&%T
M82@D;6%P*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]C86-H95LD;6%P
M+3YG971.86UE*"E=(#T@)&UA<#L*("`@("`@("`D=&AI<RT^9&EE3VY%<G)O
M<B@D<BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%1H:7,@:7,@82!S;6%L;"!H96QP97(@9G5N8W1I;VX@=&AA="!C86X@
M8F4@:6YC;'5D960@=&\@8VAE8VL*("`@("`J('=H971H97(@82!G:79E;B`D
M;V)J(&ES(&$@4$5!4E]%<G)O<B!O<B!N;W0N($EF('-O+"!I="!L;V=S"B`@
M("`@*B!T;R!D96)U9RP@=F%R7V1U;7!S('1H92`D;V)J(&%N9"!E>&ET<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@9&EE3VY%<G)O<B@D;V)J+"`D9FEL92`]
M(%]?1DE,15]?+"`D;&EN92`](%]?3$E.15]?*0H@("`@>PH@("`@("`@(&EF
M("@A:7-?82@D;V)J+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;CL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YL;V=-97-S86=E*"=3
M>6YC34PZ(%!%05(@17)R;W(Z("<@+B`D;V)J+3YG971-97-S86=E*"DL("1F
M:6QE+"`D;&EN92P@4$5!4E],3T=?15)2*3L*("`@("`@("!P<FEN="`B4$5!
M4B!%4E)/4EQN7&XB.PH@("`@("`@('9A<E]D=6UP*"1O8FHI.PH@("`@?0H*
M("`@(&9U;F-T:6]N("9?9V5T3V(H)&YA;64I"B`@("!["B`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7V-A8VAE6R1N86UE72DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]C86-H95LD;F%M95T@/28@)'1H:7,M/E]D871A=')E92T^9V5T
M3V)J96-T*"1N86UE*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?8V%C:&5;)&YA;65=.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U-Y
M;F--3"]#;VUM86YD+P``````````````````````````````````````````
M```````````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<T-``P,C$Q-#<`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O4WEN8TU,+T-O;6UA;F0O06QE<G0N<&AP````````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(U,#(U`#$P-3$U-#,S-S0T`#`R
M,C<S,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`H*:6YC;'5D95]O;F-E("=3>6YC34PO0V]M;6%N9"YP:'`G.PH*
M+RHJ"B`J(%1H92!3>6YC34Q?06QE<G0@8VQA<W,@<')O=FED97,@82!3>6YC
M34P@:6UP;&5M96YT871I;VX@;V8*("H@=&AE($%L97)T(&-O;6UA;F0@87,@
M9&5F:6YE9"!I;B!3>6YC34P@4F5P<F5S96YT871I;VX@4')O=&]C;VPL"B`J
M('9E<G-I;VX@,2XQ(#4N-2XR+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]3
M>6YC34PO4WEN8TU,+T-O;6UA;F0O06QE<G0N<&AP+'8@,2XQ."XQ,"XY(#(P
M,#8O,#$O,S$@,3<Z-34Z,S$@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`S+3(P,#8@06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($%N=&AO;GD@36EL;',@/&%M
M:6QL<T!P>7)A;6ED-BYC;VT^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`
M<&%C:V%G92!3>6YC34P*("HO"F-L87-S(%-Y;F--3%]#;VUM86YD7T%L97)T
M(&5X=&5N9',@4WEN8TU,7T-O;6UA;F0@>PH*("`@("\J*@H@("`@("H@0'9A
M<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7V%L97)T.PH*("`@("\J*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<V]U<F-E3&]C
M55)).PH*("`@("\J*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?=&%R9V5T3&]C55)).PH*("`@("\J*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?;65T84%N8VAO<DYE>'0["@H@("`@+RHJ
M"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?;65T84%N
M8VAO<DQA<W0["@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@;F5W(&EN<W1A
M;F-E(&]F($%L97)T+@H@("`@("HO"B`@("!F=6YC=&EO;B!3>6YC34Q?0V]M
M;6%N9%]!;&5R="@D86QE<G0@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@D
M86QE<G0@(3T@;G5L;"D@>PH@("`@("`@("`@("`D=&AI<RT^7V%L97)T(#T@
M)&%L97)T.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!O=71P=70H
M)&-U<G)E;G1#;61)1"P@)B1O=71P=70I"B`@("!["B`@("`@("`@9VQO8F%L
M("1B86-K96YD.PH*("`@("`@("`D871T<G,@/2!A<G)A>2@I.PH@("`@("`@
M("1S=&%T92`]("8D7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==.PH*("`@("`@
M("`O+R!(86YD;&4@=6YA=71H;W)I>F5D(&9I<G-T+@H@("`@("`@(&EF("@A
M)'-T871E+3YI<T%U=&AO<FEZ960H*2D@>PH@("`@("`@("`@("`D<W1A='5S
M(#T@)FYE=R!3>6YC34Q?0V]M;6%N9%]3=&%T=7,H4D534$].4T5?24Y604Q)
M1%]#4D5$14Y424%,4RP@)T%L97)T)RD["B`@("`@("`@("`@("1S=&%T=7,M
M/G-E=$-M9%)E9B@D=&AI<RT^7V-M9$E$*3L*("`@("`@("`@("`@)&-U<G)E
M;G1#;61)1"`]("1S=&%T=7,M/F]U='!U="@D8W5R<F5N=$-M9$E$+"`D;W5T
M<'5T*3L*("`@("`@("`@("`@<F5T=7)N("1C=7)R96YT0VUD240["B`@("`@
M("`@?0H*("`@("`@("`D9&%T86)A<V4@/2`D=&AI<RT^7W1A<F=E=$QO8U52
M23L*"B`@("`@("`@+R\@4W1O<F4@8VQI96YT)W,@3F5X="!!;F-H;W(@:6X@
M4W1A=&4N("!!9G1E<B!S=6-C97-S9G5L('-Y;F,*("`@("`@("`O+R!T:&ES
M(&ES('1H96X@=W)I='1E;B!T;R!P97)S:7-T96YC92!F;W(@;F5G;W1I871I
M;VX@;V8*("`@("`@("`O+R!F=7)T:&5R('-Y;F-S+@H@("`@("`@("1S=&%T
M92T^<V5T0VQI96YT06YC:&]R3F5X="@D9&%T86)A<V4L("1T:&ES+3Y?;65T
M84%N8VAO<DYE>'0I.PH*("`@("`@("`D:6YF;R`]("1B86-K96YD+3YG9713
M>6YC4W5M;6%R>2@D<W1A=&4M/F=E=%-Y;F-)9&5N=&EF:65R*"DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T
M87)G971,;V-54DDI.PH*("`@("`@("!I9B`H:7-?82@D:6YF;RP@)T1A=&%4
M<F5E3V)J96-T)RDI('L*("`@("`@("`@("`@)'@@/2`D:6YF;RT^9V5T*"=#
M;&EE;G1!;F-H;W(G*3L*("`@("`@("`@("`@)&-L:65N=&QA<W0@/2`D>%LD
M9&%T86)A<V5=.PH@("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G92AS
M<')I;G1F*"=P<F5V:6]U<R!S>6YC(&9O=6YD(&9O<B!D871A8F%S93H@)7,[
M(&-L:65N="UT<SH@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1D871A8F%S92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D8VQI96YT;&%S="DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?1$5"54<I.PH@("`@("`@("`@("`D>"`]("1I;F9O+3YG970H)U-E
M<G9E<D%N8VAO<B<I.PH@("`@("`@("`@("`D<W1A=&4M/G-E=%-E<G9E<D%N
M8VAO<DQA<W0H)&1A=&%B87-E+"`D>%LD9&%T86)A<V5=*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G92AS<')I
M;G1F*"=3>6YC34PZ($YO(&EN9F\@86)O=70@<')E=FEO=7,@<WEN8W,@9F]U
M;F0@9F]R(&ED("5S(&%N9"!D871A8F%S92`E<R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T871E+3YG9713>6YC261E
M;G1I9FEE<B@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1D871A8F%S92DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@
M("`@("`@("`@("`D8VQI96YT;&%S="`](#`["B`@("`@("`@("`@("1S=&%T
M92T^<V5T4V5R=F5R06YC:&]R3&%S="@D9&%T86)A<V4L(#`I.PH@("`@("`@
M('T*"B`@("`@("`@+R\@4V5T(%-E<G9E<B!!;F-H;W(@9F]R('1H:7,@<WEN
M8R!T;R!C=7)R96YT('1I;64N"B`@("`@("`@)'-T871E+3YS971397)V97)!
M;F-H;W).97AT*"1D871A8F%S92P@=&EM92@I*3L*("`@("`@("!I9B`H*"1C
M;&EE;G1L87-T('Q\("1C;&EE;G1L87-T(#T]/2`G,"<I"B`@("`@("`@("`@
M("`@("`@)B8@)&-L:65N=&QA<W0@/3T@)'1H:7,M/E]M971A06YC:&]R3&%S
M="D@>PH@("`@("`@("`@("`O+R!,87-T(%-Y;F,@06YC:&]R(&UA=&-H97,L
M(%1W;U=A>5-Y;F,@=VEL;"!D;RX*("`@("`@("`@("`@)&-O9&4@/2!215-0
M3TY315]/2SL*("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H(E-Y
M;F--3#H@06YC:&]R(&UA=&-H+"!4=V]787E3>6YC('-I;F-E("(*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`N("1C;&EE;G1L87-T+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?
M+"!014%27TQ/1U]$14)51RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@:68@*"1C;&EE;G1L87-T*2!["B`@("`@("`@("`@("`@("`D8F%C:V5N
M9"T^;&]G365S<V%G92@G8VQI96YT(')E<75E<W1E9"!S>6YC('=I=&@@86YC
M:&]R('1S("<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]M971A06YC:&]R3&%S="`N("<@8G5T('-E<G9E<B`G("X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=H87,@=&EM
M97-T86UP)R`N("1C;&EE;G1L87-T("X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("<@;VX@9FEL92<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7TE.1D\I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1B86-K96YD
M+3YL;V=-97-S86=E*")3>6YC34PZ($%N8VAO<B!M:7-M871C:"P@96YF;W)C
M:6YG(%-L;W=3>6YC(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@
M("`@("`@("1C;&EE;G1L87-T(#T@,#L*("`@("`@("`@("`@)'-T871E+3YS
M971397)V97)!;F-H;W),87-T*"1D871A8F%S92P@,"D["B`@("`@("`@("`@
M(&EF("@D=&AI<RT^7V%L97)T(#T](#(P,2D@>PH@("`@("`@("`@("`@("`@
M+RH@4VQO=W-Y;F,@<F5Q=65S=&5D(&9R;VT@8VQI96YT(&%N>7=A>3H@:G5S
M="!A8VMN;W=L961G92X@*B\*("`@("`@("`@("`@("`@("1C;V1E(#T@4D53
M4$].4T5?3TL["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`O*B!-:7-M871C:"P@96YF;W)C92!S;&]W('-Y;F,N("HO"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V%L97)T(#T@,C`Q.PH@("`@("`@("`@("`@("`@
M)&-O9&4@/2`U,#@["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("1S=&%T=7,@/2`F;F5W(%-Y;F--3%]#;VUM86YD7U-T871U<R@D8V]D92P@
M)T%L97)T)RD["B`@("`@("`@)'-T871U<RT^<V5T0VUD4F5F*"1T:&ES+3Y?
M8VUD240I.PH@("`@("`@(&EF("@D=&AI<RT^7W-O=7)C94QO8U5222`A/2!N
M=6QL*2!["B`@("`@("`@("`@("1S=&%T=7,M/G-E=%-O=7)C95)E9B@D=&AI
M<RT^7W-O=7)C94QO8U5222D["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI
M<RT^7W1A<F=E=$QO8U5222`A/2!N=6QL*2!["B`@("`@("`@("`@("1S=&%T
M=7,M/G-E=%1A<F=E=%)E9B@D=&AI<RT^7W1A<F=E=$QO8U5222D["B`@("`@
M("`@?0H*("`@("`@("`O+R!-:7)R;W(@3F5X="!!;F-H;W(@9G)O;2!C;&EE
M;G0@8F%C:R!T;R!C;&EE;G0N"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M;65T84%N8VAO<DYE>'0I*2!["B`@("`@("`@("`@("1S=&%T=7,M/G-E=$ET
M96U$871A06YC:&]R3F5X="@D=&AI<RT^7VUE=&%!;F-H;W).97AT*3L*("`@
M("`@("!]"@H@("`@("`@("\O($UI<G)O<B!,87-T($%N8VAO<B!F<F]M(&-L
M:65N="!B86-K('1O(&-L:65N="X*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]M971A06YC:&]R3&%S="DI('L*("`@("`@("`@("`@)'-T871U<RT^<V5T
M271E;41A=&%!;F-H;W),87-T*"1T:&ES+3Y?;65T84%N8VAO<DQA<W0I.PH@
M("`@("`@('T*"B`@("`@("`@)&-U<G)E;G1#;61)1"`]("1S=&%T=7,M/F]U
M='!U="@D8W5R<F5N=$-M9$E$+"`D;W5T<'5T*3L*"B`@("`@("`@:68@*"1S
M=&%T92T^:7-!=71H;W)I>F5D*"DI('L*("`@("`@("`@("`@)&]U='!U="T^
M<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=!;&5R="<L("1A='1R
M<RD["@H@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E
M+3YG97154DDH*2P@)T-M9$E$)RP@)&%T=')S*3L*("`@("`@("`@("`@)&-H
M87)S(#T@)&-U<G)E;G1#;61)1#L*("`@("`@("`@("`@)&]U='!U="T^8VAA
M<F%C=&5R<R@D8VAA<G,I.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M
M96YT*"1S=&%T92T^9V5T55))*"DL("=#;61)1"<I.PH*("`@("`@("`@("`@
M)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=$871A
M)RP@)&%T=')S*3L*("`@("`@("`@("`@)&-H87)S(#T@)'1H:7,M/E]A;&5R
M=#L*("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@
M("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))
M*"DL("=$871A)RD["@H@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE
M;G0H)'-T871E+3YG97154DDH*2P@)TET96TG+"`D871T<G,I.PH*("`@("`@
M("`@("`@:68@*"1T:&ES+3Y?<V]U<F-E3&]C55))("$](&YU;&PI('L*("`@
M("`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E
M=%5222@I+"`G5&%R9V5T)RP@)&%T=')S*3L*("`@("`@("`@("`@("`@("1O
M=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G3&]C55))
M)RP@)&%T=')S*3L*("`@("`@("`@("`@("`@("1C:&%R<R`]("1T:&ES+3Y?
M<V]U<F-E3&]C55)).PH@("`@("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C
M=&5R<R@D8VAA<G,I.PH@("`@("`@("`@("`@("`@)&]U='!U="T^96YD16QE
M;65N="@D<W1A=&4M/F=E=%5222@I+"`G3&]C55)))RD["B`@("`@("`@("`@
M("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=4
M87)G970G*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1T:&ES
M+3Y?=&%R9V5T3&]C55))("$](&YU;&PI('L*("`@("`@("`@("`@("`@("1O
M=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G4V]U<F-E
M)RP@)&%T=')S*3L*("`@("`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE
M;65N="@D<W1A=&4M/F=E=%5222@I+"`G3&]C55)))RP@)&%T=')S*3L*("`@
M("`@("`@("`@("`@("1C:&%R<R`]("1T:&ES+3Y?=&%R9V5T3&]C55)).PH@
M("`@("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@
M("`@("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E
M=%5222@I+"`G3&]C55)))RD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YE
M;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=3;W5R8V4G*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S
M=&%T92T^9V5T55))*"DL("=-971A)RP@)&%T=')S*3L*"B`@("`@("`@("`@
M("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5224UE=&$H*2P@
M)T%N8VAO<B<L("1A='1R<RD["@H@("`@("`@("`@("`D;W5T<'5T+3YS=&%R
M=$5L96UE;G0H)'-T871E+3YG97154DE-971A*"DL("=,87-T)RP@)&%T=')S
M*3L*("`@("`@("`@("`@)&-H87)S(#T@)'-T871E+3YG971397)V97)!;F-H
M;W),87-T*"1D871A8F%S92D["B`@("`@("`@("`@("1O=71P=70M/F-H87)A
M8W1E<G,H)&-H87)S*3L*("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N
M="@D<W1A=&4M/F=E=%5224UE=&$H*2P@)TQA<W0G*3L*"B`@("`@("`@("`@
M("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5224UE=&$H*2P@
M)TYE>'0G+"`D871T<G,I.PH@("`@("`@("`@("`D8VAA<G,@/2`D<W1A=&4M
M/F=E=%-E<G9E<D%N8VAO<DYE>'0H)&1A=&%B87-E*3L*("`@("`@("`@("`@
M)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@("`@("`@("`@("`D;W5T
M<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))365T82@I+"`G3F5X="<I
M.PH*("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E
M=%5224UE=&$H*2P@)T%N8VAO<B<I.PH@("`@("`@("`@("`D;W5T<'5T+3YE
M;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=-971A)RD["B`@("`@("`@
M("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TET
M96TG*3L*("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M
M/F=E=%5222@I+"`G06QE<G0G*3L*"B`@("`@("`@("`@("1C=7)R96YT0VUD
M240K*SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D8W5R<F5N=$-M9$E$
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T=&5R(&9O<B!P<F]P97)T>2!S
M;W5R8V554DDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V]U<F-E
M55))("!.97<@=F%L=64@;V8@<')O<&5R='D@<V]U<F-E55))+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!S9713;W5R8V5,;V-54DDH)'-O=7)C955222D*("`@
M('L*("`@("`@("`D=&AI<RT^7W-O=7)C955222`]("1S;W5R8V554DD["B`@
M("!]"@H@("`@9G5N8W1I;VX@9V5T5&%R9V5T3&]C55))*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]T87)G97154DD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3971T97(@9F]R('!R;W!E<G1Y('1A<F=E=%5222X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1T87)G97154DD@($YE=R!V86QU92!O
M9B!P<F]P97)T>2!T87)G97154DDN"B`@("`@*B\*("`@(&9U;F-T:6]N('-E
M=%1A<F=E=%5222@D=&%R9V5T55))*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M=&%R9V5T55))(#T@)'1A<F=E=%5223L*("`@('T*"B`@("!F=6YC=&EO;B!S
M=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD*("`@('L*("`@
M("`@("!P87)E;G0Z.G-T87)T16QE;65N="@D=7)I+"`D96QE;65N="P@)&%T
M=')S*3L*"B`@("!]"@H@("`@9G5N8W1I;VX@96YD16QE;65N="@D=7)I+"`D
M96QE;65N="D*("`@('L*("`@("`@("!G;&]B86P@)&)A8VME;F0["@H@("`@
M("`@('-W:71C:"`H8V]U;G0H)'1H:7,M/E]3=&%C:RDI('L*("`@("`@("!C
M87-E(#$Z"B`@("`@("`@("`@("1S=&%T92`]("8D7U-%4U-)3TY;)U-Y;F--
M3"YS=&%T92==.PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]T87)G971,;V-5
M4DD@(3T@)W1A<VMS)PH@("`@("`@("`@("`@("`@)B8@)'1H:7,M/E]T87)G
M971,;V-54DD@(3T@)V-A;&5N9&%R)PH@("`@("`@("`@("`@("`@)B8@)'1H
M:7,M/E]T87)G971,;V-54DD@(3T@)VYO=&5S)PH@("`@("`@("`@("`@("`@
M)B8@)'1H:7,M/E]T87)G971,;V-54DD@(3T@)V-O;G1A8W1S)RD@>PH@("`@
M("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H)T5R<F]R(2!);G9A
M;&ED(&1A=&%B87-E.B`G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`N("1T:&ES+3Y?=&%R9V5T3&]C55))"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`N("<N($]N;'D@=&%S:W,L(&-A;&5N
M9&%R+"!N;W1E<RPG"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`N("<@86YD(&-O;G1A8W1S(&%L;&]W960A)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@("`@(&1I92@B97)R;W(Z(&EN
M=F%L:60@9&%T86)A<V4A(BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1B86-K96YD+3YL;V=-97-S86=E*"=L;V]K:6YG(&9O<B!S>6YC(&9O<B`G
M("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T
M87)G971,;V-54DDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@
M("`@("`D<WEN8R`]("8@)'-T871E+3YG9713>6YC*"1T:&ES+3Y?=&%R9V5T
M3&]C55))*3L*"B`@("`@("`@("`@(&EF("@A)'-Y;F,I('L*("`@("`@("`@
M("`@("`@("1B86-K96YD+3YL;V=-97-S86=E*"=#<F5A=&4@;F5W('-Y;F,@
M9F]R("<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]T87)G971,;V-54DDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%
M0E5'*3L*"B`@("`@("`@("`@("`@("`D<WEN8R`]("9N97<@4WEN8TU,7U-Y
M;F,H)'1H:7,M/E]A;&5R="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W1A<F=E=$QO8U5222P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-O=7)C
M94QO8U5222D["B`@("`@("`@("`@("`@("`D<W1A=&4M/G-E=%-Y;F,H)'1H
M:7,M/E]T87)G971,;V-54DDL("1S>6YC*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`R.@H@("`@("`@("`@("!I
M9B`H)&5L96UE;G0@/3T@)T1A=&$G*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V%L97)T(#T@:6YT=F%L*'1R:6TH)'1H:7,M/E]C:&%R<RDI.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(#0Z
M"B`@("`@("`@("`@(&EF("@D96QE;65N="`]/2`G3&]C55)))RD@>PH@("`@
M("`@("`@("`@("`@:68@*"1T:&ES+3Y?4W1A8VM;,ET@/3T@)U-O=7)C92<I
M('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-O=7)C94QO8U5222`]
M('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H)'1H:7,M/E]3=&%C:ULR72`]/2`G5&%R9V5T)RD@>PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?=&%R9V5T3&]C55))(#T@8F%S96YA;64H<')E
M9U]R97!L86-E*"<O7#\N*B0O)RP@)R<L('1R:6TH)'1H:7,M/E]C:&%R<RDI
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@8V%S92`U.@H@("`@("`@("`@("!I9B`H)&5L
M96UE;G0@/3T@)TYE>'0G*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VUE
M=&%!;F-H;W).97AT(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@
M("`@?2!E;'-E:68@*"1E;&5M96YT(#T]("=,87-T)RD@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]M971A06YC:&]R3&%S="`]('1R:6TH)'1H:7,M/E]C
M:&%R<RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@?0H*("`@("`@("!P87)E;G0Z.F5N9$5L96UE;G0H)'5R:2P@)&5L96UE
M;G0I.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$%L97)T*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]A;&5R=#L*("`@('T*"B`@("!F=6YC=&EO
M;B!S971!;&5T*"1A;&5R="D*("`@('L*("`@("`@("`D=&AI<RT^7V%L97)T
M(#T@)&%L97)T.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+U-Y;F--3"]#;VUM86YD+T9I;F%L+G!H<```````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-S4Q,0`Q,#4Q-30S,S<T-``P,C(W,34`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"FEN8VQU
M9&5?;VYC92`G4WEN8TU,+T-O;6UA;F0N<&AP)SL*"B\J*@H@*B!4:&4@4WEN
M8TU,7T-O;6UA;F1?1FEN86P@8VQA<W,N"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+U-Y;F--3"]3>6YC34PO0V]M;6%N9"]&:6YA;"YP:'`L=B`Q+C$P+C$P
M+C4@,C`P-B\P,2\P,2`R,3HR.#HS-B!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#,M,C`P-B!!;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N
M8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@06YT:&]N>2!-:6QL
M<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*("H@0'-I;F-E("`@2&]R9&4@,RXP
M"B`J($!P86-K86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7T-O;6UA;F1?
M1FEN86P@97AT96YD<R!3>6YC34Q?0V]M;6%N9"!["@H@("`@+RHJ"B`@("`@
M*B!#<F5A=&4@=&AE(')E<W!O;G-E(&9O<B!A(&9I;F%L('1A9PH@("`@("HO
M"B`@("!F=6YC=&EO;B!O=71P=70H)&-U<G)E;G1#;61)1"P@)B1O=71P=70I
M"B`@("!["B`@("`@("`@)'-T871E(#T@)B1?4T534TE/3ELG4WEN8TU,+G-T
M871E)UT["B`@("`@("`@)&%T=')S(#T@87)R87DH*3L*"B`@("`@("`@+R\@
M268@=&AE(&-L:65N="!H87-N)W0@<V5N="!U<R!D979I8V4@:6YF;RP@<F5Q
M=65S="!I="!N;W<N"B`@("`@("`@)&1I(#T@4WEN8TU,7T1E=FEC93HZ9&5V
M:6-E26YF;R@I.PH@("`@("`@(&EF("AE;7!T>2@D9&DM/E]-86XI*2!["B`@
M("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%52
M22@I+"`G1V5T)RP@)&%T=')S*3L*"B`@("`@("`@("`@("1O=71P=70M/G-T
M87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G0VUD240G+"`D871T<G,I
M.PH@("`@("`@("`@("`D8VAA<G,@/2`D8W5R<F5N=$-M9$E$.PH@("`@("`@
M("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@("`@("`@
M("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)T-M9$E$
M)RD["@H@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E
M+3YG97154DDH*2P@)TUE=&$G+"`D871T<G,I.PH@("`@("`@("`@("`D;W5T
M<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DE-971A*"DL("=4>7!E
M)RP@)&%T=')S*3L*("`@("`@("`@("`@)&%T=')S(#T@87)R87DH*3L*("`@
M("`@("`@("`@:68@*&ES7V$H)&]U='!U="P@)UA-3%]70EA-3%]%;F-O9&5R
M)RDI('L*("`@("`@("`@("`@("`@("1C:&%R<R`]($U)345?4UE.0TU,7T1%
M5DE#15])3D9/7U="6$U,.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)&-H87)S(#T@34E-15]364Y#34Q?1$5624-%7TE.1D]?6$U,
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E
M<G,H)&-H87)S*3L*("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D
M<W1A=&4M/F=E=%5222@I+"`G5'EP92<I.PH@("`@("`@("`@("`D;W5T<'5T
M+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=-971A)RD["@H@("`@
M("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH
M*2P@)TET96TG+"`D871T<G,I.PH@("`@("`@("`@("`D;W5T<'5T+3YS=&%R
M=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)U1A<F=E="<L("1A='1R<RD[
M"B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E
M=%5222@I+"`G3&]C55)))RP@)&%T=')S*3L*("`@("`@("`@("`@)&-H87)S
M(#T@*"1S=&%T92T^9V5T5F5R<VEO;B@I(#T](#`I(#\@)RXO9&5V:6YF,3`G
M(#H@)RXO9&5V:6YF,3$G.PH@("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T
M97)S*"1C:&%R<RD["B`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H
M)'-T871E+3YG97154DDH*2P@)TQO8U5222<I.PH@("`@("`@("`@("`D;W5T
M<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=487)G970G*3L*
M("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%52
M22@I+"`G271E;2<I.PH*("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N
M="@D<W1A=&4M/F=E=%5222@I+"`G1V5T)RD["@H@("`@("`@("`@("`O+R!-
M87)K('1H:7,@:60@9&]W;B!A<R!N965D:6YG(&$@<F5S=6QT<R!P86-K970@
M<F]U=&5D('1O"B`@("`@("`@("`@("\O('1H92!0=70@8V]M;6%N9"X*("`@
M("`@("`@("`@)'-T871E+3YS971%>'!E8W1E9%)E<W5L=%1Y<&4H)&-U<G)E
M;G1#;61)1"P@)U!U="<I.PH*("`@("`@("`@("`@)&-U<G)E;G1#;61)1"LK
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&-U<G)E;G1#;61)1#L*("`@
M('T*("`@("\J*@H@("`@("H@0W)E871E(&$@)FQT.T9I;F%L)F=T.R!O=71P
M=70N"B`@("`@*B!"969O<F4@=&AA="!C;VYT:6YU92!A('-Y;F,@:68@=&AE
M<F4@87)E('!E;F1I;F<@96YT<FEE<RX*("`@("`J(%-T871I8R!M971H;V0*
M("`@("`J+PH@("`@9G5N8W1I;VX@;W5T<'5T1FEN86PH)&-U<G)E;G1#;61)
M1"P@)B1O=71P=70I"B`@("!["B`@("`@("`@)'-T871E(#T@)B1?4T534TE/
M3ELG4WEN8TU,+G-T871E)UT["B`@("`@("`@)&%T=')S(#T@87)R87DH*3L*
M"B`@("`@("`@9VQO8F%L("1M97-S86=E1G5L;#L*("`@("`@("`O*B!)9B!T
M:&5R92=S('!E;F1I;F<@<WEN8R!D871A(&%N9"!S<&%C92!L969T(&EN('1H
M92!M97-S86=E.@H@("`@("`@("`J('-E;F0@9&%T82!N;W<N("HO"B`@("`@
M("`@:68@*"$D;65S<V%G949U;&P@)B8*("`@("`@("`@("`@("`@(&-O=6YT
M*"1P(#T@)'-T871E+3YG971096YD:6YG4WEN8W,H*2D@/B`P*2!["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1P(&%S("1P96YD:6YG4WEN8RD@>PH@("`@("`@
M("`@("`@("`@:68@*"$D;65S<V%G949U;&PI('L*("`@("`@("`@("`@("`@
M("`@("1'3$]"04Q36R=B86-K96YD)UTM/FQO9TUE<W-A9V4H)V-O;G1I;G5E
M('-Y;F,@9F]R('-Y;F-4>7!E/2<@+B`D<&5N9&EN9U-Y;F,L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@("`@("`@("`D<WEN
M8R`]("8@)'-T871E+3YG9713>6YC*"1P96YD:6YG4WEN8RD["B`@("`@("`@
M("`@("`@("`@("`@)&-U<G)E;G1#;61)1"`]("1S>6YC+3YC<F5A=&53>6YC
M3W5T<'5T*"1C=7)R96YT0VUD240L("1O=71P=70I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2`@("`@("`O*@H@("`@("`@
M("`J($1O;B=T('-E;F0@=&AE(&9I;F%L('1A9R!I9B!W92!H879E;B=T('-E
M;G0@86QL('-Y;F,@9&%T82!Y970N"B`@("`@("`@("HO"B`@("`@("`@:68@
M*"$D<W1A=&4M/FAA<U!E;F1I;F=%;&5M96YT<R@I*2!["B`@("`@("`@("`@
M("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G1FEN
M86PG+"`D871T<G,I.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT
M*"1S=&%T92T^9V5T55))*"DL("=&:6YA;"<I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1'3$]"04Q36R=B86-K96YD)UTM/FQO9TUE<W-A9V4H
M)W!E;F1I;F<@96QE;65N=',L(&YO="!S96YD:6YG(&9I;F%L('1A9R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@
M7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1C=7)R96YT0VUD240["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+U-Y;F--3"]#;VUM86YD+T=E="YP:'``````
M```````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,38Q-@`Q,#4Q-30S,S<T
M-``P,C(T,#4`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"G)E<75I<F5?;VYC92`G4WEN8TU,+T-O;6UA;F0N<&AP
M)SL*"B\J*@H@*B!4:&4@4WEN8TU,7T-O;6UA;F1?1V5T(&-L87-S+@H@*@H@
M*B!4:&ES(&-L87-S(')E<W!O;F1S('1O(&$@8VQI96YT(&=E="!R97%U97-T
M(&%N9"!R971U<FYS('1H92!$979);F8*("H@:6YF;W)M871I;VX@9F]R('1H
M92!3>6YC34P@<V5R=F5R+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]3>6YC
M34PO4WEN8TU,+T-O;6UA;F0O1V5T+G!H<"QV(#$N,30N,3`N,3`@,C`P-B\P
M-2\R.2`Q-CHT,#HS-R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M
M,C`P-B!!;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2V%R<W1E;B!&;W5R;6]N="`\9F]U
M<FUO;G1`9VUX+F1E/@H@*B!`875T:&]R("!!;G1H;VYY($UI;&QS(#QA;6EL
M;'-`<'ER86UI9#8N8V]M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A
M8VMA9V4@4WEN8TU,"B`J+PIC;&%S<R!3>6YC34Q?0V]M;6%N9%]'970@97AT
M96YD<R!3>6YC34Q?0V]M;6%N9"!["@H@("`@9G5N8W1I;VX@;W5T<'5T*"1C
M=7)R96YT0VUD240L("8D;W5T<'5T*0H@("`@>PH@("`@("`@("1S=&%T92`]
M("8D7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==.PH*("`@("`@("`D<F5F(#T@
M*"1S=&%T92T^9V5T5F5R<VEO;B@I(#T](#`I(#\@)RXO9&5V:6YF,3`G(#H@
M)RXO9&5V:6YF,3$G.PH*("`@("`@("`D<W1A='5S(#T@)FYE=R!3>6YC34Q?
M0V]M;6%N9%]3=&%T=7,H*"1S=&%T92T^:7-!=71H;W)I>F5D*"D@/R!215-0
M3TY315]/2R`Z(%)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,I+"`G1V5T
M)RD["B`@("`@("`@)'-T871U<RT^<V5T0VUD4F5F*"1T:&ES+3Y?8VUD240I
M.PH@("`@("`@("1S=&%T=7,M/G-E=%1A<F=E=%)E9B@D<F5F*3L*("`@("`@
M("`D8W5R<F5N=$-M9$E$(#T@)'-T871U<RT^;W5T<'5T*"1C=7)R96YT0VUD
M240L("1O=71P=70I.PH*("`@("`@("!I9B`H)'-T871E+3YI<T%U=&AO<FEZ
M960H*2D@>PH@("`@("`@("`@("`D871T<G,@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@
M)U)E<W5L=',G+"`D871T<G,I.PH*("`@("`@("`@("`@)&]U='!U="T^<W1A
M<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=#;61)1"<L("1A='1R<RD[
M"B`@("`@("`@("`@("1C:&%R<R`]("1C=7)R96YT0VUD240["B`@("`@("`@
M("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`@("`@
M)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G0VUD240G
M*3L*"B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M
M/F=E=%5222@I+"`G37-G4F5F)RP@)&%T=')S*3L*("`@("`@("`@("`@)&-H
M87)S(#T@)'-T871E+3YG971-<V=)1"@I.PH@("`@("`@("`@("`D;W5T<'5T
M+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@("`@("`@("1O=71P=70M/F5N
M9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TUS9U)E9B<I.PH*("`@("`@
M("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL
M("=#;612968G+"`D871T<G,I.PH@("`@("`@("`@("`D8VAA<G,@/2`D=&AI
M<RT^7V-M9$E$.PH@("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1C
M:&%R<RD["B`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E
M+3YG97154DDH*2P@)T-M9%)E9B<I.PH*("`@("`@("`@("`@)&]U='!U="T^
M<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=-971A)RP@)&%T=')S
M*3L*("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^
M9V5T55))365T82@I+"`G5'EP92<L("1A='1R<RD["B`@("`@("`@("`@(&EF
M("AI<U]A*"1O=71P=70L("=834Q?5T)834Q?16YC;V1E<B<I*2!["B`@("`@
M("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*$U)345?4UE.0TU,7T1%
M5DE#15])3D9/7U="6$U,*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H34E-15]364Y#34Q?1$56
M24-%7TE.1D]?6$U,*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&]U
M='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5224UE=&$H*2P@)U1Y<&4G
M*3L*("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E
M=%5222@I+"`G365T82<I.PH*("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%
M;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=)=&5M)RP@)&%T=')S*3L*("`@
M("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))
M*"DL("=3;W5R8V4G+"`D871T<G,I.PH@("`@("`@("`@("`D;W5T<'5T+3YS
M=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TQO8U5222<L("1A='1R
M<RD["B`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)')E9BD["B`@
M("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH
M*2P@)TQO8U5222<I.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT
M*"1S=&%T92T^9V5T55))*"DL("=3;W5R8V4G*3L*"B`@("`@("`@("`@("1O
M=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G1&%T82<L
M("1A='1R<RD["@H@("`@("`@("`@("`O*B!$979);F8@9&%T82!I<R!S=&]R
M960@:6X@=V)X;6P@;F]T(&%S(&$@<V5P97)A=&4@8V]D97!A9V4@8G5T"B`@
M("`@("`@("`@("`J(')A=&AE<B!A<R!A(&-O;7!L971E('=B>&UL('-T<F5A
M;2!A<R!O<&%Q=64@9&%T82X@(%-O('=E(&YE960@80H@("`@("`@("`@("`@
M*B!N97<@2&%N9&QE<BX@*B\*("`@("`@("`@("`@)&1E=FEN9F]U='!U="`]
M("1O=71P=70M/F-R96%T95-U8DAA;F1L97(H*3L*("`@("`@("`@("`@"B`@
M("`@("`@("`@("1D979I;F9O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M
M/F=E=%52241E=DEN9B@I("P@)T1E=DEN9B<L("1A='1R<RD["B`@("`@("`@
M("`@("1D979I;F9O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%52
M241E=DEN9B@I("P@)U9E<D141"<L("1A='1R<RD["B`@("`@("`@("`@("1D
M979I;F9O=71P=70M/F-H87)A8W1E<G,H*"1S=&%T92T^9V5T5F5R<VEO;B@I
M(#T](#`I(#\@)S$N,"<@.B`G,2XQ)RD["B`@("`@("`@("`@("1D979I;F9O
M=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=6
M97)$5$0G+"`D871T<G,I.PH@("`@("`@("`@("`D9&5V:6YF;W5T<'5T+3YS
M=&%R=$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=-86XG+"`D
M871T<G,I.PH@("`@("`@("`@("`D9&5V:6YF;W5T<'5T+3YC:&%R86-T97)S
M*"=4:&4@2&]R9&4@4')O:F5C="`H:'1T<#HO+W=W=RYH;W)D92YO<F<I)RD[
M"B`@("`@("`@("`@("1D979I;F9O=71P=70M/F5N9$5L96UE;G0H)'-T871E
M+3YG97154DE$979);F8H*2`L("=-86XG+"`D871T<G,I.PH@("`@("`@("`@
M("`D9&5V:6YF;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DE$
M979);F8H*2`L("=$979)1"<L("1A='1R<RD["B`@("`@("`@("`@("1D979I
M;F9O=71P=70M/F-H87)A8W1E<G,H)%]315)615);)TA45%!?2$]35"==*3L*
M("`@("`@("`@("`@)&1E=FEN9F]U='!U="T^96YD16QE;65N="@D<W1A=&4M
M/F=E=%52241E=DEN9B@I("P@)T1E=DE$)RP@)&%T=')S*3L*("`@("`@("`@
M("`@)&1E=FEN9F]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))
M1&5V26YF*"D@+"`G1&5V5'EP)RP@)&%T=')S*3L*("`@("`@("`@("`@)&1E
M=FEN9F]U='!U="T^8VAA<F%C=&5R<R@G<V5R=F5R)RD["B`@("`@("`@("`@
M("1D979I;F9O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DE$979)
M;F8H*2`L("=$9794>7`G+"`D871T<G,I.PH@("`@("`@("`@("`D=&AI<RT^
M7W=R:71E1&%T85-T;W)E*"=N;W1E<R<L("=T97AT+W@M=FYO=&4G+"`G,2XQ
M)RP@)&1E=FEN9F]U='!U="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@G=&5X="]P;&%I;B<@/3X@)S$N,"<I*3L*("`@("`@
M("`@("`@)'1H:7,M/E]W<FET941A=&%3=&]R92@G8V]N=&%C=',G+"`G=&5X
M="]X+79C87)D)RP@)S,N,"<L("1D979I;F9O=71P=70L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W1E>'0O>"UV8V%R9"<@
M/3X@)S(N,2<I*3L*("`@("`@("`@("`@)'1H:7,M/E]W<FET941A=&%3=&]R
M92@G=&%S:W,G+"`G=&5X="]C86QE;F1A<B<L("<R+C`G+"`D9&5V:6YF;W5T
M<'5T+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=T97AT+W@M=F-A;&5N9&%R)R`]/B`G,2XP)RDI.PH@("`@("`@("`@("`D
M=&AI<RT^7W=R:71E1&%T85-T;W)E*"=C86QE;F1A<B<L("=T97AT+V-A;&5N
M9&%R)RP@)S(N,"<L("1D979I;F9O=71P=70L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87DH)W1E>'0O>"UV8V%L96YD87(G(#T^
M("<Q+C`G*2D["B`@("`@("`@("`@("1D979I;F9O=71P=70M/F5N9$5L96UE
M;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=$979);F8G+"`D871T<G,I
M.PH*("`@("`@("`@("`@)&]U='!U="T^;W!A<75E*"1D979I;F9O=71P=70M
M/F=E=$]U='!U="@I*3L*("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N
M="@D<W1A=&4M/F=E=%5222@I+"`G1&%T82<I.PH@("`@("`@("`@("`D;W5T
M<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=)=&5M)RD["B`@
M("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH
M*2P@)U)E<W5L=',G*3L*"B`@("`@("`@("`@("1C=7)R96YT0VUD240K*SL*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D8W5R<F5N=$-M9$E$.PH@("`@
M?0H*("`@("\J*@H@("`@("H@5W)I=&5S($1E=DEN9B!D871A(&9O<B!O;F4@
M1&%T85-T;W)E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-O=7)C
M97)E9CH@9&%T82!F;W(@4V]U<F-E4F5F(&5L96UE;G0N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1M:6UE='EP93H@9&%T82!F;W(@)FQT.RA2?%0I>"U0<F5F
M)F=T.R9L=#M#5%1Y<&4F9W0["B`@("`@*B!`<&%R86T@<W1R:6YG("1V97)S
M:6]N.B!D871A(&9O<B`F;'0[*%)\5"EX+5!R968F9W0[)FQT.U9E<D-4)F=T
M.PH@("`@("H@0'!A<F%M('-T<FEN9R`F)&]U='!U="!C;VYT96YT:&%N9&QE
M<B!T:&%T('=I;&P@<F5C96EV960@=&AE(&]U='!U="X*("`@("`J($!P87)A
M;2!A<G)A>2`D861D:71I;VYA;'1Y<&5S.B!A<G)A>2!O9B!A9&1I=&EO;F%L
M('1Y<&5S(&9O<B!4>"!A;F0@4G@["B`@("`@*B`@("`@("`@("`@("`@9F]R
M;6%T(&%R<F%Y*"=T97AT+W9C87)D)R`]/B`G,BXP)RD*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W=R:71E1&%T85-T;W)E*"1S;W5R8V5R968L("1M:6UE='EP
M92P@)'9E<G-I;VXL("8D;W5T<'5T+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1A9&1I=&EO;F%L='EP97,@/2!F86QS92D*("`@('L*("`@("`@
M("`D871T<G,@/2!A<G)A>2@I.PH*("`@("`@("`D<W1A=&4@/2`F)%]315-3
M24].6R=3>6YC34PN<W1A=&4G73L*"B`@("`@("`@)&]U='!U="T^<W1A<G1%
M;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G1&%T85-T;W)E)RP@
M)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E
M+3YG97154DE$979);F8H*2`L("=3;W5R8V52968G+"`D871T<G,I.PH@("`@
M("`@("1O=71P=70M/F-H87)A8W1E<G,H)'-O=7)C97)E9BD["B`@("`@("`@
M)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@
M)U-O=7)C95)E9B<L("1A='1R<RD["@H@("`@("`@("1O=71P=70M/G-T87)T
M16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@)U)X+5!R968G+"`D
M871T<G,I.PH@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M
M/F=E=%52241E=DEN9B@I("P@)T-45'EP92<L("1A='1R<RD["B`@("`@("`@
M)&]U='!U="T^8VAA<F%C=&5R<R@D;6EM971Y<&4I.PH@("`@("`@("1O=71P
M=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=#5%1Y
M<&4G+"`D871T<G,I.PH@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D
M<W1A=&4M/F=E=%52241E=DEN9B@I("P@)U9E<D-4)RP@)&%T=')S*3L*("`@
M("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1V97)S:6]N*3L*("`@("`@("`D
M;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G
M5F5R0U0G+"`D871T<G,I.PH@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H
M)'-T871E+3YG97154DE$979);F8H*2`L("=2>"U0<F5F)RP@)&%T=')S*3L*
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1A9&1I=&EO;F%L='EP97,I*2!["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1A9&1I=&EO;F%L='EP97,@87,@)&-T(#T^
M("1C='9E<BE["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE
M;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=2>"<L("1A='1R<RD["B`@
M("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG
M97154DE$979);F8H*2`L("=#5%1Y<&4G+"`D871T<G,I.PH@("`@("`@("`@
M("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8W0I.PH@("`@("`@("`@("`@
M("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I
M("P@)T-45'EP92<L("1A='1R<RD["B`@("`@("`@("`@("`@("`D;W5T<'5T
M+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=697)#
M5"<L("1A='1R<RD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T
M97)S*"1C='9E<BD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M
M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G5F5R0U0G+"`D871T<G,I
M.PH@("`@("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M
M/F=E=%52241E=DEN9B@I("P@)U)X)RP@)&%T=')S*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S
M=&%T92T^9V5T55))1&5V26YF*"D@+"`G5'@M4')E9B<L("1A='1R<RD["B`@
M("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V
M26YF*"D@+"`G0U14>7!E)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YC
M:&%R86-T97)S*"1M:6UE='EP92D["B`@("`@("`@)&]U='!U="T^96YD16QE
M;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@)T-45'EP92<L("1A='1R
M<RD["B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T
M55))1&5V26YF*"D@+"`G5F5R0U0G+"`D871T<G,I.PH@("`@("`@("1O=71P
M=70M/F-H87)A8W1E<G,H)'9E<G-I;VXI.PH@("`@("`@("1O=71P=70M/F5N
M9$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=697)#5"<L("1A
M='1R<RD["B`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E
M=%52241E=DEN9B@I("P@)U1X+5!R968G+"`D871T<G,I.PH*("`@("`@("!I
M9B`H:7-?87)R87DH)&%D9&ET:6]N86QT>7!E<RDI('L*("`@("`@("`@("`@
M9F]R96%C:"`H)&%D9&ET:6]N86QT>7!E<R!A<R`D8W0@/3X@)&-T=F5R*7L*
M("`@("`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M
M/F=E=%52241E=DEN9B@I("P@)U1X)RP@)&%T=')S*3L*("`@("`@("`@("`@
M("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN
M9B@I("P@)T-45'EP92<L("1A='1R<RD["B`@("`@("`@("`@("`@("`D;W5T
M<'5T+3YC:&%R86-T97)S*"1C="D["B`@("`@("`@("`@("`@("`D;W5T<'5T
M+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G0U14>7!E
M)RP@)&%T=')S*3L*("`@("`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE
M;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@)U9E<D-4)RP@)&%T=')S
M*3L*("`@("`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-T=F5R
M*3L*("`@("`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E
M+3YG97154DE$979);F8H*2`L("=697)#5"<L("1A='1R<RD["B`@("`@("`@
M("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V
M26YF*"D@+"`G5'@G+"`D871T<G,I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG9715
M4DE$979);F8H*2`L("=3>6YC0V%P)RP@)&%T=')S*3L*("`@("`@("`D;W5T
M<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=3
M>6YC5'EP92<L("1A='1R<RD["B`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R
M<R@G,2<I.PH@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG
M97154DE$979);F8H*2`L("=3>6YC5'EP92<L("1A='1R<RD["B`@("`@("`@
M)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@
M+"`G4WEN8U1Y<&4G+"`D871T<G,I.PH@("`@("`@("1O=71P=70M/F-H87)A
M8W1E<G,H)S(G*3L*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T
M92T^9V5T55))1&5V26YF*"D@+"`G4WEN8U1Y<&4G+"`D871T<G,I.PH@("`@
M("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H
M*2`L("=3>6YC0V%P)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YE;F1%
M;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G1&%T85-T;W)E)RP@
M)&%T=')S*3L*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O4WEN8TU,+T-O;6UA;F0O36%P
M+G!H<```````````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P-3(R`#$P
M-3$U-#,S-S0T`#`R,C,W-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*:6YC;'5D95]O;F-E("=3>6YC34PO0V]M
M;6%N9"YP:'`G.PH*+RHJ"B`J(%1H92!3>6YC34Q?36%P(&-L87-S('!R;W9I
M9&5S(&$@4WEN8TU,(&EM<&QE;65N=&%T:6]N(&]F"B`J('1H92!-87`@8V]M
M;6%N9"!A<R!D969I;F5D(&EN(%-Y;F--3"!297!R97-E;G1A=&EO;B!0<F]T
M;V-O;"P*("H@=F5R<VEO;B`Q+C`N,2`U+C4N."X*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO4WEN8TU,+U-Y;F--3"]#;VUM86YD+TUA<"YP:'`L=B`Q+C$N
M,3`N-B`R,#`V+S`Q+S`Q(#(Q.C(X.C,V(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P-"TR,#`V($MA<G-T96X@1F]U<FUO;G0@/&MA<G-T96Y`:&]R
M9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2V%R<W1E;B!&
M;W5R;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E
M(#,N,`H@*B!`<&%C:V%G92!3>6YC34P*("HO"F-L87-S(%-Y;F--3%]#;VUM
M86YD7TUA<"!E>'1E;F1S(%-Y;F--3%]#;VUM86YD('L*"B`@("`O*BH*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W-O=7)C94QO8U52
M23L*"B`@("`O*BH*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D7W1A<F=E=$QO8U5223L*"B`@("!V87(@)%]M87!487)G970["B`@("!V
M87(@)%]M87!3;W5R8V4["@H@("`@9G5N8W1I;VX@;W5T<'5T*"1C=7)R96YT
M0VUD240L("8D;W5T<'5T*0H@("`@>PH@("`@("`@("1A='1R<R`](&%R<F%Y
M*"D["@H@("`@("`@("1S=&%T92`]("8D7U-%4U-)3TY;)U-Y;F--3"YS=&%T
M92==.PH*("`@("`@("`D<W1A='5S(#T@)FYE=R!3>6YC34Q?0V]M;6%N9%]3
M=&%T=7,H)'-T871E+3YI<T%U=&AO<FEZ960H*2`_(%)%4U!/3E-%7T]+(#H@
M4D534$].4T5?24Y604Q)1%]#4D5$14Y424%,4RP@)TUA<"<I.PH@("`@("`@
M("1S=&%T=7,M/G-E=$-M9%)E9B@D=&AI<RT^7V-M9$E$*3L*("`@("`@("!I
M9B`H)'1H:7,M/E]S;W5R8V5,;V-54DD@(3T@;G5L;"D@>PH@("`@("`@("`@
M("`D<W1A='5S+3YS9713;W5R8V52968H)'1H:7,M/E]S;W5R8V5,;V-54DDI
M.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/E]T87)G971,;V-54DD@
M(3T@;G5L;"D@>PH@("`@("`@("`@("`D<W1A='5S+3YS971487)G9712968H
M)'1H:7,M/E]T87)G971,;V-54DDI.PH@("`@("`@('T*"B`@("`@("`@)&-U
M<G)E;G1#;61)1"`]("1S=&%T=7,M/F]U='!U="@D8W5R<F5N=$-M9$E$+"`D
M;W5T<'5T*3L*"B`@("`@("`@<F5T=7)N("1C=7)R96YT0VUD240["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3971T97(@9F]R('!R;W!E<G1Y('-O=7)C9552
M22X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S;W5R8V554DD@($YE
M=R!V86QU92!O9B!P<F]P97)T>2!S;W5R8V554DDN"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E=%-O=7)C94QO8U5222@D<V]U<F-E55))*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?<V]U<F-E55))(#T@)'-O=7)C955223L*("`@('T*"B`@
M("!F=6YC=&EO;B!G971487)G971,;V-54DDH*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7W1A<F=E=%5223L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E='1E<B!F;W(@<')O<&5R='D@=&%R9V5T55))+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'1A<F=E=%5222`@3F5W('9A;'5E(&]F('!R;W!E
M<G1Y('1A<F=E=%5222X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T5&%R9V5T
M55))*"1T87)G97154DDI"B`@("!["B`@("`@("`@)'1H:7,M/E]T87)G9715
M4DD@/2`D=&%R9V5T55)).PH@("`@?0H*("`@(&9U;F-T:6]N('-T87)T16QE
M;65N="@D=7)I+"`D96QE;65N="P@)&%T=')S*0H@("`@>PH@("`@("`@('!A
M<F5N=#HZ<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M96YT+"`D871T<G,I.PH*
M("`@("`@("!S=VET8V@@*&-O=6YT*"1T:&ES+3Y?4W1A8VLI*2!["B`@("`@
M("`@8V%S92`R.@H@("`@("`@("`@("!I9B`H)&5L96UE;G0@/3T@)TUA<$ET
M96TG*2!["B`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^7VUA<%1A<F=E
M="D["B`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^7VUA<%-O=7)C92D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@
M("`@?0H*("`@(&9U;F-T:6]N(&5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I
M"B`@("!["B`@("`@("`@9VQO8F%L("1B86-K96YD.PH*("`@("`@("!S=VET
M8V@@*&-O=6YT*"1T:&ES+3Y?4W1A8VLI*2!["B`@("`@("`@8V%S92`Q.@H@
M("`@("`@("`@("`D<W1A=&4@/2`F)%]315-324].6R=3>6YC34PN<W1A=&4G
M73L*("`@("`@("`@("`@)'-Y;F,@/2`F("1S=&%T92T^9V5T4WEN8R@D=&AI
M<RT^7W1A<F=E=$QO8U5222D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E(#(Z"B`@("`@("`@("`@(&EF("@D96QE;65N="`]/2`G36%P271E
M;2<I('L*("`@("`@("`@("`@("`@("1S=&%T92`]("8D7U-%4U-)3TY;)U-Y
M;F--3"YS=&%T92==.PH@("`@("`@("`@("`@("`@)'-Y;F,@/2`F("1S=&%T
M92T^9V5T4WEN8R@D=&AI<RT^7W1A<F=E=$QO8U5222D["B`@("`@("`@("`@
M("`@("!I9B`H(21S=&%T92T^:7-!=71H;W)I>F5D*"DI('L*("`@("`@("`@
M("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G92@G3F]T($%U=&AO<FEZ
M960@:6X@36%P271E;2$G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2
M*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@+R\@3W9E<G=R:71E(&5X:7-T:6YG(&1A=&$@8GD@<F5M;W9I;F<@:70@
M9FER<W0N"B`@("`@("`@("`@("`@("`@("`@)&)A8VME;F0M/F-R96%T955I
M9$UA<"@D<W1A=&4M/F=E=%-Y;F-)9&5N=&EF:65R*"DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W1A<F=E
M=$QO8U5222P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;6%P4V]U<F-E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]M87!487)G970I.PH*
M("`@("`@("`@("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G92@G8W)E
M871E9"!-87`@9F]R('-O=7)C93TG"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^7VUA<%-O=7)C90H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)R!A;F0@=&%R
M9V5T/2<@+B`D=&AI<RT^7VUA<%1A<F=E=`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("X@)R!I;B!D8B`G("X@)'1H:7,M/E]T
M87)G971,;V-54DDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD[
M"@H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("!C87-E(#,Z"B`@("`@("`@("`@(&EF("@D96QE
M;65N="`]/2`G3&]C55)))RD@>PH@("`@("`@("`@("`@("`@:68@*"1T:&ES
M+3Y?4W1A8VM;,5T@/3T@)U-O=7)C92<I('L*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W-O=7)C94QO8U5222`]('1R:6TH)'1H:7,M/E]C:&%R<RD[
M"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'1H:7,M/E]3=&%C:ULQ72`]
M/2`G5&%R9V5T)RD@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=&%R
M9V5T3&]C55))(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@8V%S92`T.@H@("`@("`@("`@("!I9B`H)&5L96UE;G0@/3T@)TQO8U52
M22<I('L*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7U-T86-K6S)=(#T]
M("=3;W5R8V4G*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]M87!3
M;W5R8V4@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*"1T:&ES+3Y?4W1A8VM;,ET@/3T@)U1A<F=E="<I('L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7VUA<%1A<F=E="`]('1R:6TH)'1H
M:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("!P87)E;G0Z
M.F5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO0V]M;6%N9"]0=70N<&AP````````
M````````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C$P,#$`,3`U,34T,S,W-#0`
M,#(R-#(R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@II;F-L=61E7V]N8V4@)U-Y;F--3"]#;VUM86YD+G!H<"<[
M"@HO*BH*("H@)$AO<F1E.B!F<F%M97=O<FLO4WEN8TU,+U-Y;F--3"]#;VUM
M86YD+U!U="YP:'`L=B`Q+C$R+C$P+C<@,C`P-B\P-2\S,2`Q-SHP-CHS-B!S
M96QS:WD@17AP("0*("H*("H@5&AE(%-Y;F--3%]#;VUM86YD7U!U=#HZ(&-L
M87-S(&AA;F1L97,@1&5V26YF(&1E=FEC92!I;F9O<FUA=&EO;@H@*B!S96YT
M(&)Y('1H92!C;&EE;G0N(%1H92!D871A(&ES('-T;W)E9"!I;B!A(%-Y;F--
M3%]$979I8V5);F9O"B`J(&]B:F5C="!W:&EC:"!I<R!D969I;F5D(&EN($1E
M=FEC92YP:'`@86YD('1H96X@<W1O<F5D(&EN"B`J(%-Y;F--3%]$979I8V4@
M87,@86X@871T<FEB=71E+@H@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($-U
M8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!+87)S=&5N($9O=7)M;VYT(#QK87)S=&5N0&AO<F1E
M+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E(%-Y;F--
M3`H@*B\*8VQA<W,@4WEN8TU,7T-O;6UA;F1?4'5T(&5X=&5N9',@4WEN8TU,
M7T-O;6UA;F0@>PH*("`@('9A<B`D7V1E=FEN9CL*"B`@("`O*BH*("`@("`J
M($QO8V%L('9A<G,@=&\@<F5M96UB97(@<W1A=&4N"B`@("`@*B\*("`@('9A
M<B`D7V-U<G)E;G1$4SL*("`@('9A<B`D7T-45'EP93L*("`@('9A<B`D7U9E
M<D-4.PH*("`@('9A<B`D7V-U<G)E;G10<F]P3F%M93L*("`@('9A<B`D7V-U
M<G)E;G1087)A;4YA;64["B`@("!V87(@)%]C=7)R96YT0U14>7!E.PH*("`@
M('9A<B`D7V-U<G)E;G183F%M.PH*("`@(&9U;F-T:6]N('-T87)T16QE;65N
M="@D=7)I+"`D96QE;65N="P@)&%T=')S*0H@("`@>PH@("`@("`@('!A<F5N
M=#HZ<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M96YT+"`D871T<G,I.PH@("`@
M("`@('-W:71C:"`H8V]U;G0H)'1H:7,M/E]3=&%C:RDI('L*("`@("`@("!C
M87-E(#$Z"B`@("`@("`@("`@("1T:&ES+3Y?9&5V:6YF(#T@)FYE=R!3>6YC
M34Q?1&5V:6-E26YF;R@I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M8V%S92`U.@H@("`@("`@("`@("!I9B`H)&5L96UE;G0@/3T@)T1A=&%3=&]R
M92<I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=$13(#T@)FYE
M=R!3>6YC34Q?1&%T85-T;W)E*"D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&5N9$5L
M96UE;G0H)'5R:2P@)&5L96UE;G0I"B`@("!["B`@("`@("`@9VQO8F%L("1B
M86-K96YD.PH*("`@("`@("`D9&D@/2`F)'1H:7,M/E]D979I;F8["B`@("`@
M("`@<W=I=&-H("AC;W5N="@D=&AI<RT^7U-T86-K*2D@>PH@("`@("`@(&-A
M<V4@,3H*("`@("`@("`@("`@)%]315-324].6R=3>6YC34PN<W1A=&4G72T^
M<V5T1&5V:6-E26YF;R@D9&DI.PH@("`@("`@("`@("!I9B`H1$5"54=,3T=?
M1$5624Y&*2!["B`@("`@("`@("`@("`@("`D9G`@/2!`9F]P96XH)R]T;7`O
M<WEN8R]D979I;F8N='AT)RP@)V$G*3L*("`@("`@("`@("`@("`@(&EF("@D
M9G`I('L*("`@("`@("`@("`@("`@("`@("!`9G=R:71E*"1F<"P@=F%R7V5X
M<&]R="@D9&DL('1R=64I*3L*("`@("`@("`@("`@("`@("`@("!`9F-L;W-E
M*"1F<"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@
M("`@8V%S92`U.@H@("`@("`@("`@("!S=VET8V@@*"1E;&5M96YT*2!["B`@
M("`@("`@("`@(&-A<V4@)U9E<D141"<Z"B`@("`@("`@("`@("`@("`D9&DM
M/E]697)$5$0@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=-86XG.@H@("`@("`@("`@
M("`@("`@)&1I+3Y?36%N(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G36]D)SH*("`@
M("`@("`@("`@("`@("1D:2T^7TUO9"`]('1R:6TH)'1H:7,M/E]C:&%R<RD[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)T]%
M32<Z"B`@("`@("`@("`@("`@("`D9&DM/E]/14T@/2!T<FEM*"1T:&ES+3Y?
M8VAA<G,I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E("=&=U8G.@H@("`@("`@("`@("`@("`@)&1I+3Y?1G=6(#T@=')I;2@D
M=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@8V%S92`G4W=6)SH*("`@("`@("`@("`@("`@("1D:2T^7U-W5B`]
M('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@(&-A<V4@)TAW5B<Z"B`@("`@("`@("`@("`@("`D9&DM
M/E](=U8@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("!C87-E("=$979)1"<Z"B`@("`@("`@("`@
M("`@("`D9&DM/E]$979)1"`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)T1E=E1Y<"<Z
M"B`@("`@("`@("`@("`@("`D9&DM/E]$9794>7`@/2!T<FEM*"1T:&ES+3Y?
M8VAA<G,I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E("=55$,G.@H@("`@("`@("`@("`@("`@)&1I+3Y?551#(#T@=')U93L*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G4W5P
M<&]R=$QA<F=E3V)J<R<Z"B`@("`@("`@("`@("`@("`D9&DM/E]3=7!P;W)T
M3&%R9V5/8FIS(#T@=')U93L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`G4W5P<&]R=$YU;6)E<D]F0VAA;F=E<R<Z"B`@("`@
M("`@("`@("`@("`D9&DM/E]3=7!P;W)T3G5M8F5R3V9#:&%N9V5S(#T@=')U
M93L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G
M1&%T85-T;W)E)SH*("`@("`@("`@("`@("`@("1D:2T^7T1A=&%3=&]R95M=
M(#T@)'1H:7,M/E]C=7)R96YT1%,["B`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@(&-A<V4@)T-40V%P)SH*("`@("`@("`@("`@8V%S92`G
M17AT)SH*("`@("`@("`@("`@("`@("\O($%U=&]M871I8V%L;'D@:&%N9&QE
M9"!B>2!S=6)E;&5M96YT<RX*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(#8Z
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^7U-T86-K6S1=(#T]("=$871A4W1O
M<F4G*2!["B`@("`@("`@("`@("`@("!S=VET8V@@*"1E;&5M96YT*2!["B`@
M("`@("`@("`@("`@("!C87-E("=3;W5R8V52968G.@H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?8W5R<F5N=$13+3Y?4V]U<F-E4F5F(#T@=')I;2@D
M=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@("`@("!C87-E("=$:7-P;&%Y3F%M92<Z"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]C=7)R96YT1%,M/E]$:7-P;&%Y3F%M92`]('1R
M:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("`@("`@8V%S92`G36%X1U5)1%-I>F4G.@H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=$13+3Y?36%X1U5)1%-I>F4@
M/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)T13365M)SH*("`@("`@("`@
M("`@("`@("`@("`O+R!#=7)R96YT;'D@:6=N;W)E9"P@=&\@8F4@9&]N92X*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C
M87-E("=3>6YC0V%P)SH*("`@("`@("`@("`@("`@("`@("`O+R!!=71O;6%T
M:6-A;&QY(&AA;F1L960@8GD@4WEN8U1Y<&4@<W5B96QE;65N="X*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=2
M>"U0<F5F)SH*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G1$
M4RT^7U)X7U!R969;)'1H:7,M/E]#5%1Y<&5=(#T@)'1H:7,M/E]697)#5#L*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C
M87-E("=2>"<Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT
M1%,M/E]2>%LD=&AI<RT^7T-45'EP95T@/2`D=&AI<RT^7U9E<D-4.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@
M)U1X+5!R968G.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N
M=$13+3Y?5'A?4')E9ELD=&AI<RT^7T-45'EP95T@/2`D=&AI<RT^7U9E<D-4
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@
M(&-A<V4@)U1X)SH*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-U<G)E
M;G1$4RT^7U1X6R1T:&ES+3Y?0U14>7!E72`]("1T:&ES+3Y?5F5R0U0["B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D=&AI<RT^7U-T86-K6S1=
M(#T]("=#5$-A<"<I('L*("`@("`@("`@("`@("`@('-W:71C:"`H)&5L96UE
M;G0I('L*("`@("`@("`@("`@("`@(&-A<V4@)T-45'EP92<Z"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT0U14>7!E(#T@=')I;2@D=&AI
M<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@("`@("!C87-E("=0<F]P3F%M92<Z"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]C=7)R96YT4')O<$YA;64@/2!T<FEM*"1T:&ES+3Y?8VAA
M<G,I.PH@("`@("`@("`@("`@("`@("`@("\O(%)E<V5T('!A<F%M('-T871E
M+@H@("`@("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?8W5R<F5N=%!A
M<F%M3F%M92D["B`@("`@("`@("`@("`@("`@("`@)&1I+3Y?0U1#87!;)'1H
M:7,M/E]C=7)R96YT0U14>7!E75LD=&AI<RT^7V-U<G)E;G10<F]P3F%M95T@
M/2`F;F5W(%-Y;F--3%]0<F]P97)T>2@I.PH@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)U!A<F%M3F%M92<Z"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT4&%R86U.86UE(#T@
M=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@("`@("`D9&DM
M/E]#5$-A<%LD=&AI<RT^7V-U<G)E;G1#5%1Y<&5=6R1T:&ES+3Y?8W5R<F5N
M=%!R;W!.86UE72T^7W!A<F%M<ULD=&AI<RT^7V-U<G)E;G1087)A;4YA;65=
M(#T@)FYE=R!3>6YC34Q?4')O<&5R='E087)A;65T97(H*3L*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=686Q%
M;G5M)SH*("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?
M8W5R<F5N=%!A<F%M3F%M92DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M+R\@5V4G<F4@:6X@<&%R86UE=&5R(&UO9&4N"B`@("`@("`@("`@("`@("`@
M("`@("`@("1D:2T^7T-40V%P6R1T:&ES+3Y?8W5R<F5N=$-45'EP95U;)'1H
M:7,M/E]C=7)R96YT4')O<$YA;65=+3Y?<&%R86US6R1T:&ES+3Y?8W5R<F5N
M=%!A<F%M3F%M95TM/E]686Q%;G5M6W1R:6TH)'1H:7,M/E]C:&%R<RE=(#T@
M=')U93L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D9&DM/E]#5$-A<%LD=&AI<RT^7V-U<G)E;G1#5%1Y
M<&5=6R1T:&ES+3Y?8W5R<F5N=%!R;W!.86UE72T^7U9A;$5N=6U;=')I;2@D
M=&AI<RT^7V-H87)S*5T@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C
M87-E("=$871A5'EP92<Z"B`@("`@("`@("`@("`@("`@("`@:68@*"%E;7!T
M>2@D=&AI<RT^7V-U<G)E;G1087)A;4YA;64I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("\O(%=E)W)E(&EN('!A<F%M971E<B!M;V1E+@H@("`@("`@
M("`@("`@("`@("`@("`@("`D9&DM/E]#5$-A<%LD=&AI<RT^7V-U<G)E;G1#
M5%1Y<&5=6R1T:&ES+3Y?8W5R<F5N=%!R;W!.86UE72T^7W!A<F%M<ULD=&AI
M<RT^7V-U<G)E;G1087)A;4YA;65=+3Y?1&%T851Y<&4@/2!T<FEM*"1T:&ES
M+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1D:2T^7T-40V%P6R1T:&ES+3Y?8W5R<F5N
M=$-45'EP95U;)'1H:7,M/E]C=7)R96YT4')O<$YA;65=+3Y?1&%T851Y<&4@
M/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C
M87-E("=3:7IE)SH*("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1T
M:&ES+3Y?8W5R<F5N=%!A<F%M3F%M92DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@5V4G<F4@:6X@<&%R86UE=&5R(&UO9&4N"B`@("`@("`@("`@
M("`@("`@("`@("`@("1D:2T^7T-40V%P6R1T:&ES+3Y?8W5R<F5N=$-45'EP
M95U;)'1H:7,M/E]C=7)R96YT4')O<$YA;65=+3Y?<&%R86US6R1T:&ES+3Y?
M8W5R<F5N=%!A<F%M3F%M95TM/E]3:7IE(#T@=')I;2@D=&AI<RT^7V-H87)S
M*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D9&DM/E]#5$-A<%LD=&AI<RT^7V-U<G)E;G1#5%1Y<&5=
M6R1T:&ES+3Y?8W5R<F5N=%!R;W!.86UE72T^7U-I>F4@/2!T<FEM*"1T:&ES
M+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=$:7-P;&%Y
M3F%M92<Z"B`@("`@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^
M7V-U<G)E;G1087)A;4YA;64I*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("\O(%=E)W)E(&EN('!A<F%M971E<B!M;V1E+@H@("`@("`@("`@("`@("`@
M("`@("`@("`D9&DM/E]#5$-A<%LD=&AI<RT^7V-U<G)E;G1#5%1Y<&5=6R1T
M:&ES+3Y?8W5R<F5N=%!R;W!.86UE72T^7W!A<F%M<ULD=&AI<RT^7V-U<G)E
M;G1087)A;4YA;65=+3Y?1&ES<&QA>4YA;64@/2!T<FEM*"1T:&ES+3Y?8VAA
M<G,I.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1D:2T^7T-40V%P6R1T:&ES+3Y?8W5R<F5N=$-45'EP
M95U;)'1H:7,M/E]C=7)R96YT4')O<$YA;65=+3Y?1&ES<&QA>4YA;64@/2!T
M<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1T:&ES+3Y?4W1A8VM;-%T@
M/3T@)T5X="<@)B8@)&5L96UE;G0@/3T@)UA.86TG*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V-U<G)E;G183F%M(#T@=')I;2@D=&AI<RT^7V-H87)S
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]3=&%C
M:ULT72`]/2`G17AT)R`F)B`D96QE;65N="`]/2`G6%9A;"<I('L*("`@("`@
M("`@("`@("`@("1D:2T^7T5X=%LD=&AI<RT^7V-U<G)E;G183F%M75M=(#T@
M=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@8V%S92`W.@H@("`@("`@("`@("!I9B`H)&5L
M96UE;G0@/3T@)U9E<D-4)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]6
M97)#5"`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@('T@96QS
M96EF("@D96QE;65N="`]/2`G0U14>7!E)RD@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]#5%1Y<&4@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@
M("`@("!](&5L<V5I9B`H)&5L96UE;G0@/3T@)U-Y;F-4>7!E)RD@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT1%,M/E]3>6YC0V%P6W1R:6TH
M)'1H:7,M/E]C:&%R<RE=(#T@=')U93L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@('!A<F5N=#HZ96YD16QE
M;65N="@D=7)I+"`D96QE;65N="D["B`@("!]"@H@("`@9G5N8W1I;VX@;W5T
M<'5T*"1C=7)R96YT0VUD240L("8D;W5T<'5T*0H@("`@>PH@("`@("`@("1S
M=&%T92`]("8D7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==.PH*("`@("`@("`D
M<W1A='5S(#T@)FYE=R!3>6YC34Q?0V]M;6%N9%]3=&%T=7,H*"@D<W1A=&4M
M/FES075T:&]R:7IE9"@I*2`_(%)%4U!/3E-%7T]+(#H@4D534$].4T5?24Y6
M04Q)1%]#4D5$14Y424%,4RDL("=0=70G*3L*("`@("`@("`D<W1A='5S+3YS
M971#;612968H)'1H:7,M/E]C;61)1"D["@H@("`@("`@("1R968@/2`H)'-T
M871E+3YG971697)S:6]N*"D@/3T@,"D@/R`G+B]D979I;F8Q,"<@.B`G+B]D
M979I;F8Q,2<["@H@("`@("`@("1S=&%T=7,M/G-E=%-O=7)C95)E9B@D<F5F
M*3L*"B`@("`@("`@<F5T=7)N("1S=&%T=7,M/F]U='!U="@D8W5R<F5N=$-M
M9$E$+"`D;W5T<'5T*3L*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U-Y;F--3"]#;VUM86YD+U)E<W5L
M=',N<&AP````````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C<P-0`Q,#4Q
M-30S,S<T-``P,C,S,S$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"FEN8VQU9&5?;VYC92`G4WEN8TU,+T-O;6UA
M;F0N<&AP)SL*"B\J*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]3>6YC34PO4WEN
M8TU,+T-O;6UA;F0O4F5S=6QT<RYP:'`L=B`Q+C$Q+C$P+C8@,C`P-B\P-R\P
M,B`Q,#HT.#HR,"!K87)S=&5N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S
M+3(P,#8@06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($YA=&AA;B!0(%-H87)P"B`J($!S
M:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!3>6YC34P*("HO"F-L87-S
M(%-Y;F--3%]#;VUM86YD7U)E<W5L=',@97AT96YD<R!3>6YC34Q?0V]M;6%N
M9"!["@H@("`@=F%R("1?<W5B0V]M;6%N9#L*("`@('9A<B`D7W-A=F5D57)I
M.PH@("`@=F%R("1?<V%V961%;&5M96YT.PH@("`@=F%R("1?<V%V961!='1R
M<SL*("`@('9A<B`D7W-A=F5D0VUD240["B`@("!V87(@)%]C:&%R<SL*"B`@
M("!F=6YC=&EO;B!S=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R
M<RD*("`@('L*("`@("`@("!P87)E;G0Z.G-T87)T16QE;65N="@D=7)I+"`D
M96QE;65N="P@)&%T=')S*3L*"B`@("`@("`@<W=I=&-H("AC;W5N="@D=&AI
M<RT^7U-T86-K*2D@>PH@("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@+R\@
M4V%V92!T:&4@:6YF;RP@=V4@;6%Y(&AA=F4@=&\@<F4M<V5N9"!T:&ES('-T
M87)T16QE;65N=`H@("`@("`@("`@("`O+R!T;R!T:&4@<W5B+6-O;6UA;F0@
M;&%T97(N"B`@("`@("`@("`@("1T:&ES+3Y?<V%V9615<FD@/2`D=7)I.PH@
M("`@("`@("`@("`D=&AI<RT^7W-A=F5D16QE;65N="`]("1E;&5M96YT.PH@
M("`@("`@("`@("`D=&AI<RT^7W-A=F5D071T<G,@/2`D871T<G,["B`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3Y?<W5B0V]M;6%N9"DI('L*("`@("`@("`@("`@)'1H:7,M/E]S=6)#
M;VUM86YD+3YS=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD[
M"B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&5N9$5L96UE;G0H)'5R
M:2P@)&5L96UE;G0I"B`@("!["B`@("`@("`@<W=I=&-H("AC;W5N="@D=&AI
M<RT^7U-T86-K*2D@>PH@("`@("`@(&-A<V4@,CH*("`@("`@("`@("`@:68@
M*"1E;&5M96YT(#T]("=#;61)1"<@)B8@(6ES<V5T*"1T:&ES+3Y?<W5B0V]M
M;6%N9"DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V%V961#;61)1"`]
M(&EN='9A;"AT<FEM*"1T:&ES+3Y?8VAA<G,I*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@:68@*"1E;&5M96YT(#T]("=#;612968G*2!["B`@("`@
M("`@("`@("`@("`D8VUD4F5F(#T@:6YT=F%L*'1R:6TH)'1H:7,M/E]C:&%R
M<RDI.PH@("`@("`@("`@("`@("`@)'-T871E(#T@)B1?4T534TE/3ELG4WEN
M8TU,+G-T871E)UT["@H@("`@("`@("`@("`@("`@+R\@268@=&AI<R!R97-U
M;'0@<&%C:V5T(&ES(')E;&%T960@=&\@<V]M971H:6YG(&%N9`H@("`@("`@
M("`@("`@("`@+R\@;F5E9',@=&\@8F4@<F]U=&5D('1O(&$@<&%R=&EC=6QA
M<B!C;VUM86YD(&]B:F5C="P*("`@("`@("`@("`@("`@("\O(&1O(&ET(&YO
M=RX*("`@("`@("`@("`@("`@("1C;614>7!E(#T@)'-T871E+3YG971%>'!E
M8W1E9%)E<W5L=%1Y<&4H)&-M9%)E9BD["B`@("`@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1C;614>7!E*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<W5B0V]M;6%N9"`]("93>6YC34Q?0V]M;6%N9#HZ9F%C=&]R>2@D8VUD
M5'EP92D["B`@("`@("`@("`@("`@("`@("`@+R\@5&AI<R!I<VXG="!T;W1A
M;&QY('1E8VAN:6-A;&QY(&-O<G)E8W0@8F5C875S90H@("`@("`@("`@("`@
M("`@("`@("\O('1H92!834P@8V]U;&0@:&%V92!B965N(&]U="!O9B!O<F1E
M<B!A;F0@=V4*("`@("`@("`@("`@("`@("`@("`O+R!M:6=H="!H879E(&UI
M<W-E9"!S;VUE('-T=69F+"!B=70@:6X@<F5A;&ET>2P*("`@("`@("`@("`@
M("`@("`@("`O+R!I="!P<F]B86)L>2!W;VXG="!H87!P96XN"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]S=6)#;VUM86YD+3YS=&%R=$5L96UE;G0H
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V%V9615<FDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V%V961%;&5M96YT+`H@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-A=F5D071T<G,I.PH@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W-A=F5D0VUD
M240I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\O($9)6$U%.B!3:&]U
M;&1N)W0@8F4@86-C97-S:6YG('1H:7,@<')I=F%T90H@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!M96UB97(N"B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<W5B0V]M;6%N9"T^7V-M9$E$(#T@)'1H:7,M/E]S879E9$-M
M9$E$.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("`@("`@+R\@1F%L;"!T:')O=6=H('1O('1H92!D969A=6QT(&-A
M<V4N"@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7W-U8D-O;6UA;F0I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W-U8D-O;6UA;F0M/F5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@
M("`@<&%R96YT.CIE;F1%;&5M96YT*"1U<FDL("1E;&5M96YT*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!C:&%R86-T97)S*"1S='(I"B`@("!["B`@("`@("`@
M<&%R96YT.CIC:&%R86-T97)S*"1S='(I.PH@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7W-U8D-O;6UA;F0I*2!["B`@("`@("`@("`@("1T:&ES+3Y?<W5B
M0V]M;6%N9"T^8VAA<F%C=&5R<R@D<W1R*3L*("`@("`@("!]"B`@("!]"@H@
M("`@9G5N8W1I;VX@;W5T<'5T*"1C=7)R96YT0VUD240L("8D;W5T<'5T*0H@
M("`@>PH@("`@("`@("1S=&%T92`]("8D7U-%4U-)3TY;)U-Y;F--3"YS=&%T
M92==.PH*("`@("`@("`D<W1A='5S(#T@)FYE=R!3>6YC34Q?0V]M;6%N9%]3
M=&%T=7,H4D534$].4T5?3TLL("=297-U;'1S)RD["B`@("`@("`@)'-T871U
M<RT^<V5T0VUD4F5F*"1T:&ES+3Y?8VUD240I.PH*("`@("`@("`D<F5F(#T@
M*"1S=&%T92T^9V5T5F5R<VEO;B@I(#T](#`I(#\@)RXO9&5V:6YF,3`G(#H@
M)RXO9&5V:6YF,3$G.PH@("`@("`@("1S=&%T=7,M/G-E=%-O=7)C95)E9B@D
M<F5F*3L*"B`@("`@("`@<F5T=7)N("1S=&%T=7,M/F]U='!U="@D8W5R<F5N
M=$-M9$E$+"`D;W5T<'5T*3L*("`@('T*"GT*````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO0V]M;6%N9"]3=&%T
M=7,N<&AP````````````````````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,38Q,3``,3`U
M,34T,S,W-#0`,#(S,30R`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)U-Y;F--3"]#;VUM
M86YD+G!H<"<["G)E<75I<F5?;VYC92`G4WEN8TU,+T-O;G-T86YT<RYP:'`G
M.PH*+RHJ"B`J("1(;W)D93H@9G)A;65W;W)K+U-Y;F--3"]3>6YC34PO0V]M
M;6%N9"]3=&%T=7,N<&AP+'8@,2XQ-2XQ,"XV(#(P,#8O,#$O,S$@,3<Z-34Z
M,3D@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@06YT:&]N
M>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($%N=&AO;GD@36EL;',@/&%M:6QL<T!P>7)A;6ED-BYC
M;VT^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!3>6YC34P*
M("HO"F-L87-S(%-Y;F--3%]#;VUM86YD7U-T871U<R!E>'1E;F1S(%-Y;F--
M3%]#;VUM86YD('L*"B`@("!V87(@)%]R97-P;VYS93L*"B`@("!V87(@)%]C
M;612968["@H@("`@+RHJ"B`@("`@*B!-=7-T(&)E('!R97-E;G0N"B`@("`@
M*B\*("`@('9A<B`D7V-M9#L*"B`@("!V87(@)%]S;W5R8V52968["@H@("`@
M=F%R("1?=&%R9V5T4F5F.PH*("`@('9A<B`D7V-H86Q-971A1F]R;6%T.PH*
M("`@('9A<B`D7V-H86Q-971A5'EP93L*"B`@("!V87(@)%]C:&%L365T84YE
M>'1.;VYC93L*"B`@("!V87(@)%]I=&5M1&%T84%N8VAO<DYE>'0["@H@("`@
M=F%R("1?:71E;41A=&%!;F-H;W),87-T.PH*("`@(&9U;F-T:6]N(%-Y;F--
M3%]#;VUM86YD7U-T871U<R@D<F5S<&]N<V4@/2!N=6QL+"`D8VUD(#T@;G5L
M;"D*("`@('L*("`@("`@("!I9B`H)')E<W!O;G-E("$](&YU;&PI('L*("`@
M("`@("`@("`@)'1H:7,M/E]R97-P;VYS92`]("1R97-P;VYS93L*("`@("`@
M("!]"@H@("`@("`@(&EF("@D8VUD("$](&YU;&PI('L*("`@("`@("`@("`@
M)'1H:7,M/E]C;60@/2`D8VUD.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC
M=&EO;B!O=71P=70H)&-U<G)E;G1#;61)1"P@)B1O=71P=70I"B`@("!["B`@
M("`@("`@)&%T=')S(#T@87)R87DH*3L*"B`@("`@("`@)'-T871E(#T@)B1?
M4T534TE/3ELG4WEN8TU,+G-T871E)UT["@H@("`@("`@(&EF("@D=&AI<RT^
M7V-M9"`A/2!N=6QL*2!["B`@("`@("`@("`@("1A='1R<R`](&%R<F%Y*"D[
M"B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E
M=%5222@I+"`G4W1A='5S)RP@)&%T=')S*3L*"B`@("`@("`@("`@("1O=71P
M=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G0VUD240G+"`D
M871T<G,I.PH@("`@("`@("`@("`D8VAA<G,@/2`D8W5R<F5N=$-M9$E$.PH@
M("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@
M("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@
M)T-M9$E$)RD["@H@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H
M)'-T871E+3YG97154DDH*2P@)TUS9U)E9B<L("1A='1R<RD["B`@("`@("`@
M("`@("1C:&%R<R`]("1S=&%T92T^9V5T37-G240H*3L*("`@("`@("`@("`@
M)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@("`@("`@("`@("`D;W5T
M<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=-<V=2968G*3L*
M"B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E
M=%5222@I+"`G0VUD4F5F)RP@)&%T=')S*3L*("`@("`@("`@("`@)&-H87)S
M(#T@)'1H:7,M/E]C;612968["B`@("`@("`@("`@("1O=71P=70M/F-H87)A
M8W1E<G,H)&-H87)S*3L*("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N
M="@D<W1A=&4M/F=E=%5222@I+"`G0VUD4F5F)RD["@H@("`@("`@("`@("`D
M;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)T-M9"<L
M("1A='1R<RD["B`@("`@("`@("`@("1C:&%R<R`]("1T:&ES+3Y?8VUD.PH@
M("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@
M("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@
M)T-M9"<I.PH*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?=&%R9V5T
M4F5F*2D@>PH@("`@("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT
M*"1S=&%T92T^9V5T55))*"DL("=487)G9712968G+"`D871T<G,I.PH@("`@
M("`@("`@("`@("`@)&-H87)S(#T@)'1H:7,M/E]T87)G9712968["B`@("`@
M("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@
M("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))
M*"DL("=487)G9712968G*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<V]U<F-E4F5F*2D@>PH@("`@("`@("`@("`@
M("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=3
M;W5R8V52968G+"`D871T<G,I.PH@("`@("`@("`@("`@("`@)&-H87)S(#T@
M)'1H:7,M/E]S;W5R8V52968["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YC
M:&%R86-T97)S*"1C:&%R<RD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YE
M;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=3;W5R8V52968G*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+R\@268@=V4@87)E(')E<W!O;F1I
M;F<@=&\@=&AE(%-Y;F-(9'(@86YD('=E(&%R92!N;W0*("`@("`@("`@("`@
M+R\@875T:&]R:7IE9"!T:&5N(')E<75E<W0@8F%S:6,@875T:&]R:7IA=&EO
M;BX*("`@("`@("`@("`@+R\*("`@("`@("`@("`@+R\@1DE8344Z(%)I9VAT
M(&YO=R!W92!A;'=A>7,@<V5N9"!T:&ES+"!I9VYO<FEN9R!T:&4*("`@("`@
M("`@("`@+R\@:7-!=71H;W)I>F5D*"D@=&5S="X@27,@=&AA="!C;W)R96-T
M/PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]C;60@/3T@)U-Y;F-(9'(G("8F
M("$D<W1A=&4M/FES075T:&]R:7IE9"@I*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V-H86Q-971A1F]R;6%T(#T@)V(V-"<["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V-H86Q-971A5'EP92`]("=S>6YC;6PZ875T:"UB87-I8R<[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7W)E<W!O;G-E(#T@4D534$].4T5?
M0U)%1$5.5$E!3%-?34E34TE.1SL*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?8VAA;$UE=&%&;W)M870I("8F(&ES<V5T
M*"1T:&ES+3Y?8VAA;$UE=&%4>7!E*2D@>PH@("`@("`@("`@("`@("`@)&]U
M='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=#:&%L)RP@
M)&%T=')S*3L*("`@("`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N
M="@D<W1A=&4M/F=E=%5222@I+"`G365T82<L("1A='1R<RD["@H@("`@("`@
M("`@("`@("`@)&UE=&%I;F9U<FD@/2`D<W1A=&4M/F=E=%5224UE=&$H*3L*
M"B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)&UE=&%I
M;F9U<FDL("=4>7!E)RP@)&%T=')S*3L*("`@("`@("`@("`@("`@("1C:&%R
M<R`]("1T:&ES+3Y?8VAA;$UE=&%4>7!E.PH@("`@("`@("`@("`@("`@)&]U
M='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@("`@("`@("`@("`@("`@)&]U
M='!U="T^96YD16QE;65N="@D;65T86EN9G5R:2P@)U1Y<&4G*3L*"B`@("`@
M("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)&UE=&%I;F9U<FDL
M("=&;W)M870G+"`D871T<G,I.PH@("`@("`@("`@("`@("`@)&-H87)S(#T@
M)'1H:7,M/E]C:&%L365T849O<FUA=#L*("`@("`@("`@("`@("`@("1O=71P
M=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`@("`@("`@("1O=71P
M=70M/F5N9$5L96UE;G0H)&UE=&%I;F9U<FDL("=&;W)M870G*3L*"B`@("`@
M("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))
M*"DL("=-971A)RD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M
M96YT*"1S=&%T92T^9V5T55))*"DL("=#:&%L)RD["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E
M=%5222@I+"`G1&%T82<L("1A='1R<RD["B`@("`@("`@("`@("1C:&%R<R`]
M("1T:&ES+3Y?<F5S<&]N<V4["B`@("`@("`@("`@("1O=71P=70M/F-H87)A
M8W1E<G,H)&-H87)S*3L*("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N
M="@D<W1A=&4M/F=E=%5222@I+"`G1&%T82<I.PH*("`@("`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?:71E;41A=&%!;F-H;W).97AT*2!\?"!I<W-E="@D
M=&AI<RT^7VET96U$871A06YC:&]R3&%S="DI('L*("`@("`@("`@("`@("`@
M("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G271E
M;2<L("1A='1R<RD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L
M96UE;G0H)'-T871E+3YG97154DDH*2P@)T1A=&$G+"`D871T<G,I.PH*("`@
M("`@("`@("`@("`@("1M971A:6YF=7)I(#T@)'-T871E+3YG97154DE-971A
M*"D["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)&UE
M=&%I;F9U<FDL("=!;F-H;W(G+"`D871T<G,I.PH*("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7VET96U$871A06YC:&]R3&%S="DI('L*"B`@
M("`@("`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D;65T86EN
M9G5R:2P@)TQA<W0G+"`D871T<G,I.PH@("`@("`@("`@("`@("`@("`D8VAA
M<G,@/2`D=&AI<RT^7VET96U$871A06YC:&]R3&%S=#L*("`@("`@("`@("`@
M("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@("`@("`@("`@
M("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1M971A:6YF=7)I+"`G3&%S
M="<I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7VET96U$871A06YC:&]R3F5X="DI('L*"B`@("`@("`@
M("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D;65T86EN9G5R:2P@
M)TYE>'0G+"`D871T<G,I.PH@("`@("`@("`@("`@("`@("`D8VAA<G,@/2`D
M=&AI<RT^7VET96U$871A06YC:&]R3F5X=#L*("`@("`@("`@("`@("`@("`@
M)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@("`@("`@("`@("`@("`@
M("`D;W5T<'5T+3YE;F1%;&5M96YT*"1M971A:6YF=7)I+"`G3F5X="<I.PH@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1O=71P=70M/F5N
M9$5L96UE;G0H)&UE=&%I;F9U<FDL("=!;F-H;W(G*3L*"B`@("`@("`@("`@
M("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=$
M871A)RD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S
M=&%T92T^9V5T55))*"DL("=)=&5M)RD["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@
M)U-T871U<R<I.PH*("`@("`@("`@("`@)&-U<G)E;G1#;61)1"LK.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1C=7)R96YT0VUD240["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!3971T97(@9F]R('!R;W!E<G1Y(')E<W!O;G-E+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)')E<W!O;G-E("!.97<@=F%L
M=64@;V8@<')O<&5R='D@<F5S<&]N<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E=%)E<W!O;G-E*"1R97-P;VYS92D*("`@('L*("`@("`@("`D=&AI<RT^
M7W)E<W!O;G-E(#T@)')E<W!O;G-E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4V5T=&5R(&9O<B!P<F]P97)T>2!C;60N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8VUD("!.97<@=F%L=64@;V8@<')O<&5R='D@8VUD+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S971#;60H)&-M9"D*("`@('L*("`@("`@("`D
M=&AI<RT^7V-M9"`]("1C;60["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971T
M97(@9F]R('!R;W!E<G1Y(&-M9%)E9BX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1C;612968@($YE=R!V86QU92!O9B!P<F]P97)T>2!C;612968N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$-M9%)E9B@D8VUD4F5F*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?8VUD4F5F(#T@)&-M9%)E9CL*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E='1E<B!F;W(@<')O<&5R='D@<V]U<F-E4F5F+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-O=7)C95)E9B`@3F5W('9A
M;'5E(&]F('!R;W!E<G1Y('-O=7)C95)E9BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V5T4V]U<F-E4F5F*"1S;W5R8V52968I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]S;W5R8V52968@/2`D<V]U<F-E4F5F.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4V5T=&5R(&9O<B!P<F]P97)T>2!T87)G9712968N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=&%R9V5T4F5F("!.97<@=F%L=64@;V8@
M<')O<&5R='D@=&%R9V5T4F5F+@H@("`@("HO"B`@("!F=6YC=&EO;B!S9714
M87)G9712968H)'1A<F=E=%)E9BD*("`@('L*("`@("`@("`D=&AI<RT^7W1A
M<F=E=%)E9B`]("1T87)G9712968["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M971T97(@9F]R('!R;W!E<G1Y(&ET96U$871A06YC:&]R3F5X="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1I=&5M1&%T84%N8VAO<DYE>'0@($YE
M=R!V86QU92!O9B!P<F]P97)T>2!I=&5M1&%T84%N8VAO<DYE>'0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=$ET96U$871A06YC:&]R3F5X="@D:71E;41A
M=&%!;F-H;W).97AT*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:71E;41A=&%!
M;F-H;W).97AT(#T@)&ET96U$871A06YC:&]R3F5X=#L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E='1E<B!F;W(@<')O<&5R='D@:71E;41A=&%!;F-H;W),
M87-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ET96U$871A06YC
M:&]R3&%S="`@3F5W('9A;'5E(&]F('!R;W!E<G1Y(&ET96U$871A06YC:&]R
M3&%S="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T271E;41A=&%!;F-H;W),
M87-T*"1I=&5M1&%T84%N8VAO<DQA<W0I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]I=&5M1&%T84%N8VAO<DQA<W0@/2`D:71E;41A=&%!;F-H;W),87-T.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U-Y;F--3"]#;VUM86YD+U-Y
M;F,N<&AP````````````````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,3(R-@`Q
M,#4Q-30S,S<T-``P,C(U-S8`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*"FEN8VQU9&5?;VYC92`G4WEN8TU,+T-O
M;6UA;F0N<&AP)SL*:6YC;'5D95]O;F-E("=3>6YC34PO0V]M;6%N9"]3>6YC
M16QE;65N="YP:'`G.PH*+RHJ"B`J("1(;W)D93H@9G)A;65W;W)K+U-Y;F--
M3"]3>6YC34PO0V]M;6%N9"]3>6YC+G!H<"QV(#$N,3<N,3`N."`R,#`V+S`Q
M+S$Q(#$X.C,Y.C(X('-E;'-K>2!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M-2TR,#`V($MA<G-T96X@1F]U<FUO;G0@/&MA<G-T96Y`:&]R9&4N;W)G/@H@
M*@H@*B!4:&4@8V]M;6%N9"!H86YD;&5R(&9O<B!T:&4@)F=T.U-Y;F,F;'0[
M(&-O;6UA;F0@:7,@=&AE(&-E;G1R86P*("H@8VQA<W,@=&\@9&ES<&%T8V@@
M<WEN8R!M97-S86=E<RX*("H*("H@1'5R:6YG('!A<G-I;F<@;V8@=&AE(')E
M8V5I=F5D(%A-3"P@=&AE(&%C='5A;"!S>6YC(&-O;6UA;F1S("A!9&0L"B`J
M(%)E<&QA8V4L($1E;&5T92D@9G)O;2!T:&4@8VQI96YT(&%R92!S=&]R960@
M:6X@=&AE(%]S>6YC16QE;65N=',*("H@871T<FEB=71E+B`@5VAE;B!T:&4@
M;W5T<'5T(&UE=&AO9"!O9B!3>6YC34Q?0V]M;6%N9%]3>6YC(&ES"B`J(&-A
M;&QE9"P@=&AE<V4@96QE;65N=',@87)E('!R;V-E<W-E9"!A;F0@=&AE(')E
M<W5L=&EN9R!S=&%T=7,*("H@;65S<V%G97,@8W)E871E9"X*("H*("H@5&AE
M;B!T:&4@<V5R=F5R(&UO9&EF:6-A=&EO;G,@87)E('-E;G0@8F%C:R!T;R!T
M:&4@8VQI96YT(&)Y('1H90H@*B!H86YD;&53>6YC(&UE=&AO9"!W:&EC:"!I
M<R!C86QL960@9G)O;2!W:71H:6X@=&AE(&]U='!U="!M971H;V0N"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!+87)S=&5N($9O=7)M;VYT(#QK87)S
M=&5N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K
M86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7T-O;6UA;F1?4WEN8R!E>'1E
M;F1S(%-Y;F-M;%]#;VUM86YD"GL*("`@("\J*@H@("`@("H@0'9A<B!3>6YC
M34Q?0V]M;6%N9%]3>6YC16QE;65N=`H@("`@("HO"B`@("!V87(@)%]C=7)R
M96YT4WEN8T5L96UE;G0["@H@("`@+RHJ"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D7W-Y;F-%;&5M96YT<R`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*B!C;VYT86-T<RP@8V%L96YD87(L('1A<VMS(&]R(&YO=&5S
M"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?
M=&%R9V5T55)).PH*("`@("\J*@H@("`@("H@0W)E871E<R!A(')E<W!O;G-E
M('1O(&$@<WEN8R!C;VUM86YD+@H@("`@("H@0W5R<F5N=&QY('1H870G<R!T
M:&4@<&QA8V4@=VAE<F4@=V4@86QS;R!C<F5A=&4*("`@("`J('1H92`F;'0[
M<WEN8R9G=#L@=VET:"!T:&4@<V5R=F5R(&-H86YG97,@=&AA=`H@("`@("H@
M;F5E9',@=&\@8F4@<V5N9"!T;R!T:&4@8VQI96YT+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!O=71P=70H)&-U<G)E;G1#;61)1"P@)B1O=71P=70I"B`@("![
M"B`@("`@("`@)'-T871E(#TF("1?4T534TE/3ELG4WEN8TU,+G-T871E)UT[
M"B`@("`@("`@)'-Y;F,@/28@)'-T871E+3YG9713>6YC*"1T:&ES+3Y?=&%R
M9V5T55))*3L*("`@("`@("!I9B`H(6ES7V]B:F5C="@D<WEN8RDI('L*("`@
M("`@("`@("`@)$=,3T)!3%-;)V)A8VME;F0G72T^;&]G365S<V%G92@G3F\@
M<WEN8R!O8FIE8W0@9F]U;F0@9F]R(%5222`]("<@+B`D=&AI<RT^7W1A<F=E
M=%5222P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@
M("`@("`@("\O($!43T1/.B!C<F5A=&4@;65A;FEN9V9U;"!S=&%T=7,@8V]D
M92!H97)E+@H@("`@("`@('T*"B`@("`@("`@+R\@2&5R92=S('=H97)E(&-L
M:65N="!M;V1I9FEC871I;VYS(&%R92!P<F]C97-S960Z"B`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/E]S>6YC16QE;65N=',@87,@)&5L96UE;G0I('L*("`@
M("`@("`@("`@9F]R96%C:"`H)&5L96UE;G0M/F=E=$ET96US*"D@87,@)&ET
M96TI('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D<WEN8RT^:&%N9&QE
M4WEN8TET96TH)&ET96TI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1C
M=7)R96YT0VUD240@/2`D96QE;65N="T^;W5T<'5T*"1C=7)R96YT0VUD240L
M("1O=71P=70I.PH@("`@("`@('T*"B`@("`@("`@+RH@3F]W('-E;F0@8VQI
M96YT(&-H86YG97,@=&\@<V5R=F5R.B!T:&ES('=I;&P@<')E8V5D92!T:&4*
M("`@("`@("`@*B`\<WEN8SX@<F5S<&]N<V4Z("HO"B`@("`@("`@)&-U<G)E
M;G1#;61)1"`]("1S>6YC+3YC<F5A=&53>6YC3W5T<'5T*"1C=7)R96YT0VUD
M240L("1O=71P=70I.PH*("`@("`@("`D<W1A='5S(#T@)FYE=R!3>6YC34Q?
M0V]M;6%N9%]3=&%T=7,H4D534$].4T5?3TLL("=3>6YC)RD["B`@("`@("`@
M)'-T871U<RT^<V5T0VUD4F5F*"1T:&ES+3Y?8VUD240I.PH*("`@("`@("!I
M9B`H)'1H:7,M/E]T87)G97154DD@(3T@;G5L;"D@>PH@("`@("`@("`@("`D
M<W1A='5S+3YS971487)G9712968H)'1H:7,M/E]T87)G97154DDI.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"1T:&ES+3Y?<V]U<F-E55))("$](&YU;&PI
M('L*("`@("`@("`@("`@)'-T871U<RT^<V5T4V]U<F-E4F5F*"1T:&ES+3Y?
M<V]U<F-E55))*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<W1A='5S
M+3YO=71P=70H)&-U<G)E;G1#;61)1"P@)&]U='!U="D["B`@("!]"@H@("`@
M9G5N8W1I;VX@9V5T5&%R9V5T55))*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]T87)G97154DD["B`@("!]"@H@("`@9G5N8W1I;VX@<W1A<G1%
M;&5M96YT*"1U<FDL("1E;&5M96YT+"`D871T<G,I"B`@("!["B`@("`@("`@
M<&%R96YT.CIS=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD[
M"@H@("`@("`@('-W:71C:"`H8V]U;G0H)'1H:7,M/E]3=&%C:RDI('L*("`@
M("`@("!C87-E(#(Z"B`@("`@("`@("`@(&EF("@D96QE;65N="`]/2`G4F5P
M;&%C92<@?'P@)&5L96UE;G0@/3T@)T%D9"<@?'P@)&5L96UE;G0@/3T@)T1E
M;&5T92<I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=%-Y;F-%
M;&5M96YT(#T@)FYE=R!3>6YC34Q?0V]M;6%N9%]3>6YC16QE;65N="@D96QE
M;65N="D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@?0H*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C=7)R96YT4WEN8T5L
M96UE;G0I*2!["B`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=%-Y;F-%;&5M
M96YT+3YS=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD["B`@
M("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&5N9$5L96UE;G0H)'5R:2P@
M)&5L96UE;G0I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8W5R
M<F5N=%-Y;F-%;&5M96YT*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V-U<G)E
M;G13>6YC16QE;65N="T^96YD16QE;65N="@D=7)I+"`D96QE;65N="D["B`@
M("`@("`@?0H*("`@("`@("!S=VET8V@@*&-O=6YT*"1T:&ES+3Y?4W1A8VLI
M*2!["B`@("`@("`@8V%S92`R.@H@("`@("`@("`@("!I9B`H)&5L96UE;G0@
M/3T@)U)E<&QA8V4G('Q\("1E;&5M96YT(#T]("=!9&0G('Q\("1E;&5M96YT
M(#T]("=$96QE=&4G*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W-Y;F-%
M;&5M96YT<UM=(#T@)'1H:7,M/E]C=7)R96YT4WEN8T5L96UE;G0["B`@("`@
M("`@("`@("`@("!U;G-E="@D=&AI<RT^7V-U<G)E;G13>6YC16QE;65N="D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@,SH*("`@("`@("`@("`@:68@*"1E;&5M96YT(#T@)TQO8U5222<@)B8@
M(6ES<V5T*"1T:&ES+3Y?8W5R<F5N=%-Y;F-%;&5M96YT*2D@>PH@("`@("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?4W1A8VM;,5T@/3T@)U-O=7)C92<I('L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-O=7)C955222`]('1R:6TH
M)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'1H
M:7,M/E]3=&%C:ULQ72`]/2`G5&%R9V5T)RD@>PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?=&%R9V5T55))(#T@8F%S96YA;64H<')E9U]R97!L86-E
M*"<O7#\N*B0O)RP@)R<L('1R:6TH)'1H:7,M/E]C:&%R<RDI*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("!]"@H@("`@("`@('!A<F5N=#HZ96YD16QE;65N="@D=7)I+"`D
M96QE;65N="D["B`@("!]"@H@("`@9G5N8W1I;VX@8VAA<F%C=&5R<R@D<W1R
M*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-U<G)E;G13>6YC
M16QE;65N="DI('L*("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT4WEN8T5L
M96UE;G0M/F-H87)A8W1E<G,H)'-T<BD["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8VAA<G,I*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V-H87)S(#T@)'1H:7,M/E]C:&%R<R`N("1S='([
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7V-H87)S(#T@)'-T<CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO0V]M
M;6%N9"]3>6YC16QE;65N="YP:'``````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,3$V,S0`,3`U,34T,S,W-#0`,#(T,3$S`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@II;F-L=61E7V]N8V4@)U-Y
M;F--3"]#;VUM86YD+G!H<"<["@HO*BH*("H@5&AE(&-L87-S(%-Y;F--3%]#
M;VUM86YD7U-Y;F-%;&5M96YT('-T;W)E<R!I;F9O<FUA=&EO;B!F<F]M('1H
M92!!9&0L"B`J($1E;&5T92!A;F0@4F5P;&%C92!E;&5M96YT<R!F;W5N9"!I
M;G-I9&4@82!S>6YC(&-O;6UA;F0N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+U-Y;F--3"]3>6YC34PO0V]M;6%N9"]3>6YC16QE;65N="YP:'`L=B`Q+C,N
M,BXS(#(P,#8O,#$O,#$@,C$Z,C@Z,S8@:F%N($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`R,#`U+3(P,#8@5&AE(&AO<F1E('!R;VIE8W0@*'=W=RYH;W)D92YO
M<F<I"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!+87)S=&5N($9O=7)M
M;VYT(#QK87)S=&5N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP
M"B`J($!P86-K86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7T-O;6UA;F1?
M4WEN8T5L96UE;G0@97AT96YD<R!3>6YC34Q?0V]M;6%N9"!["@H@("`@+RHJ
M"B`@("`@*B!!9&0L($1E;&5T92!O<B!297!L86-E+@H@("`@("HO"B`@("!V
M87(@)%]E;&5M96YT5'EP93L*"B`@("`O*BH*("`@("`J($%R<F%Y(&]F(%-Y
M;F--3%]3>6YC271E;2!E;G1R:65S+@H@("`@("HO"B`@("!V87(@)%]I=&5M
M<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!-:6UE='EP92!F;W(@86QL
M(&ET96US+@H@("`@("HO"B`@("!V87(@)%]C;VYT96YT5'EP93L*"B`@("`O
M*BH*("`@("`J(%1E;7`@9&%T82!F;W(@8W)E871I;VX@;V8@:6YD:79I9'5A
M;"!I=&5M<RX*("`@("`J+PH@("`@=F%R("1?8V]N=&5N=#L*"B`@("!V87(@
M)%]C=6ED.PH*("`@("\J*@H@("`@("H@36EM971Y<&4@9F]R(&EN9&EV:61U
M86P@:71E;2X*("`@("`J+PH@("`@=F%R("1?:71E;4-O;F5N=%1Y<&4["@H@
M("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@4WEN8R!%;&5M96YT+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@96QE;65N=%1Y<&4@96ET:&5R($%D9"P@
M1&5L971E(&]R(%)E<&QA8V4*("`@("`J+PH@("`@9G5N8W1I;VX@4WEN8TU,
M7T-O;6UA;F1?4WEN8T5L96UE;G0H)&5L96UE;G14>7!E*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?96QE;65N=%1Y<&4@/2`D96QE;65N=%1Y<&4["B`@("!]
M"@H@("`@9G5N8W1I;VX@;W5T<'5T*"1C=7)R96YT0VUD240L("8D;W5T<'5T
M*0H@("`@>PH@("`@("`@('-W:71C:"`H)'1H:7,M/E]E;&5M96YT5'EP92D@
M>PH@("`@("`@(&-A<V4@)T%D9"<Z"B`@("`@("`@("`@("1R97-P;VYS92`]
M(%)%4U!/3E-%7TE414U?041$140["B`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("!C87-E("=$96QE=&4G.@H@("`@("`@("`@("`D<F5S<&]N<V4@/2!2
M15-03TY315]/2SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@
M)U)E<&QA8V4G.@H@("`@("`@("`@("`D<F5S<&]N<V4@/2!215-03TY315]/
M2SL*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("`D<W1A
M='5S(#T@)FYE=R!3>6YC34Q?0V]M;6%N9%]3=&%T=7,H)')E<W!O;G-E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V5L96UE;G14>7!E*3L*("`@("`@("`D<W1A='5S+3YS971#;612
M968H)'1H:7,M/E]C;61)1"D["@H@("`@("`@(')E='5R;B`D<W1A='5S+3YO
M=71P=70H)&-U<G)E;G1#;61)1"P@)&]U='!U="D["B`@("!]"@H@("`@9G5N
M8W1I;VX@<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M96YT+"`D871T<G,I"B`@
M("!["B`@("`@("`@<&%R96YT.CIS=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE
M;G0L("1A='1R<RD["B`@("`@("`@<W=I=&-H("AC;W5N="@D=&AI<RT^7U-T
M86-K*2D@>PH@("`@("`@(&-A<V4@,CH*("`@("`@("`@("`@)'1H:7,M/E]C
M=6ED(#T@;G5L;#L*("`@("`@("`@("`@)'1H:7,M/E]C;VYT96YT(#T@;G5L
M;#L*("`@("`@("`@("`@)'1H:7,M/E]I=&5M0V]N=&5N=%1Y<&4@/2!N=6QL
M.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]"@H@("`@9G5N
M8W1I;VX@96YD16QE;65N="@D=7)I+"`D96QE;65N="D*("`@('L*("`@("`@
M("!S=VET8V@@*&-O=6YT*"1T:&ES+3Y?4W1A8VLI*2!["B`@("`@("`@8V%S
M92`Q.@H@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`R.@H@("`@
M("`@("`@("!I9B`H)&5L96UE;G0@/3T@)TET96TG*2!["B`@("`@("`@("`@
M("`@("!I9B`H96UP='DH)'1H:7,M/E]I=&5M0V]N=&5N=%1Y<&4I"B`@("`@
M("`@("`@("`@("`@("`@)B8@(65M<'1Y*"1T:&ES+3Y?8V]N=&5N=%1Y<&4I
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I=&5M0V]N=&5N=%1Y
M<&4@/2`D=&AI<RT^7V-O;G1E;G14>7!E.PH@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?:71E;7-;72`]("9N97<@4WEN8TU,
M7U-Y;F-)=&5M*"1T:&ES+3Y?96QE;65N=%1Y<&4L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V-O;G1E;G0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VET96U#;VYT96YT5'EP
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8W5I9"D["B`@("`@("`@("`@('T*"B`@
M("`@("`@8V%S92`S.@H@("`@("`@("`@("!I9B`H)&5L96UE;G0@/3T@)U1Y
M<&4G*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;G1E;G14>7!E(#T@
M=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1E
M;&5M96YT(#T]("=$871A)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C
M;VYT96YT(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`T.@H@("`@("`@("`@
M("!I9B`H)&5L96UE;G0@/3T@)TQO8U5222<I('L*("`@("`@("`@("`@("`@
M(&EF("@D=&AI<RT^7U-T86-K6S)=(#T]("=3;W5R8V4G*2!["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]C=6ED(#T@=')I;2@D=&AI<RT^7V-H87)S
M*3L*("`@("`@("`@("`@("`@('T@96QS96EF("@D=&AI<RT^7U-T86-K6S)=
M(#T]("=487)G970G*2!["B`@("`@("`@("`@("`@("`@("`@+R\@3F]T('5S
M960Z('=E(&EG;F]R92`B<W5I9"!P<F]P;W-A;',B(&9R;VT*("`@("`@("`@
M("`@("`@("`@("`O+R!C;&EE;G0N"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@-3H*
M("`@("`@("`@("`@:68@*"1E;&5M96YT(#T]("=4>7!E)RD@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]I=&5M0V]N=&5N=%1Y<&4@/2!T<FEM*"1T:&ES
M+3Y?8VAA<G,I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@('T*"B`@("`@("`@<&%R96YT.CIE;F1%;&5M96YT*"1U<FDL("1E
M;&5M96YT*3L*("`@('T*"B`@("!F=6YC=&EO;B!G971)=&5M<R@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?:71E;7,["B`@("!]"@H@("`@9G5N
M8W1I;VX@9V5T0V]N=&5N=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7V-O;G1E;G14>7!E.PH@("`@?0H*?0H*+RHJ"B`J(%1H92!C;&%S
M<R!3>6YC34Q?0V]M;6%N9%]3>6YC16QE;65N="!S=&]R97,@:6YF;W)M871I
M;VX@86)O=70*("H@=&AE(&ET96US(&EN<VED92!A('-Y;F,@96QE;65N="`H
M061D?$1E;&5T97Q297!L86-E*2X*("H*("H@02!S:6YG;&4@4WEN8T5L96UE
M;G0@8V%N(&-O;G1A:6X@;75L=&EP;&4@:71E;7,N"B`J"B`J($EN<W1A;F-E
M<R!O9B!T:&ES(&-L87-S(&%R92!C<F5A=&5D(&1U<FEN9R!T:&4@6$U,('!A
M<G-I;F<@8GD*("H@4WEN8TU,7T-O;6UA;F1?4WEN8T5L96UE;G0N"B`J"B`J
M($!P86-K86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7U-Y;F-)=&5M('L*
M"B`@("`O*BH*("`@("`J($%D9"P@1&5L971E(&]R(%)E<&QA8V4L(&EN:&5R
M:71E9"!F<F]M"B`@("`@*B!3>6YC34Q?0V]M;6%N9%]3>6YC16QE;65N="X*
M("`@("`J+PH@("`@=F%R("1?96QE;65N=%1Y<&4["@H@("`@=F%R("1?8W5I
M9#L*"B`@("`O*BH*("`@("`J($]P=&EO;F%L+"!M87D@8F4@<')O=FED960@
M8GD@<&%R96YT(&5L96UE;G0@;W(@979E;B!N;W0@870@86QL+@H@("`@("HO
M"B`@("!V87(@)%]C;VYT96YT5'EP93L*"B`@("!V87(@)%]C;VYT96YT.PH*
M("`@(&9U;F-T:6]N(%-Y;F--3%]3>6YC271E;2@D96QE;65N=%1Y<&4L("1C
M;VYT96YT(#T@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M8V]N=&5N=%1Y<&4@/2!N=6QL+"`D8W5I9"`](&YU;&PI"B`@("!["B`@("`@
M("`@)'1H:7,M/E]E;&5M96YT5'EP92`]("1E;&5M96YT5'EP93L*("`@("`@
M("`D=&AI<RT^7V-U:60@/2`D8W5I9#L*("`@("`@("`D=&AI<RT^7V-O;G1E
M;G14>7!E(#T@)&-O;G1E;G14>7!E.PH@("`@("`@("1T:&ES+3Y?8V]N=&5N
M="`]("1C;VYT96YT.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$-U:60H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V-U:60["B`@("!]"@H@("`@
M9G5N8W1I;VX@9V5T0V]N=&5N="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?8V]N=&5N=#L*("`@('T*"B`@("!F=6YC=&EO;B!G971#;VYT96YT
M5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V]N=&5N=%1Y
M<&4["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T16QE;65N=%1Y<&4H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V5L96UE;G14>7!E.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O4WEN
M8TU,+T-O;6UA;F0N<&AP````````````````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`S-38U`#$P-3$U-#,S-S0T`#`R,38W,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`H*:6YC;'5D95]O
M;F-E("=3>6YC34PO4W1A=&4N<&AP)SL*"B\J*@H@*B!4:&4@4WEN8TU,7T-O
M;6UA;F0@8VQA<W,@<')O=FED97,@82!S=7!E<B!C;&%S<R!F;R!3>6YC0F]D
M>0H@*B!C;VUM86YD<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4WEN8TU,
M+U-Y;F--3"]#;VUM86YD+G!H<"QV(#$N-"XQ,"XW(#(P,#8O,#$O,#$@,C$Z
M,C@Z,S8@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@06YT
M:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($%N=&AO;GD@36EL;',@/&%M:6QL<T!P>7)A;6ED
M-BYC;VT^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!3>6YC
M34P*("HO"F-L87-S(%-Y;F--3%]#;VUM86YD('L*"B`@("`O*BH*("`@("`J
M($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]C;61)1#L*"B`@("`O
M*BH*("`@("`J($EN=&5R;F%L('-T<G5C='5R92!U<V5D(&1U<FEN9R!834P@
M<&%R<VEN9RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D7U-T86-K(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V-H87)S.PH*("`@(&9U;F-T:6]N
M("9F86-T;W)Y*"1C;VUM86YD+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@
M("`@("!I;F-L=61E7V]N8V4@)U-Y;F--3"]#;VUM86YD+R<@+B`D8V]M;6%N
M9"`N("<N<&AP)SL*("`@("`@("`D8VQA<W,@/2`G4WEN8TU,7T-O;6UA;F1?
M)R`N("1C;VUM86YD.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S
M*2D@>PH@("`@("`@("`@("`D8VUD(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)$=,3T)!3%-;)V)A8VME
M;F0G72T^;&]G365S<V%G92@G0VQA<W,@9&5F:6YI=&EO;B!O9B`G("X@)&-L
M87-S("X@)R!N;W0@9F]U;F0N)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T524BD["B`@("`@("`@("`@(&EN8VQU9&5?;VYC92`G4$5!4BYP:'`G
M.PH@("`@("`@("`@("`D8VUD(#T@4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@
M9&5F:6YI=&EO;B!O9B`G("X@)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&-M9#L*("`@('T*"B`@("!F=6YC
M=&EO;B!O=71P=70H)&-U<G)E;G1#;61)1"P@)&]U='!U="D*("`@('L*("`@
M('T*"B`@("!F=6YC=&EO;B!S=&%R=$5L96UE;G0H)'5R:2P@)&QO8V%L3F%M
M92P@)&%T=')S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?4W1A8VM;72`]("1L
M;V-A;$YA;64["B`@("!]"@H@("`@9G5N8W1I;VX@96YD16QE;65N="@D=7)I
M+"`D96QE;65N="D*("`@('L*("`@("`@("!S=VET8V@@*&-O=6YT*"1T:&ES
M+3Y?4W1A8VLI*2!["B`@("`@("`@8V%S92`R.@H@("`@("`@("`@("!I9B`H
M)&5L96UE;G0@/3T@)T-M9$E$)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]C;61)1"`](&EN='9A;"AT<FEM*"1T:&ES+3Y?8VAA<G,I*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@
M("1T:&ES+3Y?8VAA<G,@/2`G)SL*("`@("`@("!A<G)A>5]P;W`H)'1H:7,M
M/E]3=&%C:RD["B`@("!]"@H@("`@9G5N8W1I;VX@8VAA<F%C=&5R<R@D<W1R
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8VAA<G,@+CT@)'-T<CL*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U-Y;F--3"]#
M;VYS=&%N=',N<&AP````````````````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`Q,S$Q,@`Q,#4Q-30S,S<T-``P,C(R-30`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J($-O<'ER:6=H
M="`R,#`U+3(P,#8@2V%R<W1E;B!&;W5R;6]N="`\:V%R<W1E;D!H;W)D92YO
M<F<^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-Y;F--3"]3>6YC34PO0V]N
M<W1A;G1S+G!H<"QV(#$N,2XR+C0@,C`P-B\P-2\P,2`Q,CHP-3HQ-"!J86X@
M17AP("0*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@
M*B!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($MA<G-T96X@1F]U
M<FUO;G0@/&MA<G-T96Y`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!3>6YC34P*
M("HO"F1E9FEN92@G04Q%4E1?1$E34$Q!62<L(#$P,"D["@HO+R!.;W0@:6UP
M;&5M96YT960N"F1E9FEN92@G04Q%4E1?5%=/7U=!62<L(#(P,"D["F1E9FEN
M92@G04Q%4E1?4TQ/5U]364Y#)RP@,C`Q*3L*9&5F:6YE*"=!3$525%]/3D5?
M5T%97T923TU?0TQ)14Y4)RP@,C`R*3L*9&5F:6YE*"=!3$525%]2149215-(
M7T923TU?0TQ)14Y4)RP@,C`S*3L*9&5F:6YE*"=!3$525%]/3D5?5T%97T92
M3TU?4T525D52)RP@,C`T*3L*9&5F:6YE*"=!3$525%]2149215-(7T923TU?
M4T525D52)RP@,C`U*3L*"B\O($YO="!I;7!L96UE;G1E9"X*9&5F:6YE*"=!
M3$525%]45T]?5T%97T)97U-%4E9%4B<L(#(P-BD["F1E9FEN92@G04Q%4E1?
M3TY%7U=!65]&4D]-7T-,245.5%]"65]315)615(G+"`R,#<I.PID969I;F4H
M)T%,15)47U)%1E)%4TA?1E)/35]#3$E%3E1?0EE?4T525D52)RP@,C`X*3L*
M9&5F:6YE*"=!3$525%]/3D5?5T%97T923TU?4T525D527T)97U-%4E9%4B<L
M(#(P.2D["F1E9FEN92@G04Q%4E1?4D5&4D532%]&4D]-7U-%4E9%4E]"65]3
M15)615(G+"`R,3`I.PH*9&5F:6YE*"=!3$525%]215-53%1?04Q%4E0G+"`R
M,C$I.PID969I;F4H)T%,15)47TY%6%1?34534T%'12<L(#(R,BD["F1E9FEN
M92@G04Q%4E1?3D]?14Y$7T]&7T1!5$$G+"`R,C,I.PH*9&5F:6YE*"=-24U%
M7U-93D--3%]834PG+"`G87!P;&EC871I;VXO=FYD+G-Y;F-M;"MX;6PG*3L*
M9&5F:6YE*"=-24U%7U-93D--3%]70EA-3"<L("=A<'!L:6-A=&EO;B]V;F0N
M<WEN8VUL*W=B>&UL)RD["@ID969I;F4H)TU)345?4UE.0TU,7T1%5DE#15])
M3D9/7UA-3"<L("=A<'!L:6-A=&EO;B]V;F0N<WEN8VUL+61E=FEN9BMX;6PG
M*3L*9&5F:6YE*"=-24U%7U-93D--3%]$159)0T5?24Y&3U]70EA-3"<L("=A
M<'!L:6-A=&EO;B]V;F0N<WEN8VUL+61E=FEN9BMW8GAM;"<I.PH*9&5F:6YE
M*"=-24U%7U1%6%1?4$Q!24XG+"`G=&5X="]P;&%I;B<I.PID969I;F4H)TU)
M345?5D-!4D1?5C(Q)RP@)W1E>'0O>"UV8V%R9"<I.PID969I;F4H)TU)345?
M5D-!4D1?5C,P)RP@)W1E>'0O=F-A<F0G*3L*"F1E9FEN92@G34E-15]60T%,
M14Y$05(G+"`G=&5X="]X+79C86QE;F1A<B<I.PID969I;F4H)TU)345?24-!
M3$5.1$%2)RP@)W1E>'0O8V%L96YD87(G*3L*9&5F:6YE*"=-24U%7UA-3%])
M0T%,14Y$05(G+"`G87!P;&EC871I;VXO=FYD+G-Y;F-M;"UX8V%L)RD["@ID
M969I;F4H)TU)345?34534T%'12<L("=T97AT+VUE<W-A9V4G*3L*"F1E9FEN
M92@G34E-15]364Y#34Q?6$U,7T5-04E,)RP@)V%P<&QI8V%T:6]N+W9N9"YS
M>6YC;6PM>&US9R<I.PID969I;F4H)TU)345?4UE.0TU,7UA-3%]"3T]+34%2
M2R<L("=A<'!L:6-A=&EO;B]V;F0N<WEN8VUL+7AB;V]K;6%R:R<I.PID969I
M;F4H)TU)345?4UE.0TU,7U)%3$%424].04Q?3T)*14-4)RP@)V%P<&QI8V%T
M:6]N+W9N9"YS>6YC;6PM>')E;&%T:6]N86PG*3L*"F1E9FEN92@G4D534$].
M4T5?24Y?4%)/1U)%4U,G+"`Q,#$I.PH*9&5F:6YE*"=215-03TY315]/2R<L
M(#(P,"D["F1E9FEN92@G4D534$].4T5?251%35]!1$1%1"<L(#(P,2D["F1E
M9FEN92@G4D534$].4T5?04-#15!4141?1D]27U!23T-%4U-)3D<G+"`R,#(I
M.PID969I;F4H)U)%4U!/3E-%7TY/3D%55$A/4DE!5$%4259%7U)%4U!/3E-%
M)RP@,C`S*3L*9&5F:6YE*"=215-03TY315].3U]#3TY414Y4)RP@,C`T*3L*
M9&5F:6YE*"=215-03TY315]215-%5%]#3TY414Y4)RP@,C`U*3L*9&5F:6YE
M*"=215-03TY315]005)424%,7T-/3E1%3E0G+"`R,#8I.PID969I;F4H)U)%
M4U!/3E-%7T-/3D9,24-47U)%4T],5D5$7U=)5$A?34521T4G+"`R,#<I.PID
M969I;F4H)U)%4U!/3E-%7T-/3D9,24-47U)%4T],5D5$7U=)5$A?0TQ)14Y4
M7U=)3DY)3D<G+"`R,#@I.PID969I;F4H)U)%4U!/3E-%7T-/3D9)3$-47U)%
M4T],5D5$7U=)5$A?1%503$E#051%)RP@,C`Y*3L*9&5F:6YE*"=215-03TY3
M15]$14Q%5$5?5TE42$]55%]!4D-(259%)RP@,C$P*3L*9&5F:6YE*"=215-0
M3TY315])5$5-7TY/7T1%3$54140G+"`R,3$I.PID969I;F4H)U)%4U!/3E-%
M7T%55$A%3E1)0T%424].7T%#0T505$5$)RP@,C$R*3L*9&5F:6YE*"=215-0
M3TY315]#2%5.2T5$7TE414U?04-#15!4141?04Y$7T)51D9%4D5$)RP@,C$S
M*3L*9&5F:6YE*"=215-03TY315]/4$52051)3TY?0T%.0T5,3$5$)RP@,C$T
M*3L*9&5F:6YE*"=215-03TY315].3U]%6$5#551%1"<L(#(Q-2D["F1E9FEN
M92@G4D534$].4T5?051/34E#7U)/3$Q?0D%#2U]/2R<L(#(Q-BD["@ID969I
M;F4H)U)%4U!/3E-%7TU53%1)4$Q%7T-(3TE#15,G+"`S,#`I.PHO+R!.965D
M('1O(&-H86YG92!N86UE<RX*+R\@9&5F:6YE*"=215-03TY315]-54Q425!,
M15]#2$])0T53)RP@,S`Q*3L*+R\@9&5F:6YE*"=215-03TY315]-54Q425!,
M15]#2$])0T53)RP@,S`R*3L*+R\@9&5F:6YE*"=215-03TY315]-54Q425!,
M15]#2$])0T53)RP@,S`S*3L*+R\@9&5F:6YE*"=215-03TY315]-54Q425!,
M15]#2$])0T53)RP@,S`T*3L*9&5F:6YE*"=215-03TY315]54T5?4%)/6%DG
M+"`S,#4I.PH*9&5F:6YE*"=215-03TY315]"041?4D5154535"<L(#0P,"D[
M"F1E9FEN92@G4D534$].4T5?24Y604Q)1%]#4D5$14Y424%,4R<L(#0P,2D[
M"B\O($YE960@=&\@8VAA;F=E(&YA;65S+@HO+R!D969I;F4H)U)%4U!/3E-%
M7TE.5D%,241?0U)%1$5.5$E!3%,G+"`T,#(I.PHO+R!D969I;F4H)U)%4U!/
M3E-%7TE.5D%,241?0U)%1$5.5$E!3%,G+"`T,#,I.PID969I;F4H)U)%4U!/
M3E-%7TY/5%]&3U5.1"<L(#0P-"D["B\O($YE960@=&\@8VAA;F=E(&YA;65S
M+@HO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,G+"`T
M,#4I.PHO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,G
M+"`T,#8I.PID969I;F4H)U)%4U!/3E-%7T-2141%3E1)04Q37TU)4U-)3D<G
M+"`T,#<I.PHO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!
M3%,G+"`T,#@I.PHO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.
M5$E!3%,G+"`T,#DI.PHO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%
M1$5.5$E!3%,G+"`T,3`I.PHO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?
M0U)%1$5.5$E!3%,G+"`T,3$I.PHO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,
M241?0U)%1$5.5$E!3%,G+"`T,3(I.PHO+R!D969I;F4H)U)%4U!/3E-%7TE.
M5D%,241?0U)%1$5.5$E!3%,G+"`T,3,I.PHO+R!D969I;F4H)U)%4U!/3E-%
M7TE.5D%,241?0U)%1$5.5$E!3%,G+"`T,30I.PHO+R!D969I;F4H)U)%4U!/
M3E-%7TE.5D%,241?0U)%1$5.5$E!3%,G+"`T,34I.PID969I;F4H)U)%4U!/
M3E-%7U)%455%4U1?4TE:15]43T]?0DE')RP@-#$V*3L*+R\@3F5E9"!T;R!C
M:&%N9V4@;F%M97,N"B\O(&1E9FEN92@G4D534$].4T5?24Y604Q)1%]#4D5$
M14Y424%,4R<L(#0Q-RD["B\O(&1E9FEN92@G4D534$].4T5?24Y604Q)1%]#
M4D5$14Y424%,4R<L(#0Q."D["B\O(&1E9FEN92@G4D534$].4T5?24Y604Q)
M1%]#4D5$14Y424%,4R<L(#0Q.2D["B\O(&1E9FEN92@G4D534$].4T5?24Y6
M04Q)1%]#4D5$14Y424%,4R<L(#0R,"D["B\O(&1E9FEN92@G4D534$].4T5?
M24Y604Q)1%]#4D5$14Y424%,4R<L(#0R,2D["B\O(&1E9FEN92@G4D534$].
M4T5?24Y604Q)1%]#4D5$14Y424%,4R<L(#0R,BD["B\O(&1E9FEN92@G4D53
M4$].4T5?24Y604Q)1%]#4D5$14Y424%,4R<L(#0R,RD["F1E9FEN92@G4D53
M4$].4T5?4TE:15]-25--051#2"<L(#0R-"D["@ID969I;F4H)U)%4U!/3E-%
M7T-/34U!3D1?1D%)3$5$)RP@-3`P*3L*+R\@3F5E9"!T;R!C:&%N9V4@;F%M
M97,N"B\O(&1E9FEN92@G4D534$].4T5?0T]-34%.1%]&04E,140G+"`U,#$I
M.PHO+R!D969I;F4H)U)%4U!/3E-%7T-/34U!3D1?1D%)3$5$)RP@-3`R*3L*
M+R\@9&5F:6YE*"=215-03TY315]#3TU-04Y$7T9!24Q%1"<L(#4P,RD["B\O
M(&1E9FEN92@G4D534$].4T5?0T]-34%.1%]&04E,140G+"`U,#0I.PHO+R!D
M969I;F4H)U)%4U!/3E-%7T-/34U!3D1?1D%)3$5$)RP@-3`U*3L*+R\@9&5F
M:6YE*"=215-03TY315]#3TU-04Y$7T9!24Q%1"<L(#4P-BD["B\O(&1E9FEN
M92@G4D534$].4T5?0T]-34%.1%]&04E,140G+"`U,#<I.PHO+R!D969I;F4H
M)U)%4U!/3E-%7T-/34U!3D1?1D%)3$5$)RP@-3`X*3L*+R\@9&5F:6YE*"=2
M15-03TY315]#3TU-04Y$7T9!24Q%1"<L(#4P.2D["B\O(&1E9FEN92@G4D53
M4$].4T5?0T]-34%.1%]&04E,140G+"`U,3`I.PHO+R!D969I;F4H)U)%4U!/
M3E-%7T-/34U!3D1?1D%)3$5$)RP@-3$Q*3L*+R\@9&5F:6YE*"=215-03TY3
M15]#3TU-04Y$7T9!24Q%1"<L(#4Q,BD["B\O(&1E9FEN92@G4D534$].4T5?
M0T]-34%.1%]&04E,140G+"`U,3,I.PHO+R!D969I;F4H)U)%4U!/3E-%7T-/
M34U!3D1?1D%)3$5$)RP@-3$T*3L*+R\@9&5F:6YE*"=215-03TY315]#3TU-
M04Y$7T9!24Q%1"<L(#4Q-2D["B\O(&1E9FEN92@G4D534$].4T5?051/34E#
M7U)/3$Q?0D%#2U]&04E,140G+"`U,38I.PH*9&5F:6YE*"=.04U%7U-004-%
M7U5225]364Y#34Q?,5\Q)RP@)W-Y;F-M;#IS>6YC;6PQ+C$G*3L*9&5F:6YE
M*"=.04U%7U-004-%7U5225]364Y#34PG+"`G<WEN8VUL.G-Y;F-M;"<I.PID
M969I;F4H)TY!345?4U!!0T5?55))7TU%5$E.1B<L("=S>6YC;6PZ;65T:6YF
M)RD["F1E9FEN92@G3D%-15]34$%#15]54DE?345424Y&7S%?,2<L("=S>6YC
M;6PZ;65T:6YF)RD["F1E9FEN92@G3D%-15]34$%#15]54DE?1$5624Y&)RP@
M)W-Y;F-M;#ID979I;F8G*3L*9&5F:6YE*"=.04U%7U-004-%7U5225]$159)
M3D9?,5\Q)RP@)W-Y;F-M;#ID979I;F8G*3L*"B\J*@H@*B!)9B!S970@=&\@
M=')U92P@;&]G<R!A;&P@:6YC;VUI;F<@86YD(&]U=&=O=6YD(&EC86QE;F1A
M<B]V8V%R9"!D871A"B`J('1O("]T;7`O<WEN8R]L;V<N='AT+B!4:&4@=V5B
M('-E<G9E<B!U<V5R("AL:6ME('=W=W)U;BD@;75S="!H879E"B`J('=R:71E
M(&%C8V5S<R!T;R!T:&ES(&9I;&4N"B`J+PID969I;F4H)T1%0E5'3$]'7TE#
M04Q%3D1!4D1!5$$G+"!T<G5E*3L*"B\J*@H@*B!)9B!S970@=&\@=')U92P@
M82!C;W!Y(&]F(&%N>2!$979);F8@<F5C96EV960@9G)O;2!C;&EE;G1S"B`J
M(&ES('-A=F5D('1O("]T;7`O<WEN8R]D979I;F8N='AT+@H@*B!4:&4@=V5B
M('-E<G9E<B!U<V5R("AL:6ME('=W=W)U;BD@;75S="!H879E"B`J('=R:71E
M(&%C8V5S<R!T;R!T:&ES(&9I;&4N"B`J+PH*9&5F:6YE*"=$14)51TQ/1U]$
M159)3D8G+"!T<G5E*3L*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O4WEN8TU,+T1E=FEC
M92\`````````````````````````````````````````````````````````
M`````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-3$U-#,S-S0T`#`R,#<W,``@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B]3>6YC34PO1&5V:6-E+TYO:VEA+G!H<```````````````````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#0U-34`,3`U,34T,S,W-#0`,#(R-34S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!4:&4@4WEN8TU,7T1E=FEC95].;VMI83HZ(&-L87-S('!R;W9I9&5S
M(&9U;F-T:6]N86QI='D@=&AA="!I<PH@*B!S<&5C:69I8R!T;R!T:&4@3F]K
M:6$@4WEN8TU,(&-L:65N=',N"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@
M2V%R<W1E;B!&;W5R;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]3>6YC34PO4WEN8TU,+T1E
M=FEC92].;VMI82YP:'`L=B`Q+C(N,BXS(#(P,#8O,#4O,#$@,3(Z,#4Z,30@
M:F%N($5X<"`D"B`J"B`J($!A=71H;W(@($MA<G-T96X@1F]U<FUO;G0@/&MA
M<G-T96Y`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!3>6YC34P*("HO"F-L87-S
M(%-Y;F--3%]$979I8V5?3F]K:6$@97AT96YD<R!3>6YC34Q?1&5V:6-E('L*
M"B`@("`O*BH*("`@("`J($-O;G9E<G1S('1H92!C;VYT96YT(&9R;VT@=&AE
M(&)A8VME;F0@=&\@82!F;W)M870@<W5I=&%B;&4@9F]R('1H90H@("`@("H@
M8VQI96YT(&1E=FEC92X*("`@("`J"B`@("`@*B!3=')I<',@=&AE('5I9"`H
M<')I;6%R>2!K97DI(&EN9F]R;6%T:6]N(&%S(&-L:65N="!A;F0@<V5R=F5R
M(&UI9VAT('5S90H@("`@("H@9&EF9F5R96YT(&]N97,N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N="`@("`@("!4:&4@8V]N=&5N="!T
M;R!C;VYV97)T"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT96YT5'EP92`@
M(%1H92!C;VYT96YT5'EP92!O9B!C;VYT96YT(&%S(')E='5R;F5D(&9R;VT*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&)A8VME
M;F0*("`@("`J($!R971U<FX@87)R87D@("`@("`@("`@("`@("`@87)R87DH
M)&YE=V-O;G1E;G0L("1N97=C;VYT96YT5'EP92DZ"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('1H92!C;VYV97)T960@8V]N=&5N="!A
M;F0@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("AP
M;W-S:6)L>2!C:&%N9V5D*2!N97<@0V]N=&5N=%1Y<&4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-O;G9E<G1397)V97(R0VQI96YT*"1C;VYT96YT+"`D8V]N
M=&5N=%1Y<&4I"B`@("!["B`@("`@("`@9VQO8F%L("1B86-K96YD.PH*("`@
M("`@("!L:7-T*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I(#T*("`@("`@("`@
M("`@<&%R96YT.CIC;VYV97)T4V5R=F5R,D-L:65N="@D8V]N=&5N="P@)&-O
M;G1E;G14>7!E*3L*"B`@("`@("`@+R\@1DE8344Z(&IU<W0@<W=A<'!I;F<@
M;W5T('1H92!V97)S:6]N(&YU;6)E<B!I;B!T:&4@:&5A9&5R"B`@("`@("`@
M+R\@<V\@=&AA="!T:&4@8VQI96YT(&1O97-N)W0@:6UM961I871E;'D@9&5N
M>2!W:71H(&$@(D9O<FUA=`H@("`@("`@("\O(&YO="!S=7!P;W)T960B+B!3
M964@:'1T<#HO+V)U9W,N:&]R9&4N;W)G+W1I8VME="\_:60],3@X,2X*("`@
M("`@("`D8V]N=&5N="`]('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*59%
M4E-)3TXZ,BXP+R<L("=<,59%4E-)3TXZ,2XP)RP@)&-O;G1E;G0L(#$I.PH*
M("`@("`@("!I9B`H1$5"54=,3T=?24-!3$5.1$%21$%402D@>PH@("`@("`@
M("`@("`D9G`@/2!`9F]P96XH)R]T;7`O<WEN8R]L;V<N='AT)RP@)V$G*3L*
M("`@("`@("`@("`@:68@*"1F<"D@>PH@("`@("`@("`@("`@("`@0&9W<FET
M92@D9G`L(")<;F]U='!U="!C;VYV97)T960@9F]R(&-L:65N="`H)&-O;G1E
M;G14>7!E*3I<;B(I.PH@("`@("`@("`@("`@("`@0&9W<FET92@D9G`L("1C
M;VYT96YT("X@(EQN(BD["B`@("`@("`@("`@("`@("!`9F-L;W-E*"1F<"D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A
M>2@D8V]N=&5N="P@)&-O;G1E;G14>7!E*3L*("`@('T*"B`@("`O*B!.;VMI
M82!C=7)R96YT;'D@97AP96-T<R!N;W1E<R!A<R!T97AT+W!L86EN+B!-87EB
M92!W92!C86X@97AT<F%C=`H@("`@("H@=&AI<R!F<F]M($1E=DEN9B!R871H
M97(@=&AA;B!H87)D8V]D92!I="X*("`@("`J+PH*("`@9G5N8W1I;VX@9V5T
M4')E9F5R<F5D0V]N=&5N=%1Y<&4H)'1Y<&4I"B`@("!["B`@("`@("`@(&EF
M("@D='EP92`]/2`G;F]T97,G*2!["B`@("`@("`@("`@(')E='5R;B`G=&5X
M="]P;&%I;B<["B`@("`@("`@?0H@("`@("`@(')E='5R;B!P87)E;G0Z.F=E
M=%!R969E<G)E9$-O;G1E;G14>7!E*"1T>7!E*3L*("`@('T*"B`@(&9U;F-T
M:6]N(&AA;F1L951A<VMS26Y#86QE;F1A<B@I"B`@('L*("`@("`@<F5T=7)N
M('1R=64[("`@("`@"B`@('T*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO1&5V:6-E+U`X,#`N<&AP````````
M````````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3,T-3(`,3`U,34T,S,W-#0`
M,#(R,3,U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!0.#`P+U`Y,#`O4#DQ,#H*("H@+2TM+2TM+2TM
M+2TM+2TM"B`J($-H87)S970Z"B`J(%1H:7,@9&5V:6-E(&ES(&%B;&4@=&\@
M:&%N9&QE(%541BTX(&%N9"!S96YD<R!I=',@6$U,('!A8VMA9V5S(&EN(%54
M1C@N"B`J($AO=V5V97(@979E;B!T:&]U9V@@=&AE(%A-3"!I='-E;&8@:7,@
M551&+3@L(&ET(&5X<&5C=',@=&AE(&5N8VQO<V5D"B`J('9C87)D+61A=&$@
M=&\@8F4@25-/+3@X-3DM,2!U;FQE<W,@97AP;&EC:71L>2!S=&%T960@;W1H
M97)W:7-E("AU<VEN9R!T:&4*("H@0TA!4E-%5"!O<'1I;VXL('=H:6-H(&ES
M(&1E<')E8V%T960@9F]R(%9#05)$(#,N,"D*("H*("H@16YC;V1I;F<Z"B`J
M(%-T<FEN9R!V86QU97,@87)E(&5N8V]D960@(E%53U1%1"U04DE.5$%"3$4B
M"B`J"B`J($]T:&5R.@H@*B!4:&ES(&1E=FEC97,@:&%N9&QE<R!T87-K<R!A
M;F0@979E;G1S(&EN(&]N92!D871A8F%S92X*("H*("H@07,@=&AE(%`X,#`@
M=V%S('1H92!F:7)S="!D979I8V4@=&\@=V]R:R!W:71H('!A8VMA9V4L(&UO
M<W0@;V8@=&AE"B`J(')E<75I<F5D(&-O;G9E<G-I;VYS(&%R92!I;B!$979I
M8V4N<&AP)W,@9&5F875L="!H86YD;&EN9RX*("H*("H@0V]P>7)I9VAT(#(P
M,#4M,C`P-B!+87)S=&5N($9O=7)M;VYT(#QK87)S=&5N0&AO<F1E+F]R9SX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-Y;F--3"]3
M>6YC34PO1&5V:6-E+U`X,#`N<&AP+'8@,2XW+C(N-2`R,#`V+S`U+S`Q(#$R
M.C`U.C$T(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R("!+87)S=&5N($9O=7)M
M;VYT(#QK87)S=&5N0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@4WEN8TU,"B`J
M+PIC;&%S<R!3>6YC34Q?1&5V:6-E7U`X,#`@97AT96YD<R!3>6YC34Q?1&5V
M:6-E('L*"B`@("`O*BH*("`@("`J($-O;G9E<G0@=&AE(&-O;G1E;G0N"B`@
M("`@*@H@("`@("H@0W5R<F5N=&QY('-T<FEP<R!U:60@*'!R:6UA<GD@:V5Y
M*2!I;F9O<FUA=&EO;B!A<R!C;&EE;G0@86YD"B`@("`@*B!S97)V97(@;6EG
M:'0@=7-E(&1I9F9E<F5N="!O;F5S+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&-O;G1E;G0@("`@("`@5&AE(&-O;G1E;G0@=&\@8V]N=F5R="X*
M("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E;G14>7!E("`@5&AE(&-O;G1E
M;G14>7!E(&]F('1H92!C;VYT96YT+@H@("`@("H@0')E='5R;B!A<G)A>2`@
M("`@("`@("`@("`@("!A<G)A>2@D;F5W8V]N=&5N="P@)&YE=V-O;G1E;G14
M>7!E*3H*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE
M(&-O;G9E<G1E9"!C;VYT96YT(&%N9"!T:&4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@*'!O<W-I8FQY(&-H86YG960I(&YE=R!#;VYT
M96YT5'EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]N=F5R=$-L:65N=#)3
M97)V97(H)&-O;G1E;G0L("1C;VYT96YT5'EP92D*("`@('L*("`@("`@("!L
M:7-T*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I(#T*("`@("`@("`@("`@<&%R
M96YT.CIC;VYV97)T0VQI96YT,E-E<G9E<B@D8V]N=&5N="P@)&-O;G1E;G14
M>7!E*3L*"B`@("`@("`@+RH@4#@P,"!S96YD<R!C871E9V]R:65S(&%S(")8
M+4-A=&5G;W)Y(BX@4F5M;W9E('1H92`B6"TB.B`J+PH@("`@("`@("1C;VYT
M96YT(#T@<')E9U]R97!L86-E*"<O*%QR7&Y\7')\7&XI0T%414=/4DE%4SI8
M+2\G+"`G7#%#051%1T]22453.B<L("1C;VYT96YT+"`Q*3L*"B`@("`@("`@
M+RH@4#@P,"!S96YD<R!A;&P@9&%Y(&5V96YT<R!A<R!S+G1H+B!L:6ME"B`@
M("`@("`@("H@1%135$%25#HR,#`U,#4P-50P,#`P,#!:7DT*("`@("`@("`@
M*B!$5$5.1#HR,#`U,#4P-50R-#`P,#!:7DT*("`@("`@("`@*B!4:&ES(&ES
M(&YO(&QO;F=E<B!A;B!A;&P@9&%Y(&5V96YT('=H96X@8V]N=F5R=&5D('1O
M(&QO8V%L('1I;65Z;VYE+@H@("`@("`@("`J(%-O(&UA;G5A;&QY(&AA;F1L
M92!T:&ES+@H@("`@("`@("`J("HO"B`@("`@("`@:68@*'!R96=?;6%T8V@H
M)R\H7')<;GQ<<GQ<;BE$5%-405)4.BXJ5#`P,#`P,%HH7')<;GQ<<GQ<;BDO
M)RP*("`@("`@("`@("`@("`@("`@("`@("`D8V]N=&5N="D*("`@("`@("`@
M("`@)B8@<')E9U]M871C:"@G+RA<<EQN?%QR?%QN*41414Y$.BA<9%QD7&1<
M9"DH7&1<9"DH7&1<9"E4,C0P,#`P6BA<<EQN?%QR?%QN*2\G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("1C;VYT96YT+"`D;2DI('L*("`@("`@("`@
M("`@)&-O;G1E;G0@/2!P<F5G7W)E<&QA8V4H)R\H7')<;GQ<<GQ<;BE$5%-4
M05)4.B@N*BE4,#`P,#`P6BA<<EQN?%QR?%QN*2\G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`B)#%$5%-405)4.U9!3%5%/41!5$4Z
M)#(D,R(L("1C;VYT96YT*3L*("`@("`@("`@("`@+RH@16YD('1I;65S=&%M
M<"!M=7-T(&)E(&-O;G9E<G1E9"!T;R!N97AT(&1A>2=S(&1A=&4N("HO"B`@
M("`@("`@("`@("1S(#T@9&%T92@G66UD)RP@;6MT:6UE*#`L(#`L(#`L("1M
M6S-=+"`D;5LT72P@)&U;,ETI("L@,C0J,S8P,"D["B`@("`@("`@("`@("1C
M;VYT96YT(#T@<')E9U]R97!L86-E*"<O*%QR7&Y\7')\7&XI1%1%3D0Z*"XJ
M*50R-#`P,#!:*%QR7&Y\7')\7&XI+R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("(D,41414Y$.U9!3%5%/41!5$4Z)',D,R(L("1C
M;VYT96YT*3L*("`@("`@("!]"@H@("`@("`@(&EF("A$14)51TQ/1U])0T%,
M14Y$05)$051!*2!["B`@("`@("`@("`@("1F<"`]($!F;W!E;B@G+W1M<"]S
M>6YC+VQO9RYT>'0G+"`G82<I.PH@("`@("`@("`@("!I9B`H)&9P*2!["B`@
M("`@("`@("`@("`@("!`9G=R:71E*"1F<"P@(EQN:6YP=70@8V]N=F5R=&5D
M(&9O<B!S97)V97(Z("1C;VYT96YT5'EP95QN(BD["B`@("`@("`@("`@("`@
M("!`9G=R:71E*"1F<"PD8V]N=&5N="`N(")<;B(I.PH@("`@("`@("`@("`@
M("`@0&9C;&]S92@D9G`I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@87)R87DH)&-O;G1E;G0L("1C;VYT96YT5'EP92D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T<R!T:&4@8V]N=&5N="!F<F]M
M('1H92!B86-K96YD('1O(&$@9F]R;6%T('-U:71A8FQE(&9O<B!T:&4*("`@
M("`J(&-L:65N="!D979I8V4N"B`@("`@*@H@("`@("H@4W1R:7!S('1H92!U
M:60@*'!R:6UA<GD@:V5Y*2!I;F9O<FUA=&EO;B!A<R!C;&EE;G0@86YD('-E
M<G9E<B!M:6=H="!U<V4*("`@("`J(&1I9F9E<F5N="!O;F5S+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E;G0@("`@("`@5&AE(&-O;G1E
M;G0@=&\@8V]N=F5R="X*("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E;G14
M>7!E("`@5&AE(&-O;G1E;G14>7!E(&]F(&-O;G1E;G0@87,@<F5T=7)N960@
M9G)O;0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@
M8F%C:V5N9"X*("`@("`J($!R971U<FX@87)R87D@("`@("`@("`@("`@("`@
M87)R87DH)&YE=V-O;G1E;G0L("1N97=C;VYT96YT5'EP92DZ"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H92!C;VYV97)T960@8V]N
M=&5N="!A;F0@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("AP;W-S:6)L>2!C:&%N9V5D*2!N97<@0V]N=&5N=%1Y<&4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-O;G9E<G1397)V97(R0VQI96YT*"1C;VYT96YT
M+"`D8V]N=&5N=%1Y<&4I"B`@("!["B`@("`@("`@9VQO8F%L("1B86-K96YD
M.PH*("`@("`@("!L:7-T*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I(#T*("`@
M("`@("`@("`@<&%R96YT.CIC;VYV97)T4V5R=F5R,D-L:65N="@D8V]N=&5N
M="P@)&-O;G1E;G14>7!E*3L*"B`@("`@("`@+RH@0V]N=F5R="!A;&P@9&%Y
M(&5V96YT<RX@*B\*("`@("`@("!I9B`H<')E9U]M871C:"@G+RA<<EQN?%QR
M?%QN*4144U1!4E0[5D%,544]1$%413HH7&1[.'TI+R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@)&-O;G1E;G0I"B`@("`@("`@("`@("8F('!R96=?;6%T
M8V@H)R\H7')<;GQ<<GQ<;BE$5$5.1#M604Q513U$051%.BA<9%QD7&1<9"DH
M7&1<9"DH7&1<9"DO)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]N
M=&5N="P@)&TI*2!["B`@("`@("`@("`@("1C;VYT96YT(#T@<')E9U]R97!L
M86-E*"<O*%QR7&Y\7')\7&XI1%135$%25#M604Q513U$051%.BA<9'LX?2DO
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(B0Q1%13
M5$%25#HD,E0P,#`P,#!:(BP@)&-O;G1E;G0I.PH@("`@("`@("`@("`O*B!%
M;F0@9&%T92!M=7-T(&)E(&-O;G9E<G1E9"!T;R!T:6UE<W1A;7`N("HO"B`@
M("`@("`@("`@("1S(#T@9&%T92@G66UD)RP@;6MT:6UE*#`L(#`L(#`L("1M
M6S-=+"`D;5LT72P@)&U;,ETI("T@,C0J,S8P,"D["B`@("`@("`@("`@("1C
M;VYT96YT(#T@<')E9U]R97!L86-E*"<O*%QR7&Y\7')\7&XI1%1%3D0[5D%,
M544]1$%413HH7&1[.'TI+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("(D,41414Y$.SHD>W-]5#(T,#`P,%HB+"`D8V]N=&5N="D[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H1$5"54=,3T=?24-!3$5.1$%21$%4
M02D@>PH@("`@("`@("`@("`D9G`@/2!`9F]P96XH)R]T;7`O<WEN8R]L;V<N
M='AT)RP@)V$G*3L*("`@("`@("`@("`@:68@*"1F<"D@>PH@("`@("`@("`@
M("`@("`@0&9W<FET92@D9G`L(")<;F]U='!U="!C;VYV97)T960@9F]R(&-L
M:65N="`H)&-O;G1E;G14>7!E*3I<;B(I.PH@("`@("`@("`@("`@("`@0&9W
M<FET92@D9G`L("1C;VYT96YT("X@(EQN(BD["B`@("`@("`@("`@("`@("!`
M9F-L;W-E*"1F<"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!A<G)A>2@D8V]N=&5N="P@)&-O;G1E;G14>7!E*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%-O;64@9&5V:6-E<R!L:6ME('1H92!3;VYY($5R
M:6-S<V]N(%`X,#`O4#DP,"]0.3$P(&AA;F1L92!V=&]D;W,@*'1A<VMS*0H@
M("`@("H@86YD('9E=F5N=',@:6X@=&AE('-A;64@(F-A;&5N9&%R(B!S>6YC
M+@H@("`@("H@5&AI<R!R97%U:7)E<R!S<&5C:6%L(&%C=&EO;G,@;VX@;W5R
M('-I9&4@87,@=V4@<W1O<F4@=&AI<R!I;B!D:69F97)E;G0*("`@("`J(&1A
M=&%B87-E<R`H;F%G(&%N9"!K<F]N;VQI=&@I+@H@("`@("H@5&AI<R!F=6YC
M=&EO;B!C;W5L9"!D:7)E8W1L>2!R971U<FX@=')U92!B=70@=')I97,@=&\@
M8F4@82!B:70@;6]R90H@("`@("H@9V5N97)I8R!S;R!I="!M:6=H="!W;W)K
M(&9O<B!O=&AE<B!P:&]N97,@87,@=V5L;"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@:&%N9&QE5&%S:W-);D-A;&5N9&%R*"D*("`@('L*("`@("`@("`D9&D@
M/2`D=&AI<RT^9&5V:6-E26YF;R@I.PH*("`@("`@("!I9B`H(65M<'1Y*"1D
M:2T^7T-40V%P6R=T97AT+W@M=F-A;&5N9&%R)UU;)T)%1TE.)UTM/E]686Q%
M;G5M6R=6159%3E0G72D@)B8*("`@("`@("`@("`@(65M<'1Y*"1D:2T^7T-4
M0V%P6R=T97AT+W@M=F-A;&5N9&%R)UU;)T)%1TE.)UTM/E]686Q%;G5M6R=6
M5$]$3R==*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!P87)E;G0Z.FAA;F1L951A<VMS26Y#86QE;F1A
M<B@I.PH@("`@?0H*("`@(&9U;F-T:6]N(&YE961S0V%T96=O<GE-87!P:6YG
M*"D*("`@('L*("`@("`@("`O+R!0.#`P('5S97,@;G5M97)I8R!C871E9V]R
M>2!C;V1E<RX*("`@("`@("!R971U<FX@=')U93L*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+U-Y;F--3"]$979I8V4O4WEN8S1J+G!H<```````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`U-#4V,P`Q,#4Q-30S,S<T-``P,C(V
M-S``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O:4-A;&5N9&%R+G!H<"<["@HO
M*BH*("H@4WEN8S1J("AW=W<N<WEN8S1J+F]R9RD*("H*("H@5&AE(%-Y;F,T
M2B!O=71L;V]K(&-O;G9E<G1E<B!U<V5S(&ET<R!N871I=F4@4TE&(&9O<FUA
M="!F;W(@9&%T80H@*B!E>&-H86YG92X@0V]N=F5R<VEO;B!T;R!T97AT+W9C
M86QE;F1A<B!E=&,N(&ES(&1O;F4@8GD*("H@4VEF0V]N=F5R=&5R+G!H<"!4
M:&4@8V]N;F5C=&]R('-E96US(&YO="!S=7!P;W)T($1E=DEN9@H@*B!I;F9O
M<FUA=&EO;BP@<V\@4WEN8TU,7T1E=FEC92!C86X@;VYL>2!D971E8W0@:70@
M8GD@=&AE(&1E8VEC92!)1#H*("H@<V\@:6X@=&AE(&-O;FYE8W1O<B!C;VYF
M:6=U<F%T:6]N('1H92!D979I8V4@240@;75S="!B92!S970@=&\*("H@)W-C
M+7!I;2T\='EP93XG('=H:6-H('-H;W5L9"!B92!T:&4@9&5F875L="!A;GEH
M;W<N"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@2V%R<W1E;B!&;W5R;6]N
M="`\:V%R<W1E;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]3>6YC34PO4WEN8TU,+T1E=FEC92]3>6YC-&HN<&AP
M+'8@,2XX+C(N-"`R,#`V+S`Q+S`Q(#(Q.C(X.C,W(&IA;B!%>'`@)`H@*@H@
M*B!`875T:&]R("!+87)S=&5N($9O=7)M;VYT(#QK87)S=&5N0&AO<F1E+F]R
M9SX*("H@0'!A8VMA9V4@4WEN8TU,"B`J+PIC;&%S<R!3>6YC34Q?1&5V:6-E
M7W-Y;F,T:B!E>'1E;F1S(%-Y;F--3%]$979I8V4@>PH*("`@("\J*@H@("`@
M("H@0V]N=F5R="!T:&4@8V]N=&5N="X*("`@("`J"B`@("`@*B!#=7)R96YT
M;'D@<W1R:7!S('5I9"`H<')I;6%R>2!K97DI(&EN9F]R;6%T:6]N(&%S(&-L
M:65N="!A;F0*("`@("`J('-E<G9E<B!M:6=H="!U<V4@9&EF9F5R96YT(&]N
M97,N"B`@("`@*@H@("`@("H@0VAA<G-E="!C;VYV97)S:6]N<R!M:6=H="!B
M92!A9&1E9"!H97)E('1O;RX*("`@("`J+PH@("`@9G5N8W1I;VX@8V]N=F5R
M=$-L:65N=#)397)V97(H)&-O;G1E;G0L("1C;VYT96YT5'EP92D*("`@('L*
M("`@("`@("!L:7-T*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I(#T*("`@("`@
M("`@("`@<&%R96YT.CIC;VYV97)T0VQI96YT,E-E<G9E<B@D8V]N=&5N="P@
M)&-O;G1E;G14>7!E*3L*"B`@("`@("`@<W=I=&-H("@D8V]N=&5N=%1Y<&4I
M('L*("`@("`@("!C87-E("=S:68O;F]T92<@.@H@("`@("`@(&-A<V4@)W1E
M>'0O>"US-&HM<VEF;B<@.@H@("`@("`@("`@("`D8V]N=&5N="`]("1T:&ES
M+3YS:68R=FYO=&4H8F%S938T7V1E8V]D92@D8V]N=&5N="DI.PH@("`@("`@
M("`@("`D8V]N=&5N=%1Y<&4@/2`G=&5X="]X+79N;W1E)SL*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&-A<V4@)W-I9B]C;VYT86-T)R`Z"B`@("`@
M("`@8V%S92`G=&5X="]X+7,T:BUS:69C)R`Z"B`@("`@("`@("`@("1C;VYT
M96YT(#T@)'1H:7,M/G-I9C)V8V%R9"AB87-E-C1?9&5C;V1E*"1C;VYT96YT
M*2D["B`@("`@("`@("`@("1C;VYT96YT5'EP92`]("=T97AT+W@M=F-A<F0G
M.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G<VEF+V-A;&5N
M9&%R)R`Z"B`@("`@("`@8V%S92`G=&5X="]X+7,T:BUS:69E)R`Z"B`@("`@
M("`@("`@("1C;VYT96YT(#T@)'1H:7,M/G-I9C)V979E;G0H8F%S938T7V1E
M8V]D92@D8V]N=&5N="DI.PH@("`@("`@("`@("`D8V]N=&5N=%1Y<&4@/2`G
M=&5X="]X+79E=F5N="<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C
M87-E("=S:68O=&%S:R<@.@H@("`@("`@(&-A<V4@)W1E>'0O>"US-&HM<VEF
M="<@.@H@("`@("`@("`@("`D8V]N=&5N="`]("1T:&ES+3YS:68R=G1O9&\H
M8F%S938T7V1E8V]D92@D8V]N=&5N="DI.PH@("`@("`@("`@("`D8V]N=&5N
M=%1Y<&4@/2`G=&5X="]X+79T;V1O)SL*("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@?0H*("`@("`@("!I9B`H1$5"54=,3T=?24-!3$5.1$%21$%402D@
M>PH@("`@("`@("`@("`D9G`@/2!`9F]P96XH)R]T;7`O<WEN8R]L;V<N='AT
M)RP@)V$G*3L*("`@("`@("`@("`@:68@*"1F<"D@>PH@("`@("`@("`@("`@
M("`@0&9W<FET92@D9G`L(")<;FEN<'5T(&-O;G9E<G1E9"!F;W(@<V5R=F5R
M.B`D8V]N=&5N=%1Y<&5<;B(I.PH@("`@("`@("`@("`@("`@0&9W<FET92@D
M9G`L)&-O;G1E;G0@+B`B7&XB*3L*("`@("`@("`@("`@("`@($!F8VQO<V4H
M)&9P*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M(&%R<F%Y*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0V]N=F5R=',@=&AE(&-O;G1E;G0@9G)O;2!T:&4@8F%C:V5N
M9"!T;R!A(&9O<FUA="!S=6ET86)L92!F;W(@=&AE"B`@("`@*B!C;&EE;G0@
M9&5V:6-E+@H@("`@("H*("`@("`J(%-T<FEP<R!T:&4@=6ED("AP<FEM87)Y
M(&ME>2D@:6YF;W)M871I;VX@87,@8VQI96YT(&%N9"!S97)V97(@;6EG:'0@
M=7-E"B`@("`@*B!D:69F97)E;G0@;VYE<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1C;VYT96YT("`@("`@(%1H92!C;VYT96YT('1O(&-O;G9E
M<G0*("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E;G14>7!E("`@5&AE(&-O
M;G1E;G14>7!E(&]F(&-O;G1E;G0@87,@<F5T=7)N960@9G)O;0H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@8F%C:V5N9`H@("`@
M("H@0')E='5R;B!A<G)A>2`@("`@("`@("`@("`@("!A<G)A>2@D;F5W8V]N
M=&5N="P@)&YE=V-O;G1E;G14>7!E*3H*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=&AE(&-O;G9E<G1E9"!C;VYT96YT(&%N9"!T:&4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*'!O<W-I8FQY
M(&-H86YG960I(&YE=R!#;VYT96YT5'EP92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@8V]N=F5R=%-E<G9E<C)#;&EE;G0H)&-O;G1E;G0L("1C;VYT96YT5'EP
M92D*("`@('L*("`@("`@("!G;&]B86P@)&)A8VME;F0["@H@("`@("`@(&QI
M<W0H)&-O;G1E;G0L("1C;VYT96YT5'EP92D@/0H@("`@("`@("`@("!P87)E
M;G0Z.F-O;G9E<G1397)V97(R0VQI96YT*"1C;VYT96YT+"`D8V]N=&5N=%1Y
M<&4I.PH*("`@("`@("!S=VET8V@@*"1C;VYT96YT5'EP92D@>PH@("`@("`@
M(&-A<V4@)W1E>'0O8V%L96YD87(G(#H*("`@("`@("!C87-E("=T97AT+W@M
M:6-A;&5N9&%R)R`Z"B`@("`@("`@8V%S92`G=&5X="]X+79C86QE;F1A<B<@
M.@H@("`@("`@(&-A<V4@)W1E>'0O>"UV979E;G0G(#H*("`@("`@("`@("`@
M)&-O;G1E;G0@/2`D=&AI<RT^=F5V96YT,G-I9B@D8V]N=&5N="D["B`@("`@
M("`@("`@("1C;VYT96YT(#T@8F%S938T7V5N8V]D92@D8V]N=&5N="D["B`@
M("`@("`@("`@("1C;VYT96YT5'EP92`]("=S:68O8V%L96YD87(G.PH@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G=&5X="]X+79T;V1O)R`Z
M"B`@("`@("`@("`@("1C;VYT96YT(#T@)'1H:7,M/G9T;V1O,G-I9B@D8V]N
M=&5N="D["B`@("`@("`@("`@("1C;VYT96YT(#T@8F%S938T7V5N8V]D92@D
M8V]N=&5N="D["B`@("`@("`@("`@("1C;VYT96YT5'EP92`]("=S:68O=&%S
M:R<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=T97AT+W@M
M=F-A<F0G(#H*("`@("`@("`@("`@)&-O;G1E;G0@/2`D=&AI<RT^=F-A<F0R
M<VEF*"1C;VYT96YT*3L*("`@("`@("`@("`@)&-O;G1E;G0@/2!B87-E-C1?
M96YC;V1E*"1C;VYT96YT*3L*("`@("`@("`@("`@)&-O;G1E;G14>7!E(#T@
M)W-I9B]C;VYT86-T)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@)W1E>'0O>"UV;F]T92<Z"B`@("`@("`@("`@("1C;VYT96YT(#T@)'1H
M:7,M/G9N;W1E,G-I9B@D8V]N=&5N="D["B`@("`@("`@("`@("1C;VYT96YT
M(#T@8F%S938T7V5N8V]D92@D8V]N=&5N="D["B`@("`@("`@("`@("1C;VYT
M96YT5'EP92`]("=S:68O;F]T92<["B`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@('T*"B`@("`@("`@:68@*$1%0E5'3$]'7TE#04Q%3D1!4D1!5$$I('L*
M("`@("`@("`@("`@)&9P(#T@0&9O<&5N*"<O=&UP+W-Y;F,O;&]G+G1X="<L
M("=A)RD["B`@("`@("`@("`@(&EF("@D9G`I('L*("`@("`@("`@("`@("`@
M($!F=W)I=&4H)&9P+"!S97)I86QI>F4H)&-O;G1E;G14>7!E*2D["B`@("`@
M("`@("`@("`@("!`9G=R:71E*"1F<"P@(EQN8V]N=F5R=&5D(&9O<B!S>6YC
M-&H@8VQI96YT.B`D8V]N=&5N=%1Y<&5<;B(I.PH@("`@("`@("`@("`@("`@
M0&9W<FET92@D9G`L(&)A<V4V-%]D96-O9&4H)&-O;G1E;G0I("X@(EQN(BD[
M"B`@("`@("`@("`@("`@("!`9F-L;W-E*"1F<"D["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>2@D8V]N=&5N="P@)&-O
M;G1E;G14>7!E*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E8V]D97,@82!S
M:68@>&UL('-T<FEN9R!T;R!A;B!A<W-O8VEA=&EV92!A<G)A>2X*("`@("`J
M"B`@("`@*B!1=6EC:R!H86-K('1O(&-O;G9E<G0@9G)O;2!T97AT+W9C87)D
M(&%N9"!T97AT+W9C86QE;F1A<B!T;PH@("`@("H@4WEN8S1*)W,@<')O<')I
M971E<GD@<VEF(&1A=&%T>7!E<R!A;F0@=FEC92!V97)S82X@($9O<B!D971A
M:6QS"B`@("`@*B!A8F]U="!T:&4@<VEF(&9O<FUA="!S964@=&AE(&%P<&5N
M9&EX(&]F('1H92!D979E;&]P97(@9W5I9&4@;VX*("`@("`J('=W=RYS>6YC
M-&HN;W)G+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'-I9B`@02!S:68@<W1R:6YG(&QI:V4@
M/&LQ/G8Q)F=T.SPO:S$^/&LR/G8R/"]K,CX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!!<W-O8R!A<G)A>2!I;B!U=&8X(&QI:V4@87)R87D@*"=K
M,2<@/3X@)W8Q/B<L("=K,B<@/3X@)W8R)RD["B`@("`@*B\*("`@(&9U;F-T
M:6]N('-I9C)A<G)A>2@D<VEF*0H@("`@>PH@("`@("`@("1R(#T@87)R87DH
M*3L*("`@("`@("!I9B`H<')E9U]M871C:%]A;&PH)R\\*%M>/ETJ*3XH6UX\
M72HI/%PO7#$^+W-I)RP@)'-I9BP@)&UA=&-H97,L(%!214=?4T547T]21$52
M*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D;6%T8VAE<R!A<R`D;6%T8V@I
M('L*("`@("`@("`@("`@("`@("1R6R1M871C:%LQ75T@/2!H=&UL7V5N=&ET
M>5]D96-O9&4H)&UA=&-H6S)=*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("!R971U<FX@)'(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%;F-O
M9&5S(&%N(&%S<V]C+B!A<G)A>2!T;R!S:68@>&UL"B`@("`@*@H@("`@("H@
M475I8VL@:&%C:R!T;R!C;VYV97)T(&9R;VT@=&5X="]V8V%R9"!A;F0@=&5X
M="]V8V%L96YD87(@=&\*("`@("`J(%-Y;F,T2B=S('!R;W!R:65T97)Y('-I
M9B!D871A='EP97,@86YD('9I8V4@=F5R<V$N("!&;W(@9&5T86EL<PH@("`@
M("H@86)O=70@=&AE('-I9B!F;W)M870@<V5E('1H92!A<'!E;F1I>"!O9B!T
M:&4@9&5V96QO<&5R(&=U:61E(&]N"B`@("`@*B!W=W<N<WEN8S1J+F]R9RX*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)&%R<F%Y("!!;B!A<W-O8R!A<G)A>2X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E<W5L=&EN9R!834P@<W1R:6YG
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!A<G)A>3)S:68H)&%R<F%Y+"`D<')E
M/2<G+"`D<&]S=#TG)RD*("`@('L*("`@("`@("`D<V5A<F-H(#T@87)R87DH
M)SPG+"`G/B<I.PH@("`@("`@("1R97!L86-E(#T@87)R87DH)R9L=#LG+"`G
M)F=T.R<I.PH*("`@("`@("`D<B`]("1P<F4["B`@("`@("`@9F]R96%C:"`H
M)&%R<F%Y(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1R("X]
M("<\)R`N("1K97D@+B`G/B<@+@H@("`@("`@("`@("`@("`@<W1R7W)E<&QA
M8V4H)'-E87)C:"P@)')E<&QA8V4L("1V86QU92D@+@H@("`@("`@("`@("`@
M("`@)SPO)R`N("1K97D@+B`G/B<["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'(@+B`D<&]S=#L*("`@('T*"B`@("!F=6YC=&EO;B!S:68R=FYO=&4H
M)'-I9BD*("`@('L*("`@("`@("`D82`]("1T:&ES+3YS:68R87)R87DH)'-I
M9BD["@H@("`@("`@("1I0V%L(#T@)FYE=R!(;W)D95]I0V%L96YD87(H*3L*
M("`@("`@("`D:4-A;"T^<V5T071T<FEB=71E*"=615)324].)RP@)S$N,2<I
M.PH@("`@("`@("1I0V%L+3YS971!='1R:6)U=&4H)U!23T1)1"<L("<M+R]4
M:&4@2&]R9&4@4')O:F5C="\O36YE;6\@+R]%3B<I.PH@("`@("`@("1I0V%L
M+3YS971!='1R:6)U=&4H)TU%5$A/1"<L("=054),25-()RD["@H@("`@("`@
M("1V;F]T92`]("9(;W)D95]I0V%L96YD87(Z.FYE=T-O;7!O;F5N="@G=FYO
M=&4G+"`D:4-A;"D["B`@("`@("`@)'9N;W1E+3YS971!='1R:6)U=&4H)T)/
M1%DG+"!I<W-E="@D85LG0F]D>2==*2`_("1A6R=";V1Y)UT@.B`G)RD["@H@
M("`@("`@(')E='5R;B`D=FYO=&4M/F5X<&]R='9#86QE;F1A<B@I.PH@("`@
M?0H*("`@(&9U;F-T:6]N('-I9C)V8V%R9"@D<VEF*0H@("`@>PH@("`@("`@
M("1A(#T@)'1H:7,M/G-I9C)A<G)A>2@D<VEF*3L*"B`@("`@("`@)&E#86P@
M/2`F;F5W($AO<F1E7VE#86QE;F1A<B@I.PH@("`@("`@("1I0V%L+3YS971!
M='1R:6)U=&4H)U9%4E-)3TXG+"`G,BXQ)RD["B`@("`@("`@)&E#86PM/G-E
M=$%T=')I8G5T92@G4%)/1$E$)RP@)RTO+U1H92!(;W)D92!0<F]J96-T+R]-
M;F5M;R`O+T5.)RD["B`@("`@("`@)&E#86PM/G-E=$%T=')I8G5T92@G3454
M2$]$)RP@)U!50DQ)4T@G*3L*"B`@("`@("`@)'9C87)D(#T@)DAO<F1E7VE#
M86QE;F1A<CHZ;F5W0V]M<&]N96YT*"=V8V%R9"<L("1I0V%L*3L*"B`@("`@
M("`@)'9C87)D+3YS971!='1R:6)U=&4H)T9.)RP@)&%;)T9I;&5!<R==*3L*
M("`@("`@("`D=F-A<F0M/G-E=$%T=')I8G5T92@G3DE#2TY!344G+"`D85LG
M3FEC:TYA;64G72D["B`@("`@("`@)'9C87)D+3YS971!='1R:6)U=&4H)U1%
M3"<L("1A6R=(;VUE5&5L97!H;VYE3G5M8F5R)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)U194$4G/3XG2$]-12<I*3L*("`@("`@
M("`D=F-A<F0M/G-E=$%T=')I8G5T92@G5$5,)RP@)&%;)T)U<VEN97-S5&5L
M97!H;VYE3G5M8F5R)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)U194$4G/3XG5T]22R<I*3L*("`@("`@("`D=F-A<F0M/G-E=$%T
M=')I8G5T92@G5$5,)RP@)&%;)TUO8FEL951E;&5P:&]N94YU;6)E<B==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=465!%)ST^)T-%
M3$PG*2D["B`@("`@("`@)'9C87)D+3YS971!='1R:6)U=&4H)U1%3"<L("1A
M6R="=7-I;F5S<T9A>$YU;6)E<B==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=465!%)ST^)T9!6"<I*3L*("`@("`@("`D=F-A<F0M
M/G-E=$%T=')I8G5T92@G14U!24PG+"`D85LG16UA:6PQ061D<F5S<R==*3L*
M("`@("`@("`D=F-A<F0M/G-E=$%T=')I8G5T92@G5$E43$4G+"`D85LG2F]B
M5&ET;&4G72D["B`@("`@("`@)'9C87)D+3YS971!='1R:6)U=&4H)T]21R<L
M("1A6R=#;VUP86YY3F%M92==*3L*("`@("`@("`D=F-A<F0M/G-E=$%T=')I
M8G5T92@G3D]412<L("1A6R=";V1Y)UTI.PH@("`@("`@("1V8V%R9"T^<V5T
M071T<FEB=71E*"=54DPG+"`D85LG5V5B4&%G92==*3L*"B`@("`@("`@)'8@
M/2!A<G)A>2@*("`@("`@("`@("`@5D-!4D1?3E]&04U)3%D@("`@("`]/B`D
M85LG3&%S=$YA;64G72P*("`@("`@("`@("`@5D-!4D1?3E]'259%3B`@("`@
M("`]/B`D85LG1FER<W1.86UE)UTL"B`@("`@("`@("`@(%9#05)$7TY?041$
M3"`@("`@("`@/3X@)&%;)TUI9&1L94YA;64G72P*("`@("`@("`@("`@5D-!
M4D1?3E]04D5&25@@("`@("`]/B`D85LG5&ET;&4G72P*("`@("`@("`@("`@
M5D-!4D1?3E]3549&25@@("`@("`]/B`D85LG4W5F9FEX)UT*("`@("`@("`I
M.PH@("`@("`@("1V8V%R9"T^<V5T071T<FEB=71E*"=.)RP@:6UP;&]D92@G
M.R<L("1V*2P@87)R87DH*2P@9F%L<V4L("1V*3L*"B`@("`@("`@)'8@/2!A
M<G)A>2@*("`@("`@("`@("`@5D-!4D1?04127U!/0B`@("`@("`@("`@/3X@
M)&%;)TAO;65!9&1R97-S4&]S=$]F9FEC94)O>"==+`H@("`@("`@("`@("!6
M0T%21%]!1%)?15A414Y$("`@("`@("`]/B`G)RP*("`@("`@("`@("`@5D-!
M4D1?04127U-44D5%5"`@("`@("`@/3X@)&%;)TAO;65!9&1R97-S4W1R965T
M)UTL"B`@("`@("`@("`@(%9#05)$7T%$4E],3T-!3$E462`@("`@(#T^("1A
M6R=(;VUE061D<F5S<T-I='DG72P*("`@("`@("`@("`@5D-!4D1?04127U)%
M1TE/3B`@("`@("`@/3X@)&%;)TAO;65!9&1R97-S4W1A=&4G72P*("`@("`@
M("`@("`@5D-!4D1?04127U!/4U1#3T1%("`@("`@/3X@)&%;)TAO;65!9&1R
M97-S4&]S=&%L0V]D92==+`H@("`@("`@("`@("!60T%21%]!1%)?0T]53E12
M62`@("`@("`]/B`D85LG2&]M94%D9')E<W-#;W5N=')Y)UTL"B`@("`@("`@
M*3L*("`@("`@("`D=F-A<F0M/G-E=$%T=')I8G5T92@G0412)RP@:6UP;&]D
M92@G.R<L("1V*2P@87)R87DH)U194$4G(#T^("=(3TU%)R`I+"!T<G5E+"`D
M=BD["@H@("`@("`@("1V(#T@87)R87DH"B`@("`@("`@("`@(%9#05)$7T%$
M4E]03T(@("`@("`@("`@(#T^("1A6R="=7-I;F5S<T%D9')E<W-0;W-T3V9F
M:6-E0F]X)UTL"B`@("`@("`@("`@(%9#05)$7T%$4E]%6%1%3D0@("`@("`@
M(#T^("<G+`H@("`@("`@("`@("!60T%21%]!1%)?4U121454("`@("`@("`]
M/B`D85LG0G5S:6YE<W-!9&1R97-S4W1R965T)UTL"B`@("`@("`@("`@(%9#
M05)$7T%$4E],3T-!3$E462`@("`@(#T^("1A6R="=7-I;F5S<T%D9')E<W-#
M:71Y)UTL"B`@("`@("`@("`@(%9#05)$7T%$4E]214=)3TX@("`@("`@(#T^
M("1A6R="=7-I;F5S<T%D9')E<W-3=&%T92==+`H@("`@("`@("`@("!60T%2
M1%]!1%)?4$]35$-/1$4@("`@("`]/B`D85LG0G5S:6YE<W-!9&1R97-S4&]S
M=&%L0V]D92==+`H@("`@("`@("`@("!60T%21%]!1%)?0T]53E1262`@("`@
M("`]/B`D85LG0G5S:6YE<W-!9&1R97-S0V]U;G1R>2==+`H@("`@("`@("D[
M"@H@("`@("`@("1V8V%R9"T^<V5T071T<FEB=71E*"=!1%(G+"!I;7!L;V1E
M*"<[)RP@)'8I+"!A<G)A>2@G5%E012<@/3X@)U=/4DLG("DL('1R=64L("1V
M*3L*"B`@("`@("`@<F5T=7)N("1V8V%R9"T^97AP;W)T=D-A;&5N9&%R*"D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@<VEF,G9E=F5N="@D<VEF*0H@("`@>PH@
M("`@("`@("1A(#T@)'1H:7,M/G-I9C)A<G)A>2@D<VEF*3L*"B`@("`@("`@
M)&E#86P@/2`F;F5W($AO<F1E7VE#86QE;F1A<B@I.PH@("`@("`@("1I0V%L
M+3YS971!='1R:6)U=&4H)U9%4E-)3TXG+"`G,2XP)RD["B`@("`@("`@)&E#
M86PM/G-E=$%T=')I8G5T92@G4%)/1$E$)RP@)RTO+U1H92!(;W)D92!0<F]J
M96-T+R]-;F5M;R`O+T5.)RD["B`@("`@("`@)&E#86PM/G-E=$%T=')I8G5T
M92@G34542$]$)RP@)U!50DQ)4T@G*3L*"B`@("`@("`@)'9%=F5N="`]("9(
M;W)D95]I0V%L96YD87(Z.FYE=T-O;7!O;F5N="@G=F5V96YT)RP@)&E#86PI
M.PH*("`@("`@("!I9B`H)&%;)T%L;$1A>45V96YT)UT@/3T@)U1R=64G*2![
M"B`@("`@("`@("`@("1T(#T@)&E#86PM/E]P87)S941A=&54:6UE*"1A6R=3
M=&%R="==*3L*("`@("`@("`@("`@)'9%=F5N="T^<V5T071T<FEB=71E*"=$
M5%-405)4)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=Y96%R)R`]/B!D871E*"=9)RP@)'0I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)VUO;G1H)R`]/B!D871E*"=M)RP@
M)'0I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VUD87DG(#T^(&1A=&4H)V0G+"1T*2DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2@G5D%,544G(#T^("=$051%)RDI.PH@("`@
M("`@("`@("`D="`]("1I0V%L+3Y?<&%R<V5$871E5&EM92@D85LG16YD)UTI
M.PH@("`@("`@("`@("`D=D5V96YT+3YS971!='1R:6)U=&4H)T1414Y$)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=Y96%R
M)R`]/B!D871E*"=9)RP@)'0I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VUO;G1H)R`]/B!D871E*"=M)RP@)'0I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUD87DG(#T^
M(&1A=&4H)V0G+"1T*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@G5D%,544G(#T^("=$051%)RDI.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1V179E;G0M/G-E=$%T=')I8G5T92@G1%135$%2
M5"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:4-A;"T^
M7W!A<G-E1&%T951I;64H)&%;)U-T87)T)UTI*3L*("`@("`@("`@("`@)'9%
M=F5N="T^<V5T071T<FEB=71E*"=$5$5.1"<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D:4-A;"T^7W!A<G-E1&%T951I;64H)&%;)T5N
M9"==*2D["B`@("`@("`@?0H*("`@("`@("`D=D5V96YT+3YS971!='1R:6)U
M=&4H)T144U1!35`G+"!T:6UE*"DI.PH@("`@("`@("1V179E;G0M/G-E=$%T
M=')I8G5T92@G4U5-34%262<L("1A6R=3=6)J96-T)UTI.PH@("`@("`@("1V
M179E;G0M/G-E=$%T=')I8G5T92@G1$530U))4%1)3TXG+"`D85LG0F]D>2==
M*3L*("`@("`@("`O+R`D=D5V96YT+3YS971!='1R:6)U=&4H)T-!5$5'3U))
M15,G+"`D85LG)UTI.PH@("`@("`@("1V179E;G0M/G-E=$%T=')I8G5T92@G
M3$]#051)3TXG+"`D85LG3&]C871I;VXG72D["@H@("`@("`@(')E='5R;B`D
M=D5V96YT+3YE>'!O<G1V0V%L96YD87(H*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!S:68R=G1O9&\H)'-I9BD*("`@('L*("`@("`@("`D82`]("1T:&ES+3YS
M:68R87)R87DH)'-I9BD["@H@("`@("`@("1I0V%L(#T@)FYE=R!(;W)D95]I
M0V%L96YD87(H*3L*("`@("`@("`D:4-A;"T^<V5T071T<FEB=71E*"=615)3
M24].)RP@)S$N,"<I.PH@("`@("`@("1I0V%L+3YS971!='1R:6)U=&4H)U!2
M3T1)1"<L("<M+R]4:&4@2&]R9&4@4')O:F5C="\O36YE;6\@+R]%3B<I.PH@
M("`@("`@("1I0V%L+3YS971!='1R:6)U=&4H)TU%5$A/1"<L("=054),25-(
M)RD["@H@("`@("`@("1V=&]D;R`]("9(;W)D95]I0V%L96YD87(Z.FYE=T-O
M;7!O;F5N="@G=G1O9&\G+"`D:4-A;"D["@H@("`@("`@("1V=&]D;RT^<V5T
M071T<FEB=71E*"=354U-05)9)RP@)&%;)U-U8FIE8W0G72D["B`@("`@("`@
M)'9T;V1O+3YS971!='1R:6)U=&4H)T1%4T-225!424].)RP@)&%;)T)O9'DG
M72D["B`@("`@("`@:68@*"1A6R=);7!O<G1A;F-E)UT@/3T@,"D@>PH@("`@
M("`@("`@("`D=G1O9&\M/G-E=$%T=')I8G5T92@G4%))3U))5%DG+"`U*3L*
M("`@("`@("!](&5L<V5I9B`H)&%;)TEM<&]R=&%N8V4G72`]/2`R*2!["B`@
M("`@("`@("`@("1V=&]D;RT^<V5T071T<FEB=71E*"=04DE/4DE462<L(#$I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1V=&]D;RT^<V5T071T
M<FEB=71E*"=04DE/4DE462<L(#,I.PH@("`@("`@('T*("`@("`@("!I9B`H
M)&%;)T1U941A=&4G72`A/2`G-#4P,#$R,S%4,C,P,#`P6B<I('L*("`@("`@
M("`@("`@)'9T;V1O+3YS971!='1R:6)U=&4H)T1512<L("1I0V%L+3Y?<&%R
M<V5$871E5&EM92@D85LG1'5E1&%T92==*2D["B`@("`@("`@?0H@("`@("`@
M("1V=&]D;RT^<V5T071T<FEB=71E*"=#3TU03$54140G+"`D85LG0V]M<&QE
M=&4G72`]/2`G5')U92<@/R`Q(#H@,"D["@H@("`@("`@(')E='5R;B`D=G1O
M9&\M/F5X<&]R='9#86QE;F1A<B@I.PH@("`@?0H*("`@(&9U;F-T:6]N('9N
M;W1E,G-I9B@D=FYO=&4I"B`@("!["B`@("`@("`@)&E#86P@/2`F;F5W($AO
M<F1E7VE#86QE;F1A<B@I.PH@("`@("`@(&EF("@A)&E#86PM/G!A<G-E=D-A
M;&5N9&%R*"1V;F]T92DI('L*("`@("`@("`@("`@9&EE*")4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!D871A+B(I.PH@("`@("`@('T*"B`@
M("`@("`@)&-O;7!O;F5N=',@/2`D:4-A;"T^9V5T0V]M<&]N96YT<R@I.PH*
M("`@("`@("!S=VET8V@@*&-O=6YT*"1C;VUP;VYE;G1S*2D@>PH@("`@("`@
M(&-A<V4@,#H*("`@("`@("`@("`@9&EE*").;R!D871A('=A<R!F;W5N9"XB
M*3L*"B`@("`@("`@8V%S92`Q.@H@("`@("`@("`@("`D8V]N=&5N="`]("1C
M;VUP;VYE;G1S6S!=.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@9&5F
M875L=#H*("`@("`@("`@("`@9&EE*")-=6QT:7!L92!C;VUP;VYE;G1S(&9O
M=6YD.R!O;FQY(&]N92!I<R!S=7!P;W)T960N(BD["B`@("`@("`@?0H*("`@
M("`@("`D82`](&%R<F%Y*"=";V1Y)R`]/B`D8V]N=&5N="T^9V5T071T<FEB
M=71E*"="3T19)RDI.PH*("`@("`@("!R971U<FX@)'1H:7,M/F%R<F%Y,G-I
M9B@*("`@("`@("`@("`@)&$L"B`@("`@("`@("`@("<\/WAM;"!V97)S:6]N
M/2(Q+C`B/SX\;F]T93XG+`H@("`@("`@("`@("`G/$-A=&5G;W)I97,^/"]#
M871E9V]R:65S/B<*("`@("`@("`@("`@+B`G/%-U8FIE8W0^/"]3=6)J96-T
M/CQ#;VQO<CX\+T-O;&]R/CQ(96EG:'0^/"](96EG:'0^/%=I9'1H/CPO5VED
M=&@^/$QE9G0^/"],969T/CQ4;W`^/"]4;W`^)PH@("`@("`@("`@("`N("<\
M+VYO=&4^)RD["B`@("!]"@H@("`@9G5N8W1I;VX@=F-A<F0R<VEF*"1V8V%R
M9"D*("`@('L*("`@("`@("`D:4-A;"`]("9N97<@2&]R9&5?:4-A;&5N9&%R
M*"D["B`@("`@("`@:68@*"$D:4-A;"T^<&%R<V5V0V%L96YD87(H)'9C87)D
M*2D@>PH@("`@("`@("`@("!D:64H(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@=&AE(&1A=&$N(BD["B`@("`@("`@?0H*("`@("`@("`D8V]M<&]N
M96YT<R`]("1I0V%L+3YG971#;VUP;VYE;G1S*"D["@H@("`@("`@('-W:71C
M:"`H8V]U;G0H)&-O;7!O;F5N=',I*2!["B`@("`@("`@8V%S92`P.@H@("`@
M("`@("`@("!D:64H(DYO(&1A=&$@=V%S(&9O=6YD+B(I.PH*("`@("`@("!C
M87-E(#$Z"B`@("`@("`@("`@("1C;VYT96YT(#T@)&-O;7!O;F5N='-;,%T[
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@("`@
M("`@("!D:64H(DUU;'1I<&QE(&-O;7!O;F5N=',@9F]U;F0[(&]N;'D@;VYE
M(&ES('-U<'!O<G1E9"XB*3L*("`@("`@("!]"@H@("`@("`@("\O(&9R;VT@
M:&5R92!O;BP@=&AE(&-O9&4@:7,@=&%K96X@9G)O;0H@("`@("`@("\O(%1U
M<F)A7T1R:79E<CHZ=&](87-H+"!V(#$N-C4@,C`P-2\P,R\Q,@H@("`@("`@
M("\O(&%N9"!M;V1I9FEE9"!F;W(@=&AE(%-Y;F,T2B!A='1R:6)U=&4@;F%M
M97,N"B`@("`@("`@)&%T='(@/2`D8V]N=&5N="T^9V5T06QL071T<FEB=71E
M<R@I.PH@("`@("`@(&9O<F5A8V@@*"1A='1R(&%S("1I=&5M*2!["B`@("`@
M("`@("`@('-W:71C:"`H)&ET96U;)VYA;64G72D@>PH@("`@("`@("`@("!C
M87-E("=&3B<Z"B`@("`@("`@("`@("`@("`D:&%S:%LG1FEL94%S)UT@/2`D
M:71E;5LG=F%L=64G73L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@8V%S92`G3B<Z"B`@("`@("`@("`@("`@("`D;F%M92`]("1I=&5M
M6R=V86QU97,G73L*("`@("`@("`@("`@("`@("1H87-H6R=,87-T3F%M92==
M(#T@)&YA;65;5D-!4D1?3E]&04U)3%E=.PH@("`@("`@("`@("`@("`@)&AA
M<VA;)T9I<G-T3F%M92==(#T@)&YA;65;5D-!4D1?3E]'259%3ET["B`@("`@
M("`@("`@("`@("`D:&%S:%LG36ED9&QE3F%M92==(#T@)&YA;65;5D-!4D1?
M3E]!1$1,73L*("`@("`@("`@("`@("`@("1H87-H6R=4:71L92==(#T@)&YA
M;65;5D-!4D1?3E]04D5&25A=.PH@("`@("`@("`@("`@("`@)&AA<VA;)U-U
M9F9I>"==(#T@)&YA;65;5D-!4D1?3E]3549&25A=.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=.24-+3D%-12<Z"B`@("`@
M("`@("`@("`@("`D:&%S:%LG3FEC:TYA;64G72`]("1I=&5M6R=V86QU92==
M.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`O+R!&;W(@
M=D-A<F0@,RXP+@H@("`@("`@("`@("!C87-E("=!1%(G.@H@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1I=&5M6R=P87)A;7,G75LG5%E012==*2D@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&ET96U;)W!A<F%M
M<R==6R=465!%)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1I=&5M
M6R=P87)A;7,G75LG5%E012==(#T@87)R87DH)&ET96U;)W!A<F%M<R==6R=4
M65!%)UTI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&ET96U;)W!A<F%M<R==
M6R=465!%)UT@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D:71E;5LG<&%R86US)UU;)U=/4DLG72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&ET96U;)W!A<F%M<R==6R=465!%)UU;72`]("=73U)+
M)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1I=&5M6R=P87)A;7,G75LG2$]-12==*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D:71E;5LG<&%R86US)UU;)U194$4G75M=(#T@
M)TA/344G.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`D861D<F5S<R`]("1I=&5M6R=V86QU97,G
M73L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1I=&5M6R=P87)A;7,G75LG
M5%E012==(&%S("1A9'(I('L*("`@("`@("`@("`@("`@("`@("!S=VET8V@@
M*%-T<FEN9SHZ=7!P97(H)&%D<BDI('L*("`@("`@("`@("`@("`@("`@("!C
M87-E("=(3TU%)SH*("`@("`@("`@("`@("`@("`@("`@("`@)'!R969I>"`]
M("=(;VUE061D<F5S<R<["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@("`@("`@("!C87-E("=73U)+)SH*("`@("`@("`@
M("`@("`@("`@("`@("`@)'!R969I>"`]("=7;W)K061D<F5S<R<["B`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@("`@
M("!D969A=6QT.@H@("`@("`@("`@("`@("`@("`@("`@("`D<')E9FEX(#T@
M)TAO;65!9&1R97-S)SL*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@("`@(&EF("@D<')E9FEX*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1H87-H6R1P<F5F:7@@+B`G4W1R965T)UT@/2!I<W-E="@D861D
M<F5S<UM60T%21%]!1%)?4U12145472D@/R`D861D<F5S<UM60T%21%]!1%)?
M4U12145472`Z(&YU;&P["B`@("`@("`@("`@("`@("`@("`@("`@("1H87-H
M6R1P<F5F:7@@+B`G0VET>2==(#T@:7-S970H)&%D9')E<W-;5D-!4D1?0412
M7TQ/0T%,251972D@/R`D861D<F5S<UM60T%21%]!1%)?3$]#04Q)5%E=(#H@
M;G5L;#L*("`@("`@("`@("`@("`@("`@("`@("`@)&AA<VA;)'!R969I>"`N
M("=3=&%T92==(#T@:7-S970H)&%D9')E<W-;5D-!4D1?04127U)%1TE/3ETI
M(#\@)&%D9')E<W-;5D-!4D1?04127U)%1TE/3ET@.B!N=6QL.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D:&%S:%LD<')E9FEX("X@)U!O<W1A;$-O9&4G
M72`](&ES<V5T*"1A9&1R97-S6U9#05)$7T%$4E]03U-40T]$15TI(#\@)&%D
M9')E<W-;5D-!4D1?04127U!/4U1#3T1%72`Z(&YU;&P["B`@("`@("`@("`@
M("`@("`@("`@("`@("1H87-H6R1P<F5F:7@@+B`G0V]U;G1R>2==(#T@:7-S
M970H)&%D9')E<W-;5D-!4D1?04127T-/54Y44EE=*2`_("1A9&1R97-S6U9#
M05)$7T%$4E]#3U5.5%)972`Z(&YU;&P["B`@("`@("`@("`@("`@("`@("`@
M("`@("1H87-H6R1P<F5F:7@@+B`G4&]S=$]F9FEC94)O>"==(#T@:7-S970H
M)&%D9')E<W-;5D-!4D1?04127U!/0ETI(#\@)&%D9')E<W-;5D-!4D1?0412
M7U!/0ET@.B!N=6QL.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M8V%S92`G5$5,)SH*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:71E;5LG
M<&%R86US)UU;)T9!6"==*2D@>PH@("`@("`@("`@("`@("`@("`@("1H87-H
M6R="=7-I;F5S<T9A>$YU;6)E<B==(#T@)&ET96U;)W9A;'5E)UT["B`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)&ET96U;)W!A<F%M<R==6R=4
M65!%)UTI*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D
M:71E;5LG<&%R86US)UU;)U194$4G72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&ET96U;)W!A<F%M<R==6R=465!%)UT@/2!A<G)A>2@D:71E;5LG
M<&%R86US)UU;)U194$4G72D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("\O($9O<B!V0V%R9"`S+C`N"B`@("`@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&ET96U;)W!A<F%M<R==6R=465!%)UT@87,@
M)'1E;"D@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H4W1R:6YG.CIU
M<'!E<B@D=&5L*2`]/2`G5T]22R<I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1H87-H6R="=7-I;F5S<U1E;&5P:&]N94YU;6)E<B==(#T@)&ET
M96U;)W9A;'5E)UT["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF
M("A3=')I;F<Z.G5P<&5R*"1T96PI(#T]("=(3TU%)RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&AA<VA;)TAO;65496QE<&AO;F5.=6UB97(G
M72`]("1I=&5M6R=V86QU92==.PH@("`@("`@("`@("`@("`@("`@("`@("!]
M(&5L<V5I9B`H4W1R:6YG.CIU<'!E<B@D=&5L*2`]/2`G0T5,3"<I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1H87-H6R=-;V)I;&5496QE<&AO
M;F5.=6UB97(G72`]("1I=&5M6R=V86QU92==.PH@("`@("`@("`@("`@("`@
M("`@("`@("!](&5L<V5I9B`H4W1R:6YG.CIU<'!E<B@D=&5L*2`]/2`G1D%8
M)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&AA<VA;)T)U<VEN
M97-S1F%X3G5M8F5R)UT@/2`D:71E;5LG=F%L=64G73L*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1I=&5M6R=P87)A;7,G75LG2$]-12==*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D:&%S:%LG2&]M951E;&5P:&]N94YU;6)E<B==(#T@)&ET96U;
M)W9A;'5E)UT["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T
M*"1I=&5M6R=P87)A;7,G75LG5T]22R==*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D:&%S:%LG0G5S:6YE<W-496QE<&AO;F5.=6UB97(G72`]("1I
M=&5M6R=V86QU92==.PH@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI
M<W-E="@D:71E;5LG<&%R86US)UU;)T-%3$PG72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&AA<VA;)TUO8FEL951E;&5P:&]N94YU;6)E<B==(#T@
M)&ET96U;)W9A;'5E)UT["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&AA<VA;)TAO;65496QE<&AO;F5.
M=6UB97(G72`]("1I=&5M6R=V86QU92==.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@8V%S92`G14U!24PG.@H@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1I=&5M6R=P87)A;7,G75LG4%)%1B==*2!\?"`A:7-S970H)&AA
M<VA;)V5M86EL)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&AA<VA;)T5M
M86EL,4%D9')E<W,G72`]($AO<F1E7VE#86QE;F1A<E]V8V%R9#HZ9V5T0F%R
M945M86EL*"1I=&5M6R=V86QU92==*3L*("`@("`@("`@("`@("`@("`@("`D
M:&%S:%LG16UA:6PQ061D<F5S<U1Y<&4G72`]("=33510)SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M8V%S92`G5$E43$4G.@H@("`@("`@("`@("`@("`@)&AA<VA;)TIO8E1I=&QE
M)UT@/2`D:71E;5LG=F%L=64G73L*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@8V%S92`G3U)')SH*("`@("`@("`@("`@("`@("1H87-H
M6R=#;VUP86YY3F%M92==(#T@)&ET96U;)W9A;'5E)UT["B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)TY/5$4G.@H@("`@("`@
M("`@("`@("`@)&AA<VA;)T)O9'DG72`]("1I=&5M6R=V86QU92==.PH@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=54DPG.@H@
M("`@("`@("`@("`@("`@)&AA<VA;)U=E8E!A9V4G72`]("1I=&5M6R=V86QU
M92==.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^87)R87DR<VEF*`H@("`@
M("`@("`@("`D:&%S:"P*("`@("`@("`@("`@)SP_>&UL('9E<G-I;VX](C$N
M,"(_/CQC;VYT86-T/B<L"B`@("`@("`@("`@("<\+V-O;G1A8W0^)RD["B`@
M("!]"@H@("`@9G5N8W1I;VX@=F5V96YT,G-I9B@D=F-A<F0I"B`@("!["B`@
M("`@("`@)&E#86P@/2`F;F5W($AO<F1E7VE#86QE;F1A<B@I.PH@("`@("`@
M(&EF("@A)&E#86PM/G!A<G-E=D-A;&5N9&%R*"1V8V%R9"DI('L*("`@("`@
M("`@("`@9&EE*")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!D
M871A+B(I.PH@("`@("`@('T*"B`@("`@("`@)&-O;7!O;F5N=',@/2`D:4-A
M;"T^9V5T0V]M<&]N96YT<R@I.PH*("`@("`@("!S=VET8V@@*&-O=6YT*"1C
M;VUP;VYE;G1S*2D@>PH@("`@("`@(&-A<V4@,#H*("`@("`@("`@("`@9&EE
M*").;R!D871A('=A<R!F;W5N9"XB*3L*"B`@("`@("`@8V%S92`Q.@H@("`@
M("`@("`@("`D8V]N=&5N="`]("1C;VUP;VYE;G1S6S!=.PH@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@9&EE*")-
M=6QT:7!L92!C;VUP;VYE;G1S(&9O=6YD.R!O;FQY(&]N92!I<R!S=7!P;W)T
M960N(BD["B`@("`@("`@?0H*("`@("`@("`O+R!)<R!T:&5R92!A(')E86P@
M;F5E9"!T;R!P<F]V:61E('1H92!C;W)R96-T('9A;'5E/PH@("`@("`@("1D
M=7)A=&EO;B`](#`["@H@("`@("`@("1A='1R(#T@)&-O;G1E;G0M/F=E=$%L
M;$%T=')I8G5T97,H*3L*("`@("`@("!F;W)E86-H("@D871T<B!A<R`D:71E
M;2D@>PH@("`@("`@("`@("!S=VET8V@@*"1I=&5M6R=N86UE)UTI('L*("`@
M("`@("`@("`@8V%S92`G1%135$%25"<Z"B`@("`@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1I=&5M6R=P87)A;7,G75LG5D%,544G72D@)B8@)&ET96U;)W!A
M<F%M<R==6R=604Q512==(#T](")$051%(BD@>PH@("`@("`@("`@("`@("`@
M("`@("1H87-H6R=!;&Q$87E%=F5N="==(#T@(E1R=64B.PH@("`@("`@("`@
M("`@("`@("`@("1H87-H6R=3=&%R="==(#T@2&]R9&5?:4-A;&5N9&%R.CI?
M97AP;W)T1&%T951I;64H)&ET96U;)W9A;'5E)UTI.PH@("`@("`@("`@("`@
M("`@("`@("1D=7)A=&EO;B`](#$T-#`["B`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("1H87-H6R=!;&Q$87E%=F5N="==
M(#T@(D9A;'-E(CL*("`@("`@("`@("`@("`@("`@("`D:&%S:%LG4W1A<G0G
M72`]($AO<F1E7VE#86QE;F1A<CHZ7V5X<&]R=$1A=&54:6UE*"1I=&5M6R=V
M86QU92==*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@8V%S92`G1%1%3D0G.@H@("`@("`@("`@("`@
M("`@:68@*"%E;7!T>2@D:71E;5LG<&%R86US)UU;)U9!3%5%)UTI("8F("1I
M=&5M6R=P87)A;7,G75LG5D%,544G72`]/2`B1$%412(I('L*("`@("`@("`@
M("`@("`@("`@("`D:&%S:%LG06QL1&%Y179E;G0G72`](")4<G5E(CL*("`@
M("`@("`@("`@("`@("`@("`D:&%S:%LG16YD)UT@/2!(;W)D95]I0V%L96YD
M87(Z.E]E>'!O<G1$871E5&EM92@D:71E;5LG=F%L=64G72D["B`@("`@("`@
M("`@("`@("`@("`@)&1U<F%T:6]N(#T@,30T,#L*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&AA<VA;)T%L;$1A>45V
M96YT)UT@/2`B1F%L<V4B.PH@("`@("`@("`@("`@("`@("`@("1H87-H6R=%
M;F0G72`]($AO<F1E7VE#86QE;F1A<CHZ7V5X<&]R=$1A=&54:6UE*"1I=&5M
M6R=V86QU92==*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G4U5-34%262<Z"B`@("`@("`@
M("`@("`@("`D:&%S:%LG4W5B:F5C="==(#T@)&ET96U;)W9A;'5E)UT["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)T1%4T-2
M25!424].)SH*("`@("`@("`@("`@("`@("1H87-H6R=";V1Y)UT@/2`D:71E
M;5LG=F%L=64G73L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@8V%S92`G3$]#051)3TXG.@H@("`@("`@("`@("`@("`@)&AA<VA;)TQO
M8V%T:6]N)UT@/2`D:71E;5LG=F%L=64G73L*("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)'1H:7,M/F%R<F%Y,G-I9B@*("`@("`@("`@("`@)&AA<V@L"B`@("`@("`@
M("`@("<\/WAM;"!V97)S:6]N/2(Q+C`B/SX\87!P;VEN=&UE;G0^/$1U<F%T
M:6]N/B<*("`@("`@("`@("`@+B`D9'5R871I;VX@+B`G/"]$=7)A=&EO;CXG
M+`H@("`@("`@("`@("`G/$ES4F5C=7)R:6YG/D9A;'-E/"])<U)E8W5R<FEN
M9SX\365E=&EN9U-T871U<SXP/"]-965T:6YG4W1A='5S/CQ"=7-Y4W1A='5S
M/C(\+T)U<WE3=&%T=7,^/"]A<'!O:6YT;65N=#XG*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!V=&]D;S)S:68H)'9C87)D*0H@("`@>PH@("`@("`@("1I0V%L
M(#T@)FYE=R!(;W)D95]I0V%L96YD87(H*3L*("`@("`@("!I9B`H(21I0V%L
M+3YP87)S979#86QE;F1A<B@D=F-A<F0I*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=4:&5R92!W87,@86X@97)R;W(@:6UP;W)T
M:6YG('1H92!D871A+B<I.PH@("`@("`@('T*"B`@("`@("`@)&-O;7!O;F5N
M=',@/2`D:4-A;"T^9V5T0V]M<&]N96YT<R@I.PH*("`@("`@("!S=VET8V@@
M*&-O=6YT*"1C;VUP;VYE;G1S*2D@>PH@("`@("`@(&-A<V4@,#H*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TYO(&1A=&$@=V%S(&9O
M=6YD)RD["@H@("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@)&-O;G1E;G0@
M/2`D8V]M<&]N96YT<ULP73L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=-=6QT:7!L92!C;VUP;VYE;G1S(&9O=6YD.R!O;FQY(&]N92!I<R!S=7!P
M;W)T960N)RD["B`@("`@("`@?0H*("`@("`@("`D:&%S:%LG0V]M<&QE=&4G
M72`]("=&86QS92<["B`@("`@("`@+R\@3W5T;&]O:R=S(&1E9F%U;'0@9F]R
M(&YO(&1U92!D871E"B`@("`@("`@)&AA<VA;)T1U941A=&4G72`]("<T-3`P
M,3(S,50R,S`P,#!:)SL*"B`@("`@("`@)&%T='(@/2`D8V]N=&5N="T^9V5T
M06QL071T<FEB=71E<R@I.PH@("`@("`@(&9O<F5A8V@@*"1A='1R(&%S("1I
M=&5M*2!["B`@("`@("`@("`@('-W:71C:"`H)&ET96U;)VYA;64G72D@>PH@
M("`@("`@("`@("!C87-E("=$544G.@H@("`@("`@("`@("`@("`@)&AA<VA;
M)T1U941A=&4G72`]($AO<F1E7VE#86QE;F1A<CHZ7V5X<&]R=$1A=&54:6UE
M*"1I=&5M6R=V86QU92==*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`G4U5-34%262<Z"B`@("`@("`@("`@("`@("`D:&%S
M:%LG4W5B:F5C="==(#T@)&ET96U;)W9A;'5E)UT["B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)T1%4T-225!424].)SH*("`@
M("`@("`@("`@("`@("1H87-H6R=";V1Y)UT@/2`D:71E;5LG=F%L=64G73L*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G4%))
M3U))5%DG.@H@("`@("`@("`@("`@("`@:68@*"1I=&5M6R=V86QU92==(#T]
M(#$I('L*("`@("`@("`@("`@("`@("`@("`D:&%S:%LG26UP;W)T86YC92==
M(#T@,CL*("`@("`@("`@("`@("`@('T@96QS96EF("@D:71E;5LG=F%L=64G
M72`]/2`U*2!["B`@("`@("`@("`@("`@("`@("`@)&AA<VA;)TEM<&]R=&%N
M8V4G72`](#`["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1H87-H6R=);7!O<G1A;F-E)UT@/2`Q.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E("=#3TU03$54140G.@H@("`@("`@("`@("`@("`@)&AA<VA;)T-O;7!L
M971E)UT@/2`D:71E;5LG=F%L=64G72`_("=4<G5E)R`Z("=&86QS92<["B`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YA<G)A>3)S:68H"B`@("`@("`@("`@
M("1H87-H+`H@("`@("`@("`@("`G/#]X;6P@=F5R<VEO;CTB,2XP(C\^/'1A
M<VL^)RP*("`@("`@("`@("`@)SPO=&%S:SXG*3L*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O4WEN8TU,+T1E=FEC92]3
M>6YT:&5S:7,N<&AP````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P-C0W
M`#$P-3$U-#,S-S0T`#`R,S4P,@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@5&AE(%-Y;F--3%]$979I
M8V5?4WEN=&AE<VES.CH@8VQA<W,@<')O=FED97,@9G5N8W1I;VYA;&ET>2!T
M:&%T(&ES"B`J('-P96-I9FEC('1O('1H92!3>6YT:&5S:7,N8V@@4WEN8TU,
M(&-L:65N=',N"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@2V%R<W1E;B!&
M;W5R;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]3>6YC34PO4WEN8TU,+T1E=FEC92]3>6YT
M:&5S:7,N<&AP+'8@,2XR+C(N-2`R,#`V+S`U+S`Q(#$R.C`U.C$T(&IA;B!%
M>'`@)`H@*@H@*B!`875T:&]R("!+87)S=&5N($9O=7)M;VYT(#QK87)S=&5N
M0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@4WEN8TU,"B`J+PIC;&%S<R!3>6YC
M34Q?1&5V:6-E7U-Y;G1H97-I<R!E>'1E;F1S(%-Y;F--3%]$979I8V4@>PH*
M("`@("\J*@H@("`@("H@0V]N=F5R=',@=&AE(&-O;G1E;G0@9G)O;2!T:&4@
M8F%C:V5N9"!T;R!A(&9O<FUA="!S=6ET86)L92!F;W(@=&AE"B`@("`@*B!C
M;&EE;G0@9&5V:6-E+@H@("`@("H*("`@("`J(%-T<FEP<R!T:&4@=6ED("AP
M<FEM87)Y(&ME>2D@:6YF;W)M871I;VX@87,@8VQI96YT(&%N9"!S97)V97(@
M;6EG:'0@=7-E"B`@("`@*B!D:69F97)E;G0@;VYE<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1C;VYT96YT("`@("`@(%1H92!C;VYT96YT('1O
M(&-O;G9E<G0*("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E;G14>7!E("`@
M5&AE(&-O;G1E;G14>7!E(&]F(&-O;G1E;G0@87,@<F5T=7)N960@9G)O;0H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@8F%C:V5N
M9`H@("`@("H@0')E='5R;B!A<G)A>2`@("`@("`@("`@("`@("!A<G)A>2@D
M;F5W8V]N=&5N="P@)&YE=V-O;G1E;G14>7!E*3H*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&AE(&-O;G9E<G1E9"!C;VYT96YT(&%N
M9"!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*'!O
M<W-I8FQY(&-H86YG960I(&YE=R!#;VYT96YT5'EP92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@8V]N=F5R=%-E<G9E<C)#;&EE;G0H)&-O;G1E;G0L("1C;VYT
M96YT5'EP92D*("`@('L*("`@("`@("!G;&]B86P@)&)A8VME;F0["@H@("`@
M("`@(&QI<W0H)&-O;G1E;G0L("1C;VYT96YT5'EP92D@/0H@("`@("`@("`@
M("!P87)E;G0Z.F-O;G9E<G1397)V97(R0VQI96YT*"1C;VYT96YT+"`D8V]N
M=&5N=%1Y<&4I.PH*"B`@("`@("`@+R\@4V]M92!S<&5C:6%L('!R:6]R:71Y
M(&AA;F1L:6YG(&ES(')E<75I<F5D+B!3>6YT:&5S:7,@=7-E<PH@("`@("`@
M("\O(#$@*&AI9V@I+"`R("AM961I=6TI+"`S*&QO=RDL(&%T(&QE87-T(&9O
M<B!M>2!W:6YD;W=S(&UO8FEL92!D979I8V4N"B`@("`@("`@+R\@8V]N=F5R
M="!T:&5S92!T;R!V86QI9"!P<FEO<FET>2!S971T:6YG<SH*("`@("`@("`D
M8V]N=&5N="`]('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*5!224]22519
M.ELQ+3)=*%QR7&Y\7')\7&XI+R<L("=<,5!224]22519.C%<,B<L("1C;VYT
M96YT+"`Q*3L*("`@("`@("`D8V]N=&5N="`]('!R96=?<F5P;&%C92@G+RA<
M<EQN?%QR?%QN*5!224]22519.ELS72A<<EQN?%QR?%QN*2\G+"`G7#%04DE/
M4DE463HR7#(G+"`D8V]N=&5N="P@,2D["B`@("`@("`@)&-O;G1E;G0@/2!P
M<F5G7W)E<&QA8V4H)R\H7')<;GQ<<GQ<;BE04DE/4DE463I;-"TY72A<<EQN
M?%QR?%QN*2\G+"`G7#%04DE/4DE463HS7#(G+"`D8V]N=&5N="P@,2D["B`@
M("`@(`H*("`@("`@("`O+R!7:6YD;W=S($UO8FEL92!A;'-O(&5X<&5C=',@
M1%5%($1!5$53(&QI:V4@1%5%.C(P,#8P-#$Y5#`P,#`P,`H@("`@("`@(&EF
M("AP<F5G7VUA=&-H*"<O*%QR7&Y\7')\7&XI1%5%.B@N+BXN+BXN+E0N+BXN
M+BY:*2A<<EQN?%QR?%QN*2\G+`H@("`@("`@("`@("`@("`@)&-O;G1E;G0L
M)&TI*2!["B`@("`@("`@("`@("1M6S)=(#T@)'1H:7,M/E540S),;V-A;$1A
M=&4H)&U;,ETI.PH@("`@("`@("`@("`D8V]N=&5N="`]('!R96=?<F5P;&%C
M92@G+RA<<EQN?%QR?%QN*41513HH+BXN+BXN+BY4+BXN+BXN6BDH7')<;GQ<
M<GQ<;BDO)RP*("`@("`@("`@("`@("`@("=<,41513HG("X@)&U;,ET@+B`G
M7#,G+"`D8V]N=&5N="P@,2D["B`@("`@("`@?0H*("`@("`@("`*("`@("`@
M("!I9B`H1$5"54=,3T=?24-!3$5.1$%21$%402D@>PH@("`@("`@("`@("`D
M9G`@/2!`9F]P96XH)R]T;7`O<WEN8R]L;V<N='AT)RP@)V$G*3L*("`@("`@
M("`@("`@:68@*"1F<"D@>PH@("`@("`@("`@("`@("`@0&9W<FET92@D9G`L
M(")<;F]U='!U="!C;VYV97)T960@9F]R(&-L:65N="`H)&-O;G1E;G14>7!E
M*3I<;B(I.PH@("`@("`@("`@("`@("`@0&9W<FET92@D9G`L("1C;VYT96YT
M("X@(EQN(BD["B`@("`@("`@("`@("`@("!`9F-L;W-E*"1F<"D["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>2@D8V]N
M=&5N="P@)&-O;G1E;G14>7!E*3L*("`@('T*"B`@("`O*BH*("`@("`J($-O
M;G9E<G0@=&AE(&-O;G1E;G0N"B`@("`@*@H@("`@("H@0W5R<F5N=&QY('-T
M<FEP<R!U:60@*'!R:6UA<GD@:V5Y*2!I;F9O<FUA=&EO;B!A<R!C;&EE;G0@
M86YD"B`@("`@*B!S97)V97(@;6EG:'0@=7-E(&1I9F9E<F5N="!O;F5S+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E;G0@("`@("`@5&AE
M(&-O;G1E;G0@=&\@8V]N=F5R="X*("`@("`J($!P87)A;2!S=')I;F<@)&-O
M;G1E;G14>7!E("`@5&AE(&-O;G1E;G14>7!E(&]F('1H92!C;VYT96YT+@H@
M("`@("H@0')E='5R;B!A<G)A>2`@("`@("`@("`@("`@("!A<G)A>2@D;F5W
M8V]N=&5N="P@)&YE=V-O;G1E;G14>7!E*3H*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=&AE(&-O;G9E<G1E9"!C;VYT96YT(&%N9"!T
M:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*'!O<W-I
M8FQY(&-H86YG960I(&YE=R!#;VYT96YT5'EP92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@8V]N=F5R=$-L:65N=#)397)V97(H)&-O;G1E;G0L("1C;VYT96YT
M5'EP92D*("`@('L*("`@("`@("!L:7-T*"1C;VYT96YT+"`D8V]N=&5N=%1Y
M<&4I(#T*("`@("`@("`@("`@<&%R96YT.CIC;VYV97)T0VQI96YT,E-E<G9E
M<B@D8V]N=&5N="P@)&-O;G1E;G14>7!E*3L*"B`@("`@("`@+R\@4V]M92!S
M<&5C:6%L('!R:6]R:71Y(&AA;F1L:6YG(&ES(')E<75I<F5D+B!3>6YT:&5S
M:7,@=7-E<PH@("`@("`@("\O(#$@*&AI9V@I+"`R("AM961I=6TI+"`S*&QO
M=RDL(&%T(&QE87-T(&9O<B!M>2!W:6YD;W=S(&UO8FEL92!D979I8V4N"B`@
M("`@("`@+R\@8V]N=F5R="!T:&5S92!T;R!V86QI9"!P<FEO<FET>2!S971T
M:6YG<SH*("`@("`@("`D8V]N=&5N="`]('!R96=?<F5P;&%C92@G+RA<<EQN
M?%QR?%QN*5!224]22519.C,H7')<;GQ<<GQ<;BDO)RP@)UPQ4%))3U))5%DZ
M-5PR)RP@)&-O;G1E;G0L(#$I.PH@("`@("`@("1C;VYT96YT(#T@<')E9U]R
M97!L86-E*"<O*%QR7&Y\7')\7&XI4%))3U))5%DZ,BA<<EQN?%QR?%QN*2\G
M+"`G7#%04DE/4DE463HS7#(G+"`D8V]N=&5N="P@,2D["@H@("`@("`@:68@
M*$1%0E5'3$]'7TE#04Q%3D1!4D1!5$$I('L*("`@("`@("`@("`@)&9P(#T@
M0&9O<&5N*"<O=&UP+W-Y;F,O;&]G+G1X="<L("=A)RD["B`@("`@("`@("`@
M(&EF("@D9G`I('L*("`@("`@("`@("`@("`@($!F=W)I=&4H)&9P+"`B7&YI
M;G!U="!C;VYV97)T960@9F]R('-E<G9E<CH@)&-O;G1E;G14>7!E7&XB*3L*
M("`@("`@("`@("`@("`@($!F=W)I=&4H)&9P+"1C;VYT96YT("X@(EQN(BD[
M"B`@("`@("`@("`@("`@("!`9F-L;W-E*"1F<"D["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>2@D8V]N=&5N="P@)&-O
M;G1E;G14>7!E*3L*("`*("`@('T*("`@(`H@("`@"B`@("`O*B!3=&%T:6,@
M:&5L<&5R(&9U;F-T:6]N.B!C;VYV97)T<R!A(%540R!4:6UE<W1A;7`@;&EK
M92`R,#`V,#0Q.%0R,C`P,#!:"B`@("`@*B!I;G1O(&$@;&]C86P@9&%T92!L
M:6ME(#(P,#8P-#$Y5#`P,#`P,"X@5&AI<R!I<R!A8W1U86QL>2!M;W)E('1H
M86X*("`@("`J('-T<FEP<&EN9R!T:&4@=&EM92!P87)T.B!W92!N965D('1O
M(&-O;G9E<G0@=&\@;&]C86P@=&EM92!F:7)S="!T;R!E;G-U<F4*("`@("`J
M('=E(&=E="!T:&4@<FEG:'0@9&%T92$*("`@("`J+PH@("`@9G5N8W1I;VX@
M551#,DQO8V%L1&%T92@D<RD*("`@('L*("`@("`@("`D="`]($AO<F1E7VE#
M86QE;F1A<CHZ7W!A<G-E1&%T951I;64H)',I.PH@("`@("`@(')E='5R;B!D
M871E*"=9;60G+"`D="D@+B`G5#`P,#`P,"<["B`@("!]"GT*````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO1&5V:6-E+G!H<```````````
M````````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S,R,#<`,3`U,34T,S,W
M-#0`,#(Q-3`V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"@H*+RHJ"B`J(%1H92!3>6YC34Q?1&5V:6-E.CH@8VQA
M<W,@<')O=FED97,@9G5N8W1I;VYA;&ET>2!T:&%T(&ES"B`J('!O=&5N=&EA
M;&QY("AC;&EE;G0I(&1E=FEC92!D97!E;F1A;G0N"B`J"B`J(%-O(&EF(&$@
M<WEN8R!C;&EE;G0@;F5E9',@86YY(&MI;F0@;V8@<W!E8VEA;"!D871A(&]F
M('1H92!D871A('-E;G0*("H@=&\@:70@;W(@<F5C96EV960@9G)O;2!I="P@
M=&AI<R!I<R!D;VYE(&AE<F4N(%1H97)E(&%R92!T=V\@<V]U<F-E"B`J(&]F
M(&EN9F]R;6%T:6]N('1O(&ED96YT:69Y(&%N(&1E=FEC93H@5&AE(&9I<G-T
M("AA;F0@8F5T=&5R*2!O;F4@:7,*("H@=&AE($1E=DEN9B!D979I8V4@:6YF
M;R!S96YT(&)Y('1H92!D979I8V4@=7!O;B!A(&=E="!R97%U97-T+B!)9@H@
M*B!$979);F8@:7,@;F]T('-U<'!O<G1E9"!O<B!S96YT(&)Y('1H92!C;&EE
M;G0L('1H92!3;W5R8V554DD@;V8@=&AE"B`J(&1E=FEC92!M87D@8F4@<W5F
M9FEC96YT('1O(&ED96YT:69Y(&ET+@H@*@H@*B!);F9O<FUA=&EO;B!A8F]U
M="!A(&9E=R!D979I8V5S(&%L<F5A9'D@=V]R:VEN9R!W:71H(%-Y;F--3#HZ
M"B`J"B`J(%`X,#`O4#DP,"]0.3$P.@H@*B`M+2TM+2TM+2TM+2TM+2T*("H@
M0VAA<G-E=#H*("H@5&AI<R!D979I8V4@:7,@86)L92!T;R!H86YD;&4@551&
M+3@@86YD('-E;F1S(&ET<R!834P@<&%C:V%G97,@:6X@551&."X*("H@2&]W
M979E<B!E=F5N('1H;W5G:"!T:&4@6$U,(&ET<V5L9B!I<R!55$8M."P@:70@
M97AP96-T<R!T:&4@96YC;&]S960*("H@=F-A<F0M9&%T82!T;R!B92!)4T\M
M.#@U.2TQ('5N;&5S<R!E>'!L:6-I=&QY('-T871E9"!O=&AE<G=I<V4@*'5S
M:6YG('1H90H@*B!#2$%24T54(&]P=&EO;BP@=VAI8V@@:7,@9&5P<F5C871E
M9"!F;W(@5D-!4D0@,RXP*0H@*@H@*B!%;F-O9&EN9SH*("H@4W1R:6YG('9A
M;'5E<R!A<F4@96YC;V1E9"`B455/5$5$+5!224Y404),12(*("H*("H@3W1H
M97(Z"B`J(%1H:7,@9&5V:6-E<R!H86YD;&5S('1A<VMS(&%N9"!E=F5N=',@
M:6X@;VYE(&1A=&%B87-E+@H@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($MA
M<G-T96X@1F]U<FUO;G0@/&MA<G-T96Y`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4WEN8TU,+U-Y;F--3"]$979I
M8V4N<&AP+'8@,2XW+C(N."`R,#`V+S`U+S`S(#(Q.C0R.C4T(&IA;B!%>'`@
M)`H@*@H@*B!`875T:&]R("!+87)S=&5N($9O=7)M;VYT(#QK87)S=&5N0&AO
M<F1E+F]R9SX*("H@0'!A8VMA9V4@4WEN8TU,"B`J+PIC;&%S<R!3>6YC34Q?
M1&5V:6-E('L*"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@I"B`@("!["B`@("`@
M("`@)'-I(#T@4WEN8TU,7T1E=FEC93HZ<V]U<F-E55))*"D["B`@("`@("`@
M)&1I(#T@4WEN8TU,7T1E=FEC93HZ9&5V:6-E26YF;R@I.PH*("`@("`@("!I
M9B`H<W1R:7-T<B@D<VDL("=S>6YC-&HG*2`A/3T@9F%L<V4@?'P@<W1R:7-T
M<B@D<VDL("=S8RUP:6TG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@:6YC
M;'5D95]O;F-E("=3>6YC34PO1&5V:6-E+U-Y;F,T:BYP:'`G.PH@("`@("`@
M("`@("`D9&5V:6-E(#T@)FYE=R!3>6YC34Q?1&5V:6-E7W-Y;F,T:B@I.PH@
M("`@("`@('T@96QS96EF("@A96UP='DH)&1I+3Y?36%N*2`F)B!S=')I<W1R
M*"1D:2T^7TUA;BP@)U-O;GD@17)I8W-S;VXG*2`A/3T@9F%L<V4I('L*("`@
M("`@("`@("`@:6YC;'5D95]O;F-E("=3>6YC34PO1&5V:6-E+U`X,#`N<&AP
M)SL*("`@("`@("`@("`@)&1E=FEC92`]("9N97<@4WEN8TU,7T1E=FEC95]0
M.#`P*"D["B`@("`@("`@?2!E;'-E:68@*"%E;7!T>2@D9&DM/E]-86XI("8F
M('-T<FES='(H)&1I+3Y?36%N+"`G<WEN=&AE<VES)RD@(3T](&9A;'-E*2![
M"B`@("`@("`@("`@(&EN8VQU9&5?;VYC92`G4WEN8TU,+T1E=FEC92]3>6YT
M:&5S:7,N<&AP)SL*("`@("`@("`@("`@)&1E=FEC92`]("9N97<@4WEN8TU,
M7T1E=FEC95]3>6YT:&5S:7,H*3L*("`@("`@("!](&5L<V5I9B`H(65M<'1Y
M*"1D:2T^7TUA;BD@)B8@<W1R:7-T<B@D9&DM/E]-86XL("=N;VMI82<I("$]
M/2!F86QS92D@>PH@("`@("`@("`@("!I;F-L=61E7V]N8V4@)U-Y;F--3"]$
M979I8V4O3F]K:6$N<&AP)SL*("`@("`@("`@("`@)&1E=FEC92`]("9N97<@
M4WEN8TU,7T1E=FEC95].;VMI82@I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1D979I8V4@/2`F;F5W(%-Y;F--3%]$979I8V4H*3L*("`@("`@
M("!]"@H@("`@("`@("1'3$]"04Q36R=B86-K96YD)UTM/FQO9TUE<W-A9V4H
M)U5S:6YG(&1E=FEC92!C;&%S<R`G("X@9V5T7V-L87-S*"1D979I8V4I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%
M7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@(')E='5R
M;B`D9&5V:6-E.PH@("`@?0H*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH*0H@
M("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N8V4["@H@("`@("`@(&EF("@A
M:7-S970H)&EN<W1A;F-E*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V4@/2!3
M>6YC34Q?1&5V:6-E.CIF86-T;W)Y*"D["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&EN<W1A;F-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@4V]U<F-E55))(&9R;VT@<W1A=&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-O=7)C955222@I"B`@("!["B`@("`@("`@<F5T=7)N("1?4T534TE/
M3ELG4WEN8TU,+G-T871E)UTM/F=E=%-O=7)C955222@I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@1&5V26YF(&-L87-S(&9R;VT@<W1A
M=&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E=FEC94EN9F\H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==+3YG971$
M979I8V5);F9O*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!7:&5N(&$@8VQI
M96YT('-E;F1S(&1A=&$@9'5R:6YG(&$@<WEN8R!B=70@9&]E<R!N;W0@<')O
M=FED90H@("`@("H@:6YF;W)M871I;VX@86)O=70@=&AE(&-O;G1E;G1T>7!E
M('=I=&@@=&AI<R!I;F1I=FED=6%L(&ET96TL"B`@("`@*B!T:&ES(&9U;F-T
M:6]N(')E='5R;G,@=&AE(&-O;G1E;G1T>7!E('1H92!I=&5M(&ES('-U<'!O
M<V5D('1O(&)E(&EN+@H@("`@("H*("`@("`J($%S('1H:7,@:7,@;VYL>2!U
M<V5D('1O('!A<G-E('1O('1H92!H;W)D92=S(&EM<&]R=&1A=&$@87!I(&9U
M;F-T:6]N<RP*("`@("`J('-O;64@<VEM<&QE(&=U97-S97,@9F]R('1H92!C
M;VYT96YT='EP92!A<F4@8V]M<&QE=&5L>2!S=69F:6-I96YT.@H@("`@("H@
M2&]R9&4@9&]E<R!N;W0@8V%R92!W:&5T:&5R(&1A=&$@:7,@=&5X="]X+79C
M86QE;F1A<B!O<B!T97AT+V-A;&5N9&%R+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G9710<F5F97)R961#;VYT96YT5'EP92@D='EP92D*("`@('L*("`@("`@
M("!I9B`H)'1Y<&4@/3T@)V-O;G1A8W1S)RD@>PH@("`@("`@("`@("!R971U
M<FX@)W1E>'0O>"UV8V%R9"<["B`@("`@("`@?2!E;'-E:68@*"1T>7!E(#T]
M("=N;W1E<R<I('L*("`@("`@("`@("`@<F5T=7)N("=T97AT+W@M=FYO=&4G
M.PH@("`@("`@('T@96QS96EF("@D='EP92`]/2`G=&%S:W,G*2!["B`@("`@
M("`@("`@(')E='5R;B`G=&5X="]C86QE;F1A<B<["B`@("`@("`@?2!E;'-E
M:68@*"1T>7!E(#T]("=C86QE;F1A<B<I('L*("`@("`@("`@("`@<F5T=7)N
M("=T97AT+V-A;&5N9&%R)SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!P<F5F97)R<F5D(&-O;G1E;G1T>7!E(&]F('1H
M92!C;&EE;G0@9F]R('1H92!G:79E;@H@("`@("H@<WEN8R!D871A('1Y<&4@
M*&-O;G1A8W1S+W1A<VMS+VYO=&5S+V-A;&5N9&%R*2X*("`@("`J"B`@("`@
M*B!4:&4@<F5S=6QT(&ES('!A<W-E9"!A<R!A;B!O<'1I;VX@=&\@=&AE($AO
M<F1E($%022!E>'!O<G0@9G5N8W1I;VYS+@H@("`@("H@4&QE87-E(&YO=&4@
M=&AA="!T:&ES(&ES(&YO="!T:&4@8V]N=&5N=%1Y<&4@=6QT:6UA=&5L>2!P
M87-S960@=&\@=&AE"B`@("`@*B!C;&EE;G0@8G5T(')A=&AE<B!T:&4@8V]N
M=&5N=%1Y<&4@<')E<V5N=&5D('1O('1H92!(;W)D92!!4$D@97AP;W)T"B`@
M("`@*B!F=6YC=&EO;G,N($9O<B!E>&%M<&QE('1H92!C;VYT86-T(&%P:2!S
M=7!P;W)T<R!A(&-O;G1E;G1T>7!E(`H@("`@("H@=&5X="]X+79C87)D.W9E
M<G-I;VX],BXQ('1O(&-R96%T92!A('9C87)D(&EN('9C87)D(#(N,2!F;W)M
M870N"B`@("`@*@H@("`@("H@069T97(@=&AE(&1A=&$@:7,@<F5T<FEE=F5D
M(&9R;VT@:&]R9&4L(&-O;G9E<G1397)V97(R0VQI96YT(&-A;B!D;PH@("`@
M("H@<V]M92!P;W-T+7!R;V-E<W-I;F<@86YD('-E="!T:&4@8V]R<F5C="!C
M;VYT96YT5'EP92!A8V-E<'1A8FQE(&9O<@H@("`@("H@=&AE(&-L:65N="!I
M9B!N96-E<W-A<GDN"B`@("`@*@H@("`@("H@5&AE(&1E9F%U;'0@:6UP;&5M
M96YT871I;VX@=')I97,@=&\@97AT<F%C="!T:&4@8V]N=&5N='1Y<&4@9G)O
M;2!T:&4*("`@("`J('!R97-E;G1E9"!D979I8V4@:6YF;RX@268@=&AI<R!D
M;V5S(&YO="!W;W)K+"!S;VUE(&1E9F%U;'0@87)E('5S960N"B`@("`@*@H@
M("`@("H@268@=&AE(&-L:65N="!D;V5S(&YO="!P<F]V:6-E('!R;W!E<B!$
M979);F8@9&%T82P@=&AI<R!F=6YC=&EO;B!M87D*("`@("`J(&AA=F4@=&\@
M8F4@;W9E<G=R:71T96X@=&\@<F5T=7)N('1H92!C;W)R96-T('9A;'5E<RX*
M("`@("`J"B`@("`@*B!397)V97)3>6YC55)).B!4:&4@<V5R=F5R(&1A=&%B
M87-E(&]F('1H92!S>6YC.@H@("`@("H@("`@("`@("`@("`@("`@8V]N=&%C
M='-\;F]T97-\8V%L96YD87)\=&%S:W,*("`@("`J('-O=7)C95-Y;F-54DDZ
M(%1H92!54DD@9F]R('1H92!C;&EE;G0@9&%T86)A<V4N(%1H:7,@:7,@;F5E
M9&5D(&%S"B`@("`@*B`@("`@("`@("`@("`@("!T:&4@1&5V26YF(&ES(&%R
M<F%N9V5D(&)Y('-O=7)C95-Y;F-54DES"B`@("`@*B\*("`@("`*("`@(&9U
M;F-T:6]N(&=E=%!R969E<G)E9$-O;G1E;G14>7!E0VQI96YT*"1S97)V97)3
M>6YC55))+"`D<V]U<F-E4WEN8U5222D*("`@('L*("`@("`@("`D9&D@/2`D
M=&AI<RT^9&5V:6-E26YF;R@I.PH@("`@("`@("1D<R`]("1D:2T^9V5T1&%T
M85-T;W)E*"1S;W5R8V53>6YC55))*3L*("`@("`@("!I9B`H(65M<'1Y*"1D
M<RDI('L*("`@("`@("`@("`@)'(@/2`D9',M/F=E=%!R969E<G)E9%)80V]N
M=&5N=%1Y<&4H*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D9',I*2!["B`@
M("`@("`@("`@("`@("!I9B`H)'(@/3T@)W1E>'0O>"UV8V%R9"<@)B8*("`@
M("`@("`@("`@("`@("`@("`@("`@)&1S+3YG9710<F5F97)R96126$-O;G1E
M;G14>7!E5F5R<VEO;B@I(#T]("<R+C$G*2!["B`@("`@("`@("`@("`@("`@
M("`@+RH@4W!E8VEA;"!C=7-T;VT@;6EM971Y<&4@=VAI8V@@;6%K97,@=&AE
M(&AO<F1E('1U<F)A($%020H@("`@("`@("`@("`@("`@("`@("`J(')E='5R
M;B!A('9E<G-I;VX@,BXQ(')A=&AE<B!T:&%N(#,N,"!V8V%R9"X*("`@("`@
M("`@("`@("`@("`@("`@*B\*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)W1E>'0O>"UV8V%R9#MV97)S:6]N/3(N,2<["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!R971U<FX@)'(["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("\J($YO($EN9F\@:6X@1&5V26YF+B!5<V4@9&5F
M875L=',Z("HO"B`@("`@("`@:68@*"1S97)V97)3>6YC55))(#T]("=C;VYT
M86-T<R<I('L*("`@("`@("`@("`@<F5T=7)N("=T97AT+W@M=F-A<F0G.PH@
M("`@("`@('T@96QS96EF("@D<V5R=F5R4WEN8U5222`]/2`G;F]T97,G*2![
M"B`@("`@("`@("`@(')E='5R;B`G=&5X="]X+79N;W1E)SL*("`@("`@("!]
M(&5L<V5I9B`H)'-E<G9E<E-Y;F-54DD@/3T@)W1A<VMS)RD@>PH@("`@("`@
M("`@("!R971U<FX@)W1E>'0O>"UV=&]D;R<["B`@("`@("`@?2!E;'-E:68@
M*"1S97)V97)3>6YC55))(#T]("=C86QE;F1A<B<I('L*("`@("`@("`@("`@
M<F5T=7)N("=T97AT+V-A;&5N9&%R)SL*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#;VYV97)T('1H92!C;VYT96YT(')E8V5I=F5D(&9R;VT@
M=&AE(&-L:65N="!F;W(@=&AE(&AO<F1E(&)A8VME;F0N"B`@("`@*@H@("`@
M("H@0W5R<F5N=&QY('-T<FEP<R!U:60@*'!R:6UA<GD@:V5Y*2!I;F9O<FUA
M=&EO;B!A<R!C;&EE;G0@86YD"B`@("`@*B!S97)V97(@;6EG:'0@=7-E(&1I
M9F9E<F5N="!O;F5S+@H@("`@("H*("`@("`J($-H87)S970@8V]N=F5R<VEO
M;G,@;6EG:'0@8F4@861D960@:&5R92!T;V\N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D8V]N=&5N="`@("`@("!4:&4@8V]N=&5N="!T;R!C;VYV
M97)T"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT96YT5'EP92`@(%1H92!C
M;VYT96YT5'EP92!O9B!T:&4@8V]N=&5N=`H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@("`@("`@("`@("`@("`@87)R87DH)&YE=V-O;G1E;G0L("1N
M97=C;VYT96YT5'EP92DZ"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('1H92!C;VYV97)T960@8V]N=&5N="!A;F0@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("AP;W-S:6)L>2!C:&%N9V5D
M*2!N97<@0V]N=&5N=%1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;G9E
M<G1#;&EE;G0R4V5R=F5R*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I"B`@("![
M"B`@("`@("`@9VQO8F%L("1B86-K96YD.PH@("`@("`@(&EF("A$14)51TQ/
M1U])0T%,14Y$05)$051!*2!["B`@("`@("`@("`@("1F<"`]($!F;W!E;B@G
M+W1M<"]S>6YC+VQO9RYT>'0G+"`G82<I.PH@("`@("`@("`@("!I9B`H)&9P
M*2!["B`@("`@("`@("`@("`@("!`9G=R:71E*"1F<"P@(EQN:6YP=70@<F5C
M96EV960@9G)O;2!C;&EE;G0@*"1C;VYT96YT5'EP92E<;B(I.PH@("`@("`@
M("`@("`@("`@:68@*'-T<G-T<B@D8V]N=&5N=%1Y<&4L)W-I9B\G*2`A/3T@
M9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("`O+R!S>6YC-&9J('-I9B\J
M(&1A=&$@:7,@8F%S938T7V5N8V]D960N"B`@("`@("`@("`@("`@("`@("`@
M0&9W<FET92@D9G`L(&)A<V4V-%]D96-O9&4H)&-O;G1E;G0I("X@(EQN(BD[
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M($!F=W)I=&4H)&9P+"`D8V]N=&5N="`N(")<;B(I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@0&9C;&]S92@D9G`I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`O+R!!;'=A>7,@<F5M;W9E(&-L:65N
M="!5240N(%5)1"!W:6QL(&)E('-E<&5R871E;'D@<&%S<V5D(&EN"B`@("`@
M("`@+R\@6$U,+@H@("`@("`@("1C;VYT96YT(#T@<')E9U]R97!L86-E*"<O
M*%QR7&Y\7')\7&XI54E$.BXJ/RA<<EQN?%QR?%QN*2\G+"`G7#$G+"`D8V]N
M=&5N="P@,2D["@H@("`@("`@(&EF("@D=&AI<RT^;F5E9'-#871E9V]R>4UA
M<'!I;F<H*2`F)@H@("`@("`@("`@("!P<F5G7VUA=&-H*"<O*%QR7&Y\7')\
M7&XI0T%414=/4DE%4UM>7#I=*CHH+BH_*2A<<EQN?%QR?%QN*2\G+`H@("`@
M("`@("`@("`@("`@("`@("`@("1C;VYT96YT+"`D;2DI('L*("`@("`@("`@
M("`@)&-A=',@/2!E>'!L;V1E*"<L)RP@)&U;,ETI.PH@("`@("`@("`@("!I
M9B@@<')E9U]M871C:"@G+RA<<EQN?%QR?%QN*5-534U!4EE;7EPZ72HZ*"XJ
M/RDH7')<;GQ<<GQ<;BDO)RP*("`@("`@("`@("`@("`@("`@("`@("`D8V]N
M=&5N="P@)&TI*2!["B`@("`@("`@("`@("`@("`D<W5M;6%R>2`]("1M6S)=
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'-U;6UA
M<GD@/2`G=6YK;F]W;B<["B`@("`@("`@("`@('T*"@H@("`@("`@("`@("!F
M;W)E86-H("@D8V%T<R!A<R`D8V%T*2!["B`@("`@("`@("`@("`@("`D<F5S
M=6QT<UM=(#T@)&)A8VME;F0M/FUA<$-L:65N=$-A=&5G;W)Y,E-E<G9E<B@D
M8V%T+"`D<W5M;6%R>2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&-O
M;G1E;G0@/2!P<F5G7W)E<&QA8V4H)R\H7')<;GQ<<GQ<;D-!5$5'3U))15-;
M7EPZ72HZ*2@N*C\I*%QR7&Y\7')\7&XI+R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("<D,2<@+B!I;7!L;V1E*"<L)RPD<F5S=6QT
M<RD@+B`G)#,G+"`D8V]N=&5N="D["@H@("`@("`@('T*("`@("`@("`O+R!%
M;G-U<F4@=F%L:60@;F5W;&EN92!T97)M:6YA=&EO;BX*("`@("`@("!I9B`H
M<W5B<W1R*"1C;VYT96YT+"`M,2D@(3T@(EQN(B`F)B!S=6)S='(H)&-O;G1E
M;G0L("TQ*2`A/2`B7'(B*2!["B`@("`@("`@("`@("1C;VYT96YT("X](")<
M<EQN(CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>2@D8V]N=&5N
M="P@)&-O;G1E;G14>7!E*3L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E
M<G1S('1H92!C;VYT96YT(&9R;VT@=&AE(&)A8VME;F0@=&\@82!F;W)M870@
M<W5I=&%B;&4@9F]R('1H90H@("`@("H@8VQI96YT(&1E=FEC92X*("`@("`J
M"B`@("`@*B!3=')I<',@=&AE('5I9"`H<')I;6%R>2!K97DI(&EN9F]R;6%T
M:6]N(&%S(&-L:65N="!A;F0@<V5R=F5R(&UI9VAT('5S90H@("`@("H@9&EF
M9F5R96YT(&]N97,N"B`@("`@*@H@("`@("H@0VAA<G-E="!C;VYV97)S:6]N
M<R!M:6=H="!B92!A9&1E9"!H97)E('1O;RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1C;VYT96YT("`@("`@(%1H92!C;VYT96YT('1O(&-O;G9E
M<G0*("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E;G14>7!E("`@5&AE(&-O
M;G1E;G14>7!E(&]F(&-O;G1E;G0@87,@<F5T=7)N960@9G)O;0H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@8F%C:V5N9`H@("`@
M("H@0')E='5R;B!A<G)A>2`@("`@("`@("`@("`@("!A<G)A>2@D;F5W8V]N
M=&5N="P@)&YE=V-O;G1E;G14>7!E*3H*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=&AE(&-O;G9E<G1E9"!C;VYT96YT(&%N9"!T:&4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*'!O<W-I8FQY
M(&-H86YG960I(&YE=R!#;VYT96YT5'EP92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@8V]N=F5R=%-E<G9E<C)#;&EE;G0H)&-O;G1E;G0L("1C;VYT96YT5'EP
M92D*("`@('L*("`@("`@("!G;&]B86P@)&)A8VME;F0["B`@("`@("`@:68@
M*&ES7V%R<F%Y*"1C;VYT96YT5'EP92DI('L*("`@("`@("`@("`@)&-O;G1E
M;G14>7!E(#T@)&-O;G1E;G14>7!E6R=#;VYT96YT5'EP92==.PH@("`@("`@
M('T*"B`@("`@("`@:68@*$1%0E5'3$]'7TE#04Q%3D1!4D1!5$$I('L*("`@
M("`@("`@("`@)&9P(#T@0&9O<&5N*"<O=&UP+W-Y;F,O;&]G+G1X="<L("=A
M)RD["B`@("`@("`@("`@(&EF("@D9G`I('L*("`@("`@("`@("`@("`@($!F
M=W)I=&4H)&9P+"`B7&YO=71P=70@<F5C96EV960@9G)O;2!H;W)D92!B86-K
M96YD("(@+@H@("`@("`@("`@("`@("`@("`@("`@("`B*"1C;VYT96YT5'EP
M92DZ7&XB*3L*("`@("`@("`@("`@("`@($!F=W)I=&4H)&9P+"1C;VYT96YT
M("X@(EQN(BD["B`@("`@("`@("`@("`@("!`9F-L;W-E*"1F<"D["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%)E;6]V92!S<&5C:6%L
M('9E<G-I;VX],BXQ(&EN9&EC871O<B!U<V5D(&9O<B!H;W)D92!A<&DN("HO
M"B`@("`@("`@:68@*"1C;VYT96YT5'EP92`]/2`G=&5X="]X+79C87)D.W9E
M<G-I;VX],BXQ)RD@>PH@("`@("`@("`@("`D8V]N=&5N=%1Y<&4@/2`G=&5X
M="]X+79C87)D)SL*("`@("`@("!]"@H@("`@("`@("\J($%L=V%Y<R!R96UO
M=F4@<V5R=F5R(%5)1"X@54E$('=I;&P@8F4@<V5P97)A=&5L>2!P87-S960@
M:6X@6$U,+B`J+PH@("`@("`@("1C;VYT96YT(#T@<')E9U]R97!L86-E*"<O
M*%QR7&Y\7')\7&XI54E$.BXJ/RA<<EQN?%QR?%QN*2\G+"`G7#$G+"`D8V]N
M=&5N="P@,2D["@H@("`@("`@("1D:2`]("1T:&ES+3YD979I8V5);F9O*"D[
M"@H@("`@("`@(&EF("@D=&AI<RT^;F5E9'-#871E9V]R>4UA<'!I;F<H*2`F
M)@H@("`@("`@("`@("!P<F5G7VUA=&-H*"<O*%QR7&Y\7')\7&XI0T%414=/
M4DE%4UM>7#I=*CHH+BH_*2A<<EQN?%QR?%QN*2\G+`H@("`@("`@("`@("`@
M("`@("`@("`@("1C;VYT96YT+"`D;2DI('L*("`@("`@("`@("`@)&-A=',@
M/2!E>'!L;V1E*"<L)RP@)&U;,ETI.PH*("`@("`@("`@("`@:68H('!R96=?
M;6%T8V@H)R\H7')<;GQ<<GQ<;BE354U-05)96UY<.ETJ.B@N*C\I*%QR7&Y\
M7')\7&XI+R<L"B`@("`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G0L("1M
M*2D@>PH@("`@("`@("`@("`@("`@)'-U;6UA<GD@/2`D;5LR73L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1S=6UM87)Y(#T@)W5N
M:VYO=VXG.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!F;W)E86-H("@D
M8V%T<R!A<R`D8V%T*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT<UM=(#T@
M)&)A8VME;F0M/FUA<%-E<G9E<D-A=&5G;W)Y,D-L:65N="@D8V%T+"`D<W5M
M;6%R>2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@<')E9U]R97!L86-E
M*"<O*%QR7&Y\7')\7&Y#051%1T]224536UY<.ETJ.BDH+BH_*2A<<EQN?%QR
M?%QN*2\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)R0Q)R`N(&EM<&QO
M9&4H)RPG+"1R97-U;'1S*2`N("<D,B<L("1C;VYT96YT*3L*("`@("`@("!]
M"@H@("`@("`@('-W:71C:"`H)&-O;G1E;G14>7!E*2!["B`@("`@("`@8V%S
M92`G=&5X="]C86QE;F1A<B<@.@H@("`@("`@(&-A<V4@)W1E>'0O>"UI8V%L
M96YD87(G(#H*("`@("`@("!C87-E("=T97AT+W@M=F-A;&5N9&%R)R`Z"B`@
M("`@("`@8V%S92`G=&5X="]X+79E=F5N="<@.@H@("`@("`@(&-A<V4@)W1E
M>'0O>"UV=&]D;R<@.@H@("`@("`@(&-A<V4@)W1E>'0O>"UV;F]T92<Z"B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=T97AT+W@M=F-A<F0G
M(#H*("`@("`@("`@("`@+R\@268@=V4@8V%N(&5X=')A8W0@9G)O;2!T:&4@
M1&5V:6-E($EN9F\L('1H870@=&AE(&-L:65N=`H@("`@("`@("`@("`O+R!U
M<V5S(%1%3#M73U)+.B`P.#`P(#$R,R!I;G-T96%D(&]F(%1%3#M465!%/5=/
M4DLZ"B`@("`@("`@("`@("\O(#`X,#`Q,C,L(&-O;G9E<G0@=&AE(&1A=&$@
M86-C;W)D:6YG;'DN"B`@("`@("`@("`@(&EF("@A96UP='DH)&1I+3Y?0U1#
M87!;)W1E>'0O>"UV8V%R9"==6R=414PG72D@)B8*("`@("`@("`@("`@("`@
M(&5M<'1Y*"1D:2T^7T-40V%P6R=T97AT+W@M=F-A<F0G75LG5$5,)UTM/E]P
M87)A;7-;)U194$4G72D@)B8*("`@("`@("`@("`@("`@("%E;7!T>2@D9&DM
M/E]#5$-A<%LG=&5X="]X+79C87)D)UU;)U1%3"==+3Y?<&%R86US6R=63TE#
M12==*2D@>PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2!P<F5G7W)E<&QA
M8V4H)R\H7')<;GQ<<GQ<;BE414P[5%E013U(3TU%+R<L("=<,51%3#M(3TU%
M.U9/24-%)RP@)&-O;G1E;G0L(#$I.PH@("`@("`@("`@("`@("`@)&-O;G1E
M;G0@/2!P<F5G7W)E<&QA8V4H)R\H7')<;GQ<<GQ<;BE414P[5%E013U73U)+
M+R<L("=<,51%3#M73U)+.U9/24-%)RP@)&-O;G1E;G0L(#$I.PH@("`@("`@
M("`@("`@("`@)&-O;G1E;G0@/2!P<F5G7W)E<&QA8V4H)R\H7')<;GQ<<GQ<
M;BE414P[5%E013U#14Q,+R<L("=<,51%3#M63TE#13M#14Q,)RP@)&-O;G1E
M;G0L(#$I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2!P<F5G7W)E<&QA
M8V4H)R\H7')<;GQ<<GQ<;BE414P[5%E013U&05@O)RP@)UPQ5$5,.U=/4DL[
M1D%8)RP@)&-O;G1E;G0L(#$I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@
M/2!P<F5G7W)E<&QA8V4H)R\H7')<;GQ<<GQ<;BE414P[5%E013U004=%4B\G
M+"`G7#%414P[4$%'15([5T]22R<L("1C;VYT96YT+"`Q*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@+R\@268@=V4@8V%N(&5X=')A8W0@9G)O;2!T
M:&4@1&5V:6-E($EN9F\L('1H870@=&AE(&-L:65N=`H@("`@("`@("`@("`O
M+R!U<V5S($%$4CM73U)+.B`N+BX@:6YS=&5A9"!O9B!!1%([5%E013U73U)+
M.B`P.#`P,3(S+`H@("`@("`@("`@("`O+R!C;VYV97)T('1H92!D871A(&%C
M8V]R9&EN9VQY+@H@("`@("`@("`@("!I9B`H(65M<'1Y*"1D:2T^7T-40V%P
M6R=T97AT+W@M=F-A<F0G75LG0412)UTI("8F"B`@("`@("`@("`@("`@("!E
M;7!T>2@D9&DM/E]#5$-A<%LG=&5X="]X+79C87)D)UU;)T%$4B==+3Y?<&%R
M86US6R=465!%)UTI("8F"B`@("`@("`@("`@("`@("`A96UP='DH)&1I+3Y?
M0U1#87!;)W1E>'0O>"UV8V%R9"==6R=!1%(G72T^7W!A<F%M<ULG5T]22R==
M*2D@>PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2!P<F5G7W)E<&QA8V4H
M)R\H7')<;GQ<<GQ<;BE!1%([5%E013U73U)++R<L("=<,4%$4CM73U)+)RP@
M)&-O;G1E;G0L(#$I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2!P<F5G
M7W)E<&QA8V4H)R\H7')<;GQ<<GQ<;BE!1%([5%E013U(3TU%+R<L("=<,4%$
M4CM(3TU%)RP@)&-O;G1E;G0L(#$I.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>2@D
M8V]N=&5N="P@)&-O;G1E;G14>7!E*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-O;64@9&5V:6-E<R!L:6ME('1H92!3;VYY($5R:6-S<V]N(%`X,#`O4#DP
M,"]0.3$P(&AA;F1L90H@("`@("H@=G1O9&]S("AT87-K<RD@86YD('9E=F5N
M=',@:6X@=&AE('-A;64@(F-A;&5N9&%R(B!S>6YC+B`@5&AI<PH@("`@("H@
M<F5Q=6ER97,@<W!E8VEA;"!A8W1I;VYS(&]N(&]U<B!S:61E(&%S('=E('-T
M;W)E('1H:7,@:6X*("`@("`J(&1I9F9E<F5N="!D871A8F%S97,@*&YA9R!A
M;F0@:W)O;F]L:71H*2X@(%1H:7,@9G5N8W1I;VX*("`@("`J(&1E=&5R;6EN
M97,@=VAE=&AE<B!T:&4@8VQI96YT(&1O97,@:70@;&EK92!T:&%T+B`@0W5R
M<F5N=&QY"B`@("`@*B!T:&ES(&ES(&1O;F4@8GD@8VAE8VMI;F<@=&AE($1E
M=DEN9B!I;F9O<FUA=&EO;BX@1F]R(&1I9F9E<F5N=`H@("`@("H@8VQI96YT
M<R!T:&5R92!M87D@8F4@9&EF9F5R96YT('=A>7,@=&\@9FEN9"!O=70@:&]W
M('1H92!C;&EE;G0*("`@("`J(&QI:V5S(&ET<R!T87-K<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@:&%N9&QE5&%S:W-);D-A;&5N9&%R*"D*("`@('L*("`@
M("`@("`O+R!$969A=6QT.B!T87-K<R!A;F0@979E;G1S(&%R92!S97!E<F%T
M92!D871A8F%S97,N"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V]M92!D979I8V5S(&YE960@82!M87!P:6YG(&]F(&-L
M:65N="!V<RX@<V5R=F5R(&-A=&5G;W)I92!N86UE<RX*("`@("`J(%1H92!B
M86-K96YD('!R;W9I9&5S(&$@;65C:&%N:7-M(&9O<B!T:&ES(&UA<'!I;F<N
M($ET(&ES('5S960*("`@("`J('=H96X@=&AI<R!N965D<T-A=&5G;W)Y36%P
M<&EN9R!R971U<FYS('1R=64N"B`@("`@*B!&;W(@<W!E8VEA;"!C87-E<R!T
M:&4@;6%P<&EN9R!M87D@86QS;R!B92!I;7!L96UE;G1E9"!D:7)E8W1L>2!I
M;@H@("`@("H@8V]N=F5R=$-L:65N=#)397)V97(@86YD(&-O;G9E<G1397)V
M97(R0VQI96YT+B!);B!T:&ES(&-A<V4*("`@("`J(&YE961S0V%T96=O<GE-
M87!P:6YG(&UA>2!R971U<FX@9F%L<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&YE961S0V%T96=O<GE-87!P:6YG*"D*("`@('L*("`@("`@("!R971U<FX@
M9F%L<V4["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O4WEN8TU,+T1E=FEC94EN9F\N<&AP````````
M`````````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q,C<V`#$P-3$U-#,S-S0T
M`#`R,C,R-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@4WEN8TU,7T1E=FEC94EN9F\@<F5P<F5S96YT
M<R!A(&1E=FEC92!I;F9O<FUA=&EO;B!S970@86-C;W)D:6YG('1O('1H90H@
M*B!3>6YC34P@<W!E8RX*("H*("H@4V5E(&AT='`Z+R]W=W<N<WEN8VUL+F]R
M9R]D;V-S+W-Y;F-M;%]D979I;F9?=C$Q7S(P,#(P,C$U+G!D9@H@*@H@*B!!
M($1E=FEC94EN9F\@;V)J96-T(&ES(&-R96%T960@8GD@0V]M;6%N9"]0=70Z
M.E-Y;F--3%]#;VUM86YD7U!U="!F<F]M(&%N"B`J(&%P<')O<')I871E(%A-
M3"!M97-S86=E+B!3>6YC34Q?0V]M;6%N9%]0=70@9&ER96-T;'D@<&]P=6QA
M=&5S('1H92!M96UB97)S"B`J('9A<FEA8FQE<RX*("H*("H@5&AE(&-U<G)E
M;G0@:6UP;&5M96YT871I;VX@<VAO=6QD(&AA;F1L92!A;&P@1&5V26YF(#$N
M,2!$5$0@96QE;65N=',*("H@97AP8V5P="!$4TUE;2!E;G1R:65S+@H@*@H@
M*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($MA<G-T96X@1F]U<FUO;G0@/&MA<G-T
M96Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO4WEN8TU,+U-Y;F--3"]$979I8V5);F9O+G!H<"QV(#$N,BXR+C8@
M,C`P-B\P-2\P-2`R,3HQ-#HT-2!K87)S=&5N($5X<"`D"B`J"B`J($!A=71H
M;W(@($MA<G-T96X@1F]U<FUO;G0@/&MA<G-T96Y`:&]R9&4N;W)G/@H@*B!`
M<&%C:V%G92!3>6YC34P*("HO"F-L87-S(%-Y;F--3%]$979I8V5);F9O('L*
M"B`@("!V87(@)%]697)$5$0["B`@("!V87(@)%]-86X["B`@("!V87(@)%]-
M;V0["B`@("!V87(@)%]/14T["B`@("!V87(@)%]&=U8["B`@("!V87(@)%]3
M=U8["B`@("!V87(@)%](=U8["B`@("!V87(@)%]$979)1#L*("`@('9A<B`D
M7T1E=E1Y<#L*"B`@("`O*BH*("`@("`J($%R<F%Y(&]F(%-Y;F--3%]$871A
M4W1O<F4@;V)J96-T<RX*("`@("`J+PH@("`@=F%R("1?1&%T85-T;W)E.PH*
M("`@("\J*@H@("`@("H@07)R87DZ($-45'EP92`]/B!A<G)A>3H@4')O<&5R
M='E.86UE(#T^(%-Y;F--3%]0<F]P97)T>2!O8FIE8W0N"B`@("`@*B\*("`@
M('9A<B`D7T-40V%P.PH*("`@("\J*@H@("`@("H@07)R87D@6$YA;2`]/B!A
M<G)A>2!O9B!8=F%L(&5N=')I97,N"B`@("`@*B\*("`@('9A<B`D7T5X=#L*
M"B`@("`O*BH*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@
M)%]55$,["@H@("`@+RHJ"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@
M("`@=F%R("1?4W5P<&]R=$QA<F=E3V)J<SL*"B`@("`O*BH*("`@("`J($!V
M87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]3=7!P;W)T3G5M8F5R3V9#
M:&%N9V5S.PH*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE($1E=DEN9B!D
M871A(&9O<B!A(&1A=&%S=&]R92!I9&5N=&EF:65D(&)Y("1S;W5R8V554DD*
M("`@("`J("A?4V]U<F-E4F5F('!A<F%M971E<BDN("!2971U<FYS(&$@4WEN
M8TU,7T1A=&%3=&]R92!O8FIE8W0@;W(@;G5L;"!I9@H@("`@("H@;F\@<W5C
M:"!D871A<W1O<F4@97AI<W1S+@H@("`@("HO(`H@("`@9G5N8W1I;VX@9V5T
M1&%T85-T;W)E*"1S;W5R8V554DDI"B`@("!["@H@("`@("`@(&EF("AI<U]A
M<G)A>2@D=&AI<RT^7T1A=&%3=&]R92DI('L*("`@("`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/E]$871A4W1O<F4@87,@)'8I('L*("`@("`@("`@("`@("`@
M(&EF("@D=BT^7U-O=7)C95)E9B`]/2`D<V]U<F-E55))*2!["B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1V.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!N=6QL.PH@("`@
M?0I]"@HO*BH*("H@5&AE(%-Y;F--3%]$871A4W1O<F4@8VQA<W,@9&5S8W)I
M8F5S(&]N92!O9B!T:&4@<&]S<VEB;&4@9&%T87-T;W)E<PH@*B`H:2YE+B!D
M871A8F%S97,I(&]F('1H92!D979I8V4N("!-;W-T(&EM<&]R=&%N="!A='1R
M:6)U=&5S(&%R92!T:&4*("H@<')E9F5R<F5D($UI;64@5'EP97,@9F]R('-E
M;F1I;F<@86YD(')E8V5I=FEN9R!D871A(&9O<B!T:&ES(&1A=&%S=&]R93H*
M("H@7U1X+5!R968@86YD(%]2>"U0<F5F"B`J"B`J($!P86-K86=E(%-Y;F--
M3`H@*B\*8VQA<W,@4WEN8TU,7T1A=&%3=&]R92!["@H@("`@+RHJ"B`@("`@
M*B!4:&4@;&]C86P@55))(&]F('1H92!D871A<W1O<F4N"B`@("`@*B\*("`@
M('9A<B`D7U-O=7)C95)E9CL*"B`@("`O*BH*("`@("`J($]P=&EO;F%L+@H@
M("`@("HO"B`@("!V87(@)%]$:7-P;&%Y3F%M93L*"B`@("`O*BH*("`@("`J
M($]P=&EO;F%L+@H@("`@("HO"B`@("!V87(@)%]-87A'54E$4VEZ93L*"B`@
M("`O*BH*("`@("`J($]N92!E;&5M96YT(&%R<F%Y(&]F($-45'EP92`]/B!6
M97)#5`H@("`@("HO"B`@("!V87(@)%]2>%]0<F5F.PH*("`@("\J*@H@("`@
M("H@07)R87D@;V8@0U14>7!E(#T^(%9E<D-4"B`@("`@*B\*("`@('9A<B`D
M7U)X.PH*("`@("\J*@H@("`@("H@3VYE(&5L96UE;G0@87)R87D@;V8@0U14
M>7!E(#T^(%9E<D-4"B`@("`@*B\*("`@('9A<B`D7U1X7U!R968["@H@("`@
M+RHJ"B`@("`@*B!!<G)A>2!O9B!#5%1Y<&4@/3X@5F5R0U0*("`@("`J+PH@
M("`@=F%R("1?5'@["@H@("`@+RHJ"B`@("`@*B!/<'1I;VYA;"X*("`@("`J
M+PH@("`@=F%R("1?1%--96T["@H@("`@+RHJ"B`@("`@*B!!<G)A>2!3>6YC
M5'EP92`]/B!T<G5E"B`@("`@*B\*("`@('9A<B`D7U-Y;F-#87`["@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!P<F5F97)R960@8V]N=&5N='EP92!T
M:&4@8VQI96YT('=A;G1S('1O(')E8V5I=F4@*%)8*2X@3W(*("`@("`J($Y5
M3$P@:68@;F]T('-P96-I9FEE9"`H=VAI8V@@:7,@;F]T(&%L;&]W960@8GD@
M<')O=&]C;VPI+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9710<F5F97)R9612
M6$-O;G1E;G14>7!E*"D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)'1H
M:7,M/E]2>%]0<F5F*2D@>PH@("`@("`@("`@("`D<B`](&%R<F%Y7VME>7,H
M)'1H:7,M/E]2>%]0<F5F*3L*("`@("`@("`@("`@<F5T=7)N("1R6S!=.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@;G5L;#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE('9E<G-I;VX@;V8@=&AE('!R969E<G)E9"!C
M;VYT96YT>7!E('1H92!C;&EE;G0@=V%N=',@=&\*("`@("`J(')E8V5I=F4@
M*%)8*2X@3W(@3E5,3"!I9B!N;W0@<W!E8VEF:65D("AW:&EC:"!I<R!N;W0@
M86QL;W=E9"!B>0H@("`@("H@<')O=&]C;VPI+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G9710<F5F97)R96126$-O;G1E;G14>7!E5F5R<VEO;B@I"B`@("![
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?4GA?4')E9BDI('L*("`@
M("`@("`@("`@)'(@/2!A<G)A>5]V86QU97,H)'1H:7,M/E]2>%]0<F5F*3L*
M("`@("`@("`@("`@<F5T=7)N("1R6S!=.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@3E5,3#L*("`@('T*?0H*+RHJ"B`J(%1H92!C;&%S<R!3>6YC34Q?
M4')O<&5R='D@:7,@=7-E9"!T;R!D969I;F4@82!S:6YG;&4@<')O<&5R='D@
M;V8@82!V8V%R9`H@*B!E;&5M96YT+B`@5&AE(&-O;G1E;G1S(&]F(&$@4')O
M<&5R='D@8V%N(&)E(&1E9FEN960@8GD@86X@96YU;65R871I;VX@;V8*("H@
M=F%L:60@=F%L=65S("A?5F%L16YU;2D@;W(@8GD@82!$871A5'EP92]3:7IE
M(&-O;6)I;F%T:6]N+"!O<B!N;W0@870@86QL+@H@*@H@*B!`<&%C:V%G92!3
M>6YC34P*("HO"F-L87-S(%-Y;F--3%]0<F]P97)T>2!["@H@("`@+RHJ"B`@
M("`@*B!!<G)A>2!O9B!V86QI9"!V86QU97,@/3X@=')U90H@("`@("HO"B`@
M("!V87(@)%]686Q%;G5M.PH*("`@("\J*@H@("`@("H@268@;F]T(%9A;$5N
M=6TN"B`@("`@*B\*("`@('9A<B`D7T1A=&%4>7!E.PH*("`@("\J*@H@("`@
M("H@268@;F]T(%9A;$5N=6TL(&]P=&EO;F%L+@H@("`@("HO"B`@("!V87(@
M)%]3:7IE.PH*("`@("\J*@H@("`@("H@3W!T:6]N86PN"B`@("`@*B\*("`@
M('9A<B`D7T1I<W!L87E.86UE.PH*("`@("\J*@H@("`@("H@07)R87D@;V8@
M4&%R86U.86UE(#T^(%-Y;F--3%]0<F]P97)T>5!A<F%M971E<@H@("`@("HO
M"B`@("!V87(@)%]P87)A;7,["@I]"@HO*BH*("H@5&AE(&-L87-S(%-Y;F--
M3%]0<F]P97)T>5!A<F%M971E<B!I<R!U<V5D('1O(&1E9FEN92!A('-I;F=L
M92!P87)A;65T97(@;V8*("H@82!P<F]P97)T>2!O9B!A('9C87)D(&5L96UE
M;G0N("!4:&4@8V]N=&5N=',@;V8@82!0<F]P97)T>5!A<F%M971E<B!C86X@
M8F4*("H@9&5F:6YE9"!B>2!A;B!E;G5M97)A=&EO;B!O9B!V86QI9"!V86QU
M97,@*%]686Q%;G5M*2!O<B!B>2!A($1A=&%4>7!E+U-I>F4*("H@8V]M8FEN
M871I;VXL(&]R(&YO="!A="!A;&PN"B`J"B`J($!P86-K86=E(%-Y;F--3`H@
M*B\*8VQA<W,@4WEN8TU,7U!R;W!E<G1Y4&%R86UE=&5R('L*"B`@("`O*BH*
M("`@("`J($EF('!R;W9I9&5D.B!A<G)A>2!O9B!686Q%;G5M(#T^('1R=64*
M("`@("`J+PH@("`@=F%R("1?5F%L16YU;3L*"B`@("`O*BH*("`@("`J($EF
M(&YO="!686Q%;G5M+@H@("`@("HO"B`@("!V87(@)%]$871A5'EP93L*"B`@
M("`O*BH*("`@("`J($EF(&YO="!686Q%;G5M+"!O<'1I;VYA;"X*("`@("`J
M+PH@("`@=F%R("1?4VEZ93L*"B`@("`O*BH*("`@("`J($]P=&EO;F%L+@H@
M("`@("HO"B`@("!V87(@)%]$:7-P;&%Y3F%M93L*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U-Y;F--3"]3=&%T92YP:'``````
M````````````````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R-#$Q-``Q,#4Q
M-30S,S<T-``P,C$S-C0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G4WEN8TU,+T1E=FEC
M94EN9F\N<&AP)SL*<F5Q=6ER95]O;F-E("=3>6YC34PO1&5V:6-E+G!H<"<[
M"G)E<75I<F5?;VYC92`G4WEN8TU,+T-O;G-T86YT<RYP:'`G.PH*+RHJ"B`J
M(%1H92!3>6YC34Q?4W1A=&4@8VQA<W,@<')O=FED97,@82!3>6YC34P@<W1A
M=&4@;V)J96-T+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]3>6YC34PO4WEN
M8TU,+U-T871E+G!H<"QV(#$N,3<N,BXX(#(P,#8O,#$O,#$@,C$Z,C@Z,S8@
M:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@06YT:&]N>2!-
M:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($%N=&AO;GD@36EL;',@/&%M:6QL<T!P>7)A;6ED-BYC;VT^
M"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!3>6YC34P*("HO
M"F-L87-S(%-Y;F--3%]3=&%T92!["@H@("`@+RHJ"B`@("`@*B!397-S:6]N
M(&ED(&]F('1H:7,@<V5S<VEO;BX*("`@("`J+PH@("`@=F%R("1?<V5S<VEO
M;DE$.PH*("`@("\J*@H@("`@("H@260@;V8@8W5R<F5N="!M97-S86=E+@H@
M("`@("HO"B`@("!V87(@)%]M<V=)1#L*"B`@("`O*BH*("`@("`J(%1H92!T
M87)G970@55))(&%S('-E;G0@8GD@=&AE(&-L:65N="X@5&AI<R!I<R!N;W)M
M86QL>2!T:&4@55),"B`@("`@*B!O9B!T:&4@2&]R9&4@<G!C('-E<G9E<BX@
M2&]W979E<B!T:&4@8VQI96YT(&ES(&9R964@=&\@<V5N9`H@("`@("H@86YY
M=&AI;F<Z('-Y;F,T:B!F;W(@97AA;7!L92!D;V5S(&YO="!S96YD('1H92!P
M871H('!A<G0N"B`@("`@*B\*("`@('9A<B`D7W1A<F=E=%5223L*"B`@("`O
M*BH*("`@("`J(%1H92!S;W5R8V4@55))(&%S('-E;G0@8GD@=&AE(&-L:65N
M="X@0V%N(&)E('5S960@=&\@:61E;G1I9GD*("`@("`J('1H92!C;&EE;G0[
M('1H92!S97-S:6]N(&ED(&ES(&-O;G-T<G5C=&5D(&UA:6YL>2!F<F]M('1H
M:7,*("`@("`J(&1A=&$N"B`@("`@*B\*("`@('9A<B`D7W-O=7)C955223L*
M"B`@("`O*BH*("`@("`J(#`@9F]R('-Y;F-M;"`Q+C`L(#$@9F]R('-Y;F-M
M;"`Q+C$N"B`@("`@*B\*("`@('9A<B`D7W9E<G-I;VX["@H@("`@+RHJ"B`@
M("`@*B!5<V5R;F%M92!U<V5D('1O(&%U=&@@=VET:"!T:&4@8F%C:V5N9"X*
M("`@("`J+PH@("`@=F%R("1?;&]C3F%M93L*"B`@("`O*BH*("`@("`J(%!A
M<W-W;W)D('5S960@=&\@875T:"!W:71H('1H92!B86-K96YD+@H@("`@("HO
M"B`@("!V87(@)%]P87-S=V]R9#L*"B`@("`O*BH*("`@("`J(%1R=64@;65A
M;G,@=&AA="!T:&ES('-E<W-I;VX@:&%S(&%U=&AE;G1I8V%T960@<W5C8V5S
M<V9U;&QY+@H@("`@("HO"B`@("!V87(@)%]I<T%U=&AO<FEZ960["@H@("`@
M+RHJ"B`@("`@*B!.86UE<W!A8V4@:6YF;W)M871I;VXN"B`@("`@*B\*("`@
M('9A<B`D7W5R:3L*"B`@("`O*BH*("`@("`J($YA;65S<&%C92!I;F9O<FUA
M=&EO;BX*("`@("`J+PH@("`@=F%R("1?=7)I365T83L*"B`@("`O*BH*("`@
M("`J($YA;65S<&%C92!I;F9O<FUA=&EO;BX*("`@("`J+PH@("`@=F%R("1?
M=7)I1&5V26YF.PH*("`@('9A<B`D7W=B>&UL.R`O+R!B;V]L96%N"@H@("`@
M=F%R("1?;6%X37-G4VEZ93L*"B`@("!V87(@)%]S>6YC<R`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`@*B!7<FET=&5N('1O(&1B(&%F=&5R('-U8V-E<W-F
M=6P@<WEN8RX*("`@("`J+PH@("`@=F%R("1?8VQI96YT06YC:&]R3F5X="`]
M(&%R<F%Y*"D["@H@("`@=F%R("1?<V5R=F5R06YC:&]R3&%S="`](&%R<F%Y
M*"D["@H@("`@+RHJ"B`@("`@*B!7<FET=&5N('1O(&1B(&%F=&5R('-U8V-E
M<W-F=6P@<WEN8RX*("`@("`J+PH@("`@=F%R("1?<V5R=F5R06YC:&]R3F5X
M="`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!3;6%L;"!H87-H('1O('-T
M;W)E('1H92!N=6UB97(@;V8@861D<RP@9&5L971E<RP@971C+B!D=7)I;F<@
M80H@("`@("H@<V5S<VEO;B!F;W(@8W)E871I;VX@;V8@<W5M;6%R>2!F;W(@
M;&]G9FEL92X*("`@("`J+PH@("`@=F%R("1?;&]G(#T@87)R87DH*3L*"B`@
M("`O*BH*("`@("`J(%1H92!3>6YC34Q?1&5V:6-E(&-L87-S(&1E9FEN960@
M:6X@1&5V:6-E+G!H<"X@5&AI<R!C;&%S<PH@("`@("H@:&%N9&QE<R!D96-I
M8V4@<W!E8VEF:6,@<W1U9F8N"B`@("`@*B\*("`@('9A<B`D7V1E=FEC93L*
M"B`@("`O*BH*("`@("`J($1E=FEC92!I;F9O('!R;W9I9&5D(&)Y('1H92!3
M>6YC34P@1&5V26YF(&1A=&$N($UA:6YL>2!U<V5D(&)Y"B`@("`@*B!T:&4@
M4WEN8TU,7T1E=FEC92!C;&%S<RX*("`@("`J+PH@("`@=F%R("1?9&5V:6-E
M26YF;SL*"B`@("`O*BH*("`@("`J($EF('=E(&%R92!E>'!E8W1I;F<@82!2
M97-U;'0@<&%C:V5T+"!T:&ES('-T;W)E<R!W:&5R92!T;PH@("`@("H@<F]U
M=&4@:70N"B`@("`@*B\*("`@('9A<B`D7V5X<&5C=&5D4F5S=6QT(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("`J($-R96%T97,@82!N97<@:6YS=&%N8V4@
M;V8@4WEN8TU,7U-T871E+@H@("`@("HO"B`@("!F=6YC=&EO;B!3>6YC34Q?
M4W1A=&4H)'-O=7)C955222P@)&QO8TYA;64L("1S97-S:6]N240L("1P87-S
M=V]R9"`](&9A;'-E*0H@("`@>PH@("`@("`@("1T:&ES+3YS9713;W5R8V55
M4DDH)'-O=7)C955222D["B`@("`@("`@)'1H:7,M/G-E=$QO8TYA;64H)&QO
M8TYA;64I.PH@("`@("`@("1T:&ES+3YS971397-S:6]N240H)'-E<W-I;VY)
M1"D["B`@("`@("`@:68@*"1P87-S=V]R9"D@>PH@("`@("`@("`@("`D=&AI
M<RT^<V5T4&%S<W=O<F0H)'!A<W-W;W)D*3L*("`@("`@("!]"@H@("`@("`@
M("1T:&ES+3YI<T%U=&AO<FEZ960@/2!F86QS93L*"B`@("`@("`@+R\@0W)E
M871E(&5M<'1Y(&1U;6UY(&1E=FEC92!I;F9O+B!7:6QL(&)E(')E<&QA8V5D
M('=I=&@@<F5A;`H@("`@("`@("\O($1E=DEN9B!I;F9O<FUA=&EO;B!I9B!T
M:&5Y(&%R92!T<F%N<V9E<G)E9"X*("`@("`@("`D=&AI<RT^7V1E=FEC94EN
M9F\@/2`F;F5W(%-Y;F--3%]$979I8V5);F9O*"D["@H@("`@("`@("\J(&%L
M;&]W('9E<GD@8FEG(&UE<W-A9V5S('5N;&5S<R!T;VQD(&]T:&5R=VES93H@
M*B\*("`@("`@("`D=&AI<RT^<V5T36%X37-G4VEZ92@Q,#`P,#`P,#`P*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!S971$979I8V5);F9O*"1D:2D*("`@('L*
M("`@("`@("`D=&AI<RT^7V1E=FEC94EN9F\@/2`D9&D["B`@("!]"@H@("`@
M9G5N8W1I;VX@9V5T1&5V:6-E26YF;R@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?9&5V:6-E26YF;SL*("`@('T*"B`@("!F=6YC=&EO;B!G971,
M;V-.86UE*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]L;V-.86UE
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%-O=7)C955222@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?<V]U<F-E55)).PH@("`@?0H*("`@(&9U
M;F-T:6]N(&=E=%1A<F=E=%5222@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?=&%R9V5T55)).PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%9E<G-I
M;VXH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W9E<G-I;VX["B`@
M("!]"@H@("`@9G5N8W1I;VX@9V5T37-G240H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7VUS9TE$.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=%="
M6$U,*"1W8GAM;"D*("`@('L*("`@("`@("`D=&AI<RT^7W=B>&UL(#T@)'=B
M>&UL.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES5T)834PH*0H@("`@>PH@("`@
M("`@(')E='5R;B`A96UP='DH)'1H:7,M/E]W8GAM;"D["B`@("!]"@H@("`@
M9G5N8W1I;VX@<V5T36%X37-G4VEZ92@D<RD*("`@('L*("`@("`@("`D=&AI
M<RT^7VUA>$US9U-I>F4@/2`D<SL*("`@('T*"B`@("!F=6YC=&EO;B!G971-
M87A-<V=3:7IE*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]M87A-
M<V=3:7IE.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T=&5R(&9O<B!P<F]P
M97)T>2!M<V=)1"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M<V=)
M1"`@3F5W('9A;'5E(&]F('!R;W!E<G1Y(&US9TE$+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!S971-<V=)1"@D;7-G240I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]M<V=)1"`]("1M<V=)1#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E='1E
M<B!F;W(@<')O<&5R='D@;&]C3F%M92X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1L;V-.86UE("!.97<@=F%L=64@;V8@<')O<&5R='D@;&]C3F%M
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T3&]C3F%M92@D;&]C3F%M92D*
M("`@('L*("`@("`@("`D=&AI<RT^7VQO8TYA;64@/2`D;&]C3F%M93L*("`@
M('T*"B`@("!F=6YC=&EO;B!S971087-S=V]R9"@D<&%S<W=O<F0I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]P87-S=V]R9"`]("1P87-S=V]R9#L*("`@('T*
M"B`@("!F=6YC=&EO;B!S9713;W5R8V554DDH)'-O=7)C955222D*("`@('L*
M("`@("`@("`D=&AI<RT^7W-O=7)C955222`]("1S;W5R8V554DD["B`@("!]
M"@H@("`@9G5N8W1I;VX@<V5T5&%R9V5T55))*"1T87)G97154DDI"B`@("![
M"B`@("`@("`@)'1H:7,M/E]T87)G97154DD@/2`D=&%R9V5T55)).PH@("`@
M?0H*("`@(&9U;F-T:6]N('-E=%9E<G-I;VXH)'9E<G-I;VXI"B`@("!["B`@
M("`@("`@)'1H:7,M/E]V97)S:6]N(#T@)'9E<G-I;VX["@H@("`@("`@(&EF
M("@D=F5R<VEO;B`]/2`P*2!["B`@("`@("`@("`@("1T:&ES+3Y?=7)I(#T@
M3D%-15]34$%#15]54DE?4UE.0TU,.PH@("`@("`@("`@("`D=&AI<RT^7W5R
M:4UE=&$@/2!.04U%7U-004-%7U5225]-151)3D8["B`@("`@("`@("`@("1T
M:&ES+3Y?=7)I1&5V26YF(#T@3D%-15]34$%#15]54DE?1$5624Y&.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?=7)I(#T@3D%-15]3
M4$%#15]54DE?4UE.0TU,7S%?,3L*("`@("`@("`@("`@)'1H:7,M/E]U<FE-
M971A(#T@3D%-15]34$%#15]54DE?345424Y&7S%?,3L*("`@("`@("`@("`@
M)'1H:7,M/E]U<FE$979);F8@/2!.04U%7U-004-%7U5225]$159)3D9?,5\Q
M.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!S971397-S:6]N240H
M)'-E<W-I;VY)1"D*("`@('L*("`@("`@("`D=&AI<RT^7W-E<W-I;VY)1"`]
M("1S97-S:6]N240["B`@("!]"@H@("`@9G5N8W1I;VX@:7-!=71H;W)I>F5D
M*"D*("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?:7-!=71H;W)I>F5D("8F
M("%E;7!T>2@D=&AI<RT^7W!A<W-W;W)D*2D@>PH@("`@("`@("`@("`D1TQ/
M0D%,4ULG8F%C:V5N9"==+3YL;V=-97-S86=E*"=C:&5C:VEN9R!A=71H(&9O
M<B!U<V5R/2<*("`@("`@("`@("`@+B`D=&AI<RT^7VQO8TYA;64L"B`@("`@
M("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*
M"B`@("`@("`@("`@("1A=71H(#T@)D%U=&@Z.G-I;F=L971O;B@D1TQ/0D%,
M4ULG8V]N9B==6R=A=71H)UU;)V1R:79E<B==*3L*("`@("`@("`@("`@)'1H
M:7,M/E]I<T%U=&AO<FEZ960@/2`D875T:"T^875T:&5N=&EC871E*"1T:&ES
M+3Y?;&]C3F%M92P@87)R87DH)W!A<W-W;W)D)R`]/B`D=&AI<RT^7W!A<W-W
M;W)D*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]I<T%U
M=&AO<FEZ960["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T4WEN8R@D=&%R9V5T
M+"`F)'-Y;F,I"B`@("!["B`@("`@("`@)'1H:7,M/E]S>6YC<ULD=&%R9V5T
M72`]("8D<WEN8SL*("`@('T*"B`@("!F=6YC=&EO;B`F9V5T4WEN8R@D=&%R
M9V5T*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W-Y;F-S6R1T
M87)G971=*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]S>6YC<ULD
M=&%R9V5T73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9F%L<V4@
M/2!F86QS93L*("`@("`@("`@("`@<F5T=7)N("1F86QS93L*("`@("`@("!]
M"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T55))*"D*("`@('L*("`@("`@("`O
M*@H@("`@("`@("`J(%1H92!N;VX@5T)834P@9&5V:6-E<R`H;F]T86)L>2!0
M.3`P(&%N9"!3>6YC-&H@<V5E;2!T;R!G970@8V]N9G5S960*("`@("`@("`@
M*B!B>2!A(#Q3>6YC34P@>&UL;G,](G-Y;F-M;#I364Y#34PQ+C$B/B!E;&5M
M96YT+B!4:&5Y(')E<75I<F4*("`@("`@("`@*B!J=7-T(#Q3>6YC34P^+B!3
M;R!D;VXG="!U<V4@86X@;G,@9F]R(&YO;B!W8GAM;"!D979I8V5S+@H@("`@
M("`@("`J+PH@("`@("`@(&EF("@D=&AI<RT^:7-70EA-3"@I*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7W5R:3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H@("`@?0H@("`@9G5N
M8W1I;VX@9V5T55))365T82@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?=7)I365T83L*("`@('T*"B`@("!F=6YC=&EO;B!G97154DE$979);F8H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W5R:41E=DEN9CL*("`@
M('T*"B`@("!F=6YC=&EO;B!S971#;&EE;G1!;F-H;W).97AT*"1T>7!E+"`D
M82D*("`@('L*("`@("`@("`D=&AI<RT^7V-L:65N=$%N8VAO<DYE>'1;)'1Y
M<&5=(#T@)&$["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T4V5R=F5R06YC:&]R
M3&%S="@D='EP92P@)&$I"B`@("!["B`@("`@("`@)'1H:7,M/E]S97)V97)!
M;F-H;W),87-T6R1T>7!E72`]("1A.PH@("`@?0H*("`@(&9U;F-T:6]N('-E
M=%-E<G9E<D%N8VAO<DYE>'0H)'1Y<&4L("1A*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?<V5R=F5R06YC:&]R3F5X=%LD='EP95T@/2`D83L*("`@('T*"B`@
M("!F=6YC=&EO;B!G971#;&EE;G1!;F-H;W).97AT*"1T>7!E*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7V-L:65N=$%N8VAO<DYE>'1;)'1Y<&5=
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%-E<G9E<D%N8VAO<DYE>'0H)'1Y
M<&4I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<V5R=F5R06YC:&]R
M3F5X=%LD='EP95T["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T4V5R=F5R06YC
M:&]R3&%S="@D='EP92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]S
M97)V97)!;F-H;W),87-T6R1T>7!E73L*("`@('T*"B`@("`O*BH*("`@("`J
M(%1H92!L;V<@<VEM<&QY(&-O=6YT<R!T:&4@96YT<FEE<R!F;W(@96%C:"!T
M;W!I8RX*("`@("`J+PH@("`@9G5N8W1I;VX@;&]G*"1T;W!I8RD*("`@('L*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]L;V=;)'1O<&EC72DI('L*("`@
M("`@("`@("`@)'1H:7,M/E]L;V=;)'1O<&EC72`K/2`Q.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?;&]G6R1T;W!I8UT@/2`Q.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%1H92!,;V<@:7,@86X@
M87)R87D@=VAE<F4@=&AE(&ME>2!I<R!T:&4@979E;G0@;F%M92!A;F0@=&AE
M"B`@("`@*B!V86QU92!S87ES(&AO=R!O9G1E;B!T:&ES(&5V96YT(&]C8W5R
M960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$QO9R@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?;&]G.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!A;B!I9&5N=&EF:65R('5S960@=&\@:61E;G1I9GD@=&AE('-Y
M;F,@9&5V:6-E(&EN('1H90H@("`@("H@;6%P+B!#=7)R96YT;'D@(FQO8VYA
M;64Z<V]U<F-E55))(BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4WEN8TED
M96YT:69I97(H*0H@("`@>PH@("`@("`@(')E='5R;B!S=')?<F5P;&%C92@G
M.B<L("=?)RP@)'1H:7,M/E]L;V-.86UE*0H@("`@("`@("`@("`@("`@+B`G
M.B<*("`@("`@("`@("`@("`@("X@<W1R7W)E<&QA8V4H)SHG+"`G7R<L("1T
M:&ES+3Y?<V]U<F-E55))*3L*("`@('T*"B`@("!F=6YC=&EO;B`F9V5T1&5V
M:6-E*"D*("`@('L*("`@("`@("!R971U<FX@4WEN8TU,7T1E=FEC93HZ<VEN
M9VQE=&]N*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!E
M>'!E8W1E9"!R97-U;'0@='EP92!F;W(@82!297-U;'1S('1A9RP@=7-E9"!T
M;R!R961I<F5C="!T:&4*("`@("`J(&EN8V]M:6YG(&-O;6UA;F0@<V]M97=H
M97)E('-P96-I86PN("!&;W(@97AA;7!L92P@:68@=V4@:&%V92!R97%U97-T
M960*("`@("`J(&1E=FEC92!I;F9O+"!T:&4@4F5S=6QT<R!T86<@<VAO=6QD
M(&)E('-E;G0@=&\@=&AE(%!U="!C;VUM86YD('-O('=E(&-A;@H@("`@("H@
M<F5A9"!I="!I;BX*("`@("`J"B`@("`@*B!#;&5A<G,@=&AE(&AA<V@@;V8@
M=&AI<R!#;VUM86YD(%)E9F5R96YC92!B969O<F4@<F5T=7)N:6YG(&$@=F%L
M=64N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-M9%)E9B`@5&AE
M($-M9%)E9B!O9B!T:&4@:6YC;VUI;F<@8V]M;6%N9"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O;6UA;F0@='EP92!T;R!R961I<F5C
M="!T;RP@;W(*("`@("`J("`@("`@("`@("`@("`@("!U;F1E9FEN960@:68@
M;F\@<F5D:7)E8W0@<F5G:7-T97)E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T17AP96-T961297-U;'14>7!E*"1C;612968I"B`@("!["B`@("`@("`@
M:68@*"!I<W-E="@D=&AI<RT^7V5X<&5C=&5D4F5S=6QT6R1C;612969=*2`I
M('L*("`@("`@("`@("`@)&-M9%1Y<&4@/2`D=&AI<RT^7V5X<&5C=&5D4F5S
M=6QT6R1C;612969=.PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^7V5X<&5C
M=&5D4F5S=6QT6R1C;612969=*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1C;614>7!E.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!U<"!A(&-O
M;6UA;F0@<F5D:7)E8W1I;VX@9F]R(&$@9G5T=7)E(%)E<W5L="!C;VUM86YD
M+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1C;61)1"`@("!4:&4@
M0VUD240@;V8@=&AE(&-O;6UA;F0@=V4@87)E('-E;F1I;F<@=&\*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@8VQI96YT+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`@)&-M9%1Y<&4@(%1H92!T>7!E(&]F(&-O;6UA;F0@
M=&\@<F5D:7)E8W0@=&\@=VAE;@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@('1H92!297-U;'1S(&-O;6UA;F0@:7,@<F5C96EV960N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=$5X<&5C=&5D4F5S=6QT5'EP92@D8VUD240L
M("1C;614>7!E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?97AP96-T961297-U
M;'1;)&-M9$E$72`]("1C;614>7!E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0VAE8VL@:68@=&AE<F4@87)E(&%N>2!P96YD:6YG(&5L96UE;G1S('1H870@
M:&%V92!N;W0@8F5E;B!S96YT('1O(&1U90H@("`@("H@=&\@;65S<V%G92!S
M:71Z92!R97-T<FEC=&EO;G,N(%1H97-E('=I;&P@8F4@<V5N="!I;G0@=&AE
M(&YE>'0@;7-G+@H@("`@("H*("`@("`J+PH@("`@9G5N8W1I;VX@:&%S4&5N
M9&EN9T5L96UE;G1S*"D*("`@('L*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1T
M:&ES+3Y?<WEN8W,I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?
M<WEN8W,@87,@)'-Y;F,I('L*("`@("`@("`@("`@("`@(&EF("@D<WEN8RT^
M:&%S4&5N9&EN9T5L96UE;G1S*"DI('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS(&%L;"!S>6YC<R!W:&EC:"!H879E('!E;F1I;F<@
M96QE;65N=',@;&5F="X*("`@("`J(%)E='5R;G,@86X@87)R87D@;V8@5&%R
M9V5T3&]C55))<R!W:&EC:"!C86X@8F4@=7-E9`H@("`@("H@87,@82!K97D@
M:6X@9V5T4WEN8R!C86QL<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&5N
M9&EN9U-Y;F-S*"D*("`@('L*("`@("`@("`D<B`](&%R<F%Y*"D["B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?<WEN8W,I*2!["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?<WEN8W,@87,@)'1A<F=E="`]/B`D<WEN8RD@
M>PH@("`@("`@("`@("`@("`@:68@*"1S>6YC+3YH87-096YD:6YG16QE;65N
M=',H*2D@>PH@("`@("`@("`@("`@("`@("`@("1R6UT@/2`D=&%R9V5T.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D<CL*("`@('T*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O4WEN8TU,
M+U-Y;F,N<&AP````````````````````````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#0P-C0S`#$P-3$U-#,S-S0T`#`R,3(R-0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E
M.B!F<F%M97=O<FLO4WEN8TU,+U-Y;F--3"]3>6YC+G!H<"QV(#$N."XT+CD@
M,C`P-B\P-2\P,2`Q,CHP-3HQ-"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#,M,C`P-B!!;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N8V]M
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@06YT:&]N>2!-:6QL<R`\
M86UI;&QS0'!Y<F%M:60V+F-O;3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J
M($!P86-K86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7U-Y;F,@>PH*("`@
M("\J*@H@("`@("H@5&%R9V5T.B!C;VYT86-T<RP@;F]T97,L(&-A;&5N9&%R
M+"!T87-K<RP*("`@("`J+PH@("`@=F%R("1?=&%R9V5T3&]C55)).R`O+R!T
M87)G970@;65A;G,@<V5R=F5R(&AE<F4*"B`@("!V87(@)%]S;W5R8V5,;V-5
M4DD[("\O('-O=7)C92!M96%N<R!C;&EE;G0@:&5R90H*("`@('9A<B`D7V%L
M97)T.PH*("`@("\J*@H@("`@("H@5')U92!I;F1I8V%T97,@=&AA="!T:&5R
M92!A<F4@<W1I;&P@<WEN8R!E;&5M96YT<R!T:&%T(&AA=F4@;F]T(&)E96X*
M("`@("`J('-E;G0@>65T(&1U92!T;R!M97-S86=E('-I>F4@;&EM:71A=&EO
M;G,@86YD(&AA=F4@=&\@8F4@<V5N="!I;B!T:&4@;F5X=`H@("`@("H@;65S
M<V%G92X*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@
M=F%R("1?<&5N9&EN9T5L96UE;G1S.PH*("`@("\J*@H@("`@("H@4F5M96UB
M97(@96YT<FEE<R!W92!H879E(&AA;F1L960@86QR96%D>3H@;VYC92!W92!S
M96YD(&$@9&5L971E(&9O<B!A;@H@("`@("H@96YT<GDL('=E(&1O;B=T('=A
M;G0@=&\@<V5N9"!A;B!A9&0@869T97)W87)D<RX@5&AI<R!A<G)A>2!I<R!A
M;'-O('5S960*("`@("`J(&EF(&$@<WEN8R!I<R!S96YT(&EN(&UU;'1I<&QE
M(&UE<W-A9V5S(&1U92!T;R!M97-S86=E('-I>F4@<F5S=')I8W1I;VYS+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?9&]N
M93L*"B`@("!F=6YC=&EO;B!3>6YC34Q?4WEN8R@D86QE<G0L("1S97)V97)5
M4DDL("1C;&EE;G154DDI"B`@("!["B`@("`@("`@)'1H:7,M/E]A;&5R="`]
M("1A;&5R=#L*("`@("`@("`D=&AI<RT^7W!E;F1I;F=%;&5M96YT<R`](&9A
M;'-E.PH@("`@("`@("1T:&ES+3Y?9&]N92`](&%R<F%Y*"D["B`@("`@("`@
M)'1H:7,M/E]T87)G971,;V-54DD@/2!B87-E;F%M92@D<V5R=F5R55))*3L*
M("`@("`@("`D=&AI<RT^7W-O=7)C94QO8U5222`]("1C;&EE;G154DD["B`@
M("`@("`@9VQO8F%L("1B86-K96YD.PH@("`@("`@("1B86-K96YD+3YL;V=-
M97-S86=E*")C<F5A=&4@9F]R('-Y;F-4>7!E/21S97)V97)54DDB+"!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($AE<F4G<R!W:&5R92!T:&4@86-T=6%L('!R;V-E<W-I;F<@
M;V8@82!C;&EE;G0M<V5N="!3>6YC"B`@("`@*B!)=&5M('1A:V5S('!L86-E
M+B!%;G1R:65S(&%R92!A9&1E9"P@9&5L971E9"!O<B!R97!L86-E9`H@("`@
M("H@9G)O;2!T:&4@<V5R=F5R(&1A=&%B87-E(&)Y('5S:6YG($AO<F1E($%0
M22`H4F5G:7-T<GDI(&-A;&QS+@H@("`@("HO"B`@("!F=6YC=&EO;B!H86YD
M;&53>6YC271E;2@D:71E;2D*("`@('L*("`@("`@("!G;&]B86P@)&)A8VME
M;F0["@H@("`@("`@("1S=&%T92`]("8D7U-%4U-)3TY;)U-Y;F--3"YS=&%T
M92==.PH@("`@("`@("1D979I8V4@/2`F)'-T871E+3YG971$979I8V4H*3L*
M("`@("`@("`D<WEN8TED96YT:69I97(@/2`D<W1A=&4M/F=E=%-Y;F-)9&5N
M=&EF:65R*"D["@H@("`@("`@("1H;W)D951Y<&4@/2`D='EP92`]("1T:&ES
M+3Y?=&%R9V5T3&]C55)).PH*("`@("`@("`O+R!5<V4@8V]N=&5N=%1Y<&4@
M97AP;&EC:71L>2!S<&5C:69I960@:6X@=&AI<R!S>6YC(&-O;6UA;F0N"B`@
M("`@("`@)&-O;G1E;G14>7!E(#T@)&ET96TM/F=E=$-O;G1E;G14>7!E*"D[
M"@H@("`@("`@("\O($EF(&YO="!P<F]V:61E9"P@=7-E(&1E9F%U;'0@9G)O
M;2!D979I8V4@:6YF;RX*("`@("`@("!I9B`H(21C;VYT96YT5'EP92D@>PH@
M("`@("`@("`@("`D8V]N=&5N=%1Y<&4@/2`D9&5V:6-E+3YG9710<F5F97)R
M961#;VYT96YT5'EP92@D='EP92D["B`@("`@("`@?0H*("`@("`@("!L:7-T
M*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I(#T*("`@("`@("`@("`@)&1E=FEC
M92T^8V]N=F5R=$-L:65N=#)397)V97(H)&ET96TM/F=E=$-O;G1E;G0H*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O
M;G1E;G14>7!E*3L*("`@("`@("`D8W5I9"`]("1I=&5M+3YG971#=6ED*"D[
M"B`@("`@("`@)'-U:60@/2!F86QS93L*"B`@("`@("`@+R\@2&%N9&QE(&-L
M:65N="!A9&0@<F5Q=65S=',N"B`@("`@("`@:68@*"1I=&5M+3YG971%;&5M
M96YT5'EP92@I(#T])T%D9"<I('L*("`@("`@("`@("`@)'-U:60@/2`D8F%C
M:V5N9"T^:6UP;W)T16YT<GDH)'-Y;F-)9&5N=&EF:65R+"`D:&]R9&54>7!E
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M8V]N=&5N="P@)&-O;G1E;G14>7!E+"`D8W5I9"D["B`@("`@("`@("`@(&EF
M("@A:7-?82@D<W5I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@)'-T871E+3YL;V<H(D-L:65N="U!9&0B*3L*("`@("`@("`@("`@("`@
M("1B86-K96YD+3YL;V=-97-S86=E*"=A9&1E9"!C;&EE;G0@96YT<GD@87,@
M)R`N("1S=6ED+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<W1A=&4M/FQO9R@B
M0VQI96YT+4%D9$9A:6QU<F4B*3L*("`@("`@("`@("`@("`@("1B86-K96YD
M+3YL;V=-97-S86=E*"=%<G)O<B!I;B!A9&1I;F<@8VQI96YT(&5N=')Y.B<@
M+B`D<W5I9"T^;65S<V%G92P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U]%4E(I.PH@("`@("`@("`@("!]"@H@("`@("`@("\O($AA;F1L92!C;&EE
M;G0@9&5L971E(')E<75E<W1S+@H@("`@("`@('T@96QS96EF("@D:71E;2T^
M9V5T16QE;65N=%1Y<&4H*2`]/2=$96QE=&4G*2!["B`@("`@("`@("`@("1S
M=6ED(#T@)&)A8VME;F0M/F1E;&5T945N=')Y*"1S>6YC261E;G1I9FEE<BP@
M)'1Y<&4L("1C=6ED*3L*("`@("`@("`@("`@:68@*"1T>7!E(#T]("=C86QE
M;F1A<B<*("`@("`@("`@("`@("`@("8F("1D979I8V4M/FAA;F1L951A<VMS
M26Y#86QE;F1A<B@I*2!["B`@("`@("`@("`@("`@("`O+R!D96QE=&5%;G1R
M>2!D;V5S(&YO="!N965D('1O(')E='5R;B!A;B!E<G)O<B!O;@H@("`@("`@
M("`@("`@("`@+R\@9&5L971I;VX@;V8@;F]N97AI<W1E;G0@96YT<FEE<RX@
M4V\@:G5S="!T;R!B92!S=7)E"B`@("`@("`@("`@("`@("`O+R!W92!H879E
M('1O(&1E;&5T92!F<F]M('1H92!T87-K<R!D871A8F%S92!A<R!W96QL.@H@
M("`@("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H)W-P96-I86P@
M=&%S:W,@9&5L971E("<@+B`D<W5I9"`N("<@9'5E('1O(&-L:65N="!R97%U
M97-T)RP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@
M("`@("`@("`@("`@("`D<W5I9"`]("1B86-K96YD+3YD96QE=&5%;G1R>2@D
M<WEN8TED96YT:69I97(L("=T87-K<R<L("1C=6ED*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!I9B`H(6ES7V$H)'-U:60L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@("1S=&%T92T^;&]G*")#;&EE;G0M1&5L971E
M(BD["B`@("`@("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G92@G9&5L
M971E9"!E;G1R>2`G("X@)'-U:60@+B`G(&1U92!T;R!C;&EE;G0@<F5Q=65S
M="<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'-T871E+3YL;V<H
M(D-L:65N="U$96QE=&5&86EL=7)E(BD["B`@("`@("`@("`@("`@("`D=&AI
M<RT^;&]G365S<V%G92@G1F%I;'5R92!D96QE=&EN9R!C;&EE;G0@96YT<GDL
M(&UA>6)E(&=O;F4@86QR96%D>2!O;B!S97)V97(N(&US9SHG+B`D<W5I9"T^
M;65S<V%G92P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@
M("`@("`@("`@("!]"@H@("`@("`@("\O($AA;F1L92!C;&EE;G0@<F5P;&%C
M92!R97%U97-T<RX*("`@("`@("!](&5L<V5I9B`H)&ET96TM/F=E=$5L96UE
M;G14>7!E*"D@/3T@)U)E<&QA8V4G*2!["B`@("`@("`@("`@("1S=6ED(#T@
M)&)A8VME;F0M/G)E<&QA8V5%;G1R>2@D<WEN8TED96YT:69I97(L("1H;W)D
M951Y<&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D8V]N=&5N="P@)&-O;G1E;G14>7!E+"`D8W5I9"D["@H@("`@("`@
M("`@("!I9B`H(6ES7V$H)'-U:60L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@("1S=&%T92T^;&]G*")#;&EE;G0M4F5P;&%C92(I.PH@("`@
M("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H)W)E<&QA8V5D(&5N
M=')Y("<@+B`D<W5I9"`N("<@9'5E('1O(&-L:65N="!R97%U97-T)RP@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G
M92@D<W5I9"T^;65S<V%G92P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U]$14)51RD["B`@("`@("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G
M92@D<W5I9"P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD[
M"@H@("`@("`@("`@("`@("`@+R\@16YT<GD@;6%Y(&AA=F4@8F5E;B!D96QE
M=&5D.R!T<GD@861D:6YG(&ET+@H@("`@("`@("`@("`@("`@)'-U:60@/2`D
M8F%C:V5N9"T^:6UP;W)T16YT<GDH)'-Y;F-)9&5N=&EF:65R+"`D:&]R9&54
M>7!E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&-O;G1E;G0L("1C;VYT96YT5'EP92P@)&-U:60I.PH@("`@("`@
M("`@("`@("`@:68@*"%I<U]A*"1S=6ED+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("`@("`@)'-T871E+3YL;V<H(D-L:65N="U!9&1297!L
M86-E(BD["B`@("`@("`@("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A
M9V4H)V%D9&5D(&-L:65N="!E;G1R>2!D=64@=&\@<F5P;&%C92!R97%U97-T
M(&%S("<@+B`D<W5I9"P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$
M14)51RD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1S=&%T92T^;&]G*")#;&EE;G0M061D1F%I;'5R92(I.PH@("`@
M("`@("`@("`@("`@("`@("1B86-K96YD+3YL;V=-97-S86=E*"=%<G)O<B!I
M;B!A9&1I;F<@8VQI96YT(&5N=')Y(&1U92!T;R!R97!L86-E(')E<75E<W0Z
M)R`N("1S=6ED+3YM97-S86=E+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T524BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G
M92@G56YE>'!E8W1E9"!E;&5M96YT5'EP93H@)R`N("1I=&5M+3YG971%;&5M
M96YT5'EP92@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'-U:60["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M<F5A=&5S(&$@)FQT.U-Y;F,F9W0[(&]U='!U="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@8W)E871E4WEN8T]U='!U="@D8W5R<F5N=$-M9$E$+"`F)&]U='!U
M="D*("`@('L*("`@("`@("`D<W1A=&4@/2`F)%]315-324].6R=3>6YC34PN
M<W1A=&4G73L*("`@("`@("`D871T<G,@/2!A<G)A>2@I.PH*("`@("`@("`D
M;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)U-Y;F,G
M+"`D871T<G,I.PH@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A
M=&4M/F=E=%5222@I+"`G0VUD240G+"`D871T<G,I.PH@("`@("`@("1O=71P
M=70M/F-H87)A8W1E<G,H)&-U<G)E;G1#;61)1"D["B`@("`@("`@)&-U<G)E
M;G1#;61)1"LK.PH@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E
M+3YG97154DDH*2P@)T-M9$E$)RD["@H@("`@("`@("1O=71P=70M/G-T87)T
M16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G5&%R9V5T)RP@)&%T=')S*3L*
M("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH
M*2P@)TQO8U5222<L("1A='1R<RD["B`@("`@("`@)&]U='!U="T^8VAA<F%C
M=&5R<R@D=&AI<RT^7W-O=7)C94QO8U5222D["B`@("`@("`@)&]U='!U="T^
M96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G3&]C55)))RD["B`@("`@
M("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G5&%R
M9V5T)RD["@H@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M
M/F=E=%5222@I+"`G4V]U<F-E)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T
M+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TQO8U5222<L("1A
M='1R<RD["B`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D=&AI<RT^7W1A
M<F=E=$QO8U5222D["B`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A
M=&4M/F=E=%5222@I+"`G3&]C55)))RD["B`@("`@("`@)&]U='!U="T^96YD
M16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G4V]U<F-E)RD["@H@("`@("`@
M("1S>6YC5'EP92`]("1T:&ES+3Y?=&%R9V5T3&]C55)).PH*("`@("`@("!G
M;&]B86P@)&)A8VME;F0["B`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H
M(FAA;F1L95-Y;F,@9F]R('-Y;F-4>7!E/21S>6YC5'EP92(L(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`O+R!(97)E
M)W,@=VAE<F4@<V5R=F5R(&UO9&EF:6-A=&EO;G,@87)E('-E;G0@=&\@=&AE
M(&-L:65N=#H*("`@("`@("`D<F5F=',@/2`D<W1A=&4M/F=E=%-E<G9E<D%N
M8VAO<DQA<W0H)'-Y;F-4>7!E*3L*("`@("`@("`D8W5R<F5N=$-M9$E$(#T@
M)'1H:7,M/FAA;F1L95-Y;F,H)&-U<G)E;G1#;61)1"P@)'-Y;F-4>7!E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;W5T
M<'5T+"`D<F5F=',I.PH*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S
M=&%T92T^9V5T55))*"DL("=3>6YC)RD["@H@("`@("`@(')E='5R;B`D8W5R
M<F5N=$-M9$E$.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5N9',@<V5R=F5R
M(&-H86YG97,@=&\@=&AE(&-L:65N="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M:&%N9&QE4WEN8R@D8W5R<F5N=$-M9$E$+"`D<WEN8U1Y<&4L("8D;W5T<'5T
M+"`D<F5F=',L("1E;F1?=',@/2`P*0H@("`@>PH@("`@("`@(&=L;V)A;"`D
M8F%C:V5N9#L*("`@("`@("!G;&]B86P@)&UE<W-A9V5&=6QL.PH*("`@("`@
M("`O*B`D;65S<V%G949U;&P@=VEL;"!B92!S970@=&\@=')U92!T;R!I;F1I
M8V%T92!T:&%T('1H97)E)W,@;F\@<F]O;0H@("`@("`@("`J(&9O<B!O=&AE
M<B!D871A(&EN('1H:7,@;65S<V%G92X@268@:70G<R!F86QS92`H96UP='DI
M(&%N9"!T:&5R90H@("`@("`@("`J(&%R92!P96YD:6YG(%-Y;F,@9&%T82P@
M=&AE(&9I;F%L(&-O;6UA;F0@=VEL;"!S96YT('1H92!P96YD:6YG(&1A=&$N
M"B`@("`@("`@("H@5&AI<R!G;&]B86P@9&%T82!S:&]U;&0@8F4@;6]V960@
M=&\@82!G;&]B86P@;V)J96-T+"!T;V=E=&AE<@H@("`@("`@("`J('=I=&@@
M8W5R<F5N=$-M9$E$(&%N9"`D;W5T<'5T+B`J+PH@("`@("`@("1M97-S86=E
M1G5L;"`](&9A;'-E.PH*("`@("`@("`D<W1A=&4@/2`F)%]315-324].6R=3
M>6YC34PN<W1A=&4G73L*("`@("`@("`D9&5V:6-E(#T@)B1S=&%T92T^9V5T
M1&5V:6-E*"D["B`@("`@("`@)'-Y;F-)9&5N=&EF:65R(#T@)'-T871E+3YG
M9713>6YC261E;G1I9FEE<B@I.PH@("`@("`@("1C;VYT96YT5'EP92`]("1D
M979I8V4M/F=E=%!R969E<G)E9$-O;G1E;G14>7!E0VQI96YT*"1S>6YC5'EP
M92P@)'1H:7,M/E]S;W5R8V5,;V-54DDI.PH*("`@("`@("`O*B!792!F86ET
M:&9U;&QY(&5X<&5C="!T;R!D96%L('=I=&@@86QL(')E;6%I;FEN9R!E;&5M
M96YT<RX@5VEL;"!B90H@("`@("`@("`J('-E="!T;R!T<G5E(&EF('=E(')U
M;B!O=70@;V8@<W!A8V4@9F]R(&UE<W-A9V4@8W)E871I;VXN("HO"B`@("`@
M("`@)'1H:7,M/G-E=%!E;F1I;F=%;&5M96YT<RAF86QS92D["@H@("`@("`@
M("\O($AA;F1L92!D96QE=&EO;G,N"B`@("`@("`@)&1E;&5T:6]N<R`]("1B
M86-K96YD+3YG971397)V97)$96QE=&EO;G,H)'-Y;F-)9&5N=&EF:65R+"`D
M<WEN8U1Y<&4L("1R969T<RP@)&5N9%]T<RD["@H@("`@("`@(&EF("@D<F5F
M=',@/B`P*2!["B`@("`@("`@("`@("\O($1O;B=T('-E;F0@9&5L971E<R!O
M;B!3;&]W4WEN8RX*("`@("`@("`@("`@9F]R96%C:"`H)&1E;&5T:6]N<R!A
M<R`D<W5I9"`]/B`D8W5I9"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]D
M;VYE6R1S=6ED72`]('1R=64["B`@("`@("`@("`@("`@("`D8F%C:V5N9"T^
M;&]G365S<V%G92@B9&5L971E.B!C=6ED/21C=6ED('-U:60])'-U:60@<F5F
M=',Z("1R969T<R(L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"
M54<I.PH@("`@("`@("`@("`@("`@+R\@0W)E871E(&$@1&5L971E(')E<75E
M<W0@9F]R(&-L:65N="X*("`@("`@("`@("`@("`@("1C=7)R96YT0VUD240@
M/2`D=&AI<RT^;W5T<'5T0V]M;6%N9"@D8W5R<F5N=$-M9$E$+"`D;W5T<'5T
M+"`G1&5L971E)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL+"`D8W5I9"P@;G5L;"D[
M"B`@("`@("`@("`@("`@("`D<W1A=&4M/FQO9R@G4V5R=F5R+41E;&5T92<I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("\O($AA;F1L92!A
M9&1I=&EO;G,N"B`@("`@("`@)&%D9',@/2`D8F%C:V5N9"T^9V5T4V5R=F5R
M061D:71I;VYS*"1S>6YC261E;G1I9FEE<BP@)'-Y;F-4>7!E+"`D<F5F=',L
M("1E;F1?=',I.PH@("`@("`@(&9O<F5A8V@@*"1A9&1S(&%S("1S=6ED(#T^
M("1C=6ED*2!["B`@("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]D;VYE
M6R1S=6ED72DI('L*("`@("`@("`@("`@("`@("\O($%L<F5A9'D@<V5N="!D
M96QE=&4L(&YO(&YE960@=&\@861D+@H@("`@("`@("`@("`@("`@8V]N=&EN
M=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE
M<W-A9V4H(F%D9#H@)'-U:60B+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T1%0E5'*3L*"B`@("`@("`@("`@("1C(#T@)&)A8VME;F0M/G)E=')I
M979E16YT<GDH)'-Y;F-4>7!E+"`D<W5I9"P@)&-O;G1E;G14>7!E*3L*("`@
M("`@("`@("`@:68@*"%I<U]A*"1C+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("`O+R!)=&5M(&EN(&AI<W1O<GD@8G5T(&YO="!I;B!D871A
M8F%S92X@4W1R86YG92P@8G5T(&-A;B!H87!P96XN"B`@("`@("`@("`@("`@
M("!L:7-T*"1C;&EE;G1#;VYT96YT+"`D8VQI96YT0V]N=&5N=%1Y<&4I(#T*
M("`@("`@("`@("`@("`@("`@("`D9&5V:6-E+3YC;VYV97)T4V5R=F5R,D-L
M:65N="@D8RP@)&-O;G1E;G14>7!E*3L*("`@("`@("`@("`@("`@("\O($-H
M96-K(&EF('=E(&AA=F4@<W!A8V4@;&5F="!I;B!T:&4@;65S<V%G92X*("`@
M("`@("`@("`@("`@(&EF("@H)'-T871E+3YG971-87A-<V=3:7IE*"D*("`@
M("`@("`@("`@("`@("`@("`M("1O=71P=70M/F=E=$]U='!U=%-I>F4H*0H@
M("`@("`@("`@("`@("`@("`@("T@<W1R;&5N*"1C;&EE;G1#;VYT96YT*2D@
M/"`U,"D@>PH@("`@("`@("`@("`@("`@("`@("1B86-K96YD+3YL;V=-97-S
M86=E*"=M87@@;65S<V%G92!S:7IE(')E86-H960@8W5R<VEZ93TG"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D;W5T<'5T
M+3YG971/=71P=713:7IE*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$
M14)51RD["B`@("`@("`@("`@("`@("`@("`@)&UE<W-A9V5&=6QL(#T@=')U
M93L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T4&5N9&EN9T5L96UE
M;G1S*'1R=64I.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D8W5R<F5N
M=$-M9$E$.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1H
M:7,M/E]D;VYE6R1S=6ED72`]('1R=64["B`@("`@("`@("`@("`@("`D8W5R
M<F5N=$-M9$E$(#T@)'1H:7,M/F]U='!U=$-O;6UA;F0H)&-U<G)E;G1#;61)
M1"P@)&]U='!U="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G061D)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8VQI96YT0V]N
M=&5N="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D8VQI96YT0V]N=&5N=%1Y<&4L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;G5L
M;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<W5I9"D["B`@("`@("`@("`@("`@("`D<W1A=&4M/FQO
M9R@G4V5R=F5R+4%D9"<I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H)V%P:2!E>'!O<G0@8V%L
M;"!F;W(@)R`N("1S=6ED("X@)R!F86EL960Z("`G("X@)&,M/F=E=$UE<W-A
M9V4H*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`O+R!(86YD;&4@8VAA;F=E<RX*("`@
M("`@("!I9B`H)')E9G1S("$](#`I('L*("`@("`@("`@("`@+R\@1&]N)W0@
M<V5N9"!C:&%N9V5S(&9O<B!3;&]W4WEN8RP@8V]N9G5S97,@<V]M92!C;&EE
M;G1S+@H@("`@("`@("`@("`D96YD7W1S(#T@=&EM92@I.PH@("`@("`@("`@
M("`D8VAA;F=E<R`]("1B86-K96YD+3YG971397)V97)-;V1I9FEC871I;VYS
M*"1S>6YC261E;G1I9FEE<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<WEN8U1Y<&4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)')E9G1S+"`D96YD7W1S*3L*("`@("`@("`@("`@:68@*&ES7V$H
M)&-H86YG97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1B
M86-K96YD+3YL;V=-97-S86=E*"1C:&%N9V5S+"!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@("`@("!R971U<FX@)&-H
M86YG97,["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&9O<F5A8V@@*"1C
M:&%N9V5S(&%S("1S=6ED(#T^("1C=6ED*2!["B`@("`@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1T:&ES+3Y?9&]N95LD<W5I9%TI*2!["B`@("`@("`@("`@
M("`@("`@("`@+R\@06QR96%D>2!S96YT(&1E;&5T92!O<B!A9&0L(&YO(&YE
M960@=&\@;6]D:69Y+@H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("@A)&-U:60I
M('L*("`@("`@("`@("`@("`@("`@("`O+R!43T1/.B!C<F5A=&4@86X@(F%D
M9"(@:&5R92!I;G-T96%D/PH@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1C(#T@)&)A
M8VME;F0M/G)E=')I979E16YT<GDH)'-Y;F-4>7!E+"`D<W5I9"P@)&-O;G1E
M;G14>7!E*3L*("`@("`@("`@("`@("`@(&EF("@A:7-?82@D8RP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@("1B86-K96YD+3YL;V=-
M97-S86=E*")C:&%N9V4Z("1S=6ED(BP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T1%0E5'*3L*("`@("`@("`@("`@("`@("`@("!L:7-T*"1C;&EE;G1#
M;VYT96YT+"`D8VQI96YT0V]N=&5N=%1Y<&4I(#T*("`@("`@("`@("`@("`@
M("`@("`@("`@)&1E=FEC92T^8V]N=F5R=%-E<G9E<C)#;&EE;G0H)&,L("1C
M;VYT96YT5'EP92D["B`@("`@("`@("`@("`@("`@("`@+R\@0VAE8VL@:68@
M=V4@:&%V92!S<&%C92!L969T(&EN('1H92!M97-S86=E+@H@("`@("`@("`@
M("`@("`@("`@(&EF("@H)'-T871E+3YG971-87A-<V=3:7IE*"D*("`@("`@
M("`@("`@("`@("`@("`@("`@("T@)&]U='!U="T^9V5T3W5T<'5T4VEZ92@I
M"B`@("`@("`@("`@("`@("`@("`@("`@("`M('-T<FQE;B@D8VQI96YT0V]N
M=&5N="DI(#P@-3`I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&)A8VME
M;F0M/FQO9TUE<W-A9V4H)VUA>"!M97-S86=E('-I>F4@<F5A8VAE9"!C=7)S
M:7IE/2<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+B`D;W5T<'5T+3YG971/=71P=713:7IE*"DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("`@("`@("`@
M("`@("`D;65S<V%G949U;&P@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T4&5N9&EN9T5L96UE;G1S*'1R=64I.PH@("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)&-U<G)E;G1#;61)1#L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D
M;VYE6R1S=6ED72`]('1R=64["B`@("`@("`@("`@("`@("`@("`@)&-U<G)E
M;G1#;61)1"`]("1T:&ES+3YO=71P=71#;VUM86YD*"1C=7)R96YT0VUD240L
M("1O=71P=70L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=297!L86-E)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&-L:65N=$-O;G1E;G0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;&EE;G1#;VYT96YT5'EP
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&-U:60L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PI.PH@("`@
M("`@("`@("`@("`@("`@("1S=&%T92T^;&]G*"=397)V97(M4F5P;&%C92<I
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`O+R!)=&5M(&EN(&AI<W1O<GD@8G5T(&YO="!I;B!D871A8F%S92X@4W1R
M86YG92P@8G5T"B`@("`@("`@("`@("`@("`@("`@+R\@8V%N(&AA<'!E;BX*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@+R\@268@=&%S:W,@87)E(&AA;F1L960@:6YS:61E(&-A;&5N9&%R
M+"!D;R!T:&4@<V%M92!A9V%I;B!F;W(*("`@("`@("`O+R!T87-K<RX*("`@
M("`@("!I9B`H)'-Y;F-4>7!E(#T]("=C86QE;F1A<B<@)B8@)&1E=FEC92T^
M:&%N9&QE5&%S:W-);D-A;&5N9&%R*"DI('L*("`@("`@("`@("`@)&)A8VME
M;F0M/FQO9TUE<W-A9V4H(FAA;F1L:6YG('1A<VMS(&EN(&-A;&5N9&%R('-Y
M;F,B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@("`@("1C
M=7)R96YT0VUD240@/2`D=&AI<RT^:&%N9&QE4WEN8R@D8W5R<F5N=$-M9$E$
M+"`G=&%S:W,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&]U='!U="P@)')E9G1S+"`D96YD7W1S*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D8W5R<F5N=$-M9$E$.PH@("`@?0H*("`@
M("\J*@H@("`@("H@3W5T<'5T(&$@<VEN9VQE(%-Y;F,@8V]M;6%N9"`H061D
M+"!$96QE=&4L(%)E<&QA8V4I+@H@("`@("HO"B`@("!F=6YC=&EO;B!O=71P
M=71#;VUM86YD*"1C=7)R96YT0VUD240L("8D;W5T<'5T+"`D8V]M;6%N9"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G0L("1C;VYT96YT
M5'EP92`](&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1C=6ED
M(#T@;G5L;"P@)'-U:60@/2!N=6QL*0H@("`@>PH@("`@("`@("1S=&%T92`]
M("8D7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==.PH*("`@("`@("`D871T<G,@
M/2!A<G)A>2@I.PH@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A
M=&4M/F=E=%5222@I+"`D8V]M;6%N9"P@)&%T=')S*3L*"B`@("`@("`@)&]U
M='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=#;61)1"<L
M("1A='1R<RD["B`@("`@("`@)&-H87)S(#T@)&-U<G)E;G1#;61)1#L*("`@
M("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@("`@)&]U
M='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G0VUD240G*3L*
M"B`@("`@("`@:68@*&ES<V5T*"1C;VYT96YT5'EP92DI('L*("`@("`@("`@
M("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=-
M971A)RP@)&%T=')S*3L*("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M
M96YT*"1S=&%T92T^9V5T55))365T82@I+"`G5'EP92<L("1A='1R<RD["B`@
M("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-O;G1E;G14>7!E*3L*
M("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%52
M24UE=&$H*2P@)U1Y<&4G*3L*("`@("`@("`@("`@)&]U='!U="T^96YD16QE
M;65N="@D<W1A=&4M/F=E=%5222@I+"`G365T82<I.PH@("`@("`@('T*"B`@
M("`@("`@:68@*&ES<V5T*"1C;VYT96YT*0H@("`@("`@("`@("!\?"!I<W-E
M="@D8W5I9"D@?'P@:7-S970H)'-U:60I*2!["B`@("`@("`@("`@("1O=71P
M=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G271E;2<L("1A
M='1R<RD["B`@("`@("`@("`@(&EF("@D<W5I9"`A/2!N=6QL*2!["B`@("`@
M("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG9715
M4DDH*2P@)U-O=7)C92<L("1A='1R<RD["B`@("`@("`@("`@("`@("`D;W5T
M<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TQO8U5222<L
M("1A='1R<RD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S
M*"1S=6ED*3L*("`@("`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H
M)'-T871E+3YG97154DDH*2P@)TQO8U5222<I.PH@("`@("`@("`@("`@("`@
M)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G4V]U<F-E
M)RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D8W5I9"`A/2!N
M=6QL*2!["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H
M)'-T871E+3YG97154DDH*2P@)U1A<F=E="<L("1A='1R<RD["B`@("`@("`@
M("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH
M*2P@)TQO8U5222<L("1A='1R<RD["B`@("`@("`@("`@("`@("`D;W5T<'5T
M+3YC:&%R86-T97)S*"1C=6ED*3L*("`@("`@("`@("`@("`@("1O=71P=70M
M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TQO8U5222<I.PH@("`@
M("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%52
M22@I+"`G5&%R9V5T)RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*&ES<V5T*"1C;VYT96YT*2D@>PH@("`@("`@("`@("`@("`@)&]U='!U="T^
M<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=$871A)RP@)&%T=')S
M*3L*("`@("`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-O;G1E
M;G0I.PH@("`@("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A
M=&4M/F=E=%5222@I+"`G1&%T82<I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TET
M96TG*3L*("`@("`@("!]"@H@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H
M)'-T871E+3YG97154DDH*2P@)&-O;6UA;F0I.PH*("`@("`@("`D8W5R<F5N
M=$-M9$E$*RL["@H@("`@("`@(')E='5R;B`D8W5R<F5N=$-M9$E$.PH@("`@
M?0H*("`@(&9U;F-T:6]N('-E=%!E;F1I;F=%;&5M96YT<R@D92D*("`@('L*
M("`@("`@("`D=&AI<RT^7W!E;F1I;F=%;&5M96YT<R`]("1E.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&AA<U!E;F1I;F=%;&5M96YT<R@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?<&5N9&EN9T5L96UE;G1S.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PN<&AP````
M````````````````````````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#$V
M-S(`,3`U,34T,S,W-3(`,#(P,S$S`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"@II;F-L=61E7V]N8V4@)U-Y;F--
M3"]#;VUM86YD+G!H<"<["FEN8VQU9&5?;VYC92`G4WEN8TU,+T-O;6UA;F0O
M4W1A='5S+G!H<"<["FEN8VQU9&5?;VYC92`G4WEN8TU,+T-O;6UA;F0O06QE
M<G0N<&AP)SL*:6YC;'5D95]O;F-E("=3>6YC34PO0V]M;6%N9"]3>6YC+G!H
M<"<["FEN8VQU9&5?;VYC92`G4WEN8TU,+T-O;6UA;F0O1FEN86PN<&AP)SL*
M:6YC;'5D95]O;F-E("=3>6YC34PO4WEN8RYP:'`G.PII;F-L=61E7V]N8V4@
M)U-Y;F--3"]"86-K96YD+G!H<"<["@HO*BH*("H@5&AE(%-Y;F--3%]3>6YC
M2&1R(&%N9"!3>6YC34Q?4WEN8T)O9'D@8VQA<W-E<R!P<F]V:61E<PH@*B!A
M(%-Y;F-(9'(@86YD(%-Y;F-";V1Y(&EN(%-Y;F--3"!297!R97-E;G1A=&EO
M;B!0<F]T;V-O;"P@=F5R<VEO;@H@*B`Q+C$@-2XR+C(@86YD(#4N,BXS+B`@
M36]S="!O9B!T:&4@=V]R:R!I<R!P87-S960@;VX@=&\*("H@4WEN8TU,7T-O
M;6UA;F1?06QE<G0@86YD(%-Y;F--3%]#;VUM86YD7U-Y;F,N"B`J"B`J(%1H
M97)E(&%R92!T=V\@9VQO8F%L(&]B:F5C=',@=&AA="!A<F4@=7-E9"!B>2!3
M>6YC34PZ"B`J(#$I("1?4T534TE/3ELG4WEN8TU,+G-T871E)UTZ"B`J("`@
M('-E<W-I;VX@;V)J96-T('5S960@=&\@;6%I;G1A:6X@=&AE('-T871E(&)E
M='=E96X@=&AE(&EN9&EV:61U86P*("H@("`@4WEN8TU,(&UE<W-A9V5S+@H@
M*@H@*B`R*2`D1TQ/0D%,4ULG8F%C:V5N9"=="B`J("`@($)A8VME;F0@=&\@
M:&%N9&QE('1H92!C;VUM=6YI8V%T:6]N('=I=&@@=&AE(&1A=&%S=&]R92X@
M0W5R<F5N=&QY('1H90H@*B`@("!H;W)D92!B86-K96YD(&ES('1H92!O;FQY
M(&)A8VME;F0@<')O=FED960N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-Y
M;F--3"]3>6YC34PN<&AP+'8@,2XR,2XQ,"XQ,"`R,#`V+S`Q+S`Q(#(Q.C(X
M.C,U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($%N=&AO
M;GD@36EL;',@/&%M:6QL<T!P>7)A;6ED-BYC;VT^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!!;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N
M8V]M/@H@*B!`875T:&]R("!+87)S=&5N($9O=7)M;VYT(#QF;W5R;6]N=$!G
M;7@N9&4^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!3>6YC
M34P*("HO"F-L87-S(%-Y;F--3%]#;VYT96YT2&%N9&QE<B!["@H@("`@+RHJ
M"B`@("`@*B!/=71P=70@0V]N=&5N=$AA;F1L97(@=7-E9"!T;R!O=71P=70@
M6$U,(&5V96YT<RX*("`@("`J"B`@("`@*B!`=F%R(&]B:F5C=`H@("`@("HO
M"B`@("!V87(@)%]O=71P=70["@H@("`@+RHJ"B`@("`@*B!3=&%C:R!F;W(@
M:&]L9&EN9R!T:&4@>&UL(&5L96UE;G1S(&1U<FEN9R!C<F5A=&EO;B!O9B!T
M:&4@;V)J96-T(&9R;VT*("`@("`J('1H92!X;6P@979E;G0@9FQO=RX*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7U-T86-K
M(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D7V-H87)S.PH*("`@(&9U;F-T:6]N('-E=$]U='!U="@F
M)&]U='!U="D*("`@('L*("`@("`@("`D=&AI<RT^7V]U='!U="`]("8D;W5T
M<'5T.PH@("`@?0H*("`@(&9U;F-T:6]N('-T87)T16QE;65N="@D=7)I+"`D
M96QE;65N="P@)&%T=')S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?4W1A8VM;
M72`]("1E;&5M96YT.PH@("`@?0H*("`@(&9U;F-T:6]N(&5N9$5L96UE;G0H
M)'5R:2P@)&5L96UE;G0I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?8VAA<G,I*2!["B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?8VAA<G,I
M.PH@("`@("`@('T*"B`@("`@("`@87)R87E?<&]P*"1T:&ES+3Y?4W1A8VLI
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&-H87)A8W1E<G,H)'-T<BD*("`@('L*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C:&%R<RDI('L*("`@("`@("`@
M("`@)'1H:7,M/E]C:&%R<R`]("1T:&ES+3Y?8VAA<G,@+B`D<W1R.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?8VAA<G,@/2`D<W1R
M.PH@("`@("`@('T*("`@('T*"GT*"@HO*BH*("H@1&5F:6YE9"!I;B!3>6YC
M34P@4F5P<F5S96YT871I;VX@4')O=&]C;VPL('9E<G-I;VX@,2XQ(#4N,BXR
M"B`J"B`J($!P86-K86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7U-Y;F--
M3$AD<B!E>'1E;F1S(%-Y;F--3%]#;VYT96YT2&%N9&QE<B!["@H@("`@+RHJ
M"B`@("`@*B!$969I;F5D(&EN(%-Y;F--3"!297!R97-E;G1A=&EO;B!0<F]T
M;V-O;"P@=F5R<VEO;B`Q+C$@-2XQ+CDN(%5S97(@;F%M92X*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]L;V-.86UE.PH*
M("`@("\J*@H@("`@("H@1&5F:6YE9"!I;B!3>6YC34P@4F5P<F5S96YT871I
M;VX@4')O=&]C;VPL('9E<G-I;VX@,2XQ(#4N,2XQ.`H@("`@("H*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W-E<W-I;VY)1#L*"B`@
M("`O*BH*("`@("`J($1E9FEN960@:6X@4WEN8TU,(%)E<')E<V5N=&%T:6]N
M(%!R;W1O8V]L+"!V97)S:6]N(#$N,2X@($UU<W0@8F4@,2XP("@P*0H@("`@
M("H@;W(@,2XQ("@Q*2X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)%]V97)S:6]N.PH*("`@("\J*@H@("`@("H@1&5F:6YE
M9"!I;B!3>6YC34P@4F5P<F5S96YT871I;VX@4')O=&]C;VPL('9E<G-I;VX@
M,2XQ(#4N,2XQ,@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7VUS9TE$.PH*("`@("\J*@H@("`@("H@1&5F:6YE9"!I;B!3
M>6YC34P@4F5P<F5S96YT871I;VX@4')O=&]C;VPL('9E<G-I;VX@,2XQ(#4N
M,2XQ,`H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D7W1A<F=E=%5223L*"B`@("`O*BH*("`@("`J($1E9FEN960@:6X@4WEN
M8TU,(%)E<')E<V5N=&%T:6]N(%!R;W1O8V]L+"!V97)S:6]N(#$N,2`U+C$N
M,3`L(#4N,2XR,`H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7W-O=7)C955223L*"B`@("!V87(@)%]C<F5D1&%T83L*"B`@
M("!V87(@)%]C<F5D1F]R;6%T.PH*("`@('9A<B`D7V-R9614>7!E.PH*("`@
M('9A<B`D7VUA>$US9U-I>F4["@H@("`@9G5N8W1I;VX@9V5T4W1A=&5&<F]M
M4V5S<VEO;B@D<V]U<F-E55))+"`D;&]C3F%M92P@)'-E<W-I;VY)1"D*("`@
M('L*("`@("`@("`D1TQ/0D%,4ULG8F%C:V5N9"==(#T@)FYE=R!3>6YC34Q?
M0F%C:V5N9%](;W)D92@I.PH*("`@("`@("`O+R!296QO860@=&AE($AO<F1E
M(%-E<W-I;VY(86YD;&5R(&EF(&YE8V5S<V%R>2X*("`@("`@("!(;W)D93HZ
M<V5T=7!397-S:6]N2&%N9&QE<B@I.PH*("`@("`@("`O+R!3>6YC34P@<')O
M=&]C;VP@9&]E<R!N;W0@<F5Q=6ER92!T:&4@8VQI96YT('1O('-E;F0@=&AE
M"B`@("`@("`@+R\@=7-E<FYA;64@;VX@86YY(&UE<W-A9V5S(&)U="!T:&4@
M9FER<W0N("!3;R!U;F9O<G1U;F%T96QY"B`@("`@("`@+R\@=V4@8V%N)W0@
M=7-E(&ET('1O(&UA:V4@82!U;FEQ=64@<V5S<VEO;B!I9"X*("`@("`@("!S
M97-S:6]N7VED*"=S>6YC;6PG("X@<')E9U]R97!L86-E*"<O6UYA+7I!+5HP
M+3E=+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G)RP@)'-O=7)C955222`N("1S97-S:6]N240I*3L*("`@("`@("!S
M97-S:6]N7W-T87)T*"D["@H@("`@("`@("\O($ET('=O=6QD('-E96T@;75L
M=&ES>6YC(&1O97,@;F]T('-E;F0@=&AE('5S97(@;F%M92!O;F-E(&ET"B`@
M("`@("`@+R\@:&%S(&)E96X@875T:&]R:7IE9"X@36%K92!S=7)E('=E(&AA
M=F4@82!V86QI9"!S97-S:6]N(&ED+@H@("`@("`@('-E<W-I;VY?:60H)W-Y
M;F-M;"<@+B!P<F5G7W)E<&QA8V4H)R];7F$M>D$M6C`M.5TO)RP@)R<L("1S
M;W5R8V554DD@+B`D<V5S<VEO;DE$*2D["B`@("`@("`@0'-E<W-I;VY?<W1A
M<G0H*3L*"B`@("`@("`@:68@*"%I<W-E="@D7U-%4U-)3TY;)U-Y;F--3"YS
M=&%T92==*2D@>PH@("`@("`@("`@("`O+R!#<F5A=&4@82!N97<@<W1A=&4@
M:68@;VYE(&1O97,@;F]T(&%L<F5A9'D@97AI<W0N"B`@("`@("`@("`@("1'
M3$]"04Q36R=B86-K96YD)UTM/FQO9TUE<W-A9V4H)TYE=R!S97-S:6]N(&-R
M96%T960Z("<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B!S97-S
M:6]N7VED*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`@("`@
M)%]315-324].6R=3>6YC34PN<W1A=&4G72`]("9N97<@4WEN8TU,7U-T871E
M*"1S;W5R8V554DDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D;&]C3F%M92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1S97-S:6]N240I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1'3$]"04Q36R=B86-K96YD)UTM/FQO9TUE<W-A9V4H)T5X:7-T:6YG('-E
M<W-I;VX@8V]N=&EN=65D.B`G"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("X@<V5S<VEO;E]I9"@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D7U-%4U-)3TY;)U-Y;F--3"YS=&%T
M92==.PH@("`@?0H*("`@(&9U;F-T:6]N('-T87)T16QE;65N="@D=7)I+"`D
M96QE;65N="P@)&%T=')S*0H@("`@>PH@("`@("`@('!A<F5N=#HZ<W1A<G1%
M;&5M96YT*"1U<FDL("1E;&5M96YT+"`D871T<G,I.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I"B`@("!["B`@("`@
M("`@<W=I=&-H("AC;W5N="@D=&AI<RT^7U-T86-K*2D@>PH@("`@("`@(&-A
M<V4@,3H*("`@("`@("`@("`@+R\@/"]3>6YC2&1R/CPO4WEN8TU,/@H@("`@
M("`@("`@("`O+R!&:6YD('1H92!S=&%T92X*("`@("`@("`@("`@)'-T871E
M(#T@)'1H:7,M/F=E=%-T871E1G)O;5-E<W-I;VXH)'1H:7,M/E]S;W5R8V55
M4DDL("1T:&ES+3Y?;&]C3F%M92P@)'1H:7,M/E]S97-S:6]N240I.PH*("`@
M("`@("`@("`@)'-T871E+3YS971697)S:6]N*"1T:&ES+3Y?=F5R<VEO;BD[
M"B`@("`@("`@("`@("1S=&%T92T^<V5T37-G240H)'1H:7,M/E]M<V=)1"D[
M"B`@("`@("`@("`@("1S=&%T92T^<V5T5&%R9V5T55))*"1T:&ES+3Y?=&%R
M9V5T55))*3L*("`@("`@("`@("`@)'-T871E+3YS971087-S=V]R9"@D=&AI
M<RT^7V-R961$871A*3L*("`@("`@("`@("`@)'-T871E+3YS97170EA-3"AI
M<U]A*"1T:&ES+3Y?;W5T<'5T+"`G6$U,7U="6$U,7T5N8V]D97(G*2D["@H@
M("`@("`@("`@("`O+R!3=&]R92!L;V=I;B!N86UE(&EN('-T871E(&EF(&YO
M="!A;')E861Y('-E=`H@("`@("`@("`@("!I9B`H96UP='DH)'-T871E+3Y?
M;&]C3F%M92D@)B8@(65M<'1Y*"1T:&ES+3Y?;&]C3F%M92DI('L*("`@("`@
M("`@("`@("`@("1S=&%T92T^<V5T3&]C3F%M92@D=&AI<RT^7VQO8TYA;64I
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M
M/E]M87A-<V=3:7IE*2D@>PH@("`@("`@("`@("`@("`@)'-T871E+3YS971-
M87A-<V=3:7IE*"1T:&ES+3Y?;6%X37-G4VEZ92D["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("1S='(@/2`G875T:&]R:7IE9#TG("X@)'-T871E+3YI
M<T%U=&AO<FEZ960H*2`N"B`@("`@("`@("`@("`@("`G('9E<G-I;VX])R`N
M("1S=&%T92T^9V5T5F5R<VEO;B@I("X*("`@("`@("`@("`@("`@("<@;7-G
M:60])R`N("1S=&%T92T^9V5T37-G240H*2`N"B`@("`@("`@("`@("`@("`G
M('-O=7)C93TG("X@)'-T871E+3YG9713;W5R8V554DDH*2`N"B`@("`@("`@
M("`@("`@("`G('1A<F=E=#TG("X@)'-T871E+3YG971487)G97154DDH*2`N
M"B`@("`@("`@("`@("`@("`G('5S97(])R`N("1S=&%T92T^9V5T3&]C3F%M
M92@I("X*("`@("`@("`@("`@("`@("<@8VAA<G-E=#TG("X@3DQ3.CIG971#
M:&%R<V5T*"D@+@H@("`@("`@("`@("`@("`@)R!W8GAM;#TG("X@)'-T871E
M+3YI<U="6$U,*"D*"B`@("`@("`@("`@("`@("`["@H@("`@("`@("`@("`D
M7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==(#T@)'-T871E.PH*("`@("`@("`@
M("`@)$=,3T)!3%-;)V)A8VME;F0G72T^;&]G365S<V%G92@D<W1R+"!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@("`@
M("\O($=O="!T:&4@<W1A=&4[(&YO=R!W<FET92!O=7(@4WEN8TAD<B!H96%D
M97(N"B`@("`@("`@("`@("1T:&ES+3YO=71P=713>6YC2&1R*"1T:&ES+3Y?
M;W5T<'5T*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@,CH*
M("`@("`@("`@("`@:68@*"1E;&5M96YT(#T]("=697)0<F]T;R<I('L*("`@
M("`@("`@("`@("`@("\O(#PO5F5R4')O=&\^/"]3>6YC2&1R/CPO4WEN8TU,
M/@H@("`@("`@("`@("`@("`@:68@*'1R:6TH)'1H:7,M/E]C:&%R<RD@/3T@
M)U-Y;F--3"\Q+C$G*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V
M97)S:6]N(#T@,3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]V97)S:6]N(#T@,#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?2!E;'-E:68@*"1E;&5M96YT(#T]("=397-S
M:6]N240G*2!["B`@("`@("`@("`@("`@("`O+R`\+U-E<W-I;VY)1#X\+U-Y
M;F-(9'(^/"]3>6YC34P^"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-E<W-I
M;VY)1"`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@('T@96QS
M96EF("@D96QE;65N="`]/2`G37-G240G*2!["B`@("`@("`@("`@("`@("`O
M+R`\+TUS9TE$/CPO4WEN8TAD<CX\+U-Y;F--3#X*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;7-G240@/2!I;G1V86PH=')I;2@D=&AI<RT^7V-H87)S*2D[
M"B`@("`@("`@("`@('T@96QS96EF("@D96QE;65N="`]/2`G0W)E9"<I('L*
M("`@("`@("`@("`@("`@("\O(#PO0W)E9#X\+U-Y;F-(9'(^/"]3>6YC34P^
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-R961$871A(#T@8F%S938T7V1E
M8V]D92@D=&AI<RT^7V-R961$871A*3L*"B`@("`@("`@("`@("`@("`D=&UP
M(#T@97AP;&]D92@G.B<L("1T:&ES+3Y?8W)E9$1A=&$I.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]L;V-.86UE(#T@)'1M<%LP73L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?8W)E9$1A=&$@/2`D=&UP6S%=.PH@("`@("`@("`@("`@
M("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-Y;F--3#H@<F5C96EV960@8W)E9&5N
M=&EA;',@9F]R('5S97(])PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`N("1T:&ES+3Y?;&]C3F%M92`L("=C<F5D
M/2<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+B`D=&AI<RT^7V-R961$871A+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@("`@('T*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&-A<V4@,SH*("`@("`@("`@("`@:68@*"1E
M;&5M96YT(#T]("=,;V-54DDG*2!["B`@("`@("`@("`@("`@("!I9B`H)'1H
M:7,M/E]3=&%C:ULQ72`]/2`G4V]U<F-E)RD@>PH@("`@("`@("`@("`@("`@
M("`@("\O(#PO3&]C55))/CPO4V]U<F-E/CPO4WEN8TAD<CX\+U-Y;F--3#X*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-O=7)C955222`]('1R:6TH
M)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'1H
M:7,M/E]3=&%C:ULQ72`]/2`G5&%R9V5T)RD@>PH@("`@("`@("`@("`@("`@
M("`@("\O(#PO3&]C55))/CPO5&%R9V5T/CPO4WEN8TAD<CX\+U-Y;F--3#X*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W1A<F=E=%5222`]('1R:6TH
M)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T@96QS96EF("@D96QE;65N="`]/2`G3&]C3F%M92<I('L*("`@("`@("`@
M("`@("`@(&EF("@D=&AI<RT^7U-T86-K6S%=(#T]("=3;W5R8V4G*2!["B`@
M("`@("`@("`@("`@("`@("`@+R\@/"],;V-.86UE/CPO4V]U<F-E/CPO4WEN
M8TAD<CX\+U-Y;F--3#X*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VQO
M8TYA;64@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!](&5L<V5I9B`H)&5L96UE;G0@/3T@)T1A=&$G*2![
M"B`@("`@("`@("`@("`@("`@("`@+R\@/"]$871A/CPO0W)E9#X\+U-Y;F-(
M9'(^/"]3>6YC34P^"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]3=&%C
M:ULQ72`]/2`G0W)E9"<I('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V-R961$871A(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?2!E;'-E:68@*"1E;&5M96YT(#T]("=-87A-
M<V=3:7IE)RD@>PH@("`@("`@("`@("`@("`@+R\@/"]-87A-<V=3:7IE/CPO
M365T83X\+U-Y;F-(9'(^/"]3>6YC34P^"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7VUA>$US9U-I>F4@/2!I;G1V86PH)'1H:7,M/E]C:&%R<RD["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@-#H*
M("`@("`@("`@("`@:68@*"1T:&ES+3Y?4W1A8VM;,5T@/3T@)T-R960G*2![
M"B`@("`@("`@("`@("`@("!I9B`H)&5L96UE;G0@/3T@)T9O<FUA="<I('L*
M("`@("`@("`@("`@("`@("`@("`O+R`\+T9O<FUA=#X\+TUE=&$^/"]#<F5D
M/CPO4WEN8TAD<CX\+U-Y;F--3#X*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V-R961&;W)M870@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*"1E;&5M96YT(#T]("=4>7!E)RD@>PH@("`@
M("`@("`@("`@("`@("`@("\O(#PO5'EP93X\+TUE=&$^/"]#<F5D/CPO4WEN
M8TAD<CX\+U-Y;F--3#X*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-R
M9614>7!E(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]
M"@H@("`@("`@('!A<F5N=#HZ96YD16QE;65N="@D=7)I+"`D96QE;65N="D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@;W5T<'5T4WEN8TAD<B@F)&]U='!U="D*
M("`@('L*("`@("`@("`D871T<G,@/2!A<G)A>2@I.PH*("`@("`@("`D<W1A
M=&4@/2`F)%]315-324].6R=3>6YC34PN<W1A=&4G73L*"B`@("`@("`@)'5R
M:2`]("1S=&%T92T^9V5T55))*"D["B`@("`@("`@)'5R:4UE=&$@/2`D<W1A
M=&4M/F=E=%5224UE=&$H*3L*"B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M
M96YT*"1U<FDL("=3>6YC2&1R)RP@)&%T=')S*3L*"B`@("`@("`@)&]U='!U
M="T^<W1A<G1%;&5M96YT*"1U<FDL("=697)$5$0G+"`D871T<G,I.PH@("`@
M("`@("1C:&%R<R`]("@D=&AI<RT^7W9E<G-I;VX@/3T@,2D@/R`G,2XQ)R`Z
M("<Q+C`G.PH@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*
M("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1U<FDL("=697)$5$0G*3L*
M"B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1U<FDL("=697)0<F]T
M;R<L("1A='1R<RD["B`@("`@("`@)&-H87)S(#T@*"1T:&ES+3Y?=F5R<VEO
M;B`]/2`Q*2`_("=3>6YC34PO,2XQ)R`Z("=3>6YC34PO,2XP)SL*("`@("`@
M("`D;W5T<'5T+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@("`@)&]U='!U
M="T^96YD16QE;65N="@D=7)I+"`G5F5R4')O=&\G*3L*"B`@("`@("`@)&]U
M='!U="T^<W1A<G1%;&5M96YT*"1U<FDL("=397-S:6]N240G+"`D871T<G,I
M.PH@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)'1H:7,M/E]S97-S:6]N
M240I.PH@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'5R:2P@)U-E<W-I
M;VY)1"<I.PH*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'5R:2P@
M)TUS9TE$)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S
M*"1T:&ES+3Y?;7-G240I.PH@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H
M)'5R:2P@)TUS9TE$)RD["@H@("`@("`@("1O=71P=70M/G-T87)T16QE;65N
M="@D=7)I+"`G5&%R9V5T)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YS
M=&%R=$5L96UE;G0H)'5R:2P@)TQO8U5222<L("1A='1R<RD["B`@("`@("`@
M)&]U='!U="T^8VAA<F%C=&5R<R@D=&AI<RT^7W-O=7)C955222D["B`@("`@
M("`@)&]U='!U="T^96YD16QE;65N="@D=7)I+"`G3&]C55)))RD["B`@("`@
M("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1U<FDL("=,;V-.86UE)RP@)&%T
M=')S*3L*("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1S=&%T92T^9V5T
M3&]C3F%M92@I*3L*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1U<FDL
M("=,;V-.86UE)RD["B`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D=7)I
M+"`G5&%R9V5T)RD["@H@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D
M=7)I+"`G4V]U<F-E)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YS=&%R
M=$5L96UE;G0H)'5R:2P@)TQO8U5222<L("1A='1R<RD["B`@("`@("`@)&]U
M='!U="T^8VAA<F%C=&5R<R@D=&AI<RT^7W1A<F=E=%5222D["B`@("`@("`@
M)&]U='!U="T^96YD16QE;65N="@D=7)I+"`G3&]C55)))RD["B`@("`@("`@
M)&]U='!U="T^96YD16QE;65N="@D=7)I+"`G4V]U<F-E)RD["@H@("`@("`@
M("\J"B`@("`@("`@1&\@;F]T('-E;F0@4F5S<%5222!%;&5M96YT+B!)="=S
M(&]P=&EO;F%L(&%N9"!M87D@8F4@;6ES;&5A9&EN9SH*("`@("`@("`D=&AI
M<RT^7W1A<F=E=%5222!I<R!D871A(&9R;VT@=&AE(&-L:65N="!A;F0@;F]T
M(&=U87)A;G1E960@=&\@8F4*("`@("`@("!T:&4@8V]R<F5C="!54DP@9F]R
M(&%C8V5S<RX@3&5T('1H92!C;&EE;G0@:G5S="!S=&%Y('=I=&@@=&AE('-A
M;64*("`@("`@("!54DP@:70@:&%S('5S960@9F]R('1H92!P<F5V:6]U<R!R
M97%U97-T*',I+@H@("`@("`@("HO"B`@("`@("`@+R\D;W5T<'5T+3YS=&%R
M=$5L96UE;G0H)'5R:2P@)U)E<W!54DDG+"`D871T<G,I.PH@("`@("`@("\O
M)&]U='!U="T^8VAA<F%C=&5R<R@D=&AI<RT^7W1A<F=E=%5222D["B`@("`@
M("`@+R\D;W5T<'5T+3YE;F1%;&5M96YT*"1U<FDL("=297-P55)))RD["@H@
M("`@("`@("\J"B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1U<FDL
M("=-971A)RP@)&%T=')S*3L*"B`@("`@("`@+R\@1'5M;7D@36%X($US<5-I
M>F4L('1H:7,@:7,@:G5S="!P=70@:6X@=&\@;6%K92!T:&4@<&%C:V5T"B`@
M("`@("`@+R\@=V]R:RP@:70@:7,@;F]T(&$@<F5A;"!V86QU92X*("`@("`@
M("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'5R:4UE=&$L("=-87A-<V=3:7IE
M)RP@)&%T=')S*3L*("`@("`@("`D8VAA<G,@/2`G-3`P,#`G.PH@("`@("`@
M("1O=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`D;W5T<'5T
M+3YE;F1%;&5M96YT*"1U<FE-971A+"`G36%X37-G4VEZ92<I.PH*("`@("`@
M("`O+R!$=6UM>2!-87A/8FI3:7IE+"!T:&ES(&ES(&IU<W0@<'5T(&EN('1O
M(&UA:V4@=&AE('!A8VME=`H@("`@("`@("\O('=O<FLL(&ET(&ES(&YO="!A
M(')E86P@=F%L=64N"B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1U
M<FE-971A+"`G36%X3V)J4VEZ92<L("1A='1R<RD["B`@("`@("`@)&-H87)S
M(#T@)S0P,#`P,#`G.PH@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-H
M87)S*3L*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1U<FE-971A+"`G
M36%X3V)J4VEZ92<I.PH*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1U
M<FDL("=-971A)RD["B`@("`@("`@*B\*"B`@("`@("`@)&]U='!U="T^96YD
M16QE;65N="@D=7)I+"`G4WEN8TAD<B<I.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&=E=%-O=7)C955222@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<V]U<F-E55)).PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$QO8TYA;64H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VQO8TYA;64["B`@("!]"@H@
M("`@9G5N8W1I;VX@9V5T4V5S<VEO;DE$*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]S97-S:6]N240["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M5F5R<VEO;B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=F5R<VEO
M;CL*("`@('T*"B`@("!F=6YC=&EO;B!G971-<V=)1"@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?;7-G240["B`@("!]"@H@("`@9G5N8W1I;VX@
M9V5T5&%R9V5T55))*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]T
M87)G97154DD["B`@("!]"@H@("`@9G5N8W1I;VX@;W!A<75E*"1O*0H@("`@
M>PH@("`@?0H*?0H*+RHJ"B`J($1E9FEN960@:6X@4WEN8TU,(%)E<')E<V5N
M=&%T:6]N(%!R;W1O8V]L+"!V97)S:6]N(#$N,2`U+C(N,PH@*@H@*B!`<&%C
M:V%G92!3>6YC34P*("HO"F-L87-S(%-Y;F--3%]3>6YC34Q";V1Y(&5X=&5N
M9',@4WEN8TU,7T-O;G1E;G1(86YD;&5R('L*"B`@("!V87(@)%]C=7)R96YT
M0VUD240@/2`Q.PH*("`@('9A<B`D7V-U<G)E;G1#;VUM86YD.PH*("`@('9A
M<B`D7V%C=&EO;D-O;6UA;F1S(#T@9F%L<V4["@H@("`@9G5N8W1I;VX@<W1A
M<G1%;&5M96YT*"1U<FDL("1E;&5M96YT+"`D871T<G,I"B`@("!["B`@("`@
M("`@<&%R96YT.CIS=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R
M<RD["@H@("`@("`@('-W:71C:"`H8V]U;G0H)'1H:7,M/E]3=&%C:RDI('L*
M("`@("`@("!C87-E(#$Z"B`@("`@("`@("`@("1S=&%T92`]("8D7U-%4U-)
M3TY;)U-Y;F--3"YS=&%T92==.PH*("`@("`@("`@("`@)'1H:7,M/E]A8W1I
M;VY#;VUM86YD<R`](&9A;'-E.R`O+R!S;R!F87(L('=E(&AA=F4@;F]T('-E
M96X@8V]M;6%N9',@=&AA="!R97%U:7)E(&%C=&EO;B!F<F]M(&]U<B!S:61E
M"@H@("`@("`@("`@("`O+R`\4WEN8TU,/CQ3>6YC0F]D>3X*("`@("`@("`@
M("`@)'5R:2`]("1S=&%T92T^9V5T55))*"D["B`@("`@("`@("`@("1T:&ES
M+3Y?;W5T<'5T+3YS=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R
M<RD["@H@("`@("`@("`@("`O+R!2:6=H="!O=7(@<W1A='5S(&%B;W5T('1H
M92!H96%D97(N"B`@("`@("`@("`@("1S=&%T=7,@/2`F;F5W(%-Y;F--3%]#
M;VUM86YD7U-T871U<R@H)'-T871E+3YI<T%U=&AO<FEZ960H*2D@/PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M4D534$].4T5?05542$5.5$E#051)3TY?04-#15!4140@.B!215-03TY315])
M3E9!3$E$7T-2141%3E1)04Q3+"`G4WEN8TAD<B<I.PH@("`@("`@("`@("`D
M<W1A='5S+3YS9713;W5R8V52968H)'-T871E+3YG9713;W5R8V554DDH*2D[
M"B`@("`@("`@("`@("1S=&%T=7,M/G-E=%1A<F=E=%)E9B@D<W1A=&4M/F=E
M=%1A<F=E=%5222@I*3L*("`@("`@("`@("`@)'-T871U<RT^<V5T0VUD4F5F
M*#`I.PH*("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT0VUD240@/2`D<W1A
M='5S+3YO=71P=70H)'1H:7,M/E]C=7)R96YT0VUD240L("1T:&ES+3Y?;W5T
M<'5T*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@,CH*("`@
M("`@("`@("`@+R\@/%-Y;F--3#X\4WEN8T)O9'D^/%M#;VUM86YD73X*("`@
M("`@("`@("`@)'1H:7,M/E]C=7)R96YT0V]M;6%N9"`](%-Y;F--3%]#;VUM
M86YD.CIF86-T;W)Y*"1E;&5M96YT*3L*("`@("`@("`@("`@)'1H:7,M/E]C
M=7)R96YT0V]M;6%N9"T^<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M96YT+"`D
M871T<G,I.PH*("`@("`@("`@("`@:68@*"1E;&5M96YT("$]("=3=&%T=7,G
M("8F("1E;&5M96YT("$]("=-87`G("8F("1E;&5M96YT("$]("=&:6YA;"<I
M('L*("`@("`@("`@("`@("`@("\O(%=E)W9E(&=O="!T;R!D;R!S;VUE=&AI
M;F<A(%1H:7,@8V%N)W0@8F4@=&AE(&QA<W0*("`@("`@("`@("`@("`@("\O
M('!A8VME="X*("`@("`@("`@("`@("`@("1T:&ES+3Y?86-T:6]N0V]M;6%N
M9',@/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`O+R`\4WEN8TU,/CQ3>6YC
M0F]D>3X\0V]M;6%N9#X\+BXN/@H@("`@("`@("`@("`D=&AI<RT^7V-U<G)E
M;G1#;VUM86YD+3YS=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R
M<RD["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*"B`@("!F
M=6YC=&EO;B!E;F1%;&5M96YT*"1U<FDL("1E;&5M96YT*0H@("`@>PH@("`@
M("`@('-W:71C:"`H8V]U;G0H)'1H:7,M/E]3=&%C:RDI('L*("`@("`@("!C
M87-E(#$Z"B`@("`@("`@("`@("\O(#PO4WEN8T)O9'D^/"]3>6YC34P^"B`@
M("`@("`@("`@("1S=&%T92`]("8D7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==
M.PH*("`@("`@("`@("`@:68@*"1S=&%T92T^:&%S4&5N9&EN9T5L96UE;G1S
M*"DI('L*("`@("`@("`@("`@("`@("\J('-T:6QL('-O;65T:&EN9R!T;R!D
M;SH@9&]N)W0@8VQO<V4@<V5S<VEO;B`J+PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]A8W1I;VY#;VUM86YD<R`]('1R=64["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)'1H:7,M/E]C=7)R96YT0VUD240@/2!3>6YC34Q?0V]M;6%N
M9%]&:6YA;#HZ;W5T<'5T1FEN86PH"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G1#;61)1"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T
M<'5T*3L*("`@("`@("`@("`@)'1H:7,M/E]O=71P=70M/F5N9$5L96UE;G0H
M)'5R:2P@)&5L96UE;G0I.PH*("`@("`@("`@("`@:68@*"$D=&AI<RT^7V%C
M=&EO;D-O;6UA;F1S*2!["B`@("`@("`@("`@("`@("`O+R!4:&ES('!A8VME
M="!D:60@;F]T(&-O;G1A:6X@86YY(')E86P@86-T:6]N<RP@:G5S=`H@("`@
M("`@("`@("`@("`@+R\@<W1A='5S(&%N9"!M87`N(%1H:7,@;65A;G,@=V4G
M<F4@9&]N92X@5&AE('-E<W-I;VX*("`@("`@("`@("`@("`@("\O(&-A;B!B
M92!C;&]S960@86YD('1H92!A;F-H;W)S('-A=F5D(&9O<B!T:&4@;F5X=`H@
M("`@("`@("`@("`@("`@+R\@<WEN8RX*("`@("`@("`@("`@("`@("1'3$]"
M04Q36R=B86-K96YD)UTM/FQO9TUE<W-A9V4H)W-Y;F,G("X@<V5S<VEO;E]I
M9"@I("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)R!C;VUP;&5T960@<W5C8V5S<V9U;&QY(2<@+@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G(%-T
M;W)I;F<@0VQI96YT+513("<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<W1A=&4M/E]C;&EE;G1!;F-H;W).
M97AT+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7TE.1D\I.PH@
M("`@("`@("`@("`@("`@)$=,3T)!3%-;)V)A8VME;F0G72T^=W)I=&53>6YC
M4W5M;6%R>2@*("`@("`@("`@("`@("`@("`@("`D<W1A=&4M/F=E=%-Y;F-)
M9&5N=&EF:65R*"DL"B`@("`@("`@("`@("`@("`@("`@)'-T871E+3Y?8VQI
M96YT06YC:&]R3F5X="P*("`@("`@("`@("`@("`@("`@("`D<W1A=&4M/E]S
M97)V97)!;F-H;W).97AT*3L*("`@("`@("`@("`@("`@("1L;V<@/2`D<W1A
M=&4M/F=E=$QO9R@I.PH@("`@("`@("`@("`@("`@)',@/2`G)SL*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1L;V<@87,@)&L@/3X@)'8I('L*("`@("`@
M("`@("`@("`@("`@("`D<R`N/2`B("1K/21V(CL*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1'3$]"04Q36R=B86-K96YD)UTM/FQO9TUE
M<W-A9V4H)U-U;6UA<GDZ)R`N("1S+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%
M05)?3$]'7TE.1D\I.PH*("`@("`@("`@("`@("`@("\O(%-E<W-I;VX@8V%N
M(&)E(&-L;W-E9"!H97)E+@H@("`@("`@("`@("`@("`@<V5S<VEO;E]U;G-E
M="@I.PH@("`@("`@("`@("`@("`@<V5S<VEO;E]D97-T<F]Y*"D["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG8F%C
M:V5N9"==+3YL;V=-97-S86=E*"=3>6YC34PZ(')E='5R;B!M97-S86=E(&-O
M;7!L971E9"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"
M54<I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E(#(Z"B`@("`@("`@("`@("\O(#PO6T-O;6UA;F1=/CPO4WEN8T)O
M9'D^/"]3>6YC34P^"B`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=$-O;6UA
M;F0M/F5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I.PH*("`@("`@("`@("`@
M)'1H:7,M/E]C=7)R96YT0VUD240@/2`D=&AI<RT^7V-U<G)E;G1#;VUM86YD
M+3YO=71P=70H)'1H:7,M/E]C=7)R96YT0VUD240L("1T:&ES+3Y?;W5T<'5T
M*3L*"B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?8W5R<F5N=$-O;6UA;F0I
M.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@+R\@/"\N+BX^/"];0V]M;6%N9%T^/"]3>6YC0F]D>3X\+U-Y;F--
M3#X*("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT0V]M;6%N9"T^96YD16QE
M;65N="@D=7)I+"`D96QE;65N="D["B`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@('T*"B`@("`@("`@<&%R96YT.CIE;F1%;&5M96YT*"1U<FDL("1E;&5M
M96YT*3L*("`@('T*"B`@("!F=6YC=&EO;B!C:&%R86-T97)S*"1S='(I"B`@
M("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8W5R<F5N=$-O;6UA;F0I
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=$-O;6UA;F0M/F-H87)A
M8W1E<G,H)'-T<BD["B`@("`@("`@?0H@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5&5S
M="YP:'``````````````````````````````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#4T-S,R`#$P-3$U-#,S-S4R`#`R,#`V-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`H*+RHJ"B`J($1E
M9FEN92!(3U)$15]"05-%+"!I9B!I="!I<R!N;W0@86QR96%D>2!S970L(&%N
M9"!I;F-L=61E('1H92!M86EN"B`J($AO<F1E(&QI8G)A<GDL('-I;F-E('=E
M(')E<75I<F4@:70@9F]R('1H:7,@<&%C:V%G92!T;R!F=6YC=&EO;BX*("HO
M"FEF("@A9&5F:6YE9"@G2$]21$5?0D%312<I*2!["B`@("!D969I;F4H)TA/
M4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXG*3L*?0IR97%U
M:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V-O<F4N<&AP)SL*"B\J*@H@
M*B!3970@=&AE('!A=&@@=&\@=&AE('1E;7!L871E<R!N965D960@9F]R('1E
M<W1I;F<@;W5T<'5T+@H@*B\*9&5F:6YE*"=415-47U1%35!,051%4R<L($A/
M4D1%7T)!4T4@+B`G+W1E;7!L871E<R]T97-T+R<I.PH*+RH@268@9V5T=&5X
M="!I<R!N;W0@;&]A9&5D+"!D969I;F4@82!D=6UM>2!?*"D@9G5N8W1I;VX@
M<V\@=&AA=`H@*B!I;F-L=61I;F<@86YY(&9I;&4@=VET:"!G971T97AT('-T
M<FEN9W,@=V]N)W0@8V%U<V4@82!F871A;"!E<G)O<BP*("H@8V%U<VEN9R!T
M97-T+G!H<"!T;R!R971U<FX@82!B;&%N:R!P86=E+B`J+PII9B`H(69U;F-T
M:6]N7V5X:7-T<R@G7R<I*2!["B`@("!F=6YC=&EO;B!?*"1S*2![(')E='5R
M;B`D<SL@?0I]"@HO*BH*("H@5&AE($AO<F1E7U1E<W0Z.B!C;&%S<R!P<F]V
M:61E<R!F=6YC=&EO;G,@=7-E9"!I;B!T:&4@=&5S="!S8W)I<'1S"B`J('5S
M960@:6X@=&AE('9A<FEO=7,@87!P;&EC871I;VYS("AT97-T+G!H<"DN"B`J
M"B`J("1(;W)D93H@:&]R9&4O;&EB+U1E<W0N<&AP+'8@,2XS,2XT+C$Y(#(P
M,#8O,#,O,C@@,3(Z,S$Z,3,@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q
M.3DY+3(P,#8@0VAA<FQE<R!*+B!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R
M9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($)R96YT($HN($YO<F1Q
M=6ES="`\8FIN0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-
M:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO
M;D!H;W)D92YO<F<^"B`J($!A=71H;W(@($)R96YT($HN($YO<F1Q=6ES="`\
M8FIN0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS
M;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!(;W)D
M92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?5&5S=`H@*B\*8VQA<W,@2&]R9&5?
M5&5S="!["@H@("`@+RHJ"B`@("`@*B!!<G)A>2!T:&%T(&AO;&1S('1H92!L
M:7-T(&]F($AO<F1E(&%P<&QI8V%T:6]N<RX*("`@("`J("A,;V%D960@9G)O
M;2!C;VYF:6<O<F5G:7-T<GDN<&AP*0H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1A<'!L:6-A=&EO;G,@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@0V%C:&5D(')E<W5L=',@;V8@9V5T07!P;&EC871I
M;VYS*"DN"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)%]A<'!O=71P=70@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@5&AE
M(%!(4"!V97)S:6]N(&]F('1H92!S>7-T96TN"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P:'!V97(["@H@("`@+RHJ"B`@
M("`@*B!#;VYS=')U8W1O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?
M5&5S="@I"B`@("!["B`@("`@("`@:6YC;'5D95]O;F-E($A/4D1%7T)!4T4@
M+B`G+V-O;F9I9R]R96=I<W1R>2YP:'`G.PH@("`@("`@(&MS;W)T*"1T:&ES
M+3YA<'!L:6-A=&EO;G,I.PH*("`@("`@("`O*B!3=&]R92!T:&4@4$A0('9E
M<G-I;VX@:6YF;W)M871I;VXN("HO"B`@("`@("`@)'1H:7,M/E]P:'!V97(@
M/2`D=&AI<RT^<W!L:7102%!697)S:6]N*'!H<'9E<G-I;VXH*2D["@H@("`@
M("`@("\J(%=E('=A;G0@=&\@8F4@87,@=F5R8F]S92!A<R!P;W-S:6)L92!H
M97)E+B`J+PH@("`@("`@(&5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["@H@("`@
M("`@("\J(%-E="!C:&%R86-T97(@96YC;V1I;F<N("HO"B`@("`@("`@:&5A
M9&5R*"=#;VYT96YT+71Y<&4Z('1E>'0O:'1M;#L@8VAA<G-E=#UU=&8M."<I
M.PH@("`@("`@(&AE861E<B@G5F%R>3H@06-C97!T+4QA;F=U86=E)RD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!087)S92!02%`@=F5R<VEO;BX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1V97)S:6]N("!!(%!(4"US='EL92!V
M97)S:6]N('-T<FEN9R`H6"Y8+E@I+@H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`@5&AE('!A<G-E9"!S=')I;F<N"B`@("`@*B`@("`@("`@("`@("`@
M($ME>7,Z("=M86IO<B<L("=M:6YO<B<L("=S=6)M:6YO<B<L("=C;&%S<R<*
M("`@("`J+PH@("`@9G5N8W1I;VX@<W!L:7102%!697)S:6]N*"1V97)S:6]N
M*0H@("`@>PH@("`@("`@("\J($9I<G-T('!I8VL@;V9F(&UA:F]R('9E<G-I
M;VXL(&%N9"!L;W=E<BUC87-E('1H92!R97-T+B`J+PH@("`@("`@(&EF("@H
M<W1R;&5N*"1V97)S:6]N*2`^/2`S*2`F)B`H)'9E<G-I;VY;,5T@/3T@)RXG
M*2D@>PH@("`@("`@("`@("`D<&AP=F5R6R=M86IO<B==(#T@<W5B<W1R*"1V
M97)S:6]N+"`P+"`S*3L*("`@("`@("`@("`@)'9E<G-I;VX@/2!S=6)S='(H
M<W1R=&]L;W=E<B@D=F5R<VEO;BDL(#,I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1P:'!V97);)VUA:F]R)UT@/2`D=F5R<VEO;CL*("`@("`@
M("`@("`@)'!H<'9E<ELG8VQA<W,G72`]("=U;FMN;W=N)SL*("`@("`@("`@
M("`@<F5T=7)N("1P:'!V97(["B`@("`@("`@?0H*("`@("`@("!I9B`H)'9E
M<G-I;VY;,%T@/3T@)RXG*2!["B`@("`@("`@("`@("1V97)S:6]N(#T@<W5B
M<W1R*"1V97)S:6]N+"`Q*3L*("`@("`@("!]"@H@("`@("`@("\J($YE>'0L
M(&1E=&5R;6EN92!I9B!T:&ES(&ES(#0N,&(@;W(@-"XP<F,[(&EF('-O+"!T
M:&5R92!I<R!N;PH@("`@("`@("`@(&UI;F]R+"!T:&4@<F5S="!I<R!T:&4@
M<W5B;6EN;W(L(&%N9"!C;&%S<R!I<R!S970@=&\@8F5T82X@*B\*("`@("`@
M("`D<R`]('-T<G-P;B@D=F5R<VEO;BP@)S`Q,C,T-38W.#DG*3L*("`@("`@
M("!I9B`H)',@/3T@,"D@>PH@("`@("`@("`@("`D<&AP=F5R6R=S=6)M:6YO
M<B==(#T@)'9E<G-I;VX["B`@("`@("`@("`@("1P:'!V97);)V-L87-S)UT@
M/2`G8F5T82<["B`@("`@("`@("`@(')E='5R;B`D<&AP=F5R.PH@("`@("`@
M('T*"B`@("`@("`@+RH@3W1H97)W:7-E+"!T:&ES(&ES(&YO;BUB971A.R`@
M=&AE(&YU;65R:6,@<&%R="!I<R!T:&4@;6EN;W(L"B`@("`@("`@("`@=&AE
M(')E<W0@:7,@96ET:&5R(&$@8VQA<W-I9FEC871I;VX@*&1E=BP@8W9S*2!O
M<B!A('-U8FUI;F]R"B`@("`@("`@("`@=F5R<VEO;B`H<F,\>#XL('!L/'@^
M*2X@*B\*("`@("`@("`D<&AP=F5R6R=M:6YO<B==(#T@<W5B<W1R*"1V97)S
M:6]N+"`P+"`D<RD["B`@("`@("`@:68@*"AS=')L96XH)'9E<G-I;VXI(#X@
M)',I("8F"B`@("`@("`@("`@("@H)'9E<G-I;VY;)'-=(#T]("<N)RD@?'P@
M*"1V97)S:6]N6R1S72`]/2`G+2<I*2D@>PH@("`@("`@("`@("`D<RLK.PH@
M("`@("`@('T*("`@("`@("`D<&AP=F5R6R=S=6)M:6YO<B==(#T@<W5B<W1R
M*"1V97)S:6]N+"`D<RD["B`@("`@("`@:68@*"@D<&AP=F5R6R=S=6)M:6YO
M<B==(#T]("=C=G,G*2!\?`H@("`@("`@("`@("`H)'!H<'9E<ELG<W5B;6EN
M;W(G72`]/2`G9&5V)RD@?'P*("`@("`@("`@("`@*'-U8G-T<B@D<&AP=F5R
M6R=S=6)M:6YO<B==+"`P+"`R*2`]/2`G<F,G*2D@>PH@("`@("`@("`@("!U
M;G-E="@D<&AP=F5R6R=S=6)M:6YO<B==*3L*("`@("`@("`@("`@)'!H<'9E
M<ELG8VQA<W,G72`]("=D978G.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(&EF("@A)'!H<'9E<ELG<W5B;6EN;W(G72D@>PH@("`@("`@("`@("`@
M("`@=6YS970H)'!H<'9E<ELG<W5B;6EN;W(G72D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)'!H<'9E<ELG8VQA<W,G72`]("=R96QE87-E)SL*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D<&AP=F5R.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0VAE8VL@=&AE(&QI<W0@;V8@4$A0(&UO9'5L97,N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1M;V1L:7-T("!4:&4@;6]D=6QE(&QI
M<W0N"B`@("`@*B`\<')E/@H@("`@("H@2T59.B`@(&UO9'5L92!N86UE"B`@
M("`@*B!604Q513H@16ET:&5R('1H92!D97-C<FEP=&EO;B!O<B!A;B!A<G)A
M>2!W:71H('1H92!F;VQL;W=I;F<@96YT<FEE<SH*("`@("`J("`@("`@("`G
M9&5S8W)I<"<@("TM("!-;V1U;&4@1&5S8W)I<'1I;VX*("`@("`J("`@("`@
M("`G97)R;W(G("`@("TM("!%<G)O<B!-97-S86=E"B`@("`@*B`@("`@("`@
M)W!H<'9E<B<@("`M+2`@5&AE(%!(4"!V97)S:6]N(&%B;W9E('=H:6-H('1O
M(&1O('1H92!T97-T"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE($A434P@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!P:'!-;V1U;&5#:&5C:R@D;6]D;&ES="D*("`@('L*("`@("`@("`D
M;W5T<'5T(#T@)R<["B`@("`@("`@)&]U='!U=%]A<G)A>2`](&%R<F%Y*"D[
M"@H@("`@("`@(&9O<F5A8V@@*"1M;V1L:7-T(&%S("1K97D@/3X@)'9A;"D@
M>PH@("`@("`@("`@("`D97)R;W)?;7-G(#T@)&UO9%]T97-T(#T@)'-T871U
M<U]O=70@/2`D9F%T86P@/2!N=6QL.PH@("`@("`@("`@("`D96YT<GD@/2!A
M<G)A>2@I.PH*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1V86PI*2!["B`@
M("`@("`@("`@("`@("`D9&5S8W)I<"`]("1V86Q;)V1E<V-R:7`G73L*("`@
M("`@("`@("`@("`@("1F871A;"`]("%E;7!T>2@D=F%L6R=F871A;"==*3L*
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=F%L6R=P:'!V97(G72D@)B8*
M("`@("`@("`@("`@("`@("`@("`H=F5R<VEO;E]C;VUP87)E*'!H<'9E<G-I
M;VXH*2P@)'9A;%LG<&AP=F5R)UTI(#T]("TQ*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1M;V1?=&5S="`]('1R=64["B`@("`@("`@("`@("`@("`@("`@
M)'-T871U<U]O=70@/2`G3B]!)SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D=F%L6R=E<G)O<B==*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1E<G)O<E]M<V<@/2`D=F%L6R=E<G)O<B==.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)&1E<V-R:7`@/2`D=F%L.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!I9B`H:7-?;G5L;"@D<W1A='5S7V]U="DI('L*("`@("`@("`@("`@
M("`@("1M;V1?=&5S="`](&5X=&5N<VEO;E]L;V%D960H)&ME>2D["B`@("`@
M("`@("`@("`@("`D<W1A='5S7V]U="`]("1T:&ES+3Y?<W1A='5S*"1M;V1?
M=&5S="P@)&9A=&%L*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&5N
M=')Y6UT@/2`D9&5S8W)I<#L*("`@("`@("`@("`@)&5N=')Y6UT@/2`D<W1A
M='5S7V]U=#L*"B`@("`@("`@("`@(&EF("@A:7-?;G5L;"@D97)R;W)?;7-G
M*2`F)B`A)&UO9%]T97-T*2!["B`@("`@("`@("`@("`@("`D96YT<GE;72`]
M("1E<G)O<E]M<V<["B`@("`@("`@("`@("`@("!I9B`H(21F871A;"D@>PH@
M("`@("`@("`@("`@("`@("`@("1E;G1R>5M=(#T@,3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&]U='!U="`N/2`D
M=&AI<RT^7V]U='!U=$QI;F4H)&5N=')Y*3L*"B`@("`@("`@("`@(&EF("@D
M9F%T86P@)B8@(21M;V1?=&5S="D@>PH@("`@("`@("`@("`@("`@96-H;R`D
M;W5T<'5T.PH@("`@("`@("`@("`@("`@97AI=#L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O=71P=70["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#:&5C:W,@=&AE(&QI<W0@;V8@4$A0('-E='1I;F=S+@H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D;6]D;&ES="`@5&AE('-E='1I
M;F=S(&QI<W0N"B`@("`@*B`\8V]D93X*("`@("`J($M%63H@("!S971T:6YG
M(&YA;64*("`@("`J(%9!3%5%.B!!;B!A<G)A>2!W:71H('1H92!F;VQL;W=I
M;F<@96YT<FEE<SH*("`@("`J("`@("`@("`G97)R;W(G("`@("TM("!%<G)O
M<B!-97-S86=E"B`@("`@*B`@("`@("`@)W-E='1I;F<G("`M+2`@0F]O;&5A
M;B`M('-H;W5L9"!T:&4@<V5T=&EN9R!B92!O;B!O<B!O9F8*("`@("`J(#PO
M8V]D93X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($A434P@
M;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!P:'!3971T:6YG0VAE8VLH
M)'-E='1I;F=S7VQI<W0I"B`@("!["B`@("`@("`@)&]U='!U="`]("<G.PH*
M("`@("`@("!F;W)E86-H("@D<V5T=&EN9W-?;&ES="!A<R`D:V5Y(#T^("1V
M86PI('L*("`@("`@("`@("`@)&5N=')Y(#T@87)R87DH*3L*("`@("`@("`@
M("`@)')E<W5L="`]("AI;FE?9V5T*"1K97DI(#T]("1V86Q;)W-E='1I;F<G
M72D["@H@("`@("`@("`@("`D96YT<GE;72`]("1K97D@+B`G("<@+B`H*"1V
M86Q;)W-E='1I;F<G72`]/3T@=')U92D@/R`G96YA8FQE9"<@.B`G9&ES86)L
M960G*3L*("`@("`@("`@("`@)&5N=')Y6UT@/2`D=&AI<RT^7W-T871U<R@D
M<F5S=6QT*3L*"B`@("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@
M("`@("`@("`@)&5N=')Y6UT@/2`D=F%L6R=E<G)O<B==.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D;W5T<'5T("X]("1T:&ES+3Y?;W5T<'5T3&EN
M92@D96YT<GDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O=71P=70[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:R!T:&4@;&ES="!O9B!014%2
M(&UO9'5L97,N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P96%R7VQI
M<W0@(%1H92!014%2(&UO9'5L92!L:7-T+@H@("`@("H@/'!R93X*("`@("`J
M($M%63H@("!014%2(&-L87-S(&YA;64*("`@("`J(%9!3%5%.B!!;B!A<G)A
M>2!W:71H('1H92!F;VQL;W=I;F<@96YT<FEE<SH*("`@("`J("`@("`@("`G
M9&5P96YD<R<@("`M+2`@5&AI<R!M;V1U;&4@9&5P96YD<R!O;B!A;F]T:&5R
M(&UO9'5L90H@("`@("H@("`@("`@("=E<G)O<B<@("`@("TM("!%<G)O<B!-
M97-S86=E"B`@("`@*B`@("`@("`@)V9U;F-T:6]N)R`@+2T@(%)E9F5R96YC
M92!T;R!F=6YC=&EO;B!T;R!R=6X@:68@;6]D=6QE(&ES(&9O=6YD"B`@("`@
M*B`@("`@("`@)W!A=&@G("`@("`@+2T@(%1H92!P871H('1O('1H92!014%2
M(&UO9'5L90H@("`@("H@("`@("`@("=R97%U:7)E9"<@("TM("!)<R!T:&ES
M(%!%05(@;6]D=6QE(')E<75I<F5D/R`H8F]O;&5A;BD*("`@("`J(#PO<')E
M/@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@2%1-3"!O=71P
M=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(%!%05)-;V1U;&5#:&5C:R@D<&5A
M<E]L:7-T*0H@("`@>PH@("`@("`@("1O=71P=70@/2`G)SL*"B`@("`@("`@
M+RH@5'5R;B!T<F%C:VEN9R!O9B!E<G)O<G,@;VXN("HO"B`@("`@("`@:6YI
M7W-E="@G=')A8VM?97)R;W)S)RP@,2D["@H@("`@("`@("\J(%!R:6YT('1H
M92!I;F-L=61E7W!A=&@N("HO"B`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^
M7V]U='!U=$QI;F4H87)R87DH(CQS=')O;F<^4$5!4B!396%R8V@@4&%T:"`H
M4$A0)W,@:6YC;'5D95]P871H*3PO<W1R;VYG/B(L("<F;F)S<#L\='0^)R`N
M(&EN:5]G970H)VEN8VQU9&5?<&%T:"<I("X@)SPO='0^)RDI.PH*("`@("`@
M("`O*B!#:&5C:R!F;W(@4$5!4B!I;B!G96YE<F%L+B`J+PH@("`@("`@('L*
M("`@("`@("`@("`@)&5N=')Y(#T@87)R87DH*3L*("`@("`@("`@("`@)&5N
M=')Y6UT@/2`G4$5!4B<["B`@("`@("`@("`@($!I;F-L=61E7V]N8V4@)U!%
M05(N<&AP)SL*("`@("`@("`@("`@)&5N=')Y6UT@/2`D=&AI<RT^7W-T871U
M<R@A:7-S970H)'!H<%]E<G)O<FUS9RDI.PH@("`@("`@("`@("!I9B`H:7-S
M970H)'!H<%]E<G)O<FUS9RDI('L*("`@("`@("`@("`@("`@("1E;G1R>5M=
M(#T@)T-H96-K('EO=7(@4$A0(&EN8VQU9&5?<&%T:"!S971T:6YG('1O(&UA
M:V4@<W5R92!I="!H87,@=&AE(%!%05(@;&EB<F%R>2!D:7)E8W1O<GDN)SL*
M("`@("`@("`@("`@("`@("1O=71P=70@+CT@)'1H:7,M/E]O=71P=71,:6YE
M*"1E;G1R>2D["B`@("`@("`@("`@("`@("!I;FE?<F5S=&]R92@G=')A8VM?
M97)R;W)S)RD["B`@("`@("`@("`@("`@("!R971U<FX@)&]U='!U=#L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D;W5T<'5T("X]("1T:&ES+3Y?;W5T
M<'5T3&EN92@D96YT<GDI.PH@("`@("`@('T*"B`@("`@("`@+RH@0VAE8VL@
M9F]R(&$@<F5C96YT(%!%05(@=F5R<VEO;BX@*B\*("`@("`@("`D96YT<GD@
M/2!A<G)A>2@I.PH@("`@("`@("1N97=P96%R(#T@)'1H:7,M/FES4F5C96YT
M4$5!4B@I.PH@("`@("`@("1E;G1R>5M=(#T@)U)E8V5N="!014%2)SL*("`@
M("`@("`D96YT<GE;72`]("1T:&ES+3Y?<W1A='5S*"1N97=P96%R*3L*("`@
M("`@("!I9B`H(21N97=P96%R*2!["B`@("`@("`@("`@("1E;G1R>5M=(#T@
M)U1H:7,@=F5R<VEO;B!O9B!014%2(&ES(&YO="!R96-E;G0@96YO=6=H+B!3
M964@=&AE(#QA(&AR968](FAT='`Z+R]W=W<N:&]R9&4N;W)G+W!E87(O(CY(
M;W)D92!014%2('!A9V4\+V$^(&9O<B!D971A:6QS+B<["B`@("`@("`@?0H@
M("`@("`@("1O=71P=70@+CT@)'1H:7,M/E]O=71P=71,:6YE*"1E;G1R>2D[
M"@H@("`@("`@("\J($=O('1H<F]U9V@@;6]D=6QE(&QI<W0N("HO"B`@("`@
M("`@)'-U8V-E961E9"`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'!E
M87)?;&ES="!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@)&5N=')Y
M(#T@87)R87DH*3L*"B`@("`@("`@("`@("\J($EF('1H:7,@;6]D=6QE(&1E
M<&5N9',@;VX@86YO=&AE<B!M;V1U;&4@=&AA="!W90H@("`@("`@("`@("`@
M*B!H879E;B=T('-U8V-E<V9U;&QY(&9O=6YD+"!F86EL('1H92!T97-T+B`J
M+PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1V86Q;)V1E<&5N9',G72D@)B8@
M96UP='DH)'-U8V-E961E9%LD=F%L6R=D97!E;F1S)UU=*2D@>PH@("`@("`@
M("`@("`@("`@)')E<W5L="`](&9A;'-E.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)')E<W5L="`]($!I;F-L=61E7V]N8V4@)'9A
M;%LG<&%T:"==.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1E<G)O<E]M
M<V<@/2`D=F%L6R=E<G)O<B==.PH@("`@("`@("`@("!I9B`H)')E<W5L="`F
M)B!I<W-E="@D=F%L6R=F=6YC=&EO;B==*2D@>PH@("`@("`@("`@("`@("`@
M)&9U;F-?;W5T<'5T(#T@8V%L;%]U<V5R7V9U;F,H)'9A;%LG9G5N8W1I;VXG
M72D["B`@("`@("`@("`@("`@("!I9B`H)&9U;F-?;W5T<'5T*2!["B`@("`@
M("`@("`@("`@("`@("`@)')E<W5L="`](&9A;'-E.PH@("`@("`@("`@("`@
M("`@("`@("1E<G)O<E]M<V<@/2`D9G5N8U]O=71P=70["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&5N=')Y6UT@/2`D
M:V5Y.PH@("`@("`@("`@("`D96YT<GE;72`]("1T:&ES+3Y?<W1A='5S*"1R
M97-U;'0L("%E;7!T>2@D=F%L6R=R97%U:7)E9"==*2D["@H@("`@("`@("`@
M("!I9B`H)')E<W5L="D@>PH@("`@("`@("`@("`@("`@)'-U8V-E961E9%LD
M:V5Y72`]('1R=64["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1V86Q;)W)E<75I<F5D)UTI*2!["B`@("`@("`@
M("`@("`@("`@("`@)&5R<F]R7VUS9R`N/2`G(%1(25,@25,@02!215%525)%
M1"!-3T153$4A)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("1E;G1R>5M=(#T@)&5R<F]R7VUS9SL*("`@("`@("`@("`@("`@(&EF("AE
M;7!T>2@D=F%L6R=R97%U:7)E9"==*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1E;G1R>5M=(#T@,3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^7V]U='!U=$QI;F4H
M)&5N=')Y*3L*("`@("`@("!]"@H@("`@("`@("\J(%)E<W1O<F4@<')E=FEO
M=7,@=F%L=64@;V8@)W1R86-K7V5R<F]R<R<N("HO"B`@("`@("`@:6YI7W)E
M<W1O<F4H)W1R86-K7V5R<F]R<R<I.PH*("`@("`@("!R971U<FX@)&]U='!U
M=#L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K('1H92!L:7-T(&]F(')E
M<75I<F5D(&9I;&5S"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1F:6QE
M7VQI<W0@(%1H92!F:6QE(&QI<W0N"B`@("`@*B`\<')E/@H@("`@("H@2T59
M.B`@(&9I;&4@<&%T:`H@("`@("H@5D%,544Z(%1H92!E<G)O<B!M97-S86=E
M('1O('5S92`H;G5L;"!T;R!U<V4@9&5F875L="!M97-S86=E*0H@("`@("H@
M/"]P<F4^"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!(5$U,
M(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5Q=6ER961&:6QE0VAE
M8VLH)&9I;&5?;&ES="D*("`@('L*("`@("`@("`D;W5T<'5T(#T@)R<["@H@
M("`@("`@(&9O<F5A8V@@*"1F:6QE7VQI<W0@87,@)&ME>2`]/B`D=F%L*2![
M"B`@("`@("`@("`@("1E;G1R>2`](&%R<F%Y*"D["B`@("`@("`@("`@("1R
M97-U;'0@/2!F:6QE7V5X:7-T<R@G+B\G("X@)&ME>2D["@H@("`@("`@("`@
M("`D96YT<GE;72`]("1K97D["B`@("`@("`@("`@("1E;G1R>5M=(#T@)'1H
M:7,M/E]S=&%T=7,H)')E<W5L="D["@H@("`@("`@("`@("!I9B`H(21R97-U
M;'0I('L*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D=F%L*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1E;G1R>5M=(#T@)U1H92!F:6QE(#QC;V1E/B<@
M+B`D:V5Y("X@)SPO8V]D93X@87!P96%R<R!T;R!B92!M:7-S:6YG+B!9;W4@
M<')O8F%B;'D@:G5S="!F;W)G;W0@=&\@8V]P>2`\8V]D93XG("X@)&ME>2`N
M("<N9&ES=#PO8V]D93X@;W9E<BX@5VAI;&4@>6]U(&1O('1H870L('1A:V4@
M82!L;V]K(&%T('1H92!S971T:6YG<R!A;F0@;6%K92!S=7)E('1H97D@87)E
M(&%P<')O<')I871E(&9O<B!Y;W5R('-I=&4N)SL*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&5N=')Y6UT@/2`D=F%L
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D;W5T<'5T("X]("1T:&ES+3Y?;W5T<'5T3&EN92@D96YT<GDI.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1O=71P=70["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$:7-P;&%Y<R!A;B!E<G)O<B!S8W)E96X@=VET:"!A(&QI<W0@
M;V8@86QL(&-O;F9I9W5R871I;VX@9FEL97,@=&AA=`H@("`@("H@87)E(&UI
M<W-I;F<L('1O9V5T:&5R('=I=&@@82!D97-C<FEP=&EO;B!W:&%T('1H97D@
M9&\@86YD(&AO=R!T:&5Y(&%R90H@("`@("H@8W)E871E9"X@268@82!F:6QE
M(&-A;B!B92!A=71O;6%T:6-A;&QY(&-R96%T960@9G)O;2!T:&4@9&5F875L
M=',L('1H96X*("`@("`J('=E(&1O('1H870@:6YS=&5A9"!A;F0@9&]N)W0@
M9&ES<&QA>2!A;B!E<G)O<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1A<'`@("`@("`@(%1H92!A<'!L:6-A=&EO;B!N86UE"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1A<'!"87-E("`@(%1H92!P871H('1O('1H92!A<'!L:6-A
M=&EO;@H@("`@("H@0'!A<F%M(&%R<F%Y("`D9FEL97,@("`@("!!;B!A<G)A
M>2!W:71H('1H92`B<W1A;F1A<F0B(&-O;F9I9W5R871I;VX*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@9FEL97,@=&AA="!S:&]U;&0@8F4@
M8VAE8VME9"X@0W5R<F5N=&QY"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-U<'!O<G1E9#H*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+2!C;VYF+G!H<`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`M('!R969S+G!H<`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`M(&UI;65?9')I=F5R<RYP:'`*("`@("`J($!P87)A;2!A<G)A>2`D
M861D:71I;VYA;"`@06X@87-S;V-I871I=F4@87)R87D@8V]N=&%I;FEN9R!M
M;W)E(&9I;&5S("AA<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("!K97ES*2!A;F0@97)R;W(@;65S<V%G92`H87,@=F%L=65S*2!I9B!T:&5Y
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&1O;B=T(&5X:7-T
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYF:6=&:6QE<TUI<W-I;F<H)&%P
M<"P@)&%P<$)A<V4L("1F:6QE<RP@)&%D9&ET:6]N86P@/2!A<G)A>2@I*0H@
M("`@>PH@("`@("`@("\J(%1R>2!T;R!L;V%D(&$@8F%S:6,@9G)A;65W;W)K
M(&EF('=E)W)E('1E<W1I;F<@86X@87!P(&]T:&5R('1H86X*("`@("`@("`@
M*B!T:&4@2&]R9&4@8F%S92!F:6QE<RX@*B\*("`@("`@("!I9B`H)&%P<"`A
M/2`G2&]R9&4G*2!["B`@("`@("`@("`@("1'3$]"04Q36R=R96=I<W1R>2==
M(#T@)E)E9VES=')Y.CIS:6YG;&5T;VXH*3L*("`@("`@("`@("`@)$=,3T)!
M3%-;)W)E9VES=')Y)UTM/G!U<VA!<'`H)VAO<F1E)RP@9F%L<V4I.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"%I<U]A<G)A>2@D9FEL97,I*2!["B`@("`@
M("`@("`@("1F:6QE<R`](&%R<F%Y*"1F:6QE<RD["B`@("`@("`@?0H@("`@
M("`@("1F:6QE<R`](&%R<F%Y7VUE<F=E*"1F:6QE<RP@87)R87E?:V5Y<R@D
M861D:71I;VYA;"DI.PH*("`@("`@("`O*B!4<GD@=&\@875T;RUC<F5A=&4@
M;6ES<VEN9R`N9&ES="!F:6QE<RX@*B\*("`@("`@("`D:6YD:6-E<R`](&%R
M<F%Y7VME>7,H)&9I;&5S*3L*("`@("`@("!F;W)E86-H("@D:6YD:6-E<R!A
M<R`D:6YD97@I('L*("`@("`@("`@("`@:68@*&ES7W)E861A8FQE*"1A<'!"
M87-E("X@)R]C;VYF:6<O)R`N("1F:6QE<ULD:6YD97A=*2D@>PH@("`@("`@
M("`@("`@("`@=6YS970H)&9I;&5S6R1I;F1E>%TI.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@:68@*$!F:6QE7V5X:7-T<R@D87!P
M0F%S92`N("<O8V]N9FEG+R<@+B`D9FEL97-;)&EN9&5X72`N("<N9&ES="<I
M("8F"B`@("`@("`@("`@("`@("`@("`@0&-O<'DH)&%P<$)A<V4@+B`G+V-O
M;F9I9R\G("X@)&9I;&5S6R1I;F1E>%T@+B`G+F1I<W0G+"`D87!P0F%S92`N
M("<O8V]N9FEG+R<@+B`D9FEL97-;)&EN9&5X72DI('L*("`@("`@("`@("`@
M("`@("`@("!U;G-E="@D9FEL97-;)&EN9&5X72D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%)E='5R
M;B!I9B!W92!H879E(&YO(&UI<W-I;F<@9FEL97,@;&5F="X@*B\*("`@("`@
M("!I9B`H(6-O=6YT*"1F:6QE<RDI('L*("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@('T*"B`@("`@("`@)&1E<V-R:7!T:6]N<R`](&%R<F%Y7VUE<F=E
M*&%R<F%Y*`H@("`@("`@("`@("`G8V]N9BYP:'`G(#T^('-P<FEN=&8H)U1H
M:7,@:7,@=&AE(&UA:6X@)7,@8V]N9FEG=7)A=&EO;B!F:6QE+B`G("X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=)="!C;VYT86EN<R!P
M871H<R!A;F0@;W!T:6]N<R!F;W(@=&AE("5S("<@+@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W-C<FEP=',N(%EO=2!N965D('1O(&QO
M9VEN(&%S(&%N("<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V%D;6EN:7-T<F%T;W(@86YD(&-R96%T92!T:&4@9FEL92!W:71H("<@
M+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1H92!W96(@
M9G)O;G1E;F0@=6YD97(@(D%D;6EN:7-T<F%T:6]N(#T^("<@+@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)U-E='5P(BXG+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%P<"P@)&%P<"P@)&%P<$)A
M<V4@+B`G+V-O;F9I9R<I+`H@("`@("`@("`@("`G<')E9G,N<&AP)R`]/B!S
M<')I;G1F*"=4:&ES(&9I;&4@8V]N=')O;',@=&AE(&1E9F%U;'0@<')E9F5R
M96YC97,@)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V9O<B`E<RP@86YD(&%L<V\@8V]N=')O;',@=VAI8V@@<')E9F5R96YC97,@
M)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5S97)S
M(&-A;B!A;'1E<BXG+"`D87!P*2P*("`@("`@("`@("`@)VUI;65?9')I=F5R
M<RYP:'`G(#T^('-P<FEN=&8H)U1H:7,@9FEL92!C;VYT<F]L<R!L;V-A;"!-
M24U%("<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G9')I=F5R<R!F;W(@)7,L('-P96-I9FEC86QL>2!W:&%T("<@+@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:VEN
M9',@;V8@9FEL97,@87)E('9I97=A8FQE(&%N9"]O<B`G("X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1O=VYL;V%D86)L
M92XG+"`D87!P*2P*("`@("`@("`@("`@)V)A8VME;F1S+G!H<"<@/3X@<W!R
M:6YT9B@G5&AI<R!F:6QE(&-O;G1R;VQS('=H870@8F%C:V5N9',@87)E("<@
M+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A=F%I
M;&%B;&4@9G)O;2`E<RXG+"`D87!P*2P*("`@("`@("`@("`@)W-O=7)C97,N
M<&AP)R`]/B!S<')I;G1F*"=4:&ES(&9I;&4@9&5F:6YE<R!T:&4@;&ES="!O
M9B!A=F%I;&%B;&4@)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<V]U<F-E<R!F;W(@)7,N)RP@)&%P<"D*("`@("`@("`I+"`D
M861D:71I;VYA;"D["@H@("`@("`@("\J($EF('=E(&MN;W<@=&AE('5S97(@
M:7,@86X@861M:6XL(&=I=F4@=&AE;2!A(&1I<F5C="!L:6YK('1O"B`@("`@
M("`@("H@9V5N97)A=&4@8V]N9BYP:'`N($EN('1H92!F=71U<F4L('-H;W5L
M9"!W92!T<GD@9V5N97)A=&EN9PH@("`@("`@("`J(&$@8F%S:6,@8V]N9BYP
M:'`@875T;VUA9VEC86QL>2!H97)E/R`J+PH@("`@("`@(&EF("A!=71H.CII
M<T%D;6EN*"DI('L*("`@("`@("`@("`@)'-E='5P7W5R;"`]($AO<F1E.CIL
M:6YK*$AO<F1E.CIU<FPH)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B
M<F]O="<L("=H;W)D92<I("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)R]A9&UI;B]S971U<"]C;VYF:6<N<&AP
M/V%P<#TG("X@4W1R:6YG.CIL;W=E<B@D87!P*2DI("X*("`@("`@("`@("`@
M("`@("=#;VYF:6=U<F%T:6]N(%=E8B!);G1E<F9A8V4G("X@)SPO83XG.PH@
M("`@("`@("`@("`D9&5S8W)I<'1I;VYS6R=C;VYF+G!H<"==(#T*("`@("`@
M("`@("`@("`@('-P<FEN=&8H)U1H:7,@:7,@=&AE(&UA:6X@)7,@8V]N9FEG
M=7)A=&EO;B!F:6QE+B`G("X*("`@("`@("`@("`@("`@("`@("`@("`@)T=E
M;F5R871E(&ET(&)Y(&=O:6YG('1O('1H92`E<RXG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`D87!P+"`D<V5T=7!?=7)L*3L*("`@("`@("!]"@H@("`@
M("`@("1T:71L92`]('-P<FEN=&8H)R5S(&ES(&YO="!P<F]P97)L>2!C;VYF
M:6=U<F5D)RP@)&%P<"D["B`@("`@("`@)&AE861E<B`]('-P<FEN=&8H)U-O
M;64@;V8@)7-<)W,@8V]N9FEG=7)A=&EO;B!F:6QE<R!A<F4@;6ES<VEN9R!O
M<B!U;G)E861A8FQE)RP@)&%P<"D["B`@("`@("`@)&9O;W1E<B`]('-P<FEN
M=&8H)T-R96%T92!T:&5S92!F:6QE<R!F<F]M('1H96ER("YD:7-T('9E<G-I
M;VYS(&EN("5S(&%N9"!C:&%N9V4@=&AE;2!A8V-O<F1I;F<@=&\@>6]U<B!N
M965D<RXG+"`D87!P0F%S92`N("<O8V]N9FEG)RD["@H@("`@("`@(&5C:&\@
M/#P\($A%041%4@H\:'1M;#X*/&AE860^/'1I=&QE/B1T:71L93PO=&ET;&4^
M/"]H96%D/@H\8F]D>2!S='EL93TB8F%C:V=R;W5N9"UC;VQO<CH@=VAI=&4[
M(&-O;&]R.B!B;&%C:SLB/@H\:#$^)&AE861E<CPO:#$^"DA%041%4CL*"B`@
M("`@("`@9F]R96%C:"`H)&9I;&5S(&%S("1F:6QE*2!["B`@("`@("`@("`@
M(&EF("AE;7!T>2@D9&5S8W)I<'1I;VYS6R1F:6QE72DI('L*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1D
M97-C<FEP=&EO;B`]("1D97-C<FEP=&EO;G-;)&9I;&5=.PH@("`@("`@("`@
M("!E8VAO(#P\/"!&24Q%"B`@("`\:#,^)&9I;&4\+V@S/CQP/B1D97-C<FEP
M=&EO;CPO<#X*1DE,13L*("`@("`@("!]"@H@("`@("`@(&5C:&\@/#P\($9/
M3U1%4@H*/&@R/B1F;V]T97(\+V@R/@H\+V)O9'D^"CPO:'1M;#X*1D]/5$52
M.PH@("`@("`@(&5X:70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:R!T
M:&4@;&ES="!O9B!R97%U:7)E9"!(;W)D92!A<'!L:6-A=&EO;G,N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1A<'!?;&ES="`@5&AE(&%P<&QI8V%T
M:6]N(&QI<W0N"B`@("`@*B`\<')E/@H@("`@("H@2T59.B`@(&%P<&QI8V%T
M:6]N(&YA;64*("`@("`J(%9!3%5%.B!!;B!A<G)A>2!W:71H('1H92!F;VQL
M;W=I;F<@96YT<FEE<SH*("`@("`J("`@("`@("`G97)R;W(G("`@("TM("!%
M<G)O<B!-97-S86=E"B`@("`@*B`@("`@("`@)W9E<G-I;VXG("`M+2`@5&AE
M(&UI;FEM=6T@=F5R<VEO;B!R97%U:7)E9`H@("`@("H@/"]P<F4^"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!(5$U,(&]U='!U="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F5Q=6ER961!<'!#:&5C:R@D87!P7VQI<W0I
M"B`@("!["B`@("`@("`@)&]U='!U="`]("<G.PH*("`@("`@("`D87!P<R`]
M("1T:&ES+3YA<'!L:6-A=&EO;DQI<W0H*3L*"B`@("`@("`@9F]R96%C:"`H
M)&%P<%]L:7-T(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`D96YT
M<GD@/2!A<G)A>2@I.PH@("`@("`@("`@("`D96YT<GE;72`]("1K97D["@H@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1A<'!S6R1K97E=*2D@>PH@("`@("`@
M("`@("`@("`@)&5N=')Y6UT@/2`D=&AI<RT^7W-T871U<RAF86QS92D["B`@
M("`@("`@("`@("`@("`D96YT<GE;72`]("1V86Q;)V5R<F]R)UT["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O*B!3=')I<"`G+6-V
M<R<@86YD($@S("AV97(I(&9R;VT@=F5R<VEO;B!S=')I;F<N("HO"B`@("`@
M("`@("`@("`@("`D87!P=F5R(#T@<W1R7W)E<&QA8V4H)RUC=G,G+"`G)RP@
M)&%P<'-;)&ME>5TM/G9E<G-I;VXI.PH@("`@("`@("`@("`@("`@)&%P<'9E
M<B`]('!R96=?<F5P;&%C92@G+T@S(%PH*"XJ*5PI+R<L("<D,2<L("1A<'!V
M97(I.PH@("`@("`@("`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92@D=F%L
M6R=V97)S:6]N)UTL("1A<'!V97(I(#T]/2`Q*2!["B`@("`@("`@("`@("`@
M("`@("`@)&5N=')Y6UT@/2`D=&AI<RT^7W-T871U<RAF86QS92D@+B`G("A(
M879E('9E<G-I;VXZ("<@+B`D87!P<ULD:V5Y72T^=F5R<VEO;B`N("<[($YE
M960@=F5R<VEO;CH@)R`N("1V86Q;)W9E<G-I;VXG72`N("<I)SL*("`@("`@
M("`@("`@("`@("`@("`D96YT<GE;72`]("1V86Q;)V5R<F]R)UT["B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1E;G1R
M>5M=(#T@)'1H:7,M/E]S=&%T=7,H=')U92D@+B`G("A697)S:6]N.B`G("X@
M)&%P<'-;)&ME>5TM/G9E<G-I;VX@+B`G*2<["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^
M7V]U='!U=$QI;F4H)&5N=')Y*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D;W5T<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@27,@=&AI<R!A("=R
M96-E;G0G('9E<G-I;VX@;V8@4$5!4C\*("`@("`J"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`@5')U92!I9B!A(')E8V5N="!V97)S:6]N(&]F(%!%05(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&ES4F5C96YT4$5!4B@I"B`@("!["B`@("`@
M("`@0&EN8VQU9&5?;VYC92`G4$5!4BYP:'`G.PH@("`@("`@("1P96%R7VUE
M=&AO9',@/2!G971?8VQA<W-?;65T:&]D<R@G4$5!4B<I.PH@("`@("`@(')E
M='5R;B`H:7-?87)R87DH)'!E87)?;65T:&]D<RD@)B8*("`@("`@("`@("`@
M("`@("AI;E]A<G)A>2@G<F5G:7-T97)S:'5T9&]W;F9U;F,G+"`D<&5A<E]M
M971H;V1S*2!\?`H@("`@("`@("`@("`@("`@(&EN7V%R<F%Y*"=R96=I<W1E
M<E-H=71D;W=N1G5N8R<L("1P96%R7VUE=&AO9',I*2D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!/8G1A:6X@:6YF;W)M871I;VX@;VX@=&AE(%!(4"!V97)S
M:6]N+@H@("`@("H*("`@("`J($!R971U<FX@;V)J96-T('-T9$-L87-S("!4
M3T1/"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!H<%9E<G-I;VY);F9O<FUA
M=&EO;B@I"B`@("!["B`@("`@("`@)&]U='!U="`]("9N97<@<W1D0VQA<W,[
M"B`@("`@("`@)'5R;"`]('5R;&5N8V]D92@D7U-%4E9%4ELG4$A07U-%3$8G
M72D["B`@("`@("`@)'9E<G-?8VAE8VL@/2!T<G5E.PH*("`@("`@("`D=&5S
M='-C<FEP="`]("1T:&ES+3YA<'!L:6-A=&EO;G-;)VAO<F1E)UU;)W=E8G)O
M;W0G72`N("<O=&5S="YP:'`G.PH@("`@("`@("1O=71P=70M/G!H<&EN9F\@
M/2`D=&5S='-C<FEP="`N("<_;6]D93UP:'!I;F9O)G5R;#TG("X@)'5R;#L*
M("`@("`@("`D;W5T<'5T+3YE>'1E;G-I;VYS(#T@)'1E<W1S8W)I<'0@+B`G
M/VUO9&4]97AT96YS:6]N<R9U<FP])R`N("1U<FP["B`@("`@("`@)&]U='!U
M="T^=F5R<VEO;B`]('!H<'9E<G-I;VXH*3L*("`@("`@("`D;W5T<'5T+3YM
M86IO<B`]("1T:&ES+3Y?<&AP=F5R6R=M86IO<B==.PH@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W!H<'9E<ELG;6EN;W(G72DI('L*("`@("`@("`@("`@
M)&]U='!U="T^;6EN;W(@/2`D=&AI<RT^7W!H<'9E<ELG;6EN;W(G73L*("`@
M("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&AP=F5R6R=S=6)M
M:6YO<B==*2D@>PH@("`@("`@("`@("`D;W5T<'5T+3YS=6)M:6YO<B`]("1T
M:&ES+3Y?<&AP=F5R6R=S=6)M:6YO<B==.PH@("`@("`@('T*("`@("`@("`D
M;W5T<'5T+3YC;&%S<R`]("1T:&ES+3Y?<&AP=F5R6R=C;&%S<R==.PH*("`@
M("`@("`D;W5T<'5T+3YS=&%T=7-?8V]L;W(@/2`G<F5D)SL*("`@("`@("!I
M9B`H)&]U='!U="T^;6%J;W(@/"`G-"XS)RD@>PH@("`@("`@("`@("`D;W5T
M<'5T+3YS=&%T=7,@/2`G5&AI<R!V97)S:6]N(&]F(%!(4"!I<R!N;W0@<W5P
M<&]R=&5D+B!9;W4@;F5E9"!T;R!U<&=R861E('1O(&$@;6]R92!R96-E;G0@
M=F5R<VEO;BXG.PH@("`@("`@("`@("`D=F5R<U]C:&5C:R`](&9A;'-E.PH@
M("`@("`@('T@96QS96EF("@H)&]U='!U="T^;6%J;W(@/3T@)S0N,R<I('Q\
M"B`@("`@("`@("`@("`@("`@("@D;W5T<'5T+3YM86IO<B`]/2`G-"XT)RD@
M?'P*("`@("`@("`@("`@("`@("`@*"1O=71P=70M/FUA:F]R(#T]("<U+C`G
M*2!\?`H@("`@("`@("`@("`@("`@("`H)&]U='!U="T^;6%J;W(@/3T@)S4N
M,2<I*2!["B`@("`@("`@("`@("1O=71P=70M/G-T871U<R`]("=9;W4@87)E
M(')U;FYI;F<@82!S=7!P;W)T960@=F5R<VEO;B!O9B!02%`N)SL*("`@("`@
M("`@("`@)&]U='!U="T^<W1A='5S7V-O;&]R(#T@)V=R965N)SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D;W5T<'5T+3YS=&%T=7,@/2`G5V]W
M+"!A(&UY<W1I8V%L('9E<G-I;VX@;V8@4$A0(&9R;VT@=&AE(&9U='5R92X@
M3&5T(#QA(&AR968](FUA:6QT;SID979`;&ES=',N:&]R9&4N;W)G(CYD979`
M;&ES=',N:&]R9&4N;W)G/"]A/B!K;F]W('=H870@=F5R<VEO;B!Y;W4@:&%V
M92!S;R!W92!C86X@9FEX('1H:7,@<V-R:7!T+B<["B`@("`@("`@("`@("1O
M=71P=70M/G-T871U<U]C;VQO<B`]("=O<F%N9V4G.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"$D=F5R<U]C:&5C:RD@>PH@("`@("`@("`@("`D;W5T<'5T
M+3YV97)S:6]N7V-H96-K(#T@)TAO<F1E(')E<75I<F5S(%!(4"`T+C,N,"!O
M<B!G<F5A=&5R+B<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&]U='!U
M=#L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@87!P;&EC871I;VX@
M;&ES="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!,:7-T(&]F('-T
M9$-L87-S(&]B:F5C=',N"B`@("`@*B`@("`@("`@("`@("`@("!+15DZ(&%P
M<&QI8V%T:6]N(&YA;64*("`@("`J("`@("`@("`@("`@("`@($5,14U%3E0@
M)W9E<G-I;VXG.B!697)S:6]N(&]F(&%P<&QI8V%T:6]N"B`@("`@*B`@("`@
M("`@("`@("`@("!%3$5-14Y4("=T97-T)SH@5&AE(&QO8V%T:6]N(&]F('1H
M92!T97-T('-C<FEP="`H:68@86YY*0H@("`@("HO"B`@("!F=6YC=&EO;B!A
M<'!L:6-A=&EO;DQI<W0H*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)'1H
M:7,M/E]A<'!O=71P=70I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7V%P<&]U='!U=#L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3YA<'!L:6-A=&EO;G,@87,@)&UO9"`]/B`D9&5T*2!["B`@("`@("`@("`@
M(&EF("@H)&1E=%LG<W1A='5S)UT@(3T@)VAE861I;F<G*2`F)@H@("`@("`@
M("`@("`@("`@*"1D971;)W-T871U<R==("$]("=B;&]C:R<I("8F"B`@("`@
M("`@("`@("`@("!I<U]R96%D86)L92@D9&5T6R=F:6QE<F]O="==("X@)R]L
M:6(O=F5R<VEO;BYP:'`G*2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E("1D971;)V9I;&5R;V]T)UT@+B`G+VQI8B]V97)S:6]N+G!H<"<["B`@
M("`@("`@("`@("`@("`D=F5R<VEO;E]C;VYS=&%N="`](%-T<FEN9SHZ=7!P
M97(H)&UO9"D@+B`G7U9%4E-)3TXG.PH@("`@("`@("`@("`@("`@:68@*&1E
M9FEN960H)'9E<G-I;VY?8V]N<W1A;G0I*2!["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]A<'!O=71P=71;)&UO9%T@/2`F;F5W('-T9$-L87-S.PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?87!P;W5T<'5T6R1M;V1=+3YV
M97)S:6]N(#T@8V]N<W1A;G0H)'9E<G-I;VY?8V]N<W1A;G0I.PH@("`@("`@
M("`@("`@("`@("`@(&EF("@H)&UO9"`A/2`G:&]R9&4G*2`F)@H@("`@("`@
M("`@("`@("`@("`@("`@("!`:7-?<F5A9&%B;&4H)&1E=%LG9FEL97)O;W0G
M72`N("<O=&5S="YP:'`G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V%P<&]U='!U=%LD;6]D72T^=&5S="`]("1D971;)W=E8G)O;W0G
M72`N("<O=&5S="YP:'`G.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?87!P;W5T<'5T.PH@("`@?0H*("`@("\J*@H@("`@
M("H@3W5T<'5T('1H92!R97-U;'1S(&]F(&$@<W1A='5S(&-H96-K+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A
M;2!B;V]L96%N("1B;V]L("`@("`@5&AE(')E<W5L="!O9B!T:&4@<W1A='5S
M(&-H96-K+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)')E<75I<F5D("!7:&5T
M:&5R('1H92!C:&5C:V5D(&ET96T@:7,@<F5Q=6ER960N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!(5$U,(&]F('1H92!R97-U;'0@;V8@
M=&AE('-T871U<R!C:&5C:RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-T871U
M<R@D8F]O;"P@)')E<75I<F5D(#T@=')U92D*("`@('L*("`@("`@("!I9B`H
M)&)O;VPI('L*("`@("`@("`@("`@<F5T=7)N("<\9F]N="!C;VQO<CTB9W)E
M96XB/CQS=')O;F<^665S/"]S=')O;F<^/"]F;VYT/B<["B`@("`@("`@?2!E
M;'-E:68@*"1R97%U:7)E9"D@>PH@("`@("`@("`@("!R971U<FX@)SQF;VYT
M(&-O;&]R/2)R960B/CQS=')O;F<^3F\\+W-T<F]N9SX\+V9O;G0^)SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)SQF;VYT(&-O;&]R
M/2)O<F%N9V4B/CQS=')O;F<^3F\\+W-T<F]N9SX\+V9O;G0^)SL*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!);G1E<FYA;"!O=71P=70@9G5N
M8W1I;VXN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1E;G1R>2`@,R!E;&5M96YT(&%R<F%Y+@H@
M("`@("H@/'!R93X*("`@("`J(#%S="!V86QU93H@2&5A9&5R"B`@("`@*B`R
M;F0@=F%L=64Z(%1E<W0@4F5S=6QT"B`@("`@*B`S<F0@=F%L=64Z($5R<F]R
M(&UE<W-A9V4@*&EF('!R97-E;G0I"B`@("`@*B`T=&@@=F%L=64Z($5R<F]R
M(&QE=F5L("AI9B!P<F5S96YT*3H@,"`](&5R<F]R+"`Q(#T@=V%R;FEN9PH@
M("`@("H@/"]P<F4^"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($A4
M34P@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!?;W5T<'5T3&EN92@D
M96YT<GDI"B`@("!["B`@("`@("`@)&]U='!U="`]("<\;&D^)R`N(&%R<F%Y
M7W-H:69T*"1E;G1R>2D@+B`G.B`G("X@87)R87E?<VAI9G0H)&5N=')Y*3L*
M("`@("`@("!I9B`H(65M<'1Y*"1E;G1R>2DI('L*("`@("`@("`@("`@)&US
M9R`](&%R<F%Y7W-H:69T*"1E;G1R>2D["B`@("`@("`@("`@("1O=71P=70@
M+CT@)SQB<B`O/CQF;VYT(&-O;&]R/2(G("X@*&5M<'1Y*"1E;G1R>2D@?'P@
M(6%R<F%Y7W-H:69T*"1E;G1R>2D@/R`G<F5D)R`Z("=O<F%N9V4G*2`N("<B
M/CQS=')O;F<^)R`N("1M<V<@+B`G/"]S=')O;F<^/"]F;VYT/B<@+B`B7&XB
M.PH@("`@("`@('T*("`@("`@("`D;W5T<'5T("X]("<\+VQI/B<@+B`B7&XB
M.PH*("`@("`@("!R971U<FX@)&]U='!U=#L*("`@('T*"GT*````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B]497AT+P``````````````````````````````````
M````````````````````````````````````````````````````,#`P,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-#4`,#$W
M,S4Q`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U1E>'0O1&EF9B\`````
M````````````````````````````````````````````````````````````
M```````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#4Q-30S,S<T-0`P,C`R,C$`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O5&5X="]$:69F+U)E;F1E<F5R+P``````````````````````````````
M`````````````````````````````````````#`P,#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S0U`#`R,3<V-P`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B]497AT+T1I9F8O4F5N9&5R97(O:6YL:6YE
M+G!H<```````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`T-34`,3`U,34T,S,W
M-#4`,#(S-S8S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"@IR97%U:7)E7V]N8V4@)U1E>'0O1&EF9B]296YD97)E
M<BYP:'`G.PH*+RHJ"B`J("));FQI;F4B(&1I9F8@<F5N9&5R97(N"B`J"B`J
M(%1H:7,@8VQA<W,@<F5N9&5R<R!D:69F<R!I;B!T:&4@5VEK:2US='EL92`B
M:6YL:6YE(B!F;W)M870N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?
M1&EF9B]$:69F+U)E;F1E<F5R+VEN;&EN92YP:'`L=B`Q+C0N,3`N,3$@,C`P
M-B\P-B\Q-B`Q-#HP.#HQ-2!C:'5C:R!%>'`@)`H@*@H@*B!`875T:&]R("!#
M:7!R:6%N(%!O<&]V:6-I"B`J($!P86-K86=E(%1E>'1?1&EF9@H@*B\*8VQA
M<W,@5&5X=%]$:69F7U)E;F1E<F5R7VEN;&EN92!E>'1E;F1S(%1E>'1?1&EF
M9E]296YD97)E<B!["@H@("`@+RHJ"B`@("`@*B!.=6UB97(@;V8@;&5A9&EN
M9R!C;VYT97AT(")L:6YE<R(@=&\@<')E<V5R=F4N"B`@("`@*B\*("`@('9A
M<B`D7VQE861I;F=?8V]N=&5X=%]L:6YE<R`](#$P,#`P.PH*("`@("\J*@H@
M("`@("H@3G5M8F5R(&]F('1R86EL:6YG(&-O;G1E>'0@(FQI;F5S(B!T;R!P
M<F5S97)V92X*("`@("`J+PH@("`@=F%R("1?=')A:6QI;F=?8V]N=&5X=%]L
M:6YE<R`](#$P,#`P.PH*("`@("\J*@H@("`@("H@4')E9FEX(&9O<B!I;G-E
M<G1E9"!T97AT+@H@("`@("HO"B`@("!V87(@)%]I;G-?<')E9FEX(#T@)SQI
M;G,^)SL*"B`@("`O*BH*("`@("`J(%-U9F9I>"!F;W(@:6YS97)T960@=&5X
M="X*("`@("`J+PH@("`@=F%R("1?:6YS7W-U9F9I>"`]("<\+VEN<SXG.PH*
M("`@("\J*@H@("`@("H@4')E9FEX(&9O<B!D96QE=&5D('1E>'0N"B`@("`@
M*B\*("`@('9A<B`D7V1E;%]P<F5F:7@@/2`G/&1E;#XG.PH*("`@("\J*@H@
M("`@("H@4W5F9FEX(&9O<B!D96QE=&5D('1E>'0N"B`@("`@*B\*("`@('9A
M<B`D7V1E;%]S=69F:7@@/2`G/"]D96P^)SL*"B`@("`O*BH*("`@("`J($AE
M861E<B!F;W(@96%C:"!C:&%N9V4@8FQO8VLN"B`@("`@*B\*("`@('9A<B`D
M7V)L;V-K7VAE861E<B`]("<G.PH*("`@("\J*@H@("`@("H@5VAA="!A<F4@
M=V4@8W5R<F5N=&QY('-P;&ET=&EN9R!O;C\@57-E9"!T;R!R96-U<G-E('1O
M('-H;W<@=V]R9"UL979E;`H@("`@("H@8VAA;F=E<RX*("`@("`J+PH@("`@
M=F%R("1?<W!L:71?;&5V96P@/2`G;&EN97,G.PH*("`@(&9U;F-T:6]N(%]B
M;&]C:TAE861E<B@D>&)E9RP@)'AL96XL("1Y8F5G+"`D>6QE;BD*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]B;&]C:U]H96%D97(["B`@("!]"@H@
M("`@9G5N8W1I;VX@7W-T87)T0FQO8VLH)&AE861E<BD*("`@('L*("`@("`@
M("!R971U<FX@)&AE861E<CL*("`@('T*"B`@("!F=6YC=&EO;B!?;&EN97,H
M)&QI;F5S+"`D<')E9FEX(#T@)R`G+"`D96YC;V1E(#T@=')U92D*("`@('L*
M("`@("`@("!I9B`H)&5N8V]D92D@>PH@("`@("`@("`@("!A<G)A>5]W86QK
M*"1L:6YE<RP@87)R87DH)B1T:&ES+"`G7V5N8V]D92<I*3L*("`@("`@("!]
M"@H@("`@("`@(&EF("@D=&AI<RT^7W-P;&ET7VQE=F5L(#T]("=W;W)D<R<I
M('L*("`@("`@("`@("`@<F5T=7)N(&EM<&QO9&4H)R<L("1L:6YE<RD["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&EM<&QO9&4H(EQN
M(BP@)&QI;F5S*2`N(")<;B(["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T
M:6]N(%]A9&1E9"@D;&EN97,I"B`@("!["B`@("`@("`@87)R87E?=V%L:R@D
M;&EN97,L(&%R<F%Y*"8D=&AI<RP@)U]E;F-O9&4G*2D["B`@("`@("`@)&QI
M;F5S6S!=(#T@)'1H:7,M/E]I;G-?<')E9FEX("X@)&QI;F5S6S!=.PH@("`@
M("`@("1L:6YE<UMC;W5N="@D;&EN97,I("T@,5T@+CT@)'1H:7,M/E]I;G-?
M<W5F9FEX.PH@("`@("`@(')E='5R;B`D=&AI<RT^7VQI;F5S*"1L:6YE<RP@
M)R`G+"!F86QS92D["B`@("!]"@H@("`@9G5N8W1I;VX@7V1E;&5T960H)&QI
M;F5S+"`D=V]R9',@/2!F86QS92D*("`@('L*("`@("`@("!A<G)A>5]W86QK
M*"1L:6YE<RP@87)R87DH)B1T:&ES+"`G7V5N8V]D92<I*3L*("`@("`@("`D
M;&EN97-;,%T@/2`D=&AI<RT^7V1E;%]P<F5F:7@@+B`D;&EN97-;,%T["B`@
M("`@("`@)&QI;F5S6V-O=6YT*"1L:6YE<RD@+2`Q72`N/2`D=&AI<RT^7V1E
M;%]S=69F:7@["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;&EN97,H)&QI;F5S
M+"`G("<L(&9A;'-E*3L*("`@('T*"B`@("!F=6YC=&EO;B!?8VAA;F=E9"@D
M;W)I9RP@)&9I;F%L*0H@("`@>PH@("`@("`@("\J($EF('=E)W9E(&%L<F5A
M9'D@<W!L:70@;VX@=V]R9',L(&1O;B=T('1R>2!T;R!D;R!S;R!A9V%I;B`M
M(&IU<W0*("`@("`@("`@*B!D:7-P;&%Y+B`J+PH@("`@("`@(&EF("@D=&AI
M<RT^7W-P;&ET7VQE=F5L(#T]("=W;W)D<R<I('L*("`@("`@("`@("`@)'!R
M969I>"`]("<G.PH@("`@("`@("`@("!W:&EL92`H)&]R:6=;,%T@(3T](&9A
M;'-E("8F("1F:6YA;%LP72`A/3T@9F%L<V4@)B8*("`@("`@("`@("`@("`@
M("`@('-U8G-T<B@D;W)I9ULP72P@,"P@,2D@/3T@)R`G("8F"B`@("`@("`@
M("`@("`@("`@("!S=6)S='(H)&9I;F%L6S!=+"`P+"`Q*2`]/2`G("<I('L*
M("`@("`@("`@("`@("`@("1P<F5F:7@@+CT@<W5B<W1R*"1O<FEG6S!=+"`P
M+"`Q*3L*("`@("`@("`@("`@("`@("1O<FEG6S!=(#T@<W5B<W1R*"1O<FEG
M6S!=+"`Q*3L*("`@("`@("`@("`@("`@("1F:6YA;%LP72`]('-U8G-T<B@D
M9FEN86Q;,%TL(#$I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R
M;B`D<')E9FEX("X@)'1H:7,M/E]D96QE=&5D*"1O<FEG*2`N("1T:&ES+3Y?
M861D960H)&9I;F%L*3L*("`@("`@("!]"@H@("`@("`@("1T97AT,2`](&EM
M<&QO9&4H(EQN(BP@)&]R:6<I.PH@("`@("`@("1T97AT,B`](&EM<&QO9&4H
M(EQN(BP@)&9I;F%L*3L*"B`@("`@("`@+RH@3F]N+7!R:6YT:6YG(&YE=VQI
M;F4@;6%R:V5R+B`J+PH@("`@("`@("1N;"`](")<,"(["@H@("`@("`@("\J
M(%=E('=A;G0@=&\@<W!L:70@;VX@=V]R9"!B;W5N9&%R:65S+"!B=70@=V4@
M;F5E9"!T;PH@("`@("`@("`J('!R97-E<G9E('=H:71E<W!A8V4@87,@=V5L
M;"X@5&AE<F5F;W)E('=E('-P;&ET(&]N('=O<F1S+`H@("`@("`@("`J(&)U
M="!I;F-L=61E(&%L;"!B;&]C:W,@;V8@=VAI=&5S<&%C92!I;B!T:&4@=V]R
M9&QI<W0N("HO"B`@("`@("`@)&1I9F8@/2`F;F5W(%1E>'1?1&EF9B@D=&AI
M<RT^7W-P;&ET3VY7;W)D<R@D=&5X=#$L("1N;"DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W-P;&ET3VY7;W)D<R@D=&5X=#(L
M("1N;"DI.PH*("`@("`@("`O*B!'970@=&AE(&1I9F8@:6X@:6YL:6YE(&9O
M<FUA="X@*B\*("`@("`@("`D<F5N9&5R97(@/2`F;F5W(%1E>'1?1&EF9E]2
M96YD97)E<E]I;FQI;F4H87)R87E?;65R9V4H)'1H:7,M/F=E=%!A<F%M<R@I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<W!L:71?;&5V96PG(#T^("=W
M;W)D<R<I*2D["@H@("`@("`@("\J(%)U;B!T:&4@9&EF9B!A;F0@9V5T('1H
M92!O=71P=70N("HO"B`@("`@("`@<F5T=7)N('-T<E]R97!L86-E*"1N;"P@
M(EQN(BP@)')E;F1E<F5R+3YR96YD97(H)&1I9F8I*2`N(")<;B(["B`@("!]
M"@H@("`@9G5N8W1I;VX@7W-P;&ET3VY7;W)D<R@D<W1R:6YG+"`D;F5W;&EN
M945S8V%P92`](")<;B(I"B`@("!["B`@("`@("`@+R\@26=N;W)E(%PP.R!O
M=&AE<G=I<V4@=&AE('=H:6QE(&QO;W`@=VEL;"!N979E<B!F:6YI<V@N"B`@
M("`@("`@)'-T<FEN9R`]('-T<E]R97!L86-E*")<,"(L("<G+"`D<W1R:6YG
M*3L*"B`@("`@("`@)'=O<F1S(#T@87)R87DH*3L*("`@("`@("`D;&5N9W1H
M(#T@<W1R;&5N*"1S=')I;F<I.PH@("`@("`@("1P;W,@/2`P.PH*("`@("`@
M("!W:&EL92`H)'!O<R`\("1L96YG=&@I('L*("`@("`@("`@("`@+R\@16%T
M(&$@=V]R9"!W:71H(&%N>2!P<F5C961I;F<@=VAI=&5S<&%C92X*("`@("`@
M("`@("`@)'-P86-E<R`]('-T<G-P;BAS=6)S='(H)'-T<FEN9RP@)'!O<RDL
M("(@7&XB*3L*("`@("`@("`@("`@)&YE>'1P;W,@/2!S=')C<W!N*'-U8G-T
M<B@D<W1R:6YG+"`D<&]S("L@)'-P86-E<RDL("(@7&XB*3L*("`@("`@("`@
M("`@)'=O<F1S6UT@/2!S=')?<F5P;&%C92@B7&XB+"`D;F5W;&EN945S8V%P
M92P@<W5B<W1R*"1S=')I;F<L("1P;W,L("1S<&%C97,@*R`D;F5X='!O<RDI
M.PH@("`@("`@("`@("`D<&]S("L]("1S<&%C97,@*R`D;F5X='!O<SL*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D=V]R9',["B`@("!]"@H@("`@9G5N
M8W1I;VX@7V5N8V]D92@F)'-T<FEN9RD*("`@('L*("`@("`@("`D<W1R:6YG
M(#T@:'1M;'-P96-I86QC:&%R<R@D<W1R:6YG*3L*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+U1E>'0O1&EF9B]296YD97)E<B]U;FEF:65D+G!H<```````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$P,``Q,#4Q-30S,S<T-0`P,C0Q,30`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*"G)E<75I<F5?;VYC92`G5&5X="]$:69F+U)E;F1E<F5R+G!H<"<["@HO
M*BH*("H@(E5N:69I960B(&1I9F8@<F5N9&5R97(N"B`J"B`J(%1H:7,@8VQA
M<W,@<F5N9&5R<R!T:&4@9&EF9B!I;B!C;&%S<VEC(")U;FEF:65D(&1I9F8B
M(&9O<FUA="X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]$:69F+T1I
M9F8O4F5N9&5R97(O=6YI9FEE9"YP:'`L=B`Q+C,N,3`N,R`R,#`V+S`Q+S`X
M(#`Q.C,W.C(P(&IA;B!%>'`@)`H@*@H@*B!`<&%C:V%G92!497AT7T1I9F8*
M("HO"F-L87-S(%1E>'1?1&EF9E]296YD97)E<E]U;FEF:65D(&5X=&5N9',@
M5&5X=%]$:69F7U)E;F1E<F5R('L*"B`@("`O*BH*("`@("`J($YU;6)E<B!O
M9B!L96%D:6YG(&-O;G1E>'0@(FQI;F5S(B!T;R!P<F5S97)V92X*("`@("`J
M+PH@("`@=F%R("1?;&5A9&EN9U]C;VYT97AT7VQI;F5S(#T@-#L*"B`@("`O
M*BH*("`@("`J($YU;6)E<B!O9B!T<F%I;&EN9R!C;VYT97AT(")L:6YE<R(@
M=&\@<')E<V5R=F4N"B`@("`@*B\*("`@('9A<B`D7W1R86EL:6YG7V-O;G1E
M>'1?;&EN97,@/2`T.PH*("`@(&9U;F-T:6]N(%]B;&]C:TAE861E<B@D>&)E
M9RP@)'AL96XL("1Y8F5G+"`D>6QE;BD*("`@('L*("`@("`@("!I9B`H)'AL
M96X@(3T@,2D@>PH@("`@("`@("`@("`D>&)E9R`N/2`G+"<@+B`D>&QE;CL*
M("`@("`@("!]"B`@("`@("`@:68@*"1Y;&5N("$](#$I('L*("`@("`@("`@
M("`@)'EB96<@+CT@)RPG("X@)'EL96X["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`B0$`@+21X8F5G("LD>6)E9R!`0"(["B`@("!]"@H@("`@9G5N8W1I
M;VX@7V%D9&5D*"1L:6YE<RD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/E]L:6YE<R@D;&EN97,L("<K)RD["B`@("!]"@H@("`@9G5N8W1I;VX@7V1E
M;&5T960H)&QI;F5S*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VQI
M;F5S*"1L:6YE<RP@)RTG*3L*("`@('T*"B`@("!F=6YC=&EO;B!?8VAA;F=E
M9"@D;W)I9RP@)&9I;F%L*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7V1E;&5T960H)&]R:6<I("X@)'1H:7,M/E]A9&1E9"@D9FEN86PI.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5&5X="]$:69F+U)E
M;F1E<F5R+G!H<```````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$R
M-C,S`#$P-3$U-#,S-S0U`#`R,C4P-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@02!C;&%S<R!T;R!R
M96YD97(@1&EF9G,@:6X@9&EF9F5R96YT(&9O<FUA=',N"B`J"B`J(%1H:7,@
M8VQA<W,@<F5N9&5R<R!T:&4@9&EF9B!I;B!C;&%S<VEC(&1I9F8@9F]R;6%T
M+B!)="!I<R!I;G1E;F1E9"!T:&%T"B`J('1H:7,@8VQA<W,@8F4@8W5S=&]M
M:7IE9"!V:6$@:6YH97)I=&%N8V4L('1O(&]B=&%I;B!F86YC:65R(&]U='!U
M=',N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1&EF9B]$:69F+U)E
M;F1E<F5R+G!H<"QV(#$N-2XQ,"XW(#(P,#4O,3(O,38@,3$Z-#0Z,#`@:F%N
M($5X<"`D"B`J"B`J($!P86-K86=E(%1E>'1?1&EF9@H@*B\*8VQA<W,@5&5X
M=%]$:69F7U)E;F1E<F5R('L*"B`@("`O*BH*("`@("`J($YU;6)E<B!O9B!L
M96%D:6YG(&-O;G1E>'0@(FQI;F5S(B!T;R!P<F5S97)V92X*("`@("`J"B`@
M("`@*B!4:&ES('-H;W5L9"!B92!L969T(&%T('IE<F\@9F]R('1H:7,@8VQA
M<W,L(&)U="!S=6)C;&%S<V5S(&UA>2!W86YT('1O"B`@("`@*B!S970@=&AI
M<R!T;R!O=&AE<B!V86QU97,N"B`@("`@*B\*("`@('9A<B`D7VQE861I;F=?
M8V]N=&5X=%]L:6YE<R`](#`["@H@("`@+RHJ"B`@("`@*B!.=6UB97(@;V8@
M=')A:6QI;F<@8V]N=&5X="`B;&EN97,B('1O('!R97-E<G9E+@H@("`@("H*
M("`@("`J(%1H:7,@<VAO=6QD(&)E(&QE9G0@870@>F5R;R!F;W(@=&AI<R!C
M;&%S<RP@8G5T('-U8F-L87-S97,@;6%Y('=A;G0@=&\*("`@("`J('-E="!T
M:&ES('1O(&]T:&5R('9A;'5E<RX*("`@("`J+PH@("`@=F%R("1?=')A:6QI
M;F=?8V]N=&5X=%]L:6YE<R`](#`["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U
M8W1O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@5&5X=%]$:69F7U)E;F1E<F5R
M*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1P
M87)A;7,@87,@)'!A<F%M(#T^("1V86QU92D@>PH@("`@("`@("`@("`D=B`]
M("=?)R`N("1P87)A;3L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3XD
M=BDI('L*("`@("`@("`@("`@("`@("1T:&ES+3XD=B`]("1V86QU93L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E
M="!A;GD@<F5N9&5R97(@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!!;&P@<&%R86UE=&5R<R!O9B!T:&ES(')E;F1E<F5R(&]B
M:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%R86US*"D*("`@('L*
M("`@("`@("`D<&%R86US(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("AG
M971?;V)J96-T7W9A<G,H)'1H:7,I(&%S("1K(#T^("1V*2!["B`@("`@("`@
M("`@(&EF("@D:WLP?2`]/2`G7R<I('L*("`@("`@("`@("`@("`@("1P87)A
M;7-;<W5B<W1R*"1K+"`Q*5T@/2`D=CL*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!296YD97)S(&$@9&EF9BX*("`@("`J"B`@("`@*B!`<&%R86T@5&5X
M=%]$:69F("1D:69F("!!(%1E>'1?1&EF9B!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!F;W)M871T960@;W5T<'5T+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R96YD97(H)&1I9F8I"B`@("!["B`@("`@("`@
M)'AI(#T@)'EI(#T@,3L*("`@("`@("`D8FQO8VL@/2!F86QS93L*("`@("`@
M("`D8V]N=&5X="`](&%R<F%Y*"D["@H@("`@("`@("1N;&5A9"`]("1T:&ES
M+3Y?;&5A9&EN9U]C;VYT97AT7VQI;F5S.PH@("`@("`@("1N=')A:6P@/2`D
M=&AI<RT^7W1R86EL:6YG7V-O;G1E>'1?;&EN97,["@H@("`@("`@("1O=71P
M=70@/2`D=&AI<RT^7W-T87)T1&EF9B@I.PH*("`@("`@("`D9&EF9G,@/2`D
M9&EF9BT^9V5T1&EF9B@I.PH@("`@("`@(&9O<F5A8V@@*"1D:69F<R!A<R`D
M:2`]/B`D961I="D@>PH@("`@("`@("`@("!I9B`H:7-?82@D961I="P@)U1E
M>'1?1&EF9E]/<%]C;W!Y)RDI('L*("`@("`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2@D8FQO8VLI*2!["B`@("`@("`@("`@("`@("`@("`@)&ME97`@/2`D
M:2`]/2!C;W5N="@D9&EF9G,I("T@,2`_("1N=')A:6P@.B`D;FQE860@*R`D
M;G1R86EL.PH@("`@("`@("`@("`@("`@("`@(&EF("AC;W5N="@D961I="T^
M;W)I9RD@/#T@)&ME97`I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&)L
M;V-K6UT@/2`D961I=#L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&YT<F%I;"D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&-O;G1E>'0@/2!A<G)A>5]S;&EC92@D
M961I="T^;W)I9RP@,"P@)&YT<F%I;"D["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D8FQO8VM;72`]("9N97<@5&5X=%]$:69F7T]P7V-O<'DH)&-O
M;G1E>'0I.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@("`@("1O=71P=70@+CT@)'1H:7,M/E]B;&]C:R@D>#`L("1N
M=')A:6P@*R`D>&D@+2`D>#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D>3`L("1N=')A:6P@*R`D>6D@+2`D
M>3`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D8FQO8VLI.PH@("`@("`@("`@("`@("`@("`@("`@("`D8FQO
M8VL@/2!F86QS93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D8V]N=&5X="`]("1E9&ET+3YO<FEG
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:68@*"%I
M<U]A<G)A>2@D8FQO8VLI*2!["B`@("`@("`@("`@("`@("`@("`@)&-O;G1E
M>'0@/2!A<G)A>5]S;&EC92@D8V]N=&5X="P@8V]U;G0H)&-O;G1E>'0I("T@
M)&YL96%D*3L*("`@("`@("`@("`@("`@("`@("`D>#`@/2`D>&D@+2!C;W5N
M="@D8V]N=&5X="D["B`@("`@("`@("`@("`@("`@("`@)'DP(#T@)'EI("T@
M8V]U;G0H)&-O;G1E>'0I.PH@("`@("`@("`@("`@("`@("`@("1B;&]C:R`]
M(&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@:68@*"1C;VYT97AT*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1B;&]C:UM=(#T@)FYE=R!497AT
M7T1I9F9?3W!?8V]P>2@D8V]N=&5X="D["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&)L;V-K6UT@
M/2`D961I=#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1E9&ET
M+3YO<FEG*2!["B`@("`@("`@("`@("`@("`D>&D@*ST@8V]U;G0H)&5D:70M
M/F]R:6<I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D961I="T^
M9FEN86PI('L*("`@("`@("`@("`@("`@("1Y:2`K/2!C;W5N="@D961I="T^
M9FEN86PI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H
M:7-?87)R87DH)&)L;V-K*2D@>PH@("`@("`@("`@("`D;W5T<'5T("X]("1T
M:&ES+3Y?8FQO8VLH)'@P+"`D>&D@+2`D>#`L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D>3`L("1Y:2`M("1Y,"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1B;&]C:RD["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&]U='!U="`N("1T:&ES+3Y?96YD1&EF9B@I
M.PH@("`@?0H*("`@(&9U;F-T:6]N(%]B;&]C:R@D>&)E9RP@)'AL96XL("1Y
M8F5G+"`D>6QE;BP@)B1E9&ET<RD*("`@('L*("`@("`@("`D;W5T<'5T(#T@
M)'1H:7,M/E]S=&%R=$)L;V-K*"1T:&ES+3Y?8FQO8VM(96%D97(H)'AB96<L
M("1X;&5N+"`D>6)E9RP@)'EL96XI*3L*"B`@("`@("`@9F]R96%C:"`H)&5D
M:71S(&%S("1E9&ET*2!["B`@("`@("`@("`@('-W:71C:"`H<W1R=&]L;W=E
M<BAG971?8VQA<W,H)&5D:70I*2D@>PH@("`@("`@("`@("!C87-E("=T97AT
M7V1I9F9?;W!?8V]P>2<Z"B`@("`@("`@("`@("`@("`D;W5T<'5T("X]("1T
M:&ES+3Y?8V]N=&5X="@D961I="T^;W)I9RD["B`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)W1E>'1?9&EF9E]O<%]A9&0G.@H@
M("`@("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^7V%D9&5D*"1E9&ET
M+3YF:6YA;"D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&-A<V4@)W1E>'1?9&EF9E]O<%]D96QE=&4G.@H@("`@("`@("`@("`@("`@
M)&]U='!U="`N/2`D=&AI<RT^7V1E;&5T960H)&5D:70M/F]R:6<I.PH@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=T97AT7V1I
M9F9?;W!?8VAA;F=E)SH*("`@("`@("`@("`@("`@("1O=71P=70@+CT@)'1H
M:7,M/E]C:&%N9V5D*"1E9&ET+3YO<FEG+"`D961I="T^9FEN86PI.PH@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D;W5T<'5T("X@)'1H:7,M/E]E;F1";&]C:R@I.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]S=&%R=$1I9F8H*0H@("`@>PH@("`@("`@
M(')E='5R;B`G)SL*("`@('T*"B`@("!F=6YC=&EO;B!?96YD1&EF9B@I"B`@
M("!["B`@("`@("`@<F5T=7)N("<G.PH@("`@?0H*("`@(&9U;F-T:6]N(%]B
M;&]C:TAE861E<B@D>&)E9RP@)'AL96XL("1Y8F5G+"`D>6QE;BD*("`@('L*
M("`@("`@("!I9B`H)'AL96X@/B`Q*2!["B`@("`@("`@("`@("1X8F5G("X]
M("<L)R`N("@D>&)E9R`K("1X;&5N("T@,2D["B`@("`@("`@?0H@("`@("`@
M(&EF("@D>6QE;B`^(#$I('L*("`@("`@("`@("`@)'EB96<@+CT@)RPG("X@
M*"1Y8F5G("L@)'EL96X@+2`Q*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D>&)E9R`N("@D>&QE;B`_("@D>6QE;B`_("=C)R`Z("=D)RD@.B`G82<I
M("X@)'EB96<["B`@("!]"@H@("`@9G5N8W1I;VX@7W-T87)T0FQO8VLH)&AE
M861E<BD*("`@('L*("`@("`@("!R971U<FX@)&AE861E<B`N(")<;B(["B`@
M("!]"@H@("`@9G5N8W1I;VX@7V5N9$)L;V-K*"D*("`@('L*("`@("`@("!R
M971U<FX@)R<["B`@("!]"@H@("`@9G5N8W1I;VX@7VQI;F5S*"1L:6YE<RP@
M)'!R969I>"`]("<@)RD*("`@('L*("`@("`@("!R971U<FX@)'!R969I>"`N
M(&EM<&QO9&4H(EQN)'!R969I>"(L("1L:6YE<RD@+B`B7&XB.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]C;VYT97AT*"1L:6YE<RD*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]L:6YE<R@D;&EN97,I.PH@("`@?0H*("`@(&9U;F-T
M:6]N(%]A9&1E9"@D;&EN97,I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?;&EN97,H)&QI;F5S+"`G/B<I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]D
M96QE=&5D*"1L:6YE<RD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]L
M:6YE<R@D;&EN97,L("<\)RD["B`@("!]"@H@("`@9G5N8W1I;VX@7V-H86YG
M960H)&]R:6<L("1F:6YA;"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/E]D96QE=&5D*"1O<FEG*2`N("(M+2U<;B(@+B`D=&AI<RT^7V%D9&5D*"1F
M:6YA;"D["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O5&5X="]$:69F+G!H<```````````````````````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#8S-34T`#$P-3$U-#,S-S0U`#`R,#<T
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@5&5X=%]$:69F"B`J"B`J($=E;F5R86P@05!)(&9O<B!G
M96YE<F%T:6YG(&%N9"!F;W)M871T:6YG(&1I9F9S("T@=&AE(&1I9F9E<F5N
M8V5S(&)E='=E96X*("H@='=O('-E<75E;F-E<R!O9B!S=')I;F=S+@H@*@H@
M*B!4:&4@4$A0(&1I9F8@8V]D92!U<V5D(&EN('1H:7,@<&%C:V%G92!W87,@
M;W)I9VEN86QL>2!W<FET=&5N(&)Y($=E;V9F<F5Y"B`J(%0N($1A:7)I:VD@
M86YD(&ES('5S960@=VET:"!H:7,@<&5R;6ES<VEO;BX*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO5&5X=%]$:69F+T1I9F8N<&AP+'8@,2XQ,2XR+C<@,C`P
M-B\P,B\P-B`P,#HR-3HU,B!J86X@17AP("0*("H*("H@0'!A8VMA9V4@5&5X
M=%]$:69F"B`J($!A=71H;W(@($=E;V9F<F5Y(%0N($1A:7)I:VD@/&1A:7)I
M:VE`9&%I<FEK:2YO<F<^"B`J+PIC;&%S<R!497AT7T1I9F8@>PH*("`@("\J
M*@H@("`@("H@07)R87D@;V8@8VAA;F=E<RX*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V5D:71S.PH*("`@("\J*@H@("`@
M("H@0V]M<'5T97,@9&EF9G,@8F5T=V5E;B!S97%U96YC97,@;V8@<W1R:6YG
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&9R;VU?;&EN97,@($%N
M(&%R<F%Y(&]F('-T<FEN9W,N("!4>7!I8V%L;'D@=&AE<V4@87)E"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&QI;F5S(&9R;VT@82!F:6QE
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1T;U]L:6YE<R`@("!!;B!A<G)A>2!O
M9B!S=')I;F=S+@H@("`@("HO"B`@("!F=6YC=&EO;B!497AT7T1I9F8H)&9R
M;VU?;&EN97,L("1T;U]L:6YE<RD*("`@('L*("`@("`@("!A<G)A>5]W86QK
M*"1F<F]M7VQI;F5S+"!A<G)A>2@D=&AI<RP@)U]T<FEM3F5W;&EN97,G*2D[
M"B`@("`@("`@87)R87E?=V%L:R@D=&]?;&EN97,L(&%R<F%Y*"1T:&ES+"`G
M7W1R:6U.97=L:6YE<R<I*3L*"B`@("`@("`@:68@*&5X=&5N<VEO;E]L;V%D
M960H)WAD:69F)RDI('L*("`@("`@("`@("`@)&5N9VEN92`]("9N97<@5&5X
M=%]$:69F7T5N9VEN95]X9&EF9B@I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1E;F=I;F4@/2`F;F5W(%1E>'1?1&EF9E]%;F=I;F5?;F%T:79E
M*"D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V5D:71S(#T@)&5N9VEN
M92T^9&EF9B@D9G)O;5]L:6YE<RP@)'1O7VQI;F5S*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&%R<F%Y(&]F(&1I9F9E<F5N8V5S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971$:69F*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]E9&ET<SL*("`@('T*"B`@("`O*BH*("`@("`J($-O
M;7!U=&5S(&$@<F5V97)S960@9&EF9BX*("`@("`J"B`@("`@*B!%>&%M<&QE
M.@H@("`@("H@/&-O9&4^"B`@("`@*B`D9&EF9B`]("9N97<@5&5X=%]$:69F
M*"1L:6YE<S$L("1L:6YE<S(I.PH@("`@("H@)')E=B`]("1D:69F+3YR979E
M<G-E*"D["B`@("`@*B`\+V-O9&4^"B`@("`@*@H@("`@("H@0')E='5R;B!4
M97AT7T1I9F8@($$@1&EF9B!O8FIE8W0@<F5P<F5S96YT:6YG('1H92!I;G9E
M<G-E(&]F('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@(&]R:6=I;F%L
M(&1I9F8N("!.;W1E('1H870@=V4@<'5R<&]S96QY(&1O;B=T(')E='5R;B!A
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@<F5F97)E;F-E(&AE<F4L('-I
M;F-E('1H:7,@97-S96YT:6%L;'D@:7,@82!C;&]N92@I"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@;65T:&]D+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M979E<G-E*"D*("`@('L*("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*'IE
M;F1?=F5R<VEO;B@I+"`G,B<L("<^)RDI('L*("`@("`@("`@("`@)')E=B`]
M(&-L;VYE*"1T:&ES*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M<F5V(#T@)'1H:7,["B`@("`@("`@?0H@("`@("`@("1R978M/E]E9&ET<R`]
M(&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]E9&ET<R!A<R`D
M961I="D@>PH@("`@("`@("`@("`D<F5V+3Y?961I='-;72`]("1E9&ET+3YR
M979E<G-E*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5V.PH@("`@
M?0H*("`@("\J*@H@("`@("H@0VAE8VMS(&9O<B!A;B!E;7!T>2!D:69F+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T=V\@<V5Q
M=65N8V5S('=E<F4@:61E;G1I8V%L+@H@("`@("HO"B`@("!F=6YC=&EO;B!I
M<T5M<'1Y*"D*("`@('L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V5D:71S
M(&%S("1E9&ET*2!["B`@("`@("`@("`@(&EF("@A:7-?82@D961I="P@)U1E
M>'1?1&EF9E]/<%]C;W!Y)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-O;7!U=&5S('1H92!L96YG
M=&@@;V8@=&AE($QO;F=E<W0@0V]M;6]N(%-U8G-E<75E;F-E("A,0U,I+@H@
M("`@("H*("`@("`J(%1H:7,@:7,@;6]S=&QY(&9O<B!D:6%G;F]S=&EC('!U
M<G!O<V5S+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&QE
M;F=T:"!O9B!T:&4@3$-3+@H@("`@("HO"B`@("!F=6YC=&EO;B!L8W,H*0H@
M("`@>PH@("`@("`@("1L8W,@/2`P.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3Y?961I=',@87,@)&5D:70I('L*("`@("`@("`@("`@:68@*&ES7V$H)&5D
M:70L("=497AT7T1I9F9?3W!?8V]P>2<I*2!["B`@("`@("`@("`@("`@("`D
M;&-S("L](&-O=6YT*"1E9&ET+3YO<FEG*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("!R971U<FX@)&QC<SL*("`@('T*"B`@("`O*BH*("`@
M("`J($=E=',@=&AE(&]R:6=I;F%L('-E="!O9B!L:6YE<RX*("`@("`J"B`@
M("`@*B!4:&ES(')E8V]N<W1R=6-T<R!T:&4@)&9R;VU?;&EN97,@<&%R86UE
M=&5R('!A<W-E9"!T;R!T:&4@8V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@5&AE(&]R:6=I;F%L('-E<75E;F-E(&]F('-T<FEN
M9W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$]R:6=I;F%L*"D*("`@('L*
M("`@("`@("`D;&EN97,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3Y?961I=',@87,@)&5D:70I('L*("`@("`@("`@("`@:68@*"1E9&ET
M+3YO<FEG*2!["B`@("`@("`@("`@("`@("!A<G)A>5]S<&QI8V4H)&QI;F5S
M+"!C;W5N="@D;&EN97,I+"`P+"`D961I="T^;W)I9RD["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1L:6YE<SL*("`@('T*"B`@
M("`O*BH*("`@("`J($=E=',@=&AE(&9I;F%L('-E="!O9B!L:6YE<RX*("`@
M("`J"B`@("`@*B!4:&ES(')E8V]N<W1R=6-T<R!T:&4@)'1O7VQI;F5S('!A
M<F%M971E<B!P87-S960@=&\@=&AE(&-O;G-T<G5C=&]R+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@(%1H92!S97%U96YC92!O9B!S=')I;F=S+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971&:6YA;"@I"B`@("!["B`@("`@("`@
M)&QI;F5S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V5D
M:71S(&%S("1E9&ET*2!["B`@("`@("`@("`@(&EF("@D961I="T^9FEN86PI
M('L*("`@("`@("`@("`@("`@(&%R<F%Y7W-P;&EC92@D;&EN97,L(&-O=6YT
M*"1L:6YE<RDL(#`L("1E9&ET+3YF:6YA;"D["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1L:6YE<SL*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E;6]V97,@=')A:6QI;F<@;F5W;&EN97,@9G)O;2!A(&QI;F4@
M;V8@=&5X="X@5&AI<R!I<R!M96%N="!T;R!B92!U<V5D"B`@("`@*B!W:71H
M(&%R<F%Y7W=A;&LH*2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1L
M:6YE("!4:&4@;&EN92!T;R!T<FEM+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&ME>2`@5&AE(&EN9&5X(&]F('1H92!L:6YE(&EN('1H92!A<G)A>2X@3F]T
M('5S960N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T<FEM3F5W;&EN97,H)B1L
M:6YE+"`D:V5Y*0H@("`@>PH@("`@("`@("1L:6YE(#T@<W1R7W)E<&QA8V4H
M87)R87DH(EQN(BP@(EQR(BDL("<G+"`D;&EN92D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#:&5C:W,@82!D:69F(&9O<B!V86QI9&ET>2X*("`@("`J"B`@
M("`@*B!4:&ES(&ES(&AE<F4@;VYL>2!F;W(@9&5B=6=G:6YG('!U<G!O<V5S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8VAE8VLH)&9R;VU?;&EN97,L("1T
M;U]L:6YE<RD*("`@('L*("`@("`@("!I9B`H<V5R:6%L:7IE*"1F<F]M7VQI
M;F5S*2`A/2!S97)I86QI>F4H)'1H:7,M/F=E=$]R:6=I;F%L*"DI*2!["B`@
M("`@("`@("`@('1R:6=G97)?97)R;W(H(E)E8V]N<W1R=6-T960@;W)I9VEN
M86P@9&]E<VXG="!M871C:"(L($5?55-%4E]%4E)/4BD["B`@("`@("`@?0H@
M("`@("`@(&EF("AS97)I86QI>F4H)'1O7VQI;F5S*2`A/2!S97)I86QI>F4H
M)'1H:7,M/F=E=$9I;F%L*"DI*2!["B`@("`@("`@("`@('1R:6=G97)?97)R
M;W(H(E)E8V]N<W1R=6-T960@9FEN86P@9&]E<VXG="!M871C:"(L($5?55-%
M4E]%4E)/4BD["B`@("`@("`@?0H*("`@("`@("`D<F5V(#T@)'1H:7,M/G)E
M=F5R<V4H*3L*("`@("`@("!I9B`H<V5R:6%L:7IE*"1T;U]L:6YE<RD@(3T@
M<V5R:6%L:7IE*"1R978M/F=E=$]R:6=I;F%L*"DI*2!["B`@("`@("`@("`@
M('1R:6=G97)?97)R;W(H(E)E=F5R<V5D(&]R:6=I;F%L(&1O97-N)W0@;6%T
M8V@B+"!%7U5315)?15)23U(I.PH@("`@("`@('T*("`@("`@("!I9B`H<V5R
M:6%L:7IE*"1F<F]M7VQI;F5S*2`A/2!S97)I86QI>F4H)')E=BT^9V5T1FEN
M86PH*2DI('L*("`@("`@("`@("`@=')I9V=E<E]E<G)O<B@B4F5V97)S960@
M9FEN86P@9&]E<VXG="!M871C:"(L($5?55-%4E]%4E)/4BD["B`@("`@("`@
M?0H*("`@("`@("`D<')E=G1Y<&4@/2!N=6QL.PH@("`@("`@(&9O<F5A8V@@
M*"1T:&ES+3Y?961I=',@87,@)&5D:70I('L*("`@("`@("`@("`@:68@*"1P
M<F5V='EP92`]/2!G971?8VQA<W,H)&5D:70I*2!["B`@("`@("`@("`@("`@
M("!T<FEG9V5R7V5R<F]R*")%9&ET('-E<75E;F-E(&ES(&YO;BUO<'1I;6%L
M(BP@15]54T527T524D]2*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M<')E=G1Y<&4@/2!G971?8VQA<W,H)&5D:70I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@I]"@HO*BH*("H@)$AO<F1E.B!F<F%M
M97=O<FLO5&5X=%]$:69F+T1I9F8N<&AP+'8@,2XQ,2XR+C<@,C`P-B\P,B\P
M-B`P,#HR-3HU,B!J86X@17AP("0*("H*("H@0'!A8VMA9V4@5&5X=%]$:69F
M"B`J($!A=71H;W(@($=E;V9F<F5Y(%0N($1A:7)I:VD@/&1A:7)I:VE`9&%I
M<FEK:2YO<F<^"B`J+PIC;&%S<R!497AT7TUA<'!E9$1I9F8@97AT96YD<R!4
M97AT7T1I9F8@>PH*("`@("\J*@H@("`@("H@0V]M<'5T97,@82!D:69F(&)E
M='=E96X@<V5Q=65N8V5S(&]F('-T<FEN9W,N"B`@("`@*@H@("`@("H@5&AI
M<R!C86X@8F4@=7-E9"!T;R!C;VUP=71E('1H:6YG<R!L:6ME(&-A<V4M:6YS
M96YS:71V92!D:69F<RP@;W(@9&EF9G,*("`@("`J('=H:6-H(&EG;F]R92!C
M:&%N9V5S(&EN('=H:71E+7-P86-E+@H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D9G)O;5]L:6YE<R`@("`@("`@($%N(&%R<F%Y(&]F('-T<FEN9W,N
M"B`@("`@*B!`<&%R86T@87)R87D@)'1O7VQI;F5S("`@("`@("`@("!!;B!A
M<G)A>2!O9B!S=')I;F=S+@H@("`@("H@0'!A<F%M(&%R<F%Y("1M87!P961?
M9G)O;5]L:6YE<R`@5&AI<R!A<G)A>2!S:&]U;&0@:&%V92!T:&4@<V%M92!S
M:7IE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N
M=6UB97(@;V8@96QE;65N=',@87,@)&9R;VU?;&EN97,N("!4:&4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&5L96UE;G1S(&EN
M("1M87!P961?9G)O;5]L:6YE<R!A;F0*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1M87!P961?=&]?;&EN97,@87)E('=H870@
M:7,@86-T=6%L;'D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&-O;7!A<F5D('=H96X@8V]M<'5T:6YG('1H92!D:69F+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1M87!P961?=&]?;&EN97,@("`@5&AI<R!A<G)A
M>2!S:&]U;&0@:&%V92!T:&4@<V%M92!N=6UB97(*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&]F(&5L96UE;G1S(&%S("1T;U]L
M:6YE<RX*("`@("`J+PH@("`@9G5N8W1I;VX@5&5X=%]-87!P961$:69F*"1F
M<F]M7VQI;F5S+"`D=&]?;&EN97,L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&UA<'!E9%]F<F]M7VQI;F5S+"`D;6%P<&5D7W1O7VQI;F5S*0H@
M("`@>PH@("`@("`@(&%S<V5R="AC;W5N="@D9G)O;5]L:6YE<RD@/3T@8V]U
M;G0H)&UA<'!E9%]F<F]M7VQI;F5S*2D["B`@("`@("`@87-S97)T*&-O=6YT
M*"1T;U]L:6YE<RD@/3T@8V]U;G0H)&UA<'!E9%]T;U]L:6YE<RDI.PH*("`@
M("`@("!P87)E;G0Z.E1E>'1?1&EF9B@D;6%P<&5D7V9R;VU?;&EN97,L("1M
M87!P961?=&]?;&EN97,I.PH*("`@("`@("`D>&D@/2`D>6D@/2`P.PH@("`@
M("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1T:&ES+3Y?961I=',I.R`D
M:2LK*2!["B`@("`@("`@("`@("1O<FEG(#T@)B1T:&ES+3Y?961I='-;)&E=
M+3YO<FEG.PH@("`@("`@("`@("!I9B`H:7-?87)R87DH)&]R:6<I*2!["B`@
M("`@("`@("`@("`@("`D;W)I9R`](&%R<F%Y7W-L:6-E*"1F<F]M7VQI;F5S
M+"`D>&DL(&-O=6YT*"1O<FEG*2D["B`@("`@("`@("`@("`@("`D>&D@*ST@
M8V]U;G0H)&]R:6<I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D9FEN
M86P@/2`F)'1H:7,M/E]E9&ET<ULD:5TM/F9I;F%L.PH@("`@("`@("`@("!I
M9B`H:7-?87)R87DH)&9I;F%L*2D@>PH@("`@("`@("`@("`@("`@)&9I;F%L
M(#T@87)R87E?<VQI8V4H)'1O7VQI;F5S+"`D>6DL(&-O=6YT*"1F:6YA;"DI
M.PH@("`@("`@("`@("`@("`@)'EI("L](&-O=6YT*"1F:6YA;"D["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@I]"@HO*BH*("H@0VQA<W,@=7-E
M9"!I;G1E<FYA;&QY(&)Y($1I9F8@=&\@86-T=6%L;'D@8V]M<'5T92!T:&4@
M9&EF9G,N("!4:&ES(&-L87-S"B`J('5S97,@=&AE('AD:69F(%!%0TP@<&%C
M:V%G92`H:'1T<#HO+W!E8VPN<&AP+FYE="]P86-K86=E+WAD:69F*2!T;R!C
M;VUP=71E"B`J('1H92!D:69F97)E;F-E<R!B971W965N('1H92!T=V\@:6YP
M=70@87)R87ES+@H@*@H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`:&]R
M9&4N;W)G/@H@*B!`<&%C:V%G92!497AT7T1I9F8*("H*("H@0&%C8V5S<R!P
M<FEV871E"B`J+PIC;&%S<R!497AT7T1I9F9?16YG:6YE7WAD:69F('L*"B`@
M("!F=6YC=&EO;B!D:69F*"1F<F]M7VQI;F5S+"`D=&]?;&EN97,I"B`@("![
M"B`@("`@("`@+RH@0V]N=F5R="!T:&4@='=O(&EN<'5T(&%R<F%Y<R!I;G1O
M('-T<FEN9W,@9F]R('AD:69F('!R;V-E<W-I;F<N("HO"B`@("`@("`@)&9R
M;VU?<W1R:6YG(#T@:6UP;&]D92@B7&XB+"`D9G)O;5]L:6YE<RD["B`@("`@
M("`@)'1O7W-T<FEN9R`](&EM<&QO9&4H(EQN(BP@)'1O7VQI;F5S*3L*"B`@
M("`@("`@+RH@1&EF9B!T:&4@='=O('-T<FEN9W,@86YD(&-O;G9E<G0@=&AE
M(')E<W5L="!T;R!A;B!A<G)A>2X@*B\*("`@("`@("`D9&EF9B`]('AD:69F
M7W-T<FEN9U]D:69F*"1F<F]M7W-T<FEN9RP@)'1O7W-T<FEN9RP@8V]U;G0H
M)'1O7VQI;F5S*2D["B`@("`@("`@)&1I9F8@/2!E>'!L;V1E*")<;B(L("1D
M:69F*3L*"B`@("`@("`@+RH@5V%L:R!T:')O=6=H('1H92!D:69F(&]N92!L
M:6YE(&%T(&$@=&EM92X@(%=E(&)U:6QD('1H92`D961I=',*("`@("`@("`@
M*B!A<G)A>2!O9B!D:69F(&]P97)A=&EO;G,@8GD@<F5A9&EN9R!T:&4@9FER
M<W0@8VAA<F%C=&5R(&]F('1H90H@("`@("`@("`J('AD:69F(&]U='!U="`H
M=VAI8V@@:7,@:6X@=&AE(")U;FEF:65D(&1I9F8B(&9O<FUA="DN"B`@("`@
M("`@("H*("`@("`@("`@*B!.;W1E('1H870@=V4@9&]N)W0@:&%V92!E;F]U
M9V@@:6YF;W)M871I;VX@=&\@9&5T96-T(")C:&%N9V5D(@H@("`@("`@("`J
M(&QI;F5S('5S:6YG('1H:7,@87!P<F]A8V@L('-O('=E(&-A;B=T(&%D9"!4
M97AT7T1I9F9?3W!?8VAA;F=E9`H@("`@("`@("`J(&EN<W1A;F-E<R!T;R!T
M:&4@)&5D:71S(&%R<F%Y+B`@5&AE(')E<W5L="!I<R!S=&EL;"!P97)F96-T
M;'D*("`@("`@("`@*B!V86QI9"P@86QB96ET(&$@;&ET=&QE(&QE<W,@9&5S
M8W)I<'1I=F4@86YD(&5F9FEC:65N="X@*B\*("`@("`@("`D961I=',@/2!A
M<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1D:69F(&%S("1L:6YE*2!["B`@
M("`@("`@("`@('-W:71C:"`H)&QI;F5;,%TI('L*("`@("`@("`@("`@8V%S
M92`G("<Z"B`@("`@("`@("`@("`@("`D961I='-;72`]("9N97<@5&5X=%]$
M:69F7T]P7V-O<'DH87)R87DH<W5B<W1R*"1L:6YE+"`Q*2DI.PH@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("<K)SH*("`@("`@
M("`@("`@("`@("1E9&ET<UM=(#T@)FYE=R!497AT7T1I9F9?3W!?861D*&%R
M<F%Y*'-U8G-T<B@D;&EN92P@,2DI*3L*("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@8V%S92`G+2<Z"B`@("`@("`@("`@("`@("`D961I
M='-;72`]("9N97<@5&5X=%]$:69F7T]P7V1E;&5T92AA<G)A>2AS=6)S='(H
M)&QI;F4L(#$I*2D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1E9&ET<SL*("`@('T*
M"GT*"B\J*@H@*B!#;&%S<R!U<V5D(&EN=&5R;F%L;'D@8GD@1&EF9B!T;R!A
M8W1U86QL>2!C;VUP=71E('1H92!D:69F<RX@(%1H:7,@8VQA<W,@:7,*("H@
M:6UP;&5M96YT960@=7-I;F<@;F%T:79E(%!(4"!C;V1E+@H@*@H@*B!4:&4@
M86QG;W)I=&AM('5S960@:&5R92!I<R!M;W-T;'D@;&EF=&5D(&9R;VT@=&AE
M('!E<FP@;6]D=6QE"B`J($%L9V]R:71H;3HZ1&EF9B`H=F5R<VEO;B`Q+C`V
M*2!B>2!.960@2V]N>BP@=VAI8V@@:7,@879A:6QA8FQE(&%T.@H@*B!H='1P
M.B\O=W=W+G!E<FPN8V]M+T-004XO875T:&]R<R]I9"].+TY%+TY%1$M/3EHO
M06QG;W)I=&AM+41I9F8M,2XP-BYZ:7`*("H*("H@36]R92!I9&5A<R!A<F4@
M=&%K96X@9G)O;3H*("H@:'1T<#HO+W=W=RYI8W,N=6-I+F5D=2]^97!P<W1E
M:6XO,38Q+SDV,#(R.2YH=&UL"B`J"B`J(%-O;64@:61E87,@*&%N9"!A(&)I
M="!O9B!C;V1E*2!A<F4@=&%K96X@9G)O;2!A;F%L>7IE+F,L(&]F($=.50H@
M*B!D:69F=71I;',M,BXW+"!W:&EC:"!C86X@8F4@9F]U;F0@870Z"B`J(&9T
M<#HO+V=N=61I<W0N9VYU+F]R9R]P=6(O9VYU+V1I9F9U=&EL<R]D:69F=71I
M;',M,BXW+G1A<BYG>@H@*@H@*B!3;VUE(&ED96%S("AS=6)D:79I<VEO;B!B
M>2!.0TA53DM3(#X@,BP@86YD('-O;64@;W!T:6UI>F%T:6]N<RD@87)E(&9R
M;VT*("H@1V5O9F9R97D@5"X@1&%I<FEK:2`\9&%I<FEK:4!D86ER:6MI+F]R
M9SXN(%1H92!O<FEG:6YA;"!02%`@=F5R<VEO;B!O9B!T:&ES"B`J(&-O9&4@
M=V%S('=R:71T96X@8GD@:&EM+"!A;F0@:7,@=7-E9"]A9&%P=&5D('=I=&@@
M:&ES('!E<FUI<W-I;VXN"B`J"B`J($!A=71H;W(@($=E;V9F<F5Y(%0N($1A
M:7)I:VD@/&1A:7)I:VE`9&%I<FEK:2YO<F<^"B`J($!P86-K86=E(%1E>'1?
M1&EF9@H@*@H@*B!`86-C97-S('!R:79A=&4*("HO"F-L87-S(%1E>'1?1&EF
M9E]%;F=I;F5?;F%T:79E('L*"B`@("!F=6YC=&EO;B!D:69F*"1F<F]M7VQI
M;F5S+"`D=&]?;&EN97,I"B`@("!["B`@("`@("`@)&Y?9G)O;2`](&-O=6YT
M*"1F<F]M7VQI;F5S*3L*("`@("`@("`D;E]T;R`](&-O=6YT*"1T;U]L:6YE
M<RD["@H@("`@("`@("1T:&ES+3YX8VAA;F=E9"`]("1T:&ES+3YY8VAA;F=E
M9"`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/GAV(#T@)'1H:7,M/GEV(#T@
M87)R87DH*3L*("`@("`@("`D=&AI<RT^>&EN9"`]("1T:&ES+3YY:6YD(#T@
M87)R87DH*3L*("`@("`@("!U;G-E="@D=&AI<RT^<V5Q*3L*("`@("`@("!U
M;G-E="@D=&AI<RT^:6Y?<V5Q*3L*("`@("`@("!U;G-E="@D=&AI<RT^;&-S
M*3L*"B`@("`@("`@+R\@4VMI<"!L96%D:6YG(&-O;6UO;B!L:6YE<RX*("`@
M("`@("!F;W(@*"1S:VEP(#T@,#L@)'-K:7`@/"`D;E]F<F]M("8F("1S:VEP
M(#P@)&Y?=&\[("1S:VEP*RLI('L*("`@("`@("`@("`@:68@*"1F<F]M7VQI
M;F5S6R1S:VEP72`A/3T@)'1O7VQI;F5S6R1S:VEP72D@>PH@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M
M/GAC:&%N9V5D6R1S:VEP72`]("1T:&ES+3YY8VAA;F=E9%LD<VMI<%T@/2!F
M86QS93L*("`@("`@("!]"@H@("`@("`@("\O(%-K:7`@=')A:6QI;F<@8V]M
M;6]N(&QI;F5S+@H@("`@("`@("1X:2`]("1N7V9R;VT[("1Y:2`]("1N7W1O
M.PH@("`@("`@(&9O<B`H)&5N9'-K:7`@/2`P.R`M+21X:2`^("1S:VEP("8F
M("TM)'EI(#X@)'-K:7`[("1E;F1S:VEP*RLI('L*("`@("`@("`@("`@:68@
M*"1F<F]M7VQI;F5S6R1X:5T@(3T]("1T;U]L:6YE<ULD>6E=*2!["B`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M=&AI<RT^>&-H86YG961;)'AI72`]("1T:&ES+3YY8VAA;F=E9%LD>6E=(#T@
M9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O+R!)9VYO<F4@;&EN97,@=VAI
M8V@@9&\@;F]T(&5X:7-T(&EN(&)O=&@@9FEL97,N"B`@("`@("`@9F]R("@D
M>&D@/2`D<VMI<#L@)'AI(#P@)&Y?9G)O;2`M("1E;F1S:VEP.R`D>&DK*RD@
M>PH@("`@("`@("`@("`D>&AA<VA;)&9R;VU?;&EN97-;)'AI75T@/2`Q.PH@
M("`@("`@('T*("`@("`@("!F;W(@*"1Y:2`]("1S:VEP.R`D>6D@/"`D;E]T
M;R`M("1E;F1S:VEP.R`D>6DK*RD@>PH@("`@("`@("`@("`D;&EN92`]("1T
M;U]L:6YE<ULD>6E=.PH@("`@("`@("`@("!I9B`H*"1T:&ES+3YY8VAA;F=E
M9%LD>6E=(#T@96UP='DH)'AH87-H6R1L:6YE72DI*2!["B`@("`@("`@("`@
M("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D>6AA
M<VA;)&QI;F5=(#T@,3L*("`@("`@("`@("`@)'1H:7,M/GEV6UT@/2`D;&EN
M93L*("`@("`@("`@("`@)'1H:7,M/GEI;F1;72`]("1Y:3L*("`@("`@("!]
M"B`@("`@("`@9F]R("@D>&D@/2`D<VMI<#L@)'AI(#P@)&Y?9G)O;2`M("1E
M;F1S:VEP.R`D>&DK*RD@>PH@("`@("`@("`@("`D;&EN92`]("1F<F]M7VQI
M;F5S6R1X:5T["B`@("`@("`@("`@(&EF("@H)'1H:7,M/GAC:&%N9V5D6R1X
M:5T@/2!E;7!T>2@D>6AA<VA;)&QI;F5=*2DI('L*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3YX
M=EM=(#T@)&QI;F4["B`@("`@("`@("`@("1T:&ES+3YX:6YD6UT@/2`D>&D[
M"B`@("`@("`@?0H*("`@("`@("`O+R!&:6YD('1H92!,0U,N"B`@("`@("`@
M)'1H:7,M/E]C;VUP87)E<V5Q*#`L(&-O=6YT*"1T:&ES+3YX=BDL(#`L(&-O
M=6YT*"1T:&ES+3YY=BDI.PH*("`@("`@("`O+R!-97)G92!E9&ET<R!W:&5N
M('!O<W-I8FQE+@H@("`@("`@("1T:&ES+3Y?<VAI9G1";W5N9&%R:65S*"1F
M<F]M7VQI;F5S+"`D=&AI<RT^>&-H86YG960L("1T:&ES+3YY8VAA;F=E9"D[
M"B`@("`@("`@)'1H:7,M/E]S:&EF=$)O=6YD87)I97,H)'1O7VQI;F5S+"`D
M=&AI<RT^>6-H86YG960L("1T:&ES+3YX8VAA;F=E9"D["@H@("`@("`@("\O
M($-O;7!U=&4@=&AE(&5D:70@;W!E<F%T:6]N<RX*("`@("`@("`D961I=',@
M/2!A<G)A>2@I.PH@("`@("`@("1X:2`]("1Y:2`](#`["B`@("`@("`@=VAI
M;&4@*"1X:2`\("1N7V9R;VT@?'P@)'EI(#P@)&Y?=&\I('L*("`@("`@("`@
M("`@87-S97)T*"1Y:2`\("1N7W1O('Q\("1T:&ES+3YX8VAA;F=E9%LD>&E=
M*3L*("`@("`@("`@("`@87-S97)T*"1X:2`\("1N7V9R;VT@?'P@)'1H:7,M
M/GEC:&%N9V5D6R1Y:5TI.PH*("`@("`@("`@("`@+R\@4VMI<"!M871C:&EN
M9R`B<VYA:V4B+@H@("`@("`@("`@("`D8V]P>2`](&%R<F%Y*"D["B`@("`@
M("`@("`@('=H:6QE("@D>&D@/"`D;E]F<F]M("8F("1Y:2`\("1N7W1O"B`@
M("`@("`@("`@("`@("`@("`F)B`A)'1H:7,M/GAC:&%N9V5D6R1X:5T@)B8@
M(21T:&ES+3YY8VAA;F=E9%LD>6E=*2!["B`@("`@("`@("`@("`@("`D8V]P
M>5M=(#T@)&9R;VU?;&EN97-;)'AI*RM=.PH@("`@("`@("`@("`@("`@*RLD
M>6D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1C;W!Y*2!["B`@
M("`@("`@("`@("`@("`D961I='-;72`]("9N97<@5&5X=%]$:69F7T]P7V-O
M<'DH)&-O<'DI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!&:6YD
M(&1E;&5T97,@)B!A9&1S+@H@("`@("`@("`@("`D9&5L971E(#T@87)R87DH
M*3L*("`@("`@("`@("`@=VAI;&4@*"1X:2`\("1N7V9R;VT@)B8@)'1H:7,M
M/GAC:&%N9V5D6R1X:5TI('L*("`@("`@("`@("`@("`@("1D96QE=&5;72`]
M("1F<F]M7VQI;F5S6R1X:2LK73L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@)&%D9"`](&%R<F%Y*"D["B`@("`@("`@("`@('=H:6QE("@D>6D@/"`D
M;E]T;R`F)B`D=&AI<RT^>6-H86YG961;)'EI72D@>PH@("`@("`@("`@("`@
M("`@)&%D9%M=(#T@)'1O7VQI;F5S6R1Y:2LK73L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@:68@*"1D96QE=&4@)B8@)&%D9"D@>PH@("`@("`@("`@
M("`@("`@)&5D:71S6UT@/2`F;F5W(%1E>'1?1&EF9E]/<%]C:&%N9V4H)&1E
M;&5T92P@)&%D9"D["B`@("`@("`@("`@('T@96QS96EF("@D9&5L971E*2![
M"B`@("`@("`@("`@("`@("`D961I='-;72`]("9N97<@5&5X=%]$:69F7T]P
M7V1E;&5T92@D9&5L971E*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1A9&0I
M('L*("`@("`@("`@("`@("`@("1E9&ET<UM=(#T@)FYE=R!497AT7T1I9F9?
M3W!?861D*"1A9&0I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&5D:71S.PH@("`@?0H*("`@("\J*@H@("`@("H@1&EV:61E
M<R!T:&4@3&%R9V5S="!#;VUM;VX@4W5B<V5Q=65N8V4@*$Q#4RD@;V8@=&AE
M('-E<75E;F-E<R`H6$]&1BP*("`@("`J(%A,24TI(&%N9"`H64]&1BP@64Q)
M32D@:6YT;R!.0TA53DM3(&%P<')O>&EM871E;'D@97%U86QL>2!S:7IE9`H@
M("`@("H@<V5G;65N=',N"B`@("`@*@H@("`@("H@4F5T=7)N<R`H3$-3+"!0
M5%,I+B`@3$-3(&ES('1H92!L96YG=&@@;V8@=&AE($Q#4RX@4%13(&ES(&%N
M(&%R<F%Y(&]F"B`@("`@*B!.0TA53DM3*S$@*%@L(%DI(&EN9&5X97,@9VEV
M:6YG('1H92!D:79I;F<@<&]I;G1S(&)E='=E96X@<W5B"B`@("`@*B!S97%U
M96YC97,N("!4:&4@9FER<W0@<W5B+7-E<75E;F-E(&ES(&-O;G1A:6YE9"!I
M;B`H6#`L(%@Q*2P@*%DP+"!9,2DL"B`@("`@*B!T:&4@<V5C;VYD(&EN("A8
M,2P@6#(I+"`H63$L(%DR*2!A;F0@<V\@;VXN("!.;W1E('1H870@*%@P+"!9
M,"D@/3T*("`@("`J("A83T9&+"!93T9&*2!A;F0@*%A;3D-(54Y+4UTL(%E;
M3D-(54Y+4UTI(#T]("A83$E-+"!93$E-*2X*("`@("`J"B`@("`@*B!4:&ES
M(&9U;F-T:6]N(&%S<W5M97,@=&AA="!T:&4@9FER<W0@;&EN97,@;V8@=&AE
M('-P96-I9FEE9"!P;W)T:6]N<R!O9@H@("`@("H@=&AE('1W;R!F:6QE<R!D
M;R!N;W0@;6%T8V@L(&%N9"!L:6ME=VES92!T:&%T('1H92!L87-T(&QI;F5S
M(&1O(&YO=`H@("`@("H@;6%T8V@N("!4:&4@8V%L;&5R(&UU<W0@=')I;2!M
M871C:&EN9R!L:6YE<R!F<F]M('1H92!B96=I;FYI;F<@86YD(&5N9`H@("`@
M("H@;V8@=&AE('!O<G1I;VYS(&ET(&ES(&=O:6YG('1O('-P96-I9GDN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]D:6%G("@D>&]F9BP@)'AL:6TL("1Y;V9F
M+"`D>6QI;2P@)&YC:'5N:W,I"B`@("!["B`@("`@("`@)&9L:7`@/2!F86QS
M93L*"B`@("`@("`@:68@*"1X;&EM("T@)'AO9F8@/B`D>6QI;2`M("1Y;V9F
M*2!["B`@("`@("`@("`@("\J(%1H:6YG<R!S965M<R!F87-T97(@*$DG;2!N
M;W0@<W5R92!)('5N9&5R<W1A;F0@=VAY*2!W:&5N('1H90H@("`@("`@("`@
M("`@*B!S:&]R=&5S="!S97%U96YC92!I<R!I;B!8+B`J+PH@("`@("`@("`@
M("`D9FQI<"`]('1R=64["B`@("`@("`@("`@(&QI<W0@*"1X;V9F+"`D>&QI
M;2P@)'EO9F8L("1Y;&EM*0H@("`@("`@("`@("`@("`@/2!A<G)A>2@D>6]F
M9BP@)'EL:6TL("1X;V9F+"`D>&QI;2D["B`@("`@("`@?0H*("`@("`@("!I
M9B`H)&9L:7`I('L*("`@("`@("`@("`@9F]R("@D:2`]("1Y;&EM("T@,3L@
M)&D@/CT@)'EO9F8[("1I+2TI('L*("`@("`@("`@("`@("`@("1Y;6%T8VAE
M<ULD=&AI<RT^>'9;)&E=75M=(#T@)&D["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!F;W(@*"1I(#T@)'EL:6T@+2`Q.R`D
M:2`^/2`D>6]F9CL@)&DM+2D@>PH@("`@("`@("`@("`@("`@)'EM871C:&5S
M6R1T:&ES+3YY=ELD:5U=6UT@/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@)'1H:7,M/FQC<R`](#`["B`@("`@("`@)'1H:7,M/G-E
M<5LP73T@)'EO9F8@+2`Q.PH@("`@("`@("1T:&ES+3YI;E]S97$@/2!A<G)A
M>2@I.PH@("`@("`@("1Y;6ED<ULP72`](&%R<F%Y*"D["@H@("`@("`@("1N
M=6UE<B`]("1X;&EM("T@)'AO9F8@*R`D;F-H=6YK<R`M(#$["B`@("`@("`@
M)'@@/2`D>&]F9CL*("`@("`@("!F;W(@*"1C:'5N:R`](#`[("1C:'5N:R`\
M("1N8VAU;FMS.R`D8VAU;FLK*RD@>PH@("`@("`@("`@("!I9B`H)&-H=6YK
M(#X@,"D@>PH@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P]("1T
M:&ES+3YL8W,[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`D>6UI9'-;
M)&E=6R1C:'5N:R`M(#%=(#T@)'1H:7,M/G-E<5LD:5T["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1X,2`]("1X;V9F
M("L@*&EN="DH*"1N=6UE<B`K("@D>&QI;2TD>&]F9BDJ)&-H=6YK*2`O("1N
M8VAU;FMS*3L*("`@("`@("`@("`@9F]R("@[("1X(#P@)'@Q.R`D>"LK*2![
M"B`@("`@("`@("`@("`@("`D;&EN92`]("1F;&EP(#\@)'1H:7,M/GEV6R1X
M72`Z("1T:&ES+3YX=ELD>%T["B`@("`@("`@("`@("`@("!I9B`H96UP='DH
M)'EM871C:&5S6R1L:6YE72DI('L*("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1M871C
M:&5S(#T@)'EM871C:&5S6R1L:6YE73L*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1M871C:&5S(&%S("1Y*2!["B`@("`@("`@("`@("`@("`@("`@:68@
M*&5M<'1Y*"1T:&ES+3YI;E]S97%;)'E=*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D:R`]("1T:&ES+3Y?;&-S4&]S*"1Y*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@87-S97)T*"1K(#X@,"D["B`@("`@("`@("`@("`@("`@
M("`@("`@("1Y;6ED<ULD:UT@/2`D>6UI9'-;)&L@+2`Q73L*("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@('=H:6QE("AL:7-T
M*"1J=6YK+"`D>2D@/2!E86-H*"1M871C:&5S*2D@>PH@("`@("`@("`@("`@
M("`@("`@(&EF("@D>2`^("1T:&ES+3YS97%;)&L@+2`Q72D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("!A<W-E<G0H)'D@/"`D=&AI<RT^<V5Q6R1K72D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("\J($]P=&EM:7IA=&EO;CH@=&AI
M<R!I<R!A(&-O;6UO;B!C87-E.B!N97AT(&UA=&-H(&ES"B`@("`@("`@("`@
M("`@("`@("`@("`@("`J(&IU<W0@<F5P;&%C:6YG('!R979I;W5S(&UA=&-H
M+B`J+PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^:6Y?<V5Q6R1T
M:&ES+3YS97%;)&M=72`](&9A;'-E.PH@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5Q6R1K72`]("1Y.PH@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^:6Y?<V5Q6R1Y72`](#$["B`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*&5M<'1Y*"1T:&ES+3YI;E]S97%;)'E=*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D:R`]("1T:&ES+3Y?;&-S4&]S*"1Y*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@87-S97)T*"1K(#X@,"D["B`@("`@("`@
M("`@("`@("`@("`@("`@("1Y;6ED<ULD:UT@/2`D>6UI9'-;)&L@+2`Q73L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1S97!S6UT@/2`D9FQI<"`_
M(&%R<F%Y*"1Y;V9F+"`D>&]F9BD@.B!A<G)A>2@D>&]F9BP@)'EO9F8I.PH@
M("`@("`@("1Y;6ED(#T@)'EM:61S6R1T:&ES+3YL8W-=.PH@("`@("`@(&9O
M<B`H)&X@/2`P.R`D;B`\("1N8VAU;FMS("T@,3L@)&XK*RD@>PH@("`@("`@
M("`@("`D>#$@/2`D>&]F9B`K("AI;G0I*"@D;G5M97(@*R`H)'AL:6T@+2`D
M>&]F9BD@*B`D;BD@+R`D;F-H=6YK<RD["B`@("`@("`@("`@("1Y,2`]("1Y
M;6ED6R1N72`K(#$["B`@("`@("`@("`@("1S97!S6UT@/2`D9FQI<"`_(&%R
M<F%Y*"1Y,2P@)'@Q*2`Z(&%R<F%Y*"1X,2P@)'DQ*3L*("`@("`@("!]"B`@
M("`@("`@)'-E<'-;72`]("1F;&EP(#\@87)R87DH)'EL:6TL("1X;&EM*2`Z
M(&%R<F%Y*"1X;&EM+"`D>6QI;2D["@H@("`@("`@(')E='5R;B!A<G)A>2@D
M=&AI<RT^;&-S+"`D<V5P<RD["B`@("!]"@H@("`@9G5N8W1I;VX@7VQC<U!O
M<R@D>7!O<RD*("`@('L*("`@("`@("`D96YD(#T@)'1H:7,M/FQC<SL*("`@
M("`@("!I9B`H)&5N9"`]/2`P('Q\("1Y<&]S(#X@)'1H:7,M/G-E<5LD96YD
M72D@>PH@("`@("`@("`@("`D=&AI<RT^<V5Q6RLK)'1H:7,M/FQC<UT@/2`D
M>7!O<SL*("`@("`@("`@("`@)'1H:7,M/FEN7W-E<5LD>7!O<UT@/2`Q.PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/FQC<SL*("`@("`@("!]"@H@("`@
M("`@("1B96<@/2`Q.PH@("`@("`@('=H:6QE("@D8F5G(#P@)&5N9"D@>PH@
M("`@("`@("`@("`D;6ED(#T@*&EN="DH*"1B96<@*R`D96YD*2`O(#(I.PH@
M("`@("`@("`@("!I9B`H)'EP;W,@/B`D=&AI<RT^<V5Q6R1M:61=*2!["B`@
M("`@("`@("`@("`@("`D8F5G(#T@)&UI9"`K(#$["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D96YD(#T@)&UI9#L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@87-S97)T*"1Y<&]S("$]("1T:&ES
M+3YS97%;)&5N9%TI.PH*("`@("`@("`D=&AI<RT^:6Y?<V5Q6R1T:&ES+3YS
M97%;)&5N9%U=(#T@9F%L<V4["B`@("`@("`@)'1H:7,M/G-E<5LD96YD72`]
M("1Y<&]S.PH@("`@("`@("1T:&ES+3YI;E]S97%;)'EP;W-=(#T@,3L*("`@
M("`@("!R971U<FX@)&5N9#L*("`@('T*"B`@("`O*BH*("`@("`J($9I;F1S
M($Q#4R!O9B!T=V\@<V5Q=65N8V5S+@H@("`@("H*("`@("`J(%1H92!R97-U
M;'1S(&%R92!R96-O<F1E9"!I;B!T:&4@=F5C=&]R<R`D=&AI<RT^>W@L>7UC
M:&%N9V5D6UTL(&)Y"B`@("`@*B!S=&]R:6YG(&$@,2!I;B!T:&4@96QE;65N
M="!F;W(@96%C:"!L:6YE('1H870@:7,@86X@:6YS97)T:6]N(&]R"B`@("`@
M*B!D96QE=&EO;B`H:64N(&ES(&YO="!I;B!T:&4@3$-3*2X*("`@("`J"B`@
M("`@*B!4:&4@<W5B<V5Q=65N8V4@;V8@9FEL92`P(&ES("A83T9&+"!83$E-
M*2!A;F0@;&EK97=I<V4@9F]R(&9I;&4@,2X*("`@("`J"B`@("`@*B!.;W1E
M('1H870@6$Q)32P@64Q)32!A<F4@97AC;'5S:79E(&)O=6YD<RX@($%L;"!L
M:6YE(&YU;6)E<G,@87)E"B`@("`@*B!O<FEG:6XM,"!A;F0@9&ES8V%R9&5D
M(&QI;F5S(&%R92!N;W0@8V]U;G1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V-O;7!A<F5S97$@*"1X;V9F+"`D>&QI;2P@)'EO9F8L("1Y;&EM*0H@("`@
M>PH@("`@("`@("\J(%-L:61E(&1O=VX@=&AE(&)O='1O;2!I;FET:6%L(&1I
M86=O;F%L+B`J+PH@("`@("`@('=H:6QE("@D>&]F9B`\("1X;&EM("8F("1Y
M;V9F(#P@)'EL:6T*("`@("`@("`@("`@("`@)B8@)'1H:7,M/GAV6R1X;V9F
M72`]/2`D=&AI<RT^>79;)'EO9F9=*2!["B`@("`@("`@("`@("LK)'AO9F8[
M"B`@("`@("`@("`@("LK)'EO9F8["B`@("`@("`@?0H*("`@("`@("`O*B!3
M;&ED92!U<"!T:&4@=&]P(&EN:71I86P@9&EA9V]N86PN("HO"B`@("`@("`@
M=VAI;&4@*"1X;&EM(#X@)'AO9F8@)B8@)'EL:6T@/B`D>6]F9@H@("`@("`@
M("`@("`@("`F)B`D=&AI<RT^>'9;)'AL:6T@+2`Q72`]/2`D=&AI<RT^>79;
M)'EL:6T@+2`Q72D@>PH@("`@("`@("`@("`M+21X;&EM.PH@("`@("`@("`@
M("`M+21Y;&EM.PH@("`@("`@('T*"B`@("`@("`@:68@*"1X;V9F(#T]("1X
M;&EM('Q\("1Y;V9F(#T]("1Y;&EM*2!["B`@("`@("`@("`@("1L8W,@/2`P
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J(%1H:7,@:7,@860@
M:&]C(&)U="!S965M<R!T;R!W;W)K('=E;&PN("`D;F-H=6YK<R`]"B`@("`@
M("`@("`@("`J('-Q<G0H;6EN*"1X;&EM("T@)'AO9F8L("1Y;&EM("T@)'EO
M9F8I("\@,BXU*3L@)&YC:'5N:W,@/0H@("`@("`@("`@("`@*B!M87@H,BQM
M:6XH."PH:6YT*21N8VAU;FMS*2D[("HO"B`@("`@("`@("`@("1N8VAU;FMS
M(#T@;6EN*#<L("1X;&EM("T@)'AO9F8L("1Y;&EM("T@)'EO9F8I("L@,3L*
M("`@("`@("`@("`@;&ES="@D;&-S+"`D<V5P<RD*("`@("`@("`@("`@("`@
M(#T@)'1H:7,M/E]D:6%G*"1X;V9F+"`D>&QI;2P@)'EO9F8L("1Y;&EM+"`D
M;F-H=6YK<RD["B`@("`@("`@?0H*("`@("`@("!I9B`H)&QC<R`]/2`P*2![
M"B`@("`@("`@("`@("\J(%@@86YD(%D@<V5Q=65N8V5S(&AA=F4@;F\@8V]M
M;6]N('-U8G-E<75E;F-E.B!M87)K(&%L;`H@("`@("`@("`@("`@*B!C:&%N
M9V5D+B`J+PH@("`@("`@("`@("!W:&EL92`H)'EO9F8@/"`D>6QI;2D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/GEC:&%N9V5D6R1T:&ES+3YY:6YD6R1Y
M;V9F*RM=72`](#$["B`@("`@("`@("`@('T*("`@("`@("`@("`@=VAI;&4@
M*"1X;V9F(#P@)'AL:6TI('L*("`@("`@("`@("`@("`@("1T:&ES+3YX8VAA
M;F=E9%LD=&AI<RT^>&EN9%LD>&]F9BLK75T@/2`Q.PH@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@57-E('1H92!P87)T
M:71I;VYS('1O('-P;&ET('1H:7,@<')O8FQE;2!I;G1O('-U8G!R;V)L96US
M+B`J+PH@("`@("`@("`@("!R97-E="@D<V5P<RD["B`@("`@("`@("`@("1P
M=#$@/2`D<V5P<ULP73L*("`@("`@("`@("`@=VAI;&4@*"1P=#(@/2!N97AT
M*"1S97!S*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VUP87)E<V5Q
M("@D<'0Q6S!=+"`D<'0R6S!=+"`D<'0Q6S%=+"`D<'0R6S%=*3L*("`@("`@
M("`@("`@("`@("1P=#$@/2`D<'0R.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@061J=7-T<R!I;G-E<G1S+V1E;&5T
M97,@;V8@:61E;G1I8V%L(&QI;F5S('1O(&IO:6X@8VAA;F=E<R!A<R!M=6-H
M(&%S"B`@("`@*B!P;W-S:6)L92X*("`@("`J"B`@("`@*B!792!D;R!S;VUE
M=&AI;F<@=VAE;B!A(')U;B!O9B!C:&%N9V5D(&QI;F5S(&EN8VQU9&4@82!L
M:6YE(&%T(&]N92!E;F0*("`@("`J(&%N9"!H87,@86X@97AC;'5D960L(&ED
M96YT:6-A;"!L:6YE(&%T('1H92!O=&AE<BX@(%=E(&%R92!F<F5E('1O"B`@
M("`@*B!C:&]O<V4@=VAI8V@@:61E;G1I8V%L(&QI;F4@:7,@:6YC;'5D960N
M("!@8V]M<&%R97-E<2<@=7-U86QL>2!C:&]O<V5S"B`@("`@*B!T:&4@;VYE
M(&%T('1H92!B96=I;FYI;F<L(&)U="!U<W5A;&QY(&ET(&ES(&-L96%N97(@
M=&\@8V]N<VED97(@=&AE"B`@("`@*B!F;VQL;W=I;F<@:61E;G1I8V%L(&QI
M;F4@=&\@8F4@=&AE(")C:&%N9V4B+@H@("`@("H*("`@("`J(%1H:7,@:7,@
M97AT<F%C=&5D('9E<F)A=&EM(&9R;VT@86YA;'EZ92YC("A'3E4@9&EF9G5T
M:6QS+3(N-RDN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S:&EF=$)O=6YD87)I
M97,H)&QI;F5S+"`F)&-H86YG960L("1O=&AE<E]C:&%N9V5D*0H@("`@>PH@
M("`@("`@("1I(#T@,#L*("`@("`@("`D:B`](#`["@H@("`@("`@(&%S<V5R
M="@G8V]U;G0H)&QI;F5S*2`]/2!C;W5N="@D8VAA;F=E9"DG*3L*("`@("`@
M("`D;&5N(#T@8V]U;G0H)&QI;F5S*3L*("`@("`@("`D;W1H97)?;&5N(#T@
M8V]U;G0H)&]T:&5R7V-H86YG960I.PH*("`@("`@("!W:&EL92`H,2D@>PH@
M("`@("`@("`@("`O*B!38V%N(&9O<G=A<F0@=&\@9FEN9"!T:&4@8F5G:6YN
M:6YG(&]F(&%N;W1H97(@<G5N(&]F"B`@("`@("`@("`@("`J(&-H86YG97,N
M($%L<V\@:V5E<"!T<F%C:R!O9B!T:&4@8V]R<F5S<&]N9&EN9R!P;VEN="!I
M;B!T:&4*("`@("`@("`@("`@("H@;W1H97(@9FEL92X*("`@("`@("`@("`@
M("H*("`@("`@("`@("`@("H@5&AR;W5G:&]U="!T:&ES(&-O9&4L("1I(&%N
M9"`D:B!A<F4@861J=7-T960@=&]G971H97(@<V\@=&AA=`H@("`@("`@("`@
M("`@*B!T:&4@9FER<W0@)&D@96QE;65N=',@;V8@)&-H86YG960@86YD('1H
M92!F:7)S="`D:B!E;&5M96YT<R!O9@H@("`@("`@("`@("`@*B`D;W1H97)?
M8VAA;F=E9"!B;W1H(&-O;G1A:6X@=&AE('-A;64@;G5M8F5R(&]F('IE<F]S
M("AU;F-H86YG960*("`@("`@("`@("`@("H@;&EN97,I+@H@("`@("`@("`@
M("`@*@H@("`@("`@("`@("`@*B!&=7)T:&5R;6]R92P@)&H@:7,@86QW87ES
M(&ME<'0@<V\@=&AA="`D:B`]/2`D;W1H97)?;&5N(&]R"B`@("`@("`@("`@
M("`J("1O=&AE<E]C:&%N9V5D6R1J72`]/2!F86QS92X@*B\*("`@("`@("`@
M("`@=VAI;&4@*"1J(#P@)&]T:&5R7VQE;B`F)B`D;W1H97)?8VAA;F=E9%LD
M:ETI('L*("`@("`@("`@("`@("`@("1J*RL["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@('=H:6QE("@D:2`\("1L96X@)B8@(2`D8VAA;F=E9%LD:5TI
M('L*("`@("`@("`@("`@("`@(&%S<V5R="@G)&H@/"`D;W1H97)?;&5N("8F
M("$@)&]T:&5R7V-H86YG961;)&I=)RD["B`@("`@("`@("`@("`@("`D:2LK
M.R`D:BLK.PH@("`@("`@("`@("`@("`@=VAI;&4@*"1J(#P@)&]T:&5R7VQE
M;B`F)B`D;W1H97)?8VAA;F=E9%LD:ETI('L*("`@("`@("`@("`@("`@("`@
M("`D:BLK.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!I9B`H)&D@/3T@)&QE;BD@>PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1S=&%R="`]("1I.PH*
M("`@("`@("`@("`@+RH@1FEN9"!T:&4@96YD(&]F('1H:7,@<G5N(&]F(&-H
M86YG97,N("HO"B`@("`@("`@("`@('=H:6QE("@K*R1I(#P@)&QE;B`F)B`D
M8VAA;F=E9%LD:5TI('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!D;R!["B`@("`@("`@("`@("`@("`O
M*B!296-O<F0@=&AE(&QE;F=T:"!O9B!T:&ES(')U;B!O9B!C:&%N9V5S+"!S
M;R!T:&%T('=E(&-A;@H@("`@("`@("`@("`@("`@("H@;&%T97(@9&5T97)M
M:6YE('=H971H97(@=&AE(')U;B!H87,@9W)O=VXN("HO"B`@("`@("`@("`@
M("`@("`D<G5N;&5N9W1H(#T@)&D@+2`D<W1A<G0["@H@("`@("`@("`@("`@
M("`@+RH@36]V92!T:&4@8VAA;F=E9"!R96=I;VX@8F%C:RP@<V\@;&]N9R!A
M<R!T:&4@<')E=FEO=7,*("`@("`@("`@("`@("`@("`J('5N8VAA;F=E9"!L
M:6YE(&UA=&-H97,@=&AE(&QA<W0@8VAA;F=E9"!O;F4N("!4:&ES(&UE<F=E
M<PH@("`@("`@("`@("`@("`@("H@=VET:"!P<F5V:6]U<R!C:&%N9V5D(')E
M9VEO;G,N("HO"B`@("`@("`@("`@("`@("!W:&EL92`H)'-T87)T(#X@,"`F
M)B`D;&EN97-;)'-T87)T("T@,5T@/3T@)&QI;F5S6R1I("T@,5TI('L*("`@
M("`@("`@("`@("`@("`@("`D8VAA;F=E9%LM+21S=&%R=%T@/2`Q.PH@("`@
M("`@("`@("`@("`@("`@("1C:&%N9V5D6RTM)&E=(#T@9F%L<V4["B`@("`@
M("`@("`@("`@("`@("`@=VAI;&4@*"1S=&%R="`^(#`@)B8@)&-H86YG961;
M)'-T87)T("T@,5TI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'-T87)T
M+2T["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M(&%S<V5R="@G)&H@/B`P)RD["B`@("`@("`@("`@("`@("`@("`@=VAI;&4@
M*"1O=&AE<E]C:&%N9V5D6RTM)&I=*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("!A<W-E<G0H)R1J(#X](#`@)B8@(21O=&AE<E]C:&%N9V5D
M6R1J72<I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\J
M(%-E="!#3U)215-03TY$24Y'('1O('1H92!E;F0@;V8@=&AE(&-H86YG960@
M<G5N+"!A="!T:&4*("`@("`@("`@("`@("`@("`J(&QA<W0@<&]I;G0@=VAE
M<F4@:70@8V]R<F5S<&]N9',@=&\@82!C:&%N9V5D(')U;B!I;B!T:&4*("`@
M("`@("`@("`@("`@("`J(&]T:&5R(&9I;&4N($-/4E)%4U!/3D1)3D<@/3T@
M3$5.(&UE86YS(&YO('-U8V@@<&]I;G0@:&%S"B`@("`@("`@("`@("`@("`@
M*B!B965N(&9O=6YD+B`J+PH@("`@("`@("`@("`@("`@)&-O<G)E<W!O;F1I
M;F<@/2`D:B`\("1O=&AE<E]L96X@/R`D:2`Z("1L96X["@H@("`@("`@("`@
M("`@("`@+RH@36]V92!T:&4@8VAA;F=E9"!R96=I;VX@9F]R=V%R9"P@<V\@
M;&]N9R!A<R!T:&4@9FER<W0*("`@("`@("`@("`@("`@("`J(&-H86YG960@
M;&EN92!M871C:&5S('1H92!F;VQL;W=I;F<@=6YC:&%N9V5D(&]N92X@(%1H
M:7,*("`@("`@("`@("`@("`@("`J(&UE<F=E<R!W:71H(&9O;&QO=VEN9R!C
M:&%N9V5D(')E9VEO;G,N("!$;R!T:&ES('-E8V]N9"P@<V\*("`@("`@("`@
M("`@("`@("`J('1H870@:68@=&AE<F4@87)E(&YO(&UE<F=E<RP@=&AE(&-H
M86YG960@<F5G:6]N(&ES(&UO=F5D"B`@("`@("`@("`@("`@("`@*B!F;W)W
M87)D(&%S(&9A<B!A<R!P;W-S:6)L92X@*B\*("`@("`@("`@("`@("`@('=H
M:6QE("@D:2`\("1L96X@)B8@)&QI;F5S6R1S=&%R=%T@/3T@)&QI;F5S6R1I
M72D@>PH@("`@("`@("`@("`@("`@("`@("1C:&%N9V5D6R1S=&%R="LK72`]
M(&9A;'-E.PH@("`@("`@("`@("`@("`@("`@("1C:&%N9V5D6R1I*RM=(#T@
M,3L*("`@("`@("`@("`@("`@("`@("!W:&EL92`H)&D@/"`D;&5N("8F("1C
M:&%N9V5D6R1I72D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:2LK.PH@
M("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@87-S
M97)T*"<D:B`\("1O=&AE<E]L96X@)B8@(2`D;W1H97)?8VAA;F=E9%LD:ETG
M*3L*("`@("`@("`@("`@("`@("`@("`D:BLK.PH@("`@("`@("`@("`@("`@
M("`@(&EF("@D:B`\("1O=&AE<E]L96X@)B8@)&]T:&5R7V-H86YG961;)&I=
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1C;W)R97-P;VYD:6YG(#T@
M)&D["B`@("`@("`@("`@("`@("`@("`@("`@('=H:6QE("@D:B`\("1O=&AE
M<E]L96X@)B8@)&]T:&5R7V-H86YG961;)&I=*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D:BLK.PH@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]('=H:6QE("@D<G5N;&5N9W1H("$]("1I("T@)'-T87)T*3L*
M"B`@("`@("`@("`@("\J($EF('!O<W-I8FQE+"!M;W9E('1H92!F=6QL>2UM
M97)G960@<G5N(&]F(&-H86YG97,@8F%C:R!T;R!A"B`@("`@("`@("`@("`J
M(&-O<G)E<W!O;F1I;F<@<G5N(&EN('1H92!O=&AE<B!F:6QE+B`J+PH@("`@
M("`@("`@("!W:&EL92`H)&-O<G)E<W!O;F1I;F<@/"`D:2D@>PH@("`@("`@
M("`@("`@("`@)&-H86YG961;+2TD<W1A<G1=(#T@,3L*("`@("`@("`@("`@
M("`@("1C:&%N9V5D6RTM)&E=(#T@,#L*("`@("`@("`@("`@("`@(&%S<V5R
M="@G)&H@/B`P)RD["B`@("`@("`@("`@("`@("!W:&EL92`H)&]T:&5R7V-H
M86YG961;+2TD:ETI('L*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&%S<V5R="@G)&H@
M/CT@,"`F)B`A)&]T:&5R7V-H86YG961;)&I=)RD["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]"@I]"@HO*BH*("H@0'!A8VMA9V4@5&5X=%]$:69F
M"B`J($!A=71H;W(@($=E;V9F<F5Y(%0N($1A:7)I:VD@/&1A:7)I:VE`9&%I
M<FEK:2YO<F<^"B`J"B`J($!A8V-E<W,@<')I=F%T90H@*B\*8VQA<W,@5&5X
M=%]$:69F7T]P('L*"B`@("!V87(@)&]R:6<["B`@("!V87(@)&9I;F%L.PH*
M("`@(&9U;F-T:6]N(')E=F5R<V4H*0H@("`@>PH@("`@("`@('1R:6=G97)?
M97)R;W(H)T%B<W1R86-T(&UE=&AO9"<L($5?55-%4E]%4E)/4BD["B`@("!]
M"@H@("`@9G5N8W1I;VX@;F]R:6<H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^;W)I9R`_(&-O=6YT*"1T:&ES+3YO<FEG*2`Z(#`["B`@("!]"@H@
M("`@9G5N8W1I;VX@;F9I;F%L*"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/F9I;F%L(#\@8V]U;G0H)'1H:7,M/F9I;F%L*2`Z(#`["B`@("!]"@I]
M"@HO*BH*("H@0'!A8VMA9V4@5&5X=%]$:69F"B`J($!A=71H;W(@($=E;V9F
M<F5Y(%0N($1A:7)I:VD@/&1A:7)I:VE`9&%I<FEK:2YO<F<^"B`J"B`J($!A
M8V-E<W,@<')I=F%T90H@*B\*8VQA<W,@5&5X=%]$:69F7T]P7V-O<'D@97AT
M96YD<R!497AT7T1I9F9?3W`@>PH*("`@(&9U;F-T:6]N(%1E>'1?1&EF9E]/
M<%]C;W!Y*"1O<FEG+"`D9FEN86P@/2!F86QS92D*("`@('L*("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1F:6YA;"DI('L*("`@("`@("`@("`@)&9I;F%L(#T@
M)&]R:6<["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YO<FEG(#T@)&]R:6<[
M"B`@("`@("`@)'1H:7,M/F9I;F%L(#T@)&9I;F%L.PH@("`@?0H*("`@(&9U
M;F-T:6]N("9R979E<G-E*"D*("`@('L*("`@("`@("`D<F5V97)S92`]("9N
M97<@5&5X=%]$:69F7T]P7V-O<'DH)'1H:7,M/F9I;F%L+"`D=&AI<RT^;W)I
M9RD["B`@("`@("`@<F5T=7)N("1R979E<G-E.PH@("`@?0H*?0H*+RHJ"B`J
M($!P86-K86=E(%1E>'1?1&EF9@H@*B!`875T:&]R("!'96]F9G)E>2!4+B!$
M86ER:6MI(#QD86ER:6MI0&1A:7)I:VDN;W)G/@H@*@H@*B!`86-C97-S('!R
M:79A=&4*("HO"F-L87-S(%1E>'1?1&EF9E]/<%]D96QE=&4@97AT96YD<R!4
M97AT7T1I9F9?3W`@>PH*("`@(&9U;F-T:6]N(%1E>'1?1&EF9E]/<%]D96QE
M=&4H)&QI;F5S*0H@("`@>PH@("`@("`@("1T:&ES+3YO<FEG(#T@)&QI;F5S
M.PH@("`@("`@("1T:&ES+3YF:6YA;"`](&9A;'-E.PH@("`@?0H*("`@(&9U
M;F-T:6]N("9R979E<G-E*"D*("`@('L*("`@("`@("`D<F5V97)S92`]("9N
M97<@5&5X=%]$:69F7T]P7V%D9"@D=&AI<RT^;W)I9RD["B`@("`@("`@<F5T
M=7)N("1R979E<G-E.PH@("`@?0H*?0H*+RHJ"B`J($!P86-K86=E(%1E>'1?
M1&EF9@H@*B!`875T:&]R("!'96]F9G)E>2!4+B!$86ER:6MI(#QD86ER:6MI
M0&1A:7)I:VDN;W)G/@H@*@H@*B!`86-C97-S('!R:79A=&4*("HO"F-L87-S
M(%1E>'1?1&EF9E]/<%]A9&0@97AT96YD<R!497AT7T1I9F9?3W`@>PH*("`@
M(&9U;F-T:6]N(%1E>'1?1&EF9E]/<%]A9&0H)&QI;F5S*0H@("`@>PH@("`@
M("`@("1T:&ES+3YF:6YA;"`]("1L:6YE<SL*("`@("`@("`D=&AI<RT^;W)I
M9R`](&9A;'-E.PH@("`@?0H*("`@(&9U;F-T:6]N("9R979E<G-E*"D*("`@
M('L*("`@("`@("`D<F5V97)S92`]("9N97<@5&5X=%]$:69F7T]P7V1E;&5T
M92@D=&AI<RT^9FEN86PI.PH@("`@("`@(')E='5R;B`D<F5V97)S93L*("`@
M('T*"GT*"B\J*@H@*B!`<&%C:V%G92!497AT7T1I9F8*("H@0&%U=&AO<B`@
M1V5O9F9R97D@5"X@1&%I<FEK:2`\9&%I<FEK:4!D86ER:6MI+F]R9SX*("H*
M("H@0&%C8V5S<R!P<FEV871E"B`J+PIC;&%S<R!497AT7T1I9F9?3W!?8VAA
M;F=E(&5X=&5N9',@5&5X=%]$:69F7T]P('L*"B`@("!F=6YC=&EO;B!497AT
M7T1I9F9?3W!?8VAA;F=E*"1O<FEG+"`D9FEN86PI"B`@("!["B`@("`@("`@
M)'1H:7,M/F]R:6<@/2`D;W)I9SL*("`@("`@("`D=&AI<RT^9FEN86P@/2`D
M9FEN86P["B`@("!]"@H@("`@9G5N8W1I;VX@)G)E=F5R<V4H*0H@("`@>PH@
M("`@("`@("1R979E<G-E(#T@)FYE=R!497AT7T1I9F9?3W!?8VAA;F=E*"1T
M:&ES+3YF:6YA;"P@)'1H:7,M/F]R:6<I.PH@("`@("`@(')E='5R;B`D<F5V
M97)S93L*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+U1E>'0O1&EF9C,N<&AP````````````````````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-3(V,@`Q,#4Q-30S,S<T-0`P,C$P
M,C,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"G)E<75I<F5?;VYC92`G5&5X="]$:69F+G!H<"<["@HO*BH*("H@
M02!C;&%S<R!F;W(@8V]M<'5T:6YG('1H<F5E('=A>2!D:69F<RX*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]$:69F+T1I9F8S+G!H<"QV(#$N,BXQ
M,"XS(#(P,#4O,3`O,3@@,3$Z,#$Z,S$@:F%N($5X<"`D"B`J"B`J($!P86-K
M86=E(%1E>'1?1&EF9@H@*B!`875T:&]R("!'96]F9G)E>2!4+B!$86ER:6MI
M(#QD86ER:6MI0&1A:7)I:VDN;W)G/@H@*B\*8VQA<W,@5&5X=%]$:69F,R!E
M>'1E;F1S(%1E>'1?1&EF9B!["@H@("`@+RHJ"B`@("`@*B!#;VYF;&EC="!C
M;W5N=&5R+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@
M("!V87(@)%]C;VYF;&EC=&EN9T)L;V-K<R`](#`["@H@("`@+RHJ"B`@("`@
M*B!#;VUP=71E<R!D:69F(&)E='=E96X@,R!S97%U96YC97,@;V8@<W1R:6YG
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&]R:6<@("`@5&AE(&]R
M:6=I;F%L(&QI;F5S('1O('5S92X*("`@("`J($!P87)A;2!A<G)A>2`D9FEN
M86PQ("!4:&4@9FER<W0@=F5R<VEO;B!T;R!C;VUP87)E('1O+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1F:6YA;#(@(%1H92!S96-O;F0@=F5R<VEO;B!T;R!C
M;VUP87)E('1O+@H@("`@("HO"B`@("!F=6YC=&EO;B!497AT7T1I9F8S*"1O
M<FEG+"`D9FEN86PQ+"`D9FEN86PR*0H@("`@>PH@("`@("`@(&EF("AE>'1E
M;G-I;VY?;&]A9&5D*"=X9&EF9B<I*2!["B`@("`@("`@("`@("1E;F=I;F4@
M/2`F;F5W(%1E>'1?1&EF9E]%;F=I;F5?>&1I9F8H*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D96YG:6YE(#T@)FYE=R!497AT7T1I9F9?16YG
M:6YE7VYA=&EV92@I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]E9&ET
M<R`]("1T:&ES+3Y?9&EF9C,H)&5N9VEN92T^9&EF9B@D;W)I9RP@)&9I;F%L
M,2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5N
M9VEN92T^9&EF9B@D;W)I9RP@)&9I;F%L,BDI.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&UE<F=E9$]U='!U="@D;&%B96PQ(#T@9F%L<V4L("1L86)E;#(@/2!F
M86QS92D*("`@('L*("`@("`@("`D;&EN97,@/2!A<G)A>2@I.PH@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?961I=',@87,@)&5D:70I('L*("`@("`@("`@
M("`@:68@*"1E9&ET+3YI<T-O;F9L:6-T*"DI('L*("`@("`@("`@("`@("`@
M("\J($9)6$U%.B!T:&ES('-H;W5L9"!P<F]B86)L>2!B92!M;W9E9"!S;VUE
M=VAE<F4@96QS92X@*B\*("`@("`@("`@("`@("`@("1L:6YE<R`](&%R<F%Y
M7VUE<F=E*"1L:6YE<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"<\/#P\/#P\)R`N("@D;&%B96PQ(#\@)R`G("X@)&QA
M8F5L,2`Z("<G*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D961I="T^9FEN86PQ+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH(CT]/3T]/3TB*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1E9&ET+3YF:6YA;#(L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G/CX^/CX^/B<@
M+B`H)&QA8F5L,B`_("<@)R`N("1L86)E;#(@.B`G)RDI*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?8V]N9FQI8W1I;F=";&]C:W,K*SL*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1L:6YE<R`](&%R<F%Y7VUE
M<F=E*"1L:6YE<RP@)&5D:70M/FUE<F=E9"@I*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1L:6YE<SL*("`@('T*"B`@("`O
M*BH*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO
M;B!?9&EF9C,H)&5D:71S,2P@)&5D:71S,BD*("`@('L*("`@("`@("`D961I
M=',@/2!A<G)A>2@I.PH@("`@("`@("1B8B`]("9N97<@5&5X=%]$:69F,U]"
M;&]C:T)U:6QD97(H*3L*"B`@("`@("`@)&4Q(#T@8W5R<F5N="@D961I=',Q
M*3L*("`@("`@("`D93(@/2!C=7)R96YT*"1E9&ET<S(I.PH@("`@("`@('=H
M:6QE("@D93$@?'P@)&4R*2!["B`@("`@("`@("`@(&EF("@D93$@)B8@)&4R
M("8F(&ES7V$H)&4Q+"`G5&5X=%]$:69F7T]P7V-O<'DG*2`F)B!I<U]A*"1E
M,BP@)U1E>'1?1&EF9E]/<%]C;W!Y)RDI('L*("`@("`@("`@("`@("`@("\J
M(%=E(&AA=F4@8V]P>2!B;&]C:W,@9G)O;2!B;W1H(&1I9F9S+B!4:&ES(&ES
M('1H92`H;VYL>2D*("`@("`@("`@("`@("`@("`J('1I;64@=V4@=V%N="!T
M;R!E;6ET(&$@9&EF9C,@8V]P>2!B;&]C:RX@($9L=7-H(&-U<G)E;G0*("`@
M("`@("`@("`@("`@("`J(&1I9F8S(&1I9F8@8FQO8VLL(&EF(&%N>2X@*B\*
M("`@("`@("`@("`@("`@(&EF("@D961I="`]("1B8BT^9FEN:7-H*"DI('L*
M("`@("`@("`@("`@("`@("`@("`D961I='-;72`]("1E9&ET.PH@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1N8V]P>2`](&UI;B@D93$M
M/FYO<FEG*"DL("1E,BT^;F]R:6<H*2D["B`@("`@("`@("`@("`@("!A<W-E
M<G0H)&YC;W!Y(#X@,"D["B`@("`@("`@("`@("`@("`D961I='-;72`]("9N
M97<@5&5X=%]$:69F,U]/<%]C;W!Y*&%R<F%Y7W-L:6-E*"1E,2T^;W)I9RP@
M,"P@)&YC;W!Y*2D["@H@("`@("`@("`@("`@("`@:68@*"1E,2T^;F]R:6<H
M*2`^("1N8V]P>2D@>PH@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W-P;&EC
M92@D93$M/F]R:6<L(#`L("1N8V]P>2D["B`@("`@("`@("`@("`@("`@("`@
M87)R87E?<W!L:6-E*"1E,2T^9FEN86PL(#`L("1N8V]P>2D["B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1E,2`](&YE
M>'0H)&5D:71S,2D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@:68@*"1E,BT^;F]R:6<H*2`^("1N8V]P>2D@>PH@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y7W-P;&EC92@D93(M/F]R:6<L(#`L("1N8V]P>2D["B`@
M("`@("`@("`@("`@("`@("`@87)R87E?<W!L:6-E*"1E,BT^9FEN86PL(#`L
M("1N8V]P>2D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1E,B`](&YE>'0H)&5D:71S,BD["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I9B`H
M)&4Q("8F("1E,BD@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D93$M/F]R
M:6<@)B8@)&4R+3YO<FEG*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1N
M;W)I9R`](&UI;B@D93$M/FYO<FEG*"DL("1E,BT^;F]R:6<H*2D["B`@("`@
M("`@("`@("`@("`@("`@("`@("1O<FEG(#T@87)R87E?<W!L:6-E*"1E,2T^
M;W)I9RP@,"P@)&YO<FEG*3L*("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87E?<W!L:6-E*"1E,BT^;W)I9RP@,"P@)&YO<FEG*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&)B+3YI;G!U="@D;W)I9RD["B`@("`@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?82@D93$L("=4
M97AT7T1I9F9?3W!?8V]P>2<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1B8BT^;W5T,2AA<G)A>5]S<&QI8V4H)&4Q+3YF:6YA;"P@,"P@)&YO<FEG
M*2D["B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-?82@D93(L("=497AT7T1I9F9?3W!?8V]P>2<I*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1B8BT^;W5T,BAA<G)A>5]S<&QI8V4H)&4R
M+3YF:6YA;"P@,"P@)&YO<FEG*2D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("@D93$@)B8@
M(2`D93$M/F]R:6<I('L*("`@("`@("`@("`@("`@("`@("`D8F(M/F]U=#$H
M)&4Q+3YF:6YA;"D["B`@("`@("`@("`@("`@("`@("`@)&4Q(#T@;F5X="@D
M961I=',Q*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF
M("@D93(@)B8@(2`D93(M/F]R:6<I('L*("`@("`@("`@("`@("`@("`@("`D
M8F(M/F]U=#(H)&4R+3YF:6YA;"D["B`@("`@("`@("`@("`@("`@("`@)&4R
M(#T@;F5X="@D961I=',R*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1E9&ET(#T@)&)B+3YF:6YI
M<V@H*2D@>PH@("`@("`@("`@("`D961I='-;72`]("1E9&ET.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1E9&ET<SL*("`@('T*"GT*"B\J*@H@*B!`
M<&%C:V%G92!497AT7T1I9F8*("H@0&%U=&AO<B`@1V5O9F9R97D@5"X@1&%I
M<FEK:2`\9&%I<FEK:4!D86ER:6MI+F]R9SX*("H*("H@0&%C8V5S<R!P<FEV
M871E"B`J+PIC;&%S<R!497AT7T1I9F8S7T]P('L*"B`@("!F=6YC=&EO;B!4
M97AT7T1I9F8S7T]P*"1O<FEG(#T@9F%L<V4L("1F:6YA;#$@/2!F86QS92P@
M)&9I;F%L,B`](&9A;'-E*0H@("`@>PH@("`@("`@("1T:&ES+3YO<FEG(#T@
M)&]R:6<@/R`D;W)I9R`Z(&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/F9I;F%L
M,2`]("1F:6YA;#$@/R`D9FEN86PQ(#H@87)R87DH*3L*("`@("`@("`D=&AI
M<RT^9FEN86PR(#T@)&9I;F%L,B`_("1F:6YA;#(@.B!A<G)A>2@I.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&UE<F=E9"@I"B`@("!["B`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7VUE<F=E9"DI('L*("`@("`@("`@("`@:68@*"1T:&ES
M+3YF:6YA;#$@/3T]("1T:&ES+3YF:6YA;#(I('L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;65R9V5D(#T@)B1T:&ES+3YF:6YA;#$["B`@("`@("`@("`@
M('T@96QS96EF("@D=&AI<RT^9FEN86PQ(#T]/2`D=&AI<RT^;W)I9RD@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]M97)G960@/2`F)'1H:7,M/F9I;F%L
M,CL*("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3YF:6YA;#(@/3T]("1T
M:&ES+3YO<FEG*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VUE<F=E9"`]
M("8D=&AI<RT^9FEN86PQ.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]M97)G960@/2!F86QS93L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;65R9V5D.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&ES0V]N9FQI8W0H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^;65R9V5D*"D@/3T](&9A;'-E.PH@("`@?0H*?0H*
M+RHJ"B`J($!P86-K86=E(%1E>'1?1&EF9@H@*B!`875T:&]R("!'96]F9G)E
M>2!4+B!$86ER:6MI(#QD86ER:6MI0&1A:7)I:VDN;W)G/@H@*@H@*B!`86-C
M97-S('!R:79A=&4*("HO"F-L87-S(%1E>'1?1&EF9C-?3W!?8V]P>2!E>'1E
M;F1S(%1E>'1?1&EF9C-?3W`@>PH*("`@(&9U;F-T:6]N(%1E>'1?1&EF9C-?
M3W!?0V]P>2@D;&EN97,@/2!F86QS92D*("`@('L*("`@("`@("`D=&AI<RT^
M;W)I9R`]("1L:6YE<R`_("1L:6YE<R`Z(&%R<F%Y*"D["B`@("`@("`@)'1H
M:7,M/F9I;F%L,2`]("8D=&AI<RT^;W)I9SL*("`@("`@("`D=&AI<RT^9FEN
M86PR(#T@)B1T:&ES+3YO<FEG.PH@("`@?0H*("`@(&9U;F-T:6]N(&UE<F=E
M9"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YO<FEG.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&ES0V]N9FQI8W0H*0H@("`@>PH@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"GT*"B\J*@H@*B!`<&%C:V%G92!497AT7T1I9F8*
M("H@0&%U=&AO<B`@1V5O9F9R97D@5"X@1&%I<FEK:2`\9&%I<FEK:4!D86ER
M:6MI+F]R9SX*("H*("H@0&%C8V5S<R!P<FEV871E"B`J+PIC;&%S<R!497AT
M7T1I9F8S7T)L;V-K0G5I;&1E<B!["@H@("`@9G5N8W1I;VX@5&5X=%]$:69F
M,U]";&]C:T)U:6QD97(H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:6YI="@I
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&EN<'5T*"1L:6YE<RD*("`@('L*("`@
M("`@("!I9B`H)&QI;F5S*2!["B`@("`@("`@("`@("1T:&ES+3Y?87!P96YD
M*"1T:&ES+3YO<FEG+"`D;&EN97,I.PH@("`@("`@('T*("`@('T*"B`@("!F
M=6YC=&EO;B!O=70Q*"1L:6YE<RD*("`@('L*("`@("`@("!I9B`H)&QI;F5S
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?87!P96YD*"1T:&ES+3YF:6YA;#$L
M("1L:6YE<RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&]U=#(H
M)&QI;F5S*0H@("`@>PH@("`@("`@(&EF("@D;&EN97,I('L*("`@("`@("`@
M("`@)'1H:7,M/E]A<'!E;F0H)'1H:7,M/F9I;F%L,BP@)&QI;F5S*3L*("`@
M("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@:7-%;7!T>2@I"B`@("!["B`@
M("`@("`@<F5T=7)N("$D=&AI<RT^;W)I9R`F)B`A)'1H:7,M/F9I;F%L,2`F
M)B`A)'1H:7,M/F9I;F%L,CL*("`@('T*"B`@("!F=6YC=&EO;B!F:6YI<V@H
M*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^:7-%;7!T>2@I*2!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D961I="`]("9N97<@5&5X=%]$:69F,U]/<"@D=&AI<RT^;W)I9RP@
M)'1H:7,M/F9I;F%L,2P@)'1H:7,M/F9I;F%L,BD["B`@("`@("`@("`@("1T
M:&ES+3Y?:6YI="@I.PH@("`@("`@("`@("!R971U<FX@)&5D:70["B`@("`@
M("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]I;FET*"D*("`@('L*("`@("`@
M("`D=&AI<RT^;W)I9R`]("1T:&ES+3YF:6YA;#$@/2`D=&AI<RT^9FEN86PR
M(#T@87)R87DH*3L*("`@('T*"B`@("!F=6YC=&EO;B!?87!P96YD*"8D87)R
M87DL("1L:6YE<RD*("`@('L*("`@("`@("!A<G)A>5]S<&QI8V4H)&%R<F%Y
M+"!S:7IE;V8H)&%R<F%Y*2P@,"P@)&QI;F5S*3L*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U1E
M>'0O1FQO=V5D+G!H<```````````````````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`R-C<R,0`Q,#4Q-30S,S<T-0`P,C$S,3(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M92!497AT7T9L;W=E9#HZ(&-L87-S('!R;W9I9&5S(&-O;6UO;B!M971H;V1S
M(&9O<B!M86YI<'5L871I;F<@=&5X=`H@*B!U<VEN9R!T:&4@96YC;V1I;F<@
M9&5S8W)I8F5D(&EN(%)&0R`S-C<V("@G9FQO=V5D)R!T97AT*2X*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]&;&]W960O1FQO=V5D+G!H<"QV(#$N
M,30N,3`N,3<@,C`P-B\P,R\Q,2`P.3HU,#HR,B!J86X@17AP("0*("H*("H@
M5&AI<R!C;&%S<R!I<R!B87-E9"!O;B!T:&4@5&5X=#HZ1FQO=V5D('!E<FP@
M;6]D=6QE("A697)S:6]N(#`N,30I(&9O=6YD"B`J(&EN('1H92!#4$%.('!E
M<FP@<F5P;W-I=&]R>2X@(%1H:7,@;6]D=6QE(&ES(')E;&5A<V5D('5N9&5R
M('1H92!097)L"B`J(&QI8V5N<V4L('=H:6-H(&ES(&-O;7!A=&EB;&4@=VET
M:"!T:&4@3$=03"X*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P,R!0:&EL:7`@
M36%K"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS
M;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN
M8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA
M9V4@2&]R9&5?5&5X=`H@*B\*8VQA<W,@5&5X=%]&;&]W960@>PH*("`@("\J
M*@H@("`@("H@5&AE(&UA>&EM=6T@;&5N9W1H('1H870@82!L:6YE(&ES(&%L
M;&]W960@=&\@8F4@*'5N;&5S<R!F86-E9"!W:71H"B`@("`@*B!W:71H(&$@
M=V]R9"!T:&%T(&ES('5N<F5A<V]N86)L>2!L;VYG*2X@5&AI<R!C;&%S<R!W
M:6QL(')E+7=R87`@80H@("`@("H@;&EN92!I9B!I="!E>&-E961S('1H:7,@
M;&5N9W1H+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@
M("!V87(@)%]M87AL96YG=&@@/2`W.#L*"B`@("`O*BH*("`@("`J(%=H96X@
M=&AI<R!C;&%S<R!W<F%P<R!A(&QI;F4L('1H92!N97=L>2!C<F5A=&5D(&QI
M;F5S('=I;&P@8F4@<W!L:70*("`@("`J(&%T('1H:7,@;&5N9W1H+@H@("`@
M("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]O<'1L
M96YG=&@@/2`W,CL*"B`@("`O*BH*("`@("`J(%1H92!T97AT('1O(&)E(&9O
M<FUA='1E9"X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]T97AT.PH*("`@("\J*@H@("`@("H@5&AE(&-A8VAE9"!O=71P
M=70@;V8@=&AE(&9O<FUA='1I;F<N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]O=71P=70@/2!N=6QL.PH*("`@("\J*@H@
M("`@("H@5&AE(&-H87)A8W1E<B!S970@;V8@=&AE('1E>'0N"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8VAA<G-E=#L*
M"B`@("`O*BH*("`@("`J($-O;G9E<G0@=&5X="!U<VEN9R!$96Q3<#\*("`@
M("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?9&5L
M<W`@/2!F86QS93L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("`@(%1H92!T97AT('1O
M('!R;V-E<W,N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:&%R<V5T("!4:&4@
M8VAA<F%C=&5R('-E="!O9B`D=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M5&5X=%]&;&]W960H)'1E>'0L("1C:&%R<V5T(#T@;G5L;"D*("`@('L*("`@
M("`@("`D=&AI<RT^7W1E>'0@/2`D=&5X=#L*("`@("`@("`D=&AI<RT^7V-H
M87)S970@/2`D8VAA<G-E=#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T
M:&4@;6%X:6UU;2!L96YG=&@@;V8@82!L:6YE(&]F('1E>'0N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&UA>"`@02!N97<@=F%L=64@9F]R("1?
M;6%X;&5N9W1H+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971-87A,96YG=&@H
M)&UA>"D*("`@('L*("`@("`@("`D=&AI<RT^7VUA>&QE;F=T:"`]("1M87@[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&]P=&EM86P@;&5N9W1H
M(&]F(&$@;&EN92!O9B!T97AT+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E
M9V5R("1M87@@($$@;F5W('9A;'5E(&9O<B`D7V]P=&QE;F=T:"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T3W!T3&5N9W1H*"1O<'0I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]O<'1L96YG=&@@/2`D;W!T.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4V5T('=H971H97(@=&\@9F]R;6%T('1E<W0@=7-I;F<@1&5L4W`N
M"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@("`@("H*("`@("`J
M($!P87)A;2!B;V]L96%N("1D96QS<"`@57-E($1E;%-P/PH@("`@("HO"B`@
M("!F=6YC=&EO;B!S971$96Q3<"@D9&5L<W`I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]D96QS<"`]("AB;V]L*2`D9&5L<W`["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2969O<FUA=',@=&AE(&EN<'5T('-T<FEN9RP@=VAE<F4@=&AE('-T
M<FEN9R!I<R`G9F]R;6%T/69L;W=E9"<@<&QA:6X*("`@("`J('1E>'0@87,@
M9&5S8W)I8F5D(&EN(%)&0R`R-C0V+@H@("`@("H*("`@("`J($!P87)A;2!B
M;V]L96%N("1Q=6]T92`@061D(&QE=F5L(&]F('%U;W1I;F<@=&\@96%C:"!L
M:6YE/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=&5X="!C
M;VYV97)T960@=&\@4D9#(#(V-#8@)V9I>&5D)R!F;W)M870N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('1O1FEX960H)'%U;W1E(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@)'1X="`]("<G.PH*("`@("`@("`D=&AI<RT^7W)E9F]R;6%T*&9A
M;'-E+"`D<75O=&4I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?;W5T<'5T
M(&%S("1V86PI('L*("`@("`@("`@("`@)'1X="`N/2`D=F%L6R=T97AT)UT@
M+B`B7&XB.PH@("`@("`@('T*("`@("`@("!R971U<FX@<G1R:6TH)'1X="D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2969O<FUA=',@=&AE(&EN<'5T('-T
M<FEN9RP@86YD(')E='5R;G,@=&AE(&]U='!U="!I;B!A;B!A<G)A>2!F;W)M
M870*("`@("`J('=I=&@@<75O=&4@;&5V96P@:6YF;W)M871I;VXN"B`@("`@
M*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'%U;W1E("!!9&0@;&5V96P@;V8@
M<75O=&EN9R!T;R!E86-H(&QI;F4_"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@06X@87)R87D@;V8@87)R87ES('=I=&@@=&AE(&9O;&QO=VEN9R!E
M;&5M96YT<SH*("`@("`J(#QP<F4^"B`@("`@*B`G;&5V96PG("T@5&AE('%U
M;W1E(&QE=F5L(&]F('1H92!C=7)R96YT(&QI;F4N"B`@("`@*B`G=&5X="<@
M("T@5&AE('1E>'0@9F]R('1H92!C=7)R96YT(&QI;F4N"B`@("`@*B`\+W!R
M93X*("`@("`J+PH@("`@9G5N8W1I;VX@=&]&:7AE9$%R<F%Y*"1Q=6]T92`]
M(&9A;'-E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<F5F;W)M870H9F%L<V4L
M("1Q=6]T92D["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;W5T<'5T.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5F;W)M871S('1H92!I;G!U="!S=')I;F<L
M('=H97)E('1H92!S=')I;F<@:7,@)V9O<FUA=#UF:7AE9"<@<&QA:6X*("`@
M("`J('1E>'0@87,@9&5S8W)I8F5D(&EN(%)&0R`R-C0V+@H@("`@("H*("`@
M("`J($!P87)A;2!B;V]L96%N("1Q=6]T92`@061D(&QE=F5L(&]F('%U;W1I
M;F<@=&\@96%C:"!L:6YE/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@=&5X="!C;VYV97)T960@=&\@4D9#(#(V-#8@)V9L;W=E9"<@9F]R
M;6%T+@H@("`@("HO"B`@("!F=6YC=&EO;B!T;T9L;W=E9"@D<75O=&4@/2!F
M86QS92D*("`@('L*("`@("`@("`D='AT(#T@)R<["@H@("`@("`@("1T:&ES
M+3Y?<F5F;W)M870H=')U92P@)'%U;W1E*3L*("`@("`@("!F;W)E86-H("@D
M=&AI<RT^7V]U='!U="!A<R`D=F%L*2!["B`@("`@("`@("`@("1T>'0@+CT@
M)'9A;%LG=&5X="==("X@(EQN(CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1T>'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2969O<FUA=',@=&AE(&EN
M<'5T('-T<FEN9RP@=VAE<F4@=&AE('-T<FEN9R!I<R`G9F]R;6%T/69L;W=E
M9"<@<&QA:6X*("`@("`J('1E>'0@87,@9&5S8W)I8F5D(&EN(%)&0R`R-C0V
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!B;V]L96%N("1T;V9L;W=E9"`@0V]N=F5R="!T;R!F;&]W960_
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<75O=&4@("`@($%D9"!L979E;"!O
M9B!Q=6]T:6YG('1O(&5A8V@@;&EN93\*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!!(&QI<W0@;V8@87)R87ES+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?<F5F;W)M870H)'1O9FQO=V5D+"`D<75O=&4I"B`@("!["B`@("`@("`@
M:68@*"%I<U]N=6QL*"1T:&ES+3Y?;W5T<'5T*2D@>PH@("`@("`@("`@("!R
M971U<FX["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V]U='!U="`](&%R
M<F%Y*"D["B`@("`@("`@)'1E>'0@/2!E>'!L;V1E*")<;B(L("1T:&ES+3Y?
M=&5X="D["@H@("`@("`@("\J(%-E="!V87)I86)L97,@=7-E9"!I;B!R96=E
M>'!S+B`J+PH@("`@("`@("1D96QS<"`]("@D=&]F;&]W960@)B8@)'1H:7,M
M/E]D96QS<"D@/R`Q(#H@,#L*("`@("`@("`D;W!T(#T@)'1H:7,M/E]O<'1L
M96YG=&@@+2`Q("T@)&1E;'-P.PH*("`@("`@("`O*B!0<F]C97-S(&UE<W-A
M9V4@;&EN92!B>2!L:6YE+B`J+PH@("`@("`@(&1O('L*("`@("`@("`@("`@
M)&QI;F4@/2!A<G)A>5]S:&EF="@D=&5X="D["@H@("`@("`@("`@("`O*B!0
M97(@4D9#(#(V-#8@6S0N,UTL('1H92`G57-E;F5T(%-I9VYA='5R92!#;VYV
M96YT:6]N)R!L:6YE"B`@("`@("`@("`@("`J("A$05-(($1!4T@@4U`I(&ES
M(&YO="!C;VYS:61E<F5D(&9L;W=E9"X@(%=A=&-H(&9O<B!T:&ES('=H96X*
M("`@("`@("`@("`@("H@9&5A;&EN9R!W:71H('!O=&5N=&EA;&QY(&9L;W=E
M9"!L:6YE<RX@*B\*"B`@("`@("`@("`@("\J(%1H92!N97AT('1H<F5E('-T
M97!S(&-O;64@9G)O;2!21D,@,C8T-B!;-"XR72X@*B\*("`@("`@("`@("`@
M+RH@4U1%4"`Q.B!$971E<FUI;F4@<75O=&4@;&5V96P@9F]R(&QI;F4N("HO
M"B`@("`@("`@("`@(&EF("@H)&YU;5]Q=6]T97,@/2`D=&AI<RT^7VYU;7%U
M;W1E<R@D;&EN92DI*2!["B`@("`@("`@("`@("`@("`D;&EN92`]('-U8G-T
M<B@D;&EN92P@)&YU;5]Q=6]T97,I.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`O*B!/;FQY(&-O;6)I;F4@;&EN97,@:68@=V4@87)E(&-O;G9E<G1I
M;F<@=&\@9FQO=V5D(&]R(&EF('1H90H@("`@("`@("`@("`@*B!C=7)R96YT
M(&QI;F4@:7,@<75O=&5D+B`J+PH@("`@("`@("`@("!I9B`H(21T;V9L;W=E
M9"!\?"`D;G5M7W%U;W1E<RD@>PH@("`@("`@("`@("`@("`@+RH@4U1%4"`R
M.B!296UO=F4@<W!A8V4@<W1U9F9I;F<@9G)O;2!L:6YE+B`J+PH@("`@("`@
M("`@("`@("`@)&QI;F4@/2`D=&AI<RT^7W5N<W1U9F8H)&QI;F4I.PH*("`@
M("`@("`@("`@("`@("\J(%-415`@,SH@4VAO=6QD('=E(&EN=&5R<')E="!T
M:&ES(&QI;F4@87,@9FQO=V5D/PH@("`@("`@("`@("`@("`@("H@5VAI;&4@
M;&EN92!I<R!F;&]W960@*&YO="!E;7!T>2!A;F0@=&AE<F4@:7,@82!S<&%C
M90H@("`@("`@("`@("`@("`@("H@870@=&AE(&5N9"!O9B!T:&4@;&EN92DL
M(&%N9"!T:&5R92!I<R!A(&YE>'0@;&EN92P@86YD('1H90H@("`@("`@("`@
M("`@("`@("H@;F5X="!L:6YE(&AA<R!T:&4@<V%M92!Q=6]T92!D97!T:"P@
M861D('1O('1H92!C=7)R96YT"B`@("`@("`@("`@("`@("`@*B!L:6YE+B!!
M(&QI;F4@:7,@;F]T(&9L;W=E9"!I9B!I="!I<R!A('-I9VYA='5R92!L:6YE
M+B`J+PH@("`@("`@("`@("`@("`@=VAI;&4@*"%E;7!T>2@D;&EN92D@)B8*
M("`@("`@("`@("`@("`@("`@("`@("`H)&QI;F4@(3T@)RTM("<I("8F"B`@
M("`@("`@("`@("`@("`@("`@("`@*"1L:6YE>W-T<FQE;B@D;&EN92DM,7T@
M/3T@)R`G*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("%E;7!T>2@D=&5X
M="D@)B8*("`@("`@("`@("`@("`@("`@("`@("`H)'1H:7,M/E]N=6UQ=6]T
M97,H)'1E>'1;,%TI(#T]("1N=6U?<75O=&5S*2D@>PH@("`@("`@("`@("`@
M("`@("`@("\J($EF($1E;%-P(&ES('EE<R!A;F0@=&AI<R!I<R!F;&]W960@
M:6YP=70L('=E(&YE960@=&\*("`@("`@("`@("`@("`@("`@("`@*B!R96UO
M=F4@=&AE('1R86EL:6YG('-P86-E+B`J+PH@("`@("`@("`@("`@("`@("`@
M(&EF("@A)'1O9FQO=V5D("8F("1T:&ES+3Y?9&5L<W`I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&QI;F4@/2!S=6)S='(H)&QI;F4L(#`L("TQ*3L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&QI
M;F4@+CT@)'1H:7,M/E]U;G-T=69F*'-U8G-T<BAA<G)A>5]S:&EF="@D=&5X
M="DL("1N=6U?<75O=&5S*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("\J($5N<W5R92!L:6YE(&ES(&9I>&5D+"!S
M:6YC92!W92!A;')E861Y(&IO:6YE9"!A;&P@9FQO=V5D"B`@("`@("`@("`@
M("`J(&QI;F5S+B!296UO=F4@86QL('1R86EL:6YG("<@)R!F<F]M('1H92!L
M:6YE+B`J+PH@("`@("`@("`@("!I9B`H)&QI;F4@(3T@)RTM("<I('L*("`@
M("`@("`@("`@("`@("1L:6YE(#T@<G1R:6TH)&QI;F4I.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`O*B!);F-R96UE;G0@<75O=&4@9&5P=&@@:68@
M=V4G<F4@<75O=&EN9RX@*B\*("`@("`@("`@("`@:68@*"1Q=6]T92D@>PH@
M("`@("`@("`@("`@("`@)&YU;5]Q=6]T97,K*SL*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@+RH@5&AE('%U;W1E('!R969I>"!F;W(@=&AE(&QI;F4N
M("HO"B`@("`@("`@("`@("1Q=6]T97-T<B`]('-T<E]R97!E870H)SXG+"`D
M;G5M7W%U;W1E<RD["@H@("`@("`@("`@("!I9B`H96UP='DH)&QI;F4I*2![
M"B`@("`@("`@("`@("`@("`O*B!,:6YE(&ES(&5M<'1Y+B`J+PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]O=71P=71;72`](&%R<F%Y*"=T97AT)R`]/B`D
M<75O=&5S='(L("=L979E;"<@/3X@)&YU;5]Q=6]T97,I.PH@("`@("`@("`@
M("!](&5L<V5I9B`H96UP='DH)'1H:7,M/E]M87AL96YG=&@I('Q\("@H4W1R
M:6YG.CIL96YG=&@H)&QI;F4L("1T:&ES+3Y?8VAA<G-E="D@*R`D;G5M7W%U
M;W1E<RD@/#T@)'1H:7,M/E]M87AL96YG=&@I*2!["B`@("`@("`@("`@("`@
M("`O*B!,:6YE(&1O97,@;F]T(')E<75I<F4@<F5W<F%P<&EN9RX@*B\*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T6UT@/2!A<G)A>2@G=&5X="<@
M/3X@)'%U;W1E<W1R("X@)'1H:7,M/E]S='5F9B@D;&EN92P@)&YU;5]Q=6]T
M97,L("1T;V9L;W=E9"DL("=L979E;"<@/3X@)&YU;5]Q=6]T97,I.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&UI;B`]("1N=6U?
M<75O=&5S("L@,3L*"B`@("`@("`@("`@("`@("`O*B!297=R87`@=&AI<R!P
M87)A9W)A<&@N("HO"B`@("`@("`@("`@("`@("!W:&EL92`H)&QI;F4I('L*
M("`@("`@("`@("`@("`@("`@("`O*B!3='5F9B!A;F0@<F4M<75O=&4@=&AE
M(&QI;F4N("HO"B`@("`@("`@("`@("`@("`@("`@)&QI;F4@/2`D<75O=&5S
M='(@+B`D=&AI<RT^7W-T=69F*"1L:6YE+"`D;G5M7W%U;W1E<RP@)'1O9FQO
M=V5D*3L*("`@("`@("`@("`@("`@("`@("`D;&EN95]L96YG=&@@/2!3=')I
M;F<Z.FQE;F=T:"@D;&EN92P@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("`@
M("`@("`@("`@("!I9B`H)&QI;F5?;&5N9W1H(#P]("1T:&ES+3Y?;W!T;&5N
M9W1H*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\J(%)E;6%I;FEN9R!S
M96-T:6]N(&]F(&QI;F4@:7,@<VAO<G0@96YO=6=H+B`J+PH@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V]U='!U=%M=(#T@87)R87DH)W1E>'0G
M(#T^("1L:6YE+"`G;&5V96PG(#T^("1N=6U?<75O=&5S*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E:68@*"1M(#T@4W1R:6YG.CIR96=E>$UA=&-H*"1L:6YE+"!A<G)A>2@G
M7B@N>R<@+B`D;6EN("X@)RPG("X@)&]P="`N("=]*2`H+BHI)RP@)UXH+GLG
M("X@)&UI;B`N("<L)R`N("1T:&ES+3Y?;6%X;&5N9W1H("X@)WTI("@N*BDG
M+"`G7B@N>R<@+B`D;6EN("X@)RQ]*3\@*"XJ*2<I+"`D=&AI<RT^7V-H87)S
M970I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\J(%=E(&YE960@=&\@
M=W)A<"!T97AT(&%T(&$@8V5R=&%I;B!N=6UB97(@;V8*("`@("`@("`@("`@
M("`@("`@("`@("`@("H@*F-H87)A8W1E<G,J+"!N;W0@82!C97)T86EN(&YU
M;6)E<B!O9B`J8GET97,J.PH@("`@("`@("`@("`@("`@("`@("`@("`@*B!T
M:'5S('1H92!N965D(&9O<B!A(&UU;'1I8GET92!C87!A8FQE(')E9V5X+@H@
M("`@("`@("`@("`@("`@("`@("`@("`@*B!)9B!A(&UU;'1I8GET92!R96=E
M>"!I<VXG="!A=F%I;&%B;&4L('=E(&%R92!S='5C:PH@("`@("`@("`@("`@
M("`@("`@("`@("`@*B!W:71H('!R96=?;6%T8V@H*2`H=&AE(&9U;F-T:6]N
M('=I;&P@<W1I;&P@=V]R:R`M"B`@("`@("`@("`@("`@("`@("`@("`@("`J
M('=E('=I;&P@:G5S="!B92!L969T('=I=&@@<VAO<G1E<B!R;W=S('1H86X@
M97AP96-T960*("`@("`@("`@("`@("`@("`@("`@("`@("H@:68@;75L=&EB
M>71E(&-H87)A8W1E<G,@97AI<W0@:6X@=&AE(')O=RDN"B`@("`@("`@("`@
M("`@("`@("`@("`@("`J"B`@("`@("`@("`@("`@("`@("`@("`@("`J($%L
M9V]R:71H:6TZ"B`@("`@("`@("`@("`@("`@("`@("`@("`J(#$N(%1R>2!T
M;R!F:6YD(&$@<W1R:6YG(&%S(&QO;F<@87,@7V]P=&QE;F=T:"X*("`@("`@
M("`@("`@("`@("`@("`@("`@("H@,BX@5')Y('1O(&9I;F0@82!S=')I;F<@
M87,@;&]N9R!A<R!?;6%X;&5N9W1H+@H@("`@("`@("`@("`@("`@("`@("`@
M("`@*B`S+B!486ME('1H92!F:7)S="!W;W)D+B`J+PH@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H96UP='DH)&U;,5TI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D;5LQ72`]("1M6S)=.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&U;,ET@/2`G)SL*("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V]U='!U=%M=
M(#T@87)R87DH)W1E>'0G(#T^("1M6S%=("X@)R`G("X@*"@D9&5L<W`I(#\@
M)R`G(#H@)R<I+"`G;&5V96PG(#T^("1N=6U?<75O=&5S*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&QI;F4@/2`D;5LR73L*("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`O*B!/;F4@
M97AC97-S:79E;'D@;&]N9R!W;W)D(&QE9G0@;VX@;&EN92X@($)E"B`@("`@
M("`@("`@("`@("`@("`@("`@("`J(&%B<V]L=71E;'D@<W5R92!I="!D;V5S
M(&YO="!E>&-E960@.3DX(&-H87)A8W1E<G,*("`@("`@("`@("`@("`@("`@
M("`@("`@("H@:6X@;&5N9W1H(&]R(&5L<V4@=V4@;75S="!T<G5N8V%T92X@
M*B\*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1L:6YE7VQE;F=T:"`^
M(#DY."D@>R`*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M;W5T<'5T6UT@/2!A<G)A>2@G=&5X="<@/3X@4W1R:6YG.CIS=6)S='(H)&QI
M;F4L(#`L(#DY."P@)'1H:7,M/E]C:&%R<V5T*2P@)VQE=F5L)R`]/B`D;G5M
M7W%U;W1E<RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;&EN92`]
M(%-T<FEN9SHZ<W5B<W1R*"1L:6YE+"`Y.3@L(&YU;&PL("1T:&ES+3Y?8VAA
M<G-E="D["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V]U='!U=%M=(#T@87)R
M87DH)W1E>'0G(#T^("1L:6YE+"`G;&5V96PG(#T^("1N=6U?<75O=&5S*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!W:&EL92`H(65M
M<'1Y*"1T97AT*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!N=6UB97(@;V8@;&5A9&EN9R`G/B<@8VAA<F%C=&5R<R!I;B!T:&4@=&5X
M="!I;G!U="X*("`@("`J("<^)R!C:&%R86-T97)S(&%R92!D969I;F5D(&)Y
M(%)&0R`R-C0V('1O(&EN9&EC871E(&$@<75O=&5D(&QI;F4N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=&5X="`@5&AE('1E>'0@=&\@86YA;'EZ92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&EN=&5G97(@(%1H92!N=6UB97(@;V8@;&5A9&EN9R!Q=6]T
M92!C:&%R86-T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?;G5M<75O=&5S
M*"1T97AT*0H@("`@>PH@("`@("`@(')E='5R;B!S=')S<&XH)'1E>'0L("<^
M)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3<&%C92US='5F9G,@:68@:70@
M<W1A<G1S('=I=&@@)R`G(&]R("<^)R!O<B`G1G)O;2`G+"!O<B!I9@H@("`@
M("H@<75O=&4@9&5P=&@@:7,@;F]N+7IE<F\@*&9O<B!A97-T:&5T:6,@<F5A
M<V]N<R!S;R!T:&%T('1H97)E(&ES(&$*("`@("`J('-P86-E(&%F=&5R('1H
M92`G/B<I+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("`@("`@(%1H92!T97AT('1O
M('-T=69F+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;G5M7W%U;W1E<R`@5&AE
M('%U;W1E+6QE=F5L(&]F('1H:7,@;&EN92X*("`@("`J($!P87)A;2!B;V]L
M96%N("1T;V9L;W=E9"`@($%R92!W92!C;VYV97)T:6YG('1O(&9L;W=E9"!T
M97AT/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<W1U9F9E
M9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<W1U9F8H)'1E>'0L("1N
M=6U?<75O=&5S+"`D=&]F;&]W960I"B`@("!["B`@("`@("`@:68@*"1T;V9L
M;W=E9"`F)@H@("`@("`@("`@("`H)&YU;5]Q=6]T97,@?'P@<')E9U]M871C
M:"@B+UXH/SH@?#Y\1G)O;2!\1G)O;20I+R(L("1T97AT*2DI('L*("`@("`@
M("`@("`@<F5T=7)N("<@)R`N("1T97AT.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)'1E>'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5;G-T=69F<R!A
M('-P86-E('-T=69F960@;&EN92X*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@
M=&5X="!T;R!U;G-T=69F+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@=6YS='5F9F5D('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]U
M;G-T=69F*"1T97AT*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)'1E>'0I
M("8F("@D=&5X='LP?2`]/2`G("<I*2!["B`@("`@("`@("`@("1T97AT(#T@
M<W5B<W1R*"1T97AT+"`Q*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T
M97AT.PH@("`@?0H*?0H`````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+U1E>'0O<F535"\`````````````````````````````````````````````
M```````````````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<T-0`P,C`R,C8`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O5&5X="]R95-4+T9O<FUA='1E<B\`````````
M`````````````````````````````````````````````````````````#`P
M,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S0U
M`#`R,C$W,0`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]497AT+W)E4U0O
M1F]R;6%T=&5R+VAT;6PN<&AP````````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#8Q,#$`,3`U,34T,S,W-#4`,#(S-C0T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+RXN+T9O<FUA='1E<BYP:'`G.PH*+RHJ"B`J
M(%1H92!497AT7W)E4U1?1F]R;6%T=&5R7VAT;6PZ.B!C;&%S<R!I<R!T:&4@
M2%1-3"!F;W)M871T97(N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?
M<F535"]R95-4+T9O<FUA='1E<B]H=&UL+G!H<"QV(#$N-BXQ,BXU(#(P,#8O
M,#$O,#$@,C$Z,C@Z,SD@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S
M+3(P,#8@2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R;VYO<WES+F-O;3X*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA<V]N($TN($9E;&EC92`\
M:F9E;&EC94!C<F]N;W-Y<RYC;VT^"B`J($!P86-K86=E(%1E>'1?<F535`H@
M*B\*8VQA<W,@5&5X=%]R95-47T9O<FUA='1E<E]H=&UL(&5X=&5N9',@5&5X
M=%]R95-47T9O<FUA='1E<B!["@H@("`@+RHJ"B`@("`@*B!4:&4@8W5R<F5N
M="!O=71P=70@8VAA<G-E="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)%]C:&%R<V5T(#T@;G5L;#L*"B`@("!F=6YC=&EO
M;B!F;W)M870H)B1N;V1E+"`D8VAA<G-E="`](&YU;&PI"B`@("!["B`@("`@
M("`@:68@*"%I<W-E="@D8VAA<G-E="DI('L*("`@("`@("`@("`@)&-H87)S
M970@/2`D=&AI<RT^7V-H87)S970["B`@("`@("`@?0H*("`@("`@("!I9B`H
M:7-?<W1R:6YG*"1N;V1E*2D@>PH@("`@("`@("`@("!I9B`H:7-S970H)&-H
M87)S970I*2!["B`@("`@("`@("`@("`@("!R971U<FX@0&AT;6QS<&5C:6%L
M8VAA<G,H)&YO9&4L($5.5%]154]415,L("1C:&%R<V5T*3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!H=&UL<W!E8VEA
M;&-H87)S*"1N;V1E+"!%3E1?455/5$53*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<W=I=&-H("@D;F]D92T^7W1Y<&4I('L*("`@("`@
M("!C87-E("=$;V-U;65N="<Z"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7V-H:6QD<F5N*"1N;V1E*3L*"B`@("`@("`@8V%S92`G2&5A9&EN9R<Z"B`@
M("`@("`@("`@("1L979E;"`]("1N;V1E+3YG9710<F]P97)T>2@G;&5V96PG
M*3L*("`@("`@("`@("`@<F5T=7)N("<\:"<@+B`D;&5V96P@+B`G/B<@+B`D
M=&AI<RT^7V-H:6QD<F5N*"1N;V1E*2`N("<\+V@G("X*("`@("`@("`@("`@
M("`@("1L979E;"`N("<^)SL*"B`@("`@("`@8V%S92`G3&EN:R<Z"B`@("`@
M("`@("`@(')E='5R;B`G/&$@:')E9CTB)R`N"B`@("`@("`@("`@("`@("`H
M:7-S970H)&-H87)S970I(#\*("`@("`@("`@("`@("`@("!`:'1M;'-P96-I
M86QC:&%R<R@D;F]D92T^9V5T4')O<&5R='DH)VAR968G*2P@14Y47U%53U1%
M4RP@)&-H87)S970I(#H*("`@("`@("`@("`@("`@("!H=&UL<W!E8VEA;&-H
M87)S*"1N;V1E+3YG9710<F]P97)T>2@G:')E9B<I+"!%3E1?455/5$53*2D@
M+@H@("`@("`@("`@("`@("`@)R(^)R`N"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V-H:6QD<F5N*"1N;V1E*2`N("<\+V$^)SL*"B`@("`@("`@8V%S92`G
M3&ET97)A;"U";&]C:R<Z"B`@("`@("`@("`@(&QI<W0H)'1E>'0I(#T@)&YO
M9&4M/E]C:&EL9')E;CL*("`@("`@("`@("`@<F5T=7)N("<\<')E/B<@+B`H
M:7-S970H)&-H87)S970I(#\*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@0&AT;6QS<&5C:6%L8VAA<G,H)'1E>'0L($5.5%]154]415,L("1C:&%R
M<V5T*2`Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&AT;6QS<&5C
M:6%L8VAA<G,H)'1E>'0L($5.5%]154]415,I*2`N("<\+W!R93XG.PH*("`@
M("`@("!C87-E("=087)A9W)A<&@G.@H@("`@("`@("`@("!R971U<FX@(CQP
M/B(@+B`D=&AI<RT^7V-H:6QD<F5N*"1N;V1E*2`N("(\+W`^(CL*"B`@("`@
M("`@8V%S92`G26YT97)P<F5T960M5&5X="<Z"B`@("`@("`@("`@('-W:71C
M:"`H)&YO9&4M/F=E=%!R;W!E<G1Y*"=R;VQE)RDI('L*("`@("`@("`@("`@
M8V%S92`G96UP:&%S:7,G.@H@("`@("`@("`@("`@("`@<F5T=7)N("<\96T^
M)R`N("1T:&ES+3Y?8VAI;&1R96XH)&YO9&4I("X@)SPO96T^)SL*"B`@("`@
M("`@("`@(&-A<V4@)VQI=&5R86PG.@H@("`@("`@("`@("`@("`@<F5T=7)N
M("<\='0^)R`N("1T:&ES+3Y?8VAI;&1R96XH)&YO9&4I("X@)SPO='0^)SL*
M"B`@("`@("`@("`@(&-A<V4@)W-T<F]N9R<Z"B`@("`@("`@("`@("`@("!R
M971U<FX@)SQS=')O;F<^)R`N("1T:&ES+3Y?8VAI;&1R96XH)&YO9&4I("X@
M)SPO<W1R;VYG/B<["@H@("`@("`@("`@("!C87-E("=S=7!E<G-C<FEP="<Z
M"B`@("`@("`@("`@("`@("!R971U<FX@)SQS=7`^)R`N("1T:&ES+3Y?8VAI
M;&1R96XH)&YO9&4I("X@)SPO<W5P/B<["@H@("`@("`@("`@("!C87-E("=S
M=6)S8W)I<'0G.@H@("`@("`@("`@("`@("`@<F5T=7)N("<\<W5B/B<@+B`D
M=&AI<RT^7V-H:6QD<F5N*"1N;V1E*2`N("<\+W-U8CXG.PH*("`@("`@("`@
M("`@8V%S92`G=&ET;&4M<F5F97)E;F-E)SH*("`@("`@("`@("`@("`@(')E
M='5R;B`G/&-I=&4^)R`N("1T:&ES+3Y?8VAI;&1R96XH)&YO9&4I("X@)SPO
M8VET93XG.PH*("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@
M("\O(%A86#H@27-S=64@82!W87)N:6YG+@H@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?8VAI;&1R96XH)&YO9&4I.PH@("`@("`@("`@("!]"@H@
M("`@("`@(&-A<V4@)U-E8W1I;VXG.@H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]C:&EL9')E;B@D;F]D92D["B`@("`@("`@?0H@("`@?0H*("`@(&9U
M;F-T:6]N(%]C:&EL9')E;B@F)&YO9&4I"B`@("!["B`@("`@("`@)')E<W5L
M="`]("<G.PH@("`@("`@(&9O<F5A8V@@*"1N;V1E+3Y?8VAI;&1R96X@87,@
M)&-H:6QD*2!["B`@("`@("`@("`@("1R97-U;'0@+CT@)'1H:7,M/F9O<FUA
M="@D8VAI;&0I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5&5X="]R95-4
M+T9O<FUA='1E<BYP:'``````````````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`S-#,T`#$P-3$U-#,S-S0U`#`R,C<P-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@5&AE(%1E>'1?
M<F535%]&;W)M871T97(Z.B!C;&%S<R!I<R!T:&4@9G)A;65W;W)K(&9O<B!R
M96YD97)I;F<*("H@<F53=')U8W1U<F5D5&5X="!D;V-U;65N=',@=&\@9&EF
M9F5R96YT(&UE9&EA("AE+F<N($A434PI+@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]497AT7W)E4U0O<F535"]&;W)M871T97(N<&AP+'8@,2XU+C$P+CD@
M,C`P-B\P,2\P,2`R,3HR.#HS.2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#,M,C`P-B!*87-O;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N
M8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%S;VX@32X@1F5L
M:6-E(#QJ9F5L:6-E0&-R;VYO<WES+F-O;3X*("H@0'!A8VMA9V4@5&5X=%]R
M95-4"B`J+PIC;&%S<R!497AT7W)E4U1?1F]R;6%T=&5R('L*"B`@("`O*BH*
M("`@("`J($%R<F%Y(&]F(&1R:79E<BUS<&5C:69I8R!P87)A;65T97)S(&9O
M<B!F;W)M871T:6YG+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?87)G<SL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C="!A
M(&YE=R!F;W)M871T97(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T
M960*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&%R9W,@($%R9W5M96YT
M<R!S<&5C:69I8R!T;R!T:&ES(&9O<FUA='1E<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@5&5X=%]R95-47T9O<FUA='1E<B@D87)G<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@)'1H:7,M/E]A<F=S(#T@)&%R9W,["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#;VYS=')U8W0@82!N97<@9F]R;6%T=&5R+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&1R:79E<B`@3F%M92!O9B!T:&4@9F]R
M;6%T=&EN9R!D<FEV97(@=&\@8V]N<W1R=6-T+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1A<F=S("`@("!!;B!A<G)A>2!O9B!D<FEV97(M<W!E8VEF:6,@<&%R
M86UE=&5R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(%1E>'1?<F535%]&;W)M
M871T97(@(%1H92!F;W)M871T97(*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A
M8W1O<GDH)&1R:79E<BP@)&%R9W,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@
M(&EF("AI<U]A<G)A>2@D9')I=F5R*2D@>PH@("`@("`@("`@("!L:7-T*"1P
M871H+"`D9')I=F5R*2`]("1D<FEV97(["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'!A=&@@/2!D:7)N86UE*%]?1DE,15]?*2`N("<O1F]R;6%T
M=&5R+R<["B`@("`@("`@?0H@("`@("`@("1C;&%S<R`]("=497AT7W)E4U1?
M1F]R;6%T=&5R7R<@+B`D9')I=F5R.PH@("`@("`@(')E<75I<F5?;VYC92`D
M<&%T:"`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@)&9O<FUA='1E<B`]
M("9N97<@)&-L87-S*"1A<F=S*3L*("`@("`@("!R971U<FX@)&9O<FUA='1E
M<CL*("`@('T*"B`@("`O*BH*("`@("`J(%)E;F1E<B!T:&4@9&]C=6UE;G0N
M"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M
M(%1E>'1?<F535"`D9&]C=6UE;G0@(%1H92!D;V-U;65N="!W92!W:6QL(')E
M;F1E<BX*("`@("`J($!P87)A;2!S=')I;F<@)&-H87)S970@("`@("!4:&4@
M;W5T<'5T(&-H87)S970N"B`@("`@*B\*("`@(&9U;F-T:6]N(&9O<FUA="@F
M)&1O8W5M96YT+"`D8VAA<G-E="`](&YU;&PI"B`@("!["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U1E>'0O<F535"]087)S
M97(N<&AP````````````````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`V,3<T
M,``Q,#4Q-30S,S<T-0`P,C(R,#,`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J(%1H92!497AT7W)E4U1?
M4&%R<V5R.CH@8VQA<W,@:6UP;&5M96YT<R!A('!A<G-E<B!F;W(@<F53=')U
M8W1U<F5D5&5X=`H@*B!D;V-U;65N=',N"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+U1E>'1?<F535"]R95-4+U!A<G-E<BYP:'`L=B`Q+C@N,BXX(#(P,#8O
M,#$O,#$@,C$Z,C@Z,SD@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S
M+3(P,#8@2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R;VYO<WES+F-O;3X*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA<V]N($TN($9E;&EC92`\
M:F9E;&EC94!C<F]N;W-Y<RYC;VT^"B`J($!P86-K86=E(%1E>'1?<F535`H@
M*B\*8VQA<W,@5&5X=%]R95-47U!A<G-E<B!["@H@("`@+RHJ"B`@("`@*B!4
M:&4@<&%R<V4@=')E92X*("`@("`J"B`@("`@*B!`=F%R(%1E>'1?<F535`H@
M("`@("HO"B`@("!V87(@)%]D;V-U;65N=#L*"B`@("`O*BH*("`@("`J($$@
M:&%S:"!O9B!A9&]R;FUE;G0@;&5V96QS+@H@("`@("H*("`@("`J(%1H92!K
M97ES(&%R92!O;F4M8VAA<F%C=&5R(&]R('1W;RUC:&%R86-T97(@<W1R:6YG
M<RX@(%1H92!O;F4M8VAA<F%C=&5R"B`@("`@*B!S=')I;F=S(')E<')E<V5N
M="!U;F1E<FQI;F4@861O<FYM96YT<R!O9B!T:&4@<W!E8VEF:65D(&-H87)A
M8W1E<BP@86YD"B`@("`@*B!T:&4@9&]U8FQE+6-H87)A8W1E<B!K97ES(&%R
M92!T:&4@=6YD97)L:6YE+6%N9"UO=F5R;&EN92!S='EL97,N("!4:&4*("`@
M("`J('9A;'5E<R!A<W-O8VEA=&5D('=I=&@@=&AE(&ME>7,@87)E(&EN=&5G
M97)S(')E<')E<V5N=&EN9R!T:&4*("`@("`J(&%D;W)N;65N="=S(&AE861I
M;F<@;&5V96PN"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]A9&]R;FUE;G1,979E;',@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(%1E>'1?
M<F535%]087)S97(H*0H@("`@>PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!A('!A<G-E('1R964@<F5P<F5S96YT:6YG(&$@9&]C=6UE;G0N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AI<R!I<R!T:&4@
M=&5X="!O9B!T:&4@9&]C=6UE;G0@=&\@<&%R<V4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!497AT7W)E4U0@(%1H92!P87)S92!T<F5E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B`F<&%R<V4H)'1E>'0I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]T97AT(#T@)'1E>'0["@H@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE
M*%]?1DE,15]?*2`N("<O+BXO<F535"YP:'`G.PH*("`@("`@("`D=&AI<RT^
M7V1O8W5M96YT(#T@)FYE=R!497AT7W)E4U0H)T1O8W5M96YT)RD["B`@("`@
M("`@)'1H:7,M/E]P=7-H4W1A=&4H)'1H:7,M/E]D;V-U;65N="P@)U-E8W1I
M;VXG+"`P*3L*"B`@("`@("`@=VAI;&4@*"1T:&ES+3Y?;F5X="@I*2!["@H@
M("`@("`@("`@("`O+PH@("`@("`@("`@("`O+R!087)S92!A(&`N+B<@9&ER
M96-T:79E+B`@5V4@<F5W<FET92!A;B!@7U\G(&1I<F5C=&EV92!T;R!A"B`@
M("`@("`@("`@("\O(&`N+B!?7SH@)R!D:7)E8W1I=F4@:&5R92X*("`@("`@
M("`@("`@+R\*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>*%PN7"Y\
M7U\I7',K*"XJ/RE<<RHD+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;&EN94)U9F9E<ELP72P@)&TI*2!["B`@("`@("`@("`@("`@
M("!I9B`H)&U;,5T@/3T@)U]?)RD@>PH@("`@("`@("`@("`@("`@("`@("1T
M97AT(#T@)U]?.B`G("X@)&U;,ET["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1T97AT(#T@)&U;,ET["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!W:&EL92`H)'1H:7,M/E]E;G-U
M<F5,:6YE<R@R*2`F)@H@("`@("`@("`@("`@("`@("`@("`@('!R96=?;6%T
M8V@H)R]>("`H6UY<<UTN*C\I7',J)"\G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]L:6YE0G5F9F5R6S%=+"`D;2DI('L*
M("`@("`@("`@("`@("`@("`@("`D=&5X="`N/2`G("<N)&U;,5T["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]N97AT*"D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<G-E1&ER96-T:79E*"1T
M97AT*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`O+PH@("`@("`@("`@("`O+R!,;V]K(&9O<B!O=F5R
M;&EN92UA;F0M=6YD97)L:6YE(&AE861I;F=S+@H@("`@("`@("`@("`O+PH@
M("`@("`@("`@("!I9B`H)'1H:7,M/E]E;G-U<F5,:6YE<R@S*2`F)@H@("`@
M("`@("`@("`@("`@<')E9U]M871C:"@G+UXH+BL_*5QS*B0O)RP@)'1H:7,M
M/E]L:6YE0G5F9F5R6S%=+"`D;&EN94UA=&-H*2`F)@H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]C:&5C:T%D;W)N;65N="AA<G)A>2@P+"`R*2P@<W1R;&5N
M*"1L:6YE36%T8VA;,5TI*2D@>PH*("`@("`@("`@("`@("`@("1A9&]R;FUE
M;G14>7!E(#T@)'1H:7,M/E]L:6YE0G5F9F5R6S!=>S!].PH@("`@("`@("`@
M("`@("`@)&%D;W)N;65N=%1Y<&4@+CT@)&%D;W)N;65N=%1Y<&4["@H@("`@
M("`@("`@("`@("`@)'1H:7,M/E]N97AT*"D["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7VYE>'0H*3L*"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]A9&]R;FUE;G1,979E;'-;)&%D;W)N;65N=%1Y<&5=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1N97=,979E;"`]("1T:&ES+3Y?861O<FYM96YT
M3&5V96QS6R1A9&]R;FUE;G14>7!E73L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!O<%1O3&5V96PH)U-E8W1I;VXG+"`D;F5W3&5V96P@+2`Q*3L*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)&YE=TQE=F5L(#T@)'1H:7,M/E]G9713=&%T94QE=F5L*"=396-T:6]N)RD@
M*R`Q.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861O<FYM96YT3&5V
M96QS6R1A9&]R;FUE;G14>7!E72`]("1N97=,979E;#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("1N;V1E(#T@)B1T:&ES+3Y?;6%K94YO
M9&4H)'1H:7,M/E]C=7)R96YT3F]D92P@)U-E8W1I;VXG+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G;&5V96PG
M(#T^("1N97=,979E;"DI.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P=7-H
M4W1A=&4H)&YO9&4L("=396-T:6]N)RP@)&YE=TQE=F5L*3L*("`@("`@("`@
M("`@("`@('!R96=?;6%T8V@H)R]>7',J*"XJ/RE<<RHD+R<L("1L:6YE36%T
M8VA;,5TL("1L:6YE36%T8V@I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]M
M86ME3F]D92@D=&AI<RT^7V-U<G)E;G1.;V1E+"`G2&5A9&EN9R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=L979E;"<@/3X@
M)&YE=TQE=F5L*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&QI;F5-871C:%LQ72D["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+R\*("`@("`@("`@("`@+R\@3&]O
M:R!F;W(@=6YD97)L:6YE(&AE861I;F=S+@H@("`@("`@("`@("`O+PH@("`@
M("`@("`@("!I9B`H)'1H:7,M/E]E;G-U<F5,:6YE<R@R*2`F)@H@("`@("`@
M("`@("`@("`@<')E9U]M871C:"@G+UXH6UY<<UTN*C\I7',J)"\G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VQI;F5"=69F97);,%TL
M("1L:6YE36%T8V@I("8F"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-H96-K
M061O<FYM96YT*&%R<F%Y*#$I+"!S=')L96XH)&QI;F5-871C:%LQ72DI*2![
M"@H@("`@("`@("`@("`@("`@)&%D;W)N;65N=%1Y<&4@/2`D=&AI<RT^7VQI
M;F5"=69F97);,5U[,'T["B`@("`@("`@("`@("`@("`D=&AI<RT^7VYE>'0H
M*3L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V%D;W)N;65N
M=$QE=F5L<ULD861O<FYM96YT5'EP95TI*2!["B`@("`@("`@("`@("`@("`@
M("`@)&YE=TQE=F5L(#T@)'1H:7,M/E]A9&]R;FUE;G1,979E;'-;)&%D;W)N
M;65N=%1Y<&5=.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&]P5&],
M979E;"@G4V5C=&EO;B<L("1N97=,979E;"`M(#$I.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D;F5W3&5V96P@/2`D
M=&AI<RT^7V=E=%-T871E3&5V96PH)U-E8W1I;VXG*2`K(#$["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]A9&]R;FUE;G1,979E;'-;)&%D;W)N;65N
M=%1Y<&5=(#T@)&YE=TQE=F5L.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@)&YO9&4@/2`F)'1H:7,M/E]M86ME3F]D92@D=&AI<RT^7V-U
M<G)E;G1.;V1E+"`G4V5C=&EO;B<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=L979E;"<@/3X@)&YE=TQE=F5L
M*2D["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!U<VA3=&%T92@D;F]D92P@
M)U-E8W1I;VXG+"`D;F5W3&5V96PI.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]M86ME3F]D92@D=&AI<RT^7V-U<G)E;G1.;V1E+"`G2&5A9&EN9R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=L979E;"<@
M/3X@)&YE=TQE=F5L*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&QI;F5-871C:%LQ72D["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\*("`@("`@("`@("`@+R\@
M4&%R<V4@82!@.CHG('!A<F%G<F%P:"X*("`@("`@("`@("`@+R\*("`@("`@
M("`@("`@:68@*'!R96=?;6%T8V@H)R]>7',J.CI<<RHD+R<L("1T:&ES+3Y?
M;&EN94)U9F9E<ELP72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;F5X
M="@I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)S94QI=&5R86Q";&]C
M:R@I.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("\O"B`@("`@("`@("`@("\O(%!A<G-E(&$@<&%R86=R
M87!H+B`@5V4@96YD('1H92!P87)A9W)A<&@@=VAE;B!W92!R971U<FX@=&\*
M("`@("`@("`@("`@+R\@82!L;W=E<B!I;F1E;G1A=&EO;B!L979E;"!O<B!E
M;F-O=6YT97(@82!B;&%N:R!L:6YE+@H@("`@("`@("`@("`O+PH@("`@("`@
M("`@("!I9B`H<')E9U]M871C:"@G+UXH7',J*2A;7EQS72XJ/RE<<RHD+R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;&EN94)U9F9E
M<ELP72P@)&TI*2!["B`@("`@("`@("`@("`@("`D=&5X="`]("1M6S)=.PH@
M("`@("`@("`@("`@("`@)&QE=F5L(#T@<W1R;&5N*"1M6S%=*3L*("`@("`@
M("`@("`@("`@('=H:6QE("@D=&AI<RT^7V5N<W5R94QI;F5S*#(I("8F"B`@
M("`@("`@("`@("`@("`@("`@("`@<')E9U]M871C:"@G+UXH7',J*2A;7EQS
M72XJ/RE<<RHD+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7VQI;F5"=69F97);,5TL("1M*2D@>PH@("`@("`@("`@("`@
M("`@("`@(&EF("AS=')L96XH)&U;,5TI(#P@)&QE=F5L*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`D=&5X="`N/2`G("<@+B`D;5LR73L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7VYE>'0H*3L*("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("`D=')A:6QI;F=,:71E<F%L(#T@9F%L
M<V4["B`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UXH+BI;7EQS
M73HI.EQS*B0O)RP@)'1E>'0L("1M*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1T97AT(#T@)&U;,5T["B`@("`@("`@("`@("`@("`@("`@)'1R86EL:6YG
M3&ET97)A;"`]('1R=64["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H<')E
M9U]M871C:"@G+UXH+BH_*5QS*CHZ7',J)"\G+"`D=&5X="P@)&TI*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1E>'0@/2`D;5LQ73L*("`@("`@("`@("`@
M("`@("`@("`D=')A:6QI;F=,:71E<F%L(#T@=')U93L*("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("`D=&AI<RT^7VUA:V5.;V1E*"1T:&ES
M+3Y?8W5R<F5N=$YO9&4L("=087)A9W)A<&@G+"!A<G)A>2@I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&5X="D["@H@("`@("`@("`@
M("`@("`@:68@*"1T<F%I;&EN9TQI=&5R86PI('L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7VYE>'0H*3L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<G-E3&ET97)A;$)L;V-K*"D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@+R\@6%A8.B!(86YD;&4@9V%R8F%G92!L:6YE+@H*("`@("`@("!]
M.PH*("`@("`@("!R971U<FX@)'1H:7,M/E]D;V-U;65N=#L*("`@('T*"B`@
M("!F=6YC=&EO;B`F7VUA:V5.;V1E*"8D<&%R96YT+"`D='EP92P@)'!R;W!S
M(#T@87)R87DH*2P@)&-H:6QD5&5X="`](&YU;&PI"B`@("!["B`@("`@("`@
M)&YO9&4@/2`F;F5W(%1E>'1?<F535"@D='EP92D["B`@("`@("`@9F]R96%C
M:"`H)'!R;W!S(&%S("1N86UE(#T^("1V86QU92D@>PH@("`@("`@("`@("`D
M;F]D92T^<V5T4')O<&5R='DH)&YA;64L("1V86QU92D["B`@("`@("`@?0H@
M("`@("`@(&EF("@A:7-?;G5L;"@D<&%R96YT*2D@>PH@("`@("`@("`@("`D
M<&%R96YT+3YA<'!E;F1#:&EL9"@D;F]D92D["B`@("`@("`@?0H@("`@("`@
M(&EF("@A:7-?;G5L;"@D8VAI;&1497AT*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7W!A<G-E26YL:6YE*"1N;V1E+"`D8VAI;&1497AT*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1N;V1E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0VAE8VMS(&UU;'1I<&QE(&%D;W)N96UN="!L:6YE<R!I;B!T:&4@;&EN92!B
M=69F97(@86YD(&UA:V5S('-U<F4@=&AE>0H@("`@("H@87)E(&%D;W)N;65N
M=',@86YD('1H870@86QL(&%R92!I9&5N=&EC86P@861O<FYM96YT<RX*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)&QI;F5S("`@("`@("!!;B!A<G)A>2!O9B!L:6YE(&YU;6)E
M<G,@=&\@8VAE8VL@:68@=&AE>2!A<F4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%D;W)N;65N=',N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D;6EN3&5N9W1H("!4:&4@;6EN:6UU;2!L96YG=&@@9F]R('1H:7,@861O
M<FYM96YT+B`@5&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!D969A=6QT(&ES(#$N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!7:&5T:&5R('1H:7,@;&EN92!I<R!A;B!A9&]R;FUE;G0@=VAI8V@@;6%T
M8VAE<R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@86)O=F4@8W)I=&5R
M:6$N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C:&5C:T%D;W)N;65N="@D;&EN
M97,@/2!A<G)A>2@P*2P@)&UI;DQE;F=T:"`](#$I"B`@("!["B`@("`@("`@
M)&-H<B`](&YU;&P["B`@("`@("`@9F]R96%C:"`H)&QI;F5S(&%S("1I*2![
M"B`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@G+UXH6UYA+7I!+5HP+3E<
M>#=F+5QX9F9<<UTK*5QS*B0O)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?;&EN94)U9F9E<ELD:5TL("1M*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("AI<U]N=6QL*"1C:'(I*2!["B`@("`@("`@("`@("`@("!I9B`H<W1R
M;&5N*"1M6S%=*2`\("1M:6Y,96YG=&@I('L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`D8VAR(#T@)&U;,5U[,'T["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("!I9B`H<W1R;&5N*"1M6S%=*2`A/2`D;6EN3&5N9W1H
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1M:6Y,96YG
M=&@@/2!S=')L96XH)&U;,5TI.PH@("`@("`@("`@("!F;W(@*"1J(#T@,#L@
M)&H@/"!S=')L96XH)&U;,5TI.R`D:BLK*2!["B`@("`@("`@("`@("`@("!I
M9B`H)&U;,5U[)&I]("$]("1C:'(I('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N
M8W1I;VX@)E]P87)S94EN;&EN92@F)&YO9&4L("1T97AT*0H@("`@>PH@("`@
M("`@('-T871I8R`D86QI87-E<R`](&%R<F%Y*"=S=7`G(#T^("=S=7!E<G-C
M<FEP="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-U8B<@
M/3X@)W-U8G-C<FEP="<I.PH@("`@("`@('-T871I8R`D<V-H96UA<R`](&%R
M<F%Y*"=H='1P)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M:'1T<',G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F='`G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=I<F,G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T96QN970G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=N97=S)RD["@H@("`@("`@('=H
M:6QE("AS=')L96XH)'1E>'0I(#X@,"D@>PH@("`@("`@("`@("!I9B`H<')E
M9U]M871C:"@G+UY<*EPJ*"@_.EQ<7%PN?%M>7%Q<7%TI*C\I7"I<*B@N*BDD
M+R<L("1T97AT+"`D;2DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;6%K
M94YO9&4H)&YO9&4L("=);G1E<G!R971E9"U497AT)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)W)O;&4G(#T^("=S=')O;F<G
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&U;,5TI.PH@
M("`@("`@("`@("`@("`@)'1E>'0@/2`D;5LR73L*("`@("`@("`@("`@?2!E
M;'-E:68@*'!R96=?;6%T8V@H)R]>7"HH*#\Z7%Q<7"Y\6UY<7%Q<72DJ/RE<
M*B@N*BDD+R<L("1T97AT+"`D;2DI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;6%K94YO9&4H)&YO9&4L("=);G1E<G!R971E9"U497AT)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W)O;&4G(#T^("=E
M;7!H87-I<R<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;5LQ72D["B`@("`@("`@("`@("`@("`D=&5X="`]("1M6S)=.PH@("`@("`@
M("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G+UY@8"@N*C\I8&`H+BHI)"\G
M+"`D=&5X="P@)&TI*2!["B`@("`@("`@("`@("`@("`D<W5B(#T@)B1T:&ES
M+3Y?;6%K94YO9&4H)&YO9&4L("=);G1E<G!R971E9"U497AT)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<F]L
M92<@/3X@)VQI=&5R86PG*2D["B`@("`@("`@("`@("`@("`D<W5B+3YA<'!E
M;F1#:&EL9"@D;5LQ72D["B`@("`@("`@("`@("`@("`D=&5X="`]("1M6S)=
M.PH@("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G+UXZ*%MA+7HM
M72LI.F`H*#\Z7%Q<7"Y\6UY<7%Q<72DJ/RE@*"XJ*20O)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1E>'0L("1M*2D@>PH@("`@("`@
M("`@("`@("`@)')O;&4@/2`D;5LQ73L*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D86QI87-E<ULD;5LQ75TI*2!["B`@("`@("`@("`@("`@("`@("`@
M)')O;&4@/2`D86QI87-E<ULD;5LQ75T["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D<W5B(#T@)B1T:&ES+3Y?;6%K94YO9&4H)&YO9&4L
M("=);G1E<G!R971E9"U497AT)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@G<F]L92<@/3X@)')O;&4I*3L*("`@
M("`@("`@("`@("`@(&EF("@D<F]L92`]/2`G;&ET97)A;"<I('L*("`@("`@
M("`@("`@("`@("`@("`D<W5B+3YA<'!E;F1#:&EL9"@D;5LR72D["B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R<V5);FQI;F4H)'-U8BP@)&U;,ETI.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)'1E>'0@/2`D;5LS73L*("`@("`@("`@("`@
M?2!E;'-E:68@*'!R96=?;6%T8V@H)R]>8"@H/SI<7%Q<+GQ;7EQ<7%Q=*2H_
M*6`Z*%MA+7HM72LI.B@N*BDD+R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T97AT+"`D;2DI('L*("`@("`@("`@("`@("`@("1R;VQE
M(#T@)&U;,ET["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%L:6%S97-;
M)&U;,EU=*2D@>PH@("`@("`@("`@("`@("`@("`@("1R;VQE(#T@)&%L:6%S
M97-;)&U;,EU=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)'-U8B`]("8D=&AI<RT^7VUA:V5.;V1E*"1N;V1E+"`G26YT97)P<F5T960M
M5&5X="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)W)O;&4G(#T^("1R;VQE*2D["B`@("`@("`@("`@("`@("!I
M9B`H)')O;&4@/3T@)VQI=&5R86PG*2!["B`@("`@("`@("`@("`@("`@("`@
M)'-U8BT^87!P96YD0VAI;&0H)&U;,5TI.PH@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<G-E26YL:6YE
M*"1S=6(L("1M6S%=*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("1T97AT(#T@)&U;,UT["B`@("`@("`@("`@('T@96QS96EF("AP<F5G
M7VUA=&-H*"<O7F`H*#\Z7%Q<7"Y\6UY<7%Q<72DJ/RE@7U\H+BHI)"\G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&5X="P@)&TI*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<G-E3&EN:R@D;F]D92P@)&U;
M,5TL('1R=64I.PH@("`@("`@("`@("`@("`@)'1E>'0@/2`D;5LR73L*("`@
M("`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)R]>8"@H/SI<7%Q<+GQ;
M7EQ<7%Q=*2H_*6!?*"XJ*20O)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1E>'0L("1M*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P87)S94QI;FLH)&YO9&4L("1M6S%=+"!F86QS92D["B`@("`@("`@("`@
M("`@("`D=&5X="`]("1M6S)=.PH@("`@("`@("`@("!](&5L<V5I9B`H<')E
M9U]M871C:"@G+UY@*"@_.EQ<7%PN?%M>7%Q<7%TI*C\I8"@N*BDD+R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T97AT+"`D;2DI('L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?;6%K94YO9&4H)&YO9&4L("=);G1E
M<G!R971E9"U497AT)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)W)O;&4G(#T^("=T:71L92UR969E<F5N8V4G*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&U;,5TI.PH@("`@("`@("`@
M("`@("`@)'1E>'0@/2`D;5LR73L*("`@("`@("`@("`@?2!E;'-E:68@*'!R
M96=?;6%T8V@H)R]>*"@_.B<@+B!J;VEN*"=\)RP@)'-C:&5M87,I("X@("<I
M.EPO7"];+3`M.6$M>B,E)BLN7"\Z.S]?7%Q^72M;+3`M.6$M>B,E)BM<+U]<
M7'Y=*2@N*BDD+VDG+"`D=&5X="P@)&TI*2!["B`@("`@("`@("`@("`@("`D
M<W5B(#T@)B1T:&ES+3Y?;6%K94YO9&4H)&YO9&4L("=,:6YK)RP@87)R87DH
M)VAR968G(#T^("1M6S%=*2D["B`@("`@("`@("`@("`@("`D<W5B+3YA<'!E
M;F1#:&EL9"@D;5LQ72D["B`@("`@("`@("`@("`@("`D=&5X="`]("1M6S)=
M.PH@("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G+UXH6V$M>C`M
M.2U=*T!;82UZ,"TY+5PN72M<+EMA+7HP+3DM72LI*"XJ*20O:2<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T97AT+"`D;2DI('L*("`@
M("`@("`@("`@("`@("1S=6(@/2`F)'1H:7,M/E]M86ME3F]D92@D;F]D92P@
M)TQI;FLG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"=H<F5F)R`]/B`G;6%I;'1O.B<@+B`D;5LQ72DI.PH@("`@
M("`@("`@("`@("`@)'-U8BT^87!P96YD0VAI;&0H)&U;,5TI.PH@("`@("`@
M("`@("`@("`@)'1E>'0@/2`D;5LR73L*("`@("`@("`@("`@?2!E;'-E:68@
M*'!R96=?;6%T8V@H)R]>*%QW*RE?7&(H+BHI)"\G+"`D=&5X="P@)&TI*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<G-E3&EN:R@D;F]D92P@)&U;
M,5TL(&9A;'-E*3L*("`@("`@("`@("`@("`@("1T97AT(#T@)&U;,ET["B`@
M("`@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"<O7EQ<7%Q<<R@N*BDD
M+R<L("1T97AT+"`D;2DI('L*("`@("`@("`@("`@("`@("\O($)A8VMS;&%S
M:"UE<V-A<&5D('=H:71E<W!A8V4@8VAA<F%C=&5R<R!A<F4@<F5M;W9E9"!F
M<F]M"B`@("`@("`@("`@("`@("`O+R!T:&4@9&]C=6UE;G0N"B`@("`@("`@
M("`@("`@("`D=&5X="`]("1M6S%=.PH@("`@("`@("`@("!](&5L<V5I9B`H
M<')E9U]M871C:"@G+UY<7%Q<*"XI*"XJ*20O)RP@)'1E>'0L("1M*2D@>PH@
M("`@("`@("`@("`@("`@)&,@/2`D;5LQ73L*("`@("`@("`@("`@("`@("1T
M97AT(#T@)&U;,ET["B`@("`@("`@("`@("`@("`D;F]D92T^87!P96YD0VAI
M;&0H)&,I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M+R\@6%A8.B!792!S:&]U;&0@=')Y('1O('5S92!A(')E9V5X<"!T;R!G<F%B
M(&%S(&UU8V@@=&5X="!A<PH@("`@("`@("`@("`@("`@+R\@<&]S<VEB;&4L
M('1H96X@9F%L;"!T:')O=6=H('1O('1H92!S:6YG;&4M8VAA<F%C=&5R(&-A
M<V4*("`@("`@("`@("`@("`@("\O(&EF('=E(&-A;B=T(&=E="!A;GET:&EN
M9RX*"B`@("`@("`@("`@("`@("`D8R`]('-U8G-T<B@D=&5X="P@,"P@,2D[
M"B`@("`@("`@("`@("`@("`D=&5X="`]('-U8G-T<B@D=&5X="P@,2D["B`@
M("`@("`@("`@("`@("`D;F]D92T^87!P96YD0VAI;&0H)&,I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&)O9'D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!087)S97,@86X@86YO;GEM;W5S(&]R(&YA;65D
M(&QI;FLN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M(%1E>'1?<F535"`@("`@("`@("`@5&AE('!A<F5N="!N
M;V1E(&9O<B!T:&4@;&EN:RX*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@
M("`@("`@(%1H92!T97AT('1O('!A<G-E+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&%N;VYY;6]U<R`@5VAE=&AE<B!T:&ES(&ES(&%N(&%N;VYY;6]U<R!L
M:6YK+@H@("`@("H*("`@("`J($!R971U<FX@5&5X=%]R95-4("!4:&4@;F5W
M(&QI;FL@;F]D92X*("`@("`J+PH@("`@9G5N8W1I;VX@)E]P87)S94QI;FLH
M)B1N;V1E+"`D=&5X="P@)&%N;VYY;6]U<R`](&9A;'-E*0H@("`@>PH@("`@
M("`@("1L:6YK(#T@)B1T:&ES+3Y?;6%K94YO9&4H)&YO9&4L("=,:6YK)RD[
M"@H@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O/"@N*BD^+R<L("1T97AT+"`D
M;2DI('L*("`@("`@("`@("`@)&QI;FLM/G-E=%!R;W!E<G1Y*"=H<F5F)RP@
M)&U;,5TI.PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UXH6UX\72L_
M*5QS*CPO)RP@)'1E>'0L("1M*2D@>PH@("`@("`@("`@("`@("`@)&QI;FLM
M/F%P<&5N9$-H:6QD*"1M6S%=*3L*("`@("`@("`@("`@("`@(&EF("@A)&%N
M;VYY;6]U<RD@>PH@("`@("`@("`@("`@("`@("`@("1L:6YK+3YS9710<F]P
M97)T>2@G;F%M92<L("1T:&ES+3Y?;F]R;6%L:7IE3F%M92@D;5LQ72DI.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@:68@*"$D86YO;GEM;W5S*2!["B`@("`@("`@("`@
M("`@("`D;&EN:RT^<V5T4')O<&5R='DH)VYA;64G+"`D=&AI<RT^7VYO<FUA
M;&EZ94YA;64H)'1E>'0I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M;&EN:RT^87!P96YD0VAI;&0H)'1E>'0I.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"1A;F]N>6UO=7,@)B8@:7-?;G5L;"@D;&EN:RT^9V5T4')O<&5R='DH
M)VAR968G*2DI('L*("`@("`@("`@("`@)'1H:7,M/E]Q=65U94%N;VYY;6]U
M<U)E9F5R96YC92@D;&EN:RP@)VQI;FLG*3L*("`@("`@("!](&5L<V5I9B`H
M(21A;F]N>6UO=7,@)B8@(6ES7VYU;&PH)&QI;FLM/F=E=%!R;W!E<G1Y*"=N
M86UE)RDI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<'5T3F%M9612969E<F5N
M8V4H)&QI;FLL("=L:6YK)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&QI;FL["B`@("!]"@H@("`@+RHJ"B`@("`@*B!.;W)M86QI>F5S(&%N(&]B
M:F5C="!N86UE+@H@("`@("H@5&AI<R!M96%N<R!T:&%T('=E(&QO=V5R8V%S
M92!I="!A;F0@;F]R;6%L:7IE(&%N>2!W:&ET97-P86-E(&EN(&ET+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@($$@;F%M92!T;R!N;W)M
M86QI>F4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!N;W)M
M86QI>F5D(&YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]N;W)M86QI>F5.
M86UE*"1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B!P<F5G7W)E<&QA8V4H
M)R]<<RLO)RP@)R`G+"!S=')T;VQO=V5R*"1N86UE*2D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!087)S97,@86YD(&5X96-U=&5S(&$@8"XN)R!D:7)E8W1I
M=F4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=&5X="`@02!D:7)E8W1I=F4@=&\@97AE8W5T
M92P@;&5S<R!T:&4@;&5A9&EN9R!@+BX@)RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W!A<G-E1&ER96-T:79E*"1T97AT*0H@("`@>PH@("`@("`@(&EF("AP
M<F5G7VUA=&-H*"<O7E]?.EQS*B@N*C\I7',J)"\G+"`D=&5X="P@)&TI*2![
M"B`@("`@("`@("`@("\O"B`@("`@("`@("`@("\O($%N;VYY;6]U<R!L:6YK
M(&1E9FEN:71I;VX*("`@("`@("`@("`@+R\*("`@("`@("`@("`@)&1E9FX@
M/2`F;F5W(%1E>'1?<F535"@G3&EN:R<I.PH@("`@("`@("`@("!I9B`H<')E
M9U]M871C:"@G+UY;82UZ,"TY+5TK0%MA+7HP+3DM7"Y=*UPN6V$M>C`M.2U=
M*R0O:2<L("1M6S%=*2D@>PH@("`@("`@("`@("`@("`@)&U;,5T@/2`G;6%I
M;'1O.B<@+B`D;5LQ73L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D9&5F
M;BT^<V5T4')O<&5R='DH)VAR968G+"`D;5LQ72D["B`@("`@("`@("`@("1T
M:&ES+3Y?<75E=65!;F]N>6UO=7-$969I;FET:6]N*"1D969N+"`G;&EN:R<I
M.PH@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"<O7EQS*E\H+BH_*3I<
M<RHH+BH_*5QS*B0O)RP@)'1E>'0L("1M*2D@>PH@("`@("`@("`@("`O+PH@
M("`@("`@("`@("`O+R!.86UE9"!L:6YK(&1E9FEN:71I;VX*("`@("`@("`@
M("`@+R\*("`@("`@("`@("`@)&1E9FX@/2`F;F5W(%1E>'1?<F535"@G3&EN
M:R<I.PH@("`@("`@("`@("`D9&5F;BT^<V5T4')O<&5R='DH)VYA;64G+"`D
M=&AI<RT^7VYO<FUA;&EZ94YA;64H)&U;,5TI*3L*("`@("`@("`@("`@:68@
M*'!R96=?;6%T8V@H)R]>6V$M>C`M.2U=*T!;82UZ,"TY+5PN72M<+EMA+7HP
M+3DM72LD+VDG+"`D;5LR72DI('L*("`@("`@("`@("`@("`@("1M6S)=(#T@
M)VUA:6QT;SHG("X@)&U;,ET["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)&1E9FXM/G-E=%!R;W!E<G1Y*"=H<F5F)RP@)&U;,ETI.PH@("`@("`@("`@
M("`D=&AI<RT^7W!U=$YA;65D1&5F:6YI=&EO;B@D9&5F;BP@)VQI;FLG*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3:VEP<R!B;&%N:R!L
M:6YE<R!U;G1I;"!W92!F:6YD(&]N92!W92!C86X@9V5T('1H92!I;F1E;G1A
M=&EO;B!L979E;`H@("`@("H@9G)O;2P@=&AE;BP@9V%T:&5R<R!L:6YE<R!U
M;G1I;"!W92!H879E(&$@9&EF9F5R96YT(&QE=F5L+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?<&%R<V5,:71E<F%L0FQO8VLH*0H@("`@>PH@("`@("`@(&EF
M("@A)'1H:7,M/E]E;G-U<F5,:6YE<R@Q*2D@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!W:&EL92`H<')E9U]M871C
M:"@G+UY<<RHD+R<L("1T:&ES+3Y?;&EN94)U9F9E<ELP72DI('L*("`@("`@
M("`@("`@:68@*"$D=&AI<RT^7VYE>'0H*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!I9B`H(7!R96=?;6%T8V@H)R]>*%QS*RDH+BH_*5QS*B0O)RP@)'1H:7,M
M/E]L:6YE0G5F9F5R6S!=+"`D;2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@("`@("`D;&5V96P@/2!S=')L96XH)&U;,5TI
M.PH@("`@("`@("1T97AT(#T@)&U;,ET["@H@("`@("`@(&EF("@D=&AI<RT^
M7VYE>'0H*2D@>PH@("`@("`@("`@("`D<F4@/2`G+UXH/SH@>R<@+B`D;&5V
M96P@+B`G?2@N*C\I?"@I*5QS*B0O)SL*("`@("`@("`@("`@=VAI;&4@*'!R
M96=?;6%T8V@H)')E+"`D=&AI<RT^7VQI;F5"=69F97);,%TL("1M*2D@>PH@
M("`@("`@("`@("`@("`@)'1E>'0@+CT@(EQN(B`N("1M6S%=.PH@("`@("`@
M("`@("`@("`@:68@*"$D=&AI<RT^7VYE>'0H*2D@>PH@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`D;"`]("8D=&AI<RT^7VUA:V5.;V1E*"1T
M:&ES+3Y?8W5R<F5N=$YO9&4L("=,:71E<F%L+4)L;V-K)RP@87)R87DH*2D[
M"B`@("`@("`@)&PM/F%P<&5N9$-H:6QD*'!R96=?<F5P;&%C92@G+UQS*R0O
M<R<L("<G+"`D=&5X="DI.PH*("`@("`@("`O+R!86%@Z($1I<G1Y(&AA8VLA
M"B`@("`@("`@87)R87E?=6YS:&EF="@D=&AI<RT^7VQI;F5"=69F97(L("<G
M*3L*("`@('T*"B`@("`O+RTM+2T*("`@("\O($QI;F4M<F5A9&EN9R!M96UB
M97)S"B`@("`O+RTM+2T*"B`@("`O*BH*("`@("`J(%1H92!R96UA:6YD97(@
M;V8@=&AE('1E>'0@=V4@87)E('!A<G-I;F<L(&)E:6YG(&UO9&EF:65D(&)Y
M(%]G971,:6YE*"D*("`@("`J(&%N9"!?;F5X="@I+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1?=&5X=#L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F('1H
M92!L:6YE<R!W92!H879E('!E96ME9"!A="X*("`@("`J"B`@("`@*B!4:&4@
M9FER<W0@96QE;65N="!I<R!T:&4@;&EN92!W92!A<F4@8W5R<F5N=&QY('=O
M<FMI;F<@=VET:"!A;F0@<V\@;VXN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7VQI
M;F5"=69F97(@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@4F5T<FEE=F5S
M('1H92!N97AT(&QI;F4@9G)O;2!A(&)L;V-K(&]F('1E>'0N"B`@("`@*@H@
M("`@("H@5V4@<F5P;&%C92!T86)S('=I=&@@."!S<&%C97,N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G
M971,:6YE*"D*("`@('L*("`@("`@("!I9B`H<W1R;&5N*"1T:&ES+3Y?=&5X
M="D@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]
M"B`@("`@("`@)&D@/2!S=')P;W,H)'1H:7,M/E]T97AT+"`B7&XB*3L*("`@
M("`@("!I9B`H)&D@(3T](&9A;'-E*2!["B`@("`@("`@("`@("1L:6YE(#T@
M<W5B<W1R*"1T:&ES+3Y?=&5X="P@,"P@)&DI.PH@("`@("`@("`@("`D=&AI
M<RT^7W1E>'0@/2!S=6)S='(H)'1H:7,M/E]T97AT+"`D:2`K(#$I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1L:6YE(#T@)'1H:7,M/E]T97AT
M.PH@("`@("`@("`@("`D=&AI<RT^7W1E>'0@/2`G)SL*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N('!R96=?<F5P;&%C92@G+UQT+R<L("<@("`@("`@("<L
M("1L:6YE*3L*("`@('T*"B`@("`O*BH*("`@("`J($)U;7!S('1O('1H92!N
M97AT(&QI;F4@:6X@=&AE(&EN<'5T+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?;F5X="@I"B`@("!["B`@
M("`@("`@+R\@4W!E8VEA;"!C87-E('1H92!F:7)S="!T:6UE("=R;W5N9"X*
M("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]L:6YE0G5F9F5R*2`]/2`P*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V5N<W5R94QI;F5S*#$I.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"$D=&AI<RT^7V5N<W5R94QI;F5S*#(I
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@
M("`@87)R87E?<VAI9G0H)'1H:7,M/E]L:6YE0G5F9F5R*3L*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($UA:V5S('-U<F4@
M=&AE<F4@:7,@82!C97)T86EN(&YU;6)E<B!O9B!L:6YE<R!A="!M:6YI;75M
M(&EN('1H92!L:6YE"B`@("`@*B!B=69F97(N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O
M=6YT("!4:&ES(&ES('1H92!N=6UB97(@;V8@;&EN97,@=VAI8V@@;75S="!B
M92!I;B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@8G5F9F5R
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N
M;W0@=V4@<W5C8V5E9&5D+B`@5V4@8V%N(&9A:6P@870*("`@("`J("`@("`@
M("`@("`@("`@("`@96YD+6]F+69I;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]E;G-U<F5,:6YE<R@D8V]U;G0@/2`Q*0H@("`@>PH@("`@("`@('=H:6QE
M("AC;W5N="@D=&AI<RT^7VQI;F5"=69F97(I(#P@)&-O=6YT*2!["B`@("`@
M("`@("`@("1L:6YE(#T@)'1H:7,M/E]G971,:6YE*"D["B`@("`@("`@("`@
M(&EF("AI<U]N=6QL*"1L:6YE*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?;&EN
M94)U9F9E<EM=(#T@)&QI;F4["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\O+2TM+0H@("`@+R\@06YO;GEM;W5S(')E9F5R
M96YC97,@86YD(&1E9FEN:71I;VYS"B`@("`O+RTM+2T*"B`@("!V87(@)%]A
M;F]N>6UO=7-2969E<F5N8V5S(#T@87)R87DH*3L*("`@('9A<B`D7V%N;VYY
M;6]U<T1E9FEN:71I;VYS(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%-I
M;F-E(&%N;VYY;6]U<R!R969E<F5N8V5S(&%N9"!D969I;FET:6]N<R`H92YG
M+B!F;V]T;F]T97,L(&QI;FMS*2!D;PH@("`@("H@;F]T(&YE960@=&\@8F4@
M9&5F:6YE9"`B:6X@;&]C:W-T97`B(&%C8V]R9&EN9R!T;R!T:&4@<W!E8RP@
M=V4@8W)E871E"B`@("`@*B!T:&4@<&%R=&EA;"!P87)S92!N;V1E(&EN(&)O
M=&@@<&QA8V5S(&%N9"!U<V4@=&AI<R!N:69T>2!S>7-T96T@=&\*("`@("`J
M('%U975E(&]R(&UE<F=E(&EN(&5A8V@@<&QA8V4N("!.;W1E('1H870@=&AE
M(')E9F5R96YC92!I<R!T:&4@(FUA<W1E<B(*("`@("`J(&YO9&4N("!4:&4@
M9&5F:6YI=&EO;B!G971S('1H<F]W;B!A=V%Y('-I;F-E(&ET(')E86QL>2!I
M<VXG="!I;B!T:&4*("`@("`J('!A<G-E('1R964@86YY=V%Y+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!O
M8FIE8W0@)B1N;V1E("!4:&4@;F]D92!T;R!Q=65U92!O<B!M97)G92!T;RX*
M("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@("!4:&4@='EP92!O9B!A;F]N
M>6UO=7,@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<75E=65!;F]N
M>6UO=7-2969E<F5N8V4H)B1N;V1E+"`D='EP92D*("`@('L*("`@("`@("!I
M9B`H(6%R<F%Y7VME>5]E>&ES=',H)'1Y<&4L("1T:&ES+3Y?86YO;GEM;W5S
M1&5F:6YI=&EO;G,I*2!["B`@("`@("`@("`@("1T:&ES+3Y?86YO;GEM;W5S
M1&5F:6YI=&EO;G-;)'1Y<&5=(#T@87)R87DH*3L*("`@("`@("!]"B`@("`@
M("`@:68@*&-O=6YT*"1T:&ES+3Y?86YO;GEM;W5S1&5F:6YI=&EO;G-;)'1Y
M<&5=*2`^(#`I('L*("`@("`@("`@("`@)&1E9FX@/2`F)'1H:7,M/E]A;F]N
M>6UO=7-$969I;FET:6]N<ULD='EP95U;,%T["B`@("`@("`@("`@(&%R<F%Y
M7W-H:69T*"1T:&ES+3Y?86YO;GEM;W5S1&5F:6YI=&EO;G-;)'1Y<&5=*3L*
M("`@("`@("`@("`@)'1H:7,M/E]M97)G94YO9&50<F]P97)T:65S*"1N;V1E
M+"`D9&5F;BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M
M/E]A;F]N>6UO=7-2969E<F5N8V5S6R1T>7!E75M=(#T@)B1N;V1E.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($AA;F1L97,@86X@86YO;GEM
M;W5S(&1E9FEN:71I;VXN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`F)&YO9&4@(%1H92!N;V1E
M('1O('%U975E(&]R(&UE<F=E(&9R;VTN"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T>7!E("`@5&AE('1Y<&4@;V8@86YO;GEM;W5S(&]B:F5C="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W%U975E06YO;GEM;W5S1&5F:6YI=&EO;B@F)&YO
M9&4L("1T>7!E*0H@("`@>PH@("`@("`@(&EF("@A87)R87E?:V5Y7V5X:7-T
M<R@D='EP92P@)'1H:7,M/E]A;F]N>6UO=7-2969E<F5N8V5S*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7V%N;VYY;6]U<U)E9F5R96YC97-;)'1Y<&5=(#T@
M87)R87DH*3L*("`@("`@("!]"B`@("`@("`@:68@*&-O=6YT*"1T:&ES+3Y?
M86YO;GEM;W5S4F5F97)E;F-E<ULD='EP95TI(#X@,"D@>PH@("`@("`@("`@
M("`D<F5F(#T@)B1T:&ES+3Y?86YO;GEM;W5S4F5F97)E;F-E<ULD='EP95U;
M,%T["B`@("`@("`@("`@(&%R<F%Y7W-H:69T*"1T:&ES+3Y?86YO;GEM;W5S
M4F5F97)E;F-E<ULD='EP95TI.PH@("`@("`@("`@("`D=&AI<RT^7VUE<F=E
M3F]D95!R;W!E<G1I97,H)')E9BP@)&YO9&4I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1T:&ES+3Y?86YO;GEM;W5S1&5F:6YI=&EO;G-;)'1Y
M<&5=6UT@/2`F)&YO9&4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@365R9V5S('1H92!P<F]P97)T:65S(&9R;VT@96%C:"!N;V1E(&EN=&\@
M=&AE(&]T:&5R(&YO9&4N"B`@("`@*@H@("`@("H@5&AE(&YO9&4@='EP92!I
M<R!N;W0@8VAA;F=E9"`H9F]R('1H92!C87-E('=H97)E('=E(&AA=F4@82!F
M;V]T;F]T90H@("`@("H@<F5F97)E;F-E(&%N9"!A(&9O;W1N;W1E(&1E9FEN
M:71I;VXI+"!B=70@8F]T:"!N;V1E<R!W:6QL(&AA=F4@86QL"B`@("`@*B!P
M<F]P97)T:65S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!P87)A;2!O8FIE8W0@)B1N;V1E("!4:&4@<F5F97)E;F-E
M(&YO9&4N"B`@("`@*B!`<&%R86T@;V)J96-T("8D9&5F;B`@5&AE(&1E9FEN
M:71I;VX@;F]D92X*("`@("`J+PH@("`@9G5N8W1I;VX@7VUE<F=E3F]D95!R
M;W!E<G1I97,H)B1N;V1E+"`F)&1E9FXI"B`@("!["B`@("`@("`@+R\@6%A8
M.B!792!S:&]U;&0@;6%K92!S=7)E('1H97)E(&ES(&YO(&-O;&QI<VEO;BX*
M("`@("`@("!F;W)E86-H("@D9&5F;BT^7W!R;W!E<G1I97,@87,@)&YA;64@
M/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1N;V1E+3YS9710<F]P97)T>2@D
M;F%M92P@)'9A;'5E*3L*("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H)&YO
M9&4M/E]P<F]P97)T:65S(&%S("1N86UE(#T^("1V86QU92D@>PH@("`@("`@
M("`@("`D9&5F;BT^<V5T4')O<&5R='DH)&YA;64L("1V86QU92D["B`@("`@
M("`@?0H@("`@?0H*("`@("\O+2TM+0H@("`@+R\@3F%M960@<F5F97)E;F-E
M<R!A;F0@9&5F:6YI=&EO;G,*("`@("\O+2TM+0H*("`@('9A<B`D7VYA;65D
M4F5F97)E;F-E<R`](&%R<F%Y*"D["B`@("!V87(@)%]N86UE9$1E9FEN:71I
M;VYS(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%-T;W)E<R!A(&YA;65D
M(')E9F5R96YC92!P87)S92!N;V1E(&EN(&$@:&%S:"!S;R!W92!C86X@;&%T
M97(@;65R9V4*("`@("`J('!R;W!E<G1I97,@=VET:"!A(&1E9FEN:71I;VXN
M("!)9B!W92!A;')E861Y(&AA=F4@82!D969I;FET:6]N+"!D;PH@("`@("H@
M=&AE(&UE<F=E(&YO=RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<&%R86T@5&5X=%]R95-4("8D;F]D92`@5&AE('!A
M<G-E('1R964@;F]D92X*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@("`@
M("!4:&4@='EP92!O9B!N86UE9"!R969E<F5N8V4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!W92!S=6-C97-S9G5L
M;'D@861D960@=&AE(')E9F5R96YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7W!U=$YA;65D4F5F97)E;F-E*"8D;F]D92P@)'1Y<&4I"B`@("!["B`@("`@
M("`@)&YA;64@/2`D;F]D92T^9V5T4')O<&5R='DH)VYA;64G*3L*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]N86UE9%)E9F5R96YC97-;)'1Y<&5=6R1N
M86UE72DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M("`@("`@("`D=&AI<RT^7VYA;65D4F5F97)E;F-E<ULD='EP95U;)&YA;65=
M(#T@)B1N;V1E.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VYA;65D1&5F
M:6YI=&EO;G-;)'1Y<&5=6R1N86UE72DI('L*("`@("`@("`@("`@)&1E9FX@
M/2`F)'1H:7,M/E]N86UE9$1E9FEN:71I;VYS6R1T>7!E75LD;F%M95T["B`@
M("`@("`@("`@("1T:&ES+3Y?;65R9V5.;V1E4')O<&5R=&EE<R@D;F]D92P@
M)&1E9FXI.PH@("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%1H92!I;G9E<G-E(&]F('M`;&EN:R!?<'5T3F%M
M9612969E<F5N8V4H*7TN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P=71.86UE9$1E9FEN:71I;VXH)B1N
M;V1E+"`D='EP92D*("`@('L*("`@("`@("`D;F%M92`]("1N;V1E+3YG9710
M<F]P97)T>2@G;F%M92<I.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VYA
M;65D1&5F:6YI=&EO;G-;)'1Y<&5=6R1N86UE72DI('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7VYA;65D
M1&5F:6YI=&EO;G-;)'1Y<&5=6R1N86UE72`]("8D;F]D93L*("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]N86UE9%)E9F5R96YC97-;)'1Y<&5=6R1N86UE
M72DI('L*("`@("`@("`@("`@)')E9B`]("8D=&AI<RT^7VYA;65D4F5F97)E
M;F-E<ULD='EP95U;)&YA;65=.PH@("`@("`@("`@("`D=&AI<RT^7VUE<F=E
M3F]D95!R;W!E<G1I97,H)')E9BP@)&YO9&4I.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O+RTM+2T*("`@("\O(%-T871E
M('-T86-K(&UA;F%G96UE;G0*("`@("\O+2TM+0H*("`@("\J*@H@("`@("H@
M5&AE('-T871E('-T86-K+@H@("`@("H*("`@("`J($ET(&ES('5S960@=&\@
M:V5E<"!T<F%C:R!O9B!N97-T960@8F]D>2UL979E;"!E;&5M96YT<R!A;F0@
M:&]W('1H97D*("`@("`J(&UI9VAT(&5N9"X*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W-T871E4W1A8VL@/2!A<G)A>2@I
M.PH*("`@('9A<B`D7V-U<G)E;G1.;V1E.PH*("`@(&9U;F-T:6]N(%]P=7-H
M4W1A=&4H)B1N;V1E+"`D<W1A=&54>7!E+"`D;&5V96PI"B`@("!["B`@("`@
M("`@)'-T871E(#T@)FYE=R!497AT7W)E4U1?4&%R<V5R7W-T871E*"1N;V1E
M+"`D<W1A=&54>7!E+"`D;&5V96PI.PH@("`@("`@("1T:&ES+3Y?<W1A=&53
M=&%C:UM=(#T@)B1S=&%T93L*("`@("`@("`D=&AI<RT^7V-U<G)E;G1.;V1E
M(#T@)B1N;V1E.PH@("`@?0H*("`@(&9U;F-T:6]N(%]G9713=&%T94QE=F5L
M*"1S=&%T951Y<&4I"B`@("!["B`@("`@("`@9F]R("@D:2`](&-O=6YT*"1T
M:&ES+3Y?<W1A=&53=&%C:RD@+2`Q.R`D:2`^/2`P.R`D:2TM*2!["B`@("`@
M("`@("`@(&EF("@D=&AI<RT^7W-T871E4W1A8VM;)&E=+3YS=&%T951Y<&4@
M/3T@)'-T871E5'EP92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<W1A=&53=&%C:ULD:5TM/FQE=F5L.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`P.PH@("`@?0H*("`@(&9U;F-T:6]N(%]P
M;W!4;TQE=F5L*"1S=&%T951Y<&4L("1L979E;"D*("`@('L*("`@("`@("!W
M:&EL92`H)'1H:7,M/E]G9713=&%T94QE=F5L*"1S=&%T951Y<&4I(#X@)&QE
M=F5L*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&]P*"D["B`@("`@("`@?0H@
M("`@?0H*("`@(&9U;F-T:6]N(%]P;W`H*0H@("`@>PH@("`@("`@(&%R<F%Y
M7W!O<"@D=&AI<RT^7W-T871E4W1A8VLI.PH@("`@("`@(&EF("AC;W5N="@D
M=&AI<RT^7W-T871E4W1A8VLI*2!["B`@("`@("`@("`@("1S=&%T92`]("8D
M=&AI<RT^7W-T871E4W1A8VM;8V]U;G0H)'1H:7,M/E]S=&%T95-T86-K*2`M
M(#%=.PH@("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G1.;V1E(#T@)B1S=&%T
M92T^;F]D93L*("`@("`@("!]"B`@("!]"@I]"@HO*BH*("H@5&AI<R!C;&%S
M<R!R97!R97-E;G1S(&$@;F]D92!O;B!T:&4@<&%R<V5R)W,@<W1A=&4@<W1A
M8VLN"B`J"B`J($!P86-K86=E(%1E>'1?<F535`H@*B\*8VQA<W,@5&5X=%]R
M95-47U!A<G-E<E]S=&%T92!["@H@("`@=F%R("1N;V1E.PH@("`@=F%R("1S
M=&%T951Y<&4["B`@("!V87(@)&QE=F5L.PH*("`@("\J*@H@("`@("H@0V]N
M<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`F)&YO9&4@
M("`@("!4:&ES(&ES('1H92!P87)S92!N;V1E(&%S<V]C:6%T960@=VET:"!T
M:&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@('-T871E+B`@
M0FQO8VLM;&5V96P@96QE;65N=',@<&%R<V5D(&EN('1H:7,*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@<W1A=&4@=VEL;"!B92!C:&EL9')E
M;B!O9B!T:&ES(&YO9&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=&%T951Y
M<&4@($-U<G)E;G1L>2!O;FQY("=396-T:6]N)RX*("`@("`J($!P87)A;2!M
M:7AE9"`D;&5V96P@("`@("`@5&AI<R!I<R!T:&4@;F5S=&EN9R!L979E;"!O
M9B!T:&ES('-T871E('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%1E>'1?
M<F535%]087)S97)?<W1A=&4H)B1N;V1E+"`D<W1A=&54>7!E+"`D;&5V96PI
M"B`@("!["B`@("`@("`@)'1H:7,M/FYO9&4@/2`F)&YO9&4["B`@("`@("`@
M)'1H:7,M/G-T871E5'EP92`]("1S=&%T951Y<&4["B`@("`@("`@)'1H:7,M
M/FQE=F5L(#T@)&QE=F5L.PH@("`@?0H*?0H`````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U1E
M>'0O<F535"YP:'``````````````````````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-S$W,@`Q,#4Q-30S,S<T-0`P,C`W-#8`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M92!497AT7W)E4U0Z.B!C;&%S<R!R97!R97-E;G1S(&$@<&%R<V4@;F]D92!O
M9B!A(')E4W1R=6-T=7)E9%1E>'0*("H@9&]C=6UE;G0@86YD('!R;W9I9&5S
M(&%N($%022!F;W(@<&%R<VEN9R!R95-T<G5C='5R961497AT(&1O8W5M96YT
M<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]R95-4+W)E4U0N<&AP
M+'8@,2XU+C$P+C<@,C`P-B\P,2\P,2`R,3HR.#HS."!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*87-O;B!-+B!&96QI8V4@/&IF96QI
M8V5`8W)O;F]S>7,N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R;VYO<WES+F-O;3X*("H@0'!A
M8VMA9V4@5&5X=%]R95-4"B`J+PIC;&%S<R!497AT7W)E4U0@>PH*("`@("\J
M*@H@("`@("H@5&AE('!A<G-E(&YO9&4@='EP92X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D7W1Y<&4["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!T:&4@
M<&%R<V4@;F]D92=S(&-H:6QD<F5N+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?
M8VAI;&1R96X@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@02!H87-H(&]F
M('!A<G-E(&YO9&4@<')O<&5R=&EE<RX*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M<')O<&5R=&EE<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U
M8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("!4:&ES
M(&ES('1H92!N;V1E('1Y<&4N("!4:&4@9&5F875L="!I<R`G1&]C=6UE;G0G
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!497AT7W)E4U0H)'1Y<&4@/2`G1&]C
M=6UE;G0G*0H@("`@>PH@("`@("`@("1T:&ES+3Y?='EP92`]("1T>7!E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@07!P96YD<R!A(&-H:6QD('!A<G-E(&YO
M9&4@=&\@=&AI<R!P87)S92!N;V1E+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F=\5&5X=%]R95-4("8D8VAI;&0@(%1H:7,@:7,@=&AE('-T<FEN9R!O
M<B!O8FIE8W0@8VAI;&0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('1O(&%P<&5N9"!T;R!T:&ES('!A<G-E(&YO9&4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%P<&5N9$-H:6QD*"8D8VAI;&0I"B`@("!["B`@
M("`@("`@)&X@/2!C;W5N="@D=&AI<RT^7V-H:6QD<F5N*3L*("`@("`@("!I
M9B`H:7-?<W1R:6YG*"1C:&EL9"D@)B8@)&X@/B`P("8F(&ES7W-T<FEN9R@D
M=&AI<RT^7V-H:6QD<F5N6R1N("T@,5TI*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?8VAI;&1R96Y;)&X@+2`Q72`N/2`D8VAI;&0["B`@("`@("`@?2!E;'-E
M:68@*&ES7W-T<FEN9R@D8VAI;&0I*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M8VAI;&1R96Y;72`]("1C:&EL9#L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=&AI<RT^7V-H:6QD<F5N6UT@/2`F)&-H:6QD.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE('9A;'5E(&]F(&$@<&%R
M<V4@;F]D92!P<F]P97)T>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("`@5&AE('!R;W!E<G1Y)W,@;F%M92X*("`@("`J($!P87)A;2!S
M=')I;F<@)'9A;'5E("!4:&4@<')O<&5R='DG<R!V86QU92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5T4')O<&5R='DH)&YA;64L("1V86QU92D*("`@('L*
M("`@("`@("`D=&AI<RT^7W!R;W!E<G1I97-;)&YA;65=(#T@)'9A;'5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S('1H92!V86QU92!O9B!A
M('!A<G-E(&YO9&4@<')O<&5R='DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;F%M92`@5&AE('!R;W!E<G1Y)W,@;F%M92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE('!R;W!E<G1Y)W,@=F%L=64N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%!R;W!E<G1Y*"1N86UE*0H@("`@>PH@("`@
M("`@(&EF("@A87)R87E?:V5Y7V5X:7-T<R@D;F%M92P@)'1H:7,M/E]P<F]P
M97)T:65S*2D@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<')O<&5R=&EE<ULD;F%M95T["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!$=6UP<R!T:&ES('!A<G-E(&YO9&4@86YD
M(&ET<R!C:&EL9')E;BX*("`@("`J(%1H:7,@;65T:&]D(&ES(&9O<B!D96)U
M9V=I;F<@<'5R<&]S97,N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&QE=F5L("!4:&ES(&ES('1H92!I;F1E;G0@;&5V96P@;V8@=&AI<R!P87)S
M92!N;V1E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D=6UP*"1L979E;"`](#`I
M"B`@("!["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&QE=F5L.R`D:2LK
M*2!["B`@("`@("`@("`@(&5C:&\@)R`@)SL*("`@("`@("!]"B`@("`@("`@
M96-H;R`D=&AI<RT^7W1Y<&4L("<Z.B<["B`@("`@("`@:W-O<G0H)'1H:7,M
M/E]P<F]P97)T:65S*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!R;W!E
M<G1I97,@87,@)&YA;64@/3X@)'9A;'5E*2!["B`@("`@("`@("`@(&5C:&\@
M)R`G+"`D;F%M92P@)STB)RP@<')E9U]R97!L86-E*"<O6R)<7%Q<72\G+"`G
M7%PD,2<L("1V86QU92DL"B`@("`@("`@("`@("`@("`G(B<["B`@("`@("`@
M?0H@("`@("`@(&5C:&\@(EQN(CL*("`@("`@("!F;W)E86-H("@D=&AI<RT^
M7V-H:6QD<F5N(&%S("1C:&EL9"D@>PH@("`@("`@("`@("!I9B`H:7-?<W1R
M:6YG*"1C:&EL9"DI('L*("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\("@D;&5V96P@*R`Q*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@
M(&5C:&\@)R`@)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&5C:&\@)R(G+"!P<F5G7W)E<&QA8V4H)R];(EQ<7%Q=+R<L("=<7"0Q)RP@
M)&-H:6QD*2P@(EPB7&XB.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)&-H:6QD+3YD=6UP*"1L979E;"`K(#$I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4&%R<V5S(&$@
M<F53=')U8W1U<F5D5&5X="!D;V-U;65N="X*("`@("`J"B`@("`@*B!`<W1A
M=&EC"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AI<R!I
M<R!T:&4@=&5X="!O9B!T:&4@9&]C=6UE;G0@=V4@=V%N="!T;R!P87)S92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(%1E>'1?<F535"`@5&AE('!A<G-E9"!D
M;V-U;65N="!O<B!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9P87)S92@D=&5X="D*("`@('L*("`@("`@("!R97%U:7)E
M7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+W)E4U0O4&%R<V5R+G!H<"<[
M"B`@("`@("`@)'!A<G-E<B`]("9N97<@5&5X=%]R95-47U!A<G-E<B@I.PH@
M("`@("`@(')E='5R;B`D<&%R<V5R+3YP87)S92@D=&5X="D["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+W9E<G-I;VXN<&AP````````````````````````
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`U,@`Q,#4Q-30S,S<U,@`P
M,C`V,38`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`@9&5F:6YE*"=(3U)$15]615)324].)RP@)S,N,2XS)RD@/SX*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B]61E,O````````````````````````````````````````````````
M````````````````````````````````````````,#`P,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-#4`,#$W,#8S`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+U9&4R]"<F]W<V5R+G!H<```````````
M````````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C8S-@`Q,#4Q-30S
M,S<T-0`P,C$R,C8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J($-L87-S(&9O<B!P<F]V:61I;F<@82!G
M96YE<FEC(%5)(&9O<B!A;GD@5D93(&EN<W1A;F-E+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]61E,O5D93+T)R;W=S97(N<&AP+'8@,2XX+C$P+CD@,C`P
M-B\P-2\S,2`P-#HU,#HP,B!S;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@5D93"B`J+PIC;&%S<R!6
M1E-?0G)O=W-E<B!["@H@("`@+RHJ"B`@("`@*B!4:&4@5D93(&EN<W1A;F-E
M('1H870@=V4@87)E(&)R;W=S:6YG+@H@("`@("H*("`@("`J($!V87(@5D93
M"B`@("`@*B\*("`@('9A<B`D7W9F<SL*"B`@("`O*BH*("`@("`J(%1H92!D
M:7)E8W1O<GD@=VAE<F4@=&AE('1E;7!L871E<R!T;R!U<V4@87)E+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W1E;7!L
M871E<SL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*@H@("`@
M("H@0'!A<F%M(%9&4R`F)'9F<R`@("`@("`@("!!(%9&4R!O8FIE8W0N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1T96UP;&%T97,@(%1/1$\*("`@("`J+PH@
M("`@9G5N8W1I;VX@5D937T)R;W=S97(H)B1V9G,L("1T96UP;&%T97,I"B`@
M("!["B`@("`@("`@:68@*&ES<V5T*"1V9G,I*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?=F9S(#T@)'9F<SL*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]T
M96UP;&%T97,@/2`D=&5M<&QA=&5S.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4V5T('1H92!61E,@;V)J96-T(&EN('1H92!L;V-A;"!O8FIE8W0N"B`@("`@
M*@H@("`@("H@0'!A<F%M(%9&4R`F)'9F<R`@02!61E,@;V)J96-T+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S97161E-/8FIE8W0H)B1V9G,I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]V9G,@/2`F)'9F<SL*("`@('T*"B`@("`O*BH*("`@
M("`J(%1/1$\*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@
M("`@(%1/1$\*("`@("`J($!P87)A;2!B;V]L96%N("1D;W1F:6QE<R`@5$]$
M3PH@("`@("H@0'!A<F%M(&)O;VQE86X@)&1I<F]N;'D@("!43T1/"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%5)*"1P871H+"`D9&]T9FEL97,@/2!F86QS
M92P@)&1I<F]N;'D@/2!F86QS92D*("`@('L*("`@("`@("`D=&AI<RT^7W9F
M<RT^;&ES=$9O;&1E<B@D<&%T:"P@)&1O=&9I;&5S+"`D9&ER;VYL>2D["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M5D93+V9I;&4N<&AP````````````````````````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#4U-#`Q`#$P-3$U-#,S-S0U`#`R,#4R,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M5D93(&EM<&QE;65N=&%T:6]N(&9O<B!A('-T86YD87)D(&9I;&5S>7-T96TN
M"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z/'!R93X*("H@("`G=F9S<F]O
M="<@(%1H92!R;V]T('!A=&@\+W!R93X*("H*("H@3F]T93H@5&AE('5S97(@
M=&AA="!Y;W5R('=E8G-E<G9E<B!R=6YS(&%S("AC;VUM;VYL>2`G;F]B;V1Y
M)RP*("H@)V%P86-H92<L(&]R("=W=W<M9&%T82<I($U54U0@:&%V92!R96%D
M+W=R:71E('!E<FUI<W-I;VX@=&\@=&AE"B`J(&1I<F5C=&]R>2!Y;W4@<W!E
M8VEF>2!A<R!T:&4@)W9F<W)O;W0G+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP+'8@,2XV,RXT+C(Q(#(P,#8O,#4O,S$@,#0Z
M-3`Z,#(@<VQU<V%R>B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H"B`J($!P86-K86=E
M(%9&4PH@*B\*8VQA<W,@5D937V9I;&4@97AT96YD<R!61E,@>PH*("`@("\J
M*@H@("`@("H@3&ES="!O9B!P97)M:7-S:6]N<R!A;F0@:68@=&AE>2!C86X@
M8F4@8VAA;F=E9"!I;B!T:&ES(%9&4PH@("`@("H@8F%C:V5N9"X*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!E<FUI<W-I
M;VYS(#T@87)R87DH"B`@("`@("`@)V]W;F5R)R`]/B!A<G)A>2@G<F5A9"<@
M/3X@=')U92P@)W=R:71E)R`]/B!T<G5E+"`G97AE8W5T92<@/3X@=')U92DL
M"B`@("`@("`@)V=R;W5P)R`]/B!A<G)A>2@G<F5A9"<@/3X@=')U92P@)W=R
M:71E)R`]/B!T<G5E+"`G97AE8W5T92<@/3X@=')U92DL"B`@("`@("`@)V%L
M;"<@("`]/B!A<G)A>2@G<F5A9"<@/3X@=')U92P@)W=R:71E)R`]/B!T<G5E
M+"`G97AE8W5T92<@/3X@=')U92D*("`@("D["@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1S(&$@;F5W($9I;&5S>7-T96T@8F%S960@5D93(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O
M;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!61E-?9FEL92@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@
M("`@("!P87)E;G0Z.E9&4R@D<&%R86US*3L*"B`@("`@("`@:68@*"%E;7!T
M>2@D=&AI<RT^7W!A<F%M<ULG=F9S<F]O="==*2D@>PH@("`@("`@("`@("!I
M9B`H<W5B<W1R*"1T:&ES+3Y?<&%R86US6R=V9G-R;V]T)UTL("TQ*2`]/2`G
M+R<@?'P*("`@("`@("`@("`@("`@('-U8G-T<B@D=&AI<RT^7W!A<F%M<ULG
M=F9S<F]O="==+"`M,2D@/3T@)UQ<)RD@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)W9F<W)O;W0G72`]('-U8G-T<B@D=&AI<RT^7W!A<F%M
M<ULG=F9S<F]O="==+"`P+"!S=')L96XH)'1H:7,M/E]P87)A;7-;)W9F<W)O
M;W0G72D@+2`Q*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E=')I979E<R!T:&4@9FEL97-I>F4@9G)O;2!T:&4@
M5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P
M871H;F%M92!T;R!T:&4@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA
M;64@(%1H92!F:6QE;F%M92!T;R!R971R:65V92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&EN=&5G97(@5&AE(&9I;&4@<VEZ92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<VEZ92@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@)'-I>F4@
M/2!`9FEL97-I>F4H)'1H:7,M/E]G971.871I=F50871H*"1P871H+"`D;F%M
M92DI.PH@("`@("`@(&EF("@D<VEZ92`]/3T@9F%L<V4I('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@
M=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB*2P@)'!A=&@L("1N
M86UE*2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<VEZ93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E=')I979E(&$@9FEL92!F<F]M('1H92!61E,N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&AN
M86UE('1O('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@
M5&AE(&9I;&5N86UE('1O(')E=')I979E+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@9FEL92!D871A+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!R96%D*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("`D9FEL92`]("1T
M:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I.PH@("`@("`@(&EF
M("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L*("`@
M("`@("`@("`@)&1A=&$@/2!F:6QE7V=E=%]C;VYT96YT<R@D9FEL92D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&9P(#T@0&9O<&5N*"1F:6QE
M+"`G<F(G*3L*("`@("`@("`@("`@:68@*"$D9G`I('L*("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE+B(I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D9FEL
M97-I>F4@/2!F:6QE<VEZ92@D9FEL92D["B`@("`@("`@("`@(&EF("@D9FEL
M97-I>F4@/3T@,"D@>PH@("`@("`@("`@("`@("`@)&1A=&$@/2`G)SL*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1D871A(#T@9G)E
M860H)&9P+"`D9FEL97-I>F4I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&9C;&]S92@D9G`I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1D871A
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S(&$@<&%R="!O9B!A
M(&9I;&4@9G)O;2!T:&4@5D93+B!087)T:6-U;&%R;'D@=7-E9G5L('=H96X*
M("`@("`J(')E861I;F<@;&%R9V4@9FEL97,@=VAI8V@@=V]U;&0@97AC965D
M('1H92!02%`@;65M;W)Y(&QI;6ET<R!I9B!T:&5Y"B`@("`@*B!W97)E('-T
M;W)E9"!I;B!A('-T<FEN9RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<&%T:"`@("`@("!4:&4@<&%T
M:&YA;64@=&\@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D;F%M
M92`@("`@("!4:&4@9FEL96YA;64@=&\@<F5T<FEE=F4N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D;V9F<V5T("`@("!4:&4@;V9F<V5T(&]F('1H92!P87)T
M+B`H5&AE(&YE=R!O9F9S970@=VEL;`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8F4@<W1O<F5D(&EN(&AE<F4I+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&QE;F=T:"`@("`@5&AE(&QE;F=T:"!O9B!T:&4@<&%R="X@
M268@=&AE(&QE;F=T:"`]("TQ+`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@=&AE('=H;VQE('!A<G0@869T97(@=&AE(&]F9G-E="!I<R!R
M971R:65V960N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!)
M9B!M;W)E(&)Y=&5S(&%R92!G:79E;B!A<R!E>&ES=',@869T97(@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!G:79E;B!O9F9S970N
M($]N;'D@=&AE(&%V86EL86)L92!B>71E<R!A<F4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(')E860N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D<F5M86EN:6YG("!4:&4@8GET97,@=&AA="!A<F4@;&5F="P@869T97(@
M=&AE('!A<G0@=&AA=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:7,@<F5T<FEE=F5D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M(%1H92!F:6QE(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E861">71E
M4F%N9V4H)'!A=&@L("1N86UE+"`F)&]F9G-E="P@)&QE;F=T:"`]("TQ+"`F
M)')E;6%I;FEN9RD*("`@('L*("`@("`@("!I9B`H)&]F9G-E="`\(#`I('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?
M*")7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(I
M+"`D;V9F<V5T*2D["B`@("`@("`@?0H*("`@("`@("`O+R!#86QC=6QA=&4@
M:&]W(&UA;GD@8GET97,@35535"!B92!R96%D+"!S;R!T:&4@<F5M86EN9VEN
M9PH@("`@("`@("\O(&)Y=&5S(&%N9"!T:&4@;F5W(&]F9G-E="!C86X@8F4@
M8V%L8W5L871E9"!C;W)R96-T;'DN"B`@("`@("`@)&9I;&4@/2`D=&AI<RT^
M7V=E=$YA=&EV95!A=&@H)'!A=&@L("1N86UE*3L*("`@("`@("`D<VEZ92`]
M(&9I;&5S:7IE("@D9FEL92D["B`@("`@("`@:68@*"1L96YG=&@@/3T@+3$@
M?'P@*"@D;&5N9W1H("L@)&]F9G-E="D@/B`D<VEZ92DI('L*("`@("`@("`@
M("`@)&QE;F=T:"`]("1S:7IE("T@)&]F9G-E=#L*("`@("`@("!]"B`@("`@
M("`@:68@*"1R96UA:6YI;F<@/"`P*2!["B`@("`@("`@("`@("1R96UA:6YI
M;F<@/2`P.PH@("`@("`@('T*"B`@("`@("`@)&9P(#T@0&9O<&5N*"1F:6QE
M+"`G<F(G*3L*("`@("`@("!I9B`H(21F<"D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92XB*2D["B`@("`@("`@?0H@("`@("`@(&9S965K*"1F<"P@)&]F9G-E="D[
M"B`@("`@("`@)&1A=&$@/2!F<F5A9"@D9G`L("1L96YG=&@I.PH@("`@("`@
M("1O9F9S970@/2!F=&5L;"@D9G`I.PH@("`@("`@("1R96UA:6YI;F<@/2`D
M<VEZ92`M("1O9F9S970["@H@("`@("`@(&9C;&]S92@D9G`I.PH*("`@("`@
M("!R971U<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R92!A
M(&9I;&4@:6X@=&AE(%9&4RP@=VET:"!T:&4@9&%T82!C;W!I960@9G)O;2!A
M('1E;7!O<F%R>0H@("`@("H@9FEL92X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I
M;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@("`@5&AE
M(&9I;&5N86UE('1O('5S92X*("`@("`J($!P87)A;2!S=')I;F<@)'1M<$9I
M;&4@("`@("!4:&4@=&5M<&]R87)Y(&9I;&4@8V]N=&%I;FEN9R!T:&4@9&%T
M82!T;R!B90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T
M;W)E9"X*("`@("`J($!P87)A;2!B;V]L96%N("1A=71O8W)E871E("!!=71O
M;6%T:6-A;&QY(&-R96%T92!D:7)E8W1O<FEE<S\*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET
M92@D<&%T:"P@)&YA;64L("1T;7!&:6QE+"`D875T;V-R96%T92`]('1R=64I
M"B`@("!["B`@("`@("`@:68@*"%`:7-?9&ER*"1T:&ES+3Y?9V5T3F%T:79E
M4&%T:"@D<&%T:"DI*2!["B`@("`@("`@("`@(&EF("@D875T;V-R96%T92D@
M>PH@("`@("`@("`@("`@("`@)')E<R`]("1T:&ES+3YA=71O8W)E871E4&%T
M:"@D<&%T:"D["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R97,[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")61E,@9&ER
M96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(I*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@)')E<R`]("1T:&ES+3Y?8VAE8VM1=6]T85=R:71E
M*"=F:6QE)RP@)'1M<$9I;&4I.PH@("`@("`@(&EF("AI<U]A*"1R97,L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@
M("`@?0H*("`@("`@("`O+R!3:6YC92!W92!A;')E861Y(&AA=F4@=&AE(&1A
M=&$@:6X@82!F:6QE+"!D;VXG="!R96%D(&ET"B`@("`@("`@+R\@:6YT;R!0
M2%`G<R!M96UO<GD@870@86QL("T@:G5S="!C;W!Y*"D@:70@=&\@=&AE(&YE
M=PH@("`@("`@("\O(&QO8V%T:6]N+B!792!L96%V92!I="!T;R!T:&4@8V%L
M;&5R('1O(&-L96%N('5P('1H90H@("`@("`@("\O('1E;7!O<F%R>2!F:6QE
M+"!S;R!W92!D;VXG="!U<V4@<F5N86UE*"DN"B`@("`@("`@:68@*$!C;W!Y
M*"1T;7!&:6QE+"`D=&AI<RT^7V=E=$YA=&EV95!A=&@H)'!A=&@L("1N86UE
M*2DI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB*2D["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@36]V97,@82!F:6QE(&EN
M('1H92!D871A8F%S92!A;F0@=&AE(&9I;&4@<WES=&5M+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H('1O('-T;W)E('1H
M92!F:6QE(&EN+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9I
M;&5N86UE('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!M;W9E*"1P871H+"`D;F%M92P@
M)&1E<W0I"B`@("!["B`@("`@("`@)&]R:6<@/2`D=&AI<RT^7V=E=$YA=&EV
M95!A=&@H)'!A=&@L("1N86UE*3L*("`@("`@("!I9B`H<')E9U]M871C:"@G
M?%XG("X@<')E9U]Q=6]T92@D;W)I9RD@+B`G+S\D?"<L("1D97-T*2D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#86YN;W0@
M;6]V92!F:6QE*',I("T@9&5S=&EN871I;VX@:7,@=VET:&EN('-O=7)C92XB
M*2D["B`@("`@("`@?0H*("`@("`@("`D9FEL94-H96-K(#T@)'1H:7,M/FQI
M<W1&;VQD97(H)&1E<W0L(&9A;'-E*3L*("`@("`@("!F;W)E86-H("@D9FEL
M94-H96-K(&%S("1F:6QE*2!["B`@("`@("`@("`@(&EF("@D9FEL95LG;F%M
M92==(#T]("1N86UE*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB*2D["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A0')E;F%M92@D
M;W)I9RP@)'1H:7,M/E]G971.871I=F50871H*"1D97-T+"`D;F%M92DI*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L
M92!T;R!M;W9E(%9&4R!F:6QE+B(I*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]P:65S(&$@9FEL
M92!T:')O=6=H('1H92!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'!A=&@@(%1H92!P871H('1O('-T;W)E('1H92!F:6QE(&EN+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9I;&5N86UE('1O('5S
M92X*("`@("`J($!P87)A;2!S=')I;F<@)&1E<W0@(%1H92!D97-T:6YA=&EO
M;B!O9B!T:&4@9FEL92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;W!Y*"1P871H+"`D;F%M92P@
M)&1E<W0I"B`@("!["B`@("`@("`@)&]R:6<@/2`D=&AI<RT^7V=E=$YA=&EV
M95!A=&@H)'!A=&@L("1N86UE*3L*("`@("`@("!I9B`H<')E9U]M871C:"@G
M?%XG("X@<')E9U]Q=6]T92@D;W)I9RD@+B`G+S\D?"<L("1D97-T*2D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#86YN;W0@
M8V]P>2!F:6QE*',I("T@<V]U<F-E(&%N9"!D97-T:6YA=&EO;B!A<F4@=&AE
M('-A;64N(BDI.PH@("`@("`@('T*"B`@("`@("`@)&9I;&5#:&5C:R`]("1T
M:&ES+3YL:7-T1F]L9&5R*"1D97-T+"!F86QS92D["B`@("`@("`@9F]R96%C
M:"`H)&9I;&5#:&5C:R!A<R`D9FEL92D@>PH@("`@("`@("`@("!I9B`H)&9I
M;&5;)VYA;64G72`]/2`D;F%M92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N
M(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(4!C
M;W!Y*"1O<FEG+"`D=&AI<RT^7V=E=$YA=&EV95!A=&@H)&1E<W0L("1N86UE
M*2DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(BDI.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R92!A
M(&9I;&4@:6X@=&AE(%9&4R!F<F]M(')A=R!D871A+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@("!4:&4@<&%T:"!T;R!S=&]R
M92!T:&4@9FEL92!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@
M("`@("!4:&4@9FEL96YA;64@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9&%T82`@("`@("`@(%1H92!F:6QE(&1A=&$N"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D875T;V-R96%T92`@075T;VUA=&EC86QL>2!C<F5A=&4@9&ER
M96-T;W)I97,_"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O
M;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&5$871A*"1P871H+"`D;F%M92P@
M)&1A=&$L("1A=71O8W)E871E(#T@=')U92D*("`@('L*("`@("`@("!I9B`H
M(4!I<U]D:7(H)'1H:7,M/E]G971.871I=F50871H*"1P871H*2DI('L*("`@
M("`@("`@("`@:68@*"1A=71O8W)E871E*2!["B`@("`@("`@("`@("`@("`D
M<F5S(#T@)'1H:7,M/F%U=&]C<F5A=&50871H*"1P871H*3L*("`@("`@("`@
M("`@("`@(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*%\H(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI
M<W0N(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!4
M<F5A="!A;B!A='1E;7!T('1O('=R:71E(&%N(&5M<'1Y(&9I;&4@87,@82!T
M;W5C:"@I(&-A;&PL"B`@("`@("`@+R\@<VEN8V4@;W1H97)W:7-E('1H92!F
M:6QE('=I;&P@;F]T(&)E(&-R96%T960@870@86QL+@H@("`@("`@(&EF("@A
M<W1R;&5N*"1D871A*2D@>PH@("`@("`@("`@("!I9B`H0'1O=6-H*"1T:&ES
M+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@
M=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(I*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@)')E<R`]("1T:&ES+3Y?8VAE8VM1=6]T85=R
M:71E*"=S=')I;F<G+"`D9&%T82D["B`@("`@("`@:68@*&ES7V$H)')E<RP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<SL*("`@
M("`@("!]"@H@("`@("`@("\O($]T:&5R=VES92!W92!G;R!A:&5A9"!A;F0@
M=')Y('1O('=R:71E(&]U="!T:&4@9FEL92X*("`@("`@("`D9G`@/2!`9F]P
M96XH)'1H:7,M/E]G971.871I=F50871H*"1P871H+"`D;F%M92DL("=W)RD[
M"B`@("`@("`@:68@*"$D9G`I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R
M:71I;F<N(BDI.PH@("`@("`@('T*"B`@("`@("`@:68@*"%`9G=R:71E*"1F
M<"P@)&1A=&$I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(I*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1&5L971E(&$@9FEL92!F<F]M('1H92!61E,N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@=&\@<W1O<F4@=&AE
M(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@9FEL
M96YA;64@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R
M=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T949I;&4H)'!A=&@L("1N
M86UE*0H@("`@>PH@("`@("`@("1R97,@/2`D=&AI<RT^7V-H96-K475O=&%$
M96QE=&4H)'!A=&@L("1N86UE*3L*("`@("`@("!I9B`H:7-?82@D<F5S+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"%`=6YL:6YK*"1T:&ES+3Y?9V5T3F%T:79E
M4&%T:"@D<&%T:"P@)&YA;64I*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(I
M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1&5L971E(&$@9F]L9&5R(&9R;VT@=&AE(%9&4RX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("!4:&4@<&%T
M:"!T;R!D96QE=&4@=&AE(&9O;&1E<B!F<F]M+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;F%M92`@("`@("`@5&AE(&9O;&1E<FYA;64@=&\@=7-E+@H@("`@
M("H@0'!A<F%M(&)O;VQE86X@)')E8W5R<VEV92`@1F]R8V4@82!R96-U<G-I
M=F4@9&5L971E/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@5')U92!O
M;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E1F]L9&5R*"1P871H+"`D;F%M
M92P@)')E8W5R<VEV92`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@D<F5C
M=7)S:79E*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^96UP='E&
M;VQD97(H)'!A=&@@+B`G+R<@+B`D;F%M92D["B`@("`@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&QI<W0@/2`D=&AI<RT^;&ES=$9O;&1E<B@D<&%T
M:"`N("<O)R`N("1N86UE*3L*("`@("`@("`@("`@:68@*&ES7V$H)&QI<W0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D;&ES
M=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H8V]U;G0H)&QI<W0I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS
M<')I;G1F*%\H(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@
M:7,@;F]T(&5M<'1Y(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P871H("X@)R\G("X@)&YA;64I*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"%`<FUD:7(H)'1H
M:7,M/E]G971.871I=F50871H*"1P871H+"`D;F%M92DI*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2XB*2D["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!F;VQD
M97(@;VX@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P
M871H("!4:&4@<&%T:"!T;R!D96QE=&4@=&AE(&9O;&1E<B!F<F]M+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9O;&1E<FYA;64@=&\@=7-E
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S
M<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&-R96%T949O;&1E<B@D<&%T:"P@)&YA;64I"B`@("![
M"B`@("`@("`@:68@*"%`;6MD:7(H)'1H:7,M/E]G971.871I=F50871H*"1P
M871H+"`D;F%M92DI*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB*2D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J($-H96-K(&EF(&$@9VEV96X@<&%T:&YA;64@:7,@82!F;VQD
M97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A
M=&@@=&\@=&AE(&9O;&1E<BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@
M(%1H92!F:6QE+V9O;&1E<B!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;B`@5')U92!I9B!I="!I<R!A(&9O;&1E<BP@9F%L<V4@;W1H97)W
M:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<T9O;&1E<B@D<&%T:"P@)&YA
M;64I"B`@("!["B`@("`@("`@<F5T=7)N($!I<U]D:7(H)'1H:7,M/E]G971.
M871I=F50871H*"1P871H+"`D;F%M92DI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0VAA;F=E<R!P97)M:7-S:6]N<R!F;W(@86X@:71E;2!I;B!T:&4@5D93
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@("!4
M:&4@<&%T:"!O9B!D:7)E8W1O<GD@;V8@=&AE(&ET96TN"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N86UE("`@("`@("`@5&AE(&YA;64@;V8@=&AE(&ET96TN
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<&5R;6ES<VEO;B`@5&AE(&]C=&%L
M('9A;'5E(&]F('1H92!N97<@<&5R;6ES<VEO;BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C:&%N
M9V5097)M:7-S:6]N<R@D<&%T:"P@)&YA;64L("1P97)M:7-S:6]N*0H@("`@
M>PH@("`@("`@(&EF("@A0&-H;6]D*"1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D
M<&%T:"P@)&YA;64I+"`D<&5R;6ES<VEO;BDI('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@8VAA
M;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(I+"`D<&%T:"P@
M)&YA;64I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@;&ES="!O9B!T:&4@8V]N=&5N
M=',@;V8@82!F;VQD97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<&%T:"`@("`@("!4:&4@<&%T:"!O9B!T:&4@9&ER96-T;W)Y+@H@("`@("H@
M0'!A<F%M(&UI>&5D("1F:6QT97(@("`@("!3=')I;F<O:&%S:"!T;R!F:6QT
M97(@9FEL92]D:7)N86UE(&]N+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&1O
M=&9I;&5S("!3:&]W(&1O=&9I;&5S/PH@("`@("H@0'!A<F%M(&)O;VQE86X@
M)&1I<F]N;'D@("!3:&]W(&]N;'D@9&ER96-T;W)I97,_"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@1FEL92!L:7-T(&]N('-U8V-E<W,L(%!%05)?
M17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]L:7-T1F]L
M9&5R*"1P871H+"`D9FEL=&5R(#T@;G5L;"P@)&1O=&9I;&5S(#T@=')U92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("1D:7)O;FQY(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@)&9I;&5S(#T@87)R87DH*3L*("`@("`@("`D<&%T:"`]
M(&ES<V5T*"1P871H*2`_("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"D@
M.B`D=&AI<RT^7V=E=$YA=&EV95!A=&@H*3L*"B`@("`@("`@:68@*"%`:7-?
M9&ER*"1P871H*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BA?*").;W0@82!D:7)E8W1O<GDB*2D["B`@("`@("`@?0H*("`@("`@
M("!I9B`H(4!C:&1I<B@D<&%T:"DI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T
M;W)Y+B(I*3L*("`@("`@("!]"@H@("`@("`@("1H86YD;&4@/2!O<&5N9&ER
M*"1P871H*3L*("`@("`@("!W:&EL92`H*"1E;G1R>2`](')E861D:7(H)&AA
M;F1L92DI("$]/2!F86QS92D@>PH@("`@("`@("`@("`O+R!&:6QT97(@;W5T
M("<N)R!A;F0@)RXN)R!E;G1R:65S+@H@("`@("`@("`@("!I9B`H)&5N=')Y
M(#T]("<N)R!\?"`D96YT<GD@/3T@)RXN)RD@>PH@("`@("`@("`@("`@("`@
M8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O($9I;'1E
M<B!O=70@9&]T9FEL97,@:68@=&AE>2!A<F5N)W0@=V%N=&5D+@H@("`@("`@
M("`@("!I9B`H(21D;W1F:6QE<R`F)B!S=6)S='(H)&5N=')Y+"`P+"`Q*2`]
M/2`G+B<I('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`O+R!&:6QE(&YA;64*("`@("`@("`@("`@)&9I
M;&5;)VYA;64G72`]("1E;G1R>3L*"B`@("`@("`@("`@("\O(%5N:7@@<W1Y
M;&4@9FEL92!P97)M:7-S:6]N<PH@("`@("`@("`@("`D9FEL95LG<&5R;7,G
M72`]("1T:&ES+3Y?9V5T56YI>%!E<FUS*&9I;&5P97)M<R@D96YT<GDI*3L*
M"B`@("`@("`@("`@("\O($]W;F5R"B`@("`@("`@("`@("1F:6QE6R=O=VYE
M<B==(#T@9FEL96]W;F5R*"1E;G1R>2D["B`@("`@("`@("`@(&EF("AF=6YC
M=&EO;E]E>&ES=',H)W!O<VEX7V=E='!W=6ED)RDI('L*("`@("`@("`@("`@
M("`@("1O=VYE<B`]('!O<VEX7V=E='!W=6ED*"1F:6QE6R=O=VYE<B==*3L*
M("`@("`@("`@("`@("`@("1F:6QE6R=O=VYE<B==(#T@)&]W;F5R6R=N86UE
M)UT["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O($=R;W5P"B`@("`@
M("`@("`@("1F:6QE6R=G<F]U<"==(#T@9FEL96=R;W5P*"1E;G1R>2D["B`@
M("`@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)W!O<VEX7V=E=&=R9VED
M)RDI('L*("`@("`@("`@("`@("`@("1G<F]U<"`]('!O<VEX7V=E=&=R9VED
M*"1F:6QE6R=G<F]U<"==*3L*("`@("`@("`@("`@("`@("1F:6QE6R=G<F]U
M<"==(#T@)&=R;W5P6R=N86UE)UT["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("\O(%-I>F4*("`@("`@("`@("`@)&9I;&5;)W-I>F4G72`](&9I;&5S
M:7IE*"1E;G1R>2D["@H@("`@("`@("`@("`O+R!$871E"B`@("`@("`@("`@
M("1F:6QE6R=D871E)UT@/2!F:6QE;71I;64H)&5N=')Y*3L*"B`@("`@("`@
M("`@("\O(%1Y<&4*("`@("`@("`@("`@:68@*$!I<U]D:7(H)&5N=')Y*2`F
M)B`A:7-?;&EN:R@D96YT<GDI*2!["B`@("`@("`@("`@("`@("`D9FEL95LG
M<&5R;7,G72`]("=D)R`N("1F:6QE6R=P97)M<R==.PH@("`@("`@("`@("`@
M("`@)&9I;&5;)W1Y<&4G72`]("<J*F1I<B<["B`@("`@("`@("`@("`@("`D
M9FEL95LG<VEZ92==(#T@+3$["B`@("`@("`@("`@('T@96QS96EF("AI<U]L
M:6YK*"1E;G1R>2DI('L*("`@("`@("`@("`@("`@("1F:6QE6R=P97)M<R==
M(#T@)VPG("X@)&9I;&5;)W!E<FUS)UT["B`@("`@("`@("`@("`@("`D9FEL
M95LG='EP92==(#T@)RHJ<WEM)SL*("`@("`@("`@("`@("`@("1F:6QE6R=L
M:6YK)UT@/2!R96%D;&EN:R@D96YT<GDI.PH@("`@("`@("`@("`@("`@)&9I
M;&5;)VQI;FMT>7!E)UT@/2`G*BIN;VYE)SL*("`@("`@("`@("`@("`@(&EF
M("AF:6QE7V5X:7-T<R@D9FEL95LG;&EN:R==*2D@>PH@("`@("`@("`@("`@
M("`@("`@(&EF("AI<U]D:7(H)&9I;&5;)VQI;FLG72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&9I;&5;)VQI;FMT>7!E)UT@/2`G*BID:7(G.PH@
M("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI<U]L:6YK*"1F:6QE6R=L
M:6YK)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1F:6QE6R=L:6YK
M='EP92==(#T@)RHJ<WEM)SL*("`@("`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H:7-?9FEL92@D9FEL95LG;&EN:R==*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D97AT(#T@97AP;&]D92@G+B<L("1F:6QE6R=L:6YK)UTI.PH@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H(2AC;W5N="@D97AT*2`]/2`Q
M('Q\("@D97AT6S!=(#T]/2`G)R`F)B!C;W5N="@D97AT*2`]/2`R*2DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F:6QE6R=L:6YK='EP92==
M(#T@5D93.CIS=')T;VQO=V5R*"1E>'1;8V]U;G0H)&5X="D@+2`Q72D["B`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("1F:6QE6R=L:6YK='EP92==(#T@)RHJ8G)O:V5N)SL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?2!E;'-E:68@*&ES7V9I;&4H)&5N=')Y*2D@
M>PH@("`@("`@("`@("`@("`@)&9I;&5;)W!E<FUS)UT@/2`G+2<@+B`D9FEL
M95LG<&5R;7,G73L*("`@("`@("`@("`@("`@("1E>'0@/2!E>'!L;V1E*"<N
M)RP@)&5N=')Y*3L*"B`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)&5X="D@
M/3T@,2!\?"`H<W5B<W1R*"1F:6QE6R=N86UE)UTL(#`L(#$I(#T]/2`G+B<@
M)B8@8V]U;G0H)&5X="D@/3T@,BDI('L*("`@("`@("`@("`@("`@("`@("`D
M9FEL95LG='EP92==(#T@)RHJ;F]N92<["B`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE6R=T>7!E)UT@/2!61E,Z
M.G-T<G1O;&]W97(H)&5X=%MC;W5N="@D97AT*2`M(#%=*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1F:6QE6R=T>7!E)UT@/2`G*BIN;VYE)SL*("`@("`@("`@("`@("`@(&EF
M("@H9FEL97!E<FUS*"1E;G1R>2D@)B`P>$,P,#`I(#T](#!X0S`P,"D@>PH@
M("`@("`@("`@("`@("`@("`@("1F:6QE6R=P97)M<R==(#T@)W,G("X@)&9I
M;&5;)W!E<FUS)UT["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H*&9I;&5P
M97)M<R@D96YT<GDI("8@,'@V,#`P*2`]/2`P>#8P,#`I('L*("`@("`@("`@
M("`@("`@("`@("`D9FEL95LG<&5R;7,G72`]("=B)R`N("1F:6QE6R=P97)M
M<R==.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"AF:6QE<&5R;7,H)&5N
M=')Y*2`F(#!X,C`P,"D@/3T@,'@R,#`P*2!["B`@("`@("`@("`@("`@("`@
M("`@)&9I;&5;)W!E<FUS)UT@/2`G8R<@+B`D9FEL95LG<&5R;7,G73L*("`@
M("`@("`@("`@("`@('T@96QS96EF("@H9FEL97!E<FUS*"1E;G1R>2D@)B`P
M>#$P,#`I(#T](#!X,3`P,"D@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE
M6R=P97)M<R==(#T@)W`G("X@)&9I;&5;)W!E<FUS)UT["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE6R=P97)M
M<R==(#T@)S\G("X@)&9I;&5;)W!E<FUS)UT["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O($9I;'1E<FEN9RX*("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?9FEL=&5R36%T8V@H)&9I;'1E<BP@)&9I
M;&5;)VYA;64G72DI('L*("`@("`@("`@("`@("`@('5N<V5T*"1F:6QE*3L*
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("@D9&ER;VYL>2`F)B`D9FEL95LG='EP92==("$]/2`G*BID
M:7(G*2!["B`@("`@("`@("`@("`@("!U;G-E="@D9FEL92D["B`@("`@("`@
M("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M)&9I;&5S6R1F:6QE6R=N86UE)UU=(#T@)&9I;&4["B`@("`@("`@("`@('5N
M<V5T*"1F:6QE*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9FEL97,[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<V]R=&5D(&QI<W0@
M;V8@9F]L9&5R<R!I;B!S<&5C:69I960@9&ER96-T;W)Y+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@("!4:&4@<&%T:"!O9B!T
M:&4@9&ER96-T;W)Y('1O(&=E="!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!D:7)E8W1O<GD@;&ES="!F;W(N"B`@("`@*B!`<&%R
M86T@;6EX960@)&9I;'1E<B`@("`@("`@2&%S:"!O9B!I=&5M<R!T;R!F:6QT
M97(@8F%S960@;VX@9F]L9&5R;&ES="X*("`@("`J($!P87)A;2!B;V]L96%N
M("1D;W1F;VQD97)S("!);F-L=61E(&1O=&9O;&1E<G,_"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@1F]L9&5R(&QI<W0@;VX@<W5C8V5S<R!O<B!A
M(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&QI<W1&;VQD97)S*"1P871H(#T@)R<L("1F:6QT97(@/2!N=6QL
M+"`D9&]T9F]L9&5R<R`]('1R=64I"B`@("!["B`@("`@("`@)&-O;FX@/2`D
M=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@
M("`@?0H*("`@("`@("`D9F]L9&5R<R`](&%R<F%Y*"D["B`@("`@("`@)&9O
M;&1E<G-;9&ER;F%M92@D<&%T:"E=(#T@87)R87DH)W9A;"<@/3X@9&ER;F%M
M92@D<&%T:"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V%B8G)E=B<@/3X@)RXN)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G;&%B96PG(#T^("<N+B<I.PH*("`@("`@
M("`D9F]L9&5R3&ES="`]("1T:&ES+3YL:7-T1F]L9&5R*"1P871H+"!N=6QL
M+"`D9&]T9F]L9&5R<RP@=')U92D["B`@("`@("`@:68@*&ES7V$H)&9O;&1E
M<DQI<W0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1F
M;VQD97),:7-T.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)&9O;&1E
M<DQI<W0@87,@)&YA;64@/3X@)&9I;&5S*2!["B`@("`@("`@("`@("1F;VQD
M97)S6R1N86UE72`](&%R<F%Y*"=V86PG(#T^("1P871H("X@)R\G("X@)&9I
M;&5S6R=N86UE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=A8F)R978G(#T^("1F:6QE<ULG;F%M92==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G;&%B96PG(#T^("1P871H("X@)R\G
M("X@)&9I;&5S6R=N86UE)UTI.PH@("`@("`@('T*"B`@("`@("`@:W-O<G0H
M)&9O;&1E<G,I.PH*("`@("`@("!R971U<FX@)&9O;&1E<G,["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FX@56YI>"!S='EL92!P97)M<RX*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D<&5R;7,@(%1H92!P97)M:7-S:6]N<R!T;R!S970N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%5N:7@@<W1Y;&4@<&5R;7,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]G9715;FEX4&5R;7,H)'!E<FUS*0H@("`@
M>PH@("`@("`@("\O($1E=&5R;6EN92!P97)M:7-S:6]N<PH@("`@("`@("1O
M=VYE<ELG<F5A9"==("`@(#T@*"1P97)M<R`F(#`P-#`P*2`_("=R)R`Z("<M
M)SL*("`@("`@("`D;W=N97);)W=R:71E)UT@("`]("@D<&5R;7,@)B`P,#(P
M,"D@/R`G=R<@.B`G+2<["B`@("`@("`@)&]W;F5R6R=E>&5C=71E)UT@/2`H
M)'!E<FUS("8@,#`Q,#`I(#\@)W@G(#H@)RTG.PH@("`@("`@("1G<F]U<%LG
M<F5A9"==("`@(#T@*"1P97)M<R`F(#`P,#0P*2`_("=R)R`Z("<M)SL*("`@
M("`@("`D9W)O=7!;)W=R:71E)UT@("`]("@D<&5R;7,@)B`P,#`R,"D@/R`G
M=R<@.B`G+2<["B`@("`@("`@)&=R;W5P6R=E>&5C=71E)UT@/2`H)'!E<FUS
M("8@,#`P,3`I(#\@)W@G(#H@)RTG.PH@("`@("`@("1W;W)L9%LG<F5A9"==
M("`@(#T@*"1P97)M<R`F(#`P,#`T*2`_("=R)R`Z("<M)SL*("`@("`@("`D
M=V]R;&1;)W=R:71E)UT@("`]("@D<&5R;7,@)B`P,#`P,BD@/R`G=R<@.B`G
M+2<["B`@("`@("`@)'=O<FQD6R=E>&5C=71E)UT@/2`H)'!E<FUS("8@,#`P
M,#$I(#\@)W@G(#H@)RTG.PH*("`@("`@("`O+R!!9&IU<W0@9F]R(%-5240L
M(%-'240@86YD('-T:6-K>2!B:70*("`@("`@("!I9B`H)'!E<FUS("8@,'@X
M,#`I('L*("`@("`@("`@("`@)&]W;F5R6R=E>&5C=71E)UT@/2`H)&]W;F5R
M6R=E>&5C=71E)UT@/3T@)W@G*2`_("=S)R`Z("=3)SL*("`@("`@("!]"B`@
M("`@("`@:68@*"1P97)M<R`F(#!X-#`P*2!["B`@("`@("`@("`@("1G<F]U
M<%LG97AE8W5T92==(#T@*"1G<F]U<%LG97AE8W5T92==(#T]("=X)RD@/R`G
M<R<@.B`G4R<["B`@("`@("`@?0H@("`@("`@(&EF("@D<&5R;7,@)B`P>#(P
M,"D@>PH@("`@("`@("`@("`D=V]R;&1;)V5X96-U=&4G72`]("@D=V]R;&1;
M)V5X96-U=&4G72`]/2`G>"<I(#\@)W0G(#H@)U0G.PH@("`@("`@('T*"B`@
M("`@("`@)'5N:7A097)M<R`]("1O=VYE<ELG<F5A9"==("X@)&]W;F5R6R=W
M<FET92==("X@)&]W;F5R6R=E>&5C=71E)UT@+@H@("`@("`@("`@("`@("`@
M("`@("`D9W)O=7!;)W)E860G72`N("1G<F]U<%LG=W)I=&4G72`N("1G<F]U
M<%LG97AE8W5T92==("X*("`@("`@("`@("`@("`@("`@("`@)'=O<FQD6R=R
M96%D)UT@+B`D=V]R;&1;)W=R:71E)UT@+B`D=V]R;&1;)V5X96-U=&4G73L*
M"B`@("`@("`@<F5T=7)N("1U;FEX4&5R;7,["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!296YA;64@82!F:6QE(&]R(&9O;&1E<B!I;B!T:&4@5D93+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&]L9'!A=&@@(%1H92!O;&0@<&%T
M:"!T;R!T:&4@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&]L9&YA;64@
M(%1H92!O;&0@9FEL96YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=P
M871H("!4:&4@;F5W('!A=&@@;V8@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N97=N86UE("!4:&4@;F5W(&9I;&5N86UE+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E;F%M92@D;VQD<&%T:"P@)&]L9&YA;64L("1N97=P871H+"`D;F5W;F%M
M92D*("`@('L*("`@("`@("!I9B`H(4!I<U]D:7(H)'1H:7,M/E]G971.871I
M=F50871H*"1N97=P871H*2DI('L*("`@("`@("`@("`@:68@*&ES7V$H)')E
M<R`]("1T:&ES+3YA=71O8W)E871E4&%T:"@D;F5W<&%T:"DL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(4!R96YA;64H)'1H:7,M
M/E]G971.871I=F50871H*"1O;&1P871H+"`D;VQD;F%M92DL"B`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D;F5W<&%T:"P@
M)&YE=VYA;64I*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BAS<')I;G1F*%\H(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O
M)7,N(BDL("1O;&1P871H+"`D;VQD;F%M92DI.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@
M82!F=6QL(&9I;&5N86UE(&]N('1H92!N871I=F4@9FEL97-Y<W1E;2P@9G)O
M;2!A(%9&4PH@("`@("H@<&%T:"!A;F0@;F%M92X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P
M871H("!4:&4@5D93(&9I;&4@<&%T:"X*("`@("`J($!P87)A;2!S=')I;F<@
M)&YA;64@(%1H92!61E,@9FEL96YA;64N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!F=6QL(&YA=&EV92!F:6QE;F%M92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V=E=$YA=&EV95!A=&@H)'!A=&@@/2`G)RP@)&YA;64@
M/2`G)RD*("`@('L*("`@("`@("`D;F%M92`](&)A<V5N86UE*"1N86UE*3L*
M("`@("`@("!I9B`H(65M<'1Y*"1N86UE*2D@>PH@("`@("`@("`@("`D;F%M
M92`]('-T<E]R97!L86-E*"<N+B<L("<G+"`D;F%M92D["B`@("`@("`@("`@
M(&EF("AS=6)S='(H)&YA;64L(#`L(#$I("$]("<O)RD@>PH@("`@("`@("`@
M("`@("`@)&YA;64@/2`G+R<@+B`D;F%M93L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D<&%T:"DI('L*("`@("`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=H;VUE)UTI("8F"B`@("`@
M("`@("`@("`@("!P<F5G7VUA=&-H*"=\7GXO/R@N*BDD?"<L("1P871H+"`D
M;6%T8VAE<RDI('L*("`@("`@("`@("`@("`@("1P871H(#T@)'1H:7,M/E]P
M87)A;7-;)VAO;64G72`N("<O)R`N("1M871C:&5S6S%=.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D<&%T:"`]('-T<E]R97!L86-E*"<N+B<L("<G
M+"`D<&%T:"D["B`@("`@("`@("`@(&EF("AS=6)S='(H)'!A=&@L(#`L(#$I
M(#T]("<O)RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%R
M86US6R=V9G-R;V]T)UT@+B`D<&%T:"`N("1N86UE.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%R86US
M6R=V9G-R;V]T)UT@+B`G+R<@+B`D<&%T:"`N("1N86UE.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<&%R86US6R=V9G-R;V]T)UT@+B`D;F%M93L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3='5B('1O(&-H96-K(&EF('=E(&AA=F4@82!V
M86QI9"!C;VYN96-T:6]N+B!-86ME<R!S=7)E('1H870*("`@("`J('1H92!V
M9G-R;V]T(&ES(')E861A8FQE+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@:68@=F9S
M<F]O="!I<R!R96%D86)L92P@4$5!4E]%<G)O<B!I9B!I="!I<VXG="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H*0H@("`@>PH@("`@("`@(&EF
M("@H0&ES7V1I<B@D=&AI<RT^7W!A<F%M<ULG=F9S<F]O="==*2`F)@H@("`@
M("`@("`@("`@0&ES7W)E861A8FQE*"1T:&ES+3Y?<&%R86US6R=V9G-R;V]T
M)UTI*2!\?`H@("`@("`@("`@("!`;6MD:7(H)'1H:7,M/E]P87)A;7-;)W9F
M<W)O;W0G72DI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M7R@B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(I*3L*
M("`@("`@("!]"B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U9&4R]F='`N<&AP
M````````````````````````````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`W
M-3(S-``Q,#4Q-30S,S<T-0`P,C`T,#``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%9&4R!I;7!L96UE
M;G1A=&EO;B!F;W(@86X@1E10('-E<G9E<BX*("H*("H@4F5Q=6ER960@=F%L
M=65S(&9O<B`D<&%R86US.CQP<F4^"B`J("`@("`@)W5S97)N86UE)R`@("`@
M("!4:&4@=7-E<FYA;64@=VET:"!W:&EC:"!T;R!C;VYN96-T('1O('1H92!F
M='`@<V5R=F5R+@H@*B`@("`@("=P87-S=V]R9"<@("`@("`@5&AE('!A<W-W
M;W)D('=I=&@@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9G1P('-E<G9E<BX*
M("H@("`@("`G:&]S='-P96,G("`@("`@(%1H92!F='`@<V5R=F5R('1O(&-O
M;FYE8W0@=&\N/"]P<F4^"B`J"B`J($]P=&EO;F%L('9A;'5E<R!F;W(@)'!A
M<F%M<SH\<')E/@H@*B`@("`@("=M87!L;V-A;&ED<R<@("`@268@=')U92!A
M;F0@=&AE(%!/4TE8(&5X=&5N<VEO;B!I<R!A=F%I;&%B;&4L('1H90H@*B`@
M("`@("`@("`@("`@("`@("`@("`@9')I=F5R('=I;&P@;6%P('1H92!U<V5R
M(&%N9"!G<F]U<"!)1',@<F5T=7)N960@9G)O;0H@*B`@("`@("`@("`@("`@
M("`@("`@("`@=&AE($944"!S97)V97(@=VET:"!T:&4@;&]C86P@241S(&9R
M;VT@=&AE(&QO8V%L"B`J("`@("`@("`@("`@("`@("`@("`@("!P87-S=V]R
M9"!F:6QE+B`@5&AI<R!I<R!U<V5F=6P@;VYL>2!I9B!T:&4@1E10('-E<G9E
M<@H@*B`@("`@("`@("`@("`@("`@("`@("`@:7,@<G5N;FEN9R!O;B!L;V-A
M;&AO<W0@;W(@:68@=&AE(&QO8V%L('5S97(O9W)O=7`*("H@("`@("`@("`@
M("`@("`@("`@("`@($E$<R!A<F4@:61E;G1I8V%L('1O('1H92!R96UO=&4@
M1E10('-E<G9E<BX*("H@("`@("`G<&%S=B<@("`@("`@("`@($EF('1R=64L
M(&-O;FYE8W1I;VX@=VEL;"!B92!S970@=&\@<&%S<VEV92!M;V1E+@H@*B`@
M("`@("=P;W)T)R`@("`@("`@("`@5&AE('!O<G0@=7-E9"!T;R!C;VYN96-T
M('1O('1H92!F='`@<V5R=F5R(&EF(&]T:&5R"B`J("`@("`@("`@("`@("`@
M("`@("`@("!T:&%N(#(Q+@H@*B`@("`@("=S<VPG("`@("`@("`@("`@268@
M=')U92P@86YD(%!(4"!H860@8F5E;B!C;VUP:6QE9"!W:71H($]P96Y34TP*
M("H@("`@("`@("`@("`@("`@("`@("`@('-U<'!O<G0L(%1,4R!T<F%N<W!O
M<G0M;&5V96P@96YC<GEP=&EO;B!W:6QL(&)E"B`J("`@("`@("`@("`@("`@
M("`@("`@("!N96=O=&EA=&5D('=I=&@@=&AE('-E<G9E<BX*("H@("`@("`G
M=&EM96]U="<@("`@("`@($EF(&1E9FEN960L('5S92!T:&ES('9A;'5E(&%S
M('1H92!T:6UE;W5T(&9O<B!T:&4*("H@("`@("`@("`@("`@("`@("`@("`@
M('-E<G9E<BX\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP+'8@,2XW-2XT+C(Q(#(P,#8O,#4O,S$@,#0Z-3`Z,#(@<VQU
M<V%R>B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P,BTR
M,#`V($UI8VAA96P@5F%R9VAE<V4@/&UI:V4N=F%R9VAE<V5`87-C96QL871E
M8V@N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@($UI8VAA96P@
M5F%R9VAE<V4@/&UI:V4N=F%R9VAE<V5`87-C96QL871E8V@N8V]M/@H@*B!`
M<&%C:V%G92!61E,*("HO"F-L87-S(%9&4U]F='`@97AT96YD<R!61E,@>PH*
M("`@("\J*@H@("`@("H@3&ES="!O9B!A9&1I=&EO;F%L(&-R961E;G1I86QS
M(')E<75I<F5D(&9O<B!T:&ES(%9&4R!B86-K96YD+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?8W)E9&5N=&EA;',@/2!A
M<G)A>2@G=7-E<FYA;64G+"`G<&%S<W=O<F0G*3L*"B`@("`O*BH*("`@("`J
M($QI<W0@;V8@<&5R;6ES<VEO;G,@86YD(&EF('1H97D@8V%N(&)E(&-H86YG
M960@:6X@=&AI<R!61E,@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7W!E<FUI<W-I;VYS(#T@87)R87DH"B`@
M("`@("`@)V]W;F5R)R`]/B!A<G)A>2@G<F5A9"<@/3X@=')U92P@)W=R:71E
M)R`]/B!T<G5E+"`G97AE8W5T92<@/3X@=')U92DL"B`@("`@("`@)V=R;W5P
M)R`]/B!A<G)A>2@G<F5A9"<@/3X@=')U92P@)W=R:71E)R`]/B!T<G5E+"`G
M97AE8W5T92<@/3X@=')U92DL"B`@("`@("`@)V%L;"<@("`]/B!A<G)A>2@G
M<F5A9"<@/3X@=')U92P@)W=R:71E)R`]/B!T<G5E+"`G97AE8W5T92<@/3X@
M=')U92DI.PH*("`@("\J*@H@("`@("H@5F%R:6%B;&4@:&]L9&EN9R!T:&4@
M8V]N;F5C=&EO;B!T;R!T:&4@9G1P('-E<G9E<BX*("`@("`J"B`@("`@*B!`
M=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D7W-T<F5A;2`](&9A;'-E
M.PH*("`@("\J*@H@("`@("H@3&]C86P@8V%C:&4@87)R87D@9F]R('5S97(@
M241S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1?=6ED<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!,;V-A;"!C86-H
M92!A<G)A>2!F;W(@9W)O=7`@241S+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?9VED<R`](&%R<F%Y*"D["@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!S:7IE(&]F(&$@9FEL92X*("`@("`J"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'!A=&@@(%1H92!P871H(&]F('1H92!F:6QE+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F%M92`@5&AE(&9I;&5N86UE+@H@("`@("H*("`@("`J($!R
M971U<FX@:6YT96=E<B`@5&AE('-I>F4@;V8@=&AE(&9I;&4@:6X@8GET97,@
M;W(@4$5!4E]%<G)O<B!O;@H@("`@("H@("`@("`@("`@("`@("`@("!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S:7IE*"1P871H+"`D;F%M92D*
M("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@
M("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@(&EF("@H)'-I
M>F4@/2!`9G1P7W-I>F4H)'1H:7,M/E]S=')E86TL("1T:&ES+3Y?9V5T4&%T
M:"@D<&%T:"P@)&YA;64I*2D@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&-H
M96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(BDL("1T:&ES+3Y?9V5T4&%T:"@D
M<&%T:"P@)&YA;64I*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'-I
M>F4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V97,@82!F:6QE(&9R
M;VT@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H
M("!4:&4@<&%T:&YA;64@=&\@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1N86UE("!4:&4@9FEL96YA;64@=&\@<F5T<FEE=F4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!F:6QE(&1A=&$N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(')E860H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@
M("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H
M)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C
M;VYN.PH@("`@("`@('T*"B`@("`@("`@)'1M<$9I;&4@/2`D=&AI<RT^7V=E
M=%1E;7!&:6QE*"D["B`@("`@("`@)&9E=&-H(#T@0&9T<%]G970H)'1H:7,M
M/E]S=')E86TL("1T;7!&:6QE+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I+"!&5%!?0DE.05)9*3L*
M("`@("`@("!I9B`H)&9E=&-H(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T;R!O
M<&5N(%9&4R!F:6QE(%PB)7-<(BXB*2P@)'1H:7,M/E]G9710871H*"1P871H
M+"`D;F%M92DI*3L*("`@("`@("!]"@H@("`@("`@("1S:7IE(#T@9FEL97-I
M>F4H)'1M<$9I;&4I.PH@("`@("`@(&EF("@D<VEZ92`]/3T@,"D@>PH@("`@
M("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H*("`@("`@("!I9B`H3U-?
M5TE.1$]74RD@>PH@("`@("`@("`@("`D;6]D92`]("=R8B<["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&UO9&4@/2`G<B<["B`@("`@("`@?0H*
M("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=F:6QE7V=E=%]C;VYT96YT
M<R<I*2!["B`@("`@("`@("`@("1D871A(#T@9FEL95]G971?8V]N=&5N=',H
M)'1M<$9I;&4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F<"`]
M(&9O<&5N*"1T;7!&:6QE+"`D;6]D92D["B`@("`@("`@("`@("1D871A(#T@
M9G)E860H)&9P+"`D<VEZ92D["B`@("`@("`@("`@(&9C;&]S92@D9G`I.PH@
M("`@("`@('T*("`@("`@("!U;FQI;FLH)'1M<$9I;&4I.PH*("`@("`@("!R
M971U<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R97,@82!F
M:6QE(&EN('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<&%T:"`@("`@("`@(%1H92!P871H('1O('-T;W)E('1H92!F:6QE(&EN+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@("`@(%1H92!F:6QE;F%M
M92!T;R!U<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T;7!&:6QE("`@("`@
M5&AE('1E;7!O<F%R>2!F:6QE(&-O;G1A:6YI;F<@=&AE(&1A=&$@=&\*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B92!S=&]R960N"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D875T;V-R96%T92`@075T;VUA=&EC86QL
M>2!C<F5A=&4@9&ER96-T;W)I97,_"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&4H)'!A=&@L
M("1N86UE+"`D=&UP1FEL92P@)&%U=&]C<F5A=&4@/2!F86QS92D*("`@('L*
M("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF
M("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@("1R97,@/2`D=&AI<RT^
M7V-H96-K475O=&%7<FET92@G9FEL92<L("1T;7!&:6QE*3L*("`@("`@("!I
M9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<F5S.PH@("`@("`@('T*"B`@("`@("`@:68@*"%`9G1P7W!U="@D
M=&AI<RT^7W-T<F5A;2P@)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92DL
M("1T;7!&:6QE+"!&5%!?0DE.05)9*2D@>PH@("`@("`@("`@("!I9B`H)&%U
M=&]C<F5A=&4I('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M875T;V-R96%T95!A=&@H)'!A=&@I.PH@("`@("`@("`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@:68@*"%`9G1P7W!U="@D=&AI<RT^7W-T<F5A;2P@)'1H:7,M
M/E]G9710871H*"1P871H+"`D;F%M92DL("1T;7!&:6QE+"!&5%!?0DE.05)9
M*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<
M(BXB*2P@)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92DI*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB*2P@)'1H:7,M/E]G9710871H
M*"1P871H+"`D;F%M92DI*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R
M97,@82!F:6QE(&EN('1H92!61E,@9G)O;2!R87<@9&%T82X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@=&\@
M<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE
M("`@("`@("`@5&AE(&9I;&5N86UE('1O('5S92X*("`@("`J($!P87)A;2!S
M=')I;F<@)&1A=&$@("`@("`@("!4:&4@9FEL92!D871A+@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&%U=&]C<F5A=&4@($%U=&]M871I8V%L;'D@8W)E871E
M(&1I<F5C=&]R:65S/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R
M=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E1&%T82@D<&%T:"P@)&YA
M;64L("1D871A+"`D875T;V-R96%T92`](&9A;'-E*0H@("`@>PH@("`@("`@
M("1R97,@/2`D=&AI<RT^7V-H96-K475O=&%7<FET92@G<W1R:6YG)RP@)&1A
M=&$I.PH@("`@("`@(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H*("`@("`@("`D
M=&UP1FEL92`]("1T:&ES+3Y?9V5T5&5M<$9I;&4H*3L*("`@("`@("`D9G`@
M/2!F;W!E;B@D=&UP1FEL92P@)W=B)RD["B`@("`@("`@9G=R:71E*"1F<"P@
M)&1A=&$I.PH@("`@("`@(&9C;&]S92@D9G`I.PH*("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/G=R:71E*"1P871H+"`D;F%M92P@)'1M<$9I;&4L("1A=71O
M8W)E871E*3L*("`@("`@("!U;FQI;FLH)'1M<$9I;&4I.PH@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E<R!A
M(&9I;&4@9G)O;2!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'!A=&@@(%1H92!P871H('1O(&1E;&5T92!T:&4@9FEL92!F<F]M+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9I;&5N86UE('1O(&1E
M;&5T92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U
M8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!D96QE=&5&:6QE*"1P871H+"`D;F%M92D*("`@
M('L*("`@("`@("`D<F5S(#T@)'1H:7,M/E]C:&5C:U%U;W1A1&5L971E*"1P
M871H+"`D;F%M92D["B`@("`@("`@:68@*&ES7V$H)')E<RP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("!]"@H@
M("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@
M*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@:68@*"%`9G1P7V1E;&5T
M92@D=&AI<RT^7W-T<F5A;2P@)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M
M92DI*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P
M<FEN=&8H7R@B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(BDL
M("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I*2D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-H
M96-K<R!I9B!A(&=I=F5N(&ET96T@:7,@82!F;VQD97(N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A<F5N="!F;VQD97(N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@:71E;2!N86UE+@H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!I="!I<R!A(&9O
M;&1E<BP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!I
M<T9O;&1E<B@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@)&-O;FX@/2`D
M=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@
M("`@?0H*("`@("`@("`D<F5S=6QT(#T@9F%L<V4["B`@("`@("`@)&]L9&1I
M<B`]("1T:&ES+3YG971#=7)R96YT1&ER96-T;W)Y*"D["@H@("`@("`@("\J
M(%-E92!I9B!W92!C86X@8VAA;F=E('1O('1H92!G:79E;B!P871H+B`J+PH@
M("`@("`@(&EF("A`9G1P7V-H9&ER*"1T:&ES+3Y?<W1R96%M+"`D=&AI<RT^
M7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI('L*("`@("`@("`@("`@)')E<W5L
M="`]('1R=64["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W-E=%!A=&@H
M)&]L9&1I<BD["@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1&5L971E<R!A(&9O;&1E<B!F<F]M('1H92!61E,N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("`@5&AE('!A
M<F5N="!F;VQD97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@
M("!4:&4@;F%M92!O9B!T:&4@9F]L9&5R('1O(&1E;&5T92X*("`@("`J($!P
M87)A;2!B;V]L96%N("1R96-U<G-I=F4@($9O<F-E(&$@<F5C=7)S:79E(&1E
M;&5T93\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U
M8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!D96QE=&5&;VQD97(H)'!A=&@L("1N86UE+"`D
M<F5C=7)S:79E(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI
M<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@
M?0H*("`@("`@("`D:7-$:7(@/2!F86QS93L*("`@("`@("`D9&ER0VAE8VL@
M/2`D=&AI<RT^;&ES=$9O;&1E<B@D<&%T:"D["B`@("`@("`@9F]R96%C:"`H
M)&1I<D-H96-K(&%S("1F:6QE*2!["B`@("`@("`@("`@(&EF("@D9FEL95LG
M;F%M92==(#T]("1N86UE("8F("1F:6QE6R=T>7!E)UT@/3T@)RHJ9&ER)RD@
M>PH@("`@("`@("`@("`@("`@)&ES1&ER(#T@=')U93L*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I
M9B`H)&ES1&ER*2!["B`@("`@("`@("`@("1F:6QE7VQI<W0@/2`D=&AI<RT^
M;&ES=$9O;&1E<B@D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2D["B`@
M("`@("`@("`@(&EF("AI<U]A*"1F:6QE7VQI<W0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D9FEL95]L:7-T.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!I9B`H8V]U;G0H)&9I;&5?;&ES="D@)B8@
M(21R96-U<G-I=F4I('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E
M=%!A=&@H)'!A=&@L("1N86UE*2DI.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!F;W)E86-H("@D9FEL95]L:7-T(&%S("1F:6QE*2!["B`@("`@("`@
M("`@("`@("!I9B`H)&9I;&5;)W1Y<&4G72`]/2`G*BID:7(G*2!["B`@("`@
M("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YD96QE=&5&;VQD97(H
M)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92DL("1F:6QE6R=N86UE)UTL
M("1R96-U<G-I=F4I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F1E;&5T949I;&4H)'1H
M:7,M/E]G9710871H*"1P871H+"`D;F%M92DL("1F:6QE6R=N86UE)UTI.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!I9B`H(4!F='!?<FUD:7(H)'1H:7,M/E]S=')E86TL
M("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")#86YN
M;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(BDL("1T:&ES+3Y?9V5T4&%T
M:"@D<&%T:"P@)&YA;64I*2D["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!I9B`H(4!F='!?9&5L971E*"1T:&ES+3Y?<W1R
M96%M+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI('L*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B
M0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB*2P@)'1H:7,M/E]G9710871H
M*"1P871H+"`D;F%M92DI*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YA
M;65S(&$@9FEL92!I;B!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&]L9'!A=&@@(%1H92!O;&0@<&%T:"!T;R!T:&4@9FEL92X*("`@
M("`J($!P87)A;2!S=')I;F<@)&]L9&YA;64@(%1H92!O;&0@9FEL96YA;64N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=P871H("!4:&4@;F5W('!A=&@@
M;V8@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=N86UE("!4
M:&4@;F5W(&9I;&5N86UE+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F%M92@D;VQD<&%T:"P@
M)&]L9&YA;64L("1N97=P871H+"`D;F5W;F%M92D*("`@('L*("`@("`@("!I
M9B`H:7-?82@D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^875T;V-R96%T95!A
M=&@H)&YE=W!A=&@I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@:68@*"%`9G1P7W)E
M;F%M92@D=&AI<RT^7W-T<F5A;2P@)'1H:7,M/E]G9710871H*"1O;&1P871H
M+"`D;VQD;F%M92DL("1T:&ES+3Y?9V5T4&%T:"@D;F5W<&%T:"P@)&YE=VYA
M;64I*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS
M<')I;G1F*%\H(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(I
M+"`D=&AI<RT^7V=E=%!A=&@H)&]L9'!A=&@L("1O;&1N86UE*2DI.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#<F5A=&5S(&$@9F]L9&5R(&]N('1H92!61E,N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A<F5N="!F;VQD97(N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@;F%M92!O9B!T:&4@;F5W
M(&9O;&1E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N
M('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!C<F5A=&5&;VQD97(H)'!A=&@L("1N86UE
M*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@
M("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@:68@*"%`
M9G1P7VUK9&ER*"1T:&ES+3Y?<W1R96%M+"`D=&AI<RT^7V=E=%!A=&@H)'!A
M=&@L("1N86UE*2DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O
M<GD@7"(E<UPB+B(I+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#:&%N9V5S('!E<FUI<W-I;VYS(&9O<B!A;B!I=&5M(&]N
M('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@
M("`@("`@5&AE('!A<F5N="!F;VQD97(@;V8@=&AE(&ET96TN"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE("`@("`@("!4:&4@;F%M92!O9B!T:&4@:71E
M;2X*("`@("`J($!P87)A;2!S=')I;F<@)'!E<FUI<W-I;VX@(%1H92!P97)M
M:7-S:6]N('1O('-E="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C:&%N9V5097)M:7-S:6]N<R@D
M<&%T:"P@)&YA;64L("1P97)M:7-S:6]N*0H@("`@>PH@("`@("`@("1C;VYN
M(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"%`9G1P7W-I=&4H)'1H:7,M/E]S=')E
M86TL("=#2$U/1"`G("X@)'!E<FUI<W-I;VX@+B`G("<@+B`D=&AI<RT^7V=E
M=%!A=&@H)'!A=&@L("1N86UE*2DI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB*2P@)'1H:7,M/E]G9710
M871H*"1P871H+"`D;F%M92DI*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!A;B!U
M;G-O<G1E9"!F:6QE(&QI<W0@;V8@=&AE('-P96-I9FEE9"!D:7)E8W1O<GDN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("!4:&4@
M<&%T:"!O9B!T:&4@9&ER96-T;W)Y+@H@("`@("H@0'!A<F%M(&UI>&5D("1F
M:6QT97(@("`@("!3=')I;F<O:&%S:"!T;R!F:6QT97(@9FEL92]D:7)N86UE
M(&]N+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&1O=&9I;&5S("!3:&]W(&1O
M=&9I;&5S/PH@("`@("H@0'!A<F%M(&)O;VQE86X@)&1I<F]N;'D@("!3:&]W
M(&]N;'D@9&ER96-T;W)I97,_"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>2`@1FEL92!L:7-T(&]N('-U8V-E<W,@;W(@4$5!4E]%<G)O<B!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?;&ES=$9O;&1E<B@D<&%T:"`]
M("<G+"`D9FEL=&5R(#T@;G5L;"P@)&1O=&9I;&5S(#T@=')U92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("1D:7)O;FQY(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H
M:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("`D9FEL97,@/2!A<G)A>2@I
M.PH@("`@("`@("1T>7!E(#T@5D93.CIS=')T;VQO=V5R*$!F='!?<WES='EP
M92@D=&AI<RT^7W-T<F5A;2DI.PH@("`@("`@(&EF("@D='EP92`]/2`G=6YK
M;F]W;B<I('L*("`@("`@("`@("`@+R\@1V\@=VET:"!U;FEX+7-T>6QE(&QI
M<W1I;F=S(&)Y(&1E9F%U;'0N"B`@("`@("`@("`@("1T>7!E(#T@)W5N:7@G
M.PH@("`@("`@('T@96QS96EF("AS=')P;W,H)'1Y<&4L("=W:6XG*2`A/3T@
M9F%L<V4I('L*("`@("`@("`@("`@)'1Y<&4@/2`G=VEN)SL*("`@("`@("!]
M(&5L<V5I9B`H<W1R<&]S*"1T>7!E+"`G;F5T=V%R92<I("$]/2!F86QS92D@
M>PH@("`@("`@("`@("`D='EP92`]("=N971W87)E)SL*("`@("`@("!]"@H@
M("`@("`@("1O;&1D:7(@/2`D=&AI<RT^9V5T0W5R<F5N=$1I<F5C=&]R>2@I
M.PH@("`@("`@(&EF("@A96UP='DH)'!A=&@I*2!["B`@("`@("`@("`@("1R
M97,@/2`D=&AI<RT^7W-E=%!A=&@H)'!A=&@I.PH@("`@("`@("`@("!I9B`H
M:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)')E<SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M:68@*"1T>7!E(#T]("=U;FEX)RD@>PH@("`@("`@("`@("`O+R!)9B!W92!D
M;VXG="!W86YT(&1O=&9I;&5S+"!792!C86X@<V%V92!W;W)K(&AE<F4@8GD@
M;F]T"B`@("`@("`@("`@("\O(&1O:6YG(&%N(&QS("UA(&%N9"!T:&5N(&YO
M="!D;VEN9R!T:&4@8VAE8VL@;&%T97(@*&)Y"B`@("`@("`@("`@("\O('-E
M='1I;F<@)&1O=&9I;&5S('1O('1R=64L('1H92!I9B!I<R!S:&]R="UC:7)C
M=6ET960I+@H@("`@("`@("`@("!I9B`H)&1O=&9I;&5S*2!["B`@("`@("`@
M("`@("`@("`D;&ES="`](&9T<%]R87=L:7-T*"1T:&ES+3Y?<W1R96%M+"`G
M+6%L)RD["B`@("`@("`@("`@("`@("`D9&]T9FEL97,@/2!T<G5E.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&QI<W0@/2!F='!?
M<F%W;&ES="@D=&AI<RT^7W-T<F5A;2P@)RUL)RD["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("1L:7-T(#T@9G1P7W)A=VQI
M<W0H)'1H:7,M/E]S=')E86TL("<G*3L*("`@("`@("!]"@H@("`@("`@(&EF
M("@A:7-?87)R87DH)&QI<W0I*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D
M;VQD9&ER*2D@>PH@("`@("`@("`@("`@("`@)')E<R`]("1T:&ES+3Y?<V5T
M4&%T:"@D;VQD9&ER*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97,L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)')E<SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!R971U<FX@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@("\J($EF
M("=M87!L;V-A;&ED<R<@:7,@<V5T+"!C:&5C:R!F;W(@=&AE(%!/4TE8(&5X
M=&5N<VEO;BX@*B\*("`@("`@("`D;6%P:61S(#T@9F%L<V4["B`@("`@("`@
M:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG;6%P;&]C86QI9',G72D@)B8*
M("`@("`@("`@("`@97AT96YS:6]N7VQO861E9"@G<&]S:7@G*2D@>PH@("`@
M("`@("`@("`D;6%P:61S(#T@=')U93L*("`@("`@("!]"@H@("`@("`@("1C
M=7)R=&EM92`]('1I;64H*3L*"B`@("`@("`@9F]R96%C:"`H)&QI<W0@87,@
M)&QI;F4I('L*("`@("`@("`@("`@)&9I;&4@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`D:71E;2`]('!R96=?<W!L:70H)R]<<RLO)RP@)&QI;F4I.PH@("`@
M("`@("`@("!I9B`H)'1Y<&4@/3T@)W5N:7@G('Q\("@D='EP92`]/2`G=VEN
M)R`F)B`A<')E9U]M871C:"@G?%QD7&0M7&1<9"U<9%QD?"<L("1I=&5M6S!=
M*2DI('L*("`@("`@("`@("`@("`@(&EF("AC;W5N="@D:71E;2D@/"`X('Q\
M('-U8G-T<B@D;&EN92P@,"P@-2D@/3T@)W1O=&%L)RD@>PH@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@)&9I;&5;)W!E<FUS)UT@/2`D:71E;5LP73L*("`@("`@("`@
M("`@("`@(&EF("@D;6%P:61S*2!["B`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7W5I9'-;)&ET96U;,EU=*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D96YT<GD@/2!P;W-I>%]G971P=W5I9"@D:71E;5LR
M72D["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=6ED<ULD:71E
M;5LR75T@/2`H96UP='DH)&5N=')Y*2D@/R`D:71E;5LR72`Z("1E;G1R>5LG
M;F%M92==.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`D9FEL95LG;W=N97(G72`]("1T:&ES+3Y?=6ED<ULD:71E;5LR75T[
M"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W5I9'-;
M)&ET96U;,UU=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D96YT<GD@
M/2!P;W-I>%]G971G<F=I9"@D:71E;5LS72D["B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?=6ED<ULD:71E;5LS75T@/2`H96UP='DH)&5N=')Y
M*2D@/R`D:71E;5LS72`Z("1E;G1R>5LG;F%M92==.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D9FEL95LG9W)O=7`G72`]
M("1T:&ES+3Y?=6ED<ULD:71E;5LS75T["@H@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D9FEL95LG;W=N97(G72`]("1I
M=&5M6S)=.PH@("`@("`@("`@("`@("`@("`@("1F:6QE6R=G<F]U<"==(#T@
M)&ET96U;,UT["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M9FEL95LG;F%M92==(#T@<W5B<W1R*"1L:6YE+"!S=')P;W,H)&QI;F4L('-P
M<FEN=&8H(B5S("4R<R`E-7,B+"`D:71E;5LU72P@)&ET96U;-ETL("1I=&5M
M6S==*2D@*R`Q,RD["@H@("`@("`@("`@("`@("`@+R\@1FEL=&5R(&]U="`G
M+B<@86YD("<N+B<@96YT<FEE<RX*("`@("`@("`@("`@("`@(&EF("AP<F5G
M7VUA=&-H*"<O7EPN7"X_7"\_)"\G+"`D9FEL95LG;F%M92==*2D@>PH@("`@
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("\O($9I;'1E<B!O=70@9&]T9FEL97,@:68@=&AE
M>2!A<F5N)W0@=V%N=&5D+@H@("`@("`@("`@("`@("`@:68@*"$D9&]T9FEL
M97,@)B8@<W5B<W1R*"1F:6QE6R=N86UE)UTL(#`L(#$I(#T]("<N)RD@>PH@
M("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@("1P,2`]('-U8G-T<B@D9FEL95LG<&5R;7,G
M72P@,"P@,2D["B`@("`@("`@("`@("`@("!I9B`H)'`Q(#T]/2`G;"<I('L*
M("`@("`@("`@("`@("`@("`@("`D9FEL95LG;&EN:R==(#T@<W5B<W1R*"1F
M:6QE6R=N86UE)UTL('-T<G!O<R@D9FEL95LG;F%M92==+"`G+3XG*2`K(#,I
M.PH@("`@("`@("`@("`@("`@("`@("1F:6QE6R=N86UE)UT@/2!S=6)S='(H
M)&9I;&5;)VYA;64G72P@,"P@<W1R<&]S*"1F:6QE6R=N86UE)UTL("<M/B<I
M("T@,2D["B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)W1Y<&4G72`]("<J
M*G-Y;2<["@H@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YI<T9O;&1E
M<B@G)RP@)&9I;&5;)VQI;FLG72DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&9I;&5;)VQI;FMT>7!E)UT@/2`G*BID:7(G.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P87)T<R`](&5X<&QO9&4H)R\G+"`D9FEL95LG
M;&EN:R==*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1N86UE(#T@97AP;&]D92@G+B<L(&%R<F%Y7W!O
M<"@D<&%R=',I*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AC;W5N="@D;F%M92D@/3T@,2!\?"`H
M)&YA;65;,%T@/3T]("<G("8F(&-O=6YT*"1N86UE*2`]/2`R*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1F:6QE6R=L:6YK='EP92==(#T@)RHJ;F]N92<["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&5;)VQI;FMT>7!E)UT@
M/2!61E,Z.G-T<G1O;&]W97(H87)R87E?<&]P*"1N86UE*2D["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T@96QS96EF("@D<#$@/3T]("=D)RD@>PH@("`@("`@("`@("`@("`@
M("`@("1F:6QE6R=T>7!E)UT@/2`G*BID:7(G.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D;F%M92`](&5X<&QO9&4H
M)RXG+"`D9FEL95LG;F%M92==*3L*("`@("`@("`@("`@("`@("`@("!I9B`H
M8V]U;G0H)&YA;64I(#T](#$@?'P@*'-U8G-T<B@D9FEL95LG;F%M92==+"`P
M+"`Q*2`]/3T@)RXG("8F(&-O=6YT*"1N86UE*2`]/2`R*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D9FEL95LG='EP92==(#T@)RHJ;F]N92<["B`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&9I;&5;)W1Y<&4G72`](%9&4SHZ<W1R=&]L;W=E<B@D;F%M95MC
M;W5N="@D;F%M92D@+2`Q72D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1F:6QE6R=T>7!E
M)UT@/3T@)RHJ9&ER)RD@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE6R=S
M:7IE)UT@/2`M,3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)&9I;&5;)W-I>F4G72`]("1I=&5M6S1=.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D:71E;5LW
M72P@)SHG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("`D9FEL
M95LG9&%T92==(#T@<W1R=&]T:6UE*"1I=&5M6S==("X@)SHP,"<@+B`D:71E
M;5LU72`N("<@)R`N("1I=&5M6S9=("X@)R`G("X@9&%T92@G62<L("1C=7)R
M=&EM92DI.PH@("`@("`@("`@("`@("`@("`@("\O($EF('1H92!F='`@<V5R
M=F5R(')E<&]R=',@82!F:6QE(&UO9&EF:6-A=&EO;B!D871E(&UO<F4*("`@
M("`@("`@("`@("`@("`@("`O+R!L97-S('1H86X@;VYE(&1A>2!I;B!T:&4@
M9G5T=7)E+"!D;VXG="!T<GD@=&\@<W5B=')A8W0*("`@("`@("`@("`@("`@
M("`@("`O+R!A('EE87(@9G)O;2!T:&4@9&%T92X@(%1H97)E(&ES(&YO('=A
M>2!T;R!K;F]W+"!F;W(*("`@("`@("`@("`@("`@("`@("`O+R!E>&%M<&QE
M+"!I9B!T:&4@5D93('-E<G9E<B!A;F0@=&AE(&9T<"!S97)V97(@<F5S:61E
M"B`@("`@("`@("`@("`@("`@("`@+R\@:6X@9&EF9F5R96YT('1I;65Z;VYE
M<RX@(%=E('-H;W5L9"!S:6UP;'D@<F5P;W)T('1O('1H90H@("`@("`@("`@
M("`@("`@("`@("\O("!U<V5R('=H870@=&AE($944"!S97)V97(@:7,@<F5T
M=7)N:6YG+@H@("`@("`@("`@("`@("`@("`@(&EF("@D9FEL95LG9&%T92==
M(#X@*"1C=7)R=&EM92`K(#@V-#`P*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D9FEL95LG9&%T92==(#T@<W1R=&]T:6UE*"1I=&5M6S==("X@)SHP
M,"<@+B`D:71E;5LU72`N("<@)R`N("1I=&5M6S9=("X@)R`G("X@*&1A=&4H
M)UDG+"`D8W5R<G1I;64I("T@,2DI.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)&9I;&5;)V1A=&4G72`]('-T<G1O=&EM92@G,#`Z,#`Z,#`G("X@)&ET96U;
M-5T@+B`G("<@+B`D:71E;5LV72`N("<@)R`N("1I=&5M6S==*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E:68@*"1T>7!E(#T]("=N
M971W87)E)RD@>PH@("`@("`@("`@("`@("`@)&9I;&4@/2!!<G)A>2@I.PH@
M("`@("`@("`@("`@("`@)&9I;&5;)W!E<FUS)UT@/2`D:71E;5LQ73L*("`@
M("`@("`@("`@("`@("1F:6QE6R=O=VYE<B==(#T@)&ET96U;,ET["B`@("`@
M("`@("`@("`@("!I9B`H)&ET96U;,%T@/3T@)V0G*2!["B`@("`@("`@("`@
M("`@("`@("`@)&9I;&5;)W1Y<&4G72`]("<J*F1I<B<["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE6R=T>7!E
M)UT@/2`G*BIN;VYE)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("1F:6QE6R=S:7IE)UT@/2`D:71E;5LS73L*("`@("`@("`@("`@("`@
M("1F:6QE6R=N86UE)UT@/2`D:71E;5LW73L*("`@("`@("`@("`@("`@("1I
M;F1E>"`](#@["B`@("`@("`@("`@("`@("!W:&EL92`H)&EN9&5X(#P@8V]U
M;G0H)&ET96TI*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)VYA;64G
M72`N/2`G("<@+B`D:71E;5LD:6YD97A=.PH@("`@("`@("`@("`@("`@("`@
M("1I;F1E>"LK.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@+RH@2&%N9&QE(%=I;F1O=W,@1E10('-E
M<G9E<G,@<F5T=7)N:6YG($1/4RUS='EL92!F:6QE"B`@("`@("`@("`@("`@
M("`@*B!L:7-T:6YG<RX@*B\*("`@("`@("`@("`@("`@("1F:6QE6R=P97)M
M<R==(#T@)R<["B`@("`@("`@("`@("`@("`D9FEL95LG;W=N97(G72`]("<G
M.PH@("`@("`@("`@("`@("`@)&9I;&5;)V=R;W5P)UT@/2`G)SL*("`@("`@
M("`@("`@("`@("1F:6QE6R=N86UE)UT@/2`D:71E;5LS73L*("`@("`@("`@
M("`@("`@("1I;F1E>"`](#0["B`@("`@("`@("`@("`@("!W:&EL92`H)&EN
M9&5X(#P@8V]U;G0H)&ET96TI*2!["B`@("`@("`@("`@("`@("`@("`@)&9I
M;&5;)VYA;64G72`N/2`G("<@+B`D:71E;5LD:6YD97A=.PH@("`@("`@("`@
M("`@("`@("`@("1I;F1E>"LK.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@)&9I;&5;)V1A=&4G72`]('-T<G1O=&EM92@D:71E;5LP72`N
M("<@)R`N("1I=&5M6S%=*3L*("`@("`@("`@("`@("`@(&EF("@D:71E;5LR
M72`]/2`G/$1)4CXG*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)W1Y
M<&4G72`]("<J*F1I<B<["B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)W-I
M>F4G72`]("TQ.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`D9FEL95LG<VEZ92==(#T@)&ET96U;,ET["B`@("`@("`@
M("`@("`@("`@("`@)&YA;64@/2!E>'!L;V1E*"<N)RP@)&9I;&5;)VYA;64G
M72D["B`@("`@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1N86UE*2`]/2`Q
M('Q\("AS=6)S='(H)&9I;&5;)VYA;64G72P@,"P@,2D@/3T]("<N)R`F)B!C
M;W5N="@D;F%M92D@/3T@,BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&9I;&5;)W1Y<&4G72`]("<J*FYO;F4G.PH@("`@("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1F:6QE6R=T>7!E
M)UT@/2!61E,Z.G-T<G1O;&]W97(H)&YA;65;8V]U;G0H)&YA;64I("T@,5TI
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+R\@1FEL=&5R:6YG+@H@("`@("`@
M("`@("!I9B`H)'1H:7,M/E]F:6QT97)-871C:"@D9FEL=&5R+"`D9FEL95LG
M;F%M92==*2D@>PH@("`@("`@("`@("`@("`@=6YS970H)&9I;&4I.PH@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*"1D:7)O;FQY("8F("1F:6QE6R=T>7!E)UT@(3T]("<J*F1I<B<I
M('L*("`@("`@("`@("`@("`@('5N<V5T*"1F:6QE*3L*("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D9FEL
M97-;)&9I;&5;)VYA;64G75T@/2`D9FEL93L*("`@("`@("`@("`@=6YS970H
M)&9I;&4I.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1O;&1D:7(I
M*2!["B`@("`@("`@("`@("1R97,@/2`D=&AI<RT^7W-E=%!A=&@H)&]L9&1I
M<BD["B`@("`@("`@("`@(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D9FEL97,["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&$@<V]R=&5D(&QI<W0@;V8@9F]L9&5R<R!I
M;B!T:&4@<W!E8VEF:65D(&1I<F5C=&]R>2X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@;V8@=&AE(&1I<F5C
M=&]R>2!T;R!G970@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@9&ER96-T;W)Y(&QI<W0@9F]R+@H@("`@("H@0'!A<F%M(&UI>&5D
M("1F:6QT97(@("`@("`@($AA<V@@;V8@:71E;7,@=&\@9FEL=&5R(&)A<V5D
M(&]N(&9O;&1E<FQI<W0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&]T9F]L
M9&5R<R`@26YC;'5D92!D;W1F;VQD97)S/PH@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@($9O;&1E<B!L:7-T(&]N('-U8V-E<W,@;W(@82!014%27T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L
M:7-T1F]L9&5R<R@D<&%T:"`]("<G+"`D9FEL=&5R(#T@;G5L;"P@)&1O=&9O
M;&1E<G,@/2!T<G5E*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C
M;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@
M("`@("`@)&9O;&1E<G,@/2!A<G)A>2@I.PH@("`@("`@("1F;VQD97(@/2!A
M<G)A>2@I.PH*("`@("`@("`D9F]L9&5R3&ES="`]("1T:&ES+3YL:7-T1F]L
M9&5R*"1P871H+"!N=6QL+"`D9&]T9F]L9&5R<RP@=')U92D["B`@("`@("`@
M:68@*&ES7V$H)&9O;&1E<DQI<W0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1F;VQD97),:7-T.PH@("`@("`@('T*"B`@("`@("`@
M)&9O;&1E<ELG=F%L)UT@/2`D=&AI<RT^7W!A<F5N=$1I<B@D<&%T:"D["B`@
M("`@("`@)&9O;&1E<ELG86)B<F5V)UT@/2`G+BXG.PH@("`@("`@("1F;VQD
M97);)VQA8F5L)UT@/2`G+BXG.PH*("`@("`@("`D9F]L9&5R<ULD9F]L9&5R
M6R=V86PG75T@/2`D9F]L9&5R.PH*("`@("`@("!F;W)E86-H("@D9F]L9&5R
M3&ES="!A<R`D9FEL97,I('L*("`@("`@("`@("`@)&9O;&1E<ELG=F%L)UT@
M/2`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1F:6QE<ULG;F%M92==*3L*("`@
M("`@("`@("`@)&9O;&1E<ELG86)B<F5V)UT@/2`D9FEL97-;)VYA;64G73L*
M("`@("`@("`@("`@)&9O;&1E<ELG;&%B96PG72`]("1F;VQD97);)W9A;"==
M.PH*("`@("`@("`@("`@)&9O;&1E<G-;)&9O;&1E<ELG=F%L)UU=(#T@)&9O
M;&1E<CL*("`@("`@("!]"@H@("`@("`@(&MS;W)T*"1F;VQD97)S*3L*("`@
M("`@("!R971U<FX@)&9O;&1E<G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M;W!I97,@82!F:6QE('1H<F]U9V@@=&AE(&)A8VME;F0N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@;V8@=&AE(&]R:6=I
M;F%L(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@;F%M
M92!O9B!T:&4@;W)I9VEN86P@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@
M)&1E<W0@(%1H92!N86UE(&]F('1H92!D97-T:6YA=&EO;B!D:7)E8W1O<GDN
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S
M(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@8V]P>2@D<&%T:"P@)&YA;64L("1D97-T*0H@("`@>PH@
M("`@("`@("1O<FEG(#T@)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92D[
M"B`@("`@("`@:68@*'!R96=?;6%T8V@H)WQ>)R`N('!R96=?<75O=&4H)&]R
M:6<I("X@)R\_)'PG+"`D9&5S="DI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B0V%N;F]T(&-O<'D@9FEL92AS*2`M('-O=7)C
M92!A;F0@9&5S=&EN871I;VX@87)E('1H92!S86UE+B(I*3L*("`@("`@("!]
M"@H@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@
M:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@)&9I;&5#:&5C:R`]
M("1T:&ES+3YL:7-T1F]L9&5R*"1D97-T+"!N=6QL+"!T<G5E*3L*("`@("`@
M("!I9B`H:7-?82@D9FEL94-H96-K+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D9FEL94-H96-K.PH@("`@("`@('T*("`@("`@("!F
M;W)E86-H("@D9FEL94-H96-K(&%S("1F:6QE*2!["B`@("`@("`@("`@(&EF
M("@D9FEL95LG;F%M92==(#T]("1N86UE*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(B5S(&%L<F5A9'D@
M97AI<W1S+B(I+"`D=&AI<RT^7V=E=%!A=&@H)&1E<W0L("1N86UE*2DI.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D:7-$:7(@/2!F86QS
M93L*("`@("`@("`D9&ER0VAE8VL@/2`D=&AI<RT^;&ES=$9O;&1E<B@D<&%T
M:"P@;G5L;"P@9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1D:7)#:&5C:RP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&1I<D-H96-K
M.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D9&ER0VAE8VL@87,@)&9I
M;&4I('L*("`@("`@("`@("`@:68@*"1F:6QE6R=N86UE)UT@/3T@)&YA;64@
M)B8@)&9I;&5;)W1Y<&4G72`]/2`G*BID:7(G*2!["B`@("`@("`@("`@("`@
M("`D:7-$:7(@/2!T<G5E.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D:7-$:7(I('L*("`@
M("`@("`@("`@)')E<W5L="`]("1T:&ES+3YC<F5A=&5&;VQD97(H)&1E<W0L
M("1N86UE*3L*"B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D9FEL95]L:7-T(#T@)'1H:7,M
M/FQI<W1&;VQD97(H)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92DI.PH@
M("`@("`@("`@("!F;W)E86-H("@D9FEL95]L:7-T(&%S("1F:6QE*2!["B`@
M("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F-O<'DH)'1H:7,M/E]G
M9710871H*"1P871H+"`D;F%M92DL("1F:6QE6R=N86UE)UTL("1T:&ES+3Y?
M9V5T4&%T:"@D9&5S="P@)&YA;64I*3L*("`@("`@("`@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T;7!&:6QE
M(#T@)'1H:7,M/E]G971496UP1FEL92@I.PH@("`@("`@("`@("`D9F5T8V@@
M/2!`9G1P7V=E="@D=&AI<RT^7W-T<F5A;2P@)'1M<$9I;&4L("1O<FEG+"!&
M5%!?0DE.05)9*3L*("`@("`@("`@("`@:68@*"$D9F5T8V@I('L*("`@("`@
M("`@("`@("`@('5N;&EN:R@D=&UP1FEL92D["B`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D9A:6QE9"!T;R!C
M;W!Y(&9R;VT@7"(E<UPB+B(I+"`D;W)I9RDI.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("!I9B`H(4!F='!?<'5T*"1T:&ES+3Y?<W1R96%M+"`D=&AI
M<RT^7V=E=%!A=&@H)&1E<W0L("1N86UE*2P@)'1M<$9I;&4L($944%]"24Y!
M4EDI*2!["B`@("`@("`@("`@("`@("!U;FQI;FLH)'1M<$9I;&4I.PH@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?
M*")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(BDL("1T:&ES+3Y?9V5T4&%T
M:"@D9&5S="P@)&YA;64I*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M('5N;&EN:R@D=&UP1FEL92D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($UO=F5S(&$@9FEL92!T:')O
M=6=H('1H92!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'!A=&@@(%1H92!P871H(&]F('1H92!O<FEG:6YA;"!F:6QE+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&YA;64@;V8@=&AE(&]R:6=I;F%L
M(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D97-T("!4:&4@9&5S=&EN
M871I;VX@9FEL92!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO=F4H)'!A=&@L("1N86UE
M+"`D9&5S="D*("`@('L*("`@("`@("`D;W)I9R`]("1T:&ES+3Y?9V5T4&%T
M:"@D<&%T:"P@)&YA;64I.PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"=\7B<@
M+B!P<F5G7W%U;W1E*"1O<FEG*2`N("<O/R1\)RP@)&1E<W0I*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-A;FYO="!M;W9E
M(&9I;&4H<RD@+2!D97-T:6YA=&EO;B!I<R!W:71H:6X@<V]U<F-E+B(I*3L*
M("`@("`@("!]"@H@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D[
M"B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@)&9I
M;&5#:&5C:R`]("1T:&ES+3YL:7-T1F]L9&5R*"1D97-T+"!N=6QL+"!T<G5E
M*3L*("`@("`@("!F;W)E86-H("@D9FEL94-H96-K(&%S("1F:6QE*2!["B`@
M("`@("`@("`@(&EF("@D9FEL95LG;F%M92==(#T]("1N86UE*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H
M(B5S(&%L<F5A9'D@97AI<W1S+B(I+"`D=&AI<RT^7V=E=%!A=&@H)&1E<W0L
M("1N86UE*2DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I
M9B`H(4!F='!?<F5N86UE*"1T:&ES+3Y?<W1R96%M+"`D;W)I9RP@)'1H:7,M
M/E]G9710871H*"1D97-T+"`D;F%M92DI*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B1F%I;&5D('1O(&UO=F4@
M=&\@7"(E<UPB+B(I+"`D=&AI<RT^7V=E=%!A=&@H)&1E<W0L("1N86UE*2DI
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!C=7)R96YT('=O<FMI;F<@9&ER96-T
M;W)Y(&]N('1H92!&5%`@<V5R=F5R+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@8W5R<F5N="!W;W)K:6YG(&1I<F5C=&]R>2X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T0W5R<F5N=$1I<F5C=&]R>2@I"B`@("!["B`@
M("`@("`@:68@*&ES7V$H)&-O;FYE8W1E9"`]("1T:&ES+3Y?8V]N;F5C="@I
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;F5C
M=&5D.PH@("`@("`@('T*("`@("`@("!R971U<FX@9G1P7W!W9"@D=&AI<RT^
M7W-T<F5A;2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&%N9V5S('1H92!C
M=7)R96YT(&1I<F5C=&]R>2!O;B!T:&4@<V5R=F5R+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'!A=&@@(%1H92!P871H('1O(&-H86YG92!T;RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,L(&]R(&$@4$5!4E]%<G)O
M<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5T4&%T:"@D
M<&%T:"D*("`@('L*("`@("`@("!I9B`H(4!F='!?8VAD:7(H)'1H:7,M/E]S
M=')E86TL("1P871H*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(BDL
M("1P871H*2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@9G5L;"!P871H(&]F(&%N
M(&ET96TN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE(&1I<F5C=&]R>2!O9B!T
M:&4@:71E;2X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE
M(&]F('1H92!I=&5M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($9U
M;&P@<&%T:"!T;R!T:&4@9FEL92!W:&5N("1P871H(&ES(&YO="!E;7!T>2!A
M;F0@:G5S=`H@("`@("H@("`@("`@("`@("`@("`@)&YA;64@=VAE;B!N;W0@
M<V5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T4&%T:"@D<&%T:"P@)&YA
M;64I"B`@("!["B`@("`@("`@:68@*"1P871H("$]/2`G)RD@>PH@("`@("`@
M("`@("!R971U<FX@*"1P871H("X@)R\G("X@)&YA;64I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@*"1N86UE*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE('!A<F5N="!D:7)E8W1O<GD@;V8@=&AE('-P96-I9FEE
M9"!P871H+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H('1O(&=E="!T
M:&4@<&%R96YT(&]F+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@<&%R96YT(&1I<F5C=&]R>2`H<W1R:6YG*2!O;B!S=6-C97-S(&]R(&$@
M4$5!4E]%<G)O<@H@("`@("H@("`@("`@("`@("`@("`@(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R96YT1&ER*"1P871H
M*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@
M("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@)&]L9&1I
M<B`]("1T:&ES+3YG971#=7)R96YT1&ER96-T;W)Y*"D["B`@("`@("`@0&9T
M<%]C9'5P*"1T:&ES+3Y?<W1R96%M*3L*"B`@("`@("`@)'!A<F5N="`]("1T
M:&ES+3YG971#=7)R96YT1&ER96-T;W)Y*"D["B`@("`@("`@)'1H:7,M/E]S
M9710871H*"1O;&1D:7(I.PH*("`@("`@("!I9B`H(21P87)E;G0I('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O
M(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB*2D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'!A<F5N=#L*("`@('T*"B`@("`O*BH*("`@("`J
M($%T=&5M<'1S('1O(&]P96X@82!C;VYN96-T:6]N('1O('1H92!&5%`@<V5R
M=F5R+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]C;VYN96-T*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]S=')E86T@
M/3T](&9A;'-E*2!["B`@("`@("`@("`@(&EF("@A97AT96YS:6]N7VQO861E
M9"@G9G1P)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N
M(BDI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y
M*"1T:&ES+3Y?<&%R86US*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R($944"!61E,N(BDI.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`D<F5Q=6ER960@/2!A<G)A>2@G:&]S='-P96,G+"`G=7-E
M<FYA;64G+"`G<&%S<W=O<F0G*3L*("`@("`@("`@("`@9F]R96%C:"`H)')E
M<75I<F5D(&%S("1V86PI('L*("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]P87)A;7-;)'9A;%TI*2!["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")297%U:7)E9"!<
M(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB*2P@
M)'9A;"DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`O*B!#;VYN96-T('1O('1H92!F='`@<V5R=F5R('5S:6YG('1H
M92!S=7!P;&EE9"!P87)A;65T97)S+B`J+PH@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1T:&ES+3Y?<&%R86US6R=S<VPG72DI('L*("`@("`@("`@("`@("`@
M(&EF("AF=6YC=&EO;E]E>&ES=',H)V9T<%]S<VQ?8V]N;F5C="<I*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S=')E86T@/2!`9G1P7W-S;%]C
M;VYN96-T*"1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==+"`D=&AI<RT^7W!A
M<F%M<ULG<&]R="==*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA
M8FQE('1O(&-O;FYE8W0@=VET:"!34TPN(BDI.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]S=')E86T@/2!`9G1P7V-O;FYE8W0H)'1H:7,M/E]P87)A;7-;)VAO<W1S
M<&5C)UTL("1T:&ES+3Y?<&%R86US6R=P;W)T)UTI.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]S=')E86TI('L*("`@("`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O;FYE8W1I;VX@
M=&\@1E10('-E<G9E<B!F86EL960N(BDI.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D8V]N;F5C=&5D(#T@0&9T<%]L;V=I;B@D=&AI<RT^7W-T<F5A
M;2P@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UTL("1T:&ES+3Y?<&%R86US
M6R=P87-S=V]R9"==*3L*("`@("`@("`@("`@:68@*"$D8V]N;F5C=&5D*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V1I<V-O;FYE8W0H*3L*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D%U=&AE;G1I
M8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(I*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG<&%S
M=B==*2D@>PH@("`@("`@("`@("`@("`@0&9T<%]P87-V*"1T:&ES+3Y?<W1R
M96%M+"!T<G5E*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%E
M;7!T>2@D=&AI<RT^7W!A<F%M<ULG=&EM96]U="==*2D@>PH@("`@("`@("`@
M("`@("`@9G1P7W-E=%]O<'1I;VXH)'1H:7,M/E]S=')E86TL($944%]424U%
M3U547U-%0RP@)'1H:7,M/E]P87)A;7-;)W1I;65O=70G72D["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1&ES8V]N;F5C=',@9G)O;2!T:&4@1E10('-E<G9E
M<B!A;F0@8VQE86YS('5P('1H92!C;VYN96-T:6]N+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?9&ES8V]N
M;F5C="@I"B`@("!["B`@("`@("`@0&9T<%]Q=6ET*"1T:&ES+3Y?<W1R96%M
M*3L*("`@("`@("`D=&AI<RT^7W-T<F5A;2`](&9A;'-E.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U9&4R]'0RYP:'``````````````
M````````````````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C8V-@`Q,#4Q
M-30S,S<T-0`P,C`P-S<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J($-L87-S(&9O<B!P<F]V:61I;F<@
M9V%R8F%G92!C;VQL96-T:6]N(&9O<B!A;GD@5D93(&EN<W1A;F-E+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]61E,O5D93+T=#+G!H<"QV(#$N-"XQ,BXX
M(#(P,#8O,#$O,#$@,C$Z,C@Z-#(@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`S+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN
M8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC
M:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@
M*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@5D93"B`J+PIC;&%S
M<R!61E-?1T,@>PH*("`@("\J*@H@("`@("H@1V%R8F%G92!C;VQL96-T(&9I
M;&5S(&EN('1H92!61E,@<W1O<F%G92!S>7-T96TN"B`@("`@*@H@("`@("H@
M0'!A<F%M(%9&4R`F)'9F<R`@("`@(%1H92!61E,@;V)J96-T('1O('!E<F9O
M<FT@9V%R8F%G92!C;VQL96-T:6]N(&]N+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<&%T:"`@(%1H92!61E,@<&%T:"!T;R!C;&5A;BX*("`@("`J($!P87)A
M;2!I;G1E9V5R("1S96-S("!4:&4@;6EN:6UU;2!A;6]U;G0@;V8@=&EM92`H
M:6X@<V5C;VYD<RD@<F5Q=6ER960*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!B969O<F4@82!F:6QE(&ES(')E;6]V960N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=C*"8D=F9S+"`D<&%T:"P@)'-E8W,@/2`S-#4V,#`I"B`@("![
M"B`@("`@("`@+RH@02`Q)2!C:&%N8V4@=V4@=VEL;"!R=6X@9V%R8F%G92!C
M;VQL96-T:6]N(&1U<FEN9R!A(&-A;&PN("HO"B`@("`@("`@:68@*')A;F0H
M,"P@.3DI(#T](#`I('L*("`@("`@("`@("`@+RH@36%K92!S=7)E(&-L96%N
M:6YG(&ES(&1O;F4@<F5C=7)S:79E;'DN("HO"B`@("`@("`@("`@("1F:6QE
M<R`]("1V9G,M/FQI<W1&;VQD97(H)'!A=&@L(&YU;&PL('1R=64L(&9A;'-E
M+"!T<G5E*3L*("`@("`@("`@("`@:68@*"%I<U]A*"1F:6QE<RP@)U!%05)?
M17)R;W(G*2`F)B!I<U]A<G)A>2@D9FEL97,I*2!["B`@("`@("`@("`@("`@
M("`D;6]D=&EM92`]('1I;64H*2`M("1S96-S.PH@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)&9I;&5S(&%S("1V86PI('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H)'9A;%LG9&%T92==(#P@)&UO9'1I;64I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'9F<RT^9&5L971E1FEL92@D<&%T:"P@)'9A;%LG;F%M
M92==*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O5D93+TE33U=R:71E<B\`````````````````````````````````````
M`````````````````````````````````````#`P,#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S0U`#`R,#<Q,@`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP
M````````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0W,#<`,3`U,34T,S,W
M-#4`,#(S,3`V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"@HO*BH*("H@1')I=F5R(&9O<B!U<VEN9R!M:VES;V9S
M(&9O<B!C<F5A=&EN9R!)4T\@:6UA9V5S+@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<"QV(#$N
M,2XX+C4@,C`P-B\P,2\P,2`R,3HR.#HT,R!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#0M,C`P-B!#<F]N;W-Y<RP@3$Q#(#QH='1P.B\O=W=W+F-R
M;VYO<WES+F-O;2\^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*87-O
M;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@*B!`<&%C:V%G
M92!61E-?25-/"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B\*8VQA<W,@5D93
M7TE33U=R:71E<E]M:VES;V9S(&5X=&5N9',@5D937TE33U=R:71E<B!["@H@
M("`@9G5N8W1I;VX@<')O8V5S<R@I"B`@("!["B`@("`@("`@<F5Q=6ER95]O
M;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]296%L26YP=713=')A=&5G>2YP
M:'`G.PH@("`@("`@("1I;G!U=%-T<F%T96=Y(#T@)E9&4U])4T]7<FET97)?
M4F5A;$EN<'5T4W1R871E9WDZ.F9A8W1O<GDH)'1H:7,M/E]S;W5R8V569G,L
M("1T:&ES+3Y?<&%R86US6R=S;W5R8V52;V]T)UTI.PH@("`@("`@(&EF("AI
M<U]A*"1I;G!U=%-T<F%T96=Y+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D:6YP=713=')A=&5G>3L*("`@("`@("!]"@H@("`@("`@
M(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O4F5A;$]U='!U
M=%-T<F%T96=Y+G!H<"<["B`@("`@("`@)&]U='!U=%-T<F%T96=Y(#T@)E9&
M4U])4T]7<FET97)?4F5A;$]U='!U=%-T<F%T96=Y.CIF86-T;W)Y*"1T:&ES
M+3Y?=&%R9V5T5F9S+"`D=&AI<RT^7W!A<F%M<ULG=&%R9V5T1FEL92==*3L*
M("`@("`@("!I9B`H:7-?82@D;W5T<'5T4W1R871E9WDL("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1O=71P=713=')A=&5G>3L*("`@
M("`@("!]"@H@("`@("`@("1C;60@/2!S<')I;G1F*"=M:VES;V9S("UQ=6EE
M="`M<B`M2B`M;R`E<R`E<R`^+V1E=B]N=6QL)RP*("`@("`@("`@("`@("`@
M("`@("`@("!E<V-A<&5S:&5L;&%R9R@D;W5T<'5T4W1R871E9WDM/F=E=%)E
M86Q&:6QE;F%M92@I*2P*("`@("`@("`@("`@("`@("`@("`@("!E<V-A<&5S
M:&5L;&%R9R@D:6YP=713=')A=&5G>2T^9V5T4F5A;%!A=&@H*2DI.PH@("`@
M("`@("1R97,@/2!S>7-T96TH)&-M9"P@)&5C*3L*"B`@("`@("`@+RH@0V]U
M;&0@8F4@82!L;W0@;V8@<W!A8V4@=7-E9"X@($=I=F4@8F]T:"!A(&-H86YC
M92!T;R!C;&5A;B!U<"!E=F5N"B`@("`@("`@("H@:68@;VYE(&5R<F]R<R!O
M=70N("HO"B`@("`@("`@)&9I;E)E<S$@/2`D:6YP=713=')A=&5G>2T^9FEN
M:7-H960H*3L*("`@("`@("`D9FEN4F5S,B`]("1O=71P=713=')A=&5G>2T^
M9FEN:7-H960H*3L*("`@("`@("!I9B`H:7-?82@D9FEN4F5S,2P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&9I;E)E<S$["B`@("`@
M("`@?0H@("`@("`@(&EF("AI<U]A*"1F:6Y297,R+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D9FEN4F5S,CL*("`@("`@("!]"@H@
M("`@("`@(&EF("@D<F5S(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@<G5N("=M:VES;V9S
M)RXB*2D["B`@("`@("`@?0H@("`@("`@(&EF("@D96,@(3T@,"D@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(FUK
M:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(I+"`D96,I
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F4@
M:68@=V4@8V%N('5S92!T:&ES(&1R:79E<B!T;R!M86ME(&EM86=E<PH@("`@
M("H*("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@(%=H971H97(@=V4@8V%N('5S92!T:&ES('-T<F%T96=Y(&9O<B!M86MI
M;F<@25-/(&EM86=E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<W1R871E9WE!
M=F%I;&%B;&4H*0H@("`@>PH@("`@("`@("\J($-H96-K(&EF('=E(&-A;B!F
M:6YD(&%N9"!E>&5C=71E('1H92!@;6MI<V]F<R<@8V]M;6%N9"X@*B\*("`@
M("`@("`D<F5S(#T@<WES=&5M*")M:VES;V9S("UH96QP(#XO9&5V+VYU;&P@
M,CXF,2(L("1E8RD["B`@("`@("`@:68@*"1R97,@/3T](&9A;'-E*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@:68@
M*"1E8R`A/2`P*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@I]"@H`````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]61E,O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+P``````````````````````````````````
M````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`U,34T,S,W-#4`,#(T,S0P`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'``
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`Q,34Q-@`Q,#4Q-30S,S<T-0`P,C8P,C<`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*"B\J
M*@H@*B!3=')A=&5G>2!F;W(@8V]P>6EN9R!I;G!U="!T<F5E(&]U="!O9B!A
M(%9&4PH@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<"QV(#$N,2XX+C4@
M,C`P-B\P,2\P,2`R,3HR.#HT-"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#0M,C`P-B!#<F]N;W-Y<RP@3$Q#(#QH='1P.B\O=W=W+F-R;VYO<WES
M+F-O;2\^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*87-O;B!-+B!&
M96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@*B!`<&%C:V%G92!61E-?
M25-/"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B\*8VQA<W,@5D937TE33U=R
M:71E<E]296%L26YP=713=')A=&5G>5]C;W!Y(&5X=&5N9',@5D937TE33U=R
M:71E<E]296%L26YP=713=')A=&5G>2!["@H@("`@=F%R("1?=&5M<%!A=&@@
M/2!N=6QL.PH*("`@(&9U;F-T:6]N(&=E=%)E86Q0871H*"D*("`@('L*("`@
M("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7W1E;7!0871H*2D@>PH@("`@("`@
M("`@("`D=&UP7VQO8V%T:6]N<R`](&%R<F%Y*"<O=&UP)RP@)R]V87(O=&UP
M)RP@)V,Z7%=55&5M<"<L("=C.EQT96UP)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G8SI<=VEN9&]W<UQT96UP)RP@)V,Z7'=I;FYT
M7'1E;7`G*3L*"B`@("`@("`@("`@("\J($9I<G-T+"!T<GD@4$A0)W,@=7!L
M;V%D7W1M<%]D:7(@9&ER96-T:79E+B`J+PH@("`@("`@("`@("`D=&UP(#T@
M:6YI7V=E="@G=7!L;V%D7W1M<%]D:7(G*3L*"B`@("`@("`@("`@("\J($]T
M:&5R=VES92P@=')Y('1O(&1E=&5R;6EN92!T:&4@5$U01$E2(&5N=FER;VYM
M96YT"B`@("`@("`@("`@("`J('9A<FEA8FQE+B`J+PH@("`@("`@("`@("!I
M9B`H96UP='DH)'1M<"DI('L*("`@("`@("`@("`@("`@("1T;7`@/2!G971E
M;G8H)U1-4$1)4B<I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!)
M9B!W92!S=&EL;"!C86YN;W0@9&5T97)M:6YE(&$@=F%L=64L('1H96X@8WEC
M;&4@=&AR;W5G:"!A"B`@("`@("`@("`@("`J(&QI<W0@;V8@<')E<V5T('!O
M<W-I8FEL:71I97,N("HO"B`@("`@("`@("`@('=H:6QE("AE;7!T>2@D=&UP
M*2`F)B!C;W5N="@D=&UP7VQO8V%T:6]N<RDI('L*("`@("`@("`@("`@("`@
M("1T;7!?8VAE8VL@/2!A<G)A>5]S:&EF="@D=&UP7VQO8V%T:6]N<RD["B`@
M("`@("`@("`@("`@("!I9B`H0&ES7V1I<B@D=&UP7V-H96-K*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1T;7`@/2`D=&UP7V-H96-K.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H96UP='DH
M)'1M<"DI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB*2D[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?=&5M<%!A=&@@
M/2!T96UP;F%M*"1T;7`L("=I<V]D)RD["B`@("`@("`@("`@($!U;FQI;FLH
M)'1H:7,M/E]T96UP4&%T:"D["@H@("`@("`@("`@("`D<F5S(#T@)'1H:7,M
M/E]C;W!Y5&]496UP4&%T:"@I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E
M<SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?=&5M<%!A=&@["B`@("!]"@H@("`@9G5N8W1I;VX@9FEN:7-H960H
M*0H@("`@>PH@("`@("`@(')E='5R;B!61E-?25-/5W)I=&5R7U)E86Q);G!U
M=%-T<F%T96=Y7V-O<'DZ.E]R96UO=F5296-U<G-I=F4H)'1H:7,M/E]T96UP
M4&%T:"D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;6]V95)E8W5R<VEV92@D
M<&%T:"D*("`@('L*("`@("`@("`D9&@@/2!`;W!E;F1I<B@D<&%T:"D["B`@
M("`@("`@:68@*"%I<U]R97-O=7)C92@D9&@I*2!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B0V]U;&0@;F]T(&]P
M96X@9&ER96-T;W)Y(%PB)7-<(BXB*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<&%T:"DI.PH@("`@("`@('T*("`@
M("`@("!W:&EL92`H*"1E;G0@/2!R96%D9&ER*"1D:"DI("$]/2!F86QS92D@
M>PH@("`@("`@("`@("!I9B`H)&5N="`]/2`G+B<@?'P@)&5N="`]/2`G+BXG
M*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)&9U;&P@/2!S<')I;G1F*"<E<R\E<R<L("1P871H+"`D
M96YT*3L*("`@("`@("`@("`@:68@*&ES7V1I<B@D9G5L;"DI('L*("`@("`@
M("`@("`@("`@("1R97,@/2!61E-?25-/5W)I=&5R7U)E86Q);G!U=%-T<F%T
M96=Y7V-O<'DZ.E]R96UO=F5296-U<G-I=F4H)&9U;&PI.PH@("`@("`@("`@
M("`@("`@:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:68@*"%`=6YL
M:6YK*"1F=6QL*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*'-P<FEN=&8H7R@B0V]U;&0@;F]T('5N;&EN:R!<(B5S
M7"(N(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9G5L;"DI.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&-L;W-E9&ER*"1D:"D["@H@
M("`@("`@(&EF("@A0')M9&ER*"1P871H*2D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-O=6QD(&YO="!R;61I
M<B!<(B5S7"(N(BDL("1F=6QL*2D["B`@("`@("`@?0H@("`@?0H*("`@(&9U
M;F-T:6]N(%]C;W!Y5&]496UP4&%T:"@I"B`@("!["B`@("`@("`@)&1I<E-T
M86-K(#T@87)R87DH)R<I.PH*("`@("`@("!W:&EL92`H8V]U;G0H)&1I<E-T
M86-K*2`^(#`I('L*("`@("`@("`@("`@)&1I<B`](&%R<F%Y7W-H:69T*"1D
M:7)3=&%C:RD["B`@("`@("`@("`@(&EF("AE;7!T>2@D9&ER*2D@>PH@("`@
M("`@("`@("`@("`@)'1A<F=E="`]("1T:&ES+3Y?=&5M<%!A=&@["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&%R9V5T(#T@<W!R
M:6YT9B@G)7,O)7,G+"`D=&AI<RT^7W1E;7!0871H+"`D9&ER*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H(4!M:V1I<B@D=&%R9V5T*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT
M9BA?*")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(I+"`D=&%R9V5T*2D["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1S;W5R8V50871H(#T@)'1H:7,M
M/E]S;W5R8V52;V]T.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1D:7(I*2![
M"B`@("`@("`@("`@("`@("`D<V]U<F-E4&%T:"`N/2`G+R<@+B`D9&ER.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D;&ES="`]("1T:&ES+3Y?<V]U
M<F-E5F9S+3YL:7-T1F]L9&5R*"1S;W5R8V50871H+"!N=6QL+"!T<G5E*3L*
M("`@("`@("`@("`@:68@*&ES7V$H)&QI<W0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D;&ES=#L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@9F]R96%C:"`H)&QI<W0@87,@)&5N=')Y*2!["B`@("`@
M("`@("`@("`@("!I9B`H)&5N=')Y6R=T>7!E)UT@/3T@)RHJ9&ER)RD@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D9&ER*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D9&ER4W1A8VM;72`]("1E;G1R>5LG;F%M92==
M.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1D:7)3=&%C:UM=(#T@<W!R:6YT9B@G)7,O)7,G+"`D9&ER
M+"`D96YT<GE;)VYA;64G72D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D9&%T
M82`]("1T:&ES+3Y?<V]U<F-E5F9S+3YR96%D*"1S;W5R8V50871H+"`D96YT
M<GE;)VYA;64G72D["B`@("`@("`@("`@("`@("`@("`@:68@*&ES7V$H)&1A
M=&$L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1D871A.PH@("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("`@("`@)'1A<F=E=$9I;&4@/2!S<')I;G1F*"<E<R\E<R<L("1T
M87)G970L("1E;G1R>5LG;F%M92==*3L*("`@("`@("`@("`@("`@("`@("`D
M9F@@/2!`9F]P96XH)'1A<F=E=$9I;&4L("=W)RD["B`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<U]R97-O=7)C92@D9F@I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B
M0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(I+"`D=&%R9V5T
M1FEL92DI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!I9B`H9G=R:71E*"1F:"P@)&1A=&$I("$]('-T<FQE;B@D9&%T82DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H<W!R:6YT9BA?*")%<G)O<B!W<FET:6YG(%PB)7-<(BXB*2P@)'1A
M<F=E=$9I;&4I*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@9F-L;W-E*"1F:"D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V1I
M<F5C="YP:'``````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$S-#8`,3`U,34T,S,W-#4`,#(V,S(W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@HO*BH*("H@4W1R871E9WD@9F]R(&1I<F5C=&QY(&%C8V5S<VEN9R!I
M;G!U="!T<F5E(&EN(&$@)V9I;&4G(%9&4PH@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]D:7)E8W0N<&AP+'8@,2XQ+C@N-"`R,#`V+S`Q+S`Q(#(Q.C(X.C0T(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($-R;VYO<WES+"!,
M3$,@/&AT='`Z+R]W=W<N8W)O;F]S>7,N8V]M+SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($IA<V]N($TN($9E;&EC92`\:F9E;&EC94!C<F]N;W-Y
M<RYC;VT^"B`J($!P86-K86=E(%9&4U])4T\*("H@0'-I;F-E("`@2&]R9&4@
M,RXP"B`J+PIC;&%S<R!61E-?25-/5W)I=&5R7U)E86Q);G!U=%-T<F%T96=Y
M7V1I<F5C="!E>'1E;F1S(%9&4U])4T]7<FET97)?4F5A;$EN<'5T4W1R871E
M9WD@>PH*("`@(&9U;F-T:6]N(&=E=%)E86Q0871H*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]S;W5R8V569G,M/E]G971.871I=F50871H*"1T
M:&ES+3Y?<V]U<F-E4F]O="D["B`@("!]"@H@("`@9G5N8W1I;VX@9FEN:7-H
M960H*0H@("`@>PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+G!H<```````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0V-S<`,3`U,34T,S,W-#4`
M,#(U,#8W`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@HO*BH*("H@16YC87!S=6QA=&4@<W1R871E9VEE<R!F;W(@
M9V5T=&EN9R!A(')E86PL(&QO8V%L(&9I;&5S>7-T96T@<W1R=6-T=7)E(&9R
M;VT*("H@82!61E,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<"QV(#$N,2XX
M+C<@,C`P-B\P,2\P,2`R,3HR.#HT,R!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#0M,C`P-B!#<F]N;W-Y<RP@3$Q#(#QH='1P.B\O=W=W+F-R;VYO
M<WES+F-O;2\^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*87-O;B!-
M+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@*B!`<&%C:V%G92!6
M1E-?25-/"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B\*8VQA<W,@5D937TE3
M3U=R:71E<E]296%L26YP=713=')A=&5G>2!["@H@("`@+RHJ"B`@("`@*B!!
M(')E9F5R96YC92!T;R!T:&4@<V]U<F-E(%9&4R!W92!W86YT('1O(')E860N
M"B`@("`@*@H@("`@("H@0'9A<B!61E,*("`@("`J+PH@("`@=F%R("1?<V]U
M<F-E5F9S(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%1H92!R;V]T(&1I<F5C
M=&]R>2!W:71H:6X@=&AE('-O=7)C92!61E,*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]S;W5R8V52;V]T.PH*("`@(&9U
M;F-T:6]N(%9&4U])4T]7<FET97)?4F5A;$EN<'5T4W1R871E9WDH)B1S;W5R
M8V569G,L("1S;W5R8V52;V]T*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V]U
M<F-E5F9S(#T@)B1S;W5R8V569G,["B`@("`@("`@)'1H:7,M/E]S;W5R8V52
M;V]T(#T@)B1S;W5R8V52;V]T.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T
M(&$@<F5A;"!P871H('1O('1H92!I;G!U="!T<F5E+@H@("`@("H*("`@("`J
M($!A8G-T<F%C=`H@("`@("H@0')E='5R;B!M:7AE9"`@("!!('-T<FEN9R!W
M:71H('1H92!R96%L('!A=&@L(&]R(%!%05)?17)R;W(@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F5A;%!A=&@H*0H@("`@>PH@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO="!I;7!L96UE;G1E
M9"XB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!);F1I8V%T92!W92!A<F4@
M9FEN:7-H960@=VET:"!T:&ES(&EN<'5T('-T<F%T96=Y+@H@("`@("H*("`@
M("`J($!A8G-T<F%C=`H@("`@("H@0')E='5R;B!M:7AE9"`@("`@("`@3G5L
M;"!O<B!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&9I;FES:&5D*"D*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*").;W0@:6UP;&5M96YT960N(BDI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1&5C:61E('=H:6-H('-T<F%T96=Y('1O('5S92!T;R!G970@
M82!R96%L($93(&%N9"!C<F5A=&4@:70N"B`@("`@*@H@("`@("H@0'-T871I
M8PH@("`@("H*("`@("`J($!P87)A;2!O8FIE8W0@)B1S;W5R8V569G,@("`@
M("`@(%1H92!61E,@=V4@=V%N="!T;R!R96%D(&9R;VTN"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1S;W5R8V52;V]T("`@("`@("!4:&4@<F]O="!D:7)E8W1O
M<GD@:6X@=&AA="!61E,N"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@($$@8V]N
M8W)E=&4@<W1R871E9WD@;W(@4$5!4E]%<G)O<B!I9B!N;R!S=')A=&5G>2!I
M<PH@("`@("H@("`@("`@("`@("`@("`@("!A=F%I;&%B;&4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&9A8W1O<GDH)B1S;W5R8V569G,L("1S;W5R8V52;V]T
M*0H@("`@>PH@("`@("`@(&EF("AS=')T;VQO=V5R*&=E=%]C;&%S<R@D<V]U
M<F-E5F9S*2D@/3T@)W9F<U]F:6QE)RD@>PH@("`@("`@("`@("`D;65T:&]D
M(#T@)V1I<F5C="<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&UE
M=&AO9"`]("=C;W!Y)SL*("`@("`@("!]"@H@("`@("`@($!I;F-L=61E7V]N
M8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+U)E86Q);G!U=%-T<F%T96=Y+R<@
M+B`D;65T:&]D("X*("`@("`@("`@("`@("`@("`@("`@("<N<&AP)SL*("`@
M("`@("`D8VQA<W,@/2`G5D937TE33U=R:71E<E]296%L26YP=713=')A=&5G
M>5\G("X@)&UE=&AO9#L*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@D8VQA
M<W,I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P
M<FEN=&8H7R@B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M
M971H;V0I*3L*("`@("`@("!]"@H@("`@("`@("1S=')A=&5G>2`]("9N97<@
M)&-L87-S*"1S;W5R8V569G,L("1S;W5R8V52;V]T*3L*("`@("`@("!R971U
M<FX@)'-T<F%T96=Y.PH@("`@?0H*?0H*````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]61E,O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2\`````````````````````````````````````
M````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`U,34T,S,W-#4`,#(T-30Q`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-#<V,0`Q,#4Q-30S,S<T-0`P,C8R,S0`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"B\J*@H@
M*B!3=')A=&5G>2!F;W(@=W)I=&EN9R!F:6QE('1O('1E;7!O<F%R>2!D:7)E
M8W1O<GDL('1H96X@8V]P>6EN9R!T;R!61E,N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]C;W!Y+G!H<"QV(#$N,2XX+C0@,C`P-B\P,2\P,2`R,3HR.#HT-"!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!#<F]N;W-Y<RP@
M3$Q#(#QH='1P.B\O=W=W+F-R;VYO<WES+F-O;2\^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!*87-O;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S
M>7,N8V]M/@H@*B!`<&%C:V%G92!61E-?25-/"B`J($!S:6YC92`@($AO<F1E
M(#,N,`H@*B\*8VQA<W,@5D937TE33U=R:71E<E]296%L3W5T<'5T4W1R871E
M9WE?8V]P>2!E>'1E;F1S(%9&4U])4T]7<FET97)?4F5A;$]U='!U=%-T<F%T
M96=Y('L*"B`@("!V87(@)%]T96UP1FEL96YA;64@/2!N=6QL.PH*("`@("\J
M*@H@("`@("H@1V5T(&$@<F5A;"!F:6QE;F%M92!T;R!W:&EC:"!W92!C86X@
M=W)I=&4N"B`@("`@*@H@("`@("H@26X@=&AI<R!I;7!L96UE;G1A=&EO;BP@
M=V4@8W)E871E(&%N9"!S=&]R92!A('1E;7!O<F%R>2!F:6QE;F%M92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T4F5A;$9I;&5N86UE*"D*("`@('L*("`@
M("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7W1E;7!&:6QE;F%M92DI('L*"B`@
M("`@("`@("`@("1T;7!?;&]C871I;VYS(#T@87)R87DH)R]T;7`G+"`G+W9A
M<B]T;7`G+"`G8SI<5U5496UP)RP@)V,Z7'1E;7`G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=C.EQW:6YD;W=S7'1E;7`G+"`G8SI<
M=VEN;G1<=&5M<"<I.PH*("`@("`@("`@("`@+RH@1FER<W0L('1R>2!02%`G
M<R!U<&QO861?=&UP7V1I<B!D:7)E8W1I=F4N("HO"B`@("`@("`@("`@("1T
M;7`@/2!I;FE?9V5T*"=U<&QO861?=&UP7V1I<B<I.PH*("`@("`@("`@("`@
M+RH@3W1H97)W:7-E+"!T<GD@=&\@9&5T97)M:6YE('1H92!435!$25(@96YV
M:7)O;FUE;G0*("`@("`@("`@("`@("H@=F%R:6%B;&4N("HO"B`@("`@("`@
M("`@(&EF("AE;7!T>2@D=&UP*2D@>PH@("`@("`@("`@("`@("`@)'1M<"`]
M(&=E=&5N=B@G5$U01$E2)RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("\J($EF('=E('-T:6QL(&-A;FYO="!D971E<FUI;F4@82!V86QU92P@=&AE
M;B!C>6-L92!T:')O=6=H(&$*("`@("`@("`@("`@("H@;&ES="!O9B!P<F5S
M970@<&]S<VEB:6QI=&EE<RX@*B\*("`@("`@("`@("`@=VAI;&4@*&5M<'1Y
M*"1T;7`I("8F(&-O=6YT*"1T;7!?;&]C871I;VYS*2D@>PH@("`@("`@("`@
M("`@("`@)'1M<%]C:&5C:R`](&%R<F%Y7W-H:69T*"1T;7!?;&]C871I;VYS
M*3L*("`@("`@("`@("`@("`@(&EF("A`:7-?9&ER*"1T;7!?8VAE8VLI*2![
M"B`@("`@("`@("`@("`@("`@("`@)'1M<"`]("1T;7!?8VAE8VL["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("AE
M;7!T>2@D=&UP*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H7R@B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y
M+B(I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]T96UP
M1FEL96YA;64@/2!T96UP;F%M*"1T;7`L("=I<V\G*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=&AI<RT^7W1E;7!&:6QE;F%M93L*("`@('T*"B`@
M("!F=6YC=&EO;B!F:6YI<VAE9"@I"B`@("!["B`@("`@("`@:68@*&5M<'1Y
M*"1T:&ES+3Y?=&5M<$9I;&5N86UE*2D@>PH@("`@("`@("`@("!R971U<FX[
M"B`@("`@("`@?0H@("`@("`@(&EF("@A9FEL95]E>&ES=',H)'1H:7,M/E]T
M96UP1FEL96YA;64I*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]
M"@H@("`@("`@(&EF("AP<F5G7VUA=&-H*"<A7B@N*BDO*%M>+UTJ*20A)RP@
M)'1H:7,M/E]T87)G971&:6QE+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@
M)&1I<B`]("1M871C:&5S6S%=.PH@("`@("`@("`@("`D9FEL92`]("1M871C
M:&5S6S)=.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1D:7(@/2`G
M)SL*("`@("`@("`@("`@)&9I;&4@/2`D=&AI<RT^7W1A<F=E=$9I;&4["B`@
M("`@("`@?0H*("`@("`@("`D<F5S(#T@)'1H:7,M/E]T87)G97169G,M/G=R
M:71E*"1D:7(L("1F:6QE+"`D=&AI<RT^7W1E;7!&:6QE;F%M92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1R=64I.PH@("`@
M("`@($!U;FQI;FLH)'1H:7,M/E]T96UP1FEL96YA;64I.PH@("`@("`@("1T
M:&ES+3Y?=&5M<$9I;&5N86UE(#T@;G5L;#L*("`@("`@("!R971U<FX@)')E
M<SL*("`@('T*"GT*"@```````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+V1I<F5C="YP:'`````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C4Q-``Q,#4Q-30S,S<T-0`P,C8U
M,C8`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"B\J*@H@*B!3=')A=&5G>2!F;W(@9&ER96-T;'D@=W)I=&EN9R!O
M=71P=70@9FEL92!T;R!61E,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E
M8W0N<&AP+'8@,2XQ+C@N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C0T(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($-R;VYO<WES+"!,3$,@/&AT
M='`Z+R]W=W<N8W)O;F]S>7,N8V]M+SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($IA<V]N($TN($9E;&EC92`\:F9E;&EC94!C<F]N;W-Y<RYC;VT^
M"B`J($!P86-K86=E(%9&4U])4T\*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J
M+PIC;&%S<R!61E-?25-/5W)I=&5R7U)E86Q/=71P=713=')A=&5G>5]D:7)E
M8W0@97AT96YD<R!61E-?25-/5W)I=&5R7U)E86Q/=71P=713=')A=&5G>2![
M"@H@("`@9G5N8W1I;VX@9V5T4F5A;$9I;&5N86UE*"D*("`@('L*("`@("`@
M("`O*B!3;R!W92!S:&]U;&1N)W0@8F4@86-C97-S:6YG(%]G971.871I=F50
M871H*"DN("!)9B!W92!H860@<F5A;`H@("`@("`@("`J(&%C8V5S<R!C;VYT
M<F]L+"!T:&%T('=O=6QD(&)E('!R;W1E8W1E9"!A;F0@=V4G9"!B92!A(&9R
M:65N9"P@87,*("`@("`@("`@*B!T:&%T(&ES('1H92!P;VEN="!O9B!T:&ES
M(&5X8V5R8VES92X@*B\*("`@("`@("`D9FEL96YA;64@/2`D=&AI<RT^7W1A
M<F=E=%9F<RT^7V=E=$YA=&EV95!A=&@H)'1H:7,M/E]T87)G971&:6QE*3L*
M"B`@("`@("`@+RH@36%K92!S=7)E('1H92!P871H('1O('1H92!F:6QE(&5X
M:7-T<RX@*B\*("`@("`@("`D9&ER(#T@9&ER;F%M92@D9FEL96YA;64I.PH@
M("`@("`@('=H:6QE("@A0&ES7V1I<B@D9&ER*2D@>PH@("`@("`@("`@("!I
M9B`H(4!M:V1I<B@D9&ER+"`P-S4U*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")#;W5L9"!N;W0@;6MD
M:7(@7"(E<UPB+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9&ER*2D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&1I<B`](&1I<FYA;64H)&1I<BD["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&9I;&5N86UE.PH@("`@?0H*("`@(&9U;F-T:6]N(&9I;FES
M:&5D*"D*("`@('L*("`@("`@("`O*B!.;W1H:6YG('1O(&1O+B`J+PH@("`@
M?0H*?0H*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5D93+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`U,S4U`#$P-3$U-#,S-S0U`#`R-3(V,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`H*+RHJ"B`J($5N8V%P<W5L
M871E('-T<F%T96=I97,@9F]R(&%B:6QI='D@=&\@=W)I=&4@;W5T<'5T('1O
M(')E86P@9FEL92X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<"QV(#$N,2XX
M+C<@,C`P-B\P,2\P,2`R,3HR.#HT,R!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#0M,C`P-B!#<F]N;W-Y<RP@3$Q#(#QH='1P.B\O=W=W+F-R;VYO
M<WES+F-O;2\^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*87-O;B!-
M+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@*B!`<&%C:V%G92!6
M1E-?25-/"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B\*8VQA<W,@5D937TE3
M3U=R:71E<E]296%L3W5T<'5T4W1R871E9WD@>PH*("`@("\J*@H@("`@("H@
M5&AE(%9&4R!T;R!W:&EC:"!W92!W:6QL('=R:71E('1H92!F:6QE+@H@("`@
M("H*("`@("`J($!V87(@5D93"B`@("`@*B\*("`@('9A<B`D7W1A<F=E=%9F
M<SL*"B`@("`O*BH*("`@("`J(%=H97)E('1O('-T;W)E('1H92!F:6QE(&EN
M('1H92!61E,N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1?=&%R9V5T1FEL93L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=&]R"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`F)'1A<F=E=%9F<R`@
M("`@("`@5&AE(%9&4R!T;R!W:&EC:"!W92!W:6QL('=R:71E('1H90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9FEL92X*("`@
M("`J($!P87)A;2!S=')I;F<@)'1A<F=E=$9I;&4@("`@("`@(%1H92!P871H
M(&%N9"!N86UE(&]F(&9I;&4@=&\@=W)I=&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%9&4U])4T]7<FET97)?4F5A;$]U='!U=%-T<F%T96=Y*"8D=&%R9V5T
M5F9S+"`D=&%R9V5T1FEL92D*("`@('L*("`@("`@("`D=&AI<RT^7W1A<F=E
M=%9F<R`]("8D=&%R9V5T5F9S.PH@("`@("`@("1T:&ES+3Y?=&%R9V5T1FEL
M92`]("1T87)G971&:6QE.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5L96-T
M(&%N9"!C<F5A=&4@82!C;VYC<F5T92!S=')A=&5G>2!F;W(@=7-I;F<@82!R
M96%L(&]U='!U="!F:6QE+@H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W0@
M)B1T87)G97169G,@("`@("`@(%1H92!61E,@=&\@=VAI8V@@=V4@=VEL;"!W
M<FET92!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(')E<W5L="X*("`@("`J($!P87)A;2!S=')I;F<@)'1A<F=E=$9I;&4@
M("`@("`@(%1H92!P871H(&%N9"!F:6QE;F%M92!O9B!T:&4@=&%R9V5T"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F:6QE('=I
M=&AI;B!T:&4@5D93+@H@("`@("H@0')E='5R;B!O8FIE8W0@("!!(&-O;F-R
M971E(&]U='!U="!S=')A=&5G>2!O8FIE8W0@;W(@4$5!4E]%<G)O<B!O;@H@
M("`@("H@("`@("`@("`@("`@("`@("!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F9F%C=&]R>2@F)'1A<F=E=%9F<RP@)'1A<F=E=$9I;&4I"B`@
M("!["B`@("`@("`@:68@*'-T<G1O;&]W97(H9V5T7V-L87-S*"1T87)G9716
M9G,I*2`]/2`G=F9S7V9I;&4G*2!["B`@("`@("`@("`@("1M971H;V0@/2`G
M9&ER96-T)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;65T:&]D
M(#T@)V-O<'DG.PH@("`@("`@('T*"B`@("`@("`@:6YC;'5D95]O;F-E(&1I
M<FYA;64H7U]&24Q%7U\I("X@)R]296%L3W5T<'5T4W1R871E9WDO)R`N("1M
M971H;V0@+@H@("`@("`@("`@("`@("`@("`@("`@)RYP:'`G.PH@("`@("`@
M("1C;&%S<R`]("=61E-?25-/5W)I=&5R7U)E86Q/=71P=713=')A=&5G>5\G
M("X@)&UE=&AO9#L*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@D8VQA<W,I
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN
M=&8H7R@B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M971H
M;V0I*3L*("`@("`@("!]"@H@("`@("`@("1S=')A=&5G>2`]("9N97<@)&-L
M87-S*"1T87)G97169G,L("1T87)G971&:6QE*3L*("`@("`@("!R971U<FX@
M)'-T<F%T96=Y.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@<F5A;"!F
M:6QE<WES=&5M(&9I;&5N86UE('=E(&-A;B!W<FET92!T;RX*("`@("`J"B`@
M("`@*B!`86)S=')A8W0*("`@("`J($!R971U<FX@<W1R:6YG("`@5&AE(&9I
M;&5N86UE(&]R(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T4F5A;$9I;&5N86UE*"D*("`@('L*("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@:6UP;&5M96YT960N(BDI.PH@
M("`@?0H*("`@("\J*@H@("`@("H@26YD:6-A=&4@=&AA="!W92=R92!D;VYE
M('=R:71I;F<@=&\@=&AE(')E86P@9FEL92X*("`@("`J"B`@("`@*B!`86)S
M=')A8W0*("`@("`J($!R971U<FX@;6EX960@("`@3G5L;"!O<B!014%27T5R
M<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&9I;FES:&5D
M*"D*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").
M;W0@:6UP;&5M96YT960N(BDI.PH@("`@?0H*?0H*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B]61E,O25-/5W)I=&5R+G!H<```````````
M````````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8U,S<`,3`U,34T,S,W
M-#4`,#(Q-#,V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"@IR97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*"B\J*@H@
M*B!61E,@05!)(&9O<B!A8G-T<F%C=&5D(&-R96%T:6]N(&]F($E33R`H0T0M
M4D]-*2!F:6QE<WES=&5M<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(N<&AP+'8@,2XQ+C@N-R`R,#`V+S`Q+S`Q
M(#(Q.C(X.C0S(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V
M($-R;VYO<WES+"!,3$,@/&AT='`Z+R]W=W<N8W)O;F]S>7,N8V]M+SX*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA<V]N($TN($9E;&EC92`\:F9E
M;&EC94!C<F]N;W-Y<RYC;VT^"B`J($!P86-K86=E(%9&4U])4T\*("H@0'-I
M;F-E("`@2&]R9&4@,RXP"B`J+PIC;&%S<R!61E-?25-/5W)I=&5R('L*"B`@
M("`O*BH*("`@("`J($$@5D93(&]B:F5C="!U<V5D(&9O<B!R96%D:6YG('1H
M92!S;W5R8V4@9FEL97,*("`@("`J"B`@("`@*B!`=F%R(%9&4PH@("`@("HO
M"B`@("!V87(@)%]S;W5R8V569G,@/2!N=6QL.PH*("`@("\J*@H@("`@("H@
M02!61E,@;V)J96-T('5S960@9F]R('=R:71I;F<@=&AE($E33R!I;6%G90H@
M("`@("H*("`@("`J($!V87(@5D93"B`@("`@*B\*("`@('9A<B`D7W1A<F=E
M=%9F<R`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!(87-H(&-O;G1A:6YI;F<@
M8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?<&%R86US(#T@87)R87DH*3L*"B`@("`O
M*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@5D937TE33U=R:71E<B!O8FIE
M8W0*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H
M(&-O;G1A:6YI;F<@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M5D937TE33U=R:71E<B@F)'-O=7)C959F<RP@)B1T87)G97169G,L("1P87)A
M;7,I"B`@("!["B`@("`@("`@)'1H:7,M/E]S;W5R8V569G,@/2`F)'-O=7)C
M959F<SL*("`@("`@("`D=&AI<RT^7W1A<F=E=%9F<R`]("8D=&%R9V5T5F9S
M.PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*("`@('T*"B`@
M("`O*BH*("`@("`J($-R96%T92!T:&4@25-/(&EM86=E"B`@("`@*@H@("`@
M("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@3G5L
M;"!O<B!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('!R;V-E<W,H*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(DYO="!I;7!L96UE;G1E9"XB*2D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!!='1E;7!T('1O(&-R96%T92!A(&-O;F-R971E(%9&4U])4T]7
M<FET97(@<W5B8VQA<W,N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@=7-E
M<R!I=',@<&%R86UE=&5R<R!A;F0@8VAE8VMS('1H92!S>7-T96T@=&\@9&5T
M97)M:6YE"B`@("`@*B!T:&4@;6]S="!A<'!R;W!R:6%T92!S=6)C;&%S<R!T
M;R!U<V4@9F]R(&)U:6QD:6YG($E33R!I;6%G97,N("!)9@H@("`@("H@;F]N
M92!I<R!F;W5N9"P@86X@97)R;W(@:7,@<F%I<V5D+@H@("`@("H*("`@("`J
M($!P87)A;2!O8FIE8W0@)B1S;W5R8V569G,@("`@("!2969E<F5N8V4@=&\@
M=&AE(%9&4R!O8FIE8W0@9G)O;2!W:&EC:`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('1H92!F:6QE<R!W:6QL(&)E(')E860@=&\@
M8W)E871E('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@($E33R!I;6%G92X*("`@("`J($!P87)A;2!O8FIE8W0@)B1T87)G9716
M9G,@("`@("!2969E<F5N8V4@=&\@=&AE(%9&4R!O8FIE8W0@=&\@=VAI8V@@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@25-/
M(&EM86=E('=I;&P@8F4@=W)I='1E;BX*("`@("`J($!P87)A;2!A<G)A>2`D
M<&%R86US("`@("`@("`@("!(87-H(&]F('!A<F%M971E<G,@9F]R(&-R96%T
M:6YG('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EM86=E.@H@("`@("H@("`@("`@("`@("`@("=S;W5R8V52;V]T)R`]/B`@
M("`@02!D:7)E8W1O<GD@:6X@=&AE('-O=7)C92!61E,@9F]R"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F:6QE<R!T;R!B92!R
M96%D(&9R;VT@9F]R('1H92!I;6%G92X*("`@("`J("`@("`@("`@("`@("`G
M=&%R9V5T1FEL92<@/3X@("`@(%!A=&@@86YD(&9I;&5N86UE(&]F('1H92!)
M4T\@9FEL92!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=W)I=&4@:6YT;R!T:&4@=&%R9V5T(%9&4RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&]B:F5C="`@("`@("`@("`@("`@("`@02!N97=L>2!C<F5A
M=&5D(&-O;F-R971E(%9&4U])4T]7<FET97(*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!S=6)C;&%S<RP@;W(@82!014%27T5R<F]R
M(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@F
M)'-O=7)C959F<RP@)B1T87)G97169G,L("1P87)A;7,I"B`@("!["B`@("`@
M("`@:68@*&5M<'1Y*"1P87)A;7-;)W1A<F=E=$9I;&4G72DI('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V%N;F]T('!R;V-E
M960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(I*3L*("`@("`@
M("!]"B`@("`@("`@:68@*&5M<'1Y*"1P87)A;7-;)W-O=7)C95)O;W0G72DI
M('L*("`@("`@("`@("`@)'!A<F%M<ULG<V]U<F-E4F]O="==(#T@)R\G.PH@
M("`@("`@('T*"B`@("`@("`@+RH@4FEG:'0@;F]W+"!M:VES;V9S(&ES('1H
M92!O;FQY(&1R:79E<BP@8G5T(&UA:V4@<W5R92!W92!C86X*("`@("`@("`@
M*B!S=7!P;W)T(&ET+B`J+PH@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE
M*%]?1DE,15]?*2`N("<O25-/5W)I=&5R+VUK:7-O9G,N<&AP)SL*("`@("`@
M("!I9B`H5D937TE33U=R:71E<E]M:VES;V9S.CIS=')A=&5G>4%V86EL86)L
M92@I*2!["B`@("`@("`@("`@("1I<V]W<FET97(@/2`F;F5W(%9&4U])4T]7
M<FET97)?;6MI<V]F<R@D<V]U<F-E5F9S+"`D=&%R9V5T5F9S+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!A<F%M<RD["B`@("`@("`@("`@(')E='5R;B`D:7-O=W)I=&5R.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F\@
M879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB*2D[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O5D93+TQI<W1)=&5M+G!H<```````````
M````````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T-3,T`#$P-3$U-#,S
M-S0U`#`R,3,S-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@06X@:71E;2!R971U<FYE9"!F<F]M(&$@
M9F]L9&5R(&QI<W0N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U9&4R]61E,O
M3&ES=$ET96TN<&AP+'8@,2XQ,2XQ,"XW(#(P,#8O,#4O,S$@,#0Z-3`Z,#(@
M<VQU<V%R>B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($IO;B!7
M;V]D(#QJ;VY`:F5L;'EB;V(N8V\N=6L^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!*;VX@5V]O9"`\:F]N0&IE;&QY8F]B+F-O+G5K/@H@*B!`<&%C
M:V%G92!61E,*("HO"F-L87-S(%9&4U],:7-T271E;2!["@H@("`@+RHJ"B`@
M("`@*B!61E,@<&%T:`H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D7W!A=&@["@H@("`@+RHJ"B`@("`@*B!&:6QE;F%M90H@
M("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VYA
M;64["@H@("`@+RHJ"B`@("`@*B!&:6QE('!E<FUI<W-I;VYS("@J;FEX(&9O
M<FUA=#H@9')W>')W>')W>"D*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)%]P97)M<SL*"B`@("`O*BH*("`@("`J($]W;F5R
M('5S97(*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)%]O=VYE<CL*"B`@("`O*BH*("`@("`J($]W;F5R(&=R;W5P"B`@("`@
M*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?9W)O=7`[
M"@H@("`@+RHJ"B`@("`@*B!3:7IE+@H@("`@("H*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D7W-I>F4["@H@("`@+RHJ"B`@("`@*B!,
M87-T(&UO9&EF:65D(&1A=&4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1?9&%T93L*"B`@("`O*BH*("`@("`J(%1Y<&4*
M("`@("`J("`@+BH@("`@("`M+2`@1FEL92!E>'1E;G-I;VX*("`@("`J("`@
M*BIN;VYE("`M+2`@56YR96-O9VYI>F5D('1Y<&4*("`@("`J("`@*BIS>6T@
M("`M+2`@4WEM;&EN:PH@("`@("H@("`J*F1I<B`@("TM("!$:7)E8W1O<GD*
M("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]T
M>7!E.PH*("`@("\J*@H@("`@("H@5'EP92!O9B!T87)G970@:68@='EP92!I
M<R`G*BIS>6TG+@H@("`@("H@3D(N($YO="!A;&P@8F%C:V5N9',@87)E(&-A
M<&%B;&4@;V8@9&ES=&EN9W5I<VAI;F<@86QL(&]F('1H97-E+@H@("`@("H@
M("`N*B`@("`@("`@+2T@($9I;&4@97AT96YS:6]N"B`@("`@*B`@("HJ;F]N
M92`@("`M+2`@56YR96-O9VYI>F5D('1Y<&4*("`@("`J("`@*BIS>6T@("`@
M("TM("!3>6UL:6YK('1O(&$@<WEM;&EN:PH@("`@("H@("`J*F1I<B`@("`@
M+2T@($1I<F5C=&]R>0H@("`@("H@("`J*F)R;VME;B`@+2T@(%1A<F=E="!N
M;W0@9F]U;F0@+2!B<F]K96X@;&EN:PH@("`@("H*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D7VQI;FMT>7!E.PH*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!297%U:7)E<R!T:&4@<&%T
M:"!T;R!T:&4@9FEL92P@86YD(&ET)W,@87)R87D@;V8@<')O<&5R=&EE<RP*
M("`@("`J(')E='5R;F5D(&9R;VT@82!S=&%N9&%R9"!61E,Z.FQI<W1&;VQD
M97(H*2!C86QL+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@
M("`@("!4:&4@<&%T:"!T;R!T:&4@9FEL92X*("`@("`J($!P87)A;2!A<G)A
M>2`D9FEL94%R<F%Y("!!;B!A<G)A>2!O9B!F:6QE('!R;W!E<G1I97,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%9&4U],:7-T271E;2@D<&%T:"P@)&9I;&5!
M<G)A>2D*("`@('L*("`@("`@("`D=&AI<RT^7W!A=&@@/2`D<&%T:"`N("<O
M)R`N("1F:6QE07)R87E;)VYA;64G73L*("`@("`@("`D=&AI<RT^7VYA;64@
M/2`D9FEL94%R<F%Y6R=N86UE)UT["B`@("`@("`@)'1H:7,M/E]D:7)N86UE
M(#T@)'!A=&@["B`@("`@("`@)'1H:7,M/E]P97)M<R`]("1F:6QE07)R87E;
M)W!E<FUS)UT["B`@("`@("`@)'1H:7,M/E]O=VYE<B`]("1F:6QE07)R87E;
M)V]W;F5R)UT["B`@("`@("`@)'1H:7,M/E]G<F]U<"`]("1F:6QE07)R87E;
M)V=R;W5P)UT["B`@("`@("`@)'1H:7,M/E]S:7IE(#T@)&9I;&5!<G)A>5LG
M<VEZ92==.PH@("`@("`@("1T:&ES+3Y?9&%T92`]("1F:6QE07)R87E;)V1A
M=&4G73L*("`@("`@("`D=&AI<RT^7W1Y<&4@/2`D9FEL94%R<F%Y6R=T>7!E
M)UT["B`@("`@("`@)'1H:7,M/E]L:6YK='EP92`]("1F:6QE07)R87E;)VQI
M;FMT>7!E)UT["B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5D93+VUU<W%L+G!H
M<```````````````````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0S
M-C(W`#$P-3$U-#,S-S0U`#`R,#<U,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E(&1I<FYA
M;64H7U]&24Q%7U\I("X@)R]S<6PN<&AP)SL*"B\J*@H@*B!097)M:7-S:6]N
M(&9O<B!R96%D(&%C8V5S<RX*("HO"F1E9FEN92@G5D937T9,04=?4D5!1"<L
M(#$I.PH*+RHJ"B`J(%!E<FUI<W-I;VX@9F]R(')E860@86-C97-S+@H@*B\*
M9&5F:6YE*"=61E-?1DQ!1U]74DE412<L(#(I.PH*+RHJ"B`J($UU;'1I(%5S
M97(@5D93(&EM<&QE;65N=&%T:6]N(&9O<B!02%`G<R!014%2(&1A=&%B87-E
M"B`J(&%B<W1R86-T:6]N(&QA>65R+@H@*@H@*B!297%U:7)E9"!V86QU97,@
M9F]R("1P87)A;7,Z/'!R93X*("H@("`@("`G<&AP='EP92<@("`@("`@5&AE
M(&1A=&%B87-E('1Y<&4@*&EE+B`G<&=S<6PG+"`G;7ES<6PG+"!E=&,N*2X\
M+W!R93X*("H*("H@3W!T:6]N86P@=F%L=65S.CQP<F4^"B`J("`@("`@)W1A
M8FQE)R`@("`@("`@(%1H92!N86UE(&]F('1H92!V9G,@=&%B;&4@:6X@)V1A
M=&%B87-E)RX@1&5F875L=',@=&\*("H@("`@("`@("`@("`@("`@("`@("`@
M)VAO<F1E7VUU=F9S)RX\+W!R93X*("H*("H@4F5Q=6ER960@8GD@<V]M92!D
M871A8F%S92!I;7!L96UE;G1A=&EO;G,Z/'!R93X*("H@("`@("`G:&]S='-P
M96,G("`@("`@5&AE(&AO<W1N86UE(&]F('1H92!D871A8F%S92!S97)V97(N
M"B`J("`@("`@)W!R;W1O8V]L)R`@("`@(%1H92!C;VUM=6YI8V%T:6]N('!R
M;W1O8V]L("@G=&-P)RP@)W5N:7@G+"!E=&,N*2X*("H@("`@("`G9&%T86)A
M<V4G("`@("`@5&AE(&YA;64@;V8@=&AE(&1A=&%B87-E+@H@*B`@("`@("=U
M<V5R;F%M92<@("`@("!4:&4@=7-E<FYA;64@=VET:"!W:&EC:"!T;R!C;VYN
M96-T('1O('1H92!D871A8F%S92X*("H@("`@("`G<&%S<W=O<F0G("`@("`@
M5&AE('!A<W-W;W)D(&%S<V]C:6%T960@=VET:"`G=7-E<FYA;64G+@H@*B`@
M("`@("=O<'1I;VYS)R`@("`@("!!9&1I=&EO;F%L(&]P=&EO;G,@=&\@<&%S
M<R!T;R!T:&4@9&%T86)A<V4N"B`J("`@("`@)W1T>2<@("`@("`@("`@(%1H
M92!45%D@;VX@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J
M("`@("`@)W!O<G0G("`@("`@("`@(%1H92!P;W)T(&]N('=H:6-H('1O(&-O
M;FYE8W0@=&\@=&AE(&1A=&%B87-E+CPO<')E/@H@*@H@*B!+;F]W;B!)<W-U
M97,Z"B`J($1E;&5T92!I<R!N;W0@<F5C=7-I=F4L('-O(&9I;&5S(&%N9"!F
M;VQD97)S('1H870@=7-E9"!T;R!B92!I;B!A(&9O;&1E<@H@*B!T:&%T(&=E
M=',@9&5L971E9"!L:79E(&9O<F5V97(@:6X@=&AE(&1A=&%B87-E+"!O<B!R
M92UA<'!E87(@=VAE;B!T:&4@9F]L9&5R"B`J(&ES(')E8W)E871E9"X*("H@
M4F5N86UE(&AA<R!T:&4@<V%M92!I<W-U92P@<V\@9FEL97,@87)E(&QO<W0@
M:68@82!F;VQD97(@:7,@<F5N86UE9"X*("H*("H@5&AE('1A8FQE('-T<G5C
M='5R92!F;W(@=&AE(%9&4R!C86X@8F4@9F]U;F0@:6X*("H@9&%T82]M=79F
M<RYS<6PN"B`J"B`J($1A=&%B87-E('-P96-I9FEC(&YO=&5S.@H@*@H@*B!-
M4U-13#H*("H@+2!4:&4@=F9S7V1A=&$@9FEE;&0@;75S="!B92!O9B!T>7!E
M($E-04=%+@H@*B`M(%EO=2!N965D('1H92!F;VQL;W=I;F<@<&AP+FEN:2!S
M971T:6YG<SH*("H@/&-O9&4^"B`J("`@(#L@5F%L:60@<F%N9V4@,"`M(#(Q
M-#<T.#,V-#<N($1E9F%U;'0@/2`T,#DV+@H@*B`@("!M<W-Q;"YT97AT;&EM
M:70@/2`P(#L@>F5R;R!T;R!P87-S('1H<F]U9V@*("H*("H@("`@.R!686QI
M9"!R86YG92`P("T@,C$T-S0X,S8T-RX@1&5F875L="`](#0P.38N"B`J("`@
M(&US<W%L+G1E>'1S:7IE(#T@,"`[('IE<F\@=&\@<&%S<R!T:')O=6=H"B`J
M(#PO8V]D93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`L=B`Q+C,P+C0N,38@,C`P-B\P-2\S,2`P-#HU,#HP,B!S;'5S87)Z
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U
M=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*
M("H@0'!A8VMA9V4@5D93"B`J+PIC;&%S<R!61E-?;75S<6P@97AT96YD<R!6
M1E-?<W%L('L*"B`@("`O*BH*("`@("`J($QI<W0@;V8@<&5R;6ES<VEO;G,@
M86YD(&EF('1H97D@8V%N(&)E(&-H86YG960@:6X@=&AI<R!61E,*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!E<FUI<W-I
M;VYS(#T@87)R87DH"B`@("`@("`@)V]W;F5R)R`]/B!A<G)A>2@G<F5A9"<@
M/3X@9F%L<V4L("=W<FET92<@/3X@9F%L<V4L("=E>&5C=71E)R`]/B!F86QS
M92DL"B`@("`@("`@)V=R;W5P)R`]/B!A<G)A>2@G<F5A9"<@/3X@9F%L<V4L
M("=W<FET92<@/3X@9F%L<V4L("=E>&5C=71E)R`]/B!F86QS92DL"B`@("`@
M("`@)V%L;"<@("`]/B!A<G)A>2@G<F5A9"<@/3X@=')U92P@("=W<FET92<@
M/3X@=')U92P@("=E>&5C=71E)R`]/B!F86QS92D*("`@("D["@H@("`@+RHJ
M"B`@("`@*B!3=&]R92!A(&9I;&4@:6X@=&AE(%9&4R!F<F]M(')A=R!D871A
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@("!4
M:&4@<&%T:"!T;R!S=&]R92!T:&4@9FEL92!I;BX*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@("`@("`@("!4:&4@9FEL96YA;64@=&\@=7-E+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9&%T82`@("`@("`@(%1H92!F:6QE(&1A=&$N
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D875T;V-R96%T92`@075T;VUA=&EC
M86QL>2!C<F5A=&4@9&ER96-T;W)I97,_"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&5$871A
M*"1P871H+"`D;F%M92P@)&1A=&$L("1A=71O8W)E871E(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D8V]N;BDI('L*("`@("`@("`@("`@<F5T
M=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@+RH@36%K92!S=7)E('=E
M(&AA=F4@=W)I=&4@86-C97-S('1O('1H:7,@86YD(&%L;"!P87)E;G0*("`@
M("`@("`@*B!P871H<RX@*B\*("`@("`@("!I9B`H)'!A=&@@(3T@)R<I('L*
M("`@("`@("`@("`@)'!A=&AS(#T@97AP;&]D92@G+R<L("1P871H*3L*("`@
M("`@("`@("`@)'!A=&A?;F%M92`](&%R<F%Y7W!O<"@D<&%T:',I.PH@("`@
M("`@("`@("!I9B`H(21T:&ES+3YI<T9O;&1E<BAI;7!L;V1E*"<O)RP@)'!A
M=&AS*2P@)'!A=&A?;F%M92DI('L*("`@("`@("`@("`@("`@(&EF("@A)&%U
M=&]C<F5A=&4I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BAS<')I;G1F*%\H(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES
M="(I+"`D<&%T:"DL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/F%U=&]C<F5A=&50871H*"1P871H*3L*("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D<&%T:'-;72`]("1P871H7VYA;64["B`@("`@("`@("`@("1P<F5V
M:6]U<R`]("<G.PH*("`@("`@("`@("`@9F]R96%C:"`H)'!A=&AS(&%S("1T
M:&ES<&%T:"D@>PH@("`@("`@("`@("`@("`@)')E<W5L=',@/2`D=&AI<RT^
M7V1B+3YG971!;&PH<W!R:6YT9B@G4T5,14-4('9F<U]O=VYE<BP@=F9S7W!E
M<FUS($923TT@)7,*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%=(15)%('9F<U]P871H(#T@/R!!3D0@
M=F9S7VYA;64](#\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G
M72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@D<')E=FEO=7,L("1T:&ES<&%T:"DI.PH@("`@("`@("`@
M("`@("`@:68@*"%I<U]A<G)A>2@D<F5S=6QT<RD@?'P@8V]U;G0H)')E<W5L
M=',I(#P@,2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(BDI.PH@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1A;&QO=V5D(#T@
M9F%L<V4["B`@("`@("`@("`@("`@("!F;W)E86-H("@D<F5S=6QT<R!A<R`D
M<F5S=6QT*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1R97-U;'1;,%T@
M/3T@)'1H:7,M/E]P87)A;7-;)W5S97(G72!\?"`D<F5S=6QT6S%=("8@5D93
M7T9,04=?5U))5$4I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&%L;&]W
M960@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@:68@*"$D86QL;W=E9"D@>PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&9I;&4N(BDI.PH@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@("1P<F5V:6]U<R`]("1T:&ES<&%T:#L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N('!A<F5N=#HZ=W)I=&5$871A
M*"1P871H+"`D;F%M92P@)&1A=&$L("1A=71O8W)E871E*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($1E;&5T92!A(&9I;&4@9G)O;2!T:&4@5D93+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H('1O('-T
M;W)E('1H92!F:6QE(&EN+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@
M5&AE(&9I;&5N86UE('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&5&:6QE*"1P
M871H+"`D;F%M92D*("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N
M;F5C="@I.PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C;VYN*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("`D
M9FEL94QI<W0@/2`D=&AI<RT^7V1B+3YG971!;&PH<W!R:6YT9B@G4T5,14-4
M('9F<U]I9"P@=F9S7V]W;F5R+"!V9G-?<&5R;7,@1E)/32`E<PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!72$52
M12!V9G-?<&%T:"`](#\@04Y$('9F<U]N86UE/2`_($%.1"!V9G-?='EP92`]
M(#\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)'!A=&@L("1N86UE
M+"!61E-?1DE,12DI.PH*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1F:6QE3&ES
M="D@?'P@8V]U;G0H)&9I;&5,:7-T*2`\(#$I('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&1E;&5T92!61E,@
M9FEL92XB*2D["B`@("`@("`@?0H*("`@("`@("`O*B!4:&5R92!M87D@8F4@
M;VYE(&]R(&UO<F4@9FEL97,@=VET:"!T:&4@<V%M92!N86UE(&)U="!T:&4*
M("`@("`@("`@("!U<V5R(&UA>2!N;W0@:&%V92!R96%D(&%C8V5S<R!T;R!T
M:&5M+"!S;R!D;V5S;B=T('-E90H@("`@("`@("`@('1H96TN(%-O('=E(&AA
M=F4@=&\@9&5L971E('1H92!O;F4@=&AE>2!H879E(&%C8V5S<R!T;RX@*B\*
M("`@("`@("!F;W)E86-H("@D9FEL94QI<W0@87,@)&9I;&4I('L*("`@("`@
M("`@("`@:68@*"1F:6QE6S%=(#T]("1T:&ES+3Y?<&%R86US6R=U<V5R)UT@
M?'P@)&9I;&5;,ET@)B!61E-?1DQ!1U]74DE412D@>PH@("`@("`@("`@("`@
M("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*'-P<FEN=&8H)T1%3$54
M12!&4D]-("5S(%=(15)%('9F<U]I9"`](#\G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W1A8FQE)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"1F:6QE6S!=*2D["@H@("`@("`@("`@
M("`@("`@:68@*"1T:&ES+3Y?9&(M/F%F9F5C=&5D4F]W<R@I(#T](#`I('L*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(I*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!&25A-13H@)T%C8V5S<R!$
M96YI960@9&5L971I;F<@9FEL92`E<R\E<R<*("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(I
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;F%M92!A(&9I;&4@;W(@9F]L
M9&5R(&EN('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;VQD<&%T:"`@5&AE(&]L9"!P871H('1O('1H92!F:6QE+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;VQD;F%M92`@5&AE(&]L9"!F:6QE;F%M92X*("`@("`J
M($!P87)A;2!S=')I;F<@)&YE=W!A=&@@(%1H92!N97<@<&%T:"!O9B!T:&4@
M9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&YE=VYA;64@(%1H92!N97<@
M9FEL96YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O
M;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5N86UE*"1O;&1P871H+"`D;VQD;F%M
M92P@)&YE=W!A=&@L("1N97=N86UE*0H@("`@>PH@("`@("`@("1C;VYN(#T@
M)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&-O;FXI*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]
M"@H@("`@("`@("1F:6QE3&ES="`]("1T:&ES+3Y?9&(M/F=E=$%L;"AS<')I
M;G1F*"=314Q%0U0@=F9S7VED+"!V9G-?;W=N97(L('9F<U]P97)M<R!&4D]-
M("5S"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!72$5212!V9G-?<&%T:"`](#\@04Y$('9F<U]N86UE
M/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)&]L
M9'!A=&@L("1O;&1N86UE*2D["@H@("`@("`@(&EF("@A:7-?87)R87DH)&9I
M;&5,:7-T*2!\?"!C;W5N="@D9FEL94QI<W0I(#P@,2D@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE+B(I*3L*("`@("`@("!]"@H@("`@("`@(&EF("AS=')P;W,H
M)&YE=W!A=&@L("<O)RD@/3T](&9A;'-E*2!["B`@("`@("`@("`@("1P87)E
M;G0@/2`G)SL*("`@("`@("`@("`@)'!A=&@@/2`D;F5W<&%T:#L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!L:7-T*"1P87)E;G0L("1P871H*2`]
M(&5X<&QO9&4H)R\G+"`D;F5W<&%T:"P@,BD["B`@("`@("`@?0H@("`@("`@
M(&EF("@A)'1H:7,M/FES1F]L9&5R*"1P87)E;G0L("1P871H*2D@>PH@("`@
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/F%U=&]C<F5A=&50
M871H*"1N97=P871H*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("\J(%1H97)E(&UA>2!B92!O;F4@;W(@;6]R92!F:6QE<R!W:71H
M('1H92!S86UE(&YA;64@8G5T('1H92!U<V5R(&UA>0H@("`@("`@("`J(&YO
M="!H879E(')E860@86-C97-S('1O('1H96TL('-O(&1O97-N)W0@<V5E('1H
M96TN(%-O('=E(&AA=F4@=&\*("`@("`@("`@*B!R96YA;64@=&AE(&]N92!T
M:&5Y(&AA=F4@86-C97-S('1O+B`J+PH@("`@("`@(&9O<F5A8V@@*"1F:6QE
M3&ES="!A<R`D9FEL92D@>PH@("`@("`@("`@("!I9B`H)&9I;&5;,5T@/3T@
M)'1H:7,M/E]P87)A;7-;)W5S97(G72!\?"`D9FEL95LR72`F(%9&4U]&3$%'
M7U=2251%*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D
M8BT^<75E<GDH<W!R:6YT9B@G55!$051%("5S(%-%5"!V9G-?<&%T:"`](#\L
M('9F<U]N86UE(#T@/RP@=F9S7VUO9&EF:65D(#T@/PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@5TA%4D4@
M=F9S7VED(#T@/R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)&YE=W!A=&@L("1N97=N86UE+"!T:6UE*"DL("1F:6QE6S!=*2D[
M"B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M<W!R:6YT9BA?*")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(I
M+"`D;VQD<&%T:"P@)&]L9&YA;64I*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($-R96%T97,@82!F;VQD97(@;VX@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1P871H("!(;VQD<R!T:&4@<&%T:"!O9B!D:7)E8W1O
M<GD@=&\@8W)E871E(&9O;&1E<BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA
M;64@($AO;&1S('1H92!N86UE(&]F('1H92!N97<@9F]L9&5R+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%
M05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&-R96%T949O;&1E<B@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@
M)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D8V]N;BDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@
M("`@("`@('T*"B`@("`@("`@+RH@;6%K92!S=7)E('=E(&AA=F4@=W)I=&4@
M86-C97-S('1O('1H:7,@86YD(&%L;"!P87)E;G0@<&%T:',@*B\*("`@("`@
M("!I9B`H)'!A=&@@(3T@(B(I('L*("`@("`@("`@("`@)'!A=&AS(#T@97AP
M;&]D92@G+R<L("1P871H*3L*("`@("`@("`@("`@)'!R979I;W5S(#T@)R<[
M"@H@("`@("`@("`@("!F;W)E86-H("@D<&%T:',@87,@)'1H:7-P871H*2![
M"B`@("`@("`@("`@("`@("`D<F5S=6QT<R`]("1T:&ES+3Y?9&(M/F=E=$%L
M;"AS<')I;G1F*"=314Q%0U0@=F9S7V]W;F5R+"!V9G-?<&5R;7,@1E)/32`E
M<PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!72$5212!V9G-?<&%T:"`](#\@04Y$('9F
M<U]N86UE/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)W1A8FQE)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)'!R979I;W5S+"`D=&AI<W!A=&@I*3L*("`@
M("`@("`@("`@("`@(&EF("@A:7-?87)R87DH)')E<W5L=',I('Q\(&-O=6YT
M*"1R97-U;'1S*2`\(#$I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E
M8W1O<GDN(BDI.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@
M("1A;&QO=V5D(#T@9F%L<V4["B`@("`@("`@("`@("`@("!F;W)E86-H("@D
M<F5S=6QT<R!A<R`D<F5S=6QT*2!["B`@("`@("`@("`@("`@("`@("`@:68@
M*"1R97-U;'1;,%T@/3T@)'1H:7,M/E]P87)A;7-;)W5S97(G72!\?"`D<F5S
M=6QT6S%=("8@5D937T9,04=?5U))5$4I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&%L;&]W960@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@:68@*"$D86QL;W=E9"D@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D%C8V5S
M<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB*2D["B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'!R979I;W5S(#T@)'1H:7-P
M871H.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D:60@/2`D
M=&AI<RT^7V1B+3YN97AT260H)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI.PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7V1B+3YQ=65R>2AS<')I;G1F*"=)3E-%
M4E0@24Y43R`E<R`H=F9S7VED+"!V9G-?='EP92P@=F9S7W!A=&@L('9F<U]N
M86UE+"!V9G-?;6]D:69I960L('9F<U]O=VYE<BP@=F9S7W!E<FUS*0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%9!3%5%4R`H
M/RP@/RP@/RP@/RP@/RP@/RP@/RDG+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)&ED+"!6
M1E-?1D],1$52+"`D<&%T:"P@)&YA;64L('1I;64H*2P@)'1H:7,M/E]P87)A
M;7-;)W5S97(G72P@,"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E
M(&$@9FEL92!F<F]M('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<&%T:"`@("`@("`@5&AE('!A=&@@=&\@9&5L971E('1H92!F;VQD
M97(@9G)O;2X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@(%1H
M92!F;VQD97)N86UE('1O('5S92X*("`@("`J($!P87)A;2!B;V]L96%N("1R
M96-U<G-I=F4@($9O<F-E(&$@<F5C=7)S:79E(&1E;&5T93\*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%2
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!D96QE=&5&;VQD97(H)'!A=&@L("1N86UE+"`D<F5C=7)S:79E(#T@9F%L
M<V4I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8V]N;BDI('L*("`@("`@("`@
M("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@:68@*"1R96-U
M<G-I=F4I('L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YE;7!T>49O
M;&1E<B@D<&%T:"`N("<O)R`N("1N86UE*3L*("`@("`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D;&ES="`]("1T:&ES+3YL:7-T1F]L9&5R*"1P871H
M("X@)R\G("X@)&YA;64I.PH@("`@("`@("`@("!I9B`H:7-?82@D;&ES="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1L:7-T
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AC;W5N="@D;&ES="DI
M('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P
M<FEN=&8H7R@B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='DB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!A=&@@+B`G+R<@+B`D;F%M92DI.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D9FEL94QI<W0@/2`D=&AI
M<RT^7V1B+3YG971!;&PH<W!R:6YT9B@G4T5,14-4('9F<U]I9"P@=F9S7V]W
M;F5R+"!V9G-?<&5R;7,@1E)/32`E<PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@5TA%4D4@=F9S7W!A
M=&@@/2`_($%.1"!V9G-?;F%M93T@/R!!3D0@=F9S7W1Y<&4@/2`_)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)'!A=&@L("1N86UE
M+"!61E-?1D],1$52*2D["@H@("`@("`@(&EF("@A:7-?87)R87DH)&9I;&5,
M:7-T*2!\?"!C;W5N="@D9FEL94QI<W0I(#P@,2D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GDN(BDI.PH@("`@("`@('T*"B`@("`@("`@+RH@5&AE<F4@
M;6%Y(&)E(&]N92!O<B!M;W)E(&9O;&1E<G,@=VET:"!T:&4@<V%M92!N86UE
M(&)U="!A<R!T:&4@=7-E<@H@("`@("`@("`J(&UA>2!N;W0@:&%V92!R96%D
M(&%C8V5S<R!T;R!T:&5M+"!T:&5Y(&1O;B=T('-E92!T:&5M+B!3;R!W92!H
M879E('1O"B`@("`@("`@("H@9&5L971E('1H92!O;F4@=&AE>2!H879E(&%C
M8V5S<R!T;R`J+PH@("`@("`@(&9O<F5A8V@@*"1F:6QE3&ES="!A<R`D9FEL
M92D@>PH@("`@("`@("`@("!I9B`H)&9I;&5;,5T@/3T@)'1H:7,M/E]P87)A
M;7-;)W5S97(G72!\?"`D9FEL95LR72`F(%9&4U]&3$%'7U=2251%*2!["B`@
M("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH<W!R
M:6YT9B@G1$5,151%($923TT@)7,@5TA%4D4@=F9S7VED(#T@/R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)&9I;&5;,%TI*3L*
M"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]D8BT^869F96-T9612;W=S
M*"D@/3T@,"D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB
M*2D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O
M($9)6$U%.B`G06-C97-S($1E;FEE9"!D96QE=&EN9R!F;VQD97(@)7,O)7,G
M"B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y+B(I*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!A(&QI<W0@;V8@=&AE(&-O;G1E;G1S(&]F(&$@9F]L9&5R
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@5&AE
M('!A=&@@;V8@=&AE(&1I<F5C=&]R>2X*("`@("`J($!P87)A;2!M:7AE9"`D
M9FEL=&5R("`@("`@4W1R:6YG+VAA<V@@=&\@9FEL=&5R(&9I;&4O9&ER;F%M
M92!O;BX*("`@("`J($!P87)A;2!B;V]L96%N("1D;W1F:6QE<R`@4VAO=R!D
M;W1F:6QE<S\*("`@("`J($!P87)A;2!B;V]L96%N("1D:7)O;FQY("`@4VAO
M=R!O;FQY(&1I<F5C=&]R:65S/PH@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@($9I;&4@;&ES="!O;B!S=6-C97-S(&]R(&9A;'-E(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]L:7-T1F]L9&5R*"1P871H+"`D9FEL
M=&5R(#T@;G5L;"P@)&1O=&9I;&5S(#T@=')U92P*("`@("`@("`@("`@("`@
M("`@("`@("`@)&1I<F]N;'D@/2!F86QS92D*("`@('L*("`@("`@("`D8V]N
M;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*
M("`@("`@("!]"@H@("`@("`@("1L96YG=&A?;W`@/2`D=&AI<RT^7V=E=$9I
M;&53:7IE3W`H*3L*("`@("`@("`D9FEL94QI<W0@/2`D=&AI<RT^7V1B+3YG
M971!;&PH<W!R:6YT9B@G4T5,14-4('9F<U]N86UE+"!V9G-?='EP92P@=F9S
M7VUO9&EF:65D+"!V9G-?;W=N97(L('9F<U]P97)M<RP@)7,H=F9S7V1A=&$I
M($923TT@)7,*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!72$5212!V9G-?<&%T:"`](#\@04Y$("AV9G-?;W=N97(@
M/2`_(&]R('9F<U]P97)M<R`F)B`_*2<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&QE;F=T:%]O<"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"1P871H+"`D=&AI<RT^7W!A<F%M<ULG
M=7-E<B==+"!61E-?1DQ!1U]214%$*2D["B`@("`@("`@:68@*&ES7V$H)&9I
M;&5,:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M9FEL94QI<W0["B`@("`@("`@?0H*("`@("`@("`D9FEL97,@/2!A<G)A>2@I
M.PH@("`@("`@(&9O<F5A8V@@*"1F:6QE3&ES="!A<R`D;&EN92D@>PH@("`@
M("`@("`@("`O+R!&:6QT97(@;W5T(&1O=&9I;&5S(&EF('1H97D@87)E;B=T
M('=A;G1E9"X*("`@("`@("`@("`@:68@*"$D9&]T9FEL97,@)B8@<W5B<W1R
M*"1L:6YE6S!=+"`P+"`Q*2`]/2`G+B<I('L*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D9FEL95LG;F%M
M92==(#T@<W1R:7!S;&%S:&5S*"1L:6YE6S!=*3L*"B`@("`@("`@("`@(&EF
M("@D;&EN95LQ72`]/2!61E-?1DE,12D@>PH@("`@("`@("`@("`@("`@)&YA
M;64@/2!E>'!L;V1E*"<N)RP@)&QI;F5;,%TI.PH*("`@("`@("`@("`@("`@
M(&EF("AC;W5N="@D;F%M92D@/3T@,2D@>PH@("`@("`@("`@("`@("`@("`@
M("1F:6QE6R=T>7!E)UT@/2`G*BIN;VYE)SL*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)W1Y<&4G72`](%9&
M4SHZ<W1R=&]L;W=E<B@D;F%M95MC;W5N="@D;F%M92D@+2`Q72D["B`@("`@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)&9I;&5;)W-I>F4G72`]
M("1L:6YE6S5=.PH@("`@("`@("`@("!](&5L<V5I9B`H)&QI;F5;,5T@/3T@
M5D937T9/3$1%4BD@>PH@("`@("`@("`@("`@("`@)&9I;&5;)W1Y<&4G72`]
M("<J*F1I<B<["B`@("`@("`@("`@("`@("`D9FEL95LG<VEZ92==(#T@+3$[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1F:6QE6R=D871E)UT@/2`D
M;&EN95LR73L*("`@("`@("`@("`@)&9I;&5;)V]W;F5R)UT@/2`D;&EN95LS
M73L*"B`@("`@("`@("`@("1L:6YE6S1=(#T@:6YT=F%L*"1L:6YE6S1=*3L*
M("`@("`@("`@("`@)&9I;&5;)W!E<FUS)UT@(#T@*"1L:6YE6S%=(#T](%9&
M4U]&3TQ$15(I(#\@)V0G(#H@)RTG.PH@("`@("`@("`@("`D9FEL95LG<&5R
M;7,G72`N/2`G<G<M)SL*("`@("`@("`@("`@)&9I;&5;)W!E<FUS)UT@+CT@
M*"1L:6YE6S1=("8@5D937T9,04=?4D5!1"D@/R`G<B<@.B`G+2<["B`@("`@
M("`@("`@("1F:6QE6R=P97)M<R==("X]("@D;&EN95LT72`F(%9&4U]&3$%'
M7U=2251%*2`_("=W)R`Z("<M)SL*("`@("`@("`@("`@)&9I;&5;)W!E<FUS
M)UT@+CT@)RTG.PH@("`@("`@("`@("`D9FEL95LG9W)O=7`G72`]("<G.PH*
M("`@("`@("`@("`@+R\@9FEL=&5R:6YG"B`@("`@("`@("`@(&EF("@D=&AI
M<RT^7V9I;'1E<DUA=&-H*"1F:6QT97(L("1F:6QE6R=N86UE)UTI*2!["B`@
M("`@("`@("`@("`@("!U;G-E="@D9FEL92D["B`@("`@("`@("`@("`@("!C
M;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&1I<F]N
M;'D@)B8@)&9I;&5;)W1Y<&4G72`A/3T@)RHJ9&ER)RD@>PH@("`@("`@("`@
M("`@("`@=6YS970H)&9I;&4I.PH@("`@("`@("`@("`@("`@8V]N=&EN=64[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1F:6QE<ULD9FEL95LG;F%M
M92==72`]("1F:6QE.PH@("`@("`@("`@("!U;G-E="@D9FEL92D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&9I;&5S.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0VAA;F=E<R!P97)M:7-S:6]N<R!F;W(@86X@271E;2!O;B!T:&4@
M5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@($AO;&1S
M('1H92!P871H(&]F(&1I<F5C=&]R>2!O9B!T:&4@271E;2X*("`@("`J($!P
M87)A;2!S=')I;F<@)&YA;64@($AO;&1S('1H92!N86UE(&]F('1H92!)=&5M
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S
M<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&-H86YG95!E<FUI<W-I;VYS*"1P871H+"`D;F%M92P@
M)'!E<FUI<W-I;VXI"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O
M;FYE8W0H*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8V]N;BDI('L*
M("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@
M)'9A;"`](&EN='9A;"AS=6)S='(H)'!E<FUI<W-I;VXL("TQ*2D["B`@("`@
M("`@)'!E<FT@/2`P.PH@("`@("`@("1P97)M('P]("@D=F%L("8@-"D@/R!6
M1E-?1DQ!1U]214%$(#H@,#L*("`@("`@("`D<&5R;2!\/2`H)'9A;"`F(#(I
M(#\@5D937T9,04=?5U))5$4@.B`P.PH*("`@("`@("`D9FEL94QI<W0@/2`D
M=&AI<RT^7V1B+3YG971!;&PH<W!R:6YT9B@G4T5,14-4('9F<U]I9"P@=F9S
M7V]W;F5R+"!V9G-?<&5R;7,@1E)/32`E<PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@5TA%4D4@=F9S
M7W!A=&@@/2`_($%.1"!V9G-?;F%M93T@/R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"1P871H+"`D;F%M92DI.PH*("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1F:6QE3&ES="D@?'P@8V]U;G0H)&9I;&5,:7-T*2`\
M(#$I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB*2D["B`@("`@("`@?0H*("`@
M("`@("`O*B!4:&5R92!M87D@8F4@;VYE(&]R(&UO<F4@9FEL97,@=VET:"!T
M:&4@<V%M92!N86UE(&)U="!T:&4@=7-E<B!M87D*("`@("`@("`@*B!N;W0@
M:&%V92!R96%D(&%C8V5S<R!T;R!T:&5M+"!S;R!D;V5S;B=T('-E92!T:&5M
M+B!3;R!W92!H879E('1O"B`@("`@("`@("H@8VAM;V0@=&AE(&]N92!T:&5Y
M(&AA=F4@86-C97-S('1O+B`J+PH@("`@("`@(&9O<F5A8V@@*"1F:6QE3&ES
M="!A<R`D9FEL92D@>PH@("`@("`@("`@("!I9B`H)&9I;&5;,5T@/3T@)'1H
M:7,M/E]P87)A;7-;)W5S97(G72!\?"`D9FEL95LR72`F(%9&4U]&3$%'7U=2
M251%*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^
M<75E<GDH<W!R:6YT9B@G55!$051%("5S(%-%5"!V9G-?<&5R;7,@/2`_"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!72$5212!V9G-?:60@/2`_)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=T86)L92==*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@D<&5R;2P@)&9I;&5;,%TI*3L*("`@("`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H
M(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O
M)7,N(BDL("1P871H+"`D;F%M92DI.PH@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]61E,O3V)J96-T+G!H
M<```````````````````````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C$R
M,C4`,3`U,34T,S,W-#4`,#(Q,#`T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+RXN+U9&4RYP:'`G.PH*+RHJ"B`J($$@=W)A<'!E
M<B!F;W(@=&AE(%9&4R!C;&%S<R!T;R!R971U<FX@;V)J96-T<RP@:6YS=&5A
M9"!O9B!A<G)A>7,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U9&4R]61E,O
M3V)J96-T+G!H<"QV(#$N,3(N,3`N,3$@,C`P-B\P-2\S,2`P-#HU,#HP,B!S
M;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@2F]N(%=O
M;V0@/&IO;D!J96QL>6)O8BYC;RYU:SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($IO;B!7;V]D(#QJ;VY`:F5L;'EB;V(N8V\N=6L^"B`J($!P86-K
M86=E(%9&4PH@*B\*8VQA<W,@5D937T]B:F5C="!["@H@("`@+RHJ"B`@("`@
M*B!4:&4@86-T=6%L('9F<R!T:&%T(&1O97,@=&AE('=O<FL*("`@("`J"B`@
M("`@*B!`=F%R(%9&4PH@("`@("HO"B`@("!V87(@)%]V9G,["@H@("`@+RHJ
M"B`@("`@*B!4:&4@8W5R<F5N="!P871H('1H870@:&%S(&)E96X@<&%S<V5D
M('1O(&QI<W1&;VQD97(L(&EF('1H:7,*("`@("`J(&-H86YG97,L('1H92!L
M:7-T('=I;&P@8F4@<F5B=6EL="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)%]C=7)R96YT4&%T:#L*"B`@("`O*BH*("`@
M("`J(%1H92!R971U<FX@=F%L=64@9G)O;2!A('-T86YD87)D(%9&4R!L:7-T
M1F]L9&5R(&-A;&PL('1O"B`@("`@*B!B92!R96%D('=I=&@@=&AE($]B:F5C
M="!L:7-T1F]L9&5R+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?9F]L9&5R3&ES=#L*"B`@("`O*BH*("`@("`J($-O;G-T
M<G5C=&]R+@H@("`@("H*("`@("`J($EF('EO=2!P87-S(&EN(&%N(&5X:7-T
M:6YG(%9&4R!O8FIE8W0L(&ET('=I;&P@8F4@=7-E9"!A<R!T:&4@5D93"B`@
M("`@*B!O8FIE8W0@9F]R('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J($!P
M87)A;2!61E,@)B1V9G,@(%1H92!61E,@;V)J96-T('1O('=R87`N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%9&4U]/8FIE8W0H)B1V9G,I"B`@("!["B`@("`@
M("`@:68@*&ES<V5T*"1V9G,I*2!["B`@("`@("`@("`@("1T:&ES+3Y?=F9S
M(#T@)'9F<SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E
M;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!61E-?3V)J96-T(&EN<W1A;F-E
M(&)A<V5D(&]N("1D<FEV97(N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D
M("1D<FEV97(@(%1H92!T>7!E(&]F(&-O;F-R971E(%9&4R!S=6)C;&%S<R!T
M;R!R971U<FXN($EF"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@)&1R
M:79E<B!I<R!A;B!A<G)A>2!T:&5N('=E('=I;&P@;&]O:R!I;@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("1D<FEV97);,%TO;&EB+U9&4R\@9F]R
M('1H92!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EM
M<&QE;65N=&%T:6]N(&YA;65D("1D<FEV97);,5TN<&AP+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I
M=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!C;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H
M="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@5D937T]B:F5C="`@5&AE
M(&YE=VQY(&-R96%T960@8V]N8W)E=&4@5D937T]B:F5C="!I;G-T86YC92P@
M;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@9F%L<V4@;VX@86X@97)R
M;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D<FEV97(L("1P
M87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1V9G,@/2`F5D93.CIF
M86-T;W)Y*"1D<FEV97(L("1P87)A;7,@/2!A<G)A>2@I*3L*("`@("`@("`D
M=F9S;V)J96-T(#T@)FYE=R!61E-?3V)J96-T*"1V9G,I.PH@("`@("`@(')E
M='5R;B`D=F9S;V)J96-T.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP
M=',@=&\@<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@5D93(&EN
M<W1A;F-E"B`@("`@*B!B87-E9"!O;B`D9')I=F5R+B!)="!W:6QL(&]N;'D@
M8W)E871E(&$@;F5W(&EN<W1A;F-E(&EF(&YO"B`@("`@*B!61E,@:6YS=&%N
M8V4@=VET:"!T:&4@<V%M92!P87)A;65T97)S(&-U<G)E;G1L>2!E>&ES=',N
M"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E9"!I9B!M=6QT:7!L
M92!T>7!E<R!O9B!F:6QE(&)A8VME;F1S("AA;F0L"B`@("`@*B!T:'5S+"!M
M=6QT:7!L92!61E,@:6YS=&%N8V5S*2!A<F4@<F5Q=6ER960N"B`@("`@*@H@
M("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R(#T@
M)E9&4SHZ<VEN9VQE=&]N*"D*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@
M)&1R:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@5D93('-U8F-L87-S('1O
M(')E='5R;BX@268*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`D9')I
M=F5R(&ES(&%N(&%R<F%Y('1H96X@=V4@=VEL;"!L;V]K(&EN"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@)&1R:79E<ELP72]L:6(O5D93+R!F;W(@
M=&AE('-U8F-L87-S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:6UP
M;&5M96YT871I;VX@;F%M960@)&1R:79E<ELQ72YP:'`N"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET
M:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT
M(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!61E-?3V)J96-T("!4:&4@
M8V]N8W)E=&4@5D937T]B:F5C="!R969E<F5N8V4L(&]R(&9A;'-E(&]N"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@(&5R<F]R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(L("1P87)A;7,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@("1V9G,@/2`F5D93.CIS:6YG;&5T;VXH)&1R:79E
M<BP@)'!A<F%M<R`](&%R<F%Y*"DI.PH@("`@("`@("1V9G-O8FIE8W0@/2`F
M;F5W(%9&4U]/8FIE8W0H)'9F<RD["B`@("`@("`@<F5T=7)N("1V9G-O8FIE
M8W0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:R!T:&4@8W)E9&5N=&EA
M;',@=&AA="!W92!H879E('1O('-E92!I9B!T:&5R92!I<R!A('9A;&ED(&QO
M9VEN+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C
M8V5S<RP@4$5!4E]%<G)O<B!D97-C<FEB:6YG('1H92!P<F]B;&5M"B`@("`@
M*B`@("`@("`@("`@("`@("!I9B!T:&4@8W)E9&5N=&EA;',@87)E(&EN=F%L
M:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-H96-K0W)E9&5N=&EA;',H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W9F<RT^8VAE8VM#<F5D96YT
M:6%L<R@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T(&-O;F9I9W5R871I
M;VX@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@06X@87-S;V-I871I=F4@87)R87D@;V8@<&%R86UE=&5R(&YA;64O
M=F%L=64*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!P86ER<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T4&%R86US*"1P87)A;7,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=F9S+3YS971087)A;7,H)'!A<F%M
M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V92!A(&9I;&4@9G)O
M;2!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@
M(%1H92!P871H;F%M92!T;R!T:&4@9FEL92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(&9I;&4@9&%T82X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5A9"@D<&%T:"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]V
M9G,M/G)E860H9&ER;F%M92@D<&%T:"DL(&)A<V5N86UE*"1P871H*2D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R92!A(&9I;&4@:6X@=&AE(%9&4RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("`@5&AE
M('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T;7!&:6QE("`@("`@5&AE('1E;7!O<F%R>2!F:6QE(&-O;G1A:6YI
M;F<@=&AE(&1A=&$@=&\@8F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!S=&]R960N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D875T;V-R
M96%T92`@075T;VUA=&EC86QL>2!C<F5A=&4@9&ER96-T;W)I97,_"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@
M4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@=W)I=&4H)'!A=&@L("1T;7!&:6QE+"`D875T;V-R96%T92`](&9A
M;'-E*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W9F<RT^=W)I=&4H
M9&ER;F%M92@D<&%T:"DL(&)A<V5N86UE*"1P871H*2P@)'1M<$9I;&4L("1A
M=71O8W)E871E(#T@9F%L<V4I.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1O
M<F4@82!F:6QE(&EN('1H92!61E,@9G)O;2!R87<@9&%T82X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@=&\@
M<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A
M("`@("`@("`@5&AE(&9I;&4@9&%T82X*("`@("`J($!P87)A;2!B;V]L96%N
M("1A=71O8W)E871E("!!=71O;6%T:6-A;&QY(&-R96%T92!D:7)E8W1O<FEE
M<S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E
M<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!W<FET941A=&$H)'!A=&@L("1D871A+"`D875T;V-R
M96%T92`](&9A;'-E*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W9F
M<RT^=W)I=&5$871A*&1I<FYA;64H)'!A=&@I+"!B87-E;F%M92@D<&%T:"DL
M("1D871A+"`D875T;V-R96%T92`](&9A;'-E*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($1E;&5T92!A(&9I;&4@9G)O;2!T:&4@5D93+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H('1O('-T;W)E('1H
M92!F:6QE(&EN+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9I
M;&5N86UE('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&5&:6QE*"1P871H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W9F<RT^9&5L971E1FEL92AD
M:7)N86UE*"1P871H*2P@8F%S96YA;64H)'!A=&@I*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E;F%M92!A(&9I;&4@:6X@=&AE(%9&4RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1O;&1P871H("!4:&4@;VQD('!A=&@@=&\@
M=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;&1N86UE("!4:&4@
M;VQD(&9I;&5N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W<&%T:"`@
M5&AE(&YE=R!P871H(&]F('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;F5W;F%M92`@5&AE(&YE=R!F:6QE;F%M92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YA
M;64H)&]L9'!A=&@L("1N97=P871H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7W9F<RT^<F5N86UE*&1I<FYA;64H)&]L9'!A=&@I+"!B87-E;F%M
M92@D;VQD<&%T:"DL(&1I<FYA;64H)&YE=W!A=&@I+"!B87-E;F%M92@D;F5W
M<&%T:"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E(&$@9F]L9&5R
M(&EN('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T
M:"`@5&AE('!A=&@@=&\@=&AE(&9O;&1E<BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A=&5&
M;VQD97(H)'!A=&@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=F9S
M+3YC<F5A=&5&;VQD97(H9&ER;F%M92@D<&%T:"DI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1&5L971E<R!A(&9O;&1E<B!F<F]M('1H92!61E,N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"!4:&4@<&%T:"!O9B!T:&4@
M9F]L9&5R('1O(&1E;&5T92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&5&;VQD97(H)'!A
M=&@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=F9S+3YD96QE=&5&
M;VQD97(H9&ER;F%M92@D<&%T:"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!A(%9&4U],:7-T271E;2!O8FIE8W0@:68@=&AE(&9O;&1E<B!C
M86X*("`@("`J(&)E(')E860L(&]R(&$@4$5!4E]%<G)O<B!I9B!I="!C86XG
M="!B92X@4F5T=7)N<R!F86QS92!O;F-E"B`@("`@*B!T:&4@9F]L9&5R(&AA
M<R!B965N(&-O;7!L971E;'D@<F5A9"X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P871H("!4:&4@<&%T:"!O9B!T:&4@9&ER971O<GDN"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@1FEL92!L:7-T("AA<G)A>2D@;VX@
M<W5C8V5S<RP@82!014%27T5R<F]R"B`@("`@*B`@("`@("`@("`@("`@("!O
M8FIE8W0@;VX@9F%I;'5R92P@;W(@9F%L<V4@:68@=&AE(&9O;&1E<B!I<PH@
M("`@("H@("`@("`@("`@("`@("`@8V]M<&QE=&5L>2!R96%D+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!L:7-T1F]L9&5R*"1P871H*0H@("`@>PH@("`@("`@
M(&EF("@A*"1P871H(#T]/2`D=&AI<RT^7V-U<G)E;G10871H*2D@>PH@("`@
M("`@("`@("`D9F]L9&5R3&ES="`]("1T:&ES+3Y?=F9S+3YL:7-T1F]L9&5R
M*"1P871H*3L*("`@("`@("`@("`@:68@*"1F;VQD97),:7-T*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7V9O;&1E<DQI<W0@/2`D9F]L9&5R3&ES=#L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=%!A=&@@/2`D<&%T:#L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B0V]U;&0@;F]T(')E860@)7,N
M(BDL("1P871H*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O3&ES=$ET96TN
M<&AP)SL*("`@("`@("!I9B`H)&9I;&4@/2!A<G)A>5]S:&EF="@D=&AI<RT^
M7V9O;&1E<DQI<W0I*2!["B`@("`@("`@("`@("1F:6QE(#T@)FYE=R!61E-?
M3&ES=$ET96TH)'!A=&@L("1F:6QE*3L*("`@("`@("`@("`@<F5T=7)N("1F
M:6QE.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&%N9V5S('!E
M<FUI<W-I;VYS(&9O<B!A;B!)=&5M(&]N('1H92!61E,N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("`@2&]L9',@=&AE('!A=&@@
M;V8@9&ER96-T;W)Y(&]F('1H92!)=&5M+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<&5R;6ES<VEO;B`@5$]$3PH@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-H86YG95!E<FUI<W-I
M;VYS*"1P871H+"`D<&5R;6ES<VEO;BD*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]V9G,M/F-H86YG95!E<FUI<W-I;VYS*&1I<FYA;64H)'!A=&@I
M+"!B87-E;F%M92@D<&%T:"DL("1P97)M:7-S:6]N*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;B!T:&4@;&ES="!O9B!A9&1I=&EO;F%L(&-R961E
M;G1I86QS(')E<75I<F5D+"!I9B!A;GDN"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@0W)E9&5N=&EA;"!L:7-T+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971297%U:7)E9$-R961E;G1I86QS*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]V9G,M/F=E=%)E<75I<F5D0W)E9&5N=&EA;',H*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@87)R87D@<W!E8VEF:6-Y
M:6YG('=H870@<&5R;6ES<VEO;G,@87)E(&-H86YG96%B;&4@9F]R('1H:7,*
M("`@("`J(&EM<&QE;65N=&%T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@($-H86YG96%B;&4@<&5R;6ES:6]N<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T36]D:69I86)L95!E<FUI<W-I;VYS*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]V9G,M/F=E=$UO9&EF:6%B;&5097)M:7-S:6]N
M<R@I.PH@("`@?0H*("`@("\J*@H@("`@("H@0VQO<V4@86YY(')E<V]U<F-E
M<R!T:&%T(&YE960@=&\@8F4@8VQO<V5D+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?9&ES8V]N;F5C="@I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]V9G,M/E]D:7-C;VYN96-T*"D["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U9&4R]S
M;6(N<&AP````````````````````````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`U-C`Q-@`Q,#4Q-30S,S<T-0`P,C`S-C4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J(%-T871E
M;&5S<R!61E,@:6UP;&5M96YT871I;VX@9F]R(&$@4TU"('-E<G9E<BP@8F%S
M960@;VX@<VUB8VQI96YT+@H@*@H@*B!297%U:7)E9"!V86QU97,@9F]R("1P
M87)A;7,Z"B`J(#QP<F4^"B`J("`@)W5S97)N86UE)R`@+2!4:&4@=7-E<FYA
M;64@=VET:"!W:&EC:"!T;R!C;VYN96-T('1O('1H92!334(@<V5R=F5R+@H@
M*B`@("=P87-S=V]R9"<@("T@5&AE('!A<W-W;W)D('=I=&@@=VAI8V@@=&\@
M8V]N;F5C="!T;R!T:&4@4TU"('-E<G9E<BX*("H@("`G:&]S='-P96,G("`M
M(%1H92!334(@<V5R=F5R('1O(&-O;FYE8W0@=&\N"B`J("`@)W!O<G0G("`@
M("`@+2!4:&4@4TU"('!O<G0@;G5M8F5R('1O(&-O;FYE8W0@=&\N"B`J("`@
M)W-H87)E)R`@("`@+2!4:&4@<VAA<F4@=&\@86-C97-S(&]N('1H92!334(@
M<V5R=F5R+@H@*B`@("=S;6)C;&EE;G0G("T@5&AE('!A=&@@=&\@=&AE("=S
M;6)C;&EE;G0G(&5X96-U=&%B;&4N"B`J(#PO<')E/@H@*@H@*B!/<'1I;VYA
M;"!V86QU97,@9F]R("1P87)A;7,Z"B`J(#QP<F4^"B`J("`@)VEP861D<F5S
M<R<@+2!4:&4@861D<F5S<R!O9B!T:&4@<V5R=F5R('1O(&-O;FYE8W0@=&\N
M"B`J(#PO<')E/@H@*@H@*B!&=6YC=&EO;G,@;F]T(&EM<&QE;65N=&5D.@H@
M*B`@("T@8VAA;F=E4&5R;6ES<VEO;G,H*3H@5&AE(%--0B!P97)M:7-S:6]N
M('-T>6QE(&1O97,@;F]T(&9I="!W:71H('1H90H@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@;6]D=6QE+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`L=B`Q+C$Q+C(N."`R,#`V+S`U+S,Q(#`T.C4P.C`R
M('-L=7-A<GH@17AP("0*("H*("H@0V]D96)A<V4@8V]P>7)I9VAT(#(P,#(@
M4&%U;"!'87)E874@/'!A=6Q`>&AA=VLN;F5T/BX@($%D87!T960@=VET:`H@
M*B!P97)M:7-S:6]N(&)Y(%!A=')I8V4@3&5V97-Q=64@/'=A>6YE0'!T869F
M+F-A/B!F<F]M('!H<'-M8BTP+C@@8V]D92P@86YD"B`J(&-O;G9E<G1E9"!T
M;R!T:&4@3$=03"X@(%!L96%S92!D;R!N;W0@=&%U;G0@;W)I9VEN86P@875T
M:&]R+"!C;VYT86-T"B`J(%!A=')I8V4@3&5V97-Q=64@;W(@9&5V0&QI<W1S
M+FAO<F1E+F]R9RX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@(%!A=6P@
M1V%R96%U(#QP875L0'AH87=K+FYE=#X*("H@0&%U=&AO<B`@4&%T<FEC92!,
M979E<W%U92`\=V%Y;F5`<'1A9F8N8V$^"B`J($!S:6YC92`@($AO<F1E(#,N
M,0H@*B!`<&%C:V%G92!61E,*("HO"F-L87-S(%9&4U]S;6(@97AT96YD<R!6
M1E,@>PH*("`@("\J*@H@("`@("H@3&ES="!O9B!A9&1I=&EO;F%L(&-R961E
M;G1I86QS(')E<75I<F5D(&9O<B!T:&ES(%9&4R!B86-K96YD+@H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?8W)E9&5N=&EA
M;',@/2!A<G)A>2@G=7-E<FYA;64G+"`G<&%S<W=O<F0G*3L*"B`@("`O*BH*
M("`@("`J($QI<W0@;V8@<&5R;6ES<VEO;G,@86YD(&EF('1H97D@8V%N(&)E
M(&-H86YG960@:6X@=&AI<R!61E,@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!E<FUI<W-I;VYS(#T@87)R
M87DH"B`@("`@("`@)V]W;F5R)R`]/B!A<G)A>2@G<F5A9"<@/3X@9F%L<V4L
M("=W<FET92<@/3X@9F%L<V4L("=E>&5C=71E)R`]/B!F86QS92DL"B`@("`@
M("`@)V=R;W5P)R`]/B!A<G)A>2@G<F5A9"<@/3X@9F%L<V4L("=W<FET92<@
M/3X@9F%L<V4L("=E>&5C=71E)R`]/B!F86QS92DL"B`@("`@("`@)V%L;"<@
M("`]/B!A<G)A>2@G<F5A9"<@/3X@9F%L<V4L("=W<FET92<@/3X@9F%L<V4L
M("=E>&5C=71E)R`]/B!F86QS92DI.PH*("`@("\J*@H@("`@("H@075T:&5N
M=&EC871E<R!A('5S97(@;VX@=&AE(%--0B!S97)V97(@86YD('-H87)E+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;GQ014%27T5R<F]R("!4<G5E(&]N('-U8V-E<W,@;W(@
M82!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]C;VYN96-T*"D*("`@('L*("`@("`@("`D8VUD(#T@87)R87DH)W%U:70G
M*3L*("`@("`@("`D97)R(#T@)'1H:7,M/E]C;VUM86YD*"<G+"`D8VUD*3L*
M("`@("`@("!I9B`H:7-?82@D97)R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D%U=&AE;G1I8V%T
M:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB*2D["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M<FEE=F5S(&$@9FEL92!F<F]M('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&AN86UE('1O('1H92!F:6QE+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9I;&5N86UE('1O(')E
M=')I979E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9FEL
M92!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D*"1P871H+"`D;F%M
M92D*("`@('L*("`@("`@("!L:7-T*"1P871H+"`D;F%M92D@/2`D=&AI<RT^
M7V5S8V%P95-H96QL0V]M;6%N9"@D<&%T:"P@)&YA;64I.PH@("`@("`@("1T
M96UP(#T@)'1H:7,M/E]G971496UP1FEL92@I.PH@("`@("`@("1C;60@/2!A
M<G)A>2@G9V5T(%PB)R`N("1N86UE("X@)UPB("<@+B`D=&5M<"D["B`@("`@
M("`@)&5R<B`]("1T:&ES+3Y?8V]M;6%N9"@D<&%T:"P@)&-M9"D["B`@("`@
M("`@:68@*&ES7V$H)&5R<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&5R<CL*("`@("`@("!]"B`@("`@("`@:68@*"%F:6QE7V5X
M:7-T<R@D=&5M<"DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S
M7"(N(BDL("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I*2D["B`@("`@
M("`@?0H@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T7V-O
M;G1E;G1S)RDI('L*("`@("`@("`@("`@)&9I;&4@/2!F:6QE7V=E=%]C;VYT
M96YT<R@D=&5M<"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&9P
M(#T@9F]P96XH)'1E;7`L("=R)RD["B`@("`@("`@("`@("1F:6QE(#T@9G)E
M860H)&9P+"!F:6QE<VEZ92@D=&5M<"DI.PH@("`@("`@("`@("!F8VQO<V4H
M)&9P*3L*("`@("`@("!]"B`@("`@("`@=6YL:6YK*"1T96UP*3L*("`@("`@
M("!I9B`H)&9I;&4I('L*("`@("`@("`@("`@<F5T=7)N("1F:6QE.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB
M+B(I+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%-T;W)E<R!A(&9I;&4@:6X@=&AE
M(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@
M("`@5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N86UE("`@("`@("`@5&AE(&9I;&5N86UE('1O('5S92X*
M("`@("`J($!P87)A;2!S=')I;F<@)'1M<$9I;&4@("`@("!4:&4@=&5M<&]R
M87)Y(&9I;&4@8V]N=&%I;FEN9R!T:&4@9&%T82!T;R!B90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('-T;W)E9"X*("`@("`J($!P87)A
M;2!B;V]L96%N("1A=71O8W)E871E("!!=71O;6%T:6-A;&QY(&-R96%T92!D
M:7)E8W1O<FEE<S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86Y\4$5!
M4E]%<G)O<B`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET92@D<&%T:"P@)&YA
M;64L("1T;7!&:6QE+"`D875T;V-R96%T92`](&9A;'-E*0H@("`@>PH@("`@
M("`@("\O($1O=6)L92!Q=6]T97,@;F]T(&%L;&]W960@:6X@4TU"(&9I;&5N
M86UE+@H@("`@("`@("1N86UE(#T@<W1R7W)E<&QA8V4H)R(G+"`B)R(L("1N
M86UE*3L*"B`@("`@("`@;&ES="@D<&%T:"P@)&YA;64I(#T@)'1H:7,M/E]E
M<V-A<&53:&5L;$-O;6UA;F0H)'!A=&@L("1N86UE*3L*("`@("`@("`D8VUD
M(#T@87)R87DH)W!U="!<(B<@+B`D=&UP1FEL92`N("=<(B!<(B<@+B`D;F%M
M92`N("=<(B<I.PH@("`@("`@("\O(&1O('=E(&YE960@=&\@9FER<W0@875T
M;V-R96%T92!T:&4@9&ER96-T;W)Y/PH@("`@("`@(&EF("@D875T;V-R96%T
M92D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F%U=&]C<F5A=&50
M871H*"1P871H*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@)&5R<B`]("1T:&ES
M+3Y?8V]M;6%N9"@D<&%T:"P@)&-M9"D["B`@("`@("`@:68@*&ES7V$H)&5R
M<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<CL*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3=&]R97,@82!F:6QE(&EN('1H92!61E,@9G)O;2!R87<@9&%T
M82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("`@
M5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N86UE("`@("`@("`@5&AE(&9I;&5N86UE('1O('5S92X*("`@
M("`J($!P87)A;2!S=')I;F<@)&1A=&$@("`@("`@("!4:&4@9FEL92!D871A
M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%U=&]C<F5A=&4@($%U=&]M871I
M8V%L;'D@8W)E871E(&1I<F5C=&]R:65S/PH@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;GQ014%27T5R<F]R("!4<G5E(&]N('-U8V-E<W,@;W(@82!0
M14%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R
M:71E1&%T82@D<&%T:"P@)&YA;64L("1D871A+"`D875T;V-R96%T92`](&9A
M;'-E*0H@("`@>PH@("`@("`@("1T;7!&:6QE(#T@)'1H:7,M/E]G971496UP
M1FEL92@I.PH@("`@("`@("1F<"`](&9O<&5N*"1T;7!&:6QE+"`G=V(G*3L*
M("`@("`@("!F=W)I=&4H)&9P+"`D9&%T82D["B`@("`@("`@9F-L;W-E*"1F
M<"D["B`@("`@("`@)')E<W5L="`]("1T:&ES+3YW<FET92@D<&%T:"P@)&YA
M;64L("1T;7!&:6QE+"`D875T;V-R96%T92D["B`@("`@("`@=6YL:6YK*"1T
M;7!&:6QE*3L*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O
M*BH*("`@("`J($1E;&5T97,@82!F:6QE(&9R;VT@=&AE(%9&4RX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!T;R!D96QE
M=&4@=&AE(&9I;&4@9G)O;2X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@
M(%1H92!F:6QE;F%M92!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N?%!%05)?17)R;W(@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?
M17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E
M1FEL92@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@;&ES="@D<&%T:"P@
M)&YA;64I(#T@)'1H:7,M/E]E<V-A<&53:&5L;$-O;6UA;F0H)'!A=&@L("1N
M86UE*3L*("`@("`@("`D8VUD(#T@87)R87DH)V1E;"!<(B<@+B`D;F%M92`N
M("=<(B<I.PH@("`@("`@("1E<G(@/2`D=&AI<RT^7V-O;6UA;F0H)'!A=&@L
M("1C;60I.PH@("`@("`@(&EF("AI<U]A*"1E<G(L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1E<G(["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS(&EF
M(&$@9VEV96X@<&%T:&YA;64@:7,@82!F;VQD97(N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@=&\@=&AE(&9O;&1E<BX*
M("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F:6QE(&]R(&9O;&1E
M<B!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I
M9B!I="!I<R!A(&9O;&1E<BP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!I<T9O;&1E<B@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@
M("`@;&ES="@D<&%T:"P@)&YA;64I(#T@)'1H:7,M/E]E<V-A<&53:&5L;$-O
M;6UA;F0H)'!A=&@L("1N86UE*3L*("`@("`@("`D8VUD(#T@87)R87DH)W%U
M:70G*3L*("`@("`@("`D97)R(#T@)'1H:7,M/E]C;VUM86YD*"1T:&ES+3Y?
M9V5T4&%T:"@D<&%T:"P@)&YA;64I+"`D8VUD*3L*("`@("`@("!I9B`H:7-?
M82@D97)R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@9F]L9&5R(&9R;VT@=&AE(%9&4RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("!4:&4@
M<&%T:"!T;R!D96QE=&4@=&AE(&9O;&1E<B!F<F]M+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F%M92`@("`@("`@5&AE(&YA;64@;V8@=&AE(&9O;&1E<B!T
M;R!D96QE=&4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<F5C=7)S:79E("!&
M;W)C92!A(')E8W5R<VEV92!D96QE=&4_"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N?%!%05)?17)R;W(@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%
M05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L
M971E1F]L9&5R*"1P871H+"`D;F%M92P@)')E8W5R<VEV92`](&9A;'-E*0H@
M("`@>PH@("`@("`@("1I<T1I<B`](&9A;'-E.PH@("`@("`@("1D:7)#:&5C
M:R`]("1T:&ES+3YL:7-T1F]L9&5R*"1P871H*3L*("`@("`@("!F;W)E86-H
M("@D9&ER0VAE8VL@87,@)&9I;&4I('L*("`@("`@("`@("`@:68@*"1F:6QE
M6R=N86UE)UT@/3T@)&YA;64@)B8@)&9I;&5;)W1Y<&4G72`]/2`G*BID:7(G
M*2!["B`@("`@("`@("`@("`@("`D:7-$:7(@/2!T<G5E.PH@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(&EF("@A)&ES1&ER*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*'-P<FEN=&8H7R@B7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB
M*2P@)'!A=&@@+B`G+R<@+B`D;F%M92DI.PH@("`@("`@('T*"B`@("`@("`@
M)&9I;&5?;&ES="`]("1T:&ES+3YL:7-T1F]L9&5R*"1T:&ES+3Y?9V5T4&%T
M:"@D<&%T:"P@)&YA;64I*3L*("`@("`@("!I9B`H:7-?82@D9FEL95]L:7-T
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D9FEL95]L
M:7-T.PH@("`@("`@('T*"B`@("`@("`@:68@*"1F:6QE7VQI<W0@)B8@(21R
M96-U<G-I=F4I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I
M<F5C=&]R>2!I<R!N;W0@96UP='DN(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G9710871H*"1P871H
M+"`D;F%M92DI*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1F:6QE
M7VQI<W0@87,@)&9I;&4I('L*("`@("`@("`@("`@:68@*"1F:6QE6R=T>7!E
M)UT@/3T@)RHJ9&ER)RD@>PH@("`@("`@("`@("`@("`@)')E<W5L="`]("1T
M:&ES+3YD96QE=&5&;VQD97(H)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M
M92DL("1F:6QE6R=N86UE)UTL("1R96-U<G-I=F4I.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YD96QE
M=&5&:6QE*"1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I+"`D9FEL95LG
M;F%M92==*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M+R\@4F5A;&QY(&1E;&5T92!T:&4@9F]L9&5R+@H@("`@("`@(&QI<W0H)'!A
M=&@L("1N86UE*2`]("1T:&ES+3Y?97-C87!E4VAE;&Q#;VUM86YD*"1P871H
M+"`D;F%M92D["B`@("`@("`@)&-M9"`](&%R<F%Y*"=R;61I<B!<(B<@+B`D
M;F%M92`N("=<(B<I.PH@("`@("`@("1E<G(@/2`D=&AI<RT^7V-O;6UA;F0H
M)'!A=&@L("1C;60I.PH@("`@("`@(&EF("AI<U]A*"1E<G(L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M<W!R:6YT9BA?*")5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB
M+B(I+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E;F%M97,@82!F:6QE(&EN('1H92!6
M1E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VQD<&%T:"`@5&AE
M(&]L9"!P871H('1O('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;VQD;F%M92`@5&AE(&]L9"!F:6QE;F%M92X*("`@("`J($!P87)A;2!S=')I
M;F<@)&YE=W!A=&@@(%1H92!N97<@<&%T:"!O9B!T:&4@9FEL92X*("`@("`J
M($!P87)A;2!S=')I;F<@)&YE=VYA;64@(%1H92!N97<@9FEL96YA;64N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N?%!%05)?17)R;W(@(%1R=64@
M;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5N86UE*"1O;&1P871H+"`D;VQD;F%M92P@)&YE
M=W!A=&@L("1N97=N86UE*0H@("`@>PH@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0@/2`D=&AI<RT^875T;V-R96%T95!A=&@H)&YE=W!A=&@I+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M('T*"B`@("`@("`@+R\@1&]U8FQE('%U;W1E<R!N;W0@86QL;W=E9"!I;B!3
M34(@9FEL96YA;64N"B`@("`@("`@)&YE=VYA;64@/2!S=')?<F5P;&%C92@G
M(B<L("(G(BP@)&YE=VYA;64I.PH*("`@("`@("!L:7-T*"1F:6QE+"`D;F%M
M92D@/2`D=&AI<RT^7V5S8V%P95-H96QL0V]M;6%N9"@D;VQD;F%M92P@)&YE
M=VYA;64I.PH@("`@("`@("1C;60@/2!A<G)A>2@G<F5N86UE(%PB)R`N("!S
M=')?<F5P;&%C92@G+R<L("=<7%Q<)RP@)&]L9'!A=&@I("X@)UQ<)R`N("1F
M:6QE("X@)UPB(%PB)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-T<E]R97!L86-E*"<O)RP@)UQ<7%PG+"`D;F5W<&%T:"D@+B`G
M7%PG("X@)&YA;64@+B`G7"(G*3L*("`@("`@("!I9B`H:7-?82@D97)R(#T@
M)'1H:7,M/E]C;VUM86YD*"<G+"`D8VUD*2P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H
M(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(I+"`D=&AI<RT^
M7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@
M9F]L9&5R(&]N('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<&%T:"`@5&AE('!A=&@@;V8@9&ER96-T;W)Y('1O(&-R96%T92!F;VQD
M97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@;F%M92!O9B!T
M:&4@;F5W(&9O;&1E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86Y\
M4$5!4E]%<G)O<B`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A=&5&;VQD97(H
M)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@("\O($1O=6)L92!Q=6]T97,@
M;F]T(&%L;&]W960@:6X@4TU"(&9I;&5N86UE+@H@("`@("`@("1N86UE(#T@
M<W1R7W)E<&QA8V4H)R(G+"`B)R(L("1N86UE*3L*"B`@("`@("`@;&ES="@D
M9&ER+"`D;6MD:7(I(#T@)'1H:7,M/E]E<V-A<&53:&5L;$-O;6UA;F0H)'!A
M=&@L("1N86UE*3L*("`@("`@("`D8VUD(#T@87)R87DH)VUK9&ER(%PB)R`N
M("1M:V1I<B`N("=<(B<I.PH@("`@("`@("1E<G(@/2`D=&AI<RT^7V-O;6UA
M;F0H)&1I<BP@)&-M9"D["B`@("`@("`@:68@*&ES7V$H)&5R<BP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BAS<')I;G1F*%\H(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S
M7"(N(BDL("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I*2D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A;B!U;G-O<G1E9"!F:6QE(&QI<W0N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("!4:&4@<&%T:"!O9B!T:&4@
M9&ER96-T;W)Y('1O(&=E="!T:&4@9FEL92!L:7-T"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&9O<BX*("`@("`J($!P87)A;2!M:7AE9"`D
M9FEL=&5R("`@("`@2&%S:"!O9B!I=&5M<R!T;R!F:6QT97(@8F%S960@;VX@
M9FEL96YA;64N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&]T9FEL97,@(%-H
M;W<@9&]T9FEL97,_(%1H:7,@:7,@:7)R96QE=F%N="!W:71H"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@('-M8F-L:65N="X*("`@("`J($!P
M87)A;2!B;V]L96%N("1D:7)O;FQY("`@4VAO=R!D:7)E8W1O<FEE<R!O;FQY
M/PH@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;GQ014%27T5R<F]R("!&
M:6QE(&QI<W0@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;VX*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!L:7-T1F]L9&5R*"1P871H(#T@)R<L("1F:6QT97(@
M/2!N=6QL+"`D9&]T9FEL97,@/2!T<G5E+"`D9&ER;VYL>2`](&9A;'-E*0H@
M("`@>PH@("`@("`@(&QI<W0H)'!A=&@I(#T@)'1H:7,M/E]E<V-A<&53:&5L
M;$-O;6UA;F0H)'!A=&@I.PH@("`@("`@("1C;60@/2!A<G)A>2@G;',G*3L*
M("`@("`@("`D<F5S(#T@)'1H:7,M/E]C;VUM86YD*"1P871H+"`D8VUD*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*("`@("`@("`D;G5M7VQI
M;F5S(#T@8V]U;G0H)')E<RD["B`@("`@("`@)&9I;&5S(#T@87)R87DH*3L*
M("`@("`@("!F;W(@*"1R(#T@,#L@)'(@/"`D;G5M7VQI;F5S.R`D<BLK*2![
M"B`@("`@("`@("`@("\O($UA=&-H(&9I;&4@;&ES=&EN9RX*("`@("`@("`@
M("`@:68@*'!R96=?;6%T8V@H)R]>*%QS7',N*UQS>S8L?2DO)RP@)')E<ULD
M<ETI*2!["B`@("`@("`@("`@("`@("`O+R!3<&QI="!I;G1O(&-O;'5M;G,@
M870@979E<GD@<VEX('-P86-E<PH@("`@("`@("`@("`@("`@)'-P;&ET,2`]
M('!R96=?<W!L:70H)R]<<WLV+'TO)RP@=')I;2@D<F5S6R1R72DI.PH@("`@
M("`@("`@("`@("`@+R\@268@=&AE(&9I;&4@;F%M92!I<VXG="`N(&]R("XN
M"B`@("`@("`@("`@("`@("!I9B`H)'-P;&ET,5LP72`A/2`G+B<@)B8@)'-P
M;&ET,5LP72`A/2`G+BXG*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1S<&QI=#%;,ETI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\O
M($EF('1H97)E(&ES(&$@<VUA;&P@9FEL92!S:7IE+"!I;F8@8V]U;&0@8F4@
M<W!L:70*("`@("`@("`@("`@("`@("`@("`@("`@+R\@:6YT;R`S(&-O;',N
M"B`@("`@("`@("`@("`@("`@("`@("`@("1S<&QI=#%;,5T@+CT@)R`G("X@
M)'-P;&ET,5LR73L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@+R\@4W!L:70@9FEL92!I;F8@870@979E<GD@;VYE(&]R(&UO
M<F4@<W!A8V5S+@H@("`@("`@("`@("`@("`@("`@("1S<&QI=#(@/2!P<F5G
M7W-P;&ET*"<O7',K+R<L("1S<&QI=#%;,5TI.PH@("`@("`@("`@("`@("`@
M("`@(&EF("AI<U]N=6UE<FEC*"1S<&QI=#);,%TI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("\O($EF('1H97)E(&ES(&YO(&9I;&4@871T<BP@<VAI
M9G0@8V]L<R!O=F5R+@H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]U
M;G-H:69T*"1S<&QI=#(L("<G*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@)&UY7VYA;64@/2`D<W!L:70Q6S!=.PH*("`@
M("`@("`@("`@("`@("`@("`O+R!&:6QT97(@;W5T(&1O=&9I;&5S(&EF('1H
M97D@87)E;B=T('=A;G1E9"X*("`@("`@("`@("`@("`@("`@("!I9B`H(21D
M;W1F:6QE<R`F)B!S=6)S='(H)&UY7VYA;64L(#`L(#$I(#T]("<N)RD@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@("1M>5]S:7IE(#T@)'-P
M;&ET,ELQ73L*("`@("`@("`@("`@("`@("`@("`D97AT7VYA;64@/2!E>'!L
M;V1E*"<N)RP@)&UY7VYA;64I.PH*("`@("`@("`@("`@("`@("`@("!I9B`H
M*'-T<G!O<R@D<W!L:70R6S!=+"`G1"<I("$]/2!F86QS92DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&UY7W1Y<&4@/2`G*BID:7(G.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D;7E?<VEZ92`]("TQ.PH@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1M>5]T
M>7!E(#T@5D93.CIS=')T;VQO=V5R*"1E>'1?;F%M95MC;W5N="@D97AT7VYA
M;64I("T@,5TI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`D;7E?9&%T92`]('-T<G1O=&EM92@D<W!L:70R6S1=("X@)R`G
M("X@)'-P;&ET,ELS72`N("<@)R`N"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'-P;&ET,ELV72`N("<@)R`N("1S<&QI=#);
M-5TI.PH@("`@("`@("`@("`@("`@("`@("1F:6QE9&%T82`](&%R<F%Y*"=O
M=VYE<B<@/3X@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V=R;W5P)R`]/B`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<&5R;7,G(#T^("<G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B`D;7E?;F%M92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@/3X@
M)&UY7W1Y<&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V1A=&4G(#T^("1M>5]D871E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=S:7IE)R`]/B`D;7E?<VEZ92D["B`@("`@("`@
M("`@("`@("`@("`@+R\@=V%T8V@@9F]R(&9I;'1E<G,@86YD(&1I<F]N;'D*
M("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]F:6QT97)-871C:"@D
M9FEL=&5R+"`D;7E?;F%M92DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M=6YS970H)&9I;&4I.PH@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M:68@*"1D:7)O;FQY("8F("1M>5]T>7!E("$]/2`G*BID:7(G*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@('5N<V5T*"1F:6QE*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("`@("`D9FEL97-;)&9I;&5D871A6R=N86UE)UU=
M(#T@)&9I;&5D871A.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D9FEL97,["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&$@<V]R=&5D(&QI<W0@;V8@9F]L9&5R<R!I
M;B!S<&5C:69I960@9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'!A=&@@("`@("`@("!4:&4@<&%T:"!O9B!T:&4@9&ER96-T;W)Y
M('1O(&=E="!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!D:7)E8W1O<GD@;&ES="!F;W(N"B`@("`@*B!`<&%R86T@;6EX960@)&9I
M;'1E<B`@("`@("`@2&%S:"!O9B!I=&5M<R!T;R!F:6QT97(@8F%S960@;VX@
M9F]L9&5R;&ES="X*("`@("`J($!P87)A;2!B;V]L96%N("1D;W1F;VQD97)S
M("!);F-L=61E(&1O=&9O;&1E<G,_($ER<F5L979A;G0@9F]R(%--0BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86Y\4$5!4E]%<G)O<B`@1F]L9&5R
M(&QI<W0@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;VX*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!L:7-T1F]L9&5R<R@D<&%T:"`]("<G+"`D9FEL=&5R(#T@
M;G5L;"P@)&1O=&9O;&1E<G,@/2!T<G5E*0H@("`@>PH@("`@("`@("1F;VQD
M97)S(#T@87)R87DH*3L*("`@("`@("`D9F]L9&5R(#T@87)R87DH*3L*"B`@
M("`@("`@)&9O;&1E<DQI<W0@/2`D=&AI<RT^;&ES=$9O;&1E<B@D<&%T:"P@
M;G5L;"P@)&1O=&9O;&1E<G,L('1R=64I.PH@("`@("`@(&EF("AI<U]A*"1F
M;VQD97),:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D9F]L9&5R3&ES=#L*("`@("`@("!]"@H@("`@("`@("\O(&1I<FYA;64@
M=VEL;"!S=')I<"!L87-T(&-O;7!O;F5N="!F<F]M('!A=&@L(&5V96X@;VX@
M82!D:7)E8W1O<GD*("`@("`@("`D9F]L9&5R6R=V86PG72`](&1I<FYA;64H
M)'!A=&@I.PH@("`@("`@("1F;VQD97);)V%B8G)E=B==(#T@)RXN)SL*("`@
M("`@("`D9F]L9&5R6R=L86)E;"==(#T@)RXN)SL*"B`@("`@("`@)&9O;&1E
M<G-;)&9O;&1E<ELG=F%L)UU=(#T@)&9O;&1E<CL*"B`@("`@("`@9F]R96%C
M:"`H)&9O;&1E<DQI<W0@87,@)&9I;&5S*2!["B`@("`@("`@("`@("1F;VQD
M97);)W9A;"==(#T@)'1H:7,M/E]G9710871H*"1P871H+"`D9FEL97-;)VYA
M;64G72D["B`@("`@("`@("`@("1F;VQD97);)V%B8G)E=B==(#T@)&9I;&5S
M6R=N86UE)UT["B`@("`@("`@("`@("1F;VQD97);)VQA8F5L)UT@/2`D9F]L
M9&5R6R=V86PG73L*"B`@("`@("`@("`@("1F;VQD97)S6R1F;VQD97);)W9A
M;"==72`]("1F;VQD97(["B`@("`@("`@?0H*("`@("`@("!K<V]R="@D9F]L
M9&5R<RD["B`@("`@("`@<F5T=7)N("1F;VQD97)S.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0V]P:65S(&$@9FEL92!T:')O=6=H('1H92!B86-K96YD+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H('1O
M('-T;W)E('1H92!F:6QE(&EN+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M
M92`@5&AE(&9I;&5N86UE('1O('5S92X*("`@("`J($!P87)A;2!S=')I;F<@
M)&1E<W0@(%1H92!D97-T:6YA=&EO;B!O9B!T:&4@9FEL92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86Y\4$5!4E]%<G)O<B`@5')U92!O;B!S=6-C
M97-S(&]R(&$@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!C;W!Y*"1P871H+"`D;F%M92P@)&1E<W0I"B`@("!["B`@("`@
M("`@)&]R:6<@/2`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*3L*("`@
M("`@("!I9B`H<')E9U]M871C:"@G?%XG("X@<')E9U]Q=6]T92@D;W)I9RD@
M+B`G+S\D?"<L("1D97-T*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BA?*")#86YN;W0@8V]P>2!F:6QE*',I("T@<V]U<F-E(&%N
M9"!D97-T:6YA=&EO;B!A<F4@=&AE('-A;64N(BDI.PH@("`@("`@('T*"B`@
M("`@("`@)&9I;&5#:&5C:R`]("1T:&ES+3YL:7-T1F]L9&5R*"1D97-T+"!N
M=6QL+"!T<G5E*3L*("`@("`@("!F;W)E86-H("@D9FEL94-H96-K(&%S("1F
M:6QE*2!["B`@("`@("`@("`@(&EF("@D9FEL95LG;F%M92==(#T]("1N86UE
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS
M<')I;G1F*%\H(B5S(&%L<F5A9'D@97AI<W1S+B(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E
M=%!A=&@H)&1E<W0L("1N86UE*2DI.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("`D:7-$:7(@/2!F86QS93L*("`@("`@("`D9&ER0VAE8VL@
M/2`D=&AI<RT^;&ES=$9O;&1E<B@D<&%T:"P@;G5L;"P@9F%L<V4I.PH@("`@
M("`@(&9O<F5A8V@@*"1D:7)#:&5C:R!A<R`D9FEL92D@>PH@("`@("`@("`@
M("!I9B`H)&9I;&5;)VYA;64G72`]/2`D;F%M92`F)B`D9FEL95LG='EP92==
M(#T]("<J*F1I<B<I('L*("`@("`@("`@("`@("`@("1I<T1I<B`]('1R=64[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@:68@*"1I<T1I<BD@>PH@("`@("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/F-R96%T949O;&1E<B@D9&5S="P@)&YA;64I.PH*("`@("`@
M("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1F:6QE7VQI<W0@/2`D=&AI<RT^;&ES=$9O;&1E<B@D;W)I
M9RD["B`@("`@("`@("`@(&9O<F5A8V@@*"1F:6QE7VQI<W0@87,@)&9I;&4I
M('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^8V]P>2@D;W)I
M9RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEL
M95LG;F%M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9V5T4&%T:"@D9&5S="P@)&YA;64I*3L*("`@("`@("`@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1T;7!&:6QE(#T@)'1H:7,M/E]C<F5A=&5496UP1FEL92@D<&%T:"P@
M)&YA;64I.PH@("`@("`@("`@("!I9B`H:7-?82@D=&UP1FEL92P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H<W!R:6YT9BA?*")&86EL960@=&\@<F5T<FEE=F4Z("5S(BDL("1O
M<FEG*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1R97,@/2`D=&AI
M<RT^=W)I=&4H)&1E<W0L("1N86UE+"`D=&UP1FEL92D["B`@("`@("`@("`@
M('5N;&EN:R@D=&UP1FEL92D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97,L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*'-P<FEN=&8H7R@B0V]P>2!F86EL960Z("5S(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?9V5T4&%T:"@D9&5S="P@)&YA;64I*2D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@36]V97,@82!F:6QE('1H<F]U9V@@=&AE(&)A8VME;F0N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@
M=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N
M86UE("!4:&4@9FEL96YA;64@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9&5S="`@5&AE(&1E<W1I;F%T:6]N(&]F('1H92!F:6QE+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;GQ014%27T5R<F]R("!4<G5E(&]N('-U
M8V-E<W,@;W(@82!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&UO=F4H)'!A=&@L("1N86UE+"`D9&5S="D*("`@('L*("`@
M("`@("`D;W)I9R`]("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I.PH@
M("`@("`@(&EF("AP<F5G7VUA=&-H*"=\7B<@+B!P<F5G7W%U;W1E*"1O<FEG
M*2`N("<O/R1\)RP@)&1E<W0I*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(D-A;FYO="!M;W9E(&9I;&4H<RD@+2!D97-T:6YA
M=&EO;B!I<R!W:71H:6X@<V]U<F-E+B(I*3L*("`@("`@("!]"@H@("`@("`@
M("1F:6QE0VAE8VL@/2`D=&AI<RT^;&ES=$9O;&1E<B@D9&5S="P@;G5L;"P@
M=')U92D["B`@("`@("`@9F]R96%C:"`H)&9I;&5#:&5C:R!A<R`D9FEL92D@
M>PH@("`@("`@("`@("!I9B`H)&9I;&5;)VYA;64G72`]/2`D;F%M92D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT
M9BA?*"(E<R!A;')E861Y(&5X:7-T<RXB*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G9710871H
M*"1D97-T+"`D;F%M92DI*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@)&5R<B`]("1T:&ES+3YR96YA;64H)'!A=&@L("1N86UE+"`D9&5S
M="P@)&YA;64I.PH@("`@("`@(&EF("AI<U]A*"1E<G(L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R
M:6YT9BA?*")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G
M9710871H*"1D97-T+"`D;F%M92DI*3L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!F
M=6QL('!A=&@@;V8@86X@:71E;2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1P871H("!4:&4@<&%T:"!O9B!D:7)E8W1O<GD@;V8@=&AE(&ET96TN
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@;F%M92!O9B!T:&4@
M:71E;2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!&=6QL('!A=&@@
M=VAE;B`D<&%T:"!I<W-E="!A;F0@:G5S="`D;F%M92!W:&5N(&YO="!S970N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G9710871H*"1P871H+"`D;F%M92D*
M("`@('L*("`@("`@("!I9B`H)'!A=&@@(3T]("<G*2!["B`@("`@("`@("`@
M("!R971U<FX@*"1P871H("X@)R\G("X@)&YA;64I.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)&YA;64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!297!L
M86-E;65N="!F;W(@97-C87!E<VAE;&QC;60H*2P@=F%R:6%B;&4@;&5N9W1H
M(&%R9W,L(&%S('=E(&]N;'D@=V%N=`H@("`@("H@8V5R=&%I;B!C:&%R86-T
M97)S(&5S8V%P960N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1A<G)A>2`@4W1R:6YG<R!T;R!E
M<V-A<&4N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>0H@("`@("HO"B`@
M("!F=6YC=&EO;B!?97-C87!E4VAE;&Q#;VUM86YD*"D*("`@('L*("`@("`@
M("`D<F5T(#T@87)R87DH*3L*("`@("`@("`D87)G<R`](&9U;F-?9V5T7V%R
M9W,H*3L*("`@("`@("!F;W)E86-H("@D87)G<R!A<R`D87)G*2!["B`@("`@
M("`@("`@("1R971;72`]('-T<E]R97!L86-E*&%R<F%Y*"<[)RP@)UQ<)RDL
M(&%R<F%Y*"=<.R<L("=<7%Q<)RDL("1A<F<I.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)')E=#L*("`@('T*"B`@("`O*BH*("`@("`J($5X96-U=&5S
M(&$@8V]M;6%N9"!A;F0@<F5T=7)N<R!O=71P=70@;&EN97,@:6X@87)R87DN
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8VUD("!#;VUM86YD('1O(&)E(&5X96-U=&5D"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@07)R87D@;VX@<W5C8V5S<RP@
M9F%L<V4@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V5X96-U
M=&4H)&-M9"D*("`@('L*("`@("`@("`D8VUD(#T@<W1R7W)E<&QA8V4H)R(M
M524B)RP@)RU.)RP@)&-M9"D["B`@("`@("`@97AE8R@D8VUD+"`D;W5T+"`D
M<F5T*3L*"B`@("`@("`@+R\@26X@<V]M92!C87-E<RP@*&QI:V4@=')Y:6YG
M('1O(&1E;&5T92!A(&YO;F5X:7-T86YT(&9I;&4I+`H@("`@("`@("\O('-M
M8F-L:65N="!W:6QL(')E='5R;B!S=6-C97-S("AA="!L96%S="!O;B`R+C(N
M-R!V97)S:6]N($DG;0H@("`@("`@("\O('1E<W1I;F<@;VXI+B!3;R!T<GD@
M=&\@;6%T8V@@97)R;W(@<W1R:6YG<RP@979E;B!A9G1E<B!S=6-C97-S+@H@
M("`@("`@(&EF("@D<F5T("$](#`I('L*("`@("`@("`@("`@)&5R<B`]("<G
M.PH@("`@("`@("`@("!F;W)E86-H("@D;W5T(&%S("1L:6YE*2!["B`@("`@
M("`@("`@("`@("!I9B`H<W1R<&]S*"1L:6YE+"`G57-A9V4Z)RD@/3T](#`I
M('L*("`@("`@("`@("`@("`@("`@("`D97)R(#T@)T-O;6UA;F0@<WEN=&%X
M(&EN8V]R<F5C="<["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1L:6YE
M+"`G15)24U)6)RD@(3T](&9A;'-E('Q\"B`@("`@("`@("`@("`@("`@("`@
M<W1R<&]S*"1L:6YE+"`G15)21$]3)RD@(3T](&9A;'-E*2!["B`@("`@("`@
M("`@("`@("`@("`@)&5R<B`]('!R96=?<F5P;&%C92@G+RXJ7"@H+BLI7"DN
M*B\G+"`G7%PQ)RP@)&QI;F4I.PH@("`@("`@("`@("`@("`@("`@(&EF("@A
M)&5R<BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D97)R(#T@)&QI;F4[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&EF("@A)&5R<BD@>PH@("`@("`@("`@("`@("`@)&5R<B`]("1O=70@
M/R`D;W5T6V-O=6YT*"1O=70I("T@,5T@.B`D<F5T.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1E<G(I.PH@
M("`@("`@('T*"B`@("`@("`@+R\@0VAE8VL@9F]R(&5R<F]R<R!E=F5N(&]N
M('-U8V-E<W,N"B`@("`@("`@)&5R<B`]("<G.PH@("`@("`@(&9O<F5A8V@@
M*"1O=70@87,@)&QI;F4I('L*("`@("`@("`@("`@:68@*'-T<G!O<R@D;&EN
M92P@)TY47U-405154U].3U]354-(7T9)3$4G*2`A/3T@9F%L<V4@?'P*("`@
M("`@("`@("`@("`@('-T<G!O<R@D;&EN92P@)TY47U-405154U]/0DI%0U1?
M3D%-15].3U1?1D]53D0G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@
M("1E<G(@/2!?*").;R!S=6-H(&9I;&4B*3L*("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("!](&5L<V5I9B`H<W1R<&]S*"1L:6YE+"`G3E1?
M4U1!5%537T%#0T534U]$14Y)140G*2`A/3T@9F%L<V4I('L*("`@("`@("`@
M("`@("`@("1E<G(@/2!?*")097)M:7-S:6]N($1E;FEE9"(I.PH@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(&EF("@D97)R*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*"1E<G(I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O=70[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>&5C=71E<R!334(@8V]M;6%N9',@
M+2!W:71H;W5T(&%U=&AE;G1I8V%T:6]N("T@86YD(')E='5R;G,@;W5T<'5T
M"B`@("`@*B!L:6YE<R!I;B!A<G)A>2X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A=&@@($)A
M<V4@<&%T:"!F;W(@8V]M;6%N9"X*("`@("`J($!P87)A;2!A<G)A>2`D8VUD
M("`@0V]M;6%N9',@=&\@8F4@97AE8W5T960N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@07)R87D@;VX@<W5C8V5S<RP@9F%L<V4@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;6UA;F0H)'!A=&@L("1C;60I
M"B`@("!["B`@("`@("`@;&ES="@D<VAA<F4I(#T@)'1H:7,M/E]E<V-A<&53
M:&5L;$-O;6UA;F0H)'1H:7,M/E]P87)A;7-;)W-H87)E)UTI.PH@("`@("`@
M('!U=&5N=B@G4$%34U=$/2<@+B`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G
M72D["B`@("`@("`@)&EP;W!T:6]N(#T@*&ES<V5T*"1T:&ES+3Y?<&%R86US
M6R=I<&%D9')E<W,G72DI(#\@*"<@+4D@)R`N("1T:&ES+3Y?<&%R86US6R=I
M<&%D9')E<W,G72D@.B!N=6QL.PH@("`@("`@("1F=6QL8VUD(#T@)'1H:7,M
M/E]P87)A;7-;)W-M8F-L:65N="==("X*("`@("`@("`@("`@)R`B+R\G("X@
M)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UT@+B`G+R<@+B`D<VAA<F4@+B`G
M(B<@+@H@("`@("`@("`@("`G("(M<"<@+B`D=&AI<RT^7W!A<F%M<ULG<&]R
M="==("X@)R(G("X*("`@("`@("`@("`@)R`B+54G("X@)'1H:7,M/E]P87)A
M;7-;)W5S97)N86UE)UT@+B`G(B<@+@H@("`@("`@("`@("`G("U$("(G("X@
M)'!A=&@@+B`G(B`G("X*("`@("`@("`@("`@)&EP;W!T:6]N("X*("`@("`@
M("`@("`@)R`M8R`B)SL*("`@("`@("!F;W)E86-H("@D8VUD(&%S("1C*2![
M"B`@("`@("`@("`@("1F=6QL8VUD("X]("1C("X@(CLB.PH@("`@("`@('T*
M("`@("`@("`D9G5L;&-M9"`N/2`G(B<["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?97AE8W5T92@D9G5L;&-M9"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971R:65V97,@82!F:6QE(&9R;VT@=&AE(%9&4R!A;F0@<W1O<F5S(&ET('1O
M(&$@=&5M<&]R87)Y(&9I;&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A
M=&AN86UE('1O('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M
M92`@5&AE(&9I;&5N86UE('1O(')E=')I979E+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1H92!T96UP;W)A<GD@9FEL96YA;64@;W(@82!014%2
M7T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C<F5A
M=&5496UP1FEL92@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@;&ES="@D
M<&%T:"P@)&YA;64I(#T@)'1H:7,M/E]E<V-A<&53:&5L;$-O;6UA;F0H)'!A
M=&@L("1N86UE*3L*("`@("`@("`D=&5M<"`]("1T:&ES+3Y?9V5T5&5M<$9I
M;&4H*3L*("`@("`@("`D8VUD(#T@87)R87DH)V=E="!<(B<@+B`D;F%M92`N
M("=<(B`G("X@)'1E;7`I.PH@("`@("`@("1E<G(@/2`D=&AI<RT^7V-O;6UA
M;F0H)'!A=&@L("1C;60I.PH@("`@("`@(&EF("AI<U]A*"1E<G(L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1E<G(["B`@("`@("`@
M?0H@("`@("`@(&EF("@A9FEL95]E>&ES=',H)'1E;7`I*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE
M('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(I+"`D=&AI<RT^7V=E=%!A=&@H
M)'!A=&@L("1N86UE*2DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1E
M;7`["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+U9&4R]S<6PN<&AP````````````````````````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#$P-#0P-P`Q,#4Q-30S,S<T-0`P,C`T,#$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"B\J*@H@
M*B!&:6QE('9A;'5E(&9O<B!V9G-?='EP92!C;VQU;6XN"B`J+PID969I;F4H
M)U9&4U]&24Q%)RP@,2D["@HO*BH*("H@1F]L9&5R('9A;'5E(&9O<B!V9G-?
M='EP92!C;VQU;6XN"B`J+PID969I;F4H)U9&4U]&3TQ$15(G+"`R*3L*"B\J
M*@H@*B!61E,@:6UP;&5M96YT871I;VX@9F]R(%!(4"=S(%!%05(@9&%T86)A
M<V4@86)S=')A8W1I;VX@;&%Y97(N"B`J"B`J(%)E<75I<F5D('9A;'5E<R!F
M;W(@)'!A<F%M<SH\<')E/@H@*B`@("`@("=P:'!T>7!E)R`@("`@("!4:&4@
M9&%T86)A<V4@='EP92`H:64N("=P9W-Q;"<L("=M>7-Q;"<L(&5T8RXI+CPO
M<')E/@H@*@H@*B!/<'1I;VYA;"!V86QU97,Z/'!R93X*("H@("`@("`G=&%B
M;&4G("`@("`@("`@5&AE(&YA;64@;V8@=&AE('9F<R!T86)L92!I;B`G9&%T
M86)A<V4G+B!$969A=6QT<R!T;PH@*B`@("`@("`@("`@("`@("`@("`@("`G
M:&]R9&5?=F9S)RX\+W!R93X*("H*("H@4F5Q=6ER960@8GD@<V]M92!D871A
M8F%S92!I;7!L96UE;G1A=&EO;G,Z/'!R93X*("H@("`@("`G:&]S='-P96,G
M("`@("`@5&AE(&AO<W1N86UE(&]F('1H92!D871A8F%S92!S97)V97(N"B`J
M("`@("`@)W!R;W1O8V]L)R`@("`@(%1H92!C;VUM=6YI8V%T:6]N('!R;W1O
M8V]L("@G=&-P)RP@)W5N:7@G+"!E=&,N*2X*("H@("`@("`G9&%T86)A<V4G
M("`@("`@5&AE(&YA;64@;V8@=&AE(&1A=&%B87-E+@H@*B`@("`@("=U<V5R
M;F%M92<@("`@("!4:&4@=7-E<FYA;64@=VET:"!W:&EC:"!T;R!C;VYN96-T
M('1O('1H92!D871A8F%S92X*("H@("`@("`G<&%S<W=O<F0G("`@("`@5&AE
M('!A<W-W;W)D(&%S<V]C:6%T960@=VET:"`G=7-E<FYA;64G+@H@*B`@("`@
M("=O<'1I;VYS)R`@("`@("!!9&1I=&EO;F%L(&]P=&EO;G,@=&\@<&%S<R!T
M;R!T:&4@9&%T86)A<V4N"B`J("`@("`@)W1T>2<@("`@("`@("`@(%1H92!4
M5%D@;VX@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@
M("`@)W!O<G0G("`@("`@("`@(%1H92!P;W)T(&]N('=H:6-H('1O(&-O;FYE
M8W0@=&\@=&AE(&1A=&%B87-E+CPO<')E/@H@*@H@*B!4:&4@=&%B;&4@<W1R
M=6-T=7)E(&9O<B!T:&4@5D93(&-A;B!B92!F;W5N9"!I;@H@*B!D871A+W9F
M<RYS<6PN"B`J"B`J($1A=&%B87-E('-P96-I9FEC(&YO=&5S.@H@*@H@*B!-
M4U-13#H*("H@/'!R93X*("H@+2!4:&4@=F9S7V1A=&$@9FEE;&0@;75S="!B
M92!O9B!T>7!E($E-04=%+@H@*B`M(%EO=2!N965D('1H92!F;VQL;W=I;F<@
M<&AP+FEN:2!S971T:6YG<SH*("H@("`@.R!686QI9"!R86YG92`P("T@,C$T
M-S0X,S8T-RX@1&5F875L="`](#0P.38N"B`J("`@(&US<W%L+G1E>'1L:6UI
M="`](#`@.R!Z97)O('1O('!A<W,@=&AR;W5G:`H@*@H@*B`@("`[(%9A;&ED
M(')A;F=E(#`@+2`R,30W-#@S-C0W+B!$969A=6QT(#T@-#`Y-BX*("H@("`@
M;7-S<6PN=&5X='-I>F4@/2`P(#L@>F5R;R!T;R!P87-S('1H<F]U9V@*("H@
M/"]P<F4^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<"QV(#$N.#4N-"XR-B`R,#`V+S`U+S,Q(#`T.C4P.C`R('-L=7-A<GH@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<&%C:V%G
M92!61E,*("HO"F-L87-S(%9&4U]S<6P@97AT96YD<R!61E,@>PH*("`@("\J
M*@H@("`@("H@2&%N9&QE(&9O<B!T:&4@8W5R<F5N="!D871A8F%S92!C;VYN
M96-T:6]N+@H@("`@("H*("`@("`J($!V87(@1$(*("`@("`J+PH@("`@=F%R
M("1?9&(@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%)E=')I979E<R!T:&4@
M9FEL97-I>F4@9G)O;2!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'!A=&@@(%1H92!P871H;F%M92!T;R!T:&4@9FEL92X*("`@("`J
M($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F:6QE;F%M92!T;R!R971R:65V
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="!4:&4@9FEL92!S:7IE+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!S:7IE*"1P871H+"`D;F%M92D*("`@('L*
M("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF
M("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@("1L96YG=&A?;W`@/2`D
M=&AI<RT^7V=E=$9I;&53:7IE3W`H*3L*("`@("`@("`D<W%L(#T@<W!R:6YT
M9B@*("`@("`@("`@("`@)U-%3$5#5"`E<RAV9G-?9&%T82D@1E)/32`E<R!7
M2$5212!V9G-?<&%T:"`](#\@04Y$('9F<U]N86UE(#T@/R<L"B`@("`@("`@
M("`@("1L96YG=&A?;W`L"B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T
M86)L92=="B`@("`@("`@*3L*("`@("`@("`D=F%L=65S(#T@87)R87DH)'1H
M:7,M/E]C;VYV97)T4&%T:"@D<&%T:"DL("1N86UE*3L*("`@("`@("`D=&AI
M<RT^;&]G*"1S<6PL(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`D<VEZ92`]
M("1T:&ES+3Y?9&(M/F=E=$]N92@D<W%L+"`D=F%L=65S*3L*"B`@("`@("`@
M:68@*&ES7VYU;&PH)'-I>F4I*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&-H96-K(&9I;&4@
M<VEZ92!O9B!<(B5S+R5S7"(N(BDL("1P871H+"`D;F%M92DI.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1S:7IE.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@<VEZ92!O9B!A(&9I;&4N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P
M871H("!4:&4@<&%T:"!O9B!T:&4@9FEL92X*("`@("`J($!P87)A;2!S=')I
M;F<@)&YA;64@(%1H92!F:6QE;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN=&5G97(@(%1H92!S:7IE(&]F('1H92!F;VQD97(@:6X@8GET97,@;W(@
M4$5!4E]%<G)O<B!O;@H@("`@("H@("`@("`@("`@("`@("`@("!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971&;VQD97)3:7IE*"1P871H(#T@
M;G5L;"P@)&YA;64@/2!N=6QL*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H
M:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@
M('T*"B`@("`@("`@)'=H97)E(#T@*&ES7VYU;&PH)'!A=&@I*2`_(&YU;&P@
M.B!S<')I;G1F*"=72$5212!V9G-?<&%T:"`]("5S)RP@*"@A<W1R;&5N*"1P
M871H*2D@/R`G(B(G(#H@)'1H:7,M/E]D8BT^<75O=&4H)'1H:7,M/E]C;VYV
M97)T4&%T:"@D<&%T:"DI*2D["B`@("`@("`@)&QE;F=T:%]O<"`]("1T:&ES
M+3Y?9V5T1FEL95-I>F5/<"@I.PH@("`@("`@("1S<6P@/2!S<')I;G1F*`H@
M("`@("`@("`@("`G4T5,14-4(%-532@E<RAV9G-?9&%T82DI($923TT@)7,@
M)7,G+`H@("`@("`@("`@("`D;&5N9W1H7V]P+`H@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@("`@("`@)'=H97)E"B`@("`@
M("`@*3L*("`@("`@("`D=&AI<RT^;&]G*"1S<6PL(%!%05)?3$]'7T1%0E5'
M*3L*("`@("`@("`D<VEZ92`]("1T:&ES+3Y?9&(M/F=E=$]N92@D<W%L*3L*
M"B`@("`@("`@<F5T=7)N("1S:7IE("$]/2!N=6QL(#\@)'-I>F4@.B`P.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F4@82!F:6QE(&9R;VT@=&AE
M(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@
M<&%T:&YA;64@=&\@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N
M86UE("!4:&4@9FEL96YA;64@=&\@<F5T<FEE=F4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!F:6QE(&1A=&$N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(')E860H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@("1C;VYN
M(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F5A9$)L;V(H)'1H
M:7,M/E]P87)A;7-;)W1A8FQE)UTL("=V9G-?9&%T82<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)W9F<U]P871H)R`]/B`D=&AI
M<RT^7V-O;G9E<G10871H*"1P871H*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=F9S7VYA;64G(#T^("1N86UE*2D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971R:65V97,@82!P87)T(&]F(&$@9FEL92!F
M<F]M('1H92!61E,N(%!A<G1I8W5L87)L>2!U<V5F=6P*("`@("`J('=H96X@
M<F5A9&EN9R!L87)G92!F:6QE<R!W:&EC:"!W;W5L9"!E>&-E960@=&AE(%!(
M4"!M96UO<GD*("`@("`J(&QI;6ET<R!I9B!T:&5Y('=E<F4@<W1O<F5D(&EN
M(&$@<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1P871H
M("`@("`@(%1H92!P871H;F%M92!T;R!T:&4@9FEL92X*("`@("`J($!P87)A
M;2!S=')I;F<@("1N86UE("`@("`@(%1H92!F:6QE;F%M92!T;R!R971R:65V
M92X*("`@("`J($!P87)A;2!I;G1E9V5R("1O9F9S970@("`@(%1H92!O9F9S
M970@;V8@=&AE('!A<G0N("A4:&4@;F5W(&]F9G-E="!W:6QL(&)E"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=&]R960@:6X@:&5R92DN
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;&5N9W1H("`@("!4:&4@;&5N9W1H
M(&]F('1H92!P87)T+B!)9B!T:&4@;&5N9W1H(#T@+3$L('1H90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@=VAO;&4@<&%R="!A9G1E<B!T
M:&4@;V9F<V5T(&ES(')E=')I979E9"X@268*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&UO<F4@8GET97,@87)E(&=I=F5N(&%S(&5X:7-T
M<R!A9G1E<B!T:&4@9VEV96X*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&]F9G-E="X@3VYL>2!T:&4@879A:6QA8FQE(&)Y=&5S(&%R92!R
M96%D+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')E;6%I;FEN9R`@5&AE(&)Y
M=&5S('1H870@87)E(&QE9G0L(&%F=&5R('1H92!P87)T('1H870@:7,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E=')I979E9"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R!4:&4@9FEL92!D871A+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R96%D4&%R="@D<&%T:"P@)&YA;64L("8D;V9F
M<V5T+"`D;&5N9W1H(#T@+3$L("8D<F5M86EN:6YG*0H@("`@>PH@("`@("`@
M("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H
M)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C
M;VYN.PH@("`@("`@('T*"B`@("`@("`@)&1A=&$@/2`D=&AI<RT^7W)E861"
M;&]B*"1T:&ES+3Y?<&%R86US6R=T86)L92==+"`G=F9S7V1A=&$G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G=F9S7W!A=&@G
M(#T^("1T:&ES+3Y?8V]N=F5R=%!A=&@H)'!A=&@I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=F9S7VYA;64G(#T^("1N86UE
M*2D["@H@("`@("`@("\O($-A;&-U;&%T92!H;W<@;6%N>2!B>71E<R!-55-4
M(&)E(')E860L('-O('1H92!R96UA:6YG:6YG"B`@("`@("`@+R\@8GET97,@
M86YD('1H92!N97<@;V9F<V5T(&-A;B!B92!C86QC=6QA=&5D(&-O<G)E8W1L
M>2X*("`@("`@("`D<VEZ92`]('-T<FQE;B`H)&1A=&$I.PH@("`@("`@(&EF
M("@D;&5N9W1H(#T]("TQ('Q\("@H)&QE;F=T:"`K("1O9F9S970I(#X@)'-I
M>F4I*2!["B`@("`@("`@("`@("1L96YG=&@@/2`D<VEZ92`M("1O9F9S970[
M"B`@("`@("`@?0H@("`@("`@(&EF("@D<F5M86EN:6YG(#P@,"D@>PH@("`@
M("`@("`@("`D<F5M86EN:6YG(#T@,#L*("`@("`@("!]"@H@("`@("`@("1D
M871A(#T@<W5B<W1R*"1D871A+"`D;V9F<V5T+"`D;&5N9W1H*3L*("`@("`@
M("`D;V9F<V5T(#T@)&]F9G-E="`K("1L96YG=&@["B`@("`@("`@)')E;6%I
M;FEN9R`]("1S:7IE("T@)&]F9G-E=#L*"B`@("`@("`@<F5T=7)N("1D871A
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1O<F5S(&$@9FEL92!I;B!T:&4@
M5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@
M("!4:&4@<&%T:"!T;R!S=&]R92!T:&4@9FEL92!I;BX*("`@("`J($!P87)A
M;2!S=')I;F<@)&YA;64@("`@("`@("!4:&4@9FEL96YA;64@=&\@=7-E+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=&UP1FEL92`@("`@(%1H92!T96UP;W)A
M<GD@9FEL92!C;VYT86EN:6YG('1H92!D871A('1O"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8F4@<W1O<F5D+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&%U=&]C<F5A=&4@($%U=&]M871I8V%L;'D@8W)E871E(&1I
M<F5C=&]R:65S/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@
M;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E*"1P871H+"`D;F%M92P@)'1M
M<$9I;&4L("1A=71O8W)E871E(#T@9F%L<V4I"B`@("!["B`@("`@("`@+RH@
M1&]N)W0@;F5E9"!T;R!C:&5C:R!Q=6]T82!H97)E('-I;F-E(&ET('=I;&P@
M8F4@8VAE8VME9"!W:&5N"B`@("`@("`@("H@=W)I=&5$871A*"D@:7,@8V%L
M;&5D+B`J+PH@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T
M7V-O;G1E;G1S)RDI('L*("`@("`@("`@("`@)&1A=&$@/2!F:6QE7V=E=%]C
M;VYT96YT<R@D=&UP1FEL92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'-I>F4@/2!F:6QE<VEZ92@D=&UP1FEL92D["B`@("`@("`@("`@(&EF
M("@D<VEZ92`]/3T@,"D@>PH@("`@("`@("`@("`@("`@)&1A=&$@/2`G)SL*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D9&%T
M8490(#T@0&9O<&5N*"1T;7!&:6QE+"`G<F(G*3L*("`@("`@("`@("`@("`@
M(&EF("@A)&1A=&%&4"D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B5&AE('1E;7!O<F%R>2!F:6QE
M(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB*2P@)'1M<$9I;&4I*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1D871A(#T@0&9R96%D*"1D
M871A1E`L("1S:7IE*3L*("`@("`@("`@("`@("`@($!F8VQO<V4H)&1A=&%&
M4"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M=&AI<RT^=W)I=&5$871A*"1P871H+"`D;F%M92P@)&1A=&$L("1A=71O8W)E
M871E*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-T;W)E(&$@9FEL92!I;B!T
M:&4@5D93(&9R;VT@<F%W(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<&%T:"`@("`@("`@(%1H92!P871H('1O('-T;W)E('1H92!F:6QE
M(&EN+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@("`@(%1H92!F
M:6QE;F%M92!T;R!U<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("`@
M("`@("`@5&AE(&9I;&4@9&%T82X*("`@("`J($!P87)A;2!B;V]L96%N("1A
M=71O8W)E871E("!!=71O;6%T:6-A;&QY(&-R96%T92!D:7)E8W1O<FEE<S\*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@
M;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!W<FET941A=&$H)'!A=&@L("1N86UE+"`D9&%T82P@)&%U
M=&]C<F5A=&4@/2!F86QS92D*("`@('L*("`@("`@("`D<F5S(#T@)'1H:7,M
M/E]C:&5C:U%U;W1A5W)I=&4H)W-T<FEN9R<L("1D871A*3L*("`@("`@("!I
M9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<F5S.PH@("`@("`@('T*"B`@("`@("`@)&-O;FX@/2`D=&AI<RT^
M7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*
M("`@("`@("`D<&%T:"`]("1T:&ES+3Y?8V]N=F5R=%!A=&@H)'!A=&@I.PH*
M("`@("`@("`O*B!#:&5C:R!T;R!S964@:68@=&AE(&1A=&$@86QR96%D>2!E
M>&ES=',N("HO"B`@("`@("`@)'-Q;"`]('-P<FEN=&8H)U-%3$5#5"!V9G-?
M:60@1E)/32`E<R!72$5212!V9G-?<&%T:"`E<R!!3D0@=F9S7VYA;64@/2`_
M)RP*("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`H96UP='DH)'!A=&@I("8F
M("1T:&ES+3Y?9&(M/F1B<WEN=&%X(#T]("=O8VDX)RD@/R`G($E3($Y53$PG
M(#H@)R`]("<@+B`D=&AI<RT^7V1B+3YQ=6]T92@D<&%T:"DI.PH@("`@("`@
M("1V86QU97,@/2!A<G)A>2@D;F%M92D["B`@("`@("`@)'1H:7,M/FQO9R@D
M<W%L+"!014%27TQ/1U]$14)51RD["B`@("`@("`@)&ED(#T@)'1H:7,M/E]D
M8BT^9V5T3VYE*"1S<6PL("1V86QU97,I.PH*("`@("`@("!I9B`H:7-?82@D
M:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)'1H:7,M/FQO9R@D
M:60L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B`D:60["B`@
M("`@("`@?0H*("`@("`@("!I9B`H(6ES7VYU;&PH)&ED*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]U<&1A=&5";&]B*"1T:&ES+3Y?<&%R86US
M6R=T86)L92==+"`G=F9S7V1A=&$G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1D871A+"!A<G)A>2@G=F9S7VED)R`]/B`D:60I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=V9G-?;6]D:69I960G(#T^('1I;64H*2DI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("\J($-H96-K('1O('-E92!I9B!T:&4@9F]L9&5R(&%L
M<F5A9'D@97AI<W1S+B`J+PH@("`@("`@("`@("`D9&ER<R`](&5X<&QO9&4H
M)R\G+"`D<&%T:"D["B`@("`@("`@("`@("1P871H7VYA;64@/2!A<G)A>5]P
M;W`H)&1I<G,I.PH@("`@("`@("`@("`D<&%R96YT(#T@:6UP;&]D92@G+R<L
M("1D:7)S*3L*("`@("`@("`@("`@:68@*"$D=&AI<RT^:7-&;VQD97(H)'!A
M<F5N="P@)'!A=&A?;F%M92DI('L*("`@("`@("`@("`@("`@(&EF("@A)&%U
M=&]C<F5A=&4I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BAS<')I;G1F*%\H(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES
M="(I+"`D<&%T:"DL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/F%U=&]C<F5A=&50871H*"1P871H*3L*("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)&ED(#T@)'1H:7,M/E]D8BT^;F5X=$ED*"1T:&ES+3Y?<&%R86US
M6R=T86)L92==*3L*("`@("`@("`@("`@:68@*&ES7V$H)&ED+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*"1I9"P@4$5!
M4E],3T=?15)2*3L*("`@("`@("`@("`@("`@(')E='5R;B`D:60["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6YS97)T0FQO
M8B@D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P@)W9F<U]D871A)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T82P@87)R87DH
M)W9F<U]I9"<@/3X@)&ED+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G=F9S7W1Y<&4G(#T^(%9&4U]&24Q%
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G=F9S7W!A=&@G(#T^("1P871H+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=F9S7VYA;64G
M(#T^("1N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=F9S7VUO9&EF:65D)R`]/B!T:6UE*"DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=V9G-?;W=N97(G(#T^("1T:&ES+3Y?<&%R86US6R=U<V5R)UTI*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&4@82!F:6QE
M(&9R;VT@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P
M871H("!4:&4@<&%T:"!T;R!S=&]R92!T:&4@9FEL92!I;BX*("`@("`J($!P
M87)A;2!S=')I;F<@)&YA;64@(%1H92!F:6QE;F%M92!T;R!U<V4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@
M4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9&5L971E1FEL92@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@
M)')E<R`]("1T:&ES+3Y?8VAE8VM1=6]T841E;&5T92@D<&%T:"P@)&YA;64I
M.PH@("`@("`@(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H*("`@("`@("`D8V]N
M;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*
M("`@("`@("!]"@H@("`@("`@("1P871H(#T@)'1H:7,M/E]C;VYV97)T4&%T
M:"@D<&%T:"D["@H@("`@("`@("1S<6P@/2!S<')I;G1F*"=$14Q%5$4@1E)/
M32`E<R!72$5212!V9G-?='EP92`](#\@04Y$('9F<U]P871H("5S($%.1"!V
M9G-?;F%M92`](#\G+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=T86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("AE;7!T
M>2@D<&%T:"D@)B8@)'1H:7,M/E]D8BT^9&)S>6YT87@@/3T@)V]C:3@G*2`_
M("<@25,@3E5,3"<@.B`G(#T@)R`N("1T:&ES+3Y?9&(M/G%U;W1E*"1P871H
M*2D["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*%9&4U]&24Q%+"`D;F%M92D[
M"B`@("`@("`@)'1H:7,M/FQO9R@D<W%L+"!014%27TQ/1U]$14)51RD["B`@
M("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1S<6PL("1V86QU
M97,I.PH*("`@("`@("!I9B`H)'1H:7,M/E]D8BT^869F96-T9612;W=S*"D@
M/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(I*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5N86UE(&$@9FEL92!O<B!F;VQD97(@:6X@=&AE(%9&4RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1O;&1P871H("!4:&4@;VQD('!A=&@@=&\@
M=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;&1N86UE("!4:&4@
M;VQD(&9I;&5N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W<&%T:"`@
M5&AE(&YE=R!P871H(&]F('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;F5W;F%M92`@5&AE(&YE=R!F:6QE;F%M92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YA
M;64H)&]L9'!A=&@L("1O;&1N86UE+"`D;F5W<&%T:"P@)&YE=VYA;64I"B`@
M("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@
M("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("!I9B`H<W1R<&]S
M*"1N97=P871H+"`G+R<I(#T]/2!F86QS92D@>PH@("`@("`@("`@("`D<&%R
M96YT(#T@)R<["B`@("`@("`@("`@("1P871H(#T@)&YE=W!A=&@["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@;&ES="@D<&%R96YT+"`D<&%T:"D@
M/2!E>'!L;V1E*"<O)RP@)&YE=W!A=&@L(#(I.PH@("`@("`@('T*("`@("`@
M("!I9B`H(21T:&ES+3YI<T9O;&1E<B@D<&%R96YT+"`D<&%T:"DI('L*("`@
M("`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3YA=71O8W)E871E
M4&%T:"@D;F5W<&%T:"DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`D;VQD<&%T:"`]("1T:&ES+3Y?8V]N=F5R=%!A=&@H)&]L9'!A
M=&@I.PH@("`@("`@("1N97=P871H(#T@)'1H:7,M/E]C;VYV97)T4&%T:"@D
M;F5W<&%T:"D["@H@("`@("`@("1S<6P@(#T@)U501$%412`G("X@)'1H:7,M
M/E]P87)A;7-;)W1A8FQE)UT["B`@("`@("`@)'-Q;"`N/2`G(%-%5"!V9G-?
M<&%T:"`](#\L('9F<U]N86UE(#T@/RP@=F9S7VUO9&EF:65D(#T@/R!72$52
M12!V9G-?<&%T:"`](#\@04Y$('9F<U]N86UE(#T@/R<["B`@("`@("`@)'1H
M:7,M/FQO9R@D<W%L+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("1V86QU
M97,@/2!A<G)A>2@D;F5W<&%T:"P@)&YE=VYA;64L('1I;64H*2P@)&]L9'!A
M=&@L("1O;&1N86UE*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M
M/G%U97)Y*"1S<6PL("1V86QU97,I.PH*("`@("`@("!I9B`H)'1H:7,M/E]D
M8BT^869F96-T9612;W=S*"D@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M+B(I*3L*("`@("`@("!]"@H@("`@("`@("1R96YA;64@/2`D=&AI<RT^7W)E
M8W5R<VEV95)E;F%M92@D;VQD<&%T:"P@)&]L9&YA;64L("1N97=P871H+"`D
M;F5W;F%M92D["B`@("`@("`@:68@*&ES7V$H)')E;F%M92P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`D=&AI<RT^;&]G*"1R96YA;64L(%!%05)?
M3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*'-P<FEN=&8H7R@B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E
M<RXB*2P@)')E;F%M92T^9V5T365S<V%G92@I*2D["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*("`@("`J($-R
M96%T97,@82!F;VQD97(@;VX@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1P871H("!(;VQD<R!T:&4@<&%T:"!O9B!D:7)E8W1O<GD@
M=&\@8W)E871E(&9O;&1E<BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@
M($AO;&1S('1H92!N86UE(&]F('1H92!N97<@9F]L9&5R+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&-R96%T949O;&1E<B@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@)&-O
M;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N
M;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX[
M"B`@("`@("`@?0H*("`@("`@("`D:60@/2`D=&AI<RT^7V1B+3YN97AT260H
M)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI.PH@("`@("`@(&EF("AI<U]A*"1I
M9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D=&AI<RT^;&]G*"1I
M9"P@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N("1I9#L*("`@
M("`@("!]"@H@("`@("`@("1S<6P@(#T@)TE.4T525"!)3E1/("<@+B`D=&AI
M<RT^7W!A<F%M<ULG=&%B;&4G73L*("`@("`@("`D<W%L("X]("<@*'9F<U]I
M9"P@=F9S7W1Y<&4L('9F<U]P871H+"!V9G-?;F%M92P@=F9S7VUO9&EF:65D
M+"!V9G-?;W=N97(I(%9!3%5%4R`H/RP@/RP@/RP@/RP@/RP@/RDG.PH@("`@
M("`@("1T:&ES+3YL;V<H)'-Q;"P@4$5!4E],3T=?1$5"54<I.PH*("`@("`@
M("`D=F%L=65S(#T@87)R87DH)&ED+"!61E-?1D],1$52+"`D=&AI<RT^7V-O
M;G9E<G10871H*"1P871H*2P@)&YA;64L('1I;64H*2P@)'1H:7,M/E]P87)A
M;7-;)W5S97(G72D["@H@("`@("`@(')E='5R;B`D=&AI<RT^7V1B+3YQ=65R
M>2@D<W%L+"`D=F%L=65S*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T
M92!A(&9O;&1E<B!F<F]M('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<&%T:"`@("`@("`@5&AE('!A=&@@;V8@=&AE(&9O;&1E<BX*
M("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@(%1H92!F;VQD97(@
M;F%M92!T;R!U<V4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<F5C=7)S:79E
M("!&;W)C92!A(')E8W5R<VEV92!D96QE=&4_"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E
M1F]L9&5R*"1P871H+"`D;F%M92P@)')E8W5R<VEV92`](&9A;'-E*0H@("`@
M>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@
M:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@)'!A=&@@/2`D=&AI
M<RT^7V-O;G9E<G10871H*"1P871H*3L*"B`@("`@("`@)&9O;&1E<E!A=&@@
M/2`D=&AI<RT^7V=E=$YA=&EV95!A=&@H)'!A=&@L("1N86UE*3L*"B`@("`@
M("`@+RH@0VAE8VL@:68@;F]T(')E8W5R<VEV92!A;F0@9F%I;"!I9B!D:7)E
M8W1O<GD@;F]T(&5M<'1Y("HO"B`@("`@("`@:68@*"$D<F5C=7)S:79E*2![
M"B`@("`@("`@("`@("1F;VQD97),:7-T(#T@)'1H:7,M/FQI<W1&;VQD97(H
M)&9O;&1E<E!A=&@L(&YU;&PL('1R=64I.PH@("`@("`@("`@("!I9B`H:7-?
M82@D9F]L9&5R3&ES="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/FQO9R@D9F]L9&5R3&ES="P@4$5!4E],3T=?15)2*3L*("`@
M("`@("`@("`@("`@(')E='5R;B`D9F]L9&5R3&ES=#L*("`@("`@("`@("`@
M?2!E;'-E:68@*"%E;7!T>2@D9F]L9&5R3&ES="DI('L*("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE
M('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'!A=&@@+B`G+R<@+B`D;F%M92DI.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`O*B!&:7)S="!D96QE=&4@979E<GET:&EN9R!B96QO
M=R!T:&4@9F]L9&5R+"!S;R!I9B!E<G)O<B!W90H@("`@("`@("`J(&=E="!N
M;R!O<G!H86YS("HO"B`@("`@("`@)'-Q;"`]('-P<FEN=&8H)T1%3$5412!&
M4D]-("5S(%=(15)%('9F<U]P871H("5S)RP*("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@("`@("`@("`@
M("`@("`@("`H96UP='DH)&9O;&1E<E!A=&@I("8F("1T:&ES+3Y?9&(M/F1B
M<WEN=&%X(#T]("=O8VDX)RD@/R`G($E3($Y53$PG(#H@)R!,24M%("<@+B`D
M=&AI<RT^7V1B+3YQ=6]T92@D=&AI<RT^7V=E=$YA=&EV95!A=&@H)&9O;&1E
M<E!A=&@L("<E)RDI*3L*("`@("`@("`D=&AI<RT^;&]G*"1S<6PL(%!%05)?
M3$]'7T1%0E5'*3L*("`@("`@("`D9&5L971E0V]N=&5N=',@/2`D=&AI<RT^
M7V1B+3YQ=65R>2@D<W%L*3L*("`@("`@("!I9B`H:7-?82@D9&5L971E0V]N
M=&5N=',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)'1H:7,M/FQO
M9R@D9&5L971E0V]N=&5N=',L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O
M(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(I+"`D9&5L971E0V]N=&5N
M=',M/F=E=$UE<W-A9V4H*2DI.PH@("`@("`@('T*"B`@("`@("`@+RH@3F]W
M(&1E;&5T92!E=F5R>71H:6YG(&EN<VED92!T:&4@9F]L9&5R+B`J+PH@("`@
M("`@("1S<6P@/2!S<')I;G1F*"=$14Q%5$4@1E)/32`E<R!72$5212!V9G-?
M<&%T:"`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@*&5M<'1Y*"1P
M871H*2`F)B`D=&AI<RT^7V1B+3YD8G-Y;G1A>"`]/2`G;V-I."<I(#\@)R!)
M4R!.54Q,)R`Z("<@/2`G("X@)'1H:7,M/E]D8BT^<75O=&4H)&9O;&1E<E!A
M=&@I*3L*("`@("`@("`D=&AI<RT^;&]G*"1S<6PL(%!%05)?3$]'7T1%0E5'
M*3L*("`@("`@("`D9&5L971E(#T@)'1H:7,M/E]D8BT^<75E<GDH)'-Q;"D[
M"B`@("`@("`@:68@*&ES7V$H)&1E;&5T92P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^;&]G*"1D96QE=&4L(%!%05)?3$]'7T524BD[
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H
M7R@B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB*2P@)&1E
M;&5T92T^9V5T365S<V%G92@I*2D["B`@("`@("`@?0H*("`@("`@("`O*B!!
M;&P@;VL@;F]W(&1E;&5T92!T:&4@86-T=6%L(&9O;&1E<B`J+PH@("`@("`@
M("1S<6P@/2!S<')I;G1F*"=$14Q%5$4@1E)/32`E<R!72$5212!V9G-?<&%T
M:"`E<R!!3D0@=F9S7VYA;64@/2`_)RP*("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@("`@("`@("`@("`@
M("`@("`H96UP='DH)'!A=&@I("8F("1T:&ES+3Y?9&(M/F1B<WEN=&%X(#T]
M("=O8VDX)RD@/R`G($E3($Y53$PG(#H@)R`]("<@+B`D=&AI<RT^7V1B+3YQ
M=6]T92@D<&%T:"DI.PH@("`@("`@("1V86QU97,@/2!A<G)A>2@D;F%M92D[
M"B`@("`@("`@)'1H:7,M/FQO9R@D<W%L+"!014%27TQ/1U]$14)51RD["B`@
M("`@("`@)&1E;&5T92`]("1T:&ES+3Y?9&(M/G%U97)Y*"1S<6PL("1V86QU
M97,I.PH@("`@("`@(&EF("AI<U]A*"1D96QE=&4L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@)'1H:7,M/FQO9R@D9&5L971E+"!014%27TQ/1U]%
M4E(I.PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I
M;G1F*%\H(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(BDL
M("1D96QE=&4M/F=E=$UE<W-A9V4H*2DI.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1D96QE=&4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@
M82!L:7-T(&]F('1H92!C;VYT96YT<R!O9B!A(&9O;&1E<BX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@(%1H92!D:7)E8W1O<GD@
M<&%T:"X*("`@("`J($!P87)A;2!M:7AE9"`D9FEL=&5R("`@("`@4W1R:6YG
M+VAA<V@@;V8@:71E;7,@=&\@9FEL=&5R(&)A<V5D(&]N"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&9I;&5N86UE+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)&1O=&9I;&5S("!3:&]W(&1O=&9I;&5S/PH@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&1I<F]N;'D@("!3:&]W(&1I<F5C=&]R:65S(&]N;'D_
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1FEL92!L:7-T(&]N('-U
M8V-E<W,@;W(@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7VQI<W1&;VQD97(H)'!A=&@L("1F:6QT97(@/2!N=6QL+"`D9&]T9FEL
M97,@/2!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@)&1I<F]N;'D@
M/2!F86QS92D*("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C
M="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@
M("1P871H(#T@)'1H:7,M/E]C;VYV97)T4&%T:"@D<&%T:"D["@H@("`@("`@
M("\O($9I>"!F;W(@3W)A8VQE(&YO="!D:69F97)E;G1I871I;F<@8F5T=V5E
M;B`G)R!A;F0@3E5,3"X*("`@("`@("!I9B`H96UP='DH)'!A=&@I("8F("1T
M:&ES+3Y?9&(M/F1B<WEN=&%X(#T]("=O8VDX)RD@>PH@("`@("`@("`@("`D
M=VAE<F4@/2`G=F9S7W!A=&@@25,@3E5,3"<["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'=H97)E(#T@)W9F<U]P871H(#T@)R`N("1T:&ES+3Y?
M9&(M/G%U;W1E*"1P871H*3L*("`@("`@("!]"@H@("`@("`@("1L96YG=&A?
M;W`@/2`D=&AI<RT^7V=E=$9I;&53:7IE3W`H*3L*("`@("`@("`D<W%L(#T@
M<W!R:6YT9B@G4T5,14-4('9F<U]N86UE+"!V9G-?='EP92P@)7,H=F9S7V1A
M=&$I+"!V9G-?;6]D:69I960L('9F<U]O=VYE<B!&4D]-("5S(%=(15)%("5S
M)RP*("`@("`@("`@("`@("`@("`@("`@("`D;&5N9W1H7V]P+`H@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@("`@
M("`@("`@("`@("`@("`@("`@("1W:&5R92D["B`@("`@("`@)'1H:7,M/FQO
M9R@D<W%L+"!014%27TQ/1U]$14)51RD["B`@("`@("`@)&9I;&5,:7-T(#T@
M)'1H:7,M/E]D8BT^9V5T06QL*"1S<6PI.PH@("`@("`@(&EF("AI<U]A*"1F
M:6QE3&ES="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&9I;&5,:7-T.PH@("`@("`@('T*"B`@("`@("`@)&9I;&5S(#T@87)R87DH
M*3L*("`@("`@("!F;W)E86-H("@D9FEL94QI<W0@87,@)&QI;F4I('L*("`@
M("`@("`@("`@+R\@1FEL=&5R(&]U="!D;W1F:6QE<R!I9B!T:&5Y(&%R96XG
M="!W86YT960N"B`@("`@("`@("`@(&EF("@A)&1O=&9I;&5S("8F('-U8G-T
M<B@D;&EN95LP72P@,"P@,2D@/3T@)RXG*2!["B`@("`@("`@("`@("`@("!C
M;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&9I;&5;)VYA
M;64G72`]("1L:6YE6S!=.PH*("`@("`@("`@("`@:68@*"1L:6YE6S%=(#T]
M(%9&4U]&24Q%*2!["B`@("`@("`@("`@("`@("`D;F%M92`](&5X<&QO9&4H
M)RXG+"`D;&EN95LP72D["@H@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1N
M86UE*2`]/2`Q*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)W1Y<&4G
M72`]("<J*FYO;F4G.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D9FEL95LG='EP92==(#T@5D93.CIS=')T;VQO=V5R
M*"1N86UE6V-O=6YT*"1N86UE*2`M(#%=*3L*("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("`@("`D9FEL95LG<VEZ92==(#T@)&QI;F5;,ET["B`@
M("`@("`@("`@('T@96QS96EF("@D;&EN95LQ72`]/2!61E-?1D],1$52*2![
M"B`@("`@("`@("`@("`@("`D9FEL95LG='EP92==(#T@)RHJ9&ER)SL*("`@
M("`@("`@("`@("`@("1F:6QE6R=S:7IE)UT@/2`M,3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@)&9I;&5;)V1A=&4G72`]("1L:6YE6S-=.PH@("`@
M("`@("`@("`D9FEL95LG;W=N97(G72`]("1L:6YE6S1=.PH@("`@("`@("`@
M("`D9FEL95LG<&5R;7,G72`]("<G.PH@("`@("`@("`@("`D9FEL95LG9W)O
M=7`G72`]("<G.PH*("`@("`@("`@("`@+R\@9FEL=&5R:6YG"B`@("`@("`@
M("`@(&EF("@D=&AI<RT^7V9I;'1E<DUA=&-H*"1F:6QT97(L("1F:6QE6R=N
M86UE)UTI*2!["B`@("`@("`@("`@("`@("!U;G-E="@D9FEL92D["B`@("`@
M("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H)&1I<F]N;'D@)B8@)&9I;&5;)W1Y<&4G72`A/3T@)RHJ9&ER)RD@
M>PH@("`@("`@("`@("`@("`@=6YS970H)&9I;&4I.PH@("`@("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1F:6QE
M<ULD9FEL95LG;F%M92==72`]("1F:6QE.PH@("`@("`@("`@("!U;G-E="@D
M9FEL92D["B`@("`@("!]"@H@("`@("`@(')E='5R;B`D9FEL97,["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<V]R=&5D(&QI<W0@;V8@9F]L
M9&5R<R!I;B!S<&5C:69I960@9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'!A=&@@("`@("`@("!4:&4@<&%T:"!O9B!T:&4@9&ER
M96-T;W)Y('1O(&=E="!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!D:7)E8W1O<GD@;&ES="!F;W(N"B`@("`@*B!`<&%R86T@;6EX
M960@)&9I;'1E<B`@("`@("`@4W1R:6YG+VAA<V@@;V8@:71E;7,@=&\@9FEL
M=&5R(&)A<V5D(&]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@9F]L9&5R;&ES="X*("`@("`J($!P87)A;2!B;V]L96%N("1D;W1F;VQD
M97)S("!);F-L=61E(&1O=&9O;&1E<G,_"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@1F]L9&5R(&QI<W0@;VX@<W5C8V5S<R!O<B!014%27T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T
M1F]L9&5R<R@D<&%T:"`]("<G+"`D9FEL=&5R(#T@87)R87DH*2P@)&1O=&9O
M;&1E<G,@/2!T<G5E*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C
M;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@
M("`@("`@)'!A=&@@/2`D=&AI<RT^7V-O;G9E<G10871H*"1P871H*3L*"B`@
M("`@("`@)'-Q;"`@/2`G4T5,14-4('9F<U]N86UE+"!V9G-?<&%T:"!&4D]-
M("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G73L*("`@("`@("`D<W%L("X]
M("<@5TA%4D4@=F9S7W!A=&@@/2`_($%.1"!V9G-?='EP92`](#\G.PH@("`@
M("`@("1T:&ES+3YL;V<H)'-Q;"P@4$5!4E],3T=?1$5"54<I.PH*("`@("`@
M("`D=F%L=65S(#T@87)R87DH)'!A=&@L(%9&4U]&3TQ$15(I.PH*("`@("`@
M("`D9F]L9&5R3&ES="`]("1T:&ES+3Y?9&(M/F=E=$%L;"@D<W%L+"`D=F%L
M=65S*3L*("`@("`@("!I9B`H:7-?82@D9F]L9&5R3&ES="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&9O;&1E<DQI<W0["B`@("`@
M("`@?0H*("`@("`@("`D9F]L9&5R<R`](&%R<F%Y*"D["B`@("`@("`@9F]R
M96%C:"`H)&9O;&1E<DQI<W0@87,@)&QI;F4I('L*("`@("`@("`@("`@)&9O
M;&1E<ELG=F%L)UT@/2`D=&AI<RT^7V=E=$YA=&EV95!A=&@H)&QI;F5;,5TL
M("1L:6YE6S!=*3L*("`@("`@("`@("`@)&9O;&1E<ELG86)B<F5V)UT@/2`G
M)SL*("`@("`@("`@("`@)&9O;&1E<ELG;&%B96PG72`]("<G.PH*("`@("`@
M("`@("`@)&-O=6YT(#T@<W5B<W1R7V-O=6YT*"1F;VQD97);)W9A;"==+"`G
M+R<I.PH*("`@("`@("`@("`@)'@@/2`P.PH@("`@("`@("`@("!W:&EL92`H
M)'@@/"`D8V]U;G0I('L*("`@("`@("`@("`@("`@("1F;VQD97);)V%B8G)E
M=B==("X]("<@("`@)SL*("`@("`@("`@("`@("`@("1F;VQD97);)VQA8F5L
M)UT@+CT@)R`@("`G.PH@("`@("`@("`@("`@("`@)'@K*SL*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)&9O;&1E<ELG86)B<F5V)UT@+CT@)&QI;F5;
M,%T["B`@("`@("`@("`@("1F;VQD97);)VQA8F5L)UT@+CT@)&QI;F5;,%T[
M"@H@("`@("`@("`@("`D<W1R;&5N(#T@5D93.CIS=')L96XH)&9O;&1E<ELG
M;&%B96PG72D["B`@("`@("`@("`@(&EF("@D<W1R;&5N(#X@,C8I('L*("`@
M("`@("`@("`@("`@("1F;VQD97);)V%B8G)E=B==(#T@<W5B<W1R*"1F;VQD
M97);)VQA8F5L)UTL(#`L("@D8V]U;G0@*B`T*2D["B`@("`@("`@("`@("`@
M("`D;&5N9W1H(#T@*#(Y("T@*"1C;W5N="`J(#0I*2`O(#(["B`@("`@("`@
M("`@("`@("`D9F]L9&5R6R=A8F)R978G72`N/2!S=6)S='(H)&9O;&1E<ELG
M;&%B96PG72P@*"1C;W5N="`J(#0I+"`D;&5N9W1H*3L*("`@("`@("`@("`@
M("`@("1F;VQD97);)V%B8G)E=B==("X]("<N+BXG.PH@("`@("`@("`@("`@
M("`@)&9O;&1E<ELG86)B<F5V)UT@+CT@<W5B<W1R*"1F;VQD97);)VQA8F5L
M)UTL("TQ("H@)&QE;F=T:"P@)&QE;F=T:"D["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1F;W5N9"`](&9A;'-E.PH@("`@("`@("`@("!F;W)E86-H
M("@D9FEL=&5R(&%S("1F;'1R*2!["B`@("`@("`@("`@("`@("!I9B`H)&9O
M;&1E<ELG=F%L)UT@/3T@)&9L='(I('L*("`@("`@("`@("`@("`@("`@("`D
M9F]U;F0@/2!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!I9B`H(21F;W5N9"D@>PH@("`@("`@("`@("`@("`@
M)&9O;&1E<G-;)&9O;&1E<ELG=F%L)UU=(#T@)&9O;&1E<CL*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@:W-O<G0H)&9O;&1E<G,I.PH@("`@
M("`@(')E='5R;B`D9F]L9&5R<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M;F%M97,@86QL(&-H:6QD('!A=&AS+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H
M92!P871H(&]F('1H92!F;VQD97(@=&\@<F5N86UE+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F%M92`@5&AE(&9O;&1E<FYA;64@=&\@=7-E+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%
M05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]R96-U<G-I=F5296YA;64H)&]L9'!A=&@L("1O;&1N86UE+"`D;F5W
M<&%T:"P@)&YE=VYA;64I"B`@("!["B`@("`@("`@)&]L9'!A=&@@/2`D=&AI
M<RT^7V-O;G9E<G10871H*"1O;&1P871H*3L*("`@("`@("`D;F5W<&%T:"`]
M("1T:&ES+3Y?8V]N=F5R=%!A=&@H)&YE=W!A=&@I.PH*("`@("`@("`D<W%L
M("`]("=314Q%0U0@=F9S7VYA;64@1E)/32`G("X@)'1H:7,M/E]P87)A;7-;
M)W1A8FQE)UT["B`@("`@("`@)'-Q;"`N/2`G(%=(15)%('9F<U]T>7!E(#T@
M/R!!3D0@=F9S7W!A=&@@/2`_)SL*("`@("`@("`D=&AI<RT^;&]G*"1S<6PL
M(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*%9&
M4U]&3TQ$15(L("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D;VQD<&%T:"P@)&]L
M9&YA;64I*3L*"B`@("`@("`@)&9O;&1E<DQI<W0@/2`D=&AI<RT^7V1B+3YG
M971#;VPH)'-Q;"P@,"P@)'9A;'5E<RD["@H@("`@("`@(&9O<F5A8V@@*"1F
M;VQD97),:7-T(&%S("1F;VQD97(I('L*("`@("`@("`@("`@)'1H:7,M/E]R
M96-U<G-I=F5296YA;64H)'1H:7,M/E]G971.871I=F50871H*"1O;&1P871H
M+"`D;VQD;F%M92DL("1F;VQD97(L("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D
M;F5W<&%T:"P@)&YE=VYA;64I+"`D9F]L9&5R*3L*("`@("`@("!]"@H@("`@
M("`@("1S<6P@/2`G55!$051%("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G
M72`N("<@4T54('9F<U]P871H(#T@/R!72$5212!V9G-?<&%T:"`](#\G.PH@
M("`@("`@("1T:&ES+3YL;V<H)'-Q;"P@4$5!4E],3T=?1$5"54<I.PH*("`@
M("`@("`D=F%L=65S(#T@87)R87DH)'1H:7,M/E]G971.871I=F50871H*"1N
M97=P871H+"`D;F5W;F%M92DL("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D;VQD
M<&%T:"P@)&]L9&YA;64I*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?
M9&(M/G%U97)Y*"1S<6PL("1V86QU97,I.PH*("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!A(&9U;&P@9FEL
M96YA;64@;VX@=&AE(&YA=&EV92!F:6QE<WES=&5M+"!F<F]M(&$@5D93"B`@
M("`@*B!P871H(&%N9"!N86UE+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!6
M1E,@9FEL92!P871H+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE
M(%9&4R!F:6QE;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(&9U;&P@;F%T:79E(&9I;&5N86UE+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?9V5T3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@
M:68@*&5M<'1Y*"1P871H*2D@>PH@("`@("`@("`@("!R971U<FX@)&YA;64[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1P871H*2D@>PH@("`@
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P87)A;7-;)VAO;64G72D@)B8*
M("`@("`@("`@("`@("`@('!R96=?;6%T8V@H)WQ>?B\_*"XJ*21\)RP@)'!A
M=&@L("1M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@)'!A=&@@/2`D=&AI
M<RT^7W!A<F%M<ULG:&]M92==("X@)R\G("X@)&UA=&-H97-;,5T["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<&%T:"`N("<O
M)R`N("1N86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@
M;W!E;B!A('!E<G-I<W1E;G0@8V]N;F5C=&EO;B!T;R!T:&4@4U%,('-E<G9E
M<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M8V]N;F5C="@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?9&(@/3T](&9A
M;'-E*2!["B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)'1H:7,M/E]P87)A
M;7,I*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BA?*").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@4U%,(%9&4RXB*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1R
M97%U:7)E9"`](&%R<F%Y*"=P:'!T>7!E)RD["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1R97%U:7)E9"!A<R`D=F%L*2!["B`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?<&%R86US6R1V86Q=*2D@>PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B4F5Q
M=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I
M;VXN(BDL("1V86PI*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG9&%T
M86)A<V4G72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=D
M871A8F%S92==(#T@)R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;64G72DI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M92==(#T@)R<["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A
M<F%M<ULG:&]S='-P96,G72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=H;W-T<W!E8R==(#T@)R<["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DI('L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==(#T@)VAO
M<F1E7W9F<R<["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($-O;FYE
M8W0@=&\@=&AE(%-13"!S97)V97(@=7-I;F<@=&AE('-U<'!L:65D('!A<F%M
M971E<G,N("HO"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G1$(N<&AP)SL*
M("`@("`@("`@("`@)'1H:7,M/E]D8B`]("9$0CHZ8V]N;F5C="@D=&AI<RT^
M7W!A<F%M<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@G<&5R<VES=&5N="<@/3X@(65M<'1Y*"1T:&ES+3Y?<&%R86US
M6R=P97)S:7-T96YT)UTI*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1T:&ES
M+3Y?9&(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3YL;V<H)'1H:7,M/E]D8BP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@
M("`@("1E<G)O<B`]("1T:&ES+3Y?9&(["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V1B(#T@9F%L<V4["B`@("`@("`@("`@("`@("!R971U<FX@)&5R<F]R
M.PH@("`@("`@("`@("!]"@H*("`@("`@("`@("`@+R\@4V5T($1"('!O<G1A
M8FEL:71Y(&]P=&EO;G,N"B`@("`@("`@("`@('-W:71C:"`H)'1H:7,M/E]D
M8BT^<&AP='EP92D@>PH@("`@("`@("`@("!C87-E("=M<W-Q;"<Z"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7V1B+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y
M)RP@1$)?4$]25$%"24Q)5%E?3$]715)#05-%('P@1$)?4$]25$%"24Q)5%E?
M15)23U)3('P@1$)?4$]25$%"24Q)5%E?4E1224TI.PH@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V1B+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]2
M5$%"24Q)5%E?3$]715)#05-%('P@1$)?4$]25$%"24Q)5%E?15)23U)3*3L*
M("`@("`@("`@("`@?0H*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1&ES8V]N;F5C="!F<F]M('1H92!3
M44P@<V5R=F5R(&%N9"!C;&5A;B!U<"!T:&4@8V]N;F5C=&EO;BX*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V1I<V-O;FYE8W0H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V1B*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?9&(M/F1I<V-O;FYE8W0H*3L*("`@("`@
M("`@("`@)'1H:7,M/E]D8B`](&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%1/1$\*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T86)L92`@("`@5$]$
M3PH@("`@("H@0'!A<F%M('-T<FEN9R`D9FEE;&0@("`@(%1/1$\*("`@("`J
M($!P87)A;2!S=')I;F<@)&-R:71E<FEA("!43T1/"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@5$]$3PH@("`@("HO"B`@("!F=6YC=&EO;B!?<F5A
M9$)L;V(H)'1A8FQE+"`D9FEE;&0L("1C<FET97)I82D*("`@('L*("`@("`@
M("!I9B`H(6-O=6YT*"1C<FET97)I82DI('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)UEO=2!M=7-T('-P96-I9GD@=&AE(&9E=&-H
M(&-R:71E<FEA)RD["B`@("`@("`@?0H*("`@("`@("`D=VAE<F4@/2`G)SL*
M"B`@("`@("`@<W=I=&-H("@D=&AI<RT^7V1B+3YD8G-Y;G1A>"D@>PH@("`@
M("`@(&-A<V4@)V]C:3@G.@H@("`@("`@("`@("!F;W)E86-H("@D8W)I=&5R
M:6$@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@("`@(&EF("@A
M96UP='DH)'=H97)E*2D@>PH@("`@("`@("`@("`@("`@("`@("1W:&5R92`N
M/2`G($%.1"`G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M:68@*&5M<'1Y*"1V86QU92DI('L*("`@("`@("`@("`@("`@("`@("`D=VAE
M<F4@+CT@)&ME>2`N("<@25,@3E5,3"<["B`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("1W:&5R92`N/2`D:V5Y("X@)R`]
M("<@+B`D=&AI<RT^7V1B+3YQ=6]T92@D=F%L=64I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<W1A=&5M96YT(#T@
M3T-)4&%R<V4H)'1H:7,M/E]D8BT^8V]N;F5C=&EO;BP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('-P<FEN=&8H)U-%3$5#5"`E<R!&4D]-
M("5S(%=(15)%("5S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&9I96QD+"`D=&%B;&4L("1W:&5R92DI.PH@("`@("`@
M("`@("!/0TE%>&5C=71E*"1S=&%T96UE;G0I.PH@("`@("`@("`@("!I9B`H
M3T-)1F5T8VA);G1O*"1S=&%T96UE;G0L("1L;V(I*2!["B`@("`@("`@("`@
M("`@("`D<F5S=6QT(#T@)&QO8ELP72T^;&]A9"@I.PH@("`@("`@("`@("`@
M("`@:68@*&ES7VYU;&PH)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@
M("`D<F5S=6QT(#T@4$5!4CHZ<F%I<V5%<G)O<B@G56YA8FQE('1O(&QO860@
M4U%,(&1A=&$N)RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@4$5!4CHZ<F%I<V5%
M<G)O<B@G56YA8FQE('1O(&QO860@4U%,(&1A=&$N)RD["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@3T-)1G)E95-T871E;65N="@D<W1A=&5M96YT*3L*
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@
M("`@(&9O<F5A8V@@*"1C<FET97)I82!A<R`D:V5Y(#T^("1V86QU92D@>PH@
M("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D=VAE<F4I*2!["B`@("`@("`@
M("`@("`@("`@("`@)'=H97)E("X]("<@04Y$("<["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D=VAE<F4@+CT@)&ME>2`N("<@/2`G("X@
M)'1H:7,M/E]D8BT^<75O=&4H)'9A;'5E*3L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@)'-Q;"`]('-P<FEN=&8H)U-%3$5#5"`E<R!&4D]-("5S(%=(
M15)%("5S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I96QD+"`D
M=&%B;&4L("1W:&5R92D["B`@("`@("`@("`@("1T:&ES+3YL;V<H)'-Q;"P@
M4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/E]D8BT^9V5T3VYE*"1S<6PI.PH*("`@("`@("`@("`@:68@*&ES7VYU;&PH
M)')E<W5L="DI('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2!014%2.CIR
M86ES945R<F]R*"=5;F%B;&4@=&\@;&]A9"!344P@9&%T82XG*3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@('-W:71C:"`H)'1H:7,M
M/E]D8BT^9&)S>6YT87@I('L*("`@("`@("`@("`@("`@(&-A<V4@)W!G<W%L
M)SH*("`@("`@("`@("`@("`@("`@("`D<F5S=6QT(#T@<&%C:R@G2"<@+B!S
M=')L96XH)')E<W5L="DL("1R97-U;'0I.PH@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%1/1$\*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T86)L92`@("`@("!43T1/"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1F:65L9"`@("`@("!43T1/"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1D871A("`@("`@("!43T1/"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1A='1R:6)U=&5S("!43T1/"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5$]$3PH@("`@("HO"B`@("!F=6YC=&EO;B!?:6YS97)T0FQO
M8B@D=&%B;&4L("1F:65L9"P@)&1A=&$L("1A='1R:6)U=&5S*0H@("`@>PH@
M("`@("`@("1F:65L9',@/2!A<G)A>2@I.PH@("`@("`@("1V86QU97,@/2!A
M<G)A>2@I.PH*("`@("`@("!S=VET8V@@*"1T:&ES+3Y?9&(M/F1B<WEN=&%X
M*2!["B`@("`@("`@8V%S92`G;V-I."<Z"B`@("`@("`@("`@(&9O<F5A8V@@
M*"1A='1R:6)U=&5S(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@
M("`@("`D9FEE;&1S6UT@/2`D:V5Y.PH@("`@("`@("`@("`@("`@)'9A;'5E
M<UM=(#T@)'1H:7,M/E]D8BT^<75O=&53;6%R="@D=F%L=64I.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D<W1A=&5M96YT(#T@3T-)4&%R<V4H)'1H
M:7,M/E]D8BT^8V]N;F5C=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('-P<FEN=&8H)TE.4T525"!)3E1/("5S("@E<RP@)7,I)R`N
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<@
M5D%,5453("@E<RP@14U05%E?0DQ/0B@I*2!215154DY)3D<@)7,@24Y43R`Z
M8FQO8B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T86)L92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:6UP;&]D92@G+"`G+"`D9FEE;&1S*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I96QD+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I;7!L;V1E*"<L
M("<L("1V86QU97,I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9FEE;&0I*3L*"B`@("`@("`@("`@("1L;V(@/2!/0TE.
M97=$97-C<FEP=&]R*"1T:&ES+3Y?9&(M/F-O;FYE8W1I;VXI.PH@("`@("`@
M("`@("!/0TE":6YD0GE.86UE*"1S=&%T96UE;G0L("<Z8FQO8B<L("1L;V(L
M("TQ+"!344Q47T),3T(I.PH@("`@("`@("`@("!/0TE%>&5C=71E*"1S=&%T
M96UE;G0L($]#25]$149!54Q4*3L*("`@("`@("`@("`@)&QO8BT^<V%V92@D
M9&%T82D["B`@("`@("`@("`@("1R97-U;'0@/2!/0TE#;VUM:70H)'1H:7,M
M/E]D8BT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("1L;V(M/F9R964H*3L*
M("`@("`@("`@("`@3T-)1G)E95-T871E;65N="@D<W1A=&5M96YT*3L*("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0@/R!T<G5E(#H@4$5!4CHZ<F%I<V5%
M<G)O<B@G56YK;F]W;B!%<G)O<B<I.PH*("`@("`@("!D969A=6QT.@H@("`@
M("`@("`@("!F;W)E86-H("@D871T<FEB=71E<R!A<R`D:V5Y(#T^("1V86QU
M92D@>PH@("`@("`@("`@("`@("`@)&9I96QD<UM=(#T@)&ME>3L*("`@("`@
M("`@("`@("`@("1V86QU97-;72`]("1V86QU93L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G24Y315)4($E.5$\@)7,@
M*"5S+"`E<RD@5D%,5453("@E<RDG+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T86)L92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M;7!L;V1E*"<L("<L("1F:65L9',I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1F:65L9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M/R<@+B!S=')?<F5P96%T*"<L(#\G+"!C;W5N="@D=F%L=65S*2DI.PH@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@('-W:71C:"`H)'1H
M:7,M/E]D8BT^9&)S>6YT87@I('L*("`@("`@("!C87-E("=M<W-Q;"<Z"B`@
M("`@("`@8V%S92`G<&=S<6PG.@H@("`@("`@("`@("`D=F%L=65S6UT@/2!B
M:6XR:&5X*"1D871A*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@("1V86QU97-;72`]("1D871A.PH@("`@("`@
M('T*"B`@("`@("`@+RH@17AE8W5T92!T:&4@<75E<GDN("HO"B`@("`@("`@
M)'1H:7,M/FQO9R@D<75E<GDL(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%1/1$\*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T86)L92`@
M("`@(%1/1$\*("`@("`J($!P87)A;2!S=')I;F<@)&9I96QD("`@("`@5$]$
M3PH@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T82`@("`@("!43T1/"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1W:&5R92`@("`@(%1/1$\*("`@("`J($!P87)A
M;2!A<G)A>2`D86QS;W5P9&%T92`@5$]$3PH@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%1/1$\*("`@("`J+PH@("`@9G5N8W1I;VX@7W5P9&%T94)L
M;V(H)'1A8FQE+"`D9FEE;&0L("1D871A+"`D=VAE<F4L("1A;'-O=7!D871E
M*0H@("`@>PH@("`@("`@("1F:65L9',@/2!A<G)A>2@I.PH@("`@("`@("1V
M86QU97,@/2!A<G)A>2@I.PH*("`@("`@("!S=VET8V@@*"1T:&ES+3Y?9&(M
M/F1B<WEN=&%X*2!["B`@("`@("`@8V%S92`G;V-I."<Z"B`@("`@("`@("`@
M("1W:&5R97-T<FEN9R`]("<G.PH@("`@("`@("`@("!F;W)E86-H("@D=VAE
M<F4@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@("`@(&EF("@A
M96UP='DH)'=H97)E<W1R:6YG*2D@>PH@("`@("`@("`@("`@("`@("`@("1W
M:&5R97-T<FEN9R`N/2`G($%.1"`G.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@)'=H97)E<W1R:6YG("X]("1K97D@+B`G(#T@)R`N("1T
M:&ES+3Y?9&(M/G%U;W1E*"1V86QU92D["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1S=&%T96UE;G0@/2!/0TE087)S92@D=&AI<RT^7V1B+3YC;VYN
M96-T:6]N+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W!R
M:6YT9B@G4T5,14-4("5S($923TT@)7,@5TA%4D4@)7,@1D]2(%501$%412<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F
M:65L9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1A8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=VAE<F5S=')I;F<I*3L*"B`@("`@("`@("`@($]#245X96-U
M=&4H)'-T871E;65N="P@3T-)7T1%1D%53%0I.PH@("`@("`@("`@("!/0TE&
M971C:$EN=&\H)'-T871E;65N="P@)&QO8BD["B`@("`@("`@("`@("1L;V);
M,%TM/G-A=F4H)&1A=&$I.PH@("`@("`@("`@("`D<F5S=6QT(#T@3T-)0V]M
M;6ET*"1T:&ES+3Y?9&(M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`D;&]B
M6S!=+3YF<F5E*"D["B`@("`@("`@("`@($]#249R9653=&%T96UE;G0H)'-T
M871E;65N="D["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT(#\@=')U92`Z
M(%!%05(Z.G)A:7-E17)R;W(H)U5N:VYO=VX@17)R;W(G*3L*"B`@("`@("`@
M9&5F875L=#H*("`@("`@("`@("`@)'5P9&%T97-T<FEN9R`]("<G.PH@("`@
M("`@("`@("`D=F%L=65S(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R96%C
M:"`H)&%L<V]U<&1A=&4@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@
M("`@("`@("1U<&1A=&5S=')I;F<@+CT@)&ME>2`N("<@/2`_+"`G.PH@("`@
M("`@("`@("`@("`@)'9A;'5E<UM=(#T@)'9A;'5E.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1U<&1A=&5S=')I;F<@+CT@)&9I96QD("X@)R`](#\G
M.PH@("`@("`@("`@("!S=VET8V@@*"1T:&ES+3Y?9&(M/F1B<WEN=&%X*2![
M"B`@("`@("`@("`@(&-A<V4@)VUS<W%L)SH*("`@("`@("`@("`@8V%S92`G
M<&=S<6PG.@H@("`@("`@("`@("`@("`@)'9A;'5E<UM=(#T@8FEN,FAE>"@D
M9&%T82D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@("`@("`D=F%L=65S6UT@/2`D9&%T83L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)'=H97)E<W1R:6YG(#T@)R<["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1W:&5R92!A<R`D:V5Y(#T^("1V86QU92D@
M>PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D=VAE<F5S=')I;F<I*2![
M"B`@("`@("`@("`@("`@("`@("`@)'=H97)E<W1R:6YG("X]("<@04Y$("<[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=VAE<F5S=')I
M;F<@+CT@)&ME>2`N("<@/2`_)SL*("`@("`@("`@("`@("`@("1V86QU97-;
M72`]("1V86QU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'%U97)Y
M(#T@<W!R:6YT9B@G55!$051%("5S(%-%5"`E<R!72$5212`E<R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1A8FQE+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1U<&1A=&5S=')I;F<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'=H97)E<W1R:6YG*3L*("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@?0H*("`@("`@("`O*B!%>&5C=71E('1H92!Q=65R>2X@
M*B\*("`@("`@("`D=&AI<RT^;&]G*"1Q=65R>2P@4$5!4E],3T=?1$5"54<I
M.PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V
M86QU97,I.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R="!T:&4@<&%T
M:&YA;64@9G)O;2!R96=U;&%R(&9I;&5S>7-T96T@9F]R;2!T;R!T:&4@:6YT
M97)N86P*("`@("`J(&9O<FUA="!N965D960@=&\@86-C97-S('1H92!F:6QE
M(&EN('1H92!D871A8F%S92X*("`@("`J($YA;65L>2P@=V4@=VEL;"!T<F5A
M="`G+R<@87,@82!B87-E(&1I<F5C=&]R>2!A<R!T:&ES(&ES('!R971T>2!M
M=6-H"B`@("`@*B!T:&4@<W1A;F1A<F0@=V%Y('1O(&%C8V5S<R!B87-E(&1I
M<F5C=&]R:65S(&]V97(@;6]S="!F:6QE<WES=&5M<RX*?2`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1P871H("!!(%9&4R!P871H+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@<&%T:"!W:71H(&%N>2!B96=I;FYI;F<@<VQA<V@@<W1R:7!P
M960@;V9F+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N=F5R=%!A=&@H)'!A
M=&@I"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D<&%T:"D@)B8@*'-T<G!O
M<R@D<&%T:"P@)R\G*2`]/3T@,"DI('L*("`@("`@("`@("`@)'!A=&@@/2!S
M=')V86PH<W5B<W1R*"1P871H+"`Q*2D["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)'!A=&@["B`@("!]"@H@("`@9G5N8W1I;VX@7V=E=$9I;&53:7IE
M3W`H*0H@("`@>PH@("`@("`@('-W:71C:"`H)'1H:7,M/E]D8BT^9&)S>6YT
M87@I('L*("`@("`@("!C87-E("=M>7-Q;"<Z"B`@("`@("`@("`@(')E='5R
M;B`G3$5.1U1()SL*"B`@("`@("`@8V%S92`G;V-I."<Z"B`@("`@("`@("`@
M(')E='5R;B`G3$5.1U1(0B<["@H@("`@("`@(&-A<V4@)VUS<W%L)SH*("`@
M("`@("!C87-E("=S>6)A<V4G.@H@("`@("`@("`@("!R971U<FX@)T1!5$%,
M14Y'5$@G.PH*("`@("`@("!C87-E("=P9W-Q;"<Z"B`@("`@("`@9&5F875L
M=#H*("`@("`@("`@("`@<F5T=7)N("=/0U1%5%],14Y'5$@G.PH@("`@("`@
M('T*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O5D93+W-Q;%]F:6QE+G!H<```````````
M````````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#<R-#4T`#$P-3$U-#,S
M-S0U`#`R,30P-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`H*+RHJ"B`J($9I;&4@=F%L=64@9F]R('9F<U]T>7!E
M(&-O;'5M;BX*("HO"F1E9FEN92@G5D937T9)3$4G+"`Q*3L*"B\J*@H@*B!&
M;VQD97(@=F%L=64@9F]R('9F<U]T>7!E(&-O;'5M;BX*("HO"F1E9FEN92@G
M5D937T9/3$1%4B<L(#(I.PH*+RHJ"B`J(%9&4SHZ(&EM<&QE;65N=&%T:6]N
M('5S:6YG(%!(4"=S(%!%05(@9&%T86)A<V4@86)S=')A8W1I;VX*("H@;&%Y
M97(@86YD(&QO8V%L(&9I;&4@<WES=&5M(&9O<B!F:6QE('-T;W)A9V4N"B`J
M"B`J(%)E<75I<F5D('9A;'5E<R!F;W(@)'!A<F%M<SH\<')E/@H@*B`@("`@
M("=P:'!T>7!E)R`@("`@("!4:&4@9&%T86)A<V4@='EP92`H:64N("=P9W-Q
M;"<L("=M>7-Q;"<L(&5T8RXI+@H@*B`@("`@("=V9G-R;V]T)R`@("`@("!4
M:&4@<F]O="!D:7)E8W1O<GD@;V8@=VAE<F4@=&AE(&9I;&5S('-H;W5L9"!B
M90H@*B`@("`@("`@("`@("`@("`@("`@("!A8W1U86QL>2!S=&]R960N/"]P
M<F4^"B`J"B`J($]P=&EO;F%L('9A;'5E<SH\<')E/@H@*B`@("`@("=T86)L
M92<@("`@("`@("!4:&4@;F%M92!O9B!T:&4@=F9S('1A8FQE(&EN("=D871A
M8F%S92<N($1E9F%U;'1S('1O"B`J("`@("`@("`@("`@("`@("`@("`@("=H
M;W)D95]V9G,G+CPO<')E/@H@*@H@*B!297%U:7)E9"!B>2!S;VUE(&1A=&%B
M87-E(&EM<&QE;65N=&%T:6]N<SH\<')E/@H@*B`@("`@("=H;W-T<W!E8R<@
M("`@("!4:&4@:&]S=&YA;64@;V8@=&AE(&1A=&%B87-E('-E<G9E<BX*("H@
M("`@("`G<')O=&]C;VPG("`@("`@5&AE(&-O;6UU;FEC871I;VX@<')O=&]C
M;VP@*"=T8W`G+"`G=6YI>"<L(&5T8RXI+@H@*B`@("`@("=D871A8F%S92<@
M("`@("!4:&4@;F%M92!O9B!T:&4@9&%T86)A<V4N"B`J("`@("`@)W5S97)N
M86UE)R`@("`@(%1H92!U<V5R;F%M92!W:71H('=H:6-H('1O(&-O;FYE8W0@
M=&\@=&AE(&1A=&%B87-E+@H@*B`@("`@("=P87-S=V]R9"<@("`@("!4:&4@
M<&%S<W=O<F0@87-S;V-I871E9"!W:71H("=U<V5R;F%M92<N"B`J("`@("`@
M)V]P=&EO;G,G("`@("`@($%D9&ET:6]N86P@;W!T:6]N<R!T;R!P87-S('1O
M('1H92!D871A8F%S92X*("H@("`@("`G='1Y)R`@("`@("`@("`@5&AE(%14
M62!O;B!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A8F%S92X*("H@("`@
M("`G<&]R="<@("`@("`@("`@5&AE('!O<G0@;VX@=VAI8V@@=&\@8V]N;F5C
M="!T;R!T:&4@9&%T86)A<V4N/"]P<F4^"B`J"B`J(%1H92!T86)L92!S=')U
M8W1U<F4@9F]R('1H92!61E,@8V%N(&)E(&9O=6YD(&EN"B`J(&1A=&$O=F9S
M+G-Q;"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`L=B`Q+C0T+C0N,C(@,C`P-B\P-2\S,2`P-#HU,#HP,B!S;'5S87)Z
M($5X<"`D"B`J"B`J($!A=71H;W(@($UI8VAA96P@5F%R9VAE<V4@/&UI:V4N
M=F%R9VAE<V5`87-C96QL871E8V@N8V]M/@H@*B!`<&%C:V%G92!61E,*("HO
M"F-L87-S(%9&4U]S<6Q?9FEL92!E>'1E;F1S(%9&4R!["@H@("`@+RHJ"B`@
M("`@*B!(86YD;&4@9F]R('1H92!C=7)R96YT(&1A=&%B87-E(&-O;FYE8W1I
M;VXN"B`@("`@*@H@("`@("H@0'9A<B!$0@H@("`@("HO"B`@("!V87(@)%]D
M8B`](&9A;'-E.PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<VEZ92!O
M9B!A(&9I;&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!O9B!T:&4@
M9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F:6QE;F%M
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!S:7IE(&]F
M('1H92!F:6QE(&EN(&)Y=&5S(&]R(%!%05)?17)R;W(@;VX*("`@("`J("`@
M("`@("`@("`@("`@("`@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<VEZ92@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@:68@*"@D<VEZ92`]
M($!F:6QE<VEZ92@D=&AI<RT^7V=E=$YA=&EV95!A=&@H)'!A=&@L("1N86UE
M*2DI(#T]/2!F86QS92E["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O
M9B!<(B5S+R5S7"(N(BP@)'!A=&@L("1N86UE*2DI.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1S:7IE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M<FEE=F4@82!F:6QE(&9R;VT@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1P871H("!4:&4@<&%T:&YA;64@=&\@=&AE(&9I;&4N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@9FEL96YA;64@=&\@<F5T
M<FEE=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!F:6QE
M(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E860H)'!A=&@L("1N86UE
M*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@
M("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@)&9I;&4@
M/2`D=&AI<RT^7V=E=$YA=&EV95!A=&@H)'!A=&@L("1N86UE*3L*"B`@("`@
M("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G9FEL95]G971?8V]N=&5N=',G*2D@
M>PH@("`@("`@("`@("`D9&%T82`](&9I;&5?9V5T7V-O;G1E;G1S*"1F:6QE
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9G`@/2!`9F]P96XH
M)&9I;&4L("=R8B<I.PH@("`@("`@("`@("!I9B`H(21F<"D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O
M(&]P96X@5D93(&9I;&4N(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1D871A(#T@9G)E860H)&9P+"!F:6QE<VEZ92@D9FEL92DI.PH@("`@("`@
M("`@("!F8VQO<V4H)&9P*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J(%-T;W)E(&$@9FEL92!I;B!T
M:&4@5D93+"!W:71H('1H92!D871A(&-O<&EE9"!F<F]M(&$@=&5M<&]R87)Y
M"B`@("`@*B!F:6QE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A
M=&@@("`@("`@("!4:&4@<&%T:"!T;R!S=&]R92!T:&4@9FEL92!I;BX*("`@
M("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@("!4:&4@9FEL96YA;64@
M=&\@=7-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&UP1FEL92`@("`@(%1H
M92!T96UP;W)A<GD@9FEL92!C;VYT86EN:6YG('1H92!D871A('1O(&)E"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1O<F5D+@H@("`@
M("H@0'!A<F%M(&)O;VQE86X@)&%U=&]C<F5A=&4@($%U=&]M871I8V%L;'D@
M8W)E871E(&1I<F5C=&]R:65S/PH@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E*"1P871H+"`D
M;F%M92P@)'1M<$9I;&4L("1A=71O8W)E871E(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@+RH@3F\@;F5E9"!T;R!C:&5C:R!Q=6]T82!H97)E(&%S('=E('=I
M;&P@8VAE8VL@:70@=VAE;B!W92!C86QL"B`@("`@("`@("H@=W)I=&5$871A
M*"DN("HO"@H@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T
M7V-O;G1E;G1S)RDI('L*("`@("`@("`@("`@)&1A=&$@/2!F:6QE7V=E=%]C
M;VYT96YT<R@D=&UP1FEL92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&1A=&%&4"`]($!F;W!E;B@D=&UP1FEL92P@)W)B)RD["B`@("`@("`@
M("`@("1D871A(#T@0&9R96%D*"1D871A1E`L(&9I;&5S:7IE*"1T;7!&:6QE
M*2D["B`@("`@("`@("`@(&9C;&]S92@D9&%T8490*3L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1T:&ES+3YW<FET941A=&$H)'!A=&@L("1N86UE+"`D
M9&%T82P@)&%U=&]C<F5A=&4I.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1O
M<F4@82!F:6QE(&EN('1H92!61E,@9G)O;2!R87<@9&%T82X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@=&\@
M<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE
M("`@("`@("`@5&AE(&9I;&5N86UE('1O('5S92X*("`@("`J($!P87)A;2!S
M=')I;F<@)&1A=&$@("`@("`@("!4:&4@9FEL92!D871A+@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&%U=&]C<F5A=&4@($%U=&]M871I8V%L;'D@8W)E871E
M(&1I<F5C=&]R:65S/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R
M=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E1&%T82@D<&%T:"P@)&YA
M;64L("1D871A+"`D875T;V-R96%T92`](&9A;'-E*0H@("`@>PH@("`@("`@
M("1R97,@/2`D=&AI<RT^7V-H96-K475O=&%7<FET92@G<W1R:6YG)RP@)&1A
M=&$I.PH@("`@("`@(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H*("`@("`@("`D
M9G`@/2!`9F]P96XH)'1H:7,M/E]G971.871I=F50871H*"1P871H+"`D;F%M
M92DL("=W)RD["B`@("`@("`@:68@*"$D9G`I('L*("`@("`@("`@("`@:68@
M*"1A=71O8W)E871E*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H
M:7,M/F%U=&]C<F5A=&50871H*"1P871H*3L*("`@("`@("`@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1F<"`]($!F;W!E;B@D=&AI<RT^7V=E=$YA=&EV95!A
M=&@H)'!A=&@L("1N86UE*2P@)W<G*3L*("`@("`@("`@("`@("`@(&EF("@A
M)&9P*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H7R@B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N
M(BDI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA
M8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(BDI.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(4!F=W)I=&4H)&9P+"`D
M9&%T82DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M7R@B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(BDI.PH@("`@("`@
M('T*"B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]W<FET95-13$1A=&$H)'!A
M=&@L("1N86UE+"`D875T;V-R96%T92DL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@0'5N;&EN:R@D=&AI<RT^7V=E=$YA=&EV95!A=&@H)'!A=&@L
M("1N86UE*2D["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(I*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!-;W9E<R!A(&9I;&4@:6X@=&AE
M(&1A=&%B87-E(&%N9"!T:&4@9FEL92!S>7-T96TN"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I
M;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@;VQD(&9I
M;&5N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&5S="`@5&AE(&YE=R!F
M:6QE;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N
M('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!M;W9E*"1P871H+"`D;F%M92P@)&1E<W0I
M"B`@("!["B`@("`@("`@)&]R:6<@/2`D=&AI<RT^7V=E=$YA=&EV95!A=&@H
M)'!A=&@L("1N86UE*3L*("`@("`@("!I9B`H<')E9U]M871C:"@G?%XG("X@
M<')E9U]Q=6]T92@D;W)I9RD@+B`G+S\D?"<L("1D97-T*2D@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#86YN;W0@;6]V92!F
M:6QE*',I("T@9&5S=&EN871I;VX@:7,@=VET:&EN('-O=7)C92XB*2D["B`@
M("`@("`@?0H*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@
M("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@("1F:6QE
M0VAE8VL@/2`D=&AI<RT^;&ES=$9O;&1E<B@D9&5S="P@;G5L;"P@9F%L<V4I
M.PH@("`@("`@(&9O<F5A8V@@*"1F:6QE0VAE8VL@87,@)&9I;&4I('L*("`@
M("`@("`@("`@:68@*"1F:6QE6R=N86UE)UT@/3T@)&YA;64I('L*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T
M;R!M;W9E(%9&4R!F:6QE+B(I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@:68@*'-T<G!O<R@D9&5S="P@)'1H:7,M/E]G971344Q.871I
M=F50871H*"1P871H+"`D;F%M92DI("$]/2!F86QS92D@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@;6]V92!6
M1E,@9FEL92XB*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M
M/G)E;F%M92@D<&%T:"P@)&YA;64L("1D97-T+"`D;F%M92D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#;W!I97,@82!F:6QE('1H<F]U9V@@=&AE(&)A8VME
M;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A
M=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("!4:&4@9FEL96YA;64@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9&5S="`@5&AE(&1E<W1I;F%T:6]N(&]F('1H92!F:6QE+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A
M(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&-O<'DH)'!A=&@L("1N86UE+"`D9&5S="D*("`@('L*("`@("`@
M("`D;W)I9R`]("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I
M.PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"=\7B<@+B!P<F5G7W%U;W1E*"1O
M<FEG*2`N("<O/R1\)RP@)&1E<W0I*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*%\H(D-A;FYO="!C;W!Y(&9I;&4H<RD@+2!S;W5R
M8V4@86YD(&1E<W1I;F%T:6]N(&%R92!T:&4@<V%M92XB*2D["B`@("`@("`@
M?0H*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@
M(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@("1F:6QE0VAE8VL@
M/2`D=&AI<RT^;&ES=$9O;&1E<B@D9&5S="P@;G5L;"P@9F%L<V4I.PH@("`@
M("`@(&9O<F5A8V@@*"1F:6QE0VAE8VL@87,@)&9I;&4I('L*("`@("`@("`@
M("`@:68@*"1F:6QE6R=N86UE)UT@/3T@)&YA;64I('L*("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!C;W!Y
M(%9&4R!F:6QE+B(I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@:68@*'-T<G!O<R@D9&5S="P@)'1H:7,M/E]G971344Q.871I=F50871H
M*"1P871H+"`D;F%M92DI("$]/2!F86QS92D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@8V]P>2!61E,@9FEL
M92XB*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?9&ER*"1O<FEG*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R96-U<G-I=F5#;W!Y*"1P
M871H+"`D;F%M92P@)&1E<W0I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%`
M8V]P>2@D;W)I9RP@)'1H:7,M/E]G971.871I=F50871H*"1D97-T+"`D;F%M
M92DI*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(I*3L*("`@("`@("!]"@H@("`@
M("`@("1I9"`]("1T:&ES+3Y?9&(M/FYE>'1)9"@D=&AI<RT^7W!A<F%M<ULG
M=&%B;&4G72D["@H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)TE.4T525"!)
M3E1/("5S("AV9G-?:60L('9F<U]T>7!E+"!V9G-?<&%T:"P@=F9S7VYA;64L
M('9F<U]M;V1I9FEE9"P@=F9S7V]W;F5R*2!604Q515,@*#\L(#\L(#\L(#\L
M(#\L(#\I)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=T86)L92==*3L*("`@("`@("`D=F%L=65S(#T@87)R87DH)&ED+"!6
M1E-?1DE,12P@)&1E<W0L("1N86UE+"!T:6UE*"DL("1T:&ES+3Y?<&%R86US
M6R=U<V5R)UTI.PH*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E
M<GDH)'%U97)Y+"`D=F%L=65S*3L*"B`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!U;FQI;FLH)'1H:7,M
M/E]G971.871I=F50871H*"1D97-T+"`D;F%M92DI.PH@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A(&9O;&1E<B!O;B!T
M:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@($AO
M;&1S('1H92!P871H(&]F(&1I<F5C=&]R>2!T;R!C<F5A=&4@9F]L9&5R+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@2&]L9',@=&AE(&YA;64@;V8@
M=&AE(&YE=R!F;VQD97(N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E1F]L9&5R*"1P871H
M+"`D;F%M92D*("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C
M="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@
M("1I9"`]("1T:&ES+3Y?9&(M/FYE>'1)9"@D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G72D["B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*'-P
M<FEN=&8H)TE.4T525"!)3E1/("5S("AV9G-?:60L('9F<U]T>7!E+"!V9G-?
M<&%T:"P@=F9S7VYA;64L('9F<U]M;V1I9FEE9"P@=F9S7V]W;F5R*0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%9!3%5%
M4R`H/RP@/RP@/RP@/RP@/RP@/RDG+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)&ED+"!61E-?1D],1$52+"`D<&%T:"P@)&YA;64L('1I;64H*2P@)'1H:7,M
M/E]P87)A;7-;)W5S97(G72DI.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H(4!M:V1I<B@D=&AI<RT^7V=E=$YA
M=&EV95!A=&@H)'!A=&@L("1N86UE*2DI('L*("`@("`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?9&(M/G%U97)Y*'-P<FEN=&8H)T1%3$5412!&4D]-("5S
M(%=(15)%('9F<U]I9"`](#\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G
M72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@D:60I*3L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(I*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5N86UE(&$@9FEL92!O<B!F;VQD97(@:6X@=&AE(%9&4RX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;&1P871H("!4:&4@;VQD('!A
M=&@@=&\@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;&1N86UE
M("!4:&4@;VQD(&9I;&5N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W
M<&%T:"`@5&AE(&YE=R!P871H(&]F('1H92!F:6QE+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F5W;F%M92`@5&AE(&YE=R!F:6QE;F%M92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%2
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!R96YA;64H)&]L9'!A=&@L("1O;&1N86UE+"`D;F5W<&%T:"P@)&YE=VYA
M;64I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*
M("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("!I9B`H
M<W1R<&]S*"1N97=P871H+"`G+R<I(#T]/2!F86QS92D@>PH@("`@("`@("`@
M("`D<&%R96YT(#T@)R<["B`@("`@("`@("`@("1P871H(#T@)&YE=W!A=&@[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@;&ES="@D<&%R96YT+"`D
M<&%T:"D@/2!E>'!L;V1E*"<O)RP@)&YE=W!A=&@L(#(I.PH@("`@("`@('T*
M("`@("`@("!I9B`H(21T:&ES+3YI<T9O;&1E<B@D<&%R96YT+"`D<&%T:"DI
M('L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3YA=71O
M8W)E871E4&%T:"@D;F5W<&%T:"DL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH<W!R
M:6YT9B@G55!$051%("5S(%-%5"!V9G-?<&%T:"`](#\L('9F<U]N86UE(#T@
M/RP@=F9S7VUO9&EF:65D(#T@/PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%=(15)%('9F<U]P871H(#T@/R!!3D0@=F9S
M7VYA;64@/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1N97=P871H+"`D
M;F5W;F%M92P@=&EM92@I+"`D;VQD<&%T:"P@)&]L9&YA;64I*3L*"B`@("`@
M("`@:68@*"1T:&ES+3Y?9&(M/F%F9F5C=&5D4F]W<R@I(#T](#`I('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92XB*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M:7-?82@D=&AI<RT^7W)E8W5R<VEV95-13%)E;F%M92@D;VQD<&%T:"P@)&]L
M9&YA;64L("1N97=P871H+"`D;F5W;F%M92DL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*'-P<FEN
M=&8H)U501$%412`E<R!3150@=F9S7W!A=&@@/2`_+"!V9G-?;F%M92`](#\*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@5TA%4D4@=F9S7W!A=&@@/2`_($%.1"!V9G-?;F%M92`](#\G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@D;VQD<&%T:"P@)&]L9&YA;64L
M("1N97=P871H+"`D;F5W;F%M92DI.PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O
M<GDN(BDI.PH@("`@("`@('T*"B`@("`@("`@:68@*"%`:7-?9&ER*"1T:&ES
M+3Y?9V5T3F%T:79E4&%T:"@D;F5W<&%T:"DI*2!["B`@("`@("`@("`@(&EF
M("AI<U]A*"1R97,@/2`D=&AI<RT^875T;V-R96%T95!A=&@H)&YE=W!A=&@I
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E
M<SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"%`<F5N
M86UE*"1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D;VQD<&%T:"P@)&]L9&YA;64I
M+"`D=&AI<RT^7V=E=$YA=&EV95!A=&@H)&YE=W!A=&@L("1N97=N86UE*2DI
M('L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*'-P
M<FEN=&8H)U501$%412`E<R!3150@=F9S7W!A=&@@/2`_+"!V9G-?;F%M92`]
M(#\*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@5TA%4D4@=F9S7W!A=&@@/2`_($%.1"!V9G-?;F%M92`](#\G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@D;VQD<&%T:"P@)&]L9&YA
M;64L("1N97=P871H+"`D;F5W;F%M92DI.PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M+B(I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1&5L971E(&$@9F]L9&5R(&9R;VT@=&AE(%9&4RX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("!4:&4@
M<&%T:"!T;R!D96QE=&4@=&AE(&9O;&1E<B!F<F]M+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F%M92`@("`@("`@5&AE(&9O;&1E<FYA;64@=&\@=7-E+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)')E8W5R<VEV92`@1F]R8V4@82!R96-U
M<G-I=F4@9&5L971E/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R
M=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T949O;&1E<B@D<&%T:"P@
M)&YA;64L("1R96-U<G-I=F4@/2!F86QS92D*("`@('L*("`@("`@("`D8V]N
M;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*
M("`@("`@("!]"@H@("`@("`@(&EF("@D<F5C=7)S:79E*2!["B`@("`@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^96UP='E&;VQD97(H)'!A=&@@+B`G+R<@
M+B`D;F%M92D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&QI
M<W0@/2`D=&AI<RT^;&ES=$9O;&1E<B@D<&%T:"`N("<O)R`N("1N86UE*3L*
M("`@("`@("`@("`@:68@*&ES7V$H)&QI<W0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D;&ES=#L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H8V]U;G0H)&QI<W0I*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T
M;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1P871H("X@)R\G("X@)&YA;64I*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*'-P<FEN
M=&8H)T1%3$5412!&4D]-("5S(%=(15)%('9F<U]T>7!E(#T@/R!!3D0@=F9S
M7W!A=&@@/2`_($%.1"!V9G-?;F%M92`](#\G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T
M86)L92==*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH5D937T9/3$1%4BP@)'!A=&@L("1N86UE*2D["@H@("`@("`@(&EF
M("@D=&AI<RT^7V1B+3YA9F9E8W1E9%)O=W,H*2`]/2`P('Q\(&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GDN(BDI.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]R
M96-U<G-I=F5344Q$96QE=&4H)'!A=&@L("1N86UE*2P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(BDI
M.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]R96-U<G-I
M=F5,1E-$96QE=&4H)'!A=&@L("1N86UE*2P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(BDI.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$96QE=&4@82!F:6QE(&9R;VT@=&AE(%9&4RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!T;R!S=&]R92!T
M:&4@9FEL92!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F
M:6QE;F%M92!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E1FEL92@D<&%T:"P@
M)&YA;64I"B`@("!["B`@("`@("`@)')E<R`]("1T:&ES+3Y?8VAE8VM1=6]T
M841E;&5T92@D<&%T:"P@)&YA;64I.PH@("`@("`@(&EF("AI<U]A*"1R97,L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@
M("`@("`@?0H*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@
M("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2AS<')I;G1F*"=$14Q%5$4@1E)/32`E
M<R!72$5212!V9G-?='EP92`](#\@04Y$('9F<U]P871H(#T@/R!!3D0@=F9S
M7VYA;64@/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*%9&4U]&24Q%+"`D
M<&%T:"P@)&YA;64I*3L*"B`@("`@("`@:68@*"1T:&ES+3Y?9&(M/F%F9F5C
M=&5D4F]W<R@I(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H7R@B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB*2D["B`@
M("`@("`@?0H*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"%`=6YL:6YK*"1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D
M<&%T:"P@)&YA;64I*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(I*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N(&$@;&ES="!O9B!T:&4@8V]N=&5N=',@;V8@82!F;VQD
M97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("!4
M:&4@9&ER96-T;W)Y('!A=&@N"B`@("`@*B!`<&%R86T@;6EX960@)&9I;'1E
M<B`@("`@(%-T<FEN9R]H87-H(&]F(&ET96US('1O(&9I;'1E<B!B87-E9"!O
M;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!F:6QE;F%M92X*
M("`@("`J($!P87)A;2!B;V]L96%N("1D;W1F:6QE<R`@4VAO=R!D;W1F:6QE
M<S\*("`@("`J($!P87)A;2!B;V]L96%N("1D:7)O;FQY("`@4VAO=R!D:7)E
M8W1O<FEE<R!O;FQY/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@($9I
M;&4@;&ES="!O;B!S=6-C97-S(&]R(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]L:7-T1F]L9&5R*"1P871H+"`D9FEL=&5R(#T@
M;G5L;"P@)&1O=&9I;&5S(#T@=')U92P*("`@("`@("`@("`@("`@("`@("`@
M("`@)&1I<F]N;'D@/2!F86QS92D*("`@('L*("`@("`@("`D8V]N;B`]("1T
M:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@
M("!]"@H@("`@("`@("1F:6QE<R`](&%R<F%Y*"D["B`@("`@("`@)&9I;&5,
M:7-T(#T@87)R87DH*3L*"B`@("`@("`@)&9I;&5,:7-T(#T@)'1H:7,M/E]D
M8BT^9V5T06QL*'-P<FEN=&8H)U-%3$5#5"!V9G-?;F%M92P@=F9S7W1Y<&4L
M('9F<U]M;V1I9FEE9"P@=F9S7V]W;F5R($923TT@)7,*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!72$5212!V9G-?
M<&%T:"`](#\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)'!A=&@I
M*3L*("`@("`@("!I9B`H:7-?82@D9FEL94QI<W0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1F:6QE3&ES=#L*("`@("`@("!]"@H@
M("`@("`@(&9O<F5A8V@@*"1F:6QE3&ES="!A<R`D;&EN92D@>PH@("`@("`@
M("`@("`O+R!&:6QT97(@;W5T(&1O=&9I;&5S(&EF('1H97D@87)E;B=T('=A
M;G1E9"X*("`@("`@("`@("`@:68@*"$D9&]T9FEL97,@)B8@<W5B<W1R*"1L
M:6YE6S!=+"`P+"`Q*2`]/2`G+B<I('L*("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D9FEL95LG;F%M92==
M(#T@)&QI;F5;,%T["@H@("`@("`@("`@("!I9B`H)&QI;F5;,5T@/3T@5D93
M7T9)3$4I('L*("`@("`@("`@("`@("`@("1N86UE(#T@97AP;&]D92@G+B<L
M("1L:6YE6S!=*3L*"B`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)&YA;64I
M(#T](#$I('L*("`@("`@("`@("`@("`@("`@("`D9FEL95LG='EP92==(#T@
M)RHJ;F]N92<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1F:6QE6R=T>7!E)UT@/2!61E,Z.G-T<G1O;&]W97(H)&YA
M;65;8V]U;G0H)&YA;64I("T@,5TI.PH@("`@("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@("`@("1F:6QE6R=S:7IE)UT@/2!F:6QE<VEZ92@D=&AI<RT^
M7V=E=$YA=&EV95!A=&@H)'!A=&@L("1L:6YE6S!=*2D["B`@("`@("`@("`@
M('T@96QS96EF("@D;&EN95LQ72`]/2!61E-?1D],1$52*2!["B`@("`@("`@
M("`@("`@("`D9FEL95LG='EP92==(#T@)RHJ9&ER)SL*("`@("`@("`@("`@
M("`@("1F:6QE6R=S:7IE)UT@/2`M,3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)&9I;&5;)V1A=&4G72`]("1L:6YE6S)=.PH@("`@("`@("`@("`D
M9FEL95LG;W=N97(G72`]("1L:6YE6S-=.PH@("`@("`@("`@("`D9FEL95LG
M<&5R;7,G72`]("<G.PH@("`@("`@("`@("`D9FEL95LG9W)O=7`G72`]("<G
M.PH*("`@("`@("`@("`@+R\@1FEL=&5R:6YG+@H@("`@("`@("`@("!I9B`H
M)'1H:7,M/E]F:6QT97)-871C:"@D9FEL=&5R+"`D9FEL95LG;F%M92==*2D@
M>PH@("`@("`@("`@("`@("`@=6YS970H)&9I;&4I.PH@("`@("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1D
M:7)O;FQY("8F("1F:6QE6R=T>7!E)UT@(3T]("<J*F1I<B<I('L*("`@("`@
M("`@("`@("`@('5N<V5T*"1F:6QE*3L*("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D9FEL97-;)&9I;&5;
M)VYA;64G75T@/2`D9FEL93L*("`@("`@("`@("`@=6YS970H)&9I;&4I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1F:6QE<SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@82!S;W)T960@;&ES="!O9B!F;VQD97)S(&EN
M('-P96-I9FEE9"!D:7)E8W1O<GDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<&%T:"`@("`@("`@(%1H92!P871H(&]F('1H92!D:7)E8W1O<GD@
M=&\@9V5T('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&1I<F5C=&]R>2!L:7-T(&9O<BX*("`@("`J($!P87)A;2!M:7AE9"`D9FEL
M=&5R("`@("`@("!3=')I;F<O:&%S:"!O9B!I=&5M<R!T;R!F:6QT97(@8F%S
M960@;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;VQD
M97)L:7-T+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&1O=&9O;&1E<G,@($EN
M8VQU9&4@9&]T9F]L9&5R<S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!&;VQD97(@;&ES="!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$9O;&1E
M<G,H)'!A=&@@/2`G)RP@)&9I;'1E<B`](&%R<F%Y*"DL("1D;W1F;VQD97)S
M(#T@=')U92D*("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C
M="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@
M("1S<6P@/2!S<')I;G1F*"=314Q%0U0@=F9S7VYA;64L('9F<U]P871H($92
M3TT@)7,@5TA%4D4@=F9S7W!A=&@@/2`_($%.1"!V9G-?='EP92`](#\G+`H@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==
M*3L*"B`@("`@("`@)&9O;&1E<DQI<W0@/2`D=&AI<RT^7V1B+3YG971!;&PH
M)'-Q;"P@87)R87DH)'!A=&@L("161E-?1D],1$52*2D["B`@("`@("`@:68@
M*&ES7V$H)&9O;&1E<DQI<W0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1F;VQD97),:7-T.PH@("`@("`@('T*"B`@("`@("`@)&9O
M;&1E<G,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1F;VQD97),:7-T
M(&%S("1L:6YE*2!["B`@("`@("`@("`@("1F;VQD97);)W9A;"==(#T@)'1H
M:7,M/E]G971.871I=F50871H*"1L:6YE6S%=+"`D;&EN95LP72D["B`@("`@
M("`@("`@("1F;VQD97);)V%B8G)E=B==(#T@)R<["B`@("`@("`@("`@("1F
M;VQD97);)VQA8F5L)UT@/2`G)SL*"B`@("`@("`@("`@("1C;W5N="`]('-U
M8G-T<E]C;W5N="@D9F]L9&5R6R=V86PG72P@)R\G*3L*"B`@("`@("`@("`@
M("1X(#T@,#L*("`@("`@("`@("`@=VAI;&4@*"1X(#P@)&-O=6YT*2!["B`@
M("`@("`@("`@("`@("`D9F]L9&5R6R=A8F)R978G72`N/2`G("`@("<["B`@
M("`@("`@("`@("`@("`D9F]L9&5R6R=L86)E;"==("X]("<@("`@)SL*("`@
M("`@("`@("`@("`@("1X*RL["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1F;VQD97);)V%B8G)E=B==("X]("1L:6YE6S!=.PH@("`@("`@("`@("`D
M9F]L9&5R6R=L86)E;"==("X]("1L:6YE6S!=.PH*("`@("`@("`@("`@)'-T
M<FQE;B`](%9&4SHZ<W1R;&5N*"1F;VQD97);)VQA8F5L)UTI.PH@("`@("`@
M("`@("!I9B`H)'-T<FQE;B`^(#(V*2!["B`@("`@("`@("`@("`@("`D9F]L
M9&5R6R=A8F)R978G72`]('-U8G-T<B@D9F]L9&5R6R=L86)E;"==+"`P+"`H
M)&-O=6YT("H@-"DI.PH@("`@("`@("`@("`@("`@)&QE;F=T:"`]("@R.2`M
M("@D8V]U;G0@*B`T*2D@+R`R.PH@("`@("`@("`@("`@("`@)&9O;&1E<ELG
M86)B<F5V)UT@+CT@<W5B<W1R*"1F;VQD97);)VQA8F5L)UTL("@D8V]U;G0@
M*B`T*2P@)&QE;F=T:"D["B`@("`@("`@("`@("`@("`D9F]L9&5R6R=A8F)R
M978G72`N/2`G+BXN)SL*("`@("`@("`@("`@("`@("1F;VQD97);)V%B8G)E
M=B==("X]('-U8G-T<B@D9F]L9&5R6R=L86)E;"==+"`M,2`J("1L96YG=&@L
M("1L96YG=&@I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D9F]U;F0@
M/2!F86QS93L*("`@("`@("`@("`@9F]R96%C:"`H)&9I;'1E<B!A<R`D9FQT
M<BD@>PH@("`@("`@("`@("`@("`@:68@*"1F;VQD97);)W9A;"==(#T]("1F
M;'1R*2!["B`@("`@("`@("`@("`@("`@("`@)&9O=6YD(#T@=')U93L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@
M*"$D9F]U;F0I('L*("`@("`@("`@("`@("`@("1F;VQD97)S6R1F;VQD97);
M)W9A;"==72`]("1F;VQD97(["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(&MS;W)T*"1F;VQD97)S*3L*("`@("`@("!R971U<FX@)&9O;&1E
M<G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296-U<G-I=F5L>2!C;W!I97,@
M=&AE(&-O;G1E;G1S(&]F(&$@9F]L9&5R('1O(&$@9&5S=&EN871I;VXN"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@=&\@<W1O<F4@=&AE(&1I<F5C
M=&]R>2!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE
M(&]F('1H92!D:7)E8W1O<GDN"B`@("`@*B!`<&%R86T@<W1R:6YG("1D97-T
M("!4:&4@9&5S=&EN871I;VX@;V8@=&AE(&1I<F5C=&]R>2X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%2
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?<F5C=7)S:79E0V]P>2@D<&%T:"P@)&YA;64L("1D97-T*0H@("`@>PH@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^8W)E871E1F]L9&5R*"1D97-T+"`D
M;F%M92D["@H@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*
M("`@("`@("`D9FEL95]L:7-T(#T@)'1H:7,M/FQI<W1&;VQD97(H)'1H:7,M
M/E]G971344Q.871I=F50871H*"1P871H+"`D;F%M92DI.PH*("`@("`@("!F
M;W)E86-H("@D9FEL95]L:7-T(&%S("1F:6QE*2!["B`@("`@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^8V]P>2@D=&AI<RT^7V=E=%-13$YA=&EV95!A=&@H
M)'!A=&@L("1N86UE*2P@)&9I;&5;)VYA;64G72P@)'1H:7,M/E]G971344Q.
M871I=F50871H*"1D97-T+"`D;F%M92DI.PH*("`@("`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@?0H*("`@("\J*@H@("`@("H@4W1O<F4@
M82!F:6QE<R!I;F9O<FUA=&EO;B!W:71H:6X@=&AE(&1A=&%B87-E+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'!A=&@@("`@("`@("!4:&4@<&%T:"!T;R!S=&]R92!T:&4@
M9FEL92!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@("!4
M:&4@9FEL96YA;64@=&\@=7-E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%U
M=&]C<F5A=&4@($%U=&]M871I8V%L;'D@8W)E871E(&1I<F5C=&]R:65S/PH@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O
M<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]W<FET95-13$1A=&$H)'!A=&@L("1N86UE+"`D875T;V-R
M96%T92`](&9A;'-E*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C
M;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@
M("`@("`@+R\@1FEL92!A;')E861Y(&5X:7-T<R!I;B!D871A8F%S90H@("`@
M("`@(&EF("@D=&AI<RT^97AI<W1S*"1P871H+"`D;F%M92DI('L*("`@("`@
M("`@("`@)'%U97)Y(#T@)U501$%412`G("X@)'1H:7,M/E]P87)A;7-;)W1A
M8FQE)UT@+@H@("`@("`@("`@("`@("`@("`@("`G(%-%5"!V9G-?;6]D:69I
M960@/2`_)R`N"B`@("`@("`@("`@("`@("`@("`@("<@5TA%4D4@=F9S7W!A
M=&@@/2`_($%.1"!V9G-?;F%M92`](#\G.PH@("`@("`@("`@("`D=F%L=65S
M(#T@87)R87DH=&EM92@I+"`D<&%T:"P@)&YA;64I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1I9"`]("1T:&ES+3Y?9&(M/FYE>'1)9"@D=&AI
M<RT^7W!A<F%M<ULG=&%B;&4G72D["@H@("`@("`@("`@("`D<75E<GD@/2`G
M24Y315)4($E.5$\@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==("X*("`@
M("`@("`@("`@("`@("`@("`@)R`H=F9S7VED+"!V9G-?='EP92P@=F9S7W!A
M=&@L('9F<U]N86UE+"!V9G-?;6]D:69I960L)R`N"B`@("`@("`@("`@("`@
M("`@("`@("<@=F9S7V]W;F5R*2!604Q515,@*#\L(#\L(#\L(#\L(#\L(#\I
M)SL*("`@("`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1I9"P@5D937T9)3$4L
M("1P871H+"`D;F%M92P@=&EM92@I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W5S97(G72D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5N86UE<R!A;&P@8VAI;&0@<&%T
M:',N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;VQD<&%T:"`@5&AE(&]L9"!P871H(&]F('1H
M92!F;VQD97(@=&\@<F5N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VQD
M;F%M92`@5&AE(&]L9"!N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W
M<&%T:"`@5&AE(&YE=R!P871H(&]F('1H92!F;VQD97(@=&\@<F5N86UE+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;F5W;F%M92`@5&AE(&YE=R!N86UE+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O
M<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]R96-U<G-I=F5344Q296YA;64H)&]L9'!A=&@L("1O;&1N
M86UE+"`D;F5W<&%T:"P@)&YE=VYA;64I"B`@("!["B`@("`@("`@)&9O;&1E
M<DQI<W0@/2`D=&AI<RT^7V1B+3YG971#;VPH<W!R:6YT9B@G4T5,14-4('9F
M<U]N86UE($923TT@)7,@5TA%4D4@=F9S7W1Y<&4@/2`_($%.1"!V9G-?<&%T
M:"`](#\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#`L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH5D937T9/
M3$1%4BP@)'1H:7,M/E]G971344Q.871I=F50871H*"1O;&1P871H+"`D;VQD
M;F%M92DI*3L*"B`@("`@("`@9F]R96%C:"`H)&9O;&1E<DQI<W0@87,@)&9O
M;&1E<BD@>PH@("`@("`@("`@("`D=&AI<RT^7W)E8W5R<VEV95-13%)E;F%M
M92@D=&AI<RT^7V=E=%-13$YA=&EV95!A=&@H)&]L9'!A=&@L("1O;&1N86UE
M*2P@)&9O;&1E<BP@)'1H:7,M/E]G971344Q.871I=F50871H*"1N97=P871H
M+"`D;F5W;F%M92DL("1F;VQD97(I.PH@("`@("`@('T*"B`@("`@("`@)')E
M<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*'-P<FEN=&8H)U501$%412`E<R!3
M150@=F9S7W!A=&@@/2`_(%=(15)%('9F<U]P871H(#T@/R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W1A8FQE)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@D=&AI<RT^7V=E=%-13$YA=&EV95!A=&@H)&YE=W!A
M=&@L("1N97=N86UE*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]G971344Q.871I=F50871H*"1O;&1P871H
M+"`D;VQD;F%M92DI*3L*"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&4@82!F;VQD97)S
M(&-O;G1E;G1S(&9R;VT@=&AE(%9&4R!I;B!T:&4@4U%,(&1A=&%B87-E+`H@
M("`@("H@<F5C=7)S:79E;'DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A
M=&@@;V8@=&AE(&9O;&1E<BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@
M(%1H92!F;VQD97)N86UE('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<F5C=7)S:79E
M4U%,1&5L971E*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/E]D8BT^<75E<GDH<W!R:6YT9B@G1$5,151%($923TT@)7,@
M5TA%4D4@=F9S7W1Y<&4@/2`_($%.1"!V9G-?<&%T:"`](#\G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=T86)L92==*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH5D937T9)3$4L("1T:&ES+3Y?9V5T4U%,3F%T:79E
M4&%T:"@D<&%T:"P@)&YA;64I*2D["B`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("!]"@H@("`@("`@("1F;VQD97),:7-T(#T@)'1H:7,M/E]D
M8BT^9V5T0V]L*'-P<FEN=&8H)U-%3$5#5"!V9G-?;F%M92!&4D]-("5S(%=(
M15)%('9F<U]T>7!E(#T@/R!!3D0@=F9S7W!A=&@@/2`_)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=T86)L92==*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*%9&4U]&3TQ$15(L("1T:&ES+3Y?9V5T
M4U%,3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I*2D["@H@("`@("`@(&9O<F5A
M8V@@*"1F;VQD97),:7-T(&%S("1F;VQD97(I('L*("`@("`@("`@("`@)'1H
M:7,M/E]R96-U<G-I=F5344Q$96QE=&4H)'1H:7,M/E]G971344Q.871I=F50
M871H*"1P871H+"`D;F%M92DL("1F;VQD97(I.PH@("`@("`@('T*"B`@("`@
M("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*'-P<FEN=&8H)T1%3$54
M12!&4D]-("5S(%=(15)%('9F<U]T>7!E(#T@/R!!3D0@=F9S7VYA;64@/2`_
M($%.1"!V9G-?<&%T:"`](#\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH5D93
M7T9/3$1%4BP@)&YA;64L("1P871H*2D["@H@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E(&$@9F]L9&5R<R!C
M;VYT96YT<R!F<F]M('1H92!61E,L(')E8W5R<VEV96QY+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'!A=&@@(%1H92!P871H(&]F('1H92!F;VQD97(N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N86UE("!4:&4@9F]L9&5R;F%M92!T;R!U<V4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@
M4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7W)E8W5R<VEV94Q&4T1E;&5T92@D<&%T:"P@)&YA;64I"B`@("![
M"B`@("`@("`@)&1I<B`]("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"P@
M)&YA;64I.PH@("`@("`@("1D:"`]($!O<&5N9&ER*"1D:7(I.PH*("`@("`@
M("!W:&EL92`H9F%L<V4@(3T]("@D9FEL92`](')E861D:7(H)&1H*2DI('L*
M("`@("`@("`@("`@:68@*"1F:6QE("$]("<N)R`F)B`D9FEL92`A/2`G+BXG
M*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?9&ER*"1D:7(@+B`G+R<@+B`D
M9FEL92DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)E8W5R<VEV
M94Q&4T1E;&5T92AE;7!T>2@D<&%T:"D@/R`D;F%M92`Z("1P871H("X@)R\G
M("X@)&YA;64L("1F:6QE*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@0'5N;&EN:R@D9&ER("X@)R\G("X@)&9I;&4I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@($!C;&]S961I<B@D9&@I.PH*("`@("`@("!R971U<FX@<FUD:7(H
M)&1I<BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!O<&5N
M(&$@<&5R<VES=&5N="!C;VYN96-T:6]N('1O('1H92!344P@<V5R=F5R+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN
M96-T*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]D8B`]/3T@9F%L<V4I
M('L*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D=&AI<RT^7W!A<F%M<RDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44PM1FEL92!61E,N(BDI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M<F5Q=6ER960@/2!A<G)A>2@G<&AP='EP92<L("=V9G-R;V]T)RD["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1R97%U:7)E9"!A<R`D=F%L*2!["B`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R1V86Q=*2D@>PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P
M<FEN=&8H7R@B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93
M(&-O;F9I9W5R871I;VXN(BDL("1V86PI*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7W!A<F%M<ULG9&%T86)A<V4G72DI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=D871A8F%S92==(#T@)R<["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)W5S97)N86UE
M)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA
M;64G72`]("<G.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==*2D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UT@/2`G)SL*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M
M<ULG=&%B;&4G72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=T86)L92==(#T@)VAO<F1E7W9F<R<["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("\J($-O;FYE8W0@=&\@=&AE(%-13"!S97)V97(@=7-I;F<@=&AE
M('-U<'!L:65D('!A<F%M971E<G,N("HO"B`@("`@("`@("`@(')E<75I<F5?
M;VYC92`G1$(N<&AP)SL*("`@("`@("`@("`@)'1H:7,M/E]D8B`]("9$0CHZ
M8V]N;F5C="@D=&AI<RT^7W!A<F%M<RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@G<&5R<VES=&5N="<@/3X@(65M<'1Y
M*"1T:&ES+3Y?<&%R86US6R=P97)S:7-T96YT)UTI*2D["B`@("`@("`@("`@
M(&EF("AI<U]A*"1T:&ES+3Y?9&(L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@("1E<G)O<B`]("1T:&ES+3Y?9&(["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V1B(#T@9F%L<V4["B`@("`@("`@("`@("`@("!R971U<FX@
M)&5R<F]R.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!3970@1$(@
M<&]R=&%B:6QI='D@;W!T:6]N<RX*("`@("`@("`@("`@<W=I=&-H("@D=&AI
M<RT^7V1B+3YP:'!T>7!E*2!["B`@("`@("`@("`@(&-A<V4@)VUS<W%L)SH*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?9&(M/G-E=$]P=&EO;B@G<&]R=&%B
M:6QI='DG+"!$0E]03U)404))3$E465],3U=%4D-!4T4@?"!$0E]03U)404))
M3$E465]%4E)/4E,@?"!$0E]03U)404))3$E465]25%))32D["B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$
M0E]03U)404))3$E465],3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%4E)/
M4E,I.PH@("`@("`@("`@("!]"@H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$:7-C;VYN96-T(&9R;VT@
M=&AE(%-13"!S97)V97(@86YD(&-L96%N('5P('1H92!C;VYN96-T:6]N+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC
M=&EO;B!?9&ES8V]N;F5C="@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?
M9&(I('L*("`@("`@("`@("`@)'1H:7,M/E]D8BT^9&ES8V]N;F5C="@I.PH@
M("`@("`@("`@("`D=&AI<RT^7V1B(#T@9F%L<V4["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@9G5L;"!F:6QE;F%M92!O;B!T
M:&4@;F%T:79E(&9I;&5S>7-T96TL(&9R;VT@82!61E,*("`@("`J('!A=&@@
M86YD(&YA;64N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE(%9&4R!F:6QE('!A
M=&@N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@5D93(&9I;&5N
M86UE+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9G5L;"!N
M871I=F4@9FEL96YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971.871I
M=F50871H*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("!I9B`H(65M<'1Y
M*"1N86UE*2D@>PH@("`@("`@("`@("`D;F%M92`]("<O)R`N("1N86UE.PH@
M("`@("`@('T*("`@("`@("!I9B`H:7-S970H)'!A=&@I*2!["B`@("`@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W!A<F%M<ULG:&]M92==*2`F)@H@("`@
M("`@("`@("`@("`@<')E9U]M871C:"@G?%Y^+S\H+BHI)'PG+"`D<&%T:"P@
M)&UA=&-H97,I*2!["B`@("`@("`@("`@("`@("`D<&%T:"`]("1T:&ES+3Y?
M<&%R86US6R=H;VUE)UT@("X@)R\G("X@)&UA=&-H97-;,5T["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A<F%M<ULG=F9S
M<F]O="==("X@)R\G("X@)'!A=&@@+B`D;F%M93L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P87)A;7-;)W9F<W)O;W0G
M72`N("1N86UE.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!A(&9U;&P@4U%,(&9I;&5N86UE(&]N('1H92!N871I=F4@9FEL97-Y
M<W1E;2P@9G)O;2!A(%9&4PH@("`@("H@<&%T:"!A;F0@;F%M92X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P871H("!4:&4@5D93(&9I;&4@<&%T:"X*("`@("`J($!P87)A
M;2!S=')I;F<@)&YA;64@(%1H92!61E,@9FEL96YA;64N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!F=6QL(&YA=&EV92!F:6QE;F%M92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=%-13$YA=&EV95!A=&@H)'!A=&@L
M("1N86UE*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D<&%T:"DI('L*("`@
M("`@("`@("`@<F5T=7)N("1N86UE.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1P871H("X@)R\G("X@)&YA;64["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O5D93+G!H<```````````````````````````````````````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#8V-C<V`#$P-3$U-#,S-S4S`#`Q-S8R,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M<F5Q=6ER95]O;F-E("=014%2+G!H<"<["G)E<75I<F5?;VYC92`G3&]G+G!H
M<"<["@ID969I;F4H)U9&4U]154]405]-151224-?0EE412<L(#$I.PID969I
M;F4H)U9&4U]154]405]-151224-?2T(G+"`R*3L*9&5F:6YE*"=61E-?455/
M5$%?34544DE#7TU")RP@,RD["F1E9FEN92@G5D937U%53U1!7TU%5%))0U]'
M0B<L(#0I.PH*+RHJ"B`J(%9&4R!!4$D@9F]R(&%B<W1R86-T960@9FEL92!S
M=&]R86=E(&%N9"!A8V-E<W,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U9&
M4R]61E,N<&AP+'8@,2XV.2XT+C$V(#(P,#8O,#@O,#<@,#`Z,S`Z,30@8VAU
M8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`
M<&%C:V%G92!61E,*("H@0'-I;F-E("`@2&]R9&4@,BXR"B`J+PIC;&%S<R!6
M1E,@>PH*("`@("\J*@H@("`@("H@2&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I
M;VX@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@
M*B!,:7-T(&]F(&%D9&ET:6]N86P@8W)E9&5N=&EA;',@<F5Q=6ER960@9F]R
M('1H:7,@5D93(&)A8VME;F0@*&5X86UP;&4Z"B`@("`@*B!&;W(@1E10+"!W
M92!N965D(&$@=7-E<FYA;64@86YD('!A<W-W;W)D('1O(&QO9R!I;B!T;R!T
M:&4@<V5R=F5R('=I=&@I+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1?8W)E9&5N=&EA;',@/2!A<G)A>2@I.PH*("`@("\J
M*@H@("`@("H@3&ES="!O9B!P97)M:7-S:6]N<R!A;F0@:68@=&AE>2!C86X@
M8F4@8VAA;F=E9"!I;B!T:&ES(%9&4R!B86-K96YD+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&5R;6ES<VEO;G,@/2!A
M<G)A>2@*("`@("`@("`G;W=N97(G(#T^(&%R<F%Y*"=R96%D)R`]/B!F86QS
M92P@)W=R:71E)R`]/B!F86QS92P@)V5X96-U=&4G(#T^(&9A;'-E*2P*("`@
M("`@("`G9W)O=7`G(#T^(&%R<F%Y*"=R96%D)R`]/B!F86QS92P@)W=R:71E
M)R`]/B!F86QS92P@)V5X96-U=&4G(#T^(&9A;'-E*2P*("`@("`@("`G86QL
M)R`@(#T^(&%R<F%Y*"=R96%D)R`]/B!F86QS92P@)W=R:71E)R`]/B!F86QS
M92P@)V5X96-U=&4G(#T^(&9A;'-E*2D["@H@("`@+RHJ"B`@("`@*B!!(%!%
M05(@3&]G(&]B:F5C="X@268@<')E<V5N="P@=VEL;"!B92!U<V5D('1O(&QO
M9R!E<G)O<G,@86YD"B`@("`@*B!I;F9O<FUA=&EO;F%L(&UE<W-A9V5S(&%B
M;W5T(%9&4R!A8W1I=FET>2X*("`@("`J"B`@("`@*B!`=F%R($QO9PH@("`@
M("HO"B`@("!V87(@)%]L;V=G97(@/2!N=6QL.PH*("`@("\J*@H@("`@("H@
M5&AE(&QO9R!L979E;"!T;R!U<V4@+2!M97-S86=E<R!W:71H(&$@:&EG:&5R
M(&QO9R!L979E;"!T:&%N(&-O;F9I9W5R960*("`@("`J(&AE<F4@=VEL;"!N
M;W0@8F4@;&]G9V5D+B!$969A=6QT<R!T;R!O;FQY(&QO9V=I;F<@97)R;W)S
M(&]R(&AI9VAE<BX*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J
M+PH@("`@=F%R("1?;&]G3&5V96P@/2!014%27TQ/1U]%4E(["@H@("`@+RHJ
M"B`@("`@*B!4:&4@8W5R<F5N="!S:7IE+"!I;B!B>71E<RP@;V8@=&AE(%9&
M4R!I=&5M+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@
M("!V87(@)%]V9G-3:7IE(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($-O;G-T
M<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!
M(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%9&4R@D<&%R86US(#T@87)R87DH*2D*("`@('L*
M("`@("`@("!I9B`H96UP='DH)'!A<F%M<ULG=7-E<B==*2D@>PH@("`@("`@
M("`@("`D<&%R86US6R=U<V5R)UT@/2`G)SL*("`@("`@("!]"B`@("`@("`@
M:68@*&5M<'1Y*"1P87)A;7-;)W9F<U]Q=6]T86QI;6ET)UTI*2!["B`@("`@
M("`@("`@("1P87)A;7-;)W9F<U]Q=6]T86QI;6ET)UT@/2`M,3L*("`@("`@
M("!]"B`@("`@("`@:68@*&5M<'1Y*"1P87)A;7-;)W9F<U]Q=6]T87)O;W0G
M72DI('L*("`@("`@("`@("`@)'!A<F%M<ULG=F9S7W%U;W1A<F]O="==(#T@
M)R\G.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A
M;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@=&AE(&-R961E;G1I
M86QS('1H870@=V4@:&%V92!B>2!C86QL:6YG(%]C;VYN96-T*"DL('1O('-E
M92!I9@H@("`@("H@=&AE<F4@:7,@82!V86QI9"!L;V=I;BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,L(%!%05)?17)R
M;W(@9&5S8W)I8FEN9R!T:&4@<')O8FQE;2!I9B!T:&4*("`@("`J("`@("`@
M("`@("`@("`@(&-R961E;G1I86QS(&%R92!I;G9A;&ED+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!C:&5C:T-R961E;G1I86QS*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]C;VYN96-T*"D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3971S(&-O;F9I9W5R871I;VX@<&%R86UE=&5R<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06X@87-S;V-I871I=F4@87)R87D@
M=VET:"!P87)A;65T97(@;F%M97,@87,@:V5Y<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T4&%R86US*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@
M("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)&YA;64@/3X@)'9A;'5E*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R1N86UE72`]("1V86QU93L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&-O;F9I9W5R
M871I;VX@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("!4:&4@<&%R86UE=&5R('1O(')E='5R;BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!4:&4@<&%R86UE=&5R('9A;'5E(&]R(&YU;&P@
M:68@:70@9&]E<VXG="!E>&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M4&%R86TH)&YA;64I"B`@("!["B`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES
M+3Y?<&%R86US6R1N86UE72D@/R`D=&AI<RT^7W!A<F%M<ULD;F%M95T@.B!N
M=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@3&]G<R!A(&UE<W-A9V4@:68@
M82!014%2($QO9R!O8FIE8W0@:7,@879A:6QA8FQE+"!A;F0@=&AE(&UE<W-A
M9V4G<PH@("`@("H@<')I;W)I='D@:7,@;&]W97(@=&AA;B!O<B!E<75A;"!T
M;R!T:&4@8V]N9FEG=7)E9"!L;V<@;&5V96PN"B`@("`@*@H@("`@("H@0'!A
M<F%M(&UI>&5D("`@)&UE<W-A9V4@("!4:&4@;65S<V%G92!T;R!B92!L;V=G
M960N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<')I;W)I='D@(%1H92!M97-S
M86=E)W,@<')I;W)I='DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO9R@D;65S
M<V%G92P@)'!R:6]R:71Y(#T@4$5!4E],3T=?15)2*0H@("`@>PH@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/E]L;V=G97(I('Q\("1P<FEO<FET>2`^("1T
M:&ES+3Y?;&]G3&5V96PI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@
M('T*"B`@("`@("`@:68@*&ES7V$H)&UE<W-A9V4L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@)'5S97)I;F9O(#T@)&UE<W-A9V4M/F=E=%5S97))
M;F9O*"D["B`@("`@("`@("`@("1M97-S86=E(#T@)&UE<W-A9V4M/F=E=$UE
M<W-A9V4H*3L*("`@("`@("`@("`@:68@*"1U<V5R:6YF;RD@>PH@("`@("`@
M("`@("`@("`@:68@*&ES7V%R<F%Y*"1U<V5R:6YF;RDI('L*("`@("`@("`@
M("`@("`@("`@("`D=7-E<FEN9F\@/2!I;7!L;V1E*"<L("<L("1U<V5R:6YF
M;RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D;65S<V%G
M92`N/2`G.B`G("X@)'5S97)I;F9O.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("`O*B!-86ME('-U<F4@=&\@;&]G(&EN('1H92!S>7-T96TG
M<R!L;V-A;&4N("HO"B`@("`@("`@)&QO8V%L92`]('-E=&QO8V%L92A,0U]4
M24U%+"`P*3L*("`@("`@("!S971L;V-A;&4H3$-?5$E-12P@)T,G*3L*"B`@
M("`@("`@)'1H:7,M/E]L;V=G97(M/FQO9R@D;65S<V%G92P@)'!R:6]R:71Y
M*3L*"B`@("`@("`@+RH@4F5S=&]R92!O<FEG:6YA;"!L;V-A;&4N("HO"B`@
M("`@("`@<V5T;&]C86QE*$Q#7U1)344L("1L;V-A;&4I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T<R!T:&4@4$5!4B!,;V<@;V)J96-T('5S960@=&\@
M;&]G(&EN9F]R;6%T:6]N86P@;W(@97)R;W(@;65S<V%G97,N"B`@("`@*@H@
M("`@("H@0'!A<F%M($QO9R`F)&QO9V=E<B`@5&AE($QO9R!O8FIE8W0@=&\@
M=7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971,;V=G97(H)B1L;V=G97(L
M("1L;V=,979E;"`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1L
M;V=G97(L("=,;V<G*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H*("`@("`@("`D=&AI<RT^7VQO9V=E<B`]("8D;&]G9V5R.PH@
M("`@("`@(&EF("@A:7-?;G5L;"@D;&]G3&5V96PI*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?;&]G3&5V96P@/2`D;&]G3&5V96P["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S('1H92!S:7IE(&]F(&$@9FEL
M92!F<F]M('1H92!61E,N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&AN86UE('1O
M('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9I
M;&5N86UE('1O(')E=')I979E+@H@("`@("H*("`@("`J($!R971U<FX@:6YT
M96=E<B!4:&4@9FEL92!S:7IE+@H@("`@("HO"B`@("!F=6YC=&EO;B!S:7IE
M*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*").;W0@<W5P<&]R=&5D+B(I*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE('-I>F4@;V8@82!F;VQD97(*("`@("`J"B`@
M("`@*B!`<VEN8V4@2&]R9&4@,RXQ"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<&%T:"`@5&AE('!A=&@@=&\@=&AE(&9O;&1E<BX*("`@("`J($!P
M87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE(&]F('1H92!F;VQD97(N"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@<VEZ92!O9B!T:&4@
M9F]L9&5R+"!I;B!B>71E<RP@;W(@4$5!4E]%<G)O<B!O;@H@("`@("H@("`@
M("`@("`@("`@("`@("!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971&;VQD97)3:7IE*"1P871H(#T@;G5L;"P@)&YA;64@/2!N=6QL*0H@("`@
M>PH@("`@("`@("1S:7IE(#T@,#L*("`@("`@("`D<F]O="`]("@H(6ES7VYU
M;&PH)'!A=&@I*2`_("1P871H("X@)R\G(#H@)R<I("X@)&YA;64["B`@("`@
M("`@)&]B:F5C=%]L:7-T(#T@)'1H:7,M/FQI<W1&;VQD97(H)')O;W0L(&YU
M;&PL('1R=64L(&9A;'-E+"!T<G5E*3L*("`@("`@("!F;W)E86-H("@D;V)J
M96-T7VQI<W0@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@(&EF("AI
M<W-E="@D=F%L6R=S=6)D:7)S)UTI*2!["B`@("`@("`@("`@("`@("`D<VEZ
M92`K/2`D=&AI<RT^9V5T1F]L9&5R4VEZ92@D<F]O="P@)&ME>2D["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D9FEL97-I>F4@/2`D
M=&AI<RT^<VEZ92@D<F]O="P@)&ME>2D["B`@("`@("`@("`@("`@("!I9B`H
M:7-?82@D9FEL97-I>F4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)&9I;&5S:7IE.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)'-I>F4@*ST@)&9I;&5S:7IE.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'-I>F4["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971R:65V97,@82!F:6QE(&9R;VT@=&AE(%9&4RX*
M("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P871H("!4:&4@<&%T:&YA;64@=&\@=&AE(&9I;&4N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@9FEL96YA;64@=&\@<F5T<FEE
M=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@5&AE(&9I;&4@9&%T
M82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9"@D<&%T:"P@)&YA;64I"B`@
M("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F]T('-U
M<'!O<G1E9"XB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V97,@
M82!P87)T(&]F(&$@9FEL92!F<F]M('1H92!61E,N(%!A<G1I8W5L87)L>2!U
M<V5F=6P@=VAE;@H@("`@("H@<F5A9&EN9R!L87)G92!F:6QE<R!W:&EC:"!W
M;W5L9"!E>&-E960@=&AE(%!(4"!M96UO<GD@;&EM:71S(&EF('1H97D*("`@
M("`J('=E<F4@<W1O<F5D(&EN(&$@<W1R:6YG+@H@("`@("H*("`@("`J($!A
M8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1P871H("`@
M("`@(%1H92!P871H;F%M92!T;R!T:&4@9FEL92X*("`@("`J($!P87)A;2!S
M=')I;F<@("1N86UE("`@("`@(%1H92!F:6QE;F%M92!T;R!R971R:65V92X*
M("`@("`J($!P87)A;2!I;G1E9V5R("1O9F9S970@("`@(%1H92!O9F9S970@
M;V8@=&AE('!A<G0N("A4:&4@;F5W(&]F9G-E="!W:6QL"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!B92!S=&]R960@:6X@:&5R92DN"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D;&5N9W1H("`@("!4:&4@;&5N9W1H(&]F
M('1H92!P87)T+B!)9B!T:&4@;&5N9W1H(#T@+3$L"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!T:&4@=VAO;&4@<&%R="!A9G1E<B!T:&4@
M;V9F<V5T(&ES(')E=')I979E9"X*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@($EF(&UO<F4@8GET97,@87)E(&=I=F5N(&%S(&5X:7-T<R!A
M9G1E<B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&=I
M=F5N(&]F9G-E="X@3VYL>2!T:&4@879A:6QA8FQE(&)Y=&5S(&%R90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5A9"X*("`@("`J($!P
M87)A;2!I;G1E9V5R("1R96UA:6YI;F<@(%1H92!B>71E<R!T:&%T(&%R92!L
M969T+"!A9G1E<B!T:&4@<&%R="!T:&%T"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I<R!R971R:65V960N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@5&AE(&9I;&4@9&%T82X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5A9$)Y=&5286YG92@D<&%T:"P@)&YA;64L("8D;V9F<V5T+"`D;&5N
M9W1H(#T@+3$L("8D<F5M86EN:6YG*0H@("`@>PH@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*%\H(DYO="!S=7!P;W)T960N(BDI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4W1O<F5S(&$@9FEL92!I;B!T:&4@5D93+@H@("`@
M("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'!A=&@@("`@("`@("!4:&4@<&%T:"!T;R!S=&]R92!T:&4@9FEL92!I
M;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@("!4:&4@9FEL
M96YA;64@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&UP1FEL92`@
M("`@(%1H92!T96UP;W)A<GD@9FEL92!C;VYT86EN:6YG('1H92!D871A('1O
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8F4@<W1O<F5D
M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%U=&]C<F5A=&4@($%U=&]M871I
M8V%L;'D@8W)E871E(&1I<F5C=&]R:65S/PH@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J
M96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E*"1P
M871H+"`D;F%M92P@)'1M<$9I;&4L("1A=71O8W)E871E(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F]T('-U
M<'!O<G1E9"XB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R97,@82!F
M:6QE(&EN('1H92!61E,@9G)O;2!R87<@9&%T82X*("`@("`J"B`@("`@*B!`
M86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@
M("`@("`@5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE("`@("`@("`@5&AE(&9I;&5N86UE('1O('5S
M92X*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&$@("`@("`@("!4:&4@9FEL
M92!D871A+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%U=&]C<F5A=&4@($%U
M=&]M871I8V%L;'D@8W)E871E(&1I<F5C=&]R:65S/PH@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R
M:71E1&%T82@D<&%T:"P@)&YA;64L("1D871A+"`D875T;V-R96%T92`](&9A
M;'-E*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(DYO="!S=7!P;W)T960N(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@36]V
M97,@82!F:6QE('1H<F]U9V@@=&AE(&)A8VME;F0N"B`@("`@*@H@("`@("H@
M0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@
M5&AE('!A=&@@;V8@=&AE(&]R:6=I;F%L(&9I;&4N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N86UE("!4:&4@;F%M92!O9B!T:&4@;W)I9VEN86P@9FEL92X*
M("`@("`J($!P87)A;2!S=')I;F<@)&1E<W0@(%1H92!D97-T:6YA=&EO;B!F
M:6QE(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O
M;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@;6]V92@D<&%T:"P@)&YA;64L("1D97-T
M*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO
M="!S=7!P;W)T960N(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]P:65S
M(&$@9FEL92!T:')O=6=H('1H92!B86-K96YD+@H@("`@("H*("`@("`J($!A
M8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H
M92!P871H(&]F('1H92!O<FEG:6YA;"!F:6QE+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;F%M92`@5&AE(&YA;64@;V8@=&AE(&]R:6=I;F%L(&9I;&4N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1D97-T("!4:&4@;F%M92!O9B!T:&4@9&5S
M=&EN871I;VX@9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O<'DH)'!A=&@L("1N
M86UE+"`D9&5S="D*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BA?*").;W0@<W5P<&]R=&5D+B(I*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($1E;&5T97,@82!F:6QE(&9R;VT@=&AE(%9&4RX*("`@("`J"B`@("`@
M*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H
M("!4:&4@<&%T:"!T;R!D96QE=&4@=&AE(&9I;&4@9G)O;2X*("`@("`J($!P
M87)A;2!S=')I;F<@)&YA;64@(%1H92!F:6QE;F%M92!T;R!D96QE=&4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R
M(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9&5L971E1FEL92@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F]T('-U<'!O<G1E9"XB
M*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YA;65S(&$@9FEL92!I;B!T
M:&4@5D93+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&]L9'!A=&@@(%1H92!O;&0@<&%T:"!T;R!T:&4@
M9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&]L9&YA;64@(%1H92!O;&0@
M9FEL96YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=P871H("!4:&4@
M;F5W('!A=&@@;V8@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N
M97=N86UE("!4:&4@;F5W(&9I;&5N86UE+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J
M96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F%M92@D
M;VQD<&%T:"P@)&]L9&YA;64L("1N97=P871H+"`D;F5W;F%M92D*("`@('L*
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@<W5P<&]R
M=&5D+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@:68@82!G
M:79E;B!F:6QE(&]R(&9O;&1E<B!E>&ES=',@:6X@82!F;VQD97(N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@=&\@=&AE
M(&9O;&1E<BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F:6QE
M(&]R(&9O;&1E<B!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5')U92!I9B!I="!E>&ES=',L(&9A;'-E(&]T:&5R=VES92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@97AI<W1S*"1P871H+"`D;F%M92D*("`@('L*("`@
M("`@("`D;&ES="`]("1T:&ES+3YL:7-T1F]L9&5R*"1P871H*3L*("`@("`@
M("!I9B`H:7-?82@D;&ES="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N(&ES<V5T*"1L:7-T6R1N86UE72D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@0W)E871E<R!A(&9O;&1E<B!I;B!T:&4@5D93+@H@
M("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'!A=&@@(%1H92!P87)E;G0@9F]L9&5R+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F%M92`@5&AE(&YA;64@;V8@=&AE(&YE=R!F;VQD97(N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R
M(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@8W)E871E1F]L9&5R*"1P871H+"`D;F%M92D*("`@('L*("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@<W5P<&]R=&5D
M+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J($%U=&]M871I8V%L;'D@8W)E
M871E<R!A;GD@;F5C97-S87)Y('!A<F5N="!D:7)E8W1O<FEE<R!I;B!T:&4@
M<W!E8VEF:65D"B`@("`@*B`D<&%T:"X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P871H("!4:&4@5D93('!A=&@@=&\@875T;V-R96%T92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@875T;V-R96%T95!A=&@H)'!A=&@I"B`@("![
M"B`@("`@("`@)&1I<G,@/2!E>'!L;V1E*"<O)RP@)'!A=&@I.PH@("`@("`@
M(&EF("AI<U]A<G)A>2@D9&ER<RDI('L*("`@("`@("`@("`@)&-U<B`]("<O
M)SL*("`@("`@("`@("`@9F]R96%C:"`H)&1I<G,@87,@)&1I<BD@>PH@("`@
M("`@("`@("`@("`@:68@*"%E;7!T>2@D9&ER*2D@>PH@("`@("`@("`@("`@
M("`@("`@(&EF("@A)'1H:7,M/FES1F]L9&5R*"1C=7(L("1D:7(I*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^8W)E871E
M1F]L9&5R*"1C=7(L("1D:7(I.PH@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("!I9B`H)&-U<B`A/2`G+R<I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&-U<B`N/2`G+R<["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("1C=7(@+CT@)&1I<CL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@82!G:79E
M;B!I=&5M(&ES(&$@9F]L9&5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'!A=&@@(%1H92!P87)E;G0@9F]L9&5R+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;F%M92`@5&AE(&ET96T@;F%M92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@:68@:70@:7,@82!F;VQD97(L(&9A;'-E(&]T
M:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-&;VQD97(H)'!A=&@L
M("1N86UE*0H@("`@>PH@("`@("`@("1F;VQD97),:7-T(#T@)'1H:7,M/FQI
M<W1&;VQD97(H)'!A=&@L(&YU;&PL('1R=64L('1R=64I.PH@("`@("`@(')E
M='5R;B!I<W-E="@D9F]L9&5R3&ES=%LD;F%M95TI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1&5L971E<R!A(&9O;&1E<B!F<F]M('1H92!61E,N"B`@("`@
M*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<&%T:"`@("`@("`@5&AE('!A<F5N="!F;VQD97(N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N86UE("`@("`@("!4:&4@;F%M92!O9B!T:&4@9F]L9&5R
M('1O(&1E;&5T92X*("`@("`J($!P87)A;2!B;V]L96%N("1R96-U<G-I=F4@
M($9O<F-E(&$@<F5C=7)S:79E(&1E;&5T93\*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&5&
M;VQD97(H)'!A=&@L("1N86UE+"`D<F5C=7)S:79E(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F]T('-U<'!O
M<G1E9"XB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296-U<G-I=F5L>2!R
M96UO=F4@86QL(&9I;&5S(&%N9"!S=6)F;VQD97)S(&9R;VT@=&AE(&=I=F5N
M"B`@("`@*B!F;VQD97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<&%T:"`@5&AE('!A=&@@;V8@=&AE(&9O;&1E<B!T;R!E;7!T>2X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!0
M14%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!E;7!T>49O;&1E<B@D<&%T:"D*("`@('L*("`@("`@("`O+R!'970@
M86YD(&1E;&5T92!T:&4@<W5B9F]L9&5R<RX*("`@("`@("`D;&ES="`]("1T
M:&ES+3YL:7-T1F]L9&5R*"1P871H+"!N=6QL+"!T<G5E+"!T<G5E*3L*("`@
M("`@("!I9B`H:7-?82@D;&ES="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&QI<W0["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@
M*"1L:7-T(&%S("1F;VQD97(I('L*("`@("`@("`@("`@)')E<W5L="`]("1T
M:&ES+3YD96QE=&5&;VQD97(H)'!A=&@L("1F;VQD97);)VYA;64G72P@=')U
M92D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@("\O($]N;'D@9FEL97,@87)E(&QE
M9G0L(&=E="!A;F0@9&5L971E('1H96TN"B`@("`@("`@)&QI<W0@/2`D=&AI
M<RT^;&ES=$9O;&1E<B@D<&%T:"D["B`@("`@("`@:68@*&ES7V$H)&QI<W0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1L:7-T.PH@
M("`@("`@('T*("`@("`@("!F;W)E86-H("@D;&ES="!A<R`D9FEL92D@>PH@
M("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F1E;&5T949I;&4H)'!A=&@L
M("1F:6QE6R=N86UE)UTI.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@9FEL92!L
M:7-T(&]F('1H92!D:7)E8W1O<GD@<&%S<V5D(&EN+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@(%1H92!P871H(&]F('1H92!D
M:7)E8W1O<GDN"B`@("`@*B!`<&%R86T@;6EX960@)&9I;'1E<B`@("`@("!3
M=')I;F<O:&%S:"!T;R!F:6QT97(@9FEL92]D:7)N86UE(&]N+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)&1O=&9I;&5S("`@4VAO=R!D;W1F:6QE<S\*("`@
M("`J($!P87)A;2!B;V]L96%N("1D:7)O;FQY("`@(%-H;W<@;VYL>2!D:7)E
M8W1O<FEE<S\*("`@("`J($!P87)A;2!B;V]L96%N("1R96-U<G-I=F4@(%)E
M='5R;B!A;&P@9&ER96-T;W)Y(&QE=F5L<R!R96-U<G-I=F5L>3\*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!&:6QE(&QI<W0@;VX@<W5C8V5S<R!O
M<B!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&QI<W1&;VQD97(H)'!A=&@L("1F:6QT97(@/2!N=6QL+"`D9&]T9FEL97,@
M/2!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`D9&ER;VYL>2`](&9A
M;'-E+"`D<F5C=7)S:79E(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&QI<W0@
M/2`D=&AI<RT^7VQI<W1&;VQD97(H)'!A=&@L("1F:6QT97(L("1D;W1F:6QE
M<RP@)&1I<F]N;'DI.PH@("`@("`@(&EF("@A)')E8W5R<VEV92!\?"!I<U]A
M*"1L:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M;&ES=#L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1L:7-T(&%S("1N
M86UE(#T^("1V86QU97,I('L*("`@("`@("`@("`@:68@*"1V86QU97-;)W1Y
M<&4G72`]/2`G*BID:7(G*2!["B`@("`@("`@("`@("`@("`D;&ES=%LD;F%M
M95U;)W-U8F1I<G,G72`]("1T:&ES+3YL:7-T1F]L9&5R*"1P871H("X@)R\G
M("X@)&YA;64L("1F:6QT97(L("1D;W1F:6QE<RP@)&1I<F]N;'DL("1R96-U
M<G-I=F4I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&QI<W0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%N
M('5N<V]R=&5D(&9I;&4@;&ES="!O9B!T:&4@<W!E8VEF:65D(&1I<F5C=&]R
M>2X*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1P871H("`@("`@(%1H92!P871H(&]F('1H92!D:7)E8W1O
M<GDN"B`@("`@*B!`<&%R86T@;6EX960@)&9I;'1E<B`@("`@(%-T<FEN9R]H
M87-H('1O(&9I;'1E<B!F:6QE+V1I<FYA;64@;VXN"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D9&]T9FEL97,@(%-H;W<@9&]T9FEL97,_"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D9&ER;VYL>2`@(%-H;W<@;VYL>2!D:7)E8W1O<FEE<S\*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!&:6QE(&QI<W0@;VX@<W5C
M8V5S<R!O<B!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]L:7-T1F]L9&5R*"1P871H+"`D9FEL=&5R(#T@;G5L;"P@)&1O
M=&9I;&5S(#T@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("1D:7)O
M;FQY(#T@9F%L<V4I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H7R@B3F]T('-U<'!O<G1E9"XB*2D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!C=7)R96YT('=O<FMI;F<@9&ER96-T;W)Y(&]F
M('1H92!61E,@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&-U<G)E;G0@=V]R:VEN9R!D:7)E8W1O<GDN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$-U<G)E;G1$:7)E8W1O<GDH*0H@("`@>PH@("`@("`@
M(')E='5R;B`G)SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=VAE
M=&AE<B!O<B!N;W0@82!F:6QE;F%M92!M871C:&5S(&%N>2!F:6QT97(@96QE
M;65N="X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@;6EX960@)&9I;'1E<B`@("`@4W1R:6YG+VAA<V@@=&\@
M8G5I;&0@=&AE(')E9W5L87(@97AP<F5S<VEO;@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@(&9R;VTN"B`@("`@*B!`<&%R86T@<W1R:6YG("1F
M:6QE;F%M92`@4W1R:6YG(&-O;G1A:6YI;F<@=&AE(&9I;&5N86UE('1O(&UA
M=&-H+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!M
M871C:"P@9F%L<V4@;VX@;F\@;6%T8V@N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]F:6QT97)-871C:"@D9FEL=&5R+"`D9FEL96YA;64I"B`@("!["B`@("`@
M("`@)&YA;65F:6QT97(@/2!N=6QL.PH*("`@("`@("`O+R!"=6EL9"!A(')E
M9V5X<"!B87-E9"!O;B`D9FEL=&5R+@H@("`@("`@(&EF("@D9FEL=&5R("$]
M/2!N=6QL*2!["B`@("`@("`@("`@("1N86UE9FEL=&5R(#T@)R\G.PH@("`@
M("`@("`@("!I9B`H:7-?87)R87DH)&9I;'1E<BDI('L*("`@("`@("`@("`@
M("`@("1O;F-E(#T@9F%L<V4["B`@("`@("`@("`@("`@("!F;W)E86-H("@D
M9FEL=&5R(&%S("1I=&5M*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1O
M;F-E("$]/2!T<G5E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1N86UE
M9FEL=&5R("X]("<H)SL*("`@("`@("`@("`@("`@("`@("`@("`@)&]N8V4@
M/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1N86UE9FEL=&5R("X]("=\*"<["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1N86UE9FEL=&5R
M("X]("1I=&5M("X@)RDG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&YA;65F:6QT97(@+CT@)R@G
M("X@)&9I;'1E<B`N("<I)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M;F%M969I;'1E<B`N/2`G+R<["B`@("`@("`@?0H*("`@("`@("`D;6%T8V@@
M/2!F86QS93L*("`@("`@("!I9B`H)&YA;65F:6QT97(@(3T](&YU;&PI('L*
M("`@("`@("`@("`@)&UA=&-H(#T@<')E9U]M871C:"@D;F%M969I;'1E<BP@
M)&9I;&5N86UE*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;6%T8V@[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&%N9V5S('!E<FUI<W-I;VYS(&9O
M<B!A;B!I=&5M(&]N('1H92!61E,N"B`@("`@*@H@("`@("H@0&%B<W1R86-T
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("`@5&AE
M('!A<F5N="!F;VQD97(@;V8@=&AE(&ET96TN"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1N86UE("`@("`@("!4:&4@;F%M92!O9B!T:&4@:71E;2X*("`@("`J
M($!P87)A;2!S=')I;F<@)'!E<FUI<W-I;VX@(%1H92!P97)M:7-S:6]N('1O
M('-E="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U
M8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!C:&%N9V5097)M:7-S:6]N<R@D<&%T:"P@)&YA
M;64L("1P97)M:7-S:6]N*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(DYO="!S=7!P;W)T960N(BDI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!A('-O<G1E9"!L:7-T(&]F(&9O;&1E<G,@:6X@
M=&AE('-P96-I9FEE9"!D:7)E8W1O<GDN"B`@("`@*@H@("`@("H@0&%B<W1R
M86-T"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("`@
M(%1H92!P871H(&]F('1H92!D:7)E8W1O<GD@=&\@9V5T('1H90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1I<F5C=&]R>2!L:7-T(&9O
M<BX*("`@("`J($!P87)A;2!M:7AE9"`D9FEL=&5R("`@("`@("!(87-H(&]F
M(&ET96US('1O(&9I;'1E<B!B87-E9"!O;B!F;VQD97)L:7-T+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)&1O=&9O;&1E<G,@($EN8VQU9&4@9&]T9F]L9&5R
M<S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!&;VQD97(@;&ES="!O
M;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$9O;&1E<G,H)'!A=&@@/2`G)RP@
M)&9I;'1E<B`](&YU;&PL("1D;W1F;VQD97)S(#T@=')U92D*("`@('L*("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@<W5P<&]R=&5D
M+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&QI<W0@
M;V8@861D:71I;VYA;"!C<F5D96YT:6%L<R!R97%U:7)E9"P@:68@86YY+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@($-R961E;G1I86P@;&ES="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F5Q=6ER961#<F5D96YT:6%L<R@I
M"B`@("!["B`@("`@("`@<F5T=7)N(&%R<F%Y7V1I9F8H)'1H:7,M/E]C<F5D
M96YT:6%L<RP@87)R87E?:V5Y<R@D=&AI<RT^7W!A<F%M<RDI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!A<G)A>2!S<&5C:69Y:6YG('=H
M870@<&5R;6ES<VEO;G,@87)E(&-H86YG96%B;&4@9F]R('1H:7,*("`@("`J
M(%9&4R!I;7!L96UE;G1A=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!#:&%N9V5A8FQE('!E<FUI<VEO;G,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$UO9&EF:6%B;&5097)M:7-S:6]N<R@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?<&5R;6ES<VEO;G,["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#;VYV97)T<R!A('-T<FEN9R!T;R!A;&P@;&]W97)C87-E(&-H87)A
M8W1E<G,@:6=N;W)I;F<@=&AE(&-U<G)E;G0*("`@("`J(&QO8V%L92X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=')I;F<@(%1H92!S=')I;F<@
M=&\@8F4@;&]W97)C87-E9`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@<W1R:6YG('=I=&@@;&]W97)C87-E(&-H87)A8W1E<G,*("`@("`J
M+PH@("`@9G5N8W1I;VX@<W1R=&]L;W=E<B@D<W1R:6YG*0H@("`@>PH@("`@
M("`@("1L86YG=6%G92`]('-E=&QO8V%L92A,0U]#5%E012P@,"D["B`@("`@
M("`@<V5T;&]C86QE*$Q#7T-465!%+"`G96XG*3L*("`@("`@("`D<W1R:6YG
M(#T@<W1R=&]L;W=E<B@D<W1R:6YG*3L*("`@("`@("!S971L;V-A;&4H3$-?
M0U194$4L("1L86YG=6%G92D["B`@("`@("`@<F5T=7)N("1S=')I;F<["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C:&%R86-T97(@*&YO
M="!B>71E*2!L96YG=&@@;V8@82!S=')I;F<N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<W1R:6YG("`@5&AE('-T<FEN9R!T;R!R971U<FX@=&AE
M(&QE;F=T:"!O9BX*("`@("`J($!P87)A;2!S=')I;F<@)&-H87)S970@(%1H
M92!C:&%R<V5T('1O('5S92!W:&5N(&-A;&-U;&%T:6YG('1H90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@<W1R:6YG)W,@;&5N9W1H+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<W1R:6YG)W,@;&5N9W1H
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!S=')L96XH)'-T<FEN9RP@)&-H87)S
M970@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AE>'1E;G-I;VY?;&]A9&5D
M*"=M8G-T<FEN9R<I*2!["B`@("`@("`@("`@(&EF("AI<U]N=6QL*"1C:&%R
M<V5T*2D@>PH@("`@("`@("`@("`@("`@)&-H87)S970@/2`G25-/+3@X-3DM
M,2<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E="`]($!M8E]S=')L
M96XH)'-T<FEN9RP@)&-H87)S970I.PH@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1R970I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E=#L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@<W1R;&5N*"1S=')I
M;F<I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<VEZ92!O
M9B!T:&4@5D93(&ET96TN"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N
M,0H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE('-I>F4L(&EN
M(&)Y=&5S+"!O9B!T:&4@5D93(&ET96TN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=%9&4U-I>F4H*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1T:&ES
M+3Y?=F9S4VEZ92DI('L*("`@("`@("`@("`@)'1H:7,M/E]V9G-3:7IE(#T@
M)'1H:7,M/F=E=$9O;&1E<E-I>F4H)'1H:7,M/E]P87)A;7-;)W9F<U]Q=6]T
M87)O;W0G72D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^7W9F
M<U-I>F4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!61E,@<75O
M=&$@;&EM:70N"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@("`@
M("H*("`@("`J($!P87)A;2!I;G1E9V5R("1Q=6]T82`@(%1H92!L:6UI="!T
M;R!A<'!L>2X*("`@("`J($!P87)A;2!I;G1E9V5R("1M971R:6,@(%1H92!M
M971R:6,@=&\@;75L=&EP;'D@=&AE('%U;W1A(&EN=&\N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-E=%%U;W1A*"1Q=6]T82P@)&UE=')I8R`](%9&4U]154]4
M05]-151224-?0EE412D*("`@('L*("`@("`@("!S=VET8V@@*"1M971R:6,I
M('L*("`@("`@("!C87-E(%9&4U]154]405]-151224-?2T(Z"B`@("`@("`@
M("`@("1Q=6]T82`J/2!P;W<H,BP@,3`I.PH@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@8V%S92!61E-?455/5$%?34544DE#7TU".@H@("`@("`@("`@
M("`D<75O=&$@*CT@<&]W*#(L(#(P*3L*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&-A<V4@5D937U%53U1!7TU%5%))0U]'0CH*("`@("`@("`@("`@
M)'%U;W1A("H]('!O=R@R+"`S,"D["B`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/E]P87)A;7-;)W9F<U]Q=6]T86QI;6ET
M)UT@/2`D<75O=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!6
M1E,@<75O=&$@<F]O="X*("`@("`J"B`@("`@*B!`<VEN8V4@2&]R9&4@,RXQ
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&ER("!4:&4@<F]O="!D
M:7)E8W1O<GD@9F]R('1H92!Q=6]T82!D971E<FUI;F%T:6]N+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!S9711=6]T85)O;W0H)&1I<BD*("`@('L*("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG=F9S7W%U;W1A<F]O="==(#T@)&1I<CL*("`@
M('T*"B`@("`O*BH*("`@("`J($=E="!Q=6]T82!I;F9O<FUA=&EO;B`H=7-E
M9"]A;&QO8V%T960I+"!I;B!B>71E<RX*("`@("`J"B`@("`@*B!`<VEN8V4@
M2&]R9&4@,RXQ"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@06X@87-S
M;V-I871I=F4@87)R87DN"B`@("`@*B`@("`@("`@("`@("`@("`G;&EM:70G
M(#T@36%X:6UU;2!Q=6]T82!A;&QO=V5D"B`@("`@*B`@("`@("`@("`@("`@
M("`G=7-A9V4G(#T@0W5R<F5N=&QY('5S960@<&]R=&EO;B!O9B!Q=6]T82`H
M:6X@8GET97,I"B`@("`@*B`@("`@("`@("`@("`@("!2971U<FYS(%!%05)?
M17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T475O
M=&$H*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG
M=F9S7W%U;W1A;&EM:70G72DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B3F\@<75O=&$@<V5T+B(I*3L*("`@("`@("!]"@H@
M("`@("`@("1U<V%G92`]("1T:&ES+3YG97161E-3:7IE*"D["B`@("`@("`@
M:68@*&ES7V$H)'5S86=E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D=7-A9V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N(&%R<F%Y*"=U<V%G92<@/3X@)'5S86=E+"`G;&EM:70G(#T^("1T
M:&ES+3Y?<&%R86US6R=V9G-?<75O=&%L:6UI="==*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S('1H92!L;V-A=&EO;B!O
M9B!T:&4@<WES=&5M('1E;7!O<F%R>2!D:7)E8W1O<GDN"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@02!D:7)E8W1O<GD@;F%M92!W:&EC:"!C86X@8F4@=7-E9"!F;W(@
M=&5M<"!F:6QE<RX*("`@("`J("`@("`@("`@("`@("`@("!2971U<FYS(&9A
M;'-E(&EF(&]N92!C;W5L9"!N;W0@8F4@9F]U;F0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]G971496UP1&ER*"D*("`@('L*("`@("`@("`D=&UP7VQO8V%T
M:6]N<R`](&%R<F%Y*"<O=&UP)RP@)R]V87(O=&UP)RP@)V,Z7%=55&5M<"<L
M("=C.EQT96UP)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C
M.EQW:6YD;W=S7'1E;7`G+"`G8SI<=VEN;G1<=&5M<"<I.PH*("`@("`@("`O
M*B!4<GD@4$A0)W,@=7!L;V%D7W1M<%]D:7(@9&ER96-T:79E+B`J+PH@("`@
M("`@("1T;7`@/2!I;FE?9V5T*"=U<&QO861?=&UP7V1I<B<I.PH*("`@("`@
M("`O*B!/=&AE<G=I<V4L('1R>2!T;R!D971E<FUI;F4@=&AE(%1-4$1)4B!E
M;G9I<F]N;65N="!V87)I86)L92X@*B\*("`@("`@("!I9B`H96UP='DH)'1M
M<"DI('L*("`@("`@("`@("`@)'1M<"`](&=E=&5N=B@G5$U01$E2)RD["B`@
M("`@("`@?0H*("`@("`@("`O*B!)9B!W92!S=&EL;"!C86YN;W0@9&5T97)M
M:6YE(&$@=F%L=64L('1H96X@8WEC;&4@=&AR;W5G:"!A(&QI<W0@;V8*("`@
M("`@("`@*B!P<F5S970@<&]S<VEB:6QI=&EE<RX@*B\*("`@("`@("!W:&EL
M92`H96UP='DH)'1M<"D@)B8@<VEZ96]F*"1T;7!?;&]C871I;VYS*2D@>PH@
M("`@("`@("`@("`D=&UP7V-H96-K(#T@87)R87E?<VAI9G0H)'1M<%]L;V-A
M=&EO;G,I.PH@("`@("`@("`@("!I9B`H0&ES7V1I<B@D=&UP7V-H96-K*2D@
M>PH@("`@("`@("`@("`@("`@)'1M<"`]("1T;7!?8VAE8VL["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("\J($EF(&ET(&ES('-T:6QL(&5M
M<'1Y+"!W92!H879E(&9A:6QE9"P@<V\@<F5T=7)N(&9A;'-E.R!O=&AE<G=I
M<V4*("`@("`@("`@*B!R971U<FX@=&AE(&1I<F5C=&]R>2!D971E<FUI;F5D
M+B`J+PH@("`@("`@(')E='5R;B!E;7!T>2@D=&UP*2`_(&9A;'-E(#H@)'1M
M<#L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!T96UP;W)A<GD@
M9FEL92X*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("`@4F5T=7)N<R!T:&4@9G5L;"!P871H
M+6YA;64@=&\@=&AE('1E;7!O<F%R>2!F:6QE(&]R"B`@("`@*B`@("`@("`@
M("`@("`@("`@(&9A;'-E(&EF(&$@=&5M<&]R87)Y(&9I;&4@8V]U;&0@;F]T
M(&)E(&-R96%T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971496UP1FEL
M92@I"B`@("!["B`@("`@("`@)'1M<%]D:7(@/2`D=&AI<RT^7V=E=%1E;7!$
M:7(H*3L*("`@("`@("!I9B`H96UP='DH)'1M<%]D:7(I*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1T;7!?9FEL
M92`]('1E;7!N86TH)'1M<%]D:7(L("=V9G,G*3L*"B`@("`@("`@+RH@268@
M=&AE(&9I;&4@=V%S(&-R96%T960L('1H96X@<F5G:7-T97(@:70@9F]R(&1E
M;&5T:6]N(&%N9`H@("`@("`@("`J(')E='5R;BX@*B\*("`@("`@("!I9B`H
M96UP='DH)'1M<%]F:6QE*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T;7!?9FEL
M93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@=&AE
M('%U;W1A('=H96X@<')E<&%R:6YG('1O('=R:71E(&1A=&$N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;6]D92`@($5I=&AE<B`G<W1R:6YG)R!O<B`G9FEL92<N("!)9B`G
M<W1R:6YG)RP@)&1A=&$@:7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!T:&4@9&%T82!T;R!B92!W<FET=&5N+B`@268@)V9I;&4G+"`D9&%T82!I
M<R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!F:6QE;F%M92!C
M;VYT86EN:6YG('1H92!D871A('1O(&)E('=R:71T96XN"B`@("`@*B!`<&%R
M86T@<W1R:6YG("8D9&%T82`@16ET:&5R('1H92!D871A(&]R('1H92!F:6QE
M;F%M92!T;R!T:&4@9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!014%27T5R<F]R(&]N(&5R<F]R+"!T<G5E(&]N('-U8V-E<W,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]C:&5C:U%U;W1A5W)I=&4H)&UO9&4L("8D9&%T
M82D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]P87)A;7-;)W9F<U]Q=6]T
M86QI;6ET)UT@(3T@+3$I('L*("`@("`@("`@("`@:68@*"1M;V1E(#T]("=F
M:6QE)RD@>PH@("`@("`@("`@("`@("`@)&9I;&5S:7IE(#T@0&9I;&5S:7IE
M*"1D871A*3L*("`@("`@("`@("`@("`@(&EF("@D9FEL97-I>F4@/3T](&9A
M;'-E*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H7R@B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@
M9F%I;&5D*2XB*2D["B`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1F:6QE<VEZ92`]('-T<FQE;B@D9&%T
M82D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'9F<W-I>F4@/2`D=&AI
M<RT^9V5T5D934VEZ92@I.PH@("`@("`@("`@("!I9B`H:7-?82@D=F9S<VEZ
M92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1V
M9G-S:7IE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@H)'9F<W-I
M>F4@*R`D9FEL97-I>F4I(#X@)'1H:7,M/E]P87)A;7-;)W9F<U]Q=6]T86QI
M;6ET)UTI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B
M92!E>&-E961E9"XB*2D["B`@("`@("`@("`@('T@96QS96EF("@D=&AI<RT^
M7W9F<U-I>F4@(3T](#`I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?=F9S
M4VEZ92`K/2`D9FEL97-I>F4["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE
M8VMS('1H92!Q=6]T82!W:&5N('!R97!A<FEN9R!T;R!D96QE=&4@9&%T82X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!T:&4@9FEL92!I<R!L;V-A
M=&5D(&EN+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9I;&5N
M86UE+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%!%05)?17)R;W(@
M;VX@97)R;W(L('1R=64@;VX@<W5C8V5S<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V-H96-K475O=&%$96QE=&4H)'!A=&@L("1N86UE*0H@("`@>PH@("`@
M("`@(&EF("@H)'1H:7,M/E]P87)A;7-;)W9F<U]Q=6]T86QI;6ET)UT@(3T@
M+3$I("8F"B`@("`@("`@("`@("%E;7!T>2@D=&AI<RT^7W9F<U-I>F4I*2![
M"B`@("`@("`@("`@("1F:6QE<VEZ92`]("1T:&ES+3YS:7IE*"1P871H+"`D
M;F%M92D["B`@("`@("`@("`@(&EF("AI<U]A*"1F:6QE<VEZ92P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H7R@B56YA8FQE('1O(')E860@5D93(&9I;&4@*'-I>F4H*2!F86EL
M960I+B(I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7W9F
M<U-I>F4@+3T@)&9I;&5S:7IE.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U
M<FX@82!C;VYC<F5T92!61E,@:6YS=&%N8V4@8F%S960@;VX@)&1R:79E<BX*
M("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1R:79E<B`@5&AE('1Y<&4@
M;V8@8V]N8W)E=&4@5D93('-U8F-L87-S('1O(')E='5R;BX@5&AI<PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@(&ES(&)A<V5D(&]N('1H92!S=&]R
M86=E(&1R:79E<B`H)&1R:79E<BDN(%1H90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(&-O9&4@:7,@9'EN86UI8V%L;'D@:6YC;'5D960N"B`@("`@
M*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY
M(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S
M(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!61E,@(%1H92!N
M97=L>2!C<F5A=&5D(&-O;F-R971E(%9&4R!I;G-T86YC92P@;W(@82!014%2
M7T5R<F]R"B`@("`@*B`@("`@("`@("`@("`@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@:6YC;'5D95]O;F-E("=61E,O)R`N("1D
M<FEV97(@+B`G+G!H<"<["B`@("`@("`@)&-L87-S(#T@)U9&4U\G("X@)&1R
M:79E<CL*("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@
M("`@("`@("`@)'9F<R`]("9N97<@)&-L87-S*"1P87)A;7,I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1V9G,@/2!014%2.CIR86ES945R<F]R
M*'-P<FEN=&8H7R@B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N
M(BDL("1C;&%S<RDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1V9G,[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R
M969E<F5N8V4@=&\@82!C;VYC<F5T92!61E,@:6YS=&%N8V4@8F%S960@;VX*
M("`@("`J("1D<FEV97(N($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS
M=&%N8V4@:68@;F\@5D93(&EN<W1A;F-E('=I=&@@=&AE"B`@("`@*B!S86UE
M('!A<F%M971E<G,@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4
M:&ES('-H;W5L9"!B92!U<V5D(&EF(&UU;'1I<&QE('1Y<&5S(&]F(&9I;&4@
M8F%C:V5N9',@*&%N9"P@=&AU<RP*("`@("`J(&UU;'1I<&QE(%9&4R!I;G-T
M86YC97,I(&%R92!R97%U:7)E9"X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO
M9"!M=7-T(&)E(&EN=F]K960@87,Z("1V87(@/2`F5D93.CIS:6YG;&5T;VXH
M*0H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP
M92!O9B!C;VYC<F5T92!61E,@<W5B8VQA<W,@=&\@<F5T=7)N+B!4:&ES"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@:7,@8F%S960@;VX@=&AE('-T
M;W)A9V4@9')I=F5R("@D9')I=F5R*2X@5&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@8V]D92!I<R!D>6YA;6EC86QL>2!I;F-L=61E9"X*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!A
M;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S(&$@<W5B8VQA
M<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(%9&4R`@5&AE
M(&-O;F-R971E(%9&4R!R969E<F5N8V4L(&]R(&$@4$5!4E]%<G)O<B!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV
M97(L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@('-T871I8R`D
M:6YS=&%N8V5S.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<RDI('L*
M("`@("`@("`@("`@)&EN<W1A;F-E<R`](&%R<F%Y*"D["B`@("`@("`@?0H*
M("`@("`@("`D<VEG;F%T=7)E(#T@<V5R:6%L:7IE*&%R<F%Y*"1D<FEV97(L
M("1P87)A;7,I*3L*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97-;)'-I
M9VYA='5R95TI*2!["B`@("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R
M95T@/2`F5D93.CIF86-T;W)Y*"1D<FEV97(L("1P87)A;7,I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+UA-3"\`````````````````````````````````````
M```````````````````````````````````````````````````P,#`P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<T-0`P,3<P
M-C4`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O6$U,+U-61RYP:'``````
M````````````````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#4S,C$V
M`#$P-3$U-#,S-S0U`#`R,#(T-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@6$U,7U-61PH@*@H@*B!7
M<F%P<&5R(&-L87-S('1H870@<')O=FED97,@<V]M92!E>&%M<&QE<R!A;F0@
M82!F97<@8V]N=F5N:65N8V4*("H@;65T:&]D<RX*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO6$U,7U-61R]35D<N<&AP+'8@,2XQ-RXQ,"XT(#(P,#8O,#$O
M,#$@,C$Z,C@Z-#0@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P
M,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`<&%C:V%G92!834Q?4U9'"B`J+PIC;&%S<R!834Q?4U9'
M('L*"B`@("!F=6YC=&EO;B!E>&%M<&QE*"D*("`@('L*("`@("`@("`O+R!#
M<F5A=&4@86X@:6YS=&%N8V4@;V8@6$U,7U-61U]$;V-U;65N="X@06QL(&]T
M:&5R(&]B:F5C=',*("`@("`@("`O+R!W:6QL(&)E(&%D9&5D('1O('1H:7,@
M:6YS=&%N8V4@9F]R('!R:6YT:6YG+B!3970@=&AE(&AE:6=H=`H@("`@("`@
M("\O(&%N9"!W:61T:"!O9B!T:&4@=FEE=W!O<G0N"B`@("`@("`@)'-V9R`]
M("9N97<@6$U,7U-61U]$;V-U;65N="AA<G)A>2@G=VED=&@G(#T^(#0P,"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=H
M96EG:'0G(#T^(#(P,"DI.PH*("`@("`@("`O+R!#<F5A=&4@86X@:6YS=&%N
M8V4@;V8@6$U,7U-61U]'<F]U<"X@4V5T('1H92!S='EL92P*("`@("`@("`O
M+R!T<F%N<V9O<FUS(&9O<B!C:&EL9"!O8FIE8W1S+@H@("`@("`@("1G(#T@
M)FYE=R!834Q?4U9'7T=R;W5P*&%R<F%Y*"=S='EL92<@/3X@)W-T<F]K93IB
M;&%C:R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W1R86YS9F]R;2<@/3X@)W1R86YS;&%T92@R,#`@,3`P*2<I*3L*"B`@("`@
M("`@+R\@061D(&$@<&%R96YT('1O('1H92!G(&EN<W1A;F-E+@H@("`@("`@
M("1G+3YA9&1087)E;G0H)'-V9RD["@H@("`@("`@("\O(%1H92!S86UE(')E
M<W5L=',@8V%N(&)E(&%C8V]M<&QI<VAE9"!B>2!M86MI;F<@9R!A(&-H:6QD
M(&]F('1H92!S=F<N"B`@("`@("`@+R\@)'-V9RT^861D0VAI;&0H)&<I.PH*
M("`@("`@("`O+R!#<F5A=&4@86YD(&%N:6UA=&4@82!C:7)C;&4N"B`@("`@
M("`@)&-I<F-L92`]("9N97<@6$U,7U-61U]#:7)C;&4H87)R87DH)V-X)R`]
M/B`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V-Y)R`]/B`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W(G(#T^(#$P,"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=S='EL92<@/3X@)W-T<F]K92UW:61T
M:#HS)RDI.PH@("`@("`@("1C:7)C;&4M/F%D9$-H:6QD*&YE=R!834Q?4U9'
M7T%N:6UA=&4H87)R87DH)V%T=')I8G5T94YA;64G(#T^("=R)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=A='1R:6)U=&54>7!E)R`]/B`G6$U,)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F<F]M)R`]/B`P
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W1O)R`]/B`W-2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D=7(G(#T^("<S<R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G9FEL;"<@/3X@)V9R965Z92<I*2D["B`@("`@("`@)&-I<F-L92T^
M861D0VAI;&0H;F5W(%A-3%]35D=?06YI;6%T92AA<G)A>2@G871T<FEB=71E
M3F%M92<@/3X@)V9I;&PG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V%T=')I8G5T951Y<&4G(#T^("=#
M4U,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V9R;VTG(#T^("=G<F5E;B<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&\G(#T^
M("=R960G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V1U<B<@/3X@)S-S)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F:6QL)R`]
M/B`G9G)E97IE)RDI*3L*"B`@("`@("`@+R\@36%K92!T:&4@8VER8VQE(&$@
M8VAI;&0@;V8@9RX*("`@("`@("`D9RT^861D0VAI;&0H)&-I<F-L92D["@H@
M("`@("`@("\O($-R96%T92!A;F0@86YI;6%T92!S;VUE('1E>'0N"B`@("`@
M("`@)'1E>'0@/2`F;F5W(%A-3%]35D=?5&5X="AA<G)A>2@G=&5X="<@/3X@
M)U-61R!C:&%R="$G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G>"<@/3X@,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)WDG(#T^(#`L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=S='EL92<@/3X@)V9O;G0M<VEZ93HR,#MT97AT
M+6%N8VAO<CIM:61D;&4[)RDI.PH@("`@("`@("1T97AT+3YA9&1#:&EL9"AN
M97<@6$U,7U-61U]!;FEM871E*&%R<F%Y*"=A='1R:6)U=&5.86UE)R`]/B`G
M9F]N="US:7IE)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G871T<FEB=71E5'EP92<@/3X@)V%U=&\G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=F<F]M)R`]/B`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=T;R<@/3X@,C`L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1U<B<@
M/3X@)S-S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G9FEL;"<@/3X@)V9R965Z92<I*2D["@H@("`@("`@
M("\O($UA:V4@=&AE('1E>'0@82!C:&EL9"!O9B!G+@H@("`@("`@("1G+3YA
M9&1#:&EL9"@D=&5X="D["@H@("`@("`@("\O(%-E;F0@82!M97-S86=E('1O
M('1H92!S=F<@:6YS=&%N8V4@=&\@<W1A<G0@<')I;G1I;F<N"B`@("`@("`@
M)'-V9RT^<')I;G1%;&5M96YT*"D["B`@("!]"@I]"@HO*BH*("H@6$U,7U-6
M1U]%;&5M96YT"B`J"B`J(%1H:7,@:7,@=&AE(&)A<V4@8VQA<W,@9F]R('1H
M92!D:69F97)E;G0@4U9'($5L96UE;G0*("H@3V)J96-T<RX@17AT96YD('1H
M:7,@8VQA<W,@=&\@8W)E871E(&$@;F5W(%-61R!%;&5M96YT+@H@*@H@*B!`
M<&%C:V%G92!834Q?4U9'"B`J+PIC;&%S<R!834Q?4U9'7T5L96UE;G0@>PH*
M("`@('9A<B`D7V5L96UE;G1S(#T@;G5L;#L*("`@('9A<B`D7W-T>6QE(#T@
M;G5L;#L*("`@('9A<B`D7W1R86YS9F]R;2`](&YU;&P["B`@("!V87(@)%]I
M9"`](&YU;&P["@H@("`@9G5N8W1I;VX@6$U,7U-61U]%;&5M96YT*"1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@
M87,@)'`@/3X@)'8I('L*("`@("`@("`@("`@)'!A<F%M(#T@)U\G("X@)'`[
M"B`@("`@("`@("`@("1T:&ES+3XD<&%R86T@/2`D=CL*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!-;W-T(%-61R!E;&5M96YT<R!C86X@8V]N
M=&%I;B!C:&EL9"!E;&5M96YT<RX@5&AI<R!M971H;V0@8V%L;',*("`@("`J
M('1H92!P<FEN=$5L96UE;G0@;65T:&]D(&]F(&%N>2!C:&EL9"!E;&5M96YT
M(&%D9&5D('1O('1H:7,*("`@("`J(&]B:F5C="!B>2!U<V4@;V8@=&AE(&%D
M9$-H:6QD(&UE=&AO9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<')I;G1%;&5M
M96YT*"D*("`@('L*("`@("`@("`O+R!,;V]P(&%N9"!C86QL+@H@("`@("`@
M(&EF("AI<U]A<G)A>2@D=&AI<RT^7V5L96UE;G1S*2D@>PH@("`@("`@("`@
M("!F;W)E86-H("@D=&AI<RT^7V5L96UE;G1S(&%S("1C:&EL9"D@>PH@("`@
M("`@("`@("`@("`@)&-H:6QD+3YP<FEN=$5L96UE;G0H*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@;65T
M:&]D(&%D9',@86X@;V)J96-T(')E9F5R96YC92`H;W(@=F%L=64L(&EF("1C
M;W!Y(&ES"B`@("`@*B!T<G5E*2!T;R!T:&4@7V5L96UE;G1S(&%R<F%Y+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!A9&1#:&EL9"@F)&5L96UE;G0L("1C;W!Y
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"1C;W!Y*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?96QE;65N='-;72`]("8D96QE;65N="T^8V]P>2@I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?96QE;65N='-;
M72`]("8D96QE;65N=#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!4:&ES(&UE=&AO9"!S96YD<R!A(&UE<W-A9V4@=&\@=&AE('!A<W-E9"!E
M;&5M96YT(')E<75E<W1I;F<@=&\*("`@("`J(&)E(&%D9&5D(&%S(&$@8VAI
M;&0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9%!A<F5N="@F)'!A<F5N="D*
M("`@('L*("`@("`@("!I9B`H:7-?<W5B8VQA<W-?;V8H)'!A<F5N="P@)UA-
M3%]35D=?16QE;65N="<I*2!["B`@("`@("`@("`@("1P87)E;G0M/F%D9$-H
M:6QD*"1T:&ES*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@8V]P
M>2@I"B`@("!["B`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92AZ96YD7W9E
M<G-I;VXH*2P@)S(G+"`G/B<I*2!["B`@("`@("`@("`@(')E='5R;B!C;&]N
M92@D=&AI<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'AM;%]S
M=F<@/2`D=&AI<SL*("`@("`@("`@("`@<F5T=7)N("1X;6Q?<W9G.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%!R:6YT(&5A8V@@;V8@=&AE
M('!A<W-E9"!P87)A;65T97)S+"!I9B!T:&5Y(&%R92!S970N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('!R:6YT4&%R86US*"D*("`@('L*("`@("`@("!F;W)E
M86-H("AF=6YC7V=E=%]A<F=S*"D@87,@)'!A<F%M*2!["B`@("`@("`@("`@
M("1?<&%R86T@/2`G7R<@+B`D<&%R86T["B`@("`@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^)%]P87)A;2DI('L*("`@("`@("`@("`@("`@('-W:71C:"`H
M)'!A<F%M*2!["B`@("`@("`@("`@("`@("!C87-E("=F:6QT97(G.@H@("`@
M("`@("`@("`@("`@("`@(&5C:&\@)R!F:6QT97(](G5R;"@C)R`N("1T:&ES
M+3XD7W!A<F%M("X@)RDB)SL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@("`@
M(&5C:&\@)R`G("X@<W1R7W)E<&QA8V4H)U\G+"`G+2<L("1P87)A;2D@+B`G
M/2(G("X@)'1H:7,M/B1?<&%R86T@+B`G(B<["B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"@H@("`@+R\@4V5T(&%N>2!N86UE9"!A='1R:6)U=&4@
M;V8@86X@96QE;65N="!T;R!A('9A;'5E+@H@("`@9G5N8W1I;VX@<V5T4&%R
M86TH)'!A<F%M+"`D=F%L=64I"B`@("!["B`@("`@("`@)&%T='(@/2`G7R<@
M+B`D<&%R86T["B`@("`@("`@)'1H:7,M/B1A='1R(#T@)'9A;'5E.PH@("`@
M?0H*("`@("\O($=E="!A;GD@;F%M960@871T<FEB=71E(&]F(&%N(&5L96UE
M;G0N"B`@("!F=6YC=&EO;B!G971087)A;2@D<&%R86TI"B`@("!["B`@("`@
M("`@)&%T='(@/2`G7R<@+B`D<&%R86T["B`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3XD871T<BDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3XD871T
M<CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*
M("`@("`@("!]"B`@("!]"@H@("`@+R\@4')I;G0@;W5T('1H92!O8FIE8W0@
M9F]R(&1E8G5G9VEN9RX*("`@(&9U;F-T:6]N(&1E8G5G*"D*("`@('L*("`@
M("`@("!E8VAO("<\<')E/B<[('9A<E]D=6UP*"1T:&ES*3L@96-H;R`G/"]P
M<F4^)SL*("`@('T*"GT*"B\J*@H@*B!834Q?4U9'7T9R86=M96YT"B`J"B`J
M($!P86-K86=E(%A-3%]35D<*("HO"F-L87-S(%A-3%]35D=?1G)A9VUE;G0@
M97AT96YD<R!834Q?4U9'7T5L96UE;G0@>PH*("`@('9A<B`D7W=I9'1H.PH@
M("`@=F%R("1?:&5I9VAT.PH@("`@=F%R("1?=FEE=T)O>#L*("`@('9A<B`D
M7W@["B`@("!V87(@)%]Y.PH*("`@(&9U;F-T:6]N('!R:6YT16QE;65N="@I
M"B`@("!["B`@("`@("`@96-H;R`G/'-V9R<["B`@("`@("`@)'1H:7,M/G!R
M:6YT4&%R86US*"=I9"<L("=W:61T:"<L("=H96EG:'0G+"`G>"<L("=Y)RP@
M)W9I97=";W@G+"`G<W1Y;&4G*3L*("`@("`@("!E8VAO("<@>&UL;G,](FAT
M='`Z+R]W=W<N=S,N;W)G+S(P,#`O<W9G(B!X;6QN<SIX;&EN:STB:'1T<#HO
M+W=W=RYW,RYO<F<O,3DY.2]X;&EN:R(^)R`N(")<;B(["B`@("`@("`@<&%R
M96YT.CIP<FEN=$5L96UE;G0H*3L*("`@("`@("!E8VAO("(\+W-V9SY<;B([
M"B`@("!]"@H@("`@9G5N8W1I;VX@8G5F9F5R3V)J96-T*"D*("`@('L*("`@
M("`@("!O8E]S=&%R="@I.PH@("`@("`@("1T:&ES+3YP<FEN=$5L96UE;G0H
M*3L*("`@("`@("`D;W5T<'5T(#T@;V)?9V5T7V-O;G1E;G1S*"D["B`@("`@
M("`@;V)?96YD7V-L96%N*"D["@H@("`@("`@(')E='5R;B`D;W5T<'5T.PH@
M("`@?0I]"@HO*BH*("H@6$U,7U-61U]$;V-U;65N=`H@*@H@*B!4:&ES(&5X
M=&5N9',@=&AE(%A-3%]35D=?1G)A9VUE;G0@8VQA<W,N($ET('=R87!S('1H
M92!834Q?4U9'7T9R86UE;G0@;W5T<'5T"B`J('=I=&@@82!C;VYT96YT(&AE
M861E<BP@>&UL(&1E9FEN:71I;VX@86YD(&1O8W1Y<&4N"B`J"B`J($!P86-K
M86=E(%A-3%]35D<*("HO"F-L87-S(%A-3%]35D=?1&]C=6UE;G0@97AT96YD
M<R!834Q?4U9'7T9R86=M96YT('L*"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE
M;G0H*0H@("`@>PH@("`@("`@(&AE861E<B@G0V]N=&5N="U4>7!E.B!I;6%G
M92]S=F<K>&UL)RD["@H@("`@("`@('!R:6YT*"<\/WAM;"!V97)S:6]N/2(Q
M+C`B(&5N8V]D:6YG/2)I<V\M.#@U.2TQ(C\^)RXB7&XB*3L*("`@("`@("!P
M<FEN="@G/"%$3T-465!%('-V9R!054),24,@(BTO+U<S0R\O1%1$(%-61R`Q
M+C`O+T5.(@H)("`@("`@("`B:'1T<#HO+W=W=RYW,RYO<F<O5%(O,C`P,2]2
M14,M4U9'+3(P,#$P.3`T+T141"]S=F<Q,"YD=&0B/B<@+B`B7&XB*3L*"B`@
M("`@("`@<&%R96YT.CIP<FEN=$5L96UE;G0H*3L*("`@('T*"GT*"B\J*@H@
M*B!834Q?4U9'7T=R;W5P"B`J"B`J($!P86-K86=E(%A-3%]35D<*("HO"F-L
M87-S(%A-3%]35D=?1W)O=7`@97AT96YD<R!834Q?4U9'7T5L96UE;G0@>PH*
M("`@(&9U;F-T:6]N('!R:6YT16QE;65N="@I"B`@("!["B`@("`@("`@96-H
M;R`G/&<G.PH@("`@("`@("1T:&ES+3YP<FEN=%!A<F%M<R@G:60G+"`G<W1Y
M;&4G+"`G=')A;G-F;W)M)RP@)V9I;'1E<B<I.PH@("`@("`@('!R:6YT*"(^
M7&XB*3L*("`@("`@("!P87)E;G0Z.G!R:6YT16QE;65N="@I.PH@("`@("`@
M('!R:6YT*"(\+V<^7&XB*3L*("`@('T*"GT*"B\J*@H@*B!834Q?4U9'7U1E
M>'1P871H"B`J"B`J($!P86-K86=E(%A-3%]35D<*("HO"F-L87-S(%A-3%]3
M5D=?5&5X='!A=&@@97AT96YD<R!834Q?4U9'7T5L96UE;G0@>PH*("`@('9A
M<B`D7W1E>'0["B`@("!V87(@)%]X.PH@("`@=F%R("1?>3L*("`@('9A<B`D
M7V1X.PH@("`@=F%R("1?9'D["B`@("!V87(@)%]R;W1A=&4["B`@("!V87(@
M)%]T97AT3&5N9W1H.PH@("`@=F%R("1?;&5N9W1H061J=7-T.PH@("`@=F%R
M("1?8VAA<G-E=#L*"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE;G0H)&5L96UE
M;G0@/2`G=&5X='!A=&@G*0H@("`@>PH@("`@("`@(&5C:&\@)SPG("X@)&5L
M96UE;G0["B`@("`@("`@)'1H:7,M/G!R:6YT4&%R86US*"=I9"<L("=X)RP@
M)WDG+"`G9'@G+"`G9'DG+"`G<F]T871E)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W1E>'1,96YG=&@G+"`G;&5N9W1H061J=7-T)RP@)W-T>6QE
M)RP@)W1R86YS9F]R;2<I.PH@("`@("`@(&5C:&\@)SXG.PH@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7V-H87)S970I*2!["B`@("`@("`@("`@(&5C:&\@
M0&AT;6QS<&5C:6%L8VAA<G,H)'1H:7,M/E]T97AT+"!%3E1?0T]-4$%4+"`D
M=&AI<RT^7V-H87)S970I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D=&AI<RT^7W1E>'0I.PH@("`@("`@
M('T*("`@("`@("!P87)E;G0Z.G!R:6YT16QE;65N="@I.PH@("`@("`@(&5C
M:&\@(CPO)&5L96UE;G0^7&XB.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=%-H
M87!E*"1X+"`D>2P@)'1E>'0I"B`@("!["B`@("`@("`@)'1H:7,M/E]X(#T@
M)'@["B`@("`@("`@)'1H:7,M/E]Y(#T@)'D["B`@("`@("`@)'1H:7,M/E]T
M97AT(#T@)'1E>'0["B`@("!]"@I]"@HO*BH*("H@6$U,7U-61U]497AT"B`J
M"B`J($!P86-K86=E(%A-3%]35D<*("HO"F-L87-S(%A-3%]35D=?5&5X="!E
M>'1E;F1S(%A-3%]35D=?5&5X='!A=&@@>PH*("`@(&9U;F-T:6]N('!R:6YT
M16QE;65N="@I"B`@("!["B`@("`@("`@<&%R96YT.CIP<FEN=$5L96UE;G0H
M)W1E>'0G*3L*("`@('T*"B`@("!F=6YC=&EO;B!S9713:&%P92@D>"P@)'DL
M("1T97AT*0H@("`@>PH@("`@("`@("1T:&ES+3Y?>"`]("1X.PH@("`@("`@
M("1T:&ES+3Y?>2`]("1Y.PH@("`@("`@("1T:&ES+3Y?=&5X="`]("1T97AT
M.PH@("`@?0H*?0H*+RHJ"B`J(%A-3%]35D=?5'-P86X*("H*("H@0'!A8VMA
M9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]4<W!A;B!E>'1E;F1S(%A-
M3%]35D=?16QE;65N="!["@H@("`@=F%R("1?=&5X=#L*("`@('9A<B`D7W@[
M"B`@("!V87(@)%]Y.PH@("`@=F%R("1?9'@["B`@("!V87(@)%]D>3L*("`@
M('9A<B`D7W)O=&%T93L*("`@('9A<B`D7W1E>'1,96YG=&@["B`@("!V87(@
M)%]L96YG=&A!9&IU<W0["@H@("`@9G5N8W1I;VX@<')I;G1%;&5M96YT*"D*
M("`@('L*("`@("`@("!E8VAO("<\='-P86XG.PH@("`@("`@("1T:&ES+3YP
M<FEN=%!A<F%M<R@G:60G+"`G>"<L("=Y)RP@)V1X)RP@)V1Y)RP@)W)O=&%T
M92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("=T97AT3&5N9W1H)RP@
M)VQE;F=T:$%D:G5S="<L("=S='EL92<L("=T<F%N<V9O<FTG*3L*("`@("`@
M("!E8VAO("<^)R`N("1T:&ES+3Y?=&5X=#L*("`@("`@("!I9B`H:7-?87)R
M87DH)'1H:7,M/E]E;&5M96YT<RDI('L*("`@("`@("`@("`@<&%R96YT.CIP
M<FEN=$5L96UE;G0H*3L*("`@("`@("!]"B`@("`@("`@96-H;R`B/"]T<W!A
M;CY<;B(["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T4VAA<&4H)'@L("1Y+"`D
M=&5X="D*("`@('L*("`@("`@("`D=&AI<RT^7W@@/2`D>#L*("`@("`@("`D
M=&AI<RT^7WD@/2`D>3L*("`@("`@("`D=&AI<RT^7W1E>'0@(#T@)'1E>'0[
M"B`@("!]"@I]"@HO*BH*("H@6$U,7U-61U]#:7)C;&4*("H*("H@0'!A8VMA
M9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]#:7)C;&4@97AT96YD<R!8
M34Q?4U9'7T5L96UE;G0@>PH*("`@('9A<B`D7V-X.PH@("`@=F%R("1?8WD[
M"B`@("!V87(@)%]R.PH*("`@(&9U;F-T:6]N('!R:6YT16QE;65N="@I"B`@
M("!["B`@("`@("`@96-H;R`G/&-I<F-L92<["@H@("`@("`@("1T:&ES+3YP
M<FEN=%!A<F%M<R@G:60G+"`G8W@G+"`G8WDG+"`G<B<L("=S='EL92<L("=T
M<F%N<V9O<FTG*3L*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/E]E;&5M
M96YT<RDI('L*("`@("`@("`@("`@+R\@4')I;G0@8VAI;&1R96XL('-T87)T
M(&%N9"!E;F0@=&%G+@H@("`@("`@("`@("!E8VAO("(^7&XB.PH@("`@("`@
M("`@("!P87)E;G0Z.G!R:6YT16QE;65N="@I.PH@("`@("`@("`@("!E8VAO
M("(\+V-I<F-L93Y<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M+R\@4')I;G0@<VAO<G0@=&%G+@H@("`@("`@("`@("!E8VAO("(O/EQN(CL*
M("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@<V5T4VAA<&4H)&-X+"`D
M8WDL("1R*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8W@@/2`D8W@["B`@("`@
M("`@)'1H:7,M/E]C>2`]("1C>3L*("`@("`@("`D=&AI<RT^7W(@(#T@)'([
M"B`@("!]"@I]"@HO*BH*("H@6$U,7U-61U],:6YE"B`J"B`J($!P86-K86=E
M(%A-3%]35D<*("HO"F-L87-S(%A-3%]35D=?3&EN92!E>'1E;F1S(%A-3%]3
M5D=?16QE;65N="!["@H@("`@=F%R("1?>#$["B`@("!V87(@)%]Y,3L*("`@
M('9A<B`D7W@R.PH@("`@=F%R("1?>3(["@H@("`@9G5N8W1I;VX@<')I;G1%
M;&5M96YT*"D*("`@('L*("`@("`@("!E8VAO("<\;&EN92<["B`@("`@("`@
M)'1H:7,M/G!R:6YT4&%R86US*"=I9"<L("=X,2<L("=Y,2<L("=X,B<L("=Y
M,B<L("=S='EL92<I.PH@("`@("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^7V5L
M96UE;G1S*2D@>PH@("`@("`@("`@("`O+R!0<FEN="!C:&EL9')E;BP@<W1A
M<G0@86YD(&5N9"!T86<N"B`@("`@("`@("`@('!R:6YT*"(^7&XB*3L*("`@
M("`@("`@("`@<&%R96YT.CIP<FEN=$5L96UE;G0H*3L*("`@("`@("`@("`@
M<')I;G0H(CPO;&EN93Y<;B(I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("\O(%!R:6YT('-H;W)T('1A9RX*("`@("`@("`@("`@<')I;G0H(B\^
M7&XB*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@<V5T4VAA<&4H
M)'@Q+"`D>3$L("1X,BP@)'DR*0H@("`@>PH@("`@("`@("1T:&ES+3Y?>#$@
M/2`D>#$["B`@("`@("`@)'1H:7,M/E]Y,2`]("1Y,3L*("`@("`@("`D=&AI
M<RT^7W@R("`]("1X,CL*("`@("`@("`D=&AI<RT^7WDR("`]("1Y,CL*("`@
M('T*"GT*"B\J*@H@*B!834Q?4U9'7U)E8W0*("H*("H@0'!A8VMA9V4@6$U,
M7U-61PH@*B\*8VQA<W,@6$U,7U-61U]296-T(&5X=&5N9',@6$U,7U-61U]%
M;&5M96YT('L*"B`@("!V87(@)%]X.PH@("`@=F%R("1?>3L*("`@('9A<B`D
M7W=I9'1H.PH@("`@=F%R("1?:&5I9VAT.PH@("`@=F%R("1?<G@["B`@("!V
M87(@)%]R>3L*"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE;G0H*0H@("`@>PH@
M("`@("`@(&5C:&\@)SQR96-T)SL*("`@("`@("`D=&AI<RT^<')I;G1087)A
M;7,H)VED)RP@)W@G+"`G>2<L("=W:61T:"<L("=H96EG:'0G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<G@G+"`G<GDG+"`G<W1Y;&4G*3L*("`@
M("`@("!I9B`H:7-?87)R87DH)'1H:7,M/E]E;&5M96YT<RDI('L*("`@("`@
M("`@("`@+R\@4')I;G0@8VAI;&1R96XL('-T87)T(&%N9"!E;F0@=&%G+@H@
M("`@("`@("`@("!P<FEN="@B/EQN(BD["B`@("`@("`@("`@('!A<F5N=#HZ
M<')I;G1%;&5M96YT*"D["B`@("`@("`@("`@('!R:6YT*"(\+W)E8W0^7&XB
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!0<FEN="!S:&]R
M="!T86<N"B`@("`@("`@("`@('!R:6YT*"(O/EQN(BD["B`@("`@("`@?0H@
M("`@?0H*("`@(&9U;F-T:6]N('-E=%-H87!E*"1X+"`D>2P@)'=I9'1H+"`D
M:&5I9VAT*0H@("`@>PH@("`@("`@("1T:&ES+3Y?>"`]("1X.PH@("`@("`@
M("1T:&ES+3Y?>2`]("1Y.PH@("`@("`@("1T:&ES+3Y?=VED=&@@(#T@)'=I
M9'1H.PH@("`@("`@("1T:&ES+3Y?:&5I9VAT("`]("1H96EG:'0["B`@("!]
M"@I]"@HO*BH*("H@6$U,7U-61U]%;&QI<'-E"B`J"B`J($!P86-K86=E(%A-
M3%]35D<*("HO"F-L87-S(%A-3%]35D=?16QL:7!S92!E>'1E;F1S(%A-3%]3
M5D=?16QE;65N="!["@H@("`@=F%R("1?8W@["B`@("!V87(@)%]C>3L*("`@
M('9A<B`D7W)X.PH@("`@=F%R("1?<GD["@H@("`@9G5N8W1I;VX@<')I;G1%
M;&5M96YT*"D*("`@('L*("`@("`@("!E8VAO("<\96QL:7!S92<["B`@("`@
M("`@)'1H:7,M/G!R:6YT4&%R86US*"=I9"<L("=C>"<L("=C>2<L("=R>"<L
M("=R>2<L("=S='EL92<L("=T<F%N<V9O<FTG*3L*("`@("`@("!I9B`H:7-?
M87)R87DH)'1H:7,M/E]E;&5M96YT<RDI('L*("`@("`@("`@("`@+R\@4')I
M;G0@8VAI;&1R96XL('-T87)T(&%N9"!E;F0@=&%G+@H@("`@("`@("`@("!P
M<FEN="@B/EQN(BD["B`@("`@("`@("`@('!A<F5N=#HZ<')I;G1%;&5M96YT
M*"D["B`@("`@("`@("`@('!R:6YT*"(\+V5L;&EP<V4^7&XB*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`O+R!0<FEN="!S:&]R="!T86<N"B`@
M("`@("`@("`@('!R:6YT*"(@+SY<;B(I.PH@("`@("`@('T*("`@('T*"B`@
M("!F=6YC=&EO;B!S9713:&%P92@D8W@L("1C>2P@)')X+"`D<GDI"B`@("![
M"B`@("`@("`@)'1H:7,M/E]C>"`]("1C>#L*("`@("`@("`D=&AI<RT^7V-Y
M(#T@)&-Y.PH@("`@("`@("1T:&ES+3Y?<G@@(#T@)')X.PH@("`@("`@("1T
M:&ES+3Y?<GD@(#T@)')Y.PH@("`@?0H*?0H*+RHJ"B`J(%A-3%]35D=?4&]L
M>6QI;F4*("H*("H@0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-6
M1U]0;VQY;&EN92!E>'1E;F1S(%A-3%]35D=?16QE;65N="!["@H@("`@=F%R
M("1?<&]I;G1S.PH*("`@(&9U;F-T:6]N('!R:6YT16QE;65N="@I"B`@("![
M"B`@("`@("`@96-H;R`G/'!O;'EL:6YE)SL*("`@("`@("`D=&AI<RT^<')I
M;G1087)A;7,H)VED)RP@)W!O:6YT<R<L("=S='EL92<L("=T<F%N<V9O<FTG
M*3L*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?96QE;65N=',I*2![
M"B`@("`@("`@("`@("\O(%!R:6YT(&-H:6QD<F5N+"!S=&%R="!A;F0@96YD
M('1A9RX*("`@("`@("`@("`@<')I;G0H(CY<;B(I.PH@("`@("`@("`@("!P
M87)E;G0Z.G!R:6YT16QE;65N="@I.PH@("`@("`@("`@("!P<FEN="@B/"]P
M;VQY;&EN93Y<;B(I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O
M(%!R:6YT('-H;W)T('1A9RX*("`@("`@("`@("`@<')I;G0H(B\^7&XB*3L*
M("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@<V5T4VAA<&4H)'!O:6YT
M<RD*("`@('L*("`@("`@("`D=&AI<RT^7W!O:6YT<R`]("1P;VEN=',["B`@
M("!]"@I]"@HO*BH*("H@6$U,7U-61U]0;VQY9V]N"B`J"B`J($!P86-K86=E
M(%A-3%]35D<*("HO"F-L87-S(%A-3%]35D=?4&]L>6=O;B!E>'1E;F1S(%A-
M3%]35D=?16QE;65N="!["@H@("`@=F%R("1?<&]I;G1S.PH*("`@(&9U;F-T
M:6]N('!R:6YT16QE;65N="@I"B`@("!["B`@("`@("`@96-H;R`G/'!O;'EG
M;VXG.PH@("`@("`@("1T:&ES+3YP<FEN=%!A<F%M<R@G:60G+"`G<&]I;G1S
M)RP@)W-T>6QE)RP@)W1R86YS9F]R;2<I.PH@("`@("`@(&EF("AI<U]A<G)A
M>2@D=&AI<RT^7V5L96UE;G1S*2D@>PH@("`@("`@("`@("`O+R!0<FEN="!C
M:&EL9')E;BP@<W1A<G0@86YD(&5N9"!T86<N"B`@("`@("`@("`@('!R:6YT
M*"(^7&XB*3L*("`@("`@("`@("`@<&%R96YT.CIP<FEN=$5L96UE;G0H*3L*
M("`@("`@("`@("`@<')I;G0H(CPO<&]L>6=O;CY<;B(I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("\O(%!R:6YT('-H;W)T('1A9RX*("`@("`@
M("`@("`@<')I;G0H(B\^7&XB*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N
M8W1I;VX@<V5T4VAA<&4H)'!O:6YT<RD*("`@('L*("`@("`@("`D=&AI<RT^
M7W!O:6YT<R`]("1P;VEN=',["B`@("!]"@I]"@HO*BH*("H@6$U,7U-61U]0
M871H"B`J"B`J($!P86-K86=E(%A-3%]35D<*("HO"F-L87-S(%A-3%]35D=?
M4&%T:"!E>'1E;F1S(%A-3%]35D=?16QE;65N="!["@H@("`@=F%R("1?9#L*
M"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE;G0H*0H@("`@>PH@("`@("`@(&5C
M:&\@)SQP871H)SL*("`@("`@("`D=&AI<RT^<')I;G1087)A;7,H)VED)RP@
M)V0G+"`G<W1Y;&4G+"`G=')A;G-F;W)M)RD["B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1T:&ES+3Y?96QE;65N=',I*2!["B`@("`@("`@("`@("\O(%!R:6YT
M(&-H:6QD<F5N+"!S=&%R="!A;F0@96YD('1A9RX*("`@("`@("`@("`@<')I
M;G0H(CY<;B(I.PH@("`@("`@("`@("!P87)E;G0Z.G!R:6YT16QE;65N="@I
M.PH@("`@("`@("`@("!P<FEN="@B/"]P871H/EQN(BD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@+R\@4')I;G0@<VAO<G0@=&%G+@H@("`@("`@
M("`@("!P<FEN="@B+SY<;B(I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC
M=&EO;B!S9713:&%P92@D9"D*("`@('L*("`@("`@("`D=&AI<RT^7V0@/2`D
M9#L*("`@('T*"GT*"B\J*@H@*B!834Q?4U9'7TEM86=E"B`J"B`J($!P86-K
M86=E(%A-3%]35D<*("HO"F-L87-S(%A-3%]35D=?26UA9V4@97AT96YD<R!8
M34Q?4U9'7T5L96UE;G0@>PH*("`@('9A<B`D7W@["B`@("!V87(@)%]Y.PH@
M("`@=F%R("1?=VED=&@["B`@("!V87(@)%]H96EG:'0["B`@("!V87(@)%]H
M<F5F.PH*("`@(&9U;F-T:6]N('!R:6YT16QE;65N="@I"B`@("!["B`@("`@
M("`@96-H;R`G/&EM86=E)SL*("`@("`@("`D=&AI<RT^<')I;G1087)A;7,H
M)VED)RP@)W@G+"`G>2<L("=W:61T:"<L("=H96EG:'0G+"`G<W1Y;&4G*3L*
M("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?:')E9BDI('L*("`@("`@("`@
M("`@96-H;R`G('AL:6YK.FAR968](B<@+B`D=&AI<RT^7VAR968@+B`G(B<[
M"B`@("`@("`@?0H@("`@("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^7V5L96UE
M;G1S*2D@>PH@("`@("`@("`@("`O+R!0<FEN="!C:&EL9')E;BP@<W1A<G0@
M86YD(&5N9"!T86<N"B`@("`@("`@("`@(&5C:&\@(CY<;B(["B`@("`@("`@
M("`@('!A<F5N=#HZ<')I;G1%;&5M96YT*"D["B`@("`@("`@("`@(&5C:&\@
M(CPO:6UA9V4^7&XB.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O
M(%!R:6YT('-H;W)T('1A9RX*("`@("`@("`@("`@96-H;R`B("\^7&XB.PH@
M("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!S9713:&%P92@D>"P@)'DL
M("1W:61T:"P@)&AE:6=H="D*("`@('L*("`@("`@("`D=&AI<RT^7W@@/2`D
M>#L*("`@("`@("`D=&AI<RT^7WD@/2`D>3L*("`@("`@("`D=&AI<RT^7W=I
M9'1H("`]("1W:61T:#L*("`@("`@("`D=&AI<RT^7VAE:6=H="`@/2`D:&5I
M9VAT.PH@("`@?0H*?0H*+RHJ"B`J(%A-3%]35D=?06YI;6%T90H@*@H@*B!`
M<&%C:V%G92!834Q?4U9'"B`J+PIC;&%S<R!834Q?4U9'7T%N:6UA=&4@97AT
M96YD<R!834Q?4U9'7T5L96UE;G0@>PH*("`@('9A<B`D7V%T=')I8G5T94YA
M;64["B`@("!V87(@)%]A='1R:6)U=&54>7!E.PH@("`@=F%R("1?9G)O;3L*
M("`@('9A<B`D7W1O.PH@("`@=F%R("1?8F5G:6X["B`@("!V87(@)%]D=7([
M"B`@("!V87(@)%]F:6QL.PH*("`@(&9U;F-T:6]N('!R:6YT16QE;65N="@I
M"B`@("!["B`@("`@("`@96-H;R`G/&%N:6UA=&4G.PH@("`@("`@("1T:&ES
M+3YP<FEN=%!A<F%M<R@G:60G+"`G871T<FEB=71E3F%M92<L("=A='1R:6)U
M=&54>7!E)RP@)V9R;VTG+"`G=&\G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G8F5G:6XG+"`G9'5R)RP@)V9I;&PG*3L*("`@("`@("!I9B`H:7-?
M87)R87DH)'1H:7,M/E]E;&5M96YT<RDI('L*("`@("`@("`@("`@+R\@4')I
M;G0@8VAI;&1R96XL('-T87)T(&%N9"!E;F0@=&%G+@H@("`@("`@("`@("!E
M8VAO("(^7&XB.PH@("`@("`@("`@("!P87)E;G0Z.G!R:6YT16QE;65N="@I
M.PH@("`@("`@("`@("!E8VAO("(\+V%N:6UA=&4^7&XB.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(&5C:&\@(B`O/EQN(CL*("`@("`@("!]"B`@
M("!]"@H@("`@9G5N8W1I;VX@<V5T4VAA<&4H)&%T=')I8G5T94YA;64L("1A
M='1R:6)U=&54>7!E(#T@)R<L("1F<F]M(#T@)R<L"B`@("`@("`@("`@("`@
M("`@("`@("`D=&\@/2`G)RP@)&)E9VEN(#T@)R<L("1D=7(@/2`G)RP@)&9I
M;&P@/2`G)RD*("`@('L*("`@("`@("`D=&AI<RT^7V%T=')I8G5T94YA;64@
M/2`D871T<FEB=71E3F%M93L*("`@("`@("`D=&AI<RT^7V%T=')I8G5T951Y
M<&4@/2`D871T<FEB=71E5'EP93L*("`@("`@("`D=&AI<RT^7V9R;VT@(#T@
M)&9R;VT["B`@("`@("`@)'1H:7,M/E]T;R`]("1T;SL*("`@("`@("`D=&AI
M<RT^7V)E9VEN(#T@)&)E9VEN.PH@("`@("`@("1T:&ES+3Y?9'5R(#T@)&1U
M<CL*("`@("`@("`D=&AI<RT^7V9I;&P@/2`D9FEL;#L*("`@('T*"GT*"B\J
M*@H@*B!834Q?4U9'7T9I;'1E<@H@*@H@*B!`<&%C:V%G92!834Q?4U9'"B`J
M+PIC;&%S<R!834Q?4U9'7T9I;'1E<B!E>'1E;F1S(%A-3%]35D=?16QE;65N
M="!["@H@("`@9G5N8W1I;VX@<')I;G1%;&5M96YT*"D*("`@('L*("`@("`@
M("!E8VAO("<\9FEL=&5R)SL*("`@("`@("`D=&AI<RT^<')I;G1087)A;7,H
M)VED)RD["B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?96QE;65N=',I
M*2!["B`@("`@("`@("`@("\O(%!R:6YT(&-H:6QD<F5N+"!S=&%R="!A;F0@
M96YD('1A9RX*("`@("`@("`@("`@96-H;R`B/EQN(CL*("`@("`@("`@("`@
M<&%R96YT.CIP<FEN=$5L96UE;G0H*3L*("`@("`@("`@("`@96-H;R`B/"]F
M:6QT97(^7&XB.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&5C:&\@
M(B`O/EQN(CL*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@861D4')I
M;6ET:79E*"1P<FEM:71I=F4L("1P87)A;7,I"B`@("!["B`@("`@("`@)'1H
M:7,M/F%D9$-H:6QD*&YE=R!834Q?4U9'7T9I;'1E<E!R:6UI=&EV92@D<')I
M;6ET:79E+"`D<&%R86US*2D["B`@("!]"@I]"@HO*BH*("H@6$U,7U-61U]&
M:6QT97)0<FEM:71I=F4*("H*("H@0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA
M<W,@6$U,7U-61U]&:6QT97)0<FEM:71I=F4@97AT96YD<R!834Q?4U9'7T5L
M96UE;G0@>PH*("`@('9A<B`D7W!R:6UI=&EV97,@/2!A<G)A>2@G0FQE;F0G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=#;VQO<DUA=')I>"<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)T-O;7!O;F5N=%1R86YS
M9F5R)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G0V]M<&]S:71E
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G0V]N=F]L=F5-871R
M:7@G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=$:69F=7-E3&EG
M:'1I;F<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=$:7-P;&%C
M96UE;G1-87`G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=&;&]O
M9"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)T=A=7-S:6%N0FQU
M<B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)TEM86=E)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G365R9V4G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=-;W)P:&]L;V=Y)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G3V9F<V5T)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G4W!E8W5L87),:6=H=&EN9R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)U1I;&4G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=4=7)B=6QE;F-E)RD["@H@("`@=F%R("1?<')I;6ET:79E.PH*
M("`@('9A<B`D7VEN.PH@("`@=F%R("1?:6XR.PH@("`@=F%R("1?<F5S=6QT
M.PH@("`@=F%R("1?>#L*("`@('9A<B`D7WD["B`@("!V87(@)%]D>#L*("`@
M('9A<B`D7V1Y.PH@("`@=F%R("1?=VED=&@["B`@("!V87(@)%]H96EG:'0[
M"B`@("!V87(@)%]M;V1E.PH@("`@=F%R("1?='EP93L*("`@('9A<B`D7W9A
M;'5E<SL*("`@('9A<B`D7V]P97)A=&]R.PH@("`@=F%R("1?:S$["B`@("!V
M87(@)%]K,CL*("`@('9A<B`D7VLS.PH@("`@=F%R("1?:S0["B`@("!V87(@
M)%]S=7)F86-E4V-A;&4["B`@("!V87(@)%]D:69F=7-E0V]N<W1A;G0["B`@
M("!V87(@)%]K97)N96Q5;FET3&5N9W1H.PH@("`@=F%R("1?9FQO;W)?8V]L
M;W(["B`@("!V87(@)%]F;&]O9%]O<&%C:71Y.PH*("`@(&9U;F-T:6]N(%A-
M3%]35D=?1FEL=&5R4')I;6ET:79E*"1P<FEM:71I=F4L("1P87)A;7,@/2!A
M<G)A>2@I*0H@("`@>PH@("`@("`@('!A<F5N=#HZ6$U,7U-61U]%;&5M96YT
M*"1P87)A;7,I.PH@("`@("`@("1T:&ES+3Y?<')I;6ET:79E(#T@)'!R:6UI
M=&EV93L*("`@('T*"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE;G0H*0H@("`@
M>PH@("`@("`@("1N86UE(#T@)V9E)R`N("1T:&ES+3Y?<')I;6ET:79E.PH@
M("`@("`@(&5C:&\@)SPG("X@)&YA;64["B`@("`@("`@)'1H:7,M/G!R:6YT
M4&%R86US*"=I9"<L("=X)RP@)WDG+"`G9'@G+"`G9'DG+"`G=VED=&@G+"`G
M:&5I9VAT)RP@)VEN)RP@)VEN,B<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=R97-U;'0G+"`G;6]D92<L("=T>7!E)RP@)W9A;'5E<R<L("=O<&5R
M871O<B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("=K,2<L("=K,B<L
M("=K,R<L("=K-"<L("=S=7)F86-E4V-A;&4G+"`G<W1D1&5V:6%T:6]N)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1I9F9U<V5#;VYS=&%N="<L
M("=K97)N96Q5;FET3&5N9W1H)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V9L;V]D7V-O;&]R)RP@)V9L;V]D7V]P86-I='DG*3L*("`@("`@("!I
M9B`H:7-?87)R87DH)'1H:7,M/E]E;&5M96YT<RDI('L*("`@("`@("`@("`@
M+R\@4')I;G0@8VAI;&1R96XL('-T87)T(&%N9"!E;F0@=&%G+@H@("`@("`@
M("`@("!E8VAO("(^7&XB.PH@("`@("`@("`@("!P87)E;G0Z.G!R:6YT16QE
M;65N="@I.PH@("`@("`@("`@("!E8VAO("<\+R<@+B`D;F%M92`N("<^)SL*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!E8VAO("<O/B<["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1F]R(&9E365R9V4@96QE;65N
M=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$UE<F=E3F]D92@D:6XI"B`@
M("!["B`@("`@("`@)'1H:7,M/F%D9$-H:6QD*&YE=R!834Q?4U9'7T9I;'1E
M<DUE<F=E3F]D92AA<G)A>2@G:6XG(#T^("1I;BDI*3L*("`@('T*"GT*"B\J
M*@H@*B!834Q?4U9'7T9I;'1E<DUE<F=E3F]D90H@*@H@*B!`<&%C:V%G92!8
M34Q?4U9'"B`J+PIC;&%S<R!834Q?4U9'7T9I;'1E<DUE<F=E3F]D92!E>'1E
M;F1S(%A-3%]35D=?16QE;65N="!["@H@("`@=F%R("1?:6X["@H@("`@9G5N
M8W1I;VX@<')I;G1%;&5M96YT*"D*("`@('L*("`@("`@("!E8VAO("<\9F5-
M97)G94YO9&4G.PH@("`@("`@("1T:&ES+3YP<FEN=%!A<F%M<R@G:6XG*3L*
M("`@("`@("!E8VAO("<O/B<["B`@("!]"@I]"@HO*BH*("H@6$U,7U-61U]5
M<V4*("H*("H@0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]5
M<V4@97AT96YD<R!834Q?4U9'7T5L96UE;G0@>PH*("`@('9A<B`D7W-Y;6)O
M;#L*"B`@("!F=6YC=&EO;B!834Q?4U9'7U5S92@D<WEM8F]L+"`D<&%R86US
M(#T@87)R87DH*2D*("`@('L*("`@("`@("!P87)E;G0Z.EA-3%]35D=?16QE
M;65N="@D<&%R86US*3L*("`@("`@("`D=&AI<RT^7W-Y;6)O;"`]("1S>6UB
M;VP["B`@("!]"@H@("`@9G5N8W1I;VX@<')I;G1%;&5M96YT*"D*("`@('L*
M("`@("`@("!E8VAO("<\=7-E('AL:6YK.FAR968](B,G("X@)'1H:7,M/E]S
M>6UB;VP@+B`G(B\^)SL*("`@('T*"GT*"B\J*@H@*B!834Q?4U9'7T1E9G,*
M("H*("H@0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]$969S
M(&5X=&5N9',@6$U,7U-61U]%;&5M96YT('L*"B`@("!F=6YC=&EO;B!P<FEN
M=$5L96UE;G0H*0H@("`@>PH@("`@("`@(&5C:&\@)SQD969S)SL*("`@("`@
M("`D=&AI<RT^<')I;G1087)A;7,H)VED)RP@)W-T>6QE)RP@)W1R86YS9F]R
M;2<I.PH@("`@("`@(&5C:&\@(CY<;B(["B`@("`@("`@<&%R96YT.CIP<FEN
M=$5L96UE;G0H*3L*("`@("`@("!E8VAO("(\+V1E9G,^7&XB.PH@("`@?0H*
M?0H*+RHJ"B`J(%A-3%]35D=?36%R:V5R"B`J"B`J($!P86-K86=E(%A-3%]3
M5D<*("HO"F-L87-S(%A-3%]35D=?36%R:V5R(&5X=&5N9',@6$U,7U-61U]%
M;&5M96YT('L*"B`@("!V87(@)%]R9698.PH@("`@=F%R("1?<F5F63L*("`@
M('9A<B`D7VUA<FME<E5N:71S.PH@("`@=F%R("1?;6%R:V5R5VED=&@["B`@
M("!V87(@)%]M87)K97)(96EG:'0["B`@("!V87(@)%]O<FEE;G0["@H@("`@
M9G5N8W1I;VX@<')I;G1%;&5M96YT*"D*("`@('L*("`@("`@("!E8VAO("<\
M;6%R:V5R)SL*("`@("`@("`D=&AI<RT^<')I;G1087)A;7,H)VED)RP@)W)E
M9E@G+"`G<F5F62<L("=M87)K97)5;FET<R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=M87)K97)7:61T:"<L("=M87)K97)(96EG:'0G+"`G;W)I
M96YT)RD["B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?96QE;65N=',I
M*2![("\O(%!R:6YT(&-H:6QD<F5N+"!S=&%R="!A;F0@96YD('1A9RX*("`@
M("`@("`@("`@<')I;G0H(CY<;B(I.PH@("`@("`@("`@("!P87)E;G0Z.G!R
M:6YT16QE;65N="@I.PH@("`@("`@("`@("!P<FEN="@B/"]M87)K97(^7&XB
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!P<FEN="@B+SY<;B(I
M.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!S9713:&%P92@D<F5F
M6"`]("<G+"`D<F5F62`]("<G+"`D;6%R:V5R56YI=',@/2`G)RP*("`@("`@
M("`@("`@("`@("`@("`@("1M87)K97)7:61T:"`]("<G+"`D;6%R:V5R2&5I
M9VAT(#T@)R<L("1O<FEE;G0@/2`G)RD*("`@('L*("`@("`@("`D=&AI<RT^
M7W)E9E@@/2`D<F5F6#L*("`@("`@("`D=&AI<RT^7W)E9ED@(#T@)')E9ED[
M"B`@("`@("`@)'1H:7,M/E]M87)K97)5;FET<R`]("1M87)K97)5;FET<SL*
M("`@("`@("`D=&AI<RT^7VUA<FME<E=I9'1H(#T@)&UA<FME<E=I9'1H.PH@
M("`@("`@("1T:&ES+3Y?;6%R:V5R2&5I9VAT(#T@)&UA<FME<DAE:6=H=#L*
M("`@("`@("`D=&AI<RT^7V]R:65N="`]("1O<FEE;G0["B`@("!]"@I]"@HO
M*BH*("H@6$U,7U-61U]4:71L90H@*@H@*B!`<&%C:V%G92!834Q?4U9'"BHO
M"F-L87-S(%A-3%]35D=?5&ET;&4@97AT96YD<R!834Q?4U9'7T5L96UE;G0@
M>PH*("`@('9A<B`D7W1I=&QE.PH*("`@(&9U;F-T:6]N('!R:6YT16QE;65N
M="@I"B`@("!["B`@("`@("`@96-H;R`G/'1I=&QE)SL*("`@("`@("`D=&AI
M<RT^<')I;G1087)A;7,H)VED)RP@)W-T>6QE)RD["B`@("`@("`@<')I;G0H
M(CY<;B(I.PH@("`@("`@('!R:6YT*"1T:&ES+3Y?=&ET;&4I.PH@("`@("`@
M('!A<F5N=#HZ<')I;G1%;&5M96YT*"D["B`@("`@("`@<')I;G0H(CPO=&ET
M;&4^7&XB*3L*("`@('T*"GT*"B\J*@H@*B!834Q?4U9'7T1E<V,*("H*("H@
M0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]$97-C(&5X=&5N
M9',@6$U,7U-61U]%;&5M96YT('L*"B`@("!V87(@)%]D97-C.PH*("`@(&9U
M;F-T:6]N('!R:6YT16QE;65N="@I"B`@("!["B`@("`@("`@96-H;R`G/&1E
M<V,G.PH@("`@("`@("1T:&ES+3YP<FEN=%!A<F%M<R@G:60G+"`G<W1Y;&4G
M*3L*("`@("`@("!E8VAO("<^)R`N("1T:&ES+3Y?9&5S8SL*("`@("`@("!P
M87)E;G0Z.G!R:6YT16QE;65N="@I.PH@("`@("`@(&5C:&\@(CPO9&5S8SY<
M;B(["B`@("!]"@I]"@HO*BH*("H@6$U,7U-61U]4<F5F"B`J"B`J($!P86-K
M86=E(%A-3%]35D<*("HO"F-L87-S(%A-3%]35D=?5')E9B!E>'1E;F1S(%A-
M3%]35D=?16QE;65N="!["@H@("`@=F%R("1?=&5X=#L*("`@('9A<B`D7W@[
M"B`@("!V87(@)%]Y.PH@("`@=F%R("1?9'@["B`@("!V87(@)%]D>3L*("`@
M('9A<B`D7W)O=&%T93L*("`@('9A<B`D7W1E>'1,96YG=&@["B`@("!V87(@
M)%]L96YG=&A!9&IU<W0["@H@("`@9G5N8W1I;VX@<')I;G1%;&5M96YT*"D*
M("`@('L*("`@("`@("!E8VAO("<\=')E9B<["B`@("`@("`@)'1H:7,M/G!R
M:6YT4&%R86US*"=I9"<L("=X)RP@)WDG+"`G9'@G+"`G9'DG+"`G<F]T871E
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1E>'1,96YG=&@G+"`G
M;&5N9W1H061J=7-T)RP@)W-T>6QE)RD["B`@("`@("`@96-H;R`G/B<@+B`D
M=&AI<RT^7W1E>'0["B`@("`@("`@<&%R96YT.CIP<FEN=$5L96UE;G0H*3L*
M("`@("`@("!E8VAO("(\+W1R968^7&XB.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O6$U,+U="6$U,+P``````
M````````````````````````````````````````````````````````````
M`````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-3$U-#,S-S0U`#`Q-S<U-@`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B]834PO5T)834PO0V]N=&5N=$AA;F1L97(N<&AP````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#8P-S$`,3`U,34T,S,W-#4`,#(S-#`S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]834Q?5T)834PO5T)834PO0V]N=&5N=$AA
M;F1L97(N<&AP+'8@,2XY+C$P+C<@,C`P-B\P-2\P,2`Q,CHP-3HQ-2!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!!;G1H;VYY($UI;&QS
M(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M("!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($9R
M;VT@0FEN87)Y(%A-3"!#;VYT96YT($9O<FUA="!3<&5C:69I8V%T:6]N(%9E
M<G-I;VX@,2XS+"`R-2!*=6QY(#(P,#$*("H@9F]U;F0@870@:'1T<#HO+W=W
M=RYW87!F;W)U;2YO<F<*("H*("H@0'!A8VMA9V4@6$U,7U="6$U,"B`J+PIC
M;&%S<R!834Q?5T)834Q?0V]N=&5N=$AA;F1L97(@>PH*("`@('9A<B`D7V-U
M<G)E;G15<FD["B`@("!V87(@)%]O=71P=70@/2`G)SL*"B`@("!V87(@)%]O
M<&%Q=65(86YD;&5R.PH*("`@("\J*@H@("`@("H@0VAA<G-E="X*("`@("`J
M+PH@("`@=F%R("1?8VAA<G-E="`]("=55$8M."<["@H@("`@+RHJ"B`@("`@
M*B!70EA-3"!697)S:6]N+@H@("`@("H@,2P@,BP@;W(@,R!S=7!P;W)T960*
M("`@("`J+PH@("`@=F%R("1?=V)X;6Q697)S:6]N(#T@,CL*"B`@("!F=6YC
M=&EO;B!834Q?5T)834Q?0V]N=&5N=$AA;F1L97(H*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?8W5R<F5N=%5R:2`]("9N97<@6$U,7U="6$U,7TQI9F]1=65U
M92@I.PH@("`@?0H*("`@(&9U;F-T:6]N(')A:7-E17)R;W(H)&5R<F]R*0H@
M("`@>PH@("`@("`@(&EN8VQU9&5?;VYC92`G4$5!4BYP:'`G.PH@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*"1E<G)O<BD["B`@("!]"@H@("`@
M9G5N8W1I;VX@9V5T0VAA<G-E=%-T<B@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?8VAA<G-E=#L*("`@('T*"B`@("!F=6YC=&EO;B!S971#:&%R
M<V5T*"1C<RD*("`@('L*("`@("`@("`D=&AI<RT^7V-H87)S970@/2`D8W,[
M"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T5F5R<VEO;B@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?=V)X;6Q697)S:6]N.PH@("`@?0H*("`@(&9U
M;F-T:6]N('-E=%9E<G-I;VXH)'8I"B`@("!["B`@("`@("`@)'1H:7,M/E]W
M8GAM;%9E<G-I;VX@/2`R.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$]U='!U
M="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;W5T<'5T.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&=E=$]U='!U=%-I>F4H*0H@("`@>PH@("`@("`@
M(')E='5R;B!S=')L96XH)'1H:7,M/E]O=71P=70I.PH@("`@?0H*("`@(&9U
M;F-T:6]N('-T87)T16QE;65N="@D=7)I+"`D96QE;65N="P@)&%T=')S*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?;W5T<'5T("X]("<\)R`N("1E;&5M96YT
M.PH*("`@("`@("`D8W5R<F5N=%5R:2`]("1T:&ES+3Y?8W5R<F5N=%5R:2T^
M=&]P*"D["@H@("`@("`@(&EF("@H*"$D8W5R<F5N=%5R:2D@?'P@*"1C=7)R
M96YT57)I("$]("1U<FDI*2`F)B`D=7)I*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?;W5T<'5T("X]("<@>&UL;G,](B<@+B`D=7)I("X@)R(G.PH@("`@("`@
M('T*"B`@("`@("`@)'1H:7,M/E]C=7)R96YT57)I+3YP=7-H*"1U<FDI.PH*
M("`@("`@("!F;W)E86-H("@D871T<G,@87,@)&%T='(I('L*("`@("`@("`@
M("`@)'1H:7,M/E]O=71P=70@+CT@)R`G("X@)&%T=');)V%T=')I8G5T92==
M("X@)STB)R`N("1A='1R6R=V86QU92==("X@)R(G.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/E]O=71P=70@+CT@)SXG.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]O=71P=70@+CT@)SPO)R`N("1E;&5M96YT("X@)SXG.PH*("`@
M("`@("`D=&AI<RT^7V-U<G)E;G15<FDM/G!O<"@I.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&-H87)A8W1E<G,H)'-T<BD*("`@('L*("`@("`@("`D=&AI<RT^
M7V]U='!U="`N/2`D<W1R.PH@("`@?0H*("`@(&9U;F-T:6]N(&]P87%U92@D
M;RD*("`@('L*("`@("`@("`D=&AI<RT^7V]U='!U="`N/2`D;SL*("`@('T*
M"B`@("!F=6YC=&EO;B!S971/<&%Q=65(86YD;&5R*"1O<&%Q=65(86YD;&5R
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;W!A<75E2&%N9&QE<B`]("1O<&%Q
M=65(86YD;&5R.PH@("`@?0H*("`@(&9U;F-T:6]N(')E;6]V94]P87%U94AA
M;F1L97(H*0H@("`@>PH@("`@("`@('5N<V5T*"1T:&ES+3Y?;W!A<75E2&%N
M9&QE<BD["B`@("!]"@H@("`@9G5N8W1I;VX@8W)E871E4W5B2&%N9&QE<B@I
M"B`@("!["B`@("`@("`@)&YA;64@/2!G971?8VQA<W,H)'1H:7,I.R`O+R!C
M;&]N92!C=7)R96YT(&-L87-S"B`@("`@("`@)'-H(#T@)FYE=R`D;F%M92@I
M.PH@("`@("`@("1S:"T^<V5T0VAA<G-E="@D=&AI<RT^9V5T0VAA<G-E=%-T
M<B@I*3L*("`@("`@("`D<V@M/G-E=%9E<G-I;VXH)'1H:7,M/F=E=%9E<G-I
M;VXH*2D["B`@("`@("`@<F5T=7)N("1S:#L*("`@('T*"GT*"F-L87-S(%A-
M3%]70EA-3%],:69O475E=64@>PH*("`@('9A<B`D7W%U975E(#T@87)R87DH
M*3L*"B`@("!F=6YC=&EO;B!834Q?5T)834Q?3&EF;U%U975E*"D*("`@('L*
M("`@('T*"B`@("!F=6YC=&EO;B!P=7-H*"1O8FHI"B`@("!["B`@("`@("`@
M)'1H:7,M/E]Q=65U95M=(#T@)&]B:CL*("`@('T*"B`@("!F=6YC=&EO;B!P
M;W`H*0H@("`@>PH@("`@("`@(&EF("AC;W5N="@D=&AI<RT^7W%U975E*2D@
M>PH@("`@("`@("`@("!R971U<FX@87)R87E?<&]P*"1T:&ES+3Y?<75E=64I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@
M("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!T;W`H*0H@("`@>PH@("`@
M("`@(&EF("@D8V]U;G0@/2!C;W5N="@D=&AI<RT^7W%U975E*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]Q=65U95LD8V]U;G0@+2`Q73L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@
M("!]"B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O6$U,+U="6$U,+T1E8V]D97(N<&AP````````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#0W-S$W`#$P-3$U-#,S-S0U`#`R,C`U-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`H*:6YC
M;'5D95]O;F-E("=834PO5T)834PN<&AP)SL*:6YC;'5D95]O;F-E("=834PO
M5T)834PO1%1$36%N86=E<BYP:'`G.PII;F-L=61E7V]N8V4@)UA-3"]70EA-
M3"]#;VYT96YT2&%N9&QE<BYP:'`G.PH*+RHJ"B`J("1(;W)D93H@9G)A;65W
M;W)K+UA-3%]70EA-3"]70EA-3"]$96-O9&5R+G!H<"QV(#$N,C(N,3`N."`R
M,#`V+S`Q+S`Q(#(Q.C(X.C0U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P,RTR,#`V($%N=&AO;GD@36EL;',@/&%M:6QL<T!P>7)A;6ED-BYC;VT^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@1G)O;2!":6YA<GD@6$U,($-O;G1E;G0@
M1F]R;6%T(%-P96-I9FEC871I;VX@5F5R<VEO;B`Q+C,L(#(U($IU;'D*("H@
M,C`P,2!F;W5N9"!A="!H='1P.B\O=W=W+G=A<&9O<G5M+F]R9PH@*@H@*B!`
M<&%C:V%G92!834Q?5T)834P*("HO"F-L87-S(%A-3%]70EA-3%]$96-O9&5R
M(&5X=&5N9',@6$U,7U="6$U,7T-O;G1E;G1(86YD;&5R('L*"B`@("`O*BH*
M("`@("`J($1O8W5M96YT(%!U8FQI8R!)9&5N=&EF:65R('1Y<&4*("`@("`J
M(#$@;6)?=5]I;G0S,B!W96QL(&MN;W=N('1Y<&4*("`@("`J(#(@<W1R:6YG
M('1A8FQE"B`@("`@*B!F<F]M('-P96,@8G5T(&-O;G9E<G1E9"!I;G1O(&$@
M<W1R:6YG+@H@("`@("H*("`@("`J($1O8W5M96YT(%!U8FQI8R!)9&5N=&EF
M:65R"B`@("`@*B!5<V5D('=I=&@@9'!I5'EP92X*("`@("`J+PH@("`@=F%R
M("1?9'!I.PH*("`@("\J*@H@("`@("H@4W1R:6YG('1A8FQE(&%S(&1E9FEN
M960@:6X@-2XW"B`@("`@*B\*("`@('9A<B`D7W-T<FEN9U1A8FQE(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("`J($-O;G1E;G0@:&%N9&QE<BX*("`@("`J
M($-U<G)E;G1L>2!J=7-T(&]U='!U=',@<F%W(%A-3"X*("`@("`J+PH@("`@
M=F%R("1?8V@["@H@("`@=F%R("1?=&%G1%1$.PH*("`@('9A<B`D7W!R979!
M='1R:6)U=&5$5$0["@H@("`@=F%R("1?871T<FEB=71E1%1$.PH*("`@("\J
M*@H@("`@("H@4W1A=&4@=F%R:6%B;&5S+@H@("`@("HO"B`@("!V87(@)%]T
M86=3=&%C:R`](&%R<F%Y*"D["B`@("!V87(@)%]I<T%T=')I8G5T93L*("`@
M('9A<B`D7VES1&%T82`](&9A;'-E.PH*("`@('9A<B`D7V5R<F]R(#T@9F%L
M<V4["@H@("`@+RHJ"B`@("`@*B!4:&4@1%1$($UA;F%G97(N"B`@("`@*@H@
M("`@("H@0'9A<B!834Q?5T)834Q?1%1$36%N86=E<@H@("`@("HO"B`@("!V
M87(@)%]D=&1-86YA9V5R.PH*("`@("\J*@H@("`@("H@5&AE('-T<FEN9R!P
M;W-I=&EO;BX*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@
M("`@=F%R("1?<W1R<&]S.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%A-3%]70EA-3%]$96-O9&5R*"D*("`@
M('L*("`@("`@("`D=&AI<RT^7V1T9$UA;F%G97(@/2`F;F5W(%A-3%]70EA-
M3%]$5$1-86YA9V5R*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H
M92!C;VYT96YT2&%N9&QE<B!T:&%T('=I;&P@<F5C96EV92!T:&4@;W5T<'5T
M(&]F('1H90H@("`@("H@9&5C;V1I;F<N"B`@("`@*@H@("`@("H@0'!A<F%M
M(%A-3%]70EA-3%]#;VYT96YT2&%N9&QE<B`D8V@@5&AE(&-O;G1E;G1(86YD
M;&5R"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$-O;G1E;G1(86YD;&5R*"8D
M8V@I"B`@("!["B`@("`@("`@)'1H:7,M/E]C:"`]("8D8V@["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FX@;VYE(&)Y=&4@9G)O;2!T:&4@:6YP=70@
M<W1R96%M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&EN<'5T("!4
M:&4@5T)834P@:6YP=70@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971">71E*"1I;G!U="D*("`@('L*("`@("`@("!R971U<FX@;W)D*"1I;G!U
M='LD=&AI<RT^7W-T<G!O<RLK?2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4
M86ME<R!A(%="6$U,(&EN<'5T(&1O8W5M96YT(&%N9"!R971U<FYS(&1E8V]D
M960@6$U,+@H@("`@("H@2&]W979E<B!T:&4@<')E9F5R<F5D(&%N9"!M;W)E
M(&5F9F5C:65N="!M971H;V0@:7,@=&\*("`@("`J('5S92!D96-O9&4H*2!R
M871H97(@=&AA;B!D96-O9&54;U-T<FEN9R@I(&%N9"!H879E(&%N"B`@("`@
M*B!A<'!R;W!R:6%T92!C;VYT96YT2&%N9&QE<B!D96%L('=I=&@@=&AE(&1E
M8V]D960@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1W8GAM
M;"`@5&AE(%="6$U,(&1O8W5M96YT('1O(&1E8V]D92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(&1E8V]D960@6$U,(&1O8W5M96YT+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!D96-O9&54;U-T<FEN9R@D=V)X;6PI"B`@
M("!["B`@("`@("`@)'1H:7,M/E]C:"`]("9N97<@6$U,7U="6$U,7T-O;G1E
M;G1(86YD;&5R*"D["@H@("`@("`@("1R(#T@)'1H:7,M/F1E8V]D92@D=V)X
M;6PI.PH@("`@("`@(&EF("AI<U]A*"1R+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?8V@M/F=E=$]U='!U="@I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@5&%K97,@82!70EA-3"!I;G!U="!D;V-U;65N="!A;F0@9&5C;V1E<R!I
M="X*("`@("`J($1E8V]D:6YG(')E<W5L="!I<R!D:7)E8W1L>2!P87-S960@
M=&\@=&AE(&-O;G1E;G1(86YD;&5R+@H@("`@("H@02!C;VYT96YT:&%N9&QE
M<B!M=7-T(&)E('-E="!U<VEN9R!S971#;VYT96YT2&%N9&QE<@H@("`@("H@
M<')I;W(@=&\@:6YV;V-A=&EO;B!O9B!T:&ES(&UE=&AO9`H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'=B>&UL("!4:&4@5T)834P@9&]C=6UE;G0@
M=&\@9&5C;V1E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@
M;VX@<W5C8V5S<R!O<B!014%27T5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!D96-O9&4H)'=B>&UL*0H@("`@>PH@("`@("`@("1T:&ES+3Y?97)R;W(@
M/2!F86QS93L@+R\@<F5S970@<W1A=&4*"B`@("`@("`@)'1H:7,M/E]S=')P
M;W,@/2`P.PH*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]C:"DI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=.;R!#;VYT96YT
M:&%N9&QE<B!D969I;F5D+B<I.PH@("`@("`@('T*"B`@("`@("`@+R\@1V5T
M(%9E<G-I;VX@3G5M8F5R(&9R;VT@4V5C=&EO;B`U+C0*("`@("`@("`O+R!V
M97)S:6]N(#T@=5]I;G0X"B`@("`@("`@+R\@8W5R<F5N=&QY(#$L(#(@;W(@
M,PH@("`@("`@("1T:&ES+3Y?=V)X;6Q697)S:6]N(#T@)'1H:7,M/F=E=%9E
M<G-I;VY.=6UB97(H)'=B>&UL*3L*"B`@("`@("`@+R\@1V5T($1O8W5M96YT
M(%!U8FQI8R!)9&5T:69I97(@9G)O;2!396-T:6]N(#4N-0H@("`@("`@("\O
M('!U8FQI8VED(#T@;6)?=5]I;G0S,B!\("AZ97)O(&EN9&5X*0H@("`@("`@
M("\O('IE<F\@/2!U7VEN=#@*("`@("`@("`O+R!#;VYT86EN:6YG('1H92!V
M86QU92!Z97)O("@P*0H@("`@("`@("\O(%1H92!A8W1U86P@1%!)(&ES(&1E
M=&5R;6EN960@869T97(@=&AE(%-T<FEN9R!486)L92!I<R!R96%D+@H@("`@
M("`@("1D<&E3=')U8W0@/2`D=&AI<RT^9V5T1&]C=6UE;G10=6)L:6-)9&5N
M=&EF:65R*"1W8GAM;"D["@H@("`@("`@("\O($=E="!#:&%R<V5T(&9R;VT@
M-2XV"B`@("`@("`@+R\@8VAA<G-E="`](&UB7W5?:6YT,S(*("`@("`@("`D
M=&AI<RT^7V-H87)S970@/2`D=&AI<RT^9V5T0VAA<G-E="@D=V)X;6PI.PH*
M("`@("`@("`O+R!'970@4W1R:6YG(%1A8FQE(&9R;VT@-2XW"B`@("`@("`@
M+R\@<W1R8C$@/2!L96YG=&@@*F)Y=&4*("`@("`@("`D=&AI<RT^<F5T<FEE
M=F53=')I;F=486)L92@D=V)X;6PI.PH*("`@("`@("`O+R!'970@1&]C=6UE
M;G0@4'5B;&EC($ED971I9FEE<B!F<F]M(%-E8W1I;VX@-2XU+@H@("`@("`@
M("1T:&ES+3Y?9'!I(#T@)'1H:7,M/F=E=$1O8W5M96YT4'5B;&EC261E;G1I
M9FEE<DEM<&PH)&1P:5-T<G5C=%LG9'!I5'EP92==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&1P:5-T<G5C=%LG9'!I3G5M8F5R)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W-T<FEN9U1A8FQE*3L*"B`@("`@("`@+R\@3F]W('1H92!R96%L
M(&9U;B!B96=I;G,N"B`@("`@("`@+R\@1G)O;2!396-T:6]N<R`U+C(@86YD
M(#4N.`H*"B`@("`@("`@+R\@1&5F875L="!C;VYT96YT(&AA;F1L97(N"B`@
M("`@("`@)'1H:7,M/E]D=&1-86YA9V5R(#T@)FYE=R!834Q?5T)834Q?1%1$
M36%N86=E<B@I.PH*("`@("`@("`O+R!'970@=&AE('-T87)T:6YG($141"X*
M("`@("`@("`D=&AI<RT^7W1A9T141"`]("1T:&ES+3Y?9'1D36%N86=E<BT^
M9V5T26YS=&%N8V4H)'1H:7,M/E]D<&DI.PH*("`@("`@("!I9B`H(21T:&ES
M+3Y?=&%G1%1$*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@G3F\@1%1$(&9O=6YD(&9O<B`G"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+B`D=&AI<RT^7V1P:2`N("<O)PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("X@)&1P:5-T<G5C=%LG9'!I3G5M8F5R)UTI.PH@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/E]A='1R:6)U=&5$5$0@/2`D=&AI<RT^
M7W1A9T141#L*"B`@("`@("`@=VAI;&4@*&5M<'1Y*"1T:&ES+3Y?97)R;W(I
M("8F("1T:&ES+3Y?<W1R<&]S(#P@<W1R;&5N*"1W8GAM;"DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]D96-O9&4H)'=B>&UL*3L*("`@("`@("!]"B`@("`@
M("`@:68@*"%E;7!T>2@D=&AI<RT^7V5R<F]R*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]E<G)O<CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T5F5R<VEO;DYU;6)E<B@D
M:6YP=70I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YG971">71E*"1I
M;G!U="D["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T1&]C=6UE;G10=6)L:6-)
M9&5N=&EF:65R*"1I;G!U="D*("`@('L*("`@("`@("`D:2`](%A-3%]70EA-
M3#HZ34)526YT,S)4;TEN="@D:6YP=70L("1T:&ES+3Y?<W1R<&]S*3L*("`@
M("`@("!I9B`H)&D@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH
M)V1P:51Y<&4G(#T^(#(L"B`@("`@("`@("`@("`@("`@("`@("`@("`G9'!I
M3G5M8F5R)R`]/B`D=&AI<RT^9V5T0GET92@D:6YP=70I*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@87)R87DH)V1P:51Y<&4G(#T^
M(#$L"B`@("`@("`@("`@("`@("`@("`@("`@("`G9'!I3G5M8F5R)R`]/B`D
M:2D["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&=E=$1O8W5M96YT
M4'5B;&EC261E;G1I9FEE<DEM<&PH)&1P:51Y<&4L("1D<&E.=6UB97(I"B`@
M("!["B`@("`@("`@:68@*"1D<&E4>7!E(#T](#$I('L*("`@("`@("`@("`@
M<F5T=7)N(%A-3%]70EA-3#HZ9V5T1%!)4W1R:6YG*"1D<&E.=6UB97(I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9V5T
M4W1R:6YG5&%B;&5%;G1R>2@D9'!I3G5M8F5R*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C:&%R86-T97(@96YC;V1I
M;F<N($]N;'D@9&5F875L="!C:&%R86-T97(*("`@("`J(&5N8V]D:6YG<R!F
M<F]M($HR4T4@87)E('-U<'!O<G1E9"X@($9R;VT*("`@("`J(&AT='`Z+R]W
M=W<N:6%N82YO<F<O87-S:6=N;65N=',O8VAA<F%C=&5R+7-E=',@86YD"B`@
M("`@*B!H='1P.B\O:F%V82YS=6XN8V]M+VHR<V4O,2XT+C(O9&]C<R]A<&DO
M:F%V82]N:6\O8VAA<G-E="]#:&%R<V5T+FAT;6P*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T0VAA<G-E="@D:6YP=70I"B`@("!["B`@("`@("`@)&-S(#T@
M6$U,7U="6$U,.CI-0E5);G0S,E1O26YT*"1I;G!U="P@)'1H:7,M/E]S=')P
M;W,I.PH@("`@("`@(')E='5R;B!834Q?5T)834PZ.F=E=$-H87)S9713=')I
M;F<H)&-S*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E<R!T:&4@
M<W1R:6YG('1A8FQE+@H@("`@("H@5&AE('-T<FEN9R!T86)L92!C;VYS:7-T
M<R!O9B!A;B!M8E]U7VEN=#,R(&QE;F=T:`H@("`@("H@86YD('1H96X@;&5N
M9W1H(&)Y=&5S(&9O<FUI;F<@=&AE('1A8FQE+@H@("`@("H@4F5F97)E;F-E
M<R!T;R!T:&4@<W1R:6YG('1A8FQE(')E9F5R('1O('1H90H@("`@("H@<W1A
M<G1I;F<@<&]S:71I;VX@;V8@=&AE("AN=6QL('1E<FUI;F%T960I"B`@("`@
M*B!S=')I;F<@:6X@=&AI<R!T86)L92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F5T<FEE=F53=')I;F=486)L92@D:6YP=70I"B`@("!["B`@("`@("`@)'-I
M>F4@/2!834Q?5T)834PZ.DU"54EN=#,R5&]);G0H)&EN<'5T+"`D=&AI<RT^
M7W-T<G!O<RD["B`@("`@("`@)'1H:7,M/E]S=')I;F=486)L92`]('-U8G-T
M<B@D:6YP=70L("1T:&ES+3Y?<W1R<&]S+"`D<VEZ92D["B`@("`@("`@)'1H
M:7,M/E]S=')P;W,@*ST@)'-I>F4["B`@("`@("`@+R\@<')I;G0@(G-T<FEN
M9W1A8FQE*"1S:7IE*3HB("X@)'1H:7,M/E]S=')I;F=486)L92`N(EQN(CL*
M("`@('T*"B`@("!F=6YC=&EO;B!G9713=')I;F=486)L945N=')Y*"1I;F1E
M>"D*("`@('L*("`@("`@("!I9B`H)&EN9&5X(#X]('-T<FQE;B@D=&AI<RT^
M7W-T<FEN9U1A8FQE*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V5R<F]R(#T*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?8V@M/G)A:7-E17)R;W(H)TEN=F%L
M:60@;V9F<V5T("<@+B`D:6YD97@*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("X@)R!V86QU92!E;F-O=6YT97)E9"!A<F]U;F0@<&]S
M:71I;VX@)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+B`D=&AI<RT^7W-T<G!O<PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+B`G+B!"<F]K96X@=V)X;6P_)RD["B`@("`@("`@("`@(')E
M='5R;B`G)SL*("`@("`@("!]"@H@("`@("`@("\O(&-O<'D@;V8@;65T:&]D
M('1E<FUS='(@8G5T('=I=&AO=70@;6]D:69I8V%T:6]N(&]F('1H:7,M/E]S
M=')P;W,*"B`@("`@("`@)'-T<B`]("<C)SL@+R\@;75S="!S=&%R="!W:71H
M(&YO;F5M<'1Y('-T<FEN9R!T;R!A;&QO=R!A<G)A>2!A8V-E<W,*"B`@("`@
M("`@)&D@/2`P.PH@("`@("`@("1C:"`]("1T:&ES+3Y?<W1R:6YG5&%B;&5;
M)&EN9&5X*RM=.PH@("`@("`@(&EF("AO<F0H)&-H*2`]/2`P*2!["B`@("`@
M("`@("`@(')E='5R;B`G)SL@+R\@9&]N)W0@<F5T=7)N("<C)PH@("`@("`@
M('T*"B`@("`@("`@=VAI;&4@*&]R9"@D8V@I("$](#`I('L*("`@("`@("`@
M("`@)'-T<ELD:2LK72`]("1C:#L*("`@("`@("`@("`@:68@*"1I;F1E>"`^
M/2!S=')L96XH)'1H:7,M/E]S=')I;F=486)L92DI('L*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1C:"`]("1T
M:&ES+3Y?<W1R:6YG5&%B;&5;)&EN9&5X*RM=.PH@("`@("`@('T*("`@("`@
M("`O+R!P<FEN="`B<W1R:6YG('1A8FQE(&5N=')Y.B`D<W1R7&XB.PH@("`@
M("`@(')E='5R;B`D<W1R.PH*("`@('T*"B`@("!F=6YC=&EO;B!?9&5C;V1E
M*"1I;G!U="D*("`@('L*("`@("`@("`D=&]K96X@/2`D=&AI<RT^9V5T0GET
M92@D:6YP=70I.PH@("`@("`@("1S='(@/2`G)SL*"B`@("`@("`@+R\@<')I
M;G0@(G!O<VET:6]N.B`B("X@)'1H:7,M/E]S=')P;W,@+B`B('1O:V5N.B`B
M("X@)'1O:V5N("X@(B!S='(Q,#H@(B`N('-U8G-T<B@D:6YP=70L("1T:&ES
M+3Y?<W1R<&]S+"`Q,"D@+B`B7&XB.R`O+R!`=&]D;SH@<F5M;W9E(&1E8G5G
M(&]U='!U=`H*("`@("`@("!S=VET8V@@*"1T;VME;BD@>PH@("`@("`@(&-A
M<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]35%)?23H*("`@("`@("`@("`@
M+R\@4V5C=&EO;B`U+C@N-"XQ"B`@("`@("`@("`@("1S='(@/2`D=&AI<RT^
M=&5R;7-T<B@D:6YP=70I.PH@("`@("`@("`@("`D=&AI<RT^7V-H+3YC:&%R
M86-T97)S*"1S='(I.PH@("`@("`@("`@("`O+R!P<FEN="`B<W1R.B1S=')<
M;B([("\O($!43T1/(%)E;6]V92!D96)U9R!C;V1E"B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?4U12
M7U0Z"B`@("`@("`@("`@("\O(%-E8W1I;VX@-2XX+C0N,0H@("`@("`@("`@
M("`D>"`](%A-3%]70EA-3#HZ34)526YT,S)4;TEN="@D:6YP=70L("1T:&ES
M+3Y?<W1R<&]S*3L*("`@("`@("`@("`@)'-T<B`]("1T:&ES+3YG9713=')I
M;F=486)L945N=')Y*"1X*3L*("`@("`@("`@("`@)'1H:7,M/E]C:"T^8VAA
M<F%C=&5R<R@D<W1R*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?25\P.@H@("`@("`@(&-A
M<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?25\Q.@H@("`@("`@(&-A
M<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?25\R.@H@("`@("`@("`@
M("`O+R!396-T:6]N(#4N."XT+C(*("`@("`@("`@("`@)'-T<B`]("1T:&ES
M+3YT97)M<W1R*"1I;G!U="D["B`@("`@("`@("`@("1T:&ES+3Y?8V@M/F-H
M87)A8W1E<G,H)'-T<BD["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C
M87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?15A47U1?,#H*("`@("`@("!C
M87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?15A47U1?,3H*("`@("`@("!C
M87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?15A47U1?,CH*("`@("`@("`@
M("`@+R\@4V5C=&EO;B`U+C@N-"XR"B`@("`@("`@("`@("1S='(@/2`D=&AI
M<RT^9V5T4W1R:6YG5&%B;&5%;G1Y*%A-3%]70EA-3#HZ34)526YT,S)4;TEN
M="@D:6YP=70L("1T:&ES+3Y?<W1R<&]S*2D["B`@("`@("`@("`@("1T:&ES
M+3Y?8V@M/F-H87)A8W1E<G,H)'-T<BD["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?15A47S`Z"B`@
M("`@("`@8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%\Q.@H@("`@
M("`@(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?,CH*("`@("`@
M("`@("`@+R\@4V5C=&EO;B`U+C@N-"XR"B`@("`@("`@("`@("1E>'1E;G-I
M;VX@/2`D=&AI<RT^9V5T0GET92@D:6YP=70I.PH@("`@("`@("`@("`D=&AI
M<RT^7V-H+3YC:&%R86-T97)S*"1E>'1E;G-I;VXI.PH@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T5.
M5$E463H*("`@("`@("`@("`@+R\@4V5C=&EO;B`U+C@N-"XS"B`@("`@("`@
M("`@("\O(%5#4RTT(&-H<F%C=&5R(&5N8V]D:6YG/PH@("`@("`@("`@("`D
M96YT:71Y(#T@)'1H:7,M/F5N=&ET>2A834Q?5T)834PZ.DU"54EN=#,R5&])
M;G0H)&EN<'5T+"`D=&AI<RT^7W-T<G!O<RDI.PH*("`@("`@("`@("`@)'1H
M:7,M/E]C:"T^8VAA<F%C=&5R<R@G)B,G("X@)&5N=&ET>2`N("<[)RD["B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%A-3%]70EA-3%]'3$]"
M04Q?5$]+14Y?4$DZ"B`@("`@("`@("`@("\O(%-E8W1I;VX@-2XX+C0N-`H@
M("`@("`@("`@("`O+R!T:')O=R!N97<@24]%>&-E<'1I;VX*("`@("`@("`@
M("`@+R\@9&EE*")70EA-3"!G;&]B86P@=&]K96X@<')O8V5S<VEN9R!I;G-T
M<G5C=&EO;BA022P@(B`K('1O:V5N("L@(BD@:7,@=6YS=7!P;W)T960A7&XB
M*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@6$U,7U="6$U,
M7T=,3T)!3%]43TM%3E],251%4D%,.@H@("`@("`@("`@("`O+R!396-T:6]N
M(#4N."XT+C4*("`@("`@("`@("`@)'-T<B`]("1T:&ES+3YG9713=')I;F=4
M86)L945N=')Y*%A-3%]70EA-3#HZ34)526YT,S)4;TEN="@D:6YP=70L("1T
M:&ES+3Y?<W1R<&]S*2D["B`@("`@("`@("`@("1T:&ES+3YP87)S951A9R@D
M:6YP=70L("1S='(L(&9A;'-E+"!F86QS92D["B`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?3$E415)!
M3%]!.@H@("`@("`@("`@("`O+R!396-T:6]N(#4N."XT+C4*("`@("`@("`@
M("`@)'-T<B`]("1T:&ES+3YG9713=')I;F=486)L945N=')Y*%A-3%]70EA-
M3#HZ34)526YT,S)4;TEN="@D:6YP=70L("1T:&ES+3Y?<W1R<&]S*2D["B`@
M("`@("`@("`@("1T:&ES+3YP87)S951A9R@D:6YP=70L("1S='(L('1R=64L
M(&9A;'-E*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@6$U,
M7U="6$U,7T=,3T)!3%]43TM%3E],251%4D%,7T%#.@H@("`@("`@("`@("`O
M+R!396-T:6]N(#4N."XT+C4*("`@("`@("`@("`@)'-T<B`]("1T:&ES+3YG
M9713=')I;F=486)L945N=')Y*%A-3%]70EA-3#HZ34)526YT,S)4;TEN="@D
M:6YP=70L("1T:&ES+3Y?<W1R<&]S*2D["B`@("`@("`@("`@("1T:&ES+3YP
M87)S951A9R@D:6YP=70L("1S=')I;F<L('1R=64L('1R=64I.PH@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/
M2T5.7TQ)5$5204Q?0SH*("`@("`@("`@("`@+R\@4V5C=&EO;B`U+C@N-"XU
M"B`@("`@("`@("`@("1S='(@/2`D=&AI<RT^9V5T4W1R:6YG5&%B;&5%;G1R
M>2A834Q?5T)834PZ.DU"54EN=#,R5&]);G0H)&EN<'5T+"`D=&AI<RT^7W-T
M<G!O<RDI.PH@("`@("`@("`@("`D=&AI<RT^<&%R<V5486<H)&EN<'5T+"`D
M<W1R+"!F86QS92P@=')U92D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?3U!!455%.@H@("`@("`@
M("`@("`O+R!396-T:6]N(#4N."XT+C8*("`@("`@("`@("`@)'-I>F4@/2!8
M34Q?5T)834PZ.DU"54EN=#,R5&]);G0H)&EN<'5T+"`D=&AI<RT^7W-T<G!O
M<RD["B`@("`@("`@("`@("\O('!R:6YT(")O<&%Q=64@;V8@<VEZ92`D<VEZ
M95QN(CL@+R\@0'1O9&\@<F5M;W9E(&1E8G5G"B`@("`@("`@("`@("1B(#T@
M<W5B<W1R*"1I;G!U="P@)'1H:7,M/E]S=')P;W,L("1S:7IE*3L*("`@("`@
M("`@("`@)'1H:7,M/E]S=')P;W,@*ST@)'-I>F4["@H@("`@("`@("`@("`O
M+R!O<&%Q=64@9&%T82!I;G-I9&4@82`\9&%T83X@96QE;65N="!M87D@;W(@
M;6%Y(&YO="!B90H@("`@("`@("`@("`O+R!A(&YE<W1E9"!W8GAM;"!D;V-U
M;65N="`H9F]R(&5X86UP;&4@9&5V:6YF(&1A=&$I+@H@("`@("`@("`@("`O
M+R!792!F:6YD(&]U="!B>2!C:&5C:VEN9R!T:&4@9FER<W0@8GET92!O9B!T
M:&4@9&%T83H@:68@:70G<PH@("`@("`@("`@("`O+R`Q+"`R(&]R(#,@=V4@
M97AP96-T(&ET('1O(&)E('1H92!V97)S:6]N(&YU;6)E<B!O9B!A('=B>&UL
M"B`@("`@("`@("`@("\O(&1O8W5M96YT(&%N9"!T:'5S('-T87)T(&$@;F5W
M('=B>&UL(&1E8V]D97(@:6YS=&%N8V4@;VX@:70N"@H@("`@("`@("`@("!I
M9B`H)'1H:7,M/E]I<T1A=&$@)B8@;W)D*"1B*2`\/2`Q,"D@>PH@("`@("`@
M("`@("`@("`@)&1E8V]D97(@/2`F;F5W(%A-3%]70EA-3%]$96-O9&5R*'1R
M=64I.PH@("`@("`@("`@("`@("`@)&1E8V]D97(M/G-E=$-O;G1E;G1(86YD
M;&5R*"1T:&ES+3Y?8V@I.PH@("`@("`@("`@("`@("`@)',@/2`D9&5C;V1E
M<BT^9&5C;V1E*"1B*3L*("`@("`@("`O+R`@("`@("`@("`@("`@("`O*B`O
M+R!`=&]D;SH@1DE8344@8W5R<F5N=&QY('=E(&-A;B=T(&1E8V]D92!.;VMI
M80H@("`@("`@("`@("`@("`@+R\@1&5V26YF(&1A=&$N(%-O(&EG;F]R92!E
M<G)O<B!F;W(@=&AE('1I;64@8F5E:6YG+@H@("`@("`@(&EF("AI<U]A*"1S
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]E<G)O<B`]("1S.PH@("`@("`@("`@("`@("`@("`@(')E='5R;CL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("\O("HO"B`@("`@("`@
M("`@("`@("`O+R`D=&AI<RT^7V-H+3YC:&%R86-T97)S*"1S*3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\J(&YO<FUA;"!O<&%Q
M=64@8F5H879I;W5R.B!J=7-T(&-O<'D@=&AE(')A=R!D871A.B`J+PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]C:"T^8VAA<F%C=&5R<R@@)&(I.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O+R!O;&0@87!P<F]A8V@@=&\@9&5A
M;"!W:71H(&]P87%U92!D871A(&EN<VED92!#;VYT96YT2&%N9&QE<CH*("`@
M("`@("`@("`@+R\@1DE8344@3W!A<75E(&ES('5S960@8GD@4UE.0TU,+B`@
M3W!A<75E(&1A=&$@=&AA="!D97!E;F1S(&]N('1H92!C;VYT97AT"B`@("`@
M("`@("`@("\O(&EF("AC;VYT96YT2&%N9&QE<B!I;G-T86YC96]F($]P87%U
M94-O;G1E;G1(86YD;&5R*2!["B`@("`@("`@("`@("\O("`@("`H*$]P87%U
M94-O;G1E;G1(86YD;&5R*6-O;G1E;G1(86YD;&5R*2YO<&%Q=64H8BD["B`@
M("`@("`@("`@("\O('T@96QS92!["B`@("`@("`@("`@("\O("`@("!3=')I
M;F<@<W1R(#T@;F5W(%-T<FEN9RAB+"`P+"!S:7IE+"!C:&%R<V5T*3L*("`@
M("`@("`@("`@+R\@("`@(&-H87);72!C:&%R<R`]('-T<BYT;T-H87)!<G)A
M>2@I.PH*("`@("`@("`@("`@+R\@("`@(&-O;G1E;G1(86YD;&5R+F-H87)A
M8W1E<G,H8VAA<G,L(#`L(&-H87)S+FQE;F=T:"D["B`@("`@("`@("`@("\O
M('T*"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%A-3%]70EA-
M3%]'3$]"04Q?5$]+14Y?14Y$.@H@("`@("`@("`@("`O+R!396-T:6]N(#4N
M."XT+C<N,0H@("`@("`@("`@("`D<W1R(#T@)'1H:7,M/F5N9%1A9R@I.PH@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!834Q?5T)834Q?1TQ/
M0D%,7U1/2T5.7U-7251#2%]004=%.@H@("`@("`@("`@("`O+R!396-T:6]N
M(#4N."XT+C<N,@H@("`@("`@("`@("`D8V]D95!A9V4@/2`D=&AI<RT^9V5T
M0GET92@D:6YP=70I.PH@("`@("`@("`@("`O+R!P<FEN="`B<W=I=&-H('1O
M(&-O9&5P86=E("1C;V1E4&%G95QN(CL@+R\@0'1O9&\Z(')E;6]V92!D96)U
M9R!C;V1E"B`@("`@("`@("`@("1T:&ES+3YS=VET8VA%;&5M96YT0V]D95!A
M9V4H)&-O9&5086=E*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@("\O(%-E8W1I;VX@-2XX+C(*("`@("`@("`@
M("`@+R\@4V5C=&EO;B`U+C@N,PH@("`@("`@("`@("`D:&%S071T<FEB=71E
M<R`]("@H)'1O:V5N("8@,'@X,"D@(3T@,"D["B`@("`@("`@("`@("1H87-#
M;VYT96YT(#T@*"@D=&]K96X@)B`P>#0P*2`A/2`P*3L*("`@("`@("`@("`@
M)')E86Q4;VME;B`]("1T;VME;B`F(#!X,T8["B`@("`@("`@("`@("1S='(@
M/2`D=&AI<RT^9V5T5&%G*"1R96%L5&]K96XI.PH*("`@("`@("`@("`@+R\@
M<')I;G0@(F5L96UE;G0Z)'-T<EQN(CL@+R\@0%1/1$\@4F5M;W9E(&1E8G5G
M(&-O9&4*("`@("`@("`@("`@)'1H:7,M/G!A<G-E5&%G*"1I;G!U="P@)'-T
M<BP@)&AA<T%T=')I8G5T97,L("1H87-#;VYT96YT*3L*"B`@("`@("`@("`@
M(&EF("@D<F5A;%1O:V5N(#T](#!X,&8I('L*("`@("`@("`@("`@("`@("\O
M('-T;W)E(&EF('=E)W)E(&EN<VED92!A($1A=&$@=&%G+B!4:&ES(&UA>2!C
M;VYT86EN"B`@("`@("`@("`@("`@("`O+R!A;B!A9&1I=&EO;F%L(&5N8VQO
M<V5D('=B>&UL(&1O8W5M96YT(&]N('=H:6-H('=E(&AA=F4*("`@("`@("`@
M("`@("`@("\O('1O(')U;B!A('-E<&5R871E(&5N8V]D97(*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?:7-$871A(#T@=')U93L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?:7-$871A(#T@9F%L<V4[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@
M("`@?0H*("`@(&9U;F-T:6]N('!A<G-E5&%G*"1I;G!U="P@)'1A9RP@)&AA
M<T%T=')I8G5T97,L("1H87-#;VYT96YT*0H@("`@>PH@("`@("`@("1A='1R
M<R`](&%R<F%Y*"D["B`@("`@("`@:68@*"1H87-!='1R:6)U=&5S*2!["B`@
M("`@("`@("`@("1A='1R<R`]("1T:&ES+3YG971!='1R:6)U=&5S*"1I;G!U
M="D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-H+3YS=&%R=$5L96UE
M;G0H)'1H:7,M/F=E=$-U<G)E;G154DDH*2P@)'1A9RP@)&%T=')S*3L*"B`@
M("`@("`@:68@*"1H87-#;VYT96YT*2!["B`@("`@("`@("`@("\O($9)6$U%
M($D@9F]R9V]T('=H870@9&]E<R!T:&ES(&1O97,N($YO="!S=7)E(&EF('1H
M:7,@:7,*("`@("`@("`@("`@+R\@<FEG:'0_"B`@("`@("`@("`@("1T:&ES
M+3Y?=&%G4W1A8VM;72`]("1T86<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'1H:7,M/E]C:"T^96YD16QE;65N="@D=&AI<RT^9V5T0W5R<F5N
M=%5222@I+"`D=&%G*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@
M96YD5&%G*"D*("`@('L*("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]T86=3
M=&%C:RDI('L*("`@("`@("`@("`@)'1A9R`](&%R<F%Y7W!O<"@D=&AI<RT^
M7W1A9U-T86-K*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&%G
M(#T@)U5N:VYO=VXG.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]C:"T^
M96YD16QE;65N="@D=&AI<RT^9V5T0W5R<F5N=%5222@I+"`D=&%G*3L*"B`@
M("`@("`@<F5T=7)N("1T86<["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T071T
M<FEB=71E<R@D:6YP=70I"B`@("!["B`@("`@("`@)'1H:7,M/G-T87)T1V5T
M071T<FEB=71E<R@I.PH@("`@("`@("1H87--;W)E071T<FEB=71E<R`]('1R
M=64["@H@("`@("`@("1A='1R<R`](&%R<F%Y*"D["B`@("`@("`@)&%T='(@
M/2!N=6QL.PH@("`@("`@("1V86QU92`](&YU;&P["B`@("`@("`@)'1O:V5N
M(#T@;G5L;#L*"B`@("`@("`@=VAI;&4@*"1H87--;W)E071T<FEB=71E<RD@
M>PH@("`@("`@("`@("`D=&]K96X@/2`D=&AI<RT^9V5T0GET92@D:6YP=70I
M.PH*("`@("`@("`@("`@<W=I=&-H("@D=&]K96XI('L*("`@("`@("`@("`@
M+R\@071T<FEB=71E('-P96-I9FEE9"X*("`@("`@("`@("`@8V%S92!834Q?
M5T)834Q?1TQ/0D%,7U1/2T5.7TQ)5$5204PZ"B`@("`@("`@("`@("`@("`O
M+R!396-T:6]N(#4N."XT+C4*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M871T<BDI('L*("`@("`@("`@("`@("`@("`@("`D871T<G-;72`](&%R<F%Y
M*"=A='1R:6)U=&4G(#T^("1A='1R+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W9A;'5E)R`]/B`D=F%L=64I.PH@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@("1A='1R(#T@)'1H:7,M/F=E=%-T
M<FEN9U1A8FQE16YT<GDH6$U,7U="6$U,.CI-0E5);G0S,E1O26YT*"1I;G!U
M="P@)'1H:7,M/E]S=')P;W,I*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@+R\@5F%L=64@<W!E8VEF:65D+@H@("`@("`@("`@("!C
M87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?15A47TE?,#H*("`@("`@("`@
M("`@8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%])7S$Z"B`@("`@
M("`@("`@(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?25\R.@H@
M("`@("`@("`@("`@("`@+R\@4V5C=&EO;B`U+C@N-"XR"B`@("`@("`@("`@
M("`@("`D=F%L=64@+CT@)'1H:7,M/G1E<FUS='(H)&EN<'5T*3L*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92!834Q?5T)834Q?
M1TQ/0D%,7U1/2T5.7T585%]47S`Z"B`@("`@("`@("`@(&-A<V4@6$U,7U="
M6$U,7T=,3T)!3%]43TM%3E]%6%1?5%\Q.@H@("`@("`@("`@("!C87-E(%A-
M3%]70EA-3%]'3$]"04Q?5$]+14Y?15A47U1?,CH*("`@("`@("`@("`@("`@
M("\O(%-E8W1I;VX@-2XX+C0N,@H@("`@("`@("`@("`@("`@)'9A;'5E("X]
M("1T:&ES+3YG9713=')I;F=486)L945N=')Y*%A-3%]70EA-3#HZ34)526YT
M,S)4;TEN="@D:6YP=70L("1T:&ES+3Y?<W1R<&]S*2D["B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@6$U,7U="6$U,7T=,3T)!
M3%]43TM%3E]%6%1?,#H*("`@("`@("`@("`@8V%S92!834Q?5T)834Q?1TQ/
M0D%,7U1/2T5.7T585%\Q.@H@("`@("`@("`@("!C87-E(%A-3%]70EA-3%]'
M3$]"04Q?5$]+14Y?15A47S(Z"B`@("`@("`@("`@("`@("`O+R!396-T:6]N
M(#4N."XT+C(*("`@("`@("`@("`@("`@("1V86QU92`N/2`D:6YP=71;)'1H
M:7,M/E]S=')P;W,K*UT["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%3E1)5%DZ"B`@
M("`@("`@("`@("`@("`O+R!396-T:6]N(#4N."XT+C,*("`@("`@("`@("`@
M("`@("1V86QU92`N/2`D=&AI<RT^96YT:71Y*%A-3%]70EA-3#HZ34)526YT
M,S)4;TEN="@D:6YP=70L("1T:&ES+3Y?<W1R<&]S*2D["B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@6$U,7U="6$U,7T=,3T)!
M3%]43TM%3E]35%)?23H*("`@("`@("`@("`@("`@("\O(%-E8W1I;VX@-2XX
M+C0N,0H@("`@("`@("`@("`@("`@)'9A;'5E("X]("1T:&ES+3YT97)M<W1R
M*"1I;G!U="D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]35%)?5#H*("`@("`@("`@
M("`@("`@("\O(%-E8W1I;VX@-2XX+C0N,0H@("`@("`@("`@("`@("`@)'9A
M;'5E("X]("1T:&ES+3YG9713=')I;F=486)L945N=')Y*%A-3%]70EA-3#HZ
M34)526YT,S)4;TEN="@D:6YP=70L("1T:&ES+3Y?<W1R<&]S*2D["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@6$U,7U="6$U,
M7T=,3T)!3%]43TM%3E]/4$%1544Z"B`@("`@("`@("`@("`@("`O+R!396-T
M:6]N(#4N."XT+C8*("`@("`@("`@("`@("`@("1S:7IE(#T@6$U,7U="6$U,
M.CI-0E5);G0S,E1O26YT*"1I;G!U="P@)'1H:7,M/E]S=')P;W,I.PH@("`@
M("`@("`@("`@("`@)&(@/2!S=6)S='(H)&EN<'5T+"`D=&AI<RT^7W-T<G!O
M<RP@)'1H:7,M/E]S=')P;W,@*R`D<VEZ92D["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7W-T<G!O<R`K/2`D<VEZ93L*"B`@("`@("`@("`@("`@("`D=F%L
M=64@+CT@)&(["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%3D0Z"B`@("`@("`@("`@
M("`@("`O+R!396-T:6]N(#4N."XT+C<N,0H@("`@("`@("`@("`@("`@)&AA
M<TUO<F5!='1R:6)U=&5S(#T@9F%L<V4["B`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&%T='(I*2!["B`@("`@("`@("`@("`@("`@("`@)&%T=')S6UT@
M/2!A<G)A>2@G871T<FEB=71E)R`]/B`D871T<BP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=V86QU92<@/3X@)'9A;'5E*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7U-7251#2%]004=%
M.@H@("`@("`@("`@("`@("`@+R\@4V5C=&EO;B`U+C@N-"XW+C(*("`@("`@
M("`@("`@("`@("1C;V1E4&%G92`]("1T:&ES+3YG971">71E*"1I;G!U="D[
M"B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3Y?<')E=D%T=')I8G5T9414
M1"D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<')E=D%T=')I8G5T
M94141"`]("1T:&ES+3Y?871T<FEB=71E1%1$.PH@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@("1T:&ES+3YS=VET8VA!='1R:6)U=&5#;V1E
M4&%G92@D8V]D95!A9V4I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@:68@*"1T;VME;B`^
M(#$R."D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D871T<BDI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&%T=')S6UT@/2!A<G)A>2@G
M871T<FEB=71E)R`]/B`D871T<BP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=F%L=64G(#T^("1V86QU92D["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1A='1R(#T@)'1H
M:7,M/E]A='1R:6)U=&5$5$0M/G1O071T<FEB=71E*"1T;VME;BD["B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("\O(%9A
M;'5E+@H@("`@("`@("`@("`@("`@("`@("1V86QU92`N/2`D=&AI<RT^7V%T
M=')I8G5T94141"T^=&]!='1R:6)U=&4H)'1O:V5N*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!I9B`H(21T:&ES+3Y?<')E=D%T=')I8G5T9414
M1"D@>PH@("`@("`@("`@("`D=&AI<RT^7V%T=')I8G5T94141"`]("1T:&ES
M+3Y?<')E=D%T=')I8G5T94141#L*("`@("`@("`@("`@)'1H:7,M/E]P<F5V
M071T<FEB=71E1%1$(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^<W1O<$=E=$%T=')I8G5T97,H*3L*("`@('T*"B`@("!F=6YC=&EO;B!S
M=&%R=$=E=$%T=')I8G5T97,H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:7-!
M='1R:6)U=&4@/2!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N('-T;W!'971!
M='1R:6)U=&5S*"D*("`@('L*("`@("`@("`D=&AI<RT^7VES071T<FEB=71E
M(#T@9F%L<V4["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T0W5R<F5N=%5222@I
M"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?:7-!='1R:6)U=&4I('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&%G1%1$+3YG97154DDH*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]A='1R
M:6)U=&5$5$0M/F=E=%5222@I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC
M=&EO;B!W<FET95-T<FEN9R@D<W1R*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M8V@M/F-H87)A8W1E<G,H)'-T<BD["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M5&%G*"1T86<I"B`@("!["B`@("`@("`@+R\@4VAO=6QD(&MN;W<@=VAI8V@@
M<W1A=&4@:70@:7,@:6XN"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&%G1%1$
M+3YT;U1A9U-T<B@D=&%G*3L*("`@('T*"B`@("!F=6YC=&EO;B!G971!='1R
M:6)U=&4H)&%T=')I8G5T92D*("`@('L*("`@("`@("`O+R!3:&]U;&0@:VYO
M=R!W:&EC:"!S=&%T92!I="!I<R!I;BX*("`@("`@("`D=&AI<RT^7V%T=')I
M8G5T94141"T^=&]!='1R:6)U=&5);G0H)&%T=')I8G5T92D["B`@("!]"@H@
M("`@9G5N8W1I;VX@<W=I=&-H16QE;65N=$-O9&5086=E*"1C;V1E4&%G92D*
M("`@('L*("`@("`@("`D=&AI<RT^7W1A9T141"`]("8D=&AI<RT^7V1T9$UA
M;F%G97(M/F=E=$EN<W1A;F-E*"1T:&ES+3Y?=&%G1%1$+3YT;T-O9&5086=E
M4W1R*"1C;V1E4&%G92DI.PH@("`@("`@("1T:&ES+3YS=VET8VA!='1R:6)U
M=&5#;V1E4&%G92@D8V]D95!A9V4I.PH@("`@?0H*("`@(&9U;F-T:6]N('-W
M:71C:$%T=')I8G5T94-O9&5086=E*"1C;V1E4&%G92D*("`@('L*("`@("`@
M("`D=&AI<RT^7V%T=')I8G5T94141"`]("8D=&AI<RT^7V1T9$UA;F%G97(M
M/F=E=$EN<W1A;F-E*"1T:&ES+3Y?871T<FEB=71E1%1$+3YT;T-O9&5086=E
M4W1R*"1C;V1E4&%G92DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M('1H92!H97@@=F5R<VEO;B!O9B!T:&4@8F%S92`Q,"`D96YT:71Y+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!E;G1I='DH)&5N=&ET>2D*("`@('L*("`@("`@
M("!R971U<FX@9&5C:&5X*"1E;G1I='DI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5A9',@82!N=6QL('1E<FUI;F%T960@<W1R:6YG+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!T97)M<W1R*"1I;G!U="D*("`@('L*("`@("`@("`D<W1R
M(#T@)R,G.R`O+R!M=7-T('-T87)T('=I=&@@;F]N96UP='D@<W1R:6YG('1O
M(&%L;&]W(&%R<F%Y(&%C8V5S<PH@("`@("`@("1I(#T@,#L*("`@("`@("`D
M8V@@/2`D:6YP=71;)'1H:7,M/E]S=')P;W,K*UT["B`@("`@("`@:68@*&]R
M9"@D8V@I(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N("<G.R`O+R!D;VXG
M="!R971U<FX@)R,G"B`@("`@("`@?0H@("`@("`@('=H:6QE("AO<F0H)&-H
M*2`A/2`P*2!["B`@("`@("`@("`@("1S=');)&DK*UT@/2`D8V@["B`@("`@
M("`@("`@("1C:"`]("1I;G!U=%LD=&AI<RT^7W-T<G!O<RLK73L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D<W1R.PH@("`@?0H*?0H*````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+UA-3"]70EA-3"]$5$0O````````
M````````````````````````````````````````````````````````````
M```````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q
M-30S,S<T-0`P,C`S-S$`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O6$U,
M+U="6$U,+T141"]3>6YC34PN<&AP````````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`W,3,S`#$P-3$U-#,S-S0U`#`R,C(U,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`H*:6YC;'5D95]O
M;F-E("=834PO5T)834PO1%1$+G!H<"<["@HO*BH*("H@)$AO<F1E.B!F<F%M
M97=O<FLO6$U,7U="6$U,+U="6$U,+T141"]3>6YC34PN<&AP+'8@,2XV+C$R
M+C4@,C`P-B\P,R\Q,2`P.3HU-3HQ,B!J86X@17AP("0*("H*("H@1G)O;2!"
M:6YA<GD@6$U,($-O;G1E;G0@1F]R;6%T(%-P96-I9FEC871I;VX@5F5R<VEO
M;B`Q+C,L(#(U($IU;'D@,C`P,0H@*B!F;W5N9"!A="!H='1P.B\O=W=W+G=A
M<&9O<G5M+F]R9PH@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($%N=&AO;GD@
M36EL;',@/&%M:6QL<T!P>7)A;6ED-BYC;VT^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0'!A8VMA9V4@6$U,7U="6$U,"B`J+PIC;&%S<R!834Q?5T)834Q?1%1$
M7U-Y;F--3"!E>'1E;F1S(%A-3%]70EA-3%]$5$0@>PH*("`@(&9U;F-T:6]N
M(&EN:70H*0H@("`@>PH@("`@("`@("\J('1H:7,@8V]D92!T86)L92!H87,@
M8F5E;B!E>'1R86-T960@9G)O;2!L:6)W8GAM;`H@("`@("`@("`J("AS964@
M:'1T<#HO+VQI8G=B>&UL+F%Y;65R:6-K+F-O;2\I(&)Y('5S:6YG"B`@("`@
M("`@("H*("`@("`@("`@*B!G<F5P("=<(EM>7")=*EPB+"`J,'@N+BP@,'@N
M+B!]+"<@=V)X;6Q?=&%B;&5S+F,*("`@("`@("`@*B!\('-E9"`M92`G<R->
M+BI<(EPH6UY<(ETJ7"E<(BP@*EPH,'@N+EPI+"!<*#!X+BY<*2!]+"XJ)",@
M("`@("`@(%PD=&AI<RT^<V5T5&%G7"A<,RP@7")<,5PB7"D[("\O(%PR(V<G
M"B`@("`@("`@("HO"@H@("`@("`@("1T:&ES+3YS971486<H,'@P-2P@(D%D
M9"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#`V+"`B06QE
M<G0B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@P-RP@(D%R
M8VAI=F4B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@P."P@
M(D%T;VUI8R(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#`Y
M+"`B0VAA;"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#!A
M+"`B0VUD(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,&(L
M(")#;61)1"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#!C
M+"`B0VUD4F5F(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X
M,&0L(")#;W!Y(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X
M,&4L(")#<F5D(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X
M,&8L(")$871A(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X
M,3`L(")$96QE=&4B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H
M,'@Q,2P@(D5X96,B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H
M,'@Q,BP@(D9I;F%L(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G
M*#!X,3,L(")'970B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H
M,'@Q-"P@(DET96TB*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H
M,'@Q-2P@(DQA;F<B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H
M,'@Q-BP@(DQO8TYA;64B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS9714
M86<H,'@Q-RP@(DQO8U5222(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E
M=%1A9R@P>#$X+"`B36%P(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T
M5&%G*#!X,3DL(")-87!)=&5M(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^
M<V5T5&%G*#!X,6$L(")-971A(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^
M<V5T5&%G*#!X,6(L(")-<V=)1"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M
M/G-E=%1A9R@P>#%C+"`B37-G4F5F(BD[("\O(#!X,#`*("`@("`@("`D=&AI
M<RT^<V5T5&%G*#!X,60L(").;U)E<W`B*3L@+R\@,'@P,`H@("`@("`@("1T
M:&ES+3YS971486<H,'@Q92P@(DYO4F5S=6QT<R(I.R`O+R`P>#`P"B`@("`@
M("`@)'1H:7,M/G-E=%1A9R@P>#%F+"`B4'5T(BD[("\O(#!X,#`*("`@("`@
M("`D=&AI<RT^<V5T5&%G*#!X,C`L(")297!L86-E(BD[("\O(#!X,#`*("`@
M("`@("`D=&AI<RT^<V5T5&%G*#!X,C$L(")297-P55))(BD[("\O(#!X,#`*
M("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,C(L(")297-U;'1S(BD[("\O(#!X
M,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,C,L(")396%R8V@B*3L@+R\@
M,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@R-"P@(E-E<75E;F-E(BD[
M("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,C4L(")397-S:6]N
M240B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@R-BP@(E-F
M=$1E;"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#(W+"`B
M4V]U<F-E(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,C@L
M(")3;W5R8V52968B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H
M,'@R.2P@(E-T871U<R(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A
M9R@P>#)A+"`B4WEN8R(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A
M9R@P>#)B+"`B4WEN8T)O9'DB*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS
M971486<H,'@R8RP@(E-Y;F-(9'(B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES
M+3YS971486<H,'@R9"P@(E-Y;F--3"(I.R`O+R`P>#`P"B`@("`@("`@)'1H
M:7,M/G-E=%1A9R@P>#)E+"`B5&%R9V5T(BD[("\O(#!X,#`*("`@("`@("`D
M=&AI<RT^<V5T5&%G*#!X,F8L(")487)G9712968B*3L@+R\@,'@P,`H@("`@
M("`@("1T:&ES+3YS971486<H,'@S,"P@(E)E<V5R=F5D(&9O<B!F=71U<F4@
M=7-E(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,S$L(")6
M97)$5$0B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@S,BP@
M(E9E<E!R;W1O(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X
M,S,L(").=6UB97)/9D-H86YG960B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES
M+3YS971486<H,'@S-"P@(DUO<F5$871A(BD[("\O(#!X,#`*"B`@("`@("`@
M:68@*"1T:&ES+3YV97)S:6]N(#T](#`I('L*("`@("`@("`@("`@)'1H:7,M
M/G-E=$-O9&5086=E*#`L("<M+R]364Y#34PO+T141"!3>6YC34P@,2XP+R]%
M3B<L("=S>6YC;6PZ<WEN8VUL,2XP)RD["B`@("`@("`@("`@("1T:&ES+3YS
M971#;V1E4&%G92@Q+"`G+2\O4UE.0TU,+R]$5$0@365T26YF(#$N,"\O14XG
M+"`G<WEN8VUL.FUE=&EN9C$N,"<I.PH@("`@("`@("`@("`D=&AI<RT^<V5T
M55))*"=S>6YC;6PZ<WEN8VUL,2XP)RD["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'1H:7,M/G-E=$-O9&5086=E*#`L("<M+R]364Y#34PO+T14
M1"!3>6YC34P@,2XQ+R]%3B<L("=S>6YC;6PZ<WEN8VUL,2XQ)RD["B`@("`@
M("`@("`@("1T:&ES+3YS971#;V1E4&%G92@Q+"`G+2\O4UE.0TU,+R]$5$0@
M365T26YF(#$N,2\O14XG+"`G<WEN8VUL.FUE=&EN9C$N,2<I.PH@("`@("`@
M("`@("`D=&AI<RT^<V5T55))*"=S>6YC;6PZ<WEN8VUL,2XQ)RD["B`@("`@
M("`@?0H@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O6$U,+U="6$U,+T141"]3>6YC34Q$979);F8N<&AP
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-S0P`#$P-3$U-#,S-S0U`#`R
M,S,U,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`H*:6YC;'5D95]O;F-E("=834PO5T)834PO1%1$+G!H<"<["@HO
M*BH*("H@)$AO<F1E.B!F<F%M97=O<FLO6$U,7U="6$U,+U="6$U,+T141"]3
M>6YC34Q$979);F8N<&AP+'8@,2XT+C$R+C4@,C`P-B\P,R\Q,2`P.3HU-3HR
M,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!!;G1H;VYY
M($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@*@H@*B!&<F]M($)I;F%R
M>2!834P@0V]N=&5N="!&;W)M870@4W!E8VEF:6-A=&EO;B!697)S:6]N(#$N
M,RP@,C4@2G5L>2`R,#`Q"B`J(&9O=6YD(&%T(&AT='`Z+R]W=W<N=V%P9F]R
M=6TN;W)G"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0'!A8VMA9V4@6$U,7U="6$U,
M"B`J+PIC;&%S<R!834Q?5T)834Q?1%1$7U-Y;F--3$1E=DEN9B!E>'1E;F1S
M(%A-3%]70EA-3%]$5$0@>PH*("`@(&9U;F-T:6]N(&EN:70H*0H@("`@>PH@
M("`@("`@("\J('1H:7,@8V]D92!T86)L92!H87,@8F5E;B!E>'1R86-T960@
M9G)O;2!L:6)W8GAM;`H@("`@("`@("`J("AS964@:'1T<#HO+VQI8G=B>&UL
M+F%Y;65R:6-K+F-O;2\I(&)Y('5S:6YG"B`@("`@("`@("H*("`@("`@("`@
M*B!G<F5P("=<(EM>7")=*EPB+"`J,'@N+BP@,'@N+B!]+"<@=V)X;6Q?=&%B
M;&5S+F,*("`@("`@("`@*B!\('-E9"`M92`G<R->+BI<(EPH6UY<(ETJ7"E<
M(BP@*EPH,'@N+EPI+"!<*#!X+BY<*2!]+"XJ)",@("`@("`@(%PD=&AI<RT^
M<V5T5&%G7"A<,RP@7")<,5PB7"D[("\O(%PR(V<G"B`@("`@("`@("HO"@H@
M("`@("`@("1T:&ES+3YS971486<H,'@P-2P@(D-40V%P(BD[("\O(#!X,#`*
M("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,#8L(")#5%1Y<&4B*3L@+R\@,'@P
M,`H@("`@("`@("1T:&ES+3YS971486<H,'@P-RP@(D1A=&%3=&]R92(I.R`O
M+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#`X+"`B1&%T851Y<&4B
M*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@P.2P@(D1E=DE$
M(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,&$L(")$979)
M;F8B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@P8BP@(D1E
M=E1Y<"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#!C+"`B
M1&ES<&QA>4YA;64B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H
M,'@P9"P@(D13365M(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G
M*#!X,&4L(")%>'0B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H
M,'@P9BP@(D9W5B(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P
M>#$P+"`B2'=6(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X
M,3$L(")-86XB*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q
M,BP@(DUA>$=52413:7IE(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T
M5&%G*#!X,3,L(")-87A)1"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E
M=%1A9R@P>#$T+"`B36%X365M(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^
M<V5T5&%G*#!X,34L(")-;V0B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS
M971486<H,'@Q-BP@(D]%32(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E
M=%1A9R@P>#$W+"`B4&%R86U.86UE(BD[("\O(#!X,#`*("`@("`@("`D=&AI
M<RT^<V5T5&%G*#!X,3@L(")0<F]P3F%M92(I.R`O+R`P>#`P"B`@("`@("`@
M)'1H:7,M/G-E=%1A9R@P>#$Y+"`B4G@B*3L@+R\@,'@P,`H@("`@("`@("1T
M:&ES+3YS971486<H,'@Q82P@(E)X+5!R968B*3L@+R\@,'@P,`H@("`@("`@
M("1T:&ES+3YS971486<H,'@Q8BP@(E-H87)E9$UE;2(I.R`O+R`P>#`P"B`@
M("`@("`@)'1H:7,M/G-E=%1A9R@P>#%C+"`B4VEZ92(I.R`O+R`P>#`P"B`@
M("`@("`@)'1H:7,M/G-E=%1A9R@P>#%D+"`B4V]U<F-E4F5F(BD[("\O(#!X
M,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,64L(")3=U8B*3L@+R\@,'@P
M,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q9BP@(E-Y;F-#87`B*3L@+R\@
M,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@R,"P@(E-Y;F-4>7!E(BD[
M("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,C$L(")4>"(I.R`O
M+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#(R+"`B5'@M4')E9B(I
M.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#(S+"`B5F%L16YU
M;2(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#(T+"`B5F5R
M0U0B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@R-2P@(E9E
M<D141"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#(V+"`B
M6$YA;2(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#(W+"`B
M6%9A;"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#(X+"`B
M551#(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,CDL(")3
M=7!P;W)T3G5M8F5R3V9#:&%N9V5S(BD[("\O(#!X,#`*("`@("`@("`D=&AI
M<RT^<V5T5&%G*#!X,F$L(")3=7!P;W)T3&%R9V5/8FIS(BD[("\O(#!X,#`*
M"B`@("`@("`@:68@*"1T:&ES+3YV97)S:6]N(#T](#`I('L*("`@("`@("`@
M("`@)'1H:7,M/G-E=$-O9&5086=E*#`L("<M+R]364Y#34PO+T141"!$979)
M;F8@,2XP+R]%3B<L("=S>6YC;6PZ9&5V:6YF,2XP)RD["B`@("`@("`@("`@
M("1T:&ES+3YS97154DDH)W-Y;F-M;#ID979I;F8Q+C`G*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^<V5T0V]D95!A9V4H,"P@)RTO
M+U-93D--3"\O1%1$($1E=DEN9B`Q+C$O+T5.)RP@)W-Y;F-M;#ID979I;F8Q
M+C$G*3L*("`@("`@("`@("`@)'1H:7,M/G-E=%5222@G<WEN8VUL.F1E=FEN
M9C$N,2<I.PH@("`@("`@('T*("`@('T*"GT*````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]8
M34PO5T)834PO1%1$+U-Y;F--3$UE=$EN9BYP:'``````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#0T,C,`,3`U,34T,S,W-#4`,#(S,S4U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"@II;F-L=61E
M7V]N8V4@)UA-3"]70EA-3"]$5$0N<&AP)SL*"B\J*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]834Q?5T)834PO5T)834PO1%1$+U-Y;F--3$UE=$EN9BYP:'`L
M=B`Q+C0N,3(N-2`R,#`V+S`S+S$Q(#`Y.C4U.C,S(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($%N=&AO;GD@36EL;',@/&%M:6QL<T!P
M>7)A;6ED-BYC;VT^"B`J"B`J($9R;VT@0FEN87)Y(%A-3"!#;VYT96YT($9O
M<FUA="!3<&5C:69I8V%T:6]N(%9E<G-I;VX@,2XS+"`R-2!*=6QY(#(P,#$*
M("H@9F]U;F0@870@:'1T<#HO+W=W=RYW87!F;W)U;2YO<F<*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`<&%C:V%G92!834Q?5T)834P*("HO"F-L87-S(%A-3%]7
M0EA-3%]$5$1?4WEN8TU,365T26YF(&5X=&5N9',@6$U,7U="6$U,7T141"![
M"@H@("`@9G5N8W1I;VX@:6YI="@I"B`@("!["B`@("`@("`@+RH@=&AI<R!C
M;V1E('1A8FQE(&AA<R!B965N(&5X=')A8W1E9"!F<F]M(&QI8G=B>&UL"B`@
M("`@("`@("H@*'-E92!H='1P.B\O;&EB=V)X;6PN87EM97)I8VLN8V]M+RD@
M8GD@=7-I;F<*("`@("`@("`@*@H@("`@("`@("`J(&=R97`@)UPB6UY<(ETJ
M7"(L("HP>"XN+"`P>"XN('TL)R!W8GAM;%]T86)L97,N8PH@("`@("`@("`J
M('P@<V5D("UE("=S(UXN*EPB7"A;7EPB72I<*5PB+"`J7"@P>"XN7"DL(%PH
M,'@N+EPI('TL+BHD(R`@("`@("`@7"1T:&ES+3YS971486=<*%PS+"!<(EPQ
M7")<*3L@+R\@7#(C9R<*("`@("`@("`@*B\*"B`@("`@("`@)'1H:7,M/G-E
M=%1A9R@P>#`U+"`B06YC:&]R(BD[("\O(#!X,#$*("`@("`@("`D=&AI<RT^
M<V5T5&%G*#!X,#8L(")%34DB*3L@+R\@,'@P,0H@("`@("`@("1T:&ES+3YS
M971486<H,'@P-RP@(D9O<FUA="(I.R`O+R`P>#`Q"B`@("`@("`@)'1H:7,M
M/G-E=%1A9R@P>#`X+"`B1G)E94E$(BD[("\O(#!X,#$*("`@("`@("`D=&AI
M<RT^<V5T5&%G*#!X,#DL(")&<F5E365M(BD[("\O(#!X,#$*("`@("`@("`D
M=&AI<RT^<V5T5&%G*#!X,&$L("),87-T(BD[("\O(#!X,#$*("`@("`@("`D
M=&AI<RT^<V5T5&%G*#!X,&(L(")-87)K(BD[("\O(#!X,#$*("`@("`@("`D
M=&AI<RT^<V5T5&%G*#!X,&,L(")-87A-<V=3:7IE(BD[("\O(#!X,#$*("`@
M("`@("`D=&AI<RT^<V5T5&%G*#!X,34L(")-87A/8FI3:7IE(BD[("\O(#!X
M,#$*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,&0L(")-96TB*3L@+R\@,'@P
M,0H@("`@("`@("1T:&ES+3YS971486<H,'@P92P@(DUE=$EN9B(I.R`O+R`P
M>#`Q"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#!F+"`B3F5X="(I.R`O+R`P
M>#`Q"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#$P+"`B3F5X=$YO;F-E(BD[
M("\O(#!X,#$*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,3$L(")3:&%R961-
M96TB*3L@+R\@,'@P,0H@("`@("`@("1T:&ES+3YS971486<H,'@Q,BP@(E-I
M>F4B*3L@+R\@,'@P,0H@("`@("`@("1T:&ES+3YS971486<H,'@Q,RP@(E1Y
M<&4B*3L@+R\@,'@P,0H@("`@("`@("1T:&ES+3YS971486<H,'@Q-"P@(E9E
M<G-I;VXB*3L@+R\@,'@P,0H*("`@("`@("!I9B`H)'1H:7,M/G9E<G-I;VX@
M/3T@,"D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T0V]D95!A9V4H,"P@)RTO
M+U-93D--3"\O1%1$(%-Y;F--3"`Q+C`O+T5.)RP@)W-Y;F-M;#IS>6YC;6PQ
M+C`G*3L*("`@("`@("`@("`@)'1H:7,M/G-E=$-O9&5086=E*#$L("<M+R]3
M64Y#34PO+T141"!-971);F8@,2XP+R]%3B<L("=S>6YC;6PZ;65T:6YF,2XP
M)RD["B`@("`@("`@("`@("1T:&ES+3YS97154DDH)W-Y;F-M;#IM971I;F8Q
M+C`G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^<V5T
M0V]D95!A9V4H,"P@)RTO+U-93D--3"\O1%1$(%-Y;F--3"`Q+C$O+T5.)RP@
M)W-Y;F-M;#IS>6YC;6PQ+C$G*3L*("`@("`@("`@("`@)'1H:7,M/G-E=$-O
M9&5086=E*#$L("<M+R]364Y#34PO+T141"!-971);F8@,2XQ+R]%3B<L("=S
M>6YC;6PZ;65T:6YF,2XQ)RD["B`@("`@("`@("`@("1T:&ES+3YS97154DDH
M)W-Y;F-M;#IM971I;F8Q+C$G*3L*("`@("`@("`@("`@+R\D=&AI<RT^<V5T
M55))*"=S>6YC;6PZ;65T:6YF)RD[("\O(&9O<B!S;VUE(&9U;FYY(')E87-O
M;BP@;&EB=V)X;6P@<')O9'5C97,@;F\@.FUE=&EN9C$N,2!H97)E"B`@("`@
M("`@?0H@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B]834PO5T)834PO1%1$+G!H<```````````````````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8V-#<`,3`U,34T,S,W-#4`,#(Q,3$W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]834Q?5T)834PO5T)834PO
M1%1$+G!H<"QV(#$N-BXQ,BXU(#(P,#8O,#,O,3$@,#DZ-34Z,#$@:F%N($5X
M<"`D"B`J"B`J($9R;VT@0FEN87)Y(%A-3"!#;VYT96YT($9O<FUA="!3<&5C
M:69I8V%T:6]N(%9E<G-I;VX@,2XS+"`R-2!*=6QY(#(P,#$*("H@9F]U;F0@
M870@:'1T<#HO+W=W=RYW87!F;W)U;2YO<F<*("H*("H@0V]P>7)I9VAT(#(P
M,#,M,C`P-B!!;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!P86-K86=E(%A-3%]70EA-3`H@*B\*8VQA
M<W,@6$U,7U="6$U,7T141"!["@H@("`@=F%R("1V97)S:6]N.PH@("`@=F%R
M("1I;G1486=S.PH@("`@=F%R("1I;G1!='1R:6)U=&5S.PH@("`@=F%R("1S
M=')486=S.PH@("`@=F%R("1S=')!='1R:6)U=&5S.PH@("`@=F%R("1I;G1#
M;V1E4&%G97,["B`@("!V87(@)'-T<D-O9&5086=E<SL*("`@('9A<B`D<W1R
M0V]D95!A9V5S55)).PH@("`@=F%R("154DD["B`@("!V87(@)%A-3$Y3.PH@
M("`@=F%R("1$4$D["@H@("`@9G5N8W1I;VX@6$U,7U="6$U,7T141"@D=BD*
M("`@('L*("`@("`@("`D=&AI<RT^=F5R<VEO;B`]("1V.PH@("`@("`@("1T
M:&ES+3YI;FET*"D["B`@("!]"@H@("`@9G5N8W1I;VX@:6YI="@I"B`@("![
M"B`@("!]"@H@("`@9G5N8W1I;VX@<V5T071T<FEB=71E*"1I;G1!='1R:6)U
M=&4L("1S=')!='1R:6)U=&4I"B`@("!["B`@("`@("`@)'1H:7,M/G-T<D%T
M=')I8G5T97-;)'-T<D%T=')I8G5T95T@/2`D:6YT071T<FEB=71E.PH@("`@
M("`@("1T:&ES+3YI;G1!='1R:6)U=&5S6R1I;G1!='1R:6)U=&5=(#T@)'-T
M<D%T=')I8G5T93L*("`@('T*"B`@("!F=6YC=&EO;B!S971486<H)&EN=%1A
M9RP@)'-T<E1A9RD*("`@('L*("`@("`@("`D=&AI<RT^<W1R5&%G<ULD<W1R
M5&%G72`]("1I;G1486<["B`@("`@("`@)'1H:7,M/FEN=%1A9W-;)&EN=%1A
M9UT@/2`D<W1R5&%G.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=$-O9&5086=E
M*"1I;G1#;V1E4&%G92P@)'-T<D-O9&5086=E+"`D<W1R0V]D95!A9V554DDI
M"B`@("!["B`@("`@("`@)'1H:7,M/G-T<D-O9&5086=E<U5225LD<W1R0V]D
M95!A9V554DE=(#T@)&EN=$-O9&5086=E.PH@("`@("`@("1T:&ES+3YS=')#
M;V1E4&%G97-;)'-T<D-O9&5086=E72`]("1I;G1#;V1E4&%G93L*("`@("`@
M("`D=&AI<RT^:6YT0V]D95!A9V5S6R1I;G1#;V1E4&%G95T@/2`D<W1R0V]D
M95!A9V4["B`@("!]"@H@("`@9G5N8W1I;VX@=&]486=3='(H)'1A9RD*("`@
M('L*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/FEN=%1A9W-;)'1A9UTI
M(#\@)'1H:7,M/FEN=%1A9W-;)'1A9UT@.B!F86QS93L*("`@('T*"B`@("!F
M=6YC=&EO;B!T;T%T=')I8G5T95-T<B@D871T<FEB=71E*0H@("`@>PH@("`@
M("`@(')E='5R;B!I<W-E="@D=&AI<RT^:6YT5&%G<ULD871T<FEB=71E72D@
M/R`D=&AI<RT^:6YT5&%G<ULD871T<FEB=71E72`Z(&9A;'-E.PH@("`@?0H*
M("`@(&9U;F-T:6]N('1O0V]D95!A9V53='(H)&-O9&5086=E*0H@("`@>PH@
M("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^:6YT0V]D95!A9V5S6R1C;V1E
M4&%G95TI(#\@)'1H:7,M/FEN=$-O9&5086=E<ULD8V]D95!A9V5=(#H@9F%L
M<V4["B`@("!]"@H@("`@9G5N8W1I;VX@=&]486=);G0H)'1A9RD*("`@('L*
M("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/G-T<E1A9W-;)'1A9UTI(#\@
M)'1H:7,M/G-T<E1A9W-;)'1A9UT@.B!F86QS93L*("`@('T*"B`@("!F=6YC
M=&EO;B!T;T%T=')I8G5T94EN="@D871T<FEB=71E*0H@("`@>PH@("`@("`@
M(')E='5R;B!I<W-E="@D=&AI<RT^<W1R071T<FEB=71E<ULD871T<FEB=71E
M72D@/R`D=&AI<RT^<W1R071T<FEB=71E<ULD871T<FEB=71E72`Z(&9A;'-E
M.PH@("`@?0H*("`@(&9U;F-T:6]N('1O0V]D95!A9V5);G0H)&-O9&5086=E
M*0H@("`@>PH@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^<W1R0V]D95!A
M9V5S6R1C;V1E4&%G95TI(#\@)'1H:7,M/G-T<D-O9&5086=E<ULD8V]D95!A
M9V5=(#H@9F%L<V4["B`@("!]"@H@("`@9G5N8W1I;VX@=&]#;V1E4&%G9552
M22@D=7)I*0H@("`@>PH@("`@("`@("1U<FD@/2!S=')T;VQO=V5R*"1U<FDI
M.PH@("`@("`@(&EF*"%I<W-E="@D=&AI<RT^<W1R0V]D95!A9V5S55))6R1U
M<FE=*2D@>PH@("`@("`@("`@("!D:64H(G5N86)L92!T;R!F:6YD(&-O9&5P
M86=E(&9O<B`D=7)I(5QN(BD["B`@("`@("`@?0H*("`@("`@("`D<F5T(#T@
M:7-S970H)'1H:7,M/G-T<D-O9&5086=E<U5225LD=7)I72D@/R`D=&AI<RT^
M<W1R0V]D95!A9V5S55))6R1U<FE=(#H@9F%L<V4["@H@("`@("`@(')E='5R
M;B`D<F5T.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T=&5R(&9O<B!P<F]P
M97)T>2!V97)S:6]N+@H@("`@("H@0')E='5R;B!686QU92!O9B!P<F]P97)T
M>2!V97)S:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971697)S:6]N*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G9E<G-I;VX["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!3971T97(@9F]R('!R;W!E<G1Y('9E<G-I;VXN"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D=B`@3F5W('9A;'5E(&]F('!R;W!E<G1Y
M('9E<G-I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%9E<G-I;VXH)'8I
M"B`@("!["B`@("`@("`@)'1H:7,M/G9E<G-I;VX@/2`D=CL*("`@('T*"B`@
M("`O*BH*("`@("`J($=E='1E<B!F;W(@<')O<&5R='D@55))+@H@("`@("H@
M0')E='5R;B!686QU92!O9B!P<F]P97)T>2!54DDN"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%5222@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y5
M4DD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971T97(@9F]R('!R;W!E<G1Y
M(%5222X*("`@("`J($!P87)A;2!S=')I;F<@)'4@($YE=R!V86QU92!O9B!P
M<F]P97)T>2!54DDN"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%5222@D=2D*
M("`@('L*("`@("`@("`D=&AI<RT^55))(#T@)'4["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'971T97(@9F]R('!R;W!E<G1Y($1022X*("`@("`J($!R971U
M<FX@5F%L=64@;V8@<')O<&5R='D@1%!)+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971$4$DH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^1%!).PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V5T=&5R(&9O<B!P<F]P97)T>2!$4$DN
M"B`@("`@*B!`<&%R86T@1%!)($YE=R!V86QU92!O9B!P<F]P97)T>2!$4$DN
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$1022@D9"D*("`@('L*("`@("`@
M("`D=&AI<RT^1%!)(#T@)&0["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O6$U,+U="6$U,+T141$UA;F%G97(N<&AP````````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U,34U`#$P-3$U-#,S-S0U`#`R,C0P
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*:6YC;'5D95]O;F-E("=834PO5T)834PO1%1$+U-Y;F--3"YP:'`G
M.PII;F-L=61E7V]N8V4@)UA-3"]70EA-3"]$5$0O4WEN8TU,365T26YF+G!H
M<"<["FEN8VQU9&5?;VYC92`G6$U,+U="6$U,+T141"]3>6YC34Q$979);F8N
M<&AP)SL*"B\J*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]834Q?5T)834PO5T)8
M34PO1%1$36%N86=E<BYP:'`L=B`Q+C,N,3(N,3$@,C`P-B\P-2\P,2`Q,CHP
M-3HQ-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!!;G1H
M;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($9R;VT@0FEN87)Y(%A-3"!#;VYT96YT($9O<FUA="!3<&5C:69I
M8V%T:6]N(%9E<G-I;VX@,2XS+"`R-2!*=6QY"B`J(#(P,#$@9F]U;F0@870@
M:'1T<#HO+W=W=RYW87!F;W)U;2YO<F<*("H*("H@0'!A8VMA9V4@6$U,7U="
M6$U,"B`J+PIC;&%S<R!834Q?5T)834Q?1%1$36%N86=E<B!["@H@("`@+RHJ
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W-T<D141"`]
M(&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D7W-T<D141%5222`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%A-3%]70EA-3%]$5$1-86YA9V5R*"D*("`@('L*
M("`@("`@("`D=&AI<RT^<F5G:7-T97)$5$0H)RTO+U-93D--3"\O1%1$(%-Y
M;F--3"`Q+C`O+T5.)RP@)W-Y;F-M;#IS>6YC;6PQ+C`G+"!N97<@6$U,7U="
M6$U,7T141%]3>6YC34PH,"DI.PH@("`@("`@("1T:&ES+3YR96=I<W1E<D14
M1"@G+2\O4UE.0TU,+R]$5$0@4WEN8TU,(#$N,2\O14XG+"`G<WEN8VUL.G-Y
M;F-M;#$N,2<L(&YE=R!834Q?5T)834Q?1%1$7U-Y;F--3"@Q*2D["@H@("`@
M("`@("1T:&ES+3YR96=I<W1E<D141"@G+2\O4UE.0TU,+R]$5$0@365T26YF
M(#$N,"\O14XG+"`G<WEN8VUL.FUE=&EN9C$N,"<L(&YE=R!834Q?5T)834Q?
M1%1$7U-Y;F--3$UE=$EN9B@P*2D["B`@("`@("`@)'1H:7,M/G)E9VES=&5R
M1%1$*"<M+R]364Y#34PO+T141"!-971);F8@,2XQ+R]%3B<L("=S>6YC;6PZ
M;65T:6YF,2XQ)RP@;F5W(%A-3%]70EA-3%]$5$1?4WEN8TU,365T26YF*#$I
M*3L*"B`@("`@("`@)'1H:7,M/G)E9VES=&5R1%1$*"<M+R]364Y#34PO+T14
M1"!$979);F8@,2XP+R]%3B<L("=S>6YC;6PZ9&5V:6YF,2XP)RP@;F5W(%A-
M3%]70EA-3%]$5$1?4WEN8TU,1&5V26YF*#`I*3L*("`@("`@("`D=&AI<RT^
M<F5G:7-T97)$5$0H)RTO+U-93D--3"\O1%1$($1E=DEN9B`Q+C$O+T5.)RP@
M)W-Y;F-M;#ID979I;F8Q+C$G+"!N97<@6$U,7U="6$U,7T141%]3>6YC34Q$
M979);F8H,2DI.PH@("`@?0H*("`@("\J*@H@("`@("HO"B`@("!F=6YC=&EO
M;B`F9V5T26YS=&%N8V4H)'!U8FQI8TED96YT:69I97(I"B`@("!["B`@("`@
M("`@)'!U8FQI8TED96YT:69I97(@/2!S=')T;VQO=V5R*"1P=6)L:6-)9&5N
M=&EF:65R*3L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]S=')$5$1;)'!U
M8FQI8TED96YT:69I97)=*2D@>PH@("`@("`@("`@("`D9'1D(#T@)B1T:&ES
M+3Y?<W1R1%1$6R1P=6)L:6-)9&5N=&EF:65R73L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D9'1D(#T@;G5L;#L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1D=&0["B`@("!]"@H@("`@+RHJ"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9G971);G-T86YC955222@D=7)I*0H@("`@>PH@("`@("`@("1U<FD@
M/2!S=')T;VQO=V5R*"1U<FDI.PH*("`@("`@("`O+R!S;VUE(&UA;G5A;"!H
M86-K<SH*("`@("`@("!I9B`H)'5R:2`]/2`G<WEN8VUL.G-Y;F-M;"<I('L*
M("`@("`@("`@("`@)'5R:2`]("=S>6YC;6PZ<WEN8VUL,2XP)SL*("`@("`@
M("!]"B`@("`@("`@:68@*"1U<FD@/3T@)W-Y;F-M;#IM971I;F8G*2!["B`@
M("`@("`@("`@("1U<FD@/2`G<WEN8VUL.FUE=&EN9C$N,"<["B`@("`@("`@
M?0H@("`@("`@(&EF("@D=7)I(#T]("=S>6YC;6PZ9&5V:6YF)RD@>PH@("`@
M("`@("`@("`D=7)I(#T@)W-Y;F-M;#ID979I;F8Q+C`G.PH@("`@("`@('T*
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<W1R1%1$55))6R1U<FE=*2D@
M>PH@("`@("`@("`@("`D9'1D(#T@)B1T:&ES+3Y?<W1R1%1$55))6R1U<FE=
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1D=&0@/2!N=6QL.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)&1T9#L*("`@('T*"B`@("`O*BH*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5G:7-T97)$5$0H)'!U8FQI8TED96YT
M:69I97(L("1U<FDL("8D9'1D*0H@("`@>PH@("`@("`@("1P=6)L:6-)9&5N
M=&EF:65R(#T@<W1R=&]L;W=E<B@D<'5B;&EC261E;G1I9FEE<BD["B`@("`@
M("`@)&1T9"T^<V5T1%!)*"1P=6)L:6-)9&5N=&EF:65R*3L*"B`@("`@("`@
M)'1H:7,M/E]S=')$5$1;)'!U8FQI8TED96YT:69I97)=(#T@)&1T9#L*("`@
M("`@("`D=&AI<RT^7W-T<D141%5225MS=')T;VQO=V5R*"1U<FDI72`]("1D
M=&0["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]834PO
M5T)834PO16YC;V1E<BYP:'``````````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,C<W,C``,3`U,34T,S,W-#4`,#(R,#4V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@II;F-L=61E7V]N
M8V4@)UA-3"]70EA-3"YP:'`G.PII;F-L=61E7V]N8V4@)UA-3"]70EA-3"]#
M;VYT96YT2&%N9&QE<BYP:'`G.PII;F-L=61E7V]N8V4@)UA-3"]70EA-3"]$
M5$1-86YA9V5R+G!H<"<["FEN8VQU9&5?;VYC92`G2&]R9&4O4W1R:6YG+G!H
M<"<["@HO*BH*("H@)$AO<F1E.B!F<F%M97=O<FLO6$U,7U="6$U,+U="6$U,
M+T5N8V]D97(N<&AP+'8@,2XR-2XQ,"XQ,R`R,#`V+S`U+S,Q(#$W.C`V.C,W
M('-E;'-K>2!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($%N=&AO
M;GD@36EL;',@/&%M:6QL<T!P>7)A;6ED-BYC;VT^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@1G)O;2!":6YA<GD@6$U,($-O;G1E;G0@1F]R;6%T(%-P96-I9FEC
M871I;VX@5F5R<VEO;B`Q+C,L(#(U($IU;'D*("H@,C`P,2!F;W5N9"!A="!H
M='1P.B\O=W=W+G=A<&9O<G5M+F]R9PH@*@H@*B!`<&%C:V%G92!834Q?5T)8
M34P*("HO"F-L87-S(%A-3%]70EA-3%]%;F-O9&5R(&5X=&5N9',@6$U,7U="
M6$U,7T-O;G1E;G1(86YD;&5R('L*"B`@("!V87(@)%]S=')I;F=S(#T@87)R
M87DH*3L*"B`@("!V87(@)%]S=')I;F=486)L93L*"B`@("!V87(@)%]H87-7
M<FET=&5N2&5A9&5R(#T@9F%L<V4["@H@("`@=F%R("1?9'1D.PH*("`@('9A
M<B`D7V]U='!U="`]("<G.PH*("`@('9A<B`D7W5R:7,@/2!A<G)A>2@I.PH*
M("`@('9A<B`D7W5R:4YU;7,@/2!A<G)A>2@I.PH*("`@('9A<B`D7V-U<G)E
M;G154DD["@H@("`@=F%R("1?<W5B4&%R<V5R(#T@;G5L;#L*("`@('9A<B`D
M7W-U8E!A<G-E<E-T86-K(#T@,#L*"B`@("`O*BH*("`@("`J(%1H92!834P@
M<&%R<V5R+@H@("`@("H*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@
M("`@=F%R("1?<&%R<V5R.PH*("`@("\J*@H@("`@("H@5&AE($141"!-86YA
M9V5R+@H@("`@("H*("`@("`J($!V87(@6$U,7U="6$U,7T141$UA;F%G97(*
M("`@("`J+PH@("`@=F%R("1?9'1D36%N86=E<CL*"B`@("`O*BH*("`@("`J
M($-O;G-T<G5C=&]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!834Q?5T)834Q?
M16YC;V1E<B@I"B`@("!["B`@("`@("`@)'1H:7,M/E]D=&1-86YA9V5R(#T@
M)FYE=R!834Q?5T)834Q?1%1$36%N86=E<B@I.PH@("`@("`@("1T:&ES+3Y?
M<W1R:6YG5&%B;&4@/2`F;F5W(%A-3%]70EA-3%](87-H5&%B;&4H*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%1A:V4@=&AE(&EN<'5T("1X;6P@86YD('1U
M<FX@:70@:6YT;R!70EA-3"X@5&AI<R!I<R!?;F]T7R!T:&4*("`@("`J(&EN
M=&5N9&5D('=A>2!O9B!U<VEN9R!T:&ES(&-L87-S+B!)="!I<R!D97)I=F5D
M(&9R;VT*("`@("`J($-O;G1E;G1H86YD;&5R(&%N9"!O;F4@<VAO=6QD('5S
M92!I="!A<R!A($-O;G1E;G1(86YD;&5R(&%N9`H@("`@("H@<')O9'5C92!T
M:&4@6$U,+7-T<G5C='5R92!W:71H('-T87)T16QE;65N="@I+"!E;F1%;&5M
M96YT*"DL"B`@("`@*B!A;F0@8VAA<F%C=&5R<R@I+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!E;F-O9&4H)'AM;"D*("`@('L*("`@("`@("`O+R!#<F5A=&4@
M=&AE(%A-3"!P87)S97(@86YD('-E="!M971H;V0@<F5F97)E;F-E<RX*("`@
M("`@("`D=&AI<RT^7W!A<G-E<B`]('AM;%]P87)S97)?8W)E871E7VYS*"1T
M:&ES+3Y?8VAA<G-E="D["B`@("`@("`@>&UL7W-E=%]O8FIE8W0H)'1H:7,M
M/E]P87)S97(L("1T:&ES*3L*("`@("`@("!X;6Q?<&%R<V5R7W-E=%]O<'1I
M;VXH)'1H:7,M/E]P87)S97(L(%A-3%]/4%1)3TY?0T%315]&3TQ$24Y'+"!F
M86QS92D["B`@("`@("`@>&UL7W-E=%]E;&5M96YT7VAA;F1L97(H)'1H:7,M
M/E]P87)S97(L("=?<W1A<G1%;&5M96YT)RP@)U]E;F1%;&5M96YT)RD["B`@
M("`@("`@>&UL7W-E=%]C:&%R86-T97)?9&%T85]H86YD;&5R*"1T:&ES+3Y?
M<&%R<V5R+"`G7V-H87)A8W1E<G,G*3L*("`@("`@("!X;6Q?<V5T7W!R;V-E
M<W-I;F=?:6YS=')U8W1I;VY?:&%N9&QE<B@D=&AI<RT^7W!A<G-E<BP@)R<I
M.PH@("`@("`@('AM;%]S971?97AT97)N86Q?96YT:71Y7W)E9E]H86YD;&5R
M*"1T:&ES+3Y?<&%R<V5R+"`G)RD["@H@("`@("`@(&EF("@A>&UL7W!A<G-E
M*"1T:&ES+3Y?<&%R<V5R+"`D>&UL*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H<W!R:6YT9B@G6$U,(&5R<F]R.B`E<R!A="!L
M:6YE("5D)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@>&UL7V5R<F]R7W-T<FEN9RAX;6Q?9V5T7V5R<F]R7V-O9&4H
M)'1H:7,M/E]P87)S97(I*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@>&UL7V=E=%]C=7)R96YT7VQI;F5?;G5M8F5R
M*"1T:&ES+3Y?<&%R<V5R*2DI.PH@("`@("`@('T*"B`@("`@("`@>&UL7W!A
M<G-E<E]F<F5E*"1T:&ES+3Y?<&%R<V5R*3L*"B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?;W5T<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!W:6QL
M('=R:71E('1H92!C;W)R96-T(&AE861E<G,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('=R:71E2&5A9&5R*"1U<FDI"B`@("!["B`@("`@("`@)'1H:7,M/E]D
M=&0@/2`F)'1H:7,M/E]D=&1-86YA9V5R+3YG971);G-T86YC955222@D=7)I
M*3L*("`@("`@("!I9B`H(21T:&ES+3Y?9'1D*2!["B`@("`@("`@("`@("\O
M(%1/1$\Z('!R;W!E<B!E<G)O<B!H86YD;&EN9PH@("`@("`@("`@("!D:64H
M)U5N86)L92!T;R!F:6YD(&1T9"!F;W(@)R`N("1U<FDI.PH@("`@("`@('T*
M("`@("`@("`D9'!I4W1R:6YG(#T@)'1H:7,M/E]D=&0M/F=E=$1022@I.PH*
M("`@("`@("`O+R!3970@5F5R<VEO;B!.=6UB97(@9G)O;2!396-T:6]N(#4N
M-`H@("`@("`@("\O('9E<G-I;VX@/2!U7VEN=#@*("`@("`@("`O+R!C=7)R
M96YT;'D@,2P@,B!O<B`S"B`@("`@("`@)'1H:7,M/G=R:71E5F5R<VEO;DYU
M;6)E<B@D=&AI<RT^7W=B>&UL5F5R<VEO;BD["@H@("`@("`@("\O(%-E="!$
M;V-U;65N="!0=6)L:6,@261E=&EF:65R(&9R;VT@4V5C=&EO;B`U+C4*("`@
M("`@("`O+R!P=6)L:6-I9"`](&UB7W5?:6YT,S(@?"`H('IE<F\@:6YD97@@
M*0H@("`@("`@("\O('IE<F\@/2!U7VEN=#@*("`@("`@("`O+R!C;VYT86EN
M:6YG('1H92!V86QU92!Z97)O("@P*0H@("`@("`@("\O(%1H92!A8W1U86P@
M1%!)(&ES(&1E=&5R;6EN960@869T97(@=&AE(%-T<FEN9R!486)L92!I<R!R
M96%D+@H@("`@("`@("1T:&ES+3YW<FET941O8W5M96YT4'5B;&EC261E;G1I
M9FEE<B@D9'!I4W1R:6YG+"`D=&AI<RT^7W-T<FEN9W,I.PH*("`@("`@("`O
M+R!3970@0VAA<G-E="!F<F]M(#4N-@H@("`@("`@("\O(&-H87)S970@/2!M
M8E]U7VEN=#,R"B`@("`@("`@)'1H:7,M/G=R:71E0VAA<G-E="@D=&AI<RT^
M7V-H87)S970I.PH*("`@("`@("`O+R!3970@4W1R:6YG(%1A8FQE(&9R;VT@
M-2XW"B`@("`@("`@+R\@<W1R8C$@/2!L96YG=&@@*F)Y=&4*("`@("`@("`D
M=&AI<RT^=W)I=&53=')I;F=486)L92@D=&AI<RT^7W-T<FEN9W,L("1T:&ES
M+3Y?8VAA<G-E="P@)'1H:7,M/E]S=')I;F=486)L92D["@H@("`@("`@("1T
M:&ES+3Y?8W5R<F5N=%5222`]("1U<FD["@H@("`@("`@("1T:&ES+3Y?:&%S
M5W)I='1E;DAE861E<B`]('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@=W)I
M=&5697)S:6]N3G5M8F5R*"1V97)S:6]N*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?;W5T<'5T("X](&-H<B@D=F5R<VEO;BD["B`@("!]"@H@("`@9G5N8W1I
M;VX@=W)I=&5$;V-U;65N=%!U8FQI8TED96YT:69I97(H)&1P:5-T<FEN9RP@
M)B1S=')I;F=S*0H@("`@>PH@("`@("`@("1I(#T@6$U,7U="6$U,.CIG971$
M4$E);G0H)&1P:5-T<FEN9RD["@H@("`@("`@(&EF("@D:2`]/2`P*2!["B`@
M("`@("`@("`@("1S=')I;F=S6S!=(#T@)&1P:5-T<FEN9SL*("`@("`@("`@
M("`@)'1H:7,M/E]O=71P=70@+CT@8VAR*#`I.PH@("`@("`@("`@("`D=&AI
M<RT^7V]U='!U="`N/2!C:'(H,"D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@6$U,7U="6$U,.CII;G14;TU"54EN=#,R*"1T:&ES+3Y?;W5T<'5T
M+"`D:2D["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('=R:71E0VAA
M<G-E="@D8VAA<G-E="D*("`@('L*("`@("`@("`D8W,@/2!834Q?5T)834PZ
M.F=E=$-H87)S971);G0H)&-H87)S970I.PH*("`@("`@("!I9B`H)&-S(#T]
M(#`I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=5
M;G-U<'!O<G1E9"!#:&%R<V5T.B`G("X@)&-H87)S970I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(%A-3%]70EA-3#HZ:6YT5&]-0E5);G0S,B@D
M=&AI<RT^7V]U='!U="P@)&-S*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N
M8W1I;VX@=W)I=&53=')I;F=486)L92@D<W1R:6YG<RP@)&-H87)S970L("1S
M=')I;F=486)L92D*("`@('L*("`@("`@("`D<W1R:6YG0GET97,@/2!A<G)A
M>2@I.PH@("`@("`@("1C;W5N="`](#`["B`@("`@("`@9F]R96%C:"`H)'-T
M<FEN9W,@87,@)'-T<BD@>PH@("`@("`@("`@("`D8GET97,@/2`D=&AI<RT^
M7V=E=$)Y=&5S*"1S='(L("1C:&%R<V5T*3L*("`@("`@("`@("`@)'-T<FEN
M9T)Y=&5S(#T@87)R87E?;65R9V4H)'-T<FEN9T)Y=&5S+"`D8GET97,I.PH@
M("`@("`@("`@("`D;G5L;$QE;F=T:"`]("1T:&ES+3Y?861D3G5L;$)Y=&4H
M)&)Y=&5S*3L*("`@("`@("`@("`@)'1H:7,M/E]S=')I;F=486)L92T^<V5T
M*"1S='(L("1C;W5N="D["B`@("`@("`@("`@("1C;W5N="`K/2!C;W5N="@D
M8GET97,I("L@)&YU;&Q,96YG=&@["B`@("`@("`@?0H*("`@("`@("!834Q?
M5T)834PZ.FEN=%1O34)526YT,S(H)'1H:7,M/E]O=71P=70L(&-O=6YT*"1S
M=')I;F=">71E<RDI.PH@("`@("`@("1T:&ES+3Y?;W5T<'5T("X](&EM<&QO
M9&4H)R<L("1S=')I;F=">71E<RD["B`@("!]"@H@("`@9G5N8W1I;VX@=W)I
M=&53=')I;F<H)'-T<BP@)&-S*0H@("`@>PH@("`@("`@("1B>71E<R`]("1T
M:&ES+3Y?9V5T0GET97,H)'-T<BP@)&-S*3L*("`@("`@("`D=&AI<RT^7V]U
M='!U="`N/2!I;7!L;V1E*"<G+"`D8GET97,I.PH@("`@("`@("1T:&ES+3YW
M<FET94YU;&PH)&-S*3L*("`@('T*"B`@("!F=6YC=&EO;B!W<FET94YU;&PH
M)&-H87)S970I"B`@("!["B`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@8VAR
M*#`I.PH@("`@("`@(')E='5R;B`Q.PH@("`@?0H*("`@(&9U;F-T:6]N(%]A
M9&1.=6QL0GET92@F)&)Y=&5S*0H@("`@>PH@("`@("`@("1B>71E<UM=(#T@
M8VAR*#`I.PH@("`@("`@(')E='5R;B`Q.PH@("`@?0H*("`@(&9U;F-T:6]N
M(%]G971">71E<R@D<W1R:6YG+"`D8W,I"B`@("!["B`@("`@("`@)'-T<FEN
M9R`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'-T<FEN9RP@)&-S+"`G=71F
M+3@G*3L*("`@("`@("`D;F)Y=&5S(#T@<W1R;&5N*"1S=')I;F<I.PH*("`@
M("`@("`D8GET97,@/2!A<G)A>2@I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\("1N8GET97,[("1I*RLI('L*("`@("`@("`@("`@)&)Y=&5S6UT@/2`D
M<W1R:6YG>R1I?3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D8GET97,[
M"B`@("!]"@H@("`@9G5N8W1I;VX@7W-P;&ET55))*"1T86<I"B`@("!["B`@
M("`@("`@)'!A<G1S(#T@97AP;&]D92@G.B<L("1T86<I.PH@("`@("`@("1N
M86UE(#T@87)R87E?<&]P*"1P87)T<RD["B`@("`@("`@)'5R:2`](&EM<&QO
M9&4H)SHG+"`D<&%R=',I.PH@("`@("`@(')E='5R;B!A<G)A>2@D=7)I+"`D
M;F%M92D["B`@("!]"@H@("`@9G5N8W1I;VX@<W1A<G1%;&5M96YT*"1U<FDL
M("1N86UE+"`D871T<FEB=71E<RD*("`@('L*("`@("`@("!I9B`H)'1H:7,M
M/E]S=6)087)S97(@/3T@;G5L;"D@>PH@("`@("`@("`@("!I9B`H(21T:&ES
M+3Y?:&%S5W)I='1E;DAE861E<BD@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/G=R:71E2&5A9&5R*"1U<FDI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("@D=&AI<RT^7V-U<G)E;G154DD@(3T@)'5R:2D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/F-H86YG96-O9&5P86=E*"1U<FDI.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&EF("@D=&AI<RT^7W-U8E!A<G-E<B`]/2!N=6QL
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^=W)I=&5486<H)&YA;64L("1A
M='1R:6)U=&5S+"!T<G5E+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]S=6)087)S97(M
M/G-T87)T16QE;65N="@D=7)I+"1N86UE+"`D871T<FEB=71E<RD["B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^
M7W-U8E!A<G-E<E-T86-K*RL["B`@("`@("`@("`@("1T:&ES+3Y?<W5B4&%R
M<V5R+3YS=&%R=$5L96UE;G0H)'5R:2PD;F%M92PD871T<FEB=71E<RD["B`@
M("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]S=&%R=$5L96UE;G0H)'!A
M<G-E<BP@)'1A9RP@)&%T=')I8G5T97,I"B`@("!["B`@("`@("`@;&ES="@D
M=7)I+"`D;F%M92D@/2`D=&AI<RT^7W-P;&ET55))*"1T86<I.PH*("`@("`@
M("`D=&AI<RT^<W1A<G1%;&5M96YT*"1U<FDL("1N86UE+"`D871T<FEB=71E
M<RD["B`@("!]"@H@("`@9G5N8W1I;VX@;W!A<75E*"1O*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?;W5T<'5T("X](&-H<BA834Q?5T)834Q?1TQ/0D%,7U1/
M2T5.7T]005%512D["B`@("`@("`@6$U,7U="6$U,.CII;G14;TU"54EN=#,R
M*"1T:&ES+3Y?;W5T<'5T+"!S=')L96XH)&\I*3L*("`@("`@("`D=&AI<RT^
M7V]U='!U="`N/2`D;SL*("`@('T*"B`@("!F=6YC=&EO;B!C:&%R86-T97)S
M*"1C:&%R<RD*("`@('L*("`@("`@("`D8VAA<G,@/2!T<FEM*"1C:&%R<RD[
M"@H@("`@("`@(&EF("AS=')L96XH)&-H87)S*2D@>PH@("`@("`@("`@("`O
M*B!792!D969I;FET96QY(&1O;B=T('=A;G0@86YY('=H:71E<W!A8V4N("HO
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^7W-U8E!A<G-E<B`]/2!N=6QL*2![
M"B`@("`@("`@("`@("`@("`D:2`]("1T:&ES+3Y?<W1R:6YG5&%B;&4M/F=E
M="@D8VAA<G,I.PH@("`@("`@("`@("`@("`@:68@*"1I("$](&YU;&PI('L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N/2!C:'(H6$U,
M7U="6$U,7T=,3T)!3%]43TM%3E]35%)?5"D["B`@("`@("`@("`@("`@("`@
M("`@6$U,7U="6$U,.CII;G14;TU"54EN=#,R*"1T:&ES+3Y?;W5T<'5T+"`D
M:2D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?;W5T<'5T("X](&-H<BA834Q?5T)834Q?1TQ/0D%,7U1/
M2T5.7U-44E])*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W)I=&53
M=')I;F<H)&-H87)S+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]S=6)087)S97(M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?8VAA<F%C=&5R
M<R@D<&%R<V5R+"`D8VAA<G,I"B`@("!["B`@("`@("`@)'1H:7,M/F-H87)A
M8W1E<G,H)&-H87)S*3L*("`@('T*"B`@("!F=6YC=&EO;B!W<FET951A9R@D
M;F%M92P@)&%T=')S+"`D:&%S0V]N=&5N="P@)&-S*0H@("`@>PH@("`@("`@
M(&EF("@D871T<G,@(3T@;G5L;"`F)B`A8V]U;G0H)&%T=')S*2D@>PH@("`@
M("`@("`@("`D871T<G,@/2!N=6QL.PH@("`@("`@('T*"B`@("`@("`@)'0@
M/2`D=&AI<RT^7V1T9"T^=&]486=);G0H)&YA;64I.PH@("`@("`@(&EF("@D
M="`]/2`M,2D@>PH@("`@("`@("`@("`D:2`]("1T:&ES+3Y?<W1R:6YG5&%B
M;&4M/F=E="@D;F%M92D["B`@("`@("`@("`@(&EF("@D:2`]/2!N=6QL*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&YA
M;64@+B`G(&ES(&YO="!F;W5N9"!I;B!3=')I;F<@5&%B;&4@;W(@1%1$)RD[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I9B`H)&%T
M=')S(#T](&YU;&P@)B8@(21H87-#;VYT96YT*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]O=71P=70@+CT@8VAR*%A-3%]70EA-3%]'3$]"04Q?
M5$]+14Y?3$E415)!3"D["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&%T
M=')S(#T](&YU;&P@)B8@)&AA<T-O;G1E;G0I('L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V]U='!U="`N/2!C:'(H6$U,7U="6$U,7T=,3T)!3%]4
M3TM%3E],251%4D%,7T$I.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1A
M='1R<R`A/2!N=6QL("8F("1H87-#;VYT96YT*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]O=71P=70@+CT@8VAR*%A-3%]70EA-3%]'3$]"04Q?
M5$]+14Y?3$E415)!3%]#*3L*("`@("`@("`@("`@("`@('T@96QS96EF("@D
M871T<G,@(3T@;G5L;"`F)B`A)&AA<T-O;G1E;G0I('L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V]U='!U="`N/2!C:'(H6$U,7U="6$U,7T=,3T)!
M3%]43TM%3E],251%4D%,7T%#*3L*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("!834Q?5T)834PZ.FEN=%1O34)526YT,S(H)'1H:7,M/E]O
M=71P=70L("1I*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(&EF("@D871T<G,@/3T@;G5L;"`F)B`A)&AA<T-O;G1E;G0I
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X](&-H<B@D="D[
M"B`@("`@("`@("`@('T@96QS96EF("@D871T<G,@/3T@;G5L;"`F)B`D:&%S
M0V]N=&5N="D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@
M8VAR*"1T('P@-C0I.PH@("`@("`@("`@("!](&5L<V5I9B`H)&%T=')S("$]
M(&YU;&P@)B8@)&AA<T-O;G1E;G0I('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;W5T<'5T("X](&-H<B@D="!\(#$R."D["B`@("`@("`@("`@('T@96QS
M96EF("@D871T<G,@(3T@;G5L;"`F)B`A)&AA<T-O;G1E;G0I('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X](&-H<B@D="!\(#$Y,BD["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D871T<G,@(3T@
M;G5L;"`F)B!I<U]A<G)A>2@D871T<G,I("8F(&-O=6YT*"1A='1R<RD@/B`P
M*2!["B`@("`@("`@("`@("1T:&ES+3YW<FET94%T=')I8G5T97,H)&%T=')S
M+"`D8W,I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!W<FET94%T
M=')I8G5T97,H)&%T=')S+"`D8W,I"B`@("!["B`@("`@("`@9F]R96%C:"`H
M)&%T=')S(&%S("1N86UE(#T^("1V86QU92D@>PH@("`@("`@("`@("`D=&AI
M<RT^=W)I=&5!='1R:6)U=&4H)&YA;64L("1V86QU92P@)&-S*3L*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3Y?;W5T<'5T("X](&-H<BA834Q?5T)834Q?
M1TQ/0D%,7U1/2T5.7T5.1"D["B`@("!]"@H@("`@9G5N8W1I;VX@=W)I=&5!
M='1R:6)U=&4H)&YA;64L("1V86QU92P@)&-S*0H@("`@>PH@("`@("`@("1A
M(#T@)'1H:7,M/E]D=&0M/G1O071T<FEB=71E*"1N86UE*3L*("`@("`@("!I
M9B`H)&$@/3T@+3$I('L*("`@("`@("`@("`@)&D@/2`D=&AI<RT^7W-T<FEN
M9U1A8FQE+3YG970H)&YA;64I.PH@("`@("`@("`@("!I9B`H)&D@/3T@;G5L
M;"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*"1N86UE("X@)R!I<R!N;W0@9F]U;F0@:6X@4W1R:6YG(%1A8FQE(&]R($14
M1"<I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]O=71P=70@+CT@8VAR*%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?3$E4
M15)!3"D["B`@("`@("`@("`@("`@("!834Q?5T)834PZ.FEN=%1O34)526YT
M,S(H)'1H:7,M/E]O=71P=70L("1I*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X]("1A.PH@
M("`@("`@('T*"B`@("`@("`@)&D@/2`D=&AI<RT^7W-T<FEN9U1A8FQE+3YG
M970H)&YA;64I.PH@("`@("`@(&EF("@D:2`A/2!N=6QL*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?;W5T<'5T("X](&-H<BA834Q?5T)834Q?1TQ/0D%,7U1/
M2T5.7U-44E]4*3L*("`@("`@("`@("`@6$U,7U="6$U,.CII;G14;TU"54EN
M=#,R*"1T:&ES+3Y?;W5T<'5T+"`D:2D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@8VAR*%A-3%]70EA-3%]'3$]"
M04Q?5$]+14Y?4U127TDI.PH@("`@("`@("`@("`D=&AI<RT^=W)I=&53=')I
M;F<H)'9A;'5E+"`D8W,I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO
M;B!E;F1%;&5M96YT*"1U<FDL("1N86UE*0H@("`@>PH@("`@("`@(&EF("@D
M=&AI<RT^7W-U8E!A<G-E<B`]/2!N=6QL*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?;W5T<'5T("X](&-H<BA834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T5.1"D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]S=6)087)S
M97(M/F5N9$5L96UE;G0H)'5R:2P@)&YA;64I.PH@("`@("`@("`@("`D=&AI
M<RT^7W-U8E!A<G-E<E-T86-K+2T["@H@("`@("`@("`@("!I9B`H)'1H:7,M
M/E]S=6)087)S97)3=&%C:R`]/2`P*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V]U='!U="`N/2!C:'(H6$U,7U="6$U,7T=,3T)!3%]43TM%3E]/4$%1
M544I.PH*("`@("`@("`@("`@("`@(%A-3%]70EA-3#HZ:6YT5&]-0E5);G0S
M,B@D=&AI<RT^7V]U='!U="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!S=')L96XH)'1H:7,M/E]S=6)087)S97(M/F=E=$]U
M='!U="@I*2D["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N/2`D
M=&AI<RT^7W-U8E!A<G-E<BT^9V5T3W5T<'5T*"D["@H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]S=6)087)S97(@/2!N=6QL.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]E;F1%;&5M96YT*"1P87)S
M97(L("1T86<I"B`@("!["B`@("`@("`@;&ES="@D=7)I+"`D;F%M92D@/2`D
M=&AI<RT^7W-P;&ET55))*"1T86<I.PH@("`@("`@("1T:&ES+3YE;F1%;&5M
M96YT*"1U<FDL("1N86UE*3L*("`@('T*"B`@("!F=6YC=&EO;B!C:&%N9V5C
M;V1E<&%G92@D=7)I*0H@("`@>PH@("`@("`@("\O($!T;V1O.B!T:&ES(&ES
M(&$@:&%C:R$*("`@("`@("!I9B`H)'1H:7,M/E]D=&0M/F=E=%9E<G-I;VXH
M*2`]/2`Q("8F("%P<F5G7VUA=&-H*"<O,5PN,20O)RP@)'5R:2DI('L*("`@
M("`@("`@("`@)'5R:2`N/2`G,2XQ)SL*("`@("`@("!]"B`@("`@("`@:68@
M*"1T:&ES+3Y?9'1D+3YG971697)S:6]N*"D@/3T@,"`F)B`A<')E9U]M871C
M:"@G+S%<+C`D+R<L("1U<FDI*2!["B`@("`@("`@("`@("1U<FD@+CT@)S$N
M,"<["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@("1C<"`]("1T:&ES+3Y?
M9'1D+3YT;T-O9&5086=E55))*"1U<FDI.PH@("`@("`@(&EF("AS=')L96XH
M)&-P*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V1T9"`]("8D=&AI<RT^7V1T
M9$UA;F%G97(M/F=E=$EN<W1A;F-E55))*"1U<FDI.PH*("`@("`@("`@("`@
M)'1H:7,M/E]O=71P=70@+CT@8VAR*%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?
M4U=)5$-(7U!!1T4I.PH@("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N/2!C
M:'(H)&-P*3L*("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT55))(#T@)'5R
M:3L*"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]S=6)0
M87)S97(@/2`F;F5W(%A-3%]70EA-3%]%;F-O9&5R*'1R=64I.PH@("`@("`@
M("`@("`D=&AI<RT^7W-U8E!A<G-E<E-T86-K(#T@,3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'971T97(@9F]R('!R;W!E<G1Y(&]U='!U
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3W5T<'5T*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]O=71P=70["B`@("!]"@H@("`@9G5N8W1I
M;VX@9V5T3W5T<'5T4VEZ92@I"B`@("!["B`@("`@("`@<F5T=7)N('-T<FQE
M;B@D=&AI<RT^7V]U='!U="D["B`@("!]"@I]"@``````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+UA-3"]70EA-3"YP:'``````````````````````
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,C(P-@`Q,#4Q-30S,S<T-0`P
M,C`T-S$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*"B\J*@H@*B!#;VYS=&%N=',@87)E(&9R;VT@0FEN87)Y(%A-
M3"!#;VYT96YT($9O<FUA="!3<&5C:69I8V%T:6]N(%9E<G-I;VX*("H@,2XS
M+"`R-2!*=6QY(#(P,#$@9F]U;F0@870@:'1T<#HO+W=W=RYW87!F;W)U;2YO
M<F<*("HO"@HO*BH*("H@1G)O;2`W+C$@1VQO8F%L(%1O:V5N<RX*("HO"@ID
M969I;F4H)UA-3%]70EA-3%]'3$]"04Q?5$]+14Y?4U=)5$-(7U!!1T4G+"`P
M*3L@("\O(#!X,#`*9&5F:6YE*"=834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T5.
M1"<L(#$I.R`@("`@("`@("`O+R`P>#`Q"F1E9FEN92@G6$U,7U="6$U,7T=,
M3T)!3%]43TM%3E]%3E1)5%DG+"`R*3L@("`@("`@+R\@,'@P,@ID969I;F4H
M)UA-3%]70EA-3%]'3$]"04Q?5$]+14Y?4U127TDG+"`S*3L@("`@("`@("\O
M(#!X,#,*9&5F:6YE*"=834Q?5T)834Q?1TQ/0D%,7U1/2T5.7TQ)5$5204PG
M+"`T*3L@("`@("`O+R`P>#`T"@ID969I;F4H)UA-3%]70EA-3%]'3$]"04Q?
M5$]+14Y?15A47TE?,"<L(#8T*3L@("`@("\O(#!X-#`*9&5F:6YE*"=834Q?
M5T)834Q?1TQ/0D%,7U1/2T5.7T585%])7S$G+"`V-2D[("`@("`O+R`P>#0Q
M"F1E9FEN92@G6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?25\R)RP@-C8I
M.R`@("`@+R\@,'@T,@ID969I;F4H)UA-3%]70EA-3%]'3$]"04Q?5$]+14Y?
M4$DG+"`V-RD[("`@("`@("`@("\O(#!X-#,*9&5F:6YE*"=834Q?5T)834Q?
M1TQ/0D%,7U1/2T5.7TQ)5$5204Q?0R<L(#8X*3L@("`O+R`P>#0T"@ID969I
M;F4H)UA-3%]70EA-3%]'3$]"04Q?5$]+14Y?15A47U1?,"<L(#$R."D[("`@
M("\O(#!X.#`*9&5F:6YE*"=834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%]4
M7S$G+"`Q,CDI.R`@("`O+R`P>#@Q"F1E9FEN92@G6$U,7U="6$U,7T=,3T)!
M3%]43TM%3E]%6%1?5%\R)RP@,3,P*3L@("`@+R\@,'@X,@ID969I;F4H)UA-
M3%]70EA-3%]'3$]"04Q?5$]+14Y?4U127U0G+"`Q,S$I.R`@("`@("\O(#!X
M.#,*9&5F:6YE*"=834Q?5T)834Q?1TQ/0D%,7U1/2T5.7TQ)5$5204Q?02<L
M(#$S,BD[("`O+R`P>#@T"@ID969I;F4H)UA-3%]70EA-3%]'3$]"04Q?5$]+
M14Y?15A47S`G+"`Q.3(I.R`@("`@("\O(#!X0S`*9&5F:6YE*"=834Q?5T)8
M34Q?1TQ/0D%,7U1/2T5.7T585%\Q)RP@,3DS*3L@("`@("`O+R`P>$,Q"F1E
M9FEN92@G6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?,B<L(#$Y-"D[("`@
M("`@+R\@,'A#,@ID969I;F4H)UA-3%]70EA-3%]'3$]"04Q?5$]+14Y?3U!!
M455%)RP@,3DU*3L@("`@("\O(#!X0S,*9&5F:6YE*"=834Q?5T)834Q?1TQ/
M0D%,7U1/2T5.7TQ)5$5204Q?04,G+"`Q.38I.R`O+R`P>$,T"@HO*BH*("H@
M3F]T('-U<F4@=VAE<F4@9&5F:6YE9"X*("H@041$($-(05!415(*("HO"F1E
M9FEN92@G1%!)7T141%]734Q?,5\P)RP@)RTO+U=!4$9/4E5-+R]$5$0@5TU,
M(#$N,"\O14XG*3L*9&5F:6YE*"=$4$E?1%1$7U=405\Q7S`G+"`G+2\O5T%0
M1D]254TO+T141"!75$$@,2XP+R]%3B<I.PID969I;F4H)T1025]$5$1?5TU,
M7S%?,2<L("<M+R]705!&3U)532\O1%1$(%=-3"`Q+C$O+T5.)RD["F1E9FEN
M92@G1%!)7T141%]325\Q7S$G+"`G+2\O5T%01D]254TO+T141"!322`Q+C$O
M+T5.)RD["F1E9FEN92@G1%!)7T141%]33%\Q7S`G+"`G+2\O5T%01D]254TO
M+T141"!33"`Q+C`O+T5.)RD["F1E9FEN92@G1%!)7T141%]#3U\Q7S`G+"`G
M+2\O5T%01D]254TO+T141"!#3R`Q+C`O+T5.)RD["F1E9FEN92@G1%!)7T14
M1%]#2$%.3D5,7S%?,2<L("<M+R]705!&3U)532\O1%1$($-(04Y.14P@,2XQ
M+R]%3B<I.PID969I;F4H)T1025]$5$1?5TU,7S%?,B<L("<M+R]705!&3U)5
M32\O1%1$(%=-3"`Q+C(O+T5.)RD["F1E9FEN92@G1%!)7T141%]734Q?,5\S
M)RP@)RTO+U=!4$9/4E5-+R]$5$0@5TU,(#$N,R\O14XG*3L*9&5F:6YE*"=$
M4$E?1%1$7U!23U9?,5\P)RP@)RTO+U=!4$9/4E5-+R]$5$0@4%)/5B`Q+C`O
M+T5.)RD["F1E9FEN92@G1%!)7T141%]75$%?5TU,7S%?,B<L("<M+R]705!&
M3U)532\O1%1$(%=402U734P@,2XR+R]%3B<I.PID969I;F4H)T1025]$5$1?
M0TA!3DY%3%\Q7S(G+"`G+2\O5T%01D]254TO+T141"!#2$%.3D5,(#$N,B\O
M14XG*3L*9&5F:6YE*"=$4$E?1%1$7U-93D--3%\Q7S`G+"`G+2\O4UE.0TU,
M+R]$5$0@4WEN8TU,(#$N,"\O14XG*3L*9&5F:6YE*"=$4$E?1%1$7T1%5DE.
M1E\Q7S`G+"`G+2\O4UE.0TU,+R]$5$0@1&5V26YF(#$N,"\O14XG*3L*9&5F
M:6YE*"=$4$E?1%1$7U-93D--3%\Q7S$G+"`G+2\O4UE.0TU,+R]$5$0@4WEN
M8TU,(#$N,2\O14XG*3L*9&5F:6YE*"=$4$E?1%1$7T1%5DE.1E\Q7S$G+"`G
M+2\O4UE.0TU,+R]$5$0@1&5V26YF(#$N,2\O14XG*3L*"B\J*@H@*B!/;FQY
M(&1E9F%U;'0@8VAA<F%C=&5R(&5N8V]D:6YG<R!F<F]M($HR4T4@87)E(&-U
M<G)E;G1L>2!S=7!P;W)T960N"B`J+PID969I;F4H)T-(05)3151?55-?05-#
M24DG+"`G55,M05-#24DG*3L*9&5F:6YE*"=#2$%24T547TE33U\X.#4Y7S$G
M+"`G25-/+3@X-3DM,2<I.PID969I;F4H)T-(05)3151?551&7S@G+"`G551&
M+3@G*3L*9&5F:6YE*"=#2$%24T547U541E\Q-D)%)RP@)U541BTQ-D)%)RD[
M"F1E9FEN92@G0TA!4E-%5%]55$9?,39,12<L("=55$8M,39,12<I.PID969I
M;F4H)T-(05)3151?551&7S$V)RP@)U541BTQ-B<I.PH*+RHJ"B`J($-O<'ER
M:6=H="`R,#`S+3(P,#8@06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V
M+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]8
M34Q?5T)834PO5T)834PN<&AP+'8@,2XQ,RXQ,BXX(#(P,#8O,#,O,3,@,#DZ
M,38Z,C4@:F%N($5X<"`D"B`J"B`J($!P86-K86=E(%A-3%]70EA-3`H@*B\*
M8VQA<W,@6$U,7U="6$U,('L*"B`@("`O*BH*("`@("`J($1E8V]D:6YG($UU
M;'1I+6)Y=&4@26YT96=E<G,@9G)O;2!396-T:6]N(#4N,0H@("`@("H*("`@
M("`J(%5S92!L;VYG(&)E8V%U<V4@:70@:7,@=6YS:6=N960N"B`@("`@*B\*
M("`@(&9U;F-T:6]N($U"54EN=#,R5&]);G0H)&EN+"`F)'!O<RD*("`@('L*
M("`@("`@("`D=F%L(#T@,#L*"B`@("`@("`@9&\@>PH@("`@("`@("`@("`D
M8B`](&]R9"@D:6Y;)'!O<RLK72D["B`@("`@("`@("`@("1V86P@/#P](#<[
M("\O($)I='-H:69T(&QE9G0@-R!B:71S+@H@("`@("`@("`@("`D=F%L("L]
M("@D8B`F(#$R-RD["B`@("`@("`@?2!W:&EL92`H*"1B("8@,3(X*2`A/2`P
M*3L*"B`@("`@("`@<F5T=7)N("1V86P["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!%;F-O9&EN9R!-=6QT:2UB>71E($EN=&5G97)S(&9R;VT@4V5C=&EO;B`U
M+C$*("`@("`J+PH@("`@9G5N8W1I;VX@:6YT5&]-0E5);G0S,B@F)&]U="P@
M)&DI"B`@("!["B`@("`@("`@:68@*"1I(#X@,C8X-#,U-#4U*2!["B`@("`@
M("`@("`@("1B>71E<S`@/2`P('P@6$U,7U="6$U,.CIG971":71S*#`L("1I
M*3L*("`@("`@("`@("`@)&)Y=&5S,2`](#$R."!\(%A-3%]70EA-3#HZ9V5T
M0FET<R@Q+"`D:2D["B`@("`@("`@("`@("1B>71E<S(@/2`Q,C@@?"!834Q?
M5T)834PZ.F=E=$)I=',H,BP@)&DI.PH@("`@("`@("`@("`D8GET97,S(#T@
M,3(X('P@6$U,7U="6$U,.CIG971":71S*#,L("1I*3L*("`@("`@("`@("`@
M)&)Y=&5S-"`](#$R."!\(%A-3%]70EA-3#HZ9V5T0FET<R@T+"`D:2D["@H@
M("`@("`@("`@("`D;W5T("X](&-H<B@D8GET97,T*2`N(&-H<B@D8GET97,S
M*2`N(&-H<B@D8GET97,R*2`N(&-H<B@D8GET97,Q*2`N(&-H<B@D8GET97,P
M*3L*("`@("`@("!](&5L<V5I9B`H)&D@/B`R,#DW,34Q*2!["B`@("`@("`@
M("`@("1B>71E<S`@/2`P('P@6$U,7U="6$U,.CIG971":71S*#`L("1I*3L*
M("`@("`@("`@("`@)&)Y=&5S,2`](#$R."!\(%A-3%]70EA-3#HZ9V5T0FET
M<R@Q+"`D:2D["B`@("`@("`@("`@("1B>71E<S(@/2`Q,C@@?"!834Q?5T)8
M34PZ.F=E=$)I=',H,BP@)&DI.PH@("`@("`@("`@("`D8GET97,S(#T@,3(X
M('P@6$U,7U="6$U,.CIG971":71S*#,L("1I*3L*"B`@("`@("`@("`@("1O
M=70@+CT@8VAR*"1B>71E<S,I("X@8VAR*"1B>71E<S(I("X@8VAR*"1B>71E
M<S$I("X@8VAR*"1B>71E<S`I.PH@("`@("`@('T@96QS96EF("@D:2`^(#$V
M,S@S*2!["B`@("`@("`@("`@("1B>71E<S`@/2`P('P@6$U,7U="6$U,.CIG
M971":71S*#`L("1I*3L*("`@("`@("`@("`@)&)Y=&5S,2`](#$R."!\(%A-
M3%]70EA-3#HZ9V5T0FET<R@Q+"`D:2D["B`@("`@("`@("`@("1B>71E<S(@
M/2`Q,C@@?"!834Q?5T)834PZ.F=E=$)I=',H,BP@)&DI.PH*("`@("`@("`@
M("`@)&]U="`N/2!C:'(H)&)Y=&5S,BD@+B!C:'(H)&)Y=&5S,2D@+B!C:'(H
M)&)Y=&5S,"D["B`@("`@("`@?2!E;'-E:68@*"1I(#X@,3(W*2!["B`@("`@
M("`@("`@("1B>71E<S`@/2`P('P@6$U,7U="6$U,.CIG971":71S*#`L("1I
M*3L*("`@("`@("`@("`@)&)Y=&5S,2`](#$R."!\(%A-3%]70EA-3#HZ9V5T
M0FET<R@Q+"`D:2D["@H@("`@("`@("`@("`D;W5T("X](&-H<B@D8GET97,Q
M*2`N(&-H<B@D8GET97,P*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D8GET97,P(#T@,"!\(%A-3%]70EA-3#HZ9V5T0FET<R@P+"`D:2D["@H@
M("`@("`@("`@("`D;W5T("X](&-H<B@D8GET97,P*3L*("`@("`@("!]"B`@
M("!]"@H@("`@9G5N8W1I;VX@9V5T0FET<R@D;G5M+"`D;"D*("`@('L*("`@
M("`@("!S=VET8V@@*"1N=6TI('L*("`@("`@("!C87-E(#`Z"B`@("`@("`@
M("`@(')E='5R;B`D;"`F(#$R-SL@+R\@,'@W1@H*("`@("`@("!C87-E(#$Z
M"B`@("`@("`@("`@(')E='5R;B`H)&P@/CX@-RD@)B`Q,C<[("\O(#!X-T8*
M"B`@("`@("`@8V%S92`R.@H@("`@("`@("`@("!R971U<FX@*"1L(#X^(#$T
M*2`F(#$R-SL@+R\@,'@W1@H*("`@("`@("!C87-E(#,Z"B`@("`@("`@("`@
M(')E='5R;B`H)&P@/CX@,C$I("8@,3(W.R`O+R`P>#=&"@H@("`@("`@(&-A
M<V4@-#H*("`@("`@("`@("`@<F5T=7)N("@D;"`^/B`R."D@)B`Q,C<[("\O
M(#!X-T8*("`@("`@("!]"@H@("`@("`@(')E='5R;B`P.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=$1025-T<FEN9R@D:2D*("`@('L*("`@("`@("`O*BH*
M("`@("`@("`@*B!!1$0@0TA!4%1%4@H@("`@("`@("`J+PH@("`@("`@("1$
M4$E3=')I;F<@/2!A<G)A>2@R(#T^($1025]$5$1?5TU,7S%?,"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@,R`]/B!$4$E?1%1$7U=405\Q7S`L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#0@/3X@1%!)7T141%]734Q?,5\Q
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`U(#T^($1025]$5$1?4TE?
M,5\Q+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`V(#T^($1025]$5$1?
M4TQ?,5\P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`W(#T^($1025]$
M5$1?0T]?,5\P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`X(#T^($10
M25]$5$1?0TA!3DY%3%\Q7S$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#D@/3X@1%!)7T141%]734Q?,5\R+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Q,"`]/B!$4$E?1%1$7U=-3%\Q7S,L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#$Q(#T^($1025]$5$1?4%)/5E\Q7S`L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#$R(#T^($1025]$5$1?5U1!7U=-3%\Q7S(L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#$S(#T^($1025]$5$1?0TA!3DY%
M3%\Q7S(L"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!.;W0@86QL
M(%-Y;F--3"!C;&EE;G1S(&MN;W<@=&AI<RP@<V\@=V4*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@<VAO=6QD('5S92!T:&4@<W1R:6YG('1A8FQE
M+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R`P>$9$,2`]/B!$4$E?
M1%1$7U-93D--3%\Q7S$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@(#0P
M-#D@/3X@1%!)7T141%]364Y#34Q?,5\P+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`T,#4P(#T^($1025]$5$1?1$5624Y&7S%?,"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@-#`U,2`]/B!$4$E?1%1$7U-93D--3%\Q7S$L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@(#0P-3(@/3X@1%!)7T141%]$
M159)3D9?,5\Q+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@
M("`@(')E='5R;B!I<W-E="@D1%!)4W1R:6YG6R1I72D@/R`D1%!)4W1R:6YG
M6R1I72`Z(&YU;&P["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T1%!)26YT*"1D
M<&DI"B`@("!["B`@("`@("`@+RHJ"B`@("`@("`@("H@041$($-(05!415(*
M("`@("`@("`@*B\*("`@("`@("`D1%!)26YT(#T@87)R87DH1%!)7T141%]7
M34Q?,5\P(#T^(#(L"B`@("`@("`@("`@("`@("`@("`@("`@($1025]$5$1?
M5U1!7S%?,"`]/B`S+`H@("`@("`@("`@("`@("`@("`@("`@("!$4$E?1%1$
M7U=-3%\Q7S$@/3X@-"P*("`@("`@("`@("`@("`@("`@("`@("`@1%!)7T14
M1%]325\Q7S$@/3X@-2P*("`@("`@("`@("`@("`@("`@("`@("`@1%!)7T14
M1%]33%\Q7S`@/3X@-BP*("`@("`@("`@("`@("`@("`@("`@("`@1%!)7T14
M1%]#3U\Q7S`@/3X@-RP*("`@("`@("`@("`@("`@("`@("`@("`@1%!)7T14
M1%]#2$%.3D5,7S%?,2`]/B`X+`H@("`@("`@("`@("`@("`@("`@("`@("!$
M4$E?1%1$7U=-3%\Q7S(@/3X@.2P*("`@("`@("`@("`@("`@("`@("`@("`@
M1%!)7T141%]734Q?,5\S(#T^(#$P+`H@("`@("`@("`@("`@("`@("`@("`@
M("!$4$E?1%1$7U!23U9?,5\P(#T^(#$Q+`H@("`@("`@("`@("`@("`@("`@
M("`@("!$4$E?1%1$7U=405]734Q?,5\R(#T^(#$R+`H@("`@("`@("`@("`@
M("`@("`@("`@("!$4$E?1%1$7T-(04Y.14Q?,5\R(#T^(#$S+`H*("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@3F]T(&%L;"!3>6YC34P@8VQI96YT<R!K
M;F]W('1H:7,L('-O(&UA>6)E('=E"B`@("`@("`@("`@("`@("`@("`@("`@
M("\O('-H;W5L9"!U<V4@=&AE('-T<FEN9R!T86)L92X*("`@("`@("`@("`@
M("`@("`@("`@("`@1%!)7T141%]364Y#34Q?,5\P(#T^(#0P-#DL"B`@("`@
M("`@("`@("`@("`@("`@("`@($1025]$5$1?1$5624Y&7S%?,"`]/B`T,#4P
M+`H@("`@("`@("`@("`@("`@("`@("`@("!$4$E?1%1$7U-93D--3%\Q7S$@
M/3X@-#`U,2P*("`@("`@("`@("`@("`@("`@("`@("`@1%!)7T141%]$159)
M3D9?,5\Q(#T^(#0P-3(*("`@("`@("`@("`@("`@("`@("`@("`@+R\@1%!)
M7T141%]364Y#34Q?,5\Q(#T^(#!X1D0Q+`H@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!$4$E?1%1$7T1%5DE.1E\Q7S$@/3X@,'A&1#(L"B`@("`@("`@
M("`@("`@("`@("`@("`@("D["@H@("`@("`@(')E='5R;B!I<W-E="@D1%!)
M26YT6R1D<&E=*2`_("1$4$E);G1;)&1P:5T@.B`P.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@8VAA<F%C=&5R(&5N8V]D:6YG+@H@("`@
M("H@;VYL>2!D969A=6QT(&-H87)A8W1E<B!E;F-O9&EN9W,@9G)O;2!*,E-%
M(&%R92!S=7!P;W)T960*("`@("`J(&9R;VT@:'1T<#HO+W=W=RYI86YA+F]R
M9R]A<W-I9VYM96YT<R]C:&%R86-T97(M<V5T<PH@("`@("H@86YD(&AT='`Z
M+R]J879A+G-U;BYC;VTO:C)S92\Q+C0N,B]D;V-S+V%P:2]J879A+VYI;R]C
M:&%R<V5T+T-H87)S970N:'1M;`H@("`@("HO"B`@("!F=6YC=&EO;B!G971#
M:&%R<V5T4W1R:6YG*"1C<RD*("`@('L*("`@("`@("`O*BH*("`@("`@("`@
M*B!&<F]M(&AT='`Z+R]W=W<N:6%N82YO<F<O87-S:6=N;65N=',O8VAA<F%C
M=&5R+7-E=',*("`@("`@("`@*B\*("`@("`@("`D8VAA<G-E=%-T<FEN9R`]
M(&%R<F%Y*#,@/3X@)U53+4%30TE))RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#0@/3X@)TE33RTX.#4Y+3$G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@,3`V(#T^("=55$8M."<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Q,#$S(#T^("=55$8M,39"12<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Q,#$T(#T^("=55$8M,39,12<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Q,#$U(#T^("=55$8M,38G
M*3L*"B`@("`@("`@<F5T=7)N(&ES<V5T*"1C:&%R<V5T4W1R:6YG6R1C<UTI
M(#\@)&-H87)S9713=')I;F=;)&-S72`Z(&YU;&P["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!C:&%R86-T97(@96YC;V1I;F<N"B`@("`@
M*@H@("`@("H@3VYL>2!D969A=6QT(&-H87)A8W1E<B!E;F-O9&EN9W,@9G)O
M;2!*,E-%(&%R92!S=7!P;W)T960N"B`@("`@*@H@("`@("H@1G)O;2!H='1P
M.B\O=W=W+FEA;F$N;W)G+V%S<VEG;FUE;G1S+V-H87)A8W1E<BUS971S(&%N
M9`H@("`@("H@:'1T<#HO+VIA=F$N<W5N+F-O;2]J,G-E+S$N-"XR+V1O8W,O
M87!I+VIA=F$O;FEO+V-H87)S970O0VAA<G-E="YH=&UL"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$-H87)S971);G0H)&-S*0H@("`@>PH@("`@("`@("\J
M*@H@("`@("`@("`J($9R;VT@:'1T<#HO+W=W=RYI86YA+F]R9R]A<W-I9VYM
M96YT<R]C:&%R86-T97(M<V5T<PH@("`@("`@("`J+PH@("`@("`@("1C:&%R
M<V5T26YT(#T@87)R87DH)U53+4%30TE))R`]/B`S+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)TE33RTX.#4Y+3$G(#T^(#0L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G551&+3@G(#T^(#$P-BP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=55$8M,39"12<@/3X@,3`Q,RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=55$8M,39,12<@/3X@,3`Q-"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=55$8M,38G(#T^(#$P,34I.PH*("`@
M("`@("!R971U<FX@:7-S970H)&-H87)S971);G1;)&-S72D@/R`D8VAA<G-E
M=$EN=%LD8W-=(#H@;G5L;#L*("`@('T*"GT*"B\J*@H@*B!`<&%C:V%G92!8
M34Q?5T)834P*("HO"F-L87-S(%A-3%]70EA-3%](87-H5&%B;&4@>PH*("`@
M('9A<B`D7V@["@H@("`@9G5N8W1I;VX@<V5T*"1K+"`D=BD*("`@('L*("`@
M("`@("`D=&AI<RT^7VA;)&M=(#T@)'8["B`@("!]"@H@("`@9G5N8W1I;VX@
M9V5T*"1K*0H@("`@>PH@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7VA;
M)&M=*2`_("1T:&ES+3Y?:%LD:UT@.B!N=6QL.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92\`
M````````````````````````````````````````````````````````````
M````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`U,34T,S,W-30`,#$W,3$V`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&]C86QE+RYH=&%C8V5S<P``````````````````````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`Q-@`Q,#4Q-30S,S<U-``P,C`W
M,3$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M1&5N>2!F<F]M(&%L;`H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO
M8V%L92]A<E]362\`````````````````````````````````````````````
M````````````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-3,`,#(P,3,R`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&]C86QE+V%R7U-9+TQ#7TU%4U-!1T53+P``````
M```````````````````````````````````````````````````````````P
M,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U
M,P`P,C$W,3<`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O87)?4UDO
M3$-?34534T%'15,O:&]R9&4N;6\`````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#$V-#$T`#$P-3$U-#,S-S4S`#`R,S,V,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#>$@25`````'L````<````]`,``*<`
M``#,!P```````&@*```(````:0H```4```!R"@``"````'@*```'````@0H`
M``P```")"@``'P```)8*```Y````M@H``"D```#P"@``$0```!H+```6````
M+`L``!8```!#"P``"````%H+```(````8PL``!4```!L"P``"@```((+```,
M````C0L```8```":"P``!P```*$+```I````J0L```(```#3"P``!0```-8+
M```0````W`L``!0```#M"P``+P````(,```/````,@P``"8```!"#```!0``
M`&D,```-````;PP```4```!]#```$````(,,```0````E`P```\```"E#```
M"P```+4,```/````P0P```P```#1#```#P```-X,```>````[@P``"$````-
M#0``(````"\-```#````4`T```0```!4#0``!````%D-```,````7@T```H`
M``!K#0``!0```'8-```*````?`T```\```"'#0``$@```)<-```0````J@T`
M`"@```"[#0``"````.0-```0````[0T```8```#^#0``!P````4.```"````
M#0X```0````0#@``#P```!4.```*````)0X```<````P#@``!P```#@.```$
M````0`X```4```!%#@```@```$L.```S````3@X``#,```""#@``.````+8.
M```Q````[PX``"P````A#P``!0```$X/```"````5`\```<```!7#P``$0``
M`%\/```(````<0\``!X```!Z#P``!0```)D/```H````GP\``"D```#(#P``
M$P```/(/```+````!A```!$````2$```!````"00```,````*1```!H````V
M$```%P```%$0```7````:1```!L```"!$```'P```)T0```3````O1```!``
M``#1$```%P```.(0```'````^A````4````"$0``"0````@1```A````$A$`
M`!P````T$0``!0```%$1```#````5Q$``"\```!;$0``(````(L1```E````
MK!$``"````#2$0``)@```/,1```,````&A(```P````G$@``"````#02```'
M````/1(```8```!%$@``#0```$P2```+````6A(```P```!F$@``"@```',2
M```"````?A(```8```"!$@```P```(@2``!%````C!(``#````#2$@``$```
M``,3```?````%!,``!`````T$P``#P```$43```$````51,```4```!:$P``
M:`$``&`3```'````R10```P```#1%```"0```-X4```'````Z!0```L```#P
M%```&````/P4```F````%14``"T````\%0``$````&H5```?````>Q4``"$`
M``";%0``"P```+T5```%````R14``!4```#/%0``#0```.45```-````\Q4`
M``8````!%@``!@````@6```J````#Q8```L````Z%@``!````$86```0````
M2Q8```L```!<%@``'````&@6```,````A18``"D```"2%@``$0```+P6```-
M````SA8```,```#<%@``"P```.`6```+````[!8```H```#X%@``!P````,7
M```+````"Q<```@````7%P``$````"`7```?````,1<``!\```!1%P``'@``
M`'$7```$````D!<```@```"5%P``!P```)X7```,````IA<```L```"S%P``
M!0```+\7```+````Q1<```\```#1%P``%````.$7```1````]A<``"4````(
M&```!0```"X8```5````-!@```0```!*&```!````$\8```+````5!@```8`
M``!@&```#0```&<8```-````=1@```4```"#&```!@```(D8```%````D!@`
M``4```"6&````@```)P8```G````GQ@``"<```#'&```*0```.\8```@````
M&1D``!P````Z&0``!P```%<9```%````7QD```8```!E&0``#````&P9```+
M````>1D``!0```"%&0``!````)H9```<````GQD``"@```"\&0``"P```.49
M```,````\1D``!$```#^&0``!0```!`:```,````%AH``!4````C&@``$P``
M`#D:```1````31H``!0```!?&@``$@```'0:```8````AQH```P```"@&@``
M#P```*T:```(````O1H```<```#&&@``!@```,X:```C````U1H``!L```#Y
M&@``!0```!4;```/````&QL``"L````K&P``'0```%<;```?````=1L``"X`
M``"5&P``(@```,0;```2````YQL```\```#Z&P``#`````H<```%````%QP`
M``@````='```#P```"8<```-````-AP```L```!$'```"@```%`<```(````
M6QP```8```!D'````P```&L<```F````;QP``"T```"6'```"````,0<```1
M````S1P```\```#?'```$````.\<```%`````!T```4````&'0```0```&P`
M``!T````1P````D````P`````````$D`````````*0```&@```!<````90``
M`&(````G````5P````0````O`````````$$```!5````7@````````!`````
M*P```````````````````#8```!J````60```#$```!*````3P```%(`````
M`````````$(````:````"@`````````@````9@```#<``````````````%,`
M``!D````;@````4```!6````1@```'<````9`````````$L````/````````
M`!L```!4``````````````!S````;0````T`````````'P```!,````"````
M`````&\```!#`````````"(````+````<````!0````6````8P```"X```!I
M````80```!@```!(````+```````````````>0````8```!@````=@```#H`
M``!X````70```#\````[````3@```'$````1````3````#(````2````6@``
M``X````S````'0```&<`````````````````````````:P```%@`````````
M```````````C````$````%```````````````#4````<`````````$0````(
M```````````````X`````P`````````7````>@````P````\````/@``````
M```H`````````%L````M````)````````````````````$T`````````)0``
M```````>````10````<````A````7P```!4````T````=0````````![````
M/0```%$`````````<@```#D````F````*@``````````,C0@:&]U<G,`04TO
M4$T`061D('!A:7(`061D<F5S<P!!9&1R97-S($)O;VL`06X@:6QL96=A;"!V
M86QU92!W87,@<W!E8VEF:65D+@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O
M<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`075T:&5N=&EC871I
M;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`079A:6QA8FQE(&9I96QD
M<SH`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA
M;64N`$)I<G1H9&%Y`$-A;&5N9&%R`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#
M96QL(%!H;VYE`$-L;W-E(%=I;F1O=P!#;VUI8W,`0V]M<&%N>0!#;W5L9"!N
M;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!$1`!$86EL>0!$
M969A=6QT($ED96YT:71Y`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E=&%I;',@
M:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1I<W!L
M87D@3W!T:6]N<P!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E
M+G!H<`!%;6%I;`!%;7!T>2!R97-U;'0N`$5R<F]R`$5V97)Y(#$U(&UI;G5T
M97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G
M:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E
M<SH`1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C
M;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!3
M34(@<V5R=F5R+@!&87@`2&5L<`!(;VUE`$AO;64@061D<F5S<P!(;VUE(%!H
M;VYE`$AO<F1E`$EC;VYS($]N;'D`26-O;G,@=VET:"!T97AT`$EM<&]R=&5D
M(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$ME<F)E<F]S('-E<G9E<B!R
M96IE8W1E9"!A=71H96YT:6-A=&EO;BX`3&%N9W5A9V4`3&ES="!(96QP(%1O
M<&EC<P!,;V<@:6X`3&]G(&]U=`!-30!-86EL`$UA=&-H:6YG(&9I96QD<P!-
M96YU(&UO9&4Z`$UE<W-A9V4`36]N=&AL>0!.86UE`$YE=F5R`$YO`$YO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R(%-13"U&:6QE(%9&4RX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;W1E<P!/2P!/<'1I;VYS`$]T
M:&5R($EN9F]R;6%T:6]N`%!A<W-W;W)D`%!E<F9O<FT@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<P!0:&]N90!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@
M=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD
M('!A<W-W;W)D`%!R;V)L96T@1&5S8W)I<'1I;VX`4F5M;W9E('!A:7(`4F5T
M=7)N('1O($]P=&EO;G,`4F]L90!3879E($]P=&EO;G,`4V5L96-T('1H92!D
M871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T
M('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N
M`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M
M(%)E<&]R=`!3:VEP($UA:6YT96YA;F-E`%-P96-I86P@0VAA<F%C=&5R($EN
M<'5T`%-U8V-E<W,`5&%S:W,`5&5X="!/;FQY`%1H:7,@;G5M8F5R(&UU<W0@
M8F4@870@;&5A<W0@;VYE+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N
M`%1I=&QE`%523`!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&
M4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R
M+@!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!T<F%N<VQA
M=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N9&\@0VAA;F=E<P!5<V5R($]P=&EO
M;G,`57-E<FYA;64`5V%R;FEN9P!7965K;'D`5V5L8V]M92!T;R`E<P!796QC
M;VUE+"`E<P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!960!996%R;'D`665S
M`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N
M('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W5R("5S('-E<W-I;VX@:&%S
M(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!);F9O<FUA=&EO
M;@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%M0<F]B;&5M(%)E
M<&]R=%T`6VQI;F4@)7,@;V8@)7-=`&YA;64`=D-A<F0`4')O:F5C="U)9"U6
M97)S:6]N.B!(3U)$12!V,BXP+C`*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E
M=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M
M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`S+3`T+3,P(#$R
M.C`P*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!0;&%T:6YU;2!$979E;&]P;65N
M="!496%M(#QD979T96%M0'!L871I;G5M+7-Y+FYE=#X*3&%N9W5A9V4M5&5A
M;3H@07)A8FEC(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N
M.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+VAT;6P[(&-H87)S970]0U`Q,C4V
M"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`#(T(-/'VLD`Y.7'
MT<?P+^'MX<?P`,/6W2#+Y,?&[0#'X=KDYL?D`,_=RM$@VN3'YNWD`,KC(,K-
MS^W/(-[MX\D@V^W1(./>R.;AR0#*P]_MSR#'X=CAR"#>R.$@Q^'(S\$@R-KC
MX>W'RB#'X=7MQ^3)OP#*XR#1W=8@Q^'*S=[>(./D(,?AY>;MR2#CY"#>R.$@
MQ^'CSL_C(-''S^WFTRX`Q^'-WN;A(,?AX\KFW=').@#?X>/)(./1YM$@V\C1
M(./>R.;AR2`HW^W1R.W1YM,I`,?3XR#'X>/3RL[/XR#;R-$@X][(YN$@*-_M
MT<CMT>;3*0#MYN,@Q^'C[>''SP##S.3/R0#%X=O'P2#'X<CAQ]L@VN0@X]3?
MX<D`Q^'EQ\K=(,?AS.;'X0#%V^''WB#'X>3'W=#)`-'3YN/'R@#'X=31W\D`
MX<?%X]_'Y.W)(.'=RLT@36%I;G1E;F%N8V5?5&%S:R#AX<C1[>/,("5S`.WF
MXR`M(-'>X^WD`.WFX^T`Q^'*S=[>(,?AQ]W*T<?6[0#4T<T@Q^'CU-_AR0#*
MXR#-W=D@Q^'*W<?5[>$@X>//[=$@Q^'DV<?C`,[MQ]''RB#'X=K1U@#AQR#*
MS\[A(./(Q]31R?`@Q>'L(,?AX^'=(&UA:6YT96YA;F-E+G!H<`#'X<C1[<\@
MQ^'%X=_*T>;D[0#AQ\KFS,\@Y,K'QLPN`,[8PP#?X2`Q-2#/WNW>R0#?X2`S
M,"#/WNW>R0#?X2`U(,_>[=[)`-_A(,_.YN$`W^$@Y-7=(-/'VLD`W^$@S][M
MWLD`P^/+X<D@VN'L(,?AWNWC.@#AQ\7CW\?D[<D@X>':R^;1(-KA["#'X<K=
MUNWAQ\HN`.''Q>/?Q^3MR2#AX<7*U<?A(,C'X>/.S^,@3$1!4"X`X<?%X]_'
MY.W)(.'AQ<K5Q^$@R,?AX\[/XR!334(N`-W'W],`Q^'CT\?:S\D`Q^'(S\?M
MR0#:Y.;'Y"#'X>/DTN$`Y<?*W2#'X>/DTN$`Y>;1S^T`P^W>YN3'RB#=WM@`
MP^W>YN3'RB#CVB#DU>;5`,?AS=[FX2#'X>/3RN;1S\DZ("5S`,?AS=[FX2#'
MX>/3RN;1S\DZ`,?AX\[/XR#?[='([='FTR#1W=8@Q^'*S=[>(./D(,?AY>;M
MR2X`Q^'AV\D`WL?&X\D@VN3'YNWD(,?AX]/'VL_)`,_.YN$`SM'FS`#4Y=$@
M+2#1WN/MY`#'X<C1[<\`X]C'R-[)(,?AS=[FX0#FUMH@Q^'CT-_1Q\HZ`-'3
MQ^')`-3ET>W'\`#'X<?3XP##R,_'\`#AQP#AQ\KFS,\@X]KAYN/'RB#-YN$@
MQ=K/Q\_'RB#'X=P@1E10(%9&4RX`X<?*YLS/(./:X>;CQ\H@S>;A(,7:S\?/
MQ\H@Q^'<(%-13"!61E,N`.''RN;,SR#CVN'FX\?*(,WFX2#%VL_'S\?*(./A
MW<?*(%-13"!61E,N`.''RN;,SR#?X>/)(./1YM$@X>'*S=[>(-_MT<CMT>;3
M`.''RN;,SR#?X>/)(./1YM$@X>'*S=[>(%--0CX`X^''S=G'R@#CYL?=W@#.
M[<?1Q\H`X]KAYN/'RB#"SM'L`-_AX\D@Q^'CT>;1`,KDW>W0(-KCX>W'RB#'
MX=7MQ^3)`.7'RMT`Q^'1S,?!(,K2YNW/Y,<@X^'.U2#'X>/4W^')+@#'X=',
MQ\$@RM+F[<_DQR#(Q]/C(,?AX]/*SL_C(.;?X>/)(,?AT]$N`-31S2#'X>/4
MW^')`,72X<D@Q^'+Y,?&[0#:YL_)(,7A["#'X<[MQ]''R@#'X<_FT0#-W=D@
MQ^'.[<?1Q\H`Q\[*T2#'X=WFQ]7A(.'ARL?1[<XZ`,?.RM$@RN33[=X@Q^'*
MQ]'MSCH`Q\[*T2#*Y-/MWB#'X>;>RCH`Q<[*T2#-WN'MY"#CRN/'R^'MY"X`
MQ<[*T2#AV\K?(,?AX]W6X<DZ`,/1T^$@RM[1[=''\"#(X]3?X<D@S=7AR@#%
MY>/A(,?AU>W'Y,D`Q<_.Q]$@S='FW2#.Q]7)`,KC(,CDS,?-`,?AX^7CQ\H`
MY-4@W=[8`.W,R"##Y"#MW^;D(.70QR#'X='>XR##W\C1(./D(,?AU=W1`.W,
MR"##Y"#*W^;D(.70Y2#'X=[MX\D@T=[C+@#'X>'>R`#:Y.;'Y"#'X<7DRM'D
M[<H`X<<@Q>/?Q^3MR2#ARMOM[=$@Q^'3X\?-[<?*(.'CX=T@5D93("5S+R5S
M+@#AQR#%X]_'Y.W)(.'AQ<K5Q^$@R./.S^,@4U%,+@#AQR#%X]_'Y.W)(.'>
MT<?!R2#CS.'/('9F<W)O;W0N`.''(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C
M("#CX=T@Q^'<(%9&4R`E<R\E<RX`V^W1(-['S]$@VN'L(,K1S./)(./3RN3/
M(,?AYM'/(.70QP#*T<?,VB#:Y"#'X<K;[>W1Q\H`SNW'T<?*(,?AX]/*SL_C
M`,?3XR#'X>/3RL[/XP#*Y,CMY0##T\CFVNW'\`##Y>''(,C?XR#%X>P@)7,`
MP^7AQR#FT^7AQR`E<P#:Y.;'Y"#'X=KCX0#EQ\K=(,?AVN/A`-/DR2`M(-?7
M`-/DYNW'\`#DVN,`[<S((-31S2#'X>/4W^')(-[(X2#'T=/'X2#*WM'MT<?P
M(,CEQRX`Q^3*Y<H@U>''S>W)(,?AQ\K5Q^$@)7,N(,?AT<S'P2#%VL?/R2#'
MX<_.YN$N`,CMQ^3'RM\Z`,KC(,K-S^W+(,?ASNW'T<?*`%O*WM'MT2#'X>/4
MW^')70!;Q^'3V-$@)7,@X^0@)7-=`,?AQ]/C`'9#87)D````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]B9U]"
M1R\`````````````````````````````````````````````````````````
M````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`U,34T,S,W-3,`,#(P,#4U`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&]C86QE+V)G7T)'+VAE;'`N>&UL````````````````````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S,R,``Q,#4Q-30S,S<U,P`P,C$U,C4`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]X
M;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O
M8F=?0D<O:&5L<"YX;6PL=B`Q+C(@,C`P-"\P-2\R-R`R,#HR,CHQ-B!J86X@
M17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4]
M(FYE=R(^"CQT:71L93Y4:&4@4&]R=&%L(%!A9V4\+W1I=&QE/@H@/'!A<F$^
M"B`@5&AI<R!P;W)T86P@<&%G92!P<F]V:61E<R!A('%U:6-K('-U;6UA<GD@
M;V8@86QL('EO=7(@:6UP;W)T86YT"B`@:6YF;W)M871I;VXN($9O<B!E>&%M
M<&QE+"!I="!M:6=H="!S:&]W(&AO=R!M86YY(&YE=R!E+6UA:6P@;65S<V%G
M97,@>6]U"B`@:&%V92!I;B!Y;W5R($E.0D]8+"!U<&-O;6EN9R!E=F5N=',@
M;VX@>6]U<B!C86QE;F1A<BP@=&%S:W,@;VX@>6]U<B!T;RUD;PH@(&QI<W0L
M(&AE861L:6YE<R!F<F]M('-E;&5C=&5D(&YE=W,@<V5R=FEC97,L(&%N9"!S
M;R!O;BX@($UA;GD@;V8@=&AE<V4*("!S=6UM87)I97,@=VEL;"!C;VYT86EN
M('%U:6-K('-H;W)T8W5T<R!T;R!C;VUM;VX@9G5N8W1I;VYS+"!S=6-H(&%S
M"B`@8V]M<&]S:6YG(&$@;F5W(&UA:6P@;65S<V%G92P@8W)E871I;F<@82!N
M97<@8V%L96YD87(@979E;G0@;W(@=&%S:RP@971C+@H@/"]P87)A/@H@/'!A
M<F$^"B`@5&AE(&-O;G1E;G1S(&]F('1H:7,@<&]R=&%L('!A9V4@87)E(&-U
M<W1O;6EZ86)L92!V:6$@=&AE($QA>6]U="!B=71T;VXN"B`@1F]R(&5X86UP
M;&4L('EO=2!C86X@8VAO;W-E('=H:6-H(&ET96US('1O(&EN8VQU9&4@;VX@
M=&AI<R!P;W)T86P@<&%G92!A<PH@('=E;&P@87,@:6X@=VAI8V@@;W)D97(@
M=&AE>2!A<F4@<VAO=VXN"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)N879B87(B('-T871E/2)N97<B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N
M($YA=FEG871I;VX@0F%R/"]T:71L93X*(#QP87)A/@H@($%T('1H92!L969T
M(&AA;F0@<VED92!O9B!T:&4@=V5B('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N
M(&YA=FEG871I;VX@8F%R+@H@($-L:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES
M(&YA=FEG871I;VX@8F%R('1O('%U:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*
M("!B971W965N('1H92!A=F%I;&%B;&4@87!P;&EC871I;VYS+@H@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N
M86YC93H@1&\@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)
M9B!Y;W4@=V]U;&0@;&EK92!T;R!P97)F;W)M(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@;VX@;&]G:6XL(&-H96-K('1H:7,@8F]X+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC
M92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT
M96YA;F-E.B!#;VYF:7)M($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A
M/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@8V]N9FER;2!A;&P@;6%I;G1E
M;F%N8V4@=&%S:W,@8F5F;W)E('1H97D@87)E(')U;BP@8VAE8VL@=&AI<R!B
M;W@N($EF(&QE9G0@=6YC:&5C:V5D+"!A;&P@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<R!T:&%T(&YE960@=&\@8F4@<G5N('=I;&P@8F4@<&5R9F]R;65D(&%U
M=&]M871I8V%L;'D@=VET:"!N;R!C:&%N8V4@=&\@8V%N8V5L(&]N(&QO9VEN
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQO8V%L92]B9U]"1R],0U]-15-304=%4R\`````````````````````````
M````````````````````````````````````````,#`P,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-3,`,#(Q-C0R`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V)G7T)'+TQ#7TU%4U-!1T53+VAO
M<F1E+FUO````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T,C8Q,0`Q,#4Q-30S
M,S<U,P`P,C,S,#0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````WA($E0````#Z````'````.P'``!1`0``O`\`````````%0``
M#@````$5```(````$!4```P````9%0``"P```"85```H````,A4``!4```!;
M%0``#@```'$5```(````@!4``#(```")%0``.````+P5``!4````]14``%$`
M``!*%@``-````)P6```%````T18```T```#7%@``$@```.46```/````^!8`
M`!D````(%P``!P```"(7```,````*A<```X````W%P```P```$87```%````
M2A<```H```!0%P``#P```%L7```?````:Q<``!$```"+%P``#````)T7```Y
M````JA<``"<```#D%P``+`````P8```J````.1@```H```!D&```%0```&\8
M```I````A1@``!$```"O&```%@```,$8```6````V!@```@```#O&```!```
M`/@8```)````_1@```,````'&0```P````L9```(````#QD``"`````8&0``
M!@```#D9```*````0!D```P```!+&0``!@```%@9```'````7QD``!````!G
M&0``*P```'@9```$````I!D``!X```"I&0``&P```,@9```;````Y!D``#,`
M````&@``+P```#0:```I````9!H```,```".&@```@```)(:```%````E1H`
M`!````";&@``!@```*P:```O````LQH```\```#C&@``!````/,:```%````
M^!H```T```#^&@``&P````P;```-````*!L```4````V&P``$````#P;```0
M````31L```\```!>&P``"P```&X;```/````>AL```P```"*&P``#P```)<;
M```>````IQL``"$```#&&P``(````.@;```#````"1P``!,````-'```%```
M`"$<```,````-AP```D```!#'```&P```$T<```'````:1P```8```!Q'```
M"0```'@<```4````@AP```8```"7'```$0```)X<```>````L!P```0```#/
M'```!````-0<```,````V1P```H```#F'```!0```/$<```@````]QP``"``
M```8'0``)@```#D=```I````8!T```H```"*'0``#P```)4=```2````I1T`
M`!````"X'0``%P```,D=```&````X1T```P```#H'0``#````/4=```-````
M`AX``"@````0'@``*P```#D>```(````91X``!````!N'@``&@```'\>```&
M````FAX```<```"A'@```@```*D>```E````K!X```0```#2'@``#P```-<>
M```'````YQX```H```#O'@``!P```/H>```&`````A\```D````)'P``#0``
M`!,?```'````(1\```H````I'P``!````#0?```'````.1\```4```!!'P``
M%P```$<?```"````7Q\``#,```!B'P``,P```)8?```X````RA\``"T````#
M(```,0```#$@```L````8R```!H```"0(```"0```*L@```%````M2````(`
M``"[(```!P```+X@```,````QB```!$```#3(```$0```.4@```)````]R``
M``@````!(0``"0````HA```*````%"$``!4````?(0``!0```#4A```H````
M.R$```L```!D(0``&@```'`A```%````BR$``"````"1(0``,@```+(A```%
M````Y2$```0```#K(0``,@```/`A```J````(R(```8```!.(@``#P```%4B
M```$````92(```D```!J(@```P```'0B```5````>"(``!(```".(@``#P``
M`*$B```4````L2(``!H```#&(@``%P```.$B```7````^2(``!L````1(P``
M&0```"TC```?````1R,``%<```!G(P``!````+\C```$````Q",``!<```#)
M(P``!@```.$C```'````Z",```4```#P(P``"0```/8C``!*`````"0``#@`
M``!+)```2````(0D``!)````S20``#`````7)0``:0```$@E```]````LB4`
M`&4```#P)0``30```%8F```N````I"8``"\```#3)@``+`````,G```7````
M,"<``"4```!()P``,@```&XG```^````H2<``"4```#@)P``(0````8H```P
M````*"@``!P```!9*```#0```'8H```%````A"@```,```"**```(````(XH
M```B````KR@``"4```#2*```)@```/@H```)````'RD```8````I*0``"0``
M`#`I```3````.BD```@```!.*0``"0```%<I```*````82D``!0```!L*0``
M"````($I```_````BBD```<```#**0``!@```-(I```-````V2D```L```#G
M*0``+P```/,I```,````(RH```H````P*@```@```#LJ```&````/BH```,`
M``!%*@``*````$DJ```F````<BH``"4```"9*@``*````+\J```0````Z"H`
M`',```#Y*@``'P```&TK```4````C2L```\```"B*P``!````+(K```'````
MMRL```4```"_*P``4@$``,4K```/````&"T```<````H+0``"````#`M```.
M````.2T``"4```!(+0``'````&XM```,````BRT```<```"8+0``-0```*`M
M```U````UBT``%(````,+@``3P```%\N```W````KRX```4```#G+@``%@``
M`.TN```6````!"\``!8````;+P``)@```#(O```%````62\``!````!?+P``
M#@```'`O```'````?R\```D```"'+P``#````)$O```,````GB\``",```"K
M+P``%P```,\O```-````YR\``#<```#U+P``+0```"TP```M````6S```"\`
M``"),```"````+DP```8````PC```#(```#;,```#P````XQ```;````'C$`
M`"4````Z,0``"@```&`Q```)````:S$```<```!U,0```P```'TQ```#````
M@3$```@```"%,0``)@```(XQ```&````M3$```\```"\,0``$````,PQ```'
M````W3$```@```#E,0``$P```.XQ```I`````C(```<````L,@``)0```#0R
M```E````6C(``"<```"`,@``)0```*@R```Z````SC(``#4````),P``!@``
M`#\S```"````1C,```D```!),P``&P```%,S```&````;S,``"X```!V,P``
M#0```*4S```(````LS,```4```"\,P``"P```,(S```B````SC,``!````#Q
M,P``!@````(T```/````"30``!`````9-```#@```"HT```-````.30``!0`
M``!'-```#````%PT```3````:30``"D```!]-```,@```*<T```D````VC0`
M``0```#_-```%0````0U```6````&C4```P````Q-0``"P```#XU```F````
M2C4```8```!Q-0``!@```'@U```+````?S4``!<```"+-0``!0```*,U```.
M````J34``"$```"X-0``!0```-HU```&````X#4```T```#G-0``#P```/4U
M```%````!38``"\````+-@``+P```#LV```\````:S8``"8```"H-@``"@``
M`,\V```-````VC8``!0```#H-@``$P```/TV```?````$3<```D````Q-P``
M$@```#LW```1````3C<``!(```!@-P``*@```',W```M````GC<```0```#,
M-P``"@```-$W```A````W#<```0```#^-P``!0````,X```"````"3@``"T`
M```,.```!````#HX```0````/S@```<```!0.```#@```%@X```%````9S@`
M``4```!M.```"````',X```1````?#@```<```"..```"@```)8X```#````
MH3@```4```"E.```!@```*LX```C````LC@```(```#6.```)@```-DX```F
M`````#D``"L````G.0``*P```%,Y```O````?SD``#4```"O.0``&0```.4Y
M```.````_SD```<````..@```@```!8Z```%````&3H```\````?.@``$```
M`"\Z```4````0#H```D```!5.@``!@```%\Z```'````9CH```@```!N.@``
M$@```'<Z```&````BCH``#(```"1.@``!0```,0Z```9````RCH```<```#D
M.@``'@```.PZ```W````"SL```H```!#.P``!@```$X[``!"````53L``"D`
M``"8.P``"````,([```7````RSL```0```#C.P``"0```.@[```#````\CL`
M`!H```#V.P``(````!$\```/````,CP``!T```!"/```&0```&`\```:````
M>CP``!@```"5/```'@```*X\```C````S3P``"0```#Q/```:````!8]```)
M````?ST```8```")/0``'@```)`]```'````KST```4```"W/0``!@```+T]
M```*````Q#T``$<```#//0``*P```!<^``!)````0SX``%<```"-/@``+P``
M`.4^``!?````%3\``#4```!U/P``80```*L_```_````#4```"<```!-0```
M'````'5````;````DD```!<```"N0```*@```,9````Q````\4```$4````C
M00``(````&E!```D````BD$``#<```"O00``(````.=!```5````"$(```@`
M```>0@```P```"="```D````*T(``"L```!00@``)0```'Q"```H````HD(`
M``H```#+0@``!P```-9"```*````WD(``!\```#I0@```P````E#```$````
M#4,```4````20P``&````!A#```(````,4,``#T````Z0P``"````'A#```(
M````@4,``!````"*0P``#P```)M#```T````JT,```P```#@0P``#@```.U#
M```"````_$,```<```#_0P```@````=$```A````"D0``"L````L1```*@``
M`%A$```M````@T0``!$```"Q1```90```,-$```K````*44```\```!510``
M$````&5%```$````=D4```<```![10``!0```(-%```!`````````+<```":
M````/````.4```"G````=````````````````````(H`````````E@```%``
M``!W`````````%$```".````9P```!(```!S```````````````H````KP``
M`)`````=````"0````\```!_```````````````_````;@```!L```!+````
M9@````````#V`````````"H````M`````````%L`````````5````/4`````
M````B0```$D```!]`````````*H```!%````K````'L```#S`````````,X`
M``!M````-0```.\`````````K@```.<```"&````,P```),```"M````6@``
M``````#R````8````$,```!V`````````$P``````````````$<`````````
M(````#H````Y````V@`````````X````&@```#(```"+````30``````````
M````8P```&\```"K````[@```.````!A````````````````````9```````
M``#,````7@```-`````N````<@```.@``````````````#8```#=````HP``
M`-L```",``````````````#3````5P```!0```#)````U`````(```"9````
M!````!`````>````W@```+4``````````````*(```!*````SP```"$```"5
M`````````%@````F````"@```"\````E````/@```+D```"!`````````!D`
M``!H````^@```&H```#5````M`````````"Q````%P```.8`````````D@``
M``````!3````1@```-\```"E`````````%P`````````60```)P```#+````
M``````````"I````R````.P````B`````````&4```"R````[0```'X```!L
M`````````.(```#$````$P``````````````````````````````M@``````
M``""````Z@```/$```#K````D0```'$```"=``````````````#<````L```
M`!4```"@````T@```!8```#-`````````+X```"X````]````(<```">````
MQ0````````!!`````````)<`````````,0```(T```!X````OP````````#C
M``````````X```!=````T0```$(`````````.P```.$```!U````````````
M``!(````4@```$\```"/``````````````!P````"`````T````T````5@``
M`",```````````````````!5````V0```/D```#X````V`````````"?````
M$0```-<```"\````QP```-8```"A````/0```"L```"H````'`````4````#
M````"P```,8```"S`````````+T`````````P0````````#*`````````/``
M``"`````&````)@```"Z`````````&L```````````````````!\````>0``
M`$``````````>@```"0```#D````@P```.D`````````A0```&(````P````
M'P```/<```````````````P```"(````*0```+L```";`````````$0`````
M````PP```(0````W````I````,`````G`````````)0```!I````!@````<`
M``!.```````````````L````P@```*8```!?`````"`H)7,@9&%Y<R!A9V\I
M`"`H=&]D87DI`"`H>65S=&5R9&%Y*0`E<R`M($YO=&EC90`E<R!-86EN=&5N
M86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%1E<FUS(&]F($%G
M<F5E;65N=``E<R!I<R!R97%U:7)E9``R-"!H;W5R<P!!('!U8FQI8R!01U`@
M:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI
M8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S
M86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`
M02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`
M04TO4$T`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@
M;F5W('5S97(Z`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!
M9&1R97-S($)O;VL`061M:6YI<W1R871I;VX`061S`$%L:6%S`$%L;"!'<F]U
M<',`06QL(%!E<FUI<W-I;VYS`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I
M9FEE9"X`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%S:R!F;W(@
M8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I
M;VYS/P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`
M071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`
M071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T
M=')I8G5T97,`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N
M(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%V86EL86)L92!F:65L9',Z
M`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE
M+@!":7)T:&1A>0!";VQD`$)O;VMM87)K<P!#35,`0U)#`$-A;&5N9&%R`$-A
M;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;F-E;`!#96QL(%!H
M;VYE`$-O;&]R(%!I8VME<@!#;VUI8W,`0V]M<&%N>0!#;VYF:7)M(%!A<W-W
M;W)D`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BX`0V]P>0!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@
M;F]T(%!'4"!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D
M871A+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA
M:6P@861D<F5S<RX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@
M=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S
M:R!M;V1U;&4@)7,`0W5T`$1$`$1A:6QY`$1E9F%U;'0@261E;G1I='D`1&5L
M971E`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T
M<F%T;W(N`$1I<W!L87D@3W!T:6]N<P!%9&ET`$5M86EL`$5M86EL($%D9')E
M<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M<'1Y(')E<W5L="X`
M17)R;W(`179E<GD@,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y
M(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@
M;6EN=71E`$5X86UP;&4@=F%L=65S.@!&86EL960@<F5T<FEE=FEN9R!P<F5F
M97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A
M:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A>`!&:6QE($-O=6YT
M.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&
M:6QE($YA;64`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`
M1F]R=6US`$9U;&P@3F%M90!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<',`
M1W5E<W0@4&5R;6ES<VEO;G,`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U
M;F0N`$AE;'``2&]M90!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;W)D90!)
M34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@
M9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I
M;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#
M2412(&)L;V-K+@!)8V]N<R!/;FQY`$EC;VYS('=I=&@@=&5X=`!);7!O<G1E
M9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);G9A;&ED(&1A=&$@<W5B
M;6ET=&5D+@!)=&%L:6,`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T
M:69Y(%)I9VAT`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A
M=&EO;BX`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+@!,86YG=6%G90!,:7-T($AE;'`@5&]P:6-S`$QI<W1I;F<@=7-E<G,@
M:7,@9&ES86)L960N`$QO9R!I;@!,;V<@;W5T`$U-`$U3+51.148@071T86-H
M;65N="!C;VYT86EN960@;F\@9&%T82X`36%I;`!-871C:&EN9R!F:65L9',`
M365M8F5R<P!-96YU(&UO9&4Z`$UE<W-A9V4`365T:&]D`$UI;64@5'EP90!-
M;V1I9FEE9"!$871E`$UO;G1H;'D`37D@06-C;W5N=`!.86UE`$YE='=O<FL`
M3F5V97(`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F\`3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,+49I;&4@5D93+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E
M<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE
M9`!.;R!V86QU97,`3F]T97,`3TL`3W!T:6]N<P!/<F1E<F5D($QI<W0`3W1H
M97(@26YF;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$A0(%-H96QL`%!A
M<W-W;W)D`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA
M=&-H+@!087-T90!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@
M;&]G:6X_`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N
M`%!H;VYE`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!U8FQI
M8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN
M`%)A=&EO`%)E860`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@
M8V%N;F]T(&)E('5N9&]N92X`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M
M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@=7-E<CH@)7,`4F]L90!3
M44P@4VAE;&P`4U-(`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N
M97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D
M`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F
M;W)M870Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T
M8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C
M="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5T('EO=7(@<W1A<G1U<"!A
M<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N
M9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-H;W<`4VEZ90!3<&5C:6%L($-H
M87)A8W1E<B!);G!U=`!3=6)M:70`4W5C8V5S<P!487-K<P!497AT($]N;'D`
M5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&5N8W)Y<'1I;VX@
M9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE
M(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T
M;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!P<F]G<F%M('5S960@=&\@
M=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE
M('-Y<W1E;2X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L
M87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN
M('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@
M>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B
M;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N
M`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H
M92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE
M("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N
M`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T
M82X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C
M:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@
M9FEL92X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@
M;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O
M;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UU<W0@
M8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R
M<P!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@
M;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG
M="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!V86QU92!M
M=7-T(&)E(&$@;G5M8F5R+@!4:6UE(%1R86-K:6YG`%1I=&QE`%523`!5;F%B
M;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@;W!E;B!C
M;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T
M(&1I<F5C=&]R>2X`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C
M=6UE;G0`56YD97)L:6YE`%5P9&%T90!5<&1A=&4@)7,`57-E<B!!9&UI;FES
M=')A=&EO;@!5<V5R;F%M90!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I
M;B!T:&4@<WES=&5M.@!686-A=&EO;@!697)I9FEC871I;VX@9F%I;&5D("T@
M=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5V%R
M;FEN9P!7965K;'D`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!7:&%T(&%P
M<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7;W)K
M($%D9')E<W,`5V]R:R!0:&]N90!960!996%R;'D`665S`%EO=2!D:60@;F]T
M(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@
M=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M
M92!T;R!U<&1A=&4N`%EO=7(@26YF;W)M871I;VX`66]U<B!A=71H96YT:6-A
M=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@
M;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H
M97(@<F5A<V]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO
M=7(@<F5M;W1E('-E<G9E<G,Z`%ML:6YE("5S(&]F("5S70!F:6QE`'5N;F%M
M960`=D-A<F0`4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`M8W9S"E)E
M<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#
M<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I
M;VXM1&%T93H@,C`P,BTQ,2TQ.2`R,#HT-"TP-3`P"DQA<W0M5')A;G-L871O
M<CH@36ER;W-L878@4&5N9&5V(#QM:7)O0&-Y8F5R<VAA9&4N=7,^"DQA;F=U
M86=E+51E86TZ(&DQ.&Y`;&ES=',N:&]R9&4N;W)G"DU)344M5F5R<VEO;CH@
M,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U#4#$R-3$*
M0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`("@E<R#D[>@@[>#G
MX.0I`"`HY.WE\2D`("CB]^7PX"D`)7,@+2#'X.'EZ^7FZN``)7,@SN'QZ_/F
MXN#YZ"#N[^7PX/;HZ"`M(,_N\N+Z\.;DY>WHY0`E<R#3\>ONXNC_(._N(-'O
M[O#@Y_/LY>WHY?+N`"5S(.WE[N'U[N3H[``R-"#WX/'@`,?@(.3@(.KPZ._R
MZ/#@\N4@[^CQ[.X@Y2#MY>[A]>[DZ.P@[_/AZ^CWY>T@4$=0(.KK_O<N`,?@
M(.3@(._P[N+E\.CRY2#O[N3OZ/'@[>X@[^CQ[.X@Y2#MY>[A]>[DZ.P@4$=0
M(.KK_O<N`,?@(.3@(.3EZO#H[_+H\.#RY2#OZ/'L[B#QX"#MY>[A]>[DZ.SH
M.B#O\^'KZ/?E[2#JZ_[W+"#KZ/?E[2#JZ_[W(.@@ZNO^]^[BX"#T\.#GX"X`
MQ^`@Y.`@[^[D[^CXY?+E(._H\>SN(/'@(.WE[N'U[N3H[.@Z(._SX>OH]^7M
M(.KK_O<L(.OH]^7M(.KK_O<@Z"#JZ_[W[N+@(/3PX.?@+@#'X"#DX"#J\.CO
M\NCPX/+E(._H\>SN(.4@[>7NX?7NY.CL(._SX>OH]^7M(%--24U%(.KK_O<N
M`$%-+U!-`,3NX>#B_^WE(.W@(.WNXN`@X_#S[^``Q.[AX.+_[>4@[>`@[>[B
MZ"#O\.#BX`#$[N'@XN@@[>[B(._N\O#EX>CRY>LZ`,3NX>#B_^WE\NX@[>`@
M[^[R\.7AZ/+EZ^@@Y2#GX.'PX.WE[>XN`,#D\.7Q`,#D\.7QY>T@X>7KY>;M
MZ.H`P.3LZ.WH\?+PZ/#@[>4`Q.[AX.+JZ`#/\>7BY.[MZ.P`PO'H]^KH(./P
M\^_H`,+QZ/?JZ"#O\.#BX`#"^N+EY.7MX/+@(/'R[NGM[O'R(.WE(.4@Y.[O
M\_'RZ.S@+@#0X.?LY?`@[>`@X/#UZ.+MZ/\@].#IZP#([.4@[>`@X/#UZ.+@
M`,3@(/'E(.CQZN`@Z^@@[^[RXOKPYN3E[>CE(._PY>3H(.[A\>OSYN+@^>CR
MY2#N[^7PX/;HZ#\`P_#E^.K@(._PZ"#HY_+PZ.+@[>4@[>`@[>7Q^OGE\?+B
M\^+@^>`@X_#S[^`N`,/PY?CJX"#O\.@@Z.?R\.CBX.WE(.WE(.WE\?KYY?'R
MXO/BX/GH(._PX.+@+@##\.7XZN`@[_#H(/#EY.#J\NCPX.WE(.W@(.WE\?KY
MY?'RXO/BX/GH(._PX.+@+@#`\O#HX?/RZ`##\.7XZN`@[_#H(.CDY>WRZ/3H
MZN#VZ/\`R.3E[?+H].CJX/;H__+@(.'E^.4@[O+UXOKPZ^7MX"#N\B!2041)
M55,@\?KPXOKPX"X`S>#KZ/?MZ"#O[NOE\N`Z`,WEXN#KZ.3MX"!K97)B97)O
M<R`@[^#P[NO@+@#-Y>+@Z^CD[>X@:V5R8F5R;W,@[^[R\.7AZ/+EZ_'J[B#H
M[.4N`-#NYN3E[2#DY>T`T^3EX>7KY>WH`,[R[.7RZN@`0TU3`$-20P#*X.OE
M[>3@\`##\.7XZN`@[_#H(/'B^O#GXN#MY2#Q(.SEZ>L@\?KPXOKP.B`E<P#.
M\NK@YN@`S.[AZ.OE[2#RY>OE].[M`,CGX>CPX.WE(.W@(/;B__(`RN[LZ.KQ
MZ`#*[NSOX.WH_P#/[O+B^O#DY?+E(._@\.[KX/+@`,3N\?+Z[^`@Y.X@[_/A
MZ^CW[>C_(/'Z\.+Z\"#AY?CE(.[RZN#GX.TN`,KN[^CPX.D`P_#E^.K@(._P
MZ"!01U`@ZO#H[_+H\.#MY?+N(.W@(._H\>SN+@##\.7XZN`@[_#H(%!'4"#O
M[N3OZ/'BX.WE\NX@[>`@[^CQ[.XN`,/PY?CJX"#O\.@@Y.7J\.CO\NCPX.WE
M\NX@[>`@4$=0(.3@[>WH+@#-Y>KN\.7J\N7M(&5M86EL(.#D\.7Q(.W@(._N
MZ_/WX/+EZ_\N`,/PY?CJX"#O\.@@[^[K\_?@XN#MY?+N(.W@(._SX>OH]^WH
M_R#JZ_[W(.[R(.KK_O<M\?KPXOKPX"X`S>7B^N?L[N;M[O'R(.3@(/'E(.[R
MXN[PZ"#.X?'K\^;BX/GH7^?@Y.#WZ"#L[N3SZR`E<R``Z.?PY>;H`,3$`,7F
MY>3MY>+M[@#(Y.7M\NCW[>[Q\B#O[B#O[N3PX.?AZ/#@[>4`R.?R\.CI`,3E
M\N#IZ^CRY2#A__7@(/#EX^CQ\O#H\.#MZ"#GX"#@Y.SH[>CQ\O#@\N[PX"X`
MQ.CQ[^OEZ2#.[_;HZ`#0Y>3@ZO;H_P#/Z/'L[@#%;6%I;"#@Y/#E\0!%;6%I
M;"#@Y/#E\>CRY2#R\/_AXN`@Y.`@\?KB[^#DX/(N`,_PX.?E[2#PY>?SZ_+@
M\BX`P_#E^.K@`,+QY>KH(#$U(.SH[?/RZ`#"\>7JZ"`S,"#QY>KS[>3H`,+Q
MY>KH(#4@[.CM\_+H`,+Q_^KN(.ONX^+@[>4`S>`@XO'EZN@@[^[K[N+H[2#W
MX/$`PO'_ZN`@[.CM\_+@`,_PZ.SE\.WH(/'R[NGM[O'RZ#H`S>7B^N?L[N;M
M[O'R(.3@(/'E(.?@\.7D__(@[_#E].7PY>WVZ.CRY2X`S>7B^N?L[N;M[O'R
M(.3@(/'E(.[Q^OGE\?+BZ"#B\/KGZN`@\2!,1$%0(/'Z\.+Z\"X`P_#E^.K@
M(._PZ"#QXOKPY^+@[>4@\?KQ(%--0B#Q^O#B^O`N`-3@ZO$`P?#NZ2#TX.GK
M[N+E.B`E<R#TX.GK`,'P[ND@].#IZ^[BY3H@)7,@].#IZ^``U.#IZR#LY>W@
MYN7P`,CLY2#MX"#TX.GK`,CG[_#@^>#MY?+N(.W@(/3@Z>ONXN4@[>4@\>4@
M[^[DY/KPYN`N`-3HZ_+Z\`#4[O#S[.@`R.SE(.W@(/3@Z>L`P.3LZ.WH\?+P
MZ/#@[>4@[>`@X_#S[^@`P_#S[^@`S_#@XN`@Y^`@X^[Q\N@`2%144"#HY.7M
M\NCTZ.K@]NC_(.WE(.4@[>#LY?#E[>`N`,_N[.[Y`,W@]^#K[@#$[NS@^.7M
M(.#D\.7Q`,3N[.#XY>T@\N7KY?3N[0!(;W)D90##\.7XZN`@[_#H(/'ZY^3@
MXN#MY2#MX"!)34%0(._N^>7M\>K@(.KS\NC_.B`E<P##\.7XZN`@[_#H(.CG
M\O#HXN#MY2#MX"!)34%0(._N^>7M\>K@(.KS\NC_.B`E<P##\.7XZN`@[^[P
MX.3H(.KB[O+@(._PZ"#Q^N?DX.+@[>4@[>`@24U!4"#O[OGE[?'JX"#J\_+H
M_SH@)7,`25`@X.3PY?'@(.WE(.4@XB#O[N?B[NOE[>C_($-)1%(@X>ONZBX`
MT>#L[B#HZN[MZ`#(ZN[MZ"#Q(/+EZO'R`,CL[^[P\NCPX.WN(._NZ^4Z("5S
M`,CL[^[P\NCPX.WH(._NZ^7RX#H`R.?O\.#RY>WH\N4@Y.#M[>@@\>`@[>7B
MX.OHY.WH+@#-X.KK[NWE[>@`[_KK[>X@[^[D\.#B[?_BX.WE`.O_XNX@[^[D
M\.#B[?_BX.WE`.3_\>WN(._NY/#@XNW_XN#MY0!+97)B97)O<R#Q^O#B^O#@
M(.[R]>+Z\.OH(.CDY>WRZ/3HZN#VZ/_RX"X`RNO^]^`@XN7WY2#Q^OGE\?+B
M\^+@(.(@[_/AZ^CW[>C_(.KK_O?Q^O#B^O`N`,7GZ.H`S^[L[OD@\N7LZ`#1
M[^CQ^NK@(/$@[^[R\.7AZ/+EZ^@@Y2#GX.'PX.WE[2X`PO7NY`#(Y_7NY`#,
MS`!-4RU43D5&(._PZ.KPY>_E[>C_\B#TX.GK(.WE(/'ZY/KPYN#XY2#DX.WM
MZ"X`S^[YX`#1^N+OX.3@^>@@[^[KY?+@`-?KY>WNXN4`PNCD(.W@(.SE[?[R
M[CH`S^CQ[.X`S.7R[N0`36EM92#RZ.\`Q.#RX"#MX"#O\.[LY>W_[>4`S.7Q
MY??M[@#,[O_RX"#/[OG@`,CLY0#,\.7FX`#-Z.KNX^``S>[B[B#O[O+PY>'H
M\N7K\>KN(.CLY2`H[N_VZ.[MX.OM[BD`S>4`S?_LX"#GX.3@Y.7MX"#J[NWT
MZ./S\.#VZ/\@Y^`@1E10(%9&4RX`S?_LX"#GX.3@Y.7MX"#J[NWTZ./S\.#V
MZ/\@Y^`@4U%,(%9&4RX`S?_LX"#GX.3@Y.7MX"#J[NWTZ./S\.#VZ/\@Y^`@
M4U%,+49I;&4@5D93+@#-_^S@(.?@Y.#DY>W@(._@\.[KX"#GX"!)34%0(.CD
MY>WRZ/3HZN#VZ/\N`,W_[.`@Y^#DX.3E[>`@[^#P[NO@(.?@($ME<F)E<F]S
M(.CDY>WRZ/3HZN#VZ/\N`,W_[.`@ZN[M].CC\_#@]NCN[>W@(.CM].[P[.#V
MZ/\@Y^`@4TU"(.CDY>WRZ/3HZN#VZ/\N`,+Z\.W@\NCRY2#DX.WMZ"#MY2#Q
MX"!834P`S?_LX"#Q\N[I[>[Q\N@`P>7KY>;JZ`#.R@#.[_;HZ`#/[N3PY>3E
M[2#Q[^CQ^NH`Q/#SX^`@Z.WT[O#LX/;H_P#/\.#BX"#MX"#O\.CRY>;@\N7K
M_P!01U`@4VAE;&P`S^#P[NO@`,_@\.[KX#H`S^#P[NO@.B``S>7J[O#EZO+M
MX"#OX/#NZ^`N`,+L^NKMZ`#$X"#QY2#HY^+Z\/CBX/(@Z^@@[N'QZ_/FXN#Y
MZ/+E(.[OY?#@]NCH(._PZ"#"]>[D/P#/\.#BX`#`Y.SH[>CQ\O#H\.#MY2#M
MX"#O\.#BX/+@`-+EZ^7T[NT`S.[K_RP@XOKBY>3E\N4@[.7QY?8@Z"#C[N3H
M[>`N`,KK_O?NXN`@Y.+NZ>K@(._SX>OH]^7M+_?@\?+E[2#JZ_[W(.WE(.'E
M^.4@X^7MY?#H\.#MX"X`RN[E].CVZ.7M\@#7Y?+E[>4`R/'JX/+E(.3@(.CG
M\O#HY?+E("5S(.OH/R#2X.?H(.[OY?#@]NC_(.WE(.SNYN4@Y.`@\>4@XOKP
M[>4@[>#GX.0N`,#D\.7Q(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H
M;W)D92DZ`,_PY>S@]>WH`,_PY>S@]>WH(._N\O#EX>CRY>LZ("5S`-#NZ_\`
M4U%,(%-H96QL`%-32`#(Y^'E\.7RY2#C\//OX"#GX"#D[N'@XO_MY0#(Y^'E
M\.7RY2#M[N(@[_#H\N7FX/+EZR#MX"#C\//OX`#(Y^'E\.7RY2#Q^O#B^O``
MR.?AY?#H(._N\O#EX>CRY>L@Y^`@Y.[AX.+_[>4`R.?AY?#E\N4@Q.#RX"#P
MX.?DY>OH\N7K.@#(Y^'E\.7RY2#T[O#LX/(@Y^`@Q.#RX/+@.@#(Y^'E\.7R
MY2#T[O#LX/(@Y^`@U^#QX#H`R.?AY?#E\N4@Y.+E(/'ZXN_@Y.#YZ"#O[NOE
M\N`Z`,CGX>7PY?+E(.+@^.#RX"#Q]>7LX"#GX"#VXN7R[N+E\N4N`,CGX>7P
MY?+E(._PY>3O[O?H\N#MZ/_R(.[R(,+@\2#EY^CJ.@#'X.3@Z?+E(,+@^.7R
M[B#MX/?@Z^WN(._PZ.ONYN7MZ.4L(/'UY>S@(.?@(/;BY?+NXN4L(.[O\.7Q
M[?_BX.WE(.W@(/'R\.#MZ/;@\N`@Z"#D\//CZ"#N[_;HZ"#GX"#DZ/'OZ^7_
M+@#/[NK@Y^+@[>4`T.#G[.7P`,+ZXN7FY.#MY2#MX"#Q[^7VZ.#K[>@@\>CL
MXN[KZ`#(Y^_PX/+H`-/Q[^7U`,?@Y.#WZ`#1X.SN(/+EZO'R`,_PZ.KPY>_E
M[>C_\B!01U`@[^[D[^CQ(.4@[>7NX?7NY.CL(.?@(.3@(/'E(._P[N+E\.@@
M[^[D[^CQX.WN\NX@[^CQ[.XN`,KPZ._RZ/#@[>7R[B#HY^CQZN+@(.KPZ._R
MZ/#@[>`@=V5B(.+P^N?JX"X`S.7Q\N[O[NONYN7MZ.7R[B#MX"!';G501R#T
MX.GKX"#R\/_AXN`@Y.`@X?KDY2#DX.3E[6\@[>`@0W)Y<'1?<&=P.CH@8VQA
M<P#/\.[C\.#LX/+@+"#J[O_R[B#QZ_/FZ"#GX"#O[NK@Y^+@[>4@[>`@\N[G
MZ"#RZ.\@Y.#M[>@@*"5S*2#MY2#AY?CE(.[RZO#H\N`@XB#QZ/'RY>S@\N``
MS?_LX"#DXN[IZN@L(.KNZ/+N(.3@(.'ZY.#R(._NZN#GX.WH(.(@Z^CMZ/_R
MX"X`R.S@(/+B^O#DY2#L[>[C[B#QZ.SB[NOH(.(@\N[BX"#O[NOE+B#"^N+E
MZ^@@\?+E("5S(/'H[.+NZ^`[(/+P_^'BX"#DX"#B^N+EY.7RY2#O[BWLX.OJ
M[B#N\B`E<RX`P_#E^.K@(._PZ"#HY^_PX/G@[>7R[B#MX"#TX.GKX#H@)7,@
M[>4@X>7XY2#HY^_PX/+E[2X`R.S@^.4@[_#NX>OE["#O\.@@Z.?O\.#YX.WE
M\NX@[>`@].#IZ^`N("5S(.4@[^XMX^[K_^P@[O(@[.#J\>CLX.OM[B#D[N_S
M\?+H[.C_(/#@Y^SE\"`H)60@X>#I\N`I+@##\.7XZN`@[_#H(.CG[_#@^>#M
MY?+N(.W@(/3@Z>O@+B`E<R#AY?CE(/'@[.X@[O+WX/'RZ"#HY^_PX/+E[2X`
MP_#E^.K@(._PZ"#H[._N\/(@[>`@Y.#M[>@@Y^`@ZN[M\N#J\N@N`-+NXN`@
M[>4@Y2#BX.OHY.7M(')A<B#@\/7HXBX`TN[BX"#MY2#E(.+@Z^CDY>T@>FEP
M(/3@Z>LN`-+NXN`@[^[KY2#E(.WE[N'U[N3H[.XN`-+NXN`@[^[KY2#L[N;E
M(.3@(/'ZY/KPYN`@\>#L[B#VY>OH(/?H\>O@+@#2[N+@(._NZ^4@[.[FY2#D
MX"#Q^N3Z\.;@(/'@[.X@]^CQZ^`@Z"#DXN[E\N[WZ.4N`-+NXN`@[^[KY2#R
M\/_AXN`@Y.`@Y2#GX._E\N#_(.CKZ"#H[?+E\.+@ZR#PX.?DY>OE[2#Q[^CQ
M^NH@[_#N[.7MZ^CBZ`#2X.?H(/3N\.S@(.+E]^4@X>7XY2#NX?#@X>[RY>W@
M+@#2[N+@(/?H\>ON(/+P_^'BX"#DX"#E(._N[>4@Y>3H[>CVX"X`TN[GZ"#Q
M^O#B^O`@[>4@[.[FY2#DX"#DY>KN[._PY?'H\.`@>FEP(.@@9WII<"#TX.GK
M[N+E+@#2X.?H(/'R[NGM[O'R(/+P_^'BX"#DX"#E(/?H\>ON+@#/\.[QZ^7D
M_^+@[>4@[>4@XO#E[.4`Q.OZYNWN\?(`55),`,WEXOKG[.[F[>[Q\B#GX"#B
M\/KGZN`@\2!344P@\?KPXOKP+@##\.7XZN`@[_#H(.[RXN#P_^WE\NX@[>`@
MZN[L[_#E\>CPX.T@X/#UZ.(N`,/PY?CJX"#O\.@@]^7RY>WE\NX@[>`@=F9S
M<F]O="#OX._JX"X`P_#E^.K@(._PZ"#O\.7B[N3@(.W@(/+NY^@@5V]R9"#D
M[NKS[.7M\@#/[N3WY?#RX.WH`,[O\.7Q[>@`SN_PY?'MZ"`E<P#`Y.SH[>CQ
M\O#H\.#MY2#MX"#O[O+PY>'H\N7KZ/+E`,CLY0#([.4Z`,CLY3H@`,_N\O#E
MX>CRY>OH(.(@\>CQ\N7LX/+@.@#"X.K@[?;H_P##\.7XZN`@[_#H(._P[N+E
M\.K@\N`@+2#R[N+@(._H\>SN(.SNYN4@Y.`@Y2#AZ.ON(._NY._PX.+E[>XN
M`,+MZ.S@[>CE`-'EY.SH]^WN`,3NX?#E(,3N^.OH(.(@)7,`Q.[A\.4@Y.[X
MZ^@L("5S`,CGX>7PY?+E(._PZ.ONYN7MZ.7R[BP@ZN[E\NX@)7,@Y.`@[^[J
MX.;E(/'KY>0@XO7NY"X`P>CG[>7Q(.#D\.7Q`,'HY^WE\2#RY>OE].[M`,/#
M`,/NY.CX[>X`Q.``S>4@XOKBY>3N]?+E(.+@Z^CDY>T@96UA:6P@X.3PY?$N
M`-+P_^'BX"#DX"#GX.3@Y.7RY2#O[O+PY>'H\N7K(.?@(.CG\O#HXN#MY2X`
MTO#_X>+@(.3@(.?@Y.#DY?+E(._N\O#EX>CRY>L@Y^`@Y.[AX.+_[>4N`-+P
M_^'BX"#DX"#GX.3@Y.7RY2#O[O+PY>'H\N7K(.?@(.[O\.7Q[?_BX.WE+@#(
M[?3N\.S@]NC_(.?@(,+@\0#"X/CH__(@Z.3E[?+H].CJX/;H[NWE[2#D\.#I
MXN7P(.WE(._NY.3Z\.;@(/'OZ/'ZZB#MX"#O[O+PY>'H\N7KZ/+E+"#HZ^@@
M\N#GZ"#B^N?L[N;M[O'R(.4@Y^#A\.#MY>W@+@#"X/CH\N4@ZN[M].CC\_#@
M]NCN[>WH(.[O]NCH(.'_]>`@[N'M[N+E[>@N`,+@^.CRY2#Q^O#B^O#H.@!;
MZ^CMZ/\@)7,@[O(@)7-=`/3@Z>L`X>7G(.CLY0!V0V%R9```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&]C86QE+V)S7T)!+P``````````````````````````````````````````
M```````````````````````````````````````P,#`P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U,P`P,C`P-C,`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L;V-A;&4O8G-?0D$O3$-?34534T%'15,O````
M````````````````````````````````````````````````````````````
M`#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S
M-S4S`#`R,38U,``@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]B<U]"
M02],0U]-15-304=%4R]H;W)D92YM;P``````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P-34T,S<`,3`U,34T,S,W-3,`,#(S,S(T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````-X2!)4`````C0$``!P```"$#```
M'0(``.P8````````8"$```X```!A(0``#0```'`A```(````?B$```L```"'
M(0``#````),A```$````H"$```P```"E(0``"P```+(A```%````OB$``"@`
M``#$(0``"````.TA```*````]B$``!4````!(@``$@```!<B```+````*B(`
M``H````V(@``#0```$$B```.````3R(``!$```!>(@``#0```'`B```,````
M?B(```T```"+(@``!@```)DB```,````H"(```X```"M(@``#@```+PB```(
M````RR(``!H```#4(@``!0```.\B```1````]2(```@````'(P``$````!`C
M```/````(2,```H````Q(P```P```#PC```)````0",```\```!*(P``"@``
M`%HC```D````92,``!0```"*(P``#````)\C```L````K",```L```#9(P``
M!P```.4C```'````[2,```,```#U(P``(P```/DC```4````'20``!<````R
M)```%P```$HD```?````8B0```4```"")```.0```(@D```&````PB0``!0`
M``#))```"@```-XD```$````Z20```<```#N)```"0```/8D```&`````"4`
M`!$````')0``!P```!DE```6````(24```0````X)0``"````#TE```&````
M1B4```T```!-)0``!@```%LE```>````8B4``!$```"!)0``"````),E```-
M````G"4```P```"J)0``!P```+<E```#````OR4```,```##)0``$P```,<E
M```(````VR4```@```#D)0``"````.TE```@````]B4```8````7)@``!@``
M`!XF```5````)28``!4````[)@``%````%$F```8````9B8``!T```!_)@``
M!@```)TF``!4````I"8```4```#Y)@``!0```/\F```;````!2<``!H````A
M)P``$0```#PG```1````3B<``!P```!@)P``*@```'TG```0````J"<```4`
M``"Y)P``$P```+\G```0````TR<```<```#D)P``!P```.PG```$````]"<`
M``X```#Y)P``!@````@H```-````#R@``!`````=*```$@```"XH```H````
M02@```4```!J*```!````'`H```(````=2@```<```!^*```#0```(8H```0
M````E"@```L```"E*```!@```+$H```9````N"@``!@```#2*```%````.LH
M```+`````"D```D````,*0``%@```!8I```/````+2D``!8````]*0``"```
M`%0I```+````72D```0```!I*0``#P```&XI```0````?BD``!<```"/*0``
M$0```*<I```-````N2D```D```#'*0``(````-$I```1````\BD```<````$
M*@``!0````PJ```'````$BH```@````:*@``!@```",J```&````*BH``!``
M```Q*@``#P```$(J```0````4BH```\```!C*@``"P```',J```/````?RH`
M``P```"/*@``#P```)PJ```(````K"H```<```"U*@``!````+TJ```0````
MPBH```(```#3*@``#0```-8J```2````Y"H``!4```#W*@``!`````TK```%
M````$BL```0````8*P``#````!TK```*````*BL```@````U*P``"0```#XK
M```%````2"L```H```!.*P``&0```%DK```I````<RL```<```"=*P``"@``
M`*4K```,````L"L```\```"]*P``$````,TK```/````WBL```<```#N*P``
M%@```/8K```$````#2P```0````2+```!P```!<L```(````'RP``"`````H
M+```#0```$DL```.````5RP``!8```!F+```$0```'TL```&````CRP```,`
M``"6+```!@```)HL```'````H2P```<```"I+```!P```+$L```6````N2P`
M``T```#0+```!0```-XL```>````Y"P```D````#+0``"@````TM```,````
M&"T```\````E+0``"````#4M```&````/BT```<```!%+0``"P```$TM``!'
M````62T```T```"A+0``"0```*\M```*````N2T``&@```#$+0``!0```"TN
M```;````,RX``"\```!/+@``$````'\N```*````D"X```\```";+@``"@``
M`*LN```)````MBX```,```#`+@``!P```,0N```*````S"X```L```#7+@``
M!P```.,N```)````ZRX```<```#U+@``$````/TN```$````#B\```<````3
M+P``!0```!LO```-````(2\```P````O+P``"````#PO```7````12\```L`
M``!=+P``$P```&DO```$````?2\```H```""+P``!````(TO```,````DB\`
M``D```"?+P``!0```*DO```'````KR\```4```"W+P``!````+TO```"````
MPB\``"$```#%+P``!````.<O```4````["\```@````!,```!P````HP```0
M````$C````<````C,```#@```"LP```%````.C```!$```!`,```"````%(P
M```&````6S````<```!B,```'@```&HP```H````B3````H```"R,```&@``
M`+TP```4````V#```"@```#M,```*@```!8Q```0````03$```<```!2,0``
M$P```%HQ```-````;C$``!X```!\,0``%````)LQ```.````L#$``"H```"_
M,0``!0```.HQ```1````\#$```<````",@``%`````HR```8````'S(```P`
M```X,@``!@```$4R```/````3#(``"<```!<,@``&0```(0R```?````GC(`
M`!,```"^,@``"````-(R```'````VS(```@```#C,@``"0```.PR```5````
M]C(```T````,,P``$P```!HS```#````+C,``$8````R,P``/P```'DS```W
M````N3,``%<```#Q,P``!0```$DT```*````3S0```T```!:-```+0```&@T
M```$````EC0``"4```";-```'P```,$T```=````X30```0```#_-```$```
M``0U```;````%34```<````Q-0``!P```#DU```$````034``!\```!&-0``
M)P```&8U```C````CC4``!\```"R-0``+P```-(U```A`````C8``!P````D
M-@``,0```$$V```"````<S8``!0```!V-@``#````(LV```'````F#8```\`
M``"@-@``%````+`V```=````Q38```<```#C-@``,@```.LV```A````'C<`
M``P```!`-P``$0```$TW```(````7S<```<```!H-P``!P```'`W```&````
M>#<```<```!_-P``#0```(<W```+````E3<``!0```"A-P``%0```+8W```.
M````S#<``"\```#;-P``,0````LX```_````/3@```8```!].````P```(0X
M```U````B#@``!D```"^.```,````-@X```2````"3D``!,````<.0``$```
M`#`Y``!Y````03D```D```"[.0``*P```,4Y```7````\3D``!8````).@``
M#P```"`Z```?````,#H``$````!0.@``'P```)$Z```<````L3H``%$```#.
M.@``%````"`[```*````-3L```4```!`.P``!@```$8[```(````33L```4`
M``!6.P``$@```%P[```0````;SL``!,```"`.P``'0```)0[```/````LCL`
M``\```#".P``!````-([```)````USL```L```#A.P``!P```.T[```%````
M]3L``!0```#[.P``!P```!`\```(````&#P```\````A/```"````#$\```,
M````.CP```\```!'/```!@```%<\```4````7CP```8```!S/```#````'H\
M```)````ASP```<```"1/```!0```)D\```+````GSP``'4!``"K/```$```
M`"$^```-````,CX```@```!`/@``"````$D^```'````4CX```,```!:/@``
M"@```%X^```-````:3X```4```!W/@``'P```'T^```.````G3X```H```"L
M/@``$0```+<^```/````R3X```H```#9/@``"0```.0^```1````[CX```X`
M````/P``"@````\_```+````&C\```T````F/P``"0```#0_```&````/C\`
M``\```!%/P``#P```%4_```/````93\```<```!U/P``&@```'T_```%````
MF#\```X```">/P``#0```*T_```8````NS\``!(```#4/P``#0```.<_```%
M````]3\```P```#[/P``%@````A````,````'T```!\````L0```$````$Q`
M```&````74```#8```!D0```"@```)M````(````ID````4```"O0````P``
M`+5````E````N4```!<```#?0```%P```/=````@````#T$``!\````P00``
M!0```%!!```K````5D$```8```""00``%@```(E!```+````H$$```4```"L
M00``"````+)!```*````NT$```,```#&00``$````,I!```&````VT$``!,`
M``#B00```P```/9!```'````^D$```,````"0@``#0````9"```&````%$(`
M`"8````;0@``$0```$)"```(````5$(``!````!=0@``#````&Y"```'````
M>T(```,```"#0@```P```(="```2````BT(```@```">0@``!P```*="```'
M````KT(``"4```"W0@``!@```-U"```(````Y$(``!P```#M0@``$P````I#
M```5````'D,``!L````T0P``'P```%!#```(````<$,``%$```!Y0P``!```
M`,M#```$````T$,``"$```#50P``'````/=#```/````%$0``!@````D1```
M(@```#U$```K````8$0```\```",1```!@```)Q$```6````HT0```H```"Z
M1```!@```,5$```)````S$0```<```#61```$````-Y$```'````[T0```P`
M``#W1```#`````1%```6````$44``#L````H10``!@```&1%```%````:T4`
M``@```!Q10``"@```'I%```/````A44``!$```"510``"@```*=%```&````
MLD4``!T```"Y10``&0```-=%```D````\44```0````61@``"@```!M&```D
M````)D8```X```!+1@``%@```%I&```(````<48```L```!Z1@``"````(9&
M```0````CT8``!````"@1@``%@```+%&```5````R$8```P```#>1@``"```
M`.M&```H````]$8``!4````=1P``"````#-'```&````/$<```@```!#1P``
M"````$Q'```'````54<```8```!=1P``$````&1'```/````=4<``!$```"%
M1P``#P```)='```1````IT<``!````"Y1P``"P```,I'```5````UD<```<`
M``#L1P``!P```/1'```"````_$<```T```#_1P``!0````U(```/````$T@`
M`!(````C2```&````#9(```%````3T@```@```!52```!P```%Y(```-````
M9D@```X```!T2```"````(-(```)````C$@```4```"62```"0```)Q(```8
M````ID@``"P```"_2```!@```.Q(```*````\T@```L```#^2```$`````I)
M```/````&TD``!`````K20``!@```#Q)```6````0TD```0```!:20``!```
M`%])```)````9$D```4```!N20``(0```'1)```/````EDD``!(```"F20``
M(````+E)```5````VDD```<```#P20``!0```/A)```(````_DD```4````'
M2@``!@````U*```(````%$H``!P````=2@``"P```#I*```'````1DH``"<`
M``!.2@``!0```'9*```+````?$H``!$```"(2@``&@```)I*```(````M4H`
M``H```"^2@``!0```,E*```.````STH``%(```#>2@``%0```#%+```*````
M1TL```H```!22P``2@```%U+```$````J$L``"4```"M2P``-P```--+```0
M````"TP```@````<3```$@```"5,```+````.$P```H```!$3````P```$],
M```'````4TP```T```!;3```"P```&E,```&````=4P```@```!\3```"```
M`(5,```4````CDP```,```"C3```!0```*=,```&````K4P```\```"T3```
M#P```,1,```+````U$P``",```#@3```"P````1-```5````$$T```<````F
M30``"@```"Y-```%````.4T```\````_30``"0```$]-```%````64T```@`
M``!?30```P```&A-```$````;$T```(```!Q30``*````'1-```'````G4T`
M`!<```"E30``"````+U-```'````QDT``!$```#.30``!@```.!-```,````
MYTT```8```#T30``$@```/M-```%````#DX```4````43@``"````!I.```9
M````(TX``"T````]3@``!P```&M.```D````<TX``!$```"83@``-0```*I.
M```U````X$X``!`````63P``"````"=/```-````,$\```X````^3P``(P``
M`$U/```:````<4\``!````",3P``+````)U/```'````RD\```\```#23P``
M!P```.)/```9````ZD\``!4````$4```#@```!I0```%````*5```!`````O
M4```+````$!0```4````;5```!@```""4```&````)M0```+````M%````<`
M``#`4```"````,A0```)````T5```!(```#;4```#0```.Y0```5````_%``
M``<````240``2````!I1``!'````8U$``#P```"K40``8@```.A1```(````
M2U(```<```!44@``"P```%Q2```L````:%(```<```"54@``+P```)U2```F
M````S5(``!<```#T4@``"`````Q3```/````%5,``!L````E4P``!````$%3
M```(````1E,```4```!/4P``)P```%53```F````?5,``!H```"D4P``%@``
M`+]3```Q````UE,``"\````(5```'@```#A4```T````5U0```(```",5```
M$P```(]4```/````HU0```X```"S5```#@```,)4```:````T50``",```#L
M5```"````!!5```X````&54``!\```!250``$0```')5```6````A%4```X`
M``";50``"0```*I5```*````M%4```@```"_50``"P```,A5```1````U%4`
M``\```#F50``%````/95```5````"U8```X````A5@``+````#!6``!$````
M758``$H```"B5@``"````.U6```"````]E8``#,```#Y5@``(P```"U7```U
M````45<``!(```"'5P``$@```)I7```0````K5<``(````"^5P``"````#]8
M```F````2%@``!@```!O6```%@```(A8```3````GU@``!P```"S6```,@``
M`-!8```3`````UD``!<````760``3@```"]9```6````?ED```L```"560``
M!````*%9```'````IED```@```"N60``!0```+=9```7````O5D``!(```#5
M60``&0```.A9```D`````EH```X````G6@``#P```#9:```$````1EH```D`
M``!+6@``"P```%5:```&````85H```8```!H6@``$0```&]:```+````@5H`
M``8```"-6@``$0```)1:```'````IEH```@```"N6@``#P```+=:```'````
MQUH``!(```#/6@``"@```.):```&````[5H```X```#T6@``"0````-;```%
M````#5L```L````36P```0```,<```!B`0``````````````````B@```$$!
M```7````8P````T```!I````'P```(\`````````%P$`````````````]P``
M`%(````I`0``M````(D!``````````````H!``"F````@P```+\````?`0``
M9@```(T!``"D``````````````!M`0``_````&@!``"?`````````+L```"R
M``````````````"G````BP````````!"`0``1P```!(!`````````````%D`
M``!\`0``;@$``/L``````````````/````!U````W@```-L```#X````?P``
M````````````E````"X````"`0``<`$``'X`````````=@$``$P```"H````
M+````#0!``#5`````````#8```!8`0```````"\```!0`0``7@$`````````
M````J@```$L!``!Y````!```````````````2@```&<!``#+````(P$``%L!
M``!@`0``1`$`````````````(`$``*$`````````+0$````````R````EP``
M`#<!``#6````)`$```,`````````Z0```!P```!5`````````(4````1`0``
M`````*X```````````````,!```U````[P```($```"2````6````&H!``"K
M`````````,T````_`0`````````````(````'`$``),```!N````B```````
M````````^@````D```"E`````````(P!``!9`0```````$,!```S````````
M`"T`````````@@$``%8!``!\``````````H```##`````````((```!)`0``
MG@````````````````````````!<`0```````!8```!W````K````-<```!6
M````F@```&H````/`0```````,````#*````.````-0```#F`````````-H`
M``"'````C@````L`````````C````'(````1````3P$``#$!```O`0``)0$`
M`,0``````````````!T`````````50$`````````````!@$``"X!````````
MZP```-@`````````M0```````````````````!0`````````1@$``)$````S
M`0``G``````````]````SP```'H`````````B0```'0````Q`````````$(`
M```J````'@$``#L```!K`0``5P````X!``"\````-@$```````"=````P0``
M`$L```#R````&0```#4!`````````````%(!`````````````+X```"I````
M(@```#X!``#D````)P$```````!0`````````/$```!=`0``?@$````````$
M`0``%@$``,(````E`````````(````!V``````````````#M````&0$``&@`
M``"!`0``^0````````#3````#@```'`````5````N0```(8```!_`0``````
M`.X```#G````!0````````"&`0``2``````````^````%0$``&\!``#=````
M@P$``.``````````3@$``"8```";````B`$`````````````O0```!H!````
M````*P$``(`!``!S`0``T0```+H```"9````<P```!@````W`````````-\`
M``!*`0``L0```#H`````````_P```#\`````````H``````````Y````2`$`
M`#````#A````.0$``&P```#<````4P$```@!``#J````-````$T````I````
M10```'<!``#,`````````$D``````````````'D!``!:`0``V0`````````R
M`0``/`$```````"-````A`$```<```![````Z````(4!```4`0``AP$``'@!
M``!A`0```````````````````````-`````0`0```````"L````,`0``````
M`!H`````````40```'T`````````&P`````````H`0``/`````````!:````
M.P$``/,```!G`````````"(!````````!0$`````````````!@```!X```"*
M`0```````*,````````````````````L`0``(0$``%P```!``0``8````'0!
M````````*@$``+@```#L````,`$``$````#]````7P$``&(```!Z`0``&`$`
M`)4``````````````&$````]`0``:P```%L`````````;P`````````G````
M"P$``+8```!=````7P`````````X`0``]0```!(````"````L````+<````3
M``````````````!,`0``T@```$X```#^````:0$``$T!``"8````<@$``$$`
M``!E````H@```,4````=`0```````*\```!$````(P```.4```!#````#P``
M`&P!````````8P$``)````!&`````````+,````'`0``R0```/8`````````
M9```````````````1P$```````````````````P`````````X@````````!F
M`0``K0```'T!``!U`0```````#H!``#.````10$``%0`````````4P```"0`
M``!X````>P$``'$`````````Q@`````!```;`0``5P$``(0````-`0``40$`
M``````#T`````````!````#(````5`$``$\````H````XP`````````F`0``
ME@`````````A`````````"````!E`0````````D!``!>`````0$``&0!````
M````<0$``!,!``!M````BP$````@*"5S(&1A>7,@86=O*0`@*&EN("5S(&1A
M>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@870@`"5D
M("5S(&%N9"`E<P`E<R`M($YO=&EC90`E<R!+0@`E<R!-86EN=&5N86YC92!/
M<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``
M)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A
M="`E<R`E<P`E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@
M)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P
M860`)7,G<R!487-K;&ES=``E<SH@)7,`+2T@<V5L96-T("TM`#$R($AO=7(@
M1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`$$@9F%T86P@97)R;W(@
M:&%S(&]C8W5R<F5D`$%-+U!-`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN
M`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`
M061D`$%D9"!(97)E.@!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@
M=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D9')E
M<W,@8F]O:SH`061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES
M<VEO;G,@9F]R(&]T:&5R('5S97)S`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG
M97)I80!!;&P`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`
M06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`
M06QT97)N871E($E-4U`@57-E<FYA;64`06X@:6QL96=A;"!V86QU92!W87,@
M<W!E8VEF:65D+@!!<')I;`!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@
M9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`075G=7-T`$)A;'1I8R`H
M25-/+3@X-3DM,3,I`$)L;V-K(%1Y<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K
M<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD
M($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA
M;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N
M96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@
M1F%S;P!"=7)U;F1I`$--4P!#4D,`0U]E;&P@4')O<&5R=&EE<RXN+@!#86QE
M;F1A<@!#86UB;V1I80!#86UE<F]O;@!#86XG="!C;VYN96-T('1O($E-05`@
M<V5R=F5R.B`E<P!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R
M=`!#871E9V]R:65S(&%N9"!,86)E;',`0V5L=&EC("A)4T\M.#@U.2TQ-"D`
M0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E86X@*$E3
M3RTX.#4Y+3(I`$-H86YG90!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@
M=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y
M;W5R(&5M86EL<RX`0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D("A'
M0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S92!A('!A
M<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA
M>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@
M;&ES=',I`$-H<FES=&UA<R!)<VQA;F0`0VQE87(`0VQE87(@35-/9F9I8V4@
M=&%G<P!#;VQO=7(@<V5L96-T:6]N`$-O;6]R;W,`0V]M<&%N>0!#;W!Y`$-O
M<'D@<V5L96-T:6]N`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE
M=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-U<W1O;6EZ92!T87-K<R!T;R!R
M=6X@=7!O;B!L;V=O;B!T;R`E<RX`1&%I;'D`1&%T90!$96-E;6)E<@!$969A
M=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969I;FET:6]N
M<P!$96QE=&4`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@<V5L
M96-T960@:61E;G1I='D`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I
M;VX`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/
M<'1I;VYS`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&]W;FQO860`1&]W;FQO
M860@)7,`161I=`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%
M9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%;6%I
M;"!!9&1R97-S`$5M;W1I8V]N<P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X
M="!M96YU/P!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5S=&]N
M:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V
M97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E
M<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X
M86UP;&4@=F%L=65S.@!&96)R=6%R>0!&:6QT97)S`$9R;VT`1G5L;"!$97-C
M<FEP=&EO;@!';P!';V]G;&4@4V5A<F-H`$=R965K("A)4T\M.#@U.2TW*0!(
M96)R97<@*$E33RTX.#4Y+3@M22D`2&5L<`!(;U]M90!(;VUE`$AO;64@061D
M<F5S<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!)4"!!
M9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N
M;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`26-E;&%N9`!)8V]N<R!/
M;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N
M86UE.@!);G-E<G0@;65S<V%G97,`2F%N=6%R>0!*87!A;F5S92`H25-/+3(P
M,C(M2E`I`$IU;'D`2G5N90!,85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G
M<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@57!D871E9#H`3&%S="!L;V=I
M;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E
M<@!,871V:6$`3&%W`$QA>6]U=`!,96)A;F]N`$QE<V]T:&\`3&EB97)I80!,
M:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EN:W,`3&ES
M="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI=&AU86YI80!,;V%D:6YG
M+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G
M(&EN`$QO9R!O=70`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@
M>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E
M8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3'5X96UB;W5R9P!-86YA
M9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I
M=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C
M871E9V]R:65S+@!-87)C:`!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`
M36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E
M9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H:6YG(&9I96QD
M<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87D`365M8F5R<P!-96YU(&UO9&4Z
M`$UE<F=E(&-E;&QS`$UE<W-A9V4`36EM92!4>7!E`$UO;G1H;'D`37D@4&]R
M=&%L($QA>6]U=`!.86UE`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI80!.
M97<@0V%T96=O<GD`3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`
M3F5W(%IE86QA;F0`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U
M<',`3F5X=`!.97AT(&]P=&EO;G,`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`
M3FEG:'0`3FEU90!.;P!.;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N
M="X`3F]N90!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W9E;6)E<@!/8W1O8F5R
M`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/=&AE
M<@!/=&AE<B!);F9O<FUA=&EO;@!087-S=V]R9`!096]P;&4`4&5R8V5N=`!0
M97)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N
M86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I
M;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!L96%S
M92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&]S="!T;R!T
M:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!R979I;W5S(&]P
M=&EO;G,`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%)E860@;65S<V%G
M97,`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R
M=&%L(%9I97<Z`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W
M=W<N97AA;7!L92YC;VTO:&]R9&4I.@!297-E=`!2971U<FX@=&\@3W!T:6]N
M<P!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET
M;W(@3W!T:6]N<P!3879E($]P=&EO;G,`4V5A<F-H`%-E;&5C="!A('-E<G9E
M<@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L
M96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N96=A
M;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E
M<FEA;"!.=6UB97(`4V5S<VEO;B!)1"!E>'!I<F5D+@!3970`4V5T(&]P=&EO
M;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U
M(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y
M;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@
M<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS
M+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L
M('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`
M4V5T=7``4V5Y8VAE;&QE<P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@
M:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@;&%S
M="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!T86)L92!O<&5R
M871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T
M/P!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4V]U=&@@175R;W!E86X@*$E33RTX
M.#4Y+3,I`%-U8FIE8W0`4W5C8V5S<P!497AT`%1H86YK('EO=2!F;W(@=7-I
M;F<@=&AE('-Y<W1E;2X`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N
M($5X:71I;F<N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N
M`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@=V%S(&%N
M(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AI<R!N=6UB
M97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@=F%L=64@;75S="!B92!A
M(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/
M<'1I;VYS('=I;F1O=P!4;P!4=7)K:7-H("A)4T\M.#@U.2TY*0!5;F1O($-H
M86YG97,`56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@16UI
M<F%T97,`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YN86UE9`!5
M<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R
M=F5R+@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!/
M<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97)N86UE`%9I97<@)7,`5V%R
M;FEN9P!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S
M`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!7
M97-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P
M;&%Y(&%F=&5R(&QO9VEN/P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@
M=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H(&]F('1H92`E<R!M96YU(&]N
M('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!996%R
M;'D`665S`%EO=2!C86X@;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@
M>6]U<B!F=6QL(&YA;64N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U
M<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN
M`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@
M26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D
M('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P
M<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9
M;W5R($YA;64`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F
M96%T=7)E+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@
M:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&YE=R!P87-S=V]R9"!F
M;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F
M;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS
M(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E
M<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@
M96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R
M(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB
M86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P;W)T
M70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@
M;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T-,20!?
M1&%T851R964`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O
M<&5R=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?
M3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]3971U<`!?
M5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`'1A<VL@
M;&ES=`!U;FYA;65D`'9#87)D`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R
M<VEO;CH@:&]R9&4M8G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T
M<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z
M,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`U+3`W+3`Q(#$S.C,Q*S`R
M,#`*3&%S="U4<F%N<VQA=&]R.B!6961R86X@3&IU8F]V:6,@/'9L:G5B;W9I
M8T!S;6%R=&YE="YB83X*3&%N9W5A9V4M5&5A;3H@0F]S;FEA;B`\;&]K86Q`
M;&EN=7@N;W)G+F)A/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z
M('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,@I#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X8FET"E@M1V5N97)A=&]R.B!+0F%B96P@,2XQ,`H`
M("AP<FEJ92`E<R!D86YA*0`@*'IA("5S(&1A;F$I`"`H9&%N87,I`"`H<W5T
M<F$I`"`H:G7H92D`('4@`"5D("5S(&D@)7,`)7,@+2!.87!O;65N80`E<R!+
M0@`E<R!397)V:7-N92!O<&5R86-I:F4@+2!P;W1V<F1A`"5S('!O9&6Y879A
M;FIE`"5S('!R:6IA=F$`)7,@=7-L;W9I('5G;W9O<F$`)7,@=F7F('!O<W1O
M:FDN`"5S('4@)7,@)7,`)7,@;6EN=71A`"5S(&YI:F4@<')O;F'P96XN`"5S
M('IA("5S(&]D("5S`"5S(&%D<F5S87(`)7,@:V%L96YD87(`)7,@8FEL:F6^
M;FEC80`E<R!Z861A8VD`)7,Z("5S`"TM(&EZ86)E<FET92`M+0`Q,BUS871N
M:2!F;W)M870`,C0M<V%T;FD@9F]R;6%T`#(T('-A=&$`1&^Y;&\@:F4@9&\@
M9F%T86QN92!G<F6Y:V4`04TO4$T`3R!O=F]M(&5D:71O<G4`3R!P<F]G<F%M
M=2XN+@"I:69R82!K;W)I<VYIZ&MO9R!N86QO9V$`3F%L;V<@:F4@>F%M<GIN
M=70N`%)AZ'5N;W9O9'-T=F\`1&]D86H`1&]D86H@;W9D:F4Z`$1O9&%J(&YO
M=F]G(&MO<FES;FEK83H`1&]D86H@:V]L;VYU`$1O9&%J("5S(&UE;FD@=2!-
M;WII;&QA(%-I9&5B87(`1&]D86H@=2!A9')E<V%R.@!);65N:6L`061M:6YI
M<W1R:7)A;FIE("T@<&]D9;EA=F%N:F4@9&]Z=F]L82!D<G5G:6@@:V]R:7-N
M:6MA`$%F9V%N:7-T86X`06QB86YI:F$`06R^:7(`4W9E`$1O>G9O;&D@<')A
M=FQJ96YJ92!N=6UE<FES86YI:"!L:7-T:3\`06QT97)N871I=FYI($E-4U`@
M;&]G:6X`06QT97)N871I=FYA($E-4U`@N6EF<F$`06QT97)N871I=FYO($E-
M4U`@:V]R:7-N:>AK;R!I;64`56YEN65N82!J92!I;&5G86QN82!V<FEJ961N
M;W-T+@!!<')I;`!0:71A:B!P<FEJ92!O8F%V;&IA;FIA('-E<G9I<VYI:"!O
M<&5R86-I:F$_`$%U9W5S=`!"86QT:>AK:2`H25-/+3@X-3DM,3,I`%9R<W1A
M(&)L;VMA`$UA<VYO`$)O;&EV:6IA`%IA8FEL:F6Y:V4`4G5B`$1E8FQJ:6YA
M(')U8F]V83H`4G5B;W9I`$)O<VYA(&D@2&5R8V5G;W9I;F$`3V)A`$)O8W9A
M;F$`1&YO`$)O=79E="!O<W1R=F\`0G)A>FEL`$)R:71A;G-K82!);F1I:G-K
M;RU/:V5A;G-K82!497)I=&]R:6IA`$)R=6YE:2!$87)U<W-A;&%M`$)U9V%R
M<VMA`$QI<W1A('-A('1AZ&MA;6$`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3
M`$-20P!/<V]B:6YE(.9?96QI:F4N+BX`2V%L96YD87(`2V%M8F_P80!+86UE
M<G5N`$YE(&UO9W4@<V4@<W!O:FET:2!N82!)34%0('-E<G9E<CH@)7,`2V%N
M861A`$]D=7-T86YI`$]D=7-T86YI(&]D('!R:6IA=F4@<')O8FQE;6$`2V%T
M96=O<FEJ92!I(&]Z;F%K90!+96QT<VMI("A)4T\M.#@U.2TQ-"D`0V5N=')A
M;&YO+4%F<FGH:V$@4F5P=6)L:6MA`$-E;G1R86QN;RUE=G)O<'-K:2`H25-/
M+3@X-3DM,BD`4')O;6IE;FD`4')O;6EJ96YI=&4@:6UE(&D@861R97-U(&MO
M:F4@=FED92!D<G5G:2!K861A(.AI=&%J=2!I(&]D9V]V87)A:G4@;F$@=F&Y
M92!P;W)U:V4N`,AI;&4`2VEN80!+:6YE<VMI('!O:F5D;F]S=&%V;&IE;FD@
M*$=",C,Q,BD`2VEN97-K:2!T<F%D:6-I;VYA;&YI("A":6<U*0!)>F%B97)I
M=&4@N6EF<G4`27IA8F5R:71E(&MO<FES;FGH:V\@:6UE`$EZ86)E<FET92!K
M86MO('-E('!R:6MA>G5J92!D871U;3H`27IA8F5R:71E('9R<W1U('-T:6QA
M("AZ82!N=6UE<FES86YE(&QI<W1E*0!5<VMRN6YJ92!O<W1R=F\`3^AI<W1I
M`$_H:7-T:2!-4T]F9FEC92!T86=O=F4`27IB;W(@8F]J90!+;VUO<FD`2V]M
M<&%N:6IA`$MO<&ER86H`2V]P:7)A:B!I>F%B<F%N;P!+<F5I<F%J`$YA<')A
M=FD@;&EN:P!.87!R879I(&YO=FD`4')A=FQJ96YJ92!P;V0M9F]L9&5R80!0
M;V1E<VET92!Z861A=&ME(&MO:FD@YF4@<V4@:7IV<KEA=F%T:2!N86MO;B!P
M<FEJ879E(&YA("5S+@!$;F5V;F\`1&%T=6T`1&5C96UB87(`4W1A;F1A<F1N
M;P!3=&%N9&%R9&YA(&)O:F$`1&5F875L="!I9&5N=&ET970`1&5F:6YI8VEJ
M90!/8G)IN6D`0G)I<V%N:F4@:2!I>F)A8VEV86YJ92!P;W)U:V$`3V)R:;EI
M(&EZ86)R86YI(&ED96YT:71E=`!/<&FY:71E('!R;V)L96UE('4@<F%D=2!S
M82!W96)M86EL;VT`3W!I<P!$:7)E:W1O<FEJ`%!R:6MAOFD@=G)I:F5M92!U
M(#(T+7-A=&YO;2!F;W)M871U/P!/<&-I:F4@<')I:V%Z80!0<FEK8;YI('!R
M;V=N;WIU("A4048I`$1O=VYL;V%D`$1O=VYL;V%D("5S`$EZ;6EJ96YI`$EZ
M;6EJ96YI(&1O>G9O;'4`27IM:6IE;FD@9&]Z=F]L90!)>FUI:F5N:2!D;WIV
M;VQE('IA("5S`$EZ;6EJ96YI=&4@;W!C:6IE('IA.@!%;6%I;"!A9')E<V$`
M4VUA:FQI:FD`06MT:79I<F%J(&MO;G1E:W-T(&UE;FD@;F$@9&5S;F]M(&ML
M:6MU/P!%:W9A=&]R:6IA;&YA($=V:6YE:F$`17)I=')E:F$`1W)EN6MA`$5S
M=&]N:6IA`$5T:6]P:6IA`$5T;FGH:VD`179R;W!A`%-V86MI:"`Q-2!M:6YU
M=&$`4W9A:VEH(#(@;6EN=71E`%-V86MI:"`S,"!S96MU;F1I`%-V86MI:"`U
M(&UI;G5T80!+;V0@<W9A:V4@<')I:F%V90!3=F%K:6@@<&]L82!S871A`%-V
M86MI(&UI;G5T`%9R:6IE9&YO<W1I('!R:6UJ97)I.@!&96)R=6%R`$9I;'1E
M<FD`3V0`1&5T86QJ86X@;W!I<P!+<F5N:0!';V]G;&4@<')E=')A9V$`1W+H
M:VD@*$E33RTX.#4Y+3<I`$AE8G)E:G-K:2`H25-/+3@X-3DM."U)*0!0;VUO
MY@!0;^A?971A:P!0;^AE=&%K`$%D<F5S82`H:W7F:2D`5&5L969O;B`H:W7F
M:2D`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$E0(&%D<F5S80!)4"!A9')E
M<V$@;FEJ92!D;W-T=7!N82X`25`@861R97-A(&YI:F4@9&]Z=F]L:F5N82!U
M;G5T87(@0TE$4B!B;&]K82X`27-L86YD`%-A;6\@:6MO;F4`26MO;F4@>F$@
M)7,`26MO;F4@<V$@=&5K<W1O;0!);64@:61E;G1I=&5T83H`1&]D879A;FIE
M('!O<G5K80!*86YU87(`2F%P86YS:VD@*$E33RTR,#(R+4I0*0!*=6QI`$IU
M;FD`4F%?<W!O<F5D`$IE>FEK`$QA;R!.87)O9&YA($1E;6]K<F%T<VMA(%)E
M<'5B;&EK80!:861N:F$@:7IM:F5N83H`6F%D;FIA('!R:6IA=F$Z("5S`%IA
M9&YJ82!P<FEJ879A.B`E<R!S82!A9')E<V4Z("5S`%IA9&YJ82!P<FEJ879A
M.B!.:6MA9`!,871V:6IA`%IA:V]N`%)A<W!O<F5D`$QI8F%N`$QE<V]T;P!,
M:6)E<FEJ80!,:6)I:G-K82!!<F%P<VMA($2^86UA:&ER:6IA`$QI:'1E;KET
M86IN`$QI;FMO=FD`3&ES=&%N:F4@+2!K;W)I<VYI:R!M;[YE('9I9&IE=&D@
M9F]L9&5R`$QI='9A`%7H:71A=F%M+BXN`$QO:V%L;F\@=G)I:F5M93H@`$QO
M:V%L;F4@<&]S=&%V:V4@:2!V<FEJ96UE`$QO:V%C:6IA`%!R:6IA=FD@<V4`
M27IL87H`6F%D86-I('!R:6IA=F4`4')I:F%V82!N:6IE('5S<&IE;&$N($YA
M:G9E<F]V871N:6IE(&IE('!O9W)EN6YO('5N97-E;F\@:V]R:7-N:>AK;R!I
M;64@:6QI(+EI9G)A+@!0<FEJ879A(&YI:F4@=7-P:F5L82X`1'5G:2!T96MS
M=`!,=6MS96UB=7)G`$YA<')A=FET92!K871E9V]R:6IE('-T879K:2!I('IA
M('-V86MU(&]D(&YJ:6@@;V1R961I=&4@;V1G;W9A<F%J=>9U(&)O:G4N`$UA
M<G0`3WIN8>AA=F%N:F4@:V%O('!R;^AI=&%N;R]N97!R;^AI=&%N;P!/>FYA
MZ&%V86YJ92!D<G5G:6T@;WIN86MA;6$@*&YP<BX@=F&^;F\@:6QI(&]D9V]V
M;W)E;F\I`$UA<KEA;&]V82!O<W1R=F$`36%R=&EN:6L`3V1G;W9A<F%J=>9A
M('!O;&IA`$UA=7)I=&%N:6IA`$UA=7)I8VEJ=7,`36%J`,AL86YO=FD`5G)S
M=&$@;65N:6IA.@!3<&]J:2!P;VQJ80!0;W)U:V$`36EM92!T:7``36IE<V7H
M;F\`4F%S<&]R960@;6]G('!O<G1A;&$`26UE`$UR9;YA`$YI:V%D80!.;W9A
M($MA;&5D;VYI:F$`3F]V82!K871E9V]R:6IA`$YO=FD@;6IE<V5C`$YO=F\@
M:V]R:7-N:>AK;R!I;64@*&YI:F4@;V)A=F5Z;F\I`$YO=FD@6F5L86YD`$YO
M=FD@<')O>F]R("A?<')A>F%N*0!.;W9O<W1I`$YE=W,M9W)U<&4`1&%L:F4`
M4VQJ961EYF4@;W!C:6IE`$YI:V%R86=V80!.:6=E<@!.:6=E<FEJ80!.;^8`
M3FEU90!.90!.:6IE('!O<VQA;F\@:V]R:7-N:>AK;R!I;64@:2]I;&D@N6EF
M<F$N`$YI:F5D86X`3F]R9&EJ<VMI("A)4T\M.#@U.2TQ,"D`3F]V96UB87(`
M3VMT;V)A<@!/<&5R871I=FYI('-I<W1E;0!/<&-I:F4`3W!C:6IE('IA("5S
M`$]S=&%L;P!/<W1A;&4@:6YF;W)M86-I:F4`J6EF<F$`3&IU9&D`4')O8V5N
M870`27IV<KEI('-E<G9I<VYE(&]P97)A8VEJ90!)>G9RN6D@<V5R=FES;F4@
M;W!E<F%C:6IE('!R:6QI:V]M(&QO9VER86YJ83\`1&]Z=F]L90!!9&UI;FES
M=')A8VEJ82!D;WIV;VQA("AP<FEV:6QE9VEJ82D`3&GH;F4@:6YF;W)M86-I
M:F4`36]L:6UO(&1A:G1E(&MR871A:R!O<&ES('9AN65G('!R;V)L96UA('-A
M('=E8FUA:6QO;2X`4VQA;FIE('4@;W9A:B!F;VQD97(@*&YI:F4@<')I;G7P
M96YO(&]D('-T<F%N92!)34%082D`4')E=&AO9&YE(&]P8VEJ90!0<F]B;&5M
M/P!/<&ES('!R;V)L96UA`,AI=&%N:F4@<&]R=6MA`$&^=7)I<F%J(&1I;F%M
M:>AK92!E;&5M96YT92!M96YI:F$Z`$&^=7)I<F%J('!OZ&5T;G4@<W1R86YI
M8W4Z`%5D86QJ96YI('-E<G9E<FD`561A;&IE;FD@55),("AH='1P.B\O=W=W
M+F5X86UP;&4N8V]M+VAO<F1E*3H`4&]N:;ET:0!.87IA9"!N82!O<&-I:F4`
M4F5U;FEO;@!6<F%T:2!S=&%R=2!K;VYF:6=U<F%C:6IU`$]P8VEJ92!E9&ET
M;W)A('1E:W-T80!38>AU=F%J(&]P8VEJ90!4<F&^:0!)>F%B97)I=&4@<V5R
M=F5R`$EZ86)E<FET92!I9&5N=&ET970@:V]J:2"^96QI=&4@<')O;6EJ96YI
M=&DZ`$EZ86)E<FET92"Y96UU(&)O:F$N`$EZ86)E<FET92"^96QJ96YI(&IE
M>FEK.@!0;[EA;&II('!R:6IA=G4@<')O8FQE;6$`4&^Y86QJ:2!335,`4V5N
M96=A;`!396YZ;W(Z(`!397!T96UB87(`4W)B:6IA(&D@0W)N82!';W)A`%-E
M<FEJ<VMI(&)R;VH`240@<V5S:6IE(&IE(&ES=&5K86\N`$]D86)E<FD`4&]D
M97-I=&4@;W!C:6IE(&MO:F4@=F%M(&]M;V=UYG5J=2!D82!P;VYIN71I=&4@
MN6EF<G4@86MO(&IE('IA8F]R879I=&4N`%!O9&5S:71E('5D86QJ96YE('-E
M<G9E<F4@:V]J:6UA(+YE;&ET92!P<FES='5P:71I('!U=&5M('9AN65G('!O
M<G1A;&$N`$]D86)E<FET92"^96QJ96YI(&IE>FEK+"!V<F5M96YS:W4@>F]N
M=2!I('!O<W1A=FME('IA(&1A='5M+@!0;V1E<VET92!S=&%R=&YU(&MO;7!O
M;F5N='4L(+EE;74@8F]J82P@;W-V:F6^879A;FIE('-T<F%N:6-E(&D@9')U
M9V4@;W!C:6IE(&MO:F4@<V4@=&GH=2!P<FEK87IA+@!0;W-T879K90!396JY
M96QI`$MR871A:R!O<&ES`$1A(&QI(&1E9FEN:7-A=&D@<')I<W1U<&YE('1I
M<&ME('IA(&QI;FMO=F4_`%!R:6MAOFD`4')I:V&^:2!V<FEJ96UE('IA9&YJ
M92!P<FEJ879E(&YA:V]N(&QO9VER86YJ83\`4')I:V&^:2!M96YI('IA(&UA
M;FEP=6QA8VEJ92!T86)E;&%M83\`4')I:V&^:2`E<R!M96YI(&QI:F5V;S\`
M5F5L:>AI;F$`4')E<VMOZ&D@<V5R=FES`$IUOFYO+65V<F]P<VMI("A)4T\M
M.#@U.2TS*0!496UA`%5S<&IEN6YO`%1E:W-T`$AV86QA(+ET;R!K;W)I<W1I
M=&4@16YE<F=O9&%T82!W96)M86EL+@!0<F]Z;W(@>F$@;W!C:6IE('-E('IA
M='9O<FEO+B!)>FQA>FEM+@!)9&5N=&ET970@(B5S(B!J92!O8G)I<V%N+@!.
M96UA(&1O<W1U<&YI:"!O<&-I:F$N`$1E<VEL82!S92!G<F6Y:V$@=&]K;VT@
M<')I:V%Z82!O=F]G(&1I:F5L82!P;W)U:V4`5G)I:F5D;F]S="!O=F]G(&)R
M;VIA(&UO<F$@;F%J;6%N:F4@:7IN;W-I=&D@,2X`3W9A('9R:6IE9&YO<W0@
M;6]R82!B:71I(&)R;VHN`$]V86H@<')O>F]R('-E('-M:6IE('!O>FEV871I
M('-A;6\@:7H@<')O>F]R82!/<&-I:F4`6F$`5'5R<VMI("A)4T\M.#@U.2TY
M*0!0;VYIN71I(&EZ;6IE;F4`3F5K871E9V]R:7-A;F\`56YI:V]D("A55$8M
M."D`56IE9&EN:F5N:2!!<F%P<VMI($5M:7)A=&D`3F5P;WIN871O(&MO<FES
M;FGH:V\@:6UE(&EL:2"Y:69R82X`0F5Z:6UE;FD`2V]R:7-T:71E(&]V;R!A
M:V\@<V4@:6UE+[EI9G)A(')A>FQI:W5J=2!Z82!)35-0('-E<G9E<BX`2V]R
M:7-N:6L@)7,@;F5M82!D;WIV;VQU('IA("5S+@!+;W)I<VYIZ&ME(&]P8VEJ
M90!296=I<W1R86-I:F$@:V]R:7-N:6MA`$MO<FES;FGH:V\@:6UE`%!R:6MA
M>B`E<P!5<&]Z;W)E;FIE`%-E9&UIZ&YO`$1O8G)O(&1ON6QI`$1O8G)O(&1O
MN6QI(&YA("5S`$1O8G)O(&1ON6QI+"`E<P!:87!A9&YI("A)4T\M.#@U.2TQ
M*0!:87!A9&YI("A)4T\M.#@U.2TQ-2D`6F%P861N82!386AA<F$`2V]J=2!K
M;VUP;VYE;G1U(.9E("5S('!R:6MA>F%T:2!N86MO;B!U;&%Z83\`2V]J92!D
M;V1A=&ME(+YE;&ET92!A:W1I=FER871I('IA(&5D:71O<B!F;W)M871I<F%N
M;V<@*')I8V@I('1E:W-T82X`J6ER:6YA("5S(&UE;FEJ82!S82!L:6IE=F4@
M<W1R86YI8V4@*'-T=7!A(&YA('-N86=U(&MO9"!S;&IE9&7F92!P<FEJ879E
M*3H`1V]D:;EN:F4`1&$`3F4@;6^^92!S861ROF%V871I("=<)R!K87)A:W1E
M<B!U('1V;VT@<'5N;VT@:6UE;G4N`$]D:F%V;&II=F%N:F4@:F4@=7-P:F6Y
M;F\@:7IV<KEE;F\N`"`E<R!S97-I:F$@:F4@:7-T96ML82X@36]L:6UO(&1A
M('-E('!O;F]V;R!P<FEJ879I=&4N`%9AN6$@92UM86EL(&%D<F5S80!68;EA
M($9R;VTZ(&%D<F5S83H`5F&Y92!I;F9O<FUA8VEJ90!68;EA($EN=&5R;F5T
M(&%D<F5S82!J92!P<F]M:6IE;FIE;F$@;F%K;VX@<')I:F%V;&II=F%N:F$@
M;F$@)7,N($1A(&)I('9AN6$@<VEG=7)N;W-T(&)I;&$@<V'H=79A;F$L(&UO
M<F%T92!S92!P;VYO=F\@<')I:F%V:71I+@!68;EE(&EM90!68;D@8G)O=W-E
M<B!N92!P;V1ROF%V82!O=G4@;6]G=>9N;W-T+@!4<F5N=71N82!V<F5M96YS
M:V$@>F]N83H`5F&Y(&1E9F%U;'0@:61E;G1I=&5T.@!68;EE(&EM92!I('!R
M97II;64Z`%9AN6$@;F]V82"Y:69R82!Z82`E<R!J93H@)7,`5F&Y92!O<&-I
M:F4@<W4@<V'H=79A;F4@=&]K;VT@=')A:F%N:F$@;W9E('-E<VEJ92X`3W!C
M:6IE('-U('-AZ'5V86YE+@!68;EA(+EI9G)A(&IE('!O;FFY=&5N80!68;EA
M(+EI9G)A(&IE('!O;FFY=&5N82P@<')O=FIE<FET92!V8;D@92UM86EL(&D@
M<')I:F%V:71E('-E('-A(&YO=F]M(+EI9G)O;2X`5F&Y:2!U9&%L:F5N:2!S
M97)V97)I.@!*=6=O<VQA=FEJ80!:86ER`%IA;6)I:F$`6FEM8F%B=F4`6FEP
M<'D`6U-A:W)I:B!C:71I<F%N:2!T96MS=%T`6U!R:6IA=F$@<')O8FQE;6%=
M`%M0<FEK8;YI(&-I=&ER86YI('1E:W-T("T`6U!R:6MAOFD@8VET:7)A;FD@
M=&5K<W0@+2`E<R!R961O=F%=`%MR960@)7,@;V0@)7-=`%]!9&UI;FES=')A
M8VEJ80!?0TQ)`%]$871A5')E90!?3V)R:;EI(')E9`!?1W)U<&4`7U!O;6_F
M`%]/<V]B:6YE('-L:6ME+BXN`%]0<FEJ879I('-E`%])>FQA>@!?27IM:6IE
M;FD@;&EN:RXN+@!?3W!C:6IE`%]$;WIV;VQE`%]5:VQO;FD@;&EN:RXN+@!?
M4&]D97-I`$]S;V)I;F4@7W1A8F5L92XN+@!?2V]R:7-N:6-I`&EM96YI:P!L
M:7-T82!Z861A=&%K80!B97H@:6UE;F$`=D-A<F0`=V5A=&AE<BYC;VT`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O8V%?15,O````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-3$U-#,S-S4S`#`R,#`V-P`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L
M92]C85]%4R],0U]-15-304=%4R\`````````````````````````````````
M````````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-3,`,#(Q-C4T`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&]C86QE+V-A7T53+TQ#7TU%4U-!1T53+VAO<F1E+FUO
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#,V,3(S,0`Q,#4Q-30S,S<U,P`P
M,C,S,C``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````WA($E0````#&!@``'````$PV```="0``?&P```````#PD```#@```/&0
M```/`````)$```T````0D0``"````!Z1```+````)Y$```P````SD0``!```
M`$"1```8````19$```P```!>D0``$0```&N1```E````?9$```\```"CD0``
M"P```+.1```.````OY$```4```#.D0``*````-21```(````_9$```H````&
MD@``%0```!&2```2````)Y(```L````ZD@``#@```$:2```*````59(```T`
M``!@D@``+@```&Z2```.````G9(``!$```"LD@``#0```+Z2```,````S)(`
M``T```#9D@``!@```.>2```/````[I(``!@```#^D@``#````!>3```;````
M)),```X```!`DP``#@```$^3```(````7I,```D```!GDP``+@```'&3```:
M````H),``#(```"[DP``.````.Z3``!4````)Y0``%$```!\E```6@```,Z4
M``!7````*94``#0```"!E0``"0```+:5```-````P)4```<```#.E0``"@``
M`-:5```/````X94```4```#QE0``!@```/>5```1````_I4```@````0E@``
M"0```!F6```)````(Y8``"4````ME@``(````%.6```0````=)8```\```"%
ME@``"@```)66```#````H)8```\```"DE@``%````+26```)````R98```T`
M``#3E@``$@```.&6```/````])8```H````$EP``#P````^7```(````'Y<`
M`"0````HEP``%````$V7```6````8I<```@```!YEP``'P```(*7```9````
MHI<```<```"\EP``#````,27```L````T9<```X```#^EP```P````V8```+
M````$9@```<````=F```!P```"68```%````+9@```4````SF```"@```#F8
M```#````1)@``!<```!(F```"@```&"8```/````:Y@```X```![F```&```
M`(J8```C````HY@```X```#'F```%````-:8```7````ZY@``!<````#F0``
M%P```!N9```3````,YD```\```!'F0``#@```%>9```?````9ID``!T```"&
MF0``!P```*29```&````K)D```@```"SF0``#P```+R9```&````S)D```H`
M``#3F0``$P```-Z9```+````\ID``!````#^F0``%0````^:```5````)9H`
M``<````[F@``$````$.:```%````5)H``!4```!:F@``$0```'":```,````
M@IH``#L```"/F@``"0```,N:```'````U9H``!0```#=F@```P```/*:```%
M````]IH``!````#\F@``"0````V;```3````%YL``#D````KFP``$@```&6;
M```G````>)L``"P```"@FP``*@```,V;```E````^)L```H````>G```!@``
M`"F<```)````,)P```<````ZG```+P```$*<```W````<IP``"X```"JG```
M50```-F<```M````+YT``"T```!=G0``+0```(N=``!`````N9T``",```#Z
MG0``(P```!Z>```M````0IX``#,```!PG@``%0```*2>```9````NIX``"D`
M``#4G@``)````/Z>```H````(Y\``!$```!,GP``"@```%Z?```,````:9\`
M``H```!VGP``$````(&?```6````DI\``!8```"IGP``!P```,"?```'````
MR)\``!0```#0GP``"@```.6?```(````\)\```@```#YGP``!P````*@```'
M````"J````8````2H```!0```!F@```'````'Z````8````GH```"````"Z@
M```I````-Z````X```!AH```"@```'"@```$````>Z````<```"`H```"0``
M`(B@```&````DJ```!$```"9H```!P```*N@```6````LZ````0```#*H```
M"````,^@```&````V*````T```#?H```!@```.V@```>````]*```!$````3
MH0``(@```"6A```6````2*$```@```!?H0``#0```&BA```,````=J$```<`
M``"#H0```P```(NA```#````CZ$``!<```"3H0``$P```*NA```=````OZ$`
M``@```#=H0``!````.:A```(````ZZ$```@```#TH0``00```/VA```@````
M/Z(```8```!@H@``!@```&>B```5````;J(``!@```"$H@``(@```)VB```N
M````P*(``!T```#OH@``(0````VC``!4````+Z,``"D```"$HP``"@```*ZC
M```'````N:,``!4```#!HP``#@```->C```*````YJ,```\```#QHP``#0``
M``&D```/````#Z0```T````?I```"0```"VD```4````-Z0```8```!,I```
M&````%.D```=````;*0``!,```"*I```$0```)ZD```4````L*0```0```#%
MI```!@```,JD``!4````T:0```0````FI0``#@```"NE```%````.J4```4`
M``!`I0``&P```$:E```:````8J4``!$```!]I0``$0```(^E```<````H:4`
M`"H```"^I0``$````.FE```A````^J4```4````<I@``$P```"*F```2````
M-J8```H```!)I@``#P```%2F```-````9*8``!$```!RI@``$P```(2F```,
M````F*8```8```"EI@``#````*RF```&````N:8``!<```#`I@``$````-BF
M```1````Z:8```@```#[I@``!0````2G```,````"J<``!`````7IP``!0``
M`"BG```-````+J<```8````\IP``!P```$.G```-````2Z<```<```!9IP``
M"P```&&G```'````;:<```<```!UIP``%````'VG```)````DJ<```H```"<
MIP``&0```*>G```=````P:<```P```#?IP``$````.RG```%````_:<``"4`
M```#J```$@```"FH```3````/*@``"L```!0J```.P```'RH```@````N*@`
M`#8```#9J```"````!"I```,````&:D```8````FJ0``!````"VI```/````
M,JD```X```!"J0``"@```%&I```-````7*D``"$```!JJ0``'@```(RI```9
M````JZD``!X```#%J0``&P```.2I```F`````*H``!X````GJ@``'````$:J
M```F````8ZH``#,```"*J@``)@```+ZJ```K````Y:H``#@````1JP``+P``
M`$JK```2````>JL``"D```"-JP``$@```+>K``"B````RJL``!8```!MK```
M(P```(2L```H````J*P``"D```#1K```*````/NL```?````)*T``"````!$
MK0``)0```&6M```H````BZT``#````"TK0``D@```.6M```A````>*X``!P`
M``":K@``)@```+>N``!!````WJX```P````@KP``!P```"VO```'````-:\`
M``8````]KP``#0```$2O```0````4J\``!(```!CKP``$P```':O```2````
MBJ\```<```"=KP``!````*6O```0````JJ\```P```"[KP``#@```,BO```/
M````UZ\``!,```#GKP``#0```/NO```H````";````,````RL```#0```#:P
M```&````1+```!$```!+L```%P```%VP```;````=;````X```"1L````@``
M`*"P```%````H[```!````"IL```!````+JP```-````O[````X```#-L```
M`P```-RP```.````X+````@```#OL```#P```/BP```/````"+$```<````8
ML0``#0```""Q```0````+K$```L````_L0``!@```$NQ```,````4K$``!$`
M``!?L0``&0```'&Q```+````B[$```T```"7L0``(@```*6Q```*````R+$`
M`!@```#3L0``&0```.RQ```6````!K(```T````=L@``!P```"NR```4````
M,[(```L```!(L@``(@```%2R```O````=[(```L```"GL@``"0```+.R```9
M````O;(```L```#7L@``%P```..R```7````^[(```D````3LP``%@```!VS
M```/````-+,``!8```!$LP``#@```%NS```8````:K,```@```"#LP``#0``
M`(RS```F````FK,``$,```#!LP``"`````6T```2````#K0```@````AM```
M"P```"JT```O````-K0```X```!FM```!0```'6T```&````>[0```,```""
MM```!P```(:T```$````CK0```H```"3M```"@```)ZT```/````J;0``!``
M``"YM```%P```,JT```1````XK0``!<```#TM```"0````RU```%````%K4`
M``L````<M0``"@```"BU```"````,[4```4````VM0``#0```#RU```;````
M2K4``!<```!FM0``"0```'ZU```.````B+4```T```"7M0``$@```*6U```X
M````N+4``"````#QM0``"````!*V```.````&[8``'L````JM@``&````*:V
M```1````O[8```<```#1M@``!0```-FV```9````W[8```<```#YM@``"```
M``&W```&````"K<```8````1MP``$````!BW```/````*;<``!`````YMP``
M#P```$JW```+````6K<```\```!FMP``#````':W```/````@[<```<```"3
MMP``!@```)NW```.````HK<```P```"QMP``*````+ZW```/````Y[<```@`
M``#WMP``"`````"X```3````";@``!X````=N```(0```#RX```@````7K@`
M`!D```!_N```%P```)FX```E````L;@``!<```#7N```%@```.^X```$````
M!KD``!L````+N0``#0```">Y```,````-;D```,```!"N0``"````$:Y```*
M````3[D```P```!:N0``"P```&>Y```0````<[D```P```"$N0``!````)&Y
M```3````EKD``!0```"JN0``#````+^Y```)````S+D```X```#6N0``"P``
M`.6Y```;````\;D```<````-N@``!P```!6Z```*````';H```T````HN@``
M"0```#:Z```$````0+H```4```!%N@```P```$NZ```8````3[H```H```!H
MN@``!````'.Z```F````>+H```X```"?N@``?````*ZZ```5````*[L```4`
M``!!NP``!P```$>[```,````3[L```@```!<NP``"@```&6[```&````<+L`
M``@```!WNP```@```("[```&````@[L```8```"*NP``%````)&[```-````
MIKL``!````"TNP``&P```,6[```$````X;L```D```#FNP``$````/"[```)
M`````;P```D````+O```!0```!6\```:````&[P```@````VO```!@```#^\
M```9````1KP```X```!@O```!P```&^\```'````=[P```4```!_O```"0``
M`(6\```*````C[P```(```":O```!@```)V\```-````I+P```D```"RO```
M!@```+R\```2````P[P```D```#6O```!P```."\```4````Z+P``!T```#]
MO```!@```!N]```*````(KT```0````MO0``"0```#*]```(````/+T``!$`
M``!%O0``"0```%>]```&````8;T```T```!HO0``!@```':]```$````?;T`
M`#D```""O0``/0```+R]```Z````^KT``!X````UO@``!0```%2^```.````
M6KX```0```!IO@``!@```&Z^```A````=;X``!4```"7O@``!@```*V^```$
M````M+X``!$```"YO@``!@```,N^```*````TKX``"(```#=O@``!`````"_
M```%````!;\``!T````+OP``!````"F_```,````+K\```H````[OP``"```
M`$:_```)````3[\```4```!9OP``.@```%^_```P````FK\``#4```#+OP``
M*0````'```!'````*\```#@```!SP```*0```*S````_````UL```"X````6
MP0``+0```$7!```?````<\$```\```"3P0``$@```*/!```+````ML$``"8`
M``#"P0``*0```.G!```D````$\(``"8````XP@``"````%_"```*````:,(`
M``D```!SP@``!P```'W"```@````A<(``"````"FP@``)@```,?"```*````
M[L(``!D```#YP@``*0```!/#```6````/<,``!(```!4PP``!P```&?#```*
M````;\,```P```!ZPP``#P```(?#```0````E\,``$````"HPP``<````.G#
M``!F````6L0```X```#!Q```"0```-#$```*````VL0``!(```#EQ```$P``
M`/C$```,````#,4```8````9Q0``#P```"#%```2````,,4``!````!#Q0``
M$0```%3%```<````9L4``",```"#Q0``:@```*?%```/````$L8```4````B
MQ@``$````"C&```)````.<8```0```!#Q@``"P```$C&```:````5,8``!0`
M``!OQ@``#````(3&```,````D<8```\```">Q@``%0```*[&```I````Q,8`
M`"H```#NQ@``)@```!G'```G````0,<``"D```!HQP``*@```)+'```9````
MO<<``$(```#7QP``$0```!K(```2````+,@``!,````_R```%````%/(```/
M````:,@``!8```!XR```%P```(_(```0````I\@``!$```"XR```-````,K(
M```3````_\@``!(````3R0``-0```";)```4````7,D```<```!QR0``#```
M`'G)```@````ALD``!0```"GR0``$0```+S)```7````SLD``!P```#FR0``
M$P````/*```4````%\H``!H````LR@``$0```$?*```:````6<H``!X```!T
MR@``&@```)/*```3````KLH``!4```#"R@``$0```-C*```4````ZLH``!<`
M``#_R@``%0```!?+```)````+<L``!D````WRP``!````%'+```'````5LL`
M``L```!>RP``$0```&K+```&````?,L```8```"#RP``!@```(K+```%````
MD<L```<```"7RP``!P```)_+```%````I\L``!8```"MRP``!@```,3+```&
M````R\L```0```#2RP``!````-?+```'````W,L```X```#DRP``#````//+
M```,`````,P```T````-S```"@```!O,```.````)LP```4````US```*```
M`#O,```.````9,P```P```!SS```#P```(#,```*````D,P```@```";S```
M"0```*3,```K````KLP```0```#:S```"````-_,```F````Z,P``!(````/
MS0``#P```"+-```&````,LT```H````YS0``!P```$3-```(````3,T``"``
M``!5S0``"0```';-```,````@,T```T```"-S0``#@```)O-```6````JLT`
M`!$```#!S0``!@```-/-```#````VLT```8```#>S0``&0```.7-```'````
M_\T```0````'S@``"P````S.```+````&,X```<````DS@``!P```"S.```6
M````-,X```T```!+S@``#0```%G.```*````9\X``!````!RS@``#P```(/.
M```1````D\X``!<```"ES@``"@```+W.```1````R,X```@```#:S@``!```
M`./.```/````Z,X``#H```#XS@``!0```#//```,````.<\``!X```!&SP``
M#@```&7/```0````=,\```L```"%SP``#````)'/```)````GL\```<```"H
MSP``"@```+#/```)````N\\```X```#%SP``$````-3/```:````Y<\```H`
M````T```"0````O0```*````%=````P````@T```#P```"W0```(````/=``
M``8```!&T```!P```$W0```+````5=```$<```!AT```#0```*G0```)````
MM]````0```#!T````P```,;0```3````RM```!,```#>T```$P```/+0```*
M````!M$```(````1T0``!````!31```E````&=$```,````_T0``!0```$/1
M```J````2=$```H```!TT0``!0```'_1```$````A=$```H```"*T0``#0``
M`)71```&````H]$```@```"JT0``"````+/1```$````O-$```4```#!T0``
M:````,?1```)````,-(```P````ZT@``!0```$?2```&````3=(``!L```!4
MT@``+P```'#2```0````H-(```H```"QT@``#P```+S2```*````S-(```D`
M``#7T@``$P```.'2```;````]=(``!@````1TP``%P```"K3```.````0M,`
M``,```!1TP``!P```%73```(````7=,```<```!FTP``"@```&[3```+````
M>=,```<```"%TP``40```(W3```0````W],```P```#PTP``#0```/W3```:
M````"]0``$H````FU```&0```''4```&````B]0```8```"2U```!@```)G4
M```?````H-0```8```#`U```"0```,?4```8````T=0``!<```#JU```!@``
M``+5```-````"=4``"(````7U0``5P```#K5```3````DM4``",```"FU0``
M$P```,K5```"````WM4```L```#AU0``"````.W5```-````]M4```H````$
MU@``!P````_6```4````%]8```8````LU@``"````#/6```.````/-8```<`
M``!+U@``"@```%/6```+````7M8```<```!JU@``#````'+6```-````?]8`
M``P```"-U@``"0```)K6```)````I-8```H```"NU@``!P```+G6```)````
MP=8```<```#+U@``"@```-/6```;````WM8``!(```#ZU@``"@````W7```)
M````&-<``!`````BUP``!P```#/7```2````.]<```0```!.UP``!P```%/7
M```%````6]<```4```!AUP``"P```&?7```4````<]<``!$```"(UP``&@``
M`)K7```6````M=<``!0```#,UP``%P```.'7```8````^=<``!P````2V```
M&0```"_8```'````2=@```4```!1V```#0```%?8```,````9=@```@```!R
MV```%P```'O8```+````D]@``!,```"?V```!````+/8```*````N-@```0`
M``##V```#0```,C8```,````UM@```4```#CV```"0```.G8```%````\]@`
M``<```#YV```!0````'9```$````!]D```(````,V0``.`````_9```L````
M2-D``!(```!UV0``*0```(C9```R````LMD```H```#EV0``+````/#9```N
M````'=H``#,```!,V@``,P```(#:```X````M-H```\```#MV@``&````/W:
M```0````%ML```\````GVP``$P```#?;```5````2]L``!0```!AVP``$@``
M`';;```4````B=L``!4```">VP``+0```+3;```M````XML``#$````0W```
M+@```$+<```O````<=P``"P```"AW```8@```,[<```3````,=T```T```!%
MW0``"````%/=```(````7-T```P```!EW0``*P```'+=```A````GMT``!H`
M``#`W0``"0```-O=``!%````Y=T``$$````KW@``!````&W>```3````<MX`
M`!0```"&W@``#@```)O>```3````JMX``!@```"^W@``!@```-?>```)````
MWMX```H```#HW@``#P```//>```0`````]\```<````4WP``#@```!S?```%
M````*]\``!L````QWP``"````$W?```&````5M\``!0```!=WP``$0```'+?
M```.````A-\``#@```"3WP```@```,S?```&````S]\```X```#6WP``!0``
M`.7?```'````Z]\```X```#SWP``!@````+@```$````">```"D````.X```
M%P```#C@```?````4.```%P```!PX```%````,W@```^````XN```!\````A
MX0``$````$'A```'````4N$```X```!:X0``#````&GA```,````=N$``!,`
M``"#X0``"@```)?A```=````HN$``!D```#`X0``!0```-KA```1````X.$`
M`!$```#RX0``)`````3B```5````*>(``!(````_X@``#@```%+B```9````
M8>(```@```![X@``"0```(3B```-````CN(```H```"<X@``!P```*?B```/
M````K^(```8```"_X@``"P```,;B```*````TN(```<```#=X@``"````.7B
M```%````[N(``!\```#TX@``!@```!3C```0````&^,```@````LXP``#0``
M`#7C```(````0^,``!(```!,XP``+````%_C```:````C.,```D```"GXP``
M"@```+'C```5````O.,```4```#2XP``%````-CC```$````[>,``!````#R
MXP``!@````/D```'````"N0``!X````2Y```*````#'D```*````6N0``!$`
M``!EY```&@```'?D```4````DN0```0```"GY```!````*SD```+````L>0`
M``4```"]Y```!@```,/D```(````RN0```8```#3Y```"@```-KD```;````
MY>0``#0````!Y0``-````#;E```@````:^4``"D```",Y0``(````+;E``!!
M````U^4``!H````9Y@``*````#3F```I````7>8``"(```"'Y@``!@```*KF
M```(````L>8```4```"ZY@``"````,#F```9````R>8``!D```#CY@``*@``
M`/WF```C````*.<``"X```!,YP``-````'OG```(````L.<``!<```"YYP``
M"@```-'G```'````W.<``"$```#DYP``$`````;H```.````%^@```L````F
MZ```!P```#+H```3````.N@```@```!.Z```"P```%?H```*````8^@``!0`
M``!NZ```#P```(/H```R````D^@```L```#&Z```!0```-+H```%````V.@`
M`!<```#>Z```#P```/;H```$````!ND```H````+Z0``"0```!;I```+````
M(.D```T````LZ0``#````#KI```.````1^D```4```!6Z0``!````%SI```-
M````8>D``#(```!OZ0``10```*+I```7````Z.D``!X`````Z@``%````!_J
M```%````-.H``!0````ZZ@``!P```$_J```.````5^H``"D```!FZ@``!@``
M`)#J```,````E^H```T```"DZ@``$0```++J```+````Q.H``#8```#0Z@``
M"@````?K```B````$NL```L````UZP``#P```$'K```R````4>L``"4```"$
MZP``#@```*KK```%````N>L```X```"_ZP``$P```,[K```'````XNL``!$`
M``#JZP``!P```/SK```4````!.P``!@````9[```!P```#+L```%````.NP`
M``P```!`[```#````$WL```2````6NP```0```!M[```!P```'+L```*````
M>NP```L```"%[```#````)'L```.````GNP```X```"M[```!0```+SL```%
M````PNP``"X```#([```)@```/?L```C````'NT```,```!"[0``$@```$;M
M```&````6>T``!X```!@[0``&````'_M```E````F.T```T```"^[0``"0``
M`,SM```#````UNT```<```#:[0``"@```.+M```"````[>T```P```#P[0``
M%0```/WM```+````$^X``!D````?[@``(````#GN```2````6NX```4```!M
M[@``"@```'/N```5````?NX``!(```"4[@``#````*?N```$````M.X```<`
M``"Y[@``#````,'N``!2````SNX``!<````A[P``$@```#GO```'````3.\`
M``8```!4[P``#@```%OO```,````:N\```T```!W[P``%0```(7O```2````
MF^\```\```"N[P``%````+[O```;````T^\``!````#O[P``:0````#P```:
M````:O```!<```"%\```)P```)WP```:````Q?```!<```#@\```&P```/CP
M```9````%/$``!\````N\0``$P```$[Q```(````8O$```<```!K\0``"```
M`'/Q```)````?/$``!4```"&\0``#0```)SQ```C````JO$``!,```#.\0``
M`P```.+Q``!&````YO$``#\````M\@``-P```&WR``!7````I?(```4```#]
M\@``'P````/S```O````(_,```H```!3\P``"````%[S```-````9_,``"T`
M``!U\P``!````*/S``!/````J/,``"4```#X\P``'````![T```+````._0`
M`!\```!']```'0```&?T```E````A?0``"````"K]```)````,ST```@````
M\?0```L````2]0``!P```![U```-````)O4```P````T]0``%P```$'U```&
M````6?4``#D```!@]0``#````)KU```'````I_4```D```"O]0``$P```+GU
M```)````S?4```0```#7]0``$````-SU```(````[?4```@```#V]0``!```
M`/_U```+````!/8```P````0]@``$@```!WV```1````,/8```P```!"]@``
M&@```$_V```/````:O8```<```!Z]@``#0```(+V```4````D/8```X```"E
M]@``#````+3V```;````P?8``"P```#=]@``$P````KW```<````'O<``"@`
M```[]P``!@```&3W```'````:_<``!,```!S]P``!0```(?W```$````C?<`
M`!<```"2]P``"@```*KW```,````M?<```D```#"]P``!@```,SW```)````
MT_<```@```#=]P``"0```.;W```*````\/<``!$```#[]P``!@````WX```.
M````%/@```X````C^```#0```#+X```+````0/@``!T```!,^```"P```&KX
M```"````=O@```<```!Y^```!@```('X```)````B/@```<```"2^```.P``
M`)KX```H````UO@``#0```#_^```%0```#3Y```%````2OD```<```!0^0``
M"````%CY```'````8?D```4```!I^0``!P```&_Y```.````=_D```D```"&
M^0``!@```)#Y```(````E_D```L```"@^0``!P```*SY```(````M/D```<`
M``"]^0``%@```,7Y```)````W/D```8```#F^0``"P```.WY```<````^?D`
M`!0````6^@``!P```"OZ```1````,_H```@```!%^@``"````$[Z```0````
M5_H``!````!H^@``!@```'GZ```9````@/H```H```":^@``'````*7Z```'
M````POH```4```#*^@``$````-#Z```4````X?H```L```#V^@``#0````+[
M```7````$/L```0````H^P``"0```"W[```*````-_L```<```!"^P```@``
M`$K[```.````3?L```@```!<^P``(P```&7[```X````B?L``#$```#"^P``
M)P```/3[``!D````'/P``!0```"!_```50```);\```X````[/P``$H````E
M_0``6P```'#]```H````S/T``#@```#U_0``*````"[^```L````5_X``!L`
M``"$_@``/@```*#^``"I`0``W_X``",```")``$`%P```*T``0!(````Q0`!
M`(4````.`0$`,````)0!`0!!````Q0$!`%L````'`@$`20```&,"`0`=````
MK0(!`!@```#+`@$`(0```.0"`0`?````!@,!`"L````F`P$`)P```%(#`0`=
M````>@,!`!$```"8`P$`,P```*H#`0`E````W@,!`"<````$!`$`'P```"P$
M`0`P````3`0!`&D```!]!`$`/0```.<$`0!E````)04!`$T```"+!0$`+P``
M`-D%`0`N````"08!`#`````X!@$`5````&D&`0!:````O@8!`$@````9!P$`
M2@```&('`0`R````K0<!`"\```#@!P$`+````!`(`0`M````/0@!`'$```!K
M"`$`;P```-T(`0"S````30D!`!<````!"@$`)0```!D*`0`R````/PH!`"D`
M``!R"@$`/@```)P*`0`B````VPH!`%(```#^"@$`)0```%$+`0`+````=PL!
M`+$```"#"P$`10```#4,`0`A````>PP!`#````"=#`$`)0```,X,`0`<````
M]`P!`#$````1#0$`!P```$,-`0`'````2PT!``0```!3#0$`#0```%@-`0`+
M````9@T!``X```!R#0$`"P```($-`0`%````C0T!`!````"3#0$``@```*0-
M`0!9````IPT!``4````!#@$`$@````<.`0`$````&@X!``<````?#@$`"```
M`"<.`0`%````,`X!``,````V#@$`$````#H.`0`,````2PX!`!,```!8#@$`
M#0```&P.`0`"````>@X!``<```!]#@$`!@```(4.`0`4````C`X!``P```"A
M#@$`&````*X.`0`&````QPX!`!(```#.#@$`#````.$.`0`#````[@X!`"H`
M``#R#@$`!````!T/`0`&````(@\!``<````I#P$`'P```#$/`0`U````40\!
M`"X```"'#P$`+P```+8/`0`7````Y@\!`"````#^#P$`&P```!\0`0`8````
M.Q`!`"0```!4$`$`'P```'D0`0`:````F1`!`"$```"T$`$`(````-80`0`:
M````]Q`!`#(````2$0$`+P```$41`0`K````=1$!`!\```"A$0$`(P```,$1
M`0`?````Y1$!`!H````%$@$`(0```"`2`0`E````0A(!`"8```!H$@$`)0``
M`(\2`0`D````M1(!`!@```#:$@$`'0```/,2`0`D````$1,!`!@````V$P$`
M(@```$\3`0`L````<A,!`"\```"?$P$`%0```,\3`0`E````Y1,!`#P````+
M%`$`'P```$@4`0`C````:!0!`!\```",%`$`(````*P4`0`:````S10!`!@`
M``#H%`$`)@````$5`0`>````*!4!`"D```!'%0$`'@```'$5`0`Q````D!4!
M``D```#"%0$`#````,P5`0`7````V14!`"\```#Q%0$`)````"$6`0`'````
M1A8!``\```!.%@$`%````%X6`0`.````<Q8!``T```""%@$`)````)`6`0`%
M````M18!``<```"[%@$`(@```,,6`0`E````YA8!`!H````,%P$`'0```"<7
M`0`:````11<!``<```!@%P$`QP```&@7`0`+````,!@!`!4````\&`$`!@``
M`%(8`0`)````61@!``L```!C&`$`%P```&\8`0`&````AQ@!`#,```".&`$`
M$P```,(8`0`3````UA@!``<```#J&`$`#P```/(8`0`'`````AD!`#(````*
M&0$`(0```#T9`0`3````7QD!``P```!S&0$`$0```(`9`0`R````DAD!``@`
M``#%&0$`"0```,X9`0`*````V!D!`!0```#C&0$`"@```/@9`0`=`````QH!
M``@````A&@$`'P```"H:`0`(````2AH!`!H```!3&@$`)P```&X:`0`&````
MEAH!`!4```"=&@$`!P```+,:`0`(````NQH!``D```#$&@$`/P```,X:`0`'
M````#AL!``\````6&P$`#@```"8;`0`0````-1L!``D```!&&P$`"0```%`;
M`0`(````6AL!`!,```!C&P$`!P```'<;`0`9````?QL!``H```"9&P$`%P``
M`*0;`0`4````O!L!``H```#1&P$`#````-P;`0`7````Z1L!``0````!'`$`
M*@````8<`0`1````,1P!``<```!#'`$``@```$L<`0`0````3AP!`!@```!?
M'`$`"P```'@<`0`#````A!P!``@```"('`$`!@```)$<`0`'````F!P!``T`
M``"@'`$`"P```*X<`0`4````NAP!`!4```#/'`$`#@```.4<`0`O````]!P!
M`"`````D'0$`'````$4=`0`,````8AT!`#$```!O'0$`!0```*$=`0`2````
MIQT!`#\```"Z'0$`$@```/H=`0`*````#1X!``8````8'@$`!````!\>`0`$
M````)!X!``H````I'@$`$P```#0>`0`%````2!X!``8```!.'@$`!@```%4>
M`0`$````7!X!``P```!A'@$`"@```&X>`0`%````>1X!`!@```!_'@$`&0``
M`)@>`0`?````LAX!`!T```#2'@$`$0```/`>`0`"`````A\!``0````%'P$`
M"@````H?`0`&````%1\!``4````<'P$``P```"(?`0`,````)A\!`$4````S
M'P$`&@```'D?`0`H````E!\!`%,```"]'P$`&0```!$@`0!R````*R`!`"``
M``">(`$`-0```+\@`0`A````]2`!`$4````7(0$`,````%TA`0`H````CB$!
M`"D```"W(0$`)@```.$A`0`E````""(!`"@````N(@$`*````%<B`0`B````
M@"(!`#````"C(@$`$@```-0B`0`3````YR(!`!````#[(@$`>0````PC`0`)
M````AB,!`',```"0(P$`?`````0D`0`K````@20!`%0```"M)`$`%P````(E
M`0`6````&B4!``\````Q)0$`'P```$$E`0!`````824!`!\```"B)0$`'```
M`,(E`0!1````WR4!`!0````Q)@$`"@```$8F`0`%````428!``8```!7)@$`
M"````%XF`0`%````9R8!`!(```!M)@$`$````(`F`0`3````D28!`!T```"E
M)@$`#P```,,F`0`/````TR8!``0```#C)@$`"0```.@F`0`+````\B8!``<`
M``#^)@$`!0````8G`0`4````#"<!``<````A)P$`"````"DG`0`/````,B<!
M``@```!")P$`#````$LG`0`/````6"<!``8```!H)P$`%````&\G`0`&````
MA"<!``P```"+)P$`"````)@G`0`$````H2<!``H```"F)P$`!P```+$G`0`$
M````N2<!`!D```"^)P$``@```-@G`0`"````VR<!``D```#>)P$`!@```.@G
M`0`&````[R<!`"<```#V)P$``@```!XH`0`$````(2@!``\````F*`$`$P``
M`#8H`0`'````2B@!``<```!2*`$`!@```%HH`0`&````82@!`!````!H*`$`
M$@```'DH`0`"````C"@!``8```"/*`$`"0```)8H`0`B````H"@!``<```##
M*`$`!P```,LH`0`+````TR@!``4```#?*`$``@```.4H`0`+````Z"@!`%T!
M``#T*`$`#````%(J`0`2````7RH!``P```!R*@$`!@```'\J`0`&````ABH!
M``8```"-*@$``@```)0J`0`8````ERH!``H```"P*@$`$0```+LJ`0`L````
MS2H!`!8```#Z*@$`"0```!$K`0`4````&RL!``4````P*P$`*@```#8K`0`2
M````82L!``H```!T*P$`&P```'\K`0`/````FRL!``L```"K*P$`$````+<K
M`0`)````R"L!`!(```#2*P$`,P```.4K`0`.````&2P!`!@````H+`$`#```
M`$$L`0`3````3BP!`!<```!B+`$`!@```'HL`0`/````@2P!`!4```"1+`$`
M$0```*<L`0`;````N2P!`!(```#5+`$`$@```.@L`0`(````^RP!``D````$
M+0$`.@````XM`0`B````22T!`#D```!L+0$`0P```*8M`0!E````ZBT!`&(`
M``!0+@$`:P```+,N`0!H````'R\!`#L```"(+P$`#@```,0O`0`3````TR\!
M``T```#G+P$`#P```/4O`0`6````!3`!``4````<,`$`"0```"(P`0`3````
M+#`!``T```!`,`$`&0```$XP`0`7````:#`!`"\```"`,`$`*@```+`P`0`6
M````VS`!`!````#R,`$`$`````,Q`0`&````%#$!`!D````;,0$`(@```#4Q
M`0`5````6#$!`!(```!N,0$`'0```($Q`0`5````GS$!`!,```"U,0$`%```
M`,DQ`0`2````WC$!`#(```#Q,0$`(````"0R`0`D````13(!`!````!J,@$`
M(@```'LR`0`J````GC(!``8```#),@$`$@```-`R`0!`````XS(!``T````D
M,P$`!P```#(S`0`*````.C,!``<```!%,P$`!P```$TS`0`%````53,!``<`
M``!;,P$`"@```&,S`0`$````;C,!`!P```!S,P$`#@```)`S`0`1````GS,!
M`!,```"Q,P$`%0```,4S`0`Y````VS,!``L````5-`$`%0```"$T`0`<````
M-S0!`!P```!4-`$`'@```'$T`0`7````D#0!`!````"H-`$`#P```+DT`0`C
M````R30!`"$```#M-`$`!P````\U`0`&````%S4!``@````>-0$`%0```"<U
M`0`(````/34!``D```!&-0$`$0```%`U`0`)````8C4!`!0```!L-0$`%@``
M`($U`0`J````F#4!``<```##-0$`#P```,LU`0`%````VS4!`!0```#A-0$`
M#P```/8U`0`.````!C8!`"H````5-@$`"0```$`V`0`'````2C8!`!(```!2
M-@$``P```&4V`0`%````:38!`!(```!O-@$`#````((V`0`9````CS8!`$$`
M``"I-@$`%0```.LV`0`K`````3<!`#0````M-P$`,@```&(W`0`U````E3<!
M``@```#+-P$`!0```-0W`0`)````VC<!``<```#D-P$`-P```.PW`0`V````
M)#@!`#8```!;.`$`8P```)(X`0`U````]C@!`#4````L.0$`-0```&(Y`0!/
M````F#D!`"X```#H.0$`,0```!<Z`0`U````23H!`#L```!_.@$`*````+LZ
M`0`K````Y#H!`"X````0.P$`/````#\[`0`\````?#L!`!(```"Y.P$`"P``
M`,P[`0`,````V#L!``0```#E.P$`#@```.H[`0`@````^3L!`"$````:/`$`
M!P```#P\`0`'````1#P!`!0```!,/`$`"P```&$\`0`(````;3P!``H```!V
M/`$`"P```($\`0`'````C3P!``8```"5/`$`!0```)P\`0`(````HCP!``8`
M``"K/`$`"@```+(\`0`Q````O3P!`!,```#O/`$`#0````,]`0`'````$3T!
M``<````9/0$`"0```"$]`0`'````*ST!`!$````S/0$`"````$4]`0`4````
M3CT!``8```!C/0$`"````&H]`0`(````<ST!``X```!\/0$`!@```(L]`0`F
M````DCT!`!$```"Y/0$`)P```,L]`0`0````\ST!``@````$/@$`#@````T^
M`0`,````'#X!``<````I/@$``P```#$^`0`#````-3X!`!L````Y/@$`%P``
M`%4^`0`_````;3X!``D```"M/@$`!0```+<^`0`(````O3X!``<```#&/@$`
M:@```,X^`0`Q````.3\!``8```!K/P$`"@```'(_`0`B````?3\!`"````"@
M/P$`)P```,$_`0`T````Z3\!`"4````>0`$`*@```$1``0!P````;T`!`#0`
M``#@0`$`"````!5!`0`(````'D$!`!8````G00$`#````#Y!`0`-````2T$!
M`!0```!900$`$P```&Y!`0`7````@D$!`!4```":00$`#0```+!!`0`4````
MOD$!``<```#300$`&````-M!`0`;````]$$!`!8````00@$`%@```"="`0`:
M````/D(!``0```!90@$`!@```%Y"`0!V````94(!``0```#<0@$`%````.%"
M`0`$````]D(!``0```#[0@$`&@````!#`0`8````&T,!`!0````T0P$`%```
M`$E#`0`D````7D,!`#D```"#0P$`$0```+U#`0`M````ST,!``@```#]0P$`
M(0````9$`0`4````*$0!`!`````]1`$`'0```$Y$`0`7````;$0!`!,```"$
M1`$`$P```)A$`0`1````K$0!``8```"^1`$`%0```,5$`0`)````VT0!`!@`
M``#E1`$`%P```/Y$`0`.````%D4!``@````E10$`!0```"Y%`0`1````-$4!
M`!$```!&10$`"0```%A%`0`6````8D4!``8```!Y10$`!0```(!%`0`'````
MAD4!``D```".10$`"````)A%`0`'````H44!``D```"I10$`%P```+-%`0`*
M````RT4!``H```#610$`&P```.%%`0`E````_44!``P````C1@$`&````#!&
M`0`%````248!`"````!/1@$`)0```'!&`0`E````ED8!`#D```"\1@$`1@``
M`/9&`0`U````/4<!`$4```!S1P$`"0```+E'`0`*````PT<!``8```#.1P$`
M!@```-5'`0`8````W$<!``\```#U1P$`"@````5(`0`-````$$@!`"@````>
M2`$`*````$=(`0`@````<$@!`"D```"12`$`(````+M(`0`Q````W$@!`"D`
M```.20$`)@```#A)`0`S````7TD!`#X```"320$`,@```-))`0`U````!4H!
M`$0````[2@$`/0```(!*`0`7````ODH!`#H```#62@$`&````!%+`0#,````
M*DL!`!\```#W2P$`,0```!=,`0`T````24P!`#8```!^3`$`-@```+5,`0`H
M````[$P!`"<````530$`,@```#U-`0`U````<$T!`$@```"F30$`H````.]-
M`0`F````D$X!`"D```"W3@$`-@```.%.`0!C````&$\!``P```!\3P$`!```
M`(E/`0`&````CD\!``4```"53P$`#P```)M/`0`2````JT\!`!$```"^3P$`
M%````-!/`0`>````Y4\!``<````$4`$`!`````Q0`0`/````$5`!``P````A
M4`$`$````"Y0`0`,````/U`!`!````!,4`$`#````%U0`0!*````:E`!``@`
M``"U4`$`%````+Y0`0`%````TU`!`!(```#94`$`&````.Q0`0`;````!5$!
M``\````A40$``@```#%1`0`*````-%$!`!4````_40$`!````%51`0`2````
M6E$!`!````!M40$``P```'Y1`0`0````@E$!``@```"340$`$````)Q1`0`0
M````K5$!``T```"^40$`$P```,Q1`0`8````X%$!``L```#Y40$`"`````52
M`0`-````#E(!``\````<4@$`&P```"Q2`0`/````2%(!`!````!84@$`*@``
M`&E2`0`-````E%(!`"(```"B4@$`&@```,52`0`7````X%(!`!(```#X4@$`
M"0````M3`0`5````%5,!``H````K4P$`+P```#93`0`W````9E,!``\```">
M4P$`#@```*Y3`0`B````O5,!`!````#@4P$`$@```/%3`0`3````!%0!``D`
M```85`$`*@```")4`0`8````350!`!@```!F5`$`%P```']4`0`7````EU0!
M``@```"O5`$`#@```+A4`0`H````QU0!`%0```#P5`$`"````$55`0`4````
M3E4!``L```!C50$`#@```&]5`0`[````?E4!`!(```"Z50$`!P```,U5`0`1
M````U54!``,```#G50$`!P```.M5`0`%````\U4!``H```#Y50$`"@````16
M`0`,````#U8!``X````<5@$`%````"M6`0`1````0%8!`!0```!25@$`"```
M`&=6`0`&````<%8!``L```!W5@$`"@```(-6`0`(````CE8!`!$```"75@$`
M$@```*E6`0`K````O%8!`"$```#H5@$`"@````I7`0`2````%5<!`!(````H
M5P$`&@```#M7`0!%````5E<!`#4```"<5P$`$P```-)7`0`0````YE<!`)0`
M``#W5P$`(@```(Q8`0`1````KU@!``<```#!6`$`!0```,E8`0`P````SU@!
M``<`````60$`!P````A9`0`%````$%D!``8````660$`#@```!U9`0`-````
M+%D!``X````Z60$`#0```$E9`0`4````5UD!``\```!L60$`"@```'Q9`0`1
M````AUD!``<```"960$`"0```*%9`0`9````JUD!``X```#%60$`+P```-19
M`0`1````!%H!``@````66@$`$P```!]:`0`B````,UH!`"D```!66@$`+0``
M`(!:`0`L````KEH!`!T```#;6@$`'````/E:`0`K````%EL!`"````!"6P$`
M&P```&-;`0`$````?UL!`!D```"$6P$`"P```)Y;`0`4````JEL!``,```"_
M6P$`!@```,-;`0`+````REL!``P```#66P$`#0```.-;`0`2````\5L!``\`
M```$7`$`!````!1<`0`;````&5P!`!P````U7`$`#P```%)<`0`.````8EP!
M`!$```!Q7`$`$@```(-<`0`:````EEP!``<```"Q7`$`"0```+E<`0`.````
MPUP!``P```#27`$`"@```-]<`0`(````ZEP!``P```#S7`$`!0````!=`0`9
M````!ET!`!`````@70$`!@```#%=`0`M````.%T!``X```!F70$`E@```'5=
M`0`;````#%X!``H````H7@$`!````#->`0`.````.%X!``4```!'7@$`!P``
M`$U>`0`&````55X!``P```!<7@$``P```&E>`0`%````;5X!``8```!S7@$`
M%````'I>`0`0````CUX!`!(```"@7@$`'````+->`0`&````T%X!``<```#7
M7@$`$P```-]>`0`+````\UX!``L```#_7@$`!0````M?`0`H````$5\!``<`
M```Z7P$`!@```$)?`0`<````25\!``P```!F7P$`!P```'-?`0`(````>U\!
M``4```"$7P$`"0```(I?`0`+````E%\!``8```"@7P$`!0```*=?`0`/````
MK5\!`!````"]7P$`!@```,Y?`0`1````U5\!``H```#G7P$`!P```/)?`0`/
M````^E\!`"P````*8`$`!0```#=@`0`)````/6`!``0```!'8`$`"0```$Q@
M`0`(````5F`!`!<```!?8`$`$P```'=@`0`&````BV`!``T```"28`$`!@``
M`*!@`0`$````IV`!`#D```"L8`$`.P```.9@`0`X````(F$!`",```!;80$`
M!0```']A`0`1````A6$!``<```"780$`"0```)]A`0`;````J6$!`!4```#%
M80$`!@```-MA`0`%````XF$!`!P```#H80$`$0````5B`0`)````%V(!`!T`
M```A8@$``P```#]B`0`%````0V(!`"8```!)8@$`!0```'!B`0`1````=F(!
M`!(```"(8@$`"````)MB`0`)````I&(!``4```"N8@$`0P```+1B`0!'````
M^&(!`$8```!`8P$`,0```(=C`0!$````N6,!`$0```#^8P$`+P```$-D`0!4
M````<V0!`#(```#(9`$`-@```/MD`0`M````,F4!`!$```!@90$`%0```')E
M`0`,````B&4!`"X```"590$`(````,1E`0`>````Y64!`!T````$9@$`!P``
M`")F`0`(````*F8!``H````S9@$`!P```#YF`0`F````1F8!`"D```!M9@$`
M0````)=F`0`)````V&8!`!\```#B9@$`+P````)G`0`9````,F<!`!<```!,
M9P$`"````&1G`0`,````;6<!``P```!Z9P$`#P```(=G`0`0````EV<!`$``
M``"H9P$`D0```.EG`0!M````>V@!`"(```#I:`$`$`````QI`0`1````'6D!
M`!0````O:0$`%0```$1I`0`4````6FD!``<```!O:0$`$@```'=I`0`1````
MBFD!`!````"<:0$`%P```*UI`0`T````Q6D!`"H```#Z:0$`E@```"5J`0`3
M````O&H!``4```#0:@$`$P```-9J`0`)````ZFH!``H```#T:@$`"@```/]J
M`0`:````"FL!`!L````E:P$`$P```$%K`0`2````56L!`!,```!H:P$`&@``
M`'QK`0`L````EVL!`"T```#$:P$`*0```/)K`0`K````'&P!`"L```!(;`$`
M+````'1L`0`:````H6P!`(0```"\;`$`&@```$%M`0`;````7&T!`!H```!X
M;0$`&P```)-M`0`1````KVT!`!H```#!;0$`&P```-QM`0`7````^&T!`!@`
M```0;@$`+P```"EN`0`8````66X!`!@```!R;@$`1````(MN`0`3````T&X!
M``P```#D;@$`&````/%N`0`M````"F\!`!0````X;P$`(P```$UO`0`J````
M<6\!`"0```"<;P$`(0```,%O`0`E````XV\!`"X````)<`$`&0```#AP`0`T
M````4G`!`#L```"'<`$`)````,-P`0`L````Z'`!`"$````5<0$`&````#=Q
M`0`?````4'$!`!\```!P<0$`(0```)!Q`0`)````LG$!`!L```"\<0$`!```
M`-AQ`0`'````W7$!``L```#E<0$`$@```/%Q`0`&````!'(!``<````+<@$`
M!P```!-R`0`&````&W(!``<````B<@$`!0```"IR`0`$````,'(!`!4````U
M<@$`!@```$MR`0`(````4G(!``8```!;<@$`!````&)R`0`*````9W(!`!0`
M``!R<@$`'````(=R`0`7````I'(!`!4```"\<@$`"@```-)R`0`;````W7(!
M``4```#Y<@$`,````/]R`0`.````,',!`!`````_<P$`&P```%!S`0`3````
M;',!``T```"`<P$`#0```(YS`0`W````G',!``0```#4<P$`"````-ES`0`G
M````XG,!`!,````*=`$`#@```!YT`0`&````+70!``P````T=`$`!@```$%T
M`0`&````2'0!`"4```!/=`$`#@```'5T`0`,````A'0!`!8```"1=`$`%```
M`*AT`0`:````O70!`!$```#8=`$`!P```.IT`0`$````\G0!``<```#W=`$`
M*@```/]T`0`%````*G4!``@````P=0$`$@```#EU`0`4````3'4!``<```!A
M=0$`!P```&EU`0`%````<74!``T```!W=0$`#````(5U`0`+````DG4!`!H`
M``">=0$`%P```+EU`0`,````T74!`!8```#>=0$`#````/5U`0`2`````G8!
M``@````5=@$`!@```!YV`0`8````)78!`$0````^=@$`"````(-V`0`,````
MC'8!`"<```"9=@$`&@```,%V`0`9````W'8!`!(```#V=@$`#`````EW`0`)
M````%G<!``<````@=P$`"@```"AW`0`)````,W<!``X````]=P$`$````$QW
M`0`F````77<!``P```"$=P$`"````)%W`0`3````FG<!``P```"N=P$`#0``
M`+MW`0`(````R7<!`!````#2=P$`!````.-W`0`9````Z'<!`&8````">`$`
M%@```&EX`0`*````@'@!``0```"+>`$`!````)!X`0`9````E7@!`!H```"O
M>`$`&P```,IX`0`)````YG@!``(```#P>`$`!````/-X`0`I````^'@!``,`
M```B>0$`!0```"9Y`0`H````+'D!``H```!5>0$`!0```&!Y`0`1````9GD!
M`!<```!X>0$`&@```)!Y`0`&````JWD!``@```"R>0$`"````+MY`0`$````
MQ'D!``4```#)>0$`?0```,]Y`0`*````37H!``T```!8>@$`!````&9Z`0`%
M````:WH!`"D```!Q>@$`-P```)MZ`0`.````TWH!``D```#B>@$`%@```.QZ
M`0`*`````WL!``<````.>P$`%````!9[`0`R````*WL!`"T```!>>P$`+```
M`(Q[`0`/````N7L!``0```#)>P$`!P```,Y[`0`(````UGL!``<```#?>P$`
M#@```.=[`0`3````]GL!``@````*?`$`8P```!-\`0`1````=WP!`!$```")
M?`$`#@```)M\`0`A````JGP!`%D```#,?`$`*@```"9]`0`&````47T!``8`
M``!8?0$`!0```%]]`0`>````97T!``8```"$?0$`"@```(M]`0`M````EGT!
M`"P```#$?0$`!P```/%]`0`+````^7T!`"T````%?@$`40```#-^`0`C````
MA7X!`#4```"I?@$`(````-]^`0`#`````'\!``P````$?P$`!P```!%_`0`/
M````&7\!`!`````I?P$`!0```#I_`0`6````0'\!``8```!7?P$`"````%Y_
M`0`)````9W\!``L```!Q?P$`"@```'U_`0`,````B'\!``8```"5?P$`&0``
M`)Q_`0`9````MG\!`!H```#0?P$`#P```.M_`0`2````^W\!`!`````.@`$`
M#P```!^``0`/````+X`!``\````_@`$`"````$^``0`R````6(`!`!$```"+
M@`$`#0```)V``0`-````JX`!`!8```"Y@`$`!P```-"``0`7````V(`!``,`
M``#P@`$`!P```/2``0`%````_(`!``4````"@0$`#0````B!`0`5````%H$!
M`!0````L@0$`(@```$&!`0`C````9($!`!P```"(@0$`'````*6!`0`@````
MPH$!`"0```#C@0$`'P````B"`0`%````*((!``,````N@@$`#@```#*"`0`.
M````08(!``H```!0@@$`&P```%N"`0`,````=X(!`!D```"$@@$`"0```)Z"
M`0`2````J((!``<```"[@@$`$````,."`0`0````U((!``@```#E@@$`"0``
M`.Z"`0`%````^((!``<```#^@@$``P````:#`0`$````"H,!``(````/@P$`
M1````!*#`0`U````5X,!`!L```"-@P$`+P```*F#`0`_````V8,!``T````9
MA`$`+@```">$`0`W````5H0!`$````".A`$`0````,^$`0!'````$(4!`!``
M``!8A0$`(0```&F%`0`;````BX4!`!D```"GA0$`'0```,&%`0`?````WX4!
M`!X```#_A0$`&P```!Z&`0`>````.H8!`",```!9A@$`/````'V&`0`\````
MNH8!`$````#WA@$`/P```#B'`0`^````>(<!`#L```"WAP$`;````/.'`0`8
M````8(@!`",```!YB`$`#````)V(`0`+````JH@!`!@```"VB`$`/0```,^(
M`0`Q````#8D!`",````_B0$`#````&.)`0!0````<(D!`$<```#!B0$``P``
M``F*`0`1````#8H!`!0````?B@$`#P```#2*`0`.````1(H!`!@```!3B@$`
M!P```&R*`0`*````=(H!``@```!_B@$`$@```(B*`0`/````FXH!``H```"K
MB@$`"@```+:*`0`%````P8H!`"<```#'B@$`"````.^*`0`&````^(H!`!,`
M``#_B@$`$@```!.+`0`/````)HL!`%<````VBP$`!P```(Z+`0`'````EHL!
M`!0```">BP$`!0```+.+`0`'````N8L!`!0```#!BP$`!P```-:+`0`$````
MWHL!`#\```#CBP$`&````".,`0`N````/(P!`((```!KC`$`&@```.Z,`0!+
M````"8T!`"<```!5C0$`$````'V-`0`'````CHT!``P```"6C0$`#P```*.-
M`0`,````LXT!`!0```#`C0$`$@```-6-`0`>````Z(T!`!L````'C@$`!0``
M`"..`0`0````*8X!`!<````ZC@$`)@```%*.`0`5````>8X!`!8```"/C@$`
M$````*:.`0`?````MXX!``@```#7C@$`%@```.".`0`0````]XX!``\````(
MCP$`$````!B/`0`8````*8\!``P```!"CP$`$@```$^/`0`7````8H\!``D`
M``!ZCP$`"````(2/`0`%````C8\!`!D```"3CP$`!@```*V/`0`1````M(\!
M``@```#&CP$`%0```,^/`0`+````Y8\!`!8```#QCP$`.@````B0`0`;````
M0Y`!``P```!?D`$`#0```&R0`0`B````>I`!``@```"=D`$`&@```*:0`0`$
M````P9`!``\```#&D`$`!````-:0`0`+````VY`!`",```#GD`$`/P````N1
M`0`&````2Y$!``X```!2D0$`&0```&&1`0`/````>Y$!``0```"+D0$`%```
M`)"1`0`)````I9$!``<```"OD0$`!0```+>1`0`(````O9$!``8```#&D0$`
M!@```,V1`0`4````U)$!`"P```#ID0$`+P```!:2`0`:````1I(!`"D```!A
MD@$`'P```(N2`0`\````JY(!`!H```#HD@$`(P````.3`0`M````)Y,!`"4`
M``!5DP$`!P```'N3`0`(````@Y,!``D```",DP$`"````):3`0`<````GY,!
M`!L```"\DP$`+````-B3`0`P````!90!`#@````VE`$`0````&^4`0`'````
ML)0!`!H```"XE`$`"0```-.4`0`4````W90!`#4```#RE`$`#P```"B5`0`4
M````.)4!``P```!-E0$`"````%J5`0`7````8Y4!``D```![E0$`#@```(65
M`0`,````E)4!`!D```"AE0$`&@```+N5`0!`````UI4!``L````7E@$`!0``
M`".6`0`(````*98!`!D````RE@$`$````$R6`0`%````798!`!0```!CE@$`
M$0```'B6`0`&````BI8!``L```"1E@$`"````)V6`0`.````II8!``<```"U
ME@$`!@```+V6`0`4````Q)8!`$,```#9E@$`:````!V7`0`<````AI<!`"@`
M``"CEP$`)0```,R7`0`1````\I<!`!8````$F`$`"@```!N8`0`0````)I@!
M`"D````WF`$`"````&&8`0`-````:I@!`!````!XF`$`%@```(F8`0`3````
MH)@!`$$```"TF`$`"P```/:8`0`A`````ID!`!$````DF0$`%0```#:9`0!!
M````3)D!`"4```".F0$`$````+29`0`(````Q9D!`!@```#.F0$`&````.>9
M`0`)`````)H!``\````*F@$`!@```!J:`0`9````(9H!`"0````[F@$`!P``
M`&":`0`%````:)H!``\```!NF@$`$@```'Z:`0`8````D9H!``8```"JF@$`
M!P```+&:`0`)````N9H!`!(```##F@$`$````-::`0`5````YYH!`!4```#]
MF@$`!@```!.;`0`&````&IL!`#,````AFP$`)P```%6;`0`D````?9L!``@`
M``"BFP$`#P```*N;`0`&````NYL!`"(```#"FP$`&@```.6;`0`G`````)P!
M``\````HG`$`%@```#B<`0`#````3YP!``0```!3G`$`%@```%B<`0`#````
M;YP!``P```!SG`$`&0```("<`0`+````FIP!`!@```"FG`$`'@```+^<`0`3
M````WIP!``4```#RG`$`"@```/B<`0`3`````YT!`!8````7G0$`#@```"Z=
M`0`$````/9T!``<```!"G0$`$````$J=`0!;````6YT!`"$```"WG0$`$P``
M`-F=`0`'````[9T!``4```#UG0$`#P```/N=`0`6````"YX!`!0````BG@$`
M)@```#>>`0`=````7IX!`!<```!\G@$`*````)2>`0`I````O9X!`!8```#G
MG@$`=````/Z>`0`F````<Y\!`"$```":GP$`+P```+R?`0`E````[)\!`"``
M```2H`$`)P```#.@`0`D````6Z`!`!X```"`H`$`'P```)^@`0`*````OZ`!
M``<```#*H`$`"````-*@`0`(````VZ`!`!,```#DH`$`#P```/B@`0`^````
M"*$!`"4```!'H0$`"````&VA`0!/````=J$!`$````#&H0$`20````>B`0!W
M````4:(!``P```#)H@$`,P```-:B`0`V````"J,!``H```!!HP$`!P```$RC
M`0`*````5*,!`#\```!?HP$`!@```)^C`0`^````IJ,!`#D```#EHP$`)@``
M`!^D`0`4````1J0!`#D```!;I`$`*P```)6D`0`Q````P:0!`"<```#SI`$`
M+P```!NE`0`H````2Z4!`!$```!TI0$`!P```(:E`0`6````CJ4!`!,```"E
MI0$`%````+FE`0`&````SJ4!`#````#5I0$`#`````:F`0`0````$Z8!``D`
M```DI@$`%@```"ZF`0`(````1:8!``0```!.I@$`$````%.F`0`*````9*8!
M``D```!OI@$`!@```'FF`0`,````@*8!``T```"-I@$`'````)NF`0`9````
MN*8!``X```#2I@$`'P```.&F`0`,`````:<!``<````.IP$`$````!:G`0`I
M````)Z<!``\```!1IP$`"@```&&G`0`8````;*<!`"P```"%IP$`#0```+*G
M`0`=````P*<!`#(```#>IP$`"0```!&H`0`'````&Z@!`!,````CJ`$`!P``
M`#>H`0`-````/Z@!`"$```!-J`$`#@```&^H`0`/````?J@!``P```".J`$`
M!P```)NH`0`)````HZ@!``D```"MJ`$`"0```+>H`0`+````P:@!`!$```#-
MJ`$`!0```-^H`0`7````Y:@!`!$```#]J`$`!@````^I`0`1````%JD!`!X`
M```HJ0$`"P```$>I`0`#````4ZD!``@```!7J0$`!0```&"I`0`(````9JD!
M``0```!OJ0$`3@```'2I`0`Q````PZD!`#\```#UJ0$`'0```#6J`0`%````
M4ZH!``4```!9J@$`#P```%^J`0`-````;ZH!``H```!]J@$`#P```(BJ`0`=
M````F*H!`!$```"VJ@$`#0```,BJ`0`.````UJH!``H```#EJ@$`"P```/"J
M`0`'````_*H!``8````$JP$`%`````NK`0`+````(*L!``8````LJP$`!@``
M`#.K`0`G````.JL!`!8```!BJP$`"````'FK`0`1````@JL!``D```"4JP$`
M"0```)ZK`0`3````J*L!`!,```"\JP$`!@```-"K`0`<````UZL!``L```#T
MJP$`'`````"L`0`)````':P!``<````GK`$`$0```"^L`0`D````0:P!``L`
M``!FK`$`#0```'*L`0`;````@*P!``0```"<K`$`"@```*&L`0`1````K*P!
M``X```"^K`$``P```,VL`0`3````T:P!``D```#EK`$`(@```.^L`0`X````
M$JT!`#<```!+K0$`-@```(.M`0!A````NJT!`!D````<K@$`<P```#:N`0`]
M````JJX!`%````#HK@$`>@```#FO`0`M````M*\!`$0```#BKP$`+@```">P
M`0`S````5K`!`!H```"*L`$`3````*6P`0#C`0``\K`!`"````#6L@$`&```
M`/>R`0!"````$+,!`'@```!3LP$`.````,RS`0!`````!;0!`&H```!&M`$`
M60```+&T`0`A````"[4!`!0````MM0$`'P```$*U`0`<````8K4!`"H```!_
MM0$`(@```*JU`0`E````S;4!`!@```#SM0$`-P````RV`0`E````1+8!`"<`
M``!JM@$`'@```)*V`0`O````L;8!`%X```#AM@$`00```$"W`0!C````@K<!
M`%,```#FMP$`.@```#JX`0`X````=;@!`#8```"NN`$`;````.6X`0!Q````
M4KD!`%P```#$N0$`70```"&Z`0`\````?[H!`"<```"\N@$`)P```.2Z`0`S
M````#+L!`($```!`NP$`?@```,*[`0#6````0;P!`!D````8O0$`+@```#*]
M`0`W````8;T!`"T```"9O0$`3P```,>]`0`F````%[X!`%T````^O@$`(P``
M`)R^`0`+````P+X!`.4```#,O@$`3P```+*_`0`I`````L`!`#8````LP`$`
M*@```&/``0`A````CL`!`#P```"PP`$``P```.W``0`'````\<`!``0```#Y
MP`$`$````/[``0`-````#\$!`!$````=P0$`#@```"_!`0`%````/L$!`"(`
M``!$P0$``0```&?!`0!K````:<$!``0```#5P0$`%0```-K!`0`$````\,$!
M``<```#UP0$`!````/W!`0`%`````L(!``@````(P@$`&0```!'"`0`+````
M*\(!`!$````WP@$`#@```$G"`0`#````6,(!``<```!<P@$`!P```&3"`0`1
M````;,(!``P```!^P@$`%````(O"`0`&````H,(!`!H```"GP@$`"@```,+"
M`0`#````S<(!`#P```#1P@$`!`````[#`0`&````$\,!``<````:PP$`)P``
M`"+#`0`^````2L,!`#0```")PP$`-0```+[#`0`;````],,!`"@````0Q`$`
M(````#G$`0`A````6L0!`"H```!\Q`$`)0```*?$`0`@````S<0!`"@```#N
MQ`$`)@```!?%`0`E````/L4!`#<```!DQ0$`-0```)S%`0`\````TL4!`"@`
M```/Q@$`+````#C&`0`H````9<8!`",```".Q@$`*P```++&`0`S````WL8!
M`"T````2QP$`,@```$#'`0`J````<\<!`"````">QP$`)0```+_'`0`P````
MY<<!`"`````6R`$`)@```#?(`0!'````7L@!`$````"FR`$`'P```.?(`0`O
M````!\D!`$\````WR0$`+P```(?)`0`S````M\D!`#$```#KR0$`,@```!W*
M`0`L````4,H!`"$```!]R@$`+0```)_*`0`H````S<H!`$T```#VR@$`,```
M`$3+`0!#````=<L!``H```"YRP$`$0```,3+`0`6````ULL!`#X```#MRP$`
M,````"S,`0`/````7<P!``\```!MS`$`%P```'W,`0`*````E<P!``P```"@
MS`$`*P```*W,`0`'````V<P!``H```#AS`$`.P```.S,`0`\````*,T!`"L`
M``!ES0$`)P```)'-`0`<````N<T!``D```#6S0$`!0$``.#-`0`1````YLX!
M`!@```#XS@$`"P```!'/`0`.````'<\!`!0````LSP$`*P```$'/`0`(````
M;<\!`$@```!VSP$`&@```+_/`0`;````VL\!``<```#VSP$`%@```/[/`0`-
M````%=`!`$0````CT`$`*````&C0`0`7````D=`!`!````"IT`$`$@```+K0
M`0`U````S=`!``P````#T0$`#0```!#1`0`.````'M$!`!0````MT0$`"@``
M`$+1`0`=````3=$!``@```!KT0$`+````'31`0`(````H=$!`!\```"JT0$`
M*0```,K1`0`&````]-$!`!\```#[T0$`!P```!O2`0`(````(](!``D````L
MT@$`10```#;2`0`&````?-(!`!,```"#T@$`$@```)?2`0`2````JM(!``D`
M``"]T@$`"````,?2`0`'````T-(!`!,```#8T@$`#@```.S2`0`B````^](!
M`!0````>TP$`&````#/3`0`<````3-,!``L```!ITP$`#0```'73`0`A````
M@],!``L```"ETP$`+0```+'3`0`/````W],!``0```#OTP$``P```/33`0`2
M````^-,!`"H````+U`$`"P```#;4`0`#````0M0!``@```!&U`$`#````$_4
M`0`*````7-0!``\```!GU`$`#@```'?4`0`7````AM0!`!@```">U`$`$0``
M`+?4`0`Z````R=0!`"`````$U0$`'P```"75`0`,````1=4!`#````!2U0$`
M!P```(/5`0`:````B]4!`$0```"FU0$`$P```.O5`0`0````_]4!``@````0
MU@$`!````!G6`0`$````'M8!`!,````CU@$`&P```#?6`0`%````4]8!``8`
M``!9U@$`!P```&#6`0`%````:-8!`!(```!NU@$`$P```('6`0`%````E=8!
M`!L```";U@$`&P```+?6`0`@````T]8!`"<```#TU@$`$0```!S7`0`"````
M+M<!``0````QUP$`#@```#;7`0`)````1=<!``4```!/UP$``@```%77`0`.
M````6-<!`#P```!GUP$`%0```*37`0`O````NM<!`$\```#JUP$`&````#K8
M`0!Z````4]@!`!\```#.V`$`.P```.[8`0`B````*MD!`#D```!-V0$`,```
M`(?9`0`T````N-D!`#<```#MV0$`-P```"7:`0`Q````7=H!`#@```"/V@$`
M+0```,C:`0`H````]MH!`$<````?VP$`'````&?;`0`:````A-L!`!0```"?
MVP$`?0```+3;`0`-````,MP!`((```!`W`$`@````,/<`0`V````1-T!`%@`
M``![W0$`%````-3=`0`9````Z=T!``P````#W@$`(P```!#>`0!%````--X!
M`"0```!ZW@$`)````)_>`0!M````Q-X!`!$````RWP$`"@```$3?`0`%````
M3]\!``8```!5WP$`"````%S?`0`%````9=\!`!,```!KWP$`%@```'_?`0`4
M````EM\!`!\```"KWP$`$````,O?`0`-````W-\!``0```#JWP$`#P```._?
M`0`.````_]\!``8````.X`$`!@```!7@`0`;````'.`!`!$````XX`$`!0``
M`$K@`0`5````4.`!``@```!FX`$`"0```&_@`0`4````>>`!``T```".X`$`
M&@```)S@`0`(````M^`!`!(```#`X`$`!@```-/@`0`%````VN`!``H```#@
MX`$`"P```.O@`0`%````]^`!`!L```#]X`$``@```!GA`0`"````'.$!``@`
M```?X0$`"````"CA`0`'````,>$!`#D````YX0$`!````'/A`0`#````>.$!
M`!,```!\X0$`&@```)#A`0`-````J^$!``L```"YX0$`!@```,7A`0`+````
MS.$!`!,```#8X0$`&0```.SA`0`"````!N(!``@````)X@$`$0```!+B`0`U
M````).(!``@```!:X@$`"0```&/B`0`4````;>(!``4```""X@$`!````(CB
M`0`+````C>(!``$```"^!0``@`4``-L%``!*!0``-P8```````#'!0``#@8`
M``````!6`@``5P,```\%``"9`@``&`,``"L!````````IP$```````!:!0``
M`````$L```"%!@``J@```'H"``!6!```E``````````X`@``'08``%X"````
M```````````````^````'P$``!\```#4!0``G04``$,&``#"`@```````",&
M``"+!@``8@0``/H"```)`P``;@4``"$&``!B`0``*P```%L#``#Z!```4@,`
M`)\&```3!@``0`(``.T#```^`P````````0"``!^`@``V@$``*,%``#*`@``
M+P```!L$``#I````+@,``*D```"N!```X@0``&P"````````SP4``)P```!W
M`P``5`8```````!-!0``G0$```````!=`@```@(``'````"Z!```5P$`````
M`````````````.\"``"&!`````````````"V`0``604``)P%``"[!0``````
M`&X#``"!`````````-,!```6````4`8``,L%```J!0````````<&```]!@``
M``````````#0!0``=0,``%<```"<`0``Q@4``(0$```M`P``PP0````````-
M!@``-@```&8&``#S```````````#``"6``````````````#Q`@``M0$``(,!
M`````````````'(#``!1!```)00``(<#``#R`0``.P(``%@#``"<`@``````
M`-0```"V!````````%$```#\`P``00$``"`"``!*!```2@8``,4%``!T`0``
MXP4```````">`@```````````````````````,4"```````````````````Z
M````_`$```````#\!````````+P`````````2@(``&@"``!)`0``R0,`````
M``#Y`@``8`$``-D!```<`@``````````````````W@(`````````````UP(`
M```````%!0``!`0``)<%``#J!```A@4``"P````%!@``ZP0``&X$``"6!0``
M#0```(D&``#N`P``00(``!@"````````O04``-,$````````.0$``)\%``#1
M`P``;`8``,P!`````````````&$%``!+!0``5``````````>!0``$@4``$P$
M``````````````````!B`@``WP4``&8`````````%08``$H```##!@``=`0`
M```````D!0``-0,````````2`0``[P````````!Q!@```````%4$````````
M-P4````````(`P``Y0,``+P&``!$!```R04``#8&```%````CP8``(<&``!8
M!```WP(``,$$``!U!```9`8```````!$!@``&@0```````#(!```>0,``"4&
M```:`P``I`$``#(!````````%````"D"```*!@``5`,``!@!````````_0(`
M`,$"``#R`P``M@````````#F````:P0`````````````>P$````````P`@``
M9`0```````"&!@``:P,```````!E!@``^`0``(@!````````"P````````!E
M````%@0``,$&``!.!``````````````*`P``[@(``.T%``#%!```J@4``#8!
M``#T`0``O@$`````````````)P4``'H$```.!```'@$``"\$``"5`P``_0``
M`,<$``"Z`@``B0$``/T$``#8````6@,```(#``"(!0````````````!G!0``
M(0$``"8````W`0```````"@%``#H!````````,X%``#+!```9P$``-@#``"0
M`P```````````````````````,0&```2`@``'0(``+(`````````9`,``)L`
M````````D`$``!H"``!G!`````````````"]`0``.P4``!4%``#%`P``204`
M`/X$``"S````$P4``$8#``#M`@``U0(``'0%````````CP4```````!S`@``
M*P,```````"[`0``A`$```````````````````````!)`P``$`,`````````
M````^P$``-X$``"H`0```````"X&````````@0,`````````````/`(``)D$
M``#,!0```````!`"``#+`P``=````(8```````````````8&````````````
M`&(&````````H`4``'8!``"J`P``N`(````````\`P``,P(``*\"````````
M`````&$!``"9!0``D`4``"L$```#!0```````(H"``#N````*00``'D$``#)
M````I0,```````!'!````````!T`````````ZP4``*\````U!```G0```!$&
M``!``P``O00```````"%`@```````*4&```S````P@$`````````````60,`
M`/$%``!+!@```````````````````````+X&``#E````A0$``(H%````````
M.`8``'8$``#F!0``0@$``'(```!.`0``:0$````````.`````````/L````L
M!```F0````````!W!```````````````````MP4```````#,`````````,H!
M``#S`P``````````````````60``````````````R`,``!8"``#!!0``9`4`
M`#`$```/`P````````````"J!``````````````!`@```````#X&``!7!@``
MW````.0%``!K!0``XP$``,@%````````"P,``"8$`````````````!D%```]
M````GP$``*$$``#@!0``$0(``````````````````+H#``#B`````````%8#
M````````LP$`````````````IP(```````"6!```#04```````";!@``#0,`
M`%X&``#/`@``"@(``,T```"&`P``7`,``),!``#V`P``G`,``%L%``!?!@``
MJ`0``,\#``##````/@$`````````````*`$``-L"``#W`@``40$``'$#``#"
M!@```````'T"````````E`,```````"%!```#@(``%`%``!@!````````/$#
M````````70,``,\$```=`0``Z0(`````````````;P0```````"]`@``=`,`
M``````````````````````"5!0```````+`#````````>@$``/X%```C````
M7P0``$`&``!C````S0$``/H!``!/`P``LP4``.4%``![!@``\`4``/4"``!\
M`P``D00``+4`````````)````#D&``"T`@``UP4``-T"```;!@``&P4``)H`
M``!"!@``<P0```````#P`P```````%4%``!%`@``T@0``$D&```?!0``````
M`(X```#T`P````````````#L!```=04``",$``#=!0``*P4``"$%``#L`P``
M`````,P"``#A`````````$8"````````/`8```````!+`@``-@4`````````
M````UP$``!L````@`P``RP$``#,%```%!```60$````````*!```+0(`````
M````````0P4`````````````N0,``.````!0`@``C@(``.0$``!1!@``````
M`/8"``!4`@``CP$``$@&``"_`@``Z@(``)(%```^`@``.@4``%@````0!@``
M;P```+L"``"S!```KP8``/T%``",!@``$04``)P$```K`@```````-8!````
M````/P8````````_`@``:@8``*L%``!:`@``V04``!X#````````&P$``#,$
M````````<@8`````````````*@8``)0"``#F`0``+P4````````C`P``````
M``````"R`P```````"4#````````&P(``+@#``",!```YP````````"\!```
M$P0````````4`P```````)L!```0````1@0````````P`P``!P```"`$``".
M!@`````````````[`0``U0,``"T!``!:!```B`,```````"L`P``G08``"(`
M``"#!@````````````#W`P```````(`&`````````````"`%``!R`@``````
M`*D%`````````````'T!``!L````;`4``-0$``"(`@``-08``#L&``"$`P``
M:P```-8#``#A`P``Q`(```````#V!```@@8``&D&``#]`P``X`$``*H&``!M
M!@``>@4```,$``"H`@``,0,``&4!```6`P``4P$``"P!```(!```Q@0``&8%
M```/`````````-@%````````F`4``%("```N````&`0``/8%````````)P(`
M`,$#```_`0``/P``````````````"@$``,P#````````'P0```8"````````
M````````````````_P4`````````````^`4``+$$``!_````H0,``)`&```V
M!```CP(``,`&``!K`@``R0(``"\#````````@`0``"D!``#3!0``4`0``,4&
M```B!```M04``'\&``!5`P``K0,``(8!``#L`0``\@0``"<$````````````
M`'0&``"D`@``I@0``.\!``"A!@``R00``-@"```I!@``10```&D%``#&!@``
MO@,```````"+`````````%D$``"D````-`(``*8"``"=`@``B00```````!.
M`@``F0$```````"=!```H````.(#``!N`@```````$D$``"!!````````/$$
M``"*`P```````$@!``"``@``4@8``/4!``#``@``JP(```````!X`@``1@$`
M````````````+00``$<#```W`@````````````"_!```_````/@#``#F`@``
M_`(``#$```!1`P```````*$```#D`0``D`(```````#J`0``%@8`````````
M!```[00``.(%````````(@$``*`#````````HP8``(H!````````````````
M````````L`0``&L!``!4!0``@@```.$!``"I`P``*`0``&\%````````E@,`
M``````#B`0``&````&@&``"(````I@4`````````````(@4``,T"``#^````
MK@$``,($``""!```U`,```````!_`P```````'`%```R!@```````$@%````
M````L0``````````````P0$``+P%``#S`@``D@8```T!``!%`P``L08``.8#
M``!G`@``?P0````````'`P``VP````````#:!0````````````"1!@``7`8`
M````````````.`$``!$$``#/`0``5P4``,H````!`P``C04``'D````^!```
M@@$``&<&````````7```````````````&0(``/(```!3!@```````,@!```N
M!0``H`8``%`!``#;`P``'`$```````"M!```7@````H%````````JP,``(,"
M````````!P0```````#A!```?0````8```"M`@``:@(```````!]!0``<P,`
M`*<&````````)`$````````$!@``"00``#$$``"M`0``J`8``&X&``#I`P``
MQ@```(H```!9`@``>P4`````````````.@0``'L$``#W!```Z`,``*D$```2
M`````````+D$```T!```CP0``"<&``#?`0``@0(```````#K`0``*0,``&\!
M````````E@8`````````````T0(``"(#``!Q````E0```!@&``#C`@``````
M`!,#``"%!0``U04``$,!`````````````/(%``!U`0``80```#(#```5````
M9`$```(````T!@``^00```````#^`@```````-P!``!$`@``````````````
M````<`,```````!M`0``H@,``/L$``"2`@``U0$`````````````GP(``%\"
M``"B!0``N````","``!A!@``&08``)L"``!3`````````&T%````````E@(`
M`!X$`````@``8P4``!`%``"<!@``/P0``)`````P!@``M@8```````!4!```
M.@(``.P````,`@``^`$``+<#``")`@``K@```&````#A`@``:`````````!P
M`0``:@````````#-!0``C00``-<#``"T!@```P$```````"D`P``V@(```$&
M````````Z@```+<````E`0``>`4``%,$``"C`@```````"<!``#@!```2`(`
M`&H%``#;`0```````.<!```L`@```````%<"``!'!@```````",%``#Q````
M!0,``!$```"G````E08``!H&``"L!@```````'L"``!H`P``WP0``+`"``":
M!0``20(``)@$``"#!0``_@$```````"Y`0`````````````)`0```````',%
M``!8`0``&@4```````":`@``;@``````````````#`,``)$"``#<!```+P(`
M`/D#``"H````_@,``#("``"``0```````"`&``#<!0`````````````/`@``
M`````)8!``!+`0``U@(`````````````Q@$`````````````3P$``&T#``!!
M!```)@(``'8#``!V````6@8``&$$````````4@0``*L``````````````(X%
M``!C`P```````'@$``"A`0````````````!5!@``]04```````#$!```?`0`
M`````````````````)0&```\`````````&D"``"H!0``Z0$```````">!@``
MOP8``*X&``!L`0```````$4$````````S@(``'$%``#,!```*````'X%``#;
M!```!P4`````````````.`4``%\%``#Z`P``7@$``````````````````$\`
M``!$`P````````,```"-`@`````````````H`P``Z04``!H```"8`0``"08`
M`!(&``"T!0``,@0```````!F`0````````````#_`````````"@&``#S`0``
M`````)L%``"]`P``9```````````````F@0```8#``#G`P``5`$```````"X
M!0``PP4``!<```#7````%P,``+@$``#G!```K@(``+0!``!#````,0(``-(!
M``"O!```3`$``'D&``"B````?P$``$D`````````B@8``*L&```+`0``+P$`
M`*8#``!O`@``T`,``$`!```P`````````!($````````PP,``+<$``!&````
M`````*0&``!W````"0(``+,&```)!0``608``+`&``#_`P``D0,``,8"````
M````1P```-P"``#_!```%P$``)H#``#X`@``50(``,4!```/`0```````"(&
M````````'@```/<!``"2`P``GP`````````-!```-`$```````#G`@``````
M`$<!``!F!```_P(``&D$``!J`P``2P0``/@`````````AP````````"$````
MI00``"8#``")````BP0````````5!```HP0``"<#``"I`@``/0,``*,!``!8
M!0``)0```,(%````````A@(````````R!0``Q`,``,,"`````````````$T&
M``"P`0``-@,``"H#```T!0``0`0``#L#````````'`4`````````````3@4`
M`.@``````````````'L#``"\`P``[`4```L$````````Y`(``!4!````!@``
MH`(``+,"``!U`@````````@%``!Y`0``$@,``$$%```4!```$P$````````Q
M`0```````#P%``"5`0```````,<#```6`0``EP(``.T```">!0``"````',`
M``#``P``H`$``*,``````````````-4```!,`@``Y00```````"G!0``<@0`
M`*\!``#P!```%`(``!<$```E!0``3P0``*T%``"Z!@``#0(````````%`0``
MN`$``#H!```M````8`(``,,!`````````````$\%``"/``````````````#(
M````I04`````````````\````#4%``#Y`0```````,D!````````,04``.X!
M``!8!@``]P4``)`$````````1`$```````#]`0``4P4``&$#``"K!```````
M`!@%``"L`@``(0```"`!``!3`@``0@0``*8&````````U@```+(%```4`0``
M`````'D%``#1`0``+`8``&P$``!E!```TP````````#0!```!`,```````"R
M!```BP4``'8"```9!```70$``*P```"(!@``W0````````!5`0```````'(!
M``"$`@``*`(``%\!```U`@``'````!8%``!7!```M0,```(!``#-`P``Y`,`
M````````````1@4````````,`0``\`(``#P!``!X!@``0P(``#L$```.`0``
M+08``.@%````````.`0```````"U`@``6P$``"P%``!#`P``F@8```L&````
M````?08``!0%````````[0$`````````````EP$``'@!``!%!0``K`4``+0`
M``#K`P``EP8``"D```"5!````````````````````````%8&```O!@``H04`
M`!P#``#C`````````$4&``#O`P``^P4```$!````````#`4```````!G`P``
M`````-,#````````M@4```````"V`P```````-,"``!.`P```````-(%``!U
M````S00```````#5!```#@4`````````````OP4``'8%```"!@``NP8``#0`
M``````````````````"+`P``N04``,8#````````OP$``"H"``!#!```D@``
M``````!Z!@```````/P%``!`````2@,`````````````*P8``#D%````````
M!@0``.,#``#9`````````)$```#U!````````%P%```(`0```@0``.@!```S
M!@````$``&8#``"'`@``QP(```````!3`P```````(0%``#N!0```````%T&
M````````1P4``*L!`````````````#X%``"^````3````(`#```0!```'P,`
M`,<!```Y`@``"P(``*T&``"1!0``P`0``+0$``!G````?`$``$T`````````
M`````%X$````````,`4``"0&````````C`$`````````````!`4``!D#``"H
M`P``0`4``%``````````D0$``,````"5`@```````.`#```=!0``]````$P&
M````````$P(```````"B!````````+L`````````W@4``!P&```D!```"@``
M`%H```#W`````````!,```!\`@``%P4```8%``!W`@``M08``%L$``#`!0``
MBP$```0!``#7!```HP,``$$&``#I!```%P(``'$$``#0`````````'H#``!H
M`0``7P````````#J!0``'@8``````````````````"8%````````X04``'H`
M``"8`P``@@4``"H$``!V!@``Q0```(T!``#?`P``@08``'0"``#P`0``````
M``````!.`````````+H%``"G`P``8P$``/8```"$!@```````+\```#2````
M=08``#T"````````=P4``/("``!@`P``<`(````````E`@``80(``(,#````
M``````````````````````````````!X````V@,```P&````````%0,``.4!
M`````````````#P$``"7`P``Q`4```````!;!@``)@$``"T%````````<0$`
M`&D#``!;`````````#,!``"Z`0``^@4``(T```!X`P``EP````````"7!```
M\P4``(("``"T`P``L@8``,(#````````T@,````````!!0```````-8%``!E
M`P``-`,``),&``!!````\0$``.L````F!@``MP(``+L#``!O`P``RP(```\$
M``!>!0``7`(``(P``````````````$@$````````I0(```<!````````-0``
M``````!<`0``\P0````````9`0``OP,````````A`P``ZP(```P```![````
M````````````````L````&(#````````:`0``,H#``!>`P``8@```+L$``#T
M!````@4```````!K!@```````*0%``!1`@```````.@"``!]`P``2@$``",!
M```]`0``W@```),#```D`@``D@$``,(````0`0```````!D```"L`0``-P``
M`)X$````````;00``"0#``"8!@``Q`$``!$#```B`@``L@(``',&``!2````
M1````+H```"3````W00```````!@!@``]`4``#D#````````BP(``#8"``!&
M!@``H@8``%(%``!"`P```````)0%``#L`@``]`(```````"B`0``AP4``),$
M``!W`0``L`4``'X&``#6!```<P$``+P!``#<`P``2P,```````!L`P``L0$`
M``````"\`@``G@```&,&``#B`@``*04``)L$````````3P(````````]!```
M@````-H$````````CP,```````#F!```F@$``-$$``"@!```0@````D```!P
M!```T`$``(,$`````````````)($```.`P```````(P%`````````````"X$
M````````5@```)X!``"]!@``;0```/\!``#*!0``W0,```\&````````F```
M`*\#````````[@0``.H#````````+`,```````"I!@``0@4``$("````````
MW@,````````7!@``F08``%T%``!%`0```````*\%``#0`@`````````````U
M`0```P(``.\%``"%`P``!P(``'`&``"X!@``,`$``*H!``!E`@``700`````
M``#$````50```!T#``!!`P``DP4``((#```@`````````+X"``#*!```1`4`
M`)L#``!Q`@``8P(``&H!````````RP```#$&``#=`0``AP$``,$```!1!0``
M````````````````5@$``)0!``!F`@``G0,`````````````$0$``%8%``!2
M`0``904``&0"``"M`````````*8`````````6@$``&H$```_!0``GP,`````
M`````````````&@%````````O0````````#G!0```````&T"````````'P8`
M``````"R`0``````````````````G@,``"H``````````````(@$```_`P``
M6`(``,X```"A`@``````````````````;P8````````#!@``@04``%T````!
M!```%0(``*8!``"G!````````+,#``#(`@``>0(``-D#``#``0```````*4`
M````````-P0``-@!``!^````)P```!X"`````````````$X&``"Q`@``U`$`
M`(<$``!C!````P,``'X!``!_`@``"P4``-@$``!I````!````*("```Y````
M!0(``+D&``"W`0```````($!````````&P,`````````````'00``$T!```R
M````C@$```````"I`0``M@(``%`#``!B!0``U`(``+$#``#/````A0```'X$
M````````DP(```````#9!```!@$``$T#````````"`8``!0&``".`P``O@0`
M`"H!``!-`@``C`,````````]!0``.00``-$`````````?00``%P$``")!0``
M3`,``-H````[```````````````A`@``K@,``"$$``!N`0``Y`````````!R
M!0```````)D#``#>`0``7P,```@"````````K`0``.4"`````````````'\%
M````````@P```"X!``#V`0``V0(``*4!``"D!`````4``$P%``"4!```````
M``````"N!0```````/L"``"W!@``S@,``)@"```?`@``T@(``,X!```Z`P``
M`````+$%```S`P``300``#@#``"?!```N0```(H$````````S@0``$@#```:
M`0``C08````````W`P```````*H"```X````WP```$<"``#O!```C`(``%L"
M``"-`P``QP```.,$``#U````^0````P$```Z!@``2````'<&````````````
M`!P$````````M00``'P&``#@`@``T04```````")`P``^P,``+D"``!\````
M8`4```````#U`P```````"X"````````?`4``````````````````/H```".
M!```^04```````!/!@````````````!^`P```"`H)7,@9&%Y<R!A9V\I`"`H
M06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R
M;W<I`"`H>65S=&5R9&%Y*0`@870@`"(E<R(@:7,@;F]T(&$@9&ER96-T;W)Y
M+@`E9"`E<R!A;F0@)7,`)60@8GET97,@=W)I='1E;BX`)60@;V8@)60@96YT
M<FEE<R!M87)K960@87,@=7`M=&\M9&%T90`E9"UD87D@9F]R96-A<W0`)7,@
M+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P
M`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@
M870@)7,@)7,`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U
M;F0N`"5S(&YO="!F;W5N9"X@4G5N("=T<F%N<VQA=&EO;B!E>'1R86-T)R!F
M:7)S="X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#
M86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`+"!G
M=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE
M8W0@+2T`+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM`#$R($AO=7(@1F]R
M;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P!!(&1A=&%B
M87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T
M86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q
M=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@
M:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B
M;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!0
M1U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME
M>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K
M97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@
M:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D<P!!
M32!,:6=H="!286EN`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E
M<G,`04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B
M<V)O='1O;0!!8G-M:61D;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@
M9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!
M8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D
M9`!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE
M<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&YE
M=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!
M9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D
M9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!
M9&1I;F<@;F5W(&9I;&5S('1O(')E<&]S:71O<GDZ`$%D9&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M
M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I
M;VX`061S`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG
M;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@
M1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M
M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI
M<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`
M06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA
M;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E
M<P!!;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V
M86QU92!W87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U
M<F5D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`
M06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A
M=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!
M<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE
M`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ
M90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V
M92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)G96YT:6YA`$%R;65N
M:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N<VEO;B!)
M<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C
M;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N
M="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`
M075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D
M(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS
M:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M
M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@
M)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z
M(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T
M;R!U<&1A=&4@=7-E<B`E<P!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A
M=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&9A:6QE
M9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E
M:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($94
M4"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E
M<G9E<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0D]&
M2"!%>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R
M8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA
M<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R
M8F%D;W,`0F%S96QI;F4`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96YI;@!"
M97)M=61A`$)H=71A;@!":7)T:&1A>0!";&]C:R`B)7,B(&]F(&%P<&QI8V%T
M:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E
M`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE
M<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W
M86YA`$)O='1O;0!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA
M;B!/8V5A;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T`0G5I;&1I;F<@
M34\@9FEL97,@9F]R(&UO9'5L92`E<RXN+@!"=6EL9&EN9R!L;V-A;&4@)7,N
M+BX@`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N
M9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P
M97)T:65S+BXN`$-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N`$-A;&5N
M9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S
M=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O
M<BX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N861A`$-A
M;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE
M("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N
M;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#
M86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E
M9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E
M;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU
M;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE
M9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#871E9V]R:65S(&%N9"!,
M86)E;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I
M97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG
M.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R
M86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U
M.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E
M<G1I9FEC871E(%!O;&EC:65S`$-H860`0VAA;F=E`$-H86YG92!T:&4@;F%M
M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@
M86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%R`$-H96-?:R!,:6YK+BXN
M`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN
M97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@82!P87-S=V]R9`!#:&]O
M<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H
M;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:')I
M<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD
M+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(&]U="!U<V5R.B`E
M<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L
M:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN
M9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O8V]S("A+965L:6YG
M*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`
M0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`
M0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H
M96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;7!O
M<V4@365S<V%G92`H)7,I`$-O;7!U=&5R<P!#;VYD:71I;VYS`$-O;F9I9W5R
M871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T
M92X`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L
M(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A
M:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@
M=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE
M8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S('=E<F4@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT:6YU
M90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!F86EL960Z("5S`$-O
M<'D@<V5L96-T:6]N`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N
M;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S
M:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@
M;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C:R!B86QA
M;F-E+B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<P!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E
M;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G
M<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D
M9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U
M=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@
M;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI
M8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`E<RX`
M0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U
M;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@
M9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E
M=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#
M;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R
M97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE
M<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S
M879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P
M(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG
M=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R
M871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I
M;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T
M:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU
M86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T
M:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`
M0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&1N
M)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I
M9&5B87(@:7,@;W!E;BX`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#
M<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S
M=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU
M;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="`T(%!H87-E<P!#=7)R96YT(%1I
M;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N
M9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N
M('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#
M>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I
M;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1&%I
M;'D`1&%T851R964@0G)O=W-E<@!$871E`$1A=&4@4F5C96EV960`1&%T92!S
M96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@
M;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R
M`$1E9F%U;'0@261E;G1I='D`1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92!'
M<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A
M9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG
M(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E
M9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T
M:&4@8W5R<F5N="!R;W<`1&5L:79E<GD@=&EM90!$96YM87)K`$1E<V-R:6)E
M('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R
M9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T
M:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0
M;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE
M9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y
M`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L
M87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@
M3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I
M<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&]E<R!T:&4@9FER<W0@
M<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H
M:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]W;FQO860`
M1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@
M87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$52
M4@!%8W5A9&]R`$5D:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R
M;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R
M("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S
M`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M
M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N
M`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N<P!%;7!T>2!M97-S
M86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@
M:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T
M97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@>65A
M<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H
M:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO
M=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P
M970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5Q=6%T;W)I86P@1W5I
M;F5A`$5R:71R96$`17)R;W(`17)R;W(@=VET:"!E;6%I;"!M97-S86=E+@!%
M<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN=71E
M<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI
M;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T
M90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP86YD(%-I9&5B
M87(`17AP96-T960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@
M<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$9'($-O;&]R
M`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R
M96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL
M960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F
M<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C
M<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@
M(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E<P!&86ER`$9A;&ML86YD($ES
M;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&
M87@`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E
M<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M871R:7@`1FEJ:0!&:6QE($-O
M=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E
M<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U
M<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1FEN;&%N9`!&:7)S="!(
M86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``1FQO870`1F]G`$9O
M;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`1F]R(&)R
M;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R96-A<W0@*%1!
M1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E
M8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N=6UB
M97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*0!&;W)G;W0@
M>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R
M='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`1G(`1G)A;65S`$9R
M86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5N8V@@1W5I86YA`$9R96YC
M:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S`$9R;VT`
M1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M
M90!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'
M86UB:6$`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D
M90!'96]R9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`
M1V\`1V]E9&5L`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R965C90!'<F5E
M:R`H25-/+3@X-3DM-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M:6YI
M<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!S
M`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R
M;6ES<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N
M80!(5$U,`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T
M86)L92X`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA
M<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE87)D($ES;&%N9"!A;F0@36-$
M;VYA;&0@27-L86YD<P!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE
M;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES<&AE<F4`2&5R92!I
M<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H`$AO7VUE`$AO;'D@
M4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO;64`2&]M92!!9&1R97-S`$AO
M;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B
M.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@
M)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J
M96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N
M9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M
M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG
M:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J
M96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z
M("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F
M;W(@=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O
M('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W
M;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I
M;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@
M<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M
M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO
M=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y
M`$AU;6ED:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R
M96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE
M9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`
M25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E
M<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N
M('9I;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`26-O;G,@
M3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@
M;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O
M(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N
M>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D
M('1O(&-H96-K('1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N
M8WDN`$EF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE
M(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@
M8GD@>6]U<B!B<F]W<V5R+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA
M9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y
M.@!);6%G92!U<&QO860`26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E
M9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E
M<@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A
M;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A
M<V4@26YD96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN
M9F\`26YF;W)M871I;VX`26YI=&EA;&EZ:6YG(&UO9'5L92`E<RXN+B``26YS
M97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L90!)
M;G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A
M(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE
M=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@
M<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E
M9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R
M('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T
M:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS
M97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E
M('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R="!C
M96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@
M8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F=&5R
M`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`26YS
M97)T(')O=R!B969O<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@
M=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E`$EN
M<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@
M=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET
M+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED(%5$2"X@*%5S97(@1&%T
M82!(96%D97(I+@!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H
M($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T
M:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!L:6-E
M;G-E(&ME>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV86QI9"!M
M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O
M<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I
M;VXN`$EN=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D=6-T(&-O9&4N
M`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L
M:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E
M;G1O<GD`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`
M27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)
M=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)
M4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*
M=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I
M9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B
M97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.
M97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T
M:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO
M8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O
M9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,
M86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T
M($AA;&8`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@
M)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,
M871V:6$`3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE
M8F%N;VX`3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QI
M8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI
M9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT
M(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@
M5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K
M`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@
M=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN
M=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T
M($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M
M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S
M=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@=7-E
M<G,@:7,@9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N
M+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@
M:6X`3&]G(&]U=`!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y
M;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C
M=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G
M<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@
M;G5M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT
M(&-O;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@
M1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`
M36%I;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA
M`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G
M;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R
M<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P
M`$UA<%%U97-T(&UA<`!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS
M965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A
M;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C
M:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@
M8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@
M;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM
M=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!M
M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C
M8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@
M;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP
M90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE
M=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@;F]T(&-O
M;FYE8W1E9"X`365T:&]D`$UE=')I8P!-97AI8V\`36EC<F]N97-I82P@1F5D
M97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA
M<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:7)R;W(`
M36ES8V5L;&%N96]U<P!-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E
M<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A
M=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N
M+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P
M86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA
M:6P`36]D97)A=&4`36]D:69I960@1&%T90!-;V1I9GD@55),`$UO9'5L=7,`
M36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N
M9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)O8V-O
M`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E
M($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`
M36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T
M<P!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!0;W)T86P`37D@
M4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE
M`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@
M06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A
M=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE
M=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!34TP@
M<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S
M8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A;&5D
M;VYI80!.97<@0V%T96=O<GD`3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I
M;VYA;"D`3F5W(%IE86QA;F0`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE
M=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S`$YE>'0@;W!T:6]N<P!.97AT
M/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO(&%V
M86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E
M<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I
M;6%G97,N`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@
M=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I
M9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H
M:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!6
M1E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S
M=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@
M9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C871I;VX@<')O=FED
M960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.
M;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A
M=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT
M:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED
M960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W
M:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!Q=6]T
M82!S970N`$YO(')U;&5S`$YO('-I9&5S`$YO('-U8V@@9FEL90!.;R!T96UP
M;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N
M86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R
M971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA
M;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO
M('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.
M;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(
M96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T
M($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L96UE
M;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1H:6YG('1O
M(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C
M:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$YU
M;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T
M:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/8W1A;`!/8W1O
M8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;6%N`$]N;'D@24U!4"!S97)V
M97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@;V9F96YS:79E(&9O
M<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T
M:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O
M=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E
M;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X
M=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="X`3W!E;G,@=&AI
M<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO
M;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/
M<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC
M871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE
M<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N<P!004T@875T
M:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$=0($1I9VET86P@4VEG
M;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@
M4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,
M:6=H="!286EN`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`
M4$T@4W5N`%!-(%0M4W1O<FUS`%!?2%`@4VAE;&P`4&%D9&EN9P!086MI<W1A
M;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D`%!A;F%M
M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G1L>2!#;&]U9'D`4&%S
M<W=O<F0`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O
M<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER
M;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA
M=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@
M4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/
M<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L
M;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N($1E;FEE9`!097)M:7-S:6]N
M<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!E
M=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0
M;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@
M8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z
M`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@
M96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE
M87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E
M(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L
M:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT
M:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E('!R;W9I9&4@
M82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R
M('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@='EP92!T:&4@;F5W(&-A
M=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T=6=A;`!0
M;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@
M=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-
M05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R969S
M7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E
M9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R
M93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W
M`%!R979I;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!+97D`
M4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T
M97AT`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME
M>2!);F9O`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S
M=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%%A=&%R`%%U97)Y`%)302!0=6)L
M:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R
M;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T
M;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E
M<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@
M5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S('EO=7(@
M;&%S="!A8W1I;VX`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E
M9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W<V5R
M`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W
M=RYE>&5M<&QE+F5S+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO
M=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!P86ER`%)E;6]V
M92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T
M;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C
M=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E<75E<W0@8V]U
M;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<75E
M<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q=6ER960@1FEE
M;&0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!2
M97-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E=6YI;VX`4F5V97)T($-O;F9I
M9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG
M:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N
M+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E
M(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U
M;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O
M;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I
M86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG
M;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I
M8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,(%-H
M96QL`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A
M:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@
M86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S
M`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE
M(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA
M`%-A=F4`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N
M9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T
M96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3
M8V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`4V5A<F-H($5N9VEN
M97,`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@
M=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L
M96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N
M`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N
M965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A
M;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@
M9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C
M="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE
M('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE
M8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H
M96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O
M8FQE;2!297!O<G0`4V5N9"!335,`4V5N96=A;`!396YS;W(Z(`!397!T96UB
M97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R
M(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92X`4V5S<VEO;B!)1"!E>'!I
M<F5D+@!3970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO
M=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M
M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R
M('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N
M92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T
M:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R
M(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S
M(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H
M92!P87)A;65T97(Z(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T(%-U;6UA
M<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN
M:W,_`%-H;W<`4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S
M879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3
M:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;W!T
M:6]N('1O(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO=R!T86)L92!O
M<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L
M969T/P!3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H
M;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE
M(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T
M:65S(&1I86QO9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`
M4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H<FEN:P!3
M:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H
M92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I
M9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N
M86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@
M4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S($QA=&4`
M4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@`%-O;&]M
M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!O<F1E<B!S
M96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O=71H($5U
M<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U
M=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E
M(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT
M(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N
M9"!P861D:6YG`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`
M4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@
M3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE87(`4W1A=&4@;W(@
M4')O=FEN8V4`4W1A='5S`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S
M`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R:7`@9&]M86EN(&9R;VT@
M=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B:F5C=`!3=6)M:70`4W5B
M<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R
M871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A
M=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V960@
M=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL
M>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N
M;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U
M;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3
M=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE
M<FQA;F0`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!3>7)I86X@07)A
M8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@86YD(%=I;F1Y`%0M4W1O<FUS
M`%135B!F:6QE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O<&5R=&EE<P!4
M86EW86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A
M;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K<P!496QE
M<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E
M`%1E;7!E<F%T=7)E.B``5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5X=`!4
M97AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I
M`%1H86EL86YD`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N
M`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@
M<W5P<&]R="`B)7,B`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@
M;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S
M960N($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I
M9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W
M86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`
M5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T
M(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@
M8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S
M<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R
M97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES
M=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L
M969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D
M:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y
M<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO
M;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4
M:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4
M:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@
M=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`
M5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE
M;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G
M<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI
M9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O
M<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)
M9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@
M=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@
M86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE9"X@
M(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE
M(&9U;&P@<V-R965N(&5D:71O<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E
M96X@9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T
M:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@
M0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@
M)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES
M(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E
M860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN
M9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R
M97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H
M92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@
M:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`
M5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@
M=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<FEG:'0@86YD(&QE
M9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E
M<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H
M87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@
M8F5E;B!R96UO=F5D+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO
M="!E>&ES="X`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O
M<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@
M=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO
M="!B92!S879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I
M;&%B;&4N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@
M87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H
M97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO
M=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@
M;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I
M;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R
M;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R
M('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E
M<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E
M<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E
M('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H
M87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@
M86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O
M:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S
M(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S
M92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG
M(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@
M<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED
M(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA
M=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R
M:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S
M;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN
M9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@
M9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E
M<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@*&AT='`Z
M+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F
M:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD
M(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I
M;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H
M:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="
M($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F;W)M
M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES
M(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B
M:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R
M<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T
M(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`5&AI<R!M
M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T
M:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A
M<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@
M9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A
M=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W
M(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E
M<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE
M('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O;'1I<"DZ
M`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#
M;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI
M;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M
M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871I;VYS
M`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA
M`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R
M:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E
M.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV
M97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@
M=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@
M=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C
M:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE
M('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E
M<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C
M;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@
M(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD
M97(@(B5S(BX`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA
M8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B
M+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T
M92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@
M9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY
M.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@
M=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@
M5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E
M+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I
M+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL
M960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O(')E860@=&AE
M('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S
M.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B
M;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A
M=&$N`%5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E
M>&-E961E9"X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L
M87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N
M(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R
M('1O.B``56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@16UI
M<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A
M=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN
M;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G
M:60@*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W;B!L;V-A=&EO;B!P<F]V
M:61E9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H
M92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T
M<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL
M>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E
M8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H
M;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N
M`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D
M871E("5S`%5P9&%T92!U<V5R`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P
M;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@
M=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N
M=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E(&EF
M(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`
M57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M:6YI
M<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@
M4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N
M`%5S97)N86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S
M>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES
M="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!6
M86QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU92!I<R!O
M=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L=65S`%9A;'5E<R!T
M;R!S96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z=65L80!697)I
M9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@
M=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC
M86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H
M`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`E<P!6:65W(&%N
M(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FER9VEN($ES;&%N9',L
M($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I
M8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).24Y'
M(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5V%L;&ES(&%N
M9"!&=71U;F$`5V%R;FEN9P!790!796%T:&5R($9O<F5C87-T`%=E871H97(@
M9&%T82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`5V5B(%-I=&4`5V5E
M:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N
M("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!3
M86AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E
M<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA
M="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&EC:"!P:&%S97,`5VAI8V@@
M<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7
M:61T:`!7:61T:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@
M;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I
M9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`
M5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7
M:7-D;VT`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!8+5)E9@!8-3`Y
M=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G
M90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J
M96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`
M66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@22!!9W)E90!9;W4@
M87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I
M=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@875T:&5N=&EC871E
M9"X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9
M;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I
M;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@:&%V
M92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@
M8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA
M;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9
M;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF
M:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@
M;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I
M8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE
M;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L
M:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E
M(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A
M<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N
M`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!S
M<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@
M82!N97<@8V%T96=O<GD@;F%M92X`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I
M<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9
M;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E
M<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL
M('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT
M:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R
M<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@
M;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H
M86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN
M(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A
M:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R
M92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O
M<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@=&\@<')I;G0N`%EO
M=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>3H`
M66]U<B!F=6QL(&YA;64Z`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@
M)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R
M871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P
M87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@
M;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<F5M;W1E('-E
M<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y
M`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U
M;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI
M;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?0TQ)`%]$871A5')E90!?
M1&5L971E(%)O=P!?1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN
M`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]0
M97)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P
M97)T:65S+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`8V%L96YD87(`8V%L;0!C
M;&EC:R!H97)E`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S
M("5S`&@Z`&AH`&EM;65D:6%T90!I;FQI;F4`;&EN97-=`&UK:7-O9G,@97)R
M;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+@!M;0!N86UE`&YO="!I;7!L
M96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P
M:7AE;',`<FES:6YG`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(
M5%10`'-S`'-T96%D>0!T87-K(&QI<W0`='EP92!T:&4@<&%S<W=O<F0@='=I
M8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A
M<F0`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S
M+C`U"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G
M"E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`U+3$Q(#$R.C4Q*S`R,#`*4$\M
M4F5V:7-I;VXM1&%T93H@,C`P-BTP-RTQ-"`Q,3HP."LP,3`P"DQA<W0M5')A
M;G-L871O<CH@2F]R9&D@1VER86QT(#QP<F]J96-T92YK,D!U<&-N970N961U
M/@I,86YG=6%G92U496%M.B!#871A;&%N(#QD979`;&ES=',N:&]R9&4N;W)G
M/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[
M(&-H87)S970]:7-O+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG
M.B`X8FET"@`H9F$@)7,@9&EE<RD`("A#;&%U(&0G86-CZ7,@)7,I`"AE;B`E
M<R!D:65S*0`H879U:2D`*&1E;>`I`"AA:&ER*0!E;@`B)7,B(&YO(.ES('5N
M(&1I<F5C=&]R:2X`)60@)7,@:2`E<P`E9"!B>71E<R!E<V-R:71S+@`E9"!D
M92`E9"!E;G1R861E<R!M87)C861E<R!C;VT@86-T=6%L:71Z861E<P!P<F5V
M:7-I\R!P97(@86P@9&EA("5D`$%V[7,@+2`E<P!%;7!R96UT82!D86-T:6QA
M<B`E<P`E<R!+0@!/<&5R86-I;VYS(&1E(&UA;G1E;FEM96YT("5S("T@0V]N
M9FER;6%C:?,`0V]N9FEG=7)A8VGS(&1E("5S`$%L=&$@9&4@)7,`0V]N9&EC
M:6]N<R!D96P@8V]N=')A8W1E("5S`"5S(&IA(&5X:7-T96EX+@`E<R!E;B`E
M<R`E<P#)<R!N96-E<W-A<FD@)7,N`"5S(&UI;G5T<P!.;R!S)VAA('1R;V)A
M="`E<RX`)7,@;F\@=')O8F%T+B!%>&5C=71A("=T<F%N<VQA=&EO;B!E>'1R
M86-T)R!P<FEM97(N`"5S(&%L("5S(&1E("5S`$QL:6)R971A(&0G861R96-E
M<R!D92`E<P!!9V5N9&$@9&4@)7,`0FQO8R!D92!N;W1E<R!D92`E<P!,;&ES
M=&$@9&4@=&%S<75E<R!D92`E<P`E<SH@)7,`+"!V96YT\W,@)7,@)7,@`"P@
M=F%R:6%B;&4@9&4@)7,@82`E<P`M+2!S96QE8V-I;VYA<B`M+0`M+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2T`9F]R;6%T(&1E(#$R(&AO<F5S`&9O<FUA
M="!D92`R-"!H;W)E<P`R-"!H;W)E<P`\06YT97)I;W(`4&5R(&$@87%U97-T
M(&)L;V,@97,@;F5C97-S:71A('5N(&UO=&]R(&1E(&)A<V5S(&1E(&1A9&5S
M+@!3)VAA('!R;V1U[W0@=6X@97)R;W(@:7)R97!A<F%B;&4N`$5S(&YE8V5S
M<VET82!U;F$@8VQA=2!01U`@</IB;&EC82!P97(@>&EF<F%R('5N(&UI<W-A
M=&=E+@!%<R!N96-E<W-I=&$@=6YA(&-L874@4$=0('#Z8FQI8V$@<&5R('9E
M<FEF:6-A<B!U;B!M:7-S871G92!S:6=N870N`$5S(&YE8V5S<VET96X@=6YA
M(&-L874@4$=0('#Z8FQI8V$L('5N82!C;&%U(%!'4"!P<FEV861A(&D@=6YA
M(&-O;G1R87-E;GEA('!E<B!D97-X:69R87(@=6X@;6ES<V%T9V4N`$5S(&YE
M8V5S<VET96X@=6YA(&-L874@4$=0('#Z8FQI8V$L('5N82!C;&%U(%!'4"!P
M<FEV861A(&D@=6YA(&-O;G1R87-E;GEA('!E<B!S:6=N87(@=6X@;6ES<V%T
M9V4N`$5S(&YE8V5S<VET96X@=6YA(&-L874@4R]-24U%('#Z8FQI8V$L('5N
M82!C;&%U(%,O34E-12!P<FEV861A(&D@=6YA(&-O;G1R87-E;GEA('!E<B!D
M97-X:69R87(@=6X@;6ES<V%T9V4N`$5S(&YE8V5S<VET96X@=6YA(&-L874@
M4R]-24U%('#Z8FQI8V$L('5N82!C;&%U(%,O34E-12!P<FEV861A(&D@=6YA
M(&-O;G1R87-E;GEA('!E<B!S:6=N87(@=6X@;6ES<V%T9V4N`$5S(&YE8V5S
M<VET82!U;F$@8VQA=2!334E-12!P^F)L:6-A('!E<B!X:69R87(@=6X@;6ES
M<V%T9V4N`$[Z=F]L<R!A;"!M873M`%!L=6IA(&9E8FQE(&%L(&UA=.T`4&QU
M:F$@86P@;6%T[0!2=6EX871S(&%L(&UA=.T`6.!F96-S(&1E(&YE=2!A;"!M
M873M+@!!32]030!)1"!D92!!4$D`4V]B<F4@87%U97-T(&5D:71O<@!%;B!Q
M=6%N="!A+BXN`$%L:6YE86-I\R!I;F9E<FEO<B!E>&%C=&$`06QI;F5A8VGS
M(&%L(&UI9R!E>&%C=&$`4R=H82!D96YE9V%T(&PG86-CZ7,@96X@8W)E87(@
M96P@9&ER96-T;W)I(%9&4RX`4R=H82!D96YE9V%T(&PG86-CZ7,@96X@8W)E
M87(@;"=A<GAI=2!61E,N`$-O;G1R87-E;GEA(&1E;"!C;VUP=&4`0V]M<'1E
M(&-O;F=E;&%T+@!#;VUP=&%B:6QI='IA8VGS`$%F96=I<@!!9F5G:7(@=6X@
M9W)U<"!D97-C96YD96YT`$%F96=I<B!U;F$@875T;W)I='IA8VGS(&1E<V-E
M;F1E;G0`069E9VER(&$@8V]N=&EN=6%C:?,Z`$%F96=I<B!U;B!N;W4@9W)U
M<`!!9F5G:7(@=6YA(&YO=F$@875T;W)I='IA8VGS(`!!9F5G:7(@=6X@;F]U
M('5S=6%R:3H`069E9VER('5N82!C;VQU;6YA+@!!9F5G:7(@;F]U<R!M96UB
M<F5S+@!!9F5G:7(@=6YA('!A<F5L;&$`069E9VER(&5L(&UE;OH@)7,@8V]M
M('5N82!B87)R82!L871E<F%L(&1E($UO>FEL;&$`069E9V5I>"!A(&QA(&QL
M:6)R971A(&0G861R96-E<SH`069E9V5I>"!A(&QA(&UE=F$@;&QI8G)E=&$@
M9"=A9')E8V5S`$%F96=I<B!U;B!U<W5A<FD`069E9VEN="!N;W5S(&9I='AE
M<G,@86P@<F5P;W-I=&]R:0!3)VAA(&EN:&%B:6QI=&%T(&PG;W!C:?,@9"=A
M9F5G:7(@=7-U87)I<RX`061R9>=A`$QL:6)R971A(&0G861R96-E<P!!9&UI
M;FES=')A9&]R("T@9&5F:6YE:7@@;&5S(&%U=&]R:71Z86-I;VYS('!E<B!A
M(&%L=')E<R!U<W5A<FES`$%D;6EN:7-T<F%C:?,`06YU;F-I<P!!9F=A;FES
M=&%N`$%L8N!N:6$`06QGZ')I80#`;&EE<P!!;&EN96%R`$%L:6YE86-I\SH`
M5&]T<P!4;W1S(&5L<R!U<W5A<FES(&%U=&5N=&EC871S`%1O=',@96QS(&=R
M=7!S`%1O=',@96QS('!E<FUI<V]S`%1O=',@<75A=')E(&-O<W1A=',`4&5R
M;65T(&UO;'1E<R!A9')E8V5S`$5S('!E<FUE="!L82!C;VYF:6=U<F%C:?,@
M9&5L('1I<'5S(&1E(&QL:7-T97,@;W)D96YA9&5S/P!*82!E>&ES=&5I>`!!
M8V/I<R!)35-0(&%L=&5R;F%T:74`0V]N=')A<V5N>6$@24U34"!A;'1E<FYA
M=&EV80!.;VT@9"=U<W5A<FD@24U34"!A;'1E<FYA=&EU`$%D<F7G82!E;&5C
M='+R;FEC82!A;'1E<FYA=&EV80!0;&%N=&EL;&5S(&%L=&5R;F%T:79E<P!4
M97AT(&%L=&5R;F%T:74Z`%-A;6]A($%M97)I8V%N80!3)VAA(&5S<&5C:69I
M8V%T('5N('9A;&]R('!R;VAI8FET+@!3)VAA('!R;V1U[W0@=6X@97)R;W(@
M9&5S8V]N96=U="X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`4V5R=FED;W(@
M4')O>'D@86[R;FEM`%)E<W!O<W1A`$%N=.!R=&ED80!!;G1I9W5A(&D@0F%R
M8G5D80!!<&QI8V%C:?,`3&QI<W1A(&0G87!L:6-A8VEO;G,`3"=A<&QI8V%C
M:?,@Z7,@82!P=6YT+@!!<&QI8V%R(&$@<F5C=7)S;W,@8V]M<&%R=&ET<R!D
M97-C96YD96YT<RX`07!R;W9A<@!-:61A(&%P<F]X:6UA9&$`06)R:6P`07+@
M8FEC("A7:6YD;W=S+3$R-38`36ED82!D92!L)V%R>&EU`$YO;2!D92!L)V%R
M>&EU`%9O;&5U('-U<')I;6ER(&QA('-O;+=L:6-I='5D(&0G86QT82!A("5S
M/P!!<F=E;G1I;F$`07)MZ&YI80!!<FUE;FD@*$%235-#24DM."D`07)T`$%R
M=6)A`$EL;&$@9&4@;"=!<V-E;G-I\P!G<N!F:6,@05-#24D`4F5G:?,@9&5L
M(%!A8^UF:6,@87-IX'1I8P!6;VQE=2!C;VYF:7)M86-I\R!A8F%N<R!D)V5F
M96-T=6%R(&QE<R!O<&5R86-I;VYS(&1E(&UA;G1E;FEM96YT/P!#;VQU;6YE
M<R!D)V%S<VEG;F%C:?,`4R=H82!I;G1E;G1A="!S=7!R:6UI<B!U;B!G<G5P
M(&YO(&5X:7-T96YT+@!3)VAA(&EN=&5N=&%T('-U<')I;6ER('5N82!A=71O
M<FET>F%C:?,@;F\@97AI<W1E;G0N`%,G:&$@:6YT96YT870@961I=&%R('5N
M82!A=71O<FET>F%C:?,@;F\@97AI<W1E;G0N`%,G:&$@:6YT96YT870@961I
M=&%R('5N(')E8W5R<R!C;VUP87)T:70@;F\@97AI<W1E;G0N`$%T<FEB=71S
M`$%G;W-T`$%U<W1RX&QI80#`=7-T<FEA`$%U=&A?8WER<W%L.B!.;R!S)VAA
M('1R;V)A="!L)V5X=&5N<VGS(&EM87`@;F5C97-SX')I82X`075T:%]C>7)U
M<SH@16P@;6]T;W(@;F\@=.D@;&5S(&-A<&%C:71A=',@;F5C97-SX')I97,N
M`$%U=&A?8WER=7,Z($YO(',G:&$@=')O8F%T(&PG97AT96YS:?,@24U!4"!N
M96-E<W/@<FEA+@!!=71H7V9T<#H@3F\@<R=H82!T<F]B870@;"=E>'1E;G-I
M\R!&5%`@;F5C97-SX')I82X@0V%L(&-O;7!I;&%R(%!(4"!A;6(@96P@8V]M
M;75T861O<B`M96YA8FQE+69T<"X`075T:%]I;6%P.B!.;R!S)VAA('1R;V)A
M="!L)V5X=&5N<VGS($E-05`@;F5C97-SX')I82X`075T:%]K<F(U.B!.;R!S
M)VAA('1R;V)A="!L)V5X=&5N<VGS(&MR8C4@;F5C97-SX')I82X`075T:%]L
M9&%P.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N<VGS($Q$05`@;F5C97-SX')I
M82X`075T:%]L9&%P.B!.;R!S)VAA('!O9W5T(&%F96=I<B!L)W5S=6%R:2`E
M<RX@06EX\B#I<R!E;"!Q=64@:&$@9&ET(&5L('-E<G9I9&]R.@!!=71H7VQD
M87`Z($YO(',G:&$@<&]G=70@<W5P<FEM:7(@;"=U<W5A<FD@)7,N`$%U=&]?
M;&1A<#H@3F\@<R=H82!P;V=U="!A8W1U86QI='IA<B!L)W5S=6%R:2`E<RX`
M075T;U]M8V%L.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N<VGS($U#04P@;F5C
M97-SX')I82X`075T:%]S;6)A=71H.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N
M<VGS(%--0D%55$@@;F5C97-SX')I82X`4R=H82!P<F]D=>]T('5N(&5R<F]R
M(&5N(&PG875T96YT:6-A8VGS+@!3)VAA('!R;V1U[W0@=6X@97)R;W(@96X@
M;"=A=71E;G1I8V%C:?,N("5S`$5L('-E<G9I9&]R(%)!1$E54R!H82!R96)U
M=&IA="!L)V%U=&5N=&EC86-I\RX`4R=H82!P<F]D=>]T('5N(&5R<F]R(&5N
M(&PG875T96YT:6-A8VGS(&%M8B!E;"!S97)V:61O<B!&5%`N`%,G:&$@<')O
M9'7O="!U;B!E<G)O<B!E;B!L)V%U=&5N=&EC86-I\R!A;6(@96P@<V5R=FED
M;W(@4TU"+@!#86UP<R!D:7-P;VYI8FQE<SH`07IE<F)A:61J86X`0D]&2"!%
M>&-U<V5S`$9O;G,`0V]L;W(@9&5L(&9O;G,`0V]N=')A<V5N>6$@2V5R8F5R
M;W,@:6YC;W)R96-T82X`3F]M(&0G=7-U87)I($ME<F)E<F]S(&EN8V]R<F5C
M=&4N`$)A:&%M97,`0F%H<F%I;@!"X&QT:6,@*$E33RTX.#4Y+3$S*0!"86YG
M;&$@1&5S:`!"87)B861O<P!,[6YI82!B87-E`$)I96QO<G+Z<VEA`$+H;&=I
M8V$`0F5L:7IE`$)E;NUN`$)E<FUU9&5S`$)H=71A;@!!;FEV97)S87)I`$YO
M(',G:&$@=')O8F%T(&5L(&)L;V,@(B5S(B!D92!L)V%P;&EC86-I\R`B)7,B
M("X`4&%RX&UE=')E<R!D96P@8FQO8P!4:7!U<R!D92!B;&]C`$YE9W)E=&$`
M0F]L[79I80!-87)C861O<G,`0V]N=&]R;@!'<G5I>"!D96P@8V]N=&]R;@!#
M;VYT;W)N<P!"\G-N:6$@:2!(97)C96=O=FEN80!!;6)D\W,`0F]T<W=A;F$`
M26YF97)I;W(`26QL82!D92!";W5V970`0G)A<VEL`%1E<G)I=&]R:2!O8V7@
M;FEC(&1E(&PGS6YD:6$@8G)I=.!N:6-A`$)R=6YE:2!$87)U<W-A;&%M`$-O
M;G1R=6EN="!F:71X97)S($U/('!E<B!A;"!M\F1U;"`E<RXN+@!#;VYS=')U
M:6YT("5S+BXN`$)U;&?@<FEA`$QL:7-T82!D92!P:6-S`$)U<FMI;F$@1F%S
M;P!"=7)U;F1I`$--4P!#4D,`4'5N=',@9&4@9&ES=')I8G5C:?,@9&4@0U),
M`%!R;W!I971A=',@9&4@8V5LMVQA+BXN`$YO(',G:&$@9FEN86QI='IA="!E
M;"!P<F]CZ7,@9"=I;FEC:6%L:71Z86-I\R!D92!L82!M96WR<FEA(&-A=0!#
M86QE;F1A<FD`0V%L;6$`0V%M8F]D:F$`0V%M97)U;@#)<R!I;7!O<W-I8FQE
M(')E:6YI8VEA<B!L82!C;VYT<F%S96YY82!A=71O;>!T:6-A;65N="P@<&]S
M82=T(&5N(&-O;G1A8W1E(&%M8B!L)V%D;6EN:7-T<F%D;W(@9&5L('-I<W1E
M;6$N`,ES(&EM<&]S<VEB;&4@8V]N;F5C=&%R(&%M8B!E;"!S97)V:61O<B!)
M34%0.B`E<RX`0V%N863@`$-A;F-E;+=L87(`0V%N8V5LMVQA<B!L)VEN9F]R
M;64@9&4@<')O8FQE;65S+@!.;R!E<R!P;W0@97-B;W)R87(@;"=A<GAI=2`B
M)7,B+@!.;R!E<R!P;W0@=')O8F%R('5N(&1I<F5C=&]R:2!T96UP;W)A;"X`
M3F\@97,@<&]T(&-O;G1I;G5A<B!S96YS92!E;"!P87+@;65T<F4@)W1A<F=E
M=$9I;&4G+@!.;R!E<R!P;W0@97-B;W)R87(@96P@9&ER96-T;W)I("(E<R(N
M`$YO(&5S('!O="!E<V)O<G)A<BP@8V]N=.D@9&5S8V5N9&5N=',@)60N(`!.
M;R!E<R!P;W0@<F5O<F1E;F%R+"!E;"!N;VUB<F4@9"=E;G1R861E<R!Q=64@
M<R=H86X@9&4@<F5O<F1E;F%R(&YO(&-O:6YC:61E:7@@86UB(&QE<R!Q=64@
M:&D@:&$@96UM86=A='IE;6%D97,N`$YO(&5S('!O="!A9')EYV%R(&5L(&UI
M<W-A=&=E(&%L(&YO;6)R92!E<W!E8VEF:6-A="X`0V%P(%9E<F0`3&QE9V5N
M9&$`0V%T96=O<FEE<R!I(&5T:7%U971E<P!);&QE<R!#86EM86X`5&5LZ&9O
M;B!M\F)I;`!0<F]P:65T871S(&1E(&-E;+=L80!&87)C:6UE;G0@9&4@8V5L
MMVQA`%!R;W!I971A=',@9&4@;&$@8V5LMVQA`$5S<&%I870@96YT<F4@8V5L
MMVQE<P!496SH9F]N(&WR8FEL`$/H;'1I8R`H25-/+3@X-3DM,30I`$-E;G1R
M87(`4F5P^F)L:6-A($-E;G1R96%F<FEC86YA`$5U<F]P82!C96YT<F%L("A)
M4T\M.#@U.2TR*0!$971A;&QS(&1E;"!C97)T:69I8V%T`%1I='5L87(@9&5L
M(&-E<G1I9FEC870`4&]L[71I<75E<R!D92!C97)T:69I8V%C:?,`5'AA9`!$
M97-FZ7,`0V%N=FEE=2!E;"!N;VT@:2!L)V%D<F7G82!Q=64@<_-N('9I<VEB
M;&5S('%U86X@97,@;&QE9V5I>&5N(&\@97,@<F5S<&]N96X@96QS('9O<W1R
M97,@;6ES<V%T9V5S(&1E(&-O<G)E=2!E;&5C='+R;FEC+@!#:&%R`%9E<FEF
M:6-A(&PG96YL;&'G+BXN`%AI;&4`6&EN80!8:6[H<R!S:6UP;&EF:6-A="`H
M1T(R,S$R*0!8:6[H<R!T<F%D:6-I;VYA;"`H0FEG-2D`5')I82!U;F$@8V]N
M=')A<V5N>6$`5')I82!U;B!N;VT@9"=U<W5A<FD`5')I82!C;VT@=F]L<R!V
M:7-U86QI='IA<B!L97,@9&%T97,Z`%1R:6$@=6X@=&EP=7,@9"=E<W1I;"!D
M92!L;&ES=&$@*'!E<B!A(&QL:7-T97,@;W)D96YA9&5S*0!);&QA(&1E($-H
M<FES=&UA<P!.;R!S)VAA('1R;V)A="!L82!D969I;FEC:?,@9&4@8VQA<W-E
M(&1E("`E<RX`16QI;6EN87(`16QI;6EN82!L97,@971I<75E=&5S(&1E($U3
M3V9F:6-E`$5S8F]R<F$@;"=U<W5A<FDZ("5S`$5S8F]R<F$@;"=U<W5A<FD`
M17-B;W)R82!L97,@9&%D97,@9&4@;"=U<W5A<FD`4R=A8VQA<FERX"!C87`@
M86P@=&%R9"X`4')E;6D@<&5R(&-O;G1I;G5A<@!#;&EC:V%T96QL('!E<B!(
M5%10`%1A;F-A(&QA(&9I;F5S=')A`$[Z=F]L<P!.^G9O;',@82!P<FEM97)A
M(&AO<F$`16YN=79O;&%T`$EL;&5S(&1E($-O8V]S("A+965L:6YG*0!2961U
M[W4@;&$@8F%R<F$@;&%T97)A;`!-87)G97,@<F5D=>]T<P!#;VSR;6)I80!#
M;VQO<@!396QE8W1O<B!D92!C;VQO<@!396QE8V-I\R!D92!C;VQO<@!#;VQU
M;6YE<SH`5.UT;VQS(&1E(&QE<R!C;VQU;6YE<P!#\FUI8W,`3W)D<F4`0V]N
M<V]L80!#;VUE;G1A<FD`3F]M(&-O;?H`0V]M;W)E<P!#;VUP86YY:6$`17-C
M<FEU(&5L(&UI<W-A=&=E("@E<RD`3W)D:6YA9&]R<P!#;VYD:6-I;VYS`$1I
M9F5RZ&YC:65S(&1E(&-O;F9I9W5R86-I\P!,82!C;VYF:6=U<F%C:?,@;F\@
M97-TX"!A8W1U86QI='IA9&$N`$-O;F9I9W5R82`E<P!#;VYF:7)M87(@;&$@
M8V]N=')A<V5N>6$`0V]N9V\`0V]N9V\L(%)E</IB;&EC82!$96UO8W+@=&EC
M82!D96P`3F\@Z7,@<&]S<VEB;&4@<F5A;&ET>F%R(&QA(&-O;FYE>&GS+@!.
M;R#I<R!P;W-S:6)L92!R96%L:71Z87(@;&$@8V]N;F5X:?,Z`%,G:&$@<F5B
M=71J870@;&$@8V]N;F5X:?,@86P@<V5R=FED;W(@9&4@8VQA=7,@</IB;&EQ
M=65S+@!3)VAA(')E8G5T:F%T(&QA(&-O;FYE>&GS(&%L('-E<G9I9&]R(&1E
M(&-L875S('#Z8FQI<75E<RX@4F'S.B`E<R`H)7,I`$YO(.ES('!O<W-I8FQE
M(')E86QI='IA<B!L82!C;VYN97AI\R!A;"!S97)V:61O<B!&5%`N`$5L<R!C
M;VYT86-T97,@<R=H86X@869E9VET(&-O<G)E8W1A;65N="!A(&QA('1E=F$@
M;&QI8G)E=&$@9"=A9')E8V5S+@!#;VYT:6YU87(`26QL97,@0V]O:P!'86QE
M=&$`0V]P:6%R`,ES(&EM<&]S<VEB;&4@8V]P:6%R.B`E<P!#;W!I87(@<V5L
M96-C:?,`0V]S=&$@4FEC80!#;W-T82!D)TEV;W)I`$YO(&5S('!O="!X:69R
M87(@96P@;6ES<V%T9V4@86UB(%,O34E-12X`3F\@97,@<&]T('-I9VYA<B!E
M;"!M:7-S871G92!A;6(@4R]-24U%+@!.;R!E<R!P;W0@869E9VER(&5L(&-O
M;G1A8W1E+B`E<P!.;R!E<R!P;W0@8V]N;F5C=&%R(&%M8B!E;"!S97)V:61O
M<B!,1$%0+@!.;R!E<R!P;W0@8V]M<')O=F%R(&5L('-A;&1O+B`E<P!.;R!S
M)VAA('!O9W5T(&-R96%R('5N82!L;&ES=&$@9&4@9&ES=')I8G5C:?,N("5S
M`$YO(',G:&$@<&]G=70@9&5S>&EF<F%R(&QE<R!D861E<R!3+TU)344N`$YO
M(',G:&$@<&]G=70@97-B;W)R87(@96P@8V]N=&%C=&4N("5S`$YO(',G:&$@
M<&]G=70@97-B;W)R87(@;&$@;&QI<W1A(&1E(&1I<W1R:6)U8VGS+B`E<P!.
M;R!S)VAA('!O9W5T(&1E=&5R;6EN87(@;"=A9')EYV$@96QE8W1R\FYI8V$@
M9&5L(&1E<W1I;F%T87)I+@!.;R!S)VAA('!O9W5T(')E8V]L;&ER('1O=&$@
M;&$@;&QI8G)E=&$@9"=A9')E8V5S+@!.;R!S)VAA('!O9W5T(')E8V]L;&ER
M('1O=&$@;&$@;&QI<W1A(&1E(&1I<W1R:6)U8VGS+@!.;R!S)VAA('!O9W5T
M(')E8V]L;&ER('1O=&$@;&$@;&QI<W1A(&1E(&QE<R!L;&ES=&5S(&1E(&1I
M<W1R:6)U8VGS+@!.;R!S)VAA('!O9W5T(&]B=&5N:7(@=6YA(&-L874@</IB
M;&EC82!D96P@<V5R=FED;W(@9&4@8VQA=7,N`$YO(',G:&$@<&]G=70@;V)R
M:7(@)7,N`$YO(',G:&$@<&]G=70@;V)R:7(@96P@;?)D=6P@9&4@=&%S<75E
M<R!D92!M86YT96YI;65N="`E<RX`3F\@<R=H82!P;V=U="!L;&5G:7(@)7,N
M`$YO(',G:&$@<&]G=70@<F5I;FEC:6%R(&QA(&-O;G1R87-E;GEA('!E<B!A
M(&PG=7-U87)I('-O;+=L:6-I=&%T+B!!;&=U;G,@9&5T86QL<R!O('1O=',@
M;F\@<_-N(&-O<G)E8W1E<RX@5&]R;F%R+6AO(&$@:6YT96YT87(@;RP@<&5R
M(&$@;>ES(&EN9F]R;6%C:?,L('!O<V$G="!E;B!C;VYT86-T92!A;6(@;"=A
M9&UI;FES=')A9&]R(&1E;"!S:7-T96UA+@!.;R!S)VAA('!O9W5T(')E8W5P
M97)A<B!L97,@04-,`$YO(',G:&$@<&]G=70@<F5C=7!E<F%R(&QA(&QL:6)R
M971A(&0G861R96-E<RX@)7,`3F\@<R=H82!P;V=U="!R96-U<&5R87(@;&$@
M;&QI<W1A(&1E(&1I<W1R:6)U8VGS+B`E<P!.;R!S)VAA('!O9W5T(')E8W5P
M97)A<B!L97,@;&QI<W1E<R!D92!D:7-T<FEB=6-I\RX@)7,`3F\@<R=H82!P
M;V=U="!R96-U<&5R87(@;&5S('!O<W-I8FEL:71A=',@9&5L('-E<G9I9&]R
M`$YO(',G:&$@<&]G=70@<F5S=&%U<F%R(&QA(&-O;F9I9W5R86-I\RX`3F\@
M<R=H82!P;V=U="!D97-A<B!L82!C;VYF:6=U<F%C:?,@)7,N`$YO(',G:&$@
M<&]G=70@9&5S87(@=6YA(&-O;F9I9W5R86-I\R!D92!S96=U<F5T870N`$YO
M(',G:&$@<&]G=70@9&5S87(@=6YA(&-O;F9I9W5R86-I\R!D92!S96=U<F5T
M870Z("5S`$YO(',G:&$@<&]G=70@9&5S87(@;&$@8_)P:6$@9&4@<V5G=7)E
M=&%T(&1E(&PG87)X:74@9&4@8V]N9FEG=7)A8VGS("5S+@!.;R!S)VAA('!O
M9W5T(&1E<V%R(&PG87)X:74@9&4@8V]N9FEG=7)A8VGS("5S+B!0;W1S('5T
M:6QI='IA<B!U;F$@9&4@;&5S(&]P8VEO;G,@<&5R('1O<FYA<B!A(&1E<V%R
M(&5L(&-O9&D@96X@)7,@;R!BZ2!C;W!I87(@;6%N=6%L;65N="!E;"!C;V1I
M('-E9_QE;G0@96X@)7,N`$YO(',G:&$@<&]G=70@8V5R8V%R(&%L('-E<G9I
M9&]R($Q$05`N`$YO(',G:&$@<&]G=70@86-T=6%L:71Z87(@96P@8V]N=&%C
M=&4N("5S`$YO(',G:&$@<&]G=70@86-T=6%L:71Z87(@;&$@;&QI<W1A(&1E
M(&1I<W1R:6)U8VGS+B`E<P!.;R!S)VAA('!O9W5T(&QO8V%L:71Z87(@;&$@
M8F%R<F$@;&%T97)A;"!D92!-;WII;&QA+B!#;VUP<F]V82!Q=64@;&$@8F%R
M<F$@;&%T97)A;"!E<W1I9W5I(&]B97)T82X`5&5X="!C;VUP=&%T`%!A[7,`
M0W5R<V]S`$-R96%R`$-R96%R('5N(&5N;&QAYP!#<F5A<BUN92!U;B!D92!N
M;W4`0W)E87(@<W5B8V%R<&5T97,`4&5R;6ES;W,@9&5L(&-R96%D;W(`3OIM
M97)O(&1E(&QA('1A<F=E=&$@9&4@8W+H9&ET`$-R;^!C:6$`0W5B80`T(&9A
M<V5S(&%C='5A;',`5&5M<',@86-T=6%L`$5L(%523"!A8W1U86P@Z7,`5&5M
M<',@86-T=6%L`$-O;F1I8VGS(&%C='5A;#H`17-T:6P@86-T=6%L`%!E<G-O
M;F%L:71Z974@;&5S('1A<W%U97,@<75E(',G:&%N(&5X96-U=&%R('%U86X@
M<R=I;FEC:6$@;&$@<V5S<VGS(&$@)7,N`%)E=&%L;&%R`%)E=&%L;&%R(&QA
M('-E;&5C8VGS`%AI<')E`$-I<NULMVQI8R`H2T])."U2*0!#:7+M;+=L:6,@
M*%=I;F1O=W,M,3(U,2D`0VER[6RW;&EC+U5C<F'O;NAS("A+3TDX+54I`%)E
M</IB;&EC82!4>&5C80!$1`!$:>!R:6%M96YT`$YA=F5G861O<B!D92!$871A
M5')E90!$871A`%,G:&$@<F5B=70@;&$@9&%T80!396QE8V-I\R!D92!D871A
M`$1I80!3=7!R:6UI<B!C;VQU;6YA`$1E<V5M8G)E`$YO;6)R97,@9&5C:6UA
M;',`4F5D=>]U(&5L('-A9VYA=`!0<F5D971E<FUI;F%T`$-O;&]R('!R961E
M=&5R;6EN870`261E;G1I=&%T('!R961E=&5R;6EN861A`$1E9FEN:6-I;VYS
M`%-U<')I;6ER`%-U<')I;6ER(&=R=7``4W5P<FEM:7(@<&5R;>US`%-U<')I
M;6ER(&D@8G5I9&%R(&UI<W-A=&=E<P!3=7!R:6UI<B!C96RW;&$`4W5P<FEM
M:7(@8V]L=6UN80!3=7!R:6UI<B!L82!P;&%N=&EL;&$@86QT97)N871I=F$@
M97AI<W1E;G0`4W5P<FEM:7(@9FEL80!3=7!R:6UI<B!L82!I9&5N=&ET870@
M<V5L96-C:6]N861A`%-U<')I;6ER(&QA(&-O;'5M;F$@86-T=6%L`%-U<')I
M;6ER(&QA(&9I;&$@86-T=6%L`$AO<F$@9&4@;&QI=7)A;65N=`!$:6YA;6%R
M8V$`1&5S8W)I=FEU(&5L('!R;V)L96UA`$1E<V-R:7!C:?,`1&5T86QL<R`H
M=&%M8ND@86P@9FET>&5R(&1E(')E9VES=')E(&1E($AO<F1E*3H`16QS(&1E
M=&%L;',@:&%N(&5S=&%T(')E9VES=')A=',@<&5R(&$@;"=A9&UI;FES=')A
M9&]R+@!$97-E;G9O;'5P86UE;G0`4'5N="!D92!R;W-A9&$`4'5N="!D92!R
M;W-A9&$@9&4@;&$@9&%R<F5R82!H;W)A.@!0=6YT(&1E(')O<V%D83H@`$0G
M97-Q=65R<F$@82!D<F5T80!$92!D<F5T82!A(&5S<75E<G)A`$1I<F5C=&]R
M:0!6;VQS('9I<W5A;&ET>F%R+6AO(&5N(&9O<FUA="!D92`R-"!H;W)E<S\`
M3W!C:6]N<R!D92!V:7-U86QI='IA8VGS`$UO<W1R82!L82!P<F5V:7-I\R`H
M5$%&*0!&;W)M870@9&4@=FES=6%L:71Z86-I\P!.;W1I9FEC86-I\R!D92!R
M96-E<&-I\P!$:FEB;W5T:0!.;R!H;R!S=7!R:6UI=0!.;R!A8V-E9&EU(&1I
M<F5C=&%M96YT(&$@;6%I;G1E;F%N8V4N<&AP`$QA('!R:6UE<F$@9FEL82!C
M;VYTZ2!E;',@;F]M<R!D96QS(&-A;7!S/R!%;B!C87,@869I<FUA=&EU+"!A
M8W1I=F$@87%U97-T82!C87-E;&QA.@!$;VUI;FEC80!297#Z8FQI8V$@1&]M
M:6YI8V%N80!$97-C87)R96=A<@!$97-C87)R96=A<B`E<P!$97-C87)R96=A
M<B!L82!C;VYF:6=U<F%C:?,@9V5N97)A9&$@8V]M('5N82!S97'\Z&YC:6$@
M4$A0+@!,;&ES=&$@9&5S<&QE9V%B;&4`1')O9W5E<P!#;W)R974@96QE8W1R
M\FYI8P!%4E(`17%U861O<@!%9&ET80!%9&ET82!B;&]C`$5D:71A(&=R=7``
M161I=&$@<&5R;>US`$5D:71A('!E<FUI<V]S`$5D:71A('!E<FUI<V]S(&1E
M("5S`$5D:71A(&]P8VEO;G,@9&4Z`$5D:71A('!E<FUI<V]S(&1E("5S`$5D
M=6-A8VGS`$5G:7!T90!%;"!386QV861O<@!%;&5M96YT+BXN`%%U861R873M
M`$-O<G)E=2!E;&5C='+R;FEC`$%D<F7G82!E;&5C='+R;FEC80!,97,@861R
M96-E<R!E;&5C='+R;FEQ=65S(&AA;B!D92!C;VEN8VED:7(N`$-O<G)E=2!E
M;&5C='+R;FEC(&%M8B!C;VYF:7)M86-I\P!%;6]T:6-O;F5S`$UI<W-A=&=E
M(&5N(&)L86YC+@!297-U;'1A="!E;B!B;&%N8RX`0G5I9&%R(&5L<R!T97)M
M97,@9&4@8V5R8V$`2&%B:6QI=&%R(&QA(&EN<V5R8VGS(&1E(&EM871G97,@
M9&4@;&5S(&=A;&5R:65S(&1E(&9O=&]S(&5N(&5L('1E>'0_`$AA8FEL:71A
M<B!E;"!M96[Z(&1E(&-O;G1E>'0@8VQI8V%N="!E;B!E;"!B;W3S(&1R970_
M`$%N>2!D92!F:6YA;&ET>F%C:?,`06UP;&EA<B!L)V5D:71O<@!);G1R;V1U
M[W4@=6YA('!R96=U;G1A(&1E('-E9W5R971A="!Q=64@<V4@=7,@9F]R;75L
M87+@('-I('5S(&-A;"!R96EN:6-I87(@;&$@8V]N=')A<V5N>6$L('!E<B!E
M>&5M<&QE("=C;VT@97,@9&EU(&5L('9O<W1R92!A;FEM86P@9&4@8V]M<&%N
M>6EA/R<Z`$EN=')O9'7O=2!A<77M(&5L(%523"!D92!L82!I;6%T9V4`1W5I
M;F5A($5Q=6%T;W)I86P`17)I=')E80!%<G)O<@!(:2!H82!H86=U="!U;B!E
M<G)O<B!A;6(@96P@;6ES<V%T9V4@96QE8W1R\FYI8RX`17-T\FYI80!%=&GR
M<&EA`,AT;FEC`$5U<F]P80!#861A(#$U(&UI;G5T<P!#861A(#(@;6EN=71S
M`$-A9&$@,S`@<V5G;VYS`$-A9&$@-2!M:6YU=',`0V%D82!I;FEC:2!D92!S
M97-S:?,`0V%D82!M:71J82!H;W)A`$-A9&$@;6EN=70`5F%L;W)S(&0G97AE
M;7!L93H`17AE8W5T80!%>'!A;F1E:7@`17AP86YD:7(@;&$@8F%R<F$@;&%T
M97)A;`!3)V5S<&5R879A("<I)P!3)V5S<&5R879A('5N('-O;"!M;W0@;R!U
M;B!T97)M92!D92!C97)C82!C:71A=`!$871A(&1E('9E;F-I;65N=`!%>'!O
M;F5N=`!#;VQO<B!D92!P<FEM97(@<&QA`$/@<G)E9V$@9&4@;&$@8V]N9FEG
M=7)A8VGS(&1E;"!&5%``R7,@:6UP;W-S:6)L92!R96-U<&5R87(@;&5S('!R
M969E<NAN8VEE<RX`R7,@:6UP;W-S:6)L92!C;VYN96-T87(@86UB(&5L('-E
M<G9I9&]R($Q$05`N`,ES(&EM<&]S<VEB;&4@8V]N;F5C=&%R(&%M8B!E;"!S
M97)V:61O<B!334(N`,ES(&EM<&]S<VEB;&4@8V]P:6%R(&1E("(E<R(N`,ES
M(&EM<&]S<VEB;&4@8V]P:6%R(&$@(B5S(BX`R7,@:6UP;W-S:6)L92!C<F5A
M<B!U;F$@;F]V82!C;VYN97AI\R!305-,+@#)<R!I;7!O<W-I8FQE('1R86YS
M9F5R:7(@82`B)7,B+@#)<R!I;7!O<W-I8FQE(')E8W5P97)A<CH@)7,`0VQA
M<@!);&QE<R!&86QK;&%N9"`H36%L=FEN97,I`$EL;&5S($;H<F]E`$5R<F]R
M(&ER<F5C=7!E<F%B;&4@`$9A>`!&96)R97(`4V4@<V5N="!C;VT`4V4@<V5N
M="!C;VTZ`%!O<75E<R!P;'5G97,`4&]C<R!XX&9E8W,@9&4@;F5U`$UA=')I
M=2!D96P@8V%M<`!&:6II`%)E8V]M<'1E(&0G87)X:75S.B!A<GAI=2`E<P!2
M96-O;7!T92!D)V%R>&EU<SH@)7,@87)X:75S`$=E<W1O<B!D)V%R>&EU<P!.
M;VT@9&4@;"=A<GAI=0!396QE8V-I\R!D)V%R>&EU<P!#X')R96=A(&1E(&PG
M87)X:74`3F\@Z7,@<&5R;>AS('!E;FIA<B!A<GAI=7,`1FEL=')E<P!&:6YL
MX&YD:6$`4')I;65R82!M96ET870`4')I;65R('%U87)T`%)A\R!F:7AA(R,`
M26YV97)T:74`0V]M82!F;&]T86YT`$)O:7)A`$QA(&-A<G!E=&$@)7,@;F\@
M97AI<W1E:7@`0V]L;W(@9&4@;&$@9F]N=`!-96YJ87(`4&5R(&%L<R!N879E
M9V%D;W)S('%U92!N;R!A9&UE=&5N(&QE<R!I;6%T9V5S`%!R979I<VGS("A4
M048I`%!R979I<VGS('!E<B!A;',@9&EE<R`H=&EN9W5E=2!P<F5S96YT('%U
M92!L82!P<F5V:7-I\R!F86-I;&ET861A(&-O;7!RZ&X@96P@9&EA(&D@;&$@
M;FET.B!U;B!N;VUB<F4@96QE=F%T('!O9')I82!T96YI<B!C;VT@82!R97-U
M;'1A="!U;B!B;&]C(&%M<&QE+@!(974@;V)L:61A="!L82!C;VYT<F%S96YY
M83\`1F]R;75L87)I<P!$:71A`%1I<'5S(&1E(&1I=&5S`$1I=&5S`$1I=&5S
M(#(`1O)R=6US`%)E96YV:6%M96YT<P!$=BX`36%R8W,`1G)A;N=A`$9R86[G
M82!M971R;W!O;&ET86YA`$=U86EA;F$@1G)A;F-E<V$`4&]L:6[H<VEA($9R
M86YC97-A`%1E<G)I=&]R:7,@1G)A;F-E<V]S(&1E;"!3=60`1&5S(&1E`$1E
M<R!D96P`1&5S8W)I<&-I\R!C;VUP;&5T80!,;'5N82!P;&5N80!.;VT@8V]M
M<&QE=`!'86)O;@!,82!G86QE<FEA(&1E(&QA('%U86P@<R=E>'1R974@;&$@
M:6UA=&=E`$=A;&5R:6$`1^!M8FEA`$5S(&=E;F5R82!L82!C;VYF:6=U<F%C
M:?,@)7,`0V]D:2!G96YE<F%T`$=E\G)G:6$`06QE;6%N>6$`1VAA;F$`1VEB
M<F%L=&%R`$YO;2!D92!P:6QA`$%N87(@80!']F1E;`!#97)C82!A;"!';V]G
M;&4`17-C86QA(&1E(&=R:7-O<P!'<NAC:6$`1W)E8R`H25-/+3@X-3DM-RD`
M1W)E;FS@;F1I80!'<F%N861A`$=E<W1I\R!D92!G<G5P<P!%;',@;F]M<R!D
M92!G<G5P(&YO(&5S('!O9&5N(&1E:7AA<B!E;B!B;&%N8P!'<G5P<P!'=6%D
M86QU<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`4&5R;6ES;W,@9&5L<R!V
M:7-I=&%N=',`3&QI8G)E(&1E('9I<VET86YT<P!'=6EN96$`1W5I;F5A($)I
M<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!N;R!P97)M970@<W5P<FEM:7(@
M;&$@9&%R<F5R82!C96RW;&$@9&4@;&$@9FEL82X`2%1-3$%R96$@;F\@<&5R
M;65T('-U<')I;6ER(&QA(&1A<G)E<F$@8V]L=6UN82!D92!L82!T875L82X`
M2%1-3$%R96$@;F\@<&5R;65T('-U<')I;6ER(&QA(&1A<G)E<F$@9FEL82!D
M92!L82!T875L82X`3F\@<R=H82!T<F]B870@;"=A=71E;G1I8V%C:?,@2%14
M4"X`2&%I=.T`06QG;W)I<VUE(&1E(&AA<V@`0V%L:71J80!#87#G86QE<F$`
M26QL82!(96%R9"!I(&EL;&5S($UC1&]N86QD`$AE8G)E=2`H25-/+3@X-3DM
M."U)*0!!;.=A9&$`06IU9&$`06IU9&$@<&5R('5T:6QI='IA<B!L)V5D:71O
M<@!!<&QI8V%C:?,@9"=A:G5D80!(96UI<V9E<FD`07%U97-T(.ES(&PG:6YI
M8VD@9&5L(&9I='AE<CH`06QT`$EN:6-I`&QA(%-A;G1A(%-E=2`H0VEU=&%T
M($5S=&%T(&1E;"!6871I8^`I`$EN:6-I`$%D<F7G82!P87)T:6-U;&%R`%1E
M;.AF;VX@<&%R=&EC=6QA<@!(;VYD=7)E<P!(;VYG($MO;F<`2&]R9&4`2&]R
M9&4O2V]L86(Z(%,G:&%N('1R;V)A="!D861E<R!834P@)7,@;F\@=N!L:61E
M<R!E;B!E;"!M:7-S871G92`E<P!(;W)D92]+;VQA8CH@3F\@:&D@:&$@8V%P
M(&UI<W-A=&=E('%U92!E<R!C;W)R97-P;VYG=6D@86UB(&PG;V)J96-T92`E
M<P!(;W)D92]+;VQA8CH@3F\@<R=H82!T<F]B870@8V%P(&]B:F5C=&4@9&5L
M('1I<'5S("5S(&5N(&5L(&UI<W-A=&=E("5S`$AO<F1E+TMO;&%B.B`E<R`B
M)7,B(&AA(&5S=&%T(&5X=')E="!C;W)R96-T86UE;G0`2&]R9&4O2V]L86(Z
M($5L(&UO=&]R(&0G:6YT96=R86-I\R!N96-E<W-I=&$@;"=E>'1E;G-I\R!0
M2%`@)V1O;7AM;"<`2&]R9&4O2V]L86(Z($YO(',G:&$@<&]G=70@8W)E87(@
M=6X@;F]U(&%R8G)E(%A-3"!P97(@82!L)V]B:F5C=&4@)7,`2&]R9&4O2V]L
M86(Z($YO(',G:&$@<&]G=70@97AT<F5U<F4@)7,@(B5S(CH@)7,`2&]R9&4O
M2V]L86(Z($YO(',G:&$@<&]G=70@<F5C=7!E<F%R(&PG:61E;G1I9FEC861O
M<B!-24U%('!E<B!A(&QA('!A<G0@9&5L('1I<'5S("5S`$AO<F1E+TMO;&%B
M.B!.;R!S)VAA('!O9W5T('-I;F-R;VYI='IA<B`E<R(E<R(Z("5S`$AO<F1E
M+TMO;&%B.B!.;R!S)VAA('!O9W5T('-I;F-R;VYI='IA<B!L97,@<75O=&5S
M.B`E<P!(;W)D92]+;VQA8CH@17-P86D@9&ES<&]N:6)L92!D97-C;VYE9W5T
M("(E<R(`4F5G;&$@:&]R:71Z;VYT86P`1F%R8VEM96YT(&AO<FET>F]N=&%L
M`$AO<FET>F]N=&%L.@!#;VT@:&5U(&%R<FEB870@9FEN<R!A<77M/R`H1F5U
M+6YO<RUH;R!S86)E<B$I`%%U86YT97,@8V]L=6UN97,@=F]L974@<F5F;VYD
M<F4_`%%U86YT<R!C86UP<R`H8V]L=6UN97,I(&AI(&AA/P!1=6%N=&5S(&9I
M;&5S('9O;&5U(')E9F]N9')E/P!(=6UI=&%T`$AU;6ET870Z`$AU;6]R:7-T
M97,`2&]N9W)I80#)<R!I;7!O<W-I8FQE(&-R96%R(&QA(&+Z<W1I82!)34%0
M.B`E<P#)<R!I;7!O<W-I8FQE('-U<')I;6ER(&QA(&+Z<W1I82!)34%0.B`E
M<P#)<R!I;7!O<W-I8FQE(&-R96%R('5N(&5S<&%I(&1I<W!O;FEB;&4@<&5R
M(&$@;&$@8OIS=&EA($E-05`Z("5S`$%D<F7G82!)4`!,)V%D<F7G82!)4"!N
M;R!E<W3@(&1I<W!O;FEB;&4N`$PG861R9>=A($E0(&YO(&5S('1R;V)A(&5N
M(&5L(&)L;V,@0TE$4B!P97)MZ',N`%9I;VQA8VGS(&1E;"!B;&]Q=65I9R!)
M4"X`26YS97)I=2!U;F$@9FEL82!D86UU;G0`27-LX&YD:6$`3F]MZ7,@:6-O
M;F5S`$EC;VYE<R!D92`E<P!)8V]N97,@86UB('1E>'0`3F]M(&0G:61E;G1I
M=&%T.@!3:2!N;R!E<R!V:7-U86QI='IA(&-O<G)E8W1A;65N="P@;V)R:74@
M)7,@96X@=6YA(&YO=F$@9FEN97-T<F$N`%-I(&YO('9I<W5A;&ET>F5U(&-A
M<"!I8V]N82!M:71J86[G86YT(&PG26YT97)N970@17AP;&]R97(L(.ES('!O
M<W-I8FQE('%U92!HX&=I=2!D)V%C=&EV87(@87%U97-T('%U861R92!P97(@
M9&5S86-T:79A<B!L82!T<F%N<W!A<NAN8VEA(&1E(%!.1RX`4VD@=F5I974@
M87%U97-T(&UI<W-A=&=E(&5N(&QL;V,@9&4@;&$@:6UA=&=E+"!E;"!V;W-T
M<F4@;F%V96=A9&]R(&YO('!O="!M;W-T<F%R(&QA(&EM871G92!Q=64@=F]L
M974@<&5N:F%R+@!6:7-U86QI='IA8VGS('!RZ'9I82!D92!L82!I;6%T9V4Z
M`%523"!D92!L82!I;6%T9V4`55),(&1E(&QA(&EM871G93H`26UA=&=E(&1E
M(&QA(&=A;&5R:6$`26UA=&=E(&1E(&QA(&=A;&5R:6$Z`$/@<G)E9V$@9&4@
M;&$@:6UA=&=E`$EM871G97,`26UP;W)T86-I\RP@<&%S("5D`$-A;7`@:6UP
M;W)T870Z("5S`$-A;7!S(&EM<&]R=&%T<SH`26YS97)I=2!U;F$@9FEL82!A
M('-O=&$`16P@8V]D:2!D92!L)V%C8VGS('%U92!S)VAA(&9A8VEL:71A="#I
M<R!I;F-O<G)E8W1E+@!.;VT@9"=U<W5A<FD@:2]O(&-O;G1R87-E;GEE<R!I
M;F-O<G)E8W1E<RX`4R=H82!F86-I;&ET870@=6X@;F]M(&0G=7-U87)I(&\@
M=6YA(&%D<F7G82!A;'1E<FYA=&EV82!I;F-O<G)E8W1E<RX@5&]R;F5U+6AO
M(&$@:6YT96YT87(@;R!P;W-E=2UV;W,@96X@8V]N=&%C=&4@86UB(&PG861M
M:6YI<W1R861O<B!P97(@82!MZ7,@86IU9&$N`$%U9VUE;G1A<B!E;"!S86=N
M870`S6YD:6$`57-U87)I<R!I;F1I=FED=6%L<P!);F1O;NAS:6$`26YF;W)M
M86-I\P!);F9O<FUA8VGS`$EN:6-I86QI='IA;G0@;?)D=6P@)7,N+BX@`$EN
M<V5R96EX('5N82!C;VQU;6YA(&$@<V]T80!);G-E<F5I>"!U;F$@:6UA=&=E
M`$EN<V5R96EX('5N82!T875L80!);G-E<F5I>"!E;FQL8><@=V5B`$EN<V5R
M96EX(&QA(&-O;'5M;F$@9&%M=6YT`$EN<V5R96EX('5N82!N;W9A(&-O;'5M
M;F$@82!S;W1A(&1E(&PG86-T=6%L`$EN<V5R96EX('5N82!N;W9A(&-O;'5M
M;F$@82!S;V)R92!D92!L)V%C='5A;`!);G-E<F5I>"!U;F$@;F]V82!F:6QA
M(&$@<V]T82!D92!L)V%C='5A;`!);G-E<F5I>"!U;F$@;F]V82!F:6QA(&$@
M<V]B<F4@9&4@;"=A8W1U86P@`$EN<V5R96EX('5N('!A<N!G<F%F(&$@<V]T
M82!D96P@;F]D92!A8W1U86P`26YS97)E:7@@=6X@<&%RX&=R868@82!S;V)R
M92!D96P@;F]D92!A8W1U86P`26YS97)E:7@@;"=A;'1R82!P;&%N=&EL;&$`
M26YS97)E:7@@=6YA(&%D<F7G82!D92!C;W)R974@<&5R(')E8G)E(&QA(&YO
M=F$@8V]N=')A<V5N>6%);G-E<FEU('5N82!A9')EYV$@96QE8W1R\FYI8V$@
M82!L82!Q=6%L('!O9&5U(')E8G)E(&QA(&YO=F$@8V]N=')A<V5N>6$Z`$EN
M<V5R96EX('5N82!C96RW;&$@82!S;W1A`$EN<V5R96EX('5N82!C96RW;&$@
M82!S;V)R90!);G-E<FEU('5N82!C;VQU;6YA(&$@<V]T80!);G-E<FEU('5N
M82!C;VQU;6YA(&$@<V]B<F4`26YS97)I=2!M:7-S871G97,`26YS97)I=2!U
M;B!P87+@9W)A9B!A('-O=&$`26YS97)I=2!U;B!P87+@9W)A9B!A('-O8G)E
M`$EN<V5R:74@=6YA(&9I;&$@82!S;W1A`$EN<V5R:74@=6YA(&9I;&$@82!S
M;V)R90!);G-E<FEU(&QA(')E<W!O<W1A(&$@;&$@<')E9W5N=&$@9&4@<V5G
M=7)E=&%T.@!);G-E<FER+TUO9&EF:6-A<B!I;6%T9V4`26YS97)I<B]-;V1I
M9FEC87(@96YL;&'G`$YO(&1I<W!O<V5U(&1E('!R;W4@8W+H9&ET('!E<B!E
M;G9I87(M;&\@82!L82!L;&ES=&$@9&4@9&ES=')I8G5C:?,N`$-RZ&1I="!I
M;G-U9FEC:65N="X`3F]M8G)E(&5N=&5R`$QL:7-T82!D92!N;VUB<F5S(&5N
M=&5R<P!51$@@;F\@=N!L:61A+B`H0V%PYV%L97)A(&1E(&1A9&5S(&0G=7-U
M87)I*2X`07!L:6-A8VGS(&YO(';@;&ED82X`3"=I9&5N=&EF:6-A9&]R(&1E
M;"!L;W0@;F\@Z7,@=N!L:60`3&5S(&1A9&5S('%U92!S)VAA;B!T<F%MZ',@
M;F\@<_-N(';@;&ED97,N`$PG861R9>=A(&1E(&1E<W1I;F%C:?,@;F\@Z7,@
M=N!L:61A+@!%;"!F;W)M870@9&4@;"=A<GAI=2!N;R#I<R!VX&QI9"X`3&$@
M8VQA=2!D92!L82!L;&ECZ&YC:6$@;F\@Z7,@=N!L:61A+@!,82!U8FEC86-I
M\R!Q=64@:&5U('!R;W!O<F-I;VYA="!N;R#I<R!VX&QI9&$N`$5L('1I<'5S
M+6US9R!N;R#I<R!VX&QI9"X`36%N8V$@96P@87!I7VED(&\@96P@<75E(',G
M:&$@9F%C:6QI=&%T(&YO(.ES(';@;&ED+@!-86YQ=65N('!A<N!M971R97,@
M;R!E;',@<75E(',G:&%N(&9A8VEL:71A="!N;R!S\VX@=N!L:61S+@!,)V%U
M=&]R:71Z86-I\R!P871E<FYA(&YO(.ES(';@;&ED82X`16P@8V]D:2!D)VED
M96YT:69I8V%C:?,@9&4@<V]C:2!N;R#I<R!VX&QI9"X`16P@8V]D:2!D96P@
M<')O9'5C=&4@;F\@Z7,@=N!L:60N`$5L('!R;W1O8V]L(&YO(.ES(';@;&ED
M+@!,)V]B:F5C=&4@8V]M<&%R=&ET(&YO(.ES(';@;&ED`$PG861R9>=A(&0G
M;W)I9V5N(&YO(.ES(';@;&ED82X`3&5S(&1A9&5S(%5N:6-O9&4@;F\@<_-N
M(';@;&ED97,N`$EN=F5N=&%R:0!)<F%N+"!297#Z8FQI8V$@27-LX&UI8V$@
M9"<`27)A<0!)<FQA;F1A`$EL;&$@9&4@36%N`%1E;7!E<W1E<R!A[VQL861E
M<P!)<W)A96P`16UI<W-O<@!#=7)S:79A`$ETX&QI80!*86UA:6-A`$=E;F5R
M`$IA</,`2F%P;V[H<R`H25-/+3(P,#(M2E`I`$IE<G-E>0!*;W)DX&YI80!*
M=6QI;VP`2G5N>0!*=7-T:69I8V%R`$IU<W1I9FEC87(@86P@8V5N=')E`$IU
M<W1I9FEC87(@82!T;W1S(&1O<R!M87)G97,`2G5S=&EF:6-A<B!A(&PG97-Q
M=65R<F$`2G5S=&EF:6-A<B!A(&QA(&1R971A`$MA>F%K:'-T86X`5F]L974@
M8V]N<V5R=F%R(&PG;W)I9VEN86P_`$ME;GEA`$5L('-E<G9I9&]R($ME<F)E
M<F]S(&AA(')E8G5T:F%T(&PG875T96YT:6-A8VGS+@!+97)N96P@3F5W8FEE
M<P!#<F5A8VGS(&1E(&-L875S`$5M<')E;71A(&1I9VET86P@9&4@;&$@8VQA
M=0!,;VYG:71U9"!D92!L82!C;&%U`%1I<'5S(&1E(&-L874`VG,@9&4@;&$@
M8VQA=0!*82!E>&ES=&5I>"!U;F$@8VQA=2!E;B!E;"!S97)V:61O<B!D92!C
M;&%U<R!P^F)L:7%U97,N`$YO:7,`2VER:6)A=&D`0V]R96$L(%)E</IB;&EC
M82!$96UO8W+@=&EC82!0;W!U;&%R(&1E`$-O<F5A+"!297#Z8FQI8V$@9&4`
M0V]R9>`@*$550RU+4BD`2W5W86ET`$MI<F=U:7II<W1A;@!&;W)M870`261I
M;VUA`%)E</IB;&EC82!$96UO8W+@=&EC82!0;W!U;&%R(&1E($QA;W,`1&%R
M<F5R82!M96ET870`1&%R<F5R('%U87)T`$1A<G)E<F$@86-T=6%L:71Z86-I
M\SH`1&%R<F5R82!C;VYN97AI\SH@)7,`1&%R<F5R82!C;VYN97AI\SH@)7,@
M9&4@)7,`1&%R<F5R82!C;VYN97AI\SH`3&5T\FYI80!,;&5I`$1I<W-E;GD`
M1&5I>&%R+6AO(&5N(&)L86YC('!E<B!E;&EM:6YA<B!E;"!C;VYT;W)N`$SM
M8F%N`$5S<75E<G)A`$-A<.=A;&5R82!E<W%U97)R80!686QO<G,@9&4@;"=E
M<W%U97)R80!,97-O=&AO`$QI8NAR:6$`3.UB:6$`3&EE8VAT96YS=&5I;@!0
M;'5G:6T@9F5B;&4`4&QU:F$@9F5B;&4`4&QU:F$@9F5B;&4@82!P<FEM97)A
M(&AO<F$`4&QU:F$@9F5B;&4@8V%P(&%L('1A<F0`4G5I>&%T(&9E8FQE`%)U
M:7AA="!F96)L92!A;6(@=')O;G,`3F5V861A(&9E8FQE`%C@9F5C(&1E(&YE
M=2!F96)L90!,:6UE<FEC:P!%;FQL8><`16YL;&%CYV%R(&5L<R!P=6YT<R!A
M;6(Z`$5N;&QAYV%R(&PG861R9>=A(&5L96-T<O)N:6-A(&$@;&$@<.!G:6YA
M(&1E(')E9&%C=&%T('%U86X@97,@;6]S=')I`$5N;&QAYV]S`$=A;&5T82!,
M:6YU>`!,;&ES=&%R("T@3"=U<W5A<FD@<&]T('9E=7)E(&QA(&-A<G!E=&$`
M3&QI<W1A<B!L97,@8F%S97,@9&4@9&%D97,`3&QI<W1A(&1E;',@=&5M97,@
M9"=A:G5D80!,;&ES=&%R(&QE<R!T875L97,`3&ES="U!<F-H:79E`$QI<W0M
M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R
M:6)E`$QI<W0M56YS=6)S8W)I8F4`3&$@;&QI<W1A(&0G=7-U87)I<R!E<W3@
M(&EN:&%B:6QI=&%D82X`0FEB;&EO9W)A9FEA`$QI='7@;FEA`%,G97-TX"!C
M87)R96=A;G0N+BX`2&]R82!L;V-A;#H@`$ED:6]M82!I(&AO<F$`56)I8V%C
M:?,`26YI8VEA(&QA('-E<W-I\P!3=7)T`%1A<W%U97,@9"=I;FEC:2!D92!S
M97-S:?,`2&D@:&$@:&%G=70@=6X@97)R;W(@9&4@8V]N;F5X:?,@<&5R<77H
M(&AE=2!I;G1R;V1U[W0@:6YC;W)R96-T86UE;G0@96P@;F]M(&0G=7-U87)I
M(&\@;&$@8V]N=')A<V5N>6$N`$AA(&9A;&QA="!L82!C;VYN97AI\RX`5&5X
M="!L;&%R9P!!;6]R`$)A:7@`06QF86)E="!G<F5C(&5N(&UI;OIS8W5L80!!
M;&9A8F5T(&QL873M(&5N(&UI;OIS8W5L80!8:69R97,@<F]M86YE<R!E;B!M
M:6[Z<V-U;&$`3'5X96UB=7)G`$U-`$U/5$0`3"=A<GAI=2!A9&IU;G0@35,M
M5$Y%1B!N;R!C;VYT96YI82!D861E<RX`35-'`$UA8V%U`$UA8V5D\FYI82P@
M06YT:6=A(%)E</IB;&EC82!)=6=O<VQA=F$@9&4`36%D86=A<V-A<@!-X&=I
M8P!#;W)R974@96QE8W1R\FYI8P!!9&UI;FES=')A9&]R(&1E(&-O<G)E=0!3
M)V5S=.`@8W)E86YT('5N(&5N;&QAYRXN+@!-86QA=VD`36%LX&ES:6$`36%L
M9&EV97,`36%L:0!-86QT80!'97-T:6]N974@;&$@;&QI<W1A(&1E(&-A=&5G
M;W)I97,@86UB(&QE<R!Q=6%L<R!H974@9"=E=&EQ=65T87(@96QS(&5L96UE
M;G1S+"!I(&5L<R!C;VQO<G,@87-S;V-I871S(&%M8B!A<75E<W1E<R!C871E
M9V]R:65S+@!-87!A($UA<#(T`$UA<&$@36%P475E<W0`36%RYP!-87)G90!-
M87)C87(@86UB(&EN9&EC861O<G,@=FES:6)L97,O:6YV:7-I8FQE<P!-87)C
M87(@86UB(&%L=')E<R!I;F1I8V%D;W)S("AP+B!E+BP@:6UP;W)T86YT+W)E
M<W!O<W0I`$EL;&5S($UA<G-H86QL`$UA<G1I;FEC80!#86UP<R!Q=64@8V]I
M;F-I9&5I>&EN`$UA=7)I=.!N:6$`36%U<FEC:0!#<NAD:70@;>!X:6T@<&5R
M;>AS+@!3)VAA('-U<&5R870@96P@;F]M8G)E(&W@>&EM(&1E('!A<G1S(&1E
M(&UI<W-A=&=E+@!496UP97)A='5R82!MX'AI;6$@9&4@;&5S(&1A<G)E<F5S
M(#(T(&AO<F5S.B``5&5M<&5R871U<F$@;>!X:6UA(&1E(&QE<R!D87)R97)E
M<R`V(&AO<F5S.B``3&]N9VET=60@;>!X:6UA`$UA:6<`36%Y;W1T90!-961I
M8VEN80!-96UB<F5S`%1I<'5S(&1E(&UE;OHZ`%)E9F]N87(@;&5S(&-E;+=L
M97,`36ES<V%T9V4`16P@;6ES<V%T9V4@:&$@97-T870@=F5R:69I8V%T(&-O
M<G)E8W1A;65N="P@<&5R\B!N;R!S)VAA('!O9W5T('9E<FEF:6-A<B!E;"!C
M97)T:69I8V%T(&5L('-I9VYA;G0N`$UI<W-A=&=E(&-A9'5C870N`%1I<'5S
M(&1E(&UI<W-A=&=E`%1E;7!S(&1E($U%5$%2`$5L(&)L;V,@345405(@;F\@
M97-TX"!D:7-P;VYI8FQE+@!%;"!B;&]C($U%5$%2(&YO(&5S=.`@9&ES<&]N
M:6)L92X@16QS(&1E=&%L;',@:&%N(&5S=&%T(')E9VES=')A=',@<&5R(&$@
M;"=A9&UI;FES=')A9&]R+@!,82!B87-E(&1E(&1A9&5S($U%5$%2(&YO(&5S
M=.`@8V]N;F5C=&%D82X`3>AT;V1E`$WH=')I8P!-Z'AI8P!-:6-R;V[H<VEA
M+"!%<W1A=',@1F5D97)A=',@9&4`0V5N=')E`%1I<'5S($U)344`5&5M<&5R
M871U<F$@;>UN:6UA(&1E(&QE<R!D87)R97)E<R`R-"!H;W)E<SH@`%1E;7!E
M<F%T=7)A(&WM;FEM82!D92!L97,@9&%R<F5R97,@-B!H;W)E<SH@`%+H<&QI
M8V$`36ES8V5LMVQA;FD`1F%L=&$@;&$@<V]LMVQI8VET=60@2%144"!P97(@
M86P@<&%Q=65T(%!%05(N`$9A;'1A(&QA(&-O;F9I9W5R86-I\RX@3"=H974@
M9&4@9V5N97)A<B!A<F$@<VD@=F]L974@=71I;&ET>F%R(&%Q=65S=&$@87!L
M:6-A8VGS+@!&86QT82!L)VED96YT:69I8V%D;W(@9&5L(&UI<W-A=&=E+@!&
M86QT82!E;"!C;W)R974@96QE8W1R\FYI8R!D96P@<&%Q=65T(%!%05(@;F5C
M97-S87)I+@!&86QT82!L)VED96YT:69I8V%D;W(@9&4@<V5S<VGS+@!$;"X`
M0V]R<F5U(&WR8FEL`$UO9&5R870`1&%T82!M;V1I9FEC861A`$UO9&EF:6-A
M<B!L82!54DP`3?)D=6P`36]L9.!V:6$L(%)E</IB;&EC82!D90!-\FYA8V\`
M36]N9_)L:6$`365S(&D@86YY`$UE;G-U86QM96YT`$UO;G1S97)R870`1F%S
M97,@;'5N87)S`$UA<G)O8P!-86IO<FETX')I86UE;G0@9&5S8V]B97)T`$UA
M:F]R:73@<FEA;65N="!E;FYU=F]L870`36%J;W)I=.!R:6%M96YT(&%S<V]L
M96QL870`36]U<F4@8V%P(&%V86QL`$UO=7)E(&$@;"=E<W%U97)R80!-;W5R
M92!A(&QA(&1R971A`$UO=7)E(&-A<"!A;75N=`!-;W5R92!C87`@879A;&P`
M36]U<F4@8V%P(&%M=6YT`$UOYV%M8FEC`$QI<W1E<R!D97-P;&5G86)L97,@
M96YL;&'G861E<R!E;B!D:79E<G-O<R!N:79E;&QS`%-E;&5C8VGS(&WZ;'1I
M<&QE`$5L(&UE=2!C;VUP=&4`16P@;65U('!O<G1A;`!$:7-S96YY(&1E;"!M
M974@<&]R=&%L`$UY86YM87(`3D\L($Y/(&AI(&5S=&EC(&0G86-O<F0`3F]M
M`$YA;>UB:6$`3F%U<G4`3F5P86P`4&'O<V]S($)A:7AO<P!!;G1I;&QE<R!.
M965R;&%N9&5S97,`55),(&)A<V4@9&4@3F5T<V-A<&4`55),(&1E(')E=F]C
M86-I\R!D92!#02!D92!.971S8V%P90!54DP@9&4@<&]L[71I<75E<R!D92!#
M02!D92!.971S8V%P90!54DP@9&4@<F5N;W9A8VGS(&1E($YE='-C87!E`%52
M3"!D92!R979O8V%C:?,@9&4@3F5T<V-A<&4`3F]M(&1E;"!S97)V:61O<B!3
M4TP@9&4@3F5T<V-A<&4`0V]M96YT87)I(&1E;"!C97)T:69I8V%T(&1E($YE
M='-C87!E`%1I<'5S(&1E(&-E<G1I9FEC870@9&4@3F5T<V-A<&4`6&%R>&$`
M36%I`$YO=F$@0V%L963R;FEA`$YO=F$@8V%T96=O<FEA`$QL=6YA(&YO=F$`
M3F]U(&YO;2!D)W5S=6%R:2`H;W!C:6]N86PI`$YO=F$@6F5L86YD80!.;W9A
M(&9I;F5S=')A("A?96X@8FQA;F,I`$UI<W-A=&=E<P!'<G5P<R!D92!D:7-C
M=7-S:?,`4V5G_&5N=``T(&9A<V5S('-E9_QE;G1S`$]P8VEO;G,@<V5G_&5N
M=',`4V5G_&5N=#X`3FEC87)A9W5A`$[M9V5R`$YI9^AR:6$`3FET`$YI=64`
M3F\`3F\@97,@9&ES<&]S96X@9&4@9&%D97,@9&4@8V]N9FEG=7)A8VGS('!E
M<B!M;W-T<F%R(&QE<R!D:69E<NAN8VEE<RX`3F\@97,@9&ES<&]S82!D)W5N
M82!E<W1R873H9VEA('!E<B!C<F5A<B!I;6%T9V5S($E33RX`3F\@:&D@:&$@
M<&QA;G1I;&QA(&1E(&QO=',N`$YO(&5X:7-T96EX(&-A<"!B;&]C(&5N(&QA
M('!O<VEC:?,@<V]LMVQI8VET861A`$YO(',G:&$@<')O<&]R8VEO;F%T('5N
M(&YO;2!D)V%G96YD82!P97(@82!L)V%U=&5N=&EC86-I\R!-0T%,+@!396YS
M92!C86YV:7,N`$YO(&5S('!O9&5N(&%F96=I<B!D97-C96YD96YT<R!A(&%Q
M=65S="!P97)M[7,`3F\@<R=H82!E<W!E8VEF:6-A="!L97,@9&%D97,@9&4@
M8V]N9FEG=7)A8VGS('!E<B!A("5S+@!.;R!S)VAA(&5S<&5C:69I8V%T(&QE
M<R!D861E<R!D92!C;VYF:6=U<F%C:?,@<&5R(&$@1E10('!E<B!61E,N`$YO
M(',G:&$@97-P96-I9FEC870@;&5S(&1A9&5S(&1E(&-O;F9I9W5R86-I\R!P
M97(@82!344P@<&5R(%9&4RX`3F\@<R=H82!E<W!E8VEF:6-A="!L97,@9&%D
M97,@9&4@8V]N9FEG=7)A8VGS(&1E(%-13"!P97(@86P@9FET>&5R(%-13"X`
M3F\@<75E9&$@8W+H9&ET+@!.;R!S)VAA(&9A8VEL:71A="!U;F$@9&5S=&EN
M86-I\RX`3F\@<R=H82!C87)R96=A="!C87`@87)X:74N`$YO(',G:&$@=')O
M8F%T(&-A<"!I8V]N82X`3F\@<R=H82!D969I;FET('5N82!U8FEC86-I\RX`
M3F\@<R=H82!F86-I;&ET870@=6YA('5B:6-A8VGS+@!.;R!S)VAA(&EN=')O
M9'7O="!U;B!M:7-S871G92X`3F\@<R=H82!E<W!E8VEF:6-A="!U;B!N;VTN
M`$YO(',G:&$@97-P96-I9FEC870@=6YA('AI9G)A+@!.;R!E<R!P97)M971E
M;B!L97,@9&ET97,@;V9E;G-I=F5S+@!.;R!S)VAA(&EN=')O9'7O="!U;F$@
M8V]N=')A<V5N>6$@<&5R(&$@;"=A=71E;G1I8V%C:?,@2%144"X`3F\@<R=H
M82!I;G1R;V1U[W0@=6YA(&-O;G1R87-E;GEA('!E<B!A(&PG875T96YT:6-A
M8VGS($E-05`N`$YO(',G:&$@:6YT<F]D=>]T('5N82!C;VYT<F%S96YY82!P
M97(@82!L)V%U=&5N=&EC86-I\R!+97)B97)O<RX`3F\@<R=H82!I;G1R;V1U
M[W0@=6YA(&-O;G1R87-E;GEA('!E<B!A(&PG875T96YT:6-A8VGS(&0G:6YI
M8VDN`$YO(',G:&$@:6YT<F]D=>]T('5N82!C;VYT<F%S96YY82!P97(@82!L
M)V%U=&5N=&EC86-I\R!005-35T0N`$YO(',G:&$@:6YT<F]D=>]T('5N82!C
M;VYT<F%S96YY82!P97(@82!L)V%U=&5N=&EC86-I\R!334(N`$YO(',G:&$@
M:6YD:6-A="!L82!V:6$@9"=A8V/I<R!A;"!B:6YA<FD@3W!E;E-33"X@0V%L
M(&5L(&)I;F%R:2!/<&5N4U-,('!E<B!T<F5B86QL87(@86UB(&QE<R!D861E
M<R!02T-3(#$R+@!.;R!H:2!H82!A;'1E<R!P96YD96YT<RX`3F\@<R=H82!D
M969I;FET(&PG97-P86D@9&ES<&]N:6)L92X`4V5N<V4@<F5G;&5S`%-E;G-E
M(&-A<F5S`$YO(&5X:7-T96EX(&%Q=65S="!A<GAI=0!.;R!E<R!D:7-P;W-A
M(&1E(&-A<"!D:7)E8W1O<FD@=&5M<&]R86P@<&5R(&$@;&$@;65M\G)I82!C
M874N`$YO(&AE=2!E;G9I870@96P@;F]M(&0G=7-U87)I(&YI+V\@;&$@8V]N
M=')A<V5N>6$`3F\@<R=H86X@<F5T;W)N870@9&%D97,@6$U,(';@;&ED97,`
M4V5N<V4@=F%L;W)S`$YO(',G:&$@=')O8F%T(&QA('9E<G-I\R!E;B!L82!C
M;VYF:6=U<F%C:?,@;W)I9VEN86PN(%)E9V5N97)E=2!L82!C;VYF:6=U<F%C
M:?,N`$YO(',G:&$@=')O8F%T(&QA('9E<G-I\R!E;B!L82!C;VYF:6=U<F%C
M:?,N(%)E9V5N97)E=2!L82!C;VYF:6=U<F%C:?,N`$-A<`!#87`@*/IS(&EM
M<&SM8VET*0!.\G)D:6,@*$E33RTX.#4Y+3$P*0!);&QA(&1E($YO<F9O;&L`
M2&5M:7-F97)I(&YO<F0`26QL97,@36%R:6%N;F5S(&1E;"!.;W)D`$YO<G5E
M9V$`3F\@9&5S<'+I<P!.;R!A8F%N<P!.;R#I<R!U;B!D:7)E8W1O<FD`3F\@
M:6UP;&5M96YT870N`$YO(&1E9FEN:70`3F\@<&5R;>AS+@!.;W1E<P!.;R!H
M:2!H82!R97,@82!V:7-U86QI='IA<BP@<F5T<F]C961I=2X`3F]V96UB<F4`
M3F]M8G)E`$YO;6)R92!D92!C87+@8W1E<G,`3F]M8G)E(&1E(&-O;'5M;F5S
M`$YO;6)R92!D92!F:6QE<P!.;R!S)VAA;B!E<W!E8VEF:6-A="!N;VUB<F5S
M('%U92!H86=I;B!D92!S97(@86-T=6%L:71Z871S(&5N(&QA(&QL:7-T82!D
M92!D:7-T<FEB=6-I\RX`1"=A8V]R9`!/8FIE8W1E`$-R96%D;W(@9&4@;"=O
M8FIE8W1E`$]C=&%L`$]C='5B<F4`1FEL=')E(&0G:6YF<F%C8VEO;G,`3V9I
M8VEN80!/;6%N`$YO;>ES(&5L<R!S97)V:61O<G,@24U!4"!P97)M971E;B!L
M)_IS(&1E(&-A<G!E=&5S(&-O;7!A<G1I9&5S+@!.;VWI<R!M:7-S871G97,@
M;V9E;G-I=7,`3F]MZ7,@Z7,@<&5R;65S82!U;F$@^FYI8V$@861R9>=A(&5L
M96-T<O)N:6-A+@!.;VWI<R!E;"!P<F]P:65T87)I(&\@;"=A9&UI;FES=')A
M9&]R(&1E('-I<W1E;65S('!O="!C86YV:6%R(&QA('!R;W!I971A="!O(&5L
M<R!P97)M:7-O<R!D96P@<')O<&EE=&%R:2!P97(@82!R96-U<G-O<R!C;VUP
M87)T:71S`$]B<FEU(&5N('5N82!N;W9A(&9I;F5S=')A`$5R<F]R($]P96Y3
M4TPZ(&YO(',G:&%N('!O9W5T(&5X=')E=7)E(&QE<R!D861E<R!D92!L82!P
M87)T(%,O34E-12!S:6=N861A+@!/8G)E(&%Q=65S="!E;FQL8><@96X@=6YA
M(&YO=F$@9FEN97-T<F$`4VES=&5M82!O<&5R871I=0!/<&-I;VYS`$]P8VEO
M;G,@9"<E<P!,;&ES=&$@;W)D96YA9&$`3W)G86YI='IA8VGS`%5N:71A="!O
M<F=A;FET>F%T:79A`%,G97-TX"!O<F=A;FET>F%N=`!0;&%N=&EL;&$@9"=A
M<&QI8V%C:?,@;W)I9VEN86P`4&QA;G1I;&QE<R!O<FEG:6YA;',@96X@)7,Z
M`$%L=')E`$%L=')A(&EN9F]R;6%C:?,`4&5R;6ES;W,@9&5L('!R;W!I971A
M<FD`3"=A=71E;G1I8V%C:?,@4$%-(&YO(&5S=.`@9&ES<&]N:6)L92X`4VEG
M;F%T=7)A(&1I9VET86P@4$=0`$1A9&5S('AI9G)A9&5S(&%M8B!01U``0VQA
M=2!01U`@</IB;&EC80!$861E<R!S:6=N861E<R]X:69R861E<R!A;6(@4$=0
M`$-O9&D@4$A0`$EN=.AR<')E="!D)V]R9')E<R!02%``4&QU9VEM<R!D92!T
M87)D80!0;'5G97,@9&4@=&%R9&$`3F5V861E<R!D92!T87)D80!8X&9E8W,@
M9&4@;F5U(&$@;&$@=&%R9&$`4V]L(&1E('1A<F1A`%1E;7!E<W1E<R!D92!T
M87)D80!);G3H<G!R970@9"=O<F1R97,@4%](4`!397!A<F%C:?,`4&%K:7-T
M86X`4&%L874`5&5R<FET;W)I('!A;&5S=.TL(&]C=7!A=`!086YA;>``4&%P
M=6$@3F]V82!'=6EN96$`4&%R86=U86D`4&%R8VEA;&UE;G0@96YN=79O;&%T
M`$-O;G1R87-E;GEA`$-O;G1R87-E;GEA(&EN8V]R<F5C=&$`0V%L(&EN=')O
M9'5I<B!U;F$@8V]N=')A<V5N>6$@<&5R(&$@;"=A=71E;G1I8V%C:?,@4D%$
M2553+@!#;VYT<F%S96YY82!A;6(@8V]N9FER;6%C:?,`0V]N=')A<V5N>6$Z
M`$-O;G1R87-E;GEA.B``3&5S(&-O;G1R87-E;GEE<R!H86X@9&4@8V]I;F-I
M9&ER+@!%;F=A;GAA<@!%;F=A;GAA<B!D96P@<&]R=&$M<F5T86QL<P!#86WM
M`$%L=&5S('!E;F1E;G1S.@!'96YT`%!E<F-E;G1A=&=E`%)E86QI='IA<B!O
M<&5R86-I;VYS(&1E(&UA;G1E;FEM96YT`%9O;&5U(')E86QI='IA<B!O<&5R
M86-I;VYS(&1E(&UA;G1E;FEM96YT(&5N(&EN:6-I87(@;&$@<V5S<VGS/P!0
M97)M[7,`4&5R;6ES(&1E;F5G870`061M:6YI<W1R861O<B!D92!P97)M:7-O
M<P!$861E<R!P97)S;VYA;',`4&5R^@!!;FEM86QS(&1E(&-O;7!A;GEI80!&
M:6QI<&EN97,`5&5LZ&9O;@!&;W1O<P!0:71C86ER;@!0[7AE;',`5/)P:6-S
M`$-L:6-A<B!E;B!U;F$@8V5LMVQA`$-O;F9I<FUA<B!Q=64@=F]L974@<W5P
M<FEM:7(@87%U97-T(&5L96UE;G0Z`$-O;F9I<FUA<B!Q=64@=F]L974@9&5S
M96YL;&'G87(@87%U97-T(&5L96UE;G0N`$EN=')O9'7O=2!U;B!M97,@:2!U
M;B!A;GDN`$EN=')O9'7O=2!U;B!N;VT@<&5R(&$@;&$@;F]V82!C871E9V]R
M:6$Z`$EN=')O9'7O=2!U;F$@861R9>=A($E0(';@;&ED82X`26YT<F]D=>]U
M('5N82!D871A(';@;&ED82P@8V]M<')O=F5U(&5L<R!D:65S('%U92!TZ2!E
M;"!M97,N`$EN=')O9'7O=2!U;F$@:&]R82!VX&QI9&$N`%!R;W!O<F-I;VYE
M=2!U;B!R97-U;2!D96P@<')O8FQE;6$N`%!R;W!O<F-I;VYE=2!E;"!N;VT@
M9"=U<W5A<FD@:2!L82!C;VYT<F%S96YY80!496-L96=E=2!E;"!N;VT@9&4@
M;&$@;F]V82!C871E9V]R:6$Z`%!O;/)N:6$`4&]L[71I8V$`16YQ=65S=&5S
M`%!O<G1U9V%L`$-O;+=L;V-A8VGS(&0G87%U97-T82!I;6%T9V4`0V]LMVQO
M8V%C:?,@9"=A<75E<W1A('1A=6QA`$5N=FEA<B!A(&%Q=65S=&$@8V%R<&5T
M82`H;F\@:&D@;V)L:6=A($E-05`I`%!R96-I<&ET86-I\R!D=7)A;G0@;&$@
M9&%R<F5R82`E<R!H;W)A(&\@:&]R97,Z(`!0<F5F<U]L9&%P.B!.;R!S)VAA
M('1R;V)A="!L)V5X=&5N<VGS($Q$05`@<V]LMVQI8VET861A+@!0<F5F<U]S
M97-S:6]N.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N<VGS(&1E('-E<W-I\R!S
M;VRW;&EC:71A9&$N`%!R97-S:?,`4')E<W-I\R!A;"!N:79E;&P@9&5L(&UA
M<CH`4')E<W-I\SH@`%9I<W5A;&ET>F%C:?,@<'+H=FEA`%9I<W5A;&ET>F%R
M('!RZ'9I86UE;G0@;&$@:6UA=&=E(&5N('5N82!N;W9A(&9I;F5S=')A`$]P
M8VEO;G,@<'+H=FEE<P!);7!R:6UI<B!E;"!D;V-U;65N=`!#;&%U('!R:79A
M9&$`4')O8FQE;6$`1&5S8W)I<&-I\R!D96P@<')O8FQE;6$`4')O:F5C=&5S
M`%1E>'0@:6YD:6-A9&]R`$-L874@</IB;&EC80!!;&=O<FES;64@9&4@8VQA
M=2!P^F)L:6-A`$EN9F]R;6%C:?,@9&4@8VQA=2!P^F)L:6-A`$YO(',G:&$@
M9V5N97)A="!C;W)R96-T86UE;G0@;&$@<&%R96QL82!D92!C;&%U<R!P^F)L
M:6-A+W!R:79A9&$`4'5E<G1O(%)I8V\`46%T87(`0V]N<W5L=&$`0VQA=2!P
M^F)L:6-A(%)302`H)60@8FET*0!";W3S(&1E('-E;&5C8VGS`%!L=6IA`%!L
M=6IA(&$@<')I;65R82!H;W)A`%!L=6IA(&-A<"!A;"!T87)D`%)U:7AA=`!0
M;'5J82!I(&YE=P!!:6=U86YE=0!$:71A(&%L96%T\G)I80!296QA8VGS`$QL
M96=I=0!,;&5G:74@96QS(&UI<W-A=&=E<P!#;VYF:7)M974@<75E('9O;&5U
M('-U<')I;6ER("5S/R!!<75E<W1A(&]P97)A8VGS(&YO(&5S('!O="!D97-F
M97(N`$-O;F9I<FUE=2!Q=64@=F]L974@<W5P<FEM:7(@;&5S(&1A9&5S(&1E
M(&PG=7-U87)I('!E<B!A(&PG=7-U87)I("5S/R!!<75E<W1A(&]P97)A8VGS
M(&YO(&5S('!O="!D97-F97(N`%1O<FYA(&$@9F5R(&QA(&1A<G)E<F$@86-C
M:?,`4F5F<F5S8V%R(&5L<R!E;&5M96YT<R!D96P@;65N^B!D:6[@;6EC<P!2
M969R97-C87(@;&$@=FES=6%L:71Z86-I\R!D96P@<&]R=&%L`$5X<')E<W-I
M\R!R96=U;&%R`$YA=F5G861O<B!D92!R96QA8VEO;G,`0V]M96YT87)I<P!3
M97)V:61O<G,@<F5M;W1S`%523"!R96UO="`H:'1T<',Z+R]W=W<N97AE;7!L
M92YE<R]H;W)D92DZ`%-U<')I;6ER`%-U<')I;6ER(&)L;V,`4W5P<FEM:7(@
M8V]L=6UN80!3=7!R:6UI<B!L82!F;W)M871A8VGS`%-U<')I;6ER(&QA('!A
M<F5L;&$`4W5P<FEM:7(@;&$@<V5Q_.AN8VEA(&1E<V%D82!D96P@9&ER96-T
M;W)I('1E;7!O<F%L(&1E;"!S97)V:61O<BX`4W5P<FEM:7(@96P`4W5P<FEM
M:7(@87%U97-T(&YO9&4@9&5L(&1O8W5M96YT`%-U<')I;6ER(&PG=7-U87)I
M`%-U<')I;6ER(&PG=7-U87)I.B`E<P!.;R!S)VAA('!O9W5T(')E<W!O;F1R
M92!A(&QA('-O;+=L:6-I='5D+B!#;V1I(&0G97)R;W(@<F5T;W)N870Z(`!.
M;R!S)VAA('1R;V)A="!E;"!S97)V96D@<V]LMVQI8VET870N`$-A;7`@<V]L
MMVQI8VET870`4F5I;FEC:6$`4F5I;FEC:6%R(&QA(&-O;G1R87-E;GEA`%)E
M:6YI8VEA<B!L82!C;VYT<F%S96YY80!297-U;'1A=',`5&]R;F$@82!O<&-I
M;VYS`%)E=6YI\P!297-T875R87(@;&$@8V]N9FEG=7)A8VGS`$]P8VEO;G,@
M9&4@;"=E9&ET;W(@9&4@=&5X="!E;G)I<75I=`!%;FEG;65S`$1R971A`$-A
M<.=A;&5R82!D<F5T80!686QO<G,@9&4@;&$@9')E=&$`4')O<&EE=&%T<R!D
M92!L82!F:6QA+BXN`$9U;F-I\P!2;VUA;FEA`$=I<F%R(#$X,`!':7)A<B!A
M(&PG97-Q=65R<F$`1VER87(@82!L82!D<F5T80!0<F]P:65T871S(&1E(&QA
M(&9I;&$`4')O<&EE=&%T<R!D92!L82!F:6QA`$9I;&5S.@!296=L97,`07!A
M<F5I>&5R86X@<F5G;&5S(&5N=')E('1O=&5S(&QE<R!F:6QE<R!I(&-O;'5M
M;F5S`$%P87)E:7AE<F%N(')E9VQE<R!N;VWI<R!E;G1R92!C;VQU;6YE<P!!
M<&%R96EX97)A;B!R96=L97,@;F]MZ7,@96YT<F4@9FEL97,`17AE8W5T87(`
M1F5D97)A8VGS(%)U<W-A`%)W86YD80!3:6=N871U<F$@8W)I<'1O9W+@9FEC
M82!A;6(@4R]-24U%`$UI<W-A=&=E('AI9G)A="!A;6(@4R]-24U%`$PG875T
M96YT:6-A8VGS(%-!4TP@;F\@97-TX"!D:7-P;VYI8FQE+@!-:7-S871G97)I
M82!335,`26YTZ')P<F5T(&0G;W)D<F5S(%-13`!34T@`R%A)5`!);G3H<G!R
M970@9"=O<F1R97,@4U%,`$1S+@!386EN="!(96QE;F$`4V%I;G0@0VAR:7-T
M;W!H97(@:2!.979I<P!386EN="!,=6-I80!386EN="U0:65R<F4M970M36EQ
M=65L;VX`4V%I;G0@5FEN8V5N="!I(&QE<R!'<F5N861I;F5S`$UA=&5I>"!M
M87)C("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]MZ2!I(%!R[6YC
M:7!E`%!R;W9E[V1O<B!D92!S873H;+=L:70`07+@8FEA(%-A=61I=&$`1&5S
M80!$97-A("5S`$1E<V$@;&5S(&]P8VEO;G,`1&5S974@;&$@8V]N9FEG=7)A
M8VGS(&=E;F5R861A(&-O;2!U;F$@<V5Q_.AN8VEA(%!(4"!E;B!E;"!D:7)E
M8W1O<FD@=&5M<&]R86P@9&5L('-E<G9I9&]R+@!3)VAA(&1E<V%T(&QA(&-O
M;F9I9W5R86-I\R!D92`E<RX`5&5M<&5S=&5S(&1I<W!E<G-E<P!#:>AN8VEA
M`$-E<F-A`$UO=&]R<R!D92!C97)C80!396QE8V-I;VYA<B!E;',@87)X:75S
M`%-E;&5C8VEO;F%R('5N82!D871A`%-E;&5C8VEO;F%R('5N(&=R=7`@<75E
M('9U;&=U974@869E9VER`%-E;&5C8VEO;F5U('5N(&YO=2!P<F]P:65T87)I
M`%-E;&5C8VEO;F5U('5N('-E<G9I9&]R`%-E;&5C8VEO;F5U('5N('5S=6%R
M:2!Q=64@=G5L9W5E=2!A9F5G:7(`4V5L96-C:6]N974@=&]T<R!E;',@96QE
M;65N=',@9&4@;&$@9&%T82X`4V5L96-C:6]N974@=6X@;V)J96-T90!396QE
M8V-I;VYE=2!E;',@8V%RX&-T97)S('%U92!N96-E<W-I=&5U(&1E(&QE<R!C
M87-E;&QE<R!D92!S;W1A+B!0;V1E=2!C;W!I87(M;&]S(&D@96YG86YX87(M
M;&]S(&1E(&PGX')E82!D92!T97AT+@!396QE8V-I;VYA<B!E;"!D96QI;6ET
M861O<B!D92!L82!D871A.@!396QE8V-I;VYA<B!E;"!F;W)M870@9&4@;&$@
M9&%T83H`4V5L96-C:6]N87(@;&$@:61E;G1I=&%T('%U92!V;VQE=2!Q=64@
M8V%N=FEA<CH`4V5L96-C:6]N87(@96P@9&5L:6UI=&%D;W(@9&4@;"=H;W)A
M.@!396QE8V-I;VYA<B!E;"!F;W)M870@9&4@;"=H;W)A.@!396QE8V-I;VYA
M<B!D;W,@8V%M<',@<75E(&-O:6YC:61E:7AI;BX`4V5L96-C:6]N87(@;&$@
M8V]M8FEN86-I\R!D92!C;VQO<G,N`%-E;&5C8VEO;F%R(&PG:61I;VUA('!R
M969E<FET.@!%;G9I87(@;"=I;F9O<FUE(&1E;',@<')O8FQE;65S`$5N=FEA
M<B!335,`4V5N96=A;`!396YS;W(Z(`!3971E;6)R90!3Z')B:6$@:2!-;VYT
M96YE9W)O`$[Z;65R;R!D92!SZ')I90!,97,@9&%D97,@9&5L('-E<G9I9&]R
M('/S;B!I;F-O<G)E8W1E<R!O(&YO(&5S=&%N(&1I<W!O;FEB;&5S+@!(82!C
M861U8V%T(&PG:61E;G1I9FEC861O<B!D92!S97-S:?,N`$1E9FEN96EX`$1E
M9FEN96EX(&QE<R!O<&-I;VYS('%U92!U<R!P97)M971E;B!R96EN:6-I87(@
M;&$@8V]N=')A<V5N>6$@<VD@;6%I(&PG;V)L:61E=2X`1&5F:6YI=2!E;',@
M<V5R=FED;W)S(')E;6]T<R!A('%UZ"!V;VQE=2!A8V-E9&ER(&1E<R!D96P@
M<&]R=&%L+@!$969I;FEU(&5L('9O<W1R92!I9&EO;6$@<')E9F5R:70L(&QA
M('IO;F$@:&]RX')I82!I(&QE<R!O<&-I;VYS(&1E(&1A=&$N`$1E9FEN:74@
M;"=A<&QI8V%C:?,@9"=I;FEC:2P@;&$@8V]M8FEN86-I\R!D92!C;VQO<G,L
M(&5L(')E9G)E<V-A;65N="!D92!L97,@<.!G:6YE<R!I(&%L=')E<R!O<&-I
M;VYS(&1E('9I<W5A;&ET>F%C:?,N`$-O;F9I9W5R86-I\P!(:2!H82!S97'\
MZ&YC:65S(&0G86-T=6%L:71Z86-I\R!D92!L82!C;VYF:6=U<F%C:?,`2&D@
M:&$@9&EV97)S97,@=6)I8V%C:6]N<R!P;W-S:6)L97,@86UB(&5L('!A<N!M
M971R93H@`%-E>6-H96QL97,`0V]M<')E<P!297-U;2!B<F5U`%9O;&5U(&1E
M9FEN:7(@;&5S(&-L875S(&0G86-CZ7,@<&5R(&$@;&$@;6%J;W(@<&%R="!D
M)V5N;&QAYV]S/P!-;W-T<F$`36]S=')A(&QE<R!D:69E<NAN8VEE<R!E;G1R
M92!L82!C;VYF:6=U<F%C:?,@9&5S861A(&D@;&$@;F]V82X`5F]L974@=FES
M=6%L:71Z87(@;"=H;W)A(&1E(&QA(&1A<G)E<F$@<V5S<VGS(&5N(&EN:6-I
M87(_`$UO<W1R82!L)V]P8VGS(&1E(&-O;G-E<G9A<B!L)V]R:6=I;F%L`$UO
M<W1R82!E;"!C87!T=7)A9&]R`%9O;&5U('9I<W5A;&ET>F%R(&QA(&)A<G)A
M(&1E(&UE;OH@9"=O<&5R86-I;VYS(&1E('1A=6QA/P!6;VQE=2!V:7-U86QI
M='IA<B!E;"!M96[Z("5S(&1E(&PG97-Q=65R<F$_`$UO<W1R82!E;"!D:>!L
M96<@9&4@<')O<&EE=&%T<R!D92!C96RW;&$@9&4@=&%U;&$`36]S=')A(&5L
M(&1IX&QE9R!D92!P<F]P:65T871S(&1E('1A=6QA`$UO<W1R82!E;"!D:>!L
M96<@9&4@<')O<&EE=&%T<R!D92!F:6QA(&1E('1A=6QA`$UO<W1R82!E;"!D
M:>!L96<@9&4@<')O<&EE=&%T<R!D92!I;6%T9V4`36]S=')A(&QA(&/@<G)E
M9V$`4G5I>&%T<P!2=6EX871S(&$@<')I;65R82!H;W)A`%)U:7AA=',@8V%P
M(&%L('1A<F0`4G5I>&%T<R!A(&QA(')O9&%L:6$`4F5D=>]U`%!R:6UE<B!R
M961U[W4@;R!A<&%R=&5U(&5L*',I(&)L;V,H<RD@9&5L(&-O<W1A=`!3:65R
M<F$@3&5O;F4`1&]N974M=F]S(&0G86QT80!3:6=N871U<F$`06QG;W)I<VUE
M(&1E('-I9VYA='5R80!3:6YG87!U<@!-:61A`$]M970@;6%N=&5N:6UE;G0`
M17-L;W;@<75I80!%<VQO=NAN:6$`3F5V861A`%C@9F5C(&1E(&YE=0!8X&9E
M8W,@9&4@;F5U`%C@9F5C<R!D92!N974@82!P<FEM97)A(&AO<F$`6.!F96-S
M(&1E(&YE=2!C87`@86P@=&%R9`!'<G5I>"!D92!N974Z(`!%<75I=F%L96YT
M(&1E(&QA(&YE=2!E;B!A:6=U83H@`$EL;&5S(%-A;&]M\P!3;VW@;&EA`$-A
M;N=O;G,@:2!P;V5M97,`4V5L96-C:?,@96X@96P@<V5N=&ET(&1E(&QA(&-L
M87-S:69I8V%C:?,`061R9>=A(&0G;W)I9V5N`%-U9"W@9G)I8V$`4W5D+65U
M<F]P974@*$E33RTX.#4Y+3,I`$=E\G)G:6$@9&5L(%-U9"!I(&QE<R!I;&QE
M<R!386YD=VEC:"!D96P@4W5D`$AE;6ES9F5R:2!S=60`17-P86D@96YT<F4@
M8V5LMVQE<R!A9&IA8V5N=',`17-P86D@96YT<F4@96P@8V]N=&EN9W5T(&D@
M96P@8V]N=&]R;B!D92!L82!C96RW;&$`17-P86EA9&]R`$5S<&%I870`17-P
M86EA="!I(&9A<F-I;65N=`!%<W!A;GEA`$-O<G)E=2!B<F]S<V$`17-C<FEP
M='5R82!D92!C87+@8W1E<G,@97-P96-I86QS`$1I=FED:7(@8V5LMVQA`$1I
M=FED:7(@8V]L=6UN80!$:79I9&ER(&9I;&$`17-P;W)T<P!3<FD@3&%N:V$`
M17-TX&YD87)D`%-T87(@5')E:P!!;GD@9"=I;FEC:0!%<W1A="!O('!R;W;M
M;F-I80!%<W1A=`!&;W)M870@9"=E;6UA9V%T>F5M871G90!!9')EYV$@<&%R
M=&EC=6QA<@!"87)R870`3&QI<W1A(&1E(&-A9&5N97,`16QI;6EN974@96P@
M9&]M:6YI(&1E(&PG861R9>=A`$5S=&EL(%M#4U-=`$1G+@!!<W-U;7!T90!%
M;G9I80!3=6+M;F1E>`#(>&ET`%,G:&$@<F5S=&%U<F%T(&-O<G)E8W1A;65N
M="!L82!C;VYF:6=U<F%C:?,N($%C='5A;&ET>F5U('!E<B!V975R92!E;',@
M8V%N=FES+@!3)VAA(&1E<V%T(&-O<G)E8W1A;65N="!L82!C;VYF:6=U<F%C
M:?,@9&4@8_)P:6$N`%,G:&$@9&5S870@8V]R<F5C=&%M96YT(&PG87)X:74@
M9&4@;&$@8V]N9FEG=7)A8VGS(&1E(&/R<&EA("5S+@!3)VAA(&5S8W)I="!C
M;W)R96-T86UE;G0@)R5S)P!3=61A;@!297-U;0!3;W)T:61A(&1E;"!S;VP`
M4&]S=&$@9&5L('-O;`!!<W-O;&5L;&%T`%-O<G1I9&$@9&5L('-O;`!3;W)T
M:61A(&1E;"!S;VPO4&]S=&$@9&5L('-O;`!3;W)T:61A(&1E;"!S;VPZ(`!0
M;W-T82!D96P@<V]L`%!O<W1A(&1E;"!S;VPZ`%-U<&5R[6YD97@`07-S:7-T
MZ&YC:6$`4W5R:6YA;0!#;V=N;VT`4W9A;&)A<F0@:2!*86X@36%Y96X`4W=A
M>FELX&YD:6$`4W7H8VEA`%-U[W-S80!%<G)O<B!D92!S:6YT87AI(&5N(&5L
M<R!T97)M97,@9&4@8V5R8V$`4F5P^F)L:6-A(,!R86(@4VER:6%N80!496UP
M97-T80!496UP97-T82!I('9E;G3S<P!496UP97-T97,`07)X:74@5%-6`%!R
M;W!I971A=',@9&4@=&%U;&$`4')O<&EE=&%T<R!D92!T875L80!486EW86X`
M5&%I=V%N+"!P<F]V[6YC:6$@9&4@;&$@6&EN80!4861J:6MI<W1A;@!486YZ
MX&YI82P@4F5P^F)L:6-A(%5N:61A(&1E`$]B:F5C=&EU.@!487-Q=65S`$[Z
M;65R;R!D92!T96SH9F]N`%1E;7!E<F%T=7)A(&1U<F%N="!L82!D87)R97)A
M(&AO<F$Z(`!496UP97)A='5R80!496UP97)A='5R83H@`$%D;6EN:7-T<F%C
M:?,@9&4@<&QA;G1I;&QE<P!497AT`$YO;>ES('1E>'0`06QI;F5A8VGS(&1E
M('1E>'0`06QI;F5A="!A(&1A;'0`1&HN`%1A:6QA;F3H<R`H5$E3+38R,"D`
M5&%I;.!N9&EA`$PG97AT96YS:?,@1E10(&YO(&5S=.`@9&ES<&]N:6)L92X`
M16P@;6]T;W(@9"=I;G1E9W)A8VGS($AO<F1E+TMO;&%B(&YO('!E<FUE="!L
M)_IS(&1E("(E<R(`3&$@8VQA<W-E($UA:6YT96YA;F-E.CH@;F\@<R=H82!C
M87)R96=A="!C;W)R96-T86UE;G0C(P!3)VAA('1A;F-A="!L82!F:6YE<W1R
M82!D)V]P8VEO;G,N(%-O<G1I;G0@9&5L('-I<W1E;6$`4VD@=F]L974@=71I
M;&ET>F%R(&5L<R!P97)M:7-O<RP@;"=A9&UI;FES=')A9&]R(&AA(&1E(&-O
M;F9I9W5R87(@=6X@;6]T;W(@9&4@<&5R;6ES;W,@<&5R;6%N96YT+@!.;VWI
M<R!E;"!C;VYT;W)N(&EN9F5R:6]R`$5L(&[Z;65R;R!I9&5N=&EF:6-A9&]R
M(&1E;"!C;VYT86-T92!N;R!S)VAA(&5S<&5C:69I8V%T+"!S)VAA(&1E:7AA
M="!E;B!B;&%N8R!O(&YO(',G:&$@=')O8F%T(&$@;&$@8F%S92!D92!D861E
M<RX`4R=H82!A9F5G:70@8V]R<F5C=&%M96YT(&5L(&-O;G1A8W1E(&$@;&$@
M;&QI8G)E=&$@9"=A9')E8V5S+@!%<R!N96-E<W-I=&$@96P@8FQO8R!D92!S
M:6=N871U<F5S(%!'4"!S97!A<F%T('!E<B!V97)I9FEC87(@96P@;6ES<V%T
M9V4@<VEG;F%T+@!,)VED96YT:69I8V%D;W(@9&4@;&$@;&QI<W1A(&1E(&1I
M<W1R:6)U8VGS(&YO(',G:&$@97-P96-I9FEC870L(',G:&$@9&5I>&%T(&5N
M(&)L86YC(&\@;F\@<R=H82!T<F]B870@82!L82!B87-E(&1E(&1A9&5S+@!.
M;R!S)VAA(&5S<&5C:69I8V%T(&QA(&QL:7-T82!D92!D:7-T<FEB=6-I\RX`
M3&5S(&-A<F%C=&5R[7-T:7%U97,@9&5L('AI9G)A=&=E(&5X:6=E:7AE;B!U
M;F$@8V]N;F5X:?,@=V5B(&9I86)L92X`3"=A<GAI=2`E<R!H875R:6$@9&4@
M8V]N=&5N:7(@=6X@<&%RX&UE=')E("5S+@!,)V%R>&EU("5S(&AA=7)I82!D
M92!C;VYT96YI<B!A;&=U;G,@<&%RX&UE=')E<R`E<RX`3"=A<GAI=2!N;R!C
M;VYT96YI82!D861E<RX`02!C;VYT:6YU86-I\R!E<R!P<F5S96YT96X@;&5S
M(&-A<.=A;&5R97,@9"=A<75E<W0@;6ES<V%T9V4O;6ES<V%T9V4@<F9C.#(R
M+@!3)VAA(&-O;G-T871A="!Q=64@96P@;6]D92!D92!P86YT86QL82!C;VUP
M;&5T82!D\VYA('!R;V)L96UE<R!A;6(@26YT97)N970@17AP;&]R97(@82!C
M875S82!D)V5R<F]R<R!E;B!E;"!N879E9V%D;W(@<75E(&YO(&AE;2!P;V=U
M="!R97-O;&1R92X@4&]T('-E<B!Q=64@=FES=6%L:71Z974@8G)O<W-A+"!U
M<R!M86YQ=6EN(&9U;F-I;VYS(&5N(&PG961I=&]R(&DO;R!Q=64@96P@;F%V
M96=A9&]R('5S(&9A;&QI(&1E(&UA;F5R82!A;&5A=/)R:6$N(%-I('1E;FEU
M(&5L('-I<W1E;6$@5VEN9&]W<R`Y>"#I<R!M;VQT('!R;V)A8FQE('%U92!E
M<R!P<F]D=65I>&D@=6X@)V5R<F]R(&1E('!R;W1E8V-I\R!G96YE<F%L)R!I
M(&AA9W5E=2!D92!R96EN:6-I87(@9&4@;F]U+B!3:2P@=&]T(&D@87%U97-T
M(&%D=F5R=&EM96YT+"!E;F-A<F$@=F]L974@<')O=F%R(&PG961I=&]R(&1E
M('!A;G1A;&QA(&-O;7!L971A+"!P<F5M974@1"=A8V]R9"X`4R=H82!S=7!R
M:6UI="!L82!I9&5N=&ET870@(B5S(BX`3F]MZ7,@96P@8V]S=&%T(&5S<75E
M<G)E`$QA('5B:6-A8VGS(&1E;"!B:6YA<FD@1VYU4$<@<R=H82!D)VEN9&EC
M87(@82!L82!C;&%S<V4@0W)Y<'1?<&=P+@!3)VAA(&UO<W1R870@96P@;6ES
M<V%T9V4@96YV:6%T(&5L("5S(&$@)7,@86UB(&PG87-S=6UP=&4@(B5S(BX@
M06EX\B!N;R!G87)A;G1E:7@@<75E(',G:&%G:2!L;&5G:70@;R!E;G3H<R!E
M;"!M:7-S871G92X`16P@;F]M('%U92!S)VAA(&0G=71I;&ET>F%R(&5N(&5N
M;&QAYV%R(&%M8B!#<F5A<B!PX&=I;F$`17,@;F5C97-S:71A(&5L(&WR9'5L
M(&]P96YS<VP@<&5R(&$@;&$@8VQA<W-E($AO<F1E7T-R>7!T7W-M:6UE+@!.
M;R!S)VAA('!O9W5T(&1E<V%R(&QA('!R969E<NAN8VEA("(E<R(@<&5R<77H
M(&QA(&EN9F]R;6%C:?,@<75E(&-O;G1E;FEA('-U<&5R879A(&QA(&UI9&$@
M;>!X:6UA('!E<FUE<V$N`$YO(',G:&$@=')O8F%T(&5N(&5L('-I<W1E;6$@
M96P@<')O9W)A;6$@=7-A="!P97(@=FES=6%L:71Z87(@87%U97-T('1I<'5S
M(&1E(&1A9&5S("@E<RDN`$YO;>ES(&5L<R!C;W-T871S(&1R970@:2!E<W%U
M97)R90!.;VWI<R!E;"!C;W-T870@9')E=`!3)VAA('-U<')I;6ET(&5L('-E
M<G9I9&]R("(E<R(N`%,G:&$@9&5S870@96P@<V5R=FED;W(@(B5S(BX`4R=H
M82!E;&EM:6YA="!L82!S;VRW;&EC:71U9"!D)V%L=&$@9&4@)7,N`$YO(&5X
M:7-T96EX(&PG87)X:74@=&5M<&]R86P@(B5S(BX`3F]MZ7,@96QS(&-O<W1A
M=',@<W5P97)I;W(@:2!I;F9E<FEO<@!.;VWI<R!E;"!C;W-T870@<W5P97)I
M;W(`4R=H86X@<&5R9'5T(&QE<R!D861E<R!C87)R96=A9&5S(&1E<R!D96P@
M<&%S(&%N=&5R:6]R+@!.;R!S)VAA('!O9W5T(&1E<V%R(&PG87)X:74@8V%R
M<F5G870N`$5L(&)L;V,@=V5A=&AE<BYC;VT@;F\@97-TX"!D:7-P;VYI8FQE
M+@!.;R!H:2!H82!C87`@;W!C:?,@9&ES<&]N:6)L92X`3F\@:&D@:&$@8V%P
M('!A<G0@<75E(&5S('!U9W5I(&UO<W1R87(@96X@;.UN:6$`07%U97-T(&-A
M;7`@8V]N=.D@;6%S<V$@8V%RX&-T97)S+B!(974@:6YT<F]D=>]T("5S(&-A
M<N!C=&5R<R!I(&XG:&5U(&0G:6YT<F]D=6ER(&UE;GES(&1E("5S+@!(:2!H
M82!H86=U="!U;B!P<F]B;&5M82!E;B!C87)R96=A<B!L)V%R>&EU.B!N;R!S
M)VAA(&-A<G)E9V%T("5S+@!(:2!H82!H86=U="!U;B!P<F]B;&5M82!E;B!C
M87)R96=A<B!L)V%R>&EU.B!E;"`E<R!E<F$@<W5P97)I;W(@82!L82!M:61A
M(&W@>&EM82!P97)M97-A("@E(&)Y=&5S*2X`2&D@:&$@:&%G=70@=6X@<')O
M8FQE;6$@96X@8V%R<F5G87(@;"=A<GAI=3H@;F]MZ7,@<R=H82!C87)R96=A
M="!P87)C:6%L;65N="!E;"`E<RX`4R=H82!P<F]D=>]T('5N(&5R<F]R(&5N
M(&UO<W1R87(@87%U97-T82!P87)T(&1E;"!M:7-S871G90!3)VAA('!R;V1U
M[W0@=6X@97)R;W(@96X@:6UP;W)T87(@;&5S(&1A9&5S(&1E(&-O;G1A8W1E
M+@!3)VAA('!R;V1U[W0@=6X@97)R;W(@96X@:6UP;W)T87(@;&5S(&1A9&5S
M(&E#86QE;F1A<BX`4R=H82!P<F]D=>]T('5N(&5R<F]R(&5N(&5L(&9O<FUU
M;&%R:2!D92!C;VYF:6=U<F%C:?,N(%!O='-E<B!U<R!H974@9&5S8W5I9&%T
M(&0G96UP;&5N87(@=6X@8V%M<"!N96-E<W-A<FDN`%,G:&$@<')O9'7O="!U
M;B!E<G)O<B!E;B!E>&5C=71A<B!L82!F=6YC:?,@97-P96-I9FEC861A(&1E
M(&QA(&QL:6)R971A(&0G861R96-E<RX@5&]R;F5U+6AO(&$@:6YT96YT87(@
M;>ES('1A<F0N`%,G:&$@<')O9'7O="!U;B!E<G)O<B!E;B!A8W1U86QI='IA
M<B!E;',@9&5T86QL<R!D92!C;VYT86-T92X@5&]R;F5U+6AO(&$@:6YT96YT
M87(@;>ES('1A<F0N`%,G:&$@<')O9'7O="!U;B!E<G)O<B!E;B!A8W1U86QI
M='IA<B!L82!L;&ES=&$@9&4@9&ES=')I8G5C:?,N(%1O<FYE=2UH;R!A(&EN
M=&5N=&%R(&WI<R!T87)D+@!!<75E<W0@<V5R=FED;W(@24U!4"!N;R!P97)M
M970@;"?Z<R!D92!C87)P971E<R!C;VUP87)T:61E<RX`3F\@<V5M8FQA('%U
M92!S:6=U:2!U;B!A<GAI=2!R87(@=N!L:60N`$YO('-E;6)L82!Q=64@<VEG
M=6D@=6X@87)X:74@>FEP(';@;&ED+@!.;R!S96UB;&$@<75E(&%Q=65S="!N
M^FUE<F\@9&4@=&%R9V5T82!S:6=U:2!VX&QI9"X`07%U97-T(&-O;G1R;VQA
M9&]R('!E<FUE="!E;G9I87(@;6ES<V%T9V5S('!E<B!M:71JX"!D92!L82!P
M87-S87)E;+=L82!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI
M+"!U=&EL:71Z86YT(&QA($%022!(5%10`$%Q=65S="!C;VYT<F]L861O<B!P
M97)M970@96YV:6%R(&UI<W-A=&=E<R!P97(@;6ET:N`@9&4@;&$@<&%S<V%R
M96RW;&$@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@=71I;&ET
M>F%N="!L82!!4$D@2%144`!!<75E<W0@8V]N=')O;&%D;W(@<&5R;65T(&5N
M=FEA<B!M:7-S871G97,@<&5R('9I82!D92!33510(&$@=')A=NES(&1E(&QA
M('!A<W-A<F5LMVQA(%9O9&%F;VYE(&0G273@;&EA+"!N;VWI<R!A(&[Z;65R
M;W,@5F]D869O;F4N($-A;"!T96YI<B!U;B!C;VUP=&4@9&4@8V]R<F5U(&5L
M96-T<O)N:6,@86UB(%9O9&%F;VYE(&0G273@;&EA("AH='1P.B\O=W=W+C$Y
M,"YI="DN`,ES(&YE8V5S<V%R:2!A<75E<W0@8V%M<"X`07%U97-T(&-A;7`@
M;F]MZ7,@<&]T(&-O;G1E;FER(&YO;6)R97,@96YT97)S+@!!<75E<W0@8V%M
M<"!N;VWI<R!P;W0@8V]N=&5N:7(@;F]M8G)E<R!I(&5L<R!D;W,@<'5N=',N
M`$%Q=65S="!C86UP(&YO;>ES('!O="!C;VYT96YI<B!V86QO<G,@;V-T86QS
M+@!!<75E<W0@8V%M<"!H82!D92!S97(@=6YA(&QL:7-T82!D92!N;VUB<F5S
M(&5N=&5R<R!S97!A<F%T<R!P97(@8V]M97,@;R!E<W!A:7,N`$%Q=65S="!C
M86UP(&AA(&1E('-E<B!U;B!N^FUE<F\@=N!L:60N`$%Q=65S="!C86UP(&AA
M(&1E(&-O;G1E;FER('5N(&-O9&D@9&4@8V]L;W(@9&4@9F]R;6%T(%)'0B!H
M97AA9&5C:6UA;"P@<&5R(&5X96UP;&4@)R,Q,C,T868G+@!*82!S)VAA('!R
M;V-E<W-A="!A<75E<W0@9F]R;75L87)I+@!!:7CR(.ES("5S+@!!:7CR(.ES
M('5N(&]B:F5C=&4@9&4@2V]L86(@1W)O=7!W87)E+B!097(@=FES=6%L:71Z
M87(@87%U97-T(&]B:F5C=&4L('5S(&-A;"!U;B!C;&EE;G0@9&4@8V]R<F5U
M(&5L96-T<O)N:6,@<75E(&%D;65T:2!E;"!F;W)M870@9&4@2V]L86(@1W)O
M=7!W87)E+B!097(@=&5N:7(@86-CZ7,@82!U;F$@;&QI<W1A(&0G87%U97-T
M<R!C;&EE;G1S(&1E(&-O<G)E=2!E;&5C='+R;FEC+"!V:7-I=&5U("5S`$%Q
M=65S="!M:7-S871G92!V82!S97(@97-C<FET(&%M8B!U;B!J;V,@9&4@8V%R
MX&-T97)S("@E<RD@9&EF97)E;G0@9&5L('9O<W1R92X`07%U97-T(&[Z;65R
M;R!H82!D92!S97(@8V]M(&$@;>UN:6T@=6X@,2X`07%U97-T('-E<G9I9&]R
M(&YO('!O="!D97-C;VUP<FEM:7(@87)X:75S('II<"!I(&=Z:7`N`$%Q=65S
M="!S:7-T96UA(&5S=.`@9&5S86-T:79A="!A8W1U86QM96YT+@!!<75E<W0@
M=F%L;W(@:&$@9&4@<V5R('5N(&[Z;65R;RX`07%U97-T82!F:6YE<W1R82!S
M)VAA(&1E(&-R:61A<B!D97,@9"=U;F$@9FEN97-T<F$@9"=O<&-I;VYS`%1R
M;P!4:7%U971S`$AO<F$`0V]N=')O;"!D92!T96UP<P!&;W)M870@:&]R87)I
M`%-E;&5C8VGS(&1E('1E;7!S`%1I;6]R($]R:65N=&%L`%3M=&]L`%3M=&]L
M("ARZ'1O;"!I;F1I8V%D;W(@9&4@9G5N8VGS*3H`00!097(@<V5L96-C:6]N
M87(@9&EV97)S;W,@96QE;65N=',L(&UA;G1I;F=U974@<&ET:F%D82!L82!T
M96-L82!#;VYT<F]L("A00RD@;R!#;VUM86YD("A-86,I(&UE;G1R92!C;&EQ
M=65U+@!!=G5I`$-O;6UU=&5U(&QA(&9O;G0@2%1-3`!4;V=O`%1O:V5L874`
M1&5MX`!4;VYG80!3=7!E<FEO<@!-87)C('-U<&5R:6]R("A?<W5P97)I;W(I
M`%1R861U8V-I;VYS`%1R:6YI=&%T(&D@5&]B86=O`%9E<FET870@;R!F86QS
M`$1T+@!4=6[M<VEA`%1U<G%U:6$`5'5R8R`H25-/+3@X-3DM.2D`5'5R:VUE
M;FES=&%N`$EL;&5S(%1U<FMS(&D@0V%I8V]S`%1U=F%L=0!496-L96=E=2!L
M82!V;W-T<F$@;W!C:?,Z(`#-;F1E>"!55CH@`%523`!54DP@9&5L('9O<W1R
M92!I;F9O<FUE(&1E(&PG97-T870@9&4@=')A;65S82!D92!L82!S97'\Z&YC
M:6$`55),.@!59V%N9&$`56-R8>]N80!.;R!S)VAA('!O9W5T(&%C8V5D:7(@
M86P@9&ER96-T;W)I(%9&4RX`3F\@<R=H82!P;V=U="!A9F5G:7(@;>ES(&1A
M9&5S(&1E(&PG=7-U87)I(&5N(&5F96-T=6%R(&PG86QT82X`3F\@<R=H82!P
M;V=U="!C86YV:6%R(&5L('!E<FWM<R!D92!L)V%R>&EU(%9&4R`B)7,B+@!.
M;R!S)VAA('!O9W5T(&-A;G9I87(@96P@<&5R;>US(&1E(&PG87)X:74@5D93
M("5S+R5S+@!.;R!S)VAA('!O9W5T(&-A;G9I87(@82`E<RX`3F\@<R=H82!P
M;V=U="!C;VYN96-T87(@86P@<V5R=FED;W(@4U%,+@!.;R!S)VAA('!O9W5T
M(&-O;FYE8W1A<B!A;6(@4U-,+@!.;R!S)VAA('!O9W5T(&-O<&EA<B!L)V%R
M>&EU(%9&4RX`3F\@<R=H82!P;V=U="!C<F5A<B!E;"!D:7)E8W1O<FD@5D93
M("(E<R(N`$YO(',G:&$@<&]G=70@8W)E87(@96P@9&ER96-T;W)I(%9&4RX`
M3F\@<R=H82!P;V=U="!C<F5A<B!L)V%R>&EU(%9&4RX`3F\@<R=H82!P;V=U
M="!C<F5A<B!L82!C87)P971A(%9&4R`B)7,B+@!.;R!S)VAA('!O9W5T(&-R
M96%R('5N(&%R>&EU(%9&4R!B=6ET+@!.;R!S)VAA('!O9W5T(&1E<V-O;7!R
M:6UI<B!L97,@9&%D97,N`$YO(',G:&$@<&]G=70@<W5P<FEM:7(@(B5S(BP@
M96P@9&ER96-T;W)I(&YO(&5S=.`@8G5I="X`3F\@<R=H82!P;V=U="!S=7!R
M:6UI<B`E<RP@96P@9&ER96-T;W)I(&YO(&5S=.`@8G5I="X`3F\@<R=H82!P
M;V=U="!S=7!R:6UI<B!E;"!D:7)E8W1O<FD@5D93(&1E(&UA;F5R82!R96-U
M<G-I=F$N`$YO(',G:&$@<&]G=70@<W5P<FEM:7(@96P@9&ER96-T;W)I(%9&
M4RX`3F\@<R=H82!P;V=U="!S=7!R:6UI<B!E;"!D:7)E8W1O<FD@5D93.B`E
M<RX`3F\@<R=H82!P;V=U="!S=7!R:6UI<B!L)V%R>&EU(%9&4R`B)7,B+@!.
M;R!S)VAA('!O9W5T('-U<')I;6ER(&PG87)X:74@5D93+@!.;R!S)VAA('!O
M9W5T('-U<')I;6ER(&QA(&-A<G!E=&$@5D93("(E<R(N`$YO(',G:&$@<&]G
M=70@<W5P<FEM:7(@5D93(&1E(&UA;F5R82!R96-U<G-I=F$Z("5S+@!.;R!S
M)VAA('!O9W5T(&1E=&5R;6EN87(@96P@9&ER96-T;W)I(&%C='5A;"X`3F\@
M<R=H82!P;V=U="!E>'1R975R92!E;',@9&5T86QL<R!D96P@8V5R=&EF:6-A
M="X`3F\@<R=H82!P;V=U="!C87)R96=A<B!L82!D969I;FEC:?,@9&4@)7,N
M`$YO(',G:&$@<&]G=70@;6]U<F4@;"=A<GAI=2!61E,N`$YO(',G:&$@<&]G
M=70@;V)R:7(@;"=A<GAI=2!61E,@(B5S(BX`3F\@<R=H82!P;V=U="!O8G)I
M<B!L)V%R>&EU(%9&4R!P97(@97-C<FEU<F4M:&DN`$YO(',G:&$@<&]G=70@
M;V)R:7(@;"=A<GAI=2!61E,N`$YO(',G:&$@<&]G=70@;V)R:7(@;"=A<GAI
M=2!C;VUP<FEM:70N`$YO(',G:&$@<&]G=70@;&QE9VER(&PG87)X:74@5D93
M("AL82!M:61A(&1E(&PG87)X:74H*2!H82!D;VYA="!E<G)O<BDN`$YO(',G
M:&$@<&]G=70@;&QE9VER(&PG87)X:74@5D93("AG971&:6QE4VEZ92@I(&AA
M(&1O;F%T(&5R<F]R*2X`3F\@<R=H82!P;V=U="!L;&5G:7(@;"=A<GAI=3H@
M+@!.;R!S)VAA('!O9W5T(&QL96=I<B!E;"!D:7)E8W1O<FD@87)R96P@9&4@
M5D93+@!.;R!S)VAA('!O9W5T(&-A;G9I87(@96P@;F]M(&1E("5S('!E<B`E
M<SH@;&$@8V%R<&5T82!D92!D97-T:6YA8VGS(&IA(&5X:7-T96EX`$YO(',G
M:&$@<&]G=70@8V%N=FEA<B!E;"!N;VT@9&5L(&1I<F5C=&]R:2!61E,N`$YO
M(',G:&$@<&]G=70@8V%N=FEA<B!E;"!N;VT@9&5L(&1I<F5C=&]R:2!61E,Z
M("5S+@!.;R!S)VAA('!O9W5T(&-A;G9I87(@96P@;F]M(&1E(&PG87)X:74@
M5D93("(E<R(N`$YO(',G:&$@<&]G=70@8V%N=FEA<B!E;"!N;VT@9&4@;"=A
M<GAI=2!61E,@)7,O)7,N`$YO(',G:&$@<&]G=70@8V%N=FEA<B!E;"!N;VT@
M9&4@;"=A<GAI=2!61E,N`$YO(',G:&$@<&]G=70@97AE8W5T87(@)VUK:7-O
M9G,G+@!.;R!S)VAA('!O9W5T('1R861U:7(@87%U97-T(&1O8W5M96YT(&1E
M(%=O<F0`3F\@<R=H82!P;V=U="!E<V-R:75R92!L)V%R>&EU(%9&4R`B)7,B
M+@!.;R!S)VAA('!O9W5T(&5S8W)I=7)E(&PG87)X:74@5D93("@C<R=H82!P
M<F]D=>]T('5N(&5R<F]R(&5N(&-O<&EA<BUL;R@I(",I+@!.;R!S)VAA('!O
M9W5T(&5S8W)I=7)E(&QE<R!D861E<R!D92!L)V%R>&EU(%9&4RX`3F\@<R=H
M82!P;V=U="!E<V-R:75R92!L)V%R>&EU(%9&4RP@<V4@<W5P97)A<N`@;"=E
M<W!A:2!D:7-P;VYI8FQE+@!3=6)R871L;&%T`$1E<V;I<R!E;',@8V%N=FES
M`$1E<V;@(&QA(&1A<G)E<F$@86-C:?,`16P@<V5R=FED;W(@:&$@9&]N870@
M=6YA(')E<W!O<W1A(&EN97-P97)A9&$@96X@8V]N;F5C=&%R+7-E.B``16P@
M<V5R=FED;W(@:&$@9&]N870@=6YA(')E<W!O<W1A(&EN97-P97)A9&$@83H@
M`%-E;G-E(&-A=&5G;W)I80!5;FEC;V1E("A55$8M."D`56YI\R!D96QS($5M
M:7)A=',@P')A8G,`4F5G;F4@56YI=`!%<W1A=',@56YI=',`26QL97,@4&5R
M:6;H<FEQ=65S($UE;F]R<R!D96QS($5S=&%T<R!5;FET<P!5;FET871S`$1E
M<V-O;F5G=70`87!I;7-G:60@*&ED96YT:69I8V%D;W(@9&5L(&UI<W-A=&=E
M(&1E(&QA($%022D@9&5S8V]N96=U="X`0VQI;7-G:60@9&5S8V]N96=U="`H
M:61E;G1I9FEC861O<B!D96P@;6ES<V%T9V4@9&5L(&-L:65N="DN`%,G:&$@
M<')O<&]R8VEO;F%T('5N82!U8FEC86-I\R!D97-C;VYE9W5D82X`3F]M(&0G
M=7-U87)I(&\@8V]N=')A<V5N>6$@9&5S8V]N96=U=',N`$1E<V5N;&QAYV%R
M(&PG96QE;65N="!A8W1U86P`4V5N<V4@;F]M`$QE<R!S97'\Z&YC:65S('-E
M;G-E('!E<FUI<V]S(&YO('!O9&5N(&%C8V5D:7(@82!2971A;&QA<B]#;W!I
M87(O16YG86YX87(@9&4@;6%N97)A('!R;V=R86W@=&EC82!P97(@<F%O;G,@
M9&4@<V5G=7)E=&%T+B!#;&EQ=65U(&5N($0G86-O<F0@<&5R('9I<W5A;&ET
M>F%R('5N82!N;W1A('3H8VYI8V$@82!M;WII;&QA+F]R9R!Q=64@=7,@;6]S
M=')A(&-O;2!P;V1E=2!F97(@<75E('5N82!S97'\Z&YC:6$@86-C961E:7AI
M(&%L('!O<G1A+7)E=&%L;',N(`!%;&EM:6YA<B!E;"!C;VQO<@!%>'1E;G-I
M\R!N;R!I;7!L96UE;G1A9&$`06-T=6%L:71Z87(`06-T=6%L:71Z87(@)7,`
M06-T=6%L:71Z87(@;"=U<W5A<FD`4R=H82!S=7!R:6UI="!L82!S97'\Z&YC
M:6$@9"=A8W1U86QI='IA8VGS+@!#87)R96=A<@!3)VAA(&-A<G)E9V%T(&%L
M('-E<G9I9&]R('1O=',@96QS(&%R>&EU<R!D92!C;VYF:6=U<F%C:?,@9"=A
M<&QI8V%C:6]N<RX`06QF86)E="!L;&%T[2!E;B!M86KZ<V-U;&$`6&EF<F5S
M(')O;6%N97,@96X@;6%J^G-C=6QA`%5R=6=U86D`571I;&ET>F%R(&PG86-T
M=6%L.B`E<P!5=&EL:71Z87(@4U-,`%5T:6QI='IE=2!S:2!E;"!N;VT@;R!L
M82!C;VYT<F%S96YY82!S\VX@9&EF97)E;G1S(&%L('-E<G9I9&]R($E-4U`N
M`$PG=7-U87)I("5S(&YO(&5S=.`@875T;W)I='IA="!P97(@82`E<RX`061M
M:6YI<W1R86-I\R!D)W5S=6%R:7,`3W!C:6]N<R!D)W5S=6%R:0!296=I<W1R
M92!D)W5S=6%R:7,`16P@<F5G:7-T<F4@9"=U<W5A<FES(&0G87%U97-T(&QL
M;V,@97-TX"!I;FAA8FEL:71A="X`3F]M(&0G=7-U87)I`$YO;2!D)W5S=6%R
M:3H`3F]M(&0G=7-U87)I.B``57-U87)I<R!D96P@<VES=&5M83H`57IB96MI
M<W1A;@!%;"!D:7)E8W1O<FD@5D93(&YO(&5X:7-T96EX+@!!8G/H;F-I80!,
M97,@=6)I8V%C:6]N<R!VX&QI9&5S('%U92!S)VAA;B!T<F]B870@<_-N.@!6
M86QI9&5S80!686QO<B!E;B!M:6YU=',@82!P87)T:7(@9"=A<F$N`$5L('9A
M;&]R('-U<&5R82!L82!L;VYG:71U9"!MX'AI;6$@9&4@)7,N`%9A;&]R<P!6
M86QO<G,@<75E(',G:&%N('-E;&5C8VEO;F%R(&1E`%9A;G5A='4`5F%R:6%B
M;&4`5F5N9>=U96QA`$AA(&9A;&QA="!L82!V97)I9FEC86-I\SH@Z7,@<&]S
M<VEB;&4@<75E(',G:&%G:2!A;'1E<F%T(&5L(&UI<W-A=&=E+@!697)S:?,`
M0V]N=')O;"!D92!V97)S:6]N<P!!;&EN96%C:?,@=F5R=&EC86P`1F%R8VEM
M96YT('9E<G1I8V%L`%9E<G1I8V%L.@!-;VQT(&%L=`!6:65T;F%M`%9I971N
M86UI=&$@*%9)4T-)22D`5FES=6%L:71Z87(@)7,`5FES=6%L:71Z87(@=6YA
M('#@9VEN82!W96(@97AT97)N80!6:7-U86QI='IA<B!C;VT@82`E<P!);&QE
M<R!697)G97,@8G)I=.!N:7%U97,`26QL97,@5F5R9V5S(&YO<F0M86UE<FEC
M86YE<P!6:7-I8FEL:71A=`!6:7-I8FEL:71A=#H@`%9O9&%F;VYE(&0G273@
M;&EA('!E<B!V:6$@9&4@4TU44`!!1%9%4E3(3D-)00!!5LU3(2!%3$E-24Y!
M4B!,02!315'<R$Y#24$@34%.54%,345.5"!$12`E<RX`5V%L;&ES(&D@1G5T
M=6YA`$%V[7,`1&,N`%!R979I<VGS(&1E;"!T96UP<P!);F9O<FUA8VGS(&UE
M=&5O<F]L\F=I8V$@<')O<&]R8VEO;F%D82!P97(`5V5A=&AE<BYC;VT`5V5B
M`$QL;V,@=V5B`%-E=&UA;F%L;65N=`!"96YV:6YG=71S`$)E;G9I;F=U=',@
M82`E<P!"96YV:6YG=71S+"`E<P!/8V-I9&5N=&%L("A)4T\M.#@U.2TQ*0!/
M8V-I9&5N=&%L("A)4T\M.#@U.2TQ-2D`4^!H87)A($]C8VED96YT86P`475I
M;F$@87!L:6-A8VGS(&AA=7)I82!D92!M;W-T<F%R("5S(&5N(&EN:6-I87(@
M;&$@<V5S<VGS/P!1=6EN(.ES(&5L(&-A<N!C=&5R(&1E;&EM:71A9&]R/P!1
M=6EN(.ES(&5L(&-A<N!C=&5R(&1E(&-I=&%C:?,_`%%U:6YE<R!F87-E<P!0
M;'5G:6YS(&AA8FEL:71A=',@9&4@;"=E9&ET;W(@9&4@=&5X="!E;G)I<75I
M="X`06UP;&%D80!!;7!L861A(&1E(&QE<R!U;FET871S($-34P!!;7!L861A
M(&1E;"!M96[Z("5S(&1E(&PG97-Q=65R<F$@*&1I<W!O;FEB;&4@96X@;&$@
M<')O<&5R82!S97-S:?,I.@!!;7!L861A(&1E(&QA('1A=6QA`%5N:71A="!D
M)V%M<&QA9&$`06UP;&%D83H`5VEK:0!696YT`%9E;G0@82!P<FEM97)A(&AO
M<F$`5F5L;V-I=&%T(&1E;"!V96YT(&5N(&YU<V]S`%9E;G0Z`%9E;G0Z(`!3
M879I97-A`$9E:6YA`$%D<F7G82!D92!L82!F96EN80!496SH9F]N(&1E(&QA
M(&9E:6YA`%@M4F5F`$QI;6ET86-I;VYS(&+@<VEQ=65S(%@U,#EV,P#:<R!D
M92!L82!C;&%U(&5S=&5S82!X-3`Y=C,`3F]M(&%L=&5R;F%T:74@9"=A<W-U
M;7!T92!8-3`Y=C,`261E;G1I9FEC861O<B!D92!C;&%U(&0G87-S=6UP=&4@
M6#4P.78S`$5X=&5N<VEO;G,@6#4P.'8S`$%!`$%!04$`36%P82!D92!986AO
M;R$`06YU86QM96YT`$EE;65N`%/M`%/M+"!H;R!A8V-E<'1O`%-O=2!E;B!E
M;"!-3T1%(%1%6%0N(%5S974@96P@8F]T\R!;/#Y=('!E<B!T;W)N87(@82!7
M65-)5UE'+@!.;R!E<W1E=2!A=71E;G1I8V%T<RX`3F\@:&5U(&EN=')O9'7O
M="!U;F$@861R9>=A(&5L96-T<O)N:6-A(';@;&ED82X`3F\@:&5U(&%S<V]C
M:6%T(&-A<"!C86UP(&1E(&PG87)X:74@:6UP;W)T870@86UB(&5L<R!C86UP
M<R!C;W)R97-P;VYE;G1S(&1E("5S+@!(974@<V]R=&ET(&1E(&QA('-E<W-I
M\RX`2&5U(&0G:6YT<F]D=6ER('5N(&[Z;65R;R!D92!T96SH9F]N(&WR8FEL
M(';@;&ED+"!N;VWI<R!D[6=I=',@86UB('5N("<K)R!O<&-I;VYA;"!P97(@
M86P@<')E9FEX(&1E('1R=6-A9&$@:6YT97)N86-I;VYA;"X`2&5U(&0G:6YT
M<F]D=6ER('5N('9A;&]R(';@;&ED+@!(974@9&4@8V]N9FEG=7)A<B!U;B!M
M;W1O<B!D92!$871A5')E92!P97(@=71I;&ET>F%R($%L=&5S+@!(974@9&4@
M8V]N9FEG=7)A<B!U;B!M;W1O<B!D92!61E,N`$AE=2!D92!D97-C<FEU<F4@
M96P@<')O8FQE;6$@86)A;G,@9"=E;G9I87(M;F4@;"=I;F9O<FUE+@!(974@
M9"=I;G1R;V1U:7(@96P@55),('%U92!A<75E<W0@96YL;&'G(&EN9&EC82X`
M2&5U(&1E('-E;&5C8VEO;F%R('5N('-E<G9I9&]R('%U92!V=6QG=65U(&5L
M:6UI;F%R+@!(974@9"=E<W!E8VEF:6-A<B!U;B!N;VT@9"=U<W5A<FD@<75E
M('9U;&=U974@97-B;W)R87(N`$AE=2!D)V5S<&5C:69I8V%R('5N(&YO;2!D
M)W5S=6%R:2!Q=64@=G5L9W5E=2!S=7!R:6UI<BX`2&5U(&0G97-P96-I9FEC
M87(@<75I;B!N;VT@9"=U<W5A<FD@=F]L974@869E9VER+@!(974@9"=E<W!E
M8VEF:6-A<B!E;"!N;VT@9"=U<W5A<FD@<75E('9O;&5U(&%C='5A;&ET>F%R
M+@!(974@9"=E<W!E8VEF:6-A<B!Q=6EN82!A8V-I\R!V;VQE=2!E>&5C=71A
M<BX`2&5U(&1E('1E8VQE:F%R('5N(&YO=2!N;VT@9&4@8V%T96=O<FEA+@!,
M82!V;W-T<F$@<V5S<VGS(&5N("5S(&AA(&5X<&ER870N(%-I('5S('!L874L
M(&EN:6-I974@=6YA(&YO=F$@<V5S<VGS+@!,82!V;W-T<F$@861R9>=A(&5L
M96-T<O)N:6-A`$QA('1E=F$@861R9>=A(&1E(')E<W!O<W1A`$QA('9O<W1R
M82!I;F9O<FUA8VGS`$QA('9O<W1R82!A9')EYV$@9"=);G1E<FYE="!H82!C
M86YV:6%T(&1E<R!Q=64@:&5U(&-O;65NYV%T(&QA('-E<W-I\R`E<RX@4&5R
M(')A;VYS(&1E('-E9W5R971A="P@:&5U(&1E(')E:6YI8VEA<B!L82!S97-S
M:?,N`$5L('9O<W1R92!N;VT`16P@=F]S=')E(&UO=&]R(&0G875T96YT:6-A
M8VGS(&YO('!E<FUE="!Q=64@97,@;&QI<W1I;B!E;',@=7-U87)I<RP@;R!B
MZ2!P97(@86QG=6YA(')A\R!A<75E<W1A(&-A<F%C=&5R[7-T:6-A(&5S=.`@
M:6YH86)I;&ET861A+@!396UB;&$@<75E(&5L(&YA=F5G861O<B!H82!C86YV
M:6%T(&1E<R!Q=64@=F%U(&-O;65NYV%R(&QA('-E<W-I\R`E<RX@4&5R(')A
M;VYS(&1E('-E9W5R971A="P@:&5U(&1E('1O<FYA<B!A(&5N=')A<B!A;"!S
M:7-T96UA+@!%;"!V;W-T<F4@;F%V96=A9&]R(&YO(&%C8V5P=&$@87%U97-T
M82!C87)A8W1E<NUS=&EC82X`16P@=F]S=')E(&YA=F5G861O<B!N;R!P97)M
M970@87%U97-T82!O<&-I\R!D)VEM<')E<W-I\RX@4')E;6D@0V]N=')O;"`K
M(%`@<&5R(&EM<')I;6ER+@!:;VYA(&AO<N!R:6$@86-T=6%L.@!)9&5N=&ET
M870@<')E9&5T97)M:6YA9&$Z`$YO;2!C;VUP;&5T.@!,82!N;W9A(&-O;G1R
M87-E;GEA('!E<B!A("5S(.ES.B`E<P!,97,@;W!C:6]N<R!H86X@97-T870@
M86-T=6%L:71Z861E<R!P97(@82!L82!D=7)A9&$@9"=A<75E<W1A('-E<W-I
M\RX`3&5S(&]P8VEO;G,@:&%N(&5S=&%T(&%C='5A;&ET>F%D97,N`%,G:&$@
M<F5I;FEC:6%T(&QA('9O<W1R82!C;VYT<F%S96YY80!3)VAA(')E:6YI8VEA
M="!L82!V;W-T<F$@8V]N=')A<V5N>6$L(')E=FES82!E;"!C;W)R974@96QE
M8W1R\FYI8R!I(&EN:6-I82!L82!S97-S:?,@86UB(&QA(&YO=F$@8V]N=')A
M<V5N>6$N`%-E<G9I9&]R<R!R96UO=',Z`$EU9V]S;.!V:6$`6F%I<F4`6N!M
M8FEA`%II;6)A8G=E`%II<'!Y`%M/8W5L=&$@=&5X="!C:71A=%T`6TEN9F]R
M;64@9&5L('!R;V)L96UA70!;36]S=')A('1E>'0@8VET870@+0!;36]S=')A
M('1E>'0@8VET870@+2`E<R!L[6YI97-=`%ML[6YI82`E<R!D92`E<UT`7T%D
M;6YI<W1R86-I\P!?0TQ)`%]!<F)R92!D92!D861E<P!?4W5P<FEM:7(@9FEL
M80!?1W)U<',`7T%J=61A`%]0<F]P:65T871S(&1E(&QA(&EM871G92XN+@!?
M26YI8VEA(&QA('-E<W-I\P!?4W5R=`!?36]D:69I8V$@;"=E;FQL8><N+BX`
M7T]P8VEO;G,`7U!E<FUI<V]S`%]%;&EM:6YA(&PG96YL;&'G+BXN`%]#;VYF
M:6=U<F%C:?,`7U!R;W!I971A=',@9&4@;&$@=&%U;&$N+BX`7U5S=6%R:7,`
M;&QI8G)E=&$@9"=A9')E8V5S`&%G96YD80!C86QM80!0<F5M:2!A<77M`&5S
M=.`@8V%I96YT`&%R>&EU`&1E<R!D96P@)7,@*"5S*2!A(&QE<R`E<R`E<P!H
M.@!H:`!I;6UE9&EA=`!I;G-E<F5I>`!L[6YI97-=`%,G:&$@<')O9'7O="!U
M;B!C;V1I(&0G97)R;W(@)60@9&5L(&UK:7-O9G,@96X@8W)E87(@25-/+@`C
M;6TC`&YO;0!N;R!S)VAA(&EM<&QE;65N=&%T`&5N8V%R82!N;R!S)VAA(&EM
M<&QE;65N=&%T`&)L;V,@9&4@;F]T97,`<&5R8V5N=&%T9V4`<.UX96QS`&5S
M=.`@<'5J86YT`&UO<W1R87(@9&EF97+H;F-I97,`<VUS,F5M86EL('!E<B!V
M:6$@9&4@2%144`!S<P!C;VYS=&%N=`!L;&ES=&$@9&4@=&%S<75E<P!T96-L
M96=E=2!L82!C;VYT<F%S96YY82!D=65S('9E9V%D97,@<&5R(&-O;F9I<FUA
M<BUL80!U;FEF:6-A=`!S96YS92!N;VT`<V5L96-C:?,@9&4@;"=U<W5A<FD`
M=D-A<F0`=SHC(P!W96%T:&5R+F-O;0``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&]C86QE+V-S7T-:+P``````````````````````````````````````
M```````````````````````````````````````````P,#`P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U,P`P,C`Q,38`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O8W-?0UHO:&5L<"YX;6P`````
M````````````````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,C8Q`#$P-3$U
M-#,S-S4S`#`R,34W,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2)I<V\M
M.#@U.2TR(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O8W-?0UHO:&5L
M<"YX;6PL=B`Q+C8@,C`P-"\P."\Q."`P.#HT,CHU,2!J86X@17AP("0@+2T^
M"CQH96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4](G5P=&]D871E
M(B!M9#4](C8X8V$S,V8W9C!C.6%A931C,3`S96(T-S0Y,F-D8S$U(CX*/'1I
M=&QE/E!O<G3A;#PO=&ET;&4^"B`\<&%R83X*("!3='+A;FMA(%!O<G3A;'4@
M<&]S:WET=6IE('-T<G7H;OT@</AE:&QE9"!VN65C:"!D^6QEOFET_6-H(&EN
M9F]R;6%C[2X*("!.87#X[6ML860@;?F^92!Z;V)R87IO=F%T('!OZ&5T(&5M
M86EL^2P@:6YF;W)M86-I(&\@<V-H^7IKX6-H('9E(%9A[&5M(&MA;&5N9.'X
M:2P*("#Z:V]L96-H+"!A=&0N(%;L=+EI;F$@=.QC:'1O(&EN9F]R;6/M('!O
M<VMY='5J[2!L:6YK>2!K(&+LOF[];2!F=6YK8^UM+"`*("!J86MO(&YA</CM
M:VQA9"!V>71V;_AE;NT@;F]VZ2!E;6%I;&]VZ2!Z<'+A=GDL('9Y='9O^&5N
M;>T@;F]VZ2!S8VCY>FMY+"!A=&0N"B`\+W!A<F$^"B`\<&%R83X*("!2;WIV
M<KYE;NT@=.ET;R!S='+A;FMY('!O<G3A;'4@;'IE(&YA<W1A=FET('!O;6]C
M[2!T;&'H[71K82!2;WIL;[YE;NTN"B`@3F%P^.UK;&%D+"!M^;YE=&4@<VD@
M=GEB<F%T+"!K=&5RZ2!P<G9K>2!S:2!P^&5J971E('IO8G)A>FET(&$@=&%K
MZ2!V(&IA:^EM"B`@<&_X863M+B`*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](FYA=F)A<B(@<W1A=&4](G5P=&]D871E(B!M9#4](F(X8V8P864Q
M.64U-V1F83!C,F(Y-C)E-3$V-S@R9C0W(CX*/'1I=&QE/DYA=FEG8>AN[2!,
M:;ET82!P<F\@07!L:6MA8V4\+W1I=&QE/@H@/'!A<F$^"B`@3F%V:6=AZ&[M
M(&QIN71A(&IE('5M[7-T;NQN82!V;&5V;R!N82!W96)S='+A;F-E+B!+;&EK
M;NQT92!N82!I:V]N:WD*("!TZ71O(&QIN71Y('!O<VMY='5J[6/M('#X96AL
M961N[&JY[2!A(')Y8VAL96JY[2!P^&5P[6[A;NT@;65Z:2!A<&QI:V%C96UI
M+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I
M;G1E;F%N8V4B('-T871E/2)U<'1O9&%T92(@;60U/2)D9#DU9&8P-V$P,S`S
M,3(S,F)A96$Y,3DR.#AB,F0P,"(^"B`@("`\=&ET;&4^3F%S=&%V96[M.B#:
M9'*^8F$Z(%!R;W;I<W0@VF1ROF)U/"]T:71L93X*("`@(#QP87)A/@H@("`@
M3WIN8>AT92!T96YT;R!RX6UEZ&5K+"!P;VMU9"!S:2!P^&5J971E('!R;W;I
M<W0@;W!E<F%C92#Z9'*^8GD@</AI"B`@("!P^&EH;.&Y96[M(&1O('-Y=.EM
M=2X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6-O
M;F9I<FU?;6%I;G1E;F%N8V4B('-T871E/2)U<'1O9&%T92(@;60U/2)A,C$Q
M-C)C9&9F,V(Q9#AF865A9&(W,CDV,C0P,#,V92(^"B`@("`\=&ET;&4^3F%S
M=&%V96[M.B#:9'*^8F$Z(%!O='9R9&ET(-ID<KYB=3PO=&ET;&4^"B`@("`\
M<&%R83X*("`@($]Z;F'H=&4@=&5N=&\@<N%M9>AE:RP@<&]K=60@<VD@</AE
M:F5T92!P;W1V<F1I="!VN65C:&YY(&]P97)A8V4@^F1ROF)Y"B`@("!N9;X@
M<V4@<')O=F5D;W4N(%!O:W5D('1E;G1O('+A;67H96L@>OES=&%N92!N96]Z
M;F'H96[]+"!P;W3X96)NZ2!O<&5R86-E(`H@("`@<V4@<')O=F5D;W4@875T
M;VUA=&EC:WD@8F5Z(&UOOFYO<W1I('-T;W)N82X*("`@(#PO<&%R83X*/"]E
M;G1R>3X*/"]H96QP/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&]C86QE+V-S7T-:+TQ#7TU%4U-!1T53+P``````
M```````````````````````````````````````````````````````````P
M,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U
M,P`P,C$W,#,`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O8W-?0UHO
M3$-?34534T%'15,O:&]R9&4N;6\`````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,S,V,#,U`#$P-3$U-#,S-S4S`#`R,S,U,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#>$@25`````)@&```<````W#0``,L(
M``"<:0```````,B,```.````R8P```\```#8C```#0```.B,```(````]HP`
M``L```#_C```#`````N-```$````&(T```P````=C0``#P```"J-```+````
M.HT```X```!&C0``!0```%6-```H````6XT```@```"$C0``"@```(V-```5
M````F(T``!(```"NC0``"P```,&-```.````S8T```H```#<C0``#0```.>-
M```.````]8T``!$````$C@``#0```!:.```,````)(X```T````QC@``!@``
M`#^.```/````1HX``!@```!6C@``#````&^.```.````?(X```X```"+C@``
M"````)J.```N````HXX``!H```#2C@``,@```.V.```X````((\``%0```!9
MCP``40```*Z/``!:`````)```%<```!;D```-````+.0```'````Z)````H`
M``#PD```#P```/N0```%````"Y$```8````1D0``$0```!B1```(````*I$`
M``D````SD0``"0```#V1```E````1Y$``"````!MD0``$````(Z1```/````
MGY$```H```"OD0```P```+J1```/````OI$``!0```#.D0``"0```..1```-
M````[9$``!(```#[D0``#P````Z2```*````'I(```\````ID@``"````#F2
M```D````0I(``!0```!GD@``%@```'R2```(````DY(``!D```"<D@``!P``
M`+:2```,````OI(``"P```#+D@``#@```/B2```#````!Y,```L````+DP``
M!P```!>3```'````'Y,```4````GDP``!0```"V3```*````,Y,```,````^
MDP``%P```$*3```*````6I,```\```!EDP``#@```'63```8````A),``",`
M``"=DP``#@```,&3```4````T),``!<```#EDP``%P```/V3```7````%90`
M`!,````ME```#P```$&4```.````490``!\```!@E```!P```("4```&````
MB)0```@```"/E```#P```)B4```&````J)0```H```"OE```$P```+J4```+
M````SI0``!````#:E```%0```.N4```5`````94```<````7E0``$````!^5
M```%````,)4``!4````VE0``$0```$R5```,````7I4``#L```!KE0``"0``
M`*>5```'````L94``!0```"YE0```P```,Z5```%````TI4``!````#8E0``
M"0```.F5```3````\Y4``#D````'E@``$@```$&6```G````5)8``"P```!\
ME@``*@```*F6```E````U)8```H```#ZE@``!@````67```)````#)<```<`
M```6EP``+P```!Z7```W````3I<``"X```"&EP``50```+67```M````"Y@`
M`"T````YF```+0```&>8``!`````E9@``",```#6F```(P```/J8```M````
M'ID``#,```!,F0``%0```("9```9````EID``"D```"PF0``)````-J9```1
M````_YD```H````1F@``#````!R:```*````*9H``!`````TF@``%@```$6:
M```6````7)H```<```!SF@``!P```'N:```4````@YH```H```"8F@``"```
M`*.:```(````K)H```<```"UF@``!P```+V:```&````Q9H```4```#,F@``
M!P```-*:```&````VIH```@```#AF@``*0```.J:```.````%)L```H````C
MFP``!````"Z;```'````,YL```D````[FP``!@```$6;```1````3)L```<`
M``!>FP``%@```&:;```$````?9L```@```""FP``!@```(N;```-````DIL`
M``8```"@FP``'@```*>;```1````QIL```@```#8FP``#0```.&;```,````
M[YL```<```#\FP```P````2<```#````")P``!<````,G```$P```"2<```(
M````.)P```0```!!G```"````$:<```(````3YP``$$```!8G```(````)J<
M```&````NYP```8```#"G```%0```,F<```8````WYP``"(```#XG```+@``
M`!N=```=````2IT``"$```!HG0``5````(J=```I````WYT```H````)G@``
M!P```!2>```5````')X```X````RG@``"@```$&>```/````3)X```T```!<
MG@``#P```&J>```-````>IX```D```"(G@``%````)*>```&````IYX``!@`
M``"NG@``'0```,>>```3````Y9X``!0```#YG@``!`````Z?```&````$Y\`
M`%0````:GP``!````&^?```.````=)\```4```"#GP``!0```(F?```;````
MCY\``!H```"KGP``$0```,:?```1````V)\``!P```#JGP``*@````>@```0
M````,J```"$```!#H```!0```&6@```3````:Z```!(```!_H```"@```)*@
M```/````G:```!$```"MH```$P```+^@```,````TZ````8```#@H```!@``
M`.>@```7````[J```!`````&H0``$0```!>A```(````*:$```4````RH0``
M#````#BA```0````1:$```4```!6H0``#0```%RA```&````:J$```<```!Q
MH0``#0```'FA```'````AZ$```L```"/H0``!P```)NA```'````HZ$```D`
M``"KH0``"@```+6A```9````P*$```P```#:H0``$````.>A```%````^*$`
M`"4```#^H0``$@```"2B```3````-Z(``"L```!+H@``.P```'>B```@````
MLZ(``#8```#4H@``"`````NC```,````%*,```8````AHP``!````"BC```.
M````+:,```H````\HP``#0```$>C```>````5:,``!L```!THP``(0```)"C
M```>````LJ,``!D```#1HP``'@```.NC```;````"J0``"8````FI```&P``
M`$VD```>````::0``!P```"(I```)@```*6D```S````S*0``"8`````I0``
M*P```">E```X````4Z4``"\```",I0``$@```+RE```I````SZ4``!(```#Y
MI0``H@````RF```6````KZ8``",```#&I@``*````.JF```I````$Z<``"@`
M```]IP``'P```&:G```@````AJ<``"4```"GIP``,````,VG```A````_J<`
M`!P````@J```)@```#VH``!!````9*@```P```"FJ```!P```+.H```'````
MNZ@```8```##J```#0```,JH```0````V*@``!(```#IJ```$P```/RH```2
M````$*D```<````CJ0``!````"NI```,````,*D```X````]J0``#P```$RI
M```3````7*D```T```!PJ0``*````'ZI```#````IZD```T```"KJ0``!@``
M`+FI```1````P*D``!<```#2J0``&P```.JI```.````!JH```(````5J@``
M!0```!BJ```0````'JH```0````OJ@``#0```#2J```.````0JH```,```!1
MJ@``#@```%6J```(````9*H```\```!MJ@``#P```'VJ```'````C:H```T`
M``"5J@``$````*.J```+````M*H```8```#`J@``#````,>J```1````U*H`
M`!D```#FJ@``"P````"K```-````#*L``"(````:JP``"@```#VK```8````
M2*L``!D```!AJP``%@```'NK```-````DJL```<```"@JP``%````*BK```+
M````O:L``"(```#)JP``+P```.RK```+````'*P```D````HK```&0```#*L
M```+````3*P``!<```!8K```%P```'"L```)````B*P``!8```"2K```#P``
M`*FL```6````N:P```X```#0K```&````-^L```(````^*P```T````!K0``
M)@````^M``!#````-JT```@```!ZK0``$@```(.M```(````EJT```L```"?
MK0``+P```*NM```.````VZT```4```#JK0``!@```/"M```#````]ZT```<`
M``#[K0``!`````.N```*````"*X```H````3K@``#P```!ZN```0````+JX`
M`!<````_K@``$0```%>N```7````::X```D```"!K@``!0```(NN```+````
MD:X```H```"=K@```@```*BN```%````JZX```T```"QK@``&P```+^N```7
M````VZX```D```#SK@``#@```/VN```-````#*\``!(````:KP``.````"VO
M```@````9J\```@```"'KP``#@```)"O``![````GZ\``!@````;L```$0``
M`#2P```'````1K````4```!.L```&0```%2P```'````;K````@```!VL```
M!@```'^P```&````AK```!````"-L```#P```)ZP```0````KK````\```"_
ML```"P```,^P```/````V[````P```#KL```#P```/BP```'````"+$```8`
M```0L0``#@```!>Q```,````)K$``"@````SL0``#P```%RQ```(````;+$`
M``@```!UL0``$P```'ZQ```>````DK$``"$```"QL0``(````-.Q```9````
M]+$``!<````.L@``)0```":R```7````3+(```0```!DL@``&P```&FR```-
M````A;(```P```"3L@```P```*"R```(````I+(```H```"ML@``#````+BR
M```+````Q;(``!````#1L@``#````.*R```$````[[(``!,```#TL@``%```
M``BS```,````';,```D````JLP``#@```#2S```+````0[,``!L```!/LP``
M!P```&NS```'````<[,```H```![LP``#0```(:S```)````E+,```0```">
MLP``!0```*.S```#````J;,``!@```"MLP``"@```,:S```$````T;,``"8`
M``#6LP``#@```/VS``!\````#+0``!4```")M```!0```)^T```'````I;0`
M``P```"MM```"````+JT```*````P[0```8```#.M```"````-6T```"````
MWK0```8```#AM```!@```.BT```4````[[0```T````$M0``$````!*U```;
M````([4```0````_M0``"0```$2U```0````3K4```D```!?M0``"0```&FU
M```%````<[4``!H```!YM0``"````)2U```&````G;4``!D```"DM0``#@``
M`+ZU```'````S;4```<```#5M0``!0```-VU```)````X[4```H```#MM0``
M`@```/BU```&````^[4```T````"M@``"0```!"V```&````&K8``!(````A
MM@``"0```#2V```'````/K8``!0```!&M@``'0```%NV```&````>;8```H`
M``"`M@``!````(NV```)````D+8```@```":M@``$0```*.V```)````M;8`
M``8```"_M@``#0```,:V```&````U+8```0```#;M@``.0```."V```]````
M&K<``#H```!8MP``'@```).W```%````LK<```X```"XMP``!````,>W```&
M````S+<``"$```#3MP``%0```/6W```&````"[@```0````2N```$0```!>X
M```&````*;@```H````PN```(@```#NX```$````7K@```4```!CN```'0``
M`&FX```$````A[@```P```",N```"@```)FX```(````I+@```D```"MN```
M!0```+>X```Z````O;@``#````#XN```-0```"FY```I````7[D``$<```")
MN0``.````-&Y```I````"KH``#\````TN@``+@```'2Z```M````H[H``!\`
M``#1N@``#P```/&Z```2`````;L```L````4NP``)@```""[```I````1[L`
M`"0```!QNP``)@```):[```(````O;L```H```#&NP``"0```-&[```'````
MV[L``"````#CNP``(`````2\```F````);P```H```!,O```&0```%>\```I
M````<;P``!8```";O```$@```+*\```'````Q;P```H```#-O```#````-B\
M```/````Y;P``!````#UO```0`````:]``!P````1[T``&8```"XO0``#@``
M`!^^```)````+KX```H````XO@``$@```$.^```3````5KX```P```!JO@``
M!@```'>^```/````?KX``!(```".O@``$````*&^```1````LKX``!P```#$
MO@``(P```.&^``!J````!;\```\```!POP``!0```("_```0````AK\```D`
M``"7OP``!````*&_```+````IK\``!0```"ROP``#````,>_```,````U+\`
M``\```#AOP``%0```/&_```I````!\```"H````QP```)@```%S````G````
M@\```"D```"KP```*@```-7````9`````,$``$(````:P0``$0```%W!```2
M````;\$``!,```""P0``%````);!```/````J\$``!8```"[P0``%P```-+!
M```0````ZL$``!$```#[P0``-`````W"```3````0L(``!(```!6P@``-0``
M`&G"```4````G\(```<```"TP@``#````+S"```@````R<(``!0```#JP@``
M$0```/_"```7````$<,``!P````IPP``$P```$;#```1````6L,``!H```!L
MPP``'@```(?#```:````IL,``!$```#!PP``%````-/#```7````Z,,``!4`
M````Q```"0```!;$```9````(,0```0````ZQ```!P```#_$```+````1\0`
M`!$```!3Q```!@```&7$```&````;,0```8```!SQ```!0```'K$```'````
M@,0```<```"(Q```!0```)#$```6````EL0```8```"MQ```!@```+3$```$
M````N\0```0```#`Q```!P```,7$```.````S<0```P```#<Q```#````.G$
M```-````]L0```H````$Q0``#@````_%```%````'L4``"@````DQ0``#@``
M`$W%```,````7,4```\```!IQ0``"@```'G%```(````A,4```D```"-Q0``
M*P```)?%```$````P\4```@```#(Q0``)@```-'%```2````^,4```\````+
MQ@``!@```!O&```*````(L8```<````MQ@``"````#7&```@````/L8```D`
M``!?Q@``#````&G&```-````=L8```X```"$Q@``%@```)/&```1````JL8`
M``8```"\Q@```P```,/&```&````Q\8``!D```#.Q@``!P```.C&```$````
M\,8```L```#UQ@``"P````''```'````#<<```<````5QP``%@```!W'```-
M````-,<```T```!"QP``"@```%#'```0````6\<```\```!LQP``$0```'S'
M```7````CL<```H```"FQP``$0```+''```(````P\<```0```#,QP``#P``
M`-''```Z````X<<```4````<R```#````"+(```>````+\@```X```!.R```
M$````%W(```+````;L@```P```!ZR```"0```(?(```'````D<@```H```"9
MR```"0```*3(```.````KL@``!````"]R```&@```,[(```*````Z<@```D`
M``#TR```"@```/[(```,````"<D```\````6R0``"````";)```&````+\D`
M``<````VR0``"P```#[)``!'````2LD```T```"2R0``"0```*#)```$````
MJLD```,```"OR0``$P```+/)```3````Q\D``!,```#;R0``"@```._)```"
M````^LD```0```#]R0``)0````+*```#````*,H```4````LR@``*@```#+*
M```*````7<H```4```!HR@``!````&[*```*````<\H```T```!^R@``!@``
M`(S*```(````D\H```@```"<R@``!````*7*```%````JLH``&@```"PR@``
M"0```!G+```,````(\L```4````PRP``!@```#;+```;````/<L``"\```!9
MRP``$````(G+```*````FLL```\```"ERP``"@```+7+```)````P,L``!,`
M``#*RP``&P```-[+```8````^LL``!<````3S```#@```"O,```#````.LP`
M``<````^S```"````$;,```'````3\P```H```!7S```"P```&+,```'````
M;LP``%$```!VS```$````,C,```,````V<P```T```#FS```&@```/3,``!*
M````#\T```8```!:S0``!@```&'-```&````:,T``!\```!OS0``!@```(_-
M```)````ELT``!@```"@S0``%P```+G-```&````T<T```T```#8S0``(@``
M`.;-``!7````"<X``!,```!AS@``(P```'7.```3````F<X```(```"MS@``
M"P```+#.```(````O,X```T```#%S@``"@```-/.```'````WLX``!0```#F
MS@``!@```/O.```(`````L\```X````+SP``!P```!K/```*````(L\```L`
M```MSP``!P```#G/```,````0<\```T```!.SP``#````%S/```)````:<\`
M``D```!SSP``"@```'W/```'````B,\```D```"0SP``!P```)K/```*````
MHL\``!L```"MSP``$@```,G/```*````W,\```D```#GSP``$````/'/```'
M`````M```!(````*T```!````!W0```'````(M````4````JT```!0```##0
M```+````-M```!0```!"T```$0```%?0```:````:=```!8```"$T```%```
M`)O0```7````L-```!@```#(T```'````.'0```9````_M````<````8T0``
M!0```"#1```-````)M$```P````TT0``"````$'1```7````2M$```L```!B
MT0``$P```&[1```$````@M$```H```"'T0``!````)+1```,````E]$```D`
M``"DT0``!0```*[1```'````M-$```4```"\T0``!````,+1```"````Q]$`
M`#@```#*T0``+`````/2```2````,-(``"D```!#T@``,@```&W2```*````
MH-(``"P```"KT@``+@```-C2```S````!],``#,````[TP``.````&_3```/
M````J-,``!@```"XTP``$````-'3```/````XM,``!,```#RTP``%`````;4
M```2````&]0``!0````NU```%0```$/4```M````6=0``"T```"'U```,0``
M`+74```N````Y]0``"\````6U0``+````$;5``!B````<]4``!,```#6U0``
M"````.K5```(````\]4``"L```#\U0``(0```"C6```:````2M8```D```!E
MU@``10```&_6``!!````M=8```0```#WU@``$P```/S6```4````$-<```X`
M```EUP``$P```#37```8````2-<```8```!AUP``"0```&C7```*````<M<`
M``\```!]UP``$````(W7```'````GM<```X```"FUP``!0```+77```;````
MN]<```@```#7UP``!@```.#7```4````Y]<``!$```#\UP``#@````[8```X
M````'=@```(```!6V```!@```%G8```.````8-@```4```!OV```!P```'78
M```.````?=@```8```",V```!````)/8```I````F-@``!<```#"V```'P``
M`-K8``!<````^M@``!0```!7V0``/@```&S9```?````J]D``!````#+V0``
M!P```-S9```.````Y-D```P```#SV0``#`````#:```3````#=H```H````A
MV@``'0```"S:```9````2MH```4```!DV@``$0```&K:```1````?-H``"0`
M``".V@``%0```+/:```2````R=H```X```#<V@``&0```.O:```(````!=L`
M``D````.VP``#0```!C;```*````)ML```<````QVP``#P```#G;```+````
M2=L```H```!5VP``!P```&#;```(````:-L```4```!QVP``'P```'?;```&
M````E]L``!````">VP``"````*_;```-````N-L```@```#&VP``$@```,_;
M```L````XML``!H````/W```"0```"K<```*````--P``!4````_W```!0``
M`%7<```4````6]P```0```!PW```$````'7<```&````AMP```<```"-W```
M'@```)7<```H````M-P```H```#=W```&@```.C<```4`````]T```0````8
MW0``!````!W=```+````(MT```4````NW0``!@```#3=```(````.]T```8`
M``!$W0``"@```$O=```;````5MT``#0```!RW0``-````*?=```@````W-T`
M`"D```#]W0``(````"?>``!!````2-X``!H```"*W@``*````*7>```I````
MSMX``"(```#XW@``!@```!O?```(````(M\```4````KWP``"````#'?```9
M````.M\``!D```!4WP``*@```&[?```C````F=\``"X```"]WP``-````.S?
M```(````(>```!<````JX```"@```$+@```'````3>```"$```!5X```$```
M`'?@```.````B.````L```"7X```!P```*/@```3````J^````@```"_X```
M"P```,C@```*````U.```!0```#?X```,@```/3@```+````)^$```4````S
MX0``!0```#GA```7````/^$```\```!7X0``!````&?A```*````;.$```D`
M``!WX0``"P```('A```-````C>$```P```";X0``#@```*CA```%````M^$`
M``0```"]X0``#0```,+A```R````T.$``$4````#X@``%P```$GB```>````
M8>(``!0```"`X@``!0```)7B```4````F^(```<```"PX@``#@```+CB```J
M````Q^(```8```#RX@``#````/GB```-````!N,``!$````4XP``"P```";C
M```V````,N,```H```!IXP``(@```'3C```+````E^,```\```"CXP``,@``
M`+/C```.````YN,```4```#UXP``#@```/OC```3````"N0```<````>Y```
M$0```";D```'````..0``!0```!`Y```&````%7D```'````;N0```4```!V
MY```#````'SD```,````B>0``!(```"6Y```!````*GD```'````KN0```H`
M``"VY```"P```,'D```,````S>0```X```#:Y```#@```.GD```%````^.0`
M``4```#^Y```+@````3E```F````,^4``",```!:Y0```P```'[E```2````
M@N4```8```"5Y0``'@```)SE```8````N^4``"4```#4Y0``#0```/KE```)
M````".8```,````2Y@``!P```!;F```*````'N8```(````IY@``#````"SF
M```5````.>8```L```!/Y@``&0```%OF```@````=>8``!(```"6Y@``!0``
M`*GF```*````K^8``!4```"ZY@``$@```-#F```,````X^8```0```#PY@``
M!P```/7F```,````_>8``%(````*YP``%P```%WG```'````=><```8```!]
MYP``#@```(3G```,````D^<```T```"@YP``%0```*[G```2````Q.<```\`
M``#7YP``%````.?G```;````_.<``!`````8Z```:0```"GH```:````D^@`
M`!<```"NZ```)P```,;H```:````[N@``!<````)Z0``&P```"'I```9````
M/>D``!\```!7Z0``$P```'?I```(````B^D```<```"4Z0``"````)SI```)
M````I>D``!4```"OZ0``#0```,7I```3````T^D```,```#GZ0``1@```.OI
M```_````,NH``#<```!RZ@``5P```*KJ```%`````NL``!\````(ZP``+P``
M`"CK```*````6.L```@```!CZP``#0```&SK```M````>NL```0```"HZP``
M3P```*WK```E````_>L``!P````C[```"P```$#L```?````3.P``!T```!L
M[```)0```(KL```@````L.P``"0```#1[```(````/;L```+````%^T```<`
M```C[0``#0```"OM```,````.>T``!<```!&[0``!@```%[M```Y````9>T`
M``P```"?[0``!P```*SM```)````M.T``!,```"^[0``"0```-+M```$````
MW.T``!````#A[0``"````/+M```(````^^T```0````$[@``"P````GN```,
M````%>X``!(````B[@``$0```#7N```,````1^X``!H```!4[@``#P```&_N
M```'````?^X```T```"'[@``%````)7N```.````JNX```P```"Y[@``&P``
M`,;N```L````XNX``!,````/[P``'````"/O```H````0.\```8```!I[P``
M!P```'#O```3````>.\```4```",[P``!````)+O```7````E^\```H```"O
M[P``#````+KO```)````Q^\```8```#1[P``"0```-CO```(````XN\```D`
M``#K[P``"@```/7O```1`````/````8````2\```#@```!GP```.````*/``
M``T````W\```"P```$7P```=````4?````L```!O\````@```'OP```'````
M?O````8```"&\```"0```(WP```'````E_```#L```"?\```*````-OP```T
M````!/$``!4````Y\0``!0```$_Q```'````5?$```@```!=\0``!P```&;Q
M```%````;O$```<```!T\0``#@```'SQ```)````B_$```8```"5\0``"```
M`)SQ```+````I?$```<```"Q\0``"````+GQ```'````PO$``!8```#*\0``
M"0```.'Q```&````Z_$```L```#R\0``'````/[Q```4````&_(```<````P
M\@``"````#CR```(````0?(```4```!*\@``$````%#R```0````8?(```8`
M``!R\@``&0```'GR```*````D_(``!P```">\@``!P```+OR```%````P_(`
M`!````#)\@``%````-KR```+````[_(```T```#[\@``%P````GS```$````
M(?,```D````F\P``"@```##S```'````._,```(```!#\P``#@```$;S```(
M````5?,``!\```!>\P``(P```'[S```X````HO,``#$```#;\P``)P````WT
M``!D````-?0``!0```":]```50```*_T```X````!?4``$H````^]0``6P``
M`(GU```H````Y?4``#@````.]@``*````$?V```L````</8``"<```"=]@``
M&P```,7V```^````X?8``*D!```@]P``(P```,KX```7````[O@``$@````&
M^0``A0```$_Y```P````U?D``$$````&^@``6P```$CZ``!)````I/H``!T`
M``#N^@``&`````S[```A````)?L``!\```!'^P``*P```&?[```A````D_L`
M`"<```"U^P``'0```-W[```1````^_L``#,````-_```)0```$'\```G````
M9_P``!\```"/_```,````*_\``!I````X/P``#T```!*_0``90```(C]``!-
M````[OT``"\````\_@``+@```&S^```P````F_X``%0```#,_@``6@```"'_
M``!(````?/\``$H```#%_P``,@```!```0`O````0P`!`"P```!S``$`+0``
M`*```0!Q````S@`!`&\```!``0$`LP```+`!`0`7````9`(!`"4```!\`@$`
M,@```*("`0`I````U0(!`#X```#_`@$`(@```#X#`0!2````80,!`"4```"T
M`P$`"P```-H#`0"Q````Y@,!`$4```"8!`$`(0```-X$`0`P``````4!`"4`
M```Q!0$`'````%<%`0`Q````=`4!``<```"F!0$`!P```*X%`0`$````M@4!
M``T```"[!0$`"P```,D%`0`.````U04!``L```#D!0$`!0```/`%`0`0````
M]@4!``(````'!@$`60````H&`0`%````9`8!`!(```!J!@$`!````'T&`0`'
M````@@8!``@```"*!@$`!0```),&`0`#````F08!`!````"=!@$`#````*X&
M`0`3````NP8!``T```#/!@$``@```-T&`0`'````X`8!``8```#H!@$`%```
M`.\&`0`,````!`<!`!@````1!P$`!@```"H'`0`2````,0<!``P```!$!P$`
M`P```%$'`0`J````50<!``0```"`!P$`!@```(4'`0`'````C`<!`!\```"4
M!P$`-0```+0'`0`N````Z@<!`"\````9"`$`%P```$D(`0`@````80@!`!L`
M``"""`$`&````)X(`0`D````MP@!`!\```#<"`$`&@```/P(`0`@````%PD!
M`!H````X"0$`,@```%,)`0`O````A@D!`"L```"V"0$`'P```.()`0`C````
M`@H!`!\````F"@$`&@```$8*`0`E````80H!`"8```"'"@$`)0```*X*`0`D
M````U`H!`!@```#Y"@$`'0```!(+`0`D````,`L!`!@```!5"P$`(@```&X+
M`0`E````D0L!`#P```"W"P$`'P```/0+`0`C````%`P!`!\````X#`$`(```
M`%@,`0`:````>0P!`!@```"4#`$`)@```*T,`0`>````U`P!`"D```#S#`$`
M'@```!T-`0`)````/`T!``P```!&#0$`%P```%,-`0`O````:PT!`"0```";
M#0$`!P```,`-`0`/````R`T!`!0```#8#0$`#@```.T-`0`-````_`T!`"0`
M```*#@$`!0```"\.`0`'````-0X!`"(````]#@$`)0```&`.`0`=````A@X!
M`!H```"D#@$`!P```+\.`0#'````QPX!``L```"/#P$`%0```)L/`0`&````
ML0\!``D```"X#P$`"P```,(/`0`7````S@\!``8```#F#P$`,P```.T/`0`3
M````(1`!`!,````U$`$`!P```$D0`0`/````41`!``<```!A$`$`,@```&D0
M`0`A````G!`!`!,```"^$`$`#````-(0`0`1````WQ`!`#(```#Q$`$`"```
M`"01`0`)````+1$!``H````W$0$`%````$(1`0`*````5Q$!`!T```!B$0$`
M"````(`1`0`?````B1$!``@```"I$0$`&@```+(1`0`&````S1$!`!4```#4
M$0$`!P```.H1`0`(````\A$!``D```#[$0$`/P````42`0`'````11(!``\`
M``!-$@$`#@```%T2`0`0````;!(!``D```!]$@$`"0```(<2`0`(````D1(!
M`!,```":$@$`!P```*X2`0`9````MA(!``H```#0$@$`%P```-L2`0`4````
M\Q(!``H````($P$`#````!,3`0`7````(!,!``0````X$P$`*@```#T3`0`1
M````:!,!``<```!Z$P$``@```((3`0`0````A1,!`!@```"6$P$`"P```*\3
M`0`#````NQ,!``@```"_$P$`!@```,@3`0`'````SQ,!``T```#7$P$`"P``
M`.43`0`4````\1,!`!4````&%`$`#@```!P4`0`O````*Q0!`"````!;%`$`
M'````'P4`0`,````F10!`#$```"F%`$`!0```-@4`0`2````WA0!`#\```#Q
M%`$`$@```#$5`0`*````1!4!``8```!/%0$`!````%85`0`$````6Q4!``H`
M``!@%0$`$P```&L5`0`%````?Q4!``8```"%%0$`!@```(P5`0`$````DQ4!
M``P```"8%0$`"@```*45`0`%````L!4!`!@```"V%0$`&0```,\5`0`?````
MZ14!`!T````)%@$`$0```"<6`0`"````.18!``0````\%@$`"@```$$6`0`&
M````3!8!``4```!3%@$``P```%D6`0`,````718!`$4```!J%@$`&@```+`6
M`0`U````RQ8!`"@````!%P$`4P```"H7`0`9````?A<!`'(```"8%P$`(```
M``L8`0`U````+!@!`"$```!B&`$`10```(08`0`P````RA@!`"@```#[&`$`
M*0```"09`0`F````3AD!`"4```!U&0$`*````)L9`0`H````Q!D!`"(```#M
M&0$`,````!`:`0`2````01H!`!,```!4&@$`$````&@:`0!Y````>1H!``D`
M``#S&@$`<P```/T:`0!\````<1L!`"L```#N&P$`%P```!H<`0`6````,AP!
M``\```!)'`$`'P```%D<`0!`````>1P!`!\```"Z'`$`'````-H<`0!1````
M]QP!`!0```!)'0$`"@```%X=`0`%````:1T!``8```!O'0$`"````'8=`0`%
M````?QT!`!(```"%'0$`$````)@=`0`3````J1T!`!T```"]'0$`#P```-L=
M`0`/````ZQT!``0```#['0$`"0`````>`0`+````"AX!``<````6'@$`!0``
M`!X>`0`4````)!X!``<````Y'@$`"````$$>`0`/````2AX!``@```!:'@$`
M#````&,>`0`/````<!X!``8```"`'@$`%````(<>`0`&````G!X!``P```"C
M'@$`"````+`>`0`$````N1X!``H```"^'@$`!P```,D>`0`$````T1X!`!D`
M``#6'@$``@```/`>`0`)````\QX!``8```#]'@$`!@````0?`0`G````"Q\!
M``0````S'P$`#P```#@?`0`3````2!\!``<```!<'P$`!P```&0?`0`&````
M;!\!``8```!S'P$`$````'H?`0`2````BQ\!``8```">'P$`"0```*4?`0`B
M````KQ\!``<```#2'P$`!P```-H?`0`+````XA\!``4```#N'P$``@```/0?
M`0`+````]Q\!`,<!```#(`$`#@```,LA`0`5````VB$!``T```#P(0$`!P``
M`/XA`0`(````!B(!``@````/(@$`"@```!@B`0`*````(R(!`!(````N(@$`
M#0```$$B`0`(````3R(!``4```!8(@$`'0```%XB`0`,````?"(!``T```")
M(@$`%0```)<B`0`0````K2(!``L```"^(@$`$````,HB`0`(````VR(!`!,`
M``#D(@$`#0```/@B`0`*````!B,!``L````1(P$`"P```!TC`0`/````*2,!
M``8````Y(P$`$````$`C`0`6````42,!``L```!H(P$`$@```'0C`0`2````
MAR,!``@```":(P$`+0```*,C`0`9````T2,!`#@```#K(P$`00```"0D`0!3
M````9B0!`%$```"Z)`$`60````PE`0!7````9B4!`#L```"^)0$`"@```/HE
M`0`.````!28!`!8````4)@$`!0```"LF`0`&````,28!`!D````X)@$`#```
M`%(F`0`4````7R8!`!<```!T)@$`)P```(PF`0`F````M"8!`!$```#;)@$`
M'P```.TF`0`/````#2<!``0````=)P$`$0```"(G`0`0````-"<!``<```!%
M)P$`%````$TG`0`1````8B<!`!@```!T)P$`#@```(TG`0`1````G"<!``H`
M``"N)P$`*0```+DG`0`3````XR<!`!<```#W)P$`$`````\H`0`C````("@!
M``8```!$*`$`!P```$LH`0!*````4R@!``P```">*`$`"````*LH`0`+````
MM"@!``<```#`*`$`"````,@H`0`/````T2@!``@```#A*`$`"@```.HH`0`#
M````]2@!`!D```#Y*`$`#P```!,I`0`9````(RD!`!0````]*0$`$@```%(I
M`0`H````92D!``P```".*0$`)P```)LI`0`7````PRD!`",```#;*0$`'0``
M`/\I`0`2````'2H!`!(````P*@$`#@```$,J`0`?````4BH!``8```!R*@$`
M!@```'DJ`0`(````@"H!``X```")*@$`!P```)@J`0`*````H"H!`!$```"K
M*@$`"````+TJ`0`/````QBH!`!8```#6*@$`&@```.TJ`0`(````""L!`!(`
M```1*P$`!0```"0K`0`6````*BL!`!X```!!*P$`#0```&`K`0`P````;BL!
M``D```"?*P$`!P```*DK`0`4````L2L!``4```#&*P$`!0```,PK`0`0````
MTBL!``L```#C*P$`&@```.\K`0`S````"BP!``\````^+`$`)@```$XL`0`S
M````=2P!`#$```"I+`$`,````-LL`0`(````#"T!``4````5+0$`"0```!LM
M`0`(````)2T!`#D````N+0$`+0```&@M`0`X````EBT!`%,```#/+0$`-P``
M`",N`0`W````6RX!`#8```"3+@$`-P```,HN`0`E`````B\!`"H````H+P$`
M-P```%,O`0`]````BR\!``\```#)+P$`$P```-DO`0`G````[2\!`!P````5
M,`$`#@```#(P`0`+````03`!``P```!-,`$`!@```%HP`0`,````83`!`!H`
M``!N,`$`)@```(DP`0`&````L#`!``<```"W,`$`%@```+\P`0`)````UC`!
M``@```#@,`$`!@```.DP`0`)````\#`!``8```#Z,`$`!0````$Q`0`%````
M!S$!``<````-,0$`!@```!4Q`0`*````'#$!`"4````G,0$`#P```$TQ`0`)
M````73$!``4```!G,0$`!P```&TQ`0`'````=3$!``4```!],0$`#0```(,Q
M`0`&````D3$!`!,```"8,0$``P```*PQ`0`(````L#$!``H```"Y,0$`#0``
M`,0Q`0`(````TC$!`",```#;,0$`$0```/\Q`0`)````$3(!`!(````;,@$`
M#````"XR`0`'````.S(!``,```!#,@$``P```$<R`0`4````2S(!`!0```!@
M,@$`"````'4R`0`(````?C(!``@```"',@$`!P```)`R`0!7````F#(!`"0`
M``#P,@$`!@```!4S`0`&````'#,!`!<````C,P$`&@```#LS`0`<````5C,!
M`"P```!S,P$`&P```*`S`0`N````O#,!`'(```#K,P$`)0```%XT`0`*````
MA#0!``<```"/-`$`$@```)<T`0`1````JC0!``\```"\-`$`#@```,PT`0`4
M````VS0!`!````#P-`$`%`````$U`0`/````%C4!`!4````F-0$`!0```#PU
M`0`7````0C4!`!L```!:-0$`%P```'8U`0`4````CC4!``,```"C-0$`!@``
M`*<U`0!H````KC4!``0````7-@$`%@```!PV`0`%````,S8!``0````Y-@$`
M'@```#XV`0`8````738!``P```!V-@$`&````(,V`0`8````G#8!`"T```"U
M-@$`#@```.,V`0`B````\C8!``@````5-P$`&@```!XW`0`8````.3<!`!,`
M``!2-P$`'````&8W`0`8````@S<!`!0```"<-P$`"P```+$W`0`(````O3<!
M``<```#&-P$`$````,XW`0`5````WS<!`!````#U-P$`"`````8X`0`%````
M#S@!``L````5.`$`#````"$X`0`(````+C@!``T````W.`$`!P```$4X`0`&
M````33@!`!$```!4.`$`"````&8X`0`,````;S@!``<```!\.`$`!0```(0X
M`0`(````BC@!``@```"3.`$`$P```)PX`0`+````L#@!``X```"\.`$`!0``
M`,LX`0`=````T3@!`!````#O.`$`$0`````Y`0`T````$CD!`$0```!'.0$`
M'P```(PY`0`Q````K#D!``H```#>.0$`#P```.DY`0`'````^3D!``D````!
M.@$`#P````LZ`0`)````&SH!`!$````E.@$`(0```#<Z`0`A````63H!`"0`
M``![.@$`)````*`Z`0`8````Q3H!`"$```#>.@$`&P`````[`0`E````'#L!
M`!H```!".P$`'0```%T[`0`8````>SL!`",```"4.P$`*0```+@[`0`;````
MXCL!`"8```#^.P$`,````"4\`0`N````5CP!`!$```"%/`$`*0```)<\`0`.
M````P3P!`+````#0/`$`$````($]`0`8````DCT!`",```"K/0$`)````,\]
M`0`?````]#T!`!L````4/@$`(````#`^`0`A````43X!`"X```!S/@$`'```
M`*(^`0`>````OSX!`"D```#>/@$`2P````@_`0`/````5#\!``0```!D/P$`
M$@```&D_`0`(````?#\!``X```"%/P$`#@```)0_`0`2````HS\!``L```"V
M/P$`%````,(_`0`*````US\!``0```#B/P$`#````.<_`0`/````]#\!``\`
M```$0`$`$P```!1``0`,````*$`!`#$````U0`$`"P```&=``0`1````<T`!
M``0```"%0`$`#P```(I``0`5````FD`!`!@```"P0`$`#P```,E``0`"````
MV4`!``4```#<0`$`$@```.)``0`%````]4`!``L```#[0`$`#`````=!`0`#
M````%$$!``\````800$`"````"A!`0`8````,4$!`!````!*00$`"@```%M!
M`0`0````9D$!`!,```!W00$`"````(M!`0`&````E$$!``X```";00$`#```
M`*I!`0`8````MT$!``P```#000$`#@```-U!`0`C````[$$!``P````00@$`
M'@```!U"`0`7````/$(!`!4```!40@$`#````&I"`0`&````=T(!``X```!^
M0@$`!0```(U"`0`G````DT(!`#\```"[0@$`!0```/M"`0`)`````4,!`!X`
M```+0P$`"P```"I#`0`3````-D,!`!,```!*0P$`!P```%Y#`0`9````9D,!
M`!(```"`0P$`&````)-#`0`0````K$,!`!4```"]0P$`"````--#`0`(````
MW$,!`"8```#E0P$`2`````Q$`0`(````540!`!8```!>1`$`!P```'5$`0`*
M````?40!`#$```"(1`$`#P```+I$`0`%````RD0!``8```#01`$``P```-=$
M`0`'````VT0!``<```#C1`$`#````.M$`0`/````^$0!``T````(10$`#0``
M`!9%`0`4````)$4!`!4````Y10$`%````$]%`0`%````9$4!``4```!J10$`
M"P```'!%`0`(````?$4!``(```"%10$`!0```(A%`0`/````CD4!`"$```">
M10$`$@```,!%`0`0````TT4!``\```#D10$`$0```/1%`0`>````!D8!`#$`
M```E1@$`+0```%=&`0`*````A48!``X```"01@$`BP```)]&`0`6````*T<!
M`!````!"1P$`!P```%-'`0`%````6T<!`"$```!A1P$`"````(-'`0`'````
MC$<!``<```"41P$`!@```)Q'`0`0````HT<!``X```"T1P$`$0```,-'`0`/
M````U4<!`!L```#E1P$`$0````%(`0`-````$T@!`!<````A2`$`!P```#E(
M`0`)````04@!`!0```!+2`$`#0```&!(`0`[````;D@!`!D```"J2`$`"```
M`,1(`0`-````S4@!`!T```#;2`$`&0```/E(`0`A````$TD!`"`````U20$`
M&@```%9)`0`;````<4D!`"4```"-20$`&@```+-)`0`%````SDD!`!T```#4
M20$`$````/))`0`.`````TH!``,````22@$`!````!9*`0`-````&TH!``X`
M```I2@$`#P```#A*`0`7````2$H!``L```!@2@$`!````&Q*`0`8````<4H!
M`!D```"*2@$`#P```*1*`0`-````M$H!``T```#"2@$`#@```-!*`0`?````
MWTH!``8```#_2@$`!@````9+`0`.````#4L!``X````<2P$`#0```"M+`0`(
M````.4L!``@```!"2P$`!````$M+`0`4````4$L!``L```!E2P$`!0```'%+
M`0`D````=TL!``\```"<2P$`:P```*Q+`0`:````&$P!``D````S3`$`!@``
M`#U,`0`*````1$P!``8```!/3`$`"````%9,`0`$````7TP!``H```!D3`$`
M`@```&],`0`$````<DP!``<```!W3`$`%0```'],`0`2````E4P!`!0```"H
M3`$`&@```+U,`0`"````V$P!``(```#;3`$`#@```-Y,`0`&````[4P!``H`
M``#T3`$`!0```/],`0`9````!4T!``@````?30$`!@```"A-`0`7````+TT!
M`!````!'30$`"0```%A-`0`'````8DT!``4```!J30$`"0```'!-`0`-````
M>DT!``8```"(30$`!@```(]-`0`9````EDT!``L```"P30$`!0```+Q-`0`2
M````PDT!``<```#530$`!P```-U-`0`8````Y4T!`!T```#^30$`!P```!Q.
M`0`*````)$X!``0````O3@$`"0```#1.`0`(````/DX!``L```!'3@$`"P``
M`%-.`0`&````7TX!``T```!F3@$`!@```'1.`0`$````>TX!`#<```"`3@$`
M00```+A.`0`X````^DX!`"8````S3P$`!0```%I/`0`/````8$\!``8```!P
M3P$`"````'=/`0`?````@$\!`!H```"@3P$`!0```+M/`0`(````P4\!`!,`
M``#*3P$`"````-Y/`0`)````YT\!`!<```#Q3P$`!@````E0`0`&````$%`!
M`!4````74`$`!0```"U0`0`+````,U`!``P````_4`$`"````$Q0`0`)````
M55`!``4```!?4`$`+@```&50`0`T````E%`!`#P```#)4`$`)P````91`0`^
M````+E$!`#@```!M40$`*````*91`0`R````SU$!`"T````"4@$`-0```#!2
M`0`H````9E(!`!(```"/4@$`$P```*)2`0`-````ME(!`#$```#$4@$`'```
M`/92`0`<````$U,!`!H````P4P$`!P```$M3`0`(````4U,!``<```!<4P$`
M"````&13`0`F````;5,!`"0```"44P$`,0```+E3`0`)````ZU,!`!@```#U
M4P$`*`````Y4`0`6````-U0!`!(```!.5`$`!@```&%4`0`+````:%0!``P`
M``!T5`$`#@```(%4`0`/````D%0!`#@```"@5`$`@````-E4`0!F````6E4!
M``\```#!50$`"P```-%5`0`,````W54!`!$```#J50$`$@```/Q5`0`.````
M#U8!``<````>5@$`#P```"96`0`4````-E8!`!$```!+5@$`#P```%U6`0`>
M````;58!`#````",5@$`?0```+U6`0`0````.U<!``4```!,5P$`%````%)7
M`0`)````9U<!``D```!Q5P$`"0```'M7`0`2````A5<!``X```"85P$`#@``
M`*=7`0`3````ME<!`!4```#*5P$`'P```.!7`0`A`````%@!`!T````B6`$`
M'P```$!8`0`@````8%@!`"(```"!6`$`&````*18`0`W````O5@!``\```#U
M6`$`$0````59`0`1````%UD!`!,````I60$`#0```#U9`0`2````2UD!`!0`
M``!>60$`#P```'-9`0`1````@UD!`#(```"560$`%@```,A9`0`4````WUD!
M`#P```#T60$`%````#%:`0`*````1EH!`!,```!16@$`(@```&5:`0`2````
MB%H!`"@```";6@$`&0```,1:`0`9````WEH!`!<```#X6@$`$@```!!;`0`?
M````(UL!`"(```!#6P$`&@```&9;`0`2````@5L!`!<```"46P$`'````*Q;
M`0`6````R5L!``@```#@6P$`&````.E;`0`$`````EP!``4````'7`$`"P``
M``U<`0`0````&5P!``8````J7`$`#````#%<`0`'````/EP!``8```!&7`$`
M!P```$U<`0`%````55P!``@```!;7`$`&````&1<`0`&````?5P!``D```"$
M7`$`"````(Y<`0`&````EUP!``@```">7`$`$0```*=<`0`2````N5P!``\`
M``#,7`$`$````-Q<`0`*````[5P!`!$```#X7`$`!`````I=`0`A````#UT!
M``\````Q70$`#P```$%=`0`6````45T!``L```!H70$`"0```'1=`0`+````
M?ET!`"\```"*70$`!````+I=`0`(````OUT!``0```#(70$`!0```,U=`0`1
M````TUT!``8```#E70$`"@```.Q=`0`*````]UT!``4````"7@$`(P````A>
M`0`.````+%X!`!$````[7@$`%0```$U>`0`7````8UX!`!P```![7@$`&@``
M`)A>`0`%````LUX!``4```"Y7@$`"0```+]>`0`9````R5X!``<```#C7@$`
M!@```.M>`0`-````\EX!``X`````7P$`!P````]?`0`'````%U\!``4````?
M7P$`#P```"5?`0`.````-5\!``H```!$7P$`$````$]?`0`2````8%\!`!0`
M``!S7P$`%````(A?`0`-````G5\!`!8```"K7P$`"````,)?`0`%````RU\!
M`!(```#17P$`2````.1?`0`&````+6`!``\````T8`$`(P```$1@`0`/````
M:&`!`!4```!X8`$`#@```(Y@`0`-````G6`!``\```"K8`$`"0```+M@`0`/
M````Q6`!``\```#58`$`$0```.5@`0`0````]V`!`!X````(80$`"@```"=A
M`0`(````,F$!``P````[80$`#````$AA`0`,````56$!``4```!B80$`#```
M`&AA`0`)````=6$!`!X```!_80$`9P```)YA`0`3````!F(!``L````:8@$`
M!0```"9B`0`%````+&(!`!(````R8@$`%````$5B`0`3````6F(!``L```!N
M8@$``@```'IB`0`*````?6(!`"\```"(8@$``P```+AB`0`%````O&(!`"8`
M``#"8@$`"@```.EB`0`%````]&(!``4```#Z8@$`$P````!C`0`2````%&,!
M``8````G8P$`"````"YC`0`'````-V,!``0````_8P$`!0```$1C`0!N````
M2F,!``H```"Y8P$`#0```,1C`0`&````TF,!``4```#98P$`*0```-]C`0`R
M````"60!`!$````\9`$`"@```$YD`0`1````660!``H```!K9`$`"0```'9D
M`0`9````@&0!`"<```":9`$`*0```,)D`0`H````[&0!``\````590$`!@``
M`"5E`0`'````+&4!``@````T90$`!P```#UE`0`.````164!``P```!490$`
M!@```&%E`0!%````:&4!`!````"N90$`"@```+]E`0`&````RF4!`!P```#1
M90$`80```.YE`0`&````4&8!``@```!79@$`!@```&!F`0`4````9V8!``D`
M``!\9@$`"````(9F`0`I````CV8!`"@```"Y9@$`"0```.)F`0`%````[&8!
M`"L```#R9@$`9P```!YG`0`I````AF<!`"X```"P9P$`&````-]G`0`"````
M^&<!``T```#[9P$`!0````EH`0`4````#V@!``H````D:`$`!0```"]H`0`(
M````-6@!``8````^:`$`"0```$5H`0`+````3V@!``<```!;:`$`"````&-H
M`0`+````;&@!``8```!X:`$`#@```']H`0`0````CF@!`!$```"?:`$`#0``
M`+%H`0`/````OV@!`!````#/:`$`#P```.!H`0`-````\&@!``\```#^:`$`
M"`````YI`0`>````%VD!`!,````V:0$`"````$II`0`*````4VD!`!8```!>
M:0$`!P```'5I`0`/````?6D!``4```"-:0$`!P```)-I`0`%````FVD!``4`
M``"A:0$`"````*=I`0`1````L&D!`!$```#":0$`&@```-1I`0`6````[VD!
M`!0````&:@$`%P```!MJ`0`:````,VH!`!\```!.:@$`&````&YJ`0`#````
MAVH!``4```"+:@$`#@```)%J`0`.````H&H!`!8```"O:@$`(@```,9J`0`+
M````Z6H!`!0```#U:@$`!P````IK`0`*````$FL!``4````=:P$`#@```"-K
M`0`)````,FL!``4````\:P$`!P```$)K`0`#````2FL!``0```!.:P$``@``
M`%-K`0`^````5FL!`#0```"5:P$`%````,IK`0`J````WVL!`$4````*;`$`
M"@```%!L`0`L````6VP!`#,```"(;`$`.````+QL`0`X````]6P!`#T````N
M;0$`%````&QM`0`:````@6T!`!L```"<;0$`'````+AM`0`;````U6T!`!\`
M``#Q;0$`&P```!%N`0`;````+6X!``X```!);@$`,````%AN`0`P````B6X!
M`#0```"Z;@$`/0```.]N`0`R````+6\!`"\```!@;P$`<@```)!O`0`F````
M`W`!``P````J<`$`"@```#=P`0`S````0G`!`#4```!V<`$`)P```*QP`0`-
M````U'`!`$0```#B<`$`/P```"=Q`0`%````9W$!`!L```!M<0$`%@```(EQ
M`0`2````H'$!`!$```"S<0$`&0```,5Q`0`&````WW$!``<```#F<0$`"0``
M`.YQ`0`.````^'$!`!0````'<@$`#@```!QR`0`1````*W(!``@````]<@$`
M'@```$9R`0`(````97(!``4```!N<@$`"P```'1R`0`-````@'(!``L```".
M<@$`.@```)IR`0`"````U7(!``8```#8<@$`#@```-]R`0`)````[G(!``4`
M``#X<@$`$@```/YR`0`(````$7,!``0````:<P$`,P```!]S`0`.````4W,!
M`"D```!B<P$`4````(QS`0`5````W7,!`#H```#S<P$`(````"YT`0`/````
M3W0!``@```!?=`$`#P```&AT`0`/````>'0!``H```"(=`$`%````)-T`0`,
M````J'0!`!H```"U=`$`%0```-!T`0`'````YG0!`!$```#N=`$`$0````!U
M`0`A````$G4!`!0````T=0$`$@```$EU`0`0````7'4!`",```!M=0$`!P``
M`)%U`0`+````F74!`!0```"E=0$`$@```+IU`0`1````S74!`!H```#?=0$`
M$````/IU`0`,````"W8!``<````8=@$`"````"!V`0`%````*78!`"$````O
M=@$`!@```%%V`0`1````6'8!``@```!J=@$`#@```'-V`0`%````@G8!``\`
M``"(=@$`+P```)AV`0`2````R'8!``8```#;=@$`!P```.)V`0`7````ZG8!
M``8````"=P$`$@````EW`0`%````''<!`!4````B=P$`!````#AW`0`'````
M/7<!`!8```!%=P$`,0```%QW`0`%````CG<!`!,```"4=P$`$````*AW`0`$
M````N7<!``X```"^=P$`"````,UW`0`'````UG<!``H```#>=P$`"````.EW
M`0`&````\G<!``4```#Y=P$`(````/]W`0`U````('@!`#4```!6>`$`&P``
M`(QX`0`D````J'@!`",```#->`$`/P```/%X`0`;````,7D!`"8```!->0$`
M+0```'1Y`0`D````HGD!``8```#'>0$`"````,YY`0`)````UWD!``L```#A
M>0$`%P```.UY`0`0````!7H!`"X````6>@$`)````$5Z`0`T````:GH!`#@`
M``"?>@$`$0```-AZ`0`B````ZGH!`!(````->P$`!@```"![`0`;````)WL!
M`!(```!#>P$`$0```%9[`0`-````:'L!``<```!V>P$`#@```'Y[`0`(````
MC7L!``L```"6>P$`#````*)[`0`;````KWL!`#0```#+>P$`"0````!\`0`%
M````"GP!``D````0?`$`&@```!I\`0`1````-7P!``0```!'?`$`"@```$Q\
M`0`+````5WP!`!````!C?`$`#@```'1\`0`,````@WP!`!8```"0?`$`!0``
M`*=\`0`%````K7P!``\```"S?`$`+````,-\`0!+````\'P!`!8````\?0$`
M'0```%-]`0`:````<7T!``4```",?0$`$````))]`0`'````HWT!`!$```"K
M?0$`+````+U]`0`)````ZGT!``X```#T?0$`$0````-^`0`5````%7X!``T`
M```K?@$`.0```#E^`0`)````<WX!`!T```!]?@$`$P```)M^`0`7````KWX!
M`"\```#'?@$`#P```/=^`0`1````!W\!`!<````9?P$`'@```#%_`0`(````
M4'\!`!(```!9?P$`!P```&Q_`0`4````='\!`!H```")?P$`!P```*1_`0`'
M````K'\!`!````"T?P$`#P```,5_`0`1````U7\!``4```#G?P$`"````.U_
M`0`-````]G\!``T````$@`$`#@```!*``0`0````(8`!`!`````R@`$`!@``
M`$.``0`(````2H`!`"X```!3@`$`)@```(*``0`D````J8`!``<```#.@`$`
M#@```-:``0`&````Y8`!`!<```#L@`$`%P````2!`0`B````'($!``H````_
M@0$`"P```$J!`0`#````5H$!``8```!:@0$`#````&&!`0`"````;H$!``P`
M``!Q@0$`$P```'Z!`0`+````DH$!`!D```">@0$`(````+B!`0`2````V8$!
M``4```#L@0$`"@```/*!`0`5````_8$!`!$````3@@$`#@```"6"`0`&````
M-((!``D````[@@$`$````$6"`0!*````5H(!`!<```"A@@$`!````+F"`0`(
M````OH(!`!0```#'@@$`#@```-R"`0`,````ZX(!`"(```#X@@$`%P```!N#
M`0`-````,X,!`",```!!@P$`'````&6#`0`-````@H,!`&(```"0@P$`(@``
M`/.#`0`6````%H0!`"L````MA`$`(````%F$`0`4````>H0!`!X```"/A`$`
M%@```*Z$`0`?````Q80!`!@```#EA`$`"@```/Z$`0`'````"84!``<````1
MA0$`!````!F%`0`3````'H4!``T````RA0$`$0```$"%`0`(````4H4!`$$`
M``!;A0$`/````)V%`0!"````VH4!`&`````=A@$`"0```'Z&`0`^````B(8!
M`"\```#'A@$`"@```/>&`0`*`````H<!``X````-AP$`.P```!R'`0`(````
M6(<!`#@```!AAP$`+@```)J'`0`B````R8<!``\```#LAP$`*0```/R'`0`8
M````)H@!`#`````_B`$`(@```'"(`0`H````DX@!`"(```"\B`$`#P```-^(
M`0`(````[X@!``X```#XB`$`#P````>)`0`0````%XD!``<````HB0$`/0``
M`#")`0`,````;HD!``X```![B0$`!@```(J)`0`5````D8D!``@```"GB0$`
M"````+")`0`/````N8D!``D```#)B0$`"0```-.)`0`'````W8D!`!````#E
MB0$`$````/:)`0`6````!XH!`!<````>B@$`$0```#:*`0`;````2(H!`!,`
M``!DB@$`"````'B*`0`-````@8H!``P```"/B@$`#P```)R*`0`,````K(H!
M`!D```"YB@$`+````-.*`0`/`````(L!`!\````0BP$`*````#"+`0`(````
M68L!``8```!BBP$`$````&F+`0`)````>HL!``0```"$BP$`&````(F+`0`.
M````HHL!`!````"QBP$`#@```,*+`0`%````T8L!``D```#7BP$`"````.&+
M`0`)````ZHL!``L```#TBP$`$0````",`0`$````$HP!``X````7C`$`!0``
M`":,`0`+````+(P!``X````XC`$`(0```$>,`0`*````:8P!``(```!TC`$`
M!P```'>,`0`%````?XP!``L```"%C`$`!P```)&,`0`R````F8P!`"0```#,
MC`$`,0```/&,`0`7````(XT!``4````[C0$`!P```$&-`0`'````28T!``P`
M``!1C0$`"````%Z-`0`-````9XT!`!,```!UC0$`#P```(F-`0`,````F8T!
M``X```"FC0$`"P```+6-`0`'````P8T!``@```#)C0$`"````-*-`0`6````
MVXT!``D```#RC0$`!P```/R-`0`)````!(X!`"`````.C@$`!0```"^.`0`&
M````-8X!``8````\C@$`"@```$..`0`'````3HX!`!(```!6C@$`$@```&F.
M`0`&````?(X!`!8```"#C@$`"P```)J.`0`;````IHX!``0```#"C@$`!0``
M`,>.`0`/````S8X!`!P```#=C@$`!P```/J.`0`)`````H\!`!4````,CP$`
M!````"*/`0`*````)X\!``\````RCP$`"@```$*/`0`"````38\!`!$```!0
MCP$`!P```&*/`0`>````:H\!`!X```")CP$`,P```*B/`0`E````W(\!`"D`
M```"D`$`70```"R0`0`3````BI`!`%0```">D`$`+@```/.0`0!!````(I$!
M`%X```!DD0$`(````,.1`0!*````Y)$!`"@````OD@$`,@```%B2`0`C````
MBY(!`!T```"OD@$`+````,V2`0#N`0``^I(!`!L```#IE`$`%`````65`0!&
M````&I4!`(4```!AE0$`/P```.>5`0`Q````)Y8!`$L```!9E@$`.````*66
M`0`<````WI8!`!4```#[E@$`&````!&7`0`7````*I<!`"L```!"EP$`'```
M`&Z7`0`?````BY<!`!,```"KEP$`#````+^7`0`O````S)<!`!X```#\EP$`
M'P```!N8`0`A````.Y@!`$(```!=F`$`4````*"8`0`U````\9@!`&$````G
MF0$`1@```(F9`0`O````T)D!`"<`````F@$`+````"B:`0!'````59H!`%``
M``"=F@$`00```.Z:`0!.````,)L!`"T```!_FP$`)0```*V;`0`E````TYL!
M`"8```#YFP$`:@```""<`0!H````BYP!`*X```#TG`$`&P```*.=`0`J````
MOYT!`#8```#JG0$`+P```"&>`0!%````49X!`"````"7G@$`40```+B>`0`A
M````"I\!``L````LGP$`M0```#B?`0`\````[I\!`"(````KH`$`*@```$Z@
M`0`K````>:`!`!P```"EH`$`+P```,*@`0`&````\J`!``8```#YH`$``P``
M``"A`0`.````!*$!``L````3H0$`"@```!^A`0`+````*J$!``4````VH0$`
M#````#RA`0`$````2:$!`&X```!.H0$`!````+VA`0`6````PJ$!``0```#9
MH0$`!P```-ZA`0`%````YJ$!``4```#LH0$`!````/*A`0`0````]Z$!``@`
M```(H@$`$0```!&B`0`3````(Z(!``(````WH@$`!P```#JB`0`'````0J(!
M`!0```!*H@$`#````%^B`0`6````;*(!``8```"#H@$`$P```(JB`0`,````
MGJ(!``,```"KH@$`*````*^B`0`$````V*(!``8```#=H@$`"````.2B`0`;
M````[:(!`#0````)HP$`)P```#ZC`0`H````9J,!`!,```"/HP$`(````*.C
M`0`=````Q*,!`!L```#BHP$`(````/ZC`0`;````'Z0!`!H````[I`$`(@``
M`%:D`0`4````>:0!`#$```".I`$`+P```,"D`0`F````\*0!`!H````7I0$`
M'@```#*E`0`>````4:4!`!D```!PI0$`(P```(JE`0`=````KJ4!`"@```#,
MI0$`&@```/6E`0`;````$*8!`"`````LI@$`(P```$VF`0`9````<:8!`"$`
M``"+I@$`'@```*VF`0`V````S*8!`!X````#IP$`(@```"*G`0`B````1:<!
M`",```!HIP$`'0```(RG`0`8````JJ<!`"(```##IP$`(0```.:G`0`R````
M"*@!`"`````[J`$`"@```%RH`0`+````9Z@!`!8```!SJ`$`*````(JH`0`=
M````LZ@!``H```#1J`$`#P```-RH`0`7````[*@!``X````$J0$`%@```!.I
M`0`A````*JD!``@```!,J0$`!P```%6I`0`B````7:D!`"4```"`J0$`)0``
M`*:I`0`6````S*D!``H```#CJ0$`W````.ZI`0`1````RZH!`!4```#=J@$`
M#````/.J`0`/`````*L!`!8````0JP$`(P```">K`0`&````2ZL!`$````!2
MJP$`%0```).K`0`4````J:L!``<```"^JP$`$P```,:K`0`*````VJL!`#<`
M``#EJP$`*0```!VL`0`6````1ZP!`!0```!>K`$`%````'.L`0`Q````B*P!
M`!$```"ZK`$`$@```,RL`0`3````WZP!`!$```#SK`$`"@````6M`0`7````
M$*T!``@````HK0$`(````#&M`0`(````4JT!`!,```!;K0$`!P```&^M`0`1
M````=ZT!``<```")K0$`"````)&M`0`)````FJT!`#8```"DK0$`!0```-NM
M`0`/````X:T!`!0```#QK0$`$0````:N`0`+````&*X!``P````DK@$`!P``
M`#&N`0`3````.:X!``L```!-K@$`&P```%FN`0`0````=:X!`!H```"&K@$`
M%P```*&N`0`+````N:X!``P```#%K@$`&````-*N`0`)````ZZX!`"H```#U
MK@$`$0```""O`0`*````,J\!``(````]KP$`$````$"O`0`7````4:\!``L`
M``!IKP$``P```'6O`0`*````>:\!``4```"$KP$`!P```(JO`0`,````DJ\!
M``L```"?KP$`%````*NO`0`5````P*\!``X```#6KP$`.````.6O`0`8````
M'K`!`!@````WL`$`"@```%"P`0`E````6[`!``4```"!L`$`%@```(>P`0`\
M````GK`!``T```#;L`$`#@```.FP`0`&````^+`!``0```#_L`$`!`````2Q
M`0`*````";$!`!<````4L0$`!0```"RQ`0`&````,K$!``@````YL0$`!0``
M`$*Q`0`4````2+$!`!4```!=L0$`!0```'.Q`0`7````>;$!`!X```"1L0$`
M'P```+"Q`0`:````T+$!`!````#KL0$``@```/RQ`0`$````_[$!``L````$
ML@$`!0```!"R`0`%````%K(!``,````<L@$`#@```""R`0!,````+[(!`!P`
M``!\L@$`*@```)FR`0`F````Q+(!`$X```#KL@$`'P```#JS`0!=````6K,!
M`!T```"XLP$`1P```-:S`0`@````'K0!`#$````_M`$`,P```'&T`0`H````
MI;0!`#0```#.M`$`-@````.U`0`T````.K4!`#````!OM0$`*````*"U`0`B
M````R;4!`#@```#LM0$`%````"6V`0`5````.K8!``X```!0M@$`80```%^V
M`0`*````P;8!`&,```#,M@$`:0```#"W`0`G````FK<!`!L```#"MP$`&```
M`-ZW`0`1````][<!`!T````)N`$`.0```">X`0`B````8;@!`!L```"$N`$`
M:@```*"X`0`6````"[D!``H````BN0$`!````"VY`0`&````,KD!``@````Y
MN0$`!0```$*Y`0`5````2+D!`!(```!>N0$`&0```'&Y`0`C````B[D!``\`
M``"ON0$`#0```+^Y`0`$````S;D!``D```#2N0$`#0```-RY`0`(````ZKD!
M``D```#SN0$`%@```/VY`0`+````%+H!``H````@N@$`%0```"NZ`0`)````
M0;H!``8```!+N@$`$P```%*Z`0`*````9KH!`!8```!QN@$`"@```(BZ`0`'
M````D[H!``@```";N@$`"````*2Z`0`,````K;H!``8```"ZN@$`!@```,&Z
M`0`9````R+H!``(```#BN@$`"````.6Z`0`&````[KH!``8```#UN@$`*0``
M`/RZ`0`%````)KL!`!,````LNP$`&0```$"[`0`(````6KL!``<```!CNP$`
M!@```&N[`0`*````<KL!`!````!]NP$`&0```(Z[`0`(````J+L!``P```"Q
MNP$`(P```+Z[`0`*````XKL!``D```#MNP$`$````/>[`0`%````"+P!``(`
M```.O`$`"P```!&\`0`!````+@$``!`%``"(!@``SP0``.(%``#_````%0(`
M```````T!0``'0$``#\#````````2`0````````%`P``)````'4&````````
M`````"(!``#5`P``:`$``)X!```A`P``;`0``,X!``!`!@``20,``$``````
M````GP,`````````````X`,``"D%``"7`0```````+D#``"5!````````"D`
M`````````````!P$``!'!@```````*\#`````````````#H!``!M`0``UP0`
M`#T#``#V`P``-@,````````)!````````"T!```C!```\@4``%P!````````
M`````%<#````````L0,``)T"``"6`P``70$``'@$``#^`@```````-T"``#Z
M````E0$````````N!@``T@```!0&```'!````````+P#``#D!0``D@0```P#
M``!R!@``H@,``$$!````````ZP0``````````````````%4````Y`@``O```
M`!<&``#@````-P0``&$````#``````````,!``#3`@``EP0``$H#``#2`0``
M"0(```````"&`0``R00``!\"``#A`````````)X#```-!```3@,``'8#``"W
M`P``SP````````#'`0``10$````````@!0``?@4``"4&``#F````\`0``#@#
M``!M!``````````````9`@``[@(``)@&``!W!```HP$``,P$``#<````ZP(`
M`$T!```0`@``QP````T#``!3`P``&`8``$`%```(`0```````&X$``!&`0``
M`````/\"``!Y!0``UP$``*X$``!F`````````"H$``````````````````#T
M`@``1@8``)@$``#F!```5P8``.(#```F!@``_0,``,L%``#=`P``````````
M````````)@(````````>````X`4``,X"``````````````````")!0``D`,`
M`#,"``#R`P``N0$``.0"``!_!```2@4```````#:!0``C@8``*4#``!U````
MX`$``)X%```D`@```````'(%``#`!```6P(``$<!```4!`````````````#&
M`P``C04``)L#`````````````&`!``"*````+04``'T#``"$!0``?`4``+X#
M```(````!`8``.<$``#8!```V@0````````'`0``/````#@"``!&````[00`
M`#L"````````-@````````"0!````````-L`````````A`0``(@$````````
MIP,``%,!```]`@``Y0,``!(!````````FP(```````"D`P``I`(``&P#``!8
M`P``YP(`````````!0``U`(``/@!```_````K@$```````"(!0``80(``,4%
M``!%`@``,P4``*4!``!T`P``C08``)(```"Z!0``0P$``+X$````````````
M````````````D@8``/$!``"&!```DP$``$0"````````=P8```````!8````
M40$``*@$``",`@```````&8#``"E`@```````*@````T`0```````*$```![
M`0``V`4``%8&``!2!@``8`,``$D&`````````````'`!``"]!```````````
M``!-!0``@P,```````!,!```_00``!<"``!)````XP$``-,#````````J@$`
M`'@```!K`P``[`(``+0$`````````````'`%``"<````P@4``#H````E`@``
M+00``%X"````````\P,```H"````````<`(``/\$``"$````R0```!8&````
M`````````$T````S````Y00```````"F`0``7@,``"L!``!W`P``IP4`````
M```^`P``3`$````````/````D08``%<"``#P`````````,$%```/`@``A`(`
M`&T#``!T!```"P,``"@```"=!```CP,``($#```Q`P``>@0``*$!``"Z`P``
MF`,``"X%``!3!@````(``#L#``#2`P```````',$``!*!```C@$``+T%``"R
M!0``K`(``"`"`````````````-P%``#&`@````````$"```5`0``S`(`````
M```0````70``````````````0`$``*L%``#L`P``/`(```D&````````C0$`
M`(X%````````Q@4``&0!``#S`@```````"````#C````$P4````````E!```
M````````````````=`8``-4"``!R````&`0`````````````-`0``-P"````
M````GP```-8"```#!@```````)$#```/!0``8@(``#H%`````````````&X%
M``"N!0``&08``%0&``"O`@``G0$``(\`````````J04```````#W`0``%@``
M`!(#``#!````<`,```X"```C!0```````&\$`````````````#`&``!4````
M6`$``+\!``"!!```@P(```````"I`@``AP8``!P```!5`@```````"<!````
M````0P4``/D"``#X`@``P`4``$8%``"9!``````````````V!```!P,``&,%
M``",`0````````````````````````````!@!`````````````!V`0``````
M`'D"``````````````````"S`0```````'4!````````Z00``/0%``#!`0``
M````````````````-P```(($```C````0@$``-,`````````P@````````!.
M``````````````!G!```>P0``-\```!.!0``\`,`````````````P`$``!T"
M````````&04```L&``"U!0``B````.8%``#U`@``R`(``#0#````````7@8`
M`&(```!9`0``H0(``(P&``#A!```H`0``````````````````(X```#H`@``
M*`,``(`%``!G!@``)P(``!L"``":`@``PP```%(%```$`@``700``,P#``"0
M`0``M@(``'D```"#!0``$`8```("``!K!0``@P$``","```0`P``?`$``.<!
M```<`0```````%,```"Y!```\`4``.T"``#H!0``90```,D"``!Z!@``````
M``````!:````NP```.P```"M`@``5`$````````I`0``J@```(@!```G!@``
M(0(``!@%```H!@`````````````R`@``708```````!#`P``F@4````````.
M!0``=00``)8&```!!0``&00``#D!````````,`0``%(#`````````````+\#
M````````N`4`````````````5@(````````Y!@``R04``&4#``#O!0``LP4`
M`&<#``#M`0``]@0``````````````````.4%``"H!0``1````,4!````````
M1P4``#,$```5!0``(P8``*@!``!_`0``#0(``)(!``#9````6@$``-X%``!_
M!0``$@(``&\"``!Y!```W04```,"``!$`P``6P4``'X"``![````4P0``)<"
M``",!0```````(`!``#(`0``6`0``+0%````````X@````````">`@``GP4`
M`$$"````````L@,```````!R`@```````$X&``!2`0``]P,```8#````````
M\@$``*,%``````````````````"/`0``6`(``&D"``!N````+@0````````6
M`@``U00```````#6`P``<P,``$("```?!```90$``%8#````````,0(``$`$
M``!V`@``BP4``-\%````````9@(``!$&```@!@``_P4``!@#``""`P``:`4`
M`/4$````````J00``#@$``"Z`@``>P4``!H!``!L````GP(`````````````
M`````$L````U!0```````,\"```#`P``.00``!T&``!5!@``JP0``/D$``"L
M!```]`$```X!``#8`P``!P(```````!@````*P4``)H#``"J!```````````
M``#9!0``P0(```````##!0``L`,``$0&``";````````````````````[P(`
M`(D&``!+!@```````-X!````````N````$8"````````4`(``'4"```J`0``
M`````#L&```8`@``0P0``+8%````````L@0``.\#````````M@0``!$```"D
M!0``DP8``),"``!2`@``I`$``(4$````````*P```-P!``!C`@``````````
M````````V@,``(@"``!6`0``QP,``$@!``!.!```'`(``#\!```"`P``+P0`
M``````#Y`0```````$D"````````=P(``"H#``#+`0``/P8```````!X!0``
M7`(``*(%``#(`````````%<```",!```XP,``$L$``")````D0```)(%``"<
M`0``'`4``',!``#4!0``+0,``*L!`````````````*(```"]`P``X@(`````
M``"6`@``MP4`````````````<0$``$\#``#]`@``S@0``$H```!^````*P8`
M`!<#``"$`P``]P(```````#*!0``*`$``,0"```F`P``QP4```(%``#;!0``
M```````````>`0``(@(``*,$````````%P4```````#U`````0$``($!``"@
M!0``P````#H$```]`0```````-8!`````````````/0`````````X0$`````
M````````9@0``)`````>`@```````!X$``"I````LP(``#`#``#>````P@$`
M````````````4`8``%P#````````>@,`````````````\0,``"0!````````
M/P4``$4%```^````B`,`````````````00````````#+`````````&$&``!D
M``````````````"5!@``B@4``/L#```R!0```````!,&``"4!@``Z0(`````
M````````=````/@#``!V!@``40,```8&```]!0```````+8#``"X`0``QP(`
M``````"%!0```````"`#```2!0``EP,```````!X!@``IP0``(H&````````
M`````*,"``"P`@``%@$``"$!```^!```40(``!@!``!'````1`$``/H"````
M````(00````````\!```9`(``/,````X````60```,X```!C!```9`0``*\$
M````````B00``.\$`````````````&X"`````````````(H#``"P!```@@4`
M`"<#``!(`@``A0(``````````````````!T#``#?`0````````````#A!0``
M%@4``#<&```U````A0,```````"P!0``:@``````````````Q0,````#``#I
M`0```````-L$```/!@``S`4``!,$````````L0```!<!``#-`0``5`(``"8$
M````````;@,````&``".`@``;P,```P%``"%`0``+08``$,`````````K@,`
M`%($``"M````FP4``+("```"!```V@$``&8&``"4`0``Q`````````"W!```
M?P```)L$``!``@``;P$``'H%``"G````!`,``"8```"'`P````$```````#\
M`P``_@4``&0&````````B0$``-0$````````PP$``&(!``#E````>`,``&\%
M````````I`0``'T&```[`0```````$\````O````3P(`````````````T0(`
M`.@```#0````8`(```0$```%````K@(```X$```/`0``OP````````"\`@``
M@P8``````````````````+`!``":!```_04``*T$``#(!````````%`%````
M````U@```)4"``!(!@```````/X#``!;````%0```"P!``"M!0```````'P&
M``#/`P``````````````````+P,``$<"````````U`,``&D$``!B!0``50$`
M`"\!````````]0$```````#D!```XP(```H%``#]`0``)0```!0`````````
M``````````!@!@`````````````````````````````4!0``````````````
M````UP````````!4`P``(08``(`$`````````````!(`````````S0```%0%
M``#2!0``)0$``(\$```Y`P``U04``!P&``#_`0``Q`$```````!?!@``O@(`
M`'$&``#>`P``9@$``',&``````````````````"1`0``3P4``%X%``!O````
M+@````H!`````````````-$!``#9!```!@$```````"O```````````````+
M`0``"@0``-T$````````#0$```````!9!@```````)0```#X!0``*@(``*8"
M``#7!0``H@$``!$#``!P````D0(``````````````````*<"``!/!```````
M`%`#``#,`0``)P0```````#C!```9`4`````````````&@(```````"6!0``
M^@$``$L!```L``````````````!:`@````````````!]`0````````````"S
M`````````!$"```]````3`(``-L"``!"!@```````$P```"8`@``^P$``"`!
M``"J`P````````````"F````S@,``)<%``#I`P``Y`````````#T!```*0,`
M````````````[0,``.0#``#J`P``)0,`````````````4`0``+4$``#7`@``
MV0,``#D%```X!@``[@0``)T%``"[!```E`0``)D"```:````,08``"(%``"6
M`0``904````````H!0```````/@$````````9P(``&(&``#\!0``/P(`````
M```W`@````````````"T````#P,``.$"````!```#@,````````N`P``````
M`#0"``#8`````````%L&```D`P``O0$``"4%``#Z`P```````-\"``!1!0``
M^0```(0&```F!0``7@```-@"``"V````<P4````````I!@``$@8``/$```!\
M`@``;P8```8"```V`@``PP,``-H"``#7`P```````$L#````````#P0``)`"
M``"<!0``C`,``.8#``!R!```<@$```````!9!```F0``````````````6@,`
M`%4%``#[````_@$```````!J`0``&P8````````:!0````````````!%`P``
M<P```)H`````````\P0``$$#``"$`0``'0```*4```!Z`0``7P,``+X!````
M`````````(8#`````````````#4"``#B!```70,``"P&``!^!```````````
M``"3`P``P@,``#0`````````CP4```8`````````H`(``,4```#R!```````
M`#`"``!1````PP0``",!``#(!0``200``/X```!K`0``K``````````;````
MX`(```````#K!0````````````!%!```%`,``*$$``"-!```20$````````,
M`@``7P(```````"_!0```````-\$````````7P$```H&``":`0``F0$``&$$
M``"/!@``8`4```(```!U`P``<P(````````9`````````$($``!A`0``<@,`
M``8%``#J!```Q@$``%@&``!K!@``Z@```(<"``#)`0```````)P$````````
MI@4````````A````F`4``&X&``!H`@``_`$``,P```"'`0``JP,````````,
M`0``60,``$\!```-!@```````#X!``"6````8P8``'0"```K`@```````.L`
M``"8`0``@08``(````#K`P``-@4``*L```"=`P````````````"8````````
M`!X#```:!@``4@```.P$```,````+0```'L#````````2@$```````"U`P``
MMP(``/<%``!Y`0``.@(``'\"```Q````3@(``&4&``#G````-08```@&``#G
M`P``T@0``%@%``!'`P``7@0``'L"````````Q`4``!($````````N`,`````
M```!!@``'P,``/$"````````I00````````_!```(@,```````!L`0``=`$`
M`/D#````````#0```.D%```R!````````$@#``#!`P```````#8!```A!0``
MC0```-,!``#F`0``G@0`````````````;`(``&T&```:!```]P```$D%``"!
M````VP,``(4```!^`P``_`0``,0#````````RP0``&$%``"Z`0``^P(``'L&
M``#B`0``1@,``+,$``"-`P``L@$``"($``"M`0``&````+P$``"5`P``+0(`
M``````#5`0``0P8``'P#````````%00``%<%``!4!``````````````0!```
MP@0```````"U````M0$``'P```!?!0```````#`%```R`0``GP0```P&````
M````H`$``$4&``#<`P``;`8``)P"``!]!0``[P$``&<!`````````````*H"
M``!'!`````````,%``"X!```N0```$P%``#X````?@8```````!(!0``````
M`-`#``!C````A@```),```!3!0``I`````````#L!0```````#4$``"\!0``
M\00````````[!0```````,L"```.!@``/@4``-D"``"A!0``N@0``'@!``#6
M!```[@```)T```!F!0``(`0```````#1`````````*X```!*!@``@04``%P$
M`````````````&<```"F`P``````````````````TP0``-\#``"6!```````
M`$8$```R````_@0``)L!``!I!@````````````"4`P``U@4``.T`````````
M,`$```H```!P!```]@(``&4$```L`P``(@````(!```9`0```````&H$``"3
M!```Z@$``$L"``"Z````!0$``+L%``!L!0```````,4"``"B`@``R`,``,T#
M``!B!```:`,``+T"````````]P0``*`````'````%0,``-D!``#S`0``````
M`,8```"^!0```````!$%``""!@``4`$```````"0!0``7`4``(`#``")`@``
M$P(``'@"````````U`$``/P```#S!0``6P$``/P"``#N`P``0@4``/T`````
M````AP0```````#H!````````````````````````"L$``!/!@``````````
M``"+`@```````"\&``""````70(``+0"``"I`0``A08``-T```"+````:@,`
M``0!````````2P4``&L"``!0`````````+4"````````008``#4!````````
M[@$``&T"```+!```'P4``"0%``#-`@``````````````````7````#L$``#*
M````K`,``+,#``#/`0````````````#K`0``0`,``/`"````````L````%,"
M````````,P8``-@!```(`P``Y0(``,H!``!W````J`,``-("``!I`0``````
M``````!%````6@8``-X$``"Y`@``@P0``&H%``"W`````````#P!````````
M`````*$#``#J`@```````(H"``"@`P````````````#1`P``B0,``"\"``#Y
M!0``@P```"H`````````JP(```````"9`P``C0(``%L$```I!```@`(``+(`
M``````````````````"_!```+`0``#(&``"Q!````````)<```#H`P``=04`
M```````)`````````-`"``!\!```S@4````````(!```.`4```````#Q!0``
MU0```#P&```)`0```@8``*\!`````````````'0%``"W`0````````D%````
M`````````&D```#:````E`(``)("```D!@``?0````````".`P``O0```)(#
M````````R0,``-,%``!A`P``XP4````````4`0```````,("```L!0``````
M```````(`@`````````````=!0``3`,``'<!``"[`P```````+8!```Q!0``
M2``````````Q!```Y0$````````O!0``3`8``+X```">````$P```*P%```#
M!```5P$``+0!``#U`P``/00``(8%````````PP(``!$$``#H`0``:```````
M``!-!@```````%X!``!?!```>@(``$(#``!C`P``"P4```````#``P``]@``
M`$,"```(!0``!````%D"````````!`4``#H#``"4!0```````!L#```>!@``
MF04``"0$``"5!0``400``+D%``!_`P``YP4```````"7!@``9P4``'T$``#[
M!```<04``"H&``"T`P```````%4$``"/`@``000```````!Y`P``5@```'8$
M```J!0``,P,```<&``#'!```&P$```P$``"C`P```````-P$``#0!```@@(`
M`,H$```F`0``BP$```````!H!@``L0$``"<````+`````````,0$``#-!0``
M"@,`````````````^@4``#<#``"'````.@8``&H"````````[`$``/4%``!;
M`P``408``#``````````HP```),%```S`0```````#X"``!!!0```````#$!
M````````D`8``(8"````````@@$```````!K````J0,``/8%```.````[P``
M`'$#```H`@``BP,``'8%```W!0``>@````````#P`0```````&T%````````
M]@$```````"?`0``R@(``#T&````````Q@0````````1`0``5@4`````````
M`````````($"``!-`P``<`8``$H"``"*`0```00``"@$````````5P0``,$$
M```N`@``VP$``"<%```+`@```````!,!```W`0``7`8`````````````^@0`
M`*@"```T!@````````T%``!V````1`4``%H$````````?0(``&X!``#N!0``
M6@4``%4#````````/`,`````````````(P,``````````````````!8$```&
M!````````.$#```K`P``:04``$0$``#R`````````&0#```?!@``R@,``!8#
M``!Q`@``D04``.`$`````````````,\%``#+`P``A@8``&T`````````%P``
M`-0```!"````%08``!0"``#_`P``T`$``&L$``!-!```[04``%\```#R`@``
M30(```````"Q`@```````'D&````````]`,``!D#```V!@```````,4$``#1
M!```C````(L$````````&@,````````R`P``@`8``#D````7!```+`(``!P#
M`````````````(L&```;!0``Y`$``#@!```%`@``3@$`````````````````
M``````"B!```604```````"[`@``NP$``%T%``#0!0``8@,```4&``!^`0``
MIP$````````\!0``W@(``'<%````````OP(``+@"```%!0```````.D`````
M````90(``(X$``!_!@``(@8``"D"```?```````````````3`P``I04``*\%
M```U`P``"0,``&H&``!Q````!00``'$$``"5````L04``!T$``#[!0``````
M`*P!```0`0``P`(``*T#``"\`0``'@4```<%``#F`@``B@0````````^!@``
MT04```````!C`0``I@0```$#````````G`,```````"J!0``Z@4``#L`````
M````5@0``&@$``!I`P```````!L$`````````````(<%````````W0$`````
M``"1!````````!\!``#-!````"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y
M("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S
M=&5R9&%Y*0`@870@`"5D("5S(&%N9"`E<P`E9"UD87D@9F]R96-A<W0`)7,@
M+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P
M`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@
M870@)7,@)7,`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U
M;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L
M96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"P@9W5S
M=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T
M("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`$$@
M9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`
M02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I
M<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0
M(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`
M02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)
M344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-
M24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%
M(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T@4F%I
M;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O
M=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!
M8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D
M96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@4&%S<W=O<F0`06-C
M;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!
M9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!
M9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`
M061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A
M($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@
M;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P
M97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S
M`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG
M;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S
M`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L
M92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP
M93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N
M871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT
M97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E
M<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W
M87,@<W!E8VEF:65D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO
M=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D
M80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES
M(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI
M;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E
M($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT
M('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)G96YT
M:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S
M8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`
M07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O(&1E
M;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@
M82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@
M;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO
M;BUE>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA
M`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E
M(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I
M;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&
M5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@
M+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B
M-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%)E<75I<F5D($Q$
M05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@
M861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!
M=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z
M(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VUC86PZ(%)E<75I<F5D
M($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U
M:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T
M:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I
M8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T
M:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!
M>F5R8F%I:F%N`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@
M0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E
M<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"
M86YG;&%D97-H`$)A<F)A9&]S`$)A<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"
M96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0FQO8VL@(B5S
M(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN
M9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!"
M;W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I
M;F$`0F]T:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`
M0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A
M;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N
M9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P
M97)T:65S+BXN`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N
M(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<BX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E
M<CH@)7,`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N
M;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y
M(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL
M92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#
M86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D
M97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O
M97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S
M86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#
M871E9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N
M90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I
M97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ
M-"D`0V5N=&5R`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U
M<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I
M9FEC871E(%!O;&EC:65S`$-H860`0VAA;F=E`$-H86YG92!T:&4@;F%M92!A
M;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD
M(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%R`$-H96-?:R!,:6YK+BXN`$-H
M:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E
M(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@
M82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S
M92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:')I<W1M
M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#
M;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(&]U="!U<V5R.B`E<P!#
M;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&EC:R!T;R!#;VYT:6YU90!#
M;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO=61Y
M`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L
M;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O
M;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M
M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O
M<P!#;VUP86YY`$-O;7!U=&5R<P!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@
M1&EF9F5R96YC97,`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N
M9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN
M96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N
M(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@
M<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H
M)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S
M('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!S96QE
M8W1I;VX`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@
M96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`
M0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3
M+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S
M`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE
M8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO
M="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A
M8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S
M`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A
M9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K
M+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N
M`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB
M=71I;VX@;&ES=',N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M
M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@
M;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@<F5A
M9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E
M<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@
M;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R
M971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@
M)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L
M9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO
M="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N
M9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T
M:6]N+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@
M9FEL92`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O
M=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL
M82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U
M;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN
M:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R
M(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`
M0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@5V5A=&AE<@!#
M=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A
M<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO
M;@!#>7!R=7,`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M
M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B
M;&EC`$1$`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T90!$871E(%)E8V5I
M=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E;6)E
M<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0`1&5F
M875L="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9FEN:71I;VYS`$1E;&5T
M90!$96QE=&4@1W)O=7``1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P
M=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T
M92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E(')O=P!$96QE
M=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT(&-O;'5M
M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&EV97)Y('1I;64`1&5N;6%R
M:P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA
M;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0
M;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I
M<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T
M`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T
M:6]N<P!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I
M<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N;W0@9&5L971E
M`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O97,@
M=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S
M+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC
M`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S
M`$4M36%I;`!%4E(`16-U861O<@!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U
M<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI
M<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I
M;VYS(&9O<B`E<P!%9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N
M="XN+@!%;0!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M
M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6]T:6-O;G,`
M16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R
M;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL
M97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N
M=3\`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U<FET>2!Q
M=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T
M;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE
M(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%<75A
M=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R('=I=&@@96UA:6P@
M;65S<V%G92X`17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E`$5V97)Y
M(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`
M179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%
M=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AP86YD`$5X
M<&%N9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E('=O<F0@
M;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%>'!O;F5N
M=`!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V
M:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E
M<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D
M('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&
M86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T
M;R!M;W9E('1O("(E<R(N`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN
M87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&96)R=6%R>0!&
M965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO=R!3
M:&]W97)S`$9I96QD(&UA=')I>`!&:6II`$9I;&4@0V]U;G0Z("5S(&9I;&4`
M1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&
M:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U
M<'!O<G1E9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A
M<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@
M;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D
M;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$
M87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@
M8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD
M(')E<W5L="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D
M/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE
M<R`R`$9O<G5M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@
M365T<F]P;VQI=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&
M<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``1G5L
M;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$=A8F]N`$=A;&QE
M<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%T
M92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R
M;6%N>0!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!';P!';V5D96P`1V]O
M9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E96-E`$=R965K("A)4T\M.#@U.2TW
M*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U
M<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<',`1W5A9&5L;W5P90!'
M=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!097)M:7-S:6]N<P!'=65S
M=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A434P`2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I
M;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U
M=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`
M2&%Z90!(96%D97(`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S
M`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG
M(&5D:71O<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI
M;F<@;V8@=&AE(&9I;&4Z`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@
M0VET>2!3=&%T92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;VYD
M=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@
M6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA
M8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O
M2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@
M)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`
M2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@
M=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O
M9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@
M)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES
M92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`
M2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L
M.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@
M;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N
M>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W
M;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(
M=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D
M.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA
M:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0
M($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN
M(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)
M7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O
M<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I
M<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A
M(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG
M($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI
M<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E
M92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A
M;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S
M97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E
M(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A
M9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!)
M;7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A
M8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P
M87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R
M97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD
M:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO
M;@!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A
M8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS
M97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T
M(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A
M(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R
M;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@
M869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F
M;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T
M90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E
M8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS
M97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O
M;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@
M869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E
M<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E
M<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA
M9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@
M<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C
M<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E
M<B!$871A($AE861E<BDN`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@
M8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S
M=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED
M(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED
M(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES
M<VEO;BX`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!S:&%R92!O8FIE8W0`
M26YV86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N
M`$EN=F5N=&]R>0!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E
M;&%N9`!)<VQE(&]F($UA;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S
M=65R`$ET86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE
M<V4@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T
M:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`
M2G5S=&EF>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA
M`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R
M;F5L($YE=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@
M3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@
M;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L
M($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B
M;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y
M;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC
M`$QA<W0@2&%L9@!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO
M9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE
M=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D
M97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE<V]T
M:&\`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E
M:6X`3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A:6X@16%R;'D`
M3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI9VAT(%)A:6X@
M=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3:&]W97(`3&EM
M97)I8VL`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@96UA:6P@861D
M<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9P!,:6YK
M<P!,:6YU>"!#;V]K:64`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R
M`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`
M3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES
M="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN
M9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A
M9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N
M`$QO9R!I;@!,;V<@;W5T`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A
M=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC
M;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO
M=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R
M;VUA;B!N=6UB97)S`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C
M:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L
M(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-
M86=I8P!-86EL`$UA:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L
M87ES:6$`36%L9&EV97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@
M8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@
M8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R
M-"!M87``36%P475E<W0@;6%P`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E
M;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM
M<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E
M`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL
M;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@
M=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``
M36%X:6UU;2!L96YG=&@`36%Y`$UA>6]T=&4`365D:6-I;F4`365M8F5R<P!-
M96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!697)I9FEE
M9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C
M;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G
M92!T>7!E`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L
M92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T:&]D`$UE=')I
M8P!-97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D
M;&4`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M
M<"!L87-T(#8@:&]U<G,Z(`!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG
M(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A
M=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT
M('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N
M`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@
M<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69I960@
M1&%T90!-;V1I9GD@55),`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`
M36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E
M<G)A=`!-;V]N(%!H87-E<P!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@
M0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E($1O=VX`36]V92!,969T`$UO=F4@
M4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UU
M;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:7!L92!S96QE8W1I;VX`
M37D@06-C;W5N=`!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R
M`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`
M3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S
M92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@
M<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O
M8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@
M8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E
M`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W
M($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W
M('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(&]P
M=&EO;G,`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.
M;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R
M96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)
M4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI<W1S
M(&%T('1H92!R97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M92!P
M<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.
M;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&
M5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO
M(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO(&EC
M;VYS(&9O=6YD+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&UE<W-A9V4@<W5P
M<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D
M+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T
M;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I
M;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`
M3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!R=6QE<P!.;R!S:61E<P!.;R!T96UP
M;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N
M86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R
M971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA
M;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO
M('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.
M;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(
M96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T
M($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L96UE
M;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1H:6YG('1O
M(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C
M:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$YU
M;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T
M:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/8W1A;`!/8W1O
M8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;6%N`$]N;'D@24U!4"!S97)V
M97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@;V9F96YS:79E(&9O
M<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T
M:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O
M=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E
M;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X
M=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="X`3W!E;G,@=&AI
M<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO
M;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/
M<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC
M871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE
M<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N<P!004T@875T
M:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$=0($1I9VET86P@4VEG
M;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@
M4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,
M:6=H="!286EN`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`
M4$T@5"U3=&]R;7,`4%](4"!3:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U
M`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A
M($YE=R!'=6EN96$`4&%R86=U87D`4&%R=&QY($-L;W5D>0!087-S=V]R9`!0
M87-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E5
M4R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`
M4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A
M<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S
M.@!096]P;&4`4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO
M;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!0
M97)M:7-S:6]N`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L
M($EN9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T
M;W,`4&ET8V%I<FX`4&EX96QS`%!L871I='5D97,`4&QE87-E(&-L:6-K(&EN
M=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@
M<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@
M=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M
M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@
M;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S
M+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R
M(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T
M:6UE+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN
M`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L
M96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`4&]L86YD`%!O;&ET
M:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`
M4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L9&5R
M("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S
M="`E<R!H;W5R*',I.B``4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S
M:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T
M('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I
M;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D
M;V-U;65N=`!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I
M;VX`4')O:F5C=',`4')O;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y
M($%L9V]R:71H;0!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T
M960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!1871A<@!1=65R>0!24T$@
M4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN
M($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A
M:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@;65S
M<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T
M(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@
M)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S
M.@!2969R97-H(%!O<G1A;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O
M=W-E<@!296UA<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z
M+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K
M`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`
M4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D
M:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H
M92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S
M="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``
M4F5Q=6ER960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U
M<B!087-S=V]R9`!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E=6YI;VX`
M4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS
M`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W
M(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T871E
M($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T
M:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL
M(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C
M;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N
M;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T
M;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G90!3
M05-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S
M86=I;F<`4U%,(%-H96QL`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I
M;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!3
M86EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H
M92!'<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R
M:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`
M4V%U9&D@07)A8FEA`%-A=F4`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U
M<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF
M:6=U<F%T:6]N+@!38VEE;F-E`%-E87)C:`!396%R8V@@16YG:6YE<P!396QE
M8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`
M4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U
M<V5R('1O(&%D9`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T
M(&%N(&]B:F5C=`!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O
M;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T
M92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E
M;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I
M9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D
M96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@
M;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E
M;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E
M<&]R=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B
M:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397-S:6]N($E$(&5X
M<&ER960N`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@
M>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R
M96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO
M=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z
M;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC
M871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H
M97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP
M=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@
M=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@4W5M
M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L
M:6YK<S\`4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY
M('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN
M`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O
M<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A8FQE
M(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE
M(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`
M4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B
M;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E
M<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L
M>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAR:6YK
M`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@
M=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`
M4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT
M96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO
M=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T
M90!3;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L
M;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&]R9&5R
M('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@
M175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3
M;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A
M8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E
M;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@
M86YD('!A9&1I;F<`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U
M=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R
M:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T92!O
M<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E
M<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O
M;2!T:&4@861D<F5S<P!3='EL92!;0U-370!3=0!3=6)J96-T`%-U8FUI=`!3
M=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG
M=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@
M<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S879E
M9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S<V9U
M;&QY('=R;W1E("5S`%-U9&%N`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3
M=6YN>0!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`
M4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE
M`%-V86QB87)D(&%N9"!*86X@36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET
M>F5R;&%N9`!3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!
M<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3=&]R;7,`5%-6(&9I;&4`5&%B;&4`
M5&%B;&4@4')O<&5R=&EE<P!486)L92!P<F]P97)T:65S`%1A:7=A;@!486EW
M86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N
M:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB
M97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U
M<F4Z(`!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!4
M97AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`
M5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4:&4@1E10(&5X=&5N
M<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R
M871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@36%I;G1E
M;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/
M<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI
M<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES
M<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N
M`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C;VYT86-T($E$(&YU;6)E<B!W
M87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD
M(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL
M>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'
M4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S
M:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E
M:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@
M:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO
M="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@
M82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L9"!C
M;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A
M:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I
M960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4
M:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E
M+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W
M;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D
M=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O
M<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E(&1I<W!L
M87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R
M;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@
M:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"!0
M<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO=2!H
M879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S=&EL
M;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4:&4@:61E
M;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@;&5F="UH86YD('-I
M9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T
M(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE(&UE<W-A
M9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H87,@8F5E
M;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE
M<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@;F%M92!T
M;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4`5&AE(&]P
M96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?
M<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@
M8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU
M;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI
M<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN
M`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD
M('-I9&4@;VYL>0!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`
M5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E
M<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@
M<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D
M;V5S(&YO="!E>&ES="X`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`
M5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@
M<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O
M=6QD(&YO="!B92!S879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO
M="!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`
M5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI
M;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE
M;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@
M96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@
M;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E
M<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A
M<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N
M`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M
M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R
M92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E
M<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE
M<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N
M(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U
M<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A
M:6X@;&%T97(N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S
M:&%R:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E
M(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A
M('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O
M8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H
M('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y
M+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@
M271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R
M97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@
M*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES
M(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES
M="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB
M97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T
M:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI
M<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S
M+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T
M:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T
M('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@
M82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`
M5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H
M)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@
M870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II
M<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E
M86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@
M=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`
M5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA
M=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O
M;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N
M('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@
M8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L
M874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L
M871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4
M=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T
M86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@
M8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T
M(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR86EN90!5
M;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@
M97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L
M92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`
M56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-O;FYE8W0@=&\@
M4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L
M92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E
M8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(&5M
M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B
M;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M+@!5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E
M;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E
M;'DN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!6
M1E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D
M971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T
M(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN
M:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L
M92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E860@
M=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S('1O
M("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE
M('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E
M<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T
M;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5
M;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@
M=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F
M:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M(&1A=&$N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S
M="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C
M;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T
M;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E9"!!<F%B($5M:7)A
M=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI=&5D(%-T871E
M<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO=VX`56YK;F]W
M;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N(&-L:6US9VED
M("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S
M<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP
M<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T
M92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC
M:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W
M:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S
M<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E
M;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&=R861E('-C
M<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N
M('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E
M<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E
M<P!5<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F
M;W(@24U34"!S97)V97(N`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R
M("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E
M9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@=&AI<R!S:71E+@!5<V5R;F%M90!5<V5R;F%M93H`57-E<FYA;64Z
M(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O
M<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F
M;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M
M(&YO=RX`5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A
M<FEA8FQE`%9E;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M
M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!6
M97)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN
M9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@*%9)
M4T-)22D`5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@
M87,@)7,`5FER9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L
M(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@
M=FEA(%--5%``5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,
M3%D@1E)/32`E<RX`5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!790!796%T
M:&5R($9O<F5C87-T`%=E871H97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R
M+F-O;0!796(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E
M<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)
M4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S
M:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L
M:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R
M/P!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H
M92!2:6-H(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!I;B!#4U,@=6YI=',`
M5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C
M="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U
M;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P965D(&EN
M(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5V]R:P!7;W)K($%D9')E<W,`
M5V]R:R!0:&]N90!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P
M.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA
M=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV
M,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`
M665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T
M:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U
M(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A;B!N;W0@:&%V92!T:&4@
M)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I9"!N;W0@
M96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A
M;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E
M<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@:&%V92!B965N(&QO9V=E9"!O
M=70N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E
M<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I
M;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9;W4@:&%V92!T;R!E;G1E
M<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E
M92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@;75S="!C;VYF:6=U<F4@
M82!61E,@8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@
M8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M
M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9
M;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M
M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T
M('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I
M9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@
M=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T
M:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@
M;F%M92X`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G
M:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E
M<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA
M<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S
M:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN
M(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD
M(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U
M<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9
M;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE
M(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U
M<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E
M<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!C=7)R96YT
M('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@
M;F%M93H`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P
M=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T
M:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`
M66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA
M<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET
M:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G
M;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI9&4@475O
M=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@
M+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E
M<UT`7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W
M`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TQO9R!I;@!?
M3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS
M`%]296UO=F4@3&EN:RXN+@!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`
M7U5S97)S`&%D9')E<W,@8F]O:P!C86QE;F1A<@!C86QM`&-L:6-K(&AE<F4`
M9F%L;&EN9P!F:6QE`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`:#H`:6UM
M961I871E`&EN;&EN90!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H
M:6QE(&UA:VEN9R!)4T\N`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@
M:6UP;&5M96YT960`;F]T97!A9`!P97)C96YT`'!I>&5L<P!R:7-I;F<`<VAO
M=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W1E861Y`'1A<VL@
M;&ES=`!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N:69I
M960`=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!W96%T:&5R+F-O;0!0
M<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,`I297!O<G0M37-G:60M0G5G
M<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@
M,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#0M
M,#<M,C(@,3$Z-#DM,#<P,`I,87-T+51R86YS;&%T;W(Z($UI;&]S(%=I;6UE
M<B`\=VEM;65R0'IC=2YC>CX*3&%N9W5A9V4M5&5A;3H@0WIE8V@@/&DQ.&Y`
M;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y
M<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,@I#;VYT96YT+51R
M86YS9F5R+45N8V]D:6YG.B`X8FET"E!L=7)A;"U&;W)M<SH@;G!L=7)A;',]
M,SL@<&QU<F%L/2AN)3$P/3TQ("8F(&XE,3`P(3TQ,2`_(#`@.B!N)3$P/CTR
M("8F(&XE,3`\/30@)B8@*&XE,3`P/#$P('Q\(&XE,3`P/CTR,"D@/R`Q(#H@
M,BD["@`@*'#X960@)7,@9&YY*0`@*%#X[7-T=7!O=OT@:VSMZ"`E<RD`("AV
M("5S(&1N96-H*0`@*&1N97,I`"`H>NUT<F$I`"`H=NAE<F$I`"!R>6-H;&]S
M="``)60@)7,@82`E<P`E9"UD96YN[2!P^&5D<&]V[.\`)7,@+2!O>F[A;65N
M[0`E<R!O=&ES:P`E<R!+0@`E<R!O<&5R86-E(/ID<KYB>2`M('!O='9R>F5N
M[0`E<R!N87-T879E;NT`)7,@<F5G:7-T<F%C90`E<R!P;V1M[6YK>2!P;W6^
M[7;A;NT`)7,@:FF^(&5X:7-T=6IE+@`E<R!N82`E<R`E<P`E<R!J92!P;[YA
M9&]VX6YO`"5S(&UI;G5T`"5S(&YE8GEL;R!N86QE>F5N;RX`)7,@8;X@)7,@
M>B`E<P`E<R!A9')E<^'X`"5S(&MA;&5N9.'X`"5S('KA<&ES;NUK`"5S('-E
M>FYA;2#Z:V]L^0`E<SH@)7,`+"!NX7)A>F]V_2`E<R`E<P`L('!R;VWL;F[A
M(&]D("5S(&1O("5S`"TM(';]8NQR("TM`#$R(&AO9&EN;W;](&9O<FWA=``R
M-"!H;V1I;F]V_2!F;W)MX70`,C0@:&]D:6X`4')O('1E;G1O(&)L;VL@:F4@
M=GF^861O=N%N(&1A=&%BX7IO=OT@>F1R;VHN`%9Y<VMY=&QA('-E('KA=F&^
M;N$@8VAY8F$`4')O('IAN6EF<F]VX6[M('IP<N%V>2!J92!N=71N;R!P;W6^
M[70@=F7X96IN_2!01U`@:VSMZ"X`4')O('9E<FEF:6MA8VD@<&]D97!S86[I
M('IP<N%V>2!J92!N=71N;R!P;W6^[70@=F7X96IN_2!01U`@:VSMZ"X`4')O
M(&1EN6EF<F]VX6[M('IP<N%V>2!J92!N=71N;R!P;W6^[70@=F7X96IN_2!0
M1U`@:VSMZ"P@<')I=N%T;NT@4$=0(&ML[>@@82!H97-L;RX`4')O('!O9&5P
M<^%N[2!Z<'+A=GD@:F4@;G5T;F\@<&]UONUT('9E^&5J;OT@4$=0(&ML[>@L
M('!R:7;A=&[M(%!'4"!K;.WH(&$@:&5S;&\N`%!R;R!D9;EI9G)O=N%N[2!Z
M<'+A=GD@:F4@;G5T;F\@<&]UONUT('9E^&5J;OT@4R]-24U%(&ML[>@L('!R
M:7;A=&[M(%,O34E-12!K;.WH(&$@:&5S;&\N`%!R;R!P;V1E<'/A;NT@>G!R
MX79Y(&IE(&YU=&YO('!O=;[M="!V9?AE:F[](%,O34E-12!K;.WH+"!P<FEV
MX71N[2!3+TU)344@:VSMZ"!A(&AE<VQO+@!0<F\@>F&Y:69R;W;A;NT@>G!R
MX79Y(&IE(&YU=&YO('!O=;[M="!V9?AE:F[](%,O34E-12!K;.WH+@!286YN
M[2!DZ;F[`%)A;F[M('#X96CA\FMY`%)A;F[M('-N[&AO=ND@</AE:.'R:WD`
M04TO4$T`05!)($E$`$EN9F]R;6%C92!O('1O;71O(&5D:71O<G4`26YF;W)M
M86-E+BXN`%1E>'0@9&]L^2!D;R!O8G+A>FMU`%1E>'0@9&]P<F]S=/AE9"!O
M8G+A>FMU`%9Y='9O^&5N[2!61E,@861R87/A^&4@;F5B>6QO('!O=F]L96YO
M+@!6>71V;_AE;NT@5D93('-O=6)O<G4@;F5B>6QO('!O=F]L96YO+@!5OFEV
M871E;'-KZ2!H97-L;P!5OFEV871E;&O](/KH970@8GEL('IA8FQO:V]VX6XN
M`%6^:79A=&5L:^D@^NAT>0!6;&^^`%#X:61A="!P;V1S:W5P:6YU`%#X:61A
M="!P;V0M<'+A=F$`4/AI9&%T.@!0^&ED870@;F]V;W4@<VMU<&EN=0!0^&ED
M870@;F]VX2!P<N%V80!0^&ED870@;F]VZ6AO('6^:79A=&5L93H`4/AI9&%T
M('-L;W5P96,`4/AI9&%T(&YO=ND@Z&QE;GD`4/AI9&%T('#A<@!0^&ED870@
M)7,@;65N=2!J86MO(&)OZ&[M('-L;W5P96,@36]Z:6QL>0!0^&ED870@9&\@
M861R97/A^&4Z`%#X:61A="!D;R!MZ6AO(&%D<F5SX?AE`%#X:61A="!UOFEV
M871E;&4`4/AI9.%VX6[M('6^:79A=&5L^2!J92!Z86)L;VMO=N%N;RX`061R
M97-A`$%D<F5SX?@`5GEK;V[A=F%T(&%D;6EN:7-T<F%C:2`M(&YA<W1A=F5N
M[2!P^.US='5P;W;]8V@@<'+A=B!P<F\@;W-T871N[2!UOFEV871E;&4`061M
M:6YI<W1R86-E`$EN>F5RX71Y`$%F9VCA;FES=.%N`$%L8N%N:64`06R^[7)S
M:V\`4/AE>F3M=FMA+T%L:6%S`%IA<F]V;F%T`%IA<F]V;N%N[3H`5KEE`%:Y
M:6-H;FD@;W;L^&5N[2!UOFEV871E;.D`5KEE8VAN>2!S:W5P:6YY`%:Y96-H
M;F$@=;YI=F%T96QS:^$@<'+A=F$`5KEE8VAN>2#H='GX:2!S=')A;GD`4&]V
M;VQI="!V[6-E(&%D<F5S`%!O=F]L:70@;F%S=&%V96[M('1Y<'4@<V5T^.UD
M[&[]('-E>FYA;3\`2FF^(&5X:7-T=6IE`$%L=&5R;F%T:79N[2!)35-0('#X
M:6ALX;EE;NT@9&\@<WES=.EM=0!!;'1E<FYA=&EV;NT@24U34"!H97-L;P!!
M;'1E<FYA=&EV;NT@24U34"!UOFEV871E;'-KZ2!J;>EN;P!!;'1E<FYA=&EV
M;NT@92UM86EL;W;A(&%D<F5S80!!;'1E<FYA=&EV;NT@=GIO<GD`06QT97)N
M871I=F[M('1E>'0Z`$%M97)I8VOA(%-A;6]A`$)Y;&$@>F%DX6YA(&YE<&]V
M;VQE;N$@:&]D;F]T82X`06YD;W)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UN
M[2!P<F]X>0!/9'!O=NSO`$%N=&%R:W1I:V$`06YT:6=U82!A($)A<F)U9&$`
M07!L:6MA8V4`4V5Z;F%M(&%P;&EK86/M`$%P;&EK86-E(&IE('#X:7!R879E
M;F$`4&]UONUT('!R;R!D[&1IZ&[I('-D[6QE;NT`4V-H=N%L:70`4/AI8FQI
MOF[A('9E;&EK;W-T`$1U8F5N`$%R86)S:WD@*%=I;F1O=W,M,3(U-BD`5F5L
M:6MO<W0@87)C:&EV;W9A;NEH;R!S;W5B;W)U`$IMZ6YO(&%R8VAI=G4`57+H
M:73L(&-H8V5T92!V>6UA>F%T(+[A9&]S="!O('#X:6ALX;EE;NT@9&\@)7,_
M`$%R9V5N=&EN80!!<FWI;FEE`$%R;>EN<VO]("A!4DU30TE)+3@I`%5M[&[M
M`$%R=6)A`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@=6WL;NT`07-I92]R96=I
M;VX@5&EC:.EH;R!O8V7A;G4`4&^^X61A="!O('!O='9R>F5N[2!P^&5D('!R
M;W9E9&5N[6T@;W!E<F%C[2#Z9'*^8GD_`%-L;W5P8V4@<R#Z:V]L>0!0;VMU
M<R!O('9Y;6%ZX6[M(&YE97AI<W1U:NUC[2!S:W5P:6YY+@!0;VMU<R!O('9Y
M;6%ZX6[M(&YE97AI<W1U:NUC[6-H('6^:79A=&5L<VO]8V@@<'+A=BX`4&]K
M=7,@;R#Z<')A=G4@;F5E>&ES='5J[6/M8V@@=;YI=F%T96QS:_UC:"!P<N%V
M+@!0;VMU<R!O(/IP<F%V=2!N965X:7-T=6KM8^UH;R!S9.UL96[I:&\@;V)J
M96MT=2X`071R:6)U='D`4W)P96X`075S='+A;&EE`%)A:V]U<VMO`$%U=&A?
M8WER<W%L.B!.96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P^.UP;VYA('!R
M;R!I;6%P+@!!=71H7V-Y<G5S.B!:9')O:B!N96WA('!OOF%D;W9A;ND@<V-H
M;W!N;W-T:2X`075T:%]C>7)U<SH@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A
M;N$@</CM<&]N82!P<F\@:6UA<"X`075T:%]F='`Z($YE8GEL82!N86QE>F5N
M82!P;[YA9&]V86[A('#X[7!O;F$@<')O(&9T<"X@2V]M<&EL=6IT92!02%`@
M<R`M+65N86)L92UF='``075T:%]I;6%P.B!.96)Y;&$@;F%L97IE;F$@<&^^
M861O=F%NX2!P^.UP;VYA('!R;R!)34%0+@!!=71H7VMR8C4Z($YE8GEL82!N
M86QE>F5N82!P;[YA9&]V86[A('#X[7!O;F$@<')O(&MR8C4N`$%U=&A?;&1A
M<#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N82!P<F\@3$1!
M4`!!=71H7VQD87`Z($YE;'IE('#X:61A="!UOFEV871E;&4@)7,N($ALX;EE
M;NT@<V5R=F5R=3H@`$%U=&A?;&1A<#H@3F5L>F4@=GEM87IA="!UOFEV871E
M;&4@)7,`075T:%]L9&%P.B!.96QZ92!A:W1U86QI>F]V870@=;YI=F%T96QE
M("5S`$%U=&A?;6-A;#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM
M<&]N82!P<F\@34-!3"X`075T:%]S;6)A=71H.B!.96)Y;&$@;F%L97IE;F$@
M<&^^861O=F%NX2!P^.UP;VYA('!R;R!S;6)A=71H+@!/=NSX96[M('-E;&AA
M;&\`3W;L^&5N[2!S96QH86QO+B`E<P!/=NSX96[M(&)Y;&\@>F%M[71N=71O
M(%)!1$E54R!S97)V97)E;2X`4V5L:&%L;R!O=NSX96[M($944"!S979E<F5M
M+@!$;W-T=7!NX2!P;VQE.@!!>F5R8F%J9+[A;@!"3T9((';];6QU=GD`4&]Z
M863M`$)A<G9A('!O>F%D[0"I<&%T;ND@:&5S;&\@<')O(&ME<F)E<F]S+@"I
M<&%T;ND@=;YI=F%T96QS:^D@:FWI;F\@<')O(&ME<F)E<F]S+@!"86AA;7D`
M0F%H<F%I;@!"86QT:6-KZ2`H25-/+3@X-3DM,3,I`$)A;F=L863IN0!"87)B
M861O<P!:X6ML860`0NQL;W)U<VMO`$)E;&=I90!"96QI>@!"96YI;@!"97)M
M=61Y`$)H^G3A;@!.87)O>F5N:6YY`$YE;'IE(&YA;.EZ="#HX7-T("(E<R(@
M87!L:6MA8V4@(B5S(BX`3F%S=&%V96[M(&)L;VMU`%1Y<"!B;&]K=0!4=>AN
M[`!";VSM=FEE`%KA;&^^:WD`3VMR86H`J>WX:V$@;VMR86IE.@!/:W)A:F4`
M0F]S;F$@82!(97)C96=O=FEN80!/8F$`0F]T<W=A;F$`1&]L;NT@Z.%S=`!"
M;W5V970@27-L86YD`$)R87KM;&EE`$)R:71S:^$@=&5R:71O<FEA('8@26YD
M:6-KZ6T@;V-EX6[L`$)R=6YE:2!$87)U<W-A;&%M`$)U;&AA<G-K;P!397IN
M86T@<R!O9'+AOFMA;6D`0G5R:VEN82!&87-O`$)U<G5N9&$`0TU3`$-20P!#
M4DP@9&ES=')I8G7H;NT@8F]D>0!6;&%S=&YO<W1I(&)?=?)K>2XN+@!+86QE
M;F3A^`!"97IV['3X[0!+86UB;V2^80!+86UE<G5N`$AE<VQO(&YE;'IE(&YA
M<W1A=FET(&%U=&]M871I8VMY+"!P<F]S[6T@:V]N=&%K='5J=&4@5F&Y96AO
M('-Y<W3I;6]VZ6AO(&%D;6EN:7-T<N%T;W)A+@!.96QZ92!S92!P^&EP;VII
M="!K($E-05`@<V5R=F5R=3H@)7,`2V%N861A`%-T;W)N;P!3=&]R;F\@:&SA
MN65N[2!P<F]B;.EM=0!.96QZ92!V>6UA>F%T('-O=6)O<B`B)7,B+@!.96QZ
M92!N86KM="!D;^AA<V[](&%D<F5SX?@N`$YE;'IE('!O:W)AZ&]V870@8F5Z
M('!A<F%M971R=2`G=&%R9V5T1FEL92<N`$YE;'IE('9Y;6%Z870@861R97/A
M^"`B)7,B+@!.96QZ92!V>6UA>F%T+"!P<F]T;[YE(&5X:7-T=6KM('!O9'-K
M=7!I;GD@)60N`$YE;'IE('!R;W;I<W0@>FWL;G4@=7-P;_CA9.%N[2P@<&_H
M970@<&]S:WET;G5T_6-H('!O;&^^96L@<')O(&YO=ND@=7-P;_CA9.%N[2!N
M96]D<&]V[63A('!OZ'1U('5L;[YE;OUC:"!P;VQOOF5K+@!.96QZ92!Z87-L
M870@>G!RX79U(&YA('IA9&%NZ2#H[7-L;RX@`$-A<&4@5F5R9&4`5&ET=6QK
M>0!+871E9V]R:64@82!Z;F'H:WD`2V%J;6%N<VOI(&]S=')O=GD`36]B:6QN
M[2!T96QE9F]N`$UOOFYO<W1I(&)U\FMY`$]D<W1U<"!M97II(&)U\FMA;6DZ
M`%9L87-T;F]S=&D@8G7R:WD`365Z97)Y(&UE>FD@8G7R:V%M:3H`36]B:6QN
M[2!T96QE9F]N`$ME;'1S:_T@*$E33RTX.#4Y+3$T*0!3=/AE9`!3=/AE9&]A
M9G)I8VOA(')E<'5B;&EK80!3=/AE9&]E=G)O<'-K_2`H25-/+3@X-3DM,BD`
M4&]D<F]B;F]S=&D@8V5R=&EF:6OA='4`4&]D;>UN:WD@8V5R=&EF:6OA='4`
MR&%D`%IM[&YI=`!.87-T879E;NT@:FWI;F$@82!E;6%I;&]VZ2!A9')E<WDN
M(%1Y=&\@<&]L;[YK>2!L:63I('5V:63M+"!K9'F^('-I(.AT;W4@;F5B;R!O
M9'!O=NUD86KM(&YA(%9AN64@>G!RX79Y+@!:;F%K`%IK;VYT7W)O;&]V870@
M;V1K87HN+BX`0VAI;&4`R.UN80#([6ZY=&EN82!Z:F5D;F]D=;EE;N$@*$="
M,C,Q,BD`5')A9&GH;NT@Z.UNN71I;F$@*$)I9S4I`%IV;VQT92!H97-L;P!:
M=F]L=&4@=;YI=F%T96QS:^D@:FWI;F\`5GEB<F%T('IO8G)A>F5N[2!D871U
M;74Z`%9Y8G)A="!T>7`@<W1Y;'4@<V5Z;F%M=2`H<')O(/AA>F5NZ2!S97IN
M86UY*0!6X6YOZ&[M(&]S=')O=@!.96)Y;&$@;F%L97IE;F$@9&5F:6YI8V4@
M=/CM9'D@)7,N`%9YZ&ES=&ET`%9YZ&ES=&ET('IN8>AK>2!Z($U33V9F:6-E
M`$]D<W1R86[L;NT@=;YI=F%T96QE.B`E<P!/9'-T<F%N:70@=;YI=F%T96QE
M`$]D<W1R86[L;NT@^F1A:OD@;R!UOFEV871E;&D`2VQI:V[L=&4@<')O('!O
M:W)AZ&]VX6[M`$-L:6-K871E;&P@</AE<R!(5%10`%IA=OCM="!O:VYO`%IA
M=&&^96YO`$]B;&'H;F\`2V]K;W-O=ND@;W-T<F]V>0!3:VQA<&YO=70@8F_H
M;NT@;&FY='4`4VML87!N;W5T(&]K<F%J90!+;VQU;6)I90!"87)V80!6_6+L
M<B!B87)E=@!086QE=&$@8F%R978`4VQO=7!C93H`3N%Z=GD@<VQO=7!C90!+
M;VUI:W-Y`%#X[6MA>@!0^.UK87IO=N$@:V]N>F]L80!0;WINX6UK80!/8F5C
M;ND@:FWI;F\`2V]M;W)O<P!&:7)M80!0;^CM=&'H90!0;V1M[6YK>0!2;WID
M[6QY('8@;F%S=&%V96[M`$YA<W1A=FET("5S`%!O='9R9&ET(&AE<VQO`$MO
M;F=O`$MO;F=O+"!$96UO:W)A=&EC:^$@<F5P=6)L:6MA`%-P;VIE;NT@<V5L
M:&%L;RX`4W!O:F5N[2!S96QH86QO.B``0GEL;R!Z86WM=&YU=&\@<W!O:F5N
M[2!S('9E^&5J;OUM(&ML[>AO=OUM('-E<G9E<F5M+@!">6QO('IA;>UT;G5T
M;R!S<&]J96[M(',@=F7X96IN_6T@:VSMZ&]V_6T@<V5R=F5R96TN($3Y=F]D
M(#H@)7,@*"5S*0!396QH86QO('-P;VIE;NT@<R!&5%`@<V5R=F5R96TN`$MO
M;G1A:W1Y(&)Y;'D@^G-P[+EN["!P^&EDX6YY(&1O(%9AN65H;R!A9')E<^'X
M92X`4&]K<F'H;W9A=`!#;V]K;W9Y(&]S=')O=GD`2V]LX>AE:P!+;W#M<F]V
M870`2V]P[7)O=F%T(';]8NQR`$MO<W1A<FEK80!0;V+X9;[M('-L;VYO=FEN
M>0!:<'+A=G4@;F5L>F4@N6EF<F]V870@<&]M;V/M(%!'4"X`6G!RX79U(&YE
M;'IE('!O9&5P<V%T('!O;6]C[2!01U`N`%IP<N%V=2!N96QZ92"Y:69R;W9A
M="!P;VUO8^T@4R]-24U%+@!:<'+A=G4@;F5L>F4@<&]D97!S870@<&]M;V/M
M(%,O34E-12X`3F5L>F4@</AI9&%T(&MO;G1A:W0N("5S`$YE;'IE('-E('#X
M:7!O:FET(&L@3$1!4"!S97)V97)U+@!.96QZ92!Z:V]N=')O;&]V870@^NAE
M="X@)7,`3F5L>F4@=GET=F_X:70@9&ES=')I8G7H;NT@<V5Z;F%M+B`E<P!.
M96QZ92!D9;EI9G)O=F%T(%!'4"!D871A+@!.96QZ92!D9;EI9G)O=F%T(%,O
M34E-12!D871A+@!.96QZ92!S;6%Z870@:V]N=&%K="X@)7,`3F5L>F4@<VUA
M>F%T(&1I<W1R:6)UZ&[M('-E>FYA;2X@)7,`3F5L>F4@>FII<W1I="!E+6UA
M:6QO=F]U(&%D<F5S=2!P^.UJ96UC92X`3F5L>F4@>NUS:V%T(/IP;&[](&%D
M<F5SX?@N`$YE;'IE('KM<VMA="#Z<&QN_2!D:7-T<FEB=>AN[2!S97IN86TN
M`$YE;'IE('KM<VMA="#Z<&QN_2!S97IN86T@9&ES=')I8G7H;NUC:"!S97IN
M86WY+@!.96QZ92!Z[7-K870@=F7X96IN_2!K;.WH('H@:VSMZ&]VZ6AO('-E
M<G9E<G4N`$YE;'IE(&]T97;X[70@)7,N`$YE;'IE('!R;W;I<W0@;W!E<F%C
M92#Z9'*^8GD@<')O(&UO9'5L("5S`$YE;'IE(.CM<W0@)7,N`$YE;'IE(')E
M<V5T;W9A="!H97-L;R!P<F\@9&%NZ6AO('6^:79A=&5L92X@5KEE8VAN>2!N
M96)O(&[L:W1E<ND@>B!P;V1R;V)N;W-T[2!N96)Y;'D@<W!RX79N["!Z863A
M;GDN(%IK=7-T92!T;R!Z;F]V=2!N96)O('!O:W5D('!O=/AE8G5J971E('!O
M;6]C+"!K;VYT86MT=6IT92!S<'+A=F-E('-Y<W3I;74N`$YE;'IE('KM<VMA
M="!!0TP`3F5L>F4@>NUS:V%T(&%D<F5SX?@N("5S`$YE;'IE('KM<VMA="!D
M:7-T<FEB=>AN[2!S97IN86TN("5S`$YE;'IE('KM<VMA="!D:7-T<FEB=>AN
M[2!S97IN86UY+B`E<P!.96QZ92!Z[7-K870@<V-H;W!N;W-T:2!S97)V97)U
M`$YE;'IE('#X97!N;W5T(&MO;F9I9W5R86-I+@!.96QZ92!U;&^^:70@:V]N
M9FEG=7)A8VD@<')O("5S+@!.96QZ92!U;&^^:70@>N%L;[YN[2!K;VYF:6=U
M<F%C:2X`3F5L>F4@=6QOOFET('KA;&]H=2!K;VYF:6=U<F'H;NUH;R!S;W5B
M;W)U("5S+@!.96QZ92!H;&5D870@=B!,1$%0('-E<G9E<G4N`$YE;'IE(&%K
M='5A;&EZ;W9A="!K;VYT86MT+B`E<P!.96QZ92!A:W1U86QI>F]V870@9&ES
M=')I8G7H;NT@<V5Z;F%M+B`E<P!.96QZ92!N86SI>G0@8F_H;NT@;&FY='4@
M<')O($UO>FEL;'4N(%!R;W/M;2!P^&5S=NQDZ'1E('-E+""^92!J92!O=&5V
M^&5NX2X`3V1P;^CM=&%N_2!T97AT`%IE;>P`5GEUZ&]V86/M('#X961M['1Y
M`%9Y='9O^&ET`%9Y='9O^&ET(&]D:V%Z`%9Y='9O^&ET(&YO=F]U`%9Y='9O
M^&ET('!O9'-L;[YK>0!4=OER8V4@<'+A=@#([7-L;R!K<F5D:71N[2!K87)T
M>0!#:&]R=F%T<VMO`$MU8F$`06MT=>%L;NT@Z&%S`$%K='7A;&[M(%523"!J
M90!!:W1UX6QN[2!P;^AA<^T`06MT=>%L;NT@<&]D;>UN:WDZ(`!.>6[L:KGM
M('-T>6P`3F%S=&%V96[M(/IK;VSY('!R;W;A9.QN_6-H('#X:2!P^&EH;.&Y
M96[M(&1O("5S+@!6>7-T^&EH;F]U=`!6>7-T^&EH;F]U="!V_6+L<@!+>7!R
M`$%Z8G5K82`H2T])."U2*0!!>F)U:V$@*%=I;F1O=W,M,3(U,2D`07IB=6MA
M+U5K<F%J:6YA("A+3TDX+54I`,AE<VOA(')E<'5B;&EK80!$1`!$96YN[`!$
M871A5')E92!P<F]H;.V^9>@`1&%T=6T`4/AI:F%T;R!D;F4`5OUB['(@9&%T
M=6UU`$1E;@!3;6%?>F%T('-L;W5P96,`4')O<VEN96,`R.US;&$@9&5S[71K
M;W;I('-O=7-T879Y`%IM96ZY:70@;V1S87IE;NT`26UP;&EC:71N[0!);7!L
M:6-I=&[M(&)A<G9A`$EM<&QI8VET;NT@:61E;G1I=&$`1&5F:6YI8V4`4VUA
M>F%T`%-M87IA="!S:W5P:6YU`%-M87IA="!P<N%V80!3;6%Z870@82!V>>AI
M<W1I="!Z<'+A=GD`4VUA>F%T(&)U\FMU`%-M87IA="!S;&]U<&5C`%-M87IA
M="!E>&ES='5J[6/M(&%L=&5R;F%T:79N[2!V>F]R`%-M87IA="#XX61E:P!3
M;6%Z870@=GEB<F%N;W4HZ2D@:61E;G1I='4H>2D`4VUA>F%T('-O=>AA<V[]
M('-L;W5P96,`4VUA>F%T('-O=>AA<V[](/CA9&5K`,AA<R!D;W)UZ&5N[0!$
MX6YS:V\`4&]P<V%T('!R;V)LZ6T`4&]P:7,`4&]D<F]B;F]S=&D@*'1A:^D@
M=B!L;V<@<V]U8F]R=2!(;W)D92DZ`%!O9')O8FYO<W1I(&)Y;'D@>F%Z;F%M
M96[A;GD@9&\@;&]G('-O=6)O<G4@<')O(&%D;6EN:7-T<N%T;W)A+@!6_79O
M:@!2;W-N_2!B;V0`4F]S;OT@8F]D('IA('!O<VQE9&[M(&AO9&EN=3H@`%)O
M<V[](&)O9#H@`%-M['(@>B!L979A(&1O<')A=F$`4VWL<B!Z('!R879A(&1O
M;&5V80!!9')E<^'X`%IO8G)A>FET(#(T+6AO9&EN;W;](.AA<S\`36^^;F]S
M=&D@>F]B<F%Z96[M`%IO8G)A>FET('#X961P;W;L[R`H5$%&*0!&;W)MX70@
M>F]B<F%Z96[M`$1I<W!O>FGH;NT@=7!O>F]R;NQN[0!$:FEB;W5T:0!.97-M
M87IA=`!.97#X:7-T=7!O=F%T('#X[6UO(&1O(&UA:6YT96YA;F-E+G!H<`!/
M8G-A:'5J92!P<G9N[2#XX61E:R!NX7IE=B!S;&]U<&/Y/R!0;VMU9"!A;F\L
M('IAN6MR=&[L=&4@=&5N=&\@<N%M9>AE:SH`1&]M:6YI:V$`1&]M:6YI:^%N
M<VOA(')E<'5B;&EK80!3=&&^96[M`%-T8;YE;NT@)7,`4W1A:&YO=70@9V5N
M97)O=F%N;W4@:V]N9FEG=7)A8VD@:F%K;R!02%`@<VMR:7!T+@!2;VQE=&]V
M_2!S97IN86T`1')O9WD`12UM86EL`$524@!%:W;A9&]R`%5P<F%V:70`57!R
M879I="!B;&]K`%5P<F%V:70@<VMU<&EN=0!5<')A=FET('!RX79A`%5P<F%V
M:70@<'+A=F$`57!R879I="!P<N%V82!P<F\@)7,`57!R879I="!M;[YN;W-T
M:2!P<F\Z`%5P<F%V:70@<'+A=F$@<')O("5S`%;]=6MA`$5G>7!T`$5L(%-A
M;'9A9&]R`%!R=F5K+BXN`$5M`$5M86EL`$5M86EL;W;A(&%D<F5S80!%;6%I
M;&]VZ2!A9')E<WD@<V4@;75S[2!S:&]D;W9A="X`16UA:6P@<R!P;W1V<GIE
M;NUM`$EK;VYK>2!S(&5M;V-E;6D`4'+A>F1NX2!Z<'+A=F$N`%!RX7ID;OT@
M=OUS;&5D96LN`%!RX7ID;OT@=&5R;>UN('!R;R!V>6AL963A=N%N[0!0;W9O
M;&ET('9K;.%DX6[M(&]B<F%Z:_D@>B!F;W1O(&=A;&5R:>T@9&\@=&5X='4_
M`$%K=&EV;W9A="!P<F%VZ2!K;&EK;G5T[2!P<F\@:V]N=&5X=&]VZ2!M96YU
M/P!+;VYE8R!R;VMU`%IV['2Y:70@961I=&]R`%IA9&5J=&4@8F5Z<&7H;F]S
M=&[M(&]TX7IK=2P@;F$@:W1E<F]U(&)U9&5T92!M=7-E="!O9'!O=NQD['0@
M<&]K=60@<VD@8G5D971E(&-H=.UT(')E<V5T;W9A="!S=ND@:&5S;&\L(&YA
M</@N("=*86OI(&IE(&IMZ6YO(%9AN65H;R!P<V$_)SH`6F1E('9L;[YI="!5
M4DP@;V)RX7IK=0!2;W9N[6MO=N$@1W5I;F5A`$5R:71R96$`0VAY8F$`3F%S
M=&%L82!C:'EB82!S('!ON71O=F[M('IP<N%V;W4N`$5S=&]N<VMO`$5T:6]P
M:64`171N:6-KZ0!%=G)O<&$`2V&^9/UC:"`Q-2!M:6YU=`!+8;YDZ2`R(&UI
M;G5T>0!+8;YD_6-H(#,P('-E:W5N9`!+8;YD_6-H(#4@;6EN=70`2V&^9.D@
M</AI:&SAN65N[2!D;R!S>7-TZ6UU`$MAOF1O=2!P^6P@:&]D:6YU`$MAOF1O
M=2!M:6YU='4`5GIO<F]V_2!P^.UK;&%D(&AO9&YO=#H`4')O=NES=`!2;WIV
M:6YO=70`4F]Z8F%L:70@8F_H;NT@;&FY='4`3^AE:^%VX6YA("<I)P!/Z&5K
MX7;A;F\@<V%M;W-T871NZ2!S;&]V;R!N96)O(&AL961A;OT@=&5R;>UN('8@
M=79O>F]V:^%C:`!$871U;2!P<F\@:V]N96,@<&QA=&YO<W1I`$5X<&]N96YT
M`$)A<G9A('!O</AE9.T`4/AE;F]S(&MO;F9I9W5R86-E('!O;6]C[2!&5%``
M4V5L:&%L;R!Z[7-KX6[M(&UOOFYO<W3M+@!.96QZ92!S92!P^&EP;VII="!K
M($Q$05`@<V5R=F5R=2X`3F5L>F4@<V4@</AI<&]J:70@:R!334(@<V5R=F5R
M=2X`4V5L:&%L;R!K;W#M<F]VX6[M('H@(B5S(BX`4V5L:&%L;R!K;W#M<F]V
MX6[M(&1O("(E<R(N`%-E;&AA;&\@>F%L;[YE;NT@;F]VZ6AO(%-!4TP@<W!O
M:F5N[2X`4V5L:&%L;R!P^&5S=6YU=.T@9&\@(B5S(BX`1&]B<ND`1F%L:VQA
M;F1S:^D@;W-T<F]V>2`H36%L=FEN>2D`1F%R:6IS:^D@;W-T<F]V>0!:X79A
MOF[A(&-H>6)A.@!&87@`VFYO<@!#[71I="!S92!J86MO`$/M=&ET('-E(&IA
M:V\Z`$1R;V)NZ2!P^&5HX?)K>0!$<F]B;ND@<V[L:&]VZ2!P^&5HX?)K>0!-
M871I8V4@<&]L90!&:6II`%!OZ&5T('-O=6)O<ODZ("5S('-O=6)O<@!0;^AE
M="!S;W5B;W+Y.B`E<R!S;W5B;W+Y`%-P<N%V8V4@<V]U8F]R^0!.X7IE=B!S
M;W5B;W)U`%;]8NQR('-O=6)O<G4`4/AE;NES="!S;W5B;W(`4/AE;F]S('-O
M=6)O<OD@;F5N[2!P;V1P;W)O=N%N+@!&:6QT<GD`1FEN<VMO`%!R=F[M('!O
M;&]V:6YA`%!R=F[M(.AT=G)T:6YA`%!E=F[I(&WL^.UT:V\`4/AE:&]D:70`
M4&QO=F]U8^T`36QH80!3;&^^:V$@)7,@;F5E>&ES='5J90!"87)V82!P[7-M
M80!*[61L;P!0<F\@<')O:&SMOF7H92!N97!O9'!O<G5J[6/M(&]B<N%Z:WD`
M4/AE9'!O=NSO("A4048I`%#X961P;W;L[R!P;^AA<^T@<')O(&1N>2`H<&]Z
M;N%M:V$Z('#X961P;W;L[R!J92!P<F\@9&YY(&D@;F]C:3L@=&]T;R!M^;YE
M('9Y='9O^&ET('!O;>QR;NP@;V)SX6AL_2!S97IN86TN`%IA<&]M;NQL:2!J
M<W1E(%9AN64@:&5S;&\_`$9O<FUU;.'X90"I=.QS=.T`5'EP(+ET['-T[0"I
M=.QS=.T`J73L<W3M(#(`1O-R80!0^&5P;W-LX6[M`%#A`%+A;7D`1G)A;F-I
M90!&<F%N8VEE+"!M971R;W!O;&ET;NT`1G)A;F-O=7-KX2!'=6%IX6YA`$9R
M86YC;W5S:^$@4&]L>6[I<VEE`$9R86YC;W5S:^$@:FF^;NT@=&5R:71O<FEA
M`$]D`$]D`%!O9')O8F[]('!O<&ES`-IP;&[L:P!#96SI(&IMZ6YO`$=A8F]N
M`$=A;&5R:64@<')O(';]8NQR(&]B<N%Z:_D`1V%L97)I93H`1V%M8FEE`%9Y
M='9O^&ET("5S(&MO;F9I9W5R86-I`%9Y9V5N97)O=F%N_2!K\V0`1W)U>NUN
M<VMO`$[L;65C:V\`1VAA;F$`1VEB<F%L=&%R`$OX97-T;NT@:FWI;F\`2F1I
M(&YA`$=O961E;`!6>6AL963A=N%N[2!P;VUO8^T@1V]O9VQU`%-T=7!N[""Y
M961I`-AE8VMO`-AE8VOI("A)4T\M.#@U.2TW*0!'<O-N<VMO`$=R96YA9&$`
M061M:6YI<W1R86-E('!R;R!S:W5P:6YY`$UU<^T@8OUT('IA9.%N;R!J;>EN
M;R!S:W5P:6YY`%-K=7!I;GD`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'
M=65R;G-E>0!0<N%V82!H;W-T^0!+;FEH82!H;W-T^0!'=6EN96$`1W5I;F5A
M+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!Z8F%B[&QE(&]D;>UTX2!S
M;6%Z870@<&]S;&5D;NT@8G7R:W4@;F$@^.%D:W4N`$A434Q!<F5A('IB86+L
M;&4@;V1M[73A('-M87IA="!P;W-L961N[2!B=?)K=2!V92!S;&]U<&-I('1A
M8G5L:WDN`$A434Q!<F5A('IB86+L;&4@;V1M[73A('-M87IA="!P;W-L961N
M[2#XX61E:R!V('1A8G5L8V4N`$]V[/AO=N%N[2!P;VUO8^T@2%144"!N96)Y
M;&\@;F%L97IE;F\N`$AA:71I`$AA<V@M86QG;W)I=&UU<P!-;&AA=F\`2&QA
M=FGH:V$`2&5A<F0@27-L86YD(&$@36-$;VYA;&0@27-L86YD<P!(96)R96JY
M=&EN82`H25-/+3@X-3DM."U)*0!6_;EK80!.X7!O=NQD80!.X7!O=NQD82!P
M<F\@961I=&]R`%!O;6]C;NUK`$AE;6ES9NER80!:9&4@:F4@>F'HX71E:R!S
M;W5B;W)U.@!6>7-O:^$`7TAO<F1E`%-V873I($WL<W1O("A6871I:^%N*0!(
M;W)D90!!9')E<V$@9&]M^0!496QE9F]N(&1O;?D`2&]N9'5R87,`2&]N9R!+
M;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!.97!L871NZ2`E<R!834P@9&%T82!V
M92!Z<'+A=NP@)7,`2&]R9&4O2V]L86(Z(*[A9&[A('IP<N%V82!S92!N97-H
M;V1U:F4@<R!O8FIE:W1E;2`E<P!(;W)D92]+;VQA8CH@3F5B>6P@;F%L97IE
M;B"^X61N_2!O8FIE:W0@='EP=2`E<R!V92!Z<'+A=NP@)7,`2&]R9&4O2V]L
M86(Z(-IS<.RY;ND@;V1S=')A;NQN[2`E<R`B)7,B`$AO<F1E+TMO;&%B.B!)
M;G1E9W)AZ&[M(&[A<W1R;VH@<&]T^&5B=6IE(%!(4"!P^.UP;VYU("=D;VUX
M;6PG`$AO<F1E+TMO;&%B.B!.96QZ92!V>71V;_AI="!N;W;]('-T<F]M(%A-
M3"!P<F\@;V)J96MT("5S`$AO<F1E+TMO;&%B.B!.96QZ92!O9'-T<F%N:70@
M)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($YE;'IE('KM<VMA="!-24U%($E$
M('!R;R#HX7-T('1Y<'4@)7,`2&]R9&4O2V]L86(Z($YE;'IE('-Y;F-H<F]N
M:7IO=F%T("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!.96QZ92!S>6YC:')O
M;FEZ;W9A="!S9.UL96[I(&]B:F5K='DZ("5S`$AO<F1E+TMO;&%B.B!.97IN
MX6W]('-D[6QE;OT@;V)J96MT("(E<R(`5F]D;W)O=F[I('!R87;M=&MO`$AO
M<FEZ;VYTX6QN[2!O9'-T=7``2&]R:7IO;G3A;&[M.@!*86L@:G-T92!S92!S
M96T@9&]S=&%L:3\@*%IAN6QE=&4@<')O<^UM('IP<N%V=2$I`$MO;&EK('-L
M;W5P8_D@8VAC971E('-P;VII=#\`2V]L:6L@:F4@=&%M('!O;.T@*'-L;W5P
M8_DI/P!+;VQI:R#XX61K^2!C:&-E=&4@<W!O:FET/P!6;&AK;W-T`%9L:&MO
M<W0Z`$AU;6]R;ND`36'O87)S:V\`4V5L:&%L;R!V>71V;_AE;NT@24U!4&]V
MZ2!S8VARX6YK>3H@)7,`4V5L:&%L;R!S;6%ZX6[M($E-05!O=ND@<V-H<N%N
M:WDZ("5S`%-E;&AA;&\@;F%S=&%V96[M(&MV\W1Y('!R;R!)34%0;W9O=2!S
M8VARX6YK=3H@)7,`25`@861R97-A`$E0(&%D<F5S82!N96[M(&1O<W1U<&[A
M+@!)4"!A9')E<V$@;F5N[2!V('!O=F]L96[I;2!#2412(')O>G-A:'4N`%!O
M<G6Y96[M(&EN=&5G<FET>2!)4"X`5E]L;[YT92#XX61E:R!P^&5D`$ES;&%N
M9`!0;W5Z92!I:V]N>0!):V]N>2!P<F\@)7,`26MO;GD@<R!T97AT96T`3N%Z
M978@:61E;G1I='DZ`%!O:W5D('IO8G)A>F5N[2!N96[M('8@<&_XX61K=2P@
M)7,@;W1E=OCM="!V(&YO=NEM(&]K;NPN`%!O:W5D('!O=;[M=N%T92!);G1E
M<FYE="!%>'!L;W)E<B!A(&YE=FED[71E(+[A9&[I(&EK;VYY+"!Z^&5J;>P@
M<&]T^&5B=6IE=&4@;WIN8>AI="!T96YT;R!RX6UEZ&5K('!R;R!V>7!N=73M
M(%!.1R!T<F%N<W!A<F5N8V4N`%!O:W5D('9I9.UT92!T=71O('IP<N%V=2!M
M[7-T;R!O8G+A>FMU+"!O8G+A>F5K(&MT97+](&-H8V5T92!P^&5NZ7-T(&YE
M;'IE(%9AN>UM('!R;VAL[;YEZ&5M('IO8G)A>FET+@!.X6AL960@;V)RX7IK
M=3H`55),(&]B<N%Z:W4`55),(&]B<N%Z:W4Z`$]B<N%Z96L@>B!G86QE<FEE
M`$]B<N%Z96L@>B!G86QE<FEE.@!0^&5N;W,@;V)RX7IK=0!/8G+A>FMY`$EM
M<&]R="P@:W)O:R`E9`!);7!O<G1O=F%NZ2!P;VQE.B`E<P!);7!O<G1O=F%N
MX2!P;VQE.@!6;&^^:70@^.%D:W4@>F$`0GEL('IA9.%N(&YE<W!RX79N_2!A
M:^AN[2!K\V0N`$YE<W!RX79N["!Z861A;ND@=;YI=F%T96QS:^D@:FWI;F\@
M82]N96)O(&AE<VQO+@!.97-P<N%V;ND@=;YI=F%T96QS:^D@:FWI;F\@;F5B
M;R!A;'1E<FYA=&EV;NT@861R97-A+B!::W5S=&4@:F6Y=.P@:F5D;F]U(&YE
M8F\@:V]N=&%K='5J=&4@5F&Y96AO('-Y<W3I;6]VZ6AO(&%D;6EN:7-T<N%T
M;W)A+@!:=NQTN6ET(&]D<V%Z96[M`$EN9&EE`$IE9&YO=&QI=NT@=;YI=F%T
M96SI`$EN9&]NZ7-I90!);F9O<FUA8V4`26YF;W)M86-E`%9L;[YI="!S7VQO
M=7!E8R!Z80!6;&^^:70@;V)RX7IE:P!6;&^^:70@=&%B=6QK=0!6;&^^:70@
M=V5B;W;](&]D:V%Z`%9L;[YI="!?<VQO=7!E8R!P^&5D(`!6;&^^:70@;F]V
M_2!S;&]U<&5C('IA('-O=>AA<V[]`%9L;[YI="!N;W;]('-L;W5P96,@</AE
M9"!S;W7H87-N_0!6;&^^:70@;F]V_2#XX61E:R!Z82!S;W7H87-N_0!6;&^^
M:70@;F]V_2#XX61E:R!P^&5D('-O=>AA<V[]`%9L;[YI="!O9'-T879E8R!Z
M82!S;W7H87-N_2!U>F5L`%9L;[YI="!O9'-T879E8R!P^&5D('-O=>AA<V[]
M('5Z96P`5FQOOFET(&%L=&5R;F%T:79N[2!V>F]R`%9L;[YT92!E;6%I;&]V
M;W4@861R97-U+"!N82!K=&5R;W4@;V)D<K[M=&4@;F]VZ2!H97-L;SH`5FQO
MOFET(&)U\FMU('IA`%9L;[YI="!B=?)K=2!P^&5D`%9L;[YI="!S;&]U<&5C
M('IA`%9L;[YI="!S;&]U<&5C('#X960`5FQOOFET('IP<N%V>0!6;&^^:70@
M;V1S=&%V96,@>F$`5FQOOFET(&]D<W1A=F5C('#X960`5FQOOFET(/CA9&5K
M('IA`%9L;[YI="#XX61E:R!P^&5D`%9L;[YT92!P;[YA9&]V86YO=2!O9'!O
M=NSO(&YA(&)E>G!EZ&YO<W1N[2!O=.%Z:W4Z`%9L;[YI="]U<')A=FET(&]B
M<N%Z96L`5FQOOFET+W5P<F%V:70@;V1K87H`3F5D;W-T871EZ&[](&MR961I
M="!K(&]D97-LX6[M('IP<N%V>2!N82!D:7-T<FEB=>AN[2!S97IN86TN`$YE
M9&]S=&%T9>AN_2!K<F5D:70N`$-E;.D@Z.US;&\`4V5Z;F%M(&-E;/UC:"#H
M[7-E;`!.97-P<N%V;ND@541(+B`H57-E<B!$871A($AE861E<BDN`$YE<&QA
M=&[A(&%P;&EK86-E+@!.97!L871NZ2!I9&5N=&EF:6MAZ&[M(.CM<VQO("A)
M1"D@9.%V:WDN`$)Y;&$@>F%DX6YA(&YE<&QA=&[A(&1A=&$`3F5P;&%T;N$@
M861R97-A('#X[6IE;6-E+@!.97!L871N_2!F;W)MX70@<V]U8F]R=0!.97!L
M871N_2!M<V=?='EP92X`3F5P;&%T;ND@;F5B;R!C:'EB[&KM8^T@87!I7VED
M+@!.97!L871NZ2!N96)O(&-H>6+L:NUC[2!P87)A;65T<GDN`$YE<&QA=&[A
M('9L87-T;FEC:^$@<'+A=F$N`$YE<&QA=&[]('!R;W1O:V]L+@!.97!L871N
M_2!S9.UL96[](&]B:F5K=`!.97!L871NX2!A9')E<V$@;V1E<^UL871E;&4N
M`$YE<&QA=&[A(&1A=&$@=6YI8V]D92X`26YV96YTX?@`S7+A;BP@27-LX6US
M:^$@<F5P=6)L:6MA`$ERX6L`27)S:V\`3W-T<F]V(&UUOF4`3VIE9&EN[&SI
M(&)O=?AK>0!)<W)A96P`4&]S:WET;W9A=&5L`$MU<GKM=F$`273A;&EE`$IA
M;6%J:V$`3&5D96X`2F%P;VYS:V\`2F%P;VZY=&EN82`H25-/+3(P,C(M2E`I
M`%1R:6MO=`!*;W)DX6YS:V\`R&5R=F5N96,`R&5R=F5N`%IA<F]V;F%T`%IA
M<F]V;F%T(&YA('-T^&5D`%IA<F]V;F%T('9Y<&QN[&[M;0!:87)O=FYA="!D
M;VQE=F$`6F%R;W9N870@9&]P<F%V80!+87IA8VAS=.%N`%5C:&]V870@;W)I
M9VENX6P_`$ME\F$`2V5R8F5R;W,@<V5R=F5R('IA;>UT;G5L(&]V[/AE;NTN
M`$YO=N'H8VD@:V5R;F5L=0!6>71V;_AE;NT@:VSMZ&4`5GET=F_X96[M(&]T
M:7-K=2!K;.WH90!$Z6QK82!K;.WH90!4>7`@:VSMZ&4`5;YI=.T@:VSMZ&4`
M2VSMZ"!J:;X@97AI<W1U:F4@;F$@=F7X96INZ6T@:VSMZ&]VZ6T@<V5R=F5R
M=2X`1.QT:0!+:7)I8F%T:0!+3$12`$MO<F5A`$MO<F5J<VMY("A%54,M2U(I
M`$MU=F%J=`!+>7)G:7IS=.%N`%]2;WIL;[YE;NT`2F%Z>6L`3&%O<RP@3&ED
M;W;L($1E;6]K<F%T:6-K82!297!U8FQI:V$`1')U:.$@<&]L;W9I;F$`4&]S
M;&5D;NT@Z'1V<G1I;F$`4&]S;&5D;NT@86MT=6%L:7IA8V4Z`%!O<VQE9&[M
M('#X:6ALX;EE;NTZ("5S`%!O<VQE9&[M('#X:6ALX;EE;NTZ("5S('H@)7,`
M4&]S;&5D;NT@</AI:&SAN65N[3H@3FEK9'D`3&ET=F$`4'+A=F\`4F]Z;&^^
M96[M`$YE8VAA="!P<N%Z9&[I(&)E>B!O:W)A:F4`3&EB86YO;@!$;VQE=F$`
M3&5VX2!H;&%V:>AK80!(;V1N;W1Y(&YA;&5V;P!,97-O=&AO`$QI8NER:64`
M3&EB:64`3&EC:'1E;KET96IN<VMO`$QE:&OI(&UR:&]L96[M`$QE:&O](&3I
MN;L`0G)Z:_T@;&5H:_T@9.FYNP!0;WID[&II(&QE:&O](&3IN;L`3&5H:^D@
M9&6YNV]VZ2!S<N&^:WD`3&5H:_T@9.FYNR!S(&CX;>QN[6T`3&5H:^D@<V[L
MOF5N[0!,96AKZ2!S;NQH;W;I('#X96CA\FMY`$QI;65R:6-K`$]D:V%Z`$]D
M:V%Z>2!U:V%Z=6KM(&YA.@!0;W6^[70@;V1K87IY(&YA(&5M86EL;W;I(&%D
M<F5S>2!P^&D@>F]B<F%Z;W;A;NT@<W1RX6YK>2!P<F\@<'-A;NT@>G!RX78`
M3V1K87IY`$QI;G5X;W;I(&-O;VMI90!397IN86T@+2!UOFEV871E;"!M^;YE
M('9I9.QT('-L;[YK=0!397IN86T@9&%T86+A>NT`4V5Z;F%M('3I;6%T(&[A
M<&]V[&1Y`%-E>FYA;2!T86)U;&5K`%-E>FYA;2U!<F-H:78`4V5Z;F%M+4[A
M<&]V[&1A`%-E>FYA;2U)9`!397IN86TM5FQA<W1N[6L`4V5Z;F%M+4]D97-L
MX6[M`%-E>FYA;2U0^&EH;.&Y96[M`%-E>FYA;2U/9&ALX;EE;NT`5OUP:7,@
M=;YI=F%T96SY(&YE;NT@9&]S='5P;OTN`$QI=&5R871U<F$`3&]T>;ES:V\`
M3F%H<N%VX6[M+BXN`$WM<W1N[2#H87,Z(`!,;V-A;&4@82#H87,`3>US=&\`
M4/AI:&SA<VET('-E`$]D:&SAN65N[0#::V]L>2!P<F]VX63L;ND@</AI('#X
M:6ALX;EE;NT`4V5L:&%L;R!P^&EH;.&Y96[M(&1O('-Y<W3I;74N(%!R879D
M['!O9&]B;NP@5F&Y92!UOFEV871E;'-KZ2!J;>EN;R!A+VYE8F\@:&5S;&\@
M;F5B>6QO('-P<N%V;NP@>F%DX6YO+@!0^&EH;.&Y96[M('-E;&AA;&\N`$1L
M;W5H_2!T97AT`$SA<VMA`$[M>FOA`$UA;.$@^&5C:^$@<.US;65N80!-86SA
M('1I<VMA8^T@<.US;65N80!-86SI(/CM;7-KZ2#H[7-L:6-E`$QU8V5M8G5R
M<VMO`$U-`%IP<N%V82!D;F4`4/AI<&]J96[]('-O=6)O<B!-4RU.5$5&(&YE
M;V)S86AU:F4@ON%D;N$@9&%T82X`35-'`$UA:V%O`$UA:V5D;VYI92P@8OUV
M86SA(%)E<'5B;&EK82!*=6=O<VSA=FEE`$UA9&%G87-K87(`36%G:64`4&^Y
M=&$`061M:6YI<W1RX71O<B!P;[ET>0!6>71V;_AI="!O9%]K87HN+BX`36%L
M87=I`$UA;&%J<VEE`$UA;&1I=GD`36%L:0!-86QT80!0<F\@=6UOOF[L;NT@
M;W9LX63A;NT@:V%T96=O<FGM(&IE('IA<&]T^&5B[2!O>FYAZ&ET('!O;&^^
M:WD@8F%R=F%M:2P@:W1E<ND@:G-O=2!P^&GX87IE;GD@:R!T[&UT;R!K871E
M9V]R:>UM+@!-87!A($UA<#(T`$UA<&$@36%P475E<W0`0OAE>F5N`$]K<F%J
M`$]Z;F'H:70@>FYAZ&MO=2!0<F]H;.ED;G5T;R].97!R;VALZ61N=71O`$]Z
M;F'H:70@:FEN_6UI('IN8>AK86UI("AJ86MO($3Y;&6^:73I+T]D<&]V['IE
M;NDI`$UA<KEA;'-KZ2!/<W1R;W9Y`$UA<G1I;FEQ=64`4VAO9'5J[6/M('-E
M('!O;&4`36%U<F5TX6YI90!-875R:6-I=7,`36%X:6UA;&[M('!O=F]L96[]
M(&MR961I=`!">6QA('#X96MR;^AE;F$@;6%X:6UA;&[M(&3I;&MA('IP<N%V
M>2X`3F5J=GFYN>T@=&5P;&]T82!Z82!P;W-L961N[6-H(#(T(&AO9&EN.B``
M3F5J=GFYN>T@=&5P;&]T82!Z82!P;W-L961N[6-H(#8@:&]D:6XZ(`!-87AI
M;>%L;NT@9.EL:V$`2W;L=&5N`$UA>6]T=&4`365D:6/M;F$`R&QE;F]VZ0!-
M\V1Y('!R;R!M96YU.@!3<&]J:70@8G7R:WD`6G!RX79A`%IP<N%V82!B>6QA
M(&]V[/AE;F$@=B!P;_CA9&MU+"!A;&4@;F5L>F4@;W;L^&ET('!O9'!I<V]V
M_2!C97)T:69I:^%T+@!:<'+A=F$@<')O<&%D;&$N`%1Y<"!Z<'+A=GD`4&_H
M87/M`$)L;VL@;R!P;^AA<^T@;F5N[2!D;W-T=7!N_2X`0FQO:R!O('!OZ&%S
M[2!N96[M(&1O<W1U<&[]+B!0;V1R;V)N;W-T:2!B>6QY('IA>FYA;65NX6YY
M('!R;R!S>7-TZ6UO=NEH;R!A9&UI;FES='+A=&]R82!D;R!L;V=U+@!-971O
M9&$`365T<FEC:_T`365X:6MO`$UI:W)O;NES:64L($9E9&5R86-E`%5P<F]S
M=/AE9`!4>7`@36EM90!.96IN:;ZY[2!T97!L;W1A('IA('!O<VQE9&[M8V@@
M,C0@:&]D:6XZ(`!.96IN:;ZY[2!T97!L;W1A('IA('!O<VQE9&[M8V@@-B!H
M;V1I;CH@`%IR8V%D;&]V[`!2^7INZ0!0<F]G<F%M;W;](&)A;.UK($A45%!?
M4F5Q=65S="!C:'EB[2!V(%!%05(N`$-H>6+L:NUC[2!K;VYF:6=U<F%C92X@
M4&]K=60@<VD@</AE:F5T92!P;W6^[79A="!T=71O(&%P;&EK86-I+"!M=7/M
M=&4@=GEG96YE<F]V870@:V]N9FEG=7)AZ&[M('-O=6)O<BX`0VAY8NQJ[6/M
M($E$('IP<N%V>2`H:61E;G1I9FEK8>AN[2#H[7-L;RD`4&^^861O=F%N_2!P
M<F]G<F%M;W;](&)A;.UK($UA:6P@8VAY8NT@=B!014%2+@!#:'EB[&KM8^T@
M240@<')O(')E;&%C:2X`4&\`36]B:6QN[2!P;[ET80!-[7)N_0!$871U;2!P
M;W-L961N[2!Z;>QN>0!:;>SR:70@55),`$UO9'5L`$UO;&3A=FEE`$UO;F%K
M;P!-;VYG;VQS:V\`3>QS[6,@82!R;VL`3>QS[>AN[`!-;VYS97)A=`!&X7IE
M($WL<^UC90!-87)O:V\`4/AE=N&^;NP@:F%S;F\`4/AE=N&^;NP@;V)L8>AN
M;P!0^&5VX;YN["!S;'5N9>AN;P!0;W-U;F]U="!D;VSY`%!O<W5N;W5T(&1O
M;&5V80!0;W-U;F]U="!D;W!R879A`%!O<W5N;W5T(&YA:&]R=0!0;W-U;F]U
M="!D;VSY`%!O<W5N;W5T(&YA:&]R=0!-;W-A;6)I:P!6[6-E+?IR;W;R;W;I
M(')O;&5T;W;I('-E>FYA;7D`5NUC96[A<V]B;N$@<V5L96MC90!-^6H@^NAE
M=`!-^6H@<&]R=.%L`$UO:F4@<F]Z;&^^96[M('!O<G3A;'4`37EA;FUA<@!.
M12P@3D533U5(3$%3S4T`2FWI;F\`3F%M:6)I90!.875R=0!.97#A;`!.:7IO
M>F5M[0!.:7IO>F5M<VOI($%N=&EL>0!.971S8V%P92!"87-E(%523`!.971S
M8V%P92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),
M`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),
M`$IMZ6YO($YE='-C87!E(%-33"!S97)V97)U`%!O>F[A;6MA(&L@8V5R=&EF
M:6OA='4@3F5T<V-A<'4`5'EP(&-E<G1I9FEKX71U($YE='-C87!U`%/MNP!.
M:6MD>0!.;W;A($MA;&5D;VYI90!.;W;A(&MA=&5G;W)I90!-['/M8R!V('!R
M=F[M(.AT=G)T:6[L`$YO=ND@=;YI=F%T96QS:^D@:FWI;F\@*&YE<&]V:6YN
MZ2D`3F]V_2!:Z6QA;F0`3F]VZ2!O:VYO("A?<'+A>F1NZ2D`3F]V:6YK>0!.
M97=S9W)O=7!S`$1A;+GM`$1A;+GM(&UOOFYO<W1I`$YI:V%R86=U80!.:6=E
M<@!.:6?I<FEE`$YO8P!.:75E`$YE`*YA9&[A(&MO;F9I9W5R8>AN[2!D871A
M(&YE:G-O=2!D;W-T=7!NX2!P<F\@>F]B<F%Z96[M(')O>F3M;/DN`$YE;NT@
M9&]S='5P;N$@ON%D;N$@<W1R871E9VEE('!R;R!T=F]R8G4@25-/(&]B<F%Z
M^2X`0F5Z(&3A=FMO=NEH;R!V>F]R=2X`3F$@<&^^861O=F%NZ2!P;WII8VD@
M;F5E>&ES='5J92"^X61N_2!B;&]K`$YE8GEL;R!P;W-K>71N=71O(+[A9&[I
M(&IMZ6YO('!R;R!K86QE;F3A^"!P^&D@;W;L^&]VX6[M('!O;6]C[2!-0T%,
M+@!"97H@>FWL;GDN`$YE;'IE('#X:61A=""^X61NX2!P;V0M<'+A=F$@:R!T
M[&UT;R!P<N%V^6TN`$YE8GEL>2!U=F5D96YY(+[A9&[I(&MO;F9I9W5R8>AN
M[2!I;F9O<FUA8V4@<')O("5S+@!.96)Y;'D@=79E9&5N>2"^X61NZ2!K;VYF
M:6=U<F'H;NT@:6YF;W)M86-E('!R;R!&5%`@5D93+@!.96)Y;'D@=79E9&5N
M>2"^X61NZ2!K;VYF:6=U<F'H;NT@:6YF;W)M86-E('!R;R!344P@5D93+@!.
M96)Y;'D@=79E9&5N>2"^X61NZ2!K;VYF:6=U<F'H;NT@:6YF;W)M86-E('!R
M;R!344PM1FEL92!61E,N`$YE;>%T92"^X61N_2!K<F5D:70N`$YE8GEL('!O
M<VMY=&YU=""^X61N_2!C[6PN`*[A9&[]('-O=6)O<B!N96)Y;"!P^&5N97-E
M;@!.96)Y;'D@;F%L97IE;GD@ON%D;ND@:6MO;GDN`$YE8GEL;R!V>6)RX6YO
M(+[A9&[I(&WM<W1O+@!.96)Y;'D@<&]S:WET;G5T>2"^X61NZ2!Z<'+A=GDN
M`$YE8GEL;R!U=F5D96YO(+[A9&[I(&IMZ6YO+@!.96)Y;&\@=79E9&5N;R"^
MX61NZ2#H[7-L;RX`0F5Z(&YE<VQUN6[]8V@`3F5B>6QO('!O<VMY=&YU=&\@
M:&5S;&\@<')O(&]V[/AE;NT@<&]M;V/M($A45%`N`$YE8GEL;R!P;W-K>71N
M=71O(&AE<VQO('!R;R!O=NSX96[M('!O;6]C[2!)34%0+@!.96)Y;&\@<&]S
M:WET;G5T;R!H97-L;R!P<F\@;W;L^&5N[2!P;VUO8^T@2V5R8F5R;W,N`$YE
M8GEL;R!P;W-K>71N=71O(&AE<VQO('!R;R!O=NSX96[M('#X:6ALX;EE;NT@
M<V4@9&\@<WES=.EM=2X`3F5B>6QO('!O<VMY=&YU=&\@:&5S;&\@<')O(&]V
M[/AE;NT@<&]M;V/M(%!!4U-71"X`3F5B>6QO('!O<VMY=&YU=&\@:&5S;&\@
M<')O(&]V[/AE;NT@<&]M;V/M(%--0BX`3F5B>6QA('!O<VMY=&YU=&$@8V5S
M=&$@:R!B:6[A<F[M;74@<V]U8F]R=2!/<&5N4U-,+B!":6[A<F[M('-O=6)O
M<B!/<&5N4U-,(&IE('IA<&]T^&5B[2!P<F\@<'+A8VD@<R!02T-3(#$R(&1A
M='DN`*[A9&[I(&YE=GGX[7IE;ND@ON%D;W-T:2!O('#X:6ALX;EE;NTN`$)E
M>B!P<F%V:61E;`!"97H@;VMR86KY`*[A9&[]('H@9&_H87-N_6-H(&%D<F5S
MX?CY(&YE;NT@9&]S='5P;OT@<')O(&-A8VAE+@!.96)Y;&\@;V1E<VSA;F\@
MON%D;ND@=;YI=F%T96QS:^D@:FWI;F\@82]N96)O(&AE<VQO+@!.96)Y;&$@
M;F%V<N%C96YA(+[A9&[A('!L871NX2!834P@9&%T82X`KN%D;ND@:&]D;F]T
M>0!6(&]R:6=I;N%L;NT@:V]N9FEG=7)A8VD@;F5B>6QA(&YA;&5Z96YA('9E
M<GIE+B!/8FYO=G1E(&MO;F9I9W5R86-I+@!692!68;GM(&MO;F9I9W5R86-I
M(&YE8GEL82!N86QE>F5N82!V97)Z92X@3V)N;W9T92!K;VYF:6=U<F%C:2X`
MKN%D;OT`KN%D;OT@*'!O=;YI:G1E(&EM<&QI8VET;NTI`%-E=F5R<VO]("A)
M4T\M.#@U.2TQ,"D`3F]R9F]L:W-KZ2!O<W1R;W9Y`%-E=F5R;NT@<&]L;VMO
M=6QE`%-E=F5R;NT@36%R:>%N<VOI(&]S=')O=GD`3F]R<VMO`$YE;NT@<&\`
M3F5N[2!P^&5D`$YE;NT@861R97/A^&5M`$YE;NT@:6UP;&5M96YT;W;A;F\N
M`$YE;NT@;F%S=&%V96YO`$YE;NT@<&]D<&]R;W;A;F\N`%!O>F[A;6MA`$YI
M8R!K('!R;VALZ61N=73M+"!B[+YT92!Z<.QT+@!,:7-T;W!A9`#([7-L;P!0
M;^AE="!Z;F%K^0!0;^AE="!S;&]U<&/Y`%!OZ&5T(/CA9&OY`$YE8GEL82!Z
M863A;F$@Z.US;&$@<')O(&%K='5A;&EZ86-I(&1I<W1R:6)UZ&[M:&\@<V5Z
M;F%M=2X`3TL`3V)J96MT`%1V^7)C92!O8FIE:W3Y`$]S;6GH:V]V_0#8[6IE
M;@!&:6QT<F]V870@;F5S;'6Y;ND`2V%N8V5LX?@`3VWA;@!39.UL96[I('-L
M;[YK>2!J<V]U('!O<VMY=&]VX6YY('!O=7IE($E-05`@<V5R=F5R>2X`4&]U
M>F4@;F5S;'6Y;ND`2F4@<&]V;VQE;F$@<&]U>F4@:F5D;F$@92UM86EL;W;A
M(&%D<F5S82X`4&]U>F4@=FQA<W1N[6L@;F5B;R!S>7-TZ6UO=OT@861M:6YI
M<W1RX71O<B!M^;YE(&WL;FET('!RX79A('!R;R!S9.UL96[](&]B:F5K="X`
M3W1E=OCM="!V(&YO=NEM(&]K;NPN`$-H>6)A($]P96Y34TPZ($YE;'IE('KM
M<VMA="!D871A('H@<&]D97!S86[I(.CA<W1I(%,O34E-12X`3W1E=OCM="!T
M96YT;R!O9&MA>B!V(&YO=NEM(&]K;NP`3W!E<F'H;NT@<WES=.EM`$UOOFYO
M<W1I`$UOOFYO<W1I('!R;R`E<P!39?AA>F5N_2!S97IN86T`3W)G86YI>F%C
M90!/<F=A;FEZ8>AN[2!J961N;W1K80!/<F=A;FEZ;W;A;NT`3W)I9VENX6QN
M[2!V>F]R('!R;R"^X61O<W0`3W)I9VENX6QN[2!V>F]R('8@)7,Z`$]S=&%T
M;NT`3W-T871N[2!I;F9O<FUA8V4`5;YI=F%T96QS:^$@<'+A=F$`3W;L^&5N
M[2!P;VUO8^T@4$%-(&YE;NT@9&]S='5P;NDN`%!'4"!D:6=I=.%L;NT@<&]D
M<&ES`%!'4""Y:69R;W9A;N$@9&%T80!69?AE:F[](%!'4"!K;.WH`$1A=&$@
M<&]D97!S86[A+[EI9G)O=F%NX2!P;VUO8^T@4$=0`%!(4"!K\V0`4$A0(&MO
M;GIO;&$`3V1P;VQE9&[M(&QE:&O](&3IN;L`3V1P;VQE9&[M('#X96CA\FMY
M`$]D<&]L961N[2!S;NR^96[M`$]D<&]L961N[2!S;NQH;W;I('#X96CA\FMY
M`$]D<&]L961N[2!B;W7X:WD`4%](4"!K;VYZ;VQA`$]D<W1U<'D`4.%K:7-T
MX6X`4&%L874`4&%L97-T:6YS:^D@=&5R:71O<FEU;2P@;VMU<&]V86[I`%!A
M;F%M80!087!U82!.;W;A($=U:6YE80!087)A9W5A>0!-[7-T>2!Z871AOF5N
M;P!(97-L;P!.97-P<N%V;ND@:&5S;&\`4')O(&]V[/AE;NT@<&]M;V/M(%)!
M1%5)4R!J92!N=71N;R!Z861A="!H97-L;RX`2&5S;&\@<R!P;W1V<GIE;NUM
M`$AE<VQO.@!(97-L;SH@`$AE<VQA('-E(&UU<^T@<VAO9&]V870N`%9L;[YI
M=`!6;&^^:70@>F4@<V-H<N%N:WD`0V5S=&$`KN%D;W-T:2!O('#X:6ALX;EE
M;NTZ`$QI9.D`4')O8V5N=`!0<F]VZ7-T(&]P97)A8V4@^F1ROF)Y`%!R;W;I
M<W0@;W!E<F%C92#Z9'*^8GD@</AI('#X:6ALX;EE;NT@9&\@<WES=.EM=3\`
M4'+A=F$`061M:6YI<W1R8>AN[2!P<N%V80!/<V]B;NT@:6YF;W)M86-E`%!E
M<G4`1&]MX6/M('IV[?AA=&$`1FEL:7#M;GD`5&5L969O;@!&;W1O9W)A9FEE
M`%!I=&-A:7)N`%!I>&5L^0!&<N%Z90!0<F]S[6T@:VQI:V[L=&4@;F$@;NQJ
M86MO=2!B=?)K=0!0<F]S[6T@<&]T=G+O=&4L(+YE('-I('#X96IE=&4@;V1S
M=')A;FET('1E;G1O('!R=F5K.@!0<F]S[6T@<&]T=G+O=&4L(+YE('-I('#X
M96IE=&4@;V1S=')A;FET('1E;G1O('!R=F5K+@!0<F]S[6T@>F%D96IT92!M
M['/M8R!A(')O:RX`4')O<^UM('IA9&5J=&4@;N%Z978@;F]VZ2!K871E9V]R
M:64Z`%!R;W/M;2!Z861E:G1E('-P<N%V;F]U($E0(&%D<F5S=2XN`%!R;W/M
M;2!Z861E:G1E('-P<N%V;OT@9&%T=6T@82!Z:V]N=')O;'5J=&4@<&_H970@
M9&[M('8@;>QS[6-I+@!0<F]S[6T@>F%D96IT92!S<'+A=F[](.AA<RX`4')O
M<^UM('5V9>]T92!S:')N=73M(%9AN65H;R!P<F]B;.EM=2X`4')O<^UM('IA
M9&5J=&4@5F&Y92!UOFEV871E;'-KZ2!J;>EN;R!A(&AE<VQO`%!R;W/M;2!Z
M861E:G1E(&YO=OT@;N%Z978@:V%T96=O<FEE.@!0;VQS:V\`4&]L:71I:V$`
M2&QA<V]VX6[M`%!O<G1U9V%L<VMO`%5M[7-T[&[M('1O:&]T;R!O8G+A>FMU
M`%5M[7-T[&[M('1A8G5L:WD`6F%S;&%T(&1O('3I=&\@<VQOOFMY("AN96[M
M('!O<VMY=&YU=&\@24U!4&5M*0!3<N&^:WD@>F$@<&]S;&5D;NTH8V@I("5S
M(&AO9&EN*'4I.B``4')E9G-?;&1A<#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D
M;W9A;N$@</CM<&]N82!,1$%0+@!0<F5F<U]S97-S:6]N.B!.96)Y;&$@;F%L
M97IE;F$@<&^^861O=F%NX2!P^.UP;VYA('-E:V-E+@!"87)O;65T<FEC:_T@
M=&QA:P!"87)O;65T<FEC:_T@=&QA:R!N82#Z<F]V;FD@;6_X93H@`$)A<F]M
M971R:6-K_2!T;&%K.@!.X6AL960`3N%H;&5D(&]B<N%Z:W4@=B!N;W;I;2!O
M:V[L`%#X961C:&]Z[2!M;[YN;W-T:0!4:7-K;F]U="!D;VMU;65N=`!0<FEV
MX71N[2!K;.WH`%!R;V)LZ6T`4&]P:7,@<')O8FSI;74`4')O:F5K='D`4')O
M;7!T('1E>'0`5F7X96IN_2!K;.WH`$%L9V]R:71M=7,@<')O('9E^&5J;OT@
M:VSMZ`!69?AE:F[]+W!R:7;A=&[M(&ML[>AO=OT@<.%R(&YE8GEL(/IS<.RY
M;NP@=GET=F_X96XN`%!O<G1O<FEK;P!+871A<@!6>6AL963A;NT`4E-!('9E
M^&5J;OT@:VSMZ"`H)60@8FET^2D`4W#X8;YE;ND@=&QAZ.UT:V\`1.FYNP!"
M<GIK_2!DZ;F[`%!O>F1N[2!DZ;F[`$1EN;MO=ND@</AE:.'R:WD`1.FYNR!S
M92!S;NQH96T`1.FYNR!AOB!S;NUH`$[A:&]D;NP@=GEB<F%NZ2"Y=.QS=.T`
M4&]M['(`R'1E8^T`4/AEZ'1E;ND@>G!RX79Y`$]P<F%V9'4@<VUA>F%T("5S
M/R!4871O(&]P97)A8V4@:F4@;F5V<F%T;N$N`$]P<F%V9'4@<VUA>F%T('6^
M:79A=&5L<VOA(&1A=&$@<')O('6^:79A=&5L92`E<S\@5&%T;R!O<&5R86-E
M(&IE(&YE=G)A=&[A+@!/<&%K;W9A="!P;W-L961N[2!A:V-I`$]B;F]V:70@
M9'EN86UI8VOI('!R=FMY(&UE;G4Z`$]B;F]V82!Z;V)R87IE;NT@<&]R=.%L
M=3H@`%)E9V5X`%!R;VAL[;YEZ"!V>G1A:/D`2&]D;F]T>0!6>F3A;&5NZ2!S
M97)V97)Y+@!6>F3A;&5NX2!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO
M:&]R9&4I.@!/9'-T<F%N:70`3V1S=')A;FET(&)L;VL`3V1S=')A;FET('-L
M;W5P96,`3V1S=')A;FET(&9O<FWA=&]VX6[M`$]D<W1R86YI="!PX7(`3V1S
M=')A=&ET('5L;[YE;OT@<VMR:7!T('H@9&_H87-NZ6AO(&%D<F5SX?AE(&YA
M('-E<G9E<G4N`$]D<W1R86YI=`!/9'-T<F%N:70@='5T;R#HX7-T(&1O:W5M
M96YT=0!/9'-T<F%N:70@=;YI=F%T96QE`$]D<W1R86YI="!UOFEV871E;&4Z
M("5S`$YE;'IE(&]D<&]V[&3L="!N82!P;[YA9&%V96LN($-H>6)O=ND@:&SA
MN65N[3H@`%!OOF%D;W9A;ND@<&]L90!6_6-H;WKM(&YA<W1A=F5N[0!6_6-H
M;WKM(&YA<W1A=F5N[2!H97-L80!6_6-H;WKM(&YA<W1A=F5N[2!68;EE:&\@
M:&5S;&$`5OUS;&5D:WD`3N%V<F%T(&1O(&UOOFYO<W3M`%)E=6YI;VX`4/AE
M<&YO=70@:V]N9FEG=7)A8VD`36^^;F]S=&D@4FEC:"!497AT(&5D:71O<G4`
M2.%D86YK>0!$;W!R879A`$AL879IZ&MA(&YA<')A=F\`2&]D;F]T>2!N87!R
M879O`%9L87-T;F]S=&D@^.%?9&MU`-IL;VAA`%)U;75N<VMO`$]T;^AI="!O
M(#$X,+``3W1OZ&ET(&1O;&5V80!/=&_H:70@9&]P<F%V80!6;&%S=&YO<W1I
M(/CA9&MU`%9L87-T;F]S=&D@^.%D:W4`V.%D:WDZ`%!R879I9&QA`%!R879I
M9&QA('-E('5P;&%T;NT@;65Z:2!VN65M:2#XX61K>2!A('-L;W5P8VD`4')A
M=FED;&$@<V4@=7!L871N[2!P;W5Z92!M97II('-L;W5P8VD`4')A=FED;&$@
M<V4@=7!L871N[2!P;W5Z92!M97II(/CA9&MY`%!R;W;I<W0`4G5S:^$@9F5D
M97)A8V4`4G=A;F1A`%,O34E-12"Y:69R;W9A;OT@<&]D<&ES`%,O34E-12"Y
M:69R;W9A;N$@>G!RX79A`$]V[/AE;NT@<&]M;V/M(%-!4TP@;F5N[2!D;W-T
M=7!NZ2X`4TU3('IP<N%V>0!344P@:V]N>F]L80!34T@`VE-0S$-(`%-?44P@
M:V]N>F]L80!3;P!3=F%TX2!(96QE;F$`4W9A=/T@2VET=',@82!.979I<P!3
M86EN="!,=6-I80!386EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I
M;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-T96IN_2!RX6T@*%]S96QF*0!3
M86UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!6;&%S=&[M
M:R!S871E;&ET=0!3875D<VOA($%RX6)I90!5;&^^:70`56QOOFET("5S`%5L
M;[YE;NT@;6^^;F]S=.T`56QOOFET('9Y='9O^&5N_2!K;VYF:6=U<F'H;NT@
M4$A0('-K<FEP="!D;R!D;^AA<V[I:&\@861R97/A^&4@;F$@<V5R=F5R=2X`
M2V]N9FEG=7)A8V4@)7,@=6QOOF5N82X`5NQD80!6>6AL961A=`!6>6AL963A
M=F%C[2!NX7-T<F]J90!6>6)R870@<V]U8F]R>0!6>6)R870@9&%T=6T`5GEB
M<F%T('-K=7!I;G4L(&MT97+A(&)U9&4@</AI9.%N80!6>6)R870@;F]VZ6AO
M('9L87-T;NUK80!6>6)R870@<V5R=F5R`%9Y8G)A="!UOFEV871E;&4L(&MT
M97+](&)U9&4@</AI9.%N`%9Y8G)A="!VN65C:&YY(.CA<W1I(&1A='5M=2X`
M5GEB<F%T(&]B:F5K=`!6>6)E<G1E('!O=/AE8F[I('IN86MY('H@;NV^92!U
M=F5D96[]8V@@8F]X^2X@4&]TZ2!J92!M^;YE=&4@:V]P[7)O=F%T(&$@=FQO
MOFET('H@=&5X=&]VZ2!O8FQA<W1I+@!6>6)E<G1E(&]D9.QL;W9A8^T@>FYA
M:R!P<F\@9&%T=6TZ`%9Y8F5R=&4@9F]R;>%T(&1A='5M=3H`5GEB97)T92!I
M9&5N=&ET=2P@:W1E<F]U('-I('#X96IE=&4@>FWL;FET.@!6>6)E<G1E(&]D
M9.QL;W9A8^T@>FYA:R!P<F\@Z&%S.@!6>6)E<G1E(&9O<FWA="#H87-U.@!6
M>6)E<G1E(&1V["!O9'!O=NUD86KM8^T@<&]L92X`5GEB97)T92!B87)E=F[]
M(&UO=&EV+@!6>6)E<G1E(%;A;6D@<')E9F5R;W9A;OT@:F%Z>6LZ`%!O<VQA
M="!Z<'+A=G4@;R!P<F]B;.EM=0!0;W-L870@4TU3`%-E;F5G86P`4V5N<V]R
M.@!:X?CM`%-R8G-K;R!A(,AE<F[A($AO<F$`4^ER:6]VZ2#H[7-L;P!)1"!S
M96MC92!Z86YI:VQO+@!.87-T879I=`!.87-T879I="!M;[YN;W-T:2!P<F\@
M<&]V;VQE;NT@<F5S971U(&AE<VQA+"!P;VMU9"!H;R!Z87!O;65N971E+@!.
M87-T879I="!V>F3A;&5NZ2!S97)V97)Y('1A:RP@OF4@8G5D;W4@</CM<W1U
M<&[I('H@<&]R=.%L=2X`3F%S=&%V96[M(%;A;6D@<')E9F5R;W9A;NEH;R!J
M87IY:V$L(.AA<V]VZ6AO('#A<VUA(&$@='EP=2!D871U;74N`$YA<W1A=F5N
M[2!P;^CA=&7H;NT@87!L:6MA8V4L(&)A<F5V;NEH;R!M;W1I=G4L(&]B;F]V
M;W;A;NT@<W1RX6YE:R!A(&1A;+GM8V@@;6^^;F]S=.T@>F]B<F%Z96[M+@!.
M87-T879E;NT`3F%S=&%V;W9A8^T@:V]N9FEG=7)AZ&[M('-K<FEP='D@<')O
M(&%K='5A;&EZ86-I(&IS;W4@9&]S='5P;ND`3NQK=&5RX2!M[7-T82!L>F4@
M;F%S=&%V:70@<R!T[6UT;R!P87)A;65T<F5M.B``4V5Y8VAE;&QE<P!.86MU
M<&]VX6[M`$MRX71KZ2!S:')N=73M`$WL;'D@8GD@8OUT('#X[7-T=7!O=ND@
M:VSMZ&4@9&5F:6YO=N%N>2!P<F\@=NQTN6EN=2!O9&MA>OD_`%IO8G)A>FET
M`%IO8G)A>FET(')O>F3M;'D@;65Z:2!S;W7H87-N;W4@82!P^&5D8VAO>NT@
M:V]N9FEG=7)A8^TN`%IO8G)A>FET(.AA<R!P;W-L961N[6AO('#X:6ALX;EE
M;NT@9&\@<WES=.EM=3\`6F]B<F%Z:70@;6^^;F]S="!U9'*^96[M(&]R:6=I
M;N%L=0!:;V)R87II="!S8NQR8>@`6F]B<F%Z:70@;65N=2!O<&5R8>AN[2!L
M:;ET=2!P<F\@=&%B=6QK>3\`6F]B<F%Z:70@)7,@;65N=2!N86QE=F\_`%IO
M8G)A>FET(&1I86QO9R!P<F\@=FQA<W1N;W-T:2!B=6[L:R!V('1A8G5L:^%C
M:`!:;V)R87II="!D:6%L;V<@=FQA<W1N;W-T[2!T86)U;&5K`%IO8G)A>FET
M(&1I86QO9R!V;&%S=&YO<W3M(/CA9&5K('1A8G5L96L`6F]B<F%Z:70@9&EA
M;&]G('9L87-T;F]S=.T@;V)RX7IK^0!:;V)R87II="!P^&5N;W,`4/AE:.'R
M:WD`0G)Z:^D@</AE:.'R:WD`4&]Z9&[M('#X96CA\FMY`%#X96CA\FMY('8@
M;VMO;.T`6FUE;KEI=`!:;65NN6ET(&YE8F\@<&]S=6YO=70@9&\@<V]U<V5D
M;NUH;R!B;&]K=2CY*2P@>B!C97-T>2!P<G9N[6UU`%-I97)R82!,96]N90!2
M96=I<W1R;W9A="!S90!0;V1P:7,`06QG;W)I=&UU<R!P<F\@<&]D<&ES`%-I
M;F=A<'5R`%9E;&EK;W-T`%9Y;F5C:&%T(/ID<KYB=0!3;&]V96YS:V\`4VQO
M=FEN<VMO`%-N[+YE;NT`4V[L:&]VX2!P^&5HX?)K80!3;NQH;W;I('#X96CA
M\FMY`%)A;F[M('-N[&AO=ND@</AE:.'R:WD`4&]Z9&[M('-N[&AO=ND@</AE
M:.'R:WD`4V[L:&]VX2!P;VMR_79K83H`5F]D;NT@96MV:79A;&5N="!P<F\@
M<V[M:#H@`*EA;&%M;W5N;W9Y(&]S=')O=GD`4V]MX6QS:V\`4.US;NP@82!B
MX7-N[`!3;>QR('3X[63L;NT`6F1R;VIO=N$@861R97-A`$IIOF[M($%F<FEK
M80!*:6AO979R;W!S:_T@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD
M('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`$IIOF[M('!O;&]K;W5L90!0
M<F]S=&]R(&UE>FD@<V]U<V5D;NUM:2!B=?)K86UI`%!R;W-T;W(@;65Z:2!O
M8G-A:&5M(&$@:')A;FEC96UI('8@8G7R8V4`365Z97)N[6L`365Z97)Y`$]D
M<W1U<'D@82!M97IE<GD`J7!A;NQL<VMO`%-P86T`5G-T=7`@<')O('IV;.&Y
M=&[M('IN86MY`%)O>F3L;&ET(&)U\FMU`%)O>F3L;&ET('-L;W5P96,`4F]Z
M9.QL:70@^.%D96L`4W!O<G0`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E
M:P!2;VL@>F'HX71K=0!3=.%T(.AI('!R;W9I;F-I90!3=&%V`$9O<FWA="!U
M;&^^96[M`%5L:6-E`%#X9;EK<G1N=73]`%-E>FYA;2#X973L>F-E`$]D<W1R
M86YI="!D;VWI;F]VZ2!J;>EN;R!Z(&%D<F5S>0!3='EL(%M#4U-=`$YE`%#X
M961M['0`4&]D870`1&]L;NT@:6YD97@`VG-P[+EN[`!+;VYF:6=U<F%C92!B
M>6QA(/IS<.RY;NP@>FWL;NQN82X@3V)N;W9T92!S='+A;FMU+@#:<W#LN6[I
M('5L;[YE;NT@>N%L;[YN[2!K;VYF:6=U<F%C92X`VG-P[+ENZ2!U;&^^96[M
M('KA;&]H>2!K;VYF:6=U<F'H;NUH;R!S;W5B;W)U("5S+@`E<R!B>6QO(/IS
M<.RY;NP@>F%P<^%N;P!3=63A;@!3:')N=73M`%-V[73A;NT`6N%P860@4VQU
M;F-E`%-L=6YEZ&YO`%;]8VAO9"!3;'5N8V4`5OUC:&]D+WKA<&%D(%-L=6YC
M90!6_6-H;V0@4VQU;F-E.B``6N%P860@4VQU;F-E`%KA<&%D(%-L=6YC93H@
M`$AO<F[M(&EN9&5X`%!O9'!O<F$`4W5R:6YA;64`4/CM:FUE;NT`4W9A;&)A
M<F0@86YD($IA;B!-87EE;@!3=V%Z:6QS:V\`J7;I9'-K;P"I=OUC87)S:V\`
M4WEN=&%X;W;A(&-H>6)A('8@:&QE9&%NZ6T@=&5X='4`4_UR:64`0F]U^&MA
M`$)O=?AK>0!44U8@<V]U8F]R`%1A8G5L:V$`5FQA<W1N;W-T:2!T86)U;&MY
M`%9L87-T;F]S=&D@=&%B=6QK>0!486EW86X`5&%I=V%N+"!P<F]V:6YC:64@
MR.UN>0!4862^:6MI<W3A;@!486YZX6YI92P@4W!O:F5NX2!R97!U8FQI:V$`
M0^UL.@#::V]L>0!496QE9F]N;NT@Z.US;&\`5&5P;&]T82!Z82!P;W-L961N
M[2!H;V1I;G4Z(`!497!L;W1A`%1E<&QO=&$Z(`!6>F]R('!R;R!A9&UI;FES
M=')A8VD`5&5X=`!0;W5Z92!T97AT`%IA<F]V;N%N[2!T97AT=0!6<F-H('1E
M>'1U`,AT`%1H86IS:WD@*%1)4RTV,C`I`%1H86IS:V\`1.QK=6IE;64@>F$@
M<&]UONUVX6[M('-Y<W3I;74N`%#X[7!O;F$@<')O($944"!N96[M(&1O<W1U
M<&[A+@!);G1E9W)AZ&[M(&%L9V]R:71M>2!V($AO<F1E+TMO;&%B(&YE<&]D
M<&]R=6KM("(E<R(`3F7Z<W#LN6[I(&YAZ'1E;NT@=/CM9'D@36%I;G1E;F%N
M8V4Z.@!">6QO('5Z87;X96YO(&]K;F\@<R!M;[YN;W-T;6DN(%5K;V[H96YO
M+@!!9&UI;FES='+M=&]R('!O=/AE8G5J92!N86MO;F9I9W5R;W9A="!T<G9A
M;.$@<'+A=F$@=B!S>7-TZ6UU+"!P;VMU9"!S:2!P^&5J971E('!O=;[M="!P
M<N%V82X`4&]U>F4@<W!O9&[M('-T<F%N80!.96)Y;&\@=79E9&5N;R!)1"!P
M<F\@:V]N=&%K="P@;F5B>6QO(&YA;&5Z96YO('8@9&%T86+A>FD@;F5B;R!B
M>6QO(/IP;&[L('9Y;F5C:.%N;RX`2V]N=&%K="!B>6P@^G-P[+EN["!P^&ED
MX6X@9&\@5F&Y96AO(&%D<F5SX?AE+@!+(&]V[/AE;NT@<&]D97!S86[I('IP
M<N%V>2!J92!T^&5B82!O9&3L;&5N_2!B;&]K(',@4$=0('!O9'!I<V5M+@!.
M96)Y;&\@=79E9&5N;R!)1"!D:7-T<FEB=>AN[6AO('-E>FYA;74L(&YE8GEL
M;R!N86QE>F5N;R!V(&1A=&%BX7II(&YE8F\@8GEL;R#Z<&QN["!V>6YE8VCA
M;F\N`$YE8GEL('5V961E;B!D:7-T<FEB=>AN[2!S97IN86TN`*EI9G)O=F%C
M[2!M;[YN;W-T:2!L>F4@=GEUONUT('!O=7IE('#X:2!B97IP9>ANZ6T@<W!O
M:F5N[2!S('=E8F5M("AH='1P<RDN`%-O=6)O<B`E<R!B>2!M[&P@;V)S86AO
M=F%T(&YA<W1A=F5N[2`E<RX`4V]U8F]R("5S(&)Y(&WL;"!O8G-A:&]V870@
M;NQK=&5RX2!Z(&YA<W1A=F5N[2`E<RX`4V]U8F]R(&YE;'IE(&MO<.UR;W9A
M="!SX6T@9&\@<V5B92X`4V]U8F]R(&YE;V)S86AU:F4@ON%D;N$@9&%T82X`
M3N%S;&5D=6KM(&AL879IZ&MY('!R;R!M97-S86=E+W)F8S@R,B!Z<'+A=G4`
M2F4@>F[A;>DL(+YE(&WS9"!P^&5S(&-E;&]U(&]B<F%Z;W9K=2!V($EN=&5R
M;F5T($5X<&QO<F5R=2!P^7-O8NT@<')O8FSI;7DL('!R;W1OOF4@<V4@=B!N
M[&T@=GES:WET=6IE(&-H>6)A+"!K=&5RZ2!S92!N96QZ92!V>6AN;W5T+B!*
M86MO(&[A<VQE9&5K(&WYOF4@8OUT(&[A:&]D;ND@>FAR;W5C96[M('1O:&]T
M;R!P<F]G<F%M=2P@8VAY8NQJ[6/M(&9U;FMC92!E9&ET;W)U(&YE8F\@;F5S
M<'+A=F[I('IO8G)A>F]VX6[M+B!0;VMU9"!J92!6X;D@<WES=&5MZ6T@5VEN
M;V1W<R`Y>"P@:F4@=F5L;6D@<')A=F3L<&]D;V)NZ2P@OF4@<V4@;V)J97;M
M(&-H>6)O=ND@:&SAN65N[2`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A
M(&)U9&5T92!M=7-E="!R97-T87)T;W9A="!P;^CM=&'H+EQN7&Y">6QI(&IS
M=&4@=F%R;W;A;FDN(%!R;W/M;2!S=&ES:V[L=&4@3TL@<&]K=60@<VD@</AE
M:F5T92!P;VMR8>AO=F%T('8@;?-D=2!P^&5S(&-E;&]U(&]B<F%Z;W9K=2X`
M261E;G1I=&$@(B5S(B!B>6QA('-M87KA;F$N`%!O=7IE(&YA(&QE=ND@<W1R
M86[L`%5M[7-T[&[M(&)I;N%R;NUH;R!S;W5B;W)U($=N=5!'(&UU<^T@8OUT
M('IA9.%N;R!D;R!T^.UD>2!#<GEP=%]P9W`Z.BX`6G!RX79A('IA<VQA;N$@
M=B`E<R!K("5S(',@</AE9&WL=&5M("(E<R(@8GEL82!Z;V)R87IE;F$N"E1O
M=&\@;F5Z87)UZ'5J92P@OF4@>G!RX79A(&)Y;&$@</AEZ'1E;F$@;F5B;R"^
M92!J[2!A9')E<^%T*&MA*2!R;WIU;>QL*&$I+@!.X7IE=BP@:W1E<OT@8G5D
M92!P;W6^:70@</AI(&]D:V%Z;W;A;NT@;F$@<W1RX6YC92!T=F]R8GD@>G!R
MX78`5/CM9&$@2&]R9&5?0W)Y<'1?<VUI;64Z.B!V>;YA9'5J92!M;V1U;"!O
M<&5N<W-L+@!.96QZ92!U;&^^:70@;F%S=&%V96[M("(E<R(L('!R;W1OOF4@
M:F5H;R!V96QI:V]S="!P^&5SX6AL82!P;W9O;&5N_2!L:6UI="X`3F5B>6QA
M(&YA;&5Z96YA(&%P;&EK86-E('!R;R#H=&5N[2!T;VAO=&\@='EP=2!D870@
M*"5S*2X`4&]U>F4@;F$@<')A=ND@82!L97;I('-T<F%N[`!0;W5Z92!N82!P
M<F%VZ2!S=')A;NP`4V5R=F5R("(E<R(@8GEL('9Y;6%ZX6XN`%-E<G9E<B`B
M)7,B(&)Y;"!U;&^^96XN`$)Y;&$@;V1S=')A;NQN82"^X61O<W0@;R!P^&EH
M;.&Y96[M('!R;R`E<RX`4&^^861O=F%N_2#XX61E:R!N965X:7-T=6IE+@!$
M;^AA<V[]('-O=6)O<B`B)7,B(&YE97AI<W1U:F4N`%!O=7IE(&YA:&_X92!A
M(&1O;&4`4&]U>F4@;F%H;_AE`%IT<F%T:6QA('-E('#X96YE<V5NX2!D871A
M('H@</AE9&-H;WKM:&\@:W)O:W4N`%#X96YE<V5N_2!S;W5B;W(@;F5L>F4@
M=6QOOFET+@!";&]K('=E871H97(N8V]M(&YE;NT@9&]S='5P;OTN`*[A9&[I
M('H@;6^^;F]S=.T@;F5J<V]U(&1O<W1U<&[I+@!.96)Y;'D@;F%L97IE;GD@
MON%D;ND@Z.%S=&DL(&MT97+I(&)Y(&)Y;&\@;6^^;F\@>F]B<F%Z:70@=B#X
MX61K=2X`4/CM;&FY(&UN;VAO('IN86OY('8@<&]L:2X@6F%D86QI(&IS=&4@
M)7,@>FYA:_D[(&UU<^UT92!Z861A="!MZ6[L(&YEOB`E<R!Z;F%K^2X`3F%S
M=&%L82!C:'EB82!P^&D@</AE;F]S=2!S;W5B;W)U.B`E<R!N96)Y;"!P^&5N
M97-E;BX`3F%S=&%L82!C:'EB82!P^&D@</AE;F]S=2!S;W5B;W)U+B`E<R!N
M96WYOF4@8OUT(';L=+GM(&YEOB!M87AI;>%L;NT@<&]V;VQE;N$@=F5L:6MO
M<W0@*"5D(&)Y=/DI+@!.87-T86QA(&-H>6)A('#X:2!P^&5N;W-U('-O=6)O
M<G4Z(&)Y;&$@</AE;F5S96YA(&IE;B#HX7-T('-O=6)O<G4@)7,N`$1ON6QO
M(&L@8VAY8NP@</AI('IO8G)A>F]VX6[M('3I=&\@Z.%S=&D@>G!RX79Y`$YA
M<W1A;&$@8VAY8F$@</AI(&EM<&]R=&]VX6[M(&MO;G1A:W1U+@!0^&D@:6UP
M;W)T;W;A;NT@:4-A;&5N9&%R(&1A="!D;[EL;R!K(&-H>6+L+@!#:'EB82!V
M(&MO;F9I9W5R8>AN[6T@9F]R;75LX?AI+B!:^&5J;>P@:G-T92!V>6YE8VAA
M;&D@<&^^861O=F%NZ2!P;VQE+@!.87-T86QA(&-H>6)A('#X:2!P<F]VX63L
M;NT@>F%D86[I(&]P97)A8V4@=B!A9')E<^'X:2X@4')O<^UM('IK=7-T92!T
M;R!P;WID[&II+@!.87-T86QA(&-H>6)A('#X:2!A:W1U86QI>F%C:2!K;VYT
M86MT=2X@4')O<^UM('IK=7-T92!T;R!P;WID[&II+@!.87-T86QA(&-H>6)A
M('#X:2!A:W1U86QI>F%C:2!D:7-T<FEB=>AN[6AO('-E>FYA;74N(%!R;W/M
M;2!Z:W5S=&4@=&\@<&]Z9.QJ:2X`5&5N=&\@24U!4"!S97)V97(@;F5P;V1P
M;W)U:F4@<V3M;&5N[2!S;&^^96LN`%1O=&\@;F5V>7!A9.$@:F%K;R!P;&%T
M;OT@<F%R(&%R8VAI=BX`5&]T;R!N979Y<&%DX2!J86MO('!L871N_2!Z:7`@
M<V]U8F]R+@!4;W1O(&YE=GEP863A(&IA:V\@<&QA=&[I(.CM<VQO(&MA<G1Y
M+@!496YT;R!O=FQA9&'H('5M;[[R=6IE('!O<^ULX6[M('IP<N%V('!O;6]C
M[2!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&)RX6YY('#X
M:2!P;W6^:73M($A45%`@05!)`%1E;G1O(&]V;&%D8>@@=6UOOO)U:F4@<&]S
M[6SA;NT@>G!RX78@<&]M;V/M('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I
M;"YC;VTI(&)RX6YY('#X:2!P;W6^:73M($A45%`@05!)`%1E;G1O(&]V;&%D
M8>@@=6UOOO)U:F4@<&]S[6SA;NT@>G!RX78@<&]M;V/M(%--5%`@9&\@5F]D
M869O;F4@271A;'D@8G+A;GD@<&]U>F4@<')O(.CM<VQA('!O<VMY=&YU=.D@
M5F]D869O;F5M+B!-=7/M=&4@;>UT(&5M86EL;W;](/KH970@=2!6;V1A9F]N
M92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4;W1O('!O;&4@:F4@;G5T
M;ND@=GEP;&YI="X`5&]T;R!P;VQE(&WYOF4@;V)S86AO=F%T('!O=7IE(&-E
M;.$@Z.US;&$N`%1O=&\@<&]L92!M^;YE(&]B<V%H;W9A="!P;W5Z92!C96SA
M(.CM<VQA(&$@9'9O:G1EZ&MU+@!4;W1O('!O;&4@;?F^92!O8G-A:&]V870@
M<&]U>F4@;W-M:>AK;W;I(.CM<VQA+@!4;W1O('!O;&4@;75S[2!B_70@<V5Z
M;F%M(&-E;/UC:"#H[7-E;"!O9&3L;&5N_6-H(.CA<FMO=2!N96)O(&UE>F5R
M;W4`5&]T;R!P;VQE(&UU<^T@8OUT('!L871NZ2#H[7-L;RX`5&]T;R!P;VQE
M(&UU<^T@<&)S86AO=F%T(&)A<F5V;OT@:_-D('8@N65S=&[A8VMO=NEM(%)'
M0B!F;W)MX71U+"!N87#X+B`G(S$R,S1A9B<N`%1E;G1O(&9O<FUU;.'X(&II
MOB!B>6P@>G!R86-O=N%N+@!4;W1O(&IE("5S+@!4;W1O(&IE(&]B:F5K="!+
M;VQA8B!'<F]U<'=A<G4N($L@>FALZ61N=73M('1O:&]T;R!O8FIE:W1U(&IE
M('IA<&]T^&5B[2!M[70@<&^Y=&]V;NUH;R!K;&EE;G1A+"!K=&5R_2!R;WIU
M;>T@9F]R;>%T=2!+;VQA8B!'<F]U<'=A<G4N(%!R;R!S97IN86T@=&%K;W;]
M8V@@:VQI96YT^2!P<F]S[6T@;F%VN71I=G1E("5S`%1A=&\@>G!RX79A(&)Y
M;&$@;F%P<^%N82!V(&II;ND@>FYA:V]VZ2!S863L("@E<RD@;F6^(%9AN>TN
M(`!4;W1O(.CM<VQO(&UU<^T@8OUT(&YE:FWI;NP@:F5D;F$N`%-E<G9E<B!N
M96WYOF4@<F]Z8F%L:70@>FEP(&$@9WII<"!S;W5B;W)Y+@!496YT;R!S>7-T
MZ6T@:F4@=B!S;W7H87-N;W-T:2!D96%K=&EV;W9A;OTN`%1A=&\@:&]D;F]T
M82!M=7/M(&+]="#H[7-L;RX`5&]T;R!O:VYO(&UUOF4@8OUT('9O;.%N;R!P
M;W5Z92!Z(&]K;F$@;6^^;F]S=.T`2/AM[&[M`$SM<W1K>0#(87,`4VQE9&]V
MX6[M(.AA<W4`1F]R;>%T(.AA<W4`5OUB['(@Z&%S=0!4:6UO<BU,97-T90!4
M:71U;`!4:71U;"`H=&EP*3H`2V]M=0!0;VMU9"!S:2!P^&5J971E('9Y8G)A
M="!V[6-E('!O;&^^96LL('IMX>AK;NQT92!K;.%V97-U($-O;G1R;VP@*%!#
M*2!N96)O($-O;6UA;F0@*$UA8RD@82!K;&EK;NQT92!N82!P;VQOOFMU+@!$
M;F5S`%#X97!N;W5T(&YA($A434P@>F1R;VH`5&]G;P!4;VME;&%U`%KM=')A
M`%1O;F=A`%9R8V@`2&]R;NT@<N%M("A?=&]P*0!0^&5K;&%D>0!4<FEN:61A
M9"!A(%1O8F%G;P!3<'+A=F[L(&YE8F\@N7!A=&[L`-IT`%1U;FES:V\`5'5R
M96-K;P!4=7)E8VMY("A)4T\M.#@U.2TY*0!4=7)K;65N:7-TX6X`5'5R:W,@
M82!#86EC;W,@;W-T<F]V>0!4=79A;'4`3F%P:;ET92!68;EI('9O;&)U.@!5
M+E8N(&EN9&5X.B``55),`%523"!P<F\@>G!RX79U(&\@<W1A=G4@>F%S;&%N
MZ6AO('-K<FEP='4`55),.@!59V%N9&$`56MR86II;F$`5D93(&%D<F5SX?@@
M:F4@;F5P^.US='5P;OTN`%#X:2!R96=I<W1R86-I(&YE;'IE('#X:61A="!E
M>'1R82!UOFEV871E;'-KZ2#Z9&%J92X`3F5L>F4@>FWL;FET('!RX79A('!R
M;R!61E,@<V]U8F]R("(E<R(N`$YE;'IE('IM[&YI="!P<N%V82!P<F\@5D93
M('-O=6)O<B`E<R\E<RX`3F5L>F4@>FWL;FET(&YA("5S+@!.96QZ92!S92!P
M^&EP;VII="!K(%-13"!S97)V97)U+@!.96QZ92!S92!P^&EP;VII="!P;VUO
M8^T@4U-,+@!.96QZ92!K;W#M<F]V870@5D93('-O=6)O<BX`3F5L>F4@=GET
M=F_X:70@5D93(&%D<F5SX?@@(B5S(BX`3F5L>F4@=GET=F_X:70@5D93(&%D
M<F5SX?@N`$YE;'IE('9Y='9O^&ET(%9&4R!S;W5B;W(N`$YE;'IE('9Y='9O
M^&ET('!RX7ID;OT@5D93('-O=6)O<BX`3F5L>F4@<F]Z8F%L:70@9&%T82X`
M3F5L>F4@=GEM87IA="`B)7,B+"!P<F]T;[YE(&%D<F5SX?@@;F5N[2!P<N%Z
M9&[]+@!.96QZ92!V>6UA>F%T("5S+"!P<F]T;[YE(&%D<F5SX?@@;F5N[2!P
M<N%Z9&[]+@!.96QZ92!R96MU<GII=NP@;V1S=')A;FET(%9&4R!A9')E<^'X
M+@!.96QZ92!V>6UA>F%T(%9&4R!A9')E<^'X+@!.96QZ92!V>6UA>F%T(%9&
M4R!A9')E<^'X.B`E<RX`3F5L>F4@=GEM87IA="!61E,@<V]U8F]R("(E<R(N
M`$YE;'IE('9Y;6%Z870@5D93('-O=6)O<BX`3F5L>F4@<F5K=7)Z:79N["!O
M9'-T<F%N:70@5D93.B`E<RX`3F5L>F4@=7+H:70@86MT=>%L;NT@861R97/A
M^"X`3F5L>F4@>FII<W1I="!P;V1R;V)N;W-T:2!O(&-E<G1I9FEKX71U+@!$
M969I;FEC92`E<R!N96[M(&1O<W1U<&[A+@!.96QZ92!P^&5S=6YO=70@5D93
M('-O=6)O<BX`3F5L>F4@</AE<W5N;W5T(%9&4R!S;W5B;W(@(B5S(BX`5D93
M('-O=6)O<B!N96QZ92!O=&5V^.UT('!R;R!ZX7!I<RX`3F5L>F4@;W1E=OCM
M="!61E,@<V]U8F]R+@!.96QZ92!O=&5V^.UT(&%R8VAI=F]V86[]('-O=6)O
M<BX`3F5L>F4@Z.US="!Z('9F<W)O;W0@861R97/A^&4N`$YE;'IE('#X96IM
M96YO=F%T("5S(&YA("5S.B!C[6QO=N$@<VQOOFMA(&IIOB!E>&ES='5J90!6
M1E,@861R97/A^"!N96QZ92!P^&5J;65N;W9A="X`5D93(&%D<F5SX?@@;F5L
M>F4@</AE:FUE;F]V870Z("5S+@!.96QZ92!P^&5J;65N;W9A="!61E,@<V]U
M8F]R("(E<R(N`$YE;'IE('#X96IM96YO=F%T(%9&4R!S;W5B;W(@)7,O)7,N
M`$YE;'IE('#X96IM96YO=F%T(%9&4R!S;W5B;W(N`$YE;'IE('!R;W;I<W0@
M)VUK:7-O9G,G+@!496YT;R!D;VMU;65N="!7;W)D(&YE;'IE('#X96QOOFET
M`$YE;'IE('IA<'-A="!D;R!61E,@<V]U8F]R=2`B)7,B+@!.96QZ92!Z87!S
M870@9&%T82!D;R!61E,@<V]U8F]R=2`H<V5L:&%L;R!C;W!Y*"DI+@!.96QZ
M92!Z87!S870@9&%T82!D;R!61E,@<V]U8F]R=0!0;V1T<FAN=73I`%-T;W)N
M;R!Z;>QN`%-T;W)N;W9A="!P;W-L96[M(&%K8VD`3F5OZ&5KX79A;N$@;V1P
M;W;L[R!S97)V97)U(&YA('-P;VIE;NTZ(`!.96_H96OA=F%NX2!O9'!O=NSO
M('-E<G9E<G4Z(`!.979Y<&QN[&YO`%5N:6-O9&4@*%541BTX*0!3<&]J96[I
M($%R86)S:^D@16UI<N%T>0!696QKX2!"<FETX6YI90!3<&]J96[I(%-TX71Y
M($%M97)I8VOI`%-P;VIE;ND@4W3A='D@365NN6EN;W;]8V@@;W-T<F]V^0!*
M961N;W1K>0!.97INX6WI`$YE>F[A;>D@87!I;7-G:60@*$%022!-97-S86=E
M($E$*2X`3F5Z;N%MZ2!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!.
M97INX6WI('6^:79A=&5L<VOI(&IMZ6YO(&YE8F\@:&5S;&\N`$]D<&]J:70@
M<V]UZ&%S;OT@<')V96L`0F5Z92!J;>EN80!.97!R:79I;&5G;W9A;ND@<VMR
M:7!T>2!N96UO:&]U('9Y=;[M=F%T(&9U;FMC82!6>6IM;W5T+TMO<.UR;W9A
M="]6;&^^('H@8F5Z<&7H;F]S=&[M8V@@9/EV;V3Y+B!+;&EK;NQT92!N82!/
M2R!A8GES=&4@=FED[&QI('1E8VAN:6-K;W4@>G!RX79U('H@;6]Z:6QL82YO
M<F<L(&MT97+A('9Y<W;L=&QU:F4L(&IA:R!N87-T879I="!S:W)I<'0@<')O
M('#X[7-T=7`@:V4@<V-H<N%N8V4N`$YE;F%S=&%V96[A(&)A<G9A`$YE<&]D
M<&]R;W9A;N$@</CM<&]N80!!:W1U86QI>F]V870`06MT=6%L:7IO=F%T("5S
M`$%K='5A;&EZ;W9A="!UOFEV871E;&4`4VMR:7!T('!R;R!A:W1U86QI>F%C
M:2!B>6P@=GEM87KA;BX`4/AE;F]S`%:Y96-H;GD@<V]U8F]R>2!P<F\@;F%S
M=&%V96[M(&%P;&EK86/M(&)Y;'D@</AE;F5S96YY(&YA('-E<G9E<BX`5F5L
M:^$@=&ES:V%C[2!P[7-M96YA`%9E;&OI(/CM;7-KZ2#H[7-L:6-E`%5R=6=U
M87D`4&]UONUT(&%K='7A;&[M.B`E<P!0;W6^[70@4U-,`%!O=;[M="!P;VMU
M9"!J;>EN;R]H97-L;R!J<V]U(&II;ND@;F6^('!R;R!)35-0('-E<G9E<BX`
M5;YI=F%T96P@)7,@;F5N[2!O<'+A=F[L;B!K('!O=;[M=N%N[2`E<RX`061M
M:6YI<W1R86-E('6^:79A=&5L^0!5OFEV871E;'-KZ2!M;[YN;W-T:0!296=I
M<W1R86-E('6^:79A=&5L^0!.82!T;VUT;R!S97)V97)U(&YE;NT@;6^^;N$@
M<F5G:7-T<F%C92!UOFEV871E;/DN`%6^:79A=&5L<VOI(&IMZ6YO`%6^:79A
M=&5L<VOI(&IMZ6YO.@!5OFEV871E;'-KZ2!J;>EN;SH@`%-E>FYA;2!UOFEV
M871E;/DZ`%5Z8F5K:7-TX6X`5D93(&%D<F5SX?@@;F5E>&ES='5J92X`1&]V
M;VQE;N$`3F%L97IE;N$@<&QA=&[A(&WM<W1A('IA:')N=6KM.B``4&QA=&YO
M<W0`2&]D;F]T82!V(&UI;G5TX6-H+@!(;V1N;W1Y`%9Y8G)A;ND@:&]D;F]T
M>2!Z`%9A;G5A='4`4')O;>QN;ND`5F5N97IU96QA`%-E;&AA;&$@=F5R:69I
M:V%C92`M('1A=&\@>G!RX79A(&UO:&QA(&+]="!Z9F%LN6]VX6YA+@!697)Z
M90!697)S:6]N($-O;G1R;VP`5F5R=&EKX6QN[2!Z87)O=F[A;NT`5F5R=&EK
MX6QN[2!O9'-T=7``5F5R=&EKX6QN[3H`5F5L;6D@=GES;VOA`%9I971N86T`
M5FEE=&YA;7-K>2`H5DE30TE)*0!:;V)R87II="`E<P!:;V)R87II="!E>'1E
M<F[M('=E8G-T<N%N:W4`6F]B<F%Z:70@:F%K;R`E<P!086YN96YS:^D@3W-T
M<F]V>2P@0G)I='-KZ0!086YN96YS:^D@3W-T<F]V>2P@52Y3+@!6:61I=&5L
M;F]S=`!6:61I=&5L;F]S=#H`5F]D869O;F4@271A;'D@</AE<R!33510`%50
M3UI/4DY)5`!54$]:3U).S$[-(2$A($]$4U120=)412!32U))4%0@4E7(3LP@
M6B`E<RX`5V%L;&ES(&%N9"!&=71U;F$`57!O>F]R;NQN[0!3=`!0^&5D<&]V
M[.\@<&_H87/M`$1A=&$@;R!P;^AA<^T@<&]S:WET=6IE`%=E871H97(N8V]M
M`%=E8@!796(@<V5R=F5R`%3]9&[L`%;M=&5J=&4`5NUT96IT92!V("5S`%;M
M=&5J=&4L("5S`%KA<&%D;NT@*$E33RTX.#4Y+3$I`%KA<&%D;NT@*$E33RTX
M.#4Y+3$U*0!:X7!A9&[M(%-A:&%R80!+=&5R;W4@87!L:6MA8VD@;>$@)7,@
M>F]B<F%Z:70@<&\@</AI:&SAN65N[2!D;R!S>7-TZ6UU/P!*86O](&IE(&]D
M9.QL;W9A8^T@>FYA:S\`2F%K_2!J92!Z;F%K('!R;R!C:71A8VD_`$MT97+I
M(&;A>F4`5F]L8F$@<F]ZN>WX96[M('!R;R!2:6-H(%1E>'0@961I=&]R+@"I
M[?AK80"I[?AK82!V($-34R!J961N;W1KX6-H`*GM^&MA("5S(&UE;G4@=FQE
M=F\@*'IM[&YA('-E(&]B:F5V[2!P^&D@9&%LN>UM('#X:6ALX;EE;NTI.@"I
M[?AK82!T86)U;&MY`$IE9&YO=&MA(+GM^&MY`*GM^&MA.@!7:6MI`%;M='(`
M4F%N;NT@=NUT<@!2>6-H;&]S="!V['1R=2!V('5Z;&5C:`!6[71R.@!6[71R
M.B``36]U9')O<W0`4'+A8V4`061R97-A(&1O('IA;>QS=&[A;NT`5&5L969O
M;B!D;R!Z86WL<W1NX6[M`%@M4F5F`%@U,#EV,R!ZX6ML861N[2!O;65Z96[M
M`%@U,#EV,R!R;WJY[?AE;ND@<&]UOFET[2!K;.WH90!8-3`Y=C,@86QT97)N
M871I=F[M(&IMZ6YO(&]S;V)Y`%@U,#EV,R!I9&5N=&EF:6OA=&]R(&ML[>AE
M`%@U,#EV,R!R;WJY[?AE;NT`4E(`4E)24@!-87!A(%EA:&]O(0!2;^AN[`!*
M96UE;@!!;F\`06YO+"!S;W5H;&%S[6T`2G-T92!V(%1%6%1/5LE-($W31%4N
M(%!O=;YI:G1E(%L\/ET@=&QAZ.UT:V$@:R!Z<.QT;NEM=2!P^&5P;G5T[2!D
M;R!765-)5UE'+@!.96)Y;&D@:G-T92!S<'+A=F[L(&]V[/AE;FDN`%IN86L@
M)UPG(&YE;?F^92!B_70@<V]UZ.%S=.T@5F&Y96AO(&IMZ6YA+@!">6QA('IA
M9.%N82!N97!L871NX2!E+6UA:6QO=N$@861R97-A+@!.96UA<&]V86QI(&IS
M=&4@ON%D;N$@<&]L92!Z(&EM<&]R=&]V86[I:&\@<V]U8F]R=2!K(&]D<&]V
M[61A:NUC[6T@<&]L[6T@=B`E<RX`0GEL:2!J<W1E(&]D:&SAN65N:2!Z92!S
M>7-TZ6UU+@!6;&^^=&4@Z.US;&\@;6]B:6QN[6AO('1E;&5F;VYU+"!P;W6^
M:6IT92!J96X@Z.US;&EC(&YE8F\@</CM<&%D;NP@)RLG('!R;R!M97II;N%R
M;V1N[2#H:7-L82X`375S[71E('IA9&%T('!L871N;W4@:&]D;F]T=2X`375S
M[71E(&MO;F9I9W5R;W9A="!D871A8N%Z:2!D870L('!O:W5D('-I('#X96IE
M=&4@<&]UONUV870@4F5G:7-T<F%C92X`375S[71E(&MO;F9I9W5R;W9A="!6
M1E,@8F%C:V5N9"X`375S[71E(&YE:F3X[79E('!O<'-A="!P<F]B;.EM(&$@
M<&]TZ2!H;R!O9&5S;&%T+@!-=7/M=&4@>F%D870@55),(&YA(&MT97+I(&)U
M9&4@=&5N=&\@;V1K87H@=6MA>F]V870`375S[71E('9Y8G)A="!S97)V97(L
M(&MT97+](&)U9&4@<VUA>N%N+@!-=7/M=&4@=GEB<F%T('6^:79A=&5L<VOI
M(&IMZ6YO+"!K=&5RZ2!B=61E('-M87KA;F\N`$UU<^UT92!Z861A="!UOFEV
M871E;'-KZ2!J;>EN;RP@:W1E<ND@8G5D92!O9'-T<F%N[&YO+@!.975V961L
M:2!J<W1E('6^:79A=&5L<VOI(&IMZ6YO+"!K=&5RZ2!B=61E('#X:63A;F\N
M`$YE=79E9&QI(&IS=&4@=;YI=F%T96QS:^D@:FWI;F\@<')O(&%K='5A;&EZ
M86-I+@!-=7/M=&4@>F%D870@86MC:2P@:W1E<N$@8G5D92!P<F]V961E;F$N
M`$UU<^UT92!Z861A="!J;>EN;R!N;W;I(&MA=&5G;W)I92X`5F&Y92`E<R!R
M96QA8V4@8GEL82!U:V]NZ&5N82X@3W#L="!S92!P^&EH;&&Y=&4L('!R;W/M
M;2X`5F&Y92!E;6%I;&]VX2!A9')E<V$`5F&Y92!/9"UK;VAO.B!A9')E<V$Z
M`%9AN64@:6YF;W)M86-E`%8@<F5L86-I("5S('-E('IM[&YI;&$@5F&Y92!I
M;G1E<FYE=&]VX2!A9')E<V$N(%H@8F5Z<&7H;F]S=&[M8V@@9/EV;V3Y('-E
M(&UU<^UT92!O<.QT('#X:6ALX7-I="X`5F&Y92!J;>EN;P!6X;D@;W;L^&]V
M86/M('-Y<W3I;2!N97!O9'!O<G5J92!V_7!I<R!UOFEV871E;/D@86YE8F\@
M=&%T;R!M;[YN;W-T(&YE;NT@</CM<W1U<&[A('H@:FEN_6-H(&3Y=F]D^2X`
M6F3A('-E+""^92!V('!R^6+L:'4@<F5L86-E("5S('-E('IM[&YI;"!6X;D@
M<')O:&SMOF7H+B!:(&)E>G!EZ&YO<W1N[6-H(&3Y=F]D^2!S92!M=7/M=&4@
M;W#L="!P^&EH;.%S:70N`%;AN2!P<F]H;.V^9>@@;F5P;V1P;W)U:F4@='5T
M;R!M;[YN;W-T+@!68;EE('-O=>AA<V[I(.AA<V]VZ2!PX7-M;SH`5F&Y92!I
M;7!L:6-I=&[M(&ED96YT:71A`%9AN64@^G!L;ND@:FWI;F\Z`%9AN64@;F]V
MZ2!H97-L;R!P<F\@)7,@:F4Z("5S`%9AN64@;F%S=&%V96[M(&)Y;&\@86MT
M=6%L:7IO=N%N;R!P<F\@=')VX6[M('3I=&\@<F5L86-E+@!68;EE(&YA<W1A
M=F5N[2!B>6QO(&%K='5A;&EZ;W;A;F\N`%9AN64@:&5S;&\@8GEL;R!R97-E
M=&]VX6YO+@!68;EE(&AE<VQO(&)Y;&\@<F5S971O=N%N;RP@>FMO;G1R;VQU
M:G1E('-I('IP<N%V>2!E;&5K=')O;FEC:^D@<&^Y='D@82!P^&EH;&&Y=&4@
M<V4@<R!68;GM;2!N;W;];2!H97-L96TN`%9AN64@=GIDX6QE;ND@<V5R=F5R
M>3H`2G5G;W-LX79I90!:86ER`%IA;6)I90!::6UB86)V90!::7!P>0!;56MR
M_70@8VET;W9A;OT@=&5X=%T`6TALX;EE;NT@<')O8FSI;75=`%M:;V)R87II
M="!C:71O=F%N_2!T97AT("T`6UIO8G)A>FET(&-I=&]V86[]('1E>'0@+2`E
M<R#XX61K^5T`6_CA9&5K("5S('H@)7-=`%]!9&UI;FES=')A8V4`7T-,20!?
M1&%T851R964`7U-M87IA="#XX61E:P!?4VMU<&EN>0!?3N%P;W;L9&$`7U9L
M87-T;F]S=&D@;V)RX7IK=2XN+@!?4/AI:&SAN65N[0!?3V1H;.&Y96[M`%]-
M;V1I9FEK;W9A="!O9&MA>BXN+@!?36^^;F]S=&D`7U!RX79A`%]/9'-T<F%N
M:70@;V1K87HN+BX`7TYA<W1A=F5N[0!?5FQA<W1N;W-T:2!T86)U;&MY+BXN
M`%]5OFEV871E;.D`861R97/A^`!K86QE;F3A^`!B97IV['3X[0!K;&EK;F]U
M="!Z9&4`<W+AOFMY`'-O=6)O<@!Z("5S("@E<RD@<GEC:&QO<W3M("5S("5S
M`&@Z`&]K86V^:73L`'8@^&%D[`#XX61K^5T`8VAY8F]V_2!K\V0@;6MI<V]F
M<R`E9"!P^&D@=GET=N'X96[M($E33RX`:FWI;F\`;F5N[2!I;7!L96UE;G1O
M=N%N;P!N96[M(&1O<W5D(&EM<&QE;65N=&]VX6YO`'KA<&ES;NUK`'!R;V-E
M;G0`<&EX96SY`'-T;W5P86KM8^T`>F]B<F%Z:70@<F]Z9.UL>0!S;7,R96UA
M:6P@>F$@<&]UOFET[2!(5%10`'9Y=')V86SI`'-E>FYA;2#Z:V]L^0!P<F\@
M<&]T=G)Z96[M(&YA<&FY=&4@:&5S;&\@9'9A:W+A=`!S:F5D;F]C96[]`&)E
M>B!NX7IV=0!V>6)R870@=;YI=F%T96QE`'9#87)D`'<Z`'=E871H97(N8V]M
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&]C86QE+V1A7T1++P``````````````````````
M```````````````````````````````````````````````````````````P
M,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U
M,P`P,C`P-3<`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9&%?1$LO
M:&5L<"YX;6P`````````````````````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`S,S(P`#$P-3$U-#,S-S4S`#`R,34R-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*
M/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L92]D85]$2R]H96QP+GAM;"QV(#$N
M,B`R,#`T+S`U+S(W(#(P.C(R.C$V(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@
M/&5N=')Y(&ED/2)S=6UM87)Y(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!0
M;W)T86P@4&%G93PO=&ET;&4^"B`\<&%R83X*("!4:&ES('!O<G1A;"!P86=E
M('!R;W9I9&5S(&$@<75I8VL@<W5M;6%R>2!O9B!A;&P@>6]U<B!I;7!O<G1A
M;G0*("!I;F9O<FUA=&EO;BX@1F]R(&5X86UP;&4L(&ET(&UI9VAT('-H;W<@
M:&]W(&UA;GD@;F5W(&4M;6%I;"!M97-S86=E<R!Y;W4*("!H879E(&EN('EO
M=7(@24Y"3U@L('5P8V]M:6YG(&5V96YT<R!O;B!Y;W5R(&-A;&5N9&%R+"!T
M87-K<R!O;B!Y;W5R('1O+61O"B`@;&ES="P@:&5A9&QI;F5S(&9R;VT@<V5L
M96-T960@;F5W<R!S97)V:6-E<RP@86YD('-O(&]N+B`@36%N>2!O9B!T:&5S
M90H@('-U;6UA<FEE<R!W:6QL(&-O;G1A:6X@<75I8VL@<VAO<G1C=71S('1O
M(&-O;6UO;B!F=6YC=&EO;G,L('-U8V@@87,*("!C;VUP;W-I;F<@82!N97<@
M;6%I;"!M97-S86=E+"!C<F5A=&EN9R!A(&YE=R!C86QE;F1A<B!E=F5N="!O
M<B!T87-K+"!E=&,N"B`\+W!A<F$^"B`\<&%R83X*("!4:&4@8V]N=&5N=',@
M;V8@=&AI<R!P;W)T86P@<&%G92!A<F4@8W5S=&]M:7IA8FQE('9I82!T:&4@
M3&%Y;W5T(&)U='1O;BX*("!&;W(@97AA;7!L92P@>6]U(&-A;B!C:&]O<V4@
M=VAI8V@@:71E;7,@=&\@:6YC;'5D92!O;B!T:&ES('!O<G1A;"!P86=E(&%S
M"B`@=V5L;"!A<R!I;B!W:&EC:"!O<F1E<B!T:&5Y(&%R92!S:&]W;BX*(#PO
M<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](FYA=F)A<B(@<W1A=&4](FYE
M=R(^"CQT:71L93Y4:&4@07!P;&EC871I;VX@3F%V:6=A=&EO;B!"87(\+W1I
M=&QE/@H@/'!A<F$^"B`@070@=&AE(&QE9G0@:&%N9"!S:61E(&]F('1H92!W
M96(@<&%G92!I<R!T:&4@87!P;&EC871I;VX@;F%V:6=A=&EO;B!B87(N"B`@
M0VQI8VL@;VX@=&AE(&EC;VYS(&]N('1H:7,@;F%V:6=A=&EO;B!B87(@=&\@
M<75I8VML>2!A;F0@96%S:6QY('-W:71C:`H@(&)E='=E96X@=&AE(&%V86EL
M86)L92!A<'!L:6-A=&EO;G,N"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\
M=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$;R!-86EN=&5N86YC
M93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O
M('!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;BP@8VAE
M8VL@=&AI<R!B;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@
M(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($-O;F9I<FT@36%I
M;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@
M;&EK92!T;R!C;VYF:7)M(&%L;"!M86EN=&5N86YC92!T87-K<R!B969O<F4@
M=&AE>2!A<F4@<G5N+"!C:&5C:R!T:&ES(&)O>"X@268@;&5F="!U;F-H96-K
M960L(&%L;"!M86EN=&5N86YC92!O<&5R871I;VYS('1H870@;F5E9"!T;R!B
M92!R=6X@=VEL;"!B92!P97)F;W)M960@875T;VUA=&EC86QL>2!W:71H(&YO
M(&-H86YC92!T;R!C86YC96P@;VX@;&]G:6XN"B`@("`\+W!A<F$^"CPO96YT
M<GD^"CPO:&5L<#X*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V1A7T1++TQ#7TU%
M4U-!1T53+P``````````````````````````````````````````````````
M```````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#4Q-30S,S<U,P`P,C$V-#0`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M;V-A;&4O9&%?1$LO3$-?34534T%'15,O:&]R9&4N;6\`````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P-#`U,#`Q`#$P-3$U-#,S-S4S`#`R,S,P,@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#>$@25`````(L'
M```<````=#P``!,*``#,>````````!BA```.````&:$```\````HH0``#0``
M`#BA```(````1J$```L```!/H0``#````%NA```$````:*$``!@```!MH0``
M&P```(:A```M````HJ$``!T```#0H0``)````.ZA```I````$Z(``!D````]
MH@``)@```%>B```,````?J(``"0```"+H@``#P```+"B```+````P*(```X`
M``#,H@``!0```-NB```H````X:(```@````*HP``"@```!.C```5````'J,`
M`!(````THP``"P```$>C``"%````4Z,```X```#9HP``"@```.BC```-````
M\Z,```X````!I```$0```!"D```-````(J0```P````PI```#0```#VD```&
M````2Z0``)0```!2I```"@```.>D```/````\J0``!@````"I0``#````!NE
M```.````**4```X````WI0``"````$:E```)````3Z4``"X```!9I0``&@``
M`(BE```R````HZ4``#@```#6I0``5`````^F``!1````9*8``%H```"VI@``
M5P```!&G```T````::<```D```">IP``#0```*BG```'````MJ<```H```"^
MIP``#P```,FG```%````V:<```8```#?IP``$0```.:G```(````^*<```D`
M```!J```"0````NH```E````%:@``"`````[J```$P```%RH```0````<*@`
M``\```"!J```"@```)&H```#````G*@```\```"@J```%````+"H```)````
MQ:@```T```#/J```$@```-VH```9````\*@``!X````*J0``#P```"FI```*
M````.:D```\```!$J0``"````%2I```D````7:D``!0```""J0``%@```)>I
M```(````KJD``$X```"WJ0``+0````:J```9````-*H```<```!.J@``#```
M`%:J```L````8ZH```X```"0J@```P```)^J```+````HZH```<```"OJ@``
M!P```+>J```%````OZH```4```#%J@``"@```,NJ```#````UJH``!<```#:
MJ@``"@```/*J```/````_:H```X````-JP``&````!RK```C````-:L```X`
M``!9JP``%````&BK```7````?:L``!<```"5JP``%P```*VK```3````Q:L`
M``\```#9JP``#@```.FK```?````^*L``!T````8K```!P```#:L```&````
M/JP```@```!%K```#P```$ZL```&````7JP```H```!EK```$P```'"L```+
M````A*P``!````"0K```%0```*&L```5````MZP```<```#-K```$````-6L
M```%````YJP``!4```#LK```$0````*M```,````%*T``#L````AK0``.```
M`%VM```)````EJT```<```"@K0``%````*BM```#````O:T```4```#!K0``
M$````,>M```)````V*T``!,```#BK0``.0```/:M```2````,*X``"<```!#
MK@``+````&NN```J````F*X``"4```##K@``"@```.FN```&````]*X```D`
M``#[K@``!P````6O```O````#:\``#<````]KP``+@```'6O``!5````I*\`
M`"T```#ZKP``+0```"BP```]````5K```#\```"4L```+0```-2P``!`````
M`K$``",```!#L0``(P```&>Q``!`````B[$``"T```#,L0``,P```/JQ```E
M````+K(``!4```!4L@``&0```&JR```I````A+(``"0```"NL@``*````-.R
M```1````_+(```H````.LP``#````!FS```*````)K,``!`````QLP``%@``
M`$*S```6````6;,```<```!PLP``!P```'BS```4````@+,```H```"5LP``
M"````*"S```G````J;,```@```#1LP``!P```-JS```'````XK,```8```#J
MLP``!0```/&S```'````][,```8```#_LP``"`````:T```I````#[0```X`
M```YM```"@```$BT```$````4[0```<```!8M```"0```&"T```&````:K0`
M`!$```!QM```!P```(.T```6````B[0```0```"BM```"````*>T```&````
ML+0```T```"WM```!@```,6T```>````S+0``!$```#KM```"````/VT```-
M````!K4```P````4M0``!P```"&U```#````*;4```,````MM0``%P```#&U
M```3````2;4``!T```!=M0``"````'NU```$````A+4```@```")M0``"```
M`)*U``!!````F[4``!H```#=M0``*P```/BU```@````)+8``!4```!%M@``
M!@```%NV```&````8K8``!4```!IM@``&````'^V```B````F+8``"X```"[
MM@``'0```.JV```A````"+<``%0````JMP``*0```'^W```*````J;<```<`
M``"TMP``!P```+RW```5````Q+<```X```#:MP``"@```.FW```/````]+<`
M``T````$N```#P```!*X```-````(K@```D````PN```%````#JX```&````
M3[@``!@```!6N```'0```&^X```3````C;@``!$```"AN```%````+.X```$
M````R+@```8```#-N```%````-2X``!4````Z;@``&0````^N0``!````*.Y
M```.````J+D```4```"WN0``!0```+VY```;````P[D``!H```#?N0``$P``
M`/JY```1````#KH``!$````@N@``'````#*Z```J````3[H``!````!ZN@``
M(0```(NZ```%````K;H``!,```"SN@``"P```,>Z```2````T[H```H```#F
MN@``#P```/&Z```-`````;L``!$````/NP``$P```"&[```,````-;L```8`
M``!"NP``#````$F[```&````5KL``!<```!=NP``$````'6[```1````AKL`
M``@```"8NP``!0```*&[```,````I[L``!````"TNP``!0```,6[```-````
MR[L```8```#9NP``!P```."[```-````Z+L```<```#VNP``"P```/Z[```'
M````"KP```<````2O```"0```!J\```)````)+P```H````NO```&0```#F\
M```]````4[P``!T```"1O```#````*^\```0````O+P```4```#-O```)0``
M`-.\```2````^;P``!,````,O0``*P```""]```[````3+T``"````"(O0``
M"````*F]```V````LKT``"$```#IO0``$`````N^```(````'+X```P````E
MO@``!@```#*^```$````.;X```\````^O@``#@```$Z^```'````7;X```H`
M``!EO@``#0```'"^```?````?KX``!P```">O@``(0```+N^```>````W;X`
M`!D```#\O@``'@```!:_```;````-;\``"$```!1OP``+@```'._```F````
MHK\``!P```#)OP``'@```.:_```<````!<```"8````BP```*P```$G````S
M````=<```"8```"IP```*P```-#````X````_,```!T````UP0``%0```%/!
M```O````:<$``"````"9P0``$@```+K!```I````S<$``!X```#WP0``(```
M`!;"```2````-\(``*(```!*P@``%@```.W"```C````!,,``"@````HPP``
M*0```%'#```H````>\,``!\```"DPP``%0```,3#```@````VL,``"4```#[
MPP``*````"'$```M````2L0``#````!XQ```D@```*G$```A````/,4``!8`
M``!>Q0``'````'7%```F````DL4``"H```"YQ0``00```.3%``!$````)L8`
M``P```!KQ@``!P```'C&```'````@,8```8```"(Q@``#0```(_&```0````
MG<8``!(```"NQ@``$P```,'&```2````U<8```<```#HQ@``!````/#&```0
M````]<8``!`````&QP``#````!?'```.````),<```T````SQP``#P```$''
M```3````4<<```T```!EQP``*````'/'```#````G,<```T```"@QP``!@``
M`*['```1````M<<``!<```#'QP``&P```-_'```.````^\<```(````*R```
M20````W(```%````5\@``!````!=R```#P```&[(```$````?L@```T```"#
MR```#@```)'(```#````H,@```X```"DR```"````+/(```/````O,@```\`
M``#,R```!P```-S(```-````Y,@``!````#RR```#0````/)```+````$<D`
M``8````=R0``"P```"3)```,````,,D```H````]R0``$0```$C)```9````
M6LD```L```!TR0``#0```(#)```B````CLD```\```"QR0``&P```,')```T
M````W<D```H````2R@``&````!W*```2````-LH``!D```!)R@``%@```&/*
M```B````>LH```T```"=R@``!P```*O*```4````L\H```L```#(R@``(@``
M`-3*```O````]\H```L````GRP``"0```#/+```9````/<L```L```!7RP``
M%P```&/+```7````>\L```D```"3RP``%@```)W+```/````M,L``!D```#$
MRP``%@```-[+```.````]<L``!@````$S```"````!W,```-````)LP``"8`
M```TS```0P```%O,```(````G\P``!(```"HS```'P```+O,```(````V\P`
M``L```#DS```+P```/#,```.````(,T```4````OS0``!@```#7-``!%````
M/,T```,```""S0``!P```(;-```$````CLT```H```"3S0``"@```)[-```/
M````J<T``!````"YS0``%P```,K-```1````XLT``!D```#TS0``%P````[.
M```)````)LX```4````PS@``"P```#;.```*````0LX```(```!-S@``!0``
M`%#.```-````5LX``!L```!DS@``%P```(#.```4````F,X```D```"MS@``
M#@```+?.```-````QLX``!(```#4S@``.````.?.```@````(,\```@```!!
MSP``#@```$K/``![````6<\``!@```#5SP``&````.[/```1````!]````<`
M```9T```!0```"'0```8````)]```!X```!`T```&P```%_0```9````>]``
M`!L```"5T```&0```+'0```3````R]````<```#?T```"````.?0```&````
M\-````8```#WT```$````/[0```/````#]$``!`````?T0``#P```##1```+
M````0-$```\```!,T0``#````%S1```/````:=$```<```!YT0``!@```('1
M```.````B-$```P```"7T0``*````*31```/````S=$```@```#=T0``"```
M`.;1```3````[]$``!X````#T@``(0```"+2```@````1-(``!D```!ET@``
M%P```'_2```E````E](``!<```"]T@``%@```-72```$````[-(``!L```#Q
MT@``#0````W3```,````&],```,````HTP``!0```"S3```(````,M,```H`
M```[TP``#````$;3```+````4],``!````!?TP``#````'#3```.````?=,`
M``L```",TP``!````)C3```$````G=,``!,```"BTP``%````+;3```,````
MR],```D```#8TP``#@```.+3```+````\=,``!L```#]TP``!P```!G4```'
M````(=0```H````IU```#0```#34```)````0M0```0```!,U```!0```%'4
M```#````5]0``!@```!;U```"@```'34```$````?]0``"8```"$U```#@``
M`*O4``!\````NM0``!4````WU0``!0```$W5```'````4]4```P```!;U0``
M"````&C5```*````<=4```8```!\U0``"````(/5```"````C-4```8```"/
MU0``!@```);5```4````G=4```T```"RU0``$````,#5```;````T=4```0`
M``#MU0``"0```/+5```0````_-4```D````-U@``"0```!?6```%````(=8`
M`!H````GU@``"````$+6```&````2]8``!D```!2U@``#@```&S6```'````
M>]8```<```"#U@``!0```(O6```)````D=8```H```";U@``#@```*;6```"
M````M=8```8```"XU@``"P```+_6```-````R]8```D```#9U@``!@```./6
M```2````ZM8```D```#]U@``!P````?7```4````#]<``!T````DUP``0@``
M`$+7```E````A=<``"4```"KUP``!@```-'7```*````V-<```0```#CUP``
M"0```.C7```(````\M<``!$```#[UP``"0````W8```&````%]@```T````>
MV```!@```"S8```$````,]@``#D````XV```/0```'+8```Z````L-@``!X`
M``#KV```!0````K9```.````$-D```0````?V0``!@```"39```'````*]D`
M`"$````SV0``#0```%79```5````8]D```8```!YV0``!````(#9```1````
MA=D```8```"7V0``"@```)[9```B````J=D```0```#,V0``!0```-'9```=
M````U]D```0```#UV0``#````/K9```.````!]H```H````6V@``"````"':
M```)````*MH```4````TV@``.@```#K:```P````==H``#4```"FV@``*0``
M`-S:``!'````!ML``#@```!.VP``*0```(?;```_````L=L``"X```#QVP``
M+0```"#<```?````3MP```\```!NW```$@```'[<```+````D=P``"8```"=
MW```*0```,3<```D````[MP``"8````3W0``"````#K=```*````0]T```D`
M``!.W0``!P```%C=```@````8-T``"````"!W0``)@```*+=```*````R=T`
M`!D```#4W0``*0```.[=```6````&-X``!(````OW@``!P```$+>```*````
M2MX```P```!5W@``#P```&+>```0````<MX``$````"#W@``<````,3>``!F
M````-=\```X```"<WP``"0```*O?```*````M=\``!(```#`WP``$P```-/?
M```,````Y]\```8```#TWP``#P```/O?```2````"^```!`````>X```$0``
M`"_@```<````0>```",```!>X```:@```(+@```/````[>````4```#]X```
M$`````/A```)````%.$```0````>X0``"P```"/A```@````+^$``!0```!0
MX0``#````&7A```,````<N$```\```!_X0``%0```(_A```I````I>$``"H`
M``#/X0``)@```/KA```G````(>(``"D```!)X@``*@```'/B```9````GN(`
M`$(```"XX@``$0```/OB```2````#>,``!,````@XP``%````#3C```/````
M2>,``!8```!9XP``%P```'#C```0````B.,``!$```"9XP``-````*OC```3
M````X.,``!(```#TXP``-0````?D```4````/>0```<```!2Y```#````%KD
M```@````9^0``!````"(Y```%````)GD```1````KN0``!<```#`Y```'```
M`-CD```3````]>0``!0````)Y0``&@```![E```1````.>4``!H```!+Y0``
M'@```&;E```:````A>4``!,```"@Y0``%0```+3E```1````RN4``!<```#<
MY0``%````/3E```7````">8``!4````AY@``"0```#?F```0````0>8``!D`
M``!2Y@``!````&SF```'````<>8```L```!YY@``$0```(7F```&````E^8`
M``8```">Y@``!@```*7F```%````K.8```<```"RY@``!P```+KF```%````
MPN8``!8```#(Y@``!@```-_F```&````YN8```0```#MY@``!````/+F```'
M````]^8```X```#_Y@``#`````[G```,````&^<```T````HYP``"@```#;G
M```.````0><```4```!0YP``*````%;G```.````?^<```P```".YP``#P``
M`)OG```*````J^<```@```"VYP``"0```+_G```K````R><```0```#UYP``
M"````/KG```F`````^@``!(````JZ```#P```#WH```&````3>@```H```!4
MZ```!P```%_H```(````9^@``"````!PZ```"0```)'H```4````F^@```P`
M``"PZ```#0```+WH```.````R^@``!8```#:Z```$0```/'H```&`````^D`
M``,````*Z0``!@````[I```9````%>D```<````OZ0``!````#?I```+````
M/.D```L```!(Z0``!P```%3I```%````7.D```<```!BZ0``%@```&KI```-
M````@>D```T```"/Z0``"@```)WI```0````J.D```\```"YZ0``$0```,GI
M```7````V^D```H```#SZ0``$0```/[I```(````$.H```0````9Z@``#P``
M`![J```Z````+NH```4```!IZ@``#````&_J```>````?.H```X```";Z@``
M$````*KJ```+````N^H```P```#'Z@``"0```-3J```'````WNH```H```#F
MZ@``"0```/'J```.````^^H``!`````*ZP``&P```!OK```8````-^L``!H`
M``!0ZP``"@```&OK```)````=NL```H```"`ZP``#````(OK```/````F.L`
M``@```"HZP``!@```+'K```<````N.L```<```#5ZP``!0```-WK```+````
MX^L``$<```#OZP``#0```#?L```)````1>P```0```!/[````P```%3L```3
M````6.P``!,```!L[```$P```(#L```*````E.P```(```"?[```!````*+L
M```E````I^P```,```#-[```!0```-'L```J````U^P```H````"[0``!0``
M``WM```$````$^T```H````8[0``#0```"/M```&````,>T```@````X[0``
M"````$'M```$````2NT```4```!/[0``:````%7M```)````ONT```P```#(
M[0``$````-7M```%````YNT```8```#L[0``&P```//M```O````#^X``!``
M```_[@``"@```%#N```/````6^X```H```!K[@``"0```';N```3````@.X`
M`!L```"4[@``&````+#N```7````R>X``!\```#A[@``#@````'O```#````
M$.\```<````4[P``"````!SO```'````)>\```H````M[P``"P```#CO```'
M````1.\``%$```!,[P``$````)[O```,````K^\```T```"\[P``&@```,KO
M``!*````Y>\``!D````P\```!@```$KP```:````4?```"4```!L\```!@``
M`)+P```&````F?```!\```"@\```!@```,#P```)````Q_```!@```#1\```
M%P```.KP```H`````O$```8````K\0``#0```#+Q```B````0/$``%<```!C
M\0``$P```+OQ```C````S_$``!,```#S\0```@````?R```+````"O(```@`
M```6\@``#0```!_R```*````+?(```<````X\@``%````$#R```&````5?(`
M``@```!<\@``#@```&7R```'````=/(```H```!\\@``"P```(?R```R````
MD_(```<```#&\@``#````,[R```-````V_(``!<```#I\@``#`````'S```)
M````#O,```D````8\P``"@```"+S```'````+?,```D````U\P``!P```#_S
M```*````1_,``!L```!2\P``#P```&[S```2````?O,```H```"1\P``%@``
M`)SS```)````L_,``!````"]\P``!P```,[S```2````UO,```0```#I\P``
M!P```.[S```%````]O,```4```#\\P``"P````+T```4````#O0``!$````C
M]```&@```#7T```6````4/0``!0```!G]```%P```'ST```8````E/0``!P`
M``"M]```&0```,KT```'````Y/0```4```#L]```#0```/+T```,`````/4`
M``@````-]0``%P```!;U```+````+O4```P````Z]0``'P```$?U```:````
M9_4``!,```""]0``!````);U```*````F_4```0```"F]0``#0```*OU```,
M````N?4```4```#&]0``"0```,SU```%````UO4```<```#<]0``!0```.3U
M```$````ZO4```(```#O]0``.````/+U```L````*_8``!(```!8]@``*0``
M`&OV```R````E?8```H```#(]@``+````-/V```N`````/<``#,````O]P``
M,P```&/W```X````E_<```\```#0]P``&````.#W```0````^?<```\````*
M^```$P```!KX```5````+O@``!0```!$^```$@```%GX```4````;/@``!4`
M``"!^```+0```)?X```M````Q?@``#$```#S^```+@```"7Y```O````5/D`
M`"P```"$^0``8@```+'Y```3````%/H```T````H^@``"````#;Z```7````
M/_H```@```!7^@``#````&#Z```K````;?H``"$```"9^@``&@```+OZ```)
M````UOH``$4```#@^@``00```";[```$````:/L``!,```!M^P``%````('[
M```.````EOL``!,```"E^P``&````+G[```&````TOL```D```#9^P``"@``
M`./[```/````[OL``!````#^^P``!P````_\```.````%_P```4````F_```
M&P```"S\```(````2/P```8```!1_```%````%C\```1````;?P```X```!_
M_```.````([\```"````Q_P```8```#*_```#@```-'\```%````X/P```<`
M``#F_```#@```.[\```&````_?P``"@````$_0``#````"W]```<````.OT`
M``0```!7_0``*0```%S]```7````AOT``!\```">_0``7````+[]```4````
M&_X``#X````P_@``'P```&_^```0````C_X```<```"@_@``#@```*C^```,
M````M_X```P```#$_@``$P```-'^```*````Y?X``!T```#P_@``&0````[_
M```%````*/\``!$````N_P``$0```$#_```D````4O\``!(```!W_P``%0``
M`(K_```2````H/\```X```"S_P``&0```,+_```(````W/\```D```#E_P``
M#0```.__```'````_?\```H````%``$`!P```!```0`/````&``!``8````H
M``$`"P```"\``0`:````.P`!``H```!6``$`!P```&$``0`(````:0`!``4`
M``!R``$`'P```'@``0`&````F``!`!````"?``$`"````+```0`-````N0`!
M``@```#'``$`'@```-```0`2````[P`!`"P````"`0$`&@```"\!`0`)````
M2@$!``H```!4`0$`%0```%\!`0`%````=0$!`!0```![`0$`!````)`!`0`0
M````E0$!``8```"F`0$`!P```*T!`0`>````M0$!`"@```#4`0$`"@```/T!
M`0`<````"`(!`!$````E`@$`"P```#<"`0`:````0P(!`!0```!>`@$`!```
M`',"`0`$````>`(!``L```!]`@$`!0```(D"`0`&````CP(!``@```"6`@$`
M!@```)\"`0`*````I@(!`!L```"Q`@$`-````,T"`0`T`````@,!`"`````W
M`P$`*0```%@#`0`@````@@,!`$$```"C`P$`&@```.4#`0`H``````0!`"D`
M```I!`$`4````%,$`0`B````I`0!``8```#'!`$`"````,X$`0`%````UP0!
M``@```#=!`$`&0```.8$`0`9``````4!`"H````:!0$`(P```$4%`0`9````
M:04!`"X```"#!0$`-````+(%`0`(````YP4!`!<```#P!0$`"@````@&`0`'
M````$P8!`"$````;!@$`$````#T&`0`.````3@8!``L```!=!@$`!P```&D&
M`0`3````<08!``@```"%!@$`"P```(X&`0`*````F@8!`!0```"E!@$`#P``
M`+H&`0`R````R@8!``L```#]!@$`#@````D'`0`%````&`<!``4````>!P$`
M!0```"0'`0`7````*@<!``\```!"!P$`!````%('`0`*````5P<!``D```!B
M!P$`"P```&P'`0`-````>`<!``P```"&!P$`#@```),'`0`%````H@<!``0`
M``"H!P$`#0```*T'`0`R````NP<!`$4```#N!P$`%P```#0(`0`'````3`@!
M`!X```!4"`$`%````',(`0`%````B`@!`!0```"."`$`!@```*,(`0`'````
MJ@@!``X```"R"`$`*@```,$(`0`&````[`@!``P```#S"`$`#0`````)`0`1
M````#@D!``L````@"0$`-@```"P)`0`*````8PD!`"(```!N"0$`"P```)$)
M`0`/````G0D!`#(```"M"0$`)0```.`)`0`P````!@H!`#$````W"@$`+0``
M`&D*`0`.````EPH!``4```"F"@$`#@```*P*`0`3````NPH!`!(```#/"@$`
M!P```.(*`0`1````Z@H!`!,```#\"@$`!P```!`+`0`4````&`L!`!@````M
M"P$`!P```$8+`0`%````3@L!``P```!4"P$`#````&$+`0`2````;@L!``0`
M``"!"P$`!P```(8+`0`*````C@L!``L```"9"P$`#````*4+`0`.````L@L!
M``X```#!"P$`!0```-`+`0`%````U@L!`"X```#<"P$`)@````L,`0`C````
M,@P!``,```!6#`$`$@```%H,`0`&````;0P!`!X```!T#`$`&````),,`0`E
M````K`P!``T```#2#`$`"0```.`,`0`?````Z@P!``,````*#0$`!P````X-
M`0`*````%@T!``(````A#0$`#````"0-`0`5````,0T!``L```!'#0$`&0``
M`%,-`0`@````;0T!`!(```".#0$`!0```*$-`0`*````IPT!`!4```"R#0$`
M$@```,@-`0`,````VPT!``0```#H#0$`"0```.T-`0`'````]PT!``P```#_
M#0$`4@````P.`0`7````7PX!`"0```!W#@$`$@```)P.`0`'````KPX!``8`
M``"W#@$`#@```+X.`0`,````S0X!``T```#:#@$`%0```.@.`0`2````_@X!
M``\````1#P$`%````"$/`0`*````-@\!`!L```!!#P$`$````%T/`0`+````
M;@\!`&D```!Z#P$`&@```.0/`0`7````_P\!`"<````7$`$`&@```#\0`0`7
M````6A`!`!L```!R$`$`&0```(X0`0`?````J!`!`!,```#($`$`"````-P0
M`0`'````Y1`!``@```#M$`$`"0```/80`0`5`````!$!``T````6$0$`(P``
M`"01`0`-````2!$!`!,```!6$0$`"````&H1`0`#````<Q$!`$8```!W$0$`
M/P```+X1`0`W````_A$!`%<````V$@$`!0```(X2`0`?````E!(!`"\```"T
M$@$`"@```.02`0`(````[Q(!``T```#X$@$`+0````83`0`$````-!,!`$\`
M```Y$P$`)0```(D3`0`<````KQ,!``L```#,$P$`'P```-@3`0`=````^!,!
M`"4````6%`$`(````#P4`0`D````710!`"````""%`$`"P```*,4`0`'````
MKQ0!``T```"W%`$`#````,44`0`7````TA0!``8```#J%`$`.0```/$4`0`,
M````*Q4!``<````X%0$`"0```$`5`0`3````2A4!``D```!>%0$`!````&@5
M`0`0````;14!``@```!^%0$`"````(<5`0`$````D!4!``L```"5%0$`#```
M`*$5`0`2````KA4!`!$```#!%0$`#````-,5`0`:````X!4!``\```#[%0$`
M!P````L6`0`-````$Q8!`!0````A%@$`#@```#86`0`,````118!`!L```!2
M%@$`+````&X6`0`3````FQ8!`!P```"O%@$`*````,P6`0`&````]18!``<`
M``#\%@$`$P````07`0`%````&!<!``0````>%P$`%P```",7`0`*````.Q<!
M``P```!&%P$`"0```%,7`0`&````71<!``D```!D%P$`"````&X7`0`)````
M=Q<!``H```"!%P$`$0```(P7`0`&````GA<!``X```"E%P$`#@```+07`0`-
M````PQ<!``L```#1%P$`'0```-T7`0`+````^Q<!``(````'&`$`'`````H8
M`0`'````)Q@!``8````O&`$`9````#88`0`)````FQ@!``<```"E&`$`)@``
M`*T8`0`X````U!@!`!H````-&0$`*@```"@9`0`[````4QD!`"@```"/&0$`
M-````+@9`0`9````[1D!`!4````'&@$`!0```!T:`0`'````(QH!``@````K
M&@$`!P```#0:`0`%````/!H!``<```!"&@$`#@```$H:`0`)````61H!``8`
M``!C&@$`"````&H:`0`+````<QH!``<```!_&@$`"````(<:`0`'````D!H!
M`!8```"8&@$`"0```*\:`0`&````N1H!``L```#`&@$`$````,P:`0`&````
MW1H!`!P```#D&@$`%`````$;`0`'````%AL!`!$````>&P$`"````#`;`0`.
M````.1L!``@```!(&P$`!0```%$;`0`0````5QL!``D```!H&P$`$````'(;
M`0`&````@QL!`!D```"*&P$`"@```*0;`0`<````KQL!``<```#,&P$`!0``
M`-0;`0`0````VAL!`!0```#K&P$`"P`````<`0`-````#!P!`"@````:'`$`
M&````$,<`0`7````7!P!``0```!T'`$`"0```'D<`0`*````@QP!``<```".
M'`$``@```)8<`0`.````F1P!``@```"H'`$`(P```+$<`0`?````U1P!`#@`
M``#U'`$`)@```"X=`0`Q````51T!`"<```"''0$`9````*\=`0`4````%!X!
M`%4````I'@$`.````'\>`0!*````N!X!`%L````#'P$`*````%\?`0`X````
MB!\!`"@```#!'P$`+````.H?`0`F````%R`!`!L````^(`$`/@```%H@`0"I
M`0``F2`!`",```!#(@$`%P```&<B`0!(````?R(!`(4```#((@$`,````$XC
M`0`E````?R,!`$$```"E(P$`6P```.<C`0!)````0R0!`#$```"-)`$`'0``
M`+\D`0`8````W20!`"L```#V)`$`(0```"(E`0`?````1"4!`"L```!D)0$`
M)@```)`E`0`A````MR4!`"<```#9)0$`.@````$F`0`=````/"8!`!$```!:
M)@$`,P```&PF`0`E````H"8!`"<```#&)@$`(````.XF`0`?````#R<!`#``
M```O)P$`:0```&`G`0`Q````RB<!`$$```#\)P$`,P```#XH`0`E````<B@!
M`#T```"8*`$`90```-8H`0!-````/"D!`"\```"**0$`+@```+HI`0`P````
MZ2D!`%0````:*@$`6@```&\J`0!(````RBH!`$H````3*P$`,@```%XK`0`O
M````D2L!`"P```#!*P$`+0```.XK`0!Q````'"P!`&8```".+`$`;P```/4L
M`0"S````92T!`!<````9+@$`)0```#$N`0`R````5RX!`"D```"*+@$`/@``
M`+0N`0`B````\RX!`%(````6+P$`)0```&DO`0`+````CR\!`+$```";+P$`
M10```$TP`0`A````DS`!`#````"U,`$`)0```.8P`0`<````##$!`#$````I
M,0$`!P```%LQ`0`'````8S$!``0```!K,0$`#0```'`Q`0`+````?C$!``X`
M``"*,0$`"P```)DQ`0`%````I3$!`!````"K,0$``@```+PQ`0!9````OS$!
M``4````9,@$`$@```!\R`0`$````,C(!``<````W,@$`"````#\R`0`%````
M2#(!`#````!.,@$``P```'\R`0`0````@S(!``P```"4,@$`$P```*$R`0`-
M````M3(!``(```##,@$`!P```,8R`0`&````SC(!`!0```#5,@$`#````.HR
M`0`8````]S(!``8````0,P$`$@```!<S`0`,````*C,!``,````W,P$`*@``
M`#LS`0`$````9C,!``8```!K,P$`!P```'(S`0`?````>C,!`#4```":,P$`
M+@```-`S`0`O````_S,!`!<````O-`$`(@```$<T`0`E````:C0!`"````"0
M-`$`&P```+$T`0`8````S30!`"0```#F-`$`'P````LU`0`:````*S4!`"$`
M``!&-0$`(````&@U`0`:````B34!`#(```"D-0$`&@```-<U`0`O````\C4!
M`"L````B-@$`'P```$XV`0`C````;C8!`!\```"2-@$`&@```+(V`0`A````
MS38!`"4```#O-@$`)@```!4W`0`E````/#<!`"0```!B-P$`&````(<W`0`=
M````H#<!`"0```"^-P$`&````.,W`0`B````_#<!`"P````?.`$`+P```$PX
M`0`5````?#@!`"4```"2.`$`/````+@X`0`?````]3@!`",````5.0$`'P``
M`#DY`0`@````63D!`!H```!Z.0$`&````)4Y`0`F````KCD!`!X```#5.0$`
M*0```/0Y`0`>````'CH!`#$````].@$`"0```&\Z`0`,````>3H!`!<```"&
M.@$`+P```)XZ`0`D````SCH!``<```#S.@$`#P```/LZ`0`4````"SL!``X`
M```@.P$`#0```"\[`0`D````/3L!``4```!B.P$`!P```&@[`0`B````<#L!
M`"4```"3.P$`&@```+D[`0`=````U#L!`!H```#R.P$`!P````T\`0#'````
M%3P!``L```#=/`$`%0```.D\`0`&````_SP!``D````&/0$`"P```!`]`0`-
M````'#T!`!<````J/0$`!@```$(]`0`S````23T!`!,```!]/0$`$P```)$]
M`0`'````I3T!``\```"M/0$`!P```+T]`0`R````Q3T!``0```#X/0$`(0``
M`/T]`0`3````'SX!``P````S/@$`$0```$`^`0`R````4CX!`!8```"%/@$`
M"````)P^`0`=````I3X!``D```##/@$`"@```,T^`0`4````V#X!``H```#M
M/@$`'0```/@^`0`(````%C\!`!\````?/P$`"````#\_`0`:````2#\!`"<`
M``!C/P$`!@```(L_`0`5````DC\!``<```"H/P$`"````+`_`0`)````N3\!
M`#\```##/P$`!P````-``0`/````"T`!``X````;0`$`$````"I``0`)````
M.T`!``D```!%0`$`"````$]``0`3````6$`!``<```!L0`$`&0```'1``0`*
M````CD`!`!<```"90`$`%````+%``0`*````QD`!``P```#10`$`%P```-Y`
M`0`$````]D`!`"H```#[0`$`#````"9!`0`1````,T$!``<```!%00$``@``
M`$U!`0`0````4$$!`!@```!A00$`"P```'I!`0`#````AD$!``@```"*00$`
M!@```)-!`0`'````FD$!``T```"B00$`"P```+!!`0`4````O$$!`!4```#1
M00$`#@```.=!`0`O````]D$!`"`````F0@$`'````$="`0`5````9$(!``P`
M``!Z0@$`,0```(="`0`%````N4(!`!(```"_0@$`/P```-)"`0`2````$D,!
M``H````E0P$`!@```#!#`0`$````-T,!``0````\0P$`"@```$%#`0`3````
M3$,!``4```!@0P$`!@```&9#`0`&````;4,!``@```!T0P$`!````'U#`0`,
M````@D,!``H```"/0P$`.0```)I#`0`N````U$,!`"D````#1`$`!0```"U$
M`0`8````,T0!`!D```!,1`$`'P```&9$`0`=````AD0!`!$```"D1`$``@``
M`+9$`0`$````N40!``H```"^1`$`!@```,E$`0`%````T$0!``,```#61`$`
M#````-I$`0!%````YT0!`#(````M10$`&@```&!%`0`T````>T4!`"@```"P
M10$`4P```-E%`0`9````+48!`'(```!'1@$`(````+I&`0`U````VT8!`"$`
M```11P$`10```#-'`0`P````>4<!`"@```"J1P$`*0```--'`0`F````_4<!
M`"4````D2`$`*````$I(`0`H````<T@!`"(```"<2`$`*P```+](`0`P````
MZT@!`!(````<20$`$P```"])`0`0````0TD!`'D```!420$`"0```,Y)`0"A
M````V$D!`',```!Z2@$`?````.Y*`0`K````:TL!`%0```"72P$`%P```.Q+
M`0`G````!$P!`!8````L3`$`#P```$-,`0`7````4TP!`!\```!K3`$`0```
M`(M,`0`?````S$P!`!P```#L3`$`40````E-`0`:````6TT!`!0```!V30$`
M"@```(M-`0`%````EDT!``8```"<30$`"````*--`0`%````K$T!`!(```"R
M30$`$````,5-`0`3````UDT!`!T```#J30$`#P````A.`0`/````&$X!``0`
M```H3@$`"0```"U.`0`+````-TX!``<```!#3@$`!0```$M.`0`4````44X!
M``<```!F3@$`"````&Y.`0`/````=TX!``@```"'3@$`#````)!.`0`/````
MG4X!``8```"M3@$`%````+1.`0`&````R4X!``P```#03@$`$0```-U.`0`(
M````[TX!``0```#X3@$`&0```/U.`0`1````%T\!``H````I3P$`&````#1/
M`0`3````34\!`!P```!A3P$`$0```'Y/`0`$````D$\!``\```"53P$`!P``
M`*5/`0`$````K4\!`!D```"R3P$`!P```,Q/`0`"````U$\!``(```#73P$`
M$0```-I/`0`)````[$\!``8```#V3P$`$@```/U/`0`7````$%`!``8````H
M4`$`)P```"]0`0`"````5U`!``0```!:4`$`#P```%]0`0`3````;U`!``<`
M``"#4`$`!P```(M0`0`1````DU`!``8```"E4`$`&````*Q0`0`&````Q5`!
M`!,```#,4`$`$````.!0`0`2````\5`!``(````$40$`!@````=1`0`,````
M#E$!``D````;40$`$0```"51`0`B````-U$!``<```!:40$`!P```&)1`0`+
M````:E$!``4```!V40$``@```'Q1`0`+````?U$!`)0!``"+40$`$````"!3
M`0`/````,5,!``T```!!4P$`"````$]3`0`+````6%,!``@```!D4P$`!0``
M`&U3`0`8````<U,!`!L```",4P$`+P```*A3`0`>````V%,!`"4```#W4P$`
M*````!U4`0`:````1E0!`"H```!A5`$`"P```(Q4`0`@````F%0!``X```"Y
M5`$`"P```,A4`0`/````U%0!``4```#D5`$`(````.I4`0`,````"U4!``X`
M```850$`$P```"=5`0`7````.U4!``P```!350$`B@```&!5`0`)````ZU4!
M``L```#U50$`#P````%6`0`/````$58!`!,````A5@$`#````#56`0`-````
M0E8!``L```!05@$`!@```%Q6`0"J````8U8!``@````.5P$`$````!=7`0`:
M````*%<!``H```!#5P$`$````$Y7`0`0````7U<!``@```!P5P$`#P```'E7
M`0`M````B5<!`"$```"W5P$`.P```-E7`0!&````%5@!`%L```!<6`$`60``
M`+A8`0!B````$ED!`%X```!U60$`/@```-19`0`/````$UH!`!(````C6@$`
M#@```#9:`0`/````15H!`!(```!56@$`!0```&A:`0`&````;EH!`!$```!U
M6@$`!0```(=:`0`)````C5H!``D```"76@$`*@```*%:`0`F````S%H!`!$`
M``#S6@$`$`````5;`0`2````%EL!``H````I6P$`!@```#1;`0`2````.UL!
M`!X```!.6P$`"P```&U;`0`0````>5L!`!,```"*6P$`&P```)Y;`0`A````
MNEL!`!4```#<6P$`#@```/);`0`4`````5P!``D````67`$`)P```"!<`0`;
M````2%P!`!X```!D7`$`#````(-<`0!:````D%P!`#````#K7`$`(@```!Q=
M`0`'````/UT!``\```!'70$`,P```%==`0`.````BUT!``@```":70$`"P``
M`*-=`0`(````KUT!``@```"X70$`"0```,%=`0`*````RUT!``H```#670$`
M!````.%=`0`3````YET!``P```#Z70$`$`````=>`0`/````&%X!`!@````H
M7@$`)0```$%>`0`3````9UX!`!4```![7@$`%P```)%>`0`:````J5X!`!(`
M``#$7@$`%@```-=>`0`1````[EX!`!``````7P$`+0```!%?`0`>````/U\!
M``<```!>7P$`!@```&9?`0`(````;5\!`!0```!V7P$`!@```(M?`0`(````
MDE\!`!,```";7P$`"P```*]?`0`1````NU\!`!4```#-7P$`$P```.-?`0`'
M````]U\!``X```#_7P$`!0````Y@`0`6````%&`!`!(````K8`$`"0```#Y@
M`0!"````2&`!`$````"+8`$`"0```,Q@`0`(````UF`!`!,```#?8`$`!0``
M`/-@`0`%````^6`!``P```#_8`$`"0````QA`0`9````%F$!`$0````P80$`
M#P```'5A`0`P````A6$!`#0```"V80$`,P```.MA`0`O````'V(!``L```!/
M8@$`!@```%MB`0`*````8F(!``8```!M8@$`,````'1B`0`Q````I6(!`"\`
M``#78@$`40````=C`0`N````66,!`"X```"(8P$`1P```+=C`0!(````_V,!
M`"X```!(9`$`.0```'=D`0`D````L60!`"8```#69`$`2P```/UD`0`N````
M264!`#0```!X90$`(````*UE`0`/````SF4!`!,```#>90$`(````/)E`0`C
M````$V8!`",````W9@$`%````%MF`0`+````<&8!`!,```!\9@$`"@```)!F
M`0`.````FV8!`!D```"J9@$`'````,1F`0`&````X68!``<```#H9@$`%@``
M`/!F`0`*````!V<!``@````29P$`)0```!MG`0`*````06<!``P```!,9P$`
M!P```%EG`0`&````86<!``4```!H9P$`!P```&YG`0`&````=F<!``H```!]
M9P$`*@```(AG`0`/````LV<!``@```##9P$``P```,QG`0`(````T&<!``D`
M``#99P$`!````.-G`0`.````Z&<!``4```#W9P$`%@```/UG`0`%````%&@!
M``@````::`$`!````"-H`0`)````*&@!``D````R:`$`&@```#QH`0`1````
M5V@!``D```!I:`$`"@```'-H`0`,````?F@!``<```"+:`$``P```)-H`0`#
M````EV@!`!<```";:`$`$P```+-H`0`V````QV@!``@```#^:`$`"@````=I
M`0`(````$FD!``@````;:0$`00```"1I`0`<````9FD!`"L```"#:0$`)0``
M`*]I`0`7````U6D!``8```#M:0$`"````/1I`0`=````_6D!`!D````;:@$`
M)P```#5J`0`P````76H!`!T```".:@$`)````*QJ`0!E````T6H!`"P````W
M:P$`"0```&1K`0`+````;FL!``<```!Z:P$`%````()K`0`+````EVL!``4`
M``"C:P$`$````*EK`0`-````NFL!`!````#(:P$`$````-EK`0`,````ZFL!
M`!4```#W:P$`!P````UL`0`>````%6P!`!X````T;`$`$P```%-L`0`/````
M9VP!`!4```!W;`$`!0```(UL`0`%````DVP!`!$```"9;`$`7P```*ML`0!<
M````"VT!``0```!H;0$`#@```&UM`0`%````?&T!``0```"";0$`'P```(=M
M`0`<````IVT!`!$```#$;0$`#P```-9M`0`2````YFT!`!\```#Y;0$`)```
M`!EN`0`'````/FX!`",```!&;@$`!0```&IN`0`;````<&X!`!0```",;@$`
M$@```*%N`0`.````M&X!`!(```##;@$`#0```-9N`0`5````Y&X!`!,```#Z
M;@$`"@````YO`0`%````&6\!``T````?;P$`!0```"UO`0`5````,V\!`!4`
M``!);P$`$P```%]O`0`)````<V\!``4```!];P$`"P```(-O`0`)````CV\!
M``4```"9;P$`#0```)]O`0`+````K6\!``@```"Y;P$`#0```,)O`0`)````
MT&\!``L```#:;P$`"0```.9O`0`%````\&\!``D```#V;P$`!P````!P`0`+
M````"'`!`!<````4<`$`0P```"QP`0`<````<'`!``T```"-<`$`#P```)MP
M`0`%````JW`!`"````"Q<`$`&````-)P`0`9````ZW`!`"T````%<0$`/```
M`#-Q`0`G````<'$!``D```"8<0$`,0```*)Q`0`A````U'$!``\```#V<0$`
M!P````9R`0`,````#G(!``<````;<@$`!@```"-R`0`9````*G(!`!````!$
M<@$`"````%5R`0`*````7G(!``\```!I<@$`(````'ER`0`?````FG(!`"(`
M``"Z<@$`(0```-UR`0`>````_W(!`"$````><P$`(0```$!S`0`D````8G,!
M`#<```"'<P$`*0```+]S`0`@````Z7,!`"(````*=`$`'0```"UT`0`H````
M2W0!`$0```!T=`$`+P```+ET`0`F````Z70!`"D````0=0$`0@```#IU`0`?
M````?74!`!8```"==0$`,0```+1U`0`C````YG4!`!,````*=@$`+````!YV
M`0`=````2W8!`!P```!I=@$`$P```(9V`0"S````FG8!`!0```!.=P$`)@``
M`&-W`0`G````BG<!`"@```"R=P$`'@```-MW`0`B````^G<!`!8````=>`$`
M(0```#1X`0`I````5G@!`"P```"`>`$`/P```*UX`0`O````[7@!`)X````=
M>0$`'@```+QY`0`@````VWD!`!\```#\>0$`*@```!QZ`0`L````1WH!`$4`
M``!T>@$`1````+IZ`0`,````_WH!``0````,>P$`!@```!%[`0`%````&'L!
M`!,````>>P$`"P```#)[`0`0````/GL!`!,```!/>P$`$0```&-[`0`(````
M=7L!``0```!^>P$`$0```(-[`0`3````E7L!``H```"I>P$`$````+1[`0`1
M````Q7L!``P```#7>P$`$````.1[`0`+````]7L!`#H````!?`$`!````#Q\
M`0`)````07P!``8```!+?`$`$@```%)\`0`8````97P!`!L```!^?`$`"```
M`)I\`0`"````HWP!`$D```"F?`$`!@```/!\`0`2````]WP!``\````*?0$`
M!````!I]`0`/````'WT!``@````O?0$``P```#A]`0`,````/'T!``@```!)
M?0$`"@```%)]`0`1````77T!``@```!O?0$`#0```'A]`0`2````AGT!``T`
M``"9?0$`#````*=]`0`$````M'T!``H```"Y?0$`"P```,1]`0`+````T'T!
M`!````#<?0$`&````.U]`0`*````!GX!``P````1?@$`)P```!Y^`0`-````
M1GX!`!D```!4?@$`.P```&Y^`0`*````JGX!`!4```"U?@$`$````,M^`0`9
M````W'X!`!<```#V?@$`(`````Y_`0`2````+W\!``<```!"?P$`$0```$I_
M`0`+````7'\!`"$```!H?P$`/P```(I_`0`)````RG\!``@```#4?P$`&@``
M`-U_`0`*````^'\!`!D````#@`$`&0```!V``0`'````-X`!`!4````_@`$`
M&0```%6``0`8````;X`!`!0```"(@`$`#@```)V``0`3````K(`!``@```#`
M@`$`$````,F``0`H````VH`!`$(````#@0$`&0```$:!`0`9````8($!`"8`
M``!Z@0$`!````*&!`0`'````IH$!`#````"N@0$`$0```-^!`0`,````\8$!
M``8```#^@0$`2`````6"`0`#````3H(!``<```!2@@$`!P```%J"`0`*````
M8H(!``P```!M@@$`$````'J"`0`1````BX(!`!@```"=@@$`#P```+:"`0`:
M````QH(!`!@```#A@@$`"@```/J"`0`'````!8,!``L````-@P$`"@```!F#
M`0`"````)(,!``4````G@P$`#@```"V#`0`;````/(,!`!8```!8@P$`%```
M`&^#`0`'````A(,!``L```",@P$`#P```)B#`0`+````J(,!`#H```"T@P$`
M(````.^#`0`'````$(0!`!D````8A`$`@P```#*$`0`:````MH0!`!L```#1
MA`$`$0```.V$`0`'````_X0!``0````'A0$`'0````R%`0`E````*H4!`",`
M``!0A0$`(@```'2%`0`D````EX4!`"$```"\A0$`'0```-Z%`0`'````_(4!
M``@````$A@$`!@````V&`0`&````%(8!``P````;A@$`#@```"B&`0`0````
M-X8!``T```!(A@$`#P```%:&`0`/````9H8!``H```!VA@$`$````(&&`0`%
M````DH8!``4```"8A@$`$0```)Z&`0`.````L(8!`"H```"_A@$`#P```.J&
M`0`)````^H8!``@````$AP$`&`````V'`0`A````)H<!`"P```!(AP$`(P``
M`'6'`0`>````F8<!`!P```"XAP$`*````-6'`0`;````_H<!`!0````:B`$`
M!0```"^(`0`9````-8@!``@```!/B`$`#0```%B(`0`#````9H@!``H```!J
MB`$`!P```'6(`0`%````?8@!``<```"#B`$`"````(N(`0`+````E(@!``L`
M``"@B`$`#@```*R(`0`7````NX@!``0```#3B`$``P```-B(`0`3````W(@!
M`!4```#PB`$`#0````:)`0`'````%(D!``<````<B0$`"@```"2)`0`=````
M+XD!``8```!-B0$`!P```%2)`0`.````7(D!``X```!KB0$`&````'J)`0`$
M````DXD!``@```"8B0$`!````*&)`0`8````IHD!``X```"_B0$``P```,Z)
M`0`Q````THD!`!`````$B@$`@````!6*`0`2````EHH!``H```"IB@$`"```
M`+2*`0`+````O8H!``H```#)B@$`#````-2*`0`$````X8H!``X```#FB@$`
M`P```/6*`0`&````^8H!``@`````BP$`%@````F+`0`-````((L!`!$````N
MBP$`&P```$"+`0`#````7(L!``,```!@BP$`$````&2+`0`(````=8L!``H`
M``!^BP$`!0```(F+`0`F````CXL!``@```"VBP$`!@```+^+`0`8````QHL!
M``X```#?BP$`"````.Z+`0`(````]XL!``4`````C`$`"0````:,`0`'````
M$(P!`!L````8C`$`!0```#2,`0`%````.HP!``L```!`C`$`#@```$R,`0`(
M````6XP!``H```!DC`$`$@```&^,`0`(````@HP!``<```"+C`$`%0```).,
M`0`>````J8P!`#D```#(C`$`)0````*-`0`G````*(T!``<```!0C0$`"@``
M`%B-`0`$````8XT!``D```!HC0$`"````'*-`0`0````>XT!``@```",C0$`
M!@```)6-`0`-````G(T!``8```"JC0$`!````+&-`0`^````MHT!`$````#U
MC0$`/@```#:.`0`9````=8X!``4```"/C@$`#@```)6.`0`#````I(X!``@`
M``"HC@$`#````+&.`0`A````OHX!``X```#@C@$`%P```.^.`0`%````!X\!
M``4````-CP$`'````!./`0`'````,(\!``D````XCP$`&````$*/`0`#````
M6X\!``0```!?CP$`&````&2/`0`$````?8\!``X```""CP$`#0```)&/`0`.
M````GX\!``@```"NCP$`"0```+>/`0`%````P8\!`#8```#'CP$`+@```/Z/
M`0`W````+9`!`!T```!ED`$`0````(.0`0`U````Q)`!`"@```#ZD`$`.P``
M`".1`0`N````7Y$!`"\```".D0$`'P```+Z1`0`-````WI$!``L```#LD0$`
M"````/B1`0`W`````9(!`"T````YD@$`)````&>2`0`K````C)(!``D```"X
MD@$`"P```,*2`0`*````SI(!``8```#9D@$`)````."2`0`B````!9,!`"X`
M```HDP$`"@```%>3`0`=````8I,!`",```"`DP$`%@```*23`0`0````NY,!
M``8```#,DP$`"@```-.3`0`-````WI,!`!````#LDP$`#P```/V3`0`_````
M#90!`'T```!-E`$`;@```,N4`0`7````.I4!``H```!2E0$`"P```%V5`0`3
M````:94!`!0```!]E0$`$````)*5`0`(````HY4!`!0```"LE0$`%@```,&5
M`0`3````V)4!`!(```#LE0$`(````/^5`0`E````()8!`'\```!&E@$`$```
M`,:6`0`&````UY8!`!0```#>E@$`"@```/.6`0`$````_I8!``L````#EP$`
M)`````^7`0`4````-)<!``X```!)EP$`#````%B7`0`5````99<!`!(```![
MEP$`)P```(Z7`0`E````MI<!`"4```#<EP$`(P````*8`0`K````)I@!`"D`
M``!2F`$`&@```'R8`0!"````EY@!`!(```#:F`$`$````.V8`0`4````_I@!
M`!(````3F0$`#P```":9`0`5````-ID!`!4```!,F0$`$@```&*9`0`0````
M=9D!`#,```"&F0$`%````+J9`0`7````SYD!`#L```#GF0$`%P```".:`0`&
M````.YH!``P```!"F@$`(````$^:`0`1````<)H!`!4```""F@$`$P```)B:
M`0`6````K)H!`!0```##F@$`$@```-B:`0`4````ZYH!`!H`````FP$`$0``
M`!N;`0`=````+9L!`",```!+FP$`'@```&^;`0`3````CIL!`!4```"BFP$`
M$0```+B;`0`6````RIL!`!8```#AFP$`&P```/B;`0`5````%)P!``4````J
MG`$`$@```#"<`0`;````0YP!``0```!?G`$`!@```&2<`0`#````:YP!``X`
M``!OG`$`!@```'Z<`0`(````A9P!``D```".G`$`!P```)B<`0`'````H)P!
M``8```"HG`$`!0```*^<`0`5````M9P!``8```#+G`$`!@```-*<`0`$````
MV9P!``0```#>G`$`!@```..<`0`'````ZIP!``T```#RG`$`#P````"=`0`-
M````$)T!``H````>G0$`#P```"F=`0`%````.9T!`#$````_G0$`%@```'&=
M`0`.````B)T!`!(```"7G0$`"P```*J=`0`)````MIT!``\```#`G0$`.```
M`-"=`0`$````"9X!``@````.G@$`"````!>>`0`)````()X!`!$````JG@$`
M!@```#R>`0`+````0YX!``H```!/G@$`!0```%J>`0`$````8)X!``X```!E
MG@$`%@```'2>`0`.````BYX!`!````":G@$`$````*N>`0`<````O)X!`!0`
M``#9G@$`!P```.Z>`0`#````]IX!``8```#ZG@$`%`````&?`0`'````%I\!
M``<````>GP$`$````":?`0`/````-Y\!``8```!'GP$`!@```$Z?`0`(````
M59\!``8```!>GP$`#0```&6?`0`(````<Y\!``@```!\GP$`$````(6?`0`-
M````EI\!``@```"DGP$`$P```*V?`0`'````P9\!``P```#)GP$`"0```-:?
M`0`*````X)\!`!0```#KGP$`/@````"@`0`,````/Z`!``H```!,H`$`'```
M`%>@`0`.````=*`!`!D```"#H`$`#0```)V@`0`-````JZ`!``D```"YH`$`
M!P```,.@`0`*````RZ`!``D```#6H`$`#@```."@`0`0````[Z`!`"``````
MH0$`'P```"&A`0`@````0:$!``H```!BH0$`!P```&VA`0`)````=:$!``H`
M``!_H0$`$P```(JA`0`$````GJ$!``<```"CH0$`*0```*NA`0`&````U:$!
M``<```#<H0$`#0```.2A`0!(````\J$!`!,````[H@$`"@```$^B`0`)````
M6J(!``,```!DH@$`#P```&BB`0`1````>*(!``P```"*H@$`"0```)>B`0`"
M````H:(!``0```"DH@$`(@```*FB`0`#````S*(!``4```#0H@$`+P```-:B
M`0`*````!J,!``0````1HP$`!@```!:C`0`4````':,!`!$````RHP$`!@``
M`$2C`0`(````2Z,!``H```!4HP$`!````%^C`0`%````9*,!`'````!JHP$`
M"@```-NC`0`-````YJ,!`!$```#THP$`!0````:D`0`&````#*0!`!@````3
MI`$`*@```"RD`0`-````5Z0!``H```!EI`$`%@```'"D`0`+````AZ0!``D`
M``"3I`$`$P```)VD`0`A````L:0!`!P```#3I`$`'````/"D`0`>````#:4!
M``X````LI0$``P```#NE`0`'````/Z4!``<```!'I0$`"0```$^E`0`.````
M6:4!``P```!HI0$`!@```'6E`0!5````?*4!``\```#2I0$`"@```.*E`0`-
M````[:4!`!L```#[I0$`5````!>F`0`:````;*8!``8```"'I@$`'0```(ZF
M`0`E````K*8!``D```#2I@$`!@```-RF`0`+````XZ8!``0```#OI@$`"0``
M`/2F`0`<````_J8!`!L````;IP$`*P```#>G`0`&````8Z<!``L```!JIP$`
M(````':G`0!H````EZ<!`!(`````J`$`'P```!.H`0`3````,Z@!``,```!'
MJ`$`#````$NH`0`$````6*@!``P```!=J`$`"0```&JH`0`'````=*@!``<`
M``!\J`$`!@```(2H`0`)````BZ@!``L```"5J`$`"````*&H`0`*````JJ@!
M``D```"UJ`$`-0```+^H`0`'````]:@!``P```#]J`$`"@````JI`0`6````
M%:D!``@````LJ0$`"````#6I`0`0````/JD!``D```!/J0$`!P```%FI`0`(
M````8:D!``<```!JJ0$`"@```'*I`0`?````?:D!`!````"=J0$`#0```*ZI
M`0`)````O*D!`!@```#&J0$`"@```-^I`0`5````ZJD!``<`````J@$`%0``
M``BJ`0`$````'JH!``<````CJ@$`!0```"NJ`0`%````,:H!``P````WJ@$`
M$P```$2J`0`1````6*H!`!H```!JJ@$`%@```(6J`0`4````G*H!`!<```"Q
MJ@$`&````,FJ`0`<````XJH!`!@```#_J@$`!P```!BK`0`&````(*L!``T`
M```GJP$`"P```#6K`0`&````0:L!`!D```!(JP$`"P```&*K`0`+````;JL!
M`!X```!ZJP$`&````)FK`0`3````LJL!``<```#&JP$`#0```,ZK`0`%````
MW*L!``T```#BJP$`#0```/"K`0`&````_JL!``D````%K`$`!0````^L`0`'
M````%:P!``,````=K`$`!````"&L`0`#````)JP!`#L````JK`$`-````&:L
M`0`6````FZP!`#H```"RK`$`*````.VL`0`.````%JT!`#`````EK0$`+P``
M`%:M`0`T````AJT!`#0```"[K0$`.0```/"M`0`.````*JX!`!\````YK@$`
M#P```%FN`0`3````::X!`!8```!]K@$`$P```)2N`0`5````J*X!`!,```"^
MK@$`%0```-*N`0`<````Z*X!`#`````%KP$`,````#:O`0`T````9Z\!`"D`
M``"<KP$`*@```,:O`0`F````\:\!`&0````8L`$`'0```'VP`0`6````F[`!
M``T```"RL`$`&0```,"P`0`+````VK`!``\```#FL`$`-````/:P`0`H````
M*[$!`"$```!4L0$`#0```':Q`0!'````A+$!`$(```#,L0$`!0````^R`0`5
M````%;(!`!4````KL@$`!P```$&R`0`2````2;(!`!,```!<L@$`!0```'"R
M`0`/````=K(!``@```"&L@$`$@```(^R`0`3````HK(!``\```"VL@$`$@``
M`,:R`0`%````V;(!`!X```#?L@$`"````/ZR`0`#````![,!``H````+LP$`
M#@```!:S`0`,````);,!`#4````RLP$``@```&BS`0`&````:[,!``P```!R
MLP$`!0```'^S`0`'````A;,!`!$```"-LP$`!@```)^S`0`M````IK,!``\`
M``#4LP$`(````.2S`0`$````!;0!`"X````*M`$`&@```#FT`0`>````5+0!
M`%\```!SM`$`%````-.T`0`_````Z+0!`"4````HM0$`#@```$ZU`0`-````
M7;4!`!0```!KM0$`#````("U`0`,````C;4!`!0```":M0$`#````*^U`0`?
M````O+4!`!P```#<M0$`!0```/FU`0`1````_[4!``\````1M@$`(0```"&V
M`0`0````0[8!`!0```!4M@$`$@```&FV`0`3````?+8!`!L```"0M@$`"```
M`*RV`0`(````M;8!``X```"^M@$`"@```,VV`0`+````V+8!``D```#DM@$`
M#@```.ZV`0`)````_;8!``L````'MP$`&````!.W`0`(````++<!``<````U
MMP$`"````#VW`0`%````1K<!``D```!,MP$`!@```%:W`0`/````7;<!``@`
M``!MMP$`#0```':W`0`'````A+<!``\```",MP$`#P```)RW`0`B````K+<!
M`!<```#/MP$`"````.>W`0`)````\+<!`!D```#ZMP$`!@```!2X`0`8````
M&[@!``,````TN`$`%P```#BX`0`$````4+@!``<```!5N`$`%0```%VX`0`B
M````<[@!``L```"6N`$`'0```**X`0`1````P+@!``L```#2N`$`&@```-ZX
M`0`(````^;@!``0````"N0$`!P````>Y`0`,````#[D!``<````<N0$`!0``
M`"2Y`0`(````*KD!``<````SN0$`"P```#NY`0`/````1[D!`"T```!7N0$`
M+@```(6Y`0`>````M+D!`"4```#3N0$`'0```/FY`0`X````%[H!`"````!0
MN@$`.@```'&Z`0`F````K+H!`$P```#3N@$`'0```""[`0`%````/KL!``<`
M``!$NP$`#P```$R[`0`(````7+L!`!4```!ENP$`&````'N[`0`Q````E+L!
M`!\```#&NP$`$@```.:[`0`M````^;L!`#4````GO`$`!````%V\`0`5````
M8KP!``8```!XO`$`!0```'^\`0`@````A;P!``\```"FO`$`$````+:\`0`,
M````Q[P!``<```#4O`$`$@```-R\`0`)````[[P!``T```#YO`$`$`````>]
M`0`9````&+T!`!L````RO0$`,0```$Z]`0`+````@+T!``\```",O0$`!0``
M`)R]`0`,````HKT!``4```"OO0$`'````+6]`0`.````TKT!``0```#AO0$`
M#````.:]`0`)````\[T!``D```#]O0$`"P````>^`0`$````$[X!`!(````8
MO@$`!P```"N^`0`#````,[X!``P````WO@$`.P```$2^`0!+````@+X!`!D`
M``#,O@$`!P```.:^`0`A````[KX!`!D````0OP$`#P```"J_`0`.````.K\!
M``H```!)OP$`!0```%2_`0`.````6K\!`"D```!IOP$`!````)._`0`)````
MF+\!``T```"BOP$`$````+"_`0`(````P;\!`#4```#*OP$`!0````#``0`@
M````!L`!``L````GP`$`#P```#/``0`T````0\`!`",```!XP`$`,````)S`
M`0`P````S<`!`"\```#^P`$`"P```"[!`0`'````.L$!``\```!"P0$`$P``
M`%+!`0`;````9L$!``H```""P0$`&P```(W!`0`3````J<$!``<```"]P0$`
M%````,7!`0`F````VL$!``4````!P@$`!0````?"`0`.````#<(!``T````<
MP@$`$P```"K"`0`%````/L(!``@```!$P@$`"0```$W"`0`-````5\(!``L`
M``!EP@$`$````''"`0`0````@L(!``<```"3P@$`!P```)O"`0`M````H\(!
M`"<```#1P@$`)0```/G"`0`%````'\,!``<````EPP$`!@```"W#`0`=````
M-,,!`!8```!2PP$`(0```&G#`0`#````B\,!``T```"/PP$`(````)W#`0`#
M````OL,!``8```#"PP$`#0```,G#`0`#````U\,!``L```#;PP$`$P```.?#
M`0`*````^\,!`!<````&Q`$`'````![$`0`3````.\0!``4```!/Q`$`"@``
M`%7$`0`4````8,0!``X```!UQ`$`#````(3$`0`#````D<0!``@```"5Q`$`
M"````)[$`0`3````I\0!`$X```"[Q`$`%@````K%`0`T````(<4!``T```!6
MQ0$`"0```&3%`0`#````;L4!``P```!RQ0$`"@```'_%`0`,````BL4!`!D`
M``"7Q0$`#P```+'%`0`.````P<4!`!D```#0Q0$`"0```.K%`0`;````],4!
M``X````0Q@$`"@```!_&`0!A````*L8!`!8```",Q@$`$````*/&`0`E````
MM,8!`!8```#:Q@$`$````/'&`0`H`````L<!`!P````KQP$`&@```$C'`0`7
M````8\<!``@```![QP$`!P```(3'`0`'````C,<!``D```"4QP$`%0```)['
M`0`+````M,<!`"L```#`QP$`%0```.S'`0`3`````L@!``D````6R`$`!@``
M`"#(`0!>````)\@!`#X```"&R`$`-0```,7(`0!@````^\@!``L```!<R0$`
M,0```&C)`0`D````FLD!``P```"_R0$`"````,S)`0`0````U<D!`#P```#F
MR0$``P```"/*`0!(````)\H!`#````!PR@$`)@```*'*`0`+````R,H!`"8`
M``#4R@$`&@```/O*`0`O````%LL!`"P```!&RP$`+P```'/+`0`L````H\L!
M``P```#0RP$`!0```-W+`0`-````X\L!``H```#QRP$`$````/S+`0`&````
M#<P!`"L````4S`$`#````$#,`0`)````3<P!``L```!7S`$`$0```&/,`0`)
M````=<P!``D```!_S`$`&P```(G,`0`)````I<P!``D```"OS`$``P```+G,
M`0`'````O<P!``@```#%S`$`$````,[,`0`-````W\P!``H```#MS`$`%@``
M`/C,`0`,````#\T!``<````<S0$`#@```"3-`0`.````,\T!``\```!"S0$`
M"0```%+-`0`9````7,T!`"4```!VS0$`$0```)S-`0`6````KLT!`"0```#%
MS0$`$````.K-`0`)````^\T!``\````%S@$`!P```!7.`0`)````'<X!`!\`
M```GS@$`"0```$?.`0`+````4<X!``D```!=S@$`!0```&?.`0`)````;<X!
M``@```!WS@$`"0```(#.`0`-````BLX!`!4```"8S@$`!@```*[.`0`.````
MM<X!``,```#$S@$`#P```,C.`0`0````V,X!`!D```#IS@$`"@````//`0`#
M````#L\!`!X````2SP$`!````#'/`0`'````-L\!`&T````^SP$`"@```*S/
M`0`&````M\\!`"````"^SP$`+P```-_/`0`-````#]`!`!H````=T`$`.P``
M`#C0`0`:````=-`!`"````"/T`$`#P```+#0`0`-````P-`!``4```#.T`$`
M!P```-30`0`)````W-`!``H```#FT`$`!P```/'0`0`)````^=`!`!0````#
MT0$`"P```!C1`0`*````)-$!``P````OT0$`#````#S1`0`%````2=$!``<`
M``!/T0$`"0```%?1`0`5````8=$!``D```!WT0$`!P```('1`0`'````B=$!
M`!````"1T0$`!@```*+1`0`5````J=$!``8```"_T0$`!@```,;1`0`.````
MS=$!``8```#<T0$`#@```./1`0`'````\M$!``4```#ZT0$`$`````#2`0`+
M````$=(!`!`````=T@$`!@```"[2`0`=````-=(!``L```!3T@$`"````%_2
M`0`$````:-(!``<```!MT@$`#0```'72`0`3````@](!``H```"7T@$`#```
M`*+2`0`I````K](!`!H```#9T@$`%P```/32`0`%````#-,!``D````2TP$`
M#P```!S3`0`)````+-,!``,````VTP$`#@```#K3`0`(````2=,!`"0```!2
MTP$`'P```'?3`0`V````E],!`"$```#.TP$`)P```/#3`0`L````&-0!`'$`
M``!%U`$`#@```+?4`0!9````QM0!`#(````@U0$`5P```%/5`0!0````J]4!
M`"$```#\U0$`.@```![6`0`I````6=8!`"X```"#U@$`)P```++6`0`;````
MVM8!`#8```#VU@$`QP$``"W7`0`<````]=@!`!$````2V0$`0P```"39`0"7
M````:-D!`#@`````V@$`)````#G:`0`Y````7MH!`%\```"8V@$`6P```/C:
M`0`I````5-L!`!D```!^VP$`$P```)C;`0`L````K-L!`!D```#9VP$`%@``
M`//;`0`J````"MP!`"<````UW`$`(@```%W<`0`F````@-P!`$$```"GW`$`
M#P```.G<`0`'````^=P!`#,````!W0$`)````#7=`0`H````6MT!`"````"#
MW0$`&P```*3=`0`S````P-T!`%T```#TW0$`0````%+>`0!,````D]X!`#L`
M``#@W@$`,@```!S?`0!#````3]\!`&H```"3WP$`20```/[?`0`S````2.`!
M`#T```!\X`$`.0```+K@`0!6````].`!`%D```!+X0$`10```*7A`0!&````
MZ^$!`#4````RX@$`,0```&CB`0`N````FN(!`#(```#)X@$`>P```/SB`0!P
M````>.,!`'D```#IXP$`O@```&/D`0`5````(N4!`",````XY0$`*P```%SE
M`0`K````B.4!`$<```"TY0$`)P```/SE`0!&````).8!`"<```!KY@$`#```
M`)/F`0"E````H.8!`#\```!&YP$`&````(;G`0`V````G^<!`!P```#6YP$`
M'0```//G`0`N````$>@!``8```!`Z`$`!0```$?H`0`#````3>@!``T```!1
MZ`$`"@```%_H`0`(````:N@!``L```!SZ`$`!0```'_H`0`0````A>@!``,`
M``"6Z`$`:0```)KH`0`%````!.D!`!`````*Z0$`!````!OI`0`'````(.D!
M``@````HZ0$`!0```#'I`0`_````-^D!``,```!WZ0$`$````'OI`0`-````
MC.D!`!(```":Z0$`$````*WI`0`#````OND!``@```#"Z0$`!P```,OI`0`4
M````T^D!``P```#HZ0$`%0```/7I`0`&````"^H!`!`````2Z@$`#0```"/J
M`0`#````,>H!`#$````UZ@$`!````&?J`0`&````;.H!``<```!SZ@$`'0``
M`'OJ`0`]````F>H!`"P```#7Z@$`+0````3K`0`7````,NL!`"8```!*ZP$`
M*0```''K`0`K````F^L!`"````#'ZP$`&0```.CK`0`@`````NP!`!L````C
M[`$`%@```#_L`0`@````5NP!`!H```!W[`$`&P```)+L`0`M````KNP!`!D`
M``#<[`$`*@```/;L`0`H````(>T!`!P```!*[0$`(````&?M`0`=````B.T!
M`!@```"F[0$`'P```+_M`0`B````W^T!`"(````"[@$`)````"7N`0`D````
M2NX!`!@```!O[@$`&P```(CN`0`D````I.X!`!8```#)[@$`(````.#N`0`K
M`````>\!`"X````M[P$`$P```%SO`0`@````<.\!`#0```"1[P$`'````,;O
M`0`@````X^\!`!T````$\`$`'@```"+P`0`8````0?`!`!L```!:\`$`*```
M`';P`0`=````G_`!`"D```"]\`$`'````.?P`0`V````!/$!``T````[\0$`
M$0```$GQ`0`9````6_$!`"T```!U\0$`(````*/Q`0`,````Q/$!``\```#1
M\0$`&@```.'Q`0`.````_/$!``,````+\@$`%0````_R`0`'````)?(!``8`
M```M\@$`(0```#3R`0`D````5O(!`!0```![\@$`(````)#R`0`8````L?(!
M``X```#*\@$`W````-GR`0`5````MO,!`!P```#,\P$`!P```.GS`0`*````
M\?,!``X```#\\P$`#P````OT`0`@````&_0!``8````\]`$`.0```$/T`0`8
M````??0!``X```"6]`$`!P```*7T`0`4````K?0!``@```#"]`$`-0```,OT
M`0`&`````?4!`"$````(]0$`%0```"KU`0`3````0/4!`!,```!4]0$`.0``
M`&CU`0`7````HO4!``H```"Z]0$`(````,7U`0`+````YO4!``P```#R]0$`
M$P```/_U`0`*````$_8!`!P````>]@$`!0```#OV`0`A````0?8!``D```!C
M]@$`&0```&WV`0`M````A_8!``<```"U]@$`'P```+WV`0`'````W?8!``D`
M``#E]@$`"0```._V`0`^````^?8!``<````X]P$`#P```$#W`0`1````4/<!
M``X```!B]P$`!P```''W`0`)````>?<!``<```"#]P$`%0```(OW`0`&````
MH?<!`!4```"H]P$`"@```+[W`0`3````R?<!`!8```#=]P$`"0```/3W`0`+
M````_O<!`!D````*^`$`!````"3X`0`H````*?@!``P```!2^`$`$````%_X
M`0`(````</@!``,```!Y^`$`"@```'WX`0`F````B/@!``L```"O^`$``P``
M`+OX`0`'````O_@!``@```#'^`$`"0```-#X`0`0````VO@!``T```#K^`$`
M%````/GX`0`5````#OD!``H````D^0$`+@```"_Y`0`8````7OD!`!@```!W
M^0$`%P```)#Y`0`,````J/D!`#8```"U^0$`!@```.SY`0`4````\_D!`$0`
M```(^@$`$@```$WZ`0`,````8/H!``<```!M^@$`!````'7Z`0`$````>OH!
M``T```!_^@$`%````(WZ`0`%````HOH!``8```"H^@$`!@```*_Z`0`*````
MMOH!``<```#!^@$`$0```,GZ`0`1````V_H!`#D```#M^@$`+@```"?[`0`V
M````5OL!``4```"-^P$`&````)/[`0`9````K/L!`!\```#&^P$`'0```.;[
M`0`2````!/P!``(````7_`$`!````!K\`0`+````'_P!``4````K_`$`!0``
M`#'\`0`"````-_P!``\````Z_`$`5````$K\`0`Y````G_P!`!$```#9_`$`
M+0```.O\`0`L````&?T!`&(```!&_0$`%P```*G]`0!L````P?T!`"$````N
M_@$`2P```%#^`0`D````G/X!`$H```#!_@$`.0````S_`0`K````1O\!`"\`
M``!R_P$`+P```*+_`0`P````TO\!`#$````#``(`+@```#4``@`C````9``"
M`#@```"(``(`,0```,$``@`2````\P`"`!(````&`0(`$@```!D!`@"(````
M+`$"``@```"U`0(`M````+X!`@"#````<P("`'T```#W`@(`,P```'4#`@!8
M````J0,"`!8````"!`(`(@```!D$`@`7````/`0"``\```!4!`(`%@```&0$
M`@`=````>P0"`$$```"9!`(`&@```-L$`@`@````]@0"`%@````7!0(`%P``
M`'`%`@`4````B`4"``L```"=!0(`!0```*D%`@`&````KP4"``@```"V!0(`
M!0```+\%`@`5````Q04"`!0```#;!0(`%````/`%`@`?````!08"`!,````E
M!@(`#@```#D&`@`#````2`8"``@```!,!@(`"@```%4&`@`'````8`8"``4`
M``!H!@(`%````&X&`@`'````@P8"``8```"+!@(`%0```)(&`@`-````J`8"
M``L```"V!@(`$@```,(&`@`)````U08"`!,```#?!@(`!P```/,&`@`/````
M^P8"`!`````+!P(`"````!P'`@`*````)0<"`!D````P!P(`%0```$H'`@`(
M````8`<"`"4```!I!P(`$@```(\'`@`9````H@<"`!$```"\!P(`!P```,X'
M`@`3````U@<"``@```#J!P(``P```/,'`@`5````]P<"``D````-"`(``@``
M`!<(`@`"````&@@"`!$````="`(`#0```"\(`@`)````/0@"`!,```!'"`(`
M%````%L(`@`'````<`@"`"H```!X"`(``@```*,(`@`$````I@@"`!(```"K
M"`(`&````+X(`@`)````UP@"``<```#A"`(`$0```.D(`@`'````^P@"`!X`
M```#"0(`"````"()`@`5````*PD"``T```!!"0(`$@```$\)`@`"````8@D"
M``<```!E"0(`"@```&T)`@`+````>`D"`!@```"$"0(`*@```)T)`@`-````
MR`D"``H```#6"0(`"@```.$)`@`%````[`D"``(```#R"0(`"P```/4)`@`!
M````TP0``!P$```Q!0``7P,```````"<`0``;0(``*`$````````E`,``,<!
M``#]!@``?```````````````A@(``"L'```+`0```````(,'``#!````=P4`
M`!4$``#Q!0``+````-L#``##!@``)0<```@"```!!```O`4```0'```Q`P``
M`````*8"``#P!0``9`(``+("```/!```@0,```````````````````````#6
M!```404``(4$`````````````/8!``!P`@````````````!_`@``+@0`````
M```C`0``I`4```````!D!P``Y`4``)$&```E`0``<@8``/4$``!N`@``<`$`
M`#4'``#"`0``T0(``"\$``!O`P``4`<``%H```"B`0``,P$``(L'````````
M>P$``.L```"8!@``P`4``%X'``!*!0``S@8```````"4!```8@(``/(````I
M`@``9@(```````#;!```A@8``-X%`````````````*4`````````````````
M``"8`P```````$````#F!@```````,T!````````G00``$@"``"_!0``````
M`/T"``"*!P````````P%````````3P0``,P%``#L`@``)@4``!<`````````
M-````%@```"\`0````````````"U`@``6@0``&4#``!J`P``7P$``(0'````
M``````````````#Z`0``9`,``&\```#6`0```````'\&````````"@<``)``
M````````30,``)L"````````'`,``%\&``#T`0``WP```"@#``#<`0``T`$`
M`+8#``!'`P```````!T'```3!P``)0,``/$```"P!0``T@0`````````````
MJP,``*0`````````RP4``&$#``!Y`P``E00```H$````````C`8``,`!````
M````X00``'H'``#9`P``YP$```````#_!0``3`<``*D!``!8!```Y`$`````
M``!/````O@$``````````````````"\#``!N!P```````+(`````````F`4`
M`&<$``"F!@``X@$``$@&````````*@```/L!``!H`0``5@<``-H#```J!@``
MHP0``%8&``!6!```L08```````"=`@``6P```)0&``"+`P``J0````````"L
M!0``TP```*`#``!Z`0``9P(``,(#```J!P``>P,``"L`````````-@``````
M````````,0(``(,```#D!````````/8$``!Y!```1@<```````#W````````
M``````"3`@``N@4````````7!0``J@,``"L"``!\!P```````'0$```[`@``
M``````````"0`@``C@$``(H$``#<````?@<``%<%``":`P```P(``#T'``!>
M`P``!@$```````!%!````````"\'``"?`P``I0$`````````````9P4``'$!
M`````````````$0&``#;````/P<``$H``````````@(````````I`0``````
M`%8#````````G`0```````#,`0``800``!8#````````)P0``&$`````````
M`````"4$``!W````[@,``&@&````````G@8````&``![`````````!H&``"Q
M!````P````4'``#=!0``N08``,D#``!\`@``&`<``.P``````````````&,!
M````````[@(``)H```"2````G@,```````";`0``*P4``'$"``#S`P``1@,`
M`+X"``"Z`0``W00``-@&``"T`P``XP0``,H$``"J!````````!H'```7`@``
MOP0``!@!``"Q`@````````````#B`P``CP(```````!^`0``_@4``&D!```8
M!@``^`$``"H#``!+`P``<@,``$<$``"6`0``1P```,@!``!Q`P``4`8``#H`
M``!B!@``4P```-<&``!V`@```````"X%```F`@``=08``.T````,!@``!```
M`.0"``!^`P``@P4``(D!``"3!```_@(``&8'``#G!0``%P$```````"?`0``
M#P<``'L"``!^````!00```L'```O!@``-@8```````!2`@``OP````````!W
M`P``_P,````````+````,P4`````````````:`<``"D&``#=`````````/0"
M``!!!P```````-@#``#:!`````````````!H````#0(``'0&````````U08`
M`,<&``!Q````H````/X&``!"`@```````)L$``"Y`P``P`````0$```0!@``
M3`$``)0"``"Y!0``H`$``,$!````````!0````````!.!P``U@(``&,`````
M````Q````````````````````/($````````0`4``'$'````````SP8`````
M```7`P``@P8`````````````4@4`````````````\P0``'<$``"E!@``;P0`
M``@```!>````2@<``+H#``!V!0``W@```(0#```D!```.P4``/D&``"<`P``
M=P(```````!J`0``/@(``,`&``#N!0``O@0```````!Q!@```````(D```"E
M`@```````#4&````````'@<```````!5`0``(@0``#@!````````;00`````
M``"'`@``>04``(`%``#6`````````"$"``!1!@``-P0``#,"````````````
M`)<#``#_!````@<```<#``!K!@```````/$!``#&````\`,``(\```!=!P``
M``````````#I!@``A0,`````````````W0(``"X#``!7`0``]@8```````#E
M`0``_@```$T```#-!```$`4````````V`0``D`,``'T!``"7````600``'\$
M``!S````IP4``%@"``""`@```````$,&``!V`0``_@$```````#G!```````
M`"0`````````^`0``&L$``#&!```60$``"$$```&````GP(``%X"````````
M``````0&``"4!0```````.,&``".`P``/@```"L!```4`@``UP,``),&``!"
M!P```````&P#````````C@0``*,`````````Q0,``%$```"]`@``+`0``"`$
M``#I!````````"X&``#V`@``,`8``%@%``````````````````"I`@``)`,`
M````````````LP$```````!]````)P,```````!T!P```````)$$````````
MS@$``/(&```(`0````````````````````$``$P%```Z!@```````,D%```1
M`0``7P0``/H#``"<````L`,``,0!````````=00``'$$``#7`@``R@4``'P!
M``",`0``````````````````_04``#4$````````0`<``*<&``#0`P``J@8`
M`.T!``"F`````````.\"``````````````````"M!```ZP$``/D$``#?`P``
M*`0```````!F!```GP```!$&``"Y!```Z@,```````#)!```6P(``(P$````
M````Q`(``+X%``!"!0``=@<``-8%``"5!@```````&4'`````````````!L$
M````````]`,``%0```#9`````````$@```"6`````````%8"```W````(08`
M`#P"``!S`@```````/,"````````"`0``+<"``"E!```>0<```````#<!@``
M%0````````#9!````````/P`````````'P4``(L%``#W`0``]P4``'P#``#:
M!@``M`4``)4%```#!0```````````````````````(,$``"_`@``S@(```X'
M``"9`P``_P(```````#T!```/P(``%,!````````Q00``#(!````````RP(`
M`(P``````````````$L!`````````````+P&```)`0``W@$``"8$``"D`P``
MS04``',!```S!```$@8``(L$``!B`````````"\```"B!@``.`(``%D"``"!
M!P``20<``(T%```9`````````*T```#O`P``TP8``'P%```R````O04``,H"
M````````^`8``+@&``!;!0``1`$`````````````'0(``"`'``#=!@``````
M``X%````````8`$``#D"``!#`@``NP$``(`#````````*@$``$8```#0`@``
M%08```````!_````0@,``#<'```M`0``,00``.$!````````T@4``+0"``#H
M`0``5`,``/@#``!]!````````*(#``#4`@``8@,``.L%`````````````%\`
M```?`@``,@,``/P"````````<P0```````""!@``-P4``#H%```8!```````
M`'8```"C`P```````)<%``!B!0``$@(``&P!```B`0```````(X`````````
M:@4```````#%!0``&@$``.`!````````DP,``)@`````````A04``!@`````
M````+`4``(8$````````'````)L&``!J!@``^P(``(4!````````3`,``&H'
M``!Z!```$`0``&4```!4!0``Q@8``'0"``#@``````````````"W`P``=0,`
M````````````````````````````7`$````````Z!P``?@(``&P`````````
M`````(@"````````T`8```L"```/!0``;0$``"T"``#@!0``YP(``$\#```-
M`0``8````&<`````````P08``-D"``"[!@``````````````````Z@```+($
M```H`````````#$'````````\P```*H%``#]`0``U00``!H`````````````
M``````!B!````````,H&``!A!@``3@`````````3`@````````````!*!```
M%P8``",````_````@@4``*@$``"X`@``D04``.0```!"!````````+@%``!!
M!0``'P$``+@!````````FP4```````"U`````P<``"T'`````````````+`$
M````````:P<``'L%``!F````````````````````S@0```<!``!9!@``````
M``````#A!@``8@<``#L!```[!```=0(``.T&```Y!```(0<``/\&``!S!@``
M#`$```````!)!@``GP8``+P$``!G!@``"04``$<'``````````````````!S
M`P``BP```'L'``#2`P```0(``*,!```L`P```````+,$````````)@<```$#
M``#K`@``<````&\&``#8````$P8``$4#``!?!P``\P4``.H&``#1!```/P,`
M``````#[!0``9P<``*$&``#2`@```````&L!``#1````BP8``#````#(`@``
MH00``.P!``#B````:@(``*8!``!<`@```````#@#````````708``"L$``!@
M`P``X04```````#/````E@4``-D&``!%`@````````````"5`0``````````
M```(!@``1@4````'````````20,``&P%``!5!P``TP$``(`!````````````
M`````````````````/T$``!L!```!@0``#X#```?!```WP0```````!<`P``
M?@0``!$"```M!@``RP0``!L#````````@`8``'4````%`P``D0$```````"L
M``````````0"``!Y`0``*00``#8'````````>@```'0``````````````&(!
M``!4`0``#0```#\!``#>`P``M@8``#D'`````````````"8`````````````
M``````"(!0``CP0```````!&!````08```````"S````4`$``)(&``"R`0``
M%@(``%`"``"'`P``<`<``/4"``"V````]`8``/$#``!1`0``X@0``.\$````
M````T08````````O`@````````T'``!0`````````%0"````````308``($"
M````````'08```````#U!@``C08``+L```!>!@```````/D!``"$````1P8`
M``````!U`0````````````!$`@``2`$``!4#````````)`$``%D#``#U````
MF@4``%,%``#>!@``.0$``!L'````````B`$``%P%``!7!```0P<``)H"```]
M`P``$0,``*X%``!)`0```````)\$````````/@$``&H```!^!0``IP,``*D&
M```@`````````*X```!+````$@```*8$```!`0``>@8```````#5`0``N@``
M`.0#``"V`0````````````!H!`````````````"^````N0```'($````````
M$0```%\%``#F!```(`,``*L!``#F````(@(``*`&``"]`0``\@$``#L&``"$
M!@```````($````2!```NP(``#T$``!_`0``&P```+,"````````O0,``'4%
M``!E`@``A0````````#-`@``Q08``'\%````````5P(``)\%``#P`0``K0,`
M``````"*!0``<@$``+$```"!!````````/$&````````$@<``&\"````````
M[0,````````0`@``%`$``"T#``!$!````````-4#``#?`@```````'T&``!)
M!0```````-L%``"'!````````+,&``#W`@``KP0```4"````````(0```/P%
M``!W`0``/`,```L&``#T!0``\`(``'$%``"X`P```````-0#``#H`@``6@8`
M``````![!```00,````````J`@``G`4``,8%``#:!0``804`````````````
M`0<``'H%``!'`@``/````+P```````````````\#`````````````!$'```X
M!@``%`0`````````````80(```D'```S`P```````$`!```]!0```````)P&
M`````````````(<!``#)````Z0,``.4&``"]````BP$``+T$````````-@,`
M`#4"```=!0```````(@&``"N!```!P(``.L$``"_`P``````````````````
M200``%(&``"U!```<P4``,0#````````:P,``-H!``"P`0```````),%````
M````RP8``*(%````````"0,``'T#```3````#00``,4!```+!````````$$"
M``!5````XP4```````"L`P```P,``!D$```'!@````````````#J!```[`4`
M``H#``"H!0``MP0``!8```!4!```-P$``%4%``"D`@``^0(```````"``@``
M(P4``/L#``!#`0``:@0`````````````/P4``!,!````````\@,``,<$``"_
M!@```````$@#````````S0,``%T%``!\!```/@8``/D````>!0``1@$`````
M``"K````5@$``.@$``"-`````````,X#```Y!@````````````#+````AP``
M`-T#`````````````,P$````````4P<````````9!0```````.<#```Q````
MS`,``(D%```0`0``#@```&P'``"G````SP0``&,'```9!@``V@```"$!``"B
M`@``F`(``%X$```M!```)`<``&4!``!X`@``%0<``!T$``#9!0``G`(``%T`
M````````X`0``&8%``!`!@``Y@(```````"R!0````````0#```>!```````
M````````````!`4```````"3`0``AP8``'0#``"O`P``^P8```````"2!```
MA0(``!\&````````W`,```````!;`0``7`<``!0#``#Q`@``-`<``'0%``"H
M`P``70$``"P&``````````````````"P!@``X`,``$X#``#\!```.P<``'@$
M````````+P4``&D&``#4````H`(``/D#````````*`4``(<'``#M!0``<@(`
M```````I``````````8"````````#`<``.4$````````4P8`````````````
M*`<```(&````````1@(``````````````````-<!``#-````-P,```0!````
M````+`<``','``!D!@```````($%``!N`0``KP(``,0$```N`@``500`````
M`````````````(0%```3!```D0(``%@&``#2````K@,``$H&```X!P``?0<`
M``````#0!```&P4```````"Z!`````````````""`0`````````````C`@``
M6@$````````<!P``,P<``"`"``"H`@``)P<````````Z!```B0(``&L```#S
M!@``.04``#P!```1!0```````.4%``"*````'`$``*L$``")`P``!@4`````
M```B!0``70(```````#J`0```````/H$````````WP$``$<%````````%`8`
M`(@```#I`@``-`0``.4#``"K!0``S@4``,<#````````/P0`````````````
M`````.H"``"A`P``_@,``!@%```S````]@4``'@'````````<`8```````#+
M`P``;P$``!X#``!9!0```````(8```"#`0```````+0```"/`P``A`0``#`$
M``"W`0``F0(``*`%``"V`@``Y0(````````R!```H0```"P"``#(`P``"P,`
M``````",!0```````!P&``"L!```````````````````:P4```````#8`0``
M``````X$```)!@```````"4```#A`P``G@``````````````<@4``"`&````
M````%0$``#X%```=````S`(``)X%``"*!@``C@(``"$%``"6`@```````$$&
M``!"!@``H0$``*$%```G`@`````````````M````2P<``)4"``!2!```````
M```````T`@``^`4``'0!``!=`P``-0$```````!.!```5@4``*($```)````
MPP4``(,#````````6`$``&D"``#L`P``&0(```````#"`@``6P<``$,#```\
M!```D`$``.8!``#C`P``400`````````````K`(```X"```<`@``3@$``$@$
M```*`````````$X&``#\`0``+@```(T!````````+@<``.T"``#I`0``SP$`
M`&P"`````````````-H"``##`@``)P```+,#``"2!0```````&X````0````
M`````(T$```;`0``<`0``'<'`````P``WP4``%0'``"R`P``"`<``(T#````
M````C0(``&<!``""`P``OP$``'@&``!N!```J@```$X"``!D!0```````(P#
M```P!P``@@0```````"\`P``/@0``!@"````````-P(``)(#``""``````0`
M``````````````````\"```5`@``P@```+L#````````T@8``#`%``#N````
MP04```````!(!0``%`<``%H'```"!```7@$`````````````V0$``$L&``#Q
M!```;@8``#@%```\!P``F@$``.$```"\`@``O@,``!8$`````````````)D%
M``#J!0``]0,```````!$!P``&0,``.P$``"5`P```@,```H&``"/!@``````
M`&T&``!A!P``+@$``"<&````````9@8``&D#````````8`8``+4#```*`@``
M20(``!\````-!@``9`$`````````````3P(`````````````I@4``#(&``"Q
M`0``#@8``-(!```U!0``A@$``%P`````````/`8``.8#```:!0``NP0``*T"
M````````@````'H#``")!@``R`4``(4&``#=`0``-0,``.\!````````````
M``P```"6`P``8P(``)X"``#R!0``````````````````9`0`````````````
MZ0```+8%``"C!@```````!X!``#!`P``/08``'`%``"$`0``:P(```````!-
M!```Z`8```````#(!@``CP$```````##````'P<```````!C!```=0<`````
M```-!0``/0$``%$'``!M`P``(P8``$0````7!P````````````#8`@``20``
M`#L#```7!````````.\```!L!@````````H%``!3`P``!P4``"0%``"W!@``
MJ00```<$``!'`0``108``````````````````"`%````````L````*\````Q
M!@``\`8``.,`````````)`8``!(#``#!!```VP8`````````````?P,```P$
M```8`P``K`$```````"Y`0``Y`8``,X`````````D@$``(`'``#%`@```@4`
M```````T`0```````*@````L`0``#@,```````"0!```&0$``*(```!0!0``
M`````.L&``#5`@``````````````````"00``)D!``";`P``J@$```P"``#5
M!0``]04``/4!```-`P```````)T!``#%`````````,8"``!7````.````"@"
M`````````````/T#``"G!```NP4```````#"!0```````$\!```=`0``[@8`
M`/H&``"6!```4`0```````"M`0````````````"D`0``J04``+`"``!E!@``
M`````-8#```6!0``I@,````````:`@````4```````"(!P``@@<``-$%``#C
M`0``K@8``.,"``#"!@``JP(``'`#``"0!0``KP$```````#3!0``I`8`````
M``"U!0```````,\%``!M!0```````/@"````````WP8`````````````'P,`
M`'\'``"T!```J`8```````#$!0``IP$``$,```"=`P``&P(```````!,!```
M``````(!``"7`@``3P4``$`#``![!@``W`(```````!(!P``8P4``($&``!$
M`P``Y0```$T%``#$!@```````````````````````-````!;`P``MP```'D"
M``!#!0```````%0&``#7!0``2@(``#T````M!0```````'P&``#@`@``8`0`
M`!H#``````````````````##!````````-,#``#B`@``>`,``)0```")!P``
M&@0```````````````````````!!!```&P8`````````````4@<````````I
M`P``_0```%<#`````````````",'``!1`P``.@(``),```#S`0``50(`````
M````````#P8```````"9!````````$(!``!?`@``2P0``$T'``!N!0``L0,`
M``````"$`@``3P8````````F`0```````-L!````````L04``'('``#<!```
M:04``+4&```G!0``/@<``$4'``!*`P``:00``,\#````````:`(``*\%``"`
M!```=@,``-$#``!0`P``F`$``.$"``!,`@``P@0```````"(!```;0<``'(`
M``````````````````#Z`@```````#(%``!H`P``!P<``",#``!^!@``````
M`.@#``"7!```M0$``,P&``#/`@``*`$``)<!``#+`0```````%@'``!3`@``
M6@,``(8%````````,`(``/@```"9`````````,P```"N`@``-`4```````#7
M`````````*4%```````````````````F!@``F@8``.X!```A`P``.P```)D&
M``!!`0``Q@,``(P"```&!P``%04``&4%```````````````````B`P``B@(`
M`!X```"%!P``5P<``*T%``!%````=P8``#@$``##`0``U`$``$(```!E!```
M*0<``&\%``#W!@``5@````X!``#Z!0``30(``/X$``!:`@``HP4```8&``#I
M!0``(@```$4%````````3`8``)@$``"=!@``P0(```,$`````````````+X&
M``!N`P``%@8``.\&````````?04``.@````T`P``6@4``!(%```/`0``'@(`
M``````!H!0```````"\!```]`@``30$``#`!```E`@``U0`````````E!0``
M9@,``/8```!Z`@``D`8`````````````HP(```````"N`0``_`,``&$!``"X
M````D0```````````````````)4````F`P``#P``````````````B@,`````
M``!]`@``QP4``,8!````````A@,``"('``">`0```````-L"``#)`0``"@$`
M`%4#``!Y````U`0``,,#````````R@$``!,#``````````````````!O!P``
M\`0``'8$```(`P```````#\&``#8!````````*$"``!M````CP4``!D'````
M````60<``"H$```"````8`(``!P%````````^04``$X%````````R`````P#
M``"+`@```````*4#```(!0```````#D#``#_`0``$`<``%T$```)`@``````
M`$P```":!```T0$``"D%``#H!0```````'@`````````9@$``/````#O!0``
M2P(``+<%```%!0```````%(```#K`P``2P4``-8&```Y````R`0``)T%``#`
M`@``8`<```,!``!Y!@``1`4``.`&``````````````<````V!0``*P,``/H`
M``#)!@``%@<```,&``#*````>`$``!(!``#W`P``Y@4``*P&``!3!```4@$`
M```````&`P``N0(``$\'```4````D0,``*H"``!<!```UP0``#H#```P`P``
M]````$`$````````W@(``+(&````````!08``-P%``!C!@``P`,``,H#``#M
M!```6P0``)0!``"(`P``:0<``(8'`````````````!,%``".!@``I`0``#('
M``"*`0``0P0``)L````B!@``\@(``'8&`````````````+8$````````$`,`
M`.P&``!@!0```````/L$``"6!@``X@4``"L&`````````````/<$````````
MN@(```````"T`0``1@8```````"O!@``5P8``#P%````````00```#8$````
M````,@(````````!!0```````(X%```=`P``IP(`````````````4@,``"@&
M``#4!0``_`8```````"H`0``8P,``!$$`````````````%4&```G`0``LP4`
M``````#G!@``TP(```````"'!0``@P(``+H&``!8`P``@0$```````#N!```
M)`(``-0&````````-0```+T&``#)`@``J0,``%D`````````,0$```````#B
M!@``M`8```L%``!%`0``7`8``+@$```W!@```````%L&````````9````"4&
M``#'`@```````)T```#_````!0$``$`"``")!```:0```-@%```@`0``G@0`
M``````"2`@``%`4````````Z`0``T`4````````6`0```````'@%``#'````
MS08`````````````7@4``",$``#V`P``*@4``.<```#`!```JP8``!X&``!*
M`0``,P8````"``!G`P``W@0``#8"`````````````/L```"M!@``EP8``%$"
M````````-`8````@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AI
M;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`
M(&%T(``B)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S(B!I<R!N;W0@82!V
M86QI9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO
M<F1E(%)E9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD+@`B
M)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@
M861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T
M(&-R96%T960Z("5S+@`E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H
M)2XR9B4E*0`E9"`E<R!A;F0@)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W
M;W)D(&5X<&ER97,N`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&
M:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@
M0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@
M06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!I
M<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS
M(&-H96-K960@8F5L;W<N($-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I
M;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`"5S(&ES
M(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O
M9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T
M97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`E<SH@5&AI<R!M97-S86=E(&UA
M>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F
M(&9O;&QO=VEN9R!A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H
M92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN`"P@9W5S
M=&EN9R``+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E
M<P`M+2!S96QE8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`
M,C0@:&]U<G,`/%!R979I;W5S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U
M:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R
M960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@
M;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I
M9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T
M92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C
M<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M
M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@
M;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE
M<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R
M>7!T(&$@;65S<V%G92X`04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@4F%I
M;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O
M=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!
M8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D
M96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@26YF;W)M871I;VX`
M06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!
M9&0`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(
M97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C
M:&EL9"!G<F]U<"!T;R`B)7,B`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@
M(B5S(@!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E
M<G,`061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E
M8F%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O
M;VL`061D('5S97(`061D960@(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U
M;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N
M`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W
M+@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!"
M;V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S
M97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L
M9V5R:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I
M8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O
M=7(@<VED97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I
M;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R
M;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R
M;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L
M=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A
M;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W
M;B!E<G)O<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`
M06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD
M($)A<F)U9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A
M=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`
M07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`
M07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_
M`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY
M('-U8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU3
M0TE)+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!
M<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R
M92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O
M;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N
M`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN
M`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T
M97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U
M:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A
M8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T
M:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O
M;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?
M:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T
M:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO
M="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!2
M97%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@
M56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`
M075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]L9&%P
M.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@
M1&ER96-T;W)Y+@!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R
M=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T
M:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$
M2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL
M960N`$%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"X`
M079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C
M:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R
M9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L
M=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E(&=R
M87!H:6-S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`0F%S96QI;F4`0F5L
M87)U<P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!":7)T
M:&1A>0!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD
M+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O;&0`0F]L:79I80!";V]K
M;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA
M(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W86YA`$)O='1O;0!";W5V970@
M27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`
M0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K
M:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I
M;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`0V%C:&4@:6YI="!W87,@;F]T(&-O
M;7!L971E9"X`0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86X@
M;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R+@!#86X@;F]T('=R:71E('1O(&9I;&4@(B5S(@!#
M86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N`$-A
M;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;B=T(&]P96X@9FEL
M92`B)7,B+@!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#
M86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A
M<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&
M:6QE)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N
M`$-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O
M<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@
M9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE
M<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P92!697)D90!#87!T:6]N
M`$-A<G)I97(`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S
M`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L
M;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H
M25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`
M0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T
M86EL<P!#97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#
M:&%D`$-H86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA
M;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D
M(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S
M=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG
M=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H
M96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H
M1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@07!P
M;&EC871I;VXZ`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE
M`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y
M;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-H<FES=&UA<R!)<VQA;F0`
M0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R
M($U33V9F:6-E('1A9W,`0VQE87(@475E<GD`0VQE87(@;W5T('5S97(Z("5S
M`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA=&4`0VQI
M8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD
M;W<`0VQO=61S`$-L;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I
M($ES;&%N9',`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#
M;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#
M;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE
M;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T
M97)S`$-O;F1I=&EO;@!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R
M96YC97,`0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M
M87)T<&AO;F5S(&%N9"!/=71L;V]K+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O
M9B!D871E+@!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#
M;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I
M;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F
M=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U
M<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`
M0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',`0V]N
M=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S
M(&)O;VLN`$-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#;VYT
M96YT<R!O9B`B)7,B`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;V]K:64`0V]P
M>0!#;W!Y(&9A:6QE9#H@)7,`0V]P>2!S96QE8W1I;VX`0V]S="!)1`!#;W-T
M82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE
M<W-A9V4Z(`!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@`$-O=6QD(&YO
M="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I
M9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N
M;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A;&%N
M8V4N("5S`$-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!#;W5L
M9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O
M=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO
M="!D96-R>7!T(%!'4"!D871A.B``0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%
M(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T
M(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E;&5T
M92!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T97)M
M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T
M(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H
M(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@
M=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L
M9"!N;W0@;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@(B5S
M(BX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E
M<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U;&0@
M;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@
M;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#;W5L
M9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A9"`E
M<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E
M<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T
M(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R
M871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R
M:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`
M0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L
M9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N
M;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R
M979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER("(E<R(N`$-O
M=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E
M(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K
M=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R
M861E('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU
M<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E('1H92!C
M;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@
M;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R
M(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD(&YO
M="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK("(E
M<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P
M9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T('=R:71E(&-O
M;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO
M>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN
M`$-O=6QD;B=T(&=I=F4@=7-E<B`B)7,B('1H92!F;VQL;W=I;F<@<FEG:'1S
M(&9O<B!T:&4@9F]L9&5R("(E<R(Z("5S`$-O=6YT960@=&5X=`!#;W5N=')Y
M`$-O=7)S97,`0W)E871E`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N
M90!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D
M:70@8V%R9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0@-"!0:&%S97,`
M0W5R<F5N="!397-S:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`
M0W5R<F5N="!5<V5R<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I
M;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O
M;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL
M;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC
M+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$4TX@*'-E
M92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B
M87-E+F1B+FEN=')O+61S;BYP:'`I`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`
M1&%T86)A<V4@3&]O:W5P`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C
M=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB
M97)S`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F
M875L="!)9&5N=&ET>0!$969A=6QT(%-H96QL`$1E9FEN:71I;VYS`$1E;&5T
M90!$96QE=&4@0V5L;`!$96QE=&4@1W)O=7``1&5L971E($QO9P!$96QE=&4@
M4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C
M96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T
M96UP;&%T90!$96QE=&4@;65S<V%G97,`1&5L971E('!E<FUI<W-I;VYS(&9O
M<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U
M8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E
M;G1I='D`1&5L971E('-U8B!F;VQD97)S`$1E;&5T92!T:&4@8W5R<F5N="!C
M;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&5D('-E='5P('5P
M9W)A9&4@<V-R:7!T("(E<R(N`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$97-C
M<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN
M($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F
M;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$
M97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO
M;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C
M=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$
M:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T`$1I<W!L87D@9F]R96-A<W0@*%1!
M1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J
M:6)O=71I`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M
M86EN=&5N86YC92YP:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE
M(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC
M80!$;VUI;FEC86X@4F5P=6)L:6,`1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3
M:6=N('5P+@!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T
M960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES
M=`!$<G5G<P!%+4UA:6P`14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F
M;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N`$524@!%
M8W5A9&]R`$5D:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES
M<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S
M`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E<R(`
M161I="!P97)M:7-S:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L(%-A
M;'9A9&]R`$5L96UE;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I
M;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I
M;VX`16UA:6PM=&\M4TU3($=A=&5W87D`16UO=&EC;VYS`$5M<'1Y(&UE<W-A
M9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I
M;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E
M>'0_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!Y96%R
M`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI
M8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U
M<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E
M=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`16YT97(@=&AE(&QE='1E
M<G,@8F5L;W<Z`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R
M;W(@8W)E871I;F<@8FQO8VLZ("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@86YC
M:&]R.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,`17)R;W(@9V5T
M=&EN9R!C;VYT96YT.B`E<P!%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,`
M17)R;W(@=VET:"!E;6%I;"!M97-S86=E+@!%<G)O<B!W<FET:6YG("(E<R(N
M`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU
M=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@
M;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN
M=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@4VED
M96)A<@!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E
M9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L
M;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F
M97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A
M:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y
M(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O
M(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T
M;R`B)7,B+@!&86EL960@=&\@<F5T<FEE=F4Z("5S`$9A:7(`1F%L:VQA;F0@
M27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z
M`$9A>`!&87AE<P!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&
M97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6=L
M970@0T%05$-(00!&:6=L970@9F]N=`!&:6II`$9I;&4`1FEL92!#;W5N=#H@
M)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL
M92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D
M<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&
M:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O9P!&;VQD97(@
M)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R
M<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O
M<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@
M<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE
M<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@
M<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S
M`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE<P!&<F%N8V4`
M1G)A;F-E+"!-971R;W!O;&ET86X`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L
M>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]M`$9R;VT@
M=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1V%B
M;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA
M`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5O
M<F=I80!'97)M86YY`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=L;V)A
M;"!/<'1I;VYS`$=O`$=O961E;`!';V]G;&4@36%P<P!';V]G;&4@4V5A<F-H
M`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N
M9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU
M<W0@8F4@;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O
M=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R;W5P7VQD87`Z(%5N
M86)L92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U861E;&]U<&4`1W5A
M;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B
M;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@
M<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S
M97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H
M96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA
M>F4`2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)
M<VQA;F1S`$AE879Y(%0M4W1O<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE
M:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E
M`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M
M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D
M<F5S<P!(;VUE($1I<F5C=&]R>0!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@
M2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E
M;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S
M86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@
M;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+
M;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA
M8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM
M;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T
M92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA
M8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE
M('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E
M<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@
M)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L
M(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@
M>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M
M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H
M8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L
M:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(
M=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@
M;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T
M82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N
M;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#
M2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W
M($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS
M('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P
M;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O
M=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@
M17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T
M=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S
M<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO
M860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@
M4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL
M97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!)
M;7!O<G0L(%-T97`@)60`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I
M96QD<SH`26Y?<V5R="!2;W<@069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E
M(&=I=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!)
M;F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A
M9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E
M9"!F=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED
M=6%L(%5S97)S`$EN9&]N97-I80!);F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T
M:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N`$EN<V5R="!#7V]L=6UN($%F=&5R
M`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN
M<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R
M('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T
M:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@
M;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E
M`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!)
M;G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R
M97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D
M.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T
M(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S
M<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H
M(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN
M<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S
M=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`
M26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I
M;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R
M(&QI<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI
M9"!:25`@9&%T80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H
M($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T
M:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!L:6-E
M;G-E(&ME>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV86QI9"!M
M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O
M<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I
M;VXN`$EN=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D=6-T(&-O9&4N
M`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B`$EN
M=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN
M=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`26YV97)T('-E;&5C=&EO
M;@!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)<VQE
M(&]F($UA;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S=65R`$ET86QI
M8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@*$E33RTR
M,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I
M9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2
M:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S
M('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I
M97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME
M>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U
M8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T
M:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO
M<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA;F=U
M86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L
M9@!,87-T(%!A<W-W;W)D($-H86YG90!,87-T(%%U87)T97(`3&%S="!5<&1A
M=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA
M<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y
M(&9O<B!N;R!B;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@
M=F%L=65S`$QE<V]T:&\`3&5V96P`3&EB97)I80!,:6)Y86X@07)A8B!*86UA
M:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!286EN
M`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@
M4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG
M:'0@4VYO=R!3:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK('!O:6YT<R!T;SH`
M3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H
M96X@9&ES<&QA>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES="`M('5S97(@
M8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4
M;W!I8W,`3&ES="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T
M+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M
M56YS=6)S8W)I8F4`3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S`$QI<W1I
M;F<@=7-E<G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D
M+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z
M(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O9B!P<F5V
M:6]U<R!S>6YC('-E<W-I;VX`3&]G(&]U=`!,;V=I;@!,;V=I;B!487-K<P!,
M;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D
M('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@
M=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN
M(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,=7AE;6)O=7)G`$U-`$U/
M5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+@!-4T<`
M36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC
M(&]F`$UA9&%G87-C87(`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:V4@;&EN
M7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N
M86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@
M:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@
M8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87!P:6YG<R!S
M=&]R960N`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA
M9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W
M97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H:6YG(&9I
M96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D:70N
M`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T
M(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!.=6UB
M97(@;V8@4&]R=&%L($)L;V-K<P!-87AI;75M(&QE;F=T:`!-87D`36%Y;W1T
M90!-961I8VEN90!-96UB97)S`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S
M<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I
M9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S
M<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@5V5A=&AE<@!-971A
M<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA
M8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES
M=')A=&]R+@!-971A<D1"(&ES(&YO="!C;VYN96-T960N`$UE=&AO9`!-971H
M;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-971H;V0@;F]T(&1E9FEN960N($-A
M;&QE9"!M971H;V0Z("5S`$UE=')I8P!-97AI8V\`36EC<F]N97-I82P@1F5D
M97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA
M<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:6YI;75M
M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D`$UI<G)O<@!-:7-C
M96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`
M36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I
M="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI
M<W-I;F<@;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA
M9V4@36%I;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-
M;V1E<F%T90!-;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D=6QU<P!-;VQD
M;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE
M87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F4@9FEE;&1S
M(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N`$UO<F]C
M8V\`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY($-L;W5D>2!A
M;F0@5VEN9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V
M92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`
M375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I;6%P(%5+(&UA<`!-
M=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R
M;6%T:6]N`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L
M($D@1&\@3D]4($%G<F5E`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.971H
M97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%52
M3`!.971S8V%P92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI
M8WD@55),`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I
M;VX@55),`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T
M:69I8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T
M=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@36]O
M;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@<&%S
M<W=O<F0`3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+@!.97<@<&%S
M<W=O<F1S(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`
M3F5W<V=R;W5P<P!.97AT`$YE>'0@-"!0:&%S97,`3F5X="!O<'1I;VYS`$YE
M>'0^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@
M879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N
M8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/
M(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A
M="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O
M=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@
M8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10
M(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D
M97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!I8V]N
M<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P<F]V
M:61E9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N
M`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A
M=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V
M:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K
M('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU<',N`$YO('%U
M;W1A('-E="X`3F\@<G5L97,`3F\@<V5P87)A=&]R('-P96-I9FEE9"X`3F\@
M<VED97,`3F\@<W5C:"!F:6QE`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A
M:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D
M('-E;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.
M;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y
M;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`
M3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I
M`$YO<F9O;&L@27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@
M36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.
M;W0@82!D:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S
M=7!P;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.
M;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F
M(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D
M(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T
M`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`
M3V9F:6-E`$]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N
M="X`3VQD('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`
M3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S
M+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R
M97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES
M=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I
M;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@
M97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-
M24U%('!A<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E
M<F%T:6YG(%-Y<W1E;0!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R960@
M3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ
M:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E
M;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@
M4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B
M;&4N`%!%05(Z.DUA:6P@8F%C:V5N9`!01U`@1&EG:71A;"!3:6=N871U<F4`
M4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O
M16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A
M:6X`4$T@4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S
M`%!-(%-U;@!032!4+5-T;W)M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN
M9P!07TA0(%-H96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI
M86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE
M80!087)A9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H
M86YG960@<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O
M<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O
M<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S
M<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D
M`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F;W)M
M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O
M<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@(B5S
M(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO;G,`
M4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I
M;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER
M;@!0:7AE;',`4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E
M;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI
M<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N
M;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A
M('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O
M<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E
M;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I
M;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S
M92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R
M;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E860@
M=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T
M97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y<&4@=&AE(&YE=R!C
M871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`
M4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES
M('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)
M34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C
M:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E<75I<F5D($Q$
M05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER
M960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S
M<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE
M=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`
M4')I;G0@9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E
M<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B
M;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV
M871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T
M;R!2:6-O`%!U<F=E(&UE<W-A9V5S`%%A=&%R`%%U97)Y`%%U;W1A`%)302!0
M=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@
M16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I
M;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S
M86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@
M8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E
M<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S('EO
M=7(@;&%S="!A8W1I;VX`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@365N=2!%
M;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I;VYS
M:&EP($)R;W=S97(`4F5L;V%D`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M
M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V
M90!296UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN
M9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R
M)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI
M<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U
M<V5R.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE
M9"!E<G)O<F-O9&4Z(`!297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@
M9F]U;F0N`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF
M:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@5D93
M(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I
M;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"!&:65L9`!297-E=`!297-E="!0
M87-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W1O<F4@3&%S="!1=65R
M>0!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E='EP92!N97<@<&%S<W=O
M<F0`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I
M=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@
M=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E
M(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`
M4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3
M+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E
M9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L
M92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U%,('-T871E;65N="!F;W(@
M=F%L=64@;&]O:W5P<P!34T@`4U5#0T534P!37U%,(%-H96QL`%-A`%-A:6YT
M($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I
M;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@
M1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN
M;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A
M=61I($%R86)I80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@3W!T:6]N
M<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP
M="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D
M("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T
M('1O.B`B)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`
M4V5A<F-H($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L
M96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@
M82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;`!396QE
M8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!396QE
M8W0@;F]N90!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T
M:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T
M:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM
M:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N
M=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI
M;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T
M8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C
M="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R
M=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@
M86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V97(@9&%T82!W<F]N
M9R!O<B!N;W0@879A:6QA8FQE+@!397-S:6]N($%D;6EN`%-E<W-I;VX@240@
M97AP:7)E9"X`4V5S<VEO;G,`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W('EO
M=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I
M="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C
M97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG
M=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A
M<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI
M;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P
M9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S
M<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN
M9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D
M(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E
M;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N
M9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG
M(&EN/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R
M`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@
M365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T
M:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3
M:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@
M:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3
M:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I
M;FET>0!3:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K
M*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P
M`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE
M`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W
M(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@
M4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@
M=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US
M`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F
M<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I
M82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M
M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E
M='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I
M;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA
M<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O
M=P!3<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R="!Y
M96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3
M=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP
M(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8F1I
M<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`4W5B:F5C=`!3=6)M:70`4W5B;6ET
M=&5D(')E<75E<W0@=&\@861D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A
M;FYO="!L;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B965N(&%P<')O
M=F5D+@!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@861D960@(B5S
M(B!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O
M<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@9&5L
M971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B(&9R;VT@=&AE
M('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN
M(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!U<&1A
M=&5D("(E<R(`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U;6UA<GD`
M4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T
M`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R
M=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@36%Y96X`4W=A
M>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>6YC(&QO9R!D96QE=&5D`%-Y
M;F--3`!3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B
M(%)E<'5B;&EC`%0M4W1O<FT`5"U3=&]R;2!A;F0@5VEN9'D`5"U3=&]R;7,`
M5"U3=&]R;7,@16%R;'D`5%-6(&9I;&4`5&%B;&4`5&%B;&4@4')O<&5R=&EE
M<P!486)L92!3970`5&%B;&4@<')O<&5R=&EE<P!486EW86X`5&%I=V%N+"!0
M<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET960@
M4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E
M;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``
M5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!496UP
M;&%T92`B)7,B(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`
M5&5X=`!497AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)
M4RTV,C`I`%1H86EL86YD`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I
M;&%B;&4N`%1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"X`5&AE($AO
M<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T
M("(E<R(`5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"X`
M5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F
M=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`
M5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N
M96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E
M<FUI<W-I;VYS+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V]N=&%C="!)
M1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S
M(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S
M=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!D
M971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E
M<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES
M="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@
M;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L
M:7-T('=A<R!N;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E
M<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL92`E
M<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H
M;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A;FYO
M="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE9"!N
M;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI
M<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L;"!S8W)E96X@;6]D
M92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X
M<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A
M8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B
M86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@
M<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I
M;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G
M1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N
M7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF
M('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R
M+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@;&5F
M="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I
M;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`
M5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S
M(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H
M870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4
M:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A
M9V4`5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+@!4:&4@
M;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP
M=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO
M="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI
M;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T
M:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E
M;2X`5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA
M<F%C=&5R+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG
M:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S
M:6YG;&4@8VAA<F%C=&5R+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L
M971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG
M;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C
M:69I960@<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N`%1H92!S<&5C:69I960@
M<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D
M;V5S(&YO="!E>&ES="X`5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M
M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+@!4:&4@=&]P(&%N9"!B;W1T
M;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@
M9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P
M;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A=&AE<BYC
M;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE;65S(&1I<F5C=&]R>2`B
M)7,B(&YO="!F;W5N9"X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE
M+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN
M;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F
M:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S
M="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@861D
M:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE
M;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M
M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE
M('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S(CH@
M)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M
M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@
M<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA
M>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R
M;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F
M="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E
M<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN
M(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U
M<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN
M(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R
M:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&ES($E-
M05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4
M:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E
M+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE
M+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E
M<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O
M=VEN<&QC+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE
M('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S
M:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L
M>2!G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I
M<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T
M<#HO+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@
M;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@
M9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE
M;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F
M(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`
M5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!2
M1T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O
M<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H
M:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@
M;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD
M97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI
M<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES
M(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@
M;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L
M96%S="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N
M9"!G>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I
M=F%T960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD
M;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N
M9&5R`%1I8VME=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I
M;64@<V5L96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP
M*3H`5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE
M($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC
M:VEN9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4
M;VUO<G)O=P!4;VYG80!4;V\@;6%N>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@
M=&AE(&QA<W0@;6EN=71E<RX`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L
M871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4
M=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T
M86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@
M8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T
M(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR86EN90!5
M;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@
M97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L
M92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`
M56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-H96-K(&9I;&4@
M<VEZ92!O9B`B)7,B+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E
M<R\E<R(N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L
M92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL
M92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L
M92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!6
M1E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R("(E<R(N`%5N
M86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O
M;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C
M=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N
M`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M
M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L
M>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&
M4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L
M92!T;R!D96QE=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@9&5L971E
M(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R
M<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E
M(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N
M`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN
M9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O
M;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I
M;&5S:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E
M=$9I;&53:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@9FEL93H@`%5N
M86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O
M(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@
M97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE
M('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S
M+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N
M("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C
M=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T
M;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W
M<FET92!61E,@9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L
M('%U;W1A('=I;&P@8F4@97AC965D960N`%5N9&5R;&EN90!5;F1O($-H86YG
M97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS
M92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P
M;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I
M`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3
M=&%T97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N
M:71S`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I
M+@!5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO
M=VX@;&]C871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S
M<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP
M<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T
M92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC
M:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W
M:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S
M<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E
M;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E
M<R(N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A
M;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P
M97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`
M57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@
M:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R("5S(&ES
M(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5
M<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I
M;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<B!A8V-O
M=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L<F5A9'D@
M97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES
M=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N
M`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L
M:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=64@:7,@;W9E
M<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E<P!686QU97,@=&\@
M<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R:69I
M8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A
M;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L
M(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6
M:65T($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E
M>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"
M<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I
M;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%23DE.1R$A
M(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=)3B!V:6$@2%14
M4`!786QL:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A
M<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!7
M96(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L
M("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U
M*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D
M:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA
M<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H97)E:7,@
M075S=')A;&EA(&UA<`!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E
M;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!I
M;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@
M*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T
M86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7
M:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5VES:&QI
M<W0`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7<F]N9R!N=6UB97(@
M;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`
M5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D
M+@!7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+@!8
M+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D
M($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U
M,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS
M`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@22!!
M9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T
M;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@86QL
M;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RX`66]U(&%R92!N
M;W0@875T:&5N=&EC871E9"X`66]U(&-A;FYO="!H879E('1H92`G7"<@8VAA
M<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A
M('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L
M9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN
M9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U
M(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I
M=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T
M:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L
M:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME
M;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B
M86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@
M>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT
M97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T
M('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E
M8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@
M=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M
M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@
M<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9
M;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R`%EO
M=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN
M+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R
M($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E
M9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@
M<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`
M66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO
M="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@=7-E($AO
M<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E
M(&$@9&EF9F5R96YT(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0N`%EO=7(@875T
M:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@
M=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S
M;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V
M92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S
M:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN
M(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E
M871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I
M;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R:6YT
M+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I
M='D@:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D969A=6QT(&ED96YT:71Y.@!9
M;W5R(&9U;&P@;F%M93H`66]U<B!L;V=I;B!H87,@97AP:7)E9"X`66]U<B!N
M97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B
M965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN
M`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R
M9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T
M+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P
M87-S=V]R9"X`66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"X`66]U<B!R96UO
M=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`
M6FEP<'D`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H
M;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S
M70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4
M<F5E`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I
M97,N+BX`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO
M;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4V5T=7``7U1A8FQE
M(%!R;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!A9&1R97-S964@
M=6YK;F]W;@!C86QE;F1A<@!C86QM`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I
M;&4`8V%N;F]T(&]P96X@:6YP=70`8VQI8VL@:&5R90!C;VUM86YD(&QI;F4@
M=7-A9V4@97)R;W(`8V]N9FEG=7)A=&EO;B!E<G)O<@!C<FET:6-A;"!S>7-T
M96T@9FEL92!M:7-S:6YG`&1A=&$@9F]R;6%T(&5R<F]R`&5D:70`96YT<GD@
M;F]T(&9O=6YD`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S
M("5S`&=U<W1I;F<`:#H`:&@`:&]S="!N86UE('5N:VYO=VX`:6UM961I871E
M`&EN;&EN90!I;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A<F4@
M97)R;W(`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI
M;F<@25-/+@!M;0!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE
M;65N=&5D`&YO=&5P860`<&5R8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P:7AE
M;',`<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L`')I<VEN9P!S97)V:6-E('5N
M879A:6QA8FQE`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10
M`'-S`'-T96%D>0!S>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F
M86EL=7)E`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI
M9FEE9`!U;FYA;65D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H97(N8V]M
M`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXQ+C$M8W9S"E)E<&]R="U-
M<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO
M;BU$871E.B`R,#`V+3`S+3$Q(#$R.C,Y*S`Q,#`*4$\M4F5V:7-I;VXM1&%T
M93H@,C`P-BTP,RTQ,2`Q-CHU,BLP,3`P"DQA<W0M5')A;G-L871O<CH@0G)I
M86X@5')U96QS96X@/&AO<F1E*VDQ.&Y`8G)I86YT<G5E;'-E;BYD:SX*3&%N
M9W5A9V4M5&5A;3H@1&%N:7-H(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-
M12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R
M<V5T/4E33RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I
M=`I0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3([('!L=7)A;#TH;B`A/2`Q*3L*
M`"`H)7,@9&%G92!S:61E;BD`("A!8V-E<W-K97D@)7,I`"`H;VT@)7,@9&%G
M92D`("AI(&1A9RD`("AI(&UO<F=E;BD`("AI(&?E<BD`(&UE9"``(B5S(B!E
M<B!I:VME(&5T(&MA=&%L;V<N`"(E<R(@97(@:6YT970@9WEL9&EG="!V86QG
M+@`B)7,B(&5R(&EK:V4@:V]N9FEG=7)E<F5T(&D@2&]R9&5S(&9O<G1E9VYE
M;'-E+@`B)7,B('1RYBUO<&)Y9V=E<B!I:VME(&9U;F1E="X`(B5S(B!B;&5V
M('1I;&;X:F5T(&D@9W)U<'!E+7-Y<W1E;65T+@`B)7,B(&)L978@=&EL9OAJ
M970@=&EL;&%D96QS97,M<WES=&5M970N`"(E<R(@8FQE=B!I:VME(&1A;FYE
M=#H@)7,N`"4N,F9-0B!B<G5G="!U9"!A9B`E+C)F34(@=&EL;&%D="`H)2XR
M9B4E*0`E9"`E<R!O9R`E<P`E9"!D86=E('1I;"!D:70@:V]D96]R9"!U9&SX
M8F5R+@`E9"UD86=S('5D<VEG=``E<R`M($YO=&ET<P`E<R!F:6YG97)A9G1R
M>6L`)7,@2T(`)7,@5F5D;&EG96AO;&1E;'-E("T@0F5K<N9F=&5L<V4`)7,@
M;W!SYG1N:6YG`"5S(&]P<VMR:79N:6YG`"5S(&)R=6=S8F5T:6YG96QS97(`
M)7,@96MS:7-T97)E<B!A;&QE<F5D92X`)7,@=F5D("5S("5S`"5S(&5R('!A
M<F%T('1I;"!A="!U9&;X<F4@9&4@=F5D;&EG96AO;&1E;'-E<VAA;F1L:6YG
M97(L('-O;2!E<B!M87)K97)E="!N961E;F9O<BX@(%/F="!H86L@=60@9F]R
M(&1E(&AA;F1L:6YG97(L('-O;2!D=2#X;G-K97(@=61F^')T(&YU+@`E<R!K
M<N9V970`)7,@;6EN=71T97(`)7,@:6MK92!F=6YD970N`"5S('1I;"`E<R!A
M9B`E<P`E<W,@861R97-S96MA<G1O=&5K`"5S<R!K86QE;F1E<@`E<W,@;F]T
M97-B;&]K`"5S<R!O<&=A=F5R`"5S.B`E<P`E<SH@1&5N;F4@8F5S:V5D(&5R
M(&UU;&EG=FES(&EK:V4@9G)A(&1E;B!P97)S;VXL('-O;2!D96X@:.9V9&5R
M(&%T(';F<F4@9G)A+B`@5N9R('9A<G-O;2!M960@870@9OAL9V4@:&5N=FES
M;FEN9V5R(&5L;&5R(&9O<G-Y;F4@869S96YD97)E;B!M960@<&5R<V]N;&EG
M92!I;F9O<FUA=&EO;F5R+@`L(&1I<V5T(``L(&)LYG-E;F1E("5S("5S`"P@
M<VMR:69T96YD92!F<F$@)7,@=&EL("5S`"TM(';F;&<@+2T`,3(M=&EM97)S
M(&9O<FUA=``R-"UT:6UE<G,@9F]R;6%T`#(T('1I;65R`#Q&;W)E9^5E;F1E
M(&1A9P!%;B!D871A8F%S92UB86-K96YD(&5R(&MRYG9E="!F;W(@9&5N;F4@
M8FQO:RX`1&5R(&5R(&]P<W3E970@96X@9W)A=F5R96YD92!F96IL`$5N(&]F
M9F5N=&QI9R!01U`M;OAG;&4@97(@:W+F=F5T(&9O<B!A="!K<GEP=&5R92!E
M;B!B97-K960N`$5N(&]F9F5N=&QI9R!01U`M;OAG;&4@97(@:W+F=F5T(&9O
M<B!A="!V97)I9FEC97)E(&5N('-I9VYE<F5T(&)E<VME9"X`16X@;V9F96YT
M;&EG(%!'4"UN^&=L92P@<')I=F%T(%!'4"UN^&=L92!O9R!E="!L^'-E;B!E
M<B!K<N9V970@9F]R(&%T(&1E:W)Y<'1E<F4@96X@8F5S:V5D+@!%;B!O9F9E
M;G1L:6<@4$=0+6[X9VQE+"!P<FEV870@4$=0+6[X9VQE(&]G(&5T(&SX<V5N
M(&5R(&MRYG9E="P@9F]R(&%T('-I9VYE<F4@96X@8F5S:V5D+@!%;B!O9F9E
M;G1L:6<@4R]-24U%+6[X9VQE+"!P<FEV870@4R]-24U%+6[X9VQE(&]G(&5T
M(&SX<V5N(&5R(&MRYG9E="P@9F]R(&%T(&1E:W)Y<'1E<F4@96X@8F5S:V5D
M+@!%;B!O9F9E;G1L:6<@4R]-24U%+6[X9VQE+"!P97)S;VYL:6<@4R]-24U%
M+6[X9VQE(&]G(&SX<V5N(&5R(&MRYG9E="!F;W(@870@<VEG;F5R92!E;B!B
M97-K960N`$5N(&]F9F5N=&QI9R!3+TU)344M;OAG;&4@97(@:W+F=F5T(&9O
M<B!A="!K<GEP=&5R92!E;B!B97-K960N`$9O<FUI9&1A9R!3:WEE=`!&;W)M
M:61D86<@3&5T(%)E9VX`1F]R;6ED9&%G(%)E9VX`1F]R;6ED9&%G($)Y9V5R
M`$9O<FUI9&1A9R!3;F5B>6=E<@!!32]030!!4$D@240`3VT@9&5N;F4@<VMR
M:6)E;G0`3VTN+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!9&=A;F<@;N9G=&5T
M('9E9"!D86YN96QS92!A9B!61E,M:V%T86QO9RX`061G86YG(&[F9W1E="!V
M960@9&%N;F5L<V4@868@5D93+69I;"X`2V]N=&\M:6YF;W)M871I;VX`2V]N
M=&]E;G,@:V]D96]R9`!+;VYT;R!I;F1E9G)O<W-E="X`2V]N=&5R:6YG+@!4
M:6QF^&H`5&EL9OAJ('5N9&5R9W)U<'!E`%1I;&;X:B!U;F1E<F]R9&YE9&4@
M=&EL;&%D96QS90!4:6QF^&H@:&5R.@!4:6QF^&H@;GD@9W)U<'!E`%1I;&;X
M:B!N>2!R971T:6=H960`5&EL9OAJ('5N9&5R9W)U<'!E('1I;"`B)7,B`%1I
M;&;X:B!E;B!U;F1E<G)E='1I9VAE9"!T:6P@(B5S(@!/<')E='1E(&5N(&YY
M(&)R=6=E<CH`5&EL9OAJ(&MO;&]N;F4`5&EL9OAJ(&YY92!M961L96UM97(`
M3W!R970@<&%R`%1I;&;X:B`E<RUM96YU96X@<V]M(&5N($UO>FEL;&$@4VED
M96)A<@!4:6QF^&H@=&EL(&%D<F5S<V5K87)T;W1E:SH`5&EL9OAJ('1I;"!M
M:70@861R97-S96MA<G1O=&5K`$]P<F5T(&)R=6=E<@!(87(@=&EL9OAJ970@
M(B5S(B!T:6P@<WES=&5M970L(&UE;B!K=6YN92!I:VME('1I;&;X:F4@96MS
M=')A(&]P<VMR:79N:6YG<VEN9F]R;6%T:6]N.B`E<RX`5&EL9OAJ970@(B5S
M(B!T:6P@<WES=&5M970N($1U(&MA;B!L;V=G92!I;F0@;G4N`$]P<F5T=&5L
M<V4@868@8G)U9V5R92!E<B!S;.5E="!F<F$`061R97-S90!!9')E<W-E:V%R
M=&]T96L`061M:6YI<W1RZ7(@+2!I;F1S=&EL('1I;&QA9&5L<V5R(&9O<B!A
M;F1R92!B<G5G97)E`$%D;6EN:7-T<F%T:6]N`%)E:VQA;65R`$%F9VAA;FES
M=&%N`$%L8F%N:65N`$%L9V5R:65T`$MA;&1E;F%V;@!/<'-T:6QL:6YG`$IU
M<W1E<FEN9SH`06QL90!!;&QE(.9G=&5D92!B<G5G97)E`$%L;&4@9W)U<'!E
M<@!!;&QE('1I;&QA9&5L<V5R`$%L;&4@9FER92!S:61E<@!4:6QL860@;75L
M=&EP;&4@861R97-S97(`5&EL;&%D(&%N9VEV96QS92!A9B!O<F1N970@;&ES
M=&5T>7!E/P!%:W-I<W1E<F5R(&%L;&5R961E`$%L=&5R;F%T:78@24U34"UL
M;V=I;@!!;'1E<FYA=&EV($E-4U`M:V]D96]R9`!!;'1E<FYA=&EV($E-4U`M
M8G)U9V5R;F%V;@!$:6X@92UM86EL+6%D<F5S<V4`06QT97)N871I=F4@<VMA
M8F5L;VYE<@!!;'1E<FYA=&EV('1E:W-T.@!!;65R:6MA;G-K(%-A;6]A`$1E
M;B!VYG)D:2P@9&5R(&)L978@86YG:79E="P@=F%R(&EK:V4@9WEL9&EG+@!$
M97(@97(@;W!S=.5E="!E;B!U:V5N9'0@9F5J;"X`06YD;W)R80!!;F=O;&$`
M06YG=6EL;&$`06YO;GEM:7-E<F5N9&4@<')O>'D`0F5S=F%R`%-Y9'!O;&5N
M`$%N=&EG=6$@86YD($)A<F)U9&$`07!P;&EK871I;VX`07!P;&EK871I;VYS
M;&ES=&4`07!P;&EK871I;VX@97(@<&%R870N`%#E9OAR('5N9&5R9&5L:6YG
M97(`1V]D:V5N9`!#:7)K87-T^')R96QS90!!<')I;`!!<F%B:7-K("A7:6YD
M;W=S+3$R-38I`$%R:VEV+69I;'-T^')R96QS90!!<FMI=FYA=FX`17(@9'4@
M<VEK:V5R('#E+"!A="!D=2!V:6P@<VQE='1E(&]P<VMR:79N:6YG<V%N;6]D
M;FEN9V5N(&9O<B`E<R`_`$5R(&1U('-I:VME<BP@870@9'4@^&YS:V5R(&%T
M('-L971T92`B)7,B(&]G(&5N:'9E<B!U;F1E<F=R=7!P93\`07)G96YT:6YA
M`$%R;65N:65N`$%R;65N<VL@*$%235-#24DM."D`2W5N<W0`07)U8F$`07-C
M96YS:6]N^&5N`$%30TE)($%R=`!!<VEA=&ES:R]S=&EL;&5H879S<F5G:6]N
M`%-P^')G(&5F=&5R(&)E:W+F9G1E;'-E(&;X<B!U9&;X<F5L<V4@868@=F5D
M;&EG96AO;&1E;'-E<VAA;F1L:6YG97(_`%1I;&1E;"!K;VQO;FYE<@!&;W)S
M^&<@<.4@870@<VQE='1E(&5N(&EK:V4M96MS:7-T97)E;F1E(&=R=7!P92X`
M1F]R<_AG('#E(&%T('-L971T92!E;B!I:VME+65K<VES=&5R96YD92!T:6QL
M861E;'-E+@!&;W)S^&<@<.4@870@YFYD<F4@96X@:6MK92UE:W-I<W1E<F5N
M9&4@=&EL;&%D96QS92X`1F]R<_AG('#E(&%T(.9N9')E(&5N(&EK:V4M96MS
M:7-T97)E;F1E(&1E;&EN9RX`071T<FEB=71T97(`075G=7-T`$%U<W1R86QI
M96X`V'-T<FEG`$%U=&A?8WER<W%L.B!+<N9V970@24U!4"UU9'9I9&1E;'-E
M(&EK:V4@9G5N9&5T+@!!=71H7V-Y<G5S.B!"86-K96YD(&AA<B!I:VME(&1E
M(&[X9'9E;F1I9V4@979N97(N`$%U=&A?8WER=7,Z($MRYG9E="!)34%0+75D
M=FED9&5L<V4@:6MK92!F=6YD970N`$%U=&A?9G1P.B!+<N9V970@1E10+75D
M=FED9&5L<V4@:6MK92!F=6YD970N($]V97)SYG0@4$A0(&UE9"`M+65N86)L
M92UF='`M9FQA9V5T+@!!=71H7VEM87`Z($MRYG9E="!)34%0+75D=FED9&5L
M<V4@:6MK92!F=6YD970N`$%U=&A?:W)B-3H@2W+F=F5T($M20C4M=61V:61D
M96QS92!I:VME(&9U;F1E="X`075T:%]L9&%P.B!4:6QF^&IE;'-E(&)R=6=E
M<F4@97(@:6MK92!U;F1E<G-T^'1T970@9F]R($%C=&EV92!$:7)E8W1O<GD`
M075T:%]L9&%P.B!3;&5T;FEN9R!A9B!B<G5G97)E(&5R(&EK:V4@=6YD97)S
M=/AT=&5T('9E9"!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@2W+F=F5T
M($Q$05`M=61V:61D96QS92!I:VME(&9U;F1E="X`075T:%]L9&%P.B!+=6YN
M92!I:VME('1I;&;X:F4@8G)U9V5R("5S+B!397)V97)E;B!S86=D93H@`$%U
M=&A?;&1A<#H@2V%N(&EK:V4@<VQE='1E(&)R=6=E<B`E<P!!=71H7VQD87`Z
M($MA;B!I:VME(&]P9&%T97)E(&)R=6=E<B`E<P!!=71H7VQD87`Z($]P9&%T
M97)I;F<@868@8G)U9V5R92!E<B!I:VME('5N9&5R<W3X='1E="!V960@06-T
M:79E($1I<F5C=&]R>2X`075T:%]M8V%L.B!+<N9V970@34-!3"UU9'9I9&1E
M;'-E(&EK:V4@9G5N9&5T+@!!=71H7W-M8F%U=&@Z($MRYG9E="!334)!551(
M+75D=FED9&5L<V4@:6MK92!F=6YD970N`,9G=&YI;F<@=F5D($E-05`M<V5R
M=F5R(&9E:FQE9&4N`,9G=&YI;F<@9F5J;&5D90#&9W1N:6YG(&9E:FQE9&4N
M("5S`,9G=&YI;F<@869V:7-T(&%F(%)!1$E54RUS97)V97(N`,9G=&YI;F<@
M;W9E<F9O<B!&5%`M<V5R=F5R(&9E:FQE9&4N`,9G=&YI;F<@;W9E<F9O<B!3
M34(M<V5R=F5R(&9E:FQE9&4N`$9E;'1E<B!T:6P@<N5D:6=H960Z`$%S97)B
M86ED:F%N`$)/1D@M=6YD<VMY;&1N:6YG97(`0F%C:V=R;W5N9`!"86=G<G5N
M9'-F87)V90!$Y7)L:6=T(&ME<F)E<F]S+6MO9&5O<F0N`$3E<FQI9W0@:V5R
M8F5R;W,M8G)U9V5R;F%V;BX`0F%H86UA`$)A:')A:6X`0F%L=&EK=6T@*$E3
M3RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$)A<VES(&=R869I:VMA
M=&%L;V<@(B5S(B!I:VME(&9U;F1E="X`0F%S:7-L:6YI90!(=FED97)U<VQA
M;F0`0F5L9VEE;@!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`1OAD<V5L
M<V1A9P!";&]K("(E<R(@868@87!P;&EK871I;VX@(B5S(B!I:VME(&9U;F1E
M="X`0FQO:RUE9V5N<VMA8F5R`$)L;VMT>7!E`$9E9`!";VQI=FEE;@!";V=M
MYG)K97(`4F%N9`!286UM971Y:VME;'-E.@!286YD90!";W-N:65N(&]G($AE
M<GIE9V]V:6YA`$)E9V=E`$)O='-V86YA`$)U;F0`0F]U=F5T^&5N`$)R87-I
M;&EE;@!"<FET:7-K+4EN9&EE;B!/8V5A;F]M<N5D90!"<G5N96D@1&%R=7-S
M86QA;0!"=6QG87)I96X`4'5N:W1L:7-T90!"=7)K:6YA($9A<V\`0G5R=6YD
M:0!#35,`0U)#`$-23"!D:7-T<FEB=71I;VYS<W1E9&5R`$-E;&QE+65G96YS
M:V%B97(N+BX`26YI=&EA;&ES97)I;F<@868@;6ED;&5R=&ED:6=T(&QA9V5R
M(&EK:V4@9N9R9&EG9VIO<G0N`$MA;&5N9&5R`%9I;F1S=&EL;&4`2V%M8F]D
M:6$`0V%M97)O=6X`2V%N(&EK:V4@;G5L<W1I;&QE(&MO9&5O<F0@875T;VUA
M=&ES:SL@:V]N=&%K="!D:6X@861M:6YI<W1R871O<BX`2V%N(&EK:V4@<VMR
M:79E('1I;"!F:6P@(B5S(@!+86X@:6MK92!HY6YD=&5R92!E:W-T97)N92!S
M97-S:6]N<VCE;F1T86<N`$MA;B!I:VME(&9O<F)I;F1E('1I;"!)34%0('-E
M<G9E<BX@)7,`2V%N(&EK:V4@Y6)N92!F:6P@(B5S(BX`0V%N861A`$%N;G5L
M;&5R`$%F8G)Y9"!R97!O<G1E<FEN9R!A9B!P<F]B;&5M`$MA;B!I:VME('-L
M971T92!F:6P@(B5S(BX`2V%N(&EK:V4@9FEN9&4@970@;6ED;&5R=&ED:6=T
M(&MA=&%L;V<N`$MA;B!I:VME(&9O<G1SYG1T92!U9&5N("=T87)G971&:6QE
M)RUP87)A;65T<F5N+@!+86X@:6MK92!F:F5R;F4@:V%T86QO9R`B)7,B+@!+
M86X@:6MK92!F:F5R;F4L("5D(&+X<FX@96MS:7-T97)E<BX`2V%N(&EK:V4@
M;VUF;W)D96QE.R!A;G1A;&QE="!A9B!P=6YK=&5R(&%N9VEV970@=&EL(&]M
M9F]R9&5L:6YG('-V87)E<B!I:VME('1I;"!D970@;W!B979A<F5D92!A;G1A
M;"X`2V%N(&EK:V4@9&ER:6=E<F4@8F5S:V5D('1I;"!A;F=I=FYE(&YU;6UE
M<BX`2V%P(%9E<F1E`$)I;&QE9'1E:W-T`%5D8GED97(`2V%T96=O<FEE<B!O
M9R!-YG)K97(`0V%Y;6%N^&5R;F4`36]B:6P`0V5L;&4M96=E;G-K86)E<@!#
M96QL969O<G)I;F<Z`$-E;&QE+65G96YS:V%B97(`0V5L;&4M;65L;&5M<G5M
M.@!-;V)I;'1E;&5F;VX`2V5L=&ES:R`H25-/+3@X-3DM,30I`$-E;G1RZ7(`
M1&5N(&-E;G1R86QA9G)I:V%N<VME(%)E<'5B;&EK`$-E;G1R86PM975R;W#F
M:7-K("A)4T\M.#@U.2TR*0!#97)T:69I:V%T+61E=&%L:F5R`$-E<G1I9FEK
M870M96IE<@!#97)T:69I:V%T+7!O;&ET:6MK97(`5&-H860`QFYD<F4`QFYD
M<F4@9&ET(&MO9&5O<F0`2&5R(&MA;B!D=2#F;F1R92!D970@;F%V;B!O9R!D
M96X@861R97-S92P@<V]M(&%N9')E('-E<BP@;N5R(&1E(&SF<V5R(&]G('-V
M87)E<B!PY2!D:6YE(&4M;6%I;"X`2V]D96]R9'/F;F1R:6YG(&5R(&EK:V4@
M=6YD97)S=/AT=&5T(&%F(&1E;B!N=7;F<F5N9&4@;W!SYG1N:6YG+B`@2V]N
M=&%K="!D:6X@861M:6YI<W1R871O<BX`5&5G;@!(86L@;&EN:R!A9BXN+@!#
M:&EL90!+:6YA`%-I;7!L:69I8V5R970@:VEN97-I<VL@*$=",C,Q,BD`5')A
M9&ET:6]N96QT(&MI;F5S:7-K("A":6<U*0!6YFQG(&%P<&QI:V%T:6]N.@!6
MYFQG(&5T(&MO9&5O<F0`5N9L9R!E="!B<G5G97)N879N`%;F;&<@:'9O<F1A
M;B!D871O97(@<VMA;"!V:7-E<SH`5N9L9R!L:7-T92US=&EL("AF;W(@;W)D
M;F5D92!L:7-T97(I`$IU;&7X96X`2VQA<W-E9&5F:6YI=&EO;B!A9B`E<R!I
M:VME(&9U;F1E="X`2VQA<G0`1FIE<FX@35-/9F9I8V4M;W!MYG)K;FEN9V5R
M`$YU;'-T:6P@9F]R97-P^')G<V5L`%)E;G,@8G)U9V5R('5D.B`E<P!.=6QS
M=&EL(&)R=6=E<@!6:7-K(&)R=6=E<F1A=&$@=60`4V5N(&]P:VQA<FEN9P!+
M;&EK(&9O<B!A="!F;W)T<^9T=&4`0VQI8VMA=&5L;"!V:6$@2%144`!,=6L@
M=FEN9'5E`%-K>65R`%-K>65R('1I9&QI9W0`4VMY970`0V]C;W,@*$ME96QI
M;F<I(-AE<FYE`$9O;&0@<VED97!A;F5L('-A;6UE;@!386UM96YF;VQD961E
M(')A;F1E`$MO;'5M8FEE;@!&87)V90!&87)V97;F;&=E<@!&87)V979A;&<`
M2V]L<SH`2V]L;VYN971I=&QE<@!496=N97-E<FEE<@!+;VUM86YD;P!+;VUM
M86YD;VQI;FEE`$MO;6UE;G1A<@!#;VUM;VX@3F%M90!#;VUO<F5R;F4`1FER
M;6$`0V]M<'5T97)E`$9O<FAO;&0`0F5T:6YG96QS97(`2V]N9FEG=7)A=&EO
M;G-F;W)S:V5L;&4`2V]N9FEG=7)A=&EO;B!T:6P@<WEN:W)O;FES97)I;F<@
M;65D(%!$065R+"!3;6%R='!H;VYE<R!O9R!/=71L;V]K+@!+;VYF:6=U<F%T
M:6]N96X@97(@9F]RYFQD970N`$MO;F9I9W5RZ7(@)7,`0F5K<N9F="!K;V1E
M;W)D`$MO;F=O`$MO;F=O+"!$96X@9&5M;VMR871I<VME(')E<'5B;&EK`$9O
M<F)I;F1E;'-E(&UI<VQY:VME9&5S+@!&;W)B:6YD96QS92!M:7-L>6MK961E
M<SH@`$9O<F)I;F1E;'-E('1I;"!O9F9E;G1L:6<@;OAG;&5S97)V97(@;N9G
M=&5T+@!&;W)B:6YD96QS92!T:6P@;V9F96YT;&EG(&[X9VQE<V5R=F5R(&[F
M9W1E="X@Q7)S86<Z("5S("@E<RD`1F]R8FEN9&5L<V4@=&EL($944"US97)V
M97(@;6ES;'EK:V5D97,N`$MO;G1A:W1E<@!+;VYT86MT97(@8FQE=B!T:6QF
M^&IE="!T:6P@9&ET(&%D<F5S<V5K87)T;W1E:V5T`$EN9&AO;&1S='EP92!A
M9B!K;VUP<FEM97)E="!F:6PZ(`!);F1H;VQD(&%F("(E<R(`1F]R='/F=`!#
M;V]K($ES;&%N9',`4VWE:V%G90!+;W!I97(`2V]P:65R:6YG(&UI<VQY:VME
M9&5S.B`E<P!+;W!IZ7(@;6%R:V5R:6YG`$=E8GER($E$`$-O<W1A(%)I8V$`
M16QF96YB96YS:WES=&5N`$MU;FYE(&EK:V4@4$=0+6MR>7!TZ7)E(&)E<VME
M9#H@`$MU;FYE(&EK:V4@4$=0+7-I9V[I<F4@8F5S:V5D.B``2W5N;F4@:6MK
M92!3+TU)344M:W)Y<'1E<F4@8F5S:V5D+@!+=6YN92!I:VME(%,O34E-12US
M:6=NZ7)E(&)E<VME9"X`2W5N;F4@:6MK92!T:6QF^&IE(&MO;G1A:W0N("5S
M`$MU;FYE(&EK:V4@:V]B;&4@=&EL($Q$05`M<V5R=F5R+@!+=6YN92!I:VME
M(&MO;G1R;VQL97(@8F%L86YC92X@)7,`2W5N;F4@:6MK92!F;W)B:6YD92!T
M:6P@3$1!4"US97)V97(N`$MU;FYE(&EK:V4@9F]R8FEN9&4@=&EL('-E<G9E
M<B`B)7,B('9E9"!B<G5G(&%F($944#H@)7,`2W5N;F4@:6MK92!O<')E='1E
M(&1I<W1R:6)U=&EO;G-L:7-T92X@)7,`2W5N;F4@:6MK92!D96MR>7!T97)E
M(%!'4"UD871A.B``2W5N;F4@:6MK92!D96MR>7!T97)E(%,O34E-12UD871A
M+@!+=6YN92!I:VME('-L971T92!K;VYT86MT+B`E<P!+=6YN92!I:VME('-L
M971T92!D:7-T<FEB=71I;VYS;&ES=&4N("5S`$MU;FYE(&EK:V4@<VQE='1E
M(#QE;3YS8W)I<'0\+V5M/B`B)7,B('1I;"!O<&=R861E<FEN9R!A9B!O<'/F
M=&YI;F<N`$MU;FYE(&EK:V4@8F5S=&5M;64@;6]D=&%G97)E;G,@92UM86EL
M+6%D<F5S<V4N`$MU;FYE(&EK:V4@:&5N=&4@:&5L92!A9')E<W-E:V%R=&]T
M96LN`$MU;FYE(&EK:V4@:&5N=&4@:&5L92!D:7-T<FEB=71I;VYS;&ES=&4N
M`$MU;FYE(&EK:V4@:&5N=&4@9G5L9'-TYFYD:6<@9F]R=&5G;F5L<V4@;W9E
M<B!D:7-T<FEB=71I;VYS;&ES=&5R+@!+=6YN92!I:VME(&AE;G1E('-T<F%T
M96=I("(E<R(N`$MU;FYE(&EK:V4@;6MD:7(@(B5S(BX`2W5N;F4@:6MK92!H
M96YT92!O9F9E;G1L:6<@;OAG;&4@9G)A(&[X9VQE<V5R=F5R+@!+=6YN92!I
M:VME(.5B;F4@(B5S(B!F;W(@<VMR:79N:6YG+@!+=6YN92!I:VME(.5B;F4@
M)7,N`$MU;FYE(&EK:V4@Y6)N92!M;V1U;"!T:6P@=F5D;&EG96AO;&1E;'-E
M("5S`$MU;FYE(&EK:V4@Y6)N92!K871A;&]G("(E<R(N`$MU;FYE(&EK:V4@
M;N4@3$1!4"US97)V97)E;BX`2W5N;F4@:6MK92!LYG-E("5S+@!+=6YN92!I
M:VME(&YU;'-T:6QL92!K;V1E;W)D970@9F]R(&1E;B!A;FUO9&5D92!B<G5G
M97(N("!.;V=L92!E;&QE<B!A;&QE(&1E=&%L:F5R(&5R('5K;W)R96MT92X@
M4'+X=B!I9V5N(&5L;&5R(&MO;G1A:W0@9&EN(&%D;6EN:7-T<F%T;W(L(&AV
M:7,@9'4@:&%R(&)E:&]V(&9O<B!Y9&5R;&EG97)E(&AJYFQP+@!+=6YN92!I
M:VME(&AE;G1E($%#3`!+=6YN92!I:VME(&AE;G1E(&%D<F5S<V5K87)T;W1E
M:V5T+B`E<P!+=6YN92!I:VME(&AE;G1E(&1I<W1R:6)U=&EO;G-L:7-T92X@
M)7,`2W5N;F4@:6MK92!H96YT92!D:7-T<FEB=71I;VYS;&ES=&5R+B`E<P!+
M=6YN92!I:VME(&AE;G1E('-E<G9E<G,@979N97(`2W5N;F4@:6MK92!G96YD
M86YN92!K;VYF:6=U<F%T:6]N+@!+=6YN92!I:VME(')M9&ER("(E<R(N`$MU
M;FYE(&EK:V4@9V5M;64@)7,M:V]N9FEG=7)A=&EO;@!+=6YN92!I:VME(&=E
M;6UE(&5N(&)A8VMU<"UK;VYF:6=U<F%T:6]N+@!+=6YN92!I:VME(&=E;6UE
M(&5N(&)A8VMU<"UK;VYF:6=U<F%T:6]N.B`E<P!+=6YN92!I:VME(&=E;6UE
M('-C<FEP="!T:6P@;W!G<F%D97)I;F<@868@;W!SYG1N:6YG('1I;#H@(B5S
M(BX`2W5N;F4@:6MK92!G96UM92!B86-K=7`M:V]N9FEG=7)A=&EO;G-F:6QE
M;B`E<RX`2W5N;F4@:6MK92!G96UM92!K;VYF:6=U<F%T:6]N<V9I;&5N("5S
M+B!$=2!K86X@96YT96X@86YV96YD92!E;B!A9B!M=6QI9VAE9&5R;F4@9F]R
M(&%T(&=E;6UE(&MO9&5N('1I;&)A9V4@<.4@)7,@96QL97(@;6%N=65L="!K
M;W!I97)E(&MO9&5N(&YE9&5N9F]R('1I;"`E<RX`2W5N;F4@:6MK92!S^&=E
M($Q$05`M<V5R=F5R96XN`$MU;FYE(&EK:V4@/&5M/G5N;&EN:SPO96T^("(E
M<R(N`$MU;FYE(&EK:V4@;W!D871E<F4@:V]N=&%K="X@)7,`2W5N;F4@:6MK
M92!O<&1A=&5R92!D:7-T<FEB=71I;VYS;&ES=&4N("5S`$MU;FYE(&EK:V4@
M<VMR:79E(&MO;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$MU;FYE(&EK:V4@
M9FEN9&4@36]Z:6QL82!3:61E8F%R+B!&;W)V:7,@9&EG(&]M(&%T('-I9&5B
M87)E;B!E<B#E8F5N+@!+=6YN92!I:VME(&=I=F4@8G)U9V5R("(E<R(@9OAL
M9V5N9&4@<F5T=&EG:&5D97(@=&EL(&UA<'!E;B`B)7,B.B`E<P!/<'1A;'0@
M=&5K<W0`3&%N9`!+=7)S97(`3W!R970`3W!R970@96X@:&5N=FES;FEN9P!/
M<')E="!E;B!N>0!/<')E="!U;F1E<FUA<'!E`%-K86)E<G,@<F5T=&EG:&5D
M97(`2W)E9&ET:V]R="UN=6UM97(`2W)O871I96X`0W5B80!.=7;F<F5N9&4@
M-"!F87-E<@!);F1E=N9R96YD92!S97-S:6]N`$%K='5E;"!T:60`3G5VYG)E
M;F1E(%523"!E<@!.=7;F<F5N9&4@8G)U9V5R90!!:W1U96QT('9E:G(`3G5V
MYG)E;F1E('9E:G(Z(`!!:W1U96P@<W1I;`!4:6QP87,@;W!G879E<BP@9&5R
M(&)L:79E<B!U9&;X<G0L(&[E<B!D=2!L;V=G97(@:6YD(&D@)7,N`$ML:7``
M2VQI<"!V86QG`$-Y<&5R;@!+>7)I;&QI<VL@*$M/23@M4BD`2WER:6QL:7-K
M("A7:6YD;W=S+3$R-3$I`$MY<FEL;&ES:R]5:W)A:6YS:R`H2T])."U5*0!4
M:F5K:VEE=`!$1`!$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A
M;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`$1A9VQI
M9P!$871A5')E92!S=&EF:6YD97(`1&%T86)A<V4M;W!S;&%G`$1A=&\`36]D
M=&%G96QS97-D871O`$1A=&]V86QG`$1A9P!3;&5T(&MO;&]N;F4`1&5C96UB
M97(`1&5C:6UA;'1A;`!-:6YD<VL@:6YD<GEK;FEN9P!3=&%N9&%R9`!3=&%N
M9&%R9&9A<G9E`%-T86YD87)D+6ED96YT:71E=`!3=&%N9&%R9"US:V%L`$1E
M9FEN:71I;VYE<@!3;&5T`%-L970@8V5L;&4`4VQE="!G<G5P<&4`4VQE="!L
M;V=B;V<`4VQE="!T:6QL861E;'-E<@!&:F5R;B!O9R!U9'-L970@8F5S:V5D
M97(`4VQE="!C96QL90!3;&5T(&MO;&]N;F4`4VQE="!E:W-I<W1E<F5N9&4L
M(&%L=&5R;F%T:79E('-K86)E;&]N`%-L970@8F5S:V5D97(`4VQE="!T:6QL
M861E;'-E<B!F;W(@(B5S(@!3;&5T('1I;&QA9&5L<V5R(&9O<B`B)7,B(&]G
M(&%L;&4@=6YD97)O<F1N961E('1I;&QA9&5L<V5R/P!3;&5T('+F:VME`%-L
M970@=F%L9W1E(&ED96YT:71E=`!3;&5T('5N9&5R;6%P<&5R`%-L970@9&5N
M(&%K='5E;&QE(&MO;&]N;F4`4VQE="!D96X@86MT=65L;&4@<N9K:V4`3W!G
M<F%D97)I;F=S<V-R:7!T("(E<R(@<VQE='1E="X`3&5V97)I;F=S=&ED<W!U
M;FMT`$1A;FUA<FL`0F5S:W)I=B!P<F]B;&5M970`0F5S:W)I=F5L<V4`1&5T
M86QJ97(@*&]G<^4@:2!(;W)D92=S(&QO9V9I;"DZ`$1E=&%L:F5R(&5R('-K
M<F5V970@=&EL(&QO9V)O9V5N(&%F(&AE;G-Y;B!T:6P@861M:6YI<W1R871O
M<F5N+@!59'9I:VQI;F<`1'5G<'5N:W0`1'5G<'5N:W0@9F]R('-I9'-T92!T
M:6UE.B``1'5G<'5N:W0Z(`!2971N:6YG('9E;G-T<F4@=&EL(&CX:G)E`%)E
M=&YI;F<@:/AJ<F4@=&EL('9E;G-T<F4`2V%T86QO9P!6:7,@=&ED(&UE9"`R
M-"!T:6UE<C\`26YD<W1I;&QI;F=E<B!F;W(@=FES;FEN9P!6:7,@=61D>6)E
M;F1E('9E:G)U9'-I9W0`5FES('9E:G)U9'-I9W0@*%1!1BD`5FES;FEN9W-F
M;W)M870`3W9E<F1R86=E;'-E<VYO=&ET<P!$:FEB;W5T:0!&;W)T<GED('-L
M971N:6YG`$1U(&WE(&EK:V4@:V%L9&4@;6%I;G1E;F%N8V4N<&AP(&1I<F5K
M=&4`26YD96AO;&1E<B!D96X@9OAR<W1E('+F:VME(&9E;'1N879N93\@2'9I
M<R!J82P@;6%R:^ER(&1E;FYE(&)O:W,Z`$1E;B!D;VUI;FEK86YS:V4@4F5P
M=6)L:6L`1&5N(&1O;6EN:6MA;G-K92!297!U8FQI:P!(87(@9'4@:6MK92!N
M;V=E;B!K;VYT;S\@365L9"!D:6<@=&EL+@!(96YT`$AE;G0@)7,`2&5N="!G
M96YE<F5R970@:V]N9FEG=7)A=&EO;B!N960@<V]M(%!(4"US8W)I<'0N`%)U
M;&QE9V%R9&EN+6QI<W1E`$UE9&EK86UE;G1E<@!%+6UA:6P`14UA:6PM=&EL
M+5--4R!G871E=V%Y+61R:79E<BP@9F]R(&]P97)A=/AR97(L('-O;2!U9&)Y
M9&5R(&1E;FYE('-E<G9I8V4N`$524@!%<75A9&]R`%)E9&EG97(`QFYD<F4@
M8FQO:P#&;F1R92!G<G5P<&4`QFYD<F4@=&EL;&%D96QS90#&;F1R92!T:6QL
M861E;'-E<@#&;F1R92!T:6QL861E;'-E<B!F;W(@)7,`QFYD<F4@=F%L9R!F
M;W(Z`,9N9')E('1I;&QA9&5L<V5R(&9O<B`B)7,B`,9N9')E('1I;&QA9&5L
M<V5R(&9O<B`E<P!59&1A;FYE;'-E`,9G>7!T96X`16P@4V%L=F%D;W(`16QE
M;65N="XN+@!%;0!E36%I;`!E+6UA:6PM861R97-S90!%+6UA:6PM861R97-S
M97(@<VMA;"!P87-S92X`12UM86EL(&UE9"!B96MRYF9T96QS90!%;6%I;"UT
M;RU335,@1V%T97=A>0!3;6EL97ES`%1O;2!B97-K960N`$EN=&5T(')E<W5L
M=&%T+@!4;VUT('5D=')Y:P!!:W1I=NER(&EN9'/F='1E;'-E(&%F(&)I;&QE
M9&5R(&9R82!&;W1O9V%L;&5R:65R(&D@=&5K<W0_`$%K=&EVZ7(@:/AJ<F4M
M:VQI:R!C;VYT97AT+6UE;G4_`%-L=70MY7(`1F]R<W3X<B!E9&ET97)I;F=S
M=N9R:W3X:@!);F1T87-T(&5T('-I:VME<FAE9'-S</AR9W-MY6PL('-O;2!D
M=2!V:6P@8FQI=F4@<W!U<F=T+"!NY7(@9'4@:&%R(&)R=6<@9F]R(&%T(.9N
M9')E(&1I="!K;V1E;W)D+"!F>"`G:'9A9"!E<B!D:70@:^9L961Y<G,@;F%V
M;C\G.@!);F1T87-T(%523"!T:6P@8FEL;&5D(&AE<@!);F1T87-T(&)O9W-T
M879E<B!N961E;F9O<CH`QFMV871O<FEA;"!'=6EN96$`QG)I=')E80!&96IL
M`$9E:FP@=F5D(&1A;FYE;'-E(&%F(&)L;VLZ("5S`$9E:FP@=6YD97(@<VQE
M=&YI;F<@868@<WEN8RUHYF=T93H@)7,`1F5J;"!U;F1E<B!S;&5T;FEN9R!A
M9B!S>6YC(&QO9SH@)7,`1F5J;"!U;F1E<B!H96YT;FEN9R!A9B!I;F1H;VQD
M.B`E<P!&96IL('5N9&5R(&]P9&%T97)I;F<@868@:V]D96]R9#H@)7,`1F5J
M;"!F;W)B=6YD970@;65D(&4M<&]S="!B97-K960N`$9E:FP@=6YD97(@<VMR
M:79N:6YG(&%F("(E<R(N`$5S=&QA;F0`QG1I;W!I96X`171N:7-K`$5U<F]P
M80!(=F5R(&MV87)T97(`2'9E<G0@,BX@;6EN=70`2'9E<B!H86QV92!M:6YU
M=`!(=F5R(#4N(&UI;G5T`$%L=&ED('9E9"!L;V=I;@!(=F5R(&AA;'9E('1I
M;64`2'9E<B!M:6YU=`!%:W-E;7!E;';F<F1I97(Z`%5D9OAR`%5D=FED`$9O
M;&0@<VED97!A;F5L('5D`$9O<G9E;G1E9&4@)RDG`$9O<G9E;G1E9&4@<F5N
M="!O<F0@96QL97(@8VET97)E="!S^&=E=&5R;0!&;W+F;&1E;'-E<V1A=&\`
M16MS<&]N96YT`$9'+69A<G9E`$944"UL86=R:6YG(&%F(&]P<^9T;FEN9P!+
M=6YN92!I:VME(.9N9')E(&EN9'-T:6QL:6YG97)N92X`2W5N;F4@:6MK92!F
MY2!F;W)B:6YD96QS92!T:6P@3$1!4"!S97)V97)E;BX`2W5N;F4@:6MK92!F
M;W)B:6YD92!T:6P@4TU"+7-E<G9E<BX`1F5J;"!U;F1E<B!K;W!I97)I;F<@
M9G)A("(E<R(N`$MU;FYE(&EK:V4@:V]P:65R92!T:6P@(B5S(BX`2W5N;F4@
M:6MK92!E=&%B;&5R92!N>2!305-,+69O<F)I;F1E;'-E+@!+=6YN92!I:VME
M(&9L>71T92!T:6P@(B5S(BX`2W5N;F4@:6MK92!H96YT93H@)7,`4VUU:W0`
M1F%L:VQA;F1S^&5R;F4@*$UA;'9I;F%S*0!&YG+X97)N90!$^&1E;&EG(&9E
M:FPZ`$9A>`!&86MS:6UI;&5R`$9E8G)U87(`1OAL97,`1OAL97,Z(`!&Y2!B
M>6=E<@!&Y2!S;F5B>6=E<@!&96QT;6%T<FEC90!&:6=L970@0T%05$-(00!&
M:6=L970@<VMR:69T<W1Y<&]G<F%F:0!&:6II`$9I;`!!;G1A;"!F:6QE<CH@
M)7,@9FEL`$%N=&%L(&9I;&5R.B`E<R!F:6QE<@!&:6QHY6YD=&5R:6YG`$9I
M;&YA=FX`1FEL=F%L9P!&:6QL86=R:6YG`$9I;&QA9W)I;F<@:6MK92!U;F1E
M<G-T^'1T970N`$9I;'1R90!&:6YL86YD`$;X<G-T92!H86QV9&5L`$;X<G-T
M92!K=F%R=&%L`$9I:W/I<B!S=/AR<F5L<V5S9F]R:&]L9`!&;&EP`$9L>61E
M;F1E`%3E9V4`36%P<&4@)7,@96MS:7-T97)E<B!I:VME`%1Y<&]G<F%F:69A
M<G9E`$UA9`!&;W(@=V5B<')O9W)A;6UE<BP@<V]M(&EK:V4@=6YD97)S=/AT
M=&5R(&)I;&QE9&5R`%9E:G)U9'-I9W0@*%1!1BD`561S:6=T<V1A9V4@*&)E
M;>9R:R!A="!D96X@<F5T=7)N97)E('9E:G)U9'-I9W0@=F5D<OAR97(@8N5D
M92!D86<@;V<@;F%T.R!E="!S=&]R="!A;G1A;"!H97(@:V%N(')E<W5L=&5R
M92!I(&5N(&UE9V5T(&)R960@8FQO:RD`1VQE;70@9&ET(&MO9&5O<F0_`$9O
M<FUU;&%R97(`3W)D<W!R;V<`17!I9W)A;71Y<&4`17!I9W)A;6UE<@!%<&EG
M<F%M;65R(#(`1F]R80!6:61E<F5S96YD96QS90!&<F4`4F%M;65R`$9R86YK
M<FEG`$9R86YK<FEG+"!-971R;W!O;&ET86X`1G)A;G-K($=U>6%N80!&<F%N
M<VL@4&]L>6YE<VEE;@!&<F%N<VME('-Y9&QI9V4@5&5R<FET;W)I97(`1G)A
M`$9R80!&=6QD(&)E<VMR:79E;'-E`$9U;&1MY6YE`$9U;&1T(&YA=FX`1V%B
M;VX`1V%L;&5R:2!H=F]R9G)A(&)I;&QE9&4@<VMA;"!T86=E<R!F<F$`1V%L
M;&5R:3H`1V%M8FEA`$=E;F5RZ7(@)7,M:V]N9FEG=7)A=&EO;@!'96YE<F5R
M970@:V]D90!'96]R9VEE;@!4>7-K;&%N9`!':&%N80!':6)R86QT87(`1F]R
M;F%V;@!'<G5N9&SF9V=E;F1E(&EN9'-T:6QL:6YG97(`561F^'(`1_9D96P`
M1V]O9VQE($UA<',`1V]O9VQE+7/X9VYI;F<`1W+E=&]N97(`1W+F:V5N;&%N
M9`!'<N9S:R`H25-/+3@X-3DM-RD`1W+X;FQA;F0`1W)E;F%D80!'<G5P<&4M
M861M:6YI<W1R871I;VX`1W)U<'!E;F%V;F4@;>4@:6MK92!VYG)E('1O;6UE
M`$=R;W5P7VQD87`Z($MA;B!I:VME('1I;&;X:F4@9W)U<'!E("5S+B!397)V
M97)E;B!M96QD97(Z(`!'<F]U<%]L9&%P.B!+86X@:6MK92!S;&5T=&4@9W)U
M<'!E("5S`$=R;W5P7VQD87`Z($MA;B!I:VME(&]P9&%T97)E(&=R=7!P92`E
M<P!'<G5P<&5R`$=U861E;&]U<&4`1W5A;0!'=6%T86UA;&$`1W5E<FYS97D`
M1^9S=&5T:6QL861E;'-E<@!'YG-T96)O9P!'=6EN96$`1W5I;F5A+4)I<W-A
M=0!'=7EA;F$`2%1-3`!(5$U,07)E82!NYF=T97(@<.4@9F5J('9I<R!A="!S
M;&5T=&4@9&5N('-I9'-T92!C96QL92!I('+F:VME+@!(5$U,07)E82!NYF=T
M97(@<.4@9F5J('9I<R!A="!S;&5T=&4@9&5N('-I9'-T92!K;VQO;FYE(&D@
M=&%B96PN`$A434Q!<F5A(&[F9W1E<B!PY2!F96H@=FES(&%T('-L971T92!D
M96X@<VED<W1E('+F:VME(&D@=&%B96PN`$A45%`MYF=T;FEN9R!I:VME(&9U
M;F1E="X`2&'O=&D`2&%S:"UA;&=O<FET;64`1&ES`%1O<'1E:W-T`$]V97)S
M:W)I9G1E<@!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2W)A
M9G1I9R!T;W)D96X`2&5B<F%I<VL@*$E33RTX.#4Y+3@M22D`2/AJ9&4`2&KF
M;'``2&KF;'`@=&EL(')E9&EG97)I;F=S=N9R:W3X:@!(:N9L<&5R`$AE;6ES
M9N9R90!(97(@97(@<W1A<G1E;B!A9B!F:6QE;CH`2/AJ`$AJ96T`2&5L;&EG
M<_@@*%9A=&EK86YS=&%T96XI`$AJ96T`4')I=F%T+6%D<F5S<V4`2&IE;6UE
M:V%T86QO9P!0<FEV870M=&5L969O;@!(;VYD=7)A<P!(;VYG($MO;F<`2&]R
M9&4`2&]R9&4O2V]L86(Z(%5G>6QD:6<@)7,@6$U,(&1A=&$@<.5T<G5F9F5T
M(&D@8F5S:V5D("5S`$AO<F1E+TMO;&%B.B!);F=E;B!B97-K960@<W9A<F5R
M('1I;"!O8FIE:W0@)7,`2&]R9&4O2V]L86(Z($EN=&5T(&]B:F5K="!A9B!T
M>7!E("5S(&9U;F1E="!I(&)E<VME9"`E<P!(;W)D92]+;VQA8CH@4VQE='1E
M9&4@)7,@(B5S(@!(;W)D92]+;VQA8CH@26YT96=R871I;VYS;6%S:VEN96X@
M:W+F=F5R(%!(4"UU9'9I9&1E;'-E("=D;VUX;6PG`$AO<F1E+TMO;&%B.B!+
M86X@:6MK92!D86YN92!N>70@6$U,+71RYB!F;W(@;V)J96MT("5S`$AO<F1E
M+TMO;&%B.B!+86X@:6MK92!S;&5T=&4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L
M86(Z($MA;B!I:VME(&EN9&AE;G1E($U)344M240@9F]R(&1E;&5N(&%F('1Y
M<&4@)7,`2&]R9&4O2V]L86(Z($MA;B!I:VME('-Y;FMR;VYI<V5R92`E<R`B
M)7,B.B`E<P!(;W)D92]+;VQA8CH@2V%N(&EK:V4@<WEN:W)O;FES97)E(&1E
M;&EN9V5R.B`E<P!(;W)D92]+;VQA8CH@56ME;F1T(&1E;&EN9R`B)7,B`%9A
M;F1R970@<W1R96<`5F%N9')E="!F;W(`5F%N9')E=#H`2'9O<F1A;B!B87(@
M9'4@9&EG(&%D(&UE9"!A="!H879N92!H97(_("A);F1R87!P;W)TZ7(A*0!(
M=F]R(&UA;F=E(&MO;&]N;F5R(/AN<VME<B!D=2!A="!S86UM96YLYF=G93\`
M2'9O<B!M86YG92!F96QT97(@*&MO;&]N;F5R*2!E<B!D97(_`$AV;W(@;6%N
M9V4@<N9K:V5R(/AN<VME<B!D=2!A="!S86UM96YLYF=G93\`1G5G=&EG:&5D
M`$9U9W1I9VAE9#H@`$AU;6]R:7-T97(`56YG87)N`$]P<F5T=&5L<V4@868@
M24U!4"UM87!P92!F96IL961E.B`E<P!3;&5T;FEN9R!A9B!)34%0+6UA<'!E
M(&9E:FQE9&4Z("5S`$1E9FEN97)I;F<@868@:W9O=&4@9F]R($E-05`M;6%P
M<&4@9F5J;&5D93H@)7,`25`M861R97-S90!)4"UA9')E<W-E(&EK:V4@=&EL
M9^9N9V5L:6=E+@!)4"UA9')E<W-E(&EK:V4@:6YD96YF;W(@0TE$4BUB;&]K
M+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$EN9'/F="!RYFMK92!F^'(`27-L
M86YD`$MU;B!I:V]N97(`26MO;F5R(&9O<B`E<P!):V]N97(@;65D('1E:W-T
M`$ED96YT:71E='-N879N.@!(=FES(&1E;B!I:VME('9I<W0@:V]R<F5K="P@
M)7,@9F]R(&%T(.5B;F4@9&5N(&D@970@;GET('9I;F1U92X`2'9I<R!D=2!I
M:VME('-E<B!N;V=E;B!I:V]N97(@=F5D(&)R=6<@868@26YT97)N970@17AP
M;&]R97(@<VMA;"!D=2!MY7-K92!H86MK92!D96YN92!B;VMS(&%F(&9O<B!A
M="!S;.4@4$Y'+71R86YS<&%R96YS(&9R82X`2'9I<R!D=2!S97(@9&5N;F4@
M8F5S:V5D(&D@<W1E9&5T(&9O<B!E="!B:6QL961E+"!SY2!V:6P@9'4@:6MK
M92!K=6YN92!S92!D970@:2!D:6X@;F5T+6SF<V5R(&5F=&5R(&]P;.9G;FEN
M9RX`0FEL;&5D+69O<FCE;F1S=FES;FEN9SH`0FEL;&5D+5523`!":6QL960M
M55),.@!":6QL961E(&9R82!G86QL97)I`$)I;&QE9&4@9G)A(&=A;&QE<FDZ
M`$)I;&QE9"UO<&SF9VYI;F<`0FEL;&5D97(`26UP;W)T97)I;F<L('1R:6X@
M)60`26UP;W)T97)E9&4@9F5L=&5R.B`E<P!);7!O<G1E<F5D92!F96QT97(Z
M`$EN9'/F="!RYFMK92!E9G1E<@!&96IL86=T:6<@:&%N9&QI;F=S:V]D92!A
M;F=I=F5T+@!5:V]R<F5K="!B<G5G97)N879N(&]G+V5L;&5R(&MO9&5O<F0N
M`%5K;W)R96MT(&)R=6=E<FYA=FX@96QL97(@86QT97)N871I=B!A9')E<W-E
M+B!0<OAV(&EG96X@96QL97(@:V]N=&%K="!D:6X@861M:6YI<W1R871O<BP@
M:'9I<R!D=2!H87(@8G)U9R!F;W(@>61E<FQI9V5R92!H:N9L<"X`1F]R^&<@
M:6YD<GEK;FEN9P!);F1I96X`26YD:79I9'5E;&QE(&)R=6=E<F4`26YD;VYE
M<VEE;@!);F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&EK:V4@;.9N9V5R
M92!T:6QGYFYG96QI9P!);F1SYG0@:V]L;VYN92!E9G1E<@!);F1SYG0@8FEL
M;&5D90!);F1SYG0@=&%B96P`26YD<^9T('=E8BUH96YV:7-N:6YG`$EN9'/F
M="!K;VQO;FYE(&;X<@!);F1SYG0@96X@;GD@:V]L;VYN92!E9G1E<B!D96X@
M86MT=65L;&4`26YD<^9T(&5N(&YY(&MO;&]N;F4@9OAR(&1E;B!A:W1U96QL
M90!);F1SYG0@96X@;GD@<N9K:V4@969T97(@9&5N(&%K='5E;&QE`$EN9'/F
M="!E;B!N>2!RYFMK92!F^'(@9&5N(&%K='5E;&QE`$EN9'/F="!E;B!P87)A
M9W)A9B!E9G1E<B!D970@86MT=65L;&4@<'5N:W0`26YD<^9T(&5N('!A<F%G
M<F%F(&;X<B!D970@86MT=65L;&4@<'5N:W0`26YD<^9T(&%L=&5R;F%T:78@
M<VMA8F5L;VX`26YD=&%S="!E;B!E+6UA:6PM861R97-S92P@:'9O<G1I;"!D
M=2!K86X@;6]D=&%G92!D970@;GEE(&MO9&5O<F0Z`$EN9'/F="!C96QL92!E
M9G1E<@!);F1SYG0@8V5L;&4@9OAR`$EN9'/F="!K;VQO;FYE(&5F=&5R`$EN
M9'/F="!K;VQO;FYE(&;X<@!);F1SYG0@8F5S:V5D97(`26YD<^9T('!A<F%G
M<F%F(&5F=&5R`$EN9'/F="!P87)A9W)A9B!E9G1E<@!);F1SYG0@<N9K:V4@
M969T97(`26YD<^9T('+F:VME(&;X<@!);F1T87-T(&1E="!K<N9V961E('-V
M87(@=&EL('-I:VME<FAE9'-S</AR9W-MY6QE=#H`26YD<^9T+^9N9')E(&)I
M;&QE9&4`26YD<^9T+^9N9')E(&AE;G9I<VYI;F<`571I;'-T<N9K:V5L:6<@
M:W)E9&ET('1I;"!A="!S96YD92!T:6P@9&ES=')I8G5T:6]N<VQI<W1E;BX`
M571I;'-T<N9K:V5L:6=E(&MR961I="X`2&5L=&%L`$AE;'1A;'-L:7-T90!5
M9WEL9&EG(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!59WEL9&EG92!:25`M
M9&%T80!59WEL9&EG="!A<'!L:6MA=&EO;BX`56=Y;&1I9W0@<VMR:7!T+4E$
M+@!59WEL9&EG92!D871A(&%F<V5N9'0N`%5G>6QD:6<@9&5S=&EN871I;VXN
M`%5G>6QD:6=T(&9I;&9O<FUA=`!59WEL9&EG(&QI8V5N<V[X9VQE+@!59WEL
M9&EG('!L86-E<FEN9R!A;F=I=F5T+@!59WEL9&EG(&US9U]T>7!E+@!59WEL
M9&EG(&5L;&5R(&UA;F=L96X@87!I7VED+@!59WEL9&EG92!E;&QE<B!M86YG
M;&5N9&4@<&%R86UE=')E+@!59WEL9&EG92!F;W+F;&1R92UT:6QL861E;'-E
M<BX`56=Y;&1I9R!P87)T;F5R+6ED+@!59WEL9&EG('!R;V1U:W0M:V]D92X`
M56=Y;&1I9R!P<F]T;VMO;"X`56=Y;&1I9R!M;V1T86=E<CH@(B5S(@!59WEL
M9&EG="!D96QI;F=S;V)J96MT`%5G>6QD:6<@;W!R:6YD96QS97-A9')E<W-E
M+@!59WEL9&EG('5N:6-O9&4M9&%T82X`26YD8F\`26YV97)TZ7(@;6%R:V5R
M:6YG`$ER86XL($1E;B!I<VQA;6ES:R!R97!U8FQI:P!)<F%K`$ER;&%N9`!-
M86X`4W1E9'9I<R!T;W)D96X`27-R865L`%5D<W1E9&5R`$ET86QI96YS:P!)
M=&%L:65N`$IA;6%I8V$`2F%N=6%R`$IA<&%N`$IA<&%N<VL@*$E33RTR,#(R
M+4I0*0!*97)S97D`2F]R9&5N`$IU;&D`2G5N:0!*=7-TZ7(`0V5N='+I<@!,
M:6=E(&UA<F=E;F5R`%9E;G-T<F5J=7-T97)E=`!(^&IR96IU<W1E<F5T`$MA
M<V%K:'-T86X`0F5V87(@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E
M<B!A9G9I<W1E(&=O9&ME;F1E;'-E(&%F(&ED96YT:71E="X`2V5R;F4M/&5M
M/DYE=V)I97,\+V5M/@!.^&=L92US:V%B96QS90!.^&=L92UF:6YG97)A9G1R
M>6L`3OAG;&5LYFYG9&4`3OAG;&5T>7!E`$[X9VQE86YV96YD96QS90!.^&=L
M92!E:W-I<W1E<F5R(&%L;&5R961E('#E(&1E;B!O9F9E;G1L:6=E(&[X9VQE
M<V5R=F5R+@!"^')N`$MI<FEB871I`%-Y9&MO<F5A`$YO<F1K;W)E80!K;W)E
M86YS:R`H155#+4M2*0!+=7=A:70`2VER9VES:7-T86X`561F;W)M;FEN9P!3
M<')O9P!,86]S`%-I9'-T92!H86QV9&5L`%-I9'-T92!K;V1E;W)D<^9N9')I
M;F<`4VED<W1E(&MV87)T86P`4VED<W0@;W!D871E<F5T.@!3:61S=&4@;&]G
M:6XZ("5S`%-I9'-T92!I;F1L;V=N:6YG.B`E<R!F<F$@)7,`4VED<W1E(&QO
M9VEN.B!!;&1R:6<`3&5T;&%N9`!,;W8`3&%Y;W5T`%1O;2!V960@:6YG96X@
M<F%M;65R`$QI8F%N;VX`5F5N<W1R90!696YS=')E('1O<'1E:W-T`%9E;G-T
M<F4@=N9R9&EE<@!,97-O=&\`3FEV96%U`$QI8F5R:65N`$QI8GEE;@!,:65C
M:'1E;G-T96EN`%-T^'9R96=N`$QE="!R96=N`$QE="!R96=N('1I9&QI9W0`
M3&5T(')E9VX@<V5N=`!,970@8GEG90!,970@8GEG92!M960@=&]R9&5N`$QE
M="!S;F4`3&5T('-N92!B>6=E`%9I='1I9VAE9`!(96YV:7-N:6YG`$9O<F)I
M;F0@<'5N:W1E<B!T:6PZ`$9O<F)I;F0@92UM86EL+6%D<F5S<V5N(&UE9"!I
M;F1S:W)I=FYI;F=S<VED96X@=F5D(&9R96UV:7-N:6YG`$AE;G9I<VYI;F=E
M<@!,:6YU>"UK:6MS`$QI<W1E("T@8G)U9V5R(&MA;B!S92!M87!P96X`3&ES
M="!D871A8F%S97(`3W!L:7-T;FEN9R!A9B!H:N9L<&5E;6YE<@!,:7-T('1A
M8F5L;&5R`$QI<W1E+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/
M=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB
M90!,:7-T;FEN9R!A9B!S97-S:6]N<R!F96IL961E.B`E<P!,:7-T;FEN9R!A
M9B!B<G5G97)E(&9E:FQE9&4Z("5S`%9I<VYI;F<@868@8G)U9V5R92!E<B!S
M;.5E="!F<F$N`$QI='1E<F%T=7(`3&ET875E;@!(96YT97(N+BX`3&]K86P@
M=&ED.@!296=I;VYA;&1A=&$@;V<@=&ED`%-T960`3&]G(&EN9`!,;V<@868@
M=&ED;&EG97)E('-Y;FMR;VYI<V5R:6YG<W-E<W-I;VYE<@!,;V<@=60`3&]G
M(&EN9`!,;V=I;BUO<&=A=F5R`$QO9R!I;F0@9F5J;&5D92!F;W)D:2!D:70@
M8G)U9V5R;F%V;B!E;&QE<B!K;V1E;W)D(&)L978@86YG:79E="!F;W)K97)T
M+@!,;V=I;F0@;6ES;'EK:V5D97,N`$QA;F<@=&5K<W0`2^9R;&EG:&5D`$QA
M=@!3;>4@9W+F<VME('1E9VX`4VWE(&QA=&EN<VME('1E9VX`4VWE(')O;65R
M=&%L`$QU>&5M8F]R9P!-30!-3U1$`$U3+51.148M8FEL86<@:6YD:&]L9'0@
M:6YG96X@9&%T82X`35-'`$UA8V%O`$UA:V5D;VYI96XL($1E;B!T:61L:6=E
M<F4@:G5G;W-L879I<VME(')E<'5B;&EK`$UA9&%G87-K87(`36%G:0!%+6UA
M:6P`12UM86EL+6%D;6EN:7-T<F%T;W(`1&%N(&AE;G9I<VYI;F<N+BX`36%L
M87=I`$UA;&%Y<VEA`$UA;&1I=F5R;F4`36%L:0!-86QT80!(Y6YD=.ER(&QI
M<W1E;B!A9B!K871E9V]R:65R+"!S;VT@9'4@<VMA;"!M87)K97)E(&5M;F5R
M(&UE9"P@;V<@9F%R=F5R;F4L(&1E<B!S:V%L(&MN>71T97,@=&EL(&1I<W-E
M(&MA=&5G;W)I97(N`$UA<#(T+6MO<G0`36%P475E<W0M:V]R=`!+;W)T;.9G
M;FEN9R!G96UT+@!-87)T<P!-87)G96X`36%R:^ER(&UE9"!3970O57-E="UF
M;&%G`$UA<FOI<B!M960@86YD<F4@9FQA9R`H9G@@5FEG=&EG+T)E<W9A<F5T
M*0!-87)S:&%L;/AE<FYE`$UA<G1I;FEQ=64`3W9E<F5N<W!A<W-E;F1E(&9E
M;'1E<@!-875R:71A;FEE;@!-875R:71I=7,`36%X('1I;&QA9'0@:W)E9&ET
M+@!-86MS:6UU;2!B97-K960M9&5L92!O=F5R<VMR961E="X`36%K<RX@=&5M
M<"X@<VED<W0@,C0@=&EM97(Z(`!-86MS+B!T96UP+B!S:61S=&4@-B!T:6UE
M<CH@`$UA:W-I;75M(&%N=&%L(&%F('!O<G1A;&)L;VMK90!-86MS:6UU;6SF
M;F=D90!-86H`36%Y;W1T90!-961I8VEN`$UE9&QE;6UE<@!-96YU+71I;'-T
M86YD.@!&;W+I;B!C96QL97(`0F5S:V5D`$)E<VME9"!S=6-C97-F=6QD="!V
M97)I9FEC97)E="!M960@=6YD97)S:W)I=F5R96YS(&-E<G1I9FEK870@:W5N
M;F4@:6MK92!V97)I9FEC97)E<RX`0F5S:V5D('5D;/AB970N`$)E<VME9'1Y
M<&4`365T87(@5V5A=&AE<@!-971A<F)L;VL@:6MK92!T:6QGYFYG96QI9RX`
M365T87)B;&]K(&EK:V4@=&EL9^9N9V5L:6<N($1E=&%L:F5R(&5R(&)L979E
M="!N;W1E<F5T('1I;"!B<G5G(&9O<B!A9&UI;FES=')A=&]R96XN`$UE=&%R
M1$(@97(@:6MK92!F;W)B=6YD970N`$UE=&]D90!-971O9&4@(B5S(B!E<B!I
M:VME(&1E9FEN97)E=`!-971O9&4@:6MK92!D969I;F5D+B!-971O9&4@:V%L
M9'0Z("5S`$WE;&5E;FAE9`!-97AI8V\`36EK<F]N97-I96X`36ED=`!-24U%
M+71Y<&4`36EN+B!T96UP+B!S:61S=&4@,C0@=&EM97(Z(`!-:6XN('1E;7`N
M('-I9'-T92`V('1I;65R.B``36EN:6UU;2!K;V1E;W)D<V%L9&5R(&5R(&5N
M9&YU(&EK:V4@=61S=.5E=`!3<&5J;&4`1F]R<VME;&QI9W0`36%N9VQE<B!0
M14%2+7!A:VME($A45%!?4F5Q=65S="X`2V]N9FEG=7)A=&EO;B!M86YG;&5R
M+B!$=2!B;&EV97(@;OAD="!T:6P@870@9V5N97)E<F4@9&5N(&YU+"!H=FES
M(&1U(/AN<VME<B!A="!B<G5G92!D96YN92!A<'!L:6MA=&EO;BX`36%N9VQE
M<B!B97-K960M:60N`$UA;F=L97(@:W+F=F5T(%!%05(M<&%K:V4@36%I;"X`
M36%N9VQE<B!S97-S:6]N+4E$+@!-86X`36]B:6P@12UP;W-T`$KF=FX`QFYD
M<FEN9W-D871O`,9N9')E(%523`!-;V1U;'5S`$UO;&1O=F$`36]N86-O`$UO
M;F=O;&EE;@!-Y6YE9"!O9R#E<@!-Y6YE9&QI9P!-;VYT<V5R<F%T`$WE;F5F
M87-E<@!&;&5R92!F96QT97(@9G5N9&5T(&D@;&EN:64@)60@96YD(&1E="!F
M;W)V96YT961E("5D+@!-87)O:VMO`$UE<W0@<VMY9G)I=`!-97-T('-K>65T
M`$UE<W0@<VMY970@;V<@8FSF<V5N9&4`365S="!S;VP`1FQY="!N960`1FQY
M="!T:6P@=F5N<W1R90!-;V0@:/AJ<F4`1FQY="!O<`!&;'ET(&YE9`!&;'ET
M(&]P`$UO8V%M8FEQ=64`375L=&DM;FEV96%U(')U;&QE9V%R9&EN<VQI<W1E
M<@!-=6QT:6UA<"!52R!K;W)T`$UU;'1I<&QE('9A;&<`36EN(&MO;G1O`$UI
M;F4@:V]N=&\M:6YF;W)M871I;VYE<@!-:6X@4&]R=&%L`$UI;B!0;W)T86PM
M=61F;W)M;FEN9P!->6%N;6%R`$Y%2BP@:F5G(&5R($E+2T4@96YI9P!.879N
M`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5D97)L86YD96YE`$AO;&QA;F1S:V4@
M06YT:6QL97(`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A
M=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE
M=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!34TP@
M<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S
M8V%P92!C97)T:69I8W1E('1Y<&4`3F5T=N9R:P!!;&1R:6<`3GD@2V%L961O
M;FEE;@!.>2!K871E9V]R:0!.>6WE;F4`3GET(&)R=6=E<FYA=FX@*'9A;&=F
M<FET*0!.97<@6F5A;&%N9`!.>70@:V]D96]R9`!.>70@:V]D96]R9"!V:6P@
M=61L^&)E(&1E;B`E>"X`3GEE(&MO9&5O<F0@97(@:6MK92!E;G,N`$YY="!V
M:6YD=64@*%]B;&%N:RD`3GEH961E<@!.>6AE9'-G<G5P<&5R`$[F<W1E`$[F
M<W1E(#0@9F%S97(`3N9S=&4@=&EL=F%L9P!.YG-T93X`3FEC87)A9W5A`$YI
M9V5R`$YI9V5R:6$`3F%T`$YI=64`3F5J`$EN9V5N('1I;&?F;F=E;&EG92!K
M;VYF:6=U<F%T:6]N9&%T82!A="!V:7-E(&9O<G-K96QL92!F;W(N`$EN9V5N
M('1I;&?F;F=E;&EG('-T<F%T96=I('1I;"!A="!L879E($E33RUB:6QL961E
M<BX`26YG96X@<VMR:7!T+7-K86)E;&]N+@!$97(@96MS:7-T97)E<B!I:VME
M(&YO9V5N(&)L;VL@<.4@9&5N(&9O<F5S<'5R9W1E('!O<VET:6]N`$EN9V5N
M(&MA;&5N9&5R(&%N9VEV970@=&EL($U#04PMYF=T;FEN9RX`26YG96X@YFYD
M<FEN9RX`1&5R(&MA;B!I:VME('1I;&;X:F5S(&+X<FX@=&EL(&1E;FYE('1I
M;&QA9&5L<V4N`$EN9V5N(&MO;F9I9W5R871I;VXM:6YF;W)M871I;VX@86YG
M:79E="!F;W(@)7,N`$EN9V5N(&MO;F9I9W5R871I;VXM:6YF;W)M871I;VX@
M86YG:79E="!F;W(@1E10(%9&4RX`26YG96X@:V]N9FEG=7)A=&EO;BUI;F9O
M<FUA=&EO;B!A;F=I=F5T(&9O<B!344P@5D93+@!);F=E;B!K;VYF:6=U<F%T
M:6]N+6EN9F]R;6%T:6]N(&%N9VEV970@9F]R(%-13"U&:6QE(%9&4RX`2W)E
M9&ET('5D=/AM="X`26YT970@8F5S=&5M;65L<V5S<W1E9"!A;F=I=F5T+@!)
M;F=E;B!F:6P@<V5N9'0`1F%N9'0@:6YG96X@:6MO;F5R+@!);G1E="!S=&5D
M(&EN9'-T:6QL970N`$EN=&5T('-T960@86YG:79E="X`26YG96X@8F5S:V5D
M(&%N9VEV970N`$EN=&5T(&YA=FX@86YG:79E="X`26YT970@;G5M;65R(&%N
M9VEV970N`$EN9V5N(&%N<W3X9&5L:6=E(&5P:6=R86UM97(`26YT970@:V]D
M96]R9"!A;F=I=F5T('1I;"!B<G5G(&9O<B!(5%10+>9G=&YI;F<N`$EN=&5T
M(&MO9&5O<F0@86YG:79E="!T:6P@8G)U9R!F;W(@24U!4"WF9W1N:6YG+@!)
M;G1E="!K;V1E;W)D(&%N9VEV970@=&EL(&)R=6<@9F]R($ME<F)E<F]S+>9G
M=&YI;F<N`$EN=&5T(&MO9&5O<F0@86YG:79E="!F;W(@3&]G:6YD+>9G=&YI
M;F<N`$EN=&5T(&MO9&5O<F0@86YG:79E='0@=&EL(%!!4U-71"WF9W1N:6YG
M+@!);G1E="!K;V1E;W)D(&%N9VEV970@9F]R(%--0BWF9W1N:6YG+@!3=&D@
M=&EL($]P96Y34TPM8FEB;&EO=&5K970@;6%N9VQE<BX@($]P96Y34TPM8FEB
M;&EO=&5K970@97(@;OAD=F5N9&EG="!F;W(@870@:.5N9'1E<F4@4$M#4S$R
M+61A=&$N`$EN9V5N('9E;G1E;F1E(&]P<VMR:79N:6YG97(N`$MV;W1E(&EK
M:V4@:6YD<W1I;&QE="X`26YG96X@<W1R96=E<@!);F=E;B!S:VEL;&5T96=N
M(&%N9VEV970N`$EN9V5N('-I9&5R`$EN9V5N('/E9&%N(&9I;`!$97(@;6%N
M9VQE<B!E="!M:61L97)T:61I9W0@:V%T86QO9R!T:6P@;65L;&5M;&%G97(N
M`$EN=&5T(&)R=6=E<FYA=FX@;V<O96QL97(@:V]D96]R9"!S96YD="X`26YG
M96X@9WEL9&EG92!834PM9&%T82!R971U<FYE<F5T`$EN9V5N(';F<F1I97(`
M3W)I9VEN86P@:V]N9FEG=7)A=&EO;B!M86YG;&5R('9E<G-I;VYS;G5M;65R
M+B!296=E;F5RZ7(@:V]N9FEG=7)A=&EO;BX`1&EN(&MO;F9I9W5R871I;VX@
M;6%N9VQE<B!V97)S:6]N<VYU;6UE<BX@4F5G96YE<NER(&MO;F9I9W5R871I
M;VXN`$EN9V5N`$EN9V5N("AB<G5G(&EM<&QI8VET*0!.;W)D:7-K("A)4T\M
M.#@U.2TQ,"D`3F]R9F]L:P!.;W)D;&EG92!H86QV:W5G;&4`3F]R9&QI9V4@
M36%R:6%N8?AE<@!.;W)G90!):VME('-E;F5R92!E;F0`26MK92!F^'(`26MK
M92!N;V=E="!K871A;&]G`$EK:V4@:6UP;&5M96YT97)E="X`26MK92!I;F1S
M=&EL;&5T`$EK:V4@=6YD97)S=/AT=&5T+@!.;W1E<@!);G1E="!A="!B<F]W
M<V4L('9E;F0@=&EL8F%G92X`3F]V96UB97(`5&%L`$%N=&%L('1E9VX`06YT
M86P@:V]L;VYN97(`06YT86P@<N9K:V5R`%1A;"!I:VME(&%N9VEV970@9F]R
M(&]P9&%T97)I;F<@:2!D:7-T<FEB=71I;VYS;&ES=&4N`$]+`$]B:F5K=`!/
M8FIE:W1D86YN97(`3VMT86P`3VMT;V)E<@!!;G-T^&1E;F1E(&9I;'1E<@!+
M;VYT;W(`1V%M;65L="!O9R!N>70@:V]D96]R9"!S:V%L(';F<F4@9F]R<VME
M;&QI9V4N`$=A;6UE;'0@:V]D96]R9`!'86UM96QT(&MO9&5O<F0@97(@:6MK
M92!K;W)R96MT+@!/;6%N`$1E;'1E(&UA<'!E<B!U;F1E<G-T^'1T97,@:W5N
M(&%F($E-05`M<V5R=F5R92X`2W5N(&%N<W3X9&5L:6=E(&5P:6=R86UM97(`
M2W5N(.EN(&4M<&]S="UA9')E<W-E('1I;&QA9'0N`$5N(&1E;&EN9W,@96IE
M<G-K86(@;V<@96IE<G1I;&QA9&5L<V5R(&WE(&MU;B#F;F1R92!A9B!E;B!S
M>7-T96UA9&UI;FES=')A=&]R(&5L;&5R(&5J97)E;B!S96QV`,5B96X@:2!E
M="!N>70@=FEN9'5E`$]P96Y34TPM9F5J;#H@1&%T82!K=6YN92!I:VME('5D
M9')A9V5S(&9R82!S:6=N97)E="!3+TU)344M9&5L+@#%8F5N(&1E;FYE(&AE
M;G9I<VYI;F<@:2!E="!N>70@=FEN9'5E`$]P97)A=&EV<WES=&5M`$EN9'-T
M:6QL:6YG97(`26YD<W1I;&QI;F=E<B!F;W(@)7,`3W)D;F5T(&QI<W1E`$]R
M9V%N:7-A=&EO;@!/<F=A;FES871O<FES:R!E;FAE9`!/<F=A;FES97)I;F<`
M3W!R:6YD96QI9R!A<'!L:6MA=&EO;G-S:V%B96QO;@!/<')I;F1E;&EG92!S
M:V%B96QO;F5R(&D@)7,Z`$%N9&5N`$%N9&5N(&EN9F]R;6%T:6]N`$5J97)R
M971T:6=H961E<@!004TMYF=T;FEN9R!E<B!I:VME('1I;&?F;F=E;&EG92X`
M4$5!4CHZ36%I;"UM;W1O<@!01U`@9&EG:71A;"!S:6=N871U<@!01U`M:W)Y
M<'1E<F5T(&1A=&$`3V9F96YT;&EG(%!'4"UN^&=L90!01U`M<VEG;F5R970O
M:W)Y<'1E<F5T(&1A=&$`4$A0+6MO9&4`4$A0+7-K86P`169T;2X@;&5T(')E
M9VX`169T;2X@<F5G;@!%9G1M+B!B>6=E<@!%9G1M+B!S;F4`169T;2X@<VYE
M8GEG97(`169T;2X@<V]L`$5F="X@=&]R9&5N`%!/4TE8+75D=FED9&5L<V4@
M;6%N9VQE<@!02%`M<VMA;`!&;W)R:6YG`%!A:VES=&%N`%!A;&%U`%!A;.9S
M=&EN80!086YA;6$`4&%P=6$@3GD@1W5I;F5A`%!A<F%G=6%Y`$1E;'9I<W0@
M<VMY970`2V]D96]R9`!+;V1E;W)D(.9N9')E="X`2V]D96]R9"!F;W)K97)T
M`$MO9&5O<F0@:W+F=F5T('9E9"!2041)55,MYF=T;FEN9RX`2V]D96]R9"!M
M960@8F5K<N9F=&5L<V4`2V]D96]R9#H`2V]D96]R9#H@`$MO9&5O<F1E;F4@
M<VMA;"!VYG)E(&5N<RX`26YD<^9T`$EN9'/F="!F<F$@=61K;&EP<VAO;&1E
M<@!3=&D`5F5N=&5N9&4@;W!S:W)I=FYI;F=E<CH`1F]L:P!0<F]C96YT`%5D
M9OAR('9E9&QI9V5H;VQD96QS90!59&;X<B!V961L:6=E:&]L9&5L<V4@=F5D
M(&QO9R!I;F0_`%1I;&QA9&5L<V5R`%1I;&QA9&5L<V4@(B5S(B!I:VME('-L
M971T970N`%1I;&QA9&5L<V4@;N9G=&5T`%1I;&QA9&5L<V5R`%1I;&QA9&5L
M<V5S+6%D;6EN:7-T<F%T:6]N`%!R;V9I;&5R`%!E<G4`2^9L961Y<@!&:6QI
M<'!I;F5R;F4`5&5L969O;@!&;W1O<P!0:71C86ER;@!0<FEK:V5R`$)A;F%L
M:71E=&5R`$ML:6L@:2!E;B!C96QL90!"96MRYF9T(&%T(&1U(/AN<VME<B!A
M="!S;&5T=&4@9&5T=&4@96QE;65N=#H`0F5K<N9F="!A="!D=2#X;G-K97(@
M870@869LYFYK92!D971T92!E;&5M96YT+@!);F1T87-T(&5N(&WE;F5D(&]G
M(&5T(.5R<W1A;"X`26YD=&%S="!E="!N879N('1I;"!D96X@;GEE(&MA=&5G
M;W)I.@!);F1T87-T(&5N(&=Y;&1I9R!)4"UA9')E<W-E+@!);F1T87-T(&5N
M(&=Y;&1I9R!D871O+"!T:F5K(&%N=&%L;&5T(&%F(&1A9V4@:2!MY6YE9&5N
M+@!);F1T87-T(&5N(&=Y;&1I9R!T:61S86YG:79E;'-E+@!3:W)I=B!V96YL
M:6=S="P@:'9A9"!P<F]B;&5M970@9^5R('5D('#E(&]G(&AV860@9&5R('-K
M97(N`$EN9'1A<W0@=F5N;&EG<W0@8G)U9V5R;F%V;B!O9R!K;V1E;W)D`$SF
M<R!F^&QG96YD92!T96MS="X@1'4@4TM!3"!VYG)E(&5N:6<@:2!B971I;F=E
M;'-E<FYE(&9O<B!A="!B<G5G92!S>7-T96UE="X`26YD=&%S="!D970@;GEE
M(&MA=&5G;W)I;F%V;CH`4&]L96X`4&]L:71I:P!-96YI;F=S;>5L:6YG97(`
M4&]R='5G86P`4&QA8V5R:6YG(&%F(&)I;&QE9&5T`%!L86-E<FEN9R!A9B!D
M96YN92!T86)E;`!396YD('1I;"!D96YN92!M87!P92`H:6MK92!G96YN96UT
M=G5N9V5T(&%F($E-05`I`$YE9&+X<B!G96YN96T@<V5N97-T("5S('1I;65R
M.B``3F5D8OAR/&)R("\^8VAA;F-E`%!R969S7VQD87`Z($MRYG9E="!,1$%0
M+75D=FED9&5L(&EK:V4@9G5N9&5T+@!0<F5F<U]S97-S:6]N.B!+<N9V970@
M<V5S<VEO;BUU9'9I9&1E;'-E(&EK:V4@9G5N9&5T+@!4<GEK`%1R>6L@=F5D
M(&]V97)F;&%D96XZ(`!4<GEK.B``1VQI;70`0F5T<F%G="!B:6QL961E="!I
M(&5T(&YY="!V:6YD=64`1F]R<FEG92!T:6QV86QG`%5D<VMR:78@9&]K=6UE
M;G0`4')I=F%T(&[X9VQE`%!R;V)L96T`4')O8FQE;6)E<VMR:79E;'-E`%!R
M;VIE:W1E<@!3=&EK;W)D<W1E:W-T`$]F9F5N=&QI9V4@;OAG;&4`3V9F96YT
M;&EG+6[X9VQE+6%L9V]R:71M90!/9F9E;G1L:6<@;OAG;&4@:6YF;W)M871I
M;VX`3V9F96YT;&EG+W!R:79A="UN^&=L97/F="UG96YE<F5R:6YG(&UI<VQY
M:VME9&5S+@!0=65R=&\@4FEC;P!59')E;G,@8F5S:V5D97(`46%T87(`1F]R
M97-P^')G<V5L`$MV;W1E`$]F9F5N=&QI9R!24T$M;OAG;&4@*"5D(&)I="D`
M16YK96QT=FES('9A;&<`4F5G;@!296=N('1I9&QI9W0`4F5G;B!S96YT`%)E
M9VYB>6=E<@!296=N(&]G('-N90!3;'5D`%1I;&;F;&1I9W0@97!I9W)A;0!&
M;W)H;VQD`$SF<P!,YG,@8F5S:V5D97(`5FER:V5L:6<@<VQE='1E("5S/R!$
M96YN92!O<&5R871I;VX@:V%N(&EK:V4@8FQI=F4@;VUG:F]R="X`5FER:V5L
M:6<@<VQE='1E(&1A=&$@9F]R(&)R=6=E<B`E<S\@1&5N;F4@;W!E<F%T:6]N
M(&MA;B!I:VME(&)L:79E(&]M9VIO<G0N`$]M9_AR(&1I;B!S:61S=&4@:&%N
M9&QI;F<`3W!D871E<@!/<&9R:7-K(&1Y;F%M:7-K92!M96YU+65L96UE;G1E
M<CH`1V5N;W!F<FES:R!P;W)T86QV:7-N:6YG.@!296=U;.9R="!U9'1R>6L`
M4F5L871I;VYS;.9S97(`1V5N;W!F<FES:P!.;W1E<@!&:F5R;F4@<V5R=F5R
M90!&:F5R;B!54DP@*&AT='`Z+R]W=W<N96MS96UP96PN9&LO:&]R9&4I.@!3
M;&5T`%-L970@8FQO:P!&:F5R;B!K;VQO;FYE`%-L970@9F]R;6%T97)I;F<`
M4VQE="!P87(`1FIE<FX@;&%G<F5T('-K<FEP="!F<F$@<V5R=F5R<R!M:61L
M97)T:61I9V4@:V%T86QO9RX`1FIE<FX`1FIE<FX@9&5T=&4@<'5N:W0@9G)A
M(&1O:W5M96YT970`4VQE="!B<G5G97(`4VQE="!B<G5G97(Z("5S`$%N;6]D
M;FEN9R!K=6YN92!I:VME(&)E<W9A<F5S+B!2971U<FYE<F5T(&9E:FQK;V1E
M.B``06YM;V1E="!T:F5N97-T92!K=6YN92!I:VME(&9I;F1E<RX`2W+F=F5D
M92`G)7,G(&5R(&EK:V4@86YG:79E="!I("5S+6MO;F9I9W5R871I;VXN`$MR
MYG9E="`B)7,B(&5R(&EK:V4@86YG:79E="!I(%9&4R!K;VYF:6=U<F%T:6]N
M+@!+<N9V961E("(E<R(@97(@:6MK92!A;F=I=F5T(&D@:V]N9FEG=7)A=&EO
M;F5N+@!+<N9V970@9F5L=`!.=6QS=&EL`$YU;'-T:6P@:V]D96]R9`!.=6QS
M=&EL(&1I="!K;V1E;W)D`$=E;G-K86(@<VED<W1E(&9O<F5S</AR9W-E;`!2
M97-U;'1A=&5R`%1I;&)A9V4@=&EL(&EN9'-T:6QL:6YG97)N90!'96YT87-T
M(&YY="!K;V1E;W)D`%)E=6YI;VX`1V5N9&%N(&MO;F9I9W5R871I;VX`26YD
M<W1I;&QI;F=E<B!F;W(@4FEC:"!497AT+7)E9&EG97)I;F<`1^5D97(`2/AJ
M<F4`2/AJ<F4@=&]P=&5K<W0`2/AJ<F4@=N9R9&EE<@!2YFMK92UE9V5N<VMA
M8F5R+BXN`%)E9V5L`%)U;>9N:65N`%)O=.ER(#$X,`!2;W3I<B!V96YS=')E
M`%)O=.ER(&CX:G)E`%+F:VME+65G96YS:V%B97(`4N9K:V4M96=E;G-K86)E
M<@!2YFMK97(Z`%-T<F5G97(`4W1R96=E<B!V:6P@;W!T<N9D92!M96QL96T@
M<N9K:V5R(&]G(&MO;&]N;F5R`%-T<F5G97(@=FEL(&MU;B!O<'1RYF1E(&UE
M;&QE;2!K;VQO;FYE<@!3=')E9V5R('9I;"!K=6X@;W!T<N9D92!M96QL96T@
M<N9K:V5R`%5D9OAR`%)U<VQA;F0`4G=A;F1A`$MR>7!T;V=R869I<VL@4R]-
M24U%+7-I9VYA='5R`%,O34E-12US:6=N97)E="!B97-K960`4T%33"WF9W1N
M:6YG(&5R(&EK:V4@=&EL9^9N9V5L:6<N`%--4P!344PM9F]R=&]L:V5R`%-1
M3"UU9'1R>6L@9F]R(&]P<VQA9R!A9B!VYG)D:65R`%-32`!354-#15,`4U%,
M+69O<G1O;&ME<@!,^'(`4VMT+B!(96QE;F$`4VMT+B!+:71T<R!O9R!.979I
M<P!3:W0N($QU8VEA`%-K="X@4&EE<G)E(&]G($UI<75E;&]N`%-K="X@5FEN
M8V5N="!O9R!'<F5N861I;F5R;F4`4V%M;64@<F%M;64@*%]S96QF*0!386UO
M80!386X@36%R:6YO`%-O82!4;VUE(&]G(%!R:6YC:7!E`%-A=&5L:71U9&)Y
M9&5R`%-A=61I87)A8FEE;@!'96T`1V5M("(E<R(`1V5M("(E<R(`1V5M;64@
M26YD<W1I;&QI;F=E<@!'96T@9V5N97)E<F5T(&MO;F9I9W5R871I;VX@<V]M
M(%!(4"US:W)I<'0@:2!D:6X@<V5R=F5R<R!M:61L97)T:61I9V4@:V%T86QO
M9RX`1V5M="`E<RUK;VYF:6=U<F%T:6]N+@!'96UT92!S:W)I<'0@9F]R(&]P
M9W)A9&5R:6YG(&%F(&]P<^9T;FEN9R!T:6PZ("(E<R(N`%-P<F5D="!T;W)D
M96X`5FED96YS:V%B`%/X9P!3^&=E;6%S:VEN97(`5N9L9R!F:6QE<@!6YFQG
M(&5N(&1A=&\`5N9L9R!E;B!G<G5P<&4@870@=&EL9OAJ90!6YFQG(&5N(&YY
M(&5J97(`5N9L9R!E;B!S97)V97(`5N9L9R!E;B!B<G5G97(@870@=&EL9OAJ
M90!6YFQG(&%L;&4`5N9L9R!A;&QE(&1A=&\M:V]M<&]N96YT97(N`%;F;&<@
M970@;V)J96MT`%;F;&<@:6YG96X`5N9L9R!D92!T96=N(&1U(&AA<B!B<G5G
M(&9O<B!F<F$@:V%S<V5R;F4@;F5D96YF;W(N($1E(&MA;B!SY2!K;&EP<&5S
M(&]G(&MO<&EE<F5S(&9R82!T97AT9F5L=&5T+@!6YFQG(&1A=&\M861S:VEL
M;&5R96XZ`%;F;&<@9&%T;V9O<FUA=#H`5N9L9R!D96X@:61E;G1I=&5T+"!S
M;VT@9'4@=FEL(.9N9')E.@!6YFQG('1I9',M861S:VEL;&5R96XZ`%;F;&<@
M=&ED<V9O<FUA=#H`5N9L9R!T;R!F96QT97(L(&1E<B!S=F%R97(@=&EL(&AI
M;F%N9&5N+@!6YFQG(&1I;B!F87)V97-A;6UE;G/F=&YI;F<N`%;F;&<@9&ET
M(&9O<F5T<G5K;F4@<W!R;V<Z`%-E;F0@<')O8FQE;6)E<VMR:79E;'-E`%-E
M;F0@4TU3`%-E;F5G86P`1OAL97(Z(`!397!T96UB97(`4V5R8FEE;B!O9R!-
M;VYT96YE9W)O`%-E<FEE;G5M;65R`%-E<G9E<BUD871A(&9O<FME<G0@96QL
M97(@:6MK92!T:6QGYFYG96QI9RX`4V5S<VEO;G-A9&UI;FES=')A=&]R`%-E
M<W-I;VXM240@=61L^&)E="X`4V5S<VEO;F5R`$WF;F=D90!);F1S=&EL;&EN
M9V5R(&1E<B!T:6QL861E<B!D:6<@870@;G5L<W1I;&QE(&1I="!K;V1E;W)D
M+"!H=FES(&1U(&YO9V5N<VEN9&4@<VMU;&QE(&=L96UM92!D970N`$EN9'-T
M:6P@9FIE<FYE('-E<G9E<F4L('-O;2!D=2#X;G-K97(@870@=&EL9^4@9G)A
M(&1I;B!P;W)T86PN`$EN9'-T:6P@9&EN(&9O<F5T<G5K;F4@<W!R;V<M+"!T
M:61S>F]N92T@;V<@9&%T;W9A;&<N`$EN9'-T:6P@9&EN92!O<'-T87)T<V%P
M<&QI:V%T:6]N97(L(&9A<G9E<V%M;65N<^9T;FEN9RP@<VED96]P9G)I<VMN
M:6X@;V<@86YD<F4@=FES;FEN9W-T:6QV86QG+@!);F1S=&EL;&EN9P!3:W)I
M<'1S('1I;"!O<&=R861E<FEN9R!A9B!O<'/F=&YI;F<@=&EL9^9N9V5L:6=E
M`$9L97)E('-T961E<B!M=6QI9R!M960@<&%R86UE=&5R96XZ(`!397EC:&5L
M;&5R;F4`4VAO<'!I;F<`2V]R="!O<'-U;6UE<FEN9P!3:V%L(&AU<G1I9RUT
M87-T97(@9&5F:6YE<F5S(&9O<B!D92!F;&5S=&4@:&5N=FES;FEN9V5R/R`H
M]RD`5FES`%9I<R!F;W)S:V5L;&5N92!M96QL96T@9&5N(&=E;71E(&]G(&1E
M;B!N>6QI9W0@9V5N97)E<F5D92!K;VYF:6=U<F%T:6]N+@!6:7,@=&ED<W!U
M;FMT(&9O<B!S96YE<W1E('1I;&=A;F<@=F5D('#E;&]G;FEN9S\`5FES(&UU
M;&EG:&5D(&9O<B!A="!B96AO;&1E(&]P<FEN9&5L:6<`5FES('-N=7!P97(`
M5FES(%1A8F5L;W!E<F%T:6]N97(M:VYA<'!E;B!I(&UE;G5E;C\`5FES("5S
M+6UE;G5E;B!T:6P@=F5N<W1R93\`5FES(&1I86QO9W9I;F1U92!M960@96=E
M;G-K86)E<B!F;W(@=&%B96QC96QL96X`5FES(&1I86QO9W9I;F1U92!M960@
M96=E;G-K86)E<B!F;W(@=&%B96QL96X`5FES(&1I86QO9W9I;F1U92!M960@
M96=E;G-K86)E<B!F;W(@=&%B96QRYFMK96X`5FES(&1I86QO9W9I;F1U92!M
M960@96=E;G-K86)E<B!F;W(@8FEL;&5D970`5FES(&%F<V5N9'1E`$)Y9V5R
M`$)Y9V5R('1I9&QI9W0`0GEG97(@<V5N=`!">6=E<B!I(&[F<FAE9&5N`%-K
M<G5M<`!3:W)U;7`@96QL97(@9FQY="!N86)O8FQO:VME(&%F('9E:F5N(&;X
M<G-T`%-I97)R82!,96]N90!3:W)I=B!I;F0`56YD97)S:W)I9G0`4VEG;F%T
M=7)A;&=O<FET;64`4VEN9V%P;W)E`%-T^')R96QS90!3<')I;F<@=F5D;&EG
M96AO;&1E;'-E(&]V97(`4VQO=F%K:65T`%-L;W9E;FEE;@!3;F4`4VYE8GEG
M90!3;F5B>6=E<@!3;F5B>6=E<B!T:61L:6=T`%-N96)Y9V5R('-E;G0`4VYE
M9'EB9&4Z(`!3;F7F:W9I=F%L96YT(&D@=F%N9#H@`%-A;&]M;V[X97)N90!3
M;VUA;&EA`%-A;F=E(&]G('!O97-I`%-O<G1E<FEN9W-V86QG`$%F<V5N9&5R
M861R97-S90!3>61A9G)I:V$`4WED975R;W#F:7-K("A)4T\M.#@U.2TS*0!3
M>60@1V5O<F=I82!O9R!$92!S>61L:6=E(%-A;F1W:6-H^&5R`%-Y9&QI9V4@
M:&%L=FMU9VQE`$QU9G0@;65L;&5M(&YA8F]C96QL97(`3'5F="!M96QL96T@
M:6YD:&]L9"!O9R!R86UM92!I(&-E;&QE`$UE;&QE;7)U;7-T86YG970`365L
M;&5M<G5M`$QU9G0@;V<@9F]R<FEN9P!3<&%N:65N`%-K:61T<&]S=`!);F1T
M87-T;FEN9R!F;W(@<W!E8VEA;&MA<F%K=&5R`$1E;"!C96QL90!$96P@:V]L
M;VYN90!$96P@<N9K:V4`4W!O<G0`4W)I($QA;FMA`%-T86YD87)D`%-T87(@
M5')E:P!"96=Y;F1E;'-E<^5R`$1E;'-T870@96QL97(@<')O=FEN<P!3=&%T
M=7,`3&%G<FEN9W-F;W)M870`5F5J`$=E;FYE;7-T<F5G;FEN9P!,:7-T92!A
M9B!S=')E;F=E`$9J97)N(&1O;>9N92!F<F$@861R97-S96X`4W1I;"!;0U-3
M70!3^&X`56YD97)K871A;&]G("(E<R(@:6MK92!F=6YD970N`$5M;F4`1V]D
M:V5N9`!!;FUO9&YI;F<@;VT@870@=&EL9OAJ92`B)7,B('1I;"!S>7-T96T@
M869S96YD="X@($1U(&MA;B!I:VME(&QO9V=E('#E(&;X<B!D:6X@86YM;V1N
M:6YG(&5R(&)L979E="!A;F5R:V5N9'0N`$QA=B!S:W)I9G0`561F^')T`"(E
M<R(@8FQE=B!T:6QF^&IE="!T:6P@<WES=&5M970N`$1A=&$@9F]R(&)R=6=E
M<B`B)7,B(&)L978@<VQE='1E="!F<F$@<WES=&5M970N`"(E<R(@<VQE='1E
M="X`(B5S(B!S;&5T=&5T(&9R82!S>7-T96UE="X`2V]N9FEG=7)A=&EO;B!T
M:6QB86=E9OAR="X@1V5N:6YD;.9S(&9O<B!A="!S92#F;F1R:6YG97)N92X`
M4F5S97)V96MO;F9I9W5R871I;VX@9V5M="X`4F5S97)V96MO;F9I9W5R871I
M;VYF:6P@)7,@9V5M="X`(B5S(B!O<&1A=&5R970N`"(E<R(@<VMR979E="X`
M4W5D86X`26YD:&]L9`!3;VQO<&=A;F<`4V]L;F5D9V%N9P!3;VQR:6=T`%-O
M;&]P9V%N9P!3;VQO<&=A;F<O<V]L;F5D9V%N9P!3;VQO<&=A;F<Z(`!3;VQN
M961G86YG`%-O;&YE9&=A;F<Z(`!(YG9E="!S:W)I9G0`2&KF;'``4W5R:6YA
M;0!%9G1E<FYA=FX`4W9A;&)A<F0@;V<@2F%N($UA>65N`%-W87II;&%N9`!3
M=F5R:6=E`%-C:'=E:7H`4WEN8R!L;V<@<VQE='1E=`!3>6YC34P`4WEN=&%K
M<V9E:FP@:2!S^&=E;&5D`%-Y<FEE;@!4;W)D96X`5&]R9&5N(&]G('9I;F0`
M5&]R9&5N`%1O<F1E;B!T:61L:6=T`%135BUF:6P`5&%B96P`5&%B96PM96=E
M;G-K86)E<@!486)E;&WF;F=D90!486)E;"UE9V5N<VMA8F5R`%1A:7=A;@!4
M86EW86XL($1E;B!K:6YE<VES:V4@<')O=FEN<P!4861J:6MI<W1A;@!486YZ
M86YI80!-Y6PZ`$]P9V%V97(`5&5L969O;FYU;6UE<@!496UP+B!S:61S=&4@
M=&EM93H@`%1E;7!E<F%T=7(`5&5M<&5R871U<CH@`%1E;7!E<F%T=7(\8G(@
M+SXH)7-(^&HE<R\E<TQA=B5S*2`F9&5G.R5S`%-K86)E;&]N("(E<R(@:6MK
M92!F=6YD970N`%-K86)E;&]N+6%D;6EN:7-T<F%T:6]N`%1E:W-T`%)E;B!T
M96MS=`!496MS="UJ=7-T97)I;F<`5&5K<W0M=&]P`%1O<@!4:&%I("A425,M
M-C(P*0!4:&%I;&%N9`!&5%`M=61V:61D96QS96X@97(@:6MK92!T:6QGYFYG
M96QI9RX`2&ES=&]R:6LM<WES=&5M970@97(@<VSE970@9G)A+@!(;W)D92]+
M;VQA8BUI;G1E9W)A=&EO;G-M;W1O<F5N('5N9&5R<W3X='1E<B!I:VME("(E
M<R(`24U34"UL;V=G96X@:W5N;F4@:6MK92!K;&%R9_AR97,N`$UA:6YT96YA
M;F-E.CHM:VQA<W-E;B!B;&5V(&EK:V4@:6YD;.9S=`!4:6QV86QG<W9I;F1U
M970@97(@8FQE=F5T(&QU:VME="X@069S;'5T=&5R+@!!9&UI;FES=')A=&]R
M96X@8FQI=F5R(&[X9'0@=&EL(&%T(&MO;F9I9W5R97)E(&5N('!E<FUA;F5N
M="!4:6QL861E;'-E<RUB86-K96YD+"!H=FES(&1U('9I;"!A;G9E;F1E(%1I
M;&QA9&5L<V5R+@!+=6X@=6YD97)S:61E;@!+;VYT86MT+4E$+6YU;6UE<F5T
M(&)L978@:6MK92!A;F=I=F5T+"!E9G1E<FQA9'0@=&]M="!E;&QE<B!B;&5V
M(&EK:V4@9G5N9&5T(&D@9&%T86)A<V5N+@!+;VYT86MT96X@8FQE=B!T:6QF
M^&IE="!T:6P@9&ET(&%D<F5S<V5K87)T;W1E:V5T+@!$96X@;/AS9VIO<G1E
M(%!'4"US:6=N871U<BUB;&]K(&5R(&MRYG9E="!F;W(@870@:W5N;F4@=F5R
M:69I8V5R92!D96X@<VEG;F5R961E(&)E<VME9"X`1&ES=')I8G5T:6]N<VQI
M<W1E+4E$(&5R(&5N=&5N(&EK:V4@86YG:79E="P@=&]M="!E;&QE<B!I:VME
M(&9U;F1E="!I(&1A=&%B87-E;BX`1&ES=')I8G5T:6]N<VQI<W1E;B!I:VME
M(&%N9VEV970N`$MR>7!T97)I;F=S9F%C:6QI=&5T97)N92!K<N9V97(@96X@
M<VEK:V5R('=E8BUF;W)B:6YD96QS92X`1FEL96X@)7,@8OAR(&EN9&5H;VQD
M92!E;B`E<RUI;F1S=&EL;&EN9RX`1FEL96X@)7,@8OAR(&EN9&5H;VQD92!N
M;V=L92`E<RUI;F1S=&EL;&EN9V5R+@!&:6QE;B!K86X@:6MK92!K;W!I97)E
M<R!O=F5N<.4@<VEG<V5L=BX`1FEL96X@:6YD96AO;&1T(&EN9V5N(&1A=&$N
M`$;X;&=E;F1E(&5R(&AO=F5D97)N92!F<F$@9&5N;F4@;65S<V%G92]R9F,X
M,C(M8F5S:V5D+@!&=6QD<VOF<FUS=&EL<W1A;F0@=FED97,@870@=F]L9&4@
M<')O8FQE;65R(&D@26YT97)N970@17AP;&]R97(@9W)U;F1E="!B<F]W<V5R
M+69E:FPL('-O;2!V:2!I:VME(&AA<B!K=6YN970@;VUGY2X@1'4@=FEL(&UU
M;&EG=FES(&]P;&5V92!F;W)V86YS:V5D92!V:7-N:6YG97(L(&UA;F=E;"!P
MY2!E9&ET97)I;F=S9G5N:W1I;VYE<B!O9R]E;&QE<B!T:6QFYFQD:6=E(&)R
M;W=S97(M;F5D8G)U9"X@2'9I<R!D:70@<WES=&5M(&5R(%=I;F1O=W,F;F)S
M<#LY>"!V:6P@9'4@;65D(&CX:B!S86YD<WEN;&EG:&5D(&]P;&5V92`G1V5N
M97)E;"!B97-K>71T96QS97-F96IL)R!O9R!V:6P@8FQI=F4@;OAD="!T:6P@
M870@9V5N<W1A<G1E(&UA<VMI;F5N+EQN7&Y$=2!E<B!N=2!A9'9A<F5T+B`@
M5')Y:R!/2R!H=FES(&1U('-T861I9R#X;G-K97(@870@<'+X=F5T(&9U;&1S
M:^9R;7-R961I9V5R:6YG+@!)9&5N=&ET971E;B`B)7,B(&5R('-L971T970N
M`$MU;B!V96YS=')E('-I9&4N`%!L86-E<FEN9V5N(&%F($=N=5!'+7!R;V=R
M86UM970@<VMA;"!G:79E<R!T:6P@0W)Y<'1?<&=P.CHM:VQA<W-E;BX`0F5S
M:V5D96XL('-O;2!E<B!S96YD="!D96X@)7,@=&EL("5S(&UE9"!E;6YE="`B
M)7,B(&5R(&)L979E="!V:7-T+@I$971T92!E<B!I;F=E;B!G87)A;G1I(&9O
M<BP@870@8F5S:V5D96X@<F5N="!F86MT:7-K(&5R(&)L979E="!LYG-T(&5L
M;&5R(&9O<G-TY65T+@!.879N970L(&1E<B!S:V%L(&)R=6=E+"!NY7(@9&5R
M(&AE;G9I<V5S('1I;"!S:W)I=F5S:61E;@!!;G1A;&QE="!A9B!F96QT97(@
M<VMA;"!VYG)E(&5T('1A;"X`;W!E;G-S;"UM;V1U;&5T(&5R(&MRYG9E="!A
M9B!(;W)D95]#<GEP=%]S;6EM93HZ+6ML87-S96XN`%!RYF9E<F5N8V5N("(E
M<R(@:W5N;F4@:6MK92!G96UM97,@9F]R9&D@9&5N<R!D871A(&]V97)S:W)I
M9&5R(&1E;B!M86MS:6UA;'0@=&EL;&%D=&4@<W3X<G)E;'-E`%!R;V=R86UM
M970L(&1E<B!B<G5G97,@=&EL(&%T(&)E=')A9W1E(&1E;FYE(&1A=&%T>7!E
M("@E<RDL(&)L979E="!I:VME(&9U;F1E="!PY2!S>7-T96UE="X`0VET871I
M;VYS=&5G;F5T('-K86P@=N9R92!E="!E;FME;'0@=&5G;BX`2W5N(&CX:G)E
M(&]G('9E;G-T<F4@<VED90!+=6X@<VED96X@=&EL(&CX:G)E`$%D<VMI;&QE
M;'-E<W1E9VYE="!S:V%L(';F<F4@970@96YK96QT('1E9VXN`%-E<G9E<F5N
M("(E<R(@97(@<VQE='1E="X`4V5R=F5R96X@(B5S(B!E<B!G96UT+@!/<'-K
M<FEV;FEN9W-A;FUO9&YI;F=E;B!F;W(@)7,@97(@<VQE='1E="X`1&5N(&%N
M9VEV;F4@<N9K:V4@*"5D*2!E:W-I<W1E<F5R(&EK:V4N`$1E;B!A;F=I=FYE
M('+F:VME(&5K<VES=&5R97(@:6MK92X`1&5N(&UI9&QE<G1I9&EG92!F:6P@
M(B5S(B!F:6YD97,@:6MK92X`1&5N('1E:W-T+"!S;VT@9'4@:6YD=&%S=&5D
M92P@<&%S<V5R(&EK:V4@=&EL('1E:W-T96X@<.4@<VOF<FUE;BX`2W5N('1O
M<"!O9R!B=6YD`$MU;B!T;W``1&5N(&%F<V5N9'1E(&EN9F]R;6%T:6]N(&5R
M('1A8G0@<VED96X@<VED<W1E('1R:6XN`$1E;B!O=F5R9OAR=&4@9FEL(&MU
M;FYE(&EK:V4@9V5M;65S+@!W96%T:&5R+F-O;2UB;&]K:V5N(&5R(&EK:V4@
M=&EL9^9N9V5L:6<N`%1E;6$M:V%T86QO9V5T("(E<R(@:6MK92!F=6YD970N
M`$EN9V5N('1I;'9A;&<@=&EL('+E9&EG:&5D+@!$97(@9F]R969I;F1E<R!I
M;F=E;B!D96QE+"!S;VT@:V%N('9I<V5S(&EN9&QE:G)E="X`1&5R(&5R(&9O
M<B!M86YG92!T96=N(&D@9&5T=&4@9F5L="X@1'4@:&%R(&EN9'1A<W1E="`E
M<R!T96=N.R!D=2!S:V%L(&EN9'1A<W1E(&UI;F1R92!E;F0@)7,N`$1E<B!O
M<'-T;V0@970@<')O8FQE;2!U;F1E<B!T:6QF^&IE;'-E;B!A9B`G)7,G('1I
M;"!S>7-T96UE=#H@)7,`1&5R(&]P<W1O9"!E="!P<F]B;&5M('5N9&5R(&9J
M97)N96QS92!A9B!D871A(&9O<B!B<G5G97(@(B5S(B!F<F$@<WES=&5M970Z
M(`!$97(@;W!S=&]D(&5T('!R;V)L96T@=6YD97(@<VQE=&YI;F<@868@(B5S
M(B!F<F$@<WES=&5M970Z(`!$97(@;W!S=&]D(&5T('!R;V)L96T@=6YD97(@
M;W!D871E<FEN9R!A9B`B)7,B.B`E<P!$97(@;W!S=&]D(&5T('!R;V)L96T@
M=6YD97(@9FEL;W9E<F;X<G-L96XZ($EN9V5N("5S(&)L978@;W9E<F;X<G0N
M`$1E<B!O<'-T;V0@970@<')O8FQE;2!U;F1E<B!F:6QO=F5R9OAR<VQE;CH@
M)7,@=F%R('-T^')R92!E;F0@9&5N(&UA:W-I;6%L="!T:6QL861T92!S=/AR
M<F5L<V4@*"5D(&)Y=&5S*2X`1&5R(&]P<W1O9"!E="!P<F]B;&5M('5N9&5R
M(&9I;&]V97)F^')S;&5N.B`E<R!B;&5V(&MU;B!D96QV:7-T(&]V97)F^')T
M+@!$97(@;W!S=&]D(&5N(&9E:FP@=6YD97(@=FES;FEN9R!A9B!D96YN92!B
M97-K961D96P`1&5R(&]P<W1O9"!E;B!F96IL('5N9&5R(&EM<&]R=&5R:6YG
M96X@868@:V]N=&%K=&EN9F]R;6%T:6]N+@!$97(@;W!S=&]D(&5N(&9E:FP@
M=6YD97(@:6UP;W)T97)I;F=E;B!A9B!I0V%L96YD87(@9&%T82X`1&5R(&]P
M<W1O9"!E;B!F96IL(&D@:V]N9FEG=7)A=&EO;G-F;W)M=6QA<F5N+B!.=6QI
M9W9I<R!H87(@9'4@=61E;&%D="!E="!K<N9V970@9F5L="X`1&5R(&]P<W1O
M9"!E="!P<F]B;&5M('5N9&5R('5D9OAR96QS92!A9B!D96X@86YG:79N92!A
M9')E<W-E:V%R=&]T96MS9G5N:W1I;VXN(%!R^'8@:6=E;BX`1&5R(&]P<W1O
M9"!E;B!F96IL('5N9&5R(&]P9&%T97)I;F<@868@:V]N=&%K="UD971A;&IE
M<FYE+B!0<OAV(&EG96XN`$1E<B!O<'-T;V0@96X@9F5J;"!U;F1E<B!O<&1A
M=&5R:6YG(&%F(&1I<W1R:6)U=&EO;G-L:7-T96XN(%!R^'8@:6=E;BX`1&5N
M;F4@24U!4"US97)V97(@=6YD97)S=/AT=&5R(&EK:V4@9&5L:6YG(&%F(&UA
M<'!E<BX`1&5T=&4@='ED97(@:6MK92!PY2!A="!VYG)E(&5T(&=Y;&1I9W0@
M<F%R+6%R:VEV+@!$96YN92!T>61E<B!I:VME('#E(&%T(';F<F4@96X@9WEL
M9&EG('II<"UF:6PN`$1E='1E('1Y9&5R(&EK:V4@<.4@870@=N9R92!E="!G
M>6QD:6=T(&MO<G1N=6UM97(N`$1E;FYE(&1R:79E<B!T:6QL861E<B!A9G-E
M;F1E;'-E(&%F(&)E<VME9&5R(&EG96YN96T@0VQI8VMA=&5L;"`H:'1T<#HO
M+V-L:6-K871E;&PN8V]M*2!A9&=A;F=S<'5N:W1E="!V960@8G)U9R!A9B!(
M5%10($%020!$96YN92!D<FEV97(@=&EL;&%D97(@869S96YD96QS92!A9B!B
M97-K961E<B!I9V5N;F5M(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&%D9V%N
M9W-P=6YK=&5T('9E9"!B<G5G(&%F($A45%`@05!)`$1E;FYE(&1R:79E<B!T
M:6QL861E<B!A9G-E;F1E;'-E(&%F(&)E<VME9&5R(&EG96YN96T@<VUS,F5M
M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@861G86YG<W!U;FMT970@=F5D
M(&)R=6<@868@2%144"!!4$D`1&5N;F4@9')I=F5R('1I;&QA9&5R(&%F<V5N
M9&5L<V4@868@8F5S:V5D97(@=FEA(%--5%`@:6=E;FYE;2!6;V1A9F]N92!)
M=&%L:65N(&%D9V%N9W-P=6YK=&5T+"!D;V<@:W5N('1I;"!6;V1A9F]N92UN
M=6UR92X@1&5N(&MRYG9E<B!E;B!E+6UA:6QK;VYT;R!H;W,@5F]D869O;F4@
M271A;&EE;B`H:'1T<#HO+W=W=RXQ.3`N:70I+@!$971T92!F96QT(&5R(&MR
MYG9E="X`1&5T=&4@9F5L="!MY2!K=6X@:6YD96AO;&1E(&AE;'1A;"X`1&5T
M=&4@9F5L="!MY2!K=6X@:6YD96AO;&1E(&YU;7)E(&]G(&MO;&]N+@!$971T
M92!F96QT(&WE(&MU;B!I;F1E:&]L9&4@;VMT86QE(';F<F1I97(N`$1E='1E
M(&9E;'0@<VMA;"!VYG)E(&5N(&MO;6UA+2!E;&QE<B!M96QL96UR=6US861S
M:VEL9'0@;&ES=&4@868@:&5L=&%L`$1E='1E(&9E;'0@<VMA;"!VYG)E(&5T
M(&=Y;&1I9W0@;G5M;65R+@!$971T92!F96QT('-K86P@:6YD96AO;&1E(&5N
M(&9A<G9E:V]D92!I(%)'0B!H97@M9F]R;6%T+"!F>"`G(S$R,S1A9B<N`$1E
M;FYE(&9O<FUU;&%R(&5R(&%L;&5R961E('!R;V-E<W-E<F5T+@!$971T92!E
M<B`E<RX`1&5T=&4@97(@970@2V]L86(@1W)O=7!W87)E+6]B:F5K="X@1F]R
M(&%T('-E(&1E='1E(&]B:F5K="!H87(@9'4@8G)U9R!F;W(@96X@92UM86EL
M+6ML:65N="P@<V]M(&9O<G-TY7(@2V]L86(@1W)O=7!W87)E+69O<FUA=&5T
M+B!"97/X9R`E<R!F;W(@96X@;&ES=&4@868@:VQI96YT97(N`$1E;FYE(&)E
M<VME9"!E<B!S:W)E=F5T(&UE9"!E="!A;F1E="!T96=N<^9T("@E<RD@96YD
M(&1I="!E9V5T+@!486QL970@<VMA;"!VYG)E(&UI;BX@,2X`1&5N;F4@<V5R
M=F5R(&MA;B!I:VME(&1E:V]M<')I;65R92!Z:7`M(&]G(&=Z:7`M9FEL97(N
M`$1E='1E('-Y<W1E;2!E<B!D96%K=&EV97)E="X`1&5N;F4@=N9R9&D@<VMA
M;"!VYG)E(&5T('1A;"X`1&5T=&4@=FEN9'5E('-K86P@:V%L9&5S(&9R82!E
M="!4:6QV86QG<W9I;F1U90!4;W)D96X`4V%G97(`5&ED`%1I9'-O<&?X<F5L
M<V4`5&ED<V9O<FUA=`!4:61S=F%L9P!4:6UO<BU,97-T90!4:71E;`!4:71L
M92`H=&]O;'1I<"DZ`%1I;`!&;W(@870@=N9L9V4@;75L=&EP;&4@:6YD9V%N
M9V4@<VMA;"!#=')L+2`H4$,I(&5L;&5R($-O;6UA;F0@*$UA8RDM=&%S=&5N
M(&AO;&1E<R!N961E(&UE9&5N<R!D97(@:VQI:VME<RX`22!$86<`4VMI9G0@
M2%1-3"UK:6QD90!4;V=O`%1O:V5L874`22!M;W)G96X`5&]N9V$`1F]R(&UA
M;F=E('5G>6QD:6=E(&QO9VEN9"UF;W)S^&<@:2!L^&)E="!A9B!D92!S:61S
M=&4@;6EN=71T97(N`%1O<`!4;W`@9G)A;64@*%]T;W`I`$]V97)SYG1T96QS
M97(`5')I;FED860@;V<@5&]B86=O`%-A;F0@96QL97(@9F%L<VL`5&ER`%1U
M;F5S:65N`%1Y<FMI970`5'ER:VES:R`H25-/+3@X-3DM.2D`5'5R:VUE;FES
M=&%N`%1U<FMS(&]G($-A:6-O<R#897)N90!4=79A;'4`4VMR:78@9&ET('9A
M;&<Z(`!5+E8N+6EN9&5K<SH@`%523`!54DP@9F]R('-K<FEP="!T:6P@;6]D
M=&%G96QS92!A9B!S=&%T=7,@<F%P<&]R=&5N`%523#H`56=A;F1A`%5K<F%I
M;F4`2W5N;F4@:6MK92!T:6QGY2!61E,M:V%T86QO9RX`2V%N(&EK:V4@=&EL
M9OAJ92!E:W-T<F$@8G)U9V5R(&EN9F]R;6%T:6]N('5N9&5R(&]P<VMR:79N
M:6YG+@!+86X@:6MK92#F;F1R92!T:6QL861E;'-E<B!F;W(@5D93+69I;"`B
M)7,B+@!+86X@:6MK92#F;F1R92!T:6QL861E;'-E<B!F;W(@5D93+69I;"`E
M<R\E<RX`2V%N(&EK:V4@<VMI9G1E('1I;"`E<RX`2V%N(&EK:V4@=&IE:VME
M(&9I;'-T^')R96QS96X@868@(B5S(BX`2V%N(&EK:V4@=&IE:VME(&9I;'-T
M^')R96QS96X@868@(B5S+R5S(BX`2W5N;F4@:6MK92!FY2!F;W)B:6YD96QS
M92!T:6P@4U%,('-E<G9E<F5N+@!+86X@:6MK92!FY2!F;W)B:6YD96QS92!M
M960@4U-,+@!+86X@:6MK92!K;W!I97)E(%9&4RUF:6PN`$MA;B!I:VME(&1A
M;FYE(%9&4RUK871A;&]G("(E<R(N`$MA;B!I:VME(&1A;FYE(%9&4RUK871A
M;&]G+@!+86X@:6MK92!L879E(%9&4RUF:6PN`$MA;B!I:VME(&]P<F5T=&4@
M5D93+6UA<'!E("(E<R(N`$MA;B!I:VME(&QA=F4@=&]M(%9&4RUF:6PN`$MA
M;B!I:VME(&1E:V]M<')I;65R92!D871A+@!+86X@:6MK92!S;&5T=&4@(B5S
M(CL@:V%T86QO9V5T(&5R(&EK:V4@=&]M="X`2V%N(&EK:V4@<VQE='1E("(E
M<R(Z("5S+@!+86X@:6MK92!S;&5T=&4@)7,[(&MA=&%L;V=E="!E<B!I:VME
M('1O;70`2V%N(&EK:V4@<VQE='1E(%9&4RUK871A;&]G970@<F5K=7)S:79T
M+@!+86X@:6MK92!S;&5T=&4@5D93+6MA=&%L;V<N`$MA;B!I:VME('-L971T
M92!61E,M:V%T86QO9SH@)7,N`$MA;B!I:VME('-L971T92!61E,M9FEL("(E
M<R(N`$MA;B!I:VME('-L971T92!61E,M9FEL+@!+86X@:6MK92!S;&5T=&4@
M5D93+6UA<'!E("(E<R(N`$MA;B!I:VME('-L971T92!61E,@<F5K=7)S:79T
M.B`E<RX`2V%N(&EK:V4@8F5S=&5M;64@86MT=65L="!K871A;&]G+@!+86X@
M:6MK92!U9&1R86=E(&-E<G1I9FEK870M9&5T86QJ97(`2V%N(&EK:V4@:6YD
M;.9S92!D969I;FET:6]N96X@868@)7,N`$MA;B!I:VME(&9L>71T92!61E,M
M9FEL+@!+86X@:6MK92#E8FYE(%9&4RUF:6P@(B5S(BX`2V%N(&EK:V4@Y6)N
M92!61E,M9FEL('1I;"!S:W)I=FYI;F<N`$MA;B!I:VME(.5B;F4@5D93+69I
M;"X`2V%N(&EK:V4@Y6)N92!K;VUP<FEM97)E="!A<FMI=BX`2V%N(&EK:V4@
M;.9S92!61E,M9FEL("AF:6QE<VEZ92@I(&9E:FQE9&4I+@!+86X@:6MK92!L
MYG-E(%9&4RUF:6P@*&=E=$9I;&53:7IE*"D@9F5J;&5D92DN`$MA;B!I:VME
M(&SF<V4@9FEL.B``2V%N(&EK:V4@;.9S92!V9G-R;V]T+6MA=&%L;V=E="X`
M2V%N(&EK:V4@;VUD^&)E("5S('1I;"`E<SH@;>5L;6%P<&5N(&9I;F1E<R!A
M;&QE<F5D90!+86X@:6MK92!O;63X8F4@5D93+6MA=&%L;V<N`$MA;B!I:VME
M(&]M9/AB92!61E,M:V%T86QO9SH@)7,N`$MA;B!I:VME(&]M9/AB92!61E,M
M9FEL("(E<R(N`$MA;B!I:VME(&]M9/AB92!61E,M9FEL("5S+R5S+@!+86X@
M:6MK92!O;63X8F4@5D93+69I;"X`2V%N(&EK:V4@869V:6ML92`G;6MI<V]F
M<R<N`$MU;FYE(&EK:V4@;W9E<G/F='1E(&1E='1E(%=O<F0@9&]K=6UE;G0`
M2V%N(&EK:V4@<VMR:79E(%9&4RUF:6P@(B5S(BX`2V%N(&EK:V4@<VMR:79E
M(%9&4RUF:6P@*&-O<'DH*2!F96IL961E*2X`2V%N(&EK:V4@<VMR:79E(%9&
M4RUF:6QD871A+@!+86X@:6MK92!S:W)I=F4@5D93+69I;#L@:W9O=&5N('9I
M;"!B;&EV92!O=F5R<VMR961E="X`56YD97)L:6YI97)E=`!&;W)T<GED(.9N
M9')I;F=E<@!/;6?X<B!D:6X@<VED<W1E(&AA;F1L:6YG`%5V96YT970@<F5A
M:W1I;VX@9G)A('-E<G9E<B!PY2!F;W)B:6YD96QS96XZ(`!5=F5N=&5T(')E
M86MT:6]N(&9R82!S97)V97(@<.4Z(`!):VME(&%N8G)A9W0`56YI8V]D92`H
M551&+3@I`$9O<F5N961E($%R86)I<VME($5M:7)A=&5R`%-T;W)B<FET=&%N
M:65N`%5300!54T%S('5N9&5R;W)D;F5D92#X97(`16YH961E<@!5:V5N9'0`
M56ME;F1T(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5K96YD="!C;&EM
M<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!5:V5N9'0@<W1E9"!A;F=I=F5T
M+@!5:V5N9'0@8G)U9V5R;F%V;B!E;&QE<B!K;V1E;W)D+@!(YF=T(&%K='5E
M;'0@96QE;65N="!A9BX`26MK92!N879N9VEV970`57!R:79I;&EG97)E9&4@
M<VMR:7!T97(@:V%N(&EK:V4@=&EL9^4@:VQI<'!E+VMO<&DO:6YD<^9T('!R
M;V=R86UMYG-S:6=T(&%F('-I:VME<FAE9'/E<G-A9V5R+B`@2VQI:R!/2R!F
M;W(@870@<V4@96X@=&5K;FES:R!N;W1E(&AO<R!M;WII;&QA+F]R9RP@<V]M
M('9I<V5R(&1I9RP@:'9O<F1A;B!D=2!K86X@=&EL;&%D92!E="!S:W)I<'0@
M870@=&EL9^4@=61K;&EP<VAO;&1E<F5N+@!&87)V92!I:VME(&EN9'-T:6QL
M970`561V:61D96QS92!I:VME('5N9&5R<W3X='1E=`!/<&1A=.ER`$]P9&%T
MZ7(@)7,`3W!D873I<B!B<G5G97(`(B5S(B!O<&1A=&5R970N`$]P9W)A9&5R
M:6YG<RUF;W)E<VMR:69T('-L971T970N`%5P;&]A9`!/<'/F=&YI;F=S9FEL
M97(@=&EL(&%L;&4@87!P;&EK871I;VYE<B!L86=T(&]P('#E('-E<G9E<BX`
M4W1O<F4@;&%T:6YS:V4@8F]G<W1A=F5R`%-T;W)E(')O;65R=&%L`%5R=6=U
M87D`06YV96YD(&YU=N9R96YD93H@)7,`0G)U9R!34TP`0G)U9R!H=FES(&YA
M=FXO:V]D96]R9"!E<B!F;W)S:V5L;&EG(&9O<B!)35-0+7-E<G9E<BX`0G)U
M9V5R`$)R=6=E<B`E<R!I:VME(&)E;7EN9&EG970@=&EL("5S+@!"<G5G97(M
M861M:6YI<W1R871I;VX`0G)U9V5R:6YD<W1I;&QI;F=E<@!"<G5G97(M<F5G
M:7-T<F5R:6YG`$)R=6=E<BUR96=I<W1R97)I;F<@97(@8FQE=F5T('-LY65T
M(&9R82!PY2!D971T92!W96)S=&5D+@!"<G5G97)K;VYT;R!I:VME(&9U;F1E
M=`!"<G5G97)N879N`$)R=6=E<FYA=FX@(B5S(B!F:6YD97,@86QL97)E9&4N
M`$)R=6=E<FYA=FXZ`$)R=6=E<FYA=FXZ(`!"<G5G97)E(&D@<WES=&5M970Z
M`%5S8F5K:7-T86X`5D93+6MA=&%L;V<@96MS:7-T97)E<B!I:VME+@!&97)I
M90!'>6QD:6=E(&9U;F1E="!S=&5D97(@:6YK;'5D97)E<CH`1WEL9&EG:&5D
M`%;F<F1I(&5R(&UI;G5T=&5R(&9R82!N=2X`5N9R9&D@97(@;65R92!E;F0@
M9&5N(&UA:W-I;6%L92!LYFYG9&4@868@)7,N`%;F<F1I97(`5N9R9&EE<BP@
M9&5R(&MA;B!VYFQG97,@:6)L86YD=`!686YU871U`%-K:69T96YD90!696YE
M>G5E;&$`169T97)P<OAV;FEN9R!F96IL961E("T@9&5R(&5R(&)L979E="!P
M:6QL970@=F5D(&1E;FYE(&)E<VME9"X`5F5R<VEO;@!697)S:6]N<VMO;G1R
M;VP`3&]D<F5T(&]P<W1I;&QI;F<`3&]D<F5T(&9O<G)I;F<`3&]D<F5T.@!-
M96=E="!H^&H`5FEE=&YA;0!6:65T;F%M97-I<VL@*%9)4T-)22D`5FES("5S
M`%-E('#E(&5K<W1E<FX@=V5B<VED90!6:7,@<V]M("5S`$IO;69R=?AE<BP@
M0G)I=&ES:V4`2F]M9G)U^&5R+"!!;65R:6MA;G-K90!3>6YL:6=H960`4WEN
M;&EG:&5D.B``5F]D869O;F4@271A;&EE;B!V:6$@4TU44`!705).`$%$5D%2
M4T5,(2$A($9*15).(%-#4DE05"!-04Y514Q4($9202`E<RX`5TE.('9I82!(
M5%10`%=A;&QI<R!O9R!&=71U;F$`061V87)S96P`3VYS`%9E:G)U9'-I9W0`
M5F5J<FEN9F]R;6%T:6]N('-T:6QL970@=&EL<N5D:6=H960@868`5V5A=&AE
M<BYC;VT`5V5B`%=E8G-I=&4`56=E;G1L:6<`5F5L:V]M;65N`%9E;&MO;6UE
M;B!T:6P@)7,`5F5L:V]M;65N+"`E<P!697-T;&EG("A)4T\M.#@U.2TQ*0!6
M97-T;&EG("A)4T\M.#@U.2TQ-2D`5F5S='-A:&%R80!(=FEL:V5N(&%P<&QI
M:V%T:6]N('-K86P@)7,@=FES92!E9G1E<B!L;V=I;F0_`$AV860@97(@<V5P
M87)A=&]R=&5G;F5T/P!(=F%D(&5R(&-I=&%T:6]N<W1E9VYE=#\`5VAE<F5I
M<R!!=7-T<F%L:65N+6MO<G0`2'9I;&ME(&9A<V5R`$AV:6QK92!P;'5G:6YS
M('-K86P@86MT:79E<F5S(&9O<B!2:6-H(%1E>'0M=N9R:W3X:F5T+@!"<F5D
M9&4`0G)E9&1E(&D@0U-3+65N:&5D97(`0G)E9&1E(&%F("5S+6UE;G5E;B!T
M:6P@=F5N<W1R92`H8FQI=F5R(&%K=&EV97)E="!V960@;N9S=&4@;&]G:6YD
M*3H`0G)E9&1E(&%F('1A8F5L;&5N`$)R961D92UE;FAE9`!"<F5D9&4Z`%=I
M:VD`5FEN9`!";.9S="!T:61L:6=T`%9I;F1H87-T:6=H960@:2!K;F]B`%9I
M;F0Z`%9I;F0Z(`!6:7-D;VT`V&YS:V5L:7-T90!!<F)E:F1E`$%D<F5S<V4@
M*&%R8F5J9&4I`%1E;&5F;VX@*&%R8F5J9&4I`$9O<FME<G0@86YT86P@9F5L
M=&5R(&D@;&EN:64@)60N($9O<G9E;G1E9&4@)60L(&9A;F1T("5D+@!&;W)K
M97)T(&%N=&%L(&9E;'1E<BX@1F]R=F5N=&5D92`E9"P@9F%N9'0@)60N`$9O
M<FME<G0@9F]R<VMY9&YI;F<@)60@=6YD97(@:6YD;.9S;FEN9R!A9B!E;B!6
M1E,M9FEL+@!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S
M($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV
M92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!U
M9'9I9&1E;'-E<@#%Q0#%Q<7%`%EA:&]O(2UK;W)T`,5R;&EG`%EE;65N`$IA
M`$IA+"!J96<@97(@96YI9P!$=2!B969I;F1E<B!D:6<@:2!414M35"!-3T15
M4RX@($)R=6<@6SP^72UK;F%P<&5N('1I;"!A="!S:VEF=&4@=&EL8F%G92!T
M:6P@5UE325=91RX`1'4@:&%R(&EK:V4@=&EL;&%D96QS92!T:6P@870@;W!R
M971T92!M97)E(&5N9"`E9"!B;&]K:V4N`$1U(&5R(&EK:V4@YF=T970N`$1U
M(&MA;B!I:VME(&AA=F4@)UPG+71E9VYE="!I(&1I="!F=6QD92!N879N+@!$
M=2!I;F1T87-T961E(&EK:V4@96X@9WEL9&EG(&4M<&]S="UA9')E<W-E+@!&
M;W(@870@:6UP;W)T97)E('-K86P@9'4@=&EL;W)D;F4@9F5L=&5R(&9R82!D
M96X@9FEL(&1U(&EM<&]R=&5R97(@=&EL(&1E('1I;'-V87)E;F1E(&9E;'1E
M<B!I("5S+@!$=2!E<B!B;&5V970@;&]G9V5T('5D+@!$=2!S:V%L(&EN9'1A
M<W1E(&5T(&9U;F=E<F5N9&4@;6]B:6QN=6UM97([(&MU;B!C:69R92!M960@
M970@=F%L9V9R:2`G*R<@9F]R(&1E;B!I;G1E<FYA=&EO;F%L(')E=&YI;F=S
M:V]D92X`1'4@<VMA;"!I;F1T87-T92!E;B!G>6QD:6<@=N9R9&DN`$1U('-K
M86P@:V]N9FEG=7)E<F4@96X@1&%T851R964M8F%C:V5N9"!F;W(@870@:W5N
M;F4@86YV96YD92!/<'-K<FEV;FEN9V5R+@!$=2!S:V%L(&MO;F9I9W5R97)E
M(&5N9"!61E,M8F%C:V5N9"X`1'4@8FQI=F5R(&[X9"!T:6P@870@;&%V92!E
M;B!P<F]B;&5M8F5S:W)I=F5L<V4L(&;X<B!D=2!K86X@<V5N9&4@9&5N(&EN
M9"X`1'4@<VMA;"!I;F1T87-T92!D96X@55),(&AV;W)T:6P@9&5N;F4@:.9G
M=&4@<VMA;"!H96YV:7-E`$1U('-K86P@=N9L9V4@9&5N('-E<G9E<BP@<V]M
M('-K86P@<VQE='1E<RX`1'4@<VMA;"!A;F=I=F4@8G)U9V5R;F%V;F5T+"!S
M;VT@9'4@=FEL(&9J97)N92X`1'4@<VMA;"!A;F=I=F4@8G)U9V5R;F%V;F5T
M+"!S;VT@9'4@=FEL(&9J97)N92X`1'4@<VMA;"!A;F=I=F4@8G)U9V5R;F%V
M;F5T+"!S;VT@9'4@=FEL('1I;&;X:F4N`$1U('-K86P@86YG:79E(&)R=6=E
M<FYA=FYE="P@<V]M(&1U('9I;"!O<&1A=&5R92X`1'4@<VMA;"!A;F=I=F4@
M9&5N(&AA;F1L:6YG+"!S;VT@<VMA;"!U9&;X<F5S+@!$=2!S:V%L(&%N9VEV
M92!E="!N>70@:V%T96=O<FEN879N+@!$=2!B;&EV97(@;OAD="!T:6P@870@
M86YG:79E(&5T(&ET86QI96YS:V4@=&5L969O;FYU;6UE<@!$:6X@)7,@<V5S
M<VEO;B!E<B!U9&SX8F5T+B!,;V<@=F5N;&EG<W0@:6YD(&EG96XN`$1I;B!E
M+7!O<W0M861R97-S90!$:6X@1G)O;3H@861R97-S93H`1&EN92!I;F9O<FUA
M=&EO;F5R`$1I;B!);G1E<FYE="UA9')E<W-E(&5R('-K:69T970@<VED96X@
M8F5G>6YD96QS96X@868@9&EN("5S+7-E<W-I;VXN($9O<B!A="!B97-K>71T
M92!D:6X@<VEK:V5R:&5D(&)L:79E<B!D=2!N^&1T('1I;"!A="!L;V=G92!I
M;F0@:6=E;BX`1&ET(&YA=FX`1&EN(.9G=&YI;F=S+6)A8VME;F0@=6YD97)S
M=/AT=&5R(&EK:V4@=&EL9OAJ96QS96X@868@8G)U9V5R92X@2'9I<R!D=2#X
M;G-K97(@870@8G)U9V4@2&]R9&4@=&EL(&%T(&%D;6EN:7-T<F5R92!B<G5G
M97)K;VYT:2P@8FQI=F5R(&1U(&[X9'0@=&EL(&%T(&)R=6=E(&5N(&%N9&5N
M(.9G=&YI;F=S+6)A8VME;F0N`$1I;B!A=71O<FES871I;VYS+6)A8VME;F0@
M=6YD97)S=/AT=&5R(&EK:V4@;W!L:7-T;FEN9V5N(&%F(&)R=6=E<F4@96QL
M97(@97(@9&5N(&9U;FMT:6]N(&%F(&5N(&5L;&5R(&%N9&5N(&=R=6YD(&)L
M979E="!S;.5E="!F<F$N`$1I;B!B<F]W<V5R('-Y;F5S(&%T(';F<F4@<VMI
M9G1E="!S:61E;B!B96=Y;F1E;'-E;B!A9B!D:6X@)7,M<V5S<VEO;BX@1F]R
M(&%T(&)E<VMY='1E(&1I;B!S:6MK97)H960L('-K86P@9'4@;&]G9V4@:6YD
M(&EG96XN`$1I;B!B<F]W<V5R('5N9&5R<W3X='1E<B!I:VME(&1E;FYE(&9U
M;FMT:6]N86QI=&5T+@!$:6X@8G)O=W-E<B!U;F1E<G-T^'1T97(@:6MK92!D
M96YN92!P<FEN="UM=6QI9VAE9"X@5')Y:R!#=')L+T-O;6UA;F0@*R!0(&9O
M<B!A="!P<FEN=&4N`$1I;B!A:W1U96QL92!T:61S>F]N93H`1&EN(&9O<G9A
M;&=T92!I9&5N=&ET970@97(@YFYD<F5T+@!$:6X@<W1A;F1A<F0M:61E;G1I
M=&5T.@!$:70@9G5L9&4@;F%V;CH`1&ET(&QO9VEN9"!E<B!U9&SX8F5T+@!$
M:70@;GEE(&MO9&5O<F0@9F]R("5S(&5R.B`E<P!$:6YE('1I;'9A;&<@97(@
M8FQE=F5T(&]P9&%T97)E="!F;W(@=F%R:6=H961E;B!A9B!D96YN92!S97-S
M:6]N+@!$:6YE('1I;'9A;&<@97(@;W!D871E<F5T+@!$:70@:V]D96]R9"!E
M<B!B;&5V970@;G5L<W1I;&QE=`!$:70@:V]D96]R9"!E<B!B;&5V970@;G5L
M<W1I;&QE.R!K;VYT<F]L;.ER(&1I;B!I;F1B86MK92!O9R!L;V<@:6YD(&UE
M9"!D:70@;GEE(&MO9&5O<F0N`$1I="!K;V1E;W)D(&5R('5D;/AB970N`$1I
M;F4@9FIE<FYE('-E<G9E<F4Z`$IU9V]S;&%V:65N`%IA[W)E`%IA;6)I80!:
M:6UB86)W90!::7!P>0!;4VMJ=6P@8VET97)E="!T96MS=%T`6U!R;V)L96UB
M97-K<FEV96QS95T`6U9I<R!C:71E<F5T('1E:W-T("T`6U9I<R!C:71E<F5T
M('1E:W-T("T@)7,@;&EN:65R70!;;&EN:64@)7,@=60@868@)7-=`$%D;6EN
M:7-T<F%T:6]N`$-,20!$871A5')E90!3;&5T('+F:VME`$=R=7!P97(`2&KF
M;'``0FEL;&5D+65G96YS:V%B97(N+BX`3&]G(&EN9`!,;V<@=60`QFYD<FEN
M9R!H96YV:7-N:6YG+BXN`$EN9'-T:6QL:6YG97(`5&EL;&%D96QS97(`4VQE
M="!H96YV:7-N:6YG+BXN`$]P<^9T;FEN9P!486)E;"UE9V5N<VMA8F5R+BXN
M`$)R=6=E<F4`861R97-S96MA<G1O=&5K`&%D<F5S<V5N="!U:V5N9'0`:V%L
M96YD97(`=FEN9'-T:6QL90!K86X@:6MK92!D86YN92!U9&1A=&$M9FEL`&MA
M;B!I:VME(.5B;F4@:6YD9&%T80!K;&EK(&AE<@!F96IL('9E9"!A;G9E;F1E
M;'-E(&%F(&MO;6UA;F1O+6QI;FEE`&MO;F9I9W5R871I;VYS9F5J;`!M86YG
M;&5R(&MR:71I<VL@<WES=&5M9FEL`&9E:FP@:2!D871A9F]R;6%T`')E9&EG
M97(`:6YD9V%N9R!I:VME(&9U;F1E=`!F86QD96YD90!F:6P`9G)A("5S("@E
M<RD@;65D("5S("5S`'-T;W)M9G5L9`!H.@!H:`!U:V5N9'0@;6%S:VEN;F%V
M;@#X:F5B;&EK:V5L:6=T`&EN9&QE:G)E=`!I;F1D871A+W5D9&%T82UF96IL
M`&EN=&5R;B!S;V9T=V%R92UF96IL`&QI;FEE<ET`;6MI<V]F<R!F96IL:V]D
M92`E9"!U;F1E<B!D86YN96QS92!A9B!)4T\N`&UM`&YA=FX`:6MK92!I;7!L
M96UE;G1E<F5T`&5N9&YU(&EK:V4@:6UP;&5M96YT97)E=`!N;W1E<V)L;VL`
M<')O8V5N=`!T:6QL861E;'-E(&[F9W1E=`!P<FEK:V5R`&9E:FP@:2!P<F]T
M;VMO;"!F<F$@9FIE<FX@<VED90!S=&EG96YD90!T:F5N97-T92!U=&EL9^9N
M9V5L:6<`=FES(&9O<G-K96QL90!S;7,R96UA:6P@=FEA($A45%``<W,`<W1A
M8FEL=`!S>7-T96UF96IL`&]P9V%V96QI<W1E`&UI9&QE<G1I9&EG(&9E:FQT
M:6QS=&%N9`!I;F1T87-T(&MO9&5O<F1E="!T;R!G86YG92!F;W(@870@8F5K
M<N9F=&4`<V%M;65N<VUE;'1E=`!U;F%V;F=I=F5N`&)R=6=E<G9A;&<`=D-A
M<F0`=SH`=V5A=&AE<BYC;VT`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&]C86QE+V1E7T1%+P``````````````````````
M```````````````````````````````````````````````````````````P
M,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U
M,P`P,C`P-34`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9&5?1$4O
M:&5L<"YX;6P`````````````````````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`T-#$P`#$P-3$U-#,S-S4S`#`R,34R-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/WAM;"!V97)S:6]N/2(Q+C`B(&5N
M8V]D:6YG/2)I<V\M.#@U.2TQ(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A
M;&4O9&5?1$4O:&5L<"YX;6PL=B`Q+C4@,C`P-"\Q,"\R,B`Q,SHS-SHQ.2!J
M86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@;60U
M/2(V.&-A,S-F-V8P8SEA864T8S$P,V5B-#<T.3)C9&,Q-2(@<W1A=&4](G5P
M=&]D871E(CX*("`@(#QT:71L93Y$:64@4&]R=&%L<V5I=&4\+W1I=&QE/@H@
M("`@/'!A<F$^"B`@("`@($1I92!0;W)T86QS96ET92!E<FQA=6)T(&5I;F4@
M:W5R>F4@W&)E<G-I8VAT(/QB97(@86QL92!):')E('=I8VAT:6=E;@H@("`@
M("!);F9O<FUA=&EO;F5N+B!3:64@:V%N;B!Z=6T@0F5I<W!I96P@86YZ96EG
M96XL('=I92!V:65L92!N975E($5M86EL<R!3:64*("`@("`@:&%B96XL('=E
M;&-H92!497)M:6YE(&1E;6[D8VAS="!A;G-T96AE;BP@=V5L8VAE($%U9F=A
M8F5N(%-I92!N;V-H('IU"B`@("`@(&5R;&5D:6=E;B!H86)E;B!O9&5R(&%U
M8V@@9&EE(&YE=65S=&5N($YA8VAR:6-H=&5N+B!6:65L92!D:65S97(*("`@
M("`@W&)E<G-I8VAT96X@96YT:&%L=&5N('-C:&YE;&QE(%IU9W)I9F9E(&%U
M9B!HY'5F:6<@8F5N]G1I9W1E($9U;FMT:6]N96XL"B`@("`@('=I92!D87,@
M4V-H<F5I8F5N(&YE=65R($5M86EL<R!O9&5R(&1E;2!!;FQE9V5N(&YE=65R
M($MA;&5N9&5R96EN='+D9V4*("`@("`@;V1E<B!!=69G86)E;BX*("`@(#PO
M<&%R83X*("`@(#QP87)A/@H@("`@("!$97(@26YH86QT(&1I97-E<B!0;W)T
M86QS96ET92!K86YN(/QB97(@9&5N(")!;G!A<W-E;B(M3&EN:PH@("`@("!V
M97+D;F1E<G0@=V5R9&5N+B!3:64@:_9N;F5N('IU;2!"96ES<&EE;"!A=7-W
MY&AL96XL('=E;&-H92#<8F5R<VEC:'1E;@H@("`@("!I;B!D:64@4&]R=&%L
M<V5I=&4@875F9V5N;VUM96X@=V5R9&5N('-O;&QE;BP@=6YD(&9E<W1L96=E
M;BP@:6X@=V5L8VAE<@H@("`@("!296EH96YF;VQG92!S:64@86YG97IE:6=T
M('=E<F1E;BX*("`@(#PO<&%R83X*("`\+V5N=')Y/@H*("`\96YT<GD@:60]
M(FYA=F)A<B(@;60U/2)B.&-F,&%E,3EE-3=D9F$P8S)B.38R934Q-C<X,F8T
M-R(@<W1A=&4](G5P=&]D871E(CX*("`@(#QT:71L93Y$:64@06YW96YD=6YG
M<RU.879I9V%T:6]N<VQE:7-T93PO=&ET;&4^"B`@("`\<&%R83X*("`@("`@
M075F(&1E<B!L:6YK96X@4V5I=&4@9&5S($9E;G-T97)S(&)E9FEN9&5T('-I
M8V@@9&EE($YA=FEG871I;VYS;&5I<W1E"B`@("`@(&;\<B!D:64@06YW96YD
M=6YG96XN($ML:6-K96X@4VEE(&%U9B!D:64@4WEM8F]L92!O9&5R($YA;65N
M(&1E<@H@("`@("!!;G=E;F1U;F=E;BP@=6T@<V-H;F5L;"!U;F0@96EN9F%C
M:"!Z=VES8VAE;B!D:65S96X@:&EN+2!U;F0*("`@("`@:&5R>G5S8VAA;'1E
M;BX*("`@(#PO<&%R83X*("`\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M
M9&]?;6%I;G1E;F%N8V4B('-T871E/2)U<'1O9&%T92(@;60U/2)D9#DU9&8P
M-V$P,S`S,3(S,F)A96$Y,3DR.#AB,F0P,"(^"B`@("`\=&ET;&4^16EN<W1E
M;&QU;F=E;CH@06YM96QD96%U9F=A8F5N.B!787)T=6YG<V%R8F5I=&5N"B`@
M("`@(&1U<F-H9OQH<F5N/"]T:71L93X*("`@(#QP87)A/@H@("`@("!796YN
M(%-I92!M]F-H=&5N+"!D87-S(&YA8V@@9&5R($%N;65L9'5N9R!787)T=6YG
M<V%R8F5I=&5N(&1U<F-H9V5F_&AR=`H@("`@("!W97)D96XL(&UA<FMI97)E
M;B!3:64@9&EE<V5S($%U<W=A:&QF96QD+@H@("`@/"]P87)A/@H@(#PO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!S
M=&%T93TB=7!T;V1A=&4B(&UD-3TB83(Q,38R8V1F9C-B,60X9F%E861B-S(Y
M-C(T,#`S-F4B/@H@("`@/'1I=&QE/D5I;G-T96QL=6YG96XZ($%N;65L9&5A
M=69G86)E;CH@5V%R='5N9W-A<F)E:71E;B!B97-TY'1I9V5N/"]T:71L93X*
M("`@(#QP87)A/@H@("`@("!796YN(%-I92!A;&QE(%=A<G1U;F=S87)B96ET
M96X@8F5S=.1T:6=E;B!M]F-H=&5N+"!B979O<B!D:65S90H@("`@("!A=7-G
M96;\:')T('=E<F1E;BP@;6%R:VEE<F5N(%-I92!D:65S97,@075S=V%H;&9E
M;&0N(%=E;FX@4VEE(&1A<R!&96QD"B`@("`@(&1E86MT:79I97)T(&QA<W-E
M;BP@=V5R9&5N(&%L;&4@5V%R='5N9W-A<F)E:71E;B!A=71O;6%T:7-C:`H@
M("`@("!D=7)C:&=E9OQH<G0L(&]H;F4@9&%S<R!3:64@8F5I(&1E<B!!;FUE
M;&1U;F<@9&EE($=E;&5G96YH96ET(&AA8F5N+`H@("`@("!D:65S92!A8GIU
M8G)E8VAE;BX*("`@(#PO<&%R83X*("`\+V5N=')Y/@H\+VAE;'`^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M;V-A;&4O9&5?1$4O3$-?34534T%'15,O````````````````````````````
M`````````````````````````````````````#`P,#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S4S`#`R,38T,@`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]D95]$12],0U]-15-304=%4R]H;W)D
M92YM;P``````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`T,C8S-#``,3`U,34T,S,W
M-3,`,#(S,S$Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````-X2!)4`````D`<``!P```"</```'PH``!QY````````F*$```X`
M``"9H0``#P```*BA```-````N*$```@```#&H0``"P```,^A```,````VZ$`
M``0```#HH0``&````.VA```;````!J(``"T````BH@``'0```%"B```D````
M;J(``"D```"3H@``&0```+VB```F````UZ(```P```#^H@``)`````NC```/
M````,*,```L```!`HP``#@```$RC```%````6Z,``"@```!AHP``"````(JC
M```*````DZ,``!4```">HP``$@```+2C```+````QZ,``(4```#3HP``#@``
M`%FD```*````:*0```T```!SI```#@```(&D```1````D*0```T```"BI```
M#````+"D```-````O:0```8```#+I```E````-*D```*````9Z4```\```!R
MI0``&````(*E```,````FZ4```X```"HI0``#@```+>E```(````QJ4```D`
M``#/I0``+@```-FE```:````"*8``#(````CI@``.````%:F``!4````CZ8`
M`%$```#DI@``6@```#:G``!7````D:<``#0```#IIP``"0```!ZH```-````
M**@```T````VJ```!P```$2H```*````3*@```\```!7J```!0```&>H```&
M````;:@``!$```!TJ```"````(:H```)````CZ@```D```"9J```)0```*.H
M```@````R:@``!,```#JJ```$````/ZH```/````#ZD```H````?J0```P``
M`"JI```/````+JD``!0````^J0``"0```%.I```+````7:D```T```!IJ0``
M$@```'>I```9````BJD``!X```"DJ0``#P```,.I```*````TZD```@```#>
MJ0``)````.>I```4````#*H``!8````AJ@``"````#BJ``!.````0:H``"T`
M``"0J@``&0```+ZJ```'````V*H```P```#@J@``+````.VJ```.````&JL`
M``,````IJP``"P```"VK```'````.:L```<```!!JP``!0```$FK```%````
M3ZL```H```!5JP```P```&"K```7````9*L```H```!\JP``#P```(>K```.
M````EZL``!@```"FJP``(P```+^K```.````XZL``!0```#RJP``%P````>L
M```7````'ZP``!<````WK```$P```$^L```/````8ZP```X```!SK```'P``
M`(*L```=````HJP```<```#`K```!@```,BL```(````SZP```\```#8K```
M!@```.BL```*````[ZP``!,```#ZK```"P````ZM```0````&JT``!4````K
MK0``%0```$&M```'````5ZT``!````!?K0``!0```'"M```5````=JT``!$`
M``",K0``#````)ZM```[````JZT``#@```#GK0``"0```""N```'````*JX`
M`!0````RK@```P```$>N```%````2ZX``!````!1K@``"0```&*N```3````
M;*X``#D```"`K@``$@```+JN```G````S:X``"P```#UK@``*@```"*O```E
M````3:\```H```!SKP``!@```'ZO```)````A:\```<```"/KP``+P```)>O
M```W````QZ\``"X```#_KP``50```"ZP```M````A+```"T```"RL```/0``
M`."P```_````'K$``"T```!>L0``0````(RQ```C````S;$``",```#QL0``
M0````!6R```M````5K(``#,```"$L@``)0```+BR```5````WK(``!D```#T
ML@``*0````ZS```D````.+,``"@```!=LP``$0```(:S```*````F+,```P`
M``"CLP``"@```+"S```0````N[,``!8```#,LP``%@```..S```'````^K,`
M``<````"M```%`````JT```*````'[0```@````JM```)P```#.T```(````
M6[0```<```!DM```!P```&RT```&````=+0```4```![M```!P```(&T```&
M````B;0```@```"0M```*0```)FT```.````P[0```H```#2M```!````-VT
M```'````XK0```D```#JM```!@```/2T```1````^[0```<````-M0``%@``
M`!6U```$````++4```@````QM0``!@```#JU```-````0;4```8```!/M0``
M'@```%:U```1````=;4```@```"'M0``#0```)"U```,````GK4```<```"K
MM0```P```+.U```#````M[4``!<```"[M0``$P```-.U```=````Y[4```@`
M```%M@``!`````ZV```(````$[8```@````<M@``*P```"6V```@````4;8`
M`!4```!RM@``!@```(BV```&````C[8``!4```"6M@``.@```*RV```8````
MY[8``"(`````MP``,P```".W```N````5[<``!T```"&MP``(0```*2W``!4
M````QK<``$`````;N```*0```%RX```9````AK@```H```"@N```!P```*NX
M```'````L[@``!4```"[N```#@```-&X```*````X+@```\```#KN```#0``
M`/NX```/````";D```T````9N0``"0```">Y```4````,;D```8```!&N0``
M&````$VY```=````9KD``!,```"$N0``$0```)BY```4````JKD```0```"_
MN0``!@```,2Y```4````R[D``%0```#@N0``9````#6Z```$````FKH```X`
M``"?N@``!0```*ZZ```%````M+H``!L```"ZN@``&@```-:Z```3````\;H`
M`!$````%NP``$0```!>[```<````*;L``"H```!&NP``$````'&[```A````
M@KL```4```"DNP``$P```*J[```+````OKL``!(```#*NP``"@```-V[```/
M````Z+L```T```#XNP``$0````:\```3````&+P```P````LO```!@```#F\
M```,````0+P```8```!-O```%P```%2\```0````;+P``!$```!]O```"```
M`(^\```%````F+P```P```">O```$````*N\```%````O+P```T```#"O```
M!@```-"\```'````U[P```T```#?O```!P```.V\```+````];P```<````!
MO0``!P````F]```)````$;T```D````;O0``"@```"6]```9````,+T``!T`
M``!*O0``#````&B]```0````=;T```4```"&O0``)0```(R]```2````LKT`
M`!,```#%O0``*P```-F]```[````!;X``"````!!O@``"````&*^```V````
M:[X``"$```"BO@``$````,2^```(````U;X```P```#>O@``!@```.N^```$
M````\KX```\```#WO@``#@````>_```'````%K\```H````>OP``#0```"F_
M```?````-[\``!P```!7OP``(0```'2_```>````EK\``!D```"UOP``'@``
M`,^_```;````[K\``"$````*P```+@```"S````F````6\```!P```""P```
M'@```)_````<````OL```"8```#;P```*P````+!```S````+L$``"8```!B
MP0``*P```(G!```X````M<$``!T```#NP0``%0````S"```O````(L(``"``
M``!2P@``$@```'/"```I````AL(``!X```"PP@``(````,_"```2````\,(`
M`*(````#PP``%@```*;#```C````O<,``"@```#APP``*0````K$```H````
M-,0``!\```!=Q```%0```'W$```@````D\0``"4```"TQ```*````-K$```M
M`````\4``#`````QQ0``D@```&+%```A````]<4``!8````7Q@``'````"[&
M```F````2\8``"H```!RQ@``00```)W&``!$````W\8```P````DQP``!P``
M`#''```'````.<<```8```!!QP``#0```$C'```0````5L<``!(```!GQP``
M$P```'K'```2````CL<```<```"AQP``!````*G'```0````KL<``!````"_
MQP``#````-#'```.````W<<```T```#LQP``#P```/K'```3````"L@```T`
M```>R```*````"S(```#````5<@```T```!9R```!@```&?(```1````;L@`
M`!<```"`R```&P```)C(```.````M,@```(```##R```20```,;(```%````
M$,D``!`````6R0``#P```"?)```$````-\D```T````\R0``#@```$K)```#
M````6<D```X```!=R0``"````&S)```/````=<D```\```"%R0``!P```)7)
M```-````G<D``!````"KR0``#0```+S)```+````RLD```8```#6R0``"P``
M`-W)```,````Z<D```H```#VR0``$0````'*```9````$\H```L````MR@``
M#0```#G*```B````1\H```\```!JR@``&P```'K*```T````ELH```H```#+
MR@``&````-;*```2````[\H``!D````"RP``%@```!S+```B````,\L```T`
M``!6RP``!P```&3+```4````;,L```L```"!RP``(@```(W+```O````L,L`
M``L```#@RP``"0```.S+```9````]LL```L````0S```%P```!S,```7````
M-,P```D```!,S```%@```%;,```/````;<P``!D```!]S```%@```)?,```.
M````KLP``!@```"]S```"````-;,```-````W\P``"8```#MS```0P```!3-
M```(````6,T``!(```!AS0``'P```'3-```(````E,T```L```"=S0``+P``
M`*G-```.````V<T```4```#HS0``!@```.[-``!%````]<T```,````[S@``
M!P```#_.```$````1\X```H```!,S@``"@```%?.```/````8LX``!````!R
MS@``%P```(/.```1````F\X``!D```"MS@``%P```,?.```)````W\X```4`
M``#IS@``"P```._.```*````^\X```(````&SP``!0````G/```-````#\\`
M`!L````=SP``%P```#G/```4````4<\```D```!FSP``#@```'#/```-````
M?\\``!(```"-SP``.````*#/```@````V<\```@```#ZSP``#@````/0``![
M````$M```!@```".T```&````*?0```1````P-````<```#2T```!0```-K0
M```8````X-```!X```#YT```&P```!C1```9````--$``!L```!.T0``&0``
M`&K1```3````A-$```<```"8T0``"````*#1```&````J=$```8```"PT0``
M$````+?1```/````R-$``!````#8T0``#P```.G1```+````^=$```\````%
MT@``#````!72```/````(M(```<````RT@``!@```#K2```,````0=(``"@`
M``!.T@``#P```'?2```(````A](```@```"0T@``$P```)G2```>````K=(`
M`"$```#,T@``(````.[2```9````#],``!<````ITP``)0```$'3```7````
M9],``!8```!_TP``!````);3```;````F],```T```"WTP``#````,73```#
M````TM,```4```#6TP``"````-S3```*````Y=,```P```#PTP``"P```/W3
M```0````"=0```P````:U```#@```"?4```+````-M0```0```!"U```!```
M`$?4```3````3-0``!0```!@U```#````'74```)````@M0```X```",U```
M"P```)O4```;````I]0```<```##U```!P```,O4```*````T]0```T```#>
MU```"0```.S4```$````]M0```4```#[U````P````'5```8````!=4```H`
M```>U0``!````"G5```F````+M4```X```!5U0``?````&35```5````X=4`
M``4```#WU0``!P```/W5```,````!=8```@````2U@``"@```!O6```&````
M)M8```@````MU@```@```#;6```&````.=8```8```!`U@``%````$?6```0
M````7-8```T```!MU@``$````'O6```;````C-8```0```"HU@``"0```*W6
M```0````M]8```D```#(U@``"0```-+6```%````W-8``!H```#BU@``"```
M`/W6```&````!M<``!D````-UP``#@```"?7```'````-M<```<````^UP``
M!0```$;7```)````3-<```H```!6UP``#@```&'7```"````<-<```8```!S
MUP``"P```'K7```-````AM<```D```"4UP``!@```)[7```2````I=<```D`
M``"XUP``!P```,+7```4````RM<``!T```#?UP``0@```/W7```E````0-@`
M`"4```!FV```!@```(S8```*````D]@```0```">V```"0```*/8```(````
MK=@``!$```"VV```"0```,C8```&````TM@```T```#9V```!@```.?8```$
M````[M@``#D```#SV```/0```"W9```Z````:]D``!X```"FV0``!0```,79
M```.````R]D```0```#:V0``!@```-_9```'````YMD``"$```#NV0``#0``
M`!#:```5````'MH```8````TV@``!````#O:```1````0-H```8```!2V@``
M"@```%G:```B````9-H```0```"'V@``!0```(S:```=````DMH```P```"P
MV@``#@```+W:```*````S-H```@```#7V@``"0```.#:```%````ZMH``#H`
M``#PV@``,````"O;```U````7-L``"D```"2VP``1P```+S;```X````!-P`
M`"D````]W```/P```&?<```N````I]P``"T```#6W```'P````3=```/````
M)-T``!(````TW0``"P```$?=```F````4]T``"D```!ZW0``)````*3=```F
M````R=T```@```#PW0``"@```/G=```)````!-X```<````.W@``(````!;>
M```@````-]X``"8```!8W@``"@```'_>```9````BMX``"D```"DW@``%@``
M`,[>```2````Y=X```<```#XW@``"@````#?```,````"]\```\````8WP``
M$````"C?``!`````.=\``'````!ZWP``9@```.O?```.````4N````D```!A
MX```"@```&O@```2````=N```!,```")X```#````)W@```&````JN````\`
M``"QX```$@```,'@```0````U.```!$```#EX```'````/?@```C````%.$`
M`&H````XX0``#P```*/A```%````L^$``!````"YX0``"0```,KA```$````
MU.$```L```#9X0``(````.7A```1````!N(``!0````8X@``#````"WB```,
M````.N(```\```!'X@``%0```%?B```I````;>(``"H```"7X@``)@```,+B
M```G````Z>(``"D````1XP``*@```#OC```9````9N,``$(```"`XP``$0``
M`,/C```2````U>,``!,```#HXP``%````/SC```/````$>0``!8````AY```
M%P```#CD```0````4.0``!$```!AY```-````'/D```3````J.0``!(```"\
MY```-0```,_D```4````!>4```<````:Y0``#````"+E```@````+^4``!``
M``!0Y0``%````&'E```1````=N4``!<```"(Y0``'````*#E```3````O>4`
M`!0```#1Y0``&@```.;E```1`````>8``!H````3Y@``'@```"[F```:````
M3>8``!,```!HY@``%0```'SF```1````DN8``!<```"DY@``%````+SF```7
M````T>8``!4```#IY@``"0```/_F```0````"><``!D````:YP``!````#3G
M```'````.><```L```!!YP``$0```$WG```&````7^<```8```!FYP``!@``
M`&WG```%````=.<```<```!ZYP``!P```(+G```%````BN<``!8```"0YP``
M!@```*?G```&````KN<```0```"UYP``!````+KG```'````O^<```X```#'
MYP``#````-;G```,````X^<```T```#PYP``"@```/[G```.````">@```4`
M```8Z```*````![H```.````1^@```P```!6Z```#P```&/H```*````<^@`
M``@```!^Z```"0```(?H```K````D>@```0```"]Z```"````,+H```F````
MR^@``!(```#RZ```#P````7I```&````%>D```H````<Z0``!P```"?I```(
M````+^D``"`````XZ0``"0```%GI```4````8^D```P```!XZ0``#0```(7I
M```.````D^D``!8```"BZ0``$0```+GI```&````R^D```,```#2Z0``!@``
M`-;I```9````W>D```<```#WZ0``!````/_I```+````!.H```L````0Z@``
M!P```!SJ```%````).H```<````JZ@``%@```#+J```-````2>H```T```!7
MZ@``"@```&7J```0````<.H```\```"!Z@``$0```)'J```7````H^H```H`
M``"[Z@``$0```,;J```(````V.H```0```#AZ@``"````.;J```/````[^H`
M``\```#_Z@``"P````_K```)````&^L``#H````EZP``%````&#K```%````
M=>L```P```![ZP``'@```(CK```.````I^L``!````"VZP``"P```,?K```,
M````T^L```D```#@ZP``!P```.KK```*````\NL```D```#]ZP``#@````?L
M```0````%NP``!L````G[```&````$/L```:````7.P```H```!W[```"0``
M`(+L```*````C.P```P```"7[```#P```*3L```(````M.P```8```"][```
M'````,3L```'````X>P```4```#I[```"P```._L``!'````^^P```T```!#
M[0``"0```%'M```$````6^T```,```!@[0``$P```&3M```3````>.T``!,`
M``",[0``"@```*#M```"````J^T```0```"N[0``)0```+/M```#````V>T`
M``4```#=[0``*@```./M```*````#NX```4````9[@``!````!_N```*````
M).X```T````O[@``!@```#WN```(````1.X```@```!-[@``!````%;N```%
M````6^X``&@```!A[@``"0```,KN```,````U.X``!````#A[@``!0```/+N
M```&````^.X``!L```#_[@``+P```!OO```0````2^\```H```!<[P``#P``
M`&?O```*````=^\```D```""[P``$P```(SO```;````H.\``!@```"\[P``
M%P```-7O```?````[>\```X````-\````P```!SP```'````(/````@````H
M\```!P```#'P```*````.?````L```!$\```!P```%#P``!1````6/```!``
M``"J\```#````+OP```-````R/```!H```#6\```2@```/'P```9````//$`
M``8```!6\0``&@```%WQ```E````>/$```8```">\0``!@```*7Q```?````
MK/$```8```#,\0``"0```-/Q```8````W?$``!<```#V\0``*`````[R```&
M````-_(```T````^\@``(@```$SR``!7````;_(``!,```#'\@``(P```-OR
M```3````__(```(````3\P``"P```!;S```(````(O,```T````K\P``"@``
M`#GS```'````1/,``!0```!,\P``!@```&'S```(````:/,```X```!Q\P``
M!P```(#S```*````B/,```L```"3\P``,@```)_S```'````TO,```P```#:
M\P``#0```.?S```7````]?,```P````-]```"0```!KT```)````)/0```H`
M```N]```!P```#GT```)````0?0```<```!+]```"@```%/T```;````7O0`
M``\```!Z]```$@```(KT```*````G?0``!8```"H]```"0```+_T```0````
MR?0```<```#:]```$@```.+T```$````]?0```<```#Z]```!0````+U```%
M````"/4```L````.]0``%````!KU```1````+_4``!H```!!]0``%@```%SU
M```4````<_4``!<```"(]0``&````*#U```<````N?4``!D```#6]0``!P``
M`/#U```%````^/4```T```#^]0``#`````SV```(````&?8``!<````B]@``
M"P```#KV```,````1O8``!\```!3]@``&@```'/V```3````CO8```0```"B
M]@``"@```*?V```$````LO8```T```"W]@``#````,7V```%````TO8```D`
M``#8]@``!0```.+V```'````Z/8```4```#P]@``!````/;V```"````^_8`
M`#@```#^]@``+````#?W```2````9/<``"D```!W]P``,@```*'W```*````
MU/<``"P```#?]P``+@````SX```S````._@``#,```!O^```.````*/X```/
M````W/@``!@```#L^```$`````7Y```/````%OD``!,````F^0``%0```#KY
M```4````4/D``!(```!E^0``%````'CY```5````C?D``"T```"C^0``+0``
M`-'Y```Q````__D``"X````Q^@``+P```&#Z```L````D/H``&(```"]^@``
M$P```"#[```-````-/L```@```!"^P``%P```$O[```(````8_L```P```!L
M^P``*P```'G[```A````I?L``!H```#'^P``"0```.+[``!%````[/L``$$`
M```R_```!````'3\```3````>?P``!0```"-_```#@```*+\```3````L?P`
M`!@```#%_```!@```-[\```)````Y?P```H```#O_```#P```/K\```*````
M"OT``!`````5_0``!P```";]```.````+OT```4````]_0``&P```$/]```(
M````7_T```8```!H_0``%````&_]```1````A/T```X```"6_0``.````*7]
M```"````WOT```8```#A_0``#@```.C]```%````]_T```<```#]_0``#@``
M``7^```&````%/X``"@````;_@``#````$3^```<````4?X```0```!N_@``
M#0```'/^```I````@?X``!<```"K_@``'P```,/^``!<````X_X``!0```!`
M_P``/@```%7_```?````E/\``!````"T_P``!P```,7_```.````S?\```P`
M``#<_P``#````.G_```3````]O\```H````*``$`'0```!4``0`9````,P`!
M``4```!-``$`$0```%,``0`1````90`!`"0```!W``$`$@```)P``0`5````
MKP`!`!(```#%``$`#@```-@``0`9````YP`!``@````!`0$`"0````H!`0`-
M````%`$!``<````B`0$`"@```"H!`0`'````-0$!``\````]`0$`!@```$T!
M`0`+````5`$!`!H```!@`0$`"@```'L!`0`'````A@$!``@```".`0$`!0``
M`)<!`0`?````G0$!``8```"]`0$`$````,0!`0`(````U0$!``T```#>`0$`
M"````.P!`0`>````]0$!`!(````4`@$`+````"<"`0`:````5`(!``D```!O
M`@$`"@```'D"`0`5````A`(!``4```":`@$`%````*`"`0`$````M0(!`!``
M``"Z`@$`!@```,L"`0`'````T@(!`!X```#:`@$`*````/D"`0`*````(@,!
M`!P````M`P$`$0```$H#`0`+````7`,!`!H```!H`P$`%````(,#`0`$````
MF`,!``0```"=`P$`"P```*(#`0`%````K@,!``8```"T`P$`"````+L#`0`&
M````Q`,!``H```#+`P$`&P```-8#`0`T````\@,!`#0````G!`$`(````%P$
M`0`I````?00!`"````"G!`$`00```,@$`0`:````"@4!`"@````E!0$`*0``
M`$X%`0!0````>`4!`"(```#)!0$`!@```.P%`0`(````\P4!``4```#\!0$`
M"`````(&`0`9````"P8!`!D````E!@$`*@```#\&`0`C````:@8!`!D```".
M!@$`+@```*@&`0`T````UP8!``@````,!P$`%P```!4'`0`*````+0<!``<`
M```X!P$`(0```$`'`0`0````8@<!``X```!S!P$`"P```(('`0`'````C@<!
M`!,```"6!P$`"````*H'`0`+````LP<!``H```"_!P$`%````,H'`0`/````
MWP<!`#(```#O!P$`"P```"((`0`.````+@@!``4````]"`$`!0```$,(`0`%
M````20@!`!<```!/"`$`#P```&<(`0`$````=P@!``H```!\"`$`"0```(<(
M`0`+````D0@!``T```"="`$`#````*L(`0`.````N`@!``4```#'"`$`!```
M`,T(`0`-````T@@!`#(```#@"`$`10```!,)`0`7````60D!``<```!Q"0$`
M'@```'D)`0`4````F`D!``4```"M"0$`%````+,)`0`&````R`D!``<```#/
M"0$`#@```-<)`0`J````Y@D!``8````1"@$`#````!@*`0`-````)0H!`!$`
M```S"@$`"P```$4*`0`V````40H!``H```"("@$`(@```),*`0`+````M@H!
M``\```#""@$`,@```-(*`0`E````!0L!`#`````K"P$`,0```%P+`0`M````
MC@L!``X```"\"P$`!0```,L+`0`.````T0L!`!,```#@"P$`$@```/0+`0`'
M````!PP!`!$````/#`$`$P```"$,`0`'````-0P!`!0````]#`$`&````%(,
M`0`'````:PP!``4```!S#`$`#````'D,`0`,````A@P!`!(```"3#`$`!```
M`*8,`0`'````JPP!``H```"S#`$`"P```+X,`0`,````R@P!``X```#7#`$`
M#@```.8,`0`%````]0P!``4```#[#`$`+@````$-`0`F````,`T!`",```!7
M#0$``P```'L-`0`2````?PT!``8```"2#0$`'@```)D-`0`8````N`T!`"4`
M``#1#0$`#0```/<-`0`)````!0X!`!\````/#@$``P```"\.`0`'````,PX!
M``H````[#@$``@```$8.`0`,````20X!`!4```!6#@$`"P```&P.`0`9````
M>`X!`"````"2#@$`$@```+,.`0`%````Q@X!``H```#,#@$`%0```-<.`0`2
M````[0X!``P`````#P$`!`````T/`0`)````$@\!``<````<#P$`#````"0/
M`0!2````,0\!`!<```"$#P$`)````)P/`0`2````P0\!``<```#4#P$`!@``
M`-P/`0`.````XP\!``P```#R#P$`#0```/\/`0`5````#1`!`!(````C$`$`
M#P```#80`0`4````1A`!``H```!;$`$`&P```&80`0`0````@A`!``L```"3
M$`$`:0```)\0`0`:````"1$!`!<````D$0$`)P```#P1`0`:````9!$!`!<`
M``!_$0$`&P```)<1`0`9````LQ$!`!\```#-$0$`$P```.T1`0`(`````1(!
M``<````*$@$`"````!(2`0`)````&Q(!`!4````E$@$`#0```#L2`0`C````
M21(!``T```!M$@$`$P```'L2`0`(````CQ(!``,```"8$@$`1@```)P2`0`_
M````XQ(!`#<````C$P$`5P```%L3`0`%````LQ,!`!\```"Y$P$`+P```-D3
M`0`*````"10!``@````4%`$`#0```!T4`0`M````*Q0!``0```!9%`$`3P``
M`%X4`0`E````KA0!`!P```#4%`$`"P```/$4`0`?````_10!`!T````=%0$`
M)0```#L5`0`@````814!`"0```""%0$`(````*<5`0`+````R!4!``<```#4
M%0$`#0```-P5`0`,````ZA4!`!<```#W%0$`!@````\6`0`Y````%A8!``P`
M``!0%@$`!P```%T6`0`)````918!`!,```!O%@$`"0```(,6`0`$````C18!
M`!````"2%@$`"````*,6`0`(````K!8!``0```"U%@$`"P```+H6`0`,````
MQA8!`!(```#3%@$`$0```.86`0`,````^!8!`!H````%%P$`#P```"`7`0`'
M````,!<!``T````X%P$`%````$87`0`.````6Q<!``P```!J%P$`&P```'<7
M`0`L````DQ<!`!,```#`%P$`'````-07`0`H````\1<!``8````:&`$`!P``
M`"$8`0`3````*1@!``4````]&`$`!````$,8`0`7````2!@!``H```!@&`$`
M#````&L8`0`)````>!@!``8```""&`$`"0```(D8`0`(````DQ@!``D```"<
M&`$`"@```*88`0`1````L1@!``8```##&`$`#@```,H8`0`.````V1@!``T`
M``#H&`$`"P```/88`0`=`````AD!``L````@&0$``@```"P9`0`<````+QD!
M``<```!,&0$`!@```%09`0!D````6QD!``D```#`&0$`!P```,H9`0`F````
MTAD!`#@```#Y&0$`&@```#(:`0`J````31H!`#L```!X&@$`*````+0:`0`T
M````W1H!`!D````2&P$`%0```"P;`0`%````0AL!``<```!(&P$`"````%`;
M`0`'````61L!``4```!A&P$`!P```&<;`0`.````;QL!``D```!^&P$`!@``
M`(@;`0`(````CQL!``L```"8&P$`!P```*0;`0`(````K!L!``<```"U&P$`
M%@```+T;`0`)````U!L!``8```#>&P$`"P```.4;`0`0````\1L!`!P````"
M'`$`%````!\<`0`'````-!P!`!$````\'`$`"````$X<`0`.````5QP!``@`
M``!F'`$`$````&\<`0`)````@!P!`!````"*'`$`!@```)L<`0`9````HAP!
M``H```"\'`$`'````,<<`0`'````Y!P!``4```#L'`$`$````/(<`0`4````
M`QT!``L````8'0$`#0```"0=`0`H````,AT!`!@```!;'0$`%P```'0=`0`$
M````C!T!``D```"1'0$`"@```)L=`0`'````IAT!``(```"N'0$`#@```+$=
M`0`(````P!T!`",```#)'0$`'P```.T=`0`X````#1X!`"8```!&'@$`,0``
M`&T>`0`G````GQX!`&0```#''@$`%````"P?`0!5````01\!`#@```"7'P$`
M2@```-`?`0!;````&R`!`"@```!W(`$`.````*`@`0`H````V2`!`"P````"
M(0$`&P```"\A`0`^````2R$!`*D!``"*(0$`(P```#0C`0`7````6",!`$@`
M``!P(P$`A0```+DC`0`P````/R0!`"4```!P)`$`00```)8D`0!;````V"0!
M`$D````T)0$`,0```'XE`0`=````L"4!`!@```#.)0$`*P```.<E`0`A````
M$R8!`!\````U)@$`*P```%4F`0`F````@28!`"<```"H)@$`.@```-`F`0`=
M````"R<!`!$````I)P$`,P```#LG`0`E````;R<!`"<```"5)P$`(````+TG
M`0`?````WB<!`#````#^)P$`:0```"\H`0`Q````F2@!`$$```#+*`$`,P``
M``TI`0`E````02D!`#T```!G*0$`90```*4I`0!-````"RH!`"\```!9*@$`
M+@```(DJ`0`P````N"H!`%0```#I*@$`6@```#XK`0!(````F2L!`$H```#B
M*P$`,@```"TL`0`O````8"P!`"P```"0+`$`+0```+TL`0!Q````ZRP!`&8`
M``!=+0$`;P```,0M`0"S````-"X!`!<```#H+@$`)0`````O`0`R````)B\!
M`"D```!9+P$`/@```(,O`0`B````PB\!`%(```#E+P$`)0```#@P`0`+````
M7C`!`+$```!J,`$`10```!PQ`0`A````8C$!`#````"$,0$`)0```+4Q`0`<
M````VS$!`#$```#X,0$`!P```"HR`0`'````,C(!``0````Z,@$`#0```#\R
M`0`+````33(!``X```!9,@$`"P```&@R`0`%````=#(!`!````!Z,@$``@``
M`(LR`0!9````CC(!``4```#H,@$`$@```.XR`0`$`````3,!``<````&,P$`
M"`````XS`0`%````%S,!`#`````=,P$``P```$XS`0`0````4C,!``P```!C
M,P$`$P```'`S`0`-````A#,!``(```"2,P$`!P```)4S`0`&````G3,!`!0`
M``"D,P$`#````+DS`0`8````QC,!``8```#?,P$`$@```.8S`0`,````^3,!
M``,````&-`$`*@````HT`0`$````-30!``8````Z-`$`!P```$$T`0`?````
M230!`#4```!I-`$`+@```)\T`0`O````SC0!`!<```#^-`$`(@```!8U`0`E
M````.34!`"````!?-0$`&P```(`U`0`8````G#4!`"0```"U-0$`'P```-HU
M`0`:````^C4!`"$````5-@$`(````#<V`0`:````6#8!`#(```!S-@$`&@``
M`*8V`0`O````P38!`"L```#Q-@$`'P```!TW`0`C````/3<!`!\```!A-P$`
M&@```($W`0`A````G#<!`"4```"^-P$`)@```.0W`0`E````"S@!`"0````Q
M.`$`&````%8X`0`=````;S@!`"0```"-.`$`&````+(X`0`B````RS@!`"P`
M``#N.`$`*````!LY`0`5````1#D!`"4```!:.0$`/````(`Y`0`?````O3D!
M`",```#=.0$`'P````$Z`0`@````(3H!`!H```!".@$`&````%TZ`0`F````
M=CH!`"D```"=.@$`'@```,<Z`0`I````YCH!`!X````0.P$`,0```"\[`0`)
M````83L!``P```!K.P$`%P```'@[`0`O````D#L!`"0```#`.P$`!P```.4[
M`0`/````[3L!`!0```#].P$`#@```!(\`0`-````(3P!`"0````O/`$`!0``
M`%0\`0`'````6CP!`"(```!B/`$`)0```(4\`0`:````JSP!`!T```#&/`$`
M&@```.0\`0`'````_SP!`,<````'/0$`"P```,\]`0`5````VST!``8```#Q
M/0$`"0```/@]`0`+`````CX!``T````./@$`%P```!P^`0`&````-#X!`#,`
M```[/@$`$P```&\^`0`3````@SX!``<```"7/@$`#P```)\^`0`'````KSX!
M`#(```"W/@$`!````.H^`0`A````[SX!`!,````1/P$`#````"4_`0`1````
M,C\!`#(```!$/P$`%@```'<_`0`(````CC\!`!T```"7/P$`"0```+4_`0`*
M````OS\!`!0```#*/P$`"@```-\_`0`=````ZC\!``@````(0`$`'P```!%`
M`0`(````,4`!`!H````Z0`$`)P```%5``0`&````?4`!`!4```"$0`$`!P``
M`)I``0`(````HD`!``D```"K0`$`/P```+5``0`'````]4`!``\```#]0`$`
M#@````U!`0`0````'$$!``D````M00$`"0```#=!`0`(````04$!`!,```!*
M00$`!P```%Y!`0`9````9D$!``H```"`00$`%P```(M!`0`4````HT$!``H`
M``"X00$`#````,-!`0`7````T$$!``0```#H00$`*@```.U!`0`,````&$(!
M`!$````E0@$`!P```#="`0`"````/T(!`!````!"0@$`&````%-"`0`+````
M;$(!``,```!X0@$`"````'Q"`0`&````A4(!``<```",0@$`#0```)1"`0`+
M````HD(!`!0```"N0@$`%0```,-"`0`.````V4(!`"\```#H0@$`(````!A#
M`0`<````.4,!`!4```!60P$`#````&Q#`0`Q````>4,!``4```"K0P$`$@``
M`+%#`0`_````Q$,!`!(````$1`$`"@```!=$`0`&````(D0!``0````I1`$`
M!````"Y$`0`*````,T0!`!,````^1`$`!0```%)$`0`&````6$0!``8```!?
M1`$`"````&9$`0`$````;T0!``P```!T1`$`"@```(%$`0`Y````C$0!`"X`
M``#&1`$`*0```/5$`0`%````'T4!`!@````E10$`&0```#Y%`0`?````6$4!
M`!T```!X10$`$0```)9%`0`"````J$4!``0```"K10$`"@```+!%`0`&````
MNT4!``4```#"10$``P```,A%`0`,````S$4!`$4```#910$`,@```!]&`0`:
M````4D8!`#0```!M1@$`*````*)&`0!3````RT8!`!D````?1P$`<@```#E'
M`0`@````K$<!`#4```#-1P$`(0````-(`0!%````)4@!`#````!K2`$`*```
M`)Q(`0`I````Q4@!`"8```#O2`$`)0```!9)`0`H````/$D!`"@```!E20$`
M(@```(Y)`0`K````L4D!`#````#=20$`$@````Y*`0`3````(4H!`!`````U
M2@$`>0```$9*`0`)````P$H!`*$```#*2@$`<P```&Q+`0!\````X$L!`"L`
M``!=3`$`5````(E,`0`7````WDP!`"<```#V3`$`%@```!Y-`0`/````-4T!
M`!<```!%30$`'P```%U-`0!`````?4T!`!\```"^30$`'````-Y-`0!1````
M^TT!`!H```!-3@$`%````&A.`0`*````?4X!``4```"(3@$`!@```(Y.`0`(
M````E4X!``4```">3@$`$@```*1.`0`0````MTX!`!,```#(3@$`'0```-Q.
M`0`/````^DX!``\````*3P$`!````!I/`0`)````'T\!``L````I3P$`!P``
M`#5/`0`4````/4\!``<```!23P$`"````%I/`0`/````8T\!``@```!S3P$`
M#````'Q/`0`/````B4\!``8```"93P$`%````*!/`0`&````M4\!``P```"\
M3P$`$0```,E/`0`(````VT\!``0```#D3P$`&0```.E/`0`1`````U`!``H`
M```54`$`&````"!0`0`3````.5`!`!P```!-4`$`$0```&I0`0`$````?%`!
M``\```"!4`$`!P```)%0`0`$````F5`!`!D```">4`$`!P```+A0`0`"````
MP%`!``(```##4`$`$0```,90`0`)````V%`!``8```#B4`$`$@```.E0`0`7
M````_%`!``8````440$`)P```!M1`0`"````0U$!``0```!&40$`#P```$M1
M`0`3````6U$!``<```!O40$`!P```'=1`0`1````?U$!``8```"140$`&```
M`)A1`0`&````L5$!`!,```"X40$`$````,Q1`0`2````W5$!``(```#P40$`
M!@```/-1`0`,````^E$!``D````'4@$`$0```!%2`0`B````(U(!``<```!&
M4@$`!P```$Y2`0`+````5E(!``4```!B4@$``@```&A2`0`+````:U(!`%@!
M``!W4@$`#P```-!3`0`3````X%,!``X```#T4P$`"`````-4`0`)````#%0!
M``H````65`$`!0```"%4`0`:````)U0!`!\```!"5`$`,@```&)4`0`P````
ME50!`"D```#&5`$`*````/!4`0`>````&54!`#,````X50$`#````&Q5`0`G
M````>54!`!(```"A50$`#````+15`0`0````P54!``4```#250$`(0```-A5
M`0`0````^E4!`!`````+5@$`%@```!Q6`0`5````,U8!``P```!)5@$`A0``
M`%96`0`0````W%8!``H```#M5@$`$@```/A6`0`0````"U<!``X````<5P$`
M#````"M7`0`.````.%<!`!$```!'5P$`!@```%E7`0#!````8%<!``<````B
M6`$`"P```"I8`0`:````-E@!``\```!16`$`$0```&%8`0`1````<U@!``H`
M``"%6`$`!P```)!8`0`L````F%@!`"0```#%6`$`50```.I8`0!A````0%D!
M`'D```"B60$`>````!Q:`0!\````E5H!`'L````26P$`6````(Y;`0`1````
MYUL!`!D```#Y6P$`'@```!-<`0`0````,EP!`!(```!#7`$`&````%9<`0`%
M````;UP!``8```!U7`$`$@```'Q<`0`'````CUP!``T```"77`$`#0```*5<
M`0`W````LUP!`"X```#K7`$`$@```!I=`0`-````+5T!`!(````[70$`"P``
M`$Y=`0`*````6ET!`!L```!E70$`&P```(%=`0`0````G5T!`!4```"N70$`
M%@```,1=`0`6````VUT!`!X```#R70$`'@```!%>`0`E````,%X!`!$```!6
M7@$`#P```&A>`0`J````>%X!`!H```"C7@$`'P```+Y>`0`3````WEX!`'H`
M``#R7@$`0@```&U?`0`O````L%\!``<```#@7P$`"@```.A?`0`P````\U\!
M``X````D8`$`!P```#-@`0`+````.V`!``@```!'8`$`"````%!@`0`)````
M66`!``L```!C8`$`#````&]@`0`$````?&`!`!0```"!8`$`#````)9@`0`+
M````HV`!`!````"O8`$`&0```,!@`0`F````VF`!`!$````!80$`&@```!-A
M`0`:````+F$!`!X```!)80$`&@```&AA`0`4````@V$!`!(```"880$`$@``
M`*MA`0`G````OF$!`"<```#F80$`!P````YB`0`&````%F(!``@````=8@$`
M#@```"9B`0`'````-6(!``D````]8@$`$P```$=B`0`)````6V(!``\```!E
M8@$`%0```'5B`0`8````BV(!``H```"D8@$`#P```*]B`0`%````OV(!`!<`
M``#%8@$`"P```-UB`0`*````Z6(!`$L```#T8@$`10```$!C`0`+````AF,!
M``@```"28P$`%0```)MC`0`%````L6,!``4```"W8P$`$````+UC`0`+````
MSF,!`!<```#:8P$`+@```/)C`0`0````(60!`#T````R9`$`/````'!D`0`_
M````K60!`#\```#M9`$`"0```"UE`0`&````-V4!``H````^90$`"@```$EE
M`0!!````5&4!`#T```"690$`0````-1E`0!Q````%68!`#\```"'9@$`0P``
M`,=F`0!3````"V<!`%````!?9P$`/P```+!G`0!1````\&<!`#,```!":`$`
M-P```'9H`0!7````KF@!`#\````&:0$`0P```$9I`0`J````BFD!`"````"U
M:0$`'````-9I`0`]````\VD!`"D````Q:@$`*0```%MJ`0`2````A6H!``T`
M``"8:@$`#0```*9J`0`+````M&H!`!````#`:@$`&P```-%J`0`?````[6H!
M``<````-:P$`!P```!5K`0`6````'6L!``L````T:P$`"````$!K`0`M````
M26L!``H```!W:P$`"@```()K`0`'````C6L!``8```"5:P$`!0```)QK`0`(
M````HFL!``8```"K:P$`"@```+)K`0`M````O6L!`!(```#K:P$`"````/YK
M`0`$````!VP!``@````,;`$`"P```!5L`0`$````(6P!``P````F;`$`!@``
M`#-L`0`3````.FP!``8```!.;`$`"````%5L`0`%````7FP!``L```!D;`$`
M"0```'!L`0`I````>FP!`!$```"D;`$`"0```+9L`0`3````P&P!``P```#4
M;`$`!P```.%L`0`#````Z6P!``,```#M;`$`%P```/%L`0`7````"6T!`#<`
M```A;0$`"````%EM`0`)````8FT!``H```!L;0$`!P```'=M`0`Z````?VT!
M`#P```"Z;0$`*@```/=M`0`&````(FX!``D````I;@$`&````#-N`0!.````
M3&X!`"P```";;@$`)0```,AN`0!2````[FX!`#8```!!;P$`,@```'AO`0`S
M````JV\!`)$```#?;P$`8P```'%P`0!(````U7`!`"P````><0$`"0```$MQ
M`0`+````57$!``@```!A<0$`'0```&IQ`0`-````B'$!``P```"6<0$`$P``
M`*-Q`0`-````MW$!`!,```#%<0$`#@```-EQ`0`,````Z'$!`!8```#U<0$`
M"0````QR`0`<````%G(!`!T````S<@$`$0```%%R`0`2````8W(!`!4```!V
M<@$`!@```(QR`0`&````DW(!`!<```":<@$`@P```+)R`0![````-G,!``<`
M``"R<P$`$P```+IS`0`%````SG,!``4```#4<P$`'P```-IS`0`>````^G,!
M`!0````9=`$`%P```"YT`0`>````1G0!`#0```!E=`$`+P```)IT`0`/````
MRG0!`"@```#:=`$`!@````-U`0`8````"G4!`!0````C=0$`&0```#AU`0`5
M````4G4!`!4```!H=0$`$0```'YU`0`*````D'4!`!,```";=0$`$0```*]U
M`0`&````P74!``L```#(=0$`!P```-1U`0`+````W'4!``X```#H=0$`%P``
M`/=U`0`)````#W8!``4````9=@$`"P```!]V`0`(````*W8!``@````T=@$`
M%````#UV`0`&````4G8!``8```!9=@$`#````&!V`0`)````;78!`!````!W
M=@$`!P```(AV`0`%````D'8!``@```"6=@$`"P```)]V`0`+````JW8!`!H`
M``"W=@$`*P```-)V`0`0````_G8!`!,````/=P$`!0```"-W`0`<````*7<!
M`!H```!&=P$`&P```&%W`0`]````?7<!`$P```"[=P$`*`````AX`0`(````
M,7@!`#T````Z>`$`)````'AX`0`/````G7@!``8```"M>`$`"P```+1X`0`&
M````P'@!``@```#'>`$`&P```-!X`0`0````['@!``D```#]>`$`"@````=Y
M`0`.````$GD!`#D````A>0$`.0```%MY`0`[````E7D!`#L```#1>0$`*P``
M``UZ`0`J````.7H!`"P```!D>@$`*@```)%Z`0!"````O'H!`"\```#_>@$`
M+@```"][`0`P````7GL!`"@```"/>P$`+P```+A[`0`\````Z'L!`$`````E
M?`$`-````&9\`0`Q````FWP!`#D```#-?`$`+P````=]`0`R````-WT!`$8`
M``!J?0$`,````+%]`0`?````XGT!`#H````"?@$`+@```#U^`0`[````;'X!
M`!\```"H?@$`W````,A^`0`?````I7\!`"X```#%?P$`,0```/1_`0`R````
M)H`!`#4```!9@`$`,````(^``0`N````P(`!`#$```#O@`$`.0```"&!`0`\
M````6X$!`$0```"8@0$`/````-V!`0#%````&H(!`"\```#@@@$`(@```!"#
M`0`O````,X,!`#,```!C@P$`/@```)>#`0!D````UH,!`%T````[A`$`#@``
M`)F$`0`$````J(0!``4```"MA`$`"0```+.$`0`.````O80!`!8```#,A`$`
M%0```..$`0`/````^80!`!(````)A0$`"````!R%`0`$````)84!`!$````J
MA0$`$0```#R%`0`-````3H4!`!````!<A0$`$0```&V%`0`0````?X4!`!@`
M``"0A0$`#@```*F%`0!1````N(4!``P````*A@$`%````!>&`0`&````+(8!
M`!,````SA@$`&0```$>&`0`>````888!`!4```"`A@$``@```):&`0!+````
MF88!``<```#EA@$`$````.V&`0`0````_H8!``4````/AP$`#0```!6'`0`-
M````(X<!``,````QAP$`#P```#6'`0`(````18<!``8```!.AP$`$0```%6'
M`0`(````9X<!``T```!PAP$`$0```'Z'`0`-````D(<!``P```">AP$`!P``
M`*N'`0`-````LX<!``X```#!AP$`"P```-"'`0`.````W(<!`"$```#KAP$`
M#0````V(`0`.````&X@!`"8````JB`$`$P```%&(`0`7````98@!`"T```!]
MB`$`#0```*N(`0`=````N8@!`!,```#7B`$`&P```.N(`0`:````!XD!`"X`
M```BB0$`$0```%&)`0`(````8XD!`!L```!LB0$`#````(B)`0`B````E8D!
M`#````"XB0$`"P```.F)`0`(````]8D!`!T```#^B0$`"@```!R*`0`5````
M)XH!`!4````]B@$`"P```%.*`0`C````7XH!`!4```"#B@$`'P```)F*`0`9
M````N8H!``T```#3B@$`$P```.&*`0`)````]8H!``T```#_B@$`+P````V+
M`0!1````/8L!``@```"/BP$`%P```)B+`0`B````L(L!``T```#3BP$`$```
M`.&+`0`T````\HL!``P````GC`$`!@```#2,`0`&````.XP!`$P```!"C`$`
M!@```(^,`0`'````EHP!``H```">C`$`$````*F,`0`1````NHP!`!$```#,
MC`$`$0```-Z,`0`:````\(P!`!T````+C0$`&@```"F-`0`8````1(T!``<`
M``!=C0$`!P```&6-`0`+````;8T!``H```!YC0$``@```(2-`0`&````AXT!
M``X```".C0$`)P```)V-`0`>````Q8T!`!<```#DC0$`!P```/R-`0`0````
M!(X!`!`````5C@$`%````":.`0`[````.XX!`"<```!WC@$`!P```)^.`0`1
M````IXX!`)<```"YC@$`&0```%&/`0`C````:X\!`!$```"/CP$`!P```*&/
M`0`&````J8\!`"8```"PCP$`,@```->/`0`P````"I`!`"0````[D`$`)```
M`&"0`0`?````A9`!`!\```"ED`$`!P```,60`0`)````S9`!``D```#7D`$`
M!@```.&0`0`/````Z)`!``X```#XD`$`$`````>1`0`.````&)$!`!,````G
MD0$`$0```#N1`0`0````39$!``X```!>D0$`"0```&V1`0`*````=Y$!``P`
M``""D0$`/0```(^1`0`-````S9$!``@```#;D0$`$````.21`0`C````]9$!
M`#,````9D@$`)P```$V2`0`F````=9(!`"\```"<D@$`*0```,R2`0`V````
M]I(!`"P````MDP$`%0```%J3`0`&````<),!``X```!WDP$`!@```(:3`0`0
M````C9,!``,```">DP$`!````**3`0`'````IY,!`!,```"ODP$`%0```,.3
M`0`3````V9,!`!D```#MDP$`"@````>4`0`.````$I0!``L````AE`$`!P``
M`"V4`0`%````-90!`!`````[E`$`$@```$R4`0`,````7Y0!``D```!LE`$`
M#````':4`0`/````@Y0!`#$```"3E`$`!@```,64`0`(````S)0!``P```#5
ME`$`#@```.*4`0`7````\90!``@````)E0$`"````!*5`0`%````&Y4!`"(`
M```AE0$`#````$25`0`%````494!`"H```!7E0$`$````(*5`0!Q````DY4!
M`!,````%E@$`"0```!F6`0`*````(Y8!``T````NE@$`"P```#R6`0`-````
M2)8!``4```!6E@$`#0```%R6`0`"````:I8!``8```!ME@$`"@```'26`0`7
M````?Y8!`!(```"7E@$`$P```*J6`0`6````OI8!`#$```#5E@$``P````>7
M`0`$````"Y<!`!D````0EP$`"````"J7`0`2````,Y<!``4```!&EP$`&0``
M`$R7`0`(````9I<!``8```!OEP$`&0```':7`0`.````D)<!``@```"?EP$`
M"P```*B7`0`%````M)<!``D```"ZEP$`!P```,27`0`8````S)<!``,```#E
MEP$`!@```.F7`0`+````\)<!``P```#\EP$`"@````F8`0`,````%)@!`!<`
M```AF`$`"````#F8`0`'````0I@!`!$```!*F`$`(P```%R8`0!0````@)@!
M`#8```#1F`$`.@````B9`0`'````0YD!``H```!+F0$`!````%:9`0`)````
M6YD!``@```!EF0$`"@```&Z9`0`)````>9D!``8```"#F0$`#0```(J9`0`&
M````F)D!``0```"?F0$`.P```*29`0`^````X)D!`#T````?F@$`)@```%V:
M`0`%````A)H!`!````"*F@$`!@```)N:`0`+````HIH!``P```"NF@$`&0``
M`+N:`0`0````U9H!`!@```#FF@$`!````/^:`0`%````!)L!``L````*FP$`
M!0```!:;`0`*````')L!`!X````GFP$`!````$:;`0`+````2YL!``P```!7
MFP$`#@```&2;`0`/````<YL!``X```"#FP$`"````)*;`0`)````FYL!``4`
M``"EFP$`,P```*N;`0`S````WYL!`#P````3G`$`+P```%"<`0!.````@)P!
M`$@```#/G`$`-0```!B=`0!6````3IT!`#L```"EG0$`3````.&=`0`P````
M+IX!`!$```!?G@$`&0```'&>`0`+````BYX!`$,```"7G@$`+P```-N>`0`B
M````"Y\!`"X````NGP$`$````%V?`0`2````;I\!``<```"!GP$`!@```(F?
M`0`Q````D)\!`#$```#"GP$`.````/2?`0`*````+:`!`!L````XH`$`*0``
M`%2@`0`?````?J`!`!,```">H`$`!@```+*@`0`*````N:`!``P```#$H`$`
M#P```-&@`0`9````X:`!`%\```#[H`$`?0```%NA`0!Z````V:$!``T```!4
MH@$`"````&*B`0`)````:Z(!`!````!UH@$`$0```(:B`0`.````F*(!``8`
M``"GH@$`%P```*ZB`0`5````QJ(!`!,```#<H@$`%````/"B`0`;````!:,!
M`"H````AHP$`EP```$RC`0`1````Y*,!``8```#VHP$`$0```/VC`0`*````
M#Z0!``L````:I`$`#0```":D`0`C````-*0!`!,```!8I`$`%@```&RD`0`/
M````@Z0!`!````"3I`$`#0```*2D`0`7````LJ0!`"P```#*I`$`*P```/>D
M`0`K````(Z4!`"H```!/I0$`-@```'JE`0`U````L:4!`!P```#GI0$`40``
M``2F`0`5````5J8!`!0```!LI@$`%@```(&F`0`5````F*8!`!8```"NI@$`
M%@```,6F`0`5````W*8!`!4```#RI@$`%`````BG`0`S````':<!`!@```!1
MIP$`&````&JG`0`[````@Z<!`!(```"_IP$`"````-*G`0`4````VZ<!`",`
M``#PIP$`%````!2H`0`4````*:@!`!,````^J`$`&0```%*H`0`6````;*@!
M`!8```"#J`$`&P```)JH`0`9````MJ@!`!0```#0J`$`'P```.6H`0`B````
M!:D!`!4````HJ0$`%0```#ZI`0`7````5*D!`!4```!LJ0$`&@```(*I`0`=
M````G:D!`!L```"[J0$`&````->I`0`(````\*D!`!````#YJ0$`&`````JJ
M`0`$````(ZH!``8````HJ@$`"P```"^J`0`4````.ZH!``8```!0J@$`"@``
M`%>J`0`&````8JH!``<```!IJ@$`!P```'&J`0`&````>:H!``4```"`J@$`
M%P```(:J`0`&````GJH!``D```"EJ@$`!````*^J`0`$````M*H!``D```"Y
MJ@$`"@```,.J`0`)````SJH!`!````#8J@$`$0```.FJ`0`*````^ZH!`!4`
M```&JP$`!0```!RK`0`U````(JL!``\```!8JP$`$@```&BK`0`<````>ZL!
M``X```"8JP$`#````*>K`0`.````M*L!`$D```##JP$`!@````VL`0`(````
M%*P!`"$````=K`$`#@```#^L`0`3````3JP!``8```!BK`$`"P```&FL`0`)
M````=:P!``<```!_K`$`!````(>L`0`-````C*P!`!<```":K`$`#P```+*L
M`0`6````PJP!`!0```#9K`$`&P```.ZL`0`:````"JT!``@````EK0$`!@``
M`"ZM`0`&````-:T!`!T````\K0$`!P```%JM`0`%````8JT!`!$```!HK0$`
M"P```'JM`0`'````AJT!``4```".K0$`!P```)2M`0`&````G*T!``T```"C
MK0$`"@```+&M`0`.````O*T!`!,```#+K0$`%0```-^M`0`4````]:T!`!L`
M```*K@$`$P```":N`0`5````.JX!``@```!0K@$`!````%FN`0`(````7JX!
M`!(```!GK@$`$@```'JN`0`)````C:X!``D```"7K@$`&0```*&N`0`3````
MNZX!``4```#/K@$`$0```-6N`0`E````YZX!`!0````-KP$`%@```"*O`0`1
M````.:\!``T```!+KP$`#````%FO`0`)````9J\!``\```!PKP$`#@```("O
M`0`0````CZ\!`!````"@KP$`,````+&O`0`P````XJ\!`"P````3L`$`"0``
M`$"P`0`'````2K`!``<```!2L`$`$````%JP`0`0````:[`!``,```!\L`$`
M"````("P`0`@````B;`!``@```"JL`$`"````+.P`0`/````O+`!`&D```#,
ML`$`&0```#:Q`0`+````4+$!``4```!<L0$`!P```&*Q`0`:````:K$!`!H`
M``"%L0$`$P```*"Q`0`)````M+$!``(```"^L0$`!````,&Q`0`D````QK$!
M``<```#KL0$`!0```/.Q`0`O````^;$!``H````IL@$`!0```#2R`0`'````
M.K(!`!4```!"L@$`$````%BR`0`&````:;(!``@```!PL@$`"0```'FR`0`$
M````@[(!``4```"(L@$`=````(ZR`0`+`````[,!``X````/LP$`&````!ZS
M`0`$````-[,!``P````\LP$`)@```$FS`0`U````<+,!``X```"FLP$`"@``
M`+6S`0`2````P+,!``L```#3LP$`"0```-^S`0`9````Z;,!`"@````#M`$`
M*0```"RT`0`H````5K0!`"````!_M`$`#@```*"T`0`#````K[0!``X```"S
MM`$`!P```,*T`0`*````RK0!``H```#5M`$`%````."T`0`)````];0!`%H`
M``#_M`$`'````%JU`0`.````=[4!``P```"&M0$`&P```).U`0!,````K[4!
M`!T```#\M0$`!P```!JV`0`D````(K8!`#````!'M@$`"````'BV`0`&````
M@;8!`"(```"(M@$`!0```*NV`0`'````L;8!`"D```"YM@$`*````..V`0`T
M````#+<!``@```!!MP$`#0```$JW`0`>````6+<!`&(```!WMP$`&````-JW
M`0`6````\[<!`!4````*N`$``@```""X`0`,````([@!``4````PN`$`#@``
M`#:X`0`.````1;@!``<```!4N`$`#P```%RX`0`&````;+@!``@```!SN`$`
M#@```'RX`0`)````B[@!``H```"5N`$`"@```*"X`0`W````J[@!``<```#C
MN`$`$@```.NX`0`3````_K@!`!X````2N0$`$@```#&Y`0`*````1+D!``H`
M``!/N0$`"P```%JY`0`)````9KD!``H```!PN0$`"0```'NY`0`(````A;D!
M`!\```".N0$`$0```*ZY`0`/````P+D!``H```#0N0$`"@```-NY`0`+````
MYKD!`!$```#RN0$`!0````2Z`0`9````"KH!``0````DN@$`!P```"FZ`0`%
M````,;H!``4````WN@$`"P```#VZ`0`8````2;H!`!(```!BN@$`&0```'6Z
M`0`;````C[H!`"(```"KN@$`%@```,ZZ`0`7````Y;H!`!(```#]N@$`%@``
M`!"[`0`(````)[L!``,````PNP$`#0```#2[`0`.````0KL!``<```!1NP$`
M'0```%F[`0`*````=[L!``X```""NP$`)@```)&[`0`K````N+L!`!8```#D
MNP$`"P```/N[`0`+````![P!``8````3O`$`$````!J\`0`5````*[P!``<`
M``!!O`$`"0```$F\`0`%````4[P!``<```!9O`$`!@```&&\`0`$````:+P!
M``0```!MO`$`0````'*\`0`Z````L[P!`!0```#NO`$`,P````.]`0`[````
M-[T!`!$```!SO0$`3````(6]`0`Z````TKT!`$L````-O@$`2P```%F^`0!1
M````I;X!`!<```#WO@$`&0````^_`0`7````*;\!`!4```!!OP$`'0```%>_
M`0`3````=;\!`!H```")OP$`%````*2_`0`7````N;\!`!P```#1OP$`-P``
M`.Z_`0`W````)L`!`#L```!>P`$`.````)K``0`Y````T\`!`#8````-P0$`
M=0```$3!`0`C````NL$!`"D```#>P0$`#`````C"`0`<````%<(!``P````R
MP@$`%````#_"`0`T````5,(!`"P```")P@$`,````+;"`0`+````Y\(!`%P`
M``#SP@$`5@```%##`0`%````I\,!`!D```"MPP$`%@```,?#`0`,````WL,!
M`!0```#KPP$`$@````#$`0`(````$\0!``H````<Q`$`"0```"?$`0`0````
M,<0!``\```!"Q`$`%````%+$`0`0````9\0!`!(```!XQ`$`!P```(O$`0`E
M````D\0!``@```"YQ`$`!````,+$`0`2````Q\0!`!(```#:Q`$`$0```.W$
M`0`O````_\0!``(````OQ0$`!@```#+%`0`/````.<4!``D```!)Q0$`!P``
M`%/%`0`<````6\4!``0```!XQ0$`.P```'W%`0`.````N<4!`!@```#(Q0$`
M!````.'%`0`-````YL4!`"\```#TQ0$`&0```"3&`0`@````/L8!`%X```!?
MQ@$`%P```+[&`0!'````UL8!`"D````>QP$`#0```$C'`0`-````5L<!`!0`
M``!DQP$`$0```'G'`0`,````B\<!`!8```"8QP$`#````*_'`0`=````O,<!
M`!8```#:QP$`"````/''`0`4````^L<!``X````/R`$`*@```![(`0`2````
M2<@!`!D```!<R`$`&````';(`0`:````C\@!`"L```"JR`$`"````-;(`0`)
M````W\@!`!D```#IR`$`$0````/)`0`3````%<D!`!(````IR0$`&0```#S)
M`0`1````5LD!`!0```!HR0$`&P```'W)`0`*````F<D!``P```"DR0$`"```
M`+')`0`%````NLD!`"$```#`R0$`!@```.+)`0`/````Z<D!``@```#YR0$`
M$0````+*`0`(````%,H!`!X````=R@$`$0```#S*`0`Y````3LH!`!@```"(
MR@$`"0```*'*`0`*````J\H!`"(```"VR@$`"````-G*`0`?````XLH!``0`
M```"RP$`'`````?+`0`(````),L!``<````MRP$`'````#7+`0`P````4LL!
M``8```"#RP$`(````(K+`0`2````J\L!``8```"^RP$`$````,7+`0`3````
MULL!``0```#JRP$`"0```._+`0`+````^<L!``<````%S`$`!0````W,`0`(
M````$\P!``4````<S`$`"P```"+,`0`?````+LP!`#X```!.S`$`3````(W,
M`0`G````VLP!`#8````"S0$`)P```#G-`0!5````8<T!`"<```"WS0$`-P``
M`-_-`0`W````%\X!`(L```!/S@$`*````-O.`0`%````!,\!``<````*SP$`
M"````!+/`0`(````&\\!`!L````DSP$`'0```$#/`0`J````7L\!`"H```")
MSP$`)@```+3/`0!`````V\\!`$8````<T`$`"0```&/0`0`7````;=`!``L`
M``"%T`$`"````)'0`0`X````FM`!`!8```#3T`$`$````.K0`0`2````^]`!
M``@````.T0$`$P```!?1`0`(````*]$!``T````TT0$`%@```$+1`0`G````
M6=$!`"@```"!T0$`0P```*K1`0`+````[M$!`!T```#ZT0$`!0```!C2`0`'
M````'M(!`!@````FT@$`(P```#_2`0`,````8](!``4```!PT@$`"@```';2
M`0`,````@=(!``P```".T@$`"P```)O2`0`:````I](!``H```#"T@$`"@``
M`,W2`0`%````V-(!`!$```#>T@$`20```/#2`0!=````.M,!`!X```"8TP$`
M#````+?3`0`F````Q-,!`!P```#KTP$`$@````C4`0`3````&]0!``T````O
MU`$`"P```#W4`0`0````2=0!`"T```!:U`$`"0```(C4`0`-````DM0!``X`
M``"@U`$`%@```*_4`0`,````QM0!`#X```#3U`$`"````!+5`0`I````&]4!
M`!````!%U0$`%````%;5`0!%````:]4!`#,```"QU0$`-P```.75`0`T````
M'=8!`#````!2U@$`$````(/6`0`,````E-8!`!4```"AU@$`'@```+?6`0`7
M````UM8!``H```#NU@$`%P```/G6`0`>````$=<!``<````PUP$`&@```#C7
M`0`<````4]<!``8```!PUP$`!@```'?7`0`2````?M<!``P```"1UP$`%P``
M`)[7`0`%````MM<!``@```"\UP$`#@```,77`0`1````U-<!`!(```#FUP$`
M$P```/G7`0`3````#=@!``<````AV`$`!@```"G8`0`H````,-@!`!L```!9
MV`$`&@```'78`0`'````D-@!`!4```"8V`$`!@```*[8`0`C````M=@!`",`
M``#9V`$`*P```/W8`0`+````*=D!``D````UV0$`(P```#_9`0`#````8]D!
M``8```!GV0$`"@```&[9`0`"````>=D!``P```!\V0$`%0```(G9`0`+````
MG]D!`!D```"KV0$`(````,79`0`7````YMD!``4```#^V0$`"@````3:`0`5
M````#]H!`!(````EV@$`#0```#C:`0`)````1MH!``X```!0V@$`#````%_:
M`0`7````;-H!`%@```"$V@$`'0```-W:`0`T````^]H!`!0````PVP$`#```
M`$7;`0`%````4ML!``T```!8VP$`$0```&;;`0`/````>-L!`"````"(VP$`
M&````*G;`0`0````PML!`"(```#3VP$`#@```/;;`0`F````!=P!`!`````L
MW`$`$````#W<`0"1````3MP!`"(```#@W`$`'`````/=`0`Q````(-T!`"``
M``!2W0$`&@```'/=`0`L````CMT!`!H```"[W0$`(P```-;=`0`9````^MT!
M``\````4W@$`!P```"3>`0`(````+-X!``D````UW@$`%@```#_>`0`,````
M5MX!`"H```!CW@$`$@```([>`0`6````H=X!``D```"XW@$`#````,+>`0![
M````S]X!`%0```!+WP$`10```*#?`0!P````YM\!``T```!7X`$`)0```&7@
M`0`L````B^`!``H```"XX`$`!P```,/@`0`5````R^`!`$(```#AX`$`!@``
M`"3A`0!4````*^$!`#````"`X0$`(@```+'A`0`2````U.$!`"4```#GX0$`
M*@````WB`0`O````..(!`"D```!HX@$`+P```)+B`0`E````PN(!`!4```#H
MX@$`!P```/[B`0`,````!N,!``X````3XP$`%P```"+C`0`+````.N,!`#T`
M``!&XP$`#````(3C`0`,````D>,!``@```">XP$`$P```*?C`0`(````N^,!
M``4```#$XP$`'0```,KC`0`(````Z.,!``D```#QXP$`!@```/OC`0`-````
M`N0!``T````0Y`$`$@```![D`0`4````,>0!``P```!&Y`$`&````%/D`0`-
M````;.0!``@```!ZY`$`$0```(/D`0`>````E>0!`!````"TY`$`"0```,7D
M`0`:````S^0!`"P```#JY`$`$P```!?E`0`M````*^4!`"T```!9Y0$`#0``
M`(?E`0`'````E>4!``@```"=Y0$`!P```*;E`0`$````KN4!`!4```"SY0$`
M#````,GE`0`-````UN4!``P```#DY0$`!0```/'E`0`)````]^4!``@````!
MY@$`"0````KF`0`)````%.8!`!@````>Y@$`!@```#?F`0`.````/N8!``8`
M``!-Y@$`#P```%3F`0`,````9.8!`"````!QY@$`"@```)+F`0`"````G>8!
M`"4```"@Y@$`!P```,;F`0`*````SN8!`(H```#9Y@$`#````&3G`0`&````
M<><!`",```!XYP$`-````)SG`0`@````T><!`"````#RYP$`5P```!/H`0`Q
M````:^@!`#0```"=Z`$`(P```-+H`0`@````]N@!``4````7Z0$`#P```!WI
M`0`-````+>D!``\````[Z0$`!@```$OI`0`-````4ND!`!,```!@Z0$`#P``
M`'3I`0`/````A.D!`!$```"4Z0$`#````*;I`0`'````L^D!``<```"[Z0$`
M"````,/I`0`6````S.D!``D```#CZ0$`"````.WI`0`'````]ND!`!P```#^
MZ0$`'0```!OJ`0`9````.>H!``@```!3Z@$`$P```%SJ`0`(````<.H!``T`
M``!YZ@$`"0```(?J`0`5````D>H!``<```"GZ@$`%0```*_J`0`&````Q>H!
M`!L```#,Z@$`#0```.CJ`0`<````]NH!``4````3ZP$`"````!GK`0`-````
M(NL!`!\````PZP$`"@```%#K`0`,````6^L!`"D```!HZP$`'````)+K`0`2
M````K^L!``0```#"ZP$`"````,?K`0`+````T.L!``D```#<ZP$``@```.;K
M`0`6````Z>L!``@`````[`$`)@````GL`0`F````,.P!`#X```!7[`$`+P``
M`);L`0`T````QNP!`#H```#[[`$`;P```#;M`0`)````INT!`&P```"P[0$`
M.P```!WN`0!3````6>X!`'(```"M[@$`*0```"#O`0!'````2N\!`"\```"2
M[P$`,0```,+O`0`?````].\!`#X````4\`$`Z`$``%/P`0`B````//(!``D`
M``!?\@$`20```&GR`0"H````L_(!`"L```!<\P$`-0```(CS`0!#````OO,!
M`'8````"]`$`2````'GT`0!"````PO0!`!0````%]0$`"@```!KU`0`]````
M)?4!`!\```!C]0$`(@```(/U`0`P````IO4!`"H```#7]0$`*0````+V`0!0
M````+/8!`!(```!]]@$`"````)#V`0!(````F?8!`#<```#B]@$`*@```!KW
M`0`G````1?<!`"8```!M]P$`*P```)3W`0!H````P/<!`$,````I^`$`1@``
M`&WX`0!"````M/@!`#L```#W^`$`4````#/Y`0!M````A/D!`%@```#R^0$`
M00```$OZ`0`]````C?H!`$````#+^@$`9@````S[`0!X````<_L!`'````#L
M^P$`<````%W\`0`X````SOP!`"X````'_0$`+@```#;]`0`P````9?T!`(,`
M``"6_0$`>````!K^`0!_````D_X!`-4````3_P$`&@```.G_`0`L````!``"
M`#8````Q``(`*P```&@``@!8````E``"`"T```#M``(`5P```!L!`@`J````
M<P$"``P```">`0(`P````*L!`@!=````;`("`",```#*`@(`.````.X"`@`G
M````)P,"`"````!/`P(`0P```'`#`@`&````M`,"``<```"[`P(`!````,,#
M`@`-````R`,"``H```#6`P(`"P```.$#`@`+````[0,"``4```#Y`P(`$```
M`/\#`@`"````$`0"`%\````3!`(`!0```',$`@`<````>00"``0```"6!`(`
M!P```)L$`@`&````HP0"``4```"J!`(`.@```+`$`@`$````ZP0"`!<```#P
M!`(`#0````@%`@`3````%@4"`!`````J!0(``@```#L%`@`(````/@4"``8`
M``!'!0(`%0```$X%`@`,````9`4"`!<```!Q!0(`!@```(D%`@`.````D`4"
M``H```"?!0(`"````*H%`@`N````LP4"``@```#B!0(`!@```.L%`@`'````
M\@4"`#@```#Z!0(`7````#,&`@!(````D`8"`$D```#9!@(`,@```",'`@`P
M````5@<"`#,```"'!P(`.````+L'`@`O````]`<"`"H````D"`(`-@```$\(
M`@`Q````A@@"`"L```"X"`(`-@```.0(`@`M````&PD"`"T```!)"0(`0@``
M`'<)`@`D````N@D"`#\```#?"0(`.@```!\*`@`Q````6@H"`#4```","@(`
M,````,(*`@`K````\PH"`#8````?"P(`,@```%8+`@`V````B0L"`#4```#`
M"P(`*P```/8+`@`M````(@P"`#````!0#`(`.P```($,`@`K````O0P"`"@`
M``#I#`(`1@```!(-`@!"````60T"`"<```"<#0(`-````,0-`@!/````^0T"
M`#(```!)#@(`-@```'P.`@`Q````LPX"`#(```#E#@(`+````!@/`@`I````
M10\"`"X```!O#P(`1P```)X/`@`S````Y@\"`$8````:$`(`+P```&$0`@!@
M````D1`"``T```#R$`(`'``````1`@`B````'1$"`$$```!`$0(`)0```((1
M`@`0````J!$"``\```"Y$0(`'````,D1`@`6````YA$"`!(```#]$0(`)```
M`!`2`@`)````-1("``D````_$@(`)0```$D2`@`H````;Q("`"<```"8$@(`
M)P```,`2`@`D````Z!("``D````-$P(``P$``!<3`@`2````&Q0"`!T````N
M%`(`#@```$P4`@`0````6Q0"`!8```!L%`(`&````(,4`@`?````G!0"``D`
M``"\%`(`3@```,84`@`:````%14"`!,````P%0(`!P```$05`@`5````3!4"
M``P```!B%0(`60```&\5`@`(````R14"`"D```#2%0(`$@```/P5`@`5````
M#Q8"`!4````E%@(`/@```#L6`@`<````>A8"``P```"7%@(`*````*06`@`-
M````S18"``X```#;%@(`%0```.H6`@`*`````!<"`"0````+%P(`"P```#`7
M`@`9````/!<"``H```!6%P(`'0```&$7`@`M````?Q<"``4```"M%P(`)P``
M`+,7`@`'````VQ<"``<```#C%P(`"0```.L7`@!,````]1<"``<```!"&`(`
M$0```$H8`@`+````7!@"`!<```!H&`(`"0```(`8`@`)````BA@"``<```"4
M&`(`%@```)P8`@`+````LQ@"`!X```"_&`(`#P```-X8`@`8````[A@"`!P`
M```'&0(`!0```"09`@`'````*AD"`!D````R&0(`!P```$P9`@`Q````5!D"
M``T```"&&0(`$0```)09`@`'````IAD"``(```"N&0(`$````+$9`@`/````
MPAD"``L```#2&0(``P```-X9`@`'````XAD"``L```#J&0(`"@```/89`@`1
M`````1H"``X````3&@(`&P```"(:`@`<````/AH"``H```!;&@(`-@```&8:
M`@`D````G1H"`"H```#"&@(`%P```.T:`@`-````!1L"`#X````3&P(`!@``
M`%(;`@`7````61L"`$````!Q&P(`#@```+(;`@`'````P1L"``<```#)&P(`
M!````-$;`@`$````UAL"``D```#;&P(`'@```.4;`@`%````!!P"``8````*
M'`(`"````!$<`@`,````&AP"``8````G'`(`%````"X<`@`4````0QP"`$``
M``!8'`(`-````)D<`@`N````SAP"``P```#]'`(`'@````H=`@`A````*1T"
M`"\```!+'0(`*0```'L=`@`4````I1T"``(```"Z'0(`!````+T=`@`,````
MPAT"``@```#/'0(`!0```-@=`@`"````WAT"`!$```#A'0(`80```/,=`@`N
M````51X"`!H```"$'@(`.@```)\>`@`Q````VAX"`%X````,'P(`%@```&L?
M`@!]````@A\"`"D`````(`(`5@```"H@`@`I````@2`"`$````"K(`(`/@``
M`.P@`@`U````*R$"`$P```!A(0(`-0```*XA`@`W````Y"$"`#D````<(@(`
M'P```%8B`@`N````=B("`#(```"E(@(`0````-@B`@`3````&2,"`!(````M
M(P(`#````$`C`@")````32,"``@```#7(P(`Q@```.`C`@!Q````IR0"`(L`
M```9)0(`+0```*4E`@!E````TR4"`!<````Y)@(`)@```%$F`@`7````>"8"
M`!<```"0)@(`&@```*@F`@`D````PR8"`$,```#H)@(`)@```"PG`@`@````
M4R<"`'<```!T)P(`'````.PG`@`,````"2@"``L````6*`(`!0```"(H`@`&
M````*"@"``@````O*`(`!0```#@H`@`6````/B@"`!````!5*`(`%0```&8H
M`@`@````?"@"`!$```"=*`(`#P```*\H`@`-````OR@"``D```#-*`(`#@``
M`-<H`@`(````YB@"`!4```#O*`(`"0````4I`@`)````#RD"`!,````9*0(`
M#@```"TI`@`'````/"D"`!(```!$*0(`#@```%<I`@`9````9BD"``D```"`
M*0(`"@```(HI`@`2````E2D"``@```"H*0(`"0```+$I`@`I````NRD"`"(`
M``#E*0(`$`````@J`@`E````&2H"`!0````_*@(`&P```%0J`@`1````<"H"
M``H```""*@(`%@```(TJ`@`'````I"H"``4```"L*@(`%0```+(J`@`$````
MR"H"``(```#-*@(``@```-`J`@`2````TRH"``8```#F*@(`!@```.TJ`@`2
M````]"H"`!<````'*P(`!P```!\K`@`Z````)RL"``(```!B*P(`!````&4K
M`@`3````:BL"`!@```!^*P(`"@```)<K`@`'````HBL"`!(```"J*P(`!0``
M`+TK`@`9````PRL"``@```#=*P(`%P```.8K`@`5````_BL"`!,````4+`(`
M`@```"@L`@`.````*RP"``P````Z+`(`#0```$<L`@`6````52P"`#H```!L
M+`(`!P```*<L`@`)````KRP"`!$```"Y+`(`!0```,LL`@`"````T2P"``L`
M``#4+`(``0```%\'```P````+P8``"`%````````P`0``*X&```>````````
M`!@'``#H`0``S@0``)0%```M`@```````)<!``"S!0``````````````````
M;@0``&$"```I!```S``````````@`P``G`0````````A`````````-L"````
M````H0(``'L!``"B`P``*@``````````````FP0```````#6`0``908``&L!
M```?`0``E@,```````#'`P``G@(``&P!``"%!P``*````"@"``""`0``_0,`
M``````!]!P```````$<"```W!0`````````````?!P````````````#!`P``
M100```````!X!```30```.H&``!'`0``7@$``$X&```\`@``M@(``*<"````
M````4P$``$T"````````'P(``'L'``"%`@``J`(````````<`0``@`0`````
M```.`0``0@``````````````)@4```````#-````_0(``#,```!A!@``U@,`
M`*<$``"7!0``80$`````````````>P0``.T"```!!```;`(````````)!P``
M`````.$!`````````````'$```##`0```````*T&``!X`P````````````!Q
M!0```````#4$``!K!@``Q@```)`!```2!```]@,``$X!``!W`@``5@(`````
M```Q``````````````"F``````````T!``#-!@``!````'8%``!^!@``````
M`*L&``#O!@```````"`$```````````````````T````ZP0``+L%``"Q!0``
MTP```"<````=!````````%X$``#K`@``8P0``+@#````````UP(`````````
M````U`,```<$``````````````````#,!@``,@(```````#:`P``^0$`````
M``#[`@``&@(````````0!P```````',"``!6````^`,``,0#``"W!0``P04`
M`+L!``#@!```E04``&D$``#6!0``4@<```````!W`0``"@```%@'````````
M70$``,X!``!+````[08``(0!``#``P``V`$```````"*!@```````-`$``!?
M`0``P@```+X&````````PP4``&<&``!B````^0,``$\!```L`@``+`0``'8&
M``!G!0``70```&\#``!4!0```````+,!```$!P``Z@0`````````````````
M`#,&````````````````````````(@,``,,#``">````Q@(``.$#````````
M`````)0&```'`P``OP```(L"````````M04```````#@!@``'0,``!(#``!R
M!P```````+@&````````AP```,8!``"S!@``\00``)`#````````=@$``#$$
M``!6!0`````````````C!0``H@```!H$````````7@(``#T#``#5!0``HP(`
M``````">`P``:@0```P%``#>!@```````"`````J!```S`$``$P&``"Z!```
M)08``$<'``"T!```@`,```````"5`P``TP(``%\#```^`P``V0$``)H!````
M````?`8```````!P````Y`4`````````````]08```````"/`0``#P,``.8%
M``#@`P``3`<``)P%``!Y!```^@```&0!``!%!@```````"$$```T!0``C@``
M`"0&````````N`(``$\&````````W@```$@'``"\`0``BP$``'$'``#T`P``
M/@0``"<$```C`0``:0```+4````2`````````*L%````````M`(``'(```#W
M`0``?0````(&```1!P``BP`````````!`P``E````,X"````````G0$``"$'
M``"]`P``=P8``%`'``!S!@````````````"M`P``@@4`````````````````
M`#T"``!J`0``5`<``(("``"N`0``FP8``!X"```Q`0``.@8``*$%````````
M`````!T!``!0````O`8``/<&``"N!`````````````#+`````````)D#````
M````X@8``-\```#.!@``XP```/@````T`0```@$``#($``!*````J@,``'\!
M````````\P``````````````W`4``$\```!G!P``1`<``'(!``"C!```I```
M`#('``"(!0``P`$``&T'````````KP$````````%!@```````"\```#\`@``
M`````'0!````````X`$`````````````XP(````````+!@``$0$``!('``#A
M!```6P```/X!```C!```#P````D%``"0````)04`````````````#`0``%L&
M``!+!@``C08```````!6`0```````.(%```I!0``EP0``/\%``#2````````
M``````![!@```````!(!```X`@``^`8``,(!``!3`@``^`4``,T%``"0!P``
MH0``````````````L`,``*P&``"3!0``I`,``+X%``!I!@```````.\#````
M````@P8``-("``!O````!@$``$(#```=!P``D@8``````````````````#@#
M``",````0P$``$X```!?!0``30$```````!8!````````-@"``"Q````80,`
M`#\$``!&`0``P08``%P'``#=````GP0````````D````#`$``(0#``#H!```
MA`8``#H!``"T!0``$0```!8$``#>!````````#4!``#0`0``NP(````````Y
M````Q00`````````````%`0```T'``!.!P``50<``+\#```N`@```````"<#
M``!J`@``H`0``-L#```B`@```````,8%``#D````"P,``'D!``#*!@``;`8`
M``````#R`P``4@0``.4"```Z`P``10$``.@```#*!````````$\"``!U`P``
M`````(($````````60(``(\$``#B``````````````"2!0``HP,``#\%``"G
M!0``O@$``/X%````````O@,``"T#``!(!@``W04``),"``!B!P``!`(``#(&
M```*`P``*P4``*X"``!0`@``!P8``#,'``#@!0``-@8```````!T````D@0`
M`/8!``````````(`````````````_@```-@&``#O````/04``(P$``!Q`P``
M<`8`````````````]P```&,"```7`0``1`$``(@$````````O00``#8````L
M`P``_@0``$\%````````0P4``%P#``"#`P``V08``!H%```_`0``;`0``!8'
M`````````````(`'````````<P<``.@"````````]@```#\"``!0!```*@$`
M`)$#```)!```[`(``,<&``#5`0``#`(``(<%```N!```!`0``.($``#N!@``
M``````````!]`P````````$!```>!0``B0,```4$``#1`@``.`8``$X#``#?
M`P``4P```',$```)`P``(P,``.D&`````````````&X#``"2`P```````%,%
M````````5````#T&``!O`@``)`,```````"=`@``(@<````````3!P``?`$`
M`%@```#D!@``>P```"H%``!K!```R@(`````````````HP8``)T```!7`0``
M`````(D%```4!0``=08```8#```E`@``.````%P%````````+0```(\'```F
M`@```````"8!``!H`````````.4#``!5````,P4``"@!````````````````
M``!+!````````!`%``#Y!0```````'`%```U!0````````````!%````````
M`(D$```[!P``\0,``%T&```9!``````````````M!P```````(H```"V````
MX`````````!X!@````````````!I!0``"P$````````1`@``````````````
M````ZP$``)L```#3`P``XP,`````````````L0(``&D"``"6!````````$`'
M````````800``!D#````````"@<``-P`````````V`0``/L$````````6@(`
M``````!H!```A00``-`&``#/!0``M````"L$````````BP,``&H'``"W````
M[0```+(%```&!@``&@````````!,````<@0``,T$``#%`P``6@,````````V
M`@````````````"G`0```@````````"K!```````````````````YP,``%D%
M```J`P``3P,``"4'``#>`0````4``/4%``!'`P``8`````````"P!@``%@``
M```````````````````````\````_````*T$```Y!```U0(``,$"``#S!@``
M'@,``(T```"E`P``3@(```````!F!0```````%L#``#:!0```````(,"````
M````4@,``/0&``"N`P``U0```-$`````````Y@8``(,```#;!```#00``&("
M```D!0``90<``.T$``#X!```5P(``#$&``#&!@``7P0``,D!``!Q!@``````
M`$@$````````A````*($```#`@``M08``%@#``"]````E0$``*(&````````
M````````````````A0```(<&``!0`0``````````````````_@(```````"*
M`0``X@,````````Z!0``\0(``!,!``"(`0``'@8```````"R````&P8``&T!
M``"#`0```````)8```#G!```/@$``'X!``"/`@``R`(``+\$``!:!P``````
M`$P"```1!@``S0,``#8#```+`@``.`4``'H%``#.`P``?`<``$P$``!M!0``
MY0$````````N`0``4@$``%,$``#;`0``I@,```4!``#.!0```````%H!``#4
M!0``@0,``+4#``#:````M`$``$,$```U`@``600```X%````````2P4``$8#
M``"H`0``F00``!\```"B`@````````H%````````Q0$``%T'``"?`0``_P8`
M```````A!0``\@$``',!````````O`4``'0%``#:`@``!`8```````#=`0``
M`````/P#`````````````#`$``!D````````````````````````````````
M````QP(``/\#```;`@``V`,``!@$``!F`@```````+\"`````````````&L#
M````````R0```!8"``!H!P``EP,``$<%``!6`P``/@``````````````(P8`
M``````#(!0``:`8``)D!``````````````<'``!\`@```````+4!``"X````
M`````$X$``"+!```?P```*\%``#/`0```````/L#``"8!@``6`4``#P'``"'
M!P``*`,``!4```",`P``/00``#\'``!@`@```````"P'````````````````
M``"Y!@``^00``",'``"8````*`0`````````````5P8``-<&``##!```MP8`
M`*(!```,````"`$``#0&``!%!P``WP4``)L"````````R00``.H#``"V`0``
M!`4```````!U!P```````'8#``!_!```"`4``$T&``#,!```_0````````!7
M!P``X0(``!\&``!``P``L08```````#:!@``!P4``.0$````````-0````@#
M``!5`@```````'@!```F!@````````L$``#7`0```````*D&``"-`P``00$`
M`,D#``!$!0``D`8``````````````````($`````````A@```!H&``!\`P``
M`````/,$``#"`P```````(D&````````,`(``+(&``"3````4@8``*$#``!0
M!0```````%<```#B`0``F@0``),#``!:!0```````'8"``!Z`P``$`8``!D!
M````````H````(T$`````````````'X'``!#!@``"P4``*(%``!"!P``````
M`$D&``!C!@``````````````````KP,``#L```")!P``C@,``)8%``"!`@``
M`````!$$````````=`(``%T%``#?!@``I`8``+,`````````$P(``*`!````
M````#P(``)\"````````%0$````````<!P``6@0``$P!``#?`@```P4`````
M```9!P``;@(```````#F!```-P8``%D#``!&!P``Y@,`````````````XP4`
M`!P$``!R!@``K0```!0"``"H!````````+4"````````TP4``*L!``"Y`@``
MZP8``'<#``!@`0``[0$``*@%```@`@````````````#F`@``)00`````````
M````BP8``"@'`````````````/8%``!G`@```````,T!``!R`@``*0(``/0!
M``#"`@``)0$``!L%```5!@``.P8``%H```!>````=P4``.,!``#_`@``.P$`
M`/T$```B!```````````````````Y@$``-X"```3!```K04``*8!```'`@``
MA0,``)("``!J`P```````%<$``#J````P````'@%````````T00````&``";
M`0````````````!O`0``&08``#X%``"9`@````````````"X!0``GP,``#0"
M``"S!````````(4%``"=!@``30<```$"``"`````'P4``,L!```"!P``;P8`
M`,H#``"`!@``&`$``.X!````````8P$``+8%``#U````%P,```````!X`@``
M`````&D!``!>`P```````(X'```O`P```````"8#``#,`@``<`,```````"?
M`````````````````````````+($``"X`0``N00``-`"````````40<``#T'
M``#Z`P```````-H$```P`P``'`,``(@#``#7`P``.0<```````#2!0``^0(`
M`%$`````````V@$```````!C````W`0```T"`````````````)<"``"1````
M^P8````````L!@```````,\"``"K`P``\P(``&8'``#;`````````&X'``#$
M!@```````%$$``!"!@```````/("```I````B@(```````!#!P```````'T!
M```2!0``6@8``#,"`````````````.("``"[!````````.<"``#/````#0``
M`/``````````;00``-$%````````V````.0!``")`0``.P4``,D"``":!0``
M>0,```````#C!@``8P4``"@&````````5`$``.P`````````%04`````````
M````<`$``!("````````I08`````````````Q`0``&,'``"&`@``$P8``$\'
M``#5!@``00<```````"6`0``TP0```````":`P```````-(!``"/!@``NP``
M`*0"``#X`@``104``$8$```$`0``40(``&$'````````)`$``)P!``#9`P``
M"@0``+H"``#&`P```````'0&``#/!@``UP0``/`&````````(@4``.H%``"I
M````.`$```,&```<!@```````#4'```)`0``Z0$``"T!``"V!@``````````
M``"K`@``RP,``/\$````````,`$``$H"``"F!0``'````!<"``"O`@``-@0`
M`'0$``"0!```U`$``-\$``#I`P``+P(``&4````Q!0``+@4``+T!``":!@``
M4P8``"0"```C`@``0`4``.X$```!!P````<``!````!B!````````$H#``!8
M!@``2@<``%4&`````````````(0"``"Q`0``-`,````````B!@``&P<`````
M````````O@```%4%````````@08``.X%``#J`@``KP8```````#E!@``&`(`
M`%8$``"E!`````````````#\`0``E`(``-(&```;````=@```+<#````````
M[`$``/<$``#S`P``Y0````````"C````T@,``+("``"=`P``F08`````````
M````8@4``.T#``!=`P``8`0``/T%```G!0``*P<``*<&``"I!`````,``*8"
M````````MP(```,!``!@`P``!0,``/0$``#7!0`````````````"!```F`(`
M`&@!``!_!@``20<```4%``#'`0``R@$`````````````Y00```````!E!0``
M`````,,&``!^`@``P@0``.X"```U`P``?`0``.0#``!N`0```````-T$``#N
M`P``^P$``,(%``#P!0``"0````````",!P``F04``,8$`````````````&4"
M``!N````60`````````#````1@4```8'````````_@8``,4```#%`@``````
M`)P&````````>@(````````_`P``````````````````PP(``*0!``"/````
M304``#P%```V!P``"@8``&L"```G`@``4@4```````"_!0```P,```````#<
M`P``*0<``#@'``".`@``C0$``/4$``"6!@``&P$```````#?`0``C04`````
M``"E````9`8``!T%``")`@```````/$%````````'0```"`&````````MP$`
M`*`&``"/!0````````````"8`P``#08``#$"``"5`````````'H!``!"`0``
M`````!8&````````804``&L%``#*!0``Z`8``(T'````````\@4``.P$``"^
M!```^08``+H%````````20$``%0"```]`0```````-P"````````20(``$`&
M``#I!0```````(P&``#F````Q`(```$&````````F`4``$@```#S!0``0P,`
M``````````````````````"2````/@<``&T"``"3!@``/`$``.H!``"-`@``
M`````%P```"(````)`<``+T%``#G`0``J@(``/0````W`0``'@<``&\'``".
M!0``5`,``,@!`````````````*D!``#(!@```````$@#``#9!0``IP``````
M``![!0``W0,``&4!````````G00```````#R`````````+4$````````^@$`
M`"H'``#`!0``C@$`````````````5`8``.$%```A`P````````````#R!```
ME`$``,4%```8!0``?P4`````````````,0<``(<"``!H!0````````<```#W
M`P``1P8````````<!0``700``,`&``````````````H"```P!@``>@0`````
M```S`P``8`8````````W`@``-P<````````7``````````````"\!```T```
M`*`%``"^`@``*0$``'`'```5!P``3P0``%(```!M!@````````L'```>!```
M30,```$%`````````````.L````5!```"`(``(8'```5`@```````(,$``"`
M`@```````(8!```/!0```````"$"``"T`P``.@<``,L$````````:0,``#0'
M``!$`@``]@0``&$`````````@`4``'L"``!)!````````',```#_`0``B@0`
M`$8&``"D!0``^@0``#D&``#A!@```````$`!``"Q`P``-P``````````````
M6P0````````E````4`8``"<'```A!@``S`4```````!G`P````````````#H
M`P``=`<``/L%````````H`(``(4&```J!@```````/\````;!````````&(&
M``#+!@``[P4`````````````H08```X#```6`P```````,T"``#>!0``+00`
M`!4#``"7!@```````)\%`````````````$8```"P!```408``#D%````````
M`````,0```"Z`0``MP0``!T"````````A@4```````"3!```U`(``+H````/
M!P```````,,````N!P````````````#7````$P,``/P&``#^`P``J````$@%
M``#<`0``.0(``,L%`````````````,\$``#,`P``L00```````#A````````
M`)`%``!L`P``;`````````!C`P``\0```+D!``!5`P```````%L!````````
M``````````"L!0``?08```4"````````404``#H"``"&!```K`````````">
M!0``00,```,$``![`P````````X$``"R`P``;P0``%<%``#1`0``&04`````
M``#/`P``L@$``'4!````````^@8`````````````!P$``&4#```K`P``````
M`&8&```*`0```````)L#``!M`P``J@0``(P"``!U!0``U0,``%\"``#Q!@``
M`````'$!``"A!```R````*@#``!<`@``^0````````#!````#@```&H%````
M````>04``!,```":````<@,````````/!@```````*<#``#R!@``$`0``#L"
M````````60$``*H&```,!@``QP```(H#```.!@``*08``%X%``!;`@``G@$`
M`(@&``!!!@``AP,``(`!```W!```;P4``'H&``"&!@```````$$$``"'!```
M)@<``!<&``"+!P```````/8"``!"!```6`$```````#P`P``Z0(````````F
M````5`0``!`#```````````````````````````````````B````_`4``&H&
M```N````OP$`````````````?0(``(<!``!J````2@4``)D`````````'P,`
M``````#Q`0``D`(``-D`````````2P(`````````````;`<``&@#``!.!0``
M1`0```T#``"5`@``J@4```````""!P``204``"0$``"N````?00``!H!``#4
M````*P8``&8#`````````````&L'``"I!0``E08``.<&```@!P``300``#`'
M``!W````2P,``-,!````````[04``#,!```"!0``%`$``#T`````````````
M````````````]@8``/0%``#)!0```````$(%``#K!0```````!<'````````
MZ00``&X%```O!`````````````#0`P``?@0``*D"````````(`$``'X%``!(
M`0``R08```P'````````U`0``$D````&````[@````````".!```7`8``$`$
M```.`@``%````*$!``!;!0``_`0``%X'``"4`P`````````!````````9`(`
M```````=!@````````````#4!@``CP,````````;`P``*`4``#\&``!D!P``
M2@8``/T!``!H`@``5@<``'8'``"H!@``"`0``'P````#!P``70(```````!P
M!````````"T&``!P`@``\P$``#H````J`@```````.0"````````````````
M````````A`<``+,"```R````+P$```````#U`@``#P$``"8$```2!@``4P,`
M`*4!````````N@8``,H```!?!@``;0```*T"````````10,```8"``!F````
M5@8``(@"````````@@,``*4"``"\`P``Z0```+`!````````"P```!0'```1
M!0``M@0``#8%``!G`0````````````#(!````````&0$``"7````]0,``#X"
M````````L````'P%````````=00``)(!````````]0$``'D'```4`P``KP``
M`!H#````````@P4``-D$```6`0``+@,``&4$```<`@``K@4``'0#````````
ME00```4````T!```#04```````!*!```!`,``'@'```E`P``<@4``#$#``"8
M!`````````````````````````````!7`P```````-8"```6!0``40,``#X&
M````````7`$```````"J`0``Z`4`````````````T0,``)8"``"K````[P0`
M`)P"``!;!P````````````"<`P``>0(``.4%``!Y!@```````*0$``#W`@``
M9P```.`"``!,`P``#`,```````!D!0``3`4``+T&``#L`P``4@(``(L%````
M`````````$`"``"[`P````0``#P$``!L!0``[`8``#D#``!B`P``T@0`````
M``!D`P``0P(``+@$``"L`P``+`````````"Y!0``\`0``/H"````````#P0`
M`*`#``#W!0``W`8````````0`@```@,``!0&``")````(@$``+D#```(!P``
M_08``)X&``#G!0````````````"C`0``+@8``!`!````````OP8``-L%````
M````9P0``/`"``!_!P``N@,```@```!&`@``%P4``$$"``!$!@``K`0``(8#
M``#P`0``2`(```````!S!0```````"T%``#5!```@0$`````````````-P,`
M`"P%``!_`@``B`<```````"1`@``W@,``!@&``#6!```)P$`````````````
MKP0``$L'````````Q`$``"\%```(!@````````````!*`0``G@0``",```#C
M!```!@0``+T"``"L`0```````+0&```R`0``1P0``)$&````````T`4`````
M`````````````!D```"4!`````````````"!!```500``"D#```A`0``[`4`
M`-8&``#K`P```````)T%``";!0``A`4``,4&````````"0(``$D#``#``@``
M7`0``%,'````````"08``%\````?!````````'<$```"`@```````,X````:
M!P``V`4```````!V!```T08```````"%`0``C`$````````K`@``.@0``$,`
M``!Z!P``!@4```````#!`0``:P```$("``#'!```NP8``-D"````````````
M```````V`0``@0<``),!``!%`@``D0$``+`%``!'````,@,``)H"``#(`P``
M608`````````````&````'$$``"\`@``4`,``%D'````````````````````
M`````````!<$``!]!0``=0(```X'````````6`(``&8!```K`0``W08``&`%
M``"J````8`<`````````````P00``"P!```K````D00```````!$`P``````
M`#L#```1`P``LP,``.\!```P!0``;@8````````\!@``,@4```4'``!Q`@``
M&0(``(P%````````G````-,&``#;!@``40$``+P```!>!@``.`0```````#6
M````B@<``/@!````````00``````````````8@$``!,%``"V`P``2P$`````
M``#T`@```````.\"```G!@``'@$`````````````D04```````"E!0``>```
M`($%``"F!@``C@8``(0$`````````````#4&``""!@```````#,$```\`P``
M&`,``$$%``!S`P``+P<``(,'``"*!0``I@0``&D'``!$`````````#\`````
M````YP```-T"``!U````?P,``,<%````````RP(``/H%````````P@8``'X`
M``"M`0```````((``````````````'D```"8`0``.P0```````!Z````L`(`
M`/L`````````GP8``*P"``!`````J0,``+D````Y`0``=P<``%4!``"C!0``
M`````'X#````````Q`4``&8$````("@E<R!D87ES(&%G;RD`("A!8V-E<W-K
M97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY
M97-T97)D87DI`"!A="``(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E<R(@
M:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D
M(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO
M="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN
M`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E
M<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S960@;V8@)2XR9DU"
M(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D(&1A>7,@=6YT:6P@
M>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"UD87D@9F]R96-A<W0`)7,@+2!.
M;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E
M<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S
M(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@
M)7,@)7,`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A
M;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T
M:6UE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`
M)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A
M<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`)7,Z(%1H:7,@
M;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N
M($)E=V%R92!O9B!F;VQL;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R
M;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T
M:6]N+@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R
M;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R($AO=7(@1F]R;6%T`#(T($AO
M=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P!!(&1A=&%B87-E(&)A8VME
M;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@
M:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@
M96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER
M960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K
M97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P
M<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T
M92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A
M=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER
M960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D<P!!32!,:6=H="!2
M86EN`$%-($QI9VAT(%-N;W<`04T@4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@
M4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N
M+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I
M;&4N`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N="!087-S=V]R9`!!8V-O
M=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($-H:6QD($=R;W5P`$%D
M9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@365M8F5R<P!!9&0@
M3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U
M<"!T;R`B)7,B`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!9&0@
M82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@<&%I<@!!9&0@=&AE("5S($UE
M;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D9')E<W,@8F]O:SH`
M061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B('1O
M('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG
M;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@(B5S(B!T;R!T:&4@<WES=&5M
M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE
M9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M
M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%F
M9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE
M;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L
M;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A
M9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`
M06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E
M($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N
M871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA
M=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W87,@
M<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+@!!;F1O
M<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N
M=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L
M:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#
M:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R
M86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E
M($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG
M;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M(&1E;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`07)G96YT:6YA`$%R
M;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N<VEO
M;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O
M<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O(&1E;&5T92!A
M(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM
M97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X
M:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES
M=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R
M:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I
M<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT
M96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B
M;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N
M;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@
M4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I
M<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L
M92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A
M=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S
M=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@4F5Q
M=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z
M(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N
M=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO
M;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A
M=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO
M;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@=&\@=&AE
M(%--0B!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I
M:F%N`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`
M0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N
M`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D
M97-H`$)A<F)A9&]S`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E<R(@;F]T
M(&9O=6YD+@!"87-E;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN
M`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC
M871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y
M<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K
M;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T
M<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD
M:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I
M80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`
M0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#
M86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#86QM`$-A
M;6)O9&EA`$-A;65R;V]N`$-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S
M<VEO;B!H86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@
M)7,`0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#86YC96P`0V%N8V5L
M(%!R;V)L96T@4F5P;W)T`$-A;FYO="!C;W!Y(&9I;&4H<RD@+2!S;W5R8V4@
M86YD(&1E<W1I;F%T:6]N(&%R92!T:&4@<V%M92X`0V%N;F]T(&1E;&5T92!F
M:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`
M0V%N;F]T(&UO=F4@9FEL92AS*2`M(&1E<W1I;F%T:6]N(&ES('=I=&AI;B!S
M;W5R8V4N`$-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A
M<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T
M(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N
M=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO
M="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@<F5S970@<&%S<W=O<F0@
M875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A
M;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A;FYO
M="!W<FET92!T;R!F:6QE("(E<R(`0V%P92!697)D90!#87!T:6]N`$-A<G)I
M97(`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@
M4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P
M97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X
M-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A
M;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#
M97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H
M86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA;64@86YD
M(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R
M97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I
M<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO
M;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H96-?:R!,
M:6YK+BXN`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R
M*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@07!P;&EC871I
M;VXZ`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S
M92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP
M92`H9F]R(&]R9&5R960@;&ES=',I`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@
M9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F
M:6-E('1A9W,`0VQE87(@475E<GD`0VQE87(@;W5T('5S97(Z("5S`$-L96%R
M('5S97(`0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@
M0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO
M=61S`$-L;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N
M9',`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I
M80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#
M;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M
M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T97)S`$-O
M;F1I=&EO;@!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`
M0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O
M;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E
M<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F
M86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES
M97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E
M<B!F86EL960N`$-O;G1A8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT('1Y<&4@;V8@
M8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#
M;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!F86EL960Z("5S`$-O<'D@
M<V5L96-T:6]N`$-O<W0@240`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O
M=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B``0V]U;&0@;F]T(%!'4"!S
M:6=N(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G
M92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A
M9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N
M`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C
M="!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R
M("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@`$-O
M=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E
M(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M(B5S(BX`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM
M86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S
M(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@
M;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I
M<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@(B5S
M(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B
M;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E
M<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@
M;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E
M;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E
M<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@
M<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@
M;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@
M8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE
M<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R
M:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U
M=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A
M<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O
M=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U
M<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN
M`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U
M;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O
M=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9
M;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@
M=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E
M(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E
M<BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O
M;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E
M<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R
M92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S
M(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E
M<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@
M82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R
M96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`
M0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N
M="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@57-E<G,`0W5R<F5N="!7
M96%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T
M;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@
M<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H
M5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE
M8V@@4F5P=6)L:6,`1$0`1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M
M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!$
M86EL>0!$871A5')E92!"<F]W<V5R`$1A=&%B87-E($QO;VMU<`!$871E`$1A
M=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN
M`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F
M875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!3
M:&5L;`!$969I;FET:6]N<P!$96QE=&4`1&5L971E($-E;&P`1&5L971E($=R
M;W5P`$1E;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P
M=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T
M92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E(&UE<W-A9V5S
M`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R;6ES<VEO
M;G,@9F]R("(E<R(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R
M;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!S=6(@9F]L9&5R
M<P!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N
M="!R;W<`1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!$96QI
M=F5R>2!T:6UE`$1E;FUA<FL`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I
M<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A
M:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$
M979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z
M(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I
M;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I
M;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S
M=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I<W!O
M<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N;W0@9&5L971E`$1O
M(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O97,@=&AE
M(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C
M:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O
M;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W;FQO860`1&]W;FQO
M860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0
M('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$5-86EL+71O
M+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I
M9&4@=&AI<R!S97)V:6-E+@!%4E(`16-U861O<@!%9&ET`$5D:70@0FQO8VL`
M161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%
M9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET
M('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S
M`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M
M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N
M`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'871E=V%Y
M`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y
M('-E87)C:"!T97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M
M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@
M8V]N=&5X="!M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A
M('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF
M('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@
M:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%52
M3"!H97)E`$5N=&5R('1H92!L971T97)S(&)E;&]W.@!%<75A=&]R:6%L($=U
M:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%
M<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,`17)R;W(@9&5L971I;F<@
M<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@
M=7!D871I;F<@<&%S<W=O<F0Z("5S`$5R<F]R('=I=&@@96UA:6P@;65S<V%G
M92X`17)R;W(@=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI
M8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E
M<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E
M<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE
M8W5T90!%>'!A;F0`17AP96-T960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O
M<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X<&]N96YT
M`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I979I
M;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R
M=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@
M=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A
M:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O
M(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E<P!&86ER`$9A
M;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L
M($5R<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L
M:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M871R
M:7@`1FEG;&5T($-!4%1#2$$`1FEG;&5T(&9O;G0`1FEJ:0!&:6QE`$9I;&4@
M0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA
M9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE
M('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T
M($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`
M1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@
M8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H
M5$%&*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O
M<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU
M;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O
M="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&
M;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D<P!&<@!&<F%M97,`
M1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R965Z:6YG($1R:7IZ;&4`
M1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R
M;B!497)R:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N
M`$9U;&P@36]O;@!&=6QL($YA;64`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM
M86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R
M871I;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I
M8G)A;'1A<@!':79E;B!.86UE`$=L;V)A;"!/<'1I;VYS`$=O`$=O961E;`!'
M;V]G;&4@36%P<P!';V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E
M96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN
M:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P
M7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60Z(`!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E
M(&=R;W5P("5S`$=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@
M)7,`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`
M1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES
M<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N
M`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T
M(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N
M`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE861E<G,`2&5A
M<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE879Y(%0M4W1O<FT`
M2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@
M961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN
M9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#
M:71Y(%-T871E*0!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0
M:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN
M=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(
M;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@
M)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN
M(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D
M("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@
M<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@
M)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T
M:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN
M8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S
M>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H
M87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(
M;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O
M<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E
M/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA
M;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M
M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I
M;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E
M<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!
M9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N
M;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO
M;&%T:6]N+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY
M`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE
M.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E
M;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC
M;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@
M8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`
M268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA
M9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y
M;W5R(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!5
M4DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM
M86=E('5P;&]A9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I
M96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN
M8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE
M(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R
M;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!)
M;F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!)
M;F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!)
M;FAE<FET960@365M8F5R<P!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@
M26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O
M;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E
M<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@
M82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L
M=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W
M:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T
M(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@
M869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN
M<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`
M26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE
M(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN
M<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC
M:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N
M`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN
M=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@6DE0(&1A
M=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV
M86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R
M97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS92!K97DN
M`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N
M`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN
M9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A
M;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED
M('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H
M87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N
M:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`27)A;BP@
M27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`
M27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`
M2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`
M2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E
M<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z
M86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@
M<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#
M<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+
M97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L
M92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$55
M0RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@
M4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T($AA;&8`3&%S="!0
M87-S=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S
M="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN
M.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@
M8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,
M97-O=&AO`$QE=F5L`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,
M:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!2
M86EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,
M:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@
M4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!54DP`3&EN:R!A8V-E<W,@:V5Y
M`$QI;FL@<&]I;G1S('1O.@!,:6YK('1A<F=E=`!,:6YK('1E>'0`3&EN:R!T
M:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES
M<&QA>6EN9P!,:6YK('1I=&QE(&%T=')I8G5T90!,:6YK<P!,:6YU>"!#;V]K
M:64`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A
M<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!<F-H:79E
M`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M
M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!S97-S:6]N<R!F
M86EL960Z("5S`$QI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S
M97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG
M+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G
M(&EN`$QO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VX`3&]G(&]U=`!,;V=I
M;@!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N
M86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I
M;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T
M97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,
M=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE
M9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU
M9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I;`!-86EL
M($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S
M`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U
M(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA
M=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T
M(&UA<`!-87!P:6YG<R!S=&]R960N`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@
M4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N
M($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI
M<75E`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@
M86QL;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-
M87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S
M.B``36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87AI;75M(&QE
M;F=T:`!-87D`36%Y;W1T90!-961I8VEN90!-96UB97)S`$UE;G4@;6]D93H`
M365R9V4@8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F
M=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B
M92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T
M87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B
M;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+@!-971A<D1"(&ES(&YO="!C;VYN96-T
M960N`$UE=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-971H;V0@
M;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S`$UE=')I8P!-97AI8V\`
M36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4
M>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@
M:&]U<G,Z(`!-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I
M<F5D`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E
M($A45%!?4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V
M92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@
M87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN9R!R97%U
M:7)E9"!014%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N($E$+@!-
M;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO9&EF>2!5
M4DP`36]D=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L
M:6$`36]N=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA
M<V5S`$UO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP
M96-T960@)60N`$UO<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`
M36]S=&QY($-L;W5D>2!A;F0@5VEN9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W
M;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E
M('5P`$UO>F%M8FEQ=64`375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU
M;'1I;6%P(%5+(&UA<`!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!-
M>2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y
M;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F%M:6)I80!.
M875R=0!.97!A;`!.971H97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.
M971S8V%P92!"87-E(%523`!.971S8V%P92!#02!2979O8V%T:6]N(%523`!.
M971S8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@55),`$YE
M='-C87!E(%)E=F]C871I;VX@55),`$YE='-C87!E(%-33"!S97)V97(@;F%M
M90!.971S8V%P92!C97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I
M9FEC871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!#
M871E9V]R>0!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@
M6F5A;&%N9`!.97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D('=I;&P@97AP:7)E
M(&]N("5X+@!.97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W
M("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@-"!0:&%S97,`
M3F5X="!O<'1I;VYS`$YE>'0^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI
M9VAT`$YI=64`3F\`3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T
M;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y
M(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO
M(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A
M;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN
M`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@
M<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R
M961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U
M<&QO861E9`!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.
M;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@
M;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N
M<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@
M875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B
M97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N
M4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE
M8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG
M('-I9VYU<',N`$YO('%U;W1A('-E="X`3F\@<G5L97,`3F\@<V5P87)A=&]R
M('-P96-I9FEE9"X`3F\@<VED97,`3F\@<W5C:"!F:6QE`$YO('1E;7!O<F%R
M>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@
M86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R
M;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O
M;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R
M<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@
M8V]N9FEG=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I
M8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD`$YO<G1H97)N($AE;6ES
M<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T
M97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T(&9O=6YD+@!.;W0@
M:6UP;&5M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T
M:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E<@!.=6UB
M97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@
M<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I
M<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R96%T;W(`3V-T
M86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VQD(&%N9"!N97<@
M<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+@!/;&0@<&%S<W=O<F0`3VQD
M('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+@!/;6%N`$]N8VQI8VL@979E;G0`
M3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL
M>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A
M;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O
M<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F
M;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R
M.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P
M87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN
M9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`
M3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/
M<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T
M97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI
M<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!0
M14%2.CI-86EL(&)A8VME;F0`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%
M;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y
M<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-
M(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!3
M=6X`4$T@5"U3=&]R;7,`4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<`4%](
M4"!3:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E
M<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R
M86=U87D`4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D
M('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E
M<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I
M=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D
M<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H
M`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN
M=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N("(E<R(@;F]T
M(&1E;&5T960N`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI
M<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E
M<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX
M96QS`%!L871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L
M96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE
M;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@
M=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R
M+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0
M;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@
M82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE
M(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O
M=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E
M('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F
M;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@
M=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O
M<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET
M:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L
M90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`
M4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A
M=&EO;CQB<B`O/F-H86YC90!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E
M<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@
M870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE
M(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT
M(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP
M=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+
M97D@06QG;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L:6,O4')I=F%T92!K
M97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC
M;P!0=7)G92!M97-S86=E<P!1871A<@!1=65R>0!1=6]T80!24T$@4'5B;&EC
M($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY
M`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@
M4VYO=P!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@;65S<V%G97,`
M4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N
M9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H
M:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E<R!Y;W5R(&QA
M<W0@86-T:6]N`%)E9G)E<V@`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N
M=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"
M<F]W<V5R`%)E;&]A9`!296UA<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!5
M4DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M
M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M
M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E
M;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D
M92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@
M)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R
M;W)C;V1E.B``4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD
M+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A
M=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF
M:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O
M<F0`4F5S970@66]U<B!087-S=V]R9`!297-T;W)E($QA<W0@475E<GD`4F5S
M=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2971Y<&4@;F5W('!A<W-W;W)D`%)E
M=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/
M<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E
M<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``
M4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P
M<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R
M;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%
M($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S
M<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--
M4R!-97-S86=I;F<`4U%,(%-H96QL`%-13"!S=&%T96UE;G0@9F]R('9A;'5E
M(&QO;VMU<',`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN="!(96QE
M;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I
M97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA
M9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O
M(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!
M<F%B:6$`4V%V90!3879E("(E<R(`4V%V92`E<P!3879E($]P=&EO;G,`4V%V
M92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@
M>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C
M;VYF:6=U<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@
M(B5S(BX`4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A<F-H`%-E87)C
M:"!%;F=I;F5S`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A
M(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R
M=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P`4V5L96-T(&%L
M;"!D871E(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&YO
M;F4`4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O
M>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F
M<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z
M`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@
M>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R
M.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG
M(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U
M<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N
M9"!335,`4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-
M;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@
M;F]T(&%V86EL86)L92X`4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER
M960N`%-E<W-I;VYS`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@
M<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E
M="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F
M<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L
M('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@
M87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A
M;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E
M('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE
M('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO
M<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@
M;6]S="!L:6YK<S\`4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R
M<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`
M4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W
M('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@
M;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D
M:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T
M:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E
M('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R
M<R!%87)L>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`
M4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O
M=70@;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N
M871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP
M($UA:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W
M97(`4VYO=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E
M<G,@3&%T90!3;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R
M.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T
M(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`
M4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD
M('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE
M<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W965N
M(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P
M86-I;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E
M<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O
M<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3
M=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T
M($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA
M:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;0U-370!3=0!3=6)D:7)E8W1O
M<GD@(B5S(B!N;W0@9F]U;F0N`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R
M97%U97-T('1O(&%D9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@
M;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`
M4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@
M=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E
M<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@
M(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T
M96TN`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO
M860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@
M8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B
M)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2
M:7-E`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR
M:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R
M:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N
M9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN8R!L;V<@9&5L971E9`!3>6YT87@@
M97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M
M4W1O<FT`5"U3=&]R;2!A;F0@5VEN9'D`5"U3=&]R;7,`5"U3=&]R;7,@16%R
M;'D`5%-6(&9I;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!3970`5&%B;&4@
M<')O<&5R=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!4
M86II:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T
M.@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@
M`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&5R871U<F4\8G(@+SXH
M)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!496UP;&%T92`B)7,B(&YO="!F;W5N
M9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5X=`!497AT($]N;'D`5&5X
M="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H86EL86YD`%1H
M92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(:7-T;W)Y
M('-Y<W1E;2!I<R!D:7-A8FQE9"X`5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T
M:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE($E-4U`@;&]G
M(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"X`5&AE($UA:6YT96YA;F-E.CH@
M8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W
M:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%D;6EN:7-T<F%T;W(@
M;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A
M8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4:&4@8F]T
M=&]M('-I9&4@;VYL>0!4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S
M<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@
M9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@
M=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!D971A8VAE9"!01U`@<VEG;F%T
M=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE
M<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO
M="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN('1H92!D
M871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF
M:65D+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E
M('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A
M("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@
M)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@
M9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F
M8S@R,B!M97-S86=E+@!4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T
M;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@
M=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA
M<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E(&1I<W!L87DL
M(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S
M97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G
M<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"!0<F]T
M96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E
M(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S=&EL;"!W
M86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4:&4@:61E;G1I
M='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@;&5F="UH86YD('-I9&4@
M;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E
M(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE(&UE<W-A9V4@
M<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H87,@8F5E;B!D
M:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A
M9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@;F%M92!T;R!U
M<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4`5&AE(&YU;6)E
M<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+@!4:&4@;W!E;G-S;"!M;V1U
M;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L
M87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B
M96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L
M92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP
M92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE('%U;W1E
M(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@
M<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E
M(&]N;'D`5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C
M=&5R+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E
M<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@
M9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@<F]W("@E
M9"D@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP;W)A<GD@9FEL92`B)7,B(&1O
M97,@;F]T(&5X:7-T+@!4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA
M=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN`%1H92!T;W`@86YD(&)O='1O
M;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO861E9"!D
M871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L
M;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W96%T:&5R+F-O
M;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5M97,@9&ER96-T;W)Y("(E
M<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N
M`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL
M:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I
M96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T
M(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I
M;F<@(B5S(B!T;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M
M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TZ
M(`!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG("(E<R(@9G)O;2!T:&4@
M<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`B)7,B.B`E
M<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.
M;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T
M:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA
M>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R
M;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P
M87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y
M:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O
M<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T
M(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R;W(@<&5R
M9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@
M4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P
M9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I
M8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H:7,@24U!
M4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H
M:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N
M`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N
M`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R
M+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A
M=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W
M:6YP;&,N8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@
M<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I
M;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY
M(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER
M97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY("AH='1P
M.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@
M9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`5&AI<R!F
M:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L
M9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@
M:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4
M:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'
M0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@9F]R
M;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI
M<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O
M8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E
M<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES
M="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E('9I<VET("5S`%1H:7,@
M;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O
M=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE
M87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD
M(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV
M871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O
M=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD
M97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM
M92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I
M.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@
M0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K
M:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O
M;6]R<F]W`%1O;F=A`%1O;R!M86YY(&EN=F%L:60@;&]G:6YS(&1U<FEN9R!T
M:&4@;&%S="!M:6YU=&5S+@!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA
M=&EO;G,`5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U
M;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A
M;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C
M:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%523"!F;W(@>6]U<B!S8W)I<'0@
M9&5L:79E<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N
M86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E
M>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE
M('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B
M;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5
M;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S
M:7IE(&]F("(E<R(N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S
M+R5S(BX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE
M('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE
M('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@(B5S(BX`56YA
M8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M
M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T
M;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`
M56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP
M='D`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY
M+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93
M(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE
M('1O(&1E;&5T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@
M5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R
M96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@
M9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`
M56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG
M+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M
M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL
M97-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H<VEZ
M92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B;&4@=&\@
M<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@
M)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F
M<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N
M86)L92!T;R!T<FEG9V5R(&9R964O8G5S>2!U<&1A=&4@9F]R("5S`%5N86)L
M92!T;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@9&%T82X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL
M(&)E(&5X8V5E9&5D+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V
M97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S
M97)V97(@=&\Z(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A
M8B!%;6ER871E<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E
M9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N
M`%5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C
M;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T:6]N
M('!R;W9I9&5D+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI
M;FL@=&AE(&-U<G)E;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S
M8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T
M:6-A;&QY(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E
M(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@
M>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B
M;V%R9"X`56YS970@8V]L;W(`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T
M90!5<&1A=&4@)7,`57!D871E('5S97(`57!D871E9"`B)7,B+@!5<&=R861E
M('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T
M:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE
M='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT
M.B`E<P!5<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N
M="!F;W(@24U34"!S97)V97(N`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R
M:7-E9"!F;W(@)7,N`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS
M`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N
M(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U
M;F0`57-E<FYA;64`57-E<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E
M<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI
M<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!6
M86QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E
M(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM
M=6T@;&5N9W1H(&]F("5S+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M
M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL
M960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H
M+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T
M:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE
M=&YA;65S92`H5DE30TE)*0!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B
M('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G
M:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A
M9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#
M4DE05"!-04Y504Q,62!&4D]-("5S+@!724X@=FEA($A45%``5V%L;&ES(&%N
M9"!&=71U;F$`5V%R;FEN9P!790!796%T:&5R($9O<F5C87-T`%=E871H97(@
M9&%T82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`5V5B(%-I=&4`5V5E
M:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N
M("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!3
M86AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E
M<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA
M="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&5R96ES($%U<W1R86QI82!M
M87``5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T
M:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S
M`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E
M8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@
M=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I
M;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=I<VAL:7-T`%=O<FL`5V]R
M:R!!9&1R97-S`%=O<FL@4&AO;F4`5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I
M;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&YU;6)E
M<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;V9F
M<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92X`6"U2968`6#4P.78S
M($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`
M6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C
M="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA
M:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&%R
M92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C
M:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E
M871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%U=&AE;G1I
M8V%T960N`%EO=2!C86YN;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y
M;W5R(&9U;&P@;F%M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I
M;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE
M(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN
M("5S+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N
M=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET
M:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI
M;F<@<')E9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9
M;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3
M:6=N=7!S+@!9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U
M(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N
M9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@
M=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@
M<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R
M;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M
M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O
M(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E
M+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO
M=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE960@=&\@
M<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W5R("5S('-E<W-I
M;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I
M;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO
M;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE
M(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U
M<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9
M;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A
M9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T;R!A9&UI
M;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N
M="!A=71H96YT:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T
M:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R
M96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S
M:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O
M=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U
M<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R
M(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@
M4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN="X`66]U<B!C=7)R
M96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N
M(&-H86YG960N`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA
M;64Z`%EO=7(@;&]G:6X@:&%S(&5X<&ER960N`%EO=7(@;F5W('!A<W-W;W)D
M(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D
M(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO
M;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@
M<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U
M<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO
M=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z
M`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M(:61E
M(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!4
M97AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@
M;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?0TQ)`%]$871A5')E90!?1&5L971E
M(%)O=P!?1W)O=7!S`%]);6%G92!0<F]P97)T:65S+BXN`%],;V<@:6X`7TQO
M9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?
M4F5M;W9E($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5
M<V5R<P!A9&1R97-S(&)O;VL`861D<F5S<V5E('5N:VYO=VX`8V%L96YD87(`
M8V%L;0!C86YN;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N(&EN
M<'5T`&-L:6-K(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I
M9W5R871I;VX@97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9P!D
M871A(&9O<FUA="!E<G)O<@!E9&ET`&5N=')Y(&YO="!F;W5N9`!F86QL:6YG
M`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&@Z`&AH
M`&AO<W0@;F%M92!U;FMN;W=N`&EM;65D:6%T90!I;FQI;F4`:6YP=70O;W5T
M<'5T(&5R<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R`&QI;F5S70!M:VES
M;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;6T`;F%M90!N
M;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`'!E
M<F-E;G0`<&5R;6ES<VEO;B!D96YI960`<&EX96QS`')E;6]T92!E<G)O<B!I
M;B!P<F]T;V-O;`!R:7-I;F<`<V5R=FEC92!U;F%V86EL86)L90!S:&]W(&1I
M9F9E<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S<P!S=&5A9'D`<WES=&5M
M(&5R<F]R`'1A<VL@;&ES=`!T96UP;W)A<GD@9F%I;'5R90!T>7!E('1H92!P
M87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N:69I960`=6YN86UE9`!U<V5R
M('-E;&5C=`!V0V%R9`!W.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I
M;VXZ($AO<F1E(#,N,2UC=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L
M:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#<M,S$@
M,3@Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`V+3`X+3`Y(#$V.C0U
M*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R
M9&4N;W)G/@I,86YG=6%G92U496%M.B!'97)M86X@/&1E=D!L:7-T<RYH;W)D
M92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P
M;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC
M;V1I;F<Z(#@M8FET"@`@*'9O<B`E<R!486=E;BD`("A:=6=R:69F<W1A<W1E
M("5S*0`@*&EN("5S(%1A9V5N*0`@*&AE=71E*0`@*&UO<F=E;BD`("AG97-T
M97)N*0`@;6ET(``B)7,B(&ES="!K96EN(%9E<GIE:6-H;FES+@`B)7,B(&ES
M="!K96EN92!G_&QT:6=E($%U<W=A:&PN`"(E<R(@:7-T(&EN(&1E<B!(;W)D
M92!296=I<W1R>2!N:6-H="!K;VYF:6=U<FEE<G0N`$1E<B!"875M+5)E;F1E
M<F5R(&;\<B`B)7,B('=U<F1E(&YI8VAT(&=E9G5N9&5N+@`B)7,B('=U<F1E
M('IU;2!'<G5P<&5N<WES=&5M(&AI;GIU9V5F_&=T+@`B)7,B('=U<F1E('IU
M;2!296-H=&5S>7-T96T@:&EN>G5G96;\9W0N`"(E<R(@=W5R9&4@;FEC:'0@
M97)S=&5L;'0Z("5S+@`E+C)F34(@*"4S)"XR9B4E*2!V;VX@)3(D+C)F34(@
M97)L875B=&5N('9E<F)R875C:'0`)60@)7,@=6YD("5S`$EN("5D(%1A9V5N
M('=I<F0@26AR(%!A<W-W;W)T('5N9_QL=&EG+@`E9"U486=E+59O<FAE<G-A
M9V4`)7,@+2!(:6YW96ES`"5S($9I;F=E<F%B9')U8VL`)7,@2T(`)7,@5V%R
M='5N9W-A<F)E:71E;B`M($)E<W3D=&EG=6YG`"5S+4MO;F9I9W5R871I;VX`
M)7,@4F5G:7-T<FEE<G5N9P`E<R!.=71Z=6YG<V)E9&EN9W5N9V5N`"5S(&5X
M:7-T:65R="!B97)E:71S+@`E<R!M:70@)7,@)7,`)7,@=VER9"!D:64@5V%R
M='5N9W-A<F)E:71E;B!D=7)C:&;\:')E;BP@9&EE('5N=&5N(&UA<FMI97)T
M('-I;F0N($UA<FMI97)E;B!3:64@86QL92!!=69G86)E;BP@9&EE(&IE='IT
M(&1U<F-H9V5F_&AR="!W97)D96X@<V]L;&5N+@`E<R!I<W0@;F]T=V5N9&EG
M`"5S($UI;G5T96X`)7,@;FEC:'0@9V5F=6YD96XN`"5S(&)I<R`E<R!V;VX@
M)7,`)7-S($%D<F5S<V)U8V@`)7-S($MA;&5N9&5R`"5S<R!.;W1I>F)L;V-K
M`"5S<R!!=69G86)E;FQI<W1E`"5S.B`E<P`E<SH@1&EE<V4@3F%C:')I8VAT
M('-T86UM="!U;G1E<B!5;7-TY&YD96X@;FEC:'0@=F]N(&1E;2!A;F=E9V5B
M96YE;B!!8G-E;F1E<BX@1F]L9V5N(%-I92!K96EN96X@3&EN:W,@:6X@9&EE
M<V5R($YA8VAR:6-H="!U;F0@:/QT96X@4VEE('-I8V@@9&%V;W(L(&1E;2!!
M8G-E;F1E<B!P97)S]FYL:6-H92!$871E;B!P<F5I<WIU9V5B96XN`"P@8O9I
M9R``+"!B:6<@)7,@)7,`+"!S8VAW86YK96YD('9O;B`E<R!B:7,@)7,`+2T@
M075S=^1H;&5N("TM`#$R+5-T=6YD96XM1F]R;6%T`#(T+5-T=6YD96XM1F]R
M;6%T`#(T(%-T=6YD96X`/%IU<OQC:P!&<B!D:65S96X@0FQO8VL@=VER9"!E
M:6YE($1A=&5N8F%N:R!B96YT:6=T+@!%:6X@<V-H=V5R97(@1F5H;&5R(&ES
M="!A=69G971R971E;CH`16EN(/9F9F5N=&QI8VAE<B!01U`M4V-H;/QS<V5L
M('=I<F0@9OQR(&1I92!697)S8VAL_'-S96QU;F<@96EN97(@3F%C:')I8VAT
M(&)E;O9T:6=T+@!%:6X@]F9F96YT;&EC:&5R(%!'4"U38VAL_'-S96P@=VER
M9"!F_'(@9&EE(-QB97)P<OQF=6YG(&5I;F5R('5N=&5R>F5I8VAN971E;B!.
M86-H<FEC:'0@8F5N]G1I9W0N`$5I;B#V9F9E;G1L:6-H97(@=6YD(&5I;B!P
M<FEV871E<B!01U`M4V-H;/QS<V5L('-O=VEE(&5I;B!087-S=V]R="!W:7)D
M(&;\<B!D:64@16YT<V-H;/QS<V5L=6YG(&5I;F5R($YA8VAR:6-H="!B96[V
M=&EG="X`16EN(/9F9F5N=&QI8VAE<B!U;F0@96EN('!R:79A=&5R(%!'4"U3
M8VAL_'-S96P@<V]W:64@96EN(%!A<W-W;W)T('=I<F0@9OQR(&1I92!5;G1E
M<GIE:6-H;G5N9R!E:6YE<B!.86-H<FEC:'0@8F5N]G1I9W0N`$5I;B#V9F9E
M;G1L:6-H97(@=6YD(&5I;B!P<FEV871E<B!3+TU)344M4V-H;/QS<V5L('-O
M=VEE(&5I;B!087-S=V]R="!W:7)D(&;\<B!D:64@16YT<V-H;/QS<V5L=6YG
M(&5I;F5R($YA8VAR:6-H="!B96[V=&EG="X`16EN(/9F9F5N=&QI8VAE<B!U
M;F0@96EN('!R:79A=&5R(%,O34E-12U38VAL_'-S96P@<V]W:64@96EN(%!A
M<W-W;W)T('=I<F0@9OQR(&1I92!5;G1E<GIE:6-H;G5N9R!E:6YE<B!.86-H
M<FEC:'0@8F5N]G1I9W0N`$5I;B#V9F9E;G1L:6-H97(@4R]-24U%+5-C:&S\
M<W-E;"!W:7)D(&;\<B!D:64@5F5R<V-H;/QS<V5L=6YG(&5I;F5R($YA8VAR
M:6-H="!B96[V=&EG="X`5F]R;6ET=&%G<R!7;VQK96X`5F]R;6ET=&%G<R!L
M96EC:'1E<B!296=E;@!6;W)M:71T86=S(&QE:6-H=&5R(%-C:&YE969A;&P`
M5F]R;6ET=&%G<R!296=E;@!6;W)M:71T86=S(%-C:&%U97(`5F]R;6ET=&%G
M<R!38VAN965S8VAA=65R`$%-+U!-`$%022!)1`#<8F5R(&1I97-E;B!%9&ET
M;W(`26YF;RXN+@!!8G-O;'5T(%5N=&5N`$%B<V]L=70@36ET=&4`6G5G<FEF
M9B!V97)W96EG97)T(&)E:6T@06YL96=E;B!D97,@5D93+59E<GIE:6-H;FES
M<V5S+@!:=6=R:69F('9E<G=E:6=E<G0@8F5I;2!!;FQE9V5N(&1E<B!61E,M
M1&%T96DN`$MO;G1O:6YF;W)M871I;VYE;@!+;VYT;W!A<W-W;W)T`$MO;G1O
M(&5I;F=E9G)O<F5N+@!"=6-H:&%L='5N9P!(:6YZ=6;\9V5N`$YE=64@56YT
M97)G<G5P<&4@:&EN>G5F_&=E;@!.975E(%5N=&5R<F5C:'1E(&AI;GIU9OQG
M96X`2&EE<B!H:6YZ=6;\9V5N.@!-:71G;&EE9&5R(&AI;GIU9OQG96X`3F5U
M92!'<G5P<&4@:&EN>G5F_&=E;@!.975E(%)E8VAT92!H:6YZ=6;\9V5N`%5N
M=&5R9W)U<'!E('IU("(E<R(@:&EN>G5F_&=E;@!5;G1E<G)E8VAT92!Z=2`B
M)7,B(&AI;GIU9OQG96X`1OQG96X@4VEE(&5I;F5N(&YE=65N($)E;G5T>F5R
M(&AI;GIU.@!3<&%L=&4@:&EN>G5F_&=E;@!086%R(&AI;GIU9OQG96X`1&%S
M("5S+4UE;OP@>G5R($UO>FEL;&$@4VED96)A<B!H:6YZ=6;\9V5N`%IU;2!!
M9')E<W-B=6-H(&AI;GIU9OQG96XZ`%IU(&UE:6YE;2!!9')E<W-B=6-H(&AI
M;GIU9OQG96X`0F5N=71Z97(@:&EN>G5F_&=E;@`B)7,B('=U<F1E('IU;2!3
M>7-T96T@:&EN>G5G96;\9W0L(&%B97(@9&EE('IU<^1T>FQI8VAE;B!296=I
M<W1R:65R=6YG<VEN9F]R;6%T:6]N96X@:V]N;G1E;B!N:6-H="!G97-P96EC
M:&5R="!W97)D96XZ("5S+@`B)7,B('=U<F1E('IU;2!3>7-T96T@:&EN>G5G
M96;\9W0N(%-I92!K]FYN96X@<VEC:"!J971Z="!A;FUE;&1E;BX`1&%S($AI
M;GIU9OQG96X@=F]N($)E;G5T>F5R;B!I<W0@;FEC:'0@;?9G;&EC:"X`061R
M97-S90!!9')E<W-B=6-H`%9E<G=A;'1E;B`M(%)E8VAT92!F_'(@86YD97)E
M($)E;G5T>F5R(&9E<W1L96=E;@!!9&UI;FES=')A=&EO;@!797)B=6YG`$%F
M9VAA;FES=&%N`$%L8F%N:65N`$%L9V5R:65N`%-P:71Z;F%M90!!=7-R:6-H
M='5N9P!!=7-R:6-H='5N9SH`06QL90!!;F=E;65L9&5T92!"96YU='IE<@!!
M;&QE($=R=7!P96X`06QL92!296-H=&4`06QL92!V:65R(%-E:71E;@!-96AR
M97)E($%D<F5S<V5N(&5R;&%U8F5N`$9O<FUA="!V;VX@;G5M;65R:65R=&5N
M($QI<W1E;B#D;F1E<FX_`$5X:7-T:65R="!B97)E:71S`$%L=&5R;F%T:79E
M($E-4U`M06YM96QD=6YG`$%L=&5R;F%T:79E<R!)35-0+5!A<W-W;W)T`$%L
M=&5R;F%T:79E<B!)35-0+4)E;G5T>F5R;F%M90!!;'1E<FYA=&EV92!%+4UA
M:6PM061R97-S90!!;'1E<FYA=&EV92!6;W)L86=E;@!!;'1E<FYA=&EV97(@
M5&5X=#H`06UE<FEK86YI<V-H+5-A;6]A`$5S('=U<F1E(&5I;B!U;F?\;'1I
M9V5R(%=E<G0@86YG96=E8F5N+@!%:6X@=6YB96MA;FYT97(@1F5H;&5R(&ES
M="!A=69G971R971E;BX`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM
M97(@4')O>'D`06YT=V]R=`!!;G1A<FMT:7,`06YT:6=U82!U;F0@0F%R8G5D
M80!!;G=E;F1U;F<`06YW96YD=6YG<VQI<W1E`$%N=V5N9'5N9R!I<W0@8F5R
M96ET+@!!=68@56YT97)R96-H=&4@86YW96YD96X`0F5S=.1T:6=E;@!5;F=E
M9N1H<F4@1W+VWV4`07!R:6P`07)A8FES8V@@*%=I;F1O=W,M,3(U-BD`07)C
M:&EV9W+VWV4`07)C:&EV;F%M90!3:6YD(%-I92!S:6-H97(L(&1A<W,@4VEE
M(&1I92!296=I<W1R:65R=6YG<V%N9G)A9V4@=F]N("5S(&SV<V-H96X@;?9C
M:'1E;C\`4VEN9"!3:64@<VEC:&5R+"!D87-S(%-I92`B)7,B('5N9"!A;&QE
M(%5N=&5R9W)U<'!E;B!L]G-C:&5N(&WV8VAT96X_`$%R9V5N=&EN:65N`$%R
M;65N:65N`$%R;65N:7-C:"`H05)-4T-)22TX*0!+=6YS=`!!<G5B80!!<V-E
M;G-I;VXM26YS96QN`$%30TE)+4MU;G-T`$%S:65N+U!A>FEF:7-C:&4@4F5G
M:6]N`$%N<W1E:&5N9&4@5V%R='5N9W-A<F)E:71E;B!B97-TY'1I9V5N(&QA
M<W-E;C\`6G5O<F1N=6YG<V9E;&1E<@!%<R!W=7)D92!V97)S=6-H="P@96EN
M92!N:6-H="!E>&ES=&EE<F5N9&4@1W)U<'!E('IU(&SV<V-H96XN`$5S('=U
M<F1E('9E<G-U8VAT+"!E:6X@;FEC:'0@97AI<W1I97)E;F1E<R!296-H="!Z
M=2!L]G-C:&5N+@!%<R!W=7)D92!V97)S=6-H="P@96EN(&YI8VAT(&5X:7-T
M:65R96YD97,@4F5C:'0@>G4@8F5A<F)E:71E;BX`17,@=W5R9&4@=F5R<W5C
M:'0L(&5I;B!N:6-H="!E>&ES=&EE<F5N9&5S(%)E8VAT('IU(&)E87)B96ET
M96XN`$%T=')I8G5T90!!=6=U<W0`075S=')A;&EE;@#6<W1E<G)E:6-H`$%U
M=&A?8WER<W%L.B!$:64@8F5N]G1I9W1E($E-05`M17)W96ET97)U;F<@=W5R
M9&4@;FEC:'0@9V5F=6YD96XN`$%U=&A?8WER=7,Z($1A<R!"86-K96YD(&AA
M="!N:6-H="!D:64@8F5N]G1I9W1E;B!&Y&AI9VME:71E;BX`075T:%]C>7)U
M<SH@1&EE(&)E;O9T:6=T92!)34%0+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT
M(&=E9G5N9&5N+@!!=71H7V9T<#H@1&EE(&)E;O9T:6=T92!&5%`M17)W96ET
M97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN($MO;7!I;&EE<F5N(%-I92!0
M2%`@;6ET(&1E;2`M+65N86)L92UF='`@4&%R86UE=&5R+@!!=71H7VEM87`Z
M($1I92!B96[V=&EG=&4@24U!4"U%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G
M969U;F1E;BX`075T:%]K<F(U.B!$:64@8F5N]G1I9W1E($ME<F)E<F]S+45R
M=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+@!!=71H7VQD87`Z($1A
M<R!(:6YZ=6;\9V5N('9O;B!"96YU='IE<FX@=VER9"!F_'(@06-T:79E($1I
M<F5C=&]R>2!N:6-H="!U;G1E<G-T_'1Z=`!!=71H7VQD87`Z($1A<R!,]G-C
M:&5N('9O;B!"96YU='IE<FX@=VER9"!F_'(@06-T:79E($1I<F5C=&]R>2!N
M:6-H="!U;G1E<G-T_'1Z=`!!=71H7VQD87`Z($1I92!B96[V=&EG=&4@3$1!
M4"U%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BX`075T:%]L9&%P
M.B!$97(@0F5N=71Z97(@)7,@:V]N;G1E(&YI8VAT(&AI;GIU9V5F_&=T('=E
M<F1E;BX@365L9'5N9R!D97,@4V5R=F5R<SH@`$%U=&A?;&1A<#H@0F5N=71Z
M97(@)7,@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;@!!=71H7VQD87`Z
M($)E;G5T>F5R("5S(&MO;FYT92!N:6-H="!A:W1U86QI<VEE<G0@=V5R9&5N
M`$%U=&A?;&1A<#H@1&%S($%K='5A;&ES:65R96X@=F]N($)E;G5T>F5R;B!W
M:7)D(&;\<B!!8W1I=F4@1&ER96-T;W)Y(&YI8VAT('5N=&5R<W3\='IT+@!!
M=71H7VUC86PZ($1I92!B96[V=&EG=&4@34-!3"U%<G=E:71E<G5N9R!W=7)D
M92!N:6-H="!G969U;F1E;BX`075T:%]S;6)A=71H.B!$:64@8F5N]G1I9W1E
M(%-A;6)A+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+@!!;FUE
M;&1U;F<@8F5I;2!)34%0+5-E<G9E<B!F96AL9V5S8VAL86=E;BX`075T:&5N
M=&EF:7II97)U;F<@9F5H;&=E<V-H;&%G96X`06YM96QD=6YG(&9E:&QG97-C
M:&QA9V5N+B`E<P!$:64@075T:&5N=&EF:7II97)U;F<@=W5R9&4@=F]M(%)!
M1$E54RU397)V97(@>G5R_&-K9V5W:65S96XN`$%N;65L9'5N9R!B96EM($94
M4"U397)V97(@9F5H;&=E<V-H;&%G96XN`$%N;65L9'5N9R!B96EM(%--0BU3
M97)V97(@9F5H;&=E<V-H;&%G96XN`%9E<F;\9V)A<F4@1F5L9&5R.@!!<V5R
M8F%I9'-C:&%N`$)/1D@M075S<F5D96X`2&EN=&5R9W)U;F0`2&EN=&5R9W)U
M;F1F87)B90!&86QS8VAE<R!+97)B97)O<RU087-S=V]R="X`1F%L<V-H97(@
M2V5R8F5R;W,M0F5N=71Z97)N86UE+@!"86AA;6%S`$)A:')E:6X`0F%L=&ES
M8V@@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-C:`!"87)B861O<P!"87-I<RU"
M:6QD97(M5F5R>F5I8VAN:7,@(B5S(B!N:6-H="!G969U;F1E;BX`1W)U;F1L
M:6YI90!796G?<G5L86YD`$)E;&=I96X`0F5L:7IE`$)E;FEN`$)E<FUU9&%S
M`$)H=71A;@!'96)U<G1S=&%G`$)L;V-K("(E<R(@9&5R($%N=V5N9'5N9R`B
M)7,B(&YI8VAT(&=E9G5N9&5N+@!";&]C:V5I;G-T96QL=6YG96X`0FQO8VMT
M>7``1F5T=`!";VQI=FEE;@!,97-E>F5I8VAE;@!286YD`%)A:&UE;F1I8VME
M.@!2Y&YD97(`0F]S;FEE;BU(97)Z96=O=VEN80!"96ED97,`0F]T<W=A;F$`
M56YT96X`0F]U=F5T:6YS96P`0G)A<VEL:65N`$)R:71I<V-H97,@5&5R<FET
M;W)I=6T@:6T@26YD:7-C:&5N($]Z96%N`$)R=6YE:2!$87)U<W-A;&%M`$)U
M;&=A<FEE;@!5;FYU;6UE<FEE<G1E($QI<W1E`$)U<FMI;F$@1F%S;P!"=7)U
M;F1I`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;G-S=&5L;&4`7UIE;&QE;F5I
M9V5N<V-H869T96XN+BX`1&5R(%IW:7-C:&5N<W!E:6-H97(@:V]N;G1E(&YI
M8VAT(&EN:71I86QI<VEE<G0@=V5R9&5N+@!+86QE;F1E<@!7:6YD<W1I;&P`
M2V%M8F]D<V-H80!+86UE<G5N`$5X=&5R;F4@4V5S<VEO;BU(86YD;&5R(&OV
M;FYE;B!N:6-H="!A9&UI;FES=')I97)T('=E<F1E;BX`5F5R8FEN9'5N9R!Z
M=6T@24U!4"U397)V97(@:V%N;B!N:6-H="!H97)G97-T96QL="!W97)D96XZ
M("5S`$1I92!$871E:2`B)7,B(&MA;FX@;FEC:'0@9V7V9F9N970@=V5R9&5N
M+@!+86YA9&$`06)B<F5C:&5N`%!R;V)L96UB97)I8VAT(&%B8G)E8VAE;@!$
M871E:2AE;BD@:_9N;F5N(&YI8VAT(&MO<&EE<G0@=V5R9&5N("T@475E;&PM
M('5N9"!::65L9&%T96EE;B!S:6YD(&ED96YT:7-C:"X`1&EE($1A=&5I("(E
M<R(@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BX`2V5I;B!T96UP;W+D
M<F5S(%9E<GIE:6-H;FES(&=E9G5N9&5N+@!$871E:2AE;BD@:_9N;F5N(&YI
M8VAT('9E<G-C:&]B96X@=V5R9&5N("T@6FEE;&1A=&5I(&)E9FEN9&5T('-I
M8V@@:6T@475E;&QO<F1N97(N`$9O<G1S971Z=6YG(&]H;F4@(G1A<F=E=$9I
M;&4B+5!A<F%M971E<B!N:6-H="!M]F=L:6-H+@!$87,@5F5R>F5I8VAN:7,@
M(B5S(B!K;VYN=&4@;FEC:'0@96YT9F5R;G0@=V5R9&5N+@!+;VYN=&4@;FEC
M:'0@96YT9F5R;G0@=V5R9&5N+"`E9"!+:6YD97(@97AI<W1I97)E;BX`56US
M;W)T:65R96X@;FEC:'0@;?9G;&EC:"X@1&EE($%N>F%H;"!D97(@16EN='+D
M9V4L(&1I92!U;7-O<G1I97)T('=E<F1E;B!S;VQL96XL('-T:6UM="!N:6-H
M="!M:70@9&5R($%N>F%H;"!D97(@9V5S<&5I8VAE<G1E;B!%:6YT<N1G92#\
M8F5R96EN+@!087-S=V]R="!K86YN(&YI8VAT(&%U=&]M871I<V-H('IU<OQC
M:V=E<V5T>G0@=V5R9&5N+"!B:71T92!W96YD96X@4VEE('-I8V@@86X@26AR
M96X@061M:6YI<W1R871O<BX`1&EE($YA8VAR:6-H="!K;VYN=&4@;FEC:'0@
M86X@9&EE(&%N9V5G96)E($YU;6UE<B!W96ET97)G96QE:71E="!W97)D96XN
M`$1I92!$871E:2`B)7,B(&MA;FX@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N
M`$MA<"!697)D90#<8F5R<V-H<FEF=`!0<F]V:61E<@!+871E9V]R:65N('5N
M9"!"97-C:')I9G1U;F=E;@!#87EM86XM26YS96QN`$UO8FEL=&5L969O;@!:
M96QL96YE:6=E;G-C:&%F=&5N`$EN;F5N86)S=&%N9#H`6F5L;&5N96EG96YS
M8VAA9G1E;@!:96QL96YA8G-T86YD.@!-;V)I;'1E;&5F;VX`2V5L=&ES8V@@
M*$E33RTX.#4Y+3$T*0!:96YT<FEE<G0`6F5N=')A;&%F<FEK86YI<V-H92!2
M97!U8FQI:P!-:71T96QE=7)O<.1I<V-H("A)4T\M.#@U.2TR*0!:97)T:69I
M:V%T9&5T86EL<P!:97)T:69I:V%T8F5S:71Z97(`6F5R=&EF:6MA=')I8VAT
M;&EN:65N`%1S8VAA9`#$;F1E<FX`Q&YD97)N(%-I92!):'(@4&%S<W=O<G0`
MQ&YD97)N(%-I92!D96X@3F%M96X@;V1E<B!D:64@061R97-S92P@9&EE(&1I
M92!%;7!FY&YG97(@26AR97(@12U-86EL+4YA8VAR:6-H=&5N('-E:&5N+"!W
M96YN('-I92!D:65S92!L97-E;B!O9&5R(&1A<F%U9B!A;G=O<G1E;BX`1&%S
M(,1N9&5R;B!):')E<R!087-S=V]R=',@=VER9"!V;VX@9&EE<V5M(%-Y<W1E
M;2!Z=7(@6F5I="!N:6-H="!U;G1E<G-T_'1Z="X@0FET=&4@=V5N9&5N(%-I
M92!S:6-H(&%N($EH<F5N($%D;6EN:7-T<F%T;W(N`%IE:6-H96X`3&EN:R#\
M8F5R7W!R_&9E;BXN+@!#:&EL90!#:&EN80!#:&EN97-I<V-H('9E<F5I;F9A
M8VAT("A'0C(S,3(I`$-H:6YE<VES8V@@=')A9&ET:6]N96QL("A":6<U*0!!
M;G=E;F1U;F<@875S=^1H;&5N.@!7Y&AL96X@4VEE(&5I;B!087-S=V]R=`!7
MY&AL96X@4VEE(&5I;F5N($)E;G5T>F5R;F%M96X`3&5G96X@4VEE(&9E<W0L
M('=I92!D87,@1&%T=6T@86YG97IE:6=T('=E<F1E;B!S;VQL.@!,:7-T96YF
M;W)M870@875S=^1H;&5N("AF_'(@;G5M;65R:65R=&4@3&ES=&5N*0!796EH
M;F%C:'1S:6YS96P`2VQA<W-E;F1E9FEN:71I;VX@9OQR("5S(&YI8VAT(&=E
M9G5N9&5N+@!(96ET97(`35,M3V9F:6-E+51A9W,@96YT9F5R;F5N`$%B9G)A
M9V4@>G5R_&-K<V5T>F5N`$)E;G5T>F5R9&%T96X@;/9S8VAE;CH@)7,`0F5N
M=71Z97)D871E;B!L]G-C:&5N`$)E;G5T>F5R9&%T96X@;/9S8VAE;@!3<.1T
M97(@075F:VQA<F5N9`!&;W)T9F%H<F5N`$-L:6-K871E;&P@<&5R($A45%``
M1F5N<W1E<B!S8VAL:67?96X`5V]L:V5N`$9R_&@@5V]L:V5N`$)E=_9L:W0`
M2V]K;W-I;G-E;&X`365N_"!E:6YF86AR96X`6G5S86UM96YHY&YG96YD92!2
M86AM96X`2V]L=6UB:65N`$9A<F)E`$9A<F)A=7-W86AL`$9A<F)W86AL`%-P
M86QT96XZ`%-P86QT96[\8F5R<V-H<FEF=&5N`$-O;6EC<P!"969E:&P`0F5F
M96AL<WIE:6QE`$MO;6UE;G1A<@!%:6YD975T:6=E<B!.86UE`$MO;6]R96X`
M1FER;6$`0V]M<'5T97(`0F5D:6YG=6YG96X`0F5D:6YG=6YG96X`2V]N9FEG
M=7)A=&EO;G-U;G1E<G-C:&EE9&4`1&EE($MO;F9I9W5R871I;VX@;75S<R!A
M:W1U86QI<VEE<G0@=V5R9&5N+@`E<R!K;VYF:6=U<FEE<F5N`%!A<W-W;W)T
M(&)E<W3D=&EG96X`2V]N9V\`1&5M;VMR871I<V-H92!297!U8FQI8R!+;VYG
M;P!697)B:6YD=6YG(&9E:&QG97-C:&QA9V5N+@!697)B:6YD=6YG(&9E:&QG
M97-C:&QA9V5N.B``5F5R8FEN9'5N9R!Z=6T@]F9F96YT;&EC:&5N(%-C:&S\
M<W-E;'-E<G9E<B!W=7)D92!A8F=E=VEE<V5N+@!697)B:6YD=6YG('IU;2#V
M9F9E;G1L:6-H96X@4V-H;/QS<V5L<V5R=F5R('=U<F1E(&%B9V5W:65S96XN
M($=R=6YD.B`E<R`H)7,I`%9E<F)I;F1U;F<@>G5M($944"U397)V97(@9F5H
M;&=E<V-H;&%G96X`2V]N=&%K=&4`1&EE($MO;G1A:W1E('=U<F1E;B!E<F9O
M;&=R96EC:"!):')E;2!!9')E<W-B=6-H(&AI;GIU9V5F_&=T+@!);FAA;'1S
M='EP(&1E<B!K;VUP<FEM:65R=&5N($1A=&5I.B``26YH86QT('9O;B`B)7,B
M`%=E:71E<@!#;V]K+4EN<V5L;@!#;V]K:64`2V]P:65R96X`2V]P:65R96X@
M9F5H;&=E<V-H;&%G96XZ("5S`$%U<W=A:&P@:V]P:65R96X`2V]S=&5N+4E$
M`$-O<W1A(%)I8V$`16QF96YB96EN:_QS=&4`1&EE($YA8VAR:6-H="!K;VYN
M=&4@;FEC:'0@;6ET(%!'4"!V97)S8VAL_'-S96QT('=E<F1E;CH@`$1I92!.
M86-H<FEC:'0@:V]N;G1E(&YI8VAT(&UI="!01U`@=6YT97)Z96EC:&YE="!W
M97)D96XZ(`!$:64@3F%C:')I8VAT(&MO;FYT92!N:6-H="!M:70@4R]-24U%
M('9E<G-C:&S\<W-E;'0@=V5R9&5N+@!$:64@3F%C:')I8VAT(&MO;FYT92!N
M:6-H="!M:70@4R]-24U%('5N=&5R>F5I8VAN970@=V5R9&5N+@!+;VYT86MT
M(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W97)D96XN("5S`%9E<F)I;F1U
M;F<@>G5M($Q$05`M4V5R=F5R(&9E:&QG97-C:&QA9V5N+@!+;VYT;W-T86YD
M(&MO;FYT92!N:6-H="#\8F5R<'+\9G0@=V5R9&5N+B`E<P!697)B:6YD=6YG
M('IU;2!,1$%0+5-E<G9E<B!F96AL9V5S8VAL86=E;BX`1E10+59E<F)I;F1U
M;F<@>G5M(%-E<G9E<B`B)7,B(&MO;FYT92!N:6-H="!H97)G97-T96QL="!W
M97)D96XZ("5S`%9E<G1E:6QE<FQI<W1E(&MO;FYT92!N:6-H="!E<G-T96QL
M="!W97)D96XN("5S`%!'4"U$871E;B!K;VYN=&5N(&YI8VAT(&5N='-C:&S\
M<W-E;'0@=V5R9&5N.B``4R]-24U%+41A=&5N(&MO;FYT96X@;FEC:'0@96YT
M<V-H;/QS<V5L="!W97)D96XN`$MO;G1A:W0@:V]N;G1E(&YI8VAT(&=E;/9S
M8VAT('=E<F1E;BX@)7,`5F5R=&5I;&5R;&ES=&4@:V]N;G1E(&YI8VAT(&=E
M;/9S8VAT('=E<F1E;BX@)7,`1&%S($%K='5A;&ES:65R=6YG<W-K<FEP="`B
M)7,B(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN`$1I92!%+4UA:6PM
M061R97-S92!D97,@16UP9N1N9V5R<R!K;VYN=&4@;FEC:'0@97)M:71T96QT
M('=E<F1E;BX`1&%S($%D<F5S<V)U8V@@:V]N;G1E(&YI8VAT(&MO;7!L971T
M(&=E;&5S96X@=V5R9&5N+@!697)T96EL97)L:7-T92!K;VYN=&4@;FEC:'0@
M875S9V5L97-E;B!W97)D96XN("5S`$QI<W1E(&1E<B!697)T96EL97)L:7-T
M96X@:V]N;G1E(&YI8VAT(&%U<V=E;&5S96X@=V5R9&5N+@!$:64@4W1R871E
M9VEE("(E<R(@:V]N;G1E(&YI8VAT(&=E;&%D96X@=V5R9&5N+@!$87,@5F5R
M>F5I8VAN:7,@(B5S(B!K;VYN=&4@;FEC:'0@86YG96QE9W0@=V5R9&5N+@#6
M9F9E;G1L:6-H97(@4V-H;/QS<V5L(&MO;FYT92!N:6-H="!V;VT@4V-H;/QS
M<V5L<V5R=F5R(&=E:&]L="!W97)D96XN`"(E<R(@:V]N;G1E(&YI8VAT('IU
M;2!38VAR96EB96X@9V7V9F9N970@=V5R9&5N+@`E<R!K;VYN=&4@;FEC:'0@
M9V5L97-E;B!W97)D96XN`$1A<R!-86EN=&5N86YC95]487-K($UO9'5L("5S
M(&MO;FYT92!N:6-H="!G9?9F9FYE="!W97)D96X`5F5R>F5I8VAN:7,@(B5S
M(B!K;VYN=&4@;FEC:'0@9V7V9F9N970@=V5R9&5N+@!697)B:6YD=6YG('IU
M;2!,1$%0+5-E<G9E<B!K;VYN=&4@;FEC:'0@:&5R9V5S=&5L;'0@=V5R9&5N
M+@`E<R!K;VYN=&4@;FEC:'0@9V5L97-E;B!W97)D96XN`$1A<R!087-S=V]R
M="!F_'(@9&5N(&%N9V5G96)E;F5N($)E;G5T>F5R(&MO;FYT92!N:6-H="!Z
M=7+\8VMG97-E='IT('=E<F1E;BP@=V5I;"!E:6YI9V4@06YG86)E;B!N:6-H
M="!R:6-H=&EG('=A<F5N+B!697)S=6-H96X@4VEE(&5S(&5R;F5U="!O9&5R
M('=E;F1E;B!3:64@<VEC:"!A;B!):')E;B!!9&UI;FES=')A=&]R+"!W96YN
M(%-I92!W96ET97)E($AI;&9E(&)E;O9T:6=E;BX`04-,(&MO;FYT92!N:6-H
M="!G96QE<V5N('=E<F1E;@!$87,@061R97-S8G5C:"!K;VYN=&4@;FEC:'0@
M9V5L97-E;B!W97)D96XN("5S`%9E<G1E:6QE<FQI<W1E(&MO;FYT92!N:6-H
M="!A=7-G96QE<V5N('=E<F1E;BX@)7,`5F5R=&5I;&5R;&ES=&5N(&MO;FYT
M92!N:6-H="!A=7-G96QE<V5N('=E<F1E;BX@)7,`1&EE(%-E<G9E<F;D:&EG
M:V5I=&5N(&MO;FYT96X@;FEC:'0@875S9V5L97-E;B!W97)D96X`2V]N9FEG
M=7)A=&EO;B!K;VYN=&4@;FEC:'0@>G5R_&-K9V5S971Z="!W97)D96XN`%9E
M<GIE:6-H;FES("(E<R(@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BX`
M)7,M2V]N9FEG=7)A=&EO;B!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R
M9&5N+@!"86-K=7`@9&5R($MO;F9I9W5R871I;VX@:V]N;G1E(&YI8VAT(&=E
M<W!E:6-H97)T('=E<F1E;BX`0F%C:W5P(&1E<B!+;VYF:6=U<F%T:6]N(&MO
M;FYT92!N:6-H="!G97-P96EC:&5R="!W97)D96XZ("5S`$1A<R!!:W1U86QI
M<VEE<G5N9W-S:W)I<'0@:V]N;G1E(&YI8VAT(&YA8V@@(B5S(B!G97-P96EC
M:&5R="!W97)D96XN`$)A8VMU<"!D97(@2V]N9FEG=7)A=&EO;B`E<R!K;VYN
M=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+@!$:64@2V]N9FEG=7)A=&EO
M;B`E<R!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+B!3:64@:_9N
M;F5N(&5N='=E9&5R(&5I;F4@9&5R($WV9VQI8VAK96ET96X@=6YT97(@)7,@
M=F5R=V5N9&5N+"!U;2!D96X@0V]D92!Z=2!S<&5I8VAE<FXL(&]D97(@9&5N
M('5N=&5N<W1E:&5N9&5N($-O9&4@;6%N=65L;"!N86-H("5S(&MO<&EE<F5N
M+@!$97(@3$1!4"U397)V97(@:V]N;G1E(&YI8VAT(&1U<F-H<W5C:'0@=V5R
M9&5N+@`B)7,B(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN`$1E<B!+
M;VYT86MT(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W97)D96XN("5S`%9E
M<G1E:6QE<FQI<W1E(&MO;FYT92!N:6-H="!A:W1U86QI<VEE<G0@=V5R9&5N
M+B`E<P!$:64@2V]N9FEG=7)A=&EO;B!F_'(@(B5S(B!K;VYN=&4@;FEC:'0@
M9V5S<&5I8VAE<G0@=V5R9&5N.B`E<P!$:64@36]Z:6QL82!3:61E8F%R(&MO
M;FYT92!N:6-H="!G969U;F1E;B!W97)D96XN(%-T96QL96X@4VEE('-I8VAE
M<BP@9&%S<R!D:64@4VED96)A<B!G9?9F9FYE="!I<W0N`$1E;2!"96YU='IE
M<B`B)7,B(&MO;FYT96X@9&EE(&9O;&=E;F1E(%)E8VAT92!F_'(@9&5N($]R
M9&YE<B`B)7,B(&YI8VAT('IU9V5W:65S96X@=V5R9&5N.B`E<P!'97KD:&QT
M97(@5&5X=`!,86YD`$MU<G-E`$5R<W1E;&QE;@!,:6YK(&5R<W1E;&QE;@!.
M975E($ED96YT:73D="!A;FQE9V5N`%5N=&5R;W)D;F5R(&5R<W1E;&QE;@!%
M<G-T96QL97)R96-H=&4`2W)E9&ET:V%R=&5N;G5M;65R`$MR;V%T:65N`$MU
M8F$`06MT=65L;&4@-"!0:&%S96X`06MT=65L;&4@4V5S<VEO;G,`06MT=65L
M;&4@6F5I=`!!:W1U96QL92!54DP@:7-T`$%K='5E;&QE($)E;G5T>F5R`$%K
M='5E;&QE<R!7971T97(`1&5R>F5I=&EG92!"961I;F=U;F=E;CH@`$%K='5E
M;&QE<B!3=&EL`$QE9V5N(%-I92!F97-T+"!W96QC:&4@075F9V%B96X@;F%C
M:"!D97(@06YM96QD=6YG(&)E:2`E<R!E<FQE9&EG="!W97)D96X@<V]L;&5N
M+@!!=7-S8VAN96ED96X`075S=V%H;"!A=7-S8VAN96ED96X`6GEP97)N`$MY
M<FEL;&ES8V@@*$M/23@M4BD`2WER:6QL:7-C:"`H5VEN9&]W<RTQ,C4Q*0!+
M>7)I;&QI<V-H+U5K<F%I;FES8V@@*$M/23@M52D`5'-C:&5C:&ES8VAE(%)E
M<'5B;&EK`%14`$133B`H<VEE:&4@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU
M86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!4Y&=L
M:6-H`$1A=&%4<F5E($)R;W=S97(`1&%T96YB86YK86)F<F%G90!$871U;0!%
M;7!F86YG<V1A='5M`$1A='5M<V%U<W=A:&P`5&%G`%-P86QT92!?;/9S8VAE
M;@!$97IE;6)E<@!:86AL96X`16EN>G5G('9E<G)I;F=E<FX`4W1A;F1A<F0`
M4W1A;F1A<F1F87)B90!3=&%N9&%R9&ED96YT:73D=`!3=&%N9&%R9'-H96QL
M`$1E9FEN:71I;VYE;@!,]G-C:&5N`%IE;&QE(&SV<V-H96X`1W)U<'!E(&SV
M<V-H96X`3&]G(&SV<V-H96X`4F5C:'1E(&SV<V-H96X`3F%C:')I8VAT96X@
M;/9S8VAE;B!U;F0@96YT9F5R;F5N`%IE;&QE(&SV<V-H96X`4W!A;'1E(&SV
M<V-H96X`0F5S=&5H96YD92!A;'1E<FYA=&EV92!6;W)L86=E(&SV<V-H96X`
M3F%C:')I8VAT96X@;/9S8VAE;@!296-H=&4@9OQR("(E<R(@;/9S8VAE;@!2
M96-H=&4@9OQR("(E<R(@=6YD(&%L;&4@56YT97)R96-H=&4@;/9S8VAE;C\`
M6F5I;&4@;/9S8VAE;@!!=7-G97?D:&QT92!)9&5N=&ETY'0@;/9S8VAE;@!5
M;G1E<F]R9&YE<B!L]G-C:&5N`$1I92!A:W1U96QL92!3<&%L=&4@;/9S8VAE
M;@!$:64@86MT=65L;&4@6F5I;&4@;/9S8VAE;@!$87,@06MT=6%L:7-I97)U
M;F=S<VMR:7!T("(E<R(@=W5R9&4@9V5L]G-C:'0N`$%U<VQI969E<G5N9W-Z
M96ET`$3D;F5M87)K`$)E<V-H<F5I8F5N(%-I92!D87,@4')O8FQE;0!"97-C
M:')E:6)U;F<`1&5T86EL<R`H875C:"!I;B!(;W)D97,@3&]G9&%T96DI.@!$
M971A:6QS('=U<F1E;B!F_'(@9&5N($%D;6EN:7-T<F%T;W(@;6ET9V5L;V=G
M="X`16YT=VEC:VQU;F<`5&%U<'5N:W0`5&%U<'5N:W0@9&5R(&QE='IT96X@
M4W1U;F1E.B``5&%U<'5N:W0Z(`!6;VX@;&EN:W,@;F%C:"!R96-H=',`5F]N
M(')E8VAT<R!N86-H(&QI;FMS`%9E<GIE:6-H;FES`%IE:70@:6T@,C0M4W1U
M;F1E;BU&;W)M870@86YZ96EG96X_`$%N>F5I9V4M16EN<W1E;&QU;F=E;@!$
M971A:6QI97)T92!6;W)H97)S86=E(&%N>F5I9V5N`%9O<FAE<G-A9V4@*%1!
M1BD@86YZ96EG96X`06YZ96EG969O<FUA=`!%;7!F86YG<V)E<W3D=&EG=6YG
M`$1S8VAI8G5T:0!.:6-H="!L]G-C:&5N`$=R96EF96X@4VEE(&YI8VAT(&1I
M<F5K="!A=68@;6%I;G1E;F%N8V4N<&AP('IU`$5N=&CD;'0@9&EE(&5R<W1E
M(%IE:6QE(&1I92!&96QD;F%M96X_(%=E;FX@:F$L(&1I97-E<R!!=7-W86AL
M:^1S=&-H96X@;6%R:VEE<F5N.@!$;VUI;FEC80!$;VUI;FEK86YI<V-H92!2
M97!U8FQI:P!.;V-H(&ME:6YE;B!:=6=A;F<_($AI97(@86YM96QD96XN`$AE
M<G5N=&5R;&%D96X`)7,@2&5R=6YT97)L861E;@!%<GIE=6=T92!+;VYF:6=U
M<F%T:6]N(&%L<R!02%`M4VMR:7!T(&AE<G5N=&5R;&%D96XN`$%U<W=A:&QL
M:7-T90!$<F]G96X`12U-86EL`$4M36%I;"UN86-H+5--4RUG871E=V%Y(&;\
M<B!0<F]V:61E<BP@9&EE(&5I;F5N('-O;&-H96X@1&EE;G-T('5N=&5R<W3\
M='IE;BX`1D5(3$52`$5C=6%D;W(`0F5A<F)E:71E;@!";&]C:R!B96%R8F5I
M=&5N`$=R=7!P92!B96%R8F5I=&5N`%)E8VAT92!B96%R8F5I=&5N`%)E8VAT
M92!B96%R8F5I=&5N`%)E8VAT92!F_'(@)R5S)R!B96%R8F5I=&5N`$5I;G-T
M96QL=6YG96X@8F5A<F)E:71E;B!F_'(Z`%)E8VAT92!F_'(@(B5S(B!B96%R
M8F5I=&5N`%)E8VAT92!F_'(@)7,@8F5A<F)E:71E;@!":6QD=6YG`,1G>7!T
M96X`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%+4UA:6P`12U-86EL+4%D
M<F5S<V4`1&EE($4M36%I;"U!9')E<W-E;B!M_'-S96X@9VQE:6-H('-E:6XN
M`$4M36%I;"U!9')E<W-E(&UI="!"97-TY'1I9W5N9P!%+4UA:6PM;F%C:"U3
M35,M1V%T97=A>0!3;6EL97ES`$QE97)E($YA8VAR:6-H="X`3&5E<F5S($5R
M9V5B;FES+@!3=6-H8F5G<FEF9F4@;/9S8VAE;@!%:6YF_&=E;B!V;VX@0FEL
M9&5R;B!A=7,@1F]T;V=A;&5R:65N(&EN(&1E;B!497AT(&5R;&%U8F5N/P!+
M;VYT97AT;65N_"!B96D@4F5C:'1S:VQI8VL@86MT:79I97)E;C\`16YD:F%H
M<@!%9&ET;W(@=F5R9W+VWV5R;@!'96)E;B!3:64@96EN92!3:6-H97)H96ET
M<V9R86=E(&5I;BP@9&EE($EH;F5N(&=E<W1E;&QT('=I<F0L('=E;FX@4VEE
M($EH<B!087-S=V]R="!Z=7+\8VMS971Z96X@;?9C:'1E;BP@>BX@0BX@(E=I
M92!L875T970@9&5R($YA;64@26AR97,@2&%U<W1I97)S/R(Z`$AI97(@9&EE
M($)I;&0M55),(&%N9V5B96X`1V5B96X@<VEE(&1I92!"=6-H<W1A8F5N('5N
M=&5N(&5I;CH`Q'%U871O<FEA;"U'=6EN96$`17)I=')E80!&96AL97(`1F5H
M;&5R(&)E:6T@17)S=&5L;&5N(&5I;F5S($)L;V-K<SH@)7,`1F5H;&5R(&)E
M:6T@3/9S8VAE;B!D97,@4WEN8VAR;VYI<V%T:6]N<V%N:V5R<SH@)7,`1F5H
M;&5R(&)E:6T@3/9S8VAE;B!D97,@4WEN8VAR;VYI<V%T:6]N<VQO9W,Z("5S
M`$9E:&QE<B!B96EM($5R>F5U9V5N(&1E<R!);FAA;'1S.B`E<P!&96AL97(@
M8F5I;2#$;F1E<FX@9&5S(%!A<W-W;W)T<SH@)7,`1F5H;&5R(&EN(&1E<B!%
M+4UA:6PM3F%C:')I8VAT+@!&96AL97(@8F5I;2!38VAR96EB96X@=F]N("(E
M<R(N`$5S=&QA;F0`Q'1H:6]P:65N`$5T;FES8VAE<P!%=7)O<&$`06QL92`Q
M-2!-:6YU=&5N`$%L;&4@,B!-:6YU=&5N`$%L;&4@,S`@4V5K=6YD96X`06QL
M92`U($UI;G5T96X`0F5I(&IE9&5R($%N;65L9'5N9P!!;&QE(&AA;&)E(%-T
M=6YD90!!;&QE(#8P(%-E:W5N9&5N`$)E:7-P:65L=V5R=&4Z`$%U<V;\:')E
M;@!697)G<O;?97)N`"<I)R!E<G=A<G1E=`!%:6YZ96QN97,@5V]R="!O9&5R
M(%-U8VAB96=R:69F(&EN($%N9OQH<G5N9W-Z96EC:&5N(&5R=V%R=&5T`%9E
M<F9A;&QS9&%T=6T`17AP;VYE;G0`5F]R9&5R9W)U;F1F87)B90!(;V-H;&%D
M96X@9&5R($MO;F9I9W5R871I;VX@<&5R($944`!"96YU='IE<F5I;G-T96QL
M=6YG96X@:V]N;G1E;B!N:6-H="!G96QA9&5N('=E<F1E;BX`5F5R8FEN9'5N
M9R!Z=6T@3$1!4"!397)V97(@9V5S8VAE:71E<G0N`%9E<F)I;F1U;F<@>G5M
M(%--0BU397)V97(@9V5S8VAE:71E<G0N`$5S(&MO;FYT92!K96EN92!+;W!I
M92!V;VX@(B5S(B!E<G-T96QL="!W97)D96XN`$5S(&MO;FYT92!N:6-H="!N
M86-H("(E<R(@:V]P:65R="!W97)D96XN`$%U9F)A=2!E:6YE;B!N975E;B!3
M05-,+59E<F)I;F1U;F<@:7-T(&9E:&QG97-C:&QA9V5N+@!%<R!K;VYN=&4@
M;FEC:'0@;F%C:"`B)7,B('9E<G-C:&]B96X@=V5R9&5N+@!&96AL97(@8F5I
M;2!,97-E;CH@)7,`2&5I=&5R`$9A;&ML86YD:6YS96QN`$9A<O9E<@!38VAW
M97)E<B!&96AL97(Z`$9A>`!&87AE`$9E8G)U87(`1V5F_&AL=&4@5&5M<&5R
M871U<@!'96;\:&QT92!496UP97)A='5R.B``5F5R96EN>F5L=&4@4V-H875E
M<@!697)E:6YZ96QT92!38VAN965S8VAA=65R`$9E;&1M871R:7@`1FEG;&5T
M($-!4%1#2$$`1FEG;&5T+49O;G0`1FED<V-H:0!$871E:0!!;GIA:&PZ("5S
M($1A=&5I`$%N>F%H;#H@)7,@1&%T96EE;@!$871E:6UA;F%G97(`1&%T96EN
M86UE`$1A=&5I875S=V%H;`!$871E:2U(;V-H;&%D96X`1&%S($AO8VAL861E
M;B!V;VX@1&%T96EE;B!W:7)D(&YI8VAT('5N=&5R<W3\='IT+@!&:6QT97(`
M1FEN;FQA;F0`17)S=&4@2.1L9G1E`$5R<W1E<R!6:65R=&5L`%9E<FCD;'1N
M:7,@>G5R_&-K<V5T>F5N`%5M9')E:&5N`%1E>'1F;'7?`$YE8F5L`$1A<R!6
M97)Z96EC:&YI<R`E<R!E>&ES=&EE<G0@;FEC:'0`4V-H<FEF=&9A<F)E`$5S
M<V5N`$;\<B!"<F]W<V5R+"!D:64@:V5I;F4@0FEL9&5R('5N=&5R<W3\='IE
M;@!6;W)H97)S86=E("A4048I`%9O<FAE<F=E<V%G=&4@5&%G92`H5F]R:&5R
M<V%G96X@96YT:&%L=&5N(%1A9V4@=6YD($[D8VAT92P@96EN(&AO:&5R(%=E
M<G0@:V%N;B!Z=2!E:6YE;2!S96AR(&=R;]]E;B!";&]C:R!F_&AR96XI`%!A
M<W-W;W)T('9E<F=E<W-E;C\`1F]R;75L87)E`$=L_&-K<VME:W,`1VS\8VMS
M:V5K<W1Y<`!';/QC:W-K96MS90!';/QC:W-K96MS92`R`$9O<F5N`%=E:71E
M<FQE:71U;F<`1G(`4F%H;65N`$9R86YK<F5I8V@`175R;W#D:7-C:&5S($9R
M86YK<F5I8V@`1V5F<FEE<F5N9&5R(%)E9V5N`$9R86YZ]G-I<V-H+4=U87EA
M;F$`1G)A;GKV<VES8V@M4&]L>6YE<VEE;@!&<F%N>O9S:7-C:&4@1V5B:65T
M92!I;2!S_&1L:6-H96X@26YD:7-C:&5N($]Z96%N`%9O;@!!=7,@`%9O;&QS
M=.1N9&EG92!"97-C:')E:6)U;F<`5F]L;&UO;F0`5F]L;'-TY&YD:6=E<B!.
M86UE`$=A8G5N`$)I;&1E<B!A=7,@9&EE<V5R($=A;&5R:64`1V%L97)I93H`
M1V%M8FEA`"5S+4MO;F9I9W5R871I;VX@97)Z975G96X`17)Z975G=&5R($-O
M9&4`1V5O<F=I96X`1&5U='-C:&QA;F0`1VAA;F$`1VEB<F%L=&%R`%9O<FYA
M;64`06QL9V5M96EN92!%:6YS=&5L;'5N9V5N`$QO<P!';V5D96P`1V]O9VQE
M($UA<',`1V]O9VQE(%-U8VAE`$=R875S='5F96X`1W)I96-H96YL86YD`$=R
M:65C:&ES8V@@*$E33RTX.#4Y+3<I`$=R]FYL86YD`$=R96YA9&$`1W)U<'!E
M;G9E<G=A;'1U;F<`1W)U<'!E;FYA;65N(&3\<F9E;B!N:6-H="!L965R('-E
M:6X`1W)O=7!?;&1A<#H@1&EE($=R=7!P92`E<R!K;VYN=&4@;FEC:'0@:&EN
M>G5G96;\9W0@=V5R9&5N+B!-96QD=6YG(&1E<R!397)V97)S.B``1W)O=7!?
M;&1A<#H@1&EE($=R=7!P92`E<R!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R
M9&5N`$=R;W5P7VQD87`Z($1I92!'<G5P<&4@)7,@:V]N;G1E(&YI8VAT(&%K
M='5A;&ES:65R="!W97)D96X`1W)U<'!E;@!'=6%D96QO=7!E`$=U86T`1W5A
M=&5M86QA`$=U97)N<V5Y`$=A<W1R96-H=&4`1^1S=&5B=6-H`$=U:6YE80!'
M=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$1E<B!%9&ET;W(@:V%N;B!D:64@
M;&5T>G1E(%IE;&QE(&5I;F5R(%IE:6QE(&YI8VAT(&SV<V-H96XN`$1E<B!%
M9&ET;W(@:V%N;B!D:64@;&5T>G1E(%-P86QT92!E:6YE<B!486)E;&QE(&YI
M8VAT(&SV<V-H96XN`$1E<B!%9&ET;W(@:V%N;B!D:64@;&5T>G1E(%IE:6QE
M(&5I;F5R(%1A8F5L;&4@;FEC:'0@;/9S8VAE;BX`2%144"U!=71H96YT:69I
M>FEE<G5N9R!N:6-H="!G969U;F1E;BX`2&%I=&D`2&%S:"U!;&=O<FET:&UU
M<P!$:65S:6<`W&)E<G-C:')I9G0`2V]P9F5I;G1RY&=E`$AE87)D+2!U;F0@
M36-$;VYA;&1I;G-E;&X`4V-H=V5R92!'97=I='1E<@!(96)RY&ES8V@@*$E3
M3RTX.#4Y+3@M22D`2/9H90!(:6QF90!%9&ET;W)H:6QF90!(:6QF90!(96UI
M<W!H97)E`$1I97,@:7-T(&1E<B!"96=I;FX@9&5R($1A=&5I.@!(;V-H`%]3
M=&%R='-E:71E`%9A=&EK86YS=&%D=`!!9')E<W-E('!R:79A=`!(96EM=F5R
M>F5I8VAN:7,`5&5L969O;B!P<FEV870`2&]N9'5R87,`2&]N9R!+;VYG`$AO
M<F1E`$AO<F1E+TMO;&%B.B!5;F?\;'1I9V4@)7,M6$U,+41A=&5N(&EN($YA
M8VAR:6-H="`E<P!(;W)D92]+;VQA8CH@17,@<&%S<W0@:V5I;F4@3F%C:')I
M8VAT('IU;2!/8FIE:W0@)7,`2&]R9&4O2V]L86(Z($ME:6X@3V)J96MT('9O
M;2!4>7`@)7,@:6X@3F%C:')I8VAT("5S(&=E9G5N9&5N`$AO<F1E+TMO;&%B
M.B`E<R`B)7,B('=U<F1E(&5R9F]L9W)E:6-H(&5N=&9E<FYT`$AO<F1E+TMO
M;&%B.B!$:64@26YT96=R871I;VYS9G5N:W1I;VYE;B!B96[V=&EG96X@9&EE
M(")D;VUX;6PB(%!(4"U%<G=E:71E<G5N9P!(;W)D92]+;VQA8CH@1OQR(&1A
M<R!/8FIE:W0@)7,@:V]N;G1E(&ME:6X@;F5U97(@6$U,+4)A=6T@97)Z975G
M="!W97)D96X`2&]R9&4O2V]L86(Z("5S("(E<R(@:V]N;G1E(&YI8VAT(&5N
M=&9E<FYT('=E<F1E;CH@)7,`2&]R9&4O2V]L86(Z($1I92!-24U%+4E$(&1E
M<R!!8G-C:&YI='1S('9O;2!4>7`@)7,@:V]N;G1E(&YI8VAT(&AE<F%U<V=E
M9G5N9&5N('=E<F1E;BX`2&]R9&4O2V]L86(Z("5S("(E<R(@:V]N;G1E(&YI
M8VAT('-Y;F-H<F]N:7-I97)T('=E<F1E;CH@)7,`2&]R9&4O2V]L86(Z($1I
M92!G96UE:6YS86UE;B!/8FIE:W1E(&MO;FYT96X@;FEC:'0@<WEN8VAR;VYI
M<VEE<G0@=V5R9&5N.B`E<P!(;W)D92]+;VQA8CH@56YB96MA;FYT97,@9V5M
M96EN<V%M97,@3V)J96MT("(E<R(`2&]R:7IO;G1A;&4@3&EN:64`2&]R:7IO
M;G1A;&5R($EN;F5N86)S=&%N9`!(;W)I>F]N=&%L.@!7:64@<VEN9"!3:64@
M:&EE<FAE<F=E;&%N9W0_($)I='1E(&%N(&1I92!%;G1W:6-K;&5R('IU<OQC
M:VUE;&1E;B$I`%=I92!V:65L92!3<&%L=&5N('-O;&QE;B!Z=7-A;6UE;F=E
M9OQG="!W97)D96X_`%=I979I96QE($9E;&1E<B`H4W!A;'1E;BD@9VEB="!E
M<S\`5VEE('9I96QE(%IE:6QE;B!S;VQL96X@>G5S86UM96YG96;\9W0@=V5R
M9&5N/P!,=69T9F5U8VAT:6=K96ET`$QU9G1F975C:'1I9VME:70Z(`!+;VUI
M:V5R`%5N9V%R;@!!;FQE9V5N(&1E<R!)34%0+5!O<W1F86-H<R!I<W0@9F5H
M;&=E<V-H;&%G96XZ("5S`$SV<V-H96X@9&5S($E-05`M4&]S=&9A8VAS(&ES
M="!F96AL9V5S8VAL86=E;CH@)7,`1F5S=&QE9V5N(&1E<B!)34%0+5!O<W1F
M86-H+5%U;W1A(&ES="!F96AL9V5S8VAL86=E;CH@)7,`25`M061R97-S90!)
M4"U!9')E<W-E(&YI8VAT('9E<F;\9V)A<BX`25`M061R97-S92!N:6-H="!I
M;2!E<FQA=6)T96X@0TE$4BU";&]C:RX`5F5R;&5T>G5N9R!D97(@9F5S=&=E
M;&5G=&5N($E0+@!:96EL92!E:6YF_&=E;B!?=F]R`$ES;&%N9`!.=7(@0FEL
M9&5R`$EC;VYS(&;\<B`E<P!":6QD97(@=6YD(%1E>'0`0F5Z96EC:&YU;F<@
M9&5R($ED96YT:73D=`!796YN('-I92!N:6-H="!K;W)R96MT(&%N9V5Z96EG
M="!W:7)D+"`E<RP@=6T@<VEE(&EN(&5I;F5M(&YE=65N($9E;G-T97(@86YG
M97IE:6=T('IU(&)E:V]M;65N+@!796YN(%-I92!M:70@9&5M($EN=&5R;F5T
M($5X<&QO<F5R(&ME:6YE(%-Y;6)O;&4@<V5H96XL(&W\<W-E;B!3:64@9&EE
M<V5S($OD<W1C:&5N(&UA<FMI97)E;BP@=6T@4$Y'+51R86YP87)E;GH@875S
M>G5S=&5L;&5N+@!796YN(%-I92!D:65S92!.86-H<FEC:'0@86X@4W1E;&QE
M(&5I;F4@0FEL9&5S('-E:&5N+"!K86YN($EH<B!"<F]W<V5R(&1A<R!":6QD
M+"!D87,@4VEE(&AO8VAL861E;B!M]F-H=&5N(&YI8VAT(&%N>F5I9V5N+@!"
M:6QD=F]R<V-H874Z`$)I;&0M55),`$)I;&0M55),.@!":6QD('9O;B!'86QE
M<FEE`$)I;&0@=F]N($=A;&5R:64Z`$)I;&0M2&]C:&QA9&5N`$)I;&1E<@!)
M;7!O<G1I97)E;BP@4V-H<FET="`E9`!);7!O<G1I97)T97,@1F5L9#H@)7,`
M26UP;W)T:65R=&4@1F5L9&5R.@!:96EL92!E:6YF_&=E;B!?;F%C:`!5;F?\
M;'1I9V4@06MT:6]N(&%N9V5G96)E;BX`56YG_&QT:6=E<B!"96YU='IE<FYA
M;64@=6YD+V]D97(@4&%S<W=O<G0N`$9A;'-C:&5R($)E;G5T>F5R;F%M92!O
M9&5R($4M36%I;"U!9')E<W-E+B!697)S=6-H96X@4VEE(&5S(&5R;F5U="!O
M9&5R('=E;F1E;B!3:64@<VEC:"!A;B!):')E;B!3>7-T96UA9&UI;FES=')A
M=&]R+"!W96YN(%-I92!W96ET97)E($AI;&9E(&)E;O9T:6=E;BX`16EN>G5G
M('9E<F=R]M]E<FX`26YD:65N`$5I;GIE;&YE($)E;G5T>F5R`$EN9&]N97-I
M96X`26YF;W)M871I;VX`26YF;W)M871I;VYE;@!);F9O<FUA=&EO;F5N(&YI
M8VAT(&UE:'(@=F5R9OQG8F%R+@!697)E<F)T92!-:71G;&EE9&5R`%]3<&%L
M=&4@9&%V;W(@96EN9OQG96X`0FEL9"!H:6YZ=6;\9V5N`%1A8F5L;&4@96EN
M9OQG96X`3&EN:R!E:6YF_&=E;@!37W!A;'1E(&1A;F%C:"!E:6YF_&=E;@!%
M:6YE(&YE=64@4W!A;'1E(&YA8V@@9&5R(&%K='5E;&QE;B!E:6YF_&=E;@!%
M:6YE(&YE=64@4W!A;'1E('9O<B!D97(@86MT=65L;&5N(&5I;F;\9V5N`$5I
M;F4@;F5U92!:96EL92!N86-H(&1E<B!A:W1U96QL96X@96EN9OQG96X`16EN
M92!N975E(%IE:6QE('9O<B!D97(@86MT=65L;&5N(&5I;F;\9V5N`$5I;F5N
M(&YE=65N($%B<V%T>B!N86-H(&1E;2!A:W1U96QL96X@16QE;65N="!E:6YF
M_&=E;@!%:6YE;B!N975E;B!!8G-A='H@=F]R(&1E;2!A:W1U96QL96X@16QE
M;65N="!E:6YF_&=E;@!!;'1E<FYA=&EV92!6;W)L86=E(&5I;F;\9V5N`$=E
M8F5N(%-I92!E:6YE($4M36%I;"U!9')E<W-E(&%N+"!A;B!D:64@9&%S(&YE
M=64@4&%S<W=O<G0@9V5S8VAI8VMT('=E<F1E;B!S;VQL.@!:96QL92!D86YA
M8V@@96EN9OQG96X`6F5L;&4@9&%V;W(@96EN9OQG96X`4W!A;'1E(&1A;F%C
M:"!E:6YF_&=E;@!3<&%L=&4@9&%V;W(@96EN9OQG96X`3F%C:')I8VAT96X@
M:&EN>G5F_&=E;@!!8G-A='H@9&%N86-H(&5I;F;\9V5N`$%B<V%T>B!D879O
M<B!E:6YF_&=E;@!:96EL92!D86YA8V@@96EN9OQG96X`6F5I;&4@9&%V;W(@
M96EN9OQG96X`1V5B96X@4VEE(&1I92!!;G1W;W)T(&%U9B!D:64@4VEC:&5R
M:&5I='-F<F%G92!E:6XZ`$)I;&0@96EN9OQG96XO8F5A<F)E:71E;@!,:6YK
M(&5I;F;\9V5N+V)E87)B96ET96X`6G4@=V5N:6<@1W5T:&%B96XL('5M(&%N
M(&1I92!697)T96EL97)L:7-T92!Z=2!V97)S8VAI8VME;BX`6G4@=V5N:6<@
M1W5T:&%B96XN`$=A;GIZ86AL`$QI<W1E('9O;B!'86YZ>F%H;&5N`%5N9_QL
M=&EG97(@541(+B`H57-E<B!$871A($AE861E<BDN`%5N9_QL=&EG92!:25`M
M1&%T96XN`%5N9_QL=&EG92!!;G=E;F1U;F<N`%5N9_QL=&EG92!"871C:"U)
M1"X`56YG_&QT:6=E($1A=&5N(&5I;F=E8F5N+@!5;F?\;'1I9V4@6FEE;&%D
M<F5S<V4N`%5N9_QL=&EG97,@1&%T96EF;W)M870`56YG_&QT:6=E<B!,:7IE
M;GIS8VAL_'-S96PN`%5N9_QL=&EG97(@3W)T(&%N9V5G96)E;BX`56YG_&QT
M:6=E<B!M<V=?='EP92X`56YG_&QT:6=E(&]D97(@9F5H;&5N9&4@87!I7VED
M+@!5;F?\;'1I9V4@;V1E<B!F96AL96YD92!087)A;65T97(N`%5N9_QL=&EG
M97,@W&)E<G)E8VAT+@!5;F?\;'1I9V4@4&%R=&YE<BU)1"X`56YG_&QT:6=E
M<B!0<F]D=6MT8V]D92X`56YG_&QT:6=E<R!0<F]T;VMO;&PN`%5N9_QL=&EG
M97(@16UP9N1N9V5R.B`B)7,B`%5N9_QL=&EG97,@9V5M96EN<V%M97,@3V)J
M96MT`%5N9_QL=&EG92!5<G-P<G5N9W-A9')E<W-E+@!5;F?\;'1I9V4@56YI
M8V]D92U$871E;BX`26YV96YT87(`075S=V%H;"!U;6ME:')E;@!)<VQA;6ES
M8VAE(%)E<'5B;&EK($ER86X`27)A:P!)<FQA;F0`27-L92!O9B!-86X`5F5R
M96EN>F5L=&4@1V5W:71T97(`27-R865L`$%U<W-T96QL97(`2W5R<VEV`$ET
M86QI96X`2F%M86EK80!*86YU87(`2F%P86X`2F%P86YI<V-H("A)4T\M,C`R
M,BU*4"D`2F5R<V5Y`$IO<F1A;FEE;@!*=6QI`$IU;FD`0FQO8VMS871Z`%IE
M;G1R:65R96X`0FQO8VMS871Z`$QI;FMS(&%U<W)I8VAT96X`4F5C:'1S(&%U
M<W)I8VAT96X`2V%S86-H<W1A;@!/<FEG:6YA;"!B96EB96AA;'1E;C\`2V5N
M:6$`2V5R8F5R;W,M4V5R=F5R(&AA="!!=71H96YT:69I>FEE<G5N9R!Z=7+\
M8VMG97=I97-E;BX`2V5R;F5L+4YE=6QI;F=E`%-C:&S\<W-E;&5R>F5U9W5N
M9P!&:6YG97)A8F1R=6-K(&1E<R!38VAL_'-S96QS`%-C:&S\<W-E;&SD;F=E
M`%-C:&S\<W-E;'1Y<`!38VAL_'-S96QZ=V5C:P!$97(@4V-H;/QS<V5L(&)E
M9FEN9&5T('-I8V@@8F5R96ET<R!A=68@9&5M(/9F9F5N=&QI8VAE;B!38VAL
M_'-S96QS97)V97(N`$MI;F1E<@!+:7)I8F%T:0!$96UO:W)A=&ES8VAE(%9O
M;&MS<F5P=6)L:6,@2V]R96$`4F5P=6)L:6L@2V]R96$`2V]R96%N:7-C:"`H
M155#+4M2*0!+=7=A:70`2VER9VES:7-T86X`06Y?<&%S<V5N`%-P<F%C:&4`
M3&%O<P!,971Z=&4@2.1L9G1E`$QE='IT92!087-S=V]R=.1N9&5R=6YG`$QE
M='IT97,@5FEE<G1E;`!,971Z=&4@06MT=6%L:7-I97)U;F<Z`$QE='IT92!!
M;FUE;&1U;F<Z("5S`$QE='IT92!!;FUE;&1U;F<Z("5S('9O;B`E<P!,971Z
M=&4@06YM96QD=6YG.B!.;V-H(&YI90!,971T;&%N9`!'97-E='H`1F]R;6%T
M`$QE97(@;&%S<V5N(&;\<B!K96EN96X@4F%H;65N`$QI8F%N;VX`3&EN:W,`
M3&EN:V4@W&)E<G-C:')I9G0`3&EN:V4@5V5R=&4`3&5S;W1H;P!%8F5N90!,
M:6)E<FEA`$QI8GEE;@!,:65C:'1E;G-T96EN`%-P<OQH<F5G96X`3&5I8VAT
M97(@4F5G96X`1G+\:"!L96EC:'1E<B!296=E;@!3<.1T97(@3&5I8VAT97(@
M4F5G96X`3&5I8VAT92!296=E;G-C:&%U97(`3&5I8VAT97(@4F5G96X@;6ET
M($=E=VET=&5R`$QE:6-H=&5R(%-C:&YE969A;&P`3&5I8VAT92!38VAN965S
M8VAA=65R`$QI;65R:6-K`$QI;FL`3&EN:RU54DP`3&EN:RU:=6=R:69F<W1A
M<W1E`$QI;FL@=F5R=V5I<W0@875F.@!,:6YK+5II96P`3&EN:RU497AT`$4M
M36%I;"U!9')E<W-E('9E<FQI;FME;C\`3&EN:RU4:71L92U!='1R:6)U=`!,
M:6YK<P!,:6YU>"U';/QC:W-K96MS90!,:7-T("T@0F5N=71Z97(@:V%N;B!D
M96X@3W)D;F5R('-E:&5N`$1A=&5N8F%N:V5N(&%N>F5I9V5N`$AI;&9E96EN
M='+D9V4@86YZ96EG96X`5&%B96QL96X@86YZ96EG96X`3&ES=&5N+4%R8VAI
M=@!,:7-T96XM2&EL9F4`3&ES=&5N+4ED`$QI<W1E;BU"97-I='IE<@!,:7-T
M96XM061R97-S90!,:7-T96XM06YM96QD=6YG`$QI<W1E;BU!8FUE;&1U;F<`
M1&%S($%N>F5I9V5N(&1E<B!397-S:6]N<R!I<W0@9F5H;&=E<V-H;&%G96XZ
M("5S`$1A<R!!;GIE:6=E;B!D97(@0F5N=71Z97(@:7-T(&9E:&QG97-C:&QA
M9V5N.B`E<P!$87,@06YZ96EG96X@9&5R($)E;G5T>F5R(&ES="!N:6-H="!M
M]F=L:6-H+@!,:71E<F%T=7(`3&ET875E;@!,861E+BXN`$QO:V%L92!5:')Z
M96ET.B``4W!R86-H92!U;F0@6F5I=`!/<G0`06YM96QD96X`3&]G(&1E<B!L
M971Z=&5N(%-Y;F-H<F]N:7-A=&EO;BX`06)M96QD96X`06YM96QD96X`06YM
M96QD96%U9F=A8F5N`$1I92!!;FUE;&1U;F<@:7-T(&9E:&QG97-C:&QA9V5N
M+"!W96EL(%-I92!):')E;B!"96YU='IE<FYA;65N(&]D97(@26AR(%!A<W-W
M;W)T(&9A;'-C:"!E:6YG96=E8F5N(&AA8F5N+@!!;FUE;&1U;F<@9F5H;&=E
M<V-H;&%G96XN`$QA;F=E<B!497AT`$QI96)E`$YI961R:6<`2VPN(&=R:65C
M:&ES8VAE($)U8VAS=&%B96X`2VPN(&QA=&5I;FES8VAE($)U8VAS=&%B96X`
M2VPN('+V;6ES8VAE(%IA:&QE;@!,=7AE;6)U<F<`34T`34]41`!-4RU43D5&
M+4%N:&%N9R!E;G1H:65L="!K96EN92!$871E;BX`2$E.5T5)4P!-86-A;P!$
M:64@96AE;6%L:6=E($IU9V]S;&%W:7-C:&4@4F5P=6)L:6L@36%Z961O;FEE
M;@!-861A9V%S:V%R`$UA9VEE`%=E8FUA:6P`12U-86EL($%D;6EN:7-T<F%T
M:6]N`$QI;FL@7V%N;&5G96XN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&ED:79E
M;@!-86QI`$UA;'1A`%9E<G=A;'1E;B!3:64@9&EE($MA=&5G;W)I96XL(&UI
M="!D96YE;B!3:64@16QE;65N=&4@=6YD($5I;G1RY&=E(&ME;FYZ96EC:&YE
M;B!K]FYN96XL('-O=VEE(&1I92!Z=6=E:/9R:6=E;B!&87)B96XN`$UA<#(T
M+4MA<G1E`$UA<%%U97-T+4MA<G1E`%IU;W)D;G5N9V5N(&=E<W!E:6-H97)T
M+@!-Y')Z`$%UWV5N86)S=&%N9`!-:70@1V5L97-E;BTO56YG96QE<V5N+5-T
M871U<R!V97)S96AE;@!-:70@86YD97)E;2!3=&%T=7,@=F5R<V5H96X@*'HN
M0BX@5VEC:'1I9R]"96%N=V]R=&5T*0!-87)S:&%L;&EN<V5L;@!-87)T:6YI
M<75E`%IU9V5O<F1N971E($9E;&1E<@!-875R971A;FEE;@!-875R:71I=7,`
M36%X:6UA;"!E<FQA=6)T97(@2W)E9&ET+@!-87AI;6%L92!.86-H=&EC:'1E
M;G1E:6QE(/QB97)S8VAR:71T96XN`$CV8VAS='1E;7!E<F%T=7(@9&5R(&QE
M='IT96X@,C0@4W1U;F1E;CH@`$CV8VAS='1E;7!E<F%T=7(@9&5R(&QE='IT
M96X@-B!3='5N9&5N.B``36%X:6UA;&4@06YZ86AL(&%N(%!O<G1A;&)L]F-K
M96X`36%X:6UA;&4@3.1N9V4`36%I`$UA>6]T=&4@27-L86YD`$UE9&EZ:6X`
M36ET9VQI961E<@!-96[\;6]D=7,Z`%IE;&QE;B!Z=7-A;6UE;F;\9V5N`$YA
M8VAR:6-H=`!$:64@3F%C:')I8VAT(&MO;FYT92!E<F9O;&=R96EC:"#\8F5R
M<'+\9G0@=V5R9&5N(&%B97(@;FEC:'0@9&%S(%IE<G1I9FEK870@9&5S($%B
M<V5N9&5R<RX`3F%C:')I8VAT(&YI8VAT(&UE:'(@9_QL=&EG+@!.86-H<FEC
M:'1E;G1Y<`!-971A<B!7971T97(`365T87)B;&]C:R!N:6-H="!V97)F_&=B
M87(N`$UE=&%R8FQO8VL@;FEC:'0@=F5R9OQG8F%R+B!$971A:6QS('=U<F1E
M;B!F_'(@9&5N($%D;6EN:7-T<F%T;W(@;6ET9V5L;V=G="X`2V5I;F4@5F5R
M8FEN9'5N9R!Z=7(@365T87)$0BX`365T:&]D90!$:64@365T:&]D92`B)7,B
M(&ES="!N:6-H="!D969I;FEE<G0`365T:&]D92!N:6-H="!D969I;FEE<G0N
M($%U9F=E<G5F96YE($UE=&AO9&4Z("5S`$UE=')I<V-H`$UE>&EK;P!&]F1E
M<FEE<G1E(%-T86%T96X@=F]N($UI:W)O;F5S:65N`$UI='1E`$UI;65T>7``
M5&EE9G-T=&5M<&5R871U<B!D97(@;&5T>G1E;B`R-"!3='5N9&5N.B``5&EE
M9G-T=&5M<&5R871U<B!D97(@;&5T>G1E;B`V(%-T=6YD96XZ(`!$87,@;6EN
M:6UA;&4@4&%S<W=O<G1A;'1E<B!I<W0@;F]C:"!N:6-H="!A8F=E;&%U9F5N
M`%-P:65G96QN`%9E<G-C:&EE9&5N97,`4$5!4BU086ME="!(5%107U)E<75E
M<W0@9F5H;'0N`$9E:&QE;F1E($MO;F9I9W5R871I;VXN(%-I92!M_'-S96X@
M9&EE<V4@:F5T>G0@97)Z975G96XL('=E;FX@4VEE(&1I92!!;G=E;F1U;F<@
M=F5R=V5N9&5N(&WV8VAT96XN`$9E:&QE;F1E($YA8VAR:6-H=&5N+4E$+@!0
M14%2+5!A:V5T($UA:6P@9F5H;'0N`$9E:&QE;F1E(%-I='IU;F=S+4E$+@!-
M;P!%+4UA:6P@36]B:6P`3>3?:6<`Q&YD97)U;F=S9&%T=6T`55),(&)E87)B
M96ET96X`36]D=6QU<P!297!U8FQI:R!-;VQD874`36]N86-O`$UO;F=O;&5I
M`$UO;F%T('5N9"!*86AR`$UO;F%T;&EC:`!-;VYT<V5R<F%T`$UO;F1P:&%S
M96X`365H<B!&96QD97(@:6X@6F5I;&4@)60@86QS(&1I92!E<G=A<G1E=&5N
M("5D(&=E9G5N9&5N+@!-87)O:VMO`-QB97)W:65G96YD(&AE:71E<@#<8F5R
M=VEE9V5N9"!"97?V;&MT`-QB97)W:65G96YD($)E=_9L:W0@=6YD(%=I;F1I
M9P#<8F5R=VEE9V5N9"!3;VYN:6<`3F%C:"!U;G1E;@!.86-H(&QI;FMS`$YA
M8V@@<F5C:'1S`$YA8V@@;V)E;@!.86-H('5N=&5N`$YA8V@@;V)E;@!-;W-A
M;6)I:P!!=7-W86AL;&ES=&4@:6X@;65H<F5R96X@16)E;F5N`$UU;'1I;6%P
M+55++4MA<G1E`$UE:')F86-H875S=V%H;`!-96EN($MO;G1O`$UE:6X@2V]N
M=&\`365I;B!0;W)T86P`365I;B!0;W)T86QL87EO=70`0G5R;6$`3D5)3BP@
M:6-H('-T:6UM92!.24-(5"!Z=0!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`
M3FEE9&5R;&%N9&4`3FEE9&5R;.1N9&ES8VAE($%N=&EL;&5N`$YE='-C87!E
M+4)A<VES+5523`!.971S8V%P92U#02U3<&5R<G5N9W,M55),`$YE='-C87!E
M+4-!+5)I8VAT;&EN:65N+5523`!.971S8V%P92U:971I9FEK871S97)N975E
M<G5N9W,M55),`$YE='-C87!E+5-P97)R=6YG<RU54DP`3F5T<V-A<&4M4U-,
M+5-E<G9E<FYA;64`3F5T<V-A<&4M2V]M;65N=&%R`$YE='-C87!E+5IE<G1I
M9FEK871T>7``3F5T>G=E<FL`3FEE`$YE=6MA;&5D;VYI96X`3F5U92!+871E
M9V]R:64`3F5U;6]N9`!.975E<B!"96YU='IE<FYA;64@*&]P=&EO;F%L*0!.
M975S965L86YD`$YE=65S(%!A<W-W;W)T`$1A<R!N975E(%!A<W-W;W)D('=I
M<F0@86T@)7@@86)L875F96XN`$1I92!N975E;B!087-S=_9R=&5R('-T:6UM
M96X@;FEC:'0@_&)E<F5I;BX`3F5U97,@1F5N<W1E<B`H7V)L86YK*0!.86-H
M<FEC:'1E;@!.97=S9W)U<'!E;@!796ET97(`3N1C:'-T92`T(%!H87-E;@!.
MY&-H<W1E($5I;G-T96QL=6YG96X`5V5I=&5R/@!.:6-A<F%G=6$`3FEG97(`
M3FEG97)I80!.86-H=',`3FEU90!.96EN`$ME:6YE($MO;F9I9W5R871I;VYS
M9&%T96X@=F5R9OQG8F%R+"!U;2!5;G1E<G-C:&EE9&4@86YZ=7IE:6=E;BX`
M2V5I;F4@4W1R871E9VEE('IU;2!%<G-T96QL96X@=F]N($E33RU!8F)I;&1E
M<FX@=F5R9OQG8F%R+@!+96EN92!"871C:"U6;W)L86=E+@!%<R!E>&ES=&EE
M<G0@:V5I;B!";&]C:R!A;B!D97(@86YG96=E8F5N96X@4&]S:71I;VX`2V5I
M;B!+86QE;F1E<FYA;64@9OQR(&1I92!-0T%,+4%U=&AE;G1I9FEZ:65R=6YG
M(&%N9V5G96)E;BX`2V5I;F4@Q&YD97)U;F=E;BX`56YT97)H86QB(&1I97-E
M<B!%8F5N92!K]FYN96X@:V5I;F4@=V5I=&5R96X@56YT97)R96-H=&4@:&EN
M>G5G96;\9W0@=V5R9&5N+@!&_'(@)7,@=W5R9&5N(&ME:6YE($MO;F9I9W5R
M871I;VYS:6YF;W)M871I;VYE;B!A;F=E9V5B96XN`$;\<B!D96X@1E10+59&
M4RU4<F5I8F5R('=U<F1E;B!K96EN92!+;VYF:6=U<F%T:6]N<VEN9F]R;6%T
M:6]N96X@86YG96=E8F5N+@!&_'(@9&5N(%-13"U61E,M5')E:6)E<B!W=7)D
M96X@:V5I;F4@2V]N9FEG=7)A=&EO;G-I;F9O<FUA=&EO;F5N(&%N9V5G96)E
M;BX`1OQR(&1E;B!344PM1&%T96DM5D93+51R96EB97(@=W5R9&5N(&ME:6YE
M($MO;F9I9W5R871I;VYS:6YF;W)M871I;VYE;B!A;F=E9V5B96XN`$ME:6X@
M2W)E9&ET(&UE:'(@_&)R:6<N`$ME:6X@16UP9N1N9V5R(&%N9V5G96)E;BX`
M2V5I;F4@1&%T96D@:&]C:&=E;&%D96X`2V5I;F4@26-O;G,@9V5F=6YD96XN
M`$5S('=U<F1E(&ME:6X@3W)T(&9E<W1G96QE9W0N`$ME:6X@3W)T(&%N9V5G
M96)E;BX`2V5I;F4@3F%C:')I8VAT(&%N9V5G96)E;BX`2V5I;B!.86UE(&%N
M9V5G96)E;BX`2V5I;F4@3G5M;65R(&%N9V5G96)E;BX`2V5I;F4@86YS=/;?
M:6=E;B!';/QC:W-K96MS90!+96EN(%!A<W-W;W)T(&;\<B!D:64@2%144"U!
M=71H96YT:69I>FEE<G5N9R!A;F=E9V5B96XN`$ME:6X@4&%S<W=O<G0@9OQR
M(&1I92!)34%0+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E;BX`2V5I;B!0
M87-S=V]R="!F_'(@9&EE($ME<F)E<F]S+4%U=&AE;G1I9FEZ:65R=6YG(&%N
M9V5G96)E;BX`2V5I;B!087-S=V]R="!F_'(@9&EE($QO9VEN+4%U=&AE;G1I
M9FEZ:65R=6YG(&%N9V5G96)E;BX`2V5I;B!087-S=V]R="!F_'(@9&EE(%!!
M4U-71"U!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B96XN`$ME:6X@4&%S<W=O
M<G0@9OQR(&1I92!334(M075T:&5N=&EF:7II97)U;F<@86YG96=E8F5N+@!+
M96EN(%!F860@>G5M($]P96Y34TPM4')O9W)A;6T@86YG96=E8F5N+B!$87,@
M3W!E;E-33"U0<F]G<F%M;2!W:7)D(&)E;O9T:6=T+"!U;2!02T-3+3$R+41A
M=&5N('9E<F%R8F5I=&5N('IU(&OV;FYE;BX`2V5I;F4@875S<W1E:&5N9&5N
M(%)E9VES=')I97)U;F=E;BX`2V5I;B!3<&5I8VAE<G!L871Z+4MO;G1I;F=E
M;G0@9F5S=&=E;&5G="X`2V5I;F4@4F%H;65N`$ME:6X@5')E;FYZ96EC:&5N
M(&%N9V5G96)E;BX`2V5I;F4@4V5I=&5N`$1A=&5I(&YI8VAT(&=E9G5N9&5N
M`$ME:6YE('1E;7!O<N1R97,@5F5R>F5I8VAN:7,@9OQR(&1E;B!#86-H92!G
M969U;F1E;BX`2V5I;B!"96YU='IE<FYA;64@=6YD+V]D97(@4&%S<W=O<G0@
M86YG96)E;BX`17,@=W5R9&5N(&ME:6YE(&?\;'1I9V5N(%A-3"U$871E;B!Z
M=7+\8VMG96=E8F5N`$ME:6YE(%=E<G1E`$ME:6YE(%9E<G-I;VYS;G5M;65R
M(&EN(&1E<B!/<FEG:6YA;&MO;F9I9W5R871I;VX@9V5F=6YD96XN($5R;F5U
M97)N(%-I92!):')E($MO;F9I9W5R871I;VXN`$ME:6YE(%9E<G-I;VYS;G5M
M;65R(&EN($EH<F5R($MO;F9I9W5R871I;VX@9V5F=6YD96XN($5R;F5U97)N
M(%-I92!):')E($MO;F9I9W5R871I;VXN`$ME:6YE`$ME:6YS("A3=&%N9&%R
M9"!B96YU='IE;BD`3F]R9&ES8V@@*$E33RTX.#4Y+3$P*0!.;W)F;VQK:6YS
M96P`3O9R9&QI8VAE($AE;6ES<&AE<F4`3O9R9&QI8VAE($UA<FEA;F5N`$YO
M<G=E9V5N`$?\;'1I9R!B:7,`1_QL=&EG(&%B`$ME:6X@5F5R>F5I8VAN:7,`
M3FEC:'0@9V5F=6YD96XN`$YI8VAT(&EM<&QE;65N=&EE<G0N`$YI8VAT(&9E
M<W1G96QE9W0`3FEC:'0@=6YT97)S=/QT>G0N`$YO=&EZ96X`3FEC:'1S(&%N
M>G5Z96EG96XL(&)I='1E('IU<OQC:V=E:&5N+@!.;W9E;6)E<@!:86AL`$%N
M>F%H;"!D97(@6F5I8VAE;@!!;GIA:&P@9&5R(%-P86QT96X`06YZ86AL(&1E
M<B!:96EL96X`2V5I;F4@3G5M;65R;B!F_'(@9&EE(%9E<G1E:6QE<FQI<W1E
M(&%N9V5G96)E;BX`3TL`3V)J96MT`$]B:F5K=&5R<W1E;&QE<@!/:W1A;'IA
M:&P`3VMT;V)E<@!&:6QT97(@9OQR(&%N<W3VWVEG92!);FAA;'1E`$+\<F\`
M26AR(&YE=65S(%!A<W-W;W)T(&UU<W,@<VEC:"!V;VX@26AR96T@86QT96X@
M=6YT97)S8VAE:61E;BX`06QT97,@4&%S<W=O<G0`1F%L<V-H97,@86QT97,@
M4&%S<W=O<G0N`$]M86X`3VYC;&EC:RU%=F5N=`!.=7(@24U!4"U397)V97(@
M=6YT97)S=/QT>F5N(&=E;65I;G-A;64@3W)D;F5R+@!.=7(@86YS=/;?:6=E
M($=L_&-K<VME:W-E`$YU<B!E:6YE($4M36%I;"U!9')E<W-E(&5R;&%U8G0N
M`$YU<B!D97(@0F5S:71Z97(@;V1E<B!D97(@4WES=&5M861M:6YI<W1R871O
M<B!K86YN(&1E;B!"97-I='IE<B!O9&5R(&1I92!"97-I='IE<G)E8VAT92#D
M;F1E<FX`26X@;F5U96T@1F5N<W1E<B#V9F9N96X`3W!E;E-33"U&96AL97(Z
M(%-I9VYI97)T92!3+TU)344M1&%T96X@:V]N;G1E;B!N:6-H="!E>'1R86AI
M97)T('=E<F1E;BX`1&EE<V5N($QI;FL@:6X@96EN96T@;F5U96T@1F5N<W1E
M<B#V9F9N96X`0F5T<FEE8G-Y<W1E;0!%:6YS=&5L;'5N9V5N`$5I;G-T96QL
M=6YG96X@9OQR("5S`$YU;6UE<FEE<G1E($QI<W1E`$]R9V%N:7-A=&EO;@!/
M<F=A;FES871I;VYS86)T96EL=6YG`$]R9V%N:7-I97)E;@!/<FEG:6YA;'9O
M<FQA9V4@9&5R($%N=V5N9'5N9P!/<FEG:6YA;'9O<FQA9V4@:6X@)7,Z`%-O
M;G-T:6=E`$%N9&5R92!);F9O<FUA=&EO;F5N`$)E<VET>F5R<F5C:'1E`%!!
M32U!=71H96YT:69I>FEE<G5N9R!I<W0@;FEC:'0@=F5R9OQG8F%R+@!014%2
M.CI-86EL+4)A8VME;F0`1&EG:71A;&4@4$=0+55N=&5R<V-H<FEF=`!01U`M
M=F5R<V-H;/QS<V5L=&4@1&%T96X`UF9F96YT;&EC:&5R(%!'4"U38VAL_'-S
M96P`36ET(%!'4"!U;G1E<GIE:6-H;F5T92]V97)S8VAL_'-S96QT92!$871E
M;@!02%`@0V]D90!02%`@4VAE;&P`5F]R;6ET=&%G<R!L96EC:'1E<B!296=E
M;@!.86-H;6ET=&%G<R!296=E;@!.86-H;6ET=&%G<R!38VAA=65R`$YA8VAM
M:71T86=S(%-C:&YE90!.86-H;6ET=&%G<R!38VAN965S8VAA=65R`$YA8VAM
M:71T86=S(%-O;FYE`$YA8VAM:71T86=S($=E=VET=&5R`$1I92!03U-)6"U%
M<G=E:71E<G5N9R!F96AL=`!?4$A0(%-H96QL`$EN;F5N86)S=&%N9`!086MI
M<W1A;@!086QA=0!"97-E='IT92!086SD<W1I;F5N<VES8VAE($=E8FEE=&4`
M4&%N86UA`%!A<'5A+4YE=6=U:6YE80!087)A9W5A>0!496EL=V5I<V4@0F5W
M]FQK=`!087-S=V]R=`!087-S=V]R="!E<F9O;&=R96EC:"!G9>1N9&5R="X`
M1F%L<V-H97,@4&%S<W=O<G0`2V5I;B!087-S=V]R="!F_'(@9&EE(%)!1$E5
M4RU!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B96XN`%!A<W-W;W)T(&UI="!"
M97-TY'1I9W5N9P!087-S=V]R=#H`4&%S<W=O<G0Z(`!$:64@4&%S<W?V<G1E
M<B!M_'-S96X@9VQE:6-H('-E:6XN`$5I;F;\9V5N`%9O;B!D97(@6G=I<V-H
M96YA8FQA9V4@96EN9OQG96X`4&9A9`!!=7-S=&5H96YD92!296=I<W1R:65R
M=6YG96XZ`%!E<G-O;F5N`%!R;WIE;G0`5V%R='5N9W-A<F)E:71E;B!D=7)C
M:&;\:')E;@!787)T=6YG<V%R8F5I=&5N(&YA8V@@9&5R($%N;65L9'5N9R!D
M=7)C:&;\:')E;C\`4F5C:'1E`%)E8VAT("(E<R(@=W5R9&4@;FEC:'0@9V5L
M]G-C:'0N`%IU9W)I9F8@=F5R=V5I9V5R=`!296-H=&4`4F5C:'1E=F5R=V%L
M='5N9P!097)S]FYL:6-H92!!;F=A8F5N`%!E<G4`2&%U<W1I97)E`%!H:6QI
M<'!I;F5N`%1E;&5F;VX`1F]T;W,`4&ET8V%I<FX`4&EX96P`4&QA='1H96ET
M96X`0FET=&4@:VQI8VME;B!3:64@:6X@96EN92!:96QL90!":71T92!B97-T
MY'1I9V5N(%-I92P@9&%S<R!3:64@9&EE<V5S($5L96UE;G0@;/9S8VAE;B!M
M]F-H=&5N.@!":71T92!B973D=&EG96X@4VEE+"!D87-S(%-I92!D96X@3&EN
M:R!V;VX@9&EE<V5M($5L96UE;G0@96YT9F5R;F5N(&WV8VAT96XN`$)I='1E
M(&5I;F5N($UO;F%T('5N9"!E:6X@2F%H<B!A;F=E8F5N+@!":71T92!G96)E
M;B!3:64@96EN96X@3F%M96X@9OQR(&1I92!N975E($MA=&5G;W)I92!A;CH`
M0FET=&4@96EN92!G_&QT:6=E($E0+4%D<F5S<V4@96EN9V5B96XN`$)I='1E
M(&=E8F5N(%-I92!E:6X@9_QL=&EG97,@1&%T=6T@86X[(/QB97)P<OQF96X@
M4VEE(&1I92!:86AL(&1E<B!486=E(&EN(&1E;2!-;VYA="X`0FET=&4@96EN
M96X@9_QL=&EG96X@6F5I='=E<G0@96EN9V5B96XN`$)I='1E(&=E8F5N(%-I
M92!E:6YE(%IU<V%M;65N9F%S<W5N9R!):')E<R!0<F]B;&5M<R!A;BX`0FET
M=&4@9V5B96X@4VEE($EH<F5N($)E;G5T>F5R;F%M96X@=6YD($EH<B!087-S
M=V]R="!A;@!":71T92!L97-E;B!3:64@<VEC:"!D96X@9F]L9V5N9&5N(%1E
M>'0@<V]R9V;D;'1I9R!D=7)C:"X@4VEE($W<4U-%3B!D:65S96X@0F5D:6YG
M=6YG96X@>G5S=&EM;65N+"!W96YN(%-I92!D:65S97,@4WES=&5M(&)E;G5T
M>F5N(&WV8VAT96XN`$)I='1E(&1E;B!N975E;B!+871E9V]R:65N86UE;B!E
M:6YG96)E;CH`4&]L96X`4&]L:71I:P!5;69R86=E;@!0;W)T=6=A;`!0;W-I
M=&EO;FEE<G5N9R!D:65S92!":6QD97,`4&]S:71I;VYI97)U;F<@9&EE<V5R
M(%1A8F5L;&4`4V5N9&5N(&%N(&1I97-E;B!/<F1N97(@*&YI8VAT(&1U<F-H
M($E-05`I`$YI961E<G-C:&QA9R!I;B!D96X@;&5T>G1E;B`E<R!3='5N9&4H
M;BDZ(`!.:65D97)S8VAL86=S+3QB<B`O/G=A:')S8VAE:6YL:6-H:V5I=`!0
M<F5F<U]L9&%P.B!$:64@8F5N]G1I9W1E($Q$05`M17)W96ET97)U;F<@=W5R
M9&4@;FEC:'0@9V5F=6YD96XN`%!R969S7W-E<W-I;VXZ($1I92!B96[V=&EG
M=&4@4V5S<VEO;BU%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BX`
M3'5F=&1R=6-K`$QU9G1D<G5C:R!A=68@4V5E:/9H93H@`$QU9G1D<G5C:SH@
M`%9O<G-C:&%U`$5I;F4@5F]R<V-H874@9&5S($)I;&1E<R!I;B!E:6YE;2!N
M975E;2!&96YS=&5R(&%N>F5I9V5N`%9O:&5R:6=E($5I;G-T96QL=6YG96X`
M1&]K=6UE;G0@9')U8VME;@!0<FEV871E<B!38VAL_'-S96P`4')O8FQE;64`
M4')O8FQE;6)E<V-H<F5I8G5N9P!0<F]J96MT90!.86-H9G)A9V5T97AT`-9F
M9F5N=&QI8VAE<B!38VAL_'-S96P`06QG;W)I=&AM=7,@9&5S(/9F9F5N=&QI
M8VAE;B!38VAL_'-S96QS`$EN9F]R;6%T:6]N96X@>G5M(/9F9F5N=&QI8VAE
M;B!38VAL_'-S96P`1&%S(/9F9F5N=&QI8VAE+W!R:79A=&4@4V-H;/QS<V5L
M<&%A<B!K;VYN=&4@;FEC:'0@97)S=&5L;'0@=V5R9&5N+@!0=65R=&\@4FEC
M;P!.86-H<FEC:'1E;B!E;F1G_&QT:6<@;/9S8VAE;@!+871A<@!!8F9R86=E
M`%-P96EC:&5R<&QA='HM2V]N=&EN9V5N=`#69F9E;G1L:6-H97(@4E-!(%-C
M:&S\<W-E;"`H)60@0FET*0!!=7-W86AL:VYO<&8`4F5G96X`1G+\:"!296=E
M;@!3<.1T97(@4F5G96X`4F5G96YS8VAA=65R`%-C:&YE97)E9V5N`%)E9V5N
M(&EN(%-C:&YE92#\8F5R9V5H96YD`$=L_&-K<VME:W,`5F5R:.1L=&YI<P!,
M97-E;@!.86-H<FEC:'1E;B!L97-E;@`E<R!W:7)K;&EC:"!L]G-C:&5N/R!$
M:65S97(@5F]R9V%N9R!K86YN(&YI8VAT('+\8VMGY&YG:6<@9V5M86-H="!W
M97)D96XN`$1A=&5N(&1E<R!"96YU='IE<G,@)7,@=VER:VQI8V@@;/9S8VAE
M;C\@1&EE<V5R(%9O<F=A;F<@:V%N;B!N:6-H="!R_&-K9^1N9VEG(&=E;6%C
M:'0@=V5R9&5N+@!&_&AR="!L971Z=&4@06MT:6]N(&5R;F5U="!A=7,`06MT
M=6%L:7-I97)E`$1Y;F%M:7-C:&4@365N_&5L96UE;G1E(&%K='5A;&ES:65R
M96XZ`%!O<G1A;&%N<VEC:'0@86MT=6%L:7-I97)E;CH`4F5G=6SD<F5R($%U
M<V1R=6-K`%9E<F)I;F1U;F=S+4)R;W=S97(`06MT=6%L:7-I97)E;@!"96UE
M<FMU;F=E;@!%;G1F97)N=&4@4V5R=F5R`%-E<G9E<F%D<F5S<V4@*&AT='`Z
M+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!%;G1F97)N96X`0FQO8VL@;/9S
M8VAE;@!3<&%L=&4@;/9S8VAE;@!&;W)M871I97)U;F<@96YT9F5R;F5N`%!A
M87(@;/9S8VAE;@!'97-P96EC:&5R=&5S(%-K<FEP="!A=7,@9&5M('1E;7!O
M<N1R96X@5F5R>F5I8VAN:7,@96YT9F5R;F5N+@!%;G1F97)N90!$:65S97,@
M16QE;65N="!A=7,@9&5M($1O:W5M96YT(&5N=&9E<FYE;@!"96YU='IE<B!L
M]G-C:&5N`$)E;G5T>F5R(&SV<V-H96XZ("5S`$%N9G)A9V4@:V]N;G1E(&YI
M8VAT(&)E86YT=V]R=&5T('=E<F1E;BX@6G5R_&-K9V5G96)E;F5R($9E:&QE
M<F-O9&4Z(`!$97(@9V5W_&YS8VAT92!$:65N<W0@:V]N;G1E(&YI8VAT(&=E
M9G5N9&5N('=E<F1E;BX`(B5S(B!W=7)D92!I;B!D97(@2V]N9FEG=7)A=&EO
M;B!F_'(@)7,@;FEC:'0@86YG96=E8F5N+@`B)7,B('=U<F1E(&EN(&1E<B!6
M1E,M2V]N9FEG=7)A=&EO;B!N:6-H="!A;F=E9V5B96XN`"(E<R(@=W5R9&4@
M:6X@9&5R($MO;F9I9W5R871I;VX@;FEC:'0@86YG96=E8F5N+@!.;W1W96YD
M:6=E<R!&96QD`%IU<OQC:W-E='IE;@!087-S=V]R="!Z=7+\8VMS971Z96X`
M4V5T>F5N(%-I92!):'(@4&%S<W=O<G0@>G5R_&-K`$QE='IT92!!8F9R86=E
M(&5I;F;\9V5N`$5R9V5B;FES<V4`6G5R_&-K('IU($5I;G-T96QL=6YG96X`
M3F5U97,@4&%S<W=O<G0@97)N975T(&5I;F=E8F5N`%+I=6YI;VX`2V]N9FEG
M=7)A=&EO;B!Z=7+\8VMS971Z96X`5UE325=91RU%9&ET;W(@16EN<W1E;&QU
M;F=E;@!2Y'1S96P`4F5C:'1S`%)E8VAT92#<8F5R<V-H<FEF=`!296-H=&4@
M5V5R=&4`7UIE:6QE;F5I9V5N<V-H869T96XN+BX`4F]L;&4`4G5MY&YI96X`
M56T@,3@PL"!D<F5H96X`3F%C:"!L:6YK<R!D<F5H96X`3F%C:"!R96-H=',@
M9')E:&5N`%IE:6QE;F5I9V5N<V-H869T96X`6F5I;&5N96EG96YS8VAA9G1E
M;@!:96EL96XZ`%)E9V5L;@!286AM96X@>G=I<V-H96X@86QL96X@6F5I;&5N
M('5N9"!3<&%L=&5N`%)A:&UE;B!N=7(@>G=I<V-H96X@4W!A;'1E;@!286AM
M96X@;G5R('IW:7-C:&5N(%IE:6QE;@!3=&%R=&5N`%)U<W-I<V-H92!&]G)D
M97)A=&EO;@!2=6%N9&$`4R]-24U%(&MR>71O9W)A<&AI<V-H92!5;G1E<G-C
M:')I9G0`36ET(%,O34E-12!V97)S8VAL_'-S96QT92!.86-H<FEC:'0`4T%3
M3"U!=71H96YT:69I>FEE<G5N9R!I<W0@;FEC:'0@=F5R9OQG8F%R+@!335,M
M5F5R<V%N9`!344P@4VAE;&P`4U%,+4%N=V5I<W5N9R!Z=7(@06)F<F%G92!D
M97(@5V5R=&4`4U-(`$521D],1P!37U%,(%-H96QL`%-A`%-A:6YT($AE;&5N
M80!386EN="!+:71T<R!U;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE
M<G)E('5N9"!-:7%U96QO;@!386EN="!6:6YC96YT('5N9"!D:64@1W)E;F%D
M:6YE;@!';&5I8VAE<B!286AM96X@*%]S96QF*0!386UO80!386X@36%R:6YO
M`%-A;R!4;VUE('5N9"!0<FEN8VEP90!3871E;&QI=&5N<')O=FED97(`4V%U
M9&DM07)A8FEE;@!3<&5I8VAE<FX`(B5S(B!S<&5I8VAE<FX`)7,@<W!E:6-H
M97)N`$5I;G-T96QL=6YG96X@<W!E:6-H97)N`$5R>F5U9W1E($MO;F9I9W5R
M871I;VX@86QS(%!(4"U3:W)I<'0@:6T@=&5M<&]RY')E;B!697)Z96EC:&YI
M<R!):')E<R!397)V97)S('-P96EC:&5R;BX`)7,M2V]N9FEG=7)A=&EO;B!G
M97-P96EC:&5R="X`1&%S($%K='5A;&ES:65R=6YG<W-K<FEP="!W=7)D92!I
M;B`B)7,B(&=E<W!E:6-H97)T+@!697)E:6YZ96QT92!'97=I='1E<@!7:7-S
M96YS8VAA9G0`4W5C:&4`4W5C:&UA<V-H:6YE;@!$871E:65N(&%U<W?D:&QE
M;@!$871U;2!A=7-WY&AL96X`2&EN>G5Z=6;\9V5N9&4@1W)U<'!E;B!A=7-W
MY&AL96X`3F5U96X@0F5S:71Z97(@875S=^1H;&5N`%-E<G9E<B!A=7-WY&AL
M96X`2&EN>G5Z=6;\9V5N9&5N($)E;G5T>F5R(&%U<W?D:&QE;@!!;&QE(&%U
M<W?D:&QE;@!,96=E;B!3:64@86QL92!$871U;7-K;VUP;VYE;G1E;B!F97-T
M+@!/8FIE:W0@875S=^1H;&5N`$ME:6YE;B!A=7-WY&AL96X`5^1H;&5N(%-I
M92!D:64@8F5N]G1I9W1E;B!:96EC:&5N(&%U<R!D96X@:F5W96EL:6=E;B!&
M96QD97)N(&%U<RX@1&%N;B!K]FYN96X@4VEE(&1I97-E(&%U<R!D96T@5&5X
M=&9E;&0@:V]P:65R96X@=6YD(&EN($EH<F4@3F%C:')I8VAT(&5I;F;\9V5N
M+@!7Y&AL96X@4VEE(&1A<R!$871U;7-T<F5N;GIE:6-H96XZ`%?D:&QE;B!3
M:64@9&%S($1A='5M<V9O<FUA=#H`5^1H;&5N(%-I92!D:64@261E;G1I=.1T
M+"!D:64@4VEE(.1N9&5R;B!M]F-H=&5N.@!7Y&AL96X@4VEE(&1A<R!:96ET
M=')E;FYZ96EC:&5N.@!7Y&AL96X@4VEE(&1A<R!:96ET9F]R;6%T.@!7Y&AL
M96X@4VEE('IW96D@>G5S86UM96YG96CV<FEG92!&96QD97(@875S+@!7Y&AL
M96X@4VEE(&5I;B!&87)B<V-H96UA+@!7Y&AL96X@4VEE($EH<F4@8F5V;W)Z
M=6=T92!3<')A8VAE.@!0<F]B;&5M8F5R:6-H="!A8G-C:&EC:V5N`%--4R!V
M97)S8VAI8VME;@!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:65N
M('5N9"!-;VYT96YE9W)O`%-E<FEE;FYU;6UE<@!397)V97)D871E;B!U;F?\
M;'1I9R!O9&5R(&YI8VAT('9E<F;\9V)A<BX`4V5S<W-I;VYV97)W86QT=6YG
M`%-E<W-I;VXM240@86)G96QA=69E;BX`4VET>G5N9V5N`$%U<W=A:&PM4V%T
M>@!,96=E;B!3:64@9&EE($5I;G-T96QL=6YG96X@9F5S="P@9&EE(&5S($EH
M;F5N(&5R;&%U8F5N($EH<B!087-S=V]R="!Z=7+\8VMZ=7-E='IE;BP@9F%L
M;',@<VEE(&5S(&5I;FUA;"!V97)G97-S96X@<V]L;'1E;BX`3&5G96X@4VEE
M(&5N=&9E<FYT92!397)V97(@9F5S="P@875F(&1I92!3:64@=F]N($EH<F5M
M(%!O<G1A;"!A=7,@>G5G<F5I9F5N(&WV8VAT96XN`%?D:&QE;B!3:64@26AR
M92!B979O<GIU9W1E(%-P<F%C:&4L(%IE:71Z;VYE('5N9"!$871U;7-E:6YS
M=&5L;'5N9V5N+@!,96=E;B!3:64@9&%S(&1I92!3=&%R=&%N=V5N9'5N9RP@
M9&%S($9A<F)S8VAE;6$L(&1I92!396ET96YA:W1U86QI<VEE<G5N9R!U;F0@
M86YD97)E($%N>F5I9V5E:6YS=&5L;'5N9V5N(&9E<W0N`$MO;F9I9W5R871I
M;VX`06MT=6%L:7-I97)U;F=S<VMR:7!T92!S:6YD('9E<F;\9V)A<@!-96AR
M97)E('!A<W-E;F1E($]R=&4@;6ET(&1I97-E;2!087)A;65T97(Z(`!397EC
M:&5L;&5N`$5I;FMA=68`2W5R>F4@6G5S86UM96YF87-S=6YG`%-O;&QE;B!4
M87-T96YK;VUB:6YA=&EO;F5N(&;\<B!D:64@;65I<W1E;B!,:6YK<R!A:W1I
M=FEE<G0@=V5R9&5N/P!:96EG96X`56YT97)S8VAI961E('IW:7-C:&5N(&1E
M<B!A:W1U96QL96X@=6YD(&1E<B!G97)A9&4@97)Z975G=&5N($MO;F9I9W5R
M871I;VX@86YZ96EG96XN`$%N>F5I9V5N+"!W86YN(&1I92!L971Z=&4@06YM
M96QD=6YG(&5R9F]L9W0@:7-T/P!%<FAA;'1E;B!D97,@3W)I9VEN86QS(&5R
M;?9G;&EC:&5N`$%U<W?D:&QE<B!A;GIE:6=E;@!797)K>F5U9VQE:7-T92!F
M_'(@5&%B96QL96X@86YZ96EG96X_`$1A<R`E<RU-96[\(&%U9B!D97(@;&EN
M:V5N(%-E:71E(&%N>F5I9V5N/P!$:6%L;V<@9OQR(%1A8F5L;&5N>F5L;&5N
M96EG96YS8VAA9G1E;B!A;GIE:6=E;@!$:6%L;V<@9OQR(%1A8F5L;&5N96EG
M96YS8VAA9G1E;B!A;GIE:6=E;@!$:6%L;V<@9OQR(%1A8F5L;&5N>F5I;&5N
M96EG96YS8VAA9G1E;B!A;GIE:6=E;@!$:6%L;V<@9OQR($)I;&1E:6=E;G-C
M:&%F=&5N(&%N>F5I9V5N`$AO8VAL861E;B!E<FWV9VQI8VAE;@!38VAA=65R
M`$9R_&@@4V-H875E<@!3<.1T97(@4V-H875E<@!38VAA=65R(&EN(&1E<B!5
M;6=E8G5N9P!697)K;&5I;F5R;@!697)K;&5I;F5R;B!O9&5R('9E<G-C:&EE
M8F5N(%-I92!E<G-T(&1I92!B96YA8VAB87)T96X@0FSV8VME`%-I97)R82!,
M96]N90!296=I<W1R:65R96X`4VEG;F%T=7(`4VEG;F%T=7)A;&=O<FET:&UU
M<P!3:6YG87!U<@!'<O;?90!787)T=6YG<V%R8F5I=&5N(/QB97)S<')I;F=E
M;@!3;&]W86ME:0!3;&]W96YI96X`4V-H;F5E`%-C:&YE97-C:&%U97(`4V-H
M;F5E<V-H875E<@!&<OQH(%-C:&YE97-C:&%U97(`4W#D=&5R(%-C:&YE97-C
M:&%U97(`4V-H;F5E:/9H93H@`%-C:&YE96UE;F=E(&%L<R!787-S97(Z(`!3
M;VQO;6]N:6YS96QN`%-O;6%L:65N`$QI961E<B`F($=E9&EC:'1E`$%U<W=A
M:&P@9&5R(%-O<G1I97)R96EH96YF;VQG90!5<G-P<G5N9W-A9')E<W-E`%/\
M9&%F<FEK80!3_&1E=7)O<.1I<V-H("A)4T\M.#@U.2TS*0!3_&1G96]R9VEE
M;B!U;F0@9&EE(%/\9&QI8VAE;B!386YD=VEC:&EN<V5L;@!3_&1L:6-H92!(
M96UI<W!H97)E`$%B<W1A;F0@>G=I<V-H96X@875F96EN86YD97(@9F]L9V5N
M9&5N(%IE;&QE;@!!8G-T86YD('IW:7-C:&5N($EN:&%L="!U;F0@4F%H;65N
M('9O;B!:96QL96X`06)S=&%N9&AA;'1E<@!!8G-T86YD`$%B<W3D;F1E`%-P
M86YI96X`4W!A;0!3;VYD97)Z96EC:&5N+45I;F=A8F4`6F5L;&4@=&5I;&5N
M`%-P86QT92!T96EL96X`6F5I;&4@=&5I;&5N`%-P;W)T`%-R:2!,86YK80!3
M=&%N9&%R9`!3=&%R(%1R96L`4W1A<G1J86AR`$)U;F1E<W-T86%T(&]D97(@
M4')O=FEN>@!3=&%T=7,`4W!E:6-H97)F;W)M870`4W1R8=]E`$1U<F-H9V5S
M=')I8VAE;@!:96EC:&5N;&ES=&4`1&]M86EN(&%U<R!D97(@061R97-S92!E
M;G1F97)N96X`4W1I;"!;0U-370!3;P!5;G1E<G9E<GIE:6-H;FES("(E<R(@
M;FEC:'0@9V5F=6YD96XN`$)E=')E9F8`06)S8VAI8VME;@!$:64@4F5G:7-T
M<FEE<G5N9W-A;F9R86=E(&;\<B`B)7,B('=U<F1E(&%B9V5S8VAI8VMT+B!3
M:64@:_9N;F5N('-I8V@@;F]C:"!N:6-H="!A;FUE;&1E;BP@<V]L86YG92!D
M:64@06YF<F%G92!N;V-H(&YI8VAT(&)E<W3D=&EG="!W=7)D92X`5&EE9F=E
M<W1E;&QT`$5R9F]L9P`B)7,B('=U<F1E(&5R9F]L9W)E:6-H(&AI;GIU9V5F
M_&=T+@!$871E;B!D97,@0F5N=71Z97)S("(E<R(@=W5R9&4@97)F;VQG<F5I
M8V@@9V5L]G-C:'0N`"(E<R(@=W5R9&4@97)F;VQG<F5I8V@@9V5L]G-C:'0N
M`"(E<R(@=W5R9&4@97)F;VQG<F5I8V@@9V5L]G-C:'0N`$MO;F9I9W5R871I
M;VX@97)F;VQG<F5I8V@@>G5R_&-K9V5S971Z="X@4V5I=&4@;F5U(&QA9&5N
M+"!U;2!D:64@Q&YD97)U;F=E;B!A;GIU>F5I9V5N+@!"86-K=7`@9&5R($MO
M;F9I9W5R871I;VX@97)F;VQG<F5I8V@@9V5S<&5I8VAE<G0N`$)A8VMU<"!D
M97(@2V]N9FEG=7)A=&EO;B`E<R!E<F9O;&=R96EC:"!G97-P96EC:&5R="X`
M(B5S(B!W=7)D92!E<F9O;&=R96EC:"!A:W1U86QI<VEE<G0`)7,@=W5R9&4@
M97)F;VQG<F5I8V@@9V5S<&5I8VAE<G0`4W5D86X`6G5S86UM96YF87-S=6YG
M`%-O;FYE;F%U9F=A;F<`4V]N;F5N=6YT97)G86YG`%-O;FYI9P!3;VYN96YA
M=69G86YG`%-O;FYE;F%U9B]U;G1E<F=A;F<`4V]N;F5N875F9V%N9SH@`%-O
M;FYE;G5N=&5R9V%N9P!3;VYN96YU;G1E<F=A;F<Z(`!(;V-H9V5S=&5L;'0`
M4W5P<&]R=`!3=7)I;F%M`$YA8VAN86UE`%-V86QB87)D('5N9"!*86X@36%Y
M96X`4W=A<VEL86YD`%-C:'=E9&5N`%-C:'=E:7H`4WEN8VAR;VYI>F%T:6]N
M<VQO9R!G96SV<V-H=`!&;W)M871F96AL97(@:6X@4W5C:&)E9W)I9F9E;@!!
M<F%B:7-C:&4@4F5P=6)L:6L@4WER:65N`$=E=VET=&5R`$=E=VET=&5R('5N
M9"!7:6YD:6<`1V5W:71T97(`1G+\:"!'97=I='1E<@!44U8M1&%T96D`5&%B
M96QL96YE:6=E;G-C:&%F=&5N`%1A8F5L;&4`5&%B96QL96YE:6=E;G-C:&%F
M=&5N`%1A:7=A;@!486EW86XL(&-H:6YE<VES8VAE(%!R;W9I;GH`5&%D<V-H
M:6MI<W1A;@!697)E:6YI9W1E(%)E<'5B;&EK(%1A;G-A;FEA`%II96PZ`$%U
M9F=A8F5N`%1E;&5F;VYN=6UM97(`5&5M<&5R871U<B!D97(@;&5T>G1E;B!3
M='5N9&4Z(`!496UP97)A='5R`%1E;7!E<F%T=7(Z(`!496UP97)A='5R/&)R
M("\^*"5S36%X)7,O)7--:6XE<RD@)F1E9SLE<P!6;W)L86=E("(E<R(@;FEC
M:'0@9V5F=6YD96XN`%9O<FQA9V5N=F5R=V%L='5N9P!497AT`$YU<B!497AT
M`$%U<W)I8VAT=6YG`%1E>'0@3V)E;@!$;P!4:&%I;.1N9&ES8V@@*%1)4RTV
M,C`I`%1H86EL86YD`$1I92!&5%`M17AT96YS:6]N(&ES="!N:6-H="!V97)F
M_&=B87(N`$1I92!#:')O;FEK('-T96AT(&YI8VAT('IU<B!697)F_&=U;F<N
M`$1I92!(;W)D92]+;VQA8B!);G1E9W)A=&EO;G-F=6YK=&EO;F5N('5N=&5R
M<W3\='IE;B`B)7,B(&YI8VAT`$1I92!)35-0+4QO9V1A=&5I(&MO;FYT92!N
M:6-H="!E<G-T96QL="!W97)D96XN`$1I92!-86EN=&5N86YC93HZ($ML87-S
M92!K;VYN=&4@;FEC:'0@9V5L861E;B!W97)D96X`1&%S($5I;G-T96QL=6YG
M96XM1F5N<W1E<B!I<W0@9V5S8VAL;W-S96X@=V]R9&5N+B!!8F)R=6-H+@!$
M97(@061M:6YI<W1R871O<B!M=7-S(&5I;B!P97)M86YE;G1E<R!296-H=&4M
M0F%C:V5N9"!E:6YR:6-H=&5N+"!W96YN(%-I92!D:64@4F5C:'1E=F5R=V%L
M='5N9R!N=71Z96X@;?9C:'1E;BX`3G5R('5N=&5N`$1I92!)1"U.=6UM97(@
M9&5S($MO;G1A:W1S('=U<F1E(&YI8VAT(&%N9V5B96XL('=A<B!L965R(&]D
M97(@:V]N;G1E(&EN(&1E<B!$871E;F)A;FL@;FEC:'0@9V5F=6YD96X@=V5R
M9&5N+@!$97(@2V]N=&%K="!W=7)D92!E<F9O;&=R96EC:"!):')E;2!!9')E
M<W-B=6-H(&AI;GIU9V5F_&=T+@!$97(@4$=0+5-I9VYA='5R8FQO8VL@=VER
M9"!B96[V=&EG="P@=6T@9&EE('5N=&5R>F5I8VAN971E($YA8VAR:6-H="!Z
M=2#\8F5R<'+\9F5N+@!$:64@240M3G5M;65R(&1E<B!697)T96EL97)L:7-T
M92!W=7)D92!N:6-H="!A;F=E8F5N+"!W87(@;&5E<B!O9&5R(&MO;FYT92!I
M;B!D97(@1&%T96YB86YK(&YI8VAT(&=E9G5N9&5N('=E<F1E;BX`1&EE(%9E
M<G1E:6QE<FQI<W1E('=U<F1E(&YI8VAT(&%N9V5G96)E;BX`1&EE(%9E<G-C
M:&S\<W-E;'5N9W-F=6YK=&EO;F5N(&)E;O9T:6=E;B!E:6YE('-I8VAE<F4@
M4V5R=F5R=F5R8FEN9'5N9RX`1&EE($1A=&5I("5S('-O;&QT92!E:6YE;B`E
M<R!%:6YT<F%G(&5N=&AA;'1E;BX`1&EE($1A=&5I("5S('-O;&QT92!E:6YI
M9V4@)7,@16EN='+D9V4@96YT:&%L=&5N+@!$:64@1&%T96D@96YT:&EE;'0@
M:V5I;F4@1&%T96XN`$AI97(@<VEN9"!D:64@2V]P9F5I;G1RY&=E(&;\<B!D
M:65S92!M97-S86=E+W)F8S@R,B!.86-H<FEC:'0N`$1E<B!6;VQL8FEL9&UO
M9'5S('9E<G5R<V%C:'0@875F($=R=6YD('9O;B!&96AL97)N(&EM($EN=&5R
M;F5T($5X<&QO<F5R(&)E:V%N;G1E<FUAWV5N(%!R;V)L96UE(&UI="!D:65S
M96T@0G)O=W-E<BP@9&EE('=I<B!N:6-H="!U;6=E:&5N(&OV;FYE;BX@56YT
M97(@56US=.1N9&5N(&5R:&%L=&5N(%-I92!E:6YE(&9E:&QE<FAA9G1E($%N
M>F5I9V4L(&9E:&QE;B!%9&ET;W)F=6YK=&EO;F5N+"!O9&5R(&1E<B!"<F]W
M<V5R('-T_')Z="!A8BX@075F(&5I;F5M(%=I;F1O=R`Y>"!3>7-T96T@=V5R
M9&5N(%-I92!V97)M=71L:6-H(&5I;F4@)T%L;&=E;65I;F4@4V-H=71Z=F5R
M;&5T>G5N9R<@97)H86QT96X@=6YD(&W\<W-E;B!D96X@4F5C:&YE<B!N974@
M<W1A<G1E;BY<;EQN4VEE('=U<F1E;B!G97=A<FYT+B!":71T92!D<OQC:V5N
M(%-I92!A=68@3TLL('=E;FX@4VEE(&YO8V@@:6UM97(@9&5N(%9O;&QB:6QD
M;6]D=7,@=F5R=V5N9&5N(&WV8VAT96XN`$1I92!)9&5N=&ETY'0@(B5S(B!W
M=7)D92!G96SV<V-H="X`3G5R(&QI;FMS`$1E<B!/<G0@9&5S($=N=5!'+5!R
M;V=R86UM<R!M=7-S(&1E<B!#<GEP=%]P9W`Z.B!+;&%S<V4@_&)E<F=E8F5N
M('=E<F1E;BX`1&EE($YA8VAR:6-H="!M:70@9&5M($)E=')E9F8@(B4S)',B
M+"!D:64@86T@)3$D<R!A;B`E,B1S(&=E<V-H:6-K="!W=7)D92P@:7-T(&%N
M9V5Z96EG="!W;W)D96XN"D1A<R!H96G?="!N:6-H="P@9&%S<R!D:64@3F%C
M:')I8VAT(&%U8V@@9V5L97-E;B!O9&5R('9E<G-T86YD96X@=W5R9&4N`$YA
M;64@9OQR(&1E;B!,:6YK('IU<B!.86-H<FEC:'1E;F5R<W1E;&QU;F<`1&EE
M($%N>F%H;"!D97(@1F5L9&5R(&UU<W,@86QS(%IA:&P@86YG96=E8F5N('=E
M<F1E;BX`1&%S($]P96Y34TPM36]D=6P@=VER9"!F_'(@9&EE($AO<F1E7T-R
M>7!T7W-M:6UE.CH@2VQA<W-E(&)E;O9T:6=T+@!$:64@0F5N=71Z97)E:6YS
M=&5L;'5N9R`B)7,B(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W97)D96XL
M('=E:6P@:6AR92!$871E;B!D:64@;6%X:6UA;"!E<FQA=6)T92!'<O;?92#\
M8F5R<V-H<F5I=&5N`$1A<R!0<F]G<F%M;2!F_'(@9&EE($%N>F5I9V4@9&EE
M<V5S($1A=&5I='EP<R`H)7,I('=U<F1E(&YI8VAT(&=E9G5N9&5N+@!$87,@
M06YF_&AR=6YG<WIE:6-H96X@;75S<R!A;',@96EN>F5L;F5S(%IE:6-H96X@
M86YG96=E8F5N('=E<F1E;BX`3G5R(&QI;FMS('5N9"!R96-H=',`3G5R(')E
M8VAT<P!$87,@5')E;FYZ96EC:&5N(&UU<W,@86QS(&5I;GIE;&YE<R!:96EC
M:&5N(&%N9V5G96)E;B!W97)D96XN`$1E<B!397)V97(@(B5S(B!W=7)D92!E
M;G1F97)N="X`1&5R(%-E<G9E<B`B)7,B('=U<F1E(&=E<W!E:6-H97)T+@!$
M:64@4F5G:7-T<FEE<G5N9W-A;F9R86=E('9O;B`E<R!W=7)D92!E;G1F97)N
M="X`1&EE(&%N9V5G96)E;F4@6F5I;&4@*"5D*2!E>&ES=&EE<G0@;FEC:'0N
M`$1I92!T96UP;W+D<F4@1&%T96D@(B5S(B!E>&ES=&EE<G0@;FEC:'0N`$1E
M<B!497AT+"!D96X@4VEE(&%N9V5G96)E;B!H86)E;BP@96YT<W!R:6-H="!N
M:6-H="!D96T@5&5X="!A=68@9&5M($)I;&1S8VAI<FTN`$YU<B!O8F5N('5N
M9"!U;G1E;@!.=7(@;V)E;@!$:64@:&]C:&=E;&%D96YE;B!$871E;B!S:6YD
M(&YA8V@@9&5M(&QE='IT96X@4V-H<FET="!V97)L;W)E;B!G96=A;F=E;BX`
M1&EE(&AO8VAG96QA9&5N92!$871E:2!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE
M<G0@=V5R9&5N+@!$97(@=V5A=&AE<BYC;VT@0FQO8VL@:7-T(&YI8VAT('9E
M<F;\9V)A<BX`5&AE;65N+59E<GIE:6-H;FES("(E<R(@;FEC:'0@9V5F=6YD
M96XN`$5S('-I;F0@:V5I;F4@16EN<W1E;&QU;F=E;B!V97)F_&=B87(N`$5S
M(&=I8G0@:V5I;F4@86YZ96EG8F%R96X@3F%C:')I8VAT96YT96EL92X`1&EE
M<V5S($9E;&0@96YT:.1L="!Z=2!V:65L92!:96EC:&5N+B!3:64@:&%B96X@
M)7,@6F5I8VAE;B!A;F=E9V5B96X[(%-I92!M_'-S96X@=V5N:6=E<B!A;',@
M)7,@86YG96)E;BX`0F5I;2!(:6YZ=6;\9V5N('9O;B`B)7,B('IU;2!3>7-T
M96T@:7-T(&5I;B!0<F]B;&5M(&%U9F=E=')E=&5N.B`E<P!"96EM($SV<V-H
M96X@9&5R($1A=&5N('9O;B!"96YU='IE<B`B)7,B(&ES="!E:6X@4')O8FQE
M;2!A=69G971R971E;CH@`$)E:6T@3/9S8VAE;B!V;VX@(B5S(B!A=7,@9&5M
M(%-Y<W1E;2!I<W0@96EN(%!R;V)L96T@875F9V5T<F5T96XZ(`!"96EM($%K
M='5A;&ES:65R96X@=F]N("(E<R(@:7-T(&5I;B!0<F]B;&5M(&%U9F=E=')E
M=&5N.B`E<P!"96EM($AO8VAL861E;B!D97(@1&%T96D@:7-T(&5I;B!&96AL
M97(@875F9V5T<F5T96XN("5S('=U<F1E(&YI8VAT(&AO8VAG96QA9&5N+@!"
M96EM($AO8VAL861E;B!D97(@1&%T96D@:7-T(&5I;B!&96AL97(@875F9V5T
M<F5T96XN("5S('=A<B!G<O;?97(@86QS(&1I92!M87AI;6%L(&5R;&%U8G1E
M($=R]M]E("@E9"!">71E<RDN`$)E:6T@2&]C:&QA9&5N(&1E<B!$871E:2!I
M<W0@96EN($9E:&QE<B!A=69G971R971E;BX@)7,@=W5R9&4@;G5R('1E:6QW
M96ES92!H;V-H9V5L861E;BX`0F5I;2!!;GIE:6=E;B!D:65S97,@3F%C:')I
M8VAT96YT96EL<R!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX`0F5I;2!)
M;7!O<G1I97)E;B!D97(@2V]N=&%K=&1A=&5N(&ES="!E:6X@1F5H;&5R(&%U
M9F=E=')E=&5N+@!"96EM($EM<&]R=&EE<F5N(&1E<B!I0V%L96YD87(@1&%T
M96X@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN`$1A<R!+;VYF:6=U<F%T
M:6]N<RU&;W)M=6QA<B!E;G1H:65L="!E:6YE;B!&96AL97(N(%9I96QL96EC
M:'0@:&%B96X@4VEE(&5I;B!09FQI8VAT9F5L9"!L965R(&=E;&%S<V5N+@!"
M96EM($%U<V;\:')E;B!D97(@86YG96=E8F5N96X@061R97-S8G5C:&9U;FMT
M:6]N(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B!":71T92!V97)S=6-H
M96X@4VEE(&5S('-PY'1E<B!N;V-H(&5I;FUA;"X`0F5I(&1E<B!!:W1U86QI
M<VEE<G5N9R!D97(@2V]N=&%K=&1E=&%I;',@:7-T(&5I;B!&96AL97(@875F
M9V5T<F5T96XN($)I='1E('9E<G-U8VAE;B!3:64@97,@<W#D=&5R(&YO8V@@
M96EN;6%L+@!"96D@9&5R($%K='5A;&ES:65R=6YG(&1E<B!697)T96EL97)L
M:7-T92!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX@0FET=&4@=F5R<W5C
M:&5N(%-I92!E<R!S<.1T97(@;F]C:"!E:6YM86PN`$1I97-E<B!)34%0+5-E
M<G9E<B!U;G1E<G-T_'1Z="!K96EN92!G96UE:6YS86UE;B!/<F1N97(N`$1I
M97,@<V-H96EN="!K96EN(&?\;'1I9V5S(%)!4BU!<F-H:78@>G4@<V5I;BX`
M1&EE<R!S8VAE:6YT(&ME:6X@9_QL=&EG97,@6DE0+4%R8VAI=B!Z=2!S96EN
M+@!$:65S('-C:&5I;G0@:V5I;F4@9_QL=&EG92!+87)T96YN=6UM97(@>G4@
M<V5I;BX`1&EE<V5R(%1R96EB97(@97)L875B="!D87,@5F5R<V-H:6-K96X@
M=F]N($YA8VAR:6-H=&5N(&1U<F-H(&1E;B!#;&EC:V%T96QL+4=A=&5W87D@
M*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@;6ET($AI;&9E(&1E<B!(5%10+4%0
M22X`1&EE<V5R(%1R96EB97(@97)L875B="!D87,@5F5R<V-H:6-K96X@=F]N
M($YA8VAR:6-H=&5N(&1U<F-H(&1E;B!724XM1V%T97=A>2`H:'1T<#HO+W=I
M;G!L8RYC;VTI(&UI="!(:6QF92!D97(@2%144"U!4$DN`$1I97-E<B!4<F5I
M8F5R(&5R;&%U8G0@9&%S(%9E<G-C:&EC:V5N('9O;B!.86-H<FEC:'1E;B!D
M=7)C:"!D96X@<VUS,FUA:6PM1V%T97=A>2`H:'1T<#HO+W-M<S)M86EL+F-O
M;2D@;6ET($AI;&9E(&1E<B!(5%10+4%022X`1&EE<V5R(%1R96EB97(@97)L
M875B="!D87,@5F5R<V-H:6-K96X@=F]N($YA8VAR:6-H=&5N('!E<B!33510
M(&1U<F-H(&1E;B!6;V1A9F]N92U)=&%L:65N+4=A=&5W87D@875S<V-H;&EE
MWVQI8V@@86X@5F]D869O;F4M3G5M;65R;BX@1&%F_'(@=VER9"!E:6X@12U-
M86EL+4MO;G1O(&)E:2!6;V1A9F]N92!)=&%L:65N("AH='1P.B\O=W=W+C$Y
M,"YI="D@8F5N]G1I9W0N`$1I97-E<R!&96QD(&ES="!N;W1W96YD:6<N`$1I
M97-E<R!&96QD(&1A<F8@;G5R(&=A;GIE(%IA:&QE;B!E;G1H86QT96XN`$1I
M97-E<R!&96QD(&1A<F8@;G5R(%IA:&QE;B!U;F0@96EN96X@4'5N:W0@96YT
M:&%L=&5N+@!$:65S97,@1F5L9"!D87)F(&YU<B!/:W1A;'IA:&QE;B!E;G1H
M86QT96XN`$1I97-E<R!&96QD(&UU<W,@96EN92!K;VUM82T@;V1E<B!L965R
M>F5I8VAE;F=E=')E;FYT92!,:7-T92!V;VX@9V%N>F5N(%IA:&QE;B!E;G1H
M86QT96X`1&EE<V5S($9E;&0@;75S<R!E:6YE(&?\;'1I9V4@6F%H;"!E;G1H
M86QT96XN`$1I97-E<R!&96QD(&UU<W,@96EN96X@1F%R8G=E<G0@:6T@:&5X
M861E>FEM86QE;B!21T(M1F]R;6%T(&5N=&AA;'1E;BP@>BX@0BX@)R,Q,C,T
M868G+@!$:65S97,@1F]R;75L87(@=W5R9&4@8F5R96ET<R!V97)A<F)E:71E
M="X`1&EE<R!I<W0@)7,N`$1I92!I<W0@96EN($MO;&%B+4=R;W5P=V%R92U/
M8FIE:W0N(%5M(&1I97-E<R!/8FIE:W0@86YZ=7IE:6=E;BP@8F5N]G1I9V5N
M(%-I92!E:6X@12U-86EL+5!R;V=R86UM+"!D87,@9&%S($MO;&%B+4=R;W5P
M=V%R92U&;W)M870@=6YT97)S=/QT>G0N($5I;F4@3&ES=&4@<V]L8VAE<B!0
M<F]G<F%M;64@9FEN9&5N(%-I92!U;G1E<B`E<P!$:65S92!.86-H<FEC:'0@
M=W5R9&4@:6X@96EN96T@6F5I8VAE;G-A='H@*"5S*2!E<G-T96QL="P@9&5R
M(&YI8VAT($EH<F5M(&5I9V5N96X@96YT<W!R:6-H="X`1&EE<V4@6F%H;"!M
M=7-S(#$@;V1E<B!G<O;?97(@<V5I;BX`1&EE<V5R(%-E<G9E<B!K86YN(%I)
M4"T@=6YD($=:25`M1&%T96EN(&YI8VAT(&5N='!A8VME;BX`1&EE<V5S(%-Y
M<W1E;2!I<W0@>G5R(%IE:70@9&5A:W1I=FEE<G0N`$1I97-E<B!797)T(&UU
M<W,@96EN92!:86AL('-E:6XN`$1I97-E<R!&96YS=&5R(&UU<W,@=F]N(&5I
M;F5M($5I;G-T96QL=6YG96XM1F5N<W1E<B!G9?9F9FYE="!W97)D96X`1&]N
M;F5R`%1I8VME=',`6F5I=`!:96ET97)F87-S=6YG`%IE:71F;W)M870`6F5I
M=&%U<W=A:&P`5&EM;W(M3&5S=&4`5&ET96P`5&ET96P@*%1O;VQT:7`I.@!!
M;@!(86QT96X@4VEE(&)E:6T@2VQI8VME;B!3=')G(&)Z=RX@*%!#*2!#;VUM
M86YD("A-86,I(&=E9'+\8VMT+"!U;2!M96AR97)E($5I;G1RY&=E(&%U<WIU
M=^1H;&5N+@!(975T90!:=2!(5$U,+5%U96QL8V]D92!U;7-C:&%L=&5N`%1O
M9V\`5&]K96QA=0!-;W)G96X`5&]N9V$`6G4@=FEE;&4@=6YG_&QT:6=E($%N
M;65L9&5V97)S=6-H92!I;B!D96X@;&5T>G1E;B!-:6YU=&5N+@!/8F5N`,1U
MWV5R<W1E<B!286AM96X@*%]T;W`I`-QB97)S971Z=6YG96X`5')I;FED860@
M=6YD(%1O8F%G;P!786AR(&]D97(@9F%L<V-H`$1I`%1U;F5S:65N`%3\<FME
M:0!4_')K:7-C:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS+2!U
M;F0@0V%I8V]S:6YS96QN`%1U=F%L=0!):')E($%U<W=A:&PZ(`!55BU);F1E
M>#H@`$AO;65P86=E`%523"!):')E<R!3:W)I<'1S(&;\<B!D96X@5F5R<V%N
M9'-T871U<V)E<FEC:'0`061R97-S93H`56=A;F1A`%5K<F%I;F4`075F(&1A
M<R!61E,M5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT('IU9V5G<FEF9F5N('=E
M<F1E;BX`1&EE('IU<^1T>FQI8VAE;B!"96YU='IE<FEN9F]R;6%T:6]N96X@
M:V]N;G1E;B!B96D@9&5R(%)E9VES=')I97)U;F<@;FEC:'0@:&EN>G5F_&=T
M('=E<F1E;BX`1&EE(%IU9W)I9F9S<F5C:'1E(&;\<B!D:64@5D93+41A=&5I
M("(E<R(@:V]N;G1E;B!N:6-H="!G9>1N9&5R="!W97)D96XN`$1I92!:=6=R
M:69F<W)E8VAT92!F_'(@9&EE(%9&4RU$871E:2`E<R\E<R!K;VYN=&5N(&YI
M8VAT(&=EY&YD97)T('=E<F1E;BX`17,@:V%N;B!N:6-H="!I;B!697)Z96EC
M:&YI<R`E<R!G97=E8VAS96QT('=E<F1E;BX`1&EE($=R]M]E('9O;B`B)7,B
M(&MO;FYT92!N:6-H="!B97-T:6UM="!W97)D96XN`$1I92!'<O;?92!V;VX@
M(B5S+R5S(B!K;VYN=&4@;FEC:'0@8F5S=&EM;70@=V5R9&5N+@!697)B:6YD
M=6YG('IU;2!344P@4V5R=F5R(&MA;FX@;FEC:'0@:&5R9V5S=&5L;'0@=V5R
M9&5N+@!34TPM5F5R8FEN9'5N9R!K;VYN=&4@;FEC:'0@:&5R9V5S=&5L;'0@
M=V5R9&5N+@!$:64@5D93+41A=&5I(&MO;FYT92!N:6-H="!K;W!I97)T('=E
M<F1E;BX`1&%S(%9&4RU697)Z96EC:&YI<R`B)7,B(&MO;FYT92!N:6-H="!A
M;F=E;&5G="!W97)D96XN`$1A<R!61E,M5F5R>F5I8VAN:7,@:V]N;G1E(&YI
M8VAT(&%N9V5L96=T('=E<F1E;BX`1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC
M:'0@86YG96QE9W0@=V5R9&5N+@!$87,@5D93+59E<GIE:6-H;FES("(E<R(@
M:V]N;G1E(&YI8VAT(&%N9V5L96=T('=E<F1E;BX`3&5E<F4@5D93+41A=&5I
M(&MO;FYT92!N:6-H="!A;F=E;&5G="!W97)D96XN`$1I92!$871E;B!K;VYN
M=&5N(&YI8VAT(&1E:V]M<')I;6EE<G0@=V5R9&5N+@`B)7,B(&MO;FYT92!N
M:6-H="!G96SV<V-H="!W97)D96XL(&1A<R!697)Z96EC:&YI<R!I<W0@;FEC
M:'0@;&5E<BX`(B5S(B!K86YN(&YI8VAT(&=E;/9S8VAT('=E<F1E;CH@)7,N
M`"5S(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XL(&1A<R!697)Z96EC
M:&YI<R!I<W0@;FEC:'0@;&5E<@!$87,@5D93+59E<GIE:6-H;FES(&MO;FYT
M92!N:6-H="!R96MU<G-I=B!G96SV<V-H="!W97)D96XN`$1A<R!61E,M5F5R
M>F5I8VAN:7,@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BX`1&%S(%9&
M4RU697)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N.B`E
M<RX`1&EE(%9&4RU$871E:2`B)7,B(&MO;FYT92!N:6-H="!G96SV<V-H="!W
M97)D96XN`$1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E
M<F1E;BX`1&%S(%9&4RU697)Z96EC:&YI<R`B)7,B(&MO;FYT92!N:6-H="!G
M96SV<V-H="!W97)D96XN`$1A<R!61E,@:V]N;G1E(&YI8VAT(')E:W5R<VEV
M(&=E;/9S8VAT('=E<F1E;CH@)7,N`$1A<R!A:W1U96QL92!697)Z96EC:&YI
M<R!K;VYN=&4@;FEC:'0@8F5S=&EM;70@=V5R9&5N+@!$:64@6F5R=&EF:6MA
M=&1E=&%I;',@:V]N;G1E;B!N:6-H="!A=7-G96QE<V5N('=E<F1E;@!$97(@
M)7,M5')E:6)E<B!K;VYN=&4@;FEC:'0@9V5L861E;B!W97)D96XN`$1I92!6
M1E,M1&%T96D@:V]N;G1E(&YI8VAT('9E<G-C:&]B96X@=V5R9&5N+@!$:64@
M5D93+41A=&5I("(E<R(@:V]N;G1E(&YI8VAT(&=E]F9F;F5T('=E<F1E;BX`
M1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@>G5M($)E<V-H<F5I8F5N(&=E
M]F9F;F5T('=E<F1E;BX`1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@9V7V
M9F9N970@=V5R9&5N+@!$87,@07)C:&EV(&MO;FYT92!N:6-H="!G9?9F9FYE
M="!W97)D96XN`$1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT(&=E;&5S96X@
M=V5R9&5N("AF:6QE<VEZ92@I(&9E:&QG97-C:&QA9V5N*2X`1&EE(%9&4RU$
M871E:2!K;VYN=&4@;FEC:'0@9V5L97-E;B!W97)D96X@*'-I>F4H*2!F96AL
M9V5S8VAL86=E;BDN`$1I92!$871E:2!K;VYN=&4@;FEC:'0@9V5L97-E;B!W
M97)D96XZ(`!$87,@=F9S<F]O="U697)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@
M9V5L97-E;B!W97)D96XN`"5S(&MO;FYT92!N:6-H="!N86-H("5S('5M8F5N
M86YN="!W97)D96XZ($1A<R!::65L=F5R>F5I8VAN:7,@97AI<W1I97)T(&)E
M<F5I=',`1&%S(%9&4RU697)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@=6UB96YA
M;FYT('=E<F1E;BX`1&%S(%9&4RU697)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@
M=6UB96YA;FYT('=E<F1E;CH@)7,N`$1I92!61E,M1&%T96D@(B5S(B!K;VYN
M=&4@;FEC:'0@=6UB96YA;FYT('=E<F1E;BX`1&EE(%9&4RU$871E:2`E<R\E
M<R!K;VYN=&4@;FEC:'0@=6UB96YA;FYT('=E<F1E;BX`1&EE(%9&4RU$871E
M:2!K;VYN=&4@;FEC:'0@=6UB96YA;FYT('=E<F1E;BX`(FUK:7-O9G,B(&MO
M;FYT92!N:6-H="!A=7-G96;\:')T('=E<F1E;BX`1&EE<V5S(%=O<F0M1&]K
M=6UE;G0@;.1S<W0@<VEC:"!N:6-H="!A;GIE:6=E;@!$:64@1G)E:2]'96)U
M8VAT+4EN9F]R;6%T:6]N96X@9OQR("5S(&MO;FYT96X@;FEC:'0@86MT=6%L
M:7-I97)T('=E<F1E;@!$:64@5D93+41A=&5I("(E<R(@:V]N;G1E(&YI8VAT
M(&=E<W!E:6-H97)T('=E<F1E;BX`1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC
M:'0@9V5S8VAR:65B96X@=V5R9&5N("AC;W!Y*"D@9F5H;&=E<V-H;&%G96XI
M+@!$:64@5D93+41A=&5N(&MO;FYT96X@;FEC:'0@9V5S8VAR:65B96X@=V5R
M9&5N+@!$:64@5D93+41A=&5I(&MO;FYT92!N:6-H="!G97-C:')I96)E;B!W
M97)D96XL(&1A<R!3<&5I8VAE<G!L871Z+4MO;G1I;F=E;G0@=_QR9&4@_&)E
M<G-C:')I='1E;BX`56YT97)S=')I8VAE;@#$;F1E<G5N9V5N('+\8VMGY&YG
M:6<@;6%C:&5N`$UA8VAT(&1I92!L971Z=&4@06MT:6]N('+\8VMGY&YG:6<`
M56YG_&QT:6=E(%+\8VMM96QD=6YG('9O;2!397)V97(@8F5I;2!(97)S=&5L
M;&5N(&1E<B!697)B:6YD=6YG.B``56YE<G=A<G1E=&4@06YT=V]R="!D97,@
M4V5R=F5R<R!A=68Z(`!.:6-H="!Z=6=E;W)D;F5T`%5N:6-O9&4@*%541BTX
M*0!697)E:6YI9W1E($%R86)I<V-H92!%;6ER871E`%9E<F5I;FEG=&5S($OV
M;FEG<F5I8V@`5F5R96EN:6=T92!3=&%A=&5N`$ML96EN97)E($%M97)I:V%N
M:7-C:&4@W&)E<G-E96EN<V5L;@!%:6YH96ET96X`56YB96MA;FYT`%5N8F5K
M86YN=&4@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YB96MA;FYT92!C
M;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!%<R!W=7)D92!E:6X@=6YB
M96MA;FYT97(@3W)T(&%N9V5G96)E;BX`56YB96MA;FYT97(@0F5N=71Z97)N
M86UE(&]D97(@4&%S<W=O<G0N`$QI;FL@=F]M(&%K='5E;&QE;B!%;&5M96YT
M(&5N=&9E<FYE;@!5;F)E;F%N;G0`075S(%-I8VAE<FAE:71S9W+\;F1E;B!D
M_')F96X@=6YA=71O<FES:65R=&4@4VMR:7!T92!N:6-H="!A=7-C:&YE:61E
M;BP@:V]P:65R96X@=6YD(&5I;F;\9V5N+B!+;&EC:V5N(%-I92!A=68@3TLL
M('5M(&5I;F5N($AI;G=E:7,@875F(&UO>FEL;&$N;W)G(&%N9V5Z96EG="!Z
M=2!B96MO;6UE;BP@9&5R(&)E<V-H<F5I8G0L('=I92!3:64@96EN96T@4VMR
M:7!T(&1E;B!:=6=R:69F(&%U9B!D:64@6G=I<V-H96YA8FQA9V4@97)L875B
M96X@:_9N;F5N+@!&87)B92!Z=7+\8VMS971Z96X`17)W96ET97)U;F<@;FEC
M:'0@=6YT97)S=/QT>G0`06MT=6%L:7-I97)U;F<`)7,@86MT=6%L:7-I97)E
M;@!"96YU='IE<B!A:W1U86QI<VEE<F5N`"(E<R(@=W5R9&4@86MT=6%L:7-I
M97)T+@!!:W1U86QI<VEE<G5N9W-S:W)I<'0@9V5L]G-C:'0N`$AO8VAL861E
M;@!$:64@2V]N9FEG=7)A=&EO;G-D871E:65N(&%L;&5R($%N=V5N9'5N9V5N
M('=U<F1E;B!A=68@9&5N(%-E<G9E<B!H;V-H9V5L861E;BX`1W(N(&QA=&5I
M;FES8VAE($)U8VAS=&%B96X`1W(N('+V;6ES8VAE(%IA:&QE;@!5<G5G=6%Y
M`$%K='5E;&QE(&)E;G5T>F5N.B`E<P!34TP@8F5N=71Z96X`0FET=&4@875S
M9OQL;&5N+"!W96YN(%-I92!E:6YE;B!A;F1E<F5N($)E;G5T>F5R;F%M96XO
M4&%S<W=O<G0@9OQR(&1E;B!)35-0+5-E<G9E<B!H86)E;BX`0F5N=71Z97(`
M0F5N=71Z97(@)7,@:7-T(&;\<B`E<R!N:6-H="!A=71O<FES:65R="X`0F5N
M=71Z97)V97)W86QT=6YG`$)E;G5T>F5R96EN<W1E;&QU;F=E;@!"96YU='IE
M<G)E9VES=')I97)U;F<`1&EE($)E;G5T>F5R<F5G:7-T<FEE<G5N9R!W=7)D
M92!A=68@9&EE<V5M(%-Y<W1E;2!D96%K=&EV:65R="X`0F5N=71Z97)K;VYT
M;R!N:6-H="!G969U;F1E;@!"96YU='IE<FYA;64`1&5R($)E;G5T>F5R;F%M
M92`B)7,B(&5X:7-T:65R="!B97)E:71S+@!"96YU='IE<FYA;64Z`$)E;G5T
M>F5R;F%M93H@`$)E;G5T>F5R(&1E<R!3>7-T96US.@!5<V)E:VES=&%N`$1A
M<R!61E,M5F5R>F5I8VAN:7,@97AI<W1I97)T(&YI8VAT+@!!8G=E<V5N:&5I
M=`!087-S96YD92!G969U;F1E;F4@3W)T93H@`$?\;'1I9VME:70`5V5R="!I
M;B!-:6YU=&5N('9O;B!J971Z="!A;BX`1&5R(%=E<G0@:7-T(/QB97(@9&5R
M(&UA>&EM86QE;B!,Y&YG92!V;VX@)7,N`%=E<G1E`%=E<G1E+"!A=7,@9&5N
M96X@875S9V5WY&AL="!W97)D96X@:V%N;@!686YU871U`$1R96AE;F0`5F5N
M97IU96QA`-QB97)P<OQF=6YG(&9E:&QG97-C:&QA9V5N("T@9&EE<V4@3F%C
M:')I8VAT(&OV;FYT92!M86YI<'5L:65R="!W;W)D96X@<V5I;BX`5F5R<VEO
M;@!697)S:6]N<VMO;G1R;VQL90!!=7-R:6-H='5N9P!697)T:6MA;&5R($EN
M;F5N86)S=&%N9`!697)T:6MA;#H`4V5H<B!(;V-H`%9I971N86T`5FEE=&YA
M;65S:7-C:"`H5DE30TE)*0`E<R!A;GIE:6=E;@!%:6YE(&5X=&5R;F4@5V5B
M<V5I=&4@86YZ96EG96X`06YZ96EG96X@86QS("5S`$)R:71I<V-H92!*=6YG
M9F5R;FEN<V5L;@!!;65R:6MA;FES8VAE($IU;F=F97)N:6YS96QN`%-I8VAT
M`%-I8VAT.B``5F]D869O;F4@271A;&EE;B!P97(@4TU44`!705).54Y'`%=!
M4DY53D<A(2$@3-930TA%3B!3244@1$%3(%-+4DE05"!-04Y514Q,($%54R`E
M<RX`5TE.(/QB97(@2%144`!786QL:7,@=6YD($9U='5N80!787)N=6YG`$UI
M`%=E='1E<G9O<FAE<G-A9V4`5V5T=&5R9&%T96X@=F]N`%=E871H97(N8V]M
M`%=E8@!796)S:71E`%?V8VAE;G1L:6-H`%=I;&QK;VUM96X`5VEL;&MO;6UE
M;B!B96D@)7,`5VEL;&MO;6UE;BP@)7,`5V5S=&5U<F]PY&ES8V@@*$E33RTX
M.#4Y+3$I`%=E<W1E=7)O<.1I<V-H("A)4T\M.#@U.2TQ-2D`5V5S='-A:&%R
M80!796QC:&4@06YW96YD=6YG('-O;&P@)7,@;F%C:"!D96T@06YM96QD96X@
M86YG97IE:6=E;C\`5V5L8VAE<R!4<F5N;GIE:6-H96X@=VER9"!V97)W96YD
M970_`%=E;&-H92!!;F;\:')U;F=S>F5I8VAE;B!W97)D96X@=F5R=V5N9&5T
M/P!7:&5R96ES+4%U<W1R86QI82U+87)T90!796QC:&4@4&AA<V5N`%=E;&-H
M92!0;'5G:6YS(&;\<B!D96X@5UE325=91RU%9&ET;W(@<V]L;&5N(&%K=&EV
M:65R="!W97)D96X_`$)R96ET90!"<F5I=&4@:6X@0U-3+45I;FAE:71E;@!"
M<F5I=&4@9&5S("5S+4UE;OQS(&QI;FMS("AW:7)K<V%M(&YA8V@@9&5R(&[D
M8VAS=&5N($%N;65L9'5N9RDZ`%1A8F5L;&5N8G)E:71E`$5I;FAE:70`0G)E
M:71E.@!7:6MI`%=I;F0`1G+\:"!7:6YD`%=I;F1G97-C:'=I;F1I9W1K96ET
M(&EN($MN;W1E;@!7:6YD.@!7:6YD.B``5V5I<VAE:70`5W5N<V-H>F5T=&5L
M`$%R8F5I=`!!9')E<W-E(&=E<V-HY&9T;&EC:`!496QE9F]N(&=E<V-HY&9T
M;&EC:`!&86QS8VAE($%N>F%H;"!A;B!&96QD97)N(&EN(%IE:6QE("5D+B`E
M9"!E<G=A<G1E="P@)60@9V5F=6YD96XN`$9A;'-C:&4@06YZ86AL(&%N($9E
M;&1E<FXN("5D(&5R=V%R=&5T+"`E9"!G969U;F1E;BX`56YG_&QT:6=E<B!/
M9F9S970@)60@8F5I;2!,97-E;B!D97(@5D93+41A=&5I+@!1=65R=F5R=V5I
M<V4`6#4P.78S($=E;F5R96QL92!%:6YS8VARY&YK=6YG`%@U,#EV,R!%<G=E
M:71E<G1E<B!38VAL_'-S96QZ=V5C:P!8-3`Y=C,@06QT97)N871I=F5R($YA
M;64@9&5S(%IE<G1I9FEK871I;FAA8F5R<P!8-3`Y=C,@261E;G1I=.1T(&1E
M<R!:97)T:69I:V%T<V-H;/QS<V5L<P!8-3`Y=C,@17)W96ET97)U;F=E;@!*
M2@!*2DI*`%EA:&]O(2!+87)T90!*Y&AR;&EC:`!*96UE;@!*80!*82P@:6-H
M('-T:6UM92!Z=0!3:64@8F5F:6YD96X@<VEC:"!I;2!497AT;6]D=7,N($)E
M;G5T>F5N(%-I92!D96X@6SP^72!+;F]P9BP@=6T@:6X@9&5N(%=94TE724<M
M36]D=7,@>G4@=V5C:'-E;&XN`%-I92!D_')F96X@;FEC:'0@;65H<B!A;',@
M)60@0FSV8VME(&5R<W1E;&QE;BX`4VEE('-I;F0@;FEC:'0@86YG96UE;&1E
M="X`4VEE(&3\<F9E;B!D87,@6F5I8VAE;B`G7"<@;FEC:'0@:6X@26AR96T@
M3F%M96X@=F5R=V5N9&5N+@!3:64@:&%B96X@:V5I;F4@9_QL=&EG92!%+4UA
M:6PM061R97-S92!A;F=E9V5B96XN`%-I92!H86)E;B!K96EN92!&96QD97(@
M875S(&1E;B!I;7!O<G1I97)T96X@1&%T96X@9&5N(&5N='-P<F5C:&5N9&5N
M($9E;&1E<FX@:6X@)7,@>G5G96]R9&YE="X`4VEE('=U<F1E;B!A8F=E;65L
M9&5T+@!3:64@;?QS<V5N(&5I;F4@9_QL=&EG92!-;V)I;'1E;&5F;VYN=6UM
M97(@86YG96)E;BP@;G5R(&%U<R!:86AL96X@=6YD(&=G9BX@96EN96T@(BLB
M(&;\<B!I;G1E<FYA=&EO;F%L92!6;W)W86AL96X@8F5S=&5H96YD+@!3:64@
M;?QS<V5N(&5I;F5N(&?\;'1I9V5N(%=E<G0@86YG96=E8F5N+@!3:64@;?QS
M<V5N(&5I;B!$871A5')E92U"86-K96YD(&MO;F9I9W5R:65R96XL('5M(%)E
M9VES=')I97)U;F=E;B!V97)W96YD96X@>G4@:_9N;F5N+@!3:64@;?QS<V5N
M(&5I;B!61E,M0F%C:V5N9"!K;VYF:6=U<FEE<F5N+@!3:64@;?QS<V5N(&1A
M<R!0<F]B;&5M(&)E<V-H<F5I8F5N+"!U;2!D96X@0F5R:6-H="!A8GIU<V-H
M:6-K96XN`%-I92!M_'-S96X@9&EE(%523"!A;F=E8F5N+"!A=68@9&EE(&1I
M97-E<B!,:6YK('9E<G=E:7-E;B!S;VQL`%-I92!M_'-S96X@97)S="!D96X@
M>G4@96YT9F5R;F5N9&5N(%-E<G9E<B!A=7-WY&AL96XN`%-I92!M_'-S96X@
M96EN96X@0F5N=71Z97)N86UE;B!A;F=E8F5N+"!D97-S96X@1&%T96X@9V5L
M]G-C:'0@=V5R9&5N('-O;&QE;BX`4VEE(&W\<W-E;B!E:6YE;B!Z=2!L]G-C
M:&5N9&5N($)E;G5T>F5R;F%M96X@86YG96)E;BX`4VEE(&W\<W-E;B!E:6YE
M;B!H:6YZ=7IU9OQG96YD96X@0F5N=71Z97)N86UE;B!A;F=E8F5N+@!3:64@
M;?QS<V5N(&1E;B!Z=2!A:W1U86QI<VEE<F5N9&5N($)E;G5T>F5R;F%M96X@
M86YG96)E;BX`4VEE(&W\<W-E;B!E:6YE($%K=&EO;B!A;F=E8F5N+@!3:64@
M;?QS<V5N(&5I;F5N(&YE=65N($MA=&5G;W)I96YA;65N(&%N9V5B96XN`%-I
M92!M_'-S96X@96EN92!)=&%L:65N:7-C:&4@5&5L969O;FYU;6UE<B!A;F=E
M8F5N`$EH<F4@)7,M4V5S<VEO;B!I<W0@86)G96QA=69E;BX@0FET=&4@;65L
M9&5N(%-I92!S:6-H(&5R;F5U="!A;BX`26AR92!%+4UA:6PM061R97-S90!)
M:')E(%9O;CH@061R97-S93H`26AR92!!;F=A8F5N`$EH<F4@26YT97)N971A
M9')E<W-E(&AA="!S:6-H(&=EY&YD97)T+"!S96ET(%-I92!D:64@)7,M4VET
M>G5N9R!B96=O;FYE;B!H86)E;BX@6G5M(%-C:'5T>B!):')E<B!3:6-H97)H
M96ET(&W\<W-E;B!3:64@<VEC:"!N974@86YM96QD96XN`$EH<B!.86UE`$EH
M<B!!=71H96YT:69I>FEE<G5N9W-S>7-T96T@97)L875B="!K96EN($AI;GIU
M9OQG96X@=F]N(&YE=65N($)E;G5T>F5R;BX@5V5N;B!3:64@2&]R9&4@8F5N
M=71Z96X@;?9C:'1E;BP@=6T@26AR92!"96YU='IE<B!Z=2!V97)W86QT96XL
M(&W\<W-E;B!3:64@96EN96X@86YD97)E;B!!=71H96YT:69I>FEE<G5N9W-T
M<F5I8F5R(&)E;G5T>F5N+@!):'(@075T:&5N=&EF:7II97)U;F=S<WES=&5M
M(&5R;&%U8G0@9&%S($%N>F5I9V5N(&1E<B!"96YU='IE<B!N:6-H="P@;V1E
M<B!D:65S92!-]F=L:6-H:V5I="!W=7)D92!A=7-G97-C:&%L=&5T+@!):'(@
M0G)O=W-E<B!H870@<VEC:"!A;G-C:&5I;F5N9"!G9>1N9&5R="!S96ET(%-I
M92!D:64@)7,M4VET>G5N9R!B96=O;FYE;B!H86)E;BX@6G5M(%-C:'5T>B!)
M:')E<B!3:6-H97)H96ET(&W\<W-E;B!3:64@<VEC:"!N974@86YM96QD96XN
M`$EH<B!"<F]W<V5R('5N=&5R<W3\='IT(&1I97-E($9U;FMT:6]N(&YI8VAT
M+@!):'(@0G)O=W-E<B!U;G1E<G-T_'1Z="!D:65S92!$<G5C:V9U;FMT:6]N
M(&YI8VAT+B!":71T92!D<OQC:V5N(%-I92!3=')G+TMO;6UA;F1O("L@4"!U
M;2!Z=2!D<G5C:V5N+@!):')E(&%K='5E;&QE(%IE:71Z;VYE.@!):')E(%-T
M86YD87)D:61E;G1I=.1T('=U<F1E(&=EY&YD97)T+@!):')E(%-T86YD87)D
M:61E;G1I=.1T.@!):'(@=F]L;'-TY&YD:6=E<B!.86UE.@!):'(@6G5G86YG
M(&ES="!A8F=E;&%U9F5N+@!):'(@;F5U97,@4&%S<W=O<G0@9OQR("5S(&QA
M=71E=#H@)7,`26AR92!%:6YS=&5L;'5N9V5N('=U<F1E;B!F_'(@9&EE($1A
M=65R(&1I97-E<B!3:71Z=6YG(&=E<W!E:6-H97)T+@!):')E($5I;G-T96QL
M=6YG96X@=W5R9&5N(&=E<W!E:6-H97)T+@!):'(@4&%S<W=O<G0@=W5R9&4@
M>G5R_&-K9V5S971Z=`!):'(@4&%S<W=O<G0@=W5R9&4@>G5R_&-K9V5S971Z
M="X@4G5F96X@4VEE($EH<F4@12U-86EL+4YA8VAR:6-H=&5N(&%B('5N9"!M
M96QD96X@4VEE('-I8V@@;6ET($EH<F5M(&YE=65N(%!A<W-W;W)T(&%N+@!)
M:'(@4&%S<W=O<G0@:7-T(&%B9V5L875F96XN`$EH<F4@4V5R=F5R.@!*=6=O
M<VQA=VEE;@!:86ER90!386UB:6$`4VEM8F%B=V4`6FEP<'D`6UII=&%T=&5X
M="!V97)S=&5C:V5N70!;4')O8FQE;6)E<FEC:'1=`%M::71A='1E>'0@86YZ
M96EG96X@+0!;6FET871T97AT(&%N>F5I9V5N("T@)7,@6F5I;&5N70!;6F5I
M;&4@)7,@=F]N("5S70!?061M:6YI<W1R871I;VX`0F5?9F5H;'-Z96EL90!?
M1&%T851R964`6F5I;&4@7VSV<V-H96X`7T=R=7!P96X`7T)I;&1E:6=E;G-C
M:&%F=&5N+BXN`$%N7VUE;&1E;@!!8E]M96QD96X`3&EN:R!?8F5A<F)E:71E
M;BXN+@!?16EN<W1E;&QU;F=E;@!?4F5C:'1E`$QI;FL@7V5N=&9E<FYE;BXN
M+@!?2V]N9FEG=7)A=&EO;@!?5&%B96QL96YE:6=E;G-C:&%F=&5N+BXN`%]"
M96YU='IE<@!!9')E<W-B=6-H`$%D<F5S<V%T('5N8F5K86YN=`!+86QE;F1E
M<@!W:6YD<W1I;&P`075S9V%B961A=&5I(&MO;FYT92!N:6-H="!E<G-T96QL
M="!W97)D96X`16EN9V%B92!K86YN(&YI8VAT(&=E]F9F;F5T('=E<F1E;@!K
M;&EC:V5N(%-I92!H:65R`%5N9_QL=&EG92!"96YU='IU;F<@9&5R($MO;6UA
M;F1O>F5I;&4`2V]N9FEG=7)A=&EO;G-F96AL97(`2W)I=&ES8VAE(%-Y<W1E
M;61A=&5I(&9E:&QT`$1A=&5N9F]R;6%T9F5H;&5R`&)E87)B96ET96X`16EN
M=')A9R!N:6-H="!G969U;F1E;@!F86QL96YD`$1A=&5I`&%U<R`E<R`H)7,I
M(&UI="`E<R`E<P!B]FEG`&@Z`&AH`$AO<W1N86UE('5N8F5K86YN=`!S;V9O
M<G0`26YL:6YE`$5I;BTO075S9V%B969E:&QE<@!);G1E<FYE<B!3;V9T=V%R
M969E:&QE<@!:96EL96Y=`&UK:7-O9G,M1F5H;&5R8V]D92`E9"!B96D@9&5R
M($5R<W1E;&QU;F<@9&5S($E33RU!8F)I;&1E<RX`;6T`3F%M90!N:6-H="!I
M;7!L96UE;G1I97)T`$YO8V@@;FEC:'0@:6UP;&5M96YT:65R=`!.;W1I>F)L
M;V-K`%!R;WIE;G0`6G5G<FEF9B!V97)W96EG97)T`%!I>&5L`%)E;6]T969E
M:&QE<B!I;2!0<F]T;VMO;&P`<W1E:6=E;F0`4V5R=FEC92!N:6-H="!V97)F
M_&=B87(`56YT97)S8VAI961E(&%N>F5I9V5N`'-M<S)E;6%I;"#\8F5R($A4
M5%``<W,`9VQE:6-H8FQE:6)E;F0`4WES=&5M9F5H;&5R`$%U9F=A8F5N;&ES
M=&4`5F]R_&)E<F=E:&5N9&5R($9E:&QE<@!G96)E;B!3:64@9&%S(%!A<W-W
M;W)T(&5I;B!Z=V5I=&5S($UA;"!Z=7(@0F5S=.1T:6=U;F<@96EN`'5N:69I
M960`=6YB96YA;FYT`&)E;G5T>F5R9&5F:6YI97)T`'9#87)D`&(Z`'=E871H
M97(N8V]M````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&]C86QE+V5L7T=2+P``````````````````````````````````
M```````````````````````````````````````````````P,#`P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U,P`P,C`Q,#4`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O96Q?1U(O:&5L<"YX;6P`
M````````````````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,S(P`#$P
M-3$U-#,S-S4S`#`R,34U-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R
M9&4Z(&AO<F1E+VQO8V%L92]E;%]'4B]H96QP+GAM;"QV(#$N,B`R,#`T+S`U
M+S(W(#(P.C(R.C$V(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED
M/2)S=6UM87)Y(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!0;W)T86P@4&%G
M93PO=&ET;&4^"B`\<&%R83X*("!4:&ES('!O<G1A;"!P86=E('!R;W9I9&5S
M(&$@<75I8VL@<W5M;6%R>2!O9B!A;&P@>6]U<B!I;7!O<G1A;G0*("!I;F9O
M<FUA=&EO;BX@1F]R(&5X86UP;&4L(&ET(&UI9VAT('-H;W<@:&]W(&UA;GD@
M;F5W(&4M;6%I;"!M97-S86=E<R!Y;W4*("!H879E(&EN('EO=7(@24Y"3U@L
M('5P8V]M:6YG(&5V96YT<R!O;B!Y;W5R(&-A;&5N9&%R+"!T87-K<R!O;B!Y
M;W5R('1O+61O"B`@;&ES="P@:&5A9&QI;F5S(&9R;VT@<V5L96-T960@;F5W
M<R!S97)V:6-E<RP@86YD('-O(&]N+B`@36%N>2!O9B!T:&5S90H@('-U;6UA
M<FEE<R!W:6QL(&-O;G1A:6X@<75I8VL@<VAO<G1C=71S('1O(&-O;6UO;B!F
M=6YC=&EO;G,L('-U8V@@87,*("!C;VUP;W-I;F<@82!N97<@;6%I;"!M97-S
M86=E+"!C<F5A=&EN9R!A(&YE=R!C86QE;F1A<B!E=F5N="!O<B!T87-K+"!E
M=&,N"B`\+W!A<F$^"B`\<&%R83X*("!4:&4@8V]N=&5N=',@;V8@=&AI<R!P
M;W)T86P@<&%G92!A<F4@8W5S=&]M:7IA8FQE('9I82!T:&4@3&%Y;W5T(&)U
M='1O;BX*("!&;W(@97AA;7!L92P@>6]U(&-A;B!C:&]O<V4@=VAI8V@@:71E
M;7,@=&\@:6YC;'5D92!O;B!T:&ES('!O<G1A;"!P86=E(&%S"B`@=V5L;"!A
M<R!I;B!W:&EC:"!O<F1E<B!T:&5Y(&%R92!S:&]W;BX*(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](FYA=F)A<B(@<W1A=&4](FYE=R(^"CQT:71L
M93Y4:&4@07!P;&EC871I;VX@3F%V:6=A=&EO;B!"87(\+W1I=&QE/@H@/'!A
M<F$^"B`@070@=&AE(&QE9G0@:&%N9"!S:61E(&]F('1H92!W96(@<&%G92!I
M<R!T:&4@87!P;&EC871I;VX@;F%V:6=A=&EO;B!B87(N"B`@0VQI8VL@;VX@
M=&AE(&EC;VYS(&]N('1H:7,@;F%V:6=A=&EO;B!B87(@=&\@<75I8VML>2!A
M;F0@96%S:6QY('-W:71C:`H@(&)E='=E96X@=&AE(&%V86EL86)L92!A<'!L
M:6-A=&EO;G,N"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F
M<RUD;U]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E
M9F5R96YC97,Z($UA:6YT96YA;F-E.B!$;R!-86EN=&5N86YC93PO=&ET;&4^
M"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O('!E<F9O<FT@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;BP@8VAE8VL@=&AI<R!B
M;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC
M;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0
M<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($-O;F9I<FT@36%I;G1E;F%N8V4\
M+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!C
M;VYF:7)M(&%L;"!M86EN=&5N86YC92!T87-K<R!B969O<F4@=&AE>2!A<F4@
M<G5N+"!C:&5C:R!T:&ES(&)O>"X@268@;&5F="!U;F-H96-K960L(&%L;"!M
M86EN=&5N86YC92!O<&5R871I;VYS('1H870@;F5E9"!T;R!B92!R=6X@=VEL
M;"!B92!P97)F;W)M960@875T;VUA=&EC86QL>2!W:71H(&YO(&-H86YC92!T
M;R!C86YC96P@;VX@;&]G:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L
M<#X*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V5L7T=2+TQ#7TU%4U-!1T53+P``
M````````````````````````````````````````````````````````````
M```P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,S<U,P`P,C$V-S(`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O96Q?
M1U(O3$-?34534T%'15,O:&]R9&4N;6\`````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,S4W-S$Q`#$P-3$U-#,S-S4S`#`R,S,T-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#>$@25``````L&```<````=#``
M``\(``#,8`````````B!```E````"8$``$@````O@0``#@```'B!```/````
MAX$```T```"7@0``"````*6!```+````KH$```P```"Z@0``!````,>!```,
M````S($```\```#9@0``"P```.F!```1````]8$```X````'@@``*````!:"
M```(````/X(```H```!(@@``%0```%."```2````:8(```L```!\@@``%```
M`(B"```F````G8(``"<```#$@@``)@```.R"```.````$X,```H````B@P``
M)P```"V#```@````58,```X```!V@P``%P```(6#```B````G8,``#4```#`
M@P``$0```/:#```-````"(0```P````6A```#0```".$```;````,80``"T`
M``!-A```'0```'N$```D````F80``"D```"^A```&0```.B$```/`````H4`
M`!@````2A0``#````"N%```.````.(4```X```!'A0``"````%:%```B````
M7X4``!H```""A0``,@```)V%```X````T(4``%0````)A@``40```%Z&``!:
M````L(8``%<````+AP``-````&.'```%````F(<``!$```">AP``"````+"'
M```)````N8<```D```##AP``#@```,V'```(````W(<``"4```#EAP``(```
M``N(```0````+(@```\````]B```"@```$V(```'````6(@```,```!@B```
M#P```&2(```4````=(@```D```")B```#0```).(```2````H8@``!D```"T
MB```'@```,Z(```/````[8@```H```#]B```#P````B)```(````&(D``"0`
M```AB0``%P```$:)```4````7HD``!8```!SB0``"````(J)``!.````DXD`
M`"T```#BB0``&0```!"*```'````*HH```P````RB@``+````#^*```.````
M;(H```X```![B@``%@```(J*```%````H8H```4```"GB@``"@```*V*```#
M````N(H``!<```"\B@``"@```-2*```/````WXH```X```#OB@``&````/Z*
M```C````%XL```X````[BP``%````$J+```7````7XL``!<```!WBP``%P``
M`(^+```3````IXL```\```"[BP``'P```,N+```1````ZXL``!$```#]BP``
M#P````^,```&````'XP```L````FC```$````#*,```5````0XP``!4```!9
MC```!P```&^,```%````=XP```X```!]C```$0```(R,```,````GHP``#L`
M``"KC```.````.>,```#````((T```D````DC0``.0```"Z-```2````:(T`
M``\```![C0``.0```(N-```G````Q8T``"P```#MC0``*@```!J.```E````
M18X```D```!KC@``"@```'6.```&````@(X``!4```"'C@``&0```)V.```I
M````MXX``"0```#AC@``$0````:/```1````&(\```H````JCP``$````#6/
M```6````1H\``!8```!=CP``!````'2/```G````>8\```@```"ACP``"```
M`*J/```I````LX\```X```#=CP``"@```.R/```$````]X\```<```#\CP``
M!`````20```&````"9````T````0D```%P```!Z0```#````-I```!,````Z
MD```"````$Z0```0````5Y````D```!HD```!````'*0``!!````=Y```"``
M``"YD```!@```-J0```5````X9```!@```#WD```(@```!"1```N````,Y$`
M`!T```!BD0``(0```("1``!4````HI$``"D```#WD0``!P```"&2```5````
M*9(```H````_D@``#P```$J2```-````6I(```\```!HD@``#0```'B2```)
M````AI(```8```"0D@``$P```)>2```4````JY(```P```#`D@``!@```,V2
M```/````U)(``%0```#DD@``!````#F3```.````/I,``$0```!-DP``#0``
M`)*3```3````H),``!$```"TDP``$0```,:3```1````V),``!P```#JDP``
M*@````>4```3````,I0``"$```!&E```!0```&B4```3````;I0``!(```""
ME```"@```)64```/````H)0``!$```"PE```"@```,*4```1````S90```P`
M``#?E```$````.R4```1````_90```4````/E0``#````!65```0````(I4`
M``4````SE0``#0```#F5```&````1Y4```<```!.E0``#0```%:5```'````
M9)4```L```!LE0``!P```'B5```)````@)4``!0```"*E0``"0```)^5```*
M````J94``!D```"TE0``/0```,Z5```=````#)8``!T````JE@``#````$B6
M```0````598``!(```!FE@``$P```'F6```K````C98``#L```"YE@``(```
M`/66```.````%I<``#8````EEP``$````%R7```;````;9<```@```")EP``
M!````)*7```.````EY<``!X```"FEP``&P```,67```A````X9<``!X````#
MF```&0```"*8```>````/)@``!L```!;F```+@```'>8```F````II@``!L`
M``#-F```'@```.F8```<````")D``"8````EF0``*P```$R9```S````>)D`
M`"8```"LF0``*P```-.9```X````_YD``!T````XF@``%0```%::```O````
M;)H``!(```"<F@``(````*^:```I````T)H``!X```#ZF@``$@```!F;``"B
M````+)L``!8```#/FP``(P```.:;```H````"IP``"D````SG```*````%V<
M```?````AIP``!4```"FG```(````+R<```E````W9P``"@````#G0``+0``
M`"R=```P````6IT``)(```"+G0``(0```!Z>```6````0)X``!P```!7G@``
M)@```'2>```J````FYX``$$```#&G@``1`````B?```,````39\```<```!:
MGP``!P```&*?```&````:I\```T```!QGP``$````'^?```2````D)\``!,`
M``"CGP``$@```+>?```'````RI\```T```#2GP``#````."?```.````[9\`
M``\```#\GP``$P````R@```-````(*```"@````NH````P```%>@```-````
M6Z````(```!IH```!0```&R@```$````<J```!````!WH```%@```(B@```$
M````GZ````T```"DH```#@```+*@```#````P:````X```#%H```"````-2@
M```/````W:````@```#MH```#P```/:@```'````!J$```T````.H0``$```
M`!RA```3````+:$``!,```!!H0``"P```%6A```1````8:$```D```!SH0``
M!@```'VA```,````A*$``!$```"1H0``&0```*.A```+````O:$```T```#)
MH0``(@```->A```;````^J$``#0````6H@``"@```$NB```8````5J(``!D`
M``!OH@``%@```(FB```O````H*(``"(```#0H@``#0```/.B```,`````:,`
M`"8````.HP``%````#6C```+````2J,``"(```!6HP``+P```'FC```+````
MJ:,```D```"UHP``&0```+^C```+````V:,``!<```#EHP``%P```/VC```)
M````%:0``!8````?I```#P```#:D```6````1J0```X```!=I```&````&RD
M```-````A:0``"8```"3I```0P```+JD```(````_J0```L````'I0``+P``
M`!.E```.````0Z4```4```!2I0``!````%BE```*````7:4```H```!HI0``
M#P```'.E```0````@Z4``!<```"4I0``$0```*RE```7````OJ4``!D```#6
MI0``#P```/"E```*`````*8```4````+I@``#0```!&F```;````'Z8``!<`
M```[I@``"0```%.F```.````7:8```T```!LI@``$@```'JF```X````C:8`
M`"````#&I@```P```.>F```(````ZZ8```X```#TI@``>P````.G```8````
M?Z<```4```"8IP``&````)ZG```9````MZ<``!,```#1IP``!@```.6G```&
M````[*<``!````#SIP``#P````2H```0````%*@```\````EJ```"P```#6H
M```/````0:@```P```!1J```#P```%ZH```'````;J@```8```!VJ```#@``
M`'VH```@````C*@``!T```"MJ```#````,NH```H````V*@```\````!J0``
M"````!&I```(````&JD``!,````CJ0``'@```#>I```A````5JD``"````!X
MJ0``&0```)FI```7````LZD``"4```#+J0``%P```/&I``!"````":H```0`
M``!,J@``#````%&J```#````7JH```@```!BJ@``"@```&NJ```,````=JH`
M``L```"#J@``$````(^J```,````H*H``!,```"MJ@``%````,&J```,````
MUJH```D```#CJ@``#@```.VJ```+````_*H``!L````(JP``!P```"2K```*
M````+*L```T````WJP``"0```$6K```$````3ZL```4```!4JP```P```%JK
M```8````7JL```H```!WJP``!````(*K```F````AZL``!4```"NJP``!0``
M`,2K```'````RJL```P```#2JP``"````-^K```*````Z*L```8```#SJP``
M"````/JK```"`````ZP```8````&K```%0````VL```/````(ZP``!$````S
MK```&@```$6L```$````8*P```D```!EK```$````&^L```1````@*P```D`
M``"2K```"0```)RL```:````IJP```@```#!K```"@```,JL```.````U:P`
M``(```#DK```!@```.>L```2````[JP``!0````!K0``'0```!:M```1````
M-*T```8```!&K0``$0```$VM```1````7ZT```D```!QK0``'@```'NM```&
M````FJT```0```"AK0``$0```*:M```&````N*T```H```"_K0``$0```,JM
M```B````W*T```0```#_K0``)0````2N```%````*JX```0````PK@``#```
M`#6N```*````0JX```4```!-K@``"P```%.N```,````7ZX```X```!LK@``
M(````'NN```/````G*X``!(```"LK@``"P```+^N```F````RZX``"D```#R
MK@``)````!RO```F````0:\```@```!HKP``"@```'&O```)````?*\``"``
M``"&KP``(````*>O```F````R*\```4```#OKP``"@```/6O```9`````+``
M`"D````:L```%@```$2P```&````6[```!(```!BL```"@```'6P```,````
M@+````\```"-L```$````)VP``!`````KK```'````#OL```9@```&"Q```.
M````Q[$```D```#6L0``$@```."Q```3````\[$```P````'L@``!@```!2R
M```&````&[(```X````BL@``#P```#&R```2````0;(``!````!4L@``"@``
M`&6R```1````<+(``!P```""L@``(P```)^R``!J````P[(```\````NLP``
M$````#ZS```$````3[,```L```!4LP``%````&"S```,````=;,```P```""
MLP``#P```(^S```5````G[,``"D```"ULP``*@```-^S```F````"K0``"<`
M```QM```*0```%FT```J````@[0``!D```"NM```0@```,BT```1````"[4`
M`!(````=M0``$P```#"U```4````1+4```\```!9M0``%@```&FU```7````
M@+4``!````"8M0``$0```*FU```T````N[4``!,```#PM0``$@````2V```U
M````%[8``!0```!-M@``!P```&*V```,````:K8``"L```!WM@``(````*.V
M```4````Q+8``!$```#9M@``%P```.NV```<`````[<``!,````@MP``$0``
M`#2W```:````1K<``!X```!AMP``&@```("W```1````F[<``!<```"MMP``
M%````,6W```7````VK<``!4```#RMP``"0````BX```&````$K@```<````9
MN```!````"&X```$````)K@```<````KN```#@```#.X```,````0K@```P`
M``!/N```#0```%RX```0````:K@``!$```![N```$````(VX```.````GK@`
M`!$```"MN```*````+^X```/````Z+@```X```#XN```#`````>Y```/````
M%+D```H````DN0``"````"^Y```)````.+D``"L```!"N0``!````&ZY```+
M````<[D```X```!_N0``!P```(ZY```.````EKD```D```"EN0``#````*^Y
M```-````O+D```X```#*N0``%@```-FY```1````\+D```,````"N@``!@``
M``:Z```9````#;H```0````GN@``"P```"RZ```+````.+H```@```!$N@``
M#@```$VZ```$````7+H```\```!AN@``.@```'&Z```%````K+H```P```"R
MN@``'@```+^Z```.````WKH``!````#MN@``"P```/ZZ```:````"KL```H`
M```ENP``#````#"[```/````/;L```@```!-NP``!@```%:[```'````7;L`
M``L```!ENP``7````'&[```-````SKL```8```#<NP``"0```..[```$````
M[;L```,```#RNP``$P```/:[```3````"KP``!,````>O````@```#*\```%
M````-;P```0````[O```"@```$"\```-````2[P``&@```!9O```!@```,*\
M```8````R;P``!$```#BO```!0```/2\```&````^KP``!L````!O0``+P``
M`!V]```/````3;T``!,```!=O0``&P```'&]```8````C;T``!<```"FO0``
M#@```+Z]```#````S;T``!0```#1O0``$P```.:]```0````^KT```T````+
MO@``#@```!F^```6````*+X```<````_O@``!0```$>^```*````3;X```L`
M``!8O@``!P```&2^``!1````;+X``!````"^O@``#````,^^```-````W+X`
M`!H```#JO@``2@````6_```&````4+\``!H```!7OP``!@```'*_```&````
M>;\```D```"`OP``&````(J_```7````H[\```8```"[OP``#0```,*_```B
M````T+\``%<```#SOP``$P```$O````C````7\```!,```"#P````@```)?`
M```+````FL````@```"FP```#0```*_````*````O<````H```#(P```#@``
M`-/````'````XL```!,```#JP```"P```/[````)````"L$```D````4P0``
M"@```![!```'````*<$```D````QP0``!P```#O!```;````0\$``!(```!?
MP0``"@```'+!```)````?<$``!````"'P0``"@```)C!```0````H\$``!(`
M``"TP0``!````,?!```,````S,$```<```#9P0``!0```.'!```,````Y\$`
M``@```#TP0``#````/W!```4````"L(``!<````?P@``$P```#?"```$````
M2\(```H```!0P@``!````%O"```)````8,(```H```!JP@``#````'7"```"
M````@L(``#@```"%P@``+````+["```2````Z\(``"D```#^P@``,@```"C#
M```*````6\,``#8```!FPP``+````)W#```N````RL,``#,```#YPP``/```
M`"W$```Z````:L0``#L```"EQ```,P```.'$```^````%<4``#@```!4Q0``
M#P```(W%```8````G<4``!````"VQ0``#P```,?%```3````U\4``!0```#K
MQ0``$@````#&```4````$\8``!4````HQ@``$P```#[&```=````4L8```@`
M``!PQ@``"````'G&```K````@L8``"$```"NQ@``&@```-#&```)````Z\8`
M`$4```#UQ@``00```#O'```/````?<<```0```"-QP``$P```)+'```3````
MIL<```D```"ZQP``"@```,3'```/````S\<``!````#?QP``!P```/#'```.
M````^,<```4````'R```#0````W(```'`0``&\@```8````CR0``&P```"K)
M```&````1LD``",```!-R0``"````'')```&````>LD``!0```"!R0``$0``
M`);)```F````J,D```X```#/R0``.````-[)```&````%\H```X````>R@``
M&@```"W*```%````2,H```<```!.R@``#@```%;*```&````9<H```P```!L
MR@``*0```'G*```7````H\H``!\```"[R@``7````-O*```4````.,L``#X`
M``!-RP``'P```(S+```0````K,L``!0```"]RP``!P```-++```+````VLL`
M``X```#FRP``#````/7+```,`````LP``!,````/S```"@```"/,```=````
M+LP``!D```!,S```!0```&;,```1````;,P``!$```!^S```)````)#,```5
M````M<P``!(```#+S```#@```-[,```9````[<P```@````'S0``"0```!#-
M```*````&LT```<````ES0``"````"W-```K````-LT``!(```!BS0``+```
M`'7-```:````HLT```D```"]S0``"@```,?-```5````TLT``!````#HS0``
M!0```/G-```4````_\T```0````4S@``$````!G.```&````*LX```<````Q
MS@``'@```#G.```H````6,X```H```"!S@``'````(S.```:````J<X```\`
M``#$S@``%````-3.```$````Z<X```4```#NS@``!@```/3.```&````^\X`
M``H````"SP``&P````W/```T````*<\``#0```!>SP``(````)//```I````
MM,\``"````#>SP``00```/_/```:````0=```!T```!<T```*````'K0```<
M````H]```!P```#`T```*0```-W0```I````!]$``%$````QT0``5P```(/1
M```L````V]$``"(````(T@``'P```"O2```9````2](``!D```!ET@``*@``
M`'_2```K````JM(``",```#6T@``+@```/K2```T````*=,```T```!>TP``
M"````&S3```7````==,```H```"-TP``!P```)C3```A````H-,```T```#"
MTP``$````-#3```.````X=,```L```#PTP``!P```/S3```3````!-0```@`
M```8U```"P```"'4```*````+=0``!0````XU```,@```$W4```%````@-0`
M`!<```"&U```#P```)[4```.````KM0```4```"]U```!````,/4```-````
MR-0``#(```#6U```10````G5```7````3]4``!X```!GU0``%````(;5```5
M````F]4```4```"QU0``%````+?5```'````S-4``",```#4U0``#@```/C5
M```J````!]8```8````RU@``#````#G6```-````1M8``!$```!4U@``%P``
M`&;6```+````?M8``#8```"*U@``"@```,'6```B````S-8```L```#OU@``
M#P```/O6```+````"]<``"`````7UP``)P```#C7```K````8-<```D```",
MUP``,@```);7```P````R=<``#$```#ZUP``+0```"S8``!`````6M@``#T`
M``";V```0@```-G8```^````'-D``#\```!;V0``0@```)O9```^````WMD`
M`#\````=V@``0@```%W:```^````H-H``#\```#?V@``00```!_;```]````
M8=L``#X```"?VP``/P```-[;```[````'MP``#P```!:W```/0```)?<```Z
M````U=P``$(````0W0``/@```%/=```_````DMT```X```#2W0``%````.'=
M```%````]MT```X```#\W0``$P````O>```'````']X``!$````GW@``#@``
M`#G>```'````2-X``!0```!0W@``#@```&7>```8````=-X```<```"-W@``
M!0```)7>```,````F]X```P```"HW@``$@```+7>```$````R-X```H```#-
MW@``"P```-C>```,````Y-X```X```#QW@``#@````#?```%````#]\```4`
M```5WP``+@```!O?```F````2M\``",```!QWP```P```)7?```>````F=\`
M`!@```"XWP``)0```-'?```-````]]\```D````%X```!P````_@```*````
M%^````(````BX```$@```"7@```-````..```!(```!&X```!````%G@```'
M````7N````D```!FX```#````'#@``!2````?>```!<```#0X```)````.C@
M```'````#>$```8````5X0``#@```!SA```+````*^$```X````WX0``#```
M`$;A```-````4^$``!4```!AX0``$@```'?A```/````BN$``!0```":X0``
M&P```*_A```0````R^$``&@```#<X0``&@```$7B```7````8.(``"<```!X
MX@``&@```*#B```7````N^(``!L```#3X@``&0```._B```?````">,``!<`
M```IXP``$P```$'C```(````5>,```@```!>XP``"0```&?C```-````<>,`
M`!,```!_XP```P```)/C``!&````E^,``#\```#>XP``-````![D```D````
M4^0``#<```!XY```5P```+#D```%````".4``!\````.Y0``+P```"[E```(
M````7N4```T```!GY0``#@```'7E```M````A.4```0```"RY0``3P```+?E
M```E````!^8``!P````MY@``"P```$KF```?````5N8``!T```!VY@``)0``
M`)3F```@````NN8``"0```#;Y@``(`````#G```+````(><```8````MYP``
M.0```#3G```'````;N<``!D```!VYP``"0```)#G```3````FN<```0```"N
MYP``$````+/G```P````Q.<``!0```#UYP``#0````KH```.````&.@``!,`
M```GZ```'````#OH```H````6.@```8```"!Z```!P```(CH```3````D.@`
M``0```"DZ```%P```*GH```*````P>@```P```#,Z```"0```-GH```&````
MX^@```4```#JZ```"@```/#H```1````^^@```8````-Z0``#@```!3I```.
M````(^D```T````RZ0``"P```$#I```=````3.D```L```!JZ0```@```';I
M```<````>>D```<```"6Z0``%P```)[I```&````MND``&4```"]Z0``"0``
M`"/J```'````+>H``"8````UZ@``.````%SJ```:````E>H``"H```"PZ@``
M.P```-OJ```H````%^L``#0```!`ZP``&0```'7K```5````C^L```<```"E
MZP``"````*WK```'````MNL```<```"^ZP``#@```,;K```)````U>L```8`
M``#?ZP``"````.;K```+````[^L```<```#[ZP``!P````/L```0````"^P`
M``8````<[```'````"/L```%````0.P``!````!&[```$````%?L```/````
M:.P```<```!X[```!0```(#L```-````ANP``!````"4[```%````*7L```+
M````NNP```T```#&[```&````-3L```7````[>P``!H````%[0``%````"#M
M```$````->T```D````Z[0``"@```$3M```'````3^T```(```!7[0``'P``
M`%KM```C````>NT``#@```">[0``,0```-?M```G````">X``&0````Q[@``
M%````);N```<````J^X``%4```#([@``.````![O``!*````5^\``%L```"B
M[P``*````/[O```X````)_```"H```!@\```*````(OP```L````M/```"<`
M``#A\```&P````GQ```^````)?$``*D!``!D\0``(P````[S```7````,O,`
M`$@```!*\P``(P```)/S``"%````M_,``#`````]]```00```&[T``!;````
ML/0``$P````,]0``CP```%GU```=````Z?4``!@````']@``(0```"#V```?
M````0O8``"L```!B]@``(0```([V```I````L/8``"<```#:]@``'0````+W
M```1````(/<``#,````R]P``)0```&;W```X````C/<``"````#%]P``'P``
M`.;W```P````!O@``&D````W^```,@```*'X```Q````U/@``$$````&^0``
M,P```$CY```E````?/D``#T```"B^0``90```.#Y``!-````1OH``"\```"4
M^@``+@```,3Z```K````\_H``#`````?^P``*@```%#[```^````>_L``%0`
M``"Z^P``6@````_\``!(````:OP``$H```"S_```%````/[\```R````$_T`
M`!T```!&_0``(P```&3]```O````B/T``"P```"X_0``+0```.7]``!Q````
M$_X``&\```"%_@``LP```/7^```7````J?\``"4```#!_P``,@```.?_```I
M````&@`!`#X```!$``$`(@```(,``0!2````I@`!`,T```#Y``$`FP```,<!
M`0"F````8P(!`"4````*`P$`"P```#`#`0"Q````/`,!`(D```#N`P$`10``
M`'@$`0`A````O@0!`)<```#@!`$`,````'@%`0`E````J04!`!P```#/!0$`
M!P```.P%`0`$````]`4!``T```#Y!0$`"P````<&`0`.````$P8!``4````B
M!@$`$````"@&`0`"````.08!`%D````\!@$`!0```)8&`0`2````G`8!``@`
M``"O!@$``P```+@&`0`0````O`8!``P```#-!@$`$````-H&`0`-````ZP8!
M``(```#Y!@$`#@```/P&`0`2````"P<!``,````>!P$`*@```"('`0`$````
M30<!`!\```!2!P$`-0```'('`0`N````J`<!`"\```#7!P$`%P````<(`0`@
M````'P@!`!L```!`"`$`&````%P(`0`D````=0@!`!\```":"`$`&@```+H(
M`0`@````U0@!`!H```#V"`$`,@```!$)`0`O````1`D!`!H```!T"0$`*P``
M`(\)`0`?````NPD!`",```#;"0$`'P```/\)`0`:````'PH!`"4````Z"@$`
M)@```&`*`0`E````APH!`"0```"M"@$`&````-(*`0`=````ZPH!`"0````)
M"P$`&````"X+`0`B````1PL!`"4```!J"P$`*@```)`+`0`\````NPL!`!\`
M``#X"P$`(P```!@,`0`?````/`P!`"````!<#`$`&@```'T,`0`8````F`P!
M`"8```"Q#`$`'@```-@,`0`I````]PP!`!X````A#0$`"0```$`-`0`,````
M2@T!`!<```!7#0$`%P```&\-`0`O````APT!`"0```"W#0$`!P```-P-`0`?
M````Y`T!``4````$#@$`!P````H.`0`B````$@X!`"4````U#@$`'0```%L.
M`0`:````>0X!``<```"4#@$`QP```)P.`0`+````9`\!`!4```!P#P$`!@``
M`(8/`0`)````C0\!`!@```"7#P$`"P```+`/`0`-````O`\!`!<```#*#P$`
M!@```.(/`0`S````Z0\!`!,````=$`$`$P```#$0`0`/````11`!`!$```!5
M$`$`!P```&<0`0`R````;Q`!`"$```"B$`$`$P```,00`0`,````V!`!`!$`
M``#E$`$`,@```/<0`0`4````*A$!`!`````_$0$`"````%`1`0`=````61$!
M``D```!W$0$`"@```($1`0`%````C!$!`!0```"2$0$`'0```*<1`0`(````
MQ1$!`!\```#.$0$`"````.X1`0`:````]Q$!``8````2$@$`%0```!D2`0`(
M````+Q(!`#\````X$@$`!P```'@2`0`/````@!(!``X```"0$@$`$````)\2
M`0`)````L!(!``D```"Z$@$`!P```,02`0`9````S!(!``H```#F$@$`"@``
M`/$2`0`)````_!(!``H````&$P$`#````!$3`0`7````'A,!``0````V$P$`
M*@```#L3`0`'````9A,!``(```!N$P$`!@```'$3`0`'````>!,!``T```"`
M$P$`"P```(X3`0`O````FA,!`#(```#*$P$`(````/T3`0`<````'A0!``P`
M```[%`$`,0```$@4`0`%````>A0!`!(```"`%`$`/P```),4`0`2````TQ0!
M``H```#F%`$`!@```/$4`0`3````^!0!``4````,%0$`!@```!(5`0`&````
M&14!``D````@%0$`!````"H5`0`,````+Q4!``H````\%0$`!0```$<5`0`8
M````314!`!D```!F%0$`'P```(`5`0`=````H!4!`!$```"^%0$``@```-`5
M`0`$````TQ4!``8```#8%0$``P```-\5`0`,````XQ4!`$4```#P%0$`&@``
M`#86`0`U````418!`"@```"'%@$`4P```+`6`0`9````!!<!`#X````>%P$`
M(````%T7`0`U````?A<!`"$```"T%P$`10```-87`0`P````'!@!`"@```!-
M&`$`*0```'88`0`F````H!@!`"4```#'&`$`*````.T8`0`H````%AD!`"(`
M```_&0$`,````&(9`0`2````DQD!`!,```"F&0$`$P```+H9`0`0````SAD!
M`'D```#?&0$`"0```%D:`0!R````8QH!`',```#6&@$`?````$H;`0`K````
MQQL!`%,```#S&P$`%P```$<<`0`6````7QP!``\```!V'`$`'P```(8<`0!`
M````IAP!`!\```#G'`$`'`````<=`0!1````)!T!`!L```!V'0$`%````)(=
M`0`2````IQT!`!````"Z'0$`$P```,L=`0`=````WQT!``\```#]'0$`#P``
M``T>`0`+````'1X!``<````I'@$`!0```#$>`0`4````-QX!``<```!,'@$`
M"````%0>`0`/````71X!``@```!M'@$`#````'8>`0`/````@QX!``8```"3
M'@$`%````)H>`0`&````KQX!``P```"V'@$`"````,,>`0`$````S!X!``H`
M``#1'@$`!````-P>`0`9````X1X!``(```#['@$`"0```/X>`0`&````"!\!
M``8````/'P$`)P```!8?`0`$````/A\!``\```!#'P$`$P```%,?`0`'````
M9Q\!``<```!O'P$`!@```'<?`0`0````?A\!`!(```"/'P$`!@```*(?`0`)
M````J1\!``4```"S'P$`(@```+D?`0`'````W!\!``<```#D'P$`"P```.P?
M`0`%````^!\!`&<!``#^'P$`*P```&8A`0!=````DB$!`!4```#P(0$`%@``
M``8B`0`/````'2(!``D````M(@$`"````#<B`0`'````0"(!``8```!((@$`
M#````$\B`0`0````7"(!``T```!M(@$`#0```'LB`0`6````B2(!`"<```"@
M(@$`$@```,@B`0`*````VR(!``X```#F(@$`#P```/4B`0`+````!2,!`!``
M```1(P$`)@```"(C`0`B````22,!`"H```!L(P$`%````)<C`0`(````K",!
M`"D```"U(P$`(P```-\C`0`/`````R0!`"`````3)`$`)0```#0D`0`W````
M6B0!`!4```"2)`$`#P```*@D`0`1````N"0!`!(```#*)`$`'@```-TD`0`X
M````_"0!`"T````U)0$`)P```&,E`0`K````BR4!`!L```"W)0$`#P```-,E
M`0`8````XR4!``T```#\)0$`"P````HF`0`+````%B8!``<````B)@$`)@``
M`"HF`0`;````428!`$,```!M)@$`3````+$F`0!?````_B8!`%\```!>)P$`
M8@```+XG`0!B````(2@!`$8```"$*`$`!0```,LH`0`<````T2@!``<```#N
M*`$`#0```/8H`0`,````!"D!`!$````1*0$`#@```",I`0`X````,BD!`#8`
M``!K*0$`$P```*(I`0`5````MBD!``D```#,*0$`"0```-8I`0`(````X"D!
M`!(```#I*0$`+````/PI`0`-````*2H!`!0````W*@$`%````$PJ`0`;````
M82H!`"\```!]*@$`%0```*TJ`0`/````PRH!`!0```#3*@$`$````.@J`0`E
M````^2H!`"$````?*P$`'0```$$K`0`@````7RL!``\```"`*P$`50```)`K
M`0`Y````YBL!`"@````@+`$`"0```$DL`0`0````4RP!`"\```!D+`$`"@``
M`)0L`0`2````GRP!`!D```"R+`$`"0```,PL`0`,````UBP!``T```#C+`$`
M`P```/$L`0`7````]2P!``X````-+0$`$0```!PM`0`;````+BT!`"4```!*
M+0$`+P```'`M`0`+````H"T!`!@```"L+0$`&0```,4M`0`=````WRT!`!L`
M``#]+0$`$P```!DN`0`4````+2X!`"(```!"+@$`%0```&4N`0`7````>RX!
M`"````"3+@$`"````+0N`0`(````O2X!``\```#&+@$`&````-8N`0`G````
M[RX!``<````7+P$`"````!\O`0`2````*"\!`!T````[+P$`&@```%DO`0`\
M````="\!`$0```"Q+P$`!0```/8O`0`+````_"\!`#H````(,`$`#@```$,P
M`0`2````4C`!`$,```!E,`$`*````*DP`0`M````TC`!`#``````,0$`,P``
M`#$Q`0`/````93$!``D```!U,0$`"0```'\Q`0`9````B3$!`!T```"C,0$`
M-````,$Q`0`J````]C$!`!`````A,@$`%````#(R`0`(````1S(!``\```!0
M,@$`%P```&`R`0`<````>#(!``4```"5,@$`+0```)LR`0`-````R3(!``@`
M``#7,@$`+0```.`R`0`2````#C,!``X````A,P$`!@```#`S`0`$````-S,!
M``H````\,P$`"````$<S`0`0````4#,!`!,```!A,P$`*````'4S`0`3````
MGC,!``H```"R,P$`%````+TS`0`+````TC,!``8```#>,P$`3````.4S`0`H
M````,C0!``<```!;-`$`'````&,T`0`D````@#0!`"8```"E-`$`-````,PT
M`0`D`````34!`"D````F-0$`@````%`U`0`W````T34!``L````)-@$`%P``
M`!4V`0`/````+38!`!`````]-@$`#P```$XV`0`0````7C8!``\```!O-@$`
M#P```'\V`0`&````CS8!`!L```"6-@$`%P```+(V`0`(````RC8!``8```#3
M-@$`#@```-HV`0!:````Z38!``H```!$-P$`$P```$\W`0!;````8S<!`!``
M``"_-P$`$@```-`W`0`/````XS<!`!4```#S-P$`%@````DX`0`L````(#@!
M`"\```!-.`$`%P```'TX`0`B````E3@!``@```"X.`$`)````,$X`0`5````
MYC@!`!$```#\.`$`&P````XY`0`7````*CD!`!$```!".0$`&P```%0Y`0`2
M````<#D!`!L```"#.0$`%@```)\Y`0`%````MCD!`!(```"\.0$`$````,\Y
M`0`'````X#D!``T```#H.0$`!@```/8Y`0`&````_3D!``\````$.@$`!@``
M`!0Z`0`+````&SH!``@````G.@$`#````#`Z`0`6````/3H!``L```!4.@$`
M"````&`Z`0`9````:3H!`#X```"#.@$`*P```,(Z`0`G````[CH!`!(````6
M.P$`$P```"D[`0`2````/3L!`!,```!0.P$`-````&0[`0!$````F3L!`",`
M``#>.P$`$`````(\`0`W````$SP!`!0```!+/`$`&P```&`\`0`(````?#P!
M``D```"%/`$`$@```(\\`0`M````HCP!`"@```#0/`$`,````/D\`0`K````
M*CT!`"4```!6/0$`)````'P]`0`?````H3T!`#X```#!/0$`*``````^`0`I
M````*3X!`"P```!3/@$`'0```(`^`0`F````GCX!`"X```#%/@$`,P```/0^
M`0`O````*#\!`"X```!8/P$`-0```(<_`0`D````O3\!`"(```#B/P$`1@``
M``5``0`6````3$`!`"0```!C0`$`+````(A``0`C````M4`!`!@```#90`$`
MP````/)``0`Q````LT$!`"<```#E00$`)@````U"`0`F````-$(!`#````!;
M0@$`'@```(Q"`0`H````JT(!`"0```#40@$`,@```/E"`0`U````+$,!`#4`
M``!B0P$`-````)A#`0"U````S4,!`"H```"#1`$`'````*Y$`0`C````RT0!
M`"L```#O1`$`*P```!M%`0!.````1T4!`$L```"610$`$0```.)%`0`$````
M]$4!``<```#Y10$`"@````%&`0`9````#$8!`!0````F1@$`%0```#M&`0`:
M````448!`!D```!L1@$`"P```(9&`0`-````DD8!``P```"@1@$`$P```*U&
M`0`-````P48!`!(```#/1@$`"P```.)&`0`_````[D8!``<````N1P$`$```
M`#9'`0`"````1T<!``@```!*1P$`"````%-'`0`;````7$<!`"<```!X1P$`
M"@```*!'`0`4````JT<!`!,```#`1P$`!0```-1'`0`/````VD<!``H```#J
M1P$`$0```/5'`0`-````!T@!`!$````52`$`#@```"=(`0`3````-D@!`!<`
M``!*2`$`'P```&)(`0`?````@D@!``<```"B2`$`$0```*I(`0`/````O$@!
M``@```#,2`$`#P```-5(`0`7````Y4@!`!\```#]2`$`#P```!U)`0`/````
M+4D!`"D````]20$`(0```&=)`0`]````B4D!``\```#'20$`%P```-=)`0`9
M````[TD!`!H````)2@$`/@```"1*`0`H````8TH!``H```",2@$`$````)=*
M`0`O````J$H!`!D```#82@$`"0```/)*`0`Z````_$H!`#4````W2P$`"```
M`&U+`0`.````=DL!`"8```"%2P$`$````*Q+`0`E````O4L!`"@```#C2P$`
M"0````Q,`0`=````%DP!`!(````T3`$`&0```$=,`0`/````84P!`!(```!Q
M3`$`#0```(1,`0!`````DDP!`#X```#33`$`"0```!)-`0`,````'$T!`#``
M```I30$`$````%I-`0`1````:TT!``L```!]30$`$0```(E-`0`2````FTT!
M`!H```"N30$`&P```,E-`0`B````Y4T!`!D````(3@$`(@```").`0`D````
M14X!`!4```!J3@$`"P```(!.`0`,````C$X!``\```"93@$`)@```*E.`0`3
M````T$X!``D```#D3@$`#````.Y.`0`>````^TX!`!H````:3P$`/P```#5/
M`0`G````=4\!``4```"=3P$`"P```*-/`0`7````KT\!`(X```#'3P$`(```
M`%90`0`%````=U`!`"````!]4`$`%@```)Y0`0`5````M5`!``8```#+4`$`
M!@```-)0`0`-````V5`!``P```#G4`$`%````/10`0`,````"5$!`"0````6
M40$`#0```#M1`0`*````25$!`!8```!440$`"````&M1`0`(````=%$!`!D`
M``!]40$`(@```)=1`0`C````NE$!``\```#>40$`.````.Y1`0`0````)U(!
M``<````X4@$`$````$!2`0`8````45(!`#<```!J4@$`+````*)2`0`B````
MSU(!`!T```#R4@$`'````!!3`0`C````+5,!`!L```!14P$`30```&U3`0`'
M````NU,!`!(```##4P$``P```-93`0`+````VE,!``L```#F4P$`#0```/)3
M`0`,`````%0!`!(````-5`$`#@```"!4`0`:````+U0!`!H```!*5`$`%```
M`&54`0`-````>E0!``\```"(5`$`$@```)A4`0`E````JU0!``8```#15`$`
M"@```-A4`0`-````XU0!``X```#Q5`$`!`````!5`0`%````!54!``8````+
M50$`&````!)5`0`/````*U4!``4````[50$`*@```$%5`0`8````;%4!``8`
M``"%50$`"````(Q5`0`/````E54!``H```"E50$`#````+!5`0`&````O54!
M``H```#$50$``@```,]5`0`'````TE4!`!H```#:50$`%P```/55`0`5````
M#58!`"$````C5@$``P```$56`0`'````258!`!,```!15@$`%````&56`0`-
M````>E8!``P```"(5@$`+@```)56`0`(````Q%8!``L```#-5@$`$````-E6
M`0`(````ZE8!``8```#S5@$`%0```/I6`0`1````$%<!`"X````B5P$`%@``
M`%%7`0`&````:%<!``\```!O5P$`#P```']7`0`)````CU<!`"P```"95P$`
M!````,97`0`'````RU<!`"8```#35P$`!@```/I7`0`*`````5@!`!4````,
M6`$`'0```")8`0`$````0%@!`"P```!%6`$`#0```')8`0`-````@%@!`!$`
M``".6`$`$````*!8`0`-````L5@!`"\```"_6`$`#P```.]8`0`0````_U@!
M`"T````060$`$@```#Y9`0`3````45D!``H```!E60$`/````'!9`0`C````
MK5D!`!\```#160$`)````/%9`0`'````%EH!``@````>6@$`#````"=:`0`M
M````-%H!`"L```!B6@$`00```(Y:`0`+````T%H!``P```#<6@$`(0```.E:
M`0`M````"UL!`!8````Y6P$`"P```%!;`0`5````7%L!``X```!R6P$`$```
M`(%;`0`5````DEL!`!$```"H6P$`/````+I;`0",````]UL!`'8```"$7`$`
M%@```/M<`0`+````$ET!`!(````>70$`$P```#%=`0`0````15T!``<```!6
M70$`"````%Y=`0`9````9UT!`!$```"!70$`%0```)-=`0`5````J5T!``X`
M``"_70$`%0```,Y=`0`?````Y%T!`"$````$7@$`<@```"9>`0`1````F5X!
M`!(```"K7@$`"P```+Y>`0`+````REX!`!0```#67@$`$````.M>`0`/````
M_%X!`!4````,7P$`%````")?`0`F````-U\!`"H```!>7P$`)P```(E?`0`G
M````L5\!`"H```#97P$`*P````1@`0`>````,&`!`$P```!/8`$`%````)Q@
M`0`4````L6`!`!0```#&8`$`%````-M@`0`2````\&`!`!@````#80$`&```
M`!QA`0`5````-6$!`!4```!+80$`.P```&%A`0`9````G6$!`!H```"W80$`
M-````-)A`0`4````!V(!``@````<8@$`#@```"5B`0`O````-&(!`!X```!D
M8@$`$P```(-B`0`/````EV(!`!D```"G8@$`&P```,%B`0`7````W6(!`!,`
M``#U8@$`&@````EC`0`A````)&,!`!H```!&8P$`%0```&%C`0`;````=V,!
M`"$```"38P$`&P```+5C`0`;````T6,!`!0```#M8P$`!@````)D`0`*````
M"60!``<````49`$`!P```!QD`0`,````)&0!`!<````Q9`$`$P```$ED`0`5
M````760!`!(```!S9`$`%0```(9D`0`4````G&0!`!4```"Q9`$`&````,=D
M`0`6````X&0!`"T```#W9`$`%````"5E`0`.````.F4!`!,```!)90$`$@``
M`%UE`0`.````<&4!``X```!_90$`#@```(YE`0`Y````G64!``8```#790$`
M#@```-YE`0`3````[64!``<````!9@$`$P````EF`0`.````'68!`!$````L
M9@$`%````#YF`0`C````4V8!`"H```!W9@$`)0```*)F`0`%````R&8!``<`
M``#.9@$`*0```-9F`0`(`````&<!`!0````)9P$`#P```!YG`0`*````+F<!
M`!(````Y9P$`!P```$QG`0`7````5&<!`#4```!L9P$`"0```*)G`0`,````
MK&<!`"@```"Y9P$`%@```.)G`0`6````^6<!``T````0:`$`,0```!YH`0`*
M````4&@!``P```!;:`$`#0```&AH`0`)````=F@!``<```"`:`$`!@```(AH
M`0`2````CV@!`$<```"B:`$`$````.IH`0`&````^V@!``X````":0$`!0``
M`!%I`0`&````%VD!`!<````>:0$`%P```#9I`0`6````3FD!``(```!E:0$`
M!@```&AI`0`,````;VD!`!````!\:0$`%@```(UI`0`]````I&D!``H```#B
M:0$`&@```.UI`0`/````"&H!``<````8:@$`!````"!J`0`R````)6H!`#8`
M``!8:@$`%````(]J`0`:````I&H!`!D```"_:@$`*````-EJ`0`G`````FL!
M``T````J:P$`!0```#AK`0`2````/FL!`!8```!1:P$`%0```&AK`0`6````
M?FL!`!<```"5:P$`'P```*UK`0`$````S6L!``H```#2:P$`$````-UK`0`1
M````[FL!``8`````;`$`8@````=L`0`0````:FP!``\```![;`$`$````(ML
M`0`:````G&P!`$H```"W;`$`!P````)M`0`;````"FT!``<````F;0$`!@``
M`"YM`0`)````-6T!`"H````_;0$`*0```&IM`0`)````E&T!``<```">;0$`
M(@```*9M`0!D````R6T!`!L````N;@$`(P```$IN`0`:````;FX!``(```")
M;@$`&````(QN`0`'````I6X!`!<```"M;@$`#P```,5N`0`-````U6X!``X`
M``#C;@$`!P```/)N`0`7````^FX!``X````2;P$`"P```"%O`0`/````+6\!
M``P````];P$`"P```$IO`0`+````5F\!``L```!B;P$`)P```&YO`0`0````
MEF\!`!$```"G;P$`&````+EO`0`E````TF\!``\```#X;P$`%0````AP`0`/
M````'G`!``4````N<`$`$P```#1P`0`&````2'`!``0```!/<`$`#0```%1P
M`0`*````8G`!``P```!M<`$`$P```'IP`0`>````CG`!`!,```"M<`$``P``
M`,%P`0`;````Q7`!``<```#A<`$`#@```.EP`0`,````^'`!`!$````%<0$`
M`P```!=Q`0`Z````&W$!`#L```!6<0$`'@```))Q`0`E````L7$!`"D```#7
M<0$`%0````%R`0!"````%W(!`$(```!:<@$`*P```)UR`0`P````R7(!`#X`
M``#Z<@$`/@```#ES`0`_````>',!`"\```"X<P$`1````.AS`0`T````+70!
M`!,```!B=`$`%````'9T`0`4````BW0!`!8```"@=`$`%P```+=T`0`1````
MSW0!`!,```#A=`$`%0```/5T`0`B````"W4!`!8````N=0$`)````$5U`0`4
M````:G4!`!0```!_=0$`+0```)1U`0`F````PG4!`"0```#I=0$`$@````YV
M`0!`````(78!`$0```!B=@$`$@```*=V`0`&````NG8!`!X```#!=@$`$0``
M`.!V`0`(````\G8!``@```#[=@$`$P````1W`0`5````&'<!``X````N=P$`
M$0```#UW`0`*````3W<!`!4```!:=P$`3P$``'!W`0`+````P'@!`!\```#,
M>`$`#````.QX`0`_````^7@!``D````Y>0$`!P```$-Y`0`2````2WD!``X`
M``!>>0$`*P```&UY`0`/````F7D!`#<```"I>0$`"P```.%Y`0`7````[7D!
M`"<````%>@$`"0```"UZ`0`)````-WH!`!````!!>@$`!P```%)Z`0`.````
M6GH!`#<```!I>@$`&@```*%Z`0`E````O'H!`(,```#B>@$`%P```&9[`0!*
M````?GL!`"H```#)>P$`$P```/1[`0`7````"'P!``@````@?`$`#````"E\
M`0`/````-GP!`!(```!&?`$`"@```%E\`0`0````9'P!``@```!U?`$`&P``
M`'Y\`0`8````FGP!``0```"S?`$`$0```+A\`0`9````RGP!`"H```#D?`$`
M%`````]]`0`<````)'T!`!(```!!?0$`*@```%1]`0`+````?WT!``L```"+
M?0$`"P```)=]`0`'````HWT!``<```"K?0$`,P```+-]`0`-````YWT!`"X`
M``#U?0$`%@```"1^`0`(````.WX!``D```!$?@$`'@```$Y^`0`:````;7X!
M``H```"(?@$`&P```)-^`0`(````KWX!`!8```"X?@$`"````,]^`0`'````
MV'X!`!\```#@?@$`,`````!_`0`-````,7\!`"4````_?P$`&@```&5_`0`3
M````@'\!`!8```"4?P$`"@```*M_`0`(````MG\!``L```"_?P$`#@```,M_
M`0`+````VG\!`"(```#F?P$`0`````F``0!"````2H`!`!T```"-@`$`+@``
M`*N``0`G````VH`!`$P````"@0$`&@```$^!`0`@````:H$!`"P```"+@0$`
M'0```+B!`0`>````UH$!`"H```#U@0$`-0```"""`0!Q````5H(!`%D```#(
M@@$`-0```"*#`0`L````6(,!`"<```"%@P$`%@```*V#`0`<````Q(,!`#H`
M``#A@P$`.````!R$`0`L````580!`#,```""A`$`.P```+:$`0`,````\H0!
M``4```#_A`$`(`````6%`0`'````)H4!``T````NA0$`*@```#R%`0`2````
M9X4!`!4```!ZA0$`$0```)"%`0`0````HH4!``@```"SA0$`%0```+R%`0`.
M````TH4!`!$```#AA0$`#@```/.%`0`<`````H8!`$$````?A@$`!P```&&&
M`0`;````:88!``P```"%A@$`#P```)*&`0`%````HH8!``@```"HA@$`$@``
M`+&&`0`_````Q(8!`%D````$AP$`*````%Z'`0`K````AX<!`"(```"SAP$`
M(````-:'`0`%````]X<!`!````#]AP$`!@````Z(`0`I````%8@!`!L````_
MB`$`-P```%N(`0`(````DX@!``X```"<B`$`#P```*N(`0`5````NX@!`!X`
M``#1B`$`$````/"(`0!)`````8D!``P```!+B0$`*````%B)`0`/````@8D!
M`!,```"1B0$`$@```*6)`0`E````N(D!`$0```#>B0$`-@```".*`0`,````
M6HH!`$$```!GB@$`.0```*F*`0`Z````XXH!`#8````>BP$`3````%6+`0!+
M````HHL!`$X```#NBP$`2````#V,`0!-````AHP!`$X```#4C`$`2````".-
M`0!-````;(T!`$X```"ZC0$`2`````F.`0!-````4HX!`$T```"@C@$`1P``
M`.Z.`0!,````-H\!`$L```"#CP$`10```,^/`0!*````%9`!`$D```!@D`$`
M2````*J0`0!.````\Y`!`$@```!"D0$`30```(N1`0`1````V9$!`!<```#K
MD0$`"0````.2`0`.````#9(!`!8````<D@$`#````#.2`0`7````0)(!`!L`
M``!8D@$`"0```'22`0`7````?I(!`!$```"6D@$`+````*B2`0`)````U9(!
M``4```#?D@$`$0```.62`0`,````]Y(!`!0````$DP$`!0```!F3`0`/````
M'Y,!`!,````ODP$`$````$.3`0`1````5),!`!$```!FDP$`"````'B3`0`'
M````@9,!`$$```")DP$`,0```,N3`0`R````_9,!``@````PE`$`'@```#F4
M`0`=````6)0!`"L```!VE`$`#````**4`0`+````KY0!``@```"[E`$`#```
M`,24`0`"````T90!`!0```#4E`$`$0```.F4`0`1````^Y0!``H````-E0$`
M#0```!B5`0`/````)I4!`!,````VE0$`9@```$J5`0`>````L94!`#4```#0
ME0$`"`````:6`0`)````#Y8!`!(````9E@$`$P```"R6`0`7````0)8!``\`
M``!8E@$`%P```&B6`0`;````@)8!`!8```"<E@$`%````+.6`0`<````R)8!
M`!T```#EE@$`&0````.7`0"%````'9<!`",```"CEP$`+````,>7`0`M````
M])<!`!P````BF`$`)````#^8`0`B````9)@!`!X```"'F`$`%P```*:8`0`F
M````OI@!`!T```#EF`$`#`````.9`0`,````$)D!``L````=F0$`$0```"F9
M`0`9````.YD!``0```!5F0$`8````%J9`0!`````NYD!`$@```#\F0$`(@``
M`$6:`0!"````:)H!`'@```"KF@$`!P```"2;`0`L````+)L!`#8```!9FP$`
M!@```)";`0`0````EYL!`!$```"HFP$`00```+J;`0`(````_)L!`%$````%
MG`$`0````%><`0`O````F)P!`!$```#(G`$`*P```-J<`0`C````!IT!`"T`
M```JG0$`)@```%B=`0`N````?YT!`"<```"NG0$`&@```-:=`0`*````\9T!
M`#$```#\G0$`$````"Z>`0`H````/YX!``@```!HG@$`%````'&>`0`'````
MAIX!`!(```".G@$`-P```*&>`0`?````V9X!`!(```#YG@$`#P````R?`0`0
M````')\!`"$````MGP$`+P```$^?`0`3````?Y\!``<```"3GP$`$P```)N?
M`0`$````KY\!`!L```"TGP$`#P```-"?`0`/````X)\!`!````#PGP$`"```
M``&@`0`&````"J`!``P````1H`$`$@```!Z@`0`)````,:`!`!$````[H`$`
M#@```$V@`0`.````7*`!``P```!KH`$`)````'B@`0`*````G:`!``(```"H
MH`$`'0```*N@`0`$````R:`!`"0```#.H`$`"````/.@`0!L````_*`!``H`
M``!IH0$`"````'2A`0`C````?:$!`$````"AH0$`%P```.*A`0`F````^J$!
M`%$````AH@$`+````'.B`0`[````H*(!`!<```#<H@$`$P```/2B`0`1````
M"*,!``<````:HP$`!````"*C`0`'````)Z,!``P````OHP$`"0```#RC`0`$
M````1J,!``8```!+HP$`"P```%*C`0`*````7J,!``<```!IHP$`+````'&C
M`0`&````GJ,!`"4```"EHP$`!P```,NC`0`0````TZ,!`!````#DHP$`%```
M`/6C`0`'````"J0!``@````2I`$`$P```!ND`0`1````+Z0!`!\```!!I`$`
M"P```&&D`0`-````;:0!`!L```![I`$`$P```)>D`0`;````JZ0!`!(```#'
MI`$`!P```-JD`0`,````XJ0!`!$```#OI`$`#P````&E`0`"````$:4!`#``
M```4I0$`*0```$6E`0`K````;Z4!`"H```";I0$`)0```,:E`0!Y````[*4!
M`!(```!FI@$`*````'FF`0!,````HJ8!`#0```#OI@$`5P```"2G`0!2````
M?*<!`"$```#/IP$`.@```/&G`0`I````+*@!`"\```!6J`$`-0```(:H`0`Q
M````O*@!`"````#NJ`$`0`````^I`0#P`0``4*D!`!P```!!JP$`%@```%ZK
M`0!'````=:L!`"D```"]JP$`@````.>K`0!#````:*P!`#X```"LK`$`:@``
M`.NL`0!I````5JT!`)H```#`K0$`(0```%NN`0`3````?:X!`!X```"1K@$`
M'P```+"N`0`D````T*X!`"$```#UK@$`+````!>O`0`E````1*\!`!P```!J
MKP$`$@```(>O`0`Y````FJ\!`"L```#4KP$`-0````"P`0`D````-K`!`"$`
M``!;L`$`0````'VP`0!K````OK`!`#`````JL0$`,````%NQ`0!$````C+$!
M`"\```#1L0$`)`````&R`0`T````)K(!`'P```!;L@$`50```-BR`0!(````
M+K,!`$(```!WLP$`.0```+JS`0`]````]+,!`#@````RM`$`1@```&NT`0!5
M````LK0!`'(````(M0$`<````'NU`0!9````[+4!`!@```!&M@$`.P```%^V
M`0`B````F[8!`"T```"^M@$`+````.RV`0`L````&;<!`#$```!&MP$`:```
M`'BW`0!E````X;<!`+,```!'N`$`&0```/NX`0`L````%;D!`$@```!"N0$`
M-@```(NY`0!=````PKD!`#,````@N@$`6@```%2Z`0#(````K[H!`-T```!X
MNP$`@P```%:\`0`C````VKP!``X```#^O`$`P`````V]`0"O````SKT!`$D`
M``!^O@$`,````,B^`0":````^;X!`$,```"4OP$`)0```-B_`0`D````_K\!
M``D````CP`$``P```"W``0`4````,<`!``H```!&P`$`#````%'``0`&````
M7L`!`!$```!EP`$`!````'?``0!U````?,`!``8```#RP`$`%P```/G``0`%
M````$<$!``8````7P0$`$P```![!`0`+````,L$!`!0````^P0$`#P```%/!
M`0`"````8\$!`!P```!FP0$`(````(/!`0`5````I,$!`$P```"ZP0$`%@``
M``?"`0`E````'L(!`$,```!$P@$`.````(C"`0`Y````P<(!`!@```#[P@$`
M+@```!3#`0`B````0\,!`"````!FPP$`*````(?#`0`C````L,,!`"$```#4
MPP$`)P```/;#`0`@````'L0!`#,````_Q`$`,````'/$`0`<````I,0!`#\`
M``#!Q`$`(0````'%`0`U````(\4!`"@```!9Q0$`(P```(+%`0`Z````IL4!
M`"X```#AQ0$`+````!#&`0`A````/<8!`"0```!?Q@$`*````(3&`0`O````
MK<8!`",```#=Q@$`*0````''`0`U````*\<!`$8```!AQP$`.@```*C'`0`H
M````X\<!`"P````,R`$`*P```#G(`0`L````9<@!`"8```"2R`$`(0```+G(
M`0`O````V\@!`"8````+R0$`,@```#+)`0`K````9<D!``X```"1R0$`#P``
M`*#)`0`B````L,D!`"$```#3R0$`.0```/7)`0`Q````+\H!`!$```!AR@$`
M(0```'/*`0`'````E<H!``<```"=R@$`(@```*7*`0`E````R,H!`!\```#N
MR@$`'@````[+`0`'````+<L!``<!```URP$`$0```#W,`0`:````3\P!``D`
M``!JS`$`#````'3,`0`@````@<P!`!````"BS`$`$0```+/,`0`D````Q<P!
M``@```#JS`$`-0```//,`0`:````*<T!`!D```!$S0$`$P```%[-`0`F````
M<LT!``D```"9S0$`-@```*/-`0`O````VLT!`!(````*S@$`#P```!W.`0`.
M````+<X!`#<````\S@$`%0```'3.`0`6````BLX!``P```"AS@$`(0```*[.
M`0`-````T,X!``X```#>S@$`!P```.W.`0`4````]<X!`!P````*SP$`"```
M`"?/`0`T````,,\!``H```!ESP$`%P```'#/`0`%````B,\!`!H```".SP$`
M"0```*G/`0`[````L\\!``8```#OSP$`#P```/;/`0`3````!M`!``X````:
MT`$`!P```"G0`0`)````,=`!``L````[T`$`'P```$?0`0`/````9]`!`!(`
M``!WT`$`$0```(K0`0`)````G-`!``H```"FT`$`&@```+'0`0`'````S-`!
M`#,```#4T`$`#0````C1`0`"````%M$!``L````9T0$`"P```"71`0`2````
M,=$!``\```!$T0$`/P```%31`0`[````E-$!`"<```#0T0$`)0```/C1`0`,
M````'M(!`%,````KT@$`!@```'_2`0`5````AM(!`$4```"<T@$`$0```.+2
M`0`.````]-(!``<````#TP$`&`````O3`0`'````)-,!``@````LTP$`!0``
M`#73`0`/````.],!``<```!+TP$`$@```%/3`0`1````9M,!``4```!XTP$`
M&@```'[3`0`A````F=,!`!\```"[TP$`(P```-O3`0`1````_],!``(````1
MU`$`!````!34`0`&````&=0!``,````@U`$`#````"34`0!E````,=0!`!L`
M``"7U`$`.````+/4`0`A````[-0!`%,````.U0$`$@```&+5`0!&````==4!
M`"$```"\U0$`/@```-[5`0`C````'=8!`$$```!!U@$`.````(/6`0`Q````
MO-8!`#````#NU@$`,````!_7`0`P````4-<!`#$```"!UP$`+````+/7`0`P
M````X-<!`$$````1V`$`&P```%/8`0`<````;]@!`!$```",V`$`$@```)[8
M`0!]````L=@!``P````OV0$`=P```#S9`0!T````M-D!`(@````IV@$`,0``
M`++:`0!B````Y-H!`!4```!'VP$`'P```%W;`0`4````?=L!`",```"2VP$`
M1````+;;`0`A````^]L!`!0````=W`$`5````#+<`0`>````A]P!`",```"F
MW`$`(0```,K<`0`5````[-P!`"(````"W0$`+@```"7=`0`2````5-T!``H`
M``!GW0$`$````'+=`0`&````@]T!``<```"*W0$`%````)+=`0`'````I]T!
M``8```"OW0$`&````+;=`0`(````S]T!``\```#8W0$`%0```.C=`0`)````
M_MT!`!,````(W@$`!P```!S>`0`0````)-X!``H````UW@$`!@```$#>`0`+
M````1]X!``8```!3W@$`&0```%K>`0`"````=-X!``4```!WW@$`#````'W>
M`0`(````BMX!`#$```"3W@$`!0```,7>`0`5````R]X!`!L```#AW@$`#0``
M`/W>`0`*````"]\!``X````6WP$`$0```"7?`0`6````-]\!``@```!.WP$`
M#@```%??`0`%````9M\!`"L```!LWP$`"P```)C?`0`'````I-\!``X```"L
MWP$`#0```+O?`0`!````V@0``(,"``!+`@``J@$``$X"``"O!0``````````
M``""!```-P````````!T`P``@P```&X"```7!0```````&@"``!^!0``U@4`
M`/,$``":````@@4```````"0````J0$``(X$``#H````;`4``!8#``"E`@``
MG@0``````````````````"`%``!(!```X`,``.,```"4`0``^`4`````````
M````1P```*<```#A`P``A0,``.\```"8!0``=04``/X%``#+`0``,@(``(<!
M```G`0```````#\#``#0`@``J04``'L```!K`0``+P0``!4#```Y````G@$`
M`%4%````````K0$``"\#``!;``````,``!(!``"J`@``X@$`````````````
MIP$``-<%``"[````J```````````````Z@````````#(`0``JP0```D&``#E
M`0``\`$``#<%````````[00``!<#`````````````+@#``#D````(`,`````
M``"#`0``)`,```H%``!/`0``*P4````````[`P``NP(``)H%````````````
M`+8!`````````````,0%````````C@$``.H%``#%`@``A@$```````#(`@``
MR00`````````````[P,``#X$````````=0$``)L!``"C`P``?`4``,T!````
M````&P`````````]`0```````.<%````````'00``+L$```[!```J0(`````
M````````M@,```````#<!0``.@```#8$```E!```Q@0``+H"``!<`0``Z@$`
M`%````#U!0``\@4``(X%``"<!0``BP$``"($````````VP(``"`"````````
M,P0``+@!``!R!0``[@4``'D%``!I`P``X@0``/X`````````Z`,```````#*
M`P``$0,```````"M!```L0$``*`"```#!```#@$``%0#```V`@```````'<!
M``"F`@``4P0``)0$``"+!```RP```-8#``"D````^`$``+P"````````&@(`
M`,\#``!R`P````````T#````````E0$``$<!```A`@````````````"B!0``
M&P$``)4#````````Z`4``&D"`````````````%($``#V!```3`(``#$%````
M````;@````````"P`@``0`,``'($``"(!```>@(``#P"````````9P,``,<%
M```C`P``P@```)$#``#>````U`0``-\%````````#P4``$4%``!1!```````
M`.$```#&`0```````#T$``!3`P````````````#-````ZP,```````"O`0``
M[P4``*8```#5`@``J@,```````"&`@``10````4!````````904``,D"````
M````3@0``%X%````````R@````````!E`@``VP,``)<#``!4!```S`,``(\#
M```B`````````/<"````````>````,X"``#6`@``R@4``!\$``"L`0``````
M``````#A`0``GP$``````````````````&(```#+`@``H`4```X`````````
ME0(``!4````F`P``C04``',$```E``````````````!*`@```````/0`````
M````4P$``&\!``#$`0``^P```)$!``!P````$P```"D$``"N`0```````&<$
M``"X!`````````\#````````70```(L#``#Z`@``40```.8#``#$`@``P`,`
M``````#Y!0``%04``)4%````````N0,````````*`0``VP4``,@#``!^`P``
M`````+$#``!A!0``ZP0``&$```"L`P```````-,$``#4`@``>P$``%X$````
M`````````*L#``"B`````````)\"``!B`P```````$,```"&`P``-00``&H%
M```)````D@0``,$```!-`@```````-,`````````-P$`````````````4`4`
M`"8$````````:@```$8"```^!0``"`4``)D#``!C````N00``/@$```H!```
M`````&@!``!M!0``Q@(``/0"``#&````DP0``)D$``!+!0``<`(``%L"``!S
M`P``Z0$```\"`````````````$<$````````8P(``$D#``"Y!0``6P4``.P$
M````````M0(``)H!``"4``````````H&``!,`````````,X%``#M`@``*@4`
M`/(!``#Q!0``9P```"X%```B`0``304``.4"``"/`0``OP0``"0!``"J!```
M`````-@!````````4P(```````#>!0``"`$```````!J`P``OP4``#<"``!T
M`@``5P,``"T$````````XP4``&T"``#:!0``20```!P%`````````````","
M````````=`0``/X$``!G!0```````-X!``!/`P```````&X%``"T`0``#`,`
M`%P"```3!```!@4``+<$```(!@``.@4``+(#``"<!```$@0``,$$``#9`P``
M=P(```````#6````2P```.X!``#S`0```````"4!```H`0``4`,``+D!``#`
M!```:`0```T```!``0``Q0,``(L"``#>`P``U`4``%D!``!F`P``!P,``"T!
M````````A0````````#%`0``N@,``#L````U`0```````"T#```-`@``20$`
M``L$``!&!```<`,``````````````````-`!``"W!0``U04``!H!``"P`0``
MW@(``'\%``"-`@``D@,``/\$``"M`P``$@``````````````_`,``,\!```A
M`P``?0````4#``#2!0``OP```)D%``!C!````````(P!``"S`0``,@,``%<!
M``")`@``=@(``,T"``!#`P```````.D$``!.````K0(``'`$````````@@(`
M`'4"```I`P```````&P!```6`0``T@```.8%``"!!```C@(```````"!`0``
M:P,```````#%````%0$``-0```"$`@``S`0``````````````````!X!```^
M`@```````$P$```P`0``X@```-,!````````>P0``)T"``#V`0```````,,$
M``!A`0```````*$%```Y!```!04```````"!!0``I0```'D$``#D`P``````
M`#@"``````````````T%``"K````NP$``$L$``!$````L@(``"4#```$!@``
MHP0``+`$``#_``````````````",!```$`,``-<````L`P```````%0%````
M````\P,```$&``!3!0``P@(``)P"``#*`0``P0$``.P!```R!0``&P,`````
M``#H`0```````/\!``"T``````````H$``!:!```20(``,L%``!Y`@``````
M`"@"``"B`@````````,"``"]`P``K@(``/\"```````````````!``"\````
M`````-`$``#B`P``*P(``"\%``"J!0```````-D"````````>P,``(`#```N
M````2`(``*<"``#S````D@4```````#]!0``S`4``(`%````````````````
M``#\!0``>`,```````#P!```5@0``'0%```T!````````)D"````````:```
M`(D!``````````````````!V`0``IP4``/D````.`@``[0```+T%``#[`P``
MI04``,X#````````A0$``-T!``!L`@``?0,``+$$```T`@``)P,`````````
M````Y0```)0"```<!```)`(``,(!```"````Q`,``.`%``"9`0```````.H"
M```S`0``)`0``'T!``!*!0``````````````````7`0```````!1`P``L@0`
M``````#U!````````$$```"N!0``D0(```\`````````U0,`````````````
M\`4``!`%```K!````````&,!````````K`(``'@$````````W0,``((!```"
M!@```````+@```##````H@$```````!_````````````````````6@(``%0!
M````````]`,``)T$``"J````'@,``#T```#[`0``1P,```$%``"S`P``5P4`
M`-T`````````YP$````````T`0``>`(``)\$``"(`@```````/H%``!(`P``
M`0$``)P!````````ZP4``/,"``#;`0``2@,``"\"````````U00``-P#````
M`````````(0#``!Z!````````,D#```3`P``*@$``%<"````````,`(``.,!
M```=````WP(```````#)````FP(```````#Y`0``*`,````````I````#P0`
M```%``#^`0``M@0```X%``"W`P``&`$``*$!``!X`0```````$0"``"Y`@``
MZP(```````#W````Q04````````7````W`(``&0"``!W````>@```/P$````
M````O@````````"?```````````````1````Y0,``!D%```````````````&
M```P!```B@```/T$```\!0``6`4``'("```Q!`````````````"M````X@4`
M``````!>````4@4```````#F!```G@,```D#``"$!0``6P0``%\"```K`0``
M!@```*($``#F`@``"00```````"*!0``@P,``'P"``"Z`````````-4`````
M`````````````````````````.0!``!2`````````%X"```<`0``F@0``-`%
M````````WP```&H$``!9`@``<0,```````#U``````````````#I`P``2P,`
M`#($``#V`P``-@4````````9!```]@(``)\%````````>P4``/\%``#7!```
M40$```````"I!```:`4``'L"```@!```0P(``)\#``"7`0```````#T%``!/
M!```[04``&,#``!9`P``6`,``%L#``"!````:P```"P````F`0``"P4``&T!
M````````:P4```````"6`0```````#4#````````;0,``,0```#C`P``O`0`
M``````#^`P```````"H$```@````+@(````````I`@``)P(```````!^`0``
MMP$``.0%````````,`4```````"<`P```````&P`````````.04``,,"``!=
M!0```````'D#``!V`P``?````'T"``#@````^0,```````!,!0``L04``+,$
M``"D`P````````````!N`0``VP0```H```#Q````N@4```````#1`P``````
M``````#T!````````(<```"H!```!@0````````F`@``PP$``%0````6`@``
M%@0``%\%```G````5`(``+X!``"$!```9`4```L&```&`@``7P$``%\$````
M`````````',````2!0``F@,``(@%```2`@``1@```+,"```K`P``````````
M````````9@```%$%``"Z!```P@0````````>````:04``%8#``"'`@``Z0``
M`'P!``"^!0``X04``+8`````````B@$``,<"``!_`@``/`,``/````"*!```
MI`0``!D#``#N````604``!\"````````HP$``+T$``#V`````````)(`````
M`````````&`$``!C!0```````````````````````/4#``!_`0``(P```&0#
M``"$`````````*\`````````4@(``%8````!!````````$X#``!)!0``````
M````````````0````#@#```,`@``-`,`````````````EP```"4%````````
M!`4``"T````[!0``/P```)L%``!V````(P4``#\"``"@`P``A0(`````````
M````XP(``,P!````````S@$``-8$``#9!````````$4!````````R0$``%(#
M````````@0,``.8`````````!08``-\$``#K````H`0````````"!```&`,`
M`````````````````"@````>!0``Z`(```````#I!0``.@$``+X$``!E`P``
M00$``#8!````````/`$``-P!````````Q00``#@$``#Q!```/P$```@"```'
M!@``[0,``#D#```0`0``%P$``#<#``#R````,0$``%`$```#`0``.@,`````
M````````;P4``+T`````````[`4``*@#````````]P0``)L#```V`P``````
M`+P%``!_`P``@````(X#``#\````D`0``/$!````````^@$```````!"!```
M`````-T%```X!0``5@(``+(!````````J`4``-H```"1!```H0(``(<$````
M````"0(```````#J`P``:`,``-$"``!Q`0``'0,```````#!`P``<04```,#
M```:!0``QP,`````````````G@```-X$``!U````_0(``%(!``"C!0``WP$`
M```````.`P``\0(```<``````````````(L`````````6@,``+4`````````
M`````.\!`````````````%@"``!:!0``XP0``#\$```0!```F0```,\````Y
M`@``$P4``"D%````````H00```8&````````?`,``+<````4`0``=`$``'<$
M`````````````$8%```P````'@(```````"I`P``YP,```L"````````````
M`&0!````````!`(`````````````&0$``/<#``"&!0``<0(``!P"``"Z`0``
M8@4``$(```!P`0``V`4``#H$````````[@,``/("``#]`0``<P4``*X```!I
M`0``+P$``$P#``"E`0``J`(```````#D!```"P```%4`````````V`0```@#
M```S`@```````&`%``"V`@```````(D%``"T!```&P0``'T$``!/````(0$`
M`!P````B!0``JP4````````^````G0$``'H#``#L`@``F`,```L#``!S`@``
MD@(``/D"````````IP,``"(#``!I`````P8``.`"````````+`4``"$`````
M````$`````````!O`@``S`(```(%`````````````(@#```'`@```````+P#
M``#8````!@$``#$`````````90$```````#2!```?`0``&D$``">`@``CP0`
M`(8$``!0`0```````-4!`````````````&($````````7@$``*8!``"P!0``
M`````````````````````#$#``#,`````````-<#``!V!0``V`(```````"U
M!```]@4``!P#``!>`P`````````````,!0``(P$``!@"``"K`0``1`4``&$"
M``"]`@``E@,``"T%````````<P$``#(````L`0``.````!0$``!;`0``````
M```````R`0``RP,``+$`````````!00``!0%```````````````````1!```
M`````-0#```5!```;P,```````!"`0``@P0``,,%``"O`P``E0```),`````
M````)`````````"``@``9@0``&T$````````(@(``*$````_!0``T04``*<$
M```)!0``K`0``(@```!7````\P4```````!B`0``!@,``%\#```,````````
M`!L%``!O````+@$``'X````]`@```````,````#Z`````````/@#``#Y!```
M``````T!```X`0``G0````````"P````BP4``"P$``!:`0``Q`0``+L%````
M````S00``$H$``!L`P``2`4````````4`@``-````&<"``"N`P```````)$%
M``"H`0```````-$!``#G`@``N0```*,"``#]````C0$``%P#````````W`0`
M`),%``"7`@``A04``)H"```8!```TP(```````#7`@``1P4``"H```##`P``
MT00``,$"``!G`0``+P`````````Y`0``@`0``+0"``#'````UP$``,\%``",
M`````````#P$````````P`(``&0````$`0```@(``/T#```L`@``50,```0$
M``".````T0```*8%`````````````!0#``"<````8`,``%P````-!```00,`
M``````!Z!0``````````````````C`,``'`%```:!```'P```-P```!O!```
M\`(```````!F`0```````)T#```7!```3`$``$T```#G````E00````````/
M`0````````````!T````"@(``*,```#9!0```````'$`````!```M0,``"H"
M````````D`4``(\`````````CP(``!T!```?!0```````+<"````````2@$`
M`+0#``#3`P``.P$``/0!````````8`$``*0!```2`P``-`4``($"``!!!```
MI0,``.4%``!6`0``H````&8%````````)`4``/$#``"[`P````````````"O
M`@```````$\"``#:`@``YP0````"````````+@,```@$``!&`P``(P0`````
M``#J!````````(0!``#A!```_`$```````!-`P``/0,``'X$``!%`P``!P$`
M`$4"```+`0``5@4```X$``#X`@````````,%``#R`P``700``/`#``"F`P``
M3P4``%T#```:`P``300``)T%```*`P``=0,```,```#+!````````,$%``!?
M`````````!T"``#"`P```````!L"````````L@4``,@%``#2`0```````),!
M``"O!````````#4```!D!```E@``````````````OP$``&$#``#O!```````
M`#,```#O`@``600``),"```^`P``Q@,``/H#``#W`0``L@````````!5`@``
MR````!0```"B`P``<@````````!#!0``6@``````````````LP4``%$"```7
M`@```````((#``!7!```0@(```````"7!```VP`````````!`@``<00``-T"
M`````````````"<%``#W!0``:P(```<$``#2`P``FP```&4$````````````
M`.`!````````P`4``'H!``#'`0``0`(`````````````AP4`````````````
M1P(````````,!```````````````````S@````````!@``````````````"U
M`0``\@0``+\#``````````````````!W`P``6`$``#X!````````S0,`````
M````````$0$``+@"``#'!```S04`````````````TP4```````!(`0``100`
M`)`"``"#!0``I00``%,```"4!0``+@0``#4%``!5!```^P(```````#B`@``
MO@,```````#I`@``Q@4``(P%```S`P``_@(``$0!````````T````)@!``"U
M!0``B@,````````>!```E@0```````"T!0``(00``-T$````````F`(`````
M`````````````&P$``#E!```A@```(T$````````00(``#L"``!)!```R@(`
M`&$$```U`@``30$``!@```!F`@```````)<%``!=`@``P@4``.L!````````
M[@(```4```"\`0``SP(``)@```!(````2@```!8%``",`@```````*$#````
M````&`4``(`!```!`P```````````````````````,H$``#D`@```@$`````
M`````````````'8$``!Y`0``-P0``,X$``"*`@``K04```````!$!```SP0`
M`!$"````````50$``'T%``!U!```)P0``%P%````````,0(```````")````
M`````%T!```E`@``'P$``-H#````````"````````````````````(\%````
M````:@$````````K`````````'D````,`0``1`,```(#````````'04``$`$
M````````I`(``#`#``"8!```6````)L$````````]0(``$`%``!.!0``)@``
M`*8$``!B`@``(`$``#H"````````L`,``&`"````````B`$``.`$````````
M`````/P"``!"`P``%0(`````````````[@0``&T````$`P```````-\#``"X
M!0``3@$``-@#``"]`0```````!$%``"K`@``E`,``*D`````````V@$`````
M``"V!0``H`$```````````````````````!R`0``(04```````"0`0``````
M`"D!``"L!0``$P(```D!``"%!```)@4``(<#`````````````!H```#[!0``
MK````)`#```S!0``G@4``!\#``#L`P``90``````````````````````````
M`````````&X#``#L````B0,``$,$````````L0(``)(!``#Z!````````/\#
M````````V0```"T"````````LP```.$"``"^`@```````!`"``#M`0``````
M`/0%````````;@0``#P```"_`@``!````/@```#)!0``?@(`````````````
M*@,`````````````C0,``%D```""````T@(``%`"``!K!```D0```)8"``!!
M!0``0@4``.@$`````````````,`!``#4`0``C0```'@%``"D!0``:@(```4"
M``"6!0``6`0``/L$```3`0``=P4``!D```#F`0```````(D$``#U`0``-@``
M`!8```!_!````````-8!````````T`,```````!#`0``2P$``"@%```'!0``
M1@$``-D!```9`@``DP,```````#(!```K@0````@(%1H92!M86EL8F]X('1R
M87-H(&ES(&%L<F5A9'D@96UP='DN`"`F(S$U,3L@)7,@:7,@<F5A9'D@=&\@
M<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E
M;&]W+@`@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D
M87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``E
M9"`E<R!A;F0@)7,`)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($%D
M;6EN:7-T<F%T:6]N`"5S($9I;F=E<G!R:6YT`"5S($UA:6YT96YA;F-E($]P
M97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E
M<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T
M("5S("5S`"5S(&AA<R!C86YC96QL960@)7,N`"5S(&AA<R!R97!L:65D('1O
M(&$@9G)E92]B=7-Y(')E<75E<W0N`"5S(&AA<R!R97!L:65D('1O('1H92!I
M;G9I=&%T:6]N('1O("5S+@`E<R!H87,@<V5N="!Y;W4@9G)E92]B=7-Y(&EN
M9F]R;6%T:6]N+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(')E<75E
M<W1S('EO=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@`E<R!R97%U97-T<R!Y
M;W5R('!R97-E;F-E(&%T("5S+@`E<R!T;R`E<R!O9B`E<P`E<R!W:7-H97,@
M=&\@861D('1O("5S+@`E<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@
M)7,N`"5S('=I<VAE<R!T;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M871I
M;VX@86)O=70@)7,N`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`
M)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)R5S)R!I<R!N;W0@82!V86QI
M9"!C:&]I8V4N`"<E<R<@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E
M(%)E9VES=')Y+@`G)7,G('1R964@<F5N9&5R97(@;F]T(&9O=6YD+@`G)7,G
M('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`)R5S)R!W87,@861D
M960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`)R5S)R!W87,@;F]T(&-R
M96%T960Z("5S+@`L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S
M('1O("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O
M<FUA=``R-"!H;W5R<P`\8CY!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9#H\
M+V(^`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A
M9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!
M('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@
M4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3
M34E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-
M+U!-`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M
M:61D;&4`06-C97!T(')E<75E<W0`06-C97!T960`06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!F:6QE+@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!
M8V-O=6YT:6YG`$%C=&EO;G,`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI
M;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W
M(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@)R5S)P!!9&0@82!C
M:&EL9"!P97)M:7-S:6]N('1O("<E<R<`061D(&$@;F5W('5S97(Z`$%D9"!C
M;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N
M=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&AI<R!T;R!M>2!C86QE;F1A
M<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K
M`$%D9"!U<V5R`$%D9&5D("<E<R<@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD
M(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!
M9&1E9"`G)7,G('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`
M061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O
M:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R
M<P!!9&UI;FES=')A=&EO;@!!:W1I;VX@06ER<&]R=`!!;&5X86YD<F]U<&]L
M:2!!:7)P;W)T`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H
M96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L
M;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S
M971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!
M;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!
M;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S
M<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;B!I;&QE
M9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N8VAI86QO<R!!:7)P;W)T`$%N
M9')A=FED82!!:7)P;W)T`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`07!P;&EC
M871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`
M07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!R:6P`07)A>&]S($%I
M<G!O<G0`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O
M<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@)R5S)R!A
M;F0@86YY('-U8BUG<F]U<',_`$%R=`!!<V-I:2!!<G0`07-K(&9O<B!C;VYF
M:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_
M`$%S<VEG;FUE;G0@8V]L=6UN<P!!=&AI;F%I($%I<G!O<G0`071T86-H960@
M:7,@86X@:4-A;&5N9&%R(&9I;&4@<F5P;'D@=&\@82!R97%U97-T('EO=2!S
M96YT`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!
M='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T
M96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1E;F1E97,`
M071T<FEB=71E<P!!=6=U<W0`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE
M;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@
M8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E
M<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$%W86ET:6YG(%)E<W!O;G-E
M`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S
M<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%R90!"87-E(&=R87!H
M:6-S(&1I<F5C=&]R>2`G)7,G(&YO="!F;W5N9"X`0F%S96QI;F4`0FER=&AD
M87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`
M0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O<F1E<G,`0F]T:`!"
M;W1T;VT`0G5L;&5T960@3&ES=`!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#
M5E,`0U]E;&P@4')O<&5R=&EE<RXN+@!#86QE;F1A<@!#86QE;F1A<B!3=6UM
M87)Y`$-A;&5N9&%R.@!#86QM`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T
M;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B=T
M(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;F-E;`!#86YC96P@4')O
M8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F
M:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET
M:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I
M<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES
M="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D
M(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A
M;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<'1I
M;VX`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-E;&P@4&AO;F4`0V5L;"!0<F]P
M97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A
M8VEN9SH`0V5L;'!H;VYE`$-E;G1E<@!#97)T:69I8V%T92!$971A:6QS`$-E
M<G1I9FEC871E(%!O;&EC:65S`$-H86ER(%!E<G-O;@!#:&%N9V4`0VAA;F=E
M(%!A<W-W;W)D`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E
M;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA
M:6QS+@!#:&%R`$-H96-?:R!,:6YK+BXN`$-H96-K('1H92!B;W@@9F]R(&%N
M>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I
M;64N`$-H:6]S($%I<G!O<G0`0VAO;W-E($%P<&QI8V%T:6]N.@!#:&]O<V4@
M82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@86X@86-T:6]N
M.@!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T
M>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:')Y<V]U<&]L:2!!:7)P
M;W)T`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#
M;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U
M<V5R`$-L96%R('5S97(@9&%T80!#;&EC:R!T;R!#;VYT:6YU90!#;&]S92!(
M96QP`$-L;W-E($AE;'`@5VEN9&]W`$-L;W-E(%=I;F1O=P!#;VQL87!S92!3
M:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]R`$-O;&]R(%!I8VME<@!#
M;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O
M;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;7!A
M;GD`0V]M<&QE=&5D`$-O;7!O<V4@365S<V%G92`H)7,I`$-O;7!U=&5R<P!#
M;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A
M=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/
M=71L;V]K+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U
M<F%T:6]N(&YE961S('5P9&%T:6YG+@!#;VYF:6=U<F4@)7,`0V]N9FER;2!0
M87-S=V]R9`!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z
M(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N
M`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@
M4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL
M960N`$-O;G1A8W0@4V5A<F-H`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT<R!O9B`G)7,G
M`$-O;G1E;G1S(&]F('1H92!205(@87)C:&EV90!#;VYT:6YU90!#;W!Y`$-O
M<'D@<V5L96-T:6]N`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+@!#
M;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!E
M;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E
M+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O
M($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U
M;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("<E<R<@=7-I;F<@1E10.B`E<P!#
M;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N
M;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%
M(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T
M(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E;&5T
M92!S971U<"!U<&=R861E('-C<FEP="`G)7,G+@!#;W5L9"!N;W0@9&5T97)M
M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T
M(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H
M(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@
M=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L
M9"!N;W0@;&]A9"!S=')A=&5G>2`G)7,G+@!#;W5L9"!N;W0@;6MD:7(@)R5S
M)RX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E
M<G9E<BX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N("<E<R<@
M9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@
M;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`G)7,G+@!#;W5L
M9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F
M;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T
M86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O
M=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E
M<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S
M+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S
M`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M
M9&ER("<E<R<N`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O
M=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T
M('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V
M92!S971U<"!U<&=R861E('-C<FEP="!T;SH@)R5S)RX`0V]U;&0@;F]T('-A
M=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO
M="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET
M:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B
M86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@
M)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N
M;W0@=6YL:6YK("<E<R<N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`
M0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@
M;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("<E<R<Z("5S`$-O=6QD;B=T
M(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E
M8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`G)7,G('1H92!F;VQL
M;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("<E<R<Z("5S`$-O=6YT960@
M=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!A(&QI;FL`0W)E
M871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E871O<B!097)M
M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)E9&ET<P!#=7)R96YT(%!H
M87-E`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%=E871H
M97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ
M92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE
M8W1I;VX`1$0`1&%I;'D`1&%T80!$871A5')E92!"<F]W<V5R`$1A=&%B87-E
M('%U97)Y(&9A:6QE9"X`1&%T90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T
M:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E
M<G,`1&5C;&EN960`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0`1&5F875L="!#
M;VQO<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@4&5R;6ES<VEO;G,`1&5F
M875L="!P97)M:7-S:6]N<P!$969I;FET:6]N<P!$96QE9V%T92!P;W-I=&EO
M;@!$96QE9V%T960`1&5L971E`$1E;&5T92!'<F]U<`!$96QE=&4@4&5R;6ES
M<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E
M;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T
M90!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("<E<R<`1&5L971E('!E<FUI<W-I
M;VYS(&9O<B`G)7,G(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@
M<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E
M;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E('1H:7,@
M<&5R;6ES<VEO;B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E9"!S
M971U<"!U<&=R861E('-C<FEP="`G)7,G+@!$96QI=F5R>2!T:6UE`$1E;GD@
M<F5Q=65S=`!$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA=&EO
M;@!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA
M;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0
M;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I
M<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T
M`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T
M:6]N<P!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I
M<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$;R!N;W0@9&5L971E`$1O(&YO="!D
M:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O97,@=&AE(&9I<G-T
M(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T
M:&ES(&)O>#H`1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI
M<W0`1')U9W,`161I=`!%9&ET($)L;V-K`$5D:70@1W)O=7``161I="!097)M
M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@
M)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M:7-S:6]N<R!F;W(@)7,`
M161I="!P97)M:7-S:6]N<R!F;W(@)R5S)P!%;&5F<VES($%I<G!O<G0`16QE
M;65N="XN+@!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M
M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6]T:6-O;G,`
M16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R
M;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL
M97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N
M=3\`16YD`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I
M='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE
M960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@
M;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`
M17)R;W(`17)R;W(@<V5N9&EN9R!R97!L>3H@)7,N`$5R<F]R('=I=&@@96UA
M:6P@;65S<V%G92X`17)R;W(@=W)I=&EN9R`G)7,G+@!%=&AN:6,`175R;W!E
M`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E
M8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@
M:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AP
M86YD`$5X<&%N9"!3:61E8F%R`$5X<&5C=&5D(")"14=)3B(@:6X@=&AE(&QI
M;F4@)60N`$5X<&5C=&5D(")%3D0Z)7,B(&EN(&QI;F4@)60N`$5X<&5C=&5D
M("<I)P!%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M
M`$5X<&ER871I;VX@1&%T90!%>'!O;F5N=`!&1R!#;VQO<@!&5%`@=7!L;V%D
M(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL
M960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE
M8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&
M86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!3
M05-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:6QU
M<F4@:6X@8VAA;F=I;F<@<&%S<W=O<F0@9F]R('5S97(@)7,@9G)O;2!C;&EE
M;G0@)7,L(')E87-O;B`E<P!&86ER`$9A=&%L($5R<F]R.@!&87@`1F5B<G5A
M<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N
M;W<@4VAO=V5R<P!&:65L9"!M871R:7@`1FEL92!#;W5N=#H@)7,@9FEL90!&
M:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I
M;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P
M<&]R=&5D+@!&:6QT97)S`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@
M<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T
M`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P
M;W)T(&EM86=E<P!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N
M90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R
M=V%R9',`1G(`1G)A;65S`$9R964O0G5S>2!);F9O<FUA=&EO;@!&<F5E+T)U
M<WD@4F5P;'D`1G)E92]"=7-Y(%)E<75E<W0`1G)E92]"=7-Y(%)E<75E<W0@
M4F5S<&]N<V4`1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL
M($1E<V-R:7!T:6]N.@!&=6QL($UO;VX`1G5L;"!.86UE`$=A;&QE<GD@=&\@
M=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=I=F5N($YA;64`1VQO8F%L($]P
M=&EO;G,`1V\`1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'<F]U<"!!9&UI
M;FES=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U
M<"!P97)M:7-S:6]N<P!'<F]U<',`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W0@
M<&5R;6ES<VEO;G,`1W5E<W1B;V]K`$A45%`@075T:&5N=&EC871I;VX@;F]T
M(&9O=6YD+@!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`
M2&5M:7-P:&5R90!(97)A:VQI;VX@06ER<&]R=`!(97)E(&ES('1H92!B96=I
M;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9V@`2&ES=&]R>2!E;G1R>2!N86UE<R!M
M=7-T(&)E(&YO;BUE;7!T>0!(;U]M90!(;VUE`$AO;64@061D<F5S<P!(;VUE
M(%!H;VYE`$AO<F1E`$AO<F1E($QO9VEN`$AO<F1E(%-Y<W1E;0!(;W)D92!7
M:7)E;&5S<P!(;W)D92!I<R!N;W0@<')O<&5R;'D@8V]N9FEG=7)E9`!(;W)I
M>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO
M=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY
M(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I
M96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD
M('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R
M:7-T<P!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA
M:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@
M8W)E871I;VX@9F%I;&5D.B`E<P!)3D)/6`!)4"!!9&1R97-S`$E0($%D9')E
M<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W
M960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYB;W@`
M25]N<V5R="!2;W<@0F5F;W)E`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC
M;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D
M:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I
M;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N
M970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T
M;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@
M;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U
M<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA
M9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G
M92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T`$EM
M<&]R="!%<G)O<CH@`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@
M)7,`26UP;W)T960@9FEE;&1S.@!);B!0<F]C97-S`$EN7W-E<G0@4F]W($%F
M=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S
M97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R
M(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R
M96%S92!);F1E;G0`26YD:79I9'5A;"!5<V5R<P!);F9O`$EN9F]R;6%T:6]N
M`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B
M;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E
M<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@
M82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@
M;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O
M=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A
M9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O
M<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E('1E;7!L871E
M`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C
M96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E
M<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L
M=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A
M9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R
M`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R
M('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G
M90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S
M96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R
M961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!!8W1I;VX@<V5L
M96-T960@9F]R('1H:7,@8V]M<&]N96YT+@!);G9A;&ED(%5$2"X@*%5S97(@
M1&%T82!(96%D97(I+@!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A
M=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I
M;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!M
M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O
M<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I
M;VXN`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`G)7,G
M`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N
M`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`271A;&EC`$IA;G5A
M<GD`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&
M=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA;&%M871A($%I<G!O
M<G0`2V%R<&%T:&]S($%I<G!O<G0`2V%S=&]R:6$@06ER<&]R=`!+965P(&]R
M:6=I;F%L/P!+969A;&AN:6$@06ER<&]R=`!+97)B97)O<R!S97)V97(@<F5J
M96-T960@875T:&5N=&EC871I;VXN`$ME<FMY<F$@06ER<&]R=`!+97)N96P@
M3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG
M=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+;W,@06ER<&]R=`!+;WIA;FD@
M06ER<&]R=`!,85]Y;W5T`$QA<FES82!!:7)P;W)T`$QA<W0@2&%L9@!,87-T
M(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO
M9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA=P!,87EO=70`
M3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,969T`$QE9G0@:&5A9&5R`$QE
M9G0@=F%L=65S`$QI;65R:6-K`$QI;6YO<R!!:7)P;W)T`$QI;FL`3&EN:R!P
M;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O
M<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI
M<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,
M:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W1I;F<@=7-E<G,@:7,@
M9&ES86)L960N`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@
M5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;B!487-K<P!,;V=I
M;B!F86EL960@9F]R('-O;64@<F5A<V]N+B!-;W-T(&QI:V5L>2!Y;W5R('5S
M97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,
M;V=I;B!F86EL960N`$QO9V]U=`!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@
M9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N
M(&YU;6)E<G,`34T`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN
M+BX`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@
M;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@
M=&AO<V4@8V%T96=O<FEE<RX`36%N=6%L`$UA<"!$871E(&%N9"!4:6UE($9I
M96QD<P!-87`@26UP;W)T($9I96QD<P!-87)C:`!-87)G:6X`36%R:R!W:71H
M(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG
M+B!);7!O<G1A;G0O06YS=V5R960I`$UA=&-H:6YG(&9I96QD<P!-87@@86QL
M;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@
M=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``
M36%X:6UU;2!L96YG=&@`36%Y`$UE971I;F<@0V%N8V5L;&%T:6]N`$UE971I
M;F<@26YF;W)M871I;VX`365E=&EN9R!0<F]P;W-A;`!-965T:6YG(%)E<&QY
M`$UE971I;F<@57!D871E`$UE971I;F<@57!D871E(%)E<75E<W0`365M8F5R
M<P!-96UO<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G
M92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T
M:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E
M9"X`365S<V%G92!T>7!E`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T
M(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL
M<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T
M:&]D`$UE=&AO9"`G)7,G(&ES(&YO="!D969I;F5D`$UE=')I8P!-:61D;&4`
M36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L
M87-T(#8@:&]U<G,Z(`!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG(%!%
M05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO
M;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O
M('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI
M<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S
M<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69I960@1&%T
M90!-;V1I9GD@55),`$UO;G1H(%9I97<`36]N=&@@86YD('EE87(`36]N=&AL
M>0!-;VYT:&QY($5V96YT<R!,:7-T`$UO;VX@4&AA<V5S`$UO=F4@1&]W;@!-
M;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P
M`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:7!L92!S96QE8W1I
M;VX`37D@06-C;W5N=`!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!->2!3
M=6UM87)Y`$UY=&EL:6YI($%I<G!O<G0`3D\L($D@1&\@3D]4($%G<F5E`$YA
M;64`3F5E9',@06-T:6]N`$YE='=O<FL`3F5V97(`3F5W($-A=&5G;W)Y`$YE
M=R!-;V]N`$YE=R!087-S=V]R9`!.97<@4&%S<W=O<F0@*&%G86EN*0!.97<@
M57-E<FYA;64@*&]P=&EO;F%L*0!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`
M3F5W<V=R;W5P<P!.97AT`$YE>'0@4&%G90!.97AT(%!H87-E`$YE>'0@;W!T
M:6]N<P!.;P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H
M;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R
M(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO
M8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD
M87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@
M8VAA;F=E+@!.;R!C:&EL9"!P97)M:7-S:6]N<R!A<F4@=&\@8F4@861D960@
M8F5L;W<@=&AI<R!L979E;"X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O
M('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($Q$05`@4')E9F5R96YC97,N`$YO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@
M0V%T96=O<FEE<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R(%-13"!0<F5F97)E;F-E<RX`3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@875T:&5N=&EC
M871I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA
M=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!I8V]N<R!F;W5N
M9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!M97-S86=E('-U<'!L:65D+@!.
M;R!N86UE('-P96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@;V9F
M96YS:79E(&9O<G1U;F5S`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<')E9F5R
M96YC97,@87)E(&%V86EL86)L92X`3F\@<G5L97,`3F\@<VED97,`3F\@=&5M
M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A=&$@
M<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN
M86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.
M;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE
M<F%T92!C;VYF:6=U<F%T:6]N+@!.;VX@4&%R=&EC:7!A;G0`3F]N90!.;VYE
M("AU<V4@:6UP;&EC:70I`$YO<G1H97)N($AE;6ES<&AE<F4`3F]T($%F=&5R
M`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`
M3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1E<R!3=6UM87)Y`$YO
M=&5S(&ES(&%N(&%P<&QI8V%T:6]N('=H:6-H(&%L;&]W<R!Y;W4@=&\@8W)E
M871E('1H92!C;VUP=71E<B!E<75I=F%L96YT(&]F('-T:6-K>2!N;W1E<RX@
M3F]T97,@8V%N(&)E(&-R96%T960L(&UO9&EF:65D+"!D96QE=&5D+"!A;F0@
M<')I;G1E9"X@66]U(&-A;B!A;'-O('-E87)C:"!O;B!Y;W5R(&YO=&5S('1O
M(&QO8V%T92!I;F9O<FUA=&EO;BX@4W5P<&]R="!F;W(@:6UP;W)T:6YG(&%N
M9"!E>'!O<G1I;F<@;F]T97,@:7,@86QS;R!A=F%I;&%B;&4N`$YO=&5S.@!.
M;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]T:6-E`$YO=&EF:6-A=&EO
M;B!L:7-T96YE<B`E<R!N;W0@9F]U;F0N`$YO=F5M8F5R`$YU;6)E<@!.=6UB
M97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@
M8V]L=6UN<R!I;B!T:&4@<W5M;6%R>2!V:65W.@!.=6UB97(@;V8@<F]W<P!.
M=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U
M=&EO;B!L:7-T+@!/8FIE8W0`3V)J96-T($-R96%T;W(`3V)J96-T(&-R96%T
M;W(@<&5R;6ES<VEO;G,`3V-T86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/
M9F9I8V4`3VQD(%!A<W-W;W)D`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@
M<VAA<F5D(&9O;&1E<G,N`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@
M;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@
M;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W
M:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F
M<F]M('-I9VYE9"!3+TU)344@<&%R="X`3W!E;G,@=&AI<R!L:6YK(&EN(&$@
M;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO;F%L(%!A<G1I8VEP
M86YT`$]P=&EO;G,`3W!T:6]N<R!F;W(`3W!T:6]N<R!F;W(@)7,`3W)D97)E
M9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N
M:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@
M=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE
M<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL
M86)L92X`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T
M80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(
M4"!#;V1E`%!(4"!3:&5L;`!07TA0(%-H96QL`%!A9&1I;F<`4&%S<W=O<F0`
M4&%S<W=O<F0@8VAA;F=E9"!F;W(@=7-E<B`E<R!F<F]M(&-L:65N="`E<P!0
M87-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E5
M4R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`
M4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A
M<W0@179E;G1S($QI<W0`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T
M:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`G)7,G(&YO
M="!D96QE=&5D+@!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)M:7-S
M:6]N<R!F;W(`4&5R<V]N86P@26YF;W)M871I;VX`4&5T<P!0:&]N90!0:&]T
M;W,`4&EX96QS`%!L871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C
M96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H
M:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U
M;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@
M82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G
M;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@
M96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@
M:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A
M<V4@<')O=FED92!A(&YE=R!P87-S=V]R9`!0;&5A<V4@<')O=FED92!A('-U
M;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@<&%S
M<W=O<F0`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M90!0;&5A<V4@<')O
M=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@<')O=FED
M92!Y;W5R('5S97)N86UE('=I=&@@0&1O;6%I;@!0;&5A<V4@<F5A9"!T:&4@
M9F]L;&]W:6YG('1E>'0N("!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M
M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E(')E=FEE=R!T:&4@9F]L;&]W
M:6YG(&EN9F]R;6%T:6]N+"!A;F0@=&AE;B!S96QE8W0@86X@86-T:6]N(&9R
M;VT@=&AE(&UE;G4@8F5L;W<N`%!L96%S92!S96QE8W0@86X@86-T:6]N(&9R
M;VT@=&AE(&UE;G4@8F5L;W<N`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O
M<GD@;F%M93H`4&QE87-E('9E<FEF>2!Y;W5R(&YE=R!P87-S=V]R9`!0;W-I
M=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B
M;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I
M`%!R96-E9&4@>6]U<B!S:6=N871U<F4@=VET:"!D87-H97,@*"<M+2`G*3\`
M4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E9G-?;&1A
M<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S
M97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`%!R97-E;G1A=&EO;G,`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L
M.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@
M;F5W('=I;F1O=P!0<F5V:6]U<R!086=E`%!R979I;W5S(&]P=&EO;G,`4')I
M;G0@9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R
M:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC
M($ME>2!!;&=O<FET:&T`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N
M97)A=&5D('-U8V-E<W-F=6QL>2X`475E<GD`4E-!(%!U8FQI8R!+97D@*"5D
M(&)I="D`4F%D:6\@<V5L96-T:6]N`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E
M860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A
M=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T
M82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N
M92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:"!$>6YA;6EC($UE
M;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9G)E<V@@4W5M
M;6%R>2!6:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O=W-E<@!296UA<FMS
M`%)E;65M8F5R('1H92!F<F5E+V)U<WD@:6YF;W)M871I;VXN`%)E;6]T92!3
M97)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R
M9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E
M(&9O<FUA='1I;F<`4F5M;W9E(&9R;VT@;7D@8V%L96YD87(`4F5M;W9E('!A
M:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R
M>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M
M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5P
M;'D@4V5N="X`4F5P;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4`4F5P
M;'D@=VET:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N`%)E<&QY('=I
M=&@@<F5Q=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`4F5P;'DZ("5S
M`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R
M8V]D93H@`%)E<75I<F5D("<E<R<@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF
M:6=U<F%T:6]N+@!297%U:7)E9"`G)7,G(&YO="!S<&5C:69I960@:6X@5D93
M(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("<E<R<@;F]T('-P96-I9FEE9"!I
M;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G8F%S961N)R!N;W0@<W!E8VEF
M:65D(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN`%)E<75I<F5D
M("=B87-E9&XG(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N9FEG
M=7)A=&EO;BX`4F5Q=6ER960@)V1A=&%B87-E)R!N;W0@<W!E8VEF:65D(&EN
M(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=D871A
M8F%S92<@;F]T('-P96-I9FEE9"!I;B!C871E9V]R:65S(&-O;F9I9W5R871I
M;VXN`%)E<75I<F5D("=D871A8F%S92<@;F]T('-P96-I9FEE9"!I;B!P<F5F
M97)E;F-E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G:&]S='-P96,G(&YO
M="!S<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BX`
M4F5Q=6ER960@)VAO<W1S<&5C)R!N;W0@<W!E8VEF:65D(&EN(&-A=&5G;W)I
M97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)VAO<W1S<&5C)R!N;W0@<W!E
M8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D
M("=P87-S=V]R9"<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C
M;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G<&%S<W=O<F0G(&YO="!S<&5C:69I
M960@:6X@8V%T96=O<FEE<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G<&%S
M<W=O<F0G(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N9FEG=7)A
M=&EO;BX`4F5Q=6ER960@)W!H<'1Y<&4G(&YO="!S<&5C:69I960@:6X@875T
M:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W!H<'1Y<&4G
M(&YO="!S<&5C:69I960@:6X@8V%T96=O<FEE<R!C;VYF:6=U<F%T:6]N+@!2
M97%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE9"!I;B!P<F5F97)E;F-E
M<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G=&%B;&4G(&YO="!S<&5C:69I
M960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@
M)W1A8FQE)R!N;W0@<W!E8VEF:65D(&EN(&-A=&5G;W)I97,@8V]N9FEG=7)A
M=&EO;BX`4F5Q=6ER960@)W1A8FQE)R!N;W0@<W!E8VEF:65D(&EN('!R969E
M<F5N8V5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=U:60G(&YO="!S<&5C
M:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER
M960@)W5I9"<@;F]T('-P96-I9FEE9"!I;B!P<F5F97)E;F-E<R!C;VYF:6=U
M<F%T:6]N+@!297%U:7)E9"`G=7-E<FYA;64G(&YO="!S<&5C:69I960@:6X@
M875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W5S97)N
M86UE)R!N;W0@<W!E8VEF:65D(&EN(&-A=&5G;W)I97,@8V]N9FEG=7)A=&EO
M;BX`4F5Q=6ER960@)W5S97)N86UE)R!N;W0@<W!E8VEF:65D(&EN('!R969E
M<F5N8V5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D($9I96QD`%)E<75I<F5D
M(%!A<G1I8VEP86YT`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@
M4&%S<W=O<F0`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2971U<FX@=&\@
M;6%I;`!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)H;V1E<R!!:7)P
M;W)T`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I
M9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P97)T:65S+BXN`%)O
M;&4`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R
M;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4R]-24U%($-R>7!T;V=R87!H
M:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U
M=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`
M4U%,(%-H96QL`%-50T-%4U,`4U]13"!3:&5L;`!380!386UE(&9R86UE("A?
M<V5L9BD`4V%M;W,@06ER<&]R=`!3871E;&QI=&4@4')O=FED97(`4V%V90!3
M879E("5S`%-A=F4@)R5S)P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@
M8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G
M<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N
M+@!3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@)R5S)RX`4V-I96YC
M90!396%R8V@`4V5A<F-H($5N9VEN97,`4V5A<F-H($UA:6P`4V5A<F-H(%)E
M<W5L=',`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O
M=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`
M4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N
M=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T('1H92!C:&%R86-T97)S('EO
M=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P
M>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT87)E82X`4V5L96-T('1H
M92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L
M96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T
M:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E
M;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S
M8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!,
M871E<W0@26YF;W)M871I;VX`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--
M4P!396YS;W(Z(`!397!T96UB97(`4V5R:6%L($YU;6)E<@!397-S:6]N($E$
M(&5X<&ER960N`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S
M970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U
M<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M
M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P86=E(')E9G)E<VAI;F<L(&%N9"!O
M=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E="!Y;W5R('!R969E<G)E9"!D:7-P
M;&%Y(&QA;F=U86=E+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I
M;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P
M;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@
M;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C
M<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I
M=&@@=&AE('!A<F%M971E<CH@`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO
M<G0@4W5M;6%R>3H`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R
M(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U
M<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U
M<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_
M`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO
M=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU
M(&]N('1H92!L969T/P!3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@
M9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@
M=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G
M92!P<F]P97)T:65S(&1I86QO9P!3:&]W('5P;&]A9`!3:')I;FL`4VAR:6YK
M(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y
M(&9I<G-T`%-I9VX@=7``4VEG;B!U<"!I9B!N;W0@<F5G:7-T97)E9`!3:6=N
M871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:7IE`%-K:7`@36%I;G1E;F%N
M8V4`4V]M92!O9B!(;W)D92=S(&-O;F9I9W5R871I;VX@9FEL97,@87)E(&UI
M<W-I;F<Z`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=61A($%I<G!O<G0`4V]U
M<F-E(&%D9')E<W,`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N
M(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R
M9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN
M9P!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L
M:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W1A<G0`4W1A<G0@>65A<@!3
M=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T
M($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA
M:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;0U-370!3=0!3=6)D:7)E8W1O
M<GD@)R5S)R!N;W0@9F]U;F0N`%-U8FIE8W0`4W5B:F5C="!0=6)L:6,@2V5Y
M($EN9F\`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`G)7,G('1O
M('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R(')E
M<75E<W0@:&%S(&)E96X@87!P<F]V960N`%-U8G-C<FEP=`!3=6-C97-S`%-U
M8V-E<W-F=6QL>2!A9&1E9"`G)7,G('1O('1H92!S>7-T96TN`%-U8V-E<W-F
M=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@)R5S)R!F<F]M('1H92!S>7-T
M96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D("<E<R<N`%-U8V-E<W-F=6QL>2!R
M96UO=F5D("<E<R<@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@<F5V
M97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3
M=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E
M<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E
M<RX`4W5C8V5S<V9U;&QY('5P9&%T960@)R5S)P!3=6-C97-S9G5L;'D@=W)O
M=&4@)7,`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;G)I<V4`4W5N<FES
M92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP
M=`!3=7!P;W)T`%-U<FYA;64`4WEN8R!L;V<@9&5L971E9`!3>6YC34P`4WEN
M=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!486)L90!486)L92!0<F]P97)T
M:65S`%1A8FQE('!R;W!E<G1I97,`5&%N86=R82!!:7)P;W)T`%1A<F=E=#H`
M5&%S:W,`5&%T;VD@06ER<&]R=`!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R
M(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&QA
M=&4@)R5S)R!N;W0@9F]U;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E
M;G1A=&EV96QY($%C8V5P="!R97%U97-T`%1E;G1A=&EV96QY($%C8V5P=&5D
M`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%N:R!Y
M;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92!&5%`@97AT96YS:6]N(&ES
M(&YO="!A=F%I;&%B;&4N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E
M;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H92!-86EN=&5N86YC93HZ
M(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@
M=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R
M(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B
M86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O
M='1O;2!S:61E(&]N;'D`5&AE(&-A;&5N9&%R(&1A=&$@:7,@:6YV86QI9`!4
M:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@
M8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C
M;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S
M(&)O;VLN`%1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E
M<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T
M<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE
M9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&1I
M<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP
M=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N
M+@!4:&4@979E;G0@:&%S(&)E96X@861D960@=&\@>6]U<B!C86QE;F1A<BX`
M5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@
M9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@
M9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@
M8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D
M97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL
M('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@
M26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W
M92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E
M<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I
M;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S
M>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U
M)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D
M('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@
M<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C
M<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T
M960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T
M:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G
M<#HZ(&-L87-S+@!4:&4@;6%I;&)O>"!T<F%S:"!I<R!A;')E861Y(&5M<'1Y
M+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B
M)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@
M=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N
M`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@
M<&%G90!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(
M;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B
M(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D
M('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@
M=&\@=FEE=R!T:&ES(&UE<W-A9V4@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@
M;VX@=&AE('-Y<W1E;2X`5&AE(')E9VES=')Y(&ES(&AO=R!(;W)D92!A<'!L
M:6-A=&EO;G,@9FEN9"!O=70@:&]W('1O('1A;&L@=&\@96%C:"!O=&AE<BX@
M66]U('-H;W5L9"!L:7-T(&%N>2!I;G-T86QL960@2&]R9&4@87!P;&EC871I
M;VYS('1H870@>6]U(&AA=F4@:&5R92X`5&AE(')I9VAT(&%N9"!L969T('-I
M9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97)V97(@
M(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E
M96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@
M<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H
M92!T87-K(&AA<R!B965N(&%D9&5D('1O('EO=7(@=&%S:VQI<W0N`%1H92!T
M96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&]P(&%N
M9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L
M;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`
M5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=7-E
M<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;B!W87,@<W5C97-S9G5L;'D@<W1O
M<F5D+@!4:&5M97,@9&ER96-T;W)Y("<E<R<@;F]T(&9O=6YD+@!4:&5R92!A
M<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T
M:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA
M;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D
M("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`
M5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@)R5S)R!T;R!T:&4@<WES=&5M
M+B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@)R5S)R!T;R!T:&4@
M<WES=&5M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@
M9F]R('5S97(@)R5S)R!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P
M<F]B;&5M(')E;6]V:6YG("<E<R<@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@
M=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`G)7,G.B`E<P!4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D
M960N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S
M:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@
M9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D
M960N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G
M92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A
M8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E
M;G0Z("5S+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L
M96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M=&%S:SH@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=7-E<B=S
M(&9R964O8G5S>2!I;F9O<FUA=&EO;CH@)7,N`%1H97)E('=A<R!A;B!E<G)O
M<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T
M(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R;W(@<&5R
M9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@
M4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P
M9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I
M8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97-S86QO
M;FEK:2!!:7)P;W)T`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R
M="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T
M960N`%1H:7,@86-T:6]N(&ES(&YO="!Y970@:6UP;&5M96YT960N`%1H:7,@
M9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H
M:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H
M:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H
M('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W
M87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z
M+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--
M5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T
M;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O
M=6YT('=I=&@@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`
M5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C
M;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O
M;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM
M82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I
M96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C
M;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O
M<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F:6QE(&-O;G1R;VQS('1H92!G
M;&]B86P@<V5T(&]F($U)344@9')I=F5R<R!F;W(@=&AE($AO<F1E(&9R86UE
M=V]R:RP@86QL;W=I;F<@87!P;&EC871I;VYS('1O(&UA:V4@=7-E(&]F('!R
M;V=R86US('-U8V@@87,@96YS8W)I<'0@;W(@;7-W;W)D=FEE=R!T;R!R96YD
M97(@8V]N=&5N="!I;G1O($A434P@9F]R('9I97=I;F<@:6X@82!B<F]W<V5R
M+@!4:&ES(&9I;&4@8V]N=')O;',@=&AE('-T>6QE<VAE970@=&AA="!I<R!U
M<V5D('1O('-E="!C;VQO<G,@86YD(&9O;G1S(&9O<B!T:&4@2&]R9&4@9G)A
M;65W;W)K(&%N9"!A;&P@87!P;&EC871I;VYS('1H870@9&\@;F]T('!R;W9I
M9&4@=&AE:7(@;W=N('-E='1I;F=S+@!4:&ES(&9I;&4@;6%P<R!F:6QE(&5X
M=&5N<VEO;G,@=&\@;&]G:6-A;"!-24U%('1Y<&5S+"!E;F%B;&EN9R!(;W)D
M92!A<'!L:6-A=&EO;G,@=&\@9FEG=7)E(&]U="!H;W<@=&\@:&%N9&QE('-O
M;64@8V]N=&5N="!S=6-H(&%S(&5M86EL(&%T=&%C:&UE;G1S(&]R($-64R!C
M:&5C:V]U=',N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E
M9"X`5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE
M8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I
M;"!C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E
M(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE
M87-E('9I<VET("5S`%1H:7,@:7,@=&AE(&UA:6X@2&]R9&4@8V]N9FEG=7)A
M=&EO;B!F:6QE+B!)="!C;VYT86EN<R!P871H<R!A;F0@8F%S:6,@:71E;7,@
M=&AA="!A<'!L>2!T;R!T:&4@8V]R92!F<F%M97=O<FL@86YD(&%L;"!(;W)D
M92!A<'!L:6-A=&EO;G,N`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A
M(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES
M(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!P<F]B;&5M(')E
M<&]R="!W87,@<F5C96EV960@9G)O;2`E<RX@5&AE('5S97(@8VQI8VME9"!T
M:&4@<')O8FQE;2!R97!O<G0@;&EN:R!F<F]M('1H92!F;VQL;W=I;F<@;&]C
M871I;VXZ)7,@86YD(&ES('5S:6YG('1H92!F;VQL;W=I;F<@8G)O=W-E<CHE
M<P!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F
M:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4
M:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1I8VME=',`5&EM90!4:6UE
M(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I=&QE`%1I
M=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H
M;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME
M>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O
M;6]R<F]W`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEP
M;VQI<R!!:7)P;W)T`%1R=64@;W(@9F%L<V4`5'4`5'EP92!M:7-M871C:"X`
M5'EP92!Y;W5R(&-H;VEC93H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E
M;&EV97)Y('-T871U<R!R97!O<G0`55),.@!5;F%B;&4@=&\@86-C97-S(%9&
M4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA
M=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES
M<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M
M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T
M;R`E<RX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE
M('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE
M('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@9&5L971E("(E<R(L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E
M("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L
M971E("<E<R<Z("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@
M<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O
M(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N
M86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T
M;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO860@
M=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93(&9I
M;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE
M('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5G
M:7-T97(@<')E9F5R96YC97,@:6X@<V5S<VEO;BX`56YA8FQE('1O(')E;F%M
M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S
M`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E
M;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES
M;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET
M92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!6
M1E,@9FEL92!D871A+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@96YD(&]F(&9I;&4N`%5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N
M97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N
M:&%N9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,`56YI=',`56YK;F]W;@!5
M;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI
M;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W;B!U<V5R;F%M92!O
M<B!P87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE
M9`!5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y
M+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@
M($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N
M;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@
M86-C97-S('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D
M($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!R97-P;VYD96YT
M('-T871U<P!5<&1A=&4@=7-E<@!5<&1A=&5D("<E<R<N`%5P9W)A9&4@<V-R
M:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@
M<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R
M<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5S92!#=7)R96YT.B`E<P!5<V4@1&5F
M875L="!686QU90!5<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I
M9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S97(@)7,@:7,@;F]T(&%U=&AO
M<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N
M<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E
M;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R('!A<W-W;W)D(&-H86YG
M90!5<V5R('!E<FUI<W-I;VYS`%5S97)N86UE`%5S97)N86UE("<E<R<@86QR
M96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S`%5S97)S
M(&EN('1H92!S>7-T96TZ`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N
M`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L
M:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=65S`%9A;'5E
M<R!T;R!S96QE8W0@9G)O;0!687)I86)L90!697)I9FEC871I;VX@9F%I;&5D
M("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`
M5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC
M86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I97<@)7,`5FEE=R!A
M;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I97<@979E;G0`5FEE
M=R!T87-K`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY
M('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!
M3$Q9($923TT@)7,N`%=A<FYI;F<`5V4`5V5E:VQY`%=E;&-O;64`5V5L8V]M
M92!T;R`E<P!796QC;VUE+"`E<P!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E
M<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&%P<&QI8V%T:6]N('-H;W5L
M9"!(;W)D92!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI
M;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_
M`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE
M(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7
M:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T
M(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N
M:70`5VED=&@Z`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I
M<V1O;0!7:7-H;&ES=',`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!8
M+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D
M($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U
M,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS
M`%E9`%E965D`665A<FQY`%EE<P!997,L($D@06=R964`66]U(&%R92!I;B!4
M15A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K
M('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C
M86X@;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA
M;64N`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`
M66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F
M:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA
M=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N
M/&)R("\^5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!9;W4@:&%V
M92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@
M82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@;75S="!C
M;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I8F4@=&AE
M('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O
M<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O
M:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T
M960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N
M`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M
M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!S<&5C:69Y
M('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@
M8V%T96=O<GD@;F%M92X`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0
M;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($5M
M86EL($%D9')E<W,Z`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA
M=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@
M=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@
M>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M
M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R
M="!A9&1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B
M;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!A=71H96YT:6-A=&EO
M;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@
M=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@
M<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@
M<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R
M;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO
M=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U
M<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN
M(%!R97-S($-O;G1R;VPO3W!T:6]N("L@4"!T;R!P<FEN="X`66]U<B!C=7)R
M96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U
M;&P@;F%M93H`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R
M(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O
M9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E
M9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D
M(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@
M=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!P87-S=V]R9',@9&\@;F]T
M(&UA=&-H`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%M(:61E(%%U;W1E9"!497AT
M70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@
M475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&UI
M;FES=')A=&EO;@!?1&5L971E(%)O=P!?1W)O=7!S`%](96QP`%]);6%G92!0
M<F]P97)T:65S+BXN`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN
M`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P
M`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`8V%L
M96YD87(`8V%L;0!C;&EC:R!H97)E`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A
M="`E<R`E<P!H.@!I;6UE9&EA=&4`:6YL:6YE`&QI;F5S70!M:VES;V9S(&5R
M<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;F%M90!N;W0@:6UP;&5M
M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`'!E<F-E;G0`<&EX
M96QS`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-T96%D
M>0!T87-K(&QI<W0`=')A<V@`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@
M8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`4')O
M:F5C="U)9"U697)S:6]N.B!(;W)D93H@,RXP+6-V<PI297!O<G0M37-G:60M
M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T
M93H@,C`P,BTQ,2TP-R`Q,CHP-BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P
M,#4M,#0M,C8@,3$Z,3,K,#(P,`I,87-T+51R86YS;&%T;W(Z($MO;G-T86YT
M:6YO<R!#+B!-:6QO<VES(#QK;6EL;W-I<T!Y86AO;RYC;VT^"DQA;F=U86=E
M+51E86TZ($=R965K(#QD979`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I
M;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O
M+3@X-3DM-PI#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=`H`("#'
M(./QX>SLX?3OZ/7QW^3A("?JW.3O\B<@Y=_MX>D@WN3G(-SDY>GA+@`@)B,Q
M-3$[("5S(,7?[>'I(.<@\_3IX^S>(.WA(./?[>_U[2#OZ2#KY>GT[_7QX]_E
M\B#S]>WTWO'G\^?R(/#O]2#EW^WAZ2#E\.GKY>/LW>WE\B#PX?'AZMST^2X`
M("CP\>GM(.'P_"`E<R#G[-WQY?(I`"`HRNOEZ>3?(/#Q_//BX?/G\B`E<RD`
M("CSY2`E<R#G[-WQY?(I`"`H\][LY?'A*0`@*.']\>GO*0`@*/?HY?(I`"#S
M].GR(``E9"`E<R#JX>D@)7,`)60M[.7QYR#P\?SBZ^7XYP`E<R`M(-/G[.7?
M^?/G`"5S+<3IX??EW_'I\^<`)7,@Q.'J]/7KZ>K\(.'P[_3]\/GLX0`E<R#+
MY>GT[_7QX]_E\B#3]>WTWO'G\^?R("T@Q?#IXN7BX=_Y\^<`)7,MT.'QX>SE
M]/'O\._?Y_/G`"5S(,7CX_'A]MX`)7,@S_'OZ2#W\=[SY_(`)7,@WN3G(/7P
MW/'WY>DN`"5S(//E("5S("5S`"5S(.'J]?'^Z.?JY2`E<RX`)7,@X?#<[?3G
M\^4@\^4@Y?'^].?LX2#DZ>'HY?/I[/STY_3A\BX`)7,@X?#<[?3G\^4@\_3G
M[2#P\?SSZNOG\^<@X^GA("5S+@`E<R#SX?(@W?/TY>GKY2#PZ^?Q[_;O\=_E
M\B#DZ>'HY?/I[/STY_3A\BX`)7,@Y=_MX>D@X?#AZ?3O_>SE[>\`)7,@Z^7P
M]-P`)7,@\^'R(.;>].?SY2#PZ^?Q[_;O\=_E\B#DZ>'HY?/I[/STY_3A\BX`
M)7,@YM[TY_/E(/3G[2#PX?'O]?/?X2#SX?(@\_3I\B`E<RX`)7,@^?(@)7,@
MX?#\("5S`"5S(.7PZ>CU[.7?(/3G[2#P\>_SZ-[JYR#S].\@)7,N`"5S(.7P
MZ>CU[.7?(.WA(//A\B#E[>?LY?'^\^7I(./IX2`E<RX`)7,@Y?#IZ/7LY=\@
M[>$@Z]SBY>D@].GR(/3EZ^7U].'?Y?(@\.OG\>_V[_'?Y?(@X^GA("5S+@`E
M<R=S(,3IY?7H]>WSZ>_C\=SV[_(`)7,G<R#'[.7Q[^O\X^GO`"5S<R#3Y^SE
MZ?GLX?3<\>GO`"5S<R#+W_/TX2#%\>/A\^G^[0`G)7,G(.3E[2#EW^WAZ2#=
MX^KU\><@Y?#IZ^_CWBX`)R5S)R#DY>T@W??EZ2#Q]>CLZ?/TY=\@\_3O(')E
M9VES=')Y(/3G\B#E]N'Q[._CWO(@2&]R9&4`)7,@X>WA\.'QX?/TW/3G\B#D
MY>WD\>GJWO(@Y._LWO(@Y.7M(.+QW>CGZN4N`"<E<R<@\/'O\_3=Z.?JY2#S
M].GR(._LW.3E\B#S]?/TWNSA]._R+@`G)7,G(/#Q[_/TW>CGZN4@\_3I\B#<
MY.7IY?(@]._U(//U\_3>[.'T[_(N`"<E<R<@Y.7M(.3G[.GO]?'CWNCGZN4Z
M("5S+@`L(&=U<W1I;F<@)7,@)7,`+"#LY?3AXNOG]-X@X?#\("5S(//E("5S
M`"TM(.7PZ>OOX]X@+2T`,3+Y\><@[._Q]MX`,C3Y\><@[._Q]MX`,C0@_O'E
M\@`\8C[0X?'O]?/IW//TY^KE(-WMX2#S[^+A\?P@Z]SH[_(Z/"]B/@#0X?'O
M]?/IW//HY^KE(.KQW_/I[.\@Z]SH[_(`P?#AZ?3EW_3AZ2#DY^S\\^GO(.KK
MY>GDWR!01U`@X^GA(/3G[2#J\?7P]._C\=SVY_/G(.7M_/(@[.?M_>SA]._R
M+@#!\.'I].7?].'I(.3G[/SSZ>\@ZNOEZ>3?(%!'4"#CZ>$@Y?#IXN7BX=_Y
M\^<@Y>W\\B#U\._CY>/QX>SLW>WO]2#LY^W][.'T[_(N`,'PX>GTY=_TX>D@
MY.?L_//I[RP@\/'O\_GPZ>K\(%!'4"#JZ^7IY-\@ZN'I(.O=[N<MZOGDZ>K\
M\B#CZ>$@[>$@X?#OZO'U\/3OX_'A]M[SY?3E(-WMX2#LWNWU[.$N`,'PX>GT
MY=_TX>D@Y.?L_//I[RP@\/'O\_GPZ>K\(%!'4"#JZ^7IY-\@ZN'I(.O=[N<M
MZOGDZ>K\\B#CZ>$@[>$@]?#OX_'<^.7TY2#XY_;IX>K<(-WMX2#LWNWU[.$N
M`,'PX>GTY=_TX>D@Y.?L_//I[RP@\/'O\_GPZ>K\(%,O34E-12#JZ^7IY-\@
MZN'I(.O=[N<MZOGDZ>K\\B#CZ>$@[>$@X?#OZO'U\/3OX_'A]M[SY?3E(-WM
MX2#LWNWU[.$N`,'PX>GTY=_TX>D@Y.?L_//I[RP@\/'O\_GPZ>K\(%,O34E-
M12#JZ^7IY-\@ZN'I(.O=[N<MZOGDZ>K\\B#CZ>$@[>$@]?#OX_'<^.7TY2#X
MY_;IX>K<(-WMX2#LWNWU[.$N`,'PX>GTY=_TX>D@Y.?L_//I[R#JZ^7IY-\@
M4R]-24U%(./IX2#TY^T@ZO'U\/3OX_'<]N?SYR#E[?SR(.SG[?WLX?3O\BX`
M\.PO[.P`T.7QWR#A]?3O_2#T[_4@RN7I[.7M[^/QW/;O]0#0Y?'?+BXN`,'P
M_.OU].\@]-WK[_(`P?#\Z_7TYR#,W?/G`,'P[^3O]]X@X>GTWNSA]._R`,7C
MZ>WE(.'P[^3EZO3\`,<@\/'\\^+A\^<@X?#O\?'?]NCGZN4@ZN'TW"#TYR#D
MY^SI[_7QX]_A(%9&4R#JX?3AZ_SC[_4N`,<@\/'\\^+A\^<@X?#O\?'?]NCG
MZN4@ZN'TW"#TYR#DY^SI[_7QX]_A(%9&4R#A\??EW^_U+@#*^>3IZOSR(,OO
MX^'QZ>'S[._]`,\@Z^_CX?'IX?/L_/(@\-SC^?/E+@#*X?3AX_'A]MX`Q>W=
M\>/EZ>7R`-#Q[_/HWNKG`-#Q[_/HWNKG(/7P[^_LW.3A\@#0\>_SZ-[JYR#<
MY.7IX?(@]?#O[^S<Y.'R("AC:&EL9"!P97)M:7-S:6]N*0#0\>_SZ-[JYR#E
MY/XZ`-#Q[_/HWNKG(,W=X?(@S^S<Y.'R`-#Q[_/HWNKG(.W=X?(@W.3EZ>'R
M`-#Q[_/HWNKG(/7P[^_LW.3A\B#S].\@)R5S)P#0\>_SZ-[JYR#<Y.7IX?(@
M*'!E<FUI<W-I;VXI(/7P[^_LW.3A\B#S].\@)R5S)P#0\>_SZ-[JYR#MW>_U
M(/?QWO/TYSH`T/'O\^C>ZN<@\_3>Z^?R`-#Q[_/HWNKG(.W=[_4@[-WK[_7R
M`-#Q[_/HWNKG(.;E_>/O]?(`T/'O\^C>ZN<@]._U("5S(//T[R#LY>WO_2#T
M[_4@36]Z:6QL80#0\>_SZ-[JYR#A]?3O_2#S].\@Y^SE\>_K_./I_"#L[_4`
MT/'O\^C>ZN<@\_3O(,3IY?7H]>WSZ>_C\=SV[SH`T/'O\^C>ZN<@\_3O(,3I
MY?7H]>WSZ>_C\=SV[R#L[_4`T/'O\^C>ZN<@]_'>\_3G`-#Q[_/TW>CGZN4@
M)R5S)R#S].\@\_WS].?LX2P@X>OKW"#DY>T@[/#\\>7SX2#MX2#P\>_SZ-WS
M^2#S]>SPZ^?Q^>SA].GJW?(@\.OG\>_V[_'?Y?(`T/'O\_3=Z.?JY2`G)7,G
M(//T[R#S_?/TY^SA+B#,\._QY=_TY2#MX2#S]>WDY>CEW_3E(/3^\>$N`,<@
M\/'O\^C>ZN<@]_'G\_3^[2#=]^7I(.'PY>WE\>/O\._IY^CEWRX`Q.GE_>CU
M[?/G`,3IY?7H]>WSZ>_C\=SV[_(`Q.GA]^7?\>GSYR`M(,3^\_3E(.3IZN'I
M_NSA].$@\^4@W.OK[_7R(/?QWO/TY?(`Q.GA]^7?\>GSYP#!Y?'OZ^GLW>WA
M\B#!ZO3?[_4`P>7Q[^OI[-[M(,'KY>[A[>3Q[_WP[^OG\@#8Y?7D_NWU[.\`
MQ?7H]>/QW.SLZ?/E`,7UZ/7C\=SL[.GSYSH`S^OA`,_K[^D@[^D@W>/J]?'O
MZ2#W\=[S].7R`,_KY?(@[^D@S^S<Y.7R`,_KX2#TX2#DZ>KAZ?[LX?3A`,KA
MZ2#OZ2#TW?/SY?'I\B`H-"D@\.OE]?'=\@#-X2#E\.GT\=WP[^WTX>D@\._K
MZ^'PZ]WR(.3IY?7H_>WSY>GR`,WA(.7PZ?3QW?#O[?3AZ2#Q]>CLW_/EZ?(@
M].'NZ>WO[.GLW>WY[2#KZ?/T_NT[`,?DYR#U\-SQ]^7I`,7MX>OKX>KTZ>K>
M($E-4U`@Q=_S[^3O\@#%[>'KZ^'J].GJ_/(@24U34"#*^>3IZOSR`,7MX>OK
MX>KTZ>K\($E-4U`@O.WO[.$@U_'>\_3G`,7MX>OKX>KTZ>K>(.3IY?WH]>WS
MYR!E;6%I;`#%[>'KZ^'J].GJW"#P\?ST]?#A`,7MX>OKX>KTZ>K\(.KEW^SE
M[>\Z`,_QW_/TY^KE(.S?X2#LYR#E\.GT\>7P_.SE[><@].GLWBX`P>7Q[^OI
M[-WMX?(@P>/WW^'K[_4N`,'E\>_KZ>S=[>'R(,'MY/'AXM_DX?(N`,'M_NWU
M[._R(,3IX>SLY?/OZ^'BY_3>\B`H4')O>'DI`,'PW.WTY_/G`,7VX?'L[^/>
M`,O?\_3A(,7VX?'L[^/>\@#'(.7VX?'L[^/>(.7?[>'I(-WT[^GLYRX`Q?;A
M\>SOX]X@ZN'I(//TX2#E[N'Q]/[LY>WA(.KOZ>W\]_'G\_3A`,7CZO'?[?D`
MP?#QW^OI[_(`P>7Q[^OI[-WMX?(@P?'<[N_U`,S=X^7H[_(@X?'WY=_O]2#A
M\??EZ>_HW?3G\^?R`,_M[^SA(.'Q]^7?[_4@X?'WY>GHW?3G\^?R`,7?\_3E
M(//?X^_U\><@X^GA(/3G(.3IX>/QX?;>(/3G\B#AW_3G\^?R(/7P[^/QX?;>
M\B#CZ>$@)7,@/P#%W_/TY2#SW^/O]?'OZ2#\].D@Z-WKY?3E(.WA(.3IX>/Q
MW/CE].4@)R5S)R#JX>D@_.OE\B#TZ?(@]?#O[^S<Y.7R/P#4W??MYP!!4T-)
M22#4W??MYP#-X2#FY_3EW_3E(.7PZ>+EXN'?^?/G(/#QW^T@X?#\(.K<Z.4@
MY>W=\>/EZ>$@Y.GA]^7?\>GSY_([`,'MW.CE\^<@\_3GZ_[M`,'E\>_KZ>S=
M[>'R(,'HY^W^[0#4[R#S]>WG[.S=[>\@Y=_MX>D@W>WA(.'Q]^7?[R#G[.7Q
M[^OOX]_O]2#SY2#A\-SM].?SYR#AZ?3>[.'T_/(@\^'R`-#Q[_/PW.CEZ>$@
MY.GAX_'A]M[R(.SG(/7PX?'J]-[R(._LW.3A\BX`T/'O\_#<Z.7IX2#DZ>'C
M\>'VWO(@[.<@]?#A\>KT[_T@Y.GJX>G^[.'T[_(N`-#Q[_/PW.CEZ>$@Y?#E
M[N7QX^'SW^'R(.SG(/7PX?'J]._](.3IZN'I_NSA]._R+@#0\>_S\-SHY>GA
M(.7PY>[E\>/A\]_A\B#LYR#U\.'QZO3O_2#DZ>'L[^GQX?/LW>WO]2X`T.'Q
MY?7QZ?/J_.SE[>_I`,GDZ?STY_3E\@#!_>/O]?/T[_(`QR#A]>CE[?3IZN_P
M[]_G\^<@X?#=]/7WY0#'(.'UZ.7M].GJ[_#OW^?SYR#A\-WT]??E+B`E<P#'
M(.'UZ.7M].GJ[_#OW^?SYR#A\._Q\=_VZ.?JY2#A\/P@]._M(%)!1$E54R!S
M97)V97(N`,<@X?7HY>WTZ>KO\._?Y_/G(//T[^T@1E10+5-E<G9E<B#A\-WT
M]??E+@#$Z>'HW?/I[.$@T.7DW^$Z`,'MX>S=[>_M].'R(.'PW.WTY_/G`-7P
M_.+AZ/'O`-?Q_NSA(/7P_.+AZ/'O]0#+W.CO\B!+97)B97)O<RWJ^>3IZOSR
M+@#+W.CO\B!+97)B97)O<RV\[>_LX2#7\=[S].<N`,'DY>GO`,\@ZOWQZ>_R
M(.KA]-SK[^/O\B#C\>'VZ>K^[2`G)7,G(.3E[2#B\=WHY^KE+@#"X?/IZMX@
MX_'A[.S>`,/E[=WHZ^GA`-3O(/3LWNSA("(E<R(@].?R(.7VX?'L[^/>\B`B
M)7,B(.3E[2#B\=WHY^KE+@#1]>CLW_/EZ?(@].S>[.'T[_(`U/WP[_(@].S>
M[.'T[_(`N.WT[^WA`+SQZ>$`RN'I(/3A(.3][P#*X?3^].'T[P#+W_/TX2#L
MY2#TY>OEW^7R`-/G[.7?X2#DZ>'M[^S>\B!#4DP`P?'WY=_O(.KEZ>S=[>_U
M(/?Y\>GS[-WM[R#LY2#J_.SLX2`H0U93*0#)Y.G\].?TY?(@RN7KZ?[M+BXN
M`,?LY?'OZ_SCZ>\`T.7QW^OG^.<@Q^SE\>_K_./I[_4`Q^SE\>_K_./I[SH`
MQ_'E[-_A`,'D_>WA].<@YR#A\??IZN_P[]_G\^<@]._U(.KYY.GJ[_T@X?7T
M_.SA].$L(.7PZ>KOZ>WY[=[S].4@[.4@].\@Y.GA]^7I\>GS]-X`P>3][>'T
MYR#G(//][>3E\^<@[.4@]._M($E-05`M4V5R=F5R.B`E<P#!ZOWQ^?/G`,'J
M_?'Y\^<@P>WA]N_QW/(@T/'OXNO>[.'T[_(`P>3][>'TYR#G(.3IX>/QX?;>
M(/3O]2#A\??EW^_U("(E<R(N`,3E(.+QW_/J^2#P\>_S^?'I[?P@]MSJY>OO
M("AT96UP(&1I<BDN`,'D_>WA].<@YR#S]>W=]^7IX2#W^?'?\B#TY^T@\.'Q
MW.SE]/'O(")T87)G971&:6QE(BX`P>3][>'TYR#G(.3IX>/QX?;>(/3O]2#V
MX>K=Z^_U("(E<R(N`,'D_>WA].<@YR#DZ>'C\>'VWBP@)60@]?#VW.KEZ^_R
M(/7PW/'WY>DN`,'D_>WA].<@YR#E\.'MX?3A[NGM_.SG\^<L(.\@X?'IZ.S\
M\B#T^>T@Y>/C\>'V_NT@\._U(.3^\^'TY2#CZ>$@Y?#A[>'TX>[I[?SLY_/G
M+"#DY>T@].'I\>G<YN7I(.SE(/3O[2#A\>GH[/P@]/GM(.'P[^CGZN7U[-WM
M^>TN`,3E(.SP[_'^(.WA(.3Q[^SOZ^_CWO/Y(.S>[?7LX2#S]._M(.'QZ>CL
M_"#P[_4@[_'?\^'TY2X`Q?#IZN7VX>O?Y.$`RN'TY^/O\=_E\B#JX>D@Q?3I
MZMWTY?(`RNGMY_3\(-3GZ]WV^>WO`,GDZ?STY_3E\B#*Y>OI[_T`P]WLZ?/L
MX2#*Y>OI[_TZ`,GDZ?STY_3E\B#*Y>OI[_T`Q.G<ZN7M[R#*Y>OI_NTZ`,KI
M[>?T_"#4Y^O=]OGM[P#*W>WT\>\`R^7P]._LW?'EZ>7R(-#I\_3O\._IY_3I
MZN_]`-#OZ^GTZ>K>(-#I\_3O\._IY_3IZN_]`-#Q_.7D\>_R`,'KZ^'CW@#!
MZ^OAX]X@ZOGDZ>KO_0#!Z^O<[O3E(/3O(/SM[^SA(.KAZ2#TYR#DZ>7]Z/7M
M\^<@\._U(.CA(.+KW?#O]>T@_/3A[2#DZ>'BW.;O]>T@WB#A\.'M]._][2#S
MY2#LY^W][.'TW"#SX?(`U^'QX>KTWO'A\@"XZ^7C]^_R(//][>3E\^?R+BXN
M`-/G[.7I_O/TY2#T[R#TY?3QX>/Y[=_DZ>\@X^GA(._P[^GAY-[P[_3E(.7Q
MX^'SW^$HY?(I(.C=Z^7TY2#MX2#EZO3EZ^7S]._][2#A]?3>(/3G(//TZ>/L
MWBX`P>7Q[^OI[-WMX?(@U]_O]0#%\.GKW>[TY2#%]N'Q[._CWCH`Q?#IZ]WN
M].4@ZOGDZ>K\`,7PZ>O=[O3E(/SM[^SA(/?QWO/TYP#%\.GKW>[TY2#LZ>$@
MY>W=\>/EZ>$Z`,7PZ>O=[O3E(/#Y\B#HX2#E[/;A[=_F[^WTX>D@[^D@Y^SE
M\>_LY^W?Y?(Z`,7PZ>O=[O3E(/3]\.\@Z]_S].'R("CCZ>$@].'NZ>WO[.?L
MW>WE\B#KW_/TY?(I`,'E\>_KZ>S=[>'R(-?Q]?/O_?#OZ^?R`,3E[2#B\=WH
MY^KE(._QZ?/L_/(@ZNO<\^?R(/3O]2`E<RX`RN'HW/'I\^4`RN'HX?'I\^S\
M\B#E].GJY?3^[2`H=&%G<RD@35,M3V9F:6-E`"?!Y.7IX?/LX2<@U_'>\_3G
M.B`E<P#*X>CA\>GS[/SR(-?QWO/TYP#*X>CA\>GS[/SR(.3EY._LW>WY[2#W
M\=[S].<`RMSM].4@ZNOIZB#CZ>$@\_7MW??EZ>$`RNOEW_/I[.\@PN_>Z.7I
MX?(`RNOEW_/I[.\@T.'QW.CU\>_U(,+OWNCEZ>'R`,KKY=_SZ>SO(-#A\=SH
M]?'O]0#![>'DW_#K^?/G(-#KY?7QZ>K>\B#,\-SQX?(`P>WAY.GPZ_GLW>WA
M(-#E\>GH_O'IX0#7\?[LX0#%\.GKW>KTY_(@U_'^[.'T[_(`Q?#IZ^_CWB#7
M\?[LX?3O\@#3]-[KY?(Z`-3?].OOZ2#3].?K_NT`0V]M:6-S`,7M]._KW@#*
MW>OU]N_R(,7M]._K_NT`T_?\Z^GO`,KOZ>W\(+SM[^SA`,7TX>GQY=_A`,_K
M[^KKY_'^Z.?JY0#3_>WHY?/G(,SG[?WLX?3O\B`H)7,I`-7P[^OOX^GS]-WR
M`-/U[>C>ZN7R`,3IX?;O\=WR(-#A\>'LY?3Q[_#OW^?SY_(`Q?#IZ^_CW?(@
MX^GA(//UX_?Q[^WI\^S\(.SE(%!$07,L(-WN]?#MX2#4Y^O=]OGMX2#JX>D@
M3W5T;&]O:RX`1&EE($MO;F9I9W5R871I;VX@;75S<R!A:W1U86QI<VEE<G0@
M=V5R9&5N+@#'(/#A\>'LY?3Q[_#OW^?SYR#W\>7IW.;E].'I(.7MY^S=\?GS
MYRX`T.'QX>SE]/'O\._?Y_/G("5S`,7PZ>+EXN'?^?/G(,KYY.GJ[_T`QR#S
M_>WDY?/G(.'PW?3U]^4N`,<@\_WMY.7SYR#A\-WT]??E.B``P?'MY_/G(//]
M[>3E\^?R(.'P_"#T[R#DY^S\\^GO(.7N]?#G\>7TY_3>(.KKY>GDZ?[M+@#!
M\>WG\^<@\_WMY.7SY_(@X?#\(/3O(.3G[/SSZ>\@Y>[U\.?QY?3G]-X@ZNOE
MZ>3I_NTN(,O\X^_R(#H@)7,@*"5S*0#'(//][>3E\^<@[.4@].\@1E10+5-E
M<G9E<B#A\-WT]??E+@#![>'FWO3G\^<@Q?#A]M[R`,_I(.7PX?;=\B#P\>_S
M]-WHY^KA[2#E\.GT]??^\B#S].\@Q.GE]>CU[?/I[^/QW/;O(//A\BX`T.7Q
MZ>7W_.SE[>$@]._U("<E<R<`T.7QZ>7W_.SE[>$@]/GM(.'Q]^7?^>T@4D%2
M`-/U[=WWY>GA`,'M].GC\>'VW@#![?3IX_'A]MX@Q?#IZ^_CWO(`P>3][>'T
MYR#G(.KQ]?#T[^/QW/;G\^<@]._U(.SG[?WLX?3O\B#LY2!01U`N`,'D_>WA
M].<@YR#U\._C\>'VWB#T[_4@[.?M_>SA]._R(.SE(%!'4"X`P>3][>'TYR#G
M(.KQ]?#T[^/QW/;G\^<@]._U(.SG[?WLX?3O\B#LY2!3+TU)344N`,'D_>WA
M].<@YR#U\._C\>'VWB#T[_4@[.?M_>SA]._R(.SE(%,O34E-12X`Q.7M(.SP
M_/'E\^$@[>$@\/'O\^C=\_D@].?M(.7PX?;>+B`E<P#!Y/WMX?3G(.<@\_WM
MY.7SYR#LY2#T[R!,1$%0+5-E<G9E<BX`P>3][>'T[_(@[R#=Z^7C[_(@]?#O
MZ^_?\._U+B`E<P#!Y/WMX?3G(.<@\_WMY.7SYR#S]._M(.7N]?#G\>7TY_3>
M("<E<R<@]_'G\^GL\._I_NWTX?(@1E10.B`E<P#!Y/WMX?3G(.<@Y.?LZ>_U
M\>/?X2#KW_/TX?,@Y.GA[>_LWO(N("5S`,'D_>WA].<@YR#A\._J\?7P]._C
M\=SVY_/G(%!'4"#DY>3O[-WM^>TN`,'D_>WA].<@YR#A\._J\?7P]._C\=SV
MY_/G(%,O34E-12#DY>3O[-WM^>TN`,'D_>WA].<@YR#DZ>'C\>'VWB#E\.'V
MWO(N("5S`,'D_>WA].<@YR#DZ>'C\>'VWB#KW_/TX?(@Y.GA[>_LWO(N("5S
M`,'D_>WA].<@YR#DZ>'C\>'VWB!S971U<"!U<&=R861E('-C<FEP="`G)7,G
M("X`Q.4@[/#O\?X@[>$@Y.GE]>KQZ>W>\_D@].<@Y.GE_>CU[?/G(/3O]2#P
MX?'AZ][P].<N`,'D_>WA].<@YR#PZ][QY_(@\/'\\^+A\^<@]._U(,3IY?7H
M]>WSZ>_C\=SV[_4N`,'D_>WA].<@YR#PZ][QY_(@\/'\\^+A\^<@].?R(.O?
M\_3A\B#DZ>'M[^S>\BX`P>3][>'TYR#G(/#KWO'G\B#P\?SSXN'SYR#KW_/T
MX?(@X?#\(.O?\_3E\B#DZ>'M[^S>\BX`P>3][>'T[R#T[R#V_/'T^>SA(//T
M\>'TY^/IZM[R("(E<R(N`,'D_>WA].<@YR#DY^SI[_7QX]_A(/;AZMWK[_4@
M(B5S(BX`P>3][>'TYR#G(.'MW.KTY_/G(.3G[/SSZ>_U(.KKY>GDZ>_](.'P
M_"#T[^T@Y>[U\.?QY?3G]-X@Q.?L+LKKY>GDZ?[M+@#!Y/WMX?3O(/3O(-SM
M[^GC[.$@)7,N`,'D_>WA].\@].\@W.WOZ>/LX2`B)7,B(./IX2#EX^/QX?;>
M+@#!Y/WMX?3O(/3O(-SM[^GC[.$@]._U(.S=\>_U\B#$Z>'WY=_QZ?/G\B`E
M<P#$Y>T@[/#O\?X@[>$@X>WOW^[Y(/3O(/;<ZN7K[R`B)7,B+@#$Y>T@[/#O
M\?X@[>$@Y.GAXMSS^2`E<RX`P>3][>'TYR#G(.'Q]^GJ[_#OW^?SYR#T[_4@
MZOGDZ>KO_2#CZ>$@]._M(.'I]._][.7M[R#W\=[S].<N(,K<\._IX2#>(/SK
MY?(@[^D@Z^7P]._LW?'EZ>7R(.3E[2#EW^WAZ2#S^?/TW?(N(,[A[>'D[^KI
M[-SS].4@WB#E\.GJ[^GM^>W>\_3E(.SE(/3O(.3IX??EZ2WQZ?/TWB#A[2#W
M\>7IW//E\^CE(/#E\>GS\_STY?'G(.+OWNCEZ>$N`,'D_>WA].<@YR#A[=SJ
M].?SYR#+W_/TX?(@RN'M_.WY[2#0\?SSXN'SY_(@*$%#3"D`P>3][>'TYR#G
M(.'MW.KTY_/G(,3IY?7H]>WSZ>_C\=SV[_4N("5S`,'D_>WA].<@YR#A[=SJ
M].?SYR#+W_/TX?(@Q.GA[>_LWO(N("5S`,'D_>WA].<@YR#A[=SJ].?SYR#+
MZ?/T_NT@Q.GA[>_LWO(N("5S`,'D_>WA].<@YR#A[=SJ].?SYR#T^>T@Z>3I
M[_3>]/GM(/3O]2#E[O7PY_'E].?TW@#!Y/WMX?3G(.<@Y?#A[>'V[_'<(/'U
MZ.S?\^7Y[2X`P>3][>'TYR#G(.3IX>/QX?;>(/;AZMWK[_4@*')M9&ER*2`B
M)7,B+@#$Y2#L\._Q_B#MX2#A\._HY^KE_?/Y("5S(/'UZ.S?\^7I\BX`Q.4@
M[/#O\?X@[>$@ZMSM^2#E]N7D\>GJ_"#A[?3?X_'A]N\@]/GM(/'UZ.S?\^7Y
M[2X`Q.4@[/#O\?X@[>$@ZMSM^2#E]N7D\>GJ_"#A[?3?X_'A]N\@]/GM(/'U
MZ.S?\^7Y[3H@)7,`Q.4@[/#O\?X@[>$@X?#OZ.?JY?WS^2#P\?SC\>'L[.$@
MY>WG[-WQ^?/G\B#S].\@)R5S)RX`Q.4@[/#O\?X@[>$@X?#OZ.?JY?WS^2#E
M]N7D\>GJ_"#A\??EW^\@\?7H[-_SY?GM("5S+@#$Y2#L\._Q_B#MX2#A\._H
MY^KE_?/Y(/3O(.'Q]^7?[R#Q]>CLW_/E^>T@)7,N(,SP[_'EW_3E(.7?].4@
M[>$@]_'G\^GL[_#OZ=XM\^7TY2#LZ>$@X?#\(/3I\B#E\.GK[^/=\B#CZ>$@
M[>$@X?#OZ.?JY?WSY?3E(/#?\_D@\_3O("5S(-X@X>WTZ>/QW/CTY2#LY2#T
M[R#WW?'I(/3O[2#J_N3IZN$@\-_S^2#S].\@)7,N`,'D_>WA].<@YR#A[>'F
MWO3G\^<@\_3O[2#E[O7PY_'E].?TWB!,1$%0+@#$Y2#L\._Q_B#MX2#A\._S
M]>WDW?/Y("(E<R(N`,3E(.SP[_'^(.WA(.7MY^SE\?[S^2#TY^T@Y?#A]MXN
M("5S`,3E(.SP[_'^(.WA(.7MY^SE\?[S^2#TYR#+W_/TX2#$Z>'M[^S>\BX@
M)7,`Q.4@[/#O\?X@[>$@X_'<^/D@].GR(/'U[-_SY>GR(./IX2`G)7,G.B`E
M<P#$Y2#L\._Q_B#MX2#B\?X@].<@\.OE]?'IZMX@[/#<\>$@]._U($UO>FEL
M;&$N(,+EXN'I^>CEW_3AZ2#\].D@Y=_MX>D@X>WOZ>KTWBX`Q.4@[/#O\?X@
M[>$@Y/[S^2#S].\@]_'>\_3G("<E<R<@].$@\.'QX>K<]/D@Y.GJX>G^[.'T
MX2#S].\@]MSJY>OO("<E<R<Z("5S`,SE]/'G[-WM[R#JY=_LY>WO`-?^\>$`
MT._QY=_E\@#$Y^SI[_7QX]_A`,3G[.GO]?'CW^$@Y>W\\B#S]>WDW?/L[_4`
MQ.?LZ>_U\>/?X2#LZ>'R(.W=X?(`Q.?LZ>_U\>/?X2#U\._VX>K=Z_GM`,7N
M[_7SZ>_D[_3>\^7I\B#$Y^SI[_7QX^_]`,'QZ>CL_/(@T.GS]/GTZ>K>\B#*
MW/'TX?(`Q?7WX?'I\_3?Y?(`U/'=]^_U\^$@UMSSYP#4\=WW[_7SX2#^\>$`
MU.\@]/'=]^_M(%523"#EW^WAZ0#4\=WW[^T@RN'I\?SR`-3QW??O]?/A(//U
M[>C>ZN<Z(`#4\=WW^>T@\_3]ZP#0X?'A[.7T\>_P[]_G\^<@Y.GAY.GJX?/I
M_NT@\._U(.7J].7K[_WM].'I(.KA]-P@].?M(.7?\^_D[R`E<RX`P?#OZN_P
MW@#!\._J[_#>(.7PZ>OOX][R`,S,`,?LY?'>\^GA`,3EY._LW>WA`,7L]MSM
MZ?/G("A"<F]W<V5R*2!$871A5')E90#'(.'MX>;>].?SYR#S].<@PMSSYR#$
MY>3O[-WM^>T@X?#=]/7WY2X`Q^SE\>_LY^W?X0#'[.7Q[^SG[=_A(/#A\>'K
MX>+>\@#%\.GK[^/>(,?LY?'O[.?MW^'R`,?LW?'A`,3IX>/QX?;>(-/TWNOG
M\@#$Y>K=[.+QZ>_R`,3EZN'DZ>KOWR#A\>GH[._?`+CW[_7M(.'Q[>?HY=\`
MS.7?^?/G(-#E\>GH^?'?[_4`T/'OZN'H[_'I\^S=[>\`T/'OY?#IZ^7C[-WM
M[R#7\?[LX0#0\>_E\.GKY>/LW>WG(-3A]?3\].?TX0#0\>_JX>CO\>GS[-WM
MY?(@Q>[O]?/I[^3O]-[SY>GR`-#Q[^KAZ._QZ?/LW>WE\B#%[N_U\^GOY._T
MWO/EZ?(`S_'I\^SOWP#(W?/G(.'M].GP\>_S_O#O]0#![?3I\/'O\_GPY^S=
M[>\`Q.GAX_'A]MX`Q.GAX_'A]MX@S^S<Y.'R`,3IX>/QX?;>(,7N[_7SZ>_D
M_/3G\^?R`,3IX>/QX?;>(.KAZ2#EZNK=[?GSYR#LY^WU[-ST^>T`Q.GAX_'A
M]MX@ZN7KZ>_]`,3IX>/QX?;>(-/TWNOG\@#$Z>'C\>'VWB#U\-SQ]^_M]._R
M(.7MX>OKX>KTZ>KO_2#P\>_T_?#O]0#$Z>'C\>'VWB#E[N_U\^GOY._TWO/E
M^>T@X^GA("<E<R<`Q.GAX_'A]MX@Y>[O]?/I[^3O]-[SY?GM(./IX2`G)7,G
M(.KAZ2#JW.CE(/7P[RWE[N_U\^GOY/STY_/G.P#$Z>'C\>'VWB#S]-[KY_(`
MT/'OY?#IZ^7C[-WMYR#4X?7T_/3G].$`Q.GAX_'A]MX@]/'=]^_U\^'R(//T
MWNOG\@#$Z>'C\>'VWB#T\=WW[_7SX?(@X_'A[.S>\@#$Z>'C\>'VWB#A]?3>
M\B#TY_(@Y>[O]?/I[^3\].?SY_(@ZN'I(.K<Z.4@]?#O+>7N[_7SZ>_D_/3G
M\^?R.P#$Z>'C\=SVY^KE(/3O('-E='5P('5P9W)A9&4@<V-R:7!T("<E<R<N
M`+_QX2#<]NGNY_(`P?'MY_/G(.'I]-[LX?3O\@#!\>WG\^<@X>GTWNSA]._R
M(./IX2#PZ^?Q[_;O\=_E\B#DZ>'HY?/I[/STY_3A\@#0Y?'IX_'A]MX@]._U
M(-#Q[^+KWNSA]._R`-#E\>GC\>'VW@#+Y?#T[^S=\>7IY?(@*.7PW_/G\B#J
MX>D@\_3O(.'Q]^7?[R#JX?3AX_'A]M[R(/3O]2!(;W)D92DZ`,_I(.OE\/3O
M[-WQY>GE\B#=]^_U[2#JX?3AX_'A]N7?(./IX2#T[^T@Y.GA]^7I\>GS]-XN
M`,'MW/#T]>[G`-/G[.7?[R#$\>_SZ=SR`-/G[.7?[R#$\>_SZ=SR(./IX2#T
MY^T@].7KY?7TX=_A(/[QX3H@`-/G[.7?[R#$\>_SZ=SR.B``RN'TY?WH]>WS
MYR#A\/P@X?'I\_3E\=P@\/'O\B#TX2#DY>[IW`#*X?3E_>CU[?/G(.'P_"#T
MX2#DY>[IW"#P\>_R(/3A(.'QZ?/TY?'<`,KA]-SK[^/O\@#%[/;<[>GSYR#^
M\>'R(//E(#(T^?'G(.SO\?;>.P#%\.GK[^/=\B#%[/;<[>GSY_(`Q>SVW.WI
M\^<@\/'OXNO=^.7Y[2`H5$%&*0#,[_'VWB#%[/;<[>GSY_(`Q>WG[-WQ^?/G
M(,3IW/3A[N?R`,SG(.3IX>/QW/;EZ?(`S.?M(.7PZ??EZ?'>\^7TY2#MX2#A
M[>_?[N7TY2#A\.7UZ.7?X?(@].\@X?'WY=_O(&UA:6YT96YA;F-E+G!H<`#0
MY?'IW??EZ2#G(/#Q_O3G(./QX>SLWB#O[?SLX?3A(/#EY-_Y[3L@P>T@[>'I
M(/3SY>K<\>7TY2#A]?3\.@#*X?3=XN'S[.$`RN'TW>+A\^SA("5S`,KA]-WB
MX?/LX2#T[_4@X?'WY=_O]2#PX?'A[-WT\?GM(//A[2!02%`M<V-R:7!T+@#+
MW_/TX2#*X?3A\=SJ].?R`-;<\>SAZN$M[>'QZOGTZ>K<`,7PY>[E\>/A\]_A
M`,7PY>[E\>/A\]_A($)L;V-K`,7PY>[E\>/A\]_A(,_LW.3A\@#%\.7NY?'C
MX?/?X2#%[N_U\^GOY/STY_/G\@#%\.7NY?'CX?/?X2#%[N_U\^GOY._TWO/E
M^>T`Q?#E[N7QX^'SW^$@Q>[O]?/I[^3O]-[SY?GM(./IX2`E<P#%\.7NY?'C
MX?/?X2#E\.GK[^/^[2#CZ>$Z`,7PY>[E\>/A\]_A(,7N[_7SZ>_D[_3>\^7Y
M[2#CZ>$@)7,`Q?#E[N7QX^'SW^$@Q>[O]?/I[^3O]-[SY?GM(./IX2`G)7,G
M`,'E\>_KZ>S=[>'R(,7KY?7SW^WA\@#3]._I]^7?[RXN+@#!Z^OGZ^_C\>'V
MW^$`Q.GE_>CU[?/G($5M86EL`,<@Y.GE_>CU[?/G($5M86EL(/#QW?#EZ2#M
MX2#TX>GQZ=SFY>DN`,S>[?7LX2#LY2#Q]>CLW_/EZ?(`P>GSZ-[LX?3A`,KE
M[?P@[-[M]>SA+@#$Y>T@Y?#I\_3QW/;GZN'M(,'P[_3EZ]WS[.'TX2X`P>3E
MZ>7R(//U[>C>ZN7R(.'MX>;>].?SY_(`Q>WE\>/O\._?Y_/G(.7I\^'C^>/>
M\B#EZ>K\[?GM(.'P[R!0:&]T;R!#86QL97)I97<@\_3O(.KEW^SE[>\[`,WA
M(.7MY?'C[_#OZ>?HY=\@].\@[.7M[_T@[.4@Y.7NWR#JZ^GJ.P#4W>OO\@"X
M]._R(-3=Z^_U\@#,Y>/=[>CU\^<@RN7I[.7M[^/QW/;O]0#$_O/TY2#LZ>$@
MY?'^].?SYR#A\_;AZ^7?X?(L(.<@[_#OW^$@Z.$@\^'R(.;G].?HY=\@X>T@
M]_'EZ>'SZ.7?(.WA(.'KZ]SNY2WTY2#T[^T@ZOGDZ>K\(//A\BP@\"[W+B`G
MT._I_"#EW^WAZ2#T[R#\[>_LX2#T[_4@ZN'T[^GJZ>3?[_4@\^'R.R<Z`,3^
M\_3E(/3G(//][>3E\^<@].?R(.7IZOSMX?(@Y>3^`,O<Z._R`,O<Z._R(.'P
M[_/TW>OK[^WTX?(@X?#<[?3G\^<Z("5S`,O<Z._R(.SE(.S>[?7LX2!E;6%I
M;"X`R]SH[_(@X_'<]N_M].'R("(E<R(N`,7H[>GJ_`#%]?'^\.<`RMSHY2`Q
M-2#KY?#TW`#*W.CE(#(@R^7P]-P`RMSHY2`S,"#DY?7TY?'\Z^7P].$`RMSH
MY2`U(.OE\/3<`,K<Z.4@]N_QW"#P[_4@[/#AW^WE].4@\_3G[2#U\.?QY?/?
MX0#*W.CE(.SI\]X@_O'A`,K<Z.4@Z^7P]/P`T.'QX>3EZ>/LX?3IZMWR(/3I
M[-WR.@#%ZO3=Z^7SYP#%\-WJ].'SYP#%\-WJ].'SYR#0Z^7U\>GJWO(@S/#<
M\>'R`,'MX>SE[?SLY>WO(")"14=)3B(@\_3G(./QX>SLWB`E9"X`P>WA[.7M
M_.SE[>\@(D5.1#HE<R(@\_3G(./QX>SLWB`E9"X`P>WA[-WM[^WTX>T@)RDG
M`,'MX>S=[>_M].'M(.'PZ]X@Z]WNYR#>(//U[>C>ZN<@X>WAYM[TY_/G\B#S
MY2#EZ?/AX_GCZ>K<`,?LY?'O[.?MW^$@R][NY_(`Q>KHW?3G\@#7\?[LX2#P
M\>_SZM[MZ>_U`-'UZ.S?\^7I\B#CZ>$@1E10('5P;&]A9`#!\._T]???X2#J
MX?3<(/3G[2#P\>_S\-SHY>GA(.'MW.KTY_/G\B#T^>T@\/'O].GLWO/E^>TN
M`,'P[_3U]]_A(//][>3E\^?R(//T[^T@Y.GAZN_LZ?/TWB#*X?3AZ_SC[_4N
M`,'P[_3U]]_A(//][>3E\^?R(//T[^T@4TU"+5-E<G9E<BX`P?#O]/7WW^$@
MX>WTZ>/QX?;>\B#A\/P@(B5S(BX`P?#O]/7WW^$@X>WTZ>/QX?;>\B#SY2`B
M)7,B+@#!\._T]???X2#DY^SI[_7QX]_A\B#S_>WDY?/G\B!305-,+@#!\._T
M]???X2#LY?3A]N_QW/(@\^4@(B5S(BX`P?#O]/7WW^$@ZN'TW"#TY^T@X>OK
MX>/>(.KYY.GJ[_T@X^GA(/3O[2#W\=[S].<@)7,@X?#\(/3O(//TX>CL_"`E
M<RP@Z_SC[_(@)7,`P=_H\>GO\@#0[^O](//OXN'Q_"#+W.CO\CH`UL'.`-;E
MXO'O]=SQZ>_R`,3IW.CE\^<@X^GA`,3IW.CE\^<@X^GA.B``R]_CY?(@XO'O
M]]WR`,O?X^7R(/?I[^WO\/3^\^7I\@#0W^WAZN'R(-#EY-_O]0#!\>GH[/SR
M(.'Q]^7?[_4Z("5S(.'Q]^7?[P#!\>GH[/SR(.'Q]^7?[_4Z("5S(.'Q]^7?
MX0#$Z>'WY>GQZ?/TWO(@P?'WY=_Y[0"\[>_LX2#!\??EW^_U`,7PZ>OOX]X@
MP?'WY=_O]0`GP>W=XN'S[.$G(,'Q]^7?[_4`)\'MW>+A\^SA)R#!\??EW^_U
M(.3E[2#U\._S].?QW^;E].'I+@#6W^OT\>$`T/'^].\@S.GS_`#0\?[T[R#4
MW?3A\?3O`-/TX>CE\?SR(.O\X^_R`$9L:7``1FQO870`S^S?]^OG`,\@]MSJ
MY>OO\B`E<R#DY>T@]?#<\??EZ0#7\?[LX2#C\=SL[.'T[_(`U/'O]MX`P^GA
M($)R;W=S97)S+"#P[_4@Y.7M(/7P[_/TY_'?YN_U[2#EZ>K\[>7R`,[E]]SS
MX?3E(/3O[2#J^>3IZOP@\^'R.P#6_/'LY?(`T/'\XNOE^.<`U/WP[_(@T/'\
MXNOE^.?R`-#Q[^+KW?CEZ?(`T/'OXNO=^.7I\B`R`$9O<G5M<P#0\>_YZ-[S
MY>GR`-#A`-#KX=_SZ>$`T.OG\>_V[_'?Y?(@Q.GAZ.7SZ>S\].?TX?(`P?#<
M[?3G\^<@Q.GAZ.7SZ>S\].?TX?(`P=_TY^SA(,3IX>CE\^GL_/3G].'R`,'P
MW.WTY_/G(//E(.'?].?LX2#$Z>'HY?/I[/STY_3A\@#!\/P`P?#\(/3O(`#!
M[>'K]?3IZMX@T.7QZ>/QX?;>`,'MX>OU].GJWB#0Y?'IX_'A]MXZ`-#KWO'G
M\B#3Y>O>[><`T.O>\>7R(+SM[^SA`$=A;&QE<GD@X?#\(/3G[2#O\._?X2#H
MX2#PX=_Q[>_M].'I(._I(.7IZOSMY?(`1V%L;&5R>3H`S.GJ\?P@O.WO[.$`
MP^7MZ>K=\B#%\.GK[^/=\@#,Y?3<XN'SYP#%Z^O<Y.$`Q>OKY^WIZMP@*$E3
M3RTX.#4Y+3<I`,3IX??EW_'I\^<@S^S<Y/GM`-3A(._M_.SA].$@]/GM(._L
MW.3Y[2#DY>T@\/'=\.7I(.WA(.7?[>'I(.KE[=P`Q>[O]?/I[^3O]-[SY>GR
M(,_LW.3Y[0#/[-SDY?(`R>3I_/3G].7R($=U97-T`,GDZ?STY_3E\B!'=65S
M=`!'=65S=&)O;VL`U.\@\_WS].?LX2#A]>CE[?3IZN_P[]_G\^?R($A45%`@
MY.4@XO'=Z.?JY2X`OOCO\@#"[][HY>GA`,+OWNCEZ>$@X^GA(/3G(/?QWO/G
M(/3O]2#JY>GLY>WOX_'<]N_U`,+OY^C\\@#'[.GS]N'?\>GO`,'E\>_KZ>S=
M[>'R(,?QX>KKY=_O]0#%Y/X@Y=_MX>D@YR#A\??>(/3O]2#A\??EW^_U.@#8
MY^O<`,<@Y>/C\>'VWB#I\_3O\>GJ[_T@Y.7M(/#QW?#EZ2#MX2#EW^WAZ2#J
MY>W>`,'Q]^GJWB#3Y>O?Y.$`P?'WZ>K>(-/EZ]_DX0#$Z>7]Z/7M\^<@T_#I
M].GO_0#4Y^O=]OGM[R#3\.GTZ>_]`,'Q]^GJWB#3Y>O?Y.$`Q=_S[^3O\B#S
M].?M(-7PY_'E\]_A(,?+Y>KT\>_MZ>KO_2#4X??UY/'O[.7?[_4`T_WS].?L
MX2`G2&]R9&4G`"=(;W)D92<@P?/]\>SA].<`U.\@\/'\X_'A[.SA("=(;W)D
M92<@Y.7M(-WWY>D@\?7H[.GS].7?(//Y\_3<`,_QZ>;\[?3I[_(@RN'M_.WA
M\@#/\>GF_.WTZ>\@)^/=[.GS[.$G`,_QZ>;\[?3I[SH`T/GR(/;HW//A].4@
MY>3^.R`H\.'QX>KAZ_X@[>$@].\@X>WA]MWQY?3E(//T[R#DZ>'WY>GQZ?/T
MWB$I`-#\\^7R(//TWNOE\B#HW>OE].4@[>$@Y>WO\._IWO/E].4[`-#\\^$@
M\.7DW^$@*//TWNOE\BD@Y=_MX>D@Y>KEWSL`T/SSY?(@X_'A[.S=\B#HW>OE
M].4@[>$@Y>WO\._IWO/E].4[`-7C\>'SW^$`U>/QX?/?X3H`U^GO]>SO\=_S
M].'R`,<@Q.?LZ>_U\>/?X2#C\>'L[.'T[^CU\=_DX?(@24U!4"#A\-WT]??E
M.B`E<P#'(.3IX>/QX?;>(./QX>SLX?3OZ/7QW^3A\B!)34%0(.'PW?3U]^4Z
M("5S`,<@Q.?LZ>_U\>/?X2#PY>GQ[_'I\^S^[2`H<75O=&$I(./QX>SLX?3O
MZ/7QW^3A\B!)34%0(.'PW?3U]^4Z("5S`,7I\^7Q]_SLY>WA`$E0+<3IY?WH
M]>WSYP!)4"W$Z>7]Z/7M\^<@Y.7M(.7?[>'I(.3IX>C=\^GLYRX`25`MQ.GE
M_>CU[?/G(.SG(.7PZ?3QY?#TWB#LW?/A(//E($-)1%(M0FQO8VLN`,KKY=_D
M^>SA+=#A\>'BW^'SYR!)4"X`Q>GSY?'W_.SE[>$`Q>GSX>/YX]X@P_'A[.S>
M\B#0\>GM`,S\[>\@Q>GJ[^W?Y.GA`,7IZN_MW^3IX2#CZ>$@)7,`Q>GJ[^W?
MY.GA(.KAZ2#*Y=_LY>WO`,_M[^SA(/3A]?3\].?TX?(Z`,'M(.3E[2#E[/;A
M[=_FY?3AZ2#S^?/TW"P@)7,@X^GA(.WA(.'M[]_NY>D@\^4@[=WO(/#A\=SH
M]?'O+@#![2#DY2#BZ]WPY?3E(.KA[=WMX2#EZ>KO[=_DZ>\@]_'G\^GL[_#O
MZ?[M].'R(/3O[2!);G1E<FYE="!%>'!L;W)E<BP@W_/Y\B#P\=WPY>D@[>$@
M]//EZMSQY?3E(.7D_B#CZ>$@[>$@X?#E[>7QX^_P[^G>\^7TY2#TYR#DZ>'V
MW.WEZ>$@4$Y'+@#![2#BZ]WPY?3E(.'U]/P@].\@[-[M]>SA(/?Y\=_R(.7I
MZOSMX2P@YR#EZ>K\[>$@\._U(.C=Z^7TY2#MX2#JX?3EXMSSY?3E(.3E(.SP
M[_'EWR#MX2#E[/;A[>GSZ.7?(.'P_"#T[^T@8G)O=W-E<B#SX?(N`-#Q[^7P
MZ?/J_/#I\^<@Q>GJ_.WA\CH`55),(,7IZOSMX?(`Q>GJ_.WA(.'P_"!'86QL
M97)Y`,7IZOSMX2#A\/P@1V%L;&5R>3H`P?#O\_3OZ]X@Q>GJ_.WA\@#%Z>K\
M[>7R`,7I\^'C^>/>`,O<Z._R(.KA]-P@].?M(,7I\^'C^>/>.B``Q>GSX>/Y
MX]XL(,+>[.$@)60`T.7DW^\@\._U(.7I\][WZ.<Z("5S`-#EY-_A(/#O]2#E
MZ?/>]^CG\^'M.@#3Y2#%\.7NY?'CX?/?X0#%Z?/AX_GCWB##\>'L[-[R(,SE
M]-P`Q/SHY^KE(.O<Z._R(.KYY.GJ_/(@Y>W=\>/EZ>'R+@#+W.CO\B#\[>_L
MX2#W\=[S].<@WB_JX>D@ZOGDZ>K\\BX`R]SH[_(@_.WO[.$@]_'>\_3G(-X@
MY>WAZ^OAZO3IZMX@Y.GE_>CU[?/G+B#.X>WAY._JZ>S<\_3E(-X@Y?#IZN_I
M[?GMWO/TY2#LY2#T[R#DZ>'WY>GQZ?/TWB#CZ>$@\.7QX>GTW?'Y(.+OWNCE
MZ>$N`,'][N?SYR#0Y?'IZ/GQW^_U`,GDZ>'?].7Q[^D@U_'>\_3E\@#0Z^?Q
M[_;O\=_E\@#0Z^?Q[_;O\=_E\@#%Z?/AX_GCWB#3]-[KY_(@S.7TW`#%Z?/A
MX_GCWB#%Z>K\[>'R`,7I\^'C^>/>(-#?[>'JX0#%Z?/AX_GCWB#S_>WDY?/G
M\B!796(`Q>GSX>/YX]X@T_3>Z^?R(-#QZ>T`Q>GSX>/YX]X@[=WA\B#S]-[K
MY_(@[.7TW"#TY^T@]/'=]^_U\^$`Q>GSX>/YX]X@[=WA\B#S]-[KY_(@\/'I
M[2#A\/P@].?M(/3QW??O]?/A`,7I\^'C^>/>(.W=X?(@X_'A[.S>\B#LY?3<
M(/3G[2#T\=WW[_7SX0#%Z?/AX_GCWB#MW>'R(./QX>SLWO(@[.7TW"#TY^T@
M]/'=]^_U\^$`Q>GAX_GCWB#PX?'AX_'<]N_U(.SE]-P@]._M(/3QW??O[?3A
M(.K\[.+O`,7I\^'C^>/>(/#A\>'C\=SV[_4@\/'I[2#T[^T@]/'=]^_M].$@
MZOSLXN\`Q>GSX>/YX]X@Y>WAZ^OAZO3IZN_](/#Q[_3]\._U`,3^\_3E(&5M
M86EL(.3IY?WH]>WSYR#S].?M(._P[]_A(.7PZ>CU[.7?].4@[>$@\.'QX>O<
MXN7TY2#T[R#MW>\@\^'R(.KYY.GJ_#H`Q>GSX>/YX]X@ZN7KZ>_](.SE]-P`
MQ>GSX>/YX]X@ZN7KZ>_](/#QZ>T`Q>GSX>/YX]X@\_3>Z^?R(.SE]-P`Q>GS
MX>/YX]X@\_3>Z^?R(/#QZ>T`Q>GSX>/YX]X@[.?M_>SA]._R`,7I\^'C^>/>
M(/#A\>'C\=SV[_4@[.7TW`#%Z?/AX_GCWB#PX?'AX_'<]N_U(/#QZ>T`Q>GS
MX>/YX]X@X_'A[.S>\B#LY?3<`,7I\^'C^>/>(./QX>SLWO(@\/'I[0#%Z?/A
MX_GCWB#TY_(@X?#AZ?3O_>SE[>?R(.'PW.WTY_/G\B#S].?M(.7Q_O3G\^<@
MX?/VX>OEW^'R.@#%Z?/AX_GCWB_$Z?SQZ/GSYR#%Z>K\[>'R`,7I\^'C^>/>
M+\3I_/'H^?/G(-/][>3E\^?R`,SG(.7PX?'JW?(@]?#\Z^_I\.\@X^GA(.'P
M[_/T[^O>(//TYR#KW_/TX2#DZ>'M[^S>\BX`S.<@Y?#A\>K=\B#U\/SK[^GP
M[RX`P>K=\>'I[_(`R]_S].$@P>KE\>'?^>T`Q?#IZ]WNX?3E(,O<Z._R(,7M
MW?'CY>GA(./I)R#A]?3\(/3O(//U\_3A].GJ_"X`P>KU\>\@541(+B`H57-E
M<B!$871A($AE861E<BDN`,SG(-WCZO7QYR#E]N'Q[._CWBX`P>KU\>\@0F%T
M8V@M240N`-/TW.OHY^KA[2#KW.CO\B#DY>3O[-WMX2X`P>KU\><@Y.GE_>CU
M[?/G(/#Q[^_QZ?/L[_TN`,SG(-WCZO7QYR#L[_'VWB#A\??EW^_U`,SG(-WC
MZO7Q[R!M<V=?='EP92X`S.<@W>/J]?'O(-X@Z^7?\.7I(&%P:5]I9"X`S.<@
MW>/J]?'E\B#>(.7KZ^GPY=_R(/#A\=SLY?3Q[^DN`$EN=F%L:60@<&%R96YT
M('!E<FUI<W-I;VXN`,SG(-WCZO7Q[R#P\?GT_.KOZ^OO+@#,YR#=X^KU\>_R
M(/#A\>'KWO#TY_(Z("<E<R<`S.<@W>/J]?'O(.KOZ>W\]_'G\_3O(.'M].GJ
MY=_LY>WO`,SG(-WCZO7QYR#A\??IZMX@Y.GE_>CU[?/G+@#,YR#=X^KU\>$@
MY.7D[^S=[>$@56YI8V]D92X`RN'TW.OOX^_R(-7PX?'W_.WT^>T`T.OAX^GA
M`,GA[>_UW/'I[_(`R>_]Z^GO\@#)[_WMZ>_R`,7UZ/7C\=SL[.GSYP#%]>CU
MX_'<[.SI\^<@\_3O(,K=[?3Q[P#0Z][QY_(@Q?7H]>/QW.SLZ?/G`,7UZ/7C
M\=SL[.GSYR#!\>GS].7QW`#%]>CUX_'<[.SI\^<@Q.7NZ=P`P>7Q[^OI[-WM
MX?(@RN'KX>S<].'R`,'E\>_KZ>S=[>'R(,KA\?#<Z._U`,'E\>_KZ>S=[>'R
M(,KA\_3O\>G<\@#-X2#J\>'TWO/Y(/3O(.'UZ.7M].GJ_#L`P>7Q[^OI[-WM
MX?(@RN7VX>OO[>G<\@!+97)B97)O<RU397)V97(@X?'MWNCGZN4@].?M(.'U
MZ.7M].GJ[_#OW^?SYRX`P>7Q[^OI[-WMX?(@RMWQZO7QX?(`S=WA(.'P_"!+
M97)N96P`Q.?LZ>_U\>/?X2#*Z^7IY.GO_0#!\._T_?#Y[.$@RNOEZ>3I[_T`
MS-[J[_(@RNOEZ>3I[_T`U/WP[_(@RNOEZ>3I[_T`U_'>\^<@RNOEZ>3I[_T`
MU.\@ZNOEZ>3?(/7PW/'WY>D@WN3G(//T[^T@Y>[U\.?QY?3G]-X@Y.?L_//I
M^>T@ZNOEZ>3I_NTN`-#AZ>3IW`#!Y?'OZ^GLW>WA\B#*^0#!Y?'OZ^GLW>WA
M\B#*[^;<[>?R`,3IW/3A[N<`P>7Q[^OI[-WMX?(@R]SQZ?/A\@#4Y>OE]?3A
MW^\@S.GS_`#4Y>OE]?3AW^\@U-WTX?'T[P#4Y>OE]?3AW^$@Q>WG[-WQ^?/G
M.@#4Y>OE]?3AW^$@Q=_S[^3O\B#S].?M(/7PY_'E\]_A.B`E<P#4Y>OE]?3A
MW^$@Q=_S[^3O\B#S].?M(/7PY_'E\]_A.B`E<R#A\/P@)7,`U.7KY?7TX=_A
M(,7?\^_D[_(@\_3G[2#U\.?QY?/?X3H@T._TW0#-_.SO\@#$Z=STX>[G`,'V
MWO/TY2#JY>W\(./IX2#MX2#LY^T@]?#<\??O]>T@\.7QZ>C^\>GA`,'QZ?/T
MY?'<`,'QZ?/TY?'>(,7PZ>KE]N'KW^3A`,'QZ?/TY?'=\B#4Z>S=\@#0Y>WT
MW//TZ??O`,'E\>_KZ>S=[>'R(,O>[.WO]0#3_>WDY?/G`-/][>3E\^<@\._U
M(.3EW_?MY>D@\^4Z`-/][>3E\^<@].?R(.3IY?WH]>WSYR#CZ>$@W.WOZ>/L
MX2#PX?'AZ/WQ[_4@\_WMZ.7SY_([`-/U[>3=\^7I\@!,:6YU>"U#;V]K:64`
M3&ES="`M(,\@]_'>\_3G\B#L\._QY=\@[>$@Y.7?(/3O(/;<ZN7K[P#+W_/T
MX2#"W//E^>T@Q.7D[^S=[?GM`,O?\_3A(.CE[-ST^>T@PN_>Z.7IX?(`R]_S
M].$@T.GMW.KY[0#'(.3G[.GO]?'CW^$@Z]_S].'R(/?QY_/T_NT@W??EZ2#A
M\.7MY?'C[_#OZ>?HY=\N`-;\\?3Y\^<N+BX`U._PZ>K>(+_QX3H@`-3\\._R
M(.KAZ2#^\>$`U/SP[^CE\]_A`,7?\^_D[_(`N.[OY._R`,3IY?'CX?/?Y?(@
MY>GS_.3O]0#'(.7?\^_D[_(@P?#=]/7WY2X@T.GHX>W\].'TX2#D_.CGZN4@
MZ]SH[_(@].\@O.WO[.$@U_'>\_3G(-X@[R#*^>3IZOSR+@#%W_/OY._R(,'P
MW?3U]^4N`+CN[^3O\@#,Y>/<Z^\@RN7?[.7M[P#!X]SPYP#7X>SGZ_P`S.GJ
M\=P@Q>OKY^WIZMP@X_'<[.SA].$`S.GJ\=P@Z^'TZ>WIZMP@X_'<[.SA].$`
MS.GJ\=P@T?GLX?KJWB#!\=_H[.?SYP#,S`#,X>/IZOP`P>OKY^OOX_'A]M_A
M`,3IX??EW_'I\^<@16UA:6P`Q.?LZ>_U\>/?X2#3_>WDY?/G\BXN+@#$Z>'W
MY=_QZ?/G(.KA].?C[_'I_NT@ZN'I(/?Q^>S<]/GM(/#O]2#HX2#E[/;A[=_F
M[^WTX>D@X?7TW?(N`,7C]^7I\=_DZ>\`T.7DW^$@Q^SE\>_LY^W?X?(@ZN'I
M(+_QX?(`T.7DW^$@Y>GSX>/YX][R`,S<\?3I[_(`O/'I[P#,X?'JW/'I\^SA
M(.SE(-WMY.7I[N<@P>WAX^WY\^S=[>_U+\SG(.'MX>/M^?/LW>WO]0#,X?'J
MW/'I\^SA(.SE(-SKZ^<@W>WDY>GNYR`H\"[W+B#3Y^SA[?3IZOPOP?#A[?3G
M[-WM[RD`T.7DW^$@\._U(/3AZ?'IW.;O]>T`S-WCZ?/TYR#E\.GT\>7P]-X@
M\-_S]/GSYRX`U?#=\>+A\^<@[_'?[_4@[.?M_>SA]._R+@#,W>/I\_3G(.CE
M\>SOZO'A\]_A(/3EZ^7U].'?^>T@,C0@^?'^[3H@`,S=X^GS].<@Z.7Q[._J
M\>'SW^$@].7KY?7TX=_Y[2`V(/GQ_NTZ(`#,W>/I\_3O(.S>ZN_R`,S<Z>_R
M`,'J_?'Y\^<@T_7MW.WTY_/G\@#0Z^?Q[_;O\=_E\B#3]>W<[?3G\^?R`-#Q
M_/3A\^<@X^GA(-/U[=SM].?SYP#!\-SM].?SYR#CZ>$@T_7MW.WTY_/G`,7M
MY^S=\?GSYR#CZ>$@T_7MW.WTY_/G`,'?].?LX2#E[>?LW?'Y\^?R(./IX2#3
M]>W<[?3G\^<`S-WKYP#3Y^SEZ?[SY>GR`,KA]-SS].'SYR#,Y>WO_3H`T_7C
M]_[MY?7SYR#JY>OI_NT`S-[M]>SA`-3O(.S>[?7LX2#E\.GBY>+AZ?[HY^KE
M(.7PZ?3U]_[R+"#AZ^O<(/3O(/#I\_3O\._IY_3IZOP@]._U(/7P[^/QW/;O
M[?3A(.3E(.SP[_'EWR#MX2#E\.GBY>+AZ?GHY=\N`-3O(.S>[?7LX2#=Z^?N
MY2X`U/WP[_(@[.?M_>SA]._R`,KAZ?'\\B#A\/P@365T87(`365T87(@8FQO
M8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BX`S-WH[^3O\@#'(,S=Z._D[_(@)R5S)R#DY>T@[_'?\^CGZN4`S.7T\>GJ
M_`#,Y?/AW^\`36EM92!4>7!E`,SIZO'\].7QYR#HY?'L[^KQX?/?X2#TY>OE
M]?3AW_GM(#(T(/GQ_NTZ(`#,Z>KQ_/3E\><@Z.7Q[._J\>'SW^$@].7KY?7T
MX=_Y[2`V(/GQ_NTZ(`#*X>CQW?#TY_(`Q.G<]N_QX0!-:7-S:6YG(%!%05(@
M<&%C:V%G92!(5%107U)E<75E<W0N`,OEW_#EZ2#T[R!C;VYF:6=U<F%T:6]N
M+B#0\=WPY>D@[>$@].\@Y.?LZ>_U\>/>\^7TY2#A[2#HW>OE].4@[>$@]_'G
M\^DM[._P[^G>\^7TY2#A]?3>(/3G[2#E]N'Q[._CWBX`R^7?\.7I(/3O($E$
M(/3O]2#LY^W][.'T[_(N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E
M($UA:6PN`,OEW_#EZ2#T[R!)1"#TY_(@\_WMY.7SY_(N`,3E`$5M86EL(,KI
M[>?TWO(@U.?KY?;Y[=_A\@#,W?3QZ>_R`,?LY?'O[.?MW^$@]/'O\._P[]_G
M\^?R`-3Q[_#O\._?Y_/G(%523`#%[/;<[>GSYR#,WNWA`,S>[>'R(.KAZ2#=
M]._R`,SG[>GAW^$`S.?MZ>'?X2#+W_/TX2##Y>/O[?ST^>T`UMSSY>GR(-/E
MZ][MY_(`RM_MY_/G(.K<]/D`RM_MY_/G(.'QZ?/TY?'<`,K?[>?SYR#DY>[I
MW`#*W^WG\^<@\-SM^0#*W^WG\^<@ZMST^0#*W^WG\^<@\-SM^0#0[^OKX?#K
MW?(@Z]_S].7R(.7PZ>OOX][R("CJX?3A\?'<ZO3E\BD`T._KZ^'PZ]X@Y?#I
MZ^_CW@#/(,OOX^'QZ>'S[/SR(.SO]0#/(.GS]/ST[_#\\B#L[_4@*'!O<G1A
M;"D`QR#E[/;<[>GSYR#T[_4@Z?/T_/3O\._](.SO]2`H<&]R=&%L*0#'(-#E
M\=_KY_CG(.SO]3H`P>7Q[^OI[-WMX?(@S/7TY^O>[>?R`,_7R2P@Q,4@\_7L
M]OGM_@"\[>_LX0#!\.'I].7?].'I(.7MW?'CY>GA`,3?ZO3U[P#0[_3=`,W=
MX2#*X?3GX^_QW^$`S=WA(-/EZ][MYP#-W>_R(,KYY.GJ_/(`S=WO\B#*^>3I
MZOSR("CNX>W<*0#-W>\@_.WO[.$@U_'>\_3G("CP\>_AZ?'E].GJ_"D`S=WO
M(/#A\=SH]?'O("CJY>W\*0#-W>$`S^S<Y.7R(./IX2#MW>$@*&YE=W-G<F]U
M<',I`,7P_.SE[>\`Q?#\[.7MYR#3Y>O?Y.$`Q?#\[.7MYR#6W//G`,7P_.SE
M[>7R(,7PZ>OOX]WR`,_WZ0#$Y>T@]?#<\??EZ2#DZ>'HW?/I[.\@8V]N9FEG
M=7)A=&EO;B#CZ>$@[>$@Y.7?[OD@Y.GA]N_QW?(N`,3E[2#U\-SQ]^7I(.3I
MX>C=\^GLYR#S]/'A].?CZ>K>(./IX2#DY^SI[_7QX]_A($E33R!I;6%G97,N
M`,3E[2#U\-SQ]^7I(/#Q_/3U\.\@X^GA($)A=&-H+@#$Y>T@]?#<\??EZ2!"
M;&]C:R#S].?M(.'I]._][.7MYR#HW?/G`,3E(.3\Z.?JY2#\[>_LX2#CZ>$@
MX?7HY>WTZ>KO\._?Y_/G($U#04PN`,3E[2#U\-SQ]^_U[2#AZ^OAX]WR+@#$
MY2#L\._Q[_WM(.WA(/#Q[_/TY>CO_>T@Y>[O]?/I[^3O]-[SY>GR(.K<]/D@
MX?`G(.'U]/P@].\@Y?#?\.7D[RX`Q.7M(.SP[_'O_>T@[>$@\/'O\_3EZ._]
M[2#U\._JX?3GX^_QW^7R(//E(.'U]-X@].?M(.7N[_7SZ>_D_/3G\^<N`,3E
M[2#O\=_SZ.?JX>T@\.OG\>_V[_'?Y?(@\?7H[-_SY?GM(./IX2`E<RX`Q.7M
M(._QW_/HY^KA[2#PZ^?Q[_;O\=_E\B#Q]>CLW_/E^>T@X^GA($944"!61E,N
M`,3E[2#=]^_U[2#Q]>CLZ?/TY=\@[^D@\.OG\>_V[_'?Y?(@X^GA(/3G[2#U
M\.?QY?/?X2#*X?3AZ_SC[_4N`,3E[2#=]^_U[2#Q]>CLZ?/TY=\@[^D@\.OG
M\>_V[_'?Y?(@X^GA(/3I\B#JX?3GX^_QW^7R(/3G\B!344PN`,3E[2#=]^_U
M[2#Q]>CLZ?/TY=\@[^D@\.OG\>_V[_'?Y?(@X^GA(/3I\B#P\>_TZ>S>\^7I
M\B#TY_(@4U%,+@#$Y>T@W??O]>T@\?7H[.GS].7?(._I(/#KY_'O]N_QW^7R
M(./IX2!344P@5D93+@#$Y>T@W??O]>T@\?7H[.GS].7?(._I(/#KY_'O]N_Q
MW^7R(./IX2#TY^T@X?7HY>WTZ>KO\._?Y_/G(//TY^T@4U%,+@#$Y>T@W??O
M]>T@\?7H[.GS].7?(._I(/#KY_'O]N_QW^7R(./IX2!344PM1FEL92!61E,N
M`,3E[2#=[.7I[>4@\-_S]/GSYRX`Q.4@Y/[SX?3E(/#Q[^_QZ?/L_"X`Q.4@
M]N_Q]/[HY^KA[2#A\??EW^$`Q.4@XO'=Z.?JX>T@Y>GJ[^W?Y.GA+@#$Y>T@
M[_'?\^CGZN4@]._P[^CE\]_A+@#$Y2#D_O/A].4@[-[M]>SA+@#$Y>T@[_'?
M\^CGZN4@_.WO[.$N`,3E[2#O\=_SZ.?JY2#A\>GH[/SR+@#$Y>T@]?#<\??O
M]>T@Y/7SW/'E\_3E\B#P\>_BZ]WXY>GR`,3E[2#EZNKQY>SO_>T@Y=_S[^3O
MZ2X`S^D@\/'O].GLWO/EZ?(@Y.7M(.7?[>'I(.3IX>C=\^GLY?(N`,3E[2#U
M\-SQ]^_U[2#JX>W\[>7R`,3E[2#U\-SQ]^_U[2#PZ^7U\=WR`,3E[2#U\-SQ
M]^7I(/#Q[_/Y\>GM_/(@]_[Q[_(@X^GA(.SMWNSG(&-A8VAE+@#$Y>T@Y/SH
MY^KE(/SM[^SA(/?QWO/TYR#>+^KAZ2#J^>3IZOSR+@#$Y>T@Y?#I\_3QW/;G
MZN'M(-WCX_7QX2!834P@Y.7D[^S=[>$`Q.7M(/7PW/'W[_7M(/3I[-WR`,3E
M(.+QW>CGZN4@W>KD[_/G(//T[R#A\??IZOP@8V]N9FEG=7)A=&EO;BX@SN'M
MX>3G[.GO]?'CWO/TY2#T[RX`Q.4@XO'=Z.?JY2#=ZN3O\^<@\_3O(.'Q]^GJ
M_"#SX?(@8V]N9FEG=7)A=&EO;BX@SN'MX>3G[.GO]?'CWO/TY2#T[RX`RN'M
MW>WA\B#3]>SLY?3=]_GM`,KA[.S?X0#*X>W=[>$@*-?QWO/G(/#Q[^KAZ._Q
MZ?/LW>WO]2D`POSQY>GO(,?LZ?/VX=_QZ>\`O/?I(,SE]-P`O/?I(-#QZ>T`
MQ.7M(.7?[>'I(.KA]-SK[^/O\@#$Y>T@W??EZ2#OZ^_JZ^?Q^>CEWRX`Q.7M
M(-WWZ>4@].7HY=\`Q.7M(/7P[_/TY_'?YN7TY2X`T^?LY>G^\^7I\@#3Y^SE
MZ?[SY>GR("T@T.7QW^OG^.<`S^D@\^?LY>G^\^7I\B#EW^WAZ2#LZ>$@Y?;A
M\>SOX]X@\._U(//A\B#E\.GT\=WPY>D@[>$@Y.?LZ>_U\>/>\^7TY2#T[R#A
M[?3?\_3OZ??O(/3Y[2#JW_3QZ>WY[2#LZ>KQ_NT@]^'Q].G^[2#S]._M(/7P
M[^OOX^GS]-XN(,SP[_'EW_3E(.WA(.3G[.GO]?'CWO/E].4L(.WA(/3Q[_#O
M\._IWO/E].4L(.WA(.3IX>/QW/CE].4@ZN'I(.WA(/3U\/[SY?3E+B#,\._Q
MY=_TY2#E\-_SY_(@[>$@^-SNY?3E(//TZ?(@\^?LY=_Y\^7I\B#SX?(@X^GA
M(.WA(.7M]._PW_/E].4@[.GA(/#KY_'O]N_QW^$N(-7P[_/TY_'?YN7TX>D@
MZN'I(.7I\^'C^>/>("T@Y>[AX_GCWB#T^>T@\^?LY>G^\^7Y[2X`T^?LY>G^
M\^7I\CH`U-_P[_3A(./IX2#E[/;<[>GSYRP@Y?#I\_3Q[_;>+@#![>'J[^GM
M_O/EZ?(`U.\@\/'\X_'A[.SA(/#O]2#DZ>'WY>GQW^;E].'I(/3I\B#EZ>3O
M\._IWO/EZ?(@)7,@Y.7M(.+QW>CGZN4N`,WOW>SB\>GO\@#!\>GH[/SR`,'Q
MZ>CL_/(@]^'QX>KTWO'Y[0#!\>GH[/SR(//TY^O^[0#!\>GH[/SR(//TY^O^
M[2#S].?M(.7L]MSMZ?/G(/3G\B#PY?'?Z^?XY_(Z`,'QZ>CL_/(@X_'A[.S^
M[0#$Y>T@[_'?\^CGZN4@X?'IZ.S\\B#CZ>$@Y>WG[-WQ^?/G(/3Y[2#KZ?/T
M_NT@Y.GA[>_LWO(N`,'M].GJY=_LY>WO`,3G[.GO]?'C_/(@P>WTZ>KEZ>S=
M[>_U`,7N[_7SZ>_D[_3>\^7I\B#$Y^SI[_7QX^_](,'M].GJY>GLW>WO]0#/
MZO3AY.GJ_/(`S^KT_N+QZ>_R`-;?Z_3Q[R#P\>_SXN_K_NT`P_'A]N7?[P#0
MX>OI_/(@ROGDZ>K\\@#,_.WO($E-05`M4V5R=F5R<R#U\._S].?QW^;O]>T@
MZN_U[?SW\>?S]._U\B#VX>K=Z^OO]?(N`,S\[>\@Y/7SW/'E\_3E\B#P\>_B
MZ]WXY>GR`,S\[>\@[.GA($5M86EL(.3IY?WH]>WSYR#E\.GT\=WPY?3AZ2X`
MS/SM[R#O(.GDZ>_J]-[TY_(@WB#O(.3IX??EZ?'I\_3>\B#S]?/TWNSA]._R
M(.SP[_'EWR#MX2#AZ^O<[N7I(/3G[2#IY.GOZO3G\]_A(-X@].GR(.7N[_7S
MZ>_D[_3>\^7I\B#T[_4@Z>3I[^KTWO3G(./IX2#J[^GMWB#W\=[SYRX`P>WO
MZ>/LX2#SY2#MW>\@\.'QW.CU\>\`3W!E;E-33"W+W.CO\CH@Q.7M(.SP[_'^
M(.WA(.+CW.OY(.3EY._LW>WA(.'P_"!3+TU)344@]?#OX^7C\>'L[-WM[R#L
MW?'O\BX`P>WOZ>/LX2#A]?3>\B#TY_(@\_WMY.7SY_(@\^4@[=WO(/#A\=SH
M]?'O`,OEZ?3O]?'CZ>K\(-/]\_3G[.$`T/'OY?'AZ?3IZOSR(-/U[.SE]-WW
M^>T`Q?#IZ^_CW?(`Q?#IZ^_CW?(@X^GA`,7PZ>OOX]WR(./IX2`E<P#4X>[I
M[>_LY^S=[><@R]_S].$`S_'CX>WI\^S\\@#4[-[LX2#/\>/A[>GS[._]`,_Q
MX]SM^?/G`,'UZ.7M].GJ_"#P\?ST]?#O(.7VX?'L[^/>\@#!]>CE[?3IZMP@
M\/'\]/7PX2#S92`E<SH`P>OK[P#!Z^OE\B#0Z^?Q[_;O\=_E\@#%[N_U\^GO
MY._TWO/EZ?(@R>3I[^KTWO3G`,<@P?7HY>WTZ>KO\._?Y_/G(%!!32#DY>T@
MY=_MX>D@Y.GAZ-WSZ>SG+@#8Y_;IX>K>(-7P[^/QX?;>(%!'4`#*\?7P]._C
M\>'VY^S=[>$@Y.7D[^S=[>$@4$=0`,3G[/SSZ>\@RNOEZ>3?(%!'4`#5\._C
MY>/QX>SLW>WA+\KQ]?#T[^/QX?;G[-WMX2!01U`@Y.7D[^S=[>$`4$A0(,K^
MY.GJX?(`4$A0(,K=Z_7V[_(`4$A0(,K=Z_7V[_(`P]WLZ?/LX0#*^>3IZOSR
M`,\@ZOGDZ>K\\B#<Z^OA[N4@X^GA(/3O[2#W\=[S].<@)7,@X?#\(/3O(//T
MX>CL_"`E<P#+W.CO\B#J^>3IZOSR`,'PX>GTY=_TX>D@ZOGDZ>K\\B#CZ>$@
MX?7HY>WTZ>KO\._?Y_/G(%)!1$E54RX`ROGDZ>K\\B#LY2#E\.GBY>+AW_GS
MYP#*^>3IZOSR.@#*^>3IZOSR.B``SR#J^>3IZOSR(/#QW?#EZ2#MX2#TX>GQ
MZ=SFY>DN`,O?\_3A(-#E\>'S[-WM^>T@X^7C[^W\]/GM`,7PZ>K\Z^OG\^<`
MQ?#IZOSKZ^?SYR#A\/P@].\@8VQI<&)O87)D`,3IX>3Q[^S>`,7?\^_D[^D@
M\._U(.7JZO'E[._][3H`P>WH\?GP[^D`T._S[_/T_`#%ZO3=Z^7SYR#+Y>GT
M[_7QX^G^[2#3]>WTWO'G\^?R`,7J]-WKY?/G(,OEZ?3O]?'CZ?[M(-/U[?3>
M\>?SY_(@ZN'TW"#TY^T@Y=_S[^3O.P#%[N_U\^GOY/STY_/G`,7N[_7SZ>_D
M_/3G\^<@X^GA("<E<R<@Y.4@Y.GAX_'<]N?JY2X`Q.GA]^7?\>GSYR#%[N_U
M\^GOY._TWO/E^>T`Q>[O]?/I[^3O]-[SY>GR(./IX0#0\>_S^?#IZMWR(/#K
MY_'O]N_QW^7R`,KA]._IZM_DZ>$`U.?KW?;Y[>\`UOGT[^/QX?;?Y?(`Q>GJ
M[^WO\_3OZ??EW^$`RN_I[>_T]?#?Y?(`T.'QX>KAZ_X@ZMSM].4@ZNOIZB#S
MY2#JW/#OZ>\@ZN7KWP#0X?'AZN'K_B#E\.GBY>+AZ?[S].4@_/3I(.C=Z^7T
MY2#MX2#DZ>'C\=SXY?3E(.'U]/P@].\@\_3OZ??EW^\Z`-#A\>'JX>O^(.7P
MZ>+EXN'I_O/TY2#\].D@Z-WKY?3E(.WA(.'P[_/U[>3=\^7TY2#A]?3\(/3O
M(//T[^GWY=_O+@#0X?'AZN'K_B#D_O/TY2#LWNWA(.KAZ2#=]._R+@#0X?'A
MZN'K_B#D_O/TY2#=[>$@_.WO[.$@X^GA(/3G(.W=X2#JX?3GX^_QW^$Z`-#A
M\>'JX>O^(.3^\_3E(.SIX2#=X^KU\><@25`@Y.GE_>CU[?/G+@#0X?'AZN'K
M_B#D_O/TY2#LZ>$@W>/J]?'G(.?LY?'O[.?MW^$L(.7KW>[TY2#T[^T@X?'I
MZ.S\(/3Y[2#G[.7Q_NT@]._U(.S>[>$N`-#A\>'JX>O^(.3^\_3E(-WCZO7Q
MYR#^\>$N`-#A\>'JX>O^(.3^\_3E(/3O(.W=[R#J^>3IZOP@\^'R`-#A\>'J
MX>O^(.3^\_3E(.SIX2#PY?'?Z^?XYR#T[_4@\/'OXNO>[.'T[_(N`-#A\>'J
MX>O^(.3^\_3E(/3O[2#J^>3IZOP@\^'R`-#A\>'JX>O^(.3^\_3E(/3O(+SM
M[^SA(-?QWO/TYP#0X?'AZN'K_B#D_O/TY2#T[R#\[>_LX2#JX>D@]._M(.KY
MY.GJ_"#SX?(`T_7L\.OG\?[S].4@].\@_.WO[.$@]_'>\_3G(.SE(/3O[2#T
M[^S=X2`H0&5R;6ES+GED="D`T.'QX>KAZ_X@Y.GAXMSS].4@].\@X>K\Z^_U
MZ.\@ZN7?[.7O[2X@T/'=\.7I(.WA(//U[/;Y[>7?].4@[.4@]._U\B#\\>_U
M\B#CZ>$@[>$@]_'G\^GL[_#OZ=[SY?3E(.'U]/P@].\@\_WS].?LX2X`T.'Q
MX>KAZ_X@Y.7?].4@].GR(.'J_.OO]>CE\B#PZ^?Q[_;O\=_E\B#JX>D@Y?#I
MZ]WN].4@[.GA(.7MW?'CY>GA(.'P_"#T[R#PX?'AZMST^2#LY>WO_2X`T.'Q
MX>KAZ_X@Y?#IZ]WN].4@[.GA(.7MW?'CY>GA(.'P_"#T[R#PX?'AZMST^2#L
MY>WO_2X`T.'QX>KAZ_X@Y/[S].4@].\@_.WO[.$@].?R(.W=X?(@ZN'TY^/O
M\=_A\CH`T.'QX>KAZ_X@Y?#IXN7BX>G^\_3E(/3O(.W=[R#J^>3IZOP@\^'R
M`,C=\^<@X?7TWO(@].?R(.7IZOSMX?(`U._P[^CE]/[M].'R(.'U]/P@]._M
M(/#?[>'JX0#!\._S]._KWB#SY2#A]?3\(/3O(/;<ZN7K[R`HY.7M(/7P[_/T
MY_'?YN7TX>D@X?#\(/3O($E-05`I`,WA(/#Q[_3<\_/O[?3AZ2#D_>\@\.']
MZ^7R(/#QW^T@].?M(/7P[^/QX?;>(//A\B`H)RTM)RD[`,KA].'J\=[L[>GS
MYR#CZ>$@].GR(/3EZ^7U].'?Y?(@)7,@_O'A*.7R*3H@`%!R969S7VQD87`Z
M(,3E(.+QW>CGZN4@YR#A\.'I]._][.7MYR#E\-WJ].'SYR!,1$%0+@!0<F5F
M<U]S97-S:6]N.B#$Y2#B\=WHY^KE(.<@X?#AZ?3O_>SE[><@Y?#=ZO3A\^<@
M\_7MY>3QW^'R+@#0X?'O]?/IW//EZ?(`T-_E\^<`T-_E\^<@\_3O(.7PW_#E
MY.\@].?R(.C<Z^'S\^'R.B``T-_E\^<Z(`#0\>_E\.GSZOSPZ?/G`-#Q[^7P
MZ?/J_/#I\^<@].?R(.7IZOSM[^'R(//E(.W=[R#PX?'<Z/7Q[P#0\>_GX^_]
M[.7MYR#3Y>O?Y.$`T/'OY^/O_>SE[>7R(,7PZ>OOX]WR`,7J]/WP^?/G(.7C
MX_'<]N_U`-#Q[_/Y\.GJ_"#*Z^7IY-\`T/'\XNOG[.$`T.7QZ>/QX?;>(-#Q
M[^+KWNSA]._R`+CQX^\@*'!R;VIE8W0I`,KEW^SE[>\@\/'O]/'O\-[R`,3G
M[/SSZ>\@RNOEZ>3?`,'KX_SQZ>CL[_(@Q.?L_//I[_4@RNOEZ>3I[_T`U.\@
MYN7]X^_R(,3G[/SSZ>_U+]#Q[_/Y\.GJ[_T@ZNOEZ>3I[_T@Y.4@Y.?LZ>_U
M\>/>Z.?JY2#E\.GT]??^\BX`Q?'^].?SYP#$Y^S\\^GO(,KKY>GDWR!24T$@
M*"5D($)I="D`Q?#IZ^_CWR#E[?SR`-3U]^'?X2#0\?SBZ^7XYP#+_./O\@#!
M[=SC[?GSYP#![=SC[?GSYR#LY^W][.'T[_(`Q=_S].4@XMWBX>GO\B#CZ>$@
M].<@Y.GAX_'A]MX@)7,[(,'U]/P@Y.7M(.SP[_'EWR#MX2#E\.'MW>OHY>DN
M`,7?\_3E(//?X^_U\>_R(./IX2#TYR#DZ>'C\>'VWB#T^>T@Y.7D[^S=[?GM
M(/3O]2#W\=[S].<@)7,[(,'U]/P@Y.7M(.SP[_'EWR#MX2#E\.'MW>OHY>DN
M`,7PX>WEZO3=Z^7SYR#TY_(@].7KY?7TX=_A\B#E\>/A\]_A\B#SX?(`P>WA
M[=WY\^<@]/GM(.3U[>'LZ>K^[2#S]._I]^7?^>T@]._U(,SE[>_].@#![>'M
MW?GSYR#TY_(@Y>SVW.WI\^?R(/3O]2!0;W)T86PZ`,'MX>W=^?/G(/3G\B#0
M\>_B[^O>\B#0Y?'?Z^?XY_(Z`%)E9V5X`,7L]MSMZ?/G(-/WW?/E^>T`T_?\
MZ^GA`,'P[^SMY^S\[>7U\^<@\.OG\>_V[_'I_NT@Y.GAZ.7SZ>S\].?TX?(N
M`,'P[^SAZO'U\^S=[>_I(,7N]?#G\>7TY_3=\@#!\._LX>KQ]?/LW>WG(.3I
MY?WH]>WSYR`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`,'VX=_Q
MY?/G`,'VX=_QY?/G(,SPZ_SJ`,'VX=_QY?/G(-/TWNOG\@#!]N'?\>7SYR#L
M[_'V[_#OW^?SY_(`P?;AW_'E\^<@X?#\(/3O(.?LY?'OZ_SCZ?P@[._U`,'V
MX=_QY?/G(.;E_>/O]?(`P?;AW_'E\^<@X?#OZ.?JY?7LW>WO]2!S8W)I<'0@
MX?#\(/3O[2#P\>_S^?'I[?P@ZN'TW.OOX^\@]._U(.7N]?#G\>7TY_3>+@#!
M]N'?\>7SYR#T[_4`P?;AW_'E\^<@X?7T[_T@]._U(.K\[.+O]2#A\/P@].\@
MW>/C\>'V[P#$Z>'C\>'VWB#W\=[S].<`Q.GAX_'A]MX@U_'>\_3G.B`E<P#3
M]-SKZ.?JY2#!\-SM].?SYRX`P?#<[?3G\^<@[.4@S,<@]?#O\_3G\>GF_.SE
M[>\@[-[M]>SA+@#!\-SM].?SYR#LY2#PZ^?Q[_;O\=_E\B#DZ>'HY?/I[/ST
MY_3A\B#CZ>$@]._U\B#E\/SLY>WO]?(@Y/WO(.S>[>7R+@#!\-SM].?SYR#L
MY2#TZ?(@YN?T[_WLY>WE\B#PZ^?Q[_;O\=_E\B#DZ>'HY?/I[/STY_3A\BX`
MP?#<[?3G\^<Z("5S`-3O(.'?].?LX2#DY2#L\._QY=\@[>$@X?#A[?3GZ.7?
M+B#%\.GS]/'E]OSLY>WO\B#J^>3IZOSR(.O<Z._U\CH@`-3O(.'PX>GT[_WL
MY>WO("<E<R<@Y.7M(.KAZ._QW_/HY^KE(//T[R`E<R!C;VYF:6=U<F%T:6]N
M+@#4[R#A\.'I]._][.7M[R`G)7,G(.3E[2#JX>CO\=_SZ.?JY2#S].\@5D93
M(&-O;F9I9W5R871I;VXN`-3O(.'PX>GT[_WLY>WO("<E<R<@Y.7M(.KAZ._Q
MW_/HY^KE(//T[R!C;VYF:6=U<F%T:6]N+@#4[R#A\.'I]._][.7M[R`G8F%S
M961N)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(.'UZ.7M
M].GJ[_#OW^?SY_(N`-3O(.'PX>GT[_WLY>WO("=B87-E9&XG(.3E[2#=]^7I
M(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@]/GM(/#Q[_3I[-[SY?GM+@#4
M[R#A\.'I]._][.7M[R`G9&%T86)A<V4G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@
M\_3I\B#Q]>CLW_/EZ?(@X?7HY>WTZ>KO\._?Y_/G\BX`U.\@X?#AZ?3O_>SE
M[>\@)V1A=&%B87-E)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_S
MY>GR(.KA].?C[_'I_NTN`-3O(.'PX>GT[_WLY>WO("=D871A8F%S92<@Y.7M
M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#T^>T@\/'O].GLWO/E
M^>TN`-3O(.'PX>GT[_WLY>WO("=H;W-T<W!E8R<@Y.7M(-WWY>D@ZN'H[_'I
M\_3EWR#S].GR(/'UZ.S?\^7I\B#A]>CE[?3IZN_P[]_G\^?R+@#4[R#A\.'I
M]._][.7M[R`G:&]S='-P96,G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q
M]>CLW_/EZ?(@ZN'TY^/O\>G^[2X`U.\@X?#AZ?3O_>SE[>\@)VAO<W1S<&5C
M)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(/3Y[2#P\>_T
MZ>S>\^7Y[2X`U.\@X?#AZ?3O_>SE[>\@)W!A<W-W;W)D)R#DY>T@W??EZ2#J
MX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(.'UZ.7M].GJ[_#OW^?SY_(N`-3O
M(.'PX>GT[_WLY>WO("=P87-S=V]R9"<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S
M].GR(/'UZ.S?\^7I\B#JX?3GX^_QZ?[M+@#4[R#A\.'I]._][.7M[R`G<&%S
M<W=O<F0G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@]/GM
M(/#Q[_3I[-[SY?GM+@#4[R#A\.'I]._][.7M[R`G<&AP='EP92<@Y.7M(-WW
MY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#A]>CE[?3IZN_P[]_G\^?R
M+@#4[R#A\.'I]._][.7M[R`G<&AP='EP92<@Y.7M(-WWY>D@ZN'H[_'I\_3E
MWR#S].GR(/'UZ.S?\^7I\B#JX?3GX^_QZ?[M+@#4[R#A\.'I]._][.7M[R`G
M<&AP='EP92<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#T
M^>T@\/'O].GLWO/E^>TN`-3O(.'PX>GT[_WLY>WO("=T86)L92<@Y.7M(-WW
MY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#A]>CE[?3IZN_P[]_G\^?R
M+@#4[R#A\.'I]._][.7M[R`G=&%B;&4G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@
M\_3I\B#Q]>CLW_/EZ?(@ZN'TY^/O\>G^[2X`U.\@X?#AZ?3O_>SE[>\@)W1A
M8FQE)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(/3Y[2#P
M\>_TZ>S>\^7Y[2X`U.\@X?#AZ?3O_>SE[>\@)W5I9"<@Y.7M(-WWY>D@ZN'H
M[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#A]>CE[?3IZN_P[]_G\^?R+@#4[R#A
M\.'I]._][.7M[R`G=6ED)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H
M[-_SY>GR(/3Y[2#P\>_TZ>S>\^7Y[2X`U.\@X?#AZ?3O_>SE[>\@)W5S97)N
M86UE)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(.'UZ.7M
M].GJ[_#OW^?SY_(N`-3O(.'PX>GT[_WLY>WO("=U<V5R;F%M92<@Y.7M(-WW
MY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#JX?3GX^_QZ?[M+@#4[R#A
M\.'I]._][.7M[R`G=7-E<FYA;64G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I
M\B#Q]>CLW_/EZ?(@]/GM(/#Q[_3I[-[SY?GM+@#!\.'I]._][.7M[R#0Y>3?
M[P#!\.'I]._][.7M[_(@T_7L[.7TW??Y[0#%\.'MX?;O\=P`P>OKX>/>(,KY
MY.GJ[_T`P>OKW.[TY2#T[^T@ROGDZ>K\(//A\@#!\._TY>O=\^SA].$`Q?#I
M\_3Q[_;>(//TZ?(@Q?#IZ^_CW?(`Q?#I\_3Q[_;>(//TY^T@X>OKY^OOX_'A
M]M_A`,7PX>W=[?GSYP#%\.'MX?;O\=P@0V]N9FEG=7)A=&EO;@#!Y?'OZ^GL
MW>WA\B#1_.3O]0#%\.GK[^/=\B#E\.7NY?'CX?/TWB#E[/#K[_7TZ?/LW>WO
M]2#JY>GLW>WO]0#!Z>W?X^SA].$`Q.7NZ=P`Q.7NZ=P@Y?#IZN7VX>O?Y.$`
MQ.7NZ=WR(/3I[-WR`,GDZ?STY_3E\B#C\>'L[-[R+BXN`-'\Z^_R`-#E\>GS
M]/'O]MX@,3@PL`#0Y?'I\_3Q[_;>(,'QZ?/TY?'<`-#E\>GS]/'O]MX@Q.7N
MZ=P`R>3I_/3G].7R(,/QX>SLWO(`R>3I_/3G].7R(,/QX>SLWO(`P_'A[.S=
M\CH`RN'M_.WE\@#/Z2#JX>W\[>7R(.CA(.7L]N'MW^;O[?3AZ2#LY?3A[OT@
M_.OY[2#T^>T@X_'A[.S^[2#JX>D@]/GM(//TY^O^[0#/Z2#JX>W\[>7R(.CA
M(.7L]N'MW^;O[?3AZ2#LY?3A[OT@]/GM(//TY^O^[2#L_.WO`,_I(.KA[?SM
MY?(@Z.$@Y>SVX>W?YN_M].'I(.SE].'N_2#T^>T@X_'A[.S^[2#L_.WO`,7J
M]-WKY?/G`-7P[^/QX?;>(,KQ]?#T[^/QW/;G\^?R(%,O34E-10#*\?7P]._C
M\>'VY^S=[>\@[-[M]>SA(%,O34E-10#'(.'UZ.7M].GJ[_#OW^?SYR!305-,
M(.3E[2#EW^WAZ2#DZ>'HW?/I[.<N`,SG[?WLX?3A(%--4P!344P@RMWK]?;O
M\@#%T,G4U=?9TP!37U%,(,K=Z_7V[_(`T^$`NN3I[R#PZ^'?\^GO("A?<V5L
M9BD`P>7Q[^OI[-WMX?(@T]SL[_4`T-SQ[_?O\B#$[_'U]OSQ[_4`P?#OZ-[J
MY?7SYP#!\._HWNKE]?/G("5S`,'P[^C>ZN7U\^<@)R5S)P#!\._HWNKE]?/G
M(,7PZ>OOX_[M`,'P[^C>ZN7U\^<@]._U(&-O;F9I9W5R871I;VX@\._U(.3G
M[.GO]?'CWNCGZN4@\^'M(%!(4"!38W)I<'0@\_3O[2#P\>_S^?'I[?P@ZN'T
MW.OOX^\@]._U(.7N]?#G\>7TY_3>+@#!\._HY^KE]>S=[>\@)7,@8V]N9FEG
M=7)A=&EO;BX`U.\@<V-R:7!T(.7MY^S=\?GSY_(@].\@<V5T=7`@X?#OZ.?J
MY?WHY^KE(//T[SH@)R5S)RX`Q?#I\_3>[.<`P>WAYM[TY_/G`,SG]^'MW?(@
MP>WAYM[TY_/G\@#![>'FWO3G\^<@S.?M]>S<]/GM`,'P[_3EZ]WS[.'TX2#!
M[>'FWO3G\^?R`,7PZ>OOX]X@P?'WY=_Y[0#%\.GKW>[TY2#LZ>$@Y^SE\>_L
MY^W?X0#%\.GKW>[TY2#O[-SDX2#CZ>$@\/'O\^C>ZN<`Q?#IZ]WN].4@[=WO
M(,GDZ>_J]-[TYP#%\.GKW>[TY2#E[O7PY_'E].?TW@#%\.GKW>[TY2#W\=[S
M].<@X^GA(/#Q[_/HWNKG`,7PZ>OOX]X@_.OY[2#T^>T@Y^SE\>_LY^WI_NTN
M`,7PZ>OOX]X@Y>W\\B#A[?3IZN7I[-WM[_4`Q?#IZ]WN].4@]._U\B#WX?'A
MZO3>\>7R(/#O]2#HW>OE].4@X?#\(/3I\B#PX?'AZMST^2#KW_/TY?(N(,KA
M]/SPZ>WL\._QY=_TY2#MX2#TX2#A[?3IX_'<^.7TY2#JX>D@[>$@].$@Y?#I
MZN_KZ][SY?3E(//T[R#LWNWU[.$@\^'R+@#%\.GK[^/>(/3O]2#DZ>'W^?'I
M\_3>(.?LY?'O[.?MW^'R.@#%\.GK[^/>(/3G\B#L[_'VWO(@\._U(.CA(-WW
MY>D@YR#G[.7Q[^SG[=_A.@#%\.GKW>[TY2#TYR#TX?7T_/3G].$@\._U(.C=
MZ^7TY2#MX2#AZ^O<[N7TY3H`Q?#IZ]WN].4@].\@Y.GA]_GQZ?/TWB#^\>'R
M.@#%\.GKW>[TY2#TYR#L[_'VWB#P[_4@Z.$@W??EZ2#G(/[QX3H`Q?#IZ]WN
M].4@Y/WO(/#EY-_A(/#O]2#TX>GQZ=SF[_7M+@#%\.GKW>[TY2#T[R#W\?GL
MX?3IZOP@)_/WWNSA)RX`Q?#IZ]WN].4@].<@X^O^\_/A(//A\CH`P?#O\_3O
MZ]X@]/GM(/#I[R#P\?SS]N'T^>T@\.OG\>_V[_'I_NT`P?#O\_3OZ]X@P>WA
M]N_QW/(@T/'OXNO>[.'T[_(`P?#O\_3OZ]X@4TU3`,'I\^CG]-[QX?(Z(`#3
MY?#TW>SB\>GO\@#3Y>GQZ>'J_/(@P?'IZ.S\\@#4[R!)1"#TY_(@\_WMY.7S
MY_(@W>OG[N4N`,C=\^4`R-WS].4@Y?#IZ^_CW?(@\._U(.CA(//A\B#E\.GT
M\=WP[_7M(.WA(.'KZ]SFY?3E(/3O[2#J^>3IZOP@\^'R+"#AZOSLYR#JX>D@
MX>T@]._M(-WWY?3E(.[E]]SSY>DN`-#A\>'LY?3Q[_#OW^?SYR#A\._LX>KQ
M]?/LW>WY[2#E[O7PY_'E].?T_NT@\._U(.C=Z^7TY2#P\?SSXN'SYRX`T?7H
M[-_S].4@Y.G<]N_QY?(@Y?#IZ^_CW?(@Y>SVW.WI\^?R(.KAZ2#T[R#W\?SM
M[R#A[>'MW?GSY_(@]/GM(//EZ]_D^>TN`,7PZ>OOX]X@].?R(/#Q[_3I[._]
M[.7MY_(@X^O^\_/A\BX`RN'H[_'?\_3E(/3G[2#P\>_TZ>S^[.7MYR#CZ_[S
M\^$L(.;^[><@_O'A\B#JX>D@[._Q]MX@Y^SE\>_LY^W?X?(N`,KAZ._QW_/T
MY2#TY^T@Y?;A\>SOX]X@Y>KJW^WG\^?R+"#TX2#P\>_TZ>S^[.7MX2#W\?[L
MX?3A+"#TYR#PY?'?[^3O(.'MX>W=^?/G\B#TY_(@\^7KW^3A\B#JX>D@W.OK
MY?(@Y?#IZ^_CW?(@Y>SVW.WI\^?R+@#1_>CLZ?/G`,7?[>'I(.3IX>C=\^GL
MX2!38W)I<'1S(.7MY^S=\?GSY_(@\?7H[-_SY?GM`-#OZ^O=\B#T[_#OZ.7S
MW^7R(.7?[>'I(/#IZ.'MW?(@[.4@X?7TWB#TYR#PX?'<[.7T\>\Z(`#!X^_Q
MW?(`T_WM]._LYR#0Y?'?Z^?XYP#3_>WT[^SG(-#E\=_KY_CG.@#0\=WPY>D@
M].\@ZNOEZ>3?(/#Q_//BX?/G\B#MX2#O\>GSZ.7?(./IX2#PY?'I\_/\].7Q
MY?(@\_7MY-WSY>GR.P#%[/;<[>GSYP#%[/;<[>GSYR#DZ>'V[_'^[2#LY?3A
M[OT@]._U(.'P[^CGZN7U[-WM[_4@ZN'I(/3O]2#DY^SI[_7QX^?HW>WT[_(@
M8V]N9FEG=7)A=&EO;BX`Q>SVW.WI\^<@].?R(/[QX?(@].7KY?7TX=_A\B#E
MZ?/\Y._U(/STX>T@[/#AW^WO]>SE(//T[R#S_?/TY^SA.P#%[/;<[>GSYR#E
M\.GK[^/>\B#CZ>$@X?#OZ-[JY?7SYR#T[_4@X?7HY>WTZ>KO_0#%[/;<[>GS
MYR#S]>OKW>KTYP#-X2#E[/;A[=_FY?3AZ2#T[R#LY>WO_2#LY2#E\>/A\]_E
M\B#PW^WAZN$[`,7L]MSMZ?/G(/3O]2`E<R#,Y>WO_2#S].$@X?'I\_3E\=P[
M`,7L]MSMZ?/G(/3O]2#DZ>'K_./O]2#)Y.GO]-[T^>T@RN7KZ?[M(-#?[>'J
MX0#%[/;<[>GSYR#T[_4@Y.GAZ_SC[_4@R>3I[_3>]/GM(-#?[>'JX0#%[/;<
M[>GSYR#T[_4@Y.GAZ_SC[_4@R>3I[_3>]/GM(,/QX>SL_NT@T-_MX>KA`,7L
M]MSMZ?/G(/3O]2#DZ>'K_./O]2#)Y.GO]-[T^>T@Q>GJ_.WA\@#%[/;<[>GS
MYR#V_/'T^?/G\B`H=7!L;V%D*0#3]?'QW^KM^?/G`-#Q_O3A(//U\?'?ZNWY
M\^<@WB#LY?3AZM_MY_/G(./EZ?3O[>GJ_NT@].SG[-ST^>T`Q=_S[^3O\BW5
M\._C\>'VW@#'(,7?\^_D[_(MU?#OX_'A]MX@Y.7M(-WWY>D@ZN'TX??Y\>?H
MY=\N`-7P[^/QX?;>`,'KX_SQZ>CL[_(@U?#OX_'A]M[R`,S=X^7H[_(`P>K]
M\?GSYR#3]>WTWO'G\^?R`,SE\>GJW"#A\/P@].$@X?'WY=_A(.3IX??EW_'I
M\^?R(/3O]2!(;W)D92#=]^_U[2#WX>CEWSH`Q?#IZ^_CWB#JX?3E_>CU[?/G
M\B#TX>[I[?SLY_/G\@#!Y?'OZ^GLW>WA\B#3[_WDX?(`Q.GE_>CU[?/G(-#G
MX][R`,W\].GO(,?LZ?/VX=_QZ>\`Q.G<\_3G[.$@[.7TX>[](./EZ?3O[>GJ
M_NT@ZN7KZ?[M`,3IW//TY^SA(.SE].'N_2#PY?'IY??O[-WM[_4@ZN'I(./Q
MX>SLWO(@ZN7KZ?[M`-#KWNKT\>\@Q.GA\_3>[.'T[_(`P?'AW_GSYP#!\>'?
M^?/G(.KAZ2#CW>SI\^SA`%-P86T`Q>GSX>/YX]X@Q>GDZ>K^[2#7X?'AZO3>
M\?GM`,3IX=_QY?/G(.KEZ^GO_0#$Z>'?\>7SYR#S]-[KY_(`Q.GAW_'E\^<@
MX_'A[.S>\@#!Z.O>[.'TX0"X[>'Q[N<`N/3O\B"X[>'Q[N?R`-#OZ^GTY=_A
M(-X@Q?#A\???X0#*X?3<\_3A\^<`S._Q]MX@X?#OZ-[JY?7SY_(`Q.GE_>CU
M[?/G+<_D_/(`Q.GAX_'A[.SI\^S=[>$`R]_S].$@Z]WNY?GM`,'VX=_QY?/G
M(/3O]2!D;VUA:6X@X?#\(/3G(.3IY?WH]>WSYP#3]/WK(%M#4U-=`,KU`,\@
M]?#O]MSJY>OO\B`G)7,G(.3E(.+QW>CGZN4N`,C=[.$`R-WLX2`GT.OG\>_V
M[_'?Y?(@Q.?L_//I[_4@RNOEZ>3I[_TG`,'P[_/T[^O>`-3O(.'?].?LX2#C
MZ>$@\/'O\^C>ZN<@)R5S)R#S].\@\_WS].?LX2#A\.7S]-SKYRX@Q.4@[/#O
M\>7?].4@[>$@[N'MX>SPY=_TY2#LW??QZ2#MX2#EX^KQZ>CEWR#T[R#AW_3G
M[-P@\^'R+@#5\._DY=_J].?R`,7PZ?3U]]_A`,7PZ?3U]][R(/#Q[_/HWNKG
M("<E<R<@\_3O(//]\_3G[.$N`-3A(.3EY._LW>WA(/3O]2#W\=[S].<@)R5S
M)R#DZ>'C\=SVY^KA[2#E\.GT]??^\B#A\/P@].\@\_WS].?LX2X`Q?#I]/7W
MWO(@Y.GAX_'A]MX@)R5S)RX`Q?#I]/7WWO(@Y.GAX_'A]MX@)R5S)R#A\/P@
M].\@\_WS].?LX2X`S^D@\?7H[-_SY>GR(.7PX>WA]MWQZ.?JX>T@Y?#I]/7W
M_O(N(,K<[?3E(.7PX>WA]OSQ]/GSYR#CZ>$@[>$@Y.7?].4@].GR(.'KZ^'C
MW?(N`,7PZ?3U]][R(.7P[^C>ZN7U\^<@Y?;EY/'IZN_](&-O;F9I9W5R871I
M;VXN`,7PZ?3U]][R(.'P[^C>ZN7U\^<@]._U(.7VY>3QZ>KO_2#A\??EW^_U
M(&-O;F9I9W5R871I;VX@)7,N`,7PZ?3U]][R(.7MY^S=\?GSYR`G)7,G`,7P
MZ?3U]][R(.7CX_'A]MX@)7,`T_WM[_CG("T@T.7QW^OG^.<`P>WA]._KW@#$
M_?/G`,'MX?3OZ]X`P>WA]._KWB_$_?/G`,'MX?3OZ]XZ(`#$_?/G`,3]\^<Z
M(`#5\.7QY.7?ZO3E\@#5\._S]-[QZ>[G`,7PW^CE].\`U.\@X?'WY=_O(.KA
M].'C\>'VWO(@\_7C]_'O[>GS[._](.3IX>/QW/;GZN4`4WEN8TU,`,O<Z._R
M(//][?3A[N?R(//T[_7R(/SQ[_7R(.'MX>;>].?SY_(`T-_MX>KA\@#)Y.G\
M].?TY?(@T-_MX>KA`,GDZ?STY_3E\B#0W^WAZN$`P>7Q[^OI[-WMX?(@U.'M
MW./QX?(`T_3\]^_R.@#%\>/A\]_E\@#!Y?'OZ^GLW>WA\B#4X?3O^N_U`,'Q
MZ>CL_/(@U.?KY?;^[>_U`,CE\>SOZO'A\]_A(/3G[2#TY>OE]?3AW^$@_O'A
M.B``R.7Q[._J\>'SW^$`R.7Q[._J\>'SW^$Z(`#4[R#P\?ST]?#O("<E<R<@
MY.4@XO'=Z.?JY2X`Q.GA]^7?\>GSYR#0\>_T_?#O]0#0\>_S^?'I[=X@P?#O
MY._WWB#AZ?3>[.'T[_(`T/'O\_GQZ>W<(,'P[^3EZO3\`,KEW^SE[>\`S/SM
M[R#*Y=_LY>WO`-/T[]_WY_/G(.KEZ>S=[>_U`,KO\?7VWB#JY>GLW>WO]0#4
MY0#%]??A\>GS]._][.4@\._U(/?QY_/I[._P[^G>\^'TY2#T[R#3_?/TY^S<
M(.SA\BX`QR#E\-WJ].'SYR!&5%`@Y.7M(.7?[>'I(.'J_.SG(.3IX>C=\^GL
MYRX`U.\@\_WS].?LX2!(;W)D92]+;VQA8B#DY>T@]?#O\_3G\=_FY>D@(B5S
M(@#$Z>'WY=_QZ?/G.CH@QR#JZ]SSYR#DY2#V[_'T_NCGZN4@Y?#I]/7W_O(`
MU.\@\.'QW.CU\>\@Y?#IZ^_C_NT@W>KKY>GSY2X@N.[OY._R+@#/(.3IX??E
MZ?'I\_3>\B#P\=WPY>D@[>$@\?7H[-_SY>D@W>WA(.S\[>GL[R#PZ^'?\^GO
M(,7N[_7SZ>_D[_3>\^7Y[2P@X^GA(.WA(.SP[_'EW_3E(.WA(/?QY_/I[._P
M[^G>\^7TY2#E[N_U\^GOY._TWO/EZ?(N`,<@ZMST^2#PZ^7U\=P@[/SM[P#4
MX2#DY>3O[-WMX2#G[.7Q[^OOX]_O]2#DY>T@Y=_MX>D@W>/J]?'A`-3O($E$
M(/3G\B#E\.'VWO(@Y.7M(.KAZ._QW_/HY^KE+"#>].'M(.KE[?P@WB#DY2#B
M\=WHY^KE(//TYR#BW//G(.3EY._LW>WY[2X`QR#E\.'VWB#P\>_S]-WHY^KE
M(.7PZ?3U]_[R(//T[R#$Z>7UZ/7M\^GOX_'<]N\@\^'R+@#4[R#T[-[LX2!0
M1U`@\._U(.'P[_/PW//HY^KE(.'PX>GTY=_T[R#CZ>$@].?M(.7PX>O>Z.7U
M\^<@]._U(/7P[^/EX_'A[.S=[>_U(.SG[=[LX?3O\BX`U.\@240@].?R(.O?
M\_3A\B#DZ>'M[^S>\B#DY>T@[_'?\^CGZN4L(-[TX>T@ZN7M_"#>(.3E(.+Q
MW>CGZN4@\_3G(.+<\^<@Y.7D[^S=[?GM+@#'(.O?\_3A(.3IX>WO[-[R(.3E
M[2#JX>CO\=_SZ.?JY2X`S^D@Y/7MX?3\].?TY?(@ZO'U\/3OX_'<]N?SY_(@
MX?#AZ?3O_>T@X?/VX>O>(//][>3E\^<@5T5"+@#4[R#CY>/O[?SR(/#Q[_/T
MW>CGZN4@\_3O(.?LY?'OZ_SCZ?P@\^'R+@#4[R#A\??EW^\@)7,@\/'=\.7I
M(.WA(/#E\>G=]^7I(.SIX2`E<R#Q_>CLZ?/G+@#4[R#A\??EW^\@)7,@\/'=
M\.7I(.WA(/#E\>G=]^7I(.K<\._IY?(@)7,@\?7H[-_SY>GR+@#4[R#A\??E
MW^\@Y.4@[/#O\>7?(.WA(.'M].GC\>'VY=\@\_3O[2#EX?7T_"#T[_4N`-3O
M(.'Q]^7?[R#DY>T@\.7QZ=WWY>D@Y.7D[^S=[>$N`-3A(/#A\>'JW/3Y(.7?
M[>'I(.7PZ>KE]N'KW^3E\B#CZ>$@X?7T_"#T[R#LWNWU[.$O<F9C.#(R(.S>
M[?7LX2X`QR#JX?3<\_3A\^<@\.O>\>_U\B#OZ/SMY_(@Y=_MX>D@X^WY\_3\
M(/STZ2#DY^SI[_7QX^7?(/#Q_.+KY^SA(.SE(/3O[2!);G1E<FYE="!%>'!L
M;W)E<BP@Y>[AZ?3?X?(@\/'OXNOG[-ST^>T@*&)U9W,I(/3O]2!B<F]W<V5R
M+"#TX2#O\._?X2#DY>T@Y=_AZ2#D]>WA]/P@[>$@[N7PY?'A\^CO_>TN(,SP
M[_'EWR#MX2#DY=_TY2`G\^KO]?#?Y.GA)R#S].?M(._H_.WG+"#P\>_BZ][L
MX?3A(//TYR#KY>GT[_7QX]_A(/3O]2!B<F]W<V5R(-X@ZN'I(.K\Z^?LW"#T
M[_4N(,'M(/3O(//]\_3G[-P@\^'R(.7?[>'I(%=I;F1O=R`Y>"#EW^WAZ2#P
M[^O](/#IZ.'M_"#MX2#DY=_TY2`GP^7MZ>K>(,'P[_3U]]_A(-#Q[_/TX?/?
MX?(G(.KAZ2#MX2#P\=WPY>D@[>$@Y?#A[>7JZNGMWO/E].4@*')E8F]O="DN
M7&Y<P?7TWB#EW^WAZ2#P\>_EZ>3O\._?Y_/G+B#0X?3>\_3E(,_*(.'M(.C=
MZ^7TY2#AZOSLYR#MX2#D[_7KW?CE].4@\^4@ZN'TW//TX?/G(/#KWO'O]?(@
M[^C\[>?R+@#'(/3A]?3\].?TX2`B)7,B(.3IX>/QW/;GZN4N`,<@X?'I\_3E
M\=X@\.OE]?'<(.S\[>\`QR#HW?/G(/3O]2#P\>_C\=SL[.'T[_(@1VYU4$<@
M\/'=\.7I(.WA(.3OZ.7?(./IX2#TYR!#<GEP=%]P9W`Z.B#JZ]SSYRX`QR#C
M\>'L[.'T[^CU\=_DX2`GZMSD[_(G(.7?[>'I(-[DYR#<Y.7IX2X`U.\@[-[M
M]>SA(/#O]2#S]-SKZ.?JY2#S].GR("5S(//T[^T@)7,@[.4@Z-WLX2`E<R#E
M[/;A[=_SZ.?JY2X*P?7T_"#DY>T@X?#O].7KY=\@Y?#IXN7BX=_Y\^<@_/3I
M(.3IX>+<\^CGZN4@ZN'I(-WCZ>WE(.KA].'M[^?T_"X`U.\@_.WO[.$@\._U
M(.CA(/?QY_/I[._P[^GEW_3AZ2#\].'M(//U[>3=Y?/TY2#S].<@\^7KW^3A
M(//][>CE\^?R+@#'(.+IXNOI[^C>ZN<@3W!E;E-33"#A\.'I].7?].'I(./I
MX2!(;W)D95]#<GEP=%]S;6EM93HZ(.KKW//G+@#'(/#Q[_3?[.?SYR`B)7,B
M(.3E[2#L\/SQY?/E(.WA(.'P[^CGZN7UZ.7?(./IX?3?(/3A(.3EY._LW>WA
M(/3G\B#U\.7QXN'?[>_U[2#T[R#LW>/I\_3O(.7PZ?3QY?#T_"#LW>/EZ._R
M`-3O(/#Q_./QX>SLX2#P[_4@]_'G\^GL[_#OZ>7?].4@X^GA(/3G[2#E[/;<
M[>GSYR#A]?3O_2#T[_4@Y=_D[_7R(.SG[?7LW/3Y[2`H)7,I(.3E[2#B\=WH
MY^KE(//T[R#S_?/TY^SA+@#'(')E9VES=')Y(.7?[>'I(.\@]/'\\._R(.SE
M(/3O[2#O\._?[R#OZ2#E]N'Q[._CW?(@]._U($AO<F1E(.7PZ>KOZ>WY[>_]
M[2X@[.7TX>[](/3O]?(N(,7D_B#P\=WPY>D@[>$@X_'<^.7TY2#\].D@Y?;A
M\>SOX]WR(/3O]2!(;W)D92#=]^7TY2#EX^KA].'S]-[SY>DN`,<@X?'I\_3E
M\=X@ZN'I(.3E[NG<(/#KY?7QW?(@[/SM[P#'(.3E[NG<(/#KY?7QW"#L_.WO
M`,\@Y>[U\.?QY?3G]-[R("(E<R(@Y.GAX_'<Y^KE+@#/(.7N]?#G\>7TWO(@
M(B5S(B#A\._HY^KE_>CGZN4N`-3O(.'?].?LX2#EZ?/\Y._U(./IX2`E<R#D
MZ>'C\=SVY^KE+@#'(./QX>SLWB#P[_4@[_'?\^'TY2#DY>T@]?#<\??EZ2X`
MQR#E\>/A\]_A(/#Q[_/TW>CGZN4@\_3G(.O?\_3A(.7QX^'SZ?[M(//A\BX`
MU.\@\/'O\_GQZ>W\(.'Q]^7?[R`B)7,B(.3E[2#U\-SQ]^7I+@#'(/#<[?D@
MZN'I(.K<]/D@\.OE]?'=\B#L_.WO`,<@\-SM^2#PZ^7U\=P@[/SM[P#4X2#D
MY>3O[-WMX2#P[_4@\_3=Z^WA].4@]]SHY^KA[2#A\/P@].\@\/'OY^/O_>SE
M[>\@XM[LX2X`U.\@X?'WY=_O(/#O]2#S].7?Z^'TY2#DY2#L\/SQY?/E(.WA
M(//YZ.7?+@#/Z2#PZ^?Q[_;O\=_E\B#DZ>'HY?/I[/STY_3A\B#A\._HY^KE
M_>CGZN'M(.7PZ?3U]_[R+@#/(.KA]-SK[^/O\B#HY>S<]/GM("<E<R<@Y.4@
MXO'=Z.?JY2X`Q.7M(/7PW/'W[_7M(,7PZ>OOX]WR(.3IX>C=\^GLY?(N`,3E
M[2#U\-SQ]^_U[2#T[-[LX?3A(/#O]2#DY2#L\._Q[_WM(.WA(.7L]N'MZ?/H
M[_WM(.7M\_GLX?3Y[-WMX2X`U?#<\??O]>T@\._KZ^_?(/?A\>'J]-[QY?(@
M\^4@X?7T_"#T[R#PY>3?[RX@Q>GSX>/<X^'TY2`E<R#WX?'AZO3>\>7R+"#P
M\=WPY>D@[>$@]?#<\??O]>T@Z^GC_/3E\>_I(.'P_"`E<RX`T/'\XNOG[.$@
MZN'TW"#TY^T@\/'O\^C>ZN<@)R5S)R#S].\@\_WS].?LX2X@)7,N`-#Q_.+K
MY^SA(.KA]-P@].?M(/#Q[_/HWNKG("<E<R<@\_3O(//]\_3G[.$Z("5S+@#0
M\?SBZ^?LX2#JX?3<(/3G(.3IX>/QX?;>(.3EY._LW>WY[2#T[_4@]_'>\_3G
M("<E<R<@X?#\(/3O(//]\_3G[.$Z(`#0\?SBZ^?LX2#JX?3<(/3G(.3IX>/Q
MX?;>("<E<R<@X?#\(/3O(//]\_3G[.$Z(`#0\?SBZ^?LX2#JX?3<(/3G[2#E
M[>?LW?'Y\^<@)R5S)SH@)7,`T/'\XNOG[.$@ZN'TW"#TY^T@X?#O\_3OZ]X@
MX?'WY=_O]3H@Q.7M(//TW.OHY^KE("5S+@#0X?'O]?/IW//HY^KE(/#Q_.+K
MY^SA(.KA]-P@].?M(.'P[_/T[^O>(/3O]2#A\??EW^_U.B#4[R`E<R#EW^WA
MZ2#LY>/AZ_WTY?'O(.'P_"#T[R#LW>/I\_3O(.7PZ?3QY?#\[.7M[R#LW>/E
MZ._R("@E9"!">71E<RDN`-#A\>_U\^G<\^CGZN4@\/'\XNOG[.$@ZN'TW"#T
MY^T@X?#O\_3OZ]X@]._U(.'Q]^7?[_4Z(-/TW.OHY^KE(.S\[>\@W>WA(/3L
MWNSA(/3O]2`E<RX`T.'Q[_7SZ=SSZ.?JY2#S]MSK[.$@ZN'TW"#TY^T@Y>SV
MW.WI\^<@X?7T[_T@]._U(/3LWNSA]._R(/3O]2#LY^W][.'T[_(N`-#A\>_U
M\^G<\^CGZN4@\_;<Z^SA(.KA]-P@].?M(.7I\^'C^>/>(.3EY._LW>WY[2#$
MZ>7UZ/7M\^GOX_'<]N_U+@#0X?'O]?/IW//HY^KE(//VW.OLX2#JX?3<(/3G
M[2#EZ?/AX_GCWB#T[_4@X^7C[^WO]._R.B`E<RX`T.'Q[_7SZ=SSZ.?JY2#S
M]MSK[.$@ZN'TW"#TY^T@Y>GSX>/YX]X@Y.7D[^S=[?GM(.?LY?'OZ^_CW^_U
M+@#0X?'O]?/IW//HY^KE(//VW.OLX2#JX?3<(/3G[2#EZ?/AX_GCWB#TY_(@
MY?'CX?/?X?(Z("5S+@#0X?'O]?/IW//HY^KE(//VW.OLX2#JX?3<(/3G[2#E
MZ?/AX_GCWB#PZ^?Q[_;O\>G^[2#DZ>'HY?/I[/STY_3A\CH@)7,N`-#A\>_U
M\^G<\^CGZN4@\_;<Z^SA(//TYR#V_/'LX2#Q]>CLW_/E^>TN(+KS^?(@X?;>
M\^'TY2#JY>W\(.K<\._I[R#A\.'I]._][.7M[R#PY>3?[RX`T.'Q[_7SZ=SS
MZ.?JY2#S]MSK[.$@\_3G[2#EZO3=Z^7SYR#TY_(@ZN'H[_'I\^S=[>?R(.OE
MZ?3O]?'CW^'R(/3O]2#$Z>7UZ/7M\^GOX_'<]N_U+B#0X?'AZN'K_B#D[^KI
M[-SS].4@X?'C_/3E\>$N`$)E:2!D97(@06MT=6%L:7-I97)U;F<@9&5R($MO
M;G1A:W1D971A:6QS(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B!":71T
M92!V97)S=6-H96X@4VEE(&5S('-PY'1E<B!N;V-H(&5I;FUA;"X`T.'Q[_7S
MZ=SSZ.?JY2#S]MSK[.$@ZN'TW"#TY^T@Y>WG[-WQ^?/G(/3G\B#KW_/TX?(@
MY.GA[>_LWO(N(-#A\>'JX>O^(.3OZNGLW//TY2#A\>/\].7QX2X`P>7Q[^OI
M[-WMX?(@R.7S\^'K[^W?ZN?R`,\@Y>[U\.?QY?3G]-[R($E-05`@Y.7M(/7P
M[_/TY_'?YN7I(.KOZ>W\]_'G\_3O]?(@]N'JW>OO]?(N`,'U]-X@YR#E[=WQ
MX^7IX2#DY>T@]?#O\_3G\=_FY?3AZ2X`P?7TWB#G(.OEZ?3O]?'CW^$@Y.7M
M(-WWY>D@[^OOZNOG\?GHY=\@X>K\[.<N`,'U]/P@Y.4@]N'?[>7TX>D@[>$@
MY=_MX>D@W>/J]?'O(.'Q]^7?[R!R87(N`,'U]/P@Y.4@]N'?[>7TX>D@[>$@
MY=_MX>D@W>/J]?'O(.'Q]^7?[R!Z:7`N`,'U]/P@Y.4@]N'?[>7TX>D@[>$@
MY=_MX>D@W>/J]?'O\B#A\>GH[/SR(.K<\?3A\BX`P?7T_/(@[R#OY.?C_/(@
M\^'R(.7PZ?3QW?#EZ2#MX2#S]-WK[>7TY2#LY^W][.'TX2#LW?/Y($-L:6-K
M871E;&PM*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@[-WS^2!(5%10+4%022X`
MP?7T_/(@[R#OY.?C_/(@\^'R(.7PZ?3QW?#EZ2#MX2#S]-WK[>7TY2#LY^W]
M[.'TX2#LW?/Y('-M<S)E;6%I;"TH:'1T<#HO+W-M<S)M86EL+F-O;2D@[-WS
M^2!(5%10+4%022X`P?7T_/(@[R#OY.?C_/(@\^'R(.7PZ?3QW?#EZ2#MX2#S
M]-WK[>7TY2#LY^W][.'TX2#LW?/Y(%--5%`@(.KAZ2#TY_(@5F]D869O;F4M
M271A;'D@[/SM[R#SY2#A\>GH[._]\B!6;V1A9F]N92X@P?#AZ?3EWR#=[>$@
MZ^_CX?'IX?/L_"!E;6%I;"#S].<@5F]D869O;F4@271A;'D@*&AT='`Z+R]W
M=W<N,3DP+FET*2X`U.\@\.7DW^\@X?7T_"#A\.'I].7?].'I+@#4[R#PY>3?
M[R#A]?3\(.SP[_'EWR#MX2#=]^7I(.S\[>\@X>K=\>'I[_7R+@#!]?3\(/3O
M(/#EY-_O]2#L\._QY=\@[>$@\.7QZ=WWY>D@[/SM[R#A\>GH[._]\B#JX>D@
MW.WY(.K<]/D@].7KY=_A("@Z*2X`P?7T_"#T[R#PY>3?[R#L\._QY=\@[>$@
M\.7QZ=WWY>D@[/SM[R#OZO3AY.GJW?(@].GLW?(N`,'U]/P@].\@\.7DW^\@
M[/#O\>7?(.WA(/#E\>G=]^7I(.S\[>\@Z]_S].$@X?'IZ.S^[2#W^?'I\^S=
M[?GM(.SE(.KE[?P@WB#EZ^OG[>GJ_"#E\?GTY^SA].GJ_`#!]?3\(/3O(/#E
MY-_O(/#QW?#EZ2#MX2#EW^WAZ2#=[>'R(-WCZO7Q[_(@X?'IZ.S\\BX`P?7T
M_"#T[R#PY>3?[R#P\=WPY>D@[>$@\.7QZ=WWY>D@ZOGDZ>K\(/?Q_NSA]._R
M(//E(%)'0B#DY>KAY>[AY.GJWB#L[_'VWBP@\"[W+B`G(S$R,S1A9B<N`,'U
M]/P@].\@X?'WY=_O(/#E\>G=]^7I(/3O]?(@34E-12!D<FEV97)S(/#O]2#W
M\>?SZ>SO\._I[_WM].'I(.'P_"#TY^T@]?#G\>7SW^$@Y?#I]/'=\._M].'R
M(.3IW/;O\>$@\/'OX_'<[.SA].$@[>$@Y.GA]^7I\=_F[^WTX>D@].$@\.7Q
MZ>7W_.SE[>$@]/GM(&5M86EL(.KAZ2#MX2#TX2#E[/;A[=_F[_7M(.SE(/3O
M[2#JX?3<Z^OGZ^\@]/'\\.\N`,'U]/P@].\@X?'WY=_O(.7KW>/WY>D@].GR
M(/'UZ.S?\^7I\B#T^>T@]_'Y[-ST^>T@ZN'I(/3Y[2#C\>'L[.'T[_/EZ?'^
M[2#CZ>$@_.OA(/3O(/#Q_./QX>SLX2#T[_4@2&]R9&4L(.KAZ2#CZ>$@].GR
M(.7VX?'L[^/=\B#P[_4@Y=_MX>D@Y>/JX?3E\_3G[-WMY?(@\^4@X?7T_"#J
MX>D@Y.7M(/#A\=WW[_7M(.3IZMWR(/3O]?(@Y?#IZ^_CW?(@X^GA(.'U]-WR
M(/3I\B#Q]>CLW_/EZ?(N`,'U]/P@].\@X?'WY=_O(.KA].'C\=SVY>D@].GR
M(.7PY>KTW//EZ?(@]/GM(/3]\/GM(,S)S,4L(/[S].4@].$@\.7QZ>7W_.SE
M[>$@[_'I\^S=[?GM(&UA:6P@[>$@Y>SVX>W?YN_M].'I(.SE(/3O[2#JX?3<
MZ^OGZ^\@]/'\\.\N`,'U]-X@YR#V_/'LX2#=]^7I(-[DYR#E\.7NY?'CX?/H
MY=\N`,'U]/P@Y=_MX>D@)7,N`,'U]/P@Y=_MX>D@2V]L86(@1W)O=7!W87)E
M(&]B:F5C="X@P^GA(.WA(.3EW_3E(/3O(.'M].GJY=_LY>WO(.'U]/P@]_'E
MZ=SFY?/HY2#=[>$@\/'\X_'A[.SA(&5M86EL(/#O]2#JX?3AZ^'BX=_MY>D@
MX?7TWB#TYR#L[_'VWBX@P^GA(.O?\_3A(/3=]._I^>T@\/'OX_'A[.S<]/GM
M(.SP[_'EW_3E(.WA(.7PZ?/JY?7HY=_TY2#T[R`E<P#!]?3\(.7?[>'I(/3O
M(.+A\^GJ_"#A\??EW^\@\?7H[-_SY?GM(/3O]2#P\>_C\=SL[.'T[_(@)TAO
M<F1E)RX@T.7QZ=WWY>D@].$@[._M[_#<].GA(.KAZ2#TX2#BX?/IZMP@[-WQ
MYR#P[_4@]_'G\^GL[_#OZ>_][?3AZ2#A\/P@]._M(/#U\=[MX2#JX>D@].GR
M(.7VX?'L[^/=\B#T[_4@\_7S]-[LX?3O\BX@`-3O(.S>[?7LX2#A]?3\(./Q
MW/;HY^KE(.SE(.KYY.GJ[_/EZ]_DX2`H)7,I(.3IX?;O\>7TZ>K>(.'P_"#T
MYR#DZ>K>(//A\BX`P?7T_/(@[R#A\>GH[/SR(/#QW?#EZ2#MX2#EW^WAZ2#T
M[_7KW/?I\_3O[2#=[>$N`-3O(/#Q_.+KY^SA(.'U]/P@X>WA]MWQZ.?JY2#A
M\/P@)7,N(,\@]_'>\_3G\B#JW.OE\^4@].?M/&)R+S[A[>'V[_'<(/#Q[^+K
MWNSA]._R(.'P_"#T[R#PX?'AZMST^2!54DPZ/&)R+SXE<R#JX>D@]_'G\^GL
M[_#OZ>7?(/3O[2#AZOSK[_7H[R!B<F]W<V5R.CQB<B\^)7,`P?7T_/(@[R#E
M[O7PY_'E].?TWO(@Y.4@[/#O\>7?(.WA(.'P[_/U[/#IW?/EZ2!Z:7`@ZN'I
M(&=Z:7`@X?'WY=_A+@#4[R#S_?/TY^SA(.'U]/P@W??EZ2#A\.7MY?'C[_#O
MZ>?HY=\N`,'U]-X@YR#TZ>S>(/#QW?#EZ2#MX2#EW^WAZ2#A\>GH[/SR+@#%
MZ?/I]-[QZ>$`V?'A`,GW[>?KX?3^[?3A\B#TY^T@_O'A`,SO\?;>(/[QX?(`
MQ?#IZ^_CWB#^\>'R`-3?].OO\@#4W_3K[_(@*%1O;VQT:7`I.@#0\?SR`,/I
MX2#MX2#J\>'TWO/E].4@\._KZ^'PZ]P@X>WTZ>KEW^SE[>$L(.KQX?3>\_3E
M(/#A].?LW.WO(/3O($-O;G1R;VP@*%!#*2#>(/3O($-O;6UA;F0@*$UA8RD@
M\.O>ZO3Q[RP@Y>W^(.K<[>7TY2#JZ^GJ+@#3WNSE\>$`Q>WAZ^OAX]X@\^4@
M\.?CX=_O($A434P`P?WQZ>\`RN_Q]?;>`-#<[?D@\.OAW_/I[R`H7W1O<"D`
MS.7TX?;QW//EZ?(`P>7Q[^OI[-WMX?(@U/'?\._KY_(`P>OGZ-WR(-X@^.7U
MY-WR`-3Q`,OA[>CA\^S=[>_R(/3]\._R(.3EY._LW>WY[2X`T.OGZO3Q[^OO
MX][S].4@].?M(.7PZ>OOX]X@\^'R.B``Q^OEZO3Q[^WIZMX@Q.GE_>CU[?/G
M`,?KY>KT\>_MZ>K>(,3IY?WH]>WSYR#CZ>$@Y?#I\_3Q[_;>(.'MX?;O\=SR
M(.KA]-SS].'SY_(@]._U(/#Q[^/QW.SLX?3\\B#SX?(`Q^OEZO3Q[^WIZMX@
MQ.GE_>CU[?/G.@#!Y/WMX?3G(.<@\/'\\^+A\^<@\_3O[2!61E,@ZN'TW.OO
MX^\N`,'D_>WA].<@YR#P\>_SZ-[JY2#E\.GPZ]WO[2#PZ^?Q[_;O\>G^[2#J
MX?3<(/3G[2#EW_/OY.\@]._U(/?QWO/TYRX`P>3][>'TYR#G(.'KZ^'CWB#E
M[N_U\^GOY._TWO/E^>T@X^GA(/3O(%9&4R#A\??EW^\@(B5S(BX`P>3][>'T
MYR#G(.'KZ^'CWB#E[N_U\^GOY._TWO/E^>T@X^GA(/3O(%9&4R#A\??EW^\@
M)7,O)7,N`,'D_>WA].<@YR#AZ^OAX]X@]._U("5S+@#$Y>T@Y=_MX>D@Y/7M
MX?3>(.<@\_WMY.7SYR#S].\@Y.GAZN_LZ?/TWB!344PN`,3E[2#EW^WAZ2#D
M]>WA]-X@YR#S_>WDY?/G(.SE(%-33"X`P>3][>'TYR#G(.'M].GC\>'VWB!6
M1E,@X?'WY=_O]2X`P>3][>'TYR#G(.3G[.GO]?'CW^$@ZN'TX>O\X^_U(%9&
M4R`B)7,B+@#!Y/WMX?3G(.<@Y.?LZ>_U\>/?X2#JX?3AZ_SC[_4@5D93+@#!
MY/WMX?3G(.<@Y.?LZ>_U\>/?X2!61E,@X?'WY=_O]2X`P>3][>'TYR#G(.3G
M[.GO]?'CW^$@ZN7M[_T@5D93(.'Q]^7?[_4N`,'D_>WA].<@YR#A\._S]>SP
MW^7SYR#DY>3O[-WM^>TN`,'D_>WA].<@YR#DZ>'C\>'VWB`B)7,B+"#O(/;<
MZN7K[_(@Y.7M(.7?[>'I(.KE[?SR+@#!Y/WMX?3G(.<@Y.GAX_'A]MX@)7,L
M(.\@]MSJY>OO\B#DY>T@Y=_MX>D@ZN7M_/(`P>3][>'TYR#G(.3IX>/QX?;>
M("<E<R<Z("5S+@#!Y/WMX?3G(.<@Y.GAX_'A]MX@ZN'TX>O\X^_U(%9&4R#E
M\.'MX>OLXN'M_.SE[>$@*')E8W5R<VEV96QY*2X`P>3][>'TYR#G(.3IX>/Q
MX?;>(.KA].'K_./O]2!61E,N`$1A<R!61E,M5F5R>F5I8VAN:7,@:V]N;G1E
M(&YI8VAT(&=E;/9S8VAT('=E<F1E;CH@)7,N`,'D_>WA].<@YR#DZ>'C\>'V
MWB#T[_4@5D93(.'Q]^7?[_4@(B5S(BX`P>3][>'TYR#G(.3IX>/QX?;>(/3O
M]2!61E,@X?'WY=_O]2X`P>3][>'TYR#G(.3IX>/QX?;>(%9&4R#E\.'MX>OA
M[.+A[?SLY>WA("AR96-U<G-I=F5L>2DZ("5S+@#$Y2#L\._Q_B#MX2#P\>_S
MY.GO\=_S^2#T[^T@]/'=]^_M].$@ZN'TW.OOX^\N`,3E(.SP[_'^(.WA(.7N
MW./Y(/#KY_'O]N_QW^7R(/#I\_3O\._IY_3IZN_]`,'D_>WA].<@YR#V_/'T
M^?/G(._QZ?/L[_T@]._U("5S+@#!Y/WMX?3G(.<@[.7TX>K?[>?SYR#T[_4@
M5D93(.'Q]]_O]2X`P>3][>'T[R#T[R#<[>_IX^SA(/3O]2!61E,@X?'WY=_O
M]2`B)7,B+@#!Y/WMX?3O(/3O(-SM[^GC[.$@]._U(%9&4R#A\??EW^_U(./I
MX2#C\=SXZ>SO+@#!Y/WMX?3O(/3O(-SM[^GC[.$@]._U(%9&4R#A\??EW^_U
M+@#$Y2#L\._Q_B#MX2#A[>_?[OD@].\@\_7L\.GE\^S=[>\@X?'WY=_O+@#$
MY2#L\._Q_B#MX2#DZ>'BW//Y(/3O[2#J_?'I[R#JX?3<Z^_C[R!61E,@*'9F
M<W)O;W0I+@#$Y>T@Y=_MX>D@Y/7MX?3\[2#MX2#JX?3A]_GQY^CO_>T@[^D@
M\/'O].GLWO/EZ?(@X^GA(.'U]-X@].?M(//][>3E\^<N`,'D_>WA].<@YR#L
MY?3O[>_LX?/?X2#T[_4@)7,@\^4@)7,Z(.\@]MSJY>OK[_(@]?#<\??EZ2#>
MY.<`P>3][>'TYR#G(.SE]._M[^SA\]_A(/3O]2!61E,@ZN'TX>O\X^_U+@#!
MY/WMX?3G(.<@[.7T[^WO[.'SW^$@]._U(%9&4R#JX?3AZ_SC[_4Z("5S+@#!
MY/WMX?3G(.<@[.7T[^WO[.'SW^$@]._U(%9&4R#A\??EW^_U("(E<R(N`,'D
M_>WA].<@YR#LY?3O[>_LX?/?X2#T[_4@5D93(.'Q]^7?[_4@)7,O)7,N`,'D
M_>WA].<@YR#LY?3O[>_LX?/?X2#T[_4@5D93(.'Q]^7?[_4N`,'D_>WA].<@
MYR#EZO3=Z^7SYR#T[_4@(FUK:7-O9G,B+@#$Y>T@[/#\\>7SY2#MX2#LY?3A
M]O'A\_3EWR#A]?3\(/3O(-WCX_'A]N\@5V]R9`#$Y2#L\._Q_B#MX2#C\=SX
M^2#S].\@5D93(.'Q]^7?[R`B)7,B+@#$Y2#L\._Q_B#MX2#C\=SXYR#S].\@
M5D93(.'Q]^7?[R`H8V]P>2@I(.'PW?3U]^4I+@#$Y2#L\._Q_B#MX2#C\=SX
M^2#DY>3O[-WMX2#T[_4@5D93(.'Q]^7?[_4N`-7P[^/QX>SLZ?/LW>WA`,'J
M_?'Y\^<@P>OKX>/^[0#!ZO7Q_NWEZ2#TYR#TY>OE]?3AW^$@\^'R(.7MW?'C
MY>GA`,SG(.'MX>SE[?SLY>WO(/3=Z^_R(/3O]2#A\??EW^_U+@#,YR#A[>'L
MY>W\[.7MYR#A\-SM].?SYR#A\/P@]._M(.7N]?#G\>7TY_3>(//TYR#S_>WD
MY?/G.B``S.<@X>WA[.7M_.SE[><@X?#<[?3G\^<@X?#\(/3O[2#E[O7PY_'E
M].?TWB#S].\Z(`#,YR#!\??EZ>_HY?3G[-WM[P#,YR#WY>GQZ>;\[.7M[R#S
M]._I]^7?[R#T_?#O]3H@)7,`S._MW.3E\@#!X^WY\_3O`%5N:VYO=VX@87!I
M;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI
M96YT($UE<W-A9V4@240I+@#!X^WY\_3O(/SM[^SA(/?QWO/TYR#>(.KYY.GJ
M_/(N`,'P[_/][>3E\^<@]/'=]^_M]._R(//T[^GWY=_O]0#![?[M]>SO`,SG
M(.7N[_7SZ>_D[_3G[-WMX2#P\>_C\=SL[.'TX2#DY2#L\._Q[_WM(.WA(-WW
M[_7M(/#Q_//BX?/G(//E(.OEZ?3O]?'CW^7R(.'P[^KO\-[R+^'M].GC\>'V
MWO(OY?#IZOSKY_/G\B#CZ>$@Z_SC[_7R(.'S]N'KY=_A\BX@T.'TWO/TY2#/
MRB#CZ>$@[>$@Y.7?].4@].7W[>GJW?(@\^?LY>G^\^7I\B#S].\@;6]Z:6QL
M82YO<F<@\._U(//A\B#DY=_W[>_U[2#P^?(@[>$@Y?#I]/'=^.7TY2#SY2#P
M\>_C\=SL[.'TX2#TYR#P\?SSXN'SYR#S].\@8VQI<&)O87)D`,SG(._QZ?/L
MW>WO(/?Q_NSA`,SG(/7P[_/TY_'IYOSLY>WG(.7PW>KTX?/G`,7MY^S=\?GS
MYP#%[>?LW?'Y\^<@)7,`Q>WG[-WQ^?/G(.KA]-SS].'SY_(@X?#A[?3G[-WM
M[_4`Q>WG[-WQ^?/G(/?QWO/TYP`G)7,G(,7MY^SE\?[HY^KE+@#4[R#P\?SC
M\>'L[.$@X>WAXMSH[.GSY_(@Y.GAX_'<]N?JY2X`P?#O\_3OZ]X`P?#O\_3O
MZ]X@_.OY[2#T^>T@X?'WY=_Y[2#Q]>CLW_/E^>T@\_3O[2#E[O7PY_'E].?T
MWBX`RN7VX>OAW^$@Z^'TZ>WIZMP@X_'<[.SA].$`T?GLX?KJ[]\@X?'IZ.SO
MWRW*Y?;AZ^'?X0#7\=[SYR#T\=WW[^WT[_(Z("5S`,WA(/?QY_/I[._P[^GG
MZ.7?(.<@\/'OY?#IZ^7C[-WMYR#TZ>S>`-?QWO/G(%-33`#7\>?SZ>SO\._I
MY=_TX>D@X>T@].\@_.WO[.$OZOGDZ>K\\B#EW^WAZ2#DZ>'V[_'E].GJW"X`
MSR#W\=[S].?R("5S(.3E[2#EW^WAZ2#E[N_U\^GOY._TY^S=[>_R(./IX2`E
M<RX`Q.GA]^7?\>GSYR#7\>?S]/[M`,7PZ>OOX]WR(-?QWO/TYP#%X^/QX?;>
M(-?QWO/TYP#'(.7CX_'A]MX@]_'>\_3G(-WWY>D@X?#E[>7QX^_P[^GGZ.7?
M(./I)R#A]?3\(/3O('-I=&4N`,'KZ^'CWB#J^>3IZN_](/?QWO/TYP#%[N_U
M\^GOY._TWO/EZ?(@U_'>\_3G`+SM[^SA(-?QWO/TYP#4[R#\[>_LX2#W\=[S
M].<@)R5S)R#U\-SQ]^7I(-[DYRX`O.WO[.$@U_'>\_3G.@"\[>_LX2#7\=[S
M].<Z(`#7\=[S].7R`-?QWO/TY?(@\_3O(-/]\_3G[.$Z`,\@ZN'TW.OOX^_R
M(%9&4R#DY>T@]?#<\??EZ2X`Q.GAZN_PW?(`N./J]?'E\B#T[_#OZ.7SW^7R
M(/#O]2#B\=WHY^KA[2#S]>SPY?'IZ^'LXMSM[^WTX>DZ(`#%X^KU\?STY_3A
M`-3I[-X@\^4@Z^7P]-P@X?#\(/3^\>$N`-3I[-WR`,3^\_3E(/3I[-WR(./I
MX2#MX2#E\.GKW>[Y`,SE].'BZ^?TW@#'(.7PZ>+EXN'?^?/G(.'PW?3U]^4@
M+2#A]?3\(/3O(.S>[?7LX2#L\._QY=\@[>$@W.OKX>[E(.SE+@"XZN3O\^<`
MN.OEX_?O\B"XZN3O\^?R`,K<Z.7TYR#%]>CUX_'<[.SI\^<`RMSHY?3O(./=
M[.GS[.$`RMSHY?3A.@#0[^O](/CGZ]X`Q>SVW.WI\^<@)7,`Q>SVW.WI\^<@
MY>[Y].7QZ>K>\B#I\_3O\^7KW^3A\@#%[/;<[>GSYR#SX>T@)7,`Q>SVW.WI
M\^<@X^7C[^W\]._R`,7L]MSMZ?/G(.7QX^'SW^'R`,_QX?3\].?TX0#/\>'T
M_/3G].$Z`%9O9&%F;VYE(,GTX>O?X?(@[-WS^2!33510`-#1S]//U\<`T-'/
MT\_7QR$A(2#!UL')T<73U,4@U,\@T-'/P]'!S,S!(,S/S<_)(-/!TR#!T,\@
M)7,N`-#Q[^7IY._P[]_G\^<`U.4`Q>+D[^SAY.GAW^$`RN'K^?/>Z^CA].4`
MRN'K^?/>Z^CA].4@\_3O("5S`,KAZ_GSWNOHX?3E+"`E<P#0[^G<(.7VX?'L
M[^/>(.CA(.7L]N'LW^;EZ2#T[R`E<R#A]N_](//U[>3EZ.7?].4@\_3G[2#U
M\.?QY?/?X3L`T._IX2#E]N'Q[._CWB#MX2#E[/;A[=_FY?3AZ2#A]N_](//U
M[>3EZ.7?].4@\_3G[2#U\.?QY?/?X3L`T._I_/(@Y=_MX>D@[R#DZ>'W^?'I
M\_3IZOSR(/?A\>'J]-[QX?([`-#OZ?SR(.7?[>'I(.\@]^'QX>KTWO'A\B#E
MZ?/AX_GCZ>K^[3L`T._IW?(@UMSSY>GR`,KAZ._QW_/TY2#P[^G<(/#Q_//H
MY?3A(.CA(.7MY?'C[_#OZ>?H[_WM(//T[^T@Y?#E[N7QX^'S]-X@Y>SPZ^_U
M].GS[-WM[_4@ZN7I[-WM[_4N`-#KW/3O\@#0Z]ST[_(@\^4@[._MW.3E\B!#
M4U,`T.O<]._R(/3O]2`E<R#LY>WO_2#S].$@X?'I\_3E\=P@*.CA(.7VX?'L
M[_/HY=\@\_3G[2#E\/SLY>WG(.7?\^_D[RDZ`-#KW/3O\B#T[_4@\-_MX>KA
M`,SO[=SDX2#PZ]ST[_7R`-#KW/3O\CH`N.WTX?/G(.'MW>SO]2#SY2#J_.SB
M[_7R`,'MY>SO\CH`P>WE[._R.B``T^_VW^$`R]_S].$@Y?#IZ/7LZ?[M`,7Q
MX^'SW^$`Q.GE_>CU[?/G(,7QX^'SW^'R`-3GZ]WV^>WO(,7QX^'SW^'R`%@M
M4F5F`%@U,#EV,R#"X?/IZN_?(-#E\>GO\>GS[._?`%@U,#EV,R#7\=[SYR#E
M\.7J].'LW>WO]2#JZ^7IY.GO_0!8-3`Y=C,@Q>WAZ^'J].GJ_""\[>_LX2#(
MW>SA]._R`%@U,#EV,R#![>'C[?GQZ?/TZ>K\(,KKY>GDWR#(W>SA]._R`%@U
M,#EV,R#%\.7J]-SSY>GR`,7%`,7%Q<4`Q?3>\^GA`,WAWP#-X>DL(-/U[/;Y
M[?X`Q=_S].4@\^4@ZN'TW//TX?/G(,K%R<S%S<_5+B#7\>?SZ>SO\._IY=_S
M].4@].\@6SP^72#PZ][J]/'O(./IX2#MX2#E\.GS]/'=^.7TY2#SY2#JX?3<
M\_3A\^<@5UE325=)1RX`Q.7M(-WWY?3E(.'UZ.7M].GJ[_#OZ>?HY=\N`,3E
M[2#E\.GT\=WPY?3AZ2#MX2#=]^7TY2#T[R#WX?'AZO3>\>$@)UPG(//T[R"\
M[>_LW"#SX?(N`,3E(.3^\^'TY2#=X^/U\><@Y.GE_>CU[?/G(&5M86EL+@#$
MY>T@X>WTZ?/T[^GWW_/A].4@ZN'MW>WA(/#EY-_O(.'P_"#T[R#A\??EW^\@
MY>GSX>/YX][R(//E(.'M]-_S]._I]^$@\.7DW^$@\_3O("5S+@"X]^7TY2#A
M\._S]>WDY>CEWRX`N/?E].4@X?#O\_7MY.7HY=\N/&)R("\^Q?7WX?'I\_3O
M_>SE(/#O]2#W\>?SZ>SO\._IWO/A].4@].?M(/7PY_'E\]_A+@#0\=WPY>D@
M[>$@Y/[SY?3E(.SIX2#=X^KU\><@].GLWBX`T/'=\.7I(.WA(/'UZ.S?\^7T
MY2#T[R!$871A5')E92#CZ>$@[>$@]_'G\^GL[_#OZ>7?].4@4VEG;G5P<RX`
MT/'=\.7I(.WA(/'UZ.S?\^7TY2#T[R!61E,M0F%C:V5N9"X`T/'=\.7I(.WA
M(/#E\>GC\=SXY?3E(/3O(/#Q_.+KY^SA(/#QZ>T@\_3EW^OE].4@X>WA]N_Q
MW"#CZ>$@X?7T_"X`T/'=\.7I(.WA(//U[/#KY_'^\^7TY2#T[R!54DP@\._U
M(.3EW_?MY>D@X?7TWB#G(//][>3E\^<`T/'=\.7I(.WA(.7PZ>O=[N7TY2#T
M[^T@Y>[U\.?QY?3G]-X@X^GA(.3IX>/QX?;>+@#0\=WPY>D@[>$@[_'?\^7T
MY2#=[>$@_.WO[.$@]_'>\_3G(./IX2#DZ>'C\>'VWBX`T/'=\.7I(.WA(._Q
MW_/E].4@W>WA(/SM[^SA(/?QWO/TYR#CZ>$@Y.GAX_'A]MXN`-#QW?#EZ2#M
MX2#O\=_SY?3E(-WMX2#\[>_LX2#W\=[S].<@X^GA(/#Q[_/HWNKG+@#0\=WP
MY>D@[>$@[_'?\^7TY2#=[>$@_.WO[.$@]_'>\_3G(./IX2#E[>?LW?'Y\^<N
M`-#QW?#EZ2#MX2#O\=_SY?3E(.SIX2#E[=WQX^7IX2#CZ>$@Y>KTW>OE\^<N
M`-#QW?#EZ2#MX2#D_O/E].4@W>WA(/SM[^SA(./IX2#TYR#MW>$@ZN'TY^/O
M\=_A+@#'(//][>3E\^<@\^'R("5S(.3IX>K\\.?JY2X@T.'QX>KAZ_X@Y._J
MZ>S<\_3E(.WA(.[A[>'S]>WDY>CEW_3E+@#'(,?KY>KT\>_MZ>K>(//A\B#$
MZ>7]Z/7M\^<`QR#'Z^7J]/'O[>GJWB#SX?(@Q.GE_>CU[?/G.@#'(,'P_#H@
MQ.GE_>CU[?/G.@#/Z2#0Z^?Q[_;O\=_E\B#SX?(`QR!);G1E<FYE="#DZ>7]
MZ/7M\]X@\^'R(-SKZ^'NY2#A\/P@].?M(-WMX?'NYR#TY_(@)7,@\_WMY.7S
MWO(@\^'R+B##Z>$@].?M(/#Q[_/TX?/?X2#TY_(@X?/VW.OEZ>'R(/#QW?#E
MZ2#MX2#NX>WA\_7MY.7HY=_TY2X`U.\@_.WO[-P@\^'R`-3O(//]\_3G[.$@
MX?7HY>WTZ>KO\._?Y_/G\B#DY>T@]?#O\_3G\=_FY>D@\/'O\^C>ZN<@]_'G
M\_3^[2P@WB#G(.OEZ?3O]?'CW^$@X?7TWB#=]^7I(.'PY>WE\>/O\._IY^CE
MWR#CZ>$@ZMSP[^GO(.O\X^\N`-3O(//]\_3G[.$@X?7HY>WTZ>KO\._?Y_/G
M\B#DY>T@]?#O\_3G\=_FY>D@Z]_S].$@]_'G\_3^[2P@WB#G(.OEZ?3O]?'C
MW^$@X?7TWB#=]^7I(.'PY>WE\>/O\._IY^CEWR#CZ>$@ZMSP[^GO(.O\X^\N
M`,\@0G)O=W-E<B#SX?(@]N'?[>7TX>D@[>$@W??EZ2#AZ^O<[N7I(.'P_"#T
MY^T@W>WA\>[G(/3G\B`E<R#S_>WDY?/>\B#SX?(N(,/IX2#TY^T@\/'O\_3A
M\]_A(/3G\B#A\_;<Z^7IX?(L(.CA(/#QW?#EZ2#MX2#NX>WA\_7MY.7HY=_T
MY2X`SR!"<F]W<V5R(//A\B#DY>T@]?#O\_3G\=_FY>D@X?7TWB#TYR#KY>GT
M[_7QX]_A+@#/($)R;W=S97(@\^'R(.3E[2#U\._S].?QW^;EZ2#A]?3>(/3G
M[2#E\.GK[^/>(.7J]/WP^?/G\BX@T.'TWO/TY2!#;VYT<F]L+T]P=&EO;B`K
M(%`@X^GA(.7J]/WP^?/G+@#'(/3QW??O]?/A(.;^[><@_O'A\CH`QR#P\>_J
MX>CO\>GS[-WMYR#SX?(@].'U]/STY_3A.@#4[R#PZ][QY?(@_.WO[-P@\^'R
M.@#/(.W=[_(@\^'R(.KYY.GJ_/(@X^GA("5S(.7?[>'I.B`E<P#/Z2#E\.GK
M[^/=\B#SX?(@W??O]>T@Y>WG[.7Q^>CEWR#CZ>$@].<@Y.G<\>KEZ>$@X?7T
MWO(@].?R(//][>3E\^?R+@#/Z2#E\.GK[^/=\B#SX?(@W??O]>T@Y>WG[.7Q
M^>CEWRX`SR#J^>3IZOSR(//A\B#<Z^OA[N4`SR#J^>3IZOSR(//A\B#<Z^OA
M[N4L(.7KW>/N].4@].$@[.?M_>SA]-P@\^'R(.KAZ2#JW.WTY2#EW_/OY.\@
M[.4@].\@[=WO(//A\B#J^>3IZOPN`,_I(.W=[^D@ZOGDZ>KOWR#DY>T@].'I
M\>G<YN_U[0#/Z2#A\._LX>KQ]?/LW>WOZ2#SX?(@Y>[U\.?QY?3G]-WR.@!;
MP?#\ZO'U^.<@ZN7I[-WM[_4@\^4@Y>GSX>/YX^GJW%T`6\'MX?;O\=P@T/'O
MXNO>[.'T[_)=`%O%[/;<[>GSYR#JY>GLW>WO]2#SY2#EZ?/AX_GCZ>K<("T`
M6\7L]MSMZ?/G(.KEZ>S=[>_U(//E(.7I\^'C^>/IZMP@+2`E<R#C\>'L[-WR
M70!;X_'A[.S>("5S(.'P_"`E<UT`Q.GA]^7?\>GSYP#$Z>'C\>'VWB##\>'L
M[-[R`,_LW.3E\@#"[][HY>GA`,GDZ?STY_3E\B#%Z>K\[>'R+BXN`,7?\^_D
M[_(`Q>[OY._R`-3Q[_#O\._?Y_/G(-/][>3E\^SO]2XN+@#%\.GK[^/=\@#%
M[N_U\^GOY._TWO/EZ?(`Q.GAX_'A]MX@T_7MY-WS[._U+BXN`-'UZ.S?\^7I
M\@#)Y.G\].?TY?(@T-_MX>KA+BXN`-?QWO/TY?(`Q.GE]>CU[?/I[^/QW/;O
M\@#'[.7Q[^O\X^GO`.?QY>S?X0#PX?3>\_3E(.7D_@#A\??EW^\`X?#\(/3O
M("5S("@E<RD@\_3I\B`E<R`E<P!H.@#<[.7SX0#E[?/Y[.'T^>S=[>\`X_'A
M[.S=\ET`;6MI<V]F<RWJ^>3IZOSR(.O<Z._U\B`E9"#JX?3<(/3G(.3G[.GO
M]?'CW^$@25-/+@#\[>_LX0#DY>T@W??EZ2#EX^KA].'S].'HY=\`Y.7M(-WW
MY>D@Y>/JX?3A\_3AZ.7?(.'J_.SG`//G[.7I^>SA]-SQZ>\`]._I\B#EZN'T
M_`#EZ>KO[>_S]._I]^7?X0#E[/;<[>GSYR#DZ>'V[_'^[0!S;7,@\^4@96UA
M:6P@[-WS^2!(5%10`//TX>CE\?SR`.O?\_3A(.7QX^'SZ?[M`.K<Y._R`,/Q
MW/CTY2#T[^T@ZOGDZ>K\(.3][R#V[_'=\B#CZ>$@Y?#IXN7BX=_Y\^<`Y>WO
M\._IY^S=[>$`X>W^[?7LX0#E\.GK[^/>(/?QWO/TYP#8Y_;IX>K>(,K<\?3A
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]E
M;E]54R\`````````````````````````````````````````````````````
M````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`U,34T,S,W-3,`,#(P,3(V`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&]C86QE+V5N7U53+VAE;'`N>&UL````````````````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S$Q-``Q,#4Q-30S,S<U,P`P,C$U
M-S<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CQH96QP/@H*/&5N=')Y(&ED/2)S=6UM
M87)Y(CX*/'1I=&QE/E1H92!0;W)T86P@4&%G93PO=&ET;&4^"B`\<&%R83X*
M("!4:&ES('!O<G1A;"!P86=E('!R;W9I9&5S(&$@<75I8VL@<W5M;6%R>2!O
M9B!A;&P@>6]U<B!I;7!O<G1A;G0*("!I;F9O<FUA=&EO;BX@1F]R(&5X86UP
M;&4L(&ET(&UI9VAT('-H;W<@:&]W(&UA;GD@;F5W(&4M;6%I;"!M97-S86=E
M<R!Y;W4*("!H879E(&EN('EO=7(@24Y"3U@L('5P8V]M:6YG(&5V96YT<R!O
M;B!Y;W5R(&-A;&5N9&%R+"!T87-K<R!O;B!Y;W5R('1O+61O"B`@;&ES="P@
M:&5A9&QI;F5S(&9R;VT@<V5L96-T960@;F5W<R!S97)V:6-E<RP@86YD('-O
M(&]N+B`@36%N>2!O9B!T:&5S90H@('-U;6UA<FEE<R!W:6QL(&-O;G1A:6X@
M<75I8VL@<VAO<G1C=71S('1O(&-O;6UO;B!F=6YC=&EO;G,L('-U8V@@87,*
M("!C;VUP;W-I;F<@82!N97<@;6%I;"!M97-S86=E+"!C<F5A=&EN9R!A(&YE
M=R!C86QE;F1A<B!E=F5N="!O<B!T87-K+"!E=&,N"B`\+W!A<F$^"B`\<&%R
M83X*("!4:&4@8V]N=&5N=',@;V8@=&AI<R!P;W)T86P@<&%G92!A<F4@8W5S
M=&]M:7IA8FQE('9I82!T:&4@3&%Y;W5T(&)U='1O;BX*("!&;W(@97AA;7!L
M92P@>6]U(&-A;B!C:&]O<V4@=VAI8V@@:71E;7,@=&\@:6YC;'5D92!O;B!T
M:&ES('!O<G1A;"!P86=E(&%S"B`@=V5L;"!A<R!I;B!W:&EC:"!O<F1E<B!T
M:&5Y(&%R92!S:&]W;BX*(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB
M;F%V8F%R(CX*/'1I=&QE/E1H92!!<'!L:6-A=&EO;B!.879I9V%T:6]N($)A
M<CPO=&ET;&4^"B`\<&%R83X*("!!="!T:&4@;&5F="!H86YD('-I9&4@;V8@
M=&AE('=E8B!P86=E(&ES('1H92!A<'!L:6-A=&EO;B!N879I9V%T:6]N(&)A
M<BX*("!#;&EC:R!O;B!T:&4@:6-O;G,@;VX@=&AI<R!N879I9V%T:6]N(&)A
M<B!T;R!Q=6EC:VQY(&%N9"!E87-I;'D@<W=I=&-H"B`@8F5T=V5E;B!T:&4@
M879A:6QA8FQE(&%P<&QI8V%T:6]N<RX*(#PO<&%R83X*/"]E;G1R>3X*"CQE
M;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B/@H@("`@/'1I=&QE/E!R
M969E<F5N8V5S.B!-86EN=&5N86YC93H@1&\@36%I;G1E;F%N8V4\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!P97)F;W)M
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6XL(&-H96-K('1H:7,@
M8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)P<F5F<RUC
M;VYF:7)M7VUA:6YT96YA;F-E(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@
M36%I;G1E;F%N8V4Z($-O;F9I<FT@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!C;VYF:7)M(&%L;"!M
M86EN=&5N86YC92!T87-K<R!B969O<F4@=&AE>2!A<F4@<G5N+"!C:&5C:R!T
M:&ES(&)O>"X@268@;&5F="!U;F-H96-K960L(&%L;"!M86EN=&5N86YC92!O
M<&5R871I;VYS('1H870@;F5E9"!T;R!B92!R=6X@=VEL;"!B92!P97)F;W)M
M960@875T;VUA=&EC86QL>2!W:71H(&YO(&-H86YC92!T;R!C86YC96P@;VX@
M;&]G:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^"@H\+VAE;'`^"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQO8V%L92]E<U]%4R\`````````````````````````````````````
M````````````````````````````````````````````,#`P,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-3,`,#(P,3$S`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V5S7T53+VAE;'`N>&UL````
M````````````````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#,R,P`Q,#4Q
M-30S,S<U,P`P,C$U-C<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E
M.B!H;W)D92]L;V-A;&4O97-?15,O:&5L<"YX;6PL=B`Q+C,@,C`P-"\Q,B\Q
M,"`Q-CHQ-SHS-R!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB
M<W5M;6%R>2(@<W1A=&4](G5P=&]D871E(B!M9#4](C8X8V$S,V8W9C!C.6%A
M931C,3`S96(T-S0Y,F-D8S$U(CX*/'1I=&QE/DQA('`F(WA%,3MG:6YA(&1E
M;"!P;W)T86P\+W1I=&QE/@H@/'!A<F$^"B`@17-T82!P)B-X13$[9VEN82!D
M96P@<&]R=&%L('!R;W!O<F-I;VYA('5N('(F(WA%,3MP:61O(')E<W5M96X@
M9&4@=&]D82!S=2!I;F9O<FUA8VDF(WA&,SMN"B`@:6UP;W)T86YT92X@4&]R
M(&5J96UP;&\L('!U961E(&UO<W1R87(@8W4F(WA%,3MN=&]S(&UE;G-A:F5S
M(&YU979O<R!T:65N92!E;B!E;`H@(&)U>B8C>$8S.VX@9&4@16YT<F%D82P@
M86-O;G1E8VEM:65N=&]S(&EN;6EN96YT97,@9&4@;&$@86=E;F1A+"!T87)E
M87,@<&5N9&EE;G1E<PH@(&1E(&QA(&QI<W1A(&1E('1A<F5A<RP@=&ET=6QA
M<F5S(&1E('-E<G9I8VEO<R!D92!N;W1I8VEA<R!S96QE8V-I;VYA9&]S+"!E
M=&,N"B`@375C:&]S(&1E(&5S=&]S(')E<R8C>$9!.VUE;F5S('!O9'(F(WA%
M,3MN(&-O;G1E;F5R(&%T86IO<R!A(&%C=&EV:61A9&5S('5S=6%L97,@=&%L
M97,*("!C;VUO(&QA(')E9&%C8VDF(WA&,SMN(&1E(&YU979O<R!M96YS86IE
M<RP@;&$@8W)E86-I)B-X1C,[;B!D92!A8V]N=&5C:6UI96YT;W,@9&4@;&$*
M("!A9V5N9&$@;R!T87)E87,@;G5E=F%S+"!E=&,N"B`\+W!A<F$^"B`\<&%R
M83X*("!,;W,@8V]N=&5N:61O<R!D92!E<W1A('`F(WA%,3MG:6YA(&1E;"!P
M;W)T86P@<V4@<'5E9&5N('!E<G-O;F%L:7IA<B!M961I86YT92!E;`H@(&)O
M="8C>$8S.VX@1&ES=')I8G5C:28C>$8S.VXN(%!O<B!E:F5M<&QO+"!P=65D
M92!E;&5G:7(@<74F(WA%.3L@96QE;65N=&]S(&EN8VQU:7(@96X@97-T80H@
M('`F(WA%,3MG:6YA(&1E;"!P;W)T86P@87,F(WA%1#L@8V]M;R!E;"!O<F1E
M;B!E;B!E;"!Q=64@<V4@;6]S=')A<B8C>$4Q.VXN"B`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)N879B87(B('-T871E/2)U<'1O9&%T92(@;60U
M/2)B.&-F,&%E,3EE-3=D9F$P8S)B.38R934Q-C<X,F8T-R(^"CQT:71L93Y,
M82!B87)R82!D92!N879E9V%C:28C>$8S.VX@9&4@87!L:6-A8VEO;F5S/"]T
M:71L93X*(#QP87)A/@H@($5N(&5L(&QA9&\@:7IQ=6EE<F1O(&1E(&QA('`F
M(WA%,3MG:6YA('=E8B!S92!E;F-U96YT<F$@;&$@8F%R<F$@9&4@;F%V96=A
M8VDF(WA&,SMN(&1E"B`@87!L:6-A8VEO;F5S+B!0=6QS92!L;W,@:6-O;F]S
M(&1E(&1I8VAA(&)A<G)A('!A<F$@8V%M8FEA<B!R)B-X13$[<&ED82!Y(&8F
M(WA%,3MC:6QM96YT90H@(&5N=')E(&QA<R!A<&QI8V%C:6]N97,@9&ES<&]N
M:6)L97,N"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD
M;U]M86EN=&5N86YC92(@<W1A=&4](G5P=&]D871E(B!M9#4](F1D.35D9C`W
M83`S,#,Q,C,R8F%E83DQ.3(X.&(R9#`P(CX*("`@(#QT:71L93Y0<F5F97)E
M;F-I87,Z($UA;G1E;FEM:65N=&\Z(%)E86QI>F%R(&UA;G1E;FEM:65N=&\\
M+W1I=&QE/@H@("`@/'!A<F$^"B`@("!3:2!D97-E82!R96%L:7IA<B!L87,@
M;W!E<F%C:6]N97,@9&4@;6%N=&5N:6UI96YT;R!A;"!I;FEC:6%R(&QA('-E
M<VDF(WA&,SMN+`H@("`@<V5L96-C:6]N92!E<W1A(&-A<VEL;&$N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC;VYF:7)M7VUA
M:6YT96YA;F-E(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB83(Q,38R8V1F9C-B
M,60X9F%E861B-S(Y-C(T,#`S-F4B/@H@("`@/'1I=&QE/E!R969E<F5N8VEA
M<SH@36%N=&5N:6UI96YT;SH@0V]N9FER;6%R(&UA;G1E;FEM:65N=&\\+W1I
M=&QE/@H@("`@/'!A<F$^"B`@("!3:2!Q=6ES:65R82!C;VYF:7)M87(@;&%S
M('1A<F5A<R!D92!M86YT96YI;6EE;G1O(&%N=&5S(&1E('%U92!S92!E:F5C
M=71E;BP*("`@('-E;&5C8VEO;F4@97-T82!C87-I;&QA+B!3:2!S92!D96IA
M('-I;B!S96QE8V-I;VYA<BP@<V4@96IE8W5T87(F(WA%,3MN"B`@("!A=71O
M;28C>$4Q.W1I8V%M96YT92!A;"!I;FEC:6%R(&QA('-E<VDF(WA&,SMN('1O
M9&%S(&QA<R!T87)E87,@9&4@;6%N=&5N:6UI96YT;PH@("`@<&5N9&EE;G1E
M<R!S:6X@;&$@<&]S:6)I;&ED860@9&4@8V%N8V5L87)L87,N"B`@("`\+W!A
M<F$^"CPO96YT<GD^"CPO:&5L<#X*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V5S7T53
M+TQ#7TU%4U-!1T53+P``````````````````````````````````````````
M```````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#4Q-30S,S<U,P`P,C$W,#``(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L;V-A;&4O97-?15,O3$-?34534T%'15,O:&]R9&4N;6\`````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P-#(Q-S,T`#$P-3$U-#,S-S4S`#`R,S,U,0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#>$@25
M`````(H'```<````;#P``!,*``"\>`````````BA```.````":$```\````8
MH0``#0```"BA```(````-J$```L````_H0``#````$NA```$````6*$``!@`
M``!=H0``&P```':A```M````DJ$``!T```#`H0``)````-ZA```I`````Z(`
M`!D````MH@``)@```$>B```,````;J(``"0```![H@``#P```*"B```+````
ML*(```X```"\H@``!0```,NB```H````T:(```@```#ZH@``"@````.C```5
M````#J,``!(````DHP``"P```#>C``"%````0Z,```X```#)HP``"@```-BC
M```-````XZ,```X```#QHP``$0````"D```-````$J0```P````@I```#0``
M`"VD```&````.Z0``)0```!"I```"@```->D```/````XJ0``!@```#RI```
M#`````NE```.````&*4```X````GI0``"````#:E```)````/Z4``"X```!)
MI0``&@```'BE```R````DZ4``#@```#&I0``5````/^E``!1````5*8``%H`
M``"FI@``5P````&G```T````6:<```D```".IP``#0```)BG```'````IJ<`
M``H```"NIP``#P```+FG```%````R:<```8```#/IP``$0```-:G```(````
MZ*<```D```#QIP``"0```/NG```E````!:@``"`````KJ```$P```$RH```0
M````8*@```\```!QJ```"@```(&H```#````C*@```\```"0J```%````*"H
M```)````M:@```T```"_J```$@```,VH```9````X*@``!X```#ZJ```#P``
M`!FI```*````*:D```\````TJ0``"````$2I```D````3:D``!0```!RJ0``
M%@```(>I```(````GJD``$X```"GJ0``+0```/:I```9````)*H```<````^
MJ@``#````$:J```L````4ZH```X```"`J@```P```(^J```+````DZH```<`
M``"?J@``!P```*>J```%````KZH```4```"UJ@``"@```+NJ```#````QJH`
M`!<```#*J@``"@```.*J```/````[:H```X```#]J@``&`````RK```C````
M):L```X```!)JP``%````%BK```7````;:L``!<```"%JP``%P```)VK```3
M````M:L```\```#)JP``#@```-FK```?````Z*L``!T````(K```!P```":L
M```&````+JP```@````UK```#P```#ZL```&````3JP```H```!5K```$P``
M`&"L```+````=*P``!````"`K```%0```)&L```5````IZP```<```"]K```
M$````,6L```%````UJP``!4```#<K```$0```/*L```,````!*T``#L````1
MK0``.````$VM```)````AJT```<```"0K0``%````)BM```#````K:T```4`
M``"QK0``$````+>M```)````R*T``!,```#2K0``.0```.:M```2````(*X`
M`"<````SK@``+````%NN```J````B*X``"4```"SK@``"@```-FN```&````
MY*X```D```#KK@``!P```/6N```O````_:X``#<````MKP``+@```&6O``!5
M````E*\``"T```#JKP``+0```!BP```]````1K```#\```"$L```+0```,2P
M``!`````\K```",````SL0``(P```%>Q``!`````>[$``"T```"\L0``,P``
M`.JQ```E````'K(``!4```!$L@``&0```%JR```I````=+(``"0```">L@``
M*````,.R```1````[+(```H```#^L@``#`````FS```*````%K,``!`````A
MLP``%@```#*S```6````2;,```<```!@LP``!P```&BS```4````<+,```H`
M``"%LP``"````)"S```G````F;,```@```#!LP``!P```,JS```'````TK,`
M``8```#:LP``!0```.&S```'````Y[,```8```#OLP``"````/:S```I````
M_[,```X````IM```"@```#BT```$````0[0```<```!(M```"0```%"T```&
M````6K0``!$```!AM```!P```'.T```6````>[0```0```"2M```"````)>T
M```&````H+0```T```"GM```!@```+6T```>````O+0``!$```#;M```"```
M`.VT```-````]K0```P````$M0``!P```!&U```#````&;4```,````=M0``
M%P```"&U```3````.;4``!T```!-M0``"````&NU```$````=+4```@```!Y
MM0``"````(*U```[````B[4``#0```#'M0``00```/RU```:````/K8``"L`
M``!9M@``(````(6V```5````IK8```8```"\M@``!@```,.V```5````RK8`
M`!@```#@M@``(@```/FV```N````'+<``!T```!+MP``(0```&FW``!4````
MB[<``"D```#@MP``"@````JX```'````%;@```<````=N```%0```"6X```.
M````.[@```H```!*N```#P```%6X```-````9;@```\```!SN```#0```(.X
M```)````D;@``!0```";N```!@```+"X```8````M[@``!T```#0N```$P``
M`.ZX```1`````KD``!0````4N0``!````"FY```&````+KD``!0````UN0``
M5````$JY``!D````G[D```0````$N@``#@````FZ```%````&+H```4````>
MN@``&P```"2Z```:````0+H``!,```!;N@``$0```&^Z```1````@;H``!P`
M``"3N@``*@```+"Z```0````V[H``"$```#LN@``!0````Z[```3````%+L`
M``L````HNP``$@```#2[```*````1[L```\```!2NP``#0```&*[```1````
M<+L``!,```""NP``#````):[```&````H[L```P```"JNP``!@```+>[```7
M````OKL``!````#6NP``$0```.>[```(````^;L```4````"O```#`````B\
M```0````%;P```4````FO```#0```"R\```&````.KP```<```!!O```#0``
M`$F\```'````5[P```L```!?O```!P```&N\```'````<[P```D```![O```
M"0```(6\```*````C[P``!D```":O```/0```+2\```=````\KP```P````0
MO0``$````!V]```%````+KT``"4````TO0``$@```%J]```3````;;T``"L`
M``"!O0``.P```*V]```@````Z;T```@````*O@``-@```!.^```A````2KX`
M`!````!LO@``"````'V^```,````AKX```8```"3O@``!````)J^```/````
MG[X```X```"OO@``!P```+Z^```*````QKX```T```#1O@``'P```-^^```<
M````_[X``"$````<OP``'@```#Z_```9````7;\``!X```!WOP``&P```):_
M```A````LK\``"X```#4OP``)@````/````<````*L```!X```!'P```'```
M`&;````F````@\```"L```"JP```,P```-;````F````"L$``"L````QP0``
M.````%W!```=````EL$``!4```"TP0``+P```,K!```@````^L$``!(````;
MP@``*0```"["```>````6,(``"````!WP@``$@```)C"``"B````J\(``!8`
M``!.PP``(P```&7#```H````B<,``"D```"RPP``*````-S#```?````!<0`
M`!4````EQ```(````#O$```E````7,0``"@```""Q```+0```*O$```P````
MV<0``)(````*Q0``(0```)W%```6````O\4``!P```#6Q0``)@```//%```J
M````&L8``$$```!%Q@``1````(?&```,````S,8```<```#9Q@``!P```.'&
M```&````Z<8```T```#PQ@``$````/[&```2````#\<``!,````BQP``$@``
M`#;'```'````2<<```0```!1QP``$````%;'```0````9\<```P```!XQP``
M#@```(7'```-````E,<```\```"BQP``$P```++'```-````QL<``"@```#4
MQP```P```/W'```-`````<@```8````/R```$0```!;(```7````*,@``!L`
M``!`R```#@```%S(```"````:\@``$D```!NR```!0```+C(```0````OL@`
M``\```#/R```!````-_(```-````Y,@```X```#RR````P````')```.````
M!<D```@````4R0``#P```!W)```/````+<D```<````]R0``#0```$7)```0
M````4\D```T```!DR0``"P```'+)```&````?LD```L```"%R0``#````)')
M```*````GLD``!$```"IR0``&0```+O)```+````U<D```T```#AR0``(@``
M`._)```/````$LH``!L````BR@``-````#[*```*````<\H``!@```!^R@``
M$@```)?*```9````JLH``!8```#$R@``(@```-O*```-````_LH```<````,
MRP``%````!3+```+````*<L``"(````URP``+P```%C+```+````B,L```D`
M``"4RP``&0```)[+```+````N,L``!<```#$RP``%P```-S+```)````],L`
M`!8```#^RP``#P```!7,```9````)<P``!8````_S```#@```%;,```8````
M9<P```@```!^S```#0```(?,```F````E<P``$,```"\S```"`````#-```2
M````"<T``!\````<S0``"````#S-```+````1<T``"\```!1S0``#@```('-
M```%````D,T```8```"6S0``10```)W-```#````X\T```<```#GS0``!```
M`._-```*````],T```H```#_S0``#P````K.```0````&LX``!<````KS@``
M$0```$/.```9````5<X``!<```!OS@``"0```(?.```%````D<X```L```"7
MS@``"@```*/.```"````KLX```4```"QS@``#0```+?.```;````Q<X``!<`
M``#AS@``%````/G.```)````#L\```X````8SP``#0```"?/```2````-<\`
M`#@```!(SP``(````('/```(````HL\```X```"KSP``>P```+K/```8````
M-M```!@```!/T```$0```&C0```'````>M````4```""T```&````(C0```>
M````H=```!L```#`T```&0```-S0```;````]M```!D````2T0``$P```"S1
M```'````0-$```@```!(T0``!@```%'1```&````6-$``!````!?T0``#P``
M`'#1```0````@-$```\```"1T0``"P```*'1```/````K=$```P```"]T0``
M#P```,K1```'````VM$```8```#BT0``#@```.G1```,````^-$``"@````%
MT@``#P```"[2```(````/M(```@```!'T@``$P```%#2```>````9-(``"$`
M``"#T@``(````*72```9````QM(``!<```#@T@``)0```/C2```7````'M,`
M`!8````VTP``!````$W3```;````4M,```T```!NTP``#````'S3```#````
MB=,```4```"-TP``"````)/3```*````G-,```P```"GTP``"P```+33```0
M````P-,```P```#1TP``#@```-[3```+````[=,```0```#YTP``!````/[3
M```3`````]0``!0````7U```#````"S4```)````.=0```X```!#U```"P``
M`%+4```;````7M0```<```!ZU```!P```(+4```*````BM0```T```"5U```
M"0```*/4```$````K=0```4```"RU````P```+C4```8````O-0```H```#5
MU```!````.#4```F````Y=0```X````,U0``?````!O5```5````F-4```4`
M``"NU0``!P```+35```,````O-4```@```#)U0``"@```-+5```&````W=4`
M``@```#DU0```@```.W5```&````\-4```8```#WU0``%````/[5```-````
M$]8``!`````AU@``&P```#+6```$````3M8```D```!3U@``$````%W6```)
M````;M8```D```!XU@``!0```(+6```:````B-8```@```"CU@``!@```*S6
M```9````L]8```X```#-U@``!P```-S6```'````Y-8```4```#LU@``"0``
M`/+6```*````_-8```X````'UP```@```!;7```&````&=<```L````@UP``
M#0```"S7```)````.M<```8```!$UP``$@```$O7```)````7M<```<```!H
MUP``%````'#7```=````A=<``$(```"CUP``)0```.;7```E````#-@```8`
M```RV```"@```#G8```$````1-@```D```!)V```"````%/8```1````7-@`
M``D```!NV```!@```'C8```-````?]@```8```"-V```!````)38```Y````
MF=@``#T```#3V```.@```!'9```>````3-D```4```!KV0``#@```''9```$
M````@-D```8```"%V0``!P```(S9```A````E-D```T```"VV0``%0```,39
M```&````VMD```0```#AV0``$0```.;9```&````^-D```H```#_V0``(@``
M``K:```$````+=H```4````RV@``'0```#C:```$````5MH```P```!;V@``
M#@```&C:```*````=]H```@```""V@``"0```(O:```%````E=H``#H```";
MV@``,````-;:```U````!]L``"D````]VP``1P```&?;```X````K]L``"D`
M``#HVP``/P```!+<```N````4MP``"T```"!W```'P```*_<```/````S]P`
M`!(```#?W```"P```/+<```F````_MP``"D````EW0``)````$_=```F````
M=-T```@```";W0``"@```*3=```)````K]T```<```"YW0``(````,'=```@
M````XMT``"8````#W@``"@```"K>```9````-=X``"D```!/W@``%@```'G>
M```2````D-X```<```"CW@``"@```*O>```,````MMX```\```##W@``$```
M`-/>``!`````Y-X``'`````EWP``9@```);?```.````_=\```D````,X```
M"@```!;@```2````(>```!,````TX```#````$C@```&````5>````\```!<
MX```$@```&S@```0````?^```!$```"0X```'````*+@```C````O^```&H`
M``#CX```#P```$[A```%````7N$``!````!DX0``"0```'7A```$````?^$`
M``L```"$X0``(````)#A```4````L>$```P```#&X0``#````-/A```/````
MX.$``!4```#PX0``*0````;B```J````,.(``"8```!;X@``)P```(+B```I
M````JN(``"H```#4X@``&0```/_B``!"````&>,``!$```!<XP``$@```&[C
M```3````@>,``!0```"5XP``#P```*KC```6````NN,``!<```#1XP``$```
M`.GC```1````^N,``#0````,Y```$P```$'D```2````5>0``#4```!HY```
M%````)[D```'````L^0```P```"[Y```(````,CD```0````Z>0``!0```#Z
MY```$0````_E```7````(>4``!P````YY0``$P```%;E```4````:N4``!H`
M``!_Y0``$0```)KE```:````K.4``!X```#'Y0``&@```.;E```3`````>8`
M`!4````5Y@``$0```"OF```7````/>8``!0```!5Y@``%P```&KF```5````
M@N8```D```"8Y@``$````*+F```9````L^8```0```#-Y@``!P```-+F```+
M````VN8``!$```#FY@``!@```/CF```&````_^8```8````&YP``!0````WG
M```'````$^<```<````;YP``!0```"/G```6````*><```8```!`YP``!@``
M`$?G```$````3N<```0```!3YP``!P```%CG```.````8.<```P```!OYP``
M#````'SG```-````B><```H```"7YP``#@```*+G```%````L><``"@```"W
MYP``#@```.#G```,````[^<```\```#\YP``"@````SH```(````%^@```D`
M```@Z```*P```"KH```$````5N@```@```!;Z```)@```&3H```2````B^@`
M``\```">Z```!@```*[H```*````M>@```<```#`Z```"````,CH```@````
MT>@```D```#RZ```%````/SH```,````$>D```T````>Z0``#@```"SI```6
M````.^D``!$```!2Z0``!@```&3I```#````:^D```8```!OZ0``&0```';I
M```'````D.D```0```"8Z0``"P```)WI```+````J>D```<```"UZ0``!0``
M`+WI```'````P^D``!8```#+Z0``#0```.+I```-````\.D```H```#^Z0``
M$`````GJ```/````&NH``!$````JZ@``%P```#SJ```*````5.H``!$```!?
MZ@``"````''J```$````>NH```\```!_Z@``.@```(_J```%````RNH```P`
M``#0Z@``'@```-WJ```.````_.H``!`````+ZP``"P```!SK```,````*.L`
M``D````UZP``!P```#_K```*````1^L```D```!2ZP``#@```%SK```0````
M:^L``!L```!\ZP``&````)CK```:````L>L```H```#,ZP``"0```-?K```*
M````X>L```P```#LZP``#P```/GK```(````">P```8````2[```'````!GL
M```'````-NP```4````^[```"P```$3L``!'````4.P```T```"8[```"0``
M`*;L```$````L.P```,```"U[```$P```+GL```3````S>P``!,```#A[```
M"@```/7L```"`````.T```0````#[0``)0````CM```#````+NT```4````R
M[0``*@```#CM```*````8^T```4```!N[0``!````'3M```*````>>T```T`
M``"$[0``!@```)+M```(````F>T```@```"B[0``!````*OM```%````L.T`
M`&@```"V[0``"0```!_N```,````*>X``!`````V[@``!0```$?N```&````
M3>X``!L```!4[@``+P```'#N```0````H.X```H```"Q[@``#P```+SN```*
M````S.X```D```#7[@``$P```.'N```;````]>X``!@````1[P``%P```"KO
M```?````0N\```X```!B[P```P```''O```'````=>\```@```!][P``!P``
M`(;O```*````CN\```L```"9[P``!P```*7O``!1````K>\``!````#_[P``
M#````!#P```-````'?```!H````K\```2@```$;P```9````D?````8```"K
M\```&@```++P```E````S?````8```#S\```!@```/KP```?`````?$```8`
M```A\0``"0```"CQ```8````,O$``!<```!+\0``*````&/Q```&````C/$`
M``T```"3\0``(@```*'Q``!7````Q/$``!,````<\@``(P```##R```3````
M5/(```(```!H\@``"P```&OR```(````=_(```T```"`\@``"@```([R```'
M````F?(``!0```"A\@``!@```+;R```(````O?(```X```#&\@``!P```-7R
M```*````W?(```L```#H\@``,@```/3R```'````)_,```P````O\P``#0``
M`#SS```7````2O,```P```!B\P``"0```&_S```)````>?,```H```"#\P``
M!P```([S```)````EO,```<```"@\P``"@```*CS```;````L_,```\```#/
M\P``$@```-_S```*````\O,``!8```#]\P``"0```!3T```0````'O0```<`
M```O]```$@```#?T```$````2O0```<```!/]```!0```%?T```%````7?0`
M``L```!C]```%````&_T```1````A/0``!H```"6]```%@```+'T```4````
MR/0``!<```#=]```&````/7T```<````#O4``!D````K]0``!P```$7U```%
M````3?4```T```!3]0``#````&'U```(````;O4``!<```!W]0``"P```(_U
M```,````F_4``!\```"H]0``&@```,CU```3````X_4```0```#W]0``"@``
M`/SU```$````!_8```T````,]@``#````!KV```%````)_8```D````M]@``
M!0```#?V```'````/?8```4```!%]@``!````$OV```"````4/8``#@```!3
M]@``+````(SV```2````N?8``"D```#,]@``,@```/;V```*````*?<``"P`
M```T]P``+@```&'W```S````D/<``#,```#$]P``.````/CW```/````,?@`
M`!@```!!^```$````%KX```/````:_@``!,```![^```%0```(_X```4````
MI?@``!(```"Z^```%````,WX```5````XO@``"T```#X^```+0```";Y```Q
M````5/D``"X```"&^0``+P```+7Y```L````Y?D``&(````2^@``$P```'7Z
M```-````B?H```@```"7^@``%P```*#Z```(````N/H```P```#!^@``*P``
M`,[Z```A````^OH``!H````<^P``"0```#?[``!%````0?L``$$```"'^P``
M!````,G[```3````SOL``!0```#B^P``#@```/?[```3````!OP``!@````:
M_```!@```#/\```)````.OP```H```!$_```#P```$_\```0````7_P```<`
M``!P_```#@```'C\```%````A_P``!L```"-_```"````*G\```&````LOP`
M`!0```"Y_```$0```,[\```.````X/P``#@```#O_````@```"C]```&````
M*_T```X````R_0``!0```$']```'````1_T```X```!/_0``!@```%[]```H
M````9?T```P```"._0``'````)O]```$````N/T``"D```"]_0``%P```.?]
M```?````__T``%P````?_@``%````'S^```^````D?X``!\```#0_@``$```
M`/#^```'`````?\```X````)_P``#````!C_```,````)?\``!,````R_P``
M"@```$;_```=````4?\``!D```!O_P``!0```(G_```1````C_\``!$```"A
M_P``)````+/_```2````V/\``!4```#K_P``$@````$``0`.````%``!`!D`
M```C``$`"````#T``0`)````1@`!``T```!0``$`!P```%X``0`*````9@`!
M``<```!Q``$`#P```'D``0`&````B0`!``L```"0``$`&@```)P``0`*````
MMP`!``<```#"``$`"````,H``0`%````TP`!`!\```#9``$`!@```/D``0`0
M``````$!``@````1`0$`#0```!H!`0`(````*`$!`!X````Q`0$`$@```%`!
M`0`L````8P$!`!H```"0`0$`"0```*L!`0`*````M0$!`!4```#``0$`!0``
M`-8!`0`4````W`$!``0```#Q`0$`$````/8!`0`&````!P(!``<````.`@$`
M'@```!8"`0`H````-0(!``H```!>`@$`'````&D"`0`1````A@(!``L```"8
M`@$`&@```*0"`0`4````OP(!``0```#4`@$`!````-D"`0`+````W@(!``4`
M``#J`@$`!@```/`"`0`(````]P(!``8``````P$`"@````<#`0`;````$@,!
M`#0````N`P$`-````&,#`0`@````F`,!`"D```"Y`P$`(````.,#`0!!````
M!`0!`!H```!&!`$`*````&$$`0`I````B@0!`%````"T!`$`(@````4%`0`&
M````*`4!``@````O!0$`!0```#@%`0`(````/@4!`!D```!'!0$`&0```&$%
M`0`J````>P4!`",```"F!0$`&0```,H%`0`N````Y`4!`#0````3!@$`"```
M`$@&`0`7````408!``H```!I!@$`!P```'0&`0`A````?`8!`!````">!@$`
M#@```*\&`0`+````O@8!``<```#*!@$`$P```-(&`0`(````Y@8!``L```#O
M!@$`"@```/L&`0`4````!@<!``\````;!P$`,@```"L'`0`+````7@<!``X`
M``!J!P$`!0```'D'`0`%````?P<!``4```"%!P$`%P```(L'`0`/````HP<!
M``0```"S!P$`"@```+@'`0`)````PP<!``L```#-!P$`#0```-D'`0`,````
MYP<!``X```#T!P$`!0````,(`0`$````"0@!``T````."`$`,@```!P(`0!%
M````3P@!`!<```"5"`$`!P```*T(`0`>````M0@!`!0```#4"`$`!0```.D(
M`0`4````[P@!``8````$"0$`!P````L)`0`.````$PD!`"H````B"0$`!@``
M`$T)`0`,````5`D!``T```!A"0$`$0```&\)`0`+````@0D!`#8```"-"0$`
M"@```,0)`0`B````SPD!``L```#R"0$`#P```/X)`0`R````#@H!`"4```!!
M"@$`,````&<*`0`Q````F`H!`"T```#*"@$`#@```/@*`0`%````!PL!``X`
M```-"P$`$P```!P+`0`2````,`L!``<```!#"P$`$0```$L+`0`3````70L!
M``<```!Q"P$`%````'D+`0`8````C@L!``<```"G"P$`!0```*\+`0`,````
MM0L!``P```#""P$`$@```,\+`0`$````X@L!``<```#G"P$`"@```.\+`0`+
M````^@L!``P````&#`$`#@```!,,`0`.````(@P!``4````Q#`$`!0```#<,
M`0`N````/0P!`"8```!L#`$`(P```),,`0`#````MPP!`!(```"[#`$`!@``
M`,X,`0`>````U0P!`!@```#T#`$`)0````T-`0`-````,PT!``D```!!#0$`
M'P```$L-`0`#````:PT!``<```!O#0$`"@```'<-`0`"````@@T!``P```"%
M#0$`%0```)(-`0`+````J`T!`!D```"T#0$`(````,X-`0`2````[PT!``4`
M```"#@$`"@````@.`0`5````$PX!`!(````I#@$`#````#P.`0`$````20X!
M``D```!.#@$`!P```%@.`0`,````8`X!`%(```!M#@$`%P```,`.`0`D````
MV`X!`!(```#]#@$`!P```!`/`0`&````&`\!``X````?#P$`#````"X/`0`-
M````.P\!`!4```!)#P$`$@```%\/`0`/````<@\!`!0```""#P$`"@```)</
M`0`;````H@\!`!````"^#P$`"P```,\/`0!I````VP\!`!H```!%$`$`%P``
M`&`0`0`G````>!`!`!H```"@$`$`%P```+L0`0`;````TQ`!`!D```#O$`$`
M'P````D1`0`3````*1$!``@````]$0$`!P```$81`0`(````3A$!``D```!7
M$0$`%0```&$1`0`-````=Q$!`",```"%$0$`#0```*D1`0`3````MQ$!``@`
M``#+$0$``P```-01`0!&````V!$!`#\````?$@$`-P```%\2`0!7````EQ(!
M``4```#O$@$`'P```/42`0`O````%1,!``H```!%$P$`"````%`3`0`-````
M61,!`"T```!G$P$`!````)43`0!/````FA,!`"4```#J$P$`'````!`4`0`+
M````+10!`!\````Y%`$`'0```%D4`0`E````=Q0!`"````"=%`$`)````+X4
M`0`@````XQ0!``L````$%0$`!P```!`5`0`-````&!4!``P````F%0$`%P``
M`#,5`0`&````2Q4!`#D```!2%0$`#````(P5`0`'````F14!``D```"A%0$`
M$P```*L5`0`)````OQ4!``0```#)%0$`$````,X5`0`(````WQ4!``@```#H
M%0$`!````/$5`0`+````]A4!``P````"%@$`$@````\6`0`1````(A8!``P`
M```T%@$`&@```$$6`0`/````7!8!``<```!L%@$`#0```'06`0`4````@A8!
M``X```"7%@$`#````*86`0`;````LQ8!`"P```#/%@$`$P```/P6`0`<````
M$!<!`"@````M%P$`!@```%87`0`'````71<!`!,```!E%P$`!0```'D7`0`$
M````?Q<!`!<```"$%P$`"@```)P7`0`,````IQ<!``D```"T%P$`!@```+X7
M`0`)````Q1<!``@```#/%P$`"0```-@7`0`*````XA<!`!$```#M%P$`!@``
M`/\7`0`.````!A@!``X````5&`$`#0```"08`0`+````,A@!`!T````^&`$`
M"P```%P8`0`"````:!@!`!P```!K&`$`!P```(@8`0`&````D!@!`&0```"7
M&`$`"0```/P8`0`'````!AD!`"8````.&0$`.````#49`0`:````;AD!`"H`
M``")&0$`.P```+09`0`H````\!D!`#0````9&@$`&0```$X:`0`5````:!H!
M``4```!^&@$`!P```(0:`0`(````C!H!``<```"5&@$`!0```)T:`0`'````
MHQH!``X```"K&@$`"0```+H:`0`&````Q!H!``@```#+&@$`"P```-0:`0`'
M````X!H!``@```#H&@$`!P```/$:`0`6````^1H!``D````0&P$`!@```!H;
M`0`+````(1L!`!`````M&P$`!@```#X;`0`<````11L!`!0```!B&P$`!P``
M`'<;`0`1````?QL!``@```"1&P$`#@```)H;`0`(````J1L!`!````"R&P$`
M"0```,,;`0`0````S1L!``8```#>&P$`&0```.4;`0`*````_QL!`!P````*
M'`$`!P```"<<`0`%````+QP!`!`````U'`$`%````$8<`0`+````6QP!``T`
M``!G'`$`*````'4<`0`8````GAP!`!<```"W'`$`!````,\<`0`)````U!P!
M``H```#>'`$`!P```.D<`0`"````\1P!``X```#T'`$`"`````,=`0`C````
M#!T!`!\````P'0$`.````%`=`0`F````B1T!`#$```"P'0$`)P```.(=`0!D
M````"AX!`!0```!O'@$`50```(0>`0`X````VAX!`$H````3'P$`6P```%X?
M`0`H````NA\!`#@```#C'P$`*````!P@`0`L````12`!`!L```!R(`$`/@``
M`(X@`0"I`0``S2`!`",```!W(@$`%P```)LB`0!(````LR(!`(4```#\(@$`
M,````((C`0`E````LR,!`$$```#9(P$`6P```!LD`0!)````=R0!`#$```#!
M)`$`'0```/,D`0`8````$24!`"L````J)0$`(0```%8E`0`?````>"4!`"L`
M``"8)0$`)@```,0E`0`G````ZR4!`#H````3)@$`'0```$XF`0`1````;"8!
M`#,```!^)@$`)0```+(F`0`G````V"8!`"``````)P$`'P```"$G`0`P````
M02<!`&D```!R)P$`,0```-PG`0!!````#B@!`#,```!0*`$`)0```(0H`0`]
M````JB@!`&4```#H*`$`30```$XI`0`O````G"D!`"X```#,*0$`,````/LI
M`0!4````+"H!`%H```"!*@$`2````-PJ`0!*````)2L!`#(```!P*P$`+P``
M`*,K`0`L````TRL!`"T`````+`$`<0```"XL`0!F````H"P!`&\````'+0$`
MLP```'<M`0`7````*RX!`"4```!#+@$`,@```&DN`0`I````G"X!`#X```#&
M+@$`(@````4O`0!2````*"\!`"4```![+P$`"P```*$O`0"Q````K2\!`$4`
M``!?,`$`(0```*4P`0`P````QS`!`"4```#X,`$`'````!XQ`0`Q````.S$!
M``<```!M,0$`!P```'4Q`0`$````?3$!``T```"",0$`"P```)`Q`0`.````
MG#$!``L```"K,0$`!0```+<Q`0`0````O3$!``(```#.,0$`60```-$Q`0`%
M````*S(!`!(````Q,@$`!````$0R`0`'````23(!``@```!1,@$`!0```%HR
M`0`P````8#(!``,```"1,@$`$````)4R`0`,````IC(!`!,```"S,@$`#0``
M`,<R`0`"````U3(!``<```#8,@$`!@```.`R`0`4````YS(!``P```#\,@$`
M&`````DS`0`&````(C,!`!(````I,P$`#````#PS`0`#````23,!`"H```!-
M,P$`!````'@S`0`&````?3,!``<```"$,P$`'P```(PS`0`U````K#,!`"X`
M``#B,P$`+P```!$T`0`7````030!`"(```!9-`$`)0```'PT`0`@````HC0!
M`!L```##-`$`&````-\T`0`D````^#0!`!\````=-0$`&@```#TU`0`A````
M6#4!`"````!Z-0$`&@```)LU`0`R````MC4!`!H```#I-0$`+P````0V`0`K
M````-#8!`!\```!@-@$`(P```(`V`0`?````I#8!`!H```#$-@$`(0```-\V
M`0`E`````3<!`"8````G-P$`)0```$XW`0`D````=#<!`!@```"9-P$`'0``
M`+(W`0`D````T#<!`!@```#U-P$`(@````XX`0`L````,3@!`"\```!>.`$`
M%0```(XX`0`E````I#@!`#P```#*.`$`'P````<Y`0`C````)SD!`!\```!+
M.0$`(````&LY`0`:````C#D!`!@```"G.0$`*0```,`Y`0`>````ZCD!`"D`
M```).@$`'@```#,Z`0`Q````4CH!``D```"$.@$`#````(XZ`0`7````FSH!
M`"\```"S.@$`)````.,Z`0`'````"#L!``\````0.P$`%````"`[`0`.````
M-3L!``T```!$.P$`)````%([`0`%````=SL!``<```!].P$`(@```(4[`0`E
M````J#L!`!H```#..P$`'0```.D[`0`:````!SP!``<````B/`$`QP```"H\
M`0`+````\CP!`!4```#^/`$`!@```!0]`0`)````&ST!``L````E/0$`#0``
M`#$]`0`7````/ST!``8```!7/0$`,P```%X]`0`3````DCT!`!,```"F/0$`
M!P```+H]`0`/````PCT!``<```#2/0$`,@```-H]`0`$````#3X!`"$````2
M/@$`$P```#0^`0`,````2#X!`!$```!5/@$`,@```&<^`0`6````FCX!``@`
M``"Q/@$`'0```+H^`0`)````V#X!``H```#B/@$`%````.T^`0`*`````C\!
M`!T````-/P$`"````"L_`0`?````-#\!``@```!4/P$`&@```%T_`0`G````
M>#\!``8```"@/P$`%0```*<_`0`'````O3\!``@```#%/P$`"0```,X_`0`_
M````V#\!``<````80`$`#P```"!``0`.````,$`!`!`````_0`$`"0```%!`
M`0`)````6D`!``@```!D0`$`$P```&U``0`'````@4`!`!D```")0`$`"@``
M`*-``0`7````KD`!`!0```#&0`$`"@```-M``0`,````YD`!`!<```#S0`$`
M!`````M!`0`J````$$$!``P````[00$`$0```$A!`0`'````6D$!``(```!B
M00$`$````&5!`0`8````=D$!``L```"/00$``P```)M!`0`(````GT$!``8`
M``"H00$`!P```*]!`0`-````MT$!``L```#%00$`%````-%!`0`5````YD$!
M``X```#\00$`+P````M"`0`@````.T(!`!P```!<0@$`%0```'E"`0`,````
MCT(!`#$```"<0@$`!0```,Y"`0`2````U$(!`#\```#G0@$`$@```"=#`0`*
M````.D,!``8```!%0P$`!````$Q#`0`$````44,!``H```!60P$`$P```&%#
M`0`%````=4,!``8```![0P$`!@```()#`0`(````B4,!``0```"20P$`#```
M`)=#`0`*````I$,!`#D```"O0P$`+@```.E#`0`I````&$0!``4```!"1`$`
M&````$A$`0`9````840!`!\```![1`$`'0```)M$`0`1````N40!``(```#+
M1`$`!````,Y$`0`*````TT0!``8```#>1`$`!0```.5$`0`#````ZT0!``P`
M``#O1`$`10```/Q$`0`R````0D4!`!H```!U10$`-````)!%`0`H````Q44!
M`%,```#N10$`&0```$)&`0!R````7$8!`"````#/1@$`-0```/!&`0`A````
M)D<!`$4```!(1P$`,````(Y'`0`H````OT<!`"D```#H1P$`)@```!)(`0`E
M````.4@!`"@```!?2`$`*````(A(`0`B````L4@!`"L```#42`$`,`````!)
M`0`2````,4D!`!,```!$20$`$````%A)`0!Y````:4D!``D```#C20$`H0``
M`.U)`0!S````CTH!`'P````#2P$`*P```(!+`0!4````K$L!`!<````!3`$`
M)P```!E,`0`6````04P!``\```!83`$`%P```&A,`0`?````@$P!`$````"@
M3`$`'P```.%,`0`<`````4T!`%$````>30$`&@```'!-`0`4````BTT!``H`
M``"@30$`!0```*M-`0`&````L4T!``@```"X30$`!0```,%-`0`2````QTT!
M`!````#:30$`$P```.M-`0`=````_TT!``\````=3@$`#P```"U.`0`$````
M/4X!``D```!"3@$`"P```$Q.`0`'````6$X!``4```!@3@$`%````&9.`0`'
M````>TX!``@```"#3@$`#P```(Q.`0`(````G$X!``P```"E3@$`#P```+).
M`0`&````PDX!`!0```#)3@$`!@```-Y.`0`,````Y4X!`!$```#R3@$`"```
M``1/`0`$````#4\!`!D````23P$`$0```"Q/`0`*````/D\!`!@```!)3P$`
M$P```&)/`0`<````=D\!`!$```"33P$`!````*5/`0`/````JD\!``<```"Z
M3P$`!````,)/`0`9````QT\!``<```#A3P$``@```.E/`0`"````[$\!`!$`
M``#O3P$`"0````%0`0`&````"U`!`!(````24`$`%P```"50`0`&````/5`!
M`"<```!$4`$``@```&Q0`0`$````;U`!``\```!T4`$`$P```(10`0`'````
MF%`!``<```"@4`$`$0```*A0`0`&````NE`!`!@```#!4`$`!@```-I0`0`3
M````X5`!`!````#U4`$`$@````91`0`"````&5$!``8````<40$`#````"-1
M`0`)````,%$!`!$````Z40$`(@```$Q1`0`'````;U$!``<```!W40$`"P``
M`']1`0`%````BU$!``(```"140$`"P```)11`0!]`0``H%$!``\````>4P$`
M$@```"Y3`0`-````05,!``8```!/4P$`"0```%93`0`'````8%,!``,```!H
M4P$`&0```&Q3`0`?````AE,!`#(```"F4P$`+P```-E3`0`H````"50!`"T`
M```R5`$`&0```&!4`0`K````>E0!``H```"F5`$`+@```+%4`0`6````X%0!
M``H```#W5`$`%`````)5`0`%````%U4!`"X````=50$`$P```$Q5`0`+````
M8%4!`!H```!L50$`#0```(=5`0`.````E54!`)D```"D50$`#0```#Y6`0`*
M````3%8!`!<```!75@$`#@```&]6`0`1````?E8!``P```"05@$`%@```)U6
M`0`,````M%8!``8```#!5@$`G0```,A6`0`*````9E<!``\```!Q5P$`%0``
M`(%7`0`1````EU<!`!,```"I5P$`$P```+U7`0`(````T5<!``D```#:5P$`
M-@```.17`0`D````&U@!`#@```!`6`$`0P```'E8`0!E````O5@!`&(````C
M60$`:P```(99`0!H````\ED!`#H```!;6@$`#P```)9:`0`5````IEH!``X`
M``"\6@$`$P```,M:`0`9````WUH!``4```#Y6@$`"0```/]:`0`1````"5L!
M``P````;6P$`#0```"A;`0`-````-EL!`#0```!$6P$`,0```'E;`0`)````
MJUL!`!0```"U6P$`%````,I;`0`,````WUL!``8```#L6P$`&0```/-;`0`>
M````#5P!``P````L7`$`#````#E<`0`1````1EP!`",```!87`$`*````'Q<
M`0`2````I5P!``X```"X7`$`#P```,=<`0`*````UUP!`"\```#B7`$`&0``
M`!)=`0`9````+%T!``X```!&70$`7````%5=`0`Z````LET!`"H```#M70$`
M"0```!A>`0`+````(EX!`#0````N7@$`#@```&->`0`(````<EX!``H```![
M7@$`!P```(9>`0`'````CEX!``4```"67@$`!P```)Q>`0`+````I%X!``4`
M``"P7@$`(0```+9>`0`0````V%X!`!4```#I7@$`#P```/]>`0`;````#U\!
M`#0````K7P$`"0```&!?`0`7````:E\!`!8```""7P$`&````)E?`0`A````
MLE\!`!<```#47P$`$0```.Q?`0`/````_E\!`!\````.8`$`)0```"Y@`0`'
M````5&`!``8```!<8`$`!P```&-@`0`-````:V`!``D```!Y8`$`"0```(-@
M`0`2````C6`!``H```"@8`$`%0```*M@`0`9````P6`!`"P```#;8`$`!P``
M``AA`0`1````$&$!``4````B80$`%@```"AA`0`2````/V$!`!(```!280$`
M/@```&5A`0`^````I&$!``D```#C80$`!P```.UA`0`3````]6$!``0````)
M8@$`!0````YB`0`.````%&(!``X````C8@$`%P```#)B`0!'````2F(!`!8`
M``"28@$`)@```*EB`0`K````T&(!`"P```#\8@$`-````"EC`0`)````7F,!
M``8```!H8P$`"0```&]C`0`'````>6,!`#@```"!8P$`.@```+IC`0`W````
M]6,!`%P````M9`$`-@```(ID`0`V````P60!`$<```#X9`$`2P```$!E`0`V
M````C&4!`$X```##90$`+````!)F`0`N````/V8!`$T```!N9@$`-@```+QF
M`0`\````\V8!`"X````P9P$`&````%]G`0`<````>&<!`#,```"59P$`+0``
M`,EG`0`M````]V<!`!,````E:`$`"@```#EH`0`,````1&@!``4```!1:`$`
M#@```%=H`0`?````9F@!`"8```"&:`$`!P```*UH`0`'````M6@!`!4```"]
M:`$`"@```--H`0`(````WF@!`#,```#G:`$`"@```!MI`0`'````)FD!``<`
M```N:0$`!@```#9I`0`%````/6D!``@```!#:0$`!@```$QI`0`*````4VD!
M`#0```!>:0$`$@```)-I`0`.````IFD!``<```"U:0$`!P```+UI`0`*````
MQ6D!``4```#0:0$`$0```-9I`0`&````Z&D!`!(```#O:0$`!0````)J`0`(
M````"&H!``@````1:@$`#@```!IJ`0`&````*6H!`"D````P:@$`$0```%IJ
M`0`(````;&H!`!$```!U:@$`#````(=J`0`'````E&H!``,```"<:@$``P``
M`*!J`0`:````I&H!`!@```"_:@$`*@```-AJ`0`&`````VL!``4````*:P$`
M!P```!!K`0`'````&&L!`$@````@:P$`3P```&EK`0!E````N6L!`"<````?
M;`$`.````$=L`0`I````@&P!`"(```"J;`$`!@```,UL`0`(````U&P!`!T`
M``#=;`$`)0```/ML`0`G````(6T!`#0```!);0$`*````'YM`0`M````IVT!
M`&(```#5;0$`-@```#AN`0`*````;VX!``D```!Z;@$`"0```(1N`0`6````
MCFX!``P```"E;@$`#@```+)N`0`4````P6X!`!````#6;@$`%````.=N`0`3
M````_&X!``X````0;P$`%0```!]O`0`'````-6\!`!@````];P$`&P```%9O
M`0`8````<F\!`!L```"+;P$`&0```*=O`0`$````P6\!``<```#&;P$`%```
M`,YO`0!8````XV\!`'(````\<`$`!P```*]P`0`5````MW`!``4```#-<`$`
M!0```--P`0`;````V7`!`!@```#U<`$`"P````YQ`0`4````&G$!`!H````O
M<0$`'@```$IQ`0`[````:7$!``X```"E<0$`+````+1Q`0`'````X7$!`!L`
M``#I<0$`#P````5R`0`2````%7(!``X````H<@$`&````#=R`0`0````4'(!
M`!8```!A<@$`$P```'AR`0`.````C'(!``4```";<@$`#P```*%R`0`&````
ML7(!`!@```"X<@$`%0```-%R`0`/````YW(!``@```#W<@$`!0````!S`0`1
M````!G,!`!(````8<P$`"0```"MS`0`7````-7,!``8```!-<P$`!P```%1S
M`0`1````7',!``H```!N<P$`#````'ES`0`'````AG,!``@```".<P$`"P``
M`)=S`0`)````HW,!``L```"M<P$`'P```+ES`0!)````V7,!`"4````C=`$`
M#0```$ET`0`4````5W0!``4```!L=`$`(````')T`0`2````DW0!`!,```"F
M=`$`.@```+IT`0!*````]70!`"<```!`=0$`"0```&AU`0`\````<G4!`"H`
M``"O=0$`$0```-IU`0`)````['4!``H```#V=0$`!@````%V`0`&````"'8!
M`!(````/=@$`$````")V`0`+````,W8!``H````_=@$`#P```$IV`0`L````
M6G8!`"P```"'=@$`+0```+1V`0`N````XG8!`"(````1=P$`)0```#1W`0`B
M````6G<!`"8```!]=P$`-@```*1W`0`N````VW<!`"8````*>`$`*````#%X
M`0`D````6G@!`#$```!_>`$`10```+%X`0!`````]W@!`#4````X>0$`-```
M`&YY`0`^````HWD!`"8```#B>0$`)0````EZ`0`\````+WH!`"4```!L>@$`
M%0```))Z`0`Y````J'H!`"4```#B>@$`)P````A[`0`4````,'L!`,H```!%
M>P$`&P```!!\`0`Q````+'P!`#````!>?`$`,P```(]\`0`Q````PWP!`"<`
M``#U?`$`*````!U]`0`K````1GT!`#(```!R?0$`-0```*5]`0!+````VWT!
M`#0````G?@$`I````%Q^`0`G`````7\!`!T````I?P$`)@```$=_`0`S````
M;G\!`#$```"B?P$`3@```-1_`0!5````(X`!``T```!Y@`$`!````(>``0`&
M````C(`!``4```"3@`$`#P```)F``0`%````J8`!`!$```"O@`$`%@```,&`
M`0`<````V(`!``<```#U@`$`!````/V``0`0`````H$!`!$````3@0$`"P``
M`"6!`0`*````,8$!`!$````\@0$`#0```$Z!`0`2````7($!``T```!O@0$`
M.@```'V!`0`&````N($!`!````"_@0$`!@```-"!`0`1````UX$!`!<```#I
M@0$`&P````&"`0`/````'8(!``(````M@@$`20```#""`0`+````>H(!``P`
M``"&@@$`'````)."`0`%````L((!`!<```"V@@$`$@```,Z"`0`#````X8(!
M`!$```#E@@$`"0```/>"`0`1`````8,!`!`````3@P$`"P```"2#`0`1````
M,(,!`!4```!"@P$`$0```%B#`0`,````:H,!`!0```!W@P$`#@```(R#`0`.
M````FX,!`!$```"J@P$`$P```+R#`0`:````T(,!``X```#K@P$`$````/J#
M`0`K````"X0!`!$````WA`$`'````$F$`0!$````9H0!``T```"KA`$`'P``
M`+F$`0`4````V80!`!D```#NA`$`%@````B%`0!#````'X4!`!````!CA0$`
M"0```'2%`0`4````?H4!``L```"3A0$`-@```)^%`0`U````UH4!``H````,
MA@$`%0```!>&`0`I````+88!`!<```!7A@$`%@```&^&`0`6````AH8!``H`
M``"=A@$`(````*B&`0`9````R88!`!P```#CA@$`&`````"'`0`9````&8<!
M`!@````SAP$`"````$R'`0`+````58<!`"D```!AAP$`6````(N'`0`(````
MY(<!`!0```#MAP$`(@````*(`0`)````)8@!``P````OB`$`-@```#R(`0`1
M````<X@!``8```"%B`$`!@```(R(`0!5````DX@!``,```#IB`$`!P```.V(
M`0`5````]8@!`!`````+B0$`#P```!R)`0`4````+(D!`!4```!!B0$`&P``
M`%>)`0`6````<XD!`!T```"*B0$`&P```*B)`0`)````Q(D!``8```#.B0$`
M"P```-6)`0`+````X8D!``(```#MB0$`!@```/")`0`3````]XD!`"\````+
MB@$`%P```#N*`0`5````4XH!``H```!IB@$`$0```'2*`0`4````AHH!`!P`
M``";B@$`.0```+B*`0`W````\HH!`!(````JBP$`#P```#V+`0"&````38L!
M`",```#4BP$`(````/B+`0`1````&8P!``<````KC`$`!0```#.,`0`<````
M.8P!`"T```!6C`$`,P```(2,`0`?````N(P!`"4```#8C`$`'P```/Z,`0`7
M````'HT!``<````VC0$`!P```#Z-`0`&````1HT!``8```!-C0$`#P```%2-
M`0`.````9(T!`!````!SC0$`#@```(2-`0`5````DXT!``\```"IC0$`"P``
M`+F-`0`3````Q8T!``@```#9C0$`"````.*-`0`5````ZXT!``\````!C@$`
M10```!&.`0`4````5XX!``D```!LC@$`#@```':.`0`?````A8X!`"````"E
MC@$`)P```,:.`0`F````[HX!`!@````5CP$`%P```"Z/`0`@````1H\!`!@`
M``!GCP$`%@```("/`0`)````EX\!`!D```"ACP$`"P```+N/`0`4````QX\!
M``,```#<CP$`!0```."/`0`'````YH\!``X```#NCP$`$````/V/`0`-````
M#I`!`!@````<D`$`$````#60`0`1````1I`!``\```!8D`$`!````&B0`0`'
M````;9`!`!H```!UD`$`&P```)"0`0`(````K)`!`!$```"UD`$`%````,>0
M`0`.````W)`!`"<```#KD`$`!P```!.1`0`)````&Y$!`!`````ED0$`$```
M`#:1`0`*````1Y$!``<```!2D0$`"P```%J1`0`&````9I$!`!@```!MD0$`
M#@```(:1`0`&````E9$!`"@```"<D0$`$````,61`0";````UI$!`!L```!R
MD@$`"P```(Z2`0`'````FI(!``\```"BD@$`"````+*2`0`*````NY(!``4`
M``#&D@$`"````,R2`0`#````U9(!``8```#9D@$`!P```."2`0`6````Z)(!
M`!````#_D@$`$@```!"3`0`=````(Y,!``(```!!DP$`!````$23`0`4````
M29,!``H```!>DP$`#P```&F3`0`%````>9,!`",```!_DP$`"````*.3`0`&
M````K),!`!L```"SDP$`#P```,^3`0`'````WY,!``@```#GDP$`!0```/"3
M`0`)````]I,!``\`````E`$`$0```!"4`0`"````(I0!``8````EE`$`#P``
M`"R4`0`2````/)0!`!````!/E`$`!@```&"4`0`3````9Y0!``L```![E`$`
M!P```(>4`0`8````CY0!`#````"HE`$`30```-F4`0`K````)Y4!`"T```!3
ME0$`!@```(&5`0`)````B)4!``0```"2E0$`"0```)>5`0`)````H94!`!<`
M``"KE0$`#````,.5`0`&````T)4!``T```#7E0$`!P```.65`0`$````[94!
M`$$```#RE0$`2````#26`0!!````?98!`"<```"_E@$`!0```.>6`0`-````
M[98!``<```#[E@$`"`````.7`0`)````#)<!`!L````6EP$`&0```#*7`0`5
M````3)<!``8```!BEP$`!0```&F7`0`0````;Y<!``@```"`EP$`"@```(F7
M`0`C````E)<!``0```"XEP$`!P```+V7`0`G````Q9<!``8```#MEP$`"0``
M`/27`0`3````_I<!`!,````2F`$`"````":8`0`)````+Y@!``4````YF`$`
M1P```#^8`0`T````AY@!`$$```"\F`$`,@```/Z8`0!)````,9D!`#L```![
MF0$`+````+>9`0`^````Y)D!`"\````CF@$`/0```%.:`0`Q````D9H!`!``
M``##F@$`$0```-2:`0`+````YIH!`#(```#RF@$`(0```"6;`0`?````1YL!
M`!X```!GFP$`!P```(:;`0`)````CIL!``H```"8FP$`!P```*.;`0`I````
MJYL!`"P```#5FP$`/0````*<`0`,````0)P!`",```!-G`$`-@```'&<`0`6
M````J)P!`!4```"_G`$`"````-6<`0`+````WIP!``P```#JG`$`$````/><
M`0`7````")T!`$4````@G0$`?````&:=`0!G````XYT!``T```!+G@$`$```
M`%F>`0`1````:IX!`!0```!\G@$`%0```)&>`0`7````IYX!``@```"_G@$`
M$0```,B>`0`3````VIX!`!(```#NG@$`%0````&?`0`N````%Y\!`"T```!&
MGP$`EP```'2?`0`1````#*`!``4````>H`$`%0```"2@`0`)````.J`!``L`
M``!$H`$`"P```%"@`0`E````7*`!`!@```""H`$`#P```)N@`0`.````JZ`!
M`!0```"ZH`$`&0```,^@`0`M````Z:`!`"X````7H0$`*@```$:A`0`J````
M<:$!`"8```"<H0$`*````,.A`0`>````[*$!`$$````+H@$`%0```$VB`0`4
M````8Z(!`!<```!XH@$`%@```)"B`0`1````IZ(!`!<```"YH@$`%@```-&B
M`0`4````Z*(!`!0```#]H@$`.P```!*C`0`9````3J,!`!H```!HHP$`.@``
M`(.C`0`3````OJ,!``8```#2HP$`$````-FC`0`M````ZJ,!`!0````8I`$`
M%0```"VD`0`5````0Z0!`"````!9I`$`'@```'JD`0`<````F:0!`!P```"V
MI`$`)P```-.D`0`3````^Z0!`"`````/I0$`)@```#"E`0`@````5Z4!`!D`
M``!XI0$`'0```)*E`0`4````L*4!`!P```#%I0$`'````.*E`0`A````_Z4!
M`!D````AI@$`"@```#NF`0`2````1J8!`!L```!9I@$`!````'6F`0`'````
M>J8!``L```""I@$`$@```(ZF`0`&````H:8!``8```"HI@$`!P```*^F`0`&
M````MZ8!``<```"^I@$`!0```,:F`0`%````S*8!`!4```#2I@$`!@```.BF
M`0`&````[Z8!``4```#VI@$`!0```/RF`0`*`````J<!`!$````-IP$`"@``
M`!^G`0`6````*J<!`!0```!!IP$`"@```%:G`0`7````8:<!``4```!YIP$`
M-0```'^G`0`2````M:<!`!$```#(IP$`&@```-JG`0`/````]:<!``T````%
MJ`$`$````!.H`0`T````)*@!``4```!9J`$`"````%^H`0`G````:*@!`!,`
M``"0J`$`$````*2H`0`&````M:@!``H```"\J`$`#0```,>H`0`&````U:@!
M`"(```#<J`$`$````/^H`0`;````$*D!`!`````LJ0$`%0```#VI`0`1````
M4ZD!`!H```!EJ0$`%````("I`0`&````E:D!``4```"<J0$`#````**I`0`F
M````KZD!``<```#6J0$`"0```-ZI`0`2````Z*D!`!<```#[J0$`!P```!.J
M`0`%````&ZH!``<````AJ@$`%@```"FJ`0`-````0*H!``\```!.J@$`#0``
M`%ZJ`0`6````;*H!`!@```"#J@$`#P```)RJ`0`1````K*H!``P```"^J@$`
M&````,NJ`0`,````Y*H!``<```#QJ@$`%````/FJ`0!"````#JL!``@```!1
MJP$`#````%JK`0`M````9ZL!`!4```"5JP$`%0```*NK`0`-````P:L!``P`
M``#/JP$`"0```-RK`0`'````YJL!``H```#NJP$`"0```/FK`0`.`````ZP!
M`!`````2K`$`*0```".L`0`E````3:P!`"H```!SK`$`"@```)ZL`0`(````
MJ:P!``H```"RK`$`#````+VL`0`-````RJP!``D```#8K`$`#@```.*L`0`U
M````\:P!``4````GK0$`#@```"VM`0`:````/*T!`%T```!7K0$`&@```+6M
M`0`.````T*T!``0```#?K0$`!````.2M`0`:````Z:T!`!H````$K@$`&@``
M`!^N`0`*````.JX!``(```!%K@$`!````$BN`0`E````3:X!``,```!SK@$`
M!0```'>N`0`I````?:X!``H```"GK@$`!0```+*N`0`&````N*X!``L```"_
MK@$`$0```,NN`0`&````W:X!``<```#DK@$`"````.RN`0`$````]:X!``4`
M``#ZK@$`:P````"O`0`*````;*\!``T```!WKP$`'0```(6O`0`%````HZ\!
M``8```"IKP$`*0```+"O`0`V````VJ\!``X````1L`$`"0```""P`0`3````
M*K`!``H````^L`$`"````$FP`0`7````4K`!`#@```!JL`$`'P```*.P`0`>
M````P[`!`",```#BL`$`#P````:Q`0`$````%K$!``<````;L0$`"````".Q
M`0`(````++$!`!$````UL0$`#P```$>Q`0`'````5[$!`&$```!?L0$`$0``
M`,&Q`0`/````T[$!``\```#CL0$`&P```/.Q`0!1````#[(!`!P```!AL@$`
M!@```'ZR`0`?````A;(!`"8```"EL@$`!P```,RR`0`&````U+(!`"````#;
ML@$`"````/RR`0`)````!;,!`"$````/LP$`(````#&S`0`\````4K,!``@`
M``"/LP$`"@```)BS`0`G````H[,!`%0```#+LP$`&P```""T`0`?````/+0!
M`!H```!<M`$``P```'>T`0`,````>[0!``@```"(M`$`&0```)&T`0`-````
MJ[0!``8```"YM`$`%@```,"T`0`&````U[0!``@```#>M`$`"0```.>T`0`,
M````\;0!``H```#^M`$`$`````FU`0!!````&K4!``D```!<M0$`&@```&:U
M`0`7````@;4!`"$```"9M0$`&````+NU`0`5````U+4!`!@```#JM0$`%@``
M``.V`0`6````&K8!`!4````QM@$`%@```$>V`0`*````7K8!`!\```!IM@$`
M$````(FV`0`2````FK8!``D```"MM@$`#````+>V`0`)````Q+8!`!D```#.
MM@$`!P```.BV`0`7````\+8!``8````(MP$`!P````^W`0`%````%[<!``4`
M```=MP$`!P```".W`0`3````*[<!`!0````_MP$`(@```%2W`0`B````=[<!
M`!T```":MP$`'````+BW`0`B````U;<!`"8```#XMP$`'P```!^X`0`#````
M/[@!``4```!#N`$`#P```$FX`0`/````6;@!``H```!IN`$`(@```'2X`0`-
M````E[@!`!````"EN`$`(P```+:X`0`=````VK@!`!8```#XN`$`"`````^Y
M`0`.````&+D!``D````GN0$`$````#&Y`0`3````0KD!``H```!6N0$`"0``
M`&&Y`0`%````:[D!``<```!QN0$`!0```'FY`0`$````?[D!``(```"$N0$`
M-P```(>Y`0`[````O[D!`!D```#[N0$`)@```!6Z`0!&````/+H!``P```"#
MN@$`-````)"Z`0`[````Q;H!`$0````!NP$`1````$:[`0!,````B[L!``\`
M``#8NP$`(````.B[`0`?````";P!`!P````IO`$`'P```$:\`0`?````9KP!
M`"````"&O`$`(````*>\`0`@````R+P!``P```#IO`$`00```/:\`0!!````
M.+T!`$4```!ZO0$`1@```,"]`0!#````![X!`$````!+O@$`>0```(R^`0`5
M````!K\!`!`````<OP$`"0```"V_`0`C````-[\!``<```!;OP$`%````&._
M`0`Z````>+\!`#@```"SOP$`)````.R_`0`+````$<`!`%,````=P`$`2@``
M`''``0`'````O,`!`!<```#$P`$`%0```-S``0`/````\L`!`!`````"P0$`
M&````!/!`0`'````+,$!``H````TP0$`"````#_!`0`3````2,$!`!````!<
MP0$`#@```&W!`0`2````?,$!``4```"/P0$`)````)7!`0`)````NL$!``8`
M``#$P0$`%````,O!`0`2````X,$!``\```#SP0$`2`````/"`0`'````3,(!
M``8```!4P@$`$@```%O"`0`%````;L(!``<```!TP@$`#P```'S"`0`'````
MC,(!`#4```"4P@$`$@```,K"`0`E````W<(!``0````#PP$`.P````C#`0`.
M````1,,!`"@```!3PP$`AP```'S#`0`:````!,0!`$4````?Q`$`)P```&7$
M`0`1````C<0!``@```"?Q`$`#@```*C$`0`.````M\0!``P```#&Q`$`$P``
M`-/$`0`,````Y\0!`"````#TQ`$`'````!7%`0`$````,L4!`!`````WQ0$`
M&P```$C%`0`J````9,4!`!4```"/Q0$`$0```*7%`0`6````M\4!`!$```#.
MQ0$`'P```.#%`0`*`````,8!``P````+Q@$`$P```!C&`0`1````+,8!`!<`
M```^Q@$`$````%;&`0`<````9\8!``X```"$Q@$`%0```)/&`0`B````J<8!
M``T```#,Q@$`!@```-K&`0`(````X<8!``4```#JQ@$`(````/#&`0`&````
M$<<!`!(````8QP$`"````"O'`0`3````-,<!``H```!(QP$`*````%/'`0`5
M````?,<!`$$```"2QP$`&P```-3'`0`+````\,<!``P```#\QP$`)0````G(
M`0`%````+\@!`!8````UR`$``P```$S(`0`1````4,@!``4```!BR`$`"@``
M`&C(`0`E````<\@!`#D```"9R`$`"@```-/(`0`F````WL@!`!,````%R0$`
M"P```!G)`0`=````)<D!`!0```!#R0$`!````%C)`0`(````7<D!``D```!F
MR0$`"````'#)`0`+````><D!``@```"%R0$`!P```([)`0`'````ELD!`!(`
M``">R0$`*@```+')`0`W````W,D!`!L````4R@$`*P```##*`0`C````7,H!
M`$$```"`R@$`&P```,+*`0`D````WLH!`"T````#RP$`3````#'+`0`H````
M?LL!``<```"GRP$`"````*_+`0`)````N,L!``@```#"RP$`%0```,O+`0`4
M````X<L!`"P```#VRP$`+P```"/,`0`B````4\P!`#<```!VS`$`/P```*[,
M`0`'````[LP!`!H```#VS`$`"0```!'-`0`,````&\T!`"X````HS0$`$P``
M`%?-`0`2````:\T!``T```!^S0$`"P```(S-`0`8````F,T!``D```"QS0$`
M$@```+O-`0`1````SLT!`!H```#@S0$`'````/O-`0`Y````&,X!``L```!2
MS@$`$````%[.`0`%````;\X!``@```!US@$`!0```'[.`0`:````A,X!``\`
M``"?S@$`!@```*_.`0`/````MLX!`!$```#&S@$`"````-C.`0`.````X<X!
M``X```#PS@$`$P```/_.`0`%````$\\!`!`````9SP$`#0```"K/`0`\````
M.,\!`%(```!USP$`(@```,C/`0`*````Z\\!`"<```#VSP$`&P```![0`0`%
M````.M`!`!<```!`T`$`"0```%C0`0`-````8M`!`!(```!PT`$`*@```(/0
M`0`&````KM`!``T```"UT`$`#@```,/0`0`0````TM`!``H```#CT`$`/0``
M`.[0`0`)````+-$!`"`````VT0$`$````%?1`0`4````:-$!`$````!]T0$`
M)@```+[1`0!"````Y=$!`$,````HT@$`/````&S2`0`/````J=(!``<```"Y
MT@$`$@```,'2`0`2````U-(!`!D```#GT@$`"@````'3`0`3````#-,!`!L`
M```@TP$`!P```#S3`0`7````1-,!`"@```!<TP$`!@```(73`0`'````C-,!
M`!````"4TP$`%0```*73`0`7````N],!``<```#3TP$`!P```-O3`0`)````
MX],!`!0```#MTP$`$@````+4`0`3````%=0!`!,````IU`$`!@```#W4`0`%
M````1-0!`#$```!*U`$`*````'S4`0`E````I=0!``@```#+U`$`#P```-34
M`0`&````Y-0!`!H```#KU`$`&0````;5`0`K````(-4!``D```!,U0$`#```
M`%;5`0`G````8]4!``,```"+U0$`!0```(_5`0`-````E=4!``,```"CU0$`
M#````*?5`0`3````M-4!``L```#(U0$`%P```-35`0`8````[-4!`!,````%
MU@$`!0```!G6`0`*````']8!`!8````JU@$`%0```$'6`0`.````5]8!``<`
M``!FU@$`#````&[6`0`*````>]8!`!````"&U@$`70```)?6`0`F````]=8!
M`#P````<UP$`$@```%G7`0`'````;-<!``8```!TUP$`"P```'O7`0`4````
MA]<!`!0```"<UP$`'````+'7`0`?````SM<!`!8```#NUP$`'@````78`0`0
M````)-@!`"T````UV`$`%0```&/8`0`-````>=@!`&X```"'V`$`)````/;8
M`0`@````&]D!`"L````\V0$`(P```&C9`0`?````C-D!`",```"LV0$`)0``
M`-#9`0`?````]MD!`!L````6V@$`"@```#+:`0`'````/=H!``@```!%V@$`
M"@```$[:`0`3````6=H!``\```!MV@$`+0```'W:`0`8````J]H!`!P```#$
MV@$`"````.':`0`*````ZMH!`%(```#UV@$`10```$C;`0!`````CML!`'@`
M``#/VP$`#0```$C<`0`P````5MP!`#$```"'W`$`"@```+G<`0`'````Q-P!
M``T```#,W`$`.@```-K<`0`3````%=T!`$0````IW0$`+0```&[=`0`G````
MG-T!`!````#$W0$`,@```-7=`0`C````"-X!`#,````LW@$`*@```&#>`0`R
M````B]X!`"L```"^W@$`#0```.K>`0`)````^-X!`!$````"WP$`$P```!3?
M`0`8````*-\!``<```!!WP$`-P```$G?`0`,````@=\!``0```".WP$`!0``
M`)/?`0`2````F=\!``@```"LWP$`!@```+7?`0`4````O-\!``H```#1WP$`
M"0```-S?`0`%````YM\!`!$```#LWP$`$0```/[?`0`:````$.`!`!P````K
MX`$`%0```$C@`0`A````7N`!``T```"`X`$`!P```([@`0`2````EN`!`"D`
M``"IX`$`"0```-/@`0`)````W>`!`!L```#GX`$`*`````/A`0`.````+.$!
M`"$````[X0$`-````%WA`0`)````DN$!``D```"<X0$`$@```*;A`0`&````
MN>$!``0```#`X0$`(@```,7A`0`-````Z.$!``\```#VX0$`#`````;B`0`(
M````$^(!``D````<X@$`"````";B`0`)````+^(!``T````YX@$`$@```$?B
M`0`&````6N(!`!D```!AX@$`%0```'OB`0`'````D>(!`!````"9X@$`(```
M`*KB`0`,````R^(!``,```#8X@$`)0```-SB`0`&`````N,!``8````)XP$`
M>P```!#C`0`)````C.,!``4```"6XP$`+````)SC`0!&````R>,!`",````0
MY`$`+P```#3D`0!0````9.0!`#H```"UY`$`/0```/#D`0`D````+N4!`"``
M``!3Y0$`!0```'3E`0`'````>N4!``@```""Y0$`"0```(OE`0`'````E>4!
M``@```"=Y0$`$@```*;E`0`*````N>4!``D```#$Y0$`"P```,[E`0`+````
MVN4!``<```#FY0$`!P```.[E`0`(````]N4!`!0```#_Y0$`"P```!3F`0`&
M````(.8!``4````GY@$`)````"WF`0`&````4N8!`"T```!9Y@$`&````(?F
M`0`(````H.8!`!0```"IY@$`"0```+[F`0`3````R.8!``L```#<Y@$`%```
M`.CF`0`%````_>8!`!0````#YP$`!@```!CG`0`:````'^<!``H````ZYP$`
M'````$7G`0`(````8N<!``8```!KYP$`$@```'+G`0`D````A><!``L```"J
MYP$`#0```+;G`0`J````Q.<!`"$```#OYP$`'````!'H`0`%````+N@!``H`
M```TZ`$`$P```#_H`0`8````4^@!``,```!LZ`$`$P```'#H`0`)````A.@!
M`"0```".Z`$`*````+/H`0`S````W.@!`"@````0Z0$`-0```#GI`0`O````
M;^D!`&0```"?Z0$`%@````3J`0!<````&^H!`#H```!XZ@$`20```+/J`0!K
M````_>H!`"H```!IZP$`00```)3K`0`Q````UNL!`#<````([`$`'0```$#L
M`0!"````7NP!`-,!``"A[`$`(@```'7N`0`7````F.X!`$P```"P[@$`@```
M`/WN`0`W````?N\!`"P```"V[P$`/P```./O`0!>````(_`!`$H```""\`$`
M*@```,WP`0`B````^/`!`!0````;\0$`'P```##Q`0`A````4/$!`"````!R
M\0$`*P```)/Q`0`D````O_$!`",```#D\0$`/@````CR`0`B````1_(!`!4`
M``!J\@$`-P```(#R`0`F````N/(!`"P```#?\@$`*P````SS`0`:````./,!
M`"T```!3\P$`:0```('S`0`V````Z_,!`$D````B]`$`-P```&ST`0`M````
MI/0!`$````#2]`$`<````!/U`0!2````A/4!`#4```#7]0$`-P````WV`0`T
M````1?8!`&L```!Z]@$`<P```.;V`0!:````6O<!`%D```"U]P$`-P````_X
M`0`I````1_@!`"D```!Q^`$`+P```)OX`0!Y````R_@!`&X```!%^0$`=P``
M`+3Y`0#$````+/H!`!8```#Q^@$`)P````C[`0`X````,/L!`"\```!I^P$`
M30```)G[`0`J````Y_L!`&,````2_`$`(P```';\`0`+````FOP!`*@```"F
M_`$`2@```$_]`0`I````FOT!`#@```#$_0$`*@```/W]`0`C````*/X!`#T`
M``!,_@$`!@```(K^`0`+````D?X!``0```"=_@$`"@```*+^`0`/````K?X!
M`!$```"]_@$`"P```,_^`0`&````V_X!`!$```#B_@$`!````/3^`0!F````
M^?X!``,```!@_P$`%````&3_`0`$````>?\!``<```!^_P$`!@```(;_`0`%
M````C?\!`#0```"3_P$`"````,C_`0`5````T?\!``P```#G_P$`$0```/3_
M`0`1````!@`"``,````8``(`!0```!P``@`'````(@`"`!(````J``(`#```
M`#T``@`4````2@`"``8```!?``(`%0```&8``@`-````?``"``,```"*``(`
M+@```(X``@`$````O0`"``8```#"``(`!P```,D``@`E````T0`"`$<```#W
M``(`.````#\!`@`Y````>`$"`!@```"R`0(`)P```,L!`@`J````\P$"`"8`
M```>`@(`'````$4"`@`A````8@("`"@```"$`@(`(P```*T"`@`@````T0("
M`"0```#R`@(`)@```!<#`@`B````/@,"`#8```!A`P(`'0```)@#`@`S````
MM@,"`#D```#J`P(`)@```"0$`@`J````2P0"`"@```!V!`(`(P```)\$`@`H
M````PP0"`#(```#L!`(`*P```!\%`@`P````2P4"`"8```!\!0(`)````*,%
M`@`E````R`4"`"X```#N!0(`(````!T&`@`G````/@8"`#<```!F!@(`.@``
M`)X&`@`<````V08"`"8```#V!@(`/0```!T'`@`G````6P<"`"L```"#!P(`
M*````*\'`@`J````V`<"`"0````#"`(`'@```"@(`@!.````1P@"`"@```"6
M"`(`-P```+\(`@`N````]P@"`#D````F"0(`"0```&`)`@`0````:@D"`!@`
M``!["0(`,@```)0)`@`E````QPD"``T```#M"0(`#P```/L)`@`6````"PH"
M``H````B"@(`#@```"T*`@`J````/`H"``@```!G"@(`"P```'`*`@`O````
M?`H"`#$```"L"@(`*0```-X*`@`B````"`L"`"0````K"P(`"@```%`+`@#L
M````6PL"``P```!(#`(`%@```%4,`@`*````;`P"``T```!W#`(`$@```(4,
M`@`7````F`P"`"H```"P#`(`!@```-L,`@!2````X@P"`!H````U#0(`&@``
M`%`-`@`'````:PT"``\```!S#0(`"````(,-`@!"````C`T"``<```#/#0(`
M+0```-<-`@`:````!0X"`!,````@#@(`%````#0.`@`T````20X"`"````!^
M#@(`!P```)\.`@`D````IPX"``@```#,#@(`"0```-4.`@`7````WPX"``H`
M``#W#@(`'`````(/`@`(````'P\"`"X````H#P(`!P```%</`@`C````7P\"
M`"<```"##P(`!P```*L/`@`5````LP\"``<```#)#P(`"````-$/`@`)````
MV@\"`$````#D#P(`!P```"40`@`,````+1`"`!,````Z$`(`#P```$X0`@`)
M````7A`"``@```!H$`(`!P```'$0`@`3````>1`"``8```"-$`(`&@```)00
M`@`+````KQ`"`!H```"[$`(`%````-80`@`+````ZQ`"``T```#W$`(`(```
M``41`@`%````)A$"`#4````L$0(`#````&(1`@`/````;Q$"``L```!_$0(`
M`P```(L1`@`4````CQ$"`"(```"D$0(`"P```,<1`@`#````TQ$"``@```#7
M$0(`#````.`1`@`*````[1$"`!````#X$0(`#@````D2`@`2````&!("`!,`
M```K$@(`$0```#\2`@`X````41("`"$```"*$@(`'P```*P2`@`A````S!("
M``D```#N$@(`-````/@2`@`'````+1,"`!<````U$P(`0````$T3`@`3````
MCA,"`!,```"B$P(`"````+83`@`$````OQ,"``8```#$$P(`#P```,L3`@`=
M````VQ,"``<```#Y$P(`"`````$4`@`)````"A0"``8````4%`(`!@```!L4
M`@`5````(A0"`!0````X%`(`0@```$T4`@`S````D!0"`"D```#$%`(`!0``
M`.X4`@`;````]!0"`!T````0%0(`(P```"X5`@`G````4A4"`!(```!Z%0(`
M`@```(T5`@`$````D!4"``\```"5%0(`"@```*45`@`%````L!4"``(```"V
M%0(`#0```+D5`@!(````QQ4"`#<````0%@(`%@```$@6`@`W````7Q8"`"P`
M``"7%@(`6@```,06`@`7````'Q<"`(,````W%P(`)0```+L7`@`Z````X1<"
M`"(````<&`(`-@```#\8`@`X````=A@"`"T```"O&`(`+````-T8`@`L````
M"AD"`"H````W&0(`+@```&(9`@`N````D1D"`#(```#`&0(`,P```/,9`@`R
M````)QH"`!8```!:&@(`#0```'$:`@`.````?QH"`(8```".&@(`"0```!4;
M`@"M````'QL"`'$```#-&P(`A0```#\<`@`K````Q1P"`%P```#Q'`(`%```
M`$X=`@`H````8QT"`!8```",'0(`$````*,=`@`D````M!T"`"(```#9'0(`
M0@```/P=`@`@````/QX"`!X```!@'@(`7````'\>`@`:````W!X"`!,```#W
M'@(`"@````L?`@`%````%A\"``8````<'P(`"````",?`@`%````+!\"`!8`
M```R'P(`%0```$D?`@`7````7Q\"`"(```!W'P(`$````)H?`@`/````JQ\"
M``0```"['P(`#````,`?`@`.````S1\"``<```#<'P(`!@```.0?`@`9````
MZQ\"``\````%(`(`!@```!4@`@`5````'"`"``D````R(`(`#````#P@`@`4
M````22`"``P```!>(`(`&````&L@`@`)````A"`"``L```".(`(`&````)H@
M`@`&````LR`"``4```"Z(`(`)P```,`@`@`;````Z"`"``H````$(0(`&0``
M``\A`@`6````*2$"`"0```!`(0(`&0```&4A`@`)````?R$"`!4```")(0(`
M"````)\A`@`'````J"$"`!<```"P(0(`!P```,@A`@`"````T"$"``(```#3
M(0(`'P```-8A`@`.````]B$"``@````%(@(`%P````XB`@`9````)B("``<`
M``!`(@(`*P```$@B`@`"````="("``8```!W(@(`#P```'XB`@`9````CB("
M``4```"H(@(`"@```*XB`@`3````N2("``<```#-(@(`&0```-4B`@`*````
M[R("`!<```#Z(@(`$P```!(C`@`2````)B,"``(````Y(P(`!P```#PC`@`1
M````1","``8```!6(P(`#@```%TC`@`P````;","``D```"=(P(`"@```*<C
M`@`4````LB,"``4```#'(P(``@```,TC`@`+````T","``$```#5!```'@0`
M`#,%``!A`P```````)X!``!O`@``H@0```````"6`P``R0$``/P&``!\````
M``````````"(`@``*@<```T!````````@@<``,$```!Y!0``%P0``/$%```L
M````W0,``,(&```D!P``"@(```,$``"^!0```P<``#,#````````J`(``+@&
M``!F`@``M`(``!$$``"#`P```````````````````````-@$``!3!0``AP0`
M````````````^`$``'("`````````````($"```P!````````"4!``"F!0``
M`````&,'``#E!0``D`8``"<!``!Q!@``]P0``'`"``!R`0``-`<``,0!``#3
M`@``,00``'$#``!/!P``6@```*0!```U`0``B@<```````!]`0``[0```)<&
M``#"!0``70<``$P%``#-!@```````)8$``!D`@``]````"L"``!H`@``````
M`-T$``"%!@``WP4`````````````I0```````````````````)H#````````
M0````.4&````````SP$```````"?!```2@(``,$%````````_P(``(D'````
M````#@4```````!1!```S04``.X"```H!0``%P`````````T````6````+X!
M`````````````+<"``!<!```9P,``&P#``!A`0``@P<`````````````````
M`/P!``!F`P``;P```-@!````````?@8````````)!P``D`````````!/`P``
MG0(````````>`P``7@8``/8!``#?````*@,``-X!``#2`0``N`,``$D#````
M````'`<``!('```G`P``\P```+(%``#4!`````````````"M`P``I```````
M``#,!0``8P,``'L#``"7!```#`0```````"+!@``P@$```````#C!```>0<`
M`-L#``#I`0```````/\%``!+!P``JP$``%H$``#F`0```````$\```#``0``
M````````````````,0,``&T'``"(!@``L@````````":!0``:00``*4&``#D
M`0``1P8````````J````_0$``&H!``!5!P``W`,``"D&``"E!```508``%@$
M``"P!@```````)\"``!;````DP8``(T#``"I`````````*X%``#3````H@,`
M`'P!``!I`@``Q`,``"D'``!]`P``*P`````````V```````````````S`@``
M@P```.8$````````^`0``'L$``!%!P```````/D``````````````)4"``"\
M!0```````!D%``"L`P``+0(``'L'````````=@0``#T"`````````````)("
M``"0`0``C`0``-P```!]!P``604``)P#```%`@``/`<``&`#```(`0``````
M`$<$````````+@<``*$#``"G`0````````````!I!0``<P$`````````````
M0P8``-L````^!P``2@`````````$`@```````"L!````````6`,```````">
M!````````,X!``!C!```&`,````````I!```80``````````````)P0``'<`
M``#P`P``9P8```````"=!@````8``'L`````````&08``+,$```#````!`<`
M`-X%````````RP,``'X"```7!P``[@``````````````90$```````#P`@``
MF@```)(```"@`P```````)T!```M!0``<P(``/4#``!(`P``P`(``+P!``#?
M!```UP8``+8#``#E!```S`0``*P$````````&0<``!D"``#!!```&@$``+,"
M`````````````.0#``"1`@```````(`!``#^!0``:P$``!<&``#Z`0``+`,`
M`$T#``!T`P``200``)@!``!'````R@$``',#``!/!@``.@```&$&``!3````
MU@8``'@"````````,`4``"@"``!T!@``[P````L&```$````Y@(``(`#``"%
M!0``BP$``)4$`````P``90<``.@%```9`0```````*$!```.!P``?0(``'X`
M```'!```"@<``"X&```U!@```````%0"``"_`````````'D#```!!```````
M``L````U!0````````````!G!P``*`8``-T`````````]@(``$`'````````
MV@,``-P$`````````````&@````/`@``<P8```````#4!@``Q@8``'$```"@
M````_08``$0"````````G00``+L#``#`````!@0```\&``!.`0``E@(``+L%
M``"B`0``PP$````````%`````````$T'``#8`@``8P````````#$````````
M````````````]`0```````!"!0``<`<```````#.!@```````!D#``""!@``
M``````````!4!0````````````#U!```>00``*0&``!Q!```"````%X```!)
M!P``O`,``'@%``#>````A@,``"8$```]!0``^`8``)X#``!Y`@```````&P!
M``!``@``OP8``.\%``#`!````````'`&````````B0```*<"````````-`8`
M```````=!P```````%<!```D!```.@$```````!O!````````(D"``![!0``
M@@4``-8`````````(P(``%`&```Y!```-0(`````````````F0,```$%```!
M!P``"0,``&H&````````\P$``,8```#R`P``CP```%P'`````````````.@&
M``"'`P````````````#?`@``,`,``%D!``#U!@```````.<!`````0``30``
M`,\$```2!0```````#@!``"2`P``?P$``)<```!;!```@00``',```"I!0``
M6@(``(0"````````0@8``'@!`````@```````.D$````````)`````````#Z
M!```;00``,@$``!;`0``(P0```8```"A`@``8`(`````````````!`8``)8%
M````````X@8``)`#```^````+0$``!8"``#9`P``D@8`````````````;@,`
M``````"0!```HP````````#'`P``40```+\"```N!```(@0``.L$````````
M+08``/@"```O!@``6@4``````````````````*L"```F`P````````````"U
M`0```````'T````I`P```````','````````DP0```````#0`0``\08```H!
M```````````````````"`0``3@4``#D&````````R@4``!,!``#G````_`,`
M`)P```"R`P``Q@$```````!W!```<P0``-D"``#+!0``?@$``(X!````````
M``````````#]!0``-P0````````_!P``I@8``-(#``"I!@``[P$``*8`````
M````\0(``````````````````*\$``#M`0``^P0``.$#```J!````````&@$
M``"?````$`8``+L$``#L`P```````,L$``!=`@``C@0```````#&`@``P`4`
M`$0%``!U!P``UP4``)0&````````9`<`````````````'00```````#V`P``
M5````-D`````````2````)8`````````6`(``#<````@!@``/@(``'4"````
M````]0(````````*!```N0(``*<$``!X!P```````-L&```5`````````-L$
M````````_@`````````A!0``C04``/D!``#W!0``?@,``-D&``"V!0``EP4`
M``4%````````````````````````A00``,$"``#0`@``#0<``)L#```!`P``
M`````/8$``!!`@``50$```````#'!```-`$```````#-`@``C`````````!R
M!@``30$`````````````NP8```L!``#@`0``*`0``*8#``#.!0``=0$``#4$
M```1!@``C00``&(`````````+P```*$&```Z`@``6P(``(`'``!(!P``CP4`
M`!D`````````K0```/$#``#2!@``?@4``#(```"_!0``S`(```````#W!@``
MMP8``%T%``!&`0`````````````?`@``'P<``-P&````````$`4```````!B
M`0``.P(``$4"``"]`0``@@,````````L`0``1@```-("```4!@```````'\`
M``!$`P``-@<``"\!```S!```XP$```````#3!0``M@(``.H!``!6`P``^@,`
M`'\$````````I`,``-8"``!D`P``[`4`````````````7P```"$"```T`P``
M_@(```````!U!````````($&```Y!0``/`4``!H$````````=@```*4#````
M````F04``&0%```4`@``;@$``"0!````````C@````````!L!0```````,<%
M```<`0``X@$```````"5`P``F`````````"'!0``&``````````N!0``B`0`
M```````<````F@8``&D&``#]`@``AP$```````!.`P``:0<``'P$```2!```
M90```%8%``#%!@``=@(``.```````````````+D#``!W`P``````````````
M``````````````!>`0```````#D'``"``@``;```````````````B@(`````
M``#/!@``#0(``!$%``!O`0``+P(``.$%``#I`@``40,```\!``!@````9P``
M``````#`!@``VP(``+H&``````````````````#L````M`0``"@`````````
M,`<```````#U````K`4``/\!``#7!```&@```````````````````&0$````
M````R08``&`&``!.`````````!4"`````````````$P$```6!@``(P```#\`
M``"$!0``J@0``+H"``"3!0``Y````$0$````````N@4``$,%```A`0``N@$`
M``````"=!0```````+4````"!P``+`<`````````````L@0```````!J!P``
M?04``&8```````````````````#0!```"0$``%@&`````````````.`&``!A
M!P``/0$``#T$``!W`@``[`8``#L$```@!P``_@8``.8````.`0```````$@&
M``">!@``O@0``&8&```+!0``1@<``````````````````'4#``"+````>@<`
M`-0#```#`@``I0$``"X#````````M00````````E!P```P,``.T"``!P````
M;@8``-@````2!@``1P,``%X'``#S!0``Z08``-,$``!!`P```````/L%``!F
M!P``H`8``-0"````````;0$``-$```"*!@``,````,H"``"C!```[@$``.(`
M``!L`@``J`$``%X"````````.@,```````!<!@``+00``&(#``#B!0``````
M`,\```"8!0``V`8``$<"`````````````)<!``````````````<&``!(!0``
M_P8```````!+`P``;@4``%0'``#5`0``@@$`````````````````````````
M````_P0``&X$```(!```0`,``"$$``#A!````````%X#``"`!```$P(``"P&
M``#-!```'0,```````!_!@``=0````<#``"3`0```````*P`````````!@(`
M`'L!```K!```-0<```````!Z````=```````````````9`$``%8!```-````
M00$``.`#``"U!@``.`<`````````````)@```````````````````(H%``"1
M!````````$@$```!!@```````+,```!2`0``D08``+0!```8`@``4@(``(D#
M``!O!P``]P(``+8```#S!@``\P,``%,!``#D!```\00```````#0!@``````
M`#$"````````#`<``%``````````5@(```````!,!@``@P(````````<!@``
M`````/0&``",!@``NP```%T&````````^P$``(0```!&!@```````'<!````
M`````````$8"``!*`0``%P,````````F`0``6P,``/<```"<!0``504``-T&
M```[`0``&@<```````"*`0``7@4``%D$``!"!P``G`(``#\#```3`P``L`4`
M`$L!````````H00```````!``0``:@```(`%``"I`P``J`8``"``````````
MK@```$L````2````J`0```,!``!Y!@```````-<!``"Z````Y@,``+@!````
M`````````&H$`````````````+X```"Y````=`0````````1````804``.@$
M```B`P``K0$``.@````D`@``GP8``+\!``#T`0``.@8``(,&````````@0``
M`!0$``"]`@``/P0``($!```;````M0(```````"_`P``=P4``&<"``"%````
M`````,\"``#$!@``@04```````!9`@``H04``/(!``"O`P```````(P%``!T
M`0``L0```(,$````````\`8````````1!P``<0(```````#O`P```````!("
M```6`0``+P,``$8$````````UP,``.$"````````?`8``$L%````````W`4`
M`(D$````````L@8``/D"``"Q!```!P(````````A````_`4``'D!```^`P``
M"@8``/0%``#R`@``<P4``+H#````````U@,``.H"``!9!@```````'T$``!#
M`P```````"P"``">!0``R`4``-L%``!C!0``````````````!P``?`4``$D"
M```\````O```````````````$0,`````````````$`<``#<&```6!```````
M``````!C`@``"`<``#4#````````0@$``#\%````````FP8`````````````
MB0$``,D```#K`P``Y`8``+T```"-`0``OP0````````X`P``-P(``!\%````
M````AP8``+`$```)`@``[00``,$#``````````````````!+!```408``+<$
M``!U!0``Q@,```````!M`P``W`$``+(!````````E04```````#*!@``I`4`
M```````+`P``?P,``!,````/!```QP$```T$````````0P(``%4```#D!0``
M`````*X#```%`P``&P0```8&`````````````.P$``#M!0``#`,``*H%``"Y
M!```%@```%8$```Y`0``5P4``*8"``#[`@```````(("```E!0``_0,``$4!
M``!L!`````````````!!!0``%0$```````#T`P``R00``+X&````````2@,`
M``````#/`P``7P4``'X$```]!@``^P```"`%``!(`0```````*L```!8`0``
MZ@0``(T`````````T`,``#@&`````````````,L```"'````WP,`````````
M````S@0```````!2!P```````!L%````````Z0,``#$```#.`P``BP4``!(!
M```.````:P<``*<```#1!```8@<``!@&``#:````(P$``*0"``":`@``8`0`
M`"\$```C!P``9P$``'H"```4!P``'P0``-H%``">`@``70````````#B!```
M:`4``#\&``#H`@```````+0%````````!@,``"`$```````````````````&
M!0```````)4!``"&!@``=@,``+$#``#Z!@```````)0$``"'`@``'@8`````
M``#>`P```````%T!``!;!P``%@,``/,"```S!P``=@4``*H#``!?`0``*P8`
M`````````````````*\&``#B`P``4`,``/X$```Z!P``>@0````````Q!0``
M:`8``-0```"B`@``^P,````````J!0``A@<``.X%``!T`@```````"D`````
M````"`(````````+!P``YP0```````!2!@`````````````G!P```@8`````
M``!(`@``````````````````V0$``,T````Y`P``!@$````````K!P``<@<`
M`&,&````````@P4``'`!``"Q`@``Q@0``#`"``!7!```````````````````
MA@4``!4$``"3`@``5P8``-(```"P`P``208``#<'``!\!P```````-($```=
M!0```````+P$`````````````(0!`````````````"4"``!<`0```````!L'
M```R!P``(@(``*H"```F!P```````#P$``"+`@``:P```/(&```[!0``/@$`
M`!,%````````Y@4``(H````>`0``K00``(L#```(!0```````"0%``!?`@``
M`````.P!````````_`0```````#A`0``204````````3!@``B````.L"```V
M!```YP,``*T%``#/!0``R0,```````!!!```````````````````[`(``*,#
M````!```&@4``#,```#V!0``=P<```````!O!@```````,T#``!Q`0``(`,`
M`%L%````````A@```(4!````````M````)$#``"&!```,@0``+D!``";`@``
MH@4``+@"``#G`@``;`8``#0$``"A````+@(``,H#```-`P```````(X%````
M````&P8``*X$``````````````````!M!0```````-H!````````$`0```@&
M````````)0```.,#``">``````````````!T!0``'P8````````7`0``0`4`
M`!T```#.`@``H`4``(D&``"0`@``(P4``)@"````````0`8``$$&``"C`0``
MHP4``"D"`````````````"T```!*!P``EP(``%0$`````````````#8"``#X
M!0``=@$``%\#```W`0```````%`$``!8!0``I`0```D```#%!0``A0,`````
M``!:`0``:P(``.X#```;`@```````,0"``!:!P``10,``#X$``"2`0``Z`$`
M`.4#``!3!`````````````"N`@``$`(``!X"``!0`0``2@0```H`````````
M308``/X!```N````CP$````````M!P``[P(``.L!``#1`0``;@(`````````
M````W`(``,4"```G````M0,``)0%````````;@```!``````````CP0``!T!
M``!R!```=@<```(#``#@!0``4P<``+0#```'!P``CP,```````"/`@``:0$`
M`(0#``#!`0``=P8``'`$``"J````4`(``&8%````````C@,``"\'``"$!```
M`````+X#``!`!```&@(````````Y`@``E`,``((````"!```````````````
M````$0(``!<"``#"````O0,```````#1!@``,@4``/````##!0```````$H%
M```3!P``60<```0$``!@`0````````````#;`0``2@8``/,$``!M!@``.@4`
M`#L'``"<`0``X0```+X"``#``P``&`0`````````````FP4``.L%``#W`P``
M`````$,'```;`P``[@0``)<#```$`P``"08``(X&````````800``&`'```P
M`0``)@8```````!E!@``:P,```````!?!@``MP,```P"``!+`@``'P````P&
M``!F`0````````````!1`@````````````"H!0``,08``+,!```-!@``U`$`
M`#<%``"(`0``7``````````[!@``Z`,``!P%``"]!```KP(```````"`````
M?`,``$$'````````A`8``-\!```W`P``\0$`````````````#````)@#``!E
M`@``H`(``/(%``````````````````!F!`````````````#K````N`4``*(&
M````````(`$``,,#```\!@``<@4``(8!``!M`@```````$\$``#G!@``````
M`,<&``"1`0```````,,````>!P```````&4$``!T!P````````\%```_`0``
M4`<``&\#```B!@``1````!8'`````````````-H"``!)````/0,``!D$````
M````\0```&L&````````#`4``%4#```)!0``)@4``+8&``"K!```"00``$D!
M``!$!@``````````````````(@4```````"P````KP```#`&``#O!@``XP``
M```````C!@``%`,``,,$``#:!@````````````"!`P``#@0``!H#``"N`0``
M`````+L!``#C!@``S@````````"4`0``?P<``,<"```$!0```````#8!````
M````J````"X!```0`P```````)($```;`0``H@```%(%````````Z@8``-<"
M```````````````````+!```FP$``)T#``"L`0``#@(``-8%``#U!0``]P$`
M``\#````````GP$``,4`````````R`(``%<````X````*@(`````````````
M_P,``*D$``"]!0```````,0%````````40$``!\!``#M!@``^08``)@$``!2
M!````````*\!`````````````*8!``"K!0``L@(``&0&````````V`,``!@%
M``"H`P```````!P"```"!0```````(<'``"!!P``T@4``.4!``"M!@``Y0(`
M`,$&``"M`@``<@,``)(%``"Q`0```````-0%``"C!@```````+<%````````
MT`4``&\%````````^@(```````#>!@`````````````A`P``?@<``+8$``"G
M!@```````,8%``"I`0``0P```)\#```=`@```````$X$````````!`$``)D"
M``!1!0``0@,``'H&``#>`@```````$<'``!E!0``@`8``$8#``#E````3P4`
M`,,&````````````````````````T````%T#``"W````>P(``$4%````````
M4P8``-@%``!,`@``/0```"\%````````>P8``.("``!B!```'`,`````````
M`````````,4$````````U0,``.0"``!Z`P``E````(@'```<!```````````
M`````````````$,$```:!@````````````!1!P```````"L#``#_````60,`
M````````````(@<``%,#```\`@``DP```/4!``!7`@`````````````.!@``
M`````)L$````````1`$``&$"``!-!```3`<``'`%``"S`P```````(8"``!.
M!@```````"@!````````W0$```````"S!0``<0<``-X$``!K!0``M`8``"D%
M```]!P``1`<``$P#``!K!```T0,```````!J`@``L04``(($``!X`P``TP,`
M`%(#``":`0``XP(``$X"``#$!````````(H$``!L!P``<@``````````````
M`````/P"````````-`4``&H#```&!P``)0,``'T&````````Z@,``)D$``"W
M`0``RP8``-$"```J`0``F0$``,T!````````5P<``%4"``!<`P``B`4`````
M```R`@``^@```)D`````````S````+`"```V!0```````-<`````````IP4`
M`````````````````"4&``"9!@``\`$``",#```[````F`8``$,!``#(`P``
MC@(```4'```7!0``9P4``````````````````"0#``",`@``'@```(0'``!6
M!P``KP4``$4```!V!@``.@0``,4!``#6`0``0@```&<$```H!P``<04``/8&
M``!6````$`$``/H%``!/`@````4``%P"``"E!0``!08``.H%```B````1P4`
M``````!+!@``F@0``)P&``##`@``!00`````````````O08``'`#```5!@``
M[@8```````!_!0``Z@```#8#``!<!0``%`4``!$!```@`@```````&H%````
M````,0$``#\"``!/`0``,@$``"<"``#5`````````"<%``!H`P``^````'P"
M``"/!@````````````"E`@```````+`!``#^`P``8P$``+@```"1````````
M````````````E0```"@#```/``````````````",`P```````'\"``#)!0``
MR`$```````"(`P``(0<``*`!````````W0(``,L!```,`0``5P,``'D```#6
M!```Q0,```````#,`0``%0,``````````````````&X'``#R!```>`0```H#
M````````/@8``-H$````````HP(``&T```"1!0``&`<```````!8!P``+`0`
M``(```!B`@``'@4```````#Y!0``4`4```````#(````#@,``(T"````````
MIP,```H%````````.P,```$"```/!P``7P0```L"````````3````)P$``#3
M`0``*P4``.D%````````>`````````!H`0``\@```/`%``!-`@``N04```<%
M````````4@```.T#``!-!0``U08``#D```#*!```GP4``,("``!?!P``!0$`
M`'@&``!&!0``WP8`````````````!P```#@%```M`P``_````,@&```5!P``
M`P8``,H```!Z`0``%`$``/D#``#G!0``JP8``%4$``!4`0````````@#``"[
M`@``3@<``!0```"3`P``K`(``%X$``#9!```/`,``#(#``#V````0@0`````
M``#@`@``L08`````````````W04``&(&``#"`P``S`,``.\$``!=!```E@$`
M`(H#``!H!P``A0<`````````````%04``(T&``"F!```,0<``(P!``!%!```
MFP```"$&``#T`@``=08`````````````N`0````````2`P``ZP8``&(%````
M````_00``)4&``#C!0``*@8`````````````^00```````"\`@```````+8!
M``!%!@```````*X&``!6!@``/@4```````!!````.`0````````T`@``````
M``,%````````D`4``!\#``"I`@````````````!4`P``)P8``-4%``#[!@``
M`````*H!``!E`P``$P0`````````````5`8``"D!``"U!0```````.8&``#5
M`@```````(D%``"%`@``N08``%H#``"#`0```````/`$```F`@``TP8`````
M```U````O`8``,L"``"K`P``60`````````S`0```````.$&``"S!@``#04`
M`$<!``!;!@``N@0``#8&````````6@8```````!D````)`8``,D"````````
MG0````$!```'`0``0@(``(L$``!I````V04``"(!``"@!````````)0"```6
M!0```````#P!``#1!0```````!@!````````>@4``,<```#,!@``````````
M``!@!0``)00``/@#```L!0``Z0```,($``"J!@``'08``$P!```R!@```@(`
M`&D#``#@!```.`(`````````````_0```*P&``"6!@``4P(````````S!@``
M`"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I
M`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@870@`"(E<R(@
M:7,@;F]T(&$@9&ER96-T;W)Y+@`B)7,B(&ES(&YO="!A('9A;&ED(&-H;VEC
M92X`(B5S(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T
M<GDN`"(E<R(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N`"(E<R(@=V%S(&%D
M9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`B)7,B('=A<R!A9&1E9"!T;R!T
M:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`B)7,B('=A<R!N;W0@8W)E871E9#H@
M)7,N`"4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I`"5D
M("5S(&%N9"`E<P`E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E
M<RX`)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT
M`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I
M;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`
M)7,@86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S`"5S(&ES(')E861Y('1O
M('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B
M96QO=RX@0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@
M=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`)7,@:7,@<F5Q=6ER960`
M)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S('1O("5S(&]F("5S`"5S)W,@
M061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@
M5&%S:VQI<W0`)7,Z("5S`"5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F
M<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG
M(&%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W
M:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BX`+"!G=7-T:6YG(``L(&=U
M<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C
M="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\
M4')E=FEO=7,`02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T
M:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI
M8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!
M('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE
M9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S
M<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@
M<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!
M('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P
M=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S
M86=E+@!!32!#;&]U9',`04T@3&EG:'0@4F%I;@!!32!286EN`$%-(%-H;W=E
M<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D
M:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5S<R!D96YI
M960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A
M=&EN9R!61E,@9FEL92X`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A
M<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI
M;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.
M97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P
M('1O("(E<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A
M(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I
M<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O
M(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E
M<@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D
M(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@(B5S
M(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!U
M<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI
M<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI
M<W1R871I;VX`061S`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA
M<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R
M<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!
M;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E
M<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@
M3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@
M57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E
M;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL
M96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA
M<R!O8V-U<F5D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@
M4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!
M<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E
M861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T
M92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I
M;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O
M(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S
M=7)E('EO=2!W:7-H('1O(&1E;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P
M<S\`07)G96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)T
M`$%R=6)A`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I
M8R!296=I;VX`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E
M;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T
M;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T
M;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`
M075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S
M(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!2
M97%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!2
M97%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@
M=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U
M:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q
M=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D
M9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T
M;W)Y`$%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$
M05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@
M861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!
M=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z
M(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN
M`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D
M+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D
M+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R
M+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N
M=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@
M9FEE;&1S.@!!>F5R8F%I:F%N`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A
M8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R
M8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX
M.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$)A<V4@9W)A<&AI8W,@9&ER
M96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!"87-E;&EN90!"96QA<G5S`$)E;&=I
M=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K
M("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E
M='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D
M97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE
M9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A
M>FEL`$)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R
M=7-S86QA;0!"=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"
M=7)U;F1I`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@
M4')O<&5R=&EE<RXN+@!#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#
M86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@8V]P>2!F
M:6QE*',I("T@<V]U<F-E(&%N9"!D97-T:6YA=&EO;B!A<F4@=&AE('-A;64N
M`$-A;B!N;W0@;6]V92!F:6QE*',I("T@9&5S=&EN871I;VX@:7,@=VET:&EN
M('-O=7)C92X`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY
M+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N(&YO="!W<FET92!T
M;R!F:6QE("(E<R(`0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N
M(&AA;F1L97)S+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#
M86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#86YC96P@4')O
M8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F
M:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET
M:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I
M<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES
M="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D
M(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A
M;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@
M5F5R9&4`0V%P=&EO;@!#87)R:65R`$-A=&5G;W)I97,@86YD($QA8F5L<P!#
M87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL
M('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP
M:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N=')A;"!!9G)I
M8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E
M<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A
M=&4@4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E(%EO=7(@4&%S<W=O<F0`
M0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W
M:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG
M:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C
M=7)R96YT(&-O;F9I9W5R871I;VXN("!#;VYT86-T('EO=7(@861M:6YI<W1R
M871O<BX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EL90!#:&EN80!#:&EN97-E
M(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG
M-2D`0VAO;W-E($%P<&QI8V%T:6]N.@!#:&]O<V4@82!P87-S=V]R9`!#:&]O
M<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H
M;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:')I
M<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD
M+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(%%U97)Y`$-L96%R
M(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A
M<FEN9R!,871E`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A4
M5%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O
M8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P
M<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U
M<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N
M9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#
M;VUP86YY`$-O;7!U=&5R<P!#;VYD:71I;VX`0V]N9&ET:6]N<P!#;VYF:6=U
M<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@
M=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RX`0V]N9FEG=7)A
M=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S
M<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F
M('1H90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#
M;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O
M;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A
M<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N
M`$-O;G1A8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E
M9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#;V]K($ES;&%N
M9',`0V]O:VEE`$-O<'D`0V]P>2!F86EL960Z("5S`$-O<'D@<V5L96-T:6]N
M`$-O<W0@240`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!0
M1U`@96YC<GEP="!M97-S86=E.B``0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A
M9V4Z(`!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@
M;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C
M="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO
M="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0
M('-E<G9E<BX`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I
M;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@`$-O=6QD(&YO="!D
M96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N
M("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O
M=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U
M;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E
M<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O
M=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U
M;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO
M;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@
M;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F
M<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R
M:71I;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN
M=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O
M<GD@(B5S(BX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BX`0V]U
M;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@
M9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E
M=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#
M;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R
M97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE
M<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R
M;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#
M;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A
M=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S
M879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N
M;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I
M=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@
M8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O
M("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@
M;F]T('5N;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S
M`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD
M(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E<P!#;W5L9&XG
M="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED
M96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S(B!T:&4@9F]L
M;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E<P!#;W5N=&5D
M('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R
M96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R
M;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R
M96YT(#0@4&AA<V5S`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U
M<G)E;G0@55),(&ES`$-U<G)E;G0@57-E<G,`0W5R<F5N="!796%T:&5R`$-U
M<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S
M:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N
M`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ
M,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L
M:6,`1$0`1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO
M<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!$86EL>0!$871A
M5')E92!"<F]W<V5R`$1A=&%B87-E($QO;VMU<`!$871E`$1A=&4@4F5C96EV
M960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R
M`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A
M=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!3:&5L;`!$969I
M;FET:6]N<P!$96QE=&4`1&5L971E($-E;&P`1&5L971E($=R;W5P`$1E;&5T
M92!,;V<`1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S
M86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN
M9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E(&UE<W-A9V5S`$1E;&5T92!P
M97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E
M<R(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R;W<`1&5L971E
M('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!S=6(@9F]L9&5R<P!$96QE=&4@
M=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L
M971E9"!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!$96QI=F5R>2!T:6UE
M`$1E;FUA<FL`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T
M86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@
M8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N
M=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I
M;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@
M=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P
M;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S=`!$:7-P;&%Y
M(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N($YO
M=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E
M8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O
M=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES
M(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O;B=T(&AA=F4@
M86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W;FQO860`1&]W;FQO860@)7,`1&]W
M;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`
M1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$5-86EL+71O+5--4R!G871E
M=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S
M97)V:6-E+@!%4E(`16-U861O<@!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U
M<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI
M<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I
M;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A=&EO
M;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M86EL
M($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I
M=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'871E=V%Y`$5M;W1I8V]N
M<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T
M97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A
M;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M
M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y
M('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D
M('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA
M;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5N
M=&5R('1H92!L971T97)S(&)E;&]W.@!%<75A=&]R:6%L($=U:6YE80!%<FET
M<F5A`$5R<F]R`$5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%<G)O<B!D96QE
M=&EN9R!S>6YC(&%N8VAO<CH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z
M("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@=7!D871I;F<@
M<&%S<W=O<F0Z("5S`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`17)R;W(@
M=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`
M179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C
M;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H
M;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A
M;F0`17AP86YD(%-I9&5B87(`17AP96-T960@)RDG`$5X<&5C=&5D(&)A<F4@
M=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X
M<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E
M=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$
M05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&
M86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E
M<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I
M;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E<P!&
M86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S
M`$9A=&%L($5R<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`1F5E;',@3&EK90!&
M965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L
M9"!M871R:7@`1FEG;&5T($-!4%1#2$$`1FEG;&5T(&9O;G0`1FEJ:0!&:6QE
M`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL
M92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A
M9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&:6YL86YD
M`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A
M=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O
M9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E
M8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R
M;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA
M<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI
M`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@
M='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D<P!&<@!&
M<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R96YC:"!'=6EA
M;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I
M97,`1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`
M1G5L;"!.86UE`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A
M;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R
M871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV
M96X@3F%M90!';&]B86P@3W!T:6]N<P!';P!';V5D96P`1V]O9VQE($UA<',`
M1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E96-E`$=R965K("A)4T\M.#@U
M.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A=&EO;@!'
M<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED.B``1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<P!'
M<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S`$=R;W5P<P!'
M=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI
M<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`
M2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B
M;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H
M+4%L9V]R:71H;0!(87IE`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A
M;F0@36-$;VYA;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE8G)E=R`H25-/
M+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP
M97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I
M;&4Z`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`
M2&]M90!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(
M;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@
M)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+
M;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R
M9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A
M9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E
M<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER
M97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R
M="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI
M<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O
M;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E
M<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N
M=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(
M;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@
M;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ
M(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I
M;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0
M(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S
M`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET
M:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N
M+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS
M(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I
M="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I
M;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S
M:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@
M=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U
M('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U
M('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R
M;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM
M86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P
M;&]A9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E
M<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C
M="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O
M<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A
M9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`
M26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA
M=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);G-E<G0@
M0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R
M="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W
M(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O
M;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@
M869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E
M('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE
M(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C
M=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@
M86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE
M(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@
M8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O
M<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS
M97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@
M<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@
M<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T
M+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T
M:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN
M=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE
M861E<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`
M26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV
M86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T
M`$EN=F%L:60@;&EC96YS92!K97DN`$EN=F%L:60@;&]C871I;VX@<')O=FED
M960N`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?
M:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A
M<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@:60N`$EN=F%L:60@
M<')O9'5C="!C;V1E+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP
M:65N=#H@(B5S(@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C
M92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN
M=F5R="!S96QE8W1I;VX`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q
M`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L
M`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA
M<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`
M2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,
M969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+
M96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN
M`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`
M2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI
M<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO
M<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!2
M97!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`
M3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U
M8FQI8P!,87-T($AA;&8`3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1=6%R
M=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@
M)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U
M=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T
M(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QE=F5L`$QI8F5R:6$`3&EB
M>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ
M;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T
M90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,
M:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN
M:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O
M;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE
M`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E
M<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,
M:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U
M8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@<V5S<VEO;G,@9F%I
M;&5D.B`E<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R
M<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A9&EN9RXN
M+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I
M;@!,;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N`$QO9R!O=70`3&]G:6X`
M3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M
M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@
M9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R
M<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`3'5X
M96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN960@
M;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O
M<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!
M9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-
M86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H
M879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E
M9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M
M87``36%P<&EN9W,@<W1O<F5D+@!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E
M96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!)
M;7!O<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U
M90!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L
M;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X
M('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@
M`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,`36%X:6UU;2!L96YG
M=&@`36%Y`$UA>6]T=&4`365D:6-I;F4`365M8F5R<P!-96YU(&UO9&4Z`$UE
M<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L
M;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@
M=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&%R
M(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO
M8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O
M<B!T:&4@861M:6YI<W1R871O<BX`365T87)$0B!I<R!N;W0@8V]N;F5C=&5D
M+@!-971H;V0`365T:&]D("(E<R(@:7,@;F]T(&1E9FEN960`365T:&]D(&YO
M="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<P!-971R:6,`365X:6-O`$UI
M8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP
M90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO
M=7)S.B``36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E
M9`!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG(%!%05(@<&%C:V%G92!(
M5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@
M=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P
M<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER
M960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`
M36]B:6QE($UA:6P`36]D97)A=&4`36]D:69I960@1&%T90!-;V1I9GD@55),
M`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA
M`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E
M<P!-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C
M=&5D("5D+@!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO
M<W1L>2!#;&]U9'D@86YD(%=I;F1Y`$UO<W1L>2!3=6YN>0!-;W9E($1O=VX`
M36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!U
M<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT
M:6UA<"!52R!M87``375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`37D@
M06-C;W5N="!);F9O<FUA=&EO;@!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U
M=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`3F%U
M<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T
M<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T
M<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.971S
M8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`
M3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I
M8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI80!.97<@0V%T
M96=O<GD`3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE
M86QA;F0`3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O
M;B`E>"X`3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"X`3F5W('=I;F1O=R`H
M7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S`$YE
M>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H
M=`!.:75E`$YO`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@
M<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F
M;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L871E+@!.;R!B
M;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE
M;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.
M;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E
M<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D
M:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L
M;V%D960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@
M;&]C871I;VX@<')O=FED960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA
M;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I
M=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R
M;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,
M;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-3
M3"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E
M<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S
M:6=N=7!S+@!.;R!Q=6]T82!S970N`$YO(')U;&5S`$YO('-E<&%R871O<B!S
M<&5C:69I960N`$YO('-I9&5S`$YO('-U8V@@9FEL90!.;R!T96UP;W)A<GD@
M9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N
M9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE
M9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF
M:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I
M;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@
M*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H
M97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R
M`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`
M3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S
M92P@9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T
M97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@
M;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI
M<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F
M9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@86YD(&YE=R!P87-S=V]R9',@;75S
M="!B92!D:69F97)E;G0N`$]L9"!P87-S=V]R9`!/;&0@<&%S<W=O<F0@:7,@
M;F]T(&-O<G)E8W0N`$]M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S
M:&%R960@9F]L9&5R<RX`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O
M;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S
M>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O
M=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I
M;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R
M;VT@<VEG;F5D(%,O34E-12!P87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N
M97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O
M<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L
M(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T
M90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R
M;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I
M<R!N;W0@879A:6QA8FQE+@!014%2.CI-86EL(&)A8VME;F0`4$=0($1I9VET
M86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME
M>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L
M;`!032!,:6=H="!286EN`%!-(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-
M(%-N;W<@4VAO=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`4$]325@@97AT96YS
M:6]N(&ES(&UI<W-I;F<`4%](4"!3:&5L;`!0861D:6YG`%!A:VES=&%N`%!A
M;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A
M<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R=&QY($-L;W5D>0!087-S=V]R
M9`!087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0@:6YC
M;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC
M871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!0
M87-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F
M<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E
M<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!0
M97)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@1&5N:65D
M`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O
M;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0
M:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L871I='5D97,`4&QE87-E(&-L:6-K
M(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@
M=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y
M;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@
M82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T
M:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R
M97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M
M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI
M9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L
M96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D
M`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R
M964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!T
M>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O
M;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I
M;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@
M96YF;W)C960@8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H
M;W5R*',I.B``4')E8VEP:71A=&EO;CQB<B`O/F-H86YC90!0<F5F<U]L9&%P
M.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E
M<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`
M4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0
M<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V
M:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L
M96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0
M=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R!+97D@26YF
M;P!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S
M<V9U;&QY+@!0=65R=&\@4FEC;P!0=7)G92!M97-S86=E<P!1871A<@!1=65R
M>0!1=6]T80!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I
M;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN
M(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!2
M96%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A
M=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@`4F5F<F5S:"!$
M>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E
M9V5X`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!296UA<FMS`%)E;6]T
M92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO
M:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M
M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP
M="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T
M:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@
M=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W
M97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S=&5D('-E<G9I8V4@
M8V]U;&0@;F]T(&)E(&9O=6YD+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I
M960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E
M8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO
M="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@1FEE;&0`
M4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-T
M;W)E($QA<W0@475E<GD`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2971Y
M<&4@;F5W('!A<W-W;W)D`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`
M4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@
M:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2
M;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O
M=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A
M=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O
M34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES
M(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,(%-H96QL`%-13"!S
M=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',`4U-(`%-50T-%4U,`4U]13"!3
M:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A
M:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN
M8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A
M;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET
M92!0<F]V:61E<@!3875D:2!!<F%B:6$`4V%V90!3879E("(E<R(`4V%V92`E
M<P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A
M<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER
M96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E9"!S971U<"!U
M<&=R861E('-C<FEP="!T;SH@(B5S(BX`4V-A='1E<F5D(%0M4W1O<FUS`%-C
M:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E;&5C="!&:6QE<P!396QE
M8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@
M;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E
M;&5C="!A;&P`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N`%-E;&5C="!A
M;B!O8FIE8W0`4V5L96-T(&YO;F4`4V5L96-T('1H92!C:&%R86-T97)S('EO
M=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P
M>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T
M:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E
M;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@
M=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!3
M96QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@
M<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@
M4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N96=A;`!396YS;W(Z(`!397!T
M96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`4V5R
M=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92X`4V5S<VEO;B!!9&UI
M;@!397-S:6]N($E$(&5X<&ER960N`%-E<W-I;VYS`%-E=`!3970@;W!T:6]N
M<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@
M979E<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO
M=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P
M<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N
M`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@
M<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3
M971U<`!3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@
M;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H
M96QL97,`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME
M>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&1I9F9E
M<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@
M9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE
M('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA
M;`!3:&]W('!I8VME<@!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_
M`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE
M($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R
M=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA
M;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L
M;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAO=V5R
M<R!I;B!T:&4@5FEC:6YI='D`4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H
M8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@
M3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3
M:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E
M;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3:&]W97)S`%-N;W<@4VAO=V5R
M<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H.B``4VYO=R!E
M<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`
M4V]N9W,@)B!0;V5M<P!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D
M<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I
M`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S
M`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C
M96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL
M`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A
M;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O
M;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R
M(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O
M<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I
M;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;
M0U-370!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%-U8FIE8W0`
M4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B('1O('1H92!S
M>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S="!H
M87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U
M;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L
M96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C
M8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@
M(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C
M;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F
M=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY
M('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C
M97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3
M=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES90!3
M=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R
M<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@
M2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN8R!L
M;V<@9&5L971E9`!3>6YC34P`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M
M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@86YD(%=I
M;F1Y`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY`%135B!F:6QE`%1A8FQE(%!R
M;W!E<G1I97,`5&%B;&4@4V5T`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A
M:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@
M56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU
M;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A
M='5R93H@`%1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[
M)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N`%1E;7!L871E($%D;6EN:7-T
M<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4
M:&%I("A425,M-C(P*0!4:&%I;&%N9`!4:&4@1E10(&5X=&5N<VEO;B!I<R!N
M;W0@879A:6QA8FQE+@!4:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L960N
M`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@
M<W5P<&]R="`B)7,B`%1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA
M;&EZ960N`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S
M=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X
M:71I;F<N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A
M('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O
M('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O
M;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK
M(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C
M="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T
M:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L
M86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB
M=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@
M9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL
M92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL
M92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE
M861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9U
M;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET
M:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T
M('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X
M<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC
M=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R
M('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y
M;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE
M960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S
M92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@
M<V-R965N(&5D:71O<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L
M971E9"X`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F
M('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?
M<&=P.CH@8VQA<W,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET
M:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO
M(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@
M=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T
M:&4@8V]M<&]S92!P86=E`%1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@
M;G5M97)I8RX`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T
M:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@
M(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E
M961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U
M<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD
M(&]N('1H92!S>7-T96TN`%1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O
M;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE(')I9VAT(&%N9"!L969T('-I9&5S
M(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97!A<F%T;W(@
M;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE('-E<G9E<B`B)7,B
M(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S
M879E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO
M=F5D+@!4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T+@!4
M:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('1E
M>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@
M<V-R965N+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P
M('-I9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T
M:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T
M(&)E('-A=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL
M86)L92X`5&AE;65S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`5&AE<F4@
M87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@
M=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M
M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E
M9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N
M`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("(E<R(@=&\@=&AE('-Y<W1E
M;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U
M<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE
M;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A
M('!R;V)L96T@=7!D871I;F<@(B5S(CH@)7,`5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4
M:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@
M)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H
M)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4
M:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R
M=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A
M=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A
M<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I
M;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L
M9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE
M9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D
M971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@
M97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@
M=')Y(&%G86EN(&QA=&5R+@!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U
M<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@
M=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H
M:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%14
M4"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@9V%T97=A>2P@
M=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+W-M
M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T
M:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O;FQY('1O(%9O
M9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@
M=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4:&ES
M(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB
M97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R
M('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@
M;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A
M:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X
M86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P
M<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'<F]U<'=A
M<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@
M86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R
M;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"!C;&EE
M;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@
M:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`
M5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@<V5R=F5R
M(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y
M<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@;75S
M="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O
M;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME=',`5&EM90!4:6UE
M(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I;6]R+4QE
M<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T(&UU;'1I
M<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM
M86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G9VQE($A4
M34P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4;V\@;6%N
M>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA<W0@;6EN=71E<RX`5&]P
M`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4
M;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H
M("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)
M<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@
M`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O
M<G0`55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D
M:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO
M;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO
M;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S
M:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E
M<RX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B;&4@
M=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R\E<R(N`%5N86)L92!T;R!C;VYN
M96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,
M+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!6
M1E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R
M96%T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!C<F5A=&4@96UP='D@
M5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T
M;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N
M86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D96QE=&4@)7,L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!6
M1E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ
M("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T
M;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E
M<B`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N
M`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L
M92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO
M860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93
M(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA
M8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2X`56YA
M8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2X`
M56YA8FQE('1O(')E860@9FEL93H@`%5N86)L92!T;R!R96%D('1H92!V9G-R
M;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S
M=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T
M;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O
M('1R:6=G97(@9G)E92]B=7-Y('5P9&%T92!F;W(@)7,`56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H
M8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A
M+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC
M965D960N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S
M="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C
M;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T
M;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E9"!!<F%B($5M:7)A
M=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI=&5D(%-T871E
M<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO=VX`56YK;F]W
M;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N(&-L:6US9VED
M("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@;&]C871I;VX@<')O=FED
M960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@
M8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV:6QE9V5D('-C<FEP=',@
M8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@
M9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H
M;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W
M('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5
M;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T
M92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P9W)A9&4@<V-R:7!T
M(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T
M=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5
M<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S
M92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)
M35-0('-E<G9E<BX`57-E<@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O
M<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!2
M96=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L
M960@9F]R('1H:7,@<VET92X`57-E<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R
M;F%M90!5<V5R;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`
M57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&
M4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO
M8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN
M=71E<R!F<F]M(&YO=RX`5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG
M=&@@;V8@)7,N`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T
M=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H
M:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I
M;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A
M9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M97-E
M("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6
M:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA
M;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET
M86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!
M3E5!3$Q9($923TT@)7,N`%=)3B!V:6$@2%144`!786QL:7,@86YD($9U='5N
M80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R
M;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET90!7965K;'D`5V5L
M8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX
M.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7
M:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN
M/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H
M92!Q=6]T92!C:&%R86-T97(_`%=H97)E:7,@075S=')A;&EA(&UA<`!7:&EC
M:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H
M(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!I;B!#4U,@=6YI=',`5VED=&@@
M;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N
M97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I
M9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S
M`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5VES:&QI<W0`5V]R:P!7;W)K($%D9')E
M<W,`5V]R:R!0:&]N90!7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@
M)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;G5M8F5R(&]F(&9I
M96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!O9F9S970@)60@
M=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+@!8+5)E9@!8-3`Y=C,@0F%S:6,@
M0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@
M4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)
M9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA
M<`!996%R;'D`665M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%
M6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@
M=&\@5UE325=91RX`66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R
M92!T:&%N("5D(&)L;V-K<RX`66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`
M66]U(&-A;FYO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L
M;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E
M<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T
M960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO
M=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P
M=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F
M:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T
M(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N
M`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D
M97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P
M<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T
M:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@
M=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O
M(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E
M;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9
M;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M
M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@
M='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W4@;F5E9"!T;R!P<F]V:61E
M(&%N($ET86QI86X@<&AO;F4@;G5M8F5R`%EO=7(@)7,@<V5S<VEO;B!H87,@
M97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E
M<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@
M26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN
M:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R
M:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T
M:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U
M<V5R<RX@268@>6]U('=I<V@@=&\@=7-E($AO<F1E('1O(&%D;6EN:7-T97(@
M=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0N`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N
M9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T
M=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`
M66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H
M92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO
M=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S
M97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8G)O=W-E
M<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#
M;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@=&EM
M92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E
M9"X`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U
M<B!L;V=I;B!H87,@97AP:7)E9"X`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S
M(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H
M92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9
M;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL
M(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!P87-S
M=V]R9"!H87,@97AP:7)E9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L
M879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI9&4@475O=&5D
M(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;
M4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`
M7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]'
M<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TQO9R!I;@!?3&]G
M(&]U=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]2
M96UO=F4@3&EN:RXN+@!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S
M97)S`&%D9')E<W,@8F]O:P!A9&1R97-S964@=6YK;F]W;@!C86QE;F1A<@!C
M86QM`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4`8V%N;F]T(&]P96X@:6YP
M=70`8VQI8VL@:&5R90!C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(`8V]N9FEG
M=7)A=&EO;B!E<G)O<@!C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG`&1A
M=&$@9F]R;6%T(&5R<F]R`&5D:70`96YT<GD@;F]T(&9O=6YD`&9A;&QI;F<`
M9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&=U<W1I;F<`:#H`:&@`
M:&]S="!N86UE('5N:VYO=VX`:6UM961I871E`&EN;&EN90!I;G!U="]O=71P
M=70@97)R;W(`:6YT97)N86P@<V]F='=A<F4@97)R;W(`;&EN97-=`&UK:7-O
M9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+@!M;0!N86UE`&YO
M="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`<&5R
M8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5M;W1E(&5R<F]R(&EN
M('!R;W1O8V]L`')I<VEN9P!S97)V:6-E('5N879A:6QA8FQE`'-H;W<@9&EF
M9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-S`'-T96%D>0!S>7-T96T@
M97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E`'1Y<&4@=&AE('!A
M<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@
M<V5L96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO
M;CH@2&]R9&4@,RXP+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI
M<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-BTP-2TQ."`P
M.#HQ-RLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,34@,3<Z,C0K
M,#$P,`I,87-T+51R86YS;&%T;W(Z($UA;G5E;"!0+B!!>6%L82`\;6%Y86QA
M0'5N97@N97,^"DQA;F=U86=E+51E86TZ(&DQ.&Y`;&ES=',N:&]R9&4N;W)G
M"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@
M8VAA<G-E=#U)4T\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z
M(#AB:70*4&QU<F%L+49O<FUS.B!N<&QU<F%L<STR.R!P;'5R86P]*&X@(3T@
M,2D["@`@*&AA8V4@)7,@9.UA<RD`("A!8V-E9&EE;F1O(&$@)7,I`"`H96X@
M)7,@9.UA<RD`("AH;WDI`"`H;6'Q86YA*0`@*&%Y97(I`&5N(``B)7,B(&YO
M(&5S('5N(&1I<F5C=&]R:6\N`"(E<R(@;F\@97,@=6YA(&5L96-C:?-N(';A
M;&ED82X`3F\@<V4@:&$@8V]N9FEG=7)A9&\@(B5S(B!E;B!E;"!R96=I<W1R
M;R!D92!(;W)D92X`3F\@<V4@96YC;VYT<O,@96P@9V5N97)A9&]R(&1E(.%R
M8F]L97,@9&4@(B5S(BX`4V4@:&$@8?%A9&ED;R`B)7,B(&%L('-I<W1E;6$@
M9&4@9W)U<&]S+@!392!H82!A\6%D:61O("(E<R(@86P@<VES=&5M82!D92!P
M<FEV:6QE9VEO<RX`3F\@<V4@:&$@8W)E861O("(E<R(Z("5S+@!5<V%D;W,@
M)2XR9DU"(&1E("4N,F9-0B!P97)M:71I9&]S("@E+C)F)24I`"5D("5S('D@
M)7,`475E9&%N("5D(&3M87,@:&%S=&$@<75E(&5X<&ER92!L82!C;VYT<F%S
M9?%A+@`E9"!P<F]N\W-T:6-O<R!D:6%R:6]S`"5S("T@079I<V\`2'5E;&QA
M(&1I9VET86P@9&4@)7,`)7,@2T(`)7,@;W!E<F%C:6]N97,@9&4@;6%N=&5N
M:6UI96YT;R`M($-O;F9I<FUA8VGS;@!#;VYF:6=U<F%C:?-N(&1E("5S`$9I
M<FUA(&1E("5S`$%C=65R9&]S(&1E(&QI8V5N8VEA(&1E("5S`%EA(&5X:7-T
M92`E<RX`)7,@82!L87,@)7,@)7,`)7,@97-TX2!P<F5P87)A9&\@<&%R82!R
M96%L:7IA<B!L87,@;W!E<F%C:6]N97,@9&4@;6%N=&5N:6UI96YT;R!S96QE
M8V-I;VYA9&%S+D%C=&EV92!L87,@8V%S:6QL87,@9&4@;&%S(&]P97)A8VEO
M;F5S('%U92!D97-E82!E:F5C=71A<B!E;B!E<W1A(&]C87-I\VXN`$AA8V4@
M9F%L=&$@)7,`)7,@;6EN=71O<P!.;R!S92!H82!E;F-O;G1R861O("5S+@`E
M<R!A;"`E<R!D92`E<P!$:7)E8V-I;VYE<R!D92`E<P!!9V5N9&$@9&4@)7,`
M3&EB<F5T82!D92!N;W1A<R!D92`E<P!487)E87,@9&4@)7,`)7,Z("5S`"5S
M.B!%<W1E(&UE;G-A:F4@<'5E9&4@<75E(&YO('!R;V-E9&$@9&4@<75I96X@
M<&%R96-E('-E<BX@179I=&4@<V5G=6ER(&-U86QQ=6EE<B!V[6YC=6QO(&EN
M8VQU[61O(&\@<W5M:6YI<W1R87(@8W5A;'%U:65R(&EN9F]R;6%C:?-N('!E
M<G-O;F%L(&%L(')E;6ET96YT92X`+"!V96YT;W-O(``L('9E;G1O<V\@)7,@
M)7,`+"!V87)I86)L92!D92`E<R!A("5S`"TM('-E;&5C8VEO;F%R("TM`$9O
M<FUA=&\@9&4@,3(@:&]R87,`1F]R;6%T;R!D92`R-"!H;W)A<P`R-"!H;W)A
M<P`\06YT97)I;W(`4&%R82!E<W1E(&)L;W%U92!H86-E(&9A;'1A('5N(&UO
M=&]R(&1E(&)A<V4@9&4@9&%T;W,N`%-E(&AA('!R;V1U8VED;R!U;B!E<G)O
M<B!I<G)E<&%R86)L90!(86-E(&9A;'1A('5N82!C;&%V92!01U`@</IB;&EC
M82!P87)A(&-I9G)A<B!U;B!M96YS86IE+@!(86-E(&9A;'1A('5N82!C;&%V
M92!01U`@</IB;&EC82!P87)A(&-O;7!R;V)A<B!U;B!M96YS86IE(&9I<FUA
M9&\N`$AA8V5N(&9A;'1A('5N82!C;&%V92!01U`@</IB;&EC82P@=6YA(&-L
M879E(%!'4"!P<FEV861A('D@=6YA(&9R87-E(&-L879E('!A<F$@9&5S8VEF
M<F%R('5N(&UE;G-A:F4N`$AA8V5N(&9A;'1A('5N82!C;&%V92!01U`@</IB
M;&EC82P@=6YA(&-L879E(%!'4"!P<FEV861A('D@=6YA(&9R87-E(&-L879E
M('!A<F$@9FER;6%R('5N(&UE;G-A:F4N`$AA8V5N(&9A;'1A('5N82!C;&%V
M92!3+TU)344@</IB;&EC82P@=6YA(&-L879E(%,O34E-12!P<FEV861A('D@
M=6YA(&9R87-E(&-L879E('!A<F$@9&5S8VEF<F%R('5N(&UE;G-A:F4N`$AA
M8V5N(&9A;'1A('5N82!C;&%V92!3+TU)344@</IB;&EC82P@=6YA(&-L879E
M(%,O34E-12!P<FEV861A('D@=6YA(&9R87-E(&-L879E('!A<F$@9FER;6%R
M('5N(&UE;G-A:F4N`$AA8V4@9F%L=&$@=6YA(&-L879E(%--24U%('#Z8FQI
M8V$@<&%R82!C:69R87(@=6X@;65N<V%J92X`3G5B97,@;6%T:6YA;&5S`$QI
M9V5R82!L;'5V:6$@;6%T:6YA;`!,;'5V:6$@;6%T:6YA;`!!9W5A8V5R;W,@
M;6%T:6YA;&5S`$%G=6%C97)O(&UA=&EN86P@9&4@;FEE=F4`04TO4$T`240@
M9&4@05!)`$%C97)C82!D96P@961I=&]R`$%C97)C82!D92XN+@!);F9E<FEO
M<B!!8G,N`$5N(&UE9&EO($%B<RX`4V4@:&$@9&5N96=A9&\@96P@86-C97-O
M(&%L(&-R96%R(&5L(&1I<F5C=&]R:6\@5D93+@!392!H82!D96YE9V%D;R!E
M;"!A8V-E<V\@86P@8W)E87(@96P@87)C:&EV;R!61E,N`$ED96YT:61A9`!#
M;VYT<F%S9?%A(&1E(&%C8V5S;P!)9&5N=&ED860@8FQO<75E861A+@!#;VYT
M86)I;&ED860`0?%A9&ER`$'Q861I<B!G<G5P;R!D97-C96YD:65N=&4`0?%A
M9&ER('!R:79I;&5G:6\@9&5S8V5N9&EE;G1E`$'Q861I<B!A<77M.@!!\6%D
M:7(@9W)U<&\`0?%A9&ER('!R:79I;&5G:6\`0?%A9&ER(&$@(B5S(B!U;B!G
M<G5P;R!D97-C96YD:65N=&4`0?%A9&ER(&$@(B5S(B!U;B!P<FEV:6QE9VEO
M(&1E<V-E;F1I96YT90!!\6%D:7(@=6X@=7-U87)I;SH`0?%A9&ER(&-O;'5M
M;F$`0?%A9&ER(&UI96UB<F]S`$'Q861I<B!P87(`0?%A9&ER(&5L(&UE;OH@
M)7,@8V]M;R!P86YE;"!L871E<F%L(&1E($UO>FEL;&$`0?%A9&ER(&$@;&%S
M(&1I<F5C8VEO;F5S.@!!\6%D:7(@82!L87,@9&ER96-C:6]N97,Z`$'Q861I
M<B!U<W5A<FEO`%-E(&AA(&'Q861I9&\@(B5S(B!A;"!S:7-T96UA+"!P97)O
M(&YO('-E('!U961E(&'Q861I<B!L82!I;F9O<FUA8VGS;B!A9&EC:6]N86P@
M9&4@86QT83H@)7,N`%-E(&AA(&'Q861I9&\@(B5S(B!A;"!S:7-T96UA+B!9
M82!P=65D92!I;FEC:6%R(&QA('-E<VGS;BX`3&$@861I8VGS;B!D92!U<W5A
M<FEO<R!E<W3A(&1E<VAA8FEL:71A9&$N`$1I<F5C8VGS;@!$:7)E8V-I;VYE
M<P!!9&UI;FES=')A9&]R("T@9&5F:6YE('!R:79I;&5G:6]S(&1E(&]T<F]S
M('5S=6%R:6]S`$%D;6EN:7-T<F%C:?-N`$%N=6YC:6]S`$%F9V%N:7-TX6X`
M06QB86YI80!!<F=E;&EA`$%L:6%S`$%L:6YE87(`06QI;F5A8VGS;CH`5&]D
M;W,`5&]D;W,@;&]S('5S=6%R:6]S(&%U=&5N=&EF:6-A9&]S`%1O9&]S(&QO
M<R!G<G5P;W,`5&]D;W,@;&]S('!R:79I;&5G:6]S`%1O9&]S(&QO<R!L861O
M<P!097)M:71I<B!V87)I87,@9&ER96-C:6]N97,`OU!E<FUI=&ER(&-O;F9I
M9W5R86-I\VX@9&4@=&EP;R!D92!L:7-T87,@;W)D96YA9&%S/P!982!E>&ES
M=&4`06-C97-O($E-4U`@86QT97)N871I=F\`0VQA=F4@24U34"!A;'1E<FYA
M=&EV80!5<W5A<FEO($E-4%,@86QT97)N871I=F\`1&ER96-C:?-N(&5L96-T
M<O-N:6-A(&%L=&5R;F%T:79A`%!L86YT:6QL87,@86QT97)N871I=F%S`%1E
M>'1O(&%L=&5R;F%T:79O`%-A;6]A($%M97)I8V%N80!392!H82!I;F1I8V%D
M;R!U;B!V86QO<B!I;&5G86PN`%-E(&AA('!R;V1U8VED;R!U;B!E<G)O<B!D
M97-C;VYO8VED;RX`06YD;W)R80!!;F=O;&$`06YG=6EL80!0<F]X>2!A;O-N
M:6UO`%)E<W!U97-T80!!;G3A<G1I9&$`06YT:6=U82!Y($)A<F)A9&]S`$%P
M;&EC86-I\VX`3&ES=&$@9&4@87!L:6-A8VEO;F5S`$QA(&%P;&EC86-I\VX@
M97-TX2!L:7-T82X`07!L:6-A<B!A(')E8W5R<V]S(&-O;7!A<G1I9&]S(&1E
M<V-E;F1I96YT97,`07!R;V)A<@!486UA\6\@87!R;WAI;6%D;P!!8G)I;`!!
M<N%B:6=O("A7:6YD;W=S+3$R-38I`%1A;6'Q;R!D96P@87)C:&EV;P!.;VUB
M<F4@9&5L(&%R8VAI=F\`OT5S=&$@<V5G=7)O(&1E('%U92!D97-E82!E;&EM
M:6YA<B!L82!S;VQI8VET=60@9&4@86QT82!D92`E<S\`OT5S=.$@<V5G=7)O
M(&1E('%U92!D97-E82!E;&EM:6YA<B`B)7,B('D@=&]D;W,@<W5S('-U8F=R
M=7!O<S\`07)G96YT:6YA`$%R;65N:6$`07)M96YI;R`H05)-4T-)22TX*0!!
M<G1E`$%R=6)A`$ES;&$@07-C96YS:?-N`$=RX69I8V]S($%S8VEI`%)E9VGS
M;B!D92!!<VEA+U!A8^UF:6-O`+]3;VQI8VET87(@8V]N9FER;6%C:?-N(&%N
M=&5S(&1E(')E86QI>F%R(&]P97)A8VEO;F5S(&1E(&UA;G1E;FEM:65N=&\_
M`$-O;'5M;F%S(&1E(&%S:6=N86-I\VX`26YT96YT82!E;&EM:6YA<B!U;B!G
M<G5P;R!I;F5X:7-T96YT92X`26YT96YT82!E;&EM:6YA<B!U;B!P<FEV:6QE
M9VEO(&EN97AI<W1E;G1E+@!);G1E;G1A(&UO9&EF:6-A<B!U;B!P<FEV:6QE
M9VEO(&EN97AI<W1E;G1E+@!);G1E;G1A(&UO9&EF:6-A<B!U;B!R96-U<G-O
M(&-O;7!A<G1I9&\@:6YE>&ES=&5N=&4N`$%T<FEB=71O<P!!9V]S=&\`075S
M=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ($YO('-E(&5N8V]N='+S(&QA
M(&5X=&5N<VGS;B!I;6%P(&YE8V5S87)I82X`075T:%]C>7)U<SH@16P@;6]T
M;W(@8V%R96-E(&1E(&QA<R!C87!A8VED861E<R!N96-E<V%R:6%S+@!!=71H
M7V-Y<G5S.B!.;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@:6UA<"!N96-E
M<V%R:6$N`$%U=&A?9G1P.B!.;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@
M1E10(&YE8V5S87)I82X@0V]M<&EL92!02%`@8V]N(&QA(&]P8VGS;B`M+65N
M86)L92UF='`N`$%U=&A?:6UA<#H@3F\@<V4@96YC;VYT<O,@;&$@97AT96YS
M:?-N($E-05`@;F5C97-A<FEA+@!!=71H7VMR8C4Z($YO('-E(&5N8V]N='+S
M(&QA(&5X=&5N<VGS;B!K<F(U(&YE8V5S87)I82X`075T:%]L9&%P.B!.;R!E
M<W3A('-O<&]R=&%D82!L82!A9&EC:?-N(&1E('5S=6%R:6]S(&1E($%C=&EV
M92!$:7)E8W1O<GD`075T:%]L9&%P.B!.;R!E<W3A('-O<&]R=&%D82!L82!E
M;&EM:6YA8VGS;B!D92!U<W5A<FEO<R!D92!!8W1I=F4@1&ER96-T;W)Y`$%U
M=&A?;&1A<#H@3F\@<V4@96YC;VYT<O,@;&$@97AT96YS:?-N($Q$05`@;F5C
M97-A<FEA+@!!=71H7VQD87`Z($YO('-E('!U961E(&'Q861I<B!E;"!U<W5A
M<FEO("5S+B#)<W1O(&5S(&QO('%U92!D:6IO(&5L('-E<G9I9&]R.B``075T
M:%]L9&%P.B!);F-A<&%Z(&1E(&5L:6UI;F%R(&5L('5S=6%R:6\@)7,`075T
M:%]L9&%P.B!);F-A<&%Z(&1E(&%C='5A;&EZ87(@96P@=7-U87)I;R`E<P!!
M=71H7VQD87`Z($YO(&5S=.$@<V]P;W)T861A(&QA(&%C='5A;&EZ86-I\VX@
M9&4@=7-U87)I;W,@9&4@06-T:79E($1I<F5C=&]R>0!!=71H7VUC86PZ($YO
M('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!-0T%,(&YE8V5S87)I82X`075T
M:%]S;6)A=71H.B!.;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@<VUB875T
M:"!N96-E<V%R:6$N`$9A;&SS(&QA(&%U=&5N=&EF:6-A8VGS;B!C;VX@96P@
M<V5R=FED;W(@24U!4"X`1F%L;/,@;&$@875T96YT:69I8V%C:?-N`$9A;&SS
M(&QA(&%U=&5N=&EF:6-A8VGS;BX@)7,`16P@<V5R=FED;W(@4D%$2553(&AA
M(')E8VAA>F%D;R!L82!A=71E;G1I9FEC86-I\VXN`$9A;&SS(&QA(&%U=&5N
M=&EF:6-A8VGS;B!C;VX@96P@<V5R=FED;W(@1E10+@!&86QL\R!L82!A=71E
M;G1I9FEC86-I\VX@8V]N(&5L('-E<G9I9&]R(%--0BX`0V%M<&]S(&1I<W!O
M;FEB;&5S.@!!>F5R8F%I:F%N`$5X8W5S87,@0D]&2`!&;VYD;P!#;VQO<B!D
M92!F;VYD;P!#;VYT<F%S9?%A(&ME<F)E<F]S(&EN8V]R<F5C=&$N`$YO;6)R
M92!D92!U<W5A<FEO(&ME<F)E<F]S(&EN8V]R<F5C=&\N`$)A:&%M87,`0F%H
M<F%I;@!"X6QT:6-O("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O
M<P!.;R!S92!E;F-O;G1R\R!E;"!D:7)E8W1O<FEO(&)A<V4@9&4@:6WA9V5N
M97,@(B5S(BX`3.UN96$@8F%S90!"96QA<G5S`$+I;&=I8V$`0F5L:7IE`$)E
M;FEN`$)E<FUU9&%S`$)H=71A;@!#=6UP;&5A\6]S`$YO('-E(&5N8V]N='+S
M(&5L(&)L;W%U92`B)7,B(&1E(&QA(&%P;&EC86-I\VX@(B5S(BX`3W!C:6]N
M97,@9&4@8FQO<75E`%1I<&\@9&4@8FQO<75E`$YE9W)I=&$`0F]L:79I80!-
M87)C861O<F5S`$)O<F1E`$=R;W-O<B!D96P@8F]R9&4Z`$)O<F1E<P!";W-N
M:6$@2&5R>F5G;W9I;F$`06UB;W,`0F]T<W=A;F$`26YF97)I;W(`27-L82!D
M92!";W5V970`0G)A<VEL`%1E<G)I=&]R:6\@;V-EX6YI8V\@9&4@;&$@26YD
M:6$@8G)I=.%N:6-A`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$QI<W1A
M(&1E<V]R9&5N861A`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`4'5N
M=&]S(&1E(&1I<W1R:6)U8VGS;B!#4D,`4')O<&EE9&%D97,@9&4@7V-E;&1A
M+BXN`$YO('-E(&AA(&9I;F%L:7IA9&\@96P@:6YI8VEO(&1E(&QA(&-A8VCI
M+@!!9V5N9&$`0V%L;6$`0V%M8F]Y80!#86UE<OIN`$YO('-E('!U961E*&XI
M(&-O<&EA<B!E;"]L;W,@87)C:&EV;RAS*2`M(&]R:6=E;B!Y(&1E<W1I;F\@
M<V]N(&5L(&UI<VUO+@!.;R!S92!P=65D92AN*2!T<F%S;&%D87(@96PO;&]S
M(&%R8VAI=F\H<RD@+2!E;"!D97-T:6YO(&5S=.$@9&5N=')O(&1E;"!O<FEG
M96XN`$YO('-E('!U961E(')E86IU<W1A<B!L82!C;&%V92!A=71O;>%T:6-A
M;65N=&4L('#S;F=A<V4@96X@8V]N=&%C=&\@8V]N(&5L(&%D;6EN:7-T<F%D
M;W(@9&5L('-I<W1E;6$N`$YO('-E('!U961E(&5S8W)I8FER(&5N(&5L(&%R
M8VAI=F\@(B5S(@!.;R!S92!P=65D96X@861M:6YI<W1R87(@;6%N96IA9&]R
M97,@9&4@<V5S:?-N(&5X=&5R;F]S+@!.;R!S92!P=65D92!C;VYE8W1A<B!A
M;"!S97)V:61O<B!)34%0.B`E<P!.;R!S92!P=65D92!A8G)I<B!E;"!A<F-H
M:79O("(E<R(N`$-A;F%DX0!#86YC96QA<@!#86YC96QA<B!I;F9O<FUE(&1E
M('!R;V)L96UA<P!.;R!S92!P=65D92!E;&EM:6YA<B!E;"!A<F-H:79O("(E
M<R(N`$YO('-E(&5N8W5E;G1R82!U;B!D:7)E8W1O<FEO('1E;7!O<F%L+@!.
M;R!S92!P=65D92!C;VYT:6YU87(@<VEN(&5L('!A<N%M971R;R`G=&%R9V5T
M1FEL92<N`$YO('-E('!U961E(&5L:6UI;F%R(&5L(&1I<F5C=&]R:6\@(B5S
M(BX`3F\@<V4@<'5E9&4@96QI;6EN87(L('1I96YE("5D(&1E<V-E;F1I96YT
M97,N`$YO('-E('!U961E(')E;W)D96YA<BP@96P@;OIM97)O(&1E(&5N=')A
M9&%S('%U92!S92!D97-E82!O<F1E;F%R(&YO(&-O:6YC:61E(&-O;B!L87,@
M86QM86-E;F%D87,N`$YO('-E('!U961E(&1I<FEG:7(@96P@;65N<V%J92!A
M;"!N^FUE<F\@97-P96-I9FEC861O+@!#86)O(%9E<F1E`%-U8G3M='5L;P!0
M<F]V965D;W(`0V%T96=O<NUA<R!Y(&5T:7%U971A<P!)<VQA<R!#86EMX6X`
M5&5LZ69O;F\@;?-V:6P`4')O<&EE9&%D97,@9&4@8V5L9&$`36%R9V5N(&1E
M(&-E;&1A.@!0<F]P:65D861E<R!D92!C96QD80!%<W!A8VEA9&\@9&4@8V5L
M9&$Z`%1E;.EF;VYO(&WS=FEL`$/I;'1I8V\@*$E33RTX.#4Y+3$T*0!#96YT
M<F%R`%)E</IB;&EC82!#96YT<F]A9G)I8V%N80!%=7)O<&$@0V5N=')A;"`H
M25-/+3@X-3DM,BD`1&5T86QL97,@9&5L(&-E<G1I9FEC861O`%!R;W!I971A
M<FEO(&1E;"!C97)T:69I8V%D;P!0;VSM=&EC87,@9&5L(&-E<G1I9FEC861O
M`$-H860`0V%M8FEA<@!#86UB:64@;&$@8V]N=')A<V7Q80!#86UB:6$@96P@
M;F]M8G)E('D@;&$@9&ER96-C:?-N(&5L96-T<O-N:6-A('9I<VEB;&5S(&%L
M(&QE97(@;R!R97-P;VYD97(@82!S=7,@;65N<V%J97,N`$QA(&-O;F9I9W5R
M86-I\VX@86-T=6%L(&YO('-O<&]R=&$@96P@8V%M8FEO(&1E(&-O;G1R87-E
M\6%S+B!0\VYG87-E(&5N(&-O;G1A8W1O(&-O;B!E;"!A9&UI;FES=')A9&]R
M(&1E;"!S:7-T96UA+@!'<N%F:6-O`%9E<FEF:6-A<B!?=NUN8W5L;RXN+@!#
M:&EL90!#:&EN80!#:&EN;R!S:6UP;&EF:6-A9&\@*$=",C,Q,BD`0VAI;F\@
M=')A9&EC:6]N86P@*$)I9S4I`$%P;&EC86-I\VXZ`$5L:6IA('5N82!C;VYT
M<F%S9?%A`$5L:6IA('5N(&YO;6)R92!D92!U<W5A<FEO`$5L:6IA(&/S;6\@
M;6]S=')A<B!L87,@9F5C:&%S.@!396QE8V-I;VYA<B!T:7!O(&1E(&5S=&EL
M;R!D92!L:7-T82`H<&%R82!L:7-T87,@;W)D96YA9&%S*0!)<VQA(&1E(%!A
M<V-U80!.;R!S92!E;F-O;G1R\R!L82!D969I;FEC:?-N(&1E(&-L87-E(&1E
M("5S+@!,:6UP:6%R`$5L:6UI;F%R(&5T:7%U971A<R!-4T]F9FEC90!";W)R
M87(@8V]N<W5L=&$`0F]R<F%R('5S=6%R:6\Z("5S`$)O<G)A<B!U<W5A<FEO
M`$)O<G)A<B!D871O<R!D96P@=7-U87)I;P!$97-P96IA9&\@=&%R9.UO`$AA
M9V$@8VQI8VL@<&%R82!S96=U:7(`0VQI8VMA=&5L;"!P;W(@2%144`!#97)R
M87(@=F5N=&%N80!.=6)E<P!.=6)E<R!T96UP<F%N87,`;G5B;W-O`$ES;&%S
M(&1E(&-O8V]S("A+965L:6YG*0!/8W5L=&%R(&)A<G)A(&QA=&5R86P`0V]L
M87!S87(@8F]R9&5S`$-O;&]M8FEA`$-O;&]R`%-E;&5C=&]R(&1E(&-O;&]R
M`%-E;&5C8VGS;B!D92!C;VQO<@!#;VQU;6YA<SH`5.UT=6QO<R!D92!L87,@
M8V]L=6UN87,`0_-M:6-S`$-O;6%N9&\`26YTZ7)P<BX@8V]M86YD;W,`0V]M
M96YT87)I;P!.;VUB<F4@8V]M^FX`0V]M;W)O<P!#;VUP8?'M80!/<F1E;F%D
M;W)E<P!#;VYD:6-I\VX`0V]N9&EC:6]N97,`1&EF97)E;F-I87,@9&4@;&$@
M8V]N9FEG=7)A8VGS;@!#;VYF:6=U<F%C:?-N('!A<F$@<VEN8W)O;FEZ86-I
M\VX@8V]N(%!$07,L($WS=FEL97,@8V]N(&%G96YD82!Y($]U=&QO;VLN`$QA
M(&-O;F9I9W5R86-I\VX@97-TX2!D97-A8W1U86QI>F%D82X`0V]N9FEG=7)A
M<B`E<P!#;VYF:7)M87(@8V]N=')A<V7Q80!#;VYG;P!#;VYG;RP@4F5P^F)L
M:6-A($1E;6]C<N%T:6-A(&1E;`!&86QL\R!L82!C;VYE>&GS;BX`1F%L;/,@
M;&$@8V]N97AI\VXZ(`!392!H82!R96-H87IA9&\@;&$@8V]N97AI\VX@86P@
M<V5R=FED;W(@9&4@8VQA=F5S('#Z8FQI8V\N`%-E(&AA(')E8VAA>F%D;R!L
M82!C;VYE>&GS;B!A;"!S97)V:61O<B!D92!C;&%V97,@</IB;&EC;RX@36]T
M:79O.B`E<R`H)7,I`$AA(&9A;&QA9&\@;&$@8V]N97AI\VX@86P@<V5R=FED
M;W(@1E10+@!#;VYT86-T;W,`4V4@:&%N(&'Q861I9&\@8V]R<F5C=&%M96YT
M92!L;W,@8V]N=&%C=&]S(&$@<W5S(&1I<F5C8VEO;F5S`%1I<&\@9&4@8V]N
M=&5N:61O(&1E;"!A<F-H:79O(&-O;7!R:6UI9&\Z(`!#;VYT96YI9&\@9&4@
M(B5S(@!#;VYT:6YU87(`27-L87,@0V]O:P!#;V]K:64`0V]P:6%R`$9A;&SS
M(&QA(&-O<&EA.B`E<P!#;W!I87(@<V5L96-C:?-N`$E$(&1E(&-O<W1E`$-O
M<W1A(%)I8V$`0V]S=&$@9&4@36%R9FEL`$YO('-E('!U961E(&-I9G)A<B!E
M;"!M96YS86IE(&UE9&EA;G1E(%!'4#H@`$YO('-E('!U961E(&9I<FUA<B!E
M;"!M96YS86IE(&UE9&EA;G1E(%!'4#H@`$YO('-E('!U961E(&-I9G)A<B!E
M;"!M96YS86IE(&UE9&EA;G1E(%,O34E-10!.;R!S92!P=65D92!F:7)M87(@
M96P@;65N<V%J92!M961I86YT92`@4R]-24U%`$YO('-E('!U961E(&'Q861I
M<B!E;"!C;VYT86-T;RX@)7,`3F\@<V4@<'5E9&4@96YL87IA<B!A;"!S97)V
M:61O<B!,1$%0+@!.;R!S92!P=65D92!C;VUP<F]B87(@96P@<V%L9&\N("5S
M`$YO('-E('!U961E(&-O;F5C=&%R(&%L('-E<G9I9&]R($Q$05`N`$YO('-E
M('!U961E(&-O;F5C=&%R(&%L('-E<G9I9&]R("(E<R(@;65D:6%N=&4@1E10
M.B`E<P!.;R!S92!P=65D92!C<F5A<B!L82!L:7-T82!D92!D:7-T<FEB=6-I
M\VXN("5S`$YO('-E('!U961E;B!D97-C:69R87(@;&]S(&1A=&]S(%!'4#H@
M`$YO('-E('!U961E;B!D97-C:69R87(@;&]S(&1A=&]S(%,O34E-12X`3F\@
M<V4@<'5E9&4@96QI;6EN87(@96P@8V]N=&%C=&\N("5S`$YO('-E('!U961E
M(&5L:6UI;F%R(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BX@)7,`3F\@<V4@
M<'5E9&4@96QI;6EN87(@96P@9W5I\VX@9&4@86-T=6%L:7IA8VGS;B!D92!C
M;VYF:6=U<F%C:?-N("(E<R(N`$YO('-E('!U961E(&1E=&5R;6EN87)A(&QA
M(&1I<F5C8VGS;B!D92!C;W)R96\@9&5L(&1E<W1I;F%T87)I;RX`3F\@<V4@
M<'5E9&4@=')A97(@;&$@;&EB<F5T82!D92!D:7)E8V-I;VYE<R!C;VUP;&5T
M82X`3F\@<V4@<'5E9&4@=')A97(@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N
M(&-O;7!L971A+@!.;R!S92!P=65D92!T<F%E<B!L82!L:7-T82!C;VUP;&5T
M82!D92!L:7-T87,@9&4@9&ES=')I8G5C:?-N+@!.;R!S92!P=65D92!C87)G
M87(@;&$@97-T<F%T96=I82`B)7,B+@!.;R!S92!P=65D92!C<F5A<B!E;"!D
M:7)E8W1O<FEO("(E<R(N`$YO('-E('!U961E(&]B=&5N97(@;&$@8VQA=F4@
M</IB;&EC82!D96P@<V5R=FED;W(@9&4@8VQA=F5S+@!.;R!S92!P=65D92!A
M8G)I<B`B)7,B('!A<F$@97-C<FEB:7(N`$YO('-E('!U961E(&%B<FER("5S
M+@!.;R!S92!P=65D92!A8G)I<B!E;"!M\V1U;&\@9&4@=&%R96%S(&1E(&UA
M;G1E;FEM:65N=&\@)7,`3F\@<V4@<'5E9&4@86)R:7(@96P@9&ER96-T;W)I
M;R`B)7,B+@!.;R!S92!P=65D92!L;V-A;&EZ87(@96P@<V5R=FED;W(@3$1!
M4"X`3F\@<V4@<'5E9&4@;&5E<B`E<RX`3F\@<V4@<'5E9&4@<F5S=&%B;&5C
M97(@;&$@8V]N=')A<V7Q82!D96P@=7-U87)I;R!S;VQI8VET861O+B!087)T
M92!D92!L;W,@9&5T86QL97,@;R!T;V1O<RP@<V]N(&EN8V]R<F5C=&]S+B!0
M<G5E8F4@;W1R82!V97H@;R!P\VYG87-E(&5N(&-O;G1A8W1O(&-O;B!E;"!A
M9&UI;FES=')A9&]R(&1E;"!S:7-T96UA('!A<F$@;>%S(&EN9F]R;6%C:?-N
M+@!.;R!S92!P=65D92!O8G1E;F5R(&QA($%#3"X`3F\@<V4@<'5E9&4@;V)T
M96YE<B!L82!L:6)R971A(&1E(&1I<F5C8VEO;F5S+B`E<P!.;R!S92!P=65D
M92!O8G1E;F5R(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BX@)7,`3F\@<V4@
M<'5E9&5N(&]B=&5N97(@;&%S(&QI<W1A<R!D92!D:7-T<FEB=6-I\VXN("5S
M`$YO('-E('!U961E;B!O8G1E;F5R(&QA<R!C87!A8VED861E<R!D96P@<V5R
M=FED;W(`3F\@<V4@<'5E9&4@<F5S=&%U<F%R(&QA(&-O;F9I9W5R86-I\VXN
M`$YO('-E('!U961E(&5L:6UI;F%R(&5L(&1I<F5C=&]R:6\@(B5S(BX`3F\@
M<V4@<'5E9&4@9W5A<F1A<B!L82!C;VYF:6=U<F%C:?-N(&1E("5S+@!.;R!S
M92!P=65D92!G=6%R9&%R('5N82!C;W!I82!D92!L82!C;VYF:6=U<F%C:?-N
M+@!.;R!S92!P=65D92!G=6%R9&%R('5N82!C;W!I82!D92!L82!C;VYF:6=U
M<F%C:?-N.B`E<P!.;R!S92!P=65D92!G=6%R9&%R(&5L(&=U:?-N(&1E(&%C
M='5A;&EZ86-I\VX@9&4@;&$@8V]N9FEG=7)A8VGS;B!E;CH@(B5S(BX`3F\@
M<V4@<'5E9&4@9W5A<F1A<B!L82!C;W!I82`E<R!D92!L82!C;VYF:6=U<F%C
M:?-N+@!.;R!S92!P=65D92!G=6%R9&%R(&5L(&%R8VAI=F\@)7,@9&4@8V]N
M9FEG=7)A8VGS;BX@4'5E9&4@=71I;&EZ87(@=6YA(&1E(&QA<R!O<&-I;VYE
M<R!P87)A(')E<W1A=7)A<B!E;"!C\V1I9V\@9&4@)7,@;R!C;W!I87(@;6%N
M=6%L;65N=&4@82`E<R!E;"!C\V1I9V\@<VEG=6EE;G1E+@!.;R!S92!P=65D
M92!B=7-C87(@96X@96P@<V5R=FED;W(@3$1!4"X`3F\@<V4@<'5E9&4@9&5S
M=FEN8W5L87(@(B5S(BX`3F\@<V4@<'5E9&4@86-T=6%L:7IA<B!E;"!C;VYT
M86-T;RX@)7,`3F\@<V4@<'5E9&4@86-T=6%L:7IA<B!L82!L:7-T82!D92!D
M:7-T<FEB=6-I\VXN("5S`$YO('-E('!U961E(&5S8W)I8FER(&QA(&-O;F9I
M9W5R86-I\VX@9&4@(B5S(CH@)7,`3F\@<V4@<'5E9&4@;&]C86QI>F%R(&5L
M('!A;F5L(&QA=&5R86P@9&4@36]Z:6QL82X@0V]M<')U96)E('%U92!E<W3I
M(&%B:65R=&\N`$YO('-E('!U961E;B!O=&]R9V%R(&%L('5S=6%R:6\@(B5S
M(B!L;W,@<VEG=6EE;G1E<R!D97)E8VAO<R!P87)A(&QA(&-A<G!E=&$@(B5S
M(CH@)7,`5&5X=&\@8V]N=&%D;P!08>US`$-U<G-O<P!#<F5A<@!#<F5A('5N
M(';M;F-U;&\`0W)E87(`0W)E87(@<W5B8V%R<&5T87,`4')I=FEL96=I;W,@
M9&4@8W)E861O<@!.^FUE<F\@9&4@=&%R:F5T82!D92!C<NED:71O`$-R;V%C
M:6$`0W5B80`T($9A<V5S(&%C='5A;&5S`%-E<VEO;F5S(&%C='5A;&5S`$AO
M<F$@86-T=6%L`%523"!A8W1U86P`57-U87)I;W,@86-T=6%L97,`5&EE;7!O
M(&%C='5A;`!#;VYD:6-I\VX@86-T=6%L.B``17-T:6QO(&%C='5A;`!097)S
M;VYA;&EZ82!L87,@=&%R96%S(&$@96IE8W5T87(@86P@:6YI8VEA<B!S97-I
M\VX@96X@)7,N`$-O<G1A<@!#;W)T87(@<V5L96-C:?-N`$-H:7!R90!#:7+M
M;&EC;R`H2T])."U2*0!#:7+M;&EC;R`H5VEN9&]W<RTQ,C4Q*0!#:7+M;&EC
M;R]58W)A;FEA;F\@*$M/23@M52D`4F5P^F)L:6-A($-H96-A`$1$`$133B`H
M=F5A(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5S+W!A8VMA9V4N9&%T
M86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`1&EA<FEA;65N=&4`P7)?8F]L(&1A
M=&]S`$-O;G-U;'1A(&1E(&QA(&)A<V4@9&4@9&%T;W,`1F5C:&$`4V4@:&$@
M<F5C:6)I9&\@;&$@9F5C:&$`4V5L96-C:?-N(&1E(&9E8VAA`$3M80!%7VQI
M;6EN87(@8V]L=6UN80!$:6-I96UB<F4`3OIM97)O<R!D96-I;6%L97,`4F5D
M=6-I<B!S86YG<F%D;P!0;W(@;VUI<VGS;@!#;VQO<B!P;W(@;VUI<VGS;@!)
M9&5N=&ED860@<&]R(&]M:7-I\VX`4VAE;&P@<&]R(&]M:7-I\VX`1&5F:6YI
M8VEO;F5S`"9N8G-P.T5L:6UI;F%R)FYB<W`[`$5L:6UI;F%R(&-E;&1A`$5L
M:6UI;F%R(&=R=7!O`$5L:6UI;F%R(')E9VES=')O`$5L:6UI;F%R('!R:79I
M;&5G:6\`16QI;6EN87(@>2!V86-I87(@;65N<V%J97,`16QI;6EN87(@8V5L
M9&$`16QI;6EN87(@8V]L=6UN80!%;&EM:6YA<B!P;&%N=&EL;&%S(&%L=&5R
M;F%T:79A<R!E>&ES=&5N=&5S`$5L:6UI;F%R(&UE;G-A:F5S`$5L:6UI;F%R
M('!R:79I;&5G:6]S(&1E("(E<R(`OT5L:6UI;F%R('!R:79I;&5G:6]S('!A
M<F$@(B5S(B!Y(&-U86QQ=6EE<B!P<FEV:6QE9VEO(&1E<V-E;F1I96YT93\`
M16QI;6EN87(@9FEL80!%;&EM:6YA<B!I9&5N=&ED860@<V5L96-C:6]N861A
M`$5L:6UI;F%R('-U8F-A<G!E=&%S`$5L:6UI;F$@;&$@8V]L=6UN82!A8W1U
M86P`16QI;6EN82!L82!F:6QA(&%C='5A;`!392!H82!E;&EM:6YA9&\@96P@
M9W5I\VX@9&4@86-T=6%L:7IA8VGS;B!D92!L82!C;VYF:6=U<F%C:?-N("(E
M<R(N`$AO<F$@9&4@96YT<F5G83H`1&EN86UA<F-A`$1E<V-R:6)A(&5L('!R
M;V)L96UA`$1E<V-R:7!C:?-N`$1E=&%L;&5S("AT86UB:>EN(&5N(&5L(&%R
M8VAI=F\@9&4@<F5G:7-T<F\@9&4@2&]R9&4I.@!392!H86X@<F5G:7-T<F%D
M;R!L;W,@9&5T86QL97,@<&%R82!E;"!A9&UI;FES=')A9&]R+@!$97-A<G)O
M;&QO`%!U;G1O(&1E(&-O;F1E;G-A8VGS;@!0=6YT;R!D92!C;VYD96YS86-I
M\VX@9&4@;&$@^FQT:6UA(&AO<F$Z(`!0=6YT;R!D92!C;VYD96YS86-I\VXZ
M(`!$92!I>G%U:65R9&$@82!D97)E8VAA`$1E(&1E<F5C:&$@82!I>G%U:65R
M9&$`1&ER96-T;W)I;P"_36]S=')A<B!E;B!F;W)M871O(&1E(#(T+6AO<F%S
M/P!/<&-I;VYE<R!D92!6:7-U86QI>F%C:?-N`$UO<W1R87(@<')O;O-S=&EC
M;R!D971A;&QA9&\`36]S=')A<B!P<F]N\W-T:6-O("A4048I`$9O<FUA=&\@
M9&4@=FES=7IA;&EZ86-I\VX`3F]T:69I8V%C:?-N(&1E(&-O;G-U;'1A`$1J
M:6)O=71I`$YO(&5L:6UI;F%R`$YO(&%C8V5D97(@9&ER96-T86UE;G1E(&$@
M;6%I;G1E;F%N8V4N<&AP`+]#;VYT:65N92!L82!P<FEM97)A(&9I;&$@;&]S
M(&YO;6)R97,@9&4@;&]S(&-A;7!O<S\@4VD@97,@87/M+"!S96QE8V-I;VYE
M(&5S=&$@8V%S:6QL83H`1&]M:6YI8V$`4F5P^F)L:6-A($1O;6EN:6-A;F$`
MOTYO(&1I<W!O;F4@9&4@8W5E;G1A/R!3;VQI8^UT96QA+@!$97-C87)G87(`
M1&5S8V%R9V%R("5S`$1E<V-A<F=A<B!L82!C;VYF:6=U<F%C:?-N(&=E;F5R
M861A(&-O;6\@=6X@9W5I\VX@4$A0+@!,:7-T82!D97-P;&5G86)L90!$<F]G
M87,`0V]R<F5O`$-O;G1R;VQA9&]R(&1E('!A<V%R96QA($-O<G)E;RUA+5--
M4R!P87)A('!R;W9E961O<F5S('%U92!P<F]P;W)C:6]N96X@97-T92!S97)V
M:6-I;RX`15)2`$5C=6%D;W(`)FYB<W`[36]D:69I8V%R)FYB<W`[`$UO9&EF
M:6-A<B!B;&]Q=64`36]D:69I8V%R(&=R=7!O`$UO9&EF:6-A<B!P<FEV:6QE
M9VEO`$UO9&EF:6-A<B!P<FEV:6QE9VEO<P!-;V1I9FEC87(@<')I=FEL96=I
M;W,@9&4@)7,`36]D:69I8V%R(&]P8VEO;F5S(&1E.@!-;V1I9FEC87(@<')I
M=FEL96=I;W,@9&4@(B5S(@!-;V1I9FEC87(@<')I=FEL96=I;W,@9&4@)7,`
M161U8V%C:?-N`$5G:7!T;P!%;"!386QV861O<@!%;&5M96YT;RXN+@!%;0!#
M;W)R96\`1&ER96-C:?-N(&1E(&-O<G)E;P!,87,@9&ER96-C:6]N97,@9&4@
M8V]R<F5O('1I96YE;B!Q=64@8V]I;F-I9&ER+@!#;W)R96\@8V]N(&-O;F9I
M<FUA8VGS;@!087-A<F5L82!#;W)R96\M82U335,`16UO=&EC;VYE<P!-96YS
M86IE(&5N(&)L86YC;P!297-U;'1A9&\@96X@8FQA;F-O+@!,:6UP:6%R('3I
M<FUI;F]S(&1E(&+Z<W%U961A`+]097)M:71I<B!I;G-E<F-I\VX@9&4@:6WA
M9V5N97,@9&4@;&%S($=A;&5R[6%S(&1E(&9O=&]S/P"_4&5R;6ET:7(@;65N
M^B!D92!C;VYT97AT;R!D96P@8F]T\VX@9&5R96-H;R!D96P@<F%T\VX_`$'Q
M;R!D92!T97)M:6YA8VGS;@!!9W)A;F1A<B!E9&ET;W(`26YT<F]D=7IC82!U
M;F$@<')E9W5N=&$@9&4@<V5G=7)I9&%D('%U92!S92!L92!F;W)M=6QA<N$@
M<VD@<')E8VES82!R96%J=7-T87(@;&$@8V]N=')A<V7Q82P@<"YE+B`GOT-U
MX6P@97,@96P@;F]M8G)E(&1E('-U(&UA<V-O=&$_)SH`26YT<F]D=7IC82!A
M<77M(&QA(%523"!D92!L82!I;6%G96X`26YT<F]D=7IC82!L87,@;&5T<F%S
M(&1E(&1E8F%J;SH`1W5I;F5A($5C=6%T;W)I86P`17)I=')E80!%<G)O<@!%
M<G)O<B!A;"!C<F5A<B!E;"!B;&]Q=64Z("5S`$5R<F]R(&%L(&5L:6UI;F%R
M(&%N8VQA(&1E('-I;F-R;VYI>F%C:?-N.B`E<P!%<G)O<B!A;"!E;&EM:6YA
M<B!E;"!R96=I<W1R;R!D92!S:6YC<F]N:7IA8VGS;CH@)7,`17)R;W(@86P@
M;V)T96YE<B!C;VYT96YI9&]S.B`E<P!%<G)O<B!A;"!A8W1U86QI>F%R(&QA
M(&-O;G1R87-E\6$Z("5S`$5R<F]R(&-O;B!E;"!M96YS86IE(&1E(&-O<G)E
M;RX`17)R;W(@86P@97-C<FEB:7(@(B5S(BX`17-T;VYI80!%=&EO<.UA`,ET
M;FEC;P!%=7)O<&$`0V%D82`Q-2!M:6YU=&]S`$-A9&$@,B!M:6YU=&]S`$-A
M9&$@,S`@<V5G=6YD;W,`0V%D82`U(&UI;G5T;W,`0V%D82!I;FEC:6\@9&4@
M<V5S:?-N`$-A9&$@;65D:6$@:&]R80!#861A(&UI;G5T;P!686QO<F5S(&1E
M(&5J96UP;&\Z`$5J96-U=&%R`$5X<&%N9&ER`$UO<W1R87(@8F%R<F$@;&%T
M97)A;`!S92!E<W!E<F%B82`G*2<`4V4@97-P97)A8F$@=6YA(/IN:6-A('!A
M;&%B<F$@;R!U;B!TZ7)M:6YO(&1E(&+Z<W%U961A(&5N=')E8V]M:6QL861O
M`$9E8VAA(&1E('9E;F-I;6EE;G1O`$5X<&]N96YT90!#;VQO<B!D92!L971R
M80!#87)G87(@;&$@8V]N9FEG=7)A8VGS;B!P;W(@1E10`$9A;&QO(&%L('1R
M865R(&QA<R!P<F5F97)E;F-I87,N`$EN8V%P87H@9&4@8V]N96-T87)S92!A
M;"!S97)V:61O<B!,1$%0+@!);F-A<&%Z(&1E(&-O;F5C=&%R<V4@86P@<V5R
M=FED;W(@4TU"+@!&86QL;R!A;"!C;W!I87(@9&4@(B5S(BX`1F%L;&\@86P@
M8V]P:6%R(&$@(B5S(BX`1F%L;&\@86P@8W)E87(@=6YA(&-O;F5X:?-N(%-!
M4TP`1F%L;&\@86P@=')A<VQA9&%R("(E<R(N`$9A;&QO(&%L(')E8W5P97)A
M<CH@)7,`1&5S<&5J861O`$ES;&%S($UA;'9I;F%S("A&86QK;&%N9"D`27-L
M87,@1F%R;V4`17)R;W(@:7)R96-U<&5R86)L93H`1F%X`$9A>&5S`$9E8G)E
M<F\`4V4@<VEE;G1E(&-O;6\`4V4@<VEE;G1E(&-O;6\Z(`!0;V-A<R!L;'5V
M:6%S`$5S8V%S;R!A9W5A8V5R;R!D92!N:65V90!-871R:7H@9&4@8V%M<&]S
M`$-!4%1#2$$@9&4@1FEG;&5T`$QE=')A(&1E($9I9VQE=`!&:6II`$%R8VAI
M=F\`3KH@9&4@87)C:&EV;W,Z("5S(&%R8VAI=F\`3KH@9&4@87)C:&EV;W,Z
M("5S(&%R8VAI=F]S`$%R8VAI=F]S`$YO;6)R92!D92!A<F-H:79O`%-E;&5C
M8VGS;B!D92!A<F-H:79O`$-A<F=A<B!A<F-H:79O`$QA(&-A<F=A(&1E(&%R
M8VAI=F]S(&YO(&5S=.$@<V]P;W)T861A+@!&:6QT<F]S`$9I;FQA;F1I80!#
M=6%R=&\@8W)E8VEE;G1E`$-U87)T;R!C<F5C:65N=&4`4F%Z\VX@9FEJ80!6
M;VQT96%R`$1I<W!O<VEC:?-N`$YI96)L80!,82!C87)P971A("5S(&YO(&5X
M:7-T92X`0V]L;W(@9&4@;&5T<F$`0V]M:61A`%!A<F$@;F%V96=A9&]R97,@
M<75E(&YO(&%D;6ET86X@:6WA9V5N97,`4')O;O-S=&EC;R`H5$%&*0!$[6%S
M(&1E;"!P<F]N\W-T:6-O("AT96YG82!E;B!C=65N=&$@<75E(&5L('!R;V[S
M<W1I8V\@9F%C:6QI=&%D;R!I;F-L=7EE('1A;G1O(&5L(&3M82!C;VUO(&QA
M(&YO8VAE.R!U;B!N^FUE<F\@9W)A;F1E('-E('1R861U8VERX2!E;B!U;B!B
M;&]Q=64@;75Y(&%N8VAO*0"_2&$@;VQV:61A9&\@;&$@8V]N=')A<V7Q83\`
M1F]R;75L87)I;W,`1F]R='5N80!4:7!O(&1E(&9O<G1U;F$`1F]R='5N87,`
M1F]R='5N87,@,@!&;W)O<P!2965N=NUO<P!6:64`1G)A;65S`$9R86YC:6$`
M1G)A;F-I82P@365T<F]P;VQI=&%N80!'=6%Y86YA(&9R86YC97-A`%!O;&EN
M97-I82!F<F%N8V5S80!497)R:71O<FEO<R!F<F%N8V5S97,@9&5L('-U<@!$
M90!$96P@`$1E<V-R:7!C:?-N(&-O;7!L971A`$QU;F$@;&QE;F$`3F]M8G)E
M(&-O;7!L971O`$=A8O-N`$=A;&5R[6$@9&4@;&$@<75E(&]B=&5N97(@;&$@
M:6UA9V5N`$=A;&5R[6$Z`$=A;6)I80!'96YE<F%R(&-O;F9I9W5R86-I\VX@
M9&4@)7,`0_-D:6=O(&=E;F5R861O`$=E;W)G:6$`06QE;6%N:6$`1VAA;F$`
M1VEB<F%L=&%R`$YO;6)R92!I;F1I8V%D;P!/<&-I;VYE<R!G;&]B86QE<P!)
M<@!';V5D96P`36%P87,@9&4@1V]O9VQE`$+Z<W%U961A(&5N($=O;V=L90!%
M<V-A;&$@9&4@9W)I<V5S`$=R96-I80!'<FEE9V\@*$E33RTX.#4Y+3<I`$=R
M;V5N;&%N9&EA`$=R86YA9&$`061M:6YI<W1R86-I\VX@9&4@9W)U<&]S`$QO
M<R!N;VUB<F5S(&1E(&=R=7!O(&YO('!U961E;B!D96IA<G-E(&5N(&)L86YC
M;P!'<F]U<%]L9&%P.B!.;R!S92!P=65D92!A\6%D:7(@96P@9W)U<&\@)7,N
M(,ES=&\@97,@;&\@<75E(&1I:F\@96P@<V5R=FED;W(Z(`!'<F]U<%]L9&%P
M.B!);F-A<&%Z(&1E(&5L:6UI;F%R(&5L(&=R=7!O("5S`$=R;W5P7VQD87`Z
M($EN8V%P87H@9&4@86-T=6%L:7IA<B!E;"!G<G5P;R`E<P!'<G5P;W,`1W5A
M9&%L=7!E`$=U86T`1W5A=&5M86QA`$=U97)N97-E>0!0<FEV:6QE9VEO<R!D
M92!I;G9I=&%D;P!,+B!I;G9I=&%D;W,`1W5I;F5A`$=U:6YE82U":7-S874`
M1W5A>6%N80!(5$U,`$A434P@<V4@;FEE9V$@8V]B87)D96UE;G1E(&$@96QI
M;6EN87(@;&$@^FQT:6UA(&-E;&1A(&1E(&QA(&9I;&$N`$A434Q!<F5A('-E
M(&YI96=A(&-O8F%R9&5M96YT92!A(&5L:6UI;F%R(&QA(/IL=&EM82!C;VQU
M;6YA(&1E(&QA('1A8FQA+@!(5$U,('-E(&YI96=A(&-O8F%R9&5M96YT92!A
M(&5L:6UI;F%R(&QA(/IL=&EM82!F:6QA(&1E(&QA('1A8FQA+@!.;R!S92!E
M;F-O;G1R\R!L82!A=71E;G1I9FEC86-I\VX@2%144"X`2&%I=.T`06QG;W)I
M;6\@2&%S:`!.96)L:6YA`$-A8F5C97)A`$-A8F5C97)A<P!)<VQA($AE87)D
M(&4@27-L87,@36-$;VYA;&0`5&]R;65N=&$@=')O<&EC86P@:6YT96YS80!(
M96)R96\@*$E33RTX.#4Y+3@M22D`06QT=7)A`$%Y=61A`$%Y=61A(&1E;"!E
M9&ET;W(`07EU9&%N=&4`2&5M:7-F97)I;P!!<77M('1I96YE(&5L(&-O;6EE
M;GIO(&1E;"!A<F-H:79O.@!!;'1A`%]);FEC:6\`4V%N=&$@4V5D92`H0VEU
M9&%D+45S=&%D;R!D96P@5F%T:6-A;F\I`$EN:6-I;P!$;VUI8VEL:6\`1&ER
M96-T;W)I;R!P97)S;VYA;`!496SI9F]N;R!P87)T:6-U;&%R`$AO;F1U<F%S
M`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@4V4@:&%N(&5N8V]N=')A
M9&\@9&%T;W,@6$U,("5S(&YO(';A;&ED;W,@96X@96P@;65N<V%J92`E<P!(
M;W)D92]+;VQA8CH@3FEN9_IN(&UE;G-A:F4@8V]R<F5S<&]N9&4@86P@;V)J
M971O("5S`$AO<F1E+TMO;&%B.B!.;R!S92!E;F-O;G1R\R!U;B!O8FIE=&\@
M9&4@=&EP;R`E<R!E;B!E;"!M96YS86IE("5S`$AO<F1E+TMO;&%B.B!392!H
M82!E;&EM:6YA9&\@8V]R<F5C=&%M96YT92`E<R`B)7,B`$AO<F1E+TMO;&%B
M.B!%;"!M;W1O<B!D92!I;G1E9W)A8VGS;B!P<F5C:7-A(&1E(&QA(&5X=&5N
M<VGS;B!02%`@)V1O;7AM;"<`2&]R9&4O2V]L86(Z($EN8V%P87H@9&4@8W)E
M87(@;G5E=F\@X7)B;VP@6$U,(&1E;"!O8FIE=&\@)7,`2&]R9&4O2V]L86(Z
M($EN8V%P87H@9&4@96QI;6EN87(@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z
M($EN8V%P87H@9&4@;V)T96YE<B!)1"!-24U%(&1E(&QA('!A<G1E(&1E('1I
M<&\@)7,`2&]R9&4O2V]L86(Z($EN8V%P87H@9&4@<VEN8W)O;FEZ87(@)7,@
M(B5S(CH@)7,`2&]R9&4O2V]L86(Z($EN8V%P87H@9&4@<VEN8W)O;FEZ87(@
M96QE;65N=&]S(&-O;7!A<G1I9&]S.B`E<P!(;W)D92]+;VQA8CH@16QE;65N
M=&\@8V]M<&%R=&ED;R!D97-C;VYO8VED;R`B)7,B`$SM;F5A(&AO<FEZ;VYT
M86P`36%R9V5N(&AO<FEZ;VYT86P`2&]R:7IO;G1A;#H`OT/S;6\@;&QE9_,@
M:&%S=&$@87%U[3\@**%#;VUU;NUQ=65L;RP@<&]R(&9A=F]R(2D`OT-U86YT
M87,@8V]L=6UN87,@9&5S96$@8V]M8FEN87(_`+]#=>%N=&]S(&-A;7!O<R`H
M8V]L=6UN87,I(&AA>3\`OT-U86YT87,@9FEL87,@9&5S96$@8V]M8FEN87(_
M`$AU;65D860`2'5M961A9#H@`$AU;6]R:7-T87,`2'5N9W+M80!(82!F86QL
M861O(&QA(&-R96%C:?-N(&1E;"!B=7KS;B!)34%0.B`E<P!(82!F86QL861O
M(&QA(&5L:6UI;F%C:?-N(&1E;"!B=7KS;B!)34%0.B`E<P!(82!F86QL861O
M(&QA(&-R96%C:?-N(&1E(&5S<&%C:6\@87-I9VYA9&\@9&5L(&)U>O-N($E-
M05`Z("5S`$1I<F5C8VGS;B!)4`!,82!D:7)E8V-I\VX@25`@;F\@97-TX2!D
M:7-P;VYI8FQE+@!,82!D:7)E8V-I\VX@25`@;F\@97-TX2!E;G1R92!B;&]Q
M=65S($-)1%(@<&5R;6ET:61O<RX`5FEO;&%C:?-N(&QO8VMD;W=N($E0+@!)
M7VYS97)T87(@9FEL82!E;F-I;6$`27-L86YD:6$`4_-L;R!I8V]N;W,`26-O
M;F]S(&1E("5S`$EC;VYO<R!C;VX@=&5X=&\`3F]M8G)E(&1E(&QA(&ED96YT
M:61A9#H`4VD@;F\@<V4@;75E<W1R82!C;W)R96-T86UE;G1E+"`E<R!P87)A
M(&%B<FER;&\@96X@=6YA('9E;G1A;F$@;G5E=F$N`%-I(&YO('9E(&YI;F?Z
M;B!I8V]N;R!M961I86YT92!);G1E<FYE="!%>'!L;W)E<BP@<'5E9&4@=&5N
M97(@<75E(&%C=&EV87(@97-T82!C87-I;&QA('!A<F$@9&5S86-T:79A<B!L
M82!T<F%N<W!A<F5N8VEA(%!.1RX`4VD@=F4@97-T92!M96YS86IE('-I;B!N
M:6YG=6YA(&EM86=E;BP@;&$@:6UA9V5N('%U92!Q=6EE<F4@8V%R9V%R(&YO
M('-E('!U961E(&UO<W1R87(@96X@<W4@;F%V96=A9&]R+@!6:7-T82!P<F5V
M:6$Z`%523"!D92!L82!I;6%G96X`55),(&1E(&QA(&EM86=E;CH`26UA9V5N
M(&1E(&QA(&=A;&5R[6$`26UA9V5N(&1E(&QA(&=A;&5R[6$Z`%-E(&AA(&-A
M<F=A9&\@;&$@:6UA9V5N`$EMX6=E;F5S`$EM<&]R=&%R+"!P87-O("5D`$-A
M;7!O(&EM<&]R=&%D;SH@)7,`0V%M<&]S(&EM<&]R=&%D;W,Z`$EN7W-E<G1A
M<B!F:6QA(&1E8F%J;P!392!H82!I;F1I8V%D;R!U;B!C\V1I9V\@9&4@86-C
M:?-N(&EN8V]R<F5C=&\N`$YO;6)R92!D92!U<W5A<FEO('DO;R!C;VYT<F%S
M9?%A(&EN8V]R<F5C=&]S+@!.;VUB<F4@9&4@=7-U87)I;R!O(&1I<F5C8VGS
M;B!A;'1E<FYA=&EV82!I;F-O<G)E8W1O<RX@5G5E;'9A(&$@:6YT96YT87)L
M;R!O('#S;F=A<V4@96X@8V]N=&%C=&\@8V]N(&5L(&%D;6EN:7-T<F%D;W(@
M9&4@<VES=&5M87,@<&%R82!MX7,@:6YF;W)M86-I\VXN`$%U;65N=&%R('-A
M;F=R861O`$EN9&EA`%5S=6%R:6]S(&EN9&EV:61U86QE<P!);F1O;F5S:6$`
M26YF;W)M86-I\VX`26YF;W)M86-I\VX`3&$@:6YF;W)M86-I\VX@>6$@;F\@
M97-TX2!D:7-P;VYI8FQE+@!);G-E<G1A<B!C7V]L=6UN82!D971RX7,`26YS
M97)T87(@:6UA9V5N`$EN<V5R=&%R('1A8FQA`$EN<V5R=&%R(';M;F-U;&\@
M5V5B`$EN<V5R=&%R(%]C;VQU;6YA(&1E;&%N=&4`26YS97)T82!U;F$@;G5E
M=F$@8V]L=6UN82!D971RX7,@9&4@;&$@86-T=6%L`$EN<V5R=&$@=6YA(&YU
M979A(&-O;'5M;F$@9&5L86YT92!D92!L82!A8W1U86P`26YS97)T82!U;F$@
M9FEL82!N=65V82!D96)A:F\@9&4@;&$@86-T=6%L`$EN<V5R=&$@=6YA(&9I
M;&$@;G5E=F$@96YC:6UA(&1E(&QA(&%C='5A;`!);G-E<G1A('5N('#A<G)A
M9F\@=')A<R!E;"!N;V1O(&%C='5A;`!);G-E<G1A('5N('#A<G)A9F\@86YT
M97,@9&5L(&YO9&\@86-T=6%L`$EN<V5R=&%R('!L86YT:6QL82!A;'1E<FYA
M=&EV80!);G-E<G1A<B!U;F$@9&ER96-C:?-N(&1E(&-O<G)E;R!E;B!L82!Q
M=64@<F5C:6)I<B!L82!C;VYT<F%S9?%A.@!);G-E<G1A<B!C96QD82!D971R
MX7,`26YS97)T87(@8V5L9&$@86YT97,`26YS97)T87(@8V]L=6UN82!D971R
MX7,`26YS97)T87(@8V]L=6UN82!A;G1E<P!);G-E<G1A<B!M96YS86IE<P!)
M;G-E<G1A<B!PX7)R869O(&1E='+A<P!);G-E<G1A<B!PX7)R869O(&%N=&5S
M`$EN<V5R=&%R(&9I;&$@9&5B86IO`$EN<V5R=&%R(&9I;&$@96YC:6UA`$EN
M<V5R=&%R(&QA(')E<W!U97-T82!N96-E<V%R:6$@82!L82!P<F5G=6YT82!D
M92!S96=U<FED860Z`$EN<V5R=&%R+TUO9&EF:6-A<B!I;6%G96X`26YS97)T
M87(O36]D:69I8V%R(';M;F-U;&\`4V%L9&\@:6YS=69I8VEE;G1E('!A<F$@
M96YV:6%R(&$@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N+@!386QD;R!I;G-U
M9FEC:65N=&4N`$5N=&5R;P!,:7-T82!D92!E;G1E<F]S`%5$2"`H0V%B96-E
M<F$@9&4@1&%T;W,@9&4@57-U87)I;RD@;F\@=N%L:61A+@!$871O<R!:25`@
M;F\@=N%L:61O<P!!<&QI8V%C:?-N(&YO(';A;&ED82X`240@9&4@;&]T92!N
M;R!VX6QI9&\N`%-E(&AA;B!E;G9I861O(&1A=&]S(&YO(';A;&ED;W,N`$1I
M<F5C8VGS;B!D92!C;W)R96\@;F\@=N%L:61A+@!&;W)M871O(&1E(&%R8VAI
M=F\@;F\@=N%L:61O`$-L879E(&1E(&QI8V5N8VEA(&YO(';A;&ED82X`4V4@
M:&$@:6YD:6-A9&\@=6YA('5B:6-A8VGS;B!N;R!VX6QI9&$N`&US9U]T>7!E
M(&YO(';A;&ED;RX`87!I7VED(&YO(';A;&ED;R!O(&1E<V%P87)E8VED;RX`
M4&%RX6UE=')O<R!N;R!VX6QI9&]S(&\@9&5S87!A<F5C:61O<RX`4')I=FEL
M96=I;R!D96P@<&%D<F4@;F\@=N%L:61O<RX`240@9&4@87-O8VEA9&\@;F\@
M=N%L:61O+@!#\V1I9V\@9&4@<')O9'5C=&\@;F\@=N%L:61O+@!0<F]T;V-O
M;&\@;F\@=N%L:61O+@!$97-T:6YA=&%R:6\@;F\@=N%L:61O.B`B)7,B`$]B
M:F5T;R!C;VUP87)T:61O(&YO(';A;&ED;RX`1&ER96-C:?-N(&1E;"!R96UI
M=&5N=&4@;F\@=N%L:61A`$1A=&]S('5N:6-O9&4@;F\@=N%L:61O<RX`26YV
M96YT87)I;P!);G9E<G1I<B!S96QE8V-I\VX`27+A;BP@4F5P^F)L:6-A($ES
M;.%M:6-A(&1E`$ER87$`27)L86YD80!)<VQA(&1E($UA;@!";W)R87-C87,@
M86ES;&%D87,`27-R865L`$5M:7-O<@!#=7)S:79A`$ET86QI80!*86UA:6-A
M`$5N97)O`$IA</-N`$IA<&]NZ7,@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R
M9.%N`$IU;&EO`$IU;FEO`$IU<W1I9FEC87(`06QI;F5A<B!A;"!C96YT<F\`
M2G5S=&EF:6-A<@!!;&EN96%R(&$@;&$@:7IQ=6EE<F1A`$%L:6YE87(@82!L
M82!D97)E8VAA`$MA>F%K:'-T86X`OT-O;G-E<G9A<B!E;"!O<FEG:6YA;#\`
M2V5N>6$`16P@<V5R=FED;W(@2V5R8F5R;W,@:&$@<F5C:&%Z861O(&QA(&%U
M=&5N=&EF:6-A8VGS;BX`3F]V871O<R!D96P@2V5R;F5L`$-R96%C:?-N(&1E
M(&-L879E`$AU96QL82!D:6=I=&%L(&1E(&QA(&-L879E`%1A;6'Q;R!D92!C
M;&%V90!4:7!O(&1E(&-L879E`%5S;R!D92!L82!C;&%V93H`3&$@8VQA=F4@
M>6$@97AI<W1E(&5N(&5L('-E<G9I9&]R(&1E(&-L879E<R!P^F)L:6-O+@!.
M:?%O<P!+:7)I8F%T:0!#;W)E82P@4F5P^F)L:6-A(%!O<'5L87(@1&5M;V-R
MX71I8V$@9&4`0V]R96$L(%)E</IB;&EC82!D90!#;W)E86YO("A%54,M2U(I
M`$MU=V%I=`!+>7)G>7IS=&%N`%]$:7-T<FEB=6-I\VX`261I;VUA`$QA;RP@
M4F5P^F)L:6-A($1E;6]C<N%T:6-A(%!O<'5L87(`0W5A<G1O(&UE;F=U86YT
M90#:;'1I;6\@8V%M8FEO(&1E(&-O;G1R87-E\6$`0W5A<G1O(&UE;F=U86YT
M90#:;'1I;6$@86-T=6%L:7IA8VGS;CH`VFQT:6UA('-E<VGS;CH@)7,`VFQT
M:6UA('-E<VGS;CH@)7,@9&5S9&4@)7,`VFQT:6UA('-E<VGS;CH@3G5N8V$`
M3&%T=FEA`$QE>65S`$1I<W1R:6)U8VGS;@!$96IA<B!E;B!B;&%N8V\@<&%R
M82!E;&EM:6YA<B!E;"!B;W)D90!,96)A;F]N`$EZ<75I97)D80!#86)E8V5R
M82!I>G%U:65R9&$`5F%L;W)E<R!D92!L82!I>G%U:65R9&$`3&5S;W1H;P!.
M:79E;`!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS
M=&5I;@!,:6=E<F$@;&QO=FEZ;F$`3&QU=FEA(&QI9V5R80!,;'5V:6$@;&EG
M97)A(&UA='5T:6YA`$QL=79I82!L:6=E<F$@=F5S<&5R=&EN80!!9W5A8V5R
M;R!L:6=E<F\`3&QU=FEA<R!Y('1R=65N;W,`3F5V861A('-U879E`$QI9V5R
M;R!A9W5A8V5R;R!D92!N:65V90!#:&%S8V%R<FEL;&\`5NUN8W5L;P!%;"!V
M[6YC=6QO(&%P=6YT82!A.@!6:6YC=6QA<B!D:7)E8V-I\VX@9&4@8V]R<F5O
M(&$@;&$@<.%G:6YA(&1E(&-O;7!O<VEC:?-N(&%L(&UO<W1R87(`5NUN8W5L
M;W,`0V]O:VEE($QI;G5X`$QI<W1A<B`M(&5L('5S=6%R:6\@<'5E9&4@97AA
M;6EN87(@;&$@8V%R<&5T80!,:7-T87(@8F%S97,@9&4@9&%T;W,`3&ES=&%R
M('1E;6%S(&1E(&%Y=61A`$QI<W1A<B!T86)L87,`3&ES="U!<F-H:79E`$QI
M<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B
M<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`2&$@9F%L;&%D;R!E;"!L:7-T861O
M(&1E(&QA<R!S97-I;VYE<SH@)7,`2&$@9F%L;&%D;R!E;"!L:7-T861O(&1E
M('5S=6%R:6]S.B`E<P!%;"!L:7-T861O(&1E('5S=6%R:6]S(&5S=.$@9&5S
M:&%B:6QI=&%D;RX`3&ET97)A='5R80!,:71U86YI80!,97EE;F1O+BXN`$AO
M<F$@;&]C86PZ(`!)9&EO;6$@>2!H;W)A`%5B:6-A8VGS;@!);FEC:6%R('-E
M<VGS;@!296=I<W1R;R!D92!L87,@<V5S:6]N97,@9&4@<VEN8W)O;FEZ86-I
M\VX@86YT97)I;W)E<P!386QI<@!);FEC:6%R('-E<VGS;@!487)E87,@9&4@
M:6YI8VEO(&1E('-E<VGS;@!&86QL\R!E;"!I;FEC:6\@9&4@<V5S:?-N('!O
M<G%U92!I;G1R;V1U:F\@:6YC;W)R96-T86UE;G1E('-U(&YO;6)R92!D92!U
M<W5A<FEO(&\@8V]N=')A<V7Q82X`1F%L;/,@96P@:6YI8VEO(&1E('-E<VGS
M;BX`5&5X=&\@8V]M<&QE=&\`06UO<@!"86IA`$%L9F%B971O(&=R:65G;R!E
M;B!M:6[Z<V,N`$%L9F%B971O(&QA=&EN;R!E;B!M:6[Z<V,N`$[Z;65R;W,@
M<F]M86YO<R!E;B!M:6[Z<V,N`$QU>&5M8G5R9V\`34T`34]41`!%;"!A9&IU
M;G1O($U3+51.148@;F\@8V]N=&5N[6$@9&%T;W,N`$U31P!-86-A;P!-86-E
M9&]N:6$L($%N=&EG=6$@4F5P^F)L:6-A(%EU9V]S;&%V82!D90!-861A9V%S
M8V%R`$UA9VEA`$-O<G)E;P!!9&TN(&-O<G)E;P!#<F5A<B!?=NUN8W5L;RXN
M+@!-86QA=VD`36%L87-I80!-86QD:79A<P!-86QI`$UA;'1A`$=E<W1I;VYA
M(&QA(&QI<W1A(&1E(&-A=&5G;W+M87,@8V]N(&QA('%U92!E=&EQ=65T87(@
M96QE;65N=&]S('D@;&]S(&-O;&]R97,@87-O8VEA9&]S(&$@9&EC:&%S(&-A
M=&5G;W+M87,N`$UA<&$@;6%P,C0`36%P82!M87!Q=65S=`!#;W)R97-P;VYD
M96YC:6%S(&%L;6%C96YA9&%S+@!-87)Z;P!-87)G96X`36%R8V%R(&-O;B!L
M87,@8F%N9&5R87,@9&4@3&7M9&\O4VEN(&QE97(`36%R8V%R(&-O;B!O=')A
M<B!B86YD97)A<R`H<"YE+B!);7!O<G1A;G1E+U)E<W!O;F1I9&\I`$ES;&%S
M($UA<G-H86QL`$UA<G1I;FEC80!#86UP;W,@8V]I;F-I9&5N=&5S`$UA=7)I
M=&%N:6$`36%U<FEC:6\`4V%L9&\@;>%X:6UO('!E<FUI=&ED;RX`4V4@:&$@
M<V]B<F5P87-A9&\@96P@;OIM97)O(&WA>&EM;R!D92!P87)T97,@9&4@;65N
M<V%J92X`5&5M<"X@;>%X:6UA(/IL=&EM87,@,C0@:&]R87,Z(`!496UP+B!M
MX7AI;6$@^FQT:6UA<R`V(&AO<F%S.B``3OIM97)O(&WA>&EM;R!D92!B;&]Q
M=65S(&1E;"!P;W)T86P`3&]N9VET=60@;>%X:6UA`$UA>6\`36%Y;W1T90!-
M961I8VEN80!-:65M8G)O<P!&;W)M871O(&1E;"!M96[Z.@!#;VUB:6YA<B!C
M96QD87,`365N<V%J90!392!H82!C;VUP<F]B861O(&-O<G)E8W1A;65N=&4@
M96P@;65N<V%J92!P97)O(&YO('-E('!U961E('9E<FEF:6-A<B!E;"!C97)T
M:69I8V%D;R!D96P@9FER;6%N=&4N`$UE;G-A:F4@8V%D=6-A9&\N`%1I<&\@
M9&4@;65N<V%J90!4:65M<&\@9&4@365T87(`0FQO<75E($UE=&%R(&YO(&1I
M<W!O;FEB;&4N`$)L;W%U92!-971A<B!N;R!D:7-P;VYI8FQE+B!392!H86X@
M<F5G:7-T<F%D;R!L;W,@9&5T86QL97,@<&%R82!E;"!A9&UI;FES=')A9&]R
M+@!.;R!E<W3A(&-O;F5C=&%D82!L82!-971A<D1"`$WI=&]D;P!%;"!MZ71O
M9&\@(B5S(B!N;R!E<W3A(&1E9FEN:61O`$WI=&]D;R!N;R!D969I;FED;RX@
M3>ET;V1O(&QL86UA9&\Z("5S`$WI=')I8V\`3>EJ:6-O`$UI8W)O;F5S:6$L
M($5S=&%D;W,@1F5D97)A9&]S(&1E`$5N(&UE9&EO`%1I<&\@36EM90!496UP
M+B!M[6XN(&QA<R#Z;'1I;6%S(#(T(&AO<F%S.B``5&5M<"X@;>UN+B!L87,@
M^FQT:6UA<R`V(&AO<F%S.B``5&]D87;M82!N;R!H82!E>'!I<F%D;R!L82!A
M;G1I9_QE9&%D(&WM;FEM82!D92!L82!C;VYT<F%S9?%A`%)E9FQE:F%R`$UI
M<V-E;.%N96$`4&%Q=65T92!014%2($A45%!?4F5Q=65S="!D97-A<&%R96-I
M9&\N`$9A;'1A(&QA(&-O;F9I9W5R86-I\VXN(%1I96YE('%U92!G96YE<F%R
M;&$@86AO<F$@<VD@9&5S96$@=71I;&EZ87(@97-T82!A<&QI8V%C:?-N+@!)
M1"!D92!M96YS86IE(&1E<V%P87)E8VED;RX`4&%Q=65T92!014%2($UA:6P@
M9&5S87!A<F5C:61O+@!)1"!D92!S97-I\VX@9&5S87!A<F5C:61O+@!,=6X`
M0V]R<F5O(&WS=FEL`$UO9&5R861O`%-E(&AA(&UO9&EF:6-A9&\@;&$@9F5C
M:&$`36]D:69I8V%R(%523`!-\V1U;&\`36]L9&%V:6$L(%)E</IB;&EC82!D
M90!-\VYA8V\`36]N9V]L:6$`365S('D@8?%O`$UE;G-U86QM96YT90!-;VYT
M<V5R<F%T`$9A<V5S(&1E(&QA(&QU;F$`4V4@:&%N(&5N8V]N=')A9&\@;>%S
M(&-A;7!O<R!E;B!L82!L[6YE82`E9"!Q=64@;&]S("5D(&5S<&5R861O<RX`
M36%R<G5E8V]S`$9U;F1A;65N=&%L;65N=&4@9&5S<&5J861O`$9U;F1A;65N
M=&%L;65N=&4@;G5B;W-O`$9U;F1A;65N=&%L;65N=&4@;G5B;W-O('D@=F5N
M=&]S;P!&=6YD86UE;G1A;&UE;G1E('-O;&5A9&\`1&5S<&QA>F%R(&AA8VEA
M(&%B86IO`$1E<W!L87IA<B!A(&QA(&EZ<75I97)D80!$97-P;&%Z87(@82!L
M82!D97)E8VAA`$1E<W!L87IA<B!H86-I82!A<G)I8F$`1&5S<&QA>F%R(&AA
M8VEA(&%B86IO`$1E<W!L87IA<B!H86-I82!A<G)I8F$`36]Z86UB:7%U90!,
M:7-T87,@9&5S<&QE9V%B;&5S(&UU;'1I+6YI=F5L`$UA<&$@54L@;?IL=&EP
M;&4`4V5L96-C:?-N(&WZ;'1I<&QE`$ED96YT:61A9`!-:2!I9&5N=&ED860`
M36D@<&]R=&%L`$1I<W1R:6)U8VGS;B!D92!M:2!P;W)T86P`37EA;FUA<@!.
M3RP@3D\@97-T;WD@9&4@86-U97)D;P!.;VUB<F4`3F%M:6)I80!.875R=0!.
M97!A;`!(;VQA;F1A`$%N=&EL;&%S($AO;&%N9&5S87,`55),(&)A<V4@9&4@
M3F5T<V-A<&4`55),(&1E(&%N=6QA8VGS;B!D92!#02!D92!.971S8V%P90!5
M4DP@9&4@<&]L[71I8V%S(&1E($-!(&1E($YE='-C87!E`%523"!D92!R96YO
M=F%C:?-N(&1E($YE='-C87!E`%523"!D92!A;G5L86-I\VX@9&4@3F5T<V-A
M<&4`3F]M8G)E(&1E('-E<G9I9&]R(%-33"!D92!.971S8V%P90!#;VUE;G1A
M<FEO(&1E;"!C97)T:69I8V%D;R!D92!.971S8V%P90!4:7!O(&1E(&-E<G1I
M9FEC861O(&1E($YE='-C87!E`%)E9`!.=6YC80!.=65V82!#86QE9&]N:6$`
M3G5E=F$@8V%T96=O<NUA`$QU;F$@;G5E=F$`3G5E=F\@;F]M8G)E(&1E('5S
M=6%R:6\@*&]P8VEO;F%L*0!.=65V82!:96QA;F1A`$-O;G1R87-E\6$@;G5E
M=F$`3&$@;G5E=F$@8V]N=')A<V7Q82!E>'!I<F%RX2!E;"`E>"X`3&%S(&-O
M;G1R87-E\6%S(&YO(&-O:6YC:61E;BX`3G5E=F$@=F5N=&%N82`H7V)L86YK
M*0!.;W1I8VEA<P!'+B!D92!N;W1I8VEA<P!3:6=U:65N=&4`4'+S>&EM87,@
M-"!F87-E<P!/<&-I;VYE<R!S:6=U:65N=&5S`%-I9W5I96YT93X`3FEC87)A
M9W5A`$YI9V5R`$YI9V5R:6$`3F]C:&4`3FEU90!.;P!.;R!H87D@9&%T;W,@
M9&4@8V]N9FEG=7)A8VGS;B!P87)A(&UO<W1R87(@9&EF97)E;F-I87,N`$YO
M('-E(&1I<W!O;F4@9&4@97-T<F%T96=I82!D92!E;&%B;W)A8VGS;B!D92!I
M;>%G96YE<R!)4T\N`$YO(&AA>2!P;&%N=&EL;&$@9&4@;&]T97,`3F\@:&%Y
M(&)L;W%U97,@96X@;&$@<&]S:6-I\VX@:6YD:6-A9&$`3F\@<V4@:&$@:6YT
M<F]D=6-I9&\@=6X@;F]M8G)E(&1E(&%G96YD82!P87)A(&QA(&%U=&5N=&EF
M:6-A8VGS;B!-0T%,+@!3:6X@8V%M8FEO<RX`3F\@<V4@<'5E9&5N(&'Q861I
M<B!D97-C96YD:65N=&5S(&$@97-T92!P<FEV:6QE9VEO+@!.;R!S92!H82!E
M<W!E8VEF:6-A9&\@:6YF;W)M86-I\VX@9&4@8V]N9FEG=7)A8VGS;B!P87)A
M("5S+@!.;R!S92!H82!E<W!E8VEF:6-A9&\@:6YF;W)M86-I\VX@9&4@8V]N
M9FEG=7)A8VGS;B!P87)A(%9&4R!P;W(@1E10+@!.;R!S92!H82!E<W!E8VEF
M:6-A9&\@:6YF;W)M86-I\VX@9&4@8V]N9FEG=7)A8VGS;B!P87)A(%9&4R!P
M;W(@4U%,+@!.;R!S92!H82!E<W!E8VEF:6-A9&\@:6YF;W)M86-I\VX@9&4@
M8V]N9FEG=7)A8VGS;B!P87)A(%9&4R!P;W(@87)C:&EV;R!344PN`$YO('%U
M961A('-A;&1O+@!.;R!S92!H82!I;G1R;V1U8VED;R!E;"!D97-T:6YO+@!.
M;R!S92!H82!C87)G861O(&YI;F?Z;B!A<F-H:79O`$YO('-E(&AA;B!E;F-O
M;G1R861O(&EC;VYO<RX`3F\@<V4@:&$@9&5F:6YI9&\@;&$@=6)I8V%C:?-N
M+@!.;R!S92!H82!D969I;FED;R!L82!U8FEC86-I\VXN`$YO('-E(&AA(&EN
M=')O9'5C:61O('5N(&UE;G-A:F4N`$YO('-E(&AA(&5S<&5C:69I8V%D;R!U
M;B!N;VUB<F4N`$YO('-E(&AA(&5S<&5C:69I8V%D;R!U;B!N^FUE<F\N`$YO
M(&]F96YS:79A<P!.;R!S92!H82!I;G1R;V1U8VED;R!U;F$@8V]N=')A<V7Q
M82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!(5%10+@!.;R!S92!H82!I;G1R
M;V1U8VED;R!U;F$@8V]N=')A<V7Q82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS
M;B!)34%0+@!.;R!S92!H82!I;G1R;V1U8VED;R!U;F$@8V]N=')A<V7Q82!P
M87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!+97)B97)O<RX`3F\@<V4@:&$@:6YT
M<F]D=6-I9&\@=6YA(&-O;G1R87-E\6$@<&%R82!L82!A=71E;G1I9FEC86-I
M\VX@9&4@:6YI8VEO+@!.;R!S92!H82!I;G1R;V1U8VED;R!U;F$@8V]N=')A
M<V7Q82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!005-35T0N`$YO('-E(&AA
M(&EN=')O9'5C:61O('5N82!C;VYT<F%S9?%A('!A<F$@;&$@875T96YT:69I
M8V%C:?-N(%--0BX`3F\@<V4@:&$@:6YD:6-A9&\@=NUA(&1E(&%C8V5S;R!A
M(&QO<R!B:6YA<FEO<R!/<&5N4U-,+B!087)A('1R86)A:F%R(&-O;B!D871O
M<R!02T-3(#$R(&AA8V5N(&9A;'1A(&QO<R!B:6YA<FEO<R!/<&5N4U-,+@!3
M:6X@86QT87,@<&5N9&EE;G1E<RX`0V%R96-E(&1E('%U;W1A+@!3:6X@<F%Y
M87,`3F\@<V4@:&$@97-P96-I9FEC861O('5N('-E<&%R861O<BX`3FEN9W5N
M;P!.;R!E>&ES=&4@96P@87)C:&EV;P!.;R!S92!D:7-P;VYE(&1E('5N(&1I
M<F5C=&]R:6\@9&4@86QM86-E;F%M:65N=&\@=&5M<&]R86PN`$YO('-E(&AA
M(&5N=FEA9&\@96P@;F]M8G)E(&1E('5S=6%R:6\@>2]O(&QA(&-O;G1R87-E
M\6$N`$YO('-E(&AA;B!D979U96QT;R!D871O<R!834P@=N%L:61O<P!3:6X@
M=F%L;W)E<P!.;R!S92!E;F-O;G1R\R!L82!V97)S:?-N(&5N(&QA(&-O;F9I
M9W5R86-I\VX@;W)I9VEN86PN(%)E9V5N97)A<B!L82!C;VYF:6=U<F%C:?-N
M+@!.;R!S92!E;F-O;G1R\R!L82!V97)S:?-N(&5N(&QA(&-O;F9I9W5R86-I
M\VXN(%)E9V5N97)A<B!L82!C;VYF:6=U<F%C:?-N+@!.:6YG=6YA`$YI;F=U
M;F\@*'5S;R!I;7!L[6-I=&\I`$[S<F1I8V\@*$E33RTX.#4Y+3$P*0!)<VQA
M(&1E($YO<F9O;&L`2&5M:7-F97)I;R!N;W)T90!)<VQA<R!-87)I86YA<R!D
M96P@3F]R=&4`3F]R=65G80!.;R!D97-P=>ES`$YO(&%N=&5S`$YO(&5S('5N
M(&1I<F5C=&]R:6\`4VEN(&1E<V%R<F]L;&%R+@!3:6X@97-T86)L96-E<@!.
M;R!E<W3A('-O<&]R=&%D;RX`3F]T87,`3F\@:&%Y(&YA9&$@=FES=6%L:7IA
M8FQE+"!R971R;V-E9&$N`$YO=FEE;6)R90!.^FUE<F\`3OIM97)O(&1E(&-A
M<F%C=&5R97,`3OIM97)O(&1E(&-O;'5M;F%S`$[Z;65R;R!D92!F:6QA<P!.
M;R!S92!H86X@97-P96-I9FEC861O(&[Z;65R;W,@82!A8W1U86QI>F%R(&5N
M(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BX`06-E<'1A<@!/8FIE=&\`0W)E
M861O<B!D92!O8FIE=&]S`$]C=&%L`$]C='5B<F4`1FEL=')A<B!O9F5N<V%S
M`$]F:6-I;F$`3&$@8V]N=')A<V7Q82!A;G1I9W5A('D@;&$@;G5E=F$@9&5B
M96X@<V5R(&1I<W1I;G1A<RX`0V]N=')A<V7Q82!A;G1I9W5A`$QA(&-O;G1R
M87-E\6$@86YT:6=U82!N;R!E<R!C;W)R96-T82X`3VWA;@!3\VQO(&QO<R!S
M97)V:61O<F5S($E-05`@<V]P;W)T86X@;&%S(&-A<G!E=&%S(&-O;7!A<G1I
M9&%S+@!3\VQO(&]F96YS:79A<P!3\VQO('-E('!E<FUI=&4@=6YA(&1I<F5C
M8VGS;B!D92!C;W)R96\N`%/S;&\@96P@<')O<&EE=&%R:6\@;R!U;B!A9&UI
M;FES=')A9&]R(&1E('-I<W1E;6%S('!U961E(&-A;6)I87(@;&$@<')O<&EE
M9&%D(&\@;&]S('!R:79I;&5G:6]S(&1E('!R;W!I971A<FEO(&1E('5N(')E
M8W5R<V\@8V]M<&%R=&ED;P!!8G)I<B!E;B!U;F$@;G5E=F$@=F5N=&%N80!%
M<G)O<B!/<&5N4U-,.B!.;R!S92!P=65D96X@97AT<F%E<B!D871O<R!D92!L
M82!P87)T92!3+TU)344@9FER;6%D82X`06)R:7(@97-T92!V[6YC=6QO(&5N
M('5N82!V96YT86YA(&YU979A`%-I<W1E;6$@;W!E<F%T:79O`$]P8VEO;F5S
M`$]P8VEO;F5S(&1E("5S`$QI<W1A(&]R9&5N861A`$]R9V%N:7IA8VGS;@!5
M;FED860@;W)G86YI>F%T:79A`$]R9V%N:7IA8VGS;@!0;&%N=&EL;&$@9&4@
M87!L:6-A8VGS;B!O<FEG:6YA;`!0;&%N=&EL;&%S(&]R:6=I;F%L97,@96X@
M)7,Z`$]T<F\`3W1R82!I;F9O<FUA8VGS;@!0<FEV:6QE9VEO<R!D96P@<')O
M<&EE=&%R:6\`3&$@875T96YT:69I8V%C:?-N(%!!32!N;R!E<W3A(&1I<W!O
M;FEB;&4N`%!%05(Z.DUO=&]R(&1E(&-O<G)E;P!&:7)M82!D:6=I=&%L(%!'
M4`!$871O<R!C:69R861O<R!C;VX@4$=0`$-L879E(%!'4"!P^F)L:6-A`$1A
M=&]S(&9I<FUA9&]S+V-I9G)A9&]S(&-O;B!01U``0_-D:6=O(%!(4`!);G3I
M<G!R+B!02%``3&QO=FEZ;F$@=F5S<&5R=&EN80!,;'5V:6$@=F5S<&5R=&EN
M80!#:&%P87)R;VYE<R!V97-P97)T:6YO<P!.:65V92!V97-P97)T:6YA`$%G
M=6%C97)O(&1E(&YI979E('9E<W!E<G1I;F\`4V]L('9E<W!E<G1I;F\`0F]R
M<F%S8V%S('9E<W!E<G1I;F%S`$YO('-E(&5N8W5E;G1R82!L82!E>'1E;G-I
M\VX@4$]325@`26YTZ7)P<BX@4%](4`!-87)G96X`4&%K:7-TX6X`4&%L874`
M4&%L97-T:6YO<RP@5&5R<FET;W)I;W,@3V-U<&%D;W,`4&%N86WA`%!A</IA
M($YU979A($=U:6YE80!087)A9W5A>0!087)C:6%L;65N=&4@;G5B;W-O`$-O
M;G1R87-E\6$`3&$@8V]N=')A<V7Q82!S92!C86UB:6%D;R!C;W)R96-T86UE
M;G1E+@!#;VYT<F%S9?%A(&EN8V]R<F5C=&$`2&%Y('%U92!I;G1R;V1U8VER
M('5N82!C;VYT<F%S9?%A('!A<F$@;&$@875T96YT:69I8V%C:?-N(%)!1$E5
M4RX`0V]N=')A<V7Q82!C;VX@8V]N9FER;6%C:?-N`$-O;G1R87-E\6$Z`$-O
M;G1R87-E\6$Z(`!,87,@8V]N=')A<V7Q87,@=&EE;F5N('%U92!C;VEN8VED
M:7(N`%!E9V%R`%!E9V%R(&1E;"!P;W)T87!A<&5L97,`5NUA`$%L=&%S('!E
M;F1I96YT97,Z`$=E;G1E`%!O<F-E;G1A:F4`4F5A;&EZ87(@;W!E<F%C:6]N
M97,@9&4@;6%N=&5N:6UI96YT;P"_4F5A;&EZ87(@;W!E<F%C:6]N97,@9&4@
M;6%N=&5N:6UI96YT;R!A;"!I;FEC:6%R('-E<VGS;C\`4')I=FEL96=I;P!.
M;R!S92!H82!E;&EM:6YA9&\@96P@<')I=FEL96=I;R`B)7,B+@!0<FEV:6QE
M9VEO(&1E;F5G861O`%!R:79I;&5G:6]S`$%D;6EN:7-T<F%C:?-N(&1E('!R
M:79I;&5G:6]S`$EN9F]R;6%C:?-N('!E<G-O;F%L`%!E<OH`36%S8V]T87,`
M1FEL:7!I;F%S`%1E;.EF;VYO`$9O=&]G<F%F[6%S`%!I=&-A:7)N`%#M>&5L
M97,`5/-P:6-O<P!0=6QS92!E;B!U;F$@8V5L9&$`0V]N9FER;64@<75E(&1E
M<V5A(&5L:6UI;F%R(&5S=&4@96QE;65N=&\Z`$-O;F9I<FUE('%U92!D97-E
M82!E;&EM:6YA<B!E;"!V[6YC=6QO(&$@97-T92!E;&5M96YT;RX`26YT<F]D
M=7IC82!U;B!M97,@>2!U;B!A\6\N`$EN=')O9'5Z8V$@96P@;F]M8G)E(&1E
M(&QA(&YU979A(&-A=&5G;W+M83H`26YT<F]D=7IC82!U;F$@9&ER96-C:?-N
M($E0(';A;&ED82X`26YT<F]D=7IC82!U;F$@9F5C:&$@=N%L:61A+"!C;VUP
M<G5E8F4@96P@;OIM97)O(&1E(&3M87,@9&5L(&UE<RX`26YT<F]D=7IC82!U
M;F$@:&]R82!VX6QI9&$N`%!R;W!O<F-I;VYE('5N(')E<W5M96X@9&5L('!R
M;V)L96UA+@!);G1R;V1U>F-A('-U(&YO;6)R92!D92!U<W5A<FEO('D@8V]N
M=')A<V7Q82X`3&5A(&5L('1E>'1O('-I9W5I96YT92X@1$5"12!A8V5P=&%R
M(&QO<R!TZ7)M:6YO<R!S:2!Q=6EE<F4@=7-A<B!E;"!S:7-T96UA+@!);G1R
M;V1U>F-A(&5L(&YU979O(&YO;6)R92!D92!C871E9V]R[6$Z`%!O;&]N:6$`
M4&]L[71I8V$`16YC=65S=&%S`%!O<G1U9V%L`%!O<VEC:?-N(&1E(&QA(&EM
M86=E;@!0;W-I8VGS;B!D92!L82!T86)L80!%;G9I87(@82!E<W1A(&-A<G!E
M=&$@*&YO(&]B;&EG861O('!O<B!)34%0*0!0<F5C:7!I=&%C:6]N97,@9&4@
M;&$H<RD@^FQT:6UA*',I("5S(&AO<F$H<RDZ(`!0<F]B86)I;&ED860\8G(@
M+SYD92!P<F5C:7!I=&%C:?-N`%!R969S7VQD87`Z(&YO('-E(&5N8V]N='+S
M(&QA(&5X=&5N<VGS;B!,1$%0(')E<75E<FED82X`4')E9G-?<V5S<VEO;CH@
M;F\@<V4@96YC;VYT<O,@;&$@97AT96YS:?-N(&1E('-E<VGS;B!R97%U97)I
M9&$N`%!R97-I\VX`4')E<VGS;B!A;"!N:79E;"!D96P@;6%R.B``4')E<VGS
M;CH@`%9I<W1A('!R979I80!6:7-T82!P<F5V:6$@9&4@;&$@:6UA9V5N(&5N
M('5N82!N=65V82!V96YT86YA`$]P8VEO;F5S(&%N=&5R:6]R97,`26UP<FEM
M:7(@9&]C=6UE;G1O`$-L879E('!R:79A9&$`OU!R;V)L96UA<S\`1&5S8W)I
M<&-I\VX@9&5L('!R;V)L96UA`%!R;WEE8W1O<P!497AT;R!D96P@:6YD=6-T
M;W(`0VQA=F4@4$=0('#Z8FQI8V$`06QG;W)I=&UO(&1E(&-L879E('#Z8FQI
M8V$`26YF;W)M86-I\VX@9&4@8VQA=F4@</IB;&EC80!.;R!S92!G96YE<F%R
M;VX@8V]R<F5C=&%M96YT92!L87,@8VQA=F5S(%#Z8FQI8V$O4')I=F%D82X`
M4'5E<G1O(%)I8V\`3&EM<&EA<B!M96YS86IE<P!1871A<@!#;VYS=6QT80!1
M=6]T80!#;&%V92!24T$@</IB;&EC82`H)60@8FET*0!";W3S;B!D92!O<&-I
M\VX`3&QU=FEA`$QL=79I82!M871U=&EN80!,;'5V:6$@=F5S<&5R=&EN80!!
M9W5A8V5R;P!,;'5V:6$@>2!.:65V90!,;'5V:6$@82!.:65V90!2=65D82!D
M92!L82!F;W)T=6YA`%)A>O-N`"9N8G-P.TQE97(F;F)S<#L`3&5E<B!M96YS
M86IE<P"_16QI;6EN87(@<F5A;&UE;G1E("5S/R!%<W1A(&]P97)A8VGS;B!N
M;R!S92!P=65D92!D97-H86-E<BX`OT5L:6UI;F%R(')E86QM96YT92!L;W,@
M9&%T;W,@9&5L('5S=6%R:6\@)7,_($5S=&$@;W!E<F%C:?-N(&YO('-E('!U
M961E(&1E<VAA8V5R+@!6=65L=F4@82!R96%L:7IA<B!L82#Z;'1I;6$@86-C
M:?-N`$%C='5A;&EZ87(`06-T=6%L:7IA<B!E;&5M96YT;W,@9&4@;65N^B!D
M:6[A;6EC;W,Z`$%C='5A;&EZ87(@=FES=&$@9&5L('!O<G1A;`!296=E>`!.
M879E9V%D;W(@9&4@<F5L86-I;VYE<P!2969R97-C87(`3V)S97)V86-I;VYE
M<P!397)V:61O<F5S(')E;6]T;W,`55),(')E;6]T82`H:'1T<#HO+W=W=RYE
M:F5M<&QO+F-O;2]H;W)D92DZ`%%U:71A<@!1=6ET87(@8FQO<75E`%%U:71A
M<B!C;VQU;6YA`$5L:6UI;F%R(&9O<FUA=&\`475I=&%R('!A<@!%;&EM:6YA
M<B!G=6GS;B!G=6%R9&%D;R!D96P@9&ER96-T;W)I;R!T96UP;W)A;"!D96P@
M<V5R=FED;W(N`$5L:6UI;F%R(`!%;&EM:6YA<B!E<W1E(&YO9&\@9&5L(&1O
M8W5M96YT;P!%;&EM:6YA<B!U<W5A<FEO`$5L:6UI;F%R('5S=6%R:6\Z("5S
M`$YO('-E('!U961E(')E<W!O;F1E<B!A(&QA('-O;&EC:71U9"X@0_-D:6=O
M(&1E(&5R<F]R(&1E=G5E;'1O.B``3F\@<V4@96YC;VYT<O,@96P@<V5R=FEC
M:6\@<V]L:6-I=&%D;RX`3F\@<V4@:&$@97-P96-I9FEC861O(&5L("(E<R(@
M<F5Q=65R:61O(&5N(&QA(&-O;F9I9W5R86-I\VX@9&4@)7,N`$YO('-E(&AA
M(&5S<&5C:69I8V%D;R!E;"`B)7,B(')E<75E<FED;R!E;B!L82!C;VYF:6=U
M<F%C:?-N(&1E(%9&4RX`3F\@<V4@:&$@97-P96-I9FEC861O(&5L("(E<R(@
M<F5Q=65R:61O(&5N(&QA(&-O;F9I9W5R86-I\VXN`$-A;7!O(&YE8V5S87)I
M;P!,:6UP:6%R`$QI;7!I87(@8V]N=')A<V7Q80!,:6UP:6%R(&-O;G1R87-E
M\6$`4F5S=&%U<F%R(/IL=&EM82!C;VYS=6QT80!297-U;'1A9&]S`%)E9W)E
M<V%R(&$@;W!C:6]N97,`4F5E<V-R:6)I<B!C;VYT<F%S9?%A(&YU979A`%)E
M=6YI\VX`4F5S=&%U<F%R(&-O;F9I9W5R86-I\VX`3W!C:6]N97,@9&4@961I
M8VGS;B!D92!T97AT;R!E;G)I<75E8VED;P!#<FEB87,`1&5R96-H80!#86)E
M8V5R82!D97)E8VAA`%9A;&]R97,@9&4@;&$@9&5R96-H80!0<F]P:65D861E
M<R!D92!?9FEL82XN+@!&=6YC:?-N`%)U;6%N[6$`1VER87(@,3@P`$=I<F%R
M(&$@;&$@:7IQ=6EE<F1A`$=I<F%R(&$@;&$@9&5R96-H80!0<F]P:65D861E
M<R!D92!F:6QA`%!R;W!I961A9&5S(&1E(&9I;&$`1FEL87,Z`%)A>6%S`$%P
M87)E8V5RX6X@<F%Y87,@96YT<F4@=&]D87,@;&%S(&9I;&%S('D@8V]L=6UN
M87,`07!A<F5C97+A;B!R87EA<R!S\VQO(&5N=')E(&QA<R!C;VQU;6YA<P!!
M<&%R96-E<N%N(')A>6%S('/S;&\@96YT<F4@;&%S(&9I;&%S`$5J96-U=&%R
M`$9E9&5R86-I\VX@4G5S80!2=6%N9&$`1FER;6$@8W)I<'1O9W+A9FEC82!3
M+TU)344`365N<V%J92!C:69R861O(&5N(%,O34E-10!.;R!E<W3A(&1I<W!O
M;FEB;&4@;&$@875T96YT:69I8V%C:?-N(%-!4TPN`$UE;G,N(%--4P!);G3I
M<G!R+B!344P`4V5N=&5N8VEA(%-13"!P87)A(&-O;G-U;'1A<R!D92!V86QO
M<F5S`%-32`#)6$E43P!);G3I<G!R+B!37U%,`%-A8@!386YT82!(96QE;F$`
M4V%I;G0@2VET=',@>2!.979I<P!386YT82!,=6/M80!386EN="!0:65R<F4@
M>2!-:7%U96QO;@!386X@5FEC96YT92!Y($=R86YA9&EN87,`36ES;6\@9G)A
M;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;G1O(%1O;>%S('D@4'+M
M;F-I<&4`4')O=F5E9&]R(&1E('-A=.EL:71E`$%R86)I82!3875D:71A`$=U
M87)D87(`1W5A<F1A<B`B)7,B`$=U87)D87(@)7,`1W5A<F1A<B!O<&-I;VYE
M<P!'=6%R9&%R(&QA(&-O;F9I9W5R86-I\VX@9V5N97)A9&$@8V]M;R!U;B!G
M=6GS;B!02%`@96X@96P@9&ER96-T;W)I;R!T96UP;W)A;"!D92!S=2!S97)V
M:61O<BX`4V4@:&$@9W5A<F1A9&\@;&$@8V]N9FEG=7)A8VGS;B!D92`E<RX`
M1W5A<F1A<B!G=6GS;B!D92!A8W1U86QI>F%C:?-N(&1E(&QA(&-O;F9I9W5R
M86-I\VX@96XZ("(E<R(N`$)O<G)A<V-A<R!A:7-L861A<P!#:65N8VEA`$)U
M<V-A<@!-+B!B^G-Q=65D80!396QE8V-I;VYA<B!A<F-H:79O<P!396QE8V-I
M;VYE('5N82!F96-H80!396QE8V-I;VYE(&5L(&=R=7!O(&$@8?%A9&ER`%-E
M;&5C8VEO;F4@=6X@;G5E=F\@<')O<&EE=&%R:6\`4V5L96-C:6]N92!U;B!S
M97)V:61O<@!396QE8V-I;VYE(&5L('5S=6%R:6\@82!A\6%D:7(`4V5L96-C
M:6]N87(@=&]D;P!396QE8V-I;VYE('1O9&]S(&QO<R!C;VUP;VYE;G1E<R!D
M92!L82!F96-H82X`4V5L96-C:6]N87(@=6X@;V)J971O`%-I;B!S96QE8V-I
M\VX`4V5L96-C:6]N92!L;W,@8V%RX6-T97)E<R!Q=64@;F5C97-I=&4@9&4@
M;&%S(&-A<VEL;&%S(&1E(&%B86IO+B!0=65D92!C;W!I87)L;W,@>2!P96=A
M<FQO<R!D96P@X7)E82!D92!T97AT;RX`4V5L96-C:6]N92!E;"!D96QI;6ET
M861O<B!D92!F96-H87,Z`%-E;&5C8VEO;F4@96P@9F]R;6%T;R!D92!F96-H
M87,Z`%-E;&5C8VEO;F4@;&$@:61E;G1I9&%D('%U92!Q=6EE<F$@8V%M8FEA
M<CH`4V5L96-C:6]N92!E;"!D96QI;6ET861O<B!D92!H;W)A<SH`4V5L96-C
M:6]N92!E;"!F;W)M871O(&1E(&AO<F%S.@!396QE8V-I;VYE(&1O<R!C86UP
M;W,@8V]I;F-I9&5N=&5S+@!396QE8V-I;VYE('-U(&-O;6)I;F%C:?-N(&1E
M(&-O;&]R97,N`%-E;&5C8VEO;F4@<W4@:61I;VUA('!R969E<FED;SH`16YV
M:6%R(&EN9F]R;64@9&4@<')O8FQE;6%S`$5N=FEA<B!335,`4V5N96=A;`!3
M96YS;W(Z(`!397!T:65M8G)E`%-E<F)I82!Y($UO;G1E;F5G<F\`3OIM97)O
M(&1E('-E<FEE`$1A=&]S(&1E;"!S97)V:61O<B!E<G+S;F5O<R!O(&YO(&1I
M<W!O;FEB;&5S+@!!9&UI;FES=')A8VGS;B!D92!S97-I\VX`2&$@8V%D=6-A
M9&\@96P@240@9&4@<V5S:?-N+@!397-I;VYE<P!%<W1A8FQE8V5R`$5S=&%B
M;&5C92!O<&-I;VYE<R!Q=64@;&4@<&5R;6ET96X@<F5A:G5S=&%R('-U(&-O
M;G1R87-E\6$@<VD@;&QE9V%R82!A(&]L=FED87)L82X`0V]N9FEG=7)A('-E
M<G9I9&]R97,@<F5M;W1O<R!A(&QO<R!Q=64@9&5S964@86-C961E<B!D97-D
M92!E;"!P;W)T86PN`$1E9FEN92!L87,@;W!C:6]N97,@<')E9F5R:61A<R!D
M92!I9&EO;6$L('IO;F$@:&]R87)I82!Y(&9E8VAA<RX`1&5F:6YE(&QA(&%P
M;&EC86-I\VX@9&4@:6YI8VEO+"!L82!C;VUB:6YA8VGS;B!D92!C;VQO<F5S
M+"!L82!A8W1U86QI>F%C:?-N(&1E('#A9VEN82!Y(&]T<F%S(&]P8VEO;F5S
M(&1E('9I<W5A;&EZ86-I\VXN`$-O;F9I9W5R86-I\VX`2&%Y(&=U:6]N97,@
M9&4@86-T=6%L:7IA8VGS;B!D92!L82!C;VYF:6=U<F%C:?-N`%9A<FEA<R!U
M8FEC86-I;VYE<R!D:7-P;VYI8FQE<R!C;VX@96P@<&%RX6UE=')O.B``4V5Y
M8VAE;&QE<P!#;VUP<F%S`%)E<W5M96X@8V]R=&\`OT1E9FEN:7(@8VQA=F5S
M(&1E(&%C8V5S;R!P87)A(&QA(&UA>6]R[6$@9&4@;&]S(';M;F-U;&]S/P`F
M;F)S<#M-;W-T<F%R)FYB<W`[`$UU97-T<F$@;&%S(&1I9F5R96YC:6%S(&5N
M=')E(&QA(&YU979A(&-O;F9I9W5R86-I\VX@>2!L82!A;&UA8V5N861A`+]-
M;W-T<F%R(&AO<F$@9&4@;&$@^FQT:6UA('-E<VGS;B!A;"!I;FEC:6%R/P!-
M;W-T<F%R(&]P8VGS;B!D92!C;VYS97)V87(@96P@;W)I9VEN86P`36]S=')A
M<B!S96QE8W1O<@"_36]S=')A<B!L82!B87)R82!D92!M96[Z(&1E(&]P97)A
M8VEO;F5S(&1E('1A8FQA/P"_36]S=')A<B!E;"!M96[Z("5S(&$@;&$@:7IQ
M=6EE<F1A/P!-=65S=')A(&5L(&1IX6QO9V\@9&4@<')O<&EE9&%D97,@9&4@
M8V5L9&$@9&4@=&%B;&$`375E<W1R82!E;"!D:>%L;V=O(&1E('!R;W!I961A
M9&5S(&1E('1A8FQA`$UU97-T<F$@96P@9&GA;&]G;R!D92!P<F]P:65D861E
M<R!D92!F:6QA(&1E('1A8FQA`$UU97-T<F$@96P@9&GA;&]G;R!D92!P<F]P
M:65D861E<R!D92!I;6%G96X`36]S=')A<B!C87)G80!!9W5A8V5R;W,`3&QU
M=FEA<R!M871U=&EN87,`3&QU=FEA<R!V97-P97)T:6YA<P!!9W5A8V5R;W,@
M96X@;&$@=F5C:6YD860`4F5D=6-I<@!0<FEM97)O(')E9'5Z8V$@;R!Q=6ET
M92!D92!E;FUE9&EO(&QO<R!B;&]Q=65S(&-E<F-A;F]S`%-I97)R82!,96]N
M80!!;'1A`$9I<FUA`$%L9V]R:71M;R!D92!F:7)M80!3:6YG87!U<@!486UA
M\6\`3VUI=&ER(&UA;G1E;FEM:65N=&\`17-L;W9A<75I80!%<VQO=F5N:6$`
M3FEE=F4`06=U86-E<F\@9&4@;FEE=F4`06=U86-E<F\@9&4@;FEE=F4`06=U
M86-E<F\@9&4@;FEE=F4@;6%T=71I;F\`06=U86-E<F\@9&4@;FEE=F4@=F5S
M<&5R=&EN;P!%<W!E<V]R(&1E(&QA(&YI979E.B``17%U:79A;&5N=&4@9&4@
M;&$@;FEE=F4@96X@86=U83H@`$ES;&%S(%-A;&]M\VX`4V]M86QI80!#86YC
M:6]N97,@)B!0;V5M87,`4V5L96-C:?-N(&1E;"!S96YT:61O(&1E(&QA(&-L
M87-I9FEC86-I\VX`4F5M:71E;G1E`%-U9.%F<FEC80!%=7)O<&$@9&5L('-U
M<B`H25-/+3@X-3DM,RD`1V5O<F=I82!D96P@4W5R(&4@27-L87,@4V%N9'=I
M8V@@9&5L(%-U<@!(96UI<V9E<FEO('-U<@!%<W!A8VEA9&\@96YT<F4@8V5L
M9&%S(&%D>6%C96YT97,`17-P86-I861O(&5N=')E(&5L(&-O;G1E;FED;R!Y
M(&5L(&)O<F1E(&1E('5N82!C96QD80!397!A<F%D;W(`17-P86-I861O`$5S
M<&%C:6%D;R!Y(&UA<F=E;@!%<W!A\6$`4W!A;0!%<V-R:71U<F$@9&4@8V%R
M86-T97)E<R!E<W!E8VEA;&5S`$1I=FED:7(@8V5L9&$`1&EV:61I<B!C;VQU
M;6YA`$1I=FED:7(@9FEL80!$97!O<G1E<P!3<FD@3&%N:V$`17-TX6YD87(`
M4W1A<B!4<F5K`$'Q;R!D92!I;FEC:6\`17-T861O(&\@<')O=FEN8VEA`$5S
M=&%D;P!&;W)M871O(&1E(&%L;6%C96YA;6EE;G1O`$1I<F5C8VGS;B!D92!L
M82!C86QL90!486-H861A`$QI<W1A(&1E(&-A9&5N87,`16QI;6EN87(@9&]M
M:6YI;R!D92!L82!D:7)E8V-I\VX`17-T:6QO(%M#4U-=`$1O;0!.;R!S92!E
M;F-O;G1R\R!E;"!S=6)D:7)E8W1O<FEO("(E<R(N`$%S=6YT;P!%;G9I87(`
M4V4@:&$@96YV:6%D;R!U;F$@<V]L:6-I='5D(&1E(&%L=&$@9&4@(B5S(B!E
M;B!E;"!S:7-T96UA+B!.;R!P;V1RX2!I;FEC:6%R('-E<VGS;B!H87-T82!Q
M=64@<V4@:&%Y82!A<')O8F%D;R!L82!S;VQI8VET=60N`%-U8NUN9&EC90#)
M>&ET;P!392!H82!A\6%D:61O(&-O<G)E8W1A;65N=&4@(B5S(B!A;"!S:7-T
M96UA+@!392!H86X@96QI;6EN861O(&-O<G)E8W1A;65N=&4@;&]S(&1A=&]S
M(&1E;"!U<W5A<FEO("(E<R(@9&5L('-I<W1E;6$N`%-E(&AA(&5L:6UI;F%D
M;R!C;W)R96-T86UE;G1E("(E<R(N`%-E(&AA(&5L:6UI;F%D;R!C;W)R96-T
M86UE;G1E("(E<R(@9&5L('-I<W1E;6$N`%-E(&AA(')E<W1A=7)A9&\@8V]R
M<F5C=&%M96YT92!L82!C;VYF:6=U<F%C:?-N+B!2969R97-Q=64@<&%R82!V
M97(@;&]S(&-A;6)I;W,N`%-E(&AA(&=U87)D861O(&-O<G)E8W1A;65N=&$@
M;&$@8V]P:6$@9&4@;&$@8V]N9FEG=7)A8VGS;BX`4V4@:&$@9W5A<F1A9&\@
M8V]R<F5C=&%M96YT92!L82!C;W!I82`E<R!D92!L82!C;VYF:6=U<F%C:?-N
M+@!392!H82!A8W1U86QI>F%D;R!C;W)R96-T86UE;G1E("(E<R(`4V4@:&$@
M97-C<FET;R!C;W)R96-T86UE;G1E("<E<R<`4W5DX6X`4F5S=6UE;@!!;6%N
M96-E<@!!=&%R9&5C97(`4V]L96%D;P!!;6%N96-E<@!!;6%N96-E<B]!=&%R
M9&5C97(`06UA;F5C97(Z(`!!=&%R9&5C97(`071A<F1E8V5R.B``4W5P97+M
M;F1I8V4`4V]P;W)T90!3=7)I;F%M`$%P96QL:61O`%-V86QB87)D('D@2F%N
M($UA>65N`%-W87II;&%N9&EA`%-U96-I80!3=6EZ80!296=I<W1R;R!D92!S
M:6YC<F]N:7IA8VGS;B!E;&EM:6YA9&\`4WEN8TU,`$5R<F]R(&1E('-I;G1A
M>&ES(&5N(&QO<R!TZ7)M:6YO<R!D92!B^G-Q=65D80!297#Z8FQI8V$@P7)A
M8F4@9&4@4VER:6$`0VAU8F%S8V\`0F]R<F%S8V]S;R!Y('9E;G1O<V\`0F]R
M<F%S8V%S`$)O<G)A<V-A<R!M871U=&EN87,`07)C:&EV;R!44U8`4')O<&EE
M9&%D97,@9&4@=&%B;&$`5&%B;&$`4')O<&EE9&%D97,@9&4@=&%B;&$`5&%I
M=^%N`%1A:7?A;BP@4')O=FEN8VEA(&1E($-H:6YA`%1A>6EK:7-TX6X`5&%N
M>F%N:6$L(%)E</IB;&EC82!5;FED82!D90!$97-T:6YO.@!487)E87,`3OIM
M97)O(&1E('1E;.EF;VYO`%1E;7!E<F%T=7)A(&1U<F%N=&4@;&$@^FQT:6UA
M(&AO<F$Z(`!496UP97)A='5R80!496UP97)A='5R83H@`%1E;7!E<F%T=7)A
M/&)R("\^*"5S3>%X)7,O)7--[6XE<RD@)F1E9SLE<P!.;R!S92!E;F-O;G1R
M\R!L82!P;&%N=&EL;&$@(B5S(BX`061M:6YI<W1R86-I\VX@9&4@<&QA;G1I
M;&QA<P!497AT;P!3\VQO('1E>'1O`$%L:6YE86-I\VX@9&4@=&5X=&\`0F]R
M9&4@<W5P97)I;W(@9&5L('1E>'1O`$IU90!486EL86YDZ7,@*%1)4RTV,C`I
M`%1A:6QA;F1I80!.;R!E<W3A(&1I<W!O;FEB;&4@;&$@97AT96YS:?-N($94
M4"X`16P@<VES=&5M82!H:7-T\W)I8V\@97-TX2!D97-H86)I;&ET861O+@!%
M;"!M;W1O<B!D92!I;G1E9W)A8VGS;B!(;W)D92]+;VQA8B!N;R!S;W!O<G1A
M("(E<R(`3F\@<V4@<'5E9&4@:6YI8VEA<B!E;"!R96=I<W1R;R!D92!)35-0
M+@!.;R!S92!H82!C87)G861O(&-O<G)E8W1A;65N=&4@;&$@8VQA<V4@36%I
M;G1E;F%N8V4Z.@!392!H82!C97)R861O(&QA('9E;G1A;F$@9&4@;W!C:6]N
M97,N(%-A;&EE;F1O+@!3:2!D97-E82!U=&EL:7IA<B!P97)M:7-O<RP@96P@
M861M:6YI<W1R861O<B!T:65N92!Q=64@8V]N9FEG=7)A<B!U;B!S;W!O<G1E
M(&1E('!E<FUI<V]S('!E<FUA;F5N=&4N`%/S;&\@96P@8F]R9&4@:6YF97)I
M;W(`16P@240@9&5L(&-O;G1A8W1O(&YO('-E(&5S<&5C:69I8_,L('-E(&1E
M:O,@96X@8FQA;F-O(&\@;F\@<V4@96YC;VYT<O,@96X@;&$@8F%S92!D92!D
M871O<RX`4V4@:&$@8?%A9&ED;R!C;W)R96-T86UE;G1E(&5L(&-O;G1A8W1O
M(&$@<W5S(&1I<F5C8VEO;F5S+@!087)A(&-O;7!R;V)A<B!E;"!M96YS86IE
M(&9I<FUA9&\@:&%C92!F86QT82!E;"!B;&]Q=64@9&4@9FER;6$@<V5P87)A
M9&\N`$5L($E$(&1E(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;B!N;R!S92!E
M<W!E8VEF:6/S+"!S92!D96KS(&5N(&)L86YC;R!O(&YO('-E(&5N8V]N='+S
M(&5N(&QA(&)A<V4@9&4@9&%T;W,N`$YO('-E(&5S<&5C:69I8_,@;&$@;&ES
M=&$@9&4@9&ES=')I8G5C:?-N+@!,87,@8V%R86-T97+M<W1I8V%S(&1E(&-I
M9G)A9&\@;F5C97-I=&%N('5N82!C;VYE>&GS;B!W96(@<V5G=7)A+@!%;"!A
M<F-H:79O("5S('1E;F1R[6$@<75E(&-O;G1E;F5R('5N82!O<&-I\VX@)7,N
M`$5L(&%R8VAI=F\@)7,@=&5N9'+M82!Q=64@8V]N=&5N97(@86QG=6YA<R!O
M<&-I;VYE<R`E<RX`16P@87)C:&EV;R!N;R!C;VYT:65N92!D871O<RX`02!C
M;VYT:6YU86-I\VX@=&EE;F4@;&%S(&-A8F5C97)A<R!D92!E<W1E(&UE;G-A
M:F4@;65S<V%G92]R9F,X,C(N`%-E('-A8F4@<75E(&5L(&UO9&\@9&4@<&%N
M=&%L;&$@8V]M<&QE=&$@9&$@<')O8FQE;6%S(&-O;B!);G1E<FYE="!%>'!L
M;W)E<B!D96)I9&\@82!F86QL;W,@9&5L(&YA=F5G861O<B!Q=64@;F\@:&5M
M;W,@<&]D:61O('-O<VQA>6%R+B!0=65D92!S=69R:7(@=FES=6%L:7IA8VGS
M;B!D92!B87-U<F$L('#I<F1I9&$@9&4@9G5N8VEO;F5S(&1E;"!E9&ET;W(@
M>2]O(&-U96QG=65S(&%L96%T;W)I;W,@9&5L(&YA=F5G861O<BX@4VD@<W4@
M<VES=&5M82!O<&5R871I=F\@97,@5VEN9&]W<R`Y>"P@97,@;75Y('!R;V)A
M8FQE('%U92!S=69R82!U;B!F86QL;R!D92!P<F]T96-C:?-N(&=E;F5R86P@
M>2!T96YG82!Q=64@<F5I;FEC:6%R(&5L(&5Q=6EP;RY<;EQN66$@97-TX2!A
M=FES861O+B!0=6QS92!!8V5P=&%R('-I(&'Z;B!D97-E82!P<F]B87(@96P@
M961I=&]R(&5N(&UO9&\@9&4@<&%N=&%L;&$@8V]M<&QE=&$N`%-E(&AA(&5L
M:6UI;F%D;R!L82!I9&5N=&ED860@(B5S(BX`4_-L;R!E;"!B;W)D92!I>G%U
M:65R9&\`2&%Y('%U92!I;F1I8V%R;&4@82!L82!C;&%S92!#<GEP=%]P9W`Z
M.B!L82!U8FEC86-I\VX@9&4@;&]S(&)I;F%R:6]S($=N=5!'+@!392!H82!M
M;W-T<F%D;R!E;"!M96YS86IE(&5N=FEA9&\@96P@)7,@82`E<R!C;VX@96P@
M87-U;G1O("(E<R(N"LES=&\@;F\@9V%R86YT:7IA('%U92!E;"!M96YS86IE
M(&AA>6$@<VED;R!L96ED;R!O(&-O;7!R96YD:61O+@!.;VUB<F4@=71I;&EZ
M861O(&%L('9I;F-U;&%R(&$@;&$@<.%G:6YA(&1E(&-O;7!O<VEC:?-N`$5L
M(&[Z;65R;R!D92!C86UP;W,@=&EE;F4@<75E('-E<B!U;B!N^FUE<F\N`$AA
M8V4@9F%L=&$@96P@;?-D=6QO(&]P96YS<VP@<&%R82!L82!C;&%S92!(;W)D
M95]#<GEP=%]S;6EM93HZ+@!.;R!S92!P=65D92!G=6%R9&%R(&QA('!R969E
M<F5N8VEA("(E<R(@<&]R<75E('-U<R!D871O<R!S;V)R97!A<V%N(&5L('1A
M;6'Q;R!MX7AI;6\@<&5R;6ET:61O`$YO('-E(&5N8V]N='+S(&5N(&5L('-I
M<W1E;6$@96P@<')O9W)A;6$@<&%R82!V97(@97-T92!T:7!O(&1E(&1A=&]S
M("@E<RDN`$5L(&-A<N%C=&5R(&1E(&-I=&$@9&5B92!S97(@<V5R('/S;&\@
M=6YO+@!3\VQO(&QO<R!L861O<R!I>G%U:65R9&\@>2!D97)E8VAO`%/S;&\@
M96P@;&%D;R!D97)E8VAO`$5L('-E<&%R861O<B!D96)E('-E<B!S\VQO('5N
M;RX`4V4@:&$@96QI;6EN861O(&5L('-E<G9I9&]R("(E<R(N`%-E(&AA(&=U
M87)D861O(&5L('-E<G9I9&]R("(E<R(N`%-E(&AA(&5L:6UI;F%D;R!L82!S
M;VQI8VET=60@9&4@86QT82!D92`E<RX`3&$@9FEL82!E<W!E8VEF:6-A9&$@
M*"5D*2!N;R!E>&ES=&4N`$5L(&%R8VAI=F\@=&5M<&]R86P@(B5S(B!N;R!E
M>&ES=&4N`$5L('1E>'1O('%U92!H82!I;G1R;V1U8VED;R!N;R!C;VEN8VED
M92!C;VX@96P@9&4@;&$@<&%N=&%L;&$N`%/S;&\@;&]S(&QA9&]S('-U<&5R
M:6]R(&4@:6YF97)I;W(`4_-L;R!E;"!L861O('-U<&5R:6]R`%-E('!E<F1I
M97)O;B!L;W,@9&%T;W,@8V%R9V%D;W,@9&5S9&4@96P@<&%S;R!A;G1E<FEO
M<BX`3F\@<V4@<'5D;R!G=6%R9&%R(&5L(&%R8VAI=F\@8V%R9V%D;RX`3F\@
M97-TX2!D:7-P;VYI8FQE(&5L(&)L;W%U92!D92!W96%T:&5R+F-O;2X`3F\@
M<V4@96YC;VYT<O,@96P@9&ER96-T;W)I;R!D92!496UA<R`B)7,B+@!.;R!S
M92!D:7-P;VYE(&1E(&]P8VEO;F5S+@!.;R!H87D@<&%R=&5S('%U92!S92!P
M=65D86X@;6]S=')A<B!E;B!L[6YE82X`16X@97-T92!C86UP;R!H87D@9&5M
M87-I861O<R!C87)A8W1E<F5S+B!(82!I;G1R;V1U8VED;R`E<R!C87)A8W1E
M<F5S('D@=&EE;F4@<75E(&EN=')O9'5C:7(@;65N;W,@9&4@)7,N`%-E('!R
M;V1U:F\@=6X@<')O8FQE;6$@86P@8?%A9&ER(&$@(B5S(B!A;"!S:7-T96UA
M.B`E<P!392!P<F]D=6IO('5N('!R;V)L96UA(&%L(&)O<G)A<B!L;W,@9&%T
M;W,@9&5L('5S=6%R:6\@(B5S(B!D96P@<VES=&5M83H@`%-E('!R;V1U:F\@
M=6X@<')O8FQE;6$@86P@96QI;6EN87(@82`B)7,B(&1E;"!S:7-T96UA.B``
M4V4@<')O9'5J;R!U;B!P<F]B;&5M82!A;"!A8W1U86QI>F%R("(E<R(Z("5S
M`%-E('!R;V1U:F\@=6X@<')O8FQE;6$@8V]N(&QA(&-A<F=A(&1E;"!A<F-H
M:79O.B!.;R!S92!C87)G\R`E<RX`4V4@<')O9'5J;R!U;B!P<F]B;&5M82!C
M;VX@;&$@8V%R9V$@9&5L(&%R8VAI=F\N($5L("5S(&5R82!MX7,@9W)A;F1E
M('%U92!E;"!T86UA\6\@;>%X:6UO('!E<FUI=&ED;R`H)60@8GET97,I+@!3
M92!P<F]D=6IO('5N('!R;V)L96UA(&-O;B!L82!C87)G82!D96P@87)C:&EV
M;RX@4_-L;R!S92!C87)G\R!P87)C:6%L;65N=&4@96P@)7,N`%-E('!R;V1U
M:F\@=6X@97)R;W(@86P@;6]S=')A<B!E<W1A('!A<G1E(&1E;"!M96YS86IE
M`%-E('!R;V1U:F\@=6X@97)R;W(@86P@:6UP;W)T87(@;&]S(&1A=&]S(&1E
M;"!C;VYT86-T;RX`4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!I;7!O<G1A<B!L
M;W,@9&%T;W,@:4-A;&5N9&%R+@!392!P<F]D=6IO('5N(&5R<F]R(&5N(&5L
M(&9O<FUU;&%R:6\@9&4@8V]N9FEG=7)A8VGS;BX@4'5E9&4@<75E(&AA>6$@
M;VQV:61A9&\@<F5L;&5N87(@=6X@8V%M<&\@;F5C97-A<FEO+@!392!P<F]D
M=6IO('5N(&5R<F]R(&%L(&5J96-U=&%R(&QA(&9U;F-I\VX@97-P96-I9FEC
M861A(&1E(&QA(&QI8G)E=&$@9&4@9&ER96-C:6]N97,N(%9U96QV82!A('!R
M;V)A<B!MX7,@861E;&%N=&4N`%-E('!R;V1U:F\@=6X@97)R;W(@86P@86-T
M=6%L:7IA<B!L;W,@9&5T86QL97,@9&5L(&-O;G1A8W1O+B!6=65L=F$@82!P
M<F]B87(@;>%S(&%D96QA;G1E+@!392!P<F]D=6IO('5N(&5R<F]R(&%L(&%C
M='5A;&EZ87(@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N+B!6=65L=F$@82!P
M<F]B87(@;>%S(&%D96QA;G1E+@!%<W1E('-E<G9I9&]R($E-05`@;F\@<V]P
M;W)T82!L87,@8V%R<&5T87,@8V]M<&%R=&ED87,N`,ES=&4@;F\@<&%R96-E
M('-E<B!U;B!A<F-H:79O(')A<B!VX6QI9&\N`,ES=&4@;F\@<&%R96-E('-E
M<B!U;B!A<F-H:79O('II<"!VX6QI9&\N`,ES=&4@;F\@<&%R96-E('-E<B!U
M;B!N^FUE<F\@9&4@=&%R:F5T82!VX6QI9&\N`$5S=&4@8V]N=')O;&%D;W(@
M<&5R;6ET92!E;G9I87(@;65N<V%J97,@82!T<F%VZ7,@9&4@;&$@<&%S87)E
M;&$@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2P@;65D:6%N
M=&4@;&$@05!)($A45%``17-T92!C;VYT<F]L861O<B!P97)M:71E(&5N=FEA
M<B!M96YS86IE<R!A('1R87;I<R!D92!L82!P87-A<F5L82!724X@*&AT='`Z
M+R]W:6YP;&,N8V]M*2P@;65D:6%N=&4@;&$@05!)($A45%``17-T92!C;VYT
M<F]L861O<B!P97)M:71E(&5N=FEA<B!M96YS86IE<R!A('1R87;I<R!D92!L
M82!P87-A<F5L82!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2P@
M;65D:6%N=&4@;&$@05!)($A45%``17-T92!C;VYT<F]L861O<B!P97)M:71E
M(&5N=FEA<B!M96YS86IE<R!V:6$@4TU44"!A('1R87;I<R!D92!L82!P87-A
M<F5L82!D92!6;V1A9F]N92!D92!)=&%L:6$L('/S;&\@82!N^FUE<F]S(%9O
M9&%F;VYE+B!(86-E(&9A;'1A('5N82!C=65N=&$@9&4@8V]R<F5O(&1E(%9O
M9&%F;VYE(&1E($ET86QI82`H:'1T<#HO+W=W=RXQ.3`N:70I+@!(86-E(&9A
M;'1A(&5S=&4@8V%M<&\N`$5S=&4@8V%M<&\@<_-L;R!P=65D92!C;VYT96YE
M<B!E;G1E<F]S+@!%<W1E(&-A;7!O('/S;&\@<'5E9&4@8V]N=&5N97(@;OIM
M97)O<R!Y(&QO<R!D;W,@<'5N=&]S+@!%<W1E(&-A;7!O('/S;&\@<'5E9&4@
M8V]N=&5N97(@=F%L;W)E<R!O8W1A;&5S+@!%<W1E(&-A;7!O('1I96YE('%U
M92!S97(@=6YA(&QI<W1A(&1E(&5N=&5R;W,@<V5P87)A9&]S('!O<B!C;VUA
M<R!O(&5S<&%C:6]S+@!%<W1E(&-A;7!O('1I96YE('%U92!S97(@=6X@;OIM
M97)O(';A;&ED;RX`17-T92!C86UP;R!T:65N92!Q=64@8V]N=&5N97(@=6X@
M8_-D:69O(&1E(&-O;&]R(&5N(&9O<FUA=&\@4D="($AE>&%D96-I;6%L+"!P
M;W(@96IE;7!L;R`G(S$R,S1A9B<N`%EA('-E(&AA('!R;V-E<V%D;R!E<W1E
M(&9O<FUU;&%R:6\N`$5S=&\@97,@)7,N`,ES=&\@97,@=6X@;V)J971O(&1E
M($MO;&%B($=R;W5P=V%R92X@4&%R82!V97)L;R!N96-E<VET82!U;B!C;&EE
M;G1E(&1E(&-O<G)E;R`@<75E(&5N=&EE;F1A(&5L(&9O<FUA=&\@2V]L86(@
M1W)O=7!W87)E+B!087)A('9E<B!U;F$@;&ES=&$@9&4@9&EC:&]S(&-L:65N
M=&5S('9I<VET92`E<P!%<W1E(&UE;G-A:F4@<V4@97-C<FEB:?,@8V]N('5N
M(&IU96=O(&1E(&-A<F%C=&5R97,@*"5S*2!D:7-T:6YT;R!A;"!S=7EO+@!%
M<W1E(&[Z;65R;R!D96)E('-E<B!P;W(@;&\@;65N;W,@=6X@=6YO+@!%<W1E
M('-E<G9I9&]R(&YO('!U961E(&1E<V-O;7!R:6UI<B!A<F-H:79O<R!Z:7`@
M>2!G>FEP+@!%<W1E('-I<W1E;6$@86-T=6%L;65N=&4@97-TX2!D97-A8W1I
M=F%D;RX`17-T92!V86QO<B!T:65N92!Q=64@<V5R('5N(&[Z;65R;RX`17-T
M82!V96YT86YA('/S;&\@<'5E9&4@86)R:7)S92!D97-D92!U;F$@=F5N=&%N
M82!D92!O<&-I;VYE<P!4<G5E;F\`26YC:61E;F-I87,`2&]R80!#+B!T:65M
M<&]S`$9O<FUA=&\@:&]R87)I;P!396QE8V-I\VX@9&4@:&]R80!4:6UO<BU,
M97-T90!4[71U;&\`5.UT=6QO("AC;VYS96IO*3H`4&%R80!087)A('-E;&5C
M8VEO;F%R('9A<FEO<R!C86UP;W,L(&UA;G1E;F=A('!U;'-A9&$@;&$@=&5C
M;&$@0V]N=')O;"`H4$,I(&\@0V]M86YD;R`H36%C*2!A;"!H86-E<B!C;&EC
M:RX`2&]Y`$-O;FUU=&%R(&]R:6=E;B!(5$U,`%1O9V\`5&]K96QA=0!-8?%A
M;F$`5&]N9V$`1&5M87-I861O<R!I;G1E;G1O<R!F86QL:61O<R!E;B!L;W,@
M^FQT:6UO<R!M:6YU=&]S+@!3=7!E<FEO<@!&<F%M92!S=7!E<FEO<B`H7W1O
M<"D`5')A9'5C8VEO;F5S`%1R:6YI9&%D('D@5&]B86=O`%9E<F1A9&5R;R!O
M(&9A;'-O`$UA<@!4^FYE>@!4=7)Q=>UA`%1U<F-O("A)4T\M.#@U.2TY*0!4
M=7)K;65N:7-TX6X`27-L87,@5'5R:W,@>2!#86EC;W,`5'5V86QU`$5S8W)I
M8F$@<W4@96QE8V-I\VXZ(`#-;F1I8V4@52Y6+CH@`%523`!54DP@9&4@<W4@
M:6YF;W)M92!D92!E<W1A9&\@9&4@96YV[6\@9&5L(&=U:?-N`%523#H`56=A
M;F1A`%5C<F%N:6$`26YC87!A>B!D92!A8V-E9&5R(&%L(&1I<F5C=&]R:6\@
M5D93+@!);F-A<&%Z(&1E(&'Q861I<B!I;F9O<FUA8VGS;B!D92!U<W5A<FEO
M(&%D:6-I;VYA;"!A;"!R96%L:7IA<B!E;"!A;'1A+@!);F-A<&%Z(&1E(&-A
M;6)I87(@;&]S('!R:79I;&5G:6]S(&1E;"!A<F-H:79O(%9&4R`B)7,B+@!)
M;F-A<&%Z(&1E(&-A;6)I87(@;&]S('!R:79I;&5G:6]S(&1E;"!A<F-H:79O
M(%9&4R`E<R\E<RX`26YC87!A>B!D92!C86UB:6%R(&$@)7,N`$EN8V%P87H@
M9&4@8V]M<')O8F%R(&5L('1A;6'Q;R!D92`B)7,B+@!);F-A<&%Z(&1E(&-O
M;7!R;V)A<B!E;"!T86UA\6\@9&4@(B5S+R5S(BX`26YC87!A>B!D92!C;VYE
M8W1A<G-E(&%L('-E<G9I9&]R(%-13"X`26YC87!A>B!D92!C;VYE8W1A<B!C
M;VX@4U-,+@!);F-A<&%Z(&1E(&-O<&EA<B!E;"!A<F-H:79O(%9&4RX`26YC
M87!A>B!D92!C<F5A<B!E;"!D:7)E8W1O<FEO(%9&4R`B)7,B+@!);F-A<&%Z
M(&1E(&-R96%R(&5L(&1I<F5C=&]R:6\@5D93+@!);F-A<&%Z(&1E(&-R96%R
M(&5L(&%R8VAI=F\@5D93+@!);F-A<&%Z(&1E(&-R96%R(&QA(&-A<G!E=&$@
M5D93("(E<R(`26YC87!A>B!D92!C<F5A<B!U;B!A<F-H:79O(%9&4R!V86/M
M;RX`26YC87!A>B!D92!D97-C;VUP<FEM:7(@;&]S(&1A=&]S+@!);F-A<&%Z
M(&1E(&5L:6UI;F%R("(E<R(L(&5L(&1I<F5C=&]R:6\@;F\@97-TX2!V86/M
M;RX`26YC87!A>B!D92!E;&EM:6YA<B`B)7,B.B`E<RX`26YC87!A>B!D92!E
M;&EM:6YA<B`E<RP@96P@9&ER96-T;W)I;R!N;R!E<W3A('9A8^UO`$EN8V%P
M87H@9&4@96QI;6EN87(@96P@9&ER96-T;W)I;R!61E,@9&4@9F]R;6$@<F5C
M=7)S:79A+@!);F-A<&%Z(&1E(&5L:6UI;F%R(&5L(&1I<F5C=&]R:6\@5D93
M+@!);F-A<&%Z(&1E(&5L:6UI;F%R(&5L(&1I<F5C=&]R:6\@5D93.B`E<RX`
M26YC87!A>B!D92!E;&EM:6YA<B!E;"!A<F-H:79O(%9&4R`B)7,B+@!);F-A
M<&%Z(&1E(&5L:6UI;F%R(&5L(&%R8VAI=F\@5D93+@!);F-A<&%Z(&1E(&5L
M:6UI;F%R(&QA(&-A<G!E=&$@5D93("(E<R(N`$EN8V%P87H@9&4@96QI;6EN
M87(@96P@5D93(&1E(&9O<FUA(')E8W5R<VEV83H@)7,N`$EN8V%P87H@9&4@
M9&5T97)M:6YA<B!E;"!D:7)E8W1O<FEO(&%C='5A;"X`26YC87!A>B!D92!E
M>'1R865R(&QO<R!D971A;&QE<R!D96P@8V5R=&EF:6-A9&\N`$EN8V%P87H@
M9&4@8V%R9V%R(&QA(&1E9FEN:6-I\VX@9&4@)7,N`$EN8V%P87H@9&4@=')A
M<VQA9&%R(&5L(&%R8VAI=F\@5D93+@!);F-A<&%Z(&1E(&%B<FER(&5L(&%R
M8VAI=F\@5D93("(E<R(N`$EN8V%P87H@9&4@86)R:7(@96P@87)C:&EV;R!6
M1E,@<&%R82!E<V-R:6)I<BX`26YC87!A>B!D92!A8G)I<B!E;"!A<F-H:79O
M(%9&4RX`26YC87!A>B!D92!A8G)I<B!E;"!A<F-H:79O(&-O;7!R:6UI9&\N
M`$EN8V%P87H@9&4@;&5E<B!U;B!A<F-H:79O(%9&4R`H:&$@9F%L;&%D;R!F
M:6QE<VEZ92@I*2X`26YC87!A>B!D92!L965R('5N(&%R8VAI=F\@5D93("AH
M82!F86QL861O(&=E=$9I;&53:7IE*"DI+@!);F-A<&%Z(&1E(&QE97(@=6X@
M87)C:&EV;SH@`$EN8V%P87H@9&4@;&5E<B!E;"!D:7)E8W1O<FEO('9F<W)O
M;W0N`$EN8V%P87H@9&4@<F5N;VUB<F%R("5S(&-O;6\@)7,Z(&QA(&-A<G!E
M=&$@9&5S=&EN;R!Y82!E>&ES=&4`26YC87!A>B!D92!R96YO;6)R87(@96P@
M9&ER96-T;W)I;R!61E,N`$EN8V%P87H@9&4@<F5N;VUB<F%R(&5L(&1I<F5C
M=&]R:6\@5D93.B`E<RX`26YC87!A>B!D92!R96YO;6)R87(@96P@87)C:&EV
M;R!61E,@(B5S(@!);F-A<&%Z(&1E(')E;F]M8G)A<B!E;"!A<F-H:79O(%9&
M4R`E<R\E<RX`26YC87!A>B!D92!R96YO;6)R87(@96P@87)C:&EV;R!61E,N
M`$EN8V%P87H@9&4@96IE8W5T87(@)VUK:7-O9G,G+@!.;R!S92!P=65D92!A
M8W1I=F%R(&QA(&%C='5A;&EZ86-I\VX@9&4@:6YF;W)M86-I\VX@9&4@=&EE
M;7!O(&1I<W!O;FEB;&4@9&4@)7,`26YC87!A>B!D92!E<V-R:6)I<B!E;"!A
M<F-H:79O(%9&4R`B)7,B+@!);F-A<&%Z(&1E(&5S8W)I8FER('5N(&%R8VAI
M=F\@5D93("AH82!F86QL861O(&-O<'DH*2DN`$EN8V%P87H@9&4@97-C<FEB
M:7(@;&]S(&1A=&]S(&1E;"!A<F-H:79O(%9&4RX`26YC87!A>B!D92!E<V-R
M:6)I<B!U;B!A<F-H:79O(%9&4RP@<V4@<W5P97)A<N$@;&$@<75O=&$N`%-U
M8G)A>6%D80!$97-H86-E<B!C86UB:6]S`$1E<VAA8V4@;&$@^FQT:6UA(&%C
M8VGS;@!297-P=65S=&$@:6YE<W!E<F%D82!D96P@<V5R=FED;W(@96X@;&$@
M8V]N97AI\VXZ(`!297-P=65S=&$@:6YE<W!E<F%D82!D96P@<V5R=FED;W(@
M83H@`%-I;B!C871E9V]R[6$`56YI8V]D92`H551&+3@I`$5M:7)A=&]S(,%R
M86)E<R!5;FED;W,`26YG;&%T97)R80!%<W1A9&]S(%5N:61O<P!%<W1A9&]S
M(%5N:61O<R!M96YO<R!L87,@:7-L87,@<&5R:6;I<FEC87,`56YI9&%D97,`
M1&5S8V]N;V-I9&\`07!I;7-G:60@9&5S8V]N;V-I9&\@*$E$(&1E(&UE;G-A
M:F4@9&4@;&$@05!)*2X`0VQI;7-G:60@9&5S8V]N;V-I9&\@*$E$(&1E(&UE
M;G-A:F4@9&5L(&-L:65N=&4I+@!392!H82!D969I;FED;R!U;F$@=6)I8V%C
M:?-N(&1E<V-O;F]C:61A+@!5<W5A<FEO(&\@8V]N=')A<V7Q82!D97-C;VYO
M8VED;W,N`$5L:6UI;F%R(';M;F-U;&\@9&5L(&5L96UE;G1O(&%C='5A;`!3
M:6X@;F]M8G)E`$QO<R!G=6EO;F5S('-I;B!P<FEV:6QE9VEO<R!N;R!P=65D
M96X@86-C961E<B!D92!F;W)M82!P<F]G<F%MX71I8V$@82!#;W)T87(O0V]P
M:6%R+U!E9V%R('!O<B!R87IO;F5S(&1E('-E9W5R:61A9"X@4'5L<V4@06-E
M<'1A<B!P87)A('9E<B!E;B!M;WII;&QA+F]R9R!U;F$@;F]T82!TZ6-N:6-A
M('%U92!L92!M=65S=')E(&/S;6\@<&5R;6ET:7(@<75E('5N(&=U:?-N(&%C
M8V5D82!A;"!P;W)T87!A<&5L97,N`$%N=6QA<B!C;VQO<@!%>'1E;G-I\VX@
M;F\@<V]P;W)T861A`$%C='5A;&EZ87(`06-T=6%L:7IA<B`E<P!!8W1U86QI
M>F%R('5S=6%R:6\`4V4@:&$@86-T=6%L:7IA9&\@(B5S(BX`4V4@:&$@96QI
M;6EN861O(&5L(&=U:?-N(&1E(&%C='5A;&EZ86-I\VXN`$-A<F=A<@!392!H
M86X@8V%R9V%D;R!E;B!E;"!S97)V:61O<B!T;V1O<R!L;W,@87)C:&EV;W,@
M9&4@8V]N9FEG=7)A8VGS;B!D92!A<&QI8V%C:6]N97,N`$%L9F%B971O(&QA
M=&EN;R!E;B!M87GZ<V,N`$[Z;65R;W,@<F]M86YO<R!E;B!M87GZ<V,N`%5R
M=6=U87D`57-A<B!A8W1U86PZ("5S`%5S87(@4U-,`%-E('5S82!S:2!E;"!U
M<W5A<FEO+V-O;G1R87-E\6$@<V]N(&1I<W1I;G1O<R!E;B!E;"!S97)V:61O
M<B!)35-0+@!5<W5A<FEO`$5L('5S=6%R:6\@)7,@8V%R96-E(&1E(&%U=&]R
M:7IA8VGS;B!P87)A("5S+@!!9&UI;FES=')A8VGS;B!D92!U<W5A<FEO<P!/
M<&-I;VYE<R!D92!U<W5A<FEO`%)E9VES=')O(&1E('5S=6%R:6]S`$5S=&$@
M<V5D92!T:65N92!D97-A8W1I=F%D;R!E;"!R96=I<W1R;R!D92!U<W5A<FEO
M<RX`3F\@<V4@:&$@96YC;VYT<F%D;R!L82!I9&5N=&ED860`57-U87)I;P!9
M82!E>&ES=&4@96P@;F]M8G)E(&1E('5S=6%R:6\@(B5S(BX`57-U87)I;SH`
M57-U87)I;SH@`%5S=6%R:6]S(&5N(&5L('-I<W1E;6$Z`%5Z8F5K:7-TX6X`
M3F\@97AI<W1E(&5L(&1I<F5C=&]R:6\@5D93+@!!=7-E;F-I80!,87,@=6)I
M8V%C:6]N97,@=N%L:61A<R!E;F-O;G1R861A<R!I;F-L=7EE;CH@`%9A;&ED
M97H`5F%L;W(@96X@;6EN=71O<R!A('!A<G1I<B!D92!A:&]R82X`16P@=F%L
M;W(@97AC961E(&5L('1A;6'Q;R!MX7AI;6\@9&4@)7,N`%9A;&]R97,`5F%L
M;W)E<R!A('-E;&5C8VEO;F%R`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA
M`$AA(&9A;&QA9&\@;&$@8V]M<')O8F%C:?-N("T@97-T92!M96YS86IE('!U
M961E(&AA8F5R<V4@9F]R>F%D;RX`5F5R<VGS;@!#+B!V97)S:6]N97,`06QI
M;F5A8VGS;B!V97)T:6-A;`!-87)G96X@=F5R=&EC86P`5F5R=&EC86PZ`$UU
M>2!A;'1A`%9I971N86T`5FEE=&YA;6ET82`H5DE30TE)*0!697(@)7,`5F5R
M('5N82!PX6=I;F$@=V5B(&5X=&5R;F$`5F5R(&-O;6\@)7,`27-L87,@5NUR
M9V5N97,L($)R:73A;FEC87,`27-L87,@5NUR9V5N97,L(%4N4RX`5FES:6)I
M;&ED860`5FES:6)I;&ED860Z(`!6;V1A9F]N92!D92!)=&%L:6$@;65D:6%N
M=&4@4TU44`!!5DE33P"AH:%!1%9%4E1%3D-)02$A(2!%3$E-24Y%($U!3E5!
M3$U%3E1%($5,($=52=-.($1%("5S+@!724X@<&]R($A45%``5V%L;&ES('D@
M1G5T=6YA`$%D=F5R=&5N8VEA`$UI90!0<F5V:7-I\VX@9&5L('1I96UP;P!$
M871O<R!D96P@=&EE;7!O('-U;6EN:7-T<F%D;W,@<&]R`%=E871H97(N8V]M
M`%=E8@!3961E(%=E8@!396UA;F%L;65N=&4`0FEE;G9E;FED;P!":65N=F5N
M:61O<R!A("5S`$)I96YV96YI9&\L("5S`$]E<W1E("A)4T\M.#@U.2TQ*0!/
M97-T92`H25-/+3@X-3DM,34I`%/A:&%R82!/8V-I9&5N=&%L`+]1=>D@87!L
M:6-A8VGS;B!D96)E<NUA(&UO<W1R87(@)7,@86P@:6YI8VEA<B!L82!S97-I
M\VX_`+]#=>%L(&5S(&5L(&-A<N%C=&5R(&1E;&EM:71A9&]R/P"_0W7A;"!E
M<R!E;"!C87+A8W1E<B!D92!C:71A9&\_`$UA<&$@9&4@;&]C86QI>F%C:?-N
M(&1E($%U<W1R86QI80!1=>D@9F%S97,`4&QU9VEN<R!H86)I;&ET861O<R!D
M96P@961I=&]R(&1E('1E>'1O(&5N<FEQ=65C:61O+@!!;F-H=7)A`$%N8VAU
M<F$@96X@=6YI9&%D97,@0U-3`$%N8VAU<F$@9&5L(&UE;OH@)7,@:7IQ=6EE
M<F1O("AD:7-P;VYI8FQE(&5N(&QA('!R\WAI;6$@<V5S:?-N*3H`06YC:'5R
M82!D92!L82!T86)L80!5;FED861E<R!D92!A;F-H=7)A`$%N8VAU<F$Z`%=I
M:VD`5FEE;G1O`%9I96YT;R!M871U=&EN80!696QO8VED860@9&5L('9I96YT
M;R!E;B!N=61O<P!6:65N=&\Z`%9I96YT;SH@`%-A8FED=7+M80!$97-E;W,`
M16UP;&5O`$1I<F5C8VGS;B!D96P@=')A8F%J;P!496SI9F]N;R!D96P@=')A
M8F%J;P!.^FUE<F\@97)R\VYE;R!D92!C86UP;W,@96X@;&$@;.UN96$@)60N
M(%-E(&5S<&5R86)A;B`E9"!Y(&AA>2`E9"X`3OIM97)O(&5R<O-N96\@9&4@
M8V%M<&]S+B!392!E<W!E<F%B86X@)60@>2!H87D@)60N`$]F9G-E="`E9"!E
M<G+S;F5O(&%L(&QE97(@=6X@87)C:&EV;R!61E,N`%@M4F5F`$QI;6ET86-I
M;VYE<R!BX7-I8V%S(%@U,#EV,P!5<V\@9&4@8VQA=F4@97AT96YD:61A(%@U
M,#EV,P!.;VUB<F4@86QT97)N871I=F\@9&4@87-U;G1O(%@U,#EV,P!)9&5N
M=&EF:6-A9&]R(&1E(&-L879E(&1E(&%S=6YT;R!8-3`Y=C,`17AT96YS:6]N
M97,@6#4P.78S`$%!`$%!04$`H4UA<&$@9&4@66%H;V\A`$%N=6%L;65N=&4`
M665M96X`4^T`4^TL(&QO(&%C97!T;P!%<W3A(&5N($U/1$\@5$585$\N(%5T
M:6QI8V4@96P@8F]T\VX@6SP^72!P87)A(')E9W)E<V%R(&%L(&UO9&\@5UE3
M25=91RX`3F\@9&ES<&]N92!D92!P<FEV:6QE9VEO<R!P87)A(&-R96%R(&WA
M<R!D92`E9"!B;&]Q=65S+@!.;R!E<W3A(&%U=&5N=&EF:6-A9&\N`$YO('!U
M961E(&EN8VQU:7(@96P@8V%RX6-T97(@(EPB(&5N(&5L(&YO;6)R92!C;VUP
M;&5T;RX`3F\@:6YT<F]D=6IO('5N82!D:7)E8V-I\VX@9&4@8V]R<F5O(';A
M;&ED82X`3F\@87-O8VGS(&YI;F=U;F\@9&4@;&]S(&-A;7!O<R!D96P@87)C
M:&EV;R!I;7!O<G1A9&\@82!L;W,@8V%M<&]S(&-O<G)E<W!O;F1I96YT97,@
M9&4@)7,N`$AA('-A;&ED;R!D92!L82!S97-I\VXN`%1I96YE('%U92!I;G1R
M;V1U8VER('5N(&[Z;65R;R!D92!T96SI9F]N;R!M\W9I;"!VX6QI9&\L('/S
M;&\@9.UG:71O<R!C;VX@=6X@)RLG(&]P8VEO;F%L('!A<F$@96P@<')E9FEJ
M;R!D92!L;&%M861A(&EN=&5R;F%C:6]N86PN`%1I96YE('%U92!I;G1R;V1U
M8VER('5N('9A;&]R(';A;&ED;RX`4&%R82!U<V%R($%L=&%S('1I96YE('%U
M92!C;VYF:6=U<F%R('5N(&UO=&]R(&1E($1A=&%4<F5E+@!4:65N92!Q=64@
M8V]N9FEG=7)A<B!U;B!M;W1O<B!61E,N`$1E8F4@9&5S8W)I8FER(&5L('!R
M;V)L96UA(&%N=&5S(&1E(&5N=FEA<B!E;"!I;F9O<FUE+@!4:65N92!Q=64@
M:6YT<F]D=6-I<B!L82!54DP@82!L82!Q=64@87!U;G1A(&5S=&4@=NUN8W5L
M;P!4:65N92!Q=64@<V5L96-C:6]N87(@=6X@<V5R=FED;W(@82!E;&EM:6YA
M<BX`5&EE;F4@<75E(&5S<&5C:69I8V%R('5N('5S=6%R:6\@82!E;&EM:6YA
M<BX`5&EE;F4@<75E(&5S<&5C:69I8V%R('5N('5S=6%R:6\@82!E;&EM:6YA
M<BX`5&EE;F4@<75E(&5S<&5C:69I8V%R(&5L('5S=6%R:6\@82!A\6%D:7(N
M`%1I96YE('%U92!E<W!E8VEF:6-A<B!E;"!U<W5A<FEO(&$@86-T=6%L:7IA
M<BX`5&EE;F4@<75E(&5S<&5C:69I8V%R('%UZ2!A8V-I\VX@<V4@96IE8W5T
M87+A+@!4:65N92!Q=64@:6YT<F]D=6-I<B!U;B!N=65V;R!N;VUB<F4@9&4@
M8V%T96=O<NUA+@!4:65N92!Q=64@:6YT<F]D=6-I<B!U;B!N^FUE<F\@9&4@
M=&5LZ69O;F\@:71A;&EA;F\`2&$@97AP:7)A9&\@<W4@<V5S:?-N("5S+B!6
M=65L=F$@82!I;FEC:6%R('-E<VGS;BX`4W4@9&ER96-C:?-N(&1E(&-O<G)E
M;P!$:7)E8V-I\VX@1&4Z`%-U(&EN9F]R;6%C:?-N`$AA(&-A;6)I861O('-U
M(&1I<F5C8VGS;B!D92!);G1E<FYE="!D97-D92!E;"!C;VUI96YZ;R!D92!S
M=2!S97-I\VX@)7,N(%!O<B!R87IO;F5S(&1E('-E9W5R:61A9"!T:65N92!Q
M=64@=F]L=F5R(&$@:6YI8VEA<B!L82!S97-I\VXN`%-U(&YO;6)R90!3=2!M
M;W1O<B!D92!A=71E;G1I9FEC86-I\VX@;F\@<&5R;6ET92!A\6%D:7(@=7-U
M87)I;W,N(%-I('%U:7-I97)A('5S87(@2&]R9&4@<&%R82!A9&UI;FES=')A
M<B!C=65N=&%S(&1E('5S=6%R:6\L('1E;F1RX2!Q=64@=71I;&EZ87(@=6X@
M;6]T;W(@9&4@875T96YT:69I8V%C:?-N(&1I<W1I;G1O+@!3=2!M;W1O<B!D
M92!A=71E;G1I9FEC86-I\VX@;F\@<&5R;6ET92!L:7-T87(@=7-U87)I;W,L
M(&\@<V4@:&$@9&5S:&%B:6QI=&%D;R!L82!C87)A8W1E<NUS=&EC82!P;W(@
M86QG^FX@;6]T:79O+@!087)E8V4@<75E(&AA(&-A;6)I861O('-U(&YA=F5G
M861O<B!D97-D92!E;"!C;VUI96YZ;R!D92!S=2!S97-I\VX@)7,N(%!O<B!R
M87IO;F5S(&1E('-E9W5R:61A9"!T:65N92!Q=64@=F]L=F5R(&$@:6YI8VEA
M<B!L82!S97-I\VXN`%-U(&YA=F5G861O<B!N;R!A9&UI=&4@97-T82!C87)A
M8W1E<NUS=&EC82X`16P@;F%V96=A9&]R(&YO(&%D;6ET92!E<W1A(&]P8VGS
M;B!D92!I;7!R97-I\VXN(%!R97-I;VYE($-O;G1R;VPO0V]M86YD;R`K(%`@
M<&%R82!I;7!R:6UI<BX`6F]N82!H;W)A<FEA(&%C='5A;#H`4V4@:&$@8V%M
M8FEA9&\@<W4@:61E;G1I9&%D('!O<B!O;6ES:?-N+@!)9&5N=&ED860@<&]R
M(&]M:7-I\VXZ`$YO;6)R92!C;VUP;&5T;SH`4V4@:&$@86=O=&%D;R!S=2!T
M:65M<&\@9&4@8V]N97AI\VXN`$QA(&YU979A(&-O;G1R87-E\6$@<&%R82`E
M<R!E<SH@)7,`4V4@:&%N(&%C='5A;&EZ861O('-U<R!O<&-I;VYE<R!S\VQO
M('!O<B!L82!D=7)A8VGS;B!D92!L82!S97-I\VXN`%-E(&AA;B!A8W1U86QI
M>F%D;R!S=7,@;W!C:6]N97,N`%-E(&AA(')E86IU<W1A9&\@<W4@8V]N=')A
M<V7Q80!392!H82!R96%J=7-T861O('-U(&-O;G1R87-E\6$L(&-O;7!R=65B
M92!E;"!C;W)R96\@92!I;FEC:64@<V5S:?-N(&-O;B!S=2!N=65V82!C;VYT
M<F%S9?%A+@!,82!C;VYT<F%S9?%A(&AA(&5X<&ER861O+@!397)V:61O<F5S
M(')E;6]T;W,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II
M<'!Y`%M/8W5L=&%R('1E>'1O(&-I=&%D;UT`6TEN9F]R;64@9&4@<')O8FQE
M;6%=`%M-;W-T<F%R('1E>'1O(&-I=&%D;R`M`%M-;W-T<F%R('1E>'1O(&-I
M=&%D;R`M("5S(&SM;F5A<UT`6VSM;F5A("5S(&1E("5S70!?061M:6YI<W1R
M86-I\VX`7T-,20#!<E]B;VP@9&%T;W,`15]L:6UI;F%R(&9I;&$`7T=R=7!O
M<P!!7WEU9&$`4')O<&EE9&%D97,@9&4@7VEM86=E;BXN+@!?26YI8VEA<B!S
M97-I\VX`7U-A;&ER`$UO9&EF:6-A<B!?=NUN8W5L;RXN+@!?3W!C:6]N97,`
M7U!R:79I;&5G:6]S`%]%;&EM:6YA<B!V[6YC=6QO+BXN`$-O;E]F:6=U<F%C
M+@!0<F]P:65D861E<R!D92!?=&%B;&$N+BX`7U5S=6%R:6]S`&1I<F5C8VEO
M;F5S`&1E<W1I;F%T87)I;R!D97-C;VYO8VED;P!A9V5N9&$`8V%L;6$`;F\@
M<V4@<'5E9&4@8W)E87(@96P@87)C:&EV;R!D92!D97-T:6YO`&YO('-E('!U
M961E(&%B<FER(&5L(&]R:6=E;@!P=6QS92!A<77M`&5R<F]R(&1E(&SM;F5A
M(&1E(&-O;6%N9&\`97)R;W(@9&4@8V]N9FEG=7)A8VGS;@!F86QT82!U;B!A
M<F-H:79O(&-R[71I8V\@9&5L('-I<W1E;6$`97)R;W(@9&4@9F]R;6%T;R!D
M92!D871O<P!M;V1I9FEC87(`96YT<F%D82!N;R!E;F-O;G1R861A`&1E<V-E
M;G-O`&%R8VAI=F\`9&5L("5S("@E<RD@82!L87,@)7,@)7,`=F5N=&]S;P!H
M.@!H:`!N;VUB<F4@9&4@86YF:71R:?-N(&1E<V-O;F]C:61O`&EN;65D:6%T
M86UE;G1E`&5N(&SM;F5A`&5R<F]R(&1E(&5N=')A9&$O<V%L:61A`&5R<F]R
M(&1E('-O9G1W87)E(&EN=&5R;F\`;.UN96%S70!C\V1I9V\@9&4@97)R;W(@
M;6MI<V]F<R`E9"!A;"!R96%L:7IA<B!)4T\N`&UM`&YO;6)R90!S:6X@9&5S
M87)R;VQL87(`8?IN(&YO('-E(&AA(&1E<V%R<F]L;&%D;P!N;W1A<P!P;W)C
M96YT86IE`'!R:79I;&5G:6\@9&5N96=A9&\`<.UX96QE<P!E<G)O<B!R96UO
M=&\@9&4@<')O=&]C;VQO`&5N(&%U;65N=&\`<V5R=FEC:6\@;F\@9&ES<&]N
M:6)L92X`;6]S=')A<B!D:69E<F5N8VEA<P!S;7,R96UA:6P@<&]R($A45%``
M<W,`97-T86)L90!E<G)O<B!D96P@<VES=&5M80!T87)E87,`9F%L;&\@=&5M
M<&]R86P`97-C<FEB82!D;W,@=F5C97,@;&$@8V]N=')A<V7Q82!P87)A(&-O
M;F9I<FUA<FQA`'5N:69I8V%D;P!S:6X@;F]M8G)E`'5S=6%R:6\@<V5L96-C
M:6]N861O`'9#87)D`'<Z`'=E871H97(N8V]M````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&]C86QE+V5T7T5%+P``````````````````````````````````````````
M```````````````````````````````````````P,#`P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U,P`P,C`P-S8`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L;V-A;&4O971?144O:&5L<"YX;6P`````````
M````````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,S(P`#$P-3$U-#,S
M-S4S`#`R,34T-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z(&AO
M<F1E+VQO8V%L92]E=%]%12]H96QP+GAM;"QV(#$N,B`R,#`T+S`U+S(W(#(P
M.C(R.C$U(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)S=6UM
M87)Y(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!0;W)T86P@4&%G93PO=&ET
M;&4^"B`\<&%R83X*("!4:&ES('!O<G1A;"!P86=E('!R;W9I9&5S(&$@<75I
M8VL@<W5M;6%R>2!O9B!A;&P@>6]U<B!I;7!O<G1A;G0*("!I;F9O<FUA=&EO
M;BX@1F]R(&5X86UP;&4L(&ET(&UI9VAT('-H;W<@:&]W(&UA;GD@;F5W(&4M
M;6%I;"!M97-S86=E<R!Y;W4*("!H879E(&EN('EO=7(@24Y"3U@L('5P8V]M
M:6YG(&5V96YT<R!O;B!Y;W5R(&-A;&5N9&%R+"!T87-K<R!O;B!Y;W5R('1O
M+61O"B`@;&ES="P@:&5A9&QI;F5S(&9R;VT@<V5L96-T960@;F5W<R!S97)V
M:6-E<RP@86YD('-O(&]N+B`@36%N>2!O9B!T:&5S90H@('-U;6UA<FEE<R!W
M:6QL(&-O;G1A:6X@<75I8VL@<VAO<G1C=71S('1O(&-O;6UO;B!F=6YC=&EO
M;G,L('-U8V@@87,*("!C;VUP;W-I;F<@82!N97<@;6%I;"!M97-S86=E+"!C
M<F5A=&EN9R!A(&YE=R!C86QE;F1A<B!E=F5N="!O<B!T87-K+"!E=&,N"B`\
M+W!A<F$^"B`\<&%R83X*("!4:&4@8V]N=&5N=',@;V8@=&AI<R!P;W)T86P@
M<&%G92!A<F4@8W5S=&]M:7IA8FQE('9I82!T:&4@3&%Y;W5T(&)U='1O;BX*
M("!&;W(@97AA;7!L92P@>6]U(&-A;B!C:&]O<V4@=VAI8V@@:71E;7,@=&\@
M:6YC;'5D92!O;B!T:&ES('!O<G1A;"!P86=E(&%S"B`@=V5L;"!A<R!I;B!W
M:&EC:"!O<F1E<B!T:&5Y(&%R92!S:&]W;BX*(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](FYA=F)A<B(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@
M07!P;&EC871I;VX@3F%V:6=A=&EO;B!"87(\+W1I=&QE/@H@/'!A<F$^"B`@
M070@=&AE(&QE9G0@:&%N9"!S:61E(&]F('1H92!W96(@<&%G92!I<R!T:&4@
M87!P;&EC871I;VX@;F%V:6=A=&EO;B!B87(N"B`@0VQI8VL@;VX@=&AE(&EC
M;VYS(&]N('1H:7,@;F%V:6=A=&EO;B!B87(@=&\@<75I8VML>2!A;F0@96%S
M:6QY('-W:71C:`H@(&)E='=E96X@=&AE(&%V86EL86)L92!A<'!L:6-A=&EO
M;G,N"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD;U]M
M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC
M97,Z($UA:6YT96YA;F-E.B!$;R!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\
M<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O('!E<F9O<FT@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;BP@8VAE8VL@=&AI<R!B;W@N"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC;VYF:7)M
M7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E
M;F-E<SH@36%I;G1E;F%N8V4Z($-O;F9I<FT@36%I;G1E;F%N8V4\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!C;VYF:7)M
M(&%L;"!M86EN=&5N86YC92!T87-K<R!B969O<F4@=&AE>2!A<F4@<G5N+"!C
M:&5C:R!T:&ES(&)O>"X@268@;&5F="!U;F-H96-K960L(&%L;"!M86EN=&5N
M86YC92!O<&5R871I;VYS('1H870@;F5E9"!T;R!B92!R=6X@=VEL;"!B92!P
M97)F;W)M960@875T;VUA=&EC86QL>2!W:71H(&YO(&-H86YC92!T;R!C86YC
M96P@;VX@;&]G:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&]C86QE+V5T7T5%+TQ#7TU%4U-!1T53+P``````````
M```````````````````````````````````````````````````````P,#`P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U,P`P
M,C$V-C,`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O971?144O3$-?
M34534T%'15,O:&]R9&4N;6\`````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-#`R
M,C,R`#$P-3$U-#,S-S4S`#`R,S,R-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#>$@25`````(\'```<````E#P``!\*```,
M>0```````(BA```.````B:$```\```"8H0``#0```*BA```(````MJ$```L`
M``"_H0``#````,NA```$````V*$``!@```#=H0``&P```/:A```M````$J(`
M`!T```!`H@``)````%ZB```I````@Z(``!D```"MH@``)@```,>B```,````
M[J(``"0```#[H@``#P```""C```+````,*,```X````\HP``!0```$NC```H
M````4:,```@```!ZHP``"@```(.C```5````CJ,``!(```"DHP``"P```+>C
M``"%````PZ,```X```!)I```"@```%BD```-````8Z0```X```!QI```$0``
M`("D```-````DJ0```P```"@I```#0```*VD```&````NZ0``)0```#"I```
M"@```%>E```/````8J4``!@```!RI0``#````(NE```.````F*4```X```"G
MI0``"````+:E```)````OZ4``"X```#)I0``&@```/BE```R````$Z8``#@`
M``!&I@``5````'^F``!1````U*8``%H````FIP``5P```(&G```T````V:<`
M``D````.J```#0```!BH```'````)J@```H````NJ```#P```#FH```%````
M2:@```8```!/J```$0```%:H```(````:*@```D```!QJ```"0```'NH```E
M````A:@``"````"KJ```$P```,RH```0````X*@```\```#QJ```"@````&I
M```#````#*D```\````0J0``%````""I```)````-:D```T````_J0``$@``
M`$VI```9````8*D``!X```!ZJ0``#P```)FI```*````J:D```\```"TJ0``
M"````,2I```D````S:D``!0```#RJ0``%@````>J```(````'JH``$X````G
MJ@``+0```':J```9````I*H```<```"^J@``#````,:J```L````TZH```X`
M````JP```P````^K```+````$ZL```<````?JP``!P```">K```%````+ZL`
M``4````UJP``"@```#NK```#````1JL``!<```!*JP``"@```&*K```/````
M;:L```X```!]JP``&````(RK```C````I:L```X```#)JP``%````-BK```7
M````[:L``!<````%K```%P```!VL```3````-:P```\```!)K```#@```%FL
M```?````:*P``!T```"(K```!P```*:L```&````KJP```@```"UK```#P``
M`+ZL```&````SJP```H```#5K```$P```."L```+````]*P``!``````K0``
M%0```!&M```5````)ZT```<````]K0``$````$6M```%````5JT``!4```!<
MK0``$0```'*M```,````A*T``#L```"1K0``.````,VM```)````!JX```<`
M```0K@``%````!BN```#````+:X```4````QK@``$````#>N```)````2*X`
M`!,```!2K@``.0```&:N```2````H*X``"<```"SK@``+````-NN```J````
M"*\``"4````SKP``"@```%FO```&````9*\```D```!KKP``!P```'6O```O
M````?:\``#<```"MKP``+@```.6O``!5````%+```"T```!JL```+0```)BP
M```]````QK```#\````$L0``+0```$2Q``!`````<K$``",```"SL0``(P``
M`->Q``!`````^[$``"T````\L@``,P```&JR```5````GK(``!D```"TL@``
M*0```,ZR```D````^+(``"@````=LP``$0```$:S```*````6+,```P```!C
MLP``"@```'"S```0````>[,``!8```",LP``%@```*.S```'````NK,```<`
M``#"LP``%````,JS```*````W[,```@```#JLP``)P```/.S```(````&[0`
M``<````DM```!P```"RT```&````-+0```4````[M```!P```$&T```&````
M2;0```@```!0M```*0```%FT```.````@[0```H```"2M```!````)VT```'
M````HK0```D```"JM```!@```+2T```1````N[0```<```#-M```%@```-6T
M```$````[+0```@```#QM```!@```/JT```-`````;4```8````/M0``'@``
M`!:U```1````-;4```@```!'M0``#0```%"U```,````7K4```<```!KM0``
M`P```'.U```#````=[4``!<```![M0``$P```).U```=````I[4```@```#%
MM0``!````,ZU```(````T[4```@```#<M0``00```.6U```:````)[8``"L`
M``!"M@``(````&ZV```5````C[8```8```"EM@``!@```*RV```5````L[8`
M`!@```#)M@``(@```.*V```N````!;<``!T````TMP``(0```%*W``!4````
M=+<``"D```#)MP``"@```/.W```'````_K<```<````&N```%0````ZX```.
M````)+@```H````SN```#P```#ZX```-````3K@```\```!<N```#0```&RX
M```)````>K@``!0```"$N```!@```)FX```8````H+@``!T```"YN```$P``
M`->X```1````Z[@``!0```#]N```!````!*Y```&````%[D``!0````>N0``
M5````#.Y``!D````B+D```0```#MN0``#@```/*Y```%`````;H```4````'
MN@``&P````VZ```:````*;H``!,```!$N@``$0```%BZ```1````:KH``!P`
M``!\N@``*@```)FZ```0````Q+H``"$```#5N@``!0```/>Z```3````_;H`
M``L````1NP``$@```!V[```*````,+L```\````[NP``#0```$N[```1````
M6;L``!,```!KNP``#````'^[```&````C+L```P```"3NP``!@```*"[```7
M````I[L``!````"_NP``$0```-"[```(````XKL```4```#KNP``#````/&[
M```0````_KL```4````/O```#0```!6\```&````([P```<````JO```#0``
M`#*\```'````0+P```L```!(O```!P```%2\```'````7+P```D```!DO```
M"0```&Z\```*````>+P``!D```"#O```/0```)V\```=````V[P```P```#Y
MO```$`````:]```%````%[T``"4````=O0``$@```$.]```3````5KT``"L`
M``!JO0``.P```):]```@````TKT```@```#SO0``-@```/R]```0````,[X`
M``@```!$O@``#````$V^```&````6KX```0```!AO@``#P```&:^```.````
M=KX```<```"%O@``"@```(V^```-````F+X``!X```"FO@``&P```,6^```A
M````X;X``!X````#OP``&0```"*_```>````/+\``!T```!;OP``&P```'F_
M```A````E;\``"X```"WOP``)@```.:_```;````#<```!X````IP```'```
M`$C````F````9<```"L```",P```,P```+C````F````[,```"L````3P0``
M.````#_!```=````>,$``!4```"6P0``+P```*S!```@````W,$``!(```#]
MP0``*0```!#"```>````.L(``"````!9P@``$@```'K"``"B````C<(``!8`
M```PPP``(P```$?#```H````:\,``"D```"4PP``*````+[#```?````Y\,`
M`!4````'Q```(````!W$```E````/L0``"@```!DQ```+0```(W$```P````
MN\0``)(```#LQ```(0```'_%```6````H<4``!P```"XQ0``)@```-7%```J
M````_,4``$$````GQ@``1````&G&```,````KL8```<```"[Q@``!P```,/&
M```&````R\8```T```#2Q@``$````.#&```2````\<8``!,````$QP``$@``
M`!C'```'````*\<```0````SQP``$````#C'```0````2<<```P```!:QP``
M#@```&?'```-````=L<```\```"$QP``$P```)3'```-````J,<``"@```"V
MQP```P```-_'```-````X\<```8```#QQP``$0```/C'```7````"L@``!L`
M```BR```#@```#[(```"````3<@``$D```!0R```!0```)K(```0````H,@`
M``\```"QR```!````,'(```-````QL@```X```#4R````P```./(```.````
MY\@```@```#VR```#P```/_(```/````#\D```<````?R0``#0```"?)```0
M````-<D```T```!&R0``"P```%3)```&````8,D```L```!GR0``#````'/)
M```*````@,D``!$```"+R0``&0```)W)```+````M\D```T```##R0``(@``
M`-')```/````],D``!L````$R@``-````"#*```*````5<H``!@```!@R@``
M&0```'G*```6````D\H``"(```"JR@``#0```,W*```'````V\H``!0```#C
MR@``"P```/C*```B````!,L``"\````GRP``"P```%?+```)````8\L``!D`
M``!MRP``"P```(?+```7````D\L``!<```"KRP``"0```,/+```6````S<L`
M``\```#DRP``&0```/3+```6````#LP```X````ES```&````#3,```(````
M3<P```T```!6S```)@```&3,``!#````B\P```@```#/S```$@```-C,```?
M````Z\P```@````+S0``"P```!3-```O````(,T```X```!0S0``!0```%_-
M```&````9<T``$4```!LS0```P```++-```'````MLT```0```"^S0``"@``
M`,/-```*````SLT```\```#9S0``$````.G-```7````^LT``!$````2S@``
M&0```"3.```7````/LX```D```!6S@``!0```&#.```]````9LX```L```"D
MS@``"@```+#.```"````N\X```4```"^S@``#0```,3.```;````TLX``!<`
M``#NS@``%`````;/```)````&\\```X````ESP``#0```#3/```2````0L\`
M`#@```!5SP``(````([/```(````K\\```X```"XSP``>P```,?/```8````
M0]```!@```!<T```$0```'70```'````A]````4```"/T```&````)70```>
M````KM```!L```#-T```&0```.G0```;`````]$``!D````?T0``$P```#G1
M```'````3=$```@```!5T0``!@```%[1```&````9=$``!````!LT0``#P``
M`'W1```0````C=$```\```">T0``"P```*[1```/````NM$```P```#*T0``
M#P```-?1```'````Y]$```8```#OT0``#@```/;1```,````!=(``"@````2
MT@``#P```#O2```(````2](```@```!4T@``$P```%W2```>````<=(``"$`
M``"0T@``(````++2```9````T](``!<```#MT@``)0````73```7````*],`
M`!8```!#TP``!````%K3```;````7],```T```![TP``#````(G3```#````
MEM,```4```":TP``"````*#3```*````J=,```P```"TTP``"P```,'3```0
M````S=,```P```#>TP``#@```.O3```+````^M,```0````&U```!`````O4
M```3````$-0``!0````DU```#````#G4```)````1M0```X```!0U```"P``
M`%_4```;````:]0```<```"'U```!P```(_4```*````E]0```T```"BU```
M"0```+#4```$````NM0```4```"_U````P```,74```8````R=0```H```#B
MU```!````.W4```F````\M0```X````9U0``?````"C5```5````I=4```4`
M``"[U0``!P```,'5```,````R=4```@```#6U0``"@```-_5```&````ZM4`
M``@```#QU0```@```/K5```&````_=4```8````$U@``%`````O6```-````
M(-8``!`````NU@``&P```#_6```$````6]8```D```!@U@``$````&K6```)
M````>]8```D```"%U@``!0```(_6```:````E=8```@```"PU@``!@```+G6
M```9````P-8```X```#:U@``!P```.G6```'````\=8```4```#YU@``"0``
M`/_6```*````"=<```X````4UP```@```"/7```&````)M<```L````MUP``
M#0```#G7```)````1]<```8```!1UP``$@```%C7```)````:]<```<```!U
MUP``%````'W7```=````DM<``$(```"PUP``)0```//7```E````&=@```8`
M```_V```"@```$;8```$````4=@```D```!6V```"````&#8```1````:=@`
M``D```![V```!@```(78```-````C-@```8```":V```!````*'8```Y````
MIM@``#T```#@V```.@```![9```>````6=D```4```!XV0``#@```'[9```$
M````C=D```8```"2V0``!P```)G9```A````H=D```T```##V0``%0```-'9
M```&````Y]D```0```#NV0``$0```//9```&````!=H```H````,V@``(@``
M`!?:```$````.MH```4````_V@``'0```$7:```$````8]H```P```!HV@``
M#@```'7:```*````A-H```@```"/V@``"0```)C:```%````HMH``#H```"H
MV@``,````./:```U````%-L``"D```!*VP``1P```'3;```X````O-L``"D`
M``#UVP``/P```!_<```N````7]P``"T```".W```'P```+S<```/````W-P`
M`!(```#LW```"P```/_<```F````"]T``"D````RW0``)````%S=```F````
M@=T```@```"HW0``"@```+'=```)````O-T```<```#&W0``(````,[=```@
M````[]T``"8````0W@``"@```#?>```9````0MX``"D```!<W@``%@```(;>
M```2````G=X```<```"PW@``"@```+C>```,````P]X```\```#0W@``$```
M`.#>``!`````\=X``'`````RWP``9@```*/?```.````"N````D````9X```
M"@```"/@```2````+N```!,```!!X```#````%7@```&````8N````\```!I
MX```$@```'G@```0````C.```!$```"=X```'````*_@```C````S.```&H`
M``#PX```#P```%OA```%````:^$``!````!QX0``"0```(+A```$````C.$`
M``L```"1X0``(````)WA```4````ON$```P```#3X0``#````.#A```/````
M[>$``!4```#]X0``*0```!/B```J````/>(``"8```!HX@``)P```(_B```I
M````M^(``"H```#AX@``&0````SC``!"````)N,``!$```!IXP``$@```'OC
M```3````CN,``!0```"BXP``#P```+?C```6````Q^,``!<```#>XP``$```
M`/;C```1````!^0``#0````9Y```$P```$[D```2````8N0``#4```!UY```
M%````*OD```'````P.0```P```#(Y```(````-7D```0````]N0``!0````'
MY0``$0```!SE```7````+N4``!P```!&Y0``$P```&/E```4````=^4``!H`
M``",Y0``$0```*?E```:````N>4``!X```#4Y0``&@```//E```3````#N8`
M`!4````BY@``$0```#CF```7````2N8``!0```!BY@``%P```'?F```5````
MC^8```D```"EY@``$````*_F```9````P.8```0```#:Y@``!P```-_F```+
M````Y^8``!$```#SY@``!@````7G```&````#.<```8````3YP``!0```!KG
M```'````(.<```<````HYP``!0```##G```6````-N<``%L```!-YP``!@``
M`*GG```&````L.<```0```"WYP``!````+SG```'````P><```X```#)YP``
M#````-CG```,````Y><```T```#RYP``"@````#H```.````"^@```4````:
MZ```*````"#H```.````2>@```P```!8Z```#P```&7H```*````=>@```@`
M``"`Z```"0```(GH```K````D^@```0```"_Z```"````,3H```F````S>@`
M`!(```#TZ```#P````?I```&````%^D```H````>Z0``!P```"GI```(````
M,>D``"`````ZZ0``"0```%OI```4````9>D```P```!ZZ0``#0```(?I```.
M````E>D``!8```"DZ0``$0```+OI```&````S>D```,```#4Z0``!@```-CI
M```9````W^D```<```#YZ0``!`````'J```+````!NH```L````2Z@``!P``
M`![J```%````)NH```<````LZ@``%@```#3J```-````2^H```T```!9Z@``
M"@```&?J```0````<NH```\```"#Z@``$0```)/J```7````I>H```H```"]
MZ@``$0```,CJ```(````VNH```0```#CZ@``#P```.CJ```Z````^.H```4`
M```SZP``#````#GK```>````1NL```X```!EZP``$````'3K```+````A>L`
M``P```"1ZP``"0```)[K```'````J.L```H```"PZP``"0```+OK```.````
MQ>L``!````#4ZP``&P```.7K```8`````>P``!H````:[```"@```#7L```)
M````0.P```H```!*[```#````%7L```/````8NP```@```!R[```!@```'OL
M```<````@NP```<```"?[```!0```*?L```+````K>P``$<```"Y[```#0``
M``'M```)````#^T```0````9[0```P```![M```3````(NT``!,````V[0``
M$P```$KM```*````7NT```(```!I[0``!````&SM```E````<>T```,```"7
M[0``!0```)OM```J````H>T```H```#,[0``!0```-?M```$````W>T```H`
M``#B[0``#0```.WM```&````^^T```@````"[@``"`````ON```$````%.X`
M``4````9[@``:````!_N```)````B.X```P```"2[@``$````)_N```%````
ML.X```8```"V[@``&P```+WN```O````V>X``!`````)[P``"@```!KO```/
M````)>\```H````U[P``"0```$#O```3````2N\``!L```!>[P``&````'KO
M```7````D^\``!\```"K[P``#@```,OO```#````VN\```<```#>[P``"```
M`.;O```'````[^\```H```#W[P``"P````+P```'````#O```%$````6\```
M$````&CP```,````>?````T```"&\```&@```)3P``!*````K_```!D```#Z
M\```!@```!3Q```:````&_$``"4````V\0``!@```%SQ```&````8_$``!\`
M``!J\0``!@```(KQ```)````D?$``!@```";\0``%P```+3Q```H````S/$`
M``8```#U\0``#0```/SQ```B````"O(``%<````M\@``$P```(7R```C````
MF?(``!,```"]\@```@```-'R```+````U/(```@```#@\@``#0```.GR```*
M````]_(```<````"\P``%`````KS```&````'_,```@````F\P``#@```"_S
M```'````/O,```H```!&\P``"P```%'S```R````7?,```<```"0\P``#```
M`)CS```-````I?,``!<```"S\P``#````,OS```)````V/,```D```#B\P``
M"@```.SS```'````]_,```D```#_\P``!P````GT```*````$?0``!L````<
M]```#P```#CT```2````2/0```H```!;]```%@```&;T```)````??0``!``
M``"']```!P```)CT```2````H/0```0```"S]```!P```+CT```%````P/0`
M``4```#&]```"P```,ST```4````V/0``!$```#M]```&@```/_T```6````
M&O4``!0````Q]0``%P```$;U```8````7O4``!P```!W]0``&0```)3U```'
M````KO4```4```"V]0``#0```+SU```,````RO4``!$```#7]0``"````.GU
M```7````\O4```L````*]@``#````!;V```?````(_8``!H```!#]@``$P``
M`%[V```$````<O8```H```!W]@``!````(+V```-````A_8```P```"5]@``
M!0```*+V```)````J/8```4```"R]@``!P```+CV```%````P/8```0```#&
M]@```@```,OV```X````SO8``"P````']P``$@```#3W```I````1_<``#(`
M``!Q]P``"@```*3W```L````K_<``"X```#<]P``,P````OX```S````/_@`
M`#@```!S^```#P```*SX```8````O/@``!````#5^```#P```.;X```3````
M]O@``!4````*^0``%````"#Y```2````-?D``!0```!(^0``%0```%WY```M
M````<_D``"T```"A^0``,0```,_Y```N`````?H``"\````P^@``+````&#Z
M``!B````C?H``!,```#P^@``#0````3[```(````$OL``!<````;^P``"```
M`#/[```,````//L``"L```!)^P``(0```'7[```:````E_L```D```"R^P``
M10```+S[``!!`````OP```0```!$_```$P```$G\```4````7?P```X```!R
M_```$P```('\```8````E?P```8```"N_```"0```+7\```*````O_P```\`
M``#*_```$````-K\```'````Z_P```X```#S_```!0````+]```;````"/T`
M``@````D_0``!@```"W]```4````-/T``!$```!)_0``#@```%O]```X````
M:OT```(```"C_0``!@```*;]```.````K?T```4```"\_0``!P```,+]```.
M````ROT```8```#9_0``*````.#]```,````"?X``!P````6_@``!````#/^
M```I````./X``!<```!B_@``'P```'K^``!<````FOX``!0```#W_@``/@``
M``S_```?````2_\``!````!K_P``!P```'S_```.````A/\```P```"3_P``
M#````*#_```3````K?\```H```#!_P``'0```,S_```9````ZO\```4````$
M``$`$0````H``0`1````'``!`"0````N``$`$@```%,``0`5````9@`!`!(`
M``!\``$`#@```(\``0`9````G@`!``@```"X``$`"0```,$``0`-````RP`!
M``<```#9``$`"@```.$``0`'````[``!``\```#T``$`!@````0!`0`+````
M"P$!`!H````7`0$`"@```#(!`0`'````/0$!``@```!%`0$`!0```$X!`0`?
M````5`$!``8```!T`0$`$````'L!`0`(````C`$!``T```"5`0$`"````*,!
M`0`>````K`$!`!(```#+`0$`+````-X!`0`:````"P(!``D````F`@$`"@``
M`#`"`0`5````.P(!``4```!1`@$`%````%<"`0`$````;`(!`!````!Q`@$`
M!@```(("`0`'````B0(!`!X```"1`@$`*````+`"`0`*````V0(!`!P```#D
M`@$`$0````$#`0`+````$P,!`!H````?`P$`%````#H#`0`$````3P,!``0`
M``!4`P$`"P```%D#`0`%````90,!``8```!K`P$`"````'(#`0`&````>P,!
M``H```""`P$`&P```(T#`0`T````J0,!`#0```#>`P$`(````!,$`0`I````
M-`0!`"````!>!`$`00```'\$`0`:````P00!`"@```#<!`$`*0````4%`0!0
M````+P4!`"(```"`!0$`!@```*,%`0`(````J@4!``4```"S!0$`"````+D%
M`0`9````P@4!`!D```#<!0$`*@```/8%`0`C````(08!`!D```!%!@$`+@``
M`%\&`0`T````C@8!``@```##!@$`%P```,P&`0`*````Y`8!``<```#O!@$`
M(0```/<&`0`0````&0<!``X````J!P$`"P```#D'`0`'````10<!`!,```!-
M!P$`"````&$'`0`+````:@<!``H```!V!P$`%````($'`0`/````E@<!`#(`
M``"F!P$`"P```-D'`0`.````Y0<!``4```#T!P$`!0```/H'`0`%``````@!
M`!<````&"`$`#P```!X(`0`$````+@@!``H````S"`$`"0```#X(`0`+````
M2`@!``T```!4"`$`#````&((`0`.````;P@!``4```!^"`$`!````(0(`0`-
M````B0@!`#(```"7"`$`10```,H(`0`7````$`D!``<````H"0$`'@```#`)
M`0`4````3PD!``4```!D"0$`%````&H)`0`&````?PD!``<```"&"0$`#@``
M`(X)`0`J````G0D!``8```#("0$`#````,\)`0`-````W`D!`!$```#J"0$`
M"P```/P)`0`V````"`H!``H````_"@$`(@```$H*`0`+````;0H!``\```!Y
M"@$`,@```(D*`0`E````O`H!`#````#B"@$`,0```!,+`0`M````10L!``X`
M``!S"P$`!0```((+`0`.````B`L!`!,```"7"P$`$@```*L+`0`'````O@L!
M`!$```#&"P$`$P```-@+`0`'````[`L!`!0```#T"P$`&`````D,`0`'````
M(@P!``4````J#`$`#````#`,`0`,````/0P!`!(```!*#`$`!````%T,`0`'
M````8@P!``H```!J#`$`"P```'4,`0`,````@0P!``X```".#`$`#@```)T,
M`0`%````K`P!``4```"R#`$`+@```+@,`0`F````YPP!`",````.#0$``P``
M`#(-`0`2````-@T!``8```!)#0$`'@```%`-`0`8````;PT!`"4```"(#0$`
M#0```*X-`0`)````O`T!`!\```#&#0$``P```.8-`0`'````Z@T!``H```#R
M#0$``@```/T-`0`,``````X!`!4````-#@$`"P```",.`0`9````+PX!`"``
M``!)#@$`$@```&H.`0`%````?0X!``H```"##@$`%0```(X.`0`2````I`X!
M``P```"W#@$`!````,0.`0`)````R0X!``<```#3#@$`#````-L.`0!2````
MZ`X!`!<````[#P$`)````%,/`0`2````>`\!``<```"+#P$`!@```),/`0`.
M````F@\!``P```"I#P$`#0```+8/`0`5````Q`\!`!(```#:#P$`#P```.T/
M`0`4````_0\!``H````2$`$`&P```!T0`0`0````.1`!``L```!*$`$`:0``
M`%80`0`:````P!`!`!<```#;$`$`)P```/,0`0`:````&Q$!`!<````V$0$`
M&P```$X1`0`9````:A$!`!\```"$$0$`$P```*01`0`(````N!$!``<```#!
M$0$`"````,D1`0`)````TA$!`!4```#<$0$`#0```/(1`0`C`````!(!``T`
M```D$@$`$P```#(2`0`(````1A(!``,```!/$@$`1@```%,2`0`_````FA(!
M`#<```#:$@$`5P```!(3`0`%````:A,!`!\```!P$P$`+P```)`3`0`*````
MP!,!``@```#+$P$`#0```-03`0`M````XA,!``0````0%`$`3P```!44`0`E
M````910!`!P```"+%`$`"P```*@4`0`?````M!0!`!T```#4%`$`)0```/(4
M`0`@````&!4!`"0````Y%0$`(````%X5`0`+````?Q4!``<```"+%0$`#0``
M`),5`0`,````H14!`!<```"N%0$`!@```,85`0`Y````S14!``P````'%@$`
M!P```!06`0`)````'!8!`!,````F%@$`"0```#H6`0`$````1!8!`!````!)
M%@$`"````%H6`0`(````8Q8!``0```!L%@$`"P```'$6`0`,````?18!`!(`
M``"*%@$`$0```)T6`0`,````KQ8!`!H```"\%@$`#P```-<6`0`'````YQ8!
M``T```#O%@$`%````/T6`0`.````$A<!``P````A%P$`&P```"X7`0`L````
M2A<!`!,```!W%P$`'````(L7`0`H````J!<!``8```#1%P$`!P```-@7`0`3
M````X!<!``4```#T%P$`!````/H7`0`7````_Q<!``H````7&`$`#````"(8
M`0`)````+Q@!``8````Y&`$`"0```$`8`0`(````2A@!``D```!3&`$`"@``
M`%T8`0`1````:!@!``8```!Z&`$`#@```($8`0`.````D!@!``T```"?&`$`
M"P```*T8`0`=````N1@!``L```#7&`$``@```.,8`0`<````YA@!``<````#
M&0$`!@````L9`0!E````$AD!``D```!X&0$`!P```((9`0`F````BAD!`#@`
M``"Q&0$`&@```.H9`0`J````!1H!`#L````P&@$`*````&P:`0`T````E1H!
M`!D```#*&@$`%0```.0:`0`%````^AH!``<`````&P$`"`````@;`0`'````
M$1L!``4````9&P$`!P```!\;`0`.````)QL!``D````V&P$`!@```$`;`0`(
M````1QL!``L```!0&P$`!P```%P;`0`(````9!L!``<```!M&P$`%@```'4;
M`0`)````C!L!``8```"6&P$`"P```)T;`0`0````J1L!``8```"Z&P$`'```
M`,$;`0`4````WAL!``<```#S&P$`$0```/L;`0`(````#1P!``X````6'`$`
M"````"4<`0`%````+AP!`!`````T'`$`"0```$4<`0`0````3QP!``8```!@
M'`$`&0```&<<`0`*````@1P!`!P```",'`$`!P```*D<`0`%````L1P!`!``
M``"W'`$`%````,@<`0`+````W1P!``T```#I'`$`*````/<<`0`8````(!T!
M`!<````Y'0$`!````%$=`0`)````5AT!``H```!@'0$`!P```&L=`0`"````
M<QT!``X```!V'0$`"````(4=`0`?````CAT!`",```"N'0$`'P```-(=`0`X
M````\AT!`"8````K'@$`,0```%(>`0`G````A!X!`&0```"L'@$`%````!$?
M`0!5````)A\!`#@```!\'P$`2@```+4?`0!;`````"`!`"@```!<(`$`.```
M`(4@`0`H````OB`!`"P```#G(`$`)P```!0A`0`;````/"$!`#X```!8(0$`
MJ0$``)<A`0`C````02,!`!<```!E(P$`2````'TC`0"%````QB,!`#````!,
M)`$`)0```'TD`0!!````HR0!`%L```#E)`$`20```$$E`0`Q````BR4!`!T`
M``"])0$`&````-LE`0`K````]"4!`"$````@)@$`'P```$(F`0`K````8B8!
M`"8```".)@$`(0```+4F`0`G````UR8!`#H```#_)@$`'0```#HG`0`1````
M6"<!`#,```!J)P$`)0```)XG`0`G````Q"<!`"````#L)P$`'P````TH`0`P
M````+2@!`&D```!>*`$`,0```,@H`0!!````^B@!`#,````\*0$`)0```'`I
M`0`]````EBD!`&4```#4*0$`30```#HJ`0`O````B"H!`"X```"X*@$`,```
M`.<J`0!4````&"L!`%H```!M*P$`2````,@K`0!*````$2P!`#(```!<+`$`
M+P```(\L`0`L````ORP!`"T```#L+`$`<0```!HM`0!F````C"T!`&\```#S
M+0$`LP```&,N`0`7````%R\!`"4````O+P$`,@```%4O`0`I````B"\!`#X`
M``"R+P$`(@```/$O`0!2````%#`!`"4```!G,`$`"P```(TP`0"Q````F3`!
M`$4```!+,0$`(0```)$Q`0`P````LS$!`"4```#D,0$`'`````HR`0`Q````
M)S(!``<```!9,@$`!P```&$R`0`$````:3(!``T```!N,@$`"P```'PR`0`.
M````B#(!``L```"7,@$`!0```*,R`0`0````J3(!``(```"Z,@$`60```+TR
M`0`%````%S,!`!(````=,P$`!````#`S`0`'````-3,!``@````],P$`!0``
M`$8S`0`P````3#,!``,```!],P$`$````($S`0`,````DC,!`!,```"?,P$`
M#0```+,S`0`"````P3,!``<```#$,P$`!@```,PS`0`4````TS,!``P```#H
M,P$`&````/4S`0`&````#C0!`!(````5-`$`#````"@T`0`#````-30!`"H`
M```Y-`$`!````&0T`0`&````:30!``<```!P-`$`'P```'@T`0`U````F#0!
M`"X```#.-`$`+P```/TT`0`7````+34!`"(```!%-0$`)0```&@U`0`@````
MCC4!`!L```"O-0$`&````,LU`0`D````Y#4!`!\````)-@$`&@```"DV`0`A
M````1#8!`"````!F-@$`&@```(<V`0`R````HC8!`!H```#5-@$`+P```/`V
M`0`K````(#<!`!\```!,-P$`(P```&PW`0`?````D#<!`!H```"P-P$`(0``
M`,LW`0`E````[3<!`"8````3.`$`)0```#HX`0`D````8#@!`!@```"%.`$`
M'0```)XX`0`D````O#@!`!@```#A.`$`(@```/HX`0`L````'3D!`"\```!*
M.0$`%0```'HY`0`E````D#D!`#P```"V.0$`'P```/,Y`0`C````$SH!`!\`
M```W.@$`(````%<Z`0`:````>#H!`!@```"3.@$`)@```*PZ`0`>````TSH!
M`"D```#R.@$`'@```!P[`0`Q````.SL!``D```!M.P$`#````'<[`0`7````
MA#L!`"\```"<.P$`)````,P[`0`'````\3L!``\```#Y.P$`%`````D\`0`.
M````'CP!``T````M/`$`)````#L\`0`%````8#P!``<```!F/`$`(@```&X\
M`0`E````D3P!`!H```"W/`$`'0```-(\`0`:````\#P!``<````+/0$`QP``
M`!,]`0`+````VST!`!4```#G/0$`!@```/T]`0`)````!#X!``L````./@$`
M#0```!H^`0`7````*#X!``8```!`/@$`,P```$<^`0`3````>SX!`!,```"/
M/@$`!P```*,^`0`/````JSX!``<```"[/@$`,@```,,^`0`$````]CX!`"$`
M``#[/@$`$P```!T_`0`,````,3\!`!$````^/P$`,@```%`_`0`6````@S\!
M``@```":/P$`'0```*,_`0`)````P3\!``H```#+/P$`%````-8_`0`*````
MZS\!`!T```#V/P$`"````!1``0`?````'4`!``@````]0`$`&@```$9``0`G
M````84`!``8```")0`$`%0```)!``0`'````ID`!``@```"N0`$`"0```+=`
M`0`_````P4`!``<````!00$`#P````E!`0`.````&4$!`!`````H00$`"0``
M`#E!`0`)````0T$!``@```!-00$`$P```%9!`0`'````:D$!`!D```!R00$`
M"@```(Q!`0`7````ET$!`!0```"O00$`"@```,1!`0`,````ST$!`!<```#<
M00$`!````/1!`0`J````^4$!``P````D0@$`$0```#%"`0`'````0T(!``(`
M``!+0@$`$````$Y"`0`8````7T(!``L```!X0@$``P```(1"`0`(````B$(!
M``8```"10@$`!P```)A"`0`-````H$(!``L```"N0@$`%````+I"`0`5````
MST(!``X```#E0@$`+P```/1"`0`@````)$,!`!P```!%0P$`%0```&)#`0`,
M````>$,!`#$```"%0P$`!0```+=#`0`2````O4,!`#\```#00P$`$@```!!$
M`0`*````(T0!``8````N1`$`!````#5$`0`$````.D0!``H````_1`$`$P``
M`$I$`0`%````7D0!``8```!D1`$`!@```&M$`0`(````<D0!``0```![1`$`
M#````(!$`0`*````C40!`#D```"81`$`+@```-)$`0`I`````44!``4````K
M10$`&````#%%`0`9````2D4!`!\```!D10$`'0```(1%`0`1````HD4!``(`
M``"T10$`!````+=%`0`*````O$4!``8```#'10$`!0```,Y%`0`#````U$4!
M``P```#810$`10```.5%`0`R````*T8!`!H```!>1@$`-0```'E&`0`H````
MKT8!`%,```#81@$`&0```"Q'`0!R````1D<!`"````"Y1P$`-0```-I'`0`A
M````$$@!`$4````R2`$`,````'A(`0`H````J4@!`"D```#22`$`)@```/Q(
M`0`E````(TD!`"@```!)20$`*````'))`0`B````FTD!`"L```"^20$`,```
M`.I)`0`2````&TH!`!,````N2@$`$````$)*`0!Y````4TH!``D```#-2@$`
MH0```-=*`0!S````>4L!`'P```#M2P$`*P```&I,`0!4````EDP!`!<```#K
M3`$`)P````--`0`6````*TT!``\```!"30$`%P```%)-`0`?````:DT!`$``
M``"*30$`'P```,M-`0`<````ZTT!`%$````(3@$`&@```%I.`0`4````=4X!
M``H```"*3@$`!0```)5.`0`&````FTX!``@```"B3@$`!0```*M.`0`2````
ML4X!`!````#$3@$`$P```-5.`0`=````Z4X!``\````'3P$`#P```!=/`0`$
M````)T\!``D````L3P$`"P```#9/`0`'````0D\!``4```!*3P$`%````%!/
M`0`'````94\!``@```!M3P$`#P```'9/`0`(````AD\!``P```"/3P$`#P``
M`)Q/`0`&````K$\!`!0```"S3P$`!@```,A/`0`,````ST\!`!$```#<3P$`
M"````.Y/`0`$````]T\!`!D```#\3P$`$0```!90`0`*````*%`!`!@````S
M4`$`$P```$Q0`0`<````8%`!`!$```!]4`$`!````(]0`0`/````E%`!``<`
M``"D4`$`!````*Q0`0`9````L5`!``<```#+4`$``@```--0`0`"````UE`!
M`!$```#94`$`"0```.M0`0`&````]5`!`!(```#\4`$`%P````]1`0`&````
M)U$!`"<````N40$``@```%91`0`$````65$!``\```!>40$`$P```&Y1`0`'
M````@E$!``<```"*40$`$0```))1`0`&````I%$!`!@```"K40$`!@```,11
M`0`3````RU$!`!````#?40$`$@```/!1`0`"`````U(!``8````&4@$`%0``
M``U2`0`,````(U(!``D````P4@$`$0```#I2`0`)````3%(!`"(```!64@$`
M!P```'E2`0`'````@5(!``L```")4@$`!0```)52`0`"````FU(!``L```">
M4@$`7`$``*I2`0`2````!U0!``\````:5`$`$@```"I4`0`'````/50!``@`
M``!%5`$`!P```$Y4`0`+````5E0!`!4```!B5`$`&P```'A4`0`H````E%0!
M`!P```"]5`$`'@```-I4`0`=````^50!`!,````750$`*0```"M5`0`+````
M554!`"(```!A50$`$0```(15`0`/````EE4!``P```"F50$`!0```+-5`0`9
M````N54!``P```#350$`$P```.!5`0`4````]%4!`!(````)5@$`$@```!Q6
M`0!:````+U8!`!$```"*5@$`"@```)Q6`0`-````IU8!`!````"U5@$`&@``
M`,96`0`4````X58!`!,```#V5@$`%0````I7`0`&````(%<!`)L````G5P$`
M#0```,-7`0`2````T5<!`!8```#D5P$`"@```/M7`0`1````!E@!`!$````8
M6`$`"````"I8`0`(````,U@!`"`````\6`$`$P```%U8`0`Q````<5@!`#0`
M``"C6`$`6````-A8`0!3````,5D!`%X```"%60$`60```.19`0`S````/EH!
M``H```!R6@$`#0```'U:`0`'````BUH!``H```"36@$`$0```)Y:`0`%````
ML%H!``8```"V6@$`$@```+U:`0`'````T%H!``D```#86@$`"0```.):`0`K
M````[%H!`"@````86P$`"@```$%;`0`.````3%L!`!$```!;6P$`#P```&U;
M`0`$````?5L!``X```""6P$`#@```)%;`0`*````H%L!``X```"K6P$`#@``
M`+I;`0`4````R5L!`!0```#>6P$`$@```/-;`0`*````!EP!`!$````17`$`
M"0```"-<`0`?````+5P!`!@```!-7`$`'````&9<`0`-````@UP!`$\```"1
M7`$`+0```.%<`0`A````#UT!``<````Q70$`#@```#E=`0`G````2%T!``8`
M``!P70$`!P```'==`0`*````?UT!``@```"*70$`"````)-=`0`%````G%T!
M``<```"B70$`"````*I=`0`$````LUT!`!L```"X70$`"P```-1=`0`,````
MX%T!``\```#M70$`$P```/U=`0`D````$5X!``X````V7@$`&````$5>`0`;
M````7EX!`!\```!Z7@$`'0```)I>`0`5````N%X!`!0```#.7@$`#@```.->
M`0`;````\EX!`!0````.7P$`!P```"-?`0`'````*U\!``@````S7P$`$P``
M`#Q?`0`&````4%\!``H```!77P$`$@```&)?`0`(````=5\!`!,```!^7P$`
M%@```))?`0`4````J5\!``<```"^7P$`$0```,9?`0`&````V%\!`!8```#?
M7P$`#@```/9?`0`,````!6`!`#0````28`$`1@```$=@`0`*````CF`!``@`
M``"98`$`%````*)@`0`%````MV`!``4```"]8`$`#0```,-@`0`/````T6`!
M`!T```#A8`$`)@```/]@`0`&````)F$!`"`````M80$`(````$YA`0`<````
M;V$!`!H```",80$`"@```*=A`0`&````LF$!``H```"Y80$`!P```,1A`0`P
M````S&$!`#````#]80$`+P```"YB`0!1````7F(!`"X```"P8@$`+@```-]B
M`0`_````#F,!`$````!.8P$`+@```(]C`0`U````OF,!`"@```#T8P$`)```
M`!UD`0`\````0F0!`"X```!_9`$`-````*YD`0`4````XV0!`!@```#X9`$`
M)@```!%E`0`D````.&4!`"0```!=90$`$P```()E`0`,````EF4!`!````"C
M90$`!0```+1E`0`+````NF4!`!@```#&90$`'````-]E`0`&````_&4!``<`
M```#9@$`$P````MF`0`*````'V8!``@````J9@$`)@```#-F`0`(````6F8!
M``D```!C9@$`!@```&UF`0`&````=&8!``4```![9@$`!P```(%F`0`&````
MB68!``D```"09@$`)@```)IF`0`/````P68!``H```#19@$`"0```-QF`0`(
M````YF8!``P```#O9@$`"````/QF`0`-````!6<!``H````39P$`%P```!YG
M`0`'````-F<!``@````^9P$`!````$=G`0`+````3&<!``D```!89P$`(```
M`&)G`0`2````@V<!``D```"69P$`!P```*!G`0`,````J&<!``<```"U9P$`
M"@```+UG`0`#````R&<!`!\```#,9P$`$P```.QG`0`N`````&@!``@````O
M:`$`!@```#AH`0`)````/V@!``<```!):`$`1P```%%H`0`?````F6@!`#H`
M``"Y:`$`(@```/1H`0`;````%VD!``8````S:0$`!0```#II`0`%````0&D!
M`"````!&:0$`&0```&=I`0`N````@6D!`"0```"P:0$`(P```-5I`0!>````
M^6D!`"@```!8:@$`%0```(%J`0`(````EVH!``X```"@:@$`&````*]J`0`.
M````R&H!``T```#7:@$`#P```.5J`0`1````]6H!``\````':P$`%````!=K
M`0`-````+&L!`!,````Z:P$`!P```$YK`0`5````5FL!`!D```!L:P$`%P``
M`(9K`0`3````GFL!`!<```"R:P$`!@```,IK`0`%````T6L!``X```#7:P$`
M6````.9K`0!6````/VP!``0```"6;`$`$P```)ML`0`'````KVP!``4```"W
M;`$`&P```+UL`0`=````V6P!``X```#W;`$`#0````9M`0`1````%&T!`!L`
M```F;0$`+@```$)M`0`+````<6T!`!\```!];0$`!0```)UM`0`:````HVT!
M``\```"^;0$`%````,YM`0`0````XVT!`!@```#T;0$`#@````UN`0`2````
M'&X!`!,````O;@$`"0```$-N`0`&````36X!``\```!4;@$`!@```&1N`0`>
M````:VX!``X```"*;@$`$P```)EN`0`(````K6X!``0```"V;@$`"@```+MN
M`0`+````QFX!``<```#2;@$`$P```-IN`0`)````[FX!``0```#X;@$`"```
M`/UN`0`*````!F\!``@````1;P$`"````!IO`0`%````(V\!``<````I;P$`
M`P```#%O`0`#````-6\!`!L````Y;P$`0@```%5O`0`5````F&\!``L```"N
M;P$`$````+IO`0`%````RV\!`!L```#1;P$`#P```.UO`0`0````_6\!`"0`
M```.<`$`-````#-P`0`=````:'`!``D```"&<`$`,@```)!P`0`)````PW`!
M``4```#-<`$`#````--P`0`)````X'`!``<```#J<`$`%@```/)P`0`-````
M"7$!``<````7<0$`"@```!]Q`0`-````*G$!`!\````X<0$`)````%AQ`0`B
M````?7$!`"<```"@<0$`'0```,AQ`0`@````YG$!`!\````'<@$`)````"=R
M`0`B````3'(!`"X```!O<@$`(@```)YR`0`A````P7(!`"0```#C<@$`(```
M``AS`0`G````*7,!`#<```!1<P$`-0```(ES`0`K````OW,!`"L```#K<P$`
M-P```!=T`0`G````3W0!`!(```!W=`$`+@```(IT`0`B````N70!`!(```#<
M=`$`*P```.]T`0`?````&W4!`!X````[=0$`$P```%IU`0"2````;G4!`!H`
M```!=@$`*0```!QV`0`I````1G8!`"L```!P=@$`*````)QV`0`G````Q78!
M`!D```#M=@$`(@````=W`0`P````*G<!`#,```!;=P$`/P```(]W`0`^````
MSW<!`)L````.>`$`$P```*IX`0`3````OG@!`!X```#2>`$`)0```/%X`0`G
M````%WD!`#P````_>0$`0@```'QY`0`8````OWD!``0```#8>0$`"````-UY
M`0`#````YGD!``D```#J>0$`"````/1Y`0`0````_7D!``X````.>@$`%```
M`!UZ`0`)````,GH!``4````\>@$`$0```$)Z`0`4````5'H!``@```!I>@$`
M#P```')Z`0`3````@GH!``P```"6>@$`#0```*-Z`0`.````L7H!`"P```#`
M>@$`!0```.UZ`0`+````\WH!``8```#_>@$`$P````9[`0`9````&GL!`!L`
M```T>P$`#P```%![`0`"````8'L!`$L```!C>P$`"````*][`0`0````N'L!
M`!````#)>P$`!P```-I[`0`1````XGL!``X```#T>P$`!`````-\`0`.````
M"'P!``D````7?`$`#@```"%\`0`1````,'P!``D```!"?`$`#@```$Q\`0`/
M````6WP!``\```!K?`$`#0```'M\`0`'````B7P!``X```"1?`$`#0```*!\
M`0`,````KGP!``T```"[?`$`&0```,E\`0`.````XWP!``T```#R?`$`)0``
M``!]`0`3````)GT!`!<````Z?0$`+````%)]`0`,````?WT!`!H```",?0$`
M%@```*=]`0`5````OGT!`"X```#4?0$`%`````-^`0`%````&'X!`!(````>
M?@$`"0```#%^`0`G````.WX!`"@```!C?@$`!P```(Q^`0`*````E'X!`!@`
M``"??@$`"P```+A^`0`7````Q'X!`!<```#<?@$`"````/1^`0`<````_7X!
M``X````:?P$`&@```"E_`0`5````1'\!``X```!:?P$`&````&E_`0`(````
M@G\!``L```"+?P$`+@```)=_`0`Z````QG\!``@````!@`$`%`````J``0`=
M````'X`!``@````]@`$`"P```$:``0`H````4H`!``@```![@`$`!P```(2`
M`0`&````C(`!`$H```"3@`$``P```-Z``0`'````XH`!``4```#J@`$`#```
M`/"``0`,````_8`!``P````*@0$`#````!>!`0`/````)($!``X````T@0$`
M$0```$.!`0`/````58$!``<```!E@0$`!P```&V!`0!$````=8$!``L```"Z
M@0$`"@```,:!`0`"````T8$!``8```#4@0$`#P```-N!`0`B````ZX$!`!(`
M```.@@$`$@```"&"`0`'````-((!``X````\@@$`$````$N"`0`7````7((!
M`"X```!T@@$`'0```*."`0`*````P8(!``\```#,@@$`:P```-R"`0`6````
M2(,!`!,```!?@P$`$0```'.#`0`'````A8,!``0```"-@P$`%P```)*#`0`K
M````JH,!`"P```#6@P$`&`````.$`0`;````'(0!`!0````XA`$`%P```$V$
M`0`%````980!``@```!KA`$`"0```'2$`0`'````?H0!`!0```"&A`$`$P``
M`)N$`0`5````KX0!`!,```#%A`$`$P```-F$`0`6````[80!``P````$A0$`
M$````!&%`0`'````(H4!``<````JA0$`#@```#*%`0`+````084!`#,```!-
MA0$`$````(&%`0`)````DH4!``L```"<A0$`(@```*B%`0`<````RX4!`"(`
M``#HA0$`(0````N&`0`<````+88!`!L```!*A@$`(0```&:&`0`7````B(8!
M`!0```"@A@$``P```+6&`0`<````N88!``P```#6A@$`#0```..&`0`$````
M\88!``8```#VA@$`"````/V&`0`+````!H<!``T````2AP$`$0```""'`0`4
M````,H<!``P```!'AP$`#@```%2'`0`+````8X<!``4```!OAP$`!````'6'
M`0`4````>H<!`!4```"/AP$`"P```*6'`0`*````L8<!``L```"\AP$`$P``
M`,B'`0`A````W(<!``<```#^AP$`!0````:(`0`,````#(@!``\````9B`$`
M#````"F(`0`(````-H@!``8````_B`$``P```$:(`0`8````2H@!``L```!C
MB`$`!````&^(`0`E````=(@!``X```":B`$`<````*F(`0`3````&HD!``8`
M```NB0$`!````#6)`0`*````.HD!``8```!%B0$`"````$R)`0`(````58D!
M``<```!>B0$``@```&:)`0`&````:8D!``L```!PB0$`&````'R)`0`2````
ME8D!`!0```"HB0$`$P```+V)`0`'````T8D!``@```#9B0$`$@```.*)`0`'
M````]8D!``@```#]B0$`!0````:*`0`8````#(H!``@````EB@$`!@```"Z*
M`0`<````-8H!`!$```!2B@$`!P```&2*`0`(````;(H!``4```!UB@$`"0``
M`'N*`0`'````A8H!``X```"-B@$`!````)R*`0`%````H8H!``X```"GB@$`
M#0```+:*`0`.````Q(H!``8```#3B@$`$P```-J*`0`)````[HH!``<```#X
MB@$`#P````"+`0`A````$(L!`#,````RBP$`)@```&:+`0`B````C8L!``8`
M``"PBP$`"@```+>+`0`$````PHL!``H```#'BP$`"````-*+`0`0````VXL!
M``\```#LBP$`!0```/R+`0`,`````HP!``@````/C`$`!````!B,`0`_````
M'8P!`$$```!=C`$`/P```)^,`0`;````WXP!``8```#[C`$`#`````*-`0`$
M````#XT!``0````4C0$`!@```!F-`0`?````((T!``\```!`C0$`%@```%"-
M`0`&````9XT!``,```!NC0$`%@```'*-`0`'````B8T!``@```"1C0$`$P``
M`)J-`0`%````KHT!``@```"TC0$`'0```+V-`0`)````VXT!``X```#EC0$`
M#````/2-`0`.`````8X!``D````0C@$`"````!J.`0`%````(XX!`"P````I
MC@$`+0```%:.`0`W````A(X!`"<```"\C@$`/@```.2.`0`V````(X\!`"D`
M``!:CP$`/````(2/`0`O````P8\!`"\```#QCP$`'P```"&0`0`/````09`!
M`!<```!1D`$`#@```&F0`0`G````>)`!`"0```"@D`$`'````,60`0`B````
MXI`!``<````%D0$`"`````V1`0`*````%I$!``8````AD0$`(0```"B1`0`E
M````2I$!`"@```!PD0$`"@```)F1`0`6````I)$!`"@```"[D0$`%@```.21
M`0`/````^Y$!``8````+D@$`#@```!*2`0`*````(9(!`!`````LD@$`$0``
M`#V2`0`Y````3Y(!`'L```")D@$`>`````63`0`/````?I,!``D```".DP$`
M"@```)B3`0`.````HY,!``\```"RDP$`$P```,*3`0`&````UI,!``\```#=
MDP$`$P```.V3`0`2`````90!`!$````4E`$`&P```":4`0`@````0I0!`%\`
M``!CE`$`$@```,.4`0`%````UI0!`!$```#<E`$`"@```.Z4`0`$````^90!
M``T```#^E`$`'@````R5`0`2````*Y4!``D````^E0$`"@```$B5`0`.````
M4Y4!`!````!BE0$`)````'.5`0`B````F)4!`"$```"[E0$`'P```-V5`0`A
M````_94!`!\````?E@$`%P```#^6`0`X````5Y8!`!(```"0E@$`$````*.6
M`0`1````M)8!``\```#&E@$`"P```-:6`0`0````XI8!``X```#SE@$`$```
M``*7`0`.````$Y<!`"$````BEP$`#P```$27`0`/````5)<!`"\```!DEP$`
M$@```)27`0`'````IY<!`!,```"OEP$`'@```,.7`0`3````XI<!`!````#V
MEP$`#0````>8`0`9````%9@!`!,````OF`$`$0```$.8`0`5````59@!`!@`
M``!KF`$`#P```(28`0`;````E)@!`"$```"PF`$`$0```-*8`0`2````Y)@!
M`!$```#WF`$`$0````F9`0`2````&YD!`!4````NF0$`%````$29`0`7````
M69D!``@```!QF0$`"@```'J9`0`5````A9D!``4```";F0$`!P```*&9`0`)
M````J9D!`!0```"SF0$`!P```,B9`0`*````T)D!``@```#;F0$`!P```.29
M`0`'````[)D!``<```#TF0$`!@```/R9`0`5`````YH!`%(````9F@$`!@``
M`&R:`0`)````<YH!``4```!]F@$`!0```(.:`0`(````B9H!``<```"2F@$`
M"````)J:`0`(````HYH!``@```"LF@$`"0```+6:`0`2````OYH!``8```#2
MF@$`(@```-F:`0`/````_)H!``T````,FP$`#P```!J;`0`,````*IL!``H`
M```WFP$`#0```$*;`0`F````4)L!``8```!WFP$`"````'Z;`0`@````AYL!
M``X```"HFP$`#@```+>;`0`&````QIL!``H```#-FP$`"0```-B;`0`$````
MXIL!`"````#GFP$`#`````B<`0`6````%9P!``\````LG`$`$0```#R<`0`4
M````3IP!`"(```!CG`$`'@```(:<`0`$````I9P!``8```"JG`$`"````+&<
M`0`A````NIP!``@```#<G`$`!0```.6<`0`*````ZYP!`!$```#VG`$`!P``
M``B=`0`$````$)T!``@````5G0$`%P```!Z=`0`-````-IT!``T```!$G0$`
M"0```%*=`0`6````7)T!`!,```!SG0$`#0```(>=`0`2````E9T!``X```"H
MG0$`#@```+>=`0`'````QIT!``0```#.G0$`%0```-.=`0`R````Z9T!``8`
M```<G@$`#@```".>`0`@````,IX!`!0```!3G@$`&````&B>`0`0````@9X!
M``P```"2G@$`"0```)^>`0`'````J9X!``H```"QG@$`"0```+R>`0`.````
MQIX!`!````#5G@$`*@```.:>`0`I````$9\!`"<````[GP$`"0```&.?`0`%
M````;9\!``<```!SGP$`#0```'N?`0`.````B9\!``<```"8GP$`"@```*"?
M`0`>````JY\!``H```#*GP$`#````-6?`0`3````XI\!`#\```#VGP$`%0``
M`#:@`0`*````3*`!``@```!7H`$`!0```&"@`0`1````9J`!`!$```!XH`$`
M%@```(J@`0`*````H:`!``(```"LH`$`!````*^@`0`E````M*`!``,```#:
MH`$`!0```-Z@`0`H````Y*`!``H````-H0$`!@```!BA`0`&````'Z$!`!0`
M```FH0$`"0```#NA`0`&````1:$!``@```!,H0$`"0```%6A`0`$````7Z$!
M``4```!DH0$`:0```&JA`0`+````U*$!``X```#@H0$`%P```.^A`0`%````
M!Z(!``0````-H@$`'P```!*B`0`I````,J(!`!````!<H@$`"@```&VB`0`.
M````>*(!``L```"'H@$`"@```).B`0`7````GJ(!`!T```"VH@$`)@```-2B
M`0`E````^Z(!`!P````AHP$`#0```#ZC`0`#````3*,!``<```!0HP$`"0``
M`%BC`0`'````8J,!``T```!JHP$`#@```'BC`0`%````AZ,!`%,```"-HP$`
M$0```.&C`0`*````\Z,!``D```#^HP$`'`````BD`0!%````):0!`!<```!K
MI`$`!@```(.D`0`?````BJ0!`#$```"JI`$`!@```-RD`0`'````XZ0!`!@`
M``#KI`$`!P````2E`0`)````#*4!`"8````6I0$`)````#VE`0`G````8J4!
M``@```"*I0$`"P```).E`0`@````GZ4!`&(```#`I0$`$0```".F`0`@````
M-:8!`!0```!6I@$``@```&NF`0`/````;J8!``@```!^I@$`$````(>F`0`)
M````F*8!``0```"BI@$`$````*>F`0`&````N*8!``D```"_I@$`#````,FF
M`0`)````UJ8!``H```#@I@$`"0```.NF`0`K````]:8!``8````AIP$`#P``
M`"BG`0`0````.*<!`!L```!)IP$`&P```&6G`0`+````@:<!``\```"-IP$`
M#P```)VG`0`+````K:<!``L```"YIP$`"P```,6G`0`)````T:<!`!4```#;
MIP$`$0```/&G`0`%`````Z@!``H````)J`$`#P```!2H`0`,````)*@!`!8`
M```QJ`$`!P```$BH`0`2````4*@!``0```!CJ`$`"````&BH`0`%````<:@!
M``8```!WJ`$`!P```'ZH`0`1````AJ@!`!$```"8J`$`&0```*JH`0`6````
MQ*@!`!4```#;J`$`%@```/&H`0`9````"*D!`"`````BJ0$`&@```$.I`0`$
M````7JD!``P```!CJ0$`#@```'"I`0`.````?ZD!``X```".J0$`!P```)VI
M`0`C````I:D!``L```#)J0$`#````-6I`0`6````XJD!`!H```#YJ0$`$P``
M`!2J`0`'````**H!``8````PJ@$`"````#>J`0`1````0*H!`!````!2J@$`
M"0```&.J`0`*````;:H!``4```!XJ@$`"````'ZJ`0`"````AZH!``0```"*
MJ@$``@```(^J`0`X````DJH!`"(```#+J@$`#````.ZJ`0`=````^ZH!`#(`
M```9JP$`$0```$RK`0`G````7JL!`!@```"&JP$`'0```)^K`0`=````O:L!
M`"(```#;JP$`%@```/ZK`0`3````%:P!``\````IK`$`$0```#FL`0`2````
M2ZP!`!$```!>K`$`#0```'"L`0`,````?JP!``X```"+K`$`%@```)JL`0`A
M````L:P!`"$```#3K`$`)0```/6L`0`B````&ZT!`",````^K0$`(````&*M
M`0!E````@ZT!`!L```#IK0$`$0````6N`0`(````%ZX!`!<````@K@$`$```
M`#BN`0`4````2:X!`"<```!>K@$`*0```(:N`0`E````L*X!`!(```#6K@$`
M1P```.FN`0!&````,:\!``D```!XKP$`"0```(*O`0`7````C*\!``T```"D
MKP$`#0```+*O`0`5````P*\!``4```#6KP$`$````-RO`0`/````[:\!``\`
M``#]KP$`#P````VP`0`)````';`!`!`````GL`$`!P```#BP`0`A````0+`!
M``@```!BL`$``P```&NP`0`+````;[`!``P```![L`$`"@```(BP`0`[````
MD[`!``(```#/L`$`!@```-*P`0`-````V;`!``\```#GL`$`"````/>P`0`.
M`````+$!``H````/L0$`*P```!JQ`0`1````1K$!`!X```!8L0$`!0```'>Q
M`0`L````?;$!`!D```"JL0$`)@```,2Q`0!5````Z[$!``X```!!L@$`1```
M`%"R`0`;````E;(!`!,```"QL@$`!@```,6R`0`-````S+(!`!,```#:L@$`
M#@```.ZR`0`(````_;(!``0````&LP$`%`````NS`0`<````(+,!``,````]
MLP$`"````$&S`0`/````2K,!`"````!:LP$`#P```'NS`0`3````B[,!`!0`
M``"?LP$`#P```+2S`0`C````Q+,!``@```#HLP$`#````/&S`0`-````_K,!
M``<````,M`$`#````!2T`0`'````(;0!`!`````IM`$`"````#JT`0`-````
M0[0!`!4```!1M`$`#0```&>T`0`%````=;0!``@```![M`$`!0```(2T`0`C
M````BK0!``8```"NM`$`$````+6T`0`(````QK0!`!$```#/M`$`"````.&T
M`0`2````ZK0!``T```#]M`$`*0````NU`0`4````-;4!``D```!*M0$`"@``
M`%2U`0`:````7[4!``4```!ZM0$`$P```("U`0`'````E+4!`!4```"<M0$`
M"````+*U`0`)````N[4!`!,```#%M0$`'@```-FU`0`%````^+4!`!H```#^
MM0$`$P```!FV`0`'````+;8!``X````UM@$`#````$2V`0`%````4;8!``P`
M``!7M@$`"@```&2V`0`'````;[8!``4```!WM@$`"````'VV`0`'````AK8!
M``H```".M@$`%@```)FV`0`K````L+8!`#````#<M@$`%0````VW`0`B````
M([<!`!T```!&MP$`-P```&2W`0`6````G+<!`!,```"SMP$`)````,>W`0!)
M````[+<!`!P````VN`$`!0```%.X`0`)````6;@!``H```!CN`$`"````&ZX
M`0`4````=[@!`!4```",N`$`*P```**X`0`:````SK@!`!<```#IN`$`+P``
M``&Y`0`U````,;D!``<```!GN0$`$P```&^Y`0`(````@[D!``@```",N0$`
M&0```)6Y`0`/````K[D!``X```"_N0$`#0```,ZY`0`(````W+D!`!,```#E
MN0$`"0```/FY`0`.`````[H!``L````2N@$`%@```!ZZ`0`2````-;H!`"<`
M``!(N@$`"P```'"Z`0`>````?+H!``4```";N@$`!@```*&Z`0`'````J+H!
M`!H```"PN@$`!0```,NZ`0`$````T;H!``T```#6N@$`"@```.2Z`0`'````
M[[H!``P```#WN@$`#`````2[`0`-````$;L!``@````?NP$``P```"B[`0`)
M````++L!`#,````VNP$`0P```&J[`0`8````KKL!``D```#'NP$`)P```-&[
M`0`9````^;L!``\````3O`$`#@```".\`0`*````,KP!``@````]O`$`$```
M`$:\`0`J````5[P!``<```""O`$`#0```(J\`0`-````F+P!`!````"FO`$`
M#````+>\`0`Y````Q+P!``<```#^O`$`$P````:]`0`0````&KT!`!0````K
MO0$`-@```$"]`0`=````=[T!`",```"5O0$`)````+F]`0`@````WKT!`!``
M``#_O0$`"````!"^`0`.````&;X!`!8````HO@$`%0```#^^`0`)````5;X!
M`!(```!?O@$`$@```'*^`0`'````A;X!`!L```"-O@$`&P```*F^`0`+````
MQ;X!``4```#1O@$`"@```->^`0`1````XKX!``X```#TO@$`!`````._`0`(
M````"+\!``D````1OP$`#@```!N_`0`.````*K\!``H````YOP$`"@```$2_
M`0`%````3[\!``8```!5OP$`+@```%R_`0`E````B[\!`",```"QOP$`!P``
M`-6_`0`1````W;\!``8```#OOP$`'P```/:_`0`5````%L`!`"$````LP`$`
M#P```$[``0`,````7L`!`"````!KP`$``P```(S``0`(````D,`!``T```"9
MP`$``@```*?``0`,````JL`!`!0```"WP`$`"P```,S``0`8````V,`!`!P`
M``#QP`$`%`````[!`0`%````(\$!``H````IP0$`%````#3!`0`6````2<$!
M``T```!@P0$`"0```&[!`0`-````>,$!``L```"&P0$`$@```)+!`0!/````
MI<$!`!\```#UP0$`-0```!7"`0`1````2\(!``8```!=P@$`!@```&3"`0`/
M````:\(!``L```![P@$`#````(?"`0`2````E,(!``\```"GP@$`"P```+?"
M`0`5````P\(!``D```#9P@$`'P```./"`0`+`````\,!``\````/PP$`1@``
M`!_#`0`7````9L,!`!D```!^PP$`(@```)C#`0`7````N\,!`!D```#3PP$`
M&````.W#`0`0````!L0!`!0````7Q`$`&0```"S$`0`)````1L0!``<```!0
MQ`$`"````%C$`0`)````8<0!`!0```!KQ`$`"P```(#$`0`E````C,0!`!(`
M``"RQ`$`&````,7$`0`+````WL0!``0```#JQ`$`3````._$`0`]````/,4!
M`#8```!ZQ0$`6P```+'%`0`)````#<8!`"L````7Q@$`+````$/&`0`*````
M<,8!``D```![Q@$`#0```(7&`0`S````D\8!``4```#'Q@$`0@```,W&`0`O
M````$,<!`"<```!`QP$`#0```&C'`0`@````=L<!`!<```"7QP$`)0```*_'
M`0`>````U<<!`"(```#TQP$`'0```!?(`0`-````-<@!``<```!#R`$`$@``
M`$O(`0`/````7L@!`!8```!NR`$`"````(7(`0`Y````CL@!``P```#(R`$`
M!0```-7(`0`'````V\@!`!$```#CR`$`"````/7(`0`&````_L@!`!,````%
MR0$`"0```!G)`0`)````(\D!``0````MR0$`#0```#+)`0`1````0,D!`!H`
M``!2R0$`%P```&W)`0`-````A<D!`!4```"3R0$`$````*G)`0`(````NLD!
M`!0```##R0$`&P```-C)`0`,````],D!``T````!R@$`&@````_*`0`G````
M*LH!``T```!2R@$`$P```&#*`0`>````=,H!``@```"3R@$`!````)S*`0`2
M````H<H!``D```"TR@$`"0```+[*`0`3````R,H!``X```#<R@$`#````.O*
M`0`+````^,H!``4````$RP$`"0````K+`0`(````%,L!``D````=RP$`"@``
M`"?+`0`3````,LL!``0```!&RP$`$````$O+`0`-````7,L!`!(```!JRP$`
M#P```'W+`0`8````C<L!``L```"FRP$``@```+++`0`=````M<L!``4```#3
MRP$`!P```-G+`0!J````X<L!``D```!,S`$`"@```%;,`0`9````8<P!`"4`
M``![S`$`$P```*',`0`>````M<P!`$<```#4S`$`,````!S-`0`X````3<T!
M`!<```"&S0$`%P```)[-`0`&````MLT!``T```"]S0$`"P```,O-`0`.````
MU\T!`!$```#FS0$`"P```/C-`0`3````!,X!``T````8S@$`#@```";.`0`0
M````-<X!``D```!&S@$`!````%#.`0`(````5<X!``T```!>S@$`%0```&S.
M`0`)````@LX!``8```",S@$`!P```)/.`0`A````F\X!``8```"]S@$`'```
M`,3.`0`7````X<X!``H```#YS@$`%0````3/`0`.````&L\!`!<````ISP$`
M"````$'/`0`%````2L\!``\```!0SP$`#0```&#/`0`/````;L\!``8```!^
MSP$`%@```(7/`0`+````G,\!`!<```"HSP$`"@```,#/`0`$````R\\!``X`
M``#0SP$`&@```-_/`0`+````^L\!``T````&T`$`*@```!30`0`5````/]`!
M``X```!5T`$`!0```&30`0`,````:M`!``X```!WT`$`!P```(;0`0`"````
MCM`!``T```"1T`$``P```)_0`0`3````H]`!`!T```"WT`$`(P```-70`0`P
M````^=`!`"(````JT0$`)0```$W1`0`@````<]$!`%(```"4T0$`$P```.?1
M`0!*````^]$!`"X```!&T@$`1P```'72`0!&````O=(!`!T````$TP$`+0``
M`"+3`0`E````4-,!`"X```!VTP$`)@```*73`0`;````S-,!`"P```#HTP$`
MUP$``!74`0`>````[=4!`!$````,U@$`10```![6`0!U````9-8!`"P```#:
MU@$`&P````?7`0`Q````(]<!`%<```!5UP$`30```*W7`0`=````^]<!`!H`
M```9V`$`$0```#38`0`=````1M@!`!H```!DV`$`&P```'_8`0`>````F]@!
M`!\```"ZV`$`&@```-K8`0`?````]=@!`#`````5V0$`'@```$;9`0`3````
M9=D!`"H```!YV0$`)````*39`0`E````R=D!`"0```#OV0$`&0```!3:`0`G
M````+MH!`%@```!6V@$`*P```*_:`0`_````V]H!`"X````;VP$`(@```$K;
M`0`Z````;=L!`%P```"HVP$`1P````7<`0`F````3=P!`"@```!TW`$`+0``
M`)W<`0!+````R]P!`%L````7W0$`0P```'/=`0!$````M]T!`"X```#\W0$`
M)@```"O>`0`D````4MX!`"<```!WW@$`9P```)_>`0!=````!]\!`&8```!E
MWP$`L@```,S?`0`8````?^`!`"8```"8X`$`-````+_@`0`M````].`!`$(`
M```BX0$`(@```&7A`0!$````B.$!`!\```#-X0$`"@```.WA`0"M````^.$!
M`#X```"FX@$`(````.7B`0`U````!N,!`"8````\XP$`'P```&/C`0`C````
M@^,!``0```"GXP$`"````*SC`0`#````M>,!``L```"YXP$`"@```,7C`0`)
M````T.,!``D```#:XP$`"````.3C`0`2````[>,!``<`````Y`$`6@````CD
M`0`$````8^0!`!$```!HY`$`!````'KD`0`'````?^0!``4```"'Y`$`!0``
M`(WD`0`Z````D^0!``0```#.Y`$`%P```-/D`0`&````Z^0!`!(```#RY`$`
M#0````7E`0`"````$^4!``@````6Y0$`!0```!_E`0`2````)>4!``P````X
MY0$`#P```$7E`0`&````5>4!`!(```!<Y0$`"P```&_E`0`#````>^4!`"<`
M``!_Y0$`!````*?E`0`&````K.4!``<```"SY0$`'@```+OE`0`V````VN4!
M`",````1Y@$`)````#7F`0`:````6N8!`"T```!UY@$`,````*/F`0`>````
MU.8!`!\```#SY@$`'0```!/G`0`B````,><!`!T```!4YP$`&0```'+G`0`?
M````C.<!`!P```"LYP$`%@```,GG`0`L````X.<!`!H````-Z`$`*0```"CH
M`0`D````4N@!`"$```!WZ`$`(P```)GH`0`@````O>@!`!T```#>Z`$`(0``
M`/SH`0`H````'ND!`"@```!'Z0$`(P```'#I`0`B````E.D!`!\```"WZ0$`
M'````-?I`0`B````].D!`!D````7Z@$`'P```#'J`0`L````4>H!`"\```!^
MZ@$`&0```*[J`0`B````R.H!`#D```#KZ@$`)0```"7K`0`G````2^L!`"4`
M``!SZP$`*````)GK`0`A````PNL!`!\```#DZP$`*@````3L`0`@````+^P!
M`"L```!0[`$`)@```'SL`0`S````H^P!`!(```#7[`$`#@```.KL`0`=````
M^>P!`"T````7[0$`&P```$7M`0`,````8>T!``\```!N[0$`%@```'[M`0`-
M````E>T!`!0```"C[0$`(0```+CM`0`&````VNT!``@```#A[0$`(P```.KM
M`0`F````#NX!`!D````U[@$`(P```$_N`0`9````<^X!``8```"-[@$`O```
M`)3N`0`,````4>\!`!(```!>[P$`!P```''O`0`(````>>\!``X```""[P$`
M#@```)'O`0`;````H.\!``X```"\[P$`-````,OO`0`0`````/`!`!0````1
M\`$`!P```";P`0`3````+O`!``L```!"\`$`-P```$[P`0`(````AO`!`!\`
M``"/\`$`#@```*_P`0`2````OO`!`!@```#1\`$`-P```.KP`0`8````(O$!
M``P````[\0$`(0```$CQ`0`-````:O$!``T```!X\0$`%````(;Q`0`*````
MF_$!`!H```"F\0$`!@```,'Q`0`E````R/$!``@```#N\0$`)P```/?Q`0`B
M````'_(!``D```!"\@$`'@```$SR`0`'````:_(!``<```!S\@$`"P```'OR
M`0!"````A_(!``L```#*\@$`#P```-;R`0`3````YO(!`!4```#Z\@$`#```
M`!#S`0`*````'?,!``<````H\P$`$0```##S`0`(````0O,!`!<```!+\P$`
M#````&/S`0`2````</,!`!````"#\P$`"````)3S`0`*````G?,!`!<```"H
M\P$`!P```,#S`0`Q````R/,!``P```#Z\P$`$`````?T`0`'````&/0!``(`
M```@]`$`#````"/T`0`1````,/0!``L```!"]`$`!````$[T`0`)````4_0!
M``P```!=]`$`#0```&KT`0`2````>/0!`!$```"+]`$`$@```)WT`0`3````
ML/0!``P```#$]`$`-@```-'T`0`E````"/4!`"8````N]0$`%P```%7U`0`/
M````;?4!`"X```!]]0$`!0```*SU`0`2````LO4!`$````#%]0$`#`````;V
M`0`)````$_8!``8````=]@$`!````"3V`0`$````*?8!``T````N]@$`%0``
M`#SV`0`%````4O8!``8```!8]@$`!@```%_V`0`-````9O8!``,```!T]@$`
M#P```'CV`0`*````B/8!`#4```"3]@$`*@```,GV`0`G````]/8!``4````<
M]P$`&@```"+W`0`?````/?<!`"(```!=]P$`)````(#W`0`1````I?<!``(`
M``"W]P$`!````+KW`0`,````O_<!``L```#,]P$`!@```-CW`0`#````W_<!
M``X```#C]P$`00```/+W`0`I````-/@!`!@```!>^`$`*0```'?X`0`M````
MH?@!`#T```#/^`$`$@````WY`0"0````(/D!`"4```"Q^0$`-P```-?Y`0`@
M````#_H!`"X````P^@$`*P```%_Z`0`A````B_H!`"H```"M^@$`*0```-CZ
M`0`F`````OL!`"4````I^P$`*````$_[`0`C````>/L!`"4```"<^P$`-0``
M`,+[`0`5````^/L!`!0````._`$`"0```"/\`0!H````+?P!``D```"6_`$`
MC0```*#\`0!W````+OT!`&\```"F_0$`-@```!;^`0!?````3?X!``X```"M
M_@$`(0```+S^`0`5````WOX!`!(```#T_@$`'@````?_`0`;````)O\!`#$`
M``!"_P$`&@```'3_`0`:````C_\!`$L```"J_P$`&0```/;_`0`6````$``"
M``L````G``(`!````#,``@`&````.``"``@````_``(`!0```$@``@`7````
M3@`"`!````!F``(`&0```'<``@`B````D0`"``\```"T``(`!P```,0``@`)
M````S``"``D```#6``(`#0```.```@`'````[@`"``0```#V``(`$@```/L`
M`@`+````#@$"``L````:`0(`#P```"8!`@`*````-@$"``@```!!`0(`$```
M`$H!`@`*````6P$"`!,```!F`0(`"@```'H!`@`.````A0$"`!(```"4`0(`
M"````*<!`@`&````L`$"`!L```"W`0(`%@```-,!`@`+````Z@$"`!<```#V
M`0(`#P````X"`@`?````'@("`!4````^`@(`!0```%0"`@`0````6@("``8`
M``!K`@(`!````'("`@`=````=P("``L```"5`@(``@```*$"`@`"````I`("
M`!(```"G`@(`"P```+H"`@`&````Q@("`!,```#-`@(`%@```.$"`@`%````
M^`("`"````#^`@(``@```!\#`@`$````(@,"``X````G`P(`$P```#8#`@`'
M````2@,"``D```!2`P(`$````%P#`@`'````;0,"`!P```!U`P(`!@```)(#
M`@`7````F0,"``\```"Q`P(`$@```,$#`@`"````U`,"``<```#7`P(`%P``
M`-\#`@`-````]P,"`!,````%!`(`#0```!D$`@`-````)P0"`#`````U!`(`
M"````&8$`@`&````;P0"``X```!V!`(`!0```(4$`@`"````BP0"``L```".
M!`(``0```%P'```P````+`8``!@%````````N`0``*H&```>``````````D&
M``#D`0``Q@0``(P%```K`@```````)0!``"K!0``````````````````9@0`
M`%X"```C!```R@`````````=`P``E`0````````A`````````-D"````````
MGP(``'@!``";`P``*@```.P&````````DP0```````#2`0``R@4``&@!```;
M`0``CP,```````#``P``FP(``&D!``""!P``*````"8"``!_`0``]@,`````
M``!Z!P```````$4"```O!0`````````````;!P````````````"Z`P``````
M``````!P!```3````.8&``!$`0```````$L&```Z`@``M`(``*4"````````
M3P$``$L"````````'0(``'@'``""`@``I@(```H'```8`0``>`0````````*
M`0``00``````````````'@4```````#+````^@(``#,```!>!@``SP,``)\$
M``"/!0``7@$```````!;`0``<P0``.H"``#[`P``:0(```````#V!```````
M`-T!`````````````'````"_`0```````*D&``!Q`P````````````!I!0``
M`````"\$``!H!@``Q````(T!```,!```[P,``$H!``!T`@``5`(````````Q
M``````````````"E``````````D!``#)!@``!````&X%``![!@```````*<&
M``#K!@```````!H$```````````````````T````XP0``+,%````````T0``
M`"<````7!````````%8$``#H`@``6P0``+$#````````U0(`````````````
MS0,```$$```````````````````_!P``,`(```````#3`P``]@$```````#X
M`@``%P(````````,!P```````'`"``!5````\0,``+T#``"O!0``N04``+@!
M``#8!```C04``&$$``#0!0``3@<```````!T`0``"@```%4'````````6@$`
M`,H!``!*````Z08``($!``"Y`P``U`$```````"'!@```````,@$``!<`0``
MP````+H&````````NP4``&0&``!A````\@,``$L!```J`@``)@0``',&``!?
M!0``7````&@#``!,!0```````+`!````!P``X@0`````````````.`<``#`&
M````````#P,`````````````(`,``+P#``"=````Q`(``-H#````````````
M`)`&```$`P``O0```(@"````````K04```````#<!@``&@,``)P"``!O!P``
M`````+0&````````A@```,(!``"O!@``Z00``(D#````````<P$``"L$``!.
M!0`````````````;!0``H0```!0$````````6P(``#L#``#/!0``H0(`````
M``"7`P``8@0```0%``#:!@```````"`````D!```R`$```````"R!```(@8`
M`$,'``"L!```>0,```````".`P``T0(``%L#```\`P``U0$``)<!````````
M>08```````!O````W@4`````````````\08```````",`0``#`,``.`%``#9
M`P``2`<``)0%``!Q!```]@```&$!``!"!@```````!L$```L!0``C0```"$&
M````````M@(``$P&````````W````$0'``"Y`0``B`$``&X'``#M`P``.`0`
M`"$$```?`0``:````+,````2`````````*,%````````L@(``'$```#T`0``
M?````/X%```-!P``B@````````#^`@``DP```,P"````````F@$``!T'``"V
M`P``0P8``$P'``!P!@````````````"F`P``>@4``````````````````#L"
M``!G`0``40<``'\"``"K`0```````!P"```M`0``-P8``)D%````````````
M`!D!``!.````N`8``/,&``"F!`````````````#)`````````)(#````````
MW@8``-T```#*!@``X0```/0````P`0``_@```"P$``!)````HP,``'P!````
M````\0``````````````U@4```````!D!P``0`<``&\!``";!```HP```"X'
M``"`!0```````&H'````````K`$```````!)!@```````"\```#Y`@``````
M`'$!````````W`$`````````````X`(````````(!@``#0$```X'``#9!```
M6@```/L!```=!```#P````$%``"/````'04`````````````!@0``%@&``!(
M!@``B@8```````!2`0``8@8``-P%```A!0``CP0``/L%``#0````````````
M``!X!@````````X!```V`@``]`8``+X!``!1`@``]`4``,8%``"/!P``H```
M````````````J0,``*@&``"+!0``G0,``+8%``!F!@```````.@#````````
M@`8``-`"``!N`````@$``$`#```9!P``C@8``````````````````#8#``"+
M````0`$``$T```!7!0``20$```````!1!````````-8"``"O````]P8``#D$
M``!#`0``O08``%D'``#;````EP0````````D````"`$``'T#``"7!@``````
M`#8!``"L!0``$0```!`$``#6!````````#$!``#,`0``N0(````````Y````
MO00`````````````#@0```D'``!*!P``4@<``$8'```L`@```````"4#``!G
M`@``F`0``-0#```@`@```````+X%``#B````"`,``'8!``#&!@``:08`````
M``#K`P``2P0``.("```X`P``0@$``.@```#"!````````$T"``!N`P``````
M`'H$````````5P(``(<$``#@``````````````"*!0``G`,``#<%``"?!0``
MNP$``/H%````````MP,``"L#``!%!@``UP4``)`"``!?!P```0(``"\&```'
M`P``(P4``*P"``!.`@```P8```````#:!0``,P8```````!S````B@0``/,!
M````````_0$`````````````^@```-0&``#N````-04``(0$``!J`P``;08`
M````````````3P0``&`"```3`0``00$``(`$````````M00``#8````J`P``
M4`$``$<%``!\!P``.P4``%H#``!\`P``U08``!(%```\`0``9`0``!('````
M`````````'T'````````<`<``.4"````````\P```#T"``!)!```)@$``(H#
M```#!```Z0(``,,&``#1`0``"0(``'\%```H!```_@,``-H$``#J!@``````
M``````!V`P```````/T````6!0``@@,``/\#``#/`@``-08``$P#``#8`P``
M40```&L$```&`P``(0,``.4&`````````````&<#``"+`P```````$L%````
M````4@```#H&``!L`@``(@,```````":`@``'@<````````/!P``>0$``%<`
M``#@!@``>@```"(%``!C!```R`(`````````````!P8``)P```!3`0``S@$`
M`($%```,!0``<@8```,#```C`@``.````%0%````````+0```(X'```D`@``
M`````"(!``!G`````````-X#``!3````*P4``"0!``````````````````!$
M!`````````@%``#U!0```````&@%```M!0````````````!$`````````%8!
M```W!P``Z@,``%H&```3!``````````````I!P```````(D```"T````W@``
M``````!U!@````````````!A!0``!P$````````.`@``````````````````
MYP$``)H```#,`P``W`,`````````````KP(``&8"``".!````````#P'````
M````600``!8#````````!@<``-H`````````T`0``/,$````````6`(`````
M``!@!```?00``,P&``#(!0``L@```"4$````````A`,``&<'``"U`````@4`
M`*H%```"!@``&@```'(%``!+````:@0``,4$``"^`P``6`,````````T`@``
M``````````"D`0```@````````"C!```````````````````X`,``%$%```H
M`P``30,``"$'``#:`0``^`0``/`%``!%`P``7P````````"L!@``%@``````
M```````````````````[````5````*4$```S!```TP(``+\"``#O!@``&P,`
M`(P```">`P``3`(```````!>!0```````%D#``#4!0```````(`"````````
M4`,``/`&``"G`P``TP```,\`````````X@8``((```#3!```!P0``%\"```<
M!0``8@<``.4$``#P!```50(``"X&``#"!@``5P0``,4!``!N!@```````$$$
M````````@P```)H$`````@``L08``%8#``"[````D@$``)X&````````````
M````````````A````(0&``!,`0``````````````````^P(```````"'`0``
MVP,````````R!0``[@(```\!``"%`0``&P8```````"P````&`8``&H!``"`
M`0```````)4```#?!```.P$``'L!``",`@``Q@(``+<$``!7!P```````$H"
M```.!@``Q@,``#0#```(`@``,`4``%$!``#'`P``%`<``$4$``!E!0``X0$`
M```````J`0``3@$``$P$``#7`0``GP,```$!``#'!0```````%<!``#.!0``
M>@,``*X#``#8````L0$``#T$```S`@``4@0```8%````````0P4``$0#``"E
M`0``D00``!\```"@`@``````````````````P0$``%H'``"<`0``^P8`````
M```9!0``[P$``'`!````````M`4``&P%``#8`@````8```````#9`0``````
M`/4#````````@08``"H$``!C````````````````````````````````````
MQ0(``/@#```8`@``T0,``!($``!C`@```````+T"`````````````&0#````
M````QP```!,"``!E!P``D`,``#\%``!4`P``/0``````````````(`8`````
M``#`!0``908``)8!``````````````,'``!Y`@```````+(!``"V````````
M`$<$``"#!```?@```*<%``#+`0```````/0#``"4!@``4`4```4'``"%!P``
M)@,``!4```"%`P``-P0``#L'``!=`@```````"@'``````````````````"U
M!@``\00``!\'``"7````(@0`````````````5`8``-,&``"[!```LP8``)\!
M```,````!`$``#$&``!!!P``V04``)@"````````P00``.,#``"S`0``_`0`
M``````!R!P```````&\#``!W!`````4``$H&``#$!```^0````````!4!P``
MW@(``!P&``#F````K08```````#6!@``_P0``-P$````````-0````4#``!3
M`@```````'4!```C!@````````4$``#3`0```````*4&``"&`P``/@$``,(#
M```\!0``C`8``````````````````(``````````A0```!<&``!U`P``````
M`.L$``"[`P```````(8&````````+@(``*X&``"2````3P8``)H#``!(!0``
M`````%8```#>`0``D@0``(P#``!2!0```````',"``!S`P``#08``!4!````
M````GP```(4$``````````````````!`!@```P4``)H%```^!P```````$8&
M``!@!@``````````````````J`,``)$%``"'!P``AP,``(X%``!^`@``````
M``L$````````<0(``%4%``#;!@``H`8``+$`````````$`(``)T!````````
M#`(``)T"````````$0$`````````````4P0``$@!``#=`@``^P0````````5
M!P``:P(```````#>!```-`8``%<#``!"!P``WP,`````````````W04``!8$
M``!O!@``K````!$"``"@!````````+,"````````S04``*@!``"W`@``YP8`
M`'`#``!=`0``Z0$``*`%```>`@````````````#C`@``'P0`````````````
MB`8``"0'`````````````/$%``!D`@```````,D!``!O`@``)P(``/$!``#`
M`@``(0$``!X#```2!@``.`8``%D```!=````;P4``-\!``#\`@``-P$``/4$
M```<!```````````````````X@$``-P"```-!```I04``*,!```$`@``?@,`
M`(\"``!C`P```````%`$``#J````O@```'`%````````R00``/P%``"8`0``
M``````````!L`0``%@8``#8%``"6`@````````````"P!0``F`,``#("``"K
M!````````'T%``"9!@``20<``/X!``!_````%P4``,<!``#^!@``;`8``!$$
M```3!0``%`$``.H!````````8`$``*X%``##`P``%`,```````!U`@``````
M`&8!`````````````(T'```M`P```````"0#``#*`@``:0,```````">````
M`````````````````````*H$``"U`0``L00``,X"````````30<``#D'``#S
M`P```````-($```N`P``&0,``($#``#0`P``-0<```````#,!0``]@(``$\`
M````````U@$```````!B````U`0```H"`````````````)0"``"0````````
M```````I!@```````,T"``"D`P``\`(``&,'``#9`````````&L'``#`!@``
M`````$H$```_!@```````.\"```I````AP(```````!]!@```````'H!```*
M!0``5P8``#$"`````````````-\"``"S!````````.0"``#-````#0```"\'
M````````900``,L%````````U@```.`!``"&`0``,P4``,<"``"2!0``<@,`
M``````#?!@``6P4``"4&`````````````.P`````````#04`````````````
M;0$```\"````````H08`````````````O`0``&`'``"#`@``$`8``$L'``#1
M!@``/0<```````"3`0``RP0```````"3`P```````#D!``"<!@``N0```*("
M``#U`@``/04``#\$`````0``3P(``%X'````````(`$``)D!``#2`P``!`0`
M`+@"``"_`P```````'$&``#+!@``SP0``),&````````&@4``.4%``"H````
M-`$``/\%```9!@``^0,``#$'```%`0``Y0$``"D!``"R!@````````````"I
M`@``Q`,``/<$````````+`$``$@"``">!0``'````!0"``"M`@``,`0``&P$
M``"(!```T`$``-<$``#B`P``+0(``&0````I!0``)@4``+H!``"6!@``4`8`
M`"("```A`@``.`4``.8$``#]!@``_`8``!````!:!````````$@#``!5!@``
M`````%(&````````Z04``($"``"N`0``,@,````````?!@``%P<`````````
M````O````$T%````````?@8``,D%``#G`@``JP8```````#A!@``%0(``.`$
M``"=!`````````````#Y`0``D0(``,X&```;````=0```+`#````````Z`$`
M`.\$``#L`P``XP````````"B````RP,``+`"``"6`P``E08`````````````
M6@4``.8#``!O!```6`0``/D%```?!0``)P<``*,&``"A!```_0(``*0"````
M````M0(``/\```"X`P```@,``.P$``#1!0````````````#\`P``E0(``&4!
M``!\!@``10<``/T$``##`0``Q@$````````8!P``W00```````!=!0``````
M`+\&``![`@``N@0``.L"```S`P``=`0``-T#``!K`0```````-4$``#G`P``
M^`$``+H%``#K!0``"0````````"+!P``R`8``+X$`````````````&("``!M
M````6``````````#````/@4```('````````^@8``,,```##`@```````)@&
M````````=P(````````]`P``````````````````P0(``*$!``".````104`
M`#0%```R!P``!@8``&@"```E`@``2@4```````"W!0````,```````#5`P``
M)0<``#0'``"+`@``B@$``.T$``"2!@``%P$```````#;`0````````````"D
M````808``!4%``"&`@```````.P%````````'0```!T&````````M`$`````
M``"'!0````````````"1`P``"@8``"\"``"4`````````'<!```_`0``````
M`!,&````````604``&,%``##!0``Y`8``(P'````````[04``.0$``"V!```
M]08``+(%````````)`4``%("```Z`0```````-H"````````1P(``#T&``#D
M!0```````(D&``#D````P@(``/T%````````D`4``$<```#N!0``00,`````
M``````````````````"1````.@<``&H"``"/!@``.`$``.8!``"*`@``````
M`%L```"'````(`<``+4%``#C`0``J`(``/(````S`0``&@<``&P'``"&!0``
M4@,``,0!`````````````*8!``#$!@```````$8#``#3!0``I@````````!S
M!0``U@,``&(!````````E00```````#P`````````*T$````````]P$``"8'
M``"X!0``BP$`````````````408``-L%```?`P````````````#J!```D0$`
M`+T%```0!0``=P4`````````````+0<``(0"``!@!0````````<```#P`P``
M1`8````````4!0``500``+P&``"B!0````````<"```M!@``<@0``(0'```Q
M`P``708````````U`@``,P<````````7``````````````"T!```S@```)@%
M``"\`@``)0$``&T'```1!P``[@$``%````!J!@````````<'```8!```2P,`
M`/D$`````````````.L````/!```!0(````````2`@```````'L$``!]`@``
M`````(,!```'!0```````!\"``"M`P``-@<``,,$````````8@,``#`'``!"
M`@``[@0``&``````````>`4``'@"``!"!````````'(```#\`0``@@0``#X#
M``"<!0``\@0``.4```#=!@```````#T!``"J`P``-P``````````````5`0`
M```````E````308``",'```>!@``Q04```````!@`P````````````#A`P``
M<0<``/<%````````G@(``((&```G!@```````/L````5!````````%\&``#'
M!@``Z@4`````````````G08```L#```3`P```````,L"``#8!0``)P0``!(#
M```V!@```````)<%`````````````$4```"H!```3@8``#$%````````````
M`,(```"W`0``KP0``!L"````````?@4```````"+!```T@(``+@````+!P``
M`````,$````J!P```````!H"``#5````$`,``/@&``#W`P``IP```$`%``#8
M`0``-P(``,0%`````````````,<$``#%`P``J00```````#?`````````(@%
M``!E`P``:P``````````````[P```+8!``!3`P```````%@!````````````
M``````"D!0``>@8```("````````204``#@"``!^!```JP````````"6!0``
M/P,``/T#``!T`P````````@$``"K`P``9P0``$\%``#-`0``$04```````#(
M`P``KP$``'(!````````]@8``````````````P$``%X#```I`P```````&,&
M```&`0```````)0#``!F`P``H@0``(D"``!M!0``S@,``%P"``#M!@``````
M`&X!``"9!```Q@```*$#``"%!0``]0````````"_````#@```&(%````````
M<04``!,```"9````:P,````````,!@```````*`#``#N!@``"@0``#D"````
M````50$``*8&``#!!0``Q0```(,#```+!@``)@8``%8%``!9`@``FP$``(4&
M```^!@``@`,``'T!```Q!```9P4``'<&``"#!@```````#L$``!_!```(@<`
M`!0&``"*!P```````/,"```\!```5`$```````#I`P``Y@(````````F````
M300```T#````````````````````````4`<````````B````^`4``&<&```N
M````O`$`````````````>@(``(0!``!I````0@4``)@`````````'`,`````
M``#M`0``C0(``-<`````````20(`````````````:0<``&$#``!&!0``/@0`
M``H#``"2`@````````````!_!P``004``!X$``![!P``=00``!8!``#2````
M*`8``%\#``"(!P```````&@'``"A!0``D08``.,&```<!P``1@0``"P'``!V
M````20,``,\!````````Z`4``"\!``#Z!```$`$``#P`````````````````
M````````\@8``.\%``#"!0```````#H%``#F!0```````!,'````````X00`
M`&8%```I!`````````````#)`P``=@0``*<"````````'`$``'8%``!%`0``
MQ08```@'````````S`0``$@````&````[0````````"&!```608``#H$```+
M`@``%````)X!``!3!0``]`0``%L'``"-`P```````/P`````````80(``.$%
M```:!@``^`````````#0!@``B`,``'0&```8`P``(`4``#P&``!A!P``1P8`
M`/H!``!E`@``4P<``','``"D!@```@0``'L```#_!@``6@(```````!H!```
M`````"H&``!M`@``\`$``#H````H`@```````.$"````````````````````
M````@0<``+$"```R````*P$```````#R`@``"P$``"`$```/!@``40,``*(!
M``!Y!P``M@8``,@```!<!@``;````*L"````````0P,```,"``!E````4P8`
M`(4"````````>P,``*,"``"U`P``Z0```*T!````````"P```!`'```)!0``
MK@0``"X%``!D`0````````````#`!````````%P$``"6````[@,``#P"````
M````K@```'0%````````;00``(\!````````\@$``'8'```1`P``K0```!<#
M````````>P4``-$$```2`0``+`,``%T$```9`@``I@4``&T#````````C00`
M``4````N!```!04```````!#!````0,``'4'```C`P``:@4``"\#``"0!```
M``````````````````````````!5`P```````-0"```.!0``3P,``#L&````
M````60$```````"G`0``XP4`````````````R@,``),"``"J````YP0``)D"
M``!8!P````````````"5`P``=@(``-\%``!V!@```````)P$``#T`@``9@``
M``````!*`P``"0,```````!<!0``1`4``+D&``#E`P``4`(``(,%````````
M`````#X"``"T`P``^@,``#8$``!D!0``Z`8``#<#``!<`P``R@0```````!=
M`P``00(``+`$``"E`P``+`````````"Q!0``Z`0``/<"````````"00``)D#
M``#S!0``V`8````````-`@``_P(``!$&``"(````'@$``+(#```$!P``^08`
M`)H&``#B!0````````````"@`0``*P8```P!````````NP8``-4%````````
M7P0``.T"``"?!@``LP,```@```!$`@``#P4``#\"``!!!@``I`0``'\#``#L
M`0``1@(``$@$``!K!0```````"4%``#-!```?@$`````````````-0,`````
M``!\`@``A@<```````".`@``UP,``!4&``#.!```(P$`````````````IP0`
M`$<'````````P`$``"<%```$!@````````````!&`0``E@0``",```#;!```
M``0``+L"``"I`0```````+`&```N`0``0`0``(T&````````@00`````````
M`````````!D```",!`````````````!Y!```3@0``"<#```=`0``YP4``-(&
M``#D`P```````)4%``"3!0``?`4``,$&````````!@(``$<#``"^`@``@P<`
M`$\'````````!08``%X````9!`````````$&``#_`0```````,P````6!P``
MT@4```````!N!```S08```````""`0``B0$````````I`@``-`0``$(```!W
M!P``_@0```````"]`0``:@```$`"``"_!```MP8``-<"````````````````
M```R`0``?@<``)`!``!#`@``C@$``*@%``!&````,`,``)<"``#!`P``5@8`
M````````````&````&D$``"Z`@``3@,``%8'````````````````````````
M`````*D%``!U!0``<@(``/(%````````5@(``&,!```G`0``V08``%@%``"I
M````70<`````````````N00``"@!```K````B00```````!"`P```````#D#
M```.`P``K`,``.L!```H!0``:P8````````Y!@``*@4```$'``!N`@``%@(`
M`(0%````````FP```,\&``#7!@``30$``+H```!;!@``,@0```````#4````
MB0<``/4!````````0```````````````7P$```L%``"O`P``1P$```````#Q
M`@```````.P"```D!@``&@$`````````````B04```````"=!0``=P```'D%
M``"B!@``BP8``'P$`````````````#(&``!_!@```````"T$```Z`P``%0,`
M`#D%``!L`P``*P<``(`'``""!0``G@0``&8'``!#`````````#X`````````
MYP```-L"``!T````>`,``+\%````````R0(``/8%````````O@8``'T```"J
M`0```````($``````````````'@```"5`0``-00```````!Y````K@(``/<`
M````````FP8``*H"```_````H@,``+<````U`0``=`<```````";!0``````
M`'<#````````O`4``%X$````("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@
M)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T
M97)D87DI`"!A="``(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E<R(@:7,@
M;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D(&EN
M('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO="!F
M;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E
M<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@
M=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S960@;V8@)2XR9DU"(&%L
M;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D(&1A>7,@=6YT:6P@>6]U
M<B!P87-S=V]R9"!E>'!I<F5S+@`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I
M8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E
M<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@
M)7,`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@
M;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE
M+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@
M=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E
M<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`)7,Z(%1H:7,@;65S
M<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E
M=V%R92!O9B!F;VQL;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I
M9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N
M+@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@
M)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@
M1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P!!(&1A=&%B87-E(&)A8VME;F0@
M:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S
M(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC
M<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV
M871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S
M:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3
M+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C
M<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@
M4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I
M9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@
M=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D<P!!32!,:6=H="!286EN
M`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`05!)
M($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M
M:61D;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!
M8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT($EN9F]R
M;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U
M;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO
M;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`
M061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P97)M:7-S
M:6]N('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE
M=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL
M;&$@4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D
M<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@
M8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I
M;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G
M(&EN(&YO=RX`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D
M9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O
M=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB
M86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!
M=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS
M`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO
M=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T
M<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R
M9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D
M<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;65R
M:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N
M('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N9&]R<F$`06YG;VQA`$%N
M9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC80!!;G1I
M9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`
M07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!
M<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`07)A8FEC("A7:6YD;W=S
M+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U
M('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F
M;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("(E<R(@
M86YD(&%N>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA
M;B`H05)-4T-)22TX*0!!<G0`07)U8F$`07-C96YS:6]N($ES;&%N9`!!<V-I
M:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO
M;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N
M;65N="!C;VQU;6YS`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M
M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES
M<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!
M='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q
M;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y
M<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET
M97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H
M+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@
M9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!296UO=FEN9R!U<V5R
M<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?
M;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H
M92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U
M<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U
M=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M06-T:79E($1I<F5C=&]R>2X`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB
M875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F86EL
M960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R
M96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&
M5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S
M97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)/
M1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME
M<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M
M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A
M<F)A9&]S`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD
M+@!"87-E;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU
M9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@
M(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L
M9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`
M0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`
M0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C
M96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL
M971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),($1I
M<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#86-H92!I
M;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#86QM`$-A;6)O9&EA
M`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL
M>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B!N;W0@=W)I=&4@
M=&\@9FEL92`B)7,B`$-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO
M;B!H86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`
M0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#86YC96P`0V%N8V5L(%!R
M;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@
M9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I
M=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D
M:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI
M<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE
M9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#
M86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E
M(%9E<F1E`$-A<'1I;VX`0V%R<FEE<@!#871E9V]R:65S(&%N9"!,86)E;',`
M0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L
M;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL
M<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@069R
M:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#
M97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E<G1I9FEC
M871E(%!O;&EC:65S`$-H860`0VAA;F=E`$-H86YG92!9;W5R(%!A<W-W;W)D
M`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@
M=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N
M9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@
M8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAI;&4`0VAI;F$`0VAI;F5S
M92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I
M9S4I`$-H;V]S92!!<'!L:6-A=&EO;CH`0VAO;W-E(&$@<&%S<W=O<F0`0VAO
M;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#
M:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAR
M:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N
M9"X`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!1=65R>0!#;&5A
M<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE
M87)I;F<@3&%T90!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(
M5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO=61S($5A<FQY`$-L;W5D>0!#
M;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&QA
M<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO
M=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA
M;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`
M0V]M<&%N>0!#;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG
M=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG
M('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN`$-O;F9I9W5R
M871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A
M<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O
M9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``
M0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#
M;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E
M87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D
M+@!#;VYT86-T<P!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T
M;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU
M90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!F86EL960Z("5S`$-O
M<'D@<V5L96-T:6]N`$-O<W0@240`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E
M`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4$=0
M('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A
M9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@
M861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R
M+@!#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<@!#;W5L9"!N;W0@8VAE
M8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE8W0@=&\@3$1!4"!S97)V
M97(N`$-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B`B)7,B('5S:6YG($94
M4#H@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`
M0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D96-R>7!T
M(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O
M=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO
M="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T
M(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O
M=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO
M="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T
M(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T
M<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK
M9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H
M92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N
M`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC
M95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S
M(BX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T
M(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H
M92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@
M87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N
M;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O
M;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`
M0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L
M9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`B
M)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N
M;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E
M(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S879E('1H
M92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V
M92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U
M<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O
M;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#
M;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N
M;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD
M(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W
M<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E<P!#;W5L9&XG="!F:6YD
M('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I
M<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S(B!T:&4@9F]L;&]W:6YG
M(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E<P!#;W5N=&5D('1E>'0`
M0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A
M(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO
M;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(#0@
M4&AA<V5S`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@
M55),(&ES`$-U<G)E;G0@57-E<G,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@
M8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@
M<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U
M<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#
M>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`
M1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G
M92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!$86EL>0!$871A5')E92!"
M<F]W<V5R`$1A=&%B87-E($QO;VMU<`!$871E`$1A=&4@4F5C96EV960`1&%T
M92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM
M86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A=6QT($-O
M;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!3:&5L;`!$969I;FET:6]N
M<P!$96QE=&4`1&5L971E($-E;&P`1&5L971E($=R;W5P`$1E;&5T92!,;V<`
M1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$
M96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E
M<FYA=&4@=&5M<&QA=&4`1&5L971E(&UE<W-A9V5S`$1E;&5T92!P97)M:7-S
M:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(@86YD
M(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R;W<`1&5L971E('-E;&5C
M=&5D(&ED96YT:71Y`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E
M('1H92!C=7)R96YT(')O=P!$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T
M("(E<R(N`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$97-C<FEB92!T:&4@4')O
M8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G
M9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN
M:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R
M(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T('1O(')I
M9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y
M(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&1E=&%I
M;&5D(&9O<F5C87-T`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F
M;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(&YO
M="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP
M:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S
M/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@
M4F5P=6)L:6,`1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+@!$;W=N
M;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA
M:6P`14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@
M=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N`$524@!%8W5A9&]R`$5D:70`
M161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E
M<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N
M<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E<R(`161I="!P97)M:7-S
M:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5I=&AE<B!E;F%B;&4@:70@
M=&AE;CH@)7,L(&]R('5S92!T:&4@8F%S:6,@2%1-3"!V97)S:6]N.B`E<RX`
M16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%;6%I;"!!9&1R97-S
M`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I
M<FUA=&EO;@!%;6%I;"UT;RU335,@1V%T97=A>0!%;6]T:6-O;G,`16UP='D@
M;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`16YA
M8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@
M:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YD
M('EE87(`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U<FET>2!Q=65S=&EO
M;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E
M="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO
M=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%;G1E<B!T:&4@
M;&5T=&5R<R!B96QO=SH`17%U871O<FEA;"!'=6EN96$`17)I=')E80!%<G)O
M<@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`17)R;W(@9&5L971I;F<@<WEN
M8R!A;F-H;W(Z("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<P!%<G)O
M<B!G971T:6YG(&-O;G1E;G0Z("5S`$5R<F]R('5P9&%T:6YG('!A<W-W;W)D
M.B`E<P!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R:71I;F<@
M(B5S(BX`17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E`$5V97)Y(#$U
M(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E
M<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R
M>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AP86YD`$5X<&%N
M9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E('=O<F0@;W(@
M<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%>'!O;F5N=`!&
M1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG
M('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E
M<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O
M(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL
M960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M
M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!R971R:65V93H@)7,`1F%I<@!&86QK
M;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%
M<G)O<CH`1F%X`$9A>&5S`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK
M93H@`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEE;&0@;6%T<FEX
M`$9I9VQE="!#05!40TA!`$9I9VQE="!F;VYT`$9I:FD`1FEL90!&:6QE($-O
M=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E
M<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U
M<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1FEN;&%N9`!&:7)S="!(
M86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``1FQO870`1F]G`$9O
M;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`1F]R(&)R
M;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R96-A<W0@*%1!
M1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E
M8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N=6UB
M97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*0!&;W)G;W0@
M>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R
M='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`1G(`1G)A;65S`$9R
M86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5N8V@@1W5I86YA`$9R96YC
M:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S`$9R;VT`
M1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M
M90!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'
M86UB:6$`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D
M90!'96]R9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`
M1VQO8F%L($]P=&EO;G,`1V\`1V]E9&5L`$=O;V=L92!-87!S`$=O;V=L92!3
M96%R8V@`1W)A>7-C86QE`$=R965C90!'<F5E:R`H25-/+3@X-3DM-RD`1W)E
M96YL86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M
M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D
M9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$=R
M;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,`1W)O=7!?;&1A
M<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<P!'<F]U<',`1W5A9&5L;W5P
M90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!097)M:7-S:6]N<P!'
M=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A434P`2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L
M;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E
M('1H92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10
M($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET
M:&T`2&%Z90!(96%D97(`2&5A9&5R<P!(96%R9"!)<VQA;F0@86YD($UC1&]N
M86QD($ES;&%N9',`2&5A=GD@5"U3=&]R;0!(96)R97<@*$E33RTX.#4Y+3@M
M22D`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES
M<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H
M`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO;64`2&]M
M92!!9&1R97-S`$AO;64@1&ER96-T;W)Y`$AO;64@4&AO;F4`2&]N9'5R87,`
M2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D
M871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO
M(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B
M.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO
M<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E
M+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G
M9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP
M92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S("(E
M<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA
M<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO<FEZ
M;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W
M(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2D`2&]W(&UA;GD@
M8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE
M;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@
M>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M;W)I
M<W1S`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`
M24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X
M('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@061D<F5S<P!)4"!!9&1R
M97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO
M=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`25]N<V5R
M="!2;W<@0F5F;W)E`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N<R!F;W(@)7,`
M26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@;F]T
M(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@
M=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E
M<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X
M('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S964@=&AI
M<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O
M('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!)
M;6%G92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!);6%G92!F<F]M
M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA
M9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T
M960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T:6]N
M(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O
M<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@
M5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO
M=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA`$EN
M9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M871I;VX`26YF
M;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92X`26YS97)T($-?;VQU;6X@
M069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI
M;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@
M869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F
M;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&%F=&5R('1H
M92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R
M<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT
M(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N
M;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M86EL
M(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S
M<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!)
M;G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R
M="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P87)A
M9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`26YS97)T(')O=R!B969O
M<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y
M('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@
M3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R
M:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E9V5R`$EN
M=&5G97(@;&ES=`!);G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!)
M;G9A;&ED(%I)4"!D871A`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@
M8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S
M=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED
M(&QI8V5N<V4@:V5Y+@!);G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+@!);G9A
M;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A
M;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R
M;6ES<VEO;BX`26YV86QI9"!P87)T;F5R(&ED+@!);G9A;&ED('!R;V1U8W0@
M8V]D92X`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!R96-I<&EE;G0Z("(E
M<R(`26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D<F5S
M<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R>0!);G9E<G0@<V5L
M96-T:6]N`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD
M`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`
M271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H
M25-/+3(P,C(M2E`I`$IA=F%S8W)I<'0@:&%S(&)E96X@9&ES86)L960@;VX@
M>6]U<B!B<F]W<V5R(&%N9"!T:&ES('!A9V4@;6%Y(&YO="!B92!D:7-P;&%Y
M:6YG(&-O<G)E8W1L>2X`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF
M>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU
M<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+
M97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE
M;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE
M;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$
M96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI
M8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U
M=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,
M87-T($AA;&8`3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R`$QA
M<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O
M;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,96%V
M92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T(&AE861E
M<@!,969T('9A;'5E<P!,97-O=&AO`$QE=F5L`$QI8F5R:6$`3&EB>6%N($%R
M86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG
M:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H
M="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3
M;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN
M=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@
M<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@
M+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T
M($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE
M;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB
M90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E
M<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!I<R!D
M:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A
M;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@
M;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N`$QO9R!O=70`3&]G:6X`3&]G:6X@
M5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P
M87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D
M+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E
M<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`3'5X96UB;W5R
M9P!-30!-3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T
M82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!2
M97!U8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-
M86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA
M;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O
M(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H
M('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M87``36%P
M<&EN9W,@<W1O<F5D+@!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS
M965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A
M;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C
M:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@
M8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@
M;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM
M=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,`36%X:6UU;2!L96YG=&@`36%Y
M`$UA>6]T=&4`365D:6-I;F4`365M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E
M;&QS`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T
M('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I
M960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&%R(%=E871H
M97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T
M(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@
M861M:6YI<W1R871O<BX`365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H
M;V0`365T:&]D("(E<R(@:7,@;F]T(&1E9FEN960`365T:&]D(&YO="!D969I
M;F5D+B!#86QL960@;65T:&]D.B`E<P!-971R:6,`365X:6-O`$UI8W)O;F5S
M:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@
M=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``
M36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9`!-:7)R
M;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E
M<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N
M97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T
M:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!
M4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE
M($UA:6P`36]D97)A=&4`36]D:69I960@1&%T90!-;V1I9GD@55),`$UO9'5L
M=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H
M(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E
M(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D
M+@!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!#
M;&]U9'D@86YD(%=I;F1Y`$UO<W1L>2!3=6YN>0!-;W9E($1O=VX`36]V92!,
M969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA
M;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:6UA<"!5
M2R!M87``375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`37D@06-C;W5N
M="!);F9O<FUA=&EO;@!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N
M;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`3F5P
M86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@
M0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@
M0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2
M979O8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A
M<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T
M>7!E`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`
M3F5W($UE<W-A9V4@=&\@)7,`3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I
M;VYA;"D`3F5W(%IE86QA;F0`3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W
M:6QL(&5X<&ER92!O;B`E>"X`3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"X`
M3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT
M(#0@4&AA<V5S`$YE>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`
M3FEG97)I80!.:6=H=`!.:75E`$YO`$YO(&%V86EL86)L92!C;VYF:6=U<F%T
M:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L
M92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E
M;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I
M=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE
M;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E
M9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@
M5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N
M`$YO(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N
M(&ES('-E="X`3F\@;&]C871I;VX@<')O=FED960N`$YO(&UE<W-A9V4@<W5P
M<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D
M+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T
M;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I
M;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`
M3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!Q=6]T82!S970N`$YO(')U;&5S`$YO
M('-E<&%R871O<B!S<&5C:69I960N`$YO('-I9&5S`$YO('-U8V@@9FEL90!.
M;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO
M('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@
M9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O
M<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I
M;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!2
M96=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI
M8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T
M:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W
M87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I
M;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1H
M:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R`$YU;6)E
M<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R
M;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES
M=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/8W1A
M;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@86YD(&YE=R!P
M87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P87-S=V]R9`!/;&0@
M<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`3VYL>2!)34%0('-E<G9E
M<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O9F9E;G-I=F4@9F]R
M='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY('1H
M92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W
M;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N
M(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT
M<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/<&5N<R!T:&ES
M(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N
M<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R
M9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A
M=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R
M`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H
M96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!014%2.CI-86EL(&)A8VME
M;F0`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!0
M1U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#
M;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-(%)A:6X`4$T@4VAO=V5R
M<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`
M4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<`4%](4"!3:&5L;`!0861D:6YG
M`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I
M960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R=&QY($-L
M;W5D>0!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`
M4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)
M55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N
M`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!0
M87-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P
M<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I
M;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`
M4&5R;6ES<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI
M<W-I;VX@1&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T
M<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P
M:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L871I='5D97,`
M4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H
M870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O
M;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0
M;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@
M82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V
M86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C
M:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@
M96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@
M;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@
M86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@
M66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T
M96TN`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`4&]L86YD
M`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@
M:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O('1H:7,@
M9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E8VEP:71A=&EO;B!F
M;W(@;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A=&EO;CQB<B`O/F-H86YC
M90!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N
M(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``
M4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W
M('=I;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A
M=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0
M<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U
M8FQI8R!+97D@26YF;P!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE
M<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!0=7)G92!M97-S86=E
M<P!1871A<@!1=65R>0!1=6]T80!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2
M861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN
M(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R
M='5N90!2871I;P!296%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E
M<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E
M;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A
M;FYO="!B92!U;F1O;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E
M<V@`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R
M=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!2
M96UA<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N
M97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V
M92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E
M('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O
M<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U
M;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L
M9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S
M=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+@!297%U:7)E9"`B)7,B
M(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@
M(B5S(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U
M:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q
M=6ER960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!0
M87-S=V]R9`!297-T;W)E($QA<W0@475E<GD`4F5S=6QT<P!2971U<FX@=&\@
M3W!T:6]N<P!2971Y<&4@;F5W('!A<W-W;W)D`%)E=6YI;VX`4F5V97)T($-O
M;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`
M4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I
M97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T
M871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z
M`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD
M(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N
M;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U
M<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@
M4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U=&AE
M;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,
M(%-H96QL`%-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',`4U-(`%-5
M0T-%4U,`4U]13"!3:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@2VET=',@
M86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L
M;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M
M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC
M:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`4V%V90!3879E
M("(E<R(`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N
M9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T
M96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3
M879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`4V-A='1E<F5D
M(%0M4W1O<FUS`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E;&5C
M="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!3
M96QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S
M97(@=&\@861D`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N
M=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&YO;F4`4V5L96-T('1H92!C
M:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@
M8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R
M96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T
M92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA
M;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I
M;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T
M('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N
M9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N96=A;`!3
M96YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA
M;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92X`
M4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N`%-E<W-I;VYS`%-E
M=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S
M=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R
M=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L
M+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D
M871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O
M;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA
M>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP=',@879A:6QA
M8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M
M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U
M;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO
M=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N
M9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S
M="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I;VX@=&\@
M:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A8FQE(&]P97)A=&EO
M;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H
M;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@
M5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R
M;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA
M;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S
M($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAR:6YK`%-H<FEN:R!O
M<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F
M:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`4VEG;F%T=7)E
M($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-L
M;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3:&]W97)S
M`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E
M<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO;B!)<VQA
M;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&]R9&5R('-E;&5C=&EO
M;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@
M*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD
M=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E
M;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O
M<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I
M;F<`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C
M96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3
M=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC
M90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME
M=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D
M<F5S<P!3='EL92!;0U-370!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U
M;F0N`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B
M)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y
M;W5R(')E<75E<W0@:&%S(&)E96X@87!P<F]V960N`%-U8G-C<FEP=`!3=6-C
M97-S`%-U8V-E<W-F=6QL>2!A9&1E9"`B)7,B('1O('1H92!S>7-T96TN`%-U
M8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H
M92!S>7-T96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F
M=6QL>2!R96UO=F5D("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L
M;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N
M9V5S+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN
M`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@
M9FEL92`E<RX`4W5C8V5S<V9U;&QY('5P9&%T960@(B5S(@!3=6-C97-S9G5L
M;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U
M;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3
M=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`
M4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z
M97)L86YD`%-Y;F,@;&]G(&1E;&5T960`4WEN8TU,`%-Y;G1A>"!E<G)O<B!I
M;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4
M+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L>0!44U8@
M9FEL90!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE(%-E=`!486)L92!P
M<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A
M:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z
M`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``
M5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP97)A='5R93QB<B`O/B@E
M<TAI)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E("(E<R(@;F]T(&9O=6YD
M+@!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!497AT
M(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AA
M;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4:&4@1E10(&5X=&5N<VEO
M;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES
M86)L960N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E
M<R!N;W0@<W5P<&]R="`B)7,B`%1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@
M:6YI=&EA;&EZ960N`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@
M;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S
M960N($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I
M9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W
M86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`
M5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T
M(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@
M8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S
M<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R
M97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES
M=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L
M969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D
M:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y
M<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO
M;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4
M:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4
M:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I
M;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H
M96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F
M=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I
M=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA
M="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E
M>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N
M8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U
M<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@
M>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N
M965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A
M<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL
M('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E
M;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O
M9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T
M7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I
M=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N
M;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R
M('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@
M=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E
M(&YU;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@
M=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E
M("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC
M965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@
M=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N
M9"!O;B!T:&4@<WES=&5M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@
M;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!R:6=H="!A;F0@;&5F="!S:61E
M<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5P87)A=&]R
M(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!S97)V97(@(B5S
M(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@
M<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M
M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="X`
M5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP;W)A
M<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!Y;W4@96YT
M97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN`%1H
M92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY
M`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U
M<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N
M`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5M
M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@;F\@;W!T
M:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B
M92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C
M=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A
M8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S
M(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M.B`E<P!4:&5R
M92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@(B5S(B!F
M<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG
M("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U
M<&1A=&EN9R`B)7,B.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE
M(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R
M9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN
M`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H
M92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A
M;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H
M97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!0
M97)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W
M87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@
M8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@
M=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R
M:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A
M;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI
M8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H
M92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O
M;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE
M(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M
M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F
M;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@
M<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R
M<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H
M92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A
M;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P
M87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@
M=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R
M(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R
M,S1A9B<N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`
M5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N
M(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C
M;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O
M<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E
M('9I<VET("5S`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A
M8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E
M<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC
M;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U
M<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M
M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO
M;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`
M5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`
M5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L
M(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@
M:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`
M5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O;R!M86YY(&EN=F%L:60@
M;&]G:6YS(&1U<FEN9R!T:&4@;&%S="!M:6YU=&5S+@!4;W``5&]P(&9R86UE
M("A?=&]P*0!4<F%N<VQA=&EO;G,`5')I;FED860@86YD(%1O8F%G;P!4<G5E
M(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y
M+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V
M86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%523"!F
M;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G
M86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG
M;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&
M4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@
M=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R(N`%5N86)L92!T;R!C:&5C:R!F
M:6QE('-I>F4@;V8@(B5S+R5S(BX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,
M('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T
M;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O
M<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B
M;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F
M;VQD97(@(B5S(BX`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`
M56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B
M)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E
M;&5T92`B)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C
M=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T
M;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!6
M1E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R("(E<R(N`%5N
M86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O
M(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A
M8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F
M:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA
M8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A
M9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A
M9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@
M<F5A9"!F:6QE.B``56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F
M;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O(')E;F%M92!61E,@9&ER
M96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4N
M`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B;&4@=&\@=')A;G-L871E
M('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D
M*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W
M<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"X`56YD97)L
M:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X
M<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5
M;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5
M;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI
M;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY
M:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!
M4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S
M86=E($E$*2X`56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U
M<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE
M;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S
M($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@
M<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T
M(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S
M8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N
M<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!U
M<V5R`%5P9&%T960@(B5S(BX`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L
M;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T
M:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N(&YU
M;6)E<G,`57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@
M;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5
M<V5R`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D
M;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5
M<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S
M:71E+@!5<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N86UE`%5S97)N86UE
M("(E<R(@86QR96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S
M97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D
M;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD
M(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W
M+@!686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L
M=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E
M;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA
M>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O
M;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A
M;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE
M=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FER
M9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES
M:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``
M5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E
M<RX`5TE.('9I82!(5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`
M5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A
M=&AE<BYC;VT`5V5B`%=E8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@
M=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R
M;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I
M;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE
M(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A
M8W1E<C\`5VAE<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC
M:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N
M`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N
M=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`
M5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN
M9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@
M`%=I<V1O;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE
M`%=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@
M)60L(&9O=6YD("5D+@!7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E
M9"`E9"P@9F]U;F0@)60N`%=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG
M(&$@5D93(&9I;&4N`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8
M-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R
M;F%T:79E($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P
M.78S(&5X=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE
M;@!997,`665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E
M('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9
M;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO
M8VMS+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N(&YO="!H
M879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@
M9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N
M)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T
M:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E96X@
M;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO
M;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F
M;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A
M($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O
M;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@
M<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R
M="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I
M;G1S('1O`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E
M9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`
M66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@
M=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C
M871E9V]R>2!N86UE+@!9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@
M<&AO;F4@;G5M8F5R`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE
M87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M
M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D
M<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@
M)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U
M('=I<V@@=&\@=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT
M<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0N`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S
M=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N
M(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R
M(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL
M('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@
M<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S
M=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA
M;F0@*R!0('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R
M(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D969A
M=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L;V=I;B!H87,@
M97AP:7)E9"X`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R
M(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O
M9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E
M9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D
M(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@
M=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!P87-S=V]R9"!H87,@97AP
M:7)E9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER90!:
M86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B
M;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@
M5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T
M:6]N`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``
M7TEM86=E(%!R;W!E<G1I97,N+BX`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y
M($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN
M+@!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@
M8F]O:P!A9&1R97-S964@=6YK;F]W;@!C86QE;F1A<@!C86QM`&-A;FYO="!C
M<F5A=&4@;W5T<'5T(&9I;&4`8V%N;F]T(&]P96X@:6YP=70`8VQI8VL@:&5R
M90!C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(`8V]N9FEG=7)A=&EO;B!E<G)O
M<@!C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG`&1A=&$@9F]R;6%T(&5R
M<F]R`&5D:70`96YT<GD@;F]T(&9O=6YD`&9A;&QI;F<`9FEL90!F<F]M('1H
M92`E<R`H)7,I(&%T("5S("5S`&=U<W1I;F<`:#H`:&@`:&]S="!N86UE('5N
M:VYO=VX`:6UM961I871E`&EN;&EN90!I;G!U="]O=71P=70@97)R;W(`:6YT
M97)N86P@<V]F='=A<F4@97)R;W(`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D
M92`E9"!W:&EL92!M86MI;F<@25-/+@!M;0!N86UE`&YO="!I;7!L96UE;G1E
M9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P97)M:7-S
M:6]N(&1E;FEE9`!P:7AE;',`<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L`')I
M<VEN9P!S97)V:6-E('5N879A:6QA8FQE`'-H;W<@9&EF9F5R96YC97,`<VUS
M,F5M86EL('9I82!(5%10`'-S`'-T96%D>0!S=VET8V@@;V9F(&IA=F%S8W)I
M<'0`<WES=&5M(&5R<F]R`'1A<VL@;&ES=`!T96UP;W)A<GD@9F%I;'5R90!T
M<GD@86=A:6X`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U
M;FEF:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC
M;VT`4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C$M8W9S"E)E<&]R="U-
M<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO
M;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T
M93H@,C`P-BTP,RTS,"`Q-CHQ,2LP,S`P"DQA<W0M5')A;G-L871O<CH@5&]O
M;6%S($%A<R`\=&]O;6%S+F%A<T!M86EL+F5E/@I,86YG=6%G92U496%M.B!%
M<W1O;FEA;B`\9&5V0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q
M+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y
M+3$S"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`"`H)7,@<.1E
M=F$@=&%G87-I*0`@*$MI:7)K;&%H=B`E<RD`("@E<R!PY&5V82!PY')A<W0I
M`"`H=.1N82D`("AH;VUM92D`("AE:6QE*0`@:VEI<G5S96=A(``B)7,B(&5I
M(&]L92!K871A;&]O9RX`(B5S(B!E:2!O;&4@=O5I;6%L:6L@=F%L:6LN`"(E
M<R(@96D@;VQE($AO<F1E(')E9VES=')I<R!HY.1L97-T871U9"X`(B5S(B!P
M=74@97-I=&%J870@96D@;&5I='5D+@`B)7,B(&QI<V%T:2!G<G5P<&ED92!S
M_'-T965M:2X`(B5S(B!L:7-A=&D@]6EG=7-T92!S_'-T965M:2X`(B5S(B!E
M:2!L;V]D=60Z("5S+@`E+C)F34(@:V%S=71A='5D(&MO:VMU("4N,F9-0BUS
M="`H)2XR9B4E*0`E9"`E<R!J82`E<P!3:6YU('!A<F]O;"!A96=U8B`E9"!P
MY&5V82!PY')A<W0N`"5D('#D979A(&5N;G5S='5S`"5S("T@5.1H96QE<&%N
M=0`E<R!S]7)M96KD;&<`)7,@2T(`)7,@:&]O;&1U<W3V]F0@+2!K:6YN:71U
M<P`E<R!P86EG86QD=7,`)7,@:V]N=&\@=&%O=&QE;6EN90`E<R!K87-U='5S
M=&EN9VEM=7-E9``E<R!O;B!J=6)A(&]L96UA<RX`)7,@:VEI<G5S96=A("5S
M("5S`"5S(&]N('9A;&UI<R!T96=E;6$@86QL<&]O;"!L;V5T;&5T=60@:&]O
M;&1U<W3V]F0N($WD<F=I<W1A('3V]F0L(&UI9&$@<V]O=FED('!R865G=2!T
M96AA+@`E<R!O;B!K;VAU<W1U<VQI:P`E<R!M:6YU=&ET`"5S(&5I(&QE:71U
M9"X`)7,@:W5N:2`E<R`E<RUS=`!+87-U=&%J82`E<R!A861R97-S:7)A86UA
M=`!+87-U=&%J82`E<R!K86QE;F1E<@!+87-U=&%J82`E<R!MY')K;65D`$MA
M<W5T86IA("5S(/QL97-A;F1E9``E<SH@)7,`)7,Z(%-E92!T96%D92!E:2!P
M<G5U9VD@;VQL82!S86%T:F%L="P@:V5L;&5L="!S964@<&%I<W1A8B!O;&5V
M870N(,1R82!K:6ER=7-T82!K;/5P<V%M82!S96QL97,@97-I;F5V86ED(&QI
M;FME(';U:2!E<VET86UA('-A871J86QE(&UI;F=I=&ES:6ML:6MK=2!I;F9O
M="X`+"!T=75L96EI;&ED(``L('1U=6QE:6EL:60@)7,@)7,`+"!V86AE;6EK
M=7,@)7,@:W5N:2`E<P`M+2!V86QI("TM`#$R+71U;FYI;F4@97-I='5S`#(T
M+71U;FYI;F4@97-I='5S`#(T('1U;F1I`#Q%96QM:6YE`%-E92!B;&]K:R!V
M86IA8B!A;F1M96)A87-I('1U9V4N`$IU:'1U<R!K;VAU=&%V('9I9V$`2VER
M:F$@:W+\<'1E97)I;6ES96MS(&]N('9A:F$@879A;&EK:W4@4$=0(';U=&ET
M+@!!;&QK:7)J82!K;VYT<F]L;&EM:7-E:W,@;VX@=F%J82!A=F%L:6MK=2!0
M1U`@=O5T:70N`$MR_'!T965R:71U9"!K:7)J82!A=F%M:7-E:W,@;VX@=F%J
M82!A=F%L:6MK=2!01U`@=O5T:70L('-A;&%J87-T(%!'4"!V]71I="!J82!S
M86QA<_5N82X`2VER:F$@86QL:VER:F%S=&%M:7-E:W,@;VX@=F%J82!A=F%L
M:6MK=2!01U`@=O5T:70L('-A;&%J87-T(%!'4"!V]71I="!J82!S86QA<_5N
M82X`2W+\<'1E97)I='5D(&MI<FIA(&%V86UI<V5K<R!O;B!V86IA(&%V86QI
M:VMU(%,O34E-12!V]71I="P@<V%L86IA<W0@4R]-24U%(';U=&ET(&IA('-A
M;&%S]6YA+@!+:7)J82!A;&QK:7)J87-T86UI<V5K<R!O;B!V86IA(&%V86QI
M:VMU(%,O34E-12!V]71I="P@<V%L86IA<W0@4R]-24U%(';U=&ET(&IA('-A
M;&%S]6YA+@!+:7)J82!K<OQP=&5E<FEM:7-E:W,@;VX@=F%J82!A=F%L:6MK
M=2!3+TU)344@=O5T:70`14P@<&EL=FEN90!%3"!K97)G92!V:6AM`$5,('9I
M:&T`14P@:&]O=FEH;0!%3"!T=6=E=B!L=6UE<V%D=0!%3"]03`!!4$D@240`
M4V5L;&4@961I=&]R:2!I;F9O`$EN9F\N+BX`06)S8F]T=&]M`$%B<VUI9&1L
M90!61E,@:V%T86QO;V=I(&QO;VUI<V5K<R!J=75R9&5PY.1S(&ME96QA='5D
M`%9&4R!F86EL:2!L;V]M:7-E:W,@:G5U<F1E<.3D<R!K965L871U9"X`2V]N
M=&\@:6YF;P!+;VYT;R!S86QA<_5N80!+;VYT;R!L=6MU<W1A='5D+@!286%M
M871U<&ED86UI;F4`3&ES80!,:7-A(&%L86UG<G5P<`!,:7-A(&%L86WU:6=U
M<P!,:7-A('-I:6$Z`$QI<V$@=75S(&=R=7!P`$QI<V$@=75S(/5I9W5S`$QI
M<V$@9W)U<'`@(B5S(B!A;&QA`$QI<V$@]6EG=7,@(B5S(B!A;&QA`$QI<V$@
M=75S(&MA<W5T86IA.@!,:7-A('9E97)G`$QI<V$@=75E9"!L:6EK;65D`$QI
M<V$@<&%A<@!4964@)7,@;65N_/P@36]Z:6QL82!K_&QG<FEB86MS`$QI<V$@
M86%D<F5S<VER86%M871U<W-E.@!,:7-A(&UI;G4@86%D<F5S<VER86%M871U
M<W-E`$QI<V$@:V%S=71A:F$`(B5S(B!L:7-A=&D@<_QS=&5E;6DL(&MU:60@
M=.1I96YD879A="!L:6ET=6UI<VEN9F]T('!O;&YU9"!V]6EM86QI:R!L:7-A
M9&$Z("5S+@`B)7,B(&QI<V%T:2!S_'-T965M:2X@3OS\9"!V]6ED('-I<W-E
M(&QO9VED82X`2V%S=71A:F%T92!L:7-A;6EN92!P;VQE(&QU8F%T=60N`$%A
M9')E<W,`06%D<F5S<VER86%M870`2&%L9'5S("T@;75U9&$@=&5I<W1E(&MA
M<W5T86IA=&4@]6EG=7-I`$AA;&1U<P!296ML86%M`$%F9V%N:7-T86X`06QB
M86%N:6$`06QZ965R:6$`06QI87,`2F]O;F1U<P!*;V]N9'5S.@!+]6EK`$OU
M:6L@<VES<V5L;V=I='5D(&MA<W5T86IA9`!+]6EK(&=R=7!I9`!+]6EK(/5I
M9W5S960`2_5I:R!N96QI(&O\;&=E`$QU8F$@;6ET=70@86%D<F5S<VD`3'5B
M82!MY.1R871A(&KD<FIE<W1A='5D(&QO96YD:2!T_/QP`$]N(&IU8F$@;VQE
M;6%S`$%L=&5R;F%T:6EV;F4@24U34"!K;VYT;P!!;'1E<FYA=&EI=FYE($E-
M4U`@<V%L87/U;F$`06QT97)N871I:79N92!)35-0(&MA<W5T86IA;FEM:0!!
M;'1E<FYA=&EI=FYE(&4M<&]S=&D@86%D<F5S<P!!;'1E<FYA=&EI=G-E9"!M
M86QL:60`06QT97)N871I:79N92!T96MS=#H`06UE97)I:V$@4V%M;V$`4VES
M97-T871I(&QU8F%M871U(';DY')T=7,N`$IU:'1U<R!T=6YD;6%T=2!V:6=A
M`$%N9&]R<F$`06YG;V]L80!!;F=U:6QL80!!;F]N_/QM;F4@=F%H96YD86IA
M`%9A<W1U<P!!;G1A<FMT:6MA`$%N=&EG=6$@:F$@0F%R8G5D80!286ME;F1U
M<P!286ME;F1U<W1E(&YI;65K:7)I`%)A:V5N9'5S(&]N('3V]G9A;&UI<RX`
M4F%K96YD82!A;&%M:F%G=61E;&4`2VEN;FET80!,:6=I:V%U9&YE('-U=7)U
M<P!!<')I;&P`07)A86)I82`H5VEN9&]W<RTQ,C4V*0!!<FAI:79I('-U=7)U
M<P!!<FAI:79I(&YI;6D`3VQE9"!S82!K:6YD96P@970@<V]O=FED("5S(&QI
M:71U;6ES<V]O=FD@:W5S='5T861A/P!/;&5D('-A(&MI;F1E;"!E="!S;V]V
M:60@:W5S='5T861A(&=R=7!I("(E<R(@:F$@:_5I:R!T96UA(&%L86UG<G5P
M:60_`$%R9V5N=&EI;F$`07)M965N:6$`07)M965N:6$@*$%235-#24DM."D`
M2W5N<W0`07)U8F$`3&EH87;U='1E<V%A<@!!4T-)22!J;V]N:7-T=7,`06%S
M:6$O5F%I:W-E(&]O:V5A;FD@<&EI<FMO;F0`2_QS:2!H;V]L9'5S=/;V9&4@
M=&5G96UI<V5K<R!K:6YN:71U<W0`5F5E<G5D`$MA='-E(&MU<W1U=&%D82!O
M;&5M871U="!G<G5P<&DN`$MA='-E(&MU<W1U=&%D82!O;&5M871U="#U:6=U
M<W0N`$MA='-E(&UU=71A(&]L96UA='5T(/5I9W5S="X`2V%T<V4@;75U=&$@
M;VQE;6%T=70@:F%G=2X`071R:6)U=61I9`!!=6=U<W0`075S=')A86QI80!!
M=7-T<FEA`$%U=&A?8WER<W%L.B!V86IA;&EK:W4@24U!4"!L86EE;F1U<W0@
M96D@;&5I='5D+@!!=71H7V-Y<G5S.B!S_'-T965M:6P@<'5U9'5V860@=F%J
M86QI:W5D(';U:6UE9"X`075T:%]C>7)U<SH@=F%J86QI:VMU($E-05`@;&%I
M96YD=7-T(&5I(&QE:71U9"X`075T:%]F='`Z(%9A:F%L:6MK=2!&5%`@;&%I
M96YD=7-T(&5I(&QE:71U9"X@2V]M<&EL965R:2!02%`@=O5T;65G82`M+65N
M86)L92UF='`N`$%U=&A?:6UA<#H@5F%J86QI:VMU($E-05`@;&%I96YD=7-T
M(&5I(&QE:71U9"X`075T:%]K<F(U.B!686IA;&EK:W4@:W)B-2!L86EE;F1U
M<W0@96D@;&5I='5D+@!!=71H7VQD87`Z($%C=&EV92!$:7)E8W1O<GDG<W-E
M(&MA<W5T86IA=&4@;&ES86UI<V4@='5G:2!P=75D=6(`075T:%]L9&%P.B!!
M8W1I=F4@1&ER96-T;W)Y<W0@:V%S=71A:F%T92!E96UA;&1A;6ES92!T=6=I
M('!U=61U8@!!=71H7VQD87`Z(%9A:F%L:6MK=2!,1$%0(&QA:65N9'5S="!E
M:2!L96ET=60N`$%U=&A?;&1A<#H@16D@<V%A(&QI<V%D82!K87-U=&%J870@
M)7,N(%-E<G9E<B#\=&QE<SH@`$%U=&A?;&1A<#H@16D@<V%A(&5E;6%L9&%D
M82!K87-U=&%J870@)7,`075T:%]L9&%P.B!%:2!S86$@;75U=&$@:V%S=71A
M:F%T("5S`$%U=&A?;&1A<#H@06-T:79E($1I<F5C=&]R>2!K87-U=&%J871E
M(&UU=71M:7-E('1U9VD@<'5U9'5B+@!!=71H7VUC86PZ(%9A:F%L:6MK=2!-
M0T%,(&QA:65N9'5S="!E:2!L96ET=60N`$%U=&A?<VUB875T:#H@5F%J86QI
M:VMU('-M8F%U=&@@;&%I96YD=7-T(&5I(&QE:71U9"X`4VES<V5L;V=I;6EN
M92!N=7)J=7,`4VES<V5L;V=I;6EN92!N=7)J=7,N("5S`%)!1$E54R!S97)V
M97(@96D@;'5B86YU9"!S:7-S92!L;V=I9&$N`$944"!S97)V97)I<W-E('-I
M<W-E;&]G:6UI;F4@;G5R:G5S+@!334(@<V5R=F5R:7-S92!S:7-S96QO9VEM
M:6YE(&YU<FIU<RX`2V%S=71A=&%V860@=N1L:F%D.@!!<V5R8F%I9'IA86X`
M0D]&2"!E='1E:^3D;F1E9`!4875S=`!4875S=&$@=N1R=@!686QE(&ME<F)E
M<F]S92!S86QA<_5N82X`5F%L92!K97)B97)O<V4@:V%S=71A:F%N:6UI+@!"
M86AA;6$`0F%H<F5I;@!"86QT:2`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`
M0F%R8F%D;W,`1W)A869I:V$@</5H:6MA=&%L;V]G:2`B)7,B(&5I(&QE:71U
M9"X`0F%S96QI;F4`5F%L9V5V96YE`$)E;&=I80!"96QI>F4`0F5N:6X`0F5R
M;75D80!":'5T86X`4_QN;FEPY&5V`$)L;VMK:2`B)7,B(')A:V5N9'5S97,@
M(B5S(B!E:2!L96ET=60N`$)L;VMI(&CDY&QE<W1U<P!";&]K:2!T_/QP`%!A
M:W,@:VER:0!";VQI:79I80!*Y')J96AO:61J860`4&EI<FIO;VX`2F]O;F4@
M<&%K<W5S.@!0:6ER:F]O;F5D`$)O<VYI82!J82!(97)T<V5G;W9I:6YA`$WU
M;&5M860`0F]T<W=A;F$`06QL80!";W5V970@<V%A<@!"<F%S:6EL:6$`0G)I
M=&D@26YD:6$@3V]K96%N:2!497)R:71O;W)I=6T`0G)U;F5I(%-U;'1A;FER
M:6EK`$)U;&=A87)I80!,;V5T96QU`$)U<FMI;F$@1F%S;P!"=7)U;F1I`%-I
M<W5H86QD=7,`0U)#`%3\:&ES='5S;FEM96MI<FIA(&IA;W1U<W!U;FMT:60`
M3%]A:'1R:2!O;6%D=7-E9"XN+@!686AE;>1L=2!I;FET<VEA;&ES965R:6UI
M;F4@96D@:O5U9&YU9"!L]7!U;&4N`$MA;&5N9&5R`%9A:6MN90!+86UB;V1Z
M:&$`2V%M97)U;@!087)O;VQI(&5I('-A82!A=71O;6%A='-E;'0@=/QH:7-T
M861A+"!V]71A(/QH96YD=7-T(&%D;6EN:7-T<F%A=&]R:6=A+@!%:2#U;FYE
M<W1U(&MI<FIU=&%D82!F86EL:2`B)7,B`%;D;&ES96ED('-E<W-I;V]N:6AA
M;&1U<F5I9"!P;VQE(';U:6UA;&EK(&%D;6EN:7-T<F5E<FED82X`16D@<V%A
M(/QH96YD=7-T($E-05`@<V5R=F5R:6=A.B`E<P!%:2#U;FYE<W1U(&%V861A
M(&9A:6QI("(E<R(`2V%N861A`$QO;V)U`$QO;V)U`$5I(/5N;F5S='4@:W5S
M='5T861A(&9A:6QI("(E<R(N`$5I(&QE:6$@86IU=&ES="!K871A;&]O9VD`
M26QM82`G=&%R9V5T1FEL92<@<&%R86UE971R:71A(&5I('-A82!JY'1K871A
M+@!%:2#U;FYE<W1U(&5E;6%L9&%D82!K871A;&]O9VD@(B5S(BX`16D@<V%A
M(&5E;6%L9&%D82P@)60M;"!O;B!A;&QU=F%I9"X`16D@<V%A(/QM8F5R(&KD
M<FIE<W1A9&$L(/QM8F5R:N1R:F5S=&%M:7-E:W,@;>3D<F%T=60@:V%N;F5T
M92!A<G8@96D@:VQA<&D@<V%L=F5S=&%T=60@87)V=6=A+@!%:2!S86$@<W5U
M;F%T82!T96%D970@;>3D<F%T=60@;G5M8G)I;&4N`%)O:&5L:7-E($YE96UE
M('-A87)E9`!096%L:VER:0!4965N=7-E<&%K:W5J80!+871E9V]O<FEA9"!J
M82!MY')G96YD:60`0V%Y;6%N:2!386%R960`36]B:6EL=&5L969O;@!,86AT
M<FD@;VUA9'5S960`3&%H=')I('9O;V1E<F1U<SH`3&%H=')I(&]M861U<V5D
M`$QA:'1R:71E('9A:&5K875G=7,Z`$UO8FEI;'1E;&5F;VX`2V5L=&D@*$E3
M3RTX.#4Y+3$T*0!+97-K96QE`$ME<VLM06%F<FEK82!686)A<FEI:P!+97-K
M+45U<F]O<&$@*$E33RTX.#4Y+3(I`%-E<G1I9FEK86%D:2#\:W-I:V%S:F%D
M`%-E<G1I9FEK86%D:2!O;6%N:6L`4V5R=&EF:6MA861I('!O;&EI=&EK860`
M5'-H86%D`$UU=61A`$UU=61A('-A;&%S]6YA`$UU=61A(&YI;64@:F$@86%D
M<F5S<VD@;6ED82!I;FEM97-E9"!NY&5V860@:W5I(&YA9"!S:6YU(&MI<FIU
M(&QO979A9"!J82!N96EL92!V87-T879A9"X`4_QS=&5E;6D@:V]N9FEG=7)A
M='-I;V]N(&5I(';U:6UA;&1A('-A;&%S]6YA(&UU=71A+B!6]71A(/QH96YD
M=7-T("!A9&UI;FES=')A871O<FEG82X`3>1R:P!?2V]N=')O;&QI(&QI;FMI
M+BXN`%1S:&EI;&D`2&EI;F$`2&EI;F$@;&EH='-U<W1A='5D("A'0C(S,3(I
M`$AI:6YA('1R861I='-I;V]N:6QI;F4@*$)I9S4I`%9A;&D@<F%K96YD=7,Z
M`%9A;&D@<V%L87/U;F$`5F%L:2!K87-U=&%J86YI;6D`5F%L:2!K=75PY&5V
M861E(&5S:71U<W9I:7,Z`%9A;&D@;&]E;F1I('-T:6EL("AJY')J97-T871U
M9"!L;V5N9&ET92!J86]K<RD`2O5U;'5S86%R960`2VQA<W-I("5S(&MI<FIE
M;&1U<W0@96D@;&5I='5D+@!396QG90!%96UA;&1A($U33V9F:6-E(&WD<F=E
M;F1I9`!4_&AJ96YD82!PY')I;F<`165M86QD82!K87-U=&%J83H@)7,`165M
M86QD82!K87-U=&%J80!4_&AJ96YD82!K87-U=&%J82!A;F1M960`U6AT=6P@
M<V5L9VEN96(`2VSU<'-A(&KD=&MA;6ES96MS`$-L:6-K871E;&P@_&QE($A4
M5%``4W5L92!A:V5N`%!I;'9E9`!(;VUM:6MU;"!P:6QV97,`4&EL=F5S`$MO
M;VMO<W-A87)E9"`H2V5E;&EN9VD@<V%A<F5D*0!096ED82!K_&QG<FEB80!0
M96ED971U9"!P:6ER:F]O;F5D`$MO;'5M8FEA`%;D<G8`5N1R=FEV86QI:P!6
MY')V:2!V86QI:P!6965R9V4Z`%9E97)G=61E('!E86QK:7)J860`2V]O;6EK
M<VED`$OD<VL`2^1S=7)I9&$`2V]M;65N=&%A<@!,:6AT;FEM:0!+;VUO;W)I
M9`!&:7)M80!!<G9U=&ED`$EL;0!);&T`2V]N9FEG=7)A='-I;V]N:2!E<FEN
M979U<V5D`%-E861I<W1U<R!S_&YK<F]N:7-E97)I;6ES96MS(%!$061E+"!N
M=71I=&5L969O;FED92!J82!/=71L;V]K:6=A+@!396%D:7-T=7,@;VX@865G
M=6YU9"X`4V5A9&ES=&$@)7,`2VEN;FET82!S86QA<_5N80!+;VYG;P!+;VYG
M;R!$96UO:W)A871L:6L@5F%B87)I:6L`W&AE;F1U<R!N=7)J=7,N`-QH96YD
M=7,@;G5R:G5S.B``079A;&EK(';U=&UE<V5R=F5R(&5I(&%N;F$@_&AE;F1U
M<W0N`$%V86QI:R!V]71M97-E<G9E<B!E:2!A;FYA(/QH96YD=7-T+B!0]6AJ
M=7,Z("5S("@E<RD`W&AE;F1U<R!&5%`@<V5R=F5R:6=A(&YU<FIU<RX`2V]N
M=&%K=&ED`$MO;G1A:W1I9"#U;FYE<W1U<R!L:7-A9&$@<VEN=2!A861R97-S
M:7)A86UA='5S<V4N`"(E<R(@<VES=0!*Y'1K80!#;V]K:2!386%R960`3?5T
M=&5T97)A`$MO<&5E<FD`2V]P965R:6UI;F4@;G5R:G5S.B`E<P!+;W!E97)I
M('9A;&EK`$-O<W0@240`2V]S=&%R:6EK80!#;W1E(&0G279O:7)E`$5I('-A
M86YU9"!K:7)J82!01U!G82!K<OQP=&ED82X`16D@<V%A;G5D(&MI<FIA(%!'
M4&=A(&%L;&MI<FIA<W1A9&$N`$5I('-A86YU9"!K:7)J82!3+TU)345G82!K
M<OQP=&ED82X`16D@<V%A;G5D(&MI<FIA(%,O34E-16=A(&%L;&MI<FIA<W1A
M9&$N`$5I('-A86YU9"!L:7-A9&$@:V]N=&%K=&DN("5S`$5I('-A86YU9"!S
M:7-S92!,1$%0('-E<G9E<FES<V4N`$5I('-A86YU9"!S:7-S92!,1$%0('-E
M<G9E<FES<V4`16D@<V%A;G5D(&MO;G1O:N3D:VD@:V]N=')O;&QI9&$N("5S
M`$5I('-A86YU9"#\:&5N9'5S="!,1$%0('-E<G9E<FEG82X`16D@<V%A;G5D
M('-E<G9E<FEG82`B)7,B($944"!A8FEL(/QH96YD=7-T.B`E<P!*86]T=7-N
M:6UE:VER:F$@;&]O;6EN92!N=7)J=7,N("5S`$5I('-A86YU9"!01U`@86YD
M;65I9"!D96MR_'!T:61A+@!%:2!S86%N=60@4R]-24U%(&%N9&UE:60@9&5K
M<OQP=&ED82X`16D@<V%A;G5D(&MU<W1U=&%D82!K;VYT86MT:2X@)7,`16D@
M<V%A;G5D(&MU<W1U=&%D82!J86]T=7-N:6UE:VER:F$N("5S`$5I('-A86YU
M9"!K=7-T=71A9&$@<&%I9V%L9'5S92!U=65N9&%M:7-E('-K<FEP=&D@(B5S
M(BX`16D@<W5U=&YU9"!VY&QJ82!S96QG:71A9&$@861R97-S86%D:2!E+7!O
M<W1I(&%A9')E<W,`2V]G=2!A861R97-S:7)A86UA='4@:V]H86QE=&ER:6UI
M;F4@;G5R:G5S+@!+;V=U(&IA;W1U<VYI;65K:7)J82!K;VAA;&5T:7)I;6EN
M92!N=7)J=7,N`$MO9W4@:F%O='5S;FEM96MI<FIA9&4@;FEM96MI<FIA(&MO
M:&%L971I<FEM:6YE(&YU<FIU<RX`16D@]6YN97-T=6YU9"!L86%D:61A('-T
M<F%T965G:6%T("(E<R(N`&UK9&ER("(E<R(@;G5R:G5S+@!%:2!S86%N=60@
M=O5T;65S97)V97)I<W0@879A;&EK:W4@=O5T:70@:^1T=&4N`"(E<R(@879A
M;6EN92!K:7)J=71A;6ES96MS(&YU<FIU<RX`)7,@879A;6EN92!N=7)J=7,N
M`$5I('-U=71N=60@:^1I=FET861A(&AO;VQD=7-T]O8@;6]O9'5L:70@)7,`
M16D@<V%A;G5D(&%V861A(&MA=&%L;V]G:2`B)7,B+@!%:2!S86%N=60@:^1T
M=&4@3$1!4"!S97)V97)I="X`)7,@;'5G96UI;F4@;G5R:G5S+@!3;V]V:71U
M9"!K87-U=&%J82!P87)O;VQI('3\:&IE;F1A;6EN92!N=7)J=7,N($WU;F5D
M(&%N9&UE9"!E:2!O;&4@]6EG960N(%!R;V]V:2!U=65S=&D@=O5I(';U=&$@
M_&AE;F1U<W0@861M:6YI<W1R86%T;W)I9V$L(&MU:2!V86IA9"!S:6ES:VD@
M86)I+@!!0TQI(&QA861I;6EN92!E8F'U;FYE<W1U<P!!861R97-S:7)A86UA
M='4@;&%A9&EM:6YE(&5B8?5N;F5S='5S+B`E<P!*86]T=7-N:6UE:VER:F$@
M;&%A9&EM:6YE(&5B8?5N;F5S='5S+B`E<P!*86]T=7-N:6UE:VER:F%D92!L
M86%D:6UI;F4@96)A]6YN97-T=7,N("5S`%-E<G9E<FD@=O5I;6%L=7-T92!L
M86%D:6UI;F4@96)A]6YN97-T=7,`2V]N9FEG=7)A='-I;V]N:2!T86=A<VEM
M=75T;6EN92!N=7)J=7,N`')M9&ER("(E<R(@96D@]6YN97-T=6YU9"X`)7,@
M<V5A9&ES='5S92!S86QV97-T86UI;F4@;G5R:G5S+@!+;VYF:6=U<F%T<VEO
M;VYI('9A<G5K;V]P:6$@<V%L=F5S=&%M:6YE(&YU<FIU<RX`2V]N9FEG=7)A
M='-I;V]N:2!V87)U:V]O<&EA('-A;'9E<W1A;6EN92!N=7)J=7,Z("5S`%!A
M:6=A;&1U<V4@=75E;F1A;6ES92!S:W)I<'1I(&5I('-A86YU9"!S86QV97-T
M861A(&MO:'1A.B`B)7,B+@!%:2#U;FYE<W1U;G5D('-A;'9E<W1A9&$@:V]N
M9FEG=7)A='-I;V]N:69A:6QI('9A<G5K;V]P:6%T("5S+@!+;VYF:6=U<F%T
M<VEO;VYI9F%I;&D@)7,@96D@]6YN97-T=6YU9"!S86QV97-T861A+B!382!V
M]6ED(&MA<W5T861A(/QH="!V]6EM86QU<W0@:V]O9&D@<V%L=F5S=&%M:7-E
M:W,@=&%G87-I(&9A:6QI("5S(';U:2!K;W!E97)I9&$@:V]O9"!KY'-I='-I
M(&9A:6QI("5S+@!,1$%0(&]T<VEN9R!N=7)J=7,N`'5N;&EN:R`B)7,B(&YU
M<FIU<RX`2V]N=&%K=&D@=75E;F1A;6EN92!N=7)J=7,N("5S`$IA;W1U<VYI
M;65K:7)J82!U=65N9&%M:6YE(&YU<FIU<RX@)7,`(B5S(B!S96%D:7-T=7-E
M('-A;'9E<W1A;6EN92!N=7)J=7,Z("5S`$5I(&QE:61N=60@36]Z:6QL82!K
M_&QG:7)B82X@5F%A=&$@970@:_QL9W)I8F$@;VQE:W,@879A='5D+@!+87-U
M=&%J86QE("(E<R(@96D@<V%A;G5D(&%N9&$@:N1R9VUI<VD@]6EG=7-E:60@
M:V%U<W1A;&4@(B5S(CH@)7,`4&EI<F%T=60@<&EK:W5S96=A('1E:W-T`%)I
M:6L`2W5R<W5S960`3&]O`$QI<V$@;&EN:P!,:7-A('5U<P!,:7-A(&%L86UK
M875S=&%D`$%U=&]R:2#U:6=U<V5D`$MR961I:71K86%R9&D@;G5M8F5R`$AO
M<G9A871I80!+=75B80!0<F%E9W5S960@-"!F86%S:0!!:W1I:79S960@<V5S
M<VEO;VYI9`!+96QL86%E9P!0<F%E9W5N92!54DP@;VX`06MT:6EV<V5D(&MA
M<W5T86IA9`!0<F%E9W5N92!I;&T`4')A96=U;F4@:6QM.@!0<F%E9W5N92!S
M=&EI;`!(Y.1L97-T82!T]FED(&UI9&$@=&5H86MS92!S:7-E;F5M:7-E;"`E
M<RUI+@!,]6EK80!,]6EK82!V86QI:P!+_'!R;W,`2VER:6QL:71S82`H2T])
M."U2*0!+:7)I;&QI='-A("A7:6YD;W=S+3$R-3$I`$MI<FEL;&ET<V$O56MR
M86EN82`H2T])."U5*0!4<V5H:&D@5F%B87)I:6L`4%``1%-.("AV86%T82!H
M='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E
M+F1B+FEN=')O+61S;BYP:'`I`$EG82!PY&5V`$1A=&%4<F5E('-I<G9I:F$`
M06YD;65B86%S:6]T<VEN9P!+=75PY&5V`%-A86)U;6ES92!K=75PY&5V`$MU
M=7#D979A('9A;&EK`%#D978`2W5?<W1U=&$@=F5E<F<`1&5T<V5M8F5R`$O\
M;6YE;F1N=6UB<FED`%;D:&5N9&$@=&%A;F1R:61A`%9A:6MI;6ES:0!686EK
M:6UI<VD@=N1R=@!686EK96ED96YT:71E970`5F%I:VEM:7-I('-H96QL`%/U
M;F%S96QE='5S960`2W5S='5T80!+=7-T=71A(&QA:'1E<@!+=7-T=71A(&=R
M=7!P`$MU<W1U=&$@;&]G:0!+=7-T=71A(/5I9W5S`$MU<W1U=&$@:F$@965M
M86QD82!K:7)J860`2W5S='5T82!L86AT97(`2W5S='5T82!V965R9P!+=7-T
M=71A(&]L96UA<V]L978@86QT97)N871I:79N92!M86QL`$MI<FIA9&4@:W5S
M='5T86UI;F4`2W5S='5T82#U:6=U<V5D("(E<R(M;&4`2W5S='5T82#U:6=U
M<V5D("(E<R(M;&4@:F$@:_5I:R!A;&%M]6EG=7-E9#\`2W5S='5T82!R:61A
M`$MU<W1U=&$@=F%L:71U9"!I9&5N=&ET965T`$MU<W1U=&$@86MT:6EV;F4@
M=F5E<F<`2W5S='5T82!A:W1I:79N92!R:61A`$MU<W1U=&%S:6X@<&%I9V%L
M9'5S92!U=65N9&%M:7-E('-K<FEP=&D@(B5S(BX`2^1T=&5T;VEM971A;6ES
M92!A96<`5&%A;FD`2VER:F5L9&$@<')O8FQE96UI`$MI<FIE;&1U<P#<:W-I
M:V%S:F%D("AK86YT=60@:V$@2&]R9&4@;&]G:69A:6QI*3H`W&MS:6MA<VIA
M9"!L;V=I=&D@861M:6YI<W1R86%T;W)I(&IA;VMS+@!!<F5N9'5S`$MA<W1E
M<'5N:W0`165L;6ES92!T=6YN:2!K87-T97!U;FMT`$MA<W1E<'5N:W0Z`%-U
M=6YD('9A<V%K=6QT('!A<F5M86QE`%-U=6YD('!A<F5M86QT('9A<V%K=6QE
M`$MA=&%L;V]G`$5S:71A(&ME;&QA86IA9"`R-"UT=6YN:7-E;F$`16MR86%N
M:2!S96%D960`3N1I=&$@</5H:F%L:6MK=2!E;FYU<W1U<W0`3N1I=&$@96YN
M=7-T=7-T("A4048I`$5K<F%A;FD@<V5A9&5D`$1I<W!O<VET:6]N($YO=&EF
M:6-A=&EO;@!$:FEB;W5T:0#$<F$@:W5S='5T80#$<F$@_')I=&$@;6%I;G1E
M;F%N8V4N<&AP(&9A:6QI(&]T<V4@:^1I=FET861A`$MU:2!E<VEM96YE(')I
M9&$@<VES86QD86(@=N1L:F%D92!N:6UE<VED+"!MY')G:2!S964@<G5U=#H`
M1&]M:6YI8V$`1&]M:6YI:V%A;FD@5F%B87)I:6L`4W5L('!O;&4@:V]N=&]T
M/R!296=I<W1R965R=2X`4V%L=F5S=&$`4V%L=F5S=&$@)7,`4V%L=F5S=&$@
M;&]O9'5D('-E861I<W1U<R!02%`@<VMR:7!T:6YA+@!.:6UE:VER:0!2879I
M;6ED`$4M<&]S=`!%+7!O<W0M4TU3:6QE('9A:&5N9'5S9')A:79E<BP@=&5E
M;G5S97!A:VMU:F%T96QE(&ME;&QE;"!S96QL:6YE('1E96YU<R!O;@!%4E(`
M16MU861O<@!-=75D80!-=75D82!B;&]K:VD`375U9&$@9W)U<'!I`$UU=61A
M(/5I9W5S=`!-=75D82#U:6=U<VD`375U9&$@)7,@]6EG=7-I`$UU=61A('-E
M861E:60Z`$UU=61A("(E<R(@]6EG=7-I`$UU=61A("5S(/5I9W5S:0!(87)I
M9'5S`$5G:7!T=7,`3/QL:71A('-E92!S:7-S92!J82!S:6ES.B`E<RP@=O5I
M(&MA<W5T82!L:6AT<V%T($A434P@=F5R<VEO;VYI.B`E<RX`16P@4V%L=F%D
M;W(`16QE;65N="XN+@!%;0!%+7!O<W0`12UP;W-T:2!A861R97-S`$4M<&]S
M=&D@86%D<F5S<VED('!E879A9"!K;&%P<&EM82X`12UP;W-T(&MI;FYI='5S
M96=A`$4M<&]S="U335-I;&4@;/S\<P!3;6%I;&ED`%/U;G5M(&]N('3\:&DN
M`%1U;&5M=7,@;VX@=/QH:2X`3W1S:6YG=71I;F=I;75S(&]N('3\:&D`3'5B
M82!T96MS=&D@<VES<V4@;&ES861A('!I;'1E(&9O=&]G86QE<FEI9&5S=`!,
M=6)A('!A<F5M:VSU<'-U9V$@:/QP:6MM96[\_`!!87-T82!L]7!P`%-U=7)E
M;F1A(&5D:71O<@!3:7-E<W1A('-A;&%J86YE(&O\<VEM=7,@;6ED82!S:6YU
M;'0@:_QS:71A:W-E('!A<F]O;&D@;75U=&UI<V5K<RP@;N1I=&5K<R`G;6ES
M(&]N('-I;G4@;&5M;6EK;&]O;6$@;FEM:3\G.@!3:7-E<W1A('-I:6$@<&EL
M9&D@55),`%-I<V5S=&$@86QL82!TY&AE9#H`16MV871O<FEA86PM1VEN96$`
M17)I=')E80!6:6=A`%9I9V$@8FQO:VD@;&]O;6ES96PZ("5S`%9I9V$@<_QN
M:W)O;FES965R:6UI<V%N:W)U(&MU<W1U=&%M:7-E;#H@)7,`5FEG82!S_&YK
M<F]N:7-E97)I;6ES92!L;V=I(&MU<W1U=&%M:7-E;#H@)7,`5FEG82!S:7-U
M(&QA861I;6ES96PZ("5S`%9I9V$@<V%L87/U;F$@;75U=&UI<V5L.B`E<P!6
M:6=A(&4M<&]S=&D@=&5A=&5S+@!6:6=A("(E<R(@:VER:G5T86UI<V5L+@!%
M97-T:0!%=&EO;W!I80!286AV=7-L:6L`175R;V]P80!)9V$@,34@;6EN=71I
M('1A9V%N=`!)9V$@,B!M:6YU=&D@=&%G86YT`$EG82`S,"!S96MU;F1I('1A
M9V%N=`!)9V$@-2!M:6YU=&D@=&%G86YT`$EG86P@<VES<V5L;V=I;6ES96P`
M26=A('!O;VQE('1U;FYI('1A9V%N=`!+;W)D(&UI;G5T:7,`3N1I9&ES=N3D
M<G1U<V5D.@!+Y&EV:71A`$QA:65N9&$`3N1I=&$@:_QL9W)I8F$`3V]T87-I
M;B`G*2<`3V]T87-I;B!L:6AT<V%T('/U;F$@=O5I(&IU='5MY')K:61E<R!O
M='-I;F=U9G)A87-I`$%E9W5M:7-E(&MU=7#D978`16MS<&]N96YT`%1E:W-T
M:2!VY')V`%-E861I<W1U<V4@_&QE<VQA861I;6EN92!&5%`@:V%U9'4`2.3D
M;&5S='5S92!L86%D:6UI;F4@;G5R:G5S+@!%:2!S86%N=60@_&AE;F1U<W0@
M3$1!4"!S97)V97)I9V$N`$5I('-A86YU9"#\:&5N9'5S="!334(@<V5R=F5R
M:6=A+@!%:2!S86%N=60@:V]P965R:61A("(E<R(M<W0N`$5I('-A86YU9"!K
M;W!E97)I9&$@(B5S(BUI+@!5=64@4T%33"#\:&5N9'5S92!L;V]M:6YE(&YU
M<FIU<RX`16D@<V%A;G5D('3U<W1A("(E<R(M:2X`16D@<V%A;G5D('1I<FED
M83H@)7,`2&5A`$9A;&ML86YD:2!S86%R960@*$UA;'9I:6YI9"D`1N3D<FD@
M<V%A<F5D`$MO:'5T878@=FEG83H`1F%K<P!&86MS:60`5F5E8G)U87(`5'5N
M9'5B(&YA9W4`5'5N9'5B(&YA9W4Z(`#<:W-I:W5D('9I:&UA:&]O9`#<:W-I
M:W5D(&QU;65S86IU:&]O9`!&:65L9"!M871R:7@`1FEG;&5T($-!4%1#2$$`
M1FEG;&5T(&9O;G0`1FED>FD`1F%I;`!&86EL:61E(&%R=CH@)7,@9F%I;`!&
M86EL:61E(&%R=CH@)7,@9F%I;&D`1F%I;&EH86QD=7(`1F%I;&D@;FEM:0!&
M86EL:2!V86QI:P!&86EL:2#\;&5S;&%A9&EM:6YE`$9A:6QI9&4@_&QE<VQA
M861I;6ES="!E:2!T;V5T871A+@!&:6QT<FED`%-O;VUE`$5S:6UE;F4@<&]O
M;`!%<VEM96YE('9E97)A;F0`4^1I;&ET82!S=6AE`%!E96=E;&1A`$CU;&IU
M=@!59'4`2V%T86QO;V=I("5S('!O;&4@;VQE;6%S`%1E:W-T:2!VY')V`%1O
M:70`5F5E8FEL96AI='-E:F%T96QE(&UI<R!P:6QT92!E:2!T;V5T80!%;FYU
M<W1U<R`H5$%&*0!0Y&5V861E(&%R=B`H;VQG=2#V96QD=60@970@=&%G87-T
M871A=B!E;FYU<W1U<R!S:7-A;&1A8B!N:6D@<.1E=FD@:W5I(/9I9#L@<W5U
M<B!A<G8@=O5I8B!B;&]K:2!L86EA:W,@=F5N:71A9&$I`%5N=7-T87-I9"!S
M86QA<_5N83\`5F]R;6ED`$MI;&0`2VEL;'4@=/S\<`!+:6QL=60`2VEL;'5D
M(#(`1F]O<G5M:60`161A<W1U<P!290!286%M:60`4')A;G1S=7-M86$`4')A
M;G1S=7-M86$L($5U<F]O<&$M;W-A`%!R86YT<W5S92!'=6%J86%N80!0<F%N
M='-U<V4@4&]L_&YE97-I80!0<F%N='-U<V4@3/5U;F%A;&%D`$ME;&QE;'0`
M4W5U;F%G82``4/5H:F%L:6L@:VER:F5L9'5S`%3D:7-K=74`5.1I<VYI;6D`
M1V%B;VX`1V%L97)I:2P@:W5S="!P:6QT(';U='1A`$=A;&5R:6DZ`$=A;6)I
M80!'96YE<F5E<FD@)7,@:V]N9FEG=7)A='-I;V]N`$=E;F5R965R:71U9"!K
M;V]D`$=R=75S:6$`4V%K<V%M86$`1V%A;F$`1VEB<F%L=&%R`$5E<VYI;6D`
MW&QD:7-E9"!S96%D960`36EN90!']F1E;`!';V]G;&4@:V%A<F1I9`!';V]G
M;&4@;W1S:6YG`$AA;&QT;V]N:61E<W-E`$MR965K80!+<F5E:V$@*$E33RTX
M.#4Y+3<I`$=R]O9N:6UA80!'<F5N861A`$=R=7!P:61E(&AA;&1U<P!'<G5P
M<&ED92!N:6UE9"!E:2!V]6D@;VQL82!T_&AJ860`1W)O=7!?;&1A<#H@16D@
M<V%A(&QI<V%D82!G<G5P<&D@)7,N(%-E<G9E<B#\=&QE<SH@`$=R;W5P7VQD
M87`Z($5I('-A82!K=7-T=71A9&$@9W)U<'!I("5S`$=R;W5P7VQD87`Z($5I
M('-A82!M=75T82!G<G5P<&D@)7,`1W)U<&ED`$=U861E;&]U<&4`1W5A;0!'
M=6%T96UA86QA`$=U97)N<V5Y`$O\;&%L:7-E(/5I9W5S960`2_QL86QI<W1E
M<F%A;6%T`$=I;F5A`$=I;F5A+4)I<W-A=0!'=6%J86%N80!(5$U,`$A434Q!
M<F5A(&ME96QD=6(@87)G</QK<VQI:W5L="!K=7-T=71A;6%S="!R96$@=FEI
M;6%S="!L86AT<FET+@!(5$U,07)E82!K965L9'5B(&%R9W#\:W-L:6MU;'0@
M:W5S='5T86UA<W0@=&%B96QI('9I:6UA<W0@=F5E<F=U+@!(5$U,07)E82!K
M965L9'5B(&%R9W#\:W-L:6MU;'0@:W5S='5T86UA<W0@=&%B96QI('9I:6UA
M<W0@<FED82X`2%144"!A=71E;G1I;6ES="!E:2!L96ET=60N`$AA:6ET:0!2
MY'-I86QG;W)I=&T`2.1G=0!0Y&ES`%#D:7-E9`!(96%R9&D@<V%A<B!J82!-
M8T1O;F%L9&D@<V%A<F5D`%+D;FL@Y&EK97-E=&]R;0!(965B<F5A("A)4T\M
M.#@U.2TX+4DI`$OU<F=U<P!!8FD`161I=&]R:2!K87-U=&%M:7-E(&%B:0!!
M8FEL:6YE`'!O;VQK97)A`%-I:6X@;VX@9F%I;&D@86QG=7,`2_5R9V4`7T%V
M86QE:'0`4/QH82!4;V]L("A6871I:V%N:2!,:6YN<FEI:RD`079A;&5H96QE
M`$MO9'5N92!A861R97-S`$MO9'5K871A;&]O9P!+;V1U;F4@=&5L969O;@!(
M;VYD=75R87,`2&]N9VMO;F<`2&]R9&4`2&]R9&4O2V]L86(Z(%9I9V%S960@
M)7,@6$U,(&%N9&UE9"!K:7)J87,@)7,`2&]R9&4O2V]L86(Z($]B:F5K=&EL
M92`E<R!E:2!V87-T82#\:W-K:2!K:7)I`$AO<F1E+TMO;&%B.B!%:2!L96ET
M=60@_&AT:VD@)7,@=/S\<&D@;V)J96MT:2!K:7)J87,@)7,`2&]R9&4O2V]L
M86(Z(-5N;F5S='5S(&5E;6%L9&%D82`E<R`B)7,B`$AO<F1E+TMO;&%B.B!)
M;G1E9W)A='-I;V]N:6UO;W1O<B!V86IA8B`G9&]M>&UL)R!02%`@;&%I96YD
M=7-T`$AO<F1E+TMO;&%B.B!%:2!S86$@;'5U82!U=70@6$U,('!U=60@;V)J
M96MT:2`E<R!J86]K<P!(;W)D92]+;VQA8CH@16D@<V%A(&5E;6%L9&%D82`E
M<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@16D@]6YN97-T=2!H86YK:61A($U)
M344@240M9"`E<R!T_/QP:2!O<V$@:F%O:W,`2&]R9&4O2V]L86(Z($5I('-A
M82!S_&YK<F]N:7-E97)I9&$@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($5I
M('-A82!S_&YK<F]N:7-E97)I9&$@:F%G=7-I9#H@)7,`2&]R9&4O2V]L86(Z
M(%1U;F1M871U(&IA9W4@(B5S(@!(;W)I<V]N=&%A;&IO;VX`2&]R:7-O;G1A
M86QN92!V;V]D97)D=7,`2&]R:7-O;G1A86QN93H`2W5I9&%S('-A('-I:6$@
M<V%T='5S:60_("A086QU;B!T96%T82$I`$MU:2!P86QJ=2!V965R9V4@<V]O
M=FEK<VED(/QH96YD861A/P!+=6D@<&%L:G4@=N1L:G4@*'9E97)G92D@;VX_
M`$MU:2!P86QJ=2!R:61U('-O;W9I:W-I9"#\:&5N9&%D83\`3FEI<VMU<P!.
M:6ES:W5S.@!(=6UO<FES=&ED`%5N9V%R:0!)34%0('!O<W1K87-T:2!L;V]M
M:6YE(&YU<FIU<SH@)7,`24U!4"!P;W-T:V%S=&D@:W5S='5T86UI;F4@;G5R
M:G5S.B`E<P!)34%0('!O<W1K87-T:2!K=F]O9&D@;&]O;6EN92!N=7)J=7,Z
M("5S`$E0(&%A9')E<W,`25`@86%D<F5S<R!P;VQE('1E861A+@!)4"!A861R
M97-S(&5I(&MU=6QU(&QU8F%T=60@0TE$4B!B;&]K:VDN`$E0('!I:7)A;F=U
M(')I:VMU;6EN92X`3&ES82!R:61A(%]E;FYE`$ES;&%N9`!!:6YU;'0@:6MO
M;VYI9``E<R!I:V]O;FED`$EK;V]N:60@:F$@=&5K<W0`261E;G1I=&5E9&D@
M;FEM:3H`2W5I('-E9&$@]6EE=&D@96D@;N1I9&%T82P@)7,@:F$@<V5E(&%V
M871A:W-E('5U97,@86MN87,N`$MU:2!S82!K87-U=&%D($EN=&5R;F5T($5X
M<&QO<F5R:70@:F$@96D@;N1E(/QL9'-E(&EK;V]N92P@<VEI<R!P<F]O=FD@
M;>1R:VED82!S964@<G5U="P@;/QL:71A;6%K<R!S:7-S92!03D<@;.1B:7!A
M:7-T=G5S+@!+=6D@<V$@;N1E9"!S961A('1E861E="!A9V$@<&EL=&D@96D@
M;N1E+"!S:6ES(&5I(&]S:V$@<VEN=2!V965B:6QE:&ET<V5J82!NY&ED871A
M('-E9&$@<&EL=&DL(&UI9&$@<V]O=FED(/QL97,@;&%A9&ED82X`4&EL9&D@
M965L=F%A9&4Z`%!I;&1I(%523`!0:6QD:2!54DPZ`%!I;'0@9V%L97)I:7-T
M`%!I;'0@9V%L97)I:7-T.@!0:6QD:2#\;&5S;&%A9&EM:6YE`%!I;&1I9`!)
M;7!O<G0L('-A;6T@)60`26UP;W)D:71U9"!VY&QI.B`E<P!);7!O<F1I='5D
M(';D;&IA9#H`3&ES82!R:61A(%]PY')A<W0`17-I=&%T:2!V86QE('1E9V5V
M=7-E(&MO;V0N`%9A;&4@:V%S=71A:F%N:6UI(&IA+W;U:2!P87)O;VPN`%9A
M;&4@:V%S=71A:F%N:6UI(';U:2!A;'1E<FYE=&EI=FYE(&%A9')E<W,N(%!R
M;V]V:2!U=65S=&D@=O5I(';U=&$@_&AE;F1U<W0@861M:6YI<W1R86%T;W)I
M9V$N`%-U=7)E;F1A('1A86YD<FED80!);F1I80#<:W-I:W5D(&MA<W5T86IA
M9`!);F1O;F5E<VEA`$EN9F\`26YF;W)M871S:6]O;@!496%V92!E:2!O;&4@
M96YA;2!KY'1T97-A861A=BX`3&ES82!?=F5E<F<@<.1R87-T`$QI<V$@<&EL
M=`!,:7-A('1A8F5L`$QI<V$@:/QP97)L:6YK`$QI<V$@=F5E7W)G(&5N;F4`
M3&ES82!U=7,@=F5E<F<@86MT:6EV<V4@=F5E<G4@:N1R96QE`$QI<V$@=75S
M('9E97)G(&%K=&EI=G-E('9E97)U(&5T=&4`3&ES82!U=7,@<FED82!A:W1I
M:79S92!R96$@:N1R96QE`$QI<V$@=75S(')I9&$@86MT:6EV<V4@<F5A(&5T
M=&4`3&ES82!L]6EK('!R865G=7-E(&%S=6MO:&$@:N1R96QE`$QI<V$@;/5I
M:R!P<F%E9W5S92!A<W5K;VAA(&5T=&4`3&ES82!A;'1E<FYA=&EI=FYE(&UA
M;&P`4VES97-T82!M86EL:6%A9')E<W,@:W5H=2!S86%K<R!S=6QL92!U=64@
M<&%R;V]L:2!S86%T83H`3&ES82!L86AT97(@<.1R87-T`$QI<V$@;&%H=&5R
M(&5N;F4`3&ES82!V965R9R!PY')A<W0`3&ES82!V965R9R!E;FYE`$QI<V$@
M:VER:F%D`$QI<V$@;/5I:R!PY')A<W0`3&ES82!L]6EK(&5N;F4`3&ES82!R
M:61A('#D<F%S=`!,:7-A(')I9&$@96YN90!+:7)J=71A('-A;&%K_'-I;75S
M92#U:6=E('9A<W1U<SH`3&ES82]M=75D82!P:6QT`$QI<V$O;75U9&$@;&EN
M:P!*86]T=7-N:6UE:VER:F%L92!S86%T;6ES96MS(&5I(&KD=&MU(&MR961I
M:71I+@!+<F5D:6ET:2!E:2!JY'1K=2X`5.1I<V%R=@!4Y&ES87)V=61E(&YI
M;65K:7)I`%9I9V%N92!51$@@*%5S97(@1&%T82!(96%D97(I+@!6:6=A<V5D
M(%I)4"!A;F1M960N`%9I9V%N92!R86ME;F1U<RX`5F%L92!B871C:"!)1`!3
M:7-E<W1A=&D@=FEG87-E9"!A;F1M960N`%9I9V%N92!S:6AT86%D<F5S<RX`
M5F%L92!F86EL:69O<FUA870`5FEG86YE(&QI='-E;G1S:7;U=&DN`%-I<V5S
M=&%T:2!V:6=A;F4@87-U:V]H=`!6:6=A;F4@;7-G7W1Y<&4`87!I7VED(&]N
M('!U=61U(';U:2!V:6=A;F4N`%9I9V%S960@=O5I('!U=61U=F%D('!A<F%M
M965T<FED+@!6:6=A;F4@_&QE;?5I9W5S+@!6:6=A;F4@<&%R=&YE<FD@240`
M5FEG86YE('1O;W1E:V]O9"X`5FEG86YE('!R;W1O:V]L;"X`5FEG86YE('-A
M86IA.B`B)7,B`%9I9V%N92!J86=A='5D(&]B:F5K=`!6:6=A;F4@;.1H=&5A
M861R97-S+@!6:6=A<V5D('5N:6-O9&4@86YD;65D+@!.:6UE:VER:0!0]O9R
M9'9A;&EK`$ER86%N:2!)<VQA;6EV86)A<FEI:P!)<F%A:P!):7)I;6%A`$UA
M;FD@<V%A<@#<:W-I:W5D(.1I:V5S971O<FUI9`!):7-R865L`%;D;&IA86YD
M:F$`2V%L9&MI<FD`271A86QI80!*86UA:6MA`$IA86YU87(`2F%A<&%N`$IA
M87!A;FD@*$E33RTR,#(R+4I0*0!+=6YA('-I;G4@=F5E8FEL96AI='-E:F%S
M(&]N($IA=F%S8W)I<'0@:V5E;&%T=60L(&5I('!R=75G:2!S964@;&5H="#U
M:65T:2!P86ES=&$N`$IE<G-E>0!*;W)D86%N:6$`2G5U;&D`2G5U;FD`4O;V
M<'-E;'0`2V5S:V5L90!2]O9P<V5L=`!687-A:W5L90!087)E;6%L90!+87-A
M:'-T86X`4^1I;&ET82!O<FEG:6YA86P_`$ME96YI80!+97)B97)O<V4@<V5R
M=F5R(&5I(&QA<VMN=60@<VES<V4N`$ME<FYE;&D@=O5H:6MU9`!6]71M92!L
M;V]M:6YE`%;U=&UE('/U<FUE:N1L9P!6]71M92!P:6MK=7,`5O5T;64@=/S\
M<`!6]71M92!K87-U='5S`%;U=&D@;VX@879A;&EK=7,@<V5R=F5R:7,@:G5B
M82!O;&5M87,N`$QA<'-E9`!+:7)I8F%T:0!+;W)E82!286AV861E;6]K<F%A
M=&QI:R!686)A<FEI:P!+;W)E82!686)A<FEI:P!+;W)E82`H155#+4M2*0!+
M=79E:70`2_5R9_5Z<W1A;@!?2W5J=6YD=7,`2V5E;`!,86]S92!286AV861E
M;6]K<F%A=&QI:R!686)A<FEI:P!6:6EM86YE('!O;VP`5FEI;6%N92!P87)O
M;VQI(&UU=71U<P!6:6EM86YE('9E97)A;F0`5FEI;6%T:2!M=75D971U9#H`
M165L;6EN92!K_&QA<W1U<SH@)7,`165L;6EN92!K_&QA<W1U<SH@)7,@86%D
M<F5S<VEL="`E<P!%96QM:6YE(&O\;&%S='5S.B!M:71T92!K=6YA9VD`3.1T
M:0!396%D=7,`2W5J=6YD=7,`5/QH:2!TY&AE;F1A8B!P:6ER:F]O;F4@<'5U
M9'5M:7-T`$QI:6)A;F]N`%9A<V%K`%9A<V%K('#D:7,`5F%S86MU9"!VY.1R
M='5S960`3&5S;W1H;P!487-E`$QI8F5E<FEA`$QI:6+\82!!<F%A8FEA(%9A
M8F%R:6EK`$QI96-H=&5N<W1E:6X`5&EB=71A8B!V:6AM80!3965N979I:&T`
M2&]M;6EK=6P@=&EB=71A8B!V:6AM80#5:'1U;"!T:6)U=&%B('9I:&UA`$ME
M<F=E(&AO;W9I:&T`2V5R9V4@=FEH;2!J82#D:6ME`$ME<F=E(&QU;65S861U
M`$ME<F=E(&QU;65T;W)M`$QI;65R:6L`3&EN:P!,:6YK('9I:71A8B!A<W5K
M;VAT83H`17-I=&%M:7-E;"!S96]S=&$@92UP;W-T:2!A861R97-S('5U92!K
M:7)J82!A:VYA9V$`3&EN9VED`$QI;G5X:2!P<N3D;FEK`$QI<W0@+2!K87-U
M=&%J82!V]6EB(&MA=7-T82!NY&AA`$%N9&UE8F%A<VED92!L;V5T96QU`$%B
M:6EN9F\@=&5E;6%D92!N:6UE:VER:0!486)E;&ET92!L;V5T96QU`$QI<W0M
M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S
M=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`%-E<W-I;V]N:61E
M(&YI;65K:7)J82!E<VET86UI;F4@;G5R:G5S.B`E<P!+87-U=&%J871E(&YI
M;65K:7)J82!E<VET86UI;F4@;G5R:G5S.B`E<P!+87-U=&%J871E(&YI;65K
M:7)J82!P;VQE(&QU8F%T=60@;N1H82X`2VER:F%N9'5S`$QE961U`$QA96XN
M+BX`2V]H86QI:R!A96<Z(`!296=I;V]N(&IA(&%E9P!!<W5K;VAT`$QO9VD@
M<VES<V4`165L;6ES92!S_&YK<F]N:7-E97)I;6ES92!L;V=I`$QO9VD@=N1L
M:F$`2V%S=71A:F%N:6UI`%3V]F0@<VES<V5L;V=I;6ES96P`4VES<V5L;V=I
M;6EN92!N=7)J=7,L(&MU;F$@:V%S=71A:F%N:6UI(';U:2!P87)O;VP@<&]L
M;G5D(/5I9V4N`%-I<W-E;&]G:6UI;F4@;G5R:G5S+@!0:6MK('1E:W-T`$%R
M;6%S='5S`$UA9&%L`$MR965K82!VY&EK973D:&5D`$QA9&EN82!VY&EK973D
M:&5D`%;D:6ME<V5D(')O;VUA(&YU;6)R:60`3'5K<V5M8G5R9P!+2P!-3U1$
M`$U3+51.148@;&ES86YD(&5I('-I<V%L9&%N=60@86YD;65I9"X`35-'`$UA
M:V%O`$UA:V5D;V]N:6$@*$5N9&EN92!*=6=O<VQA879I82!686)A<FEI:RD`
M36%D86=A<VMA<@!-86%G:6$`12UP;W-T`%!O<W1I(&%D;6EN:7-T<F%A=&]R
M`%]4964@;&EN:P!-86QA=VD`36%L86ES:6$`36%L9&EI=FED`$UA;&D`36%L
M=&$`4V5A9&ES=&$@:V%T96=O;W)I86ED+"!M:61A(&MA<W5T871A:W-E(/QK
M<W5S=&4@;>1R9V5N9&%M:7-E:W,@:F$@;F5N9&5L92!K871E9V]O<FEA=&5L
M92!V87-T879A:60@=N1R=F4N`$UA<#(T(&MA87)T`$UA<%%U97-T(&MA87)T
M`%9A<W1A=G5S960@<V%L=F5S=&%T=60N`$WD<G1S`%-E<G8`5.1H:7-T82!L
M;V5T=60O;'5G96UA=&$@<W1A871U<P!4Y&AI<W1A(&UU=2!S=&%A='5S("AN
M="X@=.1H=&ES+W9A<W1A='5D*0!-87)S:&%L;&D@<V%A<F5D`$UA<G1I;FEQ
M=64`4V]B:79A9"!VY&QJ860`36%U<F5T86%N:6$`36%U<FEI=&EU<P!3=75R
M:6T@;'5B871U9"!K<F5D:6ET+@!+:7)J82!O<V%D92!P:6ER86YG(/QL971A
M='5D+@!6:6EM87-E(#(T('1U;FYI(&OU<F=E:6T@=&5M<&5R871U=7(Z(`!6
M:6EM87-E(#8@='5N;FD@:_5R9V5I;2!T96UP97)A='5U<CH@`%-U=7)I;2!P
M;W)T86%L:2!B;&]K:VED92!A<G8`4W5U<FEM('!I:VMU<P!-86D`36%Y;W1T
M90!-961I='-I:6X`3&EI:VUE9`!-96[\_"!E<VET=7,Z`-QH96YD82!L86AT
M<FED`%1E861E`$MI<FD@;VX@961U:V%L="!K;VYT<F]L;&ET=60L(&5N="!A
M;&QK:7)J87-T86IA('-E<G1I9FEK86%T:2!E:2!S86%N=60@:V]N=')O;&QI
M9&$N`%1E861E(&]N(&%E9W5N=60N`%1E871E('3\_'``365T87(@:6QM`$UE
M=&%R(&)L;VMK(&5I(&]L92!S86%D879A;"X`365T87(@8FQO:VL@96D@;VQE
M('-A861A=F%L+B#<:W-I:V%S:F%D(&QO9VET:2!A9&UI;FES=')A871O<FD@
M:F%O:W,N`$UE=&%R1$(@_&AE;F1U<R!P=75D=6(N`$UE971O9`!-965T;V0@
M(B5S(B!E:2!O;&4@9&5F:6YE97)I='5D`$UE971O9"!E:2!O;&4@9&5F:6YE
M97)I='5D+B!+Y&EV:71A='5D(&UE971O9#H@)7,`365E=&5R`$UE:&AI:V\`
M36EK<F]N965S:6$@1O9D97)A='-I;V]N`$ME<VME;&4`34E-12!T_/QP`%9I
M:6UA<V4@,C0@='5N;FD@;6%D86QA:6T@=&5M<&5R871U=7(Z`%9I:6UA<V4@
M-B!T=6YN:2!M861A;&%I;2!T96UP97)A='5U<@!087)O;VQI(&UI;FEM86%L
M;F4@=F%N=7,@<&]L92!V965L('3D:7,`4&5E9V5L9&$`36ET;65S=6=U<W0`
M4'5U9'5B(%!%05(@<&%K971T($A45%!?4F5Q=65S="X`2V]N9FEG=7)A='-I
M;V]N('!U=61U8BX@2W5I('1A:&%D('-E9&$@<F%K96YD=7-T(&MA<W5T861A
M+"!P96%D(&5N;F4@9V5N97)E97)I;6$@:V]N9FEG=7)A='-I;V]N:2X`4'5U
M9'5B('/U;G5M:2!)1"X`4'5U9'5B('9A:F%L:6L@4$5!4B!P86ME='0@36%I
M;"X`4'5U9'5B('-E<W-I;V]N:2!)1"X`17,`36]B:6EL;F4@92UP;W-T`$WU
M]61U:V%S`$UU=71M:7-E(&MU=7#D978`375U9&$@55),`$KDY&L`36]L9&]V
M82!686)A<FEI:P!-;VYA:V\`36]N9V]O;&EA`$MU=2!J82!A87-T80!+;W)D
M(&MU=7,`36]N='-E<G)A=`!+=75F86%S:60`4F5A<R`E9"!L96ET:2!R;VAK
M96T@=N1L:G4@:W5I(&5E;&1A=&%V("5D+@!-87)O:V\`5F%L9&%V86QT('-E
M;&=E`%9A;&1A=F%L="!P:6QV97,`5F%L9&%V86QT('!I;'9E<R!J82!T=75L
M:6YE`%9A;&1A=F%L="!PY&EK97-E<&%I<W1E;&EN90!.:6AU=&$@86QL80!.
M:6AU=&$@=F%S86MU;&4`3FEH=71A('!A<F5M86QE`$YI:'5T82#\;&5S`$YI
M:'5T82!A;&QA`$YI:'5T82#\;&5S`$UO<V%M8FEI:P!-:71M971A<V5M96QI
M;F4@;&]E;F0`375L=&EM87`@54L@:V%A<G0`5F%L:6L`36EN=2!K;VYT;P!-
M:6YU(&MO;G1O(&EN9F\`36EN=2!P;W)T86%L`$UI;G4@<&]R=&%A;&D@:W5J
M=6YD=7,`37EA;FUA<@!%22P@;6$@14D@3TQ%(&[U=7,`3FEM:0!.86UI:6)I
M80!.875R=0!.97!A86P`2&]L;&%N9`!(;VQL86YD:2!!;G1I;&QI9`!.971S
M8V%P92!"87-E(%523`!.971S8V%P92!#02!T_&AI<W1U<V4@55),`$YE='-C
M87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@=75E;F1U<V4@55),`$YE='-C
M87!E('3\:&ES='5S92!54DP`3F5T<V-A<&4@4U-,('-E<G9E<FD@;FEM:0!.
M971S8V%P92!S97)T:69I:V%A9&D@:V]M;65N=&%A<@!.971S8V%P92!S97)T
M:69I:V%A9&D@=/S\<`!6]7)K`$UI='1E(&MU;F%G:0!5=7,M2V%L961O;VYI
M80!5=7,@:V%T96=O;W)I80!5=7,@:VER:2`E<RUL90!.;V]R:W5U`%5U<R!K
M87-U=&%J86YI;6D@*'!O;&4@:V]H=7-T=7-L:6LI`%5U<RU-97)E;6%A`%5U
M<R!S86QA<_5N80!5=7,@<V%L87/U;F$@865G=6(@)7@N`%-A;&%S]6YA9"!P
M96%V860@:VQA<'!I;6$N`%5U97,@86MN87,@*%]B;&%N:RD`575D:7-E9`!'
M<G5P:60`2N1R9VUI;F4`2N1R9VUI<V5D(#0@9F%A<VD`2N1R9VUI<V5D('-E
M861E9`!*Y')G;6EN93X`3FEK87)A86=U80!.:6=E<@!.:6=E97)I80#6]@!.
M:75E`$5I`%!U=61U=F%D(&MO;F9I9W5R871S:6]O;FEA;F1M960@;6EL;&4@
M97)I;F5V=7-I(&[D:61A=&$N`%!U=61U8B!S=')A=&5E9VEA($E33V1E(&QO
M;VUI<V5K<RX`4'5U9'5B(&UA;&PN`%-E;&QE<R!A<W5K;VAA<R!E:2!O;&4@
M8FQO:VMI`$U#04P@875T96YT:6UI<V5K<R!V86IA;&EK(&MA;&5N9')I(&YI
M;6D@;VX@<'5U9'4N`$5R:6YE=G5S:2!E:2!O;&4N`%-E;&QE;&4@]6EG=7-E
M;&4@96D@<V%A(&%L86UA:60@;&ES861A+@`E<R!HY.1L97-T=7-I;F9O('!U
M=61U8BX`1E10(%9&4R!HY.1L97-T=7-I;F9O('!U=61U8BX`4U%,(%9&4R!H
MY.1L97-T=7-I;F9O('!U=61U8BX`4U%,+49I;&4@5D93(&CDY&QE<W1U<VEN
M9F\@<'5U9'5B+@!+<F5D:6ET(&]N(&%M;65N9&%T=60N`%-I:'1K;VAT(&WD
MY')A;6%T82X`1F%I;&D@96D@;&%E='5D`$EK;V]N92!E:2!L96ET=60N`$%S
M=6MO:'0@;>3D<F%M871A+@!!<W5K;VAT(&WDY')A;6%T80!3]6YU;2!P=75D
M=6(N`$YI;6D@<'5U9'5B+@!.=6UB97(@<'5U9'5B+@!!:6YU;'0@=FEI<V%K
M860@:VEL;'5D`$A45%`@875T96YT:6UI<V4@<V%L87/U;F$@<'5U9'5B+@!)
M34%0(&%U=&5N=&EM:7-E('-A;&%S]6YA('!U=61U8BX`2V5R8F5R;W,@875T
M96YT:6UI<V4@<V%L87/U;F$@<'5U9'5B+@!,;V=I;B!A=71E;G1I;6ES92!S
M86QA<_5N82!P=75D=6(N`%!!4U-71"!A=71E;G1I;6ES92!S86QA<_5N82!P
M=75D=6(N`%--0B!A=71E;G1I;6ES92!S86QA<_5N82!P=75D=6(N`$]P96Y3
M4TP@<')O9W)A;6UI(&%S=6MO:'0@96D@;VQE(&WDY')A='5D+B!/<&5N4U-,
M('!R;V=R86UM(&]N('9A:F%L:6L@4$M#4R,Q,B!A;F1M971E9V$@=/;V=&%M
M:7-E:W,N`$]O=&5L(&QI:71U;6ES<V]O=F4@96D@;VQE+@!0:6ER86YG=70@
M96D@;VQE+@!0=75D=79A9`!%<F%L9&%J82!P;VQE(&WDY')A='5D+@!-:71T
M92#\:W-K:2!K_&QG`%-E;&QI<W0@9F%I;&D@96D@;VQE`%!U:'9E<F1A;6ES
M96MS('!U=61U8B!A:G5T:6YE(&MA=&%L;V]G+@!+87-U=&%J86YI;64@:F$O
M=O5I('-A;&%S]6YA(&5I('-A861E='5D+@!%:2!T86=A<W1A='5D(&MO<G)E
M:W1S96ED(%A-3"!A;F1M96ED`%;DY')T=7-E9"!P=75D=79A9`!!;&=N92!K
M;VYF:6=U<F%T<VEO;VX@96D@<VES86QD82!V97)S:6]O;FDN($QO;R!K;VYF
M:6=U<F%T<VEO;VX@=75E<W1I+@!3:6YU(&MO;F9I9W5R871S:6]O;B!E:2!S
M:7-A;&1A('9E<G-I;V]N:2X@3&]O(&MO;F9I9W5R871S:6]O;B!U=65S=&DN
M`$WDY')A;6%T80!-Y.1R86UA=&$`4/5H:F%M86%D("A)4T\M.#@U.2TQ,"D`
M3F]R9F]L:VD@<V%A<@!0]6AJ87!O;VQK97)A`%#U:&IA+4UA<FEA86YI('-A
M87)E9`!.;W)R80!-:71T92!H:6QJ96T@:W5I`$UI='1E('9A<F5M(&MU:0!%
M:2!O;&4@:V%T86QO;V<`4&]L92!T96]S=&%T=60N`$WDY')A;6%T80!%:2!O
M;&4@=&]E=&%T=60N`$WD<FMM960`4&]L92!M:61A9VD@<VER=FED82P@;6EN
M92!T86=A<VDN`$YO=F5M8F5R`$%R=@!-Y')K:61E(&%R=@!6965R9W5D92!A
M<G8`4FED861E(&%R=@!*86]T=7-N:6UE:VER:F%S(&UU=71M:7-E;&4@:W5U
M;'5V860@;G5M8G)I9"!P;VQE(&WDY')A='5D+@!/2P!/8FIE:W0`3V)J96MT
M:2!L;V]J80!+86AE:W-A;F1N=6UB97(`3VMT;V]B97(`5FEI<V%K=7-E(&%S
M=&4`2V]N=&]R:73V]@!686YA(&IA('5U<R!S86QA<_5N82!P96%V860@;VQE
M;6$@97)I;F5V860N`%!R865G=6YE('-A;&%S]6YA`%!R865G=6YE('-A;&%S
M]6YA(&5I(&]L92#U:6=E+@!/;6%A;@#<:&ES:V%U<W1U(';U:6UA;&1A=F%D
M(&%I;G5L="!)34%0('-E<G9E<FED+@!!:6YU;'0@96)A=FEI<V%K860@:VEL
M;'5D`$QU8F%T=60@;VX@86EN=6QT(/QK<R!E+7!O<W1I(&%A9')E<W,N`$IA
M;R!O;6%N:6MK=2!V]6D@;VUA;FEK=2#U:6=U<VD@<V%A8B!M=75T82!A:6YU
M;'0@;VUA;FEK(';U:2!S_'-T965M:2!A9&UI;FES=')A871O<BX`079A('5U
M97,@86MN87,`3W!E;E-33"!V:6=A.B!!;F1M971E(&5R86QD86UI;F4@86QL
M:VER:F%S=&%T=60@4R]-24U%(&]S87-T(&YU<FIU<RX`079A8B!S96QL92!L
M:6YG:2!U=65S(&%K;F%S`$]P97)A='-I;V]N:7/\<W1E96T`4V5A9&5D`%-E
M861I<W1U<SH@)7,`3G5M;65R9&%T=60@;&]E=&5L=0!/<F=A;FES871S:6]O
M;@!!;&S\:W-U<P!);F9O`%)A:V5N9'5S92!A;&=N92!M86QL`$%L9W-E9"!M
M86QL:60@:V%T86QO;V=I<R`E<SH`375U`$UU=2!I;F9O`$]M86YI:W4@]6EG
M=7-E9`!004T@875T96YT:6UI;F4@96D@;VQE('-A861A=F%L+@!014%2.CI-
M86EL('1U9VD`4$=0(&1I9VET86%L86QL:VER:0!01U`@:W+\<'1I='5D(&%N
M9&UE9`!01U`@879A;&EK(';U=&D`4$=0(&%L;&MI<FIA<W1A='5D+VMR_'!T
M:71U9"!A;F1M960`4$A0(&MO;V0`4$A0(&OD<W5R:61A`%!,(&ME<F=E('9I
M:&T`4$P@=FEH;0!03"!H;V]V:6AM860`4$P@;'5M:0!03"!T:6AE(&QU;65S
M861U`%!,('#D:6ME`%!,(.1I:V5S971O<FT`4$]325@@;&%I96YD=7,@<'5U
M9'5B`%!?2%`@:^1S=7)I9&$`5.1I9&4`4&%K:7-T86X`4&%L874`4&%L97-T
M:6EN82!O:W5P965R:71U9"!T97)R:71O;W)I=6T`4&%N86UA`%!A87!U82!5
M=7,M1VEN96$`4&%R86=U86D`5F%H96QD=78@<&EL=FES=7,`4V%L87/U;F$`
M4V%L87/U;F$@;75U9&5T=60N`%9A;&4@<V%L87/U;F$`4D%$2553(&%U=&5N
M=&EM:7-E:W,@;VX@=F%J86QI:R!S86QA<_5N82X`4V%L87/U;F$@:VEN;FET
M=7-E9V$`4V%L87/U;F$Z`%-A;&%S]6YA.B``4V%L87/U;F%D('!E879A9"!K
M;&%P<&EM82X`07-E=&$`07-E=&$@;/5I:V5P=6AV<FES=`!!<W5K;VAT`$]O
M=&5L(&QI:71U;6ES<V]O=FED.@!);FEM97-E9`!0<F]T<V5N=&D`2^1I=FET
M82!H;V]L9'5S=/;V9`!4964@<VES<V5L;V=I;6ES96P@:&]O;&1U<W3V:60`
MU6EG=7,`U6EG=7-T("(E<R(@96D@:W5S='5T871U9"X`2G5U<F1E<.3D<R!K
M965L871U9`#5:6=U<V5D`-5I9W5S=&4@:&%L9'5S`$ES:6ML:6L@:6YF;P!0
M97)U=0!,96UM:6ML;V]M860`1FEL:7!I:6YI9`!496QE9F]N`$9O=&]D`%!I
M=&-A:7)N`%!I:W-L:70`3?5T=&5T=7-E9`!+;/5P<V$@;?5N9&$@;&%H=')I
M<W-E`$MI;FYI=&$@970@<V]O=FED('-E;&QE(&5L96UE;F1I(&5E;6%L9&%D
M83H`2VEN;FET82!E="!S;V]V:60@<V5L;&4@96QE;65N9&D@;&%H=&D@_&AE
M;F1A9&$N`%-I<V5S=&$@:W5U(&IA(&%A<W1A+@!3:7-E<W1A('-E;&QE('5U
M92!K871E9V]O<FEA(&YI;6DZ`%-I<V5S=&$@:V]R<F5K=&YE($E0(&%A9')E
M<W,N`%-I<V5S=&$@:V]R<F5K=&YE(&MU=7#D978L(&MO;G1R;VQL:2!PY&5V
M861E(&%R=G4@:W5U<RX`4VES97-T82!K;W)R96MT;F4@865G+@!+:7)J96QD
M82!P<F]B;&5E;6DN`%-I<V5S=&$@;VUA(&MA<W5T86IA;FEM:2!J82!S86QA
M<_5N80!,;V4@:N1R9VYE=B!T96MS="!LY&)I+B!3_'-T965M:2!K87-U=&%M
M:7-E:W,@4$5!1"!T:6YG:6UU<W1E9V$@;O5U<W1U;6$N`$MI<FIU=&$@=75E
M(&MA=&5G;V]R:6$@;FEM:3H`4&]O;&$`4&]L:6ET:6MA`$O\<VET;'5S960`
M4&]R='5G86P`4V5L;&4@<&EL9&D@<&%I9W5T=7,`4V5L;&4@=&%B96QI('!A
M:6=U='5S`$MI<FIU=&$@<V5L;&5S<V4@:V%U<W1A("A)34%0(&5I(&MO;G1R
M;VQL:2D`5FEI;6%S92`E<R!T=6YN:2!S861E;65D.B``4V%D96UE=&4\8G(@
M+SYT]65NY&]S=7,`4')E9G-?;&1A<#H@5F%J86QI:VMU($Q$05`@;&%I96YD
M=7-T(&5I(&QE:71U9"X`4')E9G-?<V5S<VEO;CH@5F%J86QI:VMU('-E<W-I
M;VX@;&%I96YD=7-T(&5I(&QE:71U9"X`U6AU<O5H:P#5:'5R]6AK(&UE<F5P
M:6YN86PZ`-5H=7+U:&LZ`$5E;'9A861E`%!I;&1I(&5E;'9A861E('5U97,@
M86MN87,`165L;6ES960@<V5A9&5D`%1R_&MI(&1O:W5M96YT`%-A;&%J86YE
M(';U=&D`4')O8FQE96T`4')O8FQE96UI(&MI<FIE;&1U<P!0<F]J96MT:60`
M4V5L9VET878@=&5K<W0`079A;&EK(';U=&D`079A;&EK=2!V]71M92!A;&=O
M<FET;0!!=F%L:6MU(';U=&UE(&EN9F\`5O5T;65P86%R:2!G96YE<F5E<FEM
M:6YE(&5I(/5N;F5S='5N=60N`%!U97)T;W)I:6MO`$MU<W1U=&%T=60@:VER
M:F%D92!E96UA;&1A;6EN90!+871A<@!0Y')I;F<`4&EI<F%N9P!24T$@879A
M;&EK(';U=&D@*"5D(&)I='1I*0!686QI:P!6:6AM`$AO;6UI:W5L('9I:&T`
MU6AT=6P@=FEH;0!(;V]V:6AM`%9I:&T@:F$@;'5M:0!6:6AM(&IA(&QU;6D`
M2G5H=7-L:6L@:VEL9`!0<F]T<V5N=`!,;V4`3&]E(&MI<FIU`$MA<R!T]65S
M=&D@:W5S='5T861A("5S/R!3964@=&]I;6EN9R!O;B!P]O9R9'5M871U+@!+
M87,@=/5E<W1I(&MU<W1U=&%D82!K87-U=&%J82`E<R!A;F1M960_(%-E92!T
M;VEM:6YG(&]N('#V]G)D=6UA='4N`%1A87-T86(@=FEI;6%S92!T96=E=G5S
M90!6Y')S:V5N9&$`5N1R<VME;F1A(&3\;F%A;6EL:7-E9"!M96[\_"!E;&5M
M96YD:60Z`%;D<G-K96YD82!P;W)T86%L:2!V86%D93H`4F5G=6QA87)A=F%L
M9&ES`%-U:&5T92!S:7)V:6IA`$QA92!U=65S=&D`3>1R:W5S960`5N1L:7-E
M9"!S97)V97)I9`!6Y&QI;F4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M
M+VAO<F1E*3H`165M86QD80!%96UA;&1A(&)L;VMK`$MU<W1U=&$@=F5E<F<`
M165M86QD82!K=6IU;F1U<P!%96UA;&1A('!A87(`2W5S='5T82!S86QV97-T
M871U9"!S:W)I<'0@<V5R=F5R:2!A:G5T:7-E<W0@:V%T86QO;V=I<W0N`$5E
M;6%L9&$`165M86QD82!D;VMU;65N9&ES=`!+=7-T=71A(&MA<W5T86IA`$MU
M<W1U=&$@:V%S=71A:F$Z("5S`%#D<FEN9W5L92!P;VQN=60@=O5I;6%L:6L@
M=F%S=&%T82X@5&%G87-T871I('9E86MO;V0Z(`!3;V]V:71A=F%T('1E96YU
M<W0@96D@;&5I='5D+@!686IA;&EK("(E<R(@<'5U9'5B("5S('-E861I<W1U
M<V5S+@!686IA;&EK("(E<R(@<'5U9'5B(%9&4R!S96%D:7-T=7-E<RX`5F%J
M86QI:R`B)7,B('!U=61U8B!S96%D:7-T=7-E<RX`2V]H=7-T=7-L:6L@=N1L
M:0!4_&AJ96YD80!-=75D82!S86QA<_5N80!5;G5S=&%S:6X@;VUA('-A;&%S
M]6YA`%1A87-T82!E96QM:6YE('#D<FEN9P!4=6QE;75S960`5&%G87-I('-E
M861I<W1U<W-E`$MO<F1A('5U="!S86QA<_5N80!2975N:6]N`%;U=&$@:V]N
M9FEG=7)A='-I;V]N('1A9V%S:0!2:6-H(%1E>'0@161I=&]R:2!S96%D:7-T
M=7,`3?5I<W1A='5S960`4&%R96T`4&%R96T@<.1I<P!087)E;6%D(';DY')T
M=7-E9`!?4F5A('-E861E9"XN+@!2;VQL`%)U;65E;FEA`%#V]G)A(#$X,`!0
M]O9R82!V87-A:W5L90!0]O9R82!P87)E;6%L90!296$@<V5A9&5D`%)E82!S
M96%D960`4FED=3H`2F]O;F5D`$IO;VYE9"!T96MI=F%D(&OU:6=I(')I9&%D
M92!J82!V965R9W5D92!V86AE;&4`2F]O;F5D('1E:VEV860@86EN=6QT('9E
M97)G=61E('9A:&5L90!*;V]N960@=&5K:79A9"!A:6YU;'0@<FED861E('9A
M:&5L90!+Y&EV:71A`%9E;F4@1O9D97)A='-I;V]N`%)U86YD80!3+TU)344@
M:W+\<'1O9W)A869I;&EN92!A;&QK:7)I`%,O34E-12!K<OQP=&ET=60@:VER
M:0!305-,(&%U=&5N=&EM:6YE(&5I(&]L92!S86%D879A;"X`4TU3(&S\:&ES
M]6YU;6ED`%-13"!KY'-U<FED80!344P@879A;&1I<R!VY.1R='5S=&4@;&5I
M9&UI<V5K<P!34T@`U4Y.15-455,`4U]13"!KY'-U<FED80!,80!386EN="!(
M96QE;F$`4V%I;G0@2VET=',@:F$@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@
M4&EE<G)E(&IA($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@:F$@1W)E;F%D:6EN
M:60`4V%M87,@<F%A;6ES("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@
M5&]M92!J82!0<FEN8VEP90!3871E;&QI:71S:61E(&MA<W5T86IA`%-A=61I
M($%R86%B:6$`4V%L=F5S=&$@`%-A;'9E<W1A("(E<R(`4V%L=F5S=&$@)7,`
M4V%L=F5S=&$@<V5A9&ES='5S`%-A;'9E<W1A(&=E;F5R965R:71U9"!K;VYF
M:6=U<F%T<VEO;VX@4$A0('-K<FEP=&EN82!S97)V97)I(&%J=71I<W-E(&MA
M=&%L;V]G:2X`)7,@:V]N9FEG=7)A='-I;V]N('-A;'9E<W1A='5D+@!086EG
M86QD=7-E('5U96YD86UI<V4@<VMR:7!T('-A;'9E<W1A='5D(&9A:6QI.B`B
M)7,B+@!(86IU<V%D(.1I:V5S:&]O9`!496%D=7,`3W1S:6YG`$]T<VEN9W5M
M;V]T;W)I9`!686QI(&9A:6QI9`!686QI(&MU=7#D978`5F%L:2!L:7-A=&%V
M(&=R=7!P`%9A;&D@=75S(&]M86YI:P!686QI('-E<G9E<@!686QI(&QI<V%T
M878@:V%S=71A:F$`5F%L:2!K]6EK`%9A;&D@:_5I:R!K=75PY&5V82!K;V]S
M=&ES;W-A9"X`5F%L:2!O8FIE:W0`Q')A('9A;&D@;6ED86=I`%9A;&D@=F%J
M86QI:W5D(&WD<F=I9"!K87-T:61E<W0N(%-I:7,@<V%A9"!N965D(&MO<&5E
M<FED82!K:7)J82!S:7-S92X`5F%L:2!K=75PY&5V82!E<F%L9&%J83H`5F%L
M:2!K=75PY&5V82!E<VET=7-V:6ES.@!686QI(&ED96YT:71E970@;6ED82!S
M;V]V:60@;75U=&$Z`%9A;&D@:V5L;&%A:F$@97)A;&1A:F$Z`%9A;&D@:V5L
M;&%A:F$@97-I='5S=FEI<SH`5F%L:2!K86MS('-O8FEV870@=N1L:F$N`%9A
M;&D@=N1R=FES:V5E;2X`5F%L:2!O;6$@;&5M;6EK:V5E;#H`4V%A9&$@<')O
M8FQE96UI(&MI<FIE;&1U<P!386%D82!335,`4V5N96=A;`!396YS;W(Z(`!3
M97!T96UB97(`4V5R8FEA(&IA($UO;G1E;F5G<F\`2N1R:F5N=6UB97(`4V5R
M=F5R:2!A;F1M960@;VX@=F%L960@=O5I('!U=61U=F%D+@!397-S:6]O;FED
M92!H86QD=7,`4V5S<VEO;VYI($E$(&]N(&%E9W5N=60N`%-?97-S:6]O;FED
M`$AU;&L`3>3D<F$@86YD;65D(&UI<R!V]6EM86QD879A9"!S=6P@;VUA('!A
M<F]O;&D@Y')A(&UU=71A(&MU:2!S82!S96QL92!U;G5S=&%D+@!396%D:7-T
M82!VY&QI<V5D('-E<G9E<FED(&UI9&$@<V]O=FED(&]M82!P;W)T86%L:7,@
M:V%S=71A9&$N`%!A;F4@<&%I:V$@;VUA(&ME96QE+"!A:F%V]O9N9&D@:F$@
M:W5U<.1E=F$@<V5A9&ES='5S+@!-Y.1R82!O;6$@86QG<F%K96YD=7,L(';D
M<G9I<VME96TL(&QE:&5K_&QJ92!VY')S:V5N9&%M:7-E('-A9V5D=7,@:F$@
M;75U9"`@97-I='5S92!S96%D960N`%!A:6=A;&1U<P!/;&5M87-O;&5V860@
M<&%I9V%L9'5S92!U=65N9&%M:7-E('-K<FEP=&ED`%!A<F%M965T97(@;>3D
M<F%B(&UI='4@=O5I;6%L:6MK=2!A<W5K;VAT83H@`%-E:7-H96QL:60`3W-T
M;&5M:6YE`$S\:&EK;VMK=7;U=&4`2V%S(&5N86UU<V5L92!L:6YK:61E;&4@
M='5L96MS(&WDY')A=&$@:VEI<FML86AV:60_`$[D:71A`$[D:71A(&]L96UA
M<V]L979A(&IA(.1S:F$@9V5N97)E97)I='5D(&MO;F9I9W5R871S:6]O;FD@
M97)I;F5V=7-I+@!.Y&ET82!S:7-S96QO9VEM:7-E;"!E96QM:7-E('-I<W-E
M;&]G:6UI<V4@865G80!086MU(';U:6UA;'5S="!O<FEG:6YA86QI('/D:6QI
M=&%M:7-E:W,`3N1I=&$@=F%L:6IA=`!.Y&ET82!T86)E;&ET;VEM:6YG=71E
M(&UE;OS\<FEB80!.Y&ET82!V87-A:W5L("5S(&UE;OS\9`!.Y&ET82!T86)E
M;&D@;&%H=')I(&]M861U<W1E(&1I86QO;V=I`$[D:71A('1A8F5L:2!O;6%D
M=7-T92!D:6%L;V]G:0!.Y&ET82!T86)E;&D@<F5A(&]M861U<W1E(&1I86QO
M;V=I`$[D:71A('!I;&1I(&]M861U<W1E(&1I86QO;V=I`$[D:71A('5P;&]A
M9&D`2&]O=FEH;0!(;VUM:6MU;"!H;V]V:6AM860`U6AT=6P@:&]O=FEH;6%D
M`$AO;W9I:&UA9"#\;6)R=7-K;VYN87,`2VET<V5N9&$`2VET<V5N9&$@:_5I
M9V5P96%L="!N86%B97)B;&]K:V4@=O5I(&YI:'5T82!N965D(&5E<W0@Y')A
M`%-I97)R82!,96]N90!,:6ET=0!!;&QK:7)I`$%L;&MI<FIA(&%L9V]R:71M
M`%-I;F=A<'5R`%-U=7)U<P!*Y'1A(&AO;VQD=7,@=F%H96QE`%-L;W9A:VMI
M80!3;&]V965N:6$`3'5M:0!4:6AE(&QU;65S861U`%1I:&5D860@;'5M97-A
M:G5D`$AO;6UI:W5L('1I:&5D860@;'5M97-A:G5D`-5H='5L('1I:&5D860@
M;'5M97-A:G5D`$QU;64@<&%K<W5S.B``3'5M92!V964M96MV:79A;&5N=#H@
M`%-A86QO;6]N:2!S86%R960`4V]M86%L:6$`3&%U;'5D(&IA(&QU=6QE='5S
M960`4V]R=&5E<FEM:7-JY')J96MO<G)A('9A;&EK`$SD:'1E86%D<F5S<P!,
M]75N82U!869R:6MA`$SU=6YA+45U<F]O<&$@*$E33RTX.#4Y+3,I`$SU=6YA
M+4=E;W)G:6$@:F$@3/5U;F$M4V%N9'=I8VAI(%-A87)E9`!,]75N87!O;VQK
M97)A`%9A:&4@;&%H=')I=&4@=F%H96P`5F%H92!L86AT<FD@<VES=2!J82#D
MY')E('9A:&5L`$5R86QD86IA`%9A:&4`5F%H960@:F$@=F]O9&5R9'5S`$AI
M<W!A86YI80!2Y&UP<W!O<W0`17)I;>1R:VED92!S:7-E<W1U<P!%<F%L9&$@
M;&%H=')I9`!,86AU=&$@=F5E<F<`3&%H=71A(')I9&$`4W!O<G0`4W)I($QA
M;FMA`%-T86YD87)D`%-T87(@5')E:P!!;&=U<V%A<W1A`$]S87)I:6L@=O5I
M(&UA86MO;F0`3VQE:P!386QV97-T=7-F;W)M86%T`%3D;F%V(&IA(&UA:F$`
M3.1B:6IO;VYI='5D('1E:W-T`%-T<FEN9VED92!L;V5N9`!%<F%L9&$@9&]M
M965N(&%A9')E<W-I<W0`4W1I:6P@6T-34UT`4/P`06QA;6MA=&%L;V]G:2`B
M)7,B(&5I(&QE:71U9"X`5&5E;6$`2VEN;FET80!3;V]V("(E<R(@;&ES86UI
M<V5K<R!S_'-T965M:2!O;B!S86QV97-T871U9"X@4V$@96D@<V%A('-I<W-E
M(&QO9VED82!E;FYE(&MU:2!S:6YU('-O;W8@;VX@:&5A:W,@:VEI9&5T=60N
M`$%L86EN9&5K<P!,Y&MS(&MO<F1A`"(E<R(@;VX@<_QS=&5E;6D@;&ES871U
M9"X`(B5S(B!A;F1M960@;VX@<_QS=&5E;6ES="!E96UA;&1A='5D+@`B)7,B
M(&]N(&MU<W1U=&%T=60N`"(E<R(@;VX@<_QS=&5E;6ES="!E96UA;&1A='5D
M+@!+;VYF:6=U<F%T<VEO;VX@;VX@=&%G87-I(';U971U9"X@375U='5S=&4@
M;N1G96UI<V5K<R!VY')S:V5N9&$@=F%A9&5T+@!+;VYF:6=U<F%T<VEO;VYI
M('9A<G5K;V]P:6$@]6YN97-T=7,@<V%L=F5S=&%D82X`2V]N9FEG=7)A='-I
M;V]N:69A:6QI('9A<G5K;V]P:6$@)7,@]6YN97-T=7,@<V%L=F5S=&%D82X`
M(B5S(B!M=75T;6EN92#U;FYE<W1U<RX`)7,@:VER:G5T86UI;F4@]6YN97-T
M=7,`4W5D86%N`%-I<W5K;VMK=7;U=&4`4.1I:V5S973U=7,`4.1I:V5S96QO
M;VIA;F<`4.1I:V5S97!A:7-T96QI;F4`4.1I:V5S973U=7,`4.1I:V5S973U
M=7,O;&]O:F%N9P!0Y&EK97-E=/5U<SH@`%#D:6ME<V5L;V]J86YG`%#D:6ME
M<V5L;V]J86YG.B``W&QA:6YD96MS`%1U9VD`4W5R:6YA;6D`4&5R96MO;FYA
M;FEM:0!3=F%L8F%R9"!J82!*86X@36%Y96X`4W9A87-I;6%A`%)O;W1S:0!3
M:'9E:71S`%/\;FMR;VYI<V5E<FEM:7-E(&QO9VD@:W5S='5T871U9`!3>6YC
M34P`2VER:F%V:6=A(&]T<VEN9W5T:6YG:6UU<W1E<P!3_/QR:6$@07)A86)I
M82!686)A<FEI:P#$:6ME<V5T;W)M`%1U=6QI;F4@:F$@Y&EK97-E;&EN90#$
M:6ME<V5P=6AA;F=U9`!(;VUM:6MU;"#D:6ME<V5P=6AA;F=U9`!44U8@9F%I
M;`!486)E;`!486)E;&D@;VUA9'5S960`5&%B96QI=&4@:'5L:P!486)E;&D@
M;VUA9'5S960`5&%I=F%N`%1A:79A;BP@2&EI;F$@<')O=FEN=',`5&%D>FEK
M:7-T86X`5&%N<V%A;FEA(-QH96YD=F%B87)I:6L`079A;F5M:6YE.@!4]O9D
M`%1E;&5F;VYI;G5M8F5R`%9I:6UA<V4@='5N;FD@=&5M<&5R871U=7(Z`%1E
M;7!E<F%T=75R`%1E;7!E<F%T=75R.B``5&5M<&5R871U=7(\8G(@+SXH)7--
M87@E<R\E<TUI;B5S*2`F9&5G.R5S`$UA;&QI("(E<R(@96D@;&5I='5D+@!-
M86QL:61E(&AA;&1U<P!496MS=`!!:6YU;'0@=&5K<W0`5&5K<W1I(&IO;VYD
M=7,`5&5X='1O<`!.90!486D@*%1)4RTV,C`I`%1A:0!4Y&YA;64@:_QL87-T
M86UA<W0N`$944"!L86EE;F1U<R!E:2!O;&4@<V%A9&%V86PN`$AI<W1O<GD@
M<_QS=&5E;2!O;B!VY&QJ82!L_&QI=&%T=60N`$AO<F1E+TMO;&%B(&EN=&5G
M<F%T<VEO;VYI;6]O=&]R(&5I('1O971A("(E<R(M:0!)35-0(&QO9VD@86QG
M=N3D<G1U<W1A;6EN92!N=7)J=7,N`$UA:6YT96YA;F-E.CH@:VQA<W-I(&QA
M861I;6EN92!N=7)J=7,`4V5A9&5T92!A:V5N(&]N('-U;&5T=60N(%;D;&IU
M;BX`2W5I('1A:&%D(&MA<W5T861A(/5I9W5S:2P@<&5A8B!A9&UI;FES=')A
M871O<B!S96%D:7-T86UA('#\<VEV82#U:6=U<W1E('/\<W1E96UI+@!!:6YU
M;'0@86QU;6EN92!K_&QG`$MO;G1A:W1I($E$(&YU;6)R:70@96D@;>3D<F%T
M=60L(&KD971I('3\:&IA:W,@=O5I('-E92!P=75D=6(@86YD;65B86%S:7,N
M`$MI<FIE(/5N;F5S='5S(&QI<V%D82!S:6YU(&%A9')E<W-I<F%A;6%T=7-S
M92X`06QL:VER:F%S=&%T=60@:VER:F$@:V]N=')O;&QI;6ES96MS(&]N('9A
M:F$@97)A;&1I(%!'4"!A;&QK:7)J86)L;VMK:2X`2F%O='5S;FEM96MI<FIA
M($E$(&]N(&WDY')A;6%T82P@:N1E=&D@=/QH:F%K<R!V]6D@<'5U9'5B(&%N
M9&UE8F%A<VES+@!*86]T=7-N:6UE:VER:2!P;VQE(&WDY')A='5D+@!+<OQP
M=&EM:7-E:W,@;VX@=F%J82!T=7)V86QI<W0@2%144"#\:&5N9'5S="X`1F%I
M;"`E<R!P96%K<R!S:7-A;&1A;6$@)7,@;>3D<F%N9W5T+@!&86EL("5S('!E
M86MS('-I<V%L9&%M82!M:6YG96ED("5S(&WDY')A;F=U:60N`$9A:6QI(&5I
M('-A82!K;W!E97)I9&$@:7-E96YD86QE(&]T<V$N`$9A:6P@96D@<VES86QD
M86YU9"!A;F1M96ED+@!*Y')G;F5V860@<V5L;&4@;65S<V%G92]R9F,X,C(@
M:VER:F$@<.1I<V5D+@!4Y&ES96MR86%N:7)E>FEI;6D@:V%S=71A;6EN92!T
M96MI=&%B('!R;V)L965M92!);G1E<FYE="!%>'!L;W)E<FES('3D;G4@<V5L
M;&4@=F5E8FEL96AI='-E:F$@=FEG861E;&4L(&UI9&$@;65I;"!E:2#U;FYE
M<W1U(&UA:&$@<W5R=61A+B!%<VEN961A(';U:6(@;.1B=2!K=6IU=&ES97,L
M(&5D:71O<FD@9G5N:W1S:6]O;FED92!P=75D=6UI<W0@:F$O=O5I('9E96)I
M;&5H:71S96IA(&IU:'5S;&EK:W4@:VEN;FEJ;V]K<VUI<W0N($MU:2!S:6YU
M(&%R=G5T:2!O<&5R871S:6]O;FEK<R!O;B!7:6YD;W=S(#EX+"!S:6ES(&]N
M(';D9V$@=/5E;N1O;&EN92!E="!S86%D(")'96YE<F%L(%!R;W1E8W1I;VX@
M1F%U;'0B('9E871E871E(&IA('!E860@87)V=71I('1A87-KY&EV:71A;6$N
M7&Y<;E-I;F0@;VX@:&]I871A='5D+B!+;/5P<V$@3TLL(&MU:2!S;V]V:60@
M<VEI<VMI('3D:7-E:W)A86YI<F5Z:6EM:2!P<F]O=FED82X`261E;G1I=&5E
M="`B)7,B(&]N(&MU<W1U=&%T=60N`$%I;G5L="!V87-A:R!K_&QG`$-R>7!T
M7W!G<#HZ(&ML87-S:2!J86]K<R!P96%B(&]L96UA(&WDY')A='5D($=N=5!'
M('!R;V=R86UM:2!A<W5K;VAT+@!+:7)I(&UI<R!S86%D971I("5S(&%A9')E
M<W-I;&4@)7,@=&5E;6%G82`B)7,B(&]N(&%V871U9"X*4V5E(&5I(&=A<F%N
M=&5E<FD@970@:VER:2!LY&)I(&QO971I(';U:2!S96QL97-T(&%R=2!S86%D
M:2X`3FEM:2!M:61A(&MA<W5T861A(&5D:71O<FD@;&5H96=A(&QI;FMI;6ES
M96P`5N1L:F%D92!A<G8@<&5A8B!O;&5M82!A<G8N`$AO<F1E7T-R>7!T7W-M
M:6UE.CH@:VQA<W,@=F%J86(@;W!E;G-S;"!M;V]D=6QI="X`165L:7-T=7-T
M("(E<R(@96D@]6YN97-T=6YU9"!S86QV97-T861A+"!K=6YA(&%N9&UE=&4@
M:'5L:R#\;&5T87,@<W5U<FEM82!L=6)A='5D(&WDY')A`%-E9&$@=/S\<&D@
M86YD;65T92`H)7,I('9A871A;6ES96MS('9A:F%L:6MK=2!P<F]G<F%M;6D@
M96D@;&5I='5D('/\<W1E96UI<W0N`$IU='5MY')K('!E86(@;VQE;6$@_&MS
M(&WD<FLN`$%I;G5L="!V87-A:R!J82!P87)E;2!K_&QG`$%I;G5L="!P87)E
M;2!K_&QG`$5R86QD86IA('!E86(@;VQE;6$@_&MS(&WD<FLN`%-E<G9E<B`B
M)7,B(&]N(&MU<W1U=&%T=60N`%-E<G9E<B`B)7,B(&]N('-A;'9E<W1A='5D
M+@`E<R!L:6ET=6UI<W-O;W8@;VX@965M86QD871U9"X`3>3D<F%T=60@<FED
M82`H)60I('!O;&4@;VQE;6%S+@!-Y.1R871U9"!R:61A('!O;&4@;VQE;6%S
M+@!!:G5T:7-T(&9A:6QI("(E<R(@<&]L92!O;&5M87,N`%-I;G4@<VES97-T
M871U9"!T96MS="!E:2!K871T=2!E:W)A86YI;"!O;&5V86=A+@!!:6YU;'0@
M_&QE;6EN92!J82!A;'5M:6YE(&O\;&<`06EN=6QT(/QL96UI;F4@:_QL9P!3
M86%D971U9"!A;F1M960@;VX@=F%H97!E86P@:V%O='-I(&SD:6YU9"X`4V%A
M9&5T=60@9F%I;&D@96D@<V%A;G5D('-A;'9E<W1A9&$N`'=E871H97(N8V]M
M(&)L;VMK(&5I(&]L92!KY'1T97-A861A=BX`2W5J=6YD=7-T92!K871A;&]O
M9VD@(B5S(B!E:2!L96ET=60N`$5I(&]L92!M:61A9VD@<V5A9&ES=&%D82X`
M2VER:F%L(&5I(&]L92!V86AE='5L="!E<VET871A=F%I9"!O<VDN`%-E;&QE
M<R!VY&QJ87,@;VX@;&EI86QT('!A;&IU(&WD<FME+B!382!S:7-E<W1A<VED
M("5S(&WD<FMI.R!L=6)A='5D('!O;&4@<F]H:V5M(&MU:2`E<RX`(B5S(B!L
M:7-A;6ES96P@<_QS=&5E;6D@=&5K:VES('!R;V)L965M.B`E<P!+87-U=&%J
M82`B)7,B(&%N9&UE=&4@<_QS=&5E;6ES="!E96UA;&1A;6ES96P@=&5K:VES
M('!R;V)L965M.B``(B5S(B!E96UA;&1A;6ES96P@<_QS=&5E;6ES="!T96MK
M:7,@<')O8FQE96TZ(``B)7,B(&UU=71M:7-E;"!T96MK:7,@<')O8FQE96TZ
M("5S`$9A:6QI(&QA861I;6ES96P@<V5R=F5R:7-S92!T96MK:7,@<')O8FQE
M96TZ("5S(&5I(&QA971U9"X`1F%I;&D@;&%A9&EM:7-E;"!S97)V97)I<W-E
M('1E:VMI<R!P<F]B;&5E;3H@)7,@;VQI('-U=7)E;2!K=6D@=O5I;6%L9&%B
M('!I:7)A;F<@*"5D(&)A:71I*2X`1F%I;&D@;&%A9&EM:7-E;"!S97)V97)I
M<W-E('1E:VMI<R!P<F]B;&5E;3H@)7,@;&%E=&D@86EN=6QT(&]S86QI<V5L
M="X`4V5L;&4@:VER:F$@;W-A(&5S:71A;6ES96P@=&5K:VES('9I9V$`2V]N
M=&%K=&%N9&UE=&4@:6UP;W)T:6UI<V5L('1E:VMI<R!V:6=A+@!I0V%L96YD
M87(G:2!A;F1M971E(&EM<&]R=&EM:7-E;"!T96MK:7,@=FEG82X`4V5A9&ES
M='5S92!V;W)M:6P@97-I;F5S('9I9V$N($5H:R!JY'1S:60@=.1I=&UA=&$@
M;?5N92!K;VAU<W1U<VQI:W4@=N1L:F$N`%-O;W9I='5D(&%A9')E<W-I<F%A
M;6%T=2!O<&5R871S:6]O;FD@<V]O<FET86UI<V5L('1E:VMI<R!V:6=A+B!0
M86QU;B!P<F]O=FD@:&EL:F5M('5U97-T:2X`2V]N=&%K=&%N9&UE=&4@=75E
M;F1A;6ES96P@=&5K:VES('9I9V$N(%!A;'5N('!R;V]V:2!H:6QJ96T@=75E
M<W1I+@!*86]T=7-N:6UE:VER:F$@=75E;F1A;6ES96P@=&5K:VES('9I9V$N
M(%!A;'5N('!R;V]V:2!H:6QJ96T@=75E<W1I+@!3964@24U!4"!S97)V97(@
M96D@=O5I;6%L9&$@:V%U<W1A9&4@:F%G86UI<W0N`%-E92!E:2!NY&D@;VQE
M=F%T(&MO<G)A;&EK(%)!4B!A<FAI:78N`%-E92!E:2!NY&D@;VQE=F%T(&MO
M<G)A;&EK(%I)4"!F86EL+@!3964@96D@;N1I(&]L979A="!K96AT:78@:V%A
M<F1I(&YU;6)E<BX`4V5E(&1R86EV97(@=O5I;6%L9&%B('-A871A('/U;G5M
M96ED(&SD8FD@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!L
M_/QS:2P@:V%S=71A9&5S($A45%`@05!)=`!3964@9')A:79E<B!V]6EM86QD
M86(@<V%A=&$@<_5N=6UE:60@;.1B:2!724X@*&AT='`Z+R]W:6YP;&,N8V]M
M*2!L_/QS:2P@:V%S=71A9&5S($A45%`@05!)="X`4V5E(&1R86EV97(@=O5I
M;6%L9&%B('-A871A('/U;G5M96ED(&SD8FD@<VUS,F5M86EL("AH='1P.B\O
M<VUS,F5M86EL+F-O;2D@;/S\<VDL(&MA<W5T861E<R!(5%10($%0270N`%-E
M92!D<F%I=F5R(';U:6UA;&1A8B!S]6YU;6ET92!S86%T;6ES="!33510('!R
M;W1O:V]L;&EG82!LY&)I(%9O9&%F;VYE($ET86QY(&S\_'-I+"!A:6YU;'0@
M5F]D869O;F4@;G5M8G)I=&5L92X@4V5L;&5K<R!O;B!V86IA(%9O9&%F;VYE
M($ET86QY(&4M<&]S=&D@:V]N=&]T("AH='1P.B\O=W=W+C$Y,"YI="D`4V5E
M(';D;&D@;VX@:V]H=7-T=7-L:6LN`%-E92!VY&QI(';U:6(@<VES86QD861A
M('9A:60@=.1I<V%R=F4N`%-E92!VY&QI(';U:6(@<VES86QD861A(&%I;G5L
M="!N=6UB<F5I9"!J82!K;V]L;VYI="X`4V5E(';D;&D@=O5I8B!S:7-A;&1A
M9&$@86EN=6QT(&MA:&5K<V%N9&%R=F4N`%-E92!VY&QI('!E86(@;VQE;6$@
M:V]M86=A(';U:2!T_&AI:W5G82!E<F%L9&%T=60@=.1I<V%R=G5D92!L;V5N
M9`!3964@=N1L:2!P96%B(&]L96UA(&MO<G)E:W1N92!A<G8N`%-E92!VY&QI
M('!E86(@<VES86QD86UA(';D<G9I:V]O9&D@4D="($AE>"!K=6IU;"P@;N1I
M=&5K<R`G(S$R,S1A9B<N`%-E92!V;W)M(&]N(&IU8F$@;.1B:2!T]O9T871U
M9"X`4V5E(&]N("5S+@!3964@;VX@2V]L86(@1W)O=7!W87)E(&]B:F5K="X@
M4V5L;&4@;V)J96MT:2!V86%T86UI<V5K<R!V86IA9"!E+7!O<W1I(&ML:65N
M=&D@;6ES(&WU:7-T86(@2V]L86(@1W)O=7!W87)E(&9O<FUA871I+B!396QL
M:7-T92!E+7!O<W1I(&ML:65N=&ED92!N:6UE:VER:F$@;&5I860@86%D<F5S
M<VEL="`E<P!3964@:VER:2!O;B!K:7)J=71A='5D(&WD<F=I<W1I:W5S("@E
M<RD@;6ES(&5R:6YE8B!S:6YU(&]M87-T+@!3964@87)V('!E86(@;VQE;6$@
M=N1H96UA;'0@_&MS+@!3964@<V5R=F5R(&5I(&WU:7-T82!L86AT:2!P86MK
M:61A('II<"!J82!G>FEP(&9A:6QE+@!3964@<_QS=&5E;2!O;B!P<F%E9W4@
M=N1L:F$@;/QL:71A='5D+@!396QL92!K;VAA('!E86P@<&5A8B!O;&5M82!A
M<G8N`%-E92!A:V5N('1U;&5B(&%V861A(%-E861E=&4@86MN87-T`,1I:V4`
M2&5L<&1E<VL`065G`%3V]F%J871A8F5L`$%J82!E<VET=7,`06IA('9A;&EK
M`$ED82U4:6UO<@!096%L:VER:0!096%L:VER:2`H=&]O;'1I<"D`2V5L;&5L
M90!-:71M92!O8FIE:W1I('9A;&EM:7-E:W,@:&]I82!A;&P@0W1R;"`H4$,I
M(';U:2!#;VUM86YD("A-86,I(&ML86AV:2!J82!K;/5P<V$@;V)J96MT:61E
M;"X`5.1N80!(5$U,(&MO;V1I(')E>FEI;0!4;V=O`%1O:V5L874`2&]M;64`
M5&]N9V$`5FEI;6%S=&5L(&UI;G5T:71E;"!O;B!L:6EG82!P86QJ=2!N=7)J
M=6YU9"!S:7-S96QO9VEM:7-I+@#<;&5S`%!E86QM:7-E<R!R86%M:7,@*%]T
M;W`I`%3U;&ME9`!4<FEN:61A9"!J82!4;V)A9V\`5/5D92!V]6D@=F%L90!4
M90!4=6YE97-I80!4_')G:0!4_')G:2`H25-/+3@X-3DM.2D`5'5R:VUE;FES
M=&%N`%1U<FMS(&IA($-A:6-O<P!4=79A;'4`2VER:G5T82!O;6$@=F%L:6LZ
M`%56+6EN9&5K<SH@`%523`!3:6YU('-K<FEP=&D@:^1T=&5T;VEM971A;6ES
M<F%P;W)T:2!54DP`55),.@!59V%N9&$`56MR86EN80!%:2!PY.1S92!L:6=I
M(%9&4R!K871A;&]O9VEL92X`5.1I96YD879A(&MA<W5T86IA:6YF;R!L:7-A
M;6EN92!L:6ET=6UI<V5L(&5I(/5N;F5S='4N`$5I('-A82!M=75T82!61E,@
M9F%I;&D@(B5S(B#U:6=U<VDN`$5I('-A82!M=75T82!61E,@9F%I;&D@)7,O
M)7,@]6EG=7-I+@!%:2!S86$@;6EN;F$@:V%T86QO;V=I("5S+@!&86EL:2`B
M)7,B('-U=7)U<W0@<&]L92!V]6EM86QI:R!K;VYT<F]L;&ED82X`1F%I;&D@
M(B5S+R5S(B!S=75R=7-T('!O;&4@=O5I;6%L:6L@:V]N=')O;&QI9&$N`$5I
M('-A82#\:&5N9'5S="!344P@<V5R=F5R:6=A+@!34TP@_&AE;F1U<V4@86QG
M871A;6EN92!N=7)J=7,N`%9&4R!F86EL:2!K;W!E97)I;6EN92!N=7)J=7,N
M`%9&4R!K871A;&]O9VD@(B5S(B!L;V]M:6YE(&YU<FIU<RX`5D93(&MA=&%L
M;V]G:2!L;V]M:6YE(&YU<FIU<RX`5D93(&9A:6QI(&QO;VUI;F4@;G5R:G5S
M+@!61E,@:V%U<W1A("(E<R(@;&]O;6EN92!N=7)J=7,N`$5I('-A82!L=75A
M('3\:&IA(%9&4R!F86EL:2X`3&%H=&EP86MK:6UI;F4@;G5R:G5S+@`B)7,B
M(&5I('-A82!K=7-T=71A9&$L(&MA=&%L;V]G(&5I(&]L92!T_&AI+@!%:2!S
M86$@:W5S='5T861A("(E<R(Z("5S+@`E<R!E:2!S86$@:W5S='5T861A+"!K
M871A;&]O9R!E:2!O;&4@=/QH:0!61E,@:V%T86QO;V=I<'5U(&MU<W1U=&%M
M:6YE(&YU<FIU<RX`5D93(&MA=&%L;V]G:2!K=7-T=71A;6EN92!N=7)J=7,N
M`$5I('-A82!K=7-T=71A9&$@5D93(&MA=&%L;V]G:3H@)7,N`$5I('-A82!K
M=7-T=71A9&$@5D93(&9A:6QI("(E<R(N`%9&4R!F86EL:2!K=7-T=71A;6EN
M92!N=7)J=7,N`$5I('-A82!K=7-T=71A9&$@5D93(&MA=7-T82`B)7,B+@!%
M:2!S86$@:W5S='5T861A(%9&4VD@<F5K=7)S:6EV<V5L=#H@)7,N`$IO;VMS
M=F%T(&MA=&%L;V]G:2!E:2#U;FYE<W1U('1U=F%S=&%D82X`16D@<V%A(&OD
M='1E('-E<G1I9FEK86%D:2#\:W-I:V%S:G4`)7,@9&5F:6YI='-I;V]N:2!L
M86%D:6UI;F4@;G5R:G5S+@!61E,@9F%I;&D@_&UB97)T]7-T;6EN92!N=7)J
M=7,N`$5I('-A82!A=F%D82!61E,@9F%I;&D@(B5S(BX`16D@<V%A(&%V861A
M(%9&4R!F86EL:2!M=75T;6ES96MS+@!61E,@9F%I;&D@879A;6EN92!N=7)J
M=7,N`%!A:VET=60@87)H:6EV:2!A=F%M:6YE(&YU<FIU<RX`16D@<V%A(&QU
M9V5D82!61E,@9F%I;&D@*&9I;&5S:7IE*"D@;G5R:G5S*2X`16D@<V%A(&QU
M9V5D82!61E,@9F%I;&D@*&=E=$9I;&53:7IE*"D@;G5R:G5S*2X`16D@]6YN
M97-T=2!L=6=E9&$@9F%I;&DZ(`!V9G-R;V]T(&MA=&%L;V]G:2!L=6=E;6EN
M92!N=7)J=7,N`"5S(&5I('-A82#\;6)E<B!N:6UE=&%D82`E<RUK<SH@<VEH
M=&MA=7-T(&]N(&IU8F$@;VQE;6%S+@!61E,@:V%T86QO;V=I(/QM8F5R;FEM
M971A;6EN92!N=7)J=7,N`$5I('-A82#\;6)E<B!N:6UE=&%D82!61E,@:V%T
M86QO;V=I.B`E<P!%:2!S86$@_&UB97(@;FEM971A9&$@5D93(&9A:6QI("(E
M<R(N`$5I('-U=61A(/QM8F5R(&YI;65T861A(%9&4R!F86EL:2`E<R\E<RX`
M5D93(&9A:6QI(/QM8F5R;FEM971A;6EN92!N=7)J=7,N`$5I(/5N;F5S='4@
M:^1I=FET861A("=M:VES;V9S)RX`4V5D82!7;W)D:2!D;VMU;65N=&D@;VX@
M=O5I;6%T=2!T]6QG96YD861A`$5I('-A82!K:7)J=71A9&$@5D93(&9A:6QI
M("(E<R(N`$5I('-A82!K:7)J=71A9&$@5D93(&9A:6QI("AC;W!Y*"D@;G5R
M:G5S*2X`5D93(&9A:6QI(&%N9&UE=&4@<V%L=F5S=&%M:6YE(&YU<FIU<RX`
M16D@<V%A(&MI<FIU=&%D82!61E,@9F%I;&DL(&ME='1A:W9O;W0@;.1H96(@
M;/5H:VDN`$%L;&%J;V]N:71U9"!T96MS=`!486%S=&$@86QG<V5I<P!6]71A
M8B!V:6EM87-E('1E9V5V=7-E('1A9V%S:0!/;W1A;6%T=2!V87-T=7,@<V5R
M=F5R:6QT(/QH96YD=7-E(&QO;VUI<V5L.B``3V]T86UA='4@=F%S='5S('-E
M<G9E<FEL=#H@`$MA=&5G;V]R:6%T80!5;FEC;V1E("A55$8M."D`07)A86)I
M82#<:&5N9&5M:7)A861I9`!3=75R8G)I=&%N;FEA`$%M965R:6MA(-QH96YD
M<FEI9VED`$%M965R:6MA(-QH96YD<FEI:VED92!VY&EK97-A87)E9`#<:&EK
M=60`5'5N9&UA='4`5'5N9&UA='4@87!I;7-G:60@*$%022!-97-S86=E($E$
M*2X`5'5N9&UA='4@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`3>3D
M<F%T:2!T=6YD;6%T=2!A<W5K;VAT+@!4=6YD;6%T=2!K87-U=&%J86YI;6D@
M:F$@<V%L87/U;FYA+@#<:&5N9&$@<V5E(&5L96UE;G0@;&%H=&DN`$YI;65T
M=0#5:6=U<W1E=&$@<VMR:7!T:60@96D@<V%A('1U<G9A:V%A;'5T;'5S=&5L
M('!R;V=R86US96QT('-O;W)I=&%D82!L]6EK86UI<W0O:VQE97!I;6ES="X@
M2W5I(&ML]7!S860@3TLL(&[D960@;6]Z:6QL82YO<F<@=&5H;FEL:7-T('-E
M;&=I='5S="!K=6ED87,@;'5B861A('-K<FEP=&ED96P@;/5I:V5P=6AV<FET
M(&MA<W5T861A+@!%96UA;&1A(';D<G8`5&]E=&%M871A(&QA:65N9'5S`$MI
M;FYI=&$`375U9&$@)7,`375U9&$@:V%S=71A:F$`(B5S(B!M=75D971U9"X`
M575E;F1U<V4@<VMR:7!T(&MU<W1U=&%T=60N`$QA92!S97)V97)I<W-E`$OU
M:6L@<F%K96YD=7-E('!A:6=A;&1U<V9A:6QI9"!O;B!S97)V97)I<W-E(&QA
M971U9"X`3&%D:6YA('-U=7)TY&AE9`!3=75R960@<F]O;6$@;G5M8G)I9`!5
M<G5G=6%I`$MA<W5T82!P<F%E9W5S=#H@)7,`2V%S=71A(%-33&D`2V%S=71A
M(&IU:'5L(&MU:2!N:6UI+W-A;&%S]6YA($E-4U`@<V5R=F5R:7,@;VX@97)I
M;F5V+@!+87-U=&%J80!+87-U=&%J86P@)7,@96D@;VQE(&QU8F%T=60@)7,N
M`$MA<W5T86IA:&%L9'5S`$MA<W5T86IA('-E861I<W1U<P!+87-U=&%J82!R
M96=I<W1R965R:6UI;F4`4V5L;&5S('-A:61I<R!K87-U=&%J871E(')E9VES
M=')E97)I;6ES="!E:2!V]6EM86QD871A+@!+87-U=&%J86MO;G1O="!E:2!L
M96ET=60`2V%S=71A:F%N:6UI`$MA<W5T86IA;FEM:2`B)7,B(&]N(&IU8F$@
M;VQE;6%S+@!+87-U=&%J86YI;6DZ`$MA<W5T86IA;FEM:3H`2V%S=71A:F%D
M('/\<W1E96UI<SH`57-B96MI<W1A;@!61E,@:V%T86QO;V=I('!O;&4@;VQE
M;6%S+@!0=6AK=7,`3VQE;6%S;VQE=F%D(&MO<G)E:W1S960@87-U:V]H860@
M;VXZ(`!+96AT:79U<P!-:6YU=&ET92!A<G8@<')A96=U<V5S="!H971K97-T
M(&%L871E<RX`5N3D<G1U<R#\;&5T86(@)7,@;6%K<VEM=6UP:6MK=7-E+@!6
MY.1R='5S960`5N3D<G1U<V5D(&UI;&QE(&AU;&=A<W0@=F%L:61A`%9A;G5A
M='4`375U=&QI:P!696YE='-U965L80!+;VYT<F]L;&EM:6YE(&YU<FIU<R`M
M('-E92!K:7)I(';U:6(@;VQL82!P86AA=&%H=&QI:W5L="!M=75D971U9"X`
M2N1R:F5N=6UB97(`5F5R<VEO;VYI:&%L9'5S`%9E<G1I:V%A;&YE(&IO;VYD
M=7,`5F5R=&EK86%L;F4@=F]O9&5R9'5S`%9E<G1I:V%A;&YE.@!6Y&=A(&OU
M<F=E`%9I971N86T`5FEE=&YA;6D@*%9)4T-)22D`5F%A=&$@)7,`5F%A=&$@
M=N1L:7-T('9E96)I;&5H=&4`5F%A=&$@:W5I("5S`$)R:71I($YE:71S:7-A
M87)E9`!54T$@3F5I='-I<V%A<F5D`$[D:'1A=G5S`$[D:'1A=G5S.B``5F]D
M869O;F4@271A;'D@_&QE(%--5%``2$])05154P!(3TE!5%53(2$A($M54U15
M5$$@4TM225!4($O$4TE44TD@2T%404Q/3T=)4U0@)7,N`%=)3B#\;&4@2%14
M4`!786QL:7,@:F$@1G5T=6YA`$AO:6%T=7,`2V\`26QM865N;G5S='5S`$EL
M;6%A;F1M96ED('!A:W5B`%=E871H97(N8V]M`%9E96(`5F5E8FES86ET`$MO
M<F0@;N1D86QA<P!497)E('1U;&5M87-T`%1E<F4@='5L96UA<W0@)7,M:0!4
M97)E('1U;&5M87-T+"`E<P!,Y.1N92`H25-/+3@X-3DM,2D`3.3D;F4@*$E3
M3RTX.#4Y+3$U*0!,Y.1N92U386AA<F$`36EL;&ES92!R86ME;F1U<V4@<&5A
M:W,@)7,@<.1R87-T('-I<W-E;&]G:6UI<W0@879A;6$_`$UI;&QI<W0@;>1R
M:VD@:V%S=71A=&%K<V4@97)A;&1A:F%N83\`36EL;&ES="!MY')K:2!K87-U
M=&%T86MS92!J=71U;>1R9VEN83\`5VAE<F5I<R!!=7-T<F%L:6$@:V%A<G0`
M36EL;&ES960@9F%A<VED`$UI;&QI<V5I9"!P;'5G:6YA:60@;'5B861A(%)I
M8V@@5&5X="!E9&ET;W)I<RX`3&%I=7,`3&%I=7,@0U-3(/QH:6MU=&5S`"5S
M(&UE;OS\(&QA:75S('9A<V%K=6P@*&AA:VMA8B!M]6IU;6$@:N1R9VUI<V5L
M('-I<W-E;&]G:6UI<V5L*3H`5&%B96QI(&QA:75S`$QA:75S_&AI:P!,86EU
M<SH`5VEK:0!4=75L`$AO;6UI:W5L('1U=6P`5'5U;&4@:VEI<G5S('/U;&UE
M9&5S`%1U=6PZ`%1U=6PZ(`!487)K=7,`4V]O=FEN:6UE:VER:0!4]O8`5/;V
M:V]H82!A861R97-S`%3V]G1E;&5F;VX`4F5A<R`E9"!O;B!V86QE(&%R=B!V
MY&QJ=2X@4&5A:W,@;VQE;6$@)60L(&%G82!O;B`E9"X`5F%L92!A<G8@=N1L
M:G4N(%!E86MS(&]L96UA("5D+"!A9V$@;VX@)60N`%9A;&4@86QG=7-P=6YK
M="`E9"!61E,@9F%I;&D@;'5G96UI<V5L+@!8+5)E9@!8-3`Y=C,@</5H:6QI
M<V5D('!I:7)A;F=U9`!8-3`Y=C,@=O5T;64@;&%I96YD871U9"!K87-U='5S
M`%@U,#EV,R!S=6)J96MT:2!A;'1E<FYA=&EI=FYE(&YI;6D`6#4P.78S('-U
M8FIE:W1I(';U=&UE(&ED96YT:69I:V%A=&]R`%@U,#EV,R!L86EE;F1U<V5D
M`$%!`$%!04$`66%H;V\A(&MA87)T`$MO<F0@86%S=&%S`$IE96UE;@!*86@`
M2F%H+"!O;&5N(&[U=7,`3VQE9"!414M35$E215I)24U)4RX@2VSU<'-A(%L\
M/ET@970@;6EN;F$@=&%G87-I(%=94TE764<@<F5Z:6EM:2X`16D@;VQE(&QU
M8F%T=60@;'5U82!R;VAK96T@:W5I("5D(&)L;VMK:2X`4V$@96D@;VQE('-I
M<W-E(&QO9VET=60N`%-I;G4@=.1I<VYI;6D@96D@=O5I('-I<V%L9&%D82`G
M7"<@;>1R:VDN`%-A(&5I('-I<V5S=&%N=60@:V]R<F5K='-E="!E+7!O<W1I
M(&%A9')E<W-I+@!382!E:2!S96%D;G5D(&EM<&]R9&ET=60@9F%I;&D@=N1L
M:G4@=F%S=&%V=7-S92`E<R!VY&QJ861E9V$N`%-I;F0@;&]G:71I(';D;&IA
M+@!382!P96%D('-I<V5S=&%M82!K96AT:79A(&UO8FEI;'1E;&5F;VYI(&YU
M;6)R:2!M:7,@<VES86QD86(@86EN=6QT(&YU;6)R96ED(&IA(&UI;&QE(&%L
M9W5S97,@=O5I8B!O;&QA("<K)R!R86AV=7-V86AE;&ES92!S=75N86MO;V1I
M('1U;FYU<V5N82X`4V$@<&5A9"!S:7-E<W1A;6$@:V]R<F5K='-E(';DY')T
M=7-E+@!,:6ET=6UI<V4@;'5B86UI<V5K<R!P96%D('-E861I<W1A;6$@1&%T
M851R964@<_QS=&5E;6DN`%-A('!E860@<V5A9&ES=&%M82!61E,@<_QS=&5E
M;6DN`$5N;F4@<V%A=&UI<W0@;VQE:W,@=&%R:R!P<F]B;&5E;6D@:VER:F5L
M9&%D82X`4V$@<&5A9"!S:7-E<W1A;6$@55),:2!K=6AU('-E92!L:6YK('9I
M:71A8@!096%D(&WDY')A;6$@:W5S='5T871A=F$@<V5R=F5R:2X`4&5A9"!M
MY.1R86UA(&MA<W5T86IA;FEM92!M:61A('3\:&IE;F1A9&$N`%!E860@;>3D
M<F%M82!K87-U=&%J86YI;64@;6ED82!E96UA;&1A9&$N`%!E860@;>3D<F%M
M82!K87-U=&%J86YI;64@;6ED82!L:7-A9&$N`%!E860@;>3D<F%M82!K87-U
M=&%J86YI;64@;6ED82!M=75T82X`4&5A9"!MY.1R86UA('1E9V5V=7-E+"!M
M:61A('-O;W9I9"!T96AA+@!096%D('-I<V5S=&%M82!U=64@:V%T96=O;W)I
M82!N:6UE+@!096%D('-I<V5S=&%M82!)=&%A;&EA('1E;&5F;VYI;G5M8G)I
M`%-I;G4@)7,@<V5S<VEO;VX@;VX@865G=6YU9"X@4&%L=6X@;&]G:2!U=65S
M=&D@<VES<V4N`%-I;G4@92UP;W-T:2!A861R97-S.@!3:6YU('-A871J82!A
M861R97-S.@!3:6YU(&EN9F\`4VEN=2!I;G1E<FYE=&EA861R97-S(&]N("5S
M('-E<W-I;V]N:2!J;V]K<W5L(&UU=71U;G5D+B!4=7)V86QI<W5S92!T86=A
M;6ES96MS('!E860@=75E<W1I('-I<W-E(&QO9VEM82X`4VEN=2!N:6UI`%-I
M;G4@875T96YT:6UI<W/\<W1E96T@96D@=O5I;6%L9&$@:V%S=71A:F%I9"!L
M:7-A9&$N($MU:2!S;V]V:60@2&]R9&4@86)I;"!K87-U=&%J86ED(&AA;&QA
M=&$L('!E860@:V%S=71A;6$@=&5I<W1S=6=U<W0@875T96YT:6UI<W/\<W1E
M96UI+@!3:6YU(&%U=&5N=&EM:7-S_'-T965M(&5I(';U:6UA;&1A(&MA<W5T
M86IA=&4@;FEM96MI<FIA(&[D:&$L(';U:2!O;B!S964@=O5I;6%L=7,@;6EN
M9VEL(&UU=6P@</5H:G5S96P@=N1L:F$@;/QL:71A='5D+@!3:6YU('9E96)I
M;&5H:71S96IA(&[D:6(@;VQE=F%T("5S('-E<W-I;V]N:2!J;V]K<W5L(&UU
M=71U;G5D+B!4=7)V86QI<W5S92!T86=A;6ES96MS('!E860@=75E<W1I('-I
M<W-E(&QO9VEM82X`4VEN=2!V965B:6QE:&ET<V5J82!E:2!V]6EM86QD82!S
M961A(&]M861U<W0@:V%S=71A9&$N`%-I;G4@=F5E8FEL96AI='-E:F$@96D@
M=O5I;6%L9&$@;FEI;6]O9&D@='+\:VMI9&$N(%9A:G5T82!T<OQK:VEM:7-E
M:W,@0V]N=')O;"M0(';U:2!#;VUM86YD*U`N`%-I;G4@86IA=O;V;F0Z`%-I
M;G4@=F%I:V5I9&5N=&ET965T(&]N(&UU=61E='5D+@!3:6YU('9A:6ME:61E
M;G1I=&5E=#H`4VEN=2!TY&EE;&EK(&YI;6DZ`%-I;G4@<VES<V5L;V=I;6EN
M92!O;B!A96=U;G5D+@!3:6YU('5U<R`E<R!S86QA<_5N82!O;CH@)7,`375U
M9&%T=7-E9"!O;B!S86QV97-T871U9"!S96QL92!S97-S:6]O;FD@;/5P=6YI
M+@!-=75D871U<V5D(&]N('-A;'9E<W1A='5D+@!3:6YU('-A;&%S]6YA(&]N
M('9A:&5T871U9`!3:6YU('-A;&%S]6YA(&]N('9A:&5T871U9"P@=F%A=&$@
M;VUA(&4M<&]S=&D@:F$@;&]G:2!S:7-S92!U=64@<V%L87/U;F%G82X`4VEN
M=2!S86QA<_5N82!O;B!A96=U;G5D+@!3:6YU(';D;&ES960@<V5R=F5R:60Z
M`$IU9V]S;&%A=FEA`%IA:7(`4V%M8FEA`%II;6)A8G=E`%II<'!Y`%M096ED
M82!O<W5N9&%T=60@=&5K<W1=`%M(;W)D92!P<F]B;&5E;5T`6T[D:71A(&]S
M=6YD871U9"!T96MS=&D@+0!;3N1I=&$@;W-U;F1A='5D('1E:W-T:2`M("5S
M(')I9&%=`%MR:61A("5S("5S+7-T70!?2&%L9'5S`$OD<W5?<FED80!?1&%T
M851R964`7TMU<W1U=&$@<FED80!?1W)U<&ED`$%?8FD`7U!I;&1I(&]M861U
M<V5D+BXN`%],;V=I('-I<W-E`%],;V=I(';D;&IA`%]-=75D82!L:6YK:2XN
M+@!?4V5A9&ES='5S`-5I9U]U<V5D`%]%96UA;&1A(&QI;FLN+BX`7U!A:6=A
M;&1U<P!?5&%B96QI(&]M861U<V5D+BXN`%]+87-U=&%J860`86%D<F5S<VER
M86%M870`861R97-S86%T('1U;F1M871U`&MA;&5N9&5R`'9A:6MN90!VY&QJ
M=6YD9F%I;&D@;&]O;6EN92!N=7)J=7,`<VES96YD:2!A=F%M:6YE(&YU<FIU
M<P!K;/5P<V$@<VEI80!KY'-U<F5A(&MA<W5T86UI<V4@=FEG80!S96%D:7-T
M=7-E('9I9V$`96QU=.1H=&ES('/\<W1E96UI9F%I;"!O;B!P=75D=0!A;F1M
M971E(&9O<FUA861I('9I9V$`;75U9&$`:V%N;F5T(&5I(&QE:71U9`!L86YG
M96(`9F%I;`!S=75N9"`E<R`H)7,I(&IA(&MI:7)U<R`E<R`E<P!P=6AA;F=U
M;&EN90!K.@!T=`!T=6YD;6%T=2!H;W-T:6YI;6D`=FEI=FET86UA='4`:6YL
M:6YE`'-I<V5N9"]VY&QJ=6YD('9I9V$`=&%R:W9A<F$@<V5E<VUI;F4@=FEG
M80!R:61A70!M:VES;V9S('9E86MO;V0@)60@25-/(&QO;VUI<V5L+@!M;0!N
M:6UI`'!O;&4@=&5O<W1A='5D`'!O;&4@=F5E;"!T96]S=&%T=60`;>1R:VUI
M:P!P<F]T<V5N=&D`]6EG=7-E9"!P=75D=79A9`!P:6MS;&ET`'!R;W1O:V]L
M;&D@=FEG82!T96ES97,@;W1S87,`=/5U<V5B`'1E96YU<R!P;VQE(&OD='1E
M<V%A9&%V`&[D:71A(&5R:6YE=G5S:0!S;7,R96UA:6P@_&QE($A45%``<W,`
M_&AT;&%N90!L_&QI=&$@:F%V87-C<FEP="!VY&QJ80!S_'-T965M:2!V:6=A
M`/QL97-A;FYE=&4@;FEM96MI<FD`86IU=&EN92!T]7)G90!P<F]O=FD@=75E
M<W1I`&MI<FIU=&$@<V%L87/U;F$@96MS:71U<V4@=N1L=&EM:7-E:W,@:V%K
M<R!K;W)D80#\:&ET871U9`!N:6UE='4`:V%S=71A:F$@=F%L:6L`=D-A<F0`
M;#H`=V5A=&AE<BYC;VT`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE
M+V9A7TE2+P``````````````````````````````````````````````````
M```````````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U,P`P,C`P-S4`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L;V-A;&4O9F%?25(O:&5L<"YX;6P`````````````````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T-C$T`#$P-3$U-#,S-S4S`#`R
M,34U-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/WAM;"!V97)S:6]N/2(Q+C`B(#\^(`T*/&AE;'`^#0H@/&5N=')Y(&ED
M/2)S=6UM87)Y(B!M9#4](C8X8V$S,V8W9C!C.6%A931C,3`S96(T-S0Y,F-D
M8S$U(B!S=&%T93TB=7!T;V1A=&4B/@T*("`\=&ET;&4^V*_8L=JOV*?9ASPO
M=&ET;&4^(`T*("`\<&%R83[8I]F*V88@V*_8L=JOV*?9AR#8KMF$V*?8M=F'
MXH",V*?9BMF*(-BGV+(@V*?8M]F$V*?8N=BGV*H@V879A]F%(-BTV878IR#8
ML=BG(-BOV+$@V*?8KMBJV8K8I]BQ(-F"V+'8I]BQ(-F%V8KB@(S8K]F'V*\N
M(-BHV+'8I]N,(-F%V*O8I]F$(-BGV8K9AB#8K]BQVJ_8I]F'(-F&V+38I]F&
M(-F%V8KB@(S8K]F'V*\@VJG9AR#:AMF&V*\@V8;8I]F%V8?9E"#8I]F$VJG8
MJMBQV8C9AMF*VJG;C"#8JMBGV++9AR#8K]BQ(-F&V*?9A=F'XH",V*_8I]F&
M(-BTV878IR#9A=F(V*S9B-BO(-BGV+/8JMB,(-J&V8<@V8C9@MBGV8K8N=N,
M(-BWV*C9@B#8JMF"V8C9BMF%(-BTV878IR#8L=BN(-BOV*?8K]F'(-BGV+/8
MJMB,(-J&V8<@V8C8N-BGV8K9@=N,(-BWV*C9@B#9A-F*V+/8JB#9B-BXV*?9
MBMF!(-BTV878IR#8J-F'(-BYV8?8K]F'XH",V*?8JMBGV88@V*?8L]BJV(P@
MV+/8L=BJV8K8JMBQV8?8I]N,(-BSV+'9B-F*V+/9A]BGVXP@V*[8J-BQVXP@
MV*?9AMBJV*[8I]BHVXP@V+39A=BG(-J&V8K8L]BJ(-F(("XN+BX\+W!A<F$^
M(`T*("`\<&%R83[9A=BMV*K9B-BGVXP@V*?9BMF&(-BOV+':K]BGV8<@V*?8
MLB#8M]BQV8K9@B#8K]JOV879A]F4(-BLV*?9AMF%V*?8IMN,(-F%VXSB@(S8
MJMF(V*?9AMBO(-BHV8<@V+3:J=F$(-BOV838KMF(V*?9AR#8M-F%V*<@V*_8
ML=BHV8K8I]F*V*\N(-BHV+'8I]N,(-F%V*O8I]F$(-BTV878IR#9A=N,XH",
MV*K9B-BGV8;9BMBO(-F%V8C8I]BQV*\@V*_9A-BNV8C8I]F'(-BNV8C8KR#8
ML=BG(-BHV+'8I]N,(-F&V878I]F*V+0@V*_8L2#8K]BQVJ_8I]F'(-F((-F'
MV87:AMF&V8K9AB#8JMBQV*K9BMBH(-F&V878I]F*V+0@V*+9AMF'V*<@V+'8
MIR#9AMF*V+(@V*K8N=F*V8K9AB#9AMF%V*?9BMF*V*\N/"]P87)A/B`-"B`\
M+V5N=')Y/@T*(#QE;G1R>2!I9#TB;F%V8F%R(B!M9#4](F(X8V8P864Q.64U
M-V1F83!C,F(Y-C)E-3$V-S@R9C0W(B!S=&%T93TB=7!T;V1A=&4B/@T*("`\
M=&ET;&4^VJ_8LMN,V8;:K]BGV88@V878L=F(V+':K]BQ(-BHV+'9AMBGV879
MA^*`C-F'V*<\+W1I=&QE/B`-"B`@/'!A<F$^V*_8L2#8L]F%V*H@V+'8I]BS
MV*H@V*?9BMF&(-BOV+':K]BGV8<@VJ_8LMN,V8;:K]BGV88@V878L=F(V+':
MK]BQ(-BHV+'9AMBGV879A^*`C-F'V*?;C"#:J=BGV+'8J-BQV*_;C"#9@MBQ
MV*?8L2#8K]BGV+'8KR#:J=F'(-BHV*<@V8'8M-BQV*_9AB#8K]JOV879AR#9
MA=F(V+,@V*C8L2#8L=F(VXP@V8?8L2#9BMJI(-BGV+(@V*?9BMF&(-BHV+'9
MAMBGV879A^*`C-F'V*<@V*C9AR#8L=BGV*W8JMN,(-F%VXSB@(S8JMF(V*?9
MAMF*V*\@V*?8LB#8HMF&V8?8IR#8I]BSV*K9@=BGV*_9AR#9AMF%V*?9BMF*
MV*\N/"]P87)A/B`-"B`\+V5N=')Y/@T*(#QE;G1R>2!I9#TB<')E9G,M9&]?
M;6%I;G1E;F%N8V4B(&UD-3TB9&0Y-61F,#=A,#,P,S$R,S)B865A.3$Y,C@X
M8C)D,#`B('-T871E/2)U<'1O9&%T92(^#0H@(#QT:71L93[8JMBQV*S9BMBM
MV*?8JB`Z(-F&VJ_9A]BOV*?8L=N,(#H@V*?9AMBLV*?9A2#9AMJOV8?8K]BG
MV+';C#PO=&ET;&4^(`T*("`\<&%R83[8I]JOV+$@V+39A=BG(-F%V*?9BMF$
M(-BHV8<@V*?9AMBLV*?9A2#8N=F%V839BMBGV*H@V8;:K]F'V*_8I]BQVXP@
MV*C9AR#9A]F&VJ_8I]F%(-F(V+'9B-BO(-F%VXSB@(S8J-BGV+39BMBO(-BG
MV8K9AB#:K]BRV8K9AMF'(-BQV*<@V*C8I]F*V*\@V*?9AMBJV*[8I]BH(-JI
MV8;9BMBO+CPO<&%R83X@#0H@/"]E;G1R>3X-"B`\96YT<GD@:60](G!R969S
M+6-O;F9I<FU?;6%I;G1E;F%N8V4B(&UD-3TB83(Q,38R8V1F9C-B,60X9F%E
M861B-S(Y-C(T,#`S-F4B('-T871E/2)U<'1O9&%T92(^#0H@(#QT:71L93[8
MJMBQV*S9BMBMV*?8JB`Z(-F&VJ_9A]BOV*?8L=N,(#H@V*K8H]BFV8K8KR#9
MAMJOV8?8K]BGV+';C#PO=&ET;&4^(`T*("`\<&%R83[8I]JOV+$@V+39A=BG
M(-F%V*?9BMF$(-F'V+/8JMF*V*\@VJG9AR#8N=F%V839BMBGV*H@V8;:K]F'
MV*_8I]BQVXP@V+'8IR#9@MBHV80@V*?8LB#8I]F&V*S8I]F%(-BBV8;9A]BG
M(-BJV*/8IMF*V*\@VJG9AMF*V*_8C"#8I]F*V88@VJ_8LMF*V8;9AR#8L=BG
M(-BGV8;8JMBNV*?8J"#:J=F&V8K8KRX@V*_8L2#8NMF*V+$@V*?9BMF&(-BU
MV8C8L=BJ(-BJV878I]F%(-BYV879A-F*V*?8JB#9AMJOV8?8K]BGV+';C"#8
MJ-F'(-F'V8;:K]BGV84@V8C8L=F(V*\@V*?9AMBLV*?9A2#9BMBGV8'8JMF'
M(-F((-BTV878IR#8M-BGV8;8L]N,(-BHV+'8I]N,(-F%V838NMN,(-JIV+'8
MK]F&(-BBV88@V8;8KMF(V*?9A]F*V*\@V*_8I]BTV*HN/"]P87)A/B`-"B`\
M+V5N=')Y/@T*/"]H96QP/@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9F%?25(O3$-?34534T%'
M15,O````````````````````````````````````````````````````````
M`````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-3$U-#,S-S4S`#`R,38V,@`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L
M92]F85])4B],0U]-15-304=%4R]H;W)D92YM;P``````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`S-3<W,3<`,3`U,34T,S,W-3,`,#(S,S0T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````-X2!)4`````IP4``!P`
M``!4+0``BP<``(Q:````````N'@```X```"Y>```#P```,AX```-````V'@`
M``@```#F>```"P```.]X```,````^W@```0````(>0``)`````UY```I````
M,GD``!D```!<>0``)@```'9Y```,````G7D``"0```"J>0``#P```,]Y```+
M````WWD```X```#K>0``!0```/IY```H`````'H```@````I>@``"@```#)Z
M```5````/7H``!(```!3>@``"P```&9Z``"%````<GH```X```#X>@``"@``
M``=[```-````$GL```X````@>P``$0```"][```-````07L```P```!/>P``
M#0```%Q[```&````:GL```H```!Q>P``#P```'Q[```8````C'L```P```"E
M>P``#@```+)[```.````P7L```@```#0>P``+@```-E[```:````"'P``#(`
M```C?```.````%9\``!4````CWP``%$```#D?```6@```#9]``!7````D7T`
M`#0```#I?0``#0```!Y^```'````+'X```H````T?@``#P```#]^```%````
M3WX``!$```!5?@``"````&=^```)````<'X```D```!Z?@``)0```(1^```@
M````JGX``!,```#+?@``$````-]^```/````\'X```H`````?P```P````M_
M```/````#W\``!0````??P``"0```#1_```-````/G\``!(```!,?P``'@``
M`%]_```/````?G\```H```".?P``#P```)E_```(````J7\``"0```"R?P``
M%````-=_```6````['\```@````#@```&0````R````'````)H````P````N
M@```+````#N````.````:(````,```!W@```!0```'N````%````@8````H`
M``"'@````P```)*````7````EH````H```"N@```#P```+F````.````R8``
M`!@```#8@```(P```/&````.````%8$``!0````D@0``%P```#F!```7````
M48$``!<```!I@0``$P```(&!```/````E8$``!\```"E@0``#P```,6!```&
M````U8$```L```#<@0``$````.B!```5````^8$``!4````/@@``!P```"6"
M```0````+8(```4````^@@``%0```$2"```1````6H(```P```!L@@``.P``
M`'F"```4````M8(```,```#*@@``.0```,Z"```2````"(,``"<````;@P``
M+````$.#```J````<(,``"4```";@P``"@```,&#```&````S(,``"\```#3
M@P``-P````.$```N````.X0``%4```!JA```+0```,"$```M````[H0``"T`
M```<A0``0````$J%```C````BX4``",```"OA0``+0```-.%```S`````88`
M`!4````UA@``&0```$N&```I````988``"0```"/A@``$0```+2&```*````
MQH8``!````#1A@``%@```.*&```6````^88``!0````0AP``"````"6'```I
M````+H<```X```!8AP``"@```&>'```$````<H<```D```!WAP``!@```(&'
M```1````B(<```<```":AP``!````**'```&````IX<```T```"NAP```P``
M`+R'```#````P(<``!<```#$AP``$P```-R'```(````\(<```0```#YAP``
M00```/Z'```:````0(@``"````!;B```%0```'R(```&````DH@``!4```"9
MB```&````*^(```B````R(@``"X```#KB```'0```!J)```A````.(D``%0`
M``!:B0``*0```*^)```'````V8D```<```#AB0``%0```.F)```*````_XD`
M``\````*B@``#0```!J*```/````*(H```T````XB@``"0```$:*```4````
M4(H```8```!EB@``'0```&R*```3````BHH``!0```">B@``!@```+.*```4
M````NHH``%0```#/B@``9````"2+```$````B8L```X```".BP``!0```)V+
M```;````HXL``!H```"_BP``$0```-J+```1````[(L``!P```#^BP``*@``
M`!N,```A````1HP```4```!HC```$P```&Z,```2````@HP```H```"5C```
M#P```*",```1````L(P``!,```#"C```#````-:,```&````XXP```8```#J
MC```$````/&,```1`````HT```4````4C0``#````!J-```0````)XT```4`
M```XC0``#0```#Z-```&````3(T```<```!3C0``#0```%N-```'````:8T`
M``L```!QC0``!P```'V-```)````A8T```D```"/C0``"@```)F-```9````
MI(T```P```"^C0``$````,N-```2````W(T``!,```#OC0``*P````..```[
M````+XX``"````!KC@``"````(R.```V````E8X```@```#,C@``!@```-6.
M```$````W(X```X```#AC@``'@```/".```;````#X\``"$````KCP``'@``
M`$V/```9````;(\``!X```"&CP``'0```*6/```;````PX\``"````#?CP``
M)@````"0```;````)Y```!X```!#D```'````&*0```F````?Y```#,```"F
MD```)@```-J0```K`````9$``#@````MD0``+P```&:1```2````EI$``"D`
M``"ID0``$@```-.1``"B````YI$``!8```")D@``(P```*"2```H````Q)(`
M`"D```#MD@``*````!>3```?````0),``"````!@DP``)0```(&3```H````
MIY,``#````#0DP``D@````&4```A````E)0``!P```"VE```)@```-.4``!!
M````^I0```P````\E0``!P```$F5```'````494```8```!9E0``#0```&"5
M```0````;I4``!(```!_E0``$P```)*5```2````II4```P```"YE0``#@``
M`,:5```/````U94``!,```#EE0``#0```/F5```H````!Y8```,````PE@``
M#0```#26```1````0I8``!<```!4E@``&P```&R6```"````B)8```4```"+
ME@``$````)&6```$````HI8```T```"GE@``#@```+66```#````Q)8```X`
M``#(E@``"````->6```/````X)8```\```#PE@``!P````"7```-````")<`
M`!`````6EP``#0```">7```+````-9<```8```!!EP``#````$B7```1````
M59<``!D```!GEP``"P```(&7```-````C9<``"(```";EP``&P```+Z7```T
M````VI<```H````/F```&````!J8```9````,Y@``!8```!-F```#0```&28
M```4````<I@```L```"'F```(@```).8```O````MI@```L```#FF```"0``
M`/*8```9````_)@```L````6F0``%P```"*9```7````.ID```D```!2F0``
M%@```%R9```/````<YD``!D```"#F0``%@```)V9```.````M)D``!@```##
MF0``#0```-R9```F````ZID``$,````1F@``"````%6:```+````7IH``"\`
M``!JF@``#@```)J:```%````J9H```8```"OF@```P```+::```$````NIH`
M``H```"_F@``"@```,J:```/````U9H``!````#EF@``%P```/::```1````
M#IL``!D````@FP``%P```#J;```)````4IL```H```!<FP```@```&>;```%
M````:IL```T```!PFP``&P```'Z;```7````FIL```D```"RFP``#@```+R;
M```-````RYL``!(```#9FP``.````.R;```@````)9P```@```!&G```#@``
M`$^<``![````7IP``!@```#:G```!0```/.<```8````^9P``!D````2G0``
M&P```"R=```9````2)T```8```!BG0``!@```&F=```0````<)T```\```"!
MG0``$````)&=```/````HIT```L```"RG0``#P```+Z=```,````SIT```\`
M``#;G0``!P```.N=```&````\YT```X```#ZG0``#`````F>```/````%IX`
M``@````FG@``"````"^>```3````.)X``!X```!,G@``(0```&N>```@````
MC9X``!D```"NG@``%P```,B>```E````X)X``!<````&GP``!````!Z?```,
M````(Y\```,````PGP``"````#2?```+````/9\``!````!)GP``$P```%J?
M```4````;I\```P```"#GP``"0```)"?```.````FI\```L```"IGP``&P``
M`+6?```'````T9\```H```#9GP``#0```.2?```)````\I\```4```#\GP``
M`P````*@```8````!J````H````?H```!````"J@```F````+Z````X```!6
MH```%0```&6@```%````>Z````<```"!H```#````(F@```(````EJ````H`
M``"?H```!@```*J@```(````L:````(```"ZH```!@```+V@```$````Q*``
M``D```#)H```$````-.@```)````Y*````D```#NH```&@```/B@```(````
M$Z$``!D````<H0``#@```#:A```*````1:$```(```!0H0``#0```%.A```)
M````8:$``!(```!KH0``%````'ZA```=````DZ$```8```"QH0``$0```+BA
M```)````RJ$```0```#4H0``.0```-FA```]````$Z(``#H```!1H@``'@``
M`(RB```.````JZ(```0```"ZH@``!@```+^B```5````QJ(```8```#<H@``
M!````..B```1````Z*(```8```#ZH@``"@````&C```B````#*,```0````O
MHP``!0```#2C```$````.J,```P````_HP``#@```$RC```*````6Z,```4`
M``!FHP``.@```&RC```P````IZ,``#4```#8HP``*0````ZD```X````.*0`
M`"D```!QI```/P```)ND```N````VZ0``"T````*I0``'P```#BE```/````
M6*4``!(```!HI0``"P```'NE```F````AZ4``"D```"NI0``)````-BE```F
M````_:4```@````DI@``"@```"VF```@````.*8``"````!9I@``)@```'JF
M```*````H:8``!D```"LI@``*0```,:F```2````\*8```H````#IP``#```
M``ZG```/````&Z<``!`````KIP``0````#RG``!P````?:<``&8```#NIP``
M#@```%6H```)````9*@```H```!NJ```$@```'FH```3````C*@```P```"@
MJ```!@```*VH```/````M*@``!(```#$J```$````->H```1````Z*@``!P`
M``#ZJ```(P```!>I``!J````.ZD```\```"FJ0``$````+:I```$````QZD`
M``L```#,J0``(````-BI```4````^:D```P````.J@``#````!NJ```/````
M**H``!4````XJ@``*0```$ZJ```J````>*H``"8```"CJ@``)P```,JJ```I
M````\JH``"H````<JP``&0```$>K``!"````8:L``!$```"DJP``$@```+:K
M```3````R:L``!0```#=JP``#P```/*K```6`````JP``!<````9K```$```
M`#&L```1````0JP``#0```!4K```$P```(FL```2````G:P``#4```"PK```
M%````.:L```'````^ZP```P````#K0``(````!"M```4````,:T``!$```!&
MK0``%P```%BM```<````<*T``!,```"-K0``$0```*&M```:````LZT``!X`
M``#.K0``&@```.VM```1````"*X``!<````:K@``%````#*N```7````1ZX`
M`!4```!?K@``"0```'6N```0````?ZX``!$```"0K@``!@```**N```&````
MJ:X```<```"PK@``%@```+BN```&````SZX```0```#6K@``!````-NN```'
M````X*X```X```#HK@``#````/>N```,````!*\```T````1KP``#@```!^O
M```H````+J\```P```!7KP``#P```&2O```*````=*\```@```!_KP``"0``
M`(BO```K````DJ\```0```"^KP``#P```,.O```'````TZ\```@```#;KP``
M"0```.2O```4````[J\```P````#L```#0```!"P```.````'K```!8````M
ML```$0```$2P```#````5K````8```!:L```!````&&P```+````9K````L`
M``!RL```#0```'ZP```*````C+```!````"7L```#P```*BP```1````N+``
M`!<```#*L```"@```.*P```1````[;````0```#_L```#P````2Q```Z````
M%+$```4```!/L0``#````%6Q```>````8K$```X```"!L0``$````)"Q```+
M````H;$```P```"ML0``"0```+JQ```'````Q+$```H```#,L0``"0```->Q
M```.````X;$``!````#PL0``&@````&R```*````'+(```H````GL@``#```
M`#*R```/````/[(```@```!/L@``!@```%BR```'````7[(```4```!GL@``
M"P```&VR``!'````>;(```T```#!L@``"0```,^R```$````V;(```,```#>
ML@``$P```.*R```3````]K(``!,````*LP```@```!ZS```$````(;,``"4`
M```FLP```P```$RS```%````4+,```0```!6LP``"@```%NS```-````9K,`
M`&@```!TLP``"0```-VS```,````Y[,```4```#TLP``!@```/JS```;````
M`;0``"\````=M```#P```$VT```3````7;0``!L```!QM```&````(VT```7
M````IK0```X```"^M````P```,VT```(````T;0```<```#:M```"@```.*T
M```+````[;0```<```#YM```40````&U```0````4[4```P```!DM0``#0``
M`'&U```:````?[4``$H```":M0``!@```.6U```&````[+4```8```#SM0``
M"0```/JU```8````!+8``!<````=M@``!@```#6V```-````/+8``%<```!*
MM@``$P```**V```3````MK8```(```#*M@``"P```,VV```(````V;8```T`
M``#BM@``"@```/"V```.````^[8```<````*MP``"P```!*W```,````'K<`
M``T````KMP``#````#FW```)````1K<```D```!0MP``"@```%JW```'````
M9;<```D```!MMP``!P```'>W```;````?[<``!(```";MP``"@```*ZW```6
M````N;<```D```#0MP``$````-JW```2````Z[<```0```#^MP``$0````.X
M```:````%;@``!8````PN```%````$>X```7````7+@``!P```!TN```&0``
M`)&X```'````J[@```4```"SN```#````+FX```(````QK@``!<```#/N```
M#````.>X```?````]+@``!H````4N0``$P```"^Y```$````0[D```H```!(
MN0``!````%.Y```,````6+D```4```!EN0```@```&NY```X````;KD``"P`
M``"GN0``$@```-2Y```I````Y[D``#(````1N@``"@```$2Z```L````3[H`
M`"X```!\N@``,P```*NZ```S````W[H``#@````3NP``#P```$R[```8````
M7+L``!````!UNP``#P```(:[```3````EKL``!0```"JNP``$@```+^[```4
M````TKL``!4```#GNP``+0```/V[```M````*[P``#$```!9O```+@```(N\
M```O````NKP``"P```#JO```$P```!>]```(````*[T``!<````TO0``"```
M`$R]```K````5;T``"$```"!O0``&@```*.]```)````OKT``$4```#(O0``
M00````Z^```$````4+X``!,```!5O@``%````&F^```3````?KX```D```"2
MO@``"@```)R^```/````I[X``!````"WO@``!P```,B^```.````T+X```4`
M``#?O@``&P```.6^```(`````;\```8````*OP``%````!&_```1````)K\`
M``X````XOP``.````$>_```"````@+\```8```"#OP``#@```(J_```%````
MF;\```<```"?OP``#@```*>_```&````MK\``"@```"]OP``#````.:_```<
M````\[\``"D````0P```%P```#K````?````4L```%P```!RP```%````,_`
M```?````Y,```!`````$P0``!P```!7!```.````'<$```P````LP0``#```
M`#G!```3````1L$```H```!:P0``'0```&7!```9````@\$```4```"=P0``
M$0```*/!```1````M<$``"0```#'P0``%0```.S!```2`````L(```X````5
MP@``&0```"3"```(````/L(```D```!'P@``#0```%'"```*````7\(```<`
M``!JP@``#P```'+"```+````@L(``!H```".P@``"@```*G"```'````M,(`
M``T```"\P@``"````,K"```>````T\(``!(```#RP@``+`````7#```:````
M,L,```D```!-PP``"@```%?#```5````8L,```4```!XPP``%````'[#```$
M````D\,``!````"8PP``!@```*G#```'````L,,``!X```"XPP``*````-?#
M```*`````,0``!P````+Q```"P```"C$```:````-,0``!0```!/Q```!```
M`&3$```%````:<0```8```!OQ```!@```';$```;````?<0``#0```"9Q```
M-````,[$```@`````\4``"D````DQ0``(````$[%``!!````;\4``!H```"Q
MQ0``*````,S%```I````]<4``%`````?Q@``(@```'#&```(````D\8```4`
M``"<Q@``&0```*+&```9````O,8``"H```#6Q@``(P````''```N````)<<`
M`#0```!4QP``"````(G'```7````DL<```H```"JQP``!P```+7'```A````
MO<<``!````#?QP``#@```/#'```+````_\<```<````+R```$P```!/(```(
M````)\@```L````PR```"@```#S(```4````1\@``#(```!<R```!0```(_(
M```%````E<@``!<```";R```#P```+/(```$````P\@```H```#(R```"0``
M`-/(```+````W<@```T```#IR```#````/?(```.````!,D```4````3R0``
M!````!G)```-````'LD``#(````LR0``10```%_)```7````I<D``!X```"]
MR0``%````-S)```4````\<D```<````&R@``#@````[*```J````'<H```8`
M``!(R@``#````$_*```-````7,H``!$```!JR@``"P```'S*```V````B,H`
M``H```"_R@``(@```,K*```+````[<H```\```#YR@``,@````G+```.````
M/,L```4```!+RP``#@```%'+```3````8,L```<```!TRP``$0```'S+```3
M````CLL```<```"BRP``%````*K+```8````O\L```<```#8RP``!0```.#+
M```,````YLL```P```#SRP``$@````#,```$````$\P```H````8S```"P``
M`"/,```,````+\P```X````\S```#@```$O,```%````6LP```4```!@S```
M+@```&;,```F````E<P``",```"\S````P```.#,```8````Y,P``"4```#]
MS```#0```"/-```)````,<T```,````[S0``!P```#_-```*````1\T```(`
M``!2S0``$@```%7-```$````:,T```<```!MS0``#````'7-``!2````@LT`
M`!<```#5S0``!P```.W-```&````]<T```X```#\S0``#`````O.```-````
M&,X``!4````FS@``$@```#S.```/````3\X``!0```!?S@``"@```'3.```;
M````?\X``!````";S@``"P```*S.``!I````N,X``!H````BSP``%P```#W/
M```G````5<\``!H```!]SP``%P```)C/```;````L,\``!D```#,SP``'P``
M`.;/```3````!M````@````:T```"````"/0```)````+-````T````VT```
M$P```$30```#````6-```$8```!<T```/P```*/0```W````X]```%<````;
MT0``!0```'/1```?````>=$``"\```"9T0``"````,G1```-````TM$``"T`
M``#@T0``!`````[2``!/````$](``"4```!CT@``'````(G2```+````IM(`
M`!\```"RT@``'0```-+2```E````\-(``"`````6TP``)````#?3```@````
M7-,```L```!]TP``!P```(G3```-````D=,```P```"?TP``!@```*S3```Y
M````L],```<```#MTP``"0```/73```3````_],```0````3U```$````!C4
M```$````*=0```L````NU```#````#K4```2````1]0``!$```!:U```#```
M`&S4```:````>=0```T```"4U```%````*+4```.````M]0``!L```#&U```
M$P```.+4```<````]M0``"@````3U0``!@```#S5```'````0]4``!,```!+
MU0``!````%_5```7````9-4```H```!\U0``#````(?5```)````E-4```8`
M``">U0``"````*75```)````KM4```H```"XU0``$0```,/5```&````U=4`
M``X```#<U0``#@```.O5```+````^M4```L````&U@```@```!+6```'````
M%=8```8````=U@``"0```"36```'````+M8``!H````VU@``.P```%'6```H
M````C=8``#0```"VU@``%0```.O6```'`````=<```@````)UP``!P```!+7
M```%````&M<```<````@UP``#@```"C7```)````-]<```8```!!UP``"```
M`$C7```+````4=<```<```!=UP``!P```&77```<````;=<```<```"*UP``
M"````)+7```(````F]<```4```"DUP``$````*K7```0````N]<```<```#,
MUP``!0```-37```0````VM<``!0```#KUP``"P````#8```-````#-@``!<`
M```:V```!````#+8```)````-]@```H```!!V```!P```$S8```"````5-@`
M``X```!7V```'P```&;8```C````AM@``#$```"JV```)P```-S8``!D````
M!-D``!0```!IV0``50```'[9```X````U-D``$H````-V@``6P```%C:```H
M````M-H``#@```#=V@``*````!;;```L````/]L``"<```!LVP``&P```)3;
M``"I`0``L-L``",```!:W0``%P```'[=``"%````EMT``#`````<W@``)0``
M`$W>``!;````<]X``$D```#/W@``'0```!G?```8````-]\``"L```!0WP``
M(0```'S?```?````GM\``"L```"^WP``(0```.K?```G````#.```!T````T
MX```$0```%+@```S````9.```"4```"8X```)P```+[@```?````YN```#``
M```&X0``:0```#?A```]````H>$``&4```#?X0``30```$7B```O````D^(`
M`"X```##X@``,````/+B``!4````(^,``%H```!XXP``2````-/C``!*````
M'.0``#(```!GY```+P```)KD```L````RN0``"T```#WY```%P```"7E```E
M````/>4``#(```!CY0``*0```);E```^````P.4``"(```#_Y0``"P```"+F
M``!%````+N8``"$```!TY@``,````);F```E````Q^8``!P```#MY@``,0``
M``KG```'````/.<```<```!$YP``!````$SG```-````4><```L```!?YP``
M#@```&OG```%````>N<``!````"`YP```@```)'G``!9````E.<```4```#N
MYP``"````/3G```#````_><``!`````!Z```#````!+H```-````'^@```(`
M```MZ```%````##H```2````1>@```P```!8Z````P```&7H```$````:>@`
M`!\```!NZ```-0```([H```N````Q.@``"\```#SZ```%P```"/I```@````
M.^D``!L```!<Z0``&````'CI```D````D>D``!\```"VZ0``&@```-;I```@
M````\>D``!H````2Z@``,@```"WJ```:````8.H``"\```![Z@``*P```*OJ
M```?````U^H``",```#WZ@``'P```!OK```:````.^L``"4```!6ZP``)@``
M`'SK```E````H^L``"0```#)ZP``&````.[K```=````!^P``"0````E[```
M&````$KL```B````8^P``"4```"&[```/````*SL```?````Z>P``",````)
M[0``'P```"WM```@````3>T``!H```!N[0``&````(GM```F````HNT``!X`
M``#)[0``*0```.CM```>````$NX```D````Q[@``#````#ON```7````2.X`
M`"\```!@[@``)````)#N```'````M>X```\```"][@``!0```,WN```'````
MT^X``!T```#;[@``&@```/GN```'````%.\``,<````<[P``"P```.3O```5
M````\.\```8````&\```"0````WP```+````%_````T````C\```%P```#'P
M```&````2?```#,```!0\```$P```(3P```3````F/````\```"L\```!P``
M`+SP```R````Q/```"$```#W\```$P```!GQ```,````+?$``!$````Z\0``
M,@```$SQ```6````?_$```@```"6\0``"0```)_Q```*````J?$``!0```"T
M\0``'0```,GQ```(````Y_$``!\```#P\0``"````!#R```:````&?(``"<`
M```T\@``!@```%SR```5````8_(```@```!Y\@``!P```(+R```/````BO(`
M``X```":\@``$````*GR```)````NO(```D```#$\@``$P```,[R```'````
MXO(``!D```#J\@``"@````3S```*````#_,```P````:\P``*@```"?S```'
M````4O,```(```!:\P``$````%WS```8````;O,```L```"'\P```P```)/S
M```(````E_,```8```"@\P``!P```*?S```-````K_,```L```"]\P``%```
M`,GS```5````WO,``"\```#T\P``(````"3T```<````1?0```P```!B]```
M,0```&_T```%````H?0``!(```"G]```/P```+KT```2````^O0```H````-
M]0``!@```!CU```$````'_4```0````D]0``"@```"GU```3````-/4```4`
M``!(]0``!@```$[U```&````5?4```0```!<]0``#````&'U```*````;O4`
M``(```!Y]0``!````'SU```&````@?4```,```"(]0``#````(SU``!%````
MF?4``!H```#?]0``-0```/KU```H````,/8``%,```!9]@``&0```*WV``!R
M````Q_8``"`````Z]P``-0```%OW```A````D?<``$4```"S]P``,````/GW
M```H````*O@``"D```!3^```)@```'WX```E````I/@``"@```#*^```*```
M`//X```B````'/D``#`````_^0``$@```'#Y```3````@_D``!````"7^0``
M>0```*CY```)````(OH``',````L^@``?````*#Z```K````'?L``!<```!)
M^P``%@```&'[```/````>/L``!<```"(^P``'P```*#[``!`````P/L``!\`
M```!_```'````"'\``!1````/OP``!H```"0_```%````*O\```2````P/P`
M`!````#3_```$P```.3\```=````^/P```\````6_0``#P```";]```$````
M-OT```D````[_0``"P```$7]```'````4?T```4```!9_0``%````%_]```'
M````=/T```@```!\_0``#P```(7]```(````E?T```P```">_0``#P```*O]
M```&````N_T``!0```#"_0``!@```-?]```,````WOT```@```#K_0``!```
M`/3]```*````^?T```0````$_@``&0````G^```'````(_X```(````K_@``
M"0```"[^```&````./X```8````__@``!````$;^```/````2_X``!,```!;
M_@``!P```&_^```'````=_X```8```!__@``!@```(;^```0````C?X```8`
M``">_@``"0```*7^```B````K_X```<```#2_@``!P```-K^```+````XOX`
M``4```#N_@```@```/3^```+````]_X``'$!```#_P``$P```'4``0`:````
MB0`!`!````"D``$`#0```+4``0`+````PP`!``T```#/``$`!@```-T``0`X
M````Y``!`#8````=`0$`)````%0!`0`Z````>0$!``L```"T`0$`.@```,`!
M`0`<````^P$!``T````8`@$`%````"8"`0`3````.P(!`"L```!/`@$`'P``
M`'L"`0`0````FP(!`!8```"L`@$`(````,,"`0`-````Y`(!`,,```#R`@$`
M&P```+8#`0`-````T@,!`!(```#@`P$`$@```/,#`0`:````!@0!``T````A
M!`$`#````"\$`0`8````/`0!``8```!5!`$`"0```%P$`0`/````9@0!`!\`
M``!V!`$`#@```)8$`0`8````I00!`!@```"^!`$`#P```-<$`0!2````YP0!
M`"D````Z!0$`70```&0%`0!O````P@4!`)0````R!@$`C@```,<&`0"2````
M5@<!`)$```#I!P$`6P```'L(`0`@````UP@!`!D```#X"`$`&0```!()`0`7
M````+`D!``T```!$"0$`)````%()`0`/````=PD!`!,```"'"0$`#P```)L)
M`0`X````JPD!`#P```#D"0$`%P```"$*`0`6````.0H!`!,```!0"@$`$```
M`&0*`0`3````=0H!`"4```")"@$`*````*\*`0`;````V`H!`"4```#T"@$`
M)0```!H+`0`T````0`L!`"T```!U"P$`'````*,+`0`G````P`L!`!H```#H
M"P$`5`````,,`0`Q````6`P!`#4```"*#`$`'@```,`,`0`T````WPP!``@`
M```4#0$`&````!T-`0!,````-@T!``X```"##0$`#@```)(-`0`*````H0T!
M`!$```"L#0$`"0```+X-`0`&````R`T!`#@```#/#0$`%@````@.`0`6````
M'PX!`!@````V#@$`'````$\.`0!)````;`X!`!T```"V#@$`'````-0.`0`A
M````\0X!`"<````3#P$`,0```#L/`0`@````;0\!`!8```".#P$`-0```*4/
M`0`,````VP\!``@```#H#P$`(````/$/`0`O````$A`!`!X```!"$`$`,@``
M`&$0`0`*````E!`!`!D```"?$`$`"@```+D0`0`5````Q!`!`"0```#:$`$`
M$0```/\0`0!T````$1$!`!0```"&$0$`!@```)L1`0!<````HA$!`!D```#_
M$0$`1````!D2`0!$````7A(!`$H```"C$@$`3@```.X2`0`1````/1,!``H`
M``!/$P$`.@```%H3`0!=````E1,!`#8```#S$P$`-@```"H4`0`W````810!
M`#@```"9%`$`.````-(4`0!W````"Q4!`#$```"#%0$`/````+45`0`X````
M\A4!`#X````K%@$`*P```&H6`0`O````EA8!`$@```#&%@$`0@````\7`0`E
M````4A<!`!$```!X%P$`&````(H7`0`C````HQ<!`"<```#'%P$`%````.\7
M`0`-````!!@!`$4````2&`$`%P```%@8`0`/````<!@!``@```"`&`$`#0``
M`(D8`0`&````EQ@!`!(```">&`$`#0```+$8`0`)````OQ@!``H```#)&`$`
M&@```-08`0`#````[Q@!``,```#S&`$`%P```/<8`0`:````#QD!``H````J
M&0$`"````#49`0"6````/AD!`#$```#5&0$`3P````<:`0`V````5QH!``P`
M``".&@$`)P```)L:`0`X````PQH!`#@```#\&@$`4P```#4;`0`R````B1L!
M`$,```"\&P$`P0`````<`0!1````PAP!``H````4'0$`"````!\=`0`A````
M*!T!``P```!*'0$`%P```%<=`0`3````;QT!`!<```"#'0$`(````)L=`0`,
M````O!T!`!0```#)'0$`"````-X=`0`=````YQT!`!@````%'@$`&P```!X>
M`0`+````.AX!`"T```!&'@$`D````'0>`0"D````!1\!``H```"J'P$`&```
M`+4?`0`#````SA\!`!L```#2'P$`&@```.X?`0`?````"2`!`"4````I(`$`
M,````$\@`0!*````@"`!`"8```#+(`$`!@```/(@`0`C````^2`!`!\````=
M(0$`&@```#TA`0`E````6"$!`"<```!^(0$`'0```*8A`0`3````Q"$!``H`
M``#8(0$`"````.,A`0`A````["$!`!L````.(@$`!@```"HB`0`>````,2(!
M`!,```!0(@$`#0```&0B`0`9````<B(!``@```",(@$`"@```)4B`0`5````
MH"(!``H```"V(@$`$0```,$B`0`(````TR(!`!,```#<(@$`!@```/`B`0`*
M````]R(!`"$````"(P$`$P```"0C`0`8````.",!`"````!1(P$`(````'(C
M`0`Z````DR,!`$T```#.(P$`-@```!PD`0`,````4R0!`%\```!@)`$`"@``
M`,`D`0`(````RR0!``P```#4)`$`-@```.$D`0`]````&"4!`#D```!6)0$`
M0````)`E`0`\````T24!`#@````.)@$`-````$<F`0`S````?"8!`#(```"P
M)@$`-@```.,F`0`_````&B<!`#X```!:)P$`00```)DG`0`S````VR<!`$(`
M```/*`$`7@```%(H`0!'````L2@!`$<```#Y*`$`5@```$$I`0!7````F"D!
M`"<```#P*0$`3````!@J`0`D````92H!`"@!``"**@$`.0```+,K`0!1````
M[2L!`%$````_+`$`40```)$L`0!5````XRP!`#H````Y+0$`/````'0M`0!$
M````L2T!`$D```#V+0$`5````$`N`0`B`0``E2X!`#H```"X+P$`/@```/,O
M`0!,````,C`!`(,```!_,`$`&`````,Q`0`(````'#$!``\````E,0$`"@``
M`#4Q`0`:````0#$!`!H```!;,0$`(````'8Q`0`D````ES$!`"(```"\,0$`
M$0```-\Q`0`3````\3$!`!D````%,@$`%0```!\R`0`/````-3(!`#P```!%
M,@$`"@```((R`0`7````C3(!`!$```"E,@$`%P```+<R`0`;````SS(!``(`
M``#K,@$`#````.XR`0`>````^S(!``H````:,P$`'@```"4S`0`7````1#,!
M``8```!<,P$`#P```&,S`0`,````<S,!`!4```"`,P$`'````)8S`0`-````
MLS,!`!0```#!,P$`&````-8S`0`:````[S,!``P````*-`$`!@```!<T`0`/
M````'C0!``\````N-`$`)P```#XT`0`/````9C0!``\```!V-`$`*P```(8T
M`0`B````LC0!`$<```#5-`$`#0```!TU`0`E````*S4!`!@```!1-0$`%@``
M`&HU`0`3````@34!``\```"5-0$`"@```*4U`0`/````L#4!`$4```#`-0$`
M"@````8V`0`1````$38!`#`````C-@$`$P```%0V`0`>````:#8!`!X```"'
M-@$`"````*8V`0`Z````KS8!`!X```#J-@$`*`````DW`0`;````,C<!`!,`
M``!.-P$`$0```&(W`0`/````=#<!`$````"$-P$`A````,4W`0`.````2C@!
M`!$```!9.`$`4@```&LX`0`<````OC@!``P```#;.`$`'0```.@X`0`#````
M!CD!``P````*.0$`%0```!<Y`0`5````+3D!`!4```!#.0$`&0```%DY`0`E
M````<SD!`"$```"9.0$`*@```+LY`0`H````YCD!``X````/.@$`"P```!XZ
M`0`"````*CH!`!T````M.@$`*````$LZ`0!2````=#H!`"\```#'.@$`#@``
M`/<Z`0`=````!CL!`!P````D.P$`)P```$$[`0!5````:3L!`$L```"_.P$`
M$P````L\`0`B````'SP!`+L```!"/`$`,````/X\`0`&````+ST!`!X````V
M/0$`(````%4]`0`Q````=CT!`#8```"H/0$`"@```-\]`0`*````ZCT!`!P`
M``#U/0$`%````!(^`0`4````)SX!`!8````\/@$`$@```%,^`0`4````9CX!
M``\```![/@$`%@```(L^`0`(````HCX!``\```"K/@$`(@```+L^`0`9````
MWCX!`!<```#X/@$`#@```!`_`0`:````'S\!`!,````Z/P$`,@```$X_`0`X
M````@3\!`#@```"Z/P$`-@```/,_`0`W````*D`!`#\```!B0`$`+0```*)`
M`0`(````T$`!`!$```#90`$`!@```.M``0`*````\D`!`!,```#]0`$`#P``
M`!%!`0`H````(4$!`"@```!*00$`%0```'-!`0`3````B4$!`!D```"=00$`
M%P```+=!`0`Z````ST$!``X````*0@$`#P```!E"`0`-````*4(!`!$````W
M0@$`#````$E"`0`/````5D(!`"````!F0@$`#0```(="`0`&````E4(!`%<`
M``"<0@$`$````/1"`0`]````!4,!``H```!#0P$`"````$Y#`0`/````5T,!
M``P```!G0P$`#P```'1#`0`.````A$,!``X```"30P$`"````*)#`0`0````
MJT,!``0```"\0P$`!0```,%#`0`/````QT,!``\```#70P$`#P```.=#`0`L
M````]T,!``L````D1`$`'@```#!$`0`6````3T0!`!8```!F1`$`!@```'U$
M`0`5````A$0!`!<```":1`$`$@```+)$`0`7````Q40!`"P```#=1`$`%```
M``I%`0`9````'T4!`!L````Y10$`!````%5%`0!)````6D4!`$D```"D10$`
M20```.Y%`0`L````.$8!`!4```!E1@$`#P```'M&`0`*````BT8!`!4```"6
M1@$`"@```*Q&`0`,````MT8!`#,```#$1@$`$0```/A&`0`/````"D<!`#@`
M```:1P$`"````%-'`0`(````7$<!``@```!E1P$`$0```&Y'`0`3````@$<!
M`!P```"41P$`"````+%'`0!:````ND<!`$<````52`$`3@```%U(`0`V````
MK$@!`%H```#C2`$`,@```#Y)`0!<````<4D!`$(```#.20$`2P```!%*`0`O
M````74H!`!,```"-2@$`(````*%*`0`)````PDH!`%````#,2@$`/@```!U+
M`0`N````7$L!`#P```"+2P$`"@```,A+`0`,````TTL!`#P```#@2P$`.```
M`!U,`0!-````5DP!``L```"D3`$`*@```+!,`0!+````VTP!`"@````G30$`
M%0```%!-`0`:````9DT!`!H```"!30$`$@```)Q-`0!X````KTT!`)@````H
M3@$`X````,%.`0`=````HD\!``X```#`3P$`#P```,]/`0`:````WT\!`!L`
M``#Z3P$`%0```!90`0`,````+%`!`!T````Y4`$`)0```%=0`0`K````?5`!
M`"@```"I4`$`-0```-)0`0`U````"%$!`-T````^40$`&P```!Q2`0`5````
M.%(!``X```!.4@$`#@```%U2`0`P````;%(!`!L```"=4@$`$0```+E2`0`/
M````RU(!`!8```#;4@$`*````/)2`0!$````&U,!`$0```!@4P$`0````*53
M`0!`````YE,!`$$````G5`$`00```&E4`0`@````JU0!`&8```#,5`$`%@``
M`#-5`0`6````2E4!`!8```!A50$`%@```'A5`0`1````CU4!`!X```"A50$`
M'@```,!5`0`5````WU4!`!0```#U50$`40````I6`0`<````7%8!`!P```!Y
M5@$`2@```)96`0`9````X58!``\```#[5@$`&@````M7`0`2````)E<!`"P`
M```Y5P$`&@```&97`0`K````@5<!`"````"M5P$`)@```,Y7`0`@````]5<!
M`$`````66`$`.@```%=8`0`>````DE@!`!L```"Q6`$`(P```,U8`0`]````
M\5@!`"0````O60$`)0```%19`0`,````>ED!`!\```"'60$`"````*=9`0`5
M````L%D!``T```#&60$`#````-19`0`6````X5D!`!0```#X60$`"@````U:
M`0`(````&%H!`!@````A6@$`&````#I:`0`:````4UH!`!8```!N6@$`&P``
M`(5:`0`C````H5H!`#T```#%6@$`$P````-;`0`:````%UL!``\````R6P$`
M#P```$);`0`5````4EL!`$L```!H6P$`$````+1;`0`/````Q5L!``X```#5
M6P$`"````.1;`0`1````[5L!`",```#_6P$`#0```"-<`0`>````,5P!`!<`
M``!07`$`(````&A<`0`=````B5P!``@```"G7`$`#@```+!<`0`$````OUP!
M``\```#$7`$`$0```-1<`0`6````YEP!`!4```#]7`$`)@```!-=`0`F````
M.ET!`",```!A70$`*````(5=`0`-````KET!`!L```"\70$`"@```-A=`0`9
M````XUT!`(````#]70$`$0```'Y>`0`5````D%X!`$(```"F7@$`'@```.E>
M`0`D````"%\!`!4````M7P$`%0```$-?`0`7````65\!``T```!Q7P$`$P``
M`']?`0`3````DU\!`!<```"G7P$`'@```+]?`0`T````WE\!``P````38`$`
M$0```"!@`0`3````,F`!`!@```!&8`$`#````%]@`0`(````;&`!``@```!U
M8`$`"````'Y@`0`3````AV`!`'0```";8`$`'P```!!A`0`/````,&$!``8`
M``!`80$`"@```$=A`0`>````4F$!`!P```!Q80$`(````(YA`0`"````KV$!
M`!$```"R80$`0````,1A`0`#````!6(!``@````)8@$`'0```!)B`0`5````
M,&(!`!@```!&8@$`@P```%]B`0`)````XV(!``P```#M8@$`"````/IB`0`*
M`````V,!`$X````.8P$`7````%UC`0`>````NF,!`"(```#98P$`-````/QC
M`0`S````,60!`#$```!E9`$`$P```)=D`0`$````JV0!``H```"P9`$`"@``
M`+MD`0`6````QF0!`!<```#=9`$`"@```/5D`0"&`````&4!`!H```"'90$`
M$0```*)E`0`6````M&4!`"L```#+90$`<0```/=E`0`&````:68!`!,```!P
M9@$`!@```(1F`0`+````BV8!`"\```"79@$`+0```,=F`0`(````]68!``P`
M``#^9@$`KP````MG`0`B````NV<!`"$```#>9P$`#`````!H`0`1````#6@!
M`!,````?:`$`(````#-H`0`.````5&@!`!````!C:`$`#````'1H`0`3````
M@6@!`!$```"5:`$`$P```*=H`0`7````NV@!`!P```#3:`$`&@```/!H`0`:
M````"VD!`!H````F:0$`'````$%I`0`:````7FD!`"P```!Y:0$`%0```*9I
M`0`-````O&D!`!P```#*:0$`#P```.=I`0`>````]VD!`"$````6:@$`!@``
M`#AJ`0`5````/VH!`!H```!5:@$`%@```'!J`0`4````AVH!`!<```"<:@$`
M'@```+1J`0`:````TVH!``@```#N:@$`"````/=J`0`1`````&L!``L````2
M:P$`+0```!YK`0`6````3&L!`"T```!C:P$`,@```)%K`0`>````Q&L!``H`
M``#C:P$`&@```.YK`0`(````"6P!`!P````2;`$`!````"]L`0`$````-&P!
M`&D````Y;`$`3P```*-L`0`E````\VP!`$8````9;0$`60```&!M`0`3````
MNFT!`%H```#.;0$`0@```"EN`0!'````;&X!`$<```"T;@$`3````/QN`0`I
M````26\!`",```!S;P$`+@```)=O`0`F````QF\!`"4```#M;P$`)0```!-P
M`0`?````.7`!`"T```!9<`$`)````(=P`0!.````K'`!`$X```#[<`$`4@``
M`$IQ`0!2````G7$!`%````#P<0$`30```$%R`0!"````CW(!`!,```#2<@$`
M,P```.9R`0`/````&G,!`#D````J<P$`1````&1S`0!%````J7,!`!,```#O
M<P$`<@````-T`0!Y````=G0!`!$```#P=`$`-`````)U`0`4````-W4!`!@`
M``!,=0$`"P```&5U`0`+````<74!`!8```!]=0$`'@```)1U`0`3````LW4!
M`!D```#'=0$`$@```.%U`0`\````]'4!``P````Q=@$`!@```#YV`0`<````
M178!`!<```!B=@$`%0```'IV`0!2````D'8!``H```#C=@$`!@```.YV`0`<
M````]78!``P````2=P$`"@```!]W`0`<````*G<!``\```!'=P$`40```%=W
M`0`8````J7<!`"T```#"=P$`8P```/!W`0`@````5'@!`$(```!U>`$`G@``
M`+AX`0`K````5WD!`#T```"#>0$`$P```,%Y`0`6````U7D!`!8```#L>0$`
M&`````-Z`0`,````''H!`!<````I>@$`$@```$%Z`0`Q````5'H!`"````"&
M>@$`"````*=Z`0`7````L'H!`!H```#(>@$`.````.-Z`0`B````''L!`"8`
M```_>P$`&````&9[`0`V````?WL!``@```"V>P$`#@```+][`0`D````SGL!
M`!D```#S>P$`%0````U\`0`7````(WP!``@````[?`$`*P```$1\`0`.````
M<'P!`!<```!_?`$`$P```)=\`0`.````JWP!`#@```"Z?`$`(@```/-\`0!"
M````%GT!`!X```!9?0$`#P```'A]`0`0````B'T!`#,```"9?0$`#@```,U]
M`0`C````W'T!``@`````?@$`(@````E^`0`(````+'X!``@````U?@$`)@``
M`#Y^`0!+````97X!``@```"Q?@$`'````+I^`0`,````UWX!`!L```#D?@$`
M%P````!_`0`9````&'\!``@````R?P$`"@```#M_`0`.````1G\!`#4```!5
M?P$`70```(M_`0!K````Z7\!`#@```!5@`$`00```(Z``0`U````T(`!`'0`
M```&@0$`-0```'N!`0!#````L8$!`$X```#U@0$`AP```$2"`0`[````S((!
M``X````(@P$`"````!>#`0`K````((,!`"D```!,@P$`&P```':#`0`L````
MDH,!`#D```"_@P$`/P```/F#`0`(````.80!`!\```!"A`$`"@```&*$`0`3
M````;80!`#T```"!A`$`'````+^$`0`-````W(0!`!$```#JA`$`"````/R$
M`0`3````!84!`!$````9A0$`$0```"N%`0`3````/84!`"0```!1A0$`30``
M`':%`0`/````Q(4!``H```#4A0$`)````-^%`0`7````!(8!``H````<A@$`
M&P```">&`0`;````0X8!`!@```!?A@$`%````'B&`0`6````C88!`!4```"D
MA@$`"````+J&`0`,````PX8!`!P```#0A@$`2@```.V&`0!V````.(<!`"T`
M``"OAP$`.@```-V'`0`C````&(@!`",````\B`$`#@```&"(`0`B````;X@!
M``,```"2B`$`!@```):(`0`/````G8@!``\```"MB`$`&````+V(`0`-````
MUH@!`%$```#DB`$`!@```#:)`0`@````/8D!`!$```!>B0$`%0```'")`0!7
M````AHD!`"````#>B0$`$````/^)`0`>````$(H!`#,````OB@$`"@```&.*
M`0`C````;HH!`"X```"2B@$`$````,&*`0`E````THH!`"L```#XB@$`#```
M`"2+`0`(````,8L!`!,````ZBP$`%0```$Z+`0`8````9(L!``8```!]BP$`
M&````(2+`0`2````G8L!`!8```"PBP$`%0```,>+`0`5````W8L!``L```#S
MBP$`"@```/^+`0!2````"HP!`$L```!=C`$`20```*F,`0`(````\XP!`"L`
M``#\C`$`.0```"B-`0`.````8HT!``X```!QC0$``P```("-`0`0````A(T!
M``X```"5C0$`"````*2-`0`@````K8T!``\```#.C0$`$@```-Z-`0`8````
M\8T!`($````*C@$`'P```(R.`0`&````K(X!``\```"SC@$`$````,..`0`@
M````U(X!`!P```#UC@$`-P```!*/`0`C````2H\!`!X```!NCP$`.0```(V/
M`0`3````QX\!`#0```#;CP$`%@```!"0`0`>````)Y`!`/````!&D`$`)0``
M`#>1`0`A````79$!`$<```!_D0$`)0```,>1`0`?````[9$!`"4````-D@$`
M(0```#.2`0`M````59(!`!4```"#D@$`#@```)F2`0`*````J)(!``X```"S
MD@$`%P```,*2`0`D````VI(!``H```#_D@$`D@````J3`0"1````G9,!`%(`
M```OE`$`@````(*4`0`:`````Y4!`%,````>E0$`/@```'*5`0`(````L94!
M`!4```"ZE0$`9````-"5`0`*````-98!`&L```!`E@$`5P```*R6`0`[````
M!)<!`"(```!`EP$`5````&.7`0!#````N)<!`#T```#\EP$`+P```#J8`0`V
M````:I@!`#$```"AF`$`%0```-.8`0`(````Z9@!`!L```#RF`$`&P````Z9
M`0`-````*ID!`#D````XF0$`#0```'*9`0`*````@)D!`!L```"+F0$`#```
M`*>9`0`@````M)D!``8```#5F0$`"````-R9`0`(````Y9D!`!L```#NF0$`
M&P````J:`0`/````)IH!`!T````VF@$`&@```%2:`0`E````;YH!`!4```"5
MF@$`&P```*N:`0`8````QYH!`"T```#@F@$`-@````Z;`0`5````19L!``H`
M``!;FP$`*P```&:;`0`.````DIL!`",```"AFP$`$P```,6;`0`3````V9L!
M`!$```#MFP$`"@```/^;`0`2````"IP!``H````=G`$`#P```"B<`0`:````
M.)P!``T```!3G`$`'````&&<`0`5````?IP!`!,```"4G`$`#@```*B<`0`,
M````MYP!``H```#$G`$`"@```,^<`0`.````VIP!`!````#IG`$`)@```/J<
M`0"0````(9T!`$$```"RG0$`40```/2=`0`H````1IX!``H```!OG@$`$P``
M`'J>`0`3````CIX!``P```"BG@$`"````*^>`0`1````N)X!``H```#*G@$`
M"````-6>`0`*````WIX!`!````#IG@$`$````/J>`0`7````"Y\!`"P````C
MGP$`"````%"?`0`(````69\!`!````!BGP$`"````'.?`0`7````?)\!`!<`
M``"4GP$`!P```*R?`0`*````M)\!`!,```"_GP$`'````-.?`0`3````\)\!
M`!4````$H`$`&0```!J@`0`&````-*`!``T````[H`$`#P```$F@`0`1````
M6:`!``X```!KH`$`#@```'J@`0!)````B:`!`"<```#3H`$`/0```/N@`0`V
M````.:$!`)\```!PH0$`&@```!"B`0!E````*Z(!`%0```"1H@$`;P```.:B
M`0!A````5J,!`#````"XHP$`9````.FC`0`Z````3J0!`#P```")I`$`20``
M`,:D`0`T````$*4!``X!``!%I0$`)````%2F`0`4````>:8!`+P```".I@$`
M;0```$NG`0`X````N:<!`'P```#RIP$`LP```&^H`0`@````(ZD!`!@```!$
MJ0$`,P```%VI`0`F````D:D!`"8```"XJ0$`10```-^I`0`L````):H!`#``
M``!2J@$`)@```(.J`0`8````JJH!`$T```##J@$`0````!&K`0`Q````4JL!
M`#(```"$JP$`4@```+>K`0#*````"JP!`%(```#5K`$`BP```"BM`0""````
MM*T!`$@````WK@$`40```("N`0!5````TJX!`(@````HKP$`E````+&O`0!V
M````1K`!`'@```"]L`$`5````#:Q`0!&````B[$!`$@```#2L0$`2@```!NR
M`0`H````9K(!`$4```"/L@$`3````-6R`0!.````(K,!`(@```!QLP$`.```
M`/JS`0`9````,[0!`(\```!-M`$`+P```-VT`0!1````#;4!`#\```!?M0$`
M*@```)^U`0!9````RK4!``8````DM@$`#````"NV`0`(````.+8!`!4```!!
MM@$`$0```%>V`0`7````:;8!``H```"!M@$`(P```(RV`0`$````L+8!`(\`
M``"UM@$`"@```$6W`0`(````4+<!``@```!9MP$`(````&*W`0`1````@[<!
M`!T```"5MP$`#0```+.W`0`4````P;<!`"L```#6MP$`$`````*X`0`#````
M$[@!``0````7N`$`,@```!RX`0!J````3[@!`%````"ZN`$`5@````NY`0`K
M````8KD!`#0```".N0$`*````,.Y`0!&````[+D!`#P````SN@$`-P```'"Z
M`0`[````J+H!`$````#DN@$`+@```"6[`0`Z````5+L!`"X```"/NP$`.```
M`+Z[`0!0````][L!`#,```!(O`$`.````'R\`0`\````M;P!`#<```#RO`$`
M3````"J]`0`\````=[T!`$8```"TO0$`-0```/N]`0`[````,;X!`#P```!M
MO@$`20```*J^`0`W````]+X!`#H````LOP$`,@```&>_`0!L````FK\!`#P`
M```'P`$`00```$3``0!%````AL`!`$8```#,P`$`0````!/!`0`R````5,$!
M`#T```"'P0$`-P```,7!`0`R````_<$!`#L````PP@$`$P```&S"`0`A````
M@,(!`"L```"BP@$`1@```,["`0`T````%<,!``\```!*PP$`#P```%K#`0`,
M````:L,!`!D```!WPP$`.````)'#`0`C````RL,!``L```#NPP$`DP$``/K#
M`0`:````CL4!`"````"IQ0$`$@```,K%`0`5````W<4!`!T```#SQ0$`'```
M`!'&`0`T````+L8!`!,```!CQ@$`<P```'?&`0`<````Z\8!`"`````(QP$`
M'````"G'`0`7````1L<!`&0```!>QP$`0````,/'`0`9````!,@!`!X````>
MR`$`&````#W(`0!,````5L@!`",```"CR`$`$0```,?(`0`2````V<@!`!,`
M``#LR`$`'`````#)`0`@````'<D!``X````^R0$`1````$W)`0`,````DLD!
M`"@```"?R0$`00```,C)`0`,````"LH!`"<````7R@$`#````#_*`0`(````
M3,H!`!,```!5R@$`$P```&G*`0`B````?<H!``L```"@R@$`$0```*S*`0`3
M````OLH!``L```#2R@$`)@```-[*`0`:````!<L!`!D````@RP$`&P```#K+
M`0!/````5LL!``P```"FRP$`$````+/+`0`8````Q,L!`#T```#=RP$`"P``
M`!O,`0`$````)\P!``T````LS`$`"@```#K,`0`1````1<P!`!D```!7S`$`
M%@```'',`0`4````B,P!`!4```"=S`$`6@```+/,`0`C````#LT!`"@````R
MS0$`#P```%O-`0!L````:\T!``8```#8S0$`'````-_-`0!=````_,T!`!,`
M``!:S@$`$0```&[.`0`)````@,X!``0```"*S@$`!P```(_.`0`9````E\X!
M`"\```"QS@$`!P```.'.`0`(````Z<X!``8```#RS@$`!@```/G.`0`6````
M`,\!`!8````7SP$`!0```"[/`0`$````-,\!``P````YSP$`!@```$;/`0`5
M````3<\!`'(```!CSP$`)P```-;/`0!B````_L\!`%,```!AT`$`C````+70
M`0`8````0M$!`+$```!;T0$`20````W2`0!Z````5](!`%,```#2T@$`2@``
M`";3`0!H````<=,!`%(```#:TP$`4P```"W4`0!1````@=0!`%<```#3U`$`
M7@```"O5`0!1````BM4!`#\```#<U0$`5@```!S6`0`D````<]8!`"````"8
MU@$`%0```+G6`0"]````S]8!``T```"-UP$`V@```)O7`0"Y````=M@!`$P`
M```PV0$`-P```'W9`0`@````M=D!`!<```#6V0$`*````.[9`0`U````%]H!
M`%P```!-V@$`.P```*K:`0`T````YMH!`*$````;VP$`+@```+W;`0`M````
M[-L!`#$````:W`$`%@```$S<`0`I````8]P!`#(```"-W`$`$P```,#<`0`.
M````U-P!``,```#CW`$`$0```.?<`0`-````^=P!`!0````'W0$`#````!S=
M`0`<````*=T!``@```!&W0$`"````$_=`0`8````6-T!`!$```!QW0$`#```
M`(/=`0`4````D-T!`!H```"EW0$`&@```,#=`0`.````V]T!`!@```#JW0$`
M"@````/>`0`(````#MX!`"$````7W@$`#````#G>`0`7````1MX!``8```!>
MW@$``@```&7>`0`*````:-X!``@```!SW@$`"0```'S>`0`&````AMX!`!P`
M``"-W@$`+````*K>`0`'````U]X!``@```#?W@$`#@```.C>`0`(````]]X!
M`!D`````WP$`#P```!K?`0`5````*M\!`$,```!`WP$`$0```(3?`0`+````
MEM\!`!<```"BWP$`!0```+K?`0`"````P-\!``L```##WP$``0```"X````^
M````W`0``,(`````````T`0```````#M`@``````````````````*P$`````
M``!%!0``C`4``.,"``!D!0``#0```+````!(`0``````````````````F0$`
M``\$``"@!````````-T$```7!0```````)D"``!Y````Y`$```````"1`P``
M`````(D$````````H@0``,,#``#R!````````#4"``#J!```TP(`````````
M````9@$``!H#```0`P```````/@$``!;`P``!P$``+,!``#3`P``````````
M`````````````$4#```4`@``G04``'`$``!_`P``>P,```````"%`@``````
M```````.````F`(```````"*`P```````'X!``#]!```+P(````````:`@``
M?`0``)\%``"2!```J0$``+L#``"S````LP,``.X!````````?0,````````V
M````F`0``*T!``#J`@``.@,`````````````I@4``%<"```G!0``^P```(P#
M``"2`````````+`$``#G`@``V`(```````"<`@``WP````````!X!0``5P,`
M`#@#````````.`(```H```!\`P``%04````#``#W`P```````&<!```\`0``
M100``#T%``"?`0``?@`````````?````=@```+\!`````````````!D#````
M````+P,``-``````````U@,``(@!```U`P```P$``/@!``"C`0```````/4$
M``#Q`@``K@0``,`````;````2`,```````#``P``F@(``/P$````````K@``
M`&$```!I`0```````-(#``!7!0``'P4```````!$`@``[```````````````
M)`0``````````````````,H"``!8!```%0`````````S````OP(``),```!4
M`P``ZP,``)D%```Q!```>`(``'X"``!=````N`0``*````````````````<$
M````````]`(```````#S`P``7P(``%@#````````#`$``%L!``!R`P``"0$`
M``````"&`@``````````````````_`(``(L#````````V@0``$L!``#:`0``
M`````'8!``"O!```-@$``"@#````````.0,``*X!``#G`0``I0(``$$!``#S
M`0``%`4``&D%``!Z`0``,0`````````.!0``S00``'D!``"(````MP```(("
M```8!````````)$$``!E`P``````````````````)P```-X$``!F!0``@00`
M`!<#``#``0``_P$````````?`P``)````#(!`````````````)X!```+````
M]`,```````"T`P````````````!R!0````````````"!`@``(`$````````#
M````[P$``+X!``"'````Z00``.8````<`@```````)<%``#(!```I@$``$\#
M````````500``"(#``#7````+04``+0`````````N`$``.(#``"_`P``%0$`
M`#8#```!`P``\0$``!<```"G!```PP$``%D````J``````````T%```F!```
M%@4```````#@!```*P(```````"U`@``A@4``%D#``!-!0``D`4`````````
M`````````'`!```&`@``50(```````")`P````````````"\!```$04``)`!
M``!)`0``^`(``"D`````````#P,``'("````````YP0``(D```#8`0``\0``
M`,4$``"/`0``9P(``)T$````````/P4``(T```!S`0````````````"%!```
M:P,``*4#````````.0```&\!``#'!```U@````````!T`````````#X%``!8
M`0`````````````C!0``*`4``!D%``!\`0``#`(``"0"``"=````>```````
M``"A````Z0```.$"``!Z!```(@0``*(!``"*`0```````((```"/!0``O@``
M``D"``"&!``````````````*!```W`(``.8!``"C````>P0``&4%```\````
M)`$``#(%```>`P``<```````````````)`,``(@"``!2!0``%`,``#,$``"X
M`P``4P4``!P%`````````````&0#``!6!0``2P0``+(!```1`````````(\$
M``"6!```3P(``````````````````&T$``"3`@``^P0``/L!``">`@``>@4`
M`/0`````````F0```-D#`````````````.8#``"*!````````.("``#>`0``
M3@,``(T!`````````````*L$````````6P4```````"O`0`````````````/
M`@``5P0``,8```#]````H04``*4%````````UP,``(,```!N`@``.@$``.\#
M``!)!0``7@,``)(%``"+!0``LP0```D#```3`@``````````````````R`(`
M`-$````]`0``>0,``-D!``"4!0````````````"]`0````````````!U`P``
MA````.$!``"6````3@```)`"``!O`P``EP```*<"```]`P```````.L```!G
M`````````"P!``"M`P```````(($``!5`````````+<#``!(!```@04``!H`
M````````:`$``(8#``"$!0````````````"J`0``Y`(``/8`````````````
M````````````B`,``!8"``"D`0``[@,``,D"``#R`@```00``%4!``!.`0``
M`````,H$``"H`````````+\$``#.`@``E@,``+0$``!B`P``2@0``!T%````
M````'P0``.4#```^`@```````'$$``!9`@```````&`$``#?`@``.`4``*0%
M````````!P(``%(!``!0!````````!,```#&`P``L`(``.P"````````%`$`
M`#<```#<````HP4```````#K`0``#@,``"L$``````````````````#^`0``
M4@(``'0"``"[`0```````'4"````````4P$``%T%``".`0``J@```'\```#*
M`0``&00``)$!``"U````A`(``%P#`````````````$L#``#)!```XP$```T"
M``#>`@``#@0```````#9!```!@0``&@"``#Y`0``X00````````,````````
M`#("``#M`0``7`(``-`#``"H`@``7P4``.L"``#$`@``'0$``!@!``#3`0``
M\@,``$X%``"2`0```````*,$```;!```N````&(!```(!0``"@(````"```1
M`0``````````````````Z`,```P$``!&`P``Z@```!(%```@`@``(04``+X"
M``!J````+00````````J!```T@0``)@%````````+````%H!``"A`0``I@,`
M`.`!``"O`@``FP4``#L"```K!0``2@4``"<$```<`0``E0,```````"Z````
MKP,```````"2`@``-P4```@$``````````````@!````````'@```'X#``"8
M````10```,T!``#S````^@0``(\```")`@``F@,```````!)`P``F`$``(L$
M``#\`0``#P```#<!```^`P``P0(``#L`````!0``L0$``,(!```E!0``=`0`
M`+P#``!,`@``$P4``(T"``!1`@````````````#\`P```@,``-L"``"Z!```
M`````)<!``!K!0```````%0"````````!P,``%$$``!Y!0```````)D#``!'
M````70(````````Q!0``R0``````````````3@0``)\"```\!0``AP0```D%
M``##`````````$\```"#`P``Q0,``!T$``#I`@``6@,```````!\````XP0`
M`#\````N`@```````#$#```A````@P0``)8"``"U`0```````!<"````````
M.P$```````!C`@``#0,``',#``"=`P``)@```+H!```I`@``Z@$``!@"````
M````JP$```````"L`@``QP,``-P#``"B`P```````'T!``#>`````````!4"
M``"U!```004`````````````7`$``&@%```?`@``"`(``#0#``#Z`@``````
M`($#``#-`@``1P0```````#:`@``D0````````#,`P``^0,``&$!````````
M&@$```````"4!````````.4````3`P``%@$``$(#``!9`0``J0```)<$```6
M`P``/0(``'($````````K`,``&8````7`0``5@,``&@#````````'@4``+,"
M``!=`P``(@(```````!,`P``+0```)````#$`P``XP,``-$$``!T`0``=`,`
M`&X`````````(@```+(```#F!```FP,```````!6`@``S0,``.P!```-!```
M?@4``-0`````````AP$``)L!``!-````%P0``(\#``!8`@```````"$$``!C
M````U0,``(``````````_@,``',%```E`0``%0,``$\!``!2!````````.$`
M``#T!```.`0``````````````````/\#```U`0``8`(```````#&`@``Z`0`
M`&H$`````````````#`!``"1`@``C````"`````2`0``C0,```````!'`P``
M\00``#T$``"=`0``+@4`````````````_P```',$``#H````,0$``((%``!@
M`P``:P```'T%````````V@,``"4#``!B!```+@,``!($``![!0``@P(``(4!
M``#=`0``D`,```````#S!````````.T```"3`0``-`$``*T`````````````
M`&<$``!(````!04`````````````B`0```````!C`P``````````````````
M`````%X%``!8!0````````````"$`0```````-4"````````UP(``,P```"G
M`P``S@,```````#Z`P``6@(````````Z!0```````)P$``"Y`@``U@(``%`%
M````````$P0``$(````#`P```````!$$``#P`P``W@,```4"````````K`$`
M`-@```#O!```9@0``(X$````````SP```%8````H!```K0(```P#```X````
MT@(``!`!``#K!````````+D!`````````````*8```"J!`````````($``"^
M!```'P$``/D```#2````-`4``,L```#L`P``M@$```````"@!0``"@4``*H"
M````````;0,```````"M!````````,,"``!1````8@````````#&!```"P4`
M`&0```!^!```S`0```````"6`0``!@$``.($``#A`P``RP(``'T$``!3`@``
MI0$```````"1!0``(0$``&\```!P`@``^0(```0```"A`@``MP0```4!````
M````T0$``!4$``!0````&`4``*<!````````.P0``)D$````````>@(`````
M``!>`@``KP```$$#````````)@,```("````````I`,``!X"````````[`0`
M`&P!````````````````````````D`0``$4"``#H`0``7`4`````````````
MEP(``(L!``":!0``CP(```````#+`P``9`(```````"R`@````````````"4
M`@``6P0```````"Q`@````$``/`"``"B`````````-8!``!S`@```````$0%
M``!O!0``;0```$L%``!:````O`$``&<#``#^!```@`$```````!<````K`0`
M`,8!```2````!00``+H#``!]`@``(P```#L#````````@`(``(D!````````
MV`,``,`"``#_!`````````````!M`0``_0$```D````@`P``````````````
M`````@```!H%``!,````1`0``&\"````````5`0``)4%````````2`4``#<$
M``!,`0``0@4``&X%``"^`P``80,``(,%`````````````!H$``#5````Y0(`
M`+P````/`0``*P```!8````!!0``4P```#,!``#4`P``:@,``#````#+!```
MZ0$``(H```!F`P``)`4`````````````:@4``-0"``!&!0``4P0``'@#``#M
M`P``E0`````````1`P``?P(``#D$```+`@``)P(``'\$````````]@,``#L%
M````````SP$``#4$``!C!`````````````!C!0``A0```+L$```-`0``=04`
M`.@"``!=!```7`0```````!?`````````'<```!@`0``+@0``&4$``#I`P``
M*`$```````"D`@``^`,`````````````^00``'<!``!E````V0(`````````
M````R0,`````````````NP````````!Q!0``<0,``,("````````;`,``-8$
M``#<`0```````"T#```B`0```P0``,0!``!Q`````````%H%``!-`0``E@4`
M`)X$``!N!```T@$``%L````C!``````````````=````N0,``,X$``#*````
MWP$``-4!`````````````+L"`````````````($`````````U`0``),#``!U
M````U`$``)P```!P!0``R````*D"```L`@``A@```.````",!```Q0```-\$
M``#P````F@```*X#``#N!```S@$``*0$```L!0``*@(```8```!4`0``!`,`
M`.X"``!\!0``:@(``,4"````````6@0````````F!0``^`````````#7`0``
ML0```'@$``!G!0``0`,``,$#```_!```(P(``"$#````````;04``.0````+
M`P``C@```*`"```F`0``5`4``#<#``#T`0``20````````!E`@``>00`````
M```T!````````"P#````````>@,``#4%````````7P$``&P```#F`@``````
M`(D%``!&`@```````(8!```S!0```````*D#```O`0``*04``(P"``#%`0``
MSP(``#X!``#,`@``C@(``'4!``#@`P````````H#```0!````````*$$````
M`````````$D$````````2`(``!@```!0`@``[P```*8"`````````````$H"
M```0!0````````(%```\`@```````'8"``!'`@``````````````````````
M``````!"`0``,`0``+T"``!N`P``,@````@`````````30,```L!``!/!```
MX@````````!Q`0``(0(``"8"``#U````_````$0```"R!```4@````````#$
M````QP(```@#``"U`P``J`$``'L"````````````````````````GP```!$"
M``!H!```+`0``"\````R!```0`4``.(!```$`@```````!("``"C`P``?0``
M``0$```C`0`````````````'!0``&0(```````"]````]@0``"`%````````
M404``&4!````````V0```*0```#`!```M`$``)X%``"K`P``V@```'D"````
M````FP0``(@%``!!!````````*H#``!I!````````*X"````````T0(``(T$
M``";````M@0``(H"```````````````````$!0``;`0```````!"`@``````
M``````!+`@``^P,``(L"```#`@``]P$``+8#``!2`P``E`,``)X```!0`P``
M?`(``(`$`````````````!L#````````#@(`````````````A`,``,<```#3
M```````````````S`@`````````````J!0``B@4``'<"```\!`````````H!
M```0`@```````/4#``!X`0``7@$``&T"```O!```$@,`````````````EP,`
M`.T$````````9`0``,$$``![````\`0```8%````````(@4``!P$``!&!```
M``````````"F!```P0$````````>`0``7@0``+T$```Q`@``7@```&("``#8
M!```H`,``*4`````````00(```````!,!```5P$``/T"``!@!0``\`$`````
M``"3!`````````````!#`P``;P0`````````````[P(``-L!````````VP``
M`/,"```T````N0```(4#``!?!```RP$``#\"``!I`@``30(``#0"``#R````
MG`,``%L"``#;`P``N@(````$``"]`P``@0$````````_`P``?P4``%`!```O
M!0``300``-,$``">`P``!`$```````#-````.@```)\#``!K`@``*0$``+D$
M```@!```0`0```````"Q!````````/<```!,!0```````'<#``"\`@``/@0`
M`'`#```X`0```@$````````P!0``'````$H`````````)0(``$,!```N`0``
M*P,``$,"``"?!```IP4``)4!``#7!````````-L$``#!````````````````
M`````````",#````````0P4``$($``!5!0```````/T#```8`P```````!,!
M````````````````````````*`````````#D`P```````)4$``!W!```@@,`
M`"<!```=`@``BP```#`#``"'!0``````````````````:0,``(T%```Y!0``
MN`(```````"W`0````````````"V`````````&$%``##!```;`(``&P%````
M````:P0``!X$````````````````````````0````)(#````````Z@,`````
M``!K`0```````.4!```6!```-@(```````!9!```!0,``)4"```S`P``/0``
M````````````,`(````````;`0``"P0``.,```"H!````````%\#``!)`@``
MF`,``#D!```9````G`$``$H!```'````<@$``/X```!.`@```0$``#(#```U
M````3P4``"@"```J`0``C@4``!T#`````````````#D"````````DP4``%,#
M``!Q`@```````$0#``!4`````````&0!````````]P(``&8"``",`0``QP$`
M`'<%``!7```````````````%``````````````!&`0``E`$``&H!````````
M``````````!6`0``40$``(`#````````=@,`````````````F@0``*L````4
M!````````*4$````````K````%D%``!*`P``=`4```````!H````````````
M````````AP,``/4!``"H`P``F@$``&,!```Z!```$````'(```!&````````
M`-$#``#(`P``#@$``&X!```\`P``OP```-T```!U!````````(0$``#V`0``
M-P(``)0````M`0``>@````````"G````J00```````#[`@```````*,"```/
M!0``=@0``"T"```;!0``@`4``$0!``"A`P``Y`0``#\!``"R`P``T`$``+8"
M``#(`0```````(4%```Z`@``40,````````9`0``2P```&(%``!I````````
M``````#@`@``6````%4#````````WP,``/\"```V!```L`,``"D$``!'`0``
M_@(``'\!```&`P``[@```-4$``#=`P```0(``+0"``!#!```FP(``*`!````
M`````````$,```#=`@``G0(``$<%```I`P``10$```D$``!``0```````/4"
M``!6!```R0$``)P%```J`P``'`,``&````#/!````````$$```"Q`P``C@,`
M`&$"``!S````&P(```````#/`P``AP(``((!``"W`@```````'L!```#!0``
MYP,`````````````0`(``+`!```V!0```````/(!``#W!````````/$#```G
M`P````````````#V`@``@P$```````!=`0```````,0$`````````````/H!
M``#,`0``YP````````#*`P``JP(``,($``!A!```#`4``!0`````````````
M`'8%``"B!0````````````#0`@```````,X```#Z````H@(`````````````
MP@,```````#E!```)0```"4$````("@E<R!D87ES(&%G;RD`("A!8V-E<W-K
M97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY
M97-T97)D87DI`"!A="``(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S
M>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T
M96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S960@;V8@
M)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D(&1A>7,@
M=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"UD87D@9F]R96-A<W0`
M)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N
M8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N
M(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`
M)7,@870@)7,@)7,`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X
M(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@
M=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F
M;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#
M86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`+"!G
M=7-T:6YG(``L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O
M("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA
M=``R-"!H;W5R<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R
M('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B
M;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N
M`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG
M;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M
M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`
M02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N
M`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!
M('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE
M<W-A9V4N`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W97)S`$%-(%-N
M;W<@4VAO=V5R<P!!32]030!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!
M8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93
M(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`
M06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@
M9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($-H
M:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE
M=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!
M9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D
M('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D
M9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D
M('5S97(`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E
M<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE
M<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`06QI87,`06QI9VX`06QI9VYM
M96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!
M;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED97,`06QL;W<@;75L=&EP;&4@
M861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_
M`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T
M92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R
M;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N
M871E('1E>'0Z`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06YO
M;GEM;W5S(%!R;WAY`$%N<W=E<@!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,
M:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R
M97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN
M9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E
M('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E
M<W0@9F]R("5S(#\`07)M96YI86X@*$%235-#24DM."D`07)T`$%S:R!F;W(@
M8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I
M;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N
M;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X
M:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES
M=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E
M;G0@<VAA<F4N`$%T=')I8G5T97,`075G=7-T`$%U=&A?8WER<W%L.B!297%U
M:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A
M8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T
M:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O
M;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?
M:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E
M('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`
M075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@
M9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@
M<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`
M079A:6QA8FQE(&9I96QD<SH`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R
M`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE
M+@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"87-E;&EN90!";&]C:R`B)7,B(&]F
M(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!"
M;&]C:R!4>7!E`$)O;&0`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN
M97-S.@!";W)D97)S`$)O=&@`0F]T=&]M`$)U;&QE=&5D($QI<W0`0TU3`$-2
M0P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN
M`$-A;&5N9&%R`$-A;&T`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T
M:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N(&YO="!W
M<FET92!T;R!F:6QE("(E<R(`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E
M<CH@)7,`0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A;F-E;`!#86YC96P@4')O
M8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F
M:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET
M:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I
M<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES
M="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D
M(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A
M;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<'1I
M;VX`0V%R<FEE<@!#871E9V]R:65S(&%N9"!,86)E;',`0V5L;"!0:&]N90!#
M96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`
M0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`
M0V5N=&5R`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC
M871E($1E=&%I;',`0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA;F=E`$-H86YG
M92!9;W5R(%!A<W-W;W)D`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T
M:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO
M=7(@96UA:6QS+@!#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P
M;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAI
M;&4`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET
M:6]N86P@*$)I9S4I`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N
M86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@
M<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-L87-S(&1E9FEN:71I
M;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S
M`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T
M80!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E
M(%=I;F1O=P!#;&]U9',`0VQO=61Y`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P
M<V5D(&)O<F1E<G,`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I
M;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD
M(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M<&%N>0!#;VUP=71E<G,`
M0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E
M<P!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYN96-T:6]N(&9A
M:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@
M=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE
M8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S`$-O;G1A8W1S
M('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+@!#;VYT:6YU90!#;V]K:64`0V]P>0!#;W!Y('-E;&5C=&EO;@!#;W5L9"!N
M;W0@4$=0(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE
M<W-A9V4N`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L
M9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT
M86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@
M;F]T(&)I;F0@=&\@;&1A<"!S97)V97(`0V]U;&0@;F]T(&-H96-K(&)A;&%N
M8V4N("5S`$-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R`$-O=6QD
M(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D
M96-R>7!T(%!'4"!D871A+@!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T
M82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L
M971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5T97)M:6YE
M('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O
M;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE
M(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N
M;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L
M9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S
M:R!M;V1U;&4@)7,`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E
M="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O
M<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A
M:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@
M9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO
M="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I
M<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E
M<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I
M;VXN`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@
M82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!T:&4@
M8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@
M=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E
M(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@
M)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U
M;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U<&1A
M=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-
M86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;G1E9"!T97AT`$-O
M=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N
M97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS
M`$-R961I="!C87)D(&YU;6)E<@!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@
M:7,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N
M="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@
M)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL
M;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5
M*0!$1`!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&4`1&%T92!296-E:79E
M9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`
M1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U
M;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT(%-H96QL`$1E9FEN
M:71I;VYS`$1E;&5T90!$96QE=&4@1W)O=7``1&5L971E(%!E<FUI<W-I;VX`
M1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@
M8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L
M971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F
M;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$
M96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT(&-O
M;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&EV97)Y('1I;64`1&5S
M8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I
M;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`
M1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I
M;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E
M8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`
M1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4
M048I`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$
M;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N
M8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N
M86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]W;FQO860`1&]W;FQO
M860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0
M('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$524@!%9&ET
M`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!0
M97)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO
M;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES
M<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%;&5M96YT+BXN`$5M`$5M86EL`$5M
M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL
M('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%
M;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@:6YS97)T
M:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%
M;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@>65A<@!%;FQA
M<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO
M=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S
M<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`
M16YT97(@=&AE(&EM86=E(%523"!H97)E`$5R<F]R`$5R<F]R(&-R96%T:6YG
M(&)L;V-K.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S`$5R<F]R('5P
M9&%T:6YG('!A<W-W;W)D.B`E<P!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N
M`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T
M97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G
M:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E
M<SH`17AE8W5T90!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP96-T960@)RDG
M`$5X<&ER871I;VX@1&%T90!%>'!O;F5N=`!&1R!#;VQO<@!&5%`@=7!L;V%D
M(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL
M960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE
M8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&
M86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!3
M05-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:7(`
M1F%T86P@17)R;W(Z`$9A>`!&96)R=6%R>0!&97<@4VAO=V5R<P!&97<@4VYO
M=R!3:&]W97)S`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@
M9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&
M:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R
M<P!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L;V%T`$9O
M9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O
M<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T
M("A4048I`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE`$9O
M<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D
M<P!&<@!&<F%M97,`1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&
M=6QL($UO;VX`1G5L;"!.86UE`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M
M`$=A;&QE<GDZ`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D
M($-O9&4`1VEV96X@3F%M90!';P!';V]G;&4@4V5A<F-H`$=R87ES8V%L90!'
M<F5E:R`H25-/+3@X-3DM-RD`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@
M;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!S`$=U97-T(%!E<FUI<W-I
M;VYS`$=U97-T8F]O:P!(5$U,`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C;W=A
M<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B
M;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U
M;F0N`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE8G)E=R`H25-/+3@X
M-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`
M2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z
M`$AI9V@`2&]?;64`2&]M90!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O<GD`
M2&]M92!0:&]N90!(;W)D90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@
M9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.
M;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA
M8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(
M;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D
M92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B
M:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B
M.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@
M9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE
M('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO
M=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D
M:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E
M(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@
M;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(
M;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET
M>0!(=6UI9&ET>3H@`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S
M`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O
M>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@061D
M<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL
M;W=E9"!#2412(&)L;V-K+@!)7VYS97)T(%)O=R!"969O<F4`26-O;G,@3VYL
M>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M
M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P
M96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I
M8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O
M(&-H96-K('1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN
M`$EF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM
M86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@
M>6]U<B!B<F]W<V5R+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@
M55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!)
M;6%G92!U<&QO860`26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F
M:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!)
M;F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M
M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E
M<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@
M26YD96YT`$EN9&EV:61U86P@57-E<G,`26YF;P!);F9O<FUA=&EO;@!);F9O
M<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);G-E<G0@0U]O;'5M;B!!
M9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN
M:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A
M9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O
M<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R
M96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@
M;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO
M9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@
M861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S
M=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN
M<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T
M(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G
M<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R
M90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@
M<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,
M:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I
M8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT
M96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN
M=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@
M9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`
M26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED
M(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE
M=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P<F]T
M;V-O;"X`26YV86QI9"!R96-I<&EE;G0Z("(E<R(`26YV86QI9"!S:&%R92!O
M8FIE8W0`26YV86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E
M(&1A=&$N`$EN=F5N=&]R>0!);G9E<G0@<V5L96-T:6]N`$ES;VQA=&5D(%0M
M4W1O<FUS`$ES<W5E<@!)=&%L:6,`2F%N=6%R>0!*87!A;F5S92`H25-/+3(P
M,C(M2E`I`$IE<G-E>0!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E
M<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V5E
M<"!O<FEG:6YA;#\`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I
M8V%T:6]N+@!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG
M=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+;W)E86X@*$550RU+4BD`3&%?
M>6]U=`!,86YG=6%G90!,87-T($AA;&8`3&%S="!087-S=V]R9"!#:&%N9V4`
M3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S
M="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,87<`3&%Y
M;W5T`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&EG:'0@1')I>GIL
M90!,:6=H="!286EN`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I;B!,871E
M`$QI9VAT(%)A:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI
M9VAT(%-N;W<`3&EG:'0@4VYO=R!3:&]W97(`3&EN:P!,:6YK('!O:6YT<R!T
M;SH`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E
M('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES="`M('5S
M97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L
M<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,
M:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI
M<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET
M97)A='5R90!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I
M;64`3&]C871I;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`
M3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R
M9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG
M('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I
M;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`34T`34]41`!-4RU43D5&
M($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-86=I8P!-86EL
M`$UA:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86YA9V4@=&AE(&QI<W0@;V8@
M8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@
M8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R
M-"!M87``36%P475E<W0@;6%P`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E
M;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM
M<&]R=&%N="]!;G-W97)E9"D`36%T8VAI;F<@9FEE;&1S`$UA>"!A;&QO=V5D
M(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP
M(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI
M;75M(&QE;F=T:`!-87D`365D:6-I;F4`365M8F5R<P!-96YU(&UO9&4Z`$UE
M<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L
M;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@
M=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&%R
M(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO
M8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O
M<B!T:&4@861M:6YI<W1R871O<BX`365T:&]D`$UE=')I8P!-:61D;&4`36EM
M92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T
M(#8@:&]U<G,Z(`!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG(&-O;F9I
M9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@
M=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E
M($E$+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R
M871E`$UO9&EF:65D($1A=&4`36]D:69Y(%523`!-;VYT:"!A;F0@>65A<@!-
M;VYT:&QY`$UO;VX@4&AA<V5S`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y
M`$UO<W1L>2!3=6YN>0!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`
M36]V92!5<`!-;W9E(&1O=VX`36]V92!U<`!-=6QT:2UL979E;"!D<F]P(&1O
M=VX@;&ES=',`375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`37D@06-C
M;W5N="!);F9O<FUA=&EO;@!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!.
M3RP@22!$;R!.3U0@06=R964`3F%M90!.971S8V%P92!"87-E(%523`!.971S
M8V%P92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),
M`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),
M`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF
M:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=R!#871E9V]R>0!.97<@36]O
M;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@<&%S<W=O<F0`3F5W('!A
M<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+@!.97<@<&%S<W=O<F1S(&1O;B=T
M(&UA=&-H+@!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.
M97AT`$YE>'0@;W!T:6]N<P!.:6=H=`!.;P!.;R!A=F%I;&%B;&4@8V]N9FEG
M=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I
M;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C
M:"!T96UP;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@
M<&]S:71I;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A
M=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9')E;B!C86X@8F4@
M861D960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&
M:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L
M:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO(&EC;VYS(&9O=6YD+@!.;R!L;V-A
M=&EO;B!I<R!S970N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E
M8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R
M='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-7
M1"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--
M0B!A=71H96YT:6-A=&EO;BX`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!R=6QE
M<P!.;R!S97!A<F%T;W(@<W!E8VEF:65D+@!.;R!S:61E<P!.;R!T96UP;W)A
M<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE
M(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U
M<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E
M<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D
M:6,@*$E33RTX.#4Y+3$P*0!.;W)T:&5R;B!(96UI<W!H97)E`$YO="!!9G1E
M<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT960N
M`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W
M<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C
M=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!.=6UB97)S
M(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L
M:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R96%T;W(`3V-T86P`3V-T;V)E<@!/
M9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU
M<W0@8F4@9&EF9F5R96YT+@!/;&0@<&%S<W=O<F0`3VQD('!A<W-W;W)D(&ES
M(&YO="!C;W)R96-T+@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E
M9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E
M;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E
M;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R
M('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W
M`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y
M<W1E;0!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R960@3&ES=`!/<F=A
M;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I
M;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I
M;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R;6ES<VEO
M;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!'4"!$
M:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI
M8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@
M4VAE;&P`4$T@3&EG:'0@4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO
M=R!3:&]W97)S`%!-(%0M4W1O<FUS`%!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S
M:6YG`%!?2%`@4VAE;&P`4&%D9&EN9P!087)T;'D@0VQO=61Y`%!A<W-W;W)D
M`%!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O
M<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A
M=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A
M<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R
M;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R
M8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M
M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E
M<FUI<W-I;VX@(B5S(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO;G,`4&5R;6ES
M<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5T
M<P!0:&]N90!0:&]T;W,`4&EX96QS`%!L96%S92!C;&EC:R!I;G1O('-O;64@
M8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T
M:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@
M=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD
M(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E
M9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E
M(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES
M(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE
M87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@
M<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@<F5A
M9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE
M('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@='EP92!T:&4@;F5W
M(&-A=&5G;W)Y(&YA;64Z`%!O;&ET:6-S`%!O;&QS`%!O<VET:6]N:6YG(&]F
M('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O
M('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E8VEP:71A
M=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E9G-?;&1A<#H@4F5Q=6ER
M960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N.B!2
M97%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S=7)E
M`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0
M<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@;W!T
M:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L
M96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T('1E>'0`4'5B;&EC($ME
M>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,O4')I=F%T92!K97EP86ER
M(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!1=65R>0!1=6]T80!24T$@
M4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN
M($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A
M:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@;65S
M<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T
M(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@
M)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S
M.@!2969R97-H(%!O<G1A;"!6:65W.@!296QA=&EO;G-H:7`@0G)O=W-E<@!2
M96UA<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N
M97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V
M92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E
M('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O
M<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U
M;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L
M9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=6ER
M960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S
M=V]R9`!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E='EP92!N97<@<&%S
M<W=O<F0`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@
M161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG
M:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O=&%T92`Q.#``
M4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P
M<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R
M;W=S(&]N;'D`4G5N`%,O34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U
M=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`
M4U%,(%-H96QL`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%M92!F<F%M
M92`H7W-E;&8I`%-A=F4`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE
M<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S
M97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U
M<F%T:6]N+@!38VEE;F-E`%-E87)C:`!396%R8V@@16YG:6YE<P!396QE8W0@
M1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L
M96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R
M('1O(&%D9`!396QE8W0@86QL`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S
M+@!396QE8W0@86X@;V)J96-T`%-E;&5C="!N;VYE`%-E;&5C="!T:&4@8VAA
M<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A
M;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A
M+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@
M9F]R;6%T.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG
M93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T:6UE
M(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y
M;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U
M86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;G-O<CH@`%-E
M<'1E;6)E<@!397)I86P@3G5M8F5R`%-E<W-I;VX@240@97AP:7)E9"X`4V5T
M`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W
M;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V
M97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN
M`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A
M=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L
M;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y
M(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B
M;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE
M=&5R.B``4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME
M>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&1I9F9E
M<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@
M9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE
M('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA
M;`!3:&]W('!I8VME<@!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_
M`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE
M($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R
M=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA
M;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L
M;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAR:6YK
M`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@
M=&AE('=A>2!F:7)S=`!3:6=N('5P`%-I9VYA='5R90!3:6=N871U<F4@06QG
M;W)I=&AM`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;F]W`%-N;W<@4VAO=V5R
M`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S
M($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@
M`%-O;F=S("8@4&]E;7,`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D
M9')E<W,`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H97)N($AE
M;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C92!B
M971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C
M:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A;0!3<&5C:6%L($-H87)A8W1E
M<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O
M<G1S`%-T86YD87)D`%-T87(@5')E:P!3=&%R="!Y96%R`%-T871E(&]R(%!R
M;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3
M=')I;F<@;&ES=`!3='EL92!;0U-370!3=0!3=6)J96-T`%-U8FUI=`!3=6)S
M8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C
M97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E
M92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R
M871I;VXN`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R
M871I;VX@9FEL92`E<RX`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U;6UA<GD`
M4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T
M`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R
M=`!3=7)N86UE`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`5"U3=&]R
M;0!4+5-T;W)M<P!44U8@9FEL90!486)L90!486)L92!0<F]P97)T:65S`%1A
M8FQE('!R;W!E<G1I97,`5&%R9V5T.@!487-K<P!496QE<&AO;F4@3G5M8F5R
M`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E
M.B``5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5X=`!497AT($]N;'D`5&5X
M="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H86YK('EO=2!F
M;W(@=7-I;F<@=&AE('-Y<W1E;2X`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T
M(&%V86EL86)L92X`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L
M;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E
M9"X@17AI=&EN9RX`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG
M=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A
M;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4
M:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@
M8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C
M;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S
M(&)O;VLN`%1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E
M<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T
M<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE
M9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&1I
M<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP
M=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N
M+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H
M92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H
M92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL
M92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@
M:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E
M<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T
M;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D
M:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O
M;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S
M(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R
M86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9
M;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@
M<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE
M(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N
M9"!S:61E(&]N;'D`5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H
M('-U8FIE8W0@(B5S(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@
M9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U
M;F1E<G-T;V]D+@!4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H
M92!C;VUP;W-E('!A9V4`5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N
M=6UE<FEC+@!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E
M9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W
M86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@
M='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE(')I
M9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O
M;FQY`%1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E
M<BX`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V
M97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O
M<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(')O=R!D;V5S
M(&YO="!E>&ES="X`5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@
M97AI<W0N`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@
M<VED92!O;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H
M92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@
M8F4@<V%V960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA
M8FQE+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R
M92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R
M92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@
M:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE
M<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B
M;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T
M:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@
M=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R
M;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W
M87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P
M<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N
M(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@
M9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A
M;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@
M=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+@!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F
M;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A
M<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED
M('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C
M87)D(&YU;6)E<BX`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD
M(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU
M<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E
M9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@
M:7,@)7,N`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E
M<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M
M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP
M<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E
M;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R
M+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@
M=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM
M92!F;W)M870`5&EM92!S96QE8W1I;VX`5&ET;&4`5&ET;&4@*'1O;VQT:7`I
M.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@
M0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K
M:6YG+@!4;V1A>0!4;VUO<G)O=P!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N
M<VQA=&EO;G,`5')U92!O<B!F86QS90!4=0!4=7)K:7-H("A)4T\M.#@U.2TY
M*0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DPZ`%5N
M86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E
M>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE
M('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B
M;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5
M;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!3
M44P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE
M('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N
M86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@96UP
M='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L
M92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN
M`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D96QE=&4@
M)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(')E
M8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL
M<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE
M('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E
M<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E
M9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O
M<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O
M;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E
M8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`
M56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@
M=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I
M+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YD97)L:6YE`%5N
M9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FEC;V1E
M("A55$8M."D`56YI=',`56YK;F]W;@!5;FMN;W=N('5S97)N86UE(&]R('!A
M<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N=`!5;FYA;65D`%5N
M<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S
M=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI
M8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@
M=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E
M<W,@=&AE(&-L:7!B;V%R9"X`56YS970@8V]L;W(`56YS=7!P;W)T960@17AT
M96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D871E('5S97(`57!D871E9"`B
M)7,B+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@
M86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P
M<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<V4@0W5R
M<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F
M97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R("5S(&ES(&YO="!A=71H;W)I
M<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`
M57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@
M9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<B!A8V-O=6YT(&YO="!F;W5N
M9`!5<V5R;F%M90!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@
M<WES=&5M.@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO
M;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A
M;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA
M>&EM=6T@;&5N9W1H(&]F("5S+@!686QU97,`5F%L=65S('1O('-E;&5C="!F
M<F]M`%9A<FEA8FQE`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L
M(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6
M:65T;F%M97-E("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W
M96(@<&%G90!6:65W(&%S("5S`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%=!
M4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!787)N
M:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D
M(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M90!7
M96QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I
M`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!7:&%T(&%P<&QI8V%T:6]N('-H;W5L
M9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET
M97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H
M:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I
M8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T
M:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N
M(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`
M5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO
M=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7;W)K`%=O<FL@061D<F5S<P!7;W)K
M(%!H;VYE`%E9`%E965D`665A<FQY`%EE<P!997,L($D@06=R964`66]U(&%R
M92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C
M:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N
M`%EO=2!C86X@;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F
M=6QL(&YA;64N`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D
M<F5S<RX`66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O
M<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`
M66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A
M('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@
M;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R
M969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU
M<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P
M<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T
M(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE
M('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E
M('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E
M<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@
M=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@
M<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N
M`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U
M(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S
M="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO=7(@)7,@<V5S<VEO;B!H
M87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D
M9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO
M=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G
M:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E
M8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@
M875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I
M;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O
M<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@
M:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S
M97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES
M(&9E871U<F4N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L
M="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;&]G:6X@:&%S(&5X
M<&ER960N`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O
M<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@
M=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N
M`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H
M87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I
M=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<&%S<W=O<F0@:&%S(&5X<&ER
M960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%M(:61E(%%U;W1E9"!497AT70!;
M4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O
M=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES
M=')A=&EO;@!?0TQ)`%]$871A5')E90!?1&5L971E(%)O=P!?1W)O=7!S`%](
M96QP`%]);6%G92!0<F]P97)T:65S+BXN`%],;V<@:6X`7TQO9R!O=70`7TUO
M9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E($QI
M;FLN+BX`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R
M97-S(&)O;VL`8V%L96YD87(`8V%L;0!C;&EC:R!H97)E`&9I;&4`9G)O;2!T
M:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&@Z`&EM;65D:6%T90!I;FQI
M;F4`;&EN97-=`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M
M96YT960`;F]T97!A9`!P97)C96YT`'!I>&5L<P!R:7-I;F<`<VAO=R!D:69F
M97)E;F-E<P!S=&5A9'D`=&%S:R!L:7-T`'1Y<&4@=&AE('!A<W-W;W)D('1W
M:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L96-T`'9#
M87)D`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@
M,R`*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*
M4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2
M979I<VEO;BU$871E.B`R,#`U+3`W+3`X(#$U.C(W*S`R,#`*3&%S="U4<F%N
M<VQA=&]R.D%M:7)K86)I<B!-971A;F5T=V]R:VEN9R!L=&0N(#QP97)S:6%N
M+6AO<F1E0&UE=&%N971W;W)K:6YG+F-O;3X*3&%N9W5A9V4M5&5A;3H@4&5R
M<VEA;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP
M"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U55$8M.`I#;VYT
M96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@`@*-BQV8C8LB#9@MBHV80@
M)7,I`"C:J=F$VXS8KR#8K]BSV*K8L=BSVXP@)7,I`"C8K]BQ("5S(-BQV8C8
MLBD`("C8I]F%V+'9B-BR*0`@*-F!V+'8K]BG*0`@*-BOVXS8L=F(V+(I`"#8
MK]BQ(``B)7,B(-BHV8<@VJ_8L=F(V8?B@(S9A]BGVXP@V+/8I]F%V*?9AMF'
M(-BGV+;8I]F!V8<@V+38KP`B)7,B(-BHV8<@V+/8I]F%V*?9AMF'(-F%V*S9
MB-BRXH",V8?8IR#8I]BVV*?9@=F'(-BTV*\`(B5S(B#8I]N,V*S8I]BO(-F&
MV+38K]F'(-BHV8C8KSH@)7,N`"4N,F9-0B#8I]BSV*K9@=BGV*_9AR#8M-BO
MV8<@V*?8LB`E+C)F34(@V878K-BGV+(@*"4N,F9-0BD`)60@)7,@V8@@)7,`
MV*?8L]F%(-BQV878LB#8M-F%V*<@)60@V+'9B-BR(-BOVXS:K]BQ(-F%V+G8
MJMBHV+$@V*?8L]BJ+@#9OMN,V+3"K=BHVXS9AMN,("5D+=BQV8C8LMF'`"5S
M("T@V*K9B-BLV8<`V*?8J]BQ(-BGV8;:K]BTV*H@)7,`VJG;C-F$V8C8J-BG
MVXS8JB`E<P`E<R#8N=F%V83;C-BGV*H@V8;:K]F'V*_8I]BQVXP@+2#8JMBC
MVXS;C-BO`"#8L=BGV8<F(W@R,#!C.]BGV8;8K]BGV++;C"`E<R``)7,@V*O8
MJ-BJ(-F&V*?9A0#8M-BQV8C8MR#8JMF(V*?9@=F"("5S`"5S(-BGV+(@V8+8
MJ-F$(-F%V8C8K-F(V*\@V*?8L]BJ`"5S(-BOV+$@)7,@)7,`)7,@V*+9A=BG
MV*_9AR#8I]BLV+'8I]N,(-BYV879A-N,V*?8JB#9AMJOV8?8K]BGV+';C"#8
MI]F&V*K8KMBGV*@@V+38K]F'(-BGV+/8JBX@V*S8N=BHV8<@V8?8L2#8N=F%
MV83;C-BGV*K;C"#8L=BG(-JIV8<@V8?9A2#8I]JIV8;9B-F&(-F%VXSB@(S8
MKMF(V*?9A]N,V*\@V*?8K-BQV*<@VJG9AMN,V*\@V+G9A-BGV878JB#8J-BR
MV8;;C-BO`"5S(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8J@`E<R#8K]F"VXS9
M@MF'`"5S(-F^VXS8K]BG(-F&V+38KP`E<R#8J-F'("5S(-BGV+(@)7,`VJG8
MJMBGV*C:AMF'V90@V*+8K]BQV+,@)7,`V*K9@MF(VXS9A2`E<P`E<R=S($YO
M=&5P860`V8'9A]BQV+/8JB#9B-BXV*?;C-F!("5S`"5S.B`E<P#8C"#8J-BG
MV*\`V(P@V*C8I]BO("5S("5S`-B,(-F%V*K8NMN,VXS8L2#8I]BR("5S(-BH
MV8<@)7,`(-BGV8;8JMBNV*?8J"``V8+8I]F$V*@@V[';LB#8L]BGV+G8JMN,
M`-F"V*?9A-BH(-NRV[0@V+/8I]BYV*K;C`#;LMNT(-BSV*?8N=BJV8<`VXS:
MJ2#9OMBTV*K;C-BHV*?9AB#8K]BGV*_:K]BGV88@V*C8L=BGVXP@V*?;C-F&
M(-BHV838I]JI(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8J@#;C-JI(-BNV+?8
MI]N,(-BLV*_;C"#8L=BN(-BOV*?8K]F'(-BGV+/8J@#;C-JI(-JIV83;C-BO
M(-BYV879B-F%VXP@4$=0(-BHV+'8I]N,(-BQV878LMBHV8;8K]N,(-N,VJD@
MV;[;C-BZV*?9A2#9A=F(V+'8KR#9AMN,V*?8LB#8I]BSV*H`VXS:J2#:J=F$
MVXS8KR#8N=F%V8C9A=N,(%!'4"#8J-BQV*?;C"#8J-BGV++8J-N,V8;;C"#;
MC-JI(-F^VXS8NMBGV84@V*?9A=BVV*?8H2#8M-BOV8<@V879B-BQV*\@V8;;
MC-BGV+(@V*?8L]BJ`-N,VJD@VJG9A-N,V*\@V+G9A=F(V87;C-B,(-N,VJD@
MVJG9A-N,V*\@V*[8M=F(V+7;C"!01U`@V8@@VXS:J2#8N=BHV*?8L=BJ(-JO
MV+#8L2#8J-BQV*?;C"#8L=F%V++:K]BTV*?;C-N,(-N,VJD@V;[;C-BZV*?9
MA2#9A=F(V+'8KR#9AMN,V*?8LB#8I]BSV*H`VXS:J2#:J=F$VXS8KR#8N=F%
MV8C9A=N,V(P@VXS:J2#:J=F$VXS8KR#8KMBUV8C8M=N,(%!'4"#9B"#;C-JI
M(-BYV*C8I]BQV*H@VJ_8L-BQ(-BHV+'8I]N,(-BGV878MMBGV*$@VXS:J2#9
MOMN,V+K8I]F%(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8J@#;C-JI(-JIV83;
MC-BO(-BYV879B-F%VXS8C"#;C-JI(-JIV83;C-BO(-BNV+79B-BUVXP@4R]-
M24U%(-F((-N,VJD@V+G8J-BGV+'8JB#:K]BPV+$@V*C8L=BGVXP@V+'9A=BR
MVJ_8M-BGVXS;C"#9OMN,V+K8I]F%(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8
MJ@#;C-JI(-JIV83;C-BO(-BYV879B-F%VXS8C"#;C-JI(-JIV83;C-BO(-BN
MV+79B-BUVXP@4R]-24U%(-F((-N,VJD@V+G8J-BGV+'8JB#:K]BPV+$@V*C8
ML=BGVXP@V*?9A=BVV*?8H2#;C-JI(-F^VXS8NMBGV84@V879B-BQV*\@V8;;
MC-BGV+(@V*?8L]BJ`-N,VJD@VJG9A-N,V*\@V+G9A=F(V87;C"!3+TU)344@
MV*C8L=BGVXP@V+'9A=BRV*C9AMBOVXP@V;[;C-BZV*?9A2#9A=F(V+'8KR#9
MAMN,V*?8LB#8I]BSV*H`V*C8I]BQV*?9AB#8L]BHVJD@V+78J-BMVJ_8I]F'
MVXP`V*C8I]BQV*?9AB#8M=BHV*W:K]BGV8?;C`#8L=JOV*C8I]BQ(-BUV*C8
MK=JOV*?9A]N,`-BJVJ_8L=JO(-BUV*C8K=JOV*?9A]N,`-BUV*C8K2_8N=BU
MV+$`V*_8L=BHV*?8L=F'(-BGVXS9AB#9B-N,V+'8I]BSV*K8I]BQ`-BOV+'8
MJ-BGV+'9ARXN+@#9OMBGVXS;C-F&(-F%V+?9A-F"`-F(V+/8MR#9A=BWV839
M@@#8I]N,V*S8I]BO(-BTV*?8KMF'(%9&4R#9A=BLV8C8LB#8K]BSV*K8L=BS
MVXP@V8;8K]BGV+'8KP#8I]N,V*S8I]BO(-F^V+'9B-F&V*_9AR!61E,@V878
MK-F(V+(@V*_8L]BJV+'8L]N,(-F&V*_8I]BQV*\`V*?8M]F$V*?8N=BGV*H@
MV*W8L]BGV*@`V*?8L]F%(-BQV878LB#8K=BSV*?8J`#8K=BSV*?8J"#9A=BS
MV*_9B-BO`-BMV+/8I]BHV*_8I]BQVXP`V*?8MMBGV8'9AR#:J=BQV*_9A@#8
MI]BVV*?9@=F'(-JIV+'8K]F&(-JOV+'9B-F'(-F!V+'8N=N,`-BGV+;8I]F!
MV8<@VJG8L=BOV88@V878K-F(V+(@V8'8L=BYVXSB@(P`V*?;C-F&V*S8IR#8
MI]BVV*?9@=F'(-JIV88Z`-BGV+;8I]F!V8<@VJG8L=BOV88@VJ_8L=F(V8<@
MV*S8K]N,V*\`V*?8MMBGV8'9AR#:J=BQV*_9AB#9A=BLV8C8LB#8K-BOVXS8
MKP#8I]BVV*?9@=F'(-JIV+'8K]F&(-N,VJD@V878K-F(V+(@V8'8L=BYVXP@
MV*C9AR`B)7,B`-BGV+;8I]F!V8<@VJG8L=BOV88@VXS:J2#:J=BGV+'8J-BQ
M(-BLV*_;C-BO.@#8I]BVV*?9@=F'(-JIV+'8K]F&(-BSV*K9B-F&`-BGV+;8
MI]F!V8<@VJG8L=BOV88@V*?8N=BVV*?;C"#8K-BOVXS8KP#8I]BVV*?9@=F'
M(-JIV+'8K]F&(-BRV8C8K``@V*?8MMBGV8'9AR#:J=BQV*_9AB#:K]BRVXS9
MAMJOV*?9AB`E<R#8J-BYV8;9B-BGV88@V8;9B-BGV+$@V*S8I]F&V*C;C"#9
MA=F(V++;C-F$V*<`V*?8MMBGV8'9AR#:J=BQV*_9AB#8J-F'(-JIV*K8I]BH
MVH;9A]F4(-BBV*_8L=BS.@#8I]BVV*?9@=F'(-JIV+'8K]F&(-BHV8<@VJG8
MJMBGV*C:AMF'V90@V*+8K]BQV+,@V879A@#8I]BVV*?9@=F'(-F#V+'8K]F&
M(-JIV*?8L=BHV+$`V*?8MMBGV8'9AR#:J=BQV*_9AB#:J=BGV+'8J-BQV*?9
MAB#9@=BYV*?9A"#9AMN,V+/8J@#8HMBOV+'8LP#:J=BJV*?8J-J&V8?9E"#8
MHMBOV+'8LR``V+/8L=F^V+'8L]BJ(-BSV*?9A=BGV8;9ART@V*K8N=N,VXS9
MAB#9A=BLV8C8LMF'V*?;C"#:J=BGV+'8J-BQV*?9AB#8K]N,VJ_8L0#8L]BQ
MV;[8L=BSV*K;C`#8JMBHV83;C-BZV*?8J@#9A=BYV*?8K]F$`-BJV+'8I]BR
M(-JIV+'8K]F&`-BJV+'8I]BR.@#9A]F%V8<`V*K9A=BGV87;C"#:J=BGV+'8
MJ-BQV*?9AB#8JMBCVXS;C-BO(-BUV838I]BMVXS8JB#8M-BOV8<`V8?9A=F'
M(-JOV+'9B-F'XH",V8?8IP#9A]F%V8<@V878K-F(V++B@(S9A]BG`-F'V879
MA]F4(-J&V8?8I]BQ(-BSV878J@#8I]BLV*?8LMF'(-J&V8;8KR#8HMBOV+'8
ML]N,`-BBVXS8IR#8I]BLV*?8LMF'(-BJV8;8N-N,V84@V8;9B-BY(-F!V8?8
ML=BSV*H@V878L=BJV*@@V*_8I]BOV8<@V+39B-BOV)\`V*?8LB#9@MBHV80@
MV879B-BLV8C8KR#8I]BSV*H`V8C8L=F(V*\@24U34"#8K-BGVXS:K]BRVXS9
MA@#8I]BSV84@V+'9A=BR($E-4U`@V*S8I]N,VJ_8LMN,V88`V8;8I]F%(-JI
MV*?8L=BHV+';C"!)35-0(-BLV*?;C-JOV++;C-F&`-BBV*_8L=BS(-F^V+/8
MJB#8I]F$VJG8JMBQV8C9AMN,VJD@V*S8I]N,VJ_8LMN,V88`V*?9A-JOV8CB
M@(S9A]BGVXP@V*S8I]N,VJ_8LMN,V88`V878JMF&(-BLV*?;C-JOV++;C-F&
M.@#;C-JI(-F%V8+8K]BGV+$@V8;8I]BOV+'8L]BJ(-BJV+G;C-N,V88@V+38
MK]F'(-BHV8C8KP#9OMN,V+3:J=BGV+$`V;[8I]BSV*X`V*C8L=F&V*?9A=F'
MV93B@(P@VJG8I]BQV*C8L=BOVXP`V8'9A]BQV+/8JB#8J-BQV8;8I]F%V8?B
M@(S9A]BGVXP@VJG8I]BQV*C8L=BOVXP`V*C8L=F&V*?9A=F'(-BBV878I]BO
MV8<@V*?8L]BJ`-BGV+G9A=BGV80@V*C8L2#8L=F(VXP@V*?8M-BJV+'8I]JI
MV8?8I]N,(-F!V+'8N=N,`-BJV+79B-N,V*@`V*?9AMBOV*?8LMF'(-BJV8+8
ML=N,V*C;C`#8HMF(V+';C-F$`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0#8I]F&
MV*_8I]BRV8<@V;[8L=F(V8;8K]F'(-BBV+'8M-N,V8@`V8;8I]F%(-BBV+'8
MM-N,V8@`V*+;C-BG(-BTV878IR#9A=BWV878IMF&VXS8KR#:J=F'(-F%VXSB
M@(S8KMF(V*?9A]N,V*\@V*?8M]F$V*?8N=BGV*H@V*?9@=BJV*K8I]BM(-BM
MV+/8I]BH("5S(-BQV*<@V;[8I]JI(-JIV8;;C-BOV)\`07)M96YI86X@*$%2
M35-#24DM."D`V8?9AMBQ`-BBVXS8IR#9@MBHV80@V*?8LB#8N=F%V83;C-BG
MV*H@V8;:K]F'V*_8I]BQVXP@V*C8L=BGVXP@V*K8H]N,VXS8KR#8HMF&(-BS
MV*;9B-BGV80@V+39B-BOV)\@`-BGV8;8JMBSV*?8J"#8L]BJV8C9AMF'V*<`
MV+/8N=N,(-BOV+$@V*W8L-F!(-JOV+'9B-F'VXP@V+38K]F'(-BGV+/8JB#:
MJ=F'(-F%V8C8K-F(V*\@V8;;C-BSV*H`V+/8N=N,(-BOV+$@V*W8L-F!(-F%
MV*S9B-BRVXP@V+38K]F'(-BGV+/8JB#:J=F'(-F%V8C8K-F(V*\@V8;;C-BS
MV*H`V+/8N=N,(-BOV+$@V8C;C-BQV*?;C-BT(-F%V*S9B-BRVXP@V+38K]F'
M(-BGV+/8JB#:J=F'(-F%V8C8K-F(V*\@V8;;C-BSV*H`V+/8N=N,(-BOV+$@
MV8C;C-BQV*?;C-BT(-BGV+38JMBQV*?:J=N,(-BTV*_9AR#8I]BSV*H@VJG9
MAR#9A=F(V*S9B-BO(-F&VXS8L]BJ`.*`C-F(VXS:F-JOVXS9A]BG`-BBVJ_9
MB-BSV*H`075T:%]C>7)S<6PZ(-BHV+/8MR#9A=F(V+'8KR#9AMN,V*?8LB!)
M34%0(-F^VXS8K]BG(-F&V+38KP!!=71H7V-Y<G-Q;#H@V+/8I]F%V*?9AMF'
M(-F^V+38JMN,V*C8I]F&(-F"V*?8J-F$VXS8JMF'V*?;C"#9A=F(V+'8KR#9
MAMN,V*?8LB#8L=BG(-F&V*_8I]BQV*\`075T:&EM<#H@V*C8L]BW(-F%V8C8
ML=BO(-F&VXS8I]BR($E-05`@V;[;C-BOV*<@V8;8M-BO`$%U=&A?9G1P.B#8
MJ-BSV+<@V879B-BQV*\@V8;;C-BGV+(@1E10(-F^VXS8K]BG(-F&V+38KP!!
M=71H7VEM<#H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR($E-05`@V;[;C-BO
MV*<@V8;8M-BO`$%U=&A?:W)B-3H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR
M(&MR8C4@V;[;C-BOV*<@V8;8M-BO`$%U=&A?;&1A<#H@V*C8L]BW(-F%V8C8
ML=BO(-F&VXS8I]BR($Q$05`@V;[;C-BOV*<@V8;8M-BO`$%U=&A?;&1A<#K8
MI]BVV*?9@=F'(-JIV+'8K]F&(-JIV*?8L=BHV+$@)7,@V879A=JIV88@V8;;
MC-BSV*HN(-BGVXS9AB#:AMN,V++;C"#8I]BSV*H@VJG9AR#:J=BGV+'8L]BG
MV+(@VJ_9@=BJV8<@V*?8L]BJ`$%U=&A?;&1A<#K8K=BPV8$@VJG8I]BQV*C8
ML2`E<R#9A=F%VJG9AB#9AMN,V+/8JB``075T:%]L9&%P.MBHV+'9B-BRV+'8
ML]BGV8;;C"#:J=BGV+'8J-BQ("5S(-F%V87:J=F&(-F&VXS8L]BJ`$%U=&A?
M;6-A;#H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR($U#04P@V;[;C-BOV*<@
MV8;8M-BO`$%U=&A?<VUB875T:#H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR
M('-M8F%U=&@@V;[;C-BOV*<@V8;8M-BO`-BJV+78K]N,V8(@V8?9B-N,V9'8
MJB#9AMBGV879B-F!V9'9@B#8J-F(V*\`V*K8M=BOVXS9@B#9A]F(VXS9D=BJ
M(-F&V*?9A=F(V8'9D=F"(-BHV8C8KRX@)7,`V*K8M=BOVXS9@B#9A]F(VXS9
MD=BJ(-BGV+(@V+?8L=F!(-JIV*?8L=BSV*?8LB!2041)55,@V+'8KR#8M-BO
MV8<@V*?8L]BJ`-BJV+78K]N,V8(@V8?9B-N,V9'8JB#8K]BQ(-JIV*?8L=BS
MV*?8LB!&5%`@V8;8I]F%V8C9@=F1V8(@V*C9B-BO(`#9@=N,V838K]F'V*?;
MC"#9@MBGV*C9A"#8K]BSV*K8L=BSVXPZ`-F^V+/B@(S8LMF%VXS9AMF'`-BQ
MV8;:KR#9OMBSXH",V++9A=N,V8;9AP#8I]BSV84@V+'9A=BR(-F&V*?8K]BQ
MV+/8JB!K97)B97)O<P#9AMBGV84@VJG8I]BQV*C8L2#9AMBGV*_8L=BSV*H@
M:V5R8F5R;W,`0F%L=&EC("A)4T\M.#@U.2TQ,RD`V*[8MR#9A=BHV8;8IP#8
MJ-F$V8C:J2`B)7,B(-BGV+(@V*C8L=F&V*?9A=F'V90@VJG8I]BQV*C8L=BO
MVXP@(B5S(B#;C-BGV8'8JB#9AMBTV*\`V*K9AMBXVXS9A=BGV*H@V*C9A-F(
MVJD`V8;9B-BY(-BHV839B-JI`-BSVXS8I]F'`-J&V8C8J"#8I]F$V8$`V838
MJ-F'`-F^V8?9AMBGVXP@V838J-F'.@#9A-BHV8?B@(S9A]BG`-F'V+$@V*_9
MB`#9OMBGVXS;C-F&`-F$VXS8L]BJ(-BHV8C9A-BJXH",V*_8I]BQ`$--4P!#
M4D,`V8;9@MBGV+<@V*K9B-BRVXS8N2!#4DP`V*[8M=F(V+7;C-BGV*H@V+/9
MA-F(V80N+BX`V*K9@MF(VXS9A0#8HMBQV*?9A0#9AMF%VXSB@(S8JMF(V*?9
MAB#8I]BSV84@V+'9A=BR(-BQV*<@V*C8M]F(V+$@V*[9B-BOVJG8I]BQ(-BO
MV8C8J-BGV+'9AR#8J-BGV++9AMBTV*?9AMBOV(P@V*C8IR#8L]BQV;[8L=BS
MV*H@V+/8I]F%V*?9AMF'(-BNV8C8KR#8JMF%V*?8LR#8J-JOVXS8L=N,V*\`
MV8;9A=N,XH",V*K9B-BGV88@V*_8L2#9OMBQV8C9AMBOV8<@(B5S(B#9AMF(
MV+38J@#9AMF%VXSB@(S8JMF(V*?9AB#8J-F'(-JIV*?8L=BSV*?8LB#9OMBS
MV*H@V*?9A-JIV*K8L=F(V8;;C-JI(-F%V*K8M=F$(-BTV*\Z("5S`-F&V87;
MC.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR`B)7,B(-BQV*<@V*C8I]BR(-JI
MV+'8KP#8I]F&V+78L=BGV8$`V*?9AMBUV+'8I]F!(-BGV+(@V*?8L=BSV*?9
MA"#:K]BRV*?8L=BT`-F&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR`B
M)7,B(-BQV*<@V*W8L-F!(-JIV+'8KR`@`-F&V87;C.*`C-BJV8C8I]F&(-N,
MVJD@V+38I]BNV8<@V879B-F"V*H@V;[;C-BOV*<@VJG8L=BO`-F&V87;C.*`
MC-BJV8C8I]F&(-BHV*_9B-F&(-F^V*?8L=BGV878JMBQ("?9OMBQV8C9AMBO
MV8<@V879@MBUV*\G(-BGV*_8I]F%V8<@V*_8I]BO`-F&V87;C.*`C-BJV8C8
MI]F&(-BTV*?8KMF'("(E<R+8L=BG(-BMV+#9@2#:J=BQV*\@`-F&V87;C.*`
MC-BJV8C8I]F&(-BMV+#9@2#9AMF%V8C8K]B,("5D(-F!V+'8LMF&V*\@V879
MB-BLV8C8KR#8I]BSV*H`V8;9A=N,XH",V*K9B-BGV88@V*_9B-BHV*?8L=F'
M(-F%V+'8JMBH(-F&V879B-BOV(P@V*C8L=BNVXP@V*?8LB#9B-BQV8C8K]N,
MV8?8I]N,(-F!V+'8I]F'V84@V+38K]F'(-BHV+'8I]N,(-F%V+'8JMBH(-BS
MV*?8LMN,(-BHV*<@V+39A=BGV+'9A^*`C-F'V*?;C"#8L-BNVXS8L=F'(-BT
MV*_9A]B,(-BSV*?8LMJOV*?8L2#9AMN,V+/8J@#9AMF%VXSB@(S8JMF(V*?9
MAB#9OMN,V+K8I]F%(-BQV*<@V*C9AR#8M-F%V*?8L=F'(-BJV+G;C-N,V88@
MV+38K]F'(-JOV+#8L2#8K]BGV*\`V+G9AMF(V*?9A@#8K=BGV879A`#:K]BQ
MV8C9A^*`C-F'V*<@V8@@V*C8L=J&V+/8J-F'V*<`V879B-BHV*?;C-F$`-BN
MV+79B-BUVXS8I]BJ(-BSV839B-F$`-F!V*?8M=F$V8<@V+/9A-F(V80`V*[8
MM=F(V+7;C-BGV*H@V+/9A-F(V80`V8'8I]BUV839A^*`C-JOV+#8I]BQVXP@
MV+/9A-F(V80`V879B-BHV*?;C-F$`$-E;'1I8R`H25-/+3@X-3DM,30I`-F%
MV+':J=BR`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`-BLV++8IMN,
MV*?8JB#:K]F(V*?9A]N,(`#8L]N,V*?8L]BJV8?8I]N,(-JOV8C8I]F'VXP`
MV*K8NMN,VXS8L2``V*?8L]F%(-BQV878LB#8KMF(V*\@V+'8IR#8JMBZVXS;
MC-BQ(-BOV8?;C-BO`-BJV+K;C-N,V+'8K]BGV*_9AB#9AMBGV84@V8@@V*+8
MK]BQV+/;C"#:J=F'(-BGV8'8L=BGV*\@V8?9AMJOV*?9A2#8KMF(V*?9AMBO
MV88@V8@@V;[8I]BSV*X@V*_8I]BOV88@V*C9AR#9AMBGV879A]F4(-BTV878
MIR#8KMF(V*?9A]F&V*\@V*_;C-BO(`#8JMBZVXS;C-BQV*_8I]BOV88@V*?8
ML]F%(-BQV878LB#8M-F%V*<@V*_8L2#9OMN,VJG8L=BHV8;8K]N,(-F!V+G9
MA-N,(-F^V+38JMN,V*C8I]F&VXP@V8;9A=N,XH",V+39B-BO+B#8J-BG(-BS
MV+'9OMBQV+/8JB#8L]BGV878I]F&V8<@V*[9B-BO(-BJV878I]BS(-BHVJ_;
MC-BQVXS8KP#9AMF(VXS8L]F'`-BHV+'8L=BSVXP@V;[;C-F(V8;8KRXN+@#B
M@(P`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET
M:6]N86P@*$)I9S4I`-BGV8;8JMBNV*?8J"#;C-JI(-BGV+/9A2#8L=F%V+(`
MV*?9AMBJV*[8I]BH(-N,VJD@V8;8I]F%(-JIV*?8L=BHV+';C`#8I]F&V*K8
MKMBGV*@@VH;:K]F(V8;:K]N,(-F&V878I]N,V+0@V*K8I]BQVXS8KCH`V*?9
MAMBJV*[8I]BH(-F&V8C8N2#8L]BHVJD@V8'9A]BQV+/8JB`HV*C8L=BGVXP@
MV8'9A]BQV+/8JMF'V*?;C"#9A=BQV*K8J"D`V*K8N=BQVXS9@2#:J=F$V*?8
MLR`E<R#;C-BGV8'8JB#9AMBTV*\`V+78I]F!`-F^V*?:J2#:J=BQV*_9AB#8
MJMJOV8?8I]N,($U33V9F:6-E`-F^V*?:J2#:J=BQV*_9AB#:J=BGV+'8J-BQ
M(#H@)7,`V;[8I]JI(-JIV+'8K]F&(-JIV*?8L=BHV+$`V;[8I]JI(-JIV+'8
MK]F&(-BOV*?8K]F'V90@VJG8I]BQV*C8L0#8J-BQV*?;C"#8I]BOV*?9A=F'
MV(P@VJG9A-N,VJD@VJG9AMN,V*\`0VQI8VMA=&5L;"#8I]BR(-BWV+';C-F"
M($A45%``V*C8L]BJV88@V;[9AMBLV+'9AP#8I]BHV+'9A]BG`-BGV*C8L=N,
M`-BLV878N2#8M-BOV88@V8;9B-BGV+$@VJG9AMBGV+';C`#:AMF%V+D@V+38
MK]F&(-F$V*C9A^*`C-F'V*<`V+'9AMJO`-BGV8;8JMBNV*?8J"#:J=F&V8;8
MK]F'(-BQV8;:KP#8I]F&V*K8KMBGV*@@V+'9AMJO`-BSV*K9B-F&V8?8ISH`
MV+G9AMBGV8C;C-F&(-BSV*K9B-F&V8?8IP#9A=BVV*W:J0#9@=BQV878I]F&
M`-F^V8C8L]BJV8<@V8'8L=F%V*?9A@#8JMF(V+;;C-BM`-F&V*?9A2#8N=F%
MV8C9A=N,`-BTV+':J=BJ`-BQV*?;C-BGV8;9A^*`C-F'V*<`V+38L=BW`-BT
MV+'8I]N,V+<`V*K9@=BGV8C8JMF'V*?;C"#9OMN,VJG8L=BHV8;8K]N,`-F^
MVXS:J=BQV*C9AMBOVXP@)7,`V*K8H]N,VXS8KR#8I]BSV84@V+'9A=BR`-BG
MV*K8M=BGV80@V8;8I]F%V8C9@=F1V8(@V*C9B-BO`-BGV*K8M=BGV80@V8;8
MI]F%V8C9@=F1V8(@V*C9B-BO`-BGV*K8M=BGV80@V*C9AR#:J=BGV+'8L]BG
MV+(@VJG9A-N,V*\@V+G9A=F(V87;C"#8L=BO(-BTV*\`V*?8JMBUV*?9A"#8
MJ-F'(-JIV*?8L=BSV*?8LB#:J=F$VXS8KR#8N=F%V8C9A=N,(-BQV*\@V+38
MKRX@V*_9A-N,V80Z("5S("@E<RD`V*?8JMBUV*?9A"#8J-F'(-JIV*?8L=BS
MV*?8LB!&5%`@V8;8I]F%V8C9@=F1V8(@V*C9B-BO`-F&V878I]BSV8?8IP#8
MJMF%V*?8L]F'V*<@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BHV8<@VJG8JMBG
MV*C:AMF'V90@V*+8K]BQV+,@V+39A=BG(-BGV+;8I]F!V8<@V+38K]F'(-BH
MV8C8KP#8I]BOV*?9A=F'`-JIV8C:J=N,`-BQV8C9AMF(V+38J@#8L=F(V8;9
MB-BTV*H@V*C8L=BOV*?8M-BJV88@V*?8LB#8J-BNV+0@V*?9AMBJV*[8I]BH
MVXP`V8;9A=N,XH",V*K9B-BGV8;8KR#9OMN,V+K8I]F%(-BQV*<@V+'9A=BR
MV*C9AMBOVXP@VJG9AMBO(%!'4`#9AMF%VXSB@(S8JMF(V*?9AMBO(-F^VXS8
MNMBGV84@V+'8IR#8I]F%V+;8I]BA(-JIV8;8KR!01U``V8;9A=N,XH",V*K9
MB-BGV8;8KR#9OMN,V+K8I]F%(-BQV*<@V+'9A=BRV*C9AMBOVXP@VJG9AMBO
M(%,O34E-10#9AMF%VXSB@(S8JMF(V*?9AMBO(-F^VXS8NMBGV84@V+'8IR#8
MI]F%V+;8I]BA(-JIV8;8KR!3+TU)344`V8;9A=N,XH",V*K9B-BGV88@V*K9
MA=BGV+/9A]BG(-BQV*<@V*?8MMBGV8'9AR#:J=BQV*\@)7,`V8;9A=N,XH",
MV*K9B-BGV88@V*C9AR#:J=BGV+'8L]BGV+(@3$1!4"#9OMN,V8C8L]BJ(`#9
MAMF%VXSB@(S8JMF(V*?9AB#8J-F'(-JIV*?8L=BSV*?8LB!L9&%P(-F^VXS9
MB-BSV*H`V8;9A=N,XH",V*K9B-BGV88@V*C8I]F$V*?9AMBS(-BQV*<@VH;:
MJ2#:J=BQV*\@)7,`V8;9A=N,XH",V*K9B-BGV88@V*C9AR#:J=BGV+'8L]BG
MV+(@;&1A<"#9A=BJV+79A"#8M-BO`-F&V87;C.*`C-BJV8C8I]F&(-F!V8?8
ML=BSV*H@V*K9B-BRVXS8N=N,(-BGVXS8K-BGV*\@VJG8L=BO+B`E<P#9AMF%
MVXSB@(S8JMF(V*?9AB#8K]BGV*_9AR!01U`@V+'8IR#8L=F%V++:K]BTV*?;
MC-N,(-F&V879B-BO(`#9AMF%VXSB@(S8JMF(V*?9AB#8K]BGV*_9AR!3+TU)
M344@V+'8IR#8L=F%V++:K]BTV*?;C-N,(-F&V879B-BO(`#9AMF%VXSB@(S8
MJMF(V*?9AB#8JMF%V*?8LR#8L=BG(-BMV+#9@2#9AMF%V8C8KRX@)7,`V8;9
MA=N,XH",V*K9B-BGV88@V8'9A]BQV+/8JB#8JMF(V++;C-BYVXP@V+'8IR#8
MK=BPV8$@V8;9A=F(V*\N("5S`-F&V87;C.*`C-BJV8C8I]F&(-BBV*_8L=BS
M(-JOVXS8L=F&V*_9AR#9AMBGV879A]F4(-BGV83:J=BJV+'9B-F&VXS:J=N,
M(-BQV*<@V*K8M-BNVXS8M2#8K]BGV*\`V8;9A=N,XH",V*K9B-BGV88@VJG9
MA"#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR#8L=BG(-F(V*?:J=BTVXP@V8;9
MA=F(V*\`V8;9A=N,XH",V*K9B-BGV88@VJG9A"#9@=F'V+'8L]BJ(-BJV8C8
MLMN,V+G;C"#8L=BG(-F(V*?:J=BTVXP@V8;9A=F(V*\`V8;9A=N,XH",V*K9
MB-BGV88@V8'9A]BQV+/8JB#:J=BGV879A"#9@=F'V+'8L]BJ(-BJV8C8LMN,
MV+G;C"#8L=BG(-F(V*?:J=BTVXP@V8;9A=F(V*\`V8;9A=N,XH",V*K9B-BG
MV88@VJG9A-N,V*\@V+G9A=F(V87;C"#8L=BG(-BGV+(@VJG8I]BQV+/8I]BR
M(-JIV83;C-BO(-BHV*_8L]BJ(-BBV8C8L=BO`-F&V87;C.*`C-BJV8C8I]F&
M("5S(-BQV*<@V*C8I]BR(-JIV+'8KP#9AMF%VXSB@(S8JMF(V*?9AB#9A=BO
MV8C9A"#9B-BXV*?;C-F!(-F&VJ_9A]BOV*?8L=N,("5S(-BQV*<@V*C8I]BR
M(-F&V879B-BO`-F&V87;C.*`C-BJV8C8I]F&("5S(-BQV*<@V*[9B-BGV8;8
MKP#9AMF%VXSB@(S8JMF(V*?9AB#8I]BSV84@V+'9A=BR(-BQV*<@V*C8L=BG
MVXP@VJG8I]BQV*C8L2#9A=F(V+'8KR#9AMBXV+$@V*C8I]BRV8;8M-BGV8;8
MKRX@V*C8N=BVVXP@VXS8IR#9A]F%V8<@V*S8LMBFVXS8I]BJ(-F%V+'8J-F(
MV+<@V*C9AR#8HMF&(-F&V*?8K]BQV+/8JB#9A=N,XH",V*C8I]BTV*\N(-BO
MV8C8J-BGV+'9AR#8L]BYVXP@VJG9AMN,V*\@VXS8IR#8J-BQV*?;C"#:J=F%
MVJD@V*C;C-BTV*K8L2#8J-BG(-BSV+'9OMBQV+/8JB#8L]BGV878I]F&V8<@
MV*[9B-BO(-BJV878I]BS(-BHVJ_;C-BQVXS8KP#9AMF%VXSB@(S8JMF(V*?9
MAB!!0TP@V+'8IR#8K]F(V*C8I]BQV8<@V*C8K]BSV*H@V*+9B-BQV*\`V8;9
MA=N,XH",V*K9B-BGV88@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@V+'8IR#8
MK]F(V*C8I]BQV8<@V*C8K]BSV*H@V*+9B-BQV*\N("5S`-F&V87;C.*`C-BJ
MV8C8I]F&(-F!V8?8L=BSV*H@V*K9B-BRVXS8N=N,(-BQV*<@V*_9B-BHV*?8
ML=F'(-BHV*_8L]BJ(-BBV8C8L=BO+B`E<P#9AMF%VXSB@(S8JMF(V*?9AB#9
M@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"#8L=BG(-BOV8C8J-BGV+'9AR#8J-BO
MV+/8JB#8HMF(V+'8KRX@)7,`V8;9A=N,XH",V*K9B-BGV88@V8+8I]BHV83;
MC-BJV8?8I]N,(-JIV*?8L=BSV*?8LB#8L=BG(-BOV8C8J-BGV+'9AR#8J-BO
MV+/8JB#8HMF(V+'8KP#9AMF%VXSB@(S8JMF(V*?9AB#9OMN,VJG8L=BHV8;8
MK]N,(-BQV*<@V*C8I]BRVJ_8L=BOV*?9AMBO`-F&V87;C.*`C-BJV8C8I]F&
M(-F^VXS:J=BQV*C9AMBOVXP@)7,@V+'8IR#8K]BNVXS8L=F'(-JIV+'8KP#9
MAMF%VXSB@(S8JMF(V*?9AB#9OMN,VJG8L=BHV8;8K]N,(-F^V+38JMN,V*C8
MI]F&(-BQV*<@V*W9@=BX(-JIV+'8KP#9AMF%VXSB@(S8JMF(V*?9AB#9OMN,
MVJG8L=BHV8;8K]N,(-F^V+38JMN,V*C8I]F&(-BQV*<@V*W9@=BX(-JIV+'8
MKSH@)7,@`-F&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR#9OMBTV*K;
MC-BHV*?9AB#9OMN,VJG8L=BHV8;8K]N,("5S(-BQV*<@V*W9@=BX(-JIV+'8
MKP#9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@V;[;C-JIV+'8J-F&
MV*_;C"`E<R#8L=BG(-BMV8'8N"#9AMF%V8C8KRX@V+39A=BG(-F%VXP@V*K9
MB-BGV8;;C-BO(-BGV+(@VXS:J=N,(-BGV+(@VJ_8LMN,V8;9A^*`C-F'V*<@
MV*C8L=BGVXP@V*W9@=BX(-JIV*\@V*C8L2#8L=F(VXP@)7,@V*?8L]BJV8'8
MI]BOV8<@V8;9A=BGVXS;C-BO(-F((-N,V*<@V*?;C-F&VJG9AR#8I]BR(-JI
MV*\@V*C9AR#8M=F(V+'8JB#8K]BSV*K;C"#8K]BQ)7,@V+'9B-F&V8C8M-BJ
M(-BJV8?;C-F'(-F&V878I]N,VXS8KP#9AMF%VXSB@(S8JMF(V*?9AB#:J=BG
MV+'8L]BGV+(@3$1!4"#8L=BG(-BLV+/8JMBLV8@@VJG8L=BO`-F&V87;C.*`
MC-BJV8C8I]F&(-BJV878I]BS("#8L=BG(-BHV+'9B-BRV+'8L]BGV8;;C"#:
MJ=BQV*\N("5S`-F&V87;C.*`C-BJV8C8I]F&(-F!V8?8L=BSV*H@V*K9B-BR
MVXS8N=N,(-BQV*<@V*C8L=F(V++8L=BSV*?9AMN,(-JIV+'8KRX@)7,`V8;9
MA=N,XH",V*K9B-BGV88@V8;9B-BGV+$@V*S8I]F&V*C;C"#9A=F(V++;C-F$
MV*<@V+'8IR#9OMN,V*_8IR#:J=BQV*\N(-F%V+?9A=BFV88@V+39B-N,V*\@
MVJG9AR#9AMF(V*?8L2#8K-BGV8;8J-N,(-BHV*?8LB#8I]BSV*H`V878JMF&
M(-BTV878I]BQV+0@V+38K]F'`-JIV+39B-BQ`-BOV8C8L=F'XH",V8?8IP#8
MI]N,V*S8I]BO`-BGVXS8K-BGV*\@VXS:J2#9OMN,V8C9AMBO`-BGVXS8K-BG
MV*\@VXS:J=N,(-BLV*_;C-BO`-BGVXS8K-BGV*\@V++;C-BQV;[9B-BTV8?B
M@(S9A]BG`-F%V*S9B-BRV8?8I]N,(-BGVXS8K-BGV*\@VJG9AMF&V*_9AP#8
MM-F%V*?8L=F'(-JIV*?8L=BJ(-BGV+G8JMBHV*?8L=N,`-BSV*?8N=BJ(-F!
MV+G9A-N,`%523"#9@=BYV83;C"#9A]BSV*H`V*+8J"#9B"#9A]F(V*?;C"#9
M@=BYV83;C`#8M-BQV*?;C-BW(-F!V+G9A-N,.B``V+/8J-JI(-F!V+G9A-N,
M`-BSV8'8I]BQV+3;C"#:J=BQV*_9AB#9B-BXV*?;C-F!(-F'V8;:K]BGV84@
MV8C8L=F(V*\@V*C9AR`E<P#8J-BQVXS8K]F&`-BHV+';C-BOV88@V*?9AMBJ
MV*[8I]BH`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R
M-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!$1`#8L=F(V++8I]F&
MV8<`V878L=F(V+':K]BQ(-BOV+'8KMBJ(-BOV*?8K]F'`-BJV*?8L=N,V*X`
MV*K8I]BQVXS8KB#8K]BQVXS8I]F!V*H@V+38K]F'`-BJV*?8L=N,V*X@V*?9
MAMBJV*[8I]BH`-BQV8C8L@#8K=BPV8$@V+/8JMF(V88`V*_8L]BGV878J-BQ
M`-BGV+G8K]BGV*\@V*_9A]BOV8?;C`#:J=F%(-JIV+'8K]F&(-BJV8C8L=F!
MV*K:K]N,`-F^VXS8M"#9@=BQV+8`V+'9AMJO(-F^VXS8M"#9@=BQV+8`V8?9
MB-N,V9'8JB#9OMN,V+0@V8'8L=BV`-F^V8C8L]BJV8?9E"#9OMN,V+0@V8'8
ML=BV`-BJV+G8I]BQVXS9@0#8K=BPV8$`V*W8L-F!(-JOV+'9B-F'`-BMV+#9
M@2#9A=BLV8C8L@#8K=BPV8$@V8@@V;[8I]JIV+/8I]BRVXP@V;[;C-BZV*?9
MA=F'V*<`V*W8L-F!(-BSV839B-F$`-BMV+#9@2#8L]BJV8C9A@#8K=BPV8$@
MV*?9A-JOV8C;C"#8K-BGVXS:K]BRVXS9AB#9A=F(V*S9B-BO`-BMV+#9@2#9
MA=BLV8C8LMF'V*<@V*C8L=BGVXP@("(E<R(`V*+;C-BG(-F%V*S9B-BRV8?8
MIR#9B"#8LMN,V+'9A=BLV8C8LMF'V*<@V*C8L=BGVXP@(B5S(B#8K=BPV8$@
MV+39B-BOV)\`V*W8L-F!(-BSV+?8L0#8K=BPV8$@V8?9B-N,V9'8JB#8I]F&
MV*K8KMBGV*@@V+38K]F'`-BMV+#9@2#8L]BJV8C9AB#9@=BYV83;C`#8K=BP
MV8$@V+/8M]BQ(-F!V+G9A-N,`-BRV878I]F&(-BGV+'8L]BGV80`V+38L=BM
M(-F%V+3:J=F$`-BJV8C8MMN,V*T`V*S8LMF0V*;;C-BGV*HZ`"#8K-BRV*;;
MC-BGV*H@V*C8L=BGVXP@V+/8L=F^V+'8L]BJ(-BSV*?9A=BGV8;9AR#8J]BH
MV*H@V+38K]F'(-BGV+/8J@#:K]BSV*K8L=BT`-F&V8+8M]F'(-BTV*C9AMF%
M`-F&V8+8M]F'(-BTV*C9AMF%(-BHV+'8I]N,(-BSV*?8N=BJ(-JOV+#8M-BJ
MV8<Z(`#9AMF"V+?9AR#8M-BHV8;9A3H@`-BLV8?8JB#8I]BR(-J&V;X@V*C9
MAR#8L=BGV+/8J@#8K-F'V*H@V*?8LB#8L=BGV+/8JB#8J-F'(-J&V;X`V+38
MI]BNV8<`V*+;C-BG(-BRV878I]F&(#(T(-BSV*?8N=BJV8<@V8;9A=BGVXS8
MM"#8K]BGV*_9AR#8M-F(V*_8GP#:K]BRVXS9AMF'XH",V8?8I]N,(-F&V878
MI]N,V+0`V8;9A=BGVXS8M"#8K-BRV*;;C-BGV*H@V;[;C-BTPJW8J-N,V8;;
MC`#9AMF%V*?;C-BT(-F^VXS8M,*MV*C;C-F&VXP`V8;9A=BGVXS8M"#9@MBG
MV838J`#8K=BGV838JB#8JMBPVJG8L0#8K=BPV8$@V8;8M-F(V*\`V*_8L]BJ
MV+'8L]N,(-F%V+/8JMF"VXS9A2#8J-F'(&UA:6YT96YA;F-E+G!H<"#9A=F%
MVJG9AB#9AMN,V+/8J@#8HMN,V*<@V+/8M]BQ(-BGV8C9A"#8M-BGV879A"#9
M@=N,V838KR#9AMBGV84@V87;C.*`C-BHV*?8M-BOV)\@V*?:K]BQ(-J&V8;;
MC-F&(-BGV+/8JMB,(-BGVXS9AB#8K-BYV*C9AR#8L=BG(-BYV838I]F%V*H@
MV*C8LMF&VXS8KSH`V*?8L]BJV8+8L=BGV+$`V*?8L]BJV8+8L=BGV+$@)7,`
MV*?8L]BJV8+8L=BGV+$@V;[;C-JIV+'8J-F&V*_;C"#8JMF(V83;C-BO(-BT
MV*_9AR#8J-BYV8;9B-BGV88@V*_8L]BJ(-F&V8C;C-BS(%!(4`#9@=F'V+'8
ML]BJ(-F^V*?;C-N,V8;B@(S9OMBQ`-BOV*?8L=F(V8?8IP#9AMBGV879AR#8
MI]F$VJG8JMBQV8C9AMN,VJG;C`!%4E(`V8C;C-BQV*?;C-BT`-F(VXS8L=BG
MVXS8M"#8J-F$V8C:J0#9B-N,V+'8I]N,V+0@VJ_8L=F(V8<`V8C;C-BQV*?;
MC-BT(-F%V*S9B-BR`-F(VXS8L=BGVXS8M"#9A=BLV8C8LMF'V*<`V8C;C-BQ
MV*?;C-BT(-F%V*S9B-BRV8?8IR#8J-BQV*?;C"`E<P#:K]BRVXS9AMF'XH",
MV8?8I]N,(-F(VXS8L=BGVXS8M#H`V8C;C-BQV*?;C-BT(-F%V*S9B-BRXH",
MV8?8IR#8J-BQV*?;C"`B)7,B`-F(VXS8L=BGVXS8M"#9A=BLV8C8LN*`C-F'
MV*<@V*C8L=BGVXP@)7,`V*K8K=BUVXS9A-BGV*H`V+G9AMBUV+$N+BX`16T`
MV8;8I]F%V8<@V*?9A-JIV*K8L=F(V8;;C-JIVXP`V*+8K]BQV+,@V8;8I]F%
MV8?9E"#8I]F$VJG8JMBQV8C9AMN,VJG;C`#8HMBOV+'8L]F'V*?;C"#9AMBG
MV879A^*`C-F'V*?;C"#8I]F$VJG8JMBQV8C9AMN,VJG;C"#8J-BGVXS8KR#9
MA=F&V+?8J-F"(-BHV*?8M-BO`-F&V*?9A=F'V90@V*?9A-JIV*K8L=F(V8;;
MC-JIVXP@V*C8IR#8JMBCVXS;C-BO`-BGV*W8L]BGV+/8I]BJ`-BNV*?9A-N,
M(-JIV+'8K]F&(-F^VXS8NMBGV84@`-BNV*?9A-N,(-JIV+'8K]F&(-F&V*K;
MC-BLV8<`V*[8I]F$VXP@VJG8L=BOV88@V879B-BGV+'8KR#8K-BSV*K8K-F(
M`-BBVXS8IR#8K]BQV*P@V*K8M=BGV8C;C-BQ(-BGV+(@VJ_8I]F$V+';C-F'
MV*?;C"#8N=JIV+,@V*_8L2#9A=BJV88@V8'8N=BGV80@V+39B-BOV)\`V*+;
MC-BG(-JOV++;C-F&VJ_8I]F&(-BRV87;C-F&V8<@V+'9B-N,(-JIV83;C-JI
M(-BQV*?8L]BJ(-F!V+G8I]F$(-BTV8C8K]B?`-BGV8;8JMF'V*?;C"#8L]BG
MV80`V*C8LMBQVJ\@VJG8L=BOV88@V8C;C-BQV*?8L]BJV*?8L0#;C-JI(-BS
MV*;9B-BGV80@V*?9A=F&VXS8JMN,(-BHV+'8I]N,(-F^V+'8L]BT(-BGV+(@
MV+39A=BG(-BHV8<@V8?9AMJOV*?9A2#8J-BGV++9AMBTV*?9AMBOV88@V*?8
ML]F%(-BQV878LB#9B-BGV+'8KR#:J=F&VXS8K]B,(-F%V*O9A-BGV9(@)]F&
MV*?9A2#8K=N,V8C8I]F&(-BNV*?9AMJOVXP@V+39A=BG(-J&VXS8L]BJV)\G
M`%523"#8JMBUV8C;C-BQ(-BQV*<@V*?;C-F&V*S8IR#9B-BGV+'8KR#:J=F&
MVXS8KP#8KMBWV*<`V*C9A-F(VJD@V*?;C-BLV*?8KR#8KMBWV*<Z("5S`-BN
MV+?8IR#8K]BQ(-JIV+/8J"#9A=BMV*K9B-BG.B5S`-BNV+?8IR#8K]BQ(-BH
MV+'9B-BRV+'8L]BGV8;;C"#8I]BSV84@V+'9A=BR(#H@)7,`V*[8M]BG(-BH
MV*<@V;[;C-BZV*?9A2#9AMBGV879A]F4(-BGV83:J=BJV+'9B-F&VXS:J=N,
M`-BYV*K;C-F"V8<`V*?8L=F(V;[8IP#9A]BQ(-F^V*?9AMBRV*_9AR#8K]F"
MVXS9@MF'`-F'V+$@V*_9B"#8K]F"VXS9@MF'`-F'V+$@V+/;C"#8K]F"VXS9
M@MF'`-F'V+$@V;[9AMBL(-BOV8+;C-F"V8<`V*_8L2#9A]BQ(-F(V+'9B-BO
M`-F'V+$@V8;;C-F%(-BSV*?8N=BJ`-F'V+$@V*_9@MN,V8+9AP#9A=F"V*?8
MK]N,V+$@V878J]BGV80Z`-BGV*S8L=BG`-BHV*?8LB#:J=BQV*_9A@#8J-BG
MV++:J=BQV*_9AB#9AMF(V*?8L2#:J=F&V*?8L=N,`-BGV8;8JMBXV*?8L2#8
MJ-BQV*?;C"`G*"<`V*K8I]BQVXS8KB#8I]F&V8+8MMBGV*$`V8;9A=BGVXS9
MAMBOV8<`V+'9AMJO(-F^VXS8M.*`C-BRV87;C-F&V8<`1E10('5P;&]A9"!O
M9B!S971U<``@V*C8I]BRVXS8I]BHVXP@V*K9@MBOV878I]BJ(-F&V*?9A=F(
MV8'9D=F"(-BHV8C8KP`@V*?8JMBUV*?9A"#8J-F'(-JIV*?8L=BSV*?8LB!,
M1$%0(-F&V*?9A=F(V8'9D=F"(-BHV8C8KP`@V*?8JMBUV*?9A"#8J-F'(-JI
MV*?8L=BSV*?8LB!334(@V8;8I]F%V8C9@=F1V8(@V*C9B-BO(``@V*K9A]N,
MV8<@V+'9B-F&V8C8M-BJ(-BGV+(@(B5S(B#9AMBGV879B-F!V9'9@B#8J-F(
MV*\`V*?;C-BLV*?8KR#8L=F(V8;9B-BTV*H@V*_8L2`B)7,B(-F&V*?9A=F(
MV8'9D=F"(-BHV8C8KP`@V*?;C-BLV*?8KR#;C-JI(-BGV*K8M=BGV80@V*S8
MK]N,V*\@4T%33"#9AMBGV879B-F!V9'9@B#8J-F(V*\`(-BGV8;8JMF"V*?9
MA"#8J-F'("(E<R(@V8;8I]F%V8C9@=F1V8(@V*C9B-BO`-F$V+?;C-F!`-BN
MV+?8I]N,(-BLV*_;C#H@`-F!VJG8LP#9@=F(V+';C-F'`-BQVJ_8J-BGV+$@
MV*[9@=N,V8$`VJG9A=N,(-BJVJ_8L=JO`-BTV878I]BQV+0@V;[8L=F(V8;8
MK]F'.B`E<R#9OMBQV8C9AMBOV8<`V+39A=BGV+'8M"#9OMBQV8C9AMBOV8<Z
M("5S(-F^V+'9B-F&V*_9AP#9A=BOVXS8L2#9OMBQV8C9AMBOV8<`V8;8I]F%
M(-F^V+'9B-F&V*_9AP#8I]F&V*K8KMBGV*@@V;[8L=F(V8;8K]F'`-BGV+'8
ML]BGV80@V;[8L=F(V8;8K]F'`-BGV+'8L]BGV80@V;[8L=F(V8;8K]F'(-F^
MV+38JMN,V*C8I]F&VXP@V8;9A=N,XH",V+39B-BO+BX`V8';C-F$V*K8L=F'
MV*<`V8;;C-F%V8<@V*?9B-F$`-BQV*C8N2#8I]F(V80`V8;8L]BHV*H@V*O8
MI]BHV*H`V*?8N=BTV*?8L=N,`-F%V8?B@(S8HMF$V8C8KP#9OMF(V+39AR`E
M<R#9A=F(V*S9B-BO(-F&VXS8L]BJ(`#8L=F&VJ\@V8+9A-F%`-BZV+#8IP#8
MJ-BQV*?;C"#9A=BQV8C8L=JOV+'9A]BGVXS;C"#:J=F'(-BJV+78I]F(VXS8
ML2#8L=BG(-F^V+38JMN,V*C8I]F&VXP@V8;9A=N,XH",VJG9AMF&V*\`V;[;
MC-BTPJW8J-N,V8;;C`#8I]BSV84@V+'9A=BR(-BNV8C8KR#8L=BG(-F!V+'8
MI]F%V8C8M"#:J=BQV*_9A^*`C-BGXH",VXS8K]B?`-F!V+'9A=F'V*<`V+?8
MI]F$V+D`V8;9B-BY(-BWV*?9A-BY`-BWV*?9A-BYV8?8IP#8M]BGV838N=F'
MV*<@V[(`V*?9AMBLV879AMF'V*<`V*?8L=BLV*?8N=F'V*<`V*S9A=BYV8<`
MVH;8I]BQVH;9B-BHV8?8IP#8I]BR`-BGV+(@`-BTV+'8K2#:J=BGV879A`#9
MA=BGV8<@VJG8I]F%V80`V8;8I]F%(-JIV*?9A=F$`-JOV*?9A-BQVXP@V*C8
ML=BGVXP@V*_8L=N,V*?9@=BJ(-BJV+79B-N,V+$@`-JOV*?9A-BQVXPZ`-BJ
MV8C9A-N,V*\@V;[;C-JIV+'8J-F&V*_;C"`E<P#:J=BO(-BJV8C9A-N,V*\@
MV+38K]F'`-F&V*?9A2#8K]BGV*_9AR#8M-BOV8<`V*C8L=F(`-BLV+/9AMBL
MV8C;C"#:K]F(VJ_9A`#8K]BQV*S9AR#8KMBGVJG8L]BJV+';C`!'<F5E:R`H
M25-/+3@X-3DM-RD`V+/8L=F^V+'8L]BJVXP@VJ_8L=F(V8<`V8;8I]F%(-JO
MV+'9B-F'(-F&V*C8I]N,V*\@V*[8I]F$VXP@V*C8I]BTV*\`VJ_8L=F(V8<F
M(W@R,#!C.]F'V*<`V878K-F(V++9A]BGVXP@V879A]F%V*?9A@#:J=BJV*?8
MJ-J&V8?9E"#;C-BGV*_8J-F(V*\`2%1-3`!(5$U,07)E82#8K=BPV8$@V*+8
MKMBQVXS9AB#8L]F$V8C9A"#8L=BG(-BOV+$@V+'8K]N,V8$@V+'8KR#9A=N,
MXH",VJG9AMBO`$A434Q!<F5A(-BMV+#9@2#8HMBNV+';C-F&(-BSV*K9B-F&
M(-BQV*<@V*_8L2#8K-BOV8C9A"#8L=BO(-F%VXSB@(S:J=F&V*\`2%1-3$%R
M96$@V*W8L-F!(-BBV*[8L=N,V88@V+'8K]N,V8$@V+'8IR#8K]BQ(-BLV*_9
MB-F$(-BQV*\@V87;C.*`C-JIV8;8KP#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@
M2%144"#;C-BGV8'8JMF'(-F&V+38KP#8I]F$VJ_9B-BQVXS8JMF%($AA<V@`
MV879A^*`C-BBV839B-BO`-BSV+'8HMF%V*\`2&5B<F5W("A)4T\M.#@U.2TX
M+4DI`-BHV839AMBOVXP`V+'8I]F'V8;9A=BG`-BQV*?9A]F&V878I]N,(-BG
MV+/8JMF!V*?8K]F'(-BGV+(@V8C;C-BQV*?;C-BTVJ_8L0#:J=F%VJD@VJG9
MAMF&V*_9AP#9AMN,V87B@(S:J=BQV8<`V*?;C-F&V*S8IR#8I]BHV*K8K]BG
MVXP@V;[8L=F(V8;8K]F'XH",(-F%VXSB@(S8J-BGV+38KSH`V*C8I]F$V*<`
MV*[8I]F&V8<`V*[8I]F&V8<`V*+8K]BQV+,@V*[8I]F&V8<`V+38I]BNV8?9
ME"#8I]BUV83;C`#8M-F%V*?8L=F'(-BJV839@=F&(-F%V8;8LMF$`-F'V8C8
ML=BO`$AO<F1E+TMO;&%B.B`E<R#8J-BG(-BOV*?8K]F'(-F&V*?8K]BQV+/8
MJB!834P@V*_8L2#9OMN,V+K8I]F%("5S(-F%V8C8I]BLV8<@V+38K]F'(-BG
MV+/8J@!(;W)D92]+;VQA8CH@V8?;C-J&(-F^VXS8NMBGV87;C"#9A=BWV*?8
MJ-F"V*H@V*C8IR#8M-N,V*$@)7,@V8;8K]BGV+'8KP!(;W)D92]+;VQA8CH@
MV8?;C-J&(-BTVXS8IMN,(-BGV+(@V8;9B-BY("5S(-BOV+$@V;[;C-BZV*?9
MA2`E<R#;C-BGV8'8JB#9AMBTV*\`2&]R9&4O2V]L86(Z(-BHV*<@V879B-F!
MV9'9@MN,V9'8JB`E<R`B)7,B(-BMV+#9@2#8M-BO`$AO<F1E+TMO;&%B.B#8
MJMF(V83;C-BO(-N,VJD@V*_8L=BNV*H@V*S8K]N,V*\@6$U,(-BHV+'8I]N,
M(-BTVXS8H2`E<R#9A=F"V*_9B-BQ(-F&VXS8L]BJ(`!(;W)D92]+;VQA8CH@
MV*W8L-F!("5S("(E<R(Z)7,@V879@MBOV8C8L2#9AMN,V+/8J@!(;W)D92]+
M;VQA8CH@V*C8I]BRVXS8I]BHVXP@($U)344@240@V*C8L=BGVXP@V8+8L]F%
MV*K;C"#8I]BR(-F&V8C8N2`E<R#9A=F"V*_9B-BQ(-F&VXS8L]BJ(`!(;W)D
M92]+;VQA8CH@V+/9AMJIV+'9B-F&(-JIV+'8K]F&("5S("(E<R(Z("5S(-F%
MV8+8K]F(V+$@V8;;C-BSV*H`2&]R9&4O2V]L86(Z(-BSV8;:J=BQV8C9AB#:
MJ=BQV*_9AB#8I]BTV*K8L=BGVJG9A]BG(-F%V8+8K]F(V+$@V8;;C-BSV*HZ
M("5S`$AO<F1E+TMO;&%B.B#8I]BTV*K8L=BGVJD@V8;8I]BTV8;8I]BNV*K9
MAR`B)7,B`-F"V*?9AMF(V88@V*?9@=F"VXP`V8'8I]BUV839A^*`C-JOV+#8
MI]BQVXP@V*?9@=F"VXP`.MBGV8'9@MN,`-J&VJ_9B-F&V8<@V*C8IR#8I]N,
MV8;8K-BG(-BBV+39AMBG(-BTV*_;C-BOV)\@*-F$V+?9@=BGV8L@VJ_8LMBG
MV+'8M"#8K]F'VXS8KRDA`-J&V8;8KR#8L]BJV8C9AB#8L=BG(-F%VXSB@(S8
MKMF(V*?9A]N,V*\@V*?8K]BZV*?9A2#:J=F&VXS8K]B?`-J&V8;8KR#9@=N,
MV838KR`HV+/8JMF(V88I(-F(V*S9B-BO(-BOV*?8L=BOV)\`VH;9AMBO(-BS
MV+?8L2#8L=BG(-F%VXSB@(S8KMF(V*?9A]N,V*\@V*?8K]BZV*?9A2#:J=F&
MVXS8K]B?`-BQV+?9B-BHV*H`V+'8M]F(V*C8JCH@`-BGVXS8K-BGV*\@V8;8
MI]F%V8?B@(S8K]BGV88@24U!4"#9AMBGV879B-F!V9'9@B#8J-F(V*\Z("`E
M<P#8K=BPV8$@V8;8I]F%V8?B@(S8K]BGV88@24U!4"#9AMBGV879B-F!V9'9
M@B#8J-F(V*\@.B`E<P#8I]N,V*S8I]BO(-F%V*W8K]F(V*_;C-F1V*H@V8;8
MI]F%V8?B@(S8K]BGV88@24U!4"#9AMBGV879B-F!V9'9@B#8J-F(V*\@.B`E
M<P#8HMBOV+'8LR!)4`#8HMBOV+'8LR!)4"#9@MBGV*C9A"#8K]BSV*K8L=BS
MVXP@V8;;C-BSV*H`V*+8K]BQV+,@25`@V*_8L2#8K]BGV*[9A"#8J-F$V8C:
MJ2!#2412(-BGV*S8I]BRV8<@V*_8I]BOV8<@V8;9A=N,XH",V+39B-BO`-BG
MV*C8JMBOV*<@V+/8M]BQ(-BQV*<@V8C8I]BQV*\@VJG9AMN,V*\`V8'9@MBW
M(-BBVXS:J=F(V8;9A]BG`-BBVXS:J=F(V8;9A]BG(-BHV+'8I]N,("5S`-BB
MVXS:J=F(V8;9A]BG(-BHV*<@V878JMF&`-F&V*?9A2#9A]F(VXS9D=BJ.@#8
MI]JOV+$@V*+9AB#8J-F'(-BOV+'8L]BJVXP@V8;9A=BGVXS8M"#8K]BGV*_9
MAR#9AMBTV*_8C"`E<R`@V*C8L=BGVXP@V*C8I]BR(-JIV+'8K]F&(-BBV88@
MV*_8L2#;C-JI(-F^V8;8K-BQV8<@V*S8K]N,V*\`V*?:K]BQ(-BTV878IR#9
MA]N,VH8@V*+;C-JIV8C9AMN,(-BQV*<@V*_8L2#9A=BQV8C8L=JOV+$@V8;8
MJ-N,V8;;C-BOV(P@V879A=JIV88@V*?8L]BJ(-F$V*?8LMF%(-BHV*?8M-BO
M(-JIV8<@4$Y'(%1R86YS<&%R96YC>2#8L=BG(-BNV*?9A=F(V+0@VJG9AMN,
MV*\`V*?:K]BQ(-BTV878IR#8I]N,V88@V;[;C-BZV*?9A2#8L=BG(-F%V+38
MI]F'V*_9AR#:J=F&VXS8KR#8I]F%V*<@V*K8M=F(VXS8L=N,(-BQV*<@V878
MM-BGV8?8K]F'(-F&VJG9AMN,V*_8C"#8I]N,V88@V*C9AR#8I]N,V88@V+G9
MA-BJ(-BNV8C8I]F'V*\@V*C9B-BO(-JIV8<@V878L=F(V+':K]BQ(-BTV878
MIR#9@=BGV*_8L2#8J-F'(-F&V878I]N,V+0@V*K8M=F(VXS8L2#9AMN,V+/8
MJB``V;[;C-BTXH",V8;9A=BGVXP@V*K8M=F(VXS8L3H`55),(-BJV+79B-N,
MV+$`55),(-BJV+79B-N,V+$Z`-BJV+79B-N,V+$@V*?8LB#:K]BGV838L=N,
M`-BJV+79B-N,V+$@V*?8LB#:K]BGV838L=N,.@#8I]BQV+/8I]F$(-BJV+79
MB-N,V+$`V*K8M=BGV8C;C-BQ`-BOV+'9B-F&XH",V*C8L=BOV(P@VJ_8I]F%
M("5D`-F!VXS9A-BO(-BOV+'9B-F&XH",V*C8L=BO(-BTV*_9ASH@)7,`V8';
MC-F$V*_B@(S9A]BGVXP@V*_8L=F(V8;B@(S8J-BQV*\@V+38K]F'.@#8J-BY
MV*_8I]F+(-BSV+?8L2#8L=BG(-F(V*?8L=BO(-JIV8;;C-BO`-JIV*\@V+G9
MA=F$VJG8L=BO(-F&V*?8K]BQV+/8JB#8K]BGV*_9AR#8M-BOV8<@V*?8L]BJ
M`"#9AMBGV84@VJG8I]BQV*C8L2_8I]BSV84@V+'9A=BR("#9AMBGV*_8L=BS
MV*H@V*?8L]BJ`-F&V*?9A2#:J=BGV+'8J-BQ(-N,V*<@V*+8K]BQV+,@V*S8
MI]N,VJ_8LMN,V88@V8;8I]BOV+'8L]BJ(-F%VXSB@(S8J-BGV+38KRX@V838
MM]F!V*<@V878K-BOV*_8I]F2(-BSV+G;C"#:J=F&VXS8KR#9B"#;C-BG(-BO
MV+$@V+79B-BQV*H@V8;;C-BGV+(@V*C9AR#:J=F%VJD@V*C;C-BTV*K8L2#8
MJ-BG(-BSV+'9OMBQV+/8JB#8L]BGV878I]F&V8<@V*K9A=BGV+,@V*C:K]N,
MV+';C-BO`-BGV8'8LMBGVXS8M"#8JMF(V+'9@=BJVJ_;C`#:J=BGV+'8J-BQ
MV*?9AB#8KMBGV+4`V*?8M]F$V*?8N=BGV*H`V*?8M]F$V*?8N=BGV*H`V*?8
MM]F$V*?8N=BGV*H@V*_;C-JOV+$@V*_8L2#8K]BSV*K8L=BS(-F&VXS8L]BJ
M`-BOV+'8K"#8L]BJV8C9AB#8J-BYV*\@V*?8L@#8K]BQV*P@V*K8M=F(VXS8
ML0#8K]BQV*P@V*S8K]F(V80`V*_8L=BL(-F^VXS9B-F&V*\@V8C8J`#8I]BH
MV*K8K]BG(-BSV*K9B-F&(-BQV*<@V*_8L=BL(-JIV8;;C-BO`-N,VJD@V+/8
MJMF(V88@V*S8K]N,V*\@V*C8N=BO(-BGV+(@V+/8JMF(V88@V8'8N=F$VXP@
MV*_8L=BL(-JIV8;;C-BO`-N,VJD@V+/8JMF(V88@V*S8K]N,V*\@V8+8J-F$
M(-BGV+(@V+/8JMF(V88@V8'8N=F$VXP@V*_8L=BL(-JIV8;;C-BO`-N,VJD@
MV+/8M]BQ(-BLV*_;C-BO(-BHV+G8KR#8I]BR(-BSV+?8L2#9@=BYV83;C"#8
MK]BQV*P@VJG9AMN,V*\`VXS:J2#8L]BWV+$@V*S8K]N,V*\@V8+8J-F$(-BG
MV+(@V+/8M]BQ(-F!V+G9A-N,(-BOV+'8K"#:J=F&VXS8KP#;C-JI(-F^V*?8
ML=BGVJ_8L=BGV8$@V*C8N=BO(-BGV+(@VJ_8L=F'(-F!V+G9A-N,(-BOV+'8
MK"#:J=F&VXS8KP#;C-JI(-F^V*?8L=BGVJ_8L=BGV8$@V8+8J-F$(-BGV+(@
MVJ_8L=F'(-F!V+G9A-N,(-BOV+'8K"#:J=F&VXS8KP#8K]BQV*P@V*?9A-JO
MV8C;C"#8K-BGVXS:K]BRVXS9A@#;C-JI(-BBV*_8L=BS(-F^V+/8JB#8I]F$
MVJG8JMBQV8C9AMN,VJD@V*C8L=BGVXP@V*_8L=N,V*?9@=BJ(-BGV+/9A2#8
ML=F%V+(@(-BLV*_;C-BO(-BOV+'8K"#:J=F&VXS8KR``V*_8L=BL(-BSV839
MB-F$(-BHV+G8KP#8K]BQV*P@V+/9A-F(V80@V8+8J-F$`-BOV+'8K"#8L]BJ
MV8C9AB#8J-BYV*\`V*_8L=BL(-BSV*K9B-F&(-F"V*C9A`#8K]BQV*P@V;[;
MC-BZV*?9A0#8K]BQV*P@V;[8I]BQV*?:K]BQV*?9@2#8J-BYV*\`V*_8L=BL
M(-F^V*?8L=BGVJ_8L=BGV8$@V8+8J-F$`-BOV+'8K"#8L]BWV+$@V*C8N=BO
M(`#8K]BQV*P@V+/8M]BQ(-F"V*C9A`#9OMBGV+/8KB#9A=F(V+'8KR#9AMN,
MV*?8LB#8L=BG(-BHV+'8I]N,(-BSV*;9B-BGV80@V*?9A=F&VXS8JMN,(-BO
MV+'8K"#:J=F&VXS8KSH`V*_8L=BL+]BJV+K;C-N,V+$@V*K8M=F(VXS8L0#8
MK]BQV*POV*K8NMN,VXS8L2#9OMN,V8C9AMBO`-BGV+G8JMBHV*?8L2#9AMBG
MVJG8I]F!VXP@V*C8L=BGVXP@V*?8L=BSV*?9A"#8J-F'(-F!V8?8L=BSV*H@
MV*K9B-BRVXS8N=N,`-BGV+G8JMBHV*?8L2#9AMBGVJG8I]F!VXP`V+G8K]BO
M(-BUV*W;C-BM`-F!V8?8L=BSV*H@V+G8K]BO(-BUV*W;C-BM`%5$2"#9AMBG
MV878N=BJV*C8L0#8J-BQV8;8I]F%V8?9E"#:J=BGV+'8J-BQV*_;C"#9AMBG
MV878N=BJV*C8L0#8K]BSV*K9AR!)1"#9AMBGV878N=BJV*C8L0#8K]BGV*_9
MA]F4(-F&V*?9A=BYV*K8J-BQ(-BGV+'8I]BFV8<@V+38K]F'`-BBV*_8L=BS
M(-F%V8+8M=BO(-F&V*?9A=BYV*K8J-BQ`-F"V*?9A-BH(-F^V+'9B-F&V*_9
MA]F4(-F&V*?9A=BYV*K8J-BQ`-F&V8C8N2#9OMN,V+K8I]F%(-F&V*?9A=BY
MV*K8J-BQ`&%P:5]I9"#9AMBGV878N=BJV*C8L2#8I]BSV*H@V8@@VXS8IR#8
MI]BR(-BHVXS9AB#8L=F!V*K9AR#8I]BSV*H`V;[8I]BQV*?9A=BJV+$@V8;8
MI]F%V+G8JMBHV+$@V8@@VXS8IR#8I]BR(-BHVXS9AB#8L=F!V*K9AP#9A=BL
MV8C8LB#9OMBOV+$@V8;8I]F%V+G8JMBHV+$`V;[8L=F(V*K:J=F$(-F&V*?9
MA=BYV*K8J-BQ`-JOVXS8L=F&V*_9A]F4(-F&V*?9A=BYV*K8J-BQ.B`B)7,B
M`-BTVXS8H2#8J-F'(-BGV+38JMBQV*?:J2#:K]BPV*?8M-BJV8<@V+38K]F'
MV90@V8;8I]F%V+G8JMBHV+$`V*+8K]BQV+,@V+/8L=J&V+39A=F'(-F&V*?9
MA=BYV*K8J-BQ`-BOV*?8K]F'(-N,V8C9AMN,VJG8KR#9AMBGV878N=BJV*C8
ML2``V879B-BLV8C8K]N,`-BHV+':K]BQV*_8I]F&V*_9AB#8I]F&V*K8KMBG
MV*@`5"U3=&]R;7,`V879AMBJV+38L2#:J=F&V8;8K]F'`-BMV+'9B-F!(-JI
MV*P`VIC8I]F&V8C;C-F'`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`V++;C-BQ
MV;[;C-BQV*?9A]F&VXP`VIC9B-BFVXS9AP#:F-F(V*;9A@#9A]F%XH",V*K8
ML=BGV+(@VJG8L=BOV88`V8?9A>*`C-BJV+'8I]BRVXP@V8C8L]BW`-F'V87B
M@(S8JMBQV*?8LMN,(-JIV*?9A=F$`-F'V87B@(S8JMBQV*?8LMN,(-J&V;X`
MV8?9A>*`C-BJV+'8I]BRVXP@V+'8I]BSV*H@`-BGV+79A-N,(-F&VJ_9AR#8
MK]BGV+38JMF'(-BTV8C8K]B?`-JIV*?8L=BSV*?8LB!K97)B97)O<V4@V*K8
MM=BOVXS9@B#9A]F(VXS9D=BJ(-BQV*<@V+'8KR#:J=BQV*\`V*?;C-BLV*?8
MKR#:J=F$VXS8KP#8I]BKV+$@V*?9AMJOV+38JB#:J=F$VXS8KP#8M]F(V80@
MVJG9A-N,V*\`V8;9B-BY(-JIV83;C-BO`-JIV*?8L=BHV+'8KR#:J=F$VXS8
MKP#:J=F$VXS8KR#9@MBHV838I]F+(-BOV+$@VJG8I]BQV+/8I]BR(-BYV879
MB-F%VXP@VJG9A-N,V*\@V879B-BLV8C8KR#8I]BSV*H`XH",V*C:AMF'XH",
MV8?8IP!+;W)E86X@*$550RU+4BD`V*S8I]F&V878I]N,VXP`V++8J-BGV88`
MV8;;C-F%V8?9E"#8HMBNV+$`V*K8NMN,VXS8L2#8HMBNV+';C-F&(-BGV+/9
MA2#8L=F%V+(`V+'8J-BY(-BBV*[8L0#8HMBNV+';C-F&(-BHV+'9B-BRV+'8
ML]BGV8;;C#H`V*+8KMBQVXS9AB#9B-BQV8C8KSH@)7,`V*+8KMBQVXS9AB#9
MB-BQV8C8KR`Z("5S(-BGV+(@)7,`V*+8KMBQVXS9AB#9B-BQV8C8KSH@V8?8
ML=JOV+(`V*W9@MF(V8(`V*S8I]F&V878I]N,VXP`VH;9O@#8L]BQV*+9A=BO
M(-J&V;X`V879@MBGV*_;C-BQ(-J&V;X`V8;9A>*`C-F&V84@V*C8I]BQV*?9
MA@#8J-BGV+'9AMBOVJ_;C"#8L]BHVJD`V*C8I]BQV8;8K]JOVXP@V+/8J-JI
M(-BRV8C8K]F'V8;:K]BGV84`V*C8I]BQV8;8K]JOVXP@V+/8J-JI(-BOVXS8
ML=F'V8;:K]BGV84`V*C8I]BQV8;8K]JOVXP@V8@@V+':K]BHV*?8L2#8L]BH
MVJD`V*C8I]BQV*?9AB#8L]BHVJD@V*C9AR#9A]F%V+'8I]F'(-BQV+G8KP#8
MJ-BQV8$@V+/8J-JI`-BHV+'9@2#9B"#8L=JOV*C8I]BQ(-BSV*C:J0#9OMN,
MV8C9AMBO`-F&V8+8I]BW(-F^VXS9B-F&V*\@V*C9ASH`V*+8K]BQV+,@V;[8
ML]BJ(-BGV83:J=BJV+'9B-F&VXS:J2#8L=BG(-BHV8<@V+79@=BMV8<@V*?;
MC-BLV*?8KR#9OMN,V+K8I]F%V(P@V*C9AR#9A]F&VJ_8I]F%(-F%V+38I]F'
MV*_9A]B,(-F^VXS9B-F&V*\@V*_9A]N,V*\`V;[;C-F(V8;8K^*`C-F'V*<`
MVJG9B-JIVXP@V83;C-F&V8C:J=BS`-F!V8?8L=BSV*H@+2#:J=BGV+'8J-BQ
M(-F%VXSB@(S8JMF(V*?9AMBO(-F^V8C8M-F'(-BQV*<@V*C8J-N,V8;8KP#9
M@=F'V+'8L]BJ(-BOV*?8K]JOV*?9AMF'V*?B@(P`V8'9A]BQV+/8JB#8N=F&
MV*?9B-N,V88@V+'8I]F'V8;9A=BG`-F!V8?8L=BSV*H@V*S8K]BGV8C9A`#9
M@=F'V+'8L]BJ(-BBV+'8M-N,V8@`V8'9A]BQV+/8JB#8L=BGV8?9AMF%V*<`
MV8'9A]BQV+/8JB!)9`#9@=F'V+'8L]BJ(-F%V*?9A-JI`-F!V8?8L=BSV*H@
MV;[8L]BJVXP`V8'9A]BQV+/8JB#8N=BVV8C;C-F1V*H`V8'9A]BQV+/8JB#8
MN=BOV84@V+G8MMF(VXS9D=BJ`-F!V8?8L=BSV*H@VJG8I]BQV*C8L=BGV88@
MV8'8N=BGV80@V8;9A=N,XH",V*C8I]BTV*\`V*?8K]BHVXS8I]BJ`-BHV*?8
ML=JIV+'8K]F&+BXN`-BSV*?8N=BJ(-F%V*W9A-N,.B``V878K=F$VXS9D=BJ
M(-F((-BSV*?8N=BJ`-F%V8C9@MBYVXS8J@#9B-BQV8C8KP#8KMBQV8C8K`#9
MB-BQV8C8KP#9B-BXV*?;C-F!(-F(V+'9B-BO`-F(V+'9B-BO(-F&V*?9A=F(
MV8'9D=F"(-BHV8C8KR#8LMN,V+'8IR#9AMBGV84@VJG8I]BQV*C8L2#9B"#;
MC-BG(-BGV+/9A2#8L=F%V+(@V8C8I]BQV*\@V+38K]F'(-BGV+38JMBHV*?9
MAR#8J-F(V*\@`-F(V+'9B-BO(-F&V*?9A=F(V8'9D=F"(-BHV8C8KRX`V878
MJMF&(-BHV839AMBO`-BYV+39@@#9OMBGVXS;C-F&`-BMV+'9B-F!(-JIV8C:
MAMJI(-N,V8C9AMBGV8;;C`#8K=BQV8C9@2#:J=F(VH;:J2#9A-BGV*K;C-F&
M`-BGV+G8K]BGV*\@VJG9B-J&VJD@VXS9B-F&V*?9AMN,`$U-`-F^VXS8NMBG
MV84@V+'9B-BR`-F^VXS9B-BSV*H@35,M5$Y%1B#8M-BGV879A"#9A]N,VH8@
MV*_8I]BOV8?B@(S8I^*`C-N,VXP@V8;;C-BSV*H`35-'`-BLV*?8K]F(`-F&
MV*?9A=F'(-BGV83:J=BJV+'9B-F&VXS:J=N,`-BSV+'9OMBQV+/8JB#9AMBG
MV879AP#8L]BGV*[8JMF&(-F^VXS9B-F&V*\N+BX`V878K]N,V+';C-BJ(-F(
M(-BJV+G;C-N,V88@V+'9AMJO(-BOV+/8JMF'XH",V8?8I]N,VXP@VJG9AR#8
MM-F%V*<@V879B-BGV+'8KR#8L=BG(-BHV*<@V*+9AMF'V*<@V8;8I]F%XH",
MVJ_8L-BGV+';C"#9A=N,XH",VJG9AMN,V*\`36%P,C0@;6%P`$UA<%%U97-T
M(&UA<`#9A=BGV+'8LP#8K=BGV+3;C-F'`-BYV838I]F%V*H@VJ_8L-BGV+';
MC"#8J-BG(-F^V+':AMF%(-F%V+38I]F'V*_9AR#8M-BOV8<O(-F%V+38I]F'
MV*_9AR#9AMBTV*_9AP`@V+G9A-BGV878JB#:K]BPV*?8L=N,(-BHV*<@V+G9
MA-BGV*;9A2#8K]N,VJ_8L2`HV878I]F&V8;8KR#9A=F'V84OV;[8I]BSV*X@
MV*_8I]BOV8<@V+38K]F'*0#9@=N,V838K^*`C-F'V*?;C"#8I]F&V+?8J-BG
MV8(`V*C;C-BTVXS9AMF'(-BGV+G8JMBHV*?8L2#9A=BLV*?8L@#8JMBNV+?;
MC"#8I]BR(-BHVXS8M-N,V8;9AR#9@MBSV878JMF'V*?;C"#9OMN,V+K8I]F%
M`-BHVXS8M-N,V8;9AR#8K]F%V*<@V*_8L2#;LMNT(-BSV*?8N=BJ(-JOV+#8
MM-BJV8<Z(`#8J-N,V+3;C-F&V8<@V*_9A=BG(-BOV+$@V[8@V+/8I]BYV*H@
MVJ_8L-BTV*K9ASH@`-BHVXS8M-N,V8;9AR#8M]F(V80`V87;C`#9OMBRV+3:
MJ=N,`-BGV+G8MMBGV*$`V878KR#:K]BRVXS9AMJOV*?9AMN,.@#8I]BOV+K8
MI]F%(-BSV839B-F$V8?8IP#9OMN,V+K8I]F%`-F^VXS8NMBGV84@V*C8IR#9
MA=F(V8'9D=F"VXS9D=BJ(-BHV*?8LMBHVXS9AMN,(-BTV*\@V*?9A=BG(-JO
MV8C8I]F'VXP@V*?9A=BVV*?8H2#:J=F&V8;8K]F'(-F&V87;C.*`C-BJV8C8
MI]F&V*\@V*C8I]BRV*C;C-F&VXP@V+39B-BO`-F^VXS8NMBGV84@V879AMF"
MV+;;C"#8M-BO`-F&V8C8N2#9OMN,V+K8I]F%`-BBV*@@V8@@V8?9B-BGVXP@
M365T87(`V*C9A-F(VJD@365T87(@V8+8I]BHV80@V*_8L]BJV+'8LR#9AMN,
MV+/8J@#8J-F$V8C:J2!-971A<B#9@MBGV*C9A"#8K]BSV*K8L=BS(-F&VXS8
ML]BJ+B#8K-BRV*;;C-BGV*H@V*C8L=BGVXP@V+/8L=F^V+'8L]BJ(-BSV*?9
MA=BGV8;9AR#8J]BHV*H@V+38K]F'(-BGV+/8J@#8L=F(V+0`V*?9AMBOV*?8
MLMF'XH",V*?;C`#9B-BSV+<`V8;9B-BY($UI;64`(-JIV87;C-F&V8<@V*_9
MA=BGVXP@V[+;M"#8L]BGV+G8JB#:K]BPV+38JMF'.B``(-JIV87;C-F&V8<@
MV*_9A=BGVXP@V[8@V+/8I]BYV*H@VJ_8L-BTV*K9ASH@`-BBVXS9AMF'`-F%
MV*K9@=BQV8+9AP#9OMN,VJG8L=BHV8;8K]N,(-F%V8C8K-F(V*\@V8;;C-BS
MV*HN(-BTV878IR#8I]JOV+$@V87;C.*`C-BNV8C8I]F'VXS8KR#8I]BR(-BG
MVXS9AB#8J-BQV8;8I]F%V8?9E"#:J=BGV+'8J-BQV*_;C"#8I]BSV*K9@=BG
MV*_9AR#:J=F&VXS8KR#8J-BGVXS8KR#8HMF&V+'8IR#8JMF(V83;C-BO(-JI
MV8;;C-BO`-BGV+(@V*C;C-F&(-BQV8'8JMF&($E$(-F^VXS8NMBGV84`V*?8
MLB#8J-N,V88@V+'9@=BJV88@240@V8;8M-BSV*H@`-BOV8C8M-F&V*C9AP#9
MOMBSV*H@V+/9A-F(V83;C`#9A=BYV*K8K]F$(-JIV+'8K]F&`-BJV*?8L=N,
MV*X@V*K8NMN,VXS8L2#;C-BGV8'8JMF'`-BJV+K;C-N,V+$@55),`-F%V*?9
MAR#9B"#8L]BGV80`V878I]F'V*?9AMF'`-F!V*?8LMF'V*?;C"#9A=BGV8<`
MV*C;C-BTV*K8L2#8M=BGV8$`V*C;C-BTV*K8L2#8I]BHV+';C`#8J-N,V+38
MJMBQ(-BBV8'8JMBGV*C;C`#8I]F&V*K9@MBGV80@V*C9AR#9OMBGVXS;C-F&
M`-BGV8;8JMF"V*?9A"#8J-F'(-BHV*?9A-BG`-BGV8;8JMF"V*?9A"#8J-F'
M(-BQV*?8L]BJ`-BGV8;8JMF"V*?9A"#8J-F'(-BHV*?9A-BG`-BGV8;8JMF"
MV*?9A"#8J-F'(-F^V*?;C-N,V88`V*?9AMBJV8+8I]F$(-BHV8<@V*C8I]F$
MV*<`V8'9A]BQV+/8JB#9OMBGVXS;C-F&XH",V;[8L2#:AMF&V*\@V+/8M]BM
MVXP`VH;9AMBO(-BGV8;8JMBNV*?8J-N,`-BMV+/8I]BH(-F%V88`V*?8M]F$
MV*?8N=BGV*H@V*W8L]BGV*@@V879A@#8K]BQVJ_8I]F'(-F%V88`V*S8I]F&
MV878I]N,VXP@V*_8L=JOV*?9AR#9A=F&`-F&V8?8C"#9A=F&(-F%V8C8I]F!
MV8(@V8;;C-BSV*K9A0#9AMBGV84`55),(-F^V*?;C-F'($YE='-C87!E`$YE
M='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!5
M4DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!5
M4DP`V*K9B-BVVXS8K2#:K]F(V*?9A]N,($YE='-C87!E`-F&V8C8N2#:K]F(
MV*?9A]N,($YE='-C87!E`-BTV*C:J=F'`-F'V+':K]BR`-BOV+/8JMF'(-BL
MV*_;C-BO`-F%V*?9AR#9AMF(`-F&V*?9A2#:J=BGV+'8J-BQVXP@V*S8K]N,
MV*\@*-BGV*[8JMN,V*?8L=N,*0#8I]BSV84@V+'9A=BR(-BLV*_;C-BO`-BG
MV+/9A2#8L=F%V+(@V838NMF((-BNV8C8I]F'V*\@V+38KR#8K]BQ("5X(`#8
MI]BSV84@V+'9A=BRV8?8I]N,(-BLV*_;C-BO(-BJV+?8I]BHV8(@V8;8K]BG
MV+'8KP#9OMF&V*S8L=F'(-BLV*_;C-BO("C8KMBGV83;C"D`V*?8KMBHV*?8
ML0#:K]BQV8C9A^*`C-F'V*?;C"#8KMBHV+';C`#8J-BYV*_;C`#:K]BRVXS9
MAMF'XH",V8?8I]N,(-BHV+G8K]N,`-BTV*@`V8;9AP#8K]BGV*_9AR#9OMN,
MVJG8L=BHV8;8K]N,(-BOV+$@V*_8L]BJV+'8L]N,(-BHV+'8I]N,(-F&V+38
MI]F&(-BOV*?8K]F&(-BJV8'8I]F(V*K9A]BG(-F(V*S9B-BO(-F&V*_8I]BQ
MV*\`25-/(-F&VXS8L]BJ(-BGV+/8JMBQV*?8JMJ8VXP@V*_8L2#8K]BSV*K8
ML=BSVXP@V*C8L=BGVXP@V+/8I]BNV*K9AB#8JMBUV8C;C-BQ(`#8I]F$VJ_9
MB-N,(-BOV+/8JMF'XH",V*?;C-N,(-F&VXS8L]BJ`-BHV838I]JIVXP@V*_8
ML2#9A=F(V8+8N=N,V*H@V*_8L=BNV8C8I]BSV*H@V+38K]F'(-F%V8C8K-F(
MV*\@V8;;C-BSV*H`V8?;C-J&(-F&V*?9A2#8JMF"V8C;C-F%VXP@V*C8L=BG
MVXP@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ($U#04P@V8'8L=BGV8?9A2#9AMBT
MV*_9AR#8I]BSV*H`V*C8K]F(V88@V*K8NMN,VXS8L0#9A]N,VH8@V878K-F(
MV+(@V8'8L=BYVXSB@(S8I]N,(-F&V87;C.*`C-BJV8C8I]F&V*\@V*C9AR#8
MI]N,V88@V878K-F(V+(@V*?8MMBGV8'9AR#8M-F(V*\`V8?;C-J&(-BGV+?9
MA-BGV+G8I]BJ(-F^VXS:J=BQV*C9AMBOVXP@V*C8L=BGVXP@)7,@V878M-BN
MV+4@V8;8M-BO`-F'VXS:AB#8I]BWV838I]BYV*?8JB#9OMN,VJG8L=BHV8;8
MK]N,(-BHV+'8I]N,($944"!61E,@V878M-BNV+4@V8;8M-BO`-F'VXS:AB#8
MI]BWV838I]BYV*?8JB#9OMN,VJG8L=BHV8;8K]N,(-BHV+'8I]N,(%-13"!6
M1E,@V878M-BNV+4@V8;8M-BO`-F'VXS:AB#8I]BWV838I]BYV*?8JB#9OMN,
MVJG8L=BHV8;8K]N,(-BHV+'8I]N,(%-13"U&:6QE(%9&4R#9A=BTV*[8M2#9
MAMBTV*\`V8?;C-J&(-BGV+G8JMBHV*?8L=N,(-BHV*?9@MN,(-F&V878I]F&
MV*\`V8?;C-J&(-F%V8+8M=BOVXP@V8'8L=BGV8?9A2#9AMBTV*\`V8?;C-J&
M(-F^V+'9B-F&V*_9A^*`C-BGVXS;C"#8I]BQV+/8I]F$(-F&V+38KP#9A]N,
MVH8@V*+;C-JIV8C9AMN,XH",(-F^VXS8K]BG(-F&V+38KP#9A]N,VH8@V87:
MJ=BGV8;;C"#8JMF&V+C;C-F%(-F&V+38K]F'`-F'VXS:AB#9OMN,V+K8I]F%
MVXP@V8'8L=BGV8?9A2#9AMBTV*\`V8?;C-J&(-F&V*?9A=N,(-F%V+38KMBU
M(-F&V+38KP#9A]N,VH8@V+39A=BGV+'9A^*`C-BGXH",VXS;C"#9A=BTV*[8
MM2#9AMBTV*\`V*+;C-F&V*_9AR#9AMBGV878M]BHV8C8N=N,(-F&VXS8L]BJ
M`-BHV+'8I]N,(-BJV+78K]N,V8(@V8?9B-N,V9'8JB!(5%10(-BGV+/9A2#8
ML=F%V++;C"#9@=BQV*?9A]F%(-F&V+38K]F'(-BGV+/8J@#8J-BQV*?;C"#8
MJMBUV*_;C-F"(-F'V8C;C-F1V*H@24U!4"#8I]BSV84@V+'9A=BRVXP@V8'8
ML=BGV8?9A2#9AMBTV*_9AR#8I]BSV*H`V*C8L=BGVXP@V*K8M=BOVXS9@B#9
MA]F(VXS9D=BJ($ME<F)E<F]S(-BGV+/9A2#8L=F%V++;C"#9@=BQV*?9A]F%
M(-F&V+38K]F'(-BGV+/8J@#8J-BQV*?;C"#8JMBUV*_;C-F"(-F'V8C;C-F1
MV*H@V8C8L=F(V*\@V*?8L]F%(-BQV878LMN,(-F!V+'8I]F'V84@V8;8M-BO
MV8<@V*?8L]BJ`-BHV+'8I]N,(-BJV+78K]N,V8(@V8?9B-N,V9'8JB!005-3
M5T0@V*?8L]F%(-BQV878LMN,(-F!V+'8I]F'V84@V8;8M-BOV8<@V*?8L]BJ
M`-BHV+'8I]N,(-BJV+78K]N,V8(@V8?9B-N,V9'8JB!334(@V*?8L]F%(-BQ
MV878LMN,(-F!V+'8I]F'V84@V8;8M-BOV8<@V*?8L]BJ`-BJV8+8I]BVV*?;
MC"#8J]BHV*H@V8;8I]F%VXP@V*_8L2#8I]F&V*K8N-BGV+$@V*K8H]N,VXS8
MKR#9AMN,V+/8J@#8J-BOV8C9AB#9@MF(V*?8N=BO`-F'VXS:AB#8K-BOV*?:
MJ=F&V8;8K]F'XH",V*?B@(S;C-N,(-F%V+38KMBU(-F&V+38KP#8J-BOV8C9
MAB#8L]F%V*H`V+38I]BNV8<@V879B-F"V*K;C"#8J-BQV*?;C"#:J=BGV+39
MAR#9A=F(V*S9B-BO(-F&VXS8L]BJ`-F'VXS:AB#9AMBGV84@VJG8I]BQV*C8
ML=N,(-F((-N,V*<@V*?8L]F%(-BQV878LMN,(-BGV+'8L]BGV80@V8;8M-BO
M`-F'VXS:AB#8K]BGV*_9AR!834P@V878N=BJV*C8L=N,(-BHV*?8LMJOV+'8
MK]BGV8;8K]F'(-F&V+38K]F'(-BGV+/8J@#8J-BOV8C9AB#9A=F"V*_8I]BQ
M`-F&V+/8KMF'XH",(-BOV+$@V;[;C-JIV+'8J-F&V*_;C"#8I]BUV83;C"#9
MOMN,V*_8IR#9AMBTV*\N(-F^VXS:J=BQV*C9AMBOVXP@V+'8IR#8K]F(V*C8
MI]BQV8<@V*K9B-F$VXS8KR#:J=F&VXS8KP#9AMBSV*[9A^*`C"#8K]BQ(-F^
MVXS:J=BQV*C9AMBOVXP@V+39A=BG(-F^VXS8K]BG(-F&V+38K]F'(-BGV+/8
MJBX@V;[;C-JIV+'8J-F&V*_;C"#8L=BG(-BOV8C8J-BGV+'9AR#8JMF(V83;
MC-BO(-JIV8;;C-BO`-F'VXS:AN*`C-JIV*_8I]F%`-F'VXS:AN*`C-JIV*_8
MI]F%("C8MMF%V8;;C"#8I]BSV*K9@=BGV*_9AR#:J=F&VXS8KRD`3F]R9&EC
M("A)4T\M.#@U.2TQ,"D`V8;;C-F%(-JIV+'9AR#8M-F%V*?9A-N,`-F&V8<@
MV*C8N=BO`-F&V8<@V8+8J-F$`-N,VJD@V+38I]BNV8<@V8;;C-BSV*H`V;[;
MC-BGV*_9A^*`C-BSV*?8LMN,(-F&V+38K]F'`-BJV8;8N-N,V84@V8;8M-BO
MV8<`V;[8M-BJVXS8J-BGV8;;C"#9AMBTV*_9AP#;C-BGV*_8K]BGV+38JMF'
MV*<`VH;;C-BRVXP@V*C8L=BGVXP@V878L=F(V+$@V8;;C-BSV*K8C"#8J-F'
M(-BYV8+8J"#8J-BQVJ_8L=BO`-F&V8C8I]F%V*C8L0#8N=BOV*\`V*K8N=BO
MV*?8KR#9AMF(VXS8L]F'XH",V8?8IP#8JMBYV*_8I]BO(-BSV*K9B-F&V8?8
MIP#8JMBYV*_8I]BO(-BSV+?8L=F'V*<`V*?8N=BOV*?8KR#8J-BQV*?;C"#8
MJ-BQV8C8LMBQV+/8I]F&VXP@V8'9A]BQV+/8JB#8JMF(V++;C-BYVXP@V878
MM-BNV+4@V8;8M-BOV8;8KP#8JMBCVXS;C-BO`-BTVXS8H0#8I]N,V*S8I]BO
M(-JIV8;9AMBOV8<@V+3;C-BA`-F'V+38JMBGVXS;C`#8I]JIV*K8J-BQ`-F!
MVXS9A-BJV+$@V*C;C.*`C-BMV+'9A=BJVXP`V*_9@=BJV+$@VJG8I]BQ`-BG
MV+/9A2#8L=F%V+(@V*S8K]N,V*\@V8@@V*?8L]F%(-BQV878LB#9@=BYV83;
MC"#8J-BGVXS8KR#9A=BJV8'8I]F(V*H@V*C8I]BTV8;8KP#8I]BSV84@V+'9
MA=BR(-F"V*_;C-F%VXP`V*?8L]F%(-BQV878LB`@V8+8K]N,V87;C"#9AMBG
MV*_8L=BSV*H@V*?8L]BJ`-BJV8;9A]BG(-JIV*?8L=BSV*?8LMF'V*?;C"!)
M34%0V;[9B-BTV8?B@(S9A]BGVXP@V878M-BJV+':J2#8L=BG(-F^V+38JMN,
MV*C8I]F&VXP@V87;C.*`C-JIV8;9AMBO(`#9@=F"V+<@V*+;C-F&V*_9AR#9
MAMBGV878M]BHV8C8N0#8JMF&V8?8IR#;C-JI(-BBV*_8L=BS(-F^V+/8JB#8
MI]F$VJG8JMBQV8C9AMN,VJG;C"#9A=BLV*?8LB#8I]BSV*H`V*K9AMF'V*<@
MV878I]F$VJD@VXS8IR#8L]BQV;[8L=BSV*H@V+/8I]F%V*?9AMF'(-F%VXSB
M@(S8JMF(V*?9AMBO(-F%V*?9A-JIVXS8JB#;C-BG(-F%V*S9B-BRV8?8I]N,
M(-F%V*?9A-JI(-BQV*<@V*C8L=BGVXP@VXS:J2#8I]BTV*K8L=BGVJD@V*K8
MNMN,VXS8L2#8K]F'V*\`V*_8L2#;C-JI(-F^V8;8K-BQV8<@V*S8K]N,V*\@
MV*C8I]BR(-BTV8C8KP#8I]N,V88@V;[;C-F(V8;8KR#8K]BQ(-N,VJD@V;[9
MAMBLV+'9AR#8K-BOVXS8KR#8J-BGV+(@V+39B-BO`-BSVXS8L]BJV84@V+G8
MI]F%V80`VJ_8LMN,V8;9AR8C>#(P,&,[V8?8IP#:K]BRVXS9AMF'XH",V8?8
MI]N,("5S`-F$VXS8L]BJ(-F%V+'8JMBH(-BTV*_9AP#8L]BGV++9A=BGV88`
MV8C8I]BMV*\@V+/8I]BRV878I]F&VXP`V+/8I]BRV878I]F&V*_9A]N,`-BG
MV83:K]F(VXP@V*?8M=F$VXP@V*C8L=F&V*?9A=F'V90@VJG8I]BQV*C8L=BO
MVXP`V*?9A-JOV8C9A]BGVXP@V*?8M=F$VXP@V*_8L2`E<SH`V*_;C-JOV+$`
MV*?8M]F$V*?8N=BGV*H@V*_;C-JOV+$`V878K-F(V++B@(S9A]BGVXP@V878
MI]F$VJD`V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(%!!32#9@MBGV*C9A"#8K]BS
MV*K8L=BSVXP@V8;;C-BSV*H`V*?9A=BVV*?8H>*`C"#8K]N,V*S;C-BJV*?9
MA-N,(%!'4`#9OMN,V+K8I]F%(-BQV878LMBHV8;8K]N,(-BTV*_9A]F4(%!'
M4``@VJG9A-N,V*\@V+G9A=F(V87;C"!01U``V;[;C-BZV*?9A2#8L=F%V++8
MJ-F&V*_;C"#8M-BOV8<OV*?9A=BVV*?8H2#8M-BOV8<@4$=0`-JIV*\@4$A0
M`-F^V8C8L]BJV8<@4$A0`-BHV*?8L=F&V*_:K]N,(-BSV*C:J2#8N=BUV+':
MK]BGV8?;C`#8L=JOV*C8I]BQ(-BYV+78L=JOV*?9A]N,`-BHV+'9@2#8N=BU
MV+':K]BGV8?;C`#8JMJOV+':KR#8N=BUV+':K]BGV8?;C`!4+5-T;W)M<P#8
MJ-BSV+<@4$]325@@V*?8LB#8J-N,V88@V+'9@=BJV8<@XH",V*?8L]BJ`-F^
MV8C8L]BJV8<@4$A0`-F!V*?8M=F$V8?B@(S:K]BPV*?8L=N,`-F"V+/9A=BJ
MVXP@V*?8J-BQVXP`V*?8L]F%(-BQV878LB``V*?8L]F%(-BQV878LB#8J-BG
M(-F%V8C9@=F1V8+;C-F1V*H@V*K8NMN,VXS8L2#;C-BGV8'8JBX`V*?8L]F%
M(-BQV878LB`@V8;8I]BOV+'8L]BJ(-BGV+/8J@#8I]BSV84@V+'9A=BR("#8
MJ-F'(-BJV+78K]N,V8(@V8?9B-N,V9'8JB!2041)55,@V8;;C-BGV+(@V*_8
MI]BQV*\`V*?8L]F%(-BQV878LB`@V*C8IR#8JMBCVXS;C-BO`-BGV+/9A2#8
ML=F%V+(@.@#8I]BSV84@V+'9A=BR(#H@`-BGV+/9A2#8L=F%V++B@(S9A]BG
M(-BHV*?;C-BO(-F%V8;8M]BHV8(@V*C8I]BTV8;8KP#:AMBSV*C8I]F&V*_9
MA@#:AMBSV*C8I]F&V*_9AB#8I]BR(-BJV*[8JMF'(-BQV+/9A0#9A=BSVXS8
ML0#8J]BHV*H@V8;8I]F%V8?8I]N,(-F&V*?9A=BYV839B-F%`-F%V+'8K]F%
M`-BOV+'8M=BO`-BGV*S8L=BGVXP@V+G9A=F$VXS8I]BJ(-F&VJ_9A]BOV*?8
ML=N,`-BBVXS8IR#8N=F%V83;C-BGV*H@V8;:K]F'V*_8I]BQVXP@V*_8L2#9
MA-BMV+C9AR#9B-BQV8C8KR#8I]BLV+'8IR#8M-F(V*_8GP#9A=BLV8C8L@#9
MA=BLV8C8LB`@(B5S(B#8K=BPV8$@V8;8M-BO`-F%V*S9B-BRV8?8IP#8L]BQ
MV;[8L=BSV*K;C"#9A=BLV8C8LMF'V*<`V*?8M]F$V*?8N=BGV*H@V+38KMBU
MVXP`V*W;C-F(V*?9AMBGV*H@V*[8I]F&VJ_;C`#8JMF$V8'9A@#8N=JIV+/9
MA]BG`-F^VXS:J=BSV839A]BG`-F$V+?9@=BGV8L@V*_8I]BNV80@VH;9AMBO
M(-BSV839B-F$(-JIV83;C-JI(-JIV8;;C-BO`-F$V+?9@=BGV8L@V*K8H]N,
MVXS8KR#:J=F&VXS8KR#:J=F'(-F%VXSB@(S8KMF(V*?9A]N,V*\@V*?;C-F&
M(-BYV8;8M=BQ(-BQV*<@V*W8L-F!(-JIV8;;C-BO.@#9A-BWV8'8I]F+(-BJ
MV*/;C-N,V*\@VJG9AMN,V*\@VJG9AR#9A=N,XH",V*[9B-BGV8?;C-BO(-F^
MVXS9B-F&V*\@V*?;C-F&(-BYV8;8M=BQV8?8IR#8L=BG(-F"V+?8N2#:J=F&
MVXS8KP#9A-BWV8'8I]F+(-N,VJD@V878I]F'(-F((-N,VJD@V+/8I]F$(-F(
MV*?8L=BO(-JIV8;;C-BO+@#9A-BWV8'8I]F+(-F&V*?9A=N,(-BHV+'8I]N,
M(-BOV+/8JMF'(-BLV*_;C-BO(-F(V*?8L=BO(-JIV8;;C-BO.@#9A-BWV8'8
MI]F+(-BBV*_8L=BS($E0(-F%V+G8JMBHV+';C"#9B-BGV+'8KR#:J=F&VXS8
MKP#9A-BWV8'8I]F+(-N,VJD@V*K8I]BQVXS8KB#9A=BYV*K8J-BQ(-F(V*?8
ML=BO(-JIV8;;C-BOV(P@V*K8N=BOV*?8KR#8L=F(V++9A]BG(-BOV+$@V878
MI]F'(-BQV*<@VJG9AMBJV+'9A"#:J=F&VXS8KP#9A-BWV8'8I]F+(-N,VJD@
MV++9A=BGV88@V878N=BJV*C8L2#9B-BGV+'8KR#:J=F&VXS8KP#9A-BWV8'8
MI]F+(-BNV838I]BUV8?B@(S8I^*`C-N,VXP@V*?8LB#9A=BTVJG9A"#8L=BG
M(-BHV8;9B-N,V+/;C-BO`-F$V+?9@=BGV8L@V8;8I]F%(-JIV*?8L=BHV+$@
MV8@@V*?8L]F%(-BQV878LB`@V*[9B-BO(-BQV*<@V*+9A=BGV*_9AR#:J=F&
MVXS8KP#9A-BWV8'8I]F+(-F%V*K9AB#8LMN,V+$@V+'8IR#8J-BNV8C8I]F&
MVXS8KRX@V+39A=BG(-BHV+'8I]N,(-BGV+/8JMF!V*?8K]F'(-BGV+(@V+/8
MI]F%V*?9AMF'(-BHV*?;C-BO(-BTV+'9B-BW(-BQV*<@V8+8J-F(V80@VJG9
MAMN,V*\`V838M]F!V*?9BR#9AMBGV84@V*_8L]BJV8<@V*S8K]N,V*\@V+'8
MIR#9B-BGV+'8KR#:J=F&VXS8KSH`V+/;C-BGV+/8JMF'V*<`V*+8L=BGV*$`
MV878K=F$(-F"V+'8I]BQVJ_8L=F!V*K9AB#8I]N,V88@V*K8M=F(VXS8L0#9
MA=BMV80@V8+8L=BGV+':K]BQV8'8JMF&(-BGVXS9AB#8K-BOV8C9A`#9OMBS
MV*H@V*C9AR#8I]N,V88@V;[9B-BTV8<`V*_8L=BUV*\@V+'8M]F(V*C8JB#8
MK]BQ("5S(-BSV*?8N=BJ(-F"V*C9A#H`4')E9G-?;&1A<#H@V*C8L]BW(-F%
MV8C8L=BO(-F&VXS8I]BR($Q$05`@V;[;C-BOV*<@V8;8M-BO`%!R969S7W-E
M<W-I;VXZ(-BHV+/8MR#9A=F(V+'8KR#9AMN,V*?8LB!S97-S:6]N(-F^VXS8
MK]BG(-F&V+38KP#9@=BTV*?8L0#9@=BTV*?8L2#8K]BQ(-BSV+?8K2#8K]BQ
MVXS8ISH@`-F!V+38I]BQ.B``V;[;C-BTXH",V8;9A=BGVXS8M`#9OMN,V+3B
M@(S9AMF%V*?;C-BT(-BJV+79B-N,V+$@V*_8L2#;C-JI(-F^V8;8K-BQV8<@
MV*S8K]N,V*\@`-JOV++;C-F&V8?B@(S9A]BGVXP@V8+8J-F$VXP`VH;8I]F^
M(-BSV8;8KP#:J=F$VXS8KR#8M-BNV+7;C`#9A=BTVJG9A`#8JMF(V+;;C-BM
M(-F%V+3:J=F$`-F^V+'9B-J8V8?B@(S9A]BG`-F%V*K9AB#8I]BYV838I]F&
M`-JIV83;C-BO(-BYV879B-F%VXP`V*?9A-JOV8C8L=N,V*K9A2#:J=F$VXS8
MKR#8N=F%V8C9A=N,`-BLV8'8JB#:J=F$VXS8KR#8N=F%V8C9A=N,+]BNV+79
MB-BUVXP@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BJV8C9A-N,V*\@V8;8M-BO
M`-F^V+'8L^*`C-F(V*S9B`#8L]F'V87;C-F'`"#:J=F$VXS8KR#8N=F%V8C9
MA=N,(%)302`H)60@V*C;C-BJ*0#8I]F&V*K8KMBGV*@@V+'8I]BOVXS9B`#8
MJ-BGV+'8I]F&`-BHV*?8L=BGV88@V++9B-BOV8?9AMJOV*?9A0#8J-BGV+'8
MI]F&(-BOVXS8L=F'V8;:K]BGV84`V*C8I]BQV*?9AB#9B"#8L=JOV*C8I]BQ
M`-BHV*?8L=BGV88@V8@@V*C8L=F!`-BHV*?8L=BGV88@V*C9AR#8J-BQV8$`
MV+?8I]F$V+D@V*K8M=BGV*_9@=N,`-F&V+/8J-BJ`-BNV8C8I]F&V*_9A@#8
MKMF(V*?9AMBOV88@V;[;C-BZV*?9A=F'V*<@`-F(V*?9@MBYV*?9DB`E<R#8
MK=BPV8$@V+39B-BOV)\@V*?;C-F&(-BYV879A"#9@MBGV*C9A"#9B-BGVJ_8
ML=BO(-F&VXS8L]BJ`-F(V*?9@MBYV*?9BR#8K]BGV*_9A]F4(-JIV*?8L=BH
MV+';C"#8J-BQV*?;C"#:J=BGV+'8J-BQ("5S(-BMV+#9@2#8M-F(V*_8GR#8
MI]N,V88@V+G9A=F$(-F"V*?8J-F$(-F(V*?:K]BQV*\@V8;;C-BSV*H`V*?9
MAMBLV*?9A2#8HMBNV+';C-F&(-BYV879A"#8M-F%V*<@V*?8LB#9AMF(`-BH
MV*?8LMBBV8C8L=N,(-BYV8;8I]BUV+$@VJ_8LMN,V8;:K]BGV88@V*_;C-F&
MV*?9A=N,VJG;C#H`V*C8I]BRV*+9B-BQVXP@V8;9A=BGVXP@V*_8L=JOV*?9
MASH`V878L=F(V+':K]BQ(-BQV*?8J-BWV8?B@(S8I^*`C-N,VXP`V*K9B-BV
MVXS8K=BGV*H`VJG8I]BQV+/8I]BRV8?8I]N,(-BQV*?9A^*`C-BOV8C8L0!5
M4DP`V*W8L-F!`-BMV+#9@2#8J-F$V8C:J0#8K=BPV8$@V+/8JMF(V88`V*W8
ML-F!(-F"V*?9A-BH(-BHV8;8K]N,`-BMV+#9@2#8LMF(V*P`V*W8L-F!(-BO
MV+/8JB#B@(S9AMF(VXS8L]F'V*?;C"#8K=F!V+@@V+38K]F'(-BOV+$@V+38
MI]BNV8<@V879B-F"V*H@VJG8I]BQV+/8I]BR`-BMV+#9@0#8K=BPV8$@V*?;
MC-F&(-JOV+'9AR#8I]BR(-BSV8;8KP#8K=BPV8$@VJG8I]BQV*C8L0#8K=BP
MV8$@VJG8I]BQV*C8L3H@)7,`V*K9@MBGV+;8IR#9@MBGV*C9A"#9OMBGV+/8
MKMJOV8C;C-N,(-F&VXS8L]BJ+B#:J=BO(-BNV+?8I]N,(-BHV+':K]BQV*_8
MI]F&V*_9AR#8M-BOV8<Z`-F!VXS9A-BOV8?8I]N,(-F%V8C8L=BO(-F&VXS8
MI]BR`-BHV*?8LMF&V+38I]F&VXP`V*C8I]BRV8;8M-BGV8;;C"#8I]BSV84@
MV+'9A=BR`-BGV+/9A2#8L=F%V+(@V*[9B-BO(-BQV*<@V*C8I]BRV8;8M-BG
MV8;;C"#:J=F&VXS8KP#9AMBJV*?;C-BL`-BHV*?8LMJOV+38JB#8J-F'(-JO
MV++;C-F&V8?B@(S9A]BG`-BJV*?;C-F^(-BOV8C8J-BGV+'9AR#8I]BSV84@
MV+'9A=BR("#8K-BOVXS8KR``VJ_8L=BOV8?9A=BGVXS;C`#8J-BGV++:K]BQ
MV*_8I]F&V*_9AB#9OMN,VJG8L=BHV8;8K]N,`-JOV++;C-F&V8?B@(S9A]BG
MVXP@V8C;C-BQV*?;C-BTVJ_8L2#9A=BJV88`V878N=F%V*?9A]BG`-BQV*?8
ML]BJ`-BSV+'8HMF%V*\@V+'8I]BSV*H`V879@MBGV*_;C-BQ(-BQV*?8L]BJ
M`-BNV+79B-BUVXS8I]BJ(-BSV+?8L2XN+@#9AMF"V+0`VH;8L=BNV+0@V[';
MN-NP(-BOV+'8K-F'`-J&V+'8KMBT(-BHV8<@VH;9O@#:AMBQV*[8M"#8J-F'
M(-BQV*?8L]BJ`-BNV+79B-BUVXS8I]BJ(-BSV+?8L0#8KMBUV8C8M=N,V*?8
MJB#8L]BWV+$`V+/8M]BQV8?8ISH`V8+9B-BGV+G8KP#9@MF(V*?8N=BO(-BH
MVXS9AB#8JMF%V*?9A2#8L]BWV+'9A]BG(-F((-BSV*K9B-F&V8?8IR#9AMF%
MV*?;C-BGV88@V*[9B-BGV8?8KR#8M-BO`-F"V8C8I]BYV*\@V8'9@MBW(-BH
MVXS9AB#8JMF%V*?9A2#8L]BJV8C9AMF'V*<@V8;9A=BGVXS8I]F&(-BNV8C8
MI]F'V*\@V+38KP#9@MF(V*?8N=BO(-F!V8+8MR#8J-N,V88@V*K9A=BGV84@
MV+/8M]BQV8?8IR#9AMF%V*?;C-BGV88@V*[9B-BGV8?8KR#8M-BO`-BGV*S8
ML=BG`-F^VXS8NMBGV84@V+'9A=BRV*C9AMBOVXP@(-BTV*_9A]F4(%,O34E-
M12``V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(%-!4TP@V8+8I]BHV80@V*_8L]BJ
MV+'8L]N,(-F&VXS8L]BJ`-F^VXS8NMBGV84@4TU3`-F^V8C8L]BJV8<@4U%,
M`%-32`#9A=F(V8'9D=F"VXS9D=BJ`-F^V8C8L]BJV8<@4U%,`-BTV8;8J-F'
M`-F'V878I]F&(-J&V*?8L=J&V8C8J"`HV*[9B-BOV+0I`-BMV8'8N"#:J=BQ
MV*_9A@#8K=F!V+@@VJG8L=BOV88@)7,`V*W9@=BX(-JOV++;C-F&V8?B@(S9
MA]BG`-F^VXS:J=BQV*C9AMBOVXP@V*K9B-F$VXS8KR#8M-BOV8<@V*C8N=F&
MV8C8I]F&(-BOV+/8JB#B@(S9AMF(VXS8LR!02%`@V*_8L2#8M-BGV*[9A]F4
M(-F%V8C9@MBJ(-JIV*?8L=BSV*?8LB#8M-F%V*<@V*W9@=BX(-BTV8C8KP#9
MOMN,VJG8L=BHV8;8K]N,("5S(-BMV8'8N"#8M-BO`-BYV839A0#8K-BSV*KB
M@(S9B-BLV8@`V*S9B-N,V+3:K]BQV8?8IP#8I]F&V*K8KMBGV*@@V;[8L=F(
MV8;8K]F'XH",V8?8IP#8I]F&V*K8KMBGV*@@VXS:J2#8JMBGV+';C-BN`-BG
MV8;8JMBNV*?8J"#;C-JI(-JOV+'9B-F'(-BHV+'8I]N,(-BGV+;8I]F!V8<@
MVJG8L=BOV88`V*?9AMBJV*[8I]BH(-N,VJD@V878I]F$VJD@V*S8K]N,V*\`
MV*?9AMBJV*[8I]BH(-N,VJD@VJG8I]BQV+/8I]BR`-BGV8;8JMBNV*?8J"#;
MC-JI(-JIV*?8L=BHV+$@V*C8L=BGVXP@V*?8MMBGV8'9AR#:J=BQV*_9A@#8
MI]F&V*K8KMBGV*@@V8?9A=F'`-BGV8;8JMBNV*?8J"#8JMF%V*?9A2#9A=BD
MV839@=F'XH",V8?8I]N,(-BJV*?8L=N,V*X`V*?9AMBJV*[8I]BH(-N,VJD@
MV+38I@#8I]F&V*K8KMBGV*@@V8?;C-J&XH",VJG8K]BGV84`V8;9B-N,V+/9
MA^*`C-F'V*?;C-N,(-JIV8<@V838I]BRV84@V*_8I]BQVXS8KR#8L=BG(-BG
MV+(@V*S8N=BHV8<@V++;C-BQ(-BGV8;8JMBNV*?8J"#:J=F&VXS8KRX@V+/9
MOMBS(-BTV878IR#9A=N,XH",V*K9B-BGV8;;C-BO(-BGV+(@V*+9AMF'V*<@
MV*_8L2#9A=F&V+?9@MF'(-F%V*K9AB#9AMBSV*[9A^*`C-BHV+'8K]BGV+';
MC"#:J=BQV*_9AR#9B"#8K]BQ(-F%V*W9A"#8K]N,VJ_8L2#8J-J&V+/8J-BG
MV8;;C-BO`-BGV8;8JMBNV*?8J"#9A=BMV*_9B-BOV8<@V*K8I]BQVXS8KCH`
MV*?9AMBJV*[8I]BH(-F"V*?9A-BH(-BJV*?8L=N,V*XZ`-BGV8;8JMBNV*?8
MJ"#9A]F(VXS9D=BJVXP@VJG9AR#9A=N,XH",V*[9B-BGV8?;C-BO(-BJV+K;
MC-N,V+$@V*_9A]N,V*\Z`-BGV8;8JMBNV*?8J"#9A=BMV*_9B-BOV8?9E"#8
MLMF%V*?9ACH`V*?9AMBJV*[8I]BH(-F"V*?9A-BH(-BRV878I]F&.@#8I]F&
MV*K8KMBGV*@@V*_9B"#9@=N,V838KR#9A=F&V+?8J-F"`-BGV8;8JMBNV*?8
MJ"#8M]BQV*T@V+'9AMJO(-BTV878IP#8I]F&V*K8KMBGV*@@V++8J-BGV88@
MV879B-BQV*\@V8;8N-BQ(-BTV878ISH`V*?8L=BSV*?9A"#:K]BRV*?8L=BT
M`-BGV+'8L]BGV80@4TU3`-BMV+/:K]BQ.B``V+/9OMBJV*?9A=BHV+$`V*?8
MN=BOV*?8KR#8JMBQV*K;C-BHVXP`240@V8;8M-BSV*H@V879AMF"V+;;C"#8
MM-BOV8<@V*?8L]BJ`-BJV8;8N-N,V84`V*K9AMBXVXS9A2#:K]BRVXS9AMF'
MXH",V8?8IR#8J-BQV*?;C"#8I]BLV*?8LMF'(-BOV*?8K]F&(-BHV8<@V+39
MA=BG(-BHV+'8I]N,(-BHV*?8LMF&V+38I]F&VXP@V*?8L]F%(-BQV878LB#8
MJ-F'(-F'V8;:K]BGV84@V8'8L=BGV879B-BTVXP@V*+9AB``V*K9AMBXVXS9
MA2#:J=BGV+'8L]BGV++9A]BGVXP@V+'8I]F'(-BOV8C8L=N,(-JIV8<@V+39
MA=BG(-F%VXSB@(S8KMF(V*?9A]N,V*\@V*?8LB#8K]BQVJ_8I]F'(-BNV8C8
MKR#8J-F'(-BBV88@V*_8L]BJV+'8L]N,(-BOV*?8M-BJV8<@V*C8I]BTVXS8
MKP#8I]F&V*K8KMBGV*@@V++8J-BGV88@V879B-BQV*\@V8;8N-BQV(P@V+/8
MI]BYV*H@V8@@VJ_8LMN,V8;9A^*`C-F'V*?;C"#8JMBGV+';C-BN`-BGV8;8
MJMBNV*?8J"#8J-BQV8;8I]F%V8<@V++9A=BGV88@V+38L=F(V+G8C"#8M]BQ
MV*T@V+'9AMJOV(P@V*C8I]BRV*+9B-BQVXP@V+79@=BMV8<@V8@@V*C9@MN,
MV8<@VJ_8LMN,V8;9A^*`C-F'V*?;C"#9AMF%V*?;C-BT`-BQV*?9AR8C>#(P
M,&,[V*?9AMBOV*?8LMN,`-BOV+/8JB#B@(S9AMF(VXS8LR`@V*C8L=F(V++8
ML=BSV*?9AMN,(-BQV*?9A^*`C-BGV8;8K]BGV++;C"#8K]BQ(-BOV+/8JMBQ
MV+,@V*?8L]BJ`-J&V8;8K]N,V88@V879B-F"V+G;C-F1V*H@V*C8IR#9OMBG
MV+'8I]F%V*K8L2#9A=F%VJG9AB#8I]BSV*HZ`-BNV+';C-BO`-BNV838I]BU
MV8<@VJG9B-BJV*?9AP#8HMN,V*<@VJG9A-N,V*_9A]BGVXP@V*_8L]BJV+'8
ML]N,(-BHV*?;C-BO(-BHV+'8I]N,(-BHVXS8M-BJV+$@V;[;C-F(V8;8K]F'
MV*<@V*K8N=BQVXS9@2#8M-F(V8;8K]B?`-F&V878I]N,V+0`(-F&V878I]N,
MV+0@V*K9@=BGV8C8JMF'V*?;C"#9A=N,V*?9AB#9OMN,VJG8L=BHV8;8K]N,
M(-BMV8'8N"#8M-BOV8<@V8'8N=F$VXP@V8@@V*K9B-F$VXS8KR#8M-BOV8<@
MV*S8K]N,V*\`V*+;C-BG(-BRV878I]F&(-BBV*[8L=N,V88@V8C8L=F(V*\@
MV*C9AR#9A]F&VJ_8I]F%(-F(V+'9B-BO(-F&V+38I]F&(-BOV*?8K]F'(-BT
MV8C8K]B?`-F&V878I]N,V+0@VJ_8LMN,V8;9A^*`C-F'V*<@V*C8L=BGVXP@
MV8;:K]F'V*_8I]BQVXP@V*?8M=F$`-BGV8;8JMBNV*?8J"#9@]F&V8;8K]F'
M(-F&V878I]N,V+0`V*+;C-BG(-F%VXS9A-F'(-JOV++;C-F&VJ_8I]F&(-BY
MV879A-N,V*?8JB#8K-BOV8C9A.*`C"#9AMF%V*?;C-BT(-BOV*?8K]F'(-BT
MV8C8K]B?`-BBVXS8IR#:K]BRVXS9AMJOV*?9AB`E<R#8L]F%V*H@V+'8I]BS
MV*H@V8;8M-BGV88@V*_8I]BOV8<@V+39B-BOV)\`V8;9A=BGVXS8M"#:K]F!
MV*KB@(S9B-JOV8C;C"#8KMBUV8C8M=N,V*?8JB#8L]F$V8C9A"#8K-BOV8C9
MA`#9AMF%V*?;C-BT(-JOV8'8JMJOV8C;C"#8KMBUV8C8M=N,V*?8JB#8K-BO
MV8C9A`#9AMF%V*?;C-BT(-JOV8'8JMJOV8C;C"#8KMBUV8C8M=N,V*?8JB#8
ML]BWV+$@V*S8K]F(V80`V8;9A=BGVXS8M"#:K]F!V*K:K]F(VXP@V*[8M=F(
MV+7;C-BGV*H@V*K8M=F(VXS8L0#9AMF%V*?;C-BT(-BGV+'8L]BGV80`V*K:
MK]BQVJ\`V+':K]BHV*?8L2#8LMF(V*_9A]F&VJ_8I]F%`-BQVJ_8J-BGV+$@
MV*_;C-BQV8?9AMJOV*?9A0#8K-F%V+D@V+38K]F&`-BLV878N2#8M-BOV88@
MVXS8IR#8I]F&V*K9@MBGV80@V*C9A-F(VJG9A]BGVXP@V878K-BGV8C8L0#8
MJ]BHV*H@V8;8I]F%`-BGV878MMBGV*$`V*?9A-JOV8C8L=N,V*K9A2#8I]F%
MV+;8I]BA`-BGV8;8K]BGV++9AP#8M=BQV8'9AMBXV+$@V*?8LB#9AMJOV8?8
MK]BGV+';C`#8J-BQV8$`V*K:K]BQVJ\`V*K:K]BQVJ\`V+':K]BHV*?8L2#8
MLMF(V*_9A]F&VJ_8I]F%`-BQVJ_8J-BGV+$@V*_;C-BQV8?9AMJOV*?9A0#8
MN=F%V8(@V*C8L=F!.B``V878N=BGV*_9A"#8J-BQV8$@V*_8L2#8HMBH.B``
MV+38N=BQV8?8IR#9B"#8HMF(V*?8LMF'V*<`V*?9AMBJV*[8I]BH(-BLV8?8
MJB#9A=BQV*K8J"#8L]BGV++;C`#8HMBOV+'8LR#8L]BQVH;8M-F%V8<`4V]U
M=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`-F&VXS9A2#:J=BQV8<@V*S9AMF(
MV*C;C`#9@=BGV+79A-F'V90@V*C;C-F&(-BSV839B-F$V8?8I]N,(-F%V*S8
MI]F(V+$`V8'8I]BUV839A]F4(-BHVXS9AB#9A=BMV*K9B-BG(-F((-F$V*C9
MAR#8K]BQ(-BSV839B-F$`-F!V*?8M=F$V8?B@(S:K]BPV*?8L0#9@=BGV+79
MA-F'`-F!V*?8M=F$V8?B@(S:K]BPV*?8L=N,(-F((-BOV+'8LMJOV+#8I]BQ
MVXP`V8?8L=BRV8;8I]F%V8<`VJG8I]BQV*?:J=BJV+$@V*[8I]BU(-F(V*?8
ML=BO(-BTV*\`V*K9@MBSVXS9A2#8L]F$V8C9A`#8JMF"V+/;C-F%(-BSV*K9
MB-F&`-BJV8+8L]N,V84@V+/8M]BQ`-F(V+'8LMBTVXP`V*?8L]BJV*?9AMBO
MV*?8L=BO`-BSV*K8I]BQV8<`V+/8I]F$(-BTV+'9B-BY`-F(V+;8N=N,V*H@
MV*W9B-BRV8?B@(S9A]BG`-F(V+;8N=N,V*KB@(P`V8+8I]F$V*@@V+#8KMN,
MV+'9AR#8L]BGV++;C`#8HMBOV+'8LR#8KMN,V*?8J-BGV88`V8'9A]BQV+/8
MJB#8L=BTV*K9AP#8M-N,V8C9AR!;0U-370#;C-JIV+39AMBHV8<`V+G9AMF(
MV*?9A@#8I]BQV+/8I]F$`-BRVXS8L=F&V8C;C-BS`-F%V8C9@=F1V8+;C-F1
MV*H`(B5S(B#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*W8L-F!(-BTV*\`V;[;
MC-JIV+'8J-F&V*_;C"#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*C8I]BRVJ_8
ML=BOV*?9AMBOV8<@V+38KRX@V*C8L=BGVXP@V878M-BGV8?8K]F'(-BJV+K;
MC-N,V+'8I]BJ(-F%V*S8K]BOV*?9DB#8HMF&V+'8IR#8J-BGV+$@V8;9A=BG
MVXS;C-BO`-F^VXS:J=BQV*C9AMBOVXP@V;[8M-BJVXS8J-BGV88@V*C8IR#9
MA=F(V8'9D=F"VXS9D=BJ(-BMV8'8N"#8M-BO`-F^V+'9B-F&V*_9AR#9OMBT
MV*K;C-BHV*?9AB#9OMN,VJG8L=BHV8;8K]N,("5S(-BHV*<@V879B-F!V9'9
M@MN,V9'8JB#8K=F!V+@@V+38KP`E<R#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@
MV8;9B-BTV*K9AR#8M-BO`-BNV838I]BUV8<`V+?9A-F(V+D@V*+9@=BJV*?8
MJ`#8NMBQV8C8J"#8HMF!V*K8I]BH`-BBV8'8JMBGV*C;C`#8M]F$V8C8N0#8
MM]F$V8C8N2_8NMBQV8C8J`#8M]F$V8C8N3H@`-BZV+'9B-BH`-BZV+'9B-BH
M.B``V*C8I]F$V*?9AMF(VXS8LP#9OMBTV*K;C-BHV*?9AMN,`-F&V*?9A2#8
MKMBGV8;9B-BGV*_:K]N,`-BNV+?8I]N,(-F&V*W9B-N,(-BOV+$@V879B-BG
MV+'8KR#8K-BSV*K8K-F(`%0M4W1O<FUS`%0M4W1O<FUS`-F^V+'9B-F&V*_9
MAR!44U8`V*S8K]F(V80`V*[8M=F(V+7;C-BGV*H@V*S8K]F(V80`V*[8M=F(
MV+7;C-BGV*H@V*S8K]F(V80`V8?8K]F!.@#9B-BXV*?;C-F!`-BTV878I]BQ
MV8<@V*K9A-F!V88`V*_9A=BGVXP@V+/8I]BYV*H@V*?8KMN,V+$Z(`#8K]BQ
MV*S9AR#8K=BQV*?8L=BJ`-BOV+'8K-F'(-BMV+'8I]BQV*HZ(`#8I]F$VJ_9
MB-N,(-BSV+'9OMBQV+/8JMN,`-F%V*K9A@#9@=F"V+<@V878JMF&`-BJV+'8
MI]BR(-F%V*K9A@#8J-BGV838I]N,(-F%V*K9A@#9OMF&V*S8M-F&V*C9AP!4
M:&%I("A425,M-C(P*0#8I]BR(-BTV878IR#8J-F'(-BNV*?8M]BQ(-BGV+/8
MJMF!V*?8K]F'(-BGV+(@V+/8I]F%V*?9AMF'(-F%V*K8M-JIV+';C-F%`-BH
MV+/8MR!&5%`@V8+8I]BHV80@V*_8L]BJV+'8LR#9AMN,V+/8J@#9AMJOV8?8
MK]BGV+';C#HZ(-JIV838I]BS(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8J-BG
MV+$@V8;8M-BO`-F^V8;8K-BQV8?9E"#:K]BRVXS9AMF'XH",V8?8IR#8J-BS
MV*K9AR#8M-BO+B#8KMBQV8C8K`#8L]BQV;[8L=BSV*H@V*C8I]N,V*\@VXS:
MJ2#9OMBTV*K;C-BHV*?9AB#9A=BLV8C8LMF'V*<@V+'8I]B,("#8K]BQ(-BU
MV8C8L=BJ(-BJV878I]N,V80@V+39A=BG(-BHV8<@V*?8L]BJV8'8I]BOV8<@
MV*?8LB#9A=BLV8C8LMF'V*?8C"#9OMN,VJG8L=BHV8;8K]N,(-JIV8;8KRX`
MV*K9AMF'V*<@V+/9A=BJ(-F^V*?;C-N,V88`V+39A=BGV+'9AR!)1"#8JMF%
MV*?8LR#9A=BTV*[8M2#9AMBTV*_9AR#8I]BSV*K8C"#8I]N,V88@V+39A=BG
MV+'9AR#8K]BQ(-BOV*?8K]JOV*?9AB#;C-BGV8'8JB#9AMBTV*\`V*K9A=BG
MV+,@("5S(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8J-F'(-JIV*K8I]BHVH;9
MAR#8HMBOV+'8LR#8M-F%V*<@V*?8MMBGV8'9AR#8M-BO`-N,VJD@V*C9A-F(
MVJD@V*?9A=BVV*?;C"!01U`@V*C8L=BGVXP@V*C8I]BRV*C;C-F&VXP@VXS:
MJ2#9OMN,V+K8I]F%(-BGV878MMBGV*$@V+38K]F'(-F%V8C8L=BO(-F&VXS8
MI]BR(-BGV+/8J@!)1"#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"#9A=BTV*[8
MM2#9AMBTV*_9AR#8I]BSV*H@V8@@VXS8IR#8K]BQ(-BOV*?8K]JOV*?9AB#9
MA=F(V*S9B-BO(-F&VXS8L]BJ`-F!V8?8L=BSV*H@V*K9B-BRVXS8N=N,(-F%
MV+38KMBU(-F&V+38K]F'(-BGV+/8J@#9A=BTV*[8M=F'XH",XH",V8?8I]N,
M(-BQV878LMBHV8;8K]N,(-F&VXS8I]BRV879AMBO(-N,VJD@V*?8L=BJV+78
MI]F$(-BGV879AB#9B-BH(-F%VXSB@(S8J-BGV+39AMBO`-F^V+'9B-F&V*_9
MAR`E<R#8J-BGVXS8KR#8K]BGV+'8I]N,(-BJV8;8N-N,V84@)7,@V*C8I]BT
MV*\`V;[8L=F(V8;8K]F'("5S(-BHV*?;C-BO(-BMV*?9B-N,(-BJV8;8N-N,
MV878I]BJ("5S(-BHV*?8M-BO`-F^V+'9B-F&V*_9AR#8J-BQ(-BQV8C;C"#8
MKMF(V*_8M"#9AMF%VXSB@(S8JMF(V*?9AMBO(-BQV8C9AMF(V+38JB#8M-F(
MV*\`V;[8L=F(V8;8K]F'(-BMV*?9B-N,(-BOV*?8K]F'XH",V*?B@(S;C-N,
M(-F&VXS8L]BJ(`#9A=BO(-BJV878I]F%(-BUV8'8K=F'(-BHV*<@244@V878
MM-JIV80@V*_8I]BQV*\@V8@@V*?;C-F&(-BGV+(@V878M-JIV838I]BJ(-F%
MV+'9B-BQVJ_8L2#9A=N,XH",V*C8I]BTV*\N(-BGVJ_8L2#9A]F&V8C8LB#9
MA=N,XH",V*[9B-BGV8?;C-BO(-BMV*?9A-BJ(-F(VXS8L=BGVXS8M-JOV+$@
MV*K9A=BGV84@V+79@=BMV8<@V+'8IR#8I]F%V*K8K=BGV88@VJG9AMN,V*_8
MC"#9A-BWV8'8I]F+(-JIV83;C-BO(-BJV*/;C-N,V*\@V+'8IR#9@=BTV*?8
ML2#8K]F'VXS8KR``V8?9B-N,V9'8JB`B)7,B(-BMV+#9@2#8M-BOV8<@V*?8
ML]BJ`-BJV8;9A]BG(-BSV878JB#:AMF^`-F^VXS8NMBGV84@V8'8L=BSV*K8
MI]BOV8<@V+38K]F'(-BQV8C;C"`E<R#8J-F'("5S(-BHV*<@V879B-BVV8C8
MN2`B)7,B(-F&V878I]N,V+0@V*_8I]BOV8<@V+38K]F'(-BGV+/8JBX*V*K8
MMMF%VXS9AMN,(-BHV+'8I]N,(-BNV8C8I]F&V*_9AR#8M-BOV88@V8@@VXS8
MIR#8K]BQVJD@V*+9AB#9B-BLV8C8KR#9AMBOV*?8L=BO`-F&V*?9A=N,(-JI
MV8<@V*C9AR#9A]F&VJ_8I]F%(-F^VXS9B-F&V*_8K]F'VXP@V*C9AR#8M=F!
MV*W9AR#8I]N,V*S8I]BO(-F&V*?9A=F'(-BGV+/8JMF!V*?8K]F'(-F%VXSB
M@(S8M-F(V*\`V*K8N=BOV*?8KR#9@=N,V838K^*`C-F'V*<@V*C8I]N,V*\@
MVXS:J2#8N=BOV*\@V*C8I]BTV*\`V*?9B-F$V8C;C-BJ("(E<R(@V8;9A=N,
MXH",V*K9B-BGV8;8KR#8K=F!V+@@VJ_8L=BOV*\@V++;C-BQV*<@V879@MBO
MV*?8L2#8K]BGV*_9AR#8HMF&(-BGV+(@V*W8KR#9A=BLV*?8LB#8J-N,V+38
MJMBQ(-BGV+/8J@#8J-BQV8;8I]F%V8?B@(S8I^*`C-N,VXP@VJG9AR#8J-BQ
MV*?;C"#9A=BTV*?9A]BOV8<@V*?;C-F&(-F&V8C8N2#8K]BGV*_9AR`H)7,I
M(-F"V*C9A-BGV8L@V879B-BQV*\@V*?8L]BJV8'8I]BOV8<@V8+8L=BGV+$@
MV87;C.*`C-JOV+'9@=BJV(P@V*_8L2#8L]BGV878I]F&V8<@V879B-BLV8C8
MKR#9AMN,V+/8J@#8JMF&V8?8IR#8L]F%V*H@V+'8I]BSV*H@V8@@VH;9O@#8
MJMF&V8?8IR#8L]F%V*H@V+'8I]BSV*H`V*S8K]BG(-JIV8;9AMBOV8<@V*C8
MI]N,V*\@VXS:J2#9AMF(VXS8L]F'(-BHV*?8M-BO`-JIV*?8L=BSV*?8LB`B
M)7,B(-BMV+#9@2#8M-BOV8<@V*?8L]BJ`-JIV*?8L=BSV*?8LB`B)7,B(-BM
MV8'8N"#8M-BOV8<@V*?8L]BJ`-BOV+'8KMF(V*?8L]BJ(-BGV8'8JMBJV*?8
MK2#8K=BSV*?8J"#8J-BQV*?;C"`E<R#8K=BPV8$@V+38K]F'(-BGV+/8J@#8
ML=BOVXS9@2#9A=BTV*[8M2#8M-BOV8<@V8C8K-F(V*\@V8;8K]BGV+'8KP#9
MOMBQV8C9AMBOV8<@V879B-F"V*K;C"`@(B5S(MF%V8C8K-F(V*\@V8;;C-BS
MV*H`V*K9AMF'V*<@V+/9A=BJ(-BHV*?9A-BG(-F((-F^V*?;C-N,V88`V*K9
MAMF'V*<@V+/9A=BJ(-BHV*?9A-BG`-BOV*?8K]F'V90@V*?8L=BSV*?9A"#8
MM-BOV8<@V*?8LB#:K]BGV84@V8+8J-F$VXP@V*?8LB#8K]BSV*H@V+'9@=BJ
MV8<@V*?8L]BJ`-F^V+'9B-F&V*_9AR#8I]BQV+/8I]F$(-BTV*_9AR#9AMF%
MVXSB@(S8JMF(V*?9AMBO(-BMV8'8N"#8M-F(V*\`V*C9A-F(VJD@=V5A=&AE
M<BYC;VT@V8+8I]BHV80@V*_8L]BJV+'8LR#9AMN,V+/8J@#:K]BRVXS9AMF'
MXH",V*?B@(SB@(S;C-N,(-BOV+$@V*_8L]BJV+'8LR#9AMN,V+/8J@#8J-BN
MV+3;C"#:J=F'(-BHV*K9B-BGV8;8KR#8J-BQV*[8MR#9AMF%V*?;C-BT(-BO
MV*?8K]F'(-BTV8C8KR#9A=F(V*S9B-BO(-F&VXS8L]BJ`-F&V8C;C-BSV8?B
M@(S9A]BGVXP@V++;C-BGV*_;C"#8K]BQ(-BGVXS9AB#9@=N,V838KR#9@MBQ
MV*?8L2#8K]BGV+'8KRX@V+39A=BG("5S(-F&V8C;C-BSV8<@V8C8I]BQV*\@
MVJG8L=BOV8?B@(S8I^*`C-N,V*\@V*_8L2#8K=BGV83;C"#:J=F'(-BTV878
MIR#8J-BGVXS8KR#:J=F%V*K8L2#8I]BR("5S(-F&V8C;C-BSV8<@V8C8I]BQ
MV*\@VJG9AMN,V*\`V878M-JIV83;C"#8K]BQ(-BGV+'8L]BGV80@V;[8L=F(
MV8;8K]F'(-BQV*X@V*_8I]BOV8<@V*?8L]BJ.B`E<R#8I]BQV+/8I]F$(-F&
MV+38KP#9A=BTVJG9A-N,(-BOV+$@V*?8L=BSV*?9A"#9OMBQV8C9AMBOV8<@
MV+'8KB#8K]BGV*_9AR#8I]BSV*HZ(-BGV8;8K]BGV++9AR`E<R#8J-N,V+38
MJMBQ(-BGV+(@V*W8KR#9A=BLV*?8LB#8J-F(V*_9AR#8I]BSV*H@*"`E9"#8
MJ-BGVXS8JBDN`-F%V+3:J=F$VXP@V*_8L2#8I]BQV+/8I]F$(-F^V+'9B-F&
MV*_9AR#9B-BLV8C8KR#8K]BGV+38JMF'(-BGV+/8JCH@("5S(-BHV8<@V+79
MB-BQV*H@V*K:J=F'XH",V*?B@(S;C-N,(-BGV+'8L]BGV80@V+38K]F'(-BG
MV+/8JB``V*[8M]BGVXS;C"#8K]BQ(-F&V878I]N,V+0@V*?;C-F&(-BHV*[8
MM"#9OMN,V+K8I]F%(-BQV*X@V*_8I]BOV8<@V*?8L]BJ`-BNV+?8I]N,VXP@
MV*_8L2#8K]BQV8C9AN*`C-BHV+'8KR#:J=BQV*_9AB#8K]BGV*_9AR#8JMF%
MV*?8LR#8L=BN(-BOV*?8K]F'(-BGV+/8J@#8KMBWV*?;C-N,(-BOV+$@V*_8
ML=F(V8;B@(S8J-BQV*\@VJG8L=BOV88@V*_8I]BOV8?9E"#8JMF"V8C;C-F%
M(-BQV*X@V*_8I]BOV8<@V*?8L]BJ`-BNV+?8I]N,VXP@V*_8L2#9OMN,VJG8
ML=BHV8;8K]N,(-F!V+'9A2#8L=BN(-BOV*?8K]F'(-BGV+/8JBX@V+38I]N,
MV*\@V8';C-F$V*\@V879B-BQV*\@V8;;C-BGV++;C"#8L=BG(-BLV*<@V*?9
MAMBOV*?8KMBJV8?B@(S8I^*`C-N,V*\`V*[8M]BGVXS;C"#8K]BQ(-BGV*S8
ML=BG(-JIV+'8K]F&(-BYV879A-N,V*?8JB#9A=BTV*[8M2#8M-BOV8?9E"#:
MJ=BJV*?8J-J&V8<@V*+8K]BQV+,@V+'8KB#8K]BGV*_9AR#8I]BSV*HN(-F$
MV+?9@=BGV8L@V*_9B-BHV*?8L=F'(-BSV+G;C"#:J=F&VXS8KP#8KMBWV*?;
MC-N,(-BOV+$@V*C8L=F(V++8L=BSV*?9AMN,(-BLV++8IMN,V*?8JB#8JMF%
MV*?8LR#8L=BN(-BOV*?8K]F'(-BGV+/8JBX@V838M]F!V*?9BR#8K]F(V*C8
MI]BQV8<@V+/8N=N,(-JIV8;;C-BO`-BNV+?8I]N,VXP@V*_8L2#8J-BQV8C8
MLMBQV+/8I]F&VXP@V8'9A]BQV+/8JB#8JMF(V++;C-BYVXP@V+'8KB#8K]BG
MV*_9AR#8I]BSV*HN(-F$V+?9@=BGV8L@V*_9B-BHV*?8L=F'(-BSV+G;C"#:
MJ=F&VXS8KP`@VJG8I]BQV+/8I]BR($E-05#9OMF(V+39A^*`C-F'V*?;C"#9
MA=BTV*K8L=JI(-BQV*<@V;[8M-BJVXS8J-BGV8;;C"#9AMF%VXSB@(S:J=F&
MV*\`(-BHV8<@V8;8N-BQ(-F&V87;C.*`C-BQV+/8KR#:J=F'(-BBV+'8M-N,
MV8@@<F%R(-F%V+G8JMBHV+';C"#8J-BGV+38KP`@V*C9AR#9AMBXV+$@V8;9
MA=N,XH",V+'8L]BO(-JIV8<@V;[8L=F(V8;8K]F'('II<"#9A=BYV*K8J-BQ
MVXP@V*C8I]BTV*\`V*C9AR#9AMBXV+$@V8;9A=N,XH",V+'8L]BO(-JIV8<@
MV+39A=BGV+'9AR#:J=BGV+'8JB#9A=BYV*K8J-BQVXP@V*C8I]BTV*\`V*?;
MC-F&(-F!VXS9A-BO(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8J@#8I]N,V88@
MV8';C-F$V*\@V879A=JIV88@V*?8L]BJ(-BTV*?9A=F$(-BGV+G8K]BGV*\@
MV+78K=N,V*T@V*C8I]BTV*\`V*?;C-F&(-F!VXS9A-BO(-F%V87:J=F&(-BG
MV+/8JB#8M-BGV879A"#8I]BYV*_8I]BO(-F((-F(VXS8L=JOV8C9A"#8J-BG
MV+38KP#8I]N,V88@V8';C-F$V*\@V879A=JIV88@V*?8L]BJ(-BTV*?9A=F$
M(-F%V8+8I]BOVXS8L2#9A]BTV*H@V8?8M-BJVXP@V*C8I]BTV*\`V*?;C-F&
M(-F!VXS9A-BO(-BHV*?;C-BO(-BMV*?9B-N,(-JIV*?9A=BG(-F((-N,V*<@
MV8'9A]BQV+/8JMN,(-BGV+(@V*?8N=BOV*?8KR#8M=BMVXS8K2#8K-BOV*<@
MV+38K]F'(-BHV*<@V8;9B-N,V+/9AR#8KMBGV83;C"#8J-BGV+38KP#8I]N,
MV88@V8';C-F$V*\@V*C8I]N,V*\@VXS:J2#8N=BOV*\@V878N=BJV*C8L2#8
MJ-BGV+38KP#8I]N,V88@)7,@V87;C.*`C-BHV*?8M-BO`-BGVXS9AB#9OMN,
MV+K8I]F%(-BHV*<@V878K-F%V8C8N=F'(-JIV*?8L=BGVJG8JMBQ("5S(-F&
MV8C8M-BJV8<@V+38K]F'(-BGV+/8JB#:J=F'(-BHV*<@V878K-F%V8C8N=F'
M(-JIV*?8L=BGVJG8JMBQ(-BTV878IR#9A=BJV8'8I]F(V*H@V*?8L]BJ`-BG
MVXS9AB#8N=BOV*\@V*W8K]BGV8+9A"#8J-BGVXS8KR#;C-JI(-BHV*?8M-BO
M`-BGVXS9AB#:J=BGV+'8L]BGV+(@V;[8L=F(V8;8K]F'XH",V8?8I]N,('II
M<"#9B"!G>FEP(-BQV*<@V*C8I]BR(-F&V87;C.*`C-JIV8;8KP#8I]N,V88@
MV+/8I]F%V*?9AMF'(-BOV+$@V*W8I]F$(-BMV*?8MMBQ(-BZVXS8L2#9@=BY
MV*?9A"#8I]BSV*H`V*?;C-F&(-F%V8+8K]BGV+$@V*C8I]N,V*\@V+G8K]BO
M(-BHV*?8M-BO`-BGVXS9AB#9OMF&V*S8L=F'(-BHV*?;C-BO(-BGV+(@V;[9
MAMBLV+'9A]F4(-JOV++;C-F&V8?B@(SB@(S9A]BG(-F!V+'8I]BNV8C8I]F&
MVXP@V+39B-BO`-BQV+G8KP#8J-F$VXS8M]F'V*<`V++9A=BGV88`V+'8K]N,
MV*?8J-N,(-BRV878I]F&`-F"V*?9A-BH(-BRV878I]F&`"#8I]F&V*K8KMBG
MV*@@V++9A=BGV88@`-BYV8;9B-BGV88`V+G9AMF(V*?9AB`HV+'8I]F'V8;9
MA=BGVXP@V*+9AMN,*3H`V*C9AP#8J-BQV*?;C"#8I]F&V*K8KMBGV*@@VH;9
MAMBO(-F!VXS9A-BOV(P@V*_:J=F%V8<@0W1R;"#8L=F(VXP@*%!#*2#;C-BG
M($-O;6UA;F0@V+'9B-N,("A-86,I(-BQV*<@V*_8L2#9A=BOV*H@VJG9A-N,
MVJD@VJG8L=BOV88@V8;:K]F'V*_8I]BQVXS8KP#8I]F%V+'9B-BR`-F!V+'8
MK]BG`-BHV*?9A-BG`-J&V*?8L=J&V8C8J"#8J-BGV838IR`HV*C8I]F$V*<I
M`-BJV+'8K-F%V8?B@(S9A]BG`-BOV+'8L]BJ(-F((-N,V*<@V8;8I]BOV+'8
ML]BJ`-BSV8<@V+39AMBHV8<`5'5R:VES:"`H25-/+3@X-3DM.2D`V*?9AMBJ
MV*[8I]BH(-BNV8C8KR#8L=BG(-BJV*?;C-F^(-JIV8;;C-BO.@#8M-BGV*[8
MM2!5+E8N(#H@`%523`!54DPZ`-BGV87:J=BGV88@V*_8L]BJV+'8L]N,(-BH
MV8<@V+38I]BNV8<@5D93(-F&VXS8L]BJ`-BGV87:J=BGV88@V*?8MMBGV8'9
MAR#:J=BQV*_9AB#8I]BWV838I]BYV*?8JB#8I]BVV*?9@=N,(-JIV*?8L=BH
MV+$@V*C9AR#9A]F&VJ_8I]F%(-BKV*C8JB#9AMBGV84@V8;;C-BSV*H`V8;9
MA=N,XH",V*K9B-BGV88@V878K-F(V++9A]BG(-BQV*<@V*C8L=BGVXP@V;[8
ML=F(V8;8K]F'("(E<R(@V*K8NMN,VXS8L2#8K]BGV*\`V8;9A=N,XH",V*K9
MB-BGV88@V878K-F(V++9A]BG(-BQV*<@V*C8L=BGVXP@V;[8L=F(V8;8K]F'
M("5S+R5S(%9&4R`@V*K8NMN,VXS8L2#8K]BGV*\`V8;9A=N,XH",V*K9B-BG
MV88@V*_8L2`E<R#8JMBZVXS;C-BQ(-BOV*?8KP#9AMF%VXSB@(S8JMF(V*?9
MAB#8J-F'(-JIV*?8L=BSV*?8LB!344S9A=BJV+79A"#8M-BO`-F&V87;C.*`
MC-BJV8C8I]F&(-BHV*<@4U-,(-F%V*K8M=F$(-BTV*\`V8;9A=N,XH",V*K9
MB-BGV88@V*?8LB#9OMBQV8C9AMBOV8<@5D93(-BQV8C9AMF(V+38JB#8JMF'
MVXS9AR#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#8M-BGV*[9AR!61E,@
M(B5S(B#8L=BG(-BGVXS8K-BGV*\@V8;9A=F(V*\`V8;9A=N,XH",V*K9B-BG
MV88@V+38I]BNV8<@5D93(-BQV*<@V*?;C-BLV*?8KR#9AMF%V8C8KP#9AMF%
MVXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@5D93(-BQV*<@V*?;C-BLV*?8
MKR#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@V*[8
MI]F$VXP@5D93("#8I]N,V*S8I]BO(-F&V879B-BO`-F&V87;C.*`C-BJV8C8
MI]F&(-BOV*?8K]F'(-BQV*<@V*C8I]BR(-JIV+'8KR``V*W8L-F!("(E<R(@
MV879A=JIV88@V8;;C-BSV*K8C"#8M-BGV*[9AR#8KMBGV83;C"#9AMN,V+/8
MJ@#9AMF%VXSB@(S8JMF(V*?9AB`B)7,B(-BQV*<@V*W8L-F!(-JIV+'8KSH@
M)7,N`-BMV+#9@2`E<R#9A=F%VJG9AB#9AMN,V+/8JMB,(-BTV*?8KMF'(-BN
MV*?9A-N,(-F&VXS8L]BJ`-F&V87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'(%9&
M4R#8L=BG(-BHV8<@V+79B-BQV*H@V*K9B"#8K]BQ(-BJV8@@V*W8L-F!(-F&
MV879B-BO`-F&V87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'(%9&4R#8L=BG(-BM
MV+#9@2#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#8M-BGV*[9AR!61E,@
MV+'8IR#8K=BPV8$@V8;9A=F(V*\Z("5S+@#9AMF%VXSB@(S8JMF(V*?9AB#9
MOMBQV8C9AMBOV8<@5D93("(E<R(@V+'8IR#8K=BPV8$@V8;9A=F(V*\`V8;9
MA=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R#8L=BG(-BMV+#9@2#9
MAMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB!61E,@V+'8IR#8J-F'(-BUV8C8
ML=BJ(-BJV8@@V*_8L2#8JMF((-BMV+#9@2#9AMF%V8C8KSH@)7,N`-F&V87;
MC.*`C-BJV8C8I]F&(-BTV*?8KMF'V90@V8'8N=F$VXP@V+'8IR#8JMBTV*[;
MC-BU(-BOV*?8KP#9AMF%VXSB@(S8JMF(V*?9AB#8K-BRV*;;C-BGV*H@VJ_9
MB-BGV8?;C"#8L=BG(-BGV+/8JMBNV+'8I]BL(-F&V879B-BO`-F&V87;C.*`
MC-BJV8C8I]F&(-BJV+G8L=N,V8$@)7,@(-BQV*<@V*C8I]BQ(-F&V879B-BO
M`-F&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@V+'8IR#8I]F&
MV*K9@MBGV80@V*_8I]BO`-F&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9
MAR!61E,@(B5S(B#8L=BG(-BHV*?8LB#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(
MV*?9AB#9OMBQV8C9AMBOV8<@5D93(-BQV*<@V*C8L=BGVXP@V8;9B-BTV*K9
MAB#8J-BGV+(@VJG8L=BO`-F&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9
MAR!61E,@V+'8IR#8J-BGV+(@V8;9A=F(V*\`V8;9A=N,XH",V*K9B-BGV88@
MV*+8L=BTVXS9B"#9@=BTV+'8K]F'(-BQV*<@V*C8I]BR(-JIV+'8KP#9AMF%
MVXSB@(S8JMF(V*?9AB#8M-BGV*[9AR!V9G-R;V]T(-BQV*<@V*[9B-BGV8;8
MKP#9AMF%VXSB@(S8JMF(V*?9AB`E<R#8L=BG(-BHV8<@)7,@(-BJV+K;C-N,
MV+$@V8;8I]F%(-BOV*?8KSH@V;[9B-BTV8<@V879@MBUV*\@V*?8LB#9@MBH
MV80@V879B-BLV8C8KR#8I]BSV*H`V8;9A=N,XH",V*K9B-BGV88@V+38I]BN
MV8<@5D93(-BQV*<@V*K8NMN,VXS8L2#9AMBGV84@V*_8I]BO`-F&V87;C.*`
MC-BJV8C8I]F&(-BTV*?8KMF'(%9&4R#8L=BG(-BJV+K;C-N,V+$@V8;8I]F%
M(-BOV*?8KSH@)7,N`-F&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!6
M1E,@(B5S(B#8L=BG(-BJV+K;C-N,V+$@V8;8I]F%(-BOV*?8KP#9AMF%VXSB
M@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@5D93("5S+R5S(-BQV*<@V*K8NMN,
MVXS8L2#9AMBGV84@V*_8I]BO`-F&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&
MV*_9AR!61E,@V+'8IR#8JMBZVXS;C-BQ(-F&V*?9A2#8K]BGV*\`V8;9A=N,
MXH",V*K9B-BGV88@)VUK:7-O9G,G(-BQV*<@V*?8K-BQV*<@V8;9A=F(V*\`
MV8;9A=N,XH",V*K9B-BGV88@V*?;C-F&(-BSV8;8KR!7;W)D(-BQV*<@V*K8
ML=BLV879AR#9AMF%V8C8KP`@V8;9A=N,XH",V*K9B-BGV88@V*_8L2#9OMBQ
MV8C9AMBOV8<@(B5S(B!61E,@(-F&V8C8M-BJ`"#9AMF%VXSB@(S8JMF(V*?9
MAB#8K]BQ(-F^V+'9B-F&V*_9AR!61E,@V8;9B-BTV*HN`-F&V87;C.*`C-BJ
MV8C8I]F&(-BOV+$@V;[8L=F(V8;8K]F'V90@V*_8I]BOV8<@5D93(-F&V8C8
MM-BJ`-BRVXS8L=BNV+?B@(S8K]BGV+$`V8C8I]JOV+'8K]BGV8;8K]F&(-BJ
MV+K;C-N,V+'8I]BJ`-F(V*?:K]BQV*_8I]F&V*_9AB#8HMBNV+';C-F&(-BY
MV879A"#8M-F%V*<`V;[8I]BSV*X@V+K;C-BQ(-F%V8;8JMBXV+'9AR#8I]BR
M(-JIV*?8L=BSV*?8LB#8J-BQ(-BQV8C;C"#8I]BJV+78I]F$.@#9OMBGV+/8
MKB#8NMN,V+$@V879AMBJV+C8L=F'(-BGV+(@VJG8I]BQV+/8I]BR(-BHV8<Z
M`-BZVXS8L2#8K=F(V++9AP!5;FEC;V1E("A55$8M."D`V8C8I]BMV*_9A]BG
M`-BOV*?8K]F'(-F&V*?8M-F&V*?8KMBJV8<`V8;8I]F%(-JIV*?8L=BHV+$@
MV8@@VXS8IR#8I]BSV84@V+'9A=BR(-F&V*?8M-F&V*?8KMBJV8<`V8+8M]BY
M(-F^VXS9B-F&V*\@V+G9AMBUV+$@V8'8N=F$VXP`V*C;C"#9AMBGV84`V*_8
ML]BJ(.*`C-F&V8C;C-BSV8?8I]N,(-BHV*_9B-F&(-BGV878JMN,V*?8LB#8
MJ-F'(-BOV83;C-F$(-BGV879AMN,V*K;C"#9AMF%VXSB@(S8JMF(V*?9AMF&
MV*\@V*?8LB#8M]BQVXS9@B#8J-BQV8;8I]F%V8<@V8;9B-N,V+/;C"#8J-BQ
MVXS8K]F'+]BQV8C9AMF(V+38JB#:K]BQV8'8JMF'+]J&V+/8J-N,V*_9AR#8
MM-F(V8;8KRX@VJG9A-N,V*\@V*K8H]N,VXS8KR#8L=BG(-F!V+38I]BQ(-BO
MV8?;C-BO(-BJV*<@V878JMF&(-F!V8;;C.*`C-BGXH",VXS;C"#8L=BG(-BO
MV+$@;6]Z:6QL82YO<F<@V*C8IR#8N=F&V8C8I]F&(-J&VJ_9B-F&VJ_;C"#8
MK]BSV*K8L=BSVXP@VXS:J2#8K]BSV*H@XH",V8;9B-N,V+,@V*C9AR#8JMBN
MV*K9A]F4(-BQV+/9A2#8L=BG(-F%V+38I]F'V*_9AR#:J=F&VXS8KP#8L=F&
MVJ\@V*K9AMBXVXS9A2#9AMBTV*_9AP#8J-BSV+<@V*C8K]F(V88@V;[8M-BJ
MVXS8J-BGV8;;C`#8J-BQV8C8LMBQV+/8I]F&VXP`V*C8L=F(V++8L=BSV*?9
MAMN,("5S`-BHV+'9B-BRV+'8L]BGV8;;C"#:J=BGV+'8J-BQ`"(E<R(@V*C8
ML=F(V++8L=BSV*?9AMN,(-BTV*\`V*_8L]BJXH",(-F&V8C;C-BS(-BHV8?;
MC-F&V8?B@(S8L]BGV++;C"#8K=BPV8$@V+38KP#8I]BQV+/8I]F$(-JIV+'8
MK]F&`-BJV878I]F%(-F^V+'9B-F&V*_9A^*`C.*`C-F'V*?;C"#8JMF&V+C;
MC-F%(-BHV+'9AMBGV879A^*`C-F'V*?;C"#:J=BGV+'8J-BQV*_;C"#8J-F'
M(-JIV*?8L=BSV*?8LB#8I]BQV+/8I]F$(-BTV*\`V*W8L=F(V8$@V*C8LMBQ
MVJ\@V838I]BJVXS9A@#8I]BYV*_8I]BO(-N,V8C9AMBGV8;;C"#8J-BRV+':
MKP`@V*?8L]BJV8'8I]BOV8<@V8'8N=F$VXPZ("5S`-BGV+/8JMF!V*?8K]F'
M(-BGV+(@4U-,`-BGVJ_8L2#9AMBGV84OV*?8L]F%(-BQV878LB#8J-BQV*?;
MC"#:J=BGV+'8L]BGV+(@24U34"#9A=BJV8'8I]F(V*H@V*?8L]BJV(P@V*?8
ML]BJV8'8I]BOV8<@VJG9AMN,V*\`VJG8I]BQV*C8L2`E<R`@V*C8L=BGVXP@
M)7,@V*?8K=BQV*?8LB#9A]F(VXS9D=BJ(-F&V+38K]F'(-BGV+/8J@#8L]BQ
MV;[8L=BSV*K;C"#:J=BGV+'8J-BQ`-JOV++;C-F&V8?B@(S9A]BGVXP@VJG8
MI]BQV*C8L0#8J]BHV*H@V8;8I]F%(-JIV*?8L=BHV+$`V*O8J-BJ(-JIV*?8
ML=BHV+$@V*C8L=BGVXP@V*?;C-F&(-F^V*?;C-JOV*?9AR#8NMN,V+$@V8'8
MN=BGV80@V+38K]F'(-BGV+/8J@#8K=BSV*?8J"#:J=BGV+'8J-BQ(-F^VXS8
MK]BG(-F&V+38KP#9AMBGV84@VJG8I]BQV*C8L0#9AMBGV84@VJG8I]BQV*C8
ML3H`V8;8I]F%(-JIV*?8L=BHV+$Z(`#:J=BGV+'8J-BQV*?9AB#8L]BGV878
MI]F&V8<Z`-BTV*?8KMF'(%9&4R#9B-BLV8C8KR#9AMBOV*?8L=BO`-BJV+G8
MM]N,V838I]BJ`-F%V8C9@MBYVXS8JMF'V*?;C"#9A=BYV*K8J-BQ(-N,V*?9
M@=BJV8<@V+38K]F'(-BYV*C8I]BQV*K9AMBO(-BGV+(Z`-BGV+G8JMBHV*?8
ML0#9A=F"V*_8I]BQ(-BHV8<@V*_9@MN,V8+9AR#8I]BR(-BMV*?9A-BG`-F%
MV8+8K]BGV+$@V*?8LB#8J-N,V+3;C-F&V8<@V+?9B-F$(-F%V*S8I]BR("5S
M(-BHVXS8M-BJV+$@V*?8L]BJ`-F%V8+8I]BOVXS8L0#9A=F"V*?8K]N,V+$@
MV*C8L=BGVXP@V*?9AMBJV*[8I]BH(-BGV+(`V878JMBZVXS;C-BQ`-F&V+/8
MKMF'`-JIV8;8JMBQV80@V8;8L]BNV8<`V*K8L=BGV+(@V+G9A=F(V*_;C`#9
M@=BGV+79A-F'XH",VJ_8L-BGV+';C"#8N=F%V8C8K]N,`-BYV879B-BOVXPZ
M`-BNVXS9A-N,(-BHV*?9A-BG`%9I971N86UE<V4@*%9)4T-)22D`V8;9A=BG
MVXP@)7,`V8;9A=BGVXP@VXS:J2#8M=F!V*W9AR#9B-BH(-BNV*?8L=BLVXP`
M(-F&V878IR#8J-F'(-BYV8;9B-BGV88@)7,`V8+8I]BHV83;C-BJ(-F%V+38
MI]F'V*_9AP#9@MBGV*C9A-N,V*H@V878M-BGV8?8K]F'.B``V*?8KMBWV*?8
ML2$A(2#8K]BSV*H@XH",V8;9B-N,V+,@V+'8IR#8J-BWV8C8L2#8K]BSV*K;
MC"#8I]BR("5S(-BMV+#9@2#:J=F&VXS8KP#8I]BNV+?8I]BQ.B``VH;9A]BG
MV+'8M-F&V*C9AP#9OMN,V+3B@(S8J-N,V8;;C"#9A]F(V*<`V*_8I]BOV8<@
MV*+8J"#9B"#9A]F(V*?;C-N,(-F!V+'8I]F'V84@V+38K]F'(-BHV8<@V8C8
ML]N,V839AP!W96%T:&5R+F-O;0#9B-BH`-F(V*CB@(S:K]BGV8<`V8?9@=BJ
MVJ_;C`#8KMF(V+0@V*+9A=BOVXS8KP#8J-F'("5S(-BNV8C8M"#8HMF%V*_;
MC-BO`"5SV(P@V*[9B-BT(-BBV878K]N,V*\`5V5S=&5R;B`H25-/+3@X-3DM
M,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`-J&V8<@V*C8L=F&V*?9A=F'V90@
MVJG8I]BQV*C8L=BOVXP@V+'8IR`E<R#8J-BGVXS8KR#8J-BYV*\@V*?8LB#9
MB-BQV8C8KR#9AMBTV*?9AB#8K]F'V*_8GP#9AMF(VXS8L]F'V93B@(P@V*W8
MI]BFV80@VH;;C-BSV*K8GP#9AMF(VXS8L]F'XH",VXP@V8;9@MF$(-F"V8C9
MA"#:AMN,V+/8JMB?`-JIV*_8I]F%(-F!V*?8L@#:J=BOV*?9A2#8J-BQV8;8
MI]F%V8?B@(S9A]BGVXP@V878JMBUV83B@(S:J=F&V8;8K]F'(.*`C-BHV+'8
MI]N,(-F(VXS8L=BGVXS8M-JOV+$@V878JMF&(-F!V+G8I]F$(-BHV*?8M-F&
MV*\`V+G8L=BV`"#9OMF'V8;8IR#8K]BQ(-F(V*?8K=BO($-34R``V;[9A]F&
MV*?;C"#:K]BRVXS9AMJOV*?9AB`E<R#8K]BQ(-BQV*?8L]BJ("C8K]BQ(-F(
MV+'9B-BO(-BHV+G8K]N,(-F%V8C8J]BQ(-F%VXSB@(S:K]BQV*_8KRDZ`-F^
MV8?9AMBGVXP@V*S8K]F(V80`V8C8I]BMV*\@V;[9A]F&V*<`V;[9A]F&V*<Z
M`%=I:VD`V*C8I]BO.@#8J-BGV*\@V++9B-BOV8?9AMJOV*?9A3H@`-BSV+'8
MN=BJ(-BHV*?8KR#8J-BQV*W8L]BH(-F!V8C8JB#8J-BQ(-BSV*?8N=BJ`-BH
MV*?8KSH`V*C8I]BO.B``V+G9@MF$`-JIV*?8L0#8HMBOV+'8LR#9A=BMV80@
MVJG8I]BQ`-BJV839@=F&(-F%V*W9A"#:J=BGV+$`XH",65D`65E960#8L]BG
MV838I]F&V8<`V*+8L=N,`-BHV839A]B,(-F%V8C8I]F!V8+9A0#8M-F%V*<@
MV*_8L2#9A=BO(-F%V*K9AB#9A]BSV*K;C-BO+B#8I]BR(-BOVJG9A=F'("!;
M/#Y=(-BHV+'8I]N,(-BHV+':K]BTV*K9AB#8J-F'(%=94TE764<@V*?8L]BJ
MV8'8I]BOV8<@VJG9AMN,V*\`V+39A=BG(-BJV+78K]N,V8(@V8?9B-N,V9'8
MJB#9AMBTV*_;C-BO`-BTV878IR#9AMF%VXSB@(S8JMF(V*?9AMN,V*\@V8;9
MB-N,V+/9AR`G7"<@V+'8IR#8K]BQ(-F&V*?9A2#:J=BGV879A"#8KMF(V*\@
MV*_8I]BTV*K9AR#8J-BGV+3;C-BO`-BTV878IR#8HMBOV+'8LR#9OMBSV*H@
MV*?9A-JIV*K8L=F(V8;;C-JI(-F%V+G8JMBHV+';C"#9B-BGV+'8KR#9AMJI
MV+'8K]F'XH",V*?;C-BO`-BTV878IR#9A]N,VH8@V8';C-F$V*_;C"#8L=BG
M(-BOV+$@V;[8L=F(V8;8K]F'(-BOV+'9B-F&XH",V*C8L=BO(-BTV*_9AR#8
MJ-F'(-F!VXS9A-BO(-F%V*K9@MBGV*C9A-N,(-BOV+$@)7,@V8;:K]BGV+38
MJB#9AMJIV+'8K]F'XH",V*?;C-BO`-BTV878IR#8KMBGV+'8K"#8M-BOVXS8
MKP#8M-F%V*<@V878K-BHV8C8L2#9A]BSV*K;C-BO(-N,VJD@V+39A=BGV+'9
MAR#8JMF$V8'9AB#9A=BYV*K8J-BQ(-F(V*?8L=BO(-JIV8;;C-BOV(P@V*?8
MLB#8N=F$V*?9A=BJ("<K)R#8J-BQV*?;C"#8M-F%V*?8L=F'XH",V8?8I]N,
M(-BHVXS9AB#8I]F$V879A-F$VXP@V*?8L]BJV8'8I]BOV8<@VJG9AMN,V*\`
MV+39A=BG(-F%V*S8J-F(V+$@V8?8L]BJVXS8KR#;C-JI(-F%V8+8K]BGV+$@
MV878N=BJV*C8L2#9B-BGV+'8KR#:J=F&VXS8KP#8M-F%V*<@V*C8I]N,V*\@
MVXS:J2#9OMBTV*K;C-BHV*?9AB#8K]BQV*[8JB#8K]BGV*_9AR#8J-BQV*?;
MC"#8I]BSV*K9@=BGV*_9AR#8I]BR(-BKV*C8JB#9AMBGV84@V;[;C-JIV+'8
MJ-F&V*_;C"#:J=F&VXS8KP#8M-F%V*<@V*C8I]N,V*\@VXS:J2#8L]BGV878
MI]F&V8<@V;[8M-BJVXS8J-BGV88@5D93(-BQV*<@V;[;C-JIV+'8J-F&V*_;
MC"#:J=F&VXS8KP#9@MBHV80@V*?8LB#8I]BQV+/8I]F$(-JOV++8I]BQV+38
MC"#8J-BGVXS8KR#9A=BTVJG9A"#8L=BG(-BTV+'8K2#8K]F'VXS8KP#8M-F%
MV*<@V*C8I]N,V*\@55),V*?;C"#:J=F'(-BGVXS9AB#9OMN,V8C9AMBO(-BH
MV8<@V*+9AB#8I]BTV*?8L=F'(-F%VXSB@(S:J=F&V*\@V+'8IR#9B-BGV+'8
MKR#:J=F&VXS8KP#8M-F%V*<@V*C8I]N,V*\@VXS:J2#:J=BGV+'8L]BGV++8
MC"#8J-BQV*?;C"#8K=BPV8$@VJG8L=BOV88@V*?9AMBJV*[8I]BH(-JIV8;;
MC-BO`-BTV878IR#8J-BGVXS8KR#;C-JI(-F&V*?9A2#:J=BGV+'8J-BQV(P@
MV*C8L=BGVXP@V*W8L-F!(-JIV+'8K]F&(-F%V+38KMBU(-JIV8;;C-BO`-BT
MV878IR#8J-BGVXS8KR#;C-JI(-F&V*?9A2#:J=BGV+'8J-BQV(P@V*C8L=BG
MVXP@V*W8L-F!(-BTV*_9AB#9A=BTV*[8M2#:J=F&VXS8KP#8M-F%V*<@V*C8
MI]N,V*\@VXS:J2#9AMBGV84@VJG8I]BQV*C8L=B,(-BHV+'8I]N,(-BGV+;8
MI]F!V8<@VJG8L=BOV88@V878M-BNV+4@VJG9AMN,V*\`V+39A=BG(-BHV*?;
MC-BO(-N,VJD@V+39AMBGV+/9AR#:J=BGV+'8J-BQV(P@V*C8L=BGVXP@V*C8
ML=F(V++8L=BSV*?9AMN,(-BGV8;8JMBNV*?8J"#:J=F&VXS8KP#8M-F%V*<@
MV*C8I]N,V*\@V878M-BNV+4@VJG9AMN,V*\@VJG9AR#:AMF'(-BYV879A-N,
M(-BHV*?;C-BO(-BGV8;8K-BGV84@VJ_;C-BQV*\`V+39A=BG(-BHV*?;C-BO
M(-F&V*?9A2#8K-BOVXS8KR#8K]BSV*K9AR#8L=BG(-BJV*?;C-F^(-JIV8;;
MC-BO`-F&V+38L]BJ("5S(-BTV878IR#9A=F&V8+8MMN,(-BTV*_9AR#8I]BS
MV*HN(-F$V+?9@=BGV8L@V*_9B-BHV*?8L=F'(-F(V*?8L=BO(-BTV8C;C-BO
M`-BBV*_8L=BS(-BGV83:J=BJV+'9B-F&VXS:J=N,(-BTV878IP#8HMBOV+'8
MLR#9@=BQV+/8JMF&V*_9ASH@V+39A=BG.@#8I]BWV838I]BYV*?8JB#8M-F%
MV*<`V*+8K]BQV+,@V*?;C-F&V*K8L=F&V*K;C"#8M-F%V*<@V8;8L]BHV*H@
MV*C9AR#8I]BHV*K8K]BGVXP@V8;8M-BSV*H@)7,@V+39A=BG(-BJV+K;C-N,
MV+$@VJG8L=BOV8<@V*?8L]BJ+MBHV+'8I]N,(-BQV+G8I]N,V*H@V878L]BG
MV*;9A"#8I]F%V8;;C-BJVXP@V*C8I]N,V*\@V*_9B-BHV*?8L=F'(-F(V*?8
ML=BO(-BTV8C;C-BO`-F&V*?9A2#8M-F%V*<`V+/8I]F%V*?9AMF'(-F^V+38
MJMN,V*C8I]F&(-BJV+78K]N,V8(@V8?9B-N,V9'8JB#8M-F%V*<@V8'9A]BQ
MV+/8JB#:J=BQV*_9AB#:J=BGV+'8J-BQV*?9AB#8L=BG(-F^V+38JMN,V*C8
MI]F&VXP@V8;9A=N,XH",VJG9AMBOV(P@VXS8IR#8M-BGVXS8KR#8J-F&V*<@
MV*C9AR#8K]F$VXS9A"#8K]N,VJ_8L=N,(-BGVXS9AB#:J=BGV+$@V*?9AMBL
MV*?9A2#9AMF%VXSB@(S8M-F(V*\`V+C8I]F'V+$@V878L=F(V+':K]BQ(-BT
MV878IR#9AMBSV*C8JB#8J-F'(-BGV*C8JMBOV*?;C"#9AMBTV+/8JB`E<R#8
MM-F%V*<@V*K8NMN,VXS8L2#:J=BQV*_9AR#8I]BSV*HNV*C8L=BGVXP@V+'8
MN=BGVXS8JB#9A=BSV*?8IMF$(-BGV879AMN,V*K;C"#8J-BGVXS8KR#8K]F(
MV*C8I]BQV8<@V8C8I]BQV*\@V+39B-N,V*\`V878L=F(V+':K]BQ(-BTV878
MIR#8I]N,V88@V878M-BNV+79AR#8L=BG(-F^V+38JMN,V*C8I]F&VXP@V8;9
MA=N,XH",VJG9AMBO+@#8LMF%V*?9AB#9@=BYV83;C"#9A=F&V+?9@MF'(-BL
MV+K8L=BGV8';C-BGVXS;C"#8M-F%V*<Z`-F'V8C;C-F1V*H@V;[;C-BT(-F!
MV+'8MB#8M-F%V*<Z`-F&V*?9A2#:J=BGV879A"#8M-F%V*<Z`-F(V+'9B-BO
M(-BTV878IR#9A=F&V8+8MMN,(-BTV*_9AR#8I]BSV*H`V*?8L]F%(-BQV878
MLB`@V*S8K]N,V*\@V+39A=BG(-BHV+'8I]N,("5S(-F'V+/8JCH@)7,`VJ_8
MLMN,V8;9A^*`C-F'V*?;C"#8M-F%V*<@V*C8L=BGVXP@V+?9B-F$(-BGVXS9
MAB#9AMBTV+/8JB#8J-BQV8C8LMBQV+/8I]F&VXP@V+38K]F'(-BGV+/8JB``
MVJ_8LMN,V8;9A^*`C-F'V*?;C"#8M-F%V*<@V*C8L=F(V++8L=BSV*?9AMN,
M(-BTV*_9AR#8I]BSV*H`V*?8L]F%(-BQV878LB`@V+39A=BG(-BHV*?8LMF&
MV+38I]F&VXP@V+38K]F'(-BGV+/8J@#8I]BSV84@V+'9A=BR(-BTV878IR#8
MJ-BGV++9AMBTV*?9AMN,(-BTV*_9AR#8I]BSV*K8C"#9OMBSV*H@V*?9A-JI
MV*K8L=F(V8;;C-JI(-BNV8C8KR#8L=BG(-J&VJD@VJG9AMN,V*\@V8@@V*C8
MIR#8I]BSV84@V+'9A=BR(-BLV*_;C-BO(-BNV8C8KR#9B-BGV+'8KR#8M-F(
MVXS8KP#8I]BSV84@V+'9A=BR("#8M-F%V*<@V879AMF"V+;;C"#8M-BOV8<@
MV*?8L]BJ`-JIV*?8L=BSV*?8LN*`C-F'V*?;C"#8L=BGV8?B@(S8K]F(V+$@
MV+39A=BG.@!;V;[9AMF'V*?9AB#:J=BQV*_9AB#9A=BJV88@V8;9@MF$(-F"
MV8C9A"#8M-BOV8==`%O:K]BRV*?8L=BT(-F%V+3:J=F$72``6]F&V878I]N,
MV+0@V878JMF&(-F&V8+9A"#9@MF(V80@V+38K]F'("T`V8;9A=BGVXS8M"#9
MA=BJV88@V8;9@MF$(-F"V8C9A"#8M-BOV8=;("T@)7,@V*[8MUT`6]BNV+<@
M)7,@V*?8LB`E<R!=(`#8L]BQV;[8L=BSV*K;C`!#3$D`V*_8L=BNV*H@V*_8
MI]BOV8<`V*W8L-F!(-BSV+?8L0#:K]BQV8C9AR8C>#(P,&,[V8?8IP#8L=BG
MV8?9AMF%V*<`V*[8M=F(V+7;C-BGV*H@V*K8M=F(VXS8L2XN+@#9B-BQV8C8
MKP#8KMBQV8C8K`#8JMBZVXS;C-BQ(-F^VXS9B-F&V*\N+BX`VJ_8LMN,V8;9
MA^*`C-F'V*<`V878K-F(V++9A]BG`-BMV+#9@2#9OMN,V8C9AMBO+BXN`-BQ
MV*?9AR8C>#(P,&,[V*?9AMBOV*?8LMN,`-BNV+79B-BUVXS8I]BJ(-BLV*_9
MB-F$+BXN`-JIV*?8L=BHV+'8I]F&`-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS
M(`#8JMF"V8C;C-F%`-BBV+'8I]F%`-BGVXS9AMBLV*<@V+'8IR#9@=BTV*?8
ML2#8K]F'VXS8KP#9OMBQV8C9AMBOV8<`V*?8LB`E<R`H)7,I(-BOV+$@)7,@
M)7,`V*C8I]BO`&@Z`-F!V8C8L=BGV8L`V*_8L=BNV+<`V*[8M]F(V+==`-F&
MV*?9A0#9OMN,V*?8K]F'(-BSV*?8LMN,(-F&V+38K]F'`-F'V8;9B-BR(-F^
MVXS8I]BOV8<@V+/8I]BRVXP@V8;8M-BOV8<@V*?8L]BJ`&YO=&5P860`V*_8
ML=BUV*\`V;[;C-JIV+/9A-F'V*<`V+?9A-F(V+D`V8;9A=BGVXS8M"#8JMF!
MV*?9B-BJV8?8IP#9OMN,XH",V*_8L=F^VXP`V8'9A]BQV+/8JB#9B-BXVXS9
M@=F'`-BGV+/9A2#8L=F%V+(@V+'8IR#8J-BQV*?;C"#8JMBCVXS;C-BO(-BO
MV8C8J-BGV+$@V8C8I]BQV*\@VJG9AMN,V*\`VXS:K]BGV8;9AR#8M-BOV8<`
MV*C;C"#9AMBGV84`V*?9AMBJV*[8I]BH(-JIV*?8L=BHV+$`=D-A<F0`=SH`
M=V5A=&AE<BYC;VT`````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C
M86QE+V9I7T9)+P``````````````````````````````````````````````
M```````````````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U,P`P,C`P-S$`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L;V-A;&4O9FE?1DDO:&5L<"YX;6P`````````````
M`````````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T,S,W`#$P-3$U-#,S-S4S
M`#`R,34U,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E
M+VQO8V%L92]F:5]&22]H96QP+GAM;"QV(#$N,RXQ,"XS(#(P,#8O,#(O,C`@
M,3$Z,C`Z,3$@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](G-U
M;6UA<GDB(&UD-3TB-CAC83,S9C=F,&,Y86%E-&,Q,#-E8C0W-#DR8V1C,34B
M('-T871E/2)U<'1O9&%T92(^"CQT:71L93Y0;W)T86%L:3PO=&ET;&4^"B`\
M<&%R83X*("!0;W)T86%L:7-S82!V;VET(&XF(WA%-#MH9"8C>$4T.R!P:6MA
M:7-E<W1I(&QY:'EE;B!Y:'1E96YV961O;B!T)B-X130[<FME)B-X130[:W-I
M"B`@;65R:VET<V5M:7-T)B-X130[(&%S:6]I<W1A+B!%<VEM97)K:6MS:2!V
M;VET(&XF(WA%-#MH9"8C>$4T.R!M;VYT86MO('5U='1A"B`@<R8C>$4T.VAK
M)B-X1C8[<&]S=&EV:65S=&DF(WA%-#L@<VEN=6QL92!O;B!T=6QL=70@24Y"
M3U@@:V%N<VEO;VXL('1U;&5V870*("!T87!A:'1U;6%T(&MA;&5N=&5R:7-S
M82P@=&5H="8C>$4T.W8F(WA%-#MT('1O+61O(&QI<W1A;&QA+"!O='-I:V]T
M"B`@=F%L:71S96UI<W1A<VD@=75T:7-P86QV96QU:7-T82!J;F4N($UO;F5T
M(&XF(WA%-#MI<W0F(WA%-#L@>6AT965N=F5D;VES=&$*("!S:7,F(WA%-#ML
M="8C>$4T.W8F(WA%-#MT(&QI;FMK96HF(WA%-#L@>6QE:7-I;7!I:6X@=&]I
M;6EN=&]I:&EN(&MU=&5N(&5S:6UE<FMI:W-I('9I97-T:6X*("!K:7)J;VET
M=7,L(&MA;&5N=&5R:6UE<FMI;FXF(WA%-#MN('1A:2!T96AT)B-X130[=B8C
M>$4T.VX@;&ES)B-X130[>7,@:FYE+@H@/"]P87)A/@H@/'!A<F$^"B`@4&]R
M=&%A;&EN('-I<R8C>$4T.VQT)B-X1C8[(&]N(&UU;VMA='1A=FES<V$@07-E
M='1E;'4@<&%I;FEK:V5E;B!K875T=&$N(%9O:70*("!E<VEM97)K:6MS:2!V
M86QI=&$@;6ET:R8C>$4T.R!A<VEA="!L:6ET970F(WA%-#LF(WA%-#MN('!O
M<G1A86QI:6X@:F$@;6ES<R8C>$4T.PH@(&HF(WA%-#MR:F5S='EK<V5S<R8C
M>$4T.R!N92!N)B-X130[>71E="8C>$4T.R8C>$4T.VXN"B`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B(&UD-3TB8CAC9C!A93$Y934W
M9&9A,&,R8CDV,F4U,38W.#)F-#<B('-T871E/2)U<'1O9&%T92(^"CQT:71L
M93Y/:&IE;&UI96X@;F%V:6=O:6YT:79A;&EK:V\\+W1I=&QE/@H@/'!A<F$^
M"B`@5W=W+7-I=G5N('9A<V5M86QL82!L86ED86QL82!O;B!N879I9V]I;G1I
M=F%L:6MK;R!E<FD@;VAJ96QM:6EN+@H@($YA<'-A=71T86UA;&QA(&EK;VYE
M:71A(&YA=FEG;VEN=&EV86QI:V]S<V$@=F]I="!H96QP;W-T:2!J80H@(&YO
M<&5A<W1I('9A:6AT86$@;VAJ96QM87-T82!T;VES965N+@H@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B(&UD
M-3TB9&0Y-61F,#=A,#,P,S$R,S)B865A.3$Y,C@X8C)D,#`B('-T871E/2)U
M<'1O9&%T92(^"B`@("`\=&ET;&4^07-E='5K<V5T.B!9;&PF(WA%-#MP:71O
M=&]I;65N<&ET965T.B!3=6]R:71A('EL;"8C>$4T.W!I=&]T;VEM970\+W1I
M=&QE/@H@("`@/'!A<F$^"B`@("!*;W,@:&%L=6%T('-U;W)I='1A82!Y;&PF
M(WA%-#MP:71O=&]I;65N<&ET96ET)B-X130[('-I<R8C>$4T.R8C>$4T.VYK
M:7)J875T=6UI<V5N"B`@("!Y:'1E>61E<W,F(WA%-#LL(&YI:6X@87-E=&$@
M="8C>$4T.VTF(WA%-#L@=&]I;6EN=&\@<"8C>$4T.R8C>$4T.VQL92!V86QI
M;G1A<G5U9'5S=&$N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!M9#4](F$R,3$V,F-D9F8S
M8C%D.&9A96%D8C<R.38R-#`P,S9E(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@
M/'1I=&QE/D%S971U:W-E=#H@66QL)B-X130[<&ET;W1O:6UE;G!I=&5E=#H@
M5F%R;6ES=&$@>6QL)B-X130[<&ET;W1O:6UE=#PO=&ET;&4^"B`@("`\<&%R
M83X*("`@($IO<R!H86QU870@=F%R;6ES=&%A(&MA:6MK:2!Y;&PF(WA%-#MP
M:71O=&]I;65N<&ET965T(&5N96YN:W5I;B!N90H@("`@<W5O<FET971A86XL
M(&YI:6X@87-E=&$@="8C>$4T.VTF(WA%-#L@=&]I;6EN=&\@<"8C>$4T.R8C
M>$4T.VQL90H@("`@=F%L:6YT87)U=61U<W1A+B!*;W,@=F%R;6ES='5S=&$@
M96D@;VQE('`F(WA%-#LF(WA%-#ML;"8C>$4T.RP@;FEI;B!K86EK:VD*("`@
M('EL;"8C>$4T.W!I=&]T;VEM96YP:71E970@<W5O<FET971A86X@875T;VUA
M871T:7-E<W1I(&IA(&YI:70F(WA%-#L@96D@=F]I"B`@("!P97)U82X*("`@
M(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9FE?1DDO3$-?3453
M4T%'15,O````````````````````````````````````````````````````
M`````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-3$U-#,S-S4S`#`R,38U-@`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO
M8V%L92]F:5]&22],0U]-15-304=%4R]H;W)D92YM;P``````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`T,3(T,#$`,3`U,34T,S,W-3,`,#(S,S$V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````-X2!)4`````B@<`
M`!P```!L/```$PH``+QX````````"*$```X````)H0``#P```!BA```-````
M**$```@````VH0``"P```#^A```,````2Z$```0```!8H0``&````%VA```;
M````=J$``"T```"2H0``'0```,"A```D````WJ$``"D````#H@``&0```"VB
M```F````1Z(```P```!NH@``)````'NB```/````H*(```L```"PH@``#@``
M`+RB```%````RZ(``"@```#1H@``"````/JB```*`````Z,``!4````.HP``
M$@```"2C```+````-Z,``(4```!#HP``#@```,FC```*````V*,```T```#C
MHP``#@```/&C```1`````*0```T````2I```#````""D```-````+:0```8`
M```[I```E````$*D```*````UZ0```\```#BI```&````/*D```,````"Z4`
M``X````8I0``#@```">E```(````-J4```D````_I0``+@```$FE```:````
M>*4``#(```"3I0``.````,:E``!4````_Z4``%$```!4I@``6@```*:F``!7
M`````:<``#0```!9IP``"0```(ZG```-````F*<```<```"FIP``"@```*ZG
M```/````N:<```4```#)IP``!@```,^G```1````UJ<```@```#HIP``"0``
M`/&G```)````^Z<``"4````%J```(````"NH```3````3*@``!````!@J```
M#P```'&H```*````@:@```,```",J```#P```)"H```4````H*@```D```"U
MJ```#0```+^H```2````S:@``!D```#@J```'@```/JH```/````&:D```H`
M```IJ0``#P```#2I```(````1*D``"0```!-J0``%````'*I```6````AZD`
M``@```">J0``3@```*>I```M````]JD``!D````DJ@``!P```#ZJ```,````
M1JH``"P```!3J@``#@```("J```#````CZH```L```"3J@``!P```)^J```'
M````IZH```4```"OJ@``!0```+6J```*````NZH```,```#&J@``%P```,JJ
M```*````XJH```\```#MJ@``#@```/VJ```8````#*L``",````EJP``#@``
M`$FK```4````6*L``!<```!MJP``%P```(6K```7````G:L``!,```"UJP``
M#P```,FK```.````V:L``!\```#HJP``'0````BL```'````)JP```8````N
MK```"````#6L```/````/JP```8```!.K```"@```%6L```3````8*P```L`
M``!TK```$````("L```5````D:P``!4```"GK```!P```+VL```0````Q:P`
M``4```#6K```%0```-RL```1````\JP```P````$K0``.P```!&M```X````
M3:T```D```"&K0``!P```)"M```4````F*T```,```"MK0``!0```+&M```0
M````MZT```D```#(K0``$P```-*M```Y````YJT``!(````@K@``)P```#.N
M```L````6ZX``"H```"(K@``)0```+.N```*````V:X```8```#DK@``"0``
M`.NN```'````]:X``"\```#]K@``-P```"VO```N````9:\``%4```"4KP``
M+0```.JO```M````&+```#T```!&L```/P```(2P```M````Q+```$````#R
ML```(P```#.Q```C````5[$``$````![L0``+0```+RQ```S````ZK$``"4`
M```>L@``%0```$2R```9````6K(``"D```!TL@``)````)ZR```H````P[(`
M`!$```#LL@``"@```/ZR```,````";,```H````6LP``$````"&S```6````
M,K,``!8```!)LP``!P```&"S```'````:+,``!0```!PLP``"@```(6S```(
M````D+,``"<```"9LP``"````,&S```'````RK,```<```#2LP``!@```-JS
M```%````X;,```<```#GLP``!@```.^S```(````]K,``"D```#_LP``#@``
M`"FT```*````.+0```0```!#M```!P```$BT```)````4+0```8```!:M```
M$0```&&T```'````<[0``!8```![M```!````)*T```(````E[0```8```"@
MM```#0```*>T```&````M;0``!X```"\M```$0```-NT```(````[;0```T`
M``#VM```#`````2U```'````$;4```,````9M0```P```!VU```7````(;4`
M`!,````YM0``'0```$VU```(````:[4```0```!TM0``"````'FU```(````
M@K4``$$```"+M0``&@```,VU```K````Z+4``"`````4M@``%0```#6V```&
M````2[8```8```!2M@``%0```%FV```8````;[8``"(```"(M@``+@```*NV
M```=````VK8``"$```#XM@``5````!JW```I````;[<```H```"9MP``!P``
M`*2W```'````K+<``!4```"TMP``#@```,JW```*````V;<```\```#DMP``
M#0```/2W```/`````K@```T````2N```"0```""X```4````*K@```8````_
MN```&````$:X```=````7[@``!,```!]N```$0```)&X```4````H[@```0`
M``"XN```!@```+VX```4````Q+@``%0```#9N```9````"ZY```$````D[D`
M``X```"8N0``!0```*>Y```%````K;D``!L```"SN0``&@```,^Y```3````
MZKD``!$```#^N0``$0```!"Z```<````(KH``"H````_N@``$````&JZ```A
M````>[H```4```"=N@``$P```*.Z```+````M[H``!(```##N@``"@```-:Z
M```/````X;H```T```#QN@``$0```/^Z```3````$;L```P````ENP``!@``
M`#*[```,````.;L```8```!&NP``%P```$V[```0````9;L``!$```!VNP``
M"````(B[```%````D;L```P```"7NP``$````*2[```%````M;L```T```"[
MNP``!@```,F[```'````T+L```T```#8NP``!P```.:[```+````[KL```<`
M``#ZNP``!P````*\```)````"KP```D````4O```"@```!Z\```9````*;P`
M`#T```!#O```'0```(&\```,````G[P``!````"LO```!0```+V\```E````
MP[P``!(```#IO```$P```/R\```K````$+T``#L````\O0``(````'B]```(
M````F;T``#8```"BO0``(0```-F]```0````^[T```@````,O@``#````!6^
M```&````(KX```0````IO@``#P```"Z^```.````/KX```<```!-O@``"@``
M`%6^```-````8+X``!\```!NO@``'````(Z^```A````J[X``!X```#-O@``
M&0```.R^```>````!K\``!L````EOP``(0```$&_```N````8[\``"8```"2
MOP``'````+F_```>````UK\``!P```#UOP``)@```!+````K````.<```#,`
M``!EP```)@```)G````K````P,```#@```#LP```'0```"7!```5````0\$`
M`"\```!9P0``(````(G!```2````JL$``"D```"]P0``'@```.?!```@````
M!L(``!(````GP@``H@```#K"```6````W<(``",```#TP@``*````!C#```I
M````0<,``"@```!KPP``'P```)3#```5````M,,``"````#*PP``)0```.O#
M```H````$<0``"T````ZQ```,````&C$``"2````F<0``"$````LQ0``%@``
M`$[%```<````9<4``"8```""Q0``*@```*G%``!!````U,4``$0````6Q@``
M#````%O&```'````:,8```<```!PQ@``!@```'C&```-````?\8``!````"-
MQ@``$@```)[&```3````L<8``!(```#%Q@``!P```-C&```$````X,8``!``
M``#EQ@``$````/;&```,````!\<```X````4QP``#0```"/'```/````,<<`
M`!,```!!QP``#0```%7'```H````8\<```,```",QP``#0```)#'```&````
MGL<``!$```"EQP``%P```+?'```;````S\<```X```#KQP```@```/K'``!)
M````_<<```4```!'R```$````$W(```/````7L@```0```!NR```#0```'/(
M```.````@<@```,```"0R```#@```)3(```(````H\@```\```"LR```#P``
M`+S(```'````S,@```T```#4R```$````.+(```-````\\@```L````!R0``
M!@````W)```+````%,D```P````@R0``"@```"W)```1````.,D``!D```!*
MR0``"P```&3)```-````<,D``"(```!^R0``#P```*')```;````L<D``#0`
M``#-R0``"@````+*```8````#<H``!(````FR@``&0```#G*```6````4\H`
M`"(```!JR@``#0```(W*```'````F\H``!0```"CR@``"P```+C*```B````
MQ,H``"\```#GR@``"P```!?+```)````(\L``!D````MRP``"P```$?+```7
M````4\L``!<```!KRP``"0```(/+```6````C<L```\```"DRP``&0```+3+
M```6````SLL```X```#ERP``&````/3+```(````#<P```T````6S```)@``
M`"3,``!#````2\P```@```"/S```$@```)C,```?````J\P```@```#+S```
M"P```-3,```O````X,P```X````0S0``!0```!_-```&````)<T``$4````L
MS0```P```'+-```'````=LT```0```!^S0``"@```(/-```*````CLT```\`
M``"9S0``$````*G-```7````NLT``!$```#2S0``&0```.3-```7````_LT`
M``D````6S@``!0```"#.```+````)LX```H````RS@```@```#W.```%````
M0,X```T```!&S@``&P```%3.```7````<,X``!0```"(S@``"0```)W.```.
M````I\X```T```"VS@``$@```,3.```X````U\X``"`````0SP``"````#'/
M```.````.L\``'L```!)SP``&````,7/```8````WL\``!$```#WSP``!P``
M``G0```%````$=```!@````7T```'@```##0```;````3]```!D```!KT```
M&P```(70```9````H=```!,```"[T```!P```,_0```(````U]````8```#@
MT```!@```.?0```0````[M````\```#_T```$`````_1```/````(-$```L`
M```PT0``#P```#S1```,````3-$```\```!9T0``!P```&G1```&````<=$`
M``X```!XT0``#````(?1```H````E-$```\```"]T0``"````,W1```(````
MUM$``!,```#?T0``'@```//1```A````$M(``"`````TT@``&0```%72```7
M````;](``"4```"'T@``%P```*W2```6````Q=(```0```#<T@``&P```.'2
M```-````_=(```P````+TP```P```!C3```%````'-,```@````BTP``"@``
M`"O3```,````-M,```L```!#TP``$````$_3```,````8-,```X```!MTP``
M"P```'S3```$````B-,```0```"-TP``$P```)+3```4````IM,```P```"[
MTP``"0```,C3```.````TM,```L```#ATP``&P```.W3```'````"=0```<`
M```1U```"@```!G4```-````)-0```D````RU```!````#S4```%````0=0`
M``,```!'U```&````$O4```*````9-0```0```!OU```)@```'34```.````
MF]0``'P```"JU```%0```"?5```%````/=4```<```!#U0``#````$O5```(
M````6-4```H```!AU0``!@```&S5```(````<]4```(```!\U0``!@```'_5
M```&````AM4``!0```"-U0``#0```*+5```0````L-4``!L```#!U0``!```
M`-W5```)````XM4``!````#LU0``"0```/W5```)````!]8```4````1U@``
M&@```!?6```(````,M8```8````[U@``&0```$+6```.````7-8```<```!K
MU@``!P```'/6```%````>]8```D```"!U@``"@```(O6```.````EM8```(`
M``"EU@``!@```*C6```+````K]8```T```"[U@``"0```,G6```&````T]8`
M`!(```#:U@``"0```.W6```'````]]8``!0```#_U@``'0```!37``!"````
M,M<``"4```!UUP``)0```)O7```&````P=<```H```#(UP``!````-/7```)
M````V-<```@```#BUP``$0```.O7```)````_=<```8````'V```#0````[8
M```&````'-@```0````CV```.0```"C8```]````8M@``#H```"@V```'@``
M`-O8```%````^M@```X`````V0``!`````_9```&````%-D```<````;V0``
M(0```"/9```-````1=D``!4```!3V0``!@```&G9```$````<-D``!$```!U
MV0``!@```(?9```*````CMD``"(```"9V0``!````+S9```%````P=D``!T`
M``#'V0``!````.79```,````ZMD```X```#WV0``"@````;:```(````$=H`
M``D````:V@``!0```"3:```Z````*MH``#````!EV@``-0```);:```I````
MS-H``$<```#VV@``.````#[;```I````=]L``#\```"AVP``+@```.';```M
M````$-P``!\````^W```#P```%[<```2````;MP```L```"!W```)@```(W<
M```I````M-P``"0```#>W```)@````/=```(````*MT```H````SW0``"0``
M`#[=```'````2-T``"````!0W0``(````''=```F````DMT```H```"YW0``
M&0```,3=```I````WMT``!8````(W@``$@```!_>```'````,MX```H````Z
MW@``#````$7>```/````4MX``!````!BW@``0````'/>``!P````M-X``&8`
M```EWP``#@```(S?```)````F]\```H```"EWP``$@```+#?```3````P]\`
M``P```#7WP``!@```.3?```/````Z]\``!(```#[WP``$`````[@```1````
M'^```!P````QX```(P```$[@``!J````<N````\```#=X```!0```.W@```0
M````\^````D````$X0``!`````[A```+````$^$``"`````?X0``%````$#A
M```,````5>$```P```!BX0``#P```&_A```5````?^$``"D```"5X0``*@``
M`+_A```F````ZN$``"<````1X@``*0```#GB```J````8^(``!D```".X@``
M0@```*CB```1````Z^(``!(```#]X@``$P```!#C```4````).,```\````Y
MXP``%@```$GC```7````8.,``!````!XXP``$0```(GC```T````F^,``!,`
M``#0XP``$@```.3C```U````]^,``!0````MY```!P```$+D```,````2N0`
M`"````!7Y```$````'CD```4````B>0``!$```">Y```%P```+#D```<````
MR.0``!,```#EY```%````/GD```:````#N4``!$````IY0``&@```#OE```>
M````5N4``!H```!UY0``$P```)#E```5````I.4``!$```"ZY0``%P```,SE
M```4````Y.4``!<```#YY0``%0```!'F```)````)^8``!`````QY@``&0``
M`$+F```$````7.8```<```!AY@``"P```&GF```1````=>8```8```"'Y@``
M!@```([F```&````E>8```4```"<Y@``!P```*+F```'````JN8```4```"R
MY@``%@```+CF```&````S^8```8```#6Y@``!````-WF```$````XN8```<`
M``#GY@``#@```._F```,````_N8```P````+YP``#0```!CG```*````)N<`
M``X````QYP``!0```$#G```H````1N<```X```!OYP``#````'[G```/````
MB^<```H```";YP``"````*;G```)````K^<``"L```"YYP``!````.7G```(
M````ZN<``"8```#SYP``$@```!KH```/````+>@```8````]Z```"@```$3H
M```'````3^@```@```!7Z```(````&#H```)````@>@``!0```"+Z```#```
M`*#H```-````K>@```X```"[Z```%@```,KH```1````X>@```8```#SZ```
M`P```/KH```&````_N@``!D````%Z0``!P```!_I```$````)^D```L````L
MZ0``"P```#CI```'````1.D```4```!,Z0``!P```%+I```6````6ND```T`
M``!QZ0``#0```'_I```*````C>D``!````"8Z0``#P```*GI```1````N>D`
M`!<```#+Z0``"@```./I```1````[ND```@`````Z@``!`````GJ```/````
M#NH``#H````>Z@``!0```%GJ```,````7^H``!X```!LZ@``#@```(OJ```0
M````FNH```L```"KZ@``#````+?J```)````Q.H```<```#.Z@``"@```-;J
M```)````X>H```X```#KZ@``$````/KJ```;````"^L``!@````GZP``&@``
M`$#K```*````6^L```D```!FZP``"@```'#K```,````>^L```\```"(ZP``
M"````)CK```&````H>L``!P```"HZP``!P```,7K```%````S>L```L```#3
MZP``1P```-_K```-````)^P```D````U[```!````#_L```#````1.P``!,`
M``!([```$P```%SL```3````<.P```H```"$[````@```(_L```$````DNP`
M`"4```"7[````P```+WL```%````P>P``"H```#'[```"@```/+L```%````
M_>P```0````#[0``"@````CM```-````$^T```8````A[0``"````"CM```(
M````,>T```0````Z[0``!0```#_M``!H````1>T```D```"N[0``#````+CM
M```0````Q>T```4```#6[0``!@```-SM```;````X^T``"\```#_[0``$```
M`"_N```*````0.X```\```!+[@``"@```%ON```)````9NX``!,```!P[@``
M&P```(3N```8````H.X``!<```"Y[@``'P```-'N```.````\>X```,`````
M[P``!P````3O```(````#.\```<````5[P``"@```!WO```+````*.\```<`
M```T[P``40```#SO```0````CN\```P```"?[P``#0```*SO```:````NN\`
M`$H```#5[P``&0```"#P```&````.O```!H```!!\```)0```%SP```&````
M@O````8```")\```'P```)#P```&````L/````D```"W\```&````,'P```7
M````VO```"@```#R\```!@```!OQ```-````(O$``"(````P\0``5P```%/Q
M```3````J_$``",```"_\0``$P```./Q```"````]_$```L```#Z\0``"```
M``;R```-````#_(```H````=\@``!P```"CR```4````,/(```8```!%\@``
M"````$SR```.````5?(```<```!D\@``"@```&SR```+````=_(``#(```"#
M\@``!P```+;R```,````OO(```T```#+\@``%P```-GR```,````\?(```D`
M``#^\@``"0````CS```*````$O,```<````=\P``"0```"7S```'````+_,`
M``H````W\P``&P```$+S```/````7O,``!(```!N\P``"@```('S```6````
MC/,```D```"C\P``$````*WS```'````OO,``!(```#&\P``!````-GS```'
M````WO,```4```#F\P``!0```.SS```+````\O,``!0```#^\P``$0```!/T
M```:````)?0``!8```!`]```%````%?T```7````;/0``!@```"$]```'```
M`)WT```9````NO0```<```#4]```!0```-ST```-````XO0```P```#P]```
M"````/WT```7````!O4```L````>]0``#````"KU```?````-_4``!H```!7
M]0``$P```'+U```$````AO4```H```"+]0``!````);U```-````F_4```P`
M``"I]0``!0```+;U```)````O/4```4```#&]0``!P```,SU```%````U/4`
M``0```#:]0```@```-_U```X````XO4``"P````;]@``$@```$CV```I````
M6_8``#(```"%]@``"@```+CV```L````P_8``"X```#P]@``,P```!_W```S
M````4_<``#@```"']P``#P```,#W```8````T/<``!````#I]P``#P```/KW
M```3````"O@``!4````>^```%````#3X```2````2?@``!0```!<^```%0``
M`''X```M````A_@``"T```"U^```,0```./X```N````%?D``"\```!$^0``
M+````'3Y``!B````H?D``!,````$^@``#0```!CZ```(````)OH``!<````O
M^@``"````$?Z```,````4/H``"L```!=^@``(0```(GZ```:````J_H```D`
M``#&^@``10```-#Z``!!````%OL```0```!8^P``$P```%W[```4````<?L`
M``X```"&^P``$P```)7[```8````J?L```8```#"^P``"0```,G[```*````
MT_L```\```#>^P``$````.[[```'````__L```X````'_```!0```!;\```;
M````'/P```@````X_```!@```$'\```4````2/P``!$```!=_```#@```&_\
M```X````?OP```(```"W_```!@```+K\```.````P?P```4```#0_```!P``
M`-;\```.````WOP```8```#M_```*````/3\```,````'?T``!P````J_0``
M!````$?]```I````3/T``!<```!V_0``'P```([]``!<````KOT``!0````+
M_@``/@```"#^```?````7_X``!````!__@``!P```)#^```.````F/X```P`
M``"G_@``#````+3^```3````P?X```H```#5_@``'0```.#^```9````_OX`
M``4````8_P``$0```![_```1````,/\``"0```!"_P``$@```&?_```5````
M>O\``!(```"0_P``#@```*/_```9````LO\```@```#,_P``"0```-7_```-
M````W_\```<```#M_P``"@```/7_```'```````!``\````(``$`!@```!@`
M`0`+````'P`!`!H````K``$`"@```$8``0`'````40`!``@```!9``$`!0``
M`&(``0`?````:``!``8```"(``$`$````(\``0`(````H``!``T```"I``$`
M"````+<``0`>````P``!`!(```#?``$`+````/(``0`:````'P$!``D````Z
M`0$`"@```$0!`0`5````3P$!``4```!E`0$`%````&L!`0`$````@`$!`!``
M``"%`0$`!@```)8!`0`'````G0$!`!X```"E`0$`*````,0!`0`*````[0$!
M`!P```#X`0$`$0```!4"`0`+````)P(!`!H````S`@$`%````$X"`0`$````
M8P(!``0```!H`@$`"P```&T"`0`%````>0(!``8```!_`@$`"````(8"`0`&
M````CP(!``H```"6`@$`&P```*$"`0`T````O0(!`#0```#R`@$`(````"<#
M`0`I````2`,!`"````!R`P$`00```),#`0`:````U0,!`"@```#P`P$`*0``
M`!D$`0!0````0P0!`"(```"4!`$`!@```+<$`0`(````O@0!``4```#'!`$`
M"````,T$`0`9````U@0!`!D```#P!`$`*@````H%`0`C````-04!`!D```!9
M!0$`+@```',%`0`T````H@4!``@```#7!0$`%P```.`%`0`*````^`4!``<`
M```#!@$`(0````L&`0`0````+08!``X````^!@$`"P```$T&`0`'````608!
M`!,```!A!@$`"````'4&`0`+````?@8!``H```"*!@$`%````)4&`0`/````
MJ@8!`#(```"Z!@$`"P```.T&`0`.````^08!``4````(!P$`!0````X'`0`%
M````%`<!`!<````:!P$`#P```#('`0`$````0@<!``H```!'!P$`"0```%('
M`0`+````7`<!``T```!H!P$`#````'8'`0`.````@P<!``4```"2!P$`!```
M`)@'`0`-````G0<!`#(```"K!P$`10```-X'`0`7````)`@!``<````\"`$`
M'@```$0(`0`4````8P@!``4```!X"`$`%````'X(`0`&````DP@!``<```":
M"`$`#@```*((`0`J````L0@!``8```#<"`$`#````.,(`0`-````\`@!`!$`
M``#^"`$`"P```!`)`0`V````'`D!``H```!3"0$`(@```%X)`0`+````@0D!
M``\```"-"0$`,@```)T)`0`E````T`D!`#````#V"0$`,0```"<*`0`M````
M60H!``X```"'"@$`!0```)8*`0`.````G`H!`!,```"K"@$`$@```+\*`0`'
M````T@H!`!$```#:"@$`$P```.P*`0`'``````L!`!0````("P$`&````!T+
M`0`'````-@L!``4````^"P$`#````$0+`0`,````40L!`!(```!>"P$`!```
M`'$+`0`'````=@L!``H```!^"P$`"P```(D+`0`,````E0L!``X```"B"P$`
M#@```+$+`0`%````P`L!``4```#&"P$`+@```,P+`0`F````^PL!`",````B
M#`$``P```$8,`0`2````2@P!``8```!=#`$`'@```&0,`0`8````@PP!`"4`
M``"<#`$`#0```,(,`0`)````T`P!`!\```#:#`$``P```/H,`0`'````_@P!
M``H````&#0$``@```!$-`0`,````%`T!`!4````A#0$`"P```#<-`0`9````
M0PT!`"````!=#0$`$@```'X-`0`%````D0T!``H```"7#0$`%0```*(-`0`2
M````N`T!``P```#+#0$`!````-@-`0`)````W0T!``<```#G#0$`#````.\-
M`0!2````_`T!`!<```!/#@$`)````&<.`0`2````C`X!``<```"?#@$`!@``
M`*<.`0`.````K@X!``P```"]#@$`#0```,H.`0`5````V`X!`!(```#N#@$`
M#P````$/`0`4````$0\!``H````F#P$`&P```#$/`0`0````30\!``L```!>
M#P$`:0```&H/`0`:````U`\!`!<```#O#P$`)P````<0`0`:````+Q`!`!<`
M``!*$`$`&P```&(0`0`9````?A`!`!\```"8$`$`$P```+@0`0`(````S!`!
M``<```#5$`$`"````-T0`0`)````YA`!`!4```#P$`$`#0````81`0`C````
M%!$!``T````X$0$`$P```$81`0`(````6A$!``,```!C$0$`1@```&<1`0`_
M````KA$!`#<```#N$0$`5P```"82`0`%````?A(!`!\```"$$@$`+P```*02
M`0`*````U!(!``@```#?$@$`#0```.@2`0`M````]A(!``0````D$P$`3P``
M`"D3`0`E````>1,!`!P```"?$P$`"P```+P3`0`?````R!,!`!T```#H$P$`
M)0````84`0`@````+!0!`"0```!-%`$`(````'(4`0`+````DQ0!``<```"?
M%`$`#0```*<4`0`,````M10!`!<```#"%`$`!@```-H4`0`Y````X10!``P`
M```;%0$`!P```"@5`0`)````,!4!`!,````Z%0$`"0```$X5`0`$````6!4!
M`!````!=%0$`"````&X5`0`(````=Q4!``0```"`%0$`"P```(45`0`,````
MD14!`!(```">%0$`$0```+$5`0`,````PQ4!`!H```#0%0$`#P```.L5`0`'
M````^Q4!``T````#%@$`%````!$6`0`.````)A8!``P````U%@$`&P```$(6
M`0`L````7A8!`!,```"+%@$`'````)\6`0`H````O!8!``8```#E%@$`!P``
M`.P6`0`3````]!8!``4````(%P$`!`````X7`0`7````$Q<!``H````K%P$`
M#````#87`0`)````0Q<!``8```!-%P$`"0```%07`0`(````7A<!``D```!G
M%P$`"@```'$7`0`1````?!<!``8```".%P$`#@```)47`0`.````I!<!``T`
M``"S%P$`"P```,$7`0`=````S1<!``L```#K%P$``@```/<7`0`<````^A<!
M``<````7&`$`!@```!\8`0!D````)A@!``D```"+&`$`!P```)48`0`F````
MG1@!`#@```#$&`$`&@```/T8`0`J````&!D!`#L```!#&0$`*````'\9`0`T
M````J!D!`!D```#=&0$`%0```/<9`0`%````#1H!``<````3&@$`"````!L:
M`0`'````)!H!``4````L&@$`!P```#(:`0`.````.AH!``D```!)&@$`!@``
M`%,:`0`(````6AH!``L```!C&@$`!P```&\:`0`(````=QH!``<```"`&@$`
M%@```(@:`0`)````GQH!``8```"I&@$`"P```+`:`0`0````O!H!``8```#-
M&@$`'````-0:`0`4````\1H!``<````&&P$`$0````X;`0`(````(!L!``X`
M```I&P$`"````#@;`0`%````01L!`!````!'&P$`"0```%@;`0`0````8AL!
M``8```!S&P$`&0```'H;`0`*````E!L!`!P```"?&P$`!P```+P;`0`%````
MQ!L!`!````#*&P$`%````-L;`0`+````\!L!``T```#\&P$`*`````H<`0`8
M````,QP!`!<```!,'`$`!````&0<`0`)````:1P!``H```!S'`$`!P```'X<
M`0`"````AAP!``X```")'`$`"````)@<`0`C````H1P!`!\```#%'`$`.```
M`.4<`0`F````'AT!`#$```!%'0$`)P```'<=`0!D````GQT!`!0````$'@$`
M50```!D>`0`X````;QX!`$H```"H'@$`6P```/,>`0`H````3Q\!`#@```!X
M'P$`*````+$?`0`L````VA\!`"8````'(`$`&P```"X@`0`^````2B`!`*D!
M``")(`$`(P```#,B`0`7````5R(!`$@```!O(@$`A0```+@B`0`P````/B,!
M`"4```!O(P$`00```)4C`0!;````UR,!`$D````S)`$`,0```'TD`0`=````
MKR0!`!@```#-)`$`*P```.8D`0`A````$B4!`!\````T)0$`*P```%0E`0`F
M````@"4!`"<```"G)0$`.@```,\E`0`=````"B8!`!$````H)@$`,P```#HF
M`0`E````;B8!`"<```"4)@$`(````+PF`0`?````W28!`#````#])@$`:0``
M`"XG`0`Q````F"<!`$$```#*)P$`,P````PH`0`E````0"@!`#T```!F*`$`
M90```*0H`0!-````"BD!`"\```!8*0$`+@```(@I`0`P````MRD!`%0```#H
M*0$`6@```#TJ`0!(````F"H!`$H```#A*@$`,@```"PK`0`O````7RL!`"P`
M``"/*P$`+0```+PK`0!Q````ZBL!`&8```!<+`$`;P```,,L`0"S````,RT!
M`!<```#G+0$`)0```/\M`0`R````)2X!`"D```!8+@$`/@```((N`0`B````
MP2X!`%(```#D+@$`)0```#<O`0`+````72\!`+$```!I+P$`10```!LP`0`A
M````83`!`#````"#,`$`)0```+0P`0`<````VC`!`#$```#W,`$`!P```"DQ
M`0`'````,3$!``0````Y,0$`#0```#XQ`0`+````3#$!``X```!8,0$`"P``
M`&<Q`0`%````<S$!`!````!Y,0$``@```(HQ`0!9````C3$!``4```#G,0$`
M$@```.TQ`0`$`````#(!``<````%,@$`"`````TR`0`%````%C(!`#`````<
M,@$``P```$TR`0`0````43(!``P```!B,@$`$P```&\R`0`-````@S(!``(`
M``"1,@$`!P```)0R`0`&````G#(!`!0```"C,@$`#````+@R`0`8````Q3(!
M``8```#>,@$`$@```.4R`0`,````^#(!``,````%,P$`*@````DS`0`$````
M-#,!``8````Y,P$`!P```$`S`0`?````2#,!`#4```!H,P$`+@```)XS`0`O
M````S3,!`!<```#],P$`(@```!4T`0`E````.#0!`"````!>-`$`&P```'\T
M`0`8````FS0!`"0```"T-`$`'P```-DT`0`:````^30!`"$````4-0$`(```
M`#8U`0`:````5S4!`#(```!R-0$`&@```*4U`0`O````P#4!`"L```#P-0$`
M'P```!PV`0`C````/#8!`!\```!@-@$`&@```(`V`0`A````FS8!`"4```"]
M-@$`)@```.,V`0`E````"C<!`"0````P-P$`&````%4W`0`=````;C<!`"0`
M``",-P$`&````+$W`0`B````RC<!`"P```#M-P$`+P```!HX`0`5````2C@!
M`"4```!@.`$`/````(8X`0`?````PS@!`",```#C.`$`'P````<Y`0`@````
M)SD!`!H```!(.0$`&````&,Y`0`F````?#D!`!X```"C.0$`*0```,(Y`0`>
M````[#D!`#$````+.@$`"0```#TZ`0`,````1SH!`!<```!4.@$`+P```&PZ
M`0`D````G#H!``<```#!.@$`#P```,DZ`0`4````V3H!``X```#N.@$`#0``
M`/TZ`0`D````"SL!``4````P.P$`!P```#8[`0`B````/CL!`"4```!A.P$`
M&@```(<[`0`=````HCL!`!H```#`.P$`!P```-L[`0#'````XSL!``L```"K
M/`$`%0```+<\`0`&````S3P!``D```#4/`$`"P```-X\`0`-````ZCP!`!<`
M``#X/`$`!@```!`]`0`S````%ST!`!,```!+/0$`$P```%\]`0`'````<ST!
M``\```![/0$`!P```(L]`0`R````DST!``0```#&/0$`(0```,L]`0`3````
M[3T!``P````!/@$`$0````X^`0`R````(#X!`!8```!3/@$`"````&H^`0`=
M````<SX!``D```"1/@$`"@```)L^`0`4````ICX!``H```"[/@$`'0```,8^
M`0`(````Y#X!`!\```#M/@$`"`````T_`0`:````%C\!`"<````Q/P$`!@``
M`%D_`0`5````8#\!``<```!V/P$`"````'X_`0`)````AS\!`#\```"1/P$`
M!P```-$_`0`/````V3\!``X```#I/P$`$````/@_`0`)````"4`!``D````3
M0`$`"````!U``0`3````)D`!``<````Z0`$`&0```$)``0`*````7$`!`!<`
M``!G0`$`%````']``0`*````E$`!``P```"?0`$`%P```*Q``0`$````Q$`!
M`"H```#)0`$`#````/1``0`1`````4$!``<````300$``@```!M!`0`0````
M'D$!`!@````O00$`"P```$A!`0`#````5$$!``@```!800$`!@```&%!`0`'
M````:$$!``T```!P00$`"P```'Y!`0`4````BD$!`!4```"?00$`#@```+5!
M`0`O````Q$$!`"````#T00$`'````!5"`0`5````,D(!``P```!(0@$`,0``
M`%5"`0`%````AT(!`!(```"-0@$`/P```*!"`0`2````X$(!``H```#S0@$`
M!@```/Y"`0`$````!4,!``0````*0P$`"@````]#`0`3````&D,!``4````N
M0P$`!@```#1#`0`&````.T,!``@```!"0P$`!````$M#`0`,````4$,!``H`
M``!=0P$`.0```&A#`0`N````HD,!`"D```#10P$`!0```/M#`0`8`````40!
M`!D````:1`$`'P```#1$`0`=````5$0!`!$```!R1`$``@```(1$`0`$````
MAT0!``H```",1`$`!@```)=$`0`%````GD0!``,```"D1`$`#````*A$`0!%
M````M40!`#(```#[1`$`&@```"Y%`0`T````244!`"@```!^10$`4P```*=%
M`0`9````^T4!`'(````51@$`(````(A&`0`U````J48!`"$```#?1@$`10``
M``%'`0`P````1T<!`"@```!X1P$`*0```*%'`0`F````RT<!`"4```#R1P$`
M*````!A(`0`H````04@!`"(```!J2`$`*P```(U(`0`P````N4@!`!(```#J
M2`$`$P```/U(`0`0````$4D!`'D````B20$`"0```)Q)`0"A````IDD!`',`
M``!(2@$`?````+Q*`0`K````.4L!`%0```!E2P$`%P```+I+`0`G````TDL!
M`!8```#Z2P$`#P```!%,`0`7````(4P!`!\````Y3`$`0````%E,`0`?````
MFDP!`!P```"Z3`$`40```-=,`0`:````*4T!`!0```!$30$`"@```%E-`0`%
M````9$T!``8```!J30$`"````'%-`0`%````>DT!`!(```"`30$`$````)--
M`0`3````I$T!`!T```"X30$`#P```-9-`0`/````YDT!``0```#V30$`"0``
M`/M-`0`+````!4X!``<````13@$`!0```!E.`0`4````'TX!``<````T3@$`
M"````#Q.`0`/````14X!``@```!53@$`#````%Y.`0`/````:TX!``8```![
M3@$`%````().`0`&````ETX!``P```">3@$`$0```*M.`0`(````O4X!``0`
M``#&3@$`&0```,M.`0`1````Y4X!``H```#W3@$`&`````)/`0`3````&T\!
M`!P````O3P$`$0```$Q/`0`$````7D\!``\```!C3P$`!P```'-/`0`$````
M>T\!`!D```"`3P$`!P```)I/`0`"````HD\!``(```"E3P$`$0```*A/`0`)
M````ND\!``8```#$3P$`$@```,M/`0`7````WD\!``8```#V3P$`)P```/U/
M`0`"````)5`!``0````H4`$`#P```"U0`0`3````/5`!``<```!14`$`!P``
M`%E0`0`1````85`!``8```!S4`$`&````'I0`0`&````DU`!`!,```":4`$`
M$````*Y0`0`2````OU`!``(```#24`$`!@```-50`0`,````W%`!``D```#I
M4`$`$0```/-0`0`B````!5$!``<````H40$`!P```#!1`0`+````.%$!``4`
M``!$40$``@```$I1`0`+````35$!`%<!``!940$`$P```+%2`0`1````Q5(!
M``X```#74@$`"0```.92`0`+````\%(!``@```#\4@$``0````53`0`5````
M!U,!`!H````=4P$`*@```#A3`0`A````8U,!`"(```"%4P$`&@```*A3`0`2
M````PU,!`"H```#64P$`"P````%4`0`F````#50!`!(````T5`$`#0```$=4
M`0`.````550!``4```!D5`$`(P```&I4`0`*````CE0!`!````"95`$`#@``
M`*I4`0`2````N50!``\```#,5`$`90```-Q4`0`0````0E4!``P```!350$`
M#P```&!5`0`,````<%4!`!````!]50$`#@```(Y5`0`0````G54!`!$```"N
M50$`!@```,!5`0#"````QU4!``\```"*5@$`%0```)I6`0`5````L%8!``T`
M``#&5@$`%0```-16`0`5````ZE8!``D`````5P$`"@````I7`0`\````%5<!
M`!4```!25P$`,````&A7`0!#````F5<!`%X```#=5P$`8````#Q8`0!<````
MG5@!`&8```#Z6`$`,@```&%9`0`)````E%D!`!(```">60$`!P```+%9`0`*
M````N5D!``X```#$60$`!0```--9`0`&````V5D!`!(```#@60$`"@```/-9
M`0`)````_ED!``T````(6@$`+@```!9:`0`M````15H!`!@```!S6@$`&@``
M`(Q:`0`6````IUH!``H```"^6@$`!0```,E:`0`.````SUH!``\```#>6@$`
M#````.Y:`0`0````^UH!`!$````,6P$`&P```!Y;`0`6````.EL!`!0```!1
M6P$`#````&9;`0`3````<UL!``H```"'6P$`*````));`0`4````NUL!`!4`
M``#06P$`#@```.9;`0!;````]5L!`#@```!17`$`(0```(I<`0`&````K%P!
M``L```"S7`$`.0```+]<`0`(````^5P!``D````"70$`"@````Q=`0`'````
M%UT!``<````?70$`!0```"==`0`%````+5T!``<````S70$`!@```#M=`0`>
M````0ET!``T```!A70$`#P```&]=`0`9````?UT!`!4```"970$`)P```*]=
M`0`.````UUT!`"<```#F70$`'`````Y>`0`B````*UX!`"(```!.7@$`%0``
M`'%>`0`6````AUX!`!(```">7@$`%P```+%>`0`:````R5X!``<```#D7@$`
M!@```.Q>`0`(````\UX!``X```#\7@$`!P````M?`0`)````$U\!`!(````=
M7P$`!P```#!?`0`,````.%\!`!(```!%7P$`(0```%A?`0`'````>E\!``T`
M``""7P$`"````)!?`0`5````F5\!``P```"O7P$`#````+Q?`0`_````R5\!
M`#\````)8`$`"0```$E@`0`'````4V`!`!,```!;8`$`!0```&]@`0`%````
M=6`!`!````![8`$`"P```(Q@`0`6````F&`!`#<```"O8`$`$````.=@`0`E
M````^&`!`"<````>80$`)P```$9A`0`D````;F$!``\```"380$`!@```*-A
M`0`)````JF$!``@```"T80$`-@```+UA`0`_````]&$!`#4````T8@$`70``
M`&IB`0`T````R&(!`#0```#]8@$`00```#)C`0!#````=&,!`#0```"X8P$`
M1P```.UC`0`H````-60!`"H```!>9`$`10```(ED`0`T````SV0!`#H````$
M90$`+````#]E`0`9````;&4!`!T```"&90$`+@```*1E`0`K````TV4!`"L`
M``#_90$`&P```"MF`0`+````1V8!``\```!39@$`!@```&-F`0`*````:F8!
M`!@```!U9@$`'@```(YF`0`&````K68!``<```"T9@$`%````+QF`0`*````
MT68!``@```#<9@$`+@```.5F`0`*````%&<!``P````?9P$`!@```"QG`0`&
M````,V<!``4````Z9P$`!P```$!G`0`&````2&<!``P```!/9P$`*````%QG
M`0`/````A6<!``P```"59P$`"0```*)G`0`'````K&<!``P```"T9P$`!0``
M`,%G`0`/````QV<!``8```#79P$`$@```-YG`0`(````\6<!``@```#Z9P$`
M!`````-H`0`-````"&@!``@````6:`$`)P```!]H`0`0````1V@!``@```!8
M:`$`#0```&%H`0`,````;V@!``<```!\:`$``P```(1H`0`#````B&@!`!,`
M``",:`$`$````*!H`0`C````L6@!``D```#5:`$`!0```-]H`0`)````Y6@!
M``<```#O:`$`1@```/=H`0`A````/FD!`#H```!@:0$`)@```)MI`0`<````
MPFD!``8```#?:0$`!````.9I`0`2````ZVD!`"````#^:0$`(0```!]J`0`O
M````06H!`"$```!Q:@$`*````)-J`0!A````O&H!`"D````>:P$`"0```$AK
M`0`*````4FL!`!````!=:P$`%0```&YK`0`-````A&L!``P```"2:P$`#```
M`)]K`0`,````K&L!``P```"Y:P$`#````,9K`0`,````TVL!`!0```#@:P$`
M"@```/5K`0`7`````&P!`!L````8;`$`$0```#1L`0`3````1FP!`!4```!:
M;`$`!````'!L`0`%````=6P!`!$```![;`$`2P```(UL`0!3````V6P!``8`
M```M;0$`$P```#1M`0`%````2&T!``4```!.;0$`(````%1M`0`8````=6T!
M``\```".;0$`$````)YM`0`6````KVT!`!\```#&;0$`,````.9M`0`+````
M%VX!`"`````C;@$`!@```$1N`0`5````2VX!``T```!A;@$`$P```&]N`0`/
M````@VX!`!<```"3;@$`$@```*MN`0`4````OFX!`!<```#3;@$`#````.MN
M`0`&````^&X!`!$```#_;@$`"````!%O`0`7````&F\!`!0````R;P$`$@``
M`$=O`0`(````6F\!``0```!C;P$`#````&AO`0`+````=6\!``8```"!;P$`
M$P```(AO`0`*````G&\!``<```"G;P$`#0```*]O`0`)````O6\!``P```#'
M;P$`!P```-1O`0`&````W&\!``L```#C;P$`"````.]O`0`*````^&\!``\`
M```#<`$`0P```!-P`0`:````5W`!`!(```!R<`$`*@```(5P`0`%````L'`!
M`!\```"V<`$`$P```-9P`0`4````ZG`!`#,```#_<`$`0@```#-Q`0`D````
M=G$!``P```";<0$`)@```*AQ`0`=````SW$!``X```#M<0$`!0```/QQ`0`+
M`````G(!``8````.<@$`!@```!5R`0`9````''(!``X````V<@$`!P```$5R
M`0`*````37(!`!$```!8<@$`)0```&IR`0`Q````D'(!`"<```#"<@$`,P``
M`.IR`0`;````'G,!`#`````Z<P$`'0```&MS`0`C````B7,!`#D```"M<P$`
M'P```.=S`0`G````!W0!`"D````O=`$`(0```%ET`0`A````>W0!`"<```"=
M=`$`0@```,5T`0`A````"'4!`"$````J=0$`*P```$QU`0`?````>'4!`!\`
M``"8=0$`.@```+AU`0`B````\W4!`!4````6=@$`)P```"QV`0`@````5'8!
M`"L```!U=@$`%0```*%V`0"2````MW8!`!H```!*=P$`'P```&5W`0`?````
MA7<!`"````"E=P$`+@```,9W`0`=````]7<!`!\````3>`$`(````#-X`0`L
M````5'@!`"X```"!>`$`,````+!X`0`O````X7@!`*$````1>0$`*P```+-Y
M`0`@````WWD!`"0`````>@$`(P```"5Z`0`L````27H!`$````!V>@$`1```
M`+=Z`0`/````_'H!``,````,>P$`!P```!![`0`#````&'L!``\````<>P$`
M"````"Q[`0`9````-7L!`!(```!/>P$`$@```&)[`0`'````=7L!``4```!]
M>P$`&````(-[`0`6````G'L!`!D```"S>P$`%````,U[`0`7````XGL!`!$`
M``#Z>P$`%`````Q\`0`3````(7P!`$X````U?`$`!P```(1\`0`/````C'P!
M``8```"<?`$`$P```*-\`0`9````MWP!`!L```#1?`$`$````.U\`0`"````
M_GP!`%`````!?0$`"@```%)]`0`/````77T!``X```!M?0$`!P```'Q]`0`8
M````A'T!`!,```"=?0$`!0```+%]`0`.````MWT!``@```#&?0$`$````,]]
M`0`3````X'T!``8```#T?0$`"@```/M]`0`.````!GX!`!0````5?@$`"P``
M`"I^`0`&````-GX!``L````]?@$`#````$E^`0`+````5GX!``T```!B?@$`
M*@```'!^`0`+````FWX!``T```"G?@$`*P```+5^`0`4````X7X!`!<```#V
M?@$`00````Y_`0`+````4'\!`!<```!<?P$`&0```'1_`0`5````CG\!`!,`
M``"D?P$`'P```+A_`0`,````V'\!``8```#E?P$`#P```.Q_`0`&````_'\!
M`#D````#@`$`.````#V``0`'````=H`!``P```!^@`$`'P```(N``0`.````
MJX`!`!H```"Z@`$`&@```-6``0`)````\(`!`!T```#Z@`$`$0```!B!`0`D
M````*H$!`!P```!/@0$`"@```&R!`0`3````=X$!``@```"+@0$`#@```)2!
M`0`D````HX$!`$````#(@0$`#@````F"`0`8````&((!`#`````Q@@$`"```
M`&*"`0`+````:X(!`"0```!W@@$`#P```)R"`0`'````K((!`!````"T@@$`
M5@```,6"`0`%````'(,!``<````B@P$`!P```"J#`0`.````,H,!``X```!!
M@P$`$````%"#`0`1````88,!`!@```!S@P$`$@```(R#`0`8````GX,!`!8`
M``"X@P$`"````,^#`0`&````V(,!``L```#?@P$`#````.N#`0`"````^(,!
M``H```#[@P$`$`````:$`0`G````%X0!`!D````_A`$`%````%F$`0`&````
M;H0!``T```!UA`$`#@```(.$`0`/````DH0!`#H```"BA`$`+0```-V$`0`.
M````"X4!`!$````:A0$`9P```"R%`0`4````E(4!`!0```"IA0$`%@```+Z%
M`0`'````U84!``4```#=A0$`'P```..%`0`L`````X8!`"(````PA@$`'@``
M`%.&`0`B````<H8!`!H```"5A@$`&P```+"&`0`%````S(8!``<```#2A@$`
M!P```-J&`0`(````XH8!`!(```#KA@$`$0```/Z&`0`2````$(<!`!$````C
MAP$`(````#6'`0`4````5H<!``\```!KAP$`#P```'N'`0`'````BX<!``@`
M``"3AP$`%````)R'`0`6````L8<!`#````#(AP$`#P```/F'`0`+````"8@!
M``<````5B`$`(````!V(`0`;````/H@!`"0```!:B`$`(P```'^(`0`?````
MHX@!`!\```##B`$`*0```..(`0`<````#8D!`!8````JB0$`!@```$&)`0`<
M````2(D!``H```!EB0$`#0```'")`0`%````?HD!``8```"$B0$`"````(N)
M`0`+````E(D!``T```"@B0$`$````*Z)`0`4````OXD!``X```#4B0$`#@``
M`..)`0`/````\HD!``4````"B@$`"`````B*`0`B````$8H!`",````TB@$`
M%0```%B*`0`.````;HH!`!$```!]B@$`$````(^*`0`H````H(H!``L```#)
MB@$`!0```-6*`0`4````VXH!`!4```#PB@$`#`````:+`0`-````$XL!``<`
M```ABP$`!````"F+`0`<````+HL!``\```!+BP$`!0```%N+`0`A````88L!
M``T```"#BP$`DP```)&+`0`5````)8P!``D````[C`$`"@```$6,`0`3````
M4(P!``P```!DC`$`#@```'&,`0`(````@(P!`!(```")C`$``@```)R,`0`(
M````GXP!``8```"HC`$`$0```*^,`0`.````P8P!`!$```#0C`$`'0```.*,
M`0`)`````(T!``H````*C0$`#P```!6-`0`(````)8T!``D````NC0$`!0``
M`#B-`0`<````/HT!``D```!;C0$`!@```&6-`0`0````;(T!``\```!]C0$`
M!P```(V-`0`%````E8T!``4```";C0$`"0```*&-`0`'````JXT!`!$```"S
MC0$`!````,6-`0`%````RHT!``T```#0C0$`"P```-Z-`0`*````ZHT!``<`
M``#UC0$`%````/V-`0`)````$HX!``<````<C@$`#P```"2.`0`C````-(X!
M`$@```!8C@$`*P```*&.`0`K````S8X!``8```#YC@$`"@````"/`0`$````
M"X\!``D````0CP$`"````!J/`0`4````(X\!``L````XCP$`!@```$2/`0`-
M````2X\!``8```!9CP$`!````&"/`0!&````98\!`$\```"LCP$`2P```/R/
M`0`@````2)`!``4```!ID`$`#@```&^0`0`$````?I`!``8```"#D`$`!@``
M`(J0`0`8````D9`!`!0```"JD`$`%0```+^0`0`'````U9`!``0```#=D`$`
M%@```.*0`0`$````^9`!``\```#^D`$`&P````Z1`0`&````*I$!``4````Q
MD0$`)P```#>1`0`$````7Y$!``H```!DD0$`#0```&^1`0`.````?9$!``@`
M``",D0$`"0```)61`0`%````GY$!`#````"ED0$`,@```-:1`0`Z````"9(!
M`"````!$D@$`20```&62`0`Y````KY(!`"D```#ID@$`.````!.3`0`J````
M3),!`"P```!WDP$`(0```*23`0`1````QI,!`!````#8DP$`"P```.F3`0`E
M````]9,!`"<````;E`$`(0```$.4`0`C````990!``<```")E`$`"0```)&4
M`0`*````FY0!``8```"FE`$`*0```*V4`0`I````UY0!`#(````!E0$`"0``
M`#25`0`?````/I4!`"T```!>E0$`%@```(R5`0`1````HY4!``<```"UE0$`
M"P```+V5`0`-````R94!`!````#7E0$`#P```.B5`0!`````^)4!`(T````Y
ME@$`9````,>6`0`1````+)<!``@````^EP$`"0```$>7`0`0````49<!`!$`
M``!BEP$`#````'27`0`%````@9<!`!````"'EP$`$````)B7`0`.````J9<!
M`!,```"XEP$`'````,R7`0`F````Z9<!`'0````0F`$`$````(68`0`%````
MEI@!`!4```"<F`$`"0```+*8`0`$````O)@!``L```#!F`$`'@```,V8`0`5
M````[)@!``H````"F0$`#@````V9`0`0````')D!`!,````MF0$`(@```$&9
M`0`@````9)D!`"````"%F0$`'@```*:9`0`D````Q9D!`"(```#JF0$`&@``
M``V:`0`U````*)H!`!(```!>F@$`$````'&:`0`2````@IH!`!(```"5F@$`
M%````*B:`0`5````O9H!`!,```#3F@$`$````.>:`0`2````^)H!`"D````+
MFP$`$P```#6;`0`5````29L!`$H```!?FP$`'````*J;`0`,````QYL!`!$`
M``#4FP$`(0```.:;`0`5````")P!`!$````>G`$`$@```#"<`0`=````0YP!
M`!\```!AG`$`%@```(&<`0`7````F)P!`!4```"PG`$`$P```,:<`0`=````
MVIP!`"````#XG`$`)0```!F=`0`3````/YT!`!0```!3G0$`%````&B=`0`<
M````?9T!`!4```":G0$`%0```+"=`0`9````QIT!``L```#@G0$`&P```.R=
M`0`<````")X!``0````EG@$`!P```"J>`0`)````,IX!`!<````\G@$`!@``
M`%2>`0`1````6YX!``H```!MG@$`!@```'B>`0`'````?YX!``@```"'G@$`
M!@```)">`0`4````EYX!``8```"LG@$`"````+.>`0`(````O)X!``<```#%
MG@$`!P```,V>`0`0````U9X!``X```#FG@$`$@```/6>`0`0````")\!``D`
M```9GP$`%0```".?`0`%````.9\!`#`````_GP$`$P```'"?`0`.````A)\!
M`!````"3GP$`#@```*2?`0`.````LY\!``X```#"GP$`*P```-&?`0`&````
M_9\!``@````$H`$`-0````V@`0`>````0Z`!``X```!BH`$`!@```'&@`0`)
M````>*`!``D```""H`$`!0```(R@`0`D````DJ`!`!4```"WH`$`&0```,V@
M`0`6````YZ`!`!0```#^H`$`(0```!.A`0`E````-:$!`"T```!;H0$`!@``
M`(FA`0`$````D*$!``@```"5H0$`'````)ZA`0`'````NZ$!``4```##H0$`
M#````,FA`0`+````UJ$!``8```#BH0$`!````.FA`0`'````[J$!`!4```#V
MH0$`#`````RB`0`.````&:(!``\````HH@$`&````#BB`0`9````4:(!`!,`
M``!KH@$`'0```'^B`0`3````G:(!`!,```"QH@$`"0```,6B`0`&````SZ(!
M`!````#6H@$`/P```.>B`0`&````)Z,!``\````NHP$`'@```#ZC`0`1````
M7:,!`!4```!OHP$`#````(6C`0`.````DJ,!``L```"AHP$`"0```*VC`0`/
M````MZ,!``P```#'HP$`#0```-2C`0`=````XJ,!`"(`````I`$`(@```".D
M`0`H````1J0!``P```!OI`$`!P```'RD`0`+````A*0!`!,```"0I`$`%```
M`*2D`0`&````N:0!``\```#`I`$`(@```-"D`0`-````\Z0!``\````!I0$`
M'@```!&E`0!E````,*4!`"````"6I0$`#````+>E`0`'````Q*4!``8```#,
MI0$`'@```-.E`0`=````\J4!`!H````0I@$`"0```"NF`0`"````-:8!``0`
M```XI@$`(````#VF`0`&````7J8!``4```!EI@$`*@```&NF`0`*````EJ8!
M``<```"AI@$`"@```*FF`0`/````M*8!``X```#$I@$`!@```-.F`0`'````
MVJ8!``H```#BI@$`!0```.VF`0`%````\Z8!`(,```#YI@$`#````'VG`0`/
M````BJ<!`!@```":IP$`"0```+.G`0`*````O:<!`!X```#(IP$`+````.>G
M`0`/````%*@!``H````DJ`$`$````"^H`0`*````0*@!``D```!+J`$`&@``
M`%6H`0`I````<*@!`"<```":J`$`)@```,*H`0`>````Z:@!`!8````(J0$`
M"````!^I`0`)````**D!``H````RJ0$`!P```#VI`0`,````1:D!``T```!2
MJ0$`!@```&"I`0!2````9ZD!``\```"ZJ0$`#@```,JI`0`)````V:D!`"``
M``#CJ0$`60````2J`0`:````7JH!``8```!YJ@$`'@```("J`0`M````GZH!
M``@```#-J@$`!P```-:J`0`?````WJH!``@```#^J@$`"P````>K`0`G````
M$ZL!`"8````[JP$`)0```&*K`0`)````B*L!``H```"2JP$`(@```)VK`0!<
M````P*L!`!0````=K`$`)@```#*L`0`4````6:P!``(```!NK`$`$0```'&L
M`0`+````@ZP!`!8```"/K`$`#@```*:L`0`'````M:P!`!(```"]K`$`!@``
M`-"L`0`(````UZP!`!$```#@K`$`#0```/*L`0`*`````*T!``P````+K0$`
M,P```!BM`0`'````3*T!`!$```!4K0$`$@```&:M`0`@````>:T!`!<```":
MK0$`#P```+*M`0`1````PJT!``\```#4K0$`#P```.2M`0`/````]*T!``\`
M```$K@$`"````!2N`0`<````':X!`!X````ZK@$`"P```%FN`0`2````9:X!
M`!T```!XK@$`#````):N`0`7````HZX!``\```"[K@$`#0```,NN`0`$````
MV:X!``<```#>K@$`!0```.:N`0`%````[*X!``H```#RK@$`%0```/VN`0`1
M````$Z\!`!H````EKP$`%@```$"O`0`4````5Z\!`!<```!LKP$`'@```(2O
M`0`=````HZ\!`!H```#!KP$`!@```-RO`0`*````XZ\!``X```#NKP$`#0``
M`/VO`0`'````"[`!`",````3L`$`#0```#>P`0`-````1;`!`!H```!3L`$`
M)@```&ZP`0`4````E;`!``<```"JL`$`$````+*P`0`(````P[`!`!0```#,
ML`$`$P```.&P`0`)````];`!``D```#_L`$`!0````FQ`0`'````#[$!``(`
M```7L0$`!````!JQ`0`"````'[$!`$0````BL0$`0P```&>Q`0`-````J[$!
M`"(```"YL0$`-@```-RQ`0`,````$[(!`"D````@L@$`'0```$JR`0`B````
M:+(!`"(```"+L@$`)P```*ZR`0`0````UK(!`!0```#GL@$`'@```/RR`0`5
M````&[,!`!@````QLP$`%P```$JS`0`3````8K,!`!<```!VLP$`'````(ZS
M`0`:````J[,!`"\```#&LP$`+P```/:S`0`S````)K0!`#````!:M`$`,0``
M`(NT`0`N````O;0!`&L```#LM`$`)0```%BU`0`9````?K4!``L```"8M0$`
M&P```*2U`0`*````P+4!`!4```#+M0$`*@```.&U`0`L````#+8!`"@````Y
MM@$`"0```&*V`0!;````;+8!`$T```#(M@$`"0```!:W`0`@````(+<!`"8`
M``!!MP$`#@```&BW`0`8````=[<!`!L```"0MP$`!0```*RW`0`*````LK<!
M``@```"]MP$`$````,:W`0`2````U[<!``L```#JMP$`"@```/:W`0`-````
M`;@!`"4````/N`$`"0```#6X`0`)````/[@!`!(```!)N`$`%0```%RX`0`0
M````<K@!`#D```"#N`$``@```+VX`0`'````P+@!``X```#(N`$`!P```->X
M`0`'````W[@!`!,```#GN`$`"````/NX`0`X````!+D!``X````]N0$`&0``
M`$RY`0`$````9KD!`#````!KN0$`'````)RY`0`L````N;D!`%4```#FN0$`
M%@```#RZ`0!'````4[H!`",```";N@$`$0```+^Z`0`)````T;H!`!````#;
MN@$`$0```.RZ`0`,````_KH!`!,````+NP$`#````!^[`0`;````++L!`!L`
M``!(NP$``P```&2[`0`+````:+L!`!(```!TNP$`*````(>[`0`<````L+L!
M`!X```#-NP$`$P```.R[`0`2`````+P!`"<````3O`$`"0```#N\`0`1````
M1;P!`!(```!7O`$`!P```&J\`0`*````<KP!``<```!]O`$`#@```(6\`0`'
M````E+P!`!````"<O`$`'````*V\`0`2````RKP!``4```#=O`$`"````..\
M`0`%````[+P!`!P```#RO`$`!@````^]`0`1````%KT!``@````HO0$`$0``
M`#&]`0`(````0[T!`!H```!,O0$`#@```&>]`0`K````=KT!`!<```"BO0$`
M"0```+J]`0`*````Q+T!`!T```#/O0$`!0```.V]`0`3````\[T!``4````'
MO@$`*`````V^`0`'````-KX!``D````^O@$`'````$B^`0`\````9;X!``8`
M``"BO@$`&P```*F^`0`0````Q;X!``@```#6O@$`$P```-^^`0`+````\[X!
M``0```#_O@$`"`````2_`0`+````#;\!``<````9OP$`"0```"&_`0`(````
M*[\!``<````TOP$`!P```#R_`0`5````1+\!`"T```!:OP$`.P```(B_`0`7
M````Q+\!`"````#<OP$`%0```/V_`0`^````$\`!`!P```!2P`$`'0```&_`
M`0`E````C<`!`%@```"SP`$`(`````S!`0`%````+<$!``H````SP0$`!P``
M`#[!`0`)````1L$!`!(```!0P0$`%0```&/!`0`X````><$!`",```"RP0$`
M'P```-;!`0`U````]L$!`#H````LP@$`"@```&?"`0`:````<L(!``P```"-
MP@$`"@```)K"`0`A````I<(!`!,```#'P@$`$@```-O"`0`.````[L(!``<`
M``#]P@$`#P````7#`0`)````%<,!`!`````?PP$`#@```###`0`:````/\,!
M`!<```!:PP$`,````'+#`0`+````H\,!`!\```"OPP$`!0```,_#`0`&````
MU<,!``<```#<PP$`'@```.3#`0`,`````\0!``0````0Q`$`$````!7$`0`/
M````)L0!``D````VQ`$`#````$#$`0`.````3<0!`!8```!<Q`$`!0```'/$
M`0`$````><0!`!(```!^Q`$`,0```)'$`0!$````P\0!`!<````(Q0$`!P``
M`"#%`0`C````*,4!`!@```!,Q0$`%````&7%`0`.````>L4!``\```")Q0$`
M#0```)G%`0`-````I\4!`"\```"UQ0$`!@```.7%`0`+````[,4!``T```#X
MQ0$`#P````;&`0`+````%L8!`#P````BQ@$`!@```%_&`0`>````9L8!``\`
M``"%Q@$`$P```)7&`0`G````J<8!`!\```#1Q@$`.P```/'&`0`\````+<<!
M`#@```!JQP$`$0```*/'`0`(````M<<!`!$```"^QP$`$P```-#'`0`8````
MY,<!``@```#]QP$`$`````;(`0`6````%\@!``<````NR`$`$0```#;(`0`<
M````2,@!``L```!ER`$`!0```''(`0`,````=\@!``L```"$R`$`$````)#(
M`0`%````H<@!``<```"GR`$`"@```*_(`0`3````NL@!`!,```#.R`$`#```
M`.+(`0`,````[\@!``8```#\R`$`"0````/)`0`V````#<D!`"@```!$R0$`
M(P```&W)`0`'````D<D!`"````"9R0$`!@```+K)`0`D````P<D!`!4```#F
MR0$`*````/S)`0`1````)<H!`!$````WR@$`'````$G*`0`#````9LH!``@`
M``!JR@$`$@```'/*`0`"````ALH!``P```")R@$`%````);*`0`+````J\H!
M`!@```"WR@$`'````-#*`0`8````[<H!``4````&RP$`"@````S+`0`4````
M%\L!`!P````LRP$`#0```$G+`0`'````5\L!``P```!?RP$`"@```&S+`0`1
M````=\L!`$H```")RP$`'````-3+`0`W````\<L!`!@````IS`$`!0```$+,
M`0`$````2,P!``H```!-S`$`$0```%C,`0`2````:LP!`!<```!]S`$`%0``
M`)7,`0`0````J\P!`!H```"\S`$`#@```-?,`0`D````YLP!``\````+S0$`
M$````!O-`0!K````+,T!`"````"8S0$`'@```+G-`0`<````V,T!`"````#U
MS0$`&````!;.`0`D````+\X!`!(```!4S@$`&0```&?.`0`4````@<X!``H`
M``"6S@$`!P```*'.`0`+````J<X!``<```"US@$`%````+W.`0`+````TLX!
M`#H```#>S@$`$P```!G/`0`:````+<\!``@```!(SP$`!0```%'/`0!*````
M5\\!`$\```"BSP$`30```/+/`0!D````0-`!``<```"ET`$`*````*W0`0`L
M````UM`!``H````#T0$`"`````[1`0`-````%]$!`#(````ET0$`!0```%C1
M`0!2````7M$!`"P```"QT0$`)````-[1`0`.`````](!`"`````2T@$`'```
M`#/2`0`C````4-(!`!T```!TT@$`(P```)+2`0`:````MM(!``P```#1T@$`
M!P```-[2`0`0````YM(!`!$```#WT@$`%`````G3`0`(````'M,!`$`````G
MTP$`#````&C3`0`(````==,!``T```!^TP$`&@```(S3`0`)````I],!``0`
M``"QTP$`%@```+;3`0`(````S=,!``@```#6TP$`!````-_3`0`+````Y-,!
M``L```#PTP$`%````/S3`0`3````$=0!``X````EU`$`%````#34`0`.````
M2=0!``<```!8U`$`$````&#4`0`<````<=0!``L```".U`$`#0```)K4`0`;
M````J-0!`"H```#$U`$`&````._4`0`>````"-4!`"H````GU0$`!````%+5
M`0`$````5]4!``T```!<U0$`!P```&K5`0`*````<M4!`!8```!]U0$`"```
M`)35`0`*````G=4!``@```"HU0$`!P```+'5`0`)````N=4!``D```##U0$`
M"0```,W5`0`,````U]4!``X```#DU0$`!````//5`0`.````^-4!``H````'
MU@$`"@```!+6`0`/````'=8!`!P````MU@$`"P```$K6`0`"````5M8!`!\`
M``!9U@$`!P```'G6`0`&````@=8!`&@```"(U@$`#````/'6`0`(````_M8!
M`"@````'UP$`1````##7`0`?````==<!`"T```"5UP$`6````,/7`0`F````
M'-@!`"D```!#V`$`&````&W8`0`=````AM@!``4```"DV`$`"@```*K8`0`-
M````M=@!``T```##V`$`"P```-'8`0`-````W=@!`!4```#KV`$`#P````'9
M`0`-````$=D!``\````?V0$`#P```"_9`0`$````/]D!``<```!$V0$`"```
M`$S9`0`9````5=D!``@```!OV0$`!@```'C9`0`'````?]D!`!,```"'V0$`
M!@```)O9`0`;````HMD!`!8```"^V0$`"P```-79`0`9````X=D!``P```#[
MV0$`%@````C:`0`,````']H!``@````LV@$`#P```#7:`0`2````1=H!``\`
M``!8V@$`!@```&C:`0`7````;]H!``L```"'V@$`'@```)/:`0`&````LMH!
M``@```"YV@$`#0```,+:`0`@````T-H!``D```#QV@$`"P```/O:`0`F````
M!]L!`!@````NVP$`$````$?;`0`&````6-L!``L```!?VP$`#@```&O;`0`)
M````>ML!``(```"$VP$`#@```(?;`0`'````EML!`"8```">VP$`*0```,7;
M`0`K````[]L!`!P````;W`$`+````#C<`0`I````9=P!`%H```"/W`$`#0``
M`.K<`0!-````^-P!`#0```!&W0$`4P```'O=`0!,````S]T!`"$````<W@$`
M,P```#[>`0`F````<MX!`#(```"9W@$`*P```,S>`0`3````^-X!`#T````,
MWP$`F`(``$K?`0`:````X^$!`!````#^X0$`/P````_B`0"%````3^(!`"X`
M``#5X@$`)0````3C`0!$````*N,!`$\```!OXP$`2@```+_C`0`L````"N0!
M`!D````WY`$`$````%'D`0`E````8N0!`!L```"(Y`$`'````*3D`0`H````
MP>0!`"<```#JY`$`*@```!+E`0`P````/>4!`!D```!NY0$`#0```(CE`0`K
M````EN4!`"0```#"Y0$`*````.?E`0`A````$.8!`!P````RY@$`.@```$_F
M`0!E````BN8!`#4```#PY@$`2P```";G`0`U````<N<!`"@```"HYP$`-@``
M`-'G`0!<````".@!`#H```!EZ`$`+P```*#H`0`H````T.@!`"P```#YZ`$`
M5P```";I`0!6````?ND!`$<```#5Z0$`10```!WJ`0`O````8^H!`"D```"3
MZ@$`*0```+WJ`0`I````Y^H!`&@````1ZP$`8@```'KK`0!K````W>L!`+L`
M``!)[`$`&@````7M`0`N````(.T!`#<```!/[0$`*````(?M`0!D````L.T!
M`!@````5[@$`6````"[N`0`<````A^X!``L```"D[@$`S````+#N`0!/````
M?>\!`"(```#-[P$`/````/#O`0`@````+?`!`!@```!.\`$`,P```&?P`0`&
M````F_`!``<```"B\`$`!````*KP`0`,````K_`!`!````"\\`$`#````,WP
M`0`+````VO`!``<```#F\`$`$@```.[P`0`-`````?$!`((````/\0$`!@``
M`)+Q`0`5````F?$!``0```"O\0$`!P```+3Q`0`(````O/$!``4```#%\0$`
M4@```,OQ`0`$````'O(!`!D````C\@$`"@```#WR`0`2````2/(!`!````!;
M\@$``@```&SR`0`'````;_(!``8```!W\@$`$P```'[R`0`,````DO(!`!8`
M``"?\@$`!@```+;R`0`4````O?(!``\```#2\@$``P```.+R`0`N````YO(!
M``0````5\P$`!@```!KS`0`'````(?,!`!X````I\P$`/````$CS`0`N````
MA?,!`"\```"T\P$`%@```.3S`0`H````^_,!`#`````D]`$`(@```%7T`0`J
M````>/0!`"````"C]`$`(P```,3T`0`>````Z/0!`!P````']0$`+````"3U
M`0`D````4?4!`!H```!V]0$`+@```)'U`0`:````P/4!`"P```#;]0$`,```
M``CV`0`@````.?8!`"0```!:]@$`)````'_V`0`?````I/8!`",```#$]@$`
M+````.CV`0`G````%?<!`"<````]]P$`)0```&7W`0`?````B_<!`"0```"K
M]P$`,````-#W`0`=`````?@!`"H````?^`$`-@```$KX`0`Y````@?@!`!H`
M``"[^`$`)P```-;X`0!-````_O@!`"D```!,^0$`+0```';Y`0`M````I/D!
M`"X```#2^0$`*`````'Z`0`F````*OH!`"$```!1^@$`)P```'/Z`0`X````
MF_H!`"H```#4^@$`-0```/_Z`0`,````-?L!``X```!"^P$`(````%'[`0`J
M````<OL!`"$```"=^P$`#P```+_[`0`/````S_L!`!H```#?^P$`&@```/K[
M`0`+````%?P!`"<````A_`$`#````$G\`0`*````5OP!`"4```!A_`$`*```
M`(?\`0`B````L/P!`"<```#3_`$`(@```/O\`0`'````'OT!`-P````F_0$`
M"P````/^`0`3````#_X!``<````C_@$`"@```"O^`0`0````-OX!`!(```!'
M_@$`'````%K^`0`#````=_X!`#,```![_@$`&P```*_^`0`8````R_X!``<`
M``#D_@$`$@```.S^`0`2````__X!`#,````2_P$`"````$;_`0`I````3_\!
M`!,```!Y_P$`$P```(W_`0`9````H?\!`#,```"[_P$`'0```.__`0`.````
M#0`"`",````<``(`#P```$```@`0````4``"`!<```!A``(`"@```'D``@`?
M````A``"``\```"D``(`'0```+0``@`/````T@`"`!X```#B``(`)@````$!
M`@`%````*`$"`!`````N`0(`!P```#\!`@`+````1P$"``D```!3`0(`.```
M`%T!`@`&````E@$"``\```"=`0(`$0```*T!`@`0````OP$"``L```#0`0(`
M#P```-P!`@`'````[`$"`!````#T`0(`"`````4"`@`;````#@("``@````J
M`@(`&P```#,"`@`;````3P("``L```!K`@(`#0```'<"`@`<````A0("``@`
M``"B`@(`,0```*L"`@`1````W0("`!````#O`@(`"``````#`@`"````"0,"
M``H````,`P(`&````!<#`@`+````,`,"``,````\`P(`"P```$`#`@`+````
M3`,"``H```!8`P(`%P```&,#`@`.````>P,"`!@```"*`P(`'@```*,#`@`,
M````P@,"`#D```#/`P(`(@````D$`@`C````+`0"`!D```!0!`(`#0```&H$
M`@!%````>`0"``8```"^!`(`&@```,4$`@!6````X`0"``\````W!0(`$```
M`$<%`@`'````6`4"``0```!@!0(`!0```&4%`@`1````:P4"`!8```!]!0(`
M!@```)0%`@`'````FP4"``<```"C!0(`"P```*L%`@`#````MP4"``P```"[
M!0(`#0```,@%`@`Y````U@4"`"X````0!@(`+````#\&`@`%````;`8"`!8`
M``!R!@(`)0```(D&`@`B````KP8"`!\```#2!@(`$P```/(&`@`"````!@<"
M``0````)!P(`#0````X'`@`*````'`<"``4````G!P(`!0```"T'`@`/````
M,P<"`$T```!#!P(`)````)$'`@`7````M@<"`"(```#.!P(`,````/$'`@!.
M````(@@"`!8```!Q"`(`?@```(@(`@`>````!PD"`%D````F"0(`*@```(`)
M`@!/````JPD"`#````#["0(`*````"P*`@`M````50H"`"T```"#"@(`*P``
M`+$*`@`N````W0H"`"D````,"P(`*````#8+`@`L````7PL"`#<```","P(`
M%````,0+`@`:````V0L"``P```#T"P(`J`````$,`@`&````J@P"`+D```"Q
M#`(`A0```&L-`@"@````\0T"`"````"2#@(`5P```+,.`@`0````"P\"`!T`
M```<#P(`$0```#H/`@`'````3`\"`!D```!4#P(`'@```&X/`@!!````C0\"
M`!D```#/#P(`%@```.D/`@!7`````!`"`!H```!8$`(`#P```',0`@`*````
M@Q`"``4```".$`(`!@```)00`@`(````FQ`"``4```"D$`(`&0```*H0`@`)
M````Q!`"`!@```#.$`(`(@```.<0`@`/````"A$"``D````:$0(`#@```"01
M`@`)````,Q$"``P````]$0(`!P```$H1`@`%````4A$"`!````!8$0(`$```
M`&D1`@`.````>A$"`!````")$0(`"@```)H1`@`)````I1$"`!````"O$0(`
M"````,`1`@`3````R1$"``H```#=$0(`"P```.@1`@`8````]!$"``D````-
M$@(`!@```!<2`@`;````'A("`!@````Z$@(`#@```%,2`@`4````8A("``L`
M``!W$@(`)@```(,2`@`4````JA("``<```"_$@(`%0```,<2`@`'````W1("
M``@```#E$@(`(@```.X2`@`+````$1,"``(````=$P(``@```"`3`@`:````
M(Q,"``P````^$P(`!@```$L3`@`(````4A,"`!H```!;$P(`!@```'83`@`E
M````?1,"``(```"C$P(`!````*83`@`1````JQ,"`!<```"]$P(`"P```-43
M`@`)````X1,"`!````#K$P(`"@```/P3`@`6````!Q0"``<````>%`(`'```
M`"84`@`*````0Q0"`!<```!.%`(``@```&84`@`%````:10"`!````!O%`(`
M#````(`4`@`2````C10"`"D```"@%`(`!P```,H4`@`'````TA0"`!$```#:
M%`(`!0```.P4`@`"````\A0"``L```#U%`(``0```-,$```<!```,04``%\#
M````````G`$``&T"``"@!````````)0#``#'`0``_`8``'P`````````````
M`(8"```J!P``"P$```````""!P``P0```'<%```5!```\04``"P```#;`P``
MP@8``"0'```(`@```00``+P%```#!P``,0,```````"F`@``\`4``&0"``"R
M`@``#P0``($#````````````````````````U@0``%$%``"%!```````````
M``#V`0``<`(`````````````?P(``"X$````````(P$``*0%````````8P<`
M`.0%``"0!@``)0$``'$&``#U!```;@(``'`!```T!P``P@$``-$"```O!```
M;P,``$\'``!:````H@$``#,!``"*!P```````'L!``#K````EP8``,`%``!=
M!P``2@4``,T&````````E`0``&("``#R````*0(``&8"````````VP0``(4&
M``#>!0````````````"E````````````````````F`,```````!`````Y08`
M``````#-`0```````)T$``!(`@``OP4```````#]`@``B0<````````,!0``
M`````$\$``#,!0``[`(``"8%```7`````````#0```!8````O`$`````````
M````M0(``%H$``!E`P``:@,``%\!``"#!P``````````````````^@$``&0#
M``!O````U@$```````!^!@````````D'``"0`````````$T#``";`@``````
M`!P#``!>!@``]`$``-\````H`P``W`$``-`!``"V`P``1P,````````<!P``
M$@<``"4#``#Q````L`4``-($`````````````*L#``"D`````````,L%``!A
M`P``>0,``)4$```*!````````(L&``#``0```````.$$``!Y!P``V0,``.<!
M````````_P4``$L'``"I`0``6`0``.0!````````3P```+X!````````````
M```````O`P``;0<```````"R`````````)@%``!G!```I08``.(!``!'!@``
M`````"H```#[`0``:`$``%4'``#:`P``*08``*,$``!5!@``5@0``+`&````
M````G0(``%L```"3!@``BP,``*D`````````K`4``-,```"@`P``>@$``&<"
M``#"`P``*0<``'L#```K`````````#8``````````````#$"``"#````Y`0`
M``````#V!```>00``$4'````````]P``````````````DP(``+H%````````
M%P4``*H#```K`@``>P<```````!T!```.P(`````````````D`(``(X!``"*
M!```W````'T'``!7!0``F@,```,"```\!P``7@,```8!````````100`````
M```N!P``GP,``*4!`````````````&<%``!Q`0````````````!#!@``VP``
M`#X'``!*``````````("````````*0$```````!6`P```````)P$````````
MS`$``&$$```6`P```````"<$``!A```````````````E!```=P```.X#``!G
M!@```````)T&````!@``>P`````````9!@``L00```,````$!P``W04``+@&
M``#)`P``?`(``!<'``#L``````````````!C`0```````.X"``":````D@``
M`)X#````````FP$``"L%``!Q`@``\P,``$8#``"^`@``N@$``-T$``#7!@``
MM`,``.,$``#*!```J@0````````9!P``%P(``+\$```8`0``L0(`````````
M````X@,``(\"````````?@$``/X%``!I`0``%P8``/@!```J`P``2P,``'(#
M``!'!```E@$``$<```#(`0``<0,``$\&```Z````808``%,```#6!@``=@(`
M```````N!0``)@(``'0&``#M````"P8```0```#D`@``?@,``(,%``")`0``
MDP0``/X"``!E!P``YP4``!<!````````GP$```X'``![`@``?@````4$```*
M!P``+@8``#4&````````4@(``+\`````````=P,``/\#````````"P```#,%
M`````````````&<'```H!@``W0````````#T`@``0`<```````#8`P``V@0`
M````````````:`````T"``!S!@```````-0&``#&!@``<0```*````#]!@``
M0@(```````";!```N0,``,`````$!```#P8``$P!``"4`@``N04``*`!``#!
M`0````````4`````````30<``-8"``!C`````````,0`````````````````
M``#R!````````$`%``!P!P```````,X&````````%P,``((&````````````
M`%(%`````````````/,$``!W!```I`8``&\$```(````7@```$D'``"Z`P``
M=@4``-X```"$`P``)`0``#L%``#X!@``G`,``'<"````````:@$``#X"``"_
M!@``[@4``+X$````````<`8```````")````I0(````````T!@```````!T'
M````````50$``"($```X`0```````&T$````````AP(``'D%``"`!0``U@``
M```````A`@``4`8``#<$```S`@````````````"7`P``_P0```$'```'`P``
M:@8```````#Q`0``Q@```/`#``"/````7`<`````````````Z`8``(4#````
M`````````-T"```N`P``5P$``/4&````````Y0$``/X```!-````S00``!`%
M````````-@$``)`#``!]`0``EP```%D$``!_!```<P```*<%``!8`@``@@(`
M``````!"!@``=@$``/X!````````YP0````````D`````````/@$``!K!```
MQ@0``%D!```A!```!@```)\"``!>`@`````````````$!@``E`4```````#B
M!@``C@,``#X````K`0``%`(``-<#``"2!@``00<```````!L`P```````(X$
M``"C`````````,4#``!1````O0(``"P$```@!```Z00````````M!@``]@(`
M`"\&``!8!0``````````````````J0(``"0#`````````````+,!````````
M?0```"<#````````<P<```````"1!````````,X!``#Q!@``"`$`````````
M```````````!``!,!0``.08```````#)!0``$0$``%\$``#Z`P``G````+`#
M``#$`0```````'4$``!Q!```UP(``,H%``!\`0``C`$`````````````````
M`/T%```U!````````#\'``"F!@``T`,``*D&``#M`0``I@````````#O`@``
M````````````````K00``.L!``#Y!```WP,``"@$````````9@0``)\````0
M!@``N00``.H#````````R00``%L"``",!````````,0"``"^!0``0@4``'4'
M``#6!0``E`8```````!D!P`````````````;!````````/0#``!4````V0``
M``````!(````E@````````!6`@``-P```"`&```\`@``<P(```````#S`@``
M``````@$``"W`@``I00``'@'````````VP8``!4`````````V00```````#\
M`````````!\%``"+!0``]P$``/<%``!\`P``V08``+0%``"5!0```P4`````
M``````````````````"#!```OP(``,X"```-!P``F0,``/\"````````]`0`
M`#\"``!3`0```````,4$```R`0```````,L"``",``````````````!+`0``
M``````````"[!@``"0$``-X!```F!```I`,``,T%``!S`0``,P0``!$&``"+
M!```8@`````````O````H08``#@"``!9`@``@`<``$@'``"-!0``&0``````
M``"M````[P,``-(&``!\!0``,@```+T%``#*`@```````/<&``"W!@``6P4`
M`$0!`````````````!T"```?!P``W`8````````.!0```````&`!```Y`@``
M0P(``+L!``"``P```````"H!``!&````T`(``!0&````````?P```$(#```V
M!P``+0$``#$$``#A`0```````-(%``"T`@``Z`$``%0#``#X`P``?00`````
M``"B`P``U`(``&(#``#K!0````````````!?````'P(``#(#``#\`@``````
M`',$````````@08``#<%```Z!0``&`0```````!V````HP,```````"7!0``
M8@4``!("``!L`0``(@$```````".`````````&H%````````Q04``!H!``#@
M`0```````),#``"8`````````(4%```8`````````"P%``"&!````````!P`
M``":!@``:08``/L"``"%`0```````$P#``!I!P``>@0``!`$``!E````5`4`
M`,4&``!T`@``X```````````````MP,``'4#````````````````````````
M`````%P!````````.0<``'X"``!L``````````````"(`@```````,\&```+
M`@``#P4``&T!```M`@``X`4``.<"``!/`P``#0$``&````!G`````````,`&
M``#9`@``N@8``````````````````.H```"R!```*``````````P!P``````
M`/,```"J!0``_0$``-4$```:````````````````````8@0```````#)!@``
M8`8``$X`````````$P(`````````````2@0``!8&```C````/P```((%``"H
M!```N`(``)$%``#D````0@0```````"X!0``004``!\!``"X`0```````)L%
M````````M0````('```L!P````````````"P!````````&H'``![!0``9@``
M`````````````````,X$```'`0``6`8`````````````X`8``&$'```[`0``
M.P0``'4"``#L!@``.00``"`'``#^!@``<@8```P!````````2`8``)X&``"\
M!```9@8```D%``!&!P``````````````````<P,``(L```!Z!P``T@,```$"
M``"C`0``+`,```````"S!````````"4'```!`P``ZP(``'````!N!@``V```
M`!(&``!%`P``7@<``/,%``#I!@``T00``#\#````````^P4``&8'``"@!@``
MT@(```````!K`0``T0```(H&```P````R`(``*$$``#L`0``X@```&H"``"F
M`0``7`(````````X`P```````%P&```K!```8`,``.$%````````SP```)8%
M``#8!@``10(`````````````E0$`````````````!P8``$8%``#_!@``````
M`$D#``!L!0``5`<``-,!``"``0````````````````````````````#]!```
M;`0```8$```^`P``'P0``-\$````````7`,``'X$```1`@``+`8``,L$```;
M`P```````'\&``!U````!0,``)$!````````K``````````$`@``>0$``"D$
M```U!P```````'H```!T``````````````!B`0``5`$```T````_`0``W@,`
M`+4&```X!P`````````````F````````````````````B`4``(\$````````
M1@0```$&````````LP```%`!``"1!@``L@$``!8"``!0`@``AP,``&\'``#U
M`@``M@```/,&``#Q`P``40$``.($``#O!````````-`&````````+P(`````
M```,!P``4`````````!4`@```````$P&``"!`@```````!P&````````]`8`
M`(P&``"[````708```````#Y`0``A````$8&````````=0$`````````````
M1`(``$@!```5`P```````"0!``!9`P``]0```)H%``!3!0``W08``#D!```:
M!P```````(@!``!<!0``5P0``$('``":`@``/0,``!$#``"N!0``20$`````
M``"?!````````#X!``!J````?@4``*<#``"H!@``(`````````"N````2P``
M`!(```"F!````0$``'D&````````U0$``+H```#D`P``M@$`````````````
M:`0`````````````O@```+D```!R!````````!$```!?!0``Y@0``"`#``"K
M`0``Y@```"("``"?!@``O0$``/(!```Z!@``@P8```````"!````$@0``+L"
M```]!```?P$``!L```"S`@```````+T#``!U!0``90(``(4`````````S0(`
M`,0&``!_!0```````%<"``"?!0``\`$``*T#````````B@4``'(!``"Q````
M@00```````#P!@```````!$'``!O`@```````.T#````````$`(``!0!```M
M`P``1`0```````#5`P``WP(```````!\!@``204```````#;!0``AP0`````
M``"R!@``]P(``*\$```%`@```````"$```#\!0``=P$``#P#```*!@``]`4`
M`/`"``!Q!0``N`,```````#4`P``Z`(``%D&````````>P0``$$#````````
M*@(``)P%``#&!0``V@4``&$%```````````````'``!Z!0``1P(``#P```"\
M```````````````/`P`````````````0!P``-P8``!0$`````````````&$"
M```(!P``,P,```````!``0``/04```````";!@````````````"'`0``R0``
M`.D#``#D!@``O0```(L!``"]!````````#8#```U`@``'04```````"'!@``
MK@0```<"``#K!```OP,``````````````````$D$``!1!@``M00``',%``#$
M`P```````&L#``#:`0``L`$```````"3!0```````,H&``"B!0````````D#
M``!]`P``$P````T$``#%`0``"P0```````!!`@``50```.,%````````K`,`
M``,#```9!```!@8`````````````Z@0``.P%```*`P``J`4``+<$```6````
M5`0``#<!``!5!0``I`(``/D"````````@`(``",%``#[`P``0P$``&H$````
M`````````#\%```3`0```````/(#``#'!```O@8```````!(`P```````,T#
M``!=!0``?`0``#T&``#Y````'@4``$8!````````JP```%8!``#H!```C0``
M``````#.`P``.`8`````````````RP```(<```#=`P````````````#,!```
M`````%('````````&04```````#G`P``,0```,P#``")!0``$`$```X```!K
M!P``IP```,\$``!B!P``&`8``-H````A`0``H@(``)@"``!>!```+00``",'
M``!E`0``>`(``!0'```=!```V04``)P"``!=`````````.`$``!F!0``/P8`
M`.8"````````L@4````````$`P``'@0```````````````````0%````````
MDP$``(8&``!T`P``KP,``/H&````````D@0``(4"```>!@```````-P#````
M````6P$``%L'```4`P``\0(``#,'``!T!0``J`,``%T!```K!@``````````
M````````KP8``.`#``!.`P``_`0``#H'``!X!````````"\%``!H!@``U```
M`*`"``#Y`P```````"@%``"&!P``[04``'("````````*0`````````&`@``
M``````L'``#E!````````%(&`````````````"<'```"!@```````$8"````
M``````````````#7`0``S0```#<#```$`0```````"L'``!R!P``8P8`````
M``"!!0``;@$``*\"``#$!```+@(``%4$``````````````````"$!0``$P0`
M`)$"``!7!@``T@```*X#``!)!@``-P<``'P'````````T`0``!L%````````
MN@0`````````````@@$`````````````(P(``%H!````````&P<``#('```@
M`@``J`(``"8'````````.@0``(D"``!K````\@8``#D%```\`0``$04`````
M``#E!0``B@```!P!``"K!```B0,```8%````````(@4``%T"````````Z@$`
M``````#Z!````````-\!``!'!0```````!,&``"(````Z0(``#0$``#E`P``
MJP4``,X%``#'`P```````#\$``````````````````#J`@``H0,``/X#```8
M!0``,P```/8%``!W!P```````&\&````````RP,``&\!```>`P``604`````
M``"&````@P$```````"T````CP,``(0$```P!```MP$``)D"``"@!0``M@(`
M`.4"````````,@0``*$````L`@``R`,```L#````````C`4````````;!@``
MK`0``````````````````&L%````````V`$````````.!```"`8````````E
M````X0,``)X``````````````'(%```?!@```````!4!```^!0``'0```,P"
M``">!0``B08``(X"```A!0``E@(```````!`!@``008``*$!``"A!0``)P(`
M````````````+0```$H'``"5`@``4@0`````````````-`(``/@%``!T`0``
M70,``#4!````````3@0``%8%``"B!```"0```,,%``"#`P```````%@!``!I
M`@``[`,``!D"````````P@(``%H'``!#`P``/`0``)`!``#F`0``XP,``%$$
M`````````````*P"```.`@``'`(``$X!``!(!```"@````````!-!@``_`$`
M`"X```"-`0```````"T'``#M`@``Z0$``,\!``!L`@````````````#:`@``
MPP(``"<```"S`P``D@4```````!N````$`````````"-!```&P$``'`$``!V
M!P````,``-\%``!3!P``L@,```<'``"-`P```````(T"``!G`0``@@,``+\!
M``!W!@``;@0``*H```!.`@``9`4```````",`P``+P<``(($````````O`,`
M`#X$```8`@```````#<"``"2`P``@@`````$```````````````````/`@``
M%0(``,(```"[`P```````-$&```P!0``[@```,$%````````2`4``!,'``!9
M!P```@0``%X!`````````````-D!``!*!@``\00``&T&```X!0``.P<``)H!
M``#A````O`(``+X#```6!`````````````"9!0``Z@4``/4#````````0P<`
M`!D#``#L!```E0,```(#```)!@``C@8```````!L!@``8`<``"X!```F!@``
M`````&4&``!I`P```````%\&``"U`P``"@(``$D"```?````#`8``&0!````
M`````````$\"`````````````*8%```Q!@``L0$```T&``#2`0``-04``(8!
M``!<`````````#L&``#F`P``&@4``+L$``"M`@```````(````!Z`P``B`8`
M`,@%``"$!@``W0$``#4#``#O`0`````````````,````E@,``&,"``">`@``
M\@4``````````````````&0$`````````````.D```"V!0``H@8````````>
M`0``P0,``#P&``!P!0``A`$``&L"````````300``.<&````````QP8``(\!
M````````PP```!X'````````8P0``'0'````````#04``#T!``!0!P``;0,`
M`"(&``!$````%@<`````````````V`(``$D````[`P``%P0```````#O````
M:P8````````*!0``4P,```<%```D!0``M@8``*D$```'!```1P$``$0&````
M```````````````@!0```````+````"O````,`8``.\&``#C`````````",&
M```2`P``P00``-H&`````````````'\#```,!```&`,``*P!````````N0$`
M`.,&``#.`````````)(!``!_!P``Q0(```(%````````-`$```````"H````
M+`$```X#````````D`0``!D!``"B````4`4```````#J!@``U0(`````````
M``````````D$``"9`0``FP,``*H!```,`@``U04``/4%``#U`0``#0,`````
M``"=`0``Q0````````#&`@``5P```#@````H`@````````````#]`P``IP0`
M`+L%````````P@4```````!/`0``'0$``.T&``#Y!@``E@0``%`$````````
MK0$`````````````I`$``*D%``"P`@``9`8```````#6`P``%@4``*8#````
M````&@(````%````````AP<``($'``#1!0``XP$``*T&``#C`@``P08``*L"
M``!P`P``D`4``*\!````````TP4``*,&````````M04```````#/!0``;04`
M``````#X`@```````-X&`````````````!\#``!^!P``M`0``*<&````````
MQ`4``*<!``!#````G0,``!L"````````3`0````````"`0``EP(``$\%``!`
M`P``>@8``-P"````````1P<``&,%``"`!@``1`,``.4```!-!0``PP8`````
M``````````````````#0````6P,``+<```!Y`@``0P4```````!3!@``UP4`
M`$H"```]````+04```````![!@``X`(``&`$```:`P``````````````````
MPP0```````#3`P``X@(``'@#``"4````B`<``!H$````````````````````
M````000``!H&`````````````%$'````````*0,``/T```!7`P``````````
M```B!P``40,``#H"``"3````\P$``%4"``````````````X&````````F00`
M``````!"`0``7P(``$L$``!,!P``;@4``+$#````````A`(``$X&````````
M)@$```````#;`0```````+$%``!Q!P``W`0``&D%``"T!@``)P4``#T'``!$
M!P``2@,``&D$``#/`P```````&@"``"O!0``@`0``'8#``#1`P``4`,``)@!
M``#A`@``3`(``,($````````B`0``&P'``!R````````````````````^@(`
M```````R!0``:`,```8'```C`P``?08```````#H`P``EP0``+4!``#+!@``
MSP(``"@!``"7`0``RP$```````!7!P``4P(``%H#``"&!0```````#`"``#X
M````F0````````#,````K@(``#0%````````UP````````"E!0``````````
M````````)08``)D&``#N`0``(0,``#L```"8!@``00$``,8#``",`@``!0<`
M`!4%``!E!0``````````````````(@,``(H"```>````A`<``%8'``"M!0``
M10```'8&```X!```PP$``-0!``!"````900``"@'``!O!0``]@8``%8````.
M`0``^@4``$T"``#^!```6@(``*,%```%!@``Z04``"(```!%!0```````$L&
M``"8!```G`8``,$"```#!`````````````"]!@``;@,``!4&``#N!@``````
M`'T%``#H````-`,``%H%```2!0``#P$``!X"````````:`4````````O`0``
M/0(``$T!```P`0``)0(``-4`````````)04``&8#``#V````>@(``(\&````
M`````````*,"````````K@$``/P#``!A`0``N````)$`````````````````
M``"5````)@,```\``````````````(H#````````?0(``,<%``#&`0``````
M`(8#```A!P``G@$```````#;`@``R0$```H!``!5`P``>0```-0$``##`P``
M`````,H!```3`P``````````````````;@<``/`$``!V!```"`,````````^
M!@``V`0```````"A`@``;0```(\%```8!P```````%@'```J!````@```&`"
M```<!0```````/D%``!.!0```````,@````,`P``BP(```````"E`P``"`4`
M```````Y`P``_P$```\'``!=!```"0(```````!,````F@0``-$!```I!0``
MZ`4```````!X`````````&8!``#P````[P4``$L"``"W!0``!04```````!2
M````ZP,``$L%``#5!@``.0```,@$``"=!0``P`(``%\'```#`0``>`8``$0%
M``#?!@`````````````'````-@4``"L#``#Z````R`8``!4'```#!@``R@``
M`'@!```2`0``]P,``.8%``"K!@``4P0``%(!````````!@,``+D"``!.!P``
M%````)$#``"J`@``7`0``-<$```Z`P``,`,``/0```!`!````````-X"``"Q
M!@````````````#<!0``8@8``,`#``#*`P``[00``%L$``"4`0``B`,``&@'
M``"%!P`````````````3!0``C08``*0$```Q!P``B@$``$,$``";````(08`
M`/("``!U!@````````````"V!````````!`#``#K!@``8`4```````#[!```
ME08``.(%```J!@````````````#W!````````+H"````````M`$``$4&````
M````K@8``%8&```\!0```````$$````V!````````#("`````````04`````
M``".!0``'0,``*<"`````````````%(#```G!@``U`4``/L&````````J`$`
M`&,#```1!`````````````!4!@``)P$``+,%````````Y@8``-,"````````
MAP4``(,"``"Y!@``6`,``($!````````[@0``"0"``#3!@```````#4```"\
M!@``R0(``*D#``!9`````````#$!````````X08``+,&```+!0``10$``%L&
M``"X!```-@8```````!:!@```````&0````D!@``QP(```````"=````_P``
M``4!``!``@``B00``&D```#8!0``(`$``)X$````````D@(``!0%````````
M.@$``-`%````````%@$```````!X!0``QP```,P&`````````````%X%```C
M!```]@,``"H%``#G````P`0``*H&```=!@``2@$``#(&`````@``9P,``-X$
M```V`@````````````#[````K`8``)8&``!1`@```````#,&````("@E<R!D
M87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A
M>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI`"!A="``(B5S(B!I<R!N;W0@
M82!D:7)E8W1O<GDN`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B
M(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S
M(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@
M=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M
M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR
M9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD
M("5S`"5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"UD
M87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`
M)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3
M971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E
M861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@:7,@<F5A9'D@=&\@<&5R9F]R
M;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#
M:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O
M('!E<F9O<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU
M=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S
M($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES
M=``E<SH@)7,`)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO
M;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@86YY(&QI
M;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY
M('!E<G-O;F%L(&EN9F]R;6%T:6]N+@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E
M<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R
M($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U
M<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO
M8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A
M9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!
M('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@
M4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3
M34E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-
M($-L;W5D<P!!32!,:6=H="!286EN`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3
M;F]W(%-H;W=E<G,`04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R`$%B
M;W5T+BXN`$%B<V)O='1O;0!!8G-M:61D;&4`06-C97-S(&1E;FEE9"!C<F5A
M=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&
M4R!F:6QE+@!!8V-O=6YT($EN9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`
M06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U
M<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U
M<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S
M(@!!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O("(E<R(`061D(&$@;F5W('5S
M97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T
M:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D<F5S
M<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D
M("(E<R(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I
M;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H
M92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`061D:6YG('5S97)S(&ES
M(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@
M<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO
M;@!!9',`069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N
M`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'
M<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU
M;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES
M="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!
M;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M
M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S
M`$%L=&5R;F%T92!T97AT.@!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A
M;'5E('=A<R!S<&5C:69I960N`$%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R
M960N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!
M;G-W97(`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T
M:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P
M<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`
M07!R:6P`07)A8FEC("A7:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE
M`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E
M('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@9&5L971E("(E<R(@86YD(&%N>2!S=6(M9W)O=7!S/P!!<F=E
M;G1I;F$`07)M96YI80!!<FUE;FEA;B`H05)-4T-)22TX*0!!<G0`07)U8F$`
M07-C96YS:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO
M;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N="!C;VQU;6YS`$%T=&5M<'0@=&\@
M9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T
M92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@
M82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@
M;F]N+65X:7-T96YT('-H87)E+@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L
M:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA
M=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D
M(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D
M($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H
M92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-
M05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K
M<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@061D:6YG('5S
M97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T
M:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!
M8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E
M<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A
M<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE
M('1O('5P9&%T92!U<V5R("5S`$%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@
M:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2X`075T:%]M
M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N`$%U=&AE
M;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U
M=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE
M;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO
M;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N`$%V86EL86)L92!F:65L9',Z
M`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N
M9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U
M<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I
M`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@
M(B5S(B!N;W0@9F]U;F0N`$)A<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"96QI
M>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0FQO8VL@(B5S(B!O
M9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`
M0FQO8VL@5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D
M97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`
M0F]T:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I
M=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M
M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`
M0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T
M:65S+BXN`$-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N`$-A;&5N9&%R
M`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S=V]R
M9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`
M0V%N(&YO="!W<FET92!T;R!F:6QE("(E<R(`0V%N)W0@861M:6YI<W1E<B!E
M>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+@!#86XG="!C;VYN96-T('1O($E-
M05`@<V5R=F5R.B`E<P!#86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N861A`$-A
M;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE
M("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N
M;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#
M86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E
M9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E
M;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU
M;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE
M9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#87)R:65R`$-A=&5G;W)I
M97,@86YD($QA8F5L<P!#87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E;&P@
M4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL
M('-P86-I;F<Z`$-E;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT
M97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E86X@
M*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@
M3W=N97(`0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E
M(%EO=7(@4&%S<W=O<F0`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H
M870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U
M<B!E;6%I;',N`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O
M<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("!#;VYT86-T
M('EO=7(@861M:6YI<W1R871O<BX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EL
M90!#:&EN80!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4
M<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E($%P<&QI8V%T:6]N.@!#:&]O<V4@
M82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I
M<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E
M<F5D(&QI<W1S*0!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@
M;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L
M96%R(%%U97)Y`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R
M('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L:6-K('1O($-O;G1I;G5E`$-L
M:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9',@
M16%R;'D`0VQO=61Y`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E
M(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L
M;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE
M<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N
M($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;7!U=&5R<P!#;VYD:71I;VX`0V]N
M9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R871I
M;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T
M;&]O:RX`0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E
M("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A
M=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C
M=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI
M8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10
M('-E<G9E<B!F86EL960N`$-O;G1A8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT('1Y
M<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT
M:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!F86EL960Z("5S
M`$-O<'D@<V5L96-T:6]N`$-O<W0@240`0V]S=&$@4FEC80!#;W1E(&0G279O
M:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B``0V]U;&0@;F]T
M(%!'4"!S:6=N(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@
M;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD
M(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S
M97)V97(N`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@
M8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-O;FYE8W0@=&\@
M<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T
M83H@`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@
M9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@(B5S(BX`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT
M)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A
M9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB
M=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T
M(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R871E
M9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A
M:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O
M<&5N("(E<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L
M9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N
M;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T(')E86-H('1H92!,
M1$%0('-E<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E
M="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O
M<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A
M:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@
M9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO
M="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I
M<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E
M<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I
M;VXN`$-O=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C
M;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U
M871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@
M)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E
M<R(N`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F
M:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS('1O
M('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H
M92!C;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0
M('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D
M871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B
M)7,B.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA
M:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S
M97(@(B5S(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B
M)7,B.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#
M<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD
M97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R
M;V%T:6$`0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@4V5S<VEO;G,`
M0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@57-E<G,`0W5R
M<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL
M90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U
M=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I
M;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M
M52D`0WIE8V@@4F5P=6)L:6,`1$0`1%-.("AS964@:'1T<#HO+W!E87(N<&AP
M+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN
M<&AP*0!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&%B87-E($QO;VMU<`!$
M871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@
M0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E
M;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F
M875L="!3:&5L;`!$969I;FET:6]N<P!$96QE=&4`1&5L971E($-E;&P`1&5L
M971E($=R;W5P`$1E;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`1&5L971E
M(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN
M`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E(&UE
M<W-A9V5S`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R
M;6ES<VEO;G,@9F]R("(E<R(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E
M;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!S=6(@
M9F]L9&5R<P!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@
M8W5R<F5N="!R;W<`1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="`B)7,B
M+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S8W)I8F4@=&AE(%!R;V)L96T`
M1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I
M.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A
M=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T
M(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$
M:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH
M;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A:6QE9"!F
M;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T
M`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N;W0@9&5L
M971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O
M97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@
M>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B
M;&EC`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W;FQO860`
M1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@
M87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$5-
M86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H
M('!R;W9I9&4@=&AI<R!S97)V:6-E+@!%4E(`16-U861O<@!%9&ET`$5D:70@
M0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S
M:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R
M.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@
M9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN
M`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@
M;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'
M871E=V%Y`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N
M`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E
M<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@
M8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%
M;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S
M:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@
M)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM
M86=E(%523"!H97)E`$5N=&5R('1H92!L971T97)S(&)E;&]W.@!%<75A=&]R
M:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R(&-R96%T:6YG(&)L;V-K
M.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,`17)R;W(@9&5L
M971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,`
M17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S`$5R<F]R('=I=&@@96UA:6P@
M;65S<V%G92X`17)R;W(@=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA
M`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T
M97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G
M:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E
M<SH`17AE8W5T90!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP96-T960@)RDG
M`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP
M:7)A=&EO;B!$871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@
M<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T
M;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T
M;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE
M9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@
M8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O
M(')E=')I979E.B`E<P!&86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S
M*0!&87)O92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&87@`1F%X97,`1F5B<G5A
M<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N
M;W<@4VAO=V5R<P!&:65L9"!M871R:7@`1FEG;&5T($-!4%1#2$$`1FEG;&5T
M(&9O;G0`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N
M=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C
M=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`
M1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@
M<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T
M`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P
M;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E
M('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@
M86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I
M;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&
M;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M
M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI
M=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U
M=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP
M=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$=A8F]N`$=A;&QE<GD@=&\@=&%K
M92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E<R!#;VYF
M:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!':&%N
M80!':6)R86QT87(`1VEV96X@3F%M90!';&]B86P@3W!T:6]N<P!';P!';V5D
M96P`1V]O9VQE($UA<',`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E96-E
M`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!
M9&UI;FES=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'
M<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED.B``1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E
M;&5T92!G<F]U<"`E<P!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R
M;W5P("5S`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N
M<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A
M+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A
M8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O
M=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(87IE`$AE861E<@!(96%D97)S
M`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96%V>2!4+5-T
M;W)M`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S
M:6YG(&5D:71O<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I
M;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC
M86X@0VET>2!3=&%T92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O
M<GD`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O
M2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S
M<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T
M;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S
M(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL
M>2!R96UO=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO
M;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O
M<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@
M(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%
M($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5
M;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@
M<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L
M96%S92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME
M('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R
M93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M
M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB
M;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@
M9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D
M.B`E<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@
M061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C
M:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)
M8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I
M='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@
M)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S
M964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y
M(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS
M<&%R96YC>2X`268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E
M+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L
M87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%52
M3`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A
M;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM
M<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W
M($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T
M('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE
M(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!)
M;F-R96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S
M:6$`26YF;P!);F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@879A
M:6QA8FQE+@!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS
M97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O
M<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`
M26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN
M<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A
M(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A
M9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A
M<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T
M96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@
M8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T
M97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS
M97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A
M9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O
M=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D
M(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I
M9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D
M:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC
M:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@541(
M+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV86QI
M9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A
M('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A
M;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS92!K97DN`$EN=F%L:60@
M;&]C871I;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@
M;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T
M97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!A<G1N
M97(@:60N`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED('!R;W1O8V]L
M+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H87)E(&]B:F5C
M=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T
M82X`26YV96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`27)A;BP@27-L86UI8R!2
M97!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T960@
M5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*
M86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO
M<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y
M($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+
M965P(&]R:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@
M875T:&5N=&EC871I;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+
M97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`
M2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+
M:61S`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B
M;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W
M86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@
M1&5M;V-R871I8R!297!U8FQI8P!,87-T($AA;&8`3&%S="!087-S=V]R9"!#
M:&%N9V4`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@
M)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,
M871V:6$`3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE
M8F%N;VX`3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QE
M=F5L`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T
M96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY
M`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN
M('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI
M;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D
M9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN
M:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E
M<@!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S
M`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI
M<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I
M;F<@<V5S<VEO;G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@
M)7,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H
M=6%N:6$`3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE
M`$QO8V%T:6]N`$QO9R!I;@!,;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N
M`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U
M<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O
M<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W
M97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O
M;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H
M;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@
M5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA
M9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA
M>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C
M871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C
M;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T
M(&UA<`!-87!1=65S="!M87``36%P<&EN9W,@<W1O<F5D+@!-87)C:`!-87)G
M:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE
M<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES
M;&%N9',`36%R=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-
M875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T
M<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP
M(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C
M:W,`36%X:6UU;2!L96YG=&@`36%Y`$UA>6]T=&4`365D:6-I;F4`365M8F5R
M<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!697)I
M9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T
M92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`365S
M<V%G92!T>7!E`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL
M86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E
M(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T87)$0B!I
M<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`365T:&]D("(E<R(@:7,@;F]T(&1E
M9FEN960`365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<P!-
M971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`
M36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN
M('1E;7`@;&%S="`V(&AO=7)S.B``36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S
M(&YO="!Y970@97AP:7)E9`!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG
M(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A
M=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT
M('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N
M`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@
M<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69I960@
M1&%T90!-;V1I9GD@55),`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`
M36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E
M<G)A=`!-;V]N(%!H87-E<P!-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D
M('1H86X@=&AE(&5X<&5C=&5D("5D+@!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-
M;W-T;'D@0VQO=61Y`$UO<W1L>2!#;&]U9'D@86YD(%=I;F1Y`$UO<W1L>2!3
M=6YN>0!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-
M;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@
M9&]W;B!L:7-T<P!-=6QT:6UA<"!52R!M87``375L=&EP;&4@<V5L96-T:6]N
M`$UY($%C8V]U;G0`37D@06-C;W5N="!);F9O<FUA=&EO;@!->2!0;W)T86P`
M37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.
M86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N
M9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V
M;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!2
M96YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!3
M4TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.
M971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A
M;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($UO;VX`3F5W(%5S97)N86UE("AO
M<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R
M9"!W:6QL(&5X<&ER92!O;B`E>"X`3F5W('!A<W-W;W)D<R!D;VXG="!M871C
M:"X`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.
M97AT(#0@4&AA<V5S`$YE>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG
M97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO(&%V86EL86)L92!C;VYF:6=U
M<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL
M86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H
M('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P
M;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U
M=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A
M9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I
M;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI
M960N`$YO(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T
M:6]N(&ES('-E="X`3F\@;&]C871I;VX@<')O=FED960N`$YO(&UE<W-A9V4@
M<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF
M:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T
M:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,
M(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T
M82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!Q=6]T82!S970N`$YO(')U;&5S
M`$YO('-E<&%R871O<B!S<&5C:69I960N`$YO('-I9&5S`$YO('-U8V@@9FEL
M90!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N
M`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!8
M34P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I
M;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R
M871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N
M+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N92`H=7-E(&EM
M<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.
M;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.
M;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO
M="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.
M;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R`$YU
M;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O
M9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@
M9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/
M8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@86YD(&YE
M=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P87-S=V]R9`!/
M;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`3VYL>2!)34%0('-E
M<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O9F9E;G-I=F4@
M9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY
M('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E
M(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/
M<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@
M97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/<&5N<R!T
M:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T
M:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N
M`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L
M:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T
M:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A
M=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!014%2.CI-86EL(&)A
M8VME;F0`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T
M80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(
M4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-(%)A:6X`4$T@4VAO
M=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!3=6X`4$T@5"U3=&]R
M;7,`4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<`4%](4"!3:&5L;`!0861D
M:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C
M=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R=&QY
M($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL
M>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2
M041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T
M:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H
M+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG
M;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R
M871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I
M;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E
M<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN
M:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL
M:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L871I='5D
M97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M
M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT
M+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT
M97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@
M82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E
M+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A
M<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U;6UA
M<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA
M;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X
M="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S
M>7-T96TN`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`4&]L
M86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H
M:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O('1H
M:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E8VEP:71A=&EO
M;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A=&EO;CQB<B`O/F-H
M86YC90!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS
M:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L
M.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@
M;F5W('=I;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R
M:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T
M<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM
M`%!U8FQI8R!+97D@26YF;P!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G
M96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!0=7)G92!M97-S
M86=E<P!1871A<@!1=65R>0!1=6]T80!24T$@4'5B;&EC($ME>2`H)60@8FET
M*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!2
M86EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@
M1F]R='5N90!2871I;P!296%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T
M92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY
M(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N
M(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E
M9G)E<V@`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@
M4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;&]A
M9`!296UA<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W
M=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E
M;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M
M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E
M8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D
M;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S="!C
M;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q
M=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+@!297%U:7)E9"`B
M)7,B(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER
M960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!2
M97%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BX`
M4F5Q=6ER960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U
M<B!087-S=V]R9`!297-T;W)E($QA<W0@475E<GD`4F5S=6QT<P!2971U<FX@
M=&\@3W!T:6]N<P!2971Y<&4@;F5W('!A<W-W;W)D`%)E=6YI;VX`4F5V97)T
M($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9&1L
M97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E
M<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE9G0`
M4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O
M=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@
M86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS
M(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N
M`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T;V=R87!H
M:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U
M=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`
M4U%,(%-H96QL`%-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',`4U-(
M`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@2VET
M=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ
M=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M92!F
M<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R
M:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`4V%V90!3
M879E("(E<R(`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@
M8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G
M<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N
M+@!3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`4V-A='1E
M<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E
M;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D
M9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A
M('5S97(@=&\@861D`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D871E(&-O;7!O
M;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&YO;F4`4V5L96-T('1H
M92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9
M;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT
M(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@
M9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@
M8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE
M('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L
M96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N96=A
M;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E
M<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L
M92X`4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N`%-E<W-I;VYS
M`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P
M87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@
M<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R
M=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N
M9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL
M(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES
M<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP=',@879A
M:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A
M<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3
M:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`
M4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D
M(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@
M;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I;VX@
M=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A8FQE(&]P97)A
M=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_
M`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T
M:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W
M(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@
M9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W
M97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAR:6YK`%-H<FEN
M:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A
M>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`4VEG;F%T
M=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT96YA;F-E
M`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3:&]W
M97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T90!3;F]W
M(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO;B!)
M<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&]R9&5R('-E;&5C
M=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E
M86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!3
M86YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T
M=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD
M(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A
M9&1I;F<`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&QI
M="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK
M80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V
M:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R
M:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@
M861D<F5S<P!3='EL92!;0U-370!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@
M9F]U;F0N`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D
M9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL
M('EO=7(@<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U
M8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`
M4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@
M=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S
M<V9U;&QY(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F
M=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H
M86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO
M;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO
M;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F
M=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`
M4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T
M`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M
M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I
M='IE<FQA;F0`4WEN8R!L;V<@9&5L971E9`!3>6YC34P`4WEN=&%X(&5R<F]R
M(&EN('-E87)C:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T;W)M
M`%0M4W1O<FT@86YD(%=I;F1Y`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY`%13
M5B!F:6QE`%1A8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@4V5T`%1A8FQE
M('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`
M5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E
M=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z
M(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R("\^
M*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U
M;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E
M>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4
M:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&ES=&]R
M>2!S>7-T96T@:7,@9&ES86)L960N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A
M=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H92!)35-0(&QO
M9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N`%1H92!-86EN=&5N86YC93HZ
M(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@
M=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R
M(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B
M86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O
M='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@
M<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE
M(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D
M('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA
M='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M
M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N
M;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@
M9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I
M9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R
M92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@
M82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE
M("5S('-E='1I;F=S+@!4:&4@9FEL92!C86YN;W0@8F4@8V]P:65D(&]N=&\@
M:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&QO
M=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@
M;65S<V%G92X`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U
M<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R
M;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD
M+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K
M(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R
M87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R
M>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO
M;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N
M('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T
M;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE(&ED96YT:71Y("(E
M<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`
M5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E
M;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S86=E('-E;G0@
M;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES<&QA
M>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA
M<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H
M96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!N=6UB97(@;V8@
M9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`5&AE(&]P96YS<VP@;6]D=6QE(&ES
M(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`
M5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S
M92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ
M90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S
M*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!Q=6]T92!C:&%R
M86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE(')I9VAT
M(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY
M`%1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`
M5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@
M(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O<B`E
M<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O
M97,@;F]T(&5X:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO
M="!E>&ES="X`5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T
M:&4@=&5X="!O;B!T:&4@<V-R965N+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED
M97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W
M87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D
M(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO
M8VL@:7,@;F]T(&%V86EL86)L92X`5&AE;65S(&1I<F5C=&]R>2`B)7,B(&YO
M="!F;W5N9"X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R
M92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`
M5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@
M66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E
M<B!L97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("(E
M<R(@=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A
M<FEN9R!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE
M<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E
M;3H@`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S(CH@)7,`5&AE
M<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@
M=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I
M;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M
M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M
M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA
M;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T
M:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6X@
M=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@
M82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI
M;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S
M92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO
M;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&ES($E-05`@<V5R
M=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES
M(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES
M(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T
M:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y
M+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC
M+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E
M;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H
M92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E
M=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N
M(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W
M=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD
M(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@
M;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S
M="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G
M97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F
M:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X
M(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S
M(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@
M82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T
M('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N
M9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@
M<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A
M9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@
M=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O
M;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP
M(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N
M`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S
M="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I
M8VME=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L
M96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`
M5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R
M;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`
M5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O
M=P!4;VYG80!4;V\@;6%N>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA
M<W0@;6EN=71E<RX`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871I;VYS
M`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA
M`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R
M:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E
M.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV
M97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@
M=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@
M=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C
M:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE
M('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O
M9B`B)7,B+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R\E<R(N
M`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C
M;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA
M8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C
M<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL
M92X`56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T
M;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S
M(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L
M92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N
M86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E
M(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D
M96QE=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R
M96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D
M:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I
M;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L
M92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA
M8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S
M960@87)C:&EV92X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE
M*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53
M:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@9FEL93H@`%5N86)L92!T
M;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M
M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S
M`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E
M;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES
M;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET
M92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!6
M1E,@9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A
M('=I;&P@8F4@97AC965D960N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD
M;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M
M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F
M<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E
M9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`
M56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N
M:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN
M;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@;&]C
M871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N
M`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV:6QE
M9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G
M<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T
M;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S
M:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@
M8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`
M57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P
M9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P
M;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T
M:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U
M<G)E;G0Z("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF
M9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R("5S(&ES(&YO="!A
M=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P
M=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S
M(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<B!A8V-O=6YT(&YO
M="!F;W5N9`!5<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S
M+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5
M>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T
M:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`
M5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=64@:7,@;W9E<B!T:&4@
M;6%X:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E<P!686QU97,@=&\@<V5L96-T
M(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N
M(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D
M('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N
M`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA
M;0!6:65T;F%M97-E("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA
M;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H
M`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@
M`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/
M5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=)3B!V:6$@2%144`!786QL
M:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A
M=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET
M90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E
M<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T
M97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y
M(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R
M/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H97)E:7,@075S=')A
M;&EA(&UA<`!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@
M9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!I;B!#4U,@
M=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S
M(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7
M:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P
M965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5VES:&QI<W0`5V]R
M:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7<F]N9R!N=6UB97(@;V8@9FEE
M;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@
M;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N
M9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+@!8+5)E9@!8
M-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D($ME>2!5
M<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3
M=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E9
M65D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@22!!9W)E90!9
M;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@
M<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@86QL;W=E9"!T
M;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RX`66]U(&%R92!N;W0@875T
M:&5N=&EC871E9"X`66]U(&-A;FYO="!H879E('1H92`G7"<@8VAA<F%C=&5R
M(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED
M(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O
M;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L
M9',@:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL
M>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@
M9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L
M=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@
M=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD
M+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A
M;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE
M(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C
M="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A
M('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S
M97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA
M;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U
M<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R
M;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W4@;F5E
M9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R`%EO=7(@)7,@
M<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R
M($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R
M;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC
M92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C
M="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!.
M86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P
M;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@=7-E($AO<F1E('1O
M(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF
M9F5R96YT(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0N`%EO=7(@875T:&5N=&EC
M871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L
M(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T
M:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N
M9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4
M;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN
M+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N
M`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T
M:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R:6YT+@!9;W5R
M(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S
M(&)E96X@8VAA;F=E9"X`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U
M;&P@;F%M93H`66]U<B!L;V=I;B!H87,@97AP:7)E9"X`66]U<B!N97<@<&%S
M<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P
M9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@
M8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C
M:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R
M9"X`66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"X`66]U<B!R96UO=&4@<V5R
M=F5R<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`
M6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O
M=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN
M92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4<F5E`%]$
M96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`
M7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E
M<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4V5T=7``7U1A8FQE(%!R;W!E
M<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!A9&1R97-S964@=6YK;F]W
M;@!C86QE;F1A<@!C86QM`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4`8V%N
M;F]T(&]P96X@:6YP=70`8VQI8VL@:&5R90!C;VUM86YD(&QI;F4@=7-A9V4@
M97)R;W(`8V]N9FEG=7)A=&EO;B!E<G)O<@!C<FET:6-A;"!S>7-T96T@9FEL
M92!M:7-S:6YG`&1A=&$@9F]R;6%T(&5R<F]R`&5D:70`96YT<GD@;F]T(&9O
M=6YD`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&=U
M<W1I;F<`:#H`:&@`:&]S="!N86UE('5N:VYO=VX`:6UM961I871E`&EN;&EN
M90!I;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A<F4@97)R;W(`
M;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/
M+@!M;0!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D
M`&YO=&5P860`<&5R8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5M
M;W1E(&5R<F]R(&EN('!R;W1O8V]L`')I<VEN9P!S97)V:6-E('5N879A:6QA
M8FQE`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-S`'-T
M96%D>0!S>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E
M`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U
M;FYA;65D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE
M8W0M260M5F5R<VEO;CH@2&]R9&4@,RXQ+6-V<PI297!O<G0M37-G:60M0G5G
M<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@
M,C`P-BTP,BTR-R`Q.3HU,2LP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M
M,#(M,C0@,3(Z-3DK,#(P,`I,87-T+51R86YS;&%T;W(Z($QE96YA($AE:6YO
M(#QL:6EN=4!U=&$N9FD^"DQA;F=U86=E+51E86TZ($9I;FYI<V@@/&DQ.&Y`
M;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y
M<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,0I#;VYT96YT+51R
M86YS9F5R+45N8V]D:6YG.B`X+6)I=`H`("@E<R!PY&EVY.0@<VET=&5N*0`@
M*%!I:V%NY'!PY&EN("5S*0`@*"5S('#D:7;D<W/D*0`@*'3D;N3D;BD`("AH
M=6]M96YN82D`("AE:6QE;BD`(``B)7,B(&5I(&]L92!H86ME;6ES=&\`(B5S
M(B!E:2!K96QP86$@=F%L:6YN86MS:2X`(B5S(B!E:2!O;&4@87-E;FYE='1U
M($AO<F1E;B!R96MI<W1E<FES<^0N`"(E<R(@<'5I9&5N(&MU=F%A:F%A(&5I
M(&SV>71Y;GET+@`B)7,B(&QI<^1T=&EI;B!R>6AMY&KD<FIE<W1E;&WDY&XN
M`"(E<R(@;&ESY'1T:6EN(&]I:V5U:W-I:6XN`"(E<R(@96D@;'5O='4Z("5S
M+@`E+C)F34(@:^1Y=&5T='D@)2XR9DU"('-A;&QI='5S=&$@*"4N,F8E)2D`
M)60@)7,@:F$@)7,`4V%L87-A;F%S:2!V86YH96YT=74@)60@<.1I=N1N('#D
MY'-TY"X`)60@<.1I=N1N(&5N;G5S='5S`"5S("T@26QM;VET=7,`)7,@4V]R
M;65N:N1L:VD`)7,@2T(`)7,@66QLY'!I=&]T;VEM96YP:71E970@+2!687)M
M:7-T=7,`)7,@87-E;FYU<P`E<R!K:7)J875T=6UI;F5N`"5S(&OD>71T]F5H
M9&]T`"5S(&]N(&IO(&]L96UA<W-A+@`E<R!S=75N=&$@)7,@)7,`)7,@;VX@
M=F%L;6ES('-U;W)I='1A;6%A;B!Y;&SD<&ET;W1O:6UE;G!I=&5I=.0N(%9A
M;&ET<V4@=F%L:6YT87)U=61U:7-T82!S=6]R:71E='1A=F%T('1O:6UE;G!I
M=&5E="X`)7,@;VX@<&%K;VQL:6YE;@`E<R!M:6YU=71T:6$`)7,@96D@;/9Y
M='EN>70N`"5S("T@)7,@+R`E<P`E<SIN(&]S;VET96MI<FIA`"5S.FX@:V%L
M96YT97)I`"5S.FX@;75I<W1I;&ES=&$`)7,Z;B!T96ATY';D;&ES=&$`)7,Z
M("5S`"5S(#H@5.1MY"!V:65S=&D@96D@;VQE(';D;'1TY&WD='3D('-I;'3D
M(&SD:&5T=.1JY&QTY"P@:F]K82!O;B!M97)K:71T>2!LY&AE='3D:N1K<VDN
M(%-U:'1A=61U('9A<F%U:W-E;&QA('9I97-T:7-SY"!O;&5V:6EN(&QI;FMK
M96EH:6X@:F$@=F%R;R!A;G1A;6%S=&$@;.1H971TY&KD;&QE(&UI=.3D;B!Y
M:W-I;/9I=FGD('1I971O:F$N`"P@<'5U<VMI='1A:7-T80`L('!U=7-K:71T
M86ES=&$@)7,@)7,`+"!V86EH=&5L979A82`E<R`M("5S`"TM('9A;&ET<V4@
M+2T`,3(M='5N;FEN(&KD<FIE<W1E;&WD`#(T+71U;FYI;B!JY')J97-T96QM
MY``R-"!T=6YT:6$`/$5D96QL:6YE;@!4:65T;VMA;G1A=&%U<W1A:N1R:F5S
M=&5L;>3D(&5I(&]L92!MY.1R:71E;'1Y('3D;&QE(&]S:6]L;&4`5&%P86AT
M=6D@=F%K879A('9I<FAE`%9I97-T:6X@<V%L875K<V5E;B!T87)V:71A86X@
M:G5L:VEN96X@4$=0+6%V86EN+@!!;&QE:VER:F]I=&5T=6X@=FEE<W1I;B!T
M87)K:7-T=6MS965N('1A<G9I=&%A;B!J=6QK:6YE;B!01U`M879A:6XN`%-A
M;&%T=6X@=FEE<W1I;B!A=F%A;6ES965N('1A<G9I=&%A;B!J=6QK:6YE;B!0
M1U`M879A:6XL('-A;&%I;F5N(%!'4"UA=F%I;B!J82!S86QA<V%N871E:W-T
M:2X`5FEE<W1I;B!A;&QE:VER:F]I='1A;6ES96MS:2!T87)V:71A86X@:G5L
M:VEN96X@4$=0+6%V86EN+"!S86QA:6YE;B!01U`M879A:6X@:F$@<V%L87-A
M;F%T96MS=&DN`%9I97-T:6X@879A86UI<V5E;B!T87)V:71A86X@:G5L:VEN
M96X@4R]-24U%+6%V86EN+"!S86QA:6YE;B!3+TU)344M879A:6X@:F$@<V%L
M87-A;F%T96MS=&DN`%9I97-T:6X@86QL96MI<FIO:71T86UI<V5K<VD@=&%R
M=FET86%N(&IU;&MI;F5N(%,O34E-12UA=F%I;BP@<V%L86EN96X@4R]-24U%
M+6%V86EN(&IA('-A;&%S86YA=&5K<W1I+@!6:65S=&EN('-A;&%U:W-E96X@
M=&%R=FET86%N(&IU;&MI;F5N(%--24U%+6%V86EN+@!!32!0:6QV:>0`04T@
M:V5V>71TY"!S861E='1A`$%-('-A9&4`04T@<V%T96ET80!!32!L=6UI<V%T
M96ET80!!32]030!!4$D@240`5&EE=&]J82!E9&ET;W)I<W1A`%1I971O:F$N
M+BX`06)S+B!A;&EN`$%B<RX@:V5S:V5L;.0`4VEN=6QL82!E:2!O;&4@;VEK
M975K<VEA(&QU;V1A(%9&4RUH86ME;6ES=&]A+@!3:6YU;&QA(&5I(&]L92!O
M:6ME=6MS:6$@;'5O9&$@5D93+71I961O<W1O82X`2^1Y='3D:N1T=6YN=6MS
M96X@=&EE9&]T`$OD>71TY&KD='5N;G5K<V5N('-A;&%S86YA`$OD>71TY&KD
M=&EL:2!S=6QJ971T=2X`2VER:F%N<&ET;P!,:7/DY`!,:7/DY"!A;&ER>6AM
MY`!,:7/DY"!A;&EO:6ME=7,`3&ESY.0@=.1HY&XZ`$QI<^3D('5U<VD@<GEH
M;>0`3&ESY.0@=75S:2!O:6ME=7,`3&ESY.0@86QI<GEH;>0@<GEH;>3D;B`B
M)7,B`$QI<^3D(&%L:6]I:V5U9&5T("(E<R(`3&ESY.0@=75S:2!KY'ET=.1J
MY#H`3&ESY.0@<V%R86ME`$QI<^3D('5U<VEA(&KD<V5N:>0`3&ESY.0@<&%R
M:0!,:7/DY"`E<R!V86QI:VMO($UO>FEL;&%N(%-I9&5B87(@;W-I;V]N`$QI
M<^3D(&]S;VET96MI<FIA86XZ`$QI<^3D(&]S;VET96MI<FIA86YI.@!,:7/D
MY"!KY'ET=.1JY`!,:7/D='1I:6X@(B5S(B!JY')J97-T96QMY.1N+"!M=71T
M82!E:2!V;VD@;&ESY'3D('-I<^3D;FMI<FIA=71U;6ES<'EY;F[V;B!L:7/D
M=&EE=&]J83H@)7,N`$QI<^1T=&EI;B`B)7,B(&KD<FIE<W1E;&WDY&XN(%9O
M:70@;GET(&MI<FIA=71U82!S:7/DY&XN`$OD>71TY&II96X@;&ESY.1M:6YE
M;B!O;B!E<W1E='1Y+@!/<V]I=&4`3W-O:71E:VER:F$`5F]I(&%S971T86$@
M=&%I(&WDY')I=&5L;.0@;VEK975K<VEA('1O:7-I;&QE(&OD>71TY&II;&QE
M`%EL;.1P:71O`$UA:6YO:W-E=`!!9F=A;FES=&%N`$%L8F%N:6$`06QG97)I
M80!!;&EA<P!487-A80!487-A=7,Z`$MA:6MK:0!+86EK:VD@875T96YT:6MO
M:61U="!KY'ET=.1JY'0`2V%I:VMI(')Y:&WD=`!+86EK:VD@;VEK975D970`
M2V%I:VEL=&$@;F5L:N1L=.0@<VEV=6QT80!386QL:2!M;VYE="!O<V]I='1E
M970`4V%L;&D@:N1R:F5S=&5T>6X@;&ES=&%N('1Y>7!I;B!A<V5T=7,N`$]N
M(&IO(&]L96UA<W-A`%9A:6AT;V5H=&]I;F5N($E-4U`M<VESY.1N:VER:F%U
M='5M:6YE;@!686EH=&]E:'1O:6YE;B!)35-0+7-A;&%S86YA`%9A:6AT;V5H
M=&]I;F5N($E-4U`M:^1Y='3D:N1T=6YN=7,`5F%I:'1O96AT;VES970@<^1H
M:_9P;W-T:6]S;VET=&5E=`!686EH=&]E:'1O:7-E="!M86QL:70`5F%I:'1O
M96AT;VEN96X@=&5K<W1I.@!9:&1Y<W9A;'1A:6X@4V%M;V$`06YN971T=2!A
M<G9O(&5I(&ME;'!A82X`=&%P86AT=6D@='5N=&5M871O;B!V:7)H92X`06YD
M;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEY;6D@<')O>'D`5F%S=&%U<P!!
M;G1A<FMT:7,`06YT:6=U82!J82!"87)B=61A`$]H:F5L;6$`3VAJ96QM86QI
M<W1A`$]H:F5L;6$@;VX@=F%L;6ES+@!,86ET82!KY'ET=/;V;B!K86EK:VD@
M86QI:F%K;VEH:6X`2'EVY&MS>0!!<G9I;VET=2!K;VMO`&AU:'1I:W5U`$%R
M86)I82`H5VEN9&]W<RTQ,C4V*0!086ME=&EN(&MO:V\`4&%K971I;B!N:6UI
M`$]L971K;R!V87)M82P@971TY"!H86QU870@<&]I<W1A82!S:7/DY&YK:7)J
M875T=6UI<W!Y>6YN]FX@)7,@/P!/;&5T:V\@=F%R;6$L(&5T=.0@:&%L=6%T
M('!O:7-T86$@(B5S(B!J82!K86EK:VD@<V5N(&%L:7)Y:&WD=#\`06=E;G1I
M:6YA`$%R;65N:6$`07)M96YI82`H05)-4T-)22TX*0!486ED90!!<G5B80!!
M<V-E;G-I;VX@<V%A<F5T`$%S8VEI+71A:61E`$%S:6%N+U1Y>6YE;FUE<F5N
M(&%L=64`2WES>2!V87)M:7-T=7,@96YN96X@:W5I;B!T96ADY.1N('EL;.1P
M:71O=&]I;65N<&ET965T+@!496ATY';D<V%R86MK965T`%ER:71E='1I:6X@
M<&]I<W1A82!O;&5M871O;G1A(')Y:&WDY"X`67)I=&5T=&EI;B!P;VES=&%A
M(&]L96UA=&]N=&$@;VEK975T=&$N`%ER:71E='1I:6X@;75O:V%T82!O;&5M
M871O;G1A(&]I:V5U='1A+@!9<FET971T:6EN(&UU;VMA=&$@;VQE;6%T;VYT
M82!J86MO82X`3&ESY&WDY')I='EK<V5T`&5L;VMU=0!!=7-T<F%L:6$`273D
M=F%L=&$`075T:%]C>7)S<6PZ(%1A<G9I='1A=F%A($E-05`M;&%A:F5N;G5S
M=&$@96D@;/9Y='EN>70N`$%U=&A?8WER=7,Z(%1A=7-T86KD<FIE<W1E;&WD
M(&5I('1U92!T87)V:71T879I82!O;6EN86ES=75K<VEA+@!!=71H7V-Y<G5S
M.B!487)V:71T879A82!)34%0+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+@!!
M=71H7V9T<#H@=&%R=FET=&%V86$@1E10+6QA86IE;FYU<W1A(&5I(&SV>71Y
M;GET+B!+Y.1N;N0@4$A0(&OD>71TY&5N("TM96YA8FQE+69T<"!A<V5T=7-T
M82X`075T:%]I;6%P.B!487)V:71T879A82!)34%0+6QA86IE;FYU<W1A(&5I
M(&SV>71Y;GET+@!!=71H7VMR8C4Z(%1A<G9I='1A=F%A(&MR8C4M;&%A:F5N
M;G5S=&$@96D@;/9Y='EN>70N`$%U=&A?;&1A<#H@:^1Y='3D:FEE;B!L:7/D
MY&UI;F5N($%C=&EV92!$:7)E8W1O<GEY;B!E:2!O;&4@='5E='1U`$%U=&A?
M;&1A<#H@2^1Y='3D:FEE;B!P;VES=&%M:65N;B!!8W1I=F4@1&ER96-T;W)Y
M<W3D(&5I(&]L92!T=65T='4`075T:%]L9&%P.B!487)V:71T879A82!,1$%0
M+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+@!!=71H7VQD87`Z($5I('9O:61A
M(&QI<^1TY"!KY'ET=.1JY.0@)7,N(%!A;'9E;&EM96X@=FER:&5I;&UO:71U
M<R!O;&DZ(`!!=71H7VQD87`Z($5I('9O:61A('!O:7-T86$@:^1Y='3D:N3D
M("5S`$%U=&A?;&1A<#H@16D@=F]I9&$@<.1I=N1T=.3D(&OD>71TY&KDY"`E
M<P!!=71H7VQD87`Z($OD>71TY&II96X@<.1I=FET=.1M:6YE;B!!8W1I=F4@
M1&ER96-T;W)Y>6X@96D@;VQE('1U971T=2X`075T:%]M8V%L.B!487)V:71T
M879A82!-0T%,+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+@!!=71H7W-M8F%U
M=&@Z(%1A<G9I='1A=F%A('-M8F%U=&@M;&%A:F5N;G5S=&$@96D@;/9Y='EN
M>70N`$%U=&5N=&EK;VEN=&D@24U!4"UP86QV96QI;65L;&4@97#D;VYN:7-T
M=6DN`$%U=&5N=&EK;VEN=&D@97#D;VYN:7-T=6D`075T96YT:6MO:6YT:2!E
M<.1O;FYI<W1U:2X@)7,`075T96YT:6MO:6YT:2!2041)55,M<&%L=F5L:6UE
M;'1A(&5PY&]N;FES='5I+@!!=71E;G1I:V]I;G1I($944"UP86QV96QI;65L
M;&4@97#D;VYN:7-T=6DN`$%U=&5N=&EK;VEN=&D@4TU"+7!A;'9E;&EM96QL
M92!E<.1O;FYI<W1U:2X`2^1Y=&5T=.1V:7-SY&]L979A="!K96YTY'0Z`$%Z
M97)B86EZ9&%N`$)/1D@@<V5L:71Y:W-E=`!4875S=&$`5&%U<W1A=N1R:0!6
MY.1RY"!K97)B97)O<R!S86QA<V%N82X`5N3D<N0@:V5R8F5R;W,@:^1Y='3D
M:N1T=6YN=7,N`$)A:&%M80!"86AR86EN`$)A;'1I82`H25-/+3@X-3DM,3,I
M`$)A;F=L861E<V@`0F%R8F%D;W,`1W)A9FEI:V]I9&5N('!E<G5S:&%K96UI
M<W1O82`B)7,B(&5I(&SV>71Y;GET+@!097)U<W9I:79A`%9A;&MO+59E;N1J
MY`!"96QG:6$`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`%-Y;G1Y;>1P
MY&EVY`!/<VEO=&$@(B5S(B!O:&IE;&UA;&QE("(E<R(@96D@;/9Y='EN>70N
M`$]S:6]N(&%S971U:W-E=`!/<VEO;B!T>7EP<&D`3&EH879O:71U`$)O;&EV
M:6$`2VER:F%N;65R:VET`%)E=6YA`%)E=6YA;B!V86AV=75S.@!2975N870`
M0F]S;FEA($AE<GIE9V]V:6YA`$UO;&5M;6%T`$)O='-W86YA`$%L:6X`0F]U
M=F5T('-A87)E=`!"<F%S:6QI80!"<FET86YN:6%N($EN=&EA;B!V86QT86UE
M<F5N('1E<G)I=&]R:6\`0G)U;F5I($1A<G5S86QA;0!"=6QG87)I80!086QL
M=6MK86QI<W1A`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),+6IA
M:V5L=6]S;VET=&5E=`!37V]L=6X@=&EE9&]T+BXN`%;D;&EM=6ES=&EN(&%L
M=7-T=7,@96D@=F%L;6ES='5N=70N`$MA;&5N=&5R:0!4>7EN:0!+86UP=71S
M96$`2V%M97)U;@!386QA<V%N86$@96D@=F]I('1Y:&IE;G3DY"!A=71O;6%A
M='1I<V5S=&DL(&]T82!Y:'1E>71TY"!Y;&SD<&ETY&KDY&XN`$5I('9O:2!K
M:7)J;VET=&%A('1I961O<W1O;VX@(B5S(@!5;&MO:7-I82!I<W1U;G1O:^1S
M:71T96QI:O9I=.0@96D@;VQE(&UA:&1O;&QI<W1A(&AA;&QI=&$N`$E-05`M
M<&%L=F5L:6UE96X@96D@<V%A='4@>6AT97ET=.0Z("5S`$5I('9O:2!A=F%T
M82!T:65D;W-T;V$@(B5S(BX`2V%N861A`%!E<G4`4&5R=2!O;F=E;&UA=FEE
M<W1I`$5I('9O:61A('!O:7-T86$@=&EE9&]S=&]A("(E<R(N`%;D;&EA:6MA
M:7-H86ME;6ES=&]A(&5I(&SV>71Y;GET+@!%:2!V;VED82!J871K86$@:6QM
M86X@)W1A<F=E=$9I;&4G("UP87)A;65T<FEA+@!%:2!V;VED82!P;VES=&%A
M(&AA:V5M:7-T;V$@(B5S(BX`16D@=F]I9&$@<&]I<W1A82P@)60@86QI=&%S
M;VIA(&]L96UA<W-A+@!%:2!V;VD@=75D96QL965N:N1R:F5S=.3D+"!A;FYE
M='1U:F5N('1I971U96ED96X@;>3D<N0@96D@=F%S=&%A('1A;&QE=&5T='5J
M96X@=&EE='5E:61E;B!MY.1RY.0N`$5I('9O:2!O:&IA=&$@=FEE<W1IY"!A
M;FYE='1U=6X@;G5M97)O;VXN`$MA<"!697)D90!+=79A=&5K<W1I`%!A;'9E
M;'5N=&%R:F]A:F$`2V%T96=O<FEA="!J82!O='-I:V]T`$-A>6UA;B!S86%R
M970`4'5H96QI;BA'4TTI`%-O;'5N('1I961O=`!3;VQU;B!TY'ET93H`4V]L
M=6X@=&EE9&]T`%-O;'5N(';D;'ES.@!-871K87!U:&5L:6X`2V5L='1I("A)
M4T\M.#@U.2TQ-"D`2V5S:VET971T>0!+97-K:2U!9G)I:V%N('1A<V%V86QT
M80!+97-K:2U%=7)O;W!P82`H25-/+3@X-3DM,BD`5F%R;65N=&5E;B!T:65D
M;W0`5F%R;65N=&5E;B!O;6ES=&%J80!687)M96YT965N('!O;&ET:6EK870`
M5'-A9`!-=75T80!686EH9&$@<V%L87-A;F%S:0!6;VET(&UU=71T86$@;.1H
M971TY&UI<W/D<VD@<^1H:_9P;W-T96ES<V$@;N1K>79IY"!N:6UI+2!T86D@
M;W-O:71E=&EE=&]J82X`4V%L87-A;F%N('9A:6AT;R!E:2!O;&4@:^1Y=/9S
M<^0@;GEK>6ES:6QLY"!A<V5T=6MS:6QL82X@3W1A('EH=&5Y='3D('EL;.1P
M:73D:FEI;BX`365R:VMI`%1A<FMI<W1?82!L:6YK:VDN+BX`0VAI;&4`2VEI
M;F$`2VEI;F$@>6MS:6YK97)T86ES=&5T='4@*$=",C,Q,BD`2VEI;F$@<&5R
M:6YT96EN96X@*$)I9S4I`%9A;&ET<V4@;VAJ96QM80!686QI='-E('-A;&%S
M86YA`%9A;&ET<V4@:^1Y='3D:N1T=6YN=7,`5F%L:71S92!PY&EVY&WDY')I
M96X@97-I='ES87-U.@!686QI='-E(&QI<W1A;B!T>7EP<&D@*&KD<FIE<W1E
M='EI;&QE(&QI<W1O:6QL92D`2F]U;'5S86%R970`3'5O:VMA;>3D<FET>7-T
MY"`E<R!E:2!L]GET>6YY="X`4V5L:V7D`%!O:7-T82!-4T]F9FEC92!T86=I
M=`!0;VES=&$@:WES96QY`%!O:7-T82!KY'ET=.1JY#H@)7,`4&]I<W1A(&OD
M>71TY&KD`%!O:7-T82!KY'ET=.1JY&X@=&EE9&]T`%-E;&ME;F5VY.0@;7GV
M:.3D;@!.87!S875T82!J871K86%K<V5S:0!#;&EK871E;&P@2%144#IN(&MA
M=71T80!3=6QJ92!I:VMU;F$`4&EL=FGD`%!I;'9I;F5N(&%I:V%I<VEN`%!I
M;'9I;F5N`$MO;VMO<R`H2V5E;&EN9RD@<V%A<F5T`%!I96YE;F[D('-I=G5V
M86QI:VMO`%!I96YE;FYE='ET(')E=6YA=`!+;VQU;6)I80!6Y')I`%;D<FEV
M86QI='-I;@!6Y')I=F%L:6YT80!387)A:SH`4V%R86MK96ED96X@;W1S:6MO
M=`!387)J86MU=F%T`$MO;65N=&\`2V]M96YT;W1U;&MK:0!+;VUM96YT=&D`
M66QE:6YE;B!N:6UI`$MO;6]R:70`67)I='ES`%1I971O:V]N965T`$]L;W-U
M:&1E`$]L;W-U:'1E970`07-E='5K<VEE;B!E<F]T`$%S971U:W-E="!01$$M
M;&%I='1E:61E;BP@Y&QY<'5H96QI;6EE;B!J82!/=71L;V]K:6X@<WEN:W)O
M;F]I=&EI;BX`07-E='5K<VEA('!I=.3D('#D:79I='3DY"X`07-E=&$@87-E
M='5K<V5T("5S`%9A:'9I<W1A(&MI<FIO:71T86UA;&QA('-A;&%S86YA('5U
M9&5S=&%A;@!+;VYG;P!+;VYG;VX@9&5M;VMR86%T=&EN96X@=&%S879A;'1A
M`%EH=&5Y<R!E<.1O;FYI<W1U:2X`66AT97ES(&5PY&]N;FES='5I.B``66AT
M97ES(&IU;&MI<W1E;B!A=F%I;G1E;B!P86QV96QI;65L;&4@97#D;VYN:7-T
M=6DN`%EH=&5Y<R!J=6QK:7-T96X@879A:6YT96X@<&%L=F5L:6UE;&QE(&5P
MY&]N;FES='5I+B!6:7)H93H@)7,@*"5S*0!9:'1E>7,@9G1P+7!A;'9E;&EM
M96QL92!E<.1O;FYI<W1U:2X`66AT97ES=&EE9&]T`%EH=&5Y<W1I961O="!L
M:7/D='1I:6X@;W-O:71E:VER:F%A<VDN`%1I:79I<W1E='EN('1I961O<W1O
M;B!T>7EP<&DZ`"(E<R(Z;B!S:7/D;'3V`$IA=&MA`$-O;VL@<V%A<F5T`$5V
MY'-T90!+;W!I;VD`2V]P:6]I;G1I(&5PY&]N;FES='5I.B`E<P!+;W!I;VD@
M=F%L:6YT80!#;W-T($E$`$-O<W1A(%)I8V$`3F]R<W5N;'5U<F%N;FEK:V\`
M5FEE<W1I;B!01U`M<V%L875S=&$@96D@=F]I='4@=&5H9.0Z(`!6:65S=&EI
M;B!E:2!V;VET=2!M=6]D;W-T86$@4$=0+6%L;&5K:7)J;VET=7-T83H@`%9I
M97-T:6X@4R]-24U%+7-A;&%U<W1A(&5I('9O:71U('1E:&3D+@!6:65S=&EI
M;B!E:2!V;VET=2!M=6]D;W-T86$@4R]-24U%+6%L;&5K:7)J;VET=7-T82X`
M16D@=F]I='4@;W1T86$@>6AT97ET=.0N("5S`$QD87`M<&%L=F5L:6UE96X@
M96D@<V%A='4@875T;W)I<V]I='5A('EH=&5Y='3D+@!%:2!V;VET=2!T87)K
M:7-T86$@<V%L9&]A+B`E<P!,1$%0+7!A;'9E;&EM965N(&5I('-A871U('EH
M=&5Y='3D+@!%:2!V;VET=2!O='1A82!Y:'1E>71TY"!P86QV96QI;65E;B`B
M)7,B(&OD>71TY&5N($944#H@)7,`16D@=F]I='4@;'5O9&$@:F%K96QU;&ES
M=&%A+B`E<P!01U`M<V%L871T=6$@=&EE=&]A(&5I('9O:71U(&%U:V%I<W1A
M.B``4R]-24U%+7-A;&%T='5A('1I971O82!E:2!V;VET=2!A=6MA:7-T82X`
M16D@=F]I='4@<&]I<W1A82!Y:'1E>7-T:65T;V$N("5S`$5I('9O:71U('!O
M:7-T86$@:F%K96QU;&ES=&%A+B`E<P!%:2!V;VET=2!P;VES=&%A('#D:79I
M='ES<VMR:7!T:>0@(B5S(BX`5FEE<W1I;B!LY&AE='3D:N1N('/D:&OV<&]S
M=&EO<V]I=&5T=&$@96D@<'ES='ET='D@;>3D<FET=&5L96WDY&XN`$5I('9O
M:71U(&AA:V5A(&MO:V\@;W-O:71E:VER:F%A+@!%:2!V;VET=2!H86ME82!K
M;VMO(&IA:V5L=6QI<W1A82X`16D@=F]I='4@:&%K96$@:V]K;R!L:7-T86$@
M:F%K96QU;&ES=&]I<W1A+@!%:2!V;VET=2!L=6ME82!S=')A=&5G:6%A("(E
M<R(N`$MO;65N=&\@;6MD:7(@(B5S(B!E<.1O;FYI<W1U:2X`2G5L:VES=&5N
M(&%V86EN=&5N('!A;'9E;&EM96QT82!E:2!S86%T=2!J=6QK:7-T82!A=F%I
M;G1A+@!4:65D;W-T;V]N("(E<R(@96D@=F]I(&MI<FIO:71T86$N`$5I('9O
M:71U(&%U:V%I<W1A("5S+@!9;&SD<&ET;VUO9'5U;&EN("5S(&%U:V%I<W4@
M97#D;VYN:7-T=6D`16D@=F]I(&%U:V%I<W1A(&AA:V5M:7-T;V$@(B5S(BX`
M3$1!4"UP86QV96QI;65L=&$@96D@;VQE(&UA:&1O;&QI<W1A(&5T<VGD+@`E
M<SKDY"!E:2!V;VET=2!L=6ME82X`2^1Y='3D:N1N('-A;&%S86YA82!E:2!V
M;VET=2!N;VQL871A+B!*;W1K=70@=&%R=FET=&%V870@=&EE9&]T(&]V870@
M=N3D<FEN+B!9<FETY"!U=61E<W1A86X@=&%I(&]T82!Y:'1E>71TY"!Y;&SD
M<&ET;V]N(&IO<R!T87)V:71S970@;&ESY.0@87!U82X`16D@=F]I='4@:&%K
M96$@04-,+71I971O:F$`16D@=F]I='4@:&%K96$@;W-O:71E:VER:F%A+B`E
M<P!%:2!V;VET=2!H86ME82!J86ME;'5L:7-T86$N("5S`$5I('9O:71U(&AA
M:V5A(&IA:V5L=6QI<W1O:F$N("5S`$5I('9O:71U(&AA:V5A('1I971O:F$@
M<&%L=F5L:6UE;B!T;VEM:6YN;VES=&$`16D@=F]I='4@<&%L875T=&%A(&%S
M971U:W-I82X`2V]M96YT;R!R;61I<B`B)7,B(&5PY&]N;FES='5I+@!%:2!V
M;VET=2!T86QL971T86$@)7,@87-E='5K<VEA+@!%:2!V;VET=2!T86QL971T
M86$@87-E='5S=&5N('9A<FUU=7-K;W!I;W1A+@!%:2!V;VET=2!T86QL971T
M86$@87-E='5S=&5N('9A<FUU=7-K;W!I;W1A("5S`$5I('9O:71U('1A;&QE
M='1A82!A<V5T=7-PY&EV:71Y<W-K<FEP=&GD.B`B)7,B+@!%:2!V;VET=2!T
M86QL971T86$@87-E='5S=&5N('9A<FUU=7-K;W!I;W1A("5S+@!!<V5T=7-T
M:65D;W-T;VX@)7,@=&%L;&5T=7,@97#D;VYN:7-T=6DN(%9O:70@:^1Y='3D
MY"!J;W1A:VEN(&%S971U<W1A('1A;&QE='1A86MS97-I(&MO;V1I;B!T86MA
M:7-I;B`E<R!T86D@=&%I(&MO<&EO:61A(&OD<VEN(&%L;&$@;VQE=F%N(&MO
M;V1I;B!T:65D;W-T;V]N("5S+@!,1$%0+7!A;'9E;&EM96QT82!E:2!O;&4@
M;6%H9&]L;&ES=&$@971S:>0N`$MO;65N=&\@=6YL:6YK("(E<R(@97#D;VYN
M:7-T=6DN`$5I('9O:71U('#D:79I='3DY"!Y:'1E>7-T:65T;VIA+B`E<P!%
M:2!V;VET=2!PY&EV:71TY.0@:F%K96QU;&ES=&%A+B`E<P!6:65S=&5JY"!E
M:2!V;VET=2!P;VES=&%A(&MA;G-I;W-T82`B)7,B.B`E<P!-;WII;&QA(%-I
M9&5B87(@96D@;/9Y='EN>70N(%9A<FUI<W1A(&5T=.0@4VED96)A<B!O<VEO
M(&]N(&%U:VDN`$OD>71TY&KD;&QE("(E<R(@96D@=F]I='4@86YT86$@<V5U
M<F%A=FEA(&]I:V5U<VEA(&MA;G-I;V]N("(E<R(Z("5S`$QA<VME='1U('1E
M:W-T:0!-86$`2W5R<W-I=`!,=6\`3'5O('5U<VD@;&EN:VMI`$QU;R!U=7-I
M`%9O:2!L=6]D82!U=7-I82!K86YS:6]I=&$`3VEK975D970@=&5K:6KD;&SD
M`$QU;W1T;VMO<G1I;FYU;65R;P!+<F]A=&EA`$MU=6)A`%3D;>1N:&5T:VEN
M96X@-"!V86EH971T80!4Y&WD;FAE=&MI<V5T(&ES='5N;F]T`$ME;&QO;F%I
M:V$@=.1L;.0@:&5T:V5L;.0`5.1MY&YH971K:6YE;B!54DP@;VX`5.1MY&YH
M971K:7-E="!KY'ET=.1JY'0`5.1MY&YH971K:6YE;B!SY.0`5.1MY&YH971K
M:6YE;B!T:6QA.B``5.1MY&YH971K:6YE;B!T>7EL:0!6;VET(&UU;VMA=&$@
M=&5H=.1V:>0L(&IO=&MA('-U;W)I=&5T86%N(&MU;B!K:7)J875D=71A86X@
M<VESY.1N(&]H:F5L;6%A;B`E<RX`3&5I:VMA80!,96EK:V%A('9A;&ET='4`
M2WEP<F]S`$MY<FEL;&EN96X@*$M/23@M4BD`2WER:6QL:6YE;B`H5VEN9&]W
M<RTQ,C4Q*0!+>7)I;&QI;F5N+U5K<F%I;F$@*$M/23@M52D`5'-E:VEN('1A
M<V%V86QT80!04`!$4TX@*&QI<^1T:65T;V$@:'1T<#HO+W!E87(N<&AP+FYE
M="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP
M*0!0Y&EV:71TY&EN`$1A=&%4<F5E+7-E;&%I;@!4:65T;VMA;G1A:&%K=0!0
MY&EVY'ES`%#D:7;D;>3D<N0@=F%S=&%A;F]T971T=0!0Y&EVY&WDY'+D;B!V
M86QI;G1A`%#D:7;D`%!O7VES=&$@<V%R86ME`&IO=6QU:W5U`$1E<VEM86%L
M:6YU;65R;W0`4&EE;F5N;N0@<VES96YN>7-TY`!/;&5T=7,`3VQE='5S=N1R
M:0!/;&5T=7-P<F]F:6EL:0!/;&5T=7,@:V]M96YT;W1U;&MK:0!-Y.1R:71E
M;&WD=`!0;VES=&$`4&]I<W1A('-O;'4`4&]I<W1A(')Y:&WD`%!O:7-T82!L
M;VMI`%!O:7-T82!O:6ME=7,`5F]I('!O:7-T86$@:F$@='5H;W1A('!O:7-T
M971T=6IA('9I97-T96KD`%!O:7-T82!S;VQU`%!O:7-T82!S87)A:V4`4&]I
M<W1A(&]L96UA<W-A(&]L979A="!V86EH=&]E:'1O:6YE;B!M86QL:0!6;VD@
M<&]I<W1A82!V:65S=&5JY`!0;VES=&$@(B5S(CIN(&]I:V5U:W-I80!/;&5T
M:V\@=F%R;6$L(&5T=.0@:&%L=6%T('!O:7-T86$@(B5S(B!J82!K86EK:VD@
M<V5N(&%L:6]I:V5U9&5T/P!0;VES=&$@<FEV:0!0;VES=&$@=F%L:71T=2!P
M<F]F:6EL:0!6;VD@;'5O9&$@=75S:6$@:V%N<VEO:71A`%!O:7-T82!V86QI
M='1U('-A<F%K90!0;VES=&$@=F%L:71T=2!R:79I`%!O:7-T971T=2!PY&EV
M:71Y<W-K<FEP=&D@(B5S(BX`5&]I;6ET=7-A:6MA`%1A;G-K80!/;F=E;&UA
M;B!K=79A=7,`2W5V875S`%1A<FME;6UA="!T:65D;W0@*&SV>71Y=N1T(&UY
M]G,@2&]R9&4Z;B!L;VMI=&EE9&]S=&]S=&$I.@!487)K96UM870@=&EE9&]T
M(&]N('1A;&QE=&5T='4@>6QLY'!I9&]N(&OD<VET96QTY';D:W-I+@!+96AI
M='ES`$MO<W1E=7-P:7-T90!%9&5L;&ES96X@='5N;FEN(&MO<W1E=7-P:7-T
M93H@`$MO<W1E=7-P:7-T93H@`%-U=6YT82!V87-E;6UA;'1A(&]I:V5A;&QE
M`%-U=6YT82!O:6ME86QT82!V87-E;6UA;&QE`$AA:V5M:7-T;P!+Y'ETY"`R
M-"UT=6YN:6X@86EK865S:71Y<W3D+@!.Y&MY;>1N(&%S971U:W-E=`!%<VET
M>7-T87!A('EK<VET>6ES:V]H=&%I;F5N(&5N;G5S=&4`17-I='ES=&%P82!E
M;FYU<W1E96QL92`H5$%&*0!%<VET>7-T87!A`%!E<FEL;&5M96YO:6QM;VET
M=7,`1&II8F]U=&D`16D@<V%A('!O:7-T86$`Q&SD(&OD>73D('-U;W)A86X@
M;6%I;G1E;F%N8V4N<&AP.G3D`$IO<R!E;G-I;6WD:6YE;B!R:79I('-I<^1L
M=.3D('-A<F%K:V5I9&5N(&]T<VEK;W0L(&YI:6X@=F%L:71S93H`1&]M:6YI
M:V%A;FEN96X`1&]M:6YI:V%A;FEN96X@=&%S879A;'1A`$5I:_8@;VQE(&OD
M>71TY&KD='5N;G5S=&$_($MI<FIA=61U(&OD>71TY&KD:W-I+@!486QL96YN
M80!486QL96YN82`E<P!486QL96YN82!L=6]T=2!A<V5T=7,@4$A0+7-K<FEP
M=&ENY"X`06QA<W9E=&]V86QI:VMO`$AU=6UE970`4^1H:_9P;W-T:6]S;VET
M90!%36%I;"UT;RU335,@9V%T97=A>2!A:G5R:2P@;FEI;&QE('!A;'9E;'5N
M=&%R:F]A:FEL;&4L(&IO=&MA('1A<FIO879A="!TY'3D('!A;'9E;'5A+@!6
M25)(10!%8W5A9&]R`$UU;VMK86$`375O:VMA82!O<VEO=&$`375O:VMA82!R
M>6AMY.0`375O:VMA82!O:6ME=71T80!-=6]K:V%A(&]I:V5U:W-I80!-=6]K
M:V%A("<E<R<Z;B!O:6ME=6MS:6$`375O:VMA82!A<V5T=6MS:6$Z`$UU;VMK
M86$@(B5S(CIN(&]I:V5U:W-I80!-=6]K:V%A("5S.FX@;VEK975K<VEA`$MO
M=6QU='5S`$5G>7!T:0!%;"!386QV861O<@!%;&5M96YT=&DN+BX`16T`4^1H
M:_9P;W-T:0!3Y&AK]G!O<W1I;W-O:71E`%/D:&OV<&]S=&EO<V]I='1E:61E
M;B!P:73DY"!O;&QA('-A;6%T+@!3Y&AK]G!O<W1I('9A<FUI<W1U:W-E;&QA
M`$5M86EL+71O+5--4R!'871E=V%Y`$AY;6GV=`!4>6AJY"!V:65S=&DN`%1Y
M:&KD('9A<W1A=7,N`%1Y:&KD(&AA:W5T97)M:0!386QL:2!K=79I96X@;&%I
M='1A;6EN96X@:W5V86=A;&QE<FEA<W1A('1E:W-T:6X@:F]U:VMO;VXN`$QA
M:71A('#DY&QL92!O:6ME86X@<&%I;FEK:V5E;B!K;VYT96MS=&EM96YU+@!0
MY.1T='EM:7-V=6]S:0!3=75R96YN82!E9&ET;W)I80!!;FYA(&MY<WEM>7,@
M:F]K82!K>7-Y=.3D;BP@:F]S('-A;&%S86YA<VD@:F]U9'5T86%N(&YO;&QA
M86UA86X@97-I;65R:VEK<VD@)VUI:^0@;VX@;&5M;6EK:VES:2!N:6UI/R<Z
M`$QA:71A(&MU=F$@55),('3D:.1N`$%N;F$@:VER:F%I;65T(&%L;&4Z`$5K
M=F%T;W)I86%L:6YE;B!'=6EN96$`17)I=')E80!6:7)H90!6:7)H92!PY&EV
M:71E='3D97-SY"!O<VEO=&$Z("5S`%9I<FAE('#D:79I=&5T=.1E<W/D('-Y
M;F,@86YC:&]R("UT:65T;V$Z("5S`%9I<FAE('!O:7-T971T865S<V$@<WEN
M8R!L;VMI83H@)7,`5FER:&4@:&%E='1A97-S82!S:7/D;'3VY#H@)7,N`%9I
M<FAE('#D:79I=&5T=.1E<W/D('-A;&%S86YA83H@)7,`5FER:&4@<^1H:_9P
M;W-T:79I97-T:7-SY"X`5FER:&4@:VER:F]I=&5T=&%E<W-A("(E<R(N`$5E
M<W1I`$5T:6]P:6$`171N:6YE;@!%=7)O;W!P80`Q-2!M:6YU=71I;B!VY&QE
M:6X`,B!M:6YU=71I;B!VY&QE:6X`,S`@<V5K=6YN:6X@=N1L96EN`#4@;6EN
M=75T:6X@=N1L96EN`$IO:V%I<V5L;&$@<VESY.1N:VER:F%U='5M:7-E;&QA
M`%!U;VQE;B!T=6YN:6X@=N1L96EN`$UI;G5U=&EN(';D;&5I;@!%<VEM97)K
M:VEA<G9O=#H`4W5O<FET80!,86%J96YN80!,86%J96YN82!S:79U=F%L:6MK
M;P!/9&]T971T:6EN(&UE<FMK:>0@)RDG`%-A;F$@<V5L;&%I<V5N86%N('1A
M:2!H86MU=&5R;6D@;&%I;F%U<VUE<FME:7-SY`!,;W!P=7#D:7;D;>3D<N0`
M16MS<&]N96YT=&D`1D<@=N1R:0!!<V5T=7-T:65D;W-T;VIE;B!T=6]N=&D@
M1E10.FQLY`!!<V5T=7-T96X@:&%K=2!E<.1O;FYI<W1U:2X`66AT97ES($Q$
M05`M<&%L=F5L:6UE96X@97#D;VYN:7-T=6DN`%EH=&5Y<R!334(M<&%L=F5L
M:6UE96X@97#D;VYN:7-T=6DN`$MO<&EO:6YT:2`B)7,B.FQTY"!E<.1O;FYI
M<W1U:2X`2V]P:6]I;G1I("(E<R(Z;&QE(&5PY&]N;FES='5I+@!5=61E;B!3
M05-,+7EH=&5Y9&5N(&QU;VUI;F5N(&5PY&]N;FES='5I+@!3:6ER=&\@(B5S
M(CKDY&X@97#D;VYN:7-T=6DN`%-I:7)T;R!E<.1O;FYI<W1U:3H@)7,`2V%U
M;FES`$9A;&ML86YD:6X@<V%A<F5T("A-86QV:6YA<RD`1N1R('-A87)E=`!6
M86MA=F$@=FER:&4Z`$9A:W-I`$9A:W-I=`!H96QM:6MU=0!4=6YT=74@:W5I
M;@!4=6YT=74@:W5I;CH@`$UU=71A;6EA('-A=&5I=&$`375U=&%M:6$@;'5M
M:7-A=&5I=&$`2V5N='3D;6%T<FEI<VD`1FEG;&5T($-!4%1#2$$`1FEG;&5T
M(&MI<FIA<VEN`$9I9'II`%1I961O<W1O`%1I961O<W1O:F5N(&QU:W5MY.1R
MY#H@)7,@=&EE9&]S=&\`5&EE9&]S=&]J96X@;'5K=6WDY'+D.B`E<R!T:65D
M;W-T;V$`5&EE9&]S=&]J96X@:^1S:71T96QY`%1I961O<W1O;B!N:6UI`%1I
M961O<W1O;B!V86QI;G1A`%1I961O<W1O;B!T=6]N=&D`5&EE9&]S=&]J96X@
M='5O;G1I(&5I(&]L92!KY'ET971TY'9I<W/D+@!3=6]D871T:6UE=`!3=6]M
M:0!%;G-I;6WD:6YE;B!P=6]L:7-K;P!%;G-I;6WD:6YE;B!N96QJY&YN97,`
M2V]R:F%A('-U:&1E`$ODY&YNY"!Y;7#D<FD`2V5L;'5V80!3=6UU`$MA;G-I
M;W1A("5S(&5I(&]L92!O;&5M87-S82X`2VER:F%S:6UE;B!VY')I`%)U;VMA
M`%-E;&%I;6EL;&4L(&IO=&MA(&5I=N1T('1U92!K=79I80!%;FYU<W1E("A4
M048I`$5N;G5S=&5T=&%V870@=G5O<F]K875D970@*$AU;VUA871H86X@971T
MY"!E;FYU<W1U:W-E<W-A(&]N('1I961O="!S96OD('#D:79I<W3D(&5T=.0@
M]FES=.0L(&IO=&5N('-U=7)I(&WDY'+D('#D:79IY"!A:6AE=71T86$@;&EI
M86X@;&5V9>1N(&]S:6]N*0!5;F]H9&ET:V\@<V%L87-A;F%S:3\`3&]M86MK
M965T`$UI971E;&%U<V4`36EE=&5L875S965N('1Y>7!P:0!-:65T96QA=7-E
M970`36EE=&5L875S965T(#(`1F]O<G5M:70`575D96QL965N;VAJ875K<V5T
M`'!E`$ME:'EK<V5T`%)A;G-K80!286YS:V$L($UE=')O<&]L:0!286YS:V%N
M($=U>6%N80!286YS:V%N(%!O;'EN97-I80!286YS:V%N(&5T96SD:7-E="!T
M97)R:71O<FEO=`!,Y&AE='3D:N0`4W5U;FYA<W1A(`!0:61E;7!I(&MU=F%U
M<SH`5.1Y<VEK=74`2V]K;R!N:6UI`$=A8F]N`$=A;&QE<FEA+"!J;W-T82!K
M=79A(&]T971A86X`1V%L;&5R:6$Z`$=A;6)I80!4964@)7,@87-E='5K<V5T
M`$=E;F5R;VET=2!K;V]D:0!'96]R9VEA`%-A:W-A`$=H86YA`$=I8G)A;'1A
M<@!%='5N:6UI`%EL96ES970@87-E='5K<V5T`$UE;F4`1_9D96P`1V]O9VQE
M($MA<G1A=`!';V]G;&4@:&%K=0!(87)M86%SY'9Y`$MR96EK:V$`2W)E:6MK
M82`H25-/+3@X-3DM-RD`1W+V;FQA;G1I`$=R96YA9&$`4GEH;>1N('EL;.1P
M:71O`%)Y:&UI96X@;FEM970@96EVY'0@<V%A(&]L;&$@='EH:FGD`$=R;W5P
M7VQD87`Z($5I('9O:61A(&QI<^1TY"!KY'ET=.1JY.0@)7,N(%!A;'9E;&EM
M96X@=FER:&5I;&UO:71U<R!O;&DZ(`!'<F]U<%]L9&%P.B!%:2!V;VED82!P
MY&EVY'1TY.0@:^1Y='3D:N3D("5S`$=R;W5P7VQD87`Z($5I('9O:61A('#D
M:7;D='3DY"!KY'ET=.1JY.0@)7,`4GEH;>1T`$=U861E;&]U<&4`1W5A;0!'
M=6%T96UA;&$`1W5E<FYS97D`5FEE<F%I;&EJ86X@;VEK975D970`5FEE<F%S
M:VER:F$`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A434P`2%1-3$%R
M96$@<&5L:W5R:6UA:7-E<W1I(&MI96QTY'ET>7D@<&]I<W1A;6%S=&$@<FEV
M:6X@=FEI;65I<W3D('-O;'5A+@!(5$U,07)E82!P96QK=7)I;6%I<V5S=&D@
M:VEE;'3D>71Y>2!P;VES=&%M87-T82!V:6EM96ES=.0@<V%R86ME='1A('1A
M=6QU:V]S=&$N`$A434Q!<F5A('!E;&MU<FEM86ES97-T:2!K:65L=.1Y='EY
M('!O:7-T86UA<W1A('9I:6UE:7-TY"!R:79IY"!T875L=6MO<W1A+@!(5%10
M+6%U=&5N=&EK;VEN=&EA(&5I(&SV>71Y;GET+@!(86ET:0!(87-H+6%L9V]R
M:71M:0!5<W9A`$]T<V%K90!/='-A:V4`2&5A<F0@:F$@36-$;VYA;&0@<V%A
M<F5T`%9O:6UA:V%S('5K:V]S;7ER<VMY`$AE<')E82`H25-/+3@X-3DM."U)
M*0!+;W)K975S`$]H:F4`07!U82!E9&ET;W)I;B!KY'ET=/;V;@!/:&IE`%!A
M;&QO;G!U;VQI<VMO.@!4Y'-SY"!O;B!T:65D;W-T;VX@86QK=6]S83H`2V]R
M:V5A`$MO7W1I`%!Y:.0@:7-T=6EN("A6871I:V%A;FEN(&MA=7!U;FMI=F%L
M=&EO*0!+;W1I`$MO=&EO<V]I=&4`2V]T:6AA:V5M:7-T;P!0=6AE;&EN("AK
M;W1I*0!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($5P
MY&ME;'!O82`E<R!834PM9&%T86$@=FEE<W1I<W/D("5S`$AO<F1E+TMO;&%B
M.B!9:W-I:^3D;B!V:65S=&D@96D@=F%S=&%A(&]B:F5K=&EA("5S`$AO<F1E
M+TMO;&%B.B!9:'3D:^3D;B!O8FIE:W1I82`E<R!E:2!L]GET>6YY="!V:65S
M=&ES=.0@)7,`2&]R9&4O2V]L86(Z(%!O:7-T971T:6EN("5S("(E<R(`2&]R
M9&4O2V]L86(Z($EN=&5G<F%A=&EO:V]N92!V86%T:6D@=&]I;6EA:W-E96X@
M)V1O;7AM;"<@4$A0+6QA86IE;FYU:W-E;@!(;W)D92]+;VQA8CH@16D@=F]I
M9&$@;'5O9&$@=75T=&$@6$U,+7!U=71A(&]B:F5K=&EL;&4@)7,`2&]R9&4O
M2V]L86(Z($5I('9O:71U('!O:7-T86$@)7,@(B5S(CH@)7,`2&]R9&4O2V]L
M86(Z($5I('9O:61A(&AA:V5A($U)344@240ZY"!O<VEO;&QE('1Y>7!P:>0@
M)7,`2&]R9&4O2V]L86(Z($5I('9O:2!S>6MR;VYO:61A("5S("(E<R(Z("5S
M`$AO<F1E+TMO;&%B.B!%:2!V;VED82!S>6YK<F]N;VED82!J86MO:F$Z("5S
M`$AO<F1E+TMO;&%B.B!4=6YT96UA=&]N(&IA:V\@(B5S(@!686%K87-U;W)A
M('/DY&YT]@!686%K87-U;W)A('3D>71E`%9A86MA<W5O<F$Z`$UI=&5N('1U
M;&ET('3D;FYE/R`H4F%P;W)T;VD@:VEI=&]S(2D`2W5I;FMA(&UO;G1A('-A
M<F%K971T82!H86QU870@>6AD:7-TY.0_`$ME;G1T:65N("AS87)A:VME:61E
M;BD@;'5K=6WDY'+D+@!+=6EN:V$@;6]N=&$@<FEV:>0@:&%L=6%T('EH9&ES
M=.3D/P!+;W-T975S`$MO<W1E=7,Z(`!(=6UO<FES=&ET`%5N:V%R:0!)34%0
M+7!O<W1I;&%A=&EK;VX@;'5O;G1I(&5PY&]N;FES='5I.B`E<P!)34%0+7!O
M<W1I;&%A=&EK;VX@<&]I<W1O(&5PY&]N;FES='5I.B`E<P!)34%0+7!O<W1I
M;&%A=&EK;VX@:VEI;G1I]FX@;'5O;G1I(&5PY&]N;FES='5I.B`E<P!)4"UO
M<V]I=&4`25`M;W-O:71E(&5I(&]L92!KY'ET971TY'9I<W/D+@!)4"UO<V]I
M=&4@96D@;VQE('-A;&QI='5N($-)1%(M8FQO:VEN('-I<^1L;.0`25`M<^3D
M;F[V<W3V;B!R:6MK;VUU<P!,7V%I=&$@<FEV:2!E;FYE;@!)<VQA;G1I`%9A
M:6X@:6MO;FET`$EK;VYI="`E<SIL;&4`26MO;FET(&IA('1E:W-T:0!0<F]F
M:6EL:6X@;FEM:3H`2F]S('-I=G4@96D@;N1Y(&MU;FYO;&QA+"!N:6EN(&%U
M:V%I<V4@)7,@97)I;&QI<V5S<^0@:6MK=6YA<W-A+@!*;W,@970@;N1E(&EK
M;VYE:71A(&OD>71TY&5S<^1S:2!);G1E<FYE="!%>'!L;W)E<B!S96QA:6YT
M82P@;FEI;B!S:6YU;B!P:73DY"!O='1A82!P;VES('#DY&QTY"!03D<@;.1P
M:6[D:WEV>7ES(')A<W1I='1A;6%L;&$@=.1MY"!L86%T:6MK;RX`2F]S(&[D
M970@=.1MY&X@=FEE<W1I;BP@;75T=&$@970@:W5V86$L(&YI:6X@='5O;6%A
M<VD@:W5V86$@96D@=F]I(&[D>71TY.0@:^1Y='3D;>1S<^1S:2!S96QA:6UE
M<W-A+@!+=79I96X@97-I:V%T<V5L=0!+=79A(%523`!+=79A(%523#H`2W5V
M82!G86QL97)I87-T80!+=79A(&=A;&QE<FEA<W1A.@!+=79A;B!V:65N=&D`
M2W5V870`5'5O;G1I+"!A<VME;"`E9`!4=6]T=2!K96YT=.0Z("5S`%1U;V1U
M="!K96YTY'0Z`$QA7VET82!R:79I(&KD;&ME96X`5N3D<N0@=&]I;6EN=&]K
M;V]D:2!A;FYE='1U+@!+Y'ET=.1JY'1U;FYU<R!T86D@<V%L87-A;F$@;VX@
M=N3D<FEN+@!6Y.1RY"!KY'ET=.1JY'1U;FYU<R!T86D@=F%I:'1O96AT;VEN
M96X@;W-O:71E+B!9<FETY"!U=61E<W1A86X@:F$@;W1A('EH=&5Y='3D('EL
M;.1P:71O;VX@:F]S('1A<G9I='-E="!L:7/DY"!A<'5A+@!,:7/DY"!S:7-E
M;FYY<W3D`$EN=&EA`%EK<VET=.1I<V5T(&OD>71TY&KD=`!);F1O;F5S:6$`
M26YF;P!);F9O<FUA871I;P!4:65T;V$@96D@;VQE(&5NY.0@<V%A=&%V:6QL
M82X`3&%I=&$@<U]A<F%K92!JY&QK965N`$QA:71A(&MU=F$`3&%I=&$@=&%U
M;'5K:V\`3&%I=&$@=W=W+6QI;FMK:0!,86ET82!?<V%R86ME(&5N;F5N`$QA
M:71A('5U<VD@<V%R86ME(&YY:WEI<V5N(&KD;&ME96X`3&%I=&$@=75S:2!S
M87)A:V4@96YN96X@;GEK>6ES=.0`3&%I=&$@=75S:2!R:79I(&YY:WEI<V5N
M(&KD;&ME96X`3&%I=&$@=75S:2!R:79I(&5N;F5N(&YY:WEI<W3D`$QA:71A
M(&MA<'!A;&4@;GEK>6ES96X@;F]D96X@:N1L:V5E;@!,86ET82!K87!P86QE
M(&5N;F5N(&YY:WEI<W3D(&YO9&5A`$QA:71A('9A:6AT;V5H=&]I;F5N(&UA
M;&QI`$%N;F$@<^1H:_9P;W-T:6]S;VET92!J;VAO;B!U=7-I('-A;&%S86YA
M(&SD:&5T973DY&XZ`$QA:71A('-O;'4@:N1L:V5E;@!,86ET82!S;VQU(&5N
M;F5N`$QA:71A('-O;'4@:N1L:V5E;@!,86ET82!S87)A:V4@96YN96X`5F]I
M(&QA:71T86$@=FEE<W1E:N0`3&%I=&$@:V%P<&%L92!JY&QK965N`$QA:71A
M(&MA<'!A;&4@96YN96X`3&%I=&$@<FEV:2!E;FYE;@!,86ET82!R:79I(&KD
M;&ME96X`06YN82!V86%D:71T879A('9A<W1A=7,@='5R=F%K>7-Y;7EK<V5E
M;CH`3&EI=.0O375O:VMA82!K=79I80!,:6ETY"]-=6]K:V%A(&QI;FMK:>0`
M4VEN=6QL82!E:2!O;&4@=&%R<&5E:W-I(&MR961I:71T96KD(&SD:&5T=.3D
M:W-E<VD@=FEE<W1I;B!J86ME;'5L:7-T86QL92X`4FEI='3D;>1T=/9MY'-T
M:2!K<F5D:6ET=&5JY`!+;VMO;F%I<VQU:W4`2V]K;VYA:7-L=6MU;&ES=&$`
M17#D:V5L<&\@(%5$2"`H57-E<B!$871A($AE861E<BDN`$5PY&ME;'!O82!:
M25`M=&EE=&]A+@!%<.1K96QP;R!O:&IE;&UA+@!%<.1K96QP;R!B871C:"!)
M1"X`3.1H971E='1I:6X@97#D:V5L<&]A('1I971O82X`17#D:V5L<&\@=F%S
M=&%A;F]T=&%J86X@;W-O:71E+@!%<.1K96QP;R!T:65D;W-T;VUU;W1O`$5P
MY&ME;'!O(&QI<V5N<W-I879A:6XN`$5PY&ME;'!O('!A:6MK871I971O+@!%
M<.1K96QP;R!M<V=?='EP92`N`$5PY&ME;'!O('1A:2!P=75T='5V82!A<&E?
M:60N`$5PY&ME;'!O('1A:2!P=75T='5V82!P87)A;65T<FDN`$5PY&ME;'9O
M="!O:6ME=61E="!Y;&5M;>1L;.0@=&%S;VQL82X`17#D:V5L<&\@<&%R;F5R
M(&ED+@!%<.1K96QP;R!T=6]T96MO;V1I+@!%<.1K96QP;R!P<F]T;VMO;&QA
M+@!%<.1K96QP;R!V87-T86%N;W1T86IA.B`B)7,B`$5PY&ME;'!O(&IA:V\M
M;V)J96MT:0!%<.1K96QP;R!LY&AD96]S;VET92X`17#D:V5L<&]A('5N:6-O
M9&4M=&EE=&]A+@!);G9E;G1A87)I;P!+Y.1N;N0@=F%L:6YT82!KY.1N=&5I
M<V5K<VD`27)A;BP@27-L86UI;&%I;F5N('1A<V%V86QT80!)<F%K`$ER;&%N
M=&D`36%N+7-A87)I`$5R:6QL:7-IY"!5:VMO<VUY<G-K>6KD`$ES<F%E;`!,
M:6EK:V5E;&QE;&%S:VEJ80!+=7)S:79O:71U`$ET86QI80!*86UA:6MA`'1A
M;6UI:W5U`$IA<&%N:0!*87!A;FD@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R
M9&%N:6$`:&5I;N1K=74`:V5SY&MU=0!+97-K:73D`$ME<VMI=.0@:V5S:V5L
M;&4`2V5S:VETY"!TY'ES:6X`2V5S:VETY"!V87-E;6UA;&QE`$ME<VMI=.0@
M;VEK96%L;&4`2V%Z86MS=&%N`%/D:6QY=.0@86QK=7!E<N1I;F5N/P!+96YI
M80!!=71E;G1I:V]I;G1I(&5PY&]N;FES='5I($ME<F)E<F]S+7!A;'9E;&EM
M96QL92X`2V5R;F5L(&%L;VET=&5L:6IA=`!!=F%I;65N(&QU;VYT:0!!=F%I
M;65N('1U;FYI<W1E`$%V86EM96X@<&ET=75S`$%V86EM96X@='EY<'!I`$%V
M86EM96X@:^1Y='3V`$%V86EN(&]N(&IO(&IU;&MI<W1E;B!A=F%I;G1E;B!P
M86QV96QI;65L;&$`3&%P<V5T`$MI<FEB871I`$MO<F5A+"!D96UO:W)A871T
M:6YE;B!K86YS86YT87-A=F%L=&$@*%!O:&IO:7,M2V]R96$I`$MO<F5A+"!T
M87-A=F%L=&$@*$5T96SD+4MO<F5A*0!+;W)E82`H155#+4M2*0!+=7=A:70`
M2VER9VES=&%N`$%S7V5T=&5L=0!+:65L:0!,86]S+"!D96UO:W)A871T:6YE
M;B!K86YS86YT87-A=F%L=&$`2N1L:VEM;>1I;F5N('!U;VQI<VMO`$5D96QL
M:6YE;B!S86QA<V%N86YV86EH=&\`2N1L:VEM;>1I;F5N(&YE;&KD;FYE<P!0
MY&EV:71E='1Y('9I:6UE:W-I.@!%9&5L;&EN96X@<VESY.1N:VER:F%U='5M
M:6YE;CH@)7,`161E;&QI;F5N('-I<^3D;FMI<FIA=71U;6EN96XZ("5S+"`E
M<P!%9&5L;&EN96X@<VESY.1N:VER:F%U='5M:6YE;CH@16D@;6EL;&]I;FMA
M86X`3&%T=FEA`$QA:VD`07-E='1E;'4`2N1TY"!T>6AJY&MS:2!J;W,@96D@
M<F5U;F]J80!,:6)A;F]N`%9A<V5N`%9A<V5N(&]T<V%K90!687-E;B!A<G9O
M=`!,97-O=&\`5&%S;P!,:6)E<FEA`$QI8GEA($%R86(@2F%M86AI<FEY80!,
M:6-H=&5N<W1A:6X`2V5V>71TY"!RY&YTY.0`2VER:F%U9'4@<VESY.1N`$ME
M=GET=.0@<V%D971T82!A:6MA:7-I;@!+979Y='3D('-A9&5T=&$@;7GV:&5M
M;6EN`$ME=GEI=.0@<V%D96MU=7)O:F$`2V5V>71TY"!S861E='1A(&IA(&UY
M<G-K>6ES=.0`2V5V>71TY"!L=6UI<V%D971T80!+979Y:73D(&QU;6EK=75R
M;VIA`$QI;65R:6MI=`!,:6YK:VD`3&EN:VMI(&]S;VET=&%A.@!,:6YK:73D
M('/D:&OV<&]S=&EO<V]I=&4@:VER:F]I=&$@=75S:2!V:65S=&D@<VEV=6QL
M92!NY&MY;>1S<^0`3&EN:VET`$QI;G5X('!I<&%R96ET80!6;VD@;&ES=&%U
M:W-E<W-A(&[D:&3D(&MA;G-I;VX`3N1Y=.0@=&EE=&]K86YN870`3N1Y=.0@
M;VAJ96ED96X@86EH965T`$[D>73D('1A=6QU=`!,:7-T86XM07)K:7-T;P!,
M:7-T86XM3VAJ90!,:7-T86XM260`3&ES=&%N+4]M:7-T86IA`$QI<W1A+79I
M97-T:0!,:7-T86XM5&EL875S`$QI<W1A;BU4:6QA=6MS96XM;&]P971T86UI
M;F5N`$ES='5N=&]J96X@;&ES=&%U<R!E<.1O;FYI<W1U:3H@)7,`2^1Y='3D
M:FEE;B!L:7-T875S(&5PY&]N;FES='5I.B`E<P!+Y'ET=.1JY'1I971O:F5N
M(&[D>71TY&UI;F5N(&]N(&5S=&5T='DN`$MI<FIA;&QI<W5U<P!,:65T='5A
M`$QA9&%T86%N+BXN`%!A:6MA;&QI<W1A(&%I:V%A.B``3&]K86QI<V%A=&EO
M(&IA(&%I:V$`4&%I:VMA`$MI<FIA=61U('-I<^3D;@!%9&5L;&ES96X@<WEN
M:W)O;F]I;G1I<V5S<VEO;B!L;VMI`$MI<FIA=61U('5L;W,`2VER:F%U9'4@
M<VESY.1N`%1E:'3D=N1T('-I<^3D;FMI<FIA=71U;6ES97-S80!3:7/DY&YK
M:7)J875T=6UI<V5S:2!E<.1O;FYI<W1U:2X@5&]D96YNY&OV:7-E<W1I(&MI
M<FIO:71I="!VY.1R:6X@:^1Y='3D:N1T=6YN=6MS97-I('1A:2!S86QA<V%N
M87-I+@!3:7/DY&YK:7)J875T=6UI;F5N(&5PY&]N;FES='5I+@!0:71KY"!T
M96MS=&D`4F%K:V%U<P!-871A;&$`4&EE;F5T(&MR96EK:V%L86ES970@:VER
M:F%I;65T`%!I96YE="!L871I;F%L86ES970@:VER:F%I;65T`%!I96YE="!R
M;V]M86QA:7-E="!N=6UE<F]T`$QU>&5M8G5R9P!+2P!-3U1$`$U3+51.148@
M;&EI=&5T:65D;W-T;R!O;&D@='EH:N0N`%9)15-420!-86-A;P!-86ME9&]N
M:6$L($5N=&EN96X@2G5G;W-L879I86X@=&%S879A;&QA;BX`36%D86=A<VMA
M<@!486EK=75S`%/D:&OV<&]S=&D`4&]S=&EN('EL;.1P:71O`%1E92!L:6YK
M7VMI+BXN`$UA;&%W:0!-86QE<VEA`$UA;&5D:6EV:70`4&]S=&D`36%L=&$`
M5F]I="!H86QL:6YN;VED82!L:7-T86$@:V%T96=O<FEO:7-T82P@:F]I9&5N
M(&%V=6QL82!V;VET(&QI:71TY.0@87-I;VET82!Y:'1E96X@<V%M;VIE;B!O
M='-A:VME:61E;B!A;&QE(&IA(&QI:71TY.0@;FEI:&EN(';D<F5JY"X`36%P
M,C0@:V%R='1A`$UA<%%U97-T(&MA<G1T80!687-T86%V=75D970@=&%L;&5T
M971T=2X`;6%A;&ES:W5U`$UA<F=I;F%A;&D`5F]I(&UE<FMI=.0@5F%N:&$O
M575S:2!T:65T;VIA`%9O:2!M97)K:73D('9I97-T96KD("AE<VEM+B!4Y')K
M9>0O5F%S=&%T='4I`$UA<G-H86QL('-A87)E=`!-87)T:6YI<75E`%3D<VWD
MY';D="!K96YTY'0`36%U<FET86YI80!-875R:71I=7,`4W5U<FEN('-A;&QI
M='1Y(&MR961I:71T:2X`4W5U<FEN('-A;&QI='1U('9I97-T:6]S:6]MY.1R
MY"!Y;&ET971T>2X`161E;&QI<V5N(#(T('1U;FYI;B!K;W)K96EN(&SD;7#V
M=&EL83H@`$5D96QL:7-E;B`V('1U;FYI;B!K;W)K96EN(&SD;7#V=&EL83H@
M`%!O<G1A86QI;W-I;VED96X@96YI;6WD:7-MY.1RY`!3=75R:6X@<V%L;&ET
M='4@<&ET=75S`'1O=6MO:W5U`$UA>6]N971T90!,Y.1K971I961E`$KD<V5N
M970`365N=6X@;75O=&\Z`%EH9&ES=.0@<V]L=70`5FEE<W1I`%9I97-T:6X@
M=&%R:VES='5S(&]N;FES='5I+"!M=71T82!A;&QE:VER:F]I='1A:F%N('9A
M<FUE;FYE='1A(&5I('9O:71U('1A<FMI<W1A82X`5FEE<W1I('9A;FAE;FDN
M`%9I97-T:6X@='EY<'!I`$UE=&%R('/DY`!-971A<BUO<VEO(&5I(&]L92!K
MY'ET971TY'9I<W/D+@!-971A<BUO<VEO(&5I(&]L92!KY'ET971TY'9I<W/D
M+B!487)K96UM870@=&EE9&]T(&]N('1A;&QE=&5T='4@>6QLY'!I9&]N(&OD
M<VET96QTY';D:W-I+@!-971A<D1"(&5I(&]L92!Y:&1I<W1E='1Y+@!-971O
M9&D`365T;V1I82`B)7,B(&5I(&]L92!MY.1R:71E;'1Y`$UE=&]D:6$@96D@
M;VQE(&WDY')I=&5L='DN($MU='-U=F$@;65T;V1I.B`E<P!-971R:6YE;@!-
M96MS:6MO`$UI:W)O;F5S:6$L(%EH9&ES='EN965T('9A;'1I;W0`2V5S:V5L
M;.0`36EM92UT>7EP<&D`161E;&QI<V5N(#(T('1U;FYI;B!M871A;&EN(&SD
M;7#V=&EL83H@`$5D96QL:7-E;B`V('1U;FYI;B!M871A;&EN(&SD;7#V=&EL
M83H@`%-A;&%S86YA(&5I(&]L92!V:65LY"!T87)P965K<VD@=F%N:&$`4&5I
M;&EK=79A`%-E:V%L86ES970`4$5!4BUP86ME='1I($A45%!?4F5Q=65S="!P
M=75T='5U+@!0=75T='5V870@87-E='5S=&EE9&]S=&\N(%-I;G5N('!I=.3D
M('1E:&3D(&%S971U<W1I961O<W1O(&IO<R!H86QU870@:^1Y='3DY"!TY'3D
M(&]H:F5L;6%A+@!0=75T='5V82!M97-S86=E($E$+@!6Y&QT=.1MY'3V;B!0
M14%2+7!A:V5T=&D@36%I;"!P=75T='5U+@!0=75T='5V82!S97-S:6]N($E$
M+@!M80!-;V)I:6QI<^1H:_9P;W-T:0!+;VAT86QA:6YE;@!-=6]K:V%U:W-E
M;B!PY&EVY&WDY'+D`$UU;VMK86$@55),.FEA`$ME<G)O:6X`36]L9&]V82P@
M=&%S879A;'1A`$UO;F%C;P!-;VYG;VQI80!K=75K875S:2!J82!V=6]S:0!+
M=75K875S:71T86EN`$UO;G1S97)R870`2W5U;B!V86EH965T`%)I=FEL=.0@
M)60@;/9Y='EI(&5N96UMY&X@:V5N='1IY"!K=6EN(&]D;W1E='1U("5D+@!-
M87)O:VMO`$5N:6UMY&MS:2!S96QK9>3D`$5N:6UMY&MS:2!P:6QV:7-TY`!%
M;FEM;>1K<V5E;B!P:6QV:7-TY"!J82!T=75L:7-T80!%;FEM;>1K<V5E;B!A
M=7)I;FMO:7-T80!3:6ER<N0@86QA<W#D:6X`4VEI<G+D('9A<V5M;6%L;&4`
M4VEI<G+D(&]I:V5A;&QE`%-I:7)RY"!Y;/9S<.1I;@!3:6ER<N0@86QA<W#D
M:6X`4VEI<G+D('EL]G-PY&EN`$UO<V%M8FEK`$UO;FET87-O:6YE;B!A;&%S
M=F5T;W9A;&EK:V\`375L=&EM87`@27-O+4)R:71A;FYI86X@:V%R='1A`$UO
M;FEV86QI;G1A`$OD>71TY&KD='5N;G5K<V5N:0!/;6%N(&OD>71TY&KD='5N
M;G5K<V5N('1I961O=`!/;6$@<&]R=&%A;&D`3VUA;B!P;W)T86%L:6X@87-E
M='1E;'4`37EA;FUA<B`H0G5R;6$I`$5)+"!%3B!S=6]S='4`3FEM:0!.86UI
M8FEA`$YA=7)U`$YE<&%L`$%L86YK;VUA870`06QA;FMO;6%I9&5N($%N=&EL
M;&ET`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I;VX@
M55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!5
M4DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,+7!A;'9E
M;&EM96X@;W-O:71E`$YE='-C87!E('9A<FUE;G1E96X@:V]M;65N='1I`$YE
M='-C87!E('9A<FUE;G1E96X@='EY<'!I`%9E<FMK;P!%:2!K;W-K86%N`%5U
M<VDM2V%L961O;FEA`%5U<VD@;'5O:VET=7,`575S:6MU=0!5=7-I(&OD>71T
MY&KD='5N;G5S("AV87!A865H=&]I;F5N*0!5=7-I+5-E96QA;G1I`%5U<VD@
M<V%L87-A;F$`575S:2!S86QA<V%N82!V86YH96YE92`E>"X`06YT86UA<VD@
M=75D970@<V%L87-A;F%T(&5I=N1T('3D<VWDY"X`575S:2!I:VMU;F$@*%]B
M;&%N:RD`575T:7-E=`!+97-K=7-T96QU<GEH;>1T`%-E=7)A879A`%-E=7)A
M879A="`T('9A:6AE='1A`%-E=7)A879A="!A<V5T=6MS970`4V5U<F%A=F$^
M`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`%GV`$YI=64`16D`07-E='5S=&EE
M=&]J82!E:2!O;&4@<V%A=&%V:6QL82P@:F]S=&$@=F]I<VD@;N1Y='3DY"!E
M<F]A=F%I<W5U:W-I82X`16D@;VQE('-A871A=FEL;&$@<W5U;FYI=&5L;6%A
M($E33R!L979Y:W5V871I961O<W1O:F5N('1E:V5M:7-E:W-I+@!%:2!E<N1M
M86QL:6$N`$]S:6]T82!E:2!O;&4@<'EY9&5T>7-SY"!P86EK87-S82X`2V%L
M96YT97)I;B!N:6UEY"!E:2!O;&4@86YN971T=2!-0T%,+6%U=&5N=&EK;VEN
M;FEL;&4N`$5I(&UU=71O<W1A+@!!;&ET87-O:F$@96D@=F]I(&QI<^1TY"!T
MY&QL92!O:6ME=61E;&QE+@!!<V5T=6MS:6$@96D@;/9Y='EN>70@)7,Z;&QE
M+@!!<V5T=6MS:6$@96D@;/9Y='EN>70@1E10(%9&4SIL;&4N`$%S971U:W-I
M82!E:2!L]GET>6YY="!344P@5D93.FQL92X`07-E='5K<VEA(&5I(&SV>71Y
M;GET(%-13"U&:6QE(%9&4SIL;&4N`$MR961I:71I="!L;W!P=2X`2V]H9&5T
M=&$@96D@86YN971T=2X`16D@='5O='4@86EN=71T86MA86X@=&EE9&]S=&]A
M`$EK;VYE:71A(&5I(&SV>71Y;GET+@!086EK:V%A(&5I(&]L92!A<V5T971T
M=2X`4&%I:VMA82!E:2!O;&4@86YN971T=2X`16D@86YN971T=2!V:65S=&GD
M+@!.:6UEY"!E:2!O;&QU="!A;FYE='1U+@!,=6MU;>3D<N3D(&5I(&]L;'5T
M(&%N;F5T='4N`$5I(&QO=6MK86%V870@;6EE=&5L875S965T`%-A;&%S86YA
M82!E:2!O;&4@86YN971T=2!(5%10+6%U=&5N=&EK;VEN;FES<V$N`%-A;&%S
M86YA82!E:2!O;&4@86YN971T=2!)34%0+6%U=&5N=&EK;VEN;FES<V$N`%-A
M;&%S86YA82!E:2!O;&4@86YN971T=2!+97)B97)O<RUA=71E;G1I:V]I;FYI
M<W-A+@!386QA<V%N86$@96D@;VQE(&%N;F5T='4@3&]G:6X@875T96YT:6MO
M:6YN:7-S82X`4V%L87-A;F%A(&5I(&]L92!A;FYE='1U(%!!4U-71"UA=71E
M;G1I:V]I;FYI<W-A+@!386QA<V%N86$@96D@;VQE(&%N;F5T='4@4TU"+6%U
M=&5N=&EK;VEN;FES<V$N`%!O;&MU82!/<&5N4U-,(&MO;65N=&]O;B!E:2!O
M;&4@;>3D<FET96QT>2X@3W!E;E-33"!P:73DY"!O;&QA(&OD>71E='3D=FES
M<^0@:F]S(&OD<VET96QLY.1N(%!+0U,@,3(@9&%T86$N`$5I('-I<^3D;FMI
M<FIA=71U;6ES<'EY;G3V:N0@:F]N;W-S82X`2VEI;G1I]G3D(&5I(&]L92!A
M<V5T971T=0!%:2!SY.1N=/9JY`!%<F]T:6YT82!E:2!O;&4@;>3D<FET96QT
M>2X`16D@<F5U;F]J80!%:2!L]GET>6YY="!T:65D;W-T;V$`5N1L:6UU:7-T
M:6QL92!E:2!O;&4@=N1L:6%I:V%I<VAA:V5M:7-T;V$N`$OD>71TY&KD='5N
M;G5S=&$@=&%I('-A;&%S86YA82!E:2!LY&AE=&5T='DN`$MA:6MK:2!P86QA
M=71U;G5T(%A-3"UD871A(&]L:2!E<.1K96QP;V$`16D@87)V;VIA`%9E<G-I
M;W1I971O:F$@96D@;/9Y='EN>70@86QK=7!E<N1I<VETY"!A<V5T=6MS:7-T
M82X@4VEN=6X@<&ETY.0@=&5H9.0@87-E='5K<V5T('5U9&5S=&%A;BX`5F5R
M<VEO=&EE=&]J82!E:2!L]GET>6YY="!A<V5T=6MS:7-T82X@4VEN=6X@<&ET
MY.0@=&5H9.0@87-E='5K<V5T('5U9&5S=&%A;BX`16D@;6ETY.1N`$5I(&UI
M=.3D;B`H2^1Y=.0@:6UP;&ES:6ET=&ES=.0I`$QA<'!I+U!O:&IO:7-M86%T
M+T5S:VEM;R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@<V%A<F5T`%!O:&IO:6YE
M;B!P86QL;VYP=6]L:7-K;P!0;VAJ;VES970@36%R:6%A;FEE;B!S86%R970`
M3F]R:F$`16D@:N1L:V5E;@!%:2!E;FYE;@!%:2!O;&4@:&%K96UI<W1O`$5I
M(&]L92!T;W1E=71E='1U+@!%:2!A<V5T971T=0!%:2!T=65T='4N`$UU:7-T
M:6EN<&%N;W0`16D@;6ETY.1N('-E;&%T=&%V86$L('!A;&%A('1A:V%I<VEN
M+@!M87)R87-K=74`3'5K=6WDY'+D`$UE<FMK:65N(&QU:W5MY.1RY`!387)A
M:VME:61E;B!L=6MU;>3D<N0`4FEV:65N(&QU:W5MY.1RY`!*86ME;'5L:7-T
M86X@;G5M97)O:71A(&5I(&]L92!MY.1R:71E;'1Y('#D:79I=&5T=.1VY&MS
M:2X`3TL`3V)J96MT:0!/8FIE:W1I;B!L=6]J80!/:W1A86QI`&QO:V%K=74`
M3&]U:VMA879U=7-S=6]D871I;@!4;VEM:7-T;P!5=7-I('-A;&%S86YA(&5I
M('-A82!O;&QA('-A;6$@:W5I;B!N>6MY:6YE;B!S86QA<V%N87-I+@!686YH
M82!S86QA<V%N80!686YH82!S86QA<V%N82!O;B!VY.1R:6XN`$]M86X`5F%I
M;B!)34%0+7!A;'9E;&EM970@='5K979A="!J865T='5J82!K86YS:6]I=&$N
M`%9A:6X@;&]U:VMA879A="!M:65T96QA=7-E970`5F]I="!L86ET=&%A('9A
M:6X@>6AD96X@<^1H:_9P;W-T:6]S;VET=&5E;BX`5F%I;B!O;6ES=&%J82!T
M86D@:N1R:F5S=&5L;>1N('EL;.1P:73D:N0@=F]I(&UU=71T86$@:F%K;VIE
M;B!O;6ES=&%J:6$@=&%I(&]I:V5U:W-I80!!=F%A('5U9&5S<V$@:6MK=6YA
M<W-A`$]P96Y34TP@=FER:&4Z(%1I971O:F$@96D@<V%A='4@97-I;&QE(&%L
M;&5K:7)J;VET971U<W1A(%,O34E-12UO<V%S=&$N`$%V86$@=.1MY&X@;&EN
M:VEN('5U9&5S<V$@:6MK=6YA<W-A`$OD>71T]FKD<FIE<W1E;&WD`$%S971U
M:W-E=`!!<V5T=6MS970@)7,Z;&QE`$KD<FIE<W1E='1Y(&QI<W1A`$]R9V%N
M:7-A871I;P!/<F=A;FES86%T:6]Y:W-I:VOV`$]R9V%N:7-O:6YT:0!!;&MU
M<&5RY&EN96X@;VAJ96QM86X@;6%L;&D`06QK=7!E<N1I<V5T(&UA;&QI="`E
M<SIS<^0Z`$UU=0!-=75T('1I961O=`!/;6ES=&%J86X@;VEK975D970`4$%-
M+6%U=&5N=&EK;VEN=&EA(&5I(&]L92!KY'ET971TY'9I<W/D+@!014%2.CI-
M86EL('1A=7-T86KD<FIE<W1E;&WD`$1I9VET86%L:6YE;B!01U`M86QL96MI
M<FIO:71U<P!01U`M<V%L871T=6$@=&EE=&]A`$IU;&MI;F5N(%!'4"UA=F%I
M;@!01U`M86QL96MI<FIO:71E='1U82!J82!S86QA='1U82!T:65T;V$`4$A0
M+6MO;V1I`%!(4"UK;VUE;G1O='5L:VMI`%!-(&ME=GET=.0@<V%D971T80!0
M32!S861E`%!-(&MU=7)O:F$`4$T@;'5M:0!032!L=6UI<V%T96ET80!032!L
M=6UI`%!-('5K:V]S;7ER<VMY:N0`4$]325@M;&%A:F5N;G5K<V5T('!U=71T
M=79A=`!07TA0+6MO;65N=&]T=6QK:VD`5.1Y=&4`4&%K:7-T86X`4&%L874`
M4&%L97-T:6EN82`H;6EE:&ET971T>2!A;'5E*0!086YA;6$`4&%P=6$@575S
M:2U'=6EN96$`4&%R86=U87D`3W-I='1A:6X@<&EL=FES=.0`4V%L87-A;F$`
M4V%L87-A;F%N('9A:6AT;R!O;FYI<W1U:2X`5N3D<N0@<V%L87-A;F$`4V%L
M87-A;F%A('1A<G9I=&%A;B!2041)55,M875T96YT:6MO:6YT:6EN+@!386QA
M<V%N82!V87)M:7-T=6MS96QL80!386QA<V%N83H`4V%L87-A;F$Z(`!386QA
M<V%N;VIE;B!P:73DY"!O;&QA('-A;6%T+@!,:6ETY`!,:6ETY"!L96EK97#V
M>63D;'3D`%!O;&MU`$IO;F]S<V$@;VQE=F%T('-I<^3D;FMI<FIA=71U;6ES
M<'EY;F[V=#H`26AM:7-E=`!0<F]S96YT=&D`4W5O<FET82!Y;&SD<&ET;W1O
M:6UE;G!I=&5E=`!3=6]R:71A('EL;.1P:71O=&]I;65N<&ET965T('-I<^3D
M;FMI<FIA=71U;6ES96X@>6AT97ED97-SY"X`3VEK975S`$]I:V5U='1A("(E
M<R(@96D@<&]I<W1E='1U+@!+Y'ET=/8@:VEE;&QE='1Y`$]I:V5U9&5T`$]I
M:V5U:W-I96X@>6QLY'!I=&\`3VUA="!T:65D;W0`4&5R=0!,96UM:6MI=`!&
M:6QI<'!I:6YI=`!0=6AE;&EN`%9A;&]K=79A=`!0:71C86ER;@!0:6MS96QI
M`$ML:7-E970`3F%P<V%U=&$@:F]T86EN('-O;'5A`%9A<FUI<W1A(&5T=.0@
M:&%L=6%T('!O:7-T86$@=.1MY&X@96QE;65N=&EN.@!687)M:7-T82!E='3D
M(&AA;'5A="!P;VES=&%A(&QI;FMI='EK<V5N('3D:.1N(&5L96UE;G1T:6EN
M+@!!;FYA(&MU=6MA=7-I(&IA('9U;W-I+@!!;FYA(&YI;6D@=75D96QL92!L
M=6]K:71U:W-E;&QE.@!!;FYA(&]I:V5A($E0+6]S;VET92X`06YN82!O:6ME
M82!PY&EVY&WDY'+D.R!487)K:7-T82!PY&EV:65N(&QU:W5MY.1RY"!K=75K
M875D97-S82X`06YN82!A:6MA(&]I:V5A<W-A(&UU;V1O<W-A+@!!;FYA(&QY
M:'ET(&MU=F%U<R!O;F=E;&UA<W1A+@!!;FYA(&OD>71TY&KD='5N;G5K<V5S
M:2!J82!S86QA<V%N87-I`$QU92!S975R86%V82!T96MS=&DN(%-I;G5N(%!)
M5,3$('-U;W-T=6$@:^1Y='3V96AT;VEH:6X@=F]I9&%K<V5S:2!KY'ET=.3D
M(&KD<FIE<W1E;&WDY"X`06YN82!N:6UI('5U9&5L;&4@;'5O:VET=6MS96QL
M93H`4'5O;&$`4&]L:71I:6MK80!+>7-E;'ET`%!O<G1U9V%L:0!4Y&WD;B!K
M=79A;B!P86EK:V$`5.1MY&X@=&%U;'5K;VX@<&%I:VMA`%9O:2!LY&AE='3D
MY"!V:65S=&5JY"!K86YS:6]O;B`H96D@:V]S:V4@24U!4"!Y:'1E>6MS:>0I
M`%-A9&5MY.1RY"!E9&5L;&ES:6QL92`E<R!T=6YN:6QL93H@`$AA:6AT=79U
M=7,@/&)R("\^=&]D96YNY&OV:7-Y>7,`4')E9G-?;&1A<#H@5&%R=FET=&%V
M86$@3$1!4"UL86%J96YN=7-T82!E:2!L]GET>6YY="X`4')E9G-?<V5S<VEO
M;CH@5&%R=FET=&%V86$@<V5S<VEO;BUL86%J96YN=7-T82!E:2!L]GET>6YY
M=`!);&UA;G!A:6YE`$EL;6%N<&%I;F4@;65R96YP:6YN87-S83H@`$EL;6%N
M<&%I;F4Z(`!%<VEK871S96QU`$5S:6MA='-E;&4@:W5V82!U=61E<W-A(&EK
M:W5N87-S80!%9&5L;&ES970@87-E='5K<V5T`%1U;&]S=&$@9&]K=6UE;G1T
M:0!386QA:6YE;B!A=F%I;@!/;F=E;&UA`$]N9V5L;6%N(&MU=F%U<P!0<F]J
M96MT:70`2V5H;W1T965N('1E:W-T:0!*=6QK:6YE;B!A=F%I;@!*=6QK:7-E
M;B!A=F%I;65N(&%L9V]R:71M:0!*=6QK:7-E;B!A=F%I;65N('1I961O=`!*
M=6QK:7-E;B]S86QA:7-E;B!A=F%I;G!A<FEN(&QU;VYT:2!E<.1O;FYI<W1U
M:2X`4'5E<G1O(%)I8V\`5F]I('1U:&]T82!P;VES=&5T='5J82!V:65S=&5J
MY`!1871A<@!+>7-E;&4`2VEI;G1I]@!24T$@2G5L:VEN96X@879A:6X@*"5D
M(&)I='1IY"D`4F%D:6]P86EN:6ME`%-A9&4`4V%D971T82!A:6MA:7-I;@!3
M861E='1A(&UY]FCDY&X`4V%D96MU=7)O`%9E<VD@:F$@;'5M:0!6961E<W3D
M(&QU;65E;@!3871U;FYA:6YE;B!M:65T96QA=7-E`%-U:&1E`$QU:W4`5F]I
M(&QU:V5A('9I97-T96KD`%!O:7-T971A86YK;R`E<S\@5.1TY"!T;VEM:6YT
M;V$@96D@=F]I('!E<G5U='1A82X`4&]I<W1E=&%A;FMO('1I961O="!KY'ET
M=.1JY'-TY"`E<S\@5.1TY"!T;VEM:6YT;V$@96D@=F]I('!E<G5U='1A82X`
M5&5E(&UU=71O:W-E="!U=61E<W1A86X`4.1I=FETY`!0Y&EVY'0@9'EN86%M
M:7-E="!V86QI:VMO96QE;65N=&ET.@!0Y&EV:73D('!O<G1A86QI;N1K>6WD
MY#H`4^3D;F[V;&QI;F5N(&QA=7-E:V4`4F5L86%T:6]S96QA:6X`3&%T86$@
M=75D96QL965N`$UU:7-T:6EN<&%N;W0`173D<&%L=F5L:6UE=`!%=.1P86QV
M96QU;B!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!0;VES
M=&$`4&]I<W1A(&]S:6\`4&]I<W1A('-A<F%K90!0;VES=&$@;75O=&]I;'4`
M4&]I<W1A('!A<FD`4&]I<W1A('1A;&QE=&5T='4@<VMR:7!T:2!P86QV96QI
M;65N(';D;&EA:6MA:7-H86ME;6ES=&]S=&$N`%!O:7-T80!0;VES=&$@=.1M
MY"!N;V]D:2!D;VMU;65N=&ES=&$`4&]I<W1A(&OD>71TY&KD`%!O:7-T82!K
MY'ET=.1JY#H@)7,`4'EY;G3V]FX@96D@=F]I='4@=F%S=&%T82X@5FER:&5K
M;V]D:3H@`%!Y>61E='1YY"!P86QV96QU82!E:2!L]GET>6YY="X`5&%R=FET
M=&%V86$@(B5S(BUT:65T;V$@96D@;VQL=70@;>3D<FET96QT>2`E<R!A<V5T
M=6MS:7-S82X`5&%R=FET=&%V86$@(B5S(BUT:65T;V$@96D@;VQL=70@;>3D
M<FET96QT>2!61E,@87-E='5K<VES<V$N`%1A<G9I='1A=F%A("(E<R(M=&EE
M=&]A(&5I(&]L;'5T(&WDY')I=&5L='D@87-E='5K<VES<V$N`%!A:V]L;&EN
M96X@:V5N='3D`%1Y:&IE;F[D`%1Y:&IE;F[D('-A;&%S86YA`%1Y:&IE;F[D
M('-A;&%S86YA<VD`4&%L875T82!E9&5L;&EN96X@:WES96QY`%1U;&]K<V5T
M`%!A;&%A(&%S971U:W-I:6X`5F%H=FES=&$@=75S:2!S86QA<V%N80!2975N
M:6]N`%!A;&%U=&$@87-E='5K<V5T`%)I8V@@5&5X="!%9&ET;W)I;B!A<V5T
M=6MS970`07)V;VET=6MS970`3VEK96$`3VEK96$@;W1S86ME`$]I:V5A(&%R
M=F]T`%)I=FE?;B!T:65D;W0N+BX`4F]O;&D`4F]M86YI80!+Y.1N;N0@,3@P
M`$ODY&YNY"!V87-T87#D:7;DY&X`2^3D;F[D(&UY]G3D<.1I=N3D;@!2:79I
M;B!T:65D;W0`4FEV:6X@=&EE9&]T`%)I=FET.@!6:6EV;VET:6X`5FEI=F]I
M=&EN(&[D:WEY(&MA:6MK:65N(')I=FEE;B!J82!S87)A:VME:61E;B!VY&QI
M;&SD`%9I:79O:71I;B!NY&MY>2!V86EN('-A<F%K:V5I9&5N(';D;&EL;.0`
M5FEI=F]I=&EN(&[D:WEY('9A:6X@<FEV:65N(';D;&EL;.0`4W5O<FET80!6
M96[D:N1N($9E9&5R871I:79I;F5N('1A<V%V86QT80!2=6%N9&$`4R]-24U%
M(&MR>7!T;V=R86%F:6YE;B!A;&QE:VER:F]I='5S`%,O34E-12!S86QA='1U
M('9I97-T:0!305-,+6%U=&5N=&EK;VEN=&D@96D@;VQE(&OD>71E='3D=FES
M<^0N`%--4R!496MS=&EV:65S=&ET`%-13"UK;VUE;G1O='5L:VMI`%-13"UL
M875S92!A<G9O:F5N(&AA:V5M:7-E96X`4U-(`$].3DE35%5)`%-?44PM:V]M
M96YT;W1U;&MK:0!L80!386EN="!(96QE;F$`4V%I;G0@2VET=',@:F$@3F5V
M:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&IA($UI<75E;&]N`%-A:6YT
M(%9I;F-E;G0@:F$@1W)E;F%D:6EN:70`4V%M86%N(&ME:'EK<V5E;B`H7W-E
M;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@:F$@4')I;F-I<&4`4V%T
M96QL:6ET=&D@<&%L=F5L=6YT87)J;V%J80!3875D:6$@07)A8FEA`%1A;&QE
M=&$`5&%L;&5T82`B)7,B`%1A;&QE=&$@)7,`5&%L;&5T82!A<V5T=6MS970`
M5&%L;&5T82!L=6]D=70@87-E='5K<V5T(%!(4"US:W)I<'1I;N0@<&%L=F5L
M:6UE<VD@=N1L:6%I:V%I<VAA:V5M:7-T;V]N+B``5&%L;&5T971T:6EN("5S
M.FX@87-E='5K<V5T+@!!<V5T=7-T96X@<.1I=FET>7-S:W)I<'1I(&]N('1A
M;&QE=&5T='4@<&%I:VMA86XZ("(E<R(N`$AA:F%N86ES:6$@=6MK;W-M>7)S
M:WEJY`!4:65D90!(86MU`$AA:W5K;VYE970`5F%L:71S92!T:65D;W-T;W0`
M5F%L:71S92!PY&EVY&WDY'+D`%9A;&ET<V4@;&ESY'1TY';D(')Y:&WD`%9A
M;&ET<V4@=75S:2!O;6ES=&%J80!686QI='-E('!A;'9E;&EN`%9A;&ET<V4@
M;&ESY'1TY';D(&OD>71TY&KD`%9A;&ET<V4@:V%I:VMI`%9A;&ET<V4@:V%I
M:VMI('#D:7;D;>3D<N1K;VUP;VYE;G1I=`!686QI='-E(&]B:F5K=&D`5'EH
M:F5N;N0@=F%L:6YT80!686QI='-E('1A<G9I='1A=F%T(&UE<FMI="!A;&QA
M(&]L979I<W1A('9A;&EK;VES=&$N(%9O:70@<V5N(&KD;&ME96X@:V]P:6]I
M9&$@:F$@;&EI='3DY"!M97)K:70@=&5K<W1I:7-I+@!686QI='-E('#D:7;D
M>6MS96X@97)O=&EN;65R:VMI.@!686QI='-E('#D:7;D>6MS96X@97-I='ES
M=&%P83H`5F%L:71S92!M=75T971T879A('!R;V9I:6QI.@!686QI='-E(&ME
M;&QO;F%J86X@97)O=&EN;65R:VMI.@!686QI='-E(&%J86X@97-I='ES=&%P
M83H`5F%L:71S92!K86MS:2!Y:'1E96YS;W!I=F%A(&ME;G1TY.0N`%9A;&ET
M<V4@=N1R:71E96UA+@!686QI='-E(&OD>71E='3D=N0@:VEE;&DZ`$SD:&5T
MY"!O;F=E;&UA=FEE<W1I`$SD:&5TY"!335,`4V5N96=A;`!4=6YN:7-T:6XZ
M(`!S>7ES:W5U`%-E<F)I82!J82!-;VYT96YE9W)O`%-A<FIA;G5M97)O`%!A
M;'9E;&EM96X@=&EE9&]T(&]V870@=N3D<FGD('1A:2!E:7;D="!O;&4@:^1Y
M=&5T=.1V:7-SY"X`27-T=6YT;VIE;B!H86QL:6YT80!397-S:6]N($E$(&]N
M('9A;FAE;G1U;G5T+@!)<W1U;FYO=`!!<V5T80!386QA<V%N86X@<F5S971O
M:6YT:6EN(&QI:71T>79IY"!A<V5T=6MS:6$L(&IO<R!J;W-K=7,@=6YO:&1A
M="!S86QA<V%N87-I+@!6;VET(&%S971T86$@=6QK;VES=&5N('!A;'9E;&EM
M:65N(&%S971U:W-E="P@:F]I=&$@:&%L=6%T(&OD>71TY.0@<&]R=&%A;&ES
M<V$N`%9O:70@87-E='1A82!KY'ET971TY';D;B!K:65L96XL(&%I:V%V>?9H
M>6MK965N(&IA(&UU:71A('#D:7;D;>3D<N1A<V5T=6MS:6$N`%9O:70@87-E
M='1A82!A;&]I='5S;VAJ96QM86XL(';D<FET965M86XL(&[D:WEMY&X@<.1I
M=FET>6MS96X@:F$@;75I=&$@;N1K>6WDY&X@;&EI='1Y=FGD(&%S971U:W-I
M82X`07-E;FYU<P!!<V5N;G5K<V5N('#D:79I='ES<VMR:7!T:2!O;B!S86%T
M879I;&QA`%5S96%T('!A:6MA="!S;W!I=F%T(&%N;F5T='5U;B!P87)A;65T
M<FEI;CH@`%-E>6-H96QL:70`3W-T;VMS970`3'EH>70@:W5V875S.@!!<V5T
M971A('!I:V%V86QI;G1A;N1P<.1I;65T('5S96EM;6EL;&4@;&EN:V5I;&QE
M+@!.Y'ETY`!.Y'ETY"!E<F]A=F%I<W5U9&5T(&%S971U:W-I96X@=&%L;&5T
M971U<W-A(&IA('5U9&5S<V$@:G5U<FD@;75O:V%T=7-S82!V97)S:6]S<V$N
M`$[D>73D(&5D96QL:7-E;B!S:7/DY&YK:7)J875T=6UI<V5N('#D:7;D>7,N
M`$[D>73D(&%S971U<R!P:73DY&MS97-I(&%L:W5P97+D:7-E;@!.Y'ETY"!V
M86QI='-I;@!.Y'ETY"!T875L=6MK;W1O:6UI;FYO="!V86QI:VMO+@!.Y'ET
MY"!V87-E;6UA;&QA("5S('9A;&EK:V\N`$[D>73D('1A=6QU:V]N('-O;'5N
M('1I961O="!D:6%L;V=I`$[D>73D('1A=6QU:V]N('1I961O="!D:6%L;V=I
M`$[D>73D('1A=6QU:V]N(')I=FEN('1I961O="!D:6%L;V=I`$[D>73D(&MU
M=F%N('1I961O="!D:6%L;V=I`$[D>73D('1U;VYT:0!3871E:71A`%-A=&5I
M=&$@86EK86ES:6X`4V%T96ET82!M>?9H96UM:6X`4V%T96ET82!LY&AE='1Y
M=FEL;&$`4&EE;F5N;N0`4&EE;F5N;N0@=&%I('-I:7)RY"!V:65R96ES:>0@
M;W-I;VET82P@:F]T=&$@;F4@96EVY'0@;VQE('1I96QLY`!3:65R<F$@3&5O
M;F4`2VER:F%U9'4`06QL96MI<FIO:71U<P!!;&QE:VER:F]I='5K<V5N(&%L
M9V]R:71M:0!3:6YG87!O<F4`2V]K;P!/:&ET82!Y;&SD<&ET;W1E:'3D=N1T
M`%-L;W9A:VEA`%-L;W9E;FEA`$QU;6D`3'5M:7-A9&5T=&$`3'5M:7-A=&5I
M=&$`3'5M:7-A=&5I=&$@86EK86ES:6X`3'5M:7-A=&5I=&$@;7GV:.3D;@!,
M=6UE;B!S>79Y>7,Z(`!,=6UE;B!MY.1RY"!V971E;N0Z(`!386QO;6]N('-A
M87)E=`!3;VUA;&EA`$QA=6QU="!J82!2=6YO=7,`2N1R:F5S='EK<V5N('-U
M=6YN86X@=F%L:6YT80!,Y&AD96]S;VET90!%=&5LY"U!9G)I:VMA`$5T96SD
M+45U<F]O<'!A("A)4T\M.#@U.2TS*0!%=&5LY"U'96]R9VEA(&IA(&5T96SD
M:7-E="!386YD=VEC:"!S86%R970`171E;.1I;F5N('!A;&QO;G!U;VQI<VMO
M`%;D;&D@=FEE<F5I<V5T('-O;'5J96X@=N1L:7-SY`!6Y&QI('-O;'5N(&QE
M:7#D=&5K<W1I;B!J82!R975N86X@=N1L:7-SY"``5N1L:0!6Y&QI`%;D;&D@
M:F$@=.1Y=&4`17-P86YJ80!2;W-K87!O<W1I`$5R:6MO:7-M97)K:VEE;B!S
M>?9T=/8`2F%A('-O;'4`2F%A('-A<F%K90!*86$@<FEV:0!5<FAE:6QU`%-R
M:2!,86YK80!3=&%N9&%R9&D`4W1A<B!4<F5K`$%L:V%M:7-V=6]S:0!,Y.1N
M:2!T86D@86QU90!4:6QA`%1A;&QE;FYU<VUU;W1O`$MA='5O<V]I=&4`3.1P
M:6QY]FYT:0!-97)K:VEJ;VYO;&ES=&$`4&]I<W1A('1O:6UI86QU92!O<V]I
M='1E97-T80!4>7EL:2!;0U-370!S=0!!;&EH86ME;6ES=&]A("(E<R(@96D@
M;/9Y='EN>70N`$]T<VEK:V\`3.1H973D`$SD:&5T971T:6EN("(E<R(Z;B!L
M:7/D>7-P>7EN=/8N($5T('9O:2!K:7)J875T=6$@<VESY.1N(&5N;F5N(&MU
M:6X@<'EY;G3V<VD@;VX@:^1S:71E;'1Y(&IA(&AY=N1K<WET='DN`$%L:6MI
M<FIO:71U<P!/;FYI<W1U:0`B)7,B.B!L:7/DY&UI;F5N(&KD<FIE<W1E;&WD
MY&X@;VYN:7-T=6DN`$OD>71TY&KD;B`B)7,B(&OD>71TY&KD=&EE=&]J96X@
M<&]I<W1A;6EN96X@:N1R:F5S=&5L;>1S=.0@;VYN:7-T=6DN`"(E<R(@<&]I
M<W1E='1I:6X@;VYN:7-T=6YE97-T:2X`(B5S(CH@;VYN:7-T=71T:6EN('!O
M:7-T86UA86X@:N1R:F5S=&5L;>1S=.0N`%!A;&%T=&EI;B!O;FYI<W1U;F5E
M<W1I('9A;FAO:6AI;B!A<V5T=6MS:6EN+B!,871A82!S:79U('5U9&5S=&%A
M;B!NY&ADY&MS97-I(&UU=71O:W-E="X`5&%L;&5N;F5T=&EI;B!A<V5T=6MS
M:65N('9A<FUU=7-K;W!I;RX`5&%L;&5N;F5T=&EI;B!A<V5T=6MS:65N('9A
M<FUU=7-K;W!I;R`E<RX`)R5S)SH@<.1I=FET>7,@;VYN:7-T=6DN`"5S.FX@
M:VER:F]I='1A;6EN96X@;VYN:7-T=6DN`%-U9&%N`%EH=&5E;G9E=&\`075R
M:6YG;VYN;W5S=0!!=7)I;F=O;FQA<VMU`$%U<FEN:V]I;F5N`$%U<FEN9V]N
M;F]U<W4`075R:6YK;R!N;W5S964O;&%S:V5E`$%U<FEN9V]N;F]U<W4Z(`!!
M=7)I;F=O;FQA<VMU`$%U<FEN9V]N;&%S:W4Z(`!0Y.1L;&5K:7)J;VET=7,`
M5'5K:0!3=7)I;F%M`%-U:W5N:6UI`$AU:7!P=79U;W)E="!J82!*86X@36%Y
M96X`4W=A>FEM86$`4G5O='-I`%-V96ET<VD`4WEN8R!L;VMI('!O:7-T971T
M=0!3>6YC34P`4WEN=&%K<VEV:7)H92!H86MU=&5R;65I<W/D`%-Y>7)I82P@
M87)A8FET87-A=F%L=&$`56MK;W-M>7)S:WD`56MK;W-M>7)S:WEJY"!J82!T
M=75L:7-T80!5:VMO<VUY<G-K>70`56MK;W-M>7)S:WEJY"!A:6MA:7-I;@!4
M4U8M=&EE9&]S=&\`5&%U;'5K:V\`5&%U;'5K;VX@=&EE9&]T`%1A=6QU:V]N
M(&%S971U:W-E=`!4875L=6MO;B!T:65D;W0`5&%I=V%N`%1A:7=A;BP@2VEI
M;F%N(&UA86MU;G1A`%1A9'II:VES=&%N`%1A;GIA;FEA+"!9:&1I<W1Y;GET
M('1A<V%V86QT80!+;VAD93H`5&5H=.1VY'0`4'5H96QI;FYU;65R;P!,Y&UP
M]G1I;&$@961E;&QI<V5L;&4@='5N;FEL;&4Z(`!,Y&UP]G1I;&$`3.1M</9T
M:6QA.B``3.1M</9T:6QA/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`
M36%L;&EA("(E<R(@96D@;/9Y='EN>70N`$UA;&QI96X@:&%L;&EN=&$`5&5K
M<W1I`%9A:6X@=&5K<W1I`%1E:W-T:6X@=&%S875S`%1E:W-T:71O<`!T;P!4
M:&%I("A425,M-C(P*0!4:&%I;6%A`$944"UL:7/D=&]I;6EN=&\@96D@;VQE
M(&OD>71E='3D=FES<^0N`$AI<W1O<GD@:N1R:F5S=&5L;>0@96D@;VQE(&OD
M>71E='3D=FES<^0N`$AO<F1E+TMO;&%B(&EN=&5G<F]I;G1I;6]O='1O<FD@
M96D@='5E("(E<R(`24U34"!L;VMI82!E:2!V;VET=2!A;'5S=&%A+@!-86EN
M=&5N86YC93HZ("UL=6]K86X@;&%T86%M:6YE;B!E<.1O;FYI<W1U:0!!<V5T
M=6MS970@:6MK=6YA(&]N('-U;&IE='1U+B!0;VES='5T86%N+@!9;&SD<&ED
M;VX@<&ETY.0@;W1T86$@:^1Y='3V]FX@<'ES>7;D('1A;&QE='5S='EY<'!I
M(%!E<FUI<W-I;VXL(&IO<R!H86QU870@:^1Y='3DY"!N:6ETY"X`5F%I;B!A
M;&%P=6]L:0!#;VYT86-T(&ED(&YU;65R;V$@96D@;VQE(&WDY')I=&5L='DL
M(&]N('1Y:&KD('1A:2!E:2!L]GET>6YY="!T:65T;VMA;FYA<W1A+@!9:'1E
M>7-T:65D;W0@;&ESY'1T:6EN(&]N;FES='5N965S=&D@;W-O:71E:VER:F%A
M<VDN`%9I97-T:6X@86QL96MI<FIO:71U:W-E;B!T87)K:7-T86UI<V5E;B!T
M87)V:71A86X@97)I;&QI;F5N(%!'4"UA;&QE:VER:F]I='5S;&]H:V\N`$IA
M:V5L=6QI<W1A;B!)1"!E:2!O;&QU="!MY.1R:71E;'1Y+"!O;B!T>6AJY"!T
M86D@96D@;/9Y='EN>70@=&EE=&]K86YN87-T82X`2F%K96QU;&ES=&%A(&5I
M(&]L;'5T(&WDY')I=&5L='DN`%-A;&%U<W1O:6UI;FYO;B!KY'ET=/8@=F%A
M=&D@<V%L871T=6$@5U=7+7EH=&5Y='3D+@!4:65D;W-T;W-S82`E<R!P:73D
M:7-I(&]L;&$@)7,@87-E='5S+@!4:65D;W-T;W-S82`E<R!P:73D:7-I(&]L
M;&$@:F]I=&%K:6X@)7,@87-E='5K<VEA+@!4:65D;W-T;V$@96D@=F]I9&$@
M:V]P:6]I9&$@:71S96YSY"!PY.1L;&4N`%1I961O<W1O(&]L:2!T>6AJY"X`
M4V5U<F%A=F%S<V$@;VX@;W1S:6MK;W1I961O="!TY'-TY"!M97-S86=E+W)F
M8S@R,B`M=FEE<W1I<W3D+@!+;VMO<G5U9'5N(&[D>71T]G1I;&$@86EH975T
M=&%A(&]N9V5L;6EA(&IO:6QL86MI;B!);G1E<FYE="!%>'!L;W)E<B!S96QA
M:6UE;B!KY'ET=.1J:6QLY"X@5F%L:71E='1A=F%S=&D@:WES96EN96X@<V5L
M86EN('-I<^1L=.3D('!I:7)T96ETY"!J82!V:7)H96ETY"!J;VEH:6X@96D@
M;VQE(&SV>71Y;GET(&MO<FIA=7-T82!T86D@:V5I;F]A(&MI97)TY.0@;VYG
M96QM82X@2'5O;6%A=&AA;B!E='3D(&IO<R!KY'ETY'0@=.1TY"!NY'ET=/9T
M:6QA82!J82!);G1E<FYE="!%>'!L;W)E<B!S96QA:6YT82P@;FEI;B!NY'ET
M=/8@<V%A='1A82!M96YNY"!S96MA:7-I;BP@:F]T:W5T('1O:6UI;FYO="!E
M:7;D="!T;VEM:2!T86D@<V5L86EN('-A871T86$@:V%A='5A+B!*;W,@:^1Y
M=.1T(%=I;F1O=W,@.7@@=&%I($U%('9E<G-I;W1A+"!N:6EN(&]N(&UA:&1O
M;&QI<W1A(&5T=.0@:^1Y='3V:N1R:F5S=&5L;>0@:V%A='5U(&YS+B`G1V5N
M97)A;"!0<F]T96-T:6]N($9A=6QT)R`M=FER:&5E<V5E;B!J82!S:6YU;B!P
M:73DY"!KY'EN;FES=.3D(&MO;F4@=75D97-T86%N+EQN7&X@375I<W1A(&5T
M=.0@<VEN=6$@;VX@=F%R;VET971T=2X@3F%P<V%U=&$@3TLM;F%P<'5L86$@
M:F]S(&AA;'5A="!K;VME:6QL92!E9&ET;W)I;B!K;VMO<G5U='4@;N1Y='3V
M=&EL86$N`%!O:7-T971T:6EN('!R;V9I:6QI("(E<R(N`%9A:6X@=F%S96X@
M<'5O;&D`1VYU4$<@;VAJ96QM86X@<VEJ86EN=&D@<&ETY.0@;>3D<FET96QL
MY"!#<GEP=%]P9W`Z.B`M;'5O:V%S<V$N`%9I97-T:2!LY&AE=&5T='D@)7,@
M=F%S=&%A;F]T=&%J86QL92`E<R!O='-I:VMO;F$@(B5S(B!O;B!NY'ET971T
M>2X*16D@;VQE(&UI=.3D;B!T86ME:71A('-I:73D(&5T=.0@=FEE<W1I(&]N
M(&QU971T=2!T86D@>6UMY')R971T>2X`3FEM:2!J;W1A(&OD>71E=.3D;B!L
M:6YK:71E='3D97-S82!L=6\@<VEV=6QL90!+96YT=&EE;B!MY.1RY"!P:73D
MY"!A;G1A82!N=6UE<F]I;F$N`$UO9'5U;&D@;W!E;G-S;"!T87)V:71A86X@
M2&]R9&5?0W)Y<'1?<VUI;64Z.B`M;'5O:V%N(&OD>71TY&UI<V5K<VDN`$%S
M971U<W1A("(E<R(@:V]S:V$@<V5N('1I961O="!Y;&ET=&EVY'0@=&%L;&5T
M=7-T879A;B!S=75R:6UM86X@<V%L;&ET=6X@<F%J86X`3VAJ96QM86$L(&IO
M;&QA('9O:2!K871S;V$@=FEE<W1I='EY<'!IY"`H)7,I+"!E:2!L]GET>6YY
M="!JY')J97-T96QMY'-TY"X`3&%I;F%U<VUE<FMK:2!P:73DY"!O;&QA('EK
M<VET=.1I;F5N(&UE<FMK:2X`5F%I;B!O:6ME82!J82!V87-E;B!P=6]L:0!6
M86EN(&]I:V5A('!U;VQI`$5R;W1I;B!P:73DY"!O;&QA('EK<VET=.1I;F5N
M(&UE<FMK:2X`4&%L=F5L:6X@(B5S(B!O;B!P;VES=&5T='4N`%!A;'9E;&EN
M("(E<R(@;VX@=&%L;&5T971T=2X`4VESY.1N:VER:F%U='5M:7-P>7EN=/8@
M)7,@;VX@<&]I<W1E='1U+@!-Y.1R:71E;'1YY"!R:79IY"`H)60I(&5I(&]L
M92!O;&5M87-S82X`5F%L:>1A:6MA:7-T:65D;W-T;V$@(B5S(B!E:2!O;&4@
M;VQE;6%S<V$N`$MI<FIO:71T86UA<VD@=&5K<W1I(&5I('9A<W1A82!T96MS
M=&GD(')U=61U;&QA+@!686EN('ELY'!U;VQI(&IA(&%L87!U;VQI`%9A:6X@
M>6SD<'5O;&D`5'5O='4@=&EE=&\@:.1V:7-I(&5D96QL:7-E;B!K;VAD86X@
M86EK86YA+@!4=6]T=6$@=&EE9&]S=&]A(&5I('9O:71U('1A;&QE='1A82X`
M3W-I;W1A('=E871H97(N8V]M(&5I(&]L92!KY'ET971TY'9I<W/D+@!4965M
M86AA:V5M:7-T;V$@(B5S(B!E:2!L]GET>6YY="X`07-E='5K<VEA(&5I(&]L
M92!S86%T879I;&QA+@!%:2!O;&4@;W-I;VET82P@:F]T:V$@=F]I9&%A;B!N
MY'ET=.3D('9I97-T:65N('EH=&5Y9&5S<^0N`%3D<W/D(&ME;G3D<W/D(&]N
M(&QI:6%N(&UO;G1A(&UE<FMK:>0N($%N;F]I="`E<R!M97)K:VGD.R!S:6YU
M;B!P:73DY"!A;G1A82!VY&AE;6WD;B!K=6EN("5S(&UE<FMK:>0N`$IO:71A
M:VEN(&]N9V5L;6EA("(E<R(@;&ESY.1M:7-E<W/D(&KD<FIE<W1E;&WDY&XZ
M("5S`$OD>71TY&KD;B`B)7,B(&OD>71TY&KD=&EE=&]J96X@<&]I<W1A;6ES
M97-S82!JY')J97-T96QMY'-SY"!O;&D@;VYG96QM:6$Z(`!*;VET86MI;B!O
M;F=E;&UI82`B)7,B('!O:7-T86UI<V5S<V$@:N1R:F5S=&5L;>1S=.0Z(`!*
M;VET86MI;B!O;F=E;&UI82`B)7,B('#D:79I='EK<V5S<^0Z("5S`%1I961O
M<W1O;B!T=6]N;FES<V$@;VQI(&]N9V5L;6EA+B!9:'3DY&X@)7,Z82!E:2!T
M=6]T=0!4:65D;W-T;VX@='5O;FYI<W-A(&]L:2!O;F=E;&UI82X@)7,@:V]K
M;R!O;&D@<W5U<F5M<&D@:W5I;B!S=75R:6X@<V%L;&ET='4@:V]K;R`H)60@
M=&%V=6$I+@!4:65D;W-T;VX@='5O;FYI<W-A(&]L:2!O;F=E;&UI82X@)7,@
M;&%T875T=6D@=F%I;B!O<V%K<VDN`%1A<&%H='5I('9I<FAE(&[D>71E='3D
M97-SY"!V:65S=&EN('3D=.0@;W-I;W1A`%EH=&5Y<W1I971O:F5N('1U;VYN
M:7-S82!T87!A:'1U:2!V:7)H92X`:4-A;&5N9&%R+71I971O:F5N('1U;VYN
M:7-S82!T87!A:'1U:2!V:7)H92X`07-E='5S=&EE=&]L;VUA:VME97-S82!O
M;B!J;VMI;B!V:7)H92X@16AKY"!JY'1I="!J;VYK=6X@<&%K;VQL:7-E;B!K
M;VAD86X@=.1Y='3D;>1T=.0N`%1A<&%H='5I('9I<FAE('ER:71E='3D97-S
MY"!S=6]R:71T86$@;W-O:71E:VER:F%T;VEM:6YT;V$N(%ER:73D(&UY]FAE
M;6UI;B!U=61E<W1A86XN`%EH=&5Y<W1I971O:F5N('#D:79I='EK<V5S<^0@
M=&%P86AT=6D@=FER:&4N(%ER:73D(&UY]FAE;6UI;B!U=61E<W1A86XN`$IA
M:V5L=6QI<W1A;B!PY&EV:71Y:W-E<W/D('1A<&%H='5I('9I<FAE+B!9<FET
MY"!M>?9H96UM:6X@=75D97-T86%N+@!4Y&WD($E-05`@<&%L=F5L:6X@96D@
M='5E(&MA;G-I;VED96X@:F%K86UI<W1A+@!4Y&WD('1I961O<W1O(&5I('9A
M:6MU=&$@<F%R+71I961O<W1O;'1A+@!4Y&WD('1I961O<W1O(&5I('9A:6MU
M=&$@>FEP+71I961O<W1O;'1A+@!4Y&WD(&5I('9A:6MU=&$@;VEK96%L=&$@
M:V]R='1I;G5M97)O;'1A+@!4Y&QLY"!A:G5R:6QL82!V;VD@;.1H971TY.0@
M=FEE<W1E:N0@0VQI8VMA=&5L;&EN("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI
M(&=A=&5W87D@<&%L=F5L=6$@2%144"!!4$DZ;&QA+@!4Y&QLY"!A:G5R:6QL
M82!V;VD@;.1H971TY.0@=FEE<W1E:N0@5TE.("AH='1P.B\O=VEN<&QC+F-O
M;2D@9V%T97=A>2!P86QV96QU;B!K875T=&$@2%144"!!4$DZ;&QA+@!4Y&QL
MY"!A:G5R:6QL82!V;VD@;.1H971TY.0@=FEE<W1E:N0@<VUS,F5M86EL("AH
M='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2!P86QV96QU;B!K875T=&$@
M2%144"!!4$DZ;&QA+@!4Y&QLY"!A:G5R:6QL82!V;VD@;.1H971TY.0@=FEE
M<W1E:N0@5F]D869O;F5N(&YU;65R;VEH:6X@4TU44#IL;.0@:^1Y='3D96X@
M5F]D869O;F4@271A;'D@9V%T97=A>2!P86QV96QU82X@5.1TY"!P86QV96QU
M82!V;VD@:^1Y='3DY"!V86EN(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W
M+C$Y,"YI="D@='5N;G5K<VEL;&$N`%3D;>0@:V5N='3D(&]N('!A:V]L;&EN
M96XN`%3D<W/D(&ME;G3D<W/D('!I=.3D(&]L;&$@=F%I;B!K;VMO;F%I<VQU
M:W5J82X`5.1S<^0@:V5N=.1S<^0@<&ETY.0@;VQL82!N=6UE<F]I=&$@:F$@
M<&EL:VMU+6UE<FMK96KD+@!4Y'-SY"!K96YTY'-SY"!P:73DY"!O;&QA(&]K
M=&%A;&EL=6MU:F$N`%3D<W/D(&ME;G3D<W/D('!I=.3D(&]L;&$@;&ES=&$@
M:V]K;VYA:7-L=6MU:F$L(&IO=&MA('!I=.3D(&]L;&$@97)O=&5T='4@<&EL
M:W5L;&$@=&%I(';D;&EL>?9N;FEL;.0`07)V;VX@<&ETY.0@;VQL82!N=6UE
M<F\N`%3D<W/D(&ME;G3D<W/D(&]N(';D<FEMY.1R:71Y<RP@:F]N:V$@<&ET
MY.0@;VQL82!21T(@2&5X(&UU;V1O<W,L(&5S:6UE<FMI:W-I("<C,3(S-&%F
M)RX`5.1MY"!L;VUA:V4@;VX@:F\@:^1S:71E;'1Y+@!4Y&WD(&]N("5S+@!4
MY&WD(&]N($MO;&%B($=R;W5P=V%R92!O8FIE:W1I+B!+871S;V%K<V5S:2!T
MY&WD;B!O8FIE:W1I;B!S:6YU;&QA('!I=.3D(&]L;&$@<^1H:_9P;W-T:6]H
M:F5L;6$L(&IO:V$@>6UMY')TY.0@2V]L86(@1W)O=7!W87)E(&9O<FUA871T
M:6$N($QI<W1A('EH=&5E;G-O<&EV:7-T82!SY&AK]G!O<W1I;VAJ96QM:7-T
M82!L]GET>7D@;W-O:71T965S=&$@)7,`5.1MY"!V:65S=&D@;VX@:VER:F]I
M=&5T='4@97)I(&UE<FMI<W3V;&SD("@E<RD@:W5I;B!M:6OD('-I;G5L;&$@
M;VX@:^1Y=/9S<^0N(`!.=6UE<F]N('!I=.3D(&]L;&$@=N1H:6YTY.1N('EK
M<VDN`%3D;&SD('!A;'9E;&EM96QL82!E:2!V;VD@875K86ES=&$@>FEP+2!T
M86D@9WII<"UT:65D;W-T;VIA+@!4Y&WD(&KD<FIE<W1E;&WD(&]N('!O:7,@
M<.3D;'3D+@!!<G9O;B!P:73DY"!O;&QA(&YU;65R;RX`5.1MY&X@:6MK=6YA
M;B!V;VD@875K86ES=&$@=F%I;B!!<V5T=6MS970@:6MK=6YA<W1A`$UY<G-K
M>0!4:6ME=&ET`$%I:V$`06IA;G-E=7)A;G1A`$%J86X@97-I='ES;75O=&\`
M06IA;B!V86QI;G1A`%1I;6]R+4QE<W1E`%1I='1E;&D`3W1S:6MK;R`H=&]O
M;'1I<"DZ`%9A<W1A86YO='1A:F$`5F]I9&%K<V5S:2!V86QI=&$@=7-E86UP
M:6$@=F%I:'1O96AT;VIA+"!P:63D($-O;G1R;VPM("A00RD@=&%I($-O;6UA
M;F0M("A-86,I(&[D<'#D:6YTY"!P;VAJ87-S82!K=6X@;F%P<V%U=&%T(&AI
M:7)E;B!P86EN:6ME='1A+@!4Y&[DY&X`3N1Y=.0@2%1-3"ULY&AD96MO;V1I
M`%1O9V\`5&]K96QA=0!(=6]M96YN80!4;VYG80!,:6EA;B!M;VYT82!E<.1O
M;FYI<W1U;G5T=&$@:VER:F%U='5M:7-Y<FET>7-TY"!V:6EM96ES:6UP:65N
M(&UI;G5U='1I96X@:W5L=65S<V$N`%EL]G,`66QI;7#DY&X@:V5H>6MS965N
M("A?=&]P*0!+Y.1N;O9K<V5T`%1R:6YI9&%D(&IA(%1O8F%G;P!4;W-I('9A
M:2!E<.1T;W-I`'1I`%1U;FES:6$`5'5R:VMI`%1U<FMK:2`H25-/+3@X-3DM
M.2D`5'5R:VUE;FES=&%N`%1U<FMS(&IA($-A:6-O<R!S86%R970`5'5V86QU
M`$MI<FIO:71A('9A;&EN=&%S:3H@`%4N5BX@+6EN9&5K<VDZ(`!54DP`55),
M(&IO:&]N('!A;&%U=&5T86%N('-K<FEP=&EN('-T871U<R!R87!O<G1T:0!5
M4DPZ`%5G86YD80!5:W)A:6YA`%9&4RUH86ME;6ES=&]A(&5I('9O:71U(&QU
M:V5A+@!+Y'ET=.1JY&X@;&ESY'1I971O:F5N(&QI<^1Y<R!E:2!O;FYI<W1U
M;G5T(&MI<FIA=71U;6ES97-S82X`16D@=F]I('9A:6AT86$@;VEK975K<VEA
M(%9&4RUT:65D;W-T;VQL92`B)7,B+@!%:2!V;VD@=F%I:'1A82!O:6ME=6MS
M:6$@5D93+71I961O<W1O;&QE("5S+R5S+@!%:2!V;VED82!V86EH=&%A("5S
M.FXN`%1I961O<W1O;B`B)7,B(&MO:V]A(&5I('9O:71U('1A<FMI<W1A82X`
M16D@=F]I9&$@;FEM973D('5U9&5L;&5E;B!61E,M=&EE9&]S=&]A("(E<R\E
M<R(N`%-13"UP86QV96QI;65E;B!E:2!S86%D82!Y:'1E>71TY"X`66AT97ET
M=.0@96D@=F]I9&$@;75O9&]S=&%A(%-33"US86QA='1U;F$N`%9&4RUT:65D
M;W-T;V$@96D@=F]I9&$@:V]P:6]I9&$N`$5I('9O:61A(&QU;V1A(%9&4RUH
M86ME;6ES=&]A("(E<R(N`$5I('9O:61A(&QU;V1A(%9&4RUH86ME;6ES=&]A
M+@!%:2!V;VET=2!L=6]D82!61E,M=&EE9&]S=&]A`$5I('9O:61A(&YI;65T
MY"!U=61E;&QE96X@5D93+6MA;G-I;W1A("(E<R(N`$5I('9O:71U(&QU;V1A
M('1Y:&KDY"!61E,M=&EE9&]S=&]A+@!4:65T;V$@96D@=F]I9&$@;&%A:F5N
M=&%A+@!%:2!V;VED82!P;VES=&%A("(E<R(L(&AA:V5M:7-T;R!E:2!O;&4@
M='EH:N0N`$5I('9O:61A('!O:7-T86$@(B5S(CH@)7,N`$5I('9O:61A('!O
M:7-T86$@)7,L(&AA:V5M:7-T;R!E:2!O;&4@='EH:N0N`$5I('9O:61A('!O
M:7-T86$@5D93+6AA:V5M:7-T;V$@<F5K=7)S:6EV:7-E<W1I+@!%:2!V;VED
M82!P;VES=&%A(%9&4RUH86ME;6ES=&]A+@!%:2!V;VED82!P;VES=&%A(%9&
M4RUH86ME;6ES=&]A.B`E<RX`16D@=F]I9&$@<&]I<W1A82!61E,M=&EE9&]S
M=&]A("(E<R(N`$5I('9O:61A('!O:7-T86$@5D93+71I961O<W1O82X`16D@
M=F]I9&$@<&]I<W1A82!61E,M:V%N<VEO=&$@(B5S(BX`16D@=F]I9&$@<&]I
M<W1A82!61E,ZY.0@<F5K=7)S:6EV:7-E<W1I.B`E<RX`3GEK>6ES=.0@:&%K
M96UI<W1O82!E:2!V;VET=2!S96QV:71TY.0N`%9A<FUE;G1E96X@=&EE=&]J
M82!E:2!V;VED82!E>'1R86MT;VED80!-Y.1R:71Y:W-E;B`E<R!L=6ME;6EN
M96X@97#D;VYN:7-T=6DN`$5I('9O:61A('-I:7)TY.0@5D93+71I961O<W1O
M82X`16D@=F]I9&$@<&]I<W1A82!61E,M=&EE9&]S=&]A("(E<R(N`$5I('9O
M:61A(&%V871A(%9&4RUT:65D;W-T;V$@:VER:F]I='5S=&$@=F%R=&5N+@!%
M:2!V;VED82!A=F%T82!61E,M=&EE9&]S=&]A+@!4:6EV:7-T971Y;B!T:65D
M;W-T;VX@875K86ES=2!E<.1O;FYI<W1U:2X`16D@=F]I='4@;'5K96$@5D93
M+71I961O<W1O82`H9FEL97-I>F4H*2!E<.1O;FYI<W1U:2DN`$5I('9O:61A
M(&QU:V5A(%9&4RUT:65D;W-T;V$@*&=E=$9I;&53:7IE*"D@97#D;VYN:7-T
M=6DI+@!%:2!V;VET=2!L=6ME82!T:65D;W-T;V$Z(`!V9G-R;V]T(&IU=7)I
M:&%K96UI<W1O82!E:2!V;VET=2!L=6ME82X`575D96QL965N;FEM9>1M:6YE
M;B`E<R`E<SIK<VD@97#D;VYN:7-T=6D@:V]S:V$@:V]H9&5H86ME;6ES=&\@
M;VX@:F\@;VQE;6%S<V$`16D@=F]I9&$@;FEM973D('5U9&5L;&5E;B!61E,M
M:&%K96UI<W1O82X`16D@=F]I9&$@;FEM973D('5U9&5L;&5E;B!61E,M:&%K
M96UI<W1O83H@)7,N`$5I('9O:61A(&YI;65TY"!U=61E;&QE96X@5D93+71I
M961O<W1O82`B)7,B+@!%:2!V;VED82!N:6UE=.0@=75D96QL965N(%9&4RUT
M:65D;W-T;V$@)7,O)7,N`$5I('9O:71U(&YI;65TY"!U=61E;&QE96X@5D93
M+71I961O<W1O82X`16D@=F]I9&$@<W5O<FET=&%A(&MO;65N=&]A("=M:VES
M;V9S)RX`5V]R9"UD;VMU;65N='1I82!E:2!V;VET=2!KY.1N=.3D`$5I('9O
M:61A(&MI<FIO:71T86$@5D93+71I961O<W1O82`B)7,B+@!%:2!V;VED82!K
M:7)J;VET=&%A(%9&4RUT:65D;W-T;V]N("AC;W!Y*"D@97#D;VYN:7-T=6DI
M+@!%:2!V;VED82!K:7)J;VET=&%A(%9&4RUT:65D;W-T;VX@=&EE=&]J82X`
M16D@=F]I9&$@:VER:F]I='1A82!61E,M=&EE9&]S=&]A+"!K:6EN=&GV(&]N
M('3D>6YNY"X`06QL979I:79A='1U`%!E<G4@;75U=&]K<V5T`%!E<G5U='1A
M82!E9&5L;&ES96X@=&]I;65N<&ET965N`%1U;G1E;6%T;VX@=F%S=&%U<R!P
M86QV96QI;65L=&$@>6AT97ET965N.@!4=6YT96UA=&]N('9A<W1A=7,@<&%L
M=F5L:6UE;'1A.B``3'5O:VET=&5L96UA=&]N`%5N:6-O9&4@*%541BTX*0!9
M:&1I<W1Y;F5E="!A<F%B:65M:7)A871I=`!9:&1I<W1Y;F5E="!K=6YI;F=A
M<VMU;FYA=`!9:&1Y<W9A;&QA=`!9:&1Y<W9A;'1O:F5N(%1Y>6YE;FUE<F5N
M(&5R:6QL:7-S86%R970`36ET=&%Y:W-I:_9T`%1U;G1E;6%T;VX`5'5N=&5M
M871O;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!4=6YT96UA=&]N(&-L
M:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`$%N;F5T='4@<&%I:VMA=&EE
M=&\@;VX@='5N=&5M871O;BX`5'5N=&5M871O;B!KY'ET=.1JY'1U;FYU<R!T
M86D@<V%L87-A;F$N`%!O:7-T82!N>6MY:7-E;B!E;&5M96YT:6X@;&EN:VET
M>7,`3FEM973V;@!4:65T;W1U<G9A<WEI<W3D(&5I+7!R:79I;&5E9VES970@
M<VMR:7!T:70@96EVY'0@=F]I(&MU='-U82!,96EK:V%A+TMO<&EO:2],:6ET
MY"!T;VEM:6YT;VIA+B!.87!S875T82!/2RUN87!P=6QA82!NY&ADY&MS97-I
M(&UO>FEL;&$N;W)G('-I=G5I;&QA(&]L979A;B!O:&IE96XL(&IO<W-A(&YE
M=79O=&%A;B!M:71E;B!S:W)I<'1I<VD@=F]I=F%T(&OD>71TY.0@;&5I:V5P
M]GETY.0N`%!O:7-T82!VY')I`$5I+71U971T=2!L86%J96YN=7,`4.1I=FET
MY`!0Y&EV:73D("5S`%#D:79I=.0@:^1Y='3D:N0`4.1I=FET971T:6EN("(E
M<R(N`%#D:79I='ES<VMR:7!T:2!P;VES=&5T=&EI;BX`5'5O`'1U;R!K86EK
M:VD@;VAJ96QM:65N(&%S96YN=7-T:65D;W-T;W0@<&%L=F5L:6UE;&QE+@!)
M<V]T(&QA=&EN86QA:7-E="!K:7)J86EM970`27-O="!R;V]M86QA:7-E="!N
M=6UE<F]T`%5R=6=U87D`2^1Y=.0@;GEK>6ES=.0Z("5S`$OD>73D(%-33"US
M86QA=7-T80!+Y'ETY"!J;W,@='5N;G5S+W-A;&%S86YA(&]N(&5R:2!)35-0
M+7!A;'9E;&EM96QL92X`2^1Y='3D:N0`2^1Y='3D:N1L;.0@)7,@96D@;VQE
M(&]I:V5U:W-I82!T96ADY"`E<RX`2^1Y='3D:FEE;B!Y;&SD<&ET;P!+Y'ET
M=.1JY&X@87-E='5K<V5T`$OD>71TY&KD;B!R96MI<W1E<O9I;6EN96X`5.1S
M<^0@:N1R:F5S=&5L;>1S<^0@96D@=F]I(')E:VES=&5R]FEDY"!KY'ET=.1J
M:>0N`$OD>71TY&KD='5N;G5S=&$@96D@;/9Y='EN>70N`$OD>71TY&KD='5N
M;G5S`$OD>71TY&KD='5N;G5S("(E<R(@;VX@:F\@;VQE;6%S<V$N`$OD>71T
MY&KD='5N;G5S.@!+Y'ET=.1JY'1U;FYU<SH@`$KD<FIE<W1E;&WD;B!KY'ET
M=.1JY'0Z`%5Z8F5K:7-T86X`5D93+6AA:V5M:7-T;V$@96D@;VQE(&]L96UA
M<W-A+@!0;VES<V%O;&]V:65S=&D`4&%I:VMO:F$@;/9Y='EI(&5S:6UE<FMI
M:W-I.B``5F]I;6%S<V%O;&]A:6MA`$%R=F\@;6EN=75T96ES<V$@;GEK>6AE
M=&ME<W3D+@!!<G9O(&]N('EL:2!P:71U=61E;B!M86MS:6UI87)V;VX@)7,N
M/`!!<G9O=`!686QI='1A=F%T(&%R=F]T`%9A;G5A='4`5F%I:'1E;&5V86$`
M5F5N97IU96QA`%1A<FMI<W1U<R!E<.1O;FYI<W1U:2`M(%3D=.0@=FEE<W1I
MY"!O;B!V;VET=2!KY'-I=&5L;.0N`%9E<G-I;P!697)S:6]N:&%L;&EN=&$`
M4'ES='ES=6]R82!T87-A=7,`4'ES='ES=6]R82!TY'ET90!0>7-T>7-U;W)A
M.@!%<FET=.1I;B!K;W)K96$`5FEE=&YA;0!6:65T;F%M("A625-#24DI`$[D
M>73D("5S`$[D>73D(&5R:6QL:7-E;N0@=W=W+7-I=G5N80!.Y'ETY"`E<P!.
M96ET<WET<V%A<F5T+"!"<FET=&ELY&EN96X`3F5I='-Y='-A87)E="P@66AD
M>7-V86QT86EN`$[D:WEVY&ES>7ES`$[D:WEVY&ES>7ES.B``5F]D869O;F4@
M271A;'D@4TU44#IN(&%V=6QL80!605)/25154P!605)/25154R$A(2!03TE3
M5$$@4TM225!422!+Y%-)3B!004Q614Q)345,5$$@)7,N`%=)3B!(5%10.FX@
M879U;&QA`%=A;&QI<R!J82!&=71U;F$`5F%R;VET=7,`:V4`4^3D96YN=7-T
M90!3Y.1T:65D;W0@;VX@=&]I;6ET=&%N=70`5V5A=&AE<BYC;VT`5U=7`%=7
M5RUS:79U<W1O`%9I:6MO:71T86EN`%1E<G9E='5L;V$`5&5R=F5T=6QO82!O
M:&IE;&UA86X@)7,`5&5R=F5T=6QO82P@)7,`3.1N<VEM86EN96X@*$E33RTX
M.#4Y+3$I`$SD;G-I;6%I;F5N+T5U<F\@*$E33RTX.#4Y+3$U*0!,Y&YS:2U3
M86AA<F$`36EN:^0@;VAJ96QM86X@)7,@:^1Y;FYI<W3DY"!S:7/DY&YK:7)J
M875T=6UI<V5N(&KD;&ME96XN`$UI=.0@;65R:VMIY"!KY'ET973DY&X@97)O
M='1I;65N83\`36ETY"!M97)K:VGD(&OD>71E=.3D;B!L86EN875K<V5E;C\`
M5VAE<F5I<R!!=7-T<F%L:6%N(&MA<G1T80!-:71KY"!V86EH965T`%9O:70@
M;>3D<FET96QLY"!L:7/D=&]I;6EN=&]J82!L86ET971A86X@<.3D;&QE(%)I
M8V@@5&5X="!E9&ET;W)I<W-A+@!,979E>7,`3&5V97ES($-34R!M:71T87EK
M<VEK:_9I;N0`5F%S96UM86QL82!O;&5V86X@)7,@=F%L:6MO;B!L979E>7,@
M*'1U;&5E('9O:6UA86X@<V5U<F%A=F%L;&$@<VESY.1N:VER:F%U='5M:7-E
M;&QA*3H`5&%U;'5K;VX@;&5V97ES`$QE=F5Y9&5N('EK<VEK:_8`3&5V97ES
M.@!7:6MI`%1U=6QI`%1U=6QI<W1A(&%I:V%I<VEN`%1U=6QE;FYO<&5U<R!S
M;VQM=6ES<V$`5'5U;&DZ`%1U=6QI.B``5FEI<V%U<P!4;VEV96QI<W1A=`!4
M>?8`3W-O:71E("AT>?8I`%!U:&5L:6X@*'1Y]BD`5N3D<N0@;>3D<N0@:V5N
M='1IY"!R:79I;&SD("5D+B!/9&]T971T:6EN("5D+"!L]GET>6D@)60N`%;D
MY'+D(&WDY'+D(&ME;G1T:>0N($]D;W1E='1I:6X@)60L(&SV>71Y:2`E9"X`
M5N3D<N0@<&]I:VME86UA("5D(&QU971T865S<V$@5D93+71I961O<W1O82X`
M6"U2968`6#4P.78S('!E<G5S<F%J;VET=&5E=`!8-3`Y=C,@;&ESY'1O:6UI
M;FYO="!A=F%I;65N(&OD>73V;&QE`%@U,#EV,R!+;VAT965N('9A:6AT;V5H
M=&]I;F5N(&YI;6D`6#4P.78S($MO:'1E96X@879A:6UE;B!T=6YN:7-T90!8
M-3`Y=C,M;&%A:F5N;G5K<V5T`%96`%965E8`66%H;V\A(&MA<G1T80!6=6]S
M:71T86EN`$IE;65N`$MY;&SD`$MY;&SD+"!S=6]S='5N+@!+Y'ETY'0@5$5+
M4U1)5$E,04$N($OD>73D(%L\/ET@;F%P<'5L86$@=F%I:'1A86MS97-I('1A
M:V%I<VEN(%=94TE764<M=&EL86%N+@!%="!V;VD@=&5H9.0@96YE;7#DY"!K
M=6EN("5D(&]S:6]T82X`170@;VQE(&%U=&5N=&EK;VET=6YU="X`3FEM97-S
MY'-I(&5I('-A82!O;&QA("=<)RUM97)K:VGD+@!%="!A;G1A;G5T(&]I:V5A
M;B!M=6]T;VES=&$@<^1H:_9P;W-T:6]S;VET971T82X`170@;>3D<FET96QL
M>70@;6ET:^0@='5O9'5N('1I961O<W1O;B!K96YTY'0@=F%S=&%A=F%T(&UI
M=.1K:6X@:V5N='1IY"`E<SIS<^0N`$]L970@:VER:F%U='5N=70@=6QO<RX`
M4VEN=6X@<&ETY.0@86YT86$@;VEK96$@;6%T:V%P=6AE;&EN;G5M97)O+"!V
M86EN(&YU;65R;VET82!J82!M86AD;VQL:7-E<W1I("<K)R!J;W,@:^1Y=.1T
M(&MA;G-A:6YVY&QI<W3D('!U:&5L:6YN=6UE<F]M=6]T;V$N`%-I;G5N('3D
M>71Y>2!A;G1A82!O:6ME82!A<G9O+@!3:6YU;B!P:73DY"!A<V5N=&%A($1A
M=&%4<F5E+71A=7-T86KD<FIE<W1E;&WD(&5N;F5N(&MU:6X@=F]I="!KY'ET
M=.3D(%-I9VYU<"UT;VEM:6YT;VIA+@!3:6YU;B!P:73DY"!A<V5N=&%A(%9&
M4RUT875S=&%JY')J97-T96QMY"X`4VEN=6X@='5L964@:W5V86EL;&$@;VYG
M96QM871I;&%N;F5T=&$@96YN96X@:W5I;B!V;VET(&SD:&5T=.3D(&]N9V5L
M;6%V:65S=&EN+@!3:6YU;B!P:73DY"!A;G1A82!54DP@;6EH:6X@=.1MY"!L
M:6YK:VD@;W-O:71T86$`4VEN=6X@<&ETY.0@=F%L:71A('!O:7-T971T879A
M('!A;'9E;&EN+@!3:6YU;B!P:73DY"!A;G1A82!P;VES=&5T=&%V82!KY'ET
M=.1JY'1U;FYU<RX`4VEN=6X@<&ETY.0@86YT86$@<&]I<W1E='1A=F$@:^1Y
M='3D:N1T=6YN=7,N`%-I;G5N('!I=.3D(&%N=&%A(&QI<^1T=.1VY"!KY'ET
M=.1JY'1U;FYU<RX`4VEN=6X@<&ETY.0@86YT86$@<.1I=FET971TY';D(&OD
M>71TY&KD='5N;G5S+@!3:6YU;B!P:73DY"!V86QI=&$@<W5O<FET971T879A
M('1O:6UI;G1O+@!3:6YU;B!P:73DY"!A;G1A82!U=61E;B!K871E9V]R:6%N
M(&YI;6DN`%-I;G5N('!I=.3D(&%N=&%A(&ET86QI86QA:6YE;B!P=6AE;&EN
M;G5M97)O`$ES='5N=&]S:2`E<R!O;B!V86YH96YT=6YU="X@2VER:F%U9'4@
M=75D96QL965N('-I<^3D;BX`4^1H:_9P;W-T:6]S;VET=&5E<VD`4VEN=6X@
M;.1H971TY&KD;W-O:71T965S:3H`3VUA="!T:65T;W-I`%-I;G5N('1I971O
M:V]N965S:2!KY'ET=.1MY"!T:65T;W9E<FMK;RUO<V]I=&4@;VX@;75U='1U
M;G5T('-E;B!JY&QK965N(&MU;B!O;&5T(&%L;VET=&%N=70@)7,@:7-T=6YN
M;VXN(%1I971O='5R=F%S>6ES=.0@<VEN=6X@<&ETY.0@:VER:F%U='5A('5U
M9&5S=&%A;B!JY')J97-T96QMY.1N+@!.:6UE<VD`2^1Y='3D;>1S:2!A=71H
M96YT:6-A=&EO;B!T875S=&%JY')J97-T96QMY"!E:2!T=64@:^1Y='3D:FEE
M;B!L:7/DY&UI<W3D+B!*;W,@:&%L=6%T(&AA;&QI;FYO:61A(&OD>71TY&KD
M='5N;G5K<VEA+"!S:6YU;B!P:73DY"!KY'ET=.3D(&IO=&%K:6X@=&]I<W1A
M(&%U=&AE;G1I8V%T:6]N('1A=7-T86KD<FIE<W1E;&WDY"X`2^1Y='3D;>1S
M:2!A=71H96YT:6-A=&EO;B!T875S=&%JY')J97-T96QMY"!E:2!T=64@:^1Y
M='3D:N1T:65T;VIE;B!NY'ET=.1M:7-TY"!T86D@=.1MY"!P:6ER<F4@96D@
M;VQE(&IO<W1A:VEN('-Y>7-TY"!KY'ET971TY'9I<W/D+@!3:6YU;B!KY'ET
M=.1MY'-I('=W=RUS96QA:6X@;N1Y='3DY"!O;&5V86X@;75U='1U;G5T('-E
M;B!JY&QK965N(&MU;B!O;&5T(&%L;VET=&%N=70@)7,@:7-T=6YN;VXN(%1I
M971O='5R=F%S>6ES=.0@<VEN=6X@<&ETY.0@:VER:F%U='5A('5U9&5S=&%A
M;FKD<FIE<W1E;&WDY&XN`%-E;&%I;65S:2!E:2!T=64@=.1TY"!T;VEM:6YT
M;V$N`%-E;&%I;65S:2!E:2!T=64@=&%R=FET=&%V86$@='5L;W-T=7-T;VEM
M:6YT;V$N(%!A:6YA($-O;G1R;VPO3W!T:6]N("L@4"!T=6QO<W1A86MS97-I
M+@!!:6MA=GGV:'EK:V5E<VDZ`$]L971U<W!R;V9I:6QI<VD@;VX@;75U=&5T
M='4N`$]L971U<W!R;V9I:6QI<VDZ`$YI;65S:3H`27-T=6YT;W-I(&]N('9A
M;FAE;G1U;G5T+@!3:6YU;B!S86QA<V%N87-I("5S.FQL92!O;CH@)7,`07-E
M='5K<V5S:2!O;B!PY&EV:71E='1Y(&IA(&YE(&]V870@=F]I;6%S<V$@=.1M
MY&X@:7-T=6YN;VX@86IA;BX`07-E='5K<V5S:2!O;B!PY&EV:71E='1Y+@!3
M86QA<V%N87-I(&]N(&YO;&QA='1U`%-A;&%S86YA<VD@;VX@;F]L;&%T='4L
M('1A<FMI<W1A('/D:&OV<&]S=&ES:2!J82!K:7)J875D=2!S:7/DY&X@=75D
M96QL82!S86QA<V%N86QL87-I+@!386QA<V%N87-I(&]N('9A;FAE;G1U;G5T
M+@!%=.1P86QV96QI;65S:3H`2G5G;W-L879I80!:86ER90!386UB:6$`6FEM
M8F%B=V4`6FEP<'D`6U!I:6QO=&$@;&%I;F%T='4@=&5K<W1I70!;3VYG96QM
M85T`6T[D>73D(&QA:6YA='1U('1E:W-T:2`M`%M.Y'ETY"!L86EN871T=2!T
M96MS=&D@+2`E<R!R:79IY%T`6W)I=FEL;.0@)7,O)7-=`%]9;&SD<&ET;P!?
M2V]M96YT;W1U;&MK:0!?1&%T851R964`7U!O:7-T82!R:79I`%]2>6AMY'0`
M7T]H:F4`7TMU=F%N('1I961O="XN+@!?2VER:F%U9'4@<VESY.1N`%]+:7)J
M875D=2!U;&]S`%]-=6]K:V%A(&QI;FMK:>0`7T%S971U:W-E=`!?3VEK975D
M970`4&]I<W1A(&QI;FMK:2XN+@!?07-E;FYU<P!?5&%U;'5K;VX@=&EE9&]T
M+BXN`%]+Y'ET=.1JY'0`;W-O:71E:VER:F$`=F%S=&%A;F]T=&%J82!T=6YT
M96UA=&]N`&MA;&5N=&5R:0!T>7EN=.0`96D@=F]I(&QU;V1A('1U;&]S=&EE
M9&]S=&]A`&5I('9O:2!A=6MA:7-T82!LY&AD971TY`!N87!S875T82!TY'-T
MY`!V:7)H92!K;VUE;G1O<FEV:6QLY`!A<V5T=7-V:7)H90!K<FEI='1I;F5N
M(&KD<FIE<W1E;&WD=&EE9&]S=&\@<'5U='1U=0!M=6]T;W9I<FAE('1I961O
M:7-S80!M=6]K:V%A`'1I971U971T82!E:2!L]GET>6YY=`!L87-K979A`'1I
M961O<W1O`'-U=6YN87-T82`E<R`H)7,I(&YO<&5U9&5L;&$@)7,@)7,`<'5U
M<VMI='1A:6X`:#H`:&@`='5N=&5M871O;B!P86QV96QI;65N(&YI;6D`=N1L
M:71T]FWD<W1I`&EN;&EN90!I;RUV:7)H90!O:&IE;&UI<W1O;B!S:7/D:6YE
M;B!V:7)H90!R:79I=%T`;6MI<V]F<R!V:7)H96MO;V1I("5D($E33SIA('1E
M:&1E<W/D+@!M;0!N:6UI`&5I(&]L92!T;W1E=71E='1U`&5I(&]L92!V:65L
MY"!T;W1E=71E='1U`&UU:7-T:6QI<W1A`'!R;W-E;G1T:0!KY'ET=/8@:VEE
M;&QE='1Y`'!I:W-E;&5I=.0`973D=FER:&4@<')O=&]K;VQL87-S80!N;W5S
M979A`'!A;'9E;'4@96D@;VQE(&OD>71E='3D=FES<^0`;N1Y=.0@97)O=`!S
M;7,R96UA:6P@2%144#IN(&%V=6QL80!S<P!V86MA80!JY')J97-T96QMY'9I
M<FAE`'1E:'3D=N1L:7-T80!VY&QI86EK86EN96X@=FER:&4`=F%R;6ES=&%A
M:W-E<VD@:VER:F]I=&$@<V%L87-A;F$@:V%H9&5S=&D`=6YI9FEE9`!N:6UE
M=/9N`&OD>71TY&KD;B!V86QI;G1A`'9#87)D`'<Z`'=E871H97(N8V]M````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&]C86QE+V9R7T92+P``````````````````````````````
M```````````````````````````````````````````````````P,#`P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U,P`P,C`Q
M,3,`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9G)?1E(O:&5L<"YX
M;6P`````````````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T,#(S
M`#$P-3$U-#,S-S4S`#`R,34V-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG
M/2)I<V\M.#@U.2TQ(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O9G)?
M1E(O:&5L<"YX;6PL=B`Q+C(N,3`N,2`R,#`U+S$R+S`U(#$P.C,P.C0U(&IA
M;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)S=6UM87)Y(B!S=&%T
M93TB=7!T;V1A=&4B(&UD-3TB-CAC83,S9C=F,&,Y86%E-&,Q,#-E8C0W-#DR
M8V1C,34B/@H\=&ET;&4^3&$@<&%G92!P;W)T86EL(#PO=&ET;&4^"B`\<&%R
M83X*("!#971T92!P86=E('!O<G1A:6P@=F]U<R!F;W5R;FET('5N('+I<W5M
MZ2!D92!V;W,@:6YF;W)M871I;VYS(&EM<&]R=&%N=&5S+B!087(@97AE;7!L
M92P@8V5L82!P;W5R<F%I="!V;W5S('!E<FUE='1R92!D)V%F9FEC:&5R(&QE
M(&YO;6)R92!D92!N;W5V96%U>"!M97-S86=E<R!D86YS('9O=')E(&)O[G1E
M(&1E('+I8V5P=&EO;BP@;&5S(&YO=79E875X(.EVZ&YE;65N=',@9&4@=F]T
M<F4@8V%L96YD<FEE<BP@;&5S('3B8VAE<R!D92!V;W1R92!L:7-T92!D92!T
M<F%V875X(.`@9F%I<F4L(&QE<R!G<F%N9',@=&ET<F5S(&1E(&YO=79E;&QE
M<RP@971C+B!,82!P;'5P87)T(&1E<R!RZ7-U;>ES(&-O;G1I96YD<F]N="!D
M97,@<F%C8V]U<F-I<R!V97)S(&1E<R!F;VYC=&EO;G,@8VQA<W-I<75E<R!C
M;VUM92!L82!C;VUP;W-I=&EO;B!D)W5N(&YO=79E874@;65S<V%G92P@;&$@
M8W+I871I;VX@9"=U;B!N;W5V96P@Z7;H;F5M96YT(&1A;G,@;&4@8V%L96YD
M<FEE<B!O=2!D)W5N92!N;W5V96QL92!TXF-H92X*(#PO<&%R83X*(#QP87)A
M/@H@($QE(&-O;G1E;G4@9&4@8V5T=&4@<&%G92!P;W)T86EL('!E=70@ZG1R
M92!P97)S;VYN86QI<^D@X"!L)V%I9&4@9'4@8F]U=&]N("=0<NES96YT871I
M;VXG+B!087(@97AE;7!L92P@=F]U<R!P;W5V97H@8VAO:7-I<B!L97,@<&]I
M;G1S('!RZ7-E;G1S('-U<B!C971T92!P86=E('!O<G1A:6P@970@;"=O<F1R
M92!D86YS(&QE<75E;"!I;',@<V5R;VYT('!RZ7-E;G3I<RX*(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](FYA=F)A<B(@<W1A=&4](G5P=&]D871E
M(B!M9#4](F(X8V8P864Q.64U-V1F83!C,F(Y-C)E-3$V-S@R9C0W(CX*/'1I
M=&QE/DQE(&UE;G4@2&]R9&4\+W1I=&QE/@H@/'!A<F$^"B`@4W5R(&QE(&/T
M=.D@9V%U8VAE(&1E(&QA('!A9V4@<V4@=')O=79E(&QE(&UE;G4@2&]R9&4N
M"B`@0VQI<75E>B!S=7(@;&5S(&EC]&YE<R!D92!C92!M96YU($AO<F1E('!O
M=7(@86-CZ61E<B!R87!I9&5M96YT(&5T('-I;7!L96UE;G0@875X(&%P<&QI
M8V%T:6]N<R!D:7-P;VYI8FQE<RX@"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4](G5P=&]D871E
M(B!M9#4](F1D.35D9C`W83`S,#,Q,C,R8F%E83DQ.3(X.&(R9#`P(CX*("`@
M(#QT:71L93Y0<NEFZ7)E;F-E<SH@36%I;G1E;F%N8V4Z($5F9F5C='5E<B!L
M97,@;W#I<F%T:6]N<R!D92!M86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R
M83X*("`@(%-I('9O=7,@=F]U;&5Z(&5F9F5C='5E<B!L97,@;W#I<F%T:6]N
M<R!D92!M86EN=&5N86YC92#@(&QA(&-O;FYE>&EO;BP@8V]C:&5Z(&-E='1E
M(&-A<V4N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F
M<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB
M83(Q,38R8V1F9C-B,60X9F%E861B-S(Y-C(T,#`S-F4B/@H@("`@/'1I=&QE
M/E!RZ6;I<F5N8V5S.B!-86EN=&5N86YC93H@0V]N9FER;65R/"]T:71L93X*
M("`@(#QP87)A/@H@("`@4VD@=F]U<R!V;W5L97H@9&5V;VER(&-O;F9I<FUE
M<B!A=F%N="!D92!L86YC97(@;&5S(&]PZ7)A=&EO;G,@9&4@;6%I;G1E;F%N
M8V4L(&-O8VAE>B!C971T92!C87-E+B!3:2!V;W5S(&YE(&QA(&-O8VAE>B!P
M87,L('1O=71E<R!L97,@;W#I<F%T:6]N<R!D92!M86EN=&5N86YC92!S97)O
M;G0@875T;VUA=&EQ=65M96YT(&QA;F/I97,@X"!L82!C;VYN97AI;VX@<V%N
M<R!A=6-U;F4@8VAA;F-E(&0G86YN=6QA=&EO;BX*("`@(#PO<&%R83X*/"]E
M;G1R>3X*/"]H96QP/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O
M9G)?1E(O3$-?34534T%'15,O````````````````````````````````````
M`````````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S4S`#`R,3<P,``@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQO8V%L92]F<E]&4B],0U]-15-304=%4R]H;W)D92YM;P``
M````````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`T,C4U-C<`,3`U,34T,S,W-3,`,#(S
M,S8Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`-X2!)4`````B0<``!P```!D/```$PH``*QX````````^*````X```#YH```
M#P````BA```-````&*$```@````FH0``"P```"^A```,````.Z$```0```!(
MH0``&````$VA```;````9J$``"T```""H0``'0```+"A```D````SJ$``"D`
M``#SH0``&0```!VB```F````-Z(```P```!>H@``)````&NB```/````D*(`
M``L```"@H@``#@```*RB```%````NZ(``"@```#!H@``"````.JB```*````
M\Z(``!4```#^H@``$@```!2C```+````)Z,``(4````SHP``#@```+FC```*
M````R*,```T```#3HP``#@```.&C```1````\*,```T````"I```#````!"D
M```-````':0```8````KI```E````#*D```*````QZ0```\```#2I```&```
M`.*D```,````^Z0```X````(I0``#@```!>E```(````)J4```D````OI0``
M+@```#FE```:````:*4``#(```"#I0``.````+:E``!4````[Z4``%$```!$
MI@``6@```):F``!7````\:8``#0```!)IP``"0```'ZG```-````B*<```<`
M``"6IP``"@```)ZG```/````J:<```4```"YIP``!@```+^G```1````QJ<`
M``@```#8IP``"0```.&G```)````ZZ<``"4```#UIP``(````!NH```3````
M/*@``!````!0J```#P```&&H```*````<:@```,```!\J```#P```("H```4
M````D*@```D```"EJ```#0```*^H```2````O:@``!D```#0J```'@```.JH
M```/````":D```H````9J0``#P```"2I```(````-*D``"0````]J0``%```
M`&*I```6````=ZD```@```".J0``3@```)>I```M````YJD``!D````4J@``
M!P```"ZJ```,````-JH``"P```!#J@``#@```'"J```#````?ZH```L```"#
MJ@``!P```(^J```'````EZH```4```"?J@``!0```*6J```*````JZH```,`
M``"VJ@``%P```+JJ```*````TJH```\```#=J@``#@```.VJ```8````_*H`
M`",````5JP``#@```#FK```4````2*L``!<```!=JP``%P```'6K```7````
MC:L``!,```"EJP``#P```+FK```.````R:L``!\```#8JP``'0```/BK```'
M````%JP```8````>K```"````"6L```/````+JP```8````^K```"@```$6L
M```3````4*P```L```!DK```$````'"L```5````@:P``!4```"7K```!P``
M`*VL```0````M:P```4```#&K```%0```,RL```1````XJP```P```#TK```
M.P````&M```X````/:T```D```!VK0``!P```("M```4````B*T```,```"=
MK0``!0```*&M```0````IZT```D```"XK0``$P```,*M```Y````UJT``!(`
M```0K@``)P```".N```L````2ZX``"H```!XK@``)0```*.N```*````R:X`
M``8```#4K@``"0```-NN```'````Y:X``"\```#MK@``-P```!VO```N````
M5:\``%4```"$KP``+0```-JO```M````"+```#T````VL```/P```'2P```M
M````M+```$````#BL```(P```".Q```C````1[$``$````!KL0``+0```*RQ
M```S````VK$``"4````.L@``%0```#2R```9````2K(``"D```!DL@``)```
M`(ZR```H````L[(``!$```#<L@``"@```.ZR```,````^;(```H````&LP``
M$````!&S```6````(K,``!8````YLP``!P```%"S```'````6+,``!0```!@
MLP``"@```'6S```(````@+,``"<```")LP``"````+&S```'````NK,```<`
M``#"LP``!@```,JS```%````T;,```<```#7LP``!@```-^S```(````YK,`
M`"D```#OLP``#@```!FT```*````*+0```0````SM```!P```#BT```)````
M0+0```8```!*M```$0```%&T```'````8[0``!8```!KM```!````(*T```(
M````A[0```8```"0M```#0```)>T```&````I;0``!X```"LM```$0```,NT
M```(````W;0```T```#FM```#````/2T```'`````;4```,````)M0```P``
M``VU```7````$;4``!,````IM0``'0```#VU```(````6[4```0```!DM0``
M"````&FU```(````<K4``$$```![M0``&@```+VU```K````V+4``"`````$
MM@``%0```"6V```&````.[8```8```!"M@``%0```$FV```8````7[8``"(`
M``!XM@``+@```)NV```=````RK8``"$```#HM@``5`````JW```I````7[<`
M``H```")MP``!P```)2W```'````G+<``!4```"DMP``#@```+JW```*````
MR;<```\```#4MP``#0```.2W```/````\K<```T````"N```"0```!"X```4
M````&K@```8````ON```&````#:X```=````3[@``!,```!MN```$0```(&X
M```4````D[@```0```"HN```!@```*VX```4````M+@``%0```#)N```9```
M`!ZY```$````@[D```X```"(N0``!0```)>Y```%````G;D``!L```"CN0``
M&@```+^Y```3````VKD``!$```#NN0``$0````"Z```<````$KH``"H````O
MN@``$````%JZ```A````:[H```4```"-N@``$P```).Z```+````I[H``!(`
M``"SN@``"@```,:Z```/````T;H```T```#AN@``$0```.^Z```3`````;L`
M``P````5NP``!@```"*[```,````*;L```8````VNP``%P```#V[```0````
M5;L``!$```!FNP``"````'B[```%````@;L```P```"'NP``$````)2[```%
M````I;L```T```"KNP``!@```+F[```'````P+L```T```#(NP``!P```-:[
M```+````WKL```<```#JNP``!P```/*[```)````^KL```D````$O```"@``
M``Z\```9````&;P``#T````SO```'0```'&\```,````C[P``!````"<O```
M!0```*V\```E````L[P``!(```#9O```$P```.R\```K`````+T``#L````L
MO0``(````&B]```(````B;T``#8```"2O0``(0```,F]```0````Z[T```@`
M``#\O0``#`````6^```&````$KX```0````9O@``#P```!Z^```.````+KX`
M``<````]O@``"@```$6^```-````4+X``!\```!>O@``'````'Z^```A````
MF[X``!X```"]O@``&0```-R^```>````]KX``!L````5OP``(0```#&_```N
M````4[\``"8```""OP``'````*F_```>````QK\``!P```#EOP``)@````+`
M```K````*<```#,```!5P```)@```(G````K````L,```#@```#<P```'0``
M`!7!```5````,\$``"\```!)P0``(````'G!```2````FL$``"D```"MP0``
M'@```-?!```@````]L$``!(````7P@``H@```"K"```6````S<(``",```#D
MP@``*`````C#```I````,<,``"@```!;PP``'P```(3#```5````I,,``"``
M``"ZPP``)0```-O#```H`````<0``"T````JQ```,````%C$``"2````B<0`
M`"$````<Q0``%@```#[%```<````5<4``"8```!RQ0``*@```)G%``!!````
MQ,4``$0````&Q@``#````$O&```'````6,8```<```!@Q@``!@```&C&```-
M````;\8``!````!]Q@``$@```([&```3````H<8``!(```"UQ@``!P```,C&
M```$````T,8``!````#5Q@``$````.;&```,````]\8```X````$QP``#0``
M`!/'```/````(<<``!,````QQP``#0```$7'```H````4\<```,```!\QP``
M#0```(#'```&````CL<``!$```"5QP``%P```*?'```;````O\<```X```#;
MQP```@```.K'``!)````[<<```4````WR```$````#W(```/````3L@```0`
M``!>R```#0```&/(```.````<<@```,```"`R```#@```(3(```(````D\@`
M``\```"<R```#P```*S(```'````O,@```T```#$R```$````-+(```-````
MX\@```L```#QR```!@```/W(```+````!,D```P````0R0``"@```!W)```1
M````*,D``!D````ZR0``"P```%3)```-````8,D``"(```!NR0``#P```)')
M```;````H<D``#0```"]R0``"@```/+)```8````_<D``!(````6R@``&0``
M`"G*```6````0\H``"(```!:R@``#0```'W*```'````B\H``!0```"3R@``
M"P```*C*```B````M,H``"\```#7R@``"P````?+```)````$\L``!D````=
MRP``"P```#?+```7````0\L``!<```!;RP``"0```'/+```6````?<L```\`
M``"4RP``&0```*3+```6````OLL```X```#5RP``&````.3+```(````_<L`
M``T````&S```)@```!3,``!#````.\P```@```!_S```$@```(C,```?````
MF\P```@```"[S```"P```,3,```O````T,P```X`````S0``!0````_-```&
M````%<T``$4````<S0```P```&+-```'````9LT```0```!NS0``"@```'/-
M```*````?LT```\```")S0``$````)G-```7````JLT``!$```#"S0``&0``
M`-3-```7````[LT```D````&S@``!0```!#.```+````%LX```H````BS@``
M`@```"W.```%````,,X```T````VS@``&P```$3.```7````8,X``!0```!X
MS@``"0```(W.```.````E\X```T```"FS@``$@```+3.```X````Q\X``"``
M````SP``"````"'/```.````*L\``'L````YSP``&````+7/```8````SL\`
M`!$```#GSP``!P```/G/```%`````=```!@````'T```'@```"#0```;````
M/]```!D```!;T```&P```'70```9````D=```!,```"KT```!P```+_0```(
M````Q]````8```#0T```!@```-?0```0````WM````\```#OT```$````/_0
M```/````$-$```L````@T0``#P```"S1```,````/-$```\```!)T0``!P``
M`%G1```&````8=$```X```!HT0``#````'?1```H````A-$```\```"MT0``
M"````+W1```(````QM$``!,```#/T0``'@```./1```A`````M(``"`````D
MT@``&0```$72```7````7](``"4```!WT@``%P```)W2```6````M=(```0`
M``#,T@``&P```-'2```-````[=(```P```#[T@```P````C3```%````#-,`
M``@````2TP``"@```!O3```,````)M,```L````STP``$````#_3```,````
M4-,```X```!=TP``"P```&S3```$````>-,```0```!]TP``$P```(+3```4
M````EM,```P```"KTP``"0```+C3```.````PM,```L```#1TP``&P```-W3
M```'````^=,```<````!U```"@````G4```-````%-0```D````BU```!```
M`"S4```%````,=0```,````WU```&````#O4```*````5-0```0```!?U```
M)@```&34```.````B]0``'P```":U```%0```!?5```%````+=4```<````S
MU0``#````#O5```(````2-4```H```!1U0``!@```%S5```(````8]4```(`
M``!LU0``!@```&_5```&````=M4``!0```!]U0``#0```)+5```0````H-4`
M`!L```"QU0``!````,W5```)````TM4``!````#<U0``"0```.W5```)````
M]]4```4````!U@``&@````?6```(````(M8```8````KU@``&0```#+6```.
M````3-8```<```!;U@``!P```&/6```%````:]8```D```!QU@``"@```'O6
M```.````AM8```(```"5U@``!@```)C6```+````G]8```T```"KU@``"0``
M`+G6```&````P]8``!(```#*U@``"0```-W6```'````Y]8``!0```#OU@``
M'0````37``!"````(M<``"4```!EUP``)0```(O7```&````L=<```H```"X
MUP``!````,/7```)````R-<```@```#2UP``$0```-O7```)````[=<```8`
M``#WUP``#0```/[7```&````#-@```0````3V```.0```!C8```]````4M@`
M`#H```"0V```'@```,O8```%````ZM@```X```#PV```!````/_8```&````
M!-D```<````+V0``(0```!/9```-````-=D``!4```!#V0``!@```%G9```$
M````8-D``!$```!EV0``!@```'?9```*````?MD``"(```")V0``!````*S9
M```%````L=D``!T```"WV0``!````-79```,````VMD```X```#GV0``"@``
M`/;9```(`````=H```D````*V@``!0```!3:```Z````&MH``#````!5V@``
M-0```(;:```I````O-H``$<```#FV@``.````"[;```I````9]L``#\```"1
MVP``+@```-';```M`````-P``!\````NW```#P```$[<```2````7MP```L`
M``!QW```)@```'W<```I````I-P``"0```#.W```)@```//<```(````&MT`
M``H````CW0``"0```"[=```'````.-T``"````!`W0``(````&'=```F````
M@MT```H```"IW0``&0```+3=```I````SMT``!8```#XW0``$@````_>```'
M````(MX```H````JW@``#````#7>```/````0MX``!````!2W@``0````&/>
M``!P````I-X``&8````5WP``#@```'S?```)````B]\```H```"5WP``$@``
M`*#?```3````L]\```P```#'WP``!@```-3?```/````V]\``!(```#KWP``
M$````/[?```1````#^```!P````AX```(P```#[@``!J````8N````\```#-
MX```!0```-W@```0````X^````D```#TX```!````/[@```+`````^$``"``
M```/X0``%````##A```,````1>$```P```!2X0``#P```%_A```5````;^$`
M`"D```"%X0``*@```*_A```F````VN$``"<````!X@``*0```"GB```J````
M4^(``!D```!^X@``0@```)CB```1````V^(``!(```#MX@``$P````#C```4
M````%.,```\````IXP``%@```#GC```7````4.,``!````!HXP``$0```'GC
M```T````B^,``!,```#`XP``$@```-3C```U````Y^,``!0````=Y```!P``
M`#+D```,````.N0``"````!'Y```$````&CD```4````>>0``!$```".Y```
M%P```*#D```<````N.0``!,```#5Y```%````.GD```:````_N0``!$````9
MY0``&@```"OE```>````1N4``!H```!EY0``$P```(#E```5````E.4``!$`
M``"JY0``%P```+SE```4````U.4``!<```#IY0``%0````'F```)````%^8`
M`!`````AY@``&0```#+F```$````3.8```<```!1Y@``"P```%GF```1````
M9>8```8```!WY@``!@```'[F```&````A>8```4```",Y@``!P```)+F```'
M````FN8```4```"BY@``%@```*CF```&````O^8```8```#&Y@``!````,WF
M```$````TN8```<```#7Y@``#@```-_F```,````[N8```P```#[Y@``#0``
M``CG```*````%N<```X````AYP``!0```##G```H````-N<```X```!?YP``
M#````&[G```/````>^<```H```"+YP``"````);G```)````G^<``"L```"I
MYP``!````-7G```(````VN<``"8```#CYP``$@````KH```/````'>@```8`
M```MZ```"@```#3H```'````/^@```@```!'Z```(````%#H```)````<>@`
M`!0```![Z```#````)#H```-````G>@```X```"KZ```%@```+KH```1````
MT>@```8```#CZ````P```.KH```&````[N@``!D```#UZ```!P````_I```$
M````%^D```L````<Z0``"P```"CI```'````-.D```4````\Z0``!P```$+I
M```6````2ND```T```!AZ0``#0```&_I```*````?>D``!````"(Z0``#P``
M`)GI```1````J>D``!<```"[Z0``"@```-/I```1````WND```@```#PZ0``
M!````/GI```/````_ND``#H````.Z@``!0```$GJ```,````3^H``!X```!<
MZ@``#@```'OJ```0````BNH```L```";Z@``#````*?J```)````M.H```<`
M``"^Z@``"@```,;J```)````T>H```X```#;Z@``$````.KJ```;````^^H`
M`!@````7ZP``&@```##K```*````2^L```D```!6ZP``"@```&#K```,````
M:^L```\```!XZP``"````(CK```&````D>L``!P```"8ZP``!P```+7K```%
M````O>L```L```##ZP``1P```,_K```-````%^P```D````E[```!````"_L
M```#````-.P``!,````X[```$P```$SL```3````8.P```H```!T[````@``
M`'_L```$````@NP``"4```"'[````P```*WL```%````L>P``"H```"W[```
M"@```.+L```%````[>P```0```#S[```"@```/CL```-`````^T```8````1
M[0``"````!CM```(````(>T```0````J[0``!0```"_M``!H````->T```D`
M``">[0``#````*CM```0````M>T```4```#&[0``!@```,SM```;````T^T`
M`"\```#O[0``$````!_N```*````,.X```\````[[@``"@```$ON```)````
M5NX``!,```!@[@``&P```'3N```8````D.X``!<```"I[@``'P```,'N```.
M````X>X```,```#P[@``!P```/3N```(````_.X```<````%[P``"@````WO
M```+````&.\```<````D[P``40```"SO```0````?N\```P```"/[P``#0``
M`)SO```:````JN\``$H```#%[P``&0```!#P```&````*O```!H````Q\```
M)0```$SP```&````<O````8```!Y\```'P```(#P```&````H/````D```"G
M\```&````+'P```7````RO```"@```#B\```!@````OQ```-````$O$``"(`
M```@\0``5P```$/Q```3````F_$``",```"O\0``$P```-/Q```"````Y_$`
M``L```#J\0``"````/;Q```-````__$```H````-\@``!P```!CR```4````
M(/(```8````U\@``"````#SR```.````1?(```<```!4\@``"@```%SR```+
M````9_(``#(```!S\@``!P```*;R```,````KO(```T```"[\@``%P```,GR
M```,````X?(```D```#N\@``"0```/CR```*`````O,```<````-\P``"0``
M`!7S```'````'_,```H````G\P``&P```#+S```/````3O,``!(```!>\P``
M"@```''S```6````?/,```D```"3\P``$````)WS```'````KO,``!(```"V
M\P``!````,GS```'````SO,```4```#6\P``!0```-SS```+````XO,``!0`
M``#N\P``$0````/T```:````%?0``!8````P]```%````$?T```7````7/0`
M`!@```!T]```'````(WT```9````JO0```<```#$]```!0```,ST```-````
MTO0```P```#@]```"````.WT```7````]O0```L````.]0``#````!KU```?
M````)_4``!H```!']0``$P```&+U```$````=O4```H```![]0``!````(;U
M```-````B_4```P```"9]0``!0```*;U```)````K/4```4```"V]0``!P``
M`+SU```%````Q/4```0```#*]0```@```,_U```X````TO4``"P````+]@``
M$@```#CV```I````2_8``#(```!U]@``"@```*CV```L````L_8``"X```#@
M]@``,P````_W```S````0_<``#@```!W]P``#P```+#W```8````P/<``!``
M``#9]P``#P```.KW```3````^O<``!4````.^```%````"3X```2````.?@`
M`!0```!,^```%0```&'X```M````=_@``"T```"E^```,0```-/X```N````
M!?D``"\````T^0``+````&3Y``!B````D?D``!,```#T^0``#0````CZ```(
M````%OH``!<````?^@``"````#?Z```,````0/H``"L```!-^@``(0```'GZ
M```:````F_H```D```"V^@``10```,#Z``!!````!OL```0```!(^P``$P``
M`$W[```4````8?L```X```!V^P``$P```(7[```8````F?L```8```"R^P``
M"0```+G[```*````P_L```\```#.^P``$````-[[```'````[_L```X```#W
M^P``!0````;\```;````#/P```@````H_```!@```#'\```4````./P``!$`
M``!-_```#@```%_\```X````;OP```(```"G_```!@```*K\```.````L?P`
M``4```#`_```!P```,;\```.````SOP```8```#=_```*````.3\```,````
M#?T``!P````:_0``!````#?]```I````//T``!<```!F_0``'P```'[]``!<
M````GOT``!0```#[_0``/@```!#^```?````3_X``!````!O_@``!P```(#^
M```.````B/X```P```"7_@``#````*3^```3````L?X```H```#%_@``'0``
M`-#^```9````[OX```4````(_P``$0````[_```1````(/\``"0````R_P``
M$@```%?_```5````:O\``!(```"`_P``#@```)/_```9````HO\```@```"\
M_P``"0```,7_```-````S_\```<```#=_P``"@```.7_```'````\/\```\`
M``#X_P``!@````@``0`+````#P`!`!H````;``$`"@```#8``0`'````00`!
M``@```!)``$`!0```%(``0`?````6``!``8```!X``$`$````'\``0`(````
MD``!``T```"9``$`"````*<``0`>````L``!`!(```#/``$`+````.(``0`:
M````#P$!``D````J`0$`"@```#0!`0`5````/P$!``4```!5`0$`%````%L!
M`0`$````<`$!`!````!U`0$`!@```(8!`0`'````C0$!`!X```"5`0$`*```
M`+0!`0`*````W0$!`!P```#H`0$`$0````4"`0`+````%P(!`!H````C`@$`
M%````#X"`0`$````4P(!``0```!8`@$`"P```%T"`0`%````:0(!``8```!O
M`@$`"````'8"`0`&````?P(!``H```"&`@$`&P```)$"`0`T````K0(!`#0`
M``#B`@$`(````!<#`0`I````.`,!`"````!B`P$`00```(,#`0`:````Q0,!
M`"@```#@`P$`*0````D$`0!0````,P0!`"(```"$!`$`!@```*<$`0`(````
MK@0!``4```"W!`$`"````+T$`0`9````Q@0!`!D```#@!`$`*@```/H$`0`C
M````)04!`!D```!)!0$`+@```&,%`0`T````D@4!``@```#'!0$`%P```-`%
M`0`*````Z`4!``<```#S!0$`(0```/L%`0`0````'08!``X````N!@$`"P``
M`#T&`0`'````208!`!,```!1!@$`"````&4&`0`+````;@8!``H```!Z!@$`
M%````(4&`0`/````F@8!`#(```"J!@$`"P```-T&`0`.````Z08!``4```#X
M!@$`!0```/X&`0`%````!`<!`!<````*!P$`#P```"('`0`$````,@<!``H`
M```W!P$`"0```$('`0`+````3`<!``T```!8!P$`#````&8'`0`.````<P<!
M``4```""!P$`!````(@'`0`-````C0<!`#(```";!P$`10```,X'`0`7````
M%`@!``<````L"`$`'@```#0(`0`4````4P@!``4```!H"`$`%````&X(`0`&
M````@P@!``<```"*"`$`#@```)((`0`J````H0@!``8```#,"`$`#````-,(
M`0`-````X`@!`!$```#N"`$`"P`````)`0`V````#`D!``H```!#"0$`(@``
M`$X)`0`+````<0D!``\```!]"0$`,@```(T)`0`E````P`D!`#````#F"0$`
M,0```!<*`0`M````20H!``X```!W"@$`!0```(8*`0`.````C`H!`!,```";
M"@$`$@```*\*`0`'````P@H!`!$```#*"@$`$P```-P*`0`'````\`H!`!0`
M``#X"@$`&`````T+`0`'````)@L!``4````N"P$`#````#0+`0`,````00L!
M`!(```!."P$`!````&$+`0`'````9@L!``H```!N"P$`"P```'D+`0`,````
MA0L!``X```"2"P$`#@```*$+`0`%````L`L!``4```"V"P$`+@```+P+`0`F
M````ZPL!`",````2#`$``P```#8,`0`2````.@P!``8```!-#`$`'@```%0,
M`0`8````<PP!`"4```",#`$`#0```+(,`0`)````P`P!`!\```#*#`$``P``
M`.H,`0`'````[@P!``H```#V#`$``@````$-`0`,````!`T!`!4````1#0$`
M"P```"<-`0`9````,PT!`"````!-#0$`$@```&X-`0`%````@0T!``H```"'
M#0$`%0```)(-`0`2````J`T!``P```"[#0$`!````,@-`0`)````S0T!``<`
M``#7#0$`#````-\-`0!2````[`T!`!<````_#@$`)````%<.`0`2````?`X!
M``<```"/#@$`!@```)<.`0`.````G@X!``P```"M#@$`#0```+H.`0`5````
MR`X!`!(```#>#@$`#P```/$.`0`4`````0\!``H````6#P$`&P```"$/`0`0
M````/0\!``L```!.#P$`:0```%H/`0`:````Q`\!`!<```#?#P$`)P```/</
M`0`:````'Q`!`!<````Z$`$`&P```%(0`0`9````;A`!`!\```"($`$`$P``
M`*@0`0`(````O!`!``<```#%$`$`"````,T0`0`)````UA`!`!4```#@$`$`
M#0```/80`0`C````!!$!``T````H$0$`$P```#81`0`(````2A$!``,```!3
M$0$`1@```%<1`0`_````GA$!`#<```#>$0$`5P```!82`0`%````;A(!`!\`
M``!T$@$`+P```)02`0`*````Q!(!``@```#/$@$`#0```-@2`0`M````YA(!
M``0````4$P$`3P```!D3`0`E````:1,!`!P```"/$P$`"P```*P3`0`?````
MN!,!`!T```#8$P$`)0```/83`0`@````'!0!`"0````]%`$`(````&(4`0`+
M````@Q0!``<```"/%`$`#0```)<4`0`,````I10!`!<```"R%`$`!@```,H4
M`0`Y````T10!``P````+%0$`!P```!@5`0`)````(!4!`!,````J%0$`"0``
M`#X5`0`$````2!4!`!````!-%0$`"````%X5`0`(````9Q4!``0```!P%0$`
M"P```'45`0`,````@14!`!(```".%0$`$0```*$5`0`,````LQ4!`!H```#`
M%0$`#P```-L5`0`'````ZQ4!``T```#S%0$`%`````$6`0`.````%A8!``P`
M```E%@$`&P```#(6`0`L````3A8!`!,```![%@$`'````(\6`0`H````K!8!
M``8```#5%@$`!P```-P6`0`3````Y!8!``4```#X%@$`!````/X6`0`7````
M`Q<!``H````;%P$`#````"87`0`)````,Q<!``8````]%P$`"0```$07`0`(
M````3A<!``D```!7%P$`"@```&$7`0`1````;!<!``8```!^%P$`#@```(47
M`0`.````E!<!``T```"C%P$`"P```+$7`0`=````O1<!``L```#;%P$``@``
M`.<7`0`<````ZA<!``<````'&`$`!@````\8`0!D````%A@!``D```![&`$`
M!P```(48`0`F````C1@!`#@```"T&`$`&@```.T8`0`J````"!D!`#L````S
M&0$`*````&\9`0`T````F!D!`!D```#-&0$`%0```.<9`0`%````_1D!``<`
M```#&@$`"`````L:`0`'````%!H!``4````<&@$`!P```"(:`0`.````*AH!
M``D````Y&@$`!@```$,:`0`(````2AH!``L```!3&@$`!P```%\:`0`(````
M9QH!``<```!P&@$`%@```'@:`0`)````CQH!``8```"9&@$`"P```*`:`0`0
M````K!H!``8```"]&@$`'````,0:`0`4````X1H!``<```#V&@$`$0```/X:
M`0`(````$!L!``X````9&P$`"````"@;`0`0````,1L!``D```!"&P$`$```
M`$P;`0`&````71L!`!D```!D&P$`"@```'X;`0`<````B1L!``<```"F&P$`
M!0```*X;`0`0````M!L!`!0```#%&P$`"P```-H;`0`-````YAL!`"@```#T
M&P$`&````!T<`0`7````-AP!``0```!.'`$`"0```%,<`0`*````71P!``<`
M``!H'`$``@```'`<`0`.````<QP!``@```""'`$`(P```(L<`0`?````KQP!
M`#@```#/'`$`)@````@=`0`Q````+QT!`"<```!A'0$`9````(D=`0`4````
M[AT!`%4````#'@$`.````%D>`0!*````DAX!`%L```#='@$`*````#D?`0`X
M````8A\!`"@```";'P$`+````,0?`0`F````\1\!`!L````8(`$`/@```#0@
M`0"I`0``<R`!`",````=(@$`%P```$$B`0!(````62(!`(4```"B(@$`,```
M`"@C`0`E````62,!`$$```!_(P$`6P```,$C`0!)````'20!`#$```!G)`$`
M'0```)DD`0`8````MR0!`"L```#0)`$`(0```/PD`0`?````'B4!`"L````^
M)0$`)@```&HE`0`G````D24!`#H```"Y)0$`'0```/0E`0`1````$B8!`#,`
M```D)@$`)0```%@F`0`G````?B8!`"````"F)@$`'P```,<F`0`P````YR8!
M`&D````8)P$`,0```((G`0!!````M"<!`#,```#V)P$`)0```"HH`0`]````
M4"@!`&4```".*`$`30```/0H`0`O````0BD!`"X```!R*0$`,````*$I`0!4
M````TBD!`%H````G*@$`2````((J`0!*````RRH!`#(````6*P$`+P```$DK
M`0`L````>2L!`"T```"F*P$`<0```-0K`0!F````1BP!`&\```"M+`$`LP``
M`!TM`0`7````T2T!`"4```#I+0$`,@````\N`0`I````0BX!`#X```!L+@$`
M(@```*LN`0!2````SBX!`"4````A+P$`"P```$<O`0"Q````4R\!`$4````%
M,`$`(0```$LP`0`P````;3`!`"4```">,`$`'````,0P`0`Q````X3`!``<`
M```3,0$`!P```!LQ`0`$````(S$!``T````H,0$`"P```#8Q`0`.````0C$!
M``L```!1,0$`!0```%TQ`0`0````8S$!``(```!T,0$`60```'<Q`0`%````
MT3$!`!(```#7,0$`!````.HQ`0`'````[S$!``@```#W,0$`!0`````R`0`P
M````!C(!``,````W,@$`$````#LR`0`,````3#(!`!,```!9,@$`#0```&TR
M`0`"````>S(!``<```!^,@$`!@```(8R`0`4````C3(!``P```"B,@$`&```
M`*\R`0`&````R#(!`!(```#/,@$`#````.(R`0`#````[S(!`"H```#S,@$`
M!````!XS`0`&````(S,!``<````J,P$`'P```#(S`0`U````4C,!`"X```"(
M,P$`+P```+<S`0`7````YS,!`"(```#_,P$`)0```"(T`0`@````2#0!`!L`
M``!I-`$`&````(4T`0`D````GC0!`!\```##-`$`&@```.,T`0`A````_C0!
M`"`````@-0$`&@```$$U`0`R````7#4!`!H```"/-0$`+P```*HU`0`K````
MVC4!`!\````&-@$`(P```"8V`0`?````2C8!`!H```!J-@$`(0```(4V`0`E
M````IS8!`"8```#--@$`)0```/0V`0`D````&C<!`!@````_-P$`'0```%@W
M`0`D````=C<!`!@```";-P$`(@```+0W`0`L````US<!`"\````$.`$`%0``
M`#0X`0`E````2C@!`#P```!P.`$`'P```*TX`0`C````S3@!`!\```#Q.`$`
M(````!$Y`0`:````,CD!`!@```!-.0$`)@```&8Y`0`>````C3D!`"D```"L
M.0$`'@```-8Y`0`Q````]3D!``D````G.@$`#````#$Z`0`7````/CH!`"\`
M``!6.@$`)````(8Z`0`'````JSH!``\```"S.@$`%````,,Z`0`.````V#H!
M``T```#G.@$`)````/4Z`0`%````&CL!``<````@.P$`(@```"@[`0`E````
M2SL!`!H```!Q.P$`'0```(P[`0`:````JCL!``<```#%.P$`QP```,T[`0`+
M````E3P!`!4```"A/`$`!@```+<\`0`)````OCP!``L```#(/`$`#0```-0\
M`0`7````XCP!``8```#Z/`$`,P````$]`0`3````-3T!`!,```!)/0$`!P``
M`%T]`0`/````93T!``<```!U/0$`,@```'T]`0`$````L#T!`"$```"U/0$`
M$P```-<]`0`,````ZST!`!$```#X/0$`,@````H^`0`6````/3X!``@```!4
M/@$`'0```%T^`0`)````>SX!``H```"%/@$`%````)`^`0`*````I3X!`!T`
M``"P/@$`"````,X^`0`?````USX!``@```#W/@$`&@`````_`0`G````&S\!
M``8```!#/P$`%0```$H_`0`'````8#\!``@```!H/P$`"0```'$_`0`_````
M>S\!``<```"[/P$`#P```,,_`0`.````TS\!`!````#B/P$`"0```/,_`0`)
M````_3\!``@````'0`$`$P```!!``0`'````)$`!`!D````L0`$`"@```$9`
M`0`7````44`!`!0```!I0`$`"@```'Y``0`,````B4`!`!<```"60`$`!```
M`*Y``0`J````LT`!``P```#>0`$`$0```.M``0`'````_4`!``(````%00$`
M$`````A!`0`8````&4$!``L````R00$``P```#Y!`0`(````0D$!``8```!+
M00$`!P```%)!`0`-````6D$!``L```!H00$`%````'1!`0`5````B4$!``X`
M``"?00$`+P```*Y!`0`@````WD$!`!P```#_00$`%0```!Q"`0`,````,D(!
M`#$````_0@$`!0```'%"`0`2````=T(!`#\```"*0@$`$@```,I"`0`*````
MW4(!``8```#H0@$`!````.]"`0`$````]$(!``H```#Y0@$`$P````1#`0`%
M````&$,!``8````>0P$`!@```"5#`0`(````+$,!``0````U0P$`#````#I#
M`0`*````1T,!`#D```!20P$`+@```(Q#`0`I````NT,!``4```#E0P$`&```
M`.M#`0`9````!$0!`!\````>1`$`'0```#Y$`0`1````7$0!``(```!N1`$`
M!````'%$`0`*````=D0!``8```"!1`$`!0```(A$`0`#````CD0!``P```"2
M1`$`10```)]$`0`R````Y40!`!H````810$`-````#-%`0`H````:$4!`%,`
M``"110$`&0```.5%`0!R````_T4!`"````!R1@$`-0```)-&`0`A````R48!
M`$4```#K1@$`,````#%'`0`H````8D<!`"D```"+1P$`)@```+5'`0`E````
MW$<!`"@````"2`$`*````"M(`0`B````5$@!`"L```!W2`$`,````*-(`0`2
M````U$@!`!,```#G2`$`$````/M(`0!Y````#$D!``D```"&20$`H0```)!)
M`0!S````,DH!`'P```"F2@$`*P```"-+`0!4````3TL!`!<```"D2P$`)P``
M`+Q+`0`6````Y$L!``\```#[2P$`%P````M,`0`?````(TP!`$````!#3`$`
M'P```(1,`0`<````I$P!`%$```#!3`$`&@```!--`0`4````+DT!``H```!#
M30$`!0```$Y-`0`&````5$T!``@```!;30$`!0```&1-`0`2````:DT!`!``
M``!]30$`$P```(Y-`0`=````HDT!``\```#`30$`#P```-!-`0`$````X$T!
M``D```#E30$`"P```.]-`0`'````^TT!``4````#3@$`%`````E.`0`'````
M'DX!``@````F3@$`#P```"].`0`(````/TX!``P```!(3@$`#P```%5.`0`&
M````94X!`!0```!L3@$`!@```(%.`0`,````B$X!`!$```"53@$`"````*=.
M`0`$````L$X!`!D```"U3@$`$0```,].`0`*````X4X!`!@```#L3@$`$P``
M``5/`0`<````&4\!`!$````V3P$`!````$A/`0`/````34\!``<```!=3P$`
M!````&5/`0`9````:D\!``<```"$3P$``@```(Q/`0`"````CT\!`!$```"2
M3P$`"0```*1/`0`&````KD\!`!(```"U3P$`%P```,A/`0`&````X$\!`"<`
M``#G3P$``@````]0`0`$````$E`!``\````74`$`$P```"=0`0`'````.U`!
M``<```!#4`$`$0```$M0`0`&````75`!`!@```!D4`$`!@```'U0`0`3````
MA%`!`!````"84`$`$@```*E0`0`"````O%`!``8```"_4`$`#````,90`0`)
M````TU`!`!$```#=4`$`(@```.]0`0`'````$E$!``<````:40$`"P```")1
M`0`%````+E$!``(````T40$`"P```#=1`0!_`0``0U$!`!(```##4@$`&P``
M`-92`0`0````\E(!``X````#4P$`"0```!)3`0`'````'%,!``,````D4P$`
M&P```"A3`0`A````1%,!`#4```!F4P$`,0```)Q3`0`K````SE,!`"\```#Z
M4P$`'0```"I4`0`M````2%0!``L```!V5`$`,@```()4`0`4````M50!``L`
M``#*5`$`$P```-94`0`%````ZE0!`#$```#P5`$`$````")5`0`1````,U4!
M`!X```!%50$`#P```&15`0`+````=%4!`)8```"`50$`$@```!=6`0`*````
M*E8!``T````U5@$`#0```$-6`0`7````458!``P```!I5@$`$````'96`0`5
M````AU8!``<```"=5@$`G0```*56`0`,````0U<!``P```!05P$`%````%U7
M`0`2````<E<!`!````"%5P$`$````)97`0`)````IU<!``H```"Q5P$`1```
M`+Q7`0`@`````5@!`#X````B6`$`30```&%8`0!N````KU@!`&H````>60$`
M=````(E9`0!P````_ED!`$$```!O6@$`#P```+%:`0`5````P5H!``X```#7
M6@$`$````.9:`0`8````]UH!``4````06P$`!@```!9;`0`7````'5L!``L`
M```U6P$`"@```$%;`0`-````3%L!`#0```!:6P$`,````(];`0`4````P%L!
M`!8```#56P$`#@```.Q;`0`'````^UL!``<````#7`$`%@````M<`0`D````
M(EP!``T```!'7`$`&0```%5<`0`?````;UP!`!\```"/7`$`)0```*]<`0`?
M````U5P!`!,```#U7`$`&P````E=`0`1````)5T!`"@````W70$`'@```&!=
M`0`?````?UT!`!8```"?70$`80```+9=`0`P````&%X!`#(```!)7@$`!P``
M`'Q>`0`1````A%X!`$,```"67@$`#@```-I>`0`$````Z5X!``L```#N7@$`
M!P```/I>`0`'`````E\!``4````*7P$`!P```!!?`0`,````&%\!``0````E
M7P$`(@```"I?`0`0````35\!`!8```!>7P$`$````'5?`0`L````AE\!`#$`
M``"S7P$`"P```.5?`0`A````\5\!`!P````38`$`(0```#!@`0`?````4F`!
M``X```!R8`$`$@```(%@`0`/````E&`!`"0```"D8`$`(P```,E@`0`'````
M[6`!``8```#U8`$`"````/Q@`0`-````!6$!``<````380$`"P```!MA`0`2
M````)V$!``L````Z80$`%````$9A`0`7````6V$!`!L```!S80$`"````(]A
M`0`4````F&$!``4```"M80$`%````+-A`0`9````R&$!`!````#B80$`30``
M`/-A`0!!````06(!``D```"#8@$`!P```(UB`0`4````E6(!``,```"J8@$`
M!0```*YB`0`/````M&(!``D```#$8@$`%0```,YB`0!)````Y&(!`!,````N
M8P$`+@```$)C`0`U````<6,!`#<```"G8P$`,@```-]C`0`*````$F0!``0`
M```=9`$`"0```")D`0`(````+&0!`#`````U9`$`-P```&9D`0`O````GF0!
M`%X```#.9`$`+P```"UE`0`O````764!`$L```"-90$`3@```-EE`0`O````
M*&8!`%0```!89@$`-````*UF`0`W````XF8!`%<````:9P$`+P```')G`0`U
M````HF<!`"P```#89P$`&P````5H`0`>````(6@!`"X```!`:`$`*P```&]H
M`0`K````FV@!`!0```#':`$`"P```-QH`0`,````Z&@!``\```#U:`$`#P``
M``5I`0`=````%6D!`"$````S:0$`!P```%5I`0`'````76D!`!,```!E:0$`
M"@```'EI`0`'````A&D!`"P```",:0$`#0```+EI`0`'````QVD!``@```#/
M:0$`!@```-AI`0`%````WVD!``@```#E:0$`!P```.YI`0`,````]FD!`"H`
M```#:@$`$P```"YJ`0`,````0FH!``0```!/:@$`!P```%1J`0`'````7&H!
M``<```!D:@$`&0```&QJ`0`%````AFH!`!(```",:@$`"````)]J`0`(````
MJ&H!``,```"Q:@$`!@```+5J`0`&````O&H!`"H```##:@$`$@```.YJ`0`(
M`````6L!``T````*:P$`#````!AK`0`'````)6L!`!(````M:P$``P```$!K
M`0!!````1&L!`!D```"&:P$`,````*!K`0`&````T6L!``4```#8:P$`"```
M`-YK`0`(````YVL!`&0```#P:P$`*@```%5L`0`_````@&P!`"H```#`;`$`
M)@```.ML`0`&````$FT!``<````9;0$`'@```"%M`0`J````0&T!`"X```!K
M;0$`-P```)IM`0`M````TFT!`#<`````;@$`;P```#AN`0`S````J&X!``@`
M``#<;@$`!P```.5N`0`,````[6X!`!@```#Z;@$`"P```!-O`0`4````'V\!
M`!@````T;P$`(@```$UO`0`8````<&\!`!H```");P$`%0```*1O`0`3````
MNF\!``<```#.;P$`&0```-9O`0`=````\&\!`!4````.<`$`&@```"1P`0`:
M````/W`!``4```!:<`$`"````&!P`0`;````:7`!`'(```"%<`$`>0```/AP
M`0`$````<G$!`!$```!W<0$`!0```(EQ`0`%````CW$!`!H```"5<0$`&P``
M`+!Q`0`7````S'$!`!<```#D<0$`&P```/QQ`0`G````&'(!`#8```!`<@$`
M#@```'=R`0`J````AG(!``<```"Q<@$`'@```+ER`0`2````V'(!`!D```#K
M<@$`%0````5S`0`D````&W,!`!\```!`<P$`%P```&!S`0`3````>',!`!$`
M``",<P$`!@```)YS`0`/````I7,!``<```"U<P$`"@```+US`0`8````R',!
M`!$```#A<P$`"````/-S`0`'````_',!`!,````$=`$`%P```!AT`0`&````
M,'0!`!$````W=`$`!````$ET`0`(````3G0!``X```!7=`$`"P```&9T`0`)
M````<G0!``<```!\=`$`!P```(1T`0`+````C'0!``D```"8=`$`"@```*)T
M`0`<````K70!`$D```#*=`$`(@```!1U`0`-````-W4!`!D```!%=0$`!0``
M`%]U`0`@````974!`!4```"&=0$`&````)QU`0`M````M74!`#\```#C=0$`
M)````"-V`0`(````2'8!`#P```!1=@$`)P```(YV`0`1````MG8!``H```#(
M=@$`"0```--V`0`/````W78!``8```#M=@$`%@```/1V`0`5````"W<!``@`
M```A=P$`"@```"IW`0`-````-7<!`"0```!#=P$`)@```&AW`0`N````CW<!
M`"<```"^=P$`(````.9W`0`E````!W@!`"H````M>`$`)@```%AX`0`T````
M?W@!`#````"T>`$`*P```.5X`0`L````$7D!`",````^>0$`,0```&)Y`0`V
M````E'D!`#8```#+>0$`*P````)Z`0`Q````+GH!`$$```!@>@$`*@```*)Z
M`0`I````S7H!`$,```#W>@$`*P```#M[`0`;````9WL!`#$```"#>P$`)P``
M`+5[`0`G````W7L!`!H````%?`$`LP```"!\`0`?````U'P!`"H```#T?`$`
M+@```!]]`0`P````3GT!`"T```!_?0$`,@```*U]`0`I````X'T!`"L````*
M?@$`.P```#9^`0`[````<GX!`$````"N?@$`0@```.]^`0"R````,G\!`"<`
M``#E?P$`(0````V``0`E````+X`!`#(```!5@`$`.0```(B``0!&````PH`!
M`$\````)@0$`#````%F!`0`$````9H$!``4```!K@0$`!0```'&!`0`-````
M=X$!`!````"%@0$`%0```):!`0`7````K($!`!D```#$@0$`!P```-Z!`0`$
M````YH$!`!(```#K@0$`$0```/Z!`0`.````$((!`!H````?@@$`%````#J"
M`0`6````3X(!`!4```!F@@$`#0```'R"`0`Y````BH(!``8```#$@@$`$P``
M`,N"`0`&````WX(!`!,```#F@@$`&0```/J"`0`=````%(,!`!(````R@P$`
M`@```$6#`0!)````2(,!``L```"2@P$`%@```)Z#`0`0````M8,!``0```#&
M@P$`$0```,N#`0`4````W8,!``0```#R@P$`%0```/>#`0`(````#80!`!``
M```6A`$`%@```">$`0`&````/H0!`!(```!%A`$`$P```%B$`0`C````;(0!
M``L```"0A`$`!P```)R$`0`2````I(0!`!,```"WA`$`$````,N$`0`8````
MW(0!`"````#UA`$`$@```!:%`0`2````*84!`"(````\A0$`%@```%^%`0`E
M````=H4!`$4```"<A0$`$0```.*%`0`A````](4!`!D````6A@$`&P```#"&
M`0`:````3(8!`#<```!GA@$`$@```)^&`0`(````LH8!`!,```"[A@$`"P``
M`,^&`0`T````VX8!`#0````0AP$`#0```$6'`0`.````4X<!`"@```!BAP$`
M$0```(N'`0`2````G8<!`!(```"PAP$`"@```,.'`0`8````SH<!`!,```#G
MAP$`'P```/N'`0`;````&X@!`!(````WB`$`$0```$J(`0`(````7(@!`!``
M``!EB`$`+````':(`0!B````HX@!``D````&B0$`%@```!")`0`M````)XD!
M``L```!5B0$`#@```&&)`0`X````<(D!`!````"IB0$`!P```+J)`0`5````
MPHD!`$D```#8B0$``P```"**`0`(````)HH!``@````OB@$`#@```#B*`0`0
M````1XH!`!4```!8B@$`%@```&Z*`0`B````A8H!`!D```"HB@$`(@```,**
M`0`>````Y8H!``D````$BP$`!@````Z+`0`(````%8L!``H````>BP$``@``
M`"F+`0`4````+(L!`!0```!!BP$`,````%:+`0`:````AXL!`!D```"BBP$`
M"@```+R+`0`-````QXL!``X```#5BP$`&````.2+`0!%````_8L!`"\```!#
MC`$`#@```'.,`0`2````@HP!`*````"5C`$`)@```#:-`0`?````78T!`!(`
M``!]C0$`"````)"-`0`&````F8T!`"<```"@C0$`0````,B-`0!`````"8X!
M`"X```!*C@$`,@```'F.`0`7````K(X!`"H```#$C@$`!P```.^.`0`(````
M]XX!``@`````CP$`!@````F/`0`9````$(\!`!0````JCP$`%@```#^/`0`4
M````5H\!`!(```!KCP$`&@```'Z/`0`2````F8\!`!0```"LCP$`"````,&/
M`0`*````RH\!`!@```#5CP$`#@```.Z/`0`S````_8\!`!$````QD`$`#```
M`$.0`0`4````4)`!`#H```!ED`$`(P```*"0`0`F````Q)`!`"4```#KD`$`
M(````!&1`0`?````,I$!`"\```!2D0$`(0```(*1`0`B````I)$!``0```#'
MD0$`&0```,R1`0`*````YI$!``\```#QD0$``P````&2`0`*````!9(!``<`
M```0D@$`%0```!B2`0`8````+I(!`!````!'D@$`&````%B2`0`2````<9(!
M``X```"$D@$`&@```).2`0`%````KI(!``<```"TD@$`%P```+R2`0`7````
MU)(!`!@```#LD@$`#@````63`0`0````%),!`!D````EDP$`+0```#^3`0`'
M````;9,!``@```!UDP$`#@```'Z3`0`0````C9,!``X```">DP$`"0```*V3
M`0`(````MY,!``H```#`DP$`%@```,N3`0`1````XI,!``H```#TDP$`,0``
M`/^3`0`/````,90!`(0```!!E`$`)0```,:4`0`+````[)0!``@```#XE`$`
M$`````&5`0`)````$I4!``L````<E0$`!@```"B5`0`+````+Y4!``(````[
ME0$`!@```#Z5`0`&````194!`!4```!,E0$`$````&*5`0`3````<Y4!`"L`
M``"'E0$``@```+.5`0`#````MI4!`!0```"ZE0$`"P```,^5`0`+````VY4!
M``4```#GE0$`&@```.V5`0`'````")8!``8````0E@$`'@```!>6`0`+````
M-I8!``<```!"E@$`"0```$J6`0`%````5)8!``D```!:E@$`!@```&26`0`0
M````:Y8!``4```!\E@$`!@```(*6`0`-````B98!`!````"7E@$`#@```*B6
M`0`%````MY8!`!$```"]E@$`"0```,^6`0`'````V98!`!H```#AE@$`+```
M`/R6`0!0````*9<!`#````!ZEP$`,0```*N7`0`'````W9<!``H```#EEP$`
M!````/"7`0`)````]9<!``D```#_EP$`%P````F8`0`*````(9@!``8````L
MF`$`#0```#.8`0`&````09@!``0```!(F`$`1@```$V8`0!$````E)@!`$,`
M``#9F`$`(@```!V9`0`%````0)D!`!4```!&F0$`"P```%R9`0`'````:)D!
M``@```!PF0$`%@```'F9`0`/````D)D!`!4```"@F0$`!P```+:9`0`$````
MOID!`!,```##F0$`!````->9`0`*````W)D!`!L```#GF0$`!0````.:`0`(
M````"9H!``\````2F@$`!P```"*:`0`3````*IH!`!0````^F@$`$P```%.:
M`0`(````9YH!``D```!PF@$`!0```'J:`0!$````@)H!`#4```#%F@$`/@``
M`/N:`0`L````.IL!`$L```!GFP$`10```+.;`0`Q````^9L!`%(````KG`$`
M-P```'Z<`0`Z````MIP!`"0```#QG`$`$0```!:=`0`6````*)T!``P````_
MG0$`,P```$R=`0`K````@)T!`"<```"LG0$`*@```-2=`0`(````_YT!``L`
M```(G@$`"@```!2>`0`'````'YX!`"\````GG@$`,@```%>>`0`Y````BIX!
M``H```#$G@$`&@```,^>`0`D````ZIX!`!@````/GP$`%0```"B?`0`'````
M/I\!`!````!&GP$`#@```%>?`0`1````9I\!``\```!XGP$`30```(B?`0"+
M````UI\!`'<```!BH`$`$P```-J@`0`6````[J`!`!@````%H0$`$````!ZA
M`0`2````+Z$!`!<```!"H0$`!@```%JA`0`5````8:$!`!(```!WH0$`$0``
M`(JA`0`5````G*$!`!@```"RH0$`-0```,NA`0!X`````:(!`!<```!ZH@$`
M!````)*B`0`8````EZ(!``D```"PH@$`!````+JB`0`,````OZ(!`"0```#,
MH@$`%@```/&B`0`-````"*,!`!(````6HP$`$P```"FC`0`6````/:,!`#8`
M``!4HP$`-@```(NC`0`T````PJ,!`#0```#WHP$`,````"RD`0`P````7:0!
M`!<```".I`$`5````*:D`0`5````^Z0!`!4````1I0$`%0```">E`0`5````
M/:4!`!0```!3I0$`&````&BE`0`8````@:4!`!0```":I0$`%````*^E`0`P
M````Q*4!`!H```#UI0$`'````!"F`0`[````+:8!`!,```!II@$`!@```'VF
M`0`.````A*8!`!\```"3I@$`%````+.F`0`5````R*8!`!,```#>I@$`&P``
M`/*F`0`@````#J<!`!L````OIP$`&0```$NG`0`=````9:<!`!0```"#IP$`
M'@```)BG`0`B````MZ<!`!0```#:IP$`&P```.^G`0`9````"Z@!`!,````E
MJ`$`'@```#FH`0`9````6*@!`!@```!RJ`$`&````(NH`0`*````I*@!`!4`
M``"OJ`$`!````,6H`0`$````RJ@!``<```#/J`$`"@```->H`0`0````XJ@!
M``8```#SJ`$`"````/JH`0`(`````ZD!``8````,J0$`"````!.I`0`'````
M'*D!``4````DJ0$`%@```"JI`0`&````0:D!``@```!(J0$`!P```%&I`0`$
M````6:D!``D```!>J0$`!P```&BI`0`)````<*D!`!````!ZJ0$`$````(NI
M`0`*````G*D!`!,```"GJ0$`!0```+NI`0`P````P:D!`!(```#RJ0$`$```
M``6J`0`4````%JH!`!,````KJ@$`#````#^J`0`6````3*H!`#8```!CJ@$`
M!P```)JJ`0`(````HJH!``T```"KJ@$`#````+FJ`0`/````QJH!``8```#6
MJ@$`#````-VJ`0`-````ZJH!``8```#XJ@$`!````/^J`0`.````!*L!`"4`
M```3JP$`$````#FK`0`6````2JL!`!<```!AJP$`)@```'FK`0`;````H*L!
M``@```"\JP$``P```,6K`0`,````R:L!`"D```#6JP$`!0````"L`0`&````
M!JP!``T````-K`$`$0```!NL`0`'````+:P!``8````UK`$`!P```#RL`0`%
M````1*P!``T```!*K`$`#0```%BL`0`,````9JP!`"````!SK`$`$0```)2L
M`0`/````IJP!`!H```"VK`$`$P```-&L`0`6````Y:P!``4```#\K`$`!```
M``*M`0`5````!ZT!`$P````=K0$`!0```&JM`0`-````<*T!`"@```!^K0$`
M&@```*>M`0`/````PJT!`!,```#2K0$`%````.:M`0`0````^ZT!``\````,
MK@$`&````!RN`0`0````-:X!`!4```!&K@$`&0```%RN`0`C````=JX!`"<`
M``":K@$`-P```,*N`0`+````^JX!``@````&KP$`#0````^O`0`/````':\!
M``\````MKP$`!````#VO`0`)````0J\!`"\```!,KP$`"P```'RO`0`)````
MB*\!`!,```"2KP$`:P```*:O`0`3````$K`!``H````FL`$`!0```#&P`0`&
M````-[`!`!H````^L`$`&0```%FP`0`9````<[`!``H```"-L`$``@```)BP
M`0`6````F[`!`#,```"RL`$``P```.:P`0`%````ZK`!`!<```#PL`$`"@``
M``BQ`0`%````$[$!``@````9L0$`&@```"*Q`0`.````/;$!``8```!,L0$`
M"````%.Q`0`(````7+$!``0```!EL0$`!0```&JQ`0!*````<+$!``\```"[
ML0$`$@```,NQ`0`=````WK$!``0```#\L0$`!0````&R`0`E````![(!`#D`
M```ML@$`#0```&>R`0`*````=;(!`!$```"`L@$`"@```)*R`0`+````G;(!
M`!8```"IL@$`&P```,"R`0`O````W+(!`"X````,LP$`(@```#NS`0`0````
M7K,!``,```!OLP$`!P```'.S`0`*````>[,!``<```"&LP$`#@```(ZS`0`6
M````G;,!``<```"TLP$`6@```+RS`0`/````%[0!``\````GM`$`"P```#>T
M`0`G````0[0!`%T```!KM`$`&P```,FT`0`'````Y;0!`",```#MM`$`*0``
M`!&U`0`(````.[4!``<```!$M0$`&P```$RU`0`&````:+4!``D```!OM0$`
M+@```'FU`0`M````J+4!`#<```#6M0$`!@````ZV`0`&````%;8!`"P````<
MM@$`9@```$FV`0`7````L+8!`"0```#(M@$`%P```.VV`0`"````!;<!`!$`
M```(MP$`!@```!JW`0`4````(;<!``X````VMP$`!@```$6W`0`(````3+<!
M``8```!5MP$`"````%RW`0`-````9;<!``T```!SMP$`"@```(&W`0`1````
MC+<!`#L```">MP$`!0```-JW`0`7````X+<!`!0```#XMP$`(0````VX`0`7
M````+[@!``L```!'N`$`$0```%.X`0`1````9;@!``P```!WN`$`"P```(2X
M`0`,````D+@!``H```"=N`$`(````*BX`0`5````R;@!`!(```#?N`$`%0``
M`/*X`0`8````"+D!``L````AN0$`&P```"VY`0`(````2;D!`!4```!2N0$`
M`P```&BY`0`'````;+D!``4```!TN0$`!0```'JY`0`(````@+D!`!8```")
MN0$`%P```*"Y`0`D````N+D!`",```#=N0$`'@````&Z`0`:````(+H!`!L`
M```[N@$`(@```%>Z`0`;````>KH!``8```"6N@$`!@```)VZ`0`2````I+H!
M`!(```"WN@$`#0```,JZ`0`E````V+H!`!````#^N@$`%`````^[`0`G````
M)+L!`"4```!,NP$`&0```'*[`0`)````C+L!``8```"6NP$`!P```)V[`0`2
M````I;L!`!$```"XNP$`"````,J[`0`)````T[L!``4```#=NP$`!P```..[
M`0`$````Z[L!``0```#PNP$``P```/6[`0!(````^;L!`#8```!"O`$`)0``
M`'F\`0`J````G[P!`$$```#*O`$`#`````R]`0!`````&;T!`#8```!:O0$`
M.0```)&]`0`Y````R[T!`#X````%O@$`&````$2^`0`;````7;X!`!0```!Y
MO@$`$P```(Z^`0`<````HKX!`"````"_O@$`%````."^`0`3````];X!`!8`
M```)OP$`&@```""_`0`[````.[\!`#L```!WOP$`/P```+._`0`T````\[\!
M`#L````HP`$`.````&3``0![````G<`!`!X````9P0$`&````#C!`0`-````
M4<$!`!H```!?P0$`#````'K!`0`2````A\$!`#@```":P0$`,P```-/!`0`J
M````!\(!``T````RP@$`4P```$#"`0!,````E,(!``4```#AP@$`'@```.?"
M`0`6````!L,!``L````=PP$`#P```"G#`0`6````.<,!``<```!0PP$`"0``
M`%C#`0`)````8L,!``X```!LPP$`#P```'O#`0`'````B\,!`!,```"3PP$`
M!0```*?#`0`F````K<,!``@```#4PP$`!@```-W#`0`4````Y,,!`!(```#Y
MPP$`$0````S$`0!$````'L0!``(```!CQ`$`!0```&;$`0`0````;,0!``4`
M``!]Q`$`!P```(/$`0`5````B\0!``8```"AQ`$`/0```*C$`0`3````YL0!
M`",```#ZQ`$`!````![%`0`X````(\4!`"8```!<Q0$`)@```(/%`0!=````
MJL4!`"`````(Q@$`30```"G&`0`J````=\8!`!8```"BQ@$`!P```+G&`0`/
M````P<8!``\```#1Q@$`#````.'&`0`7````[L8!``P````&QP$`'0```!/'
M`0`;````,<<!``4```!-QP$`$P```%/'`0`;````9\<!`"P```"#QP$`$0``
M`+#'`0`7````PL<!`!4```#:QP$`$0```/#'`0`=`````L@!``@````@R`$`
M$````"G(`0`9````.L@!`!(```!4R`$`%````&?(`0`2````?,@!`!P```"/
MR`$`$P```*S(`0`3````P,@!`!<```#4R`$`$0```.S(`0`+````_L@!``@`
M```*R0$`!0```!/)`0`=````&<D!``8````WR0$`&0```#[)`0`(````6,D!
M`!4```!AR0$`#````'?)`0`D````A,D!`!8```"IR0$`,P```,#)`0`>````
M],D!``X````3R@$`#P```"+*`0`J````,LH!``8```!=R@$`'P```&3*`0`&
M````A,H!`!H```"+R@$`"0```*;*`0`+````L,H!`"<```"\R@$`.````.3*
M`0`*````'<L!`"D````HRP$`$@```%++`0`+````9<L!`!X```!QRP$`%```
M`)#+`0`%````I<L!``<```"KRP$`"P```+/+`0`)````O\L!``8```#)RP$`
M"````-#+`0`&````V<L!``H```#@RP$`'````.O+`0`M````",P!`#$````V
MS`$`)0```&C,`0`S````CLP!`"8```#"S`$`1P```.G,`0`A````,<T!`"<`
M``!3S0$`/@```'O-`0!<````NLT!`#`````7S@$`!P```$C.`0`)````4,X!
M``@```!:S@$`"````&/.`0`7````;,X!`!8```"$S@$`+````)O.`0`N````
MR,X!`!D```#WS@$`,````!'/`0`Z````0L\!``@```!]SP$`'P```(;/`0`+
M````IL\!``8```"RSP$`*P```+G/`0`3````Y<\!`!0```#YSP$`"P````[0
M`0`(````&M`!`!<````CT`$`!P```#O0`0`+````0]`!``T```!/T`$`&P``
M`%W0`0`A````>=`!`#P```";T`$`"@```-C0`0`3````X]`!``4```#WT`$`
M!P```/W0`0`%````!=$!`!L````+T0$`#P```"?1`0`%````-]$!`!(````]
MT0$`&@```%#1`0`'````:]$!``X```!ST0$`$````(+1`0`3````D]$!``0`
M``"GT0$`!````*S1`0`,````L=$!`!X```"^T0$`6@```-W1`0`?````.-(!
M``H```!8T@$`*P```&/2`0`@````C](!`!8```"PT@$`%@```,?2`0`)````
MWM(!``D```#HT@$`$0```/+2`0`N````!-,!``<````STP$`#P```#O3`0`2
M````2],!`!0```!>TP$`$````'/3`0!!````A-,!``H```#&TP$`'````-'3
M`0`5````[M,!`!H````$U`$`.0```!_4`0`C````6=0!`$P```!]U`$`4```
M`,K4`0!)````&]4!`!$```!EU0$``P```'?5`0`=````>]4!`"(```"9U0$`
M'0```+S5`0`)````VM4!`!,```#DU0$`(0```/C5`0`'````&M8!`"4````B
MU@$`'@```$C6`0`*````9]8!``8```!RU@$`$````'G6`0`1````BM8!`!P`
M``"<U@$`!````+G6`0`(````OM8!``L```#'U@$`$````-/6`0`0````Y-8!
M`!<```#UU@$`%P````W7`0`)````)=<!``8````OUP$`0````#;7`0`T````
M=]<!`#,```"LUP$`!@```.#7`0`&````Y]<!``8```#NUP$`'0```/77`0`6
M````$]@!`"P````JV`$`#@```%?8`0`0````9M@!`"0```!WV`$``P```)S8
M`0`&````H-@!`!$```"GV`$``@```+G8`0`-````O-@!`!H```#*V`$`#```
M`.78`0`8````\M@!`!\````+V0$`$@```"O9`0`2````/MD!``L```!1V0$`
M%````%W9`0`5````<MD!``\```"(V0$`"P```)C9`0`2````I-D!``X```"W
MV0$`%P```,;9`0!H````WMD!`"(```!'V@$`/P```&K:`0`-````JMH!``<`
M``"XV@$`"0```,#:`0`4````RMH!`!<```#?V@$`%0```/?:`0`@````#=L!
M`"0````NVP$`%P```%/;`0`E````:]L!`!$```"1VP$`+P```*/;`0`3````
MT]L!`!4```#GVP$`D````/W;`0`D````CMP!`"````"SW`$`,0```-3<`0`D
M````!MT!`",````KW0$`)````$_=`0`E````=-T!`"0```":W0$`'0```+_=
M`0`+````W=T!``<```#IW0$`"````/'=`0`)````^MT!`!0````$W@$`#P``
M`!G>`0`W````*=X!`!L```!AW@$`%@```'W>`0`(````E-X!``P```"=W@$`
M:@```*K>`0!"````%=\!`$H```!8WP$`@````*/?`0`-````).`!`#$````R
MX`$`,0```&3@`0`*````EN`!``4```"AX`$`!@```*?@`0!%````KN`!``@`
M``#TX`$`9@```/W@`0`U````9.$!`"@```":X0$`%````,/A`0`G````V.$!
M`!X`````X@$`+0```!_B`0`W````3>(!`$0```"%X@$`-P```,KB`0`;````
M`N,!``<````>XP$`&P```";C`0`7````0N,!`!4```!:XP$`"0```'#C`0`T
M````>N,!``P```"OXP$`"@```+SC`0`)````Q^,!`!<```#1XP$`"0```.GC
M`0`&````\^,!`!8```#ZXP$`"0```!'D`0`(````&^0!``4````DY`$`#P``
M`"KD`0`0````.N0!`"0```!+Y`$`(````'#D`0`3````D>0!`#0```"EY`$`
M#````-KD`0`'````Y^0!`!(```#OY`$`&P````+E`0`.````'N4!``X````M
MY0$`&0```#SE`0`F````5N4!``X```!]Y0$`(````(SE`0`V````K>4!``@`
M``#DY0$`"@```.WE`0`9````^.4!``<````2Y@$`"````!KF`0`3````(^8!
M`!(````WY@$`$@```$KF`0`1````7>8!``8```!OY@$`"0```';F`0`(````
M@.8!``D```")Y@$`#@```)/F`0`0````HN8!``8```"SY@$`%````+KF`0`#
M````S^8!``4```#3Y@$`$````-GF`0`?````ZN8!``L````*YP$``@```!;G
M`0`A````&><!``4````[YP$`!0```$'G`0!R````1^<!``8```"ZYP$`!@``
M`,'G`0`<````R.<!`$8```#EYP$`'@```"SH`0`<````2^@!`%L```!HZ`$`
M.P```,3H`0!/`````.D!`"````!0Z0$`%0```''I`0`&````A^D!``@```".
MZ0$`#P```)?I`0`1````I^D!``H```"YZ0$`#P```,3I`0`7````U.D!`!$`
M``#LZ0$`$0```/[I`0`4````$.H!``@````EZ@$`"@```"[J`0`=````.>H!
M``X```!7Z@$`&@```&;J`0`)````@>H!``4```"+Z@$`!@```)'J`0`C````
MF.H!``8```"\Z@$`+@```,/J`0`%````\NH!``8```#XZ@$`#0```/_J`0`&
M````#>L!``\````4ZP$`"P```"3K`0`5````,.L!`!(```!&ZP$`%0```%GK
M`0`&````;^L!`!D```!VZP$`"@```)#K`0`(````F^L!``<```"DZP$`!@``
M`*SK`0`3````L^L!`"4```#'ZP$`"P```.WK`0`.````^>L!`"@````([`$`
M&````#'L`0`:````2NP!``4```!E[`$`"@```&OL`0`3````=NP!``T```"*
M[`$``@```)CL`0`.````F^P!``D```"J[`$`)0```+3L`0`?````VNP!`#H`
M``#Z[`$`*P```#7M`0`X````8>T!`"P```":[0$`9P```,?M`0`;````+^X!
M`&````!+[@$`.````*SN`0!*````Y>X!`%D````P[P$`+P```(KO`0`Q````
MNN\!`"L```#L[P$`,0```!CP`0`O````2O`!`"8```!Z\`$`/0```*'P`0`B
M`@``W_`!`",````"\P$`&````";S`0!*````/_,!`($```"*\P$`,P````ST
M`0`O````0/0!`$````!P]`$`6@```+'T`0!0````#/4!`#D```!=]0$`(P``
M`)?U`0`7````N_4!`"P```#3]0$`(0````#V`0`C````(O8!`#,```!&]@$`
M)````'KV`0`J````G_8!`#8```#*]@$`&P````'W`0`1````'?<!`%0````O
M]P$`*P```(3W`0`M````L/<!`"<```#>]P$`(@````;X`0`M````*?@!`%D`
M``!7^`$`-0```+'X`0!4````Y_@!`#H````\^0$`/````'?Y`0!.````M/D!
M`&\````#^@$`6````'/Z`0!'````S/H!`$H````4^P$`20```%_[`0!K````
MJ?L!`'4````5_`$`:0```(O\`0!F````]?P!`#\```!<_0$`+0```)S]`0`L
M````ROT!`#````#W_0$`=P```"C^`0!F````H/X!`'4````'_P$`P````'W_
M`0`9````/@`"`"H```!8``(`/0```(,``@`R````P0`"`%(```#T``(`)```
M`$<!`@!;````;`$"`"````#(`0(`"0```.D!`@"]````\P$"`$H```"Q`@(`
M(P```/P"`@`]````(`,"`"8```!>`P(`(0```(4#`@`^````IP,"``@```#F
M`P(`!P```.\#`@`%````]P,"``T```#]`P(`#@````L$`@`4````&@0"``X`
M```O!`(`!0```#X$`@`3````1`0"``$```!8!`(`>0```%H$`@`+````U`0"
M`!,```#@!`(`!````/0$`@`'````^00"``8````!!0(`!0````@%`@`\````
M#@4"``0```!+!0(`%````%`%`@`+````904"`!$```!Q!0(`#````(,%`@`"
M````D`4"``<```"3!0(`!P```)L%`@`1````HP4"``P```"U!0(`%P```,(%
M`@`&````V@4"`!4```#A!0(`#````/<%`@`#````!`8"`"T````(!@(`!```
M`#8&`@`'````.P8"``<```!#!@(`*0```$L&`@!&````=08"`$(```"\!@(`
M00```/\&`@`>````00<"`#8```!@!P(`.0```)<'`@`D````T0<"`!L```#V
M!P(`)````!((`@`M````-P@"`"8```!E"`(`(P```(P(`@`M````L`@"`"D`
M``#>"`(`+@````@)`@`\````-PD"`"8```!T"0(`-P```)L)`@`P````TPD"
M`"D````$"@(`+P```"X*`@`M````7@H"`"8```","@(`,````+,*`@`J````
MY`H"`"P````/"P(`+P```#P+`@`J````;`L"`"8```"7"P(`*@```+X+`@`O
M````Z0L"`",````9#`(`+0```#T,`@`X````:PP"`#L```"D#`(`(````.`,
M`@`L`````0T"`#X````N#0(`*0```&T-`@`N````EPT"`"T```#&#0(`+```
M`/0-`@`F````(0X"`"````!(#@(`*````&D.`@`J````D@X"`$,```"]#@(`
M+P````$/`@`\````,0\"``D```!N#P(`%P```'@/`@`<````D`\"`#4```"M
M#P(`(@```.,/`@`.````!A`"``\````5$`(`$P```"40`@`+````.1`"``H`
M``!%$`(`'P```%`0`@`&````<!`"``<```!W$`(`(@```'\0`@`E````HA`"
M`"````#($`(`*@```.D0`@`8````%!$"``@````M$0(`^````#81`@`:````
M+Q("`!T```!*$@(`"````&@2`@`+````<1("`!8```!]$@(`%@```)02`@`E
M````JQ("``<```#1$@(`4P```-D2`@`:````+1,"`!H```!($P(`!P```&,3
M`@`9````:Q,"``P```"%$P(`3````)(3`@`+````WQ,"`#````#K$P(`'P``
M`!P4`@`8````/!0"`!\```!5%`(`/````'44`@`=````LA0"`!$```#0%`(`
M)P```.(4`@`3````"A4"`!0````>%0(`%@```#,5`@`+````2A4"`!H```!6
M%0(`"````'$5`@`L````>A4"``@```"G%0(`*0```+`5`@`O````VA4"``<`
M```*%@(`&0```!(6`@`'````+!8"``@````T%@(`"0```#T6`@!%````1Q8"
M``<```"-%@(`$P```)46`@`3````J18"`!0```"]%@(`"@```-(6`@`*````
MW18"``<```#H%@(`%````/`6`@`'````!1<"`!D````-%P(`#0```"<7`@`9
M````-1<"`!L```!/%P(`"@```&L7`@`-````=A<"`!<```"$%P(`!@```)P7
M`@`T````HQ<"``P```#8%P(`$````.47`@`)````]A<"``(`````&`(`$```
M``,8`@`:````%!@"``L````O&`(``P```#L8`@`(````/Q@"``X```!(&`(`
M"0```%<8`@`.````81@"``T```!P&`(`%P```'X8`@`8````EA@"`!$```"O
M&`(`/````,$8`@`E````_A@"`",````D&0(`%P```$@9`@`.````8!D"`#0`
M``!O&0(`!P```*09`@`5````K!D"`%D```#"&0(`$@```!P:`@`0````+QH"
M``D```!`&@(`!````$H:`@`$````3QH"`!$```!4&@(`'@```&8:`@`&````
MA1H"``<```",&@(`!P```)0:`@`3````G!H"``<```"P&@(`%P```+@:`@`7
M````T!H"`$(```#H&@(`-````"L;`@`X````8!L"``4```"9&P(`&P```)\;
M`@`A````NQL"`!D```#=&P(`(@```/<;`@`1````&AP"``(````L'`(`!```
M`"\<`@`1````-!P"``P```!&'`(`!0```%,<`@`#````61P"``X```!='`(`
M5@```&P<`@`R````PQP"`!P```#V'`(`00```!,=`@`V````51T"`%@```",
M'0(`&0```.4=`@![````_QT"`"@```!['@(`2````*0>`@`D````[1X"`$<`
M```2'P(`+````%H?`@`L````AQ\"`"\```"T'P(`+@```.0?`@`N````$R`"
M`#@```!"(`(`+````'L@`@`T````J"`"`"T```#=(`(`-0````LA`@`9````
M02$"`",```!;(0(`&````'\A`@!Z````F"$"``D````3(@(`RP```!TB`@"0
M````Z2("`'P```!Z(P(`+0```/<C`@!N````)20"`!T```"4)`(`)@```+(D
M`@`3````V20"`!,```#M)`(`%@````$E`@`J````&"4"`$````!#)0(`(0``
M`(0E`@`E````IB4"`'$```#,)0(`'````#XF`@`7````6R8"``L```!S)@(`
M!0```'\F`@`&````A28"``@```",)@(`!0```)4F`@`6````FR8"`!4```"R
M)@(`&0```,@F`@`D````XB8"`!`````')P(`#P```!@G`@`2````*"<"``D`
M```[)P(`%````$4G`@`(````6B<"``4```!C)P(`&0```&DG`@`*````@R<"
M``P```".)P(`&````)LG`@`(````M"<"``P```"])P(`$````,HG`@`.````
MVR<"`!8```#J)P(`#0````$H`@`1````#R@"`!0````A*`(`!@```#8H`@`%
M````/2@"`"@```!#*`(`'````&PH`@`+````B2@"`"P```"5*`(`%P```,(H
M`@`E````VB@"`!H`````*0(`"````!LI`@`1````)"D"``<````V*0(`!P``
M`#XI`@`9````1BD"``D```!@*0(``P```&HI`@`"````;BD"`!(```!Q*0(`
M#0```(0I`@`*````DBD"`!8```"=*0(`&0```+0I`@`'````SBD"`"8```#6
M*0(``@```/TI`@`#`````"H"`!(````$*@(`&0```!<J`@`*````,2H"``L`
M```\*@(`$@```$@J`@`&````6RH"`"$```!B*@(`"0```(0J`@`7````CBH"
M`!<```"F*@(`$@```+XJ`@`"````T2H"``0```#4*@(`#@```-DJ`@`/````
MZ"H"`!````#X*@(`+P````DK`@`&````.2L"``@```!`*P(`%P```$DK`@`%
M````82L"``,```!G*P(`"P```&LK`@`!````TP0``!P$```Q!0``7P,`````
M``"<`0``;0(``*`$````````E`,``,<!``#[!@``?```````````````A@(`
M`"D'```+`0```````($'``#!````=P4``!4$``#P!0``+````-L#``#!!@``
M(P<```@"```!!```O`4```('```Q`P```````*8"``#O!0``9`(``+("```/
M!```@0,```````````````````````#6!```404``(4$`````````````/8!
M``!P`@````````````!_`@``+@0````````C`0``I`4```````!B!P``XP4`
M`(\&```E`0``<`8``/4$``!N`@``<`$``#,'``#"`0``T0(``"\$``!O`P``
M3@<``%H```"B`0``,P$``(D'````````>P$``.L```"6!@``P`4``%P'``!*
M!0``S`8```````"4!```8@(``/(````I`@``9@(```````#;!```A`8``-T%
M`````````````*4```````````````````"8`P```````$````#D!@``````
M`,T!````````G00``$@"``"_!0```````/T"``"(!P````````P%````````
M3P0``,L%``#L`@``)@4``!<`````````-````%@```"\`0````````````"U
M`@``6@0``&4#``!J`P``7P$``(('``````````````````#Z`0``9`,``&\`
M``#6`0```````'T&````````"`<``)``````````30,``)L"````````'`,`
M`%T&``#T`0``WP```"@#``#<`0``T`$``+8#``!'`P```````!L'```1!P``
M)0,``/$```"P!0``T@0`````````````JP,``*0`````````R@4``&$#``!Y
M`P``E00```H$````````B@8``,`!````````X00``'@'``#9`P``YP$`````
M``#^!0``2@<``*D!``!8!```Y`$```````!/````O@$`````````````````
M`"\#``!L!P```````+(`````````F`4``&<$``"D!@``X@$``$8&````````
M*@```/L!``!H`0``5`<``-H#```H!@``HP0``%0&``!6!```KP8```````"=
M`@``6P```)(&``"+`P``J0````````"L!0``TP```*`#``!Z`0``9P(``,(#
M```H!P``>P,``"L`````````-@``````````````,0(``(,```#D!```````
M`/8$``!Y!```1`<```````#W``````````````"3`@``N@4````````7!0``
MJ@,``"L"``!Z!P```````'0$```[`@````````````"0`@``C@$``(H$``#<
M````?`<``%<%``":`P```P(``#L'``!>`P``!@$```````!%!````````"T'
M``"?`P``I0$`````````````9P4``'$!`````````````$(&``#;````/0<`
M`$H``````````@(````````I`0```````%8#````````G`0```````#,`0``
M800``!8#````````)P0``&$``````````````"4$``!W````[@,``&8&````
M````G`8``/\%``![`````````!@&``"Q!````P````,'``#<!0``MP8``,D#
M``!\`@``%@<``.P``````````````&,!````````[@(``)H```"2````G@,`
M``````";`0``*P4``'$"``#S`P``1@,``+X"``"Z`0``W00``-8&``"T`P``
MXP0``,H$``"J!````````!@'```7`@``OP0``!@!``"Q`@````````````#B
M`P``CP(```````!^`0``_04``&D!```6!@``^`$``"H#``!+`P``<@,``$<$
M``"6`0``1P```,@!``!Q`P``3@8``#H```!@!@``4P```-4&``!V`@``````
M`"X%```F`@``<P8``.T````*!@``!````.0"``!^`P``@P4``(D!``"3!```
M_@(``&0'``#F!0``%P$```````"?`0``#0<``'L"``!^````!00```D'```M
M!@``-`8```````!2`@``OP````````!W`P``_P,````````+````,P4`````
M````````9@<``"<&``#=`````````/0"```_!P```````-@#``#:!```````
M``````!H````#0(``'(&````````TP8``,4&``!Q````H````/P&``!"`@``
M`````)L$``"Y`P``P`````0$```.!@``3`$``)0"``"Y!0``H`$``,$!````
M````!0````````!,!P``U@(``&,`````````Q````````````````````/($
M````````0`4``&\'````````S08````````7`P``@08`````````````4@4`
M````````````\P0``'<$``"C!@``;P0```@```!>````2`<``+H#``!V!0``
MW@```(0#```D!```.P4``/<&``"<`P``=P(```````!J`0``/@(``+X&``#M
M!0``O@0```````!O!@```````(D```"E`@```````#,&````````'`<`````
M``!5`0``(@0``#@!````````;00```````"'`@``>04``(`%``#6````````
M`"$"``!/!@``-P0``#,"`````````````)<#``#_!`````<```<#``!I!@``
M`````/$!``#&````\`,``(\```!;!P````````````#G!@``A0,`````````
M````W0(``"X#``!7`0``]`8```````#E`0``_@```$T```#-!```$`4`````
M```V`0``D`,``'T!``"7````600``'\$``!S````IP4``%@"``""`@``````
M`$$&``!V`0``_@$```````#G!````````"0`````````^`0``&L$``#&!```
M60$``"$$```&````GP(``%X"``````````````,&``"4!0```````.$&``".
M`P``/@```"L!```4`@``UP,``)$&``!`!P```````&P#````````C@0``*,`
M````````Q0,``%$```"]`@``+`0``"`$``#I!````````"P&``#V`@``+@8`
M`%@%``````````````````"I`@``)`,`````````````LP$```````!]````
M)P,```````!R!P```````)$$````````S@$``/`&```(`0``````````````
M``````$``$P%```X!@```````,@%```1`0``7P0``/H#``"<````L`,``,0!
M````````=00``'$$``#7`@``R04``'P!``",`0``````````````````_`4`
M`#4$````````/@<``*4&``#0`P``J`8``.T!``"F`````````.\"````````
M``````````"M!```ZP$``/D$``#?`P``*`0```````!F!```GP````\&``"Y
M!```Z@,```````#)!```6P(``(P$````````Q`(``+X%``!"!0``=`<``-4%
M``"3!@```````&,'`````````````!L$````````]`,``%0```#9````````
M`$@```"6`````````%8"```W````'P8``#P"``!S`@```````/,"````````
M"`0``+<"``"E!```=P<```````#:!@``%0````````#9!````````/P`````
M````'P4``(L%``#W`0``]@4``'P#``#8!@``M`4``)4%```#!0``````````
M`````````````(,$``"_`@``S@(```P'``"9`P``_P(```````#T!```/P(`
M`%,!````````Q00``#(!````````RP(``(P``````````````$L!````````
M`````+H&```)`0``W@$``"8$``"D`P``S`4``',!```S!```$`8``(L$``!B
M`````````"\```"@!@``.`(``%D"``!_!P``1P<``(T%```9`````````*T`
M``#O`P``T08``'P%```R````O04``,H"````````]@8``+8&``!;!0``1`$`
M````````````'0(``!X'``#;!@````````X%````````8`$``#D"``!#`@``
MNP$``(`#````````*@$``$8```#0`@``$P8```````!_````0@,``#4'```M
M`0``,00``.$!````````T04``+0"``#H`0``5`,``/@#``!]!````````*(#
M``#4`@``8@,``.H%`````````````%\````?`@``,@,``/P"````````<P0`
M``````"`!@``-P4``#H%```8!````````'8```"C`P```````)<%``!B!0``
M$@(``&P!```B`0```````(X`````````:@4```````#%!0``&@$``.`!````
M````DP,``)@`````````A04``!@`````````+`4``(8$````````'````)D&
M``!H!@``^P(``(4!````````3`,``&@'``!Z!```$`0``&4```!4!0``Q`8`
M`'0"``#@``````````````"W`P``=0,`````````````````````````````
M7`$````````X!P``?@(``&P``````````````(@"````````S@8```L"```/
M!0``;0$``"T"``#?!0``YP(``$\#```-`0``8````&<`````````OP8``-D"
M``"Y!@``````````````````Z@```+($```H`````````"\'````````\P``
M`*H%``#]`0``U00``!H```````````````````!B!````````,@&``!?!@``
M3@`````````3`@````````````!*!```%08``",````_````@@4``*@$``"X
M`@``D04``.0```!"!````````+@%``!!!0``'P$``+@!````````FP4`````
M``"U`````0<``"L'`````````````+`$````````:0<``'L%``!F````````
M````````````S@0```<!``!7!@````````````#?!@``8`<``#L!```[!```
M=0(``.L&```Y!```'P<``/T&``!Q!@``#`$```````!'!@``G08``+P$``!E
M!@``"04``$4'``````````````````!S`P``BP```'D'``#2`P```0(``*,!
M```L`P```````+,$````````)`<```$#``#K`@``<````&T&``#8````$08`
M`$4#``!=!P``\@4``.@&``#1!```/P,```````#Z!0``90<``)\&``#2`@``
M`````&L!``#1````B08``#````#(`@``H00``.P!``#B````:@(``*8!``!<
M`@```````#@#````````6P8``"L$``!@`P``X`4```````#/````E@4``-<&
M``!%`@````````````"5`0`````````````&!@``1@4``/X&````````20,`
M`&P%``!3!P``TP$``(`!`````````````````````````````/T$``!L!```
M!@0``#X#```?!```WP0```````!<`P``?@0``!$"```K!@``RP0``!L#````
M````?@8``'4````%`P``D0$```````"L``````````0"``!Y`0``*00``#0'
M````````>@```'0``````````````&(!``!4`0``#0```#\!``#>`P``M`8`
M`#<'`````````````"8```````````````````"(!0``CP0```````!&!```
M``8```````"S````4`$``)`&``"R`0``%@(``%`"``"'`P``;@<``/4"``"V
M````\@8``/$#``!1`0``X@0``.\$````````SP8````````O`@````````L'
M``!0`````````%0"````````2P8``($"````````&P8```````#S!@``BP8`
M`+L```!<!@```````/D!``"$````108```````!U`0````````````!$`@``
M2`$``!4#````````)`$``%D#``#U````F@4``%,%``#<!@``.0$``!D'````
M````B`$``%P%``!7!```00<``)H"```]`P``$0,``*X%``!)`0```````)\$
M````````/@$``&H```!^!0``IP,``*<&```@`````````*X```!+````$@``
M`*8$```!`0``>`8```````#5`0``N@```.0#``"V`0````````````!H!```
M``````````"^````N0```'($````````$0```%\%``#F!```(`,``*L!``#F
M````(@(``)X&``"]`0``\@$``#D&``""!@```````($````2!```NP(``#T$
M``!_`0``&P```+,"````````O0,``'4%``!E`@``A0````````#-`@``PP8`
M`'\%````````5P(``)\%``#P`0``K0,```````"*!0``<@$``+$```"!!```
M`````.\&````````$`<``&\"````````[0,````````0`@``%`$``"T#``!$
M!````````-4#``#?`@```````'L&``!)!0```````-H%``"'!````````+$&
M``#W`@``KP0```4"````````(0```/L%``!W`0``/`,```D&``#S!0``\`(`
M`'$%``"X`P```````-0#``#H`@``6`8```````![!```00,````````J`@``
MG`4``,8%``#9!0``804`````````````_P8``'H%``!'`@``/````+P`````
M``````````\#``````````````\'```V!@``%`0`````````````80(```<'
M```S`P```````$`!```]!0```````)H&`````````````(<!``#)````Z0,`
M`.,&``"]````BP$``+T$````````-@,``#4"```=!0```````(8&``"N!```
M!P(``.L$``"_`P``````````````````200``%`&``"U!```<P4``,0#````
M````:P,``-H!``"P`0```````),%````````R08``*(%````````"0,``'T#
M```3````#00``,4!```+!````````$$"``!5````X@4```````"L`P```P,`
M`!D$```%!@````````````#J!```ZP4```H#``"H!0``MP0``!8```!4!```
M-P$``%4%``"D`@``^0(```````"``@``(P4``/L#``!#`0``:@0`````````
M````/P4``!,!````````\@,``,<$``"]!@```````$@#````````S0,``%T%
M``!\!```/`8``/D````>!0``1@$```````"K````5@$``.@$``"-````````
M`,X#```W!@````````````#+````AP```-T#`````````````,P$````````
M40<````````9!0```````.<#```Q````S`,``(D%```0`0``#@```&H'``"G
M````SP0``&$'```7!@``V@```"$!``"B`@``F`(``%X$```M!```(@<``&4!
M``!X`@``$P<``!T$``#8!0``G`(``%T`````````X`0``&8%```^!@``Y@(`
M``````"R!0````````0#```>!```````````````````!`4```````"3`0``
MA08``'0#``"O`P``^08```````"2!```A0(``!T&````````W`,```````!;
M`0``6@<``!0#``#Q`@``,@<``'0%``"H`P``70$``"H&````````````````
M``"N!@``X`,``$X#``#\!```.0<``'@$````````+P4``&<&``#4````H`(`
M`/D#````````*`4``(4'``#L!0``<@(````````I``````````8"````````
M"@<``.4$````````408`````````````)@<```$&````````1@(`````````
M`````````-<!``#-````-P,```0!````````*@<``'$'``!B!@```````($%
M``!N`0``KP(``,0$```N`@``500``````````````````(0%```3!```D0(`
M`%8&``#2````K@,``$@&```V!P``>P<```````#0!```&P4```````"Z!```
M``````````""`0`````````````C`@``6@$````````:!P``,0<``"`"``"H
M`@``)0<````````Z!```B0(``&L```#Q!@``.04``#P!```1!0```````.0%
M``"*````'`$``*L$``")`P``!@4````````B!0``70(```````#J`0``````
M`/H$````````WP$``$<%````````$@8``(@```#I`@``-`0``.4#``"K!0``
MS04``,<#````````/P0``````````````````.H"``"A`P``_@,``!@%```S
M````]04``'8'````````;@8```````#+`P``;P$``!X#``!9!0```````(8`
M``"#`0```````+0```"/`P``A`0``#`$``"W`0``F0(``*`%``"V`@``Y0(`
M```````R!```H0```"P"``#(`P``"P,```````",!0```````!H&``"L!```
M````````````````:P4```````#8`0````````X$```'!@```````"4```#A
M`P``G@``````````````<@4``!X&````````%0$``#X%```=````S`(``)X%
M``"(!@``C@(``"$%``"6`@```````#\&``!`!@``H0$``*$%```G`@``````
M```````M````20<``)4"``!2!``````````````T`@``]P4``'0!``!=`P``
M-0$```````!.!```5@4``*($```)````PP4``(,#````````6`$``&D"``#L
M`P``&0(```````#"`@``60<``$,#```\!```D`$``.8!``#C`P``400`````
M````````K`(```X"```<`@``3@$``$@$```*`````````$P&``#\`0``+@``
M`(T!````````+`<``.T"``#I`0``SP$``&P"`````````````-H"``##`@``
M)P```+,#``"2!0```````&X````0`````````(T$```;`0``<`0``'4'````
M`P``W@4``%('``"R`P``!@<``(T#````````C0(``&<!``""`P``OP$``'8&
M``!N!```J@```$X"``!D!0```````(P#```N!P``@@0```````"\`P``/@0`
M`!@"````````-P(``)(#``""``````0```````````````````\"```5`@``
MP@```+L#````````T`8``#`%``#N````P04```````!(!0``$@<``%@'```"
M!```7@$`````````````V0$``$D&``#Q!```;`8``#@%```Z!P``F@$``.$`
M``"\`@``O@,``!8$`````````````)D%``#I!0``]0,```````!"!P``&0,`
M`.P$``"5`P```@,```@&``"-!@```````&L&``!?!P``+@$``"4&````````
M9`8``&D#````````7@8``+4#```*`@``20(``!\````+!@``9`$`````````
M````3P(`````````````I@4``#`&``"Q`0``#`8``-(!```U!0``A@$``%P`
M````````.@8``.8#```:!0``NP0``*T"````````@````'H#``"'!@``````
M`(,&``#=`0``-0,``.\!``````````````P```"6`P``8P(``)X"``#Q!0``
M````````````````9`0`````````````Z0```+8%``"A!@```````!X!``#!
M`P``.P8``'`%``"$`0``:P(```````!-!```Y@8```````#&!@``CP$`````
M``##````'0<```````!C!```<P<````````-!0``/0$``$\'``!M`P``(08`
M`$0````5!P````````````#8`@``20```#L#```7!````````.\```!J!@``
M``````H%``!3`P``!P4``"0%``"U!@``J00```<$``!'`0``0P8`````````
M`````````"`%````````L````*\````O!@``[@8``.,`````````(@8``!(#
M``#!!```V08`````````````?P,```P$```8`P``K`$```````"Y`0``X@8`
M`,X`````````D@$``'X'``#%`@```@4````````T`0```````*@````L`0``
M#@,```````"0!```&0$``*(```!0!0```````.D&``#5`@``````````````
M````"00``)D!``";`P``J@$```P"``#4!0``]`4``/4!```-`P```````)T!
M``#%`````````,8"``!7````.````"@"`````````````/T#``"G!```NP4`
M``````#"!0```````$\!```=`0``[`8``/@&``"6!```4`0```````"M`0``
M``````````"D`0``J04``+`"``!C!@```````-8#```6!0``I@,````````:
M`@````4```````"&!P``@`<``-`%``#C`0``K`8``.,"``#`!@``JP(``'`#
M``"0!0``KP$```````#2!0``H@8```````"U!0```````,X%``!M!0``````
M`/@"````````W08`````````````'P,``'T'``"T!```I@8```````#$!0``
MIP$``$,```"=`P``&P(```````!,!`````````(!``"7`@``3P4``$`#``!Y
M!@``W`(```````!&!P``8P4``'\&``!$`P``Y0```$T%``#"!@``````````
M`````````````-````!;`P``MP```'D"``!#!0```````%(&``#6!0``2@(`
M`#T````M!0```````'H&``#@`@``8`0``!H#``````````````````##!```
M`````-,#``#B`@``>`,``)0```"'!P``&@0```````````````````````!!
M!```&08`````````````4`<````````I`P``_0```%<#`````````````"$'
M``!1`P``.@(``),```#S`0``50(`````````````#08```````"9!```````
M`$(!``!?`@``2P0``$L'``!N!0``L0,```````"$`@``308````````F`0``
M`````-L!````````L04``'`'``#<!```:04``+,&```G!0``/`<``$,'``!*
M`P``:00``,\#````````:`(``*\%``"`!```=@,``-$#``!0`P``F`$``.$"
M``!,`@``P@0```````"(!```:P<``'(```````````````````#Z`@``````
M`#(%``!H`P``!0<``",#``!\!@```````.@#``"7!```M0$``,H&``#/`@``
M*`$``)<!``#+`0```````%8'``!3`@``6@,``(8%````````,`(``/@```"9
M`````````,P```"N`@``-`4```````#7`````````*4%````````````````
M```D!@``F`8``.X!```A`P``.P```)<&``!!`0``Q@,``(P"```$!P``%04`
M`&4%```````````````````B`P``B@(``!X```"#!P``50<``*T%``!%````
M=08``#@$``##`0``U`$``$(```!E!```)P<``&\%``#U!@``5@````X!``#Y
M!0``30(``/X$``!:`@``HP4```0&``#H!0``(@```$4%````````2@8``)@$
M``";!@``P0(```,$`````````````+P&``!N`P``%`8``.T&````````?04`
M`.@````T`P``6@4``!(%```/`0``'@(```````!H!0```````"\!```]`@``
M30$``#`!```E`@``U0`````````E!0``9@,``/8```!Z`@``C@8`````````
M````HP(```````"N`0``_`,``&$!``"X````D0```````````````````)4`
M```F`P``#P``````````````B@,```````!]`@``QP4``,8!````````A@,`
M`"`'``">`0```````-L"``#)`0``"@$``%4#``!Y````U`0``,,#````````
MR@$``!,#``````````````````!M!P``\`0``'8$```(`P```````#T&``#8
M!````````*$"``!M````CP4``!<'````````5P<``"H$```"````8`(``!P%
M````````^`4``$X%````````R`````P#``"+`@```````*4#```(!0``````
M`#D#``#_`0``#@<``%T$```)`@```````$P```":!```T0$``"D%``#G!0``
M`````'@`````````9@$``/````#N!0``2P(``+<%```%!0```````%(```#K
M`P``2P4``-0&```Y````R`0``)T%``#``@``7@<```,!``!W!@``1`4``-X&
M``````````````<````V!0``*P,``/H```#'!@``%`<```(&``#*````>`$`
M`!(!``#W`P``Y04``*H&``!3!```4@$````````&`P``N0(``$T'```4````
MD0,``*H"``!<!```UP0``#H#```P`P``]````$`$````````W@(``+`&````
M`````````-L%``!A!@``P`,``,H#``#M!```6P0``)0!``"(`P``9P<``(0'
M`````````````!,%``",!@``I`0``#`'``"*`0``0P0``)L````@!@``\@(`
M`'0&`````````````+8$````````$`,``.H&``!@!0```````/L$``"4!@``
MX04``"D&`````````````/<$````````N@(```````"T`0``1`8```````"M
M!@``508``#P%````````00```#8$````````,@(````````!!0```````(X%
M```=`P``IP(`````````````4@,``"8&``#3!0``^@8```````"H`0``8P,`
M`!$$`````````````%,&```G`0``LP4```````#E!@``TP(```````"'!0``
M@P(``+@&``!8`P``@0$```````#N!```)`(``-(&````````-0```+L&``#)
M`@``J0,``%D`````````,0$```````#@!@``L@8```L%``!%`0``6@8``+@$
M```U!@```````%D&````````9````",&``#'`@```````)T```#_````!0$`
M`$`"``")!```:0```-<%```@`0``G@0```````"2`@``%`4````````Z`0``
MSP4````````6`0```````'@%``#'````RP8`````````````7@4``",$``#V
M`P``*@4``.<```#`!```J08``!P&``!*`0``,08````"``!G`P``W@0``#8"
M`````````````/L```"K!@``E08``%$"````````,@8````@*"5S(&1A>7,@
M86=O*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@
M*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``B)7,B(&ES(&YO="!A(&1I
M<F5C=&]R>2X`(B5S(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"(E<R(@:7,@
M;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`B)7,B('1R
M964@<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@
M9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I
M;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R96%T960Z("5S+@`E+C)F34(@
M=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*0`E9"`E<R!A;F0@)7,`
M)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N`"5D+61A>2!F
M;W)E8V%S=``E<R`M($YO=&EC90`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-
M86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E='5P
M`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@
M97AI<W1S+@`E<R!A="`E<R`E<P`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H
M92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K
M('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R
M9F]R;2!A="!T:&ES('1I;64N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`
M)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O
M:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S
M.B`E<P`E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET
M(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R!A;GD@;&EN:W,@
M:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R
M<V]N86P@:6YF;W)M871I;VXN`"P@9W5S=&EN9R``+"!G=7-T:6YG("5S("5S
M`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`,3(@2&]U
M<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`/%!R979I;W5S`$$@
M9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`
M02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I
M<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0
M(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`
M02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)
M344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-
M24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%
M(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T@0VQO
M=61S`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@
M4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N
M+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I
M;&4N`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N="!087-S=V]R9`!!8V-O
M=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($-H:6QD($=R;W5P`$%D
M9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D
M9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`B)7,B`$%D
M9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!9&0@82!N97<@=7-E<CH`
M061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H92`E
M<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T;R!A9&1R97-S(&)O
M;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D960@(B5S
M(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L
M('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D("(E<R(@=&\@=&AE('-Y
M<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@=7-E<G,@:7,@9&ES
M86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@
M<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D
M<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`06QI
M9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P
M<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED97,`06QL;W<@;75L=&EP
M;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y
M<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R
M;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L
M=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`06QT
M97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A`$%N(&EL;&5G86P@=F%L=64@
M=V%S('-P96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"X`
M06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E
M<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`07!P;&EC871I;VX`
M07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@
M=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!<')I
M;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C
M:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE
M('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES
M:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U8BUG<F]U<',_`$%R9V5N=&EN
M80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E
M;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S
M:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O
M<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T96UP="!T;R!D96QE
M=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@
M;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO
M;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM
M97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!
M=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R
M97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA
M<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM
M96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@
M:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD
M87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV
M92!$:7)E8W1O<GD`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S
M+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5
M;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@
M=7!D871E('5S97(@)7,`075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N
M;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ
M(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S;6)A
M=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC
M871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N
M=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC
M871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N('1O
M('1H92!334(@<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE(&9I96QD<SH`07IE
M<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O
M;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N
M86UE+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N
M9VQA9&5S:`!"87)B861O<P!"87-E(&=R87!H:6-S(&1I<F5C=&]R>2`B)7,B
M(&YO="!F;W5N9"X`0F%S96QI;F4`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"
M96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!";&]C:R`B)7,B(&]F(&%P
M<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!";&]C
M:R!4>7!E`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T
M:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H
M`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H
M($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T`0G5L
M9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`
M0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N
M+BX`0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%L
M;0!#86UB;V1I80!#86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U
M=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86X@
M;F]T('=R:71E('1O(&9I;&4@(B5S(@!#86XG="!A9&UI;FES=&5R(&5X=&5R
M;F%L('-E<W-I;VX@:&%N9&QE<G,N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S
M97)V97(Z("5S`$-A;B=T(&]P96X@9FEL92`B)7,B+@!#86YA9&$`0V%N8V5L
M`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S
M(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@
M<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO
M="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H
M:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I
M97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R
M('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU
M;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A<G)I97(`0V%T96=O<FEE<R!A
M;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P
M97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A
M8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#
M96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/
M+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!/=VYE
M<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H86YG90!#:&%N9V4@66]U
M<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P
M96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M
M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D
M('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@($-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H96-?:R!,:6YK+BXN`$-H:6QE`$-H
M:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I
M=&EO;F%L("A":6<U*0!#:&]O<V4@07!P;&EC871I;VXZ`$-H;V]S92!A('!A
M<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA
M>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@
M;&ES=',I`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E
M<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@
M475E<GD`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E
M<B!D871A`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA
M=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D<R!%87)L
M>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4@4VED
M96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!0
M:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O
M;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M
M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T97)S`$-O;F1I=&EO;@!#;VYD:71I
M;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!F
M;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K
M+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@)7,`
M0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@
M4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N
M(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R
M=F5R(&9A:6QE9"X`0V]N=&%C=',`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E;G0@='EP92!O
M9B!C;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O9B`B)7,B`$-O;G1I;G5E
M`$-O;VL@27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y(&9A:6QE9#H@)7,`0V]P
M>2!S96QE8W1I;VX`0V]S="!)1`!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`
M0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4$=0
M('-I9VX@;65S<V%G93H@`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S
M86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T
M(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E
M<BX`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN
M96-T('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V
M97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B``
M0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE
M=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP
M="`B)7,B+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E
M+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E
M<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO
M;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@
M9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`B
M)7,B+@!#;W5L9"!N;W0@;6MD:7(@(B5S(BX`0V]U;&0@;F]T(&]B=&%I;B!P
M=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@
M(B5S(B!F;W(@=W)I=&EN9RX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO
M="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O
M<&5N(&1I<F5C=&]R>2`B)7,B+@!#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@
M<V5R=F5R+@!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H
M92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L
M;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O
M<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T
M:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E
M=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I
M8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@
M8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`
M0V]U;&0@;F]T(')M9&ER("(E<R(N`$-O=6QD(&YO="!S879E("5S(&-O;F9I
M9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO
M;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#
M;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`
M0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V
M92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O
M9&4@8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R
M=F5R+@!#;W5L9"!N;W0@=6YL:6YK("(E<R(N`$-O=6QD(&YO="!U<&1A=&4@
M8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,`0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("(E<R(Z
M("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S
M=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`B
M)7,B('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(Z
M("5S`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T
M92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E<G,`
M0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)O871I
M80!#=6)A`$-U<G)E;G0@-"!0:&%S97,`0W5R<F5N="!397-S:6]N<P!#=7)R
M96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!5<V5R<P!#=7)R96YT
M(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U
M<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U
M="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC
M("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#
M>F5C:"!297!U8FQI8P!$1`!$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T
M+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I
M`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T86)A<V4@3&]O:W5P`$1A=&4`
M1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU
M;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$
M969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT
M(%-H96QL`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@0V5L;`!$96QE=&4@
M1W)O=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD
M('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L
M971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@;65S<V%G
M97,`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S
M:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E
M(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('-U8B!F;VQD
M97)S`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R
M96YT(')O=P!$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$1E
M;&EV97)Y('1I;64`1&5N;6%R:P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C
M<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U
M<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C
M=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@
M=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C
M87-T`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES
M<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(&YO="!D96QE=&4`
M1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&]E<R!T
M:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L
M(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`
M1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+@!$;W=N;&]A9`!$;W=N
M;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!0
M2%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`14UA:6PM
M=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O
M=FED92!T:&ES('-E<G9I8V4N`$524@!%8W5A9&]R`$5D:70`161I="!";&]C
M:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS
M`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D
M:70@<&5R;6ES<VEO;G,@9F]R("(E<R(`161I="!P97)M:7-S:6]N<R!F;W(@
M)7,`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`
M16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C
M:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UA:6PM=&\M4TU3($=A=&5W
M87D`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP
M='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R
M;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C;&EC
M:R!C;VYT97AT(&UE;G4_`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R
M(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@
M:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA
M="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@
M55),(&AE<F4`16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z`$5Q=6%T;W)I86P@
M1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@8W)E871I;F<@8FQO8VLZ("5S
M`$5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<P!%<G)O<B!D96QE=&EN
M9R!S>6YC(&QO9SH@)7,`17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<P!%<G)O
M<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,`17)R;W(@=VET:"!E;6%I;"!M97-S
M86=E+@!%<G)O<B!W<FET:6YG("(E<R(N`$5S=&]N:6$`171H:6]P:6$`171H
M;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%
M=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%
M=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%
M>&5C=71E`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP
M96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T
M:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U
M<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O
M;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--
M0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O
M(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN
M96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86EL960@=&\@<F5T
M<FEE=F4Z("5S`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A
M<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&87AE<P!&96)R=6%R>0!&
M965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO=R!3
M:&]W97)S`$9I96QD(&UA=')I>`!&:6=L970@0T%05$-(00!&:6=L970@9F]N
M=`!&:6II`$9I;&4`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E
M<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N
M`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT
M97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R871I
M;P!&;&EP`$9L;V%T`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N
M="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@
M:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA
M="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@
M;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@
M=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U
M;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O
M<G=A<F1S`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`
M1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R
M;B!497)R:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N
M`$9U;&P@36]O;@!&=6QL($YA;64`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM
M86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R
M871I;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I
M8G)A;'1A<@!':79E;B!.86UE`$=L;V)A;"!/<'1I;VYS`$=O`$=O961E;`!'
M;V]G;&4@36%P<P!';V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E
M96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN
M:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P
M7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60Z(`!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E
M(&=R;W5P("5S`$=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@
M)7,`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`
M1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES
M<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N
M`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T
M(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N
M`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE861E<G,`2&5A
M<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE879Y(%0M4W1O<FT`
M2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@
M961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN
M9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#
M:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE($1I<F5C=&]R>0!(
M;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA
M8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E
M("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B
M:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U
M;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E
M;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N
M9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D
M92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B
M:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B
M.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@
M9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE
M('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO
M=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D
M:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E
M(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@
M;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(
M;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET
M>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O>"!C
M<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL
M960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S
M`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R
M97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W
M;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS
M($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S
M(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T
M;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A
M;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E
M9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E
M;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H
M92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D
M(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM
M86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R
M>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP;W)T
M960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@069T
M97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E
M<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@
M86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E
M87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I80!)
M;F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B
M;&4N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@
M5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!)
M;G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E
M<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T
M(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W
M(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P
M:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B
M969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E('1E;7!L
M871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@
M<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!)
M;G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@
M8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G<F%P
M:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F
M=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS
M=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!)
M;6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I="!T
M;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I96YT
M(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!51$@N("A5
M<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!:25`@9&%T80!);G9A;&ED(&%P
M<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B
M;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@
M9FEL92!F;W)M870`26YV86QI9"!L:6-E;G-E(&ME>2X`26YV86QI9"!L;V-A
M=&EO;B!P<F]V:61E9"X`26YV86QI9"!M<V=?='EP92X`26YV86QI9"!O<B!M
M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N
M`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L:60@<&%R=&YE<B!I
M9"X`26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN=F%L:60@<')O=&]C;VPN`$EN
M=F%L:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN
M=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!)
M;G9E;G1O<GD`26YV97)T('-E;&5C=&EO;@!)<F%N+"!)<VQA;6EC(%)E<'5B
M;&EC(&]F`$ER87$`27)E;&%N9`!)<VQE(&]F($UA;@!)<V]L871E9"!4+5-T
M;W)M<P!)<W)A96P`27-S=65R`$ET86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A
M<GD`2F%P86X`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N
M`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L
M;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@
M;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H
M96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&
M:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@
M86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`
M2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@
M;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A:70`
M2WER9WEZ<W1A;@!,85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO
M8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T(%!A<W-W;W)D($-H86YG
M90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,
M87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I
M80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(`3&5B86YO
M;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE<V]T:&\`3&5V96P`
M3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`
M3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A:6X@16%R;'D`3&EG
M:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET
M:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3:&]W97(`3&EM97)I
M8VL`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@96UA:6P@861D<F5S
M<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,
M:6YU>"!#;V]K:64`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI
M<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES
M="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0
M;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!S
M97-S:6]N<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<P!,
M:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI
M80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C
M871I;VX`3&]G(&EN`$QO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VX`3&]G
M(&]U=`!,;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y
M;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C
M=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G
M<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@
M;G5M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT
M(&-O;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@
M1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`
M36%I;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA
M`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G
M;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R
M<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P
M`$UA<%%U97-T(&UA<`!-87!P:6YG<R!S=&]R960N`$UA<F-H`$UA<F=I;@!-
M87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L
M86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD
M<P!-87)T:6YI<75E`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I
M=&EU<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X
M8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S
M="`V(&AO=7)S.B``36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-
M87AI;75M(&QE;F=T:`!-87D`36%Y;W1T90!-961I8VEN90!-96UB97)S`$UE
M;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF:65D
M(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O
M=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E
M('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE
M+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E
M;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971A<D1"(&ES(&YO
M="!C;VYN96-T960N`$UE=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE
M9`!-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S`$UE=')I
M8P!-97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D
M;&4`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M
M<"!L87-T(#8@:&]U<G,Z(`!-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T
M('EE="!E>'!I<F5D`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!
M4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N
M+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@
M=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES
M<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S
M:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$871E
M`$UO9&EF>2!54DP`36]D=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA
M8V\`36]N9V]L:6$`36]N=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R<F%T
M`$UO;VX@4&AA<V5S`$UO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA
M;B!T:&4@97AP96-T960@)60N`$UO<F]C8V\`36]S=&QY($-L96%R`$UO<W1L
M>2!#;&]U9'D`36]S=&QY($-L;W5D>2!A;F0@5VEN9'D`36]S=&QY(%-U;FYY
M`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@
M9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`375L=&DM;&5V96P@9')O<"!D;W=N
M(&QI<W1S`$UU;'1I;6%P(%5+(&UA<`!-=6QT:7!L92!S96QE8W1I;VX`37D@
M06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY(%!O<G1A;`!->2!0
M;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$YA;64`
M3F%M:6)I80!.875R=0!.97!A;`!.971H97)L86YD<P!.971H97)L86YD<R!!
M;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S8V%P92!#02!2979O8V%T
M:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E(%)E;F5W
M86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE='-C87!E(%-33"!S
M97)V97(@;F%M90!.971S8V%P92!C97)T:69I8V%T92!C;VUM96YT`$YE='-C
M87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@0V%L961O
M;FEA`$YE=R!#871E9V]R>0!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO
M;F%L*0!.97<@6F5A;&%N9`!.97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D('=I
M;&P@97AP:7)E(&]N("5X+@!.97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+@!.
M97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@
M-"!0:&%S97,`3F5X="!O<'1I;VYS`$YE>'0^`$YI8V%R86=U80!.:6=E<@!.
M:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@879A:6QA8FQE(&-O;F9I9W5R871I
M;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE
M('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@8F%T8V@@=&5M
M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET
M:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N
M=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D
M('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!6
M1E,N`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`
M3F\@9FEL92!U<&QO861E9`!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@
M:7,@<V5T+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G92!S=7!P
M;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N
M`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O
M('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN
M87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.
M;R!P96YD:6YG('-I9VYU<',N`$YO('%U;W1A('-E="X`3F\@<G5L97,`3F\@
M<V5P87)A=&]R('-P96-I9FEE9"X`3F\@<VED97,`3F\@<W5C:"!F:6QE`$YO
M('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@
M=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D
M871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R
M:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO
M;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC
M:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD`$YO<G1H
M97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A
M>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T(&EM
M<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&5S`$YO=&AI
M;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W9E;6)E<@!.=6UB97(`3G5M8F5R
M(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O
M=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T
M<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]C=&%L
M`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]L9"!A;F0@;F5W('!A
M<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="X`3VQD('!A<W-W;W)D`$]L9"!P
M87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VUA;@!/;FQY($E-05`@<V5R=F5R
M<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T
M=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE
M(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N
M97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@
M:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R
M86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@
M;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYS
M`$]P=&EO;G,@9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G
M86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T
M:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H97(`
M3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE
M;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!%05(Z.DUA:6P@8F%C:V5N
M9`!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'
M4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O
M9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@4F%I;@!032!3:&]W97)S
M`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U;@!032!4+5-T;W)M<P!0
M3U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!07TA0(%-H96QL`%!A9&1I;F<`
M4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE
M9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@0VQO
M=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+@!0
M87-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E5
M4R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`
M4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A
M<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S
M.@!096]P;&4`4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO
M;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!0
M97)M:7-S:6]N`%!E<FUI<W-I;VX@(B5S(B!N;W0@9&5L971E9"X`4&5R;6ES
M<VEO;B!$96YI960`4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R
M871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0971S`%!H:6QI<'!I
M;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E<P!0
M;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA
M="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N
M9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L
M96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A
M(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A
M;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H
M96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E
M;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O
M9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A
M;F0@<&%S<W=O<F0`4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9
M;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E
M;2X`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`
M4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I
M;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F
M;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O
M<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E
M`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N
M9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0
M<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@
M=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T
M92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R
M;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B
M;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R
M871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%!U<F=E(&UE<W-A9V5S
M`%%A=&%R`%%U97)Y`%%U;W1A`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A
M9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@
M4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T
M=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M
M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N
M;F]T(&)E('5N9&]N92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S
M:`!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T
M86P@5FEE=SH`4F5G97@`4F5L871I;VYS:&EP($)R;W=S97(`4F5L;V%D`%)E
M;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE
M>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E
M(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@
M<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R
M>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M
M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297%U97-T(&-O=6QD
M;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U97-T
M960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N`%)E<75I<F5D("(E<R(@
M;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B
M)7,B(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I
M<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U
M:7)E9"!&:65L9`!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A
M<W-W;W)D`%)E<W1O<F4@3&%S="!1=65R>0!297-U;'1S`%)E='5R;B!T;R!/
M<'1I;VYS`%)E='EP92!N97<@<&%S<W=O<F0`4F5U;FEO;@!2979E<G0@0V]N
M9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2
M:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE
M<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A
M=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`
M4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@
M8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL
M>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S
M<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3
M:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N
M=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@
M4VAE;&P`4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<P!34T@`4U5#
M0T534P!37U%,(%-H96QL`%-A`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A
M;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO
M;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE
M("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I
M<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I($%R86)I80!3879E`%-A=F4@
M(B5S(@!3879E("5S`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E
M;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A
M=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!38V%T=&5R960@
M5"U3=&]R;7,`4V-I96YC90!396%R8V@`4V5A<F-H($5N9VEN97,`4V5L96-T
M($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E
M;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E
M<B!T;R!A9&0`4V5L96-T(&%L;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT
M<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@;F]N90!396QE8W0@=&AE(&-H
M87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C
M86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E
M82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E
M(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N
M9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM
M92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@
M>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG
M=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YE9V%L`%-E
M;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L
M($YU;6)E<@!397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+@!3
M97-S:6]N($%D;6EN`%-E<W-I;VX@240@97AP:7)E9"X`4V5S<VEO;G,`4V5T
M`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W
M;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V
M97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN
M`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A
M=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L
M;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y
M(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B
M;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE
M=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L
M9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W
M`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD
M('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T
M(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K
M965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N
M<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO
M=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!4
M86)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O
M<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L
M;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@
M3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3:')I;FL`4VAR:6YK(&]R
M(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I
M<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I9VYA='5R90!3:6=N871U<F4@
M06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO
M=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`
M4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P
M=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N
M9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@<V5L96-T:6]N
M`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H
M25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W
M:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N
M(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R
M9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN
M9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E
M;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T
M86YD87)D`%-T87(@5')E:P!3=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E
M`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T
M:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R
M97-S`%-T>6QE(%M#4U-=`%-U`%-U8F1I<F5C=&]R>2`B)7,B(&YO="!F;W5N
M9"X`4W5B:F5C=`!3=6)M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@861D("(E
M<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U
M<B!R97%U97-T(&AA<R!B965N(&%P<')O=F5D+@!3=6)S8W)I<'0`4W5C8V5S
M<P!3=6-C97-S9G5L;'D@861D960@(B5S(B!T;R!T:&4@<WES=&5M+@!3=6-C
M97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@
M<WES=&5M+@!3=6-C97-S9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L
M;'D@<F5M;W9E9"`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY
M(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E
M<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3
M=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I
M;&4@)7,N`%-U8V-E<W-F=6QL>2!U<&1A=&5D("(E<R(`4W5C8V5S<V9U;&QY
M('=R;W1E("5S`%-U9&%N`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN
M>0!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N
M<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V
M86QB87)D(&%N9"!*86X@36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R
M;&%N9`!3>6YC(&QO9R!D96QE=&5D`%-Y;F--3`!3>6YT87@@97)R;W(@:6X@
M<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3
M=&]R;2!A;F0@5VEN9'D`5"U3=&]R;7,`5"U3=&]R;7,@16%R;'D`5%-6(&9I
M;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!3970`5&%B;&4@<')O<&5R=&EE
M<P!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N
M`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K<P!4
M96QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T
M=7)E`%1E;7!E<F%T=7)E.B``5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S
M3&\E<RD@)F1E9SLE<P!496UP;&%T92`B)7,B(&YO="!F;W5N9"X`5&5M<&QA
M=&4@061M:6YI<W1R871I;VX`5&5X=`!497AT($]N;'D`5&5X="!A;&EG;@!4
M97AT=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H86EL86YD`%1H92!&5%`@97AT
M96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(:7-T;W)Y('-Y<W1E;2!I
M<R!D:7-A8FQE9"X`5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN
M92!D;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE($E-4U`@;&]G(&-O=6QD(&YO
M="!B92!I;FET:6%L:7IE9"X`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED
M(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S
M(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@
M8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@
M>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4:&4@8F]T=&]M('-I9&4@
M;VYL>0!4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L
M(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N
M`%1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A
M9&1R97-S(&)O;VLN`%1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K
M(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N`%1H
M92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I
M960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`
M5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+@!4:&4@
M96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN
M96-T:6]N+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I
M;F<N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN
M9W,N`%1H92!F:6QE(&-A;FYO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H
M92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T
M:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4
M:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M
M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S
M('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG
M:'0@97AP97)I96YC92!G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R
M(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF
M('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T
M:&%T('EO=2=L;"!G970@82`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A
M;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@
M4&QE87-E('!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@
M9G5L;"!S8W)E96X@961I=&]R+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E
M;B!D96QE=&5D+@!4:&4@;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I
M;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#
M<GEP=%]P9W`Z.B!C;&%S<RX`5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E
M<R!W:71H('-U8FIE8W0@(B5S(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@
M:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A
M9"!O<B!U;F1E<G-T;V]D+@!4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG
M('1O('1H92!C;VUP;W-E('!A9V4`5&AE(&YU;6)E<B!O9B!F:65L9',@;75S
M="!B92!N=6UE<FEC+@!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@
M9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R
M96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A
M(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G
M<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@
M9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T
M(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<FEG:'0@86YD(&QE9G0@
M<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E<&%R
M871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<V5R=F5R
M("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B
M965N('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N
M(')E;6]V960N`%1H92!S<&5C:69I960@<F]W("@E9"D@9&]E<R!N;W0@97AI
M<W0N`%1H92!T96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4
M:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N
M('1H92!S8W)E96XN`%1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H
M92!T;W`@<VED92!O;FQY`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I
M;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L
M9"!N;W0@8F4@<V%V960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@
M879A:6QA8FQE+@!4:&5M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4
M:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P
M87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@
M=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E
M;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA
M;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@
M<WES=&5M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@
M9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P
M<F]B;&5M(')E;6]V:6YG("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@
M=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`B)7,B.B`E<P!4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D
M960N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S
M:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@
M9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D
M960N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G
M92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A
M8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A
M;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG
M=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D
M(&9I96QD+@!4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E
M8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I
M;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT
M86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A
M<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N
M;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P
M96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@
M87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@
M<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T
M96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H
M92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E
M=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P
M.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)
M`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!3
M3510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@
M=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C
M;W5N="!W:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN
M`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&YU;6)E<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C
M;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M
M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F
M:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@
M8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F
M;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B
M965N('!R;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R
M;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@
M;F5E9"!A;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L
M86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL
M(&-L:65N=',@<&QE87-E('9I<VET("5S`%1H:7,@;65S<V%G92!W87,@=W)I
M='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@
M;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S
M97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H
M:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU
M92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE
M9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE
M`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM
M;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@
M;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R
M($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G
M;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O
M;R!M86YY(&EN=F%L:60@;&]G:6YS(&1U<FEN9R!T:&4@;&%S="!M:6YU=&5S
M+@!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`5')I;FED860@
M86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U
M<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I
M8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN
M9&5X.B``55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S
M(')E<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@
M5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R
M;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M
M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E
M('1O("5S+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R(N`%5N
M86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S+R5S(BX`56YA8FQE('1O
M(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET
M:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E
M871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@8W)E871E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&-R96%T92!E
M;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA
M8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T
M92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@
M9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY
M.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@
M=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@
M5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E
M+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I
M+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL
M960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O(')E860@=&AE
M('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S
M.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B
M;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A
M=&$N`%5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E
M>&-E961E9"X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L
M87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N
M(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R
M('1O.B``56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@16UI
M<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A
M=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN
M;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G
M:60@*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W;B!L;V-A=&EO;B!P<F]V
M:61E9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H
M92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T
M<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL
M>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E
M8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H
M;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N
M`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D
M871E("5S`%5P9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!G<F%D92!S8W)I
M<'0@9&5L971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S
M971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S
M`%5P<&5R(')O;6%N(&YU;6)E<G,`57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`
M57-E(%-33`!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R
M($E-4U`@<V5R=F5R+@!5<V5R`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@
M9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R
M(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A
M8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S
M97)N86UE`%5S97)N86UE("(E<R(@86QR96%D>2!E>&ES=',N`%5S97)N86UE
M.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`
M5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@
M;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M
M:6YU=&5S(&9R;VT@;F]W+@!686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE
M;F=T:"!O9B`E<RX`5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU
M871U`%9A<FEA8FQE`%9E;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D("T@
M=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R
M<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@
M<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I971N86UE
M<V4@*%9)4T-)22D`5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E
M`%9I97<@87,@)7,`5FER9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES
M;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@
M271A;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@
M34%.54%,3%D@1E)/32`E<RX`5TE.('9I82!(5%10`%=A;&QI<R!A;F0@1G5T
M=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@
M<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3:71E`%=E96ML>0!7
M96QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/
M+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A
M`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G
M:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@
M=&AE('%U;W1E(&-H87)A8W1E<C\`5VAE<F5I<R!!=7-T<F%L:6$@;6%P`%=H
M:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I
M8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T
M:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N
M(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`
M5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO
M=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D
M<F5S<P!7;W)K(%!H;VYE`%=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN
M92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!N=6UB97(@;V8@
M9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&]F9G-E="`E
M9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N`%@M4F5F`%@U,#EV,R!"87-I
M8R!#;VYS=')A:6YT<P!8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV
M,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y
M($ED96YT:69I97(`6#4P.78S(&5X=&5N<VEO;G,`65D`65E960!986AO;R$@
M;6%P`%EE87)L>0!996UE;@!997,`665S+"!)($%G<F5E`%EO=2!A<F4@:6X@
M5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C
M:R!T;R!765-)5UE'+@!9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M
M;W)E('1H86X@)60@8FQO8VMS+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D
M+@!9;W4@8V%N;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F
M=6QL(&YA;64N`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D
M<F5S<RX`66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O
M<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`
M66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A
M('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@
M;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R
M969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU
M<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P
M<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T
M(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE
M('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E
M('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E
M<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@
M=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@
M<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N
M`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U
M(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S
M="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO=2!N965D('1O('!R;W9I
M9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(`66]U<B`E<R!S97-S:6]N(&AA
M<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D
M<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U
M<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I
M;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C
M=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A
M=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG
M('5S97)S+B!)9B!Y;W4@=VES:"!T;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E
M<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@875T
M:&5N=&EC871I;VX@8F%C:V5N9"X`66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E
M871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N
M+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@
M=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@
M>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O
M=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!B<F]W
M<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S
M($-O;G1R;VPO0V]M;6%N9"`K(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T
M:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N
M9V5D+@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9
M;W5R(&QO9VEN(&AA<R!E>'!I<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@
M)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@
M=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA
M=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T
M`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA
M:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A
M<W-W;W)D(&AA<R!E>'!I<F5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O
M<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W90!::7!P>0!;2&ED92!1=6]T
M960@5&5X=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M
M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S
M70!?061M:6YI<W1R871I;VX`7T-,20!?1&%T851R964`7T1E;&5T92!2;W<`
M7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?3&]G(&EN`%],
M;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`
M7U)E;6]V92!,:6YK+BXN`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?
M57-E<G,`861D<F5S<R!B;V]K`&%D9')E<W-E92!U;FMN;W=N`&-A;&5N9&%R
M`&-A;&T`8V%N;F]T(&-R96%T92!O=71P=70@9FEL90!C86YN;W0@;W!E;B!I
M;G!U=`!C;&EC:R!H97)E`&-O;6UA;F0@;&EN92!U<V%G92!E<G)O<@!C;VYF
M:6=U<F%T:6]N(&5R<F]R`&-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<`
M9&%T82!F;W)M870@97)R;W(`961I=`!E;G1R>2!N;W0@9F]U;F0`9F%L;&EN
M9P!F:6QE`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`9W5S=&EN9P!H.@!H
M:`!H;W-T(&YA;64@=6YK;F]W;@!I;6UE9&EA=&4`:6YL:6YE`&EN<'5T+V]U
M='!U="!E<G)O<@!I;G1E<FYA;"!S;V9T=V%R92!E<G)O<@!L:6YE<UT`;6MI
M<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N`&UM`&YA;64`
M;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!P
M97)C96YT`'!E<FUI<W-I;VX@9&5N:65D`'!I>&5L<P!R96UO=&4@97)R;W(@
M:6X@<')O=&]C;VP`<FES:6YG`'-E<G9I8V4@=6YA=F%I;&%B;&4`<VAO=R!D
M:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W,`<W1E861Y`'-Y<W1E
M;2!E<G)O<@!T87-K(&QI<W0`=&5M<&]R87)Y(&9A:6QU<F4`='EP92!T:&4@
M<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E
M<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S
M:6]N.B!F<E]&4@I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO
M<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,RTP-B`Q,CHT-RLP
M,3`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#,M,S$@,C(Z,S`K,#(P,`I,
M87-T+51R86YS;&%T;W(Z(%1H:65R<GD@5&AO;6%S(#QT:&EE<G)Y0'!O;7!O
M+FYE=#X*3&%N9W5A9V4M5&5A;3H@1G)E;F-H(#QI,3AN0&QI<W1S+FAO<F1E
M+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L
M86EN.R!C:&%R<V5T/4E33RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O
M9&EN9SH@.&)I=`I0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3([('!L=7)A;#TH
M;B`^(#$I.PH`("AI;"!Y(&$@)7,@:F]U<G,I`"`H5&]U8VAE(&0G86-CZ',@
M<F%P:61E("5S*0`@*&1A;G,@)7,@:F]U<G,I`"`H875J;W5R9"=H=6DI`"`H
M9&5M86EN*0`@*&AI97(I`"#@(`"KH"5SH+L@;B=E<W0@<&%S('5N(&1O<W-I
M97(`JZ`E<Z"[(&XG97-T('!A<R!U;B!C:&]I>"!V86QI9&4N`*N@)7.@NR!N
M)V5S="!P87,@8V]N9FEG=7+I(&1A;G,@;&4@<F5G:7-T<F4@9&4@2&]R9&4N
M`$PG:6YT97)P<NET975R(&0G87)B<F4@JZ`E<Z"[(&XG82!P87,@Z73I('1R
M;W5VZ2X`JZ`E<Z"[(&$@Z73I(&%J;W5TZ2!A=2!S>7-TZ&UE(&1E<R!G<F]U
M<&5S+@"KH"5SH+L@82#I=.D@86IO=73I(&%U('-Y<W3H;64@9&5S('!E<FUI
M<W-I;VYS+@"KH"5SH+L@;B=A('!A<R#I=.D@8W+IZ:`Z("5S+@`E+C)FH$UO
M('5T:6QI<^ES('-U<B`E+C)FH$UO('!E<FUI<R`H)2XR9J`E)2D`)60@)7,@
M970@)7,`)60@:F]U<G,@879A;G0@;"=E>'!I<F%T:6]N(&1E('9O=')E(&UO
M="!D92!P87-S92X`)60M<'+I=FES:6]N(&1U(&IO=7(`)7,@+2!.;W1I8V4`
M16UP<F5I;G1E(%!'4"!D92`E<P`E<Z!+;P`E<R!O<.ER871I;VYS(&1E(&UA
M:6YT96YA;F-E("9N9&%S:#L@0V]N9FER;6%T:6]N`$-O;F9I9W5R871I;VX@
M)7,`26YS8W)I<'1I;VX@9&4@)7,`0V]N9&ET:6]N<R!D)W5T:6QI<V%T:6]N
M(&1E("5S`"5S(&5X:7-T92!DZ6K@+@`@)7.@X"`E<R`E<P`E<R!E<W0@<'+J
M="#@(&5F9F5C='5E<B!L97,@;W#I<F%T:6]N<R!D92!M86EN=&5N86YC92!C
M;V-HZ65S(&-I+61E<W-O=7,N(%/I;&5C=&EO;FYE>B!L82!O=2!L97,@;W#I
M<F%T:6]N*',I('%U92!V;W5S('9O=6QE>B!E9F9E8W1U97(@8V5T=&4@9F]I
M<RUC:2X`)7,@97-T(&]B;&EG871O:7)E`"5S(&UI;G5T97,`)7,@;F]N('1R
M;W5VZ0`E<Z#@("5S(&1E("5S`$-A<FYE="!D)V%D<F5S<V5S(&1E("5S`$%G
M96YD82!D92`E<P!";&]C+6YO=&5S(&1E("5S`$QI<W1E(&1E('3B8VAE<R!D
M92`E<P`E<Z`Z("5S`"5SH#H@;"?I;65T=&5U<B!D92!C92!M97-S86=E(&$@
M<'4@ZG1R92!F86QS:69IZ2X@071T96YT:6]N(&5N('-U:79A;G0@;&5S(&QI
M96YS('%U)VEL(&-O;G1I96YT(&]U(&5N(&9O=7)N:7-S86YT(&1E<R!I;F9O
M<FUA=&EO;G,@<&5R<V]N;F5L;&5S(.`@;"?I;65T=&5U<BX`+"!E;B!R869A
M;&4@`')A9F%L92`E<R`E<P!V87)I86)L92!D=2`E<R!A=2`E<P`M+2!3Z6QE
M8W1I;VYN97(@+2T`1F]R;6%T(#$R(&AE=7)E<P!&;W)M870@,C0@:&5U<F5S
M`#(T(&AE=7)E<P`\4'+I8^ED96YT`%5N92!B87-E(&1E(&1O;F[I97,@<')I
M;F-I<&%L92`H8F%C:V5N9"D@97-T(&[I8V5S<V%I<F4@<&]U<B!C92!B;&]C
M`%5N92!E<G)E=7(@9F%T86QE(',G97-T('!R;V1U:71E`%5N92!C;&5F('!U
M8FQI<75E(%!'4"!E<W0@;NEC97-S86ER92!P;W5R(&-H:69F<F5R('5N(&UE
M<W-A9V4N`%5N92!C;&5F('!U8FQI<75E(%!'4"!E<W0@;NEC97-S86ER92!P
M;W5R(';I<FEF:65R(&QA('-I9VYA='5R92!D)W5N(&UE<W-A9V4N`%5N92!C
M;&5F('!U8FQI<75E(%!'4"P@=6YE(&-L968@<')I=NEE(%!'4"P@970@=6YE
M('!H<F%S92!S96-RZ'1E('-O;G0@;NEC97-S86ER97,@<&]U<B!DZ6-H:69F
M<F5R('5N(&UE<W-A9V4N`%5N92!C;&5F('!U8FQI<75E(%!'4"P@=6YE(&-L
M968@<')I=NEE(%!'4"P@970@=6YE('!H<F%S92!S96-RZ'1E('-O;G0@;NEC
M97-S86ER97,@<&]U<B!S:6=N97(@=6X@;65S<V%G92X`56YE(&-L968@<'5B
M;&EQ=64@4R]-24U%+"!U;F4@8VQE9B!P<FEVZ64@4R]-24U%+"!E="!U;F4@
M<&AR87-E('-E8W+H=&4@<V]N="!NZ6-E<W-A:7)E<R!P;W5R(&3I8VAI9F9R
M97(@=6X@;65S<V%G92X`56YE(&-L968@<'5B;&EQ=64@4R]-24U%+"!U;F4@
M8VQE9B!P<FEVZ64@4R]-24U%+"!E="!U;F4@<&AR87-E('-E8W+H=&4@<V]N
M="!NZ6-E<W-A:7)E<R!P;W5R('-I9VYE<B!U;B!M97-S86=E+@!5;F4@8VQE
M9B!P=6)L:7%U92!3+TU)344@97-T(&[I8V5S<V%I<F4@<&]U<B!C:&EF9G)E
M<B!U;B!M97-S86=E+@!.=6%G97,@;&4@;6%T:6X`4&QU:64@;.EGZ')E(&QE
M(&UA=&EN`%!L=6EE(&QE(&UA=&EN`$%V97)S97,@;&4@;6%T:6X`0VAU=&5S
M(&1E(&YE:6=E(&QE(&UA=&EN`$%-+U!-`$%022!)1`#`('!R;W!O<R!D92!C
M970@Z61I=&5U<@#`('!R;W!O<RXN+@!"87,@86)S;VQU`$UI;&EE=2!A8G-O
M;'4`06-CZ',@<F5F=7/I(&QO<G,@9&4@;&$@8W+I871I;VX@9&4@<NEP97)T
M;VER92!61E,@+@!!8V/H<R!R969U<^D@;&]R<R!D92!L82!C<NEA=&EO;B!D
M92!F:6-H:65R(%9&4RX`1&]N;NEE<R!P97)S;VYN96QL97,`36]T(&1E('!A
M<W-E(&1U(&-O;7!T90!#;VUP=&4@:6YA8W1I9@!#;VUP=&5S`$%J;W5T97(`
M06IO=71E<B!U;B!S;W5S+6=R;W5P90!!:F]U=&5R('5N92!N;W5V96QL92!S
M;W5S+7!E<FUI<W-I;VX`06IO=71E<B!I8VF@.@!!:F]U=&5R('5N(&YO=79E
M874@9W)O=7!E`$%J;W5T97(@=6YE(&YO=79E;&QE('!E<FUI<W-I;VX`06IO
M=71E<B!U;B!G<F]U<&4@9FEL<R#@(*N@)7.@NP!!:F]U=&5R('5N92!P97)M
M:7-S:6]N(&9I;&QE(.`@JZ`E<Z"[`$%J;W5T97(@=6X@;F]U=F5L('5T:6QI
M<V%T975RH#H`06IO=71E<B!U;F4@8V]L;VYN90!!:F]U=&5R(&1E(&YO=79E
M875X(&UE;6)R97,`06IO=71E<B!U;F4@<&%I<F4`06IO=71E<B!L92!M96YU
M("5S(.`@;&$@8F%R<F4@9&4@36]Z:6QL80!!:F]U=&5R(&%U(&-A<FYE="!D
M)V%D<F5S<V5SH#H`06IO=71E<B#@(&UO;B!C87)N970@9"=A9')E<W-E<P!!
M:F]U=&5R('5N('5T:6QI<V%T975R`*N@)7.@NR!A(.ETZ2!A:F]U=.D@874@
M<WES=.AM92P@;6%I<R!L)V%J;W5T(&0G:6YF;W)M871I;VX@<W5P<&SI;65N
M=&%I<F5S("5S(&XG97-T('!A<R!P;W-S:6)L92X`JZ`E<Z"[(&$@Z73I(&%J
M;W5TZ2X@5F]U<R!P;W5V97H@=F]U<R!C;VYN96-T97(N`$QA(&9O;F-T:6]N
M(&0G86IO=70@9"=U=&EL:7-A=&5U<G,@97-T(&3I<V%C=&EVZ64N`$%D<F5S
M<V4`0V%R;F5T(&0G861R97-S97,`061M:6YI<W1R871E=7(@+2!A:G5S=&5R
M(&QE<R!P97)M:7-S:6]N<R!P;W5R(&0G875T<F5S('5T:6QI<V%T975R<P!!
M9&UI;FES=')A=&EO;@!0=6)S`$%F9VAA;FES=&%N`$%L8F%N:64`06QGZ7)I
M90!!;&EA<P!!;&EG;F5R`$%L:6=N96UE;G2@.@!4;W5T`%1O=7,@;&5S('!A
M<G1I8VEP86YT<R!A=71H96YT:69IZ7,`5&]U<R!L97,@9W)O=7!E<P!4;W5T
M97,@;&5S('!E<FUI<W-I;VYS`$QE<R!Q=6%T<F4@8_1TZ7,`4&5R;65T=')E
M(&1E<R!A9')E<W-E<R!D92!C;W5R<FEE;"!M=6QT:7!L97,`075T;W)I<V5R
M(&QA(&UI<V4@96X@<&QA8V4@9&4@;&ES=&5S(&YU;>ER;W3I97.@/P!%>&ES
M=&4@9.EJX`!.;VT@9"=U=&EL:7-A=&5U<B!)35-0(&%L=&5R;F%T:68`36]T
M(&1E('!A<W-E($E-4U`@86QT97)N871I9@!.;VT@9"=U=&EL:7-A=&5U<B!)
M35-0(&%L=&5R;F%T:68`061R97-S92!D92!C;W5R<FEE;"!A;'1E<FYA=&EV
M90!!=71R97,@;6]DZ&QE<P!497AT92!A;'1E<FYA=&EFH#H`4V%M;V$@06WI
M<FEC86EN`%5N92!V86QE=7(@:6QLZ6=A;&4@82#I=.D@<W#I8VEF:>EE+@!5
M;F4@97)R975R(&EN8V]N;G5E(',G97-T('!R;V1U:71E+@!!;F1O<G)E`$%N
M9V]L80!!;F=U:6QL80!0<F]X>2!A;F]N>6UE`%+I<&]N<V4`06YT87)C=&EQ
M=64`06YT:6=U82UE="U"87)B=61A`$%P<&QI8V%T:6]N`$QI<W1E(&0G87!P
M;&EC871I;VYS`$PG87!P;&EC871I;VX@97-T('!RZG1E`$%P<&QI<75E<B!A
M=7@@<&%R=&%G97,@9FEL<P!!<'!R;W5VZ0!486EL;&4@87!P<F]X:6UA=&EV
M90!!=G)I;`!!<F%B92`H5VEN9&]W<RTQ,C4V*0!486EL;&4@9'4@9FEC:&EE
M<B!A<F-H:79E`$YO;2!D92!L)V%R8VAI=F4`RG1E<RUV;W5S(&-E<G1A:6X@
M9&4@=F]U;&]I<B!S=7!P<FEM97(@8V5T=&4@<F5Q=>IT92!D)VEN<V-R:7!T
M:6]N("!P;W5R("5SH#\`RG1E<RUV;W5S(&-E<G1A:6X@9&4@=F]U;&]I<B!E
M9F9A8V5R(*N@)7.@NR!E="!S97,@<V]U<RUG<F]U<&5SH#\`07)G96YT:6YE
M`$%R;>EN:64`07)MZ6YI96X@*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N
M<VEO;B`HSFQE*0!!<G0@05-#24D`4NEG:6]N($%S:64O4&%C:69I<75E`$1E
M;6%N9&5R('5N92!C;VYF:7)M871I;VX@879A;G0@9&4@;&%N8V5R(&QE<R!O
M<.ER871I;VYS(&1E(&UA:6YT96YA;F-EH#\`0V]L;VYN97,@9&5S('3B8VAE
M<P!496YT871I=F4@9"=E9F9A8V5M96YT(&0G=6X@9W)O=7!E(&EN97AI<W1A
M;G0N`%1E;G1A=&EV92`@9"=E9F9A8V5M96YT(&0G=6YE('!E<FUI<W-I;VX@
M:6YE>&ES=&%N=&4N`%1E;G1A=&EV92!D92!M;V1I9FEC871I;VX@9"=U;F4@
M<&5R;6ES<VEO;B!I;F5X:7-T86YT92X`5&5N=&%T:79E(&1E(&UO9&EF:6-A
M=&EO;B!D)W5N('!A<G1A9V4@:6YE>&ES=&%N="X`4')O<')IZ73I<P!!;_MT
M`$%U<W1R86QI90!!=71R:6-H90!!=71H7V-Y<G5SH#H@17AT96YS:6]N(')E
M<75I<V4@24U!4"!N;VX@=')O=7;I92X`075T:%]C>7)U<Z`Z(&QE(&)A8VME
M;F0@;B=A('!A<R!L97,@8V%P86-I=.ES(')E<75I<V5S+@!!=71H7V-Y<G5S
MH#H@97AT96YS:6]N(')E<75I<V4@24U!4"!N;VX@=')O=7;I90!!=71H7V9T
M<*`Z(&5X=&5N<VEO;B!R97%U:7-E($944"!N;VX@=')O=7;I92X@26P@9F%U
M="!C;VUP:6QE<B!02%`@879E8R!L)V]P=&EO;B`M+65N86)L92UF='`N`$%U
M=&A?:6UA<*`Z(&5X=&5N<VEO;B!R97%U:7-E($E-05`@;F]N('1R;W5VZ64N
M`$%U=&A?:W)B-:`Z(&5X=&5N<VEO;B!R97%U:7-E(&MR8C4@;F]N('1R;W5V
MZ64N`$%U=&A?;&1A<*`Z(&PG86IO=70@9"=U=&EL:7-A=&5U<G,@;B=E<W0@
M<&%S('-U<'!O<G3I(&%V96,@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87"@
M.B!L92!R971R86ET(&0G=71I;&ES871E=7)S(&XG97-T('!A<R!S=7!P;W)T
MZ2!A=F5C($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%PH#H@97AT96YS:6]N
M(')E<75I<V4@3$1!4"!N;VX@=')O=7;I92X`075T:%]L9&%PH#H@:6UP;W-S
M:6)L92!D)V%J;W5T97(@;"=U=&EL:7-A=&5U<B`E<RX@0V5C:2!E<W0@;&$@
M<NEP;VYS92!D=2!S97)V975RH#H@`$%U=&A?;&1A<*`Z(&EM<&]S<VEB;&4@
M9&4@<W5P<')I;65R(&PG=71I;&ES871E=7(@)7,`075T:%]L9&%PH#H@;6]D
M:69I8V%T:6]N(&EM<&]S<VEB;&4@9&4@;"=U=&EL:7-A=&5U<B`E<P!!=71H
M7VQD87"@.B!L82!M;V1I9FEC871I;VX@9&5S('5T:6QI<V%T975R<R!N)V5S
M="!P87,@<W5P<&]R=.EE(&%V96,@06-T:79E($1I<F5C=&]R>2X`075T:%]M
M8V%LH#H@97AT96YS:6]N(')E<75I<V4@34-!3"!N;VX@=')O=7;I92X`075T
M:%]S;6)A=71HH#H@97AT96YS:6]N(')E<75I<V4@<VUB875T:"!N;VX@=')O
M=7;I92X`R6-H96,@9&4@;"=A=71H96YT:69I8V%T:6]N(&%U('-E<G9E=7(@
M24U!4"X`R6-H96,@9&4@;"=A=71H96YT:69I8V%T:6]N`,EC:&5C(&1E(&PG
M875T:&5N=&EF:6-A=&EO;B`E<P!,92!S97)V975R(%)!1$E54R!A(')E:F5T
MZ2!L)V%U=&AE;G1I9FEC871I;VXN`,EC:&5C(&1E(&PG875T:&5N=&EF:6-A
M=&EO;B!A=2!S97)V975R($944"X`R6-H96,@9&4@;"=A=71H96YT:69I8V%T
M:6]N(&%U('-E<G9E=7(@4TU"+@!#:&%M<',@9&ES<&]N:6)L97.@.@!!>F5R
M8F'O9&IA;@!%>&-U<V5S($)/1D@`0V]U;&5U<B!D92!F;VYD`$-O=6QE=7(@
M9&4@9F]N9`!-;W0@9&4@<&%S<V4@2V5R8F5R;W,@97)R;V[I+@!.;VT@9&4@
M8V]N;F5X:6]N($ME<F)E<F]S(&5R<F]NZ2X`0F%H86UA<P!"86AR9>]N`$)A
M;'1E("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861E`%+I<&5R=&]I
M<F4@9&5S(&=R87!H:7%U97,@JZ`E<Z"[(&YO;B!T<F]U=NDN`$QI9VYE(&1E
M(&)A<V4`0NEL87)U<P!"96QG:7%U90!"96QI>F4`0NEN:6X`0F5R;75D97,`
M0FAO=71A;@!!;FYI=F5R<V%I<F4`0FQO8R"K)7,@NR!D92!L)V%P<&QI8V%T
M:6]N(*N@)7.@NR!I;F-O;FYU`%!RZ6;I<F5N8V5S(&1E(&)L;V,`5'EP92!D
M92!B;&]C`$=R87,`0F]L:79I90!3:6=N971S`$)O<F1U<F4`R7!A:7-S975R
M(&1E(&QA(&)O<F1U<F6@.@!";W)D<P!";W-N:64M2&5R>NEG;W9I;F4`3&5S
M(&1E=7@`0F]T<W=A;F$`0F%S`$)O=79E=`!"<NES:6P`5&5R<FET;VER97,@
M8G)I=&%N;FEQ=65S(&1E(&PG3V/I86X@26YD:65N`%-U;'1A;F%T(&1U($)R
M=6[I:0!"=6QG87)I90!,:7-T92#@('!U8V5S`$)U<FMI;F$@1F%S;P!"=7)U
M;F1I`$=E<W1I;VX@9&4@8V]N=&5N=0!#4D,`1&ES=')I8G5T:6]N(&1E<R!P
M;VEN=',@3%)#("A,:7-T92!D92!RZ79O8V%T:6]N(&1E<R!C97)T:69I8V%T
M<RD`4')O<')IZ73I<R!D92!L82!#7V5L;'5L90!,)VEN:71I86QI<V%T:6]N
M(&1U(&-A8VAE(&YE(',G97-T('!A<R!T97)M:6[I92X`06=E;F1A`$-A;&UE
M`$-A;6)O9&=E`$-A;65R;W5N`$EM<&]S<VEB;&4@9&4@<NEI;FET:6%L:7-E
M<B!L92!M;W0@9&4@<&%S<V4@875T;VUA=&EQ=65M96YT+"!C;VYT86-T97H@
M=F]T<F4@861M:6YI<W1R871E=7(@<WES=.AM92X`26UP;W-S:6)L92!D92!S
M=7!P<FEM97(@;&4@9FEC:&EE<B"KH"5SH+LN`$EM<&]S<VEB;&4@9"=A9&UI
M;FES=')E<B!D97,@9V5S=&EO;FYA:7)E<R!D92!S97-S:6]N(&5X=&5R;F5S
M+@#)8VAE8R!D92!L82!C;VYN97AI;VX@874@<V5R=F5U<B!)34%0H#H@)7,`
M26UP;W-S:6)L92!D)V]U=G)I<B!L92!F:6-H:65R(*N@)7.@NRX`0V%N861A
M`$%N;G5L97(`06YN=6QE<B!L92!R87!P;W)T(&1U('!R;V)LZ&UE`$EM<&]S
M<VEB;&4@9&4@<W5P<')I;65R(&QE(&9I8VAI97(@JZ`E<Z"[+@!);7!O<W-I
M8FQE(&1E('1R;W5V97(@=6X@<NEP97)T;VER92!T96UP;W)A:7)E`$EM<&]S
M<VEB;&4@9&4@<')O8^ED97(@<V%N<R!L92!P87)A;>AT<F4@JR!T87)G971&
M:6QE(+L`26UP;W-S:6)L92!D92!S=7!P<FEM97(@;&4@<NEP97)T;VER92"K
MH"5SH+LN`%-U<'!R97-S:6]N(&EM<&]S<VEB;&4L(&EL('D@82`E9"!E;G)E
M9VES=')E;65N=',@9FEL<RX`26UP;W-S:6)L92!D92!RZ6]R9&]N;F5R+"!L
M92!N;VUB<F4@9"?I;.EM96YT<R#@('+I;W)D;VYN97(@;F4@8V]R<F5S<&]N
M9"!P87,@874@;F]M8G)E(&0GZ6SI;65N=',@96YR96=I<W1RZ7,N`$YE('!E
M=70@9&ER:6=E<B!L92!M97-S86=E('9E<G,@;&4@;F]M8G)E('-PZ6-I9FGI
M+@!#87`M5F5R=`!,Z6=E;F1E`%1R86YS<&]R=&5U<@!#873I9V]R:65S(&5T
M(,ET:7%U971T97,`SFQE<R!#8>]M86X`5.ELZ7!H;VYE(&-E;&QU;&%I<F4`
M4')O<')IZ73I<R!D92!L82!C96QL=6QE`%)E;7!L:7-S86=E(&%U=&]U<B!D
M92!L82!C96QL=6QEH#H`4')O<')IZ73I<R!D92!L82!C96QL=6QE`$5S<&%C
M96UE;G0@9&4@;&$@8V5L;'5L9:`Z`%3I;.EP:&]N92!C96QL=6QA:7)E(`!#
M96QT92`H25-/+3@X-3DM,30I`$-E;G1R97(`4NEP=6)L:7%U92!C96YT<F%F
M<FEC86EN90!%=7)O<.EE;B!C96YT<F%L("A)4T\M.#@U.2TR*0!$Z71A:6QS
M(&1U(&-E<G1I9FEC870`4')O<')IZ71A:7)E(&1U(&-E<G1I9FEC870`4&]L
M:71I<75E(&1E(&-E<G1I9FEC871I;VX`5&-H860`36]D:69I97(`36]D:69I
M97(@=F]T<F4@;6]T(&1E('!A<W-E`$-H86YG97(@;&4@;F]M+"!L)V%D<F5S
M<V4@970@;&$@<VEG;F%T=7)E('%U92!L97,@<&5R<V]N;F5S('9O:65N="!Q
M=6%N9"!E;&QE<R!L:7-E;G0@970@<NEP;VYD96YT(.`@=F]S(&UE<W-A9V5S
M+@!,82!M;V1I9FEC871I;VX@9&4@=F]T<F4@;6]T(&1E('!A<W-E(&XG97-T
M('!A<R!S=7!P;W)TZ64@879E8R!L82!C;VYF:6=U<F%T:6]N(&%C='5E;&QE
M+B!#;VYT86-T97H@=F]T<F4@861M:6YI<W1R871E=7(N`$-H87(`5NE?<FEF
M:65R(&QE(&QI96X`0VAI;&D`0VAI;F4`0VAI;F]I<R!S:6UP;&EF:>D@*$="
M,C,Q,BD`0VAI;F]I<R!T<F%D:71I;VYN96P@*$)I9S4I`$-H;VES:7(@;"=A
M<'!L:6-A=&EO;J`Z`$-H;VES:7(@=6X@;6]T(&1E('!A<W-E`$-H;VES:7(@
M=6X@;F]M(&1E(&-O;FYE>&EO;@!#:&]I<VER(&QE(&UO9&4@9"=A9F9I8VAA
M9V4@9&5S(&1A=&5SH#H`0VAO:7-I<B!L92!S='EL92!D92!L:7-T92`H<&]U
M<B!L97,@;&ES=&5S(&YU;>ER:7%U97,I`,YL97,@0VAR:7-T;6%S`$3I9FEN
M:71I;VX@9&4@;&$@8VQA<W-E(&1E("5S(&YO;B!T<F]U=NEE+@!%9F9A8V5R
M`$YE='1O>65R(&QE<R!B86QI<V5S($U3+4]F9FEC90!%9F9A8V5R(&QA(')E
M<77J=&4`4F5T:7)E<B!L)W5T:6QI<V%T975R.B`E<P!%9F9A8V5R(&PG=71I
M;&ES871E=7(`169F86-E<B!L97,@9&]N;NEE<R!D92!L)W5T:6QI<V%T975R
M`,EC;&%I<F-I97,@=&%R9"!D86YS(&QA(&IO=7)NZ64`0VQI<75E<B!P;W5R
M('!O=7)S=6EV<F4`0VQI8VMA=&5L;"!V:6$@2%144`!&97)M97(@;&$@9F5N
MZG1R90!.=6%G97,`3G5A9V5S(&UA=&EN875X`$YU86=E=7@`SFQE<R!#;V-O
M<P!297!L:65R(&QA(&)A<G)E(&1E(&/T=.D`4NED=6ER92!L97,@8F]R9',`
M0V]L;VUB:64`0V]U;&5U<@!086QE='1E(&1E(&-O=6QE=7)S`%/I;&5C=&EO
M;B!D)W5N92!C;W5L975R`$-O;'.@.@!4:71R97,@9&4@8V]L;VYN90!"+D0N
M`$-O;6UA;F1E`$-O;6UA;F1E('-H96QL`$-O;6UE;G1A:7)E`$YO;2!U<W5E
M;`!#;VUO<F5S`%-O8VGI=.D`3W)D:6YA=&5U<G,`0V]N9&ET:6]N`$-O;F1I
M=&EO;G,`1&EF9NER96YC97,@9&4@8V]N9FEG=7)A=&EO;@!3>6YC:')O;FES
M871I;VX@9&5S(&%S<VES=&%N=',@<&5R<V]N;F5L<RP@/$D^<VUA<G1P:&]N
M97,\+TD^(&5T($]U=&QO;VLN`$QA(&-O;F9I9W5R871I;VX@;B=E<W0@<&%S
M(.`@:F]U<BX`0V]N9FEG=7)E<B`E<P!#;VYF:7)M97(@;&4@;6]T(&1E('!A
M<W-E`$-O;F=O`%+I<'5B;&EQ=64@9.EM;V-R871I<75E(&1U($-O;F=O`,EC
M:&5C(&1E(&QA(&-O;FYE>&EO;@#)8VAE8R!D92!L82!C;VYN97AI;VZ@.B``
M0V]N;F5X:6]N(&%U('-E<G9E=7(@9&4@8VQE9G,@<'5B;&EC(')E9G5SZ64N
M`$-O;FYE>&EO;B!A=2!S97)V975R(&1E(&-L969S('!U8FQI8R!R969U<^EE
M+B!286ES;VZ@.B`@)7,@*"5S*0#)8VAE8R!D92!L82!C;VYN97AI;VX@874@
M<V5R=F5U<B!&5%``0V]N=&%C=',`0V5S(&-O;G1A8W1S(&]N="!B:65N(.ET
MZ2!A:F]U=.ES(.`@=F]T<F4@8V%R;F5T(&0G861R97-S97,N`%1Y<&4@9&4@
M8V]N=&5N=2!D=2!F:6-H:65R(&-O;7!R97-SZ:`Z(`!#;VYT96YU(&1E(*N@
M)7.@NP!0;W5R<W5I=G)E`,YL97,@0V]O:P!4Z6UO:6X@*&-O;VMI92D`0V]P
M:65R`,EC:&5C(&1E(&QA(&-O<&EEH#H@)7,`4^EL96-T:6]N(&0G=6YE(&-O
M<&EE`$ED+B!C;_MT`$-O<W1A(%)I8V$`0_1T92!D)TEV;VER90!);7!O<W-I
M8FQE(&1E(&-H:69F<F5R(&QE(&UE<W-A9V6@.B``4VEG;F%T=7)E(%!'4"!D
M=2!M97-S86=E(&EM<&]S<VEB;&6@.B``26UP;W-S:6)L92!D92!C:&EF9G)E
M<B!L92!M97-S86=E(&%V96,@4R]-24U%+@!3:6=N871U<F4@4R]-24U%(&1U
M(&UE<W-A9V4@:6UP;W-S:6)L92X`06IO=70@9'4@8V]N=&%C="`E<R!I;7!O
M<W-I8FQE+B``3F4@<&5U="!S92!C;VYN96-T97(@874@<V5R=F5U<B!,1$%0
M+@!6Z7)I9FEC871I;VX@9&4@;&$@8F%L86YC92`E<R!I;7!O<W-I8FQE+B``
MR6-H96,@9&4@;&$@8V]N;F5X:6]N(&%U('-E<G9E=7(@3$1!4"X`R6-H96,@
M9&4@;&$@8V]N;F5X:6]N(&%U('-E<G9E=7(@JZ`E<Z"[('9I82!&5%"@.B`E
M<P!#<NEA=&EO;B!D92!L:7-T92!D92!D:7-T<FEB=71I;VX@:6UP;W-S:6)L
M92X@)7,`26UP;W-S:6)L92!D92!DZ6-H:69F<F5R(&QE<R!D;VYNZ65S(%!'
M4*`Z(`!);7!O<W-I8FQE(&1E(&3I8VAI9F9R97(@;&5S(&1O;F[I97,@4R]-
M24U%+@!.92!P975T('!A<R!S=7!P<FEM97(@;&4@8V]N=&%C="`E<P!.92!P
M975T('!A<R!S=7!P<FEM97(@;&$@;&ES=&4@9&4@9&ES=')I8G5T:6]N("5S
M`$YE('!E=70@<&%S('-U<'!R:6UE<B!L92!S8W)I<'0@9&4@;6ES92#@(&IO
M=7(@JZ`E<Z"[+@!$Z71E<FUI;F%T:6]N(&1E(&PG861R97-S92!D=2!D97-T
M:6YA=&%I<F4@:6UP;W-S:6)L92X`3F4@<&5U="!RZ6-U<.ER97(@=&]U="!L
M92!C87)N970@9"=A9')E<W-E+@!.92!P975T('+I8W5PZ7)E<B!T;W5T92!L
M82!L:7-T92!D92!D:7-T<FEB=71I;VXN`$XG82!P87,@<'4@<NEC=7#I<F5R
M(&QA(&QI<W1E(&-O;7!LZ'1E(&1E(&QI<W1E<R!D92!D:7-T<FEB=71I;VXN
M`$EM<&]S<VEB;&4@9&4@8VAA<F=E<B!L82!S=')A=.EG:64@JZ`E<Z"[+@!)
M;7!O<W-I8FQE(&1E(&-RZ65R(&QE('+I<&5R=&]I<F4@JZ`E<Z"[+@!);7!O
M<W-I8FQE(&0G;V)T96YI<B!L82!C;&5F('!U8FQI<75E(.`@<&%R=&ER(&1U
M('-E<G9E=7(@9&4@8VQE9G,N`$]U=F5R='5R92!D92"KH"5SH+L@:6UP;W-S
M:6)L92!E;B#I8W)I='5R92X`3W5V97)T=7)E(&1E("5S(&EM<&]S<VEB;&4N
M`$EM<&]S<VEB;&4@9"=O=79R:7(@;&4@;6]D=6QE($UA:6YT96YA;F-E7U1A
M<VL@)7,`3W5V97)T=7)E(&1U(&1O<W-I97(@JZ`E<Z"[(&EM<&]S<VEB;&4N
M`$EM<&]S<VEB;&4@9"=A='1E:6YD<F4@;&4@<V5R=F5U<B!,1$%0+@!,96-T
M=7)E(&1E("5S(&EM<&]S<VEB;&4N(`!.)V$@<'4@<F5M971T<F4@X"!ZZ7)O
M(&QE(&UO="!D92!P87-S92!P;W5R(&PG=71I;&ES871E=7(@9&5M86YDZ2X@
M0V5R=&%I;G,@*&]U('1O=7,I(&QE<R!DZ71A:6QS(&YE('-O;G0@<&%S(&-O
M<G)E8W1S+B!2Z65S<V%Y97H@;W4@8V]N=&%C=&5Z('9O=')E(&%D;6EN:7-T
M<F%T975R('!O=7(@9&4@;"=A:61E+@!2Z6-U<.ER871I;VX@9&5S($%#3"!I
M;7!O<W-I8FQE`$YE('!E=70@<NEC=7#I<F5R(&QE(&-A<FYE="!D)V%D<F5S
M<V5S+B`E<P!.92!P975T('+I8W5PZ7)E<B!L82!L:7-T92!D92!D:7-T<FEB
M=71I;VXN("5S`$YE('!E=70@<NEC=7#I<F5R(&QE<R!L:7-T97,@9&4@9&ES
M=')I8G5T:6]N+B`E<P!.92!P975T('+I8W5PZ7)E<B!L97,@<&]S<VEB:6QI
M=.ES(&1U('-E<G9E=7(`3F4@<&5U="!P87,@<F5V96YI<B#@(&QA(&-O;F9I
M9W5R871I;VX@<'+I8^ED96YT92X`169F86-E;65N="!D=2!D;W-S:65R(*N@
M)7.@NR!I;7!O<W-I8FQE+B``3F4@<&5U="!P87,@96YR96=I<W1R97(@;&$@
M8V]N9FEG=7)A=&EO;B`E<P!.92!P975T('!A<R!E;G)E9VES=')E<B!U;F4@
M<V%U=F5G87)D92!D92!L82!C;VYF:6=U<F%T:6]N+@!);7!O<W-I8FQE(&0G
M96YR96=I<W1R97(@=6YE(&-O<&EE(&1E(&QA(&-O;F9I9W5R871I;VZ@.B`E
M<P!);7!O<W-I8FQE(&0G96YR96=I<W1R97(@;&4@<V-R:7!T(&1E(&UI<V4@
MX"!J;W5R(&1A;G.@.B"KH"5SH+LN`$EM<&]S<VEB;&4@9"=E;G)E9VES=')E
M<B!U;F4@8V]P:64@9'4@9FEC:&EE<B!D92!C;VYF:6=U<F%T:6]N("5S+@!)
M;7!O<W-I8FQE(&0G96YR96=I<W1R97(@;&4@9FEC:&EE<B!D92!C;VYF:6=U
M<F%T:6]N("5S+B!6;W5S('!O=79E>B!S;VET('5T:6QI<V5R('5N92!D97,@
M;W!T:6]N<R!P;W5R('-A=79E<B!L92!C;V1E('-U<B`E<R!S;VET(&-O<&EE
M<B!M86YU96QL96UE;G0@;&4@8V]D92!C:2UD97-S;W5S(&1A;G,@)7,N`$YE
M('!E=70@<&%S(')E8VAE<F-H97(@;&4@<V5R=F5U<B!,1$%0+@!3=7!P<F5S
M<VEO;B!D92"KH"5SH+L@:6UP;W-S:6)L92X`36ES92#@(&IO=7(@9'4@8V]N
M=&%C="!I;7!O<W-I8FQE+B`E<P!.92!P975T(&UE='1R92#@(&IO=7(@;&$@
M;&ES=&4@9&4@9&ES=')I8G5T:6]N+B`E<P!.92!P975T('!A<R!E;G)E9VES
M=')E<B!L82!C;VYF:6=U<F%T:6]N('!O=7(@JZ`E<Z"[H#H@)7,`3F4@<&5U
M="!T<F]U=F5R(&QA(&)A<G)E(&1E($UO>FEL;&$N("!!<W-U<F5Z+79O=7,@
M<74G96QL92!E<W0@86-T:79E+@!.92!P975T(&%T=')I8G5E<B!C97,@9')O
M:71S(.`@;"=U=&EL:7-A=&5U<B"KH"5SH+L@('-U<B!L92!D;W-S:65R(*N@
M)7.@NZ`Z("5S`%1E>'1E(&-O;7!TZ0!087ES`$-O=7)S`$-RZ65R`$-RZ65R
M('5N(&QI96X`0W+I97(@=6X@;F]U=F5A=0!#<NEE<B!U;B!S;W5S+61O<W-I
M97(`4&5R;6ES<VEO;G,@1&4@0W+I871E=7(`3G5MZ7)O(&1E(&-A<G1E(&1E
M(&-RZ61I=`!#<F]A=&EE`$-U8F$`-"!P:&%S97,@8V]U<F%N=&5S`%-E<W-I
M;VYS(&5N(&-O=7)S`$AE=7)E(&%C='5E;&QE`$PG861R97-S92!54DP@86-T
M=65L;&4@97-T`%5T:6QI<V%T975R<R!A8W1U96QS`$]B<V5R=F%T:6]N<R!A
M8W1U96QL97,`0V]N9&ET:6]N(&%C='5E;&QEH#H@`%-T>6QE(&-O=7)A;G0`
M1.EF:6YI<B!L97,@=.)C:&5S(.`@969F96-T=65R(&QO<G,@9&4@;&$@8V]N
M;F5X:6]N(.`@)7,N`$-O=7!E<@!#;W5P97(@;&$@<^EL96-T:6]N`$-H>7!R
M90!#>7)I;&QI<75E("A+3TDX+5(I`$-Y<FEL;&EQ=64@*%=I;F1O=W,M,3(U
M,2D`0WER:6QL:7%U92]5:W)A:6YI96X@*$M/23@M52D`4NEP=6)L:7%U92!4
M8VCH<75E`$I*`$133B`H0V8N(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L
M+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`0VAA<75E
M(&IO=7(`3F%V:6=A=&5U<B!D92!$871A5')E90!!;&EA<R!D92!L82!B87-E
M`$1A=&4`1&%T92!D92!RZ6-E<'1I;VX`4^EL96-T:6]N(&0G=6YE(&1A=&4`
M2F]U<@!3=7!P<FEM97(@7VQA(&-O;&]N;F4`1.EC96UB<F4`3F]M8G)E<R!D
MZ6-I;6%U>`!$:6UI;G5E<B!L)VEN9&5N=&%T:6]N`$3I9F%U=`!#;W5L975R
M('!A<B!DZ69A=70`261E;G1I=.D@<&%R(&3I9F%U=`!);G1E<G!RZ71E=7(@
M9&4@8V]M;6%N9&4@<&%R(&3I9F%U=`!$Z69I;FET:6]N<P!%9F9A8V5R`$5F
M9F%C97(@;&$@8V5L;'5L90!3=7!P<FEM97(@=6X@9W)O=7!E`$5F9F%C97(@
M;&$@=')A8V4`4W5P<')I;65R('5N92!P97)M:7-S:6]N`%-U<'!R:6UE<B!E
M="!P=7)G97(@;&5S(&UE<W-A9V5S`$5F9F%C97(@;&$@8V5L;'5L90!%9F9A
M8V5R(&QA(&-O;&]N;F4`4W5P<')I;65R('5N(&%U=')E(&UO9.AL92!E>&ES
M=&%N=`!3=7!P<FEM97(@;&5S(&UE<W-A9V5S`%-U<'!R:6UE<B!L97,@<&5R
M;6ES<VEO;G,@<&]U<B"KH"5SH+L`RG1E<RUV;W5S(&-E<G1A:6X@9&4@=F]U
M;&]I<B!E9F9A8V5R(*N@)7.@NR!E="!S97,@<V]U<RUP97)M:7-S:6]N<Z`_
M`$5F9F%C97(@;&$@<F%N9^EE`%-U<'!R:6UE<B!L)VED96YT:73I('/I;&5C
M=&EO;F[I90!3=7!P<FEM97(@=6X@<V]U<RUD;W-S:65R`$5F9F%C97(@;&$@
M8V]L;VYN92!A8W1U96QL90!%9F9A8V5R(&QA(')A;F?I92!A8W1U96QL90!3
M8W)I<'0@9&4@8V]N9FEG=7)A=&EO;B!D92!M:7-E(.`@:F]U<B!S=7!P<FEM
MZ2"KH"5SH+LN`$AE=7)E(&1E(&QI=G)A:7-O;@!$86YE;6%R:P!$Z6-R:7)E
M(&QE('!R;V)LZ&UE`$1E<V-R:7!T:6]N`$3I=&%I;',@*&%U<W-I(&1A;G,@
M;&4@9FEC:&EE<B!D92!T<F%C97,@9&4@2&]R9&4IH#H`3&5S(&3I=&%I;',@
M;VYT(.ETZ2!C;VYS:6=NZ7,@<&]U<B!L)V%D;6EN:7-T<F%T975R+@!$Z79E
M;&]P<&5M96YT`%!O:6YT(&1E(')O<^EE`%!O:6YT(&1E(')O<^EE('!O=7(@
M;&$@9&5R;FGH<F4@:&5U<F6@.B``4&]I;G0@9&4@<F]SZ66@.B``1&4@9V%U
M8VAE(.`@9')O:71E`$1E(&1R;VET92#@(&=A=6-H90!2Z7!E<G1O:7)E`$%F
M9FEC:&5R('-U<B`R-"!H975R97.@/P!/<'1I;VYS(&0G869F:6-H86=E`$%F
M9FEC:&5R(&QA('!RZ79I<VEO;B!DZ71A:6QLZ64`069F:6-H97(@;&$@<'+I
M=FES:6]N("A4048I`$9O<FUA="!D)V%F9FEC:&%G90!!=FES(&1E(&QI=G)A
M:7-O;@!$:FEB;W5T:0!.92!P87,@<W5P<')I;65R`$YE('!A<R!A8V/I9&5R
M(&1I<F5C=&5M96YT(.`@;6%I;G1E;F%N8V4N<&AP`$QE('!R96UI97(@96YR
M96=I<W1R96UE;G0@8V]N=&EE;G0M:6P@;&4@;F]M(&1E<R!C:&%M<'.@/R!$
M86YS(&PG869F:7)M871I=F4L(&-O8VAE>B!C971T92!B;^YT9:`Z`$1O;6EN
M:7%U90!2Z7!U8FQI<75E(&1O;6EN:6-A:6YE`%9O=7,@;B=A=F5Z('!A<R!D
M92!C;VUP=&6@/R!%;G)E9VES=')E>BUV;W5S+@!4Z6SI8VAA<F=E<@!4Z6SI
M8VAA<F=E<B`E<P!4Z6SI8VAA<F=E<B!L82!C;VYF:6=U<F%T:6]N(&?I;NER
MZ64@8V]M;64@=6X@<V-R:7!T(%!(4`!,:7-T92!DZ7)O=6QA;G1E`$1R;V=U
M97,`0V]U<G)I97(@Z6QE8W1R;VYI<75E`%!I;&]T92!D92!P87-S97)E;&QE
M(&-O=7)R:65R("\@4TU3+"!P;W5R(&QE<R!F;W5R;FES<V5U<G,@9&4@8V4@
M<V5R=FEC92X`15)2`,EQ=6%T975R`$UO9&EF:65R`,ED:71E<B!L92!B;&]C
M`,ED:71E<B!U;B!G<F]U<&4`R61I=&5R('5N92!P97)M:7-S:6]N`,ED:71E
M<B!L97,@<&5R;6ES<VEO;G,`R61I=&5R(&QE<R!P97)M:7-S:6]N<R!P;W5R
M(*N@)7.@NP#)9&ET97(@;&5S(&]P=&EO;G,@<&]U<J`Z`,ED:71E<B!L97,@
M<&5R;6ES<VEO;G,@<&]U<B"KH"5SH+L`R61I=&5R(&QE<R!P97)M:7-S:6]N
M<R!P;W5R("5S`,ED=6-A=&EO;@#)9WEP=&4`4V%L=F%D;W(`R6SI;65N="XN
M+@!%;0!!9')E<W-E(.EL96-T<F]N:7%U90!!9')E<W-E(.EL96-T<F]N:7%U
M90!,97,@861R97-S97,@Z6QE8W1R;VYI<75E<R!D;VEV96YT(&-O<G)E<W!O
M;F1R92X`0V]U<G)I97(@879E8R!C;VYF:7)M871I;VX`4&%S<V5R96QL92!C
M;W5R<FEE<B`O(%--4P#);6]T:6/T;F5S`$UE<W-A9V4@=FED92X`4NES=6QT
M870@=FED92X`5&5R;65S(&1E(')E8VAE<F-H92!V:61E`$%C=&EV97(@;"=I
M;G-E<G1I;VX@9"=I;6%G97,@=F5N86YT(&1E<R!A;&)U;7,@<&AO=&]S(&1A
M;G,@;&4@=&5X=&6@/P!!8W1I=F5R(&QE(&UE;G4@8V]N=&5X='5E;"!A=F5C
M('5N(&-L:6,@9')O:72@/P!&:6X@9&4@;"=A;F[I90!!9W)A;F1I<B!L)^ED
M:71E=7(`R6-R:79E>B!U;F4@<75E<W1I;VX@9&4@<^EC=7)I=.D@<74G;VX@
M=F]U<R!P;W-E<F$@<VD@=F]U<R!D979E>B!R96UE='1R92#@('KI<F\@=F]T
M<F4@;6]T(&1E('!A<W-E+"!P87(@97AE;7!L92"K(%%U96P@97-T(&QE(&YO
M;2!D92!V;W1R92!A;FEM86P@<'+I9NERZ:`_H+N@.@!);G-C<FEV97H@;"=A
M9')E<W-E(%523"!D92!L)VEM86=E(&EC:0!%;G1R97H@;&5S(&QE='1R97,@
M8VDM9&5S<V]U<Z`Z`$=U:6[I92#I<75A=&]R:6%L90#)<GET:'+I90!%<G)E
M=7(`17)R975R(&QO<G,@9&4@;&$@8W+I871I;VX@9'4@8FQO8Z`Z("5S`$5R
M<F5U<B!L;W)S(&1E(&QA('-U<'!R97-S:6]N(&1E(&PG86YC<F4@9&4@<WEN
M8VAR;VYI<V%T:6]NH#H@)7,`17)R975R(&QO<G,@9&4@;&$@<W5P<')E<W-I
M;VX@9'4@:F]U<FYA;"!D92!S>6YC:')O;FES871I;VZ@.B`E<P!%<G)E=7(@
M;&]R<R!D92!L82!RZ6-U<.ER871I;VX@9'4@8V]N=&5N=:`Z("5S`$5R<F5U
M<B!L;W)S(&1E(&QA(&UI<V4@X"!J;W5R(&1U(&UO="!D92!P87-S9:`Z("5S
M`$5R<F5U<B!A=F5C(&QE(&UE<W-A9V4N`$5R<F5U<B!L;W)S(&1E(&PG96YR
M96=I<W1R96UE;G0@9&4@JZ`E<Z"[+@!%<W1O;FEE`,ET:&EO<&EE`$5T:&YI
M<75E`$5U<F]P90!4;W5S(&QE<R`F9G)A8S$T.R!D)VAE=7)E`%1O=71E<R!L
M97,@,B!M:6YU=&5S`%1O=71E<R!L97,@,S`@<V5C;VYD97,`5&]U=&5S(&QE
M<R`U(&UI;G5T97,`P"!C:&%Q=64@8V]N;F5X:6]N`%1O=71E<R!L97,@)F9R
M86,Q,CL@:&5U<F5S`%1O=71E<R!L97,@;6EN=71E<P!%>&5M<&QE(&1E('9A
M;&5U<G.@.@!%>.EC=71E<@!$Z79E;&]P<&5R`$3I<&QI97(@;&$@8F%R<F4@
M9&4@8_1TZ0"K("D@NR!A='1E;F1U90!5;B!S975L(&UO="!O=2!E>'!R97-S
M:6]N(&5N=')E(&=U:6QL96UE=',@871T96YD=7,`1&%T92!D)V5X<&ER871I
M;VX`4F5P<NES96YT86YT`$-O=6QE=7(@9"=A=F%N="UP;&%N`%3I;.EC:&%R
M9V5M96YT('9E<G,@;&4@<V5R=F5U<B!D92!L82!C;VYF:6=U<F%T:6]N('!A
M<B!&5%``3&5C='5R92!D97,@<'+I9NER96YC97,@:6UP;W-S:6)L92X`R6-H
M96,@9&4@;&$@8V]N;F5X:6]N(&%U('-E<G9E=7(@3$1!4"X`R6-H96,@9&4@
M;&$@8V]N;F5X:6]N(&%U('-E<G9E=7(@4TU"+@#)8VAE8R!D92!L82!C;W!I
M92!D97!U:7,@JZ`E<Z"[+@#)8VAE8R!D92!L82!C;W!I92!V97)S(""KH"5S
MH+LN`$EM<&]S<VEB;&4@9&4@8W+I97(@=6YE(&YO=79E;&QE(&-O;FYE>&EO
M;B!305-,`,EC:&5C(&1U(&3I<&QA8V5M96YT('9E<G,@JZ`E<Z"[+@#)8VAE
M8R!L;W)S(&1E(&QA('+I8W5PZ7)A=&EO;J`Z("5S`$)E874`SFQE<R!&86QK
M;&%N9"`H36%L;W5I;F5S*0#.;&5S($;I<F_I`$5R<F5U<B!F871A;&6@.@!&
M87@`5.ELZ6-O<&EE<P!&Z79R:65R`%1E;7#I<F%T=7)E(')E<W-E;G1I90!4
M96UPZ7)A='5R92!R97-S96YT:66@.B``475E;'%U97,@879E<G-E<P!1=65L
M<75E<R!C:'5T97,@9&4@;F5I9V4`36%T<FEC92!D97,@8VAA;7!S`$9I9VQE
M="!#05!40TA!`%!O;&EC92!D92!L82`\23YF:6=L970\+TD^`$9I9&II`$9I
M8VAI97(`3F]M8G)E(&1E(&9I8VAI97)SH#H@)7,`3F]M8G)E(&1E(&9I8VAI
M97)SH#H@)7,`1V5S=&EO;FYA:7)E(&1E(&9I8VAI97)S`$YO;2!D=2!F:6-H
M:65R`$-H;VEX(&1E(&9I8VAI97(`5.ELZ6-H87)G96UE;G0@9&4@9FEC:&EE
M<@!,)V5N=F]I(&1E(&9I8VAI97)S(&XG97-T('!A<R!P<FES(&5N(&-O;7!T
M92X`1FEL=')E<P!&:6YL86YD90!0<F5M:>AR92!D96UI90!0<F5M:65R('%U
M87)T:65R`$9I>&5R(&QE(')A=&EO`%)E=&]U<FYE<@!&;&]T=&%N=`!"<F]U
M:6QL87)D`$1O<W-I97(@)7,@:6YE>&ES=&%N="X`0V]U;&5U<B!D92!P;VQI
M8V4`3F]U<G)I='5R90!0;W5R(&QE<R!N879I9V%T975R<R!N92!S=7!P;W)T
M86YT('!A<R!L97,@:6UA9V5S`%!RZ79I<VEO;B`H5$%&*0!*;W5R<R!D92!P
M<NEV:7-I;VX@*&YO=&5Z('%U92!L97,@<'+I=FES:6]N<R!F;W5R;FEE<R!D
M;VYN96YT(&QE(&IO=7(@970@;&$@;G5I=*`[('5N(&=R86YD(&YO;6)R92!I
M8VD@<&5U="!F86ER92!U;B!B;&]C('1RZ',@;&%R9V4`5F]U<R!A=F5Z(&]U
M8FQIZ2!V;W1R92!M;W0@9&4@<&%S<V6@/P!&;W)M=6QA:7)E<P!#:71A=&EO
M;@!4>7!E(&1E(&-I=&%T:6]N`$-I=&%T:6]N<P!#:71A=&EO;G,@,@!&;W)U
M;7,`4F5D:7)E8W1I;VX`5F4`0V%D<F5S`$9R86YC90!&<F%N8V4@;>ET<F]P
M;VQI=&%I;F4`1W5Y86YE(&9R86[G86ES90!0;VQY;NES:64@9G)A;N=A:7-E
M`%1E<G)E<R!A=7-T<F%L97,@970@86YT87)C=&EQ=65S(&9R86[G86ES97,`
M1&4`1'4@`$1E<V-R:7!T:6]N(&-O;7!LZ'1E`%!L96EN92!L=6YE`$YO;2!C
M;VUP;&5T`$=A8F]N`$%L8G5M(&0G;W)I9VEN92!D92!L)VEM86=E`$%L8G5M
MH#H`1V%M8FEE`$?I;NER97(@;&$@8V]N9FEG=7)A=&EO;B!D92`E<P!#;V1E
M(&?I;NERZ0!'Z6]R9VEE`$%L;&5M86=N90!':&%N80!':6)R86QT87(`4'+I
M;F]M`$]P=&EO;G,@9VQO8F%L97,`06QL97(`1V]E9&5L`$-A<G1E<R!';V]G
M;&4`4F5C:&5R8VAE($=O;V=L90!.:79E874@9&4@9W)I<P!'<NAC90!'<F5C
M("A)4T\M.#@U.2TW*0!'<F_K;FQA;F0`1W)E;F%D90!!9&UI;FES=')A=&EO
M;B!D97,@9W)O=7!E<P!,97,@;F]M<R!D92!G<F]U<&4@;F4@<&5U=F5N="!P
M87,@ZG1R92!V:61E<P!'<F]U<%]L9&%PH#H@:6UP;W-S:6)L92!D)V%J;W5T
M97(@;&4@9W)O=7!E("5S+B!#96-I(&5S="!L82!RZ7!O;G-E(&1U('-E<G9E
M=7*@.@!'<F]U<%]L9&%PH#H@<W5P<')E<W-I;VX@:6UP;W-S:6)L92!D=2!G
M<F]U<&4@)7,`1W)O=7!?;&1A<*`Z(&UO9&EF:6-A=&EO;B!I;7!O<W-I8FQE
M(&1U(&=R;W5P92`E<P!'<F]U<&5S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA
M;&$`1W5E<FYE<V5Y`%!E<FUI<W-I;VYS(&1E<R!I;G9I=.ES`$QI=G)E(&0G
M;W(`1W5I;NEE`$=U:6[I92U":7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@
M<F5F=7-E(&+J=&5M96YT(&1E('-U<'!R:6UE<B!L82!D97)N:>AR92!C96QL
M=6QE(&1E(&QA(')A;F?I90!(5$U,07)E82!R969U<V4@8NIT96UE;G0@9&4@
M<W5P<')I;65R(&QA(&1E<FYIZ')E(&-O;&]N;F4@9'4@=&%B;&5A=0!(5$U,
M07)E82!R969U<V4@8NIT96UE;G0@9&4@<W5P<')I;65R(&QA(&1E<FYIZ')E
M(')A;F?I92!D=2!T86)L96%U`$%U=&AE;G1I9FEC871I;VX@2%144"!N;VX@
M=')O=7;I92X`2&'O=&D`06QG;W)I=&AM92!D92!H86-H86=E`$)R=6UE('/H
M8VAE`$5N+73J=&4`16XM=.IT97,`SFQE<R!(96%R9"!E="!-8T1O;F%L9`!/
M<F%G97,@=FEO;&5N=',`2.EB<F5U("A)4T\M.#@U.2TX+4DI`$AA=71E=7(`
M06ED90!!:61E('!O=7(@;"?I9&ET975R`$%I9&4`2.EM:7-P:.AR90!6;VEC
M:2!L92!DZ6)U="!D=2!F:6-H:65RH#H`2&%U=&4`05]C8W5E:6P`0VETZ2!D
M=2!6871I8V%N`$%C8W5E:6P`061R97-S92!P97)S;VYN96QL90!2Z7!E<G1O
M:7)E('!E<G-O;FYE;`!4Z6SI<&AO;F4@<&5R<V]N;F5L`$AO;F1U<F%S`$AO
M;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8J`Z(&1O;F[I97,@6$U,("5S(&EN
M=F%L:61E<R!R971R;W5VZ65S(&1A;G,@;&4@;65S<V%G92`E<P!(;W)D92]+
M;VQA8J`Z(&%U8W5N(&UE<W-A9V4@;F4@8V]R<F5S<&]N9"!A=2!S=6IE="`E
M<P!(;W)D92]+;VQA8J`Z('!A<R!D)V]B:F5T(&1E('1Y<&4@)7,@=')O=7;I
M(&1A;G,@;&4@;65S<V%G92`E<P!(;W)D92]+;VQA8J`Z("5S('-U<'!R:6WI
M(*N@)7.@NR!A=F5C('-U8V/H<P!(;W)D92]+;VQA8J`Z(&QE(&UO=&5U<B!D
M)VEN=.EG<F%T:6]N(&[I8V5S<VET92!L)V5X=&5N<VEO;B`G9&]M>&UL)R!D
M92!02%``2&]R9&4O2V]L86*@.B!I;7!O<W-I8FQE(&1E(&-RZ65R('5N(&YO
M=79E;"!A<F)R92!834P@<&]U<B!L)V]B:F5T("5S`$AO<F1E+TMO;&%BH#H@
M:6UP;W-S:6)L92!D)V5N;&5V97(@)7,@JZ`E<Z"[H#H@)7,`2&]R9&4O2V]L
M86*@.B!I;7!O<W-I8FQE(&1E('+I8W5PZ7)E<B!L)VED96YT:69I86YT($U)
M344@<&]U<B!L82!P87)T:64@9&4@='EP92`E<P!(;W)D92]+;VQA8J`Z(&EM
M<&]S<VEB;&4@9&4@<WEN8VAR;VYI<V5R("5S(*N@)7.@NZ`Z("5S`$AO<F1E
M+TMO;&%BH#H@:6UP;W-S:6)L92!D92!S>6YC:')O;FES97(@;&5S('!A<G1A
M9V5SH#H@)7,`2&]R9&4O2V]L86*@.B!P87)T86=E(&EN8V]N;G4@JZ`E<Z"[
M`$QI9VYE(&AO<FEZ;VYT86QE`%)E;7!L:7-S86=E(&AO<FEZ;VYT86P`2&]R
M:7IO;G1A;*`Z`$-O;6UE;G0@ZG1E<RUV;W5S(&%R<FEVZ2!I8VF@/R`H4U90
M(')A<'!O<G1E>BUL9:`A*0!#;VUB:65N(&1E(&-O;&]N;F5S('9O=6QE>BUV
M;W5S(&9U<VEO;FYE<J`_`$-O;6)I96X@9&4@8VAA;7!S("AC;VQO;FYE<RD@
M>2!A+70M:6R@/P!#;VUB:65N(&1E(')A;F?I97,@=F]U;&5Z+79O=7,@9G5S
M:6]N;F5RH#\`2'5M:61I=.D`2'5M:61I=.F@.B``2'5M;W)I<W1E<P!(;VYG
M<FEE`,EC:&5C(&QO<G,@9&4@;&$@8W+I871I;VX@9&4@;&$@8F_N=&4@24U!
M4*`Z("5S`,EC:&5C(&QO<G,@9&4@;&$@<W5P<')E<W-I;VX@9&4@;&$@8F_N
M=&4@24U!4*`Z("5S`,EC:&5C(&QO<G,@9&4@;&$@8W+I871I;VX@9'4@<75O
M=&$@<W5R(&QA(&)O[G1E($E-05"@.B`E<P!!9')E<W-E($E0`$%D<F5S<V4@
M25`@;F]N(&1I<W!O;FEB;&4N`$%D<F5S<V4@25`@:&]R<R!D=2!B;&]C($-)
M1%(@86QL;W7I+@!6:6]L871I;VX@9&4@8FQO8V%G92!)4"X`25]N<^ER97(@
M<F%N9^EE(&%V86YT`$ES;&%N9&4`26/T;F5S('-E=6QE;65N=`!)8_1N97,@
M<&]U<B`E<P!)8_1N97,@<&QU<R!T97AT90!.;VT@9'4@8V]M<'1EH#H`4VD@
M;"=A9F9I8VAA9V4@;B=E<W0@<&%S(&-O<G)E8W0L("5S('!O=7(@;"=O=79R
M:7(@9&%N<R!U;F4@;F]U=F5L;&4@9F5NZG1R92X`4VD@=F]U<R!N92!V;WEE
M>B!A=6-U;B!I8_1N92!E;B!U=&EL:7-A;G0@26YT97)N970@17AP;&]R97(L
M('9O=7,@<&]U=F5Z(&%V;VER(.`@8V]C:&5R(&-E='1E(&-A<V4@<&]U<B!D
MZ7-A8W1I=F5R(&QA('1R86YS<&%R96YC92!D97,@4$Y'+@!3:2!V;W5S('9O
M>65Z(&-E(&UE<W-A9V4@;6%I<R!A=6-U;F4@:6UA9V4L(&PG:6UA9V4@<75E
M('9O=7,@=F]U;&5Z(&5N=F]Y97(@;F4@<&5U="#J=')E(&%F9FEC:.EE('!A
M<B!V;W1R92!N879I9V%T975R+@!!<&5RYW4@9&4@;"=I;6%G9:`Z`$%D<F5S
M<V4@55),(&1E(&PG:6UA9V4`061R97-S92!54DP@9&4@;"=I;6%G9:`Z`$EM
M86=E(&1E(&PG86QB=6T`26UA9V4@9&4@;"=A;&)U;:`Z`%3I;.EC:&%R9V5M
M96YT(&0G:6UA9V5S`$EM86=E<P!);7!O<G1A=&EO;BP@Z71A<&4@)60`0VAA
M;7`@:6UP;W)TZ:`Z("5S`$-H86UP<R!I;7!O<G3I<Z`Z`$EN7W/I<F5R(')A
M;F?I92!A<'+H<P!#;V1E(&0G86-T:6]N(&EN8V]R<F5C="X`3F]M(&0G=71I
M;&ES871E=7(@970O;W4@=F]T<F4@;6]T(&1E('!A<W-E(&EN8V]R<F5C="X`
M3F]M(&0G=71I;&ES871E=7(@;W4@861R97-S92!A;'1E<FYA=&EV92!I;F-O
M<G)E8W0N("!2Z65S<V%Y97H@;W4@8V]N=&%C=&5Z('9O=')E(&%D;6EN:7-T
M<F%T975R('-Y<W3H;64@<&]U<B!D92!L)V%I9&4N`$%U9VUE;G1E<B!L)VEN
M9&5N=&%T:6]N`$EN9&4`571I;&ES871E=7)S(&EN9&EV:61U96QS`$EN9&]N
MZ7-I90!);F9O`$EN9F]R;6%T:6]N<P!,)VEN9F]R;6%T:6]N(&XG97-T('!L
M=7,@9&ES<&]N:6)L92X`26YSZ7)E<B!C7V]L;VYN92!A<'+H<P!);G/I<F5R
M(&EM86=E`$EN<^ER97(@=6X@=&%B;&5A=0!);G/I<F5R('5N(&QI96X@=V5B
M`$EN<^ER97(@7V-O;&]N;F4@879A;G0`26YSZ7)E<B!U;F4@;F]U=F5L;&4@
M8V]L;VYN92!A<'+H<R!L82!C;VQO;FYE(&%C='5E;&QE`$EN<^ER97(@=6YE
M(&YO=79E;&QE(&-O;&]N;F4@879A;G0@;&$@8V]L;VYN92!A8W1U96QL90!)
M;G/I<F5R('5N92!N;W5V96QL92!R86YGZ64@87!RZ',@;&$@<F%N9^EE(&%C
M='5E;&QE`$EN<^ER97(@=6YE(&YO=79E;&QE(')A;F?I92!A=F%N="!L82!R
M86YGZ64@86-T=65L;&4`26YSZ7)E<B!U;B!P87)A9W)A<&AE(&%P<NAS(&QE
M(&XF;V5L:6<[=60@86-T=65L`$EN<^ER97(@=6X@<&%R86=R87!H92!A=F%N
M="!L92!N)F]E;&EG.W5D(&%C='5E;`!);G/I<F5R('5N(&%U=')E(&UO9.AL
M90!);G-C<FEV97H@=6YE(&%D<F5S<V4@9&4@8V]U<G)I97(@X"!L87%U96QL
M92!V;W5S(')E8V5V<F5Z(&QE(&YO=79E874@;6]T(&1E('!A<W-EH#H`26YS
MZ7)E<B!C96QL=6QE(&%P<NAS`$EN<^ER97(@8V5L;'5L92!A=F%N=`!);G/I
M<F5R(&-O;&]N;F4@87!RZ',`26YSZ7)E<B!C;VQO;FYE(&%V86YT`$EN<^ER
M97(@;&5S(&UE<W-A9V5S`$EN<^ER97(@<&%R86=R87!H92!A<'+H<P!);G/I
M<F5R('!A<F%G<F%P:&4@879A;G0`26YSZ7)E<B!R86YGZ64@87!RZ',`26YS
MZ7)E<B!R86YGZ64@879A;G0`26YS8W)I=F5Z(&QA('+I<&]N<V4@X"!L82!Q
M=65S=&EO;B!D92!SZ6-U<FETZ:`Z`$EN<^ER97(O36]D:69I97(@=6YE(&EM
M86=E`$EN<^ER97(O36]D:69I97(@=6X@;&EE;B!W96(`0W+I9&ET(&EN<W5F
M9FES86YT('!O=7(@96YV;WEE<B#@(&QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO
M;BX`0W+I9&ET(&EN<W5F9FES86YT+@!%;G1I97(`3&ES=&4@8V]M<&SH=&4`
M541(("A5<V5R($1A=&$@2&5A9&5R*2!I;G9A;&ED90!$;VYNZ64@6DE0(&EN
M=F%L:61E+@!!<'!L:6-A=&EO;B!I;G9A;&ED92X`1W)O=7!E($E$(&EN=F%L
M:61E+@!%;G9O:2!D92!D;VYNZ65S(&EN=F%L:61E<RX`061R97-S92!D92!D
M97-T:6YA=&EO;B!I;G9A;&ED92X`1F]R;6%T(&1E(&9I8VAI97(@:6YV86QI
M9&4N`$-L968@9&4@;&EC96YC92!I;G9A;&ED92X`16UP;&%C96UE;G0@:6YD
M:7%UZ2!I;G9A;&ED92X`JVUS9U]T>7!ENR!I;G9A;&ED92X`JV%P:5]I9+L@
M:6YV86QI9&4@;W4@;6%N<75A;G0N`%!A<F%MZ'1R97,@:6YV86QI9&5S(&]U
M(&UA;G%U86YT<RX`4&5R;6ES<VEO;B!I;G9A;&ED92X`260N(&1E('!A<G1E
M;F%I<F4@:6YV86QI9&4N`$-O9&4@9&4@<')O9'5I="!I;G9A;&ED92X`4')O
M=&]C;VQE(&EN=F%L:61E+@!$97-T:6YA=&%I<F4@:6YV86QI9&6@.B"KH"5S
MH+L`3V)J970@9&4@<&%R=&%G92!I;G9A;&ED90!!9')E<W-E('-O=7)C92!I
M;G9A;&ED92X`1&]N;NEE(%5N:6-O9&4@:6YV86QI9&4N`$EN=F5N=&%I<F4`
M26YV97)S97(@;&$@<^EL96-T:6]N`$ER86X`27)A:P!)<FQA;F1E`,YL92!D
M92!-86X`5&5M<.IT97,@:7-O;.EE<P!)<W)AZVP`R6UE='1E=7(`271A;&EQ
M=64`271A;&EE`$IA;6'O<75E`$IA;G9I97(`2F%P;VX`2F%P;VYA:7,@*$E3
M3RTR,#(R+4I0*0!*97)S97D`2F]R9&%N:64`2G5I;&QE=`!*=6EN`$IU<W1I
M9FEE<@!#96YT<F5R`$IU<W1I9FEE<@!!;&EG;F5R(.`@9V%U8VAE`$%L:6=N
M97(@X"!D<F]I=&4`2V%Z86MH<W1A;@!'87)D97(@;"=O<FEG:6YA;*`_`$ME
M;GEA`$QE('-E<G9E=7(@2V5R8F5R;W,@82!R96IE=.D@;"=A=71H96YT:69I
M8V%T:6]N+@!$Z6)U=&%N=',@9'4@;F]Y874`0W+I871I;VX@9&4@8VQE9@!%
M;7!R96EN=&4@9&4@;&$@8VQE9@!,;VYG=65U<B!D92!L82!C;&5F`%1Y<&4@
M9&4@8VQE9@!5=&EL:7-A=&EO;B!D92!L82!C;&5F`$QA(&-L968@<V4@=')O
M=79E(&3I:N`@<W5R(&QE('-E<G9E=7(@9&4@8VQE9G,@<'5B;&EC+@!%;F9A
M;G1S`$MI<FEB871I`$-O<NEE(&1U($YO<F0`0V]RZ64@9'4@4W5D`$-O<NEE
M;B`H155#+4M2*0!+;W=E[W0`2VER9VAI>FES=&%N`%!RZ5]S96YT871I;VX`
M3&%N9W5E`$QA;W,`1&5R;FGH<F4@9&5M:64`1&5R;FGH<F4@;6]D:69I8V%T
M:6]N(&1U(&UO="!D92!P87-S90!$97)N:65R('%U87)T:65R`$1E<FYIZ')E
M(&UI<V4@X"!J;W5RH#H`1&5R;FGH<F4@8V]N;F5X:6]NH#H@)7,`1&5R;FGH
M<F4@8V]N;F5X:6]NH#H@)7,@X"!P87)T:7(@9&4@)7,`1&5R;FGH<F4@8V]N
M;F5X:6]NH#H@:F%M86ES`$QE='1O;FEE`$QO:0!0<NES96YT871I;VX`3&%I
M<W-E<B!V:61E('!O=7(@;F4@<&%S(&%V;VER(&1E(&)O<F1U<F4`3&EB86X`
M1V%U8VAE`$5N=.IT92!G875C:&4`5F%L975R<R!D92!G875C:&4`3&5S;W1H
M;P!.:79E874`3&EBZ7)I80!,:6)Y90!,:65C:'1E;G-T96EN`$)R=6EN92!L
MZ6?H<F4`4&QU:64@;.EGZ')E`%!L=6EE(&SI9^AR92!T]'0@9&%N<R!L82!J
M;W5R;NEE`%!L=6EE(&SI9^AR92!T87)D`$%V97)S97,@;.EGZ')E<P!0;'5I
M92!LZ6?H<F4@879E8R!T;VYN97)R90!.96EG92!I;G1E<FUI='1E;G1E`$%V
M97)S92!D92!N96EG92!LZ6?H<F4`4FEM97,`3&EE;@!,92!L:65N('!O:6YT
M92!V97)SH#H`3&EE(&PG861R97-S92!D92!C;W5R<FEE;"#@(&QA('!A9V4@
M9&4@8V]M<&]S:71I;VX@9'4@;65S<V%G92!E;B!L)V%F9FEC:&%N=`!,:65N
M<P!":7-C=6ET($QI;G5X`$QI<W1E("T@=71I;&ES871E=7(@<&5U="!V;VER
M(&QE(&1O<W-I97(`3&ES=&4@9&5S(&)A<V5S(&1E(&1O;F[I97,`26YD97@@
M9&4@;"=A:61E`$%F9FEC:&5R(&QE<R!T86)L97,`07)C:&EV97,@9&4@;&$@
M;&ES=&4`06ED92!D92!L82!L:7-T90!)9"X@9&4@;&$@;&ES=&4`4')O<')I
MZ71A:7)E(&1E(&QA(&QI<W1E`$5N=F]I(.`@;&$@;&ES=&4`06)O;FYE;65N
M="#@(&QA(&QI<W1E`$3I<V%B;VYN96UE;G0@9&4@;&$@;&ES=&4`R6-H96,@
M9&4@;&$@;&ES=&4@9&5S('-E<W-I;VYSH#H@)7,`R6-H96,@9&4@;&$@;&ES
M=&4@9&5S('5T:6QI<V%T975R<Z`Z("5S`$PG869F:6-H86=E(&1E(&QA(&QI
M<W1E(&1E<R!U=&EL:7-A=&5U<G,@97-T(&3I<V%C=&EVZ2X`3&ET=.ER871U
M<F4`3&ET=6%N:64`0VAA<F=E;65N="XN+@!(975R92!L;V-A;&6@.B``2&5U
M<F4@970@;&]C86QE`$QI974`0V]N;F5X:6]N`%1R86-E(&1E(&QA(&1E<FYI
MZ')E('-E<W-I;VX@9&4@<WEN8VAR;VYI<V%T:6]N`$3I8V]N;F5X:6]N`$-O
M;FYE>&EO;@!4XF-H97,@9&4@8V]N;F5X:6]N`$QA(&-O;FYE>&EO;B!E<W0@
M<F5F=7/I92X@26P@97-T('!R;V)A8FQE('%U92!V;W1R92!N;VT@9"=U=&EL
M:7-A=&5U<B!O=2!V;W1R92!M;W0@9&4@<&%S<V4@82#I=.D@;6%L('-A:7-I
M`,EC:&5C(&1E(&-O;FYE>&EO;BX`5&5X=&4@;&]N9P!!;6]U<@!&86EB;&4`
M3&5T=')E(&=R96-Q=65S(&UI;G5S8W5L97,`3&5T=')E(&QA=&EN97,@;6EN
M=7-C=6QE<P!.;VUB<F4@<F]M86EN<R!M:6YU<V-U;&5S`$QU>&5M8F]U<F<`
M34T`365S<V%G92!D=2!J;W5R("A-3U1$*0!,82!P:>AC92!J;VEN=&4@35,M
M5$Y%1B!N92!C;VYT96YA:70@875C=6YE(&1O;F[I92X`35-'`$UA8V%O`%+I
M<'5B;&EQ=64@9&4@36%CZ61O:6YE`$UA9&%G87-C87(`36%G:64`0V]U<G)I
M97(`061M:6YI<W1R871I;VX@9'4@8V]U<G)I96P`1F%I<F4@=6X@;&EE7VX`
M36%L87=I`$UA;&%I<VEE`$UA;&1I=F5S`$UA;&D`36%L=&4`061M:6YI<W1R
M97H@;&$@;&ES=&4@9&4@8V%TZ6=O<FEE<R!E="!L97,@8V]U;&5U<G,@;&GI
M97,@X"!C97,@8V%TZ6=O<FEE<RX`0V%R=&4@JR!-87`R-""[`$-A<G1E(*L@
M36%P<75E<W0@NP!#;W)R97-P;VYD86YC97,@96YR96=I<W1RZ65S+@!-87)S
M`$UA<F=E`$UA<G%U97(@879E8R!D97,@Z71I<75E='1E<R!6=2].;VX@=G4`
M36%R<75E<B!A=F5C(&0G875T<F5S(.ET:7%U971T97,@*&5X+CH@26UP;W)T
M86YT+U+I<&]N9'4I`,YL97,@36%R<VAA;&P`36%R=&EN:7%U90!#:&%M<',@
M87!P87)E;G3I<P!-875R:71A;FEE`,YL92!-875R:6-E`$-RZ61I="!M87AI
M;75M(&%L;&]UZ2X`3&EM:71E(&1U(&UE<W-A9V4@9.EP87-SZ64N`%1E;7#I
M<F%T=7)E(&UA>&EM86QE(&1E<R`R-"!D97)N:>AR97,@:&5U<F5SH#H@`%1E
M;7#I<F%T=7)E(&UA>&EM86QE(&1E<R`V(&1E<FYIZ')E<R!H975R97.@.B``
M3F]M8G)E(&UA>&EM=6T@9&4@8FQO8W,@9'4@<&]R=&%I;`!,;VYG=65U<B!M
M87AI;75M`$UA:0!-87EO='1E`$WI9&EC86UE;G0`365M8G)E<P!4>7!E(&1E
M(&UE;G6@.@!&=7-I;VYN97(@;&5S(&-E;&QU;&5S`$UE<W-A9V4`5NER:69I
M8V%T:6]N(&1U(&UE<W-A9V4@<NEU<W-I92P@;6%I<R!L92!C97)T:69I8V%T
M(&1U('-I9VYA=&%I<F4@;B=A('!A<R!P=2#J=')E(';I<FEF:>DN`$UE<W-A
M9V4@97AP:7+I+@!4>7!E(&1E(&UE<W-A9V4`3>ETZ6\@365T87(`3&4@8FQO
M8R"K($UE=&%R(+L@;B=E<W0@<&%S(&1I<W!O;FEB;&4N`$QE(&)L;V,@JR!-
M971A<B"[(&XG97-T('!A<R!D:7-P;VYI8FQE+B`@3&5S(&3I=&%I;',@;VYT
M(.ETZ2!C;VYS:6=NZ7,@<&]U<B!L)V%D;6EN:7-T<F%T975R+@!-971A<D1"
M(&XG97-T('!A<R!C;VYN96-TZ2X`3>ET:&]D90!,82!MZ71H;V1E(*N@)7.@
MNR!N)V5S="!P87,@9.EF:6YI90!-Z71H;V1E(&YO;B!DZ69I;FEE+B!-Z71H
M;V1E(&%P<&5LZ66@.B`E<P!-Z71R:7%U90!-97AI<75E`,ET871S(&;I9.ER
MZ7,@9&4@36EC<F]NZ7-I90!-:6QI974`5'EP92!-24U%`%1E;7#I<F%T=7)E
M(&UI;FEM=6T@9&5S(#(T(&1E<FYIZ')E<R!H975R97.@.B``5&5M<.ER871U
M<F4@;6EN:6UU;2!D97,@-B!D97)N:>AR97,@:&5U<F5SH#H@`$QA(&1U<NEE
M(&UI;FEM86QE(&1U(&UO="!D92!P87-S92!N)V$@<&%S(&5N8V]R92!E>'!I
M<ND`36ER;VER`%9A<FGI<P!,92!P87%U971A9V4@2%144%]R97%U97-T(%!%
M05(@97-T(&UA;G%U86YT+@!#;VYF:6=U<F%T:6]N(&EN97AI<W1A;G1E+B!6
M;W5S(&1E=F5Z(&QA(&?I;NER97(@;6%I;G1E;F%N="!S:2!V;W5S('9O=6QE
M>B!U=&EL:7-E<B!C971T92!A<'!L:6-A=&EO;BX`240@9'4@;65S<V%G92!M
M86YQ=6%N="X`3&4@<&%Q=65T86=E(%!%05(@36%I;"!E<W0@;6%N<75A;G0N
M`$E$(&1E('-E<W-I;VX@;6%N<75A;G0N`$QU`$-O=7)R:65L('-A;G,@9FEL
M`$UO9.ERZ0!$871E(&1E(&UO9&EF:6-A=&EO;@!-;V1I9FEE<B!L)U523`!-
M;V1U;&\`36]L9&%V:64`36]N86-O`$UO;F=O;&EE`$UO:7,@970@86YNZ64`
M365N<W5E;&QE;65N=`!-;VYT<V5R<F%T`%!H87-E<R!D92!L82!L=6YE`$-H
M86UP<R!S=7!P;.EM96YT86ER97,@=')O=7;I<R#@(&QA(&QI9VYE("5D("AA
M='1E;F1U<R`E9"DN`$UA<F]C`$?I;NER86QE;65N="!E;G-O;&5I;&SI`$?I
M;NER86QE;65N="!N=6%G975X`%!R:6YC:7!A;&5M96YT(&YU86=E=7@@970@
M=F5N=&5U>`!'Z6[I<F%L96UE;G0@96YS;VQE:6QLZ0!697)S(&QE(&)A<P!$
MZ7!L86-E<B#@(&=A=6-H90!$Z7!L86-E<B#@(&1R;VET90!697)S(&QE(&AA
M=70`5F5R<R!L92!B87,`5F5R<R!L92!H875T`$UO>F%M8FEQ=64`3&ES=&5S
M(&3I<F]U;&%N=&5S(&UU;'1I+6YI=F5A=7@`0V%R=&4@JZ!-=6QT:6UA<"!5
M2Z"[`%/I;&5C=&EO;B!M=6QT:7!L90!087)A;>ET<F%G92!D=2!C;VUP=&4`
M365S(&1O;F[I97,@<&5R<V]N;F5L;&5S`$UO;B!P;W)T86EL`%!RZ7-E;G1A
M=&EO;B!D92!M;VX@<&]R=&%I;`!":7)M86YI90!.3TXL(&IE(&XG86-C97!T
M92!P87,`3F]M`$YA;6EB:64`3F%U<G4`3NEP86P`4&%Y<RU"87,`06YT:6QL
M97,@;NEE<FQA;F1A:7-E<P!54DP@9&4@8F%S92!D92!.971S8V%P90!54DP@
M9&4@<NEV;V-A=&EO;B!D92!L)T$N0RX@3F5T<V-A<&4`55),(&1E(&QA('!O
M;&ET:7%U92!D)T$N0RX@3F5T<V-A<&4`55),(&1E(')E;F]U=F5L;&5M96YT
M($YE='-C87!E`%523"!D92!RZ79O8V%T:6]N($YE='-C87!E`$YO;2!D=2!S
M97)V975R(%-33"!.971S8V%P90!#;VUM96YT86ER92!D=2!C97)T:69I8V%T
M($YE='-C87!E`%1Y<&4@9'4@8V5R=&EF:6-A="!.971S8V%P90!2Z7-E874`
M2F%M86ES`$YO=79E;&QE+4-A;.ED;VYI90!.;W5V96QL92!C873I9V]R:64`
M3F]U=F5L;&4@;'5N90!.;W5V96%U(&YO;2!D92!C;VYN97AI;VX@*&9A8W5L
M=&%T:68I`$YO=79E;&QE+5KI;&%N9&4`3F]U=F5A=2!M;W0@9&4@<&%S<V4`
M3&4@;F]U=F5A=2!M;W0@9&4@<&%S<V4@97AP:7)E<F$@;&4@)7@N`$QE<R!N
M;W5V96%U>"!M;W1S(&1E('!A<W-E(&1I9F;H<F5N="X`3F]U=F5L;&4@9F5N
MZG1R92`H7V)L86YK*0!.;W5V96QL97,`1F]R=6US`%-U:79A;G0`-"!P:&%S
M97,@<W5I=F%N=&5S`$]P=&EO;G,@<W5I=F%N=&5S`%-U:79A;G0^`$YI8V%R
M86=U80!.:6=E<@!.:6=E<FEA`$YU:70`3FEU90!.;VX`4&%S(&1E(&1O;F[I
M97,@9&4@8V]N9FEG=7)A=&EO;B!P;W5R(&QE<W%U96QL97,@;6]N=')E<B!L
M97,@9&EF9NER96YC97,N`%!A<R!D92!S=')A=.EG:64@9&ES<&]N:6)L92!P
M;W5R(&9A:7)E(&1E<R!I;6%G97,@25-/+@!087,@9&4@9V%B87)I="!E;B!T
M<F%I=&5M96YT('!A<B!L;W0N`$%U8W5N(&)L;V,@;B=E>&ES=&4@X"!L82!P
M;W-I=&EO;B!D96UA;F3I90!087,@9&4@;F]M(&1E(&-A;&5N9')I97(@9F]U
M<FYI('!O=7(@;"=A=71H96YT:69I8V%T:6]N('!A<B!-0T%,+@!.;VX@;6]D
M:69IZ2X`075C=6YE('-O=7,M<&5R;6ES<VEO;B!N)V$@8F5S;VEN(&0GZG1R
M92!A:F]U=.EE('-O=7,@8V4@;FEV96%U+@!!=6-U;F4@:6YF;W)M871I;VX@
M9&4@8V]N9FEG=7)A=&EO;B!S<.EC:69IZ64@<&]U<B`E<RX`075C=6YE(&EN
M9F]R;6%T:6]N(&1E(&-O;F9I9W5R871I;VX@9F]U<FYI92!P;W5R($944"!6
M1E,N`$%U8W5N92!I;F9O<FUA=&EO;B!D92!C;VYF:6=U<F%T:6]N(&9O=7)N
M:64@<&]U<B!344P@5D93+@!!=6-U;F4@:6YF;W)M871I;VX@9&4@8V]N9FEG
M=7)A=&EO;B!F;W5R;FEE('!O=7(@4U%,+49I;&4@5D93+@!!=6-U;B!C<NED
M:70@9&ES<&]N:6)L92X`075C=6YE(&1E<W1I;F%T:6]N('1R;W5VZ64N`$%U
M8W5N(&9I8VAI97(@96YV;WGI`$%U8W5N(&EC]&YE('1R;W5VZ2X`075C=6X@
M;&EE=2!N)V5S="!SZ6QE8W1I;VYNZ0!!=6-U;B!E;7!L86-E;65N="!N)V5S
M="!I;F1I<77I+@!!=6-U;B!M97-S86=E(&9O=7)N:0!!=6-U;B!N;VT@<W#I
M8VEF:>DN`$%U8W5N(&YO;6)R92!S<.EC:69IZ2X`4&%S(&0G87!H;W)I<VUE
M<R!C:&]Q=6%N=',`075C=6X@;6]T(&1E('!A<W-E(&9O=7)N:2!P;W5R(&PG
M875T:&5N=&EF:6-A=&EO;B!P87(@2%144"X`075C=6X@;6]T(&1E('!A<W-E
M(&9O=7)N:2!P;W5R(&PG875T:&5N=&EF:6-A=&EO;B!P87(@24U!4"X`075C
M=6X@;6]T(&1E('!A<W-E(&9O=7)N:2!P;W5R(&PG875T:&5N=&EF:6-A=&EO
M;B!P87(@2V5R8F5R;W,N`$%U8W5N(&UO="!D92!P87-S92!S<.EC:69IZ2!P
M;W5R(&PG875T:&5N=&EF:6-A=&EO;BX`075C=6X@;6]T(&1E('!A<W-E('-P
MZ6-I9FGI('!O=7(@;"=A=71H96YT:69I8V%T:6]N(%!!4U-71"X`075C=6X@
M;6]T(&1E('!A<W-E('-PZ6-I9FGI('!O=7(@;"=A=71H96YT:69I8V%T:6]N
M(%--0BX`075C=6X@8VAE;6EN('9E<G,@;&4@8FEN86ER92!/<&5N4U-,(&9O
M=7)N:2X@3&4@8FEN86ER92!D)T]P96Y34TP@97-T(&[I8V5S<V%I<F4@<&]U
M<B!F;VYC=&EO;FYE<B!A=F5C(&1E<R!D;VYNZ65S(%!+0U,@,3(N`$%U8W5N
M92!C;VYF:7)M871I;VX@96X@871T96YT90!087,@9&4@<75O=&$@<&]S:71I
M;VYNZ2X`4&%S(&1E('+H9VQE<P!!=6-U;B!SZ7!A<F%T975R('-PZ6-I9FGI
M+@!087,@9&4@8_1TZ7,`1FEC:&EE<B!I;F5X:7-T86YT`$%U8W5N('+I<&5R
M=&]I<F4@=&5M<&]R86ER92!E<W0@9&ES<&]N:6)L92!P;W5R(&QA(&-A8VAE
M`$%U8W5N(&YO;2!D)W5T:6QI<V%T975R(&5T("]O=2!M;W0@9&4@<&%S<V4@
M96YV;WGI+@!!=6-U;F4@9&]N;NEE(%A-3"!V86QI9&4@;B=A(.ETZ2!R971O
M=7)NZ64`4&%S(&1E('9A;&5U<@!087,@9&4@=F5R<VEO;B!T<F]U=NEE(&1A
M;G,@;&$@8V]N9FEG=7)A=&EO;B!O<FEG:6YA;&4N(%+I9^ENZ7)E>B!L82!C
M;VYF:6=U<F%T:6]N+@!087,@9&4@=F5R<VEO;B!T<F]U=NEE(&1A;G,@=F]T
M<F4@8V]N9FEG=7)A=&EO;BX@4NEGZ6[I<F5Z(&QA(&-O;F9I9W5R871I;VXN
M`$%U8W5N`$%U8W5N("AU=&EL:7-E<B!I;7!L:6-I=&5M96YT*0!.;W)D:7%U
M92`H25-/+3@X-3DM,3`I`,YL92!.;W)F;VQK`$CI;6ES<&CH<F4@3F]R9`#.
M;&5S($UA<FEA;FYE<R!D=2!N;W)D`$YO<G;H9V4`4&%S(&%P<NAS`%!A<R!A
M=F%N=`!087,@=6X@9&]S<VEE<@!.;VX@:6UP;.EM96YTZ2X`26YA8W1I9@!.
M;VX@<')I<R!E;B!C;VUP=&4N`$YO=&5S`%)I96X@X"!N879I9W5E<BP@<F5T
M;W5R;F5Z(&5N(&%R<FGH<F4N`$YO=F5M8G)E`$YO;6)R90!.;VUB<F4@9&4@
M8V%R86-TZ')E<P!.;VUB<F4@9&4@8V]L;VYN97,`3F]M8G)E(&1E(')A;F?I
M97,`3F]M8G)E(&YO;B!S<.EC:69IZ2!P;W5R(&QA(&UI<V4@X"!J;W5R(&1E
M(&QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO;BX`3TL`3V)J970`0W+I871E=7(@
M9"=O8FIE=`!/8W1A;`!/8W1O8G)E`$9I;'1R92!A;G1I+6]F9F5N<V%N=`!"
M=7)E874`3"=A;F-I96X@970@;&4@;F]U=F5A=2!M;W1S(&1E('!A<W-E(&1O
M:79E;G0@ZG1R92!D:69FZ7)E;G1S+@!!;F-I96X@;6]T(&1E('!A<W-E`$PG
M86YC:65N(&UO="!D92!P87-S92!E<W0@:6YC;W)R96-T`$]M86X`4V5U;"!L
M97,@<V5R=F5U<G,@24U!4"!S=7!P;W)T96YT(&QE<R!D;W-S:65R<R!P87)T
M86?I<RX`4V5U;&5M96YT(&QE<R"KH&9O<G1U;F5SH+L@;V9F96YS86YT97,`
M56YE('-E=6QE(&%D<F5S<V4@9&4@8V]U<G)I96P@<&5R;6ES92X`4V5U;',@
M;&4@<')O<')IZ71A:7)E(&]U(&PG861M:6YI<W1R871E=7(@<WES=.AM92!P
M975T(&UO9&EF:65R(&QE<R!P97)M:7-S:6]N<R!D)W5N('!A<G1A9V4N`$]U
M=G)I<B!D86YS('5N92!N;W5V96QL92!F96[J=')E`$5R<F5U<B!/<&5N4U-,
MH#H@:6UP;W-S:6)L92!D)V5X=')A:7)E(&QE<R!D;VYNZ65S(&1E(&QA('!A
M<G1I92!S:6=NZ64@4R]-24U%`$]U=G)I<B!L97,@;&EE;G,@9&%N<R!U;F4@
M;F]U=F5L;&4@9F5NZG1R90!3>7-TZ&UE(&0G97AP;&]I=&%T:6]N`$]P=&EO
M;G,`3W!T:6]N<R!P;W5R("5S`$QI<W1E(&YU;>ER;W3I90!/<F=A;FES871I
M;VX`56YI=.D@;W)G86YI<V%T:6]N;F5L;&4`3W)G86YI<V%T:6]N`$UO9.AL
M92!O<FEG:6YA;"!D)V%P<&QI8V%T:6]N`$UO9.AL97,@;W)I9VEN875X(&1A
M;G,@)7.@.@!!=71R90!!=71R97,@:6YF;W)M871I;VYS`%!E<FUI<W-I;VYS
M(&1U('!R;W!R:>ET86ER90!,)V%U=&AE;G1I9FEC871I;VX@4$%-(&XG97-T
M('!A<R!D:7-P;VYI8FQE+@!-;V1U;&4@4$5!4CHZ36%I;`!3:6=N871U<F4@
M;G5MZ7)I<75E(%!'4`!$;VYNZ65S(%!'4"!C:&EF9G+I97,`0VQE9B!P=6)L
M:7%U92!01U``1&]N;NEE<R!01U`@<VEG;NEE<R]C:&EF9G+I97,`0V]D92!0
M2%``26YT97)P<NET975R(%!(4`!0;'5I92!LZ6?H<F4@;"=A<'+H<RUM:61I
M`%!L=6EE(&PG87!RZ',M;6ED:0!!=F5R<V5S(&PG87!RZ',M;6ED:0!.96EG
M92!L)V%P<NAS+6UI9&D`0VAU=&5S(&1E(&YE:6=E(&PG87!RZ',M;6ED:0!3
M;VQE:6P@;"=A<'+H<RUM:61I`$]R86=E<R!L)V%P<NAS+6UI9&D`17AT96YS
M:6]N(%!/4TE8(&%B<V5N=&4`26YT97)P<NET975R(%!?2%``4F5M<&QI<W-A
M9V4`4&%K:7-T86X`0F5L874`4&%L97-T:6YE("AT97)R:71O:7)E(&]C8W5P
MZ2D`4&%N86UA`%!A<&]U87-I92U.;W5V96QL92U'=6ENZ64`4&%R86=U87D`
M4&%R=&EE;&QE;65N="!N=6%G975X`$UO="!D92!P87-S90!#:&%N9V5M96YT
M(&1U(&UO="!D92!P87-S92!E9F9E8W1UZ2X`36]T(&1E('!A<W-E(&EN8V]R
M<F5C=`!-;W0@9&4@<&%S<V4@<F5Q=6ES('!O=7(@;"=A=71H96YT:69I8V%T
M:6]N(%)!1$E54RX`36]T(&1E('!A<W-E(&%V96,@8V]N9FER;6%T:6]N`$UO
M="!D92!P87-S9:`Z`$UO="!D92!P87-S9:`Z(`!,97,@;6]T<R!D92!P87-S
M92!D;VEV96YT(.IT<F4@:61E;G1I<75E<RX`0V]L;&5R`$-O;&QE<B!D97!U
M:7,@;&4@<')E<W-E+7!A<&EE<G,`0VAE;6EN`$-O;F9I<FUA=&EO;G,@96X@
M871T96YT9:`Z`%!E<G-O;FYE<P!0;W5R8V5N=&%G90!%9F9E8W1U97(@;&5S
M(&]PZ7)A=&EO;G,@9&4@;6%I;G1E;F%N8V4`169F96-T=65R(&QE<R!O<.ER
M871I;VYS(&1E(&UA:6YT96YA;F-E(.`@;&$@8V]N;F5X:6]NH#\`4&5R;6ES
M<VEO;@!,82!P97)M:7-S:6]N(*N@)7.@NR!N)V5S="!P87,@<W5P<')I;>EE
M+@!097)M:7-S:6]N(')E9G5SZ64`4&5R;6ES<VEO;G,`061M:6YI<W1R871I
M;VX@9&5S('!E<FUI<W-I;VYS`$1O;F[I97,@<&5R<V]N;F5L;&5S`%#I<F]U
M`$%N:6UA=7@`4&AI;&EP<&EN97,`5.ELZ7!H;VYE`%!H;W1O<P!0:71C86ER
M;@!0:7AE;',`4&QA=&ET=61E<P!35E`@8VQI<75E>B!D86YS('5N92!C96QL
M=6QE`%-64"!C;VYF:7)M97H@;&$@<W5P<')E<W-I;VX@9&4@8V5T(.ELZ6UE
M;G2@.@!35E`@8V]N9FER;65Z('%U92!V;W5S('9O=6QE>B!DZ6QI97(@8V5T
M(.ELZ6UE;G0N`%9E=6EL;&5Z('-A:7-I<B!U;B!M;VES(&5T('5N92!A;F[I
M92X`5F5U:6QL97H@<V%I<VER('5N(&YO;2!P;W5R(&QA(&YO=79E;&QE(&-A
M=.EG;W)I9:`Z`%9E=6EL;&5Z(&5N=')E<B!U;F4@861R97-S92!)4"!V86QI
M9&4N`%9E=6EL;&5Z(&5N=')E<B!U;F4@9&%T92!V86QI9&6@.R!VZ7)I9FEE
M>B!L92!N;VUB<F4@9&4@:F]U<G,@9'4@;6]I<RX@`%9E=6EL;&5Z(&5N=')E
M<B!U;F4@:&5U<F4@=F%L:61E+@!6975I;&QE>B!F;W5R;FER('5N('+I<W5M
MZ2!D=2!P<F]B;.AM92X`5F5U:6QL97H@9F]U<FYI<B!V;W1R92!N;VT@9"=U
M=&EL:7-A=&5U<B!E="!V;W1R92!M;W0@9&4@<&%S<V4`5F5U:6QL97H@;&ER
M92!L92!T97AT92!S=6EV86YT+B!6;W5S(&1E=F5Z(&%C8V5P=&5R(&QE<R!C
M;VYD:71I;VYS('!O=7(@=71I;&ES97(@;&4@<WES=.AM92X`5F5U:6QL97H@
M96YT<F5R(&QE(&YO=79E874@;F]MH&1E(&QA(&-A=.EG;W)I9:`Z`%!O;&]G
M;F4`4&]L:71I<75E`%-C<G5T:6YS`%!O<G1U9V%L`%!O<VET:6]N(&1E(&-E
M='1E(&EM86=E`%!O<VET:6]N(&1E(&-E('1A8FQE874`16YV;WEE<B#@(&-E
M(&1O<W-I97(@*&YO;B!A<'!L:7%UZ2!P87(@24U!4"D`4'+I8VEP:71A=&EO
M;G,@<&]U<B!L97,@)7,@9&5R;FGH<F5S(&AE=7)E<Z`Z(`!0<F]B86)I;&ET
MZ3QB<B`O/F1E('!L=6EE`%!R969S7VQD87"@.B!E>'1E;G-I;VX@<F5Q=6ES
M92!,1$%0(&YO;B!T<F]U=NEE+@!0<F5F<U]S97-S:6]NH#H@97AT96YS:6]N
M(')E<75I<V4@JZ!S97-S:6]NH+L@;F]N('1R;W5VZ64N`%!R97-S:6]N`%!R
M97-S:6]N(&%U(&YI=F5A=2!D92!L82!M97*@.B``4')E<W-I;VZ@.B``07!E
M<N=U`$%P97+G=2!D92!L)VEM86=E(&1A;G,@=6YE(&YO=79E;&QE(&9E;NIT
M<F4`3W!T:6]N<R!P<NECZ61E;G1E<P!);7!R:6UE<B!L92!D;V-U;65N=`!#
M;&5F('!R:7;I90!0<F]B;.AM90!$97-C<FEP=&EO;B!D=2!P<F]B;.AM90!0
M<F]J971S`%1E>'1E(&-O=7)T`$-L968@<'5B;&EQ=64`06QG;W)I=&AM92!D
M92!C;&5F('!U8FQI<75E`$EN9F]R;6%T:6]N<R!S=7(@;&$@8VQE9B!P=6)L
M:7%U90#)8VAE8R!D92!L82!GZ6[I<F%T:6]N(&1E(&QA('!A:7)E(&1E(&-L
M969S('!U8FQI<75E+W!R:7;I92X`4&]R=&\@4FEC;P!0=7)G97(@;&5S(&UE
M<W-A9V5S`%%A=&%R`%)E<77J=&4`475O=&$`0VQE9B!P=6)L:7%U92!24T$@
M*"5D(&)I=',I`%/I;&5C=&EO;B!R861I;P!0;'5I90!0;'5I92!T]'0@;&4@
M;6%T:6X`4&QU:64@=&%R9"!D86YS(&QA(&IO=7)NZ64`079E<G-E<P!0;'5I
M92!E="!N96EG90!0;'5I92!P=6ES(&YE:6=E`$%P:&]R:7-M92!A=2!H87-A
M<F0`5&%U>`!,:7)E`$UE<W-A9V5S(&QU<P!3=7!P<F5S<VEO;B!DZ69I;FET
M:79E(&1E("5SH#\`4W5P<')E<W-I;VX@9.EF:6YI=&EV92!D97,@9&]N;NEE
M<R!P;W5R(&PG=71I;&ES871E=7(@)7.@/R!#971T92!O<.ER871I;VX@97-T
M(&3I9FEN:71I=F4N`%)E<')E;F1R92!V;W1R92!D97)N:>AR92!A8W1I;VX`
M4F%F<F'N8VAI<@!2869R8>YC:&ER(&QE<R#I;.EM96YT<R!D=2!M96YU(&1Y
M;F%M:7%U9:`Z`%)A9G)A[F-H:7(@;"?I8W)A;B!D=2!S;VUM86ER9:`Z`$5X
M<')E<W-I;VX@<F%T:6]N;F5L;&4`3F%V:6=A=&5U<B!R96QA=&EO;FYE;`!2
M96-H87)G97(`4F5M87)Q=65S`%-E<G9E=7)S(&1I<W1A;G1S`%523"!D:7-T
M86YT92`H:'1T<#HO+W=W=RYE>&5M<&QE+F-O;2]H;W)D92\IH#H`4F5T:7)E
M<@!2971I<F5R(&QE(&)L;V,`4F5T:7)E<B!L82!C;VQO;FYE`%)E=&ER97(@
M;&4@9F]R;6%T86=E`%)E=&ER97(@;&$@<&%I<F4`16YL979E<B!L92!S8W)I
M<'0@96YR96=I<W1RZ2!D=2!RZ7!E<G1O:7)E('1E;7!O<F%I<F4@9'4@<V5R
M=F5U<BX`4F5T:7)E<B!L90!2971I<F5R(&-E(&YO975D(&1U(&1O8W5M96YT
M`%)E=&ER97(@;"=U=&EL:7-A=&5U<@!2971I<F5R(&PG=71I;&ES871E=7*@
M.B`E<P!!=6-U;F4@<NEP;VYS92#@('9O=')E(')E<77J=&4N($-O9&4@9"=E
M<G)E=7(@<F5T;W5R;NF@.B``3&4@<V5R=FEC92!D96UA;F3I(&5S="!I;G1R
M;W5V86)L92X`3&4@<&%R86WH=')E(&]B;&EG871O:7)E(*N@)7.@NR!N)V5S
M="!P87,@<W#I8VEF:>D@9&%N<R!L82!C;VYF:6=U<F%T:6]N("5S+@!,92!P
M87)A;>AT<F4@;V)L:6=A=&]I<F4@JZ`E<Z"[(&XG97-T('!A<R!S<.EC:69I
MZ2!D86YS(&QA(&-O;F9I9W5R871I;VX@9'4@5D93+@!,92!P87)A;>AT<F4@
M;V)L:6=A=&]I<F4@JZ`E<Z"[(&XG97-T('!A<R!S<.EC:69IZ2!D86YS(&QA
M(&-O;F9I9W5R871I;VXN`$-H86UP(&]B;&EG871O:7)E`%+`6@!296UI<V4@
MX"!ZZ7)O(&1U(&UO="!D92!P87-S90!296UE='1R92#@('KI<F\@=F]T<F4@
M;6]T(&1E('!A<W-E`%)E=F5N:7(@X"!L82!D97)N:>AR92!R97%UZG1E`%+I
M<W5L=&%T<P!2979E;FER(&%U>"!O<'1I;VYS`%+I+65N=')E<B!L92!N;W5V
M96%U(&UO="!D92!P87-S90!2Z75N:6]N`%)E=F5N:7(@X"!L82!C;VYF:6=U
M<F%T:6]N('!RZ6/I9&5N=&4`3W!T:6]N<R!D92!L)^ED:71E=7(@4FEC:"!4
M97AT`$1E=FEN971T97,`1')O:71E`$5N=.IT92!D92!D<F]I=&4`5F%L975R
M<R!C;W)R96-T97,`4')O<')IZ73I<R!D92!L82!R86Y?9^EE("XN+@!2]&QE
M`%)O=6UA;FEE`%!I=F]T97(@,3@P`%!I=F]T97(@X"!G875C:&4`4&EV;W1E
M<B#@(&1R;VET90!0<F]P<FGI=.ES(&1E(&QA(')A;F?I90!0<F]P<FGI=.ES
M(&1E(&QA(')A;F?I90!286YGZ65SH#H`4NAG;&5S`$1E<R!F:6QE=',@87!P
M87)A[G1R;VYT(&5N=')E('1O=71E<R!L97,@<F%N9^EE<R!E="!L97,@8V]L
M;VYN97,`1&5S(&9I;&5T<R!A<'!A<F'N=')O;G0@96YT<F4@;&5S(&-O;&]N
M;F5S('-E=6QE;65N=`!$97,@9FEL971S(&%P<&%R8>YT<F]N="!E;G1R92!L
M97,@<F%N9^EE<R!S975L96UE;G0`3&%N8V5R`%)U<W-I90!2=V%N9&$`4VEG
M;F%T=7)E(.EL96-T<F]N:7%U92!3+TU)344`365S<V%G92!C:&EF9G+I(%,O
M34E-10!,)V%U=&AE;G1I9FEC871I;VX@4T%33"!N)V5S="!P87,@9&ES<&]N
M:6)L90!-97-S86=E<FEE(%--4P!);G1E<G!RZ71E=7(@4U%,`$]R9')E(%-1
M3"!P;W5R(')E=&]U<FYE<B!L97,@=F%L975R<P!34T@`4U5#0\A3`$EN=&5R
M<'+I=&5U<B!37U%,`%-A`%-A:6YT92U(Z6SH;F4`4V%I;G0M0VAR:7-T;W!H
M92UE="U.:>EVZ',`4V%I;G1E+4QU8VEE`%-A:6YT+5!I97)R92!E="!-:7%U
M96QO;@!386EN="U6:6YC96YT+65T+6QE<R!'<F5N861I;F5S`$WJ;64@8V%D
M<F4@*%]S96QF*0!386UO82!O8V-I9&5N=&%L97,`4V%I;G0M36%R:6X`4V%O
M+51O;>DM970M4')I;F-I<&4`1F]U<FYI<W-E=7(@<V%T96QL:71E`$%R86)I
M92!386]U9&ET90!%;G)E9VES=')E<@!%;G)E9VES=')E<B"KH"5SH+L`16YR
M96=I<W1R97(@)7,`16YR96=I<W1R97(@;&5S(&]P=&EO;G,`16YR96=I<W1R
M97(@;&$@8V]N9FEG=7)A=&EO;B!GZ6[I<NEE(&-O;6UE('5N('-C<FEP="!0
M2%`@9&%N<R!L92!RZ7!E<G1O:7)E('1E;7!O<F%I<F4@9&4@=F]T<F4@<V5R
M=F5U<BX`16YR96=I<W1R97(@;&$@8V]N9FEG=7)A=&EO;B!D92`E<P!38W)I
M<'0@9&4@;6ES92#@(&IO=7(@9&4@8V]N9FEG=7)A=&EO;B!E;G)E9VES='+I
M('-O=7.@.B"K("5SH+L`3W)A9V5S(&ES;VSI<P!38VEE;F-E`%)E8VAE<F-H
M90!-;W1E=7)S(&1E(')E8VAE<F-H90!#:&]I<VES<V5Z(&QE<R!F:6-H:65R
M<P!3Z6QE8W1I;VYN97H@=6YE(&1A=&4`4^EL96-T:6]N;F5Z('5N(&=R;W5P
M92#@(&%J;W5T97(`4^EL96-T:6]N;F5Z('5N(&YO=79E874@<')O<')IZ71A
M:7)E`%/I;&5C=&EO;FYE>B!U;B!S97)V975R`%/I;&5C=&EO;FYE>B!U;B!U
M=&EL:7-A=&5U<B#@(&%J;W5T97(`5&]U="!SZ6QE8W1I;VYN97(`4^EL96-T
M:6]N;F5Z('1O=71E<R!L97,@8V]M<&]S86YT97,@9&4@;&$@9&%T92X`0VAO
M:7-I<W-E>B!U;B!O8FIE=`!.92!SZ6QE8W1I;VYN97(@875C=6X`4^EL96-T
M:6]N;F5Z(&QE<R!C87)A8W3H<F5S(&1O;G0@=F]U<R!A=F5Z(&)E<V]I;B#@
M(&PG86ED92!D92!L)V]U=&EL(&-I+61E<W-O=7,N(%9O=7,@<&]U=F5Z(&5N
M<W5I=&4@;&5S(&-O<&EE<B!E="!L97,@8V]L;&5R(&1A;G,@=F]T<F4@=&5X
M=&4N`%/I;&5C=&EO;FYE>B!L92!DZ6QI;6ET975R(&1E(&1A=&6@.@!3Z6QE
M8W1I;VYN97H@;&4@9F]R;6%T(&1E(&1A=&6@.@!3Z6QE8W1I;VYN97(@;&4@
M<')O9FEL('%U92!V;W5S(&3I<VER97H@;6]D:69I97(Z`%/I;&5C=&EO;FYE
M>B!L92!DZ6QI;6ET975R(&0G:&5U<F6@.@!3Z6QE8W1I;VYN97H@;&4@9F]R
M;6%T(&1E(&PG:&5U<F6@.@!3Z6QE8W1I;VYN97H@9&5U>"!C:&%M<',@87!P
M87)E;G3I<RX`4^EL96-T:6]N;F5Z('9O=')E('1HZ&UE(&1E(&-O=6QE=7)S
M+@!3Z6QE8W1I;VYN97H@=F]T<F4@;&%N9W5E('!RZ6;I<NEEH#H`16YV;WEE
M<B!L92!R87!P;W)T(&0G86YO;6%L:64`16YV;WEE<B!335,`4^ENZ6=A;`!3
M;VYD9:`Z(`!397!T96UB<F4`4V5R8FEE(&5T($UO;G1E;F5G<F\`3G5MZ7)O
M(&1E('/I<FEE`$QE<R!D;VYNZ65S(&1U('-E<G9E=7(@<V]N="!F875S<V5S
M(&]U(&YO;B!D:7-P;VYI8FQE<RX`061M:6YI<W1R871I;VX@9&5S('-E<W-I
M;VYS`$ED+B!D92!S97-S:6]N(&5X<&ERZ2X`4V5S<VEO;G,`4^EL96-T:6]N
M;F5R`$-O;F9I9W5R97(@;&5S(&]P=&EO;G,@<&]U<B!V;W5S('!E<FUE='1R
M92!D92!R96UE='1R92#@('KI<F\@=F]T<F4@;6]T(&1E('!A<W-E('-I(&IA
M;6%I<R!V;W5S(&PG;W5B;&EE>BX`0V]N9FEG=7)E<B!L97,@<V5R=F5U<G,@
M9&ES=&%N=',@86-C97-S:6)L97,@9&5P=6ES('9O=')E('!O<G1A:6PN`%/I
M;&5C=&EO;FYE>B!V;W1R92!L86YG=64@<'+I9NERZ64L(&9U<V5A=2!H;W)A
M:7)E(&5T(&QE<R!O<'1I;VYS(&1E(&1A=&4N`$3I9FEN:7-S97H@;&$@<')E
M;6GH<F4@87!P;&EC871I;VX@;&%N8^EE+"!L92!T:.AM92!D92!C;W5L975R
M<RP@;&4@<F%F<F'N8VAI<W-E;65N="!D97,@<&%G97,L(&5T(&0G875T<F5S
M(&]P=&EO;G,@9"=A9F9I8VAA9V4N`$-O;F9I9W5R871I;VX`4V-R:7!T(&1E
M(&-O;F9I9W5R871I;VX@9&4@;6ES92#@(&IO=7(@9&ES<&]N:6)L90!0;'5S
M:65U<G,@96YD<F]I=',@<&]S<VEB;&5S(&%V96,@;&4@<&%R86WH=')EH#H@
M`%-E>6-H96QL97,`06-H870`4NES=6WI`$1O:70M;VX@9.EF:6YI<B!D97,@
M=&]U8VAE<R!D92!R86-C;W5R8VES('!O=7(@;&$@<&QU<&%R="!D97,@;&EE
M;G.@/P!!9F9I8VAE<@!-;VYT<F5R(&QE<R!D:69FZ7)E;F-E<R!E;G1R92!L
M82!C;VYF:6=U<F%T:6]N(&5N<F5G:7-T<NEE(&%C='5E;&QE;65N="!E="!C
M96QL92!N;W5V96QL96UE;G0@9^ENZ7+I92X`36]N=')E<B!L)VAE=7)E(&1E
M(&QA(&1E<FYIZ')E(&-O;FYE>&EO;B#@(&PG96YT<NEEH#\`36]N=')E<B!L
M)V]P=&EO;B!D92!C;VYS97)V97(@;"=O<FEG:6YA;`!-;VYT<F5R(&QE('/I
M;&5C=&5U<@!!9F9I8VAE<B!L82!B87)R92!D92!M96YU(&1E('1A8FQE875X
MH#\`069F:6-H97(@;&4@;65N=2`E<R#@(&=A=6-H9:`_`$%F9FEC:&5R(&QA
M(&)O[G1E(&1E(&1I86QO9W5E('1A8FQE874@8V5L;'5L90!!9F9I8VAE<B!L
M82!B;^YT92!D92!D:6%L;V=U92!D97,@<')O<')IZ73I<R!D=2!T86)L96%U
M`$%F9FEC:&5R(&QA(&)O[G1E(&1E(&1I86QO9W5E(&1E<R!P<F]P<FGI=.ES
M(&1E(&QA(')A;F?I92!D=2!T86)L96%U`$%F9FEC:&5R(&QA(&)O[G1E(&1E
M(&1I86QO9W5E(&1E<R!P<F]P<FGI=.ES(&1E(&PG:6UA9V4`069F:6-H97(@
M;"=E;G9O:2!D92!F:6-H:65R`$%V97)S97,`079E<G-E<R!T]'0@9&%N<R!L
M82!J;W5R;NEE`$%V97)S97,@=&%R9"!E;B!J;W5R;NEE`$%V97)S97,@875X
M(&%L96YT;W5R<P!297-S97)R97(`4F5S<V5R<F5R(&]U(&3I9V%G97(@9"=A
M8F]R9"!L92AS*2!B;&]C*',I('9O:7-I;BAS*0!3:65R<F$@3&5O;F4`4R=I
M;G-C<FER90!3:6=N871U<F4`06QG;W)I=&AM92!D92!S:6=N871U<F4`4VEN
M9V%P;W5R`%1A:6QL90!!;FYU;&5R(&QA(&UA:6YT96YA;F-E`%-L;W9A<75I
M90!3;&]VZ6YI90!.96EG90!!=F5R<V4@9&4@;F5I9V4`079E<G-E<R!D92!N
M96EG90!!=F5R<V5S(&1E(&YE:6=E('3T="!D86YS(&QA(&IO=7)NZ64`079E
M<G-E<R!D92!N96EG92!T87)D(&5N(&IO=7)NZ64`2&%U=&5U<B!D92!N96EG
M9:`Z(`!1=6%N=&ETZ2!D)V5A=2#I<75I=F%L96YT92#@(&QA('%U86YT:73I
M(&1E(&YE:6=EH#H@`,YL97,@4V%L;VUO;@!3;VUA;&EE`$-H86YS;VYS(&5T
M('!OZ&UE<P!3Z6QE8W1I;VX@9&4@;"=O<F1R92!D92!T<FD`061R97-S92!S
M;W5R8V4`069R:7%U92!D=2!S=60`4W5D+65U<F]PZ65N("A)4T\M.#@U.2TS
M*0!'Z6]R9VEE+61U+7-U9"!E="#N;&5S(%-A;F1W:6-H+61U+7-U9`!(Z6UI
M<W!HZ')E(%-U9`!%<W!A8V4@96YT<F4@8V5L;'5L97,@861J86-E;G1E<P!%
M<W!A8V4@96YT<F4@;&4@8V]N=&5N=2!E="!L82!B;W)D=7)E(&1A;G,@=6YE
M(&-E;&QU;&4`17-P86-E=7(`17-P86-E;65N=`!%<W!A8V5M96YT(&5T(')E
M;7!L:7-S86=E`$5S<&%G;F4`4&]U<G)I96P`0V%R86-TZ')E<R!S<.EC:6%U
M>`!38VEN9&5R(&QA(&-E;&QU;&4`4V-I;F1E<B!L82!C;VQO;FYE`%-C:6YD
M97(@;&$@<F%N9^EE`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4
M<F5K`$%N;NEE(&1E(&3I8G5T`,ET870@;W4@<')O=FEN8V4`4W1A='5T`$9O
M<FUA="!D92!S875V96=A<F1E`%)U90!"87)RZ0!,:7-T92!D92!C:&'N;F5S
M`%)E=&ER97(@;&4@9&]M86EN92!D92!L)V%D<F5S<V4`4W1Y;&4@6T-34UT`
M1&D`4V]U<RURZ7!E<G1O:7)E(*N@)7.@NR!N;VX@=')O=7;I`%-U:F5T`$5N
M=F]I`$QA(&1E;6%N9&4@9"=A:F]U="!D92"KH"5SH+L@874@<WES=.AM92!A
M(.ETZ2!S;W5M:7-E+B!6;W5S(&YE('!O=7)R97H@<&%S('9O=7,@8V]N;F5C
M=&5R(&IU<W%U)^`@<V]N(&%P<')O8F%T:6]N+@!);F1I8V4`4W5C8^AS`*N@
M)7.@NR!A(&)I96X@Z73I(&%J;W5TZ2AE*2X`3&5S(&1O;F[I97,@9&4@;"=U
M=&EL:7-A=&5U<B"KH"5SH+L@;VYT(&)I96X@Z73I(')E=&ERZ65S(&1U('-Y
M<W3H;64N+@"KH"5SH+L@82!B:65N(.ETZ2!S=7!P<FEMZ2AE*2X`JZ`E<Z"[
M(&$@8FEE;B#I=.D@<F5T:7+I*&4I+@!2971O=7(@X"!L82!C;VYF:6=U<F%T
M:6]N(&EN:71I86QE('+I=7-S:2X@(%)A9G)A[F-H:7(@;&$@<&%G92!P;W5R
M('9O:7(@;&5S(&UO9&EF:6-A=&EO;G,N`$5N<F5G:7-T<F5M96YT(&1E(&QA
M(&-O;F9I9W5R871I;VX@9&4@;&$@<V%U=F5G87)D92!RZ75S<VDN`$5N<F5G
M:7-T<F5M96YT('+I=7-S:2!D92!L82!C;W!I92!D92!S875V96=A<F1E(&1U
M(&9I8VAI97(@9&4@8V]N9FEG=7)A=&EO;B`E<RX`JZ`E<Z"[(&$@8FEE;B#I
M=.D@;6ES*&4I(.`@:F]U<BX`R6-R:71U<F4@9&4@)7,@<NEU<W-I`%-O=61A
M;@!3;VUM86ER90!,979E<B!D=2!3;VQE:6P`0V]U8VAE<B!D=2!3;VQE:6P`
M16YS;VQE:6QLZ0!,979E<B!D=2!3;VQE:6P`3&5V97(O0V]U8VAE<B!D=2!3
M;VQE:6P`3&5V97(@9'4@4V]L96EL.B``0V]U8VAE<B!D=2!3;VQE:6P`0V]U
M8VAE<B!D=2!3;VQE:6R@.B``17AP;W-A;G0`07-S:7-T86YC90!3=7)I;F%M
M(&]U($=U>6%N92!H;VQL86YD86ES90!.;VT@9&4@9F%M:6QL90#.;&5S(%-V
M86QB87)D(&5T($IA;B!-87EE;@!3=V%Z:6QA;F0`4W7H9&4`4W5I<W-E`$IO
M=7)N86P@9&4@<WEN8VAR;VYI<V%T:6]N('-U<'!R:6WI`%-Y;F--3`!%<G)E
M=7(@9&4@<WEN=&%X92!D86YS(&QE<R!T97)M97,@9&4@<F5C:&5R8VAE`%-Y
M<FEE`$]R86=E<P!/<F%G92!E="!V96YT`$]R86=E<P!/<F%G97,@;6%T:6YA
M=7@`1FEC:&EE<B!44U8`4')O<')IZ73I<R!D=2!T86)L96%U`%1A8FQE874@
M9&4@=F%L975R<P!0<F]P<FGI=.ES(&1U('1A8FQE874`5&'O=V%N`%1A[W=A
M;BP@<')O=FEN8V4@9&4@0VAI;F4`5&%J:6MI<W1A;@!486YZ86YI90!#:6)L
M9:`Z`%3B8VAE<P!.=6WI<F\@9&4@=.ELZ7!H;VYE`%1E;7#I<F%T=7)E('!O
M=7(@;&$@9&5R;FGH<F4@:&5U<F6@.B``5&5M<.ER871U<F4`5&5M<.ER871U
M<F6@.B``5&5M<.ER871U<F4\8G(@+SXH)7-(825S+R5S0F$E<RD@)F1E9SLE
M<P!0<F]F:6P@JZ`E<Z"[(&YO;B!T<F]U=ND`061M:6YI<W1R871I;VX@9&5S
M(&UO9.AL97,`5&5X=&4`5&5X=&4@<V5U;`!!;&EG;F5M96YT(&1U('1E>'1E
M`%1E>'1E(&5N(&AA=70`2F4`5&AA[R`H5$E3+38R,"D`5&AA[VQA;F1E`$PG
M97AT96YS:6]N($944"!N)V5S="!P87,@9&ES<&]N:6)L92X`3"=H:7-T;W)I
M<V%T:6]N(&5S="!DZ7-A8W1I=NEE+@!,92!M;W1E=7(@9"=I;G3I9W)A=&EO
M;B!(;W)D92]+;VQA8B!N92!S=7!P;W)T92!P87,@JZ`E<Z"[`$QE(&IO=7)N
M86P@24U34"!N)V$@<&%S('!U(.IT<F4@:6YI=&EA;&ESZ2X`3&$@8VQA<W-E
M($UA:6YT96YA;F-E.CH@;B=A('!A<R#I=.D@8VAA<F?I92!C;W)R96-T96UE
M;G0`3&$@9F5NZG1R92!D97,@;W!T:6]N<R!S)V5S="!F97)MZ64N(%-O<G1I
M92X`3"=A9&UI;FES=')A=&5U<B!D;VET(&-O;F9I9W5R97(@=6X@8F%C:V5N
M9"!P97)M86YE;G0@<&]U<B!L97,@<&5R;6ES<VEO;G,@<VD@=F]U<R!V;W5L
M97H@;&5S(&5M<&QO>65R+@!,82!B;W)D=7)E(&1U(&)A<R!S975L96UE;G0`
M3"=)1"!D=2!C;VYT86-T(&XG82!P87,@Z73I('-PZ6-I9FGI+"!L86ES<^D@
M=FED92!O=2!N)V$@<&%S(.ETZ2!T<F]U=ND@9&%N<R!L82!B87-E(&1E(&1O
M;F[I97,N`$-E(&-O;G1A8W0@82!B:65N(.ETZ2!A:F]U=.D@X"!V;W1R92!C
M87)N970@9"=A9')E<W-E<RX@`$QE(&)L;V,@9&4@<VEG;F%T=7)E(%!'4"!S
MZ7!A<ND@97-T(&[I8V5S<V%I<F4@<&]U<B!VZ7)I9FEE<B!L82!S:6=N871U
M<F4N`$PG240@9&4@;&$@;&ES=&4@;B=A('!A<R#I=.D@<W#I8VEF:>DL(&QA
M:7-SZ2!V:61E(&]U(&YO;B!T<F]U=ND@9&%N<R!L82!B87-E(&1E(&1O;F[I
M97,N`$QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO;B!N)V$@<&%S(.ETZ2!S<.EC
M:69IZ64N`$QE(&-H:69F<F5M96YT(&[I8V5S<VET92!U;F4@8V]N;F5X:6]N
M('/I8W5R:7/I92X`3&4@9FEC:&EE<B`E<R!D;VET(&-O;G1E;FER(&QE<R!O
M<'1I;VYS("5S+@!,92!F:6-H:65R("5S(&1O:70@8V]N=&5N:7(@8V5R=&%I
M;F5S(&]P=&EO;G,@)7,N`$QE(&9I8VAI97(@;F4@<&5U="!P87,@ZG1R92!C
M;W!IZ2!S=7(@;'5I+6WJ;64N`$QE(&9I8VAI97(@;F4@8V]N=&5N86ET(&%U
M8W5N92!D;VYNZ64N`$-E('%U:2!S=6ET('-O;G0@;&5S(&5N+73J=&5S('!O
M=7(@8V4@;65S<V%G92!M97-S86=E+U)&0S@R,BX`3&4@;6]D92!P;&5I;B#I
M8W)A;B!C875S92!D97,@<')O8FSH;65S(&%V96,@26YT97)N970@17AP;&]R
M97(@9/L@X"!D97,@8F]G=65S(&1U(&YA=FEG871E=7(@<75I(&XG;VYT('!U
M(.IT<F4@8V]N=&]U<F[I<RX@5F]U<R!P;W5V97H@ZG1R92!C;VYF<F]N=.ES
M(.`@9&4@;"=A9F9I8VAA9V4@9&4@8V%R86-TZ')E<R#I=')A;F=E<RP@874@
M;F]N+69O;F-T:6]N;F5M96YT(&1E<R!C97)T86EN97,@9F]N8W1I;VYS(&5T
M+V]U(&%U('!L86YT86=E(&%LZ6%T;VER92!D=2!N879I9V%T975R+B!3:2!V
M;W1R92!S>7-TZ&UE(&5S="!U;B!7:6YD;W=S(#EX+"!I;"!E<W0@='+H<R!P
M;W-S:6)L92!Q=64@=F]U<R!A=7)E>B!U;F4@)T9A=71E(&?I;NER86QE(&1E
M('!R;W1E8W1I;VXG(&5T('%U92!V;W5S(&1E=G)E>B!R963I;6%R<F5R('9O
M=')E(&]R9&EN871E=7(N7&Y<;E9O=7,@879E>B#I=.D@<'+I=F5N=7,N(%-6
M4"!A<'!U>65Z('-U<B!/2R!S:2!V;W5S('9O=6QE>B!T;W5J;W5R<R!E<W-A
M>65R(&QE(&UO9&4@<&QE:6X@Z6-R86X@9&4@;"?I9&ET975R`$PG:61E;G1I
M=.D@JZ`E<Z"[("!A(.ETZ2!S=7!P<FEMZ64N`$QE(&/T=.D@9V%U8VAE('-E
M=6QE;65N=`!,)V5M<&QA8V5M96YT(&1U('!R;V=R86UM92!';G501R!D;VET
M(.IT<F4@9F]U<FYI(.`@;&$@8VQA<W-E($-R>7!T7W!G<#HZ+@!,92!M97-S
M86=E(&5N=F]YZ2!L92`E<R#@("5S(&%V96,@8V]M;64@<W5J970@JZ`E<Z"[
M(&$@Z73I(&%F9FEC:.DN(`I);"!N)WD@82!A=6-U;F4@9V%R86YT:64@<75E
M(&-E(&UE<W-A9V4@82#I=.D@;'4@;W4@8V]M<')I<RX`3&4@;F]M(.`@=71I
M;&ES97(@96X@;&EA;G0@X"!L82!P86=E(&1E(&-O;7!O<VET:6]N`$QE(&YO
M;6)R92!D92!C:&%M<',@9&]I="#J=')E('5N(&YO;6)R92!V86QI9&4N`$QE
M(&UO9'5L92!/<&5N4U-,(&5S="!R97%U:7,@<&]U<B!L82!C;&%S<V4@2&]R
M9&5?0W)Y<'1?<VUI;64Z.BX`3&$@<'+I9NER96YC92"KH"5SH+L@;B=A('!A
M<R!P=2#J=')E(&5N<F5G:7-T<NEE(&-A<B!S82!T86EL;&4@9.EP87-S92!L
M92!M87AI;75M(&%U=&]R:7/I`$QE('!R;V=R86UM92!U=&EL:7/I('!O=7(@
M=FES=6%L:7-E<B!C92!T>7!E(&1E(&1O;F[I97,@*"5S*2!N)V$@<&%S(.ET
MZ2!T<F]U=NDN`$QE(&-A<F%C=.AR92!D92!P<F]T96-T:6]N(&1O:70@ZG1R
M92!U;B!C87)A8W3H<F4@=6YI<75E+@!,97,@8_1TZ7,@9V%U8VAE(&5T(&1R
M;VET('-E=6QE;65N=`!,92!C]'3I(&1R;VET('-E=6QE;65N=`!,92!SZ7!A
M<F%T975R(&1O:70@ZG1R92!U;B!C87)A8W3H<F4@=6YI<75E+@!,92!S97)V
M975R(*N@)7.@NR!A(.ETZ2!S=7!P<FEMZ2X`3&4@<V5R=F5U<B"KH"5SH+L@
M82#I=.D@96YR96=I<W1RZ2X`3&$@<F5Q=>IT92!D)V5N<F5G:7-T<F5M96YT
M('!O=7(@)7,@82#I=.D@9.EP;&%CZ64N`$QA(&QI9VYE(&1E;6%N9.EE("@E
M9"D@;B=E>&ES=&4@<&%S+@!,92!F:6-H:65R('1E;7!O<F%I<F4@JR`E<Z"[
M(&XG97AI<W1E('!A<RX`3&4@=&5X=&4@96YT<ND@;F4@8V]R<F5S<&]N9"!P
M87,@874@=&5X=&4@<W5R(&PGZ6-R86XN`$QE(&AA=70@970@;&4@8F%S('-E
M=6QE;65N=`!,92!H875T('-E=6QE;65N=`!,97,@9&]N;NEE<R!TZ6SI8VAA
M<F?I97,@=F5R<R!L92!S97)V975R(&]N="#I=.D@<&5R9'5E<R!D97!U:7,@
M;"?I=&%P92!P<NECZ61E;G1E+B``3&4@9FEC:&EE<B#I;6ES(&XG82!P87,@
M<'4@ZG1R92!E;G)E9VES='+I+@!,92!B;&]C(*N@=V5A=&AE<BYC;VV@NR!N
M)V5S="!P87,@9&ES<&]N:6)L92X`4NEP97)T;VER92!D97,@=&CH;65S(*N@
M)7.@NR!N;VX@=')O=7;I`$EL(&XG>2!A('!A<R!D)V]P=&EO;G,@9&ES<&]N
M:6)L97,`075C=6YE('!A<G1I92!N92!P975T(.IT<F4@869F:6-HZ64@96X@
M;&EG;F4N`$EL('D@(&$@=')O<"!D92!C87)A8W3H<F5S(&1A;G,@8V4@8VAA
M;7`N(%9O=7,@96X@879E>B!E;G1RZ2`E<Z`[(&EL(&5N(&9A=70@;6]I;G,@
M9&4@)7,N`%5N('!R;V)LZ&UE(&5S="!A<'!A<G4@;&]R<R!D92!L)V%J;W5T
M(&1E(*N@)7.@NZ`Z("5S`%5N('!R;V)LZ&UE(&5S="!A<'!A<G4@;&]R<R!D
M92!L82!S=7!P<F5S<VEO;B!D97,@9&]N;NEE<R!D92!L)W5T:6QI<V%T975R
M(*N@)7.@NZ`Z(`!5;B!P<F]B;.AM92!E<W0@87!P87)U(&QO<G,@9&4@;&$@
M<W5P<')E<W-I;VX@9&4@JZ`E<Z"[H#H@`%5N('!R;V)LZ&UE(&5S="!A<'!A
M<G4@;&]R<R!D92!L82!M:7-E(.`@:F]U<B!D92"KH"5SH+N@.B`E<P!5;B!P
M<F]B;.AM92!E<W0@87!P87)U(&QO<G,@9&4@;"=E;G9O:2!D=2!F:6-H:65R
MH#H@875C=6X@)7,@;B=A(.ETZ2!T<F%N<VUI<RX`56YE(&5R<F5U<B!E<W0@
M<W5R=F5N=64@;&]R<R!D92!L)V5N=F]I(&1U(&9I8VAI97*@.B!L92`E<R#I
M=&%I="!P;'5S(&=R;W,@<75E(&QE(&UA>&EM=6T@875T;W)I<^D@*"5D(&]C
M=&5T<RDN`%5N92!E<G)E=7(@97-T('-U<G9E;G5E(&QO<G,@9&4@;"=E;G9O
M:2!D=2!F:6-H:65RH#H@;&4@)7,@82#I=.D@=')A;G-M:7,@<&%R=&EE;&QE
M;65N="X`56YE(&5R<F5U<B!S)V5S="!P<F]D=6ET92!L;W)S(&1E(&PG869F
M:6-H86=E(&1E(&-E='1E('!A<G1E(&1U(&UE<W-A9V4`56YE(&5R<F5U<B!S
M)V5S="!P<F]D=6ET92!L;W)S(&1E(&PG:6UP;W)T871I;VX@9&5S(&1O;F[I
M97,@9&4@8V4@8V]N=&%C="X`56YE(&5R<F5U<B!S)V5S="!P<F]D=6ET92!L
M;W)S(&1E(&PG:6UP;W)T871I;VX@9&4@8V5T=&4@8V%R=&4@:4-A;&5N9&%R
M+@!);"!Y(&%V86ET('5N92!E<G)E=7(@9&%N<R!L92!F;W)M=6QA:7)E(&1E
M(&-O;F9I9W5R871I;VXN(%!E=70MZG1R92!A=F5Z+79O=7,@;&%I<W/I('5N
M(&-H86UP(')E<75I<R!V:61E+@!5;F4@97)R975R(',G97-T('!R;V1U:71E
M(&QO<G,@9&4@;"=E>.EC=71I;VX@9&4@8V5T=&4@9F]N8W1I;VX@9'4@8V%R
M;F5T(&0G861R97-S92X@4U90(&5S<V%Y97(@X"!N;W5V96%U('!L=7,@=&%R
M9"X`26P@>2!A(&5U('5N92!E<G)E=7(@;&]R<R!D92!L82!M:7-E(.`@:F]U
M<B!D97,@:6YF;W)M871I;VYS('-U<B!L92!C;VYT86-T+B`@5F5U:6QL97H@
M97-S87EE<B#@(&YO=79E874N`$EL('D@82!E=2!U;F4@97)R975R(&QO<G,@
M9&4@;&$@;6ES92#@(&IO=7(@9&4@;&$@;&ES=&4@9&4@9&ES=')I8G5T:6]N
M+B`@5F5U:6QL97H@97-S87EE<B!D92!N;W5V96%U+@!,92!P<NES96YT('-E
M<G9E=7(@24U!4"!N92!S=7!P;W)T92!P87,@;&4@<&%R=&%G92!D92!D;W-S
M:65R<RX`QV$@;F4@<V5M8FQE('!A<R#J=')E('5N92!A<F-H:79E(%)!4B!V
M86QI9&4N`,=A(&YE('-E;6)L92!P87,@ZG1R92!U;B!F:6-H:65R(%I)4"!V
M86QI9&4N`,=A(&YE('-E;6)L92!P87,@ZG1R92!U;B!N=6WI<F\@9&4@8V%R
M=&4@=F%L:61E+@!#92!P:6QO=&4@<&5R;65T(&PG96YV;VD@9&4@;65S<V%G
M97,@X"!T<F%V97)S(&QA('!A<W-E<F5L;&4@0VQI8VMA=&5L;"`H:'1T<#HO
M+V-L:6-K871E;&PN8V]M*2!E;B!U=&EL:7-A;G0@;"=!4$D@2%144`!#92!P
M:6QO=&4@<&5R;65T(&PG96YV;VD@9&4@;65S<V%G97,@=FEA(&QA('!A<W-E
M<F5L;&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@96X@=71I;&ES86YT(&PG
M05!)($A45%``0V4@<&EL;W1E('!E<FUE="!L)V5N=F]I(&1E(&UE<W-A9V5S
M(.`@=')A=F5R<R!L82!P87-S97)E;&QE('-M<S)E;6%I;"`H:'1T<#HO+W-M
M<S)E;6%I;"YC;VTI(&5N('5T:6QI<V%N="!L)T%022!(5%10`$-E('!I;&]T
M92!P97)M970@;"=E;G9O:2!D92!M97-S86=E<R!P87(@4TU44"#@('1R879E
M<G,@;&$@<&%S<V5R96QL92!6;V1A9F]N92!)=&%L:64L('-E=6QE;65N="!A
M=7@@;G5MZ7)O<R!6;V1A9F]N92X@0V5L82!NZ6-E<W-I=&4@=6X@8V]M<'1E
M(&1E(&-O=7)R:65L(%9O9&%F;VYE($ET86QI92`H:'1T<#HO+W=W=RXQ.3`N
M:70I+@!#92!C:&%M<"!E<W0@;V)L:6=A=&]I<F4N`$-E(&-H86UP(&YE(&1O
M:70@8V]N=&5N:7(@<75E(&1E<R!E;G1I97)S+@!#92!C:&%M<"!N92!D;VET
M(&-O;G1E;FER('%U92!D97,@;F]M8G)E<R!E="!L97,@9&5U>"UP;VEN=',N
M`$-E(&-H86UP(&YE(&1O:70@8V]N=&5N:7(@<75E(&1E<R!V86QE=7)S(&]C
M=&%L97,N`$-E(&-H86UP(&1O:70@8V]N=&5N:7(@=6YE(&QI<W1E(&0G96YT
M:65R<R!SZ7!A<NES('!A<B!D97,@=FER9W5L97,@;W4@9&5S(&5S<&%C97,`
M0V4@8VAA;7`@9&]I="#J=')E('5N(&YO;6)R92!V86QI9&4N`$-E(&-H86UP
M(&1O:70@8V]N=&5N:7(@=6X@8V]D92!D92!C;W5L975R(&%U(&9O<FUA="!2
M1T(@:&5X863I8VEM86PL('!A<B!E>&5M<&QE("<C,3(S-&%F)RX`0V4@9F]R
M;75L86ER92!A(&3I:N`@Z73I('1R86ETZ2X`0R=E<W0@)7,N`$-E8VD@97-T
M('5N(&]B:F5T($MO;&%B($=R;W5P=V%R92X@4&]U<B!V;VER(&-E="!O8FIE
M="P@=F]U<R!D979R97H@879O:7(@=6X@8VQI96YT(&1E(&-O=7)R:65L('%U
M:2!C;VUP<F5N9"!L92!F;W)M870@2V]L86(@1W)O=7!W87)E+B!0;W5R('5N
M92!L:7-T92!D92!C97,@8VQI96YT<R!D92!C;W5R<FEE;"P@=FES:71E>B`E
M<P!#92!M97-S86=E(&$@Z73I(.EC<FET(&1A;G,@=6X@8V]D92!D92!C87)A
M8W3H<F5S("@E<RD@875T<F4@<75E(&QE(';T=')E+@!#92!N;VUB<F4@9&]I
M="#J=')E('-U<.ER:65U<B#@('5N+@!#92!S97)V975R(&YE('!E=70@<&%S
M(&3I8V]M<')E<W-E<B!L97,@9FEC:&EE<G,@6DE0(&5T(&=Z:7`N`$-E('-Y
M<W3H;64@97-T('!RZ7-E;G1E;65N="!DZ7-A8W1I=NDN`$-E='1E('9A;&5U
M<B!D;VET(.IT<F4@=6X@;F]M8G)E+@!#971T92!F96[J=')E(&1O:70@ZG1R
M92!A<'!E;.EE(&1E<'5I<R!U;F4@9F5NZG1R92!D97,@;W!T:6]N<P!4;VYN
M97)R90!4:6-K971S`$AE=7)E`%-U:79I(&AO<F%I<F4`1F]R;6%T(&0G:&5U
M<F4`4^EL96-T:6]N(&1E(&PG:&5U<F4`5&EM;W(@;W)I96YT86P`5&ET<F4`
M5&ET<F4@*&EN9F]B=6QL92F@.@#``%!O=7(@<^EL96-T:6]N;F5R('!L=7-I
M975R<R!I=&5M<R#@(&QA(&9O:7,L(&UA:6YT96YE>B!E;F9O;F/I(&QE(&)O
M=71O;B"KH$-T<FR@NR`H4$,I(&]U(*N@0V]M;6%N9&6@NR`H36%C*2!E;B!C
M;&EQ=6%N="X`075J;W5R9"=H=6D`5F]I<B!L82!S;W5R8V4@2%1-3`!4;V=O
M`%1O:V5L874`1&5M86EN`%1O;F=A`%1R;W`@9&4@8V]N;F5X:6]N<R!I;F9R
M=6-T=65U<V5S(&1A;G,@;&5S(&1E<FYIZ')E<R!M:6YU=&5S+@!(875T`$-A
M9')E(&1U(&AA=70@*%]T;W`I`%1R861U8W1I;VYS`%1R:6YI=.DM970M5&]B
M86=O`%9R86D@;W4@9F%U>`!-80!4=6YI<VEE`%1U<G%U:64`5'5R8R`H25-/
M+3@X-3DM.2D`5'5R:VWI;FES=&%N`,YL97,@5'5R<75E<R!E="!#8>]Q=65S
M`%1U=F%L=0!%;G1R97H@=F]T<F4@8VAO:7B@.B``26YD:6-E(%56H#H@`%52
M3`!54DP@<&]U<B!V;W1R92!R87!P;W)T(&1E(&QI=G)A:7-O;B!D=2!S8W)I
M<'0`55),.@!/=6=A;F1A`%5K<F%I;F4`26UP;W-S:6)L92!D)V%T=&5I;F1R
M92!L92!RZ7!E<G1O:7)E(%9&4RX`26UP;W-S:6)L92!D)V%J;W5T97(@9&5S
M(&EN9F]R;6%T:6]N<R!C;VUP;.EM96YT86ER97,@X"!L)VEN<V-R:7!T:6]N
M+@!);7!O<W-I8FQE(&1E(&UO9&EF:65R(&QE<R!P97)M:7-S:6]N<R!P;W5R
M(&QE(&9I8VAI97(@5D93(*N@)7.@NRX`26UP;W-S:6)L92!D92!M;V1I9FEE
M<B!L97,@<&5R;6ES<VEO;G,@<&]U<B!L92!F:6-H:65R(%9&4R`E<R\E<RX`
M26UP;W-S:6)L92!D92!C:&%N9V5R('!O=7(@)7,N`$EM<&]S<VEB;&4@9&4@
M=NER:69I97(@;&$@=&%I;&QE(&1U(&9I8VAI97(@9&4@JZ`E<Z"[+@!);7!O
M<W-I8FQE(&1E(';I<FEF:65R(&QA('1A:6QL92!D=2!F:6-H:65R(&1E(*L@
M)7,O)7,@NRX`0V]N;F5X:6]N(&EM<&]S<VEB;&4@874@<V5R=F5U<B!344PN
M`$-O;FYE>&EO;B!I;7!O<W-I8FQE(&5N(%-33`!);7!O<W-I8FQE(&1E(&-O
M<&EE<B!U;B!F:6-H:65R(%9&4RX`26UP;W-S:6)L92!D92!C<NEE<B!U;B!R
MZ7!E<G1O:7)E(%9&4R"KH"5SH+LN`$EM<&]S<VEB;&4@9&4@8W+I97(@=6X@
M<NEP97)T;VER92!61E,N`$EM<&]S<VEB;&4@9&4@8W+I97(@;&4@9FEC:&EE
M<B!61E,N`$EM<&]S<VEB;&4@9&4@8W+I97(@;&4@<NEP97)T;VER92!61E,@
MJZ`E<Z"[+@!);7!O<W-I8FQE(&1E(&-RZ65R('5N(&9I8VAI97(@5D93('9I
M9&4N(`!/=79E<G1U<F4@:6UP;W-S:6)L92!D92!L)V%R8VAI=F4@8V]M<')E
M<W/I92X@`%-U<'!R97-S:6]N(&EM<&]S<VEB;&4@9&4@JZ`E<Z"[+"!L92!D
M;W-S:65R(&XG97-T('!A<R!V:61E+@!3=7!P<F5S<VEO;B!I;7!O<W-I8FQE
M(&1E(*N@)7.@NZ`Z("5S+@!3=7!P<F5S<VEO;B!I;7!O<W-I8FQE(&1E("5S
M+"!L92!D;W-S:65R(&XG97-T('!A<R!V:61E`%-U<'!R97-S:6]N('+I8W5R
M<VEV92!D=2!D;W-S:65R(%9&4R!I;7!O<W-I8FQE+@!3=7!P<F5S<VEO;B!D
M=2!RZ7!E<G1O:7)E(%9&4R!I;7!O<W-I8FQE+@!);7!O<W-I8FQE(&1E('-U
M<'!R:6UE<B!L92!RZ7!E<G1O:7)E(%9&4Z`Z("5S+@!3=7!P<F5S<VEO;B!I
M;7!O<W-I8FQE(&1U(&9I8VAI97(@5D93(*N@)7.@NRX`4W5P<')E<W-I;VX@
M:6UP;W-S:6)L92!D=2!F:6-H:65R(%9&4RX`4W5P<')E<W-I;VX@:6UP;W-S
M:6)L92!D=2!RZ7!E<G1O:7)E(%9&4R"KH"5SH+LN`%-U<'!R97-S:6]N(%9&
M4R!RZ6-U<G-I=F4@:6UP;W-S:6)L9:`Z("5S+@!);7!O<W-I8FQE(&1E(&3I
M=&5R;6EN97(@;&4@9&]S<VEE<B!C;W5R86YT+@!);7!O<W-I8FQE(&0G97AT
M<F%I<F4@;&5S(&3I=&%I;',@9'4@8V5R=&EF:6-A=`!);7!O<W-I8FQE(&1E
M(&-H87)G97(@;&$@9.EF:6YI=&EO;B!D92`E<RX`26UP;W-S:6)L92!D92!D
MZ7!L86-E<B!L92!F:6-H:65R(%9&4RX`26UP;W-S:6)L92!D)V]U=G)I<B!L
M92!F:6-H:65R(%9&4R"KH"5SH+LN`$EM<&]S<VEB;&4@9"=O=79R:7(@=6X@
M9FEC:&EE<B!61E,@96X@Z6-R:71U<F4N`$EM<&]S<VEB;&4@9"=O=79R:7(@
M=6X@9FEC:&EE<B!61E,N`$]U=F5R='5R92!I;7!O<W-I8FQE(&1E(&PG87)C
M:&EV92!C;VUP<F5S<^EE+@!);7!O<W-I8FQE(&1E(&QI<F4@;&4@9FEC:&EE
M<B!61E,@*.EC:&5C(&1E(&9I;&5S:7IE*"DI+@!);7!O<W-I8FQE(&1E(&QI
M<F4@;&4@9FEC:&EE<B!61E,@*.EC:&5C(&1E(&=E=$9I;&53:7IE*"DI+@!)
M;7!O<W-I8FQE(&1E(&QI<F4@;&4@9FEC:&EE<J`Z(`!,96-T=7)E(&1U('+I
M<&5R=&]I<F4@<F%C:6YE(%9&4R!I;7!O<W-I8FQE+@!);7!O<W-I8FQE(&1E
M(')E;F]M;65R("5S(&5N("5SH#H@;&4@9&]S<VEE<B!C:6)L92!E>&ES=&4@
M9.EJX`!);7!O<W-I8FQE(&1E(')E;F]M;65R(&QE('+I<&5R=&]I<F4@5D93
M+@!);7!O<W-I8FQE(&1E(')E;F]M;65R(&QE('+I<&5R=&]I<F4@5D93H#H@
M)7,N`$EM<&]S<VEB;&4@9&4@<F5N;VUM97(@;&4@9FEC:&EE<B!61E,@JZ`E
M<Z"[+@!);7!O<W-I8FQE(&1E(')E;F]M;65R(&QE(&9I8VAI97(@5D93("5S
M+R5S+@!);7!O<W-I8FQE(&1E(')E;F]M;65R(&QE(&9I8VAI97(@5D93+@!)
M;7!O<W-I8FQE(&0G97CI8W5T97(@)VUK:7-O9G,G+@!);7!O<W-I8FQE(&1E
M('1R861U:7)E(&-E(&1O8W5M96YT(%=O<F0N`$EM<&]S<VEB;&4@9"?I8W)I
M<F4@;&4@9FEC:&EE<B!61E,@JZ`E<Z"[+@!);7!O<W-I8FQE(&0GZ6-R:7)E
M(&QE<R!D;VYNZ65S(&1U(&9I8VAI97(@5D93("AC;W!Y*"D@:6UP;W-S:6)L
M92DN`$EM<&]S<VEB;&4@9"?I8W)I<F4@;&5S(&1O;F[I97,@9'4@9FEC:&EE
M<B!61E,N`$EM<&]S<VEB;&4@9"?I8W)I<F4@;&4@9FEC:&EE<B!61E,L(&QE
M('%U;W1A('-E<F%I="!DZ7!A<W/I+@!3;W5L:6=N97(`06YN=6QE<B!L97,@
M8VAA;F=E;65N=',`06YN=6QE('9O=')E(&1E<FYIZ')E(&%C=&EO;@!2Z7!O
M;G-E(&EN871T96YD=64@9'4@<V5R=F5U<B!L;W)S(&1E(&QA(&-O;FYE>&EO
M;J`Z(`!2Z7!O;G-E(&EN871T96YD=64@9'4@<V5R=F5U<B#@H#H@`$AO<G,@
M8V%TZ6=O<FEE`%5N:6-O9&4@*%541BTX*0#);6ER871S($%R86)E<R!5;FES
M`%)O>6%U;64M56YI`,ET871S+55N:7,`SFQE<R!E>'3I<FEE=7)E<R!D97,@
MR71A=',M56YI<P!5;FETZ7,`26YC;VYN=0!A<&EM<V=I9"!I;F-O;FYU("A!
M4$D@365S<V%G92!)1"DN`&-L:6US9VED(&EN8V]N;G4@*$-L:65N="!-97-S
M86=E($E$*2X`16UP;&%C96UE;G0@<^EL96-T:6]N;ND@:6YC;VYN=2X`3F]M
M(&0G=71I;&ES871E=7(@;W4@;6]T(&1E('!A<W-E(&EN8V]N;G4N`$3I;&EE
M<B!L)^ELZ6UE;G0@8V]U<F%N=`!386YS(&YO;0!,97,@<V-R:7!T<R!N;VXM
M<')I=FELZ6=IZ7,@;F4@<&5U=F5N="!A8V/I9&5R(&%U>"!F;VYC=&EO;G,@
M8V]U<&5R+V-O<&EE<B]C;VQL97(@<&]U<B!D97,@<F%I<V]N<R!D92!SZ6-U
M<FETZ2X@07!P=7EE>B!S=7(@3TL@<&]U<B!V;VER('5N92!N;W1E('1E8VAN
M:7%U92!S=7(@;6]Z:6QL82YO<F<@<75I('9O=7,@97AP;&EQ=65R82!C;VUM
M96YT(&%U=&]R:7-E<B!U;B!S8W)I<'0@X"!U=&EL:7-E<B!L92!P<F5S<V4M
M<&%P:65R<P!296UE='1R92!L82!C;W5L975R(.`@>NER;P!%>'1E;G-I;VX@
M;F]N('!R:7-E(&5N(&-O;7!T90!-;V1I9FEE<@!-;V1I9FEE<B`E<P!-;V1I
M9FEE<B!L)W5T:6QI<V%T975R`$UI<V4@X"!J;W5R(&1E(*N@)7.@NRX`3&4@
M<V-R:7!T(&1E(&UI<V4@X"!J;W5R(&5S="!S=7!P<FEMZ0!#:&%R9V5R`%1O
M=7,@;&5S(&9I8VAI97)S(&1E(&-O;F9I9W5R871I;VX@9&5S(&%P<&QI8V%T
M:6]N<R!O;G0@Z73I(&5N=F]YZ7,@<W5R(&QE('-E<G9E=7(N`$QE='1R97,@
M;&%T:6YE<R!M86IU<V-U;&5S`$YO;6)R97,@<F]M86EN<R!M86IU<V-U;&5S
M`%5R=6=U87D`16UP;&]YZ2!A8W1U96QL96UE;G2@.B`E<P!5=&EL:7-E<B!3
M4TP`571I;&ES97(@<VD@;&4@;F]M(&0G=71I;&ES871E=7(O;6]T(&1E('!A
M<W-E(&5S="!D:69FZ7)E;G0@9'4@<V5R=F5U<B!)35-0+@!5=&EL:7-A=&5U
M<@!,)W5T:6QI<V%T975R("5S(&XG82!P87,@;"=A=71O<FES871I;VX@<&]U
M<B`E<RX`061M:6YI<W1R871I;VX@9&5S('5T:6QI<V%T975R<P!0<NEFZ7)E
M;F-E<R!P97)S;VYN96QL97,`16YR96=I<W1R96UE;G0@9&5S('5T:6QI<V%T
M975R<P!,)V5N<F5G:7-T<F5M96YT(&0G=71I;&ES871E=7(@97-T(&3I<V%C
M=&EVZ2!S=7(@8V4@<WES=.AM92X`0V]M<'1E('5T:6QI<V%T975R(&YO;B!T
M<F]U=ND`3F]M(&0G=71I;&ES871E=7(`3&4@;F]M(&1E(&-O;FYE>&EO;B"K
MH"5SH+L@97AI<W1E(&3I:N`N`$YO;2!D)W5T:6QI<V%T975RH#H`3F]M(&0G
M=71I;&ES871E=7*@.B``571I;&ES871E=7)S(&3I9FEN:7.@.@!/=7IBZ6MI
M<W1A;@!2Z7!E<G1O:7)E(%9&4R!I;F5X:7-T86YT+@!!8G-E;F-E<P!,97,@
M96UP;&%C96UE;G1S('9A;&ED97,@=')O=7;I<R!I;F-L=65N=*`Z(`!686QI
M9&ETZ0!686QE=7(@96X@;6EN=71E<R#@('!A<G1I<B!D92!M86EN=&5N86YT
M+@!686QE=7(@<W5PZ7)I975R92#@(&QA(&QO;F=U975R(&UA>&EM86QE(&1E
M("5S+@!686QE=7)S`%9A;&5U<G,@X"!SZ6QE8W1I;VYN97(@9&4`5F%N=6%T
M=0!687)I86)L90!6Z6[I>G5E;&$`R6-H96,@9&4@;&$@=NER:69I8V%T:6]N
M("9M9&%S:#L@8V4@;65S<V%G92!A('!E=70MZG1R92#I=.D@9F%L<VEF:>DN
M`%9E<G-I;VX`0V]N='+T;&4@9&4@=F5R<VEO;@!!;&EG;F5M96YT('9E<G1I
M8V%L`%)E;7!L:7-S86=E('9E<G1I8V%L`%9E<G1I8V%LH#H`5'+H<R!H875T
M90!6:65T;F%M`%9IZG0M;F%M:65N("A625-#24DI`%9O:7(@)7,`5F]I<B!U
M;F4@<&%G92!W96(@97AT97)N90!6;VER(&-O;6UE("5S`,YL97,@5FEE<F=E
M<R!B<FET86YN:7%U97,`SFQE<R!6:65R9V5S(&1E<R#)=&%T<RU5;FES`%9I
M<VEB:6QI=.D`5FES:6)I;&ETZ:`Z(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU4
M4`!.3U1)0T4`051414Y424].(2$A("!355!04DE-15(@3$4@4T-225!4($U!
M3E5%3$Q%345.5"!$12`E<P!724X@=FEA($A45%``5V%L;&ES(&5T($9U='5N
M80!!='1E;G1I;VX`364`4'+I=FES:6]N<R!MZ73I;P!$;VYNZ65S(&WI=.EO
M(&9O=7)N:65S('!A<@!796%T:&5R+F-O;0!796(`4VET92!W96(`0VAA<75E
M('-E;6%I;F4`0FEE;G9E;G5E`$)I96YV96YU92#@("5S`$)I96YV96YU92P@
M)7,`3V-C:61E;G1A;"`H25-/+3@X-3DM,2D`3V-C:61E;G1A;"`H25-/+3@X
M-3DM,34I`%-A:&%R82!/8V-I9&5N=&%L`%%U96QL92!A<'!L:6-A=&EO;B`E
M<R!D;VET+6EL('!RZ7-E;G1E<B!A<'+H<R!L82!C;VYN97AI;VZ@/P!1=65L
M(&5S="!L92!C87)A8W3H<F4@9&4@<^EP87)A=&EO;J`_`%%U96P@97-T(&QE
M(&-A<F%C=.AR92!D92!C:71A=&EO;J`_`$-A<G1E(%=H97)E:7,@075S=')A
M;&EE`%%U96QL97,@<&AA<V5S`%%U96QL97,@97AT96YS:6]N<R!A8W1I=F5R
M('!O=7(@;"?I9&ET975R(%)I8V@@5&5X="X`3&%R9V5U<@!,87)G975R(&5N
M('5N:73I<R!#4U,`3&%R9V5U<B!D=2!M96YU(&1E(&=A=6-H92`E<R`@*&QA
M(&-O;F9I9W5R871I;VX@<')E;F1R82!E9F9E="#@(&QA('!R;V-H86EN92!C
M;VYN97AI;VXIH#H`3&%R9V5U<B!D=2!T86)L96%U`%5N:73I(&1E(&QA<F=E
M=7(`3&%R9V5U<J`Z`%=I:VD`5F5N=`!696YT('3T="!L92!M871I;@!6:71E
M<W-E(&1U('9E;G0@96X@;B9O96QI9SMU9',`5F5N=*`Z`%9E;G2@.B``4V%G
M97-S90!,:7-T92!D92!V)F]E;&EG.W5X`%1R879A:6P`061R97-S92!P<F]F
M97-S:6]N;F5L;&4`5.ELZ7!H;VYE('!R;V9E<W-I;VYN96P`3F]M8G)E(&1E
M(&-H86UP<R!I;F-O<G)E8W0@X"!L82!L:6=N92`E9"X@)60@871T96YD=7,L
M("5D('1R;W5VZ7,N`$YO;6)R92!D92!C:&%M<',@:6YC;W)R96-T+B`E9"!A
M='1E;F1U<RP@)60@=')O=7;I<RX`1.EC86QA9V4@)60@:6YC;W)R96-T(&QO
M<G,@9&4@;&$@;&5C='5R92!D92!F:6-H:65R(%9&4RX`6"U2968`0V]N=')A
M:6YT97,@8F%S:7%U97,@6#4P.78S`%5T:6QI<V%T:6]N(&1E(&-LZ2#I=&5N
M9'5E(%@U,#EV,P!!=71R92!N;VT@9'4@<W5J970@6#4P.78S`$ED96YT:69I
M86YT(&1E(&-LZ2!D=2!S=6IE="!8-3`Y=C,`17AT96YS:6]N<R!8-3`Y=C,`
M04$`04%!00!#87)T92"KH%EA:&]OH"&@NP!!;FYU96QL96UE;G0`6>EM96X`
M3W5I`$]U:2P@:B=A8V-E<'1E`%9O=7,@ZG1E<R!E;B!M;V1E(*N@5&5X=&6@
MNRX@571I;&ES97H@;&4@8F]U=&]N(%L\/ET@<&]U<B!R979E;FER(&%U(&UO
M9&4@JZ!765-)5UE'H+LN`%9O=7,@;B?J=&5S('!A<R!A=71O<FESZ2#@(&-R
MZ65R('!L=7,@9&4@)60@8FQO8W,N`%9O=7,@;B?J=&5S('!A<R!A=71H96YT
M:69IZ2X`5F]U<R!N92!P;W5V97H@<&%S(&%V;VER(&QE(&-A<F%C=.AR92"K
M7+L@9&%N<R!V;W1R92!N;VT@8V]M<&QE="X`5F]U<R!N)V%V97H@<&%S('-A
M:7-I('5N92!A9')E<W-E(.EL96-T<F]N:7%U92!V86QI9&4N`%9O=7,@;B=A
M=F5Z('!A<R!A<W-O8VGI(&QE<R!C:&%M<',@9'4@9FEC:&EE<B!I;7!O<G3I
M(&%U>"!C:&%M<',@8V]R<F5S<&]N9&%N=',@9&%N<R`E<RX`5F]U<R!A=F5Z
M(.ETZ2!DZ6-O;FYE8W3I+@!6;W5S(&1E=F5Z(&EN<V-R:7)E('5N(&YU;>ER
M;R!D92!C96QL=6QA:7)E('9A;&ED92P@<V5U;',@9&5S(&YO;6)R97,@970@
M=6X@JZ`KH+L@;W!T:6]N;F5L('!O=7(@;&5S(&%P<&5L<R!I;G1E<FYA=&EO
M;F%U>"X`5F]U<R!N)V%V97H@<&%S('-A:7-I('5N92!E;G1RZ64@=F%L:61E
M+@!6;W5S(&1E=F5Z(&-O;F9I9W5R97(@=6X@8F%C:V5N9"!$871A5')E92!P
M;W5R('5T:6QI<V5R(&QE<R!I;G-C<FEP=&EO;G,`5F]U<R!D979E>B!C;VYF
M:6=U<F5R('5N(&UO9'5L92!61E,N`%9O=7,@9&5V97H@9.EC<FER92!L92!P
M<F]B;.AM92!A=F%N="!D92!N;W5S(&9A:7)E('!A<G9E;FER(&QE(')A<'!O
M<G0N`%9O=7,@9&5V97H@96YT<F5R('5N92!54DP@;_D@<&]I;G1E(&1E(&QI
M96XN`$EL(&9A=70@<^EL96-T:6]N;F5R('5N('-E<G9E=7(@X"!S=7!P<FEM
M97(N`%9O=7,@9&5V97H@<W#I8VEF:65R('5N('5T:6QI<V%T975R(.`@<F5T
M:7)E<BX@`%9O=7,@9&5V97H@<W#I8VEF:65R('5N('5T:6QI<V%T975R(.`@
M<F5T:7)E<BX`5F]U<R!D979E>B!S<.EC:69I97(@=6X@=71I;&ES871E=7(@
MX"!A:F]U=&5R+@!6;W5S(&1E=F5Z('-PZ6-I9FEE<B!L92!N;VT@9&4@;"=U
M=&EL:7-A=&5U<B#@(&UO9&EF:65R+@!6;W5S(&1E=F5Z(&EN9&EQ=65R('%U
M96QL92!A8W1I;VX@86-C;VUP;&ER+@!6;W5S(&1E=F5Z(.EC<FER92!U;B!N
M;VT@<&]U<B!L82!N;W5V96QL92!C873I9V]R:64N`%9O=7,@9&5V97H@9F]U
M<FYI<B!U;B!NL"!D92!TZ6SI<&AO;F4@:71A;&EE;@!6;W1R92!S97-S:6]N
M("5S(&$@97AP:7+I+B!6975I;&QE>B!V;W5S(')E8V]N;F5C=&5R+@!6;W1R
M92!A9')E<W-E(&1E(&-O=7)R:65L`%9O=')E(&%D<F5S<V4@9&4@8V]U<G)I
M96P@JR!$93H@NZ`Z`%9O<R!D;VYNZ65S('!E<G-O;FYE;&QE<P!6;W1R92!A
M9')E<W-E($EN=&5R;F5T(&$@8VAA;F?I(&1E<'5I<R!L)V]U=F5R='5R92!D
M92!V;W1R92!S97-S:6]N("5S+B`@4&]U<B!V;W1R92!SZ6-U<FETZ2P@=F]U
M<R!D979E>B!V;W5S(')E8V]N;F5C=&5R+@!6;W1R92!N;VT`5F]T<F4@;6]D
M=6QE(&0G875T:&5N=&EF:6-A=&EO;B!N92!S=7!P;W)T92!P87,@;"=A:F]U
M="!D)W5T:6QI<V%T975R<RP@4VD@=F]U<R!S;W5H86ET97H@=71I;&ES97H@
M2&]R9&4@<&]U<B!A9&UI;FES=')E<B!L97,@8V]M<'1E<R!U=&EL:7-A=&5U
M<G,L('9O=7,@9&5V97H@=71I;&ES97(@=6X@875T<F4@;6]D=6QE(&0G875T
M:&5N=&EF:6-A=&EO;BX`5F]T<F4@;6]D=6QE(&0G875T:&5N=&EF:6-A=&EO
M;B!N)V5S="!P87,@96X@;65S=7)E(&0GZ71A8FQI<B!U;F4@;&ES=&4@9&5S
M('5T:6QI<V%T975R<RP@;W4@8V5T=&4@9F]N8W1I;VX@82#I=.D@<F5T:7+I
M92!P;W5R('5N92!A=71R92!R86ES;VXN`%9O=')E(&YA=FEG871E=7(@<V5M
M8FQE(&%V;VER(&-H86YGZ2!D97!U:7,@;&4@9.EB=70@9&4@=F]T<F4@<V5S
M<VEO;B`E<RX@(%!O=7(@=F]T<F4@<^EC=7)I=.DL('9O=7,@9&5V97H@=F]U
M<R!R96-O;FYE8W1E<BX`5F]T<F4@;F%V:6=A=&5U<B!N92!S=7!P;W)T92!P
M87,@8V5T=&4@;W!T:6]N`%9O=')E(&YA=FEG871E=7(@;F4@<')E;F0@<&%S
M(&5N(&-O;7!T92!C971T92!O<'1I;VX@9"=I;7!R97-S:6]N+B!0<F5S<V5Z
M($-O;G1R]&QE+T-O;6UA;F1E("L@4"!P;W5R(&EM<')I;65R`%9O=')E(&9U
M<V5A=2!H;W)A:7)E(&%C='5E;*`Z`%9O=')E('!R;V9I;"!P87(@9.EF875T
M(&$@Z73I(&UO9&EF:>DN`%!R;V9I;"!P87(@9.EF875TH#H`5F]T<F4@;F]M
M(&-O;7!L972@.@!6;W1R92!C;VUP=&4@82!E>'!I<NDN`%9O=')E(&YO=79E
M874@;6]T(&1E('!A<W-E('!O=7(@)7,@97-TH#HE<P!6;W,@;W!T:6]N<R!O
M;G0@Z73I(&UI<V5S(.`@:F]U<B!P;W5R(&QA(&1U<NEE(&1E(&-E='1E('-E
M<W-I;VXN`%9O<R!O<'1I;VYS(&]N="#I=.D@;6ES97,@X"!J;W5R+@!6;W1R
M92!M;W0@9&4@<&%S<V4@82#I=.D@<F5M:7,@X"!ZZ7)O`%9O=')E(&UO="!D
M92!P87-S92!A(.ETZ2!R96UI<R#@('KI<F\L(';I<FEF:65R('9O=')E(&-O
M=7)R:65R(&5T(&-O;FYE8W1E>BUV;W5S(&%V97H@=F]T<F4@;F]U=F5A=2!M
M;W0@9&4@<&%S<V4N`%9O=')E(&UO="!D92!P87-S92!A(&5X<&ERZ2X`5F]S
M('-E<G9E=7)S(&1I<W1A;G1SH#H`66]U9V]S;&%V:64`6F'O<F4`6F%M8FEE
M`%II;6)A8G=E`%II<'!Y`%M#86-H97(@;&5S(&-I=&%T:6]N<UT`6U)A<'!O
M<G0@9&4@<')O8FSH;65=`%M!9F9I8VAE<B!L92!T97AT92!C:73I("T`6T%F
M9FEC:&5R(&QE('1E>'1E(&-I=.D@+2`E<R!L:6=N97-=`%ML:6=N92`E<R!D
M92`E<UT`7T%D;6EN:7-T<F%T:6]N`$QI9VYE(&1E(%]C;VUM86YD90!?1&%T
M851R964`4W5P<')I;65R(&QA(%]R86YGZ64`7T=R;W5P97,`7T%I9&4`4')O
M<')?:>ETZ7,@9&4@;"=I;6%G92XN+@!?0V]N;F5X:6]N`%]$Z6-O;FYE>&EO
M;@!?36]D:69I97(@=6X@;&EE;B!W96(N+BX`7T]P=&EO;G,`7U!E<FUI<W-I
M;VYS`%]2971I<F5R('5N(&QI96X`7T-O;F9I9W5R871I;VX`4')O<')IZ73I
M<R!D=2!?=&%B;&5A=0!?571I;&ES871E=7)S`&-A<FYE="!D)V%D<F5S<V5S
M`&1E<W1I;F%T86ER92!I;F-O;FYU`&%G96YD80!C86QM90!I;7!O<W-I8FQE
M(&1E(&-RZ65R(&QE(&9I8VAI97(@9&4@<V]R=&EE`&EM<&]S<VEB;&4@9"=O
M=79R:7(@;"=E;G1RZ64`8VQI<75E>B!I8VD`97)R975R(&0G=71I;&ES871I
M;VX@9&4@;&$@;&EG;F4@9&4@8V]M;6%N9&4`97)R975R(&1E(&-O;F9I9W5R
M871I;VX`86)S96YC92!C<FET:7%U92!D)W5N(&9I8VAI97(@<WES=.AM90!E
M<G)E=7(@9&4@9F]R;6%T(&1E(&1O;F[I90!M;V1I9FEE<@!E;G1RZ64@;F]N
M('1R;W5VZ0!T;VUB86YT`&9I8VAI97(`9&5P=6ES(&QE("5S("@E<RD@X"`E
M<R`E<P!E;B!R869A;&4`:*`Z`&AH`&YO;2!D)VCT=&4@:6YC;VYN=0!I;6WI
M9&EA=&5M96YT`&EN8V]R<&]RZ64`97)R975R(&0G96YT<NEE+W-O<G1I90!E
M<G)E=7(@;&]G:6-I96QL92!I;G1E<FYE`&QI9VYE<UT`97)R975R(&UK:7-O
M9G,@8V]D92`E9"!E;B!C<NEA;G0@;"=)4T\`;6T`;F]M`&YO;B!P<FES(&5N
M(&-O;7!T90!P87,@96YC;W)E('!R:7,@96X@8V]M<'1E`&)L;V,M;F]T97,`
M<&]U<F-E;G1A9V4`<&5R;6ES<VEO;B!R969U<^EE`'!I>&5L<P!E<G)E=7(@
M9&ES=&%N=&4@9&%N<R!L92!P<F]T;V-O;&4`<R?I;&5V86YT`'-E<G9I8V4@
M;F]N(&1I<W!O;FEB;&4N`&UO;G1R97(@;&5S(&1I9F;I<F5N8V5S`'-M<S)E
M;6%I;"!V:6$@2%144`!S<P!F:7AE`&5R<F5U<B!S>7-TZ&UE`&QI<W1E(&1E
M('3B8VAE<P#I8VAE8R!T96UP;W)A:7)E`&5N=')E>B!L92!M;W0@9&4@<&%S
M<V4@9&5U>"!F;VES('!O=7(@8V]N9FER;65R`'5N:69IZ0!S86YS(&YO;0!3
MZ6QE8W1I;VX@9"=U=&EL:7-A=&5U<@!V0V%R9`!LH#H`=V5A=&AE<BYC;VT`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]G;%]%4R\`````
M````````````````````````````````````````````````````````````
M````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`U,34T,S,W-3,`,#(P,3`V`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&]C86QE+V=L7T53+TQ#7TU%4U-!1T53+P``````````````````````````
M```````````````````````````````````````P,#`P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U,P`P,C$V-S,`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9VQ?15,O3$-?34534T%'15,O:&]R
M9&4N;6\`````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$T,#(U`#$P-3$U-#,S
M-S4S`#`R,S,S,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#>$@25`````&0````<````/`,``(D```!<!@```````(`(```H
M````@0@```@```"J"```!0```+,(```(````N0@```<```#""```!0```,H(
M```?````T`@``!$```#P"```"`````()```(````"PD``!4````4"0``"@``
M`"H)```,````-0D```<```!""0``*0```$H)```"````=`D```4```!W"0``
M$````'T)```4````C@D``"\```"C"0``#P```-,)```F````XPD```4````*
M"@``#0```!`*```%````'@H``!`````D"@``$````#4*```/````1@H```L`
M``!6"@``#P```&(*```,````<@H```\```!_"@``'@```(\*```A````K@H`
M``,```#0"@``!````-0*```,````V0H```H```#F"@``!0```/$*```2````
M]PH``!`````*"P``"````!L+```0````)`L```8````U"P``!P```#P+```"
M````1`L```0```!'"P``#P```$P+```'````7`L```<```!D"P``!````&P+
M```%````<0L```4```!W"P``!P```'T+```1````A0L```@```"7"P``'@``
M`*`+```%````OPL``"@```#%"P``*0```.X+```3````&`P```L````L#```
M$0```#@,```$````2@P```P```!/#```&@```%P,```7````=PP``!<```"/
M#```&P```*<,```?````PPP``!,```#C#```$````/<,```7````"`T```<`
M```@#0``!0```"@-```A````+@T``!P```!0#0``!0```&T-```#````<PT`
M`"````!W#0``)@```)@-```,````OPT```P```#,#0``"````-D-```'````
MX@T```8```#J#0``#0```/$-```+````_PT```P````+#@``"@```!@.```"
M````(PX```8````F#@``10```"T.```P````<PX``!````"D#@``'P```+4.
M```0````U0X```\```#F#@``!0```/8.``!O`0``_`X``"H```!L$```"```
M`)<0```%````H!````X```"F$```"````+40```&````OA```"0```#%$```
M$P```.H0```+````_A````H````*$0``'P```!41```.````-1$```\```!$
M$0``"````%01```R````71$```(```"0$0``"P```),1```9````GQ$``!8`
M``"Y$0``+P```-`1```8`````!(``"L````9$@``$@```$42```.````6!(`
M``0```!G$@``#P```&P2```0````?!(```X```"-$@``%0```)P2```/````
MLA(```L```#"$@``$P```,X2```C````XA(``",````&$P```P```"H3```%
M````+A,``!,````T$P``$P```$@3```%````7!,``!,```!B$P``$@```'83
M```&````B1,``!@```"0$P``!@```*D3```/````L!,```(```#`$P``!@``
M`,,3```6````RA,```<```#A$P``#````.D3```$````]A,```4```#[$P``
M!0````$4```'````!Q0``!$````/%```#P```"$4```A````,10```@```!3
M%```'@```%P4```O````>Q0``!8```"K%```"P```,(4```3````SA0```<`
M``#B%```$0```.H4```A````_!0``!T````>%0``'0```#P5```E````6A4`
M`!0```"`%0``'0```)45```3````LQ4``!\```#'%0``#0```.<5```'````
M]14``"(```#]%0``&P```"`6```&````/!8```,```!#%@``*@```$<6```O
M````<A8``!,```"B%@``$@```+86```'````R18```4```#1%@``#````-<6
M```,````Y!8```T```#Q%@``%````/\6```4````%!<```(````I%P``"@``
M`"P7```N````-Q<``#P```!F%P``$0```*,7```?````M1<``!4```#5%P``
M#P```.L7```9````^Q<```$````D`````````$X````=````3P```!<```!%
M````!P```"(`````````30```"$`````````2P```&(````*````$0``````
M```,````,@```%,````Q`````````"4```!&````70````````!2````0@``
M`%4`````````1P```"P````O````5@```%$````U````$`````@````^````
M00```%\````K````#P```#D```!*````(P```!@````S````0````"@```!@
M````"P``````````````5```````````````/0````D`````````+@```$@`
M``!<````.@`````````.`````````%D`````````-@`````````;````/P``
M`!P````:````#0```#L`````````!`````4`````````$@`````````3````
M`````%<````M`````````"8``````````````!4````&`````````%L````W
M````&0````````!>`````````#@````T`````````$D````?````6@```$0`
M````````'@``````````````8P````````!8````*0`````````P````````
M```````\````9````%``````````%@```"```````````P```&$```!#````
M*@```"<```!,`````@`````````4`````"5S($UA:6YT96YA;F-E($]P97)A
M=&EO;G,@+2!#;VYF:7)M871I;VX`,C0@:&]U<G,`04TO4$T`061D('!A:7(`
M061D<F5S<P!!;&EA<P!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N
M`$%V86EL86)L92!F:65L9',Z`$)I<G1H9&%Y`$-A;&5N9&%R`$-A;F-E;"!0
M<F]B;&5M(%)E<&]R=`!#96QL(%!H;VYE`$-L;W-E(%=I;F1O=P!#;VUP86YY
M`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$1$
M`$1A:6QY`$1E9F%U;'0@261E;G1I='D`1&5S8W)I8F4@=&AE(%!R;V)L96T`
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BX`1&ES<&QA>2!/<'1I;VYS`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I
M;G1E;F%N8V4N<&AP`$5M86EL`$5M<'1Y(')E<W5L="X`17)R;W(`179E<GD@
M,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%
M=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP
M;&4@=F%L=65S.@!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I
M;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A>`!(96QP`$AO;64@
M061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$EM<&]R=&5D(&9I96QD.B`E<P!)
M;7!O<G1E9"!F:65L9',Z`$QA;F=U86=E`$QI<W0@2&5L<"!4;W!I8W,`3&]G
M(&EN`$QO9R!O=70`34T`36%I;`!-871C:&EN9R!F:65L9',`365S<V%G90!-
M;VYT:&QY`$YA;64`3F5V97(`3F]T97,`3W!T:6]N<P!/=&AE<B!);F9O<FUA
M=&EO;@!087-S=V]R9`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`
M4&AO;F4`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M
M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0
M<F]B;&5M($1E<V-R:7!T:6]N`%)E;6]V92!P86ER`%)E='5R;B!T;R!/<'1I
M;VYS`%)O;&4`4V%V92!/<'1I;VYS`%-E;&5C="!T:&4@9&%T92!D96QI;6ET
M97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@=&EM92!F
M;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U
M<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4VMI
M<"!-86EN=&5N86YC90!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3=6-C97-S
M`%1A<VMS`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES
M('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1I=&QE`%523`!5;F%B;&4@=&\@
M8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@=')A;G-L871E('1H
M:7,@5V]R9"!D;V-U;65N=`!5;F1O($-H86YG97,`57-E<B!/<'1I;VYS`%5S
M97)N86UE`%=A<FYI;F<`5V5E:VQY`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@
M)7,`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`65D`665A<FQY`%EO=2!M=7-T
M(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE
M('!R;V)L96T@<F5P;W)T+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N
M(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!);F9O<FUA=&EO;@!9;W5R(&]P
M=&EO;G,@:&%V92!B965N('5P9&%T960N`%M0<F]B;&5M(%)E<&]R=%T`6VQI
M;F4@)7,@;V8@)7-=`'9#87)D`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@
M,BXQ"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G
M"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M
M4F5V:7-I;VXM1&%T93H@,C`P,RTP."TQ.2`Q,SHS-4=-5"LQ"DQA<W0M5')A
M;G-L871O<CH@4V5R=FEC:6\@9&4@3F]R;6%L:7IA8VEO;B!,:6YG=6ES=&EC
M82`\<VYL=7-C0'5S8RYE<SX*3&%N9W5A9V4M5&5A;3H@1V%L96=O"DU)344M
M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E
M=#U)4T\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*
M6"U'96YE<F%T;W(Z($M"86)E;"`P+CDN-0H`3W!E<F%C:?-N<R!D92!M86YT
M96UE;G1O("5S("T@0V]N9FER;6%C:?-N`#(T(&AO<F%S`$%-+U!-`$5N9V%D
M:7(@=6X@<&%R`$5N9&5R97IO`$%L8W5M90!/('9A;&]R('%U92!E<W!E8VEF
M:6-O=2!N;VX@Z2!VX6QI9&\`0V%M<&]S(&1I<W!O\6EB;&5S.@!!;FEV97)S
M87)I;P!#86QE;F1A<FEO`$-A;F-E;&%R(&\@:6YF;W)M92!D92!P<F]B;&5M
M87,`5&5LZ69O;F\@;?-B:6P`4&5C:&%R(&$@>&%N96QA`$-O;7!A\>UA`$9A
M;&QO(/,@86)R:7(@;R!M\V1U;&\@9&4@=&%R969A<R!D92!M86YT96UE;G1O
M("5S`$1$`$1I87)I86UE;G1E`$ED96YT:61A9&4@<')E9&5T97)M:6YA9&$`
M1&5S8W)I8VGS;B!D;R!P<F]B;&5M80!297AI<W1RX7)O;G-E(&]S(&1E=&%L
M;&5S('!A<F$@;R!A9&UI;FES=')A9&]R+@!/<&-I\VYS(&1E('9I<W5A;&EZ
M86-I\VX`3F]N(&%C8V5D82!D:7)E8W1A;65N=&4@82`B;6%I;G1E;F%N8V4N
M<&AP(@!#;W)R96\@96QE8W1R\VYI8V\`4V5N(')E<W5L=&%D;RX`17)R;P!#
M861A(#$U(&UI;G5T;W,`0V%D82`S,"!S96=U;F1O<P!#861A(#4@;6EN=71O
M<P!#861A(&EN:6-I;R!D92!S97-I\VX`0V%D82!M961I82!H;W)A`$-A9&$@
M;6EN=71O`$5X96UP;&\@9&4@=F%L;W)E<SH`1F%L;&]U(/,@<F5C=7!E<F%R
M(&%S('!R969E<F5N8VEA<RX`1F%L;&]U(/,@8V]N96-T87(@8V\@<V5R=FED
M;W(@3$1!4"X`1F%X`$%X=61A`$5N9&5R97IO('!A<G1I8W5L87(`5&5LZ69O
M;F\@<&%R=&EC=6QA<@!(;W)D90!#86UP;R!I;7!O<G1A9&\Z("5S`$-A;7!O
M<R!I;7!O<G1A9&]S.@!,:6YG=6$`3&ES=&%R(&]S('1E;6%S(&1E(&%X=61A
M`$5N=')A<@!096-H87(@82!S97-I\VX`34T`0V]R<F5O`$-A;7!O<R!C;W)R
M97-P;VYD96YT97,`365N<V%X90!-96YS=6%L;65N=&4`3F]M90!.=6YC80!.
M;W1A<P!/<&-I\VYS`$]U=')A(&EN9F]R;6%C:?-N`$-H879E(&1E(&%C8V5S
M;P!296%L:7IA<B!O<&5R86-I\VYS(&1E(&UA;G1E;65N=&\`5&5LZ69O;F\`
M06-H96=U92!U;B!R97-U;6\@9&\@<')O8FQE;6$N`$%C:&5G=64@;R!S974@
M;F]M92!D92!U<W5A<FEO(&4@8VAA=F4@9&4@86-C97-O`$1E<V-R:6-I\VX@
M9&\@<')O8FQE;6$`4V%C87(@;R!P87(`4F5G<F5S87(@X7,@;W!C:?-N<P!&
M=6YC:?-N`$=A<F1A<B!A<R!O<&-I\VYS`%-E;&5C8VEO;F4@;R!D96QI;6ET
M861O<B!D82!D871A.@!396QE8V-I;VYE(&\@9F]R;6%T;R!D82!D871A.@!3
M96QE8V-I;VYE(&\@9F]R;6%T;R!D82!H;W)A.@!396QE8V-I;VYE(&1O=7,@
M8V%M<&]S('%U92!C;VEN8VED86XN`%-E;&5C8VEO;F4@82!L:6YG=6$Z`$5N
M=FEA<B!O(&EN9F]R;64@9&4@<')O8FQE;6%S`$]M:71I<B!O(&UA;G1E;65N
M=&\`16YT<F%D82!D92!C87)A8W1E<F5S(&5S<&5C:6%I<P!#;W)R96-T86UE
M;G1E`%1A<F5F87,`3R!N^FUE<F\@9&5B92!S97(@<&]L;R!M96YO<R!U;B`Q
M+@!/('9A;&]R(&1E8F4@<V5R('5N(&[Z;65R;RX`5.UT=6QO`%523`!.;VX@
M9F]I('!O<VEB;&4@8V]N96-T87)S92#S('-E<G9I9&]R(%-13"X`3F]N(&9O
M:2!P;W-I8FQE('1R861U8VER(&5S=&4@9&]C=6UE;G1O(&1E(%=O<F0`1&5S
M9F%C97(@;W,@8V%M8FEO<P!/<&-I\VYS(&1O('5S=6%R:6\`57-U87)I;P!!
M=FES;P!396UA;F%L;65N=&4`0F5N=FED82!A("5S`$)E;G9I9&\O82P@)7,`
M16YD97)E>F\@9&\@=')A8F%L;&\`5&5LZ69O;F\@9&\@=')A8F%L;&\`04$`
M06YU86QM96YT90!$97-C<FEB82!O('!R;V)L96UA(&%N=&5S(&1E(&5N=FEA
M<B!O(&EN9F]R;64N`$-A9'5C;W4@82!S^F$@<V5S:?-N(&5N("5S(&5X<&ER
M;W4N($EN:6-I92!U;FAA(&YO=F$@<V5S:?-N+@!!('/Z82!I;F9O<FUA8VGS
M;@!!8W1U86QI>N%R;VYS92!A<R!S^F%S(&]P8VGS;G,N`%M);F9O<FUE(&1O
M(%!R;V)L96UA70!;;&GQ82`E<R!D92`E<UT`5&%R>&5T82!D92!V:7-I=&$@
M*'9#87)D*0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VAE7TE,+P``
M````````````````````````````````````````````````````````````
M```````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#4Q-30S,S<U,P`P,C`P-S4`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L;V-A;&4O:&5?24PO3$-?34534T%'15,O````````````````````````
M`````````````````````````````````````````#`P,#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S4S`#`R,38V,@`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]H95])3"],0U]-15-304=%4R]H
M;W)D92YM;P``````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3<S,#(`,3`U,34T
M,S,W-3,`,#(S,S(S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````-X2!)4`````J0```!P```!D!0``XP```*P*````````.`X`
M``P````Y#@``"P```$8.```'````4@X```<```!:#@``"@```&(.```)````
M;0X```<```!W#@``"0```'\.```'````B0X```<```"1#@``!P```)D.```*
M````H0X```<```"L#@``!@```+0.```'````NPX```@```###@``!@```,P.
M```1````TPX```<```#E#@``"````.T.```(````]@X```8```#_#@``!@``
M``8/```*````#0\``!@````8#P``!````#$/```%````-@\```4````\#P``
M!0```$(/```&````2`\```@```!/#P``!0```%@/```*````7@\```0```!I
M#P``!@```&X/```.````=0\```<```"$#P``$@```(P/```'````GP\```4`
M``"G#P``"P```*T/```(````N0\```0```#"#P``!P```,</```#````SP\`
M``8```#3#P``!0```-H/```&````X`\```<```#G#P``!P```.\/```%````
M]P\```(```#]#P``!@`````0```'````!Q````D````/$```!@```!D0```&
M````(!````4````G$```#0```"T0```$````.Q```!T```!`$```"````%X0
M```(````9Q````H```!P$```!P```'L0```'````@Q````4```"+$```"0``
M`)$0```9````FQ````0```"U$```!P```+H0```&````PA````4```#)$```
M!P```,\0```%````UQ````8```#=$```!0```.00```&````ZA````<```#Q
M$```!P```/D0```6`````1$```H````8$0``"@```",1```&````+A$```@`
M```U$0``"````#X1```$````1Q$```4```!,$0``"@```%(1```)````71$`
M``8```!G$0``!@```&X1```(````=1$```<```!^$0``"@```(81```$````
MD1$```4```"6$0``"P```)P1```+````J!$```D```"T$0``!0```+X1```'
M````Q!$```8```#,$0``!````-,1```'````V!$```4```#@$0``"````.81
M```&````[Q$```@```#V$0``"````/\1```)````"!(```H````2$@``!```
M`!T2```+````(A(```8````N$@``"````#42```%````/A(```<```!$$@``
M$@```$P2```&````7Q(```P```!F$@``!@```',2```'````>A(```H```""
M$@``#````(T2```)````FA(```<```"D$@``#````*P2```%````N1(```D`
M``"_$@``!0```,D2```(````SQ(```D```#8$@``!@```.(2```+````Z1(`
M`!0```#U$@``'`````H3```(````)Q,```4````P$P``$P```#83```'````
M2A,```8```!2$P```P```%D3```$````71,```8```!B$P``!P```&D3```4
M````<1,```X```"&$P``#0```)43```&````HQ,```<```"J$P``"````+(3
M```'````NQ,```D```##$P``!P```,T3```(````U1,```0```#>$P``!0``
M`.,3```&````Z1,```4```#P$P``"@```/83```&`````10```@````(%```
M!0```!$4```(````%Q0```@````@%```#````"D4```$````-A0``$X!```[
M%```$P```(H5```0````GA4```P```"O%0``#````+P5```?````R14``!``
M``#I%0``#````/H5```0````!Q8```X````8%@``$0```"<6```,````.18`
M``P```!&%@``"@```%,6```(````7A8```X```!G%@``#@```'86```*````
MA18```P```"0%@``#@```)T6```.````K!8```H```"[%@``"````,86```&
M````SQ8```\```#6%@``+@```.86```$````%1<```@````:%P``!@```",7
M```3````*A<``!<````^%P``$````%87```*````9Q<``!,```!R%P``"```
M`(87```.````CQ<```@```">%P``"````*<7```I````L!<```X```#:%P``
M"@```.D7```5````]!<```X````*&```"````!D8```,````(A@```@````O
M&```"````#@8```(````01@```H```!*&```#````%48```,````8A@```8`
M``!O&```!````'88```(````>Q@```H```"$&```#@```(\8```*````GA@`
M``H```"I&```"@```+08```<````OQ@```@```#<&```"@```.48```.````
M\!@```@```#_&```"0````@9```.````$AD```P````A&0``"````"X9```2
M````-QD```@```!*&0``"````%,9```,````7!D```P```!I&0``#````'89
M```,````@QD```8```"0&0``"````)<9```(````H!D```P```"I&0``"@``
M`+89```,````P1D```8```#.&0``$@```-49```,````Z!D```H```#U&0``
M#@`````:```?````#QH```8````O&@``"````#8:```2````/QH``!(```!2
M&@``#````&4:```*````<AH``!````!]&@``"@```(X:```.````F1H```0`
M``"H&@``!@```*T:```*````M!H``!,```"_&@``$````-,:```(````Y!H`
M``P```#M&@``$````/H:```*````"QL``!`````6&P``!@```"<;```,````
M+AL```@````[&P``#@```$0;```*````4QL```L```!>&P``#````&H;```&
M````=QL``!0```!^&P``"@```),;```.````GAL```8```"M&P``#````+0;
M```*````P1L```P```#,&P``%0```-D;```*````[QL```@```#Z&P``$P``
M``,<```5````%QP```X````M'```#````#P<```7````21P```@```!A'```
M#P```&H<```(````>AP```P```"#'```$````)`<```,````H1P```H```"N
M'```"@```+D<```,````Q!P```P```#1'```(````-X<```;````_QP```X`
M```;'0``#@```"H=```&````.1T```<```!`'0``#````$@=```0````51T`
M`",```!F'0``&P```(H=```7````IAT```H```"^'0``$````,D=```<````
MVAT```P```#W'0``#@````0>```*````$QX```\````>'@``!@```"X>```'
M````-1X```@````]'@``"````$8>```2````3QX```P```!B'@``$````&\>
M```(````@!X```X```")'@``$````)@>```3````J1X```0```"]'@```0``
M`*````!`````````````````````I@```*,````I````$P````````!B````
M&````!````!,``````````<````Z````,@```&,```"-````&@````````!*
M````6@```%X```!'````:@````P```!?````)````!4````H````,````((`
M``!U````0@```)(```!;````D0```)@````]````,0````H````&````&0``
M`',````````````````````N````'@`````````C`````@``````````````
M````````````````.0```%<`````````'````&D``````````````&0```!Q
M````*P```"8```!=````=P```$X```!)````-````($```!X`````````&<`
M``!O````@P````0```"I````C@```!8````M````9@````T```":````(@``
M`!T````2````2P```*4`````````B@`````````L````>0```)X`````````
M`````#\`````````E@```&$```!\````90```&@`````````A0```#4```![
M````@````"<````?````&P````````!6````+P```(<```"7`````````'\`
M``!^`````````%(```"D````;`````4````\````G0`````````#````````
M````````````.P```````````````````%````````````````````"A````
M7`````````!%````1@```#,``````````````!<`````````H@```$,`````
M````:P```!0````W````00`````````/````(````)D```"(````50```"4`
M```1````A```````````````"0```&X``````````````'0```!Z````````
M```````^````4P```*@``````````````)P```!/````-@```(P```"/````
M8````)4`````````6````(L`````````B0```$@```"?````=@````````!-
M````E````$0````J`````````"$```!M````DP````L```"G````<````%$`
M``!9````FP````@`````````?0```%0```"0````<@```#@`````````A@``
M``X`````061D<F5S<R!";V]K`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I
M80!!;G1A<F-T:6-A`$%R9V5N=&EN80!!<FUE;FEA`$%U<W1R86QI80!!=7-T
M<FEA`$)A:&%M87,`0F%H<F%I;@!"86YG;&%D97-H`$)E;&=I=6T`0F5L:7IE
M`$)O;&EV:6$`0F]T<W=A;F$`0G)A>FEL`$)R=6YE:2!$87)U<W-A;&%M`$)U
M<G5N9&D`0V%M8F]D:6$`0V%M97)O;VX`0V%N861A`$-A;F-E;`!#87!E(%9E
M<F1E`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#:&%D`$-H:6QE`$-H:6YA
M`$-L96%R`$-L;W5D>0!#;VQO;6)I80!#;VYG;P!#;W-T82!2:6-A`$-U8F$`
M0WEP<G5S`$-Z96-H(%)E<'5B;&EC`$1E;FUA<FL`1&]M:6YI8V%N(%)E<'5B
M;&EC`$5C=6%D;W(`16=Y<'0`16P@4V%L=F%D;W(`171H:6]P:6$`1FEJ:0!&
M:6YL86YD`$9O9P!&<F%N8V4`1V%B;VX`1V%M8FEA`$=E;W)G:6$`1V5R;6%N
M>0!':&%N80!';P!'<F5E8V4`1W)E;F%D80!'=6%T96UA;&$`1W5I;F5A`$=U
M>6%N80!(86ET:0!(96%V>2!4+5-T;W)M`$AE;'``2&]L>2!3964@*%9A=&EC
M86X@0VET>2!3=&%T92D`2&]N9'5R87,`2'5M:61I='D`2'5M:61I='DZ(`!(
M=6YG87)Y`$EC96QA;F0`26YD:6$`26YD;VYE<VEA`$ER86XL($ES;&%M:6,@
M4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES<F%E;`!)=&%L>0!*86UA:6-A
M`$IA<&%N`$IO<F1A;@!+96YY80!+=7=A:70`3&5B86YO;@!,:6)E<FEA`$QI
M8GEA;B!!<F%B($IA;6%H:7)I>6$`3'5X96UB;W5R9P!-861A9V%S8V%R`$UA
M;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA=7)I=&%N:6$`
M36%U<FET:75S`$UE>&EC;P!-;VYA8V\`36]N9V]L:6$`36]R;V-C;P!-;WIA
M;6)I<75E`$YA;64`3F5P86P`3F5T:&5R;&%N9',`3F5W(%IE86QA;F0`3FEC
M87)A9W5A`$YI9V5R`$YI9V5R:6$`3F]R=V%Y`$]M86X`3W!T:6]N<P!/=&AE
M<@!086MI<W1A;@!086YA;6$`4&%R86=U87D`4&%S<W=O<F0`4&%S<W=O<F0Z
M`%!A<W-W;W)D.B``4&5R=0!0:&EL:7!P:6YE<P!0;VQA;F0`4&]R='5G86P`
M46%T87(`4F]M86YI80!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%-A=61I
M($%R86)I80!396%R8V@`4V5N96=A;`!397EC:&5L;&5S`%-I97)R82!,96]N
M90!3:6YG87!O<F4`4V]M86QI80!3;W5T:"!!9G)I8V$`4W!A:6X`4W)I($QA
M;FMA`%-U9&%N`%-U<FEN86UE`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA
M;F0`4WER:6%N($%R86(@4F5P=6)L:6,`5&%N>F%N:6$L(%5N:71E9"!297!U
M8FQI8R!O9@!4:&%I;&%N9`!4;VYG80!4<FEN:61A9"!A;F0@5&]B86=O`%1U
M;FES:6$`5'5R:V5Y`%523`!54DPZ`%5G86YD80!5:W)A:6YE`%5N:71E9"!!
M<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`57!L
M;V%D`%5R=6=U87D`57-E<FYA;64`5F%N=6%T=0!696YE>G5E;&$`5F5R<VEO
M;@!6:65T($YA;0!7:6YD`%=I;F0Z`%=I;F0Z(`!996UE;@!9=6=O<VQA=FEA
M`%IA;6)I80!::6UB86)W90!?2&5L<`!?3&]G(&]U=`!?3W!T:6]N<P!A9&1R
M97-S(&)O;VL`;F%M90!0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,BUC
M=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*
M4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#(M,#<@,#0Z,#@M,#4P,`I03RU2
M979I<VEO;BU$871E.B`R,#`V+3`R+3`W(#`T.C`X+3`U,#`*3&%S="U4<F%N
M<VQA=&]R.B!-871T(%-E;'-K>2`\<V5L<VMY0&-O;'5M8FEA+F5D=3X*3&%N
M9W5A9V4M5&5A;3H@:3$X;D!L:7-T<RYH;W)D92YO<F<*34E-12U697)S:6]N
M.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/5541BTX
M"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`->AUZ37J"#7F]>J
MUY77D=>5UZH`UY#7I->2UZ#7F=>AUZK7GP#7D-><UY'7H->9UY0`UY#7G->2
MUZC7F=>4`->9UY'7J=>JXH"3UY#7H->8UY#7J->GUYC7F=>GUY0`UY#7J->2
MUZ#7F->9UZ#7E`#7D->HUY[7H->9UY0`UY#7E=>AUYC7J-><UYG7E`#7D->5
MUZ'7F->HUYG7E`#7D->9UYGB@)/7D=>4UY[7E`#7D=>7UZC7F=>9UY\`UY'7
MH->2UYS7D]>I`->1UYS7DM>9UY0`UY'7G->9UY8`UY'7E=><UYG7D=>9UY0`
MUY'7E=>FUY77E=>@UY0`UY'7J->6UYG7G`#7D=>HUY77H->9UYD`UY'7E=>H
MUY77H->3UYD`UZ?7GM>1UY77D]>9UY0`UZ?7GM>HUY77GP#7I]>@UY/7E`#7
MJ=>@UY0`UZ?7I->4(->5UZC7D]>4`->4UZ?7E->9UYS7F=>9UY0@UY37GM>H
MUYO7EN*`D]>0UZ37J->9UZ?7H->9UZH`UZ;7DP#7IM>9UYS7F0#7H=>9UY\`
MUZG7GM>9UYT@UY'7E->9UZC7G0#7J=>>UYG7G2#7GM>BUY77H->@UYG7G0#7
MI]>5UYS7E=>>UY'7F=>4`->GUY77H->2UY4`UZ?7E=>AUYC7E"#7J->9UZ?7
ME`#7I]>5UY'7E`#7I]>DUZC7F=>AUYG7GP#7IM>;UYG7E`#7D]>@UYG7E`#7
ME->HUZ37E=>1UYS7F=>GUY0@UY37D]>5UY[7F=>@UYG7I]>@UYG7J@#7D->G
MUY77E=>3UY77J`#7GM>FUZC7F=>=`->0UYSB@)/7H=><UY77E=>3UY77J`#7
MD->JUYG7E=>DUYG7E`#7I->9UY+7F0#7I->9UZ#7G->@UY,`UZ+7J->DUYP`
MUZ;7J->DUZH`UY+7D=>5UY\`UY+7GM>1UYG7E`#7DM>5UZC7DM>9UY0`UY+7
MJ->>UZ#7F=>4`->2UZ#7E`#7G->:`->9UY77E=>?`->2UZC7H->3UY0`UY+7
ME=>0UYC7GM><UY0`UY+7F=>@UY#7E`#7DM>9UY#7H->4`->4UY#7F=>8UYD`
MUZ'7E=>DUZKB@)/7J->BUY[7F=>=(->BUY;7E`#7HM>6UZC7E`#7E=>8UYG7
MI]>?`->4UY77H->3UY77J->A`-><UY?7E=>J`#K7G->7UYG7J@#7E->5UZ#7
MDM>HUYG7E`#7D->9UZ'7G->@UY,`UY37E=>3UY4`UY#7F=>@UY/7E=>@UY;7
MF=>4`->0UYG7J->?`->BUYG7J->G`->0UYG7J-><UZ#7DP#7F=>IUX'7J->0
MUYP`UY#7F=>8UYS7F=>4`->2UY[7F=>9UZ?7E`#7F=>DUY\`UYG7J->3UY\`
MUZ?7H->9UY0`UYO7E=>5UYG7F=>J`-><UY'7H->5UY\`UYS7F=>1UZC7F=>4
M`-><UY77D0#7G->5UYO7H=>>UY'7E=>HUY(`UY[7D]>2UZ'7I]>H`->>UYS7
ME=>5UYD`UY[7G->9UYG7EM>9UY0`UY37D->9UYG7G2#7E->>UYS7D]>9UY77
ME=>9UYG7G0#7GM><UYD`UY[7G->8UY0`UY[7D->5UZC7F=>8UZ#7F=>4`->>
MUY#7E=>HUYG7IM>9UY77H0#7GM>;UZ'7F=>GUY4`UY[7E=>@UZ?7E0#7GM>5
MUZ#7DM>5UYS7F=>4`->>UZC7E=>GUY4`UY[7E=>6UY[7D=>9UZ<`UZG7G0#7
MH->DUYP`UY37E=><UZ#7DP#7H->9UY7B@)/7EM>9UYS7H->3`->@UYG7I]>H
MUY+7E=>0UY0`UZ#7F=>6UZ@`UZ#7F=>2UZC7F=>4`->@UY77J->5UY77DM>9
MUY0`UZ+7E=>>UY#7GP#7D->DUZG7J->5UYG7E=>J`->0UY?7J`#7I->GUYG7
MH=>JUY\`UZ37H->>UY0`UZ37J->2UY77D->9UYD`UZ'7F=>AUY[7D`#7H=>9
MUZ'7GM>0.@#7H=>9UZ'7GM>0.B``UZ37J->5`->DUYG7G->9UZ37F=>@UYG7
MF=>=`->DUY77G->9UY\`UZ37E=>HUYC7E=>2UYP`UZ?7F->H`->HUY77GM>@
MUYG7E`#7J->5UZ'7F=>4`->HUY77D->@UY/7E`#7HM>HUY$@UY37H=>BUY77
MD]>9UZH`UY?7F=>DUY77J0#7H=>@UY+7G`#7D->9UYGB@)/7H=>9UYG7J=><
M`->GUYG7F=>HUY0@UYS7F=>0UY77GP#7H=>9UZ#7DM>DUY77J`#7H=>5UY[7
MG->9UY0`UY/7J->5UYWB@)/7D->DUZC7F=>GUY0`UZ'7I->HUY,`UZ'7J->9
M(-><UZ#7I]>4`->AUY77D]>?`->AUY77J->9UZ#7G0#7H=>5UY77EM>9UYS7
MH->3`->IUY77E=>3UYG7E`#7J=>5UY77F=>E`->AUY77J->9UY0`UYC7H->6
MUZ#7F=>4`->JUY#7F=><UZ#7DP#7I]>1UY77IM>JXH"3UY#7F=>9XH"3UYC7
ME=>@UY+7E`#7F->HUYG7H->9UY/7DR#7E=>8UY77D=>2UY4`UYC7E=>@UYG7
MH=>9UY0`UYC7E=>HUZ?7F=>9UY0`UY#7JM>H`->0UZK7J#H`UY#7E=>2UZ#7
MD]>4`->0UY77I]>HUYG7F=>@UY0`UY37D->>UYG7J->5UYG7E=>J(->4UY[7
MD->5UY?7D]>5UZH`UY37GM>>UYS7F]>4(->4UY[7D->5UY?7D]>J`->0UZC7
MIM>5UZKB@)/7E->1UZC7F=>J`->4UZ+7G->0UY0`UY#7E=>HUY77DM>5UY77
MF0#7I]>5UY,@UY;7F=>4UY77F2#7GM>IUZK7GM>I`->5UZ#7E=>0UYC7E0#7
ME=>@UY;7E=>0UYS7E`#7DM>9UZC7H=>4`->5UYG7F=>8XH"3UZ#7G0#7J->5
MUY<`UZC7E=>7.@#7J->5UY<Z(`#7JM>9UY[7GP#7F=>5UY+7E=>AUYS7D=>9
MUY0`UY;7GM>1UYG7F=>4`->6UYG7GM>1UY'7E=>5UY0`UZ+7EM>HUY0`UY37
MJM>@UZK7I]>5UZH`UY#7I->IUZC7E=>9UY77J@#7H=>DUZ@@UYO7JM>5UY'7
ME=>J`->IUYT`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O
M:'5?2%4O````````````````````````````````````````````````````
M`````````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S4S`#`R,#$R-0`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQO8V%L92]H=5](52]H96QP+GAM;```````````````````
M````````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0P-S8`,3`U,34T,S,W-3,`,#(Q
M-C`V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_>&UL('9E<G-I;VX](C$N,"(@96YC;V1I;F<](FES;RTX.#4Y+3(B/SX*
M/"$M+2!(;W)D92`S+C$@:&5L<#H@:'5?2%4@)$AO<F1E.B!H;W)D92]L;V-A
M;&4O:'5?2%4O:&5L<"YX;6PL=B`Q+C(N,3`N,R`R,#`V+S`S+S`S(#$S.C0T
M.C$P(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)S=6UM87)Y
M(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB-CAC83,S9C=F,&,Y86%E-&,Q,#-E
M8C0W-#DR8V1C,34B/@H\=&ET;&4^02!S>F5MZ6QY97,@]G-S>F5G>O4@*'!O
M<G3A;"D@;VQD86P\+W1I=&QE/@H@/'!A<F$^"B`@17H@87H@;VQD86P@9WEO
M<G,@]G-S>F5G>NES="!A9"!A>B#6;B!S>N%MX7)A(&9O;G1O<R!I;F9O<FWA
M8VGS:W+S;"X*("!0;"X@:F5L97IH971I+"!H;V=Y(&CA;GD@^FH@;&5V96QE
M('9A;B!A>B!)3D)/6"!M87!PX6)A;BP@;6EL>65N(`H@(&5L9F]G;&%L='/A
M9V%I('9A;FYA:R!B9>UR=F$@82!K]GIE;&KV=O5B96X@82!N87!TX7)B86XL
M(&UI;'EE;@H@(&5L:6YTZ7IE;F3U(&1O;&=O:R!V86YN86L@82!F96QA9&%T
M;&ES=.%JX6)A;BP@9&4@;65G:F5L96[M=&AE=/4*("!E9WGI8B!K_&QS]2!S
M>F]L9^%L=&%TX7-O:R!T87)T86QM82!I<RP@<W1B+B!%>F5K8O5L(&%Z(/9S
M<WIE9WKI<V5K8O5L"B`@<V]K<WIO<B!K]GIV971L96[\;"!I;F3M=&AA=/-K
M(&$@9WEA:W)A;B!H87-Z;N%L="!F=6YK8VGS:RP@<&PN"B`@^FH@;&5VZ6P@
M[7+A<V$L(/IJ(&)E:F5G>7KI<R!KZ7-Z[73I<V4@82!N87!TX7)B82!V86=Y
M(&$@9F5L861A=&QI<W3A8F$L(`H@('-T8BX*("`\+W!A<F$^"B`\<&%R83X*
M("!%('-Z96WI;'EE<R#V<W-Z96=Z]2!O;&1A;"!T87)T86QMX70@82!497)V
M97KI<R!G;VUB8F%L(&WS9&]S[71H871J82X*("!-96=A9&AA=&IA('!L+BP@
M:&]G>2!M:6QY96X@:6YF;W)MX6-I\VMA="!K[7;A;B!M96=J96QE;NUT96YI
M+"#I<PH@(&UI;'EE;B!E;')E;F1E>NES8F5N+@H@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB;F%V8F%R(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB
M8CAC9C!A93$Y934W9&9A,&,R8CDV,F4U,38W.#)F-#<B/@H\=&ET;&4^07H@
M86QK86QM87KA<W;A;&%S>G3S(&UE;OP\+W1I=&QE/@H@/'!A<F$^"B`@02!W
M96)O;&1A;"!B86P@;VQD86SA;B!E9WD@86QK86QM87KA<W;A;&%S>G3S(&UE
M;OP@=&%LX6QH873S+@H@($$@;65G9F5L96SU(&9E;&ER871O:W)A(&MA='1I
M;G1V82!G>6]R<V%N(.ES(&OV;FYY96X@X71U9V]R:&%T(&5G>6EK"B`@86QK
M86QM87KA<V+S;"!A(&WA<VEK8F$N"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4](G5P=&]D871E
M(B!M9#4](F1D.35D9C`W83`S,#,Q,C,R8F%E83DQ.3(X.&(R9#`P(CX*("`@
M(#QT:71L93Y/<&-I\VLZ($)E:F5L96YT:V5ZZ7-S96P@:V%P8W-O;&%T;W,@
M9F5L861A=&]K.B!VZ6=R96AA:G3A<SPO=&ET;&4^"B`@("`\<&%R83X*("`@
M($AA(&%Z="!S>F5R971NZ2P@:&]G>2!B96IE;&5N=&ME>NES:V]R(&9U<W-A
M;F%K"B`@("!L92!A(&MA<F)A;G1A<G3A<VD@9F5L861A=&]K+"!J96SV;&IE
M(&)E(&$@;NEG>7IE=&5T+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC92(@<W1A=&4](G5P=&]D
M871E(B!M9#4](F$R,3$V,F-D9F8S8C%D.&9A96%D8C<R.38R-#`P,S9E(CX*
M("`@(#QT:71L93Y/<&-I\VLZ($)E:F5L96YT:V5ZZ7-S96P@:V%P8W-O;&%T
M;W,@9F5L861A=&]K.B!M96=E<O5S[73I<SPO=&ET;&4^"B`@("`\<&%R83X*
M("`@($AA(&%Z="!S>F5R971NZ2P@:&]G>2!A(')E;F1S>F5R(&UE9V5R]7/M
M=.ES="!KZ7)J96X@UFYT]6P@;6EE;/5T=`H@("`@=NEG<F5H86IT86[A(&$@
M:V%R8F%N=&%R=.%S:2!F96QA9&%T;VMA="P@:F5L]FQJ92!B92!E>G0@82!N
MZ6=Y>F5T970N"B`@("!(82!N96T@:F5L]FQI(&)E+"!A(&MA<F)A;G1A<G3A
M<VD@9F5L861A=&]K(&)E:F5L96YT:V5ZZ7-K;W(@875T;VUA=&EK=7-A;B`*
M("`@(&QE(&9O9VYA:R!F=71N:2P@86[I;&O\;"P@:&]G>2!B969O;'GA<V]L
M:&%T;N$@]6ME="X*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]H=5](52],0U]-15-304=%
M4R\`````````````````````````````````````````````````````````
M````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U
M,34T,S,W-3,`,#(Q-S$R`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE
M+VAU7TA5+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#0R,S$P-0`Q,#4Q-30S,S<U,P`P,C,S-34`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````WA($E0````!S!P``'```
M`+0[``#O"0``3'<````````(GP``#@````F?```/````&)\```T````HGP``
M"````#:?```+````/Y\```P```!+GP``!````%B?```8````79\``!L```!V
MGP``+0```)*?```=````P)\``"0```#>GP``*0````.@```9````+:```"8`
M``!'H```#````&Z@```D````>Z````\```"@H```"P```+"@```.````O*``
M`"@```#+H```"````/2@```*````_:```!4````(H0``$@```!ZA```+````
M,:$``(4````]H0``#@```,.A```*````TJ$```T```#=H0``#@```.NA```1
M````^J$```T````,H@``#````!JB```-````)Z(``)0````UH@``"@```,JB
M```/````U:(``!@```#EH@``#````/ZB```.````"Z,```X````:HP``"```
M`"FC```)````,J,``"X````\HP``&@```&NC```R````AJ,``#@```"YHP``
M5````/*C``!1````1Z0``%H```"9I```5P```/2D```T````3*4```D```"!
MI0``#0```(NE```'````F:4```H```"AI0``#P```*RE```%````O*4```8`
M``#"I0``$0```,FE```(````VZ4```D```#DI0``"0```.ZE```E````^*4`
M`"`````>I@``$P```#^F```0````4Z8```\```!DI@``"@```'2F```#````
M?Z8```\```"#I@``%````).F```)````J*8```T```"RI@``$@```,"F```9
M````TZ8``!X```#MI@``#P````RG```*````'*<```\````GIP``"````#>G
M```D````0*<``!0```!EIP``%@```'JG```(````D:<``$X```":IP``+0``
M`.FG```9````%Z@```<````QJ```#````#FH```L````1J@```X```!SJ```
M`P```(*H```+````AJ@```<```"2J```!P```)JH```%````HJ@```4```"H
MJ```"@```*ZH```#````N:@``!<```"]J```"@```-6H```/````X*@```X`
M``#PJ```&````/^H```C````&*D```X````\J0``%````$NI```7````8*D`
M`!<```!XJ0``%P```)"I```3````J*D```\```"\J0``#@```,RI```?````
MVZD``!T```#[J0``!P```!FJ```&````(:H```@````HJ@``#P```#&J```&
M````0:H```H```!(J@``$P```%.J```+````9ZH``!````!SJ@``%0```(2J
M```5````FJH```<```"PJ@``$````+BJ```%````R:H``!4```#/J@``$0``
M`.6J```,````]ZH``#L````$JP``.````$"K```)````>:L```<```"#JP``
M%````(NK```#````H*L```4```"DJP``$````*JK```)````NZL``!,```#%
MJP``.0```-FK```2````$ZP``"<````FK```+````$ZL```J````>ZP``"4`
M``"FK```"@```,RL```&````UZP```D```#>K```!P```.BL```O````\*P`
M`#<````@K0``+@```%BM``!5````AZT``"T```#=K0``+0````NN```]````
M.:X``#\```!WK@``+0```+>N``!`````Y:X``",````FKP``(P```$JO``!`
M````;J\``"T```"OKP``,P```-VO```E````$;```!4````WL```&0```$VP
M```I````9[```"0```"1L```*````+:P```1````W[````H```#QL```#```
M`/RP```*````";$``!`````4L0``%@```"6Q```6````/+$```<```!3L0``
M!P```%NQ```4````8[$```H```!XL0``"````(.Q```G````C+$```@```"T
ML0``!P```+VQ```'````Q;$```8```#-L0``!0```-2Q```'````VK$```8`
M``#BL0``"````.FQ```I````\K$```X````<L@``"@```"NR```$````-K(`
M``<````[L@``"0```$.R```&````3;(``!$```!4L@``!P```&:R```6````
M;K(```0```"%L@``"````(JR```&````D[(```T```":L@``!@```*BR```>
M````K[(``!$```#.L@``"````."R```-````Z;(```P```#WL@``!P````2S
M```#````#+,```,````0LP``%P```!2S```3````++,``!T```!`LP``"```
M`%ZS```$````9[,```@```!LLP``"````'6S``!!````?K,``!H```#`LP``
M*P```-NS```@````![0``!4````HM```!@```#ZT```&````1;0``!4```!,
MM```&````&*T```B````>[0``"X```">M```'0```,VT```A````Z[0``%0`
M```-M0``*0```&*U```*````C+4```<```"7M0``!P```)^U```5````I[4`
M``X```"]M0``"@```,RU```/````U[4```T```#GM0``#P```/6U```-````
M!;8```D````3M@``%````!VV```&````,K8``!@````YM@``'0```%*V```3
M````<+8``!$```"$M@``%````):V```$````J[8```8```"PM@``%````+>V
M``!4````S+8``&0````AMP``!````(:W```.````B[<```4```":MP``!0``
M`*"W```;````IK<``!H```#"MP``$P```-VW```1````\;<``!$````#N```
M'````!6X```J````,K@``!````!=N```(0```&ZX```%````D+@``!,```"6
MN```"P```*JX```2````MK@```H```#)N```#P```-2X```-````Y+@``!$`
M``#RN```$P````2Y```,````&+D```8````EN0``#````"RY```&````.;D`
M`!<```!`N0``$````%BY```1````:;D```@```![N0``!0```(2Y```,````
MBKD``!````"7N0``!0```*BY```-````KKD```8```"\N0``!P```,.Y```-
M````R[D```<```#9N0``"P```.&Y```'````[;D```<```#UN0``"0```/VY
M```)````![H```H````1N@``&0```!RZ```]````-KH``!T```!TN@``#```
M`)*Z```0````G[H```4```"PN@``)0```+:Z```2````W+H``!,```#ON@``
M*P````.[```[````+[L``"````!KNP``"````(R[```V````E;L``"$```#,
MNP``$````.Z[```(````_[L```P````(O```!@```!6\```$````'+P```\`
M```AO```#@```#&\```'````0+P```H```!(O```#0```%.\```?````8;P`
M`!P```"!O```(0```)Z\```>````P+P``!D```#?O```'@```/F\```;````
M&+T``"$````TO0``+@```%:]```F````A;T``!P```"LO0``'@```,F]```<
M````Z+T``"8````%O@``*P```"R^```S````6+X``"8```",O@``*P```+.^
M```X````W[X``!T````8OP``%0```#:_```O````3+\``"````!\OP``$@``
M`)V_```I````L+\``!X```#:OP``(````/F_```2````&L```*(````MP```
M%@```-#````C````Y\```"@````+P0``*0```#3!```H````7L$``!\```"'
MP0``%0```*?!```@````O<$``"4```#>P0``*`````3"```M````+<(``#``
M``!;P@``D@```(S"```A````'\,``!8```!!PP``'````%C#```F````=<,`
M`"H```"<PP``00```,?#``!$````"<0```P```!.Q```!P```%O$```'````
M8\0```8```!KQ```#0```'+$```0````@,0``!(```"1Q```$P```*3$```2
M````N,0```<```#+Q```!````-/$```0````V,0``!````#IQ```#````/K$
M```.````!\4```T````6Q0``#P```"3%```3````-,4```T```!(Q0``*```
M`%;%```#````?\4```T```"#Q0``!@```)'%```1````F,4``!<```"JQ0``
M&P```,+%```.````WL4```(```#MQ0``20```/#%```%````.L8``!````!`
MQ@``#P```%'&```$````8<8```T```!FQ@``#@```'3&```#````@\8```X`
M``"'Q@``"````);&```/````G\8```\```"OQ@``!P```+_&```-````Q\8`
M`!````#5Q@``#0```.;&```+````],8```8`````QP``"P````?'```,````
M$\<```H````@QP``$0```"O'```9````/<<```L```!7QP``#0```&/'```B
M````<<<```\```"4QP``&P```*3'```T````P,<```H```#UQP``&`````#(
M```2````&<@``!D````LR```%@```$;(```B````7<@```T```"`R```!P``
M`([(```4````EL@```L```"KR```(@```+?(```O````VL@```L````*R0``
M"0```!;)```9````(,D```L````ZR0``%P```$;)```7````7LD```D```!V
MR0``%@```(#)```/````E\D``!D```"GR0``%@```,')```.````V,D``!@`
M``#GR0``"`````#*```-````"<H``"8````7R@``0P```#[*```(````@LH`
M`!(```"+R@``'P```)[*```(````OLH```L```#'R@``+P```-/*```.````
M`\L```4````2RP``!@```!C+``!%````'\L```,```!ERP``!P```&G+```$
M````<<L```H```!VRP``"@```('+```/````C,L``!````"<RP``%P```*W+
M```1````Q<L``!D```#7RP``%P```/'+```)````"<P```4````3S```"P``
M`!G,```*````)<P```(````PS```!0```#/,```-````.<P``!L```!'S```
M%P```&/,```4````>\P```D```"0S```#@```)K,```-````J<P``!(```"W
MS```.````,K,```@`````\T```@````DS0``#@```"W-``![````/,T``!@`
M``"XS0``&````-'-```1````ZLT```<```#\S0``!0````3.```8````"LX`
M`!X````CS@``&P```$+.```9````7LX``!L```!XS@``&0```)3.```3````
MKLX```<```#"S@``"````,K.```&````T\X```8```#:S@``$````.'.```/
M````\LX``!`````"SP``#P```!//```+````(\\```\````OSP``#````#_/
M```/````3,\```<```!<SP``!@```&3/```.````:\\```P```!ZSP``*```
M`(?/```/````L,\```@```#`SP``"````,G/```3````TL\``!X```#FSP``
M(0````70```@````)]```!D```!(T```%P```&+0```E````>M```!<```"@
MT```%@```+C0```$````S]```!L```#4T```#0```/#0```,````_M````,`
M```+T0``!0````_1```(````%=$```H````>T0``#````"G1```+````-M$`
M`!````!"T0``#````%/1```.````8-$```0```!OT0``!````'31```3````
M>=$``!0```"-T0``#````*+1```)````K]$```X```"YT0``"P```,C1```;
M````U-$```<```#PT0``!P```/C1```*`````-(```T````+T@``"0```!G2
M```$````(](```,````HT@``&````"S2```*````1=(```0```!0T@``)@``
M`%72```.````?-(``'P```"+T@``%0````C3```%````'M,```<````DTP``
M#````"S3```(````.=,```H```!"TP``!@```$W3```(````5-,```(```!=
MTP``!@```&#3```&````9],``!0```!NTP``#0```(/3```0````D=,``!L`
M``"BTP``!````+[3```)````P],``!````#-TP``"0```-[3```)````Z-,`
M``4```#RTP``&@```/C3```(````$]0```8````<U```&0```"/4```.````
M/=0```<```!,U```!P```%34```%````7-0```D```!BU```"@```&S4```.
M````=]0```(```"&U```!@```(G4```+````D-0```T```"<U```"0```*K4
M```&````M-0``!(```"[U```"0```,[4```'````V-0``!0```#@U```'0``
M`/74``!"````$]4``"4```!6U0``)0```'S5```&````HM4```H```"IU0``
M!````+35```)````N=4```@```##U0``$0```,S5```)````WM4```8```#H
MU0``#0```._5```&````_=4``#D````$U@``/0```#[6```Z````?-8``!X`
M``"WU@``!0```-;6```.````W-8```0```#KU@``!@```/#6```'````]]8`
M`"$```#_U@``#0```"'7```5````+]<```8```!%UP``!````$S7```1````
M4=<```8```!CUP``"@```&K7```B````==<```0```"8UP``!0```)W7```=
M````H]<```0```#!UP``#````,;7```.````T]<```H```#BUP``"````.W7
M```)````]M<```4`````V```.@````;8```P````0=@``#4```!RV```*0``
M`*C8``!'````TM@``#@````:V0``*0```%/9```_````?=D``"X```"]V0``
M+0```.S9```?````&MH```\````ZV@``$@```$K:```+````7=H``"8```!I
MV@``*0```)#:```D````NMH``"8```#?V@``"`````;;```*````#]L```D`
M```:VP``!P```"3;```@````+-L``"````!-VP``)@```&[;```*````E=L`
M`!D```"@VP``*0```+K;```6````Y-L``!(```#[VP``!P````[<```*````
M%MP```P````AW```#P```"[<```0````/MP``$````!/W```<````)#<``!F
M`````=T```X```!HW0``"0```'?=```*````@=T``!(```",W0``$P```)_=
M```,````L]T```8```#`W0``#P```,?=```2````U]T``!````#JW0``$0``
M`/O=```<````#=X``",````JW@``:@```$[>```/````N=X```4```#)W@``
M$````,_>```)````X-X```0```#JW@``"P```._>```@````^]X``!0````<
MWP``#````#'?```,````/M\```\```!+WP``%0```%O?```I````<=\``"H`
M``";WP``)@```,;?```G````[=\``"D````5X```*@```#_@```9````:N``
M`$(```"$X```$0```,?@```2````V>```!,```#LX```%`````#A```/````
M%>$``!8````EX0``%P```#SA```0````5.$``!$```!EX0``-````'?A```3
M````K.$``!(```#`X0``-0```-/A```4````">(```<````>X@``#````";B
M```@````,^(``!````!4X@``%````&7B```1````>N(``!<```",X@``'```
M`*3B```3````P>(``!0```#5X@``&@```.KB```1````!>,``!H````7XP``
M'@```#+C```:````4>,``!,```!LXP``%0```(#C```1````EN,``!<```"H
MXP``%````,#C```7````U>,``!4```#MXP``"0````/D```0````#>0``!D`
M```>Y```!````#CD```'````/>0```L```!%Y```$0```%'D```&````8^0`
M``8```!JY```!@```''D```%````>.0```<```!^Y```!P```(;D```%````
MCN0``!8```"4Y```!@```*OD```&````LN0```0```"YY```!````+[D```'
M````P^0```X```#+Y```#````-KD```,````Y^0```T```#TY```"@````+E
M```.````#>4```4````<Y0``*````"+E```.````2^4```P```!:Y0``#P``
M`&?E```*````=^4```@```""Y0``"0```(OE```K````E>4```0```#!Y0``
M"````,;E```F````S^4``!(```#VY0``#P````GF```&````&>8```H````@
MY@``!P```"OF```(````,^8``"`````\Y@``"0```%WF```4````9^8```P`
M``!\Y@``#0```(GF```.````E^8``!8```"FY@``$0```+WF```&````S^8`
M``,```#6Y@``!@```-KF```9````X>8```<```#[Y@``!`````/G```+````
M".<```L````4YP``!P```"#G```%````*.<```<````NYP``%@```#;G```-
M````3><```T```!;YP``"@```&GG```0````=.<```\```"%YP``$0```)7G
M```7````I^<```H```"_YP``$0```,KG```$````W.<```\```#AYP``.@``
M`/'G```%````+.@```P````RZ```'@```#_H```.````7N@``!````!MZ```
M"P```'[H```,````BN@```D```"7Z```!P```*'H```*````J>@```D```"T
MZ```#@```+[H```0````S>@``!L```#>Z```&````/KH```:````$^D```H`
M```NZ0``"0```#GI```*````0^D```P```!.Z0``#P```%OI```(````:^D`
M``8```!TZ0``'````'OI```'````F.D```4```"@Z0``"P```*;I``!'````
MLND```T```#ZZ0``"0````CJ```$````$NH```,````7Z@``$P```!OJ```3
M````+^H``!,```!#Z@``"@```%?J```"````8NH```0```!EZ@``)0```&KJ
M```#````D.H```4```"4Z@``*@```)KJ```*````Q>H```4```#0Z@``!```
M`-;J```*````V^H```T```#FZ@``!@```/3J```(````^^H```@````$ZP``
M!`````WK```%````$NL``&@````8ZP``"0```('K```,````B^L``!````"8
MZP``!0```*GK```&````K^L``!L```"VZP``+P```-+K```0`````NP```H`
M```3[```#P```![L```*````+NP```D````Y[```$P```$/L```;````5^P`
M`!@```!S[```%P```(SL```?````I.P```X```#$[````P```-/L```'````
MU^P```@```#?[```!P```.CL```*````\.P```L```#[[```!P````?M``!1
M````#^T``!````!A[0``#````'+M```-````?^T``!H```"-[0``2@```*CM
M```9````\^T```8````-[@``&@```!3N```E````+^X```8```!5[@``!@``
M`%SN```?````8^X```8```"#[@``"0```(KN```8````E.X``!<```"M[@``
M*````,7N```&````[NX```T```#U[@``(@````/O``!7````)N\``!,```!^
M[P``(P```)+O```3````MN\```(```#*[P``"P```,WO```(````V>\```T`
M``#B[P``"@```/#O```'````^^\``!0````#\```!@```!CP```(````'_``
M``X````H\```!P```#?P```*````/_````L```!*\```,@```%;P```'````
MB?````P```"1\```#0```)[P```,````K/````D```"Y\```"0```,/P```*
M````S?````<```#8\```"0```.#P```'````ZO````H```#R\```&P```/WP
M```/````&?$``!(````I\0``"@```#SQ```6````1_$```D```!>\0``$```
M`&CQ```'````>?$``!(```"!\0``!````)3Q```'````F?$```4```"A\0``
M!0```*?Q```+````K?$``!0```"Y\0``$0```,[Q```:````X/$``!8```#[
M\0``%````!+R```7````)_(``!@````_\@``'````%CR```9````=?(```<`
M``"/\@``!0```)?R```-````G?(```P```"K\@``$0```+CR```(````RO(`
M`!<```#3\@``"P```.OR```,````]_(``!\````$\P``&@```"3S```3````
M/_,```0```!3\P``"@```%CS```$````8_,```T```!H\P``#````';S```%
M````@_,```D```")\P``!0```)/S```'````F?,```4```"A\P``!````*?S
M```"````K/,``#@```"O\P``+````.CS```2````%?0``"D````H]```,@``
M`%+T```*````A?0``"P```"0]```+@```+WT```S````[/0``#,````@]0``
M.````%3U```/````C?4``!@```"=]0``$````+;U```/````Q_4``!,```#7
M]0``%0```.OU```4`````?8``!(````6]@``%````"GV```5````/O8``"T`
M``!4]@``+0```(+V```Q````L/8``"X```#B]@``+P```!'W```L````0?<`
M`&(```!N]P``$P```-'W```-````Y?<```@```#S]P``%P```/SW```(````
M%/@```P````=^```*P```"KX```A````5O@``!H```!X^```"0```)/X``!%
M````G?@``$$```#C^```!````"7Y```3````*OD``!0````^^0``#@```%/Y
M```3````8OD``!@```!V^0``!@```(_Y```)````EOD```H```"@^0``#P``
M`*OY```0````N_D```<```#,^0``#@```-3Y```%````X_D``!L```#I^0``
M"`````7Z```&````#OH``!0````5^@``$0```"KZ```.````//H``#@```!+
M^@```@```(3Z```&````A_H```X```".^@``!0```)WZ```'````H_H```X`
M``"K^@``!@```+KZ```H````P?H```P```#J^@``'````/?Z```$````%/L`
M`"D````9^P``%P```$/[```?````6_L``%P```![^P``%````-C[```^````
M[?L``!\````L_```$````$S\```'````7?P```X```!E_```#````'3\```,
M````@?P``!,```"._```"@```*+\```=````K?P``!D```#+_```!0```.7\
M```1````Z_P``!$```#]_```)`````_]```2````-/T``!4```!'_0``$@``
M`%W]```.````</T``!D```!__0``"````)G]```-````HOT```<```"P_0``
M"@```+C]```'````P_T```\```#+_0``!@```-O]```+````XOT``!H```#N
M_0``!P````G^```(````$?X```4````:_@``'P```"#^```&````0/X``!``
M``!'_@``"````%C^```-````8?X```@```!O_@``'@```'C^```2````E_X`
M`"P```"J_@``&@```-?^```)````\OX```H```#\_@``%0````?_```%````
M'?\``!0````C_P``!````#C_```0````/?\```8```!._P``!P```%7_```>
M````7?\``"@```!\_P``"@```*7_```<````L/\``!$```#-_P``"P```-__
M```:````Z_\``!0````&``$`!````!L``0`$````(``!``L````E``$`!0``
M`#$``0`&````-P`!``@````^``$`!@```$<``0`*````3@`!`!L```!9``$`
M-````'4``0`T````J@`!`"````#?``$`*0`````!`0`@````*@$!`$$```!+
M`0$`&@```(T!`0`H````J`$!`"D```#1`0$`4````/L!`0`B````3`(!``8`
M``!O`@$`"````'8"`0`%````?P(!``@```"%`@$`&0```(X"`0`9````J`(!
M`"H```#"`@$`(P```.T"`0`9````$0,!`"X````K`P$`-````%H#`0`(````
MCP,!`!<```"8`P$`"@```+`#`0`'````NP,!`"$```##`P$`$````.4#`0`.
M````]@,!``L````%!`$`!P```!$$`0`3````&00!``@````M!`$`"P```#8$
M`0`*````0@0!`!0```!-!`$`#P```&($`0`R````<@0!``L```"E!`$`#@``
M`+$$`0`%````P`0!``4```#&!`$`!0```,P$`0`7````T@0!``\```#J!`$`
M!````/H$`0`*````_P0!``D````*!0$`"P```!0%`0`-````(`4!``P````N
M!0$`#@```#L%`0`%````2@4!``0```!0!0$`#0```%4%`0`R````8P4!`$4`
M``"6!0$`%P```-P%`0`'````]`4!`!X```#\!0$`%````!L&`0`4````,`8!
M``8```!%!@$`!P```$P&`0`.````5`8!`"H```!C!@$`!@```(X&`0`,````
ME08!``T```"B!@$`$0```+`&`0`+````P@8!`#8```#.!@$`"@````4'`0`B
M````$`<!``L````S!P$`#P```#\'`0`R````3P<!`"4```""!P$`,````*@'
M`0`Q````V0<!`"T````+"`$`#@```#D(`0`%````2`@!``X```!."`$`$P``
M`%T(`0`2````<0@!``<```"$"`$`$0```(P(`0`3````G@@!``<```"R"`$`
M%````+H(`0`8````SP@!``<```#H"`$`!0```/`(`0`,````]@@!``P````#
M"0$`$@```!`)`0`$````(PD!``<````H"0$`"@```#`)`0`+````.PD!``P`
M``!'"0$`#@```%0)`0`.````8PD!``4```!R"0$`!0```'@)`0`N````?@D!
M`"8```"M"0$`(P```-0)`0`#````^`D!`!(```#\"0$`!@````\*`0`>````
M%@H!`!@````U"@$`)0```$X*`0`-````=`H!`!\```"""@$``P```*(*`0`'
M````I@H!``(```"N"@$`#````+$*`0`5````O@H!``L```#4"@$`&0```.`*
M`0`@````^@H!`!(````;"P$`!0```"X+`0`*````-`L!`!4````_"P$`$@``
M`%4+`0`,````:`L!``0```!U"P$`"0```'H+`0`'````A`L!``P```","P$`
M4@```)D+`0`7````[`L!`"0````$#`$`$@```"D,`0`'````/`P!``8```!$
M#`$`#@```$L,`0`,````6@P!``T```!G#`$`%0```'4,`0`2````BPP!``\`
M``">#`$`%````*X,`0`*````PPP!`!L```#.#`$`$````.H,`0`+````^PP!
M`&D````'#0$`&@```'$-`0`7````C`T!`"<```"D#0$`&@```,P-`0`7````
MYPT!`!L```#_#0$`&0```!L.`0`?````-0X!`!,```!5#@$`"````&D.`0`'
M````<@X!``@```!Z#@$`"0```(,.`0`5````C0X!``T```"C#@$`(P```+$.
M`0`-````U0X!`!,```#C#@$`"````/<.`0`#``````\!`$8````$#P$`/P``
M`$L/`0`W````BP\!`%<```###P$`!0```!L0`0`?````(1`!`"\```!!$`$`
M"@```'$0`0`(````?!`!``T```"%$`$`+0```),0`0`$````P1`!`$\```#&
M$`$`)0```!81`0`<````/!$!``L```!9$0$`'P```&41`0`=````A1$!`"4`
M``"C$0$`(````,D1`0`D````ZA$!`"`````/$@$`"P```#`2`0`'````/!(!
M``T```!$$@$`#````%(2`0`7````7Q(!``8```!W$@$`.0```'X2`0`,````
MN!(!``<```#%$@$`"0```,T2`0`3````UQ(!``D```#K$@$`!````/42`0`0
M````^A(!``@````+$P$`"````!03`0`$````'1,!``L````B$P$`#````"X3
M`0`2````.Q,!`!$```!.$P$`#````&`3`0`:````;1,!``\```"($P$`!P``
M`)@3`0`-````H!,!`!0```"N$P$`#@```,,3`0`,````TA,!`!L```#?$P$`
M+````/L3`0`3````*!0!`!P````\%`$`*````%D4`0`&````@A0!``<```")
M%`$`$P```)$4`0`%````I10!``0```"K%`$`%P```+`4`0`*````R!0!``P`
M``#3%`$`"0```.`4`0`&````ZA0!``D```#Q%`$`"````/L4`0`)````!!4!
M``H````.%0$`$0```!D5`0`&````*Q4!``X````R%0$`#@```$$5`0`-````
M4!4!``L```!>%0$`'0```&H5`0`+````B!4!``(```"4%0$`'````)<5`0`'
M````M!4!``8```"\%0$`9````,,5`0`)````*!8!``<````R%@$`)@```#H6
M`0`X````818!`!H```":%@$`*@```+46`0`[````X!8!`"@````<%P$`-```
M`$47`0`9````>A<!`!4```"4%P$`!0```*H7`0`'````L!<!``@```"X%P$`
M!P```,$7`0`%````R1<!``<```#/%P$`#@```-<7`0`)````YA<!``8```#P
M%P$`"````/<7`0`+`````!@!``<````,&`$`"````!08`0`'````'1@!`!8`
M```E&`$`"0```#P8`0`&````1A@!``L```!-&`$`$````%D8`0`<````:A@!
M`!0```"'&`$`!P```)P8`0`1````I!@!``@```"V&`$`#@```+\8`0`(````
MSA@!``4```#7&`$`$````-T8`0`0````[A@!``8```#_&`$`&0````89`0`*
M````(!D!`!P````K&0$`!P```$@9`0`%````4!D!`!````!6&0$`%````&<9
M`0`+````?!D!``T```"(&0$`*````)89`0`8````OQD!`!<```#8&0$`!```
M`/`9`0`)````]1D!``H```#_&0$`!P````H:`0`"````$AH!``X````5&@$`
M"````"0:`0`C````+1H!`!\```!1&@$`.````'$:`0`F````JAH!`#$```#1
M&@$`)P````,;`0!D````*QL!`!0```"0&P$`50```*4;`0`X````^QL!`$H`
M```T'`$`6P```'\<`0`H````VQP!`#@````$'0$`*````#T=`0`L````9AT!
M`"8```"3'0$`&P```+H=`0`^````UAT!`*D!```5'@$`(P```+\?`0`7````
MXQ\!`$@```#['P$`A0```$0@`0`P````RB`!`"4```#[(`$`00```"$A`0!;
M````8R$!`$D```"_(0$`,0````DB`0`=````.R(!`!@```!9(@$`*P```'(B
M`0`A````GB(!`!\```#`(@$`*P```.`B`0`F````#",!`"<````S(P$`.@``
M`%LC`0`=````EB,!`!$```"T(P$`,P```,8C`0`E````^B,!`"<````@)`$`
M(````$@D`0`?````:20!`#````"))`$`:0```+HD`0`Q````)"4!`$$```!6
M)0$`,P```)@E`0`E````S"4!`#T```#R)0$`90```#`F`0!-````EB8!`"\`
M``#D)@$`+@```!0G`0`P````0R<!`%0```!T)P$`6@```,DG`0!(````)"@!
M`$H```!M*`$`,@```+@H`0`O````ZR@!`"P````;*0$`+0```$@I`0!Q````
M=BD!`&8```#H*0$`;P```$\J`0"S````ORH!`!<```!S*P$`)0```(LK`0`R
M````L2L!`"D```#D*P$`/@````XL`0`B````32P!`%(```!P+`$`)0```,,L
M`0`+````Z2P!`+$```#U+`$`10```*<M`0`A````[2T!`#`````/+@$`)0``
M`$`N`0`<````9BX!`#$```"#+@$`!P```+4N`0`'````O2X!``0```#%+@$`
M#0```,HN`0`+````V"X!``X```#D+@$`"P```/,N`0`%````_RX!`!`````%
M+P$``@```!8O`0!9````&2\!``4```!S+P$`$@```'DO`0`$````C"\!``<`
M``"1+P$`"````)DO`0`%````HB\!``,```"H+P$`$````*PO`0`,````O2\!
M`!,```#*+P$`#0```-XO`0`"````["\!``<```#O+P$`!@```/<O`0`4````
M_B\!``P````3,`$`&````"`P`0`&````.3`!`!(```!`,`$`#````%,P`0`#
M````8#`!`"H```!D,`$`!````(\P`0`&````E#`!``<```";,`$`'P```*,P
M`0`U````PS`!`"X```#Y,`$`+P```"@Q`0`7````6#$!`"(```!P,0$`)0``
M`),Q`0`@````N3$!`!L```#:,0$`&````/8Q`0`D````#S(!`!\````T,@$`
M&@```%0R`0`A````;S(!`"````"1,@$`&@```+(R`0`R````S3(!`!H`````
M,P$`+P```!LS`0`K````2S,!`!\```!W,P$`(P```)<S`0`?````NS,!`!H`
M``#;,P$`(0```/8S`0`E````&#0!`"8````^-`$`)0```&4T`0`D````BS0!
M`!@```"P-`$`'0```,DT`0`D````YS0!`!@````,-0$`(@```"4U`0`L````
M2#4!`"\```!U-0$`%0```*4U`0`E````NS4!`#P```#A-0$`'P```!XV`0`C
M````/C8!`!\```!B-@$`(````((V`0`:````HS8!`!@```"^-@$`)@```-<V
M`0`>````_C8!`"D````=-P$`'@```$<W`0`Q````9C<!``D```"8-P$`#```
M`*(W`0`7````KS<!`"\```#'-P$`)````/<W`0`'````'#@!``\````D.`$`
M%````#0X`0`.````23@!``T```!8.`$`)````&8X`0`%````BS@!``<```"1
M.`$`(@```)DX`0`E````O#@!`!H```#B.`$`'0```/TX`0`:````&SD!``<`
M```V.0$`QP```#XY`0`+````!CH!`!4````2.@$`!@```"@Z`0`)````+SH!
M``L````Y.@$`#0```$4Z`0`7````4SH!``8```!K.@$`,P```'(Z`0`3````
MICH!`!,```"Z.@$`!P```,XZ`0`/````UCH!``<```#F.@$`,@```.XZ`0`$
M````(3L!`"$````F.P$`$P```$@[`0`,````7#L!`!$```!I.P$`,@```'L[
M`0`6````KCL!``@```#%.P$`'0```,X[`0`)````[#L!``H```#V.P$`%```
M``$\`0`*````%CP!`!T````A/`$`"````#\\`0`?````2#P!``@```!H/`$`
M&@```'$\`0`G````C#P!``8```"T/`$`%0```+L\`0`'````T3P!``@```#9
M/`$`"0```.(\`0`_````[#P!``<````L/0$`#P```#0]`0`.````1#T!`!``
M``!3/0$`"0```&0]`0`)````;CT!``@```!X/0$`$P```($]`0`'````E3T!
M`!D```"=/0$`"@```+<]`0`7````PCT!`!0```#:/0$`"@```.\]`0`,````
M^CT!`!<````'/@$`!````!\^`0`J````)#X!``P```!//@$`$0```%P^`0`'
M````;CX!``(```!V/@$`$````'D^`0`8````BCX!``,```"C/@$`"````*<^
M`0`&````L#X!``<```"W/@$`#0```+\^`0`+````S3X!`!0```#9/@$`%0``
M`.X^`0`.````!#\!`"\````3/P$`(````$,_`0`<````9#\!`!4```"!/P$`
M#````)<_`0`Q````I#\!``4```#6/P$`$@```-P_`0`_````[S\!`!(````O
M0`$`"@```$)``0`&````34`!``0```!40`$`!````%E``0`*````7D`!`!,`
M``!I0`$`!0```'U``0`&````@T`!``8```"*0`$`"````)%``0`$````FD`!
M``P```"?0`$`"@```*Q``0`Y````MT`!`"X```#Q0`$`*0```"!!`0`%````
M2D$!`!@```!000$`&0```&E!`0`?````@T$!`!T```"C00$`$0```,%!`0`"
M````TT$!``0```#600$`"@```-M!`0`&````YD$!``4```#M00$``P```/-!
M`0`,````]T$!`$4````$0@$`,@```$I"`0`:````?4(!`#0```"80@$`*```
M`,U"`0!3````]D(!`!D```!*0P$`<@```&1#`0`@````UT,!`#4```#X0P$`
M(0```"Y$`0!%````4$0!`#````"61`$`*````,=$`0`I````\$0!`"8````:
M10$`)0```$%%`0`H````9T4!`"@```"010$`(@```+E%`0`K````W$4!`#``
M```(1@$`$@```#E&`0`3````3$8!`!````!@1@$`>0```'%&`0`)````ZT8!
M`*$```#U1@$`<P```)='`0!\````"T@!`"L```"(2`$`5````+1(`0`7````
M"4D!`"<````A20$`%@```$E)`0`/````8$D!`!<```!P20$`'P```(A)`0!`
M````J$D!`!\```#I20$`'`````E*`0!1````)DH!`!H```!X2@$`%````)-*
M`0`*````J$H!``4```"S2@$`!@```+E*`0`(````P$H!`!(```#)2@$`$```
M`-Q*`0`3````[4H!`!T````!2P$`#P```!]+`0`/````+TL!``0````_2P$`
M"P```$1+`0`'````4$L!``4```!82P$`%````%Y+`0`'````<TL!``@```![
M2P$`#P```(1+`0`(````E$L!``P```"=2P$`#P```*I+`0`&````NDL!`!0`
M``#!2P$`!@```-9+`0`,````W4L!`!$```#J2P$`"````/Q+`0`$````!4P!
M`!D````*3`$`$0```"1,`0`*````-DP!`!@```!!3`$`$P```%I,`0`<````
M;DP!`!$```"+3`$`!````)U,`0`/````HDP!``<```"R3`$`!````+I,`0`9
M````OTP!``<```#93`$``@```.%,`0`1````Y$P!``D```#V3`$`$@````!-
M`0`7````$TT!``8````K30$`)P```#)-`0`$````6DT!``\```!?30$`$P``
M`&]-`0`'````@TT!``<```"+30$`$0```)--`0`&````I4T!`!@```"L30$`
M!@```,5-`0`3````S$T!`!````#@30$`$@```/%-`0`&````!$X!``P````+
M3@$`"0```!A.`0`1````(DX!`"(````T3@$`!P```%=.`0`+````7TX!``4`
M``!K3@$``@```'%.`0!C`0``=$X!`!0```#83P$`$P```.U/`0`/`````5`!
M``4````14`$`"0```!=0`0`)````(5`!``,````K4`$`%````"]0`0`<````
M1%`!`"P```!A4`$`*P```(Y0`0`A````NE`!`"T```#<4`$`'`````I1`0`S
M````)U$!``L```!;40$`+````&=1`0`4````E%$!`!,```"I40$`"P```+U1
M`0`H````R5$!``P```#R40$`%0```/]1`0`;````%5(!`"$````Q4@$`"@``
M`%-2`0"#````7E(!`!8```#B4@$`!P```/E2`0`1`````5,!`!4````34P$`
M#@```"E3`0`*````.%,!``\```!#4P$`$0```%-3`0":````95,!``T`````
M5`$`%0````Y4`0`9````)%0!``\````^5`$`$````$Y4`0`0````7U0!``8`
M``!P5`$`!@```'=4`0`\````?E0!`!X```"[5`$`.0```-I4`0!,````%%4!
M`&L```!A50$`9P```,U5`0!Q````-58!`&T```"G5@$`/````!57`0`2````
M4E<!`!,```!E5P$`#````'E7`0`1````AE<!`!(```"85P$`!0```*M7`0`K
M````L5<!`!(```#=5P$`"@```/!7`0`)````^U<!``H````%6`$`,P```!!8
M`0`M````1%@!`!D```!R6`$`!@```(Q8`0`A````DU@!``D```"U6`$`!P``
M`+]8`0`5````QU@!`"(```#=6`$`$0````!9`0`6````$ED!`!H````I60$`
M'0```$19`0`J````8ED!`!L```"-60$`%````*E9`0`2````OED!`!$```#1
M60$`+@```.-9`0`<````$EH!`!T````O6@$`&0```$U:`0!E````9UH!`$(`
M``#-6@$`,````!!;`0`#````05L!``H```!%6P$`/````%!;`0`.````C5L!
M``H```"<6P$`"P```*=;`0`'````LUL!``<```"[6P$`!0```,-;`0`*````
MR5L!``D```#46P$`"P```-Y;`0`=````ZEL!``X````(7`$`$@```!=<`0`@
M````*EP!`!L```!+7`$`,P```&=<`0`+````FUP!`!\```"G7`$`$@```,=<
M`0`>````VEP!``\```#Y7`$`$P````E=`0`2````'5T!``\````P70$`(@``
M`$!=`0`8````8UT!``<```!\70$`!@```(1=`0`(````BUT!`"@```"470$`
M!@```+U=`0`*````Q%T!`!(```#/70$`"@```.)=`0`4````[5T!`!,````"
M7@$`+0```!9>`0`*````1%X!`!$```!/7@$`!P```&%>`0`3````:5X!`!P`
M``!]7@$`&@```)I>`0`]````M5X!`#H```#S7@$`"0```"Y?`0`,````.%\!
M`!(```!%7P$`"````%A?`0`%````85\!``<```!G7P$`#````&]?`0`:````
M?%\!`$D```"77P$`%P```.%?`0`I````^5\!`"T````C8`$`-````%%@`0`Y
M````AF`!``T```#`8`$`"0```,Y@`0`*````V&`!``@```#C8`$`-````.Q@
M`0!(````(6$!`#,```!J80$`7@```)YA`0`R````_6$!`#(````P8@$`10``
M`&-B`0`^````J6(!`#(```#H8@$`1@```!MC`0`N````8F,!`#L```"18P$`
M0@```,UC`0`R````$&0!`#@```!#9`$`.@```'QD`0`E````MV0!`"@```#=
M9`$`.0````9E`0`Z````0&4!`#D```![90$`&P```+5E`0`,````T64!`"``
M``#>90$`!@```/]E`0`+````!F8!`!X````29@$`)@```#%F`0`'````6&8!
M``<```!@9@$`$P```&AF`0`)````?&8!``@```"&9@$`-0```(]F`0`+````
MQ68!`!````#19@$`!P```.)F`0`&````ZF8!``4```#Q9@$`!P```/=F`0`&
M````_V8!``L````&9P$`+0```!)G`0`6````0&<!`!(```!79P$`"````&IG
M`0`'````<V<!`!````![9P$`!0```(QG`0`/````DF<!``<```"B9P$`$P``
M`*IG`0`)````OF<!``@```#(9P$`!````-%G`0`-````UF<!``@```#D9P$`
M&@```.UG`0`1````"&@!``@````::`$`"@```"-H`0`,````+F@!``<````[
M:`$`%0```$-H`0`#````66@!`"P```!=:`$`$P```(IH`0`I````GF@!``8`
M``#(:`$`!P```,]H`0`)````UV@!``<```#A:`$`0````.EH`0`>````*FD!
M`#L```!):0$`*@```(5I`0`D````L&D!``8```#5:0$`!0```-QI`0`:````
MXFD!`"$```#]:0$`/P```!]J`0`[````7VH!`",```";:@$`(@```+]J`0!7
M````XFH!`"P````Z:P$`$@```&=K`0`*````>FL!``L```"%:P$`%P```)%K
M`0`/````J6L!``T```"Y:P$`$@```,=K`0`2````VFL!`!(```#M:P$`$P``
M``!L`0`-````%&P!`!,````B;`$`!0```#9L`0`9````/&P!`!H```!6;`$`
M%P```'%L`0`9````B6P!`"0```"C;`$`!````,AL`0`+````S6P!`!,```#9
M;`$`1````.UL`0!<````,FT!``@```"/;0$`$@```)AM`0`%````JVT!``0`
M``"Q;0$`'@```+9M`0`9````U6T!`!T```#O;0$`$0````UN`0`>````'VX!
M`"T````^;@$`-@```&QN`0`2````HVX!`"@```"V;@$`!@```-]N`0`9````
MYFX!`!0`````;P$`%@```!5O`0`5````+&\!`!\```!";P$`$````&)O`0`D
M````<V\!`"@```"8;P$`$0```,%O`0`)````TV\!`!$```#=;P$`"@```.]O
M`0`/````^F\!`!T````*<`$`$0```"AP`0`(````.G`!``0```!#<`$`#```
M`$AP`0`-````57`!``D```!C<`$`$0```&UP`0`&````?W`!``<```"&<`$`
M$````(YP`0`*````GW`!``X```"J<`$`#P```+EP`0`#````R7`!``P```#-
M<`$`$0```-IP`0`1````['`!`!T```#^<`$`6````!QQ`0`@````=7$!`!$`
M``"6<0$`%0```*AQ`0`%````OG$!`!\```#$<0$`%P```.1Q`0`8````_'$!
M`#8````5<@$`0P```$QR`0`L````D'(!``D```"]<@$`-````,=R`0`>````
M_'(!``T````;<P$`"0```"ES`0`-````,W,!``0```!!<P$`"P```$9S`0`:
M````4G,!`!@```!M<P$`%````(9S`0`*````FW,!`!````"F<P$`+````+=S
M`0`O````Y',!`#X````4=`$`,0```%-T`0`L````A70!`!X```"R=`$`1```
M`-%T`0`L````%G4!`#X```!#=0$`+````()U`0`]````KW4!`#\```#M=0$`
M(@```"UV`0`H````4'8!`#<```!Y=@$`,0```+%V`0`M````XW8!`"\````1
M=P$`/````$%W`0`B````?G<!`"<```"A=P$`/P```,EW`0`K````"7@!`!P`
M```U>`$`*0```%)X`0`F````?'@!`!X```"C>`$`$0```,)X`0#$````U'@!
M`#H```"9>0$`*0```-1Y`0`K````_GD!`"T````J>@$`+P```%AZ`0`U````
MB'H!`",```"^>@$`*````.)Z`0`N````"WL!`#$````Z>P$`.0```&Q[`0`T
M````IGL!`)````#;>P$`-````&Q\`0`8````H7P!`"T```"Z?`$`*P```.A\
M`0`O````%'T!`$0```!$?0$`2@```(E]`0`/````U'T!``8```#D?0$`"@``
M`.M]`0`*````]GT!`!`````!?@$`#@```!)^`0`4````(7X!`"@````V?@$`
M#P```%]^`0`,````;WX!``0```!\?@$`$0```(%^`0`B````DWX!``H```"V
M?@$`#P```,%^`0`6````T7X!`!(```#H?@$`'@```/M^`0`0````&G\!`$L`
M```K?P$`!P```'=_`0`8````?W\!``8```"8?P$`#P```)]_`0`5````KW\!
M`!4```#%?P$`$````-M_`0`"````['\!`%T```#O?P$`!P```$V``0`1````
M58`!`!D```!G@`$`!0```(&``0`1````AX`!`!(```"9@`$`!@```*R``0`.
M````LX`!``@```#"@`$`!@```,N``0`0````TH`!``\```#C@`$`'P```/.`
M`0`A````$X$!`!4````U@0$`"@```$N!`0`&````5H$!``\```!=@0$`$0``
M`&V!`0`7````?X$!`!4```"7@0$`#P```*V!`0`/````O8$!`!$```#-@0$`
M*````-^!`0`1````"((!`!T````:@@$`/@```#B"`0`-````=X(!`"````"%
M@@$`$P```*:"`0`:````NH(!`!<```#5@@$`*P```.V"`0`2````&8,!``4`
M```L@P$`&P```#*#`0`&````3H,!`"\```!5@P$`00```(6#`0`*````QX,!
M``H```#2@P$`%0```-V#`0`,````\X,!`!(`````A`$`$@```!.$`0`&````
M)H0!`#(````MA`$`&0```&"$`0`E````>H0!`"8```"@A`$`%@```,>$`0`F
M````WH0!``@````%A0$`"P````Z%`0`L````&H4!`$````!'A0$`"````(B%
M`0`5````D84!`"<```"GA0$`"````,^%`0`/````V(4!`#T```#HA0$`#P``
M`":&`0`,````-H8!``4```!#A@$`40```$F&`0`$````FX8!``<```"@A@$`
M"0```*B&`0`/````LH8!`!$```#"A@$`%0```-2&`0`8````ZH8!`!X````#
MAP$`'0```"*'`0`@````0(<!`!X```!AAP$`!P```("'`0`(````B(<!``@`
M``"1AP$`!P```)J'`0`6````HH<!``4```"YAP$`"0```+^'`0`A````R8<!
M`!<```#KAP$`$`````.(`0`.````%(@!``P````CB`$`#````#"(`0`9````
M/8@!`$,```!7B`$`-@```)N(`0`,````TH@!`!8```#?B`$`>@```/:(`0`:
M````<8D!`!H```",B0$`$0```*>)`0`'````N8D!``0```#!B0$`)P```,:)
M`0`V````[HD!`#T````EB@$`(@```&.*`0`L````AHH!`!@```"SB@$`)P``
M`,R*`0`*````](H!``<```#_B@$`#`````>+`0`&````%(L!``T````;BP$`
M#````"F+`0`2````-HL!``P```!)BP$`%P```%:+`0`+````;HL!``H```!Z
MBP$`#@```(6+`0`+````E(L!``P```"@BP$`'P```*V+`0`;````S8L!`$T`
M``#IBP$`%P```#>,`0`&````3XP!``0```!6C`$`)P```%N,`0`Q````@XP!
M`!X```"UC`$`'0```-2,`0`K````\HP!`"H````>C0$`+````$F-`0`M````
M=HT!`!P```"DC0$`!@```,&-`0`<````R(T!``X```#EC0$`%P```/2-`0`#
M````#(X!``,````0C@$`!P```!2.`0`0````'(X!`!(````MC@$`#0```$".
M`0`6````3HX!``L```!EC@$`)@```'&.`0`&````F(X!``0```"?C@$`$@``
M`*2.`0`2````MXX!``X```#*C@$`!P```-F.`0`.````X8X!``\```#PC@$`
M(0````"/`0`&````(H\!``H````ICP$`"````#2/`0`+````/8\!`!8```!)
MCP$`$0```&"/`0`#````<H\!`!0```!VCP$`"````(N/`0`&````E(\!`#D`
M``";CP$`&````-6/`0",````[H\!`!D```![D`$`#````)60`0`&````HI`!
M``X```"ID`$`"````+B0`0`*````P9`!``<```#,D`$`#````-20`0`"````
MX9`!``@```#DD`$`#0```.V0`0`-````^Y`!``X````)D0$`$0```!B1`0`6
M````*I$!``8```!!D0$`!P```$B1`0`0````4)$!``@```!AD0$`"@```&J1
M`0`%````=9$!`"````![D0$`"P```)R1`0`&````J)$!`"0```"OD0$`$0``
M`-21`0`&````YI$!``L```#MD0$`!0```/F1`0`)````_Y$!``H````)D@$`
M%````!22`0`%````*9(!``4````OD@$`#0```#62`0`.````0Y(!``P```!2
MD@$`"P```%^2`0`2````:Y(!``@```!^D@$`!P```(>2`0`6````CY(!`!P`
M``"FD@$`0P```,.2`0`K````!Y,!`#@````SDP$`"0```&R3`0`*````=I,!
M``0```"!DP$`"0```(:3`0`(````D),!`!0```"9DP$`"P```*Z3`0`&````
MNI,!``T```#!DP$`!@```,^3`0!`````UI,!`$4````7E`$`0@```%V4`0`K
M````H)0!``4```#,E`$`#P```-*4`0`#````XI0!``8```#FE`$`!@```.V4
M`0`;````])0!``P````0E0$`%````!V5`0`(````,I4!``@````[E0$`(P``
M`$25`0`(````:)4!``<```!QE0$`$````'F5`0`$````BI4!``@```"/E0$`
M#````)B5`0`(````I94!``L```"NE0$`%````+J5`0`/````SY4!``@```#?
ME0$`"````.B5`0`%````\94!`#0```#WE0$`-P```"R6`0`W````9)8!`"P`
M``"<E@$`10```,F6`0!#````#Y<!`"\```!3EP$`6````(.7`0`T````W)<!
M`$H````1F`$`+0```%R8`0`0````BI@!`!````";F`$`"P```*R8`0`C````
MN)@!`"0```#<F`$`%P````&9`0`@````&9D!``P````ZF0$`#@```$>9`0`*
M````5ID!``P```!AF0$`+@```&Z9`0`J````G9D!`#\```#(F0$`!@````B:
M`0`>````#YH!`#`````NF@$`'````%^:`0`6````?)H!``8```"3F@$`"P``
M`)J:`0`*````IIH!`!````"QF@$`)0```,*:`0!&````Z)H!`)$````OFP$`
M=````,&;`0`/````-IP!``P```!&G`$`#0```%.<`0`;````89P!`!<```!]
MG`$`#@```)6<`0`%````I)P!`!4```"JG`$`%0```,"<`0`3````UIP!`!8`
M``#JG`$`%P````&=`0`T````&9T!`(T```!.G0$`$````-R=`0`%````[9T!
M`!(```#SG0$`"0````:>`0`*````$)X!``H````;G@$`*````":>`0`7````
M3YX!`!````!GG@$`%0```'B>`0`0````CIX!`!8```"?G@$`%P```+:>`0`6
M````SIX!`!,```#EG@$`$P```/F>`0`<````#9\!`!L````JGP$`(````$:?
M`0`_````9Y\!`!D```"GGP$`&````,&?`0`7````VI\!`!8```#RGP$`$@``
M``F@`0`<````'*`!`!L````YH`$`$P```%6@`0`3````::`!`#````!]H`$`
M&P```*Z@`0`<````RJ`!`$(```#GH`$`'P```"JA`0`%````2J$!`!0```!0
MH0$`+0```&6A`0`C````DZ$!`"$```"WH0$`)@```-FA`0`E`````*(!`!T`
M```FH@$`(P```$2B`0`C````:*(!`!P```",H@$`(@```*FB`0!!````S*(!
M`"(````.HP$`)P```#&C`0`G````6:,!`"````"!HP$`(````**C`0`C````
MPZ,!`"D```#GHP$`(@```!&D`0`C````-*0!``T```!8I`$`%P```&:D`0`8
M````?J0!``0```"7I`$`"````)RD`0`*````I:0!`!0```"PI`$`!@```,6D
M`0`5````S*0!``0```#BI`$`"P```.>D`0`'````\Z0!``8```#[I`$`!0``
M``*E`0`3````"*4!``8````<I0$`"````".E`0`&````+*4!``8````SI0$`
M"@```#JE`0`0````1:4!`!H```!6I0$`$````'&E`0`1````@J4!``H```"4
MI0$`&````)^E`0`%````N*4!`#D```"^I0$`%@```/BE`0`1````#Z8!`!$`
M```AI@$`#@```#.F`0`+````0J8!`!(```!.I@$`+P```&&F`0`(````D:8!
M``@```":I@$`)````*.F`0`2````R*8!``\```#;I@$`!@```.NF`0`,````
M\J8!``D```#_I@$`!0````FG`0`D````#Z<!``H````TIP$`%@```#^G`0`-
M````5J<!`!,```!DIP$`&````'BG`0`C````D:<!`"<```"UIP$`"@```-VG
M`0`#````Z*<!``H```#LIP$`(@```/>G`0`'````&J@!``,````BJ`$`$0``
M`":H`0`2````.*@!``<```!+J`$`!0```%.H`0`'````6:@!`"H```!AJ`$`
M#0```(RH`0`2````FJ@!``H```"MJ`$`$P```+BH`0`7````S*@!``P```#D
MJ`$`#@```/&H`0`.`````*D!``X````/J0$`!````!ZI`0`1````(ZD!`$,`
M```UJ0$`!@```'FI`0`%````@*D!`"<```"&J0$`%@```*ZI`0`T````Q:D!
M`!4```#ZJ0$`#@```!"J`0`3````'ZH!``\````SJ@$`$````$.J`0`/````
M5*H!`!X```!DJ@$`'P```(.J`0`U````HZH!`"L```#9J@$`)@````6K`0`(
M````+*L!``@````UJP$`"P```#ZK`0`+````2JL!`!$```!6JP$`!````&BK
M`0`-````;:L!`"H```![JP$`#0```*:K`0`-````M*L!`"8```#"JP$`40``
M`.FK`0`=````.ZP!``T```!9K`$`"````&>L`0`(````<*P!``X```!YK`$`
M#@```(BL`0`5````EZP!``D```"MK`$``@```+>L`0`-````NJP!`",```#(
MK`$`!@```.RL`0`%````\ZP!``D```#YK`$`"P````.M`0`)````#ZT!``D`
M```9K0$`%````".M`0`.````.*T!``8```!'K0$`"````$ZM`0`/````5ZT!
M``0```!GK0$`!0```&RM`0!K````<JT!``P```#>K0$`#P```.NM`0`@````
M^ZT!``<````<K@$`!0```"2N`0`J````*JX!`#$```!5K@$`$0```(>N`0`*
M````F:X!`!D```"DK@$`"@```+ZN`0`)````R:X!`"H```#3K@$`'@```/ZN
M`0`I````':\!`"@```!'KP$`*P```'"O`0`/````G*\!``4```"LKP$`!P``
M`+*O`0`-````NJ\!``4```#(KP$`$P```,ZO`0`6````XJ\!``8```#YKP$`
M60````"P`0`>````6K`!`!````!YL`$`%@```(JP`0`D````H;`!`&8```#&
ML`$`&````"VQ`0`'````1K$!`!\```!.L0$`,````&ZQ`0`(````G[$!``8`
M``"HL0$`'@```*^Q`0`%````SK$!``H```#4L0$`+@```-^Q`0`M````#K(!
M`#L````\L@$`$P```'BR`0`&````C+(!`"0```"3L@$`5@```+BR`0`?````
M#[,!`!P````OLP$`.0```$RS`0`"````AK,!`!D```")LP$`!P```*.S`0`2
M````J[,!`!$```"^LP$`!P```-"S`0`4````V+,!``8```#MLP$`"````/2S
M`0`+````_;,!``<````)M`$`"@```!&T`0`+````'+0!`"P````HM`$`!P``
M`%6T`0`0````7;0!`!````!NM`$`#P```'^T`0`)````C[0!``P```"9M`$`
M#0```*:T`0`*````M+0!``D```"_M`$`"@```,FT`0`(````U+0!`!L```#=
MM`$`'@```/FT`0`4````&+4!`!H````MM0$`%@```$BU`0`6````7[4!`"``
M``!VM0$`!P```)>U`0`6````G[4!``,```"VM0$`!P```+JU`0`%````PK4!
M``4```#(M0$`"0```,ZU`0`0````V+4!`!(```#IM0$`,P```/RU`0`N````
M,+8!`"(```!?M@$`)````(*V`0`7````I[8!`!\```"_M@$`&0```-^V`0`'
M````^;8!``0````!MP$`#`````:W`0`,````$[<!`!$````@MP$`!@```#*W
M`0`>````.;<!``D```!8MP$`"0```&*W`0`K````;+<!`"4```"8MP$`#P``
M`+ZW`0`%````SK<!``P```#4MP$`"0```.&W`0`1````Z[<!`!````#]MP$`
M"@````ZX`0`)````&;@!``4````CN`$`!P```"FX`0`'````,;@!``0````Y
MN`$``P```#ZX`0!9````0K@!`"T```"<N`$`1````,JX`0`;````#[D!`#T`
M```KN0$`#P```&FY`0!`````>;D!`"D```"ZN0$`'@```.2Y`0`>`````[H!
M`",````BN@$`-@```$:Z`0`-````?;H!`#````"+N@$`&0```+RZ`0`5````
MUKH!`!4```#LN@$`#P````*[`0`4````$KL!`!4````GNP$`(0```#V[`0`]
M````7[L!`#X```"=NP$`00```-R[`0`^````'KP!`#\```!=O`$`/0```)V\
M`0!M````V[P!`!X```!)O0$`%@```&B]`0`:````?[T!`"4```":O0$`#P``
M`,"]`0`0````T+T!`#L```#AO0$`*P```!V^`0`M````2;X!``H```!WO@$`
M*0```(*^`0`K````K+X!``4```#8O@$`)@```-Z^`0`6````!;\!``X````<
MOP$`#@```"N_`0`7````.K\!``@```!2OP$`"@```%N_`0`,````9K\!``X`
M``!SOP$`+P```(*_`0`/````LK\!``\```#"OP$`#````-*_`0`F````W[\!
M``@````&P`$`!`````_``0`0````%,`!``X````EP`$`"P```#3``0`U````
M0,`!``(```!VP`$`"````'G``0`7````@L`!``P```":P`$`!P```*?``0`&
M````K\`!`!$```"VP`$`*P```,C``0`-````],`!`!P````"P0$`!````!_!
M`0`W````),$!`",```!<P0$`'@```(#!`0!W````G\$!`!<````7P@$`2```
M`"_"`0`G````>,(!`!(```"@P@$`!@```+/"`0`.````NL(!`!0```#)P@$`
M"0```-["`0`1````Z,(!``X```#ZP@$`'@````G#`0`5````*,,!``4````^
MPP$`$````$3#`0`:````5<,!`#(```!PPP$`%0```*/#`0`5````N<,!`!@`
M``#/PP$`$P```.C#`0`?````_,,!``<````<Q`$`%P```"3$`0`+````/,0!
M`!0```!(Q`$`%````%W$`0`6````<L0!`!````")Q`$`%@```)K$`0`8````
ML<0!``L```#*Q`$`"0```-;$`0`%````X,0!`!T```#FQ`$`!@````3%`0`/
M````"\4!``@````;Q0$`$@```"3%`0`&````-\4!`"0````^Q0$`%````&/%
M`0`S````>,4!`!4```"LQ0$`!P```,+%`0`(````RL4!`!X```#3Q0$`"P``
M`/+%`0`;````_L4!``<````:Q@$`(P```"+&`0`'````1L8!``@```!.Q@$`
M)````%?&`0`[````?,8!``L```"XQ@$`)0```,3&`0`G````ZL8!``T````2
MQP$`&@```"#'`0`0````.\<!``0```!,QP$`#@```%''`0`.````8,<!``<`
M``!OQP$`#@```'?'`0`(````AL<!``4```"/QP$`"0```)7'`0`=````G\<!
M`"8```"]QP$`/P```.3'`0`H````),@!`"4```!-R`$`'P```'/(`0`[````
MD\@!`!X```#/R`$`*@```.[(`0`R````&<D!`%T```!,R0$`)0```*K)`0`-
M````T,D!``@```#>R0$`"@```.?)`0`*````\LD!`!$```#]R0$`%@````_*
M`0!'````)LH!`"4```!NR@$`&@```)3*`0`X````K\H!`$````#HR@$`"0``
M`"G+`0`F````,\L!``L```!:RP$`%````&;+`0`G````>\L!``P```"CRP$`
M&0```+#+`0`,````RLL!``X```#7RP$`#@```.;+`0`/````]<L!`!`````%
MS`$`#P```!;,`0`;````)LP!`!H```!"S`$`-0```%W,`0`+````D\P!`!H`
M``"?S`$`!0```+K,`0`5````P,P!``4```#6S`$`'@```-S,`0`7````^\P!
M``,````3S0$`#````!?-`0`0````),T!``4````US0$`#@```#O-`0`(````
M2LT!``\```!3S0$`!0```&/-`0`'````:<T!`!````!QS0$`20```(+-`0!0
M````S,T!`"<````=S@$`"0```$7.`0`R````3\X!`"L```""S@$`$0```*[.
M`0`)````P,X!``P```#*S@$`$````-?.`0`R````Z,X!``8````;SP$`#0``
M`"+/`0`.````,,\!`!4````_SP$`#0```%7/`0!<````8\\!``H```#`SP$`
M)0```,O/`0`5````\<\!`!8````'T`$`+````![0`0`F````2]`!`#X```!R
MT`$`00```+'0`0`[````\]`!``X````OT0$`!0```#[1`0`3````1-$!`!P`
M``!8T0$`(````'71`0`(````EM$!`!,```"?T0$`&P```+/1`0`'````S]$!
M`!\```#7T0$`%P```/?1`0`0````#](!``0````@T@$`$@```"72`0`3````
M.-(!`!0```!,T@$`!@```&'2`0`'````:-(!`!,```!PT@$`#@```(32`0`/
M````D](!`!$```"CT@$`$0```+72`0`&````Q](!``<```#.T@$`*````-;2
M`0`D````_](!`"`````DTP$`"````$73`0`/````3M,!``8```!>TP$`&```
M`&73`0`I````?M,!`"D```"HTP$`"@```-+3`0`8````W=,!``,```#VTP$`
M"````/K3`0`#`````]0!`!(````'U`$`%````!K4`0`+````+]0!`!@````[
MU`$`(P```%34`0`7````>-0!``8```"0U`$`"@```)?4`0`4````HM0!`!<`
M``"WU`$`#````,_4`0`&````W-0!``P```#CU`$`"@```/#4`0`5````^]0!
M`'D````1U0$`'P```(O5`0`O````J]4!`!0```#;U0$`"````/#5`0`'````
M^=4!`!<````!U@$`%P```!G6`0`8````,=8!`"(```!*U@$`'0```&W6`0`2
M````B]8!`"4```">U@$`$0```,36`0`F````UM8!`!@```#]U@$`%P```!;7
M`0"#````+M<!`"@```"RUP$`'P```-O7`0`X````^]<!`"<````TV`$`'@``
M`%S8`0`K````>]@!`",```"GV`$`)P```,O8`0`4````\]@!``L````(V0$`
M"````!39`0`)````'=D!``H````GV0$`%0```#+9`0`+````2-D!`#L```!4
MV0$`*0```)#9`0`W````NMD!`!8```#RV0$`!@````G:`0!%````$-H!`%4`
M``!6V@$`-````*S:`0"<````X=H!``L```!^VP$`-P```(K;`0`O````PML!
M`!(```#RVP$`"`````7<`0`3````#MP!`$0````BW`$`#````&?<`0!8````
M=-P!`$@```#-W`$`*````!;=`0`4````/]T!`"(```!4W0$`(@```'?=`0`L
M````FMT!`"(```#'W0$`*P```.K=`0`?````%MX!`!4````VW@$`!P```$S>
M`0`0````5-X!`!0```!EW@$`#0```'K>`0`+````B-X!`%$```"4W@$`#```
M`.;>`0`>````\]X!`!$````2WP$`'P```"3?`0`)````1-\!``4```!.WP$`
M&````%3?`0`)````;=\!``D```!WWP$`!P```('?`0`'````B=\!``D```"1
MWP$`$@```)O?`0`<````KM\!``\```#+WP$`'P```-O?`0`0````^]\!``@`
M```,X`$`#0```!7@`0`F````(^`!``L```!*X`$`"@```%;@`0`8````8>`!
M`"8```!ZX`$`#````*'@`0`B````KN`!`"L```#1X`$`"P```/W@`0`(````
M">$!`"$````2X0$`#0```#3A`0`9````0N$!`!L```!<X0$`%````'CA`0`6
M````C>$!`!(```"DX0$`!0```+?A`0`)````O>$!``@```#'X0$`"0```-#A
M`0`*````VN$!`!0```#EX0$`!P```/KA`0`0`````N(!``H````3X@$`"```
M`![B`0`,````)^(!`"$````TX@$`#````%;B`0`"````8^(!`",```!FX@$`
M!0```(KB`0`*````D.(!`'H```";X@$`"@```!;C`0`(````(>,!`"H````J
MXP$`.@```%7C`0`:````D.,!`"X```"KXP$`70```-KC`0`C````..0!`#,`
M``!<Y`$`+P```)#D`0`E````P.0!``8```#FY`$`#0```.WD`0`(````^^0!
M``D````$Y0$`!0````[E`0`(````%.4!`!(````=Y0$`"@```##E`0`)````
M.^4!``L```!%Y0$`"P```%'E`0`:````7>4!``@```!XY0$`"0```('E`0`5
M````B^4!``H```"AY0$`"@```*SE`0`%````M^4!`"X```"]Y0$`)@```.SE
M`0`8````$^8!``<````LY@$`$@```#3F`0`)````1^8!``\```!1Y@$`,P``
M`&'F`0`(````E>8!`!@```">Y@$`&````+?F`0`&````T.8!``8```#7Y@$`
M#0```-[F`0`<````[.8!``8````)YP$`"0```!#G`0`+````&N<!`!P````F
MYP$`"P```$/G`0`-````3^<!`"H```!=YP$`'P```(CG`0`8````J.<!``8`
M``#!YP$`"P```,CG`0`0````U.<!``T```#EYP$``P```//G`0`.````]^<!
M``@````&Z`$`'0````_H`0`O````+>@!`#````!=Z`$`*@```([H`0`N````
MN>@!`"X```#HZ`$`C@```!?I`0`6````IND!`&,```"]Z0$`.````"'J`0!A
M````6NH!`&D```"\Z@$`(0```";K`0!-````2.L!`#P```"6ZP$`1P```-/K
M`0`>````&^P!`!@````Z[`$`(P```%/L`0#]`0``=^P!`!T```!U[@$`'0``
M`)/N`0!)````L>X!`*````#[[@$`-````)SO`0`I````T>\!`$<```#[[P$`
M6@```$/P`0!D````GO`!`#(````#\0$`(````#;Q`0`>````5_$!`#0```!V
M\0$`'````*OQ`0`?````R/$!`"0```#H\0$`(`````WR`0`F````+O(!`"\`
M``!5\@$`&@```(7R`0`6````H/(!`#$```"W\@$`*@```.GR`0`D````%/,!
M`#P````Y\P$`&@```';S`0`R````D?,!`'$```#$\P$`.P```#;T`0`Z````
M<O0!`#(```"M]`$`*0```.#T`0!'````"O4!`&T```!2]0$`7P```,#U`0`P
M````(/8!`#````!1]@$`,P```(+V`0!.````MO8!`&8````%]P$`30```&SW
M`0!3````NO<!`$D````.^`$`)P```%CX`0`G````@/@!`"0```"H^`$`>```
M`,WX`0!M````1OD!`'<```"T^0$`S@```"SZ`0`<````^_H!`"P````8^P$`
M-@```$7[`0`N````?/L!`%````"K^P$`'````/S[`0!`````&?P!`#\```!:
M_`$`!0```)K\`0#(````H/P!`$8```!I_0$`(@```+#]`0`^````T_T!`"<`
M```2_@$`'````#K^`0`L````5_X!``D```"$_@$`%@```([^`0`#````I?X!
M`!8```"I_@$`#````,#^`0`-````S?X!``L```#;_@$`!P```.?^`0`-````
M[_X!``<```#]_@$`=0````7_`0`"````>_\!`!8```!^_P$`!````)7_`0`'
M````FO\!``8```"B_P$`!0```*G_`0`%````K_\!`!4```"U_P$`"@```,O_
M`0`2````UO\!``\```#I_P$``@```/G_`0`'````_/\!``L````$``(`$@``
M`!```@`-````(P`"`!D````Q``(`!@```$L``@`9````4@`"``H```!L``(`
M`P```'<``@!;````>P`"``0```#7``(`!@```-P``@`'````XP`"`"<```#K
M``(`3````!,!`@!&````8`$"`$<```"G`0(`*@```.\!`@`N````&@("`#$`
M``!)`@(`'0```'L"`@`B````F0("`!P```"\`@(`,@```-D"`@`J````#`,"
M`"0````W`P(`)@```%P#`@`G````@P,"`"X```"K`P(`*P```-H#`@`>````
M!@0"`"D````E!`(`*@```$\$`@`?````>@0"`",```":!`(`(0```+X$`@`9
M````X`0"`"(```#Z!`(`+````!T%`@`R````2@4"`#,```!]!0(`)P```+$%
M`@`=````V04"`"0```#W!0(`*0```!P&`@`=````1@8"`"<```!D!@(`.```
M`(P&`@`[````Q08"`!D````!!P(`(P```!L'`@`Z````/P<"`"(```!Z!P(`
M)@```)T'`@`D````Q`<"`"4```#I!P(`'`````\(`@`D````+`@"`#````!1
M"`(`'@```(((`@`Q````H0@"`"$```#3"`(`-@```/4(`@`)````+`D"`!``
M```V"0(`(@```$<)`@!'````:@D"`"P```"R"0(`#````-\)`@`/````[`D"
M`!<```#\"0(`$@```!0*`@`0````)PH"`"<````X"@(`!@```&`*`@`*````
M9PH"`"4```!R"@(`*````)@*`@`;````P0H"`"@```#="@(`'`````8+`@`/
M````(PL"`/0````S"P(`%0```"@,`@`7````/@P"``D```!6#`(`%P```&`,
M`@`B````>`P"`!T```";#`(`'@```+D,`@`)````V`P"`#X```#B#`(`#P``
M`"$-`@`6````,0T"``<```!(#0(`&P```%`-`@`1````;`T"`$X```!^#0(`
M$````,T-`@`B````W@T"`!P````!#@(`&````!X.`@`C````-PX"`&$```!;
M#@(`)P```+T.`@`0````Y0X"`"<```#V#@(`$0```!X/`@`2````,`\"`!@`
M``!##P(`"P```%P/`@`=````:`\"`"D```"&#P(`'P```+`/`@`+````T`\"
M`#,```#<#P(`/0```!`0`@`'````3A`"`!,```!6$`(`!P```&H0`@`'````
M<A`"``D```!Z$`(`20```(00`@`&````SA`"``T```#5$`(`$````.,0`@`6
M````]!`"``L````+$0(`#````!<1`@`'````)!$"`!$````L$0(`#P```#X1
M`@`<````3A$"`!<```!K$0(`%````(,1`@`8````F!$"``P```"Q$0(`#@``
M`+X1`@`L````S1$"``X```#Z$0(`-@````D2`@`:````0!("`!````!;$@(`
M#@```&P2`@`#````>Q("`!0```!_$@(`&P```)02`@`#````L!("``D```"T
M$@(`!P```+X2`@`*````QA("``X```#1$@(`#@```.`2`@`;````[Q("`!P`
M```+$P(`#@```"@3`@`T````-Q,"`!H```!L$P(`%0```(<3`@`9````G1,"
M``T```"W$P(`,@```,43`@`)````^!,"`!<````"%`(`5@```!H4`@`5````
M<10"`!D```"'%`(`"@```*$4`@`$````K!0"``0```"Q%`(`%@```+84`@`5
M````S10"``4```#C%`(`!@```.D4`@`*````\!0"``T```#[%`(`!0````D5
M`@`.````#Q4"`!(````>%0(`/P```#$5`@`R````<14"`"D```"D%0(`(```
M`,X5`@`<````[Q4"`",````,%@(`*````#`6`@`@````618"`!4```!Z%@(`
M`@```)`6`@`$````DQ8"``T```"8%@(`!@```*86`@`%````K18"``0```"S
M%@(`$0```+@6`@!X````RA8"`"0```!#%P(`+0```&@7`@`O````EA<"`",`
M``#&%P(`2````.H7`@`9````,Q@"`(X```!-&`(`(@```-P8`@!4````_Q@"
M`"$```!4&0(`5P```'89`@`N````SAD"`"D```#]&0(`0````"<:`@`S````
M:!H"`"\```"<&@(`/P```,P:`@`=````#!L"`"4````J&P(`*````%`;`@!-
M````>1L"`!````#'&P(`&P```-@;`@`4````]!L"`'4````)'`(`"@```'\<
M`@#6````BAP"`(4```!A'0(`?@```.<=`@`X````9AX"`'H```"?'@(`'```
M`!H?`@`W````-Q\"`"H```!O'P(`$@```)H?`@`E````K1\"`"0```#3'P(`
M1@```/@?`@`B````/R`"`!P```!B(`(`60```'\@`@`O````V2`"`"8````)
M(0(`"P```#`A`@`%````/"$"``8```!"(0(`"````$DA`@`B````4B$"``X`
M``!U(0(`(````(0A`@`H````I2$"``L```#.(0(`#P```-HA`@`+````ZB$"
M``D```#V(0(`"@`````B`@`)````"R("`!8````5(@(`#0```"PB`@`.````
M.B("`!0```!)(@(`!P```%XB`@`.````9B("`!$```!U(@(`#````(<B`@`6
M````E"("``T```"K(@(`"@```+DB`@`4````Q"("``8```#9(@(`!P```.`B
M`@`E````Z"("`"(````.(P(`#@```#$C`@`0````0","`!(```!1(P(`)```
M`&0C`@`1````B2,"``D```";(P(`%0```*4C`@`'````NR,"``0```##(P(`
M(P```,@C`@`+````[","``(```#X(P(`%0```/LC`@`(````$20"`!$````:
M)`(`$0```"PD`@`$````/B0"`$D```!#)`(``P```(TD`@`O````D20"`"\`
M``#!)`(`"P```/$D`@`(````_20"`!P````&)0(`!0```",E`@`=````*24"
M``D```!')0(`)````%$E`@`:````=B4"`"````"1)0(`"P```+(E`@`,````
MOB4"``P```#+)0(`#0```-@E`@`I````YB4"``H````0)@(`'P```!LF`@`%
M````.R8"``,```!!)@(``0```,4%``#"`@``UP4``),"``#Z`P``9`8`````
M``!*!@``V@4``"$$``"?````6@,``.(&````````GP$``'$%````````'@,`
M``````!.`0``;P0``/<%``!F`0``\@$``-$#```,!@```````"("``#+````
M`````%H%``!W!0``*P8```````!(`@``M`0``&`#``#=````W`0`````````
M````K04```````#8!@```````*(&``"R`0``H`4``$````#W`0```````/4$
M``#(````Z`4``&4'````````N`$```D&````````````````````````A`8`
M`+8`````````7P0``$L`````````K`$``(`!``#?!@``RP(``+$````@!0``
M1P```$H#``#,!0``9`(``+,$```-`@``MP0``&P"``#H`0```````+T&``!8
M`@``-0```(8%````````/0,```4!``!\````0P4``'H!``!"`0``$@,``#8"
M```H!P``/0(``)T&``!Q````QP4``,0#````````"@$``*H```"[!@``````
M`,$&``!5````90````````````````````````!4`0``>@8``-`!```N`P``
M`P(`````````````T0(``!8!``"Z!@``"`````````#L!```EP4```\'````
M`0`````````````A````Y@,``$0```#R!`````````$!``!Y!```,0$``"8"
M```D`P``$P,``,4!``"%`P```````)$%```M`0``6@<``-\```!P`0``QP$`
M`'X$``"X`P```````*$!```,!```<P4``.0#`````````````*0"````````
M`````&8%``#:`0```04````````,`@``Z0```.T#````````R@0``"@!``#,
M`@```````*`$``#*`P``40```$X$``"E````!P$```````"O`0``S@8``+L#
M``"V`P``EP,``!X%``",``````````0%``"`!0``4@```&8'``#_````````
M``````"4`0``0P8```````!=!P```````%P#`````````````%P"```&`@``
M#08``+,%``"5!0```````,T```!@!P``E@0``'P$``!,`P````````````!Z
M!0``<P<```````!+!```LP,``+4"`````````````+`#``#;`0```````'\#
M``"^`````````/8%````````8@$```T%````````XP8`````````````#@(`
M``````"J`P``N@$``&4&```R````X0(```````#4`@```````%X!```R!0``
MJ@4``(<"```S!P``(04``/,$``"*````>@```,4"```>!P``"@4``+4`````
M````X08``#H"``#6`@``:`0``+D&``#I`@``0P0````````&!0``.```````
M``!M!```?0```/L!``"O````&0,``*H&``#K`@``\P,```````#5!@``````
M`,D#`````````````'D#```3!0``Z00``#L`````````_P(```D%```B!0``
M`````+0```"@`P``/`<``((&````````KP(```````#=`@```````-8#```E
M`@``"P8```````!-`P``)04``(D#``#@`P``70```,4$``!N`@``I@```&4!
M``!-!0``.P$``-X$``#C!0``ZP```!L'``#"!@``JP4```\$``#.`P``````
M`$$!``")!@`````````````&`P``YP8```````!*`````````/<#``##!```
MM04```````#$`0``10<``,`$````````10$``%P```#]`0``?0$````````&
M!`````````````#Z!@``:P,```````!(!0``%`$``(X!``"V!```@P4``)("
M```,`P``Q@0`````````````TP$```````!0!0``]@0```@'``#.`0``900`
M`.4&```[`@`````````$``!V!0``8`(```````!I`0``-0(``#\%``!%`@``
MA0(``%D'``!L!P``:@```"X%```F!P``1@0``)$"````````)00``$X"``!6
M````^P0```````#L!@``<`4```````"-`P``!P4``(X#````````:P0```P'
M``"G!@``[P$``!<#````````/@```)`%``#I!0``VP8```````!:!@``K00`
M`(`&````````Z@4``'L$``#F`````````````````````````.4```!V`0``
MK`0``-@!``"Q!0``$@8``%4'``!)`0``T04```````"Z````'@0````````6
M!@``T@```(X```#L`P``AP$``+`&``!M!P`````````````G`0``%`8`````
M````````[P```"$!`````````````'("``!V!```108``",!``"``P``A`(`
M````````````I04``````````````````,@#``".!@```````-X```#6`0``
M&`0```````!?`0``$`0``#@#```2`@``'P,``!P%``!B````!@8``(<```#J
M`P``GP8`````````````6````-L$````````#P```%,&`````````````$$&
M`````````````!<$``#)````X`4``)0$``"%``````````4%````````0@4`
M`+@%````````?@4```````#$!```B@,``-$$```[!0``@@````````#3````
MA0$```,#````````'@(``,T#``#Y!0```````"P$```A`@``H@4````````?
M`0``100``.,"``!(````^0(``'D%``!9!````````&0%``">!0``]`8`````
M``"@`0``KP,```````!'!0``U0```"<#``!?````V````#P!```H`@``<0(`
M`*,"``"3`0``;P8``"T$``"T`@```````*D!``!%`P``UP(``-<!``"E`0``
M``````````#N!@```````!D"```_`@``-P$``+L!``!]`P``Y00``!H!````
M````704``)4"``!=`0``&`,``,L&``!I!```-`0``)(```#J!@``*P```'\`
M``!L!0``,@(``/(`````````&@4``)X```"G!```>0(```````"W!@``10``
M```%````````,@<```````!-`@```````+4&``!5`P``3P8``%\&````````
MN@(``/$!``#-`0```````%<```#T`P``Q0,``/(#````````&00``!$$````
M````(``````````P!0``)@,``,P!````````H`8``#4#``!&````/@$`````
M```E`````````%X'``"R!0``'00```H#``">!@```````'``````````[@$`
M`)````"D`P``-`4``-X"``#J!```KP8``(@%``#Y!@``IP,``*,```#/````
MLP8``.L&```K!```20,``"8%``!\`@``VP`````````$!@``]04```0"``!S
M`0``D@,`````````````9@```%T"```G````@04``$H'``#-!0``1`,`````
M``#(`0``BP(``!@&```=`@``C00````````P`0```````+`!``#M````````
M``````"=`P``"P<`````````````V@,``!`&```!`@``H08``#P#``"'!0``
M`````#P%`````````````+,!``#J``````````````!^`@``GP(```````"\
M`@```````&H&``#,````40$``````````````````(@```![!@``/P0`````
M``![!0```````-P````T!@``&P0``!$!````````LP```(<$``":!0``I08`
M`-L%``!E`@``$`(```````#'!@``/`8``.0``````````````#L$``#.````
M`````#`&``"9!@``:`,``%<&````````[P(``(\%``#/!0``$@4``'\!```+
M`P```````+``````````Q````&T#``!^`P``````````````````>@(``"H%
M``!1`P``&04``&,`````````@`0``',```"-````Q@```'\"``#P!0``0`,`
M`,0%``!G!@```````/D!```````````````````+!0``-@```$P'```0`P``
M+````(,"``!O````-`````````!Y!@``'````.`&``"0!@``;P$``&T%``#(
M!0```````"<&```]!P``#@``````````````G`4````````Q`@``4P``````
M``!7!P``>`0``*(```!@`0```````-X#````````"0```!8$``#8`P``0P(`
M`````````````````,(#``!/`@``*0(``/H"``",!@``E0```"\!``!6`@``
M5P4``%P%``!A!@``(P4``'<!````````F@,```$#``"A!````````.,````<
M!@``P@4```H"``"[!0```````#D%```*!@``1P,``````````````````*L&
M``!#`P``JP````4'``!D````O0```(,&````````FP,``*L#````````H0(`
M`+$!``#"!```F`0``"@``````````````!$"``#X!@``,P````,&```X!0``
M7`<``-H$```V!```O@8``(L!````````A@,``!H$``````````````````!!
M`P``P@`````````)!P``I00```````#=`P```````)(&``"1`P```````.4!
M```_!P``=P0``&P!``!(!P````8``````````````````(8&````````<@``
M`$`'```/!@```````#0"```C`````````.T%``"L!@``4P,``&0#``#&!0``
M2@0``,H"``!9````,0<``!0%`````````````/\%````````=0,```````"H
M!`````````````#B`@```````#D#`````````````/\!``",!0``/`(``+P&
M```B!@``QP0``%`&`````````````'H$``"$`P``U@```.\&``!9`0``FP0`
M`+D$``"F!0``_@$``"P%````````!08``,H````Y!@```````,\"````````
MO````&\#``!?`P``*P,``-0&```S!@``"@```%T$````````R@8``&X$```I
M!```[P,``"4#``"Q!```'`$```````!Q!```-@$```````"M`````````(0%
M``![`0``]@8``&<'````````'@8```````#5!````````+L$``!V`P``204`
M````````````40(``!4"``#Q!```A00```````"M`0``>0```-`$``!#````
M(`,``$P$```$````#0,``%D&``!W`P``0`8``.$````J````V0$````````L
M`P``H0```",#```2!```=`(``.\$``"9!`````````````#U!@``8P(``%4%
M``````````````('```!!```J`(``+\"```\```````````````2````[@0`
M`#$$````````Z`8``!4$````````5P(``+\!``".!0``^0````````#0!0``
M`````($!```-!P``:````.0!``#4`0``%`<``+`"``"!!```N04``#0'````
M````-@4``/\&``#:`@``B04``/0$````````CP(```<#``#&`0``,`0``"L'
M``!D!```,@0```````#R`@``B`(```H'``#?`@``508``'`"````````````
M`-,&``#!`P``3```````````````[0(``%P&``"U`0``.`8``(H$```@`0``
M2P<``%<$``#0`@``T@,````````?!P``.@0``#(#``!@!@```````&,#````
M````T@4``%($``"_`P``````````````````2@(``!<!``#.`@``-@8``(L`
M``#!`@``O0$````````F!```3`4```````"(`P```````*<```!;!P``)`<`
M`/$```#X!0``^@$````````V`P``NP````,`````````H@(``%('``#W`@``
MG@(``&````!^````7`$`````````````3P```'($````````4@,``!H&```4
M`@``G`(``,T$````````AP8```````!F!```D@0```````"=`@``PP8``/``
M````````O`4``,`&``#@`0``+@(``%L"````````F04``'`#``!`!0``F@``
M`'0%```,`0``-P4```0#````````:@(```````#T`0``IP(`````````````
M`````````````````````%0"``"9`P``/P$``)X$```M!0``&@````````"5
M!```-@<``/`!`````````````-0%````````#0$```````#)!@```````$$'
M``"W`@``````````````````S`8``!T````Z`P````````````"+`P``K`4`
M`%,"```N!```:P$```````#/!```+`<``%@!```C!```E@$`````````````
MO0(```X'``!K`@``80````````!A`@``E@```!$```"0`0``5@0`````````
M````&````.$!````````:`$``#`#``#E`@``'P```'P!````````\P4``"4'
M``#)!0``*`4``!8'````````_@(``+0#``#D!````````&0'```]`0``2P,`
M`"@$``"D`0```````,,"````````$````,,#``"&`@```````+X!````````
M`````$D'``#[`P``&`(``((%``!E`P``:`8``-8$`````````````-P!````
M`````````+\&``#1!@``E`8```L````T`0``Y04``'L#``"V`@```````*X&
M```H!@``Y`8``!4'````````H@$`````````````Q`8``-H````(`@``=`0`
M`!8#````````5P,``"4&```B!P````````````#P`P``!0,````````9````
M;`,``.<$``#+`0``^@0``)4!``!S!```WP$``-(!``#>`0```````/H```"B
M`P``4P4```````"T`0```````/0```!\`P``U0$``)`#````````GP4`````
M```;!@``!00``.D&```#!````````&H'``!C`0``J`8``,````#!````5`0`
M`%D%``!R`P``QP(`````````````C0(``)P#```6!0``\04``#4!``")`@``
MCP```/X```#Z!0````````````##`0``9`$```````"7!```E@,``/X$``#A
M!```T`,``*T#``#+!0``W0$```````!M!@``MP``````````````2`0`````
M``!/!P``400``,8&````````%P(```````"I`````````%`"``"]!```.@$`
M`%4"```C`@``T@(```P```"5!@``KP0``+<!```B`0```````$,!``!R!P``
M#@4```````!T`0``/@8``.P"```J`P```````%L$``#2!```Q@(`````````
M````H@0``'X!``")!````````+4$``!6!P```````$$%``"2!0``Z@$``%0'
M``"8!0``!P<```````#G`P``J0,``)4#``#\!@``0@,``!L"```J!```````
M`&L'``!G`0``/P8``)L"```O!P``?P4``+P!````````"P0````````Z````
M*P(```T$``!>!```\@8```````!A`P``O0,``$0&``#(`@```````'@#````
M````7P4``$<&``!_!```U@4``(T&``#I`P``O@,``,`"```2!P```````(T%
M```3````,`<```````#1````*P4````````J!P``5@,```````!8!0``F@(`
M``(&```\!`````````("``!H!P````````````#@````:@0``-````!?`@``
MNP(```````"=````IP4``&@"``"I!```E@(``"`$```Q!0``X@0``-\#``#W
M!```>``````````3!P``_0,``'(%``#\`P````````````#+`P``1@,``+,"
M````````U`0```D$``!L!```'08````````/!0``20(``($"```]!@``B`8`
M````````````(0,``"$&```Z!@``5@8``#``````````CP$``"H!````````
ML@(`````````````*@8``-P"```(`0``7@(``/,"``#9!@```````.X%````
M````DP````````!:!`````````````#(!@````````````"7`0``6P4``!X`
M``!/`P``[0$``!X!``!A!P``````````````````Q08``!4#``"-`0``````
M`'T$```D!0```````*D%``"L`@``)P<````````&!P````````````"V!0``
M'`(``-D"````````G0$``%<!```"`0``1@(``$\$``#K!0``2@4```````!N
M!P````````H$``#'`````````"($``!X!@``@@$``$D$``#M!@``:P``````
M``!V!@```````.L#``#/`0``TP(``!0```"7`@````````````#7`P``````
M``X$``"3!0```````#<'```G`@``:P8```````"%!0``OP0``#D```!.`P``
MQP,``&\"``";````I0(```````#\`@``FP8``%X```!`!```?04``"L!``"I
M`@```````)D```#9`P``$04``/<````X`@``L@```,H%````````V04`````
M````````\`0`````````````YP4`````````````1P(``"\%````````L0(`
M``````!I`P```````/\#```#!0``(`8``$8&```1`P```````)P$``#T!0``
M=@```%\'``"?!````````*X#``!!`@``FP4```D#`````````````$P&````
M````5@4`````````````XP0``+<%```N!@``V0```!`'``!S!@```````.D!
M```U!```;`8``#X'``"C!```9P````````!]!@``I0,````'```=!0``N0,`
M``````!4!0``:`4``'L"`````````````'@"``".!```B0```((#``"3`P``
M:@$``&X#``#Y!```P`$``%("``"#`P``Z`0``(`````^`@``-08``$0%```T
M`P``"0$``*@%`````````````)H$````````;P<``.$#```[`P``````````
M``#6!@```````)$!````````N`8``'$&```<!```]@(``+T%``![````@08`
M`*H!````````<0,```L!``#F`@``.P8``#4'`````````````(0````=`P``
M&P4``#,!```M````EP8``,D$````````+`(``)<````:!P``"`,```````"/
M!````````,\#````````BP0``"4!````````4`````````!8!P``4P<``%H`
M``!I`@````````X#``!$`0``6P,``#X$````````&@(```````"N````N```
M````````````8@8``-4%```?!@``5`,``'P&``!&`0``O@0``#@'````````
M``````````#:!@``A`0``$$````I`P``40<``+8!``#=!```9P,```````#%
M````F@$````````5````5````.<!``#Q!@``G00``"@#``#7!```^`0``)$$
M````````F0$``#D!``!@!````````#,#``"_````#`4``.@#``#;`@``D@$`
M`/$#``"P!```SP8``'X&``!"````&0$```````"/!@``8P8``(8$``!I!0``
M`````.L!``!B!P``BP8``&T"```"`P````````````#!`0``L08``.X"````
M````+08``)L!````````X@````````!0!P```````!0$```Q!@``I@,``$<'
M``#_!```0@<``/@!```"````1P$``',#```G!0```````!<%``!/`0``&`$`
M`(<#````````6P8``(D!`````````````````````````````'0&````````
MCP,```````#N`P``I@(``.,#```(!@``$P0``$L%``!G`@``!`<````````-
M`````P$``/<&``"F!```8@4``-,#````````T`8``,T"``"C`0``2`8``$P!
M``#7````/@4```````!)````<@8``"H"````````@`(``/P!``#\!0``````
M``````!W````!P8``-0````;`0``S@4````````&````_04``!<&``"M!@``
MV`(``%,!``"N`0``;P4``-X%``"A`P``_`0`````````````:0<``.T$``",
M`0``@P0````"``!-`````````$("``"^`@``B`$``.(!````````V`4``"0`
M```S!0``.`$``(0!``````````````````"Z`P``,0```)0```"0!```1`(`
M```````O`````````'\&```O!@``F@8``````````````````!H#``#7!@``
MIP$``/4``````````````*@```!"!@``M`8``(P"```U!0````````````!<
M!```4@4```````#B!0``GP,```,'````````'P(``-,$```O!```.0(`````
M``"R!@```````/`&``"X!```R@$``#<#``"O!0```````'4````^`P``=P(`
M``````"(!```P@$``````````````````+`%``!>!0``,@$``*0%``!!!```
M4`0````````_````)`0``/X%`````````````),$`````````````*L$``!U
M!0``]0(``-,%````````=`,``*X%``#E`P``N0$``!\%````````R0$`````
M````````2P$````````I!P``N@0``+X%``!L````8`4```````!N`0``(P8`
M``<$````````500``+$#```6`@``3@4```````#K!```@@(``!`%``">`P``
MX04```````!X`0``:0```($#``#F!0```````.<```!``0``#@$`````````
M````=@(``(H&``#!!0``+P(`````````````````````````````1@<`````
M``!U!```1P0``'H#``#P`@```````$($``#T`@````````````!#!P``WP4`
M`!D'```D`@``F`(``%$&``!1!0``4`,``/$"``````````````````!*`0``
M2`,``#D'``!=`P``HP4`````````````@P$``"$'``!B`P```````$`"````
M````)@$``$X```"K`0```````(H%``!-!@``<`8``%T&```S`@``300``,8#
M``#+!````````+0%```7!P``&`4``%H!``!U`0``!@$``,$$```S!```````
M``````#-!@``1`0``(L%``#$`@````````````#`!0``Z`(``.`"```3!@``
MD`(``.H"```N`0``,@8``)D"`````````````&T```!6`0``800``+(#````
M````<0$``&D&``#<`P```````/,```!;`0``%08``.<"``"Y`@``F`8``&T!
M````````8P<``%,$``"N`@```````)$````5`0```````*,&````````VP,`
M`&<%```N````Y@$`````````````L@0``*P````@`@``<@$``/,!````````
M`````$D&``#L`0```````)8%````````Y@8``+8&````````A@```"D!````
M````T0$``+@"``!$!P``.@4```````#[`@``!P````````"Y````$08```0!
M```<!P```````.0%````````C`0```4"``!>`P``$@$``/T$````````$P(`
M`(($````````]0,``*D&``"=!0``S`0``!L```!B!```WP0``/(%``"F`0``
M)@8``'T"````````'`,```@$````````8P0``+P$``!.!P``R`0``-X&````
M````_@,``,P#```X!```)P0````#````````^`(``````````````````%@#
M```?!```"0(``*,#````````K0(````````Q`P``2`$``+P#``"4`P``G`$`
M``````!5`0``[P4``.,!``"K`@``4@$``&4%````````1@4```4```!Q!P``
M.@<````````W`@``"`4``*@!``#D`@```````&$!``!N!@```````/@```"%
M!@``_````*H"``#X`P``%P```#\#``"8`P``/04``.`$````````I`0`````
M````````6P```.8$``##````.00``&,%``#9!```,`(```(%``"A!0``````
M`.(#```'`@``E@8``!$'``"D````+`8``!8````M`P````````\"``#V````
M"P(``$X&``!N!0``F`$``/T&```W!@``<`0``)0%`````````0<``,D"``!/
M!0````````````!2!@``W`4```($``!0`0``W04````````D`0``:P4`````
M````````8@(```````#[!@``*08``*8&````````\P8``&X`````````````
M`"0&```!!@``'0<```````!G!```]@,```````!S`@``%`,``"8`````````
M9@,``*H$```I````5`8``!4%``#U`0``-P0``"T'``#]````+P,``.@```"U
M`P`````````````0`0````````````#2!@```````%@&````````'0$``'4"
M```/`0``@P```$L"``#[````W`8``%X&```]````&P,``*X$````````U0,`
M`'<&``#8!```OP4``(8!``"4`@``(@```"X'``#.!```6@(```````"H`P``
M6`0`````````````804```````"D!@``9@8```````"*`0``MP,``'`'``".
M`@``G@$``-0#``"L`P``G`8``)@```!,`@``P`,``$T!``#[!0``/00``)P`
M``#Y`P``>0$``'4&``!J`P``+0(``/8!``#N`````````-4"````````!`0`
M``````!X!0``?`4````````L`0``&08```````#]`@``D08``/X&``"*`@``
M=````",'``!+!@````````X&``!%!0```````&8"``!9`@``.P<```````"3
M!@``N@4``&H%```I!0``H````-T&``````````````````!-!P``C`,```\#
M```@!P``$P$``%D#``#L````(@,``#<```"@`@``````````````````````
M`,,%``"!````[`4``!@'````("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@
M)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T
M97)D87DI`"!A="``(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E<R(@:7,@
M;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D(&EN
M('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO="!F
M;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E
M<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@
M=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S960@;V8@)2XR9DU"(&%L
M;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D(&1A>7,@=6YT:6P@>6]U
M<B!P87-S=V]R9"!E>'!I<F5S+@`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I
M8V4`)7,@1FEN9V5R<')I;G0`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M
M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F
M($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@
M:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T
M:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@`E<R!I
M<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@
M;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO
M=&5P860`)7,G<R!487-K;&ES=``E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@
M8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO
M=VEN9R!A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD
M97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN`"P@9W5S=&EN9R``
M+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S
M96QE8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U
M<G,`/%!R979I;W5S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F
M;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P
M=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S
M:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E
M+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G
M92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N
M`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@
M;65S<V%G92X`04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3
M:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI
M<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<W,@
M9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@
M8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N
M="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D
M($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!
M9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G
M<F]U<"!T;R`B)7,B`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!
M9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D
M('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D
M9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D
M('5S97(`061D960@(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T
M(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D
M("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I
M;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D
M;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D
M;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`
M06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@
M57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED
M97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@
M;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)
M35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)
M35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T
M92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A`$%N
M(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O
M<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM
M;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U
M9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I
M<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X
M:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV
M92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y
M;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U8BUG
M<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)+3@I
M`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A
M8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN
M9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`
M071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M
M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M
M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`075G
M=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I
M;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@
M9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U
M<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T
M<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@
M4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@
M4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z
M(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P
M.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I
M<F5C=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P
M;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!297%U:7)E
M9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE
M('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]L9&%P.B!5<&1A
M=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T
M;W)Y+@!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A
M:6QE9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A
M:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E
M<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U
M=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"X`079A:6QA
M8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C:V=R;W5N
M9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D
M(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)
M4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E(&=R87!H:6-S
M(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`0F%S96QI;F4`0F5L87)U<P!"
M96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!"
M;&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C
M:R!3971T:6YG<P!";&]C:R!4>7!E`$)O;&0`0F]L:79I80!";V]K;6%R:W,`
M0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(
M97)Z96=O=FEN80!";W1H`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD
M`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I
M($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A
M<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?
M96QL(%!R;W!E<G1I97,N+BX`0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E
M9"X`0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86X@;F]T(')E
M<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R+@!#86X@;F]T('=R:71E('1O(&9I;&4@(B5S(@!#86XG="!A
M9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N`$-A;B=T(&-O
M;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;B=T(&]P96X@9FEL92`B)7,B
M+@!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@
M9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER
M96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P
M87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO
M="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@
M;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N
M;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@
M=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A<G)I
M97(`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA;F1S`$-E;&P@
M4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P
M97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X
M-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A
M;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#
M97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D`$-H
M86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA;64@86YD
M(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R
M97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I
M<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO
M;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H96-?:R!,
M:6YK+BXN`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R
M*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@07!P;&EC871I
M;VXZ`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S
M92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP
M92`H9F]R(&]R9&5R960@;&ES=',I`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@
M9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F
M:6-E('1A9W,`0VQE87(@475E<GD`0VQE87(@;W5T('5S97(Z("5S`$-L96%R
M('5S97(`0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@
M0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO
M=61S`$-L;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N
M9',`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I
M80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#
M;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M
M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T97)S`$-O
M;F1I=&EO;@!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`
M0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO
M;F5S(&%N9"!/=71L;V]K+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E
M+@!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@
M5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I
M;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C
M=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',`0V]N=&%C=',@
M=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN
M`$-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O
M9B`B)7,B`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y
M(&9A:6QE9#H@)7,`0V]P>2!S96QE8W1I;VX`0V]S="!)1`!#;W-T82!2:6-A
M`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z
M(`!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@`$-O=6QD(&YO="!3+TU)
M344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S
M<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN
M9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S
M`$-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@
M8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO
M="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96-R
M>7!T(%!'4"!D871A.B``0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N
M`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E;&5T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E;&5T92!S971U
M<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H
M92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H
M(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L
M971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O
M;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@
M;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@(B5S(BX`0V]U
M;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`
M0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U;&0@;F]T(&]P
M96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE
M("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#;W5L9"!N;W0@
M<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U
M;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U
M<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E
M8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!
M0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@
M;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@
M<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T
M<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@
M8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER("(E<R(N`$-O=6QD(&YO
M="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C
M:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N
M9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C
M<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U
M<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE
M(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@
M;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R
M8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK("(E<R(N`$-O
M=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R
M871I;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@
M4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6QD
M;B=T(&=I=F4@=7-E<B`B)7,B('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T
M:&4@9F]L9&5R("(E<R(Z("5S`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S
M97,`0W)E871E`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A
M=&4@<W5B(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R
M9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0@-"!0:&%S97,`0W5R<F5N
M="!397-S:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N
M="!5<V5R<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#
M=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O
M;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+
M3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I
M;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$4TX@*'-E92!H='1P
M.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B
M+FEN=')O+61S;BYP:'`I`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T86)A
M<V4@3&]O:W5P`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$
M87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E
M8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)
M9&5N=&ET>0!$969A=6QT(%-H96QL`$1E9FEN:71I;VYS`$1E;&5T90!$96QE
M=&4@0V5L;`!$96QE=&4@1W)O=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES
M<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E
M;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T
M90!$96QE=&4@;65S<V%G97,`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B
M`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M
M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`
M1&5L971E('-U8B!F;VQD97)S`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`
M1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&5D('-E='5P('5P9W)A9&4@
M<V-R:7!T("(E<R(N`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$97-C<FEB92!T
M:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO<F1E
M)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE
M(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I
M;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T
M('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$
M:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y
M(&1E=&%I;&5D(&9O<F5C87-T`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES
M<&QA>2!F;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I
M`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N
M86YC92YP:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD
M(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI
M;FEC86X@4F5P=6)L:6,`1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P
M+@!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N
M9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G
M<P!%+4UA:6P`14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R
M<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N`$524@!%8W5A9&]R
M`$5D:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%
M9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@
M;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E<R(`161I="!P
M97)M:7-S:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R
M`$5L96UE;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R
M97-S97,@;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UA
M:6PM=&\M4TU3($=A=&5W87D`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M
M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E<G1I
M;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N
M86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!Y96%R`$5N;&%R
M9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U
M('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S
M=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%
M;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`16YT97(@=&AE(&QE='1E<G,@8F5L
M;W<Z`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@8W)E
M871I;F<@8FQO8VLZ("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E
M<P!%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,`17)R;W(@9V5T=&EN9R!C
M;VYT96YT.B`E<P!%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,`17)R;W(@
M=VET:"!E;6%I;"!M97-S86=E+@!%<G)O<B!W<FET:6YG("(E<R(N`$5S=&]N
M:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V
M97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E
M<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X
M86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%
M>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R
M8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L;W(`1E10
M('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E
M<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T
M;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@
M(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T
M92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B
M+@!&86EL960@=&\@<F5T<FEE=F4Z("5S`$9A:7(`1F%L:VQA;F0@27-L86YD
M<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&
M87AE<P!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO
M=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6=L970@0T%0
M5$-(00!&:6II`$9I;&4`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT
M.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T
M:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&
M:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R
M871I;P!&;&EP`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#
M;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA
M9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T
M:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG
M:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED
M92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`
M1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A
M<F1S`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E
M;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!4
M97)R:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U
M;&P@36]O;@!&=6QL($YA;64`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E
M(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I
M;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A
M;'1A<@!':79E;B!.86UE`$=L;V)A;"!/<'1I;VYS`$=O`$=O961E;`!';V]G
M;&4@36%P<P!';V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96L@
M*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T
M<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P7VQD
M87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60Z(`!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R
M;W5P("5S`$=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,`
M1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E
M<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U
M`$=U>6%N80!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@
M=&%B;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(
M87-H+4%L9V]R:71H;0!(87IE`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N
M9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE8G)E=R`H
M25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(
M96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE
M(&9I;&4Z`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T
M92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N
M90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L
M:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D
M92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`
M2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE
M<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S
M("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q
M=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@
M<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR
M;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC
M:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E
M("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I
M>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A
M*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(
M;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@
M<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I
M='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@
M9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)
M34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R
M97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@
M=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T
M:6]N+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC
M;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)
M9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I
M="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS
M('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE
M8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@
M>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@
M>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R
M(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ
M`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E
M('5P;&]A9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD
M.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R
M<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N
M9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T
M92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E
M;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O
M<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);G-E
M<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN
M<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@
M;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W
M(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R
M;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F
M;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@
M=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H
M92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E
M<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@
M=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E
M;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B
M969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`
M26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E
M<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T
M:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS
M97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T
M;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N
M`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A
M($AE861E<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A=&EO
M;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`
M26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R
M;6%T`$EN=F%L:60@;&EC96YS92!K97DN`$EN=F%L:60@;&]C871I;VX@<')O
M=FED960N`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A
M<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED
M('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@:60N`$EN=F%L
M:60@<')O9'5C="!C;V1E+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E
M8VEP:65N=#H@(B5S(@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O
M=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y
M`$EN=F5R="!S96QE8W1I;VX`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)
M<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R
M865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N
M`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU
M;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF
M>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L
M/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I
M;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I
M;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@
M97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I
M`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A
M+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T
M86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!2
M97!U8FQI8P!,87-T($AA;&8`3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1
M=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I
M;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA
M>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,
M969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QE=F5L`$QI8F5R:6$`
M3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R
M:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@
M3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E
M<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;FL`3&EN:R!P;VEN
M=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@
M<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@
M+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T
M($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE
M;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB
M90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E
M<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!I<R!D
M:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A
M;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@
M;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N`$QO9R!O=70`3&]G:6X`3&]G:6X@
M5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P
M87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D
M+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E
M<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`3'5X96UB;W5R
M9P!-30!-3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T
M82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!2
M97!U8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-
M86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA
M;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O
M(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H
M('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M87``36%P
M<&EN9W,@<W1O<F5D+@!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS
M965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A
M;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C
M:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@
M8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@
M;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM
M=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,`36%X:6UU;2!L96YG=&@`36%Y
M`$UA>6]T=&4`365D:6-I;F4`365M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E
M;&QS`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T
M('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I
M960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&%R(%=E871H
M97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T
M(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@
M861M:6YI<W1R871O<BX`365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H
M;V0`365T:&]D("(E<R(@:7,@;F]T(&1E9FEN960`365T:&]D(&YO="!D969I
M;F5D+B!#86QL960@;65T:&]D.B`E<P!-971R:6,`365X:6-O`$UI8W)O;F5S
M:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@
M=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``
M36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9`!-:7)R
M;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E
M<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N
M97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T
M:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!
M4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE
M($UA:6P`36]D97)A=&4`36]D:69I960@1&%T90!-;V1I9GD@55),`$UO9'5L
M=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H
M(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E
M(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D
M+@!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3
M=6YN>0!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-
M;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@
M9&]W;B!L:7-T<P!-=6QT:6UA<"!52R!M87``375L=&EP;&4@<V5L96-T:6]N
M`$UY($%C8V]U;G0`37D@06-C;W5N="!);F9O<FUA=&EO;@!->2!0;W)T86P`
M37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.
M86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N
M9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V
M;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!2
M96YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!3
M4TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.
M971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A
M;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($UE<W-A9V4@=&\@)7,`3F5W($UO
M;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W('!A
M<W-W;W)D`$YE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"X`3F5W('!A
M<W-W;W)D<R!D;VXG="!M871C:"X`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S
M`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S`$YE>'0@;W!T:6]N<P!.
M97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO
M(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E
M;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E3
M3R!I;6%G97,N`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@
M870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R
M;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO
M(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($94
M4"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@
M9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D960`3F\@:6-O
M;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C871I;VX@<')O
M=FED960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D
M+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H
M96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O
M=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R
M:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!Q
M=6]T82!S970N`$YO(')U;&5S`$YO('-E<&%R871O<B!S<&5C:69I960N`$YO
M('-I9&5S`$YO('-U8V@@9FEL90!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V
M86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R
M9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`
M3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!2
M96=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@
M>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN
M`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P
M*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N
M($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`
M3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@
M<W5P<&]R=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`
M3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O
M9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE
M9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C
M=`!/8FIE8W0@0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R
M`$]F9FEC90!/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E
M;G0N`$]L9"!P87-S=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N
M`$]M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R
M<RX`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D
M<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI
M<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S
M:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,
M(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O
M34E-12!P87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P
M97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D
M($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI
M>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T
M96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R
M(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA
M8FQE+@!014%2.CI-86EL(&)A8VME;F0`4$=0($1I9VET86P@4VEG;F%T=7)E
M`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D
M+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!-($QI9VAT(%)A:6X`4$T@4F%I
M;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U;@!0
M32!4+5-T;W)M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!0861D:6YG
M`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I
M960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R=&QY($-L
M;W5D>0!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`
M4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)
M55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N
M`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!0
M87-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P
M<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I
M;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`
M4&5R;6ES<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI
M<W-I;VX@1&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T
M<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P
M:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L871I='5D97,`
M4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H
M870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O
M;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0
M;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@
M82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V
M86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C
M:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@
M96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@
M;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@
M86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@
M66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T
M96TN`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`4&]L86YD
M`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@
M:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O('1H:7,@
M9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E8VEP:71A=&EO;B!F
M;W(@;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A=&EO;CQB<B`O/F-H86YC
M90!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N
M(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``
M4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W
M('=I;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A
M=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0
M<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U
M8FQI8R!+97D@26YF;P!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE
M<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!0=7)G92!M97-S86=E
M<P!1871A<@!1=65R>0!1=6]T80!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2
M861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN
M(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R
M='5N90!2871I;P!296%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E
M<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E
M;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A
M;FYO="!B92!U;F1O;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E
M<V@`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R
M=&%L(%9I97<Z`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!296UA<FMS
M`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L
M92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU
M;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D
M('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E
M;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!2
M96UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B
M92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S=&5D('-E
M<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+@!297%U:7)E9"`B)7,B(&YO="!S
M<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N
M;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B
M)7,B(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@
M1FEE;&0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R
M9`!297-T;W)E($QA<W0@475E<GD`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N
M<P!2971Y<&4@;F5W('!A<W-W;W)D`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R
M871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`
M4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`
M4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I
M9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S
M`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M
M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@
M1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T
M=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I8V%T
M:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,('-T871E
M;65N="!F;W(@=F%L=64@;&]O:W5P<P!34T@`4U5#0T534P!380!386EN="!(
M96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT
M(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R
M96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`
M4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D
M:2!!<F%B:6$`4V%V90!3879E("(E<R(`4V%V92`E<P!3879E($]P=&EO;G,`
M4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@
M=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E
M<R!C;VYF:6=U<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E('-C<FEP="!T
M;SH@(B5S(BX`4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A<F-H`%-E
M87)C:"!%;F=I;F5S`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C
M="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@
M<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P`4V5L96-T
M(&%L;"!D871E(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T
M(&YO;F4`4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE
M(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE
M;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET
M97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I
M='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI
M=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H
M:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@
M>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`
M4V5N9"!335,`4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N
M9"!-;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@
M;W(@;F]T(&%V86EL86)L92X`4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X
M<&ER960N`%-E<W-I;VYS`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@
M=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N
M`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S
M<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A
M9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T
M=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG
M+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R
M861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I
M8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`
M4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F
M;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@
M8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I
M;C\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3
M:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE
M;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE
M<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO
M=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM
M86=E('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO
M=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI
M='D`4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS
M*2!O=70@;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3
M:6=N871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3
M:VEP($UA:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3
M:&]W97(`4VYO=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H
M;W=E<G,@3&%T90!3;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A
M=&5R.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3
M;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I
M8V$`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@
M86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES
M<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W
M965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG
M`%-P86-I;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A
M8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`
M4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A
M<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R
M965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D
M;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;0U-370!3=0!3=6)D:7)E
M8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E
M9"!R97%U97-T('1O(&%D9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86YN
M;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E
M9"X`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@
M=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@
M=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T
M960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S(B!F<F]M('1H92!S
M>7-T96TN`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!2
M96QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K
M=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K
M=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@=7!D871E
M9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U
M;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3
M=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`
M4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II
M;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN8R!L;V<@9&5L971E9`!3>6YT
M87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC
M`%0M4W1O<FT`5"U3=&]R;2!A;F0@5VEN9'D`5"U3=&]R;7,`5"U3=&]R;7,@
M16%R;'D`5%-6(&9I;&4`5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!P
M<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A
M:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z
M`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``
M5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP97)A='5R93QB<B`O/B@E
M<TAI)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E("(E<R(@;F]T(&9O=6YD
M+@!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!497AT
M(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AE
M($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($AI<W1O<GD@
M<WES=&5M(&ES(&1I<V%B;&5D+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I
M;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@24U34"!L;V<@
M8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@36%I;G1E;F%N8V4Z.B!C
M;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I
M;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N
M965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C
M:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T
M;VT@<VED92!O;FQY`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P
M96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D
M871A8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T
M;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U
M<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S
M<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T
M('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A
M=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I
M960N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@
M=V5B(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@
M)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E
M<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET
M<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I
M;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE
M<W-A9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E
M('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W
M<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@
M(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O
M9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S
M:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@
M;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@
M1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W
M87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@
M=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B
M(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H
M92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@
M=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N
M("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE
M9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@
M8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N
M(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F(&9I
M96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R
M97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H
M92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@
M:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`
M5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@
M=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<75O=&4@8VAA<F%C
M=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!R:6=H="!A
M;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4
M:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H
M92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E
M<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@
M:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S
M(&YO="!E>&ES="X`5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@
M97AI<W0N`%1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE
M('1E>'0@;VX@=&AE('-C<F5E;BX`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S
M(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S
M(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F
M:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K
M(&ES(&YO="!A=F%I;&%B;&4N`%1H96UE<R!D:7)E8W1O<GD@(B5S(B!N;W0@
M9F]U;F0N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@
M87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H
M97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO
M=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@
M;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B
M('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I
M;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E
M('=A<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ
M(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A
M<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A
M;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL
M>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI
M<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H
M92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@
M<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG
M('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@
M=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`
M5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@
M;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI<R!)34%0('-E<G9E
M<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S
M(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D
M;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D
M;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE
M($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@
M=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC
M;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA
M:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@9V%T97=A
M>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E
M;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N
M,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@
M8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R
M<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE
M;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F
M;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F;W)M(&AA<R!A
M;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&ES(&$@
M2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y
M;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R<W1A;F1S
M('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U
M8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`5&AI<R!M97-S86=E
M('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H
M86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE
M+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F
M:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4
M:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@
M8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:6-K
M971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C
M=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O
M('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L
M("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O
M9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M;W)R;W<`
M5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871I;VYS`%1R:6YI
M9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U<FME
M>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD
M($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6
M+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T
M871U<R!R97!O<G0`55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@86-C
M97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I
M;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@
M<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG
M92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H
M86YG92!T;R`E<RX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B
M+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R\E<R(N`%5N86)L
M92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T
M('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O
M(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@
M5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA
M8FQE('1O(&-R96%T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!C<F5A
M=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N
M`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@
M96UP='DN`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D
M96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@
M5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I
M=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O
M<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA
M8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M
M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O
M(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C
M:&EV92X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I
M;&5D*2X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@
M9F%I;&5D*2X`56YA8FQE('1O(')E860@9FEL93H@`%5N86)L92!T;R!R96%D
M('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T
M;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L
M92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!6
M1E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@
M=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`
M56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@
M9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL
M92!D871A+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@
M8F4@97AC965D960N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO
M=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E
M<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E9"!!<F%B
M($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI=&5D
M(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO=VX`
M56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N(&-L
M:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@;&]C871I;VX@
M<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N;&EN
M:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV:6QE9V5D('-C
M<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I
M8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@
M82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y
M;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O
M87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E
M`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P9W)A9&4@
M<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I
M;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T
M=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z
M("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT
M(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R("5S(&ES(&YO="!A=71H;W)I
M<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`
M57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@
M9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<B!A8V-O=6YT(&YO="!F;W5N
M9`!5<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R
M;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES
M=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A
M;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@
M:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU
M;2!L96YG=&@@;V8@)7,N`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`
M5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE
M9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N
M`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I
M8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6:65T
M;F%M97-E("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@
M<&%G90!6:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I
M;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F
M;VYE($ET86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-2
M25!4($U!3E5!3$Q9($923TT@)7,N`%=)3B!V:6$@2%144`!786QL:7,@86YD
M($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE<B!D
M871A('!R;W9I9&5D(&)Y`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M90!7
M96QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I
M`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P
M<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T
M(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T
M92!C:&%R86-T97(_`%=H97)E:7,@075S=')A;&EA(&UA<`!7:&EC:"!P:&%S
M97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@
M961I=&]R+@!7:61T:`!7:61T:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE
M("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO
M9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7
M:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z
M`%=I;F0Z(`!7:7-D;VT`5VES:&QI<W0`5V]R:P!7;W)K($%D9')E<W,`5V]R
M:R!0:&]N90!7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X
M<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@
M17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!O9F9S970@)60@=VAI;&4@
M<F5A9&EN9R!A(%9&4R!F:6QE+@!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R
M86EN=',`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C
M="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF
M:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R
M;'D`665M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$
M12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE3
M25=91RX`66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N
M("5D(&)L;V-K<RX`66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A
M;FYO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE
M+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO
M=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL
M92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO=2!H879E
M(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C
M96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L
M("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO
M=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I
M9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M
M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB
M92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M
M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI
M;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@
M9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R
M(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`
M66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S
M="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P
M96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A
M(&YE=R!C871E9V]R>2!N86UE+@!9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET
M86QI86X@<&AO;F4@;G5M8F5R`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E
M9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U
M<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N
M970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F
M('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y
M;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC
M871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@
M268@>6]U('=I<V@@=&\@=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A
M8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT(&%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0N`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S
M(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA
M<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B
M<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I
M;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C
M=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E
M<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S
M(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L
M+T-O;6UA;F0@*R!0('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE
M.@!9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"X`66]U
M<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L;V=I
M;B!H87,@97AP:7)E9"X`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E
M<P!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A
M=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@
M=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A
M<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L
M;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!P87-S=V]R9"!H
M87,@97AP:7)E9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:
M86ER90!:86UB:6$`6FEM8F%B=V4`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B
M;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@
M5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T
M:6]N`%]#3$D`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O
M<&5R=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?
M3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]3971U<`!?
M5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`&%D9')E
M<W-E92!U;FMN;W=N`&-A;&5N9&%R`&-A;&T`8V%N;F]T(&-R96%T92!O=71P
M=70@9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H97)E`&-O;6UA;F0@
M;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R`&-R:71I8V%L
M('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M870@97)R;W(`961I=`!E
M;G1R>2!N;W0@9F]U;F0`9F%L;&EN9P!F:6QE`&9R;VT@=&AE("5S("@E<RD@
M870@)7,@)7,`9W5S=&EN9P!H.@!H;W-T(&YA;64@=6YK;F]W;@!I;6UE9&EA
M=&4`:6YP=70O;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R
M`&QI;F5S70!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E3
M3RX`;F%M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N
M;W1E<&%D`'!E<F-E;G0`<&5R;6ES<VEO;B!D96YI960`<&EX96QS`')E;6]T
M92!E<G)O<B!I;B!P<F]T;V-O;`!R:7-I;F<`<V5R=FEC92!U;F%V86EL86)L
M90!S:&]W(&1I9F9E<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S=&5A9'D`
M<WES=&5M(&5R<F]R`'1A<VL@;&ES=`!T96UP;W)A<GD@9F%I;'5R90!T>7!E
M('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N;F%M960`=7-E<B!S
M96QE8W0`=D-A<F0`=SH`4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C$*
M4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4
M+4-R96%T:6]N+41A=&4Z(#(P,#8M,#(M,3<@,3`Z,#`K,#$P,`I03RU2979I
M<VEO;BU$871E.B`R,#`V+3`R+3$W(#$P.C,X*S`Q,#`*3&%S="U4<F%N<VQA
M=&]R.B!,87-Z;&\@3"X@5&]R;F]C:2`\=&]R;&%S>D!X96YI82YS;W1E+FAU
M/@I,86YG=6%G92U496%M.B!(=6YG87)I86X@/&DQ.&Y`;&ES=',N:&]R9&4N
M;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA
M:6X[(&-H87)S970]:7-O+3@X-3DM,@I#;VYT96YT+51R86YS9F5R+45N8V]D
M:6YG.B`X8FET"@`@*"5S(&YA<'!A;"!E>F5L]71T*0`@*$%L="UB:6QL96YT
M>?L@)7,I`"`H)7,@;F%P(&WZ;'9A*0`@*&UA*0`@*&AO;&YA<"D`("AT96=N
M87`I`"`Z(``B)7,B(&YE;2!A;&OV;GEV=.%R+@`B)7,B(&YE;2#I<G;I;GEE
M<R!VX6QA<WITX7,N`"(E<R(@;FEN8W,@:V]N9FEG=7+A;'9A(&$@2&]R9&4@
M4F5G:7-T<GEB96XN`"(E<R(@9F%S=')U:W3Z<F$M;65G:F5L96[M=/4@;F5M
M('1A;.%L:&%T\RX`(B5S(BUT(&AO>GKA861T=6L@82!C<V]P;W)T;VMH;WHN
M`"(E<R(M="!H;WIZX6%D='5K(&$@:F]G;W-U;'1SX6=I(')E;F1S>F5R:&5Z
M+@`B)7,B+70@;F5M(&AO>G1U:R!LZ71R93H@)7,N`"4N,F9-0B!F96QH87-Z
M;N%L="!A("4N,F9-0B!M96=E;F=E9&5T=&+U;"`H)2XR9B4E*0`E9"`E<R#I
M<R`E<P`E9"!N87`@;?IL=F$@;&5JX7(@:F5L<WIA=N%N86L@Z7)VZ6YY97-S
MZ6=E+@`E9"!N87!O<R!E;/5R96IE;'KI<P`E<R`M($9I9WEE;&UE>G1E=.ES
M`"5S(&QE;GEO;6%T`"5S(&MA<F)A;G1A<G3A<VD@9F5L861A=&]K("T@;65G
M97+U<^UTZ7,`)7,@8F7A;&SM=.%S`"5S(&QO9VEN(&[I=B!I9^EN>6SI<P`E
M<R!S>F]L9^%L=&%TX7-I(&9E;'3I=&5L96L`02`B)7,B(&YE=OL@X6QL;VWA
M;GD@;>%R(&SI=&5Z:6LN`"5S(#H@)7,@)7,`02AZ*2`E<R!KZ7-Z96X@X6QL
M(&%Z(&%LX6)B:2!K87)B86YT87)TX7-I(&9E;&%D871O:R!E;';I9WKI<^ER
M92Y*96SV;&IE(&MI(&%Z;VMA="!A(&9E;&%D871O*&MA*70L(&%M:2AK92ET
M(&UO<W0@96P@:^UVX6X@=NEG97IN:2X`)7,@:VET]FQTZ7-E('-Z_&MSZ6=E
M<P`E<R!P97)C`"5S(&YE;2!T86SA;&AA=/,N`"5S("T@)7,@*/9S<WIE<V5N
M("5S*0`E<R!C[6UJ96=Y>NEK90`E<R!N87!TX7)A`"5S(&9E;&IE9WEZZ7-E
M:0`E<R!F96QA9&%T;&ES=.%J80`E<SH@3&5H971SZ6=E<RP@:&]G>2!E>B!A
M(&QE=NEL('9A;/-JX6)A;B!N96T@82!M96=A9&]T="!F96QA9/-T\VP@<WKA
M<FUA>FEK+B!';VYD;VQJ82!M96<L(&UI96SU='0@<N%K871T:6YT('9A;&%M
M:7)E+"!V86=Y('-Z96WI;'EE<R!I;F9O<FWA8VGS="!A9"!M96<N`"P@<WKI
M;&SV:^ES96L`+"`E<R`E<RUS('-ZZ6QL]FOI<V5K`"P@=N%L=&]Z\R`E<R#I
M<R`E<R!K]GKV='0`+2T@=N%L87-S>F]N("TM`#$R(/-RX7,@9F]R;>%T=6T`
M,C0@\W+A<R!F;W)MX71U;0`R-"#S<F$`/$5L]7KU`$5Z96X@8FQO:VL@:&%S
M>F[A;&%TX6AO>B!E9WD@861A=&+A>FES(&%L<F5N9'-Z97(@<WK\:W/I9V5S
M+@!(96QY<F5H;WIH871A=&QA;B!H:6)A('3V<G3I;G0`02!L97;I;"!T:71K
M;W/M=.%SX6AO>B!E9WD@;GEI;';A;F]S(%!'4"!K=6QC<R!S>OQK<^EG97,N
M`$$@9&EG:73A;&ES86X@86SA[7)T(&QE=NEL(&5L;&5N]7)ZZ7/I:&5Z(&5G
M>2!N>6EL=N%N;W,@4$=0(&MU;&-S('-Z_&MSZ6=E<RX`02!T:71K;W/M=&]T
M="!L97;I;"!D96OS9&]LX7/A:&]Z(&5G>2!N>6EL=N%N;W,@4$=0(&MU;&-S
M+"!E9WD@=&ET:V]S(%!'4"!K=6QC<R#I<R!E9WD@:F5L;6]N9&%T('-Z_&MS
MZ6=E<RX`02!L97;I;"!D:6=I=.%L:7,@86SA[7+A<^%H;WH@96=Y(&YY:6QV
MX6YO<R!01U`@:W5L8W,L(&5G>2!T:71K;W,@4$=0(&MU;&-S(.ES(&5G>2!J
M96QM;VYD870@<WK\:W/I9V5S+@!!('1I=&MO<^UT;W1T(&QE=NEL(&1E:_-D
M;VSA<^%H;WH@96=Y(&YY:6QVX6YO<R!3+TU)344@:W5L8W,L(&5G>2!T:71K
M;W,@4R]-24U%(&MU;&-S(.ES(&5G>2!J96QM;VYD870@<WK\:W/I9V5S+@!!
M(&QE=NEL(&1I9VETX6QI<R!A;.'M<N%SX6AO>B!E9WD@;GEI;';A;F]S(%,O
M34E-12!K=6QC<RP@96=Y('1I=&MO<R!3+TU)344@:W5L8W,@Z7,@96=Y(&IE
M;&UO;F1A="!S>OQK<^EG97,N`$$@;&5VZ6P@=&ET:V]S[73A<^%H;WH@96=Y
M(&YY:6QVX6YO<R!3+TU)344@:W5L8W,@<WK\:W/I9V5S+@!$Z6QE;/5T="!B
M;W)U;'0@Z6<`1.EL96SU='0@9WEE;F=E(&5S]0!$Z6QE;/5T="!E<_4`1.EL
M96SU='1I('KA<&]R;VL`1.EL96SU='0@:/-ZX7!O<F]K`&1E+V1U`$%022!)
M1"`H82!P<F]G<F%M;WKA<VD@9F5L_&QE="!A>F]N;W/M=/-J82D`17)R]6P@
M87H@961I=&]R<O-L`$[I=FIE9WDN+BX`86)S>B!A;'5L`&%B<WH@:_9ZZ7``
M3FEN8W,@:F]G;W-U;'1SX6=A(&$@5D93(&%L:_9N>79TX7(@;.ET<F5H;WKA
M<^%H;WHN`$YI;F-S(&IO9V]S=6QT<^%G82!A(%9&4R!FX6IL(&SI=')E:&]Z
MX7/A:&]Z+@!"96IE;&5N=&ME>NES:2!I;F9O<FWA8VGS`$IE;'-Z\P!!(&IO
M9V]S=6QT<^%G(&9E;"!V86X@9OQG9V5S>G1V92X`4.EN>OQG>65K`$)E=FET
M96P`06QC<V]P;W)T(&SI=')E:&]ZX7-A`$IO9V]S=6QT<^%G:2!A;&-S;W!O
M<G0@;.ET<F5H;WKA<V$`061D:G5K(&AO>GKA(&ET=#H`VFH@8W-O<&]R="!L
MZ71R96AO>N%S80#::B!J;V=O<W5L='/A9R!LZ71R96AO>N%S80!!;&-S;W!O
M<G0@:&]Z>N%A9.%S82`B)7,B+6AE>@!*;V=O<W5L='/A9VD@86QC<V]P;W)T
M(&AO>GKA863A<V$@(B5S(BUH97H`VFH@9F5L:&%S>F[A;/,@;.ET<F5H;WKA
M<V$Z`-IJ(&]S>FQO<"!H;WIZX6%DX7-A`-IJ('1A9V]K(&9E;';I=&5L90#:
M:B!PX7(@:&]Z>N%A9.%S80!!*'HI("5S(&UE;OQT(&%D:G5K(&AO>GKA(&$@
M36]Z:6QL82!M96[\<V]R:&]Z`$%D:G5K(&AO>GKA(&$@8^UM:F5G>7KI:VAE
M>CH`061J=6L@:&]Z>N$@82!C[6UJ96=Y>NEK96UH97H`VFH@9F5L:&%S>F[A
M;/,@:&]Z>N%A9.%S80`B)7,B(&9E;&AA<WINX6SS="!H;WIZX6%D='5K(&$@
M<F5N9'-Z97)H97HL(&1E(&YE;2!S:6ME<OQL="!A('3V8F)I(&)E:F5L96YT
M:V5ZZ7-I(&%D870@=.%R;VSA<V$Z("5S+@`B)7,B(&9E;&AA<WINX6SS="!F
M96QV971TZ6L@82!R96YD<WIE<F)E+B!-;W-T(&WA<B!B96IE;&5N=&ME>FAE
M="X`02!R96YD<WIE<FAE>B!N96T@861H873S:R!H;WIZX2#Z:B!F96QH87-Z
M;N%L\VLN`$/M;0!#[6UJ96=Y>NEK`$%D;6EN:7-Z='+A8VGS("T@:F]G;W-U
M;'1SX6=O:R!A9.%S82!T;W;A8F)I(&9E;&AA<WINX6SS:VYA:P!!9&UI;FES
M>G1RX6-I\P!(:7)D973I<V5K`$%F9V%N:7-Z=.%N`$%L8N%N:6$`06QGZ7)I
M80!!;&EA<P!%;&AE;'EE>NES`%)E;F1E>NES.@!A>B#V<W-Z97-E=`!-:6YD
M96X@;F5M('9E;F3I9R!F96QH87-Z;N%L\P!-:6YD96X@8W-O<&]R=`!-:6YD
M96X@:F]G;W-U;'1SX6<`36EN9"!A(&[I9WD@;VQD86QO;B!L96=Y96X@:V5R
M970`16YG961J_&YK(&UE9R!T]F)B(&/M;65T(&ES`$$@<V]R<WKA;6]S(&9E
M;'-O<F]LX7,@=.UP=7-A(';A;'1O>G1A=&AA=/,@;&5G>65N/P!-X7(@;.ET
M97II:P!)35-0(&)E:F5L96YT:V5ZZ7-I('!A<F%MZ71E<F5K`$WA<VEK+"!)
M35-0(&IE;'-Z\P!-X7-I:RP@24U34"!B96IE;&5N=&ME>NES:2!NZ78`3>%S
M:6L@96UA:6P@8^UM`$%L=&5R;F%T[78@<V%B;&]N;VL`06QT97)N873M=B!S
M>O9V96<Z`$%M97)I:V%I(%-Z86UO80!!(&UE9V%D;W1T(.ER=.EK(&YE;2!F
M;V=A9&AA=/,@96PN`$ES;65R971L96X@:&EB82!T]G)TZ6YT+@!!;F1O<G)A
M`$%N9V]L80!!;F=U:6QL80!!;F]N:6T@<')O>'EN(&ME<F5S>G3\;&D@:6YT
M97)N970@96SI<NES`%;A;&%S>@!!;G1A<FMT:7-Z`$%N=&EG=6$@Z7,@0F%R
M8G5D80!!;&MA;&UA>N%S`$%L:V%L;6%ZX7-O:R!L:7-TX6IA`$%Z(&%L:V%L
M;6%ZX7,@:^ES>BX`02!K]GKV<R!TX7)T97+\;&5T(&%L8W-O<&]R=&IA:7)A
M(&ES(.ER=NEN>65S`$KS=N%H86=YX7,`2_9R_&QB96S\;&D@;>ER970`X7!R
M:6QI<P!A<F%B("A7:6YD;W=S+3$R-38I`$$@=/9M]G+M=&5T="#A;&QO;>%N
M>2!MZ7)E=&4`02!T]FWV<NUT971T(.%L;&]MX6YY(&YE=F4`0FEZ=&]S(&)E
M;FYE+"!H;V=Y('3V<O9L;FD@:^UVX6YJ82`E<R!B96IE;&5N=&ME>NES:2!I
M9^EN>>ET/P!":7IT;W,L(&AO9WD@=/9R]FQN:2!A:V%R:F$@(B5S(BUT(&%L
M8W-O<&]R=&IA:79A;"!E9WG\='0_`$%R9V5N=.UN80#6<FWI;GEO<G-ZX6<`
M]G)MZ6YY("A!4DU30TE)+3@I`$W[=NES>F5T`$%R=6)A`%!O:&YP96D`07-C
M:6D@<F%J>F]K`,%Z<VEA+T-S96YD97,M\V-EX6YI('+I9VGS`$OI<FIE;B!A
M(')E;F1S>F5R(&UE9V5R]7/M=.ES="!A(&MA<F)A;G1A<G3A<VD@9F5L861A
M=&]K(&5L=NEG>NES92!E;/5T=#\`2&]Z>N%R96YD96SI<VD@;W-Z;&]P;VL`
M3F5M;.ET97KU(&-S;W!O<G1O="!K[7/I<F5L="!M96<@=/9R]FQN:2X`3F5M
M;.ET97KU(&IO9V]S=6QT<^%G;W0@:^USZ7)E;'0@;65G('3V<O9L;FDN`$YE
M;6SI=&5Z]2!J;V=O<W5L='/A9V]T(&OM<^ER96QT(&UE9R!M96=VX6QT;WIT
M871N:2X`3F5M;.ET97KU(&OV>O9S('3A<G1E<OQL971E="!K[7/I<F5L="!M
M96<@;65G=N%L=&]Z=&%T;FDN`%1U;&%J9&]N<^%G;VL`875G=7-Z='5S`$%U
M<WIT<N%L:6$`075S>G1R:6$`075T:%]C>7)S<6PZ(&$@<WK\:W/I9V5S(&EM
M87`@8O5V[73I<R!N96T@=&%LX6QH873S+@!!=71H7V-Y<G5S.B!A(&CA='3I
M<G-Z;VQGX6QT873A<R!N96T@<F5N9&5L:V5Z:6L@82!K[7;A;G0@:^EP97-S
MZ6=E:VME;"X`075T:%]C>7)U<SH@82!S>OQK<^EG97,@:6UA<"!B]7;M=.ES
M(&YE;2!T86SA;&AA=/,N`$%U=&A?9G1P.B!A('-Z_&MSZ6=E<R!F='`@8O5V
M[73I<R!N96T@=&%LX6QH873S+B!&;W)D[71S82!L92!A(%!(4"UT(&%Z("TM
M96YA8FQE+69T<"!O<&-I\W9A;"X`075T:%]I;6%P.B!A('-Z_&MSZ6=E<R!I
M;6%P(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RX`075T:%]K<F(U.B!A('-Z_&MS
MZ6=E<R!K<F(U(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RX`075T:%]L9&%P.B!N
M96T@:&]Z:&%T\VL@;.ET<F4@^FH@9F5L:&%S>F[A;/-K($%C=&EV92!$:7)E
M8W1O<GD@97-E=.EN`$%U=&A?;&1A<#H@9F5L:&%S>F[A;/-K(&YE;2!T]G+V
M;&AE=/5K($%C=&EV92!$:7)E8W1O<GD@97-E=.EN`$%U=&A?;&1A<#H@82!S
M>OQK<^EG97,@3$1!4"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N`$%U=&A?;&1A
M<#H@)7,@9F5L:&%S>F[A;/,@:&]Z>N%A9.%S82!N96T@<VEK97+\;'0N($$@
M<WIE<G9E<B!VX6QA<WIA.B``075T:%]L9&%P.B`E<R!F96QH87-Z;N%L\R!T
M]G)LZ7-E(&YE;2!S:6ME<OQL=`!!=71H7VQD87`Z("5S(&9E;&AA<WINX6SS
M(&%D871A:6YA:R!M96?Z:NUTX7-A(&YE;2!S:6ME<OQL=`!!=71H7VQD87`Z
M(&$@9F5L:&%S>F[A;/-K(&YE;2!M\V1O<^UT:&%T\VL@06-T:79E($1I<F5C
M=&]R>2!E<V5TZ6X`075T:%]M8V%L.B!A('-Z_&MSZ6=E<R!-0T%,(&+U=NUT
MZ7,@;F5M('1A;.%L:&%T\RX`075T:%]S;6)A=71H.B!A('-Z_&MSZ6=E<R!S
M;6)A=71H(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RX`3F5M('-I:V5R_&QT(&%Z
M($E-05`@<WIE<G9E<F5N('9A;/,@9F5L:&%S>F[A;/-A>F]N;W/M=.%S+@!!
M(&9E;&AA<WINX6SS87IO;F]S[73A<R!N96T@<VEK97+\;'0N`$$@9F5L:&%S
M>F[A;/-A>F]N;W/M=.%S(&YE;2!S:6ME<OQL="X@)7,`02!F96QH87-Z;N%L
M\R!A>F]N;W/M=.%SX70@82!2041)55,@<WIE<G9E<B!E;'5T87/M=&]T=&$N
M`$YE;2!S:6ME<OQL="!A>B!&5%`@<WIE<G9E<FAE>B!V86SS(&9E;&AA<WIN
MX6SS87IO;F]S[73A<RX`3F5M('-I:V5R_&QT(&%Z(%--0B!S>F5R=F5R96X@
M=F%L\R!F96QH87-Z;N%L\V%Z;VYO<^UTX7,N`$$@<F5N9&5L:V5ZZ7-R92#A
M;&SS(&UE>O5K.@!!>F5R8F%J9'ISX6X`02!G;VYO<WH@<F5N9'-Z97)G87ID
M82!M96YT<^EG96D`2.%T=.ER`$CA='3I<B!S>NUN`$YE;2!M96=F96QE;/4@
M:V5R8F5R;W,@:F5L<WKS+@!.96T@;65G9F5L96SU(&ME<F)E<F]S(&9E;&AA
M<WINX6SS;NEV+@!"86AA;>%K`$)A:')E:6X`8F%L=&D@*$E33RTX.#4Y+3$S
M*0!"86YG;&%D97,`0F%R8F%D;W,`02!G<F%F:6MU<R#A;&QO;>%N>6]K("(E
M<R(@86QK]FYY=G3A<F$@;F5M('1A;.%L:&%T\RX`86QA<'9O;F%L;VX`1F5H
MZ7)O<F]S>F]R<WKA9P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H
M=73A;@!3>OQL973I<VYA<`!!("(E<R(@8FQO:VL@82`B)7,B('!R;V=R86UM
M86P@;F5M('1A;.%L:&%T\RX`2^EP97)N>?5RZ7-Z(&)EX6QL[73A<P!+Z7!E
M<FYY]7+I<WH@=.UP=7,`9NEL:_9VZ7(`0F]L[79I80!+961V96YC('=E8F/M
M;65K`$ME<F5T`$ME<F5T=F%S=&%G<^%G.@!+97)E=&5K`$)O<WIN:6$M2&5R
M8V5G;W9I;F$`36EN9&ME='3U`$)O='-W86YA`&%L=6P`0F]U=F5T+7-Z:6=E
M=`!"<F%Z[6QI80!"<FET($EN9&EA:2WS8V7A;FD@5&5R_&QE=`!"<G5N96D@
M1&%R=7-S86QA;0!"=6QGX7)I80!&96QS;W)O;.%S`$)U<FMI;F$@1F%S;P!"
M=7)U;F1I`%=E8F]L9&%L(&MA<F)A;G1A<G3A<P!#4D,`02!T86[Z<^UT=N%N
M>79I<W-Z879O;N%S:2!L:7-TX6L@*$-23"D@8^UM96D`0V5L;&$@='5L86ID
M;VYSX6=O:P!!(&-A8VAE(&EN:6-I86QI>N%LX7-A(&YE;2!F96IE>O5D]G1T
M(&)E+@!.87!TX7(`3GEU9V]D=`!+86UB;V1Z<V$`2V%M97)U;@!.96T@<VEK
M97+\;'0@82!J96QS>O-T(.%TX6QL[71A;FDL(&9O<F1U;&IO;B!A(')E;F1S
M>F5R9V%Z9.%H;WHN`$$H>BD@(B5S(B#A;&QO;>%N>2!N96T@[7)H873S+@!!
M(&O\;'/U(&9E;&AA<WINX6SS:V%P8W-O;&%T+6ME>F5L]6L@;F5M(&%D;6EN
M:7-Z='+A;&AA=/-K+@!!(&OV=F5T:V5Z]2!)34%0('-Z97)V97(@;F5M(.ER
M:&5T]2!E;#H@)7,`02AZ*2`B)7,B(.%L;&]MX6YY(&YE;2!N>6ET:&%T\R!M
M96<N`$MA;F%D80!-Z6=S90!-Z6=S92!K_&QD]FL@:&EB86IE;&5N=.ES=`!!
M*'HI("(E<R(@X6QL;VWA;GD@;F5M('3V<O9L:&5T]2X`3F5M('1A;.%L:&%T
M\R!A>B!I9&5I9VQE;F5S(.%L;&]MX6YY;VMA="!T87)T86QM87KS(&%L:_9N
M>79TX7(N`$$@)W1A<F=E=$9I;&4G('!A<F%MZ71E<B!M96=A9.%S82!NZ6QK
M_&P@;F5M(&9O;'ET871H871J=6LN`$$H>BD@(B5S(B!A;&OV;GEV=.%R(&YE
M;2!T]G+V;&AE=/4N`$YE;2!T]G+V;&AE=/4L("5D(&%L8W-O<&]R=&IA('9A
M;BX`07H@^FH@<V]R8F%R96YD97KI<R!N96T@;&5H971SZ6=E<RP@82!M96=A
M9&]T="!A9&%T;VL@<WKA;6$@;F5M(&5G>65Z:6L@82!TX7)O;'1A:^EV86PN
M`$$@;65G861O='0@<WKA;7)A(&YE;2!K_&QD:&5T]2!E;"!A>B#\>F5N970N
M`%KV;&0M9F]K:2US>FEG971E:P#!8G)A<WKV=F5G`%-Z;VQGX6QT873S`$MA
M=&5G\W)IX6L@Z7,@:F5L]FSI<_QK`$MA:FWA;BUS>FEG971E:P!-;V)I;"!T
M96QE9F]N`$-E;&QA='5L86ID;VYSX6=O:P!#96QL82!B96QS]2!M87)G\SH`
M0V5L;&%T=6QA:F1O;G/A9V]K`$-E;&SA:R!K]GKV='1I('+I<SH`36]B:6P@
M=&5L969O;@!K96QT82`H25-/+3@X-3DM,30I`&OV>NEP`$OV>NEP+6%F<FEK
M86D@2_9Z=.%R<V%SX6<`:V5L970M975R\W!A:2`H25-/+3@X-3DM,BD`02!T
M86[Z<^UT=N%N>2!RZ7-Z;&5T96D`02!T86[Z<^UT=N%N>2!T=6QA:F1O;F]S
M80!486[Z<^UT=N%N>2!F96QH87-Z;N%LX7-I(&ERX6YY96QV96L`0W/A9`!6
MX6QT;WIT873A<P!!(&IE;'-Z\R#A=.%L;.UTX7-A`$%Z(-9N(.%L=&%L(&5L
M:_QL9/9T="!L979E;&5K96X@<WIE<F5P;/4@;NEV(.ES(&/M;2!M96=VX6QT
M;WIT873A<V$N`$$@:F5L96X@:V]N9FEG=7+A8VGS8F%N(&YE;2!L96AE='/I
M9V5S(&$@:F5L<WIA=F%K(&WS9&]S[73A<V$N($9O<F1U;&IO;B!A(')E;F1S
M>F5R9V%Z9.%H;WHN`$MA<F%K=&5R`$QI;E]K96QL96[U<GKI<RXN+@!#:&EL
M90!+[6YA`&OM;F%I+"!E9WES>F5R^W/M=&5T="`H1T(R,S$R*0!K[6YA:2P@
M:&%G>6]MX6YY;W,@*$)I9S4I`%;A;&%S<WIO;B!K:2!E9WD@86QK86QM87KA
M<W0Z`%;A;&%S<WIO;B!J96QS>O-T`%;A;&%S<WIO;B!E9WD@9F5L:&%S>F[A
M;/-N979E=`!6X6QA<W-Z82!K:2!A(&3A='5M;VL@;65G:F5L96[M=.ES:2!F
M;W)MX6KA=#H`5N%L87-S>F$@:VD@82!F96QS;W)O;.%S('3M<'5SX70@*'-Z
MX6UO>F]T="!L:7-TX6MNX6PI`$MA<N%C<V]N>2US>FEG971E:P!!*'HI("5S
M(&-L87-S(&1E9FEN[6-I\VIA(&YE;2!T86SA;&AA=/,N`$1E<OQL=`!4]G)L
M:2!A>B!-4T]F9FEC92!T86=E:V5T`$$@;&5KZ7)D97KI<R!T]G)LZ7-E`"5S
M(&9E;&AA<WINX6SS('3V<FSI<V4`02!F96QH87-Z;N%L\R!T]G)LZ7-E`$$@
M9F5L:&%S>F[A;/,@861A=&%I;F%K('3V<FSI<V4`17-TZ7)E(&1E<OQL="#I
M9P!!(&9O;'ET873A<VAO>B!K871T:6YT<V]N(&%Z(&5GZ7)R96P`0VQI8VMA
M=&5L;"!S>F]L9^%L=&%TX7,@2%144"UN(&ME<F5S>G3\;`!!>B!A8FQA:R!B
M97KA<N%S80!";W)U;'0@Z6<`4F5G9V5L(&9E;&CU<R!I9/4`1F5L:/5S(&ED
M]0!+\VMU<WHM<WII9V5T96L`5/QN=&5S<_QK(&5L(&%Z(&]L9&%L<_,@;65N
M_'0`UG-S>F5ZX7)T(&ME<F5T96L`2V]L=6UB:6$`4WKM;@!3>NUN=N%L87-Z
M=/,`4WKM;G;A;&%S>G3A<P!/<WIL;W!O:SH`07H@;W-Z;&]P;VL@8^UM96D`
M5FEC8V5K`%!A<F%N8W,`4&%R86YC<^ER=&5L;65Z]0!-96=J96=Y>NES`$[I
M=BP@96QN979E>NES`$-O;6]R92US>FEG971E:P!#Z6<`4WKA;>UT\V?I<&5K
M`$ED]6KA<N%S:2!H96QY>F5T`$ED]6KA<N%S:2!H96QY>F5T`$O\;/9N8G/I
M9V5K(&$@:V]N9FEG=7+A8VGS8F%N`$OI>FES>N%M[73S9^EP96MK96PL(&]K
M;W-T96QE9F]N;VMK86PL($]U=&QO;VMK86P@=F%L\R!A9&%T<WII;FMR;VYI
M>N%LX7,@:V]N9FEG=7+A8VGS:F$`02!K;VYF:6=U<N%C:?,@;>%R(&YE;2#I
M<G;I;GEE<RX`)7,@:V]N9FEG=7+A8VGS:F$`02!J96QS>O,@;65G97+U<^UT
MZ7-E`$MO;F?S`$MO;F?S:2!$96UO:W)A=&EK=7,@2_9Z=.%R<V%SX6<`4VEK
M97)T96QE;B!A(&MA<&-S;VQA="X`4VEK97)T96QE;B!A(&MA<&-S;VQA=#H@
M`$$@;GEI;';A;F]S(&MU;&-S;VL@<WIE<G9E<F4@96QU=&%S[71J82!A(&MA
M<&-S;VQA=&]T+@!!(&YY:6QVX6YO<R!K=6QC<V]K('-Z97)V97)E(&5L=71A
M<^UT:F$@82!K87!C<V]L871O="X@3VMA.B`E<R`H)7,I`%-I:V5R=&5L96X@
M87H@1E10('-Z97)V97)R96P@=F%L\R!K87!C<V]L870N`%!A<G1N97)E:P!!
M('!A<G1N97)E:V5T('-I:V5R97-E;B!H;WIZX6%D='5K(&$@8^UM:F5G>7KI
M:^EH97HN`$$@=/9M]G+M=&5T="#A;&QO;>%N>2!T[7!U<V$Z(``B)7,B('1A
M<G1A;&UA`$9O;'ET873A<P!#;V]K+7-Z:6=E=&5K`%/\=&D`3>%S;VQJ=6L@
MX70`02!MX7-O;.%S(&YE;2!S:6ME<OQL=#H@)7,`02!K:6IE;/9L="!RZ7-Z
M(&WA<V]LX7-A`%-ZX6ULX7KA<VD@87IO;F]S[73S`$-O<W1A(%)I8V$`16QE
M9N%N=&-S;VYT<&%R=`!.96T@<VEK97+\;'0@4$=0+79E;"!T:71K;W/M=&%N
M:2!A(&QE=F5L970Z(`!!(&QE=F5L970@;F5M('-I:V5R_&QT(%!'4"!A;.'M
M<N%S<V%L(&5L;.%T;FDZ(`!!(&QE=F5L970@;F5M('-I:V5R_&QT(&%Z(%,O
M34E-12!S>F%B=N%N>2!S>F5R:6YT('1I=&MO<^UT86YI+@!!(&QE=F5L970@
M;F5M('-I:V5R_&QT(%,O34E-12!A;.'M<N%S<V%L(&5L;.%T;FDN`$$@<&%R
M=&YE<B!A9&%T86ET(&YE;2!S:6ME<OQL="!E;'3A<F]L;FDN("5S`$%Z($Q$
M05`@<WIE<G9E<B!N96T@Z7)H973U(&5L+@!.96T@<VEK97+\;'0@96QL96[U
M<FEZ;FD@82!S>N%M;.%JX6X@<F5N9&5L:V5ZZ7-R92#A;&SS(/9S<WIE9V5T
M+B`E<P!.96T@<VEK97+\;'0@87H@3$1!4"!S>F5R=F5R:&5Z(&MA<&-S;VSS
M9&YI+@!.96T@<VEK97+\;'0@82AZ*2`B)7,B('-Z97)V97)R96P@1E10(&MA
M<&-S;VQA=&]T(&9E;'9E;FYI.B`E<P!.96T@<VEK97+\;'0@;.ET<F5H;WIN
M:2!A(&OV<FQE=NEL;&ES=.%T+B`E<P!!>B!A9&%T;VL@4$=0('1I=&MO<^UT
MX7-B\VP@=/9R=.EN]2!D96OS9&]LX7-A(&YE;2!S:6ME<OQL=#H@`$%Z(&%D
M871O:R!3+TU)344@=&ET:V]S[73A<V+S;"!T]G)TZ6[U(&1E:_-D;VSA<V$@
M;F5M('-I:V5R_&QT+@!!('!A<G1N97(@=/9R;.ES92!N96T@<VEK97+\;'0N
M("5S`$$@:_9R;&5VZ6QL:7-T82!T]G)LZ7-E(&YE;2!S:6ME<OQL="X@)7,`
M3F5M('-I:V5R_&QT('3V<O9L;FD@82AZ*2`B)7,B('-E='5P('5P9W)A9&4@
M<')O9W)A;6]T+@!.96T@<VEK97+\;'0@;65GX6QL87#M=&%N:2!A(&/M;7IE
M='0@96UA:6P@8^UMZ70N`$YE;2!S:6ME<OQL="!B96]L=F%S;FD@82!T96QJ
M97,@8^UM:F5G>7KI:V5T+@!.96T@<VEK97+\;'0@8F5O;'9A<VYI(&$@=&5L
M:F5S(&OV<FQE=NEL;&ES=.%T+@!.96T@<VEK97+\;'0@8F5O;'9A<VYI(&$@
M:_9R;&5VZ6QL:7-TX6L@=&5L:F5S(&9E;'-O<F]LX7/A="X`02AZ*2`B)7,B
M('-T<F%TZ6=I82!N96T@=&%LX6QH873S+@!!*'HI("(E<R(@86QK]FYY=G3A
M<B!N96T@:&]Z:&%T\R!LZ71R92X`02!N>6EL=N%N;W,@:W5L8W-O="!N96T@
M<VEK97+\;'0@;65G<WIE<F5Z;FD@82!K=6QC<W-Z97)V97)R]6PN`$YE;2!S
M:6ME<OQL="`B)7,B+70@[7+A<VD@8^EL;&%L(&UE9VYY:71N:2X`3F5M('-I
M:V5R_&QT("5S+70@;65G;GEI=&YI+@!!("5S(&MA<F)A;G1A<G3A<VD@;6]D
M=6P@;F5M(&YY:71H873S(&UE9P!!*'HI("(E<R(@86QK]FYY=G3A<B!N96T@
M;GEI=&AA=/,@;65G+@!!>B!,1$%0('-Z97)V97(@;F5M(.ER:&5T]2!E;"X`
M)7,@;F5M(&]L=F%S:&%T\RX`3F5M('-I:V5R_&QT(&$@:^UVX6YT(&9E;&AA
M<WINX6SS(&IE;'-Z87;A="#A=.%L;.UT86YI+B!!>B!M96=A9&]T="!A9&%T
M;VL@;F5M('9A9WD@;F5M('1E;&IE<V5N(&9E;&5L;F5K(&UE9RX@4'+S8N%L
M:F$@^FIR82P@=F%G>2!H82!T;W;A8F)I('-E9^UT<^EG<F4@=F%N('-Z_&MS
MZ6=E+"!F;W)D=6QJ;VX@82!R96YD<WIE<F=A>F3A:&]Z+@!.96T@<VEK97+\
M;'0@;65G:&%TX7)O>FYI(&%Z(&5LZ7+I<VD@:F]G;W-U;'1SX6=O:V%T("A!
M0TPI`$YE;2!S:6ME<OQL="!B96]L=F%S;FD@82!C[6UJ96=Y>NEK970N("5S
M`$YE;2!S:6ME<OQL="!B96]L=F%S;FD@82!K]G)L97;I;&QI<W3A="X@)7,`
M3F5M('-I:V5R_&QT(&)E;VQV87-N:2!A(&OV<FQE=NEL;&ES=.%K870N("5S
M`$YE;2!S:6ME<OQL="!M96=H873A<F]Z;FD@82!S>F5R=F5R(&OI<&5S<^EG
M96ET`$YE;2!S:6ME<OQL="!V:7-S>F'A;&SM=&%N:2!E>B!E<F5D971I(&MO
M;F9I9W5RX6-I\W0N`$$H>BD@(B5S(B!A;&OV;GEV=.%R(&YE;2!T]G+V;&AE
M=/4N`$YE;2!S:6ME<OQL="!E;&UE;G1E;FD@)7,@:V]N9FEG=7+A8VGS="X`
M3F5M('-I:V5R_&QT(&5L;65N=&5N:2!A(&)A8VMU<"!K;VYF:6=U<N%C:?-T
M+@!.96T@<VEK97+\;'0@96QM96YT96YI(&$@8F%C:W5P(&MO;F9I9W5RX6-I
M\W0Z("5S`$YE;2!S:6ME<OQL="!E;&UE;G1E;FD@82AZ*2`B)7,B('-E='5P
M('5P9W)A9&4@<')O9W)A;6]T+@!.96T@<VEK97+\;'0@96QM96YT96YI(&$H
M>BD@)7,@8F%C:W5P(&MO;F9I9W5RX6-I\W0N`$$H>BD@)7,@:V]N9FEG=7+A
M8VGS<R#A;&QO;>%N>70@;F5M('-I:V5R_&QT(&5L;65N=&5N:2X@5F%G>2!H
M87-Z;N%L:F$@82`E<R!O;&1A;&]N(&QE=O4@;&5H973U<^EG96ME="P@=F%G
M>2!MX7-O;&IA(.%T(&%Z(&%LX6)B:2!K\V1O="!I9&4Z("5S+@!!>B!,1$%0
M('-Z97)V97)E;B!N96T@<VEK97+\;'0@96QVZ6=E>FYI(&$@:V5R97/I<W0N
M`"(E<R(@;F5M('9O;'0@=/9R]FQH973U+@!!('!A<G1N97(@861A=&%I="!N
M96T@<VEK97+\;'0@;?-D;W/M=&%N:2X@)7,`3F5M('-I:V5R_&QT(&$@:_9R
M;&5VZ6QL:7-T82!M\V1O<^UTX7-A+B`E<P!.96T@<VEK97+\;'0@96QM96YT
M96YI("(E<R(@:V]N9FEG=7+A8VGS:N%T.B`E<P!!($UO>FEL;&$@;65N_'-O
M<B!N96T@=&%LX6QH873S+B!%;&QE;O5R:7IZ92P@:&]G>2!M96<@=F%N+64@
M;GEI='9A+@!.96T@<VEK97+\;'0@(B5S(B!F96QH87-Z;N%L\VYA:R!J;V=O
M<W5L='/A9V]T(&%D;FD@82AZ*2`B)7,B(&UA<'#A:&]Z.B`E<P!+;W)LX71O
M<R!S>O9V96<`3W)S>N%G`%3A=F]K=&%TX7,`3.ET<F5H;WKA<P!,:6YK(&SI
M=')E:&]ZX7-A`-IJ(&SI=')E:&]ZX7-A`$%L;6%P<.%K(&SI=')E:&]ZX7-A
M`$%Z(&]B:F5K='5M(&SI=')E:&]Z\VKA;F%K(&IO9V]S=6QT<^%G86D`2&ET
M96QKX7)T>6%S>N%M`$AO<G;A=&]R<WKA9P!+=6)A`$IE;&5N;&5G:2`T(&;A
M>FES`$$@:F5L96YL96=I(&9E;&AA<WINX6SS:V%P8W-O;&%T;VL`4&]N=&]S
M(&ED]0!!(&IE;&5N;&5G:2!54DP`2F5L96YL96=I(&9E;&AA<WINX6SS:P!*
M96QE;FQE9VD@:63U:N%RX7,`02!J96QE;FQE9VD@:63U:N%RX7-I(&AE;'EZ
M970Z`$IE;&5N;&5G:2!S=.UL=7,`36EL>65N('!A<F%N8W-O:R!F=7-S86YA
M:R!L92!A=71O;6%T:6MU<V%N(&$@)7-B92!T]G)TZ6[U(&)E:F5L96YT:V5Z
MZ7-K;W(N`$MI=N%GX7,`02!K:6IE;/9L="!RZ7-Z(&MI=N%GX7-A`$-I<')U
M<P!C:7)I;&P@*$M/23@M4BD`8VER:6QL("A7:6YD;W=S+3$R-3$I`&-I<FEL
M;"UU:W+A;B`H2T])."U5*0!#<V5H($OV>G3A<G-A<^%G`$1$`$133B`H861A
M=&9O<G+A<VQE[7+S("T@;.%S9#H@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU
M86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!N87!O
M;G1A`$1A=&%4<F5E(&+V;F?I<WKU`$%D871BX7II<V)A;B!V86SS(&ME<F5S
MZ7,`1.%T=6T`02!B9>ER:V5ZZ7,@;F%P:F$`1.%T=6T@:VEVX6QA<WITX7-A
M`&YA<'!A;`!/<WIL;W`@=/9R;.ES90!D96-E;6)E<@!S>N%M;VL`0F5K97ID
MZ7,@:VEJ:F5B8@!!;&%PZ7)T96QM97IE='0`07H@86QA<.ER=&5L;65ZZ7,@
M<WIE<FEN=&D@<WKM;@!!;&%PZ7)T96QM97KI<R!S>F5R:6YT:2!A>F]N;W/M
M=/,`06QA<.ER=&5L;65Z971T('-H96QL`$1E9FEN[6-I\VL`5/9R;.ES`$$@
M8V5L;&$@=/9R;.ES90!!(&-S;W!O<G0@=/9R;.ES90!!(&YA<&SSX6QL;VWA
M;GD@=/9R;.ES90!!(&IO9V]S=6QT<^%G('3V<FSI<V4`3&5V96QE:R!T]G)L
MZ7-E`$$@8V5L;&$@=/9R;.ES90!!>B!O<WIL;W`@=/9R;.ES90!4]G+V;&K\
M:R!K:2!A(&UE9VSI=O4@86QT97)N873M=B!S86)L;VYT`$$@;&5V96QE:R!T
M]G)LZ7-E`"(E<R(@:F]G;W-U;'1SX6=A:6YA:R!T]G)LZ7-E`%3V<O9L:OQK
M("(E<R(@:F]G;W-U;'1SX6=A:70@Z7,@96YN96L@97-E=&QE9V5S(&%L8W-O
M<&]R=&IA:70_`$$@<V]R('3V<FSI<V4`02!K:7;A;&%S>G1O='0@87IO;F]S
M[73S('3V<FSI<V4`07H@86QM87!PX6L@=/9R;.ES90!!(&IE;&5N;&5G:2!O
M<WIL;W`@=/9R;.ES90!!(&IE;&5N;&5G:2!S;W(@=/9R;.ES90!4]G+V;'3\
M:R!A*'HI("(E<R(@<V5T=7`@=7!G<F%D92!P<F]G<F%M;W0N`$$@:^EZ8F5S
M[73I<R!I9&5J90!$X6YI80!!9&IO;B!L9>URX7-T(&$@<')O8FSI;>%R\VP`
M3&7M<N%S`%+I<WIL971E:R`H82!(;W)D92!L;V=FX6IL8F%N(&ES(&UE9W1A
M;.%L:&%T\RDZ`$$@<NES>FQE=&5K(&$@<F5N9'-Z97)G87ID82!S>N%MX7)A
M(&OI<WK\;/4@;F%P;/-FX6IL8F$@:V5R_&QT96LN`$9E:FQE<WITZ7,`2&%R
M;6%T<&]N=`!(87)M871P;VYT(&IE;&5N;&5G.B``2&%R;6%T<&]N=#H@`&)A
M;'+S;"!J;V)B<F$@[7+A<P!J;V)B<O-L(&)A;')A(.URX7,`0^UM=.%R`$%Z
M(&ED]7!O;G1O:V%T(#(T(/-RX7,@9F]R;>%T=6UB86X@:F5L96[M='/\:R!M
M96<_`$UE9VIE;&5N[73I<VD@8F7A;&SM=.%S;VL`02!RZ7-Z;&5T97,@96SU
M<F5J96QZZ7,@;65G:F5L96[M=.ES90!%;/5R96IE;'KI<R!M96=J96QE;NUT
MZ7-E("AR97#\;/5TZ7)I*0!-96=J96QE;NUTZ7-I(&9O<FWA='5M`,ER=&5S
M[73I<R!A(&OI>F)E<^UT971T(&QE=NEL('-O<G/A<O-L`$1Z<VEB=71I`$YE
M('3V<O9L:OQK`$$@;6%I;G1E;F%N8V4N<&AP(&YE;2#I<FAE=/4@96P@:_9Z
M=F5T;&5N_&PN`$%Z(&5L<_4@<V]R(&$@;65Z]6L@;F5V96ET('1A<G1A;&UA
M>GIA/R!(82!I9V5N+"!J96SV;&IE(&MI(&5Z=#H`1&]M:6YI:V$`1&]M:6YI
M:V%I($OV>G3A<G-A<^%G`$YI;F-S(&WI9R!L;V=I;B!N979E/R!)9^EN>65L
M:F5N(&5G>65T+@!,973V;'3I<P!4]FQT<_QK(&QE("5S+70`5/9L='/\:R!L
M92!02%`@<')O9W)A;2!F;W)MX6KA8F%N(&%Z(&5L:^ES>OQL="!K;VYF:6=U
M<N%C:?-T+@!,96?V<F3\;/4@;&ES=&$`2^%B[73S<WIE<F5K`&5M86EL`$5M
M86EL8O5L(%--4RUK_&QD]2!M96=H86IT\RP@:&$@82!T96QE9F]N=.%R<V%S
MX6<@8FEZ=&]S[71J82!E>G0@82!S>F]L9^%L=&%TX7-T+@!(24)!`$5C=6%D
M;W(`3?-D;W/M=.%S`$)L;VMK(&WS9&]S[73A<P!#<V]P;W)T(&WS9&]S[73A
M<P!*;V=O<W5L='/A9R!M\V1O<^UTX7,`2F]G;W-U;'1SX6=O:R!M\V1O<^UT
MX7-A`"5S(&IO9V]S=6QT<^%G86EN86L@;?-D;W/M=.%S80!-96QY:6L@;W!C
M:?-K870@=N%L=&]Z=&%S<W5K.@`B)7,B(&IO9V]S=6QT<^%G86EN86L@;?-D
M;W/M=.%S80`E<R!J;V=O<W5L='/A9V%I;F%K(&WS9&]S[73A<V$`3VMT873A
M<P!%9WEI<'1O;0!386QV861O<@!%;&5M+BXN`&%Z("=M)R!B973[('-ZZ6QE
M<W/I9V4`16UA:6P`16UA:6P@8^UM`$%Z(&5M86EL(&/M;65K;F5K(&5G>65Z
M;FG\:R!K96QL+@!%;6%I;"!V:7-S>F%I9V%Z;VSA<W-A;`!%;6%I;"U335,@
MX71JX7+S`$AA;F=U;&%T:6MO;F]K`-QR97,@_'IE;F5T+@!.:6YC<R!I;'EE
M;BX`5/9R]FQJ_&L@:VD@82!K97)E<^ES96ME=`!%;F=E9&K\:R!M96<L(&AO
M9WD@:^EP96ME="!I;&QE<W-Z_&YK(&$@<WKV=F5G8F4@82!&;W3S9V%LZ7)I
MX6MB\VP_`$QE9WEE;B!J;V)B(&5GZ7)G;VUB8F%L(&5LZ7)H973U+"!K;VYT
M97AT=7-F_&=G]2!M96[\/P!!>B!U=&]L<_,@Z78`P71VX6QTX7,@:_QL]FX@
M86)L86MR80!!9&IA(&UE9R!A>G0@82!B:7IT;VYSX6=I(&OI<F3I<W0L(&%M
M96QY<F4@;6%J9"!VX6QA<WIO;&YI82!K96QL(&IE;'-Z87;A;F%K(.%TX6QL
M[73A<^%H;WHL('!L+B`G:&]G>2!H[79JX6L@82!K=71YX6KA=#\G.@!!9&IA
M(&UE9R!A(&OI<"!54DPM:NET(&ET=`#-<FIA(&)E(&%Z(&%LX6)B:2!B973[
M:V5T.@!%9WEE;FSM=/5I+4=U:6YE80!%<FET<F5A`$AI8F$`2&EB82!T]G)T
MZ6YT(&$@8FQO:VL@;.ET<F5H;WKA<V%K;W(Z("5S`$AI8F$@=/9R=.EN="!A
M>B!A9&%T<WII;FMR;VYI>N%C:?-S(&IE;"!T]G)LZ7-E:V]R.B`E<P!!>B!A
M9&%T<WII;FMR;VYI>N%C:?-S(&YA<&SSX6QL;VWA;GD@=/9R;.ES92!N96T@
M<VEK97+\;'0Z("5S`$AI8F$@=/9R=.EN="!A>B!A9&%T;&5KZ7+I<V)E;CH@
M)7,`2&EB82!T]G)TZ6YT(&$@:F5L<WKS(&UE9W;A;'1O>G1A=.%S86MO<CH@
M)7,`2&EB82!A>B!E;6%I;"#\>F5N971B96XN`$$H>BD@(B5S(B#A;&QO;>%N
M>7)A(&YE;2!S:6ME<OQL="#M<FYI+@#)<WIT;W)S>N%G`$5T:?-P:6$`3F5M
M>F5T:7/I9V5K`$5U<O-P80`Q-2!P97)C96YKZ6YT`#(@<&5R8V5N:^EN=``S
M,"!MX7-O9'!E<F-E;FOI;G0`-2!P97)C96YKZ6YT`&UI;F1E;B!B96IE;&5N
M=&ME>NES:V]R`&;I;/-RX6YKZ6YT`'!E<F-E;FOI;G0`4.EL9&$@Z7)TZ6ME
M:SH`5NEG<F5H86ITX7,`3GEI<W-U:R!S>NET`$IE;&5N[71S_&L@;65G(&%Z
M(&]L9&%L<_,@;65N_'0`271T("<I)R!K96QL96YE(&OV=F5T:V5Z>F5N`$ET
M="!C<W5P87-Z('-Z\VYA:R!V86=Y(&EDZ7KU:F5L8F5N(&QE=O4@:V5R97/I
M<VD@:VEF96IE>NES;F5K(&ME;&QE;F4@;&5N;FEE`$%Z(.ER=NEN>65S<^EG
M(&QE:N%R871A`$MI=&5V]0!3>NUN`$$@:V]N9FEG=7+A8VGS($944"UN(.%T
M('9A;/,@9F5L=/9L=.ES90!!('-Z96WI;'EE<R!B9>%L;.UTX7-O:V%T(&YE
M;2!S:6ME<OQL="!B96]L=F%S;FDN`$%Z($Q$05`@<WIE<G9E<B!N96T@Z7)H
M973U(&5L+@!!>B!334(@<WIE<G9E<B!N96T@Z7)H973U(&5L+@!.96T@<VEK
M97+\;'0@82AZ*2`B)7,B+6+U;"!T]G)TZ6[U(&WA<V]LX7,N`$YE;2!S:6ME
M<OQL="!A*'HI("(E<R(M8F4@=/9R=.EN]2!MX7-O;.%S+@!.96T@<VEK97+\
M;'0@^FH@4T%33"!K87!C<V]L871O="!LZ71R96AO>FYI+@!.96T@<VEK97+\
M;'0@82AZ*2`B)7,B+6)E('3V<G3I;O4@X71H96QY97KI<RX`P6QL;VWA;GEH
M;WIZX6;I<NES:2!H:6)A.B`E<P!4:7-Z=&$`1F%L:VQA;F0M<WII9V5T96L@
M*$UA;'9I;F%S*0!&87)O92US>FEG971E:P!(96QY<F5H;WIH871A=&QA;B!H
M:6)A.@!&87@`1F%X`&9E8G)UX7(`2/5MZ7)SZ6ML973I<GIE=`!(]6WI<G/I
M:VQE=.ER>F5T.B``16=Y+65G>2!ZX7!O<@!3>O-R=N%N>6]S86X@:/-ZX7!O
M<F]K`$UE>O4@;>%T<FEX`$9I9VQE="!#05!40TA!("AB973[:VER86OS(&AU
M;>%N=&5S>G0I`$9I9'IS:0!&X6IL`$$@9N%J;&]K('-ZX6UA.B`E<P!!(&;A
M:FQO:R!S>N%M83H@)7,`1N%J;"!M96YE9'IS97(`1N%J;&[I=@!&X6IL(&MI
M:F5L]FSI<P!&X6IL(&9E;'3V;'3I<V4`1N%J;&]K(&9E;'3V;'3I<V4@;F5M
M(&QE:&5T<^EG97,N`%-Z^W+U:P!&:6YN;W)S>N%G`&5L<_4@9NEL`&5L<_4@
M;F5G>65D`%;A;'1O>F%T;&%N(&WI<F5T87+A;GD`5/QK<O9ZZ7,@*&;V;"]L
M92D`2_9D`"5S(&UA<'!A(&YE;2!LZ71E>FEK`$)E=/MS>NUN`,ET96QE:P!/
M;'EA;B!B]FYGZ7-Z]6L@<WKA;>%R82P@86UI:R!N96T@:F5L96[M=&EK(&UE
M9R!A(&OI<&5K970`16SU<F5J96QZZ7,@*')E</QL]73I<FDI`$%Z(&5L]7)E
M:F5L>NES(&ED]71A<G1A;6$@;F%P;VMB86X@*&%Z(&5L]7)E:F5L>NES(&YA
M<'!A;&D@Z7,@Z6IS>F%K86D@861A=&]K870@=&%R=&%L;6%Z+"!E>NER="!A
M(&YA9WD@<WKA;6]K('-ZZ6QE<R!B;&]K:V]T(&5R961MZ6YY97IN96LI`$5L
M9F5L96IT971T92!A(&IE;'-Z87;A=#\`VW)L87!K97IE;.ES`$EDZ7IE=`!)
M9.EZ970@9F%J=.%J80!)9.EZ971E:P!)9.EZ971E:R`R`$;S<G5M;VL`5&]V
MX6)B[73A<V]K`%#I`$9R86UE+65K`$9R86YC:6%O<G-ZX6<`1G)A;F-I86]R
M<WKA9P!&<F%N8VEA($=U>6%N80!&<F%N8VEA(%!O;&ENZ7II80!&<F%N8VEA
M($3I;&D@5&5R_&QE=&5K`$9E;&%D\P!)<N%N>3H@`%+I<WIL971E<R!L9>UR
MX7,`=&5L:6AO;&0`5&5L:F5S(&[I=@!'86)O;@!-96QY:6L@9V%LZ7)IX6+S
M;"!V96=Y_&L@82!KZ7!E=`!+Z7!G86SI<FEA.@!'86UB:6$`2&]Z>G5K(&SI
M=')E(&$H>BD@)7,@:V]N9FEG=7+A8VGS:N%T`$$@:V5L971K97IE='0@:_-D
M`$=R^GII80!.Z6UE=&]R<WKA9P!':.%N80!':6)R86QTX7(`2V5R97-Z=&[I
M=@!';&]BX6QI<R!B9>%L;.UTX7-O:P!-96AE=`!']F1E;`!';V]G;&4@=.ER
M:^EP`$=O;V=L92!K97)E<^ES`$9E:V5T92]F96CI<@!']G+V9V]R<WKA9P!G
M]G+V9R`H25-/+3@X-3DM-RD`1W+V;FQA;F0`1W)E;F%D80!#<V]P;W)T(&%D
M;6EN:7-Z='+A8VGS`$$@8W-O<&]R=&[I=B!M87)A9&AA="#\<F5S96X`1W)O
M=7!?;&1A<#H@)7,@8W-O<&]R="!H;WIZX6%DX7-A(&YE;2!S:6ME<OQL="X@
M02!S>F5R=F5R(';A;&%S>F$Z(`!'<F]U<%]L9&%P.B`E<R!C<V]P;W)T('3V
M<FSI<V4@;F5M('-I:V5R_&QT`$=R;W5P7VQD87`Z("5S(&-S;W!O<G0@861A
M=&%I;F%K(&UE9_IJ[73A<V$@;F5M('-I:V5R_&QT`$-S;W!O<G1O:P!'=6%D
M96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`%9E;F3I9R!J;V=O<W5L
M='/A9V]K`%9E;F3I9VOV;GEV`$=U:6YE80!":7-S874M1W5I;F5A`$=U>6%N
M80!(5$U,07)E82!G>>%V87/A9V+S;"!N96T@:&%J;&%N9/,@82!S;W(@=71O
M;'/S(&-E;&SA:N%T('3V<O9L;FDN`$A434Q!<F5A(&=YX79A<^%G8O-L(&YE
M;2!H86IL86YD\R!A('3A8FSA>F%T('5T;VQS\R!O<WIL;W#A="!T]G+V;&YI
M+@!(5$U,07)E82!G>>%V87/A9V+S;"!N96T@:&%J;&%N9/,@82!TX6)LX7IA
M="!U=&]L<_,@<V]RX70@=/9R]FQN:2X`02!(5%10(&9E;&AA<WINX6SS87IO
M;F]S[73A<R!N96T@=&%LX6QH873S+@!(86ET:0!(87-H(&%L9V]R:71M=7,`
M2_9D`$9E:FSI8P!&96ILZ6,`2&5A<F0M(.ES($UC1&]N86QD+7-Z:6=E=&5K
M`$5R]7,@>FEV871A<@!HZ6)E<B`H25-/+3@X-3DM."U)*0!-86=A<W/A9P!3
M96?M='/I9P!396?M='/I9R!A('-Z97)K97-Z=/4@:&%S>F[A;&%TX6AO>@!3
M96?M='/I9P!&Z6QT96ME`$5Z(&$@9N%J;"!E;&5J93H`;F%G>0!+97ID]6QA
M<`!6871I:^%N=N%R;W,`2V5Z9/5L87``3W1T:&]N:2!C[6T`4WIE;>EL>65S
M(&%L:_9N>79TX7(`3W1T:&]N:2!T96QE9F]N`$AO;F1U<F%S`$AO;F=K;VYG
M`$AO<F1E`$AO<F1E+TMO;&%B.B!H:6+A<R`E<R!834P@861A="!V86X@82AZ
M*2`E<R#\>F5N971B96X`2&]R9&4O2V]L86(Z(&YI;F-S(&$H>BD@)7,@;V)J
M96MT=6UN86L@;65G9F5L96SU(/QZ96YE=`!(;W)D92]+;VQA8CH@;FEN8W,@
M)7,@=.UP=7/Z(&]B:F5K='5M(&$H>BD@)7,@_'IE;F5T8F5N`$AO<F1E+TMO
M;&%B.B!3:6ME<F5S96X@=/9R]FQT_&L@97IT.B`E<R`B)7,B`$AO<F1E+TMO
M;&%B.B!A>B!I;G1E9W+A;/,@<')O9W)A;6AO>B!S>OQK<^EG97,@82`G9&]M
M>&UL)R!02%`@8O5V[73I<P!(;W)D92]+;VQA8CH@;F5M('-I:V5R_&QT(/IJ
M(%A-3"!FX70@;.ET<F5H;WIN:2!A*'HI("5S(&]B:F5K='5M:&]Z`$AO<F1E
M+TMO;&%B.B!.96T@<VEK97+\;'0@=/9R]FQN:2`E<RUT("(E<R(Z("5S`$AO
M<F1E+TMO;&%B.B!N96T@<VEK97+\;'0@;65G:&%TX7)O>FYI(&$@34E-12!)
M1"UJX70@82!K]G9E=&ME>O4@=.UP=7/Z(&UE;&SI:VQE=&YE:SH@)7,`2&]R
M9&4O2V]L86(Z($YE;2!S:6ME<OQL="!S>FEN:W)O;FEZX6QN:2`E<R`B)7,B
M.B`E<P!(;W)D92]+;VQA8CH@3F5M('-I:V5R_&QT(&$@:_9V971K97KU(&OV
M>O9S('3A<G1E<OQL970@<WII;FMR;VYI>N%LX7-A.B`E<P!(;W)D92]+;VQA
M8CH@:7-M97)E=&QE;B!K]GKV<R!TX7)T97+\;&5T("(E<R(`5NUZ<WII;G1E
M<R!V;VYA;`!6[7IS>FEN=&5S(&UA<F?S`%;M>G-Z:6YT97,Z`$AO9WD@:G5T
M;W1T(&ED93\@*$OI<FK\:R#M<FIA(&UE9R$I`$CA;GD@;W-Z;&]P;W0@:^UV
MX6X@]G-S>F5O;'9A<WIT86YI/P!(X6YY(&UE>O4@*&]S>FQO<"D@=F%N/P!(
MX6YY('-O<G0@:^UVX6X@]G-S>F5O;'9A<WIT86YI/P!0X7)A=&%R=&%L;VT`
M4.%R871A<G1A;&]M.B``2'5M;W)I<W3A:P!-86=Y87)O<G-ZX6<`07H@24U!
M4"!L97;I;&SA9&$@;.ET<F5H;WKA<V$@;F5M('-I:V5R_&QT.B`E<P!!>B!)
M34%0(&QE=NEL;.%D82!T]G)LZ7-E(&YE;2!S:6ME<OQL=#H@)7,`07H@24U!
M4"!L97;I;&SA9.%H;WH@=&%R=&]Z\R!K=O-T82!LZ71R96AO>N%S82!N96T@
M<VEK97+\;'0Z("5S`$E0(&/M;0!!>B!)4"!C[6T@;F5M(&AA=.%R;WIH873S
M(&UE9RX`07H@25`@8^UM(&YI;F-S(&$@;65G96YG961E='0@0TE$4B!T87)T
M;VWA;GEB86XN`%1I;'1O='0O;65G=N%L=&]Z;W1T($E0(&/M;2X`4V]R(&)E
M:6QL97-Z=.ES92!E9O9LZ0!)>FQA;F0`8W-A:R!I:V]N;VL`)7,@:6MO;FIA
M:0!I:V]N;VL@Z7,@<WKV=F5G`$%Z(&%Z;VYO<^UT\VAO>B!VX6QA<WIT;W1T
M(&5L;F5V97KI<SH`2&$@82!M96=J96QE;NUTZ7,@;F5M(&UE9V9E;&5L]2P@
M)7,@96=Y(/IJ(&%B;&%K8F%N('9A;/,@;65G;GEI=.%S:&]Z+@!(82#6;B!)
M;G1E<FYE="!%>'!L;W)E<G0@:&%S>F[A;"P@Z7,@;F5M(&IE;&5N;F5K(&UE
M9R!A>B!I:V]N;VLL(&%K:V]R(';A;&%S<WIA(&5Z="!A>B!O<&-I\W0L(&UE
M;&QY96P@:VEK87!C<V]L:F$@82!03D<@:^EP96L@=')A;G-Z<&%R96YC:>%J
MX70N`$AA(&SA=&IA(&5Z="!A('-Z]G9E9V5T+"!D92!A(&OI<&5T(&YE;2P@
M86MK;W(@8O9N9^ES>O5P<F]G<F%M:F$@;F5M(&OI<&5S(&UE9VIE;&5N[71E
M;FD@82!S>F5R=F5R<F4@:_QL9&5N9/4@:^EP970N`$5L]7IE=&5S(&[I>F5T
M.@!!(&OI<"!54DPM:F4`02!KZ7`@55),+6IE.@!-96QY:6L@9V%LZ7)IX6+S
M;"!V86X@82!KZ7``2^EP(&5B8O5L(&$@9V%LZ7)IX6+S;#H`2^EP(&9E;'3V
M;'3I<V4`2^EP96L`26UP;W)TX6SA<RP@)60N(&SI<.ES`$%Z(&EM<&]R=.%L
M="!M97KU.B`E<P!!>B!I;7!O<G3A;'0@;65Z]6LZ`%-O<B!B96EL;&5S>G3I
M<V4@97IA;.$`2&EBX7,@<&%R86YC<W!A<F%MZ71E<BX`3F5M(&UE9V9E;&5L
M]2!A(&)E:F5L96YT:V5ZZ7-I(&[I=B#I<R]V86=Y(&$@:F5L<WKS+@!.96T@
M;65G9F5L96SU(&$@9F5L:&%S>F[A;/-I(&[I=B!V86=Y(&%Z(&%L=&5R;F%T
M[78@8^UM+B!0<O-BX6QJ82#Z:G)A('9A9WD@9F]R9'5L:F]N(&$@<F5N9'-Z
M97)G87IDX6AO>BP@:&$@=&]VX6)B:2!S96?M='/I9W)E('9A;B!S>OQK<^EG
M92X`0F5K97IDZ7,@8F5L:F5B8@!);F1I80!%9WEE<R!F96QH87-Z;N%L\VL`
M26YD;V[I>FEA`$EN9F]R;>%C:?,`26YF;W)MX6-I\P!!>B!I;F9O<FWA8VGS
M(&WA<B!N96T@X6QL(')E;F1E;&ME>NES<F4N`$]S>FQO<"!B97-Z^G+A<V$@
M97IU=.%N`$OI<"!B96EL;&5S>G3I<V4`5.%B;.%Z870@8F5I;&QE<WITZ7-E
M`$QI;FL@;.ET<F5H;WKA<V$`3W-Z;&]P(&)E<WKZ<N%S82!E>F5LZ0!/<WIL
M;W`@8F5S>OIRX7-A(&5Z=73A;@!/<WIL;W`@8F5S>OIRX7-A(&5Z96SI`%-O
M<B!B97-Z^G+A<V$@97IA;.$`4V]R(&)E<WKZ<N%S82!E9O9LZ0!"96ME>F3I
M<R!B96EL;&5S>G3I<V4@97IU=.%N`$)E:V5Z9.ES(&)E:6QL97-Z=.ES92!E
M>F5LZ0!(;WIZ=6YK(&SI=')E(&%L=&5R;F%T[78@<V%B;&]N=`!!9&IO;B!M
M96<@96=Y(&5M86EL(&/M;65T+"!M96QY<F4@96QK_&QD:&5T]2!A>B#6;B#Z
M:B!J96QS>F%V83H`0V5L;&$@8F5I;&QE<WITZ7-E(&5Z=73A;@!#96QL82!B
M96EL;&5S>G3I<V4@97IE;.D`3W-Z;&]P(&)E<WKZ<N%S82!E>G5TX6X`3W-Z
M;&]P(&)E<WKZ<N%S82!E>F5LZ0!,979E;&5K(&)E;>%S;VSA<V$`0F5K97ID
MZ7,@8F5I;&QE<WITZ7-E(&5Z=73A;@!"96ME>F3I<R!B96EL;&5S>G3I<V4@
M97IE;.D`4V]R(&)E<WKZ<N%S82!E>F%LX0!3;W(@8F5S>OIRX7-A(&5F]FSI
M`$%D:F$@;65G(&$@:^UVX6YT(';A;&%S>G0@82!B:7IT;VYSX6=I(&OI<F3I
M<W)E.@!+Z7`@8F5I;&QE<WITZ7-E+VWS9&]S[73A<V$`3&EN:R!B96EL;&5S
M>G3I<V4O;?-D;W/M=.%S80!!('-ZX6ULX6KA;B!N:6YC<R!E;.EG(&9E9&5Z
M970@_'IE;F5T970@:_QL9&5N:2!A(&OV<FQE=NEL;&ES=.%R82X`02!S>N%M
M;.%JX6X@;FEN8W,@96SI9R!F961E>F5T+@!%9^ES>@!%9^ES>B!S>N%M;VL@
M;&ES=.%J80!(:6+A<R]E;&9O9V%D:&%T871L86X@541(("A5<V5R($1A=&$@
M2&5A9&5R*2X`2&EBX7,O96QF;V=A9&AA=&%T;&%N(%I)4"!T]FWV<NUTZ7,`
M2&EBX7,O96QF;V=A9&AA=&%T;&%N(&%L:V%L;6%ZX7,N`$AI8N%S+V5L9F]G
M861H871A=&QA;B!B871C:"!A>F]N;W/M=/,N`$$@:_QL9/9T="!A9&%T(&AI
M8N%S+V5L9F]G861H871A=&QA;BX`2&EBX7,O96QF;V=A9&AA=&%T;&%N(&/M
M;7KI<RX`2&EBX7,O96QF;V=A9&AA=&%T;&%N(&;A:FP@9F]R;>%T=6T`2&EB
MX7,O96QF;V=A9&AA=&%T;&%N(&QI8V5N<WIK=6QC<RX`2&EBX7,O96QF;V=A
M9&AA=&%T;&%N(';A<F]S+@!(:6+A<R]E;&9O9V%D:&%T871L86X@_'IE;F5T
M=.UP=7,N`$AI8N%S+V5L9F]G861H871A=&QA;B!V86=Y(&AIX6YY>O,@<')O
M9W)A;6]ZX7-I9F5L_&QE="UA>F]N;W/M=/,N`$AI8N%S+V5L9F]G861H871A
M=&QA;B!P87)A;>ET97)E:RX`2&EBX7,@87H@;V)J96MT=6T@96SI<NES:2!J
M;V=O<W5L='/A9V$N`$AI8N%S+V5L9F]G861H871A=&QA;B!P87)T;F5R87IO
M;F]S[73S+@!(:6+A<R]E;&9O9V%D:&%T871L86X@=&5R;>EK:_-D+@!(:6+A
M<R]E;&9O9V%D:&%T871L86X@<')O=&]K;VQL+@!(:6+A<R]E;&9O9V%D:&%T
M871L86X@8^UM>F5T=#H@(B5S(@!(:6+A<R]E;&9O9V%D:&%T871L86X@;65G
M;W-Z=&]T="!O8FIE:W1U;0!(:6+A<R]E;&9O9V%D:&%T871L86X@9F5L863S
M:2!C[6TN`$AI8N%S+V5L9F]G861H871A=&QA;B!U;FEC;V1E(&%D870N`$YY
M:6QVX6YT87)TX7,`02!K:6IE;/9LZ7,@:6YV97)TX6SA<V$`27+A;FD@27-Z
M;.%M($OV>G3A<G-A<^%G`$ER86L`S7)O<G-ZX6<`36%N+7-Z:6=E=`!3>O-R
M=N%N>6]S('II=F%T87)O:P!)>G)A96P`02!T86[Z<^UT=N%N>2!K:6%D\VIA
M`&3U;'0`3VQA<WIO<G-ZX6<`2F%M86EC80!J86YUX7(`2F%PX6X`:F%PX6X@
M*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9.%N:6$`:OIL:75S`&KZ;FEU<P!3
M;W)K:7KA<N%S`&OV>NEP<F4@<F5N9&5ZZ7,`<V]R:VEZX7+A<R!M:6YD:^ET
M(&]L9&%L<F$`<V]R:VEZX7+A<R!B86QR80!S;W)K:7KA<N%S(&IO8F)R80!+
M87IA:'-Z=.%N`%1A<G1S=6L@;65G(&%Z(&5R961E=&ET/P!+96YY80!!(&ME
M<F)E<F]S('-Z97)V97(@96QU=&%S[71O='1A(&$@9F5L:&%S>F[A;/-A>F]N
M;W/M=.%S="X`2V5Z9/4@:V5R;F5L9F5J;&5S>G3U:P!+=6QC<R!LZ71R96AO
M>N%S80!!(&MU;&-S(&QE;GEO;6%T80!+=6QC<VAO<W-Z^G/A9P!+=6QC<R!T
M[7!U<P!!(&MU;&-S(&AA<WINX6QA=&$`02!K=6QC<R!MX7(@;.ET97II:R!A
M(&YY:6QVX6YO<R!K=6QC<W-Z97)V97)E;BX`1WEE<F5K96L`2VER:6)A=&D`
M2V]R96%I($[I<&D@1&5M;VMR871I:W5S($OV>G3A<G-A<^%G`$MO<F5A:2!+
M]GITX7)S87/A9P!K;W)E86D@*$550RU+4BD`2W5V86ET`$MI<F=I>FES>G3A
M;@!?5&5R=F5ZZ7,`3GEE;'8`3&%O<WII($[I<&D@1&5M;VMR871I:W5S($OV
M>G3A<G-A<^%G`'5T;VQS\R!FZ6P`07H@=71O;'/S(&IE;'-Z\W;A;'3A<P!U
M=&]L<_,@;F5G>65D`%5T;VQS\R!VX6QT;WIT873A<SH`571O;'/S(&)E:F5L
M96YT:V5ZZ7,Z("5S`%5T;VQS\R!B96IE;&5N=&ME>NES.B`E<RP@)7,@8^UM
M<O5L`%5T;VQS\R!B96IE;&5N=&ME>NES.B!MZ6<@<V]H82!N96T@=F]L=`!,
M971T;W)S>N%G`$IO9P!%;&AE;'EE>NES`$AA9WEJ82#\<F5S96XL(&AA(&YE
M;2!A:V%R(&ME<F5T970`3&EB86YO;@!B86P`0F%L(&]L9&%L:2!F96ILZ6,`
M0F%L(&]L9&%L:2#I<G3I:V5K`$QE<V]T:&\`4WII;G0`3&EBZ7)I80!,[6)I
M86D@07)A8B!3>F]C:6%L:7-T82!.86=Y($[I<&D@2_9Z]G-SZ6<`3&EE8VAT
M96YS=&5I;@!'>65N9V4@<WII=.%L\R!E<_4`1WEE;F=E(&5S]0!$Z6QE;/5T
M="!G>65N9V4@97/U`$3I;'5TX6XO97-T92!G>65N9V4@97/U`$=Y96YG92!Z
MX7!O<@!'>65N9V4@>FEV871A<@!'>65N9V4@:&%V87KA<P!'>65N9V4@:/-Z
MX7!O<@!,:6YK`$$@;&EN:R!I9&4@;75T870Z`$UE9VIE;&5N[73I<VMO<B!M
M=71A<W-O;B!E9WD@;&EN:R!A(&QE=NEL8^UM<O5L(&$@;&5VZ6SM<O,@86)L
M86MH;WH`3&EN:V5K`$QI;G5X`$QI<W3A>N%S("T@82!F96QH87-Z;N%L\R!L
MX71J82!A(&UA<'#A=`!!>B!A9&%T8N%Z:7-O:R!L:7-TX6IA`$%Z;VMN86L@
M82!TZ6WA:VYA:R!A(&QI<W3A:F$@86UI<O5L('-E9^UT<^EG(&MA<&AA=/,`
M07H@861A='3A8FSA:R!L:7-TX6IA`$QI<W1A(&%R8VCM=G5M`$QI<W1A('-E
M9^UT<^EG:^ERZ7,`3&ES=&$@87IO;F]S[73S`$QI<W1A('1U;&%J9&]N;W,`
M3&ES=&$@;&5VZ6SM<N%S`$QI<W1A(&9E;&ER871K;WKA<R`H<W5B<V-R:6)E
M*0!,:7-T82!L96ER871K;WKA<R`H=6YS=6)S8W)I8F4I`$$@9F5L:&%S>F[A
M;/-K87!C<V]L871O:R!K:6QI<W3A>N%S82!N96T@<VEK97+\;'0Z("5S`$$@
M9F5L:&%S>F[A;/-K(&MI;&ES=.%ZX7-A(&YE;2!S:6ME<OQL=#H@)7,`02!F
M96QH87-Z;N%L\VL@:VEL:7-TX7KA<V$@=&EL='9A('9A;BX`27)O9&%L;VT`
M3&ET=N%N:6$`3&5T]FQTZ7,N+BX`2&5L>6D@:63U.B``3GEE;'8L(&3A='5M
M+"!I9/4`2&5L>0!"96IE;&5N=&ME>NES`$%Z(&5L]7KU(&%D871S>FEN:W)O
M;FEZX6-I\R!N87!L\^%L;&]MX6YY80!+:6IE;&5N=&ME>NES`$)E:F5L96YT
M:V5ZZ7,`0F5J96QE;G1K97KI<W-E;"!K87!C<V]L871O<R!F96QA9&%T;VL`
M02!B96IE;&5N=&ME>NES(&YE;2!S:6ME<OQL="P@;65R="!R;W-S>B!F96QH
M87-Z;N%L\VYE=F5T('9A9WD@:F5L<WKS="!A9&]T="!M96<N`$$@8F5J96QE
M;G1K97KI<R!N96T@<VEK97+\;'0N`$AO<W-Z^B!S>O9V96<`4WIE<F5L96T`
M86QA8W-O;GD`9_9R]F<@:VES8F5T^VL`;&%T:6X@:VES8F5T^VL`:VES8F5T
M^W,@<O-M86D@<WKA;6]K`$QU>&5M8G5R9P!-30!.87!I(/QZ96YE=&5K`$%Z
M($U3+51.148@;65L;.EK;&5T8F5N(&YI;F-S(&%D870N`-Q:14Y%5`!-86MA
M\P!-86ME9/-N:6$`36%D86=A<WIKX7(`5F%RX7IS;&%T`$QE=F5L97KI<P!%
M;6%I;"!D;VUA:6X@:V5Z96SI<P!,:6YK(&OI<WKM=.ES90!-86QA=VD`36%L
M86IZ:6$`36%L9.UV+7-Z:6=E=&5K`$UA;&D`3>%L=&$`061A=&%I="!K871E
M9_-R:>%K8F$@<V]R;VQH871J82X@17IE:R!I='0@9&5F:6YIX6QH873S:RP@
M;?-D;W/M=&AA=/-K+"!T;W;A8F+A('-Z[6YE:R!R96YD96QH973U:R!H;WIZ
MX6IU:RX`36%P,C0@=.ER:^EP`$UA<%%U97-T('3I<FOI<`!!(&AO>GKA<F5N
M9&5LZ7-E:V5T(&5L;65N=&5T=/QK+@!MX7)C:75S`$UA<F?S`$%Z($]L=F%S
M;W1T+T]L=F%S871L86X@:F5L>F5T96L@:&%S>F[A;&%T80!-X7,@:F5L>F5T
M96L@*'!L+B!&;VYT;W,O365G=N%L87-Z;VQT*2!H87-Z;N%L871A`$UA<G-H
M86QL+7-Z:6=E=&5K`$UA<G1I;FEQ=64`16=Y;>%S;F%K(&UE9V9E;&5L]2!M
M97KU:P!-875R:73A;FEA`$UA=7)I=&EU<P!-87AI;>%L:7,@<F5N9&5L:V5Z
MZ7-R92#A;&SS('-ZX6UL8?9S<WIE9RX`07H@_'IE;F5T('3Z;"!S;VL@<NES
M>F+U;"#A;&PN`$%Z(&5L;?IL="`R-"#S<F$@;6%X:6WA;&ES(&CU;>ER<^EK
M;&5T93H@`$%Z(&5L;?IL="`V(/-R82!M87AI;>%L:7,@:/5MZ7)SZ6ML971E
M.B``07H@]G-S>F5G]6]L9&%L(&)L;VMK:F%I;F%K(&UA>&EMX6QI<R!S>N%M
M80!-87AI;>%L:7,@:&]S<WH`;>%J=7,`36%Y;W1T90!/<G9O<W1U9&]MX6YY
M`%1A9V]K`$$@;65N_"!M96=J96QE;NES93H`0V5L;.%K(&5G>6)E;VQV87-Z
M=.%S80#<>F5N970`02!D:6=I=.%L:7-A;B!A;.'M<G0@_'IE;F5T(&AI=&5L
M97,L(&1E(&%Z(&%LX>UR\R!T86[Z<^UT=N%N>>%T(&YE;2!S:6ME<OQL="!E
M;&QE;O5R:7IN:2X`3&5JX7)T(&%Z(/QZ96YE="#I<G;I;GEE<W/I9V4N`$%Z
M(/QZ96YE="!T[7!U<V$`365T87(@:63U:N%RX7-J96QE;G3I<P!!($UE=&%R
M(&)L;VMK(&YE;2#A;&P@<F5N9&5L:V5ZZ7-R92X`02!-971A<B!B;&]K:R!N
M96T@X6QL(')E;F1E;&ME>NES<F4N($$@<NES>FQE=&5K(&$@<F5N9'-Z97)G
M87ID82!S>N%MX7)A(&OI<WK\;/4@;F%P;/-FX6IL8F$@:V5R_&QT96LN`$$@
M365T87)$0B!N96T@Z7)H973U(&5L+@!-\V1S>F5R`$$H>BD@(B5S(B!M\V1S
M>F5R(&1E9FEN:>%L871L86X`02!M\V1S>F5R(&1E9FEN:>%L871L86XN($$@
M;65G:.UV;W1T(&WS9'-Z97(Z("5S`$UE=')I:W5S`$UE>&EK\P!-:6MR;V[I
M>FEA:2!3>O9V971SZ6=I(,%L;&%M;VL`:_9ZZ7``34E-12!T[7!U<P!!>B!E
M;&WZ;'0@,C0@\W)A(&QE9V%L86-S;VYY86)B(&CU;>ER<^EK;&5T93H@`$%Z
M(&5L;?IL="`V(/-R82!L96=A;&%C<V]N>6%B8B!H]6WI<G/I:VQE=&4Z(`!-
MZ6<@;F5M('1E;'0@96P@82!M:6YI;>%L:7,@:63U(&$@:F5L<WKS(&UE9W;A
M;'1O>G1A=.%SX6AO>@!4_&MR]GKI<R`H:F]B8B]B86PI`%9E9WEE<P!(:>%N
M>7II:R!A($A45%!?4F5Q=65S="!014%2(&-S;VUA9RX`2V]N9FEG=7+A8VGS
M('-Z_&MSZ6=E<RX@17IT(&UO<W0@:V5L;"!LZ71R96AO>FYI82P@:&$@:&%S
M>F[A;&YI(&%K87)J82!A>B!A;&MA;&UA>N%S="X`2&GA;GEZ:6L@87H@_'IE
M;F5T(&%Z;VYO<^UT\VIA+@!(:>%N>7II:R!A($UA:6P@4$5!4B!C<V]M86<N
M`$AIX6YY>FEK(&$@9F5L:&%S>F[A;/-K87!C<V]L870@87IO;F]S[73S:F$@
M*'-E<W-I;VX@240I+@!(Z0!,979E;&5ZZ7,@;6]B:6QT96QE9F]N<O-L`$OV
M>F5P97,`02!M\V1O<^UTX7,@9.%T=6UA`$%Z(%523"!M\V1O<^UTX7-A`$UO
M9'5L=7,`36]L9&]V86D@2_9Z=.%R<V%SX6<`36]N86-O`$UO;F?S;&EA`$CS
M;F%P(.ES(.EV`&AA=F]N=&$`36]N='-E<G)A=`!(;VQD9N%Z:7-O:P!!("5D
M+B!S;W)B86X@=/9B8B!M97KU('9O;'0L(&UI;G0@82!VX7)T("5D+@!-87)O
M:VOS`%3V8F)N>6ER92!D97+\;'0`5/9B8FYY:7)E(&)O<G5L=`!4]F)B;GEI
M<F4@;F%P;W,`=FEG>?QK(&QE`'9I9WG\:R!B86QR80!V:6=Y_&L@:F]B8G)A
M`'9I9WG\:R!F]FP`=FEG>?QK(&QE`'9I9WG\:R!F]FP`36]Z86UB:6L`5/9B
M8G-Z:6YT^R!L96?V<F3\;/4@;&ES=.%K`$UU;'1I;6%P($YA9WDM0G)I=&%N
M;FEA('3I<FOI<`!4]F)B<WKV<O9S(';A;&%S>G3A<P!"96IE;&5N=&ME>NES
M:2!B9>%L;.UTX7-O:P!"96IE;&5N=&ME>NES:2!A9&%T86EM`%-A:N%T(/9S
M<WIE9WKU(&]L9&%L86T`4V%JX70@]G-S>F5G>O4@;VQD86QA;2!T97)V97KI
M<V4`36EA;FUA<@!.14TL(&YE;2!E9WEE>F5M(&)E;&4N`$[I=@!.86WM8FEA
M`$YA=7)U`$YE<.%L`$AO;&QA;F1I80!(;VQL86YD($%N=&EL;.%K`$YE='-C
M87!E(&+A>FES+5523`!.971S8V%P92!T86[Z<^UT=N%N>6MI863A<VEJ;V<H
M0T$I+79I<W-Z879O;N%S:2!54DP`3F5T<V-A<&4@=&%N^G/M=';A;GEF96QH
M87-Z;N%LX7-I(&ERX6YY96QV(%523`!.971S8V%P92!T86[Z<^UT=N%N>6UE
M9_IJ[73A<VD@55),`$YE='-C87!E('1A;OIS[71VX6YY=FES<WIA=F]NX7-I
M(%523`!.971S8V%P92!34TP@<WIE<G9E<F[I=@!.971S8V%P92!T86[Z<^UT
M=N%N>2!M96=J96=Y>NES`$YE='-C87!E('1A;OIS[71VX6YY=.UP=7,`2.%L
M\WIA=`!S;VAA`-IJ+4MA;&5D\VYI80#::B!K871E9_-R:6$`VFH@;&5VZ6P@
M)7,@8^UM<F4`^FIH;VQD`-IJ(&9E;&AA<WINX6SS;NEV("AO<&-I;V[A;&ES
M*0#::BU:Z6QA;F0`VFH@:F5L<WKS`$%Z(/IJ(&IE;'-Z\R#I<G;I;GEE<W/I
M9V4@96MK;W(@:N%R(&QE.B`E>"X`02!M96=A9&]T="#Z:B!J96QS>F%V86L@
M;F5M(&5G>65Z;F5K+@#::B!A8FQA:R`H_')E<RD`2.UR96L`2.UR8W-O<&]R
M=&]K`$OV=F5T:V5Z]0!+]G9E=&ME>O4@-"!FX7II<P!+]G9E=&ME>O4@;W!C
M:?-K`$OV=F5T:V5Z]3X`3FEC87)A9W5A`$YI9V5R`$YI9^ER:6$`Z6IS>F%K
M80!.:75E`$YE;0!.:6YC<R!R96YD96QK97KI<W)E(.%L;/,@:V]N9FEG=7+A
M8VGS+"!A;6EH97H@:^EP97-T(&$@:_QL]FYB<^EG96ME="!M96<@;&5H971N
M92!M=71A=&YI+@!.:6YC<R!L96AE=/5SZ6<@25-/(.%L;&]MX6YY;VL@;.ET
M<F5H;WKA<^%R82X`2&GA;GEZ:6L@82!K]G1E9V5L="!F96QD;VQG;WKA<VAO
M>B!S>OQK<^EG97,@;6EN=&$@*&)A=&-H('1E;7!L871E*2X`02!K[7;A;G0@
M:&5L>65N(&YI;F-S(&)L;VMK`$%Z($U#04P@9F5L:&%S>F[A;/-A>F]N;W/M
M=.%S:&]Z(&YI;F-S(&UE9V%D=F$@82!N87!TX7(@;F5V92X`3FEN8W,@=N%L
M=&]ZX7,N`$5H:&5Z(&$@:F]G;W-U;'1SX6=H;WH@;F5M(&AO>FAA=/,@;.ET
M<F4@:F]G;W-U;'1SX6=I(&%L8W-O<&]R="X`2&GA;GEO>FYA:R!A(&MO;F9I
M9W5RX6-I\W,@861A=&]K("5S+6AE>BX`07H@1E10(%9&4R!N:6YC<R!K;VYF
M:6=U<N%L=F$N`$%Z(%-13"!61E,@;FEN8W,@:V]N9FEG=7+A;'9A+@!!>B!3
M44PM1FEL92!61E,@;FEN8W,@:V]N9FEG=7+A;'9A+@!!>B#6;B!S>N%M;.%J
MX6X@96QF;V=Y;W1T(&$@<F5N9&5L:V5ZZ7-R92#A;&SS(/9S<WIE9RX`3FEN
M8W,@8^UM>NES+@!!('-Z97)V97)R92!N96T@=/9L=/5D]G1T(&9E;"!S96UM
M:6QY96X@X6QL;VWA;GD`07H@:6MO;F]K(&YE;2!T86SA;&AA=/-K+@!.:6YC
M<R!M96=A9'9A(&$@:&5L>2X`3FEN8W,@;65G861V82!A(&AE;'DN`$%Z(/QZ
M96YE="#\<F5S+@!.:6YC<R!M96=A9'9A(&$@;NEV+@!.:6YC<R!M96=A9'9A
M(&$@<WKA;2X`3F4@;&5G>65N(&UE9V)O='+A;FMO>G1A=/,@:63I>F5T`$YI
M;F-S(&IE;'-Z\R!M96=A9'9A(&$@2%144"!A;&%P^B!F96QH87-Z;N%L\VD@
M87IO;F]S[73A<VAO>BX`3FEN8W,@:F5L<WKS(&UE9V%D=F$@87H@24U!4"!A
M;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S[73A<VAO>BX`3FEN8W,@:F5L<WKS
M(&UE9V%D=F$@82!+97)B97)O<R!A;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S
M[73A<VAO>BX`3FEN8W,@:F5L<WKS(&UE9V%D=F$@82!,;V=I;B!A;&%P^B!F
M96QH87-Z;N%L\VD@87IO;F]S[73A<VAO>BX`3FEN8W,@:F5L<WKS(&UE9V%D
M=F$@82!005-35T0@86QA</H@9F5L:&%S>F[A;/-I(&%Z;VYO<^UTX7-H;WHN
M`$YI;F-S(&IE;'-Z\R!M96=A9'9A(&%Z(%--0B!A;&%P^B!F96QH87-Z;N%L
M\VD@87IO;F]S[73A<VAO>BX`3FEN8W,@;65G861V82!A>B!/<&5N4U-,('!R
M;V=R86T@96SI<NES:2#Z='9O;F%L82X@07H@3W!E;E-33"!P<F]G<F%M('-Z
M_&MSZ6=E<R!A(%!+0U,@,3(@861A=&]K(&ME>F5LZ7/I:&5Z+@!.:6YC<R#Z
M:B!B96IE;&5N=&ME>NES:2!I9^EN>2X`3FEN8W,@:W;S=&$@8F7A;&SM='9A
M+@!.92!L96=Y96YE:R!V;VYA;&%K('-E:&]L+@!.:6YC<R!D969I;FGA;'9A
M(&5L=N%L87-Z=/,@:V%R86MT97(N`$YE(&QE9WEE;B!K97)E=`!.:6YC<R!I
M;'EE;B!FX6IL`$YI;F-S(&ED96EG;&5N97,@X6QL;VWA;GEO:R!TX7)O;.%S
MX7)A('-Z;VQGX6SS(&%L:_9N>79TX7(N`$AIX6YY>FEK(&$@9F5L:&%S>F[A
M;/-NZ78@Z7,O=F%G>2!A(&IE;'-Z\RX`02!V:7-S>F%K87!O='0@861A=&]K
M(&YE;2#I<G;I;GEE<R!834P@861A=&]K`$YI;F-S(&%D870`3FEN8W,@;>EG
M(&MO;F9I9W5RX6-I\RP@9V5N97+A;&IO;B!E9WEE="X`3FEN8W,@;>EG(&MO
M;F9I9W5RX6-I\VIA+"!G96YE<N%L:F]N(&5G>65T+@!N:6YC<P!N:6YC<R!M
M96=A9'9A("AL96=Y96X@86QA<.ER=&5L;65Z971T*0!N;W)D:6MU<R`H25-/
M+3@X-3DM,3`I`$YO<F9O;&LM<WII9V5T`,ES>F%K:2!FZ6QT96ME`,ES>F%K
M:2U-87)I86YA+7-Z:6=E=&5K`$YO<G;I9VEA`$YE;2!KZ7/U8F(`3F5M(&MO
M<N%B8F%N`$YE;2!A;&OV;GEV=.%R`$$@<')O9W)A;6YA:R!E>B!A('+I<WIE
M(&WI9R!N:6YC<R!M96=V86SS<^UT=F$N`$YI;F-S(&)EX6QL[71V80!.96T@
M=.%M;V=A=&]T="X`1F5L:F5G>7KI<V5K`$YI;F-S(&+V;F?I<WIH973U(&%D
M870L('3I<FIE;B!V:7-S>F$N`&YO=F5M8F5R`%-ZX6T`2V%R86MT97)E:R!S
M>N%M80!/<WIL;W!O:R!S>N%M80!3;W)O:R!S>N%M80!!(&OV<FQE=NEL;&ES
M=&$@;?-D;W/M=.%SX6AO>B!N96T@861O='0@;65G('-ZX6UO:V%T+@!/2P!/
M8FIE:W1U;0!!>B!O8FIE:W1U;2!LZ71R96AO>O-J80!/:W3A;&ES('-ZX6T`
M;VMT\V)E<@!3>OMRZ7,`2&EV871A;"]M=6YK86AE;'D`02!RZ6=I(.ES(&%Z
M(/IJ(&IE;'-Z\VYA:R!K_&SV;F+V>FYI92!K96QL+@!!('+I9VD@:F5L<WKS
M`$$@<NEG:2!J96QS>O,@;F5M(&UE9V9E;&5L]2X`3VWA;@!#<V%K(&%Z($E-
M05`@<WIE<G9E<F5K('3A;6]G871JX6L@82!M87!PX6L@;65G;W-Z=.%SX70N
M`$-S86L@;65G8F]T<N%N:V]Z=&%T\R!I9.EZ970@;&5G>65N`$-S86L@96=Y
M(&5M86EL(&/M;2!A9&AA=/,@;65G+@!#<V%K(&$@='5L86ID;VYO<R!V86=Y
M(&$@<F5N9'-Z97)G87ID82!VX6QT;WIT871H871J82!M96<@96=Y(&OV>O9S
M('3A<G1E<OQL970@='5L86ID;VYO<^%T('9A9WD@96SI<NES:2!J;V=O<W5L
M='/A9V%I=`!.>6ES<W5K(&UE9R#Z:B!A8FQA:V)A;@!/<&5N4U-,(&AI8F$Z
M($YE;2!S:6ME<OQL="!K:6YY97)N:2!A>B!A9&%T;VMA="!A>B!A;.'M<G0@
M4R]-24U%('+I<WIB]6P`3GEI<W-U:R!M96<@97IT(&$@8^UM970@96=Y(/IJ
M(&%B;&%K8F%N`$]P97+A8VGS<R!R96YD<WIE<@!/<&-I\VL`)7,@8F7A;&SM
M=.%S86D`4V]R<WKA;6]S(&9E;'-O<F]LX7,`4WIE<G9E>F5T`%-Z97)V97IE
M=&D@96=Y<^EG`$UU;FMA<WIE<G9E>NES`$%Z(&%L:V%L;6%ZX7,@97)E9&5T
M:2!S86)L;VYJ80`E<R!E<F5D971I('-A8FQO;FIA:3H`16=YZ6(`16=YZ6(@
M:6YF;W)MX6-I\P!!('1U;&%J9&]N;W,@:F]G;W-U;'1SX6=A:0!!(%!!32!F
M96QH87-Z;N%L\V%Z;VYO<^UTX7,@;F5M(.%L;"!R96YD96QK97KI<W)E+@!0
M14%2.CI-86EL(&%L<F5N9'-Z97(`4$=0(&1I9VETX6QI<R!A;.'M<N%S`%!'
M4"UV96P@=&ET:V]S[71O='0@861A=`!01U`@;GEI;';A;F]S(&MU;&-S`%!'
M4"UV96P@86SA[7)T+W1I=&MO<^UT;W1T(&%D870`4$A0(&OS9`!$Z6QU=.%N
M+V5S=&4@9WEE;F=E(&5S]0!$Z6QU=.%N(&5S]0!$Z6QU=.%N+V5S=&4@>N%P
M;W)O:P!$Z6QU=.%N+V5S=&4@:&%V87KA<P!$Z6QU=.%N+V5S=&4@:/-ZX7!O
M<F]K`$3I;'5TX6X@;F%P<_QTZ7,`1.EL=73A;B]E<W1E('II=F%T87)O:P!(
M:>%N>7II:R!A(%!/4TE8(&+U=NUTZ7,`8F5L<_4@;6%R9_,`4&%K:7-Z=.%N
M`%!A;&%U`%!A;&5S>G1I;B!497+\;&5T("AM96=S>N%L;'0I`%!A;F%M80!0
MX7!U82#::BU'=6EN96$`4&%R86=U87D`3>ER<^EK96QT96X@8F]R=6QT`$IE
M;'-Z\P!!(&IE;'-Z\W0@<VEK97)E<V5N(&UE9W;A;'1O>G1A='1U:RX`3F5M
M(&UE9V9E;&5L]2!J96QS>O,`02!2041)55,@9F5L:&%S>F[A;/-A>F]N;W/M
M=.%S:&]Z(&IE;'-Z\R!S>OQK<^EG97,N`$IE;'-Z\R!M96=E<O5S[73I<W-E
M;`!*96QS>O,Z`$IE;'-Z\SH@`$$@:F5L<WIA=F%K;F%K(&5G>65Z;FG\:R!K
M96QL+@!"96EL;&5S>G3I<P!"96EL;&5S>G3A<R!A(';A9_-A<WIT86QR\VP`
MVG1V;VYA;`#::B!F96QH87-Z;N%L\VYA:R!B96IE;&5N=&ME>F5T=&5K.@!%
M;6)E<F5K`'-ZX7IA;.EK`$MA<F)A;G1A<G3A<VD@9F5L861A=&]K(';I9W)E
M:&%J=.%S80!"96IE;&5N=&ME>NES:V]R(&AA:G1S=6L@=NEG<F4@82!K87)B
M86YT87)TX7-I(&9E;&%D871O:V%T/P!*;V=O<W5L='/A9P!!*'HI("(E<R(@
M:F]G;W-U;'1SX6=O="!N96T@=/9R]FQT_&LN`-9N;F5K(&YI;F-S(&5H:&5Z
M(&5L96=E;F3U(&IO9V]S=6QT<^%G80!*;V=O<W5L='/A9V]K`$IO9V]S=6QT
M<^%G(&%D;6EN:7-Z='+A8VGS`%-Z96WI;'EE<R!A9&%T;VL`4&5R=0#!;&QA
M=&ME9'9E;F-E:P!&_&SV<"US>FEG971E:P!496QE9F]N`$;I;GEKZ7!G86SI
M<FEA`%!I=&-A:7)N`'!I>&5L`$OV>FAE;'EE:P!+871T:6YT<V]N('9A;&%M
M96QY:6L@8V5L;.%R80!":7IT;W-A;B!T]G+V;&YI(&%K87)J82!E>G0@87H@
M96QE;65T.@!+Z7)E;2!E<O5S[71S92!M96<L(&AO9WD@=F%L\V)A;B!T]G+V
M;&YI(&OM=N%N:F$@97IT(&%Z(&5L96UE="X`2^ER96T@861J;VX@;65G(&5G
M>2!H\VYA<&]T(.ES(&5G>2#I=F5T+@!+Z7)E;2!A9&IA(&UE9R!A>B#Z:B!K
M871E9_-R:6$@;F5VZ70Z`$OI<F5M('9A;/-S($E0(&/M;65T(&%D:F]N(&UE
M9RX`2^ER96T@=F%L\W,@9.%T=6UO="!A9&IO;B!M96<L(&5L;&5N]7)I>GIE
M(&$@:/-N87`@;F%P:F%I="X`2^ER96T@=F%L\W,@9.%T=6UO="!A9&IO;B!M
M96<N`$OI<F5M('+V=FED96X@[7)J82!L92!A('!R;V)LZ6UA(&SI;GEE9^ET
M+@!+Z7)E;2!A9&IA(&UE9R!A(&)E:F5L96YT:V5ZZ7-I(&YE=NET(.ES(&IE
M;'-Z87;A=`!+Z7)E;2!O;'9A<W-A(&5L(&$@:_9V971K97KU('-Z]G9E9V5T
M+B!!(')E;F1S>F5R(&AA<WINX6QA=.%N86L@9F5L=.ET96QE:70@96P@2T5,
M3"!F;V=A9&YI82X`2^ER96T@861J82!M96<@87H@^FH@:V%T96?S<FEA(&YE
M=NET.@!,96YG>65L;W)S>N%G`%!O;&ET:6MA`%-Z879A>N%S;VL`4&]R='5G
MX6QI80!!(&OI<"!E;&AE;'EE>NES90!!('3A8FSA>F%T(&5L:&5L>65ZZ7-E
M`$OV>G9E=&QE;B!L97;I;&O\;&3I<R!E8F)E(&$@;6%P<.%B82`H24U!4"!N
M96T@;6EN9&EG('9E<WII(&9I9WEE;&5M8F4I`$%Z(&5L;?IL="`E<R#S<F$@
M8W-A<&%DZ6MM96YN>6ESZ6=E.B``0W-A<&%DZ6L\8G(@+SYV86SS<WKM;OMS
MZ6<`4')E9G-?;&1A<#H@;F5M('1A;.%L:&%T\R!A('-Z_&MSZ6=E<R!,1$%0
M(&MI=&5R:F5S>G3I<RX`4')E9G-?<V5S<VEO;CH@;F5M('1A;.%L:&%T\R!A
M('-Z_&MSZ6=E<R`H<V5S<VEO;BD@:VET97)J97-Z=.ES+@!,Z6=N>6]MX7,`
M02!T96YG97)S>FEN=&YE:R!M96=F96QE;/4@;.EG;GEO;>%S.B``3.EG;GEO
M;>%S.B``16SU>F5T97,@;65G=&5K:6YTZ7,`02!KZ7`@96SU>F5T97,@;65G
M=&5K:6YTZ7-E(/IJ(&%B;&%K8F%N`$5L]7KU(&]P8VGS:P!!(&1O:W5M96YT
M=6T@:VEN>6]M=&%TX7-A`%1I=&MO<R!K=6QC<P!(:6)A8F5J96QE;G3I<P!!
M(&AI8F$@;&7M<N%S80!0<F]J96MT(&ME>F5LZ7,`02!P<F]M<'0@<WKV=F5G
M90!.>6EL=N%N;W,@:W5L8W,`3GEI;';A;F]S(&MU;&-S^B!A;&=O<FET;75S
M`$YY:6QVX6YO<R!K=6QC<R!I;F9O<FWA8VGS`$$@;GEI;';A;F]S+W1I=&MO
M<R!K=6QC<W#A<G0@;F5M('-I:V5R_&QT(&SI=')E:&]Z;FDN`%!U97)T;R!2
M:6-O`$$@;&5V96QE:R!VZ6=L96=E<R!T]G)LZ7-E`$MA=&%R`$ME<F5S]2]P
M87)A;F-S('-T<FEN9P!+=O-T80!24T$@;GEI;';A;F]S(&MU;&-S("@E9"!B
M:71E<RD`4N%D:?-G;VUB;W,@:VEVX6QA<WITX7,`17/U`$5S]2!DZ6QE;/5T
M=`!%<_4@9.EL=73A;B]E<W1E`%KA<&]R`$5S]2#I<R!H879A>N%S`$AA=F%S
M97/U`%;I;&5T;&5N(&EDZ7IE=`!!<N%N>0!/;'9A<^%S`$QE=F5L96L@;VQV
M87/A<V$`5.EN>6QE9R!T]G+V;&K\:R`E<R!F96QH87-Z;N%L\W0_($5Z(&$@
M=N%L=&]Z=&%TX7,@;F5M(&9O<F3M=&AA=/,@=FES<WIA+@!4Z6YY;&5G('3V
M<O9L:OQK("5S(&9E;&AA<WINX6SS(&%D871A:70_($5Z(&$@=N%L=&]Z=&%T
MX7,@;F5M(&9O<F3M=&AA=/,@=FES<WIA+@#::G)A(';I9W)E:&%J=&IA(&%Z
M('5T;VQS\R!VX6QT;WIT873A<W0`1G)I<W/M=.ES`$$@;65N_"!D:6YA;6EK
M=7,@96QE;65I;F5K(&9R:7-S[73I<VD@9WEA:V]R:7/A9V$Z`$%Z(/9S<WIE
M9WKU;VQD86P@9G)I<W/M=.ESZ6YE:R!G>6%K;W)I<^%G83H`3V)J96MT=6T@
M8O9N9^ES>O4`1G)I<W/M=.ES`$UE9VIE9WEZZ7-E:P!4X79O;&D@<WIE<G9E
M<F5K`$$@=.%V;VQI(%523"`H<&PN(&AT='`Z+R]W=W<N=F%L86UI+FAU+VUE
M9W9A;&%M:2DZ`%3V<FSI<P!";&]K:R!T]G)LZ7-E`$]S>FQO<"!T]G)LZ7-E
M`$$@9F]R;6%T=.%LX7,@=/9R;.ES90!!('#A<B!T]G)LZ7-E`%3V<O9L:OQK
M(&%Z(&5L;65N=&5T="!P<F]G<F%M;W0@82!S>F5R=F5R(&ED96EG;&5N97,@
MX6QL;VWA;GEO:V%T('1A<G1A;&UA>O,@86QK]FYY=G3A<N%B\VPN`%9E9WG\
M:R!K:2``5F5G>?QK(&MI(&5Z="!A('+I<WIT(&$@9&]K=6UE;G1U;6+S;`!!
M(&9E;&AA<WINX6SS('3V<FSI<V4`)7,@9F5L:&%S>F[A;/,@=/9R;.ES90!!
M(&OI<NES(&YE;2!T96QJ97/M=&AE=/4N($$@:V%P;W1T(&AI8F%K\V0Z(`!!
M(&ME<F5S971T('-Z;VQGX6QT873A<R!N96T@=&%LX6QH873S+@!!(&OV=&5L
M97KU96X@;65G861A;F3S("(E<R(@;F5M('-Z97)E<&5L("5S(&MO;F9I9W5R
MX6-I\VKA8F%N+@!!(&OV=&5L97KU96X@;65G861A;F3S("(E<R(@;F5M('-Z
M97)E<&5L(&$@5D93(&MO;F9I9W5RX6-I\VKA8F%N+@!!(&OV=&5L97KU96X@
M;65G861A;F3S("(E<R(@;F5M('-Z97)E<&5L(&$@:V]N9FEG=7+A8VGS8F%N
M+@!3>OQK<^EG97,@;65Z]0!297-E=`!!(&IE;'-Z\R#A=.%L;.UTX7-A`$%Z
M(-9N(&IE;'-Z87;A;F%K(.%TX6QL[73A<V$`07H@=71O;'/S(&ME<F5SZ7,@
M=FES<WIAX6QL[73A<V$`17)E9&WI;GD`5FES<WIA(&%Z(&]P8VGS:VAO>@!!
M>B#Z:B!J96QS>O-T(.UR:F$@8F4@:7-MZ70`4NEU;FEO;@#!;&SM='-U:R!V
M:7-S>F$@82!K;VYF:6=U<N%C:?-T`%)I8V@@5&5X="!%9&ET;W(@;W!C:?-K
M`%1A;.%L\W,@:^ER9.ES96L`:F]B8@!*;V)B(&]L9&%L:2!F96ILZ6,`2F]B
M8B!O;&1A;&D@Z7)TZ6ME:P!3;W(@='5L86ID;VYSX6=O:RXN+@!3>F5R97``
M4F]MX6YI80!&;W)G873A<R`Q.#`@9F]K:V%L`$)A;')A(&9O<F=A=.%S`$IO
M8F)R82!F;W)G873A<P!3;W(@='5L86ID;VYSX6=O:P!3;W(@='5L86ID;VYS
MX6=O:P!3;W)O:SH`5F]N86QA:P!-:6YD96X@<V]R(.ES(&]S>FQO<"!K]GKV
M='0@;&5G>65N('9O;F%L`$-S86L@87H@;W-Z;&]P;VL@:_9Z]G1T(&QE9WEE
M;B!V;VYA;`!#<V%K(&$@<V]R;VL@:_9Z]G1T(&QE9WEE;B!V;VYA;`!&=71T
M873A<P!/<F]S>B!&]F1E<N%C:?,`4G5A;F1A`%,O34E-12!D:6=I=.%L:7,@
M86SA[7+A<P!3+TU)344@<WIA8G;A;GD@<WIE<FEN="!T:71K;W/M=&]T="!L
M97;I;`!305-,(&9E;&AA<WINX6SS87IO;F]S[73A<R!N96T@=&%LX6QH873S
M+@!335,@:_QL9.ES`%-13"!P87)A;F-S(&$@:V5R97/I<VAE>@!34T@`4TE+
M15+<3%0`4WIO`%-Z96YT($EL;VYA+7-Z:6=E=`!386EN="!+:71T<R#I<R!.
M979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@Z7,@36EQ=65L;VX`4V%I
M;G0@5FEN8V5N="#I<R!'<F5N861I;F4M<WII9V5T96L`56=Y86YA>B!A(&9R
M86UE("A?<V5L9BD`4WIA;6]A`%-A;B!-87)I;F\`4V%O(%1O;>D@Z7,@4'+M
M;F-I<&4`3?MH;VQD87,@:6YT97)N971E;.ERZ7,`4WIA^F0M07+A8FEA`$UE
M;G3I<P`B)7,B(&UE;G3I<V4`)7,@;65N=.ES90!!(&)EX6QL[73A<V]K(&UE
M;G3I<V4`365N='/\:R!E;"!A>B!E;&OI<WK\;'0@:V]N9FEG=7+A8VGS="!0
M2%`@<')O9W)A;2!F;W)MX6KA8F%N(&$@<WIE<G9E<B!I9&5I9VQE;F5S(.%L
M;&]MX6YY;VMA="!T87)T86QM87KS(&%L:_9N>79TX7+A8F%N+@`E<R!K;VYF
M:6=U<N%C:?-JX70@96QM96YT971T_&LN`$5L;65N=&5T=/QK(&$@<V5T=7`@
M=7!G<F%D92!P<F]G<F%M;W0@:61E.B`B)7,B`%-Z\W)VX6YY;W,@>FEV871A
M<F]K`%1U9&]MX6YY`$ME<F5SZ7,`2V5R97/I<VD@<WIO;&?A;'1A=.%S;VL`
MP6QL;VWA;GEO:R!K:7;A;&%S>G3A<V$`5N%L87-S>F]N(&MI(&5G>2!DX71U
M;6]T`$UE;'EI:R!C<V]P;W)T;W0@:^UVX6YJ82!H;WIZX6%D;FD`5N%L87-S
M>F$@:VD@87H@^FH@='5L86ID;VYO<W0`5N%L87-S>F]N('-Z97)V97)T`$UE
M;'EI:R!F96QH87-Z;N%L\W0@:^UVX6YJ82!H;WIZX6%D;FD`36EN9&5T(&MI
M:F5L]FQJ_&L`5N%L87-S>F$@:VD@87H@]G-S>F5S(&3A='5M]G-S>F5T97;U
M="X`5N%L87-S>F]N(&5G>2!O8FIE:W1U;6]T`$5G>2!S92!L96=Y96X@:VEJ
M96SV;'9E`%;A;&%S<WIA(&MI(&$@:^UVX6YT(&MA<F%K=&5R*&5K92ET(&%Z
M(&%LX6)B:2!L96AE=/5SZ6=E:R!K]GK\;"X@17IU=.%N(")C;W!Y+W!A<W1E
M(B!M\V1S>F5R<F5L(&$@;65G9F5L96SU(&AE;'ER92!MX7-O;&AA=&IA(/5K
M970N`%;A;&%S<WIA(&MI(&$@9.%T=6UE;';A;&%S>G3S(&MA<F%K=&5R=#H`
M5N%L87-S>F$@:VD@82!DX71U;2!F;W)MX71U;>%T.@!6X6QA<W-Z82!K:2P@
M;65L>6EK(&%Z;VYO<^UT\VKA="!K[7;A;FIA(&UE9W;A;'1O>G1A=&YI.@!6
MX6QA<W-Z82!K:2!A>B!I9/5E;';A;&%S>G3S(&MA<F%K=&5R=#H`5N%L87-S
M>F$@:VD@87H@:63U(&9O<FWA='5MX70Z`%;A;&%S<WIO;B!K:2!KZ70@96=Y
M;>%S;F%K(&UE9V9E;&5L]2!M97KU="X`5N%L87-S>F$@:VD@82!K[7;A;G0@
M<WKM;F5G>?QT=&5S="X`5N%L87-S>F$@:VD@87H@UFYN96L@;65G9F5L96SU
M(&YY96QV970Z`$AI8F%J96QE;G3I<R!K_&QDZ7-E`%--4R!K_&QDZ7-E`%-Z
M96YE9^%L`%-Z96YZ;W(Z(`!S>F5P=&5M8F5R`%-Z97)B:6$@Z7,@36]N=&5N
M96=R\P!3;W)O>F%T<WKA;0!!('-Z97)V97)T]6P@:V%P;W1T(&%D870@:&EB
MX7,L('9A9WD@;F5M(.%L;"!R96YD96QK97KI<W)E+@!!(&9E;&AA<WINX6SS
M:V%P8W-O;&%T;VL@861M:6YI<WIT<N%C:?-J80!,96KA<G0@82!F96QH87-Z
M;N%L\VMA<&-S;VQA="!A>F]N;W/M=/-J82`H<V5S<VEO;B!)1"DN`$9E;&AA
M<WINX6SS:V%P8W-O;&%T;VL`2&%L;6%Z`$QE:&5T]7/I9R!J96QS>F%VX6YA
M:R#A=.%L;.UTX7/A<F$L(&%B8F%N(&%Z(&5S971B96XL(&AA(&5L9F5L96IT
M96[I+@!4X79O;&D@<WIE<G9E<F5K(&5LZ7+I<V4@X6QL[71H873S(&)E+"!M
M96QY96ME="!A>B!I;F1U;/-O;&1A;.%N(&OM=N%N(&UE9VIE;&5N[71E;FDN
M`$$@:^UVX6YT(&YY96QV+"!I9/5Z\VYA(.ES(&3A='5M9F]R;>%T=6T@8F7A
M;&SM=.%S82X`0F7A;&SM=&AA=/,L(&AO9WD@;65L>6EK(&%L:V%L;6%ZX7,@
M:F5L96YJ96X@;65G(&$@8F5J96QE;G1K97KI<R!U=.%N+"!M:6QY96X@<WKM
M;F5G>?QT=&5S="P@;VQD86QF<FES<^UTZ7-I(&=Y86MO<FESX6=O="!I;&PN
M(&5G>>EB(&)EX6QL[73A<V]K870@<WIE<F5T;F4N`$)EX6QL[73A<V]K`$$@
M8F7A;&SM=.%S;VMA="!M96?Z:NUT\R!P<F]G<F%M;VL@X6QL;F%K(')E;F1E
M;&ME>NES<F4`02!M96=A9&]T="!P87)A;>ET97(@=/9B8B!H96QY970@:7,@
M:F5L96YT:&5T.B``4V5Y8VAE;&QE+7-Z:6=E=&5K`%;A<^%R;.%S`%+V=FED
M(/9S<WIE9F]G;&%LX7,`16P@:^UVX6YJ82#I<FYI(&%Z(&5G>65S(&9U;FMC
M:?-K870@06QT+6)I;&QE;G1Y^RUK;VUB:6[A8VGS:VMA;"!I<S\`365G:F5L
M96[M=.ES`$UU=&%S<W5K(&UE9R!A(&O\;/9N8G/I9V5K970@87H@96QM96YT
M971T(.ES(&%Z(/IJ;VYN86X@;.ET<F5H;WIO='0@:V]N9FEG=7+A8VGS(&OV
M>O9T="X`36EN9&5N(&)E:F5L96YT:V5ZZ7-K;W(@[7+S9&KI:R!K:2!A(&MO
M<N%B8FD@=71O;'/S(&)E:F5L96YT:V5ZZ7,@:61E:F4_`%;A;&%S>G1H873S
M(&QE9WEE;B!A>B!E<F5D971I(&UE9W1A<G3A<V$`3&5G>65N(&3A='5M=N%L
M87-Z=/,`3&5G>65N(&5G>2!TX6)LX7IA=&ME>F5L]2!M96[\<V]R/P!-=71A
M<W-U:R!A("5S(&UE;OQT(&$@8F%L(&]L9&%L;VX_`$[I>GK\:R!M96<@=.%B
M;.%Z870@8V5L;.%I;F%K('1U;&%J9&]N<^%G86ET`$[I>GK\:R!M96<@=.%B
M;.%Z870@='5L86ID;VYSX6=A:70`3NEZ>OQK(&UE9R!TX6)LX7IA="!S;W)A
M:6YA:R!T=6QA:F1O;G/A9V%I=`!.Z7IZ_&L@;65G(&$@:^EP('1U;&%J9&]N
M<^%G86ET`$UU=&%S<W5K(&$@9F5L=/9L=.ES=`!:X7!O<F]K`%KA<&]R;VL@
M9.EL96SU='0`6N%P;W)O:R!DZ6QU=.%N+V5S=&4`2&5L>6D@>N%P;W)O:P!+
M:6-S:6YY[73I<P!%;/5S>O9R(&MI8W-I;GGM=&5N:64@:V5L;"P@=F%G>2!E
M;"!K96QL(&UO>F3M=&%N:6$@82!H96QY970@96QF;V=L86SS(&)L;VMK;VMA
M="X`4VEE<G)A($QE;VYE`-IJ(&9E;&AA<WINX6SS:R!B96IE;&5N=&ME>NES
M90!$:6=I=.%L:7,@86SA[7+A<P!!(&1I9VETX6QI<R!A;.'M<N%S(&%L9V]R
M:71M=7-A`%-Z:6YG87#Z<@!-Z7)E=`!!(&MA<F)A;G1A<G3A<R!K:6AA9WGA
M<V$`4WIL;W;A:VEA`%-Z;&]VZ6YI80!(879A>N%S`$CS>N%P;W(`2/-ZX7!O
M<F]K`$CS>N%P;W)O:R!DZ6QE;/5T=`!+Z7/U(&3I;'5TX6YI+V5S=&D@:/-Z
MX7!O<F]K`$$@:/,@;>EL>7/I9V4Z(`!(\R!V[7IM96YN>6ESZ6=E8F5N(&MI
M9F5J97IV93H@`%-A;&%M;VXM<WII9V5T96L`4WIO;>%L:6$`1&%L;VLL('9E
M<G-E:P!!('-O<F)A<F5N9&5ZZ7,@:7+A;GGA;F%K(&MI=N%L87-Z=.%S80!&
M96QA9/-I(&/M;0!$Z6PM069R:6MA`&3I;"UE=7+S<&%I("A)4T\M.#@U.2TS
M*0!$Z6QI+4=E;W)G:6$@Z7,@1.EL:2!386YD=VEC:"US>FEG971E:P!$Z6QI
M(&;I;'1E:V4`4WIO;7-ZZ61O<R!C96QLX6L@:_9Z]G1T:2!TX79O;'/A9P!!
M(&-E;&QA('1A<G1A;&UA(.ES(&ME<F5T92!K]GKV='1I('3A=F]L<^%G`$AE
M;'EK:73V;'3U`%3A=F]L<^%G`%3A=F]L<^%G(.ES(&)E;'/U(&UA<F?S(&)E
MX6QL[73A<P!3<&%N>6]L;W)S>N%G`%-P86UA<W-A<W-I;F4@8F7A;&SM=.%S
M;VL`4W!E8VGA;&ES(&MA<F%K=&5R(&)E=FET96QE`$$@8V5L;&$@:V5T=.EB
M;VYTX7-A`$%Z(&]S>FQO<"!K971TZ6)O;G3A<V$`02!S;W(@:V5T=.EB;VYT
MX7-A`%-P;W)T`%-R[2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`07H@96QS
M]2#I=@#!;&QA;2!V86=Y('1A<G1O;>%N>0#!;&QA<&]T`$UE;G3I<VD@9F]R
M;>%T=6T`0^UM("AU=&-A*0#A=&CZ>F]T=`!3=')I;F<@;&ES=&$`5/9R]FQJ
M_&L@82!C[6UB]6P@82!`('5TX6YI('+I<WIT`%-T[6QU<R!;0U-370!680!!
M*'HI("(E<R(@86QK]FYY=G3A<B!N96T@=&%LX6QH873S+@!4X7)G>0!+_&QD
M:OQK(&5L`"(E<R(@^FH@9F5L:&%S>F[A;/,@8F5J96QE;G1K97KI<VD@:^ER
M96QMZ70@=&]VX6)B[71O='1U:RX@UFX@8W-A:R!KZ7)E;&WI;F5K(&5L9F]G
M863A<^%T(&OV=F5T]65N('1U9"!M86ID(&)E:F5L96YT:V5Z;FDN`&%L<_,@
M:6YD97@`4VEK97+\;'0`4VEK97)E<V5N(&AO>GKA861T=6L@(B5S(BUT(&$@
M<F5N9'-Z97)H97HN`"(E<R(@9F5L:&%S>F[A;/,@861A=&%I="!S:6ME<F5S
M96X@=/9R]FQT_&L@82!R96YD<WIE<F+U;"X`4VEK97)E<V5N('3V<O9L=/QK
M("(E<R(M="X`4VEK97)E<V5N(&5L=.%V;VSM=&]T='5K("(E<R(M="!A(')E
M;F1S>F5R8O5L+@!!(&MO;F9I9W5RX6-I\W0@<VEK97)E<V5N('9I<W-Z8>%L
M;.UT;W1T=6LN($$@=N%L=&]ZX7-O:R!M96=T96MI;G3I<^EH97H@9G)I<W/M
M='-E(&%Z(&]L9&%L="X`02!B86-K=7`@:V]N9FEG=7+A8VGS="!E;&UE;G1E
M='3\:RX`4VEK97)E<V5N(&5L;65N=&5T=/QK(&$H>BD@)7,@8F%C:W5P(&MO
M;F9I9W5RX6-I\W0N`"(E<R(@861A=&%I;F%K(&WS9&]S[73A<V$@<VEK97)E
M<V5N(&UE9W3V<G3I;G0N`%-I:V5R97-E;B!E;&UE;G1E='3\:R!A("5S(.%L
M;&]MX6YY="X`4WIU9.%N`-9S<WIE9F]G;&%LX7,`3F%P:V5L=&4`3F%P;GEU
M9W1A`&YA<&]S`$YA<&ME;'1E`$YA<&ME;'1E+VYA<&YY=6=T80!.87!K96QT
M93H@`$YA<&YY=6=T80!.87!N>75G=&$Z(`!F96QS]2!I;F1E>`!/;FQI;F4@
M:V]M;75N:6OA8VGS("AC:&%T*0!3=7)I;F%M90!#<V%LX61NZ78`4W9A;&)A
M<F0@Z7,@2F%N($UA>65N`%-Z=N%Z:6;V;&0`4W;I9&]R<WKA9P!3=N%J8P!!
M>B!A9&%T<WII;FMR;VYI>N%C:?-S(&YA<&SSX6QL;VWA;GET('3V<O9L=/QK
M`%-Z:6YT86MT:6MA:2!H:6)A(&$@:V5R97/U:VEF96IE>NES8F5N`%-Z[7)I
M86D@07)A8B!+]GITX7)S87/A9P!::79A=&%R`%II=F%T87(L(&5R]7,@<WKI
M;`!::79A=&%R;VL`2V]R86D@>FEV871A<F]K`%135B`H5$%"(&MA<F%K=&5R
M<F5L(&5L=N%L87-Z=&]T="#I<G3I:V5K*2#A;&QO;>%N>0!4X6)LX7IA=`!!
M('3A8FSA>F%T('1U;&%J9&]N<^%G86D`02!TX6)LX7IA="!T=6QA:F1O;G/A
M9V%I`%1A:G9A;@!486IV86X`5&%D>G-I:VES>G3A;@!486YZX6YI86D@16=Y
M97/\;'0@2VERX6QY<^%G`$$@8^EL.@!&96QA9&%T;VL`5&5L969O;G-ZX6T`
M07H@96QM^FQT(/-R82!H]6WI<G/I:VQE=&4Z(`!(]6WI<G/I:VQE=`!(]6WI
M<G/I:VQE=#H@`$CU;>ER<^EK;&5T/&)R("\^*"5S36%X)7,O)7--:6XE<RD@
M)F1E9SLE<P!!*'HI("(E<R(@<V%B;&]N(&YE;2!T86SA;&AA=/,N`%-A8FQO
M;F]K(&%D;6EN:7-Z=.%C:?-J80!3>O9V96<`8W-A:R!S>O9V96<`4WKV=F5G
M96QH96QY97KI<P!S>O9V96<@=&5T96IE`$-S_`!T:&%I("A425,M-C(P*0!4
M:&%I9O9L9`!!>B!F='`@8O5V[73I<R!N96T@=&%LX6QH873S+@!!($AI<W1O
M<GD@<F5N9'-Z97(@;?MK]F3I<V4@;FEN8W,@96YG963I;'EE>G9E+@!!($AO
M<F1E+TMO;&%B(&EN=&5G<N%C:?,@97IT(&YE;2!TX6UO9V%T:F$Z("(E<R(`
M07H@24U34"!N87!L\WKA<W0@;F5M('-I:V5R_&QT(&UE9VME>F1E;FDN`$$@
M36%I;G1E;F%N8V4Z.B!O<WITX6QY(&)E=/9L=.ES92!N96T@<VEK97+\;'0`
M07H@3W!C:?,@86)L86L@8F5ZX7)O9&]T="X@2VELZ7#I<R!K]G9E=&ME>FEK
M+@!!($IO9V]S=6QT<^%G;VL@:&%S>F[A;&%TX6YA:R!E;/5F96QTZ71E;&4L
M(&AO9WD@82!R96YD<WIE<F=A>F1A(&MO;F9I9W5RX6QJ;VX@96=Y(&$@:F]G
M;W-U;'1SX6=I(&%D871O:V%T('1A<G3S<V%N('3A<F]L;FD@:^EP97,@86QR
M96YD<WIE<G0N`$-S86L@86QU;"!L96=Y96X@:V5R970`02!P87)T;F5R(&%Z
M;VYO<^UT\W-ZX6UA(&YE;2!V;VQT(&UE9V%D=F$O_')E<V5N(&UA<F%D="!V
M86=Y(&%Z(&%D871BX7II<V)A;B!N96T@=F]L="!M96=T86SA;&AA=/,N`$$@
M<&%R=&YE<B!A9&%T86ET('-I:V5R97-E;B!H;WIZX6%D='5K(&$@8^UM:F5G
M>7KI:^EH97HN`$O\;/9NX6QL\R!01U`@86SA[7+A<VD@8FQO:VL@<WK\:W/I
M9V5S(&$@9&EG:73A;&ES86X@86SA[7)T(/QZ96YE="!H:71E;&5S<^EGZ6YE
M:R!E;&QE;O5R>NESZ6AE>BX`02!K]G)L97;I;&QI<W1A(&%Z;VYO<^UT\W-Z
MX6UA(&YE;2!V;VQT(&UE9V%D=F$O_')E<V5N(&UA<F%D="!V86=Y(&%Z(&%D
M871BX7II<V)A;B!N96T@=F]L="!M96=T86SA;&AA=/,N`$$@:_9R;&5VZ6QL
M:7-T82!N96T@=F]L="!M96=A9'9A+@!!('1I=&MO<^UTX7-I('-Z;VQGX6QT
M873A<V]K:&]Z(&)I>G1O;G/A9V]S("AT:71K;W/M=&]T="D@=V5B(&MA<&-S
M;VQA="!K96QL+@!!*'HI("5S(.%L;&]MX6YY8F%N('-Z97)E<&5L;FEE(&ME
M;&QE;F4@96=Y("5S(&)EX6QL[73A<VYA:RX`02AZ*2`E<R#A;&QO;>%N>6)A
M;B!S>F5R97!E;&YI92!K96QL96YE('9A;&%M:6QY96X@)7,@8F7A;&SM=.%S
M*&]K*6YA:RX`02!FX6IL(&YE;2!MX7-O;&AA=/,@]FYM86?A<F$N`$$@9N%J
M;&)A;B!N96T@=F]L="!A9&%T+@!!>B#\>F5N970@9F5J;.EC<V]R86D@82!K
M]G9E=&ME>O5K+@!!('1E;&IE<R!KZ7!E<FYY]7,@_'IE;6WS9"!P<F]B;.EM
MX6MA="!O:V]Z:&%T(&%Z($EN=&5R;F5T($5X<&QO<F5R(&AA<WINX6QA=&$@
M97-E=.EN+"!M97)T(&5B8F5N(&]L>6%N('!R;V=R86UH:6+A:R!V86YN86LL
M(&%M:6ME="!N96T@='5D='5N:R!M96=K97+\;&YI+B!!(&OI<&5R;GGU:F4@
M;VQV87-H871A=&QA;F[A(';A;&AA="P@8FEZ;VYY;W,@961I=&]R(&9U;FMC
M:?-K(&AIX6YY;WIH871N86L@Z7,O=F%G>2!VX7)A=&QA;G5L(&QE9F%G>6AA
M="!A(&+V;F?I<WKU<')O9W)A;2X@5VEN9&]W<R`Y>"!H87-Z;N%L871A(&5S
M973I;B!N86=Y;VX@=F%L\W-Z[6[[+"!H;V=Y("='96YE<F%L('!R;W1E8W1I
M;VX@9F%U;'0G(&AI8F$@;6EA='0@^FIR82!K96QL(&EN9.UT86YI82!M86ID
M(&$@9^EPZ70N7&Y<;D9I9WEE;&UE>G1E='3\:R$@2V%T=&EN='-O;B!A>B!/
M2R!G;VUB<F$L(&AA(&WI9VES(&UE9R!K[7;A;FIA(&OM<^ER96QN:2!A('1E
M;&IE<R!KZ7!E<FYY]7,@_'IE;6WS9&]T+@!!("(E<R(@87IO;F]S[73S="!K
M:73V<O9L=/QK+@!#<V%K(&)A;"!O;&1A;&]N(&QE9WEE;B!K97)E=`!!($=N
M=5!'('!R;V=R86T@:&5L>>ET(&UE9R!K96QL(&%D;FD@82!#<GEP=%]P9W`Z
M.B!O<WITX6QY(&AA<WINX6QA=.%H;WHN`$$@;&5VZ6PL(&UE;'EE="`E<R!N
M87!JX6X@:_QL9/9T="`E<R!C[6UZ971T;F5K("(E<R(@=.%R9WEB86XL(&$@
M8^UM>F5T="!S>N%M[73S9^EPZ6X@;65G:F5L96YT+B!!<G)A(&YI;F-S(&=A
M<F%N8VEA+"!H;V=Y(&5L(&ES(&]L=F%S=.%K(&EL;"X@:&]G>2!M96?I<G1E
M='3I:RX`36D@;&5G>65N(&$@;&5VZ6SM<O,@86)L86MH;WH@;75T873S(&QI
M;FL@96QN979E>NES90!!(&UE>O5K('-ZX6UA(&-S86L@;G5M97)I:W5S(.ER
M=.EK(&QE:&5T+@!!>B!O<&5N<W-L(&UO9'5L('-Z_&MSZ6=E<R!A($AO<F1E
M7T-R>7!T7W-M:6UE.CH@;W-Z=.%L>2!H87-Z;N%L873A:&]Z+@!!("(E<R(@
M<WIE;>EL>65S(&)EX6QL[73A<R!N96T@;65N=&AE=/4@96PL(&UE<G0@;>ER
M971E(&UE9VAA;&%D:F$@82!M96=E;F=E9&5T="!M87AI;75M;W0`3F5M('1A
M;.%L:&%T\R!A>B!A('!R;V=R86T@82!S>F5R=F5R96XL(&%M:2!S>OQK<^EG
M97,@96YN96L@87H@861A='3M<'5S;F%K("@E<RD@82!M96=J96QE;NUTZ7/I
M:&5Z+@!!>B!I9.EZ]6IE;"!K87)A:W1E<B!C<V%K(&5G>65T;&5N(&MA<F%K
M=&5R(&QE:&5T+@!*;V)B(.ES(&)A;"!O;&1A;&]N(&QE9WEE;B!K97)E=`!#
M<V%K(&IO8F(@;VQD86QO;B!L96=Y96X@:V5R970`07H@96QVX6QA<WIT\R!K
M87)A:W1E<B!C<V%K(&5G>65T;&5N(&MA<F%K=&5R(&QE:&5T+@!!*'HI("(E
M<R(@<WIE<G9E<G0@=/9R]FQT_&LN`$$H>BD@(B5S(B!S>F5R=F5R="!E;&UE
M;G1E='3\:RX`)7,@8F5J96QE;G1K97KI<VD@:^ER96QMZ70@=/9R]FQT_&LN
M`$$@;65G861O='0@<V]R("@E9"D@;F5M(&SI=&5Z:6LN`$$H>BD@(B5S(B!I
M9&5I9VQE;F5S(&;A:FP@;F5M(&SI=&5Z:6LN`$$@8F7M<G0@<WKV=F5G(&YE
M;2!E9WEE>FEK(&$@:^EP97)N>?5N(&QE=O5V96PN`$%L=6P@Z7,@9O9L_&P@
M;&5G>65N(&ME<F5T`$-S86L@9F5N="!L96=Y96X@:V5R970`02!F96QT]FQT
M]G1T(&%D871O:R!A>B!E;/5Z]2!LZ7#I<R#S=&$@96QV97-Z=&5K+@!!(&9E
M;'3V;'3V='0@9N%J;'0@;F5M('-I:V5R_&QT(&5L;65N=&5N:2X`02!W96%T
M:&5R+F-O;2!B;&]K:R!N96T@:&%S>F[A;&AA=/,N`$$@;65G:F5L96[I<VD@
M<W3M;'5S("AT:&5M97,I(&%L:_9N>79TX7(@(B5S(B!N96T@=&%LX6QH873S
M+@!.:6YC<V5N(';A;&%S>G1H873S(&]P8VGS+@!.:6YC<R!A(&QE=NEL(&)E
M;'-E:NEB96X@;65G:F5L96[M=&AE=/4@;65L;.EK;&5T+@!4^FP@<V]K(&MA
M<F%K=&5R('9A;B!E8F)E;B!A(&UE>O5B96XN(-9N("5S(&MA<F%K=&5R="!A
M9&]T="!M96<[(&$@;6%X:6WA;&ES86X@;65G861H873S('!E9&EG(&ME=F5S
M96)B+"!M:6YT("5S+@`B)7,B(&9E;&AA<WINX6SS;F%K(&$@<F5N9'-Z97)H
M97H@863A<V%K;W(@:&EB82!T]G)TZ6YT+B`E<P`B)7,B(&9E;&AA<WINX6SS
M(&%D871A:6YA:R!T]G)LZ7-E('-O<N%N(&AI8F$@;.EP971T(&9E;#H@`"(E
M<R(@<F5N9'-Z97)B]6P@=F%L\R!T]G)LZ7-E:V]R(&AI8F$@;.EP971T(&9E
M;#H@`"(E<R(@;?-D;W/M=.%S82!S;W+A;B!H:6)A(&SI<&5T="!F96PZ("5S
M`$%Z(.%L;&]MX6YY="!N96T@<VEK97+\;'0@82!S>F5R=F5R<F4@9F5L=/9L
M=&5N:2X@)7,@;F5M('3V;'3U9/9T="!F96PN`$%Z(.%L;&]MX6YY="!N96T@
M<VEK97+\;'0@82!S>F5R=F5R<F4@9F5L=/9L=&5N:2X@)7,@;F%G>6]B8BP@
M;6EN="!A(&UA>&EMX6QI<V%N(&UE9V5N9V5D971T(&WI<F5T("@E9"!BX6IT
M*2X`07H@X6QL;VWA;GET(&YE;2!S:6ME<OQL="!A('-Z97)V97)R92!F96QT
M]FQT96YI+B!!*'HI("5S(&;A:FQN86L@8W-A:R!E9WD@<NES>F4@=/9L=/5D
M]G1T(&;V;"X`02!L97;I;"!E('+I<WKI;F5K(&UE9VIE;&5N[73I<V5K;W(@
M:&EB82!T]G)TZ6YT`$$@<&%R=&YE<B!A9&%T;VL@:6UP;W)TX6SA<V$@<V]R
MX6X@:&EB82!T]G)TZ6YT+@!!>B!I0V%L96YD87(@861A=&]K(&EM<&]R=.%L
MX7-A('-O<N%N(&AI8F$@=/9R=.EN="X`2&EBX7,@82!M96=A9&]T="!K;VYF
M:6=U<N%C:?,N($QE:&5T+"!H;V=Y(&YE;2!T]FQT]G1T(&MI(&5G>2!S>OQK
M<^EG97,@;65Z]70N`$$@<&%R=&YE<FIE9WEZZ6MK96P@:V%P8W-O;&%T;W,@
M9F5L861A="!VZ6=R96AA:G3A<V$@<V]RX6X@:&EB82!LZ7!E='0@9F5L+B!+
MZ7)E;2!P<O-BX6QJ82!M96<@:^ES]6)B+@!(:6)A('3V<G3I;G0@82!P87)T
M;F5R(&%D871A:6YA:R!F<FES<^UTZ7-E('-O<N%N+B!+Z7)E;2!P<O-BX6QJ
M82!M96<@:^ES]6)B+@!!(&OV<FQE=NEL;&ES=&$@861A=&%I;F%K(&9R:7-S
M[73I<V4@<V]RX6X@:&EB82!T]G)TZ6YT+B!+Z7)E;2!P<O-BX6QJ82!M96<@
M:^ES]6)B+@!%>B!A>B!)34%0('-Z97)V97(@;F5M('3A;6]G871J82!A(&UA
M<'#A:VAO>B!V86SS(&AO>GKA9NERZ7,@;65G;W-Z=.%SX70N`$5Z(&YE;2!T
M^VYI:R!S>F%BX6QY;W,@<F%R(.%L;&]MX6YY;F%K+@!%>B!N96T@=/MN:6L@
M<WIA8N%L>6]S('II<"#A;&QO;>%N>6YA:RX`17H@;F5M('3[;FEK(.ER=NEN
M>65S(&OA<G1Y87-ZX6UN86LN`$5Z(&$@;65G:&%J=/,@;&5H973U=ND@=&5S
M>FDL(&AO9WD@2%144"UK87!C<V]L871O;B!335,M="!K_&QD:OQN:R!A($-L
M:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@<WIO;&?A;'1A=/-N
M(.%T+@!%>B!A(&UE9VAA:G3S(&QE:&5T]7;I('1E<WII+"!H;V=Y($A45%`M
M:V%P8W-O;&%T;VX@4TU3+70@:_QL9&K\;FL@82!724X@*&AT='`Z+R]W:6YP
M;&,N8V]M*2!S>F]L9^%L=&%T\VX@X70N`$5Z(&$@;65G:&%J=/,@;&5H973U
M=ND@=&5S>FDL(&AO9WD@2%144"UK87!C<V]L871O;B!335,M="!K_&QD:OQN
M:R!A>B!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!S>F]L9^%L
M=&%T\VX@X70N`$5Z(&$@;65G:&%J=/,@;&5H973U=ND@=&5S>FDL(&AO9WD@
M4TU44"UK87!C<V]L871O;B!335,M="!K_&QD:OQN:R!6;V1A9F]N92!S>N%M
M;VMR82!A(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="D@<WIO
M;&?A;'1A=/-N(.%T+B!!('-Z;VQGX6QT873A<R!I9^EN>6)E=NET96SI:&5Z
M(%9O9&%F;VYE($ET86QY(&5M86EL(&/M;2!S>OQK<^EG97,N`$5Z(&$@;65Z
M]2!N96T@;6%R861H870@_')E<RX`16)B96X@82!M97KU8F5N(&-S86L@96?I
M<WH@<WKA;6]K(.%L;&AA=&YA:RX`16)B96X@82!M97KU8F5N(&-S86L@96?I
M<WH@<WKA;6]K(.ES(&ME='3U<W!O;G0@;&5H970N`$5B8F5N(&$@;65Z]6)E
M;B!C<V%K(&]K=.%L:7,@<WKA;6]K(.%L;&AA=&YA:RX`17H@82!M97KU(&-S
M86L@=F5S<WKU=F5L('9A9WD@<WKS:_9Z>F5L(&5L=N%L87-Z=&]T="!E9^ES
M>B!S>N%M;VMA="!T87)T86QM87IH870`17H@87H@Z7)TZ6L@8W-A:R!S>N%M
M(&QE:&5T+@!%8F)E;B!A(&UE>O5B96X@:&5X861E8VEMX6QI<R!21T(@<WKM
M;FOS9"#A;&QH870L('!L+B`G(S$R,S1A9B<N`$5Z96X@861A=&]K:V%L(&MA
M<&-S;VQA=&]S(&9E;&%D871O:V%T(&$@<WIE<G9E<B!MX7(@96QVZ6=E>G1E
M+@!%>B`E<P!%>B!E9WD@2V]L86(@1W)O=7!W87)E(&]B:F5K='5M+B!!>B!I
M;'EE;B!O8FIE:W1U;2!M96=J96QE;NUTZ7/I:&5Z(&]L>6%N(&5M86EL(&ML
M:65N<W!R;V=R86T@<WK\:W/I9V5S+"!A;65L>2!KZ7!E<R!A($MO;&%B($=R
M;W5P=V%R92!F;W)MX71U;2!K97IE;.ESZ7)E+B!);'EE;B!E;6%I;"!K;&EE
M;G-E:R!L:7-TX6IA(&SA=&AA=/,@:71T.B`E<P!%>G0@82!L979E;&5T(&WA
M<R!K87)A:W1E<FOI<WIL971T96P@*"5S*2#M<G3A:RP@;6EN="!A;6ET(-9N
M(&AA<WINX6PN`$5Z(&$@<WKA;2!N96T@;&5H970@96=Y;NEL(&MI<V5B8BX`
M17H@82!S>F5R=F5R(&YE;2!KZ7!E<R!K:6)O;G1A;FD@82!Z:7`@:6QL+B!G
M>FEP(.%L;&]MX6YY;VMA="X`17H@82!R96YD<WIE<B!J96QE;FQE9R!I;F%K
M=&EVX6QV82!V86XN`$5Z(&%Z(.ER=.EK(&-S86L@<WKA;2!L96AE="X`17IT
M(&%Z(&%B;&%K(&-S86L@87H@3W!C:?-K(&%B;&%K8O-L(&CM=FAA=/,`5FEL
M;.%M;.%S`$AI8F%B96IE;&5N=.ES+6ME>F5LZ7,`263U`$UU;FMA:63U+6YY
M:6QVX6YT87)TX7,`263U(&9O<FWA='5M`$ED]2!VX6QA<WITX7,`2V5L970M
M5&EM;W(`5&ET=6QU<P!#[6T@*'1O;VQT:7`I`$/M;7IE='0`2&$@=/9B8B!E
M;&5M970@:7,@:VD@86MA<B!J96SV;&YI+"!T87)T<V$@;&5N>6]M=F$@82!#
M;VYT<F]L("A00RD@=F%G>2!A($-O;6UA;F0@*$UA8RD@8FEL;&5N='G[="!A
M(&MA='1I;G3A<R!K]GIB96XN`$UA`$A434P@9F]R<N%S;NEZ970@:VDO8F4`
M5&]G;P!4;VME;&%U`$AO;&YA<`!4;VYG80!F]FS\;`!,96=F96QS]2!F<F%M
M92`H7W1O<"D`1F]R9.UTX7-O:P!4<FEN:61A9"#I<R!4;V)A9V\`26=A>B!V
M86=Y(&AA;6ES`$ME`%1U;NEZ:6$`5/9R]FMO<G-ZX6<`=/9R]FL@*$E33RTX
M.#4Y+3DI`%3\<FMM96YI<WITX6X`5'5R:W,M(.ES($-A:6-O<RUS>FEG971E
M:P!4=79A;'4`S7)J82!B92P@;6ET(';A;&%S>G1O='0Z(`!55B!I;F1E>#H@
M`%523`!54DPL(&UE;'EE;B!E9WD@<')O9W)A;2!E;&9O9V%D:F$@82!S>F]L
M9^%L=&%T\R#A;'1A;"!K_&QD]G1T(&O\;&3V='0@:^EZ8F5S[73I<VD@:F5L
M96YTZ7-T`%523#H`56=A;F1A`%5K<F%J;F$`3F5M('-I:V5R_&QT(&$@5D93
M(&%L:_9N>73A<F)A(&)E;.EP;FDN`$$@8F5J96QE;G1K97KI<VD@:F]G;W-U
M;'1SX6<@:6?I;GELZ7-E:V]R(&YE;2!S:6ME<OQL="!A>B!A9&%T;VL@96QT
MX7)O;.%S82X`3F5M('-I:V5R_&QT(&$H>BD@(B5S(B!61E,@9N%J;"!E;.ER
MZ7-I(&IO9V]S=6QT<^%G86ET(&UE9W;A;'1O>G1A=&YI+@!.96T@<VEK97+\
M;'0@82AZ*2`E<R\E<R!61E,@9N%J;"!E;.ERZ7-I(&IO9V]S=6QT<^%G86ET
M(&UE9W;A;'1O>G1A=&YI+@!.96T@<VEK97+\;'0@82AZ*2`E<R!A;&OV;GEV
M=.%R8F$@8F5LZ7!N:2X`02AZ*2`B)7,B(.%L;&]MX6YY(&WI<F5T92!N96T@
MX6QL87#M=&AA=/,@;65G+@!!*'HI("(E<R\E<R(@X6QL;VWA;GD@;>ER971E
M(&YE;2#A;&QA<.UT:&%T\R!M96<N`$%Z(%-13"!S>F5R=F5R(&YE;2#I<FAE
M=/4@96PN`$%Z(%-33"!K87!C<V]L870@;F5M(.EP[71H973U(&9E;"X`02!6
M1E,@9N%J;"!N96T@;>%S;VQH873S(.%T+@!.96T@<VEK97+\;'0@82AZ*2`B
M)7,B(%9&4R!A;&OV;GEV=.%R="!LZ71R96AO>FYI+@!.96T@<VEK97+\;'0@
M;.ET<F5H;WIN:2!A(%9&4R!A;&OV;GEV=.%R="X`3F5M('-I:V5R_&QT(&SI
M=')E:&]Z;FD@82!61E,@9N%J;'0N`$$H>BD@(B5S(B!61E,@;6%P<&$@;F5M
M(&AO>FAA=/,@;.ET<F4N`$YE;2!S:6ME<OQL="!LZ71R96AO>FYI(/QR97,@
M5D93(&;A:FQT+@!!('3V;?9R[71E='0@X6QL;VWA;GET(&YE;2!S:6ME<OQL
M="!K:6)O;G1A;FDN`"(E<R(@;F5M('3V<O9L:&5T]2P@87H@86QK]FYY=G3A
M<B!N96T@_')E<RX`(B5S(B!T]G)LZ7-E(&YE;2!S:6ME<OQL=#H@)7,N`"5S
M(&YE;2!T]G+V;&AE=/4L(&%Z(&%L:_9N>79TX7(@;F5M(/QR97,N`$$@5D93
M(&%L:_9N>79TX7(@;F5M('3V<O9L:&5T]2!R96MU<GKM=F%N+@!!(%9&4R!A
M;&OV;GEV=.%R(&YE;2!T]G+V;&AE=/4N`$$@5D93(&%L:_9N>79TX7(@;F5M
M('3V<O9L:&5T]3H@)7,N`$$H>BD@(B5S(B!61E,@9N%J;"!N96T@=/9R]FQH
M973U+@!!(%9&4R!FX6IL(&YE;2!T]G+V;&AE=/4N`$$H>BD@(B5S(B!61E,@
M;6%P<&$@;F5M('3V<O9L:&5T]2X`3F5M(';I9V5Z:&5T\R!R96MU<GKM=B!T
M]G)LZ7,@82!61E,M8F5N.B`E<RX`3F5M(&AA=.%R;WIH873S(&UE9R!A(&IE
M;&5N;&5G(.ER=NEN>65S(&%L:_9N>73A<BX`02!T86[Z<^UT=N%N>2!RZ7-Z
M;&5T97,@861A=&%I(&YE;2!H873A<F]Z:&%T\VL@;65G`$YE;2!S:6ME<OQL
M="!B96]L=F%S;FD@)7,@9&5F:6[M8VGS:N%T+@!!(%9&4R!FX6IL(&YE;2!H
M96QY97IH973S(.%T+@!!*'HI("(E<R(@5D93(&;A:FP@;F5M(&YY:71H873S
M(&UE9RX`02!61E,@9N%J;"!N96T@;GEI=&AA=/,@;65G(.URX7-I(&/I;&QA
M;"X`02!61E,@9N%J;"!N96T@;GEI=&AA=/,@;65G("X`02!T]FWV<NUT971T
M(.%L;&]MX6YY(&YE;2!N>6ET:&%T\R!M96<N`$$@5D93(&;A:FP@;F5M(&]L
M=F%S:&%T\R`H82!F:6QE<VEZ92@I('-I:V5R=&5L96X@=F]L="DN`$$@5D93
M(&;A:FP@;F5M(&]L=F%S:&%T\R`H82!G971&:6QE4VEZ92@I('-I:V5R=&5L
M96X@=F]L="DN`$5Z(&$@9N%J;"!N96T@;VQV87-H873S.B``02!V9G-R;V]T
M(&%L:_9N>79TX7(@;F5M(&]L=F%S:&%T\RX`)7,@;F5M(&YE=F5Z:&5T]2#A
M="`E<R!NZ79R93H@;>%R(&SI=&5Z:6L@:6QY96X@;F5V^R!M87!P80!!(%9&
M4R!A;&OV;GEV=.%R(&YE;2!N979E>FAE=/4@X70N`$$@5D93(&%L:_9N>79T
MX7(@;F5M(&YE=F5Z:&5T]2#A=#H@)7,N`$$H>BD@(B5S(B!61E,@9N%J;"!N
M96T@;F5V97IH973U(.%T+@!!*'HI("5S+R5S(%9&4R!FX6IL(&YE;2!N979E
M>FAE=/4@X70N`$$@5D93(&;A:FP@;F5M(&YE=F5Z:&5T]2#A="X`07H@)VUK
M:7-O9G,G('!R;V=R86T@;F5M(&9U='1A=&AA=/,N`$YE;2!S:6ME<OQL="!L
M969O<F3M=&%N:2!E>G0@82!7;W)D(&1O:W5M96YT=6UO=`!!*'HI("(E<R(@
M5D93(&;A:FP@;F5M(.UR:&%T\RX`02!61E,@9N%J;"!N96T@[7)H873S("AA
M(&-O<'DH*2!S:6ME<G1E;&5N('9O;'0I+@!!(%9&4R!FX6IL(&%D871A:2!N
M96T@[7)H873S:R!K:2X`02!61E,@9N%J;"#M<N%S82!K=O-T873Z;&SI<.ES
M(&UI871T(&YE;2!F96IE>FAE=/4@8F4N`&%LX6CZ>F]T=`!-Z6=S92!M96YT
M<_QK(&5L`%9I<W-Z879O;FIA(&%Z('5T;VQS\R!VX6QT;WIT873A<W0`02!K
M87!C<V]L870@9F5L=NET96SI="!K]G9E=/5E;B!VX7)A=&QA;B!VX6QA<WH@
MZ7)K97IE='0@82!S>F5R=F5R=/5L.B``5N%R871L86X@=N%L87-Z(.ER:V5Z
M971T(&$@<WIE<G9E<G3U;"!E<G)E.B``0F5S;W)O;&%T;&%N`%5N:6-O9&4@
M*%541BTX*0!%9WEE<_QL="!!<F%B($5M[7)SZ6=E:P!%9WEE<_QL="!+:7+A
M;'ESX6<`16=Y97/\;'0@P6QL86UO:P!%9WEE<_QL="#!;&QA;6]K+"!K:7-E
M8F(@:_QL<_4@<WII9V5T96L`96=Y<^EG`$ES;65R971L96X`27-M97)E=&QE
M;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!)<VUE<F5T;&5N(&-L:6US
M9VED("A#;&EE;G0@365S<V%G92!)1"DN`$$@;65G861O='0@:&5L>2!I<VUE
M<F5T;&5N+@!)<VUE<F5T;&5N(&9E;&AA<WINX6SS:2!NZ78@=F%G>2!J96QS
M>O,N`%3A=F]L[71S=6L@96P@:6YN96X@82!L:6YK970`3FEN8W,@96QN979E
M>G9E`$)I>G1O;G/A9VD@;VMO:V+S;"!A(&9E;&AA<WINX6SS:2!P<F]G<F%M
M;VL@;F5M(&AA<WINX6QH871JX6L@82!+:7;A9^%S+TWA<V]LX7,O0F5I;&QE
M<WITZ7,@;?-D<WIE<G0N($MA='1I;G1S;VX@87H@3TL@9V]M8G)A+"!H82!A
M(&UO>FEL;&$N;W)G('=E8F]L9&%L;VX@96P@:^UVX6YJ82!O;'9A<VYI(&$@
M=&5C:&YI:V%I(&QE[7+A<W0@;65L>2!M96=A9&IA+"!H;V=Y86X@;&5H970@
M97IT(&WI9VES(&5N9V5DZ6QY97IN:2X`02!S>NUN('9I<W-Z8>%L;.UTX7-A
M`$YE;2!TX6UO9V%T;W1T(&5X=&5N>FGS`$WS9&]S[73A<P`E<R!A9&%T86EN
M86L@;?-D;W/M=.%S80!!(&9E;&AA<WINX6SS(&%D871A:6YA:R!M\V1O<^UT
MX7-A`"(E<R(@=N%L=&]ZX7-A:70@96QM96YT971T_&LN`$%Z('5P9W)A9&4@
M<')O9W)A;6]T('3V<O9L=/QK+@!&96QT]FQTZ7,`07H@]G-S>F5S(&%L:V%L
M;6%ZX7,@:V]N9FEG=7+A8VGS:N%T(&9E;'3V;'3V='3\:R!A('-Z97)V97)R
M92X`;&%T:6X@;F%G>6)E=/MK`&YA9WEB973[<R!R\VUA:2!S>N%M;VL`57)U
M9W5A>0!(87-Z;N%L:G5K(&$@:F5L96YL96=I=#H@)7,`2&%S>F[A;&IU;FL@
M4U-,+70`06MK;W(@:&%S>F[A;&IU:RP@:&$@87H@24U34"!S>F5R=F5R96X@
M;>%S(&$@8F5J96QE;G1K97KI<VD@;F5V_&YK+VIE;'-Z879U;FLN`$9E;&AA
M<WINX6SS:2!NZ78`)7,@9F5L:&%S>F[A;/,@;F5M(&IO9V]S=6QT("5S+7)E
M+@!&96QH87-Z;N%L\VL@861M:6YI<WIT<N%LX7-A`$9E;&AA<WINX6SS:2!B
M9>%L;.UTX7-O:P!"96IE;&5N=&ME>NES(&IO9V]S=6QT<^%G(&EGZ6YY;.ES
M90!%>F5N(&$@<F5N9'-Z97)E;B!N:6YC<R!E;F=E9.EL>65Z=F4@87H@^FH@
M9F5L:&%S>F[A;/-K(&)E:F5L96YT:V5ZZ7-I(&IO9V]S=6QT<^%GX6YA:R!I
M9^EN>6SI<V4N`$%Z(&9E;&AA<WINX6SS:2!A>F]N;W/M=/,@;F5M('1A;.%L
M:&%T\P!&96QH87-Z;N%L\VD@;NEV`$$H>BD@(B5S(B!F96QH87-Z;N%L\VD@
M;NEV(&WA<B!LZ71E>FEK+@!&96QH87-Z;N%L\VD@;NEV.@!&96QH87-Z;N%L
M\VD@;NEV.B``02!R96YD<WIE<B!F96QH87-Z;N%L\VDZ`-QZ8F5G:7-Z=.%N
M`$$@5D93(&%L:_9N>79TX7(@;F5M(&SI=&5Z:6LN`%-Z86)A9'/A9R!A;&%T
M=&D@875T;VUA=&EK=7,@96UA:6PM=N%L87-Z`$$@:_9V971K97KU(&AE;'EE
M:V5T('1A;.%L='5K.B``R7)VZ6YY97-SZ6<`07H@Z7)TZ6ME:V5T('!E<F-B
M96X@861J=6L@;65G+"!M;W-T86YT\VP@<WKA;>UT=F$N`$$@Z7)TZ6L@;F%G
M>6]B8BP@;6EN="!A(&QE9VYA9WEO8F(@;65G96YG961E='0@:&]S<WKZ<^%G
M.B`E<RX`R7)TZ6ME:P!6X6QA<WIT:&%T\R#I<G3I:V5K`%9A;G5A='4`=N%L
M=&]Z\P!696YE>G5E;&$`02!H:71E;&5S[73I<R!N96T@<VEK97+\;'0@+2!L
M96AE="P@:&]G>2!A(&QE=F5L970@=F%L86MI(&UE9W;A;'1O>G1A='1A+@!6
M97)Z:?,`5F5R>FGS:_9V973I<P!&_&=G+B!E;&AE;'EE>NES`$;\9V?U;&5G
M97,@8F5L<_4@;6%R9_,`9OQG9_5L96=E<SH`;F%G>6]N(&UA9V%S`%9I971N
M86T`=FEE=&YA;6D@*%9)4T-)22D`)7,@;65G=&5K:6YTZ7-E`$O\;'/U('=E
M8F]L9&%L(&UE9VIE;&5N[73I<V4`2F5L96[M='/\:R!M96<L(&UI;G0@)7,`
M0G)I="!6:7)G:6XM<WII9V5T96L`06UE<FEK86D@5FER9VEN+7-Z:6=E=&5K
M`$SA=/-TX79O;'/A9P!,X73S=.%V;VQSX6<Z(`!6;V1A9F]N92!)=&%L>2!S
M>F]L9^%L=&%TX7,@4TU44"UN(&ME<F5S>G3\;`!&24=914Q-15I4153)4P!&
M24=914Q-15I4153)4R$@2\E:6D5,(%3!5D],S51302!%3"!!(%-#4DE05$54
M("5S+5+53"X`5TE.('-Z;VQGX6QT873A<R!(5%10+6X@X70`5V%L;&ES(.ES
M($9U='5N80!&:6=Y96QM97IT973I<P!3>F4`263U:N%RX7,@96SU<F5J96QZ
MZ7,`07H@:63U:N%RX7-I(&%D871O:R!F;W)RX7-A`%=E8@!796)H96QY96L`
M:&5T96YT90#<9';V>O9L:OQK`-QD=O9Z]FQJ_&LZ("5S`-QD=O9Z]FQJ_&LL
M("5S`&YY=6=A="UE=7+S<&%I("A)4T\M.#@U.2TQ*0!N>75G870M975R\W!A
M:2`H25-/+3@X-3DM,34I`$YY=6=A="U3>F%H87)A`$UI;'EE;B!A;&MA;&UA
M>N%S="!M=71A<W-O;B`E<R!A(&)E:F5L96YT:V5ZZ7,@=73A;C\`36D@87H@
M96QVX6QA<WIT\R!K87)A:W1E<C\`36D@87H@:63I>F5T:V%R86MT97(_`%=H
M97)E:7,@075S>G1RX6QI82!TZ7)KZ7``365L>6EK(&-I:VQU<P!-96QY:6L@
M;6]D=6QO:V%T(&%K=&EVX6QJ=6L@82!2:6-H(%1E>'0@961I=&]R8F%N/P!3
M>NEL97-SZ6<`4WKI;&5S<^EG($-34R!E9WESZ6=B96X`02`E<R!M96[\('-Z
MZ6QE<W/I9V4@82!B86P@;VQD86QO;B`H82!K]G9E=&ME>O4@8F5J96QE;G1K
M97KI<W0@:_9V973U96X@;&5S>B#I<G;I;GEE<RD`02!TX6)LX7IA="!S>NEL
M97-SZ6=E`$$@<WKI;&5S<^EG(&WI<G3I:V5G>7/I9V4`4WKI;&5S<^EG.@!7
M:6MI`%-ZZ6P`4WKI;"!A(')E9V=E;&D@\W+A:V)A;@!3>NEL<V5B97-SZ6<@
M8W-O;?-B86X`4WKI;#H`4WKI;#H@`$+V;&-S97-SZ6<`2^UVX6YSX6=L:7-T
M80!-=6YK80!-=6YK86AE;'EI(&/M;0!-=6YK86AE;'EI('1E;&5F;VX`02`E
M9"X@<V]R8F%N(&YE;2!M96=F96QE;/4@82!M97KU:R!S>N%M82X@5N%R=#H@
M)60L('1A;.%L=#H@)60N`$YE;2!M96=F96QE;/4@82!M97KU:R!S>N%M82X@
M5N%R=#H@)60L('1A;.%L=#H@)60N`$AI8N%S(&]F9G-E="`H)60I(&$@5D93
M(&;A:FP@;VQV87/A<V%K;W(N`$QI;G5X(&9O<G+A<VOS9"!K97)E<WIR969E
M<F5N8VEA`%@U,#EV,R!A;&%P=F5T]2!K;W)LX71O>N%S;VL`6#4P.78S(&MI
M=&5R:F5S>G1E='0@:W5L8W-H87-Z;N%L870`6#4P.78S('1U;&%J9&]N;W,@
M86QT97)N873M=B!M96=N979E>NES90!8-3`Y=C,@='5L86ID;VYO<R!K=6QC
M<V%Z;VYO<^UT\P!8-3`Y=C,@:VET97)J97-Z=.ES96L`65D`65E960!986AO
M;R$@=.ER:^EP`.EV96YT90!*96UE;@!)9V5N`$EG96XL(&)E;&5G>65Z96TN
M`$UO<W0@2%1-3"!415A4(&WS9&)A;B!V86XN($AA<WINX6QJ82!A(%L\/ET@
M9V]M8F]T+"!H82!V:7-S>F$@86MA<B!VX6QT86YI(&$@<WIO:^%S;W,@9W)A
M9FEK=7,@*%=94TE764<I(&UE9VIE;&5N[73I<W)E+@!.96T@:&]Z:&%T(&SI
M=')E("5D(&)L;VMK;N%L('3V8F)E="X`07H@UFX@9F5L:&%S>F[A;/-A>F]N
M;W/M=.%S82!N96T@=/9R=.EN="!M96<N`$$@=&5L:F5S(&[I=F)E;B!N96T@
M<WIE<F5P96QH970@82`G7"<@:V%R86MT97(N`$YE;2!A9&]T="!M96<@Z7)V
MZ6YY97,@96UA:6P@8^UM970N`$YE;2!A9'1A(&UE9R!A(&UE9V9E;&5L=&5T
MZ7-T(&%Z(&EM<&]R=.%L="!FX6IL(.ES(&$H>BD@)7,@;65Z]6D@:_9Z]G1T
M+@!3:6ME<F5S96X@:VEJ96QE;G1K97IE='0N`$5G>2!M;V)I;'1E;&5F;VYS
M>N%M;W0@:V5L;"!M96=A9&YI82P@8W-A:R!A('-ZX6UJ96=Y96ME="P@97-E
M=&QE9R!E9WD@)RLG(&MA<F%K=&5R<F5L(&ME>F1V92P@:&$@;F5M>F5T:_9Z
M:2!TX7)C<^%ZX7-I(&WS9&]T(&OM=N%N(&AA<WINX6QN:2X`16QF;V=A9&AA
M=/,@Z7)TZ6ME="!K96QL(&UE9V%D;FEA+@!!($1A=&%4<F5E(&%L<F5N9'-Z
M97)T(&)E(&ME;&P@X6QL[71A;FD@82!B96IE;&5N=&ME>NES:2!J;V=O<W5L
M='/A9V]K(&EGZ6YY;.ESZ6AE>BX`02!61E,@86QR96YD<WIE<B!N:6YC<R!B
M9>%L;.UT=F$N`$5L]6)B(&QE(&ME;&P@[7)N:6$L(&AO9WD@;6EL>65N('!R
M;V)LZ6WA="!T87!A<WIT86QT+"!M:65L]71T(&5L:_QL9&D@82!H:6)A:F5L
M96YTZ7-T+@!-96<@:V5L;"!A9&YI(&5G>2!54DPM="P@86AO=F$@97H@82!L
M:6YK(&UU=&%T`$MI(&ME;&P@=N%L87-Z=&%N:2!E9WD@=/9R;&5N9/4@<WIE
M<G9E<G0N`$UE9R!K96QL(&%D;FEA+"!H;V=Y(&UE;'EI:R!F96QH87-Z;N%L
M\R!A9&%T86ET(&OM=N%N:F$@=/9R]FQN:2X`365G(&ME;&P@861N:6$@87H@
M96QTX79O;.UT86YD\R!F96QH87-Z;N%L\VD@;F5V970N`$UE9R!K96QL(&%D
M;FEA(&$@:&]Z>N%A9&%N9/,@9F5L:&%S>F[A;/,@;F5VZ70N`$UE9R!K96QL
M(&%D;FEA+"!H;V=Y(&UE;'EI:R!F96QH87-Z;N%L\R!A9&%T86ET(&OM=N%N
M:F$@X73M<FYI+@!-96<@:V5L;"!A9&YI82!E9WD@<&%R86YC<V]T+@!-96<@
M:V5L;"!A9&YI82!A>B#Z:B!K871E9_-R:6$@;F5VZ70N`$]L87-Z;W)S>N%G
M:2!T96QE9F]N<WKA;6]T(&ME;&P@;65G861N:6$`07H@UFX@)7,@:V%P8W-O
M;&%T82!I9/5T^FQLZ7#I<R!M:6%T="!M96=S>F%K861T+B!+Z7)E;2!J96QE
M;G1K97IZ96X@8F4@^FIR82X`07H@UFX@96UA:6P@8^UM90!!>B#6;B!F96QA
M9/-I("A&<F]M.BD@8^UM93H`4WIE;>EL>65S(&EN9F]R;>%C:?,`07H@UFX@
M)7,@:V%P8W-O;&%TX6YA:R!K97ID971E(/-T82!M96=VX6QT;WIO='0@87H@
M:6YT97)N970@8^UM92X@0FEZ=&]N<^%GX6YA:R#I<F1E:^EB96X@:7-MZ70@
M8F4@:V5L;"!J96QE;G1K97IN:64N`$%Z(-9N(&YE=F4`07H@UFX@9F5L:&%S
M>F[A;/-A>F]N;W/M=/,@86QR96YD<WIE<F4@;F5M('1E<WII(&QE:&5T]7;I
M(&%Z(/IJ(&9E;&AA<WINX6SS:R!LZ71R96AO>N%SX70N($AA(&$@2&]R9&4@
M<F5N9'-Z97)R96P@:^UVX6YJ82!K97IE;&YI(&$@9F5L:&%S>F[A;/-I(&%D
M871O:V%T+"!A:VMO<B!MX7-I:R!F96QH87-Z;N%L\V%Z;VYO<^UT\R!A;')E
M;F1S>F5R<F4@=F%N('-Z_&MSZ6=E+@!!>B#6;B!F96QH87-Z;N%L\V%Z;VYO
M<^UT\R!A;')E;F1S>F5R92!N96T@=&5S>FD@;&5H973U=ND@82!F96QH87-Z
M;N%L\VL@;&ES=.%ZX7/A="P@=F%G>2!V86QA;6D@;VMB\VP@;&5T:6QT;W1T
MX6L@97IT(&$@;&5H973U<^EG970N`$%Z(-9N(&+V;F?I<WKU<')O9W)A;6IA
M(&UE9W;A;'1O>F]T="!A>B#6;B`E<R!M=6YK86MA<&-S;VQA=.%N86L@:V5Z
M9&5T92#S=&$N($)I>G1O;G/A9V$@Z7)D96OI8F5N(&ES;>ET(&)E(&ME;&P@
M:F5L96YT:V5Z;FEE+@!!>B#6;B!B]FYGZ7-Z]7!R;V=R86UJ82!N96T@=.%M
M;V=A=&IA(&5Z="!A(&QE:&5T]7/I9V5T+@!!>B#6;B!B]FYGZ7-Z]7!R;V=R
M86UJ82!N96T@=.%M;V=A=&IA(&5Z="!A(&YY;VUT873A<VD@;W!C:?-T+B!0
M<O-BX6QJ;VX@82!#=')L+5`@*'9A9WD@0V]M;6%N9"U0*2!L96YY;VWA<^%V
M86P@;GEO;71A=&YI+@!!(&IE;&5N;&5G(.ER=NEN>65S(&ED]7KS;F$Z`$%Z
M(-9N(&%L87#I<G1E;&UE>NES('-Z97)I;G1I(&%Z;VYO<^UT\VIA(&UE9W;A
M;'1O>F]T="X`07H@UFX@86QA<.ER=&5L;65ZZ7,@<WIE<FEN=&D@87IO;F]S
M[73S:F$Z`$%Z(-9N('1E;&IE<R!N979E.@!,96KA<G0@82!B96IE;&5N=&ME
M>NES:2!J;V=O<W5L='/A9V$N`$%Z(-9N("5S+7)E(&AA<WINX6QT(/IJ(&IE
M;'-Z879A.B`E<P!!>B#6;B#Z:B!B9>%L;.UTX7-A:70@Z7)VZ6YY97/M=&5T
M=/QK(&$@;6]S=&%N:2!B96IE;&5N=&ME>NES(&ED96KI<F4N`$%Z(-9N(/IJ
M(&)EX6QL[73A<V%I="!E;&UE;G1E='3\:RX`07H@UFX@:F5L<WIA=N%T(.%T
MX6QL[71O='1U:P!!>B#6;B!J96QS>F%VX70@X73A;&SM=&]T='5K+"!NZ7IZ
M92!M96<@82!L979E;&5I="P@;6%J9"!J96QE;G1K97IZ96X@8F4@87H@^FH@
M:F5L<WKS=F%L+@!!>B#6;B!J96QS>F%VX6YA:R!L96KA<G0@87H@Z7)VZ6YY
M97-SZ6=I(&ED96IE+@!!>B#6;B#A;'1A;"!H87-Z;N%L="!TX79O;&D@<WIE
M<G9E<F5K.@!*=6=O<WILX79I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6TYE
M(&UU=&%S<W5K(&$@8F5I9.EZ971T('-Z]G9E9V5T70!;2&EB86IE;&5N=.ES
M70!;375T87-S=6L@82!B96EDZ7IE='0@<WKV=F5G970@+0!;375T87-S=6L@
M82!B96EDZ7IE='0@<WKV=F5G970@+2`E<R!S;W)=`%LE<R\E<R!S;W)=`%]!
M9&UI;FES>G1RX6-I\P!?4&%R86YC<W-O<@!3;W)T]G)LZ7,`7T-S;W!O<G1O
M:P!395]G[71SZ6<`02!KZ7`@='5L86ID;VYSX6=A:2XN+@!"96IE;&5N=&ME
M>NES`%]+:6IE;&5N=&ME>NES`$$@;&EN:R!M\V1O<^UTX7-A+BXN`%]/<&-I
M\VL`7TIO9V]S=6QT<^%G;VL`02!L:6YK('3V<FSI<V4N+BX`7T)EX6QL[73A
M<V]K`%3A8FSA>F%T('1U;&%J9&]N<^%G;VL`7T9E;&AA<WINX6SS:P!C[6UJ
M96=Y>NEK`&$@8^UM>F5T="!I<VUE<F5T;&5N`&YA<'3A<@!N>75G;V1T`&$@
M:VEM96YE=&D@X6QL;VWA;GD@;F5M(&AO>FAA=/,@;.ET<F4`82!B96UE;O4@
MX6QL;VWA;GD@;F5M(&YY:71H873S(&UE9P!K871T:6YT<V]N(&ED90!P87)A
M;F-S<V]R:2!H:6)A`&MO;F9I9W5RX6-I\W,@:&EB80!H:>%N>7II:R!E9WD@
M9F]N=&]S(')E;F1S>F5RX6QL;VWA;GD`861A=&9O<FWA='5M(&AI8F$`;?-D
M;W/M=.%S`&%Z(&%D870@;F5M('1A;.%L:&%T\P!C<_9K:V5N`&;A:FP`)7,@
M*"5S*2!I<N%N>6+S;"P@)7,@)7,@<V5B97-SZ6=G96P`<WKI;&SV:^ES96L`
M;3H`82!GZ7`@;F5V92!N96T@:7-M97)T`&%Z;VYN86QI`&EN<'5T+V]U='!U
M="!H:6)A`&)E;'/U('!R;V=R86UH:6)A`'-O<ET`07H@;6MS:6]F<R!P<F]G
M<F%M("5D(&AI8F%K\V1D86P@;&7A;&QT(&%Z($E33R#A;&QO;>%N>2!KZ7-Z
M[73I<V4@:_9Z8F5N+@!NZ78`02!P<F]G<F%M;F%K(&5Z(&$@<NES>F4@;>EG
M(&YI;F-S(&UE9W9A;/-S[71V82X`02!P<F]G<F%M;F%K(&5Z(&$@<NES>F4@
M;>EG(&YI;F-S(&UE9W9A;/-S[71V82X`:F5G>7IE='3V;6(`<WKA>F%LZ6L`
M;FEN8W,@;65G9F5L96SU(&IO9V]S=6QT<^%G80!P:7AE;`!A9&%TX71V:71E
M;&D@*'!R;W1O:V]L;"D@:&EB80!E;65L:V5D:6L`82!S>F]L9^%L=&%TX7,@
M;F5M(.%L;"!R96YD96QK97KI<W)E`&[I>GK\:R!M96<@82!K_&SV;F)SZ6=E
M:V5T`'-M<S)E;6%I;"!S>F]L9^%L=&%TX7,@2%144"UN(.%T`';A;'1O>F%T
M;&%N`')E;F1S>F5R:&EB80!F96QA9&%T;&ES=&$`X71M96YE=&D@:&EB80!M
M96=E<O5S[73I<VOI;G0@:^ET<WIE<B#M<FIA(&)E(&$@:F5L<WKS=`!NZ78@
M;NEL:_QL`&$@9F5L:&%S>F[A;/,@X6QT86P@=N%L87-Z=&AA=/,`=D-A<F0`
M<WHZ````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O:61?240O````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-3$U-#,S-S4S`#`R,#`V-0`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L
M92]I9%])1"],0U]-15-304=%4R\`````````````````````````````````
M````````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-3,`,#(Q-C4R`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&]C86QE+VED7TE$+TQ#7TU%4U-!1T53+VAO<F1E+FUO
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$V-#`Q-@`Q,#4Q-30S,S<U,P`P
M,C,S,C``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````WA($E0````!U`P``'````,0;``"=!```;#<```````#@20``!````.%)
M```D````YDD``"D````+2@``&0```#5*```F````3TH```P```!V2@``)```
M`(-*```/````J$H```L```"X2@``*````,1*```(````[4H``!4```#V2@``
M"P````Q+``"%````&$L```H```">2P``#@```*E+```/````N$L``!@```#(
M2P``#@```.%+```.````\$L```@```#_2P``+@````A,```)````-TP```T`
M``!!3```!P```$],```*````5TP```\```!B3```!0```'),```1````>$P`
M``@```"*3```"0```)-,```)````G4P``!,```"G3```$````+M,```*````
MS$P```,```#73```#P```-M,```)````ZTP```T```#U3```#P````--```/
M````$TT```@````C30``)````"Q-```(````44T``!D```!:30``#````'1-
M```.````@4T```,```"030``!0```)1-```*````FDT```,```"E30``%P``
M`*E-```*````P4T```X```#,30``(P```-M-```4````_TT``!<````43@``
M%P```"Q.```7````1$X``!,```!<3@``#P```'!.```&````@$X```L```"'
M3@``$````)-.```5````I$X``!4```"Z3@``!P```-!.```%````V$X``!4`
M``#>3@``.P```/1.```4````,$\```,```!%3P``"0```$E/```Y````4T\`
M`"<```"-3P``+````+5/```J````XD\``"4````-4```!@```#-0```1````
M.E````P```!,4```"@```%E0```0````9%```!0```!U4```"````(I0```.
M````DU````H```"B4```!````*U0```)````LE````8```"\4```$0```,-0
M```'````U5````0```#=4```!@```.)0```-````Z5````,```#W4```$P``
M`/M0```(````#U$```0````840``00```!U1```&````7U$``!4```!F40``
M!P```'Q1```5````A%$```\```":40``#0```*I1```/````N%$```T```#(
M40``%````-91```&````ZU$``!T```#R40``!@```!!2```4````%U(``%0`
M```L4@``9````(%2```$````YE(```X```#K4@``&P```/I2```:````%E,`
M`!P````Q4P``*@```$Y3```%````>5,``!,```!_4P``$@```)-3```*````
MIE,```\```"Q4P``#0```,%3```1````SU,```P```#A4P``!@```.Y3```,
M````]5,```8````"5```$`````E4```1````&E0```4````L5```#````#)4
M```%````/U0```8```!%5```!P```$Q4```-````5%0```D```!B5```"0``
M`&Q4```*````=E0``!D```"!5```'0```)M4```,````N50``!````#&5```
M"````-=4```(````X%0```8```#I5```!````/!4```.````]50``!T````$
M50``(````")5``"B````0U4``!\```#F50``(`````96```P````)U8``)(`
M``!85@``00```.M6```'````+5<```8````U5P``#0```#Q7```0````2E<`
M``P```!;5P``#@```&A7```/````=U<``!,```"'5P``#0```)M7```H````
MJ5<```,```#25P``#0```-97```1````Y%<``!<```#V5P``&P````Y8```"
M````*E@``!`````M6```#0```#Y8```#````3%@```X```!06```"````%]8
M```/````:%@```\```!X6```!P```(A8```-````D%@```T```">6```"P``
M`*Q8```&````N%@```L```"_6```#````,M8```+````V%@```T```#D6```
M(@```/)8```*````%5D``!@````@60``&0```#E9```6````4UD``!0```!J
M60``"P```']9```+````BUD```D```"760``&0```*%9```+````NUD``!<`
M``#'60``%P```-]9```)````]UD``!8````!6@``#P```!A:```9````*%H`
M`!8```!"6@``)@```%E:``!#````@%H``!\```#$6@``+P```.1:```%````
M%%L```0````:6P``"@```!];```*````*EL``!`````U6P``%P```$9;```1
M````7EL``!<```!P6P``"0```(A;```*````DEL```(```"=6P``#0```*!;
M```X````KEL``"````#G6P``#@````A<``![````%UP``!@```"37```!0``
M`*Q<```;````LEP```8```#.7```$````-5<```/````YEP``!````#V7```
M#P````==```/````%UT```P````G70``#P```#1=```'````1%T```X```!,
M70``"````%M=```3````9%T```0```!X70``!0```'U=```(````@UT```H`
M``",70``#````)==```+````I%T``!````"P70``#````,%=```'````SET`
M``H```#670``#0```.%=```%````[UT```,```#U70``"@```/E=```$````
M!%X``"8````)7@``#@```#!>``!\````/UX``!4```"\7@``!0```-)>```'
M````V%X```P```#@7@``"````.U>```*````]EX```8````!7P``"`````A?
M```"````$5\```8````47P``"0```!M?```0````)5\```D````V7P``"0``
M`$!?```:````2E\```@```!E7P``&0```&Y?```.````B%\```(```"77P``
M!@```)I?```-````H5\``!(```"O7P``%````,)?```&````UU\``!$```#>
M7P``"0```/!?```Y````^E\``#T````T8```.@```')@```$````K6```!4`
M``"R8```!@```,A@```$````SV```!$```#48```"@```.9@```B````\6``
M``0````480``!0```!EA```.````'V$```4````N80``#P```#1A```2````
M1&$```L```!780``)@```&-A```I````BF$``"0```"T80``)@```-EA```(
M`````&(```H````)8@``"0```!1B```2````'F(```H````Q8@``#````#QB
M```/````26(``!````!98@``<````&IB```.````VV(```D```#J8@``"@``
M`/1B```2````_V(``!,````28P``!@```"9C```/````+6,``!(````]8P``
M$````%!C```1````86,``&H```!S8P``#P```-YC```0````[F,```L```#_
M8P``(`````MD```4````+&0```P```!!9```#````$YD```/````6V0``!4`
M``!K9```*0```(%D```J````JV0``"8```#69```)P```/UD```I````)64`
M`"H```!/90``&0```'IE``!"````E&4``!$```#790``$@```.EE```3````
M_&4``!0````09@``%@```"5F```7````/&8``!````!49@``$0```&5F```T
M````=V8``!,```"L9@``$@```,!F```4````TV8``!H```#H9@``"0````-G
M```1````#6<```8````?9P``!P```"9G```6````+F<```0```!%9P``!```
M`$IG```'````3V<```X```!79P``#````&9G```,````<V<```T```"`9P``
M#@```(YG```$````G6<```\```"B9P``!P```+)G```(````NF<```D```##
M9P``%````,UG```,````XF<```T```#O9P```P```/UG```&`````6@``!D`
M```(:```!````")H```-````)V@```H````U:```$````$!H```/````46@`
M`!$```!A:```%P```'-H```*````BV@``!$```"6:```"````*AH```/````
ML6@```P```#!:```#@```,YH```0````W6@```L```#N:```&@```/IH```*
M````%6D```P````@:0``#P```"UI```(````/6D```8```!&:0``!P```$UI
M```%````56D```L```!;:0``!````&=I```#````;&D``!,```!P:0``$P``
M`(1I```3````F&D```(```"L:0``!````*]I```%````M&D```0```"Z:0``
M"@```+]I```-````RFD``&@```#8:0``!0```$%J```&````1VH```\```!.
M:@``&````%YJ```7````=VH``!\```"/:@```P```*]J```(````LVH```<`
M``"\:@``"@```,1J```+````SVH```T```#;:@``&@```.EJ``!*````!&L`
M``8```!/:P``!@```%9K```8````76L``!<```!V:P``#0```(YK``!7````
MG&L```(```#T:P``"P```/=K```(`````VP```H````,;```"P```!=L```,
M````(VP```T````P;```#````#YL```*````2VP``!8```!6;```"0```&UL
M```0````=VP``!(```"(;```!P```)ML```%````HVP```P```"I;```"```
M`+9L```7````OVP```P```#7;```&@```.1L```3````_VP```0````3;0``
M"@```!AM```$````(VT```4````H;0``.````"YM```*````9VT```\```!R
M;0``$P```()M```5````EFT``!,```"L;0``"````,!M```(````R6T``"L`
M``#2;0``10```/YM``!!````1&X```0```"&;@``$P```(MN```4````GVX`
M`!,```"T;@``!P```,AN```%````T&X``!L```#6;@``"````/)N```1````
M^VX```X````-;P```@```!QO```.````'V\```<````N;P``#@```#9O```&
M````16\``"@```!,;P``#````'5O```<````@F\``!<```"?;P``7````+=O
M```4````%'```!\````I<```$````$EP```'````6G````X```!B<```#```
M`'%P```*````?G```!T```")<```&0```*=P```%````P7```!$```#'<```
M$0```-EP```(````ZW````D```#T<```#0```/YP```*````#'$```<````7
M<0``#P```!]Q```&````+W$```L````V<0``&@```$)Q```*````77$```<`
M``!H<0``#0```'!Q```(````?G$``!X```"'<0``"0```*9Q```*````L'$`
M`!4```"[<0``!0```-%Q```4````UW$```0```#L<0``$````/%Q```&````
M`G(```<````)<@``'@```!%R```H````,'(``!P```!9<@``&@```'9R```4
M````D7(```0```"F<@``!@```*MR```&````LG(```H```"Y<@``&P```,1R
M```T````X'(``#0````5<P``*0```$IS```H````=',``"D```"=<P``4```
M`,=S```(````&'0```4````A=```&0```"=T```9````070``",```!;=```
M&0```']T```(````F70``!<```"B=```"@```+IT```'````Q70``"$```#-
M=```#@```.]T```3````_G0```@````2=0``!0```!MU```%````(74```0`
M```G=0``"@```"QU```)````-W4```L```!!=0``#0```$UU```,````6W4`
M``X```!H=0``!````'=U```R````?'4``$4```"O=0``%P```/5U```>````
M#78``!0````L=@``!P```$%V```.````278``"H```!8=@``!@```(-V```,
M````BG8``!$```"7=@``"P```*EV```V````M78```H```#L=@``(@```/=V
M```+````&G<```\````F=P``!0```#9W```.````/'<``!,```!+=P``!P``
M`%]W```1````9W<``!,```!Y=P``%````(UW```8````HG<```<```"[=P``
M!0```,-W```2````R7<```X```#<=P``#@```.MW```%````^G<```4`````
M>```+@````9X```F````-7@``",```!<>````P```(!X```-````A'@```D`
M``"2>````P```)QX```*````H'@```(```"K>```$@```*YX```$````P7@`
M``<```#&>```#````,YX``!2````VW@``!<````N>0``$@```$9Y```'````
M67D```8```!A>0``#@```&AY```5````=WD``!(```"->0``#P```*!Y```4
M````L'D``&D```#%>0``&@```"]Z```7````2GH``"<```!B>@``&@```(IZ
M```7````I7H``!L```"]>@``&0```-EZ```?````\WH``!,````3>P``"```
M`"=[```)````,'L``$8````Z>P``/P```(%[```W````P7L``%<```#Y>P``
M!0```%%\```?````5WP``"\```!W?```"````*=\```-````L'P``"T```"^
M?```!````.Q\``!/````\7P``"4```!!?0``'P```&=]```=````AWT``"4`
M``"E?0``(````,M]```D````['T``"`````1?@``!P```#)^```-````.GX`
M``P```!(?@``%P```%5^```0````;7X```0```!^?@``"P```(-^```,````
MCWX``!(```"<?@``$0```*]^```,````P7X``!H```#.?@``#0```.E^```;
M````]WX``!,````3?P``'````"=_```H````1'\```<```!M?P``$P```'5_
M```$````B7\``!<```".?P``"@```*9_```,````L7\```D```"^?P``!@``
M`,A_```(````SW\```D```#8?P``!@```.)_```-````Z7\```L```#W?P``
M`@````.````)````!H````<````0@```&@```!B````[````,X```"@```!O
M@```-````)B````5````S8````<```#C@```"````.N````'````](````4`
M``#\@```!P````*!```.````"H$```D````9@0``!@```".!```(````*H$`
M``L````S@0``!P```#^!```'````1X$``!$```!/@0``"````&&!```0````
M:H$``!````![@0``!P```(R!```%````E($``!0```":@0``"P```*^!```-
M````NX$``"@```#)@0``%P```/*!```)````"H(```H````4@@``!P```!^"
M```"````)X(```X````J@@``,0```#F"```G````:X(``!0```"3@@``J0$`
M`*B"```C````4H0``!<```!VA```'0```(Z$```8````K(0``"$```#%A```
M'P```.>$```K````!X4``!T````SA0``$0```%&%```G````8X4``%0```"+
MA0``"P```."%```Q````[(4```<````>A@``!P```":&```-````+H8```L`
M```\A@``!0```$B&```0````3H8```4```!?A@``$@```&6&```(````>(8`
M``,```"!A@``$````(6&```,````EH8```(```"CA@``%````*:&```,````
MNX8```,```#(A@``!````,R&```:````T88```D```#LA@``#````/:&```7
M`````X<```<````;AP``#P```".'```%````,X<``!H````YAP``QP```%2'
M```+````'(@```8````HB```"0```"^(```+````.8@```T```!%B```%P``
M`%.(```&````:X@``#,```!RB```$P```*:(```3````NH@``#(```#.B```
M$P````&)```1````%8D``#(````GB0``%@```%J)```(````<8D```D```!Z
MB0``"@```(2)```4````CXD```@```"DB0``"````*V)```/````MHD```X`
M``#&B0``$````-6)```)````YHD```D```#PB0``$P```/J)```9````#HH`
M``H````HB@``#````#.*```J````0(H```<```!KB@```@```'.*```0````
M=HH``!@```"'B@```P```*"*```(````I(H```<```"MB@``#0```+6*```+
M````PXH``!0```#/B@``%0```.2*```O````^HH``"`````JBP``'````$N+
M```,````:(L``#$```!UBP``!0```*>+```_````K8L``!(```#MBP``"@``
M``",```&````"XP```0````2C```!````!>,```*````'(P``!,````GC```
M!0```#N,```&````08P```8```!(C```"````$^,```$````6(P```4```!=
MC````@```&.,```,````9HP``$4```!SC```,@```+F,``!%````[(P``#``
M```RC0``*````&.-```I````C(T``"8```"VC0``)0```-V-```H`````XX`
M`!(````LC@``$P```#^.```0````4XX```D```!DC@``<P```&Z.```K````
MXHX``!<````.CP``)P```":/```6````3H\```\```!ECP``'P```'6/```<
M````E8\``%$```"RCP``%`````20```%````&9```!(````?D```$````#*0
M```3````0Y````\```!7D```!````&>0```)````;)````L```!VD```!P``
M`(*0```4````BI````\```"?D```#````*^0```/````O)````8```#,D```
M%````-.0```&````Z)````0```#OD```!P```/20```9````_)````<````6
MD0``!@```!Z1```&````)9$```0````LD0``!P```#&1```&````.9$```8`
M``!`D0``$````$>1```&````6)$``"(```!?D0``!P```(*1```+````BI$`
M`$8!``"6D0``!@```-V2```L````Y)(``"P````1DP``%@```#Z3``!`````
M59,```P```"6DP``,````*.3```5````U),``!(```#JDP``)````/V3```(
M````(I0``!L````KE```#0```$>4``"_````590```@````5E0``#@```!Z5
M```5````+94``!@```!#E0``#0```%R5```-````:I4```8```!XE0``*P``
M`'^5```*````JY4```H```"VE0``"````,&5```*````RI4``!````#5E0``
M!0```.:5```2````[)4```L```#_E0``.@````N6```\````1I8``!$```"#
ME@``#0```)66```)````HY8```8```"ME@``$````+26```.````Q98``!``
M``#4E@``%0```.66```3````^Y8```\````/EP``+0```!^7```/````39<`
M`"4```!=EP``#````(.7```,````D)<```4```"=EP``!````*.7```(````
MJ)<```4```"QEP``$P```+>7```*````RY<``!````#6EP``,@```.>7```4
M````&I@``!0````OF```'````$28```6````89@``!(```!XF```#P```(N8
M```'````FY@```@```"CF```#P```*R8```4````O)@``!L```#1F```"0``
M`.V8```%````]Y@``!,```#]F```20```!&9```3````6YD```0```!OF0``
M"@```'29```]````?YD``"P```"]F0``+````.J9```K````%YH``"T```!#
MF@``!P```'&:```4````>9H```L```".F@``#@```)J:```4````J9H``!0`
M``"^F@``.0```-.:```/````#9L```D````=FP``"P```">;```4````,YL`
M``8```!(FP``$````$^;```&````8)L```@```!GFP``!0```'";```-````
M=IL```,```"$FP``#0```(B;```(````EIL```8```"?FP``50```*:;```%
M````_)L``!@````"G```"P```!N<```2````)YP```P````ZG```,0```$><
M```,````>9P``!8```"&G```%````)V<```&````LIP``!D```"YG```!```
M`-.<```/````V)P``&8```#HG```:````$^=```(````N)T```\```#!G0``
M%P```-&=```7````Z9T``"4````!G@``,P```">>```)````6YX``!8```!E
MG@``%@```'R>```2````DYX``!<```"FG@``&````+Z>```1````UYX```T`
M``#IG@``!P```/>>```4````_YX```<````4GP``&````!R?```/````-9\`
M``4```!%GP``#0```$N?```%````69\```8```!?GP``!P```&:?```-````
M;I\```@```!\GP``!P```(6?```'````C9\``!4```"5GP``*````*N?```+
M````U)\``!````#@GP``!@```/&?```&````^)\```8```#_GP``!0````:@
M```-````#*```"8````:H```)````$&@``"[````9J```",````BH0``)0``
M`$:A```Q````;*$``+T```">H0``5````%RB```&````L:(```0```"XH@``
M"0```+VB```)````QZ(```X```#1H@``$P```."B```.````]*(``!$````#
MHP``#0```!6C```W````(Z,```4```!;HP``#0```&&C```1````;Z,``!<`
M``"!HP``&P```)FC```"````M:,``!````"XHP``$````,FC```$````VJ,`
M``L```#?HP``"````.NC```-````]*,``!`````"I```!P```!.D```-````
M&Z0```T````II```"````#>D```%````0*0```D```!&I```"@```%"D```)
M````6Z0```L```!EI```)P```'&D```+````F:0``!T```"EI```&0```,.D
M```9````W:0``!````#WI```"0````BE```,````$J4```L````?I0``'P``
M`"NE```+````2Z4``!(```!7I0``$@```&JE```)````?:4``!<```"'I0``
M$0```)^E```=````L:4``!T```#/I0``*0```.VE``!6````%Z8``"H```!N
MI@``.````)FF```+````TJ8```0```#>I@``"P```..F```)````[Z8```D`
M``#YI@``$@````.G```3````%J<``!(````JIP``"@```#VG```)````2*<`
M``(```!2IP``#````%6G``!!````8J<``"$```"DIP``#P```,:G``"=````
MUJ<``!H```!TJ```"0```(^H```F````F:@```0```#`J```#P```,6H```.
M````U:@```\```#DJ```#@```/2H```3`````ZD```P````7J0``$P```"2I
M```(````.*D``!<```!!J0``"````%FI```6````8JD```4```!YJ0```P``
M`'^I```(````@ZD```<```",J0``"````)2I```0````G:D``!8```"NJ0``
M#````,6I```&````TJD``!\```#9J0``'P```/FI```%````&:H```@````?
MJ@``#0```"BJ```'````-JH``"\````^J@``$P```&ZJ``"?````@JH``!<`
M```BJP``"````#JK```'````0ZL```P```!+JP``!P```%BK```)````8*L`
M``4```!JJP``"@```'"K```#````>ZL```4```!_JP``!````(6K```1````
MBJL```T```"<JP``#````*JK```B````MZL```8```#:JP``'````.&K```4
M````_JL```@````3K```!@```!RL```0````(ZP``!,````TK```$0```$BL
M```$````6JP```D```!?K```"0```&FL``!.````<ZP``%````#"K```4```
M`!.M```(````9*T``!4```!MK0``!@```(.M```'````BJT``!H```"2K0``
M#````*VM```?````NJT```8```#:K0``!0```.&M```.````YZT```4```#V
MK0``'@```/RM```[````&ZX```L```!7K@``.@```&.N```N````GJX``"0`
M``#-K@``+@```/*N```*````(:\```L````LKP``!P```#BO```9````0*\`
M``H```!:KP``#0```&6O```0````<Z\```\```"$KP``F@```)2O```-````
M+[````H````]L```"P```$BP```2````5+```!,```!GL```#0```'NP```1
M````B;```!8```";L```$P```+*P```9````QK```),```#@L```#@```'2Q
M```0````@[$```D```"4L0``(0```)ZQ```9````P+$```\```#:L0``#@``
M`.JQ```1````^;$``!D````+L@``-````"6R```T````6K(``#0```"/L@``
M-````,2R```P````^;(``#`````JLP``&P```%NS``!!````=[,``!<```"Y
MLP``%P```-&S```9````Z;,``!D````#M```'````!VT```<````.K0``!D`
M``!7M```&0```'&T```\````B[0``!0```#(M```$@```-VT```5````\+0`
M`!<````&M0``"@```!ZU```Y````*;4```P```!CM0``!P```'"U```4````
M>+4```0```"-M0``!````)*U```$````E[4```L```"<M0``$P```*BU```)
M````O+4```H```#&M0``#@```-&U```)````X+4```X```#JM0``"````/FU
M```&`````K8``"`````)M@``&````"JV```@````0[8``!(```!DM@``!0``
M`'>V```(````?;8``!X```"&M@``!````*6V```'````JK8```<```"RM@``
M%````+JV```:````S[8```<```#JM@``%@```/*V```(````";<```T````2
MMP``#0```""W```1````+K<```P```!`MP``#P```$VW```4````7;<```P`
M``!RMP``'P```'^W```-````G[<```P```"MMP``&@```+JW```&````U;<`
M``4```#<MP``!P```.*W```%````ZK<```L```#PMP``!0```/RW```&````
M`K@``!D````)N```&````".X```9````/+@```(```!6N```!````%FX```%
M````7K@```4```!DN```"P```&JX```,````=K@``&P```"#N```!0```/"X
M```&````]K@``!$```#]N```+@````^Y```L````/KD``"D```!KN0```P``
M`)6Y```+````F;D```<```"EN0``"@```*VY```-````N+D```P```#&N0``
M'````-.Y``!%````\+D```8````VN@``!@```#VZ```L````1+H``"L```!Q
MN@``"0```)VZ``!R````I[H```,````:NP``"P```!Z[```&````*KL```@`
M```QNP``"@```#J[```4````1;L``!8```!:NP``%````'&[```*````AKL`
M`!0```"1NP``"````*:[```1````K[L``!@```#!NP``!P```-J[```,````
MXKL```T```#ONP``"@```/V[```<````"+P```H````EO```%P```#"\```4
M````2+P```8```!=O```"P```&2\```*````<+P```4```![O```2P```(&\
M```4````S;P``!X```#BO```'0````&]```B````'[T``",```!"O0``$```
M`&:]```.````=[T``#<```"&O0``8````+Z]``!;````'[X```D```![O@``
M(@```(6^```9````J+X``!(```#"O@``#````-6^```'````XKX``"\```#J
MO@``"````!J_```,````([\```P````POP```@```#V_```.````0+\```<`
M``!/OP``$@```%>_```&````:K\``"(```!QOP``"@```)2_```7````G[\`
M`!X```"WOP``:P```-:_```9````0L```"(```!<P```#@```'_````'````
MCL```!````"6P```%````*?````(````O,```!8```#%P```&@```-S````)
M````]\````X````!P0``#````!#!```(````'<$```D````FP0``"@```##!
M```*````.\$```L```!&P0``$````%+!```(````8\$``"H```!LP0``'@``
M`)?!```)````ML$``!<```#`P0``$````-C!```%````Z<$``!8```#OP0``
M!@````;"```&````#<(``!(````4P@``!0```"?"```7````+<(```0```!%
MP@``&0```$K"```%````9,(```8```!JP@``(0```''"```S````D\(``"0`
M``#'P@``$0```.S"```1````_L(``!,````0PP``!````"3#```%````*<,`
M``\````OPP``(@```#_#```[````8L,``$0```">PP``+P```./#```I````
M$\0``"T````]Q```8@```&O$```'````SL0```<```#6Q```%P```-[$```6
M````]L0``"(````-Q0``'````##%```'````3<4``!P```!5Q0``"````'+%
M```%````>\4``"<```"!Q0``#0```*G%```1````M\4```8```#)Q0``!0``
M`-#%```%````UL4```4```#<Q0``$@```.+%```8````]<4```<````.Q@``
M$@```!;&```<````*<8```P```!&Q@``!````%/&```]````6,8``%P```"6
MQ@``&0```//&```<````#<<``!4````JQP``"````$#'```-````2<<``"D`
M``!7QP``"0```(''```0````B\<``!4```"<QP``$@```++'``!%````Q<<`
M``D````+R```'P```!7(```2````-<@``!8```!(R```#0```%_(```2````
M;<@``!<```"`R```!0```)C(```2````GL@``!8```"QR```%@```,C(```8
M````W\@```D```#XR```!0````+)```1````",D```X````:R0``#@```"G)
M```&````.,D```8````_R0``-@```$;)```L````?<D``"P```"JR0``"```
M`-?)```)````X,D```D```#JR0```P```/3)```*````^,D```,````#R@``
M%P````?*```&````'\H```D````FR@``#@```##*``!?````/\H``!X```"?
MR@``*0```+[*```0````Z,H```D```#YR@``#P````/+```9````$\L``!(`
M```MRP``#````$#+```=````3<L``'D```!KRP``%````.7+```5````^LL`
M`"P````0S```$@```#W,```3````4,P``!L```!DS```&````(#,```@````
MF<P``!4```"ZS```!P```-#,```)````V,P``%X```#BS```.@```$'-``!`
M````?,T``%0```"]S0``!0```!+.```=````&,X``"X````VS@``!P```&7.
M```0````;<X``#D```!^S@``"0```+C.``!5````PLX``#$````8SP``(P``
M`$K/```B````;L\``",```"1SP``'P```+7/```E````U<\``"````#[SP``
M!P```!S0```4````)-```!H````YT```&0```%30```3````;M````4```""
MT```#0```(C0```-````EM```!H```"DT```(````+_0```0````X-```"(`
M``#QT```#````!31```:````(=$``!0````\T0``(````%'1```H````<M$`
M``L```";T0``)P```*?1```$````S]$``!D```#4T0``#````.[1```.````
M^]$```X````*T@``"````!G2```'````(M(``!(````JT@``!@```#W2```J
M````1-(```H```!OT@```P```'K2```X````?M(```@```"WT@``&P```,#2
M``!)````W-(``"L````FTP``,P```%+3```;````AM,```D```"BTP``#P``
M`*S3```1````O-,```4```#.TP``#P```-33```A````Y-,``!`````&U```
M$0```!?4```2````*=0``#$````\U```"````&[4```G````=]0``"T```"?
MU```)P```,W4```.````]=0```X````$U0``!P```!/5```%````&]4``!@`
M```AU0``!````#K5```%````/]4``"$```!%U0``%0```&?5```*````?=4`
M``T```"(U0``$````);5```#````I]4```X```"KU0``+0```+K5```L````
MZ-4``!<````5U@``'0(``"W6```=````2]@``!8```!IV```(````(#8```7
M````H=@``",```"YV```)````-W8```[`````MD``"`````^V0``%@```%_9
M```E````=MD``%X```"<V0``#@```/O9```N````"MH```4````YV@``!0``
M`#_:```/````1=H```P```!5V@``!0```&+:```8````:-H```@```"!V@``
M$0```(K:```%````G-H```0```"BV@``$0```*?:```)````N=H```,```##
MV@``$@```,?:```+````VMH```,```#FV@``!````.K:```E````[]H```L`
M```5VP``$@```"';```;````--L``!````!0VP``#P```&';```$````<=L`
M`"<```!VVP``&0$``)[;```2````N-P```H```#+W```#0```-;<```3````
MY-P``!@```#XW```'0```!'=```&````+]T``#,````VW0``&````&K=```9
M````@]T``#H```"=W0``%0```-C=```4````[MT``#D````#W@``(````#W>
M```-````7MX```X```!LW@``#@```'O>```9````BMX```<```"DW@``"```
M`*S>```-````M=X``#8```##W@``,0```/K>```)````+-\```T````VWP``
M$````$3?```8````5=\```T```!NWP``#@```'S?```Y````B]\```H```#%
MWP``!````-#?```-````U=\``!H```#CWP```P```/[?```(`````N````X`
M```+X```%````!K@```2````+^```!0```!"X```%0```%?@```S````;>``
M`"4```"AX```*0```,?@```.````\>```#P`````X0``!0```#WA``!'````
M0^$```L```"+X0``"@```)?A```&````HN$```0```"IX0``!0```*[A```2
M````M.$``!T```#'X0``!@```.7A```&````[.$```X```#SX0``$`````+B
M```)````$^(```4````=X@```@```"/B```/````)N(``&(````VX@``-@``
M`)GB``!.````T.(``#4````?XP``+@```%7C```[````A.,``#L```#`XP``
M,P```/SC```W````,.0``!$```!HY```$@```'KD```.````C>0```D```"<
MY```?````*;D```M````(^4``!D```!1Y0``)````&OE```7````D.4``!(`
M``"HY0``(P```+OE```=````W^4``&$```#]Y0``$P```%_F```%````<^8`
M`!P```!YY@``$0```);F```:````J.8```T```##Y@``!````-'F```)````
MUN8```L```#@Y@``!0```.SF```2````\N8```P````%YP``!````!+G```1
M````%^<```8````IYP``$0```##G```(````0N<```8```!+YP``!0```%+G
M```7````6.<```T```!PYP``%@```'[G```&````E><```0```"<YP``!@``
M`*'G```%````J.<```0```"NYP``$P```+/G```%````Q^<``"D```#-YP``
M"@```/?G```+`````N@```$```#/````7`(``!P"``#1`@```````),````4
M````0`(``#H#``!L`0``L````$@#``#<`@```````(H"```H`P``$@```&X#
M`````````````%\#````````X0````````#D`@``&@(```````!Y````1P(`
M````````````X@```$X"``"_`@``/`$```````#7`0``\@```)(!``"``0``
M+P(``'`````T`P``:P```$L``````````````)P!``#N````<@,``/$!``!5
M`@``$`$```,`````````:P$```````!\````)P```*8!```'`@``?0(``)@`
M``"\`@```````!L!``!H````#``````````.`0``/P(```````!T`0``````
M``````"7`@```````!\``````````````````````````````#8```!S`0``
MA@(``/L```"+`@``]P(``"4#``!B`@``O`$``)L!```U````GP```!L`````
M````F0(``.8````E````!0,``(<!``"/`0```````#T"````````"0```$T"
M``!=````9@(``($"``!C````DP$``',#````````7`,````````W`P``4P``
M`!<`````````\`$``*L````"`@``!P```%8#``"L`0``GP$```````#_`@``
M`````/X"```.`P``CP(```8"``#S`0``AP```'`"``!9`P```````)H```!/
M````Q@(``",```"S`````````-4"````````H0$``$,```#J````=@(`````
M``#,`0``%@$``+H```!/`0``#`$``&0!```R`P``,````+H!``"M`0``,P,`
M`!$!``#1`0````````<#````````(0```)4!```1`@``.P(``$H!````````
M[`$```````#%`@``)`$`````````````)@````````#O`0``M````/0!``"'
M`@``*`(``-X!``#*````?0````````"#`0``,@$``,X```"Q`0``:@$``/\`
M``#]`0``<`,``%\```"0`0```````&@#``"[`0``-P(``/$```!H`@``8P(`
M`+@"``#@`0``S`(```````!O````M@````````#J`@```````)4"````````
M`````!P`````````^P$```````#8`@``:P,``!,"``!$`P``>P$``&$"``!C
M`P``<@$``.0!```Z`@```````&D!`````````````&<#````````[0(`````
M``"L````=P(``'<!``"^`0``50,``-P!``!#`0```````%\!``!/`@``10(`
M``````!3`@``O0$``&T#```.`@``80,``!0!``"+````(@,``!`"```A`P``
MK`(``-,"``````````````````!_`@``LP(```````````````````````#K
M````U`$```````#B`0``J0```+<"````````"`$```````"H`@```0,`````
M````````&@,``-X```"4`0``<@```"P```#.`0```````$("```^`@``@`(`
M```````M`P``CP````````!]`0``@@```)$"``#4`````````)@!``!X`0``
M9P$``"`#``#``0``K@$```````#E`````````),"``#H`0```````',```!)
M`0``3@```$$"````````-0$````````R`@``F0$``,<"``"[`@``9`(`````
M````````<0(``$0!``!Q`````````"4"``!_````RP```(T````]`P``UP(`
M``````!B````%0,```<!`````````````(,```"C`@``I`(``/H"````````
M`````(4```!9`0``A0$```````!U`P```````$P#````````9@$``)<!````
M````"````&<````!`@``G0$``(D!```5`@``V@$```````#Q`@``-@$``'<`
M```K`0```````/<````&````?`$````````6`@``=0``````````````````
M```````:`0``F@$``&,!````````^````&`````Q`@``,`(```````!2`@``
M3`(``+D```!^`0``'@,````````A`0``*0```$8#``#+`@``*````#0"```%
M````M`$``%(!``#0`0``;@$``$<!``"?`@`````````````G`0``!`$``#X`
M````````70(````````X`0``]0```-\```!A`0```````%(```"%`@``@0``
M`(X"```=````%0$``!@"```I`P``T@$``-H`````````H`$``/,```"E`0``
M#P(``)@"````````4`(``*8````4`P``B0(```````#L`@``6```````````
M````_0```#`#`````````````%`!```D````\````(``````````U0``````
M```U`@``/`,``#P```#(`0``T0``````````````TP```+\`````````N```
M``(#`````````````(@"```X`P``2@,``/<!````````V@(```````!Z````
M90(``'4"``!Z`@``Q0$`````````````*`$``,(```"O`0``W0$``!T!````
M````T@````4!``!+`P```````,4````3`P``Z````,L!```Q`P``X0(``$0"
M``"J`0``HP`````````$`@``P0$``)("``!0````/0```'X"```1````1P``
M`/D```#5`0``QP```'@"``"U`````````)8```````````````\#``!@`@``
ML@(``#,!``#G````(P(``"X"``!Z`0``30```",!``!'`P``````````````
M````J0(```````!7````J`$```````!S`@````````````!J`P``G0```#H!
M````````[@$``"L#````````(`(``!8````F`0``7@,````````"`0``W0``
M`*T"``#I`````````&T!``"A`@``[P(``&H"`````````````/H```!#`P``
M(````$8```!I````````````````````M0(``/\!``````````````T```!I
M`P``VP$```4"```3`````````/@!``#9````E@$``*D!``!L`````````"X`
M````````[@(``%D````Y`P```````.4!``!8`@``+`$``+0"````````'P(`
M`)H"``"!`0``10,``&8```"V`0``:@```$@!``"^`@``*@$``$H"```B````
M:0(``"P#``!1````#0$``'0```!O`@````````````">`@``8@$````````-
M`P`````````````Q````@@(``/D!``#F`@``````````````````,P```+<`
M`````````````+P`````````:P(``$\#``"9```````````````*`@``H```
M`*X`````````6@$``'0"``#O````>P(``.,"```^`P``;@(``%$#````````
M#@`````````[````20(``"X!``"G`0```````%L!``">`0``BP$``)L```!,
M`````````"H"````````.@````````!`````Z0(`````````````%P$``!(!
M``!P`0``50````````#?`@``6@(``/8````X`@`````````````P`0``S0``
M`#8"```I`@``40(``"\!``#U`@``0@$``(D```#V`0```````'D!``!M`@``
ME0```%D"`````````@```!````!\`@``&`,``!,!``"$`````````"8#```1
M`P```````+X``````P````````````!-`0``B@$``&4```"Y`0``=@```%X`
M```T`0``U`(``(P!````````)0$``*8"```X````K@(```````#`````6P``
M````````````80```.T!``".`0``N`$````````+`0``:`$```H#``!4`P``
M-````!T"``!%````-P```,0````_`0``"@``````````````&0(``#D"``#)
M`0``(@(``-D"```&`0``&@```.<"```,`@``5P$```````"7`````````+<!
M```N`P```````*H````M````0`$``.@"```6`P````````````#'`0``````
M`*4"```M`@``'@```+$"``#T````PP$`````````````H`(``%\"``"1````
M'@$``+H"````````JP$``%L#````````V````#P"```$````2P$```P#```<
M`P```````&\#`````````````$0```#[`@``"@$``#4#````````,P(``$8!
M```)`P```````+T"``"1`0``R@$``"$"`````````````,,```#P`@``@P(`
M`,$"```/``````(``+T```#U`0```````,("````````6P(```````!V`0``
M`````+`!```C`P``7`$``$X#```;`@``0@````````#R`0``V0$``-`"``#B
M`@```````,T!``!)````N0(``!@!``#Y`@``]`(``.4"```9`0``Q@```#D!
M```G`@``0P(``"L"``!%`0````````````",````B`$```````!L`@``````
M`)(```#G`0``SP$``)`"``#]`@````````````!O`0``;0````````"R`0``
M&0```-@!```2`P``7@(``%@!``"&````4P$```,!`````````````#L#``!E
M`P``A@$``/X````;`P``ZP(``*L"``!R`@``SP(``-,!````````$`,``'X`
M``#``@``[0```"0"``"S`0``00````````"O`@````````````#6`0``````
M````````````H0`````````&`P``90$``)T"```I`0``A`$``+4!```+`@``
M,@````````"P`@``````````````````1@(```````"G````"`(``)0```#,
M````S@(``'\!```B`0``.P$```````"<`@``)P,``%<#````````H@``````
M``#^`0``20,``-("````````G````&P#`````````````/,"``!"`P``/P,`
M`.L!``#D````C@````````#@`@```````#D`````````)@(``%4!``!T`P``
MC0$``'L```!:`P``Q`$````````O````&0,```````#V`@```````,D```!1
M`0```````%0"````````I````#T!````````W``````````K````;@```%T#
M```4`@``%P,```````"B`0``/P```$`#``",`@``PP(```````#\`0``````
M`-`````$`P```````-8"``#\`````````+(```#?`0``4P,``$@"````````
M`````'D"```+`P``8`$``%8"``#(`@``Q@$``#X!```V`P``"0$``%T!``!G
M`@``00,``!<"````````Q`(``*H"``#6````3@$``,@```#=`@``````````
M``!>`0``>````*\```````````$``"`!````````'`$``*,!````````%0``
M`"\#``#;````E@(``)0"```J`P``````````````````"P```'$!``"*````
MNP``````````````#P$``/("``#7```````````````W`0```````$L"``#-
M`@``P0```!X"``#;`@``FP(``*("````````5P(``/P"``"0````8@,``!T#
M```2`@``IP(``.$!``!-`P```````.P```#Z`0```P(```````"_`0``````
M`,D"``"-`@``5`$``.,``````````````$P!`````````````(@```!@`P``
M"0(``(0"``!*````Y@$``'$#```D`P``9````%0```!!`0``7````"T!``#C
M`0```````((!``#*`@``6`,``%(#```!`0``*@```*0!``#@`````````'4!
M````````#0(``.H!````````6@```&8#`````````````%8```!(````+`(`
M`*4```"Q````&````````````````````&0#``#X`@``5@$``#$!``"V`@``
MG@```!\#``!0`P``'P$```@#```#`P``P@$``.D!`````````````*T`````
M`````````*@```#>`@```"!A="``(B5S(B!W87,@861D960@=&\@=&AE(&=R
M;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N
M<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S
M960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D
M(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"UD87D@9F]R
M96-A<W0`)7,@+2!.;W1I8V4`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M
M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!497)M<R!O9B!!9W)E96UE;G0`
M)7,@870@)7,@)7,`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X
M(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@
M=&AI<R!T:6UE+@`E<R!M:6YU=&5S`"5S('1O("5S(&]F("5S`"P@9W5S=&EN
M9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`,3(@2&]U<B!&;W)M
M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`02!D871A8F%S92!B86-K96YD
M(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!32!#;&]U9',`04T@3&EG
M:'0@4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-
M+U!-`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M
M:61D;&4`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C
M8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@2&5R93H`061D($YE
M=R!'<F]U<`!!9&0@82!N97<@=7-E<CH`061D(&YE=R!M96UB97)S`$%D9"!P
M86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@
M=7-E<@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,@0F]O:P!!
M9&UI;FES=')A=&EO;@!!9',`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U
M=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@9F]U<B!S:61E<P!!
M;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;'1E<FYA=&4@
M24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@
M24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA
M=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;G-W97(`07!P;&EC871I
M;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P
M;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!R:6P`07)A8FEC("A7:6YD
M;W=S+3$R-38I`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE
M('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R;65N:6%N("A!4DU30TE)+3@I
M`$%R=`!!<V-I:2!!<G0`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O
M:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%T=&5M<'0@=&\@9&5L971E
M(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM
M97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X
M:7-T96YT('-H87)E+@!!=6=U<W0`079A:6QA8FQE(&9I96QD<SH`0D]&2"!%
M>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"86QT:6,@*$E3
M3RTX.#4Y+3$S*0!"87-E;&EN90!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E
M`$)O;&0`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D
M97)S`$)O=&@`0F]T=&]M`$)U;&QE=&5D($QI<W0`0TU3`$-?96QL(%!R;W!E
M<G1I97,N+BX`0V%L96YD87(`0V%L;0!#86X@;F]T(')E<V5T('!A<W-W;W)D
M(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#
M86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A<'1I;VX`0V%T96=O<FEE
M<R!A;F0@3&%B96QS`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E
M;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;'1I8R`H25-/+3@X-3DM
M,30I`$-E;G1E<@!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#:&%N
M9V4`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E('1H92!N86UE(&%N9"!A
M9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P
M;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@
M;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN
M("!#;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0VAA<@!#:&5C7VL@3&EN
M:RXN+@!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D
M:71I;VYA;"`H0FEG-2D`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#
M:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VQE
M87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!O=70@=7-E<CH@)7,`0VQE
M87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#;&EC:R!T
M;R!#;VYT:6YU90!#;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D<R!%87)L>0!#
M;&]U9'D`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO
M<@!#;VQO<B!0:6-K97(`0V]L<SH`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3
M:&5L;`!#;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A
M=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E
M+@!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYT86-T<P!#;VYT
M:6YU90!#;V]K:64`0V]P>0!#;W!Y('-E;&5C=&EO;@!#;W5L9"!N;W0@8FEN
M9"!T;R!L9&%P('-E<G9E<@!#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E
M<G9E<@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q
M=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N
M;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E
M=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U
M<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I
M;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@
M9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N
M<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL
M>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&1N)W0@9FEN9"!T:&4@36]Z
M:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`
M0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE
M`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%=E871H97(`
M0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T
M87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I
M;VX`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`
M0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$1$`$1A=&%4<F5E($)R;W=S
M97(`1&%T92!296-E:79E9`!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`
M1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U
M;'0@0V]L;W(`1&5F875L="!3:&5L;`!$969I;FET:6]N<P!$96QE=&4`1&5L
M971E($-E;&P`1&5L971E($=R;W5P`$1E;&5T92!C96QL`$1E;&5T92!C;VQU
M;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@
M<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E
M;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5S8W)I8F4@=&AE
M(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E
M=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N
M(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T
M;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I
M<W!L87D@9&5T86EL960@9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H5$%&
M*0!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S
M('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE
M<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG
M;B!U<"X`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0
M('-C<FEP="X`1')U9W,`161I=`!%9&ET($)L;V-K`$5D:70@1W)O=7``161I
M="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P
M=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C871I;VX`
M16QE;65N="XN+@!%;0!%;6%I;"!!9&1R97-S`$5N86)L92!I;G-E<G1I;VX@
M;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L
M92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N;&%R9V4@161I=&]R`$5N
M=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K
M960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G
M=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA
M9V4@55),(&AE<F4`17)R;W(`17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S
M`$5T:&YI8P!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R
M>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!H86QF(&AO=7(`
M179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9"!3
M:61E8F%R`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I<@!&87AE
M<P!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R
M<P!&97<@4VYO=R!3:&]W97)S`$9I;&4@36%N86=E<@!&:6QT97)S`$9I<G-T
M($AA;&8`1FER<W0@475A<G1E<@!&;&]A=`!&;V<`1F]N="!#;VQO<@!&;V]D
M`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C
M87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N
M960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R
M9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`
M1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T
M>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R
M86UE<P!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L
M;"!.86UE`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=E
M;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V\`1V]E
M9&5L`$=O;V=L92!396%R8V@`1W)E96L@*$E33RTX.#4Y+3<I`$=R;W5P($%D
M;6EN:7-T<F%T:6]N`$=R;W5P<P!'=65S="!097)M:7-S:6]N<P!'=65S=&)O
M;VL`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA
M<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE
M+@!(87IE`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP
M('5S:6YG(&5D:71O<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN
M9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VUE($1I<F5C=&]R>0!(;W)D
M90!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT
M86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO
M=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M
M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S
M('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@
M`$AU;6]R:7-T<P!)7VYS97)T(%)O=R!"969O<F4`26-O;G,@3VYL>0!)8V]N
M<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@
M>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R
M97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F
M9B!03D<@=')A;G-P87)E;F-Y+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`
M26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL
M97)Y.@!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E
M<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C
M="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R
M(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H
M97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EV:61U86P@57-E<G,`26YF
M;W)M871I;VX`26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92X`26YS
M97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L90!)
M;G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A
M(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE
M=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@
M<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E
M9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R
M('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T
M:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS
M97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E
M('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R="!C
M96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@
M8F5F;W)E`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P
M:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!)
M;G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E
M<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK
M`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@<&%R96YT('!E<FUI<W-I
M;VXN`$EN=F5N=&]R>0!)<V]L871E9"!4+5-T;W)M<P!)=&%L:6,`2F%N=6%R
M>0!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IU;'D`2G5N90!*=7-T:69Y`$IU
M<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF
M>2!2:6=H=`!+97)N96P@3F5W8FEE<P!+:61S`$MO<F5A;B`H155#+4M2*0!,
M85]Y;W5T`$QA;F=U86=E`$QA<W0@2&%L9@!,87-T(%!A<W-W;W)D($-H86YG
M90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87<`3&%Y;W5T`$QE879E
M(&5M<'1Y(&9O<B!N;R!B;W)D97(`3&5F=`!,:6=H="!$<FEZ>FQE`$QI9VAT
M(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@
M4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO
M=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK('!O:6YT<R!T;SH`
M3&EN=7@@0V]O:VEE`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`
M3&ES="!486)L97,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A
M='5R90!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO
M9R!I;@!,;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS`$QO=F4`3&]W`$QO=V5R
M(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA
M;B!N=6UB97)S`$U-`$U/5$0`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:V4@
M;&EN7VLN+BX`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA
M=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D
M('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%R8V@`36%R9VEN`$UA=&-H:6YG
M(&9I96QD<P!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S
M="`V(&AO=7)S.B``36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-
M87D`365D:6-I;F4`365M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE
M=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@
M8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T<FEC`$UI9&1L90!-:6X@=&5M
M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36ES
M8V5L;&%N96]U<P!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O
M(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L
M:6-A=&EO;BX`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69Y(%523`!-
M;V]N(%!H87-E<P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@
M4W5N;GD`37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY(%!O
M<G1A;`!->2!0;W)T86P@3&%Y;W5T`$Y/+"!)($1O($Y/5"!!9W)E90!.971W
M;W)K`$YE=F5R`$YE=R!#871E9V]R>0!.97<@36]O;@!.97<@57-E<FYA;64@
M*&]P=&EO;F%L*0!.97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D<R!D;VXG="!M
M871C:"X`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X
M=`!.:6=H=`!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H
M;W<@9&EF9F5R96YC97,@9F]R+@!.;R!C:&%N9V4N`$YO(&EC;VYS(&9O=6YD
M+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.
M;R!P96YD:6YG('-I9VYU<',N`$YO(')U;&5S`$YO('-I9&5S`$YO('1E;7!O
M<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=F5R<VEO
M;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF
M:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N
M92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)T:&5R
M;B!(96UI<W!H97)E`$YO="!S970`3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L
M(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O
M9B!R;W=S`$]+`$]B:F5C="!#<F5A=&]R`$]C=&]B97(`3V9F96YS92!F:6QT
M97(`3V9F:6-E`$]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E
M<F5N="X`3VQD('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C
M="X`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!T:&4@;W=N97(@;W(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@
M;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W
M:6YD;W<`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I
M;F<@4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T
M`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I
M9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO
M;@!/=VYE<B!097)M:7-S:6]N<P!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG
M:'0@4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-
M(%-U;@!032!4+5-T;W)M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!0
M7TA0(%-H96QL`%!A9&1I;F<`4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S
M=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0Z`%!A<W-W;W)D
M.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI
M<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!0
M97)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N
M86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N("(E<R(@;F]T
M(&1E;&5T960N`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L
M($EN9F]R;6%T:6]N`%!E=',`4&AO=&]S`%!I>&5L<P!0;&%T:71U9&5S`%!L
M96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T
M('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF
M:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE
M87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E
M('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O
M=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@<F5A9"!T
M:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E
M<FUS('1O('5S92!T:&4@<WES=&5M+@!0;VQI=&EC<P!0;VQL<P!0;W-I=&EO
M;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`
M4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A
M=&EO;CQB<B`O/F-H86YC90!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V
M96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@
M82!N97<@=VEN9&]W`%!R:6YT(&1O8W5M96YT`%!R;V)L96T@1&5S8W)I<'1I
M;VX`4')O:F5C=',`475E<GD`475O=&$`4F%I;@!286EN($5A<FQY`%)A:6X@
M3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!2
M86YD;VT@1F]R='5N90!296%D`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E
M<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E<B!D
M871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD
M;VYE+@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H($1Y;F%M:6,@
M365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5M87)K<P!2
M96UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@9F]R;6%T
M=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R
M=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@
M=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V
M92!U<V5R.B`E<P!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A
M<W-W;W)D`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5T>7!E(&YE=R!P
M87-S=V]R9`!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R
M($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2;U]W(%!R;W!E<G1I97,N+BX`4F]W
M(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@
M=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4TU3($UE<W-A9VEN9P!3
M44P@4VAE;&P`4U-(`%-?44P@4VAE;&P`4V$`4V%M92!F<F%M92`H7W-E;&8I
M`%-A=F4`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N
M9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T
M96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3
M8V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`4V5A<F-H($5N9VEN
M97,`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!3
M96QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T('1H
M92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9
M;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT
M(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@
M9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@
M8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE
M('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L
M96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N<V]R.B``4V5P=&5M
M8F5R`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A
M<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S
M97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T
M86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD
M(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@
M8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P
M;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I
M;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R
M86UE=&5R.B``4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S
M(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&1I
M9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W
M;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T
M:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!T86)L92!O<&5R871I;VYS(&UE
M;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H
M92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE
M(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T
M:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3
M:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@
M=&AE(%9I8VEN:71Y`%-K:7`@36%I;G1E;F%N8V4`4VYO=P!3;F]W(%-H;W=E
M<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R
M<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z
M(`!3;VYG<R`F(%!O96US`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3
M;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L
M;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3
M<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A;0!3<&5C:6%L($-H87)A
M8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`
M4W!O<G1S`%-T86YD87)D`%-T87(@5')E:P!3=&%T=7,`4W1R:6ME=&AR;W5G
M:`!3='EL92!;0U-370!3=0!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L
M;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG
M=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@
M<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S879E
M9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S<V9U
M;&QY('=R;W1E("5S`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3
M=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T
M.B``4W5P97)S8W)I<'0`4W5P<&]R=`!4+5-T;W)M`%0M4W1O<FT@86YD(%=I
M;F1Y`%0M4W1O<FUS`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O<&5R=&EE
M<P!487)G970Z`%1A<VMS`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T
M=7)E`%1E;7!E<F%T=7)E.B``5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S
M3&\E<RD@)F1E9SLE<P!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT($]N
M;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H92!-
M86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`
M5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!B
M;W1T;VT@<VED92!O;FQY`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N
M('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U
M92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R
M:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA
M>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O
M=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I
M="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R
M;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA
M=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL
M('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N
M=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED
M92!O;FQY`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H
M="UH86YD('-I9&4@;VYL>0!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L
M971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG
M;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!T;W`@
M86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!W
M96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5R92!W87,@
M86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y
M;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AI<R!I<R`E<RX`5&AI
M<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O
M=P!4:'5N9&5R`%1I8VME=',`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4
M:71L90!4:71L92`H=&]O;'1I<"DZ`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C
M90!4;VUO<G)O=P!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`
M5'4`5'5R:VES:"`H25-/+3@X-3DM.2D`52Y6+B!I;F1E>#H@`%523`!54DPZ
M`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N9&5R;&EN90!5;F1O($-H
M86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YF:6QE9`!5;FEC;V1E
M("A55$8M."D`56YI=',`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YP
M<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T
M92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC
M:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W
M:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S
M<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5<&1A=&4`57!D871E("5S
M`%5P9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!G<F%D92!S8W)I<'0@9&5L
M971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F
M:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R
M(')O;6%N(&YU;6)E<G,`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R
M96YT(&9O<B!)35-0('-E<G9E<BX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R
M(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A
M8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S
M97)N86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T
M96TZ`%9A8V%T:6]N`%9A<FEA8FQE`%9E<G-I;VX@0V]N=')O;`!697)T:6-A
M;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`
M5FEE=&YA;65S92`H5DE30TE)*0!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E
M`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%=!4DY)3D<A(2$@4D5-3U9%(%-#
M4DE05"!-04Y504Q,62!&4D]-("5S+@!787)N:6YG`%=E`%=E871H97(@1F]R
M96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E8@!796(@4VET90!7
M96QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/
M+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=H870@87!P;&EC871I
M;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE
M(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A
M8W1E<C\`5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O
M<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@;V8@=&AE("5S
M(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI
M;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI
M`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I
M;F0Z(`!7:7-D;VT`5VES:&QI<W0`5V]R:P!8+5)E9@!960!997,L($D@06=R
M964`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N
M('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W
M960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!M=7-T(&1E
M<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R
M;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H
M:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T
M;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@
M8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M
M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO
M=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U<B!%
M;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA
M=&EO;@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O
M97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@
M:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R
M(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@
M8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>2!H87,@
M8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L
M;"!N86UE.@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U
M<B!N97<@<&%S<W=O<F0N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%II<'!Y`%M(
M:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E
M9"!497AT("T`7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4<F5E`%]$96QE
M=&4@4F]W`%]'<F]U<',`7TEM86=E(%!R;W!E<G1I97,N+BX`7TUO9&EF>2!,
M:6YK+BXN`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P`%]4
M86)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!C86QM`&9A;&QI;F<`9G)O;2!T
M:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&EN;&EN90!L:6YE<UT`;F%M
M90!P97)C96YT`'!I>&5L<P!R:7-I;F<`<VAO=R!D:69F97)E;F-E<P!S=&5A
M9'D`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D
M`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@,C`P-2TP."TP,PI2
M97!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M
M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES
M:6]N+41A=&4Z(#(P,#4M,#@M,#0@,#DZ,3`K,#(P,`I,87-T+51R86YS;&%T
M;W(Z($IA;65S(#QJ86UE<T!A8W1I;VYM97-S86=E+F-O;3X*3&%N9W5A9V4M
M5&5A;3H@:60@/&ED0&QI+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N
M="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/553+4%30TE)"D-O;G1E;G0M
M5')A;G-F97(M16YC;V1I;F<Z(#=B:70*`"!P861A(``B)7,B('-U9&%H(&1I
M=&%M8F%H:V%N(&ME(&1A;&%M('-I<W1E;2!G<G5P+@`B)7,B('-U9&%H(&1I
M=&%M8F%H:V%N(&ME(&1A;&%M(&EZ:6X@<VES=&5M+@`B)7,B(&)E;'5M(&1I
M8G5A=#H@)7,N`"4N,F9-0B!S=61A:"!D:6=U;F%K86X@9&%R:2`E+C)F34(@
M>6%N9R!S=61A:"!D:6EJ:6YK86X@*"4N,F8E)2D`)60@)7,@9&%N("5S`"5D
M(&AA<FD@<V%M<&%I('-A;F1I(&%N9&$@:&%B:7,@;6%S82!B97)L86MU;GEA
M+@`E9"UH87)I(')A;6%L86X@8W5A8V$`)7,@+2!096UB97)I=&%H=6%N`$MO
M;F9I<FUA<VD@+2!/<&5R87-I(%!E;65L:6AA<F%A;B`E<P`E<R!3971U<``E
M<R!3>6%R870M<WEA<F%T(%!E<FIA;FII86X`)7,@<&%D82`E<R`E<P`E<R!S
M:6%P('5N='5K(&UE;&%K<V%N86MA;B!O<&5R87-I('!E;65L:6AA<F%A;B!Y
M86YG('-U9&%H(&1I=&%N9&%I(&1I(&)A=V%H(&EN:2X@0F5R:6QA:"!T86YD
M82!P861A(&MO=&%K('1E<G-E8G5T('5N='5K(&]P97)A<VD@;6%N87!U;B!Y
M86YG(&%N9&$@:6YG:6YK86X@=6YT=6L@9&EL86MS86YA:V%N('!A9&$@=V%K
M='4@:6YI+@`E<R!M96YI=``E<R!U;G1U:R`E<R`E<P`L(&%N9VEN(&ME;F-A
M;F<@)7,@)7,`+"!V87)I86)L92!D87)I("5S(&ME("5S`$9O<FUA="`Q,B!*
M86T`1F]R;6%T(#(T($IA;0`R-"!J86T`1&%T86)A<V4@8F%C:V5N9"!D:7!E
M<FQU:V%N('5N='5K(&%R96$@:6YI+@!!32!-96YD=6YG`$%-($=E<FEM:7,`
M04T@2'5J86X`04T@1V5R:6UI<P!!32!'97)I;6ES(%-A;&IU`$%-+U!-`%1E
M;G1A;F<@961I=&]R(&EN:0!496YT86YG+BXN(`!*87)A:R!A;G1A<F$@8F%G
M:6%N(&)A=V%H(&)A<FES(&1E;F=A;B!B86=I86X@8F%W86@@9V%M8F%R`$IA
M<F%K(&%N=&%R82!B86=I86X@=&5N9V%H(&)A<FES(&1E;F=A;B!B86=I86X@
M=&5N9V%H(&=A;6)A<@!);F9O<FUA<VD@06-C;W5N=`!386YD:2!!8V-O=6YT
M`$%K=6YT86YS:0!486UB86@`5&%M8F%H($=R=7`@06YA:P!486UB86@@1&ES
M:6YI.@!486UB86@@1W)U<"!"87)U`%1A;6)A:"!P96YG9W5N82!B87)U.@!4
M86UB86@@86YG9V]T82!B87)U`%1A;6)A:"!P87-A;F=A;@!486UB86@@365N
M=2`E<R!S96)A9V%I(%!A;F5L(&YA=FEG87-I($UO>FEL;&$`5&%M8F%H('!E
M;F=G=6YA`%!E;F%M8F%H86X@<&5N9V=U;F$@=&ED86L@9&EA:W1I9FMA;BX`
M0G5K=2!!;&%M870@`$%D;6EN:7-T<F%S:0!):VQA;@!2871A`%!E<F%T86%N
M`%-E;75A`%-E;75A(%!E;F=G=6YA($%S;&D`4V5M=6$@1W)U<`!396UU82!E
M;7!A="!S:7-I`$EZ:6YK86X@<&5N9V%T=7)A;B!D87)I('1I<&4@9&%F=&%R
M(&YO;6]R(&)E<G5R=70_`%!E;F=G86YT:2!,;V=I;B!)35-0`%!E;F=G86YT
M:2!386YD:2!)35-0`%!E;F=G86YT:2!.86UA(%!E;F=G=6YA($E-4U``4&5N
M9V=A;G1I(&%L86UA="!E;6%I;`!096YG9V%N=&D@=&5M<&QA=&4`4&5N9V=A
M;G1I('1E:W,Z`$IA=V%B86X`07!L:6MA<VD`1&%F=&%R($%P;&EK87-I`$%P
M;&EK87-I('-U9&%H('-I87`N`$1I9W5N86MA;B!U;G1U:R!"86=I86X@06YA
M:P!$:7-E='5J=6D`07!R:6P`07)A8B`H5VEN9&]W<RTQ,C4V*0!!<&%K86@@
M86YD82!Y86MI;B!A;F1A(&EN9VEN(&UE;6EN9&%H:V%N('!E<FUO:&]N86X@
M<&5N9&%F=&%R86X@=6YT=6L@)7,_`$%R;65N:6$@*$%235-#24DM."D`4V5N
M:0!+;V1E($%S8VEI`$UE;6EN=&$@:V]N9FER;6%S:2!S96)E;'5M(&UE;&%K
M<V%N86MA;B!O<&5R87-I('!E;65L:6AA<F%A;C\`365N8V]B82!U;G1U:R!M
M96YG:&%P=7,@9W)U<"!Y86YG('1I9&%K(&%D82X`365N8V]B82!U;G1U:R!M
M96YG:&%P=7,@:7II;B!Y86YG('1I9&%K(&%D82X`365N8V]B82!U;G1U:R!M
M96YG=6)A:"!I>FEN('EA;F<@=&ED86L@861A+@!-96YC;V)A('5N='5K(&UE
M;F=U8F%H(&)A9VEA;B!Y86YG('1I9&%K(&%D82X`06=U<W1U<P!+;VQO;2!Y
M86YG('1E<G-E9&EA.@!!;&%S86X@0D]&2`!,871A<B!"96QA:V%N9P!787)N
M82!,871A<B!"96QA:V%N9P!"86QT:6,@*$E33RTX.#4Y+3$S*0!*87)A:R!A
M;G1A<F$@8F%G:6%N(&)A=V%H(&=A;6)A<B!D96YG86X@9V%R:7,@9&%S87(@
M8F%R:7,`4&5N9V%T=7)A;B!!<F5A`%1I<&4@07)E80!(=7)U9B!496)A;`!0
M971U;FIU:R!H86QA;6%N('=E8@!";W)D97(`2V5T96)A;&%N($)O<F1E<@!"
M;W)D97(`2V5D=6%N>6$`0F%W86@`1&%F=&%R($)U;&QE=`!#35,`4')O<&5R
M=&D@4U]E;`!+86QE;F1E<@!496YA;F<`5&ED86L@9&%P870@;65N9V%T=7(@
M=6QA;F<@<V%N9&D@<V5C87)A(&]T;VUA=&ES+"!S:6QA:V%N(&AU8G5N9VD@
M861M:6YI<W1R871O<B!A;F1A+@!"871A;`!"871A;&MA;B!,87!O<F%N($UA
M<V%L86@`2G5D=6P@5&%B96P`2V%T96=O<FD@9&%N($QA8F5L`%!R;W!E<G1I
M(%-E;`!*87)A:R!S<&%S:2!D87)I(&)O<F1E<B!D96YG86X@=&5K<R!D:2!D
M86QA;2!S96PZ`'!R;W!E<G1I('-E;`!*87)A:R!S<&%S:2!A;G1A<B!S96PN
M`$-E;'1I8R`H25-/+3@X-3DM,30I`%1E;F=A:`!%<F]P82!496YG86@@*$E3
M3RTX.#4Y+3(I`%5B86@`56)A:"!386YD:2!!;F1A`%5B86@@;F%M82!D86X@
M86QA;6%T('-E:&EN9V=A(&]R86YG(&1A<&%T(&UE;&EH871N>6$@:V5T:6MA
M(&UE<F5K82!M96UB86-A(&1A;B!M96UB86QA<R!K92!E;6%I;"!A;F1A+@!-
M96YG=6)A:"!S86YD:2!A;F1A('1I9&%K(&1I9'5K=6YG(&1E;F=A;B!K;VYF
M:6=U<F%S:2!Y86YG('-E:V%R86YG+B!3:6QA:V%N(&AU8G5N9VD@861M:6YI
M<W1R871O<B!A;F1A+@!+87)A:W1E<@!097)I:W-A($QI;FLN+BX`0VEN82!3
M961E<FAA;F$@*$=",C,Q,BD`0VEN82!4<F%D:7-I;VYI;"`H0FEG-2D`4&EL
M:6@@8V%R82!U;G1U:R!M96YA;7!I;&MA;B!T86YG9V%L.@!0:6QI:"!D869T
M87(@=&EP92!G87EA("AU;G1U:R!D869T87(@;F]M;W(@8F5R=7)U="D`0F5R
M<VEH:V%N`$)E<G-I:&MA;B!T86<@35-/9F9I8V4`0F5R<VEH:V%N('!E;F=G
M=6YA.B`E<P!"97)S:6AK86X@<&5N9V=U;F$`0F5R<VEH:V%N(&1A=&$@<&5N
M9V=U;F$`0V5R86@@8F5B97)A<&$@<V%A="!L86=I`$ML:6L@=6YT=6L@3&%N
M:G5T`%1U='5P($IE;F1E;&$`365N9'5N9P!-96YD=6YG(&1I('!A9VD@:&%R
M:0!"97)A=V%N`%!E<F)E<V%R(%!A;F5L($YA=FEG87-I(`!097)B97-A<B!B
M;W)D97(`5V%R;F$`4&5M:6QI:"!787)N80!+;VQO;0!#;VUI8W,`0V]M;6%N
M9`!#;VUM86YD(%-H96QL`$MO;7!U=&5R`$MO;F1I<VD`2V]N9&ES:0!097)B
M961A86X@2V]N9FEG=7)A<VD`2V]N9FEG=7)A<VD@<W5D86@@:&%B:7,@;6%S
M82!B97)L86MU;GEA+@!-96YG871U<B`E<P!+;VYF:7)M87-I(%-A;F1I`$MO
M;G1A:P!,86YJ=70`0V]O:VEE`%-A;&EN`%-A;&EN(%!I;&EH86X`5&ED86L@
M9&%P870@=&5R:6MA="!D96YG86X@<V5R=F5R(&QD87``5&ED86L@9&%P870@
M=&5R:'5B=6YG(&ME('-E<G9E<B!L9&%P`%1I9&%K(&1A<&%T(&UE;F=A='5R
M('5L86YG('5N='5K('!E;F=G=6YA('EA;F<@9&EM:6YT82X@0F5B97)A<&$@
M871A=2!S96UU82!D971I;"!T:61A:R!B96YA<BX@0V]B82!L86=I(&%T874@
M<VEL86MA;B!H=6)U;F=I(&%D;6EN:7-T<F%T;W(@86YD82!J:6MA(&%N9&$@
M;65M97)L=6MA;B!B86YT=6%N(&QE8FEH(&QA;FIU="X`5&ED86L@9&%P870@
M:V5M8F%L:2!K92!K;VYF:6=U<F%S:2X`5&ED86L@9&%P870@;65N>6EM<&%N
M(&MO;F9I9W5R87-I("5S+@!4:61A:R!D87!A="!M96YY:6UP86X@9FEL92!K
M;VYF:6=U<F%S:2!B86-K=7`@)7,N`%1I9&%K(&1A<&%T(&UE;GEI;7!A;B!F
M:6QE(&MO;F9I9W5R87-I("5S+B!!;F1A(&1A<&%T(&UE;F=G=6YA:V%N('-A
M;&%H('-A='4@9&%R:2!P:6QI:&%N('5N='5K(&UE;GEI;7!A;B!K;V1E('1E
M<G-E8G5T(&ME;6)A;&D@:V4@)7,@871A=7!U;B!M96YY86QI;B!K;V1E(&1I
M(&)A=V%H(&EN:2!S96-A<F$@;6%N=6%L(&ME("5S+@!4:61A:R!D87!A="!M
M96YE;75K86X@4&%N96P@3F%V:6=A<VD@36]Z:6QL82X@4&%S=&EK86X@<&%N
M96P@;F%V:6=A<VD@<W5D86@@=&5R8G5K82X`2W5R<W5S`$)U870`0G5A="!L
M:6YK`$)U870@8F%R=0!786MT=2!396MA<F%N9P!54DP@4V5K87)A;F<@861A
M;&%H`$-U86-A(%-E:V%R86YG`$MO;F1I<VD@4V5K87)A;F<Z`$=A>6$@4V5K
M87)A;F<`2V]S='5M:7-A<VD@='5G87,@=6YT=6L@9&EJ86QA;FMA;B!S96)E
M;'5M(&QO9V]N(&ME("5S+@!(87!U<P!(87!U<R!P:6QI:&%N`$-Y<FEL;&EC
M("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K
M<F%I;FEA;B`H2T])."U5*0!$1`!$871A5')E92!"<F]W<V5R`%1A;F=G86P@
M1&ET97)I;6$`2&%R:0!(87!U<R!+;VQO;0!$97-E;6)E<@!!;F=K82!$97-I
M;6%L`$UE;F=U<F%N9VD@26YD96X`1&5F875L=`!$969A=6QT(%=A<FYA`$1E
M9F%U;'0@4VAE;&P`1&5F:6YI<VD`2&%P=7,`2&%P=7,@4V5L`$AA<'5S($=R
M=7``2&%P=7,@<V5L`$AA<'5S(&MO;&]M`$AA<'5S('!E;F=G86YT:2!T96UP
M;&%T92!Y86YG('-U9&%H(&%D80!(87!U<R!B87)I<P!(87!U<R!I9&5N=&ET
M87,@>6%N9R!T97)P:6QI:`!(87!U<R!K;VQO;2!Y86YG('-E:V%R86YG`$AA
M<'5S(&)A<FES('EA;F<@<V5K87)A;F<`2F5L87-K86X@36%S86QA:`!$97-K
M<FEP<VD`4&5R:V5M8F%N9V%N`%1I=&EK($5M8G5N`%1I=&EK($5M8G5N('5N
M='5K(&IA;2!T97)A:VAI<CH`5&ET:6L@16UB=6X`07)A:"!K:7)I(&ME(&MA
M;F%N`$%R86@@:V%N86X@:V4@:VER:0!$:7)E:W1O<FD`5&%M<&EL:V%N('=A
M:W1U(#(T(&IA;3\`5&%M<&EL:V%N(%!I;&EH86X`5&%M<&EL:V%N(&1E=&EL
M(')A;6%L86X@8W5A8V$`5&%M<&EL:V%N(')A;6%L86X@8W5A8V$@*%1!1BD`
M2F%N9V%N(&QA;F=S=6YG(&UE;F=A:W-E<R!M86EN=&5N86YC92YP:'``07!A
M:V%H(&)A<FES('EA;F<@<&5R=&%M82!T97)D:7)I(&1A<FD@:V]L;VT@;F%M
M83\@:FEK82!Y82P@8F5R:2!T86YD82!P861A(&MO=&%K(&EN:3H`5&ED86L@
M;65M:6QI:VD@86-C;W5N=#\@4VEL86MA;B!M96YD869T87(N`$1O=VYL;V%D
M(&MO;F9I9W5R87-I('EA;F<@9&EH87-I;&MA;B!S96)A9V%I('-C<FEP="!0
M2%`N`$]B870M;V)A=&%N`%5B86@`56)A:"!";&]K:7(`56)A:"!'<G5P`%5B
M86@@27II;@!58F%H($EZ:6X@=6YT=6L@)7,`56)A:"!P:6QI:&%N('5N='5K
M.@!58F%H(&EZ:6X@=6YT=6L@)7,`4&5N9&ED:6MA;@!%;&5M96XN+BX`16T`
M06QA;6%T($5M86EL`$%K=&EF:V%N('!E;GEI<VEP86X@9V%M8F%R+6=A;6)A
M<B!D87)I($=A;&5R:2!&;W1O(&1I(&1A;&%M('1E:W,_`$%K=&EF:V%N(&ML
M:6L@:V%N86X@;65N=2!K;VYT96MS/P!097)B97-A<B!%9&ET;W(`36%S=6MK
M86X@<&5R=&%N>6%A;B!K96%M86YA;B!D:6UA;F$@86YD82!A:V%N(&1I=&%N
M>6%K86X@87!A8FEL82!A;F1A('!E<FQU('5N='5K(&UE;F=A='5R('5L86YG
M('-A;F1I(&%N9&$L("!C;VYT;V@@)V%P86MA:"!N86UA(&)I;F%T86YG(&ME
M<V%Y86YG86X@86YD83\G.@!-87-U:VMA;B!54DP@9V%M8F%R(&1I<VEN:0!+
M97-A;&%H86X`2V5S86QA:&%N('-A870@;65M<&5R8F%H87)U:2!S86YD:3H@
M)7,`4W5K=0!3971I87`@,34@;65N:70`4V5T:6%P(#(@;65N:70`4V5T:6%P
M(#,P(&1E=&EK`%-E=&EA<"`U(&UE;FET`%-E=&EA<"!S971E;F=A:"!J86T`
M4V5T:6%P(&UE;FET`$-O;G1O:"!N:6QA:2UN:6QA:3H`2F%L86YK86X`4&5R
M8F5S87(@4&%N96P@3F%V:6=A<VD`5V%R;F$@1D<`1E10('5P;&]A9"!U;G1U
M:R!S971U<`!#97)A:`!&87@`1F5B<G5A<FD`4V5P97)T:0!397!E<G1I.@!'
M97)I;6ES(%-E8F%G:6%N`$=E<FEM:7,@4V%L:G4@4V5B86=I86X`1FEL92!-
M86YA9V5R`$9I;'1E<@!&87-E('!E<G1A;6$@9&%R:2!397!A<G5H($)U;&%N
M`$9A<V4@<&5R=&%M82!D87)I(%-E<&%R=6@@0G5L86X`1FQO870`0F5R:V%B
M=70`5V%R;F$@5'5L:7-A;@!-86MA;F%N`%5N='5K(&)R;W=S97(@>6%N9R!T
M:61A:R!D87!A="!M96YD=6MU;F<@9V%M8F%R`%)A;6%L86X@8W5A8V$@*%1!
M1BD`2&%R:2!286UA;&%N($-U86-A("AC871A=&%N(&)A:'=A(')A;6%L86X@
M8W5A8V$@>6%N9R!D:6ME;6)A;&EK86X@86MA;B!M96YG96UB86QI:V%N(&)A
M:6L@<VEA;F<@871A=2!M86QA;2!H87)I+"!S96IU;6QA:"!A;F=K82!D87!A
M="!D:6AA<VEL:V%N('!A9&$@87)E82!I;FDI`$QU<&$@9&5N9V%N('-A;F1I
M(&%N9&$_`$9O<FUU;&ER`%)A;6%L86X`5&EP92!286UA;&%N`%)A;6%L86X`
M4F%M86QA;B`R`$9O<G5M`$1I=&5R=7-K86X`2FUT`$9R86UE`$1A<FD`1&5S
M:W)I<'-I($QE;F=K87``0G5L86X@4'5R;F%M80!.86UA($QE;F=K87``1V%L
M97)I('5N='5K(&UE;F=A;6)I;"!G86UB87(@9&%R:0!'86QE<FD`365N9VAA
M<VEL:V%N("5S($MO;F9I9W5R87-I(`!+;V1E('EA;F<@9&EH87-I;&MA;@!*
M86QA;FMA;@!';V5D96P`4&5N8V%R:6%N($=O;V=L90!9=6YA;FD@*$E33RTX
M.#4Y+3<I`$%D;6EN:7-T<F%S:2!'<G5P`$=R=7``27II;B!T86UU`$)U:W4@
M=&%M=0!(5$U,07)E82!D96YG86X@<F%G=2!M96YO;&%K('5N='5K(&UE;F=H
M87!U<R!S96P@>6%N9R!T97)A:VAI<B!D:2!D86QA;2!B87)I<RX`2%1-3$%R
M96$@9&5N9V%N(')A9W4@;65N;VQA:R!U;G1U:R!M96YG:&%P=7,@:V]L;VT@
M>6%N9R!T97)A:VAI<B!D:2!D86QA;2!T86)E;"X`2%1-3$%R96$@9&5N9V%N
M(')A9W4@;65N;VQA:R!U;G1U:R!M96YG:&%P=7,@8F%R:7,@>6%N9R!T97)A
M:VAI<B!D:2!D86QA;2!T86)E;"X`0F5R:V%B=70`66%H=61I("A)4T\M.#@U
M.2TX+4DI`%1I;F=G:0!"86YT=6%N`$)A;G1U86X@;65N9V=U;F%K86X@961I
M=&]R`$)E;&%H86X@0G5M:0!);FD@861A;&%H('!E<FUU;&%A;B!D87)I(&9I
M;&4Z`%1I;F=G:0!(;U]M90!$:7)E:W1O<FD@2&]M90!(;W)D90!'87)I<R!(
M;W)I<V]N=&%L(&1I(&1A;&%M($A434P`2F%R86L@9V%R:7,@:&]R:7IO;G1A
M;"!D87)I(&)O<F1E<B!D96YG86X@=&5K<R!D:2!D86QA;2!S96P`2&]R:7IO
M;G1A;#H`0F%G86EM86YA(&-A<F$@86YD82!B:7-A('-A;7!A:2!D:7-I;FD_
M("A3:6QA:V%N(&UE;&%P;W(A*0!"97)A<&$@8F%N>6%K(&MO;&]M('EA;F<@
M:6YG:6X@86YD82!G86)U;F=K86X_`$)E<F%P82!B86YY86L@:V]L;VT@>6%N
M9R!A9&$@9&ES86YA/P!"97)A<&$@8F%N>6%K(&)A<FES('EA;F<@:6YG:6X@
M86YD82!G86)U;F=K86X_`$ME;&5M8F%B86X`2V5L96UB86)A;CH`4&5L87=A
M:P!-87-U:VMA;B!"87)I<R!396)E;'5M;GEA`$AA;GEA(&EK;VX`26MO;B!U
M;G1U:R`E<P!):V]N(&1E;F=A;B!T96MS`$YA;6$@261E;G1I=&%S.@!*:6MA
M(&%N9&$@=&ED86L@;65L:6AA="!I:V]N(&UA;F%P=6X@9&5N9V%N(&UE;F=G
M=6YA:V%N($EN=&5R;F5T($5X<&QO<F5R+"!A;F1A(&UU;F=K:6X@<&5R;'4@
M=6YT=6L@;65N86YD86D@:V]T86L@:6YI('5N='5K(&UE;F]N+6%K=&EF:V%N
M(&ME;&5M86AA;B!03D<N`$QI:&%T($=A;6)A<CH`55),($=A;6)A<@!54DP@
M1V%M8F%R.@!'86UB87(@9&%R:2!G86QE<FD`1V%M8F%R(&1A<FD@9V%L97)I
M.@!'86UB87(M9V%M8F%R`$EM<&]R+"!,86YG:V%H("5D`$MO;&]M('EA;F<@
M9&EI;7!O<CH@)7,`2V]L;VT@>6%N9R!D:6EM<&]R.@!-87-U:VMA;B!"87)I
M<R!"97)I:W5T;GEA`$YA;6$@<&5N9V=U;F$@871A=2!A;&%M870@96UA:6P@
M<&5N9V=A;G1I('1I9&%K(&)E;F%R+B!#;V)A(&QA9VD@871A=2!S:6QA:V%N
M(&AU8G5N9VD@861M:6YI<W1R871O<B!A;F1A(&II:V$@86YD82!M96UE<FQU
M:V%N(&)A;G1U86X@;&5B:6@@;&%N:G5T+@!-96YA;6)A:"!);F1E;@!096YG
M9W5N82!0<FEB861I`$EN9F]R;6%S:0!);F9O<FUA<VD@<W5D86@@=&ED86L@
M9&ES961I86MA;BX`36%S=6MK86X@2V]L;VT@0F5R:6MU=&YY80!-87-U:VMA
M;B!'86UB87(`36%S=6MK86X@5&%B96P`36%S=6MK86X@5V5B($QI;FL`36%S
M=6MK86X@2V]L;VT@4V5B96QU;6YY80!-87-U:VMA;B!K;VQO;2!Y86YG(&)A
M<G4@<V5T96QA:"!K;VQO;2!Y86YG('-E:V%R86YG`$UA<W5K:V%N(&MO;&]M
M('EA;F<@8F%R=2!S96)E;'5M(&MO;&]M('EA;F<@<V5K87)A;F<`36%S=6MK
M86X@8F%R:7,@>6%N9R!B87)U('-E=&5L86@@8F%R:7,@>6%N9R!S96MA<F%N
M9P!-87-U:VMA;B!B87)I<R!Y86YG(&)A<G4@<V5B96QU;2!K;VQO;2!Y86YG
M('-E:V%R86YG`$UA<W5K:V%N('!A<F%G<F%F('-E=&5L86@@<&%R86=R868@
M>6%N9R!S96MA<F%N9P!-87-U:VMA;B!P87)A9W)A9B!S96)E;'5M('!A<F%G
M<F%F('EA;F<@<V5K87)A;F<`36%S=6MK86X@=&5M<&QA=&4@<&5N9V=A;G1I
M`$UA<W5K:V%N(&%L86UA="!E;6%I;"!D:6UA;F$@86YD82!D87!A="!M96YE
M<FEM82!S86YD:2!Y86YG(&)A<G4Z`$UA<W5K:V%N('-E;"!B97)I:W5T;GEA
M`$UA<W5K:V%N('-E;"!S96)E;'5M;GEA`$UA<W5K:V%N(&MO;&]M(&)E<FEK
M=71N>6$`36%S=6MK86X@:V]L;VT@<V5B96QU;6YY80!-87-U:VMA;B!P87)A
M9W)A9B!B97)I:W5T;GEA`$UA<W5K:V%N('!A<F%G<F%F('-E8F5L=6UN>6$`
M36%S=6MK86X@8F%R:7,@8F5R:6MU=&YY80!-87-U:VMA;B!B87)I<R!S96)E
M;'5M;GEA`$UA<W5K:V%N(&IA=V%B86X@>6%N9R!D:7!E<FQU:V%N('5N='5K
M('!E<G1A;GEA86%N(&ME86UA;F%N.@!-87-U:VMA;B]58F%H($=A;6)A<@!-
M87-U:VMA;B]58F%H($QI;FL`07!L:6MA<VD@=&ED86L@=F%L:60N`$EZ:6X@
M:6YD=6L@=&ED86L@=F%L:60N`$EN=F5N=&]R:7,`2'5J86X@<&5T:7(@9&ES
M97)T86D@86YG:6X@<FEB=70@9&D@9&%E<F%H('EA;F<@=&5R<&5N8VEL`$AU
M<G5F($UI<FEN9P!*86YU87)I`$IE<&%N9R`H25-/+3(P,C(M2E`I`$IU;&D`
M2G5N:0!2871A`%)A=&$@5&5N9V%H`%)A=&$@2VER:2!D86X@2V%N86X`4F%T
M82!+:7)I`%)A=&$@2V%N86X`2V5R;F5L($YE=V)I97,`06YA:RUA;F%K`$MO
M<F5A("A%54,M2U(I`%1A;7!I;&%N`$)A:&%S80!&87-E('1E<F%K:&ER(&1A
M<FD@4V5P87)U:"!"=6QA;@!097)U8F%H86X@4V%N9&D@5&5R86MH:7(`1F%S
M92!T97)A:VAI<B!D87)I(%-E<&%R=6@@0G5L86X`4&5R=6)A:&%N(%1E<F%K
M:7(Z`$AU:W5M`%1A;7!I;&%N`%1I;F=G86QK86X@:V]S;VYG('1A;G!A(&)O
M<F1E<@!+:7)I`$=E<FEM:7,`1V5R:6UI<P!'97)I;6ES(&1I('!A9VD@:&%R
M:0!'97)I;6ES(&)E8F5R87!A('-A870@;&%G:0!'97)I;6ES`$=E<FEM:7,@
M9&ES97)T86D@<&5T:7(`0F5R<V%L:G4`1V5R:6UI<R!386QJ=0!086YT=6X@
M2F5N86MA`$QI;FL@;65N=6YJ=6L@:V4Z`$QI;G5X($-O;VMI90!$869T87(@
M1&%T86)A<V4`1&%F=&%R(%1O<&EK($)A;G1U86X`1&%F=&%R(%1A8F5L`$1A
M9G1A<B!P96YG9W5N82!D:6YO;BUA:W1I9FMA;BX`1&%F=&%R($)A8V%A;@!7
M86MT=2!L;V-A;#H`5&5M<&%T(%!E<FES=&EW82!D86X@5V%K='4`3&]K87-I
M`$QO9VEN`$QO9R!O=70`3&]G:6X`5'5G87,@3&]G:6X`0VEN=&$`4F5N9&%H
M`%-I;6)O;"!(=7)U9B!K96-I;"!Y=6YA;FD`4VEM8F]L($AU<G5F(&ME8VEL
M(&QA=&EN`%-I;6)O;"!(=7)U9B!K96-I;"!R;VUA=VD`34T`34]41`!3=6QA
M<`!3=7)A=`!3=7)A="!!9&UI;@!"=6%T(&QI;FLN+BX`365N9V%T=7(@9&%F
M=&%R(&MA=&5G;W)I('EA;F<@:&%R=7,@9&EB97)I(&QA8F5L(&ET96TL(&1A
M;B!W87)N82!Y86YG(&)E<FAU8G5N9V%N("!D96YG86X@:V%T96=O<FD@=&5R
M<V5B=70N`$UA<F5T`$UA<F=I;@!-96YC;V-O:VMA;B!K;VQO;0`@4W5H=2!M
M86MS:6UU;2!Y86YG(&)E<FQA;F=S=6YG('-E;&%M82`R-"!J86TZ`%-U:'4@
M;6%K<VEM=6T@>6%N9R!B97)L86YG<W5N9R!S96QA;6$@-B!J86TZ`$IU;6QA
M:"!M86MS:6UU;2!D87)I('!O<G1A;"!Y86YG(&1I8FQO:VER`$UE:0!/8F%T
M+6]B871A;@!!;F=G;W1A`$UE;G4@;6]D93H`1V%B=6YG:V%N('-E;``@0W5A
M8V$@365T87(`07)E82!-971A<B!T:61A:R!D:7-E9&EA:V%N+@!!<F5A($UE
M=&%R('1I9&%K(&1I<V5D:6%K86XN($1E=&EL('1E;&%H(&1I8V%T870@=6YT
M=6L@861M:6YI<W1R871O<BX`365T<FEK`%1E;F=A:`!3=6AU(&UI;FEM=6T@
M>6%N9R!B97)L86YG<W5N9R!S96QA;6$@,C0@:F%M.@!3=6AU(&UI;FEM=6T@
M>6%N9R!B97)L86YG<W5N9R!S96QA;6$@-B!J86TZ`$QA:6XM;&%I;@!+;VYF
M:6=U<F%S:2!T:61A:R!D:71E;75K86XN($%N9&$@:&%R=7,@;65N9VAA<VEK
M86X@:V]N9FEG=7)A<VD@<V5K87)A;F<@:FEK82!A;F1A(&EN9VEN(&UE;F=G
M=6YA:V%N(&%P;&EK87-I(&EN:2X`4V5N`$UO8FEL92!-86EL`%-E9&%N9P!5
M8F%H(%523`!&87-E($)U;&%N`%-E8F%G:6%N(&)E<V%R($-E<F%H`%-E8F%G
M:6%N(&)E<V%R($)E<F%W86X`4V5B86=I86X@8F5S87(@0V5R86@`06-C;W5N
M="UK=0!);F9O<FUA<VD@06-C;W5N="UK=0!0;W)T86QK=0!486UP:6QA;B!0
M;W)T86QK=0!4241!2RP@4V%Y82!4241!2R!3971U:G4`3F5T=V]R:P!4:61A
M:R!P97)N86@`2V%T96=O<FD@0F%R=0!"=6QA;B!"87)U`$YA;6$@4&5N9V=U
M;F$@0F%R=2`H<&EL:6AA;BD`4V%N9&D@0F%R=0!386YD:2!B87)U('1I9&%K
M(&-O8V]K+@!7:6YD;W<@0F%R=2`H7V)L86YK*0!"97)I=&$`1W)U<"!"97)I
M=&$`0F5R:6MU=&YY80!-86QA;0!4:61A:R!A9&$@9&%T82!K;VYF:6=U<F%S
M:2!Y86YG('1E<G-E9&EA('5N='5K(&UE;G5N:G5K:V%N('!E<F)E9&%A;B!U
M;G1U:RX`5&ED86L@861A('!E<G5B86AA;BX`5&ED86L@861A(&EK;VX@>6%N
M9R!D:71E;75K86XN`%1I9&%K(&%D82!L;VMA<VD@>6%N9R!D:6%T=7(N`%1I
M9&%K(&%D82!R86UA;&%N('EA;F<@=&ED86L@<V]P86X`5&ED86L@861A('!E
M;F1A9G1A<F%N('EA;F<@9&ET=6YD82X`5&ED86L@861A(&%T=7)A;@!4:61A
M:R!A9&$@<VES:0!4:61A:R!A9&$@9&ER96MT;W)I('-E;65N=&%R82!Y86YG
M('1E<G-E9&EA('5N='5K(&-A8VAE`%1I9&%K(&%D82!V97)S:2!Y86YG(&1I
M=&5M=6MA;B!D:2!D86QA;2!K;VYF:6=U<F%S:2!Y86YG(&%S;&DN($UE;F=H
M87-I;&MA;B!K;VYF:6=U<F%S:2!K96UB86QI+@!4:61A:R!A9&$@=F5R<VD@
M>6%N9R!D:71E;75K86X@9&D@9&%L86T@:V]N9FEG=7)A<VD@86YD82X@365N
M9VAA<VEL:V%N(&MO;F9I9W5R87-I(&ME;6)A;&DN`%1I9&%K(&%D80!4:61A
M:R!A9&$@*&1I9W5N86MA;B!S96QE;F=K87!N>6$I`%-C86YD:6YA=FEA("A)
M4T\M.#@U.2TQ,"D`0F5L86AA;B!"=6UI(%5T87)A`$)E;'5M(&1I871U<@!#
M871A=&%N`%1I9&%K(&%D82!Y86YG(&1A<&%T(&1I8G)O=W-E+"!S:6QA:V%N
M(&ME;6)A;&DN`$YO=F5M8F5R`$IU;6QA:"!K;VQO;0!*=6UL86@@8F%R:7,`
M3TL`4&5N8VEP=&$@3V)J96L`3VMT;V)E<@!&:6QT97(@4&5L86YG9V%R86X`
M2V%N=&]R`%-A;F1I(&QA;6$@9&%N(&)A<G4@:&%R=7,@8F5R8F5D82X`4V%N
M9&D@;&%M80!386YD:2!L86UA('1I9&%K(&)E;F%R+@!(86YY82!R86UA;&%N
M('EA;F<@=&ED86L@<V]P86X`2&%N>6$@<&5M:6QI:R!A=&%U('-I<W1E;2!A
M9&UI;FES=')A=&]R('-A:F$@>6%N9R!D87!A="!M96YG=6)A:"!K97!E;6EL
M:6MA;B!A=&%U('!E;6EL:6L@:7II;B!U;G1U:R!B86=I86X`0G5K82!D:2!J
M96YD96QA('EA;F<@8F%R=0!"=6MA(&QI;FL@:6YI(&1I(&IE;F1E;&$@>6%N
M9R!B87)U`%-I<W1E;2!/<&5R87-I`%!I;&EH86X`4&EL:6AA;B!U;G1U:R`E
M<P!$869T87(@3F]M;W(@0F5R=7)U=`!-96YG871U<@!!<&QI:V%S:2!T96UP
M;&%T92!A<VQI`%1E;7!L871E(&%S;&D@9&D@9&%L86T@)7,Z`$QA:6XM;&%I
M;@!);F9O<FUA<VD@3&%I;@!)>FEN(%!E;6EL:6L`2V]D92!02%``4$A0(%-H
M96QL`%!-($=E<FEM:7,`4$T@1V5R:6UI<P!032!"97)S86QJ=0!032!'97)I
M;6ES(%-A;&IU`%!-($-E<F%H`%!-($AU:F%N('!E=&ER(&1I<V5R=&%I(&1E
M;F=A;B!A;F=I;B!R:6)U=`!%:W-T96YS:2!03U-)6"!T:61A:R!D:71E;75K
M86X`4$A0(%-H96QL`$IA<F%K('-P87-I(&1A<FD@8F]R9&5R`%-E8F%G:6%N
M($)E<F%W86X`4V%N9&D`4V%N9&D@8F5R:&%S:6P@9&EU8F%H+@!386YD:3H`
M4V%N9&DZ`%-A;F1I(&AA<G5S(&-O8V]K+@!386QI;@!,96MA=&MA;B!D87)I
M(&-L:7!B;V%R9`!0871H`%!E;F1A9G1A<F%N('EA;F<@9&ET=6YD83H`3W)A
M;F<`4&5R<V5N`$UE;&%K<V%N86MA;B!/<&5R87-I(%!E;65L:6AA<F%A;@!-
M96QA:W-A;F%K86X@;W!E<F%S:2!P96UE;&EH87)A86X@<&%D82!W86MT=2!L
M;V=I;C\`27II;B!U;G1U:R`B)7,B('1I9&%K(&1A<&%T(&1I:&%P=7,N`$EZ
M:6X@061M:6YI<W1R87-I`$EN9F]R;6%S:2!0<FEB861I`$)I;F%T86YG($ME
M<V%Y86YG86X`1F]T;P!0:7AE;`!+871A+6MA=&$@:VQI<V4`4VEL86MA;B!K
M;&EK(&ME(&1A;&%M(&)E8F5R87!A('-E;`!3:6QA:V%N(&MO;F9I<FUA<VD@
M8F%H=V$@86YD82!I;F=I;B!M96UI;F1A:&MA;B!E;&5M96X@:6YI.@!3:6QA
M:V%N(&MO;F9I<FUA<VD@8F%H=V$@86YD82!I;F=I;B!M96YG:&%P=7,@;&EN
M:R!U;G1U:R!E;&5M96X@:6YI+@!3:6QA:V%N(&UA<W5K:V%N(&YA;6$@=6YT
M=6L@:V%T96=O<FD@>6%N9R!B87)U.@!3:6QA:V%N(&UA<W5K:V%N(')I;F=K
M87-A;B!U;G1U:R!M87-A;&%H+@!3:6QA:V%N(&UA<W5K:V%N(&YA;6$@<&5N
M9V=U;F$@9&%N('-A;F1I(&%N9&$`4VEL86MA;B!M96UB86-A('1E:W,@8F5R
M:6MU="!I;FDN($%N9&$@2$%255,@<V5T=6IU(&1E;F=A;B!S>6%R870M<WEA
M<F%T('5N='5K(&UE;F=G=6YA:V%N('-I<W1E;2X`4&]L:71I:P!0;VQL:6YG
M`%!O<VES:2!U;G1U:R!G86UB87(@:6YI`%!O<VES:2!U;G1U:R!T86)E;"!I
M;FD`2'5J86X@<V%L:G4@=6YT=6L@)7,@:F%M('1E<F%K:&ER.@!+96UU;F=K
M:6YA;B`\8G(O/DAU:F%N('-A;&IU`%1E:V%N86X`5&5K86YA;B!P861A('!E
M<FUU:V%A;B!L875T.@!496MA;F%N.@!,:6AA=`!,:6AA="!G86UB87(@9&D@
M9&%L86T@:F5N9&5L82!Y86YG(&)A<G4`0V5T86L@9&]K=6UE;@!$97-K<FEP
M<VD@36%S86QA:`!0<F]J96L`475E<GD`2W5O=&$`2'5J86X`2'5J86X@9&D@
M<&%G:2!H87)I`$AU:F%N(&)E8F5R87!A('-A870@;&%G:0!'97)I;6ES`$AU
M:F%N(&1A;B!"97)S86QJ=0!(=6IA;B!B97)C86UP=7(@9&5N9V%N('-A;&IU
M`%)A;6%L86X@06-A:P!"86-A`%EA:VEN('5N='5K(&UE;F=H87!U<R`E<S\@
M3W!E<F%S:2!I;FD@=&ED86L@9&%P870@9&EB871A;&MA;BX`66%K:6X@=6YT
M=6L@;65M:6YD86AK86X@9&%T82!P96YG9W5N82!U;G1U:R!P96YG9W5N82`E
M<S\@3W!E<F%S:2!I;FD@=&ED86L@9&%P870@9&EB871A;&MA;BX`56QA;F=I
M(&%K<VD@=&5R86MH:7(@86YD80!2969R97-H($5L96UE;B!-96YU($1I;F%M
M:7,Z`%)E9G)E<V@@3&EH870@4&]R=&%L.@!$:71A;F1A:0!296UO=&4@4V5R
M=F5R`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I
M`%!I;F1A:&MA;@!0:6YD86AK86X@0FQO:VER`%!I;F1A:&MA;B!#87)A($9O
M<FUA=`!0:6YD86AK86X@<&%S86YG86X`4&EN9&%H:V%N('-C<FEP="!Y86YG
M('-U9&%H(&1I<VEM<&%N(&1A<FD@9&ER96MT;W)I('-E<G9E<B!S96UE;G1A
M<F$N`%!I;F1A:&MA;@!0:6YD86AK86X@;F]D92!I;FD@9&%R:2!D;VMU;65N
M`%!I;F1A:&MA;B!P96YG9W5N80!0:6YD86AK86X@<&5N9V=U;F$Z("5S`$%T
M=7(@:V5M8F%L:2``071U<B!K96UB86QI(%-A;F1I`$%T=7(@:V5M8F%L:2!3
M86YD:2!!;F1A`$AA<VEL`$ME;6)A;&D@:V4@4&EL:6AA;@!+971I:R!U;&%N
M9R!S86YD:2!B87)U`$ME;6)A;&D@:V4@2V]N9FEG=7)A<VD`4&EL:6AA;B!%
M9&ET;W(@4FEC:"!497AT`%1E:V$M=&5K:0!+86YA;@!0<F]P97)T:2!"87)I
M<RXN+@!0<F]P97)T:2!"87)I<P!0<F]P97)T:2!B87)I<P!"87)I<SH`071U
M<F%N`$%T=7)A;B!A:V%N(&1I=&%M<&EL:V%N(&1I86YT87)A('-E;75A(&)A
M<FES(&1A;B!K;VQO;0!!='5R86X@86MA;B!D:71A;7!I;&MA;B!H86YY82!D
M:6%N=&%R82!K;VQO;0!!='5R86X@86MA;B!D:71A;7!I;&MA;B!H86YY82!D
M:6%N=&%R82!B87)I<P!*86QA;FMA;@!097-A;B!335,`4U%,(%-H96QL`%-3
M2`!37U%,(%-H96QL`%-B=`!&<F%M92!Y86YG('-A;6$@*%]S96QF*0!3:6UP
M86X`4VEM<&%N("5S`%-I;7!A;B!0:6QI:&%N`%-I;7!A;B!K;VYF:6=U<F%S
M:2!Y86YG(&1I:&%S:6QK86X@<V5B86=A:2!S8W)I<'0@4$A0(&ME(&1A;&%M
M(&1I<F5K=&]R:2!S97)V97(@<V5M96YT87)A(&%N9&$N`$MO;F9I9W5R87-I
M("5S('-U9&%H(&1I<VEM<&%N+@!396)A9VEA;B!(=6IA;B!P971I<B!D:7-E
M<G1A:2!A;F=I;B!R:6)U=`!);&UU(%!E;F=E=&%H=6%N`%!E;F-A<FEA;@!-
M97-I;B!096YC87)I86X`4&EL:6@@9W)U<"!U;G1U:R!D:71A;6)A:`!0:6QI
M:"!P96UI;&EK(&)A<G4`4&EL:6@@<V5R=F5R`%!I;&EH('!E;F=G=6YA('5N
M='5K(&1I=&%M8F%H`%!I;&EH(&MA<F%K=&5R('EA;F<@86YD82!P97)L=6MA
M;B!D87)I(&MO=&%K+6MO=&%K(&1I8F%W86@@:6YI+B!!;F1A(&1A<&%T(&UE
M;GEA;&EN(&1A;B!M96QE:V%T:V%N;GEA(&ME(&1A;&%M(&%R96$@=&5K<RX`
M4&EL:6@@8F%T87,@=&%N9V=A;#H`4&EL:6@@9F]R;6%T('1A;F=G86PZ`%!I
M;&EH(&ED96YT:71A<R!Y86YG(&EN9VEN(&1I=6)A:"!O;&5H(&%N9&$Z`%!I
M;&EH(&)A=&%S('=A:W1U.@!0:6QI:"!F;W)M870@=V%K='4Z`%!I;&EH(&1U
M82!K;VQO;2!Y86YG(&-O8V]K+@!0:6QI:"!W87)N82!S8VAE;64@86YD82X`
M4&EL:6@@8F%H87-A('EA;F<@86YD82!I;F=I;FMA;CH`2VER:6T@3&%P;W)A
M;B!-87-A;&%H`%-E;G-O<CH`4V5P=&5M8F5R`$%T=7(@<&EL:6AA;B!U;G1U
M:R!M96YG:7II;FMA;B!A;F1A(&1A<&%T(&UE;F=A='5R('5L86YG(&ME;6)A
M;&D@<V%N9&D@86YD82!A<&%B:6QA(&%N9&$@;'5P82X`071U<B!R96UO=&4@
M<V5R=F5R('EA;F<@:6YG:6X@86YD82!A:W-E<R!D87)I('!O<G1A;"!A;F1A
M+@!!='5R(&)A:&%S82P@>F]N82!W86MT=2!D86X@<&EL:6AA;B!T86YG9V%L
M+"!Y86YG(&%N9&$@:6YG:6YK86XN`$%T=7(@87!L:6MA<VD@87=A;"!A;F1A
M+"!W87)N82!S8VAE;64L(&AA;&%M86X@<F5F<F5S:"!D86X@<&EL:6AA;B!T
M86UP:6QA;B!L86EN;GEA+@!3971U<`!38W)I<'0@<V5T=7`@=7!G<F%D92!T
M97)S961I80!"96)E<F%P82!L;VMA<VD@>6%N9R!M=6YG:VEN(&1E;F=A;B!P
M87)A;65T97(Z`$)E;&%N:F$`4FEN9VMA<V%N(%!E;F1E:P!097)L=6MA:"!K
M=6YC:2!A:W-E<R!D:61E9FEN:7-I:V%N('5N='5K(&ME8F%N>6%K86X@;&EN
M:S\`5&%M<&EL:V%N`%1A;7!I;&MA;B!P97)B961A86X@9&EA;G1A<F$@:V]N
M9FEG=7)A<VD@>6%N9R!B87)U(&1I<VEM<&%N(&1A;B!Y86YG(&)A<G4@9&EH
M87-I;&MA;BX`5&%M<&EL:V%N('=A:W1U(&QO9VEN('1E<F%K:&ER(&ME=&EK
M82!A;F1A(&QO9VEN/P!486UP:6QK86X@<&%N96P@;65N=2!T86)E;"!O<&5R
M87-I/P!486UP:6QK86X@365N=2`E<R!D:2!S96)E;&%H(&MI<FD_`%1A;7!I
M;&MA;B!D:6%L;V<@4')O<&5R=&D@4V5L(%1A8F5L`%1A;7!I;&MA;B!D:6%L
M;V<@4')O<&5R=&D@5&%B96P`5&%M<&EL:V%N(&1I86QO9R!0<F]P97)T:2!"
M87)I<R!486)E;`!486UP:6QK86X@9&EA;&]G('!R;W!E<G1I(&=A;6)A<@!'
M97)I;6ES`$=E<FEM:7,@9&D@<&%G:2!H87)I`$=E<FEM:7,@8F5B97)A<&$@
M<V%A="!L86=I`$=E<FEM:7,@9&D@<V5K:71A<B!D865R86@`3&5W871I(%!E
M;65L:6AA<F%A;@!386QJ=0!'97)I;6ES(%-A;&IU`$=E<FEM:7,@4V%L:G4`
M1V5R:6UI<R!386QJ=2!D:2!P86=I(&AA<FD`1V5R:6UI<R!386QJ=2!B96)E
M<F%P82!S86%T(&QA9VD`2V5D86QA;6%N(%-A;&IU.@!097)B86YD:6YG86X@
M<V%L:G4@9&D@*&1A;&%M*2!A:7(Z`$QA9W4@)B!386IA:P!%<F]P82!396QA
M=&%N("A)4T\M.#@U.2TS*0!"96QA:&%N($)U;6D@4V5L871A;@!*87)A:R!A
M;G1A<F$@<V5L('EA;F<@8F5R9&5K871A;@!*87)A:R!A;G1A<F$@:7-I(&1A
M;B!B;W)D97(@9&D@9&%L86T@<V5L`$IA<F%K('-P87-I`$IA<F%K('-P87-I
M(&1A;B!J87)A:R!S<&%S:2!D87)I(&)O<F1E<@!3<&%M`$UA<W5K:V%N($MA
M<F%K=&5R(%-P97-I86P`4&ES86AK86X@4V5L`%!I<V%H:V%N(&MO;&]M`%!I
M<V%H:V%N(&)A<FES`$]L86AR86=A`%-T86YD87(`4&5R:F%L86YA;B!":6YT
M86YG`%-T871U<P!!;F=K82]H=7)U9B]S:6UB;VP@>6%N9R!D:6)E<FD@=&%N
M9&$@9V%R:7,`1V%Y82!;0U-370!-:6X`06YG:V$O:'5R=68O<VEM8F]L('EA
M;F<@9&ET=6QI<R!D:6)A=V%H(&=A<FES(&)A<FES('1E:W,`0F5R:&%S:6P`
M(B5S(G-U9&%H(&)E<FAA<VEL(&1I:&%P=7,N`$MO;F9I9W5R87-I('-U9&%H
M(&)E<FAA<VEL(&1I:V5M8F%L:6MA;BX@56QA;F=I('5N='5K(&UE;&EH870@
M<&5R=6)A:&%N+B``0F%C:W5P(&MO;F9I9W5R87-I('-U9&%H(&)E<FAA<VEL
M(&1I<VEM<&%N+@!&:6QE($)A8VMU<"!+;VYF:6=U<F%S:2`E<R!S=61A:"!B
M97)H87-I;"!D:7-I;7!A;BX`)R5S)R!S=61A:"!B97)H87-I;"!D:71U;&ES
M`%)I;F=K87-A;@!-871A:&%R:2!497)B:70`36%T86AA<FD@5&5R8F5N86T`
M0V5R86@`36%T86AA<FD@5&5R8FET`$UA=&%H87)I(%1E<F)I="]-871A:&%R
M:2!497)B96YA;0!-871A:&%R:2!497)B:70Z`$UA=&%H87)I(%1E<F)E;F%M
M`$UA=&%H87)I(%1E<F)E;F%M.@!!;F=K82]H=7)U9B]S:6UB;VP@>6%N9R!D
M:71U;&ES(&1I871A<R!B87)I<R!T96MS`$1U:W5N9V%N`$AU:F%N('!E=&ER
M(&1I<V5R=&%I(&1E;F=A;B!A;F=I;B!R:6)U=`!(=6IA;B!P971I<B!D:7-E
M<G1A:2!D96YG86X@8F%D86D@86YG:6X@<FEB=70`2'5J86X@<&5T:7(@9&ES
M97)T86D@9&5N9V%N(&%N9VEN(')I8G5T`%!R;W!E<G1I(%1A8F5L`%!R;W!E
M<G1I('1A8F5L`%1A<F=E=#H`5'5G87,`4W5H=2!U;G1U:R!J86T@=&5R86MH
M:7(Z`%-U:'4`4W5H=3H`4W5H=3QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G
M.R5S`%1E;7!L871E($%D;6EN:7-T<F%S:0!(86YY82!496MS`%!E<F%T86%N
M(%1E:W,`5&5K<R!"86=I86X@071A<P!+;7,`5&AA:2`H5$E3+38R,"D`4&5M
M96QI:&%R86%N.CH@8VQA<W,@=&ED86L@8F5R:&%S:6P@9&EP86YG9VEL`%=I
M;F1O=R!0:6QI:&%N('-U9&%H(&1I='5T=7`N(%-I;&%K86X@2V5L=6%R`$AA
M;GEA('-I<VD@8F%G:6%N(&)A=V%H`$UO9&4@3&%Y87(@4&5N=6@@9&EK96YA
M;"!D87!A="!M96YY96)A8FMA;B!M87-A;&%H(&1E;F=A;B!);G1E<FYE="!%
M>'!L;W)E<BP@:G5G82!U;G1U:R!M96YC87)I(&ME<V%L86AA;B!Y86YG(&UE
M;GEE8F%B:V%N(&%N9&$@=&ED86L@;6%M<'4@8F5K97)J82!D96YG86X@8F%I
M:RX@06YD82!M=6YG:VEN('!E<FYA:"!M96YG86QA;6D@=&%M<&EL86X@>6%N
M9R!B=7)U:RP@:V5K=7)A;F=A;B!D87)I(&9U;F=S:2!E9&ET;W(@9&%N+V%T
M874@8G)O=W-E<B!Y86YG('-E<FEN9R!K86QI(')U<V%K(&1A;B!H87)U<R!D
M:75L86YG(&ME;6)A;&DN($II:V$@<VES=&5M(&%N9&$@861A;&%H(%=I;F1O
M=W,@.7@@861A(&ME;75N9VMI;F%N(&%N9&$@86MA;B!M96YD87!A=&MA;B`G
M2V5S86QA:&%N(%!E<FQI;F1U;F=A;B!5;75M)R!D86X@<&5R;'4@=6YT=6L@
M;64M<F5S=&%R="!K;VUP=71E<B!A;F1A+EQN7&X@06YD82!S=61A:"!D:7!E
M<FEN9V%T:2X@4VEL86MA;B!K;&EK($]+(&II:V$@86YD82!I;F=I;B!M96YC
M;V)A(&5D:71O<B!L87EA<B!P96YU:"X`261E;G1I=&%S("(E<R(@<W5D86@@
M9&EH87!U<RX`2&%N>6$@<VES:2!B86=I86X@:VER:0!(86YY82!S:7-I(&)A
M9VEA;B!K86YA;B!D86X@:VER:0!(86YY82!S:7-I(&)A9VEA;B!K86YA;@!3
M97)V97(@(B5S(B!S=61A:"!B97)H87-I;"!D:6AA<'5S+@!397)V97(@(B5S
M(B!S=61A:"!B97)H87-I;"!D:7-I;7!A;BX`4&5R;6EN=&%A;B!P96YD869T
M87)A;B!U;G1U:R`E<R!S=61A:"!B97)H87-I;"!D:7!I;F1A:&MA;BX`2&%N
M>6$@<VES:2!B86=I86X@871A<R!D86X@8F%W86@`2&%N>6$@<VES:2!B86=I
M86X@871A<P!!<F5A(&ME('=E871H97(N8V]M('1I9&%K(&1I<V5D:6%K86XN
M`$%D82!K97-A;&%H86X@9&D@9&%L86T@9F]R;75L:7(@:V]N9FEG=7)A<VDN
M($UU;F=K:6X@86YD82!T:61A:R!M96YG:7-I(&MO;&]M('EA;F<@9&EP97)L
M=6MA;BX`26YI(&%D86QA:"`E<RX`5VEN9&]W(&EN:2!H87)U<R!D:7!A;F=G
M:6P@9&%R:2!0:6QI:&%N(%=I;F1O=P!0971I<@!4:6ME=`!-96YG:6MU=&D@
M5V%K='4`1F]R;6%T(%=A:W1U`$IU9'5L`$IU9'5L("A#871A=&%N('!E='5N
M:G5K*0!(87)I($EN:0!'86YT:2!3;W5R8V4@2%1-3`!"97-O:P!!=&%S`$9R
M86UE($%T87,@*%]T;W`I`%1R86YS;&%S:0!396P`5'5R:VD@*$E33RTX.#4Y
M+3DI`$EN9&5K<R!5+E8Z`%523`!54DPZ`%1I9&%K(&1A<&%T('5N='5K(&UE
M;F=H87!U<R`B)7,B.B`E<RX`1V%R:7,@8F%W86@`0F%T86QK86X@4&5R=6)A
M:&%N`$)A=&%L:V%N(&%K<VD@=&5R86MH:7(@86YD80!4:61A:R!D:6%R<VEP
M:V%N`%5N:6-O9&4@*%541BTX*0!5;FET`$)A=&%L:V%N(&QI;FL@<&%D82!E
M;&5M96X@>6%N9R!S96MA<F%N9P!38W)I<'0@>6%N9R!T:61A:R!M96UP=6YY
M86D@:&%K(&ES=&EM97=A('1I9&%K(&1A<&%T(&UE;F=A:W-E<R!(87!U<R]3
M86QI;B],96MA=&MA;B!S97-U86D@<F5N8V%N82!U;G1U:R!A;&%S86X@:V5A
M;6%N86XN2VQI:R!/2R!U;G1U:R!M96QI:&%T(&-A=&%T86X@=&5K;FES('!A
M9&$@;6]Z:6QL82YO<F<@9&EM86YA(&%N9&$@86MA;B!D:7!E<FQI:&%T:V%N
M(&-A<F$@8F%G86EM86YA('5N='5K(&UE;F=I>FEN:V%N('-C<FEP="!U;G1U
M:R!D87!A="!M96YG86MS97,@:V4@8VQI<&)O87)D+@!787)N82!B96QU;2!D
M:6%T=7(`4&5R8F%H87)U:0!097)B86AA<G5I("5S`%!E<F)A:&%R=6D@<&5N
M9V=U;F$`(B5S(B!S=61A:"!D:7!E<F)A:&%R=6DN`%-C<FEP="!U<&=R861E
M('-U9&%H(&1I:&%P=7,N`%5P;&]A9`!396UU82!F:6QE('-E='5P(&%P;&EK
M87-I('-U9&%H(&1I=7!L;V%D(&ME('-E<G9E<BX`4VEM8F]L(&AU<G5F(&)E
M<V%R(&QA=&EN`%-I;6)O;"!H=7)U9B!B97-A<B!R;VUA=VD`1W5N86MA;FQA
M:"!J:6MA(&YA;6$O<V%N9&D@86YD82!B97)B961A('5N='5K('-E<G9E<B!)
M35-0+@!!9&UI;FES=')A<VD@4&5N9V=U;F$`4&5N9&%F=&%R86X@4&5N9V=U
M;F$`4&5N9&%F=&%R86X@4&5N9V=U;F$@<W5D86@@9&EN;VXM86MT:69K86X@
M=6YT=6L@<VET92!I;FDN`$%C8V]U;G0@4&5N9V=U;F$@=&ED86L@9&ET96UU
M:V%N`$YA;6$@4&5N9V=U;F$`3F%M82!096YG9W5N83H`3F%M82!096YG9W5N
M83H`4&5N9V=U;F$@9&D@9&%L86T@<VES=&5M.@!,:6)U<F%N`%9A<FEA8FQE
M`%9E<G-I($MO;G1R;VP`2F%R86L@<&]S:7-I('9E<G1I:V%L(&%N=&%R82!G
M87)I<R!D87-A<B!D96YG86X@9V%M8F%R`$IA<F%K('!O<VES:2!V97)T:6MA
M;"!A;G1A<F$@8F]R9&5R(&1E;F=A;B!G86UB87(`5F5R=&EK86PZ`%-A;F=A
M="!4:6YG9VD`5FEE=&YA;2`H5DE30TE)*0!,:6AA="!W96(@<&%G92!E:W-T
M97)N86P`2F%R86L@4&%N9&%N9P!*87)A:R!086YD86YG.@!015))3D=!5$%.
M(2$A(%!)3D1!2$M!3B!30U))4%0@24Y)(%-%0T%202!-04Y504P@1$%222`E
M<RX`4&5R:6YG871A;@!286)U`%)A;6%L86X@0W5A8V$`1&%T82!#=6%C82!D
M:7-E9&EA:V%N(&]L96@`5V5B`%=E8B!3:71E`%-E;&%M870@1&%T86YG`%-E
M;&%M870@9&%T86YG(&ME("5S`%-E;&%M870@9&%T86YG+"`E<P!797-T97)N
M("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`07!A:V%H(&%P
M;&EK87-I("5S('!E<FQU(&1I=&%M<&EL:V%N('-E=&5L86@@;&]G:6X_`$%P
M86MA:"!Y86YG(&UE<G5P86MA;B!B871A<R!K87)A:W1E<C\`07!A:V%H('EA
M;F<@;65R=7!A:V%N(&MA<F%K=&5R(&EN9&5N=&%S:3\`1F%S92!Y86YG(&UA
M;F$`4&QU9VEN(&UA;F%K86@@>6%N9R!D87!A="!D:6%K=&EF:V%N('5N='5K
M(&5D:71O<B!2:6-H(%1E>'0N`$QE8F%R`$QE8F%R(&UE;G4@)7,@<&%D82!B
M86=I86X@:VER:2`H86MA;B!B97)P96YG87)U:"!P861A(&QO9VEN(&)E<FEK
M=71N>6$I`$QE8F%R('1A8F5L`$QE8F%R('5N:70`3&5B87(Z`%=I:VD`06YG
M:6X`06YG:6X@9&D@<&%G:2!H87)I`$ME8V5P871A;B!A;F=I;B!D:2!D86QA
M;2!K;F]T`$%N9VEN.@!!;F=I;CH`2V%T82!":6IA:W-A;F$`1&%F=&%R($ME
M:6YG:6YA;@!096ME<FIA86X`6"U2968`65D`66$L(%-!64$@4T5454I5`$%N
M9&$@8F5R861A(&1I(&1A;&%M($U/1$4@5$5+4RX@1W5N86MA;B!T;VUB;VP@
M6SP^72!U;G1U:R!M96YG9V%N=&D@:V5M8F%L:2!K92!D86QA;2!M;V1E(%=9
M4TE764<N`$%N9&$@=&ED86L@9&EI>FEN:V%N('5N='5K(&UE;6)U870@;&5B
M:6@@9&%R:2`E9"!A<F5A+@!!;F1A(&AA<G5S(&UE;FIE;&%S:V%N(&UA<V%L
M86@@<V5B96QU;2!A;F1A(&1A<&%T(&UE;F=I<FEM:V%N(&QA<&]R86X@;6%S
M86QA:"X`06YD82!H87)U<R!M96UA<W5K:V%N(%523"!D:6UA;F$@;&EN:R!I
M;FD@;65N=6YJ=6L@:V4`06YD82!H87)U<R!M96UI;&EH('-E<G9E<B!U;G1U
M:R!D87!A="!D:6AA<'5S+@!!;F1A(&AA<G5S(&UE;F5T87!K86X@;F%M82!P
M96YG9W5N82!Y86YG(&EN9VEN(&1I8F5R<VEH:V%N+@!!;F1A(&AA<G5S(&UE
M;F5T87!K86X@;F%M82!P96YG9W5N82!Y86YG(&EN9VEN(&1I<&EN9&%H:V%N
M+@!!;F1A(&AA<G5S(&UE;F5T87!K86X@;F%M82!P96YG9W5N82!U;G1U:R!D
M:71A;6)A:"X`06YD82!H87)U<R!M96YE=&%P:V%N(&YA;6$@<&5N9V=U;F$@
M=6YT=6L@9&EP97)B86AA<G5I+@!!;&%M870@16UA:6P@06YD80!!;F1A($1A
M<FDZ(&%L86UA=#H`26YF;W)M87-I($%N9&$`3F%M82!!;F1A`$)A8VME;F0@
M87-L:2!A;F1A('1I9&%K(&1A<&%T(&UE;F1U:W5N9R!P96YD869T87)A;B!P
M96YG9W5N82P@871A=2!F:71U<B!I;FD@<W5D86@@9&EN;VXM86MT:69K86X@
M=6YT=6L@8F5B97)A<&$@86QA<V%N(&QA:6X`0G)O=W-E<B!A;F1A('1I9&%K
M(&UE;F1U:W5N9R!U;G1U:R!F:71U<B!I;FDN`%IO;F$@5V%K='4@06YD82!3
M96MA<F%N9SH`1&5F875L="!I9&5N=&ET87,@86YD82!S=61A:"!D:75B86@N
M`$1E9F%U;'0@:61E;G1I=&%S(&%N9&$Z`$YA;6$@;&5N9VMA<"!A;F1A.@!3
M86YD:2!B87)U(&%N9&$@=6YT=6L@)7,@861A;&%H.B`E<P!386YD:2!A;F1A
M('-U9&%H(&1I871U<B!U;&%N9P!386YD:2!A;F1A('-U9&%H(&1I871U<B!U
M;&%N9RP@<&5R:6MS86QA:"!E;6%I;"!A;F1A(&1A;B!L;V=I;B!D96YG86X@
M;65N9V=U;F%K86X@<V%N9&D@8F%R=2!A;F1A`%)E;6]T92!S97)V97(@86YD
M83H`0V5R:6$`6U-E;6)U;GEI:V%N($EN9&5N=&%S:2!496MS70!;3&%P;W)A
M;B!-87-A;&%H70!;5&%M<&EL86X@26YD96YT87-I(%1E:W,@+0!?061M:6YI
M<W1R87-I`%]#3$D`7T1A=&%4<F5E`$AA<'5S($)A<FES`%]'<G5P`%!R;W!E
M<G1I($=A;6)A<BXN+@!58F%H($QI;FLN+BX`27II;@!0:6YD86AK86X@3&EN
M:RXN+@!?4V5T=7``4')O<&5R=&D@5&%B96PN+BX`4&5N9V=U;F$`5&5N86YG
M`&IA='5H`$1A<FD@)7,@*"5S*2!P861A("5S("5S`&%N9VEN(&ME;F-A;F<`
M;6%S:6@@9&D@9&%L86T@86YT<FEA;@!B87)I<UT`;F%M80!P97)S96X`<&EX
M96P`;F%I:P!T86UP:6QK86X@<&5R8F5D86%N`'1E=&%P`$ME=&EK('-A;F1I
M(&1U82!K86QI('5N='5K(&UE;F=K;VYF:7)M87-I`&UE;GEA='5K86X`=V5A
M=&AE<BYC;VT`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O
M:7-?25,O````````````````````````````````````````````````````
M`````````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S4S`#`R,#$R,P`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQO8V%L92]I<U])4R],0U]-15-304=%4R\`````````````
M````````````````````````````````````````````````````,#`P,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-3,`,#(Q
M-S$P`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VES7TE3+TQ#7TU%
M4U-!1T53+VAO<F1E+FUO````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,S<U
M,0`Q,#4Q-30S,S<U,P`P,C,S-34`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````WA($E0````!W````'````-0#``"C````C`<`
M```````8"@``#````!D*```#````)@H``!\````J"@``!0```$H*```&````
M4`H```0```!7"@``%@```%P*```&````<PH```8```!Z"@``&0```($*```4
M````FPH```0```"P"@``!@```+4*```H````O`H```0```#E"@``"````.H*
M```0````\PH```8````$"P``#P````L+```(````&PL```L````D"P``!```
M`#`+```-````-0L```4```!#"P``$````$D+```0````6@L```\```!K"P``
M#P```'L+```,````BPL```@```"8"P``!P```*$+```$````J0L```0```"N
M"P``$````+,+```'````Q`L```0```#,"P``!````-$+```(````U@L```T`
M``#?"P``#@```.T+```6````_`L``!$````3#```!@```"4,```&````+`P`
M``<````S#```!````#L,```'````0`P```D```!(#```!@```%(,```'````
M60P```L```!A#```!````&T,```&````<@P```@```!Y#```"````((,```$
M````BPP```4```"0#```!@```)8,```0````G0P```H```"N#````P```+D,
M```D````O0P```<```#B#```!@```.H,```?````\0P```8````1#0``#0``
M`!@-```"````)@T```H````I#0``!@```#0-```&````.PT```D```!"#0``
M!P```$P-```$````5`T```4```!9#0``!````%\-```"````9`T```0```!G
M#0``"````&P-```"````=0T```<```!X#0``!P```(`-```(````B`T``!0`
M``"1#0``*0```*8-```%````T`T```8```#6#0``'P```-T-```)````_0T`
M``0````'#@``!P````P.```'````%`X```0````<#@``(P```"$.```O````
M10X``"$```!U#@``'````)<.```"````M`X```<```"W#@``#````+\.```(
M````S`X```<```#5#@``!P```-T.```-````Y0X```,```#S#@``,````/<.
M```3````*`\``!`````\#P``4P```$T/```7````H0\``!8```"Y#P``#P``
M`-`/```?````X`\```4`````$```"`````80```(````#Q````0````8$```
M!@```!T0``!;`0``)!````L```"`$0``"@```(P1```6````EQ$```4```"N
M$0``!0```+01```$````NA$``!8```"_$0``"0```-81```&````X!$``!L`
M``#G$0``$0````,2```%````%1(```<````;$@``.````",2```$````7!(`
M``@```!A$@``%````&H2```$````?Q(``!````"$$@``%@```)42```9````
MK!(```8```#&$@``!P```,T2```%````U1(``!````#;$@``$````.P2```5
M````_1(``!$````3$P``#P```"43```'````-1,```0````]$P```P```$(3
M```%````1A,```H```!,$P``!@```%<3```$````7A,```0```!C$P``"```
M`&@3```/````<1,``!$```"!$P``&````),3```5````K!,```@```#"$P``
M"P```,L3```'````UQ,```<```#?$P``!P```.<3```'````[Q,```@```#W
M$P``!@`````4```5````!Q0```D````=%```!@```"<4```(````+A0```X`
M```W%```!````$84```$````2Q0```<```!0%```#0```%@4```)````9A0`
M``,```!P%```)@```'04```&````FQ0```8```"B%```"@```*D4```&````
MM!0```@```"[%````@```,04```+````QQ0```8```#3%```!@```-H4```,
M````X10```H```#N%```!````/D4```&````_A0```4````%%0```P````L5
M```%````#Q4```@````5%0``!@```!X5```'````)14```T````M%0``"```
M`#L5```6````1!4``"$```!;%0``"@```'T5```%````B!4``!H```".%0``
M"0```*D5```%````LQ4```0```"Y%0``"0```+X5```%````R!4``!X```#.
M%0``,0```.T5```C````'Q8``"````!#%@```P```&06```&````:!8``!$`
M``!O%@``"P```($6```'````C18```<```"5%@``$````)T6```"````KA8`
M`"\```"Q%@``&P```.$6```+````_18``%4````)%P``%````%\7```6````
M=!<``!````"+%P``)@```)P7```%````PQ<```8```#)%P``"0```-`7```%
M````VA<```@```#@%P```0````8`````````5P```&$````H`````````&0`
M`````````````#T````I`````````$T```!*````;@`````````O````$```
M`#8````.````9P````H````N````/P````(`````````$0```%$```!<````
M-````"(````^````2P```&H```!"````,````!X````(````10`````````W
M``````````````!V``````````L```!T````#`````````!(````,0``````
M``!L`````````$X``````````P```&````!H`````````!@```!M````1```
M``````!#`````````&8```!9``````````4`````````%0```%``````````
M90```"$`````````0````",````3`````````'4````Y````7@```%,```!5
M````-0````````!!`````````!D```!8````<P```$D````6````````````
M````````:P`````````Z````'0```"0`````````````````````````*P``
M`"T```!6`````````!(```!2````#0```!L````<`````````"P`````````
M3`````````!W````*@```%L```!&````8@```&D````@````)0```$\````$
M````,P```#P```!'````<`````````!?````6@````\````'````````````
M```:````;P```"<`````````70```#@````4````,@```&,`````````)@``
M`'(````)````'P```!<````[`````````'$```!4``````````!!9&1R97-S
M($)O;VL`06QL`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`07!R
M:6P`075G=7-T`$)O=&@`0G5I;&1I;F<@;&]C86QE("5S+BXN(`!#86YC96P`
M0VAA;F=E`$-L96%N:6YG('5P(&QO8V%L92`E<RXN+B``0V]M<&]S92!-97-S
M86=E("@E<RD`0V]P>0!#<F5A=&4`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U
M<&]N(&QO9V]N('1O("5S+@!$871E`$1E8V5M8F5R`$1E9F%U;'0@261E;G1I
M='D`1&5L971E`$1I<W!L87D@3W!T:6]N<P!$;W=N;&]A9`!$;W=N;&]A9"`E
M<P!%9&ET`$5M86EL($%D9')E<W,`17)R;W(`179E<GD@,34@;6EN=71E<P!%
M=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!H86QF(&AO
M=7(`179E<GD@;6EN=71E`$9E8G)U87)Y`$9I;'1E<G,`1G)O;0!(96QP`$ED
M96YT:71Y)W,@;F%M93H`2F%N=6%R>0!*=6QY`$IU;F4`3&%N9W5A9V4`3&%S
M="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M
M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,87EO=70`3&5B86YO;@!,
M969T`$QI8F5R:6$`3&ET:'5A;FEA`$QO9R!I;@!,;V<@;W5T`$QO9VEN(%1A
M<VMS`$UA:6P`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%R8V@`
M36%R9VEN`$UA<G-H86QL($ES;&%N9',`36%U<FET86YI80!-87D`365R9VEN
M9R!T<F%N<VQA=&EO;B!F;W(@;6]D=6QE("5S+BXN`$UE<W-A9V4`365X:6-O
M`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ER<F]R`$UI<V-E
M;&QA;F5O=7,`36\`36]D:69Y(%523`!-;V1U;&4`36]N86-O`$UO=F4@1&]W
M;@!-;W9E(%5P`$YA;64`3F5V97(`3F5X=`!.;P!.;VYE`$YO=F5M8F5R`$]+
M`$]C=&]B97(`3W!T:6]N<P!087-S=V]R9`!097)S;VYA;"!);F9O<FUA=&EO
M;@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!2
M97-E=`!396%R8V@`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!3
M97!T96UB97(`4VEZ90!3=6)J96-T`%-U8V-E<W,`5&5X=`!4:&4@:61E;G1I
M='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&5R92!W87,@86X@97)R;W(@
M9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&ES(&YU;6)E<B!M=7-T
M(&)E(&%T(&QE87-T(&]N92X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R
M+@!4;P!5;FYA;65D`%5S97(@3W!T:6]N<P!5<V5R;F%M90!6:65W("5S`%=A
M<FYI;F<`5V5L8V]M92!T;R`E<P!997,`66]U<B`E<R!S97-S:6]N(&AA<R!E
M>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@1G)O;3H@861D<F5S
M<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P
M<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]/<'1I;VX@
M*R!0('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E
M9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&]P=&EO;G,@
M:&%V92!B965N('5P9&%T960N`%](96QP`%],;V<@;W5T`%]/<'1I;VYS`&1O
M;F4`9F%I;&5D`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXP+C4*4F5P
M;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#(M,#$M,3`@,3DZ,#`K,#$P,`I03RU2979I<VEO
M;BU$871E.B`R,#`U+3$Q+3$Y(#(P.C,S*S`P,#`*3&%S="U4<F%N<VQA=&]R
M.B!":F]R;B!$879I9'-S;VX@/&)J;W-S:4!S;F5R<&$N:7,^"DQA;F=U86=E
M+51E86TZ($EC96QA;F1I8R`\<W5P<&]R=$!S;F5R<&$N:7,^"DU)344M5F5R
M<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI
M<V\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`$YE
M=&9A;F=A8O-K`-9L;"!S:V5Y=&D`TW3F:W0@9VEL9&D@=&EL9W)E:6YT+@!A
M<'+M;`#A9_IS=`!"YO!I`$)Y9V=I(&[Z(&QO8V%L92`E<R`N+BX`2.9T=&$@
M=FGP`$)R97ET80!(<F5I;G-A('1I;"#M(&QO8V%L92`E<R`N+BX`4V5M:F$@
M<VME>71I("@E<RD`069R:70`0OIA('1I;`!3=&EL;&$@8?!G97+P:7(@<V5M
M(&5R=2!F<F%M:W;F;61A<B#^96=A<B#^^B!T96YG:7-T("5S+@!$86=S`&1E
M<V5M8F5R`%-JX6QF9V5F:?`@:V5N;FEM87)K`$5Y\&$`VG1L:71S<W1I;&QI
M;F=A<@!3YFMJ82!Y9FER(.$@=FEN;G5S=/;P`%/F:VIA("5S('EF:7(@X2!V
M:6YN=7-T]O``0G)E>71A`$YE=&9A;F<`5FEL;&$`P2!K;W)T97)S(&9R97-T
M:0#!(#,P('-E:RX@9G)E<W1I`,$@9FEM;2!M[6[Z=&YA(&9R97-T:0#!(&CA
M;&9T[6UA(&9R97-T:0#!(&WM;OIT=2!F<F5S=&D`9F5B<OIA<@!3[75R`$9R
MX0!(:N%L<`!+96YN:6YA9FXZ`&IA;OIA<@!J^FSM`&KZ;NT`5'5N9W5MX6P`
M<^WP87-T('5P<&;F<G0Z`%/M\&%S="!T96YG<W0Z("5S`%/M\&%S="!T96YG
M<W0Z("5S(&9RX2`E<P!3[?!A<W0@=&5N9W-T.B!!;&1R96D`3&5T=&QA;F0`
M1G)A;7-E=&YI;F<`3.UB86YO;@!6:6YS=')I`$SM8F5R[6$`3&ET:.%E;@!4
M96YG:F%S=`#:='-K<N$`5F5R:V5F;FD@=FGP('1E;F=I;F=U`%9E9G#S<W1U
M<@!-86QA=NT`36%L8>US[6$`1W+F;FCV9O!A97EJ87(`36%L[0!M87)S`%-P
MX7-S[6$`36%R<VAA;&QE>6IA<@!-X7+M=&%N[6$`;6'M`%-A;65I;F$@_OWP
M:6YG87(@9GER:7(@)7,@96EN:6YG=6YA+BXN`%-K97ET:0!-97CM:_,`3>UK
M<O-N97/M80!3<&5G;&$`W6UI<VQE9W0`3>$`0G)E>71A('-L\_``16EN:6YG
M`$WS;F%K\P!&;'ET:F$@;FGP=7(`1FQY=&IA('5P<`!.869N`$%L9')E:0!.
MYG-T80!.96D`16YG:6X`;O-V96UB97(`S2!L86=I`&]K=/-B97(`5F%L<W1I
M;&QI;F=A<@!,>6MI;&]R\`!5<'!L_7-I;F=A<B!U;2!N;W1A;F1A`%-LX?!U
M(&EN;B!N;W1A;F1A;F%F;B!O9R!L>6ML:6]R\`!%;F1U<G-E=&IA`$QE:71A
M`%9E;&1U('-JX6QF9V5F:?`@='5N9W5MX6PZ`'-E<'1E;6)E<@!3=.9R\`!%
M9FYI`$9R86UK=N9M=`!497AT:0!+96YN:6YU("(E<R(@:&5F=7(@=F5R:?`@
M97ET="X`5FEL;&$@:V]M('5P<"!V:?`@8FER=&EN9W4@_F5S<V$@:&QU=&$@
M<VME>71I<VEN<P!486QA;B!V97+P=7(@8?`@=F5R82!A\"!LX6=M87)K:2`Q
M+@#>971T82!G:6QD:2!V97+P=7(@8?`@=F5R82!T86QA+@!4:6P`TVYE9FYT
M`%9A;&MO<W1I<B!N;W1A;F1A`$YO=&%N9&%N869N`%/];F$@)7,`0?!V]G)U
M;@!696QK;VUI;BAN*2#M("5S`$KA`$QO=&%N("5S(&5R(')U;FYI;B#Z="#A
M('3M;6$N(%1E;F=D=2#^:6<@869T=7(N`$9U;&QT(&YE=&9A;F<@_FET="`H
M1G+A.BD@.@!5<'!L_7-I;F=A<@!6969S:V_P87)I(/YI;FX@<W1Y\'5R(&5K
M:VD@_F5S<V$@<')E;G1A\&=E<O`N($YO=&'P=2!#5%),+T]P=&EO;B!O9R!0
M('1I;"!A\"!P<F5N=&$N`$[Z=F5R86YD:2!T[6UA8F5L=&DZ`%-JX6QF9V5F
M:?`@:V5N;FD@_FET=#H`1G5L;'0@;F%F;B#^:71T.@!3=&EL;&EN9V%R(/[M
M;F%R(&AA9F$@=F5R:?`@=7!P9N9R\&%R+@!(:N%L<`#:='-K<N$`5F%L:V]S
M=&ER`&QO:VGP`&ML:6MK8?!I````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O:71?250O````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-3$U-#,S-S4S`#`R,#$R-0`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L
M92]I=%])5"]H96QP+GAM;```````````````````````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#0T,C<`,3`U,34T,S,W-3,`,#(Q-C`V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_>&UL('9E<G-I;VX]
M(C$N,"(@96YC;V1I;F<](FES;RTX.#4Y+3$B/SX*/"$M+2`D2&]R9&4Z(&AO
M<F1E+VQO8V%L92]I=%])5"]H96QP+GAM;"QV(#$N,BXQ,"XR(#(P,#4O,3`O
M,3@@,3$Z,S,Z-#,@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60]
M(G-U;6UA<GDB('-T871E/2)U<'1O9&%T92(@;60U/2(V.&-A,S-F-V8P8SEA
M864T8S$P,V5B-#<T.3)C9&,Q-2(^"CQT:71L93Y086=I;F$@9&D@:6YG<F5S
M<V\@9&5L('!O<G1A;&4\+W1I=&QE/@H@/'!A<F$^"B`@475E<W1A('!A9VEN
M82!D:2!I;F=R97-S;R!D96P@<&]R=&%L92!F;W)N:7-C92!U;B!B<F5V92!S
M;VUM87)I;R!D:2!T=71T92!L92!T=64*("!I;F9O<FUA>FEO;FD@:6UP;W)T
M86YT:2X@060@97-E;7!I;RP@=&D@<'7R(&UO<W1R87)E('%U86YT:2!N=6]V
M:2!M97-S86=G:2!C:0H@('-O;F\@;F5L;&$@='5A($E.0D]8+"!I('!R;W-S
M:6UI(&5V96YT:2!N96P@='5O(&-A;&5N9&%R:6\L(&QE(&%T=&EV:73@(&YE
M;&QA"B`@='5A(&QI<W1A+"!L92!U;'1I;64@;F]T:7II92!D82!S97)V:7II
M('-E;&5Z:6]N871I(&4@8V]S["!V:6$N($UO;'1I(&1I('%U97-T:0H@('-O
M;6UA<FD@8V]N=&5R<F%N;F\@9&5I(&-O;&QE9V%M96YT:2!A(&9U;GII;VYI
M(&-O;75N:2P@<75A;&D@860@97-E;7!I;R!L82!C;VUP;W-I>FEO;F4*("!D
M:2!U;F$@;G5O=F\@;65S<V%G9VEO+"!L82!C<F5A>FEO;F4@9&D@=6YO(&YU
M;W9O(&5V96YT;R!D82!I;G-E<FER92!N96P@8V%L96YD87)I;PH@(&\@;&$@
M8W)E87II;VYE(&1I('5N82!N=6]V82!A='1I=FETX"!D82!I;G-E<FER92!N
M96QL82!L:7-T82P@96-C+@H@/"]P87)A/@H@/'!A<F$^"B`@22!C;VYT96YU
M=&D@9&D@<75E<W1A('!A9VEN82!D96P@<&]R=&%L92!S;VYO('!E<G-O;F%L
M:7IZ86)I;&D@=')A;6ET92!I;"!B;W1T;VYE($9O<FUA=&\N"B`@060@97-E
M;7!I;RP@<'5O:2!S8V5G;&EE<F4@<75A;&D@:6YF;W)M87II;VYI(&EN<V5R
M:7)E(&YE;&QA('!A9VEN82!C;VUE(&%N8VAE(&EN"B`@<75A;&4@;W)D:6YE
M('9E<G)A;FYO(&UO<W1R871E+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB;F%V8F%R(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB8CAC9C!A93$Y
M934W9&9A,&,R8CDV,F4U,38W.#)F-#<B/@H\=&ET;&4^3&$@8F%R<F$@9&D@
M;F%V:6=A>FEO;F4@9&5L;&4@87!P;&EC87II;VYI/"]T:71L93X*(#QP87)A
M/@H@(%-U;&QA('-I;FES=')A(&1E;&QA('!A9VEN82!W96(@Z"!P<F5S96YT
M92!L82!B87)R82!D:2!N879I9V%Z:6]N92!D96QL92!A<'!L:6-A>FEO;FDN
M"B`@0VQI8V-A('-U;&PG:6-O;F$@<')E<V5N=&4@;F5L;&$@8F%R<F$@9&D@
M;F%V:6=A>FEO;F4@<&5R('!A<W-A<F4@<F%P:61A;65N=&4@90H@('9E;&]C
M96UE;G1E('1R82!L92!V87)I92!A<'!L:6-A>FEO;FD@9&ES<&]N:6)I;&DN
M"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN
M=&5N86YC92(@<W1A=&4](G5P=&]D871E(B!M9#4](F1D.35D9C`W83`S,#,Q
M,C,R8F%E83DQ.3(X.&(R9#`P(CX*("`@(#QT:71L93Y0<F5F97)E;GIE.B!-
M86YU=&5N>FEO;F4Z($5S96=U:2!L82!M86YU=&5N>FEO;F4\+W1I=&QE/@H@
M("`@/'!A<F$^"B`@("!392!V=6]I(&5S96=U:7)E(&QE(&]P97)A>FEO;FD@
M9&D@;6%N=71E;GII;VYE(&%P<&5N82!E;G1R871O(&YE;"!P;W)T86QE+`H@
M("`@<V5L97II;VYE('%U97-T82!C87-E;&QA+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC92(@
M<W1A=&4](G5P=&]D871E(B!M9#4](F$R,3$V,F-D9F8S8C%D.&9A96%D8C<R
M.38R-#`P,S9E(CX*("`@(#QT:71L93Y0<F5F97)E;GIE.B!-86YU=&5N>FEO
M;F4Z($-O;F9E<FUA(&QA(&UA;G5T96YZ:6]N93PO=&ET;&4^"B`@("`\<&%R
M83X*("`@(%-E(&1E<VED97)I(&-H92!V96YG82!C:&EE<W1A(&QA(&-O;F9E
M<FUA('!R:6UA(&-H92!T=71T92!L92!O<&5R87II;VYI(&1I(&UA;G5T96YZ
M:6]N92`*("`@('9E;F=A;F\@97-E9W5I=&4L('-E;&5Z:6]N82!Q=65S=&$@
M8V%S96QL82X*("`@(%-E(&QA(&-A<V5L;&$@;F]N('9I96YE('-E;&5Z:6]N
M871A+"!T=71T92!L92!O<&5R87II;VYI(&1I(&UA;G5T96YZ:6]N92!C:&4@
M<V]N;PH@("`@<')O9W)A;6UA=&4@=F5R<F%N;F\@97-E9W5I=&4@875T;VUA
M=&EC86UE;G1E('-E;GIA(&QA('!O<W-I8FEL:73@(&1I(&-A;F-E;&QA<FQE
M"B`@("!Q=6%N9&\@<VD@96YT<F$@;F5L('!O<G1A;&4N"B`@("`\+W!A<F$^
M"CPO96YT<GD^"CPO:&5L<#X*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQO8V%L92]I=%])5"],0U]-15-304=%4R\`````````````````
M````````````````````````````````````````````````,#`P,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-3,`,#(Q-S$R
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VET7TE4+TQ#7TU%4U-!
M1T53+VAO<F1E+FUO````````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#,R-3$R-P`Q
M,#4Q-30S,S<U,P`P,C,S-C(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````WA($E0````"'!0``'````%0L``!A!P``C%@`````
M```0=@``#@```!%V```/````('8```T````P=@``"````#YV```+````1W8`
M``P```!3=@``!````&!V```8````978``!L```!^=@``+0```)IV```=````
MR'8``"0```#F=@``*0````MW```9````-7<``"8```!/=P``#````'9W```D
M````@W<```\```"H=P``"P```+AW```.````Q'<```4```#3=P``*````-EW
M```(`````G@```H````+>```%0```!9X```2````+'@```L````_>```A0``
M`$MX```.````T7@```H```#@>```#0```.MX```.````^7@``!$````(>0``
M#0```!IY```,````*'D```T````U>0``!@```$-Y``"4````2GD```H```#?
M>0``#P```.IY```8````^GD```P````3>@``#@```"!Z```.````+WH```@`
M```^>@``"0```$=Z```N````47H``!H```"`>@``,@```)MZ```X````SGH`
M`%0````'>P``40```%Q[``!:````KGL``%<````)?```-````&%\```)````
MEGP```T```"@?```!P```*Y\```*````MGP```\```#!?```!0```-%\```&
M````UWP``!$```#>?```"````/!\```E````^7P``"`````??0``$P```$!]
M```0````5'T```\```!E?0``"@```'5]```#````@'T```\```"$?0``%```
M`)1]```)````J7T```T```"S?0``$@```,%]```9````U'T``!X```#N?0``
M#P````U^```*````'7X```\````H?@``"````#A^```D````07X``!0```!F
M?@``%@```'M^```(````DGX``$X```";?@``+0```.I^```9````&'\```<`
M```R?P``#````#I_```L````1W\```X```!T?P``!0```(-_```*````B7\`
M``,```"4?P``%P```)A_```*````L'\```\```"[?P``#@```,M_```8````
MVG\``",```#S?P``#@```!>````4````)H```!<````[@```%P```%.````7
M````:X```!,```"#@```#P```)>````?````IX```!T```#'@```!@```.6`
M```+````[(```!````#X@```%0````F!```5````'X$```<````U@0``$```
M`#V!```%````3H$``!$```!4@0``#````&:!```[````<X$``#@```"O@0``
M.0```.B!```2````(H(``"<````U@@``+````%V"```J````BH(``"4```"U
M@@``"@```-N"```&````YH(``"\```#M@@``-P```!V#```N````58,``%4`
M``"$@P``+0```-J#```M````"(0``#T````VA```/P```'2$```M````M(0`
M`$````#BA```(P```".%```C````1X4``$````!KA0``+0```*R%```S````
MVH4``"4````.A@``%0```#2&```9````2H8``"D```!DA@``)````(Z&```H
M````LX8``!$```#<A@``"@```.Z&```0````^88``!8````*AP``%@```"&'
M```G````.(<```@```!@AP``*0```&F'```.````DX<```H```"BAP``!```
M`*V'```)````LH<```8```"\AP``$0```,.'```'````U8<``!8```#=AP``
M!````/2'```&````^8<```8`````B```#0````>(```#````%8@```,````9
MB```%P```!V(```3````-8@``!T```!)B```"````&>(```$````<(@```@`
M``!UB```.P```'Z(```T````NH@``$$```#OB```&@```#&)```K````3(D`
M`"````!XB0``%0```)F)```&````KXD``!4```"VB0``&````,R)```B````
MY8D``"X````(B@``'0```#>*```A````58H``%0```!WB@``*0```,R*```'
M````]HH``!4```#^B@``#@```!2+```*````(XL```\````NBP``#0```#Z+
M```/````3(L```T```!<BP``"0```&J+```&````=(L``!T```![BP``$P``
M`)F+```1````K8L``!0```"_BP``!@```-2+```4````VXL``%0```#PBP``
M9````$6,```$````JHP```X```"OC```!0```+Z,```%````Q(P``!,```#*
MC```$0```-Z,```1````\(P``!P````"C0``*@```!^-```A````2HT```4`
M``!LC0``"P```'*-```2````?HT```H```"1C0``#P```)R-```-````K(T`
M`!$```"ZC0``#````,R-```&````V8T```P```#@C0``!@```.V-```0````
M](T``!$````%C@``!0```!>.```,````'8X``!`````JC@``!0```#N.```-
M````08X```8```!/C@``!P```%:.```-````7HX```<```!LC@``"P```'2.
M```'````@(X```D```"(C@``"0```)*.```*````G(X``!D```"GC@``/0``
M`,&.```=````_XX```P````=CP``$````"J/```2````.X\``!,```!.CP``
M*P```&*/```[````CH\``"````#*CP``"````.N/```V````](\``"$````K
MD```$````$V0```(````7I````0```!GD```#P```&R0```.````?)```!\`
M``"+D```'````*N0```A````R)```!X```#JD```&0````F1```>````(Y$`
M`!L```!"D0``(0```%Z1```N````@)$``"8```"OD0``'````-:1```>````
M\Y$``!P````2D@``)@```"^2```K````5I(``#,```""D@``)@```+:2```K
M````W9(``#@````)DP``'0```$*3```5````8),``"\```!VDP``(````*:3
M```2````QY,``"D```#:DP``'@````24```@````(Y0``!(```!$E```H@``
M`%>4```6````^I0``",````1E0``*````#65```I````7I4``"@```"(E0``
M'P```+&5```5````T94``"````#GE0``)0````B6```H````+I8``"T```!7
ME@``,````(66``"2````MI8``"$```!)EP``'````&N7```F````B)<``"H`
M``"OEP``00```-J7``!$````')@```P```!AF```!P```&Z8```'````=I@`
M``8```!^F```#0```(68```0````DY@``!(```"DF```$P```+>8```2````
MRY@``!````#>F```$````.^8```,`````)D```X````-F0``#0```!R9```/
M````*ID``!,````ZF0``#0```$Z9```H````7)D```,```"%F0``#0```(F9
M```&````EYD```4```">F0``!````*29```-````J9D```X```"WF0```P``
M`,:9```.````RID```@```#9F0``#P```.*9```/````\ID```T````"F@``
M$````!":```-````(9H```L````OF@``!@```#N:```+````0IH```P```!.
MF@``"@```%N:```1````9IH``!D```!XF@``"P```)*:```-````GIH``"(`
M``"LF@``#P```,^:```;````WYH``#0```#[F@``"@```#";```8````.YL`
M`!(```!4FP``&0```&>;```6````@9L``"(```"8FP``#0```+N;```'````
MR9L``!0```#1FP``"P```.:;```B````\IL``"\````5G```"P```$6<```)
M````49P``!D```!;G```"P```'6<```7````@9P``!<```"9G```%@```+&<
M```/````R)P``!D```#8G```#@```/*<```8`````9T```T````:G0``)@``
M`"B=``!#````3YT``!\```"3G0``"````+.=```+````O)T``"\```#(G0``
M!0```/B=```$````_IT```H````#G@``"@````Z>```/````&9X``!`````I
MG@``%P```#J>```1````4IX``!D```!DG@``%P```'Z>```%````EIX```H`
M``"<G@``#0```*>>```;````M9X``!<```#1G@``#@```.F>```-````^)X`
M`!(````&GP``.````!F?```@````4I\```@```!SGP``#@```'R?``![````
MBY\``!@````'H```&````""@```%````.:```!@````_H```'@```%B@```;
M````=Z```!D```"3H```&P```*V@```9````R:```!,```#CH```$````/>@
M```/````"*$``!`````8H0``#P```"FA```+````.:$```\```!%H0``#```
M`%6A```/````8J$```<```!RH0``!@```'JA```.````@:$```P```"0H0``
M*````)VA```/````QJ$```@```#6H0``"````-^A```3````Z*$``!X```#\
MH0``(0```!NB```@````/:(``!D```!>H@``%P```'BB```E````D*(``!<`
M``"VH@``%@```,ZB```$````Y:(```P```#JH@``"````/>B```*`````*,`
M``P````+HP``$P```!BC```4````+*,```P```!!HP``"0```$ZC```.````
M6*,```L```!GHP``&P```'.C```'````CZ,```<```"7HP``"@```)^C```-
M````JJ,```D```"XHP```P```,*C```8````QJ,```H```#?HP``!````.JC
M```F````[Z,```X````6I```%0```"6D```(````.Z0```(```!$I```!@``
M`$>D```$````3J0```D```!3I```$````%VD```)````;J0```D```!XI```
M&@```(*D```(````G:0``!D```"FI```#@```,"D```'````SZ0```D```#7
MI```"@```.&D```.````[*0```(```#[I```"P```/ZD```)````"J4```8`
M```4I0``%````!NE```=````,*4``$(```!.I0``)0```)&E```E````MZ4`
M``8```#=I0``$0```.2E```)````]J4```8`````I@``!P````>F```&````
M#Z8```0````6I@``$0```!NF```&````+:8```H````TI@``(@```#^F```$
M````8J8```4```!GI@``'0```&VF```$````BZ8```P```"0I@``#@```)VF
M```*````K*8```\```"WI@``$@```,>F```+````VJ8``"8```#FI@``*0``
M``VG```D````-Z<``"8```!<IP``"````(.G```*````C*<```<```"7IP``
M(````)^G```@````P*<``"8```#AIP``"@````BH```9````$Z@``"D````M
MJ```$@```%>H```'````:J@```H```!RJ```#````'VH```/````BJ@``!``
M``":J```0````*NH``!P````[*@``&8```!=J0``#@```,2I```)````TZD`
M``H```#=J0``$@```.BI```3````^ZD```P````/J@``!@```!RJ```/````
M(ZH``!(````SJ@``$````$:J```1````5ZH``!P```!IJ@``(P```(:J``!J
M````JJH```\````5JP``$````"6K```+````-JL``"````!"JP``%````&.K
M```,````>*L```P```"%JP``#P```)*K```5````HJL``"D```"XJP``*@``
M`.*K```F````#:P``"<````TK```*0```%RL```J````AJP``!D```"QK```
M0@```,NL```1````#JT``!(````@K0``$P```#.M```4````1ZT```\```!<
MK0``%@```&RM```7````@ZT``!````";K0``$0```*RM```T````OJT``!,`
M``#SK0``$@````>N```U````&JX``!0```!0K@``!P```&6N```,````;:X`
M`"````!ZK@``$````)NN```4````K*X``!$```#!K@``%P```-.N```<````
MZZX``!,````(KP``%````!RO```:````,:\``!$```!,KP``&@```%ZO```>
M````>:\``!H```"8KP``$P```+.O```5````QZ\``!$```#=KP``%P```.^O
M```4````![```!<````<L```"0```#2P```0````/K````8```!/L```!0``
M`%:P```'````7+````4```!DL```!````&JP```$````;[````<```!TL```
M#@```'RP```,````B[````P```"8L```#0```*6P```.````L[```"@```#"
ML```#````.NP```/````^+````H````(L0``"````!.Q```)````'+$``"L`
M```FL0``!````%*Q```'````5[$```@```!?L0``"0```&BQ```4````<K$`
M``P```"'L0``#0```)2Q```.````HK$``!8```"QL0``$0```,BQ```#````
MVK$```8```#>L0``&0```.6Q```'````_[$```0````'L@``"P````RR```+
M````&+(```4````DL@``"@```"JR```$````-;(```\````ZL@``.@```$JR
M```%````A;(``!X```"+L@``#@```*JR```0````N;(```L```#*L@``#```
M`-:R```)````X[(```<```#ML@``"@```/6R```.`````+,``!`````/LP``
M&P```""S```8````/+,``!H```!5LP``"@```'"S```*````>[,```P```"&
MLP``#P```).S```(````H[,```8```"LLP``!P```+.S```%````N[,```L`
M``#!LP``1P```,VS```-````%;0```D````CM```!````"VT```#````,K0`
M`!,````VM```$P```$JT```3````7K0```H```!RM```)0```'VT```%````
MH[0```0```"IM```"@```*ZT```-````N;0``&@```#'M```!0```#"U```&
M````-K4``!L````]M0``+P```%FU```/````B;4``!,```"9M0``&P```*VU
M```8````R;4``!<```#BM0``'P```/JU```.````&K8```,````IM@``"```
M`"VV```'````-K8```L````^M@``!P```$JV``!1````4K8``!````"DM@``
M#````+6V```&````PK8``!H```#)M@``)0```.2V```&````"K<```8````1
MMP``!@```!BW```8````'[<``!<````XMP``*````%"W```&````>;<```T`
M``"`MP``(@```(ZW``!7````L;<``!,````)N```(P```!VX```3````0;@`
M``(```!5N```"````%BX```-````8;@```H```!ON```!P```'JX```.````
M@K@```<```"1N```"P```)FX```R````I;@```D```#8N```"0```.*X```*
M````[+@```<```#WN```"0```/^X```'````";D``!(````1N0``"@```"2Y
M```6````+[D```D```!&N0``$````%"Y```2````8;D```0```!TN0``!P``
M`'FY```%````@;D```P```"'N0``"````)2Y```7````G;D```P```"UN0``
M'P```,*Y```:````XKD``!,```#]N0``!````!&Z```*````%KH```0````A
MN@``#0```":Z```,````-+H```4```!!N@``!0```$>Z```X````3;H``"P`
M``"&N@``*0```+.Z```R````W;H```H````0NP``+````!N[```N````2+L`
M`#,```!WNP``,P```*N[```X````W[L```\````8O```&````"B\```0````
M0;P```\```!2O```$P```&*\```5````=KP``!0```",O```$@```*&\```4
M````M+P``"T```#)O```+0```/>\```Q````);T``"X```!7O0``+P```(:]
M```L````MKT``&(```#CO0``#0```$:^```(````5+X``!<```!=O@``"```
M`'6^```,````?KX``"L```"+O@``(0```+>^```:````V;X```D```#TO@``
M10```/Z^``!!````1+\```0```"&OP``$P```(N_```3````G[\```8```"S
MOP``"0```+J_```*````Q+\```\```#/OP``$````-^_```'````\+\```X`
M``#XOP``!0````?````;````#<````@````IP```!@```#+````4````.<``
M`!$```!.P```#@```&#````X````;\````8```"HP```#@```*_````%````
MOL````<```#$P```!@```,S````H````T\````P```#\P```'`````G!```I
M````)L$``!\```!0P0``7````'#!```4````S<$``#X```#BP0``'P```"'"
M```0````0<(```<```!2P@``#@```%K"```,````:<(```P```!VP@``$P``
M`(/"```*````E\(``!T```"BP@``&0```,#"```%````VL(``!$```#@P@``
M$0```/+"```D````!,,``!(````IPP``#@```#S#```9````2\,```@```!E
MPP``"0```&[#```:````>,,```<```"3PP``#0```)O#```>````J<,``!(`
M``#(PP``+````-O#```:````",0``!4````CQ```!0```#G$```4````/\0`
M``0```!4Q```!@```%G$```'````8,0``!X```!HQ```*````(?$```*````
ML,0``!P```"[Q```$0```-C$```+````ZL0``!H```#VQ```%````!'%```%
M````)L4```8````LQ0``&P```#/%```T````3\4``#0```"$Q0``(````+G%
M```I````VL4``"`````$Q@``00```"7&```:````9\8``"@```""Q@``*0``
M`*O&``!0````U<8``"(````FQP``!@```$G'```(````4,<```4```!9QP``
M"````%_'```9````:,<``!D```""QP``*@```)S'```C````Q\<``"X```#K
MQP``-````!K(```(````3\@``!<```!8R```"@```'#(```'````>\@``"$`
M``"#R```$````*7(```.````ML@```L```#%R```!P```-'(```3````V<@`
M``@```#MR```"@```/;(```4`````<D```\````6R0``,@```";)```.````
M6<D```4```!HR0``#P```&[)```$````?LD```4```"#R0``!````(G)```-
M````CLD``#(```"<R0``10```,_)```7````%<H```<````MR@``'@```#7*
M```4````5,H```8```!IR@``!P```'#*```.````>,H``"H```"'R@``!@``
M`++*```,````N<H```T```#&R@``$0```-3*```+````YLH``#8```#RR@``
M"@```"G+```B````-,L```L```!7RP``#P```&/+```R````<\L``"4```"F
MRP``,````,S+```Q````_<L``"T````OS```#@```%W,```%````;,P```X`
M``!RS```$P```(',```2````E<P```<```"HS```$0```+#,```3````PLP`
M``<```#6S```%````-[,```8````\\P```<````,S0``!0```!3-```,````
M&LT```P````GS0``$@```#3-```$````1\T```H```!,S0``"P```%?-```,
M````8\T```X```!PS0``#@```'_-```%````CLT```4```"4S0``+@```)K-
M```F````R<T``",```#PS0```P```!3.```>````&,X``!@````WS@``)0``
M`%#.```-````=LX``!\```"$S@``$@```*3.```2````M\X```0```#*S@``
M"0```,_.```'````V<X```P```#AS@``4@```.[.```7````0<\``"0```!9
MSP``!P```'[/```&````AL\```X```"-SP``#````)S/```-````J<\``!4`
M``"WSP``$@```,W/```/````X,\``!0```#PSP``"@````70```;````$-``
M`!`````LT```"P```#W0``!I````2=```!H```"ST```%P```,[0```G````
MYM```!H````.T0``%P```"G1```;````0=$``!D```!=T0``'P```'?1```3
M````E]$```@```"KT0``"````+31```)````O=$```T```#'T0``(P```-71
M```-````^=$``!,````'T@``"````!O2```#````)-(``$8````HT@``/P``
M`&_2```W````K](``%<```#GT@``!0```#_3```?````1=,``"\```!ETP``
M#0```)73```M````H],```0```#1TP``3P```-;3```E````)M0``!P```!,
MU```"P```&G4```?````==0``!T```"5U```"P```+/4```'````O]0```D`
M``#'U```$P```-'4```$````Y=0``!````#JU```!````/O4```4`````-4`
M``X````5U0``#````"35```3````,=4``!P```!%U0``*````&+5```&````
MB]4```<```"2U0``$P```)K5```%````KM4``!<```"TU0``"@```,S5```,
M````U]4```D```#DU0``"@```.[5```1````^=4```X````+U@``#@```!K6
M```=````*=8```L```!'U@```@```%/6```<````5M8```<```!SU@``!@``
M`'O6``!D````@M8``"8```#GU@``.`````[7```:````1]<``"H```!BUP``
M.P```(W7```H````R=<``#0```#RUP``&0```"?8```5````0=@```<```!7
MV```!P```%_8```'````9]@```8```!OV```"P```';8```<````@M@``!``
M``"?V```"0```+#8```0````NM@```<```#+V```!0```-/8```0````V=@`
M`!0```#JV```"P```/_8```-````"]D``!@````9V0``%P```#+9```$````
M2MD```D```!/V0``"@```%G9```"````9-D``",```!GV0``'P```(O9```X
M````J]D``"8```#DV0``,0````O:```G````/=H``!0```!EV@``.````'K:
M```H````L]H``#@```#<V@``*````!7;```L````/ML``!L```!KVP``/@``
M`(?;```C````QML``"4```#JVP``00```!#<``!;````4MP``$D```"NW```
M(0```/C<```?````&MT``"L````ZW0``)@```&;=```G````C=T``#H```"U
MW0``,P```/#=```E````)-X``"````!*W@``'P```&O>```P````B]X``&D`
M``"\W@``,0```";?``!!````6-\``#,```":WP``)0```,[?```]````]-\`
M`&4````RX```30```)C@```O````YN```"X````6X0``,````$7A``!4````
M=N$``%H```#+X0``2````";B``!*````;^(``#(```"ZX@``+P```.WB```L
M````'>,``"T```!*XP``)0```'CC```R````GN,``#X```#1XP``(@```!#D
M``!2````,^0``"4```"&Y```"P```*SD``!%````N.0``"$```#^Y```,```
M`"#E```E````4>4``!P```!WY0``,0```)3E```'````QN4```<```#.Y0``
M!````-;E```+````V^4```X```#GY0``!0```/;E```"````_.4``%D```#_
MY0``!0```%GF```(````7^8``#````!HY@```P```)GF```,````G>8```T`
M``"JY@```@```+CF```&````N^8``!(```#"Y@``'P```-7F```U````]>8`
M`"X````KYP``+P```%KG```7````BN<``"(```"BYP``)0```,7G```@````
MZ^<``!L````,Z```&````"CH```D````0>@``!\```!FZ```&@```(;H```A
M````H>@``"````##Z```&@```.3H```R````_^@``!H````RZ0``+P```$WI
M```K````?>D``!\```"IZ0``(P```,GI```?````[>D``!H````-Z@``(0``
M`"CJ```E````2NH``"8```!PZ@``)0```)?J```D````O>H``!@```#BZ@``
M'0```/OJ```D````&>L``!@````^ZP``(@```%?K```L````>NL``"\```"G
MZP``%0```-?K```E````[>L``#P````3[```'P```%#L```C````<.P``!\`
M``"4[```(````+3L```:````U>P``!@```#P[```)@````GM```I````,.T`
M`!X```!:[0``*0```'GM```>````H^T``#$```#"[0``"0```/3M```,````
M_NT``!<````+[@``+P```"/N```D````4^X```<```!X[@``'0```(#N```:
M````GNX```<```"Y[@``%0```,'N```&````U^X```D```#>[@``"P```.CN
M```-````].X``!<````"[P``!@```!KO```S````(>\``!,```!5[P``$P``
M`&GO```/````?>\```<```"-[P``,@```)7O```$````R.\``"$```#-[P``
M$P```._O```,`````_```!$````0\```,@```"+P```6````5?````@```!L
M\```'0```'7P```)````D_````H```"=\```%````*CP```=````O?````@`
M``#;\```'P```.3P```(````!/$``!H````-\0``)P```"CQ```&````4/$`
M`!4```!7\0``"````&WQ```_````=O$```<```"V\0``#P```+[Q```.````
MSO$``!````#=\0``"0```.[Q```)````^/$```<````"\@``&0````KR```*
M````)/(```H````O\@``#````#KR```$````1_(``"H```!,\@``!P```'?R
M```"````?_(``!````""\@``&````)/R```&````K/(```<```"S\@``#0``
M`+OR```+````R?(``"\```#5\@``(`````7S```Q````)O,```4```!8\P``
M$@```%[S```_````<?,``!(```"Q\P``"@```,3S```&````S_,```0```#6
M\P``$P```-OS```%````[_,```8```#U\P``!@```/SS```$`````_0```P`
M```(]```"@```!7T```Y````(/0``"X```!:]```*0```(GT```&````L_0`
M``,```"Z]```#````+[T``!%````R_0``#(````1]0``&@```$3U```T````
M7_4``"@```"4]0``4P```+WU```9````$?8``'(````K]@``(````)[V```U
M````O_8``"$```#U]@``10```!?W```P````7?<``"@```".]P``*0```+?W
M```F````X?<``"4````(^```*````"[X```H````5_@``"(```"`^```*P``
M`*/X```P````S_@``!(`````^0``$P```!/Y```0````)_D``'D````X^0``
M"0```++Y``"A````O/D``',```!>^@``?````-+Z```K````3_L``%0```![
M^P``%P```-#[```G````Z/L``!8````0_```#P```"?\```7````-_P``!\`
M``!/_```0````&_\```?````L/P``!P```#0_```40```.W\```:````/_T`
M`!0```!:_0``$@```&_]```0````@OT``!,```"3_0``'0```*?]```/````
MQ?T```\```#5_0``"P```.7]```'````\?T```4```#Y_0``%````/_]```'
M````%/X```@````<_@``#P```"7^```(````-?X```P````^_@``#P```$O^
M```&````6_X``!0```!B_@``!@```'?^```,````?OX``!$```"+_@``"```
M`)W^```$````IOX``!D```"K_@``$0```,7^```*````U_X``!@```#B_@``
M$P```/O^```1````#_\``!8````A_P``!````#C_```/````/?\``!D```!-
M_P``$0```&?_```)````>?\``!(```"#_P``%P```);_```&````KO\``"<`
M``"U_P``!````-W_```/````XO\``!,```#R_P``!P````8``0`'````#@`!
M`!$````6``$`&````"@``0`3````00`!`!````!5``$`!@```&8``0`,````
M;0`!``D```!Z``$`$0```(0``0`B````E@`!``<```"Y``$`!P```,$``0`+
M````R0`!``(```#5``$`"P```-@``0"(`0``Y``!`!,```!M`@$`%P```($"
M`0`/````F0(!``<```"I`@$`"0```+$"`0`'````NP(!``0```##`@$`&0``
M`,@"`0`=````X@(!`"T``````P$`(0```"X#`0`K````4`,!`"T```!\`P$`
M'````*H#`0`K````QP,!``H```#S`P$`*@```/X#`0`3````*00!``P````]
M!`$`$0```$H$`0`%````7`0!`"@```!B!`$`#P```(L$`0`(````FP0!`!4`
M``"D!`$`$0```+H$`0`*````S`0!`(P```#7!`$`#@```&0%`0`)````<P4!
M``\```!]!0$`#0```(T%`0`-````FP4!`!````"I!0$`"@```+H%`0`4````
MQ04!``8```#:!0$`D0```.$%`0`,````<P8!`!$```"`!@$`%@```)(&`0`/
M````J08!``X```"Y!@$`#@```,@&`0`&````UP8!``L```#>!@$`-0```.H&
M`0`<````(`<!`#T````]!P$`2````'L'`0!I````Q`<!`&<````N"`$`<```
M`)8(`0!M````!PD!`$````!U"0$`!P```+8)`0`2````O@D!``H```#1"0$`
M#0```-P)`0`+````Z@D!``4```#V"0$`!@```/P)`0`6`````PH!``L````:
M"@$`*````"8*`0`@````3PH!`!0```!P"@$`$````(4*`0`2````E@H!``H`
M``"I"@$`"````+0*`0`6````O0H!`!@```#4"@$`#0```.T*`0`5````^PH!
M`!<````1"P$`(````"D+`0`B````2@L!`!D```!M"P$`$````(<+`0`5````
MF`L!`!(```"N"P$`+````,$+`0`6````[@L!`!X````%#`$`#P```"0,`0!2
M````-`P!`"P```"'#`$`)````+0,`0`)````V0P!``<```#C#`$`-````.L,
M`0`/````(`T!``<````P#0$`#0```#@-`0`%````1@T!`!P```!,#0$`#@``
M`&D-`0`0````>`T!`!8```")#0$`'````*`-`0`V````O0T!``H```#T#0$`
M%@```/\-`0`9````%@X!`!<````P#@$`&P```$@.`0`4````9`X!`!(```!Y
M#@$`*@```(P.`0`3````MPX!``@```#+#@$`#````-0.`0`2````X0X!`!@`
M``#T#@$`&@````T/`0`'````*`\!`!D````P#P$`!@```$H/`0`;````40\!
M``T```!M#P$`.P```'L/`0`X````MP\!`$<```#P#P$`%````#@0`0`R````
M31`!`#0```"`$`$`-0```+40`0`Z````ZQ`!``D````F$0$`!@```#`1`0`S
M````-Q$!`#0```!K$0$`,@```*`1`0!7````TQ$!`#(````K$@$`,0```%X2
M`0!%````D!(!`$L```#6$@$`,0```"(3`0!/````5!,!`"T```"D$P$`+0``
M`-(3`0!.`````!0!`#$```!/%`$`-P```($4`0`J````N10!`!8```#D%`$`
M&@```/L4`0`K````%A4!`"4```!"%0$`)0```&@5`0`2````CA4!``8```"A
M%0$`#0```*@5`0`=````MA4!`!L```#4%0$`*P```/`5`0`*````'!8!`"\`
M```G%@$`$P```%<6`0`+````:Q8!``D```!W%@$`"@```($6`0`%````C!8!
M`!,```"2%@$`!0```*86`0`4````K!8!``@```#!%@$`!0```,H6`0`'````
MT!8!``X```#8%@$``P```.<6`0`#````ZQ8!`!<```#O%@$`$P````<7`0`I
M````&Q<!``H```!%%P$`!0```%`7`0`(````5A<!`$@```!?%P$`3P```*@7
M`0!/````^!<!`"$```!(&`$`)0```&H8`0`I````D!@!`"````"Z&`$`"```
M`-L8`0`;````Y!@!`",`````&0$`+0```"09`0`V````4AD!`"D```")&0$`
M*0```+,9`0!2````W1D!`#H````P&@$`"````&L:`0`5````=!H!``P```"*
M&@$`"0```)<:`0`/````H1H!`!(```"Q&@$`#P```,0:`0`-````U!H!``D`
M``#B&@$`!@```.P:`0`;````\QH!`!@````/&P$`'````"@;`0`9````11L!
M``8```!?&P$`%@```&8;`0!>````?1L!`&D```#<&P$`!P```$8<`0`.````
M3AP!``0```!='`$`!````&(<`0`6````9QP!`!,```!^'`$`%0```)(<`0`A
M````J!P!`#@```#*'`$`,P````,=`0`&````-QT!``\````^'0$`%````$X=
M`0`.````8QT!`!L```!R'0$`#P```(X=`0`4````GAT!``\```"S'0$`!```
M`,,=`0`+````R!T!``@```#4'0$`#@```-T=`0`.````[!T!``8```#['0$`
M#`````(>`0`0````#QX!``@````@'@$`#@```"D>`0`'````.!X!``<```!`
M'@$`$````$@>`0`(````61X!``L```!B'@$`!P```&X>`0`)````=AX!``H`
M``"`'@$`"@```(L>`0`?````EAX!`$<```"V'@$`'````/X>`0`,````&Q\!
M`!0````H'P$`%0```#T?`0`6````4Q\!`"P```!J'P$`/````)<?`0`B````
MU!\!``@```#W'P$`/0`````@`0`F````/B`!`!$```!E(`$`"````'<@`0`%
M````@"`!`!$```"&(`$`#P```)@@`0`F````J"`!`"8```#/(`$`*@```/8@
M`0`I````(2$!`"4```!+(0$`)@```'$A`0`F````F"$!`"8```"_(0$`-```
M`.8A`0`Q````&R(!`"X```!-(@$`,````'PB`0`E````K2(!`#,```#3(@$`
M1P````<C`0`\````3R,!`#,```",(P$`00```,`C`0!-`````B0!`"<```!0
M)`$`)0```'@D`0`S````GB0!`"L```#2)`$`%@```/XD`0`P````%24!`"4`
M``!&)0$`)@```&PE`0`7````DR4!`+$```"K)0$`&@```%TF`0`E````>"8!
M`#0```">)@$`-````-,F`0`P````""<!`"@````Y)P$`*0```&(G`0`L````
MC"<!`#,```"Y)P$`-@```.TG`0!+````)"@!`$8```!P*`$`F0```+<H`0`M
M````42D!`"8```!_*0$`-````*8I`0`S````VRD!`$4````/*@$`3````%4J
M`0`-````HBH!``<```"P*@$`!0```+@J`0`$````OBH!``P```##*@$`#@``
M`-`J`0`5````WRH!`!0```#U*@$`%P````HK`0`/````(BL!`!$````R*P$`
M#0```$0K`0`0````4BL!``X```!C*P$`#0```'(K`0`5````@"L!``X```"6
M*P$`-@```*4K`0`&````W"L!`!,```#C*P$`!0```/<K`0`,````_2L!``0`
M```*+`$`#0````\L`0`1````'2P!``8````O+`$`$````#8L`0`(````1RP!
M``\```!0+`$`&````&`L`0`/````>2P!`!,```")+`$`$````)TL`0`+````
MKBP!``<```"Z+`$`#0```,(L`0`.````T"P!``L```#?+`$`$````.LL`0`>
M````_"P!``T````;+0$`#P```"DM`0`I````.2T!`!(```!C+0$`&P```'8M
M`0`R````DBT!``P```#%+0$`'@```-(M`0`9````\2T!`!L````++@$`&```
M`"<N`0`^````0"X!``T```!_+@$`"0```(TN`0`4````ERX!``L```"L+@$`
M*@```+@N`0!#````XRX!``@````G+P$`$````#`O`0`C````02\!`!(```!E
M+P$`'@```'@O`0`>````ER\!`"<```"V+P$`&@```-XO`0`A````^2\!`!H`
M```;,`$`&````#8P`0`-````3S`!`"D```!=,`$`20```(<P`0`=````T3`!
M``<```#O,`$`"@```/<P`0`]`````C$!``8```!`,0$`"````$<Q`0`1````
M4#$!`!$```!B,0$`$P```'0Q`0`3````B#$!`!H```"<,0$`&@```+<Q`0`=
M````TC$!`!P```#P,0$`!@````TR`0`+````%#(!``\````@,@$`)0```#`R
M`0`2````5C(!`!````!I,@$`$````'HR`0`9````BS(!`$P```"E,@$`0@``
M`/(R`0`)````-3,!`!,````_,P$`B````%,S`0`A````W#,!`"4```#^,P$`
M!@```"0T`0`<````*S0!`"L```!(-`$`*0```'0T`0`A````GC0!`"(```#`
M-`$`'@```.,T`0`6`````C4!``X````9-0$`#0```"@U`0`/````-C4!``T`
M``!&-0$`#P```%0U`0`-````9#4!``L```!R-0$`$0```'XU`0`&````D#4!
M``<```"7-0$`#P```)\U`0`,````KS4!`"P```"\-0$`$````.DU`0`)````
M^C4!``D````$-@$`)`````XV`0`P````,S8!`"0```!D-@$`(P```(DV`0`A
M````K38!`"````#/-@$`,P```/`V`0`A````)#<!`!\```!&-P$`!@```&8W
M`0`.````;3<!``@```!\-P$`"````(4W`0`)````CC<!`!<```"8-P$`&```
M`+`W`0`-````R3<!``D```#7-P$`#@```.$W`0`+````\#<!`!\```#\-P$`
M!@```!PX`0`)````(S@!``L````M.`$`#````#DX`0`.````1C@!``8```!5
M.`$`&0```%PX`0`2````=C@!``0```").`$`*@```(XX`0`0````N3@!`!P`
M``#*.`$`!P```.<X`0`"````[S@!``<```#R.`$``@```/HX`0`&````_3@!
M`!0````$.0$`"0```!DY`0`-````(SD!`"D````Q.0$`"0```%LY`0`8````
M93D!``\```!^.0$`"````(XY`0`*````ESD!``D```"B.0$`#P```*PY`0`#
M````O#D!``P```#`.0$`#@```,TY`0`&````W#D!`!8```#C.0$`*@```/HY
M`0!2````)3H!`"X```!X.@$`+P```*<Z`0`&````USH!`!4```#>.@$`$@``
M`/0Z`0`,````!SL!``P````4.P$`!P```"$[`0`%````*3L!`!4````O.P$`
M"````$4[`0`(````3CL!`!L```!7.P$`!````',[`0`&````>#L!`"````!_
M.P$`!0```*`[`0`1````ICL!`!$```"X.P$`$````,H[`0`2````VSL!`!<`
M``#N.P$`#`````8\`0`Y````$SP!`!H```!-/`$`(````&@\`0`8````B3P!
M``<```"B/`$`"0```*H\`0`(````M#P!`"@```"]/`$`+````.8\`0`T````
M$ST!``P```!(/0$`'0```%4]`0`\````<ST!`!@```"P/0$`!P```,D]`0`*
M````T3T!``P```#</0$`#P```.D]`0`2````^3T!`$L````,/@$`C@```%@^
M`0!T````YSX!`"(```!</P$`#````'\_`0`-````C#\!`!<```":/P$`&```
M`+(_`0`4````RS\!``@```#@/P$`$0```.D_`0`3````^S\!`!`````/0`$`
M%````"!``0`=````-4`!`"8```!30`$`>P```'I``0`5````]D`!`!(````,
M00$`#````!]!`0`A````+$$!`!<```!.00$`$@```&9!`0`1````>4$!`!(`
M``"+00$`&````)Y!`0`P````MT$!`#0```#H00$`+0```!U"`0`Q````2T(!
M`"P```!]0@$`+@```*I"`0`B````V4(!`$@```#\0@$`&````$5#`0`9````
M7D,!`!H```!X0P$`&P```)-#`0`1````KT,!`!L```#!0P$`'````-U#`0`7
M````^D,!`!@````21`$`.@```"M$`0`=````9D0!`!H```"$1`$`/@```)]$
M`0`6````WD0!``8```#U1`$`#````/Q$`0`B````"44!`!,````L10$`&```
M`$!%`0`3````644!`"@```!M10$`*@```)9%`0`@````P44!`"4```#B10$`
M'0````A&`0`4````)D8!`!T````[1@$`(````%E&`0`A````>D8!`!H```"<
M1@$`&P```+=&`0`6````TT8!`!T```#J1@$`'`````A'`0`>````)4<!``H`
M``!$1P$`%````$]'`0`)````9$<!``8```!N1P$`!P```'5'`0`(````?4<!
M``8```"&1P$`!@```(U'`0`*````E$<!`!0```"?1P$`$````+1'`0`5````
MQ4<!`!,```#;1P$`%@```.]'`0`Q````!D@!`!`````X2`$`'@```$E(`0`6
M````:$@!`!$```!_2`$`$````)%(`0`P````HD@!``@```#32`$`#0```-Q(
M`0`*````ZD@!``P```#U2`$`+P````))`0`-````,DD!`!4```!`20$`%@``
M`%9)`0`=````;4D!`!<```"+20$`!0```*-)`0`,````J4D!`"4```"V20$`
M!@```-Q)`0`(````XTD!`!@```#L20$`$@````5*`0`'````&$H!``\````@
M2@$`#````#!*`0`8````/4H!`$\```!62@$`#````*9*`0`H````LTH!`!,`
M``#<2@$`'@```/!*`0`.````#TL!`!0````>2P$`$0```#-+`0`:````14L!
M`!@```!@2P$`%0```'E+`0`?````CTL!`"4```"O2P$`(P```-5+`0`E````
M^4L!``L````?3`$`#@```"M,`0`,````.DP!``P```!'3`$`!0```%1,`0`%
M````6DP!``0```!@3`$`!0```&5,`0`5````:TP!`%,```"!3`$`$````-5,
M`0`+````YDP!``4```#R3`$`!0```/A,`0`8````_DP!`!@````730$`%P``
M`#!-`0`+````2$T!`"T```!430$`!@```()-`0`%````B4T!`!@```"/30$`
M%0```*A-`0!E````ODT!``4````D3@$`!P```"I.`0`I````,DX!`#@```!<
M3@$`%````)5.`0`9````JDX!`"@```#$3@$`'0```.U.`0`<````"T\!`!\`
M```H3P$`$0```$A/`0`&````6D\!``@```!A3P$`!@```&I/`0`/````<4\!
M``D```"!3P$`:0```(M/`0`2````]4\!``X````(4`$`!@```!=0`0`>````
M'E`!`"@````]4`$`!P```&90`0`'````;E`!``4```!V4`$`'````'Q0`0`;
M````F5`!`#4```"U4`$`"````.M0`0`%````]%`!`"H```#Z4`$`5````"51
M`0`:````>E$!`"P```"540$`&P```,)1`0`"````WE$!``@```#A40$`$P``
M`.I1`0`,````_E$!``8````+4@$`"P```!)2`0`+````'E(!``L````J4@$`
M2P```#92`0`,````@E(!`!$```"/4@$`#P```*%2`0`,````L5(!``P```"^
M4@$`#````,M2`0`2````V%(!``L```#K4@$`'````/=2`0`+````%%,!`!P`
M```@4P$`%@```#U3`0`$````5%,!``0```!94P$``P```%Y3`0`/````8E,!
M``H```!R4P$`'0```'U3`0`.````FU,!`!\```"J4P$`(@```,I3`0`7````
M[5,!``<````%5`$`$0````U4`0`(````'U0!``\````H5`$`$````#A4`0`)
M````250!``4```!35`$`6````%E4`0`X````LE0!`"T```#K5`$`10```!E5
M`0`1````7U4!`#0```!Q50$`2````*95`0!-````[U4!`$T````]5@$`4@``
M`(M6`0`=````WE8!`"0```#\5@$`'````"%7`0`@````/E<!`",```!?5P$`
M(@```(-7`0`A````IE<!`"````#(5P$`(@```.E7`0`Z````#%@!`#H```!'
M6`$`/@```()8`0`[````P5@!`#P```#]6`$`.0```#I9`0"5````=%D!`!\`
M```*6@$`#@```"I:`0`F````.5H!``P```!@6@$`$P```&U:`0`X````@5H!
M`#````"Z6@$`*@```.M:`0`-````%EL!`%L````D6P$`50```(!;`0`'````
MUEL!`!<```#>6P$`%P```/9;`0`(````#EP!``@````77`$`"0```"!<`0`1
M````*EP!`!`````\7`$`#0```$U<`0`/````6UP!``<```!K7`$`)@```'-<
M`0`(````FEP!``8```"C7`$`$P```*I<`0`1````OEP!``\```#07`$`50``
M`.!<`0`'````-ET!`!4````^70$`!@```%1=`0`'````6UT!``<```!C70$`
M-````&M=`0`0````H%T!`",```"Q70$`-````-5=`0`D````"EX!`'\````O
M7@$`&@```*]>`0!3````REX!`"X````>7P$`$0```$U?`0`'````7U\!``X`
M``!G7P$`#P```'9?`0`.````AE\!`!,```"57P$`!@```*E?`0`C````L%\!
M`!D```#47P$`!0```.Y?`0`2````]%\!`!D````'8`$`)P```"%@`0`8````
M26`!`!,```!B8`$`(````'9@`0`*````EV`!``D```"B8`$`&0```*Q@`0`+
M````QF`!`!4```#28`$`'P```.A@`0`5````"&$!`#4````>80$`%0```%1A
M`0`A````:F$!``<```",80$`%P```)1A`0`(````K&$!``<```"U80$`"P``
M`+UA`0`D````R6$!`#0```#N80$`"````"-B`0`=````+&(!``\```!*8@$`
M"````%IB`0`1````8V(!`!8```!U8@$`"````(QB`0`*````E6(!`"0```"@
M8@$`/@```,5B`0`_````!&,!`"<```!$8P$`-````&QC`0`L````H6,!`$T`
M``#.8P$`(P```!QD`0`N````0&0!`#4```!O9`$`70```*5D`0`R`````V4!
M``<````V90$`"````#YE`0`)````1V4!``H```!190$`(0```%QE`0`@````
M?F4!`#$```"?90$`)0```-%E`0`R````]V4!`#\````J9@$`"0```&IF`0`?
M````=&8!``L```"49@$`"0```*!F`0`M````JF8!`!$```#89@$`$````.IF
M`0`.````^V8!``@````*9P$`&````!-G`0`(````+&<!``\````U9P$`'P``
M`$5G`0`B````96<!`$0```"(9P$`$@```,UG`0`'````X&<!``\```#H9P$`
M!P```/AG`0`(`````&@!``4````):`$`$@````]H`0`_````(F@!`&,```!B
M:`$`'0```,9H`0`(````Y&@!`"@```#M:`$`(````!9I`0`(````-VD!``P`
M``!`:0$`#0```$UI`0`J````6VD!``<```"&:0$`$0```(YI`0`2````H&D!
M`!@```"S:0$`$0```,QI`0!`````WFD!``H````?:@$`(0```"IJ`0`0````
M3&H!`!0```!=:@$`0````')J`0`L````LVH!`#P```#@:@$`/0```!UK`0`V
M````6VL!``\```"2:P$`!@```*)K`0`2````J6L!`!8```"\:P$`&P```--K
M`0`)````[VL!`!0```#Y:P$`&@````YL`0`(````*6P!`!D````R;`$`'P``
M`$QL`0`+````;&P!``8```!X;`$`%@```']L`0`0````EFP!`!@```"G;`$`
M!@```,!L`0`,````QVP!`!````#4;`$`#@```.5L`0`4````]&P!`!0````)
M;0$`!@```!YM`0`&````)6T!`#4````L;0$`*0```&)M`0`G````C&T!``@`
M``"T;0$`%````+UM`0`8````TFT!`"@```#K;0$`#0```!1N`0`J````(FX!
M`!@```!-;@$`%````&9N`0`%````>VX!``H```"!;@$`"````(QN`0`0````
ME6X!`&4```"F;@$`&@````QO`0`_````)V\!``<```!G;P$`!P```&]O`0`1
M````=V\!`!````");P$`$@```)IO`0`A````K6\!`!\```#/;P$`$P```.]O
M`0`A`````W`!``\````E<`$`*````#5P`0`4````7G`!`!$```!S<`$`=@``
M`(5P`0`@````_'`!`"`````=<0$`*0```#YQ`0`=````:'$!`!X```"&<0$`
M)@```*5Q`0`?````S'$!`!X```#L<0$`'`````MR`0`)````*'(!``D````R
M<@$`"0```#QR`0`/````1G(!`#0```!6<@$`&@```(MR`0`8````IG(!``@`
M``"_<@$`!P```,AR`0!;````T'(!`$`````L<P$`/0```&US`0""````JW,!
M``P````N=`$`-@```#MT`0`P````<G0!``X```"C=`$`/P```+)T`0`&````
M\G0!`%,```#Y=`$`+@```$UU`0`O````?'4!`!8```"L=0$`,@```,-U`0`D
M````]G4!`!4````;=@$`#````#%V`0`%````/G8!`!(```!$=@$`"@```%=V
M`0`C````8G8!``0```"&=@$`(0```(MV`0`2````K78!``H```#`=@$`%```
M`,MV`0`:````X'8!`"\```#[=@$`#0```"MW`0`*````.7<!`!@```!$=P$`
M!@```%UW`0`>````9'<!``\```"#=P$`$0```)-W`0`/````I7<!`!````"U
M=P$`$0```,9W`0`9````V'<!``D```#R=P$`'P```/QW`0`+````''@!``(`
M```H>`$`(````"MX`0`'````3'@!``H```!4>`$`?P```%]X`0`N````WW@!
M`%@````.>0$`'````&=Y`0`F````A'D!`$D```"K>0$`,````/5Y`0`\````
M)GH!`!P```!C>@$`%P```(!Z`0`(````F'H!``@```"A>@$`"@```*IZ`0`&
M````M7H!``@```"\>@$`*0```,5Z`0`7````[WH!`!H````'>P$`%P```")[
M`0`*````.GL!``@```!%>P$`$@```$Y[`0`>````87L!``L```"`>P$`#0``
M`(Q[`0`:````FGL!`!$```"U>P$`!0```,=[`0`*````S7L!`!(```#8>P$`
M`@```.M[`0`C````[GL!`"H````2?`$`-P```#U\`0`L````=7P!`#D```"B
M?`$`+@```-Q\`0`;````"WT!`#L````G?0$`,@```&-]`0`]````EGT!`#(`
M``#4?0$`-0````=^`0`B````/7X!`$<```!@?@$`(P```*A^`0`Q````S'X!
M`$````#^?@$`<@```#]_`0!E````LG\!`"$````8@`$`'P```#J``0`R````
M6H`!`"0```"-@`$`(P```+*``0`Y````UH`!`#P````0@0$`*````$V!`0`O
M````=H$!`"````"F@0$`.0```,>!`0!W`````8(!`#L```!Y@@$`5````+6"
M`0`V````"H,!`#0```!!@P$`3@```':#`0!T````Q8,!`%P````ZA`$`1P``
M`)>$`0!`````WX0!`$`````@A0$`8@```&&%`0!G````Q(4!`&`````LA@$`
M8P```(V&`0`\````\88!`#@````NAP$`-````&>'`0`S````G(<!`"@```#0
MAP$`-````/F'`0!-````+H@!`"H```!\B`$`5P```*>(`0`C````_X@!``P`
M```CB0$`30```#")`0`@````?HD!`#X```"?B0$`)P```-Z)`0`D````!HH!
M`$(````KB@$`!0```&Z*`0`)````=(H!``,```!^B@$`$````(**`0`2````
MDXH!``8```"FB@$``0```*V*`0!D````KXH!``0````4BP$`!@```!F+`0`T
M````((L!``0```!5BP$`"@```%J+`0`,````98L!``(```!RBP$`!P```'6+
M`0`6````?8L!`"@```"4BP$`6````+V+`0`U````%HP!`#8```!,C`$`&@``
M`(.,`0`M````GHP!`#````#,C`$`)@```/V,`0`@````)(T!`"````!%C0$`
M*0```&:-`0`D````D(T!`!\```"UC0$`*````-6-`0`E````_HT!`"D````D
MC@$`-0```$Z.`0`?````A(X!`#(```"DC@$`.0```->.`0`G````$8\!`"L`
M```YCP$`)P```&6/`0`B````C8\!`"L```"PCP$`,````-R/`0`M````#9`!
M`"X````[D`$`*@```&J0`0`A````E9`!`"0```"WD`$`,````-R0`0`?````
M#9$!`"<````MD0$`.````%61`0`W````CI$!`!T```#&D0$`*0```.21`0!+
M````#I(!`"@```!:D@$`+````(.2`0`H````L)(!`"D```#9D@$`(P````.3
M`0`?````)Y,!`"H```!'DP$`.P```'*3`0`F````KI,!`#$```#5DP$`,@``
M``>4`0!%````.I0!``P```"`E`$`$0```(V4`0`=````GY0!`#4```"]E`$`
M(````/.4`0`+````%)4!`"(````@E0$`(0```$.5`0`*````994!`!D```!P
ME0$`"````(J5`0`+````DY4!``\```"?E0$`#@```*^5`0`@````OI4!``8`
M``#?E0$`1````.:5`0`:````*Y8!`!<```!&E@$`$P```%Z6`0`'````<I8!
M`$8```!ZE@$`!@```,&6`0`D````R)8!``\```#ME@$`#@```/V6`0`4````
M#)<!`$(````AEP$`%P```&27`0`+````?)<!`"````"(EP$`#````*F7`0`-
M````MI<!`!,```#$EP$`'````-B7`0`'````]9<!`"0```#]EP$`"````"*8
M`0`8````*Y@!`#(```!$F`$`!@```'>8`0`<````?I@!``D```";F`$`0@``
M`*68`0`(````Z)@!`!4```#QF`$`%@````>9`0`5````'ID!``H````TF0$`
M"@```#^9`0`-````2ID!`"$```!8F0$`$@```'J9`0`*````C9D!``P```"8
MF0$`"@```*69`0`R````L)D!``H```#CF0$``@```.Z9`0`8````\9D!`",`
M```*F@$`#P```"Z:`0`)````/IH!``X```!(F@$`#0```%>:`0`X````99H!
M`"4```">F@$`,````,2:`0`)````]9H!`!8```#_F@$`3````!:;`0`7````
M8YL!`!(```![FP$`"@```(Z;`0`%````F9L!`!H```"?FP$`!@```+J;`0`'
M````P9L!``@```#)FP$`!@```-*;`0`4````V9L!`!,```#NFP$`/0````*<
M`0`N````0)P!`#T```!OG`$`"P```*V<`0`"````N9P!`!(```"\G`$`20``
M`,^<`0`P````&9T!`!<```!*G0$`-@```&*=`0`K````F9T!`%<```#%G0$`
M%@```!V>`0!X````-)X!`!\```"MG@$`/@```,V>`0`@````#)\!`$`````M
MGP$`.````&Z?`0`H````IY\!`"<```#0GP$`*````/B?`0`I````(:`!`"D`
M``!+H`$`)P```'6@`0`O````G:`!`"P```#-H`$`0````/J@`0`6````.Z$!
M`!\```!2H0$`$P```'*A`0"%````AJ$!``L````,H@$`J````!BB`0!Z````
MP:(!`(4````\HP$`+````,*C`0!=````[Z,!`!,```!-I`$`+@```&&D`0`;
M````D*0!`!4```"LI`$`%P```,*D`0`B````VJ0!`$8```#]I`$`)0```$2E
M`0`@````:J4!`%P```"+I0$`&@```.BE`0`5`````Z8!`!H````9I@$`%0``
M`#2F`0`9````2J8!`",```!DI@$`$````(BF`0`0````F:8!``X```"JI@$`
M!P```+FF`0`&````P:8!`!L```#(I@$`!@```.2F`0`%````ZZ8!`!D```#Q
MI@$`"`````NG`0`)````%*<!`!@````>IP$`#0```#>G`0`;````1:<!``8`
M``!AIP$`!P```&BG`0`5````<*<!``H```"&IP$`!0```)&G`0`A````EZ<!
M`!@```"YIP$`"0```-*G`0`F````W*<!`!@````#J`$`'0```!RH`0`;````
M.J@!``@```!6J`$`$0```%^H`0`4````<:@!`!4```"&J`$`"0```)RH`0`6
M````IJ@!`!L```"]J`$`!@```-FH`0`X````X*@!``0````9J0$`$````!ZI
M`0`7````+ZD!``L```!'J0$`"````%.I`0`/````7*D!`!P```!LJ0$`&```
M`(FI`0`4````HJD!``@```"WJ0$`$0```,"I`0`/````TJD!`!$```#BJ0$`
M*P```/2I`0`)````(*H!``H````JJ@$`$@```#6J`0`"````2*H!``L```!+
MJ@$``0````````!_````]P(``!8"``#(`P```````%D!```/`P````````4!
M````````704````````#!0``-`$`````````````4`$```````#5`P``,0(`
M`(4"``"+`@``]00```````!O`P``3`````D!``"#`@``A@0``%P```"1`0``
M`````&$$````````.@```"X#``#S`0``O0$```````!6!```3P(``,P#``"I
M````D@$`````````````%@```/<#````````9`4``$<%``#R!```````````
M`````````0,``#\$``"N!```00$````````/!```P@$``"<#``#$`@``(P(`
M`,<"``!"`@```````"L#```;!0``K@,``(8%```]`0``8`,``'@%``"Z`@``
M?`,`````````````<`(``````````0``=00````````B`0``_@(``#L!````
M````[`$``"0$`````````````%,%``#Q!```%P`````````<`P``6P,``)4"
M``".`0``$0(``+`"````````#@$``"X"``!D`0``]P0``/H#```3`P``<`4`
M`/0$```Q````D`$``",#````````/00``,(```",`P``%P(```$!``"@````
M7@4```````!U`0``K`$`````````````A00``$$%`````````P0``'0$``"P
M`0``2@(``%(````,!```E@```/4#``````````````````#T`0``^00`````
M``#@`@``9`,``$P#``!(`P``^`(``(````!\!0``&@,`````````````/@4`
M`),"``!;!```=04``,D```#P!```!@$````````%`P``8P4`````````````
M``````````":!```%`4`````````````XP```.H#``#Z````#`4```````!O
M!```+@4``,`````9`P``(@4``#`!``"8`@`````````````6`0```````+0#
M``!8`0``W0$```````":`P```````%<!````````3@(```````"2````_P0`
M``````````````````````#C`0```````.D```"$!0``K`0``$,%````````
MC@0``*4!```_`0``'P```,<#``!1!0```````-($```W!```#0$``#4#``",
M`0```````!4"```,`````````*0```!R!0``G@,``)8"```*`P```````'``
M````````PP(```````#]`0``/@```"X$``#*`P``1P(``)L`````````````
M`#(#````````JP$``%$!```````````````````;`@``:`````````"H`@``
MC0,``',#``"+`0``````````````````_`,``.@!``#<`0``````````````
M````6P$``%,#````````F0(``(\```!V`0``\`,``)@#````````#@``````
M```4`@``VP0``!D"``#N````O`(``)<$```_`P```````'`#``!Z````8`$`
M`)\!`````````````*$!``!J!```]`,``%L%``!W`@``(@,`````````````
MP@0``/$`````````8`(``-@#````````R0$``(`"````````>P$``!@!````
M````,`0``````````````````!@"``#:`````````+$"``#3`P``G`(``.$$
M```J`@``1@0```````#H`````````-@"```)!0``SP(``!$%``"[`0``````
M`#<%``"V!```D`(``````````````````"<````L`@``>P4```````#-`P``
MVP````````"2`@```@,``*T#``#(````:P````````!V````80,``&D%````
M`````04``*H```"V`@``000```````#F!```3@,``!(#``"8`````````&H#
M``#M`@``CP$``$,```"J`@``'`4``(@#````````(04````````^`P``````
M`*,!``"/`P``70,`````````````'@(``*\$``"=!```A`0``*P"``"Q````
M`````'<$``!K`P``A@````````"S`P``-0$```````!J````;`,``.T$``!+
M`@``X@```+\```"_!````````)L!``!^!0``=@4``-T```"=`P``1@,``$T"
M````````T0,``!T```"1`@``\0(``````````````````#H#````````````
M`!@%`````````````*("``"W!```3`4``/@!```-`@``>P```$,$``!:`0``
M`````.4"````````G`,``$D"``!(!0``T0```"("````````XP0``(<#``")
M`@``V0,``!L$```G`0``Y`$``/@```!/````4````!D$``#8!````````.X"
M``!+!0```````#T#````````10``````````````S00``&(%``"E`P``L@(`
M`#8%``#F`P``C00````````V`P```````.P"````````Q@```"@!``#8````
MC@(`````````````_`(````````?`@```````!H!``#_````204``&X#```&
M`@``9P$``+(!``#O`P```````/\#`````````````"8$```[!0```````"<%
M``"D`P``V`$````"``#X`P``+P(``!T%``#U````(P4``*H#``!Y````````
M`#`"``!)`P``*`4```D#``#/`0``9P(``&8"`````````0(``%D$``!U````
MJ`$``"$!``#Q`0``#@0``,0#``!N!```304``%<#``#0`P``\0,``&8#``!.
M````TP(````````3`@```````,8$``!U`P``G0(``!X```">`@``U@0`````
M````````:0(``.@$``!+!```(`(```0!````````_0(``"4$``"@`@``````
M`"H`````````:@(``%@%``#J`0````````````!'````@04``"4!``"I`@``
M`````!0#```(!````````'H!``"Q`0``$@0``-X!```*````-@(``%(!````
M`````````$`"``"!````*`0``!T!``!#`P``J@0``%8"``"S`@````4`````
M``!*`P``/`,``(`#``#S````C@```$L!````````,@`````````X`@``(P``
M```````N````+`$``'T$``!H`0``=0(``+H$```L````(P$```````"O`@``
M>````%4#````````6`(`````````````4P(``&$%````````MP$``)<"``#^
M`P``?`(``-P#```,`0``XP,``)\`````````;0(``(<!``"V`0``&@0`````
M``!M`0``4@(``.0$`````````````*@```#%`@``B0```/D#```*`0```@``
M`)<````Z!```Z@0``/P```"(!````````#8$``!?`0``:0$``.<````'!```
M"0```/(!``#Z!```U00``#0"``#%!```*0(``.T#``!$`@``9P4``,P$``"T
M`@```````%@$``"S````30,``-X```!-`0``7P(```````!_`0``S```````
M``"*`0``$`4```````!X!```<P$``.4```"5`P``6`,``)$````W`P``"0(`
M`"T$``"I`0``_0```+$#````````100```0%``!3````*@0``'\%````````
MY00``-("```=`@```````'(#````````U@,``'(!``#9`@```````$P"``""
M`@``(`,``,4```#G`@```````(T```!@!0``!@```'0"`````````P$``)T!
M``"C`@``*P4``&0````R!```^P```)X``````````````-`"``!G!```````
M`)D!``!S!0``8@```%T!``"]`P```````%($``!_`@``M````-P"``#L`P``
M/@(``(4````M````P0$``````````````````,L```"M````EP,`````````
M```````````````7`P``:P(``(8"````````%0,``$(```#4`@```````#H"
M````````6P```-0#``#V`0``!````!$```"0`P``G````"P#````````````
M`#@$````````.00``%\````Y!0```````.D#```H`P``^P0```````!4````
M`````)@!``"V````KP$``'L$``!P!```50(``$D```"I`P``&0```#L"``!0
M`P``*`(``%P#``!H`P``-`0``(@"``#*!```T0$``"T!``"``0````,`````
M````````?P0``*4$````````0@,```````#G`P``,`````````#]`P``````
M`#D```#4!````````+8#````````\`$``$0%``"9!```$`,``%H#``!G`P``
M]`(``)D```!F````>`,``!\#``"[`@``_P$```4%````````Y`,``*4"``"F
M`@``"P$```````#V````/`4``.@"````````&`0``-<$````````2@```),$
M```*!0``!@0```````"O`P``?0```,T`````````[0```&$!```$`@``````
M`+T$`````````````)@$```Y`0``;0,``)<!``!-!````@(``&X```"6`P``
M`````#$#``!N`@```````*<$```>`P``)@(``-`!```M!0```````%8!``"@
M`0```````%4```#U`@``BP0``#P```!E`P``2`0``%4%``"Y`@``U@$``#@`
M```\!```>0(``%4$``!9`@``/`(```````"G`@``_P(```````"4````900`
M`#8!``##`P````````````!'`P``T@,``.\"``!@`````````,<!````````
M>0$```````")!```K@$``````````````````%\$``!8````,P(``$\#````
M````'P$```````!W!0``N`(``,,```"R!```7@$```````"#!````````*$$
M``#B!`````````4$``!I!````````#T````<`@``L```````````````,P$`
M`"D!``#+`P``R@$``+@$``!C`P``@P4````````>!```VP(``(H````E````
MYP0``/L!````````#P(``(4%```R!0``6P(``$8"```M`@``Z0(``!P$````
M````@0,``!0$``!O````V00```````!"!0``0`0``&P%``"B`P``F@(``!8$
M````````\@(``!,%```,`@``"````*0"```U!```1P0``%H````_!0``O0``
M```````"`0``700``-H$``!1````!P(``,4#`````````````%\#``!Y!```
M2`(``"L````I````)@4````````P!0``@`0``(H#``"Y`0``5P0``"\!``"K
M````.P0``(<"``#,`@``P00``&D````6!0``0````/`"``"2!```BP,``)`$
M````````RP$``.0"``"U`P``<@0```4"``#\!````@0``,@$```!!```LP$`
M`,<```"(`````````%0%``!&!0``K@```&T$``#.`0```````.,"``"^`0``
M10,````````V````LP0```````!1`P``#0,````````O!```*``````````=
M`P```````&@%``#!`P````````H$```-!0`````````````2!0``P`0```(%
M```<`0``E`$``",$``##`0```````#@!````````10$``#,#````````N`$`
M`,L$``"U````I@0``.D$``!C`0``D0,``%H%``"#````>P,````````0````
MP`(````````J`P``1@```-,!``!G````<@(``````````````````'T#``"Z
M`P```````.("````````A````,D"``"5`0```````+\!````````B@(``$8!
M``!@!```L@,```````"!`@``A`$```````"K!```R0,``!X%````````3P$`
M`%`%```#`P```````!$#``!Z`@```````#X$```U`@``%````!H"``!T````
M`````&@$``#@`P```````(\$```G!```SP````````!!````AP0```````"^
M`@``3@$``(H$``#K`P``Y0,````````(`@```````*$#``"=````.0,``!`"
M````````&````.X$``!)!```8P(``-\#``!L`0``50$``#$%``"]`@``C```
M``````!Z`P```````%0$```7`0``M0(```L%`````````````$X%``!7````
M``````4`````````&04``-L!````````JP(``)P!``#@`0``<`$`````````
M````2@$``!(!```[`P``=`$```````"L`````````%0"```2`````````'X#
M``!B`0``.0(``+<"``!>`P```````-X$````````Z@(``-4!``"_`@``Q`$`
M`"4#``#4`0```````+D#```#````_00``*L#``#V`P````````````#M`0``
M)`$```````!"`0``UP$```````#N`0``6@(``)X!````````N@````````#^
M!```6@0``-L#```3````J`,``!H````,`P``[P$``````````````````-`$
M``#?`````````)\"```+`P``0`$```````"^`P``HP``````````````(@``
M`%8%```D!0``?0(```````!!`P```````#<"```'`P```````*,$``#&`P``
M`````*X"``!L!```)04```````"L`P``4P$``%(%``!\!````````.8`````
M`````````'X$``#.!```2P```%$"``"'!0``A@$```T```!4`0``D@,``'8$
M````````I`0``((!```'`0`````````````A`@``4@,```H"``!*!```````
M`'L"`````````````#T"``#<!```U````&@"``!F`0``````````````````
M`````$@````Q!````````*$```#7`@```````%D```"/`@``B0$``'P!``"[
M````4`0``+P!````````%0```'(`````````^P,``#T%``!O`0```````#4%
M``#7````H@```$,!``#O!```7`4``,T!``#'!`````````8%``#W`0``W@,`
M`"\%```(`P``%`$```````""!```V@,``,\#``!*!0``N````$4"``#.````
M`````$<!````````"00``$D!``#F`0``70(`````````````>@4``$X$```?
M!```&P$``!T$``!$`P```````-,$```&`P``WP0`````````````Q````)``
M``"'````30```/P!``#V!```0@0```````""`P``N@$``,L"``#``0``:P4`
M``````#S`@``<04``(@!``!^`@```````.4!````````;P(``-H!``!E!0``
M`````.$#````````M00``,8"``!L````%P0``%X"````````)@$```0$````
M````,P4``%D%``!X`@``:P0``"4"``#K`````````,$```#J````8@,``!4!
M````````00(```````#L````C`0``,@"```F`````````/X!``"B!```E`0`
M`-,````O`P``80(``!<%```<````$@(``'D#``!M!0``9@0``&\%````````
M,0$```````!A``````````````!^`0``;@$````````3!```DP```$0`````
M````,`,``.\```#Y`````````/H"``"[!```)P(``"$```"Q!```\@``````
M``"4`@```````/H!``#P````;0```$P$``#K!```#@,``'D%``#.`P``I0``
M`+0!``"5!```,@$````````O````I`$```````!Q`P``(`0``(L````@````
M`````$@!``"6!````````-(`````````UP,``+D$``"9`P```````)H````B
M!```KP```$\$``#Y`@``E0`````````$`P```````!L`````````M0$``,`#
M```Z`0``X@$`````````````X`````````!J`0```````-D!``#2`0``8P``
M`/<```!S`@```````#0%````````J@$```````#F`@``=@,`````````````
M``````T$``!=`````````!`!``!Q`@```````*T"```````````````````X
M`P``S`$``$L#``!%!0``5P(```````"P!```H@$``+L#``":`0``ZP(``.$!
M``````````````````#Y`0``X0(``````````````````%`"````````OP,`
M`/X```#.`@``````````````````+0,``',$````````*P(```````"?!```
M````````````````-````%D#````````)````'<!```9`0``"`4``(T!```X
M!0``!P````````"^!```*@$``/,$``"I!```!P4``*@$`````````````$\%
M``#R`P``^P(````````L!```"P(``&D#``````````````````!W````<00`
M`&4!``#=`P``%04```````#<````A0,``'T!````````O`,````````5!```
M&`,``/0```#1`@``I@$``&4"``!^````U@(``$0!``#%`0``X`0``$,"``"Y
M````@@4```\%````````H0(``%<%``";`@```````&0"``!B`@``5@``````
M``#V`@``V0```-H"``"$`@``)`(``),!````````]0$````````@`0``)`,`
M``````"G`0```````%0#``#B`P``GP,```\!``##!```DP,```````"`!0``
MT````%8#``#L!````````'P````S````U0(``((````#`@``H`,``&L!````
M````K00``,$"``!$!```S0(``*,#````!```C@,``,8!``!``P``O````#<`
M``#?`0``P@(``#H%``!Q`0``+`4``)L#``!Q````*@4``"8#````````````
M`"L!`````````````.<!``#(`0``C`(```````#$!````````"$$``"#`0``
MP@,```@!``#I`0``7@```.0`````````>@0```````"<!````````.$```#X
M!`````````````"!`0```````',```!C!```@P,```X%`````````````!L#
M``"^`````````+P$````````*0,``%P"````````-0````````#S`P``-P$`
M`$`%````````7`$`````````````W00```````!3!```/@$``&P"```R`@``
MW0(`````````````U@```-$$``!D!```[@,``#,$``!N!0``*P0``'T%````
M````A`,``&4```!W`P``7`0``!X!``"W`P``R00```````!_`P``A@,```X"
M````````7P4``"X!``"F````L@```#P!``#5````8@0``)X$```T`P``WP(`
M`$P!``"P`P``/P(``#L`````````$0$`````````````"P0``)$$``"T!```
M>`$``*<#```?!0``$P$```````")`P```````!`$``!J!0``R@```%X$```+
M````A0$``'8"```@!0``R@(``*T!``"F`P``=`4``````````````````*<`
M````````E@$``!$$``"4`P``C0(``($$``!F!0``=`,````````_````ZP$`
M``````"@!```````````````````N`,`````````````%@,``,\$```A`P``
M`````!H%``#>`@``*00``.@#``";!```400``+<````I!0``#P``````````
M("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`
M("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI`"!A="``(B5S(B!I
M<R!N;W0@82!D:7)E8W1O<GDN`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E
M+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R
M>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S(B!W87,@861D
M960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H
M92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E
M<RX`)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`)60@
M)7,@86YD("5S`"5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S
M+@`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`
M)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO
M;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E
M<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@:7,@<F5A9'D@=&\@
M<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E
M;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W
M86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E
M<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!
M9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!4
M87-K;&ES=``E<SH@)7,`)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R
M;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@
M86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I
M=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+@`L(&=U<W1I;F<@`"P@9W5S
M=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T
M("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0
M<F5V:6]U<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H
M:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC
M(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@
M<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D
M(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S
M86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P
M=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@
M<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U
M8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A
M9V4N`$%-($-L;W5D<P!!32!,:6=H="!286EN`$%-(%)A:6X`04T@4VAO=V5R
M<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I
M=&]R`$%B;W5T+BXN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C
M=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N
M="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N
M+@!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E
M<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M
M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O("(E<R(`061D(&$@8VAI;&0@
M<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN
M`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@
M82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O
M(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B('1O('1H92!S
M>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN
M9F]R;6%T:6]N.B`E<RX`061D960@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@
M8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D
M<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N
M<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`06QI9VX`06QI9VYM
M96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!
M;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED97,`06QL;W<@;75L=&EP;&4@
M861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_
M`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T
M92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R
M;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N
M871E('1E>'0Z`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@
M=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"X`06YS=V5R`$%P<&QI8V%T:6]N
M`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY
M('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R
M:6P`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R
M92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E
M<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@
M86YY('-U8BUG<F]U<',_`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D
M;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M
M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T
M=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T
M=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`
M075G=7-T`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R
M97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA
M<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM
M96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@
M:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD
M87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV
M92!$:7)E8W1O<GD`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S
M+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5
M;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@
M=7!D871E('5S97(@)7,`075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N
M;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ
M(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S;6)A
M=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC
M871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N
M=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC
M871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N('1O
M('1H92!334(@<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE(&9I96QD<SH`0F%C
M:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R
M9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"87-E(&=R87!H:6-S(&1I<F5C
M=&]R>2`B)7,B(&YO="!F;W5N9"X`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A
M<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO
M8VL@5'EP90!";VQD`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S
M<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T=&]M
M`$)R87II;`!"=6QL971E9"!,:7-T`$--4P!#4D,`0U),($1I<W1R:6)U=&EO
M;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#86-H92!I;FET('=A<R!N
M;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A;B!N;W0@
M8V]P>2!F:6QE*',I("T@<V]U<F-E(&%N9"!D97-T:6YA=&EO;B!A<F4@=&AE
M('-A;64N`$-A;B!N;W0@;6]V92!F:6QE*',I("T@9&5S=&EN871I;VX@:7,@
M=VET:&EN('-O=7)C92X`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T
M:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N(&YO="!W
M<FET92!T;R!F:6QE("(E<R(`0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S
M97-S:6]N(&AA;F1L97)S+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R
M.B`E<P!#86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N8V5L`$-A;F-E;"!0<F]B
M;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I
M;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H
M;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER
M96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T
M+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@
M9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N
M;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%R<FEE
M<@!#871E9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0
M:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E
M<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5N=&5R`$-E;G1R86P@
M175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R
M=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA;F=E`$-H
M86YG92!9;W5R(%!A<W-W;W)D`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S
M<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O
M('EO=7(@96UA:6QS+@!#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S
M=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@0V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-H87(`0VAE8U]K($QI;FLN+BX`
M0VAI;&4`0VAI;F$`0VAO;W-E($%P<&QI8V%T:6]N.@!#:&]O<V4@82!P87-S
M=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@
M9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI
M<W1S*0!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`
M0VQE87(@475E<GD`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE
M87(@=7-E<B!D871A`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@0V]N=&EN=64`
M0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O;&QA
M<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;W(`0V]L;W(@4&EC
M:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI
M8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`
M0V]M<&%N>0!#;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG
M=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG
M('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN`$-O;F9I9W5R
M871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A
M<W-W;W)D`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@
M`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`
M0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!2
M96%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE
M9"X`0V]N=&%C=',`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@
M=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E;G0@='EP92!O9B!C;VUP<F5S
M<V5D(&9I;&4Z(`!#;VYT96YT<R!O9B`B)7,B`$-O;G1I;G5E`$-O<'D`0V]P
M>2!F86EL960Z("5S`$-O<'D@<V5L96-T:6]N`$-O=6QD(&YO="!01U`@96YC
M<GEP="!M97-S86=E.B``0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#
M;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O
M34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`
M0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C
M:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E
M<BX`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10
M.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T
M(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O
M=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO
M="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T
M(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O
M=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO
M="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T
M(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T
M<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK
M9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H
M92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N
M`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC
M95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S
M(BX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T
M(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H
M92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@
M87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N
M;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O
M;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`
M0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L
M9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`B
M)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N
M;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E
M(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S879E('1H
M92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V
M92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U
M<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O
M;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#
M;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5P
M9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<P!#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@
M(B5S(CH@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-
M86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U
M<V5R("(E<R(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@
M(B5S(CH@)7,`0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`
M0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L
M9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#
M=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N="!4:6UE
M`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@57-E<G,`0W5R<F5N="!796%T:&5R
M`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@
M=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T
M:6]N`$-Y<')U<P!$86EL>0!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE
M8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M
M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L="!#;VQO<@!$969A=6QT($ED
M96YT:71Y`$1E9F%U;'0@4VAE;&P`1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T
M92!#96QL`$1E;&5T92!'<F]U<`!$96QE=&4@3&]G`$1E;&5T92!097)M:7-S
M:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L971E(&-E;&P`1&5L
M971E(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E
M`$1E;&5T92!M97-S86=E<P!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`
M1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B(&%N9"!A;GD@<W5B+7!E<FUI
M<W-I;VYS/P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$
M96QE=&4@<W5B(&9O;&1E<G,`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$
M96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T960@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@(B5S(BX`1&5L:79E<GD@=&EM90!$96YM87)K`$1E<V-R:6)E('1H
M92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G
M<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@
M861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN
M="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@
M=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ES<&QA>2`R-"UH
M;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A:6QE9"!F
M;W)E8V%S=`!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I
M;VX`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT
M96YA;F-E+G!H<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE
M;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;B=T(&AA=F4@
M86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W;FQO860`1&]W;FQO860@)7,`1&]W
M;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`
M1')U9W,`161I=`!%9&ET($)L;V-K`$5D:70@1W)O=7``161I="!097)M:7-S
M:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`
M161I="!O<'1I;VYS(&9O<CH`161I="!P97)M:7-S:6]N<R!F;W(@(B5S(@!%
M9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9WEP=`!%;&5M96YT+BXN`$5M86EL
M($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I
M=&@@8V]N9FER;6%T:6]N`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`
M16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S
M(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C
M;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N
M=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K
M960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G
M=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA
M9V4@55),(&AE<F4`16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z`$5R<F]R`$5R
M<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&%N
M8VAO<CH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R(&=E
M='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S
M`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`17)R;W(@=W)I=&EN9R`B)7,B
M+@!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S
M96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF
M(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X
M<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R
M92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`
M17AP;VYE;G0`1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@
M<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@
M3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N
M`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@
M(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&
M86EL960@=&\@;6]V92!T;R`B)7,B+@!&86EL960@=&\@<F5T<FEE=F4Z("5S
M`$9A:7(`1F%T86P@17)R;W(Z`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@
M;&EK93H@`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL
M97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE
M('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&
M:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1F]G
M`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`1F]R
M(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R96-A<W0@
M*%1!1BD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<G=A<F1S`$9R`$9R86YC
M90!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&
M=6QL($YA;64`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`
M1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'97)M
M86YY`$=I8G)A;'1A<@!':79E;B!.86UE`$=L;V)A;"!/<'1I;VYS`$=O`$=O
M;V=L92!-87!S`$=R87ES8V%L90!'<F5E8V4`1W)O=7`@061M:6YI<W1R871I
M;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!?;&1A<#H@
M56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@`$=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@
M)7,`1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<P!'<F]U
M<',`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$AE861E<@!(96%D97)S
M`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H
M97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(
M;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@
M061D<F5S<P!(;VUE($1I<F5C=&]R>0!(;VUE(%!H;VYE`$AO<FEZ;VYT86P@
M4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y
M;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC
M;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI
M:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5N9V%R>0!)34%0
M(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L
M971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@
M9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L
M92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`
M25]N<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N<R!F
M;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@
M:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@
M82!N97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN
M9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H
M:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S
M964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W
M86YT('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W
M<V5R+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!);6%G
M92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO
M860`26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`
M26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@
M86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@
M<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D
M<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN
M9&EV:61U86P@57-E<G,`26YF;W)M871I;VX`26YF;W)M871I;VX@;F\@;&]N
M9V5R(&%V86EL86)L92X`26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM
M86=E`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU
M;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT
M(&]N90!);G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!)
M;G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T
M(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@
M<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E
M<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI
M8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C
M96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F
M=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E
M<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN
M<V5R="!R;W<@869T97(`26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R
M97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E
M<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE
M;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!)
M;G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A
M;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!);G9A;&ED(%I)4"!D871A
M`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L
M:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S
M<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&QI8V5N<V4@:V5Y+@!)
M;G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+@!);G9A;&ED(&US9U]T>7!E+@!)
M;G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@
M<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI
M9"!P87)T;F5R(&ED+@!);G9A;&ED('!R;V1U8W0@8V]D92X`26YV86QI9"!P
M<F]T;V-O;"X`26YV86QI9"!R96-I<&EE;G0Z("(E<R(`26YV86QI9"!S:&%R
M92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D<F5S<RX`26YV96YT;W)Y`$EN
M=F5R="!S96QE8W1I;VX`27-S=65R`$ET86QY`$IA;G5A<GD`2F%P86X`2G5L
M>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU
M<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$ME97`@;W)I9VEN86P_`$ME<F)E
M<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5Y($-R96%T
M:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5
M<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V
M97(N`$MI9',`3&%?>6]U=`!,86YG=6%G90!,87-T($AA;&8`3&%S="!087-S
M=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L
M;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.
M979E<@!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(`3&5B
M86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE=F5L`$QI9VAT
M(%)A:6X`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@96UA:6P@861D
M<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9P!,:6YK
M<P!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S
M97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`
M3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5-U8G-C<FEB90!,
M:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<P!,
M:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"X`3&ET97)A='5R90!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A
M;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X`3&]G
M:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O
M<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I
M;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,
M;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`3'5X96UB
M;W5R9P!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$UA
M9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA;F%G92!T:&4@
M;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I
M=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I
M97,N`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`
M36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E
M9"D`36%T8VAI;F<@9FEE;&1S`$UA>"!A;&QO=V5D(&-R961I="X`36%X(&UE
M<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z
M(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M($YU;6)E<B!O9B!0
M;W)T86P@0FQO8VMS`$UA>&EM=6T@;&5N9W1H`$UA>0!-961I8VEN90!-96UB
M97)S`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C
M97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N
M;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E
M`$UE=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-971H;V0@;F]T
M(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S`$UE=')I8P!-97AI8V\`36ED
M9&QE`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@
M:&]U<G,Z(`!-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I
M<F5D`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E
M($A45%!?4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V
M92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@
M87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN9R!R97%U
M:7)E9"!014%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N($E$+@!-
M;P!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D=6QU<P!-
M;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;VX@4&AA<V5S`$UO<F4@9FEE;&1S
M(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N`$UO=F4@
M1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-
M;W9E('5P`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY($%C8V]U
M;G0@26YF;W)M871I;VX`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`3D\L
M($D@1&\@3D]4($%G<F5E`$YA;64`3F5T=V]R:P!.979E<@!.97<@0V%T96=O
M<GD`3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W('!A<W-W
M;W)D`$YE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"X`3F5W('!A<W-W
M;W)D<R!D;VXG="!M871C:"X`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE
M=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S`$YE>'0@;W!T:6]N<P!.97AT
M/@!.:6=H=`!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H
M;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R
M(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E
M<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O
M<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N
M(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@
M5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I
M;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@9F]U;F0N
M`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C871I;VX@<')O=FED960N`$YO
M(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB
M97(@<W!E8VEF:65D+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@
M875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B
M97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N
M4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE
M8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!Q=6]T82!S
M970N`$YO(')U;&5S`$YO('-E<&%R871O<B!S<&5C:69I960N`$YO('-I9&5S
M`$YO('-U8V@@9FEL90!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L
M92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT
M+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R
M<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`
M3F]N92`H=7-E(&EM<&QI8VET*0!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G=A
M>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T(&EM
M<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&5S`$YO=&AI
M;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W9E;6)E<@!.=6UB97(`3G5M8F5R
M(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O
M=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T
M<FEB=71I;VX@;&ES="X`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C
M=&]B97(`3V9F:6-E`$]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I
M9F9E<F5N="X`3VQD('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R
M<F5C="X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R
M<RX`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O
M=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R
M<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN
M(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C
M="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/<&5N<R!T:&ES(&QI
M;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/
M<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N
M:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO
M;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T
M:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT
M:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!01U`@16YC<GEP=&5D($1A=&$`
M4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@
M0V]D90!02%`@4VAE;&P`4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<`4&%D
M9&EN9P!087)T;'D@0VQO=61Y`%!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U
M;&QY+@!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R
M(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M
M871I;VX`4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@
M8VQI<&)O87)D`%!A=&@`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N
M86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E
M;&5T960N`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I
M;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!H;VYE
M`%!H;W1O<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O
M;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L
M96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S
M92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E
M;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED
M(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N
M`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E(&$@
M<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U
M<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E860@=&AE(&9O;&QO=VEN
M9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@
M=&AE('-Y<W1E;2X`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE
M.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S:71I;VYI;F<@
M;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@
M=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0<F5C:7!I
M=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5F<U]L9&%P.B!297%U
M:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ
M(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U
M<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W
M`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O
M<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O
M8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0=6)L:6,@2V5Y`%!U8FQI8R!+
M97D@06QG;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L:6,O4')I=F%T92!K
M97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=7)G92!M97-S
M86=E<P!1=65R>0!2861I;R!S96QE8W1I;VX`4F%I;@!2871I;P!296%D`%)E
M860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@
M8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R
M('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E
M9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@`4F5F<F5S:"!$>6YA;6EC
M($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E;&]A9`!2
M96UA<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N
M97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V
M92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E
M('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O
M<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U
M;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L
M9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S
M=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+@!297%U:7)E9"`B)7,B
M(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@
M(B5S(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U
M:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q
M=6ER960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!0
M87-S=V]R9`!297-T;W)E($QA<W0@475E<GD`4F5S=6QT<P!2971U<FX@=&\@
M3W!T:6]N<P!2971Y<&4@;F5W('!A<W-W;W)D`%)E=6YI;VX`4F5V97)T($-O
M;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`
M4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I
M97,N+BX`4F]L90!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H
M=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS
M`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U;@!3+TU)344@0W)Y
M<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E
M`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE
M<W-A9VEN9P!344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S`%-A;64@
M9G)A;64@*%]S96QF*0!3871E;&QI=&4@4')O=FED97(`4V%V90!3879E("(E
M<R(`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG
M=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP
M;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E
M9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`4V-I96YC90!396%R
M8V@`4V5A<F-H($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`
M4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE
M8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;`!3
M96QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!3
M96QE8W0@;F]N90!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O
M;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T
M92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E
M;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I
M9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D
M96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@
M;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E
M;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E
M<&]R=`!396YD(%--4P!396YS;W(Z(`!397!T96UB97(`4V5R:6%L($YU;6)E
M<@!397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397-S:6]N
M($%D;6EN`%-E<W-I;VX@240@97AP:7)E9"X`4V5S<VEO;G,`4V5T`%-E="!O
M<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF
M('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H
M870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y
M;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T
M:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H
M96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO
M;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V
M97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``
M4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F
M;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@
M8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I
M;C\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3
M:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE
M;G4@;VX@=&AE(&QE9G0_`%-H;W<@=7!L;V%D`%-I9VX@=7``4VEG;F%T=7)E
M`%-I9VYA='5R92!!;&=O<FET:&T`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-N
M;W<`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@
M069R:6-A`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA
M8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I
M;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A
M:6X`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C
M;VQU;6X`4W!L:70@<F]W`%-T87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`
M4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:7`@9&]M86EN(&9R
M;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B9&ER96-T;W)Y("(E
M<R(@;F]T(&9O=6YD+@!3=6)J96-T`%-U8FUI=`!3=6)M:71T960@<F5Q=65S
M="!T;R!A9&0@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I
M;B!U;G1I;"!Y;W5R(')E<75E<W0@:&%S(&)E96X@87!P<F]V960N`%-U8V-E
M<W-F=6QL>2!A9&1E9"`B)7,B('1O('1H92!S>7-T96TN`%-U8V-E<W-F=6QL
M>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TN
M`%-U8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL>2!R96UO
M=F5D("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@<F5V97)T
M960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C
M97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F
M=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`
M4W5C8V5S<V9U;&QY('5P9&%T960@(B5S(@!3=6-C97-S9G5L;'D@=W)O=&4@
M)7,`4W5M;6%R>0!3=7!P;W)T`%-U<FYA;64`4W=E9&5N`%-W:71Z97)L86YD
M`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`5&%B;&4@4')O<&5R=&EE
M<P!486)L92!3970`5&%B;&4@<')O<&5R=&EE<P!487)G970Z`%1A<VMS`%1E
M;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U
M<F4`5&5M<&5R871U<F4Z(`!496UP;&%T92`B)7,B(&YO="!F;W5N9"X`5&5M
M<&QA=&4@061M:6YI<W1R871I;VX`5&5X=`!497AT($]N;'D`5&5X="!A;&EG
M;@!4:`!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@
M2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L960N`%1H92!(;W)D92]+;VQA8B!I
M;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H92!)
M35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N`%1H92!-86EN=&5N
M86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P
M=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!B;W1T;VT@
M<VED92!O;FQY`%1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@
M=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!D:7-T<FEB=71I;VX@;&ES="!W
M87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q
M=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO
M=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C;VYT86EN960@
M;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H
M:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&ED96YT:71Y("(E<R(@
M:&%S(&)E96X@9&5L971E9"X`5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B
M92!N=6UE<FEC+@!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R
M('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC
M92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X
M8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M
M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U
M;F0@;VX@=&AE('-Y<W1E;2X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E
M;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I
M9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E
M8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5M<&]R87)Y
M(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('1E>'0@>6]U(&5N=&5R
M960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+@!4:&4@
M=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E
M<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&5M
M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@;F\@;W!T
M:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B
M92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C
M=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A
M8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S
M(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M.B`E<P!4:&5R
M92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@(B5S(B!F
M<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG
M("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U
M<&1A=&EN9R`B)7,B.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE
M(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R
M9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN
M`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H
M92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A
M;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H
M97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!0
M97)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W
M87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@
M8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@
M=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R
M:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A
M;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S
M(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R
M('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@
M;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A
M:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X
M86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P
M<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@;65S<V%G92!W87,@=W)I='1E
M;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N
M+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V
M97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@
M<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M
M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F
M<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I
M;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I=&QE`%1O`%1O('-E;&5C="!M
M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@
M0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O;6]R
M<F]W`%1O;R!M86YY(&EN=F%L:60@;&]G:6YS(&1U<FEN9R!T:&4@;&%S="!M
M:6YU=&5S+@!4;W``5')A;G-L871I;VYS`%1R=64@;W(@9F%L<V4`5'4`5'5R
M:V5Y`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5;F%B;&4@=&\@86-C97-S(%9&4R!D
M:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO
M;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO
M;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S
M:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E
M<RX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B;&4@
M=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R\E<R(N`%5N86)L92!T;R!C;VYN
M96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,
M+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!6
M1E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R
M96%T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!C<F5A=&4@96UP='D@
M5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T
M;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N
M86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D96QE=&4@)7,L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!6
M1E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ
M("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T
M;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E
M<B`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N
M`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L
M92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO
M860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93
M(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA
M8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2X`56YA
M8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2X`
M56YA8FQE('1O(')E860@9FEL93H@`%5N86)L92!T;R!R96%D('1H92!V9G-R
M;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S
M=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T
M;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O
M('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('1R:6=G
M97(@9G)E92]B=7-Y('5P9&%T92!F;W(@)7,`56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I
M(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F%B
M;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N
M`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I
M;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T
M:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N
M:VYO=VX`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H
M92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G-U<'!O<G1E9"!%>'1E;G-I
M;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N
M`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@
M87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@
M;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5S92!#=7)R96YT
M.B`E<P!5<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N
M="!F;W(@24U34"!S97)V97(N`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R
M:7-E9"!F;W(@)7,N`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS
M`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N
M(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U
M;F0`57-E<FYA;64`57-E<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E
M<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`5D93(&1I
M<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I
M;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S
M(&9R;VT@;F]W+@!686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O
M9B`E<RX`5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!687)I86)L90!6
M97)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E
M96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R
M=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(
M:6=H`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S
M("5S`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%=!4DX`5T%23DE.1R$A(2!2
M14U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=A<FYI;F<`5V4`5V5A
M=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5E:VQY
M`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!7:&%T(&%P<&QI
M8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES
M('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&EC:"!P;'5G:6YS('1O(&5N
M86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN
M($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H
M=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A
M8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I;F0`5VEN9"!S<&5E9"!I;B!K;F]T
M<P!7:6YD.@!7:6YD.B``5VES9&]M`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@
M4&AO;F4`5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E
M8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X
M<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;V9F<V5T("5D('=H:6QE(')E
M861I;F<@82!61E,@9FEL92X`665A<FQY`%EE<P!997,L($D@06=R964`66]U
M(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W
M:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@
M8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%U=&AE
M;G1I8V%T960N`%EO=2!C86YN;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I
M;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E
M;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@
M=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S
M(&EN("5S+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O
M(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@
M=VET:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I
M86QI;F<@<')E9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E
M+@!9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S
M92!3:6=N=7!S+@!9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`
M66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@
M<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!5
M4DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@
M86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U
M<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R
M;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE
M('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D
M871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN
M`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE960@
M=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W5R("5S('-E
M<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%
M;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA
M=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@
M=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@
M>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M
M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R
M="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T;R!A
M9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E
M<F5N="!A=71H96YT:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O
M<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE
M<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E
M9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@
M<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`
M66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9
M;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO
M;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN="X`66]U<B!C
M=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B
M965N(&-H86YG960N`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL
M(&YA;64Z`%EO=7(@;&]G:6X@:&%S(&5X<&ER960N`%EO=7(@;F5W('!A<W-W
M;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A
M=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P
M=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E
M96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@
M>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N
M`%EO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N`%EO=7(@<F5M;W1E('-E<G9E
M<G,Z`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W
M(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`
M6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?1&5L971E(%)O=P!?
M1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN`%],;V<@:6X`7TQO
M9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?
M4F5M;W9E($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5
M<V5R<P!A9&1R97-S(&)O;VL`861D<F5S<V5E('5N:VYO=VX`8V%L96YD87(`
M8V%L;0!C86YN;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N(&EN
M<'5T`&-L:6-K(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I
M9W5R871I;VX@97)R;W(`9&%T82!F;W)M870@97)R;W(`9&ES<&QA>2!F;W)E
M8V%S="`H=&%F*0!E9&ET`&5N=')Y(&YO="!F;W5N9`!F<F]M('1H92`E<R`H
M)7,I(&%T("5S("5S`&AO<W0@;F%M92!U;FMN;W=N`&EM;65D:6%T90!I;G!U
M="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A<F4@97)R;W(`;&EN97-=
M`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+@!N86UE
M`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`
M<&5R8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!R96UO=&4@97)R;W(@:6X@<')O
M=&]C;VP`<V5R=FEC92!U;F%V86EL86)L90!S:&]W(&1I9F9E<F5N8V5S`'-T
M96%D>0!S>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E
M`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U
M;FYA;65D`'5S97(@<V5L96-T`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M
M5F5R<VEO;CH@:&]R9&4@,RXQ+C$*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E
M=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#0M
M,3,@,30Z,38K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`V+3`T+3$S(#$T
M.C$V*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!-87)C;R!0:7)O=F%N;R`\;6%R
M8V\N<&ER;W9A;F]`=6YI8F]C8V]N:2YI=#X*3&%N9W5A9V4M5&5A;3H@:3$X
M;D!L:7-T<RYH;W)D92YO<F<*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4
M>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3$*0V]N=&5N="U4
M<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`I0;'5R86PM1F]R;7,Z(&YP;'5R86QS
M/3([('!L=7)A;#TH;B`A/2`Q*3L*`"`H)7,@9VEO<FYI('-C;W)S:2D`("A#
M:&EA=F4@9&D@86-C97-S;R`E<RD`("AI;B`E<R!G:6]R;FDI`"`H;V=G:2D`
M("AD;VUA;FDI`"`H:65R:2D`(&$@80`B)7,B(&YO;B#H('5N82!D:7)E8W1O
M<GDN`"(E<R(@;F]N(.@@=6YA('-C96QT82!V86QI9&$N`"(E<R(@;F]N(.@@
M8V]N9FEG=7)A=&\@;F5I(%)E9VES=')I(&1I($AO<F1E+@`B)7,B(&%L8F5R
M;R!R96YD97)E<B!N;VX@=')O=F%T;RX`(B5S(B#H('-T871O(&%G9VEU;G1O
M(&%I(&=R=7!P:2!D:2!S:7-T96UA+@`B)7,B(.@@<W1A=&\@86=G:75N=&\@
M86D@<&5R;65S<VD@9&D@<VES=&5M82X`(B5S(B!N;VX@Z"!S=&%T;R!C<F5A
M=&\Z("5S+@`E+C)F34(@=7-A=&D@9&D@)2XR9DU"(&1I<W!O;FEB:6QI("@E
M+C)F)24I`"5D("5S(&4@)7,`)60@9VEO<FYI(&%L;&\@<V-A9&5R92!D96QL
M82!T=6$@<&%S<W=O<F0N`"5D+6=I;VYO('!R979I<VEO;F4`)7,@+2!.;W1I
M>FEA`"5S($9I<FUA($1I9VET86QE`"5S($M"`"5S($]P97)A>FEO;FD@9&D@
M36%N=71E;GII;VYE("T@0V]N9F5R;6$`)7,@26UP;W-T87II;VYE`"5S($9I
M<FUA`"5S(%1E<FUI;FD@9&D@06-C;W)D;P`E<R!G:>`@97-I<W1E;G1E+@`E
M<R!A("5S("5S`"5S(.@@<')O;G1O('!E<B!E<V5G=6ER92!L92!O<&5R87II
M;VYI(&1I(&UA;G5T96YZ:6]N92!S;W1T;R!S96QE>FEO;F%T92X@4V5L97II
M;VYA(&QA(&-A<V5L;&$@<&5R(&]G;FD@;W!E<F%Z:6]N92AI*2!C:&4@=G5O
M:2!E<V5G=6ER92!O<F$N`"5S(.@@<FEC:&EE<W1O`"5S(&UI;G5T:0`E<R!N
M;VX@=')O=F%T;RX`)7,@82`E<R!D:2`E<P!2=6)R:6-A(&1I("5S`$-A;&5N
M9&%R:6\@9&D@)7,`3F]T92!D:2`E<P!,:7-T82!!='1I=FETX"!D:2`E<P`E
M<SH@)7,`)7,Z(%%U97-T;R!M97-S86=G:6\@<&]T<F5B8F4@;F]N(&%R<FEV
M92!D82!C:&D@9&EC:&EA<F$@9&D@97-S97)E+B!!='1E;GII;VYE(&%I(&QI
M;FL@<')E<V5N=&D@:6X@97-S;R!O(&9O<FYI<V-I(&]G;FD@:6YF;W)M87II
M;VYE(&%L(&UI='1E;G1E+@`L('-O9F9I86YD;R``+"!S;V9F:6%N9&\@)7,@
M)7,`+"!V87)I86)I;&4@9&$@)7,@82`E<P`M+2!S96QE>FEO;F$@+2T`1F]R
M;6%T;R`Q,B!O<F4`1F]R;6%T;R`R-"!O<F4`,C0@;W)E`#Q0<F5C961E;G1E
M`%5N(&1A=&%B87-E(&1I(&)A8VME;F0@Z"!R:6-H:65S=&\@<&5R('%U97-T
M;R!B;&]C8V\N`$4G(&%C8V%D=71O('5N(&5R<F]R92!F871A;&4`56YA(&-H
M:6%V92!P=6)B;&EC82!01U`@Z"!R:6-H:65S=&$@<&5R(&-I9G)A<F4@:6P@
M;65S<V%G9VEO+@!5;F$@8VAI879A('!U8F)L:6-A(%!'4"#H(')I8VAI97-T
M82!P97(@=F5R:69I8V%R92!I;"!M97-S86=G:6\@9FER;6%T;RX`56YA(&-H
M:6%V92!P=6)B;&EC82!01U`L('5N82!C:&EA=F4@<')I=F%T82!01U`L(&4@
M=6YA('!A<W-W;W)D('-O;F\@<FEC:&EE<W1E('!E<B!D96-I9G)A<F4@=6X@
M;65S<V%G9VEO`%5N82!C:&EA=F4@<'5B8FQI8V$@4$=0+"!U;F$@8VAI879E
M('!R:79A=&$@4$=0+"!E('5N82!P87-S=V]R9"!S;VYO(')I8VAI97-T92!P
M97(@9FER;6%R92!U;B!M97-S86=G:6\`56YA(&-H:6%V92!P=6)B;&EC82!3
M+TU)344L('5N82!C:&EA=F4@<')I=F%T82!3+TU)344@92!U;F$@<&%S<W=O
M<F0@<V]N;R!R:6-H:65S=&4@<&5R(&1E8VEF<F%R92!U;F$@;65S<V%G9VEO
M+@!5;F$@8VAI879E('!U8F)L:6-A(%,O34E-12P@=6YA(&-H:6%V92!P<FEV
M871A(%,O34E-12!E('5N82!P87-S=V]R9"!S;VYO(')I8VAI97-T92!P97(@
M9FER;6%R92!U;B!M97-S86=G:6\N`%5N82!C:&EA=F4@<'5B8FQI8V$@4R]-
M24U%(.@@<FEC:&EE<W1A('!E<B!C:69R87)E('5N(&UE<W-A9V=I;RX`04T@
M3G5B:0!!32!0:6]G9VEA($QE9V=E<F$`04T@4&EO9V=I80!!32!!8W%U87IZ
M;VYI`$%-($YE=FEC871E`$%-+U!-`$%022!)1`!2:6=U87)D;R!Q=65S=&\@
M961I=&]R`%)I9W5A<F1O+BXN`$%C8V5S<V\@;F5G871O(&-R96%N9&\@;&$@
M9&ER96-T;W)Y(%9&4RX`06-C97-S;R!N96=A=&\@8W)E86YD;R!61E,@9FEL
M92X`26YF;W)M87II;VYI($%C8V]U;G0`4&%S<V]W<F0@06-C;W5N=`!!8V-O
M=6YT(&-O;F=E;&%T;RX`06-C;W5N=&EN9P!!9V=I=6YG:0!!9V=I=6YG:2!'
M<G5P<&\@1FEG;&EO`$%G9VEU;F=I(%!E<FUE<W-I($9I9VQI;P!!9V=I=6YG
M:2!Q=6DZ`$%G9VEU;F=I($YU;W9O($=R=7!P;P!!9V=I=6YG:2!.=6]V;R!0
M97)M97-S;P!!9V=I=6YG:2!U;B!G<G5P<&\@9FEG;&EO(&$@(B5S(@!!9V=I
M=6YG:2!U;B!P97)M97-S;R!F:6=L:6\@82`B)7,B`$%G9VEU;F=I('5N(&YU
M;W9O('5T96YT93H`06=G:75N9VD@8V]L;VYN80!!9V=I=6YG:2!N=6]V:2!M
M96UB<FD`06=G:75N9VD@;&$@8V]P<&EA`$%G9VEU;F=I(&EL("5S($UE;G4@
M8V]M92!U;F$@36]Z:6QL82!3:61E8F%R`$%G9VEU;F=I(&%L;&$@<G5B<FEC
M83H`06=I=6YG:2!A;&QA(')U8G)I8V$@<&5R<V]N86QE`$%G9VEU;F=I('5T
M96YT90!!9V=I=6YT:2`B)7,B(&%L('-I<W1E;6$L(&UA(&YO;B!S:2!P;W-S
M;VYO(&%G9VEU;F=E<F4@=6QT97)I;W)I(&EN9F]R;6%Z:6]N:3H@)7,N`$%G
M9VEU;G1O("(E<R(@86P@<VES=&5M82X@3W)A('!U;VD@86-C961E<F4N`$PG
M86=G:75N=&$@9&D@=71E;G1I(.@@9&ES86)I;&ET871A+@!);F1I<FEZ>F\`
M4G5B<FEC80!!;6UI;FES=')A=&]R92`M(&EM<&]S=&$@:2!P97)M97-S:2!P
M97(@86QT<FD@=71E;G1I`$%M;6EN:7-T<F%Z:6]N90!!;&QI;F5A`$%L;&EN
M96%M96YT;SH`5'5T=&D`5'5T=&D@9VQI('5T96YT:2!A=71E;G1I8V%T:0!4
M=71T:2!I(&=R=7!P:0!4=71T:2!I('!E<FUE<W-I`%1U='1I(&4@<75A='1R
M;R!I(&QA=&D`5'5T=&D@9VQI(&EN9&ER:7IZ:2!M=6QT:7!L:0!097)M971T
M97)E(&QE(&EM<&]S=&%Z:6]N:2!D:2!L:7-T92!O<F1I;F%T92!P97(@=&EP
M;S\`17-I<W1E(&=IX`!,;V=I;B!)35-0(&%L=&5R;F%T:79A`%!A<W-W;W)D
M($E-4U`@86QT97)N871I=F$`571E;G1E($E-4%,@86QT97)N871I=F\`26YD
M:7)I>GIO(&5M86EL(&%L=&5R;F%T:79O`$UA<V-H97)E(&%L=&5R;F%T:79E
M`%1E<W1O(&%L=&5R;F%T:79O.@!%)R!S=&%T;R!S<&5C:69I8V%T;R!U;B!V
M86QO<F4@;F]N('9A;&ED;RX`17)R;W)E('-C;VYO<V-I=71O+@!2:7-P;W-T
M80!!<'!L:6-A>FEO;F4`3&ES=&$@07!P;&EC87II;VYI`$PG87!P;&EC87II
M;VYE(.@@<')O;G1A+@!!<'!L:6-A(&%I(&9I9VQI(&-O;F1I=FES:0!!<'!R
M;W9A`$1I;65N<VEO;F4@07!P<F]S<VEM871I=F$`07!R:6QE`$1I;65N<VEO
M;F4@9FEL92!I;B!A<F-H:79I;P!.;VUE($%R8VAI=FEO`%-E:2!S:6-U<F\@
M9&D@=F]L97(@<FEM=6]V97)E(&QE(')I8VAI97-T92!F:7)M871E('!E<B`E
M<R`_`$%S96D@<VEC=7)O(&1I('9O;&5R(&5L:6UI;F%R92`B)7,B(&4@;V=N
M:2!S;W1T;RUG<G5P<&\_`%)I8VAI961E<F4@;&$@8V]N9F5R;6$@<')I;6$@
M9&D@97-E9W5I<F4@;&4@;W!E<F%Z:6]N:2!D:2!M86YU=&5N>FEO;F4_`$%S
M<V5G;F%M96YT;R!C;VQO;FYE`%-I(.@@8V5R8V%T;R!D:2!E;&EM:6YA<F4@
M=6X@9W)U<'!O(&YO;B!E<VES=&5N=&4N`%-I(.@@8V5R8V%T;R!D:2!E;&EM
M:6YA<F4@=6X@<&5R;65S<V\@;F]N(&5S:7-T96YT92X`4VD@Z"!C97)C871O
M(&1I('!U8F)L:6-A<F4@=6X@<&5R;65S<V\@;F]N(&5S:7-T96YT92X`4VD@
MZ"!C97)C871O(&1I('!U8F)L:6-A<F4@=6YA(&-O;F1I=FES:6]N92!N;VX@
M97-I<W1E;G1E+@!!='1R:6)U=&D`06=O<W1O`$%U=&A?8WER<W%L.B!E<W1E
M;G-I;VYE(&EM87`@<FEC:&EE<W1A(&YO;B!T<F]V871A+@!!=71H7V-Y<G5S
M.B!I;"!B86-K96YD(&YO;B!H82!L92!C87!A8VETX"!R:6-H:65S=&4N`$%U
M=&A?8WER=7,Z(&5S=&5N<VEO;F4@:6UA<"!R:6-H:65S=&$@;F]N('1R;W9A
M=&$N`$%U=&A?9G1P.B!%<W1E;G-I;VYE($944"!R:6-H:65S=&$@;F]N('1R
M;W9A=&$N($-O;7!I;&$@4$A0(&-O;B!L)V]P>FEO;F4@+2UE;F%B;&4M9G1P
M+@!!=71H7VEM87`Z("!%<W1E;G-I;VYE($E-05`@<FEC:&EE<W1A(&YO;B!T
M<F]V871A+@!!=71H7VMR8C4Z($5S=&5N<VEO;F4@:W)B-2!R:6-H:65S=&$@
M;F]N('1R;W9A=&$N`$%U=&A?;&1A<#H@;"=A9V=I=6YT82!D:2!U=&5N=&D@
M;F]N(.@@<W5P<&]R=&%T82!P97(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD
M87`Z(&QA(&-A;F-E;&QA>FEO;F4@9&D@=71E;G1I(&YO;B#H('-U<'!O<G1A
M=&$@<&5R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!%<W1E;G-I;VYE
M($Q$05`@<FEC:&EE<W1A(&YO;B!T<F]V871A+@!!=71H7VQD87`Z($EM<&]S
M<VEB:6QE(&%G9VEU;F=E<F4@;"=U=&5N=&4@)7,N(%%U97-T82#H(&QA(')I
M<W!O<W1A(&1E;"!S97)V97(Z`$%U=&A?;&1A<#H@26UP;W-S:6)I;&4@8V%N
M8V5L;&%R92!L)W5T96YT92`E<P!!=71H7VQD87`Z($EM<&]S<VEB:6QE(&%G
M9VEO<FYA<F4@;"=U=&5N=&4@)7,`075T:%]L9&%P.B!L)V%G9VEO<FYA;65N
M=&\@9&5G;&D@=71E;G1I(&YO;B#H('-U<'!O<G1A=&\@<&5R($%C=&EV92!$
M:7)E8W1O<GDN`$%U=&A?;6-A;#H@97-T96YS:6]N92!-0T%,(')I8VAI97-T
M82!N;VX@=')O=F%T82X`075T:%]S;6)A=71H.B!E<W1E;G-I;VYE('-M8F%U
M=&@@<FEC:&EE<W1A(&YO;B!T<F]V871A+@!,)V%U=&5N=&EC87II;VYE(&%L
M('-E<G9E<B!)34%0(.@@9F%L;&ET82X`075T96YT:6-A>FEO;F4@9F%L;&ET
M80!!=71E;G1I8V%Z:6]N92!F86QL:71A+B`E<P!!=71E;G1I8V%Z:6]N92!R
M:69I=71A=&$@9&%L('-E<G9E<B!2041)55,N`$%U=&5N=&EC87II;VYE(&%L
M('-E<G9E<B!&5%`@9F%L;&ET82X`075T96YT:6-A>FEO;F4@86P@<V5R=F5R
M(%--0B!F86QL:71A+@!#86UP:2!D:7-P;VYI8FEL:3H`4V9O;F1O`$-O;&]R
M92!S9F]N9&\`4&%S<W=O<F0@:V5R8F5R;W,@;F]N('9A;&ED82X`571E;G1E
M(&ME<F)E<F]S(&YO;B!V86QI9&\N`$1I<F5C=&]R>2!G<F%F:6-A(&1I(&)A
M<V4@(B5S(B!N;VX@=')O=F%T82X`0V]M<&QE86YN;P!";&]C8V\@(B5S(B!D
M96QL)V%P<&QI8V%Z:6]N92`B)7,B(&YO;B!T<F]V871O+@!);7!O<W1A>FEO
M;FD@0FQO8V-O`%1I<&\@0FQO8V-O`$=R87-S971T;P!396=N86QI8G)I`$)O
M<F1O`%-P97-S;W)E(&1E;"!B;W)D;SH`0F]R9&D`0F]S;FEA(&4@2&5R>F5G
M;W9I;F$`16YT<F%M8F4`0F%S<V\`0G)A<VEL90!%;&5N8V\@<'5N=&%T;P!#
M35,`0U)#`%!U;G1I($1I<W1R:6)U>FEO;F4@0U),`%!R;W!R:65TX"!#7V5L
M;&4N+BX`3&$@8V%C:&4@:6YI>FEA;&4@;F]N(.@@<W1A=&$@8V]M<&QE=&%T
M82X`0V%L96YD87)I;P!#86QM;P!#86UB;V=I80!);7!O<W-I8FEL92!C;W!I
M87)E(&9I;&4H<RD@+2!L82!S;W)G96YT92!E(&QA(&1E<W1I;F%Z:6]N92!S
M;VYO('5G=6%L:2X`26UP;W-S:6)I;&4@<W!O<W1A<F4@:6P@9FEL92AS*2`M
M(&QA(&1E<W1I;F%Z:6]N92#H(&%L;"=I;G1E<FYO(&1E;&QA('-O<F=E;G1E
M+@!);7!O<W-I8FEL92!R96EM<&]S=&%R92!L82!P87-S=V]R9"!A=71O;6%T
M:6-A;65N=&4L(&-O;G1A='1A(&PG86UM:6YI<W1R871O<F4N`$EM<&]S<VEB
M:6QE('-C:79E<F4@;F5L(&9I;&4@(B5S(@!);7!O<W-I8FEL92!G97-T:7)E
M('-E<W-I;VYI(&5S=&5R;F4N`$EM<&]S<VEB:6QE(&-O;&QE9V%R<VD@86P@
M<V5R=F5R($E-05`Z("5S`$EM<&]S<VEB:6QE(&%P<FER92!I;"!F:6QE("(E
M<R(N`$-A;F-E;&QA`$-A;F-E;&QA(&EL(%)E<&]R="!P<F]B;&5M80!);7!O
M<W-I8FEL92!E;&EM:6YA<F4@:6P@9FEL92`B)7,B+@!);7!O<W-I8FEL92!T
M<F]V87)E('5N82!D:7)E8W1O<GD@=&5M<&]R86YE82X`26UP;W-S:6)I;&4@
M<')O8V5D97)E('-E;GIA(&EL('!A<F%M971R;R`G=&%R9V5T1FEL92<N`$EM
M<&]S<VEB:6QE(')I;75O=F5R92!L82!D:7)E8W1O<GD@("(E<R(N`$EM<&]S
M<VEB:6QE(')I;75O=F5R92P@97-I<W1O;F\@)60@9FEG;&DN`$EM<&]S<VEB
M:6QE(')I;W)D:6YA<F4L(&PG96QE;F-O(&9O<FYI=&\@;F]N(&-O<G)I<W!O
M;F1E(&-O;B!L)V5L96YC;R!M96UO<FEZ>F%T;RX`26UP;W-S:6)I;&4@:6YS
M=')A9&%R92!I;"!M97-S86=G:6\@86P@;G5M97)O('-P96-I9FEC871O+@!#
M87)R:65R80!#871E9V]R:64@92!%=&EC:&5T=&4`27-O;&4@0V%Y;6%N`$-E
M;&QU;&%R90!0<F]P<FEE=.`@0V5L;&4`4FEE;7!I;65N=&\@8V5L;&4Z`%!R
M;W!R:65TX"!C96QL90!3<&%Z:6\@8V5L;&4Z`$-E;&QU;&%R90!#96YT<F\`
M175R;W!A($-E=')A;&4@*$E33RTX.#4Y+3(I`$1E='1A9VQI(&1E;"!#97)T
M:69I8V%T;P!0<F]P<FEE=&%R:6\@9&5L($-E<G1I9FEC871O`%!O;&ET:6-H
M92!D96P@0V5R=&EF:6-A=&\`0V%M8FEA`$-A;6)I82!L82!T=6$@4&%S<W=O
M<F0`0V%M8FEA(&EL(&YO;64@92!L)VEN9&ER:7IZ;R!C:&4@;&4@<&5R<V]N
M92!V961O;F\@<75A;F1O(&QE9V=O;F\@92!R:7-P;VYD;VYO(&%L;&4@='5E
M(&5M86EL+@!);"!C86UB:6\@9&5L;&$@='5A('!A<W-W;W)D(&YO;B#H('-U
M<'!O<G1A=&\@8V]N(&QA(&-O;F9I9W5R87II;VYE(&-O<G)E;G1E+B`@0V]N
M=&%T=&$@;"=A;6UI;FES=')A=&]R92X`0V%R8F]N90!#:&5C7VL@3&EN:RXN
M+@!#:6QE`$-I;F$`4V-E9VQI(&PG87!P;&EC87II;VYE.@!38V5G;&D@=6YA
M('!A<W-W;W)D`%-C96=L:2!U;B!N;VUE('5T96YT90!38V5G;&D@8V]M92!V
M:7-U86QI>GIA<F4@;&$@9&%T83H`4V-E9VQI(&EL('1I<&\@9&D@<W1I;&4@
M9&5L;&$@;&ES=&$@*'!E<B!L:7-T92!O<F1I;F%T92D`3&$@9&5F:6YI>FEO
M;F4@9&D@8VQA<W-E(&1I("5S(&YO;B#H('-T871A('1R;W9A=&$N`$-H:6%R
M;P!!;FYU;&QA($1O;6%N9&$`16QI;6EN82!L)W5T96YT93H@)7,`16QI;6EN
M82!U=&5N=&4`16QI;6EN82!I;F9O<FUA>FEO;FD@=71E;G1E`$5L:6UI;F%R
M92!$;W!O(`!#;&EC:R!P97(@0V]N=&EN=6%R90!#:&EU9&D@1FEN97-T<F$`
M3G5B:0!.=6)I('!R97-T;P!.=79O;&]S;P!#:&EU9&D@4VED96)A<@!#:&EU
M9&D@:2!B;W)D:0!#;VQO<F4`36%P<&$@0V]L;W)I`%-E;&5Z:6]N92!C;VQO
M<FD`0V]L;VYN93H`5&ET;VQO(&-O;&]N;F4`0V]M:6-H90!#;VUA;F1O`$QI
M;F5A(&1I(&-O;6%N9&\`0V]M;65N=&\`3F]M92!#;VUU;F4`07II96YD80!#
M;VUP=71E<G,`0V]N9&EZ:6]N90!#;VYD:7II;VYI`$1I9F9E<F5N>F4@;F5L
M;&$@8V]N9FEG=7)A>FEO;F4`0V]N9FEG=7)A>FEO;F4@<&5R(&QA('-I;F-R
M;VYI>GIA>FEO;F4@8V]N(%!$07,L(%-M87)T<&AO;F5S(&4@3W5T;&]O:RX`
M3&$@8V]N9FEG=7)A>FEO;F4@Z"!V96-C:&EA+@!#;VYF:6=U<F$@)7,`0V]N
M9F5R;6$@;&$@4&%S<W=O<F0`0V]L;&5G86UE;G1O(&9A;&QI=&\N`$-O;&QE
M9V%M96YT;R!F86QL:71O.B``0V]N;F5S<VEO;F4@86P@:V5Y<V5R=F5R(&]U
M8F)L:6-O(')I9FEU=&%T82X`0V]N;F5S<VEO;F4@86P@:V5Y<V5R=F5R('!U
M8F)L:6-O(')I9FEU=&%T82X@36]T:79O.B`E<R`H)7,I`$-O;FYE<W-I;VYE
M(&%L('-E<G9E<B!&5%`@9F%L;&ET82X`0V]N=&%T=&D`22!C;VYT871T:2!S
M;VYO('-T871I(&%G9VEU;G1I(&-O;B!S=6-C97-S;R!A;&QA('1U82!R=6)R
M:6-A+@!4:7!O(&1I(&-O;G1E;G5T;R!D96P@9FEL92!C;VUP<F5S<V\Z(`!#
M;VYT96YU=&D@9&D@(B5S(@!#;VYT:6YU80!#;W!I80!#;W!I82!F86QL:71A
M.B`E<P!#;W!I82!S96QE>FEO;F4`3F]N('-I('!U\B!C:69R87)E(&EN(%!'
M4"!I;"!M97-S86=G:6\`3F]N('-I('!U\B!F:7)M87)E(&EN(%!'4"!I;"!M
M97-S86=G:6\`3F]N('-I('!U\B!C<FEF<F%R92!I;B!3+TU)344@:6P@;65S
M<V%G9VEO`$YO;B!S:2!P=?(@9FER;6%R92!I;B!3+TU)344@:6P@;65S<V%G
M9VEO`$YO;B!S:2!P=?(@86=G:75N9V5R92!I;"!C;VYT871T;RX@)7,`3F]N
M('-I('!U\B!I;G1E<G)O9V%R92!I;"!S97)V97(@3$1!4"X`3F]N('-I('!U
M\B!V97)I9FEC87)E(&PG97%U:6QI8G)I;RX@)7,`26UP;W-S:6)I;&4@8V]L
M;&5G87)S:2!A;"!S97)V97(@3$1!4"X`26UP;W-S:6)I;&4@8V]L;&5G87)S
M:2!A;"!S97)V97(@(B5S(B!U<V%N9&\@1E10.B`E<P!);7!O<W-I8FEL92!C
M<F5A<F4@=6YA(&QI<W1A(&1I(&1I<W1R:6)U>FEO;F4N("5S`$EM<&]S<VEB
M:6QE(&1E8VEF<F%R92!I;"!D871O(&EN(&9O<FUA=&\@4$=0.B``26UP;W-S
M:6)I;&4@9&5C:69R87)E(&EL(&1A=&\@:6X@9F]R;6%T;R!3+TU)344N`$EM
M<&]S<VEB:6QE(&5L:6UI;F%R92!I;"!C;VYT871T;RX@)7,`26UP;W-S:6)I
M;&4@96QI;6EN87)E(&QE(&QI<W1A(&1I(&1I<W1R:6)U>FEO;F4N("5S`$EM
M<&]S:6)I;&4@96QI;6EN87)E(&QO('-C<FEP="!D:2!A9V=I;W)N86UE;G1O
M(&1E;&PG:6UP;W-T87II;VYE("(E<R(N`$EM<&]S<VEB:6QE(&1E=&5R;6EN
M87)E(&=L:2!I;F1I<FEZ>FD@96UA:6P@9&5I(&1E<W1I;F%T87)I+@!I26UP
M;W-S:6)I;&4@<V-A<FEC87)E(&EN(&UO9&\@8V]M<&QE=&\@;&$@<G5B<FEC
M82X`26UP;W-S:6)I;&4@<V-A<FEC87)E(&EN(&UO9&\@8V]M<&QE=&\@;&$@
M;&ES=&$@9&D@9&ES=')I8G5Z:6]N92X`26UP;W-S:6)I;&4@<V-A<FEC87)E
M(&EN(&UO9&\@8V]M<&QE=&\@;&$@;&ES=&$@9&5L;&4@;&ES=&4@9&D@9&ES
M=')I8G5Z:6]N92X`26UP;W-S:6)I;&4@8V%R:6-A<F4@;&$@<W1R871E9VEA
M("(E<R(N`$EM<&]S<VEB:6QE(&-R96%R92!L82!D:7)E8W1O<GD@(B5S(BX`
M26UP;W-S:6)I;&4@;W1T96YE<F4@;&$@8VAI879E('!U8F)L:6-A(&1A;"!S
M97)V97(N`$EM<&]S<VEB:6QE(&%P<FER92`B)7,B('!E<B!L82!R:7-C<FET
M='5R82X`26UP;W-S:6)I;&4@87!R:7)E("5S+@!);7!O<W-I8FEL92!A<')I
M<F4@:6P@;6]D=6QO($UA:6YT96YA;F-E7U1A<VL@)7,`26UP;W-S:6)I;&4@
M87!R:7)E(&QA(&1I<F5C=&]R>2`B)7,B+@!);7!O<W-I8FEL92!C;VYT871T
M87)E(&EL('-E<G9E<B!,1$%0+@!);7!O<W-I8FEL92!L96=G97)E("5S+@!)
M;7!O<W-I8FEL92!A>GIE<F%R92!L82!P87-S=V]R9"!P97(@;"=U=&5N=&4@
M<FEC:&EE<W1O+B!!;&-U;FD@;R!T=71T:2!I(&1E='1A9VQI(&YO;B!S;VYO
M(&-O<G)E='1I+B!2:7!R;W9A(&%N8V]R82!O(&-O;G1A='1A(&PG86UM:6YI
M<W1R871O<F4@<V4@;F5C97-S:71I(&1I('5L=&5R:6]R92!A:75T;RX`26UP
M;W-S:6)I;&4@<F5C=7!E<F%R92!!0TP`26UP;W-S:6)I;&4@<F5C=7!E<F%R
M92!L82!R=6)R:6-A+B`E<P!);7!O<W-I8FEL92!R96-U<&5R87)E(&QA(&QI
M<W1A(&1I(&1I<W1R:6)U>FEO;F4N("5S`$EM<&]S<VEB:6QE(')E8W5P97)A
M<F4@;&4@;&ES=&4@9&D@9&ES=')I8G5Z:6]N92X@)7,`26UP;W-S:6)I;&4@
M<F5C=7!E<F%R92!L92!P;W-S:6)I;&ETX"!D96P@<V5R=F5R`$EM<&]S<VEB
M:6QE(&EN=F5R=&ER92!L82!C;VYF:6=U<F%Z:6]N92X`26UP;W-S:6)I;&4@
M8V%N8V5L;&%R92!L82!D:7)E8W1O<GD@(B5S(BX`26UP;W-S:6)I;&4@<V%L
M=F%R92!L82!C;VYF:6=U<F%Z:6]N92!D:2`E<RX`26UP;W-S:6)I;&4@<V%L
M=F%R92!U;F$@8V]P:6$@9&5L;&$@8V]N9FEG=7)A>FEO;F4N`$EM<&]S<VEB
M:6QE('-A;'9A<F4@=6YA(&-O<&EA(&1E;&QA(&-O;F9I9W5R87II;VYE.B`E
M<P!);7!O<W-I8FEL92!S86QV87)E(&QO('-C<FEP="!D:2!A9V=I;W)N86UE
M;G1O(&1E;&QE(&EM<&]S=&%Z:6]N:2!S=3H@(B5S(BX`26UP;W-S:6)I;&4@
M<V%L=F%R92!I;"!F:6QE(&1I('-A;'9A=&%G9VEO(&1E;&QA(&-O;F9I9W5R
M87II;VYE(&1I("5S+@!);7!O<W-I8FEL92!S86QV87)E(&EL(&9I;&4@9&D@
M8V]N9FEG=7)A>FEO;F4@9&D@)7,N(%!U;VD@=7-A<F4@;F$@9&5L;&4@;W!Z
M:6]N:2!P97(@<V%L=F%R92!I;"!C;V1I8V4@<W4@)7,@;R!C;W!I87)E(&UA
M;G5A;&UE;G1E(&EL(&-O9&EC92!S;W1T;R!S=2`E<RX`26UP;W-S:6)I;&4@
M9F%R92!U;F$@<G5C97)C82!N96P@<V5R=F5R($Q$05`N`$EM<&]S<VEB:6QE
M(&%G9VEO<FYA<F4@:6P@8V]N=&%T=&\N("5S`$EM<&]S<VEB:6QE(&%G9VEO
M<FYA<F4@;&$@;&ES=&$@9&D@9&ES=')I8G5Z:6]N92X@)7,`26UP;W-S:6)I
M;&4@<V-R:79E<F4@;&$@8V]N9FEG=7)A>FEO;F4@<&5R("(E<R(Z("5S`$EM
M<&]S<VEB:6QE('1R;W9A<F4@;&$@4VED96)A<B!D:2!-;WII;&QA+B!!<W-I
M8W5R871I(&-H92!S:6$@87!E<G1A+@!);7!O<W-I8FEL92!D87)E(&%L;"=U
M=&5N=&4@(B5S(B!I('-E9W5E;G1I(&1I<FET=&D@<&5R(&QA(&-A<G1E;&QA
M("(E<R(Z("5S`%1E<W1O(&-O;G1A=&\`3F%Z:6]N90!#;W)S:0!#<F5A`$-R
M96$@=6X@;&EN:P!#<F5A('5N;R!N=6]V;P!#<F5A<F4@<V]T=&\@8V%R=&5L
M;&4`0W)E871O<F4@9&D@<&5R;65S<VD`3G5M97)O(&-A<G1A(&1I(&-R961I
M=&\`0V]R<F5N=&4@-"!&87-I`%-E<W-I;VYI(&-O<G)E;G1I`%1E;7!O($%T
M='5A;&4`3&$@55),(&%T='5A;&4@Z`!5=&5N=&D@071T=6%L:0!496UP;R!!
M='1U86QE`$-O;F1I>FEO;F4@8V]R<F5N=&4Z(`!3=&EL92!C;W)R96YT90!0
M97)S;VYA;&EZ>F$@;&4@;W!E<F%Z:6]N:2!D82!E<V5G=6ER92!A;&PG879V
M:6\@9&D@)7,`5&%G;&EA`%1A9VQI82!L82!S96QE>FEO;F4`0VEP<F\`1VEO
M<FYA;&UE;G1E`$1A=&$`1&%T82!2:6-E=G5T80!396QE>FEO;F$@;&$@9&%T
M80!':6]R;F\`15]L:6UI;F$@0V]L;VYN80!$:6-E;6)R90!.=6UE<FD@9&5C
M:6UA;&D`1&EM:6YU:7-C:2!L82!R:65N=')A;GIA`$-O;&]R92!S=&%N9&%R
M9`!)9&5N=&ETX"!D:2!D969A=6QT`%-H96QL(&1I(&1E9F%U;'0`1&5F:6YI
M>FEO;FD`16QI;6EN80!%;&EM:6YA($-E;&QA`$5L:6UI;F$@1W)U<'!O`$5L
M:6UI;F$@3&]G`$5L:6UI;F$@4&5R;65S<V\`16QI;6EN87)E(&4@<W9U;W1A
M<F4@:2!M97-A9V=I`$5L:6UI;F$@8V5L;&$`16QI;6EN82!C;VQO;FYA`$5L
M:6UI;F$@;&$@;6%S8VAE<F$@86QT97)N871I=F$@97-I<W1E;G1E`$5L:6UI
M;F$@:2!M97-S86=G:0!%;&EM:6YA(&D@<&5R;65S<VD@<&5R("(E<R(`16QI
M;6EN82!I('!E<FUE<W-I('!E<B`B)7,B(&4@;V=N:2!S;W1T;RUP97)M97-S
M;S\`16QI;6EN82!R:6=A`$5L:6UI;F$@;"=I9&5N=&ETX"!S96QE>FEO;F%T
M80!%;&EM:6YA(&QE('-O='1O(&-A<G1E;&QE`$5L:6UI;F$@;&$@8V]L;VYN
M82!C;W)R96YT90!%;&EM:6YA(&QA(')I9V$@8V]R<F5N=&4`16QI;6EN82!L
M;R!S8W)I<'0@9&D@86=G:6]R;F%M96YT;R!D96QL92!I;7!O<W1A>FEO;FD@
M9&D@(B5S(BX`5&5M<&\@9"=I;G9I;P!$86YI;6%R8V$`1&5S8W)I=FD@:6P@
M<')O8FQE;6$`1&5S8W)I>FEO;F4`1&5T=&%G;&D@*&%N8VAE(&YE;"!F:6QE
M(&1I(&QO9R!D:2!(;W)D92DZ`$D@9&5T=&%G;&D@<V]N;R!S=&%T:2!S8W)I
M='1I(&YE;"!F:6QE(&1I(&QO9R!P97(@;"=A;6UI;FES=')A=&]R92X`4W9I
M;'5P<&\`4'5N=&\@9&D@<G5G:6%D80!0=6YT;R!D:2!R=6=I861A('!E<B!L
M)W5L=&EM82!O<F$Z(`!0=6YT;R!D:2!R=6=I861A.B``1&ER97II;VYE(&1A
M('-I;FES=')A(&$@9&5S=')A`$1I<F5Z:6]N92!D82!D97-T<F$@82!S:6YI
M<W1R80!6:7-U86QI>GIA(&EL('1E;7!O(&YE;"!F;W)M871O(#(T(&]R93\`
M3W!Z:6]N:2!D:2!V:7-U86QI>GIA>FEO;F4`5FES=6%L:7IZ82!P<F5V:7-I
M;VYE(&1E='1A9VQI871A`$9O<FUA=&\@9&D@=FES=6%L:7IZ87II;VYE`$YO
M=&EF:6-A(&1I(&1I<W!O<VEZ:6]N90!.;VX@96QI;6EN87)E`$YO;B!A8V-E
M9&5R92!D:7)E='1A;65N=&4@;6%I;G1E;F%N8V4N<&AP`$QA<')I;6$@<FEG
M82!C;VYT:65N92!I;"!C86UP;R!D96D@;F]M:3\@4V4@<VDL('-E;&5Z:6]N
M82!Q=65S=&$@8V%S96QL83H`3F]N(&AA:2!U;B=U=&5N>F$_(&ES8W)I=FET
M:2X`4V-A<FEC80!38V%R:6-A("5S`$QA(&-O;F9I9W5R87II;VYE(&=E;F5R
M871A(.@@<W1A=&$@<V-A<FEC871A(&-O;64@<V-R:7!T(%!(4"X`1')O9VAE
M`%!U8F)L:6-A`%9I<W5A;&EZ>F$@8FQO8V-O`%9I<W5A;&EZ>F$@1W)U<'!O
M`%9I<W5A;&EZ>F$@4&5R;65S<V\`5FES=6%L:7IZ82!097)M97-S:0!6:7-U
M86QI>GIA(%!E<FUE<W-I('!E<B`E<P!6:7-U86QI>GIA(&QE(&]P>FEO;FD@
M<&5R.@!6:7-U86QI>GIA(&D@<&5R;65S:2!P97(@(B5S(@!6:7-U86QI>GIA
M(&D@<&5R;65S<VD@<&5R("5S`$5G:71T;P!%;&5M96YT;RXN+@!);F1I<FEZ
M>F\@16UA:6P`3"=I;F1I<FEZ>F\@16UA:6P@9&5V92!C;W)R:7-P;VYD97)E
M+@!%;6%I;"!C;VX@8V]N9F5R;6$`365S<V%G9VEO('9U;W1O+@!2:7-U;'1A
M=&\@=G5O=&\N`%)I8V5R8V$@9&5I('1E<FUI;FD@=G5O=&$`06)I;&ET82!L
M)VEN<V5R:6UE;G1O(&1I(&EM;6%G:6YI(&YE;"!T97-T;R!D86QL82!'86QL
M97)I82!D96QL92!&;W1O9W)A9FEE/P!!8FEL:71A<F4@:6P@;65N=2!D:2!C
M;VYT97-T;R!C;&EC8V%N9&\@:6P@=&%S=&\@9&5S=')O(&1E;"!M;W5S93\`
M1FEN92!A;FYO`$EN9W)A9&ES8VD@;"=E9&ET;W(`26YS97)I<V-I('5N82!D
M;VUA;F1A('-I8W5R82!C:&4@=&D@=F5R<N`@8VAI97-T82!S92!A=G)A:2!N
M96-E<W-I=.`@9&D@87IZ97)A<F4@;&$@='5A('!A<W-W;W)D+"!E<R`G<75A
M;"?H(&EL(&YO;64@9&5L('1U;R!C=6-C:6]L;S\G.@!);G-E<FES8VD@;"=5
M4DP@9&5L;"=I;6UA9VEN92!Q=6D`26YS97)I<V-I(&QE(&QE='1E<F4@<V]T
M=&\@<FEP;W)T871E.@!%<G)O<F4`17)R;W)E(&-R96%N9&\@:6P@8FQO8V-O
M.B`E<P!%<G)O<F4@96QI;6EN86YD;R!L)V%N8V]R82!D:2!S:6YC<F]N:6$Z
M("5S`$5R<F]R92!E;&EM:6YA;F1O(&EL(&QO9R!D:2!S:6YC<F]N:6$Z("5S
M`$5R<F]R92!O='1E;F5N9&\@:6P@8V]N=&5N=71O.B`E<P!%<G)O<F4@86=G
M:6]R;F%N9&\@;&$@<&%S<W=O<F0Z("5S`$5R<F]R92!C;VX@:6P@;65S<V%G
M9VEO(&5M86EL+@!%<G)O<F4@<V-R:79E;F1O("(E<R(N`$]G;FD@,34@;6EN
M=71I`$]G;FD@,B!M:6YU=&D`3V=N:2`S,"!S96-O;F1I`$]G;FD@-2!M:6YU
M=&D`060@;V=N:2!A8V-E<W-O`$]G;FD@;65Z>B=O<F$`3V=N:2!M:6YU=&\`
M5F%L;W)I(&0G97-E;7!I;SH`17-E9W5I`$5S<&%N9&D`17-P86YD:2!3:61E
M8F%R`%!R979I<W1O("<I)P!I4&%R;VQA('!R979I<W1A(&\@=&5R;6EN92!C
M:71A=&\@9&D@<FEC97)C80!$871A(&1I('-C861E;GIA`$5S<&]N96YT90!#
M;VQO<F4@1D<`06=G:6]R;F%M96YT;R!&5%`@9&5L;&4@:6UP;W-T87II;VYI
M`%1E;G1A=&EV;R!F86QL:71O(&YE;"!R96-U<&5R;R!D96QL92!P<F5F97)E
M;GIE+@!#;VQL96=A;65N=&\@86P@<V5R=F5R($Q$05`@9F%L;&ET;RX`0V]L
M;&5G86UE;G1O(&%L('-E<G9E<B!334(@9F%L;&ET;RX`3F]N(.@@<FEU<V-I
M=&\@82!C;W!I87)E(&1A("(E<R(N`$YO;B#H(')I=7-C:71O(&$@8V]P:6%R
M92!A("(E<R(N`$YO;B#H(')I=7-C:71O(&$@8W)E87)E('5N82!N=6]V82!C
M;VYN97-S:6]N92!305-,+@!.;VX@Z"!R:75S8VET;R!A('-P;W-T87)E(&$@
M(B5S(BX`3F]N(.@@<FEU<V-I=&\@82!R96-U<&5R87)E.B`E<P!':75S=&\`
M17)R;W)E($9A=&%L93H`1F5B8G)A:6\`4VEM:6QE(&$`4VEM:6QE(&$Z`$-O
M;G1E9V=I;R!F:6QE.B`E<R!F:6QE`$-O;G1E9V=I;R!F:6QE.B`E<R!F:6QE
M<P!'97-T:6]N92!&:6QE`$YO;64@1FEL90!396QE>FEO;F4@9FEL90!#87)I
M8V$@1FEL90!#87)I8V%M96YT;R!F:6QE(&YO;B!S=7!P;W)T871O`$9I;'1R
M:0!&:6YL86YD:6$`4')I;6\@365Z>F\`4')I;6\@475A<G1O`%)A<'!O<G1O
M(&9I<W-O`$YE8F)I80!,82!#87)T96QL82`E<R!N;VX@97-I<W1E`$-O;&]R
M92!D96QL82!F;VYT90!#:6)O`%!E<B!B<F]W<V5R(&-H92!N;VX@<W5P<&]R
M=&%N;R!L92!I;6UA9VEN:0!0<F5V:7-I;VYE("A4048I`$AA:2!D:6UE;G1I
M8V%T;R!L82!P87-S=V]R9#\`26YO;'1R:0!690!&<F%N8VEA`$1A`$1A(&EL
M(`!$97-C<FEZ:6]N92!#;VUP;&5T80!,;F$@4&EE;F$`3F]M92!#;VUP;&5T
M;P!'86QL97)I82!D86QL82!Q=6%L92!P<F5N9&5R92!L92!I;6UA9VEN:0!'
M86QL97)I83H`1V5N97)A("5S($-O;F9I9W5R87II;VYE`$-O9&EC92!'96YE
M<F%T;P!'97)M86YI80!':6)I;'1E<G)A`$YO;64@1&%T;P!/<'II;VYI($=L
M;V)A;&D`5F%I`$UA<'!E($=O;V=L90!38V%L92!D:2!G<FEG:0!'<F5C:6$`
M06UM:6YI<W1R87II;VYE($=R=7!P:0!)(&YO;6D@9&5L(&=R=7!P;R!N;VX@
M9&5V;VYO(&5S<V5R<F4@=G5O=&D`1W)O=7!?;&1A<#H@26UP;W-S:6)I;&4@
M86=G:75N9V5R92!I;"!G<G5P<&\@)7,N(%%U97-T82#H(&QA(')I<W!O<W1A
M(&1E;"!S97)V97(Z(`!'<F]U<%]L9&%P.B!);7!O<W-I9&EL92!E;&EM:6YA
M<F4@:6P@9W)U<'!O("5S`$=R;W5P7VQD87`Z($EM<&]S<VEB:6QE(&%G9VEO
M<FYA<F4@:6P@9W)U<'!O("5S`$=R=7!P:0!097)M97-S:2!D96=L:2!O<W!I
M=&D`3&EB<F\@9&5G;&D@;W-P:71I`$EN=&5S=&%Z:6]N90!);G1E<W1A>FEO
M;FD`06QT97IZ80!!:75T;P!!:75T;R!U<V%N9&\@;"=E9&ET;W(`06EU=&%N
M=&4`16UI<V9E<F\`475E<W1O(.@@;"=I;FEZ:6\@9&5L(&9I;&4Z`$%L=&\`
M2&]?<F1E`%-A;G1A(%-E9&4@*$-I='1A)R!D96P@5F%T:6-A;F\I`$AO<F1E
M`$EN9&ER:7IZ;R!D:2!C87-A`$1I<F5C=&]R>2!D:2!C87-A`%1E;&5F;VYO
M(&1I(&-A<V$`4F5G;VQA(&]R:7IZ;VYT86QE`%)I96UP:6UE;G1O(&]R:7IZ
M;VYT86QE`$]R:7IZ;VYT86QE.@!#;VUE('-E:2!A<G)I=F%T;R!Q=6D_("A3
M96D@<')E9V%T;R!D:2!F87)E('5N(')A<'!O<G1O(2D`475A;G1E(&-O;&]N
M;F4@=G5O:2!U;FER93\`475A;G1I(&-A;7!I("AC;VQO;FYE*2!C:2!S;VYO
M(#\`475A;G1E(')I9VAE('9U;VD@=6YI<F4_`%5M:61I=.``56UI9&ETX#H@
M`%5N9VAE<FEA`$-R96%Z:6]N92!D96QL82!C87-E;&QA($E-05`@9F%L;&ET
M83H@)7,`0V%N8V5L;&%Z:6]N92!D96QL82!C87-E;&QA($E-05`@9F%L;&ET
M83H@)7,`0W)E87II;VYE(&1E;&QA('%U;W1A(&1E;&QA(&-A<V5L;&$@24U!
M4"!F86QL:71A.B`E<P!);F1I<FEZ>F\@25``26YD:7)I>GIO($E0(&YO;B!D
M:7-P;VYI8FEL92X`3"=I;F1I<FEZ>F\@25`@;F]N(.@@86QL)VEN=&5R;F\@
M9&5L(&)L;V-C;R!#2412(&-O;G-E;G1I=&\N`$E?;G-E<FES8VD@;&$@4DEG
M82!P<FEM80!)<VQA;F1A`%-O;&\@26-O;F4`26-O;F4@<&5R("5S`$EC;VYE
M(&-O;B!T97-T;P!.;VUE(&1E;&PG261E;G1I=.``4V4@;F]N(.@@<W1A=&\@
M=FES=6%L:7IZ871O(&-O<G)E='1A;65N=&4L("5S(&%P<FER92!I;B!U;F$@
M;G5O=F$@9FEN97-T<F$N`%-E(&YO;B!V961I(&YE<W-U;F$@:6-O;F$@=7-A
M;F1O($EN=&5R;F5T($5X<&QO<F5R+"!P;W1R97-T:2!D;W9E<B!S96QE>FEO
M;F%R92!Q=65S=&$@8V%S96QL82!P97(@86YN=6QL87)E(&QA('1R87-P87)E
M;GIA(&1E;&QE(&EM;6%G:6YI(%!.1RX`4V4@=F5D:2!Q=65S=&\@;65S<V%G
M9VEO(&UA(&YO;B!L)VEM;6%G:6YE+"!L)VEM86=I;F4@8VAE('9U;VD@8V%R
M:6-A<F4@;F]N('!U\B!E<W-E<F4@=FES=6%L:7IZ871A(&1A;"!T=6\@8G)O
M=W-E<BX`4')E+59I<W5A;&EZ>F%Z:6]N92!D96QL)TEM;6%G:6YE.@!54DP@
M26UM86=I;F4`55),($EM;6%G:6YE.@!);6UA9VEN92!D86QL82!G86QL97)I
M80!);6UA9VEN92!D86QL82!G86QL97)I83H`0V%R:6-A;65N=&\@26UM86=I
M;F4`26UM86=I;FD`26UP;W)T82P@4&%S<V\@)60`0V%M<&D@:6UP;W)T871I
M.B`E<P!#86UP:2!I;7!O<G1A=&DZ`$EN7W-E<FES8VD@<FEG82!D;W!O`$-O
M9&EC92!D:2!A>FEO;F4@97)R871O(&1A=&\N`$YO;64@=71E;G1E(&4O;R!P
M87-S=V]R9"!N;VX@8V]R<F5T=&\N`$YO;64@=71E;G1E(&\@:6YD:7)I>GIO
M(&%L=&5R;F%T:79O(&YO;B!V86QI9&\N(%)I<')O=F$@86YC;W)A(&\@8V]N
M=&%T=&$@;"=A;6UI;FES=')A=&]R92!S92!N96-E<W-I=&D@9&D@=6QT97)I
M;W)E(&%I=71O+@!!=6UE;G1A(&QA(')I96YT<F%N>F$`571E;G1I($EN9&EV
M:61U86QI`$EN9F]R;6%Z:6]N90!);F9O<FUA>FEO;F4@;F]N('!I^2!D:7-P
M;VYI8FEL92X`26YS97)I<V-I($-?;VQO;FYA($1O<&\`26YS97)I<V-I($EM
M;6%G:6YE`$EN<V5R:7-C:2!486)E;&QA`$EN<V5R:7-C:2!L:6YK('=E8@!)
M;G-E<FES8VD@7T-O;&]N;F$@4')I;6$`26YS97)I<V-I('5N82!N=6]V82!C
M;VQO;FYA(&1O<&\@<75E;&QA(&-O<G)E;G1E`$EN<V5R:7-C:2!U;F$@;G5O
M=F$@8V]L;VYN82!P<FEM82!D:2!Q=65L;&$@8V]R<F5N=&4`26YS97)I<V-I
M('5N82!N=6]V82!R:6=A(&1O<&\@<75E;&QA(&-O<G)E;G1E`$EN<V5R:7-C
M:2!U;F$@;G5O=F$@<FEG82!P<FEM82!D:2!Q=65L;&$@8V]R<F5N=&4`26YS
M97)I<V-I('5N('!A<F%G<F%F;R!D;W!O(&EL(&YO9&\@8V]R<F5N=&4`26YS
M97)I<V-I('5N('!A<F%G<F%F;R!P<FEM82!D96P@;F]D;R!C;W)R96YT90!)
M;G-E<FES8VD@=6YA(&UA<V-H97)A(&%L=&5R;F%T:79A`$EN<V5R:7-C:2!U
M;B!I;F1I<FEZ>F\@96UA:6P@86P@<75A;&4@<&]T<F%I(')I8V5V97)E(&QA
M(&YU;W9A('!A<W-W;W)D.@!);G-E<FES8VD@=6YA(&-E;&QA(&1O<&\`26YS
M97)I<V-I('5N82!C96QL82!P<FEM80!);G-E<FES8VD@=6YA(&-O;&]N;F$@
M9&]P;P!);G-E<FES8VD@=6YA(&-O;&]N;F$@<')I;6$`26YS97)I<F4@;65S
M<V%G9VD`26YS97)I<V-I('5N('!A<F%G<F%F;R!D;W!O`$EN<V5R:7-C:2!U
M;B!P87)A9W)A9F\@<')I;6$`26YS97)I<V-I('5N82!R:6=A(&1O<&\`26YS
M97)I<V-I('5N82!R:6=A('!R:6UA`$EN<V5R:7-C:2!L82!R:7-P;W-T82!R
M:6-H:65S=&$@86QL82!D;VUA;F1A(&1I('-I8W5R97IZ83H`26YS97)I<V-I
M+TU/9&EF:6-A(&PG:6UM86=I;F4`26YS97)I<V-I+TU/9&EF:6-A(&EL(&QI
M;FL`0W)E9&ET:2!I;G-U9F9I8VEE;G1I('!E<B!S<&5D:7)E(&%L;&$@;&ES
M=&$@9&D@9&ES=')I8G5Z:6]N92X`0W)E9&ET:2!I;G-U9F9I8VEE;G1I+@!)
M;G1E<F\`3&ES=&$@:6YT97)A`%5$2"!N;VX@=F%L:61A("A5<V5R($1A=&$@
M2&5A9&5R*2X`1&%T82!:25`@;F]N('9A;&ED80!!<'!L:6-A>FEO;F4@;F]N
M('9A;&ED82X`0F%T8V@@240@;F]N('9A;&ED;P!I3"=I;F9O<FUA>FEO;F4@
M<V]T=&]M97-S82!N;VX@Z"!V86QI9&$N`$PG:6YD:7)I>GIO(&1I(&1D97-T
M:6YA>FEO;F4@;F]N(.@@=F%L:61O+@!);"!F;W)M871O(&1E;"!F:6QE(&YO
M;B#H('9A;&ED;P!,82!C:&EA=F4@9&5L;&$@;&EC96YZ82!N;VX@Z"!V86QI
M9&$N`$EL(&QO9V\@9F]R;FET;R!N;VX@Z"!V86QI9&\N`&US9U]T>7!E(&YO
M;B!V86QI9&\N`&%P:5]I9"!N;VX@=F%L:61O(&\@;6%N8V%N=&4N`%!A<F%M
M971R;R!N;VX@=F%L:61O(&\@;6%N8V%N=&4N`%!E<FUE<W-O(&1E;"!G96YI
M=&]R92!N;VX@=F%L:61O+@!I9"!D96P@<&%R=&YE<B!N;VX@=F%L:61O+@!#
M;V1I8V4@<')O9&]T=&\@;F]N('9A;&ED;RX`4')O=&]C;VQL;R!N;VX@=F%L
M:61O+@!$97-T:6YA=&%R:6\@;F]N('9A;&ED;SH@(B5S(@!/9V=E='1O(&-O
M;F1I=FES;R!N;VX@=F%L:61O`$EN9&ER:7IZ;R!S;W)G96YT92!N;VX@=F%L
M:61O+@!);G9E;G1A<FEO`$EN=F5R=&D@;&$@<V5L97II;VYE`$5M:71T96YT
M90!)=&%L:6$`1V5N;F%I;P!':6%P<&]N90!,=6=L:6\`1VEU9VYO`$=I=7-T
M:69I8V$`1VEU<W1I9FEC82!A;"!C96YT<F\`1VEU<W1I9FEC82!T=71T;P!'
M:75S=&EF:6-A(&$@<VEN:7-T<F$`1VEU<W1I9FEC82!A(&1E<W1R80!-86YT
M96YE<F4@;"=O<FEG:6YA;&4_`$EL('-E<G9E<B!+97)B97)O<R!H82!R:69I
M=71A=&\@;"=A=71E;G1I8V%Z:6]N92X`0W)E87II;VYE(&-H:6%V90!);7!R
M;VYT82!D:6=I=&%L92!D96QL82!C:&EA=F4`3'5N9VAE>GIA(&1E;&QA(&-H
M:6%V90!4:7!O(&1E;&QA(&-H:6%V90!5<V\@9&5L;&$@8VAI879E`$QA(&-H
M:6%V92#H(&=IX"!P<F5S96YT92!S=6P@:V5Y<V5R=F5R('!U8F)L:6-O+@!"
M86UI8FEN:0!$:5]S<&]S:7II;VYE`$QI;F=U86=G:6\`56QT:6UO(&UE>GIO
M`%5L=&EM82!P;W-S:6)I;&ETX"!P97(@:6P@8V%M8FEO(&1E;&QA('!A<W-W
M;W)D`%5L=&EM;R!Q=6%R=&\`56QT:6UO(&%G9VEO<FYA;65N=&\Z`%5L=&EM
M82!C;VYN97-S:6]N93H@)7,`56QT:6UA(&-O;FYN97-S:6]N93H@)7,@9&$@
M)7,`56QT:6UA(&-O;FYE<W-I;VYE.B!-86D`3&5G9V4`1&ES<&]S:7II;VYE
M`$QA<V-I86QO('9U;W1O('!E<B!A=F5R;&\@<V5N>F$@8F]R9&D`3&EB86YO
M`%-I;FES=')A`$EN=&5S=&%Z:6]N92!D:2!S:6YI<W1R80!686QO<FD@9&D@
M<VEN:7-T<F$`3&EV96QL;P!0:6]G9VEA(&QE9V=E<F$`0V]L;&5G86UE;G1O
M`$EL(&-O;&QE9V%M96YT;R!P=6YT82!A.@!#;VQL96=A(&PG:6YD:7)I>GIO
M(&5M86EL(&%L;&$@<&%G:6YA(&1I(&-O;7!O<VEZ:6]N92!Q=6%N9&\@=FEE
M;F4@=FES=6%L:7IZ871O`$-O;&QE9V%M96YT:0!%;&5N8V\@+2!L)W5T96YT
M92!P=?(@=F5D97)E(&QE(&-A<G1E;&QE`$5L96YC;R!D96D@9&%T86)A<V4`
M16QE;F-O(&1E:2!S;V=G971T:2!D96QL)V%I=71O`$5L96YC;R!486)E;&QE
M`$%R8VAI=FEO(&1E;&QA($QI<W1A`$%I=71O(&1E;&QA($QI<W1A`$ED96YT
M:69I8V%T:79O(&1E;&QA($QI<W1A`%!R;W!R:65T87)I;R!D96QL82!L:7-T
M80!)<V-R:7II;VYE(&%L;&$@3&ES=&$`06YN=6QL82!L)VES8W)I>FEO;F4@
M86QL82!,:7-T80!,)V5L96YC;R!D96QL92!S97-S:6]N92#H(&9A;&QI=&\Z
M("5S`$PG96QE;F-O(&1E9VQI('5T96YT:2#H(&9A;&QI=&\Z("5S`$PG96QE
M;F-O(&1E9VQI('5T96YT:2#H(&1I<V%B:6QI=&%T;RX`3&5T=&5R871U<F$`
M0V%R:6-A;65N=&\N+BX`3W)A(&QO8V%L93H@`$QI;F=U82!E($]R80!,=6]G
M;P!%;G1R80!%<V-I`$5N=')A`$]P97)A>FEO;FD@9&D@06-C97-S;P!,)V%C
M8V5S<V\@Z"!F86QL:71O('!E<F-HZ"!I;"!N;VUE('5T96YT92!O(&QA('!A
M<W-W;W)D(&EN<V5R:71I(&YO;B!S;VYO(&-O<G)E='1I+@!!8V-E<W-O(&9A
M;&QI=&\N`%1E<W1O(&QU;F=O`$%M;W)E`$)A<W-O`$QE='1E<F4@9W)E8VAE
M(&UI;G5S8V]L90!,971T97)E(&QA=&EN92!M:6YU<V-O;&4`3G5M97)I(')O
M;6%N:2!M:6YU<V-O;&D`3'5S<V5M8G5R9V\`35,M5$Y%1B!L)V%L;&5G871O
M(&YO;B!C;VYT:65N92!I;F9O<FUA>FEO;FDN`$UA9VEC;P!0;W-T80!);F1I
M<FEZ>F\@86UM:6YI<W1R871O<F4`0W)E82!C;VQL96=A;65N7W1O+BXN`$=E
M<W1I<V-I(&PG96QE;F-O(&1E;&QE(&-A=&5G;W)I92!E=&EC:&5T=&%N9&\@
M9VQI(&%R=&EC;VQI+"!E(&-O;B!I(&-O;&]R:2!A<W-O8VEA=&D@86QL92!C
M871E9V]R:64N`$UA<GIO`$UA<F=I;F4`0V]N=')A<W-E9VYA<F4@8V]N(&D@
M9FQA9W,@5FES=&\O3F]N5FES=&\`0V]N=')A<W-E9VYA<F4@8V]N(&%L=')I
M(&9L86=S("AE<SH@26UP;W)T86YT92]2:7-P;W-T;RD`0V%M<&D@8V]R<FES
M<&]N9&5N=&D`0W)E9&ET;R!M87-S:6UO('!E<FUE<W-O+@!%8V-E9'5T92!L
M82!P87)T:2!M87-S:6UE(&1E;"!M97-S86=G:6\N`%1E;7!O(&UA<W-I;6\@
M=6QT:6UE(#(T(&]R93H@`%1E;7!O(&UA<W-I;6\@=6QT:6UE(#8@;W)E.B``
M3G5M97)O(&UA<W-I;6\@9&5L(%!O<G1A($)L;V-K<P!,=6YG:&5Z>F$@;6%S
M<VEM80!-86=G:6\`365D:6-I;F$`365M8G)I`%5N:7-C:2!L92!C96QL90!-
M97-S86=G:6\`26P@;65S<V%G:6\@Z"!S=&%T;R!V97)I9FEC871O(&-O<G)E
M='1A;65N=&4L(&UA(&EL(&9I<FUA=&%R:6\@9&5L(&-E<G1I9FEC871O(&YO
M;B!P=?(@97-S97)E('9E<FEF:6-A=&\N`$UE<W-A9V=I;R!S8V%D=71O+@!4
M:7!O(&UE<W-A9V=I;P!-971O9&\`26P@;65T;V1O("`B)7,B(&YO;B#H(&1E
M9FEN:71O`$UE=&]D;R!N;VX@9&5F:6YI=&\N($UE=&]D;R!C:&EA;6%T83H@
M)7,`365T<FEC80!-97-S:6-O`$UE>GIO`%1E;7!O(&UI;FEM;R!U;'1I;64@
M,C0@;W)E.B``5&5M<&\@;6EN:6UO('5L=&EM92`V(&]R93H@`$EL('1E;7!O
M(&1I(&1U<F%T82!M:6YI;6\@9&5L;&$@<&%S=V]R9"!N;VX@Z"!S8V%D=71O
M`%-P96-C:&EO`%9A<FEO`$EL('!A8V-H971T;R!014%2($A45%!?4F5Q=65S
M="#H(&UA;F-A;G1E+@!#;VYF:6=U<F%Z:6]N92!M86YC86YT92X@1&5V:2!G
M96YE<F%R;F4@=6YA(&YU;W9A('-E('9U;VD@=7-A<F4@<75E<W1A(&%P<&QI
M8V%Z:6]N92X`240@9&5L(&UE<W-A9V=I;R!M86YC86YT92X`26P@<&%C8VAE
M='1O(%!%05(@36%I;"!R:6-H:65S=&\@Z"!M86YC86YT92X`240@9&5L;&$@
M<V5S<VEO;F4@;6%N8V%N=&4N`$QU`$UO9&5R871O`$1A=&$@9&5L;&$@;6]D
M:69I8V$`36]D:69I8V$@55),`$UO9'5L;P!-97-E(&4@86YN;P!-96YS:6QM
M96YT90!&87-I(&QU;F%R:0!3;VYO('-T871I('1R;W9A=&D@<&GY(&-A;7!I
M(&YE;&QA(&QI;F5A("5D(')I<W!E='1O(&$@<75E;&QI(&EP<F5V:7-T:2`E
M9"X`4W!O<W1A(%-O='1O`%-P;W-T82!A(%-I;FES=')A`%-P;W-T82!A($1E
M<W1R80!3<&]S=&$@4V]P<F$`4W!O<W1A('-O='1O`%-P;W-T82!S;W!R80!3
M96QE>FEO;F4@;75L=&EP;&$`36EO($%C8V]U;G0`26YF;W)M87II;VYI(&1E
M;"!-:6\@06-C;W5N=`!-:6\@4&]R=&%L90!$:7-P;W-I>FEO;F4@9&5L($UI
M;R!0;W)T86QE`$Y/+"!N;VX@<V]N;R!D)V%C8V]R9&\`3F]M90!2971E`$UA
M:0!.=6]V82!#871E9V]R:6$`3'5N82!.=6]V80!.=6]V;R!.;VUE(%5T96YT
M92`H;W!Z:6]N86QE*0!.=6]V82!P87-S=V]R9`!,82!N=6]V82!P87-S=V]R
M9"!S8V%D<N`@:6X@)7@N`$QA(&YU;W9A('!A<W-W;W)D(&YO;B!C;W)R:7-P
M;VYD92X`3G5O=F$@9FEN:7-T<F$@*%]V=6]T82D`3F]T:7II90!'<G5P<&D@
M9&D@3F]T:7II90!0<F]S<VEM;P!0<F]S<VEM92`T($9A<VD`4')O<W-I;64@
M;W!Z:6]N:0!0<F]S<VEM;SX`3F]T=&4`3F]N('-O;F\@9&ES<&]N:6)I;&D@
M:6YF;W)M87II;VYI(')I9W5A<F1O(&QA(&-O;F9I9W5R87II;VYE('!E<B!M
M;W-T<F%R92!L92!D:69F97)E;GIE+@!.;VX@Z"!D:7-P;VYI8FEL92!U;F$@
M<W1R871E9VEA('!E<B!C<F5A<F4@:6UM86=I;FD@25-/+@!.;VX@97-I<W1E
M('5N(&)L;V-C;R!A;&QA('!O<VEZ:6]N92!R:6-H:65S=&$`3F]N(.@@<W1A
M=&\@9F]R;FET;R!I;"!N;VUE(&1E;"!C86QE;F1A<FEO('!E<B!L)V%U=&5N
M=&EC87II;VYE($U#04PN`$YE<W-U;F$@;6]D:69I8V$N`$YE<W-U;B!F:6=L
M:6\@<'7R(&5S<V5R92!A9V=I=6YT;R!A('%U97-T;R!P97)M97-S;RX`3F]N
M(.@@<W1A=&$@<W!E8VEF:6-A=&$@86QC=6YA(&EN9F]R;6%Z:6]N92!S=6QL
M82!C;VYF:6=U<F%Z:6]N92!P97(@)7,N`$YO;B#H('-T871A('-P96-I9FEC
M871A(&%L8W5N82!I;F9O<FUA>FEO;F4@<W5L;&$@8V]N9FEG=7)A>FEO;F4@
M<&5R($944"!61E,N`$YO;B#H('-T871A('-P96-I9FEC871A(&%L8W5N82!I
M;F9O<FUA>FEO;F4@<W5L;&$@8V]N9FEG=7)A>FEO;F4@<&5R(%-13"!61E,N
M`$YO;B#H('-T871A('-P96-I9FEC871A(&%L8W5N82!I;F9O<FUA>FEO;F4@
M<W5L;&$@8V]N9FEG=7)A>FEO;F4@<&5R(%-13"U&:6QE(%9&4RX`3F]N(.@@
M<FEM87-T;R!N97-S=6X@8W)E9&ET;RX`3F]N(.@@<W1A=&$@9F]R;FET82!L
M82!D97-T:6YA>FEO;F4N`$EL(&9I;&4@;F]N(.@@<W1A=&\@8V%R:6-A=&\`
M3F]N('-O;F\@<W1A=&4@=')O=F%T92!L92!I8V]N92X`3F]N(.@@<W1A=&\@
M:6UP;W-T871O(&QA('!O<VEZ:6]N92X`3F]N(.@@<W1A=&\@:6YD:6-A=&\@
M;&$@<&]S:7II;VYE+@!.;VX@Z"!S=&%T;R!F;W)N:71O(&EL(&UE<W-A9V=I
M;RX`3F]N(.@@<W1A=&\@<W!E8VEF:6-A=&\@:6P@;F]M92X`3F]N(.@@<W1A
M=&\@<W!E8VEF:6-A=&\@:6P@;G5M97)O+@!.;VX@Z"!S=&%T82!F;W)N:71A
M(&QA('!A<W-W;W)D('!E<B!L)V%U=&5N=&EC87II;VYE($A45%`N`$YO;B#H
M('-T871A(&9O<FYI=&$@;&$@<&%S<W=O<F0@<&5R(&PG875T96YT:6-A>FEO
M;F4@24U!4"X`3F]N(.@@<W1A=&$@9F]R;FET82!L82!P87-S=V]R9"!P97(@
M;"=A=71E;G1I8V%Z:6]N92!+97)B97)O<RX`3F]N(.@@<W1A=&$@9F]R;FET
M82!L82!P87-S=V]R9"!P97(@;"=A=71E;G1I8V%Z:6]N92!,;V=I;BX`3F]N
M(.@@<W1A=&$@9F]R;FET82!L82!P87-S=V]R9"!P97(@;"=A=71E;G1I8V%Z
M:6]N92!005-35T0N`$YO;B#H('-T871A(&9O<FYI=&$@;&$@<&%S<W=O<F0@
M<&5R(&PG875T96YT:6-A>FEO;F4@4TU"+@!.;VX@Z"!D:7-P;VYI8FEL92!A
M;&-U;F$@<&%T8V@@<&5R(&QA('9E<G-I;VYE(&)I;F%R:6$@9&D@3W!E;E-3
M3"X@3&$@=F5R<VEO;F4@8FEN87)I82!D:2!/<&5N4U-,(.@@;F5C97-S87)I
M;R!C:&4@;W!E<FD@8V]N(&QE(&EN9F]R;6%Z:6]N:2!02T-3(#$R+@!.;VX@
MZ"!S=&%T82!I;7!O<W1A=&$@;&$@<75O=&$N`$YE<W-U;F$@<F5G;VQA`$YO
M;B#H('-T871O('-P96-I9FEC871O(&EL('-E<&%R871O<F4N`$YE<W-U;F$@
M;&%T;P!.97-S=6X@=&EP;R!D:2!F:6QE`$YO;B#H(&1I<W!O;FEB:6QE('5N
M82!D:7)E8W1O<GD@=&5M<&]R86YE82!P97(@;&$@8V%C:&4N`$YO;B#H('-T
M871A(&EN=FEA=&\@:6P@;F]M92!U=&5N=&4@92]O('!A<W-W;W)D+@!.;VX@
M<V]N;R!R:71O<FYA=&4@:6YF;W)M87II;VYI(%A-3"!V86QI9&4`3F5S<W5N
M('9A;&]R90!.;VX@Z"!S=&%T82!T<F]V871A(&QA('9E<G-I;VYE(&YE;&QA
M(&-O;F9I9W5R87II;VYE(&]R:6=I;F%L92X@4FEG96YE<F$@;&$@8V]N9FEG
M=7)A>FEO;F4N`$YO;B#H('-T871A('1R;W9A=&$@;&$@=F5R<VEO;F4@;F5L
M;&$@='5A(&-O;F9I9W5R87II;VYE+B!2:6=E;F5R82!L82!C;VYF:6=U<F%Z
M:6]N92X`3F5S<W5N;P!.97-S=6YO("]U<V\@:6UP;&EC:71O*0!%;6ES9F5R
M;R!3971T96YT<FEO;F%L90!.;W)V96=I80!.;VX@1&]P;P!.;VX@4')I;6$`
M3F]N('5N82!D:7)E8W1O<GD`3F]N(&EM<&QE;65N=&%T;P!.;VX@:6UP;W-T
M871O`$YO;B!S=7!P;W)T871O+@!!<'!U;G1I`$YU;&QA(&1A('9I<W5A;&EZ
M>F%R92P@=&]R;F$@:6YD:65T<F\N`$YO=F5M8G)E`$YU;65R;P!.=6UE<F\@
M9&D@8V%R871T97)I`$YU;65R;R!D:2!C;VQO;FYE`$YU;65R;R!D:2!R:6=H
M90!)(&YU;65R:2!N;VX@<V]N;R!S=&%T:2!S<&5C:69I8V%T:2!P97(@;"=A
M9V=I;W)N86UE;G1O(&YE;&QA(&QI<W1A(&1I(&1I<W1R:6)U>FEO;F4N`$]G
M9V5T=&\`0W)E871O<F4@9&5L;"=/9V=E='1O`$]T=&%L90!/='1O8G)E`%5F
M9FEC:6\`3&4@<&%S<W=O<F0@=F5C8VAI92!E(&YU;W9E(&1E=F]N;R!E<W-E
M<F4@9&EF9F5R96YT:0!696-C:&EA('!A<W-W;W)D`$QA('9E8V-H:6$@<&%S
M<W=O<F0@;F]N(.@@8V]R<F5T=&$N`%-O;&\@:2!S97)V97(@24U!4"!S=7!P
M;W)T86YO(&QE(&-A<G1E;&QE(&-O;F1I=FES92X`12<@<&5R;65S<V\@<V]L
M;R!U;B!I;F1I<FEZ>F\@96UA:6PN`%-O;&\@:6P@<')O<')I971A<FEO(&\@
M;"=A;6UI;FES=')A=&]R92!D:2!S:7-T96UA('!U\B!C86UB:6%R92!L82!P
M<F]P<FEE=.`@;R!I('!E<FUE<W-I(&1E;"!P<F]P<FEE=&%R:6\@<&5R('5N
M82!C;VYD:79I<VEO;F4`07!R92!I;B!U;F$@;G5O=F$@9FEN:7-T<F$`17)R
M;W)E($]P96Y34TPZ(&YO;B!S:2!P;W-S;VYO(&5S=')A<G)E(&QE(&EN9F]R
M;6%Z:6]N:2!D86QL82!P87)T92!F:7)M871A(%,O34E-12X`07!R92!Q=65S
M=&\@8V]L;&5G86UE;G1O(&EN('5N82!N=6]V82!F:6YE<W1R80!3:7-T96UA
M($]P97)A=&EV;P!/<'II;VYI`$]P>FEO;FD@<&5R("5S`$5L96YC;R!O<F1I
M;F%T;P!/<F=A;FEZ>F%Z:6]N90!5;FETX"!/<F=A;FEZ>F%T:79A`$%G96YD
M80!-87-C:&5R82!O<FEG:6YA;&4@9&5L;"=A<&QI8V%Z:6]N90!-87-C:&5R
M82!O<FEG:6YA;&4@:6X@)7,Z`$%L=')O`$%L=')E($EN9F]R;6%Z:6]N90!0
M97)M97-S:2!D96P@<')O<')I971A<FEO`$PG875T96YT:6-A>FEO;F4@4$%-
M(&YO;B#H(&1I<W!O;FEB:6QE+@!);F9O<FUA>FEO;F4@0VEF<F%T82!01U``
M0VAI879E(%!U8F)L:6-A(%!'4`!);F9O<FUA>FEO;F4@1FER;6%T82]#:69R
M871A(%!'4`!#;V1I8V4@4$A0`%-H96QL(%!(4`!%<W1E;G-I;VYE(%!/4TE8
M(&UA;F-A;G1E`%)I96UP:6UE;G1O`%!A<GII86QM96YT92!.=79O;&]S;P!0
M87-S=V]R9"!C86UB:6%T82!C;VX@<W5C8V5S<V\N`%!A<W-O=W)D(&YO;B!C
M;W)R971T80!%)R!R:6-H:65S=&$@;&$@<&%S<W=O<F0@<&5R(&PG875T96YT
M:6-A>FEO;F4@4D%$2553+@!087-S=V]R9"!C;VX@8V]N9F5R;6$`3&4@<&%S
M<W=O<F0@9&5V;VYO(&-O<G)I<W!O;F1E<F4N`$EN8V]L;&$`26YC;VQL82!D
M86QL82!C;&EP8F]A<F0`4&5R8V]R<V\`4&5R<V]N90!097)C96YT=6%L90!%
M<V5G=6D@;&4@3W!E<F%Z:6]N:2!D:2!-86YU=&5N>FEO;F4`17-E9W5I<F4@
M;&4@;W!E<F%Z:6]N:2!D:2!M86YT=71E;GII;VYE(&%L;"=A8V-E<W-O/P!0
M97)M97-S;P!097)M97-S;R`B)7,B(&YO;B!C86YC96QL871O+@!097)M97-S
M;R!.96=A=&\`4&5R;65S<VD`1V5S=&EO;F4@4&5R;65S<VD`26YF;W)M87II
M;VYI(%!E<G-O;F%L:0!496QE9F]N;P!&;W1O9W)A9FEE`%-I('!R96=A(&1I
M(&-L:6-C87)E(&EN(&%L8W5N92!C96QL90!3:2!P<F5G82!D:2!C;VYF97)M
M87)E(&-H92!S:2!V=6]L92!R:6UU;W9E<F4@<75E<W1O(&5L96UE;G1O.@!3
M:2!P<F5G82!D:2!C;VYF97)M87)E(&-H92!S:2!V=6]L92!S8V]L;&5G87)E
M('%U97-T;R!E;&5M96YT;SH`4VD@<')E9V$@9&D@:6YS97)I<F4@=6X@;65S
M92!E('5N(&%N;F\N`%-I('!R96=A(&1I(&EN<V5R:7)E('5N(&YO;64@<&5R
M(&QA(&YU;W9A(&=A=&5G;W)I83H`4VD@<')E9V$@9&D@:6YS97)I<F4@=6X@
M:6YD:7)I>GIO($E0('9A;&ED;RX`4VD@<')E9V$@9&D@:6YS97)I<F4@=6YA
M(&1A=&$@=F%L:61A+"!C;VYT<F]L;&$@:6P@;G5M97)O(&1I(&=I;W)N:2!N
M96P@;65S92X`4VD@<')E9V$@9&D@:6YS97)I<F4@=6XG;W)A('9A;&ED82X`
M4VD@<')E9V$@9&D@9F]R;FER92!U;B!R:6%S<W5N=&\@9&5L('!R;V)L96UA
M+@!3:2!P<F5G82!D:2!F;W)N:7)E(&EL('!R;W!R:6\@;F]M92!U=&5N=&4@
M92!P87-S=V]R9`!3:2!P<F5G82!D:2!L96=G97)E(&EL('-E9W5E;G1E('1E
M<W1O+B!$159)(&5S<V5R92!D)V%C8V]R9&\@8V]N(&D@=&5R;6EN:2!D)W5S
M;R!D96P@<VES=&5M82X`4VD@<')E9V$@9&D@<V-R:79E<F4@:6QN;VUE(&1E
M;&QA(&YU;W9A(&-A=&5G;W)I83H`4&]L;VYI80!0;VQI=&EC80!38W)U=&EN
M:6\`4&]R=&]G86QL;P!0;W-I>FEO;F%M96YT;R!D:2!Q=65S=&$@:6UM86=I
M;F4`4&]S:7II;VYA;65N=&\@9&D@<75E<W1A('1A8F5L;&$`4&]S=&%R92!A
M('%U97-T82!C87)T96QL82`H;F]N(&%P<&QI8V%T;R!D82!)34%0*0!0<F5C
M:7!I=&%Z:6]N92!P97(@;"=U;'1I;6$@)7,@;W)A*&4I`%!R969S7VQD87`Z
M($5S=&5N<VEO;F4@3$1!4"!R:6-H:65S=&$@;F]N('1R;W9A=&$N`%!R969S
M7W-E<W-I;VXZ(&5S=&5N<VEO;F4@9&5L;&$@<V5S<VEO;F4@<FEC:&EE<W1A
M(&YO;B!T<F]V871A+@!0<F5S<VEO;F4`4')E<W-I;VYE(&%L(&QI=F5L;&\@
M9&5L(&UA<F4Z(`!0<F5S<VEO;F4Z(`!!;G1E<')I;6$`06YT97!R:6UA(&1E
M;&PG:6UM86=I;F4@:6X@=6YA(&YU;W9A(&9I;F5S=')A`$]P>FEO;FD@<')E
M8V1E;G1I`%-T86UP82!D;V-U;65N=&\`0VAI879E(%!R:79A=&$`4')O8FQE
M;6$`1&5S8W)I>FEO;F4@9&5L('!R;V)L96UA`%!R;V=E='1I`$-H:6%V92!0
M=6)B;&EC80!!;&=O<FET;6\@9&5L;&$@0VAI879E(%!U8F)L:6-A`$EN9F]R
M;6%Z:6]N:2!S=6QL82!#:&EA=F4@4'5B8FQI8V$`3&$@8V]P<&EA(&-H:6%V
M92!0=6)B;&EC82]0<FEV871A(&YO;B#H('-T871A(&=E;F5R871A(&-O;B!S
M=6-C97-S;RX`16QI;6EN82!I(&UE<W-A9V=I`$1O;6%N9&$`4V5L97II;VYE
M(')A9&EO`%!I;V=G:6$`4F%P<&]R=&\`3&5G9VD`3&5G9V5R92!I(&UE<W-A
M9V=I`$5L:6UI;F%R92!R96%L;65N=&4@)7,_($PG;W!E<F%Z:6]N92!N;VX@
M<'7R(&5S<V5R92!R96-U<&5R871A+@!%;&EM:6YA<F4@<F5A;&UE;G1E(&QE
M(&EN9F]R;6%Z:6]N:2!R96QA=&EV92!A;&PG=71E;G1E("5S/R!,)V]P97)A
M>FEO;F4@;F]N('!U\B!E<W-E<F4@<F5C=7!E<F%T82X`4FEE<V5G=64@;&$@
M='5A('5L=&EM82!A>FEO;F4`06=G:6]R;F$`06=G:6]R;F$@9VQI(&5L96UE
M;G1I(&1I;F%M:6-I(&1E;"!M96YU.@!!9V=I;W)N87)E(&QA('9I<W1A(&1E
M;"!P;W)T86QE.@!2:6-A<FEC80!/<W-E<G9A>FEO;FD`4V5R=F5R(')E;6]T
M:0!54DP@<F5M;W1A("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`
M4FEM=6]V:0!2:6UU;W9I(&EL(&)L;V-C;P!2:6UU;W9I(&QA(&-O;&]N;F$`
M4FEM=6]V:2!L82!F;W)M871T87II;VYE`%)I;75O=FD@;&$@8V]P<&EA`%)I
M;75O=FD@;&\@<V-R:7!T('-A;'9A=&\@9&%L;&$@9&ER96-T;W)Y('1E;7!O
M<F%N96$@9&5L('-E<G9E<BX`4FEM=6]V:2!I;`!2:6UU;W9I('%U97-T;R!N
M;V1O(&1A;"!D;V-U;65N=&\`4FEM=6]V:2!L)W5T96YT90!2:6UU;W9I(&PG
M=71E;G1E.B`E<P!,82!R:6-H:65S=&$@;F]N('!U\B!E<W-E<F4@979A<V$N
M($-O9&EC92!D:2!E<G)O<F4@9&D@<FET;W)N;SH@`$EL('-E<G9I>FEO(')I
M8VAI97-T;R!O;B!P=?(@97-S97)E('1R;W9A=&\N`"(E<R(@<FEC:&EE<W1O
M(&YO;B#H('-P96-I9FEC871O(&YE;&QA(&-O;F9I9W5R87II;VYE(&1I("5S
M+@`B)7,B(')I8VAI97-T;R!N;VX@Z"!S<&5C:69I8V%T;R!N96QL82!C;VYF
M:6=U<F%Z:6]N92!D:2!61E,N`"(E<R(@<FEC:&EE<W1O(&YO;B#H('-P96-I
M9FEC871O(&YE;&QA(&-O;F9I9W5R87II;VYE+@!#86UP;R!2:6-H:65S=&\`
M07IZ97)A`$%Z>F5R82!L82!P87-S=V]R9`!!>GIE<F$@;&$@='5A('!A<W-W
M;W)D`%)I<')I<W1I;F$@;"=U;'1I;6$@9&]M86YD80!2:7-U;'1A=&D`4FET
M;W)N82!A;&QE($]P>FEO;FD`4FES8W)I=FD@;&$@;G5O=F$@<&%S<W=O<F0`
M4FEU;FEO;F4`26YV97)T:2!L82!#;VYF:6=U<F%Z:6]N90!/<'II;VYI('!E
M<B!I;"!2:6-H(%1E>'0@161I=&]R`$EN9&]V:6YE;&QI`$1E<W1R80!);G1E
M<W1A>FEO;FD@9&D@9&5S=')A`%9A;&]R:2!D:2!D97-T<F$`4')O<')I973@
M(&1E;&QA(%)I7V=A+BXN`%)E9V]L80!2;W5T82!D:2`Q.#``4F]U=&$@82!S
M:6YI<W1R80!2;W5T82!A($1E<W1R80!0<F]P<FEE=.`@9&5L;&$@4FEG80!0
M<F]P<FEE=.`@9&5L;&$@<FEG80!2:6=H93H`4F5G;VQE`$QE(')E9V]L92!A
M<'!A<FER86YN;R!T<F$@='5T=&4@;&4@<FEG:&4@92!L92!C;VQO;FYE`$QE
M(')E9V]L92!A<'!A<FER86YN;R!S;VQO('1R82!L92!C;VQO;FYE`$QE(')E
M9V]L92!A<'!A<FER86YN;R!S;VQO('1R82!L92!R:6=H90!%<V5G=6ER90!&
M:7)M82!C:69R871A(%,O34E-10!-97-S86=G:6\@8VEF<F%T;R!3+TU)344`
M3"=A=71E;G1I8V%Z:6]N92!305-,(&YO;B#H(&1I<W!O;FEB:6QE+@!-97-S
M86=G:6\@4TU3`$1I8VAI87)A>FEO;F4@4U%,('!E<B!I;"!V86QO<F4@9&D@
M;&]O:W-U<`!3=&5S<V$@<W1R=71T=7)A("A?875T;RD`<')O=FED97(@<V%T
M96QL:71A<F4`4V%L=F$`4V%L=F$@(B5S(@!386QV82`E<P!386QV82!L92!/
M<'II;VYI`$QA(&-O;F9I9W5R87II;VYE(&=E;F5R871A(.@@<W1A=&$@<V%L
M=F%T82!C;VUE('-C<FEP="!02%`@;F5L;&$@9&ER96-T;W)Y('1E;7!O<F%N
M96$@9&5L('1U;R!S97)V97(N`'-A;'9A=&4@)7,@8V]N9FEG=7)A>FEO;FDN
M`%-A;'9A=&\@;&\@<V-R:7!T(&1I(&%G9VEO<FYA;65N=&\@9&5L;&4@:6UP
M;W-T87II;VYI(&EN.B`B)7,B+@!38VEE;GIA`%)I8V5R8V$`36]T;W)I(&1I
M(%)I8V5R8V$`1FEL92!S96QE>FEO;F%T:0!396QE>FEO;F$@=6YA(&1A=&$`
M4V5L97II;VYA('5N(&=R=7!P;R!D82!A9V=I=6YG97)E`%-E;&5Z:6]N82!U
M;B!N=6]V;R!P<F]P<FEE=&%R:6\`4V5L97II;VYA('5N('-E<G9E<@!396QE
M>FEO;F$@=6X@=71E;G1E(&1A(&%G9VEU;F=E<F4`4V5L97II;VYA('1U='1O
M`%-E;&5Z:6]N82!T=71T:2!I(&-O;7!O;F5N=&D@9&5L;&$@9&%T82X`<V5L
M97II;VYA('5N(&]G9V5T=&\`3F5S<W5N82!S96QE>FEO;F4`4V5L97II;VYA
M(&D@8V%R871T97)I(&1I(&-U:2!H86D@8FES;V=N;R!D86QL92!C87-E;&QE
M('-O='1O(')I<&]R=&%T92X@4'5O:2!C;W!I87)L:2!E(&EN8V]L;&%R;&D@
M9&%L;"=A<F5A(&1I('1E<W1O+@!396QE>FEO;F$@:6P@=&5R;6EN92!D96QL
M82!D871A.@!396QE>FEO;F$@:6P@9F]R;6%T;R!D96QL82!D871A.@!396QE
M>FEO;F$@;"=I9&5N=&ETX"!C:&4@=G5O:2!M;V1I9FEC87)E.@!396QE>FEO
M;F$@:6P@;&EM:71E(&1E;&PG;W)A.@!396QE>FEO;F$@:6P@9F]R;6%T;R!D
M96QL)V]R83H`4V5L97II;VYA(&1U92!C86UP:2!C:&4@8V]R<FES<&]N9&]N
M;RX`4V5L97II;VYA(&QO('-C:&5M82!D96D@8V]L;W)I+@!396QE>FEO;F$@
M;&$@;&EN9W5A('!R969E<FET83H`26YV:6$@:6P@4F5P;W)T(&1E;"!P<F]B
M;&5M80!);G9I82!335,`4V5N<V]R93H@`%-E='1E;6)R90!.=6UE<F\@9&D@
M4V5R:64`26YF;W)M87II;VYE(&1E;"!S97)V97(@<V)A9VQI871A(&\@;F]N
M(&1I<W!O;FEB:6QE+@!!;6UI;FES=')A=&]R92!D:2!S97-S:6]N90!,82!S
M97-S:6]N92!)1"#H('-C861U=&$`4V5S<VEO;FD`26UP;W-T80!);7!O<W1A
M(&QE(&]P>FEO;FD@<&5R('!E<FUE='1E<G1I(&1I(&%Z>F5R87)E(&QA('!A
M<W-W;W)D(&YE;"!C87-O(&1O=F5S<VD@9&EM96YT:6-A<G1E;&$N`$EM<&]S
M=&$@:6P@<V5R=F5R(')E;6]T;R!A;"!Q=6%L92!V=6]I(&%C8V5D97)E(&1A
M;"!T=6\@<&]R=&%L92X`26UP;W-T82!L82!L:6YG=6$@<')E9F5R:71A(&4@
M;&4@;W!Z:6]N:2!P97(@;"=O<F$@92!L82!D871A+@!);7!O<W1A(&QE(&%P
M<&QI8V%Z:6]N:2!D:2!A=G9I;RP@;&\@<V-H96UA(&1E:2!C;VQO<FDL(&EL
M('1E;7!O(&1I(&%G9VEO<FYA;65N=&\@9&5L;&$@<&%G:6YA(&4@86QT<F4@
M;W!Z:6]N:2!D:2!V:7-U86QI>GIA>FEO;F4N`$EM<&]S=&%Z:6]N90!38W)I
M<'0@9&D@86=G:6]R;F%M96YT;R!D96QL92!I;7!O<W1A>FEO;FD@9&ES<&]N
M:6)I;&D`1&EV97)S92!P;W-I>FEO;FD@9&ES<&]N:6)I;&D@8V]N(&EL('!A
M<F%M971R;SH@`$)R979E(%-O;6UA<FEO`$QA(&-H:6%V92!D)V%C8V5S<V\@
M9&]V<N`@97-S97)E(&1E9FEN:71A('!E<B!P:?D@8V]L;&5G86UE;G1I/P!-
M;W-T<F$`36]S=')A(&QE(&1I9F9E<F5N>F4@=')A(&QA(&-O;F9I9W5R87II
M;VYE(&%T='5A;&UE;G1E('-A;'9A=&$@92!L82!N=6]V82!G96YE<F%T82X`
M36]S=')A(&PG;W)A(&1E;&PG=6QT:6UO(&%C8V5S<V\@<75A;F1O(&5N=')I
M/P!-;W-T<F$@;"=O<'II;VYE('!E<B!M86YT96YE<F4@<75E;&QA(&]R:6=I
M;F%L90!-;W-T<F$@:6P@<F%C8V]G;&ET;W)E`$UO<W1R87)E(&QA('1A8F5L
M;&$@9&5L;&4@;W!E<F%Z:6]N:2!D96P@;65N=2!B87(_`$UO<W1R82!I;"!M
M96YU(&1I("5S('-U;&QA('-I;FES=')A/P!-;W-T<F$@:6P@8V%R:6-A;65N
M=&\`0V]N=')A<W-E9VYA`$9I<FUA`$%L9V]R:71M;R!D:2!F:7)M80!$:6UE
M;G-I;VYE`%-A;'1A(&QE(&]P97)A>FEO;FD@9&D@;6%N=71E;GII;VYE`$YE
M=F4`3W)D:6YA(&PG;W)D:6YA;65N=&\@9&D@<V5L97II;VYE`$EN9&ER:7IZ
M;R!S;W)G96YT90!3=60@069R:6-A`&5M:7-F97)O($UE<FED:6]N86QE`%-P
M87II;R!T<F$@8V5L;&4@86ED86-E;G1I`%-P87II;R!T<F$@:6P@8V]N=&5N
M=71O(&4@:6P@8F]R9&\@:6X@=6YA(&-E;&QA`$1I<W1A;GII871O<F4`4W!A
M>FEA='5R80!3<&%Z:6%T=7)A(&4@<FEE;7!I;65N=&\`4W!A9VYA`$EN<V5R
M:6UE;G1O($-A<F%T=&5R:2!3<&5C:6%L:0!397!A<F$@;&$@8V5L;&$`4V5P
M87)A(&QA(&-O;&]N;F$`4V5P87)A(&QA(')I9VAA`$%N;F\@9&D@<&%R=&5N
M>F$`4W1A=&\@;R!0<F]V:6YC:6$`1F]R;6%T;R!D:2!M96UO<FEZ>F%Z:6]N
M90!);F1I<FEZ>F\`5&]G;&D@:6P@9&]M:6YI;R!D86QL)VEN9&ER:7IZ;P!3
M=&EL92!;0U-370!$;P!3;W1T;V1I<F5C=&]R>2`B)7,B(&YO;B!T<F]V871A
M+@!/9V=E='1O`%-O='1O;65T=&D`12<@<W1A=&$@:6YV:6%T82!L82!R:6-H
M:65S=&$@<&5R(&%G9VEU;F=E<F4@(B5S(B!A;"!S:7-T96UA+B!.;VX@<'5O
M:2!A8V-E9&5R92!F:6YT86YT;R`@8VAE(&QA(')I8VAI97-T82!N;VX@=FEE
M;F4@87!P<F]V871A+@`B)7,B(.@@<W1A=&\@86=G:75N=&\@8V]N('-U8V-E
M<W-O(&%L('-I<W1E;6$N`$QE(&EN9F]R;6%Z:6]N:2!R96QA=&EV92!A;&PG
M=71E;G1E("(E<R(@<V]N;R!S=&%T92!C86YC96QL871E(&-O;B!S=7-S97-S
M;R!D86P@<VES=&5M82X`(B5S(B!E;&EM:6YA=&$@8V]N('-U8V-E<W-O+@`B
M)7,B(')I;6]S<V\@8V]N('-U8V-E<W-O(&1A;"!S:7-T96UA+@!#;VYF:6=U
M<F%Z:6]N92!I;G9E<G1I=&$@8V]N('-U8V-E<W-O+B!2:6-A<FEC82!P97(@
M=F5D97)E(&D@8V%M8FEA;65N=&DN`$-O<&EA(&1E;&QA(&-O;F9I9W5R87II
M;VYE('-A;'9A=&$@8V]N('-U8V-E<W-O+@!#;W!I82!D96P@9FEL92!D:2!C
M;VYF:6=U<F%Z:6]N92!D:2`E<R!S86QV871A(&-O;B!S=6-C97-S;RX`06=G
M:6]R;F%T;R!C;VX@<W5C8V5S<V\@(B5S(@!38W)I='1O(&-O;B!S=6-C97-S
M;R`E<P!3;VUM87)I;P!3=7!P;W)T;P!3;W!R86YN;VUE`%-V97II80!3=FEZ
M>F5R80!%<G)O<F4@9&D@<VEN=&%S<VD@;F5I('1E<FUI;FD@9&D@<FEC97)C
M80!0<F]P<FEE=.`@9&5L;&$@5&%B96QL80!);7!O<W1A>FEO;F4@9&5L;&$@
M5&%B96QL80!0<F]P<FEE=.`@9&5L;&$@=&%B96QL80!/8FEE='1I=F\Z`$%T
M=&EV:73@`$YU;65R;R!D:2!T96QE9F]N;P!496UP97)A='5R82!P97(@;"=U
M;'1I;6$@;W)A.B``5&5M<&5R871U<F$`5&5M<&5R871U<F$Z(`!-87-C:&5R
M82`B)7,B(&YO;B!T<F]V871A+@!'97-T:6]N92!-87-C:&5R80!497-T;P!3
M;VQO(%1E<W1O`$%L;&EN96%M96YT;R!T97-T;P!':0!,)V5S=&5N<VEO;F4@
M1E10(&YO;B#H(&1I<W!O;FEB:6QE+@!,82!C<F]N:7-T;W)I82!D96P@<VES
M=&5M82#H(&1I<V%B:6QI=&%T82X`26P@;6]T;W)E(&1I(&EN=&5G<F%Z:6]N
M92!(;W)D92]+;VQA8B!N;VX@<W5P<&]R=&$@(B5S(@!);"!L;V<@9&D@24U3
M4"!N;VX@<'7R(&5S<V5R92!I;FEZ:6%L:7IZ871O+@!,82!C;&%S<V4@36%I
M;G1E;F%N8V4Z.B!N;VX@Z"!S=&%T82!C87)I8V%T82!C;VX@<W5C8V5S<V\`
M3&$@9FEN:7-T<F$@9&5L;&4@3W!Z:6]N:2!S:2#H(&-H:75S82X@57-C:7)E
M+@!3;VQA;65N=&4@:6P@;&%T;R!I;F9E<FEO<F4`26P@8V]N=&%T=&\@Z"!S
M=&%T;R!A9V=I=6YT;R!C;VX@<W5C8V5S<V\@86QL82!T=6$@<G5B<FEC82X`
M3F]N(.@@<W1A=&$@<W!E8VEF:6-A=&$@;&$@;&ES=&$@9&D@9&ES=')I8G5Z
M:6]N92X`3&$@9G5N>FEO;F4@9&D@8VEF<F%T=7)A(')I8VAI961E('5N82!C
M;VYN97-S:6]N92!W96(@<VEC=7)A+@!);"!F:6QE("5S(&1O=G)E8F)E(&-O
M;G1E;F5R92!U;F$@)7,@:6UP;W-T87II;VYE+@!);"!F:6QE("5S(&1O=G)E
M8F)E(&-O;G1E;F5R92!A;&-U;F4@)7,@:6UP;W-T87II;VYI+@!);"!F:6QE
M(&YO;B!C;VYT:65N92!I;F9O<FUA>FEO;FDN`$QE('-E9W5E;G1I('-O;F\@
M;&4@:6YT97-T87II;VYI('!E<B!Q=65S=&\@;65S<V%G9VEO+W)F8S@R,B!M
M97-S86=G:6\N`$PG:61E;G1I=.`@(B5S(B#H('-T871A(&-A;6-E;&QA=&$N
M`$EL(&YU;65R;R!D96D@8V%M<&D@9&5V92!E<W-E<F4@9&D@=&EP;R!N=6UE
M<FEC;RX`26P@;6]D=6QO(&]P96YS<VP@Z"!R:6-H:65S=&\@<&5R(&QA(&-L
M87-S92!(;W)D95]#<GEP=%]S;6EM93HZ+@!,82!P<F5F97)E;GIA("(E<R(@
M;F]N('!U\B!E<W-E<F4@<V%L=F%T82!P97)C:.@@;"=I;F9O<FUA>FEO;F4@
M8V]N=&5N=71A(&5C8V5D92!L82!M87-S:6UA(&1I;65N<VEO;F4@9&ES<&]N
M:6)I;&4`26P@<')O9W)A;6UA('5S871O('!E<B!V:7-U86QI>GIA<F4@<75E
M<W1O('1I<&\@9&D@:6YF;W)M87II;VYE("@E<RD@;F]N(.@@<W1A=&\@=')O
M=F%T;R!N96P@<VES=&5M82X`26P@<V5R=F5R("(E<R(@Z"!S=&%T;R!E;&EM
M:6YA=&\N`$EL('-E<G9E<B`B)7,B(.@@<W1A=&\@<V%L=F%T;RX`3&$@<FEC
M:&EE<W1A(&1I(&ES8W)I>FEO;F4@<&5R("5S(.@@<W1A=&$@<FEM;W-S82X`
M3&$@<FEG82!S<&5C:69I8V%T82`H)60I(&YO;B!E<VES=&4N`$EL(&9I;&4@
M=&5M<&]R86YE;R`B)7,B(&YO;B!E<VES=&4N`$EL('1E<W1O(&1I9VET871O
M(&YO;B!C;W)R:7-P;VYD92!A;"!T97-T;R!S=6QL;R!S8VAE<FUO+@!,)VEN
M9F]R;6%Z:6]N92!C87)I8V%T82#H('-T871A('!E<G-A('-I;B!D86QL)W5L
M=&EM;R!P87-S;RX`26P@9FEL92!C87)I8V%T;R!N;VX@<'7R(&5S<V5R92!S
M86QV871O+@!,82!D:7)E8W1O<GD@9&5I('1E;6D@(B5S(B!N;VX@Z"!S=&%T
M82!T<F]V871A+@!.;VX@8VD@<V]N;R!O<'II;VYI(&1I<W!O;FEB:6QI+@!.
M;VX@8VD@<V]N;R!P87)T:2!C:&4@<&]S<V]N;R!E<W-E<F4@=FES=6%L:7IZ
M871E(&EN;&EN92X`0VD@<V]N;R!T<F]P<&D@8V%R871T97)I(&EN('%U97-T
M;R!C86UP;RX@2&%I(&1I9VET871O("5S(&-A<F%T=&5R:3L@9&5V:2!D:6=I
M=&%R92!U;B!N=6UE<F\@9&D@8V%R871T97)I(&UI;F]R92!D:2`E<RX`0VD@
M<V]N;R!A;&-U;FD@<')O8FQE;6D@;F5L;"=A9V=I=6YG97)E("(E<R(@86P@
M<VES=&5M83H@)7,`0R?H('-T871O('5N('!R;V)L96UA(&YE;"!C86YC96QL
M87)E(&QE(&EN9F]R;6%Z:6]N:2!P97(@;"=U=&5N=&4@(B5S(B!D86P@<VES
M=&5M83H@`$,GZ"!S=&%T;R!U;B!P<F]B;&5M82!N96P@<FEM=6]V97)E("(E
M<R(@9&%L('-I<W1E;6$Z(`!#)^@@<W1A=&\@=6X@<')O8FQE;6$@;F5L;"=A
M9V=I;W)N86UE;G1O(&1I("(E<R(Z("5S`$,GZ"!S=&%T;R!U;B!P<F]B;&5M
M82!C;VX@:6P@8V%R:6-A;65N=&\@9&5L(&9I;&4Z($YE<W-U;B`E<R#H('-T
M871O(&-A<FEC871O+@!#)^@@<W1A=&\@=6X@<')O8FQE;6$@8V]N(&EL(&-A
M<FEC86UE;G1O(&1E;"!F:6QE.B!);"`E<R!E<F$@<&GY(&QU;F=O(&1E;&QA
M(&UA<W-I;6$@9&EM96YS:6]N92!P97)M97-S82`H)60@8GET97,I+@!#)^@@
M<W1A=&\@=6X@<')O8FQE;6$@8V]N(&EL(&-A<FEC86UE;G1O(&1E;"!F:6QE
M.B!);"`E<R#H('-T871O(&-A<FEC871O('-O;&\@<&%R>FEA;&UE;G1E+@!#
M)^@@<W1A=&\@=6X@97)R;W)E(&YE;&QA('9I<W5A;&EZ>F%Z:6]N92!D:2!Q
M=65S=&$@<&%R=&4@9&5L(&UE<W-A9V=I;P!#)^@@<W1A=&\@=6X@97)R;W)E
M(&YE;&PG:6UP;W)T87)E(&QE(&EN9F]R;6%Z:6]N:2!D96P@8V]N=&%T=&\N
M`$,GZ"!S=&%T;R!U;B!E<G)O<F4@;F5L;"=I;7!O<G1A<F4@;&4@:6YF;W)M
M87II;VYI(&1I(&E#86QE;F1A<BX`0R?H('-T871O('5N(&5R;W)E(&YE;&QA
M(&9O<FT@9&D@8V]N9FEG=7)A>FEO;F4N(%!R;V)A8FEL;65N=&4@:&%I(&1I
M;65N=&EC871O('5N(&-A;7!O(')I8VAI97-T;RX`0R?H('-T871O('5N(&5R
M<F]R92!N96QL)V5S96=U:7)E(&QA('-P96-I9FEC82!F=6YZ:6]N92!D96QL
M82!R=6)R:6-A+B!3:2!P<F5G82!D:2!R:7!R;W9A<F4@<&GY('1A<F1I+@!#
M)^@@<W1A=&\@=6X@97)R;W)E(&YE;&PG86=G:6]R;F%M96YT;R!D96D@9&5T
M=&%G;&D@9&5L(&-O;G1A='1O+B!3:2!P<F5G82!D:2!P<F]V87)E('!I^2!T
M87)D:2X`0R?H('-T871O('5N(&5R<F]R92!N96QL)V%G9VEO<FYA;65N=&\@
M9&5L;&$@;&ES=&$@9&D@9&ES=')I8G5Z:6]N92X@4VD@<')E9V$@9&D@<')O
M=F%R92!P:?D@=&%R9&DN`%%U97-T;R!S97)V97(@24U!4"!N;VX@<W5P<&]R
M=&$@;&$@8V]N9&EV:7-I;VYE(&1I(&-A<G1E;&QE+@!1=65S=&\@<V5M8G)A
M(&YO;B!E<W-E<F4@=6X@87)C:&EV:6\@9&D@=&EP;R!R87(@=F%L:61O+@!1
M=65S=&\@<V5M8G)A(&YO;B!E<W-E<F4@=6X@9FEL92!D:2!T:7!O('II<"!V
M86QI9&\N`%%U97-T;R!N;VX@<V5M8G)A(&5S<V5R92!U;B!N=6UE<F\@9&D@
M8V%R=&$@=F%L:61O+@`@475E<W1O(&-A;7!O('!U\B!C;VYT96YE<F4@<V]L
M;R!I;G1E<FDN`"!1=65S=&\@8V%M<&\@<'7R(&-O;G1E;F5R92!S;VQO(&YU
M;65R:2!E(&1U92!P=6YT:2X`475E<W1O(&-A;7!O('!U\B!E<W-E<F4@<V]L
M;R!U;F$@;&ES=&$@9&D@:6YT97)I('-A<&%R871I(&1A('9I<F=O;&$@;R!S
M<&%Z:6\`475E<W1O(&-A;7!O(&1E=F4@97-S97)E('5N(&YU;65R;R!V86QI
M9&\N`%%U97-T;R!C86UP;R!D979E(&-O;G1E;F5R92!U;B!C;VQO<F\@:6X@
M9F]R;6%T;R!21T(@97-A9&5C:6UA;&4L(&%D(&5S96UP:6\@)R,Q,C,T868G
M+@!1=65S=&$@9F]R;2#H(&=I82!S=&%T82!P<F]C97-S871A+@!1=65S=&\@
MZ"`E<RX`475E<W1O(&UE<W-A9V=I;R#H('-T871O('-C<FET=&\@:6X@=6X@
M<V5T(&1I(&-A<F%T=&5R:2`H)7,I(&1I=F5R<V\@9&%L('1U;RX`475E<W1O
M(&YU;65R;R!D979E(&5S<V5R92!U;FEC;RX`475E<W1O('-E<G9E<B!N;VX@
M<'7R(&1E8V]M<')I;65R92!F:6QE(&EN(&9O<FUA=&\@>FEP(&4@9WII<"X`
M06P@;6]M96YT;R!Q=65S=&\@<VES=&5M82!N;VX@Z"!A='1I=F\N`%%U97-T
M;R!V86QO<F4@9&5V92!E<W-E<F4@=6X@;G5M97)O+@!1=65S=&$@9FEN97-T
M<F$@9&5V92!E<W-E<F4@8VAI86UA=&$@9&$@=6YA(&9I;F5S=')A(&1E;&QE
M($]P>FEO;FD`5'5O;F\`0FEG;&EE='1I`$]R80!&;W)M871O(&1E;&PG;W)A
M`%-E;&5Z:6]N92!D96QL)V]R80!4:71O;&\`00!097(@<V5L97II;VYE<F4@
M<&GY('9O8VDL('1I96YI('!R96UU=&\@:6P@=&%S=&\@0V]N=')O;"`H4$,I
M(&\@0V]M;6%N9"`H36%C*2!M96YT<FD@<W1A:2!C;&EC8V%N9&\N`$]G9VD`
M1&]M86YI`%1R;W!P92!A8V-E<W-I(&YO;B!V86QI9&D@9'5R96YT92!G;&D@
M=6QT:6UI(&UI;G5T:2X`06QT;P!4<F%D=7II;VYI`%9E<F\@;R!F86QS;P!-
M80!4=7)C:&EA`$1I9VET82!L82!T=6$@<V-E;'1A.B``26UP;W-S:6)I;&4@
M86-C961E<F4@86QL82!D:7)E8W1O<GD@5D93+@!);7!O<W-I8FEL92!A9V=I
M=6YG97)E(&%L=')E(&EN9F]R;6%Z:6]N:2!S=6=L:2!U=&5N=&D@;65N=')E
M(&1U<F%N=&4@;&$@<V]T=&]S8W)I>FEO;F4N`$EM<&]S<VEB:6QE(&-A;6)I
M87)E(&D@<&5R;65S<VD@<&5R(&EL(&9I;&4@5D93("(E<R(N`$EM<&]S<VEB
M:6QE(&-A;6)I87)E(&D@<&5R;65S<VD@<&5R(&EL(&9I;&4@5D93("5S+R5S
M+@!);7!O<W-I8FEL92!C86UB:6%R92!A("5S+@!);7!O<W-I8FEL92!V97)I
M9FEC87)E(&QA(&1I;65N<VEO;F4@9&D@(B5S(BX`26UP;W-S:6)I;&4@=F5R
M:69I8V%R92!L82!D:6UE;G-I;VYE(&1I("(E<R\E<R(N`$EM<&]S<VEB:6QE
M(&-O;FYE='1E<G-I(&%L('-E<G9E<B!344PN`$EM<&]S<VEB:6QE(&-O;FYE
M='1E<G-I(&-O;B!34TPN`$EM<&]S<VEB:6QE(&-O<&EA<F4@:6P@9FEL92!6
M1E,N`$EM<&]S<VEB:6QE(&-R96%R92!L82!D:7)E8W1O<GD@5D93("(E<R(N
M`$EM<&]S<VEB:6QE(&-R96%R92!L82!D:7)E8W1O<GD@5D93+@!);7!O<W-I
M8FEL92!C<F5A<F4@:6P@9FEL92!61E,N`$EM<&]S<VEB:6QE(&-R96%R92!L
M82!C87)T96QL82!61E,@(B5S(BX`26UP;W-S:6)I;&4@8W)E87)E(&EL(&9I
M;&4@5D93('9U;W1O+@!);7!O<W-I8FEL92!D96-O;7!R:6UE<F4@;&4@:6YF
M;W)M87II;VYI+@!);7!O<W-I8FEL92!E;&EM:6YA<F4@(B5S(BP@;&$@9&ER
M96-T;W)Y(&YO;B#H('9U;W1A+@!);7!O<W-I8FEL92!E;&EM:6YA<F4@(B5S
M(CH@)7,N`$EM<&]S<VEB:6QE(&5L:6UI;F%R92`E<RP@;&$@9&ER96-T;W)Y
M(&YO;B#H('9U;W1A`$EM<&]S<VEB:6QE(&5L:6UI;F%R92!L82!D:7)E8W1O
M<GD@5D93(&EN(&UO9&\@<FEC;W)S:79O+@!);7!O<W-I8FEL92!E;&EM:6YA
M<F4@;&$@9&ER96-T;W)Y(%9&4RX`26UP;W-S:6)I;&4@96QI;6EN87)E(&QA
M(&1I<F5C=&]R>2!61E,Z("5S+@!)37!O<W-I8FEL92!E;&EM:6YA<F4@:6P@
M9FEL92!61E,@(B5S(BX`26UP;W-S:6)I;&4@96QI;6EN87)E(&EL(&9I;&4@
M5D93+@!);7!O<W-I8FEL92!E;&EM:6YA<F4@;&$@8V%R=&5L;&$@5D93("(E
M<R(N`$EM<&]S<VEB:6QE(&5L:6UI;F%R92!61E,@:6X@;6]D;R!R:6-O<G-I
M=F\Z("5S+@!);7!O<W-I8FEL92!D971E<FUI;F%R92!L82!D:7)E8W1O<GD@
M871T=6%L92X`26UP;W-S:6)I;&4@97-T87)R92!I(&1E='1A9VQI(&1E;"!C
M97)T:69I8V%T;P!);7!O<W-I8FEL92!C87)I8V%R92!L82!D969I;FEZ:6]N
M92!D:2`E<RX`26UP;W-S:6)I;&4@<W!O<W1A<F4@:6P@9FEL92!61E,N`$EM
M<&]S<VEB:6QE(&%P<FER92!I;"!F:6QE(%9&4R`B)7,B+@!);7!O<W-I8FEL
M92!A<')I<F4@:6P@9FEL92!61E,@<&5R(&QA('-C<FET='5R82X`26UP;W-S
M:6)I;&4@87!R:7)E(&EL(&9I;&4@5D93+@!);7!O<W-I8FEL92!A<')I92!L
M)V%R8VAI=FEO(&-O;7!R97-S;RX`26UP;W-I8FEL92!L96=G97)E(&EL(&9I
M;&4@5D93("AF:6QE<VEZ92!F:6QE*"D@9F%I;&5D*2X`26UP;W-S:6)I;&4@
M;&5G9V5R92!I;"!F:6QE(%9&4R`H9V5T1FEL95-I>F4H*2!F86EL960I+@!)
M;7!O<W-I8FEL92!L96=G97)E(&EL(&9I;&4Z(`!);7!O<W-I8FEL92!L96=G
M97)E(&QA(&1I<F5C=&]R>2!V9G-R;V]T+@!);7!O<W-I8FEL92!R:6YO;6EN
M87)E("5S(&EN("5S.B!L82!C87)T96QL82!D:2!D97-T:6YA>FEO;F4@Z"!G
M:6$@<')E<V5N=&4`26UP;W-S:6)I;&4@<FEN;VUI;F%R92!L82!D:7)E8W1O
M<GD@5D93+@!);7!O<W-I8FEL92!R:6YO;6EN87)E(&QA(&1I<F5C=&]R>2!6
M1E,Z("5S+@!);7!O<W-I8FEL92!R:6YO;6EN87)E(&EL(&9I;&4@5D93("(E
M<R(N`$EM<&]S<VEB:6QE(')I;F]M:6YA<F4@:6P@9FEL92!61E,@)7,O)7,N
M`$EM<&]S<VEB:6QE(')I;F]M:6YA<F4@:6P@9FEL92!61E,N`$EM<&]S<VEB
M:6QE(&5S96=U:7)E("=M:VES;V9S)RX`26UP;W-S:6)I;&4@=')A9'5R<F4@
M<75E<W1O(&1O8W5M96YT;R!7;W)D`$EM<&]S<VEB:6QE(&1A<F4@;"=A=G9I
M;R!A;&PG86=G:6]R;F%M96YT;R!F<F5E+V)U<WD@<&5R("5S`$EM<&]S<VEB
M:6QE('-C<FEV97)E(&EL(&9I;&4@5D93("(E<R(N`$EM<&]S<VEB:6QE('-C
M<FEV97)E(&EL(&9I;&4@5D93("AC;W!Y*"D@9F%I;&5D*2X`26UP;W-S:6)I
M;&4@<V-R:79E<F4@;&4@:6YF;W)M87II;VYI(&YE;"!F:6QE(%9&4RX`26UP
M;W-S:6)I;&4@<V-R:79E<F4@:6P@9FEL92!61E,L(&QA('%U;W1A(&-O;G-E
M;G1I=&$@=F5R<N`@96-C961U=&$N`%-O='1O;&EN96%T;P!!;FYU;&QA($UO
M9&EF:6-H90!.;VX@9F%R92!L82!T=6$@=6QT:6UA(&%Z:6]N90!2:7-P;W-T
M82!I;F%T=&5S82!D86P@<V5R=F5R(&1U<F%N=&4@;&$@8V]N;F5S<VEO;F4Z
M(`!2:7-P;W-T82!I;F%T=&5S82!D86P@<V5R=F5R(&$Z(`!38V]N;W-C:75T
M;P!.;VUE('5T96YT92!E('!A<W-W;W)D('-C;VYO<V-I=71I`$YO;B!C;VQL
M96=A<F4@;"=E;&5M96YT;R!C;W)R96YT90!396YZ82!N;VUE`$5S=&5N<VEO
M;F4@;F]N('-U<'!O<G1A=&$`06=G:6]R;F$`06=G:6]R;F$@)7,`06=G:6]R
M;F$@=71E;G1E`$%G9VEO<FYA("(E<R(N`%-C<FEP="!D:2!C87)I8V%M96YT
M92!E;&EM:6YA=&$N`$-A<FEC80!C87)I8V%T:2!T=71T:2!I(&9I;&4@9&D@
M:6UP;W-T87II;VYE(&1E;&QE(&%P<&QI8V%Z:6]N:2!S=6P@<V5R=F5R+@!C
M87)A='1E<FD@;&%T:6YI(&UA:75S8V]L:0!.=6UE<FD@<F]M86YI(&UA:75S
M8V]L:0!U<V$@:6P@8V]R<F5N=&4Z("5S`%5S82!34TP`57-A('-E(&EL(&YO
M;64@=71E;G1E+W!A<W-W;W)D(.@@9&EF9F5R96YT92!D82!Q=65L;&$@9&5L
M('-E<G9E<B!)35-0+@!5=&5N=&4`3'5T96YT92`E<R!N;VX@Z"!A=71O<FEZ
M>F%T;R!P97(@)7,N`$=E<W1I;VYE(%5T96YT:0!/<'II;VYI(%5T96YT:0!2
M96=I<W1R87II;VYE(%5T96YT:0!,87)E9VES=')A>FEO;F4@9&5G;&D@=71E
M;G1I(.@@<W1A=&$@9&ES86)I;&ET871A('!E<B!Q=65S=&\@<VET;RX`3F]M
M92!U=&5N=&4@;F]N('1R;W9A=&\`3F]M92!5=&5N=&4`3F]M92!5=&5N=&4@
M(B5S(B#H(&=I82!P<F5S96YT92X`3F]M92!5=&5N=&4Z`$YO;64@571E;G1E
M.B``571E;G1I(&YE;"!S:7-T96UA.@!,82!D:7)E8W1O<GD@5D93(&YO;B!E
M<VES=&4N`$%S<V5N>F$`4&]S:7II;VYI('9A;&ED92!T<F]V871E(&EN8VQU
M9&]N;SH@`%9A;&ED:73@`%9A;&]R92!I;B!M:6YU=&D@9&$@;W)A+@!);"!V
M86QO<F4@Z"!M86=G:6]R92!D;&QA(&UA<W-I;6$@;'5N9VAE>GIA(&1I("5S
M+@!686QO<FD`5F%L;W)I(&1A:2!Q=6%L:2!S96QE>FEO;F%R90!687)I86)I
M;&4`5F5R:69I8V$@9F%L;&ET82`M('%U97-T;R!M97-S86=G:6\@<'7R(&5S
M<V5R92!S=&%T;R!A;'1E<F%T;R!C;VXN`%9E<G-I;VYE`%9E<G-I;VYE(&1I
M($-O;G1R;VQL;P!!;&QI;F5A;65N=&\@=F5R=&EC86QE`%)I96UP:6UE;G1O
M('9E<G1I8V%L90!697)T:6-A;&4Z`$UO;'1O($%L=&\`5FES=6%L:7IZ82`E
M<P!6:7-U86QI>GIA('5N82!P86=I;F$@=V5B(&5S=&5R;F$`5FES=6%L:7IZ
M82!C;VUE("5S`%9I<VEB:6QI=.``5FES:6)I;&ETX#H@`$%45$5.6DE/3D4`
M051414Y:24].12$A(2!224U53U9)($Q/(%-#4DE05"!-04Y504Q-14Y412!$
M02`E<RX`071T96YZ:6]N90!-90!";VQL971T:6YO(&UE=&5O<F]L;V=I8V\`
M0F]L;&5T=&EN;R!M971E;W)O;&]G:6-O(&9O<FYI=&\@9&$`4V5T=&EM86YA
M;&UE;G1E`$)E;G9E;G5T;P!"96YV96YU=&\@82`E<P!"96YV96YU=&\L("5S
M`%%U86QE(&%P<&QI8V%Z:6]N92!D;W9RX"!V:7-U86QI>GIA<F4@)7,@9&]P
M;R!L)V%C8V5S<V\_`%%U86PGZ"!I;"!C87)A='1E<F4@9&D@9&5L:6UI=&%Z
M:6]N93\`475A;&4@<&QU9VEN<R!A8FEL:71A<F4@<&5R(&EL(%)I8V@@5&5X
M="!E9&ET;W(N`$QA<F=H97IZ80!,87)G:&5Z>F$@:6X@=6YI=.`@0U-3`$QA
M<F=H97IZ82!D96P@;65N=2!D:2`E<R!S=6QL82!S:6YI<W1R82`H879RX"!E
M9F9E='1O(&-O;"!P<F]S<VEM;R!A8V-E<W-O*3H`3&%R9VAE>GIA(&1E;&QA
M('1A8F5L;&$`56YI=.`@9&D@;&%R9VAE>GIA`$QA<F=H97IZ83H`5F5N=&\`
M5F5L;V-I=.`@9&5L('9E;G1O(&EN(&YO9&D`5F5N=&\Z`%9E;G1O.B``4V%G
M9V5Z>F$`3&%V;W)O`$EN9&ER:7IZ;R!D96P@;&%V;W)O`%1E;&5F;VYO(&1E
M;"!L879O<F\`3G5M97)O(&1I(&-A;7!I(&5R<F%T;R!N96QL82!L:6YE82`E
M9"X@071T97-I("5D+"!T<F]V871I("5D+@!.=6UE<F\@9&D@8V%M<&D@97)R
M871O+B!!='1E<VD@)60L('1R;W9A=&D@)60N`$-O;7!E;G-A>FEO;F4@<V)A
M9VQI871A("5D(&1U<F%N=&4@;&$@;&5T='5R82!D:2!U;B!F:6QE(%9&4RX`
M06YN=6%L;65N=&4`4VD`4VDL('-O;F\@9"=A8V-O<F1O`%-E:2!I;B!F;W)M
M871O('1E<W1O+B!5<V$@:6P@8F]T=&]N92!;/#Y=('!E<B!T;W)N87)E(&%L
M(&9O<FUA=&\@5UE325=91RX`3F]N(&AA:2!I;"!P97)M97-S;R!D:2!C<F5A
M<F4@<&GY(&1I("5D(&)L;V-C:&DN`$YO;B!T:2!S96D@875T96YT:6-A=&\N
M`$YO;B!P=6]I(&%V97)E(&EL(&-A<F%T=&5R92`G7"<@;F5L('1U;R!N;VUE
M(&-O;7!L971O+@!.;VX@:&%I(&EN<V5R:71O('5N(&EN9&ER:7IZ;R!E;6%I
M;"!V86QI9&\N`$YO;B!H86D@87-S;V-I871O(&YE<W-U;B!D96D@8V%M<&D@
M9&%L(&9I;&4@:6UP;W)T871O(&-O;B!I(&-A;7!I(&-O<G)I<W!O;F1E;G1I
M(&EN("5S+@!396D@<W1A=&\@9&ES8V]N;F5S<V\N`$1E=FD@:6YS97)I<F4@
M=6X@;G5M97)O(&1I(&-E;&QU;&%R92!V86QI9&\L(&-O;G1E;F5N=&4@<V]L
M;R!N=6UE<FD@8V]N(&PG;W!Z:6]N92!D96P@)RLG('!E<B!I('!R969I<W-I
M(&EN=&5R;F%Z:6]N86QI+@!$979I(&EN<V5R:7)E('5N('9A;&]R92!V86QI
M9&\N`$1E=FD@8V]N9FEG=7)A<F4@=6X@8F%C:V5N9"!P97(@:6P@1&%T851R
M964@<&5R('5S87)E(%-I9VYU<',N`$1E=FD@8V]N9FEG=7)A<F4@=6X@8F%C
M:V5N9"!61E,N`$1E=FD@<')I;6$@9&5S8W)I=F5R92!I;"!P<F]B;&5M82!P
M<FEM82!D:2!M86YD87)L;R!C;VUE(')E<&]R="X`1&5V:2!I;G-E<FER92!L
M)U523"!A;&QA('%U86QE('!U;G1A('%U97-T;R!C;VQL96=A;65N=&\`1&5V
M:2!S96QE>FEO;F%R92!U;B!S97)V97(@9&$@96QI;6EN87)E+@!$979I('-P
M96-I9FEC87)E('5N('5T96YT92!D82!A>GIE<F%R92X`1&5V:2!S<&5C:69I
M8V%R92!U;B!U=&5N=&4@9&$@<FEM=6]V97)E+@!$979I('-P96-I9FEC87)E
M('5N('5T96YT92!D82!A9V=I=6YG97)E+@!$979I('-P96-I9FEC87)E('5N
M('5T96YT92!D82!A9V=I;W)N87)E+@!$979I('-P96-I9FEC87)E('5N)V%Z
M:6]N92!D82!E<V5G=6ER92X`1&5V:2!S<&5C:69I8V%R92!I;"!N;VUE(&1E
M;&QA(&YU;W9A(&-A=&5G;W)I82X`1&5V:2!I;G-E<FER92!U;B!N=6UE<F\@
M9&D@=&5L969O;F\@:71A;&EA;F\`3&$@='5A('-E<W-I;VYE("5S(.@@<V-A
M9'5T82X@4VD@<')E9V$@9&D@8V]L;&5G87)S:2!N=6]V86UE;G1E+@!);"!T
M=6\@:6YD:7)I>GIO($5M86EL`$EL(&-A;7!O($1A.B!D96P@='5O(&EN9&ER
M:7IZ;SH`3&4@='5E(&EN9F]R;6%Z:6]N:0!);"!T=6\@:6YD:7)I>GIO($EN
M=&5R;F5T(.@@8V%M8FEA=&\@9&%L;"=I;FEZ:6\@9&5L;&$@='5A('-E<W-I
M;VYE("5S+B!097(@<')O=&5G9V5R92!L82!T=6$@<VEC=7)E>GIA+"!D979I
M(')I8V]L96=A<G1I(&YU;W9A;65N=&4N`$EL('1U;R!.;VUE`$EL('1U;R!B
M86-K96YD(&1I(&%U=&5N=&EC87II;VYE(&YO;B!S=7!P;W)T82!L)V%G9VEU
M;G1A(&1I(&YU;W9I('5T96YT:2X@4V4@=G5O:2!U<V%R92!(;W)D92!P97(@
M9V5S=&ER92!G;&D@=71E;G1I+"!D979I('5S87)E('5N(&)A8VME;F0@9&D@
M875T96YT:6-A>FEO;F4@9&EF9F5R96YT90!);"!T=6\@8F%C:V5N9"!D:2!A
M=71E;G1I8V%Z:6]N92!N;VX@<W5P<&]R=&$@;"=E;&5N8V\@9&5G;&D@=71E
M;G1I+"!O(&QA(&9U;GII;VYE(.@@<W1A=&$@9&ES86)I;&ET871A('!E<B!A
M;'1R92!R86=I;VYI+@!396UB9G)A(&-H92!I;"!T=6\@8G)O=W-E<B!S:6$@
M8V%M8FEA=&$@9&%L;"=I;FEZ:6\@9&5L;&$@='5A('-E<W-I;VYE("5S+B!0
M97(@<')O=&5G9V5R92!L82!T=6$@<VEC=7)E>GIA+"!D979I(&%C8V5D97)E
M(&YU;W9A;65N=&4N`$EL('1U;R!B<F]W<V5R(&YO;B!S=7!P;W)T82!Q=65S
M=&$@9G5N>FEO;F4N`$EL('1U;R!B<F]W<V5R(&YO;B!S=7!P;W)T82!Q=65S
M=&$@;W!Z:6]N92!D:2!S=&%M<&$N(%!R96UI($-O;G1R;VPO0V]M;6%N9"`K
M(%`@<&5R('-T86UP87)E+@!);"!T=6\@9G5S;R!O<F%R:6\Z`$QA('1U82!I
M9&5N=&ETX"!D:2!D969A=6QT(.@@<W1A=&$@;6]D:69I8V%T82X`3&$@='5A
M(&ED96YT:73@(&1I(&1E9F%U;'0Z`$EL('1U;R!N;VUE(&-O;7!L971O.@!,
M82!T=6$@;&]G:6X@Z"!S8V%D=71A+@!,82!T=6$@;G5O=F$@<&%S<W=O<F0@
M<&5R("5S(.@Z("5S`$QE('1U92!O<'II;VYI('-O;F\@<W1A=&4@86=G:6]R
M;F%T92!P97(@;&$@9'5R871A(&1I('%U97-T82!S97-S:6]N92X`3&4@='5E
M(&]P>FEO;FD@<V]N;R!S=&%T92!A9V=I;W)N871E+@!,82!T=6$@<&%S<W=O
M<F0@Z"!S=&%T82!A>GIE<F%T80!,82!T=6$@<&%S<W=O<F0@Z"!S=&%T82!A
M>GIE<F%T82P@8V]N=')O;&QA(&QA('1U82!E;6%I;"!E(&%C8V5D:2!C;VX@
M;&$@='5A(&YU;W9A('!A<W-W;W)D+@!,82!T=6$@<&%S<W=O<F0@Z"!S8V%D
M=71A+@!)('1U;VD@<V5R=F5R(')E;6]T:3H`6TYA<V-O;F1I(&EL('1E<W1O
M(&-I=&%T;UT`6U)E<&]R="!D96P@<')O8FQE;6%=`%M-;W-T<F$@:6P@=&5S
M=&\@8VET871O("T`6TUO<W1R82!I;"!T97-T;R!C:71A=&\@+2`E<R!L:6YE
M95T`6VQI;F5A("5S(&1I("5S70!?06UM:6YI<W1R87II;VYE`%]#86YC96QL
M82!2:6=A`%]'<G5P<&D`7T%I=71O`'!R;W!R:65TX"!D96QL)U]);6UA9VEN
M92XN+@!?16YT<F$`7T5S8VD`7TUO9&EF:6-A($-O;&QE9V%M96YT;RXN+@!?
M3W!Z:6]N:0!?4&5R;65S<VD`7T5L:6UI;F$@0V]L;&5G86UE;G1O+BXN`%])
M;7!O<W1A>FEO;F4`4')O<')I973@(&1E;&QA(%]486)E;&QA+BXN`%5T96YT
M:0!R=6)R:6-A`&EN9&ER:7IZ:2!S8V]N;W-C:75T:0!C86QE;F1A<FEO`&-A
M;&UO`&YO;B!P;W-S;R!C<F5A<F4@:6P@9FEL92!D:2!O=7!U=`!N;VX@<&]S
M<V\@87!R:7)E(&PG:6YP=70`<')E;6D@<75I`&5R<F]R92!N96QL)W5S;R!D
M96QL82!L:6YE82!D:2!C;VUA;F1O`&5R<F]R92!D:2!C;VYF:6=U<F%Z:6]N
M90!E<G)O<F4@;F5L(&9O<FUA=&\@9&5L;&$@9&%T80!V:7-U86QI>GIA('!R
M979I<VEO;F4@*'1A9BD`<'5B8FQI8V$`96YT<GD@;F]N('1R;W9A=&$`9&%L
M("5S("@E<RD@86P@)7,@)7,`;F]M92!H;W-T('-C;VYO<V-I=71O`&EM;65D
M:6%T;P!E<G)O<F4@9&D@:6YP=70O;W5T<'5T`&5R<F]R92!I;G1E<FYO(&1E
M;"!S;V9T=V%R90!L:6YE95T`97)R;W)E(&1I(&-O9&EC92`E9"!D:2!M:VES
M;V9S(&1U<F%N=&4@;&$@<V-R:71T;W)A($E33RX`;F]M90!N;VX@:6UP;&5M
M96YT871O`&YO;B!A;F-O<F$@:6UP;&5M96YT861O`&)L;V-C;R!N;W1E`'!E
M<F-E;G1O`'!E<FUE<W-O(&YE9V%T;P!E<G)O<F4@<F5M;W1O(&YE;"!P<F]T
M;V-O;&QO`'-E<G9I>FEO(&YO;B!D:7-P;VYI8FEL90!M;W-T<F$@;&4@9&EF
M9F5R96YZ90!C;W-T86YT90!E<G)O<F4@9&D@<VES=&5M80!E;&5N8V\@871T
M:79I=.``9W5A<W1O('1E;7!O<F%N96\`<V-R:79I(&QA('!A<W-W;W)D(&1U
M92!V;VQT92!P97(@8V]N9F5R;6%R90!U;FEF:6-A=&\`<V5N>F$@;F]M90!U
M=&5N=&4@<V5L97II;VYA=&\`=SH`=V5A=&AE<BYC;VT`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]J85]*
M4"\`````````````````````````````````````````````````````````
M````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`U,34T,S,W-3,`,#(P,3`P`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&]C86QE+VIA7TI0+VAE;'`N>&UL````````````````````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S,R,``Q,#4Q-30S,S<U,P`P,C$U-3``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]X
M;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O
M:F%?2E`O:&5L<"YX;6PL=B`Q+C(@,C`P-"\P-2\R-R`R,#HR,CHQ-"!J86X@
M17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4]
M(FYE=R(^"CQT:71L93Y4:&4@4&]R=&%L(%!A9V4\+W1I=&QE/@H@/'!A<F$^
M"B`@5&AI<R!P;W)T86P@<&%G92!P<F]V:61E<R!A('%U:6-K('-U;6UA<GD@
M;V8@86QL('EO=7(@:6UP;W)T86YT"B`@:6YF;W)M871I;VXN($9O<B!E>&%M
M<&QE+"!I="!M:6=H="!S:&]W(&AO=R!M86YY(&YE=R!E+6UA:6P@;65S<V%G
M97,@>6]U"B`@:&%V92!I;B!Y;W5R($E.0D]8+"!U<&-O;6EN9R!E=F5N=',@
M;VX@>6]U<B!C86QE;F1A<BP@=&%S:W,@;VX@>6]U<B!T;RUD;PH@(&QI<W0L
M(&AE861L:6YE<R!F<F]M('-E;&5C=&5D(&YE=W,@<V5R=FEC97,L(&%N9"!S
M;R!O;BX@($UA;GD@;V8@=&AE<V4*("!S=6UM87)I97,@=VEL;"!C;VYT86EN
M('%U:6-K('-H;W)T8W5T<R!T;R!C;VUM;VX@9G5N8W1I;VYS+"!S=6-H(&%S
M"B`@8V]M<&]S:6YG(&$@;F5W(&UA:6P@;65S<V%G92P@8W)E871I;F<@82!N
M97<@8V%L96YD87(@979E;G0@;W(@=&%S:RP@971C+@H@/"]P87)A/@H@/'!A
M<F$^"B`@5&AE(&-O;G1E;G1S(&]F('1H:7,@<&]R=&%L('!A9V4@87)E(&-U
M<W1O;6EZ86)L92!V:6$@=&AE($QA>6]U="!B=71T;VXN"B`@1F]R(&5X86UP
M;&4L('EO=2!C86X@8VAO;W-E('=H:6-H(&ET96US('1O(&EN8VQU9&4@;VX@
M=&AI<R!P;W)T86P@<&%G92!A<PH@('=E;&P@87,@:6X@=VAI8V@@;W)D97(@
M=&AE>2!A<F4@<VAO=VXN"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)N879B87(B('-T871E/2)N97<B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N
M($YA=FEG871I;VX@0F%R/"]T:71L93X*(#QP87)A/@H@($%T('1H92!L969T
M(&AA;F0@<VED92!O9B!T:&4@=V5B('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N
M(&YA=FEG871I;VX@8F%R+@H@($-L:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES
M(&YA=FEG871I;VX@8F%R('1O('%U:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*
M("!B971W965N('1H92!A=F%I;&%B;&4@87!P;&EC871I;VYS+@H@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B
M('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N
M86YC93H@1&\@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)
M9B!Y;W4@=V]U;&0@;&EK92!T;R!P97)F;W)M(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@;VX@;&]G:6XL(&-H96-K('1H:7,@8F]X+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC
M92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT
M96YA;F-E.B!#;VYF:7)M($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A
M/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@8V]N9FER;2!A;&P@;6%I;G1E
M;F%N8V4@=&%S:W,@8F5F;W)E('1H97D@87)E(')U;BP@8VAE8VL@=&AI<R!B
M;W@N($EF(&QE9G0@=6YC:&5C:V5D+"!A;&P@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<R!T:&%T(&YE960@=&\@8F4@<G5N('=I;&P@8F4@<&5R9F]R;65D(&%U
M=&]M871I8V%L;'D@=VET:"!N;R!C:&%N8V4@=&\@8V%N8V5L(&]N(&QO9VEN
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQO8V%L92]J85]*4"],0U]-15-304=%4R\`````````````````````````
M````````````````````````````````````````,#`P,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-3,`,#(Q-C8U`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VIA7TI0+TQ#7TU%4U-!1T53+VAO
M<F1E+FUO````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#,Q,#$W-P`Q,#4Q-30S
M,S<U,P`P,C,S,S0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````WA($E0````"I!0``'````&0M``"-!P``K%H```````#@>```
M#@```.%X```/````\'@```T`````>0``"`````YY```+````%WD```P````C
M>0``&````#!Y```;````27D``"T```!E>0``'0```)-Y```D````L7D``"D`
M``#6>0``&0````!Z```F````&GH```P```!!>@``)````$YZ```+````<WH`
M``X```!_>@``!0```(YZ```H````E'H```@```"]>@``"@```,9Z```5````
MT7H``!(```#G>@``A0```/IZ```.````@'L```H```"/>P``#0```)I[```.
M````J'L``!$```"W>P``#0```,E[```,````UWL```T```#D>P``!@```/)[
M``"4````^7L```P```".?```#@```)M\```.````JGP```@```"Y?```"0``
M`,)\```N````S'P``!H```#[?```,@```!9]```X````27T``%0```""?0``
M40```-=]``!:````*7X``%<```"$?@``-````-Q^```%````$7\``!$````7
M?P``)0```"E_```@````3W\``!,```!P?P``$````(1_```/````E7\```H`
M``"E?P```P```+!_```/````M'\``!0```#$?P``"0```-E_```-````XW\`
M`!(```#Q?P``&0````2````>````'H````\````]@```"@```$V````/````
M6(````@```!H@```)````'&````4````EH```!8```"K@```"````,*```!.
M````RX```"T````:@0``&0```$B!```'````8H$```P```!J@0``+````'>!
M```.````I($```,```"S@0``"P```+>!```'````PX$```<```#+@0``!0``
M`-.!```*````V8$```,```#D@0``%P```.B!```*`````((```\````+@@``
M&````!N"```C````-((```X```!8@@``%````&>"```7````?((``!<```"4
M@@``%P```*R"```3````Q((```\```#8@@``#@```.B"```?````]X(``!T`
M```7@P``!P```#6#```&````/8,```@```!$@P``#P```$V#```&````78,`
M``H```!D@P``$P```&^#```+````@X,``!````"/@P``%0```*"#```5````
MMH,```<```#,@P``$````-2#```%````Y8,``!$```#K@P``#````/V#```[
M````"H0``#@```!&A```"0```'^$```'````B80```4```"1A```$````)>$
M```3````J(0``#D```"\A```)P```/:$```L````'H4``"H```!+A0``)0``
M`':%```*````G(4```8```"GA0``"0```*Z%```'````N(4``"\```#`A0``
M-P```/"%```N````*(8``%4```!7A@``+0```*V&```M````VX8``#T````)
MAP``/P```$>'```M````AX<``$````"UAP``(P```/:'```C````&H@``$``
M```^B```+0```'^(```S````K8@``"4```#AB```%0````>)```9````'8D`
M`"D````WB0``)````&&)```H````AHD``!$```"OB0``"@```,&)```*````
MS(D``!````#7B0``%@```.B)```6````_XD```<````6B@``!P```!Z*```*
M````)HH```@````QB@``)P```#J*```(````8HH```<```!KB@``!P```'.*
M```&````>XH```4```""B@``!P```(B*```&````D(H```@```"7B@``*0``
M`*"*```.````RHH```H```#9B@``!````.2*```'````Z8H```D```#QB@``
M!@```/N*```1`````HL```<````4BP``%@```!R+```(````,XL```T````\
MBP``!@```$J+```>````48L``!$```!PBP``"````(*+```-````BXL```P`
M``"9BP``!P```*:+```#````KHL```,```"RBP``%P```+:+```3````SHL`
M`!T```#BBP``"`````",```(````"8P```@````2C```00```!N,```:````
M78P``"L```!XC```(````*2,```5````Q8P```8```#;C```!@```.*,```5
M````Z8P``!@```#_C```(@```!B-```N````.XT``!T```!JC0``(0```(B-
M``!4````JHT``"D```#_C0``"@```"F.```'````-(X```<````\C@``%0``
M`$2.```.````6HX```H```!IC@``#P```'2.```-````A(X```\```"2C@``
M#0```**.```)````L(X```8```"ZC@``&````,&.```3````VHX``!$```#N
MC@``%`````"/```$````%8\```8````:CP``%````"&/``!4````-H\``&0`
M``"+CP``#@```/"/```%````_X\```4````%D```$P````N0```1````'Y``
M`!$````QD```'````$.0```0````8)```"$```!QD```$P```).0```+````
MIY```!(```"SD```"@```,:0```/````T9```!$```#AD```#````/.0```7
M`````)$``!`````8D0``"````"F1```%````,I$```P````XD0``$````$61
M```%````5I$```T```!<D0``!@```&J1```'````<9$```T```!YD0``!P``
M`(>1```+````CY$```<```";D0``!P```*.1```9````JY$``#T```#%D0``
M'0````.2```,````(9(``!`````ND@``!0```#^2```E````19(``!(```!K
MD@``$P```'Z2```K````DI(``#L```"^D@``(````/J2```(````&Y,``#8`
M```DDP``(0```%N3```0````?9,```@```".DP``#````)>3```$````I),`
M``\```"IDP``#@```+F3```*````R),```T```#3DP``'P```.&3```<````
M`90``"$````>E```'@```$"4```9````7Y0``!X```!YE```&P```)B4```A
M````M)0``"X```#6E```)@````65```<````+)4``!X```!)E0``'````&B5
M```F````A94``"L```"LE0``,P```-B5```F````#)8``"L````SE@``.```
M`%^6```=````F)8``!4```"VE@``+P```,R6```@````_)8``!(````=EP``
M*0```#"7```>````6I<``"````!YEP``$@```)J7``"B````K9<``!8```!0
MF```(P```&>8```H````BY@``"D```"TF```*````-Z8```?````!YD``!4`
M```GF0``(````#V9```E````7ID``"@```"$F0``+0```*V9```P````VYD`
M`)(````,F@``(0```)^:```6````P9H``!P```#8F@``)@```/6:```J````
M')L``$$```!'FP``!P```(F;```&````D9L``!````"8FP``$@```*F;```3
M````O)L``!(```#0FP``!P```..;```$````ZYL``!````#PFP``#`````&<
M```.````#IP```T````=G```*````"N<```#````5)P```T```!8G```!@``
M`&:<```.````;9P```(```!\G```!0```'^<```0````A9P```\```"6G```
M!````*:<```-````JYP```X```"YG```#@```,B<```(````UYP```\```#@
MG```#P```/"<```'`````)T```T````(G0``$````!:=```-````)YT```8`
M```UG0``"P```#R=```,````2)T```H```!5G0``$0```&"=```+````<IT`
M``T```!^G0``(@```(R=```/````KYT``!L```"_G0``-````-N=```*````
M$)X``!@````;G@``$@```#2>```9````1YX``!8```!AG@``(@```'B>```-
M````FYX```<```"IG@``%````+&>```+````QIX``"(```#2G@``+P```/6>
M```+````)9\``!<````QGP``%P```$F?```6````89\```\```!XGP``"```
M`(B?```-````D9\``"8```"?GP``0P```,:?```(````"J```!(````3H```
M'P```":@```(````1J````L```!/H```+P```%N@```&````BZ````<```"2
MH```!````)J@```*````GZ````H```"JH```#P```+6@```0````Q:```!<`
M``#6H```$0```.Z@```9`````*$``!<````:H0``!0```#*A```+````.*$`
M``4```!$H0``#0```$JA```;````6*$``!<```!TH0``#@```(RA```-````
MFZ$``!(```"IH0``.````+RA```@````]:$```X````6H@``>P```"6B```8
M````H:(``!$```"ZH@``!P```,RB```%````U*(``!@```#:H@``&P```/.B
M```9````#Z,``!L````IHP``&0```$6C```3````7Z,```<```!SHP``"```
M`'NC```&````A*,``!````"+HP``#P```)RC```0````K*,```\```"]HP``
M"P```,VC```/````V:,```P```#IHP``#P```/:C```'````!J0```8````.
MI```#@```!6D```,````)*0```\````QI```"````$&D```(````2J0``!,`
M``!3I```'@```&>D```A````AJ0``"````"HI```&0```,FD```7````XZ0`
M`"4```#[I```%P```"&E```6````.:4``!L```!0I0``#0```&RE```,````
M>J4```,```"'I0``!0```(NE```(````D:4```0```":I0``!````)^E```3
M````I*4``!0```"XI0``#````,VE```)````VJ4```X```#DI0``"P```/.E
M```;````_Z4```<````;I@``!P```".F```-````*Z8``!@````YI@``"@``
M`%*F```F````7:8``!4```"$I@``!0```)JF```&````H*8```(```"GI@``
M!@```*JF```&````L:8``!0```"XI@``#0```,VF```0````VZ8``!L```#L
MI@``$`````BG```)````&:<```D````CIP``!0```"VG```:````,Z<```@`
M``!.IP``!@```%>G```9````7J<```X```!XIP``!P```(>G```'````CZ<`
M``4```"7IP``"0```)VG```*````IZ<```X```"RIP``"P```,&G```-````
MS:<```8```#;IP``"0```.*G```'````[*<``!0```#TIP``'0````FH``!"
M````)Z@``"4```!JJ```)0```)"H```&````MJ@```H```"]J```!````,BH
M```)````S:@```@```#7J```$0```."H```)````\J@```8```#\J```#0``
M``.I```&````$:D``!X````8J0``!0```#>I```.````/:D```8```!,J0``
M!P```%.I```A````6ZD```8```!]J0``!````(2I```*````B:D```4```"4
MJ0``'0```)JI```$````N*D```P```"]J0``#@```,JI```*````V:D```@`
M``#DJ0``"0```.VI```%````]ZD``#H```#]J0``,````#BJ```U````::H`
M`"D```"?J@``1P```,FJ```X````$:L``"D```!*JP``/P```'2K```N````
MM*L``"T```#CJP``'P```!&L```/````,:P``"D```!!K```)````&NL```F
M````D*P```<```"WK```(````+^L```@````X*P``"8````!K0``"@```"BM
M```9````,ZT``"D```!-K0``%@```'>M```'````CJT```H```"6K0``#```
M`*&M```/````KJT``!````"^K0``0````,^M``!P````$*X```X```"!K@``
M"0```)"N```*````FJX```8```"EK@``#P```*RN```2````O*X``!````#/
MK@``'````."N```C````_:X``&H````AKP``#P```(RO```%````G*\``!``
M``"BKP``"0```+.O```$````O:\```L```#"KP``%````,ZO```,````XZ\`
M``P```#PKP``#P```/VO```5````#;```"D````CL```*@```$VP```F````
M>+```"<```"?L```*0```,>P```J````\;```!D````<L0``0@```#:Q```1
M````>;$``!(```"+L0``$P```)ZQ```4````LK$```\```#'L0``%@```->Q
M```7````[K$``!`````&L@``$0```!>R```T````*;(``!,```!>L@``$@``
M`'*R```U````A;(``!0```"[L@``$````-"R```4````X;(``!<```#VL@``
M'`````ZS```4````*[,``!H```!`LP``&@```%NS```3````=K,``!4```"*
MLP``$0```*"S```7````LK,``!0```#*LP``%P```-^S```5````][,``!``
M```-M```&0```!ZT```$````.+0```<````]M```"P```$6T```&````4;0`
M``8```!8M```!@```%^T```%````9K0```<```!LM```!P```'2T```%````
M?+0```8```""M```!@```(FT```$````D+0```0```"5M```!P```)JT```.
M````HK0```P```"QM```#````+ZT```-````R[0```H```#9M```#@```.2T
M```%````\[0``"@```#YM```#````"*U```/````+[4```H````_M0``"```
M`$JU```K````4[4```@```!_M0``)@```(BU```2````K[4```8```#"M0``
M"@```,FU```'````U+4```@```#<M0``(````.6U```,````!K8```X````3
MM@``%@```"*V```1````.;8```8```!+M@``!@```%*V```'````6;8```0`
M``!AM@``!P```&:V```'````;K8``!8```!VM@``#0```(VV```$````F[8`
M`#H```"@M@``#@```-NV```0````ZK8```L```#[M@``&P````>W```8````
M([<``!H````\MP``"0```%>W```*````8;<```P```!LMP``#P```'FW```(
M````B;<```8```"2MP``!P```)FW```%````H;<```L```"GMP``1P```+.W
M```-````^[<``!,````)N```$P```!VX```3````,;@```H```!%N````@``
M`%"X```E````4[@```4```!YN```*@```'^X```*````JK@```0```"UN```
M!@```+JX```(````P;@```@```#*N```!````-.X```%````V+@``&@```#>
MN```!0```$>Y```0````3;D```H```!>N0``#P```&FY```*````>;D```D`
M``"$N0```P```(ZY```'````DKD```<```":N0``"@```**Y```+````K;D`
M``<```"YN0``40```,&Y```&````$[H``!H````:N@``!@```#6Z```?````
M/+H```D```!<N@``(@```&:Z``!7````B;H``!,```#AN@``(P```/6Z```3
M````&;L```(````MNP``"P```#"[```-````/+L``!0```!*NP``!@```%^[
M```(````9KL```<```!ONP``"@```'>[```+````@KL```<```".NP``"0``
M`):[```)````H+L```H```"JNP``!P```+6[```)````O;L```<```#'NP``
M"@```,^[```*````VKL``!8```#ENP``!P```/R[```2````!+P```0````7
MO```!P```!R\```%````)+P```4````JO```"P```#"\```4````/+P```<`
M``!1O```!0```%F\```-````7[P```P```!MO```"````'J\```7````@[P`
M``L```";O```#````*>\```?````M+P``!H```#4O```!````.^\```*````
M]+P```0```#_O```#`````2]```%````$;T```D````7O0``!0```"&]```'
M````)[T```0````OO0``.````#2]```*````;;T``"P```!XO0``+@```*6]
M```S````U+T``#,````(O@``.````#R^```/````=;X``!@```"%O@``$```
M`)Z^```/````K[X``!4```"_O@``%````-6^```2````ZKX``!0```#]O@``
M+0```!*_```M````0+\``#$```!NOP``+@```*"_```O````S[\``"P```#_
MOP``8@```"S````3````C\````T```"CP```%P```+'````,````R<```"$`
M``#6P```&@```/C````)````$\$``$4````=P0``00```&/!```$````I<$`
M``X```"JP0``$P```+G!```8````S<$```8```#FP0``"0```.W!```*````
M]\$```\````"P@``$````!+"```.````(\(```4````RP@``"````#C"```&
M````0<(``!0```!(P@``$0```%W"```.````;\(``#@```!^P@```@```+?"
M```&````NL(```X```#!P@``!P```-#"```&````V,(```P```#?P@``'```
M`.S"```$````"<,``"D````.PP``'P```#C#``!<````6,,``!0```"UPP``
M/@```,K#```'````"<0```X````1Q```#````"#$```,````+<0``!,````Z
MQ```"@```$[$```=````6<0``!$```!WQ```$0```(G$```D````F\0``!4`
M``#`Q```$@```-;$```.````Z<0``!D```#XQ```"````!+%```)````&\4`
M`!H````EQ0``!P```$#%```(````2,4```4```!1Q0``'P```%?%```&````
M=\4``!````!^Q0``"````(_%```(````F,4``!X```"AQ0``$@```,#%```L
M````T\4``!H`````Q@``"0```!O&```*````)<8``!4````PQ@``!0```$;&
M```4````3,8```0```!AQ@``$````&;&```'````=\8``!X```!_Q@``*```
M`)[&```*````Q\8``!P```#2Q@``$0```._&```+`````<<``!H````-QP``
M%````"C'```$````/<<```L```!"QP``!0```$['```(````5,<```8```!=
MQP``(````&3'```I````A<<``$$```"OQP``*````/''```I````&L@``%``
M``!$R```!@```)7(```%````G,@```@```"BR```+@```*O(```T````VL@`
M``<````/R0``(0```!?)```0````.<D```X```!*R0``"P```%G)```'````
M9<D``!,```!MR0``"@```(')```4````C,D```\```"AR0``,@```+')```+
M````Y,D```X```#PR0``!0```/_)```%````!<H```4````+R@``%P```!'*
M```%````*<H```0````OR@``,@```#3*``!%````9\H``!<```"MR@``'@``
M`,7*```4````Y,H```8```#YR@``#@````#+```J````#\L```8````ZRP``
M#````$'+```1````3LL```L```!@RP``-@```&S+```*````H\L``"(```"N
MRP``"P```-'+```/````W<L``#(```#MRP``,````"#,```Q````4<P``"T`
M``"#S```!0```+',```.````M\P``!,```#&S```!P```-K,```1````XLP`
M`!,```#TS```%`````C-```8````'<T```4````VS0``!````#S-```'````
M0<T```H```!)S0``"P```%3-```,````8,T```X```!MS0``#@```'S-```%
M````B\T```4```"1S0``+@```)?-```F````QLT``",```#MS0```P```!'.
M```2````%<X```8````HS@``'@```"_.```8````3LX``"4```!GS@``"0``
M`(W.```#````E\X```<```";S@```@```*/.```,````ILX``!4```"SS@``
M"P```,G.```9````U<X``"````#OS@``!0```!#/```*````%L\``!4````A
MSP``#````#?/```$````1,\```D```!)SP``!P```%//```,````6\\``%(`
M``!HSP``%P```+O/```D````T\\```8```#XSP``#@```/_/```,````#M``
M``T````;T```%0```"G0```2````/]````\```!2T```%````&+0```*````
M=]```&D```""T```&@```.S0```7````!]$``"<````?T0``&@```$?1```7
M````8M$``!L```!ZT0``&0```);1```?````L-$``!,```#0T0``"````.31
M```'````[=$```D```#UT0``%0```/_1```-````%=(```T````CT@``"```
M`#'2``!&````.M(``#\```"!T@``-P```,'2``!7````^=(```4```!1TP``
M'P```%?3```*````=],```T```""TP``+0```)#3```$````OM,``$\```##
MTP``)0```!/4```?````.=0``!T```!9U```)0```'?4```@````G=0``"0`
M``"^U```(````./4```&````!-4``#D````+U0``#````$75```'````4M4`
M``D```!:U0``$P```&35```)````>-4```0```""U0``$````(?5```(````
MF-4```@```"AU0``#P```*K5```'````NM4``!0```#"U0``#@```-?5```,
M````YM4``"P```#SU0``$P```"#6```<````--8``"@```!1U@``!P```'K6
M```3````@M8```4```"6U@``%P```)S6```*````M-8```P```"_U@``"0``
M`,S6```)````UM8``!$```#@U@``!@```/+6```.````^=8```T````(UP``
M"P```!;7```"````(M<``!P````EUP``!@```$+7```)````2=<```<```!3
MUP``)@```%O7```X````@M<``!H```"[UP``*@```-;7```[`````=@``"@`
M```]V```-````&;8```9````F]@``!4```"UV```!0```,O8```'````T=@`
M``@```#9V```!P```.+8```.````ZM@```D```#YV```!@````/9```(````
M"MD```L````3V0``!P```!_9```(````)]D```<````PV0``%@```#C9```)
M````3]D```8```!9V0``"P```&#9```4````;-D```@```"!V0``$````(K9
M```0````F]D```8```"LV0``&0```+/9```*````S=D``!P```#8V0``!0``
M`/79```0````^]D``!@````,V@``%P```"7:```)````/=H```H```!'V@``
M!P```%+:```"````6MH```@```!=V@``(P```&;:```?````BMH``#$```"J
MV@``)P```-S:``!D````!-L``%4```!IVP``.````+_;``!*````^-L``%L`
M``!#W```*````)_<```X````R-P``"@````!W0``+````"K=```F````5]T`
M`!L```!^W0``/@```)K=``"I`0``V=T``",```"#WP``2````*??```E````
M\-\``$$````6X```6P```%C@``!)````M.```#$```#^X```*P```##A```A
M````7.$``!\```!^X0``)@```)[A```G````Q>$``#,```#MX0``)0```"'B
M```@````1^(``!\```!HX@``,````(CB``!I````N>(``#$````CXP``00``
M`%7C```S````E^,``"4```#+XP``/0```/'C``!E````+^0``$T```"5Y```
M+P```./D```N````$^4``#````!"Y0``5````'/E``!:````R.4``$@````C
MY@``2@```&SF```R````M^8``"\```#JY@``+````!KG```M````1^<``!<`
M``!UYP``)0```(WG```R````L^<``"D```#FYP``/@```!#H```B````3^@`
M`%(```!RZ```)0```,7H``!%````Z^@``"$````QZ0``,````%/I```E````
MA.D``!P```"JZ0``,0```,?I```$````^>D```T```#^Z0``"P````SJ```+
M````&.H```4````DZ@``60```"KJ```2````A.H```0```"7Z@``!P```)SJ
M```%````I.H``#````"JZ@``$P```-OJ```"````[^H```<```#RZ@``!@``
M`/KJ```,`````>L``!@````.ZP``!@```"?K```2````+NL```,```!!ZP``
M!@```$7K```'````3.L``!\```!4ZP``+@```'3K```O````H^L``!<```#3
MZP``(@```.OK```E````#NP``"`````T[```&P```%7L```8````<>P``"0`
M``"*[```'P```*_L```:````S^P``"$```#J[```(`````SM```:````+>T`
M`#(```!([0``&@```'OM```O````ENT``"L```#&[0``'P```/+M```C````
M$NX``!\````V[@``&@```%;N```A````<>X``"4```"3[@``)@```+GN```E
M````X.X``"0````&[P``&````"OO```=````1.\``"0```!B[P``&````(?O
M```B````H.\``"P```##[P``+P```/#O```5````(/```"4````V\```/```
M`%SP```?````F?```",```"Y\```'P```-WP```@````_?```!H````>\0``
M)@```#GQ```>````8/$``"D```!_\0``'@```*GQ```Q````R/$```D```#Z
M\0``#`````3R```7````$?(``"\````I\@``)````%GR```'````?O(``!0`
M``"&\@``#@```)OR```-````JO(``"0```"X\@``!P```-WR```=````Y?(`
M``<````#\P``QP````OS```5````T_,```8```#I\P``"0```/#S```+````
M^O,```T````&]```%P```!3T```&````+/0``#,````S]```$P```&?T```3
M````>_0```<```"/]```#P```)?T```'````I_0``#(```"O]```!````.+T
M```A````Y_0``!,````)]0``#````!WU```1````*O4``#(````\]0``%@``
M`&_U```(````AO4``!T```"/]0``"0```*WU```*````M_4``!0```#"]0``
M"@```-?U```(````XO4```@```#K]0``!P```/3U```)````_/4``#\````&
M]@``!P```$;V```/````3O8```X```!>]@``"````&WV```'````=O8``!D`
M``!^]@``%P```)CV```4````L/8``!$```#%]@``!P```-?V```"````W_8`
M``8```#B]@``!P```.GV```-````\?8```L```#_]@``#@````OW```O````
M&O<``"````!*]P``'````&OW```Q````B/<```4```"Z]P``/P```,#W```2
M`````/@```H````3^```!@```![X```(````)?@```P````N^```"@```#OX
M```Y````1O@``"X```"`^```*0```*_X```8````V?@``!D```#R^```'P``
M``SY```=````+/D``!$```!*^0```@```%SY```$````7_D```8```!D^0``
M!0```&OY```#````<?D```P```!U^0``10```(+Y```R````R/D``!H```#[
M^0``-````!;Z```H````2_H``%,```!T^@``&0```,CZ``!R````XOH``"``
M``!5^P``-0```';[```A````K/L``$4```#.^P``,````!3\```H````1?P`
M`"D```!N_```)@```)C\```E````O_P``"@```#E_```*`````[]```B````
M-_T``#````!:_0``$@```(O]```3````GOT``!````"R_0``>0```,/]```)
M````/?X``*$```!'_@``<P```.G^``!\````7?\``"L```#:_P``5`````8`
M`0`7````6P`!`"<```!S``$`%@```)L``0`/````L@`!`!<```#"``$`'P``
M`-H``0!`````^@`!`!\````[`0$`'````%L!`0!1````>`$!`!H```#*`0$`
M%````.4!`0`*````^@$!``4````%`@$`!@````L"`0`(````$@(!`!`````;
M`@$`#P```"P"`0`/````/`(!``L```!,`@$`!P```%@"`0`%````8`(!`!0`
M``!F`@$`!P```'L"`0`(````@P(!``\```",`@$`"````)P"`0`,````I0(!
M``\```"R`@$`!@```,("`0`4````R0(!``8```#>`@$`#````.4"`0`1````
M\@(!``@````$`P$`&0````T#`0`1````)P,!``H````Y`P$`&````$0#`0`3
M````70,!`!P```!Q`P$`$0```(X#`0`$````H`,!``\```"E`P$`!````+4#
M`0`1````N@,!`!(```#,`P$`%P```-\#`0`$````]P,!``\```#\`P$`$P``
M``P$`0`'````(`0!``<````H!`$`$0```#`$`0`&````0@0!`!@```!)!`$`
M$P```&($`0`0````=@0!``P```"'!`$`"0```)0$`0`1````G@0!`"(```"P
M!`$`!P```-,$`0`%````VP0!`#H!``#A!`$`"@```!P&`0`/````)P8!``\`
M```W!@$`!P```$<&`0`(````3P8!``<```!8!@$`)0```&`&`0`A````A@8!
M`"T```"H!@$`)0```-8&`0`I````_`8!`"H````F!P$`(````%$'`0`J````
M<@<!``L```"=!P$`(````*D'`0`)````R@<!``L```#4!P$`!0```.`'`0`1
M````Y@<!``D```#X!P$`#P````((`0`+````$@@!`!4````>"`$`:P```#0(
M`0`-````H`@!``4```"N"`$`$0```+0(`0`3````Q@@!``\```#:"`$`"P``
M`.H(`0`+````]@@!`!$````""0$`!@```!0)`0"2````&PD!``H```"N"0$`
M"@```+D)`0`*````Q`D!``<```#/"0$`"P```-<)`0`H````XPD!`!P````,
M"@$`*0```"D*`0`Q````4PH!`$H```"%"@$`1````-`*`0!0````%0L!`$H`
M``!F"P$`+````+$+`0`%````W@L!`!8```#D"P$`+P```/L+`0`K````*PP!
M``X```!7#`$`%@```&8,`0`>````?0P!``H```"<#`$`!````*<,`0`2````
MK`P!`!0```"_#`$`"P```-0,`0`4````X`P!`!@```#U#`$`&@````X-`0`<
M````*0T!`!(```!&#0$`"````%D-`0`2````8@T!``H```!U#0$`+````(`-
M`0`1````K0T!`!8```"_#0$`#````-8-`0!.````XPT!`#8````R#@$`)@``
M`&D.`0`$````D`X!``H```"5#@$`'0```*`.`0`$````O@X!``,```###@$`
M#@```,<.`0`*````U@X!``P```#A#@$`!````.X.`0`*````\PX!``0```#^
M#@$`#`````,/`0`.````$`\!`!`````?#P$`%````#`/`0`J````10\!``X`
M``!P#P$`%````'\/`0`6````E`\!`!0```"K#P$`%````,`/`0`2````U0\!
M``X```#H#P$`$````/</`0`:````"!`!`!X````C$`$`"````$(0`0`.````
M2Q`!``H```!:$`$`#@```&40`0`$````=!`!``P```!Y$`$`&````(80`0`0
M````GQ`!`!0```"P$`$`%@```,40`0`0````W!`!``0```#M$`$`$````/(0
M`0`$`````Q$!`!@````($0$`#````"$1`0`Q````+A$!`#,```!@$0$`$@``
M`)01`0`0````IQ$!``8```"X$0$`#@```+\1`0`2````SA$!`"X```#A$0$`
M*@```!`2`0`L````.Q(!`"P```!H$@$`)@```)42`0`$````O!(!``0```#!
M$@$`#@```,82`0`2````U1(!`#$```#H$@$`-@```!H3`0`N````41,!`&H`
M``"`$P$`*0```.L3`0`I````%10!`$(````_%`$`0@```((4`0`I````Q10!
M`#4```#O%`$`)0```"45`0`E````2Q4!`$(```!Q%0$`*0```+05`0`O````
MWA4!`"(````.%@$`$@```#$6`0`6````1!8!`"@```!;%@$`'P```(06`0`?
M````I!8!`!8```#$%@$`%@```-L6`0`$````\A8!``8```#W%@$`(````/X6
M`0`>````'Q<!``8````^%P$`"@```$47`0`8````4!<!``H```!I%P$`-```
M`'07`0`&````J1<!`!````"P%P$`"````,$7`0`(````RA<!``P```#3%P$`
M$@```.`7`0`,````\Q<!``8`````&`$`-`````<8`0`,````/!@!``X```!)
M&`$`!````%@8`0`.````71@!``P```!L&`$``@```'D8`0`*````?!@!``(`
M``"'&`$`&````(H8`0`.````HQ@!``@```"R&`$`"````+L8`0`.````Q!@!
M`!8```#3&`$`"@```.H8`0`(````]1@!``X```#^&`$`#@````T9`0`#````
M'!D!``,````@&0$`$````"09`0`-````-1D!`"@```!#&0$`!@```&P9`0`*
M````<QD!`!````!^&0$`0````(\9`0`<````T!D!`"P```#M&0$`)0```!H:
M`0`<````0!H!``8```!=&@$`"@```&0:`0`8````;QH!`"````"(&@$`(@``
M`*D:`0`O````S!H!`"8```#\&@$`)@```",;`0!(````2AL!`#(```"3&P$`
M$@```,8;`0`$````V1L!``@```#>&P$`#````.<;`0`,````]!L!``@````!
M'`$`"`````H<`0`*````$QP!``@````>'`$`"@```"<<`0`(````,AP!``0`
M```['`$`$@```$`<`0`,````4QP!``X```!@'`$`#@```&\<`0`,````?AP!
M``0```"+'`$`$````)`<`0`P````H1P!`$X```#2'`$`%0```"$=`0`*````
M-QT!``X```!"'0$`%@```%$=`0`0````:!T!``X```!Y'0$`#@```(@=`0`,
M````EQT!`"````"D'0$`&0```,4=`0`(````WQT!`!````#H'0$`"@```/D=
M`0`0````!!X!`!(````5'@$`$@```"@>`0`*````.QX!`!````!&'@$`$```
M`%<>`0`"````:!X!``8```!K'@$`!@```'(>`0`$````>1X!``H```!^'@$`
M"@```(D>`0`(````E!X!``X```"='@$`"````*P>`0`&````M1X!``H```"\
M'@$`!````,<>`0`*````S!X!`#(```#7'@$`&`````H?`0`-````(Q\!`!``
M```Q'P$`#````$(?`0`0````3Q\!``H```!@'P$`"@```&L?`0`F````=A\!
M`#,```"='P$`(0```-$?`0`&````\Q\!`"0```#Z'P$`(````!\@`0`+````
M0"`!``0```!,(`$`"@```%$@`0`&````7"`!``X```!C(`$`$````'(@`0`0
M````@R`!`!8```"4(`$`*P```*L@`0`I````UR`!`"X````!(0$`+````#`A
M`0`@````72$!`"<```!^(0$`'@```*8A`0`C````Q2$!`"P```#I(0$`)@``
M`!8B`0`E````/2(!`"D```!C(@$`(````(TB`0`F````KB(!`#(```#5(@$`
M,@````@C`0`J````.R,!`"P```!F(P$`+````),C`0`L````P",!`!L```#M
M(P$`*@````DD`0`M````-"0!`!\```!B)`$`*@```((D`0`H````K20!`!T`
M``#6)`$`%0```/0D`0",````"B4!`!H```"7)0$`)````+(E`0`F````UR4!
M`"8```#^)0$`)@```"4F`0`<````3"8!`"4```!I)@$`'P```(\F`0`J````
MKR8!`"P```#:)@$`-`````<G`0`V````/"<!`'T```!S)P$`'0```/$G`0`E
M````#R@!`"`````U*`$`)@```%8H`0`?````?2@!`$````"=*`$``@```-XH
M`0`$````X2@!``@```#F*`$`$@```.\H`0`2`````BD!`!0````5*0$`$```
M`"HI`0`.````.RD!`!````!**0$`"@```%LI`0`-````9BD!``X```!T*0$`
M+P```(,I`0`(````LRD!`!(```"\*0$`#@```,\I`0`,````WBD!``(```#K
M*0$`!````.XI`0`-````\RD!`!`````!*@$`!````!(J`0`*````%RH!``@`
M```B*@$`"@```"LJ`0`$````-BH!``8````[*@$`#````$(J`0`*````3RH!
M``P```!:*@$`#0```&<J`0`0````=2H!``0```"&*@$`"````(LJ`0`.````
ME"H!``H```"C*@$`$````*XJ`0`(````ORH!``@```#(*@$`%@```-$J`0`0
M````Z"H!`!<```#Y*@$`.0```!$K`0`(````2RL!`!````!4*P$`$@```&4K
M`0`2````>"L!`!(```"+*P$`*@```)XK`0`(````R2L!``H```#2*P$`#@``
M`-TK`0`$````["L!`",```#Q*P$`)````!4L`0`$````.BP!``H````_+`$`
M"@```$HL`0`*````52P!``X```!@+`$`#````&\L`0`*````?"P!`"X```"'
M+`$`1@```+8L`0`(````_2P!``X````&+0$`(@```!4M`0`,````."T!`!$`
M``!%+0$`.0```%<M`0`*````D2T!`!````"<+0$`!````*TM`0`.````LBT!
M``X```#!+0$`$````-`M`0`0````X2T!`!4```#R+0$`$@````@N`0`7````
M&RX!`!4````S+@$`%@```$DN`0`4````8"X!``H```!U+@$`#P```(`N`0`K
M````D"X!`!,```"\+@$`$@```-`N`0`4````XRX!``H```#X+@$`+@````,O
M`0`D````,B\!`!8```!7+P$`6@```&XO`0`/````R2\!`!````#9+P$`"@``
M`.HO`0`&````]2\!`!<```#\+P$`&0```!0P`0`3````+C`!`!D```!",`$`
M'````%PP`0`;````>3`!`!````"5,`$`"@```*8P`0`*````L3`!``8```"\
M,`$`!0```,,P`0`&````R3`!``4```#0,`$`"@```-8P`0`&````X3`!``4`
M``#H,`$`"@```.XP`0`$````^3`!``0```#^,`$`$`````,Q`0`*````%#$!
M``@````?,0$`!````"@Q`0`&````+3$!`!T````T,0$`)````%(Q`0`C````
M=S$!`"(```";,0$`(0```+XQ`0`?````X#$!`"``````,@$`'0```"$R`0`6
M````/S(!`"0```!6,@$`#````'LR`0`.````B#(!``,```"7,@$``P```)LR
M`0`$````GS(!`!(```"D,@$`"````+<R`0`7````P#(!`!<```#8,@$`$@``
M`/`R`0`*`````S,!``P````.,P$`%````!LS`0`N````,#,!``@```!?,P$`
M$@```&@S`0`(````>S,!`!H```"$,P$`!@```)\S`0`>````IC,!`"(```#%
M,P$`"````.@S`0`*````\3,!``(```#\,P$``@```/\S`0`.`````C0!`!``
M```1-`$`$````"(T`0`4````,S0!`!(```!(-`$`"@```%LT`0`$````9C0!
M``0```!K-`$`#````'`T`0`8````?30!``P```"6-`$`#@```*,T`0`5````
MLC0!`!````#(-`$`#@```-DT`0`0````Z#0!``P```#Y-`$`#`````8U`0`"
M````$S4!``X````6-0$`#0```"4U`0`+````,S4!``X````_-0$`#@```$XU
M`0`(````734!``P```!F-0$`'````',U`0`X````D#4!`"@```#)-0$`*```
M`/(U`0`(````&S8!``X````D-@$`"````#,V`0`0````/#8!``P```!--@$`
M$````%HV`0`,````:S8!``P```!X-@$`$@```(4V`0`2````F#8!`!L```"K
M-@$`#````,<V`0`4````U#8!``8```#I-@$`!@```/`V`0`8````]S8!``0`
M```0-P$`!@```!4W`0`$````'#<!``8````A-P$`'````"@W`0`&````13<!
M``H```!,-P$`%````%<W`0`.````;#<!`!(```![-P$`!````(XW`0`%````
MDS<!`$(```"9-P$`/0```-PW`0`]````&C@!`"4```!8.`$`*0```'XX`0`Z
M````J#@!`"D```#C.`$`*P````TY`0`I````.3D!`!\```!C.0$`(@```(,Y
M`0`&````ICD!`!H```"M.0$`(@```,@Y`0`:````ZSD!`!`````&.@$`*P``
M`!<Z`0`K````0SH!`#,```!O.@$`"P```*,Z`0`9````KSH!`#(```#).@$`
M$````/PZ`0`2````#3L!``P````@.P$`#0```"T[`0`2````.SL!``@```!.
M.P$`10```%<[`0!9````G3L!``X```#W.P$`"`````8\`0`)````#SP!``0`
M```9/`$`%P```!X\`0`?````-CP!`!P```!6/`$`+````',\`0`H````H#P!
M`%0```#)/`$`#````!X]`0`&````*ST!``H````R/0$`$@```#T]`0`$````
M4#T!`!(```!5/0$`$````&@]`0`*````>3T!``@```"$/0$`#````(T]`0`.
M````FCT!`!@```"I/0$`%@```,(]`0`8````V3T!`!8```#R/0$`&@````D^
M`0`8````)#X!`!8````]/@$`,````%0^`0`0````A3X!``X```"6/@$`#@``
M`*4^`0`.````M#X!`!````##/@$`$````-0^`0`.````Y3X!``X```#T/@$`
M#`````,_`0`>````$#\!`!`````O/P$`$@```$`_`0`H````4S\!`!````!\
M/P$`%P```(T_`0`<````I3\!`!T```#"/P$`'````.`_`0`:````_3\!`!P`
M```80`$`'````#5``0`8````4D`!`!8```!K0`$`%@```()``0`6````F4`!
M`!8```"P0`$`&@```,=``0`9````XD`!``H```#\0`$`%@````=!`0`,````
M'D$!``P````K00$`!@```#A!`0`*````/T$!``8```!*00$`!````%%!`0`.
M````5D$!``H```!E00$`!````'!!`0`$````=4$!``P```!Z00$`"````(=!
M`0`$````D$$!``0```"500$`!@```)I!`0`(````H4$!``@```"J00$`!@``
M`+-!`0`&````ND$!`!(```#!00$`$@```-1!`0`,````YT$!`",```#T00$`
M"````!A"`0`&````(4(!``0````H0@$`!@```"U"`0`H````-$(!``X```!=
M0@$`%@```&Q"`0`(````@T(!``H```",0@$`#@```)="`0`,````ID(!``0`
M``"S0@$`%````+A"`0`(````S4(!`!(```#60@$`'@```.E"`0`4````"$,!
M``X````=0P$`!````"Q#`0`.````,4,!``(```!`0P$`"@```$-#`0`.````
M3D,!`"P```!=0P$`%@```(I#`0`&````H4,!`"@```"H0P$`$````-%#`0`4
M````XD,!``@```#W0P$`'@````!$`0`:````'T0!`"0````Z1`$`$````%]$
M`0`+````<$0!``H```!\1`$`"@```(=$`0`$````DD0!``@```"71`$`"@``
M`*!$`0`(````JT0!``\```"T1`$`/@```,1$`0`8`````T4!`!8````<10$`
M%````#-%`0`4````2$4!`!0```!=10$``@```')%`0`M````=44!``8```"C
M10$`(````*I%`0`2````RT4!``H```#>10$`#@```.E%`0`*````^$4!`!``
M```#1@$`"@```!1&`0`,````'T8!`#`````L1@$`!````%U&`0`4````8D8!
M``X```!W1@$`'````(9&`0`<````HT8!`!(```#`1@$`!````--&`0`,````
MV$8!``8```#E1@$`#@```.Q&`0`(````^T8!``0````$1P$`0@````E'`0`(
M````3$<!`"````!51P$`#@```'9'`0`0````A4<!``D```"61P$`,0```*!'
M`0!8````TD<!`"`````K2`$`*0```$Q(`0`@````=D@!``(```"72`$`"@``
M`)I(`0`&````I4@!``X```"L2`$`"@```+M(`0`(````QD@!``0```#/2`$`
M#@```-1(`0`$````XT@!``P```#H2`$`!````/5(`0`$````^D@!``0```#_
M2`$`!`````1)`0`$````"4D!``0````.20$`$@```!-)`0`*````)DD!``X`
M```Q20$`#@```$!)`0`,````3TD!``0```!<20$`#@```&%)`0`,````<$D!
M``P```!]20$`#````(I)`0`8````ETD!``P```"P20$`!````+U)`0`:````
MPDD!``@```#=20$`!````.9)`0`4````ZTD!`!``````2@$`$````!%*`0`L
M````(DH!`"````!/2@$`"````'!*`0`0````>4H!``(```"*2@$`#@```(U*
M`0`+````G$H!`!````"H2@$`$````+E*`0`6````RDH!``@```#A2@$`)@``
M`.I*`0`*````$4L!`#(````<2P$`(P```$]+`0`H````<TL!`"@```"<2P$`
M+````,5+`0`2````\DL!`!P````%3`$`)````"),`0`6````1TP!`!H```!>
M3`$`(````'E,`0`:````FDP!`!H```"U3`$`(P```-!,`0`C````]$P!`"<`
M```830$`)P```$!-`0`E````:$T!`"@```".30$`70```+=-`0`8````%4X!
M`!X````N3@$`(````$U.`0`0````;DX!`"H```!_3@$`&P```*I.`0`&````
MQDX!`$8```#-3@$`1@```!1/`0`$````6T\!``X```!@3P$`!@```&]/`0`.
M````=D\!``X```"%3P$`"@```)1/`0`*````GT\!`!H```"J3P$`%````,5/
M`0`8````VD\!``0```#S3P$`!````/A/`0`"````_4\!``8`````4`$`!```
M``=0`0`$````#%`!`#0````14`$``@```$90`0`,````25`!`!(```!64`$`
M!````&E0`0`(````;E`!``X```!W4`$`(````(90`0`(````IU`!`#(```"P
M4`$`*0```.-0`0!"````#5$!`!0```!040$`20```&51`0`*````KU$!``T`
M``"Z40$`#@```,A1`0`$````UU$!``0```#<40$`!````.%1`0`@````YE$!
M`!8````'4@$`$@```!Y2`0`:````,5(!``P```!,4@$`"@```%E2`0`*````
M9%(!`!<```!O4@$`"0```(=2`0`)````D5(!`!H```";4@$`!````+92`0`:
M````NU(!``P```#64@$`$````.-2`0`,````]%(!`!@````!4P$`$````!I3
M`0`*````*U,!`"(````V4P$`'````%E3`0`C````=E,!`!````":4P$`"P``
M`*M3`0`,````MU,!`!H```#$4P$`"````-]3`0`:````Z%,!``0````#5`$`
M%@````A4`0`*````'U0!`!(````J5`$`)````#U4`0`*````8E0!`"@```!M
M5`$`&````)94`0`*````KU0!`!````"Z5`$`"````,M4`0`,````U%0!`!``
M``#A5`$`!````/)4`0`,````]U0!``@````$50$`&@````U5`0`A````*%4!
M`#X```!*50$`(@```(E5`0`H````K%4!`%@```#550$`$````"Y6`0`&````
M/U8!`!````!&5@$`,````%=6`0`S````B%8!``H```"\5@$`'````,=6`0`.
M````Y%8!``0```#S5@$`!@```/A6`0`$````_U8!``X````$5P$`!@```!-7
M`0`2````&E<!``H````M5P$`)0```#A7`0`,````7E<!`!(```!K5P$`"```
M`'Y7`0`(````AU<!``@```"05P$`$P```)E7`0`"````K5<!``0```"P5P$`
M-````+57`0!#````ZE<!`!0````N6`$`&0```$-8`0`0````75@!``@```!N
M6`$`$````'=8`0`L````B%@!``0```"U6`$`#@```+I8`0`*````R5@!``H`
M``#46`$`,@```-]8`0`&````$ED!`"`````960$`#````#I9`0`0````1UD!
M`!8```!860$`,@```&]9`0`Q````HED!`"P```#460$`"`````%:`0`4````
M"EH!`!P````?6@$`!````#Q:`0`0````05H!`!(```!26@$`#@```&5:`0`>
M````=%H!``(```"36@$`!````)9:`0`*````FUH!``D```"F6@$`"````+!:
M`0`(````N5H!``8```#"6@$`!@```,E:`0`$````T%H!``0```#56@$`'```
M`-I:`0`2````]UH!`!(````*6P$`!````!U;`0`*````(EL!``@````M6P$`
M#P```#9;`0`-````1EL!`!L```!46P$`"@```'!;`0`#````>UL!``0```!_
M6P$``@```(1;`0`.````AUL!`!@```"66P$`#````*];`0`8````O%L!`"@`
M``#56P$`#````/Y;`0`0````"UP!`!X````<7`$`$@```#M<`0`$````3EP!
M``L```!37`$`"0```%]<`0`0````:5P!`$D```!Z7`$`%P```,1<`0`J````
MW%P!``0````'70$`#`````Q=`0`.````&5T!`!@````H70$`(@```$%=`0`>
M````9%T!`!@```"#70$`(````)Q=`0`(````O5T!`%(```#&70$`)````!E>
M`0`>````/EX!`!,```!=7@$`)````'%>`0`>````EEX!`"H```"U7@$`%P``
M`.!>`0`7````^%X!`!8````07P$`"````"=?`0`.````,%\!``0````_7P$`
M%@```$1?`0`$````6U\!``X```!@7P$`"@```&]?`0`V````>E\!`#(```"Q
M7P$`(````.1?`0!7````!6`!``0```!=8`$`$@```&)@`0`0````=6`!``P`
M``"&8`$`/````)-@`0`$````T&`!`#0```#58`$`+@````IA`0`>````.6$!
M`"0```!880$`'````'UA`0`6````FF$!`!H```"Q80$`&@```,QA`0`$````
MYV$!`#(```#L80$`$@```!]B`0`,````,F(!``@````_8@$`%````$AB`0`2
M````76(!``8```!P8@$`$@```'=B`0`0````BF(!`!````";8@$`#````*QB
M`0`2````N6(!``P```#,8@$`#@```-EB`0`0````Z&(!`"(```#Y8@$`!@``
M`!QC`0`0````(V,!`!(````T8P$`!````$=C`0`*````3&,!``@```!78P$`
M#@```&!C`0`(````;V,!``8```!X8P$`!@```']C`0`<````AF,!``H```"C
M8P$`!````*YC`0`(````LV,!``@```"\8P$`#@```,5C`0`"````U&,!`"0`
M``#78P$`!````/QC`0`&`````60!``0````(9`$`(0````UD`0`C````+V0!
M`!<```!39`$`(P```&MD`0`T````CV0!`"H```#$9`$`-@```.]D`0`;````
M)F4!`!L```!"90$`#@```%YE`0`$````;64!``8```!R90$`"````'EE`0`/
M````@F4!``@```"290$`!````)ME`0`&````H&4!``8```"G90$`"````*YE
M`0`.````MV4!``(```#&90$`(````,EE`0`0````ZF4!`!````#[90$`"@``
M``QF`0`4````%V8!``L````L9@$`!@```#AF`0`&````/V8!``0```!&9@$`
M$@```$MF`0`2````7F8!`!0```!Q9@$`!@```(9F`0`(````C68!`"````"6
M9@$`$@```+=F`0`,````RF8!``@```#79@$`"````.!F`0`"````Z68!``@`
M``#L9@$`%@```/5F`0`B````#&<!`#(````O9P$`+@```&)G`0!,````D6<!
M`%P```#>9P$`+````#MH`0`\````:&@!`%P```"E:`$`)`````)I`0`F````
M)VD!`"8```!.:0$`)@```'5I`0`F````G&D!`"(```##:0$`+````.9I`0#C
M````$VH!`!H```#W:@$`1P```!)K`0`J````6FL!`#@```"%:P$`1P```+YK
M`0!*````!FP!`"0```!1;`$`)@```'9L`0`>````G6P!`!X```"\;`$`'@``
M`-ML`0`@````^FP!`#(````;;0$`*@```$YM`0`H````>6T!`"(```"B;0$`
M)@```,5M`0!>````[&T!`"\```!+;@$`/0```'MN`0`N````N6X!`"4```#H
M;@$`2P````YO`0!?````6F\!`$\```"Z;P$`*`````IP`0`R````,W`!`"\`
M``!F<`$`3````)9P`0!.````XW`!`$8````R<0$`1@```'EQ`0`V````P'$!
M`"T```#W<0$`*P```"5R`0`H````47(!`!H```!Z<@$`*@```)5R`0`R````
MP'(!`"L```#S<@$`3@```!]S`0`J````;G,!`$8```"9<P$`)````.!S`0!,
M````!70!`"D```!2=`$`,0```'QT`0`J````KG0!`"(```#9=`$`0@```/QT
M`0`$````/W4!``P```!$=0$`"````%%U`0`6````6G4!``@```!Q=0$`6P``
M`'IU`0`2````UG4!``P```#I=0$`#````/9U`0`*`````W8!`"P````.=@$`
M&@```#MV`0`"````5G8!`!````!9=@$`#````&IV`0`0````=W8!`!8```"(
M=@$`!@```)]V`0`&````IG8!``,```"M=@$`#@```+%V`0`*````P'8!`"8`
M``#+=@$`,````/)V`0`Q````(W<!`!4```!5=P$`*@```&MW`0`O````EG<!
M`!P```#&=P$`%@```.-W`0`@````^G<!`"@````;>`$`(@```$1X`0`>````
M9W@!`"@```"&>`$`(P```*]X`0`8````TW@!`#8```#L>`$`&0```"-Y`0`T
M````/7D!`"H```!R>0$`(@```)UY`0`D````P'D!`"0```#E>0$`'@````IZ
M`0`H````*7H!`"````!2>@$`)@```'-Z`0`<````FGH!`!T```"W>@$`'@``
M`-5Z`0`@````]'H!`"8````5>P$`&@```#Q[`0`>````5WL!`"\```!V>P$`
M,@```*9[`0`:````V7L!`"(```#T>P$`.@```!=\`0`J````4GP!`"P```!]
M?`$`*@```*I\`0`K````U7P!`"0````!?0$`(````"9]`0`@````1WT!`"@`
M``!H?0$`&@```)%]`0`T````K'T!``0```#A?0$`#@```.9]`0`4````]7T!
M`"8````*?@$`'@```#%^`0`&````4'X!`!````!7?@$`!````&A^`0`$````
M;7X!``X```!R?@$`!````(%^`0`@````AGX!``0```"G?@$`O````*Q^`0`<
M````:7\!``0```"&?P$`#P```(M_`0`0````FW\!`!4```"L?P$`'@```,)_
M`0`,````X7\!`$0```#N?P$`%````#.``0`4````2(`!`!0```!=@`$`$@``
M`'*``0`*````A8`!`#L```"0@`$`!@```,R``0`F````TX`!``H```#Z@`$`
M$`````6!`0`*````%H$!`"X````A@0$`(@```%"!`0`(````<X$!`!X```!\
M@0$`"0```)N!`0`*````I8$!`!0```"P@0$`%````,6!`0`$````VH$!``8`
M``#?@0$`#@```.:!`0`:````]8$!`#,````0@@$``@```$2"`0`.````1X(!
M``8```!6@@$`%@```%V"`0`)````=((!`!<```!^@@$`$````):"`0`0````
MIX(!`!@```"X@@$`!````-&"`0`"````UH(!``0```#9@@$`"````-Z"`0`-
M````YX(!`!$```#U@@$`"`````>#`0`P````$(,!`!8```!!@P$`%````%B#
M`0`L````;8,!``(```":@P$`,0```)V#`0`&````SX,!``@```#6@P$`!```
M`-^#`0`.````Y(,!``P```#S@P$`$`````"$`0`Y````$80!`#````!+A`$`
M/P```'R$`0`/````O(0!``\```#,A`$`$P```-R$`0`7````\(0!``\````(
MA0$``@```!B%`0`"````&X4!``0````>A0$`#@```".%`0`$````,H4!``H`
M```WA0$`/0```$*%`0`U````@(4!`!P```"VA0$`)P```-.%`0`H````^X4!
M`%$````DA@$`$P```':&`0!H````BH8!`!H```#SA@$`3@````Z'`0`J````
M78<!`#H```"(AP$`(P```,.'`0`B````YX<!`"0````*B`$`)````"^(`0`D
M````5(@!`"0```!YB`$`)@```)Z(`0`>````Q8@!`$$```#DB`$`$@```":)
M`0`7````.8D!`!H```!1B0$`:````&R)`0`,````U8D!`)4```#BB0$`=@``
M`'B*`0!N````[XH!`#(```!>BP$`8@```)&+`0`.````](L!`"8````#C`$`
M%0```"J,`0`,````0(P!`!@```!-C`$`'````&:,`0`X````@XP!`!@```"\
MC`$`(````-6,`0!.````]HP!`!H```!%C0$`#P```&"-`0`.````<(T!`"(`
M``!_C0$`#@```**-`0`0````L8T!``P```#"C0$`"@```,^-`0`&````VHT!
M``H```#AC0$`"@```.R-`0`(````]XT!`!,`````C@$`"@```!2.`0`,````
M'XX!``P````LC@$`#````#F.`0`,````1HX!``P```!3C@$`#@```&".`0`(
M````;XX!``@```!XC@$`"@```(&.`0`.````C(X!``8```";C@$`'````**.
M`0`8````OXX!``X```#8C@$`%@```.>.`0`*````_HX!`!P````)CP$`$```
M`":/`0`$````-X\!`!`````\CP$`"````$V/`0`.````5H\!``P```!ECP$`
M&````'*/`0`$````BX\!`!(```"0CP$`%@```*./`0`&````NH\!``H```#!
MCP$`&````,R/`0`(````Y8\!`!P```#NCP$`#`````N0`0`*````&)`!``X`
M```CD`$`#````#*0`0`.````/Y`!`"4```!.D`$`!````'20`0`%````>9`!
M``$```"V`0``4@`````````*`0``-0$``,@#``#D````)0$`````````````
M`````/<"``#8!```[P0``+P!````````XP$``.X#````````'@```,$!```O
M!```D0````\"````````0`(``*<#```Y!0``[@0``)P%```4````````````
M```J`P```````#4```"/!````````%$$```4`0``S0(``'<"``!:!```````
M`(4!````````I`$``+D$``!]!0``````````````````>@0```````"``P``
MV0(`````````````[`0``.X!```4`@``M0$``!H#``#^!````P(``)P$``#U
M````^P,``"<"``"P````=P$``%4$``!T!0``P@```'\$```Q`@``R````/L"
M``!K`````@$```````"\````E00``````````````````(T"```%`0``(```
M`+8#``!L`P``"P,``$\%``##`0``^@$```````!6`P``P0,``+L$````````
M?@(```8```#*`@````````````"$`@``"P(``/H"``!,!```,@````````#/
M!```80$``,8```!&`````````"D"``#W`````````-8#````````W@(``*H`
M``"&!0``M@```*0#```Z`P``/`0```````"?````F0(```````!'!```````
M`*(`````````;P(``)D!``"@!0``3@0``$@%```````````````````%!0``
M`````#4"``#X`P``X````#\!``""!0``]P,``$T#``!D`````````$P%````
M````!`,``!P!``"L`0``C0```,8"``"#`@``K@,``,P#````````]`$`````
M``!N!```RP0`````````````)0,```````#9!```Y0,``-P"````````]```
M`)\%``#.`````````'4``````````````/L!``#5`@`````````````H`0``
MLP$``)X%``#B!```F04``&X"``"H`0``9P(``-D!```-!```V`(``*4"````
M````<P0``%L#````````CP$``*<```!M`P````````````"U`@``4`,`````
M``!G````?0$``$(#```P````I@0``#$%``".`@``U`(``&4`````````````
M`%$"``!3`0```````"P#``#^````20````````````````````````"5````
M+@$``#D`````````#P4``-P```!'`0```````.8```!8!0``#P$``(D#````
M````BP$```````"G`@``#0(``#@$````````'@(``,$"```P`P``\0$``#,$
M``!D!0``L@0``,\```#;`0```````&@%``!R!```=00``#4%```H`@``````
M`,X"```D`P``]0$``'P"````````C@0``#<"```^`P``&00``'0````*`@``
M#````+<!``"]`P``]00```````!!````)P$``#0#``#$`P``F`0``(("``!P
M`P``!`4``%$#``!/`P``_P(```````"J`0``$@$```````!8`@```````'D!
M`````````````(4$````````O@(``&(````&`0``K````%H#```I`P``CP4`
M`*@$````````;0$```````!(`0``$`4```````"M`0```````#T`````````
M?P(``($$```&!0``%P````````#T`P``E@```/@"````````VP,```````"8
M`P```````)8$```N`@```````),"``!J`0```````+T$``!Q`0```````"L#
M```$````WP$``.,```"X````^00``%4```!'````0@``````````````4`0`
M``````"@`P``=`$`````````````T`$``!\$``#_````@@0``'8$```#!0``
M`````"H%`````````````%0%````````T`0`````````````0@$``'8`````
M````MP,```````#R`````````"@$``!-`@```````%(#````````40``````
M``"8`@``5`(``'`"``#3!```J0$``*4$``#3`0``)@$``*(%``!-`0``2@(`
M``````#>!```+P,``,,$````````)@,``-T#``#L`@``#`,```$"``#@`P``
M`````(X```!&`@``IP0``$("``#H`0``5`$``*P"``"X`@``[@(```````#@
M`0``UP```"4"```6!```.@```.8$``#]`0``5@4```\#``"K`````````#P"
M``!5`@``0@0```@%``#J`P```````-`#``#+`@``NP,```````!N````PP,`
M``````"'`0``2`,``$$$```B`P``A0,`````````````:@0``!H!``!7````
M$P$``,X$``",`0```````,,"``"1!```\@$``.(!``#B`P``:0```"\%``!T
M`P``RP$``!X#`````````````%(%````````9P4``.L#``!@!```'0``````
M``!C`P``8`$``-0```"*`0``'P4``$,%``"_`P``"0(``",$````````0P0`
M``````#=`0``*P(``(0```!:````_P$```````![`P``G@```&$$``!Q`@``
M=04``(`%``#S````)@4```````!I`0```````'<#``#5!```%@$``"X```!N
M`P``UP$``%@#```Y`0```````.,#``#*`0```````%L`````````20(``,\!
M`````````````$<"``!0`@``/P,``#$!``!C`@````````(%````````+0``
M`)T"````````Y0(``)P"````````^0$``$`!``"#`````````$0$````````
M``````````#\`0``+P```)X$``!9````_0,``*0%``!<`````````(\#``!K
M`@``;P```)X#``!:`@``YP0```````"\!```\`,``%`!````````F0,``"L`
M``!3!0```P````````"P`0``R0,``#`%```D`@```````!8"````````.`(`
M`*`!```5````D@4``&T$``"@````)00``/,!````````F`4``*($``!V!0``
M&`4``(0!``"0`````````"0$``!^!0``P````,0!`````````````%P!``",
M`@``?@0``````````````````*\$````````N0,``"L%``!L`@``````````
M```*!```$0$``"@```#5`0````````````"P`@``FP0```````!%`P``F@4`
M``````#"!````````-````#X!```&0$```,!```F`@``X00````````.!0``
M10$`````````````1`,``#T"``#=!`````````````"]````C`,`````````
M````>@,``(L#`````````````(,!``!X!0```````*$$```1`@``VP0`````
M``"Y`0``+P(``(@"``#,!````````#("````````.P4``",#````````KP$`
M`!$#```"`@```````)T#````````'0,```````"\`@``W`0``+H$``";`@``
MS`(``+D````1````C0$``*D$``!P`0````````````!N!0``HP(``*,%``"3
M``````````````#.`0``.@(```````#0`@``5@`````````;!```Q@$``%D"
M```^`0``!00``.<!``!8`0```````$D#``"X`P````````````!,`P``````
M`)L!```&!````````(8#````````X`0``*(#````````V`$``)\!``!)!0``
M``````````!3`@``%P(``'\#``!<`@``1`(````````A````G0$````$``!O
M`P````````<#```2!```U0```+X#``"-!```-P,```````#U`P``[`$``%8"
M``#O`@```````$$#```H`P``<@$``&,!``!'`P``K0(``"T!````````````
M`*T#``!2!```&`,````````'!```V@(````````P!```M@0`````````````
M`````$0``````````````%D!````````&@(```T#`````````````!,%``"6
M`P```````",!``"P!```4@$``!`"```?````'P,``'(`````````;@$`````
M``#_!```/P(``-(!``!B!0``I`0``/T"``````````````````!S````"P``
M`)<!``!I!```.`$``)H"``!O!0```````,4!`````````````/<!``!4!```
M``````````#?!````````!4%```+`0``]`(``/P```!E!````````'<$```)
M!0```````'(#``"%````0P,``#P!``"Q`@``>```````````````"P4`````
M`````````````$`````D!0``>P(``($"``!5`0```````#,"``"-`P``KP,`
M`)H#``!%!````````%,`````````@0,``$4```#6`@``"0````````#&`P``
MF@0````````&`@```````)`"``!*!0``>P$``!T"````````_00`````````
M````ZP$``&\!``#'`P``M````!$$``!:!0``*00``+T!``"K`0```````-($
M``!:`0``Y`,```````#$`@``)P``````````````5`,```@!````````````
M````````````@@```*8"``#6!```;P0``%X#``!5!0``OP(```````!*`P``
M0`4``)($````````N@```&`#``#:`P```````",```#+````Y0```#L"``"J
M`P``T@```*X"``"I```````````````Q`P``9P,````"````````CP(``.T#
M``#T!```B@,``/$#``#Z`````````$@"``"<````\@0``"`"```[````````
M`'$%``#:`0```````$<%``!>`@``_0```"D%```V!```2P```#@#``#7!```
M`@0``',%```;````G@$``"$!``!.`0``?0(``!4"``!H!```LP```"`%```2
M!0`````````%```V!0``W@$``!`#``!B`P``E@$``!H%``#G````X0$``(0$
M``#(`@``E0,```H#`````````````'H%``"E`P``V@0``'H"``#/`@``I0$`
M`!D```#B`@``HP0``"("`````````````$\$``"I!0``FP4``(@#``#'````
M5P,```````"\`P``J0(``!T%````````U@```'D$``"N!```#0```!<!``!P
M!0```@```*X```!6!````````$@```!F!```QP$``#8```!-````Z0(``#T!
M```I`0``!`0``&0$``!#`0``Q`0``#P%``!Y!0```````!L"``#Y`P``````
M``8#````````(0,``+H!``"4`0``;04```````"7`@``V0```&<$```8`0``
M'`4``-\"``!W`````````!,#````````;`$```````#``P``(@````````#M
M`0```````'$````N`P``#04``+\!``!X`0````````````#7`P``L00```$#
M``"A`P``PP```!<%`````````````)P#`````````````',"``!>!```6```
M``````#G`@``H0$``+4``````````````"<%````````7`,``)D$````````
MG0```'L$``"]`@``6P(``$0%```R!```5P4```````#R`@``7@$```````#O
M`0```````!<#``#J`@``2P$``-@#``#?````?@```#X$``#C!```.`4`````
M``"L`P``R00``)0```"*!0``O@$``#<!``!&`0``B`````````"+`@``8@0`
M`+,$``!7`0``>0,``/,"``!/`@``<0,``.8"``!U`@``C@,``,0```"C`0``
M'@$``+<"``"7`P``90$````````?`0``=`0``-,#`````````````.<#````
M````W`$``.0!``!F````X0(``&8#``#D!```L@(```````!F`0``40$``,@$
M``"F!0``Z@```(L%````````'`,`````````````R@`````````>!```````
M`$X"```]!0``T0````````#,`0``_P,``'(%```,!0``````````````````
M6`0````````.!```:`,``.\#````````(@4```````#X`````````!,"```M
M!```E`4``(P```!^`P``B0(``-4#```W!0``%`4``$L%```<!```1@0`````
M``#V!```70```($%``!]!`````````````#2`P``Y`(``+L```!_`0``I@$`
M`)0"``"0!```,`(````````_!0``"0$```````!?````M`0```````!-!0``
M,P,``,T!``#;````$P```!D"``!=!0``>@````````#P`0``IP4```H```!=
M`P``D04``+L"``!\!````````*T`````````?0,``!H$``#\`@``A0(``!T!
M````````I0```&0"````````+`$``*H"``"U`P``KP(``,X#``#-````````
M`````````0``?@$``!(```#H`@```````"`#```^````80(````````T`@``
M9`$``,\#``!4````````````````````E`,``%X```!%`@``(`$``)D```#Q
M`@```````(D!```+!```U@$``%D$```0`````````-L"`````````````)`#
M``#3````[`,``(0#``#<`P``2@0``%T$```]`P``E@4````````7!```P`$`
M````````````R0(``+`#``"Y`@```````-,"```%````@P,``&`%``""`0``
M"````&P````A!0``2P,```H%```3!```90(``(<"``#I`P``Y@,``'L%``#(
M`0```````*`$```.`P``.@$```D#``````````````````"D````'@4``/,$
M``"1`@``&P,``!`$``!@`@``CP```+0"````````:`(``!(#``!.`P``U`$`
M`%L!``!%!0``FP,``(H$``!=`0```````!0#```H!0``<P,``#P`````````
M``````(#``"2`@``L@$``(@%``!X`@``UP(```@$```#!````````#X%````
M````%@,``$@$```Z!```200``#0````[`P``#P```!4#``"O````?`$``&$`
M``"S`@``]@$``$\```#M!```^P```!P"```'`@``:P$``"8```"2`P``````
M`"H!```D`0``JP,``&@``````````````)$#``!#````X0,``(L````)!```
M1`$``&D#``"3!```-P````````#C`@``]@,``,("````````-`$````````M
M`@``7P$``$D!````````L@,``/(#``!L!0``(P4``!@"````````K@$`````
M``#&!````````-D#``"Q`P``^P0``$$"```(`P```````'8!``#-!```````
M`(H"```X````^0``````````````.P0``(D$``!F!0``$`$``(X%``#Z`P``
M70(``($```"&`0``*0````````#H````?P4``(P$```Z!0``5@$``-X```"8
M`0```````&H#``#%!```Q0(``%$%```M`P``>`0`````````````7P0``(P%
M`````````````(8$````````!P4``-0$````````DP,``%<"````````````
M`$H!``!J````J`4``)\#```;!0``<`0``+8"``!.````'P(`````````````
M`````%L$```_````E@(```````````````````````"B`0``MP```"P%``#P
M`````````'$$``!_`````````&L#```8!```=P4``#\$````````I@```"H$
M``"?!```P@$``+@!``"7!```M00``(8`````````!0,``(D```!#`@``<P$`
M`)4"``"*````)P,``)0$``"Q`0``\0````````";````L0```-@```#:````
M`````.D`````````IP$``+\````$`0``:@4```````#W!```^@0``!("``"H
M`@```````.L"````````MP0``/P#```1!0``````````````````D@$`````
M``#*`P``+04``$P````9`P```````$P!``#M````QP0``/$$``!!!0``90,`
M`#8#```C`@```````-$$```@!````````'0"``#P!```00$``,(#```K!```
M`````!4!``"'!```M`$```````#V`@```````(L$````````9`,``&$#````
M````D0$``&8"``!-!```804```````!U`0``JP0`````````````@P0```T!
M````````N`0``$`#```S````X0```'("``!2`@``P0```(8"``!Y`@``1@4`
M`*8#``![````6P4``#D$````````S``````#``!I`@``WP,``#D"````````
MX@````<``````````00````````J`@``C04```````#E`0```````(<%```J
M```````````````B!```5P0```````"H````S0,``)@```":`0``7`4``-("
M``#K````T0,``)(```"A`````````&T```!`!```&P$```````"J!```9P$`
M```````=!```,@$````````R`P```````'4#```D````@`(``),!````````
M-`4``$\!``!Y````#P0``%\%```%`@```````/X#````````[@`````````<
M````)04``````````````````(D%``````````````````"=!````````'T`
M``"C````#@````````".`0``W0(```````!C!```?````&4%``!3`P```04`
M`#$```#4`P``\P,``.D!```8````B`0``)P!``"(`0``,00``%`%```6````
M7P(``*("````````=@,``#,%```6!0``RP,``%D%````````(0(``/`"```4
M!```0@4``!H````9!0``NP$``#4$``"'`P``/@(`````````````:@(``&(!
M```,`@``8P4```````#%`````````(0%```B`0`````````````W!```````
M`*L"```$`@```````/X"````````K00``%D#``"Z`@``A04`````````````
MK`0```````!,`@``[0(``(`````.`@``+`0``/8```!5`P``D`4``*,#````
M``````````````"?`@``Z00```<!`````````````-$!``#X`0``-@$``#(%
M````````:P4``)<%```G!```(00```````#H`P```````((#````````[```
M`%,$`````````````$L$``#1`@``*P$``"8$````````Y@$``'H!````````
M````````````````O@0``*0"`````````````*@#``!C`````````#0$````
M`````````),%```\`P``ZP0```````#J`0`````````````V`@``3@4``'P#
M``#)`````````)H```"E!0``EP```&D%``#``@```````'P%``!X`P``````
M`(`$``"A!0```````,D!``!V`@``AP```%P$```L`@``+@0``#L!```O`0``
M1@,``*`"``#^`0``Z`0``&("``"``0```````+X````Y`P```````%````"!
M`0```````&P$``#\!```)0```,4#````````#`$``)T%````````[P```%\#
M``"R````D`$``+0#``#'`@``#@$```,#``#`!```W0```)X"````````````
M`)4%``!H`0``X`(``/4"``#J!```2P(``#4#```L`````````#T$````````
M,`$``'````"A`@``R@0``!4$```(`@```````#,!``"I`P``;0(``+,#``#E
M!````````,$$`````````````&L$``"5`0```0$```P$``#>`P```````+H#
M```N!0``^0(`````````````OP0``&````!*````@P4``%X%````("@E<R!D
M87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A
M>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI`"(E<R(@:7,@;F]T(&$@9&ER
M96-T;W)Y+@`B)7,B(&ES(&YO="!A('9A;&ED(&-H;VEC92X`(B5S(B!I<R!N
M;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"(E<R(@=')E
M92!R96YD97)E<B!N;W0@9F]U;F0N`"(E<R(@=V%S(&%D9&5D('1O('1H92!G
M<F]U<',@<WES=&5M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO
M;G,@<WES=&5M+@`B)7,B('=A<R!N;W0@8W)E871E9#H@)7,N`"4N,F9-0B!U
M<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I`"5D("5S(&%N9"`E<P`E
M9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RX`)7,@+2!.;W1I
M8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E
M<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@:7,@<F5A
M9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C
M:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I
M('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R97%U
M:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`
M)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`
M)7,G<R!487-K;&ES=``E<SH@)7,`)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T
M(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL
M;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N
M9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+@`M+2!S96QE8W0@
M+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`/%!R
M979I;W5S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI
M<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@
M4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P
M=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@
M;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A
M9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P
M=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92X`04TO4$T`06)O=70@=&AI<R!E9&ET;W(`06-C97-S(&1E;FEE9"!C<F5A
M=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&
M4R!F:6QE+@!!8V-O=6YT($EN9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`
M06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U
M<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U
M<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S
M(@!!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O("(E<R(`061D(&$@;F5W('5S
M97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T
M:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D<F5S
M<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D
M("(E<R(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I
M;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H
M92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`061D:6YG('5S97)S(&ES
M(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@
M<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO
M;@!!9',`069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N
M;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`
M06QL(%!E<FUI<W-I;VYS`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO
M=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T
M<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R
M9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D
M<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;65R
M:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N
M('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N9&]R<F$`06YG;VQA`$%N
M9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC80!!;G1I
M9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`
M07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!
M<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`07)C:&EV92!&:6QE(%-I
M>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO
M=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y
M;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U8BUG<F]U<',_`$%R
M9V5N=&EN80!!<FUE;FEA`$%R=6)A`$%S8V5N<VEO;B!)<VQA;F0`07-I82]0
M86-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I
M;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`071T96UP="!T;R!D96QE=&4@
M82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N
M+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE
M>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI
M<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T
M<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U
M:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA
M8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@
M;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z
M(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$
M:7)E8W1O<GD`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B
M;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D
M871E('5S97(@)7,`075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@
M<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ(%)E
M<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H
M.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE
M;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I
M;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC
M871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I
M;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N('1O('1H
M92!334(@<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE(&9I96QD<SH`07IE<F)A
M:6IA;@!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S
M('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H
M<F%I;@!"86YG;&%D97-H`$)A<F)A9&]S`$)A<V4@9W)A<&AI8W,@9&ER96-T
M;W)Y("(E<R(@;F]T(&9O=6YD+@!"87-E;&EN90!"96QA<G5S`$)E;&=I=6T`
M0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E
M<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I
M;F=S`$)L;V-K(%1Y<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`
M0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V
M:6YA`$)O='-W86YA`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD
M:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I
M80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`
M0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#
M86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#86UB;V1I
M80!#86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L
M;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86X@;F]T('=R:71E
M('1O(&9I;&4@(B5S(@!#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I
M;VX@:&%N9&QE<G,N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S
M`$-A;B=T(&]P96X@9FEL92`B)7,B+@!#86YA9&$`0V%N8V5L`$-A;F-E;"!0
M<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T
M(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W
M:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@
M9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X
M:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI
M960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`
M0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P
M92!697)D90!#87!T:6]N`$-A<G)I97(`0V%T96=O<FEE<R!A;F0@3&%B96QS
M`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E
M;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L
M;'!H;VYE`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5R=&EF
M:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0
M;VQI8VEE<P!#:&%D`$-H86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N
M9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@
M=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@
M>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E
M;G0@8V]N9FEG=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M+@!#:&5C7VL@3&EN:RXN+@!#:&EL90!#:&EN80!#:&]O<V4@07!P;&EC871I
M;VXZ`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S
M92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAR:7-T;6%S($ES;&%N9`!#;&%S
M<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(@35-/9F9I8V4@
M=&%G<P!#;&5A<B!1=65R>0!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E
M<@!#;&5A<B!U<V5R(&1A=&$`0VQI8VL@=&\@0V]N=&EN=64`0VQO<V4@5VEN
M9&]W`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`
M0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`
M0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H
M96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;F9I
M9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN
M9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+@!#;VYF:6=U
M<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@)7,`0V]N9FER;2!0
M87-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@
M;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@
M`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`
M0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!2
M96%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE
M9"X`0V]N=&%C=',`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@
M=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E;G0@='EP92!O9B!C;VUP<F5S
M<V5D(&9I;&4Z(`!#;VYT96YT<R!O9B`B)7,B`$-O;G1I;G5E`$-O;VL@27-L
M86YD<P!#;W!Y`$-O<'D@9F%I;&5D.B`E<P!#;W!Y('-E;&5C=&EO;@!#;W-T
M82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE
M<W-A9V4Z(`!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@`$-O=6QD(&YO
M="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I
M9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N
M;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A;&%N
M8V4N("5S`$-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!#;W5L
M9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O
M=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO
M="!D96-R>7!T(%!'4"!D871A.B``0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%
M(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T
M(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E;&5T
M92!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T97)M
M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T
M(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H
M(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@
M=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L
M9"!N;W0@;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@(B5S
M(BX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E
M<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U;&0@
M;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@
M;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#;W5L
M9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A9"`E
M<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E
M<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T
M(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R
M871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R
M:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`
M0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L
M9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N
M;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R
M979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER("(E<R(N`$-O
M=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E
M(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K
M=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R
M861E('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU
M<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E('1H92!C
M;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@
M;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R
M(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD(&YO
M="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK("(E
M<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P
M9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T('=R:71E(&-O
M;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO
M>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN
M`$-O=6YT<GD`0W)E871E`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F
M;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R
M`$-R;V%T:6$`0W5B80!#=7)R96YT(%-E<W-I;VYS`$-U<G)E;G0@5&EM90!#
M=7)R96YT(%523"!I<P!#=7)R96YT(%5S97)S`$-U<W1O;6EZ92!T87-K<R!T
M;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP
M<G5S`$-Z96-H(%)E<'5B;&EC`$1$`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`
M1&%T86)A<V4@3&]O:W5P`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C
M=&EO;@!$95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`
M1&5C<F5A<V4@26YD96YT`$1E9F%U;'0`1&5F875L="!#;VQO<@!$969A=6QT
M($ED96YT:71Y`$1E9F%U;'0@4VAE;&P`1&5L971E`$1E;&5T92!#96QL`$1E
M;&5T92!'<F]U<`!$96QE=&4@3&]G`$1E;&5T92!097)M:7-S:6]N`$1E;&5T
M92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T
M92!T96UP;&%T90!$96QE=&4@;65S<V%G97,`1&5L971E('!E<FUI<W-I;VYS
M(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY
M('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@
M:61E;G1I='D`1&5L971E('-U8B!F;VQD97)S`$1E;&5T92!T:&4@8W5R<F5N
M="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&5D('-E='5P
M('5P9W)A9&4@<V-R:7!T("(E<R(N`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$
M97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA;'-O
M(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1I<F5C=&EO
M;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<W!L
M87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1J:6)O=71I`$1O
M(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC
M92YP:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA
M;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC
M86X@4F5P=6)L:6,`1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+@!$
M;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG
M=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!%+4UA:6P`16-U861O<@!%9&ET`$5D
M:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M
M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@
M9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO
M;G,@9F]R("5S`$5G>7!T`$5L(%-A;'9A9&]R`$5M86EL`$5M86EL($%D9')E
M<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N
M9FER;6%T:6]N`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@
M<V5A<F-H('1E<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@
M4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C
M;VYT97AT(&UE;G4_`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@
M<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@
M=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M
M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`17%U
M871O<FEA;"!'=6EN96$`17)I=')E80!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B
M;&]C:SH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R(&=E
M='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S
M`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`17)R;W(@=W)I=&EN9R`B)7,B
M+@!%<W1O;FEA`$5T:&EO<&EA`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V
M97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E
M<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X
M86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%
M>'!E8W1E9"`G*2<`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$9'($-O;&]R
M`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R
M96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL
M960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F
M<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C
M<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@
M(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E<P!&86QK;&%N9"!)<VQA;F1S
M("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X`$9A
M>&5S`$9E8G)U87)Y`$9I:FD`1FEL90!&:6QE($-O=6YT.B`E<R!F:6QE`$9I
M;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL
M92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P
M;W)T960N`$9I;'1E<G,`1FEN;&%N9`!&:7)S="!1=6%R=&5R`$9O;&1E<B`E
M<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O<B!B<F]W<V5R<R!T:&%T
M(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&
M;W)M<P!&;W)U;7,`1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L
M:71A;@!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O
M=71H97)N(%1E<G)I=&]R:65S`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N
M`$9U;&P@3F%M90!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;0!'
M86QL97)Y.@!'86UB:6$`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE
M<F%T960@0V]D90!'96]R9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R`$=I
M=F5N($YA;64`1VQO8F%L($]P=&EO;G,`1V]O9VQE($UA<',`1V]O9VQE(%-E
M87)C:`!'<F5E8V4`1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R
M871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!?;&1A
M<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9#H@`$=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O
M=7`@)7,`1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<P!'
M<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S
M="!097)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`
M1W5Y86YA`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(
M87-H+4%L9V]R:71H;0!(96%D97(`2&5A9&5R<P!(96%R9"!)<VQA;F0@86YD
M($UC1&]N86QD($ES;&%N9',`2&5I9VAT`$AE;'``2&5M:7-P:&5R90!(;U]M
M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D
M<F5S<P!(;VUE($1I<F5C=&]R>0!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@
M2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E
M;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S
M86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@
M;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+
M;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA
M8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM
M;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T
M92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA
M8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE
M('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E
M<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@
M)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L
M(%)U;&4`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G
M93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M
M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;F=A<GD`24U!
M4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E
M;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N
M(&9A:6QE9#H@)7,`25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B
M;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN
M`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`26-E;&%N9`!)8V]N<R!/;FQY`$EC
M;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)
M9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I
M="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS
M('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE
M8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`26UA
M9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V5S`$EM<&]R
M="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S
M.@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A
M;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A
M<V4@26YD96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN
M9F\`26YF;W)M871I;VX`26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM
M86=E`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU
M;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT
M(&]N90!);G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!)
M;G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T
M(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@
M<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E
M<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI
M8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C
M96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F
M=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E
M<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN
M<V5R="!R;W<@869T97(`26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R
M97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E
M<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE
M;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!)
M;G-U9F9I8VEE;G0@8W)E9&ET+@!);G9A;&ED(%I)4"!D871A`$EN=F%L:60@
M87!P;&EC871I;VXN`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@
M9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!L:6-E;G-E(&ME>2X`26YV
M86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV86QI9"!P87)E;G0@<&5R;6ES
M<VEO;BX`26YV86QI9"!P87)T;F5R(&ED+@!);G9A;&ED('!R;V1U8W0@8V]D
M92X`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!R96-I<&EE;G0Z("(E<R(`
M26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D<F5S<RX`
M26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5R="!S96QE8W1I;VX`27)A;BP@
M27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`
M27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA
M<&%N`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#
M96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT
M`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R
M=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97D@0W)E871I;VX`2V5Y
M($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(&%L<F5A9'D@
M97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:7)I8F%T:0!+;W)E
M82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P
M=6)L:6,@;V8`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G90!,
M86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T(%%U87)T97(`
M3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO
M9VEN.B!.979E<@!,871V:6$`3&%Y;W5T`$QE8F%N;VX`3&5F=`!,97-O=&AO
M`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN
M`$QI;FL`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P
M86=E('=H96X@9&ES<&QA>6EN9P!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@
M5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E
M<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!I<R!D
M:7-A8FQE9"X`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO
M8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;@!,
M;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE
M(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F
M86EL960N`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R
M<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU>&5M8F]U<F<`34T`35,M5$Y%1B!!
M='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+@!-86-A;P!-86-E9&]N:6$L
M(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-
M86EL`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G
M92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET
M96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A
M=&5G;W)I97,N`$UA<F-H`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-
M871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%Y`$UA>6]T
M=&4`365M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S
M<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C
M97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE=&AO9`!-971H
M;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-97AI8V\`36EC<F]N97-I82P@1F5D
M97)A=&5D(%-T871E<R!O9@!-:6UE(%1Y<&4`36ES<VEN9R!014%2('!A8VMA
M9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H
M879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI
M<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E
M<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N
M`$UO`$UO8FEL92!-86EL`$UO9&EF:65D($1A=&4`36]L9&]V82P@4F5P=6)L
M:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N
M(%!H87-E<P!-;W)O8V-O`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H
M=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`37D@06-C
M;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY86YM87(`3D\L($D@1&\@
M3D]4($%G<F5E`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.971H97)L86YD
M<P!.971H97)L86YD<R!!;G1I;&QE<P!.971W;W)K`$YE=F5R`$YE=R!#86QE
M9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T
M:6]N86PI`$YE=R!:96%L86YD`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@
M=VEL;"!E>'!I<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N
M`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@;W!T:6]N<P!.97AT/@!.:6-A
M<F%G=6$`3FEG97(`3FEG97)I80!.:75E`$YO(&%V86EL86)L92!C;VYF:6=U
M<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&-H86YG
M92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO
M;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T
M+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.
M;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@<')O=FED960N`$YO(&UE<W-A
M9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E
M8VEF:65D+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%3
M4U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I
M;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R
M>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU
M<',N`$YO('%U;W1A('-E="X`3F\@<V5P87)A=&]R('-P96-I9FEE9"X`3F\@
M<W5C:"!F:6QE`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.
M;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO
M;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF
M:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]R
M9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I
M86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A
M(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT960N`$YO="!S=7!P;W)T960N`$YO
M=&5S`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB
M97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C
M:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/
M8FIE8W0`3V)J96-T($-R96%T;W(`3V-T;V)E<@!/9F9I8V4`3VQD('!A<W-W
M;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VUA;@!/;FQY($E-
M05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]N92!E
M;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E
M;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R
M('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W
M`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S
M:6=N960@4R]-24U%('!A<G0N`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D
M97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R
M9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W1H97(@
M26YF;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T
M:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!'4"!$:6=I=&%L(%-I9VYA='5R90!0
M1U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%
M;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`4$]325@@97AT96YS
M:6]N(&ES(&UI<W-I;F<`4&%D9&EN9P!086MI<W1A;@!086QA=0!086QE<W1I
M;FEA;B!497)R:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I
M;F5A`%!A<F%G=6%Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960@<W5C8V5S
M<V9U;&QY+@!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@
M9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF
M:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@
M;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN
M9R!3:6=N=7!S.@!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_
M`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D96QE=&5D+@!097)M
M:7-S:6]N($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES
M=')A=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!H:6QI<'!I;F5S
M`%!H;VYE`%!I=&-A:7)N`%!I>&5L<P!0;&5A<V4@96YT97(@82!M;VYT:"!A
M;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A
M=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@
M;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@<')O=FED92!A
M('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@
M=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I
M;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E
M('1H92!S>7-T96TN`%!O;&%N9`!0;VQL<P!0;W)T=6=A;`!0<F5F<U]L9&%P
M.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E
M<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`
M4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E
M=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E($ME>0!0<F]B
M;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4'5B;&EC($ME>0!0=6)L:6,@2V5Y
M($%L9V]R:71H;0!0=6)L:6,@2V5Y($EN9F\`4'5B;&EC+U!R:79A=&4@:V5Y
M<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4'5E<G1O(%)I8V\`
M4'5R9V4@;65S<V%G97,`46%T87(`475E<GD`475O=&$`4E-!(%!U8FQI8R!+
M97D@*"5D(&)I="D`4F%T:6\`4F5A9`!296%L;'D@9&5L971E("5S/R!4:&ES
M(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S
M97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E
M('5N9&]N92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:"!$>6YA
M;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E;&]A
M9`!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP
M;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@9F]R
M;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@
M<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO
M=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E
M;6]V92!U<V5R.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2
M971U<FYE9"!E<G)O<F-O9&4Z(`!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I
M960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E
M8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO
M="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5S970`4F5S970@4&%S
M<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-U;'1S`%)E='5R;B!T;R!/
M<'1I;VYS`%)E='EP92!N97<@<&%S<W=O<F0`4F5V97)T($-O;F9I9W5R871I
M;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9VAT`%)O;&4`4F]M86YI
M80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O
M<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I
M;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`
M4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@
M16YC<GEP=&5D($UE<W-A9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@
M879A:6QA8FQE+@!344P@4VAE;&P`4U-(`%-50T-%4U,`4V$`4V%I;G0@2&5L
M96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0
M:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N
M861I;F5S`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E
M`%-A=61I($%R86)I80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@3W!T
M:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C
M<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A
M=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R
M:7!T('1O.B`B)7,B+@!396%R8V@`4V5A<F-H($5N9VEN97,`4V5L96-T($9I
M;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C
M="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T
M;R!A9&0`4V5L96-T(&%L;`!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE
M960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N
M9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D
M871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T
M('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@
M=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C
M="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE
M;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B
M;&5M(%)E<&]R=`!396YD(%--4P!396YE9V%L`%-E<'1E;6)E<@!397)B:6$@
M86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397-S:6]N($%D;6EN`%-E
M<W-I;VYS`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R
M('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T
M92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P
M;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@
M86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO
M;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D
M:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A
M=F%I;&%B;&4`4V5Y8VAE;&QE<P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E
M<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@
M9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N
M97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN
M('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W('1A8FQE(&]P97)A=&EO;G,@
M;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@
M=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B
M;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E
M<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G
M`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@
M;W5T(&]F('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG
M;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI
M<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;VQO;6]N($ES;&%N
M9',`4V]M86QI80!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S
M<P!3;W5T:"!!9G)I8V$`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A
M;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W
M965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@
M8F]R9&5R(&EN(&-E;&P`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P
M86EN`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@
M8V]L=6UN`%-P;&ET(')O=P!3<FD@3&%N:V$`4W1A=&4@;W(@4')O=FEN8V4`
M4W1A='5S`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1Y;&4@6T-3
M4UT`4W4`4W5B9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!3=6)M:70`4W5B
M<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE
M('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B
M)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S
M(BX`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN
M`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@
M=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N
M9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B
M`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E
M`%-U;B!3970`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS
M970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A
M;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L
M86YD`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%135B!F:6QE`%1A8FQE(%!R;W!E
M<G1I97,`5&%B;&4@<')O<&5R=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC
M92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L
M:6,@;V8`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP;&%T92`B)7,B(&YO
M="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5X="!/;FQY`%1E
M>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I;&%N9`!4:&4@1E10(&5X=&5N<VEO
M;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES
M86)L960N`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S
M=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X
M:71I;F<N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A
M('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O
M('5S92!097)M:7-S:6]N<RX`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N
M;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@
M=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D
M9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I
M9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE
M9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE
M<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T
M:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P
M96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E
M8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A
M:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S
M;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C86YN;W0@8F4@8V]P:65D(&]N
M=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O
M;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X
M,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@
M8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E('1O
M(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O
M=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L
M86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R
M(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@
M=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C
M=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B
M965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N
M="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE(&ED96YT:71Y
M("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QO8V%T:6]N(&]F('1H92!'
M;G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@
M8VQA<W,N`%1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`
M5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?
M0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L
M9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@
M;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I
M97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S
M>7-T96TN`%1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE
M(&-H87)A8W1E<BX`5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@
M8VAA<F%C=&5R+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`
M5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<W!E8VEF:65D
M(')O=R`H)60I(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@
M(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO
M<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE
M(&-O=6QD(&YO="!B92!S879E9"X`5&AE;65S(&1I<F5C=&]R>2`B)7,B(&YO
M="!F;W5N9"X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R
M92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`
M5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@
M66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E
M<B!L97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("(E
M<R(@=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A
M<FEN9R!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE
M<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E
M;3H@`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S(CH@)7,`5&AE
M<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@
M=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I
M;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M
M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M
M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA
M;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T
M:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6X@
M=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@
M82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI
M;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S
M92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO
M;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&ES($E-05`@<V5R
M=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES
M(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES
M(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI
M<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M
M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O
M<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD
M(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT
M86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E
M>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@
M<')O8V5S<V5D+@!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R
M86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB
M97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N
M8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C
M=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU
M;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I
M;VYS('=I;F1O=P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM
M;W(M3&5S=&4`5&ET;&4`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD
M(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W
M:&EL92!C;&EC:VEN9RX`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA
M=0!4;VYG80!4;V\@;6%N>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA
M<W0@;6EN=71E<RX`5')I;FED860@86YD(%1O8F%G;P!4=0!4=6YI<VEA`%1U
M<FME>0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U
M=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``55),`%5G86YD80!5:W)A:6YE`%5N
M86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-H86YG
M92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA
M;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@
M8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E
M<R(N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S+R5S(BX`56YA
M8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE
M8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5
M;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&-R
M96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T
M82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO
M="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE('1O
M(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T
M92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R
M<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C
M=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5
M;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O
M(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A
M<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F
M86EL960I+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H
M*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O(')E
M860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S
M('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA
M8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE
M(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI
M<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+@!5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+@!5;F1E<FQI;F4`
M56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:71E
M9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`
M56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:VYO=VX`
M56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YN86UE9`!5;G!R:79I
M;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R
M;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+
M('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H
M('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H
M92!C;&EP8F]A<F0N`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D
M871E("5S`%5P9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!G<F%D92!S8W)I
M<'0@9&5L971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S
M971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S
M`%5P<&5R(')O;6%N(&YU;6)E<G,`57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`
M57-E(%-33`!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R
M($E-4U`@<V5R=F5R+@!5<V5R`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@
M9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R
M(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A
M8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S
M97)N86UE`%5S97)N86UE("(E<R(@86QR96%D>2!E>&ES=',N`%5S97)N86UE
M.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`
M5F%C871I;VX`5F%L:61I='D`5F%N=6%T=0!696YE>G5E;&$`5F5R:69I8V%T
M:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E
M<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L
M:6=N`%9I970@3F%M`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G
M90!6:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3
M+@!786QL:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E96ML>0!796QC;VUE
M`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B!386AA<F$`5VAA
M="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`
M5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@
M<75O=&4@8VAA<F%C=&5R/P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@
M=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&]F('1H92`E<R!M
M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI
M.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VES:&QI
M<W0`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`5W)O;F<@;G5M8F5R(&]F(&9I
M96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG
M(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O
M;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92X`6#4P.78S
M($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`
M6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C
M="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EE
M87)L>0!996UE;@!997,`665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-
M3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!7
M65-)5UE'+@!9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H
M86X@)60@8FQO8VMS+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@
M8V%N;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA
M;64N`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`
M66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F
M:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA
M=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED
M(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N
M86P@)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N
M9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U
M(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R
M:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L
M96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@
M;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B
M92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE
M87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E
M+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M
M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@
M<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E
M(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP
M:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`
M66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT
M97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG
M(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y
M+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T:&5N
M=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R
M<RX@268@>6]U('=I<V@@=&\@=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E
M<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT(&%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0N`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D
M;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E
M(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U
M<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B
M96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@
M<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@
M9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D
M;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT
M<F]L+T-O;6UA;F0@*R!0('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z
M;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"X`
M66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L
M;V=I;B!H87,@97AP:7)E9"X`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES
M.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D
M=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R
M('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N
M9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!P87-S=V]R
M9"!H87,@97AP:7)E9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I
M80!:86ER90!:86UB:6$`6FEM8F%B=V4`6U!R;V)L96T@4F5P;W)T70!;;&EN
M92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]$96QE=&4@4F]W`%]'<F]U
M<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TQO9R!I;@!?3&]G(&]U
M=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO
M=F4@3&EN:RXN+@!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S
M`&%D9')E<W,@8F]O:P!A9&1R97-S964@=6YK;F]W;@!C86QE;F1A<@!C86YN
M;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T`&-L:6-K
M(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R871I;VX@
M97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9P!D871A(&9O<FUA
M="!E<G)O<@!E9&ET`&5N=')Y(&YO="!F;W5N9`!F:6QE`&AO<W0@;F%M92!U
M;FMN;W=N`&EN<'5T+V]U='!U="!E<G)O<@!I;G1E<FYA;"!S;V9T=V%R92!E
M<G)O<@!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D
M`&YO=&5P860`<&5R8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5M
M;W1E(&5R<F]R(&EN('!R;W1O8V]L`'-E<G9I8V4@=6YA=F%I;&%B;&4`<VAO
M=R!D:69F97)E;F-E<P!S>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R
M>2!F86EL=7)E`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`
M=6YN86UE9`!V0V%R9`!0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,2XP
M"E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`S+3`V(#$R.C0W*S`Q,#`*4$\M
M4F5V:7-I;VXM1&%T93H@,C`P-BTP,RTR,B`Q,CHP,"LP.3`P"DQA<W0M5')A
M;G-L871O<CH@2&ER;VUI($MI;75R82`\:&ER;VUI0'1A8RYT<W5K=6)A+F%C
M+FIP/@I,86YG=6%G92U496%M.B!*87!A;F5S92`\=6YK;F]W;D!U;FMN;W=N
M+F1O;6%I;CX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT
M+W!L86EN.R!C:&%R<V5T/5-(24947TI)4PI#;VYT96YT+51R86YS9F5R+45N
M8V]D:6YG.B`X8FET"@`@*"5S()/ZD4\I`(-!@TZ#6H-8@TR#0R`E<P"!:25S
M()/Z@LR3X(+)@6H`("B-H9/Z*0"!:9:^D_J!:@`@*(WPD_HI`"<E<R<@@LV#
M9H-"@XR#3H-G@XJ!6X+%@LV"H(+H@MR"N8+Q@4(`(B5S(B""S9"S@K6"HI%)
MD?""Q8+-@J""Z(+<@KF"\8%"`"(E<R(@@LT@2&]R9&4@@XR#5X-8@V>#BH+)
MD-V2Z(*S@NJ"Q(*B@MR"N8+Q+@`B)7,B((-C@XJ!6Y5<CJ:+0)1<@JJ,J95T
M@JF"Z(+<@KF"\8%"`"(E<R(@@JJ#3X.+@5N#=H-6@UB#98.`@LF2QXG!@K."
MZH+<@K6"O8%"`"(E<R(@@JJ#08-.@UJ#6(R@@U:#6(-E@X""R9+'B<&"LX+J
M@MR"M8*]+@`B)7,B((+-C>R0K(*S@NJ"W(*Y@O&"Q8*U@KTZ("5S+@"799?*
M("4R)"XR9DU"()*&@LP@)3$D+C)F34(@CF>7<"@E,R0N,F8E)2D`)60@)7,@
M@L8@)7,`@W"#6(./@5N#:(+-@J""QB`E9""3^I=,C/B"Q8*W@4(`DLJ2;2`M
M("5S`"5S()-DCG&.=Y;D`"5S($M"`"5S()7;CN>1@(WL@LR*;91&`"5S((+,
MD-V2Z``E<R"#5(-#@Y.#08-B@W8`)7,@DZ^(TX_PC8``)7,@@LV*^8+)D;:-
MW8*U@MR"MX%"`"5S((+-CI^"R8YWDNB"LX+J@L2"HH+IE=N.YY&`C>R"\([`
MC7."MX+ICX"4]8*JD*Z"HH+<@K6"O8%"CL"-<X*U@KV"HI&`C>R"S(-[@V*#
M3H-8@O"#8(-&@V*#3H*U@L2"K8*^@K."HH%"`"5S((*JE4N7=H+%@K<`)7,@
ME:H`)7,@@JJ"H(+H@MR"N8+Q@4(`)7,@@JF"YR`E<X%!C8>,=B`E<P`E<R""
MS(-!@VB#C(-8DJ``)7,@@LR77)+HE5P`)7,@@LR#@8."DJ``)7,@@LR#7H-8
M@TZ#BH-8@V<`)7,Z("5S`"5S.B""L8+,@X&#8H-:@5N#5X+-CJ:"LX+J@L2"
MHH+ID9>038[2@JF"YX+,@N""S(+%@LV"R(*B@L:.=H+M@NJ"W(*W@4*"NX+,
MDH:"S(.*@Y.#3H+P@TZ#BH-B@TZ"M8*]@NB!08S"D&R/[I7Q@O"1EY!-@K>"
MZ8+,@LV/7)6J@LF2C8C3@K6"Q(FZ@K."HH%"`"TM()%)D?`@+2T`,3*.GHK4
MC&".K@`R-(Z>BM2,8(ZN`#(T((Z>BM0`/)%/@LR#>8%;@U<`@K&"S(-U@XV#
M8H-.@LF"S8-F@5N#7H-X@5N#6(*JE4N7=H+%@K>!0@"2=I:]DTF"R(-'@XF!
M6X*JE*V0MH*U@MR"M8*]`%!'4(SVBDJ,KH*J@X&#8H-:@5N#5X+,B,.-AHF[
M@LF52Y=V@L6"MX%"`%!'4(SVBDJ,KH*JCY"6O(*S@NJ"O8.!@V*#6H%;@U>"
MS(R?C]B"R95+EW:"Q8*W@4(`4$=0C/:*2HRN@4%01U"4Z9:GC*Z"J(+F@M&#
M<(-8@W2#C(%;@UF"JHC#C8:)NX.!@V*#6H%;@U>"S)6<C8:"R95+EW:"Q8*W
M@4(`4$=0C/:*2HRN@4%01U"4Z9:GC*Z"J(+F@M&#<(-8@W2#C(%;@UF"JH.!
M@V*#6H%;@U>"S(^0EKR"R95+EW:"Q8*W@4(`4R]-24U%C/:*2HRN@4%3+TU)
M3464Z9:GC*Z"J(+F@M&#<(-8@W2#C(%;@UF"JHC#C8:)NX.!@V*#6H%;@U>"
MS)6<C8:"R95+EW:"Q8*W@4(`4R]-24U%C/:*2HRN@4%3+TU)3464Z9:GC*Z"
MJ(+F@M&#<(-8@W2#C(%;@UF"JH.!@V*#6H%;@U>"S(^0EKR"R95+EW:"Q8*W
M@4(`4R]-24U%C/:*2HRN@JJ#@8-B@UJ!6X-7@LR(PXV&B;N"R95+EW:"Q8*W
M@4(`04TO4$T`@K&"S(-'@V:#0H->@5N"R8+"@J*"Q`!61E.#9H-"@XR#3H-G
M@XJ"S(WLD*R"S8-!@TZ#6H-8BY&4VX*S@NJ"W(*U@KV!0@!61E.#=(-`@T.#
MBX+,C>R0K(+-@T&#3H-:@UB+D93;@K."ZH+<@K6"O8%"`(-!@TJ#18.3@V>/
M[I7Q`(-!@TJ#18.3@V>"S(-P@UB#CX%;@V@`@T&#2H-%@Y.#9X+-DX",BX*S
M@NJ"Q(*B@MR"MX%"`(-!@TJ#18.3@V<`DL>)P0"#5(-U@T^#BX%;@W:"\)+'
MB<$`@U2#=8-!@TZ#6H-8C*""\)+'B<$`@K&"L8+)DL>)P3H`D%:"M8*B@T^#
MBX%;@W:"\)+'B<$`D%:"M8*B@O"#08-.@UJ#6(R@@O"2QXG!`(-4@W6#3X.+
M@5N#=H+P("(E<R(@@LF2QXG!`(-4@W6#08-.@UJ#6(R@@O`@(B5S(B""R9+'
MB<$`D%:+2X.&@5N#58+PDL>)P8%&`)?Q@O"2QXG!`)!6BTN#@8.3@V^"\)+'
MB<&!1@"#>8-!@O"2QXG!`"5S((.!@VJ#A8%;@O`@36]Z:6QL82""S(-4@T.#
M:(-O@5N"R9+'B<&"MX+I`(-!@VB#C(-8DJ""R9+'B<$Z`(Z$@LR"S(-!@VB#
MC(-8DJ""R9+'B<$`@X:!6X-5@O"2QXG!`(-6@UB#98.`@LD@(B5S(B""\)+'
MB<&"M8+<@K6"O8*J@4&#5(-#@Y.#08-B@W:"S(_NE?&"JI+'B<&"Q8*K@MR"
MN8+Q@L6"M8*]@48E<P"#5H-8@V6#@(+)("(E<R(@@O"2QXG!@K6"W(*U@KV"
MS(+%@4&#C8-/@T.#DX+%@JN"W(*W@4(`@X:!6X-5@LR2QXG!CXB7G8+-EK.,
M^(+)@LB"P8+$@J*"W(*W@4(`CUJ/B@"#08-H@XR#6)*@`(K'EYT@+2"1O(+,
M@X:!6X-5@LR#08-.@UJ#6(R@`(K'EYT`061S`(-!@W2#2X-J@UB#7H.3`(-!
M@XN#;X-J@T$`@T&#BX-7@T:#BH-!`)7*EKP`B,J2=9&U@J:!1@"14Y64`)%3
ME$:/V(.&@5N#50"14X+$@LR#3X.+@5N#=@"14X+$@LR#08-.@UJ#6(R@`)6A
MD)2"S(-!@VB#C(-8@O"+EHG"`)34C8:5=(*K@XJ#6(-G@O"0W9+H@L6"JX+I
M@N:"I(+)@K6"W(*W@JF!2`"*^8+)D;:-W8*U@MR"MP"1XY'6@LP@24U34""#
MC8-/@T.#DP"1XY'6@LP@24U34""#<(-8@X^!6X-H`)'CD=:"S"!)35-0((.&
M@5N#59:\`)'CD=:"S(.!@5N#BX-!@VB#C(-8`)'CD=:"S(-E@Y.#=H.,@5N#
M9P"1XY'6@V6#3(-8@V>!1@"#08.!@XJ#2I?,@U2#@H-!`)5SD+."R))L@JJ.
M=Y+H@K."ZH+$@J*"W(*W`)=<BOJ"M8+(@J*#1X.)@5N"JI2MD+:"M8+<@K6"
MO0"#08.3@VB#B0"#08.3@U.#B8NDF&&-D0"#08.3@T^#0H.)`).]EKR#=H.-
M@TR#5H%;`).:@J8`D^R+R8%ID>67I(%J`(-!@Y.#98-"@T^#08%%@V^!6X-U
M@5N#7P"#08-V@XJ#4(%;@U:#AX.3`(-!@W:#BH-0@5N#5H.'@Y.(ZI>7`(-!
M@W:#BH-0@5N#5H.'@Y..9Y=PB<(`B;J(RH+,BZ273(+)DTN7<`"/LY1&`(*H
M@JB"YH*[@LR#5(-#@UD`@E.,C@"#08%;@TJ#0X-U@W2#0(-#@XN#5(-#@UD`
M@T&!6X-*@T.#=9:\`"5S((+,@U2#0X.3@T&#8H-VEW:+@8+PEGN3EH+)C>V/
MG(*U@L2"HH*B@L6"MX*I@4@`EGN3EH+)("(E<R(@@L:#5(-U@T^#BX%;@W:1
M4X+$@O"-[8^<@K6"Q(*B@J*"Q8*W@JD_`(-!@XN#6X.3@V"#DXNDF&&-D0"#
M08.+@X&#:H-!BZ2888V1`(-!@XN#;P"#08-:@Y.#5H.'@Y.3AP"#08-7@T&!
M7I&^E;V7;9)NB.8`E=N.YXWLB\:"S([`C7.13X+)BFV41H+PBX&"WX+I@N:"
MI(+)@K6"W(*W@JF!2`"1MHW=@K6"R(*B@T^#BX%;@W:"\(WMCYR"M8+F@J2"
MQH*U@MR"M8*]@4(`D;:-W8*U@LB"HH-!@TZ#6H-8C*""\(WMCYR"M8+F@J2"
MQH*U@MR"M8*]@4(`D;:-W8*U@LB"HH-!@TZ#6H-8C*""\)72CU>"M8+F@J2"
MQH*U@MR"M8*]@4(`D;:-W8*U@LB"HHNDETR"\)72CU>"M8+F@J2"QH*U@MR"
MM8*]@4(`D:Z0JP""5XR.`(-)@5N#6(-G@XF#BH-!`(-)@5N#6(-G@XJ#08ND
MF&&-D0!!=71H7V-Y<G-Q;#H@E4N7=H+(24U!4(IGDJ.+0)1<@JJ,J8+"@JF"
MZ(+<@KF"\8%"`$%U=&A?8WER=7,Z((-O@V*#3H-'@Y.#:(+-E4N7=H+(E%R7
MS8+PETR"M8+$@J*"W(*Y@O&!0@!!=71H7V-Y<G5S.B"7=HN!@K>"Z6EM87"*
M9Y*C@JJ,J8+"@JF"Z(+<@KF"\8%"`$%U=&A?9G1P.B!&5%"*9Y*CBT"47(*J
M@MV"PH*I@NB"W(*Y@O$N(%!(4(+P("TM96YA8FQE+69T<""#28-V@U:#AX.3
M@O""PH*O@L2#4H.3@W"#0X.+@K6"R(*H@K6"Q(*M@KZ"LX*B@4(`075T:%]I
M;6%P.B!)34%0BF>2HXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(`075T:%]K<F(U
M.B!K<F(UBF>2HXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(`075T:%]L9&%P.B!!
M8W1I=F4@1&ER96-T;W)Y((+%@LR#AH%;@U62QXG!@LV#5(-\@5N#9X*S@NJ"
MQ(*B@MR"N8+Q`$%U=&A?;&1A<#H@06-T:79E($1I<F5C=&]R>2""Q8+,@X:!
M6X-5C>V/G(+-@U2#?(%;@V>"LX+J@L2"HH+<@KF"\0!!=71H7VQD87`Z($Q$
M05"*9Y*CBT"47(*JC*F"PH*I@NB"W(*Y@O&!0@!!=71H7VQD87`Z((.&@5N#
M52`E<R""\)+'B<&"Q8*K@MR"N8+Q@4*#5(%;@V^"S(F>DYHZ(`!!=71H7VQD
M87`Z((.&@5N#52`E<R""\(WMCYR"Q8*K@MR"N8+Q`$%U=&A?;&1A<#H@@X:!
M6X-5("5S((+PC5B05H+%@JN"W(*Y@O$`075T:%]L9&%P.B!!8W1I=F4@1&ER
M96-T;W)Y((+%@LR#AH%;@U6-6)!6@LV#5(-\@5N#9X*S@NJ"Q(*B@MR"N8+Q
M`$%U=&A?;6-A;#H@34-!4(IGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"`$%U
M=&A?<VUB875T:#H@<VUB875T:(IGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"
M`$E-05"#5(%;@V^"Q8+,E$:/V(+)CKB4<X*U@MR"M8*]@4(`E$:/V(+)CKB4
M<X*U@MR"M8*]`)1&C]B"R8ZXE'."M8+<@K6"O8%")7,`4D%$2553@U2!6X-O
M@LF"YH+HE$:/V(*JBY&4VX*S@NJ"W(*U@KV!0@!&5%"#5(%;@V^"S)1&C]B"
MR8ZXE'."M8+<@K6"O8%"`%--0H-4@5N#;X+,E$:/V(+)CKB4<X*U@MR"M8*]
M@4(`CF>7<(G"E%R"R(-T@T*!6X.+@VB!1@"#08-;@XN#;X-#@U>#@X.3BZ28
M88V1`)1WC&D`E'>,:9!&`$ME<F]B97)O<R"#<(-8@X^!6X-H@JJ6LXSX@L6"
MMX%"`$ME<F]B97)O<R"#AH%;@U66O(*JEK.,^(+%@K>!0@"#;X-N@WT`@V^!
M6X.,@5N#DP"#;X.3@T^#B8-F@U:#A9!LEJ^+I)AAC9$`@V^#BX-O@VB#6`"*
M[I9[@T^#B8-T@T*#3H-8@LR#9H-"@XR#3H-G@XJ!6R`B)7,B((*J@J""Z(+<
M@KF"\8%"`(KNCX"0_`"#>(.)@XN!6X-6BZ2888V1`(-X@XN#38%;`(-X@XJ!
M6X-9`(-X@VF#DXNDF&&-D0"#;X-^@X6!6X-?@6F/E).'@6H`@W6!6X->@Y.)
MI(V1`))AD+:3^@"#=8.-@V*#3B`B)7,B((+,@T&#=H.*@U"!6X-6@X>#DR`B
M)7,B((*J@J""Z(+<@KF"\8%"`(-U@XV#8H-.D-V2Z`"#=8.-@V*#3H->@T.#
M=@"1OHZ:`(-[@XJ#<H-!BZ2888V1`(-U@V*#3H-]@5N#3@")CP")CX+,D;Z"
MLX%&`(F/`(-[@UB#:H-!@46#=X.+@V.#1H-3@W*#:0"#>X-C@X^#:8NDF&&-
MD0"#=8%;@WB3AP"#=8.)@U>#BP")<)?,@T.#DX-HCY23AP"#=8.+@VR#0X%%
M@U^#BX-4@XF!6X.``(-U@XN#2X.*@T$`B=./\(^1@JL`@W6#BX-,@VF#=(-`
M@UP`@W6#BX.3@U>+I)AAC9$`0TU3`$-20P!#4DP@E'J5>H-\@T.#DX-G`%]%
M@UJ#BY&ND*LN+BX`@TR#@X-B@U:#A8+,CXF*^HF[@JJ*KI>Y@K6"W(*Y@O&"
MQ8*U@KV!0@"77)+HE5P`@TJ#DX-[@U>#00"#2H.!@XN!6X.3BZ2888V1`(-P
M@UB#CX%;@VB"S8ZIDZZ"Q8+-@XJ#6H-B@V>"Q8*K@MR"N8+Q@4**QY>=CM*"
MR9A!EXV"M8+$B;J"LX*B@4(`@W2#0(-#@XL@(B5S(B""R8^1@J^"W(*Y@O&!
M0@"*3Y64@LR#6H-B@U:#AX.3@VZ#DX-H@XF!6X+-BL>7G8+%@JN"W(*Y@O&!
M0@!)34%0((-4@5N#;X+)D-J1L8+%@JN"W(*Y@O&"Q8*U@KTZ("5S`(-T@T"#
M0X.+("(E<R(@@JJ*2H*O@MR"N8+Q@4(`@TJ#:8-?`(-,@X.#DX-:@XL`C^&*
M497QC9""\(-,@X.#DX-:@XN"MX+I`(-T@T"#0X.+("(E<R(@@O"-[8^<@L6"
MJX+<@KF"\8%"`(WLB\:#9H-"@XR#3H-G@XJ"JHRIE72"J8+H@MR"N8+Q@4(`
M)W1A<F=E=$9I;&4G((-P@XF#@8%;@UZ"R(*U@L6"S9&QC7."Q8*K@MR"N8+Q
M@4(`@V:#0H.,@TZ#9X.*@5L@(B5S(B""\(WMCYR"Q8*K@MR"N8+Q@4(`C>V/
MG(+%@JN"W(*Y@O&!0HYQD;>"JB`E9""1MHW=@K6"W(*W@4(`E<""UY'6@J:"
MS)'.C]N"S)"4@JJ5VY&V@K."ZH+$@J*"Z9"4@L:-AX+M@LB"HH+,@L65P(+7
MD=:"IH*J@L6"JX+<@KF"\8%"`(YWDNB"LX+J@KV4U(V&@LF#@8-B@UJ!6X-7
M@O"4>I&7@L6"JX+<@KF"\8+%@K6"O8%"`(-*@5N#?(-X@XN#9HNDF&&-D0"5
M7)'H`(-,@X.#BH-!`)6JE]Z"QH.)@WB#BP"#4(-#@WV#DX^4DX<`C&>1T9-D
MF&(`@UJ#BY&ND*L`@UJ#BY:$D9"!1@"#6H.+D:Z0JP"#6H.+EUV4DH%&`(QG
MD=&39)AB`)*&B9L`DH:)FX-!@W2#BH-*BZ2888V1`(_8EKZ/D8+,C]J-UP"/
MV):^CY&"S(^*ETR.T@"/V):^CY&#?(.*@U:!6P"#8(.#@VB+I)AAC9$`E<^-
M6`"#<(-8@X^!6X-H@O"5SXU8`)-DCG&#@8-#@XN"R8YGEW""MX+IEKR13X+&
M@T&#:(.,@UB"\)7/C5B"M8+<@K>!0@",NXW=@LR0W9+H@L6"S8-P@UB#CX%;
M@VB"S)7/C5B"\(-4@WR!6X-G@K6"Q(*B@MR"N8+Q@4**QY>=CM*"R9A!EXV"
MM8+$B;J"LX*B@4(`7TN#BH.3@TZ"\(-@@T:#8H-.+BXN`(-@@XJ+I)AAC9$`
MDH:)V)!LEJ^+I)AAC9$`@T&#=H.*@U"!6X-6@X>#DY%)D?"!1@"#<(-8@X^!
M6X-H@O"129'P`(.&@5N#59:\@O"129'P`)/ZE7257(ZFC&".KH%&`(-.@XJ#
M6(-]@UB3AP"#3H.)@UB2Z(M@("5S((*JC*F5=(*I@NB"W(*Y@O&!0@!-4RU/
M9F9I8V6"S(->@T^"\([F@NB/G(*M`(R?C?6/P8N.`(.&@5N#58+,D=Z+CH%&
M)7,`@X:!6X-5C\&+C@"#AH%;@U6#9H%;@UZ/P8N.`(-.@XJ#8H-.@K>"Z8+&
MCI^"U@"#18-"@Y.#:(-%@O"5PH*V@ND`@U*#4H-8CY23AP"#5(-#@VB#;X%;
M@O"/](+>`(-2@XV#DX-R@T&+I)AAC9$`D$8`D$:129'P`)!&D4F1\`"7\8%&
M`)?Q@UZ#0X-G@XL`@U*#?H-B@TZ#6`"#4H-]@Y.#:`"#4H-]@Y.#:(-6@T:#
MBP"#4H.!@Y.#9P"+I)+*EKP`@U*#@H.-F$&-AP")[X[0`)#=DNB"S(VWE:H`
M4$1!@4&#6(-]@5N#9X-T@TB#DX%!3W5T;&]O:X+&@LR3KXKZ@O"0W9+H@K6"
MW(*W@4(`D-V2Z(+-C]R6H8KZC,"0V(+J@L6"MX%"`"5S((+PD-V2Z(*W@ND`
M@W"#6(./@5N#:(+PBFV41@"#4H.3@U.+I)AAC9$`@U*#DX-3EJ^.Y8NDF&&-
MD0"0VI&QCKB4<X%"`)#:D;&.N)1S@48`C/:/3XRN@U2!6X-O@M:"S)#:D;&"
MJHN1E-N"LX+J@MR"M8*]@4(`C/:*2HRN@U2!6X-O@M:"S)#:D;&"JHN1E-N"
MLX+J@MR"M8*]@4*7G9=2@48E<R`H)7,I`$944(-4@5N#;X+6@LR0VI&Q@LF.
MN)1S@K6"W(*U@KV!0@"809>-D.8`F$&7C9#F@LV#08-H@XR#6)*@@LF2QXG!
M@K."ZH+<@K6"O8%"`(BSCVN#=(-`@T.#BX+,@U*#DX-E@Y.#8X->@T.#=H%&
M`"(E<R(@@LR3X)=E`)&Q@JT`@TZ#8H-.CY23AP"#4H-S@5L`@U*#<X%;CKB4
M<X%&)7,`D4F1\)3-B,V"\(-2@W.!6P"#4H-8@UZ#BH-*BZ2888V1`(-2@5N#
M9X-7@WN#CX%;@XN+I)AAC9$`@X&#8H-:@5N#5X+,(%!'4""(PXV&B;N"JH+%
M@JN"W(*Y@O&"Q8*U@KV!0@"#@8-B@UJ!6X-7@LP@4$=0((^0EKR"JH+%@JN"
MW(*Y@O&"Q8*U@KV!0@"#@8-B@UJ!6X-7@LP@4R]-24U%((C#C8:)NX*J@L6"
MJX+<@KF"\8+%@K6"O8%"`(.!@V*#6H%;@U>"S"!3+TU)344@CY"6O(*J@L6"
MJX+<@KF"\8+%@K6"O8%"`)A!EXV0YH+PDL>)P8+%@JN"W(*Y@O&"Q8*U@KV!
M0B5S`$Q$05`@@U2!6X-O@LF#;X-#@Y.#:(+%@JN"W(*Y@O&"Q8*U@KV!0@".
M8XV"@JJ*;91&@L6"JX+<@KF"\8+%@K6"O8%")7,`3$1!4""#5(%;@V^"R9#:
MD;&"Q8*K@MR"N8+Q@L6"M8*]@4(`1E10((+%@U2!6X-O("(E<R(@@LF0VI&Q
M@L6"JX+<@KF"\8+%@K6"O3H@)7,`D9>039#F@XJ#6(-G@JJ-[)"L@L6"JX+<
M@KF"\8+%@K6"O8%")7,`4$=0((-F@5N#7H+,E9R-AHF[@JJ"Q8*K@MR"N8+Q
M@L6"M8*].@!3+TU)344@@V:!6X->@LR5G(V&B;N"JH+%@JN"W(*Y@O&"Q8*U
M@KV!0@"809>-D.:"JHWMCYR"Q8*K@MR"N8+Q@L6"M8*]@4(E<P"1EY!-D.:#
MBH-8@V>"JHWMCYR"Q8*K@MR"N8+Q@L6"M8*]@4(E<P"0W9+HC5B05I=P@UB#
M3H.*@W:#9R`B)7,B((+PC>V/G(+%@JN"W(*Y@O&"Q8*U@KV!0@".\Y!-CM*"
MS)-DCG&#@8%;@XN#08-H@XR#6(*JBFV2Z(+%@JN"W(*Y@O&"Q8*U@KV!0@"#
M08-H@XR#6)*@@JJ*KI%3@LF"S8[FD[Z"Q8*K@MR"N8+Q@L6"M8*]@4(`D9>0
M39#F@XJ#6(-G@JJ*KI%3@LF"S8[FD[Z"Q8*K@MR"N8+Q@L6"M8*]@4(`D9>0
M39#F@XJ#6(-G@JJ*KI%3@LF"S8[FD[Z"Q8*K@MR"N8+Q@L6"M8*]@4(`@UB#
M9X.)@V6#5X%;("(E<R(@@O"#C8%;@VB"Q8*K@MR"N8+Q@L6"M8*]@4(`36MD
M:7(@(B5S(B""R8ZXE'."M8+<@K6"O8%"`(SVBDJ,KH+PC*Z#5(%;@V^"J8+G
MCN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0@`B)7,B((+PCY&"JXV>@MV7<(+)@TF!
M6X-V@Y."Q8*K@MR"N8+Q@L6"M8*]@4(`)7,@@O"#28%;@W:#DX+%@JN"W(*Y
M@O&"Q8*U@KV!0@"5VX[GC>R+QH."@U>#A8%;@XL@)7,@@O"*2H*O@MR"N8+Q
M@L6"M8*]@4(`@V:#0H.,@TZ#9X.*@5L@(B5S(B""JHI*@J^"W(*Y@O&"Q8*U
M@KV!0@!,1$%0((-4@5N#;X+)D-J1L8+%@JN"W(*Y@O&!0@`E<R""JI/'@MV/
M;X*Y@MR"N8+Q@4(`EW:+@8*S@NJ"O8.&@5N#58+,@W"#6(./@5N#:(+P@XJ#
M6H-B@V>"Q8*K@MR"N8+Q@L6"M8*]@4*"HH*M@L*"J8*@@NF"HH+-D5."Q(+,
MC^Z5\8+-BM2(X8+!@L2"HH+<@K>!0HW$DWB.CH*U@L2"W8+I@JF*QY>=CM*"
MR9A!EXV"M8+$B;J"LX*B@4(`04-,((+PCN:3OH+%@JN"W(*Y@O&"Q8*U@KT`
M@T&#:(.,@UB2H(+PCN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0B5S`)&7D$V0YH.*
M@UB#9X+PCN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0B5S`)&7D$V0YH.*@UB#9X+P
MCN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0B5S`(-4@5N#;X+,BT"47(CJEY>"\([F
MD[Z"Q8*K@MR"N8+Q@L6"M8*]`)#=DNB"\(RS@LF6WX*Y@MR"N8+Q@L6"M8*]
M@4(`(B5S(B"#9H-"@XR#3H-G@XJ!6X*JC>V/G(+%@JN"W(*Y@O&!0@`E<R"0
MW9+H@O"5VY&V@L6"JX+<@KF"\8+%@K6"O8%"`)#=DNB"S(-O@V*#3H-!@V*#
M=H+PE=N1MH+%@JN"W(*Y@O&"Q8*U@KV!0@"0W9+H@LR#;X-B@TZ#08-B@W:"
M\)7;D;:"Q8*K@MR"N8+Q@L6"M8*]@48E<P"0W9+HC5B05I=P@UB#3H.*@W:#
M9X+P("(E<R(@@LF5VY&V@L6"JX+<@KF"\8+%@K6"O8%"`)#=DNB"S(-O@V*#
M3H-!@V*#=H-T@T"#0X.+("5S((+PE=N1MH+%@JN"W(*Y@O&"Q8*U@KV!0@"0
MW9+H@W2#0(-#@XL@)7,@@LF5VY&V@L6"JX+<@KF"\8+%@K6"O8%")7,@@LF6
MWX+!@L25VY&V@TF#=H-6@X>#DX+PCL"-<X*W@NF"J8%!CNB"Q8*Q@LR)YI;*
M@LR#4H%;@VB"\"`E<R""R8-2@W.!6X*U@L2)NH*S@J*!0@!,1$%0((-4@5N#
M;X*JC)^-]8+%@JN"W(*Y@O&!0@`B)7,B((+PC>V/G"AU;FQI;FLI@L6"JX+<
M@KF"\8+%@K6"O8%"`)A!EXV0YH+PC5B05H+%@JN"W(*Y@O&"Q8*U@KV!0B5S
M`)&7D$V0YH.*@UB#9X+PC5B05H+%@JN"W(*Y@O&"Q8*U@KV!0B5S`"(E<R(@
M@LR0W9+H@JJ/D8*KC9Z"WX+<@KF"\8%&)7,`36]Z:6QL82""S(-4@T.#:(-O
M@5N"JHRIE72"J8+H@MR"N8+Q@4*#5(-#@VB#;X%;@O"*2H*B@L2)NH*S@J*!
M0@"-D0"-[)"L`)!6BTN-[)"L`(-4@W6#=(-(@XN#7X+PC>R0K`"-[)"LCM*"
MS(-!@TZ#6H-8C*``@TZ#C(-7@V*#9X-*@5N#:)34C88`@TZ#C8-!@V"#08ND
MF&&-D0"#3(.%@5N#;XNDF&&-D0",NXW=@LR#6H-B@U:#AX.3`(R[C=V"S(Z>
MBM0`C+N-W8+,(%523"""S0",NXW=@LR#AH%;@U6!6P`E<R""UH+,@XV#3X-)
M@Y..GH+)CL"-<X*W@NF#7H-8@TZ"\)#=DNB"M8+<@K>!0@"0V(+HCN:"Z`"1
M29'PE,V(S8+PD-B"Z([F@N@`@TR#=H.-@UB+I)AAC9$`@V"#1H-2BZ2888V1
M`)/Z`):(D_H`1&%T851R964@B7N7EP"#9H%;@UZ#>(%;@UB.48_&`)/ZE70`
M@V:!6X->CO.030"3^I5TD4F1\`!?3)?Q@LR-[8^<`#$RC(X`CUR0:9"4`))I
MB;J"L(+PD/."K0"#9H-T@TB#BX-G`(-F@W2#2(.+@V>01@"#9H-T@TB#BX-G
M($E$`(-F@W2#2(.+@V<@<VAE;&P`C>V/G`"#6H.+C>V/G`"#3X.+@5N#=H+P
MC>V/G`"#C8-/@LR-[8^<`(-!@TZ#6H-8C*""\(WMCYP`@UJ#BXWMCYP`E_&"
MS(WMCYP`D>.1UH-E@Y.#=H.,@5N#9X+,C>V/G`"#@8-B@UJ!6X-7@O"-[8^<
M`"(E<R(@@LR#08-.@UJ#6(R@@O"-[8^<`"(E<R(@@LR#08-.@UJ#6(R@@L:"
MNX+,@U2#=8-!@TZ#6H-8C*""\)%3@L2-[8^<@K6"W(*W@JF!2`"-<X+,C>V/
MG`"129'P@K6"O4E$@O"-[8^<`(-4@W6#=(-(@XN#7X+PC>V/G`",NXW=B,J2
M=8+,E_&"\(WMCYP`C+N-W8C*DG6"S(US@O"-[8^<`)#=DNB-6)!6EW"#6(-.
M@XJ#=H-G("(E<R(@@O"-[8^<@K6"W(*U@KV!0@"4>I&7CIZ*U`"#9H.3@WV!
M6X-.`(_ABE&3X)=E@LR0X):^`)#@EKX`C]J-UX%I2&]R9&6"S(.-@T^#=(-`
M@T.#BX+@CE&/QH%J@48`C]J-UX+-BL>7G8[2@LR"O8+?@LF+3)A>@K."ZH+<
M@K6"O8%"`(I*E*T`C;:"J8+GB46"U@")18*I@N>-MH+6`#(TCIZ*U)5<CJ8`
ME5R.IH-)@W:#5H.'@Y,`@U>#=8-@BZ2888V1`(WMCYR"M8+(@J(`;6%I;G1E
M;F%N8V4N<&AP((+)DKR0VH-!@TZ#6H-8@K6"R(*B@L6"K8*^@K."H@"-Q8^)
M@LR7\8*J@W2#0H%;@XN#:):\@O"*W(+Q@L6"HH+<@K>"J3\@@KN"I(+(@N>#
M8(-&@V*#3H*U@L2"K8*^@K."HH%&`(-H@WZ#:H-*`(-H@WZ#:H-*BZ2888V1
M`(-!@TJ#18.3@V>"JI5+EW:"R(+G@U2#0X.3@T&#8H-V@4(`@U^#18.3@XV!
M6X-H`"5S((+,@U^#18.3@XV!6X-H`)"VD*R"LX+J@KV0W9+H@O`@4$A0((-8
M@TZ#BH-V@V>"\(+&@K6"Q(-?@T6#DX.-@5N#:(*W@NF!0@"39(YQ@X&!6X.+
M`(-'@TZ#08-H@XN+I)AAC9$`E=*/5P"#=8.-@V*#3H+,E=*/5P"#3X.+@5N#
M=H+,E=*/5P"#08-.@UJ#6(R@@LR5TH]7`(-!@TZ#6H-8C*""S)72CU<`)7,@
M@LR#08-.@UJ#6(R@@LR5TH]7`(-)@W:#5H.'@Y."S)72CU>!1@`B)7,B((+,
M@T&#3H-:@UB,H(+,E=*/5P`E<R""S(-!@TZ#6H-8C*""S)72CU<`@T>#5X-V
M@V>!18-!@XF#=8NDF&&-D0"#1X.+@U2#BX-O@VB#BXNDF&&-D0"39(YQ@X&!
M6X.+`$6#@8%;@XN#08-H@XR#6`!%@X&!6X.+@T&#:(.,@UB"JHCJDG:"M8+(
M@J^"ZH+.@J*"KX+<@KF"\8%"`$6#@8%;@XN#08-H@XR#6(IME$8`B_.#@8-B
M@UJ!6X-7@L6"MX%"`(F]@N",J8+"@JF"Z(+<@KF"\8%"`(OS@LR,GXWUC.H`
M@TV#@X.)@XJ!6X*I@N>)YI&<@O"1?9/\@L6"JX+I@N:"I(+)@K6"W(*W@JF!
M2`")18-.@XJ#8H-.@L6#@8-J@X6!6X+PE5R.IH*U@MR"MX*I@4@`@T>#9H-"
M@UZ!6XGFELJ"\)'E@JN"K0""H(+(@KV"S(-P@UB#CX%;@VB"\(.*@UJ#8H-G
M@K>"Z8Z>@LR7<)!3@LR"O8+?@LR.OY;B@O"3_)?-@4*7X8*F@LZ!08%U@WF#
M8H-G@LR6O)%/@LV!2(%V@48`B>:1G(+,55),@O"3_)?-`)#4D[F#38-J@T&+
MI)AAC9$`@T>#BH-G@XJ#00"#1X.)@5L`@W6#C8-B@TZ-[)"L@T>#B8%;.B`E
M<RX`DZ^*^H.-@T^"S(WMCYR#1X.)@5LZ("5S+@"3X)=ECN:3OH-'@XF!6SH@
M)7,N`(-P@UB#CX%;@VB-6)!6@T>#B8%;.B`E<RX`@X&!6X.+@T&#:(.,@UB"
MS(-'@XF!6X+%@K>!0@`B)7,B((+,CY&"JXV>@MV#1X.)@5N"Q8*W@4(`@T>#
M6(-G@VJ#08NDF&&-D0"#1X-@@TF#<X-!`(.(@5N#C8-B@W``,365JI:(`#*5
MJI:(`#,PE:J6B``UE:J6B`"#C8-/@T.#DY:(`#,PE:J6B``QE:J6B`".=Y+H
MDFR"S)?A`([`C7,`DU>*2@"#5(-#@VB#;X%;@O"35XI*`"<I)R""\)-7BDH`
METR,^(KZC,``CG>0E`"13XQID$8`D-V2Z(+P($944"""Q8-!@V*#=H.-@5N#
M:(*W@ND`@W:#C(-T@T"#C(.3@UB0W9+H@O".YI.^@L6"JX+<@KF"\8%"`$Q$
M05`@@U2!6X-O@LF0VI&Q@L6"JX+<@KF"\8+%@K6"O8%"`%--0B"#5(%;@V^"
MR9#:D;&"Q8*K@MR"N8+Q@L6"M8*]@4(`(B5S(B""J8+G@LR#4H-S@5N"R8ZX
ME'."M8+<@K6"O8%"`"(E<R(@@M:"S(-2@W.!6X+)CKB4<X*U@MR"M8*]@4(`
MD%:+2X+,(%-!4TP@D-J1L8+)CKB4<X*U@MR"M8*]@4(`(B5S(B""UH+,B-J3
MKH+)CKB4<X*U@MR"M8*]@4(`CN:3OH+)CKB4<X*U@MR"M8*]@48E<P"#=(-(
M@5N#3H.)@Y.#:(^4DX>!:8-]@XN#<H-I@UB/E).'@6H`@W2#1H.-@5N/E).'
M`))VEKV328-'@XF!6X%&`$9!6`!&05@`@E&,C@"#=(-"@U>!6X^4DX>+I)AA
MC9$`@W2#0(-#@XL`@W2#0(-#@XN0E#H@)7,@@W2#0(-#@XL`@W2#0(-#@XN0
ME#H@)7,@@W2#0(-#@XL`@W2#0(-#@XN#?8-L@5N#5X.#`(-T@T"#0X.+EKP`
M@W2#0(-#@XN129'P`(-T@T"#0X.+@T&#8H-V@XV!6X-H`(-T@T"#0X.+@T&#
M8H-V@XV!6X-H@LV#5(-\@5N#9X*S@NJ"Q(*B@MR"N8+Q@4(`@W2#0H.+@UX`
M@W2#0H.3@XF#DX-HBZ2888V1`(_CC+>"S(R.`(-T@TB#BX-?@5L@)7,@@JJ"
MH(+H@MR"N8+Q`)6VCIJ01@")YI&<@O"#5(-\@5N#9X*U@LB"HH-U@XF#18-5
MEW``@W"#6(./@5N#:(+PEEF"ZH+$@K6"W(*B@MR"M8*]@JF!2`"#=(-(@5N#
M@`"#=(-(@5N#B8.``(O@`)AG`(-T@XF#DX-8BZ2888V1`(-T@XF#DX-8@6F6
M>XV1@6H`@W2#B8.3@UB7S(--@T&#:0"#=(.)@Y.#6)?,@WR#BH-L@U:#00"#
M=(.)@Y.#6)?,B\F3[(^4DX<`C]J"M8*BD."6O@"6GHR.`(Z!EKP`@TN#>X.3
MBZ2888V1`(GFD9R"\([F@NB/;X*W@TV#@X.)@XJ!6P"#38.#@XF#BH%;@48`
M@TN#DX-R@T&+I)AAC9$`)7,@C5R0K(_NE?&"\)"VD*R"MX+I`)"VD*R"LX+J
M@KV#4H%;@V@`@T^#BX-7@T&+I)AAC9$`@VB#0X-CF$&638NDF&&-D0"#2X%;
M@VF+I)AAC9$`@U>#=8.)@XN#7H.+`)"I`(NDDLJ#28-V@U:#AX.3`$=O;V=L
M92"#?8-B@W8`1V]O9VQE((R?C?4`@TV#BH-6@X.+I)AAC9$`@T^#BH%;@Y.#
MB8.3@V@`@T^#C(-I@U\`@T^#BX%;@W:*QY>=`(-/@XN!6X-VEKR"S8OSE)*"
MQ8+-@LB"HH*Q@L8`1W)O=7!?;&1A<#H@@T^#BX%;@W8@)7,@@O"2QXG!@L6"
MJX+<@KF"\8%"@U2!6X-O@LR)GI.:.B``1W)O=7!?;&1A<#H@@T^#BX%;@W8@
M)7,@@O"-[8^<@L6"JX+<@KF"\0!'<F]U<%]L9&%P.B"#3X.+@5N#=B`E<R""
M\(U8D%:"Q8*K@MR"N8+Q`(-/@XN!6X-V`(-/@T&#:(.+@5N#=I.'`(-/@T&#
M@).'`(-/@T&#98-]@XF+I)AAC9$`@TN!6X.3@U>!6Y.'`(-1@UB#9X-!@TZ#
M6H-8C*``@U&#6(-G@W6#8H-.`(--@VJ#08NDF&&-D0"#38-J@T&#<H-4@T6+
MI)AAC9$`@TN#0X-!@VF+I).OBZ2888V1`$A45%`@E$:/V(*J@MV"PH*I@NB"
MW(*Y@O&!0@"#;H-#@V"+I)AAC9$`@VZ#8H-6@X6#08.+@U.#BH-9@X``@W>#
M8H-?`(-W@V*#7P"#;H%;@VB!18-]@TZ#:(-I@XN#:(^4DX<`C8*"LP"#=X.+
M@W8`E+R+A0"#>H%;@X``@XV!6X-]ED")I)*A@6F#;X-@@TJ#DXYSC9&!:@"#
M>H%;@X``CJF1[H+,CUJ/B@"#>H%;@X"#9H-"@XR#3H-G@XJ!6P".J9'N@LR3
M9)ABE-2-A@"#>H.3@U>#A8.)@UB+I)AAC9$`C8&-8`!(;W)D90!(;W)D92]+
M;VQA8CH@E7.0LX+((%A-3""#9H%;@UX@)7,@@JJ#@8-B@UJ!6X-7("5S((+%
MC)^/;X*S@NJ"W(*U@KT`2&]R9&4O2V]L86(Z((-)@W6#5X-&@TZ#9R`E<R""
MR9'.B9Z"MX+I@X&#8H-:@5N#5X+-@J""Z(+<@KF"\0!(;W)D92]+;VQA8CH@
M@TF#=8-7@T:#3H-GC%X@)7,@@LV#@8-B@UJ!6X-7("5S((+)@LV"H(+H@MR"
MN8+Q`$AO<F1E+TMO;&%B.B`E<R""S8WMCYR"LX+J@MR"M8*]("(E<R(`2&]R
M9&4O2V]L86(Z(%!(4""*9Y*C("=D;VUX;6PG((*JE4N7=H+%@K<`2&]R9&4O
M2V]L86(Z((-)@W6#5X-&@TZ#9R`E<R""S"!834P@@V.#BH%;@JJ-[)"L@L6"
MJX+<@KF"\0!(;W)D92]+;VQA8CH@)7,@@JJ-[8^<@L6"JX+<@KF"\2`B)7,B
M.B`E<P!(;W)D92]+;VQA8CH@)7,@@LP@34E-12!)1"""JH[FD[Z"Q8*K@MR"
MN8+Q`$AO<F1E+TMO;&%B.B`E<R""QI.OBOJ"Q8*K@MR"N8+Q("(E<R(Z("5S
M`$AO<F1E+TMO;&%B.B"3KXKZ@L6"JX+<@KF"\8%&)7,`2&]R9&4O2V]L86(Z
M("(E<R(@@LV5<Y:^@LB+I)=,@L6"MP"0A96]D/P`@J*"K8+"@LR7\8+PC(N-
MAX*U@MR"MX*I@4@`@W2#0H%;@XN#:"B-<RF"S)"4@LV"HH*M@L*"Q8*W@JF!
M2`""HH*M@L*"S(US@O",BXV'@K6"W(*W@JF!2`"#;H.3@TN#BH%;BZ2888V1
M`$E-05`@@X&!6X.+@WN#8H-.@UB"S(WLD*R"R8ZXE'."M8+<@K6"O3H@)7,`
M24U!4""#@8%;@XN#>X-B@TZ#6(+,C>V/G(+)CKB4<X*U@MR"M8*].B`E<P!)
M34%0((.!@5N#BX-[@V*#3H-8@TZ#2(%;@UZ"S(WLD*R"R8ZXE'."M8+<@K6"
MO3H@)7,`25`@@T&#:(.,@U@`25`@@T&#:(.,@UB"JH*@@NB"W(*Y@O&!0@!)
M4(-!@VB#C(-8@JJ+EHG"@K."ZH*]0TE$4H-U@XV#8H-.D^""R8*@@NB"W(*Y
M@O&!0@!)4)65C;V(X92]@L6"MX%"`(-!@T.#6(.)@Y.#:(NDF&&-D0"#08-#
M@U*#DX+,@MT`)7,@@LR#08-#@U*#DP"#08-#@U*#DX+&@V6#3(-8@V<`242"
MS):\D4\`@N""M8+@D+."M8*ME5R.IH*S@NJ"R(*B@LB"YX%!)7,@@K6"Q)!6
M@K6"HH-%@T.#DX-H@5N"\(I*@J*"Q(FZ@K."HH%"`(+@@K6"X"!);G1E<FYE
M="!%>'!L;W)E<B""\(YG@L&"Q(*B@L2!08-!@T.#4H.3@JJ57(ZF@K."ZH+(
M@J*"R(+G@4&"L8*Q@O"129'P@K6"Q(FZ@K."HH%"`(GFD9R#=H.,@W*#A8%;
M`(GFD9P@55),`(GFD9P@55),.@")YI&<`(-#@Y.#?(%;@V>!08-8@V6#8H-V
M("5D`(-#@Y.#?(%;@V>"LX+J@KV#=(-"@5N#BX-H@48@)7,`@T.#DX-\@5N#
M9X*S@NJ"O8-T@T*!6X.+@VB!1@"*U(CA@L&"O8-!@TZ#5H.'@Y.#4H%;@VB"
MJI=>@J:"YX+J@L2"HH+<@K>!0@"#AH%;@U66O(*I@W"#6(./@5N#:(*JD+."
MM8*M@J""Z(+<@KF"\8%"`(.&@5N#59:\@JF1XY'6@T&#:(.,@UB"JI"S@K6"
MK8*@@NB"W(*Y@O&!0HW$DWB.CH*U@L2"W8+I@JF!08K'EYV.TH+)F$&7C8*U
M@L2)NH*S@J*!0@"2:8FZ@K""\)!;@JT`@T.#DX-H`(S"E<J#AH%;@U4`@T.#
MDX-H@VR#5H-!BZ2888V1`(_NE?$`@T.#DX-T@TB#@8%;@U:#AX.3`%]/C.."
MZX+)E_&"\)%]D_P`B>:1G(+PD7V3_`"57(+PD7V3_`"#BH.3@TZ"\)%]D_P`
M7T.13X+)E_&"\)%]D_P`C+N-W8C*DG6"S(SC@NN"R9?Q@O"1?9/\`(R[C=V(
MRI)U@LR13X+)E_&"\)%]D_P`C+N-W8C*DG6"S(SC@NN"R8US@O"1?9/\`(R[
MC=V(RI)U@LR13X+)C7."\)%]D_P`C+N-W8C*DG6"S(SC@NN"R9)IEXZ"\)%]
MD_P`C+N-W8C*DG6"S)%/@LF2:9>.@O"1?9/\`)'CD=:#98.3@W:#C(%;@V>"
MS)%]D_P`D%:"M8*B@W"#6(./@5N#:(+PCO."KX[F@NF#@8%;@XN#08-H@XR#
M6(+PD_R7S8%&`(SC@NN"R8-:@XN"\)%]D_P`D4^"R8-:@XN"\)%]D_P`C.."
MZX+)E_&"\)%]D_P`D4^"R8-:@XN"\)%]D_P`@X&#8H-:@5N#5X+PD7V3_`",
MXX+K@LF2:9>.@O"1?9/\`)%/@LF2:9>.@O"1?9/\`(SC@NN"R8US@O"1?9/\
M`)%/@LF-<X+PD7V3_`"7<)!3@LR"O8+?@LR.OY;B@LR3FH*F@O"3_)?-@48`
MB>:1G(+,D7V3_(%>E<^-6`"#BH.3@TZ"S)%]D_R!7I7/C5@`D9>039#F@LF1
MEX+I@KV"WX+,CF.-@H*JE7.1JX*U@L2"HH+<@K>!0@".8XV"@JJ5<Y&K@L6"
MMX%"`)5SD+."R"!::7`@@V:!6X->@L6"MX%"`)5SD+."R(-!@W:#BH-0@5N#
M5H.'@Y."Q8*W@4(`EK.,^(+(@V:!6X->@JJ2\8]O@K."ZH+<@K6"O2X`D9>"
MZ)#F@LR#08-H@XR#6(*JE7.0LX+%@K>!0@"5<Y"S@LB#B8-#@UJ#DX-8@TR#
M0X+%@K>!0@"5<Y"S@LB/ZH^*@JJ.=Y+H@K."ZH+<@K6"O8%"`(_CB,J"S(-!
M@TZ#6H-8C*""JI5SD+."Q8*W@4(`E7.0LX+(@W"!6X-G@VF!6TE$@L6"MX%"
M`)5SD+."R)"[E6F#4H%;@VB"Q8*W@4(`E7.0LX+(@W:#C8-G@U*#BX+%@K>!
M0@"5<Y"S@LB.\Y!-CM*"Q8*W@48B)7,B`)5SD+."R(NDETR#28-U@U>#1H-.
M@V<`E7.0LX+(E*V038RS@T&#:(.,@UB"Q8*W@4(`E7.0LX+(=6YI8V]D98-F
M@5N#7H+%@K>!0@"129'P@O"4O9-=`(-#@XF#DX%%@T.#6(.)@X"+I)AAC9$`
M@T.#B8-.BZ2888V1`(-!@T.#BX.)@Y.#:`"#?8.3DX<`@T.#6(.)@T>#BP"4
MK8USCM(`CLZ1S`"#0X->@XJ#08NDF&&-D0"#5X.#@WV#0X-*`()0C(X`D_J6
M>P"#5X.#@5N#5X%;DX<`@XB#BX-?@Y,`@E:,C@""58R.`)&U@J:"Z0"2AHF;
MD;6"I@"7O));D;6"I@"-MI&U@J8`B461M8*F`(-*@U6#=(-8@UZ#DXNDF&&-
MD0"#28.*@U>#:8.+@O"5VY&V@4@`@U"#:H-!BZ2888V1`$ME<F)E<F]S((-4
M@5N#;X*JE$:/V(N1E-N"M8+<@K6"O8%"`(RNC>R0K)/Z`(RNCG>6Y`",KI*W
M`(RNCNV7W@"39(YQC*Z"JH*W@L6"R8SVCT^,KH-4@5N#;X+)D;:-W8*U@MR"
MMX%"`(-,@XJ#;X-8BZ2888V1`)*ID4Z6KX[ECN6+8)!LEJ^+I)AAC9$`D>6*
MV):OC9$`@TZ#18-&@5N#9P"#3(.+@TV#6(NDF&&-D0!?68.,@T.#08-%@V<`
MC+Z,Z@"#B8-)@UB0;):OEJ^.Y8NDF&&-D0")NHRW@LR,C@"13XGQ@LR#C8-/
M@T.#DSH@)7,`D4^)\8+,@XV#3X-#@Y,Z("4R)',@@JF"YR`E,21S`)%/B?&"
MS(.-@T^#0X.3.B""R(*U`(.)@V>#<H-!BZ2888V1`)1ZDG4`@XR#;X-M@Y.+
MI)AAC9$`C;8`@XR#7(-GB:2-D0"#BH-X@XJ#08NDF&&-D0"1Y8.*@W*#08%%
M@T&#B8-UCM")[X[EBV"0;):O@U>#@X-]@5N#<8.*@5N#A`"#BH-Q@V6#DX-6
M@X6#7H-#@Y.,]HV1`(.*@Y.#3@"#@8%;@XN-[)"LEW""R8.!@5N#BX-!@VB#
MC(-8@LF#BH.3@TZ"MX+I`(-F@5N#7H-X@5N#6(CJEY<`@W>#BX-VC8"6VH+P
ME5R.IH*W@ND`E5R"S(CJEY<`@UJ#8H-6@X>#DX+,B.J7EXWLD*R"R8ZXE'.!
M1B5S`(.&@5N#58+,B.J7EXWLD*R"R8ZXE'.!1B5S`(.&@5N#58+,@XJ#6(-G
M@LV6LXSX@LF"R(+!@L2"HH+<@K>!0@"#BH-G@T&#:H-!BZ2888V1`(.-@5N#
M:)*&+BXN`(R[DFZ.GHK4@48`DFZ(YH+&CIZ*U`"/ZH^*`(.-@T^#0X.3`(.-
M@T^#08-%@V<`@XV#3X-#@Y,`@XV#3X-#@Y,@@UZ#6(-.`(.&@5N#59:\@JF#
M<(-8@X^!6X-H@JJ0LX*U@JV"R(*B@KV"WX+)@XV#3X-#@Y."R8ZXE'."M8+<
M@K6"O8%"`(.-@T^#0X.3@LF.N)1S@K6"W(*U@KV!0@"#38.*@U:#@Y6VCIJ!
M:8^LE;:.FH%J`(.)@V6#DY6VCIJ!:8^LE;:.FH%J`(.-@5N#?9"4CIJ!:8^L
ME;:.FH%J`(.+@TZ#6H.3@W6#BX-.D>6,]HV1`(R.`)-9E72"LX+J@KT@35,M
M5$Y%1B""S8-F@5N#7H+PBMR"\8+%@J*"W(*Y@O&!0@"#?8-*@TD`@WV#4(-H
M@VJ#08N,@X:!6X-3@UB#B8-R@T&+I)AAC9$`@WV#7X-+@UB#2H.+BZ2888V1
M`)-DCG&#@8%;@XL`@WV#B8-%@T.+I)AAC9$`@WV#C(%;@U:#00"#@H.+@V:#
M0H-UBZ2888V1`)-DCG&#@8%;@XL`@WV#BX->BZ2888V1`)!&E72"KX*S@NJ"
MO8.)@WB#BX+PD<Z)GH*S@KF"Q)6JE]Z"\(K'EYV"M8+<@K>!0@""4HR.`(-]
M@5N#5H.#@XN/E).'BZ2888V1`(-]@XN#98-"@VJ#3I.'`(-T@T*!6X.+@VB"
M\(CJDG:"LX*Y@L2"HH+<@K<`@X*!6X.*@UZ#:H-!@46#0X-8@XF#@(NDF&&-
MD0"#@H%;@XJ#5H.#@UB+I)AAC9$`@E2,C@"#?8-#@XB#8H-GDX<`@X&#DX-O
M`(.!@VJ#A8%;@X*!6X-H`(-:@XN,BXV'`)9[E;8`@X&#8H-:@5N#5X+-C)^/
MV(+%@JN"W(*U@KV"JH%!CY"6O([2@LR09XRS@LV,GX_8@L6"JX+<@KF"\8+%
M@K6"O8%"`(.!@UR#8H-H`(.!@UR#8H-H("(E<R(@@LV2Z(M@@K."ZH+$@MR"
MN8+Q`(.!@TR#5H-2C8>/3XV1`(-^@TZ#C8-L@U:#09A!EDT`36EM92!4>7!E
M`%!%05(@@W"#8H-0@5N#5X+,($A45%!?4F5Q=65S="""JHRIDY:"O8+H@MR"
MN8+Q@4(`EJ*0W9+H@L6"MX%"@K&"S(-!@W:#BH-0@5N#5H.'@Y."\(YGEW""
MMX+I@KV"WX+)@LV0W9+H@W2#0(-#@XN"\(WLD*R"MX+IE4N7=H*J@J""Z(+<
M@K>!0@"#@8-B@UJ!6X-7($E$((*JC*F3EH*]@NB"W(*Y@O&!0@!014%2((-P
M@V*#4(%;@U>"S"!-86EL((*JC*F3EH*]@NB"W(*Y@O&!0@"#6H-B@U:#AX.3
M($E$((*JC*F3EH*]@NB"W(*Y@O&!0@",C@",9Y'1@X&!6X.+`(]#D+.3^@"#
M@H.+@VB#;XNDF&&-D0"#@H-I@U*,]HV1`(."@Y.#4X.+`):(C(X`@X*#DX-G
M@UJ#B8-GDX<`C(Z7[@"#@H.-@V*#4HFDC9$`B;J"U@"-MH+6`(E%@M8`C^."
MU@")NH+6`(_C@M8`@X*#58.3@W*!6X-.BZ2888V1`(-!@TJ#18.3@V<`@T&#
M2H-%@Y.#9X_NE?$`@WZ#@X.3@WV!6YA!EDT`DZ^(TX*U@MR"N8+Q`):\D4\`
M@VF#?H-R@T&+I)AAC9$`@VF#18.+BZ2888V1`(-L@W"!6X.+B:2-D0"#28.)
M@Y.#7XFDC9$`@TF#B8.3@U^7S(-!@Y.#98-"@XN/E).'`(-L@V*#9X./@5N#
M3@""R(*U`(-T@XF#DX-8E\R#:H.%@5N#2H.,@VB#:H-!`)!6BTN5JI?>`)!6
MC(X`D%:"M8*B@X:!6X-5EKPHE$.(TRD`@VJ#A8%;@U>!6X.)@Y.#:`"05H*U
M@J*#<(-8@X^!6X-H`)!6@K6"HH-P@UB#CX%;@VB"S2`E>"""R8KZC,"0V(+J
M@LF"R(+H@MR"MX%"`)!6@K6"HH-P@UB#CX%;@VB"JHCJDG:"M8+<@KF"\8%"
M`(-J@X6!6X-8`(-J@X6!6X-8@T^#BX%;@W8`CI\`CI^"S(-)@W:#5H.'@Y,`
MCI^"S(-Y@5N#5SX`@VJ#2H.)@T^#08NDF&&-D0"#:H-7@T:!6X.+BZ2888V1
M`(-I@T.#5X-&@XJ#09A!EDV+I)AAC9$`@VJ#18-'DX<`C;>5JH+PE5R.IH*W
M@NF"O8+?@LR0W9+H@JJ"H(+H@MR"N8+Q@4(`E<^-6(+(@K6!0@""L8+,@T&#
M3H-:@UB,H(+)@LV#5(-U@T&#3H-:@UB,H(+-DL>)P8+%@JN"W(*Y@O&!0@`E
M<R""S)#=DNB/[I7Q@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0@!&5%`@5D93((+,
MC5R0K(_NE?&"JHYWDNB"LX+J@L2"HH+<@KF"\8%"`%-13"!61E,@@LR-7)"L
MC^Z5\8*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`4U%,((-*@V6#4X.*@LR-7)"L
MC^Z5\8*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`CF.-@H*J@J""Z(+<@KF"\8%"
M`)&7D$V0YH*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`@W2#0(-#@XN"JH-!@V*#
M=H.-@5N#:(*S@NJ"Q(*B@MR"N8+Q`(-!@T.#4H.3@JJ"H(+H@MR"N8+Q@4(`
MC^J/BH*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`@X&#8H-:@5N#5X*JCG>2Z(*S
M@NJ"Q(*B@MR"N8+Q@4(`EKR13X*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`E-2-
MAH*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`2%144""41H_8@LR#<(-8@X^!6X-H
M@JJ"H(+H@MR"N8+Q@4(`24U!4""41H_8@LR#<(-8@X^!6X-H@JJ"H(+H@MR"
MN8+Q@4(`2V5R8F5R;W,@E$:/V(+,@W"#6(./@5N#:(*J@J""Z(+<@KF"\8%"
M`(.-@T^#0X.3()1&C]B"S(-P@UB#CX%;@VB"JH*@@NB"W(*Y@O&!0@!005-3
M5T0@E$:/V(+,@W"#6(./@5N#:(*J@J""Z(+<@KF"\8%"`%--0B"41H_8@LR-
M7)"LC^Z5\8*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`3W!E;E-33""#=H.-@T^#
MB8.`@LR#<(-8@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0D]P96Y34TP@@LT@4$M#
M4R`Q,B""S(-F@5N#7H+PB+6"I(+,@LF52Y=V@L6"MX%"`)7;EZ^"S(-4@T.#
MDX-!@V*#=H+(@K6!0@"#3H-(@5N#7H*JD-V2Z(*S@NJ"Q(*B@MR"N8+Q@4(`
M@UJ#<(.,@5N#7H*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`BEF3EH-T@T"#0X.+
M@LB"M0"#AH%;@U66O(*I@W"#6(./@5N#:(*JD9>"YX+J@MR"N8+Q@L6"M8*]
M@4(`EK.,^(+,6$U,@V:!6X->@JJ5U(+H@MR"M8*]`))L@LB"M0"#28.*@U>#
M:8.+@LR0W9+H@W2#0(-#@XN"R8-O@5N#5X.'@Y."JH*@@NB"W(*Y@O&!0I#=
MDNB"\(W$D+:0K(*U@MR"MX%"`)#=DNB#=(-`@T.#BX+)@V^!6X-7@X>#DX*J
M@J""Z(+<@KF"\8%"D-V2Z(-T@T"#0X.+@O"-[(+HDKR"M8+$B;J"LX*B@4(`
M@LB"M0"#;8%;@W2#2(%;@TZ3AP"6:Y2\BX4`EFN#?8.*@T&#:8^4DX<`@VV#
MBX-%@T:!6XFDC9$`@K&"ZH+F@NB13P""L8+J@N:"Z(SC`(-F@T*#C(-.@V>#
MBH+%@LV"H(+H@MR"N8+Q`([`D96"LX+J@L2"HH+<@KF"\8%"`(-4@WR!6X-G
M@K."ZH+$@J*"W(*Y@O&!0@"#@8."`#$QC(X`D)0`E;:.FI"4`)?QD)0`C7.0
ME`"1EY!-D.:#BH-8@V>"\(U8D%:"O8+?@LR4U(V&@JJ.=Y+H@K."ZH+<@KF"
M\8+%@K6"O8%"`$]+`(-)@W6#5X-&@TZ#9P"#28-U@U>#1H-.@V>-[)"LCM(`
M,3",C@"#28-T@T*#6`",PX*B@W"#6(./@5N#:`",PX*B@W"#6(./@5N#:(*J
MD+."M8*M@J""Z(+<@KF"\0"#28-]@5N#DP"+I)=,@W2#2(.+@U^"S2!)34%0
M((-4@5N#;X*^@J^"JH-4@WR!6X-G@L6"JX+<@K>!0@"39(YQ@X&!6X.+@T&#
M:(.,@UB"S3&"PH*^@J^.=Y+H@L6"JX+<@K>!0@"/BI=,CM*"J8-6@UB#98.`
MBL>7G8[2@KZ"KX*JBZ273(+,CXJ73(R@@L:#08-.@UJ#6(R@@O"5SXU8@L6"
MJX+<@K<`D%:+2X-%@T.#DX-H@5N"R95<CJ8`3W!E;E-33""#1X.)@5N!1E,O
M34E-12"/D):\@K."ZH*]@W"!6X-G@JF"YX-F@5N#7H+PCN:"Z(]O@KF"W(*Y
M@O&"Q8*U@KV!0@"#28-V@U:#AX.3`"5S((-)@W:#5H.'@Y,`E-2-AI5TB=./
M\(^1@JL`D6>01`"5E(^0`)"NEYT`C+."S(-!@W:#BH-0@5N#5H.'@Y.#98.3
M@W:#C(%;@V<`D;R"S(-#@Y.#=(-(@X&!6X-6@X>#DP"/BI=,CM*"S(-!@TZ#
M6H-8C*``4$%-()1&C]B"S8YGEW""Q8*K@MR"N8+Q@4(`4$=0()-DCG&/D):\
M`%!'4""(PXV&E;8`4$=0((SVBDJ,K@!01U`@CY"6O(W/+XC#C8:)NX-F@5N#
M7@!02%"#4H%;@V@`4$A0@U:#1H.+`%!/4TE8((IGDJ."JHRIDY:"O8+H@MR"
MN8+Q`):$D9``@W"#3(-8@UZ#DX%%@T.#6(.)@X"+I)AAC9$`@W"#B8-)BZ28
M88V1`(-P@XR#6(-@@VF.J8ZAB^8`@W"#:8-]BZ2888V1`(-P@W:#08-J@X6!
M6X--@VJ#09/&EZ>-D0"#<(.)@T^#08-#BZ2888V1`(-P@UB#CX%;@V@`@W"#
M6(./@5N#:(+-D+./[8+)E<^-6(*S@NJ"W(*U@KV!0@"#<(-8@X^!6X-H@JJ0
MLX*U@JV"H(+H@MR"N8+Q`%)!1$E54R"41H_8@LR#<(-8@X^!6X-H@JJ52Y=V
M@L6"MX%"`(-P@UB#CX%;@VB"S(IME$8`@W"#6(./@5N#:#H`@W"#6(./@5N#
M:#H@`(-P@UB#CX%;@VB"JHCJDG:"M8+<@KF"\8%"`)-<@NB5=(*O`(-.@XJ#
M8H-V@WN!6X-H@JF"YY-<@NB5=(*O`(-P@U@`E=N7KY*&@LR#5(-#@Y.#08-B
M@W:!1@"#<(%;@UJ#DX-G`)7;CN>1@(WL@O".P(US@K>"Z0"#C8-/@T.#DXZ>
M@LF5VX[GD8"-[(+PCL"-<X*U@MR"MX*I@4@`@T&#3H-:@UB,H`"#08-.@UJ#
M6(R@("(E<R(@@LV-[8^<@K."ZH+<@KF"\8+%@K6"O8%"`(-!@TZ#6H-8@LV+
MD93;@K."ZH+<@K6"O0"#08-.@UJ#6(R@`(-!@TZ#6H-8C*""S(K'EYT`C,*0
M;(_NE?$`@WF#BX%;BZ2888V1`(-T@T*#BH-S@Y.+I)AAC9$`DV288@"#<X-G
M@U"#08.3DX<`@W.#3H-:@XL`C(Z"QI1.@O"3_)?-@K6"Q(*M@KZ"LX*B@4(`
MD%:"M8*BE:J7WH+,EKR13X+PD_R7S8*U@L2)NH*S@J(Z`)"S@K6"HI/ZE72"
M\)/\E\V"M8+$@JV"OH*S@J(N((R.@LR3^I"4@O"#8(-&@V*#3H*U@L2"K8*^
M@K."HH%"`(_ABE&3X)=E@O"7=I;Q@K6"Q(*RBTR3_(*M@KZ"LX*B@4(`@X:!
M6X-5EKR"QH-P@UB#CX%;@VB"\)/\E\V"M8+$@JV"OH*S@J*!0@".GX+,E;:/
MD8+PD\>"\8+%@JV"OH*S@J(N((*Q@LR#5H-8@V6#@(+PCF>7<(*W@NF"O8+?
M@LR+2Y+HCI:-@(+)DZ^(TX*W@NF52Y=V@JJ"H(+H@MR"MX%"`(-\@5N#B8.3
M@VB+I)AAC9$`DXJ56Y"4`(-\@XN#9X-+@XN+I)AAC9$`4')E9G-?;&1A<#H@
ME4N7=H+(3$1!4(IGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"`%!R969S7VQD
M87`Z()5+EW:"R'-E<W-I;VZ*9Y*CBT"47(*JC*F"PH*I@NB"W(*Y@O&!0@"#
M=H.,@W*#A8%;`)!6@K6"HH-%@T.#DX-H@5N"R8GFD9R"\)5<CJ8`D4^"S(-)
M@W:#5H.'@Y,`B/.-_`"4Z9:GC*X`C^&*40"/X8I1D^"798+,D."6O@",]HI*
MC*X`C/:/3XRN@T&#BX-3@XJ#68.``(SVBDJ,KH_NE?$`C/:/3XRN+Y3IEJ>,
MKH*JD+:0K(+%@JN"W(*Y@O&"Q8*U@KV!0@"#=H-'@XN#9X.*@U(`@X&#8H-:
M@5N#5X+P@W"!6X-7`(-*@UZ!6X.+`(-.@T>#BH%;`(-*@UZ!6X.+`%)308SV
MCT^,KB@E9(-R@V*#9RD`E.0`D\>"W@"6>Y.6@LD@)7,@@O"-[8^<@K6"W(*W
M@JD_((*Q@LR1@(WL@LV,LX+)EM^"N8+<@KF"\8%"`)9[DY:"R8.&@5N#52`E
M<R""S(-F@5N#7H+PC>V/G(*U@MR"MX*I@4@@@K&"S)&`C>R"S8[F@NB/P8*Y
M@MR"N8+Q@4(`C<6,XX+,D8"-[(+P@N*"Z)*\@K<`DZZ328.!@VJ#A8%;@LR-
MQ)5<CJ:*U(IU.@"#?(%;@UZ#BX+,C<257(ZF`(.*@XV!6X-H`(.*@X*!6X-G
M@U2!6X-R@U@`@XJ#@H%;@V=54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO
M:&]R9&4I.B``C>V/G`"#=8.-@V*#3H+PC>V/G`"/D8ZN@O"-[8^<`(-Y@T&"
M\(WMCYP`E=N1MH*U@KV#6(-.@XJ#=H-G@O"-[(O&@V:#0H.,@TZ#9X.*@JF"
MYXWMCYR"MX+I@4(`C>V/G(%&`(*Q@LR#;8%;@VB"\(-H@TR#A8.!@Y.#9X*I
M@N>-[8^<`(.&@5N#58+PC>V/G`"#AH%;@U6"\(WMCYPZ("5S`)=VBX&"R974
MDYJ"Q8*K@MR"N8+Q.B``EW:+@8*S@NJ"O2`B)7,B((+-("5S((+,D-V2Z(+)
MCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`EW:+@8*S@NJ"O2`B)7,B((+-(%9&4R"0
MW9+H@LF.=Y+H@K."ZH+$@J*"W(*Y@O&!0@"7=HN!@K."ZH*]("(E<R(@@LV0
MW9+H@LF.=Y+H@K."ZH+$@J*"W(*Y@O&!0@"#BH-:@V*#9P"#<(-8@X^!6X-H
M@O"#BH-:@V*#9P""H(+(@KV"S(-P@UB#CX%;@VB"\(.*@UJ#8H-G`(R+B<H`
M@TF#=H-6@X>#DX+)EM^"Z0"#<(-8@X^!6X-H@O"-Q)/\E\T`C+."S(U<D*R"
MR9;?@K<`@V6#3(-8@V>#1X-F@T*#7H%;@LR#28-V@U:#AX.3`(E%`);PBH0`
M@XN!6X-]@VJ#00`Q.#"3>(GQDUT`C;:"R8GQDUT`B46"R8GQDUT`C7.1KI"K
M`(USD:Z0JP"-<X%&`(QRD/P`D5."Q(+,C7."QI?Q@LR*U(+)C'*0_(+PB/B"
MK0"-<X+,BM2"R8QRD/R"\(CX@JT`E_&"S(K4@LF,<I#\@O"(^(*M`([`C7,`
M@XV#5H-!F$&630"#BX./@Y.#7P!3+TU)344@B,.-AH^0EKP`4R]-24U%((C#
MC8:5M@!305-,()1&C]B"S8YGEW""Q8*K@MR"N8+Q@4(`4U%,((-6@T:#BP!3
M4T@`D*R,]P"3>0"#6H.3@V>#=X.,@VF3AP"#6H.3@V>#3(-B@V.!E8-L@5N#
ME(-"@U@`@UJ#DX-G@XN#5H-!`(-4@Y.#<X-'@5N#BX%%@WZ#3H.-@Y.3AP"#
M6H.3@V>#<X.3@UJ#DX-G@JB"YH+1@T^#C(-I@V:#0H%;@Y./E).'`(-4@X*#
M09/&EZ>-D0"#5(.3@WV#BH-MBZ2888V1`(-4@Y.#9X.!@46#=H.*@Y.#5H-Y
MEJ^.Y8NDF&&-D0"#5(-%@U>#08.)@W*#08FDC9$`E=N1M@`B)7,B((+PE=N1
MM@`E<R""\)7;D;8`@TF#=H-6@X>#DX+PE=N1M@"0MI"L@K."ZH*]D-V2Z(+P
M(%!(4""#6(-.@XJ#=H-G@L:"M8+$@U2!6X-O@LR-[(O&@V:#0H.,@TZ#9X.*
M@LF5VY&V@K>"Z8%"`"5S()#=DNB"\)7;D;:"M8+<@K6"O8%"`)#=DNB-6)!6
MEW"#6(-.@XJ#=H-G("(E<R(@@O"5VY&V@K6"W(*U@KV!0@",GXWU`(R?C?6#
M1X.3@U>#DP"#=(-`@T.#BX+PD4F1\`"3^I5T@O".=Y+H@K6"Q(*M@KZ"LX*B
M@48`DL>)P8*W@NF#3X.+@5N#=H+PD4F1\(*U@L2"K8*^@K."H@"05H*U@J*/
MBHZ=CM*"\)%)D?""M8+$@JV"OH*S@J(`@U2!6X-O@O"129'P@K6"Q(*M@KZ"
MLX*B`)+'B<&"MX+I@X:!6X-5@O"129'P@K6"Q(*M@KZ"LX*B`)%3@L2129'P
M`)5+EW:"R)6VCIJ"\(FZ@LR#>X-B@TZ#6(*I@N>128+Q@L6#4H-S@5N"MX+I
M@L:!08-E@TR#6(-G@T>#BH-!@M:#>8%;@UB#9X+%@JN"W(*W@4(`D_J5=(+,
MB^:0V(+HE;:.FH+PCG>2Z(*U@L2"K8*^@K."HH%&`)/ZE72"S(Q@CJZ"\(YW
MDNB"M8+$@JV"OH*S@J*!1@"5SXU8@K6"O8*B242"\)%)D?`Z`(Z>C8^"S(OF
MD-B"Z)6VCIJ"\(YWDNB"M8+$@JV"OH*S@J*!1@".GHV/@LR,8(ZN@O".=Y+H
M@K6"Q(*M@KZ"LX*B@48`B.J2=H*W@NF"48+"@LR#=(-"@5N#BX-H@O"128+Q
M@L6"K8*^@K."HH%"`)!&DK*"\)%)D?""M8+$@JV"OH*S@J(N`(R^C.J"\)%)
MD?""M8+$@JV"OH*S@J(Z`(_ABE&#C(-\@5N#9X+PD9>038*W@ND`4TU3()&7
MD$T`@UJ#;(-+@XN+I)AAC9$`@EB,C@"#6H.+@W*#08%%@X*#DX-E@VR#3X.-
M`)+*E-0`@UJ#8H-6@X>#DXK'EYT`@UJ#8H-6@X>#DP"668+J@L2"M8+<@L&"
MO8-P@UB#CX%;@VB"\(.*@UJ#8H-G@L6"JX+I@N:"I(+)@K6"W(*W@4(`@WR!
M6X->@XN"Q8-!@TZ#6H-8@K>"Z8.*@X*!6X-G@U2!6X-O@O"0W9+H@K6"W(*W
M@4(`C+Z,ZH%!CIZ*U)'1@4&3^I5T@O"0W9+H@K6"W(*W@4(`BDJ.;HZ>@LR#
M08-V@XJ#4(%;@U:#AX.3@4&01I*R@4&#>8%;@U>-Q)5<CJ:!08*[@LR1O(+,
ME5R.IH-)@W:#5H.'@Y."\)%)D?""M8+$@JV"OH*S@J(N`)#=DN@`D-V2Z(U8
MD%:#6(-.@XJ#=H-G`(-:@5N#5H-&@XN+I)AAC9$`BLB24(+(EW:6\8%&`(%I
M@X&#:H.%@5N"R(+'@L6!:H-6@X>!6X-G@TJ#8H-G@TR!6X*JCF>"IH+I@N:"
MI(+)@K6"W(*W@JF!2`"57(ZF`(R[C=V"S)#=DNB"QI!6@K6"K9"VD*R"LX+J
M@KV0W9+H@L:"S(VWE:J"\)5<CJ:"MX+I@4(`@XV#3X-#@Y..GH+)D4^)\8+,
M@XV#3X-#@Y..GHK4@O"57(ZF@K6"W(*W@JF!2`"57)&`C>R#@8-J@X6!6X+P
ME5R.IH*U@MR"MX*I@4@`B>:6RHVV@LD@)7,@@X&#:H.%@5N"\)5<CJ:"M8+<
M@K>"J8%(`)5<@LR#6H.+D:Z0JX-?@T.#08.-@T^"\)5<CJ8`E5R1KI"K@U^#
M0X-!@XV#3X+PE5R.I@"57(+,E_&1KI"K@U^#0X-!@XV#3X+PE5R.I@"57(+,
MC7.1KI"K@U^#0X-!@XV#3X+PE5R.I@"/:X^L`(+<@KB7UX+H@LR#=8.-@V*#
M3H+PCVN/K(+<@KV"S8C:DZZ"LX*Y@L2"K8*^@K."HH%"`(-6@T>#B8.,@TF#
M;(NDF&&-D0"#5(-#@Y.#08-B@W8`DV2.<8^0EKP`DV2.<8^0EKR#08.+@U.#
MBH-9@X``@U:#DX-+@WR!6X.+BZ2888V1`(-4@T.#60"5VX[G@O"#6(-,@V*#
M=H*W@ND`@UB#C8-O@TR#08NDF&&-D0"#6(.-@WB#:H-!BZ2888V1`(-<@XV#
M@H.3CY23AP"#7(-]@XJ#09:OCN6+I)AAC9$`E<""T8^'@LR129'P`)&7D$V,
MLX-!@VB#C(-8`)/L@T&#=(.*@TJ+I)AAC9$`D^R#5X.'@5N#5X-!DX>!19/L
M@U2#DX-H@T.#8H-@CY23AP"3[)2\BX4`E]>"S(-:@XN"QH+,EUV4D@"#6H.+
M@L:+JXI%@L:"S)==E)(`EUV4D@"77922@L:6A)&0`(-8@WF#0X.3`)/!CNJ5
MMHZ:@LR3_)?-`(-:@XN5JHJ$`)?QE:J*A`"-<Y6JBH0`@UB#BH.)@Y.#2I:O
MCN6.T(GOCN6+8(NDF&&-D0"/0H+<@KV"S8RG`(_SD=0`CUJ/BI34DFX`CN:/
MP8*UD/P`@UB#7H-#@XL@6T-34UT`D_H`@U2#=8-F@T*#C(-.@V>#BB`B)7,B
M((*J@J""Z(+<@KF"\8%"`([`C7,`B;J5=(*K`)"LC/<`(B5S(B""S8-6@UB#
M98.`@LF2QXG!@K."ZH+<@K6"O8%"`"(E<R(@@JJ#5H-8@V6#@(*I@N>-[8^<
M@K."ZH+<@K6"O8%"`"(E<R(@@JJ-[8^<@K."ZH+<@K6"O8%"`"(E<R(@@JJ#
M5H-8@V6#@(*I@N>-[8^<@K."ZH+<@K6"O8%"`)#=DNB"S9"SC^V"R9;?@K."
MZH+<@K6"O8%"@XJ#C8%;@VB"M8+$BFV41H+%@JN"W(*W@4(`D-V2Z(+,@V^#
M8H-.@T&#8H-V@LV0LX_M@LF5VY&V@K."ZH+<@K6"O8%"`)#=DNB#=(-`@T.#
MBX+,@V^#8H-.@T&#8H-V("5S((+-D+./[8+)E=N1MH*S@NJ"W(*U@KV!0@`B
M)7,B((+-D+./[8+)C5B05H*S@NJ"W(*U@KT`)7,@@LV0LX_M@LF/D8*KC9Z"
MW(+J@MR"M8*]`(-8@5N#7X.3BZ2888V1`(I4EW8`D_J"S(]O`)/Z@LR3_(+H
M`)/Z@LR/;R^3^H+,D_R"Z`"3^H+,CV^!1@"3^I9V`)/ZEG:!1@"/XY5T@JL`
M@U2#?(%;@V<`@UB#BH-I@X"+I)AAC9$`D*D`@UB#E(-`@5N#BX-O@XN!08.$
M@Y.#?8-#@T>#DX^4DX<`@UB#CX-7@XF#DX-HB:2-D0"#6(-%@T:!6X-F@Y.)
MI(V1`(-8@T.#6)A!EDT`@U:#BH-!@46#08.)@W6+I)AAC9$`5%-6@W2#0(-#
M@XL`E5R1KI"K`)5<D:Z0JP"1Y)AP`)'DF'"!:9*&C9&"S(CJE92!:@"#7H-7
M@TR#6(->@Y.+I)AAC9$`@UZ#DX-5@VJ#09A!EDV+I)AAC9$`@UZ#6(-.`)-D
MF&*4U(V&`(-E@Y.#=H.,@5N#9R`B)7,B((*J@J""Z(+<@KF"\8%"`(-E@Y.#
M=H.,@5N#9X+,BL>7G0"#98-,@UB#9X+,@MT`E;:.FI1ZDG4`E;:.FH+,C^,`
MEM@`@UZ#0XFDC9$`1E10((IGDJ."JH*@@NB"W(*Y@O&!0@"7FI?P@U:#6(-E
M@X""S9:SC/B"R8+(@L&"Q(*B@MR"MX%"`$UA:6YT96YA;F-E((-.@XF#6(+,
MD\>-GH+=@JJ0LX_M@LF-<X*F@MR"N8+Q@L6"M8*]`(-)@W:#5H.'@Y.#18-"
M@Y.#:(-%@O"5PH*V@MR"M8*]@4*/29>Y@K6"W(*W@4(`@T&#3H-:@UB,H(+P
METR,^(+)@K>"Z8+)@LV*QY>=CM*"JH*[@LR#;X-B@TZ#1X.3@VB"\)#=DNB"
MMX+I@K&"QH*JE4N7=H+%@K>!0@"809>-D.9)1)34C8:"JHYWDNB"LX+J@LB"
MJ8+!@KV"J8%!B_."OH+!@KV"J8%!@J""Z8*B@LV#9H%;@UZ#>(%;@UB2AH+)
MC*F5=(*I@NB"W(*Y@O&"Q8*U@KV!0@"809>-D.:"S8*@@LB"O8+,@T&#:(.,
M@UB2H(+)DL>)P8*S@NJ"W(*U@KV!0@"39(YQCY"6O(*S@NJ"O8.!@V*#6H%;
M@U>"\(R?C]B"MX+I@LF"S8%!4$=0((^0EKR"JI5+EW:"Q8*W@4(`D9>039#F
M2424U(V&@JJ.=Y+H@K."ZH+(@JF"P8*]@JF!08OS@KZ"P8*]@JF!08*@@NF"
MHH+-@V:!6X->@WB!6X-8DH:"R8RIE72"J8+H@MR"N8+Q@L6"M8*]@4(`D9>0
M39#F2424U(V&@JJ.=Y+H@K."ZH+<@KF"\8+%@K6"O8%"`(C#C8:)NX+)@LV(
MP)%3@LB#18-&@W60VI&Q@JJ52Y=V@L6"MX%"`(-T@T"#0X.+("5S((+)@LT@
M)7,@@LR0W9+H@JJ52Y![@L6"MX%"`(-T@T"#0X.+("5S((+)@LT@)7,@@LR0
MW9+H@JJ52Y![@L6"MX%"`(-T@T"#0X.+@LV.J96JCJF09X+)@U*#<X%;@L6"
MJX+<@KF"\8%"`(-T@T"#0X.+@JJ#9H%;@UZ"\(K<@O&"Q8*B@MR"N8+Q@4(`
MB,B)NH+-@K&"S(.!@V*#6H%;@U>!:5)&0S@R,H%J@LR#=X-B@U^"Q8*W@4(`
MDHV(TX%)((-T@XN#6(-.@XJ!6X.3@X*!6X-H@LT@26YT97)N970@17AP;&]R
M97(@@L6"S9;BD>B"JI2MD+:"MX+I@K&"QH*J@J""Z(+<@K>!:8-U@XF#18-5
M@LR#;X-/@L6"MX%J@4*)YI;*@LF#4X-^@JJ57(ZF@K."ZH*]@NB!05=I;F1O
M=W,@@JJ#3H.)@V*#5H.%@K6"O8+H@K>"Z8*I@N""M8+J@MR"N8+Q@4(*@W2#
MBX-8@TZ#BH%;@Y.#@H%;@VB"R8*W@NF"R(+G($]+((+PB9^"M8+$B;J"LX*B
M@4(`240@(B5S(B""S8WMCYR"LX+J@MR"M8*]@4(`1VYU4$<@@V^#0X-I@XJ"
MS(-P@UB"JB!#<GEP=%]P9W`@@TZ#B8-8@LF0W9+H@K."ZH+$@J*"Z95+EW:"
MJH*@@NB"W(*W@4(`@K&"S(-T@T*!6X.+@VB"S9"4CIJ"Q8+(@J^"ZH+.@LB"
MZ(+<@KF"\8%"`$AO<F1E7T-R>7!T7W-M:6UE@TZ#B8-8@LF"S6]P96YS<VR#
M@H-7@X6!6X.+@JJ52Y=V@L6"MX%"`(-V@XR#=(-`@XR#DX-8(B5S(H+-@V:!
M6X->@JJ#5(-#@UF0IXS`@O")>H*F@KV"O8+?E=N1MH+%@JN"W(*Y@O&"Q8*U
M@KTN`(*Q@LR#9H%;@UZ,7B@E<RF"\)5<CJ:"MX+I@KV"WX+,@W:#C8-/@XF#
M@(*J@K&"S(-6@UB#98.`@LF"W8+"@JF"Z(+<@KF"\8%"`(CXEW"5A(+-@E"5
MMHZ:@L6"R(*O@NJ"SH+(@NB"W(*Y@O&!0@"+YI#8@NB5A(+-@E"5MHZ:@L6"
MR(*O@NJ"SH+(@NB"W(*Y@O&!0@"#5(%;@V\@(B5S(B""S8WMCYR"LX+J@MR"
MM8*]@4(`@U2!6X-O("(E<R(@@LV5VY&V@K."ZH+<@K6"O8%"`(YWDNB"M8*]
ME_&!:25D@6J"JH*@@NB"W(*Y@O&!0@"(ZHZ>@W2#0(-#@XL@(B5S(B""JH*@
M@NB"W(*Y@O&!0@"#08-B@W:#C8%;@VB#9H%;@UZ"JI*\D4^"S(-8@V6#8H-V
M@L6/P8ZX@K6"W(*U@KV!0@"#08-B@W:#C8%;@VB#9H%;@UZ"\)7;D;:"Q8*K
M@MR"N8+Q@L6"M8*]@4(`@V6!6X-]@V:#0H.,@TZ#9X.*@5L@(B5S(B""JH*@
M@NB"W(*Y@O&!0@".=Y+H@L6"JX+I@TF#=H-6@X>#DX+-@J""Z(+<@KF"\8%"
M`(-#@Y.#B8-#@Y.57(ZF@L6"JX+IE925JH+-@J""Z(+<@KF"\8%"`)6VCIJ0
ME(*J@K&"S(-T@T*!6X.+@VB"R9&]B=^"K(+<@K<N("5S((+,E;:.FH*JD_R7
MS8*S@NJ"Q(*B@MR"MRX@)7,@B,B)NH+%@LB"K8+$@LV"HH*O@MR"N8+Q@4(`
M(B5S(B""\(-6@UB#98.`@M:2QXG!DH:"R9;BD>B"JI2MD+:"M8+<@K6"O3H@
M)7,`@X:!6X-5("(E<R(@@LR#9H%;@UZ"\(-6@UB#98.`@JF"YX_!BXZ2AH+)
MEN*1Z(*JE*V0MH*U@MR"M8*].@`B)7,B((+P@U:#6(-E@X""J8+GC>V/G)*&
M@LF6XI'H@JJ4K9"V@K6"W(*U@KTZ`"(E<R(@@O"-6)!6DH:"R9;BD>B"JI2M
MD+:"M8+<@K6"O3H@)7,`@W2#0(-#@XN#08-B@W:#C8%;@VB"R9;BD>B"JI2M
MD+:"M8+<@K6"O3H@)7,@@LV#08-B@W:#C8%;@VB"LX+J@L2"HH+<@KF"\8%"
M`(-T@T"#0X.+@T&#8H-V@XV!6X-H@LF6XI'H@JJ4K9"V@K6"W(*U@KTZ("5S
M((+-@W2#0(-#@XN"S(-4@T.#69"GC,"2;"@E9(-O@T.#9RF"\(EZ@J:"Q(*B
M@MR"MX%"`(-T@T"#0X.+@T&#8H-V@XV!6X-H@LF6XI'H@JJ4K9"V@K6"W(*U
M@KTZ("5S((+-B.J5E(+,@MV#08-B@W:#C8%;@VB"LX+J@MR"M8*]@4(`@K&"
MS(-P@5N#9X+PE5R.II*&@LF#1X.)@5N"JI2MD+:"M8+<@K6"O0"809>-D.:#
M9H%;@UZ"S(-#@Y.#?(%;@V>2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0@!I
M0V%L96YD87(@@LR#0X.3@WR!6X-GDH:"R8-'@XF!6X*JE*V0MH*U@MR"M8*]
M+@"0W9+H@W2#2(%;@X"2AH+)@T>#B8%;@JJ"H(+H@MR"M8*]@4*"O8+4@O&!
M095+D'N-@);:@JJ+\Y22@KZ"P8*]@LR"Q8*U@N6"I(%"`(YWDNB"LX+J@KV#
M08-H@XR#6)*@@LR1@(WLDH:"R8-'@XF!6X*JE*V0MH*U@MR"M8*]@4*,XX+%
MC<23>([`C7."M8+$@JV"OH*S@J*!0@"809>-D.:"S(_:C=>"\(U8D%:2AH+)
M@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0HSC@L6-Q)-XCL"-<X*U@L2"K8*^@K."
MHH%"`)&7D$V0YH.*@UB#9X+,C5B05I*&@LF#1X.)@5N"JI2MD+:"M8+<@K6"
MO8%"C.."Q8W$DWB.P(US@K6"Q(*M@KZ"LX*B@4(`@K&"S"!)34%0((-4@5N#
M;X+-BZ273(-T@TB#BX-?@O"#5(-\@5N#9X*U@L2"HH+<@KF"\8%"`(*Q@NJ"
MS9=,C/B"R"!R87(@@T&!6X-*@T.#=8+%@LV"R(*B@N:"I(+%@K>!0@""L8+J
M@LV73(SX@L@@>FEP((-T@T"#0X.+@L6"S8+(@J*"YH*D@L6"MX%"`(*Q@NJ"
MS9=,C/B"R(-*@5N#:)34C8:"Q8+-@LB"HH+F@J2"Q8*W@4(`@K&"S(-T@T*!
M6X.+@VB"S95+D'N"Q8*W@4(`@K&"S(-T@T*!6X.+@VB"S9"ND)2"Q8+(@JV"
MQ(+-@J*"KX+<@KF"\8%"`(*Q@LR#=(-"@5N#BX-H@LV0E(Z:@L:#4H.-@Y."
MQ8+(@JV"Q(+-@J*"KX+<@KF"\8%"`(*Q@LR#=(-"@5N#BX-H@LTXD&F0E(+%
M@LB"K8+$@LV"HH*O@MR"N8+Q@4(`@K&"S(-T@T*!6X.+@VB"S8-2@Y.#?8+<
M@KV"S8OSE)*"Q8OFD-B"YX+J@KV0KI"4@LR#BH-8@V>"Q8+(@JV"Q(+-@J*"
MKX+<@KF"\8%"`(*Q@LR#=(-"@5N#BX-H@LV0E(Z:@L6"R(*O@NJ"SH+(@NB"
MW(*Y@O&!0@""L8+,@W2#0H%;@XN#:(+-,3:0:5)'0I5<BTR"S)!&@U*!6X-H
M@LB"K8+$@LV"HH*O@MR"N8+Q@4*7X3HG(S$R,S1A9B<N`(*Q@LR#=(-(@5N#
M@(+-BOF"R8^(EYV"LX+J@L2"HH+<@K>!0@""L8+,@X&#8H-:@5N#5X+-@J""
MR(*]@JJ.9Y=P@K>"Z8+,@L:(V8+(@NF5MHZ:@UJ#8H-G@6DE<X%J@L6/D8*I
M@NJ"Q(*B@MR"MX%"`(*Q@LR4U(V&@LV-Q8^L@L6"X#&"Q8+(@JV"Q(+-@J*"
MKX+<@KF"\8%"`(*Q@LR#5(%;@V^"Q8+->FEP@L9G>FEP@W2#0(-#@XN"\)-7
MBDJ"Q8*K@MR"N8+Q@4(`@K&"S(-6@UB#98.`@LV(ZHZ>DTF"R9:SC/B"R8+(
M@L&"Q(*B@MR"MX%"`(*Q@LR2;(+-D)2.FH+%@LB"KX+J@LZ"R(+H@MR"N8+Q
M@4(`@K&"S(-%@T*#DX-H@T6"S8-)@W:#5H.'@Y.#18-"@Y.#:(-%@JF"YXS$
MCV^"LX+J@NF52Y=V@JJ"H(+H@MR"MX%"`(Z>BM0`@UZ#0X.`@U:!6X-G`(Z>
MBM2/D8ZN`).,@V6#0H."@5N#BY:OCN6+I)AAC9$`@UZ#0X-G@XL`E:&0E(+,
MC8"6VH+PD4F1\(*W@NF"R8+-@4%00X+%@LU#;VYT<F]L@TR#0X%!36%C@LB"
MYT-O;6UA;F2#3(-#@O")GX*U@LB"JH+G@TZ#BH-B@TZ"M8+<@K>!0@!(5$U,
M@UR!6X-8E5R.II#8D=8`@V>!6X-3BZ2888V1`(-G@U"#B8-%CY23AP"#9X.3
M@TN)I(V1`(*Q@LR0E)6JBM2"R8F]DWB"X(.-@T^#0X.3@JJ.CHUS@K."ZH+<
M@K6"O8%"`(-G@XJ#:H-?@5N#:(%%@V>#;X-3BZ2888V1`(G.`(-@@X6#:H-7
M@T&+I)AAC9$`@V>#BX-2BZ2888V1`(-G@XN#3H.!@VJ#6(->@Y,`@UZ!6X-.
M@UB!18-*@T.#4H-8CY23AP"#8X-O@XL`D4F1\(%&`%523`"#18-+@Y.#7XND
MF&&-D0"#18-.@XF#0X-I`%9&4R"#9H-"@XR#3H-G@XJ"R8-!@TZ#6H-8@L6"
MJX+<@KF"\8%"`%9&4R"#=(-`@T.#BR`B)7,B((+,@T&#3H-:@UB,H(+-E<^-
M6(+%@JN"W(*Y@O&!0@!61E,@@W2#0(-#@XL@)7,O)7,@@LR#08-.@UJ#6(R@
M@LV5SXU8@L6"JX+<@KF"\8%"`"5S((+)E<^-6(+%@JN"W(*Y@O&!0@"#=(-`
M@T.#BR`B)7,B((+,@U2#0X-9@JJ#8(-&@V*#3H*K@MR"N8+Q@4(`@W2#0(-#
M@XL@(B5S+R5S(B""S(-4@T.#68*J@V"#1H-B@TZ"Q8*K@MR"N8+Q@4(`4U%,
M((-4@5N#;X+)D-J1L8+%@JN"W(*Y@O&!0@!34TP@@L60VI&Q@L6"JX+<@KF"
M\8%"`%9&4R"#=(-`@T.#BX+P@U*#<X%;@L6"JX+<@KF"\8%"`%9&4R"#9H-"
M@XR#3H-G@XH@(B5S(B""\(WLD*R"Q8*K@MR"N8+Q@4(`5D93((-F@T*#C(-.
M@V>#BH+PC>R0K(+%@JN"W(*Y@O&!0@!61E,@@W2#0(-#@XN"\(WLD*R"Q8*K
M@MR"N8+Q@4(`5D93((-F@T*#C(-.@V>#BB`B)7,B((+PC>R0K(+%@JN"W(*Y
M@O&!0@"+\X+,(%9&4R"#=(-`@T.#BX+PC>R0K(+%@JN"W(*Y@O&!0@"#9H%;
M@UZ"\(BSCVN"Q8*K@MR"N8+Q@4(`(B5S(H+PC>V/G(+%@JN"W(*Y@O$N((-F
M@T*#C(-.@V>#BH*JB_."Q8+-@J""Z(+<@KF"\8%"`"(E<R*"\(WMCYR"Q8*K
M@MR"N8+Q.B`E<RX`)7."\(WMCYR"Q8*K@MR"N8+Q+B"#9H-"@XR#3H-G@XJ"
MJHOS@L6"S8*@@NB"W(*Y@O&!0@!61E,@@V:#0H.,@TZ#9X.*@O"-Q(M!DTF"
MR8WMCYR"Q8*K@MR"N8+Q@4(`5D93((-F@T*#C(-.@V>#BH+PC>V/G(+%@JN"
MW(*Y@O&!0@!61E,@@V:#0H.,@TZ#9X.*@O"-[8^<@L6"JX+<@KF"\8%&)7,`
M5D93((-T@T"#0X.+("(E<R(@@O"-[8^<@L6"JX+<@KF"\8%"`%9&4R"#=(-`
M@T.#BX+PC>V/G(+%@JN"W(*Y@O&!0@!61E,@@V:#0H.,@TZ#9X.*("(E<R(@
M@O"-[8^<@L6"JX+<@KF"\8%"`%9&4R""\(W$BT&328+)C>V/G(+%@JN"W(*Y
M@O&!1B5S`(R[C=V"S(-F@T*#C(-.@V>#BH%;@JJ3P9+H@L6"JX+<@KF"\8%"
M`(_8EKZ/D8+,C]J-UX*JCN:"Z(]O@KF"W(*Y@O$`)7,@@LR2Z(M@@JJ#C8%;
M@VB"Q8*K@MR"N8+Q@4(`5D93((-T@T"#0X.+@JJ(VI.N@L6"JX+<@KF"\8%"
M`%9&4R"#=(-`@T.#BR`B)7,B((*JBDJ"KX+<@KF"\8%"`%9&4R"#=(-`@T.#
MBX+PCY&"JXV>@MV7<(+)BDJ"KX+<@KF"\8%"`%9&4R"#=(-`@T.#BX*JBDJ"
MKX+<@KF"\8%"`(BSCVN/D8S)@W2#0(-#@XN"\(I*@J^"W(*Y@O&!0@!61E,@
M@W2#0(-#@XN"JI/'@M^"W(*Y@O&!:69I;&5S:7IE*"D@@T>#B8%;@6J!0@!6
M1E,@@W2#0(-#@XN"JI/'@M^"W(*Y@O&!:6=E=$9I;&53:7IE*"D@@T>#B8%;
M@6J!0@!61E,@@W2#0(-#@XN"JI/'@M^"W(*Y@O&!0@!V9G-R;V]T((-F@T*#
MC(-.@V>#BH+PD\>"WX+<@KF"\8%"`):\D4\@)7,@@O`@)7,@@LF5SXU8@L6"
MJX+<@KF"\8%&@W2#2(.+@U^!6X+-BOF"R9&VC=V"M8+<@K<`5D93((-F@T*#
MC(-.@V>#BH%;@LR6O)%/@O"5SXU8@L6"JX+<@KF"\8%"`%9&4R"#9H-"@XR#
M3H-G@XJ!6X+,EKR13X+PE<^-6(+%@JN"W(*Y@O&!1B5S`%9&4R"#=(-`@T.#
MBR`B)7,B((+,EKR13X+PE<^-6(+%@JN"W(*Y@O&!0@!61E,@@W2#0(-#@XL@
M)7,O)7,@@LR6O)%/@O"5SXU8@L6"JX+<@KF"\8%"`%9&4R"#=(-`@T.#BX+,
MEKR13X+PE<^-6(+%@JN"W(*Y@O&!0@""L8+,(%=O<F0@E;:/D8+PEGR6\X+%
M@JN"W(*Y@O&!0@!61E,@@W2#0(-#@XL@(B5S(B""R8^1@J^"W(*Y@O&!0@!6
M1E,@@W2#0(-#@XN"R8^1@J^"W(*Y@O&!:6-O<'DH*8ZXE'.!:H%"`%9&4R"#
M=(-`@T.#BX+)CY&"KX+<@KF"\8%"`%9&4R"#=(-`@T.#BX+)CY&"KX+<@KF"
M\8%"<75O=&$@@O"2M(G?@K6"O8+F@J2"Q8*W@4(`B;J0_`"5SXU8@O".YH+H
MC\&"MP"-Q8SC@LR1@(WL@O",LX+)EM^"MP"0VI&QCIZ"S(-4@5N#;X%;@JF"
MYX+,EUR*^H*U@LB"HHF>DYJ!1@"#5(%;@V^!6X*I@N>"S)=<BOJ"M8+(@J*)
MGI.:@48`EJ*0KI>=`(-!@XF#=8[QDK>-D9A!EDT`B7"-D0"5Q(V1`)7$E\R1
MOI6]EVV/E).'`)5SEKX`@X:!6X-5EKR"J8-P@UB#CX%;@VB"JI5SEKZ"Q8*W
M@4(`EK.6O`"#6H-,@X6#BH-E@T*!6X_C@LR7G9=2@JF"YY/!C*""S):S@J*#
M6(-.@XJ#=H-G@LT@0W5T+T-O<'DO4&%S=&4@@L6"JX+<@KF"\8%"3TL@@O"#
M3H.*@V*#3H*W@NF"QH%!@L>"I(+B@L&"Q(-.@XJ#8H-V@WN!6X-H@LF#08-.
M@UJ#6(*W@NF"J8+&@J*"I"!M;WII;&QA+F]R9R""S(M:CW"5MH^1@O",J8+I
M@K&"QH*J@L6"JX+<@K>!0@"#5(-\@5N#9X*U@L2"HH+(@J**9Y*CCG&"Q8*W
M`(U8D%8`)7,@@O"-6)!6@K>"Z8%"`(.&@5N#58+PC5B05H*W@ND`(B5S(B""
M\(U8D%:"M8+<@K6"O8%"`(U8D%:#6(-.@XJ#=H-G@O"-[8^<@K6"W(*U@KV!
M0@"#08-B@W:#C8%;@V@`D5."Q(+,@T&#=H.*@U"!6X-6@X>#DX+,D-V2Z(-T
M@T"#0X.+@O"#5(%;@V^"R8-!@V*#=H.-@5N#:(*U@MR"M8*]@4(`@XF#98.3
ME;:.FH%ID>65MHZ:@6H`@XV!6X-]D)2.FH%ID>65MHZ:@6H`@T6#BX-/@T&#
M0Y.,E?N+I)AAC9$`C+N-W8+,DFR"\(YGEW"!1B5S`%-33"""\(YGEW``24U3
M4""#5(%;@V^"S(.&@5N#59:\@5Z#<(-8@X^!6X-H@JJ(V8+(@NF/ZHV'@LF.
M9Y=P@K6"W(*W@4(`@X:!6X-5`(.&@5N#52`E<R""S2`E<R""Q91&C]B"LX+J
M@L2"HH+<@KF"\8%"`(.&@5N#58K'EYT`@X:!6X-5@TF#=H-6@X>#DP"#AH%;
M@U63;YA>`(.&@5N#58+,DV^87H+-@K&"S(-4@T.#9X+%@LV+UHY^@K."ZH+$
M@J*"W(*W@4(`@X:!6X-5@5N#08-*@T6#DX-G@JJ"H(+H@MR"N8+Q@4*!0@"#
MAH%;@U66O`"#AH%;@U66O"`B)7,B((+-BOF"R8*@@NB"W(*W@4(`@X:!6X-5
MEKPZ`(.&@5N#59:\.B``@U:#6(-E@X"2AH+,@X:!6X-5@48`@T6#68-X@TR#
M6(->@Y.+I)AAC9$`BWB)R0"73(SXD*L`@V^#:X-!@V.+I)AAC9$`@WB#;(-9
M@T>#B8%%@WN#BH-O@XN+I)AAC9$`C)^/V(ZXE',@+2""L8+,@X&#8H-:@5N#
M5X+-B?SB@H*S@NJ"Q(*B@NF"YH*D@L6"MX%"`)3%`(-O@5N#5X.'@Y.*QY>=
M`(]CB,J2=0"#>(-G@VF#@([0B>^.Y8M@BZ2888V1`"5S((+PC*F"Z0"*3Y64
M@LP@=V5B((-Y@5N#5X+PE5R.I@")<)?,@V^!6X-7@Y./E).'`)7$E\R#;X%;
M@U>#DX^4DX<`@T6#2(.*@UB!18-T@V>#1(%;@VF/E).'`(QXC9``D(4`EHB/
M5`""YH*D@K&"NP`E<R""R8+F@J2"L8*[`"5S((*S@O&!08+F@J2"L8*[`)"\
M@U2#;H.)`"5S@XV#3X-#@Y.,XX+'@LR#08-V@XJ#4(%;@U:#AX.3@O"57(ZF
M@K6"W(*W@JF!2`"+YI#8@NB5MHZ:@LV)O8+%@K>"J8%(`(CXEW"5MHZ:@LV)
MO8+%@K>"J8%(`(-E@TR#6(-G@T>#9H-"@UZ!6X+,@W:#B8-/@T.#DX+PD4F1
M\(*U@MR"MX%"`)6=`(VV@LF2=8*M)7.#@8-J@X6!6X+,E9V!:8Z?B?&"S(.-
M@T^#0X.3@JF"YY=,C/B!:CH`E5R"S)6=`)6=@LR24(C*`)6=@48`EWZ"M8*B
M@N""S(CJEY<`B\Z6L9#F@LR/6H^*`(O.EK&0YH+,DV288I34C88`)60@C7.6
MVH+%BM2(X8+!@KV-@);:D)2!0I"S@K6"K8+-("5D@4&.=Y+H@K."ZH*]@LR"
MS2`E9(%"`(K4B.&"P8*]C8"6VI"4@4*0LX*U@JV"S2`E9(%!CG>2Z(*S@NJ"
MO8+,@LT@)62!0@!61E.#=(-`@T.#BX+,D\>"W8]O@K62AH+)E7.0LX+(@TF#
M=(-:@V*#9R`E9"""JHYWDNB"LX+J@MR"M8*]@4(`6#4P.78S((KNEGN0IXS`
M`%@U,#EV,R",KHYGEW"60`!8-3`Y=C,@CN61S([2@LR5RI:\`%@U,#EV,R".
MY9',CM*"S(RNCJ^5RHYQ`%@U,#EV,R"*9Y*CBT"47`"43@"43@"6B)1.`(-#
M@T>#@8.3BZ2888V1`(+-@J(`DZ^(TX*U@MR"MP"-H8+-@V6#3(-8@V>#@H%;
M@VB"Q8*W@4);/#Y=@WN#7H.3@L5765-)5UE'@X*!6X-H@LF6WX+H@MR"MX%"
M`"5D((C(C^."S(-U@XV#8H-.@O"-[)"L@K>"Z8*Q@L:"S8N6B<*"LX+J@L2"
MHH+<@KF"\8%"`(*@@LB"O8+-E$:/V(*S@NJ"Q(*B@MR"N8+Q@4(`EKR13X+,
MDH:"R2`G7"<@@L:"HH*DE;:.FH+-CF>"IH+<@KF"\8%"`)=,C/B"R)-DCG&#
M@8%;@XN#08-H@XR#6(+%@LV"H(+H@MR"N8+Q@4(`@T.#DX-\@5N#9X*S@NJ"
MO8-T@T"#0X.+@LR#=(-"@5N#BX-H@O`E<Y/@@LR1SHF>@K>"Z8-T@T*!6X.+
M@VB"R8-]@V*#=H*U@L2"W(*Y@O$N`(.-@T^#08-%@V>"M8+<@K6"O2X`D+."
MM8*BDV288I34C8:"\)/\E\V"MX+I@N:"I(+)DHV(TX*U@L2)NH*S@J*!0I"4
MCIJ"OH*O@JJ.9Y=P@L6"JX+<@K>"JH%!C9&-VY-DF&*"R(+GD.:3JH+)@7N"
M\)5T@J^"W(*W@4(`D+."M8*BDFR"\)/\E\V"M8+$B;J"LX*B@4(`@U2#0X.3
M@T&#8H-V@O"7F)=P@K>"Z8*]@M^"R8+-($1A=&%4<F5E((-O@V*#3H-'@Y.#
M:(+PD-V2Z(*W@NF52Y=V@JJ"H(+H@MR"MX%"`%9&4R"#;X-B@TZ#1X.3@VB"
M\)#=DNB"MX+IE4N7=H*J@J""Z(+<@K>!0@"/X8I1@LR3X)=E@O"+3(]Q@K6"
MQ(*I@N>!08_ABE&#C(-\@5N#9X+PD9>038*U@L2"K8*^@K."HH%"`(*Q@K&"
MR8.*@Y.#3H*W@NE54DR"\)/\E\V"M8+$B;J"LX*B`(WMCYR"MX+I@U2!6X-O
M@O".=Y+H@K6"Q(*M@KZ"LX*B@4(`C\&+CH*W@NF#AH%;@U66O(+PCG>2Z(*U
M@L2"K8*^@K."HH%"`(WMCYR"MX+I@X:!6X-5EKR"\(YWDNB"M8+$@JV"OH*S
M@J*!0@"2QXG!@K>"Z8.&@5N#59:\@O".=Y+H@K6"Q(*M@KZ"LX*B@4(`C5B0
M5H*W@NF#AH%;@U66O(+PCG>2Z(*U@L2"K8*^@K."HH%"`([`C7."MX+I@T&#
M3H-6@X>#DX+PCG>2Z(*U@L2"K8*^@K."HH%"`)!6@K6"HI6JE]Z6O(+PD_R7
MS8*U@L2)NH*S@J*!0@`E<R"#6H-B@U:#AX.3@LR73(SXBOJ,P(*JD-B"ZH+$
M@J*"W(*W@4*#C8-/@T.#DX*UDKR"M8+$@JV"OH*S@J*!0@"39(YQ@X&!6X.+
M@T&#:(.,@U@`@J""R(*]@LP@1G)O;3H@@T&#:(.,@U@`@J""R(*]@LR#0X.3
M@W2#2(.!@5N#5H.'@Y,`@UJ#8H-6@X>#DR`E<R""S(K4@LF"H(+(@KV"S(-!
M@VB#C(-8@JJ5SXU8@K."ZH+<@K6"O8%"@UJ#3(.%@XJ#98-"@5N5VXSL@LR"
MO8+?@LF#C8-/@T.#DX*UDKR"MX+7@JN"Q8*W@4(`@J""R(*]@LR6O)%/`(*Q
M@LR41H_8@V^#8H-.@T>#DX-H@L6"S8%!@X:!6X-5@LR2QXG!@JJ#5(-\@5N#
M9X*S@NJ"Q(*B@MR"N8+Q@4*"X(*U($AO<F1E((+%@X:!6X-5@T&#2H-%@Y.#
M9X+PBL>7G8*U@KV"HH+,@LB"YX%!D;R"S)1&C]B#;X-B@TZ#1X.3@VB"\(YG
M@J2"UX*K@L6"MX%"`(*Q@LR41H_8@V^#8H-.@T>#DX-H@L6"S8%!@X:!6X-5
M@LR#BH-8@V>"JH-4@WR!6X-G@K."ZH+$@J*"R(*B@JF!08*@@NF"HH+-B;V"
MYX*I@LR7G9=2@L6"L8+,BT"47(*JEK.,^(+)@LB"P8+$@J*"W(*W@4(`@UJ#
M8H-6@X>#DR`E<R""S(K4@LF"H(+(@KV"S(-U@XF#18-5@JJ5SXU8@K."ZH*]
M@N:"I(+(@LR"Q8%!@UJ#3(.%@XJ#98-"@5N5VXSL@LR"O8+?@LF#C8-/@T.#
MDX*UDKR"MX+7@JN"Q8*W@4(`@JB.9X*B@LR#=8.)@T6#58+-@K&"S(M`E%R"
M\(-4@WR!6X-G@K6"Q(*B@MR"N8+Q@4(`@JB.9X*B@LR#=8.)@T6#58+-@K&"
MS(CSC?R#28-V@U:#AX.3@O"#5(-\@5N#9X*U@L2"HH+<@KF"\8%"0V]N=')O
M;"]#;VUM86YD("L@4"""Q8CSC?R"M8+$B;J"LX*B@4(`@UZ#0X.`@UV!6X.3
M@48`@J""R(*]@LR#9H-T@TB#BX-G242"S97/C5B"LX+J@MR"M8*]@4(`@J""
MR(*]@LR#9H-T@TB#BX-G240Z`(*@@LB"O8+,CH&6O`"#C8-/@T.#DX+-BOJ,
MP)#8@NJ"Q8*W@4(`D%:"M8*B("5S()=P@LR#<(-8@X^!6X-H@48E<P""H(+(
M@KV"S(-)@W:#5H.'@Y."S8R[C=V"S(-:@V*#5H.'@Y.2AH+)E<^-6(*S@NJ"
MW(*U@KV!0@"#28-V@U:#AX.3@O"-6)!6@K6"W(*U@KT`@W"#6(./@5N#:(+-
M@XJ#6H-B@V>"LX+J@MR"M8*]@4(`@W"#6(./@5N#:(+-@XJ#6H-B@V>"LX+J
M@MR"M8*]@LR"Q8%!D%:"M8*B@W"#6(./@5N#:(+%@XV#3X-#@Y."M8+$@MV"
MQ(FZ@K."HH%"`(-P@UB#CX%;@VB"JHKZC,"0V(+J@L6"MX%"`(.*@X*!6X-G
M@U2!6X-O.@"#AH%;@U.#6(.)@W*#00"#58-#@5N#BXNDF&&-D8%I@U*#DX-3
MEJ^.Y8NDF&&-D8%J`(-5@Y.#<H-!BZ2888V1`(-7@Y.#;X-U@T>+I)AAC9$`
M@6V/X8I1E?&-D(%N`%N-<SHE<R\E<UT`7T&*QY>=`%]$C7."\(WMCYP`7T>#
M3X.+@5N#=@!?2(-W@XN#=@!?28GFD9R#=H.-@W"#98-"+BXN`%],@XV#3X-#
M@Y,`7TR#C8-/@T&#18-G`%]-@XJ#DX-.E<^-6`!?3X-)@W:#5H.'@Y,`7U"#
M08-.@UJ#6(R@`%]2@XJ#DX-.C>V/G`!?4X-:@V*#9X-!@V*#=@!?5)5<D:Z0
MJP!?58.&@5N#50"#08-H@XR#6)*@`)5SEKZ"R(-!@VB#C(-8`)=<DNB57`"/
M;Y?-@W2#0(-#@XN"JHWLD*R"Q8*K@MR"N8+Q`)/\E\V#=(-`@T.#BX*JBDJ"
MKX+<@KF"\0""L8*Q@O"#3H.*@V*#3@"#4H-]@Y.#:(USCF>7<(+,@T>#B8%;
M`)#=DNB#1X.)@5L`CV27=H+(@U:#6(-E@X"#=(-`@T.#BX+,C(>7C@"#9H%;
M@UZ,8(ZN@T>#B8%;`)72CU<`C8"6VH*J@J""Z(+<@KF"\0"#=(-`@T.#BP"#
M>H-8@V>6O(*JE7.6O@"3_(]OE\V#1X.)@5L`@UR#=(-G@T6#1H-!D^"5E(+,
M@T>#B8%;`):\D4\`CL"1E8*S@NJ"Q(*B@MR"N8+Q`(+<@KZ.P)&5@K."ZH+$
M@J*"W(*Y@O$`@X&#@I*@`(-P@5N#6H.3@V<`@T&#3H-:@UB"S8N1E-N"LX+J
M@MR"M8*]`(-S@TZ#6H.+`(.*@X*!6X-G@L6"S(-V@XV#9X-2@XN#1X.)@5L`
M@U2!6X-R@UB5<Y1<`(VWE:J"\)5<CJ8`@U:#6(-E@X"#1X.)@5L`@UZ#6(-.
M@XJ#6(-G`(CJCIZ328+(@T>#B8%;`(IME$:"S(*]@M^#<(-8@X^!6X-H,I-X
MD_R7S8*U@L2)NH*S@J(`EK.6O`!V0V%R9```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O:VU?2T@O
M````````````````````````````````````````````````````````````
M`````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-3$U-#,S-S4S`#`R,#$P-@`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQO8V%L92]K;5]+2"],0U]-15-304=%4R\`````````````````````
M````````````````````````````````````````````,#`P,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-3,`,#(Q-C<S`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VMM7TM(+TQ#7TU%4U-!1T53
M+VAO<F1E+FUO````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$Q,3<U,P`Q,#4Q
M-30S,S<U,P`P,C,S-#$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````WA($E0````!$`@``'````#P2```%`P``7"0```````!P
M,```#@```'$P```/````@#````@```"0,```"P```)DP```,````I3```!@`
M``"R,```&P```,LP```,````YS````4```#T,```!0```/HP```&`````#$`
M``P````',0``#@```!0Q```.````(S$```@````R,0``"0```#LQ```(````
M13$``!,```!.,0```P```&(Q```(````9C$```<```!O,0``#````'<Q```.
M````A#$```L```"3,0``!P```)\Q```'````IS$```4```"O,0``!0```+4Q
M```#````NS$``!<```"_,0``#@```-<Q```'````YC$```8```#N,0``"```
M`/4Q```*````_C$``!,````),@``"P```!TR```%````*3(``!4````O,@``
M"0```$4R```'````3S(```4```!7,@``"@```%TR```&````:#(```D```!O
M,@``!P```'DR```5````@3(```H```"7,@``"@```*(R```0````K3(```<`
M``"^,@``!P```,8R```*````SC(```@```#9,@``!P```.(R```'````ZC(`
M``8```#R,@``!0```/DR```'````_S(```8````',P``"`````XS```$````
M%S,```<````<,P``"0```"0S```&````+C,```<````U,P``%@```#TS```$
M````5#,```@```!9,P``!@```&(S```-````:3,```8```!W,P``'@```'XS
M```1````G3,```@```"O,P``#````+@S```'````Q3,```,```#-,P``"```
M`-$S```(````VC,```@```#C,P``!@```.PS```&````\S,```H```#Z,P``
M!P````4T```'````#30```X````5-```!@```"0T```8````*S0```0```!$
M-```!@```$DT```%````4#0```4```!6-```$````%PT```%````;30```L`
M``!S-```#````'\T```7````C#0```@```"D-```!0```*TT```'````LS0`
M``<```"[-```"P```,,T```'````SS0```<```#7-```"0```-\T```)````
MZ30```H```#S-```%0```/XT```9````%#4```4````N-0``$@```#0U```(
M````1S4```@```!0-0``#````%DU```$````9C4```H```!K-0``!P```'8U
M```&````?C4```<```"%-0``!````(TU```,````DC4```T```"?-0``*```
M`*TU```#````UC4```8```#:-0``$0```.$U```7````\S4```X````+-@``
M`@```!HV```%````'38```0````C-@```P```"@V```(````+#8```\````U
M-@``!P```$4V```&````338```T```!4-@``"@```&(V```'````;38```L`
M``!U-@``"P```($V```)````C38```@```"7-@``"````*`V```2````J38`
M`!\```"\-@``"````-PV```,````Y38```8```#R-@``!P```/DV```$````
M`3<```D````&-P``!0```!`W```+````%C<```4````B-P``#0```"@W```;
M````-C<```D```!2-P``$0```%PW```'````;C<```4```!V-P``!P```'PW
M```(````A#<```8```"--P``$````)0W```0````I3<```\```"V-P``#P``
M`,8W```,````UC<```<```#C-P``!@```.LW```(````\C<``!L```#[-P``
M#0```!<X```#````)3@```@````I.```!````#(X```$````-S@```D````\
M.```!P```$8X```'````3C@```0```!6.```!0```%LX```*````83@```4`
M``!L.```!@```'(X```&````>3@```T```"`.```$````(XX```;````GS@`
M``0```"[.```"0```,`X```%````RC@```8```#0.```!P```-<X```'````
MWS@```4```#G.```"0```.TX```*````]S@```X````".0```@```!$Y```)
M````%#D```8````>.0``$@```"4Y```)````.#D```<```!".0``!@```$HY
M```*````43D```0```!<.0``"0```&$Y```&````:SD```T```!R.0``!@``
M`(`Y```$````ASD```4```",.0``!@```)(Y```'````F3D``"$```"A.0``
M!@```,,Y```$````RCD```0```#/.0``'0```-0Y```$````\CD```P```#W
M.0``#@````0Z```*````$SH```@````>.@``"0```"<Z```'````,3H```H`
M```Y.@``!P```$0Z```*````3#H```8```!7.@``#P```%XZ```%````;CH`
M``D```!T.@``!````'XZ```+````@SH```P```"/.@``!P```)PZ```$````
MI#H```<```"I.@``!@```+$Z```&````N#H```8```"_.@``!0```,8Z```'
M````S#H```<```#4.@``!0```-PZ```6````XCH```8```#Y.@``!``````[
M```$````!3L```<````*.P``"@```!([```%````'3L```H````C.P``"```
M`"X[```(````-SL```\```!`.P``!@```%`[```*````5SL```@```!B.P``
M(````&L[```&````C#L```8```"3.P``!P```)H[```$````HCL```<```"G
M.P``!0```*\[```'````M3L``!8```"].P``#0```-0[```$````XCL```4`
M``#G.P``"0```.T[```*````]SL```@````"/```!@````L\```'````$CP`
M``4````:/```"P```"`\```$````+#P```,````Q/```"@```#4\```"````
M0#P```4```!#/```"@```$D\```$````5#P```8```!9/```"````&`\```(
M````:3P```0```!R/```!0```'<\```%````?3P```8```"#/```$````(H\
M```*````FSP```H```"F/```"0```+$\```#````NSP```<```"_/```!P``
M`,<\```'````SSP```8```#7/```!@```-X\```&````Y3P```D```#L/```
M!@```/8\```-````_3P```8````+/0``"````!(]```.````&ST```<````J
M/0``"@```#(]```'````/3T```D```!%/0``"0```$\]```*````63T```<`
M``!D/0``"0```&P]```'````=CT```H```!^/0``!P```(D]```$````D3T`
M``<```"6/0``!0```)X]```%````I#T```L```"J/0``%````+8]```'````
MRST```4```#3/0``#0```-D]```1````YST```L```#Y/0``#`````4^```$
M````$CX```H````7/@``!````"(^```)````)SX```4````Q/@``!P```#<^
M```%````/SX```0```!%/@```@```$H^```$````33X```X```!2/@``&```
M`&$^```&````>CX```4```"!/@``"````(<^```&````D#X``!0```"7/@``
M`@```*P^```&````KSX```<```"V/@``!@```+X^```,````Q3X```0```#2
M/@``%````-<^```0````[#X```<```#]/@``!0````4_```'````"S\```@`
M```3/P``!0```!P_```&````(C\``!`````I/P``"````#H_```(````0S\`
M``D```!,/P``!0```%8_```$````7#\```8```!A/P``!P```&@_```H````
M<#\```H```"9/P``"P```*0_```4````L#\```0```#%/P``"P```,H_```%
M````UC\```@```#</P``!@```.4_```&````[#\```@```#S/P``"````/P_
M```'````!4````@````-0```"@```!9````+````(4````4````M0```!0``
M`#-````%````.4````0````_0```!P```$1````-````3$````8```!:0```
M!P```&%````&````:4````4```!P0```!P```'9````1````?D````<```"0
M0```!0```)A````$````GD````<```"C0```"P```*M````,````MT````4`
M``#$0````P```,I````2````SD````8```#A0````P```.A````,````[$``
M`!4```#Y0```"P````]!```9````&T$``"`````U00``!0```%9!```*````
M7$$``!4```!G00``#````'U!```$````BD$```P```"/00``!@```)Q!```.
M````HT$```T```"R00``"@```,!!```+````RT$```<```#700``"0```-]!
M```5````Z4$```T```#_00``"`````U"```#````%D(```4````:0@``"@``
M`"!"```$````*T(```8````P0@``#````#="```)````1$(```D```!.0@``
M!````%A"```(````74(```@```!F0@``#P```&]"```'````?T(```P```"'
M0@``+````)1"```'````P4(```4```#)0@``!````,]"```)````U$(```@`
M``#>0@``!@```.="```-````[D(```<```#\0@``!@````1#```)````"T,`
M``<````50P``!0```!U#```'````(T,```L````K0P``!P```#=#```(````
M/T,``!8```!(0P``"0```%]#```&````:4,```L```!P0P``%````'Q#```%
M````D4,``!````"70P``$````*A#```&````N4,```H```#`0P``!0```,M#
M```0````T4,```L```#B0P``!````.Y#```)````\T,```@```#]0P``+P``
M``9$```$````-D0```L````[1```!0```$=$```"````340```4```!01```
M!````%9$```'````6T0```4```!C1````P```&E$```3````;40```<```"!
M1```!@```(E$```4````D$0```P```"E1```&````+)$```&````RT0```,`
M``#21```!````-9$```&````VT0```<```#B1```"0```.I$```'````]$0`
M``\```#\1```%`````Q%```.````(44```T````P10``)````#Y%```%````
M8T4```<```!I10``!P```'%%```&````>44```8```"`10``!P```(=%```$
M````CT4``!,```"410``"````*A%```)````L44```H```"[10``"````,9%
M```&````ST4```<```#610``"````-Y%```)````YT4```<```#Q10``#P``
M`/E%```'````"48``!0````11@``$0```"9&```'````.$8```,```!`1@``
M"````$1&```&````348```<```!41@``#0```%Q&```.````:D8```4```!Y
M1@``!@```']&```(````AD8```P```"/1@``"@```)Q&```"````IT8```0`
M``"J1@``!@```*]&```%````MD8```,```"\1@``"0```,!&```*````RD8`
M``4```#51@``!@```-M&```(````XD8```@```#K1@``$0```/1&```9````
M!D<``!$````@1P``&````#)'```3````2T<``!P```!?1P``$0```'Q'```/
M````CD<```(```">1P``$0```*%'```2````LT<``!<```#&1P```@```-Y'
M```$````X4<``!$```#F1P``!@```/A'```8````_T<``!,````82````@``
M`"Q(```,````+T@``!$````\2```#0```$Y(```'````7$@```4```!D2```
M)0$``&I(```M````D$D``$4```"^20``&P````1*```A````($H``!X```!"
M2@``/0```&%*``!J````GTH``!(````*2P``!0```!U+```5````(TL```D`
M```Y2P``%0```$-+```R````64L``#(```",2P``$P```+]+```*````TTL`
M`!(```#>2P``,````/%+```2````(DP``#8````U3```&P```&Q,```M````
MB$P``"H```"V3```)P```.%,```8````"4T``!X````B30``,````$%-```2
M````<DT``!@```"%30``0@```)Y-```H````X4T``!@````*3@``&P```"-.
M```>````/TX``"<```!>3@``/@```(9.```8````Q4X```P```#>3@``)```
M`.M.```>````$$\``!(````O3P``$@```$)/```;````54\```P```!Q3P``
M'@```'Y/```5````G4\``($```"S3P``+0```#50```J````8U```#8```".
M4```&````,50```2````WE```"0```#Q4```&````!91```;````+U$``!X`
M``!+40``%0```&I1```2````@%$``!@```"340``$@```*Q1```;````OU$`
M``D```#;40``$@```.51```D````^%$```P````=4@``#P```"I2``!-````
M.E(``!L```"(4@``&P```*12```)````P%(``!X```#*4@``&````.E2``!8
M`````E,``#P```!;4P``'@```)A3```J````MU,``!@```#B4P```P```/M3
M```8````_U,``!4````85```&````"Y4```2````1U0``!(```!:5```$@``
M`&U4```5````@%0``#````"65```'@```,=4```2````YE0``%$```#Y5```
M"0```$M5```D````554```P```!Z50``"0```(=5```M````D54```\```"_
M50``(0```,]5```>````\54``"H````05@``&````#M6```)````5%8``"$`
M``!>5@``,P```(!6```D````M%8``!X```#95@``&P```/A6```>````%%<`
M`!@````S5P``&````$Q7``!"````95<``%$```"H5P``%0```/I7``!*````
M$%@```@```!;6```#````&18```5````<5@```\```"'6```'@```)=8```2
M````ME@``!(```#)6```%0```-Q8```/````\E@``#P````"60``0@```#]9
M``"Y````@ED```P````\6@``$@```$E:```A````7%H``"T```!^6@``+0``
M`*Q:```"````VEH``!L```#=6@``)P```/E:```,````(5L```P````N6P``
M,0```#M;```8````;5L```P```"&6P``'@```)-;```>````LEL``!@```#1
M6P``'@```.I;```8````"5P```8````B7```&P```"E<```8````15P``#P`
M``!>7```40```)M<```/````[5P``"T```#]7```$@```"M=```;````/ET`
M`!L```!:70``&P```'9=```8````DET``"<```"K70``$@```--=```P````
MYET``&@````77@``*@```(!>```P````JUX``!@```#<7@``#P```/5>```8
M````!5\``!@````>7P``$@```#=?```O````2E\``#4```!Z7P``*0```+!?
M```Y````VE\``"0````48```'@```#E@```2````6&```"H```!K8```0@``
M`)9@```A````V6```!(```#[8```$@````YA```;````(6$```\````]80``
M(0```$UA```/````;V$``!L```!_80``$@```)MA```/````KF$``"T```"^
M80``)````.QA```,````$6(``!(````>8@``-P```#%B```S````:6(``$8`
M``"=8@``!@```.1B```;````ZV(``!4````'8P``&````!UC```;````-F,`
M`!X```!28P``$@```'%C```D````A&,``!@```"I8P``'@```,)C```&````
MX6,``#,```#H8P``#P```!QD```<````+&0``!4```!)9```'@```%]D```/
M````?F0``"<```".9```$@```+9D```A````R60``!(```#K9```(0```/YD
M```;````(&4```0````\90``#````$%E```5````3F4``!(```!D90``30``
M`'=E```2````Q64```\```#890``#P```.AE``!1````^&4``!@```!*9@``
M*@```&-F```2````CF8``"<```"A9@``'@```,EF```2````Z&8``!4```#[
M9@``(0```!%G```8````,V<``"$```!,9P``$@```&YG``!"````@6<```\`
M``#$9P``'@```-1G```5````\V<``!4````):```)````!]H```;````1&@`
M`!@```!@:```$@```'EH```>````C&@``!@```"K:```#P```,1H```5````
MU&@``!4```#J:```#`````!I```/````#6D``"`````=:0``&P```#YI```2
M````6FD``!(```!M:0``)P```(!I```G````J&D``!(```#0:0``)````.-I
M```S````"&H``!@````\:@``&P```%5J```8````<6H``"0```"*:@``#```
M`*]J``!U````O&H``!@````R:P``$@```$MK```/````7FL```\```!N:P``
M$@```'YK```2````D6L``!L```"D:P``3P```,!K```A````$&P```D````R
M;```"0```#QL```;````1FP``"0```!B;```$@```(=L```)````FFP```D`
M``"D;```"0```*YL```D````N&P``"T```#=;```"0````MM```>````%6T`
M``(````T;0``$@```#=M```J````2FT``!4```!U;0``%0```(MM```8````
MH6T``!@```"Z;0``#P```--M```5````XVT```P```#Y;0``&P````9N```2
M````(FX``!L````U;@``&P```%%N```8````;6X```P```"&;@``$@```)-N
M```2````IFX```D```"Y;@``(0```,-N```8````Y6X``!(```#^;@``%P``
M`!%O```/````*6\``!4````Y;P``%0```$]O```>````96\``"````"$;P``
M%0```*5O```;````NV\``!4```#7;P``.0```.UO```V````)W```#8```!>
M<```,````)5P```;````QG```!(```#B<```)````/5P```>````&G$```\`
M```Y<0``%0```$EQ```,````7W$``!4```!L<0``&````()Q```M````FW$`
M`!(```#)<0``"0```-QQ```G````YG$``"0````.<@``)P```#-R```V````
M6W(``!4```"2<@``*@```*AR```5````TW(``"0```#I<@``%0````YS```A
M````)',```D```!&<P``"0```%!S```&````6G,```\```!A<P``(0```'%S
M``!%````DW,``!(```#9<P``#P```.QS```8````_',```D````5=```)P``
M`!]T```5````1W0```\```!==```#````&UT```;````>G0``#8```"6=```
M#P```,UT``!%````W70``$(````C=0``%0```&9U```2````?'4``!(```"/
M=0``'@```*)U```/````P74``!@```#1=0``*@```.IU```A````%78``"<`
M```W=@``+````%]V```;````C'8```\```"H=@``$@```+AV```/````RW8`
M`&8```#;=@``$@```$)W```2````57<``#P```!H=P``$@```*5W```;````
MN'<``!@```#4=P``&P```.UW```2````"7@``!(````<>```)````"]X```2
M````5'@``"0```!G>```$@```(QX```G````GW@``!L```#'>```#````.-X
M```2````\'@```P````#>0``"0```!!Y```J````&GD``$$```!%>0``)P``
M`(=Y```G````KWD``!(```#7>0``)P```.IY```5````$GH``#`````H>@``
M(0```%EZ```2````>WH``!(```".>@``%0```*%Z```M````MWH``"T```#E
M>@``&@```!-[```,````+GL``"T````[>P``&````&E[```#````@GL``!X`
M``"&>P``+````*5[```A````TGL``$0```#T>P``30```#E\```2````AWP`
M`"$```":?```%0```+Q\```S````TGP``"0````&?0``,0```"M]```5````
M77T``"T```!S?0``,P```*%]```G````U7T``"$```#]?0``'@```!]^```/
M````/GX``$0```!.?@``(0```)-^```,````M7X```\```#"?@``#P```-)^
M```5````XGX``!(```#X?@``$@````M_```>````'G\``!@````]?P``&P``
M`%9_```,````<G\``!L```!_?P``&P```)M_```D````MW\``!4```#<?P``
M-@```/)_``"`````*8```!(```"J@```&````+V````J````UH```!L````!
M@0``'@```!V!```8````/($``"$```!5@0``&P```'>!```;````DX$``"T`
M``"O@0``$@```-V!```2````\($``!(````#@@``)````!:"```2````.X(`
M`!L```!.@@``1P```&J"```D````LH(``!4```#7@@``$@```.V"``!&````
M`(,```\```!'@P``/P```%>#``!1````EX,``!4```#I@P``+0```/^#```8
M````+80``"0```!&A```'@```&N$```2````BH0``!@```"=A```!@```+:$
M``"1````O80``!L```!/A0``2P```&N%```8````MX4```8```#0A0``&```
M`->%```2````\(4``!L````#A@``%0```!^&```/````-88``$0```!%A@``
M&````(J&```/````HX8``!P```"SA@``)````-"&```R````]88``!L````H
MAP```P```$2'```$````2(<``!X```!-AP``&P```&R'```S````B(<``"<`
M``"\AP``'0```.2'```A`````H@``#`````DB```)P```%6(``!:````?8@`
M``P```#8B```'@```.6(```A````!(D``#8````FB0``&P```%V)```D````
M>8D``!L```">B0``10```+J)```M`````(H``#(````NB@``+0```&&*```5
M````CXH```\```"EB@``(0```+6*```,````UXH``"<```#DB@``#`````R+
M``!"````&8L```P```!<BP``1@```&F+```^````L(L``!(```#OBP``"0``
M``*,```A````#(P``"0````NC```)````%.,```_````>(P``"T```"XC```
M#P```.:,```0````]HP``"H````'C0``2P```#*-``!1````?HT```(```#0
MC0``!````-.-```A````V(T```\```#ZC0``$P````J.```J````'HX``"0`
M``!)C@``!@```&Z.```8````=8X``"$```".C@``#````+".``!4````O8X`
M`%$````2CP``3@```&2/``!C````LX\``%0````7D```8````&R0``!+````
MS9```$(````9D0```@```%R1``!(````7Y$``#<```"HD0``10```."1```(
M````)I(```\````OD@``10```#^2```2````A9(``%<```"8D@``.0```/"2
M```"````*I,``"H````MDP``.0```%B3```P````DI,``"$```##DP``!0``
M`.63```!````1@```/,!``"X`````````#,!```!`0``_@```!T"``#6`0``
M`````"D!```%`@``T@$````````F`````````+,`````````3````+L```#8
M````DP```+,!```-`@```````%0!``#F````D0```,8````R`@``Q0``````
M``!1````4@$``!T!`````````````$4```#[````X@$```@"```C````)0(`
M``````"G````@P$``)D```#G`0``%@(``#\"``##`0```P$``*0!````````
MWP$``+````#`````60````X"```Q`0````````````#5````QP```(\!``!`
M`0```````.H!``"6````5@```````````````````!H"``"2````=`$``-$`
M``""````[P```(`````M````F@$``.4!``#)````,@$``!T`````````TP``
M`"@"``!W````]0$``/H```"K````^0$`````````````=0$```````#L`0``
MR@````````#5`0``L0$``#P!``"(````+P$``*(```!F`0``%P(``"8!````
M````1@$`````````````ZP```"T!````````-P(``````````````````.\!
M````````E@$`````````````TP$``-`!``#R`````````(\`````````"@(`
M`&H!```X`0``)`````X`````````N@$``*,`````````/@```'D!````````
M``````````#N`````````$D!``"U`````````#,```#?`````````)X`````
M````\`$``&\```!0`0``XP```)X!````````"````&T!``"(`0``````````
M`````````````(L!``#X`````````+X````;`@```````'````!A````8```
M``L"``"'````"0```)L``````````````'8````>`@``O0$```,````0`@``
M`````&\!``#H`0``*@```"\`````````K````%@!````````=0```"@!```/
M````=@$``'(```"?````T0$``&D```"R````_P```.T!``"C`0``Q`````P`
M````````1`$``*$!`````````````$T```!"`````````(0````U`@``````
M`,$``````````````+0```#A`0```````!\```"@`0```````+\!```P`@``
M`````(H```"J````V0$````````L`@``5````!X!``!#`0``N`$`````````
M``````````````"[`0```````)(!```G`````````.T```"7````I@```&`!
M``"D````.P$``/<````T````FP$``.`!```]`@```````&<````Y````````
M``````"8`0``$P$``,P!``"N`````````&0```"O````I0```,,```"Y`0``
MH@$``.0`````````.@(```````",````4P$``(4!``!*````<0```#@```!A
M`0``6@````````!'````,P(``$H!````````[``````````<`0``%0(``#0"
M```$````,`$``#0!````````\0```*T```"\`0``V@``````````````````
M````````````Q@$``!<```!,`0``I@$``)4```"K`0``*0```$L!```A`@``
M?0$``$@```!M````1`(```````"!`0``=````.<````+`0``#`$``#P```!L
M`0```````#4````!`@``)`$``$T!````````V@$``!\!``"@````&@``````
M``#W`0``-@$``)H```````````````,"````````0@$``($````)`0``8@$`
M`/X!``#(`0``)`(```````#<`0``Y0`````````Z`0```````#8"``!<`0``
M(@```&X`````````C0```%````#$`0``X@`````````L`0``%@```',!``"8
M`````````(,```!%`0``.P```&L```"J`0``0`(``,`!``"L`0``)P$``%4!
M```E`0``)@(````````*````_`$`````````````!P$``(`!``!;`0``````
M`/H!````````S0````````!\````1`````````#@````G````/0!```9````
M7P```%X!``#2````Z0$``(P!``"Z````>`````````!.``````````````".
M`0``\P````L````5`0``V0```$L```"9`0``%P$``,H!``"W````J`$`````
M``!W`0``*P(``)````!=````7````!D!```I`@``)P(````````2````````
M`),!``"'`0``\@$``#L"``!K`0``_```````````````@@$```8"````````
M``````8````9`@````````````!;````$0(```````!?`0``7@```#D"```%
M`0``+````.D```#+````4P````````"5`0``$@$``/\!```/`0``[@$````"
M````````K0$``#(````U`0``SP```-`````<`@``.0$``%H!````````(P$`
M`,X!``!.`0``^`$``$("``#Q`0``0P(`````````````<P``````````````
M+@```&(```````````````H!````````VP```/4```#A````]````'D`````
M````^0```````````````@$``%<!``"N`0```@```,(!``"G`0``Z```````
M``"1`0``A@```*D````]`0``$P(``,X`````````E````"`!```3````(P(`
M`!@!````````XP$``#\!``!X`0``O@$```````````````````````#!`0``
MC0$```````#4`0``W@$``.L!```$`@```````)T!``#,````B0````<"```4
M````50```+8!``"O`0``&`(``&0!````````90`````````P````60$``+(!
M```A`````````-<````%`````````%$!``!2````.@```"X!````````GP$`
M`!0"``"Q````*P```*4!``!^`````````&,!`````````````,<!``#+`0``
M'P(``,D!````````W@```'P!``#F`0``0P```+0!````````_0$````````1
M`````````+<!``!G`0``M0$```````"&`0``+0(```````!=`0``<@$``(L`
M``#P````!@$``#P"````````V`$`````````````O0```,4!``#4````^P$`
M`$$"````````Z@```*@```"A````1P$``(D!```@````2`$`````````````
MU@````````!N`0``OP```&4!````````*@(``#$"``!`````D`$```D"``#/
M`0```````"@``````````````#\```#=````]@```"`"``!7````<0$``&D!
M```B`0``A`$`````````````$@(``)<!``"I`0``?@$``#<```!!````````
M`'`!````````&P```!`!``````````$``"("```O`@``00$``/T```".````
M(0$``!$!``"Y````:`$``#@"```(`0``W0$``+P```!L````?0````T!```4
M`0``'@``````````````&@$``-L!``!)````>@$``#X!````````%0```!@`
M```E````!P```'L!````````/0```&H```!Z````G0````````#(````````
M`%8!```0`````````&,````-````*@$``"L!```"`@```````'\!```N`@``
M`````#$``````````````'L``````````````(H!``#7`0``P@````\"``"4
M`0``-P$``!8!````````W```````````````S0$``%@```!_````/@(``$\`
M``"P`0``!`$``(4```!/`0````````X!```;`0``M@```#8`````````#`(`
M`&@```"<`0``Y`$````````<````]@$`````````````9@`````@*"5S(&1A
M>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`
M("AY97-T97)D87DI`"(E<R(@:7,@;F]T(&$@9&ER96-T;W)Y+@`B)7,B(&ES
M(&YO="!A('9A;&ED(&-H;VEC92X`)60@)7,@86YD("5S`"5S($M"`"5S($U"
M`"5S.B`E<P`M+2!S96QE8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&
M;W)M870`,C0@:&]U<G,`/%!R979I;W5S`$%B;W5T+BXN`$%C8V]U;G0@26YF
M;W)M871I;VX`061D`$%D9"!U<V5R`$%D9')E<W,`061D<F5S<R!";V]K`$%D
M;6EN:7-T<F%T:6]N`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA
M<P!!;&EG;@!!;&P`06QT97)N871E(&5M86EL(&%D9')E<W,`06UE<FEC86X@
M4V%M;V$`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YT87)C=&EC80!!;G1I
M9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<FEL`$%R86)I8R`H5VEN
M9&]W<RTQ,C4V*0!!<F=E;G1I;F$`07)M96YI80!!<G5B80!!='1R:6)U=&5S
M`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H96YT:6-A=&EO;B!F86EL
M960`07IE<F)A:6IA;@!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%H
M86UA<P!"86AR86EN`$)A;F=L861E<V@`0F%R8F%D;W,`0F5L87)U<P!"96QG
M:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!";VQD
M`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97)S`$)O<VYI82!A;F0@
M2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N
M9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE
M:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$-2
M0P!#86QE;F1A<@!#86UB;V1I80!#86UE<F]O;@!#86YA9&$`0V%N8V5L`$-A
M<&4@5F5R9&4`0V%P=&EO;@!#87)R:65R`$-A>6UA;B!)<VQA;F1S`$-E;G1E
M<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0VAA9`!#:&%N9V4`0VAI;&4`
M0VAI;F$`0VAR:7-T;6%S($ES;&%N9`!#;&5A<@!#;&5A<B!1=65R>0!#;&]S
M92!7:6YD;W<`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;VUB:6$`0V]L
M;W(`0V]M;6%N9`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N
M>0!#;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FER;2!%;6%I
M;"!!9&1R97-S`$-O;F9I<FT@;F5W(&5M86EL(&%D9')E<W,`0V]N9V\`0V]N
M;F5C=&EO;B!F86EL960N`$-O;G1A8W1S`$-O;G1I;G5E`$-O;VL@27-L86YD
M<P!#;W!Y`$-O<W1A(%)I8V$`0V]U;G1R>0!#<F5A=&4`0W)O871I80!#=6)A
M`$-U<G)E;G0@5&EM90!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T
M;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-Y<')U<P!#>7)I;&QI8R`H
M2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>F5C:"!297!U8FQI
M8P!$1`!$86EL>0!$871E`$1A>0!$96-E;6)E<@!$96-R96%S92!);F1E;G0`
M1&5F875L=`!$96QE=&4`1&5L971E(&-O;'5M;@!$96QE=&4@<F]W`$1E;FUA
M<FL`1&5S8W)I<'1I;VX`1&5V96QO<&UE;G0`1&ER96-T;W)Y`$1J:6)O=71I
M`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;VXG="!H879E(&%N(&%C
M8V]U;G0_(%-I9VX@=7`N`$1O=VYL;V%D`$1Y;F%M:6,@36%I;`!%+4UA:6P`
M16-U861O<@!%9&ET`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;6%I
M;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%
M;6]T:6-O;G,`17%U871O<FEA;"!'=6EN96$`17)I=')E80!%<G)O<@!%<W1O
M;FEA`$5T:&EO<&EA`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#,P
M('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y(&AA;&8@:&]U<@!%=F5R
M>2!M:6YU=&4`17AE8W5T90!%>'!A;F0`17AP;VYE;G0`1F%L:VQA;F0@27-L
M86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%X`$9E8G)U87)Y`$9I
M:FD`1FEL90!&:6QE($YA;64`1FEL=&5R<P!&:6YL86YD`$9L:7``1FQO870`
M1F]N="!#;VQO<@!&;W)M<P!&<F%M97,`1G)A;F-E`$9R96YC:"!'=6EA;F$`
M1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`
M1G)O;0!&=6QL($YA;64`1V%B;VX`1V%M8FEA`$=E;W)G:6$`1V5R;6%N>0!'
M:&%N80!':6)R86QT87(`1VEV96X@3F%M90!';&]B86P@3W!T:6]N<P!';P!'
M<F%Y<V-A;&4`1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`
M1W)E;F%D80!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=6EN
M96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(86ET:0!(96%D97(`2&5A
M9&5R<P!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5I9VAT
M`$AE;'``2&EG:`!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE
M`$AO;64@061D<F5S<P!(;VUE($1I<F5C=&]R>0!(;VUE(%!H;VYE`$AO;F1U
M<F%S`$AO;F<@2V]N9P!(=6YG87)Y`$E0($%D9')E<W,`26-E;&%N9`!)8V]N
M<R!/;FQY`$EM86=E<P!);F-R96%S92!);F1E;G0`26YD:6$`26YD;VYE<VEA
M`$EN9F\`26YF;W)M871I;VX`26YS97)T(%1A8FQE`$EN=&5G97(`27)A<0!)
M<F5L86YD`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N
M=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IO<F1A;@!*=6QY
M`$IU;F4`2G5S=&EF>0!+87IA:VAS=&%N`$ME;GEA`$ME>2!,96YG=&@`2V5Y
M(%1Y<&4`2VER:6)A=&D`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS
M=&%N`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC
M`$QA='9I80!,87EO=70`3&5B86YO;@!,969T`$QE<V]T:&\`3&5V96P`3&EB
M97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EN
M:P!,:6YK<P!,:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A=&EO;@!,;V<@:6X`
M3&]G(&]U=`!,;V=I;@!,;V=I;B!487-K<P!,;W9E`$QO=P!,=7AE;6)O=7)G
M`$U-`$UA8V%O`$UA9&%G87-C87(`36%I;`!-86QA=VD`36%L87ES:6$`36%L
M9&EV97,`36%L:0!-86QT80!-87)C:`!-87)G:6X`36%R<VAA;&P@27-L86YD
M<P!-87)T:6YI<75E`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>0!-87EO='1E
M`$UE;6)E<G,`365S<V%G90!-971H;V0`365X:6-O`$UI9&1L90!-:6UE(%1Y
M<&4`36ER<F]R`$UI<V-E;&QA;F5O=7,`36]N86-O`$UO;F=O;&EA`$UO;G1H
M(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;W)O8V-O`$UO=F4@1&]W
M;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E
M('5P`$UO>F%M8FEQ=64`37EA;FUA<@!.86UE`$YA;6EB:6$`3F%U<G4`3F5P
M86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T=V]R:P!.
M979E<@!.97<@0V%L961O;FEA`$YE=R!-97-S86=E('1O("5S`$YE=R!:96%L
M86YD`$YE=R!P87-S=V]R9`!.97=S`$YE=W-G<F]U<',`3F5X=`!.:6-A<F%G
M=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO;F4`3F]R9F]L:R!)
M<VQA;F0`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W1E<P!.
M;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3TL`3V)J96-T
M`$]C=&]B97(`3V9F:6-E`$]L9"!P87-S=V]R9`!/;6%N`$]P96X@:6X@82!N
M97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/=&AE<@!0861D
M:6YG`%!A:VES=&%N`%!A;&%U`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A
M<F%G=6%Y`%!A<W-W;W)D`%!A<W-W;W)D.@!087-T90!0871H`%!E;W!L90!0
M97)C96YT`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I
M;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N<P!097)S;VYA;"!);F9O<FUA=&EO
M;@!097)U`%!H:6QI<'!I;F5S`%!H;VYE`%!I=&-A:7)N`%!I>&5L<P!0;VQA
M;F0`4&]R='5G86P`4')E<W-U<F4`4')E=FEE=P!0<F]J96-T<P!0=6)L:6,@
M2V5Y`%!U97)T;R!2:6-O`%%A=&%R`%%U97)Y`%%U;W1A`%)E860`4F5F<F5S
M:`!2969R97-H(')A=&4Z`%)E;&]A9`!296UA<FMS`%)E;6]V90!297-E=`!2
M97-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E=6YI;VX`4FEG:'0`4F]L90!2
M;VUA;FEA`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W=S.@!2=6X`4G5S
M<VEA;B!&961E<F%T:6]N`%)W86YD80!34T@`4V%I;G0@2&5L96YA`%-A:6YT
M($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD
M($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A
M;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=61I($%R
M86)I80!3879E`%-A=F4@3W!T:6]N<P!396%R8V@`4V5A<F-H($5N9VEN97,`
M4V5L96-T(&$@9&%T90!396QE8W0@86QL`%-E;&5C="!N;VYE`%-E;F5G86P`
M4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R
M`%-E<W-I;VYS`%-E=`!3971U<`!397EC:&5L;&5S`%-H;W<`4VAR:6YK`%-I
M97)R82!,96]N90!3:6=N871U<F4`4VEN9V%P;W)E`%-I>F4`4VQO=F%K:6$`
M4VQO=F5N:6$`4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]U=&@@069R:6-A
M`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S
M`%-P86-I;F<`4W!A:6X`4W!A;0!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A='5S
M`%-T<FEK971H<F]U9V@`4W5B:F5C=`!3=6)M:70`4W5B<V-R:7!T`%-U8V-E
M<W,`4W5D86X`4W5M;6%R>0!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE
M`%-V86QB87)D(&%N9"!*86X@36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET
M>F5R;&%N9`!3>7)I86X@07)A8B!297!U8FQI8P!486)L90!486)L92!0<F]P
M97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:FEK:7-T86X`5&%S
M:W,`5&5L97!H;VYE($YU;6)E<@!496UP97)A='5R90!497AT`%1E>'0@3VYL
M>0!4:&%I;&%N9`!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES
M(&UE<W-A9V4@<&%R=`!4:6UE`%1I;64@9F]R;6%T`%1I=&QE`%1O`%1O9&%Y
M`%1O9V\`5&]K96QA=0!4;VYG80!4;W``5')I;FED860@86YD(%1O8F%G;P!4
M=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T
M86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!54DP`55),.@!5
M9V%N9&$`56MR86EN90!5;F1E<FQI;F4`56YF:6QE9`!5;FEC;V1E("A55$8M
M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D
M(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`
M56YI=',`56YK;F]W;@!5;FYA;65D`%5P9&%T90!5<&QO860`57)U9W5A>0!5
M<V5R`%5S97(@061M:6YI<W1R871I;VX`57-E<FYA;64`57-E<FYA;64Z`%5Z
M8F5K:7-T86X`5F%L:61I='D`5F%L=65S`%9A;G5A='4`5F%R:6%B;&4`5F5N
M97IU96QA`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9I97<@)7,`5FER9VEN
M($ES;&%N9',L(%4N4RX`5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!796(`
M5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!797-T97)N
M(%-A:&%R80!7:61T:`!7:61T:#H`5VES:&QI<W0`5V]R:R!!9&1R97-S`%=O
M<FL@4&AO;F4`65D`65E960!996%R;'D`665M96X`665S`%EO=7(@3F%M90!9
M=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W90!?3&]G(&]U=`!A9&1R
M97-S964@=6YK;F]W;@!C86YN;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO
M="!O<&5N(&EN<'5T`&-O;6UA;F0@;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U
M<F%T:6]N(&5R<F]R`&-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T
M82!F;W)M870@97)R;W(`96YT<GD@;F]T(&9O=6YD`&AH`&AO<W0@;F%M92!U
M;FMN;W=N`&EN<'5T+V]U='!U="!E<G)O<@!I;G1E<FYA;"!S;V9T=V%R92!E
M<G)O<@!M;0!N86UE`'!E<FUI<W-I;VX@9&5N:65D`'!I>&5L<P!R96UO=&4@
M97)R;W(@:6X@<')O=&]C;VP`<V5R=FEC92!U;F%V86EL86)L90!S<P!S>7-T
M96T@97)R;W(`=&5M<&]R87)Y(&9A:6QU<F4`=6YK;F]W;B!E<G)O<@!U;FYA
M;65D`'9#87)D`%!R;VIE8W0M260M5F5R<VEO;CH@24U0"E!/5"U#<F5A=&EO
M;BU$871E.B`R,#`T+3$R+3`X(#$P.C(X*S`Q,#`*4$\M4F5V:7-I;VXM1&%T
M93H@,C`P-2TP-BTQ-2`Q,3HU,RLP-S`P"DQA<W0M5')A;G-L871O<CH@3&5A
M;F<@0VAU;7-O8F5N(#QS;V)E;D!K:&UE<F]S+FEN9F\^"DQA;F=U86=E+51E
M86TZ($MH;65R(#QS=7!P;W)T0&MH;65R;W,N:6YF;SX*34E-12U697)S:6]N
M.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/75T9BTX
M"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`"`H)7,@X9Z0X9^2
MX9Z$X9^#XH"+X9Z`X9Z3X9^2X9Z;X9Z$XH"+X9Z1X9^%*0`@*.&>@N&?DN&>
MFN&>MN&>E.&?B^*`B^&>A>&>N^&>A>*`B^&>E>&?DN&>F^&>O.&>G.*`B^&>
M@.&>MN&>C^&?BR`E<RD`("CAGI#AGY+AGH3AGX/B@(OAGI/AGX'AGX<I`"`H
MX9Z0X9^2X9Z$X9^#XH"+X9Z?X9^2X9ZBX9^"X9Z`*0`@*.&>F.&?DN&>G^&>
MM^&>F^&>F.&?B>&>M^&>B2D`(B5S(B#AGICAGK?AGI/B@(OAGICAGX+AGI/B
M@(OAGH?AGK;B@(OAGI#AGH_B@(OAGJ'AGK[AGIG"H.&?E``B)7,B(.&>F.&>
MM^&>D^*`B^&>F.&?@N&>D^*`B^&>A^&>MN*`B^&>A^&>F.&?DN&>FN&>ON&>
MG^*`B^&>C^&?DN&>FN&>N>&>F.&>C^&?DN&>FN&>O.&>G.*`B^&>H>&>ON&>
MF<*@X9^4`"5D("5S(.&>D^&>M^&>A"`E<P`E<R!+0@`E<R#AGICAGX'AGH#A
MGK;AGI3AGX,`)7,@X9^6("5S`"TM(.&>A^&?DN&>FN&>ON&>GR`M+0#AGI'A
MGY+AGIKAGH3AGXOAGI'AGY+AGIKAGK;AGID@X9^AX9^B(.&>F.&?B>&?A.&>
MA`#AGI'AGY+AGIKAGH3AGXOAGI'AGY+AGIKAGK;AGID@X9^BX9^D(.&>F.&?
MB>&?A.&>A`#AGZ+AGZ0@X9Z8X9^)X9^$X9Z$`#SAGICAGKOAGI,`X9ZBX9^&
MX9Z6X9ZXXH"++BXN`.&>EN&?D.&>C^&?C.&>F.&>MN&>D^*`B^&>HN&?AN&>
MEN&>N.&>@N&>CN&>D^&>N`#AGI3AGI/AGY+AGI#AGX+AGI@`X9Z4X9Z3X9^2
MX9Z0X9^"X9Z8XH"+XH"+XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z4X9^2X9Z:X9Z^
M`.&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>DP#AGI_AGX#AGISAGI?AGX7B
M@(OAGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI,`X9Z`X9ZVX9Z:XH"+X9Z"
MX9^2X9Z:X9Z4X9^+XH"+X9Z"X9^2X9Z:X9Z$`.&>HN&>MN&>H.&?DN&>@N&>
MMN&>D^&>N.&>G^&?DN&>D.&>MN&>DP#AGJ+AGK;AGIOAGXOAGI3AGK;AGI/A
MGK@`X9ZBX9ZVX9Z;X9^+X9Z@X9^2X9Z?X9^!X9Z:X9ZX`.&>B.&?DN&>F.&?
MA.&?A^*`B^&>@.&?DN&>F^&?@N&>A.&>@.&?DN&>F^&>MN&>F0#AGH_AGICA
MGY+AGIKAGKGAGI@`X9Z1X9ZVX9^&X9Z$XH"+X9ZBX9Z?X9^+`.&>E.&?DN&>
MBN&>O.&>FN*`B^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>HN&?
MBN&>N.&>F.&?@N&>FP#AGI_AGK;AGICAGKSAGJ+AGK8@X9ZBX9ZVX9Z8X9^!
MX9Z:X9ZWX9Z``.&>HN&>A.&?B^&>BN&>O.&>FN&?B>&>M@#AGJ+AGH3AGXOA
MGJ#AGY+AGH+AGX3AGJ'AGK8`X9ZBX9Z$X9^+X9Z@X9^2X9Z?X9^*X9ZXX9ZA
MX9ZV`.&>E^&>MN&>@N*`B^&>@>&>MN&>A.*`B^&>C^&?DN&>E.&>O.&>A`#A
MGJ+AGH3AGXOAGI'AGKCAGJ#AGY+AGH+AGK8@X9Z3X9ZWX9Z$(.&>E.&>MN&>
ME.&?BN&>N^&>F>&>BN&>M@#AGH#AGICAGY+AGICAGISAGK?AGI+AGK@`X9Z8
MX9^!X9Z?X9ZV`.&>HN&>MN&>FN&?B>&>MN&>E.&?BR`H5VEN9&]W<RTQ,C4V
M*0#AGJ+AGK;AGJ#AGY+AGI_AGH3AGXOAGI'AGKCAGI,`X9ZBX9ZVX9Z8X9^!
MX9Z3X9ZX`.&>HN&>MN&>FN&>O.&>E.&>M@#AGH+AGKOAGH[AGIOAGH#AGY+A
MGH'AGH[AGX@`X9Z?X9ZXX9Z@X9ZV`.&>HN&>O.&>G^&?DN&>C^&?DN&>FN&>
MMN&>F^&>N`#AGJ+AGKSAGI'AGY+AGIKAGKCAGI\`X9Z`X9ZVX9Z:XH"+X9Z5
MX9^2X9Z1X9^`X9Z$XH"+X9Z5X9^2X9Z1X9ZVX9Z/X9^+XH"+X9Z7X9ZVX9Z6
MXH"+X9Z/X9^2X9Z:X9ZYX9Z8XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZV
MX9Z3XH"+X9Z4X9Z:X9ZVX9Z'X9^0X9Z9`.&>HN&>MN&>H.&?DN&>G^&?BN&?
M@N&>FN&>E.&?@N&>H.&?DN&>G^&>A.&?BP#AGI7AGY+AGI'AGX/B@(OAGH'A
MGK;AGH3B@(OAGH#AGY+AGIKAGX3AGID`X9Z6X9Z.X9^,XH"+X9Z5X9^2X9Z1
MX9^#XH"+X9Z!X9ZVX9Z$XH"+X9Z`X9^2X9Z:X9^$X9Z9`.&>E.&>MN&>H.&>
MMN&>F.&?B>&>MN&>GP#AGI3AGK;AGIKAGXGAGX+AGI,`X9Z4X9Z$X9^+X9Z`
MX9^2X9Z;X9ZVX9Z*X9^!X9Z?X9^2X9Z@`.&>E.&>MN&>FN&>E.&>MN&>BN&>
MO.&>GP#AGI3AGX'AGJ'AGK;AGIKAGKOAGI_AGY+AGI\`X9Z4X9^"X9Z;XH"+
MX9Z@X9^2X9Z?X9^*X9ZWX9Z``.&>E.&?@>&>F^&>N.&>H.&?DN&>GP#AGI3A
MGX'AGH[AGK;AGX;AGH0`X9Z4X9^*X9^!X9Z:X9Z8X9Z\X9Z*X9ZV`.&>E.&?
MBN&>O.&>C^&>MN&>DP#AGI#AGY+AGH3AGX/AGH#AGX;AGH[AGK[AGH\`X9Z*
MX9ZWX9Z/`.&>E.&>O.&>F^&>N.&>G.&>N`#AGH#AGI/AGY+AGIOAGX+AGH3B
M@(OAGH7AGX;AGH[AGK;AGX8`X9Z?X9^*X9Z[X9Z8`.&>G^&?BN&>N^&>F.*`
MBP#AGI3AGKSAGI_AGY+AGI/AGXKAGK@@X9Z3X9ZWX9Z$(.&>H.&>NN&>H.&?
MDN&>G^&?BN&?@>&>H.&?DN&>@N&?A.&>G.&>N.&>CN&>M@#AGI'AGK;AGX;A
MGH3B@(OAGI;AGKCAGIKB@(L`X9Z4X9Z[X9Z/X9Z?X9^2X9Z<X9ZVX9Z.X9ZV
M`.&>E.&>MN&>CP#AGH#AGX3AGX?B@(OAGI3AGXKAGKSAGISAGXGAGX(`X9Z4
MX9^2X9Z:X9^!X9Z?X9^*X9ZXX9Z;`.&>HN&>MN&>CN&>MN&>A>&>@.&?DN&>
MFN*`B^&>G^&>F.&>N^&>D>&?DN&>FN*`B^&>I>&>CN&?DN&>C.&>MB#AGJ+A
MGH3AGXOAGH+AGY+AGIOAGX'AGI\`X9Z4X9^2X9Z:X9^*X9Z[X9Z9X9Z.X9^!
MXH"+X9Z*X9ZVX9Z:X9^*X9Z[X9Z9X9Z?X9ZVX9ZAX9ZVX9Z8`.&>E.&?BN&>
MN^&>F^&>H.&?DN&>@N&>MN&>FN&>N`#AGI3AGXKAGKSAGIKAGH+AGKCAGH[A
MGK;AGJ#AGY+AGISAGK;AGI_AGKP`X9Z4X9^*X9Z\X9Z:X9Z[X9Z3X9Z,X9ZX
M`$-20P#AGI3AGY+AGIKAGH_AGK?AGI'AGK?AGI,`X9Z`X9Z8X9^2X9Z6X9Z[
MX9Z'X9ZV`.&>@.&>MN&>F.&?B>&>MN&>FN&>O.&>DP#AGH#AGK;AGH[AGK;A
MGHKAGK8`X9Z4X9^$X9^'X9Z4X9Z$X9^+`.&>@.&>MN&>E.&>G.&?@N&>F@#A
MGH7AGX;AGH[AGH3AGH?AGK[AGH0`X9Z<X9Z/X9^2X9Z0X9Z[XH"+X9Z*X9ZY
MX9Z`XH"+X9Z'X9Z)X9^2X9Z'X9Z\X9Z3`.&>@.&?A.&?A^*`B^&>@.&?@^&>
MF.&?B>&>MN&>DP#AGH#AGH[AGY+AGH_AGK;AGIL`X9Z?X9ZVX9Z2X9ZVX9Z:
MX9Z.X9Z:X9Z*X9^2X9Z+XH"+X9ZBX9ZVX9Z@X9^2X9Z<X9^2X9Z:X9ZWX9Z`
MXH"+X9Z`X9Z.X9^2X9Z*X9ZVX9Z;`.&>AN&>MN&>B@#AGI7AGY+AGIOAGK;A
MGI_AGXOB@(OAGI3AGY+AGH_AGKSAGIH`X9Z(X9ZXX9Z;X9ZX`.&>A>&>M^&>
MDP#AGH#AGX3AGX?B@(OAGH+AGY+AGIKAGKCAGI_AGY+AGH_AGICAGXGAGK;A
MGI\`X9Z'X9Z8X9^2X9Z:X9^'`.&>A^&>F.&?DN&>FN&?A^*`B^&>G^&?AN&>
MCN&>O>&>F@#AGI3AGK?AGI'B@(OAGI3AGH3AGY+AGJ+AGKWAGH4`X9Z`X9^$
MX9^'XH"+X9Z`X9Z\X9Z`X9Z\("CAGH/AGKCAGIOAGKCAGH0I`.&>@.&>O.&>
MH>&>N^&?AN&>E.&?BN&>N`#AGI;AGH[AGXP`X9Z6X9ZVX9Z`X9^2X9Z9XH"+
MX9Z4X9Z)X9^2X9Z'X9ZV`.&>G^&?@>&>A>&>@.&?DN&>C^&>N.*`B^*`B^&>
MHN&>DN&>M^&>E.&?DN&>E.&>MN&>F0#AGHCAGY+AGICAGX3AGX?B@(OAGI+A
MGICAGY+AGICAGH_AGK8`X9Z`X9Z[X9^&X9Z8X9^)X9Z\X9Z:X9^)X9Z\X9Z?
M`.&>@.&?DN&>FN&>N^&>F.&>H.&?BN&>N^&>DP#AGH#AGKOAGX;AGI;AGY+A
MGIGAGKSAGI'AGY#AGIH`X9Z;X9Z`X9^2X9Z!X9Z!X9Z.X9^2X9Z,`.&>F^&>
M@.&?DN&>@>&>@>&>CN&?DN&>C`#AGJ+AGX?AGJ+AGK;AGH3B@(OAGJ+AGK;A
MGI_AGIGAGHKAGY+AGHOAGK;AGI/B@(OAGJ+AGXKAGKCAGICAGX+AGIL`X9ZB
MX9^'X9ZBX9ZVX9Z$XH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+
MX9ZBX9^*X9ZXX9Z8X9^"X9Z;XH"+X9Z0X9^2X9Z8X9ZX`.&>@.&>N^&>A.&>
MH.&?DN&>@N&?A`#AGH#AGK;AGIKB@(OAGH_AGI?AGY+AGH?AGK;AGI3AGXOB
M@(OAGI3AGK;AGI/B@(OAGI3AGIKAGK;AGH?AGY#AGIGB@(O"H.&?E`!#;VYT
M86-T<P#AGI3AGI/AGY+AGH\`X9Z`X9^$X9^'XH"+X9Z`X9Z\X9Z``.&>A>&>
MF.&?DN&>F^&>A`#AGH#AGKSAGI_AGY+AGH_AGK;AGIKAGKCAGH#AGK8`X9Z4
MX9^2X9Z:X9Z1X9^!X9Z?`.&>E.&>A.&?DN&>@.&>ON&>CP#AGH#AGY+AGIKA
MGKSAGJ+AGK;AGH\`X9Z"X9Z[X9Z9X9Z4X9ZV`.&>EN&?@>&>F^*`B^&>G.&?
M@>&>F^&>MN*`B^&>E.&>A>&?DN&>A>&>N^&>E.&?DN&>E.&>D^&?DN&>DP#A
MGIKAGH7AGI/AGK;AGI3AGY#AGI'AGY+AGICB@(OAGI3AGH7AGY+AGH7AGKOA
MGI3AGY+AGI3AGI/AGY+AGI/B@(L`X9Z4X9^2X9Z/X9Z\X9Z:XH"+X9Z7X9ZV
MX9Z:X9Z`X9ZWX9Z%X9^2X9Z%XH"+X9Z*X9^"X9Z;XH"+X9Z/X9^2X9Z:X9Z\
MX9Z<XH"+X9Z:X9Z/X9^+XH"+X9Z/X9ZVX9Z8XH"+X9Z4X9^&X9Z.X9Z$(.&>
MHN&>MN&>G^&?DN&>FN&?D.&>F>*`B^&>F^&>ON*`B^&>@.&>MN&>FN*`B^&>
MA>&>O.&>F^*`B^&>D>&?A>*`BR`E<R#AGY0`X9Z`X9ZVX9Z/X9^+`.&>G^&?
MBN&>N.&>EN&>FN&?C0#AGI_AGXKAGKCAGIKAGKCAGIOAGKCAGH`@*$M/23@M
M4BD`XH"+XH"+X9Z?X9^*X9ZXX9Z:X9ZXX9Z;X9ZXX9Z`("A7:6YD;W=S+3$R
M-3$I`.&>G^&>MN&>DN&>MN&>FN&>CN*`B^&>FN&>BN&?DN&>B^*`B^&>AN&?
M@>&>@`!$1`#AGIKAGK;AGIOAGXOB@(OAGI#AGY+AGH3AGX,`X9Z`X9ZVX9Z;
MXH"+XH"+X9Z4X9Z:X9ZWX9Z%X9^!X9^2X9Z&X9Z1`.&>D.&?DN&>A.&?@P#A
MGI+AGY+AGI/AGKP`X9Z4X9Z3X9^2X9Z0X9Z9(.&>A>&>O.&>F^*`B^&>E.&>
MD^&?DN&>D>&>MN&>C^&?BP#AGIOAGX;AGI/AGK;AGX;AGHKAGK[AGI@`X9Z;
MX9Z[X9Z4XH"+`.&>F^&>N^&>E.*`B^&>A^&>O>&>FN*`B^&>B.&>F@#AGIOA
MGKOAGI3B@(OAGH?AGKWAGIKAGHKAGX'AGH``X9Z*X9ZVX9Z.X9ZZX9Z8X9^)
MX9ZVX9Z``.&>@.&>MN&>FN&>EN&>M^&>EN&>CN&?C.&>D^&>M@#B@(OAGJ+A
MGI?AGK?AGISAGHSAGY+AGHT`X9Z0X9Z/`.&>H.&?DN&>G^&?BN&>N.&>E.&>
MO.&>D>&>N`#AGHKAGKSAGICAGKCAGI/AGKCAGH#AGK8`X9Z?X9ZVX9Z2X9ZV
MX9Z:X9Z.X9Z:X9Z*X9^2X9Z+XH"+X9Z*X9Z\X9Z8X9ZXX9Z3X9ZXX9Z`X9^"
MX9Z3`.&>F.&>M^&>D^*`B^&>F.&>MN&>D^*`B^&>@N&>CN&>D^&>N,*@/R#A
MGI_AGKSAGICB@(OAGH7AGKOAGX?AGHCAGY+AGICAGX3AGX?"H.&?E`#AGI'A
MGK;AGHGAGIGAGH``X9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z0X9ZVX9Z8
MX9Z<X9Z3X9^2X9Z/`.&>HN&?BN&>N.&>F.&?@N&>FP#AGJ+AGX'AGH#AGY+A
MGISAGK;AGHSAGY#AGIH`X9Z`X9^"XH"+X9Z?X9Z8X9^2X9Z:X9Z]X9Z;`.&>
M@.&>MN&>FN*`B^&>HN&>E.&?B^&>FN&?A@#AGJ+AGX'AGJ#AGY+AGI_AGXKA
MGKCAGI0`X9ZBX9^"X9Z;X9Z?X9ZVX9Z;X9^+X9Z<X9^)X9ZVX9Z,X9^0X9Z:
M`.&>HN&?BN&>N.&>F.&?@N&>FP#AGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;A
MGI/B@(OAGJ+AGXKAGKCAGICAGX+AGIL`X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+
MX9ZVX9Z3XH"+X9ZBX9^*X9ZXX9Z8X9^"X9Z;XH"+X9Z/X9^2X9Z:X9Z\X9Z<
MXH"+X9Z/X9^"XH"+X9Z*X9Z\X9Z%X9Z"X9^2X9Z3X9ZVPJ#AGY0`X9Z?X9Z)
MX9^2X9Z)X9ZVXH"+X9ZBX9ZVX9Z:X9Z8X9^2X9Z8X9Z.X9^-`.&>H.&?DN&>
M@N&>N.&>CN&?@>*`B^&>HN&?@>&>@.&?DN&>G.&>MN&>D>&?D.&>F@#AGJ+A
MGX'AGIKAGKCAGI'AGY+AGIKAGK8`X9Z`X9^&X9Z@X9Z[X9Z?`.&>HN&?@>&>
MG^&?DN&>C^&>O.&>D^&>N`#AGJ+AGX'AGH_AGY+AGIGAGKSAGI;AGK@`X9ZB
MX9ZZX9Z:X9^)X9Z[X9Z4`.&>FN&?@.&>A.*`B^&>FN&>MN&>F^&?B^*`BR#A
MGZ'AGZ4@X9Z3X9ZVX9Z1X9ZX`.&>FN&?@.&>A.*`B^&>FN&>MN&>F^&?B^*`
MBR#AGZ/AGZ`@X9Z<X9ZWX9Z3X9ZVX9Z1X9ZX`.&>FN&?@.&>A.*`B^&>FN&>
MMN&>F^&?BR#AGZ4@X9Z3X9ZVX9Z1X9ZX`.&>FN&?@.&>A.*`B^&>FN&>MN&>
MF^&?B^*`B^&>@.&>D^&?DN&>F^&?A^*`B^&>F.&?B>&?A.&>A`#AGIKAGX#A
MGH3B@(OAGIKAGK;AGIOAGXOAGI/AGK;AGI'AGK@`X9Z4X9^2X9Z:X9Z/X9ZW
MX9Z4X9Z/X9^2X9Z/X9ZW`.&>E.&>D^&?DN&>F^&>MN&>F0#AGJ+AGXKAGK?A
MGH7AGI_AGY+AGI3AGKSAGH[AGH3AGXOAGI_AGX+AGIL`X9Z`X9^$X9^'XH"+
MX9Z@X9^2X9Z<X9^)X9Z`X9ZAX9Z$X9^+("CAGICAGXGAGK;AGIOAGXOAGISA
MGKCAGH[AGK8I`.&>@.&?A.&?A^&>H.&?DN&>G.&>MN&>HN&?@>&>FN&>O`#A
MGI'AGKSAGIKAGI_AGK;AGIH`X9Z`X9Z[X9Z8X9^2X9Z7X9^(`.&>H.&?DN&>
MG.&>N.&>H.&?DN&>G^&?BN&>N`#AGJ_AGH#AGI_AGK;AGIH`X9Z(X9^2X9Z8
MX9^$X9^'XH"+X9ZOX9Z`X9Z?X9ZVX9Z:`.&>C^&>F.&?DN&>FN&>A`#AGJ#A
MGY+AGISAGK;AGX;AGH3AGJ'AGH3AGXL`X9Z/X9^2X9Z:X9ZAX9Z4X9^+`.&>
MD>&>G^&>E^&>MN&>@@#AGI;AGH[AGXSB@(OAGI;AGKOAGICAGY+AGI;B@(OA
MGJ+AGH#AGY+AGI_AGIH`X9Z?X9^&X9Z.X9Z[X9^&XH"+XH"+X9Z4X9^"X9Z4
MX9Z4X9Z1`.&>G^&?BN&>N^&>F`#AGI3AGK;AGIKAGK;AGX;AGH0`X9Z@X9^2
MX9Z"X9Z\X9ZBX9^*X9ZXX9Z9X9^)X9ZVX9Z.X9ZV(.&>E.&>MN&>FN&>MN&?
MAN&>A`#AGI3AGXGAGKSAGIOAGKCAGI/AGX'AGI_AGXKAGKCB@(OAGI3AGK;A
MGIKAGK;AGX;AGH0`X9ZBX9ZVX9Z.X9Z%X9Z`X9^2X9Z:XH"+X9Z!X9ZVX9Z$
MXH"+X9Z/X9^2X9Z4X9Z\X9Z$(.&>E.&>MN&>FN&>MN&?AN&>A`#AGI;AGK@`
MX9Z(X9^2X9Z8X9^$X9^'XH"+X9Z6X9^!X9Z)`.&>H.&?DN&>@N&>MN&>E.&>
MN^&>A`#AGJ#AGY+AGH#AGK;AGX;AGI3AGXKAGK@`X9Z@X9^2X9Z?X9Z`X9Z@
MX9^2X9Z?X9^*X9ZX`.&>HN&>MN&>F^&?DN&>F^&>NN&>F.&?B>&>A.&?BP#A
MGJ#AGY+AGH#AGK;AGH[AGK8`X9Z@X9^2X9Z"X9ZXX9Z4X9^2X9Z:X9ZVX9Z;
MX9^+X9Z/X9ZV`.&>D^&>MN&>F.&>@>&?DN&>F^&>O>&>DP#AGH?AGICAGY+A
MGIKAGK[AGI_B@(OAGI_AGH#AGIL`X9Z1X9^%`.&>F.&>MN&>C^&?DN&>FN&>
MBN&?DN&>B^&>MN&>D^*`B^&>E.&?DN&>FN&>E>&?@>&?AP#AGH#AGY+AGIKA
MGK?AGH``X9Z`X9^2X9Z:X9ZWX9Z`("A)4T\M.#@U.2TW*0#AGH+AGY+AGIKA
MGKCAGJ'AGH3AGXL`X9Z@X9^2X9Z"X9^2X9Z:X9ZXX9Z.X9ZVX9Z*X9ZV`.&>
M@.&?DN&>FN&>N^&>F`#AGJ#AGY+AGH+AGKSAGJ+AGK;AGHKAGKKAGIOAGKSA
MGI3AGXGAGX$`X9Z@X9^2X9Z"X9ZVX9^&X9Z8`.&>H.&?DN&>@N&>MN&>C^&?
M@>&>F.&?B>&>MN&>H>&>M@#AGJ#AGY+AGH+AGKCAGH[AGX$`X9Z@X9^2X9Z"
MX9ZXX9Z.X9^!X9Z4X9^*X9ZXX9Z?X9^%`.&>H.&?DN&>@N&>N.&>F>&?B>&>
MMN&>CN&>M@!(5$U,`.&>H.&?@^&>D>&>N`#AGI3AGHOAGICAGH#AGI#AGK;B
M@(L`X9Z4X9Z+X9Z8X9Z`X9Z0X9ZV`.&>@.&?A.&?A^*`B^&>H.&?BN&>ON&>
MBB#AGI/AGK?AGH0@X9Z`X9^$X9^'XH"+X9Z8X9^)X9ZVX9Z`X9Z*X9Z\X9Z.
MX9ZVX9Z;X9^+`.&>@.&>F.&?DN&>EN&>G^&?BP#AGH?AGX;AGI/AGKWAGID`
MX9Z!X9^2X9Z6X9Z?X9^+`.&>H.&>O.&>F^&>N.&>G^&?BN&>N"`HX9Z:X9Z*
MX9^2X9Z+XH"+X9Z`X9^2X9Z:X9Z[X9Z$XH"+X9Z<X9^)X9ZVX9Z1X9ZXX9Z`
MX9Z$X9^+*0#AGH+AGX'AGJ#AGI'AGX;AGI;AGY#AGIH`X9ZBX9ZVX9Z?X9Z9
MX9Z*X9^2X9Z+X9ZVX9Z3XH"+X9Z5X9^2X9Z1X9^'`.&>D.&>C^&>E>&?DN&>
MD>&?AP#AGI'AGKSAGIKAGI_AGY#AGI;AGY+AGI'B@(OAGI7AGY+AGI'AGX<`
MX9Z@X9Z[X9Z$X9Z,X9Z\X9Z:X9^)X9ZVX9Z?X9^+`.&>H.&>N^&>A.&>@.&>
MN^&>A`#AGJ#AGKOAGH3AGH+AGY+AGIKAGK@`X9ZBX9ZVX9Z?X9Z9X9Z*X9^2
MX9Z+X9ZVX9Z3XH"+($E0`.&>HN&?BN&>N.&>G^&?DN&>F^&>A.&?BP#AGH_A
MGX+B@(OAGIKAGKSAGI3AGH_AGX;AGH[AGK;AGH0`X9Z:X9Z\X9Z4X9Z7X9ZV
MX9Z6`.&>E.&>A.&?DN&>@.&>ON&>D^*`B^&>@.&>MN&>FN*`B^&>A>&>O.&>
MF^*`B^&>E.&>D^&?DN&>D>&>MN&>C^&?BP#AGJ7AGH[AGY+AGHSAGK8`X9ZE
MX9Z.X9^2X9Z,X9Z\X9Z3X9^!X9Z?X9^*X9ZX`.&>EN&?D.&>C^&?C.&>F.&>
MMN&>DP#AGI;AGY#AGH_AGXSAGICAGK;AGI,`X9Z4X9Z)X9^2X9Z%X9Z\X9Z;
MXH"+X9Z/X9ZVX9Z:X9ZVX9Z$`.&>A>&?AN&>D^&>O>&>D^*`B^&>@N&>C^&?
MBP#AGJ+AGXKAGKCAGIKAGXGAGK;AGH#AGXL`X9ZBX9^`X9Z:X9ZAX9Z$X9^+
M`.&>HN&?BN&>N.&>G^&?DN&>FN&>MN&>HN&?@N&>FP#AGJ+AGY+AGI/AGH#B
M@(OAGH7AGX'AGHD`X9Z1X9^2X9Z:X9^!X9Z/`.&>HN&?BN&>N.&>C^&>MN&>
MF^&>N`#AGH7AGK;AGICAGXGAGX/AGH#AGK8`X9Z8X9Z`X9Z:X9ZV`.&>A^&>
ME.&?B>&>N^&>DP#B@(OAGH?AGI3AGXGAGKOAGI,@*$E33RTR,#(R+4I0*0#A
MGJ#AGY+AGI_AGXKAGH#AGHKAGK;AGI/AGK@`X9Z`X9Z`X9^2X9Z`X9Z*X9ZV
M`.&>F.&>M^&>D.&>N^&>D^&>M@#AGH_AGICAGY+AGIKAGKGAGICB@(OAGI_A
MGH3B@(OAGH'AGK;AGH0`X9Z`X9ZVX9Z@X9^2X9Z?X9ZVX9Z`X9^+X9Z?X9^2
MX9Z/X9Z$X9^+`.&>@.&?@N&>D^&>F>&?B>&>M@#AGI3AGY+AGIKAGISAGX+A
MGH3B@(OAGH#AGKSAGI/AGI_AGX0`X9Z4X9^2X9Z:X9Z7X9^!X9Z1XH"+X9Z"
MX9^2X9Z:X9ZVX9Z4X9^+XH"+X9Z%X9Z[X9Z%`.&>@N&>M^&>FN&>M^&>E.&>
MMN&>D>&>N`#B@(OAGH#AGKSAGIKAGXGAGX$@*$550RU+4BD`X9Z"X9Z[X9Z9
MXH"+X9Z<X9^)X9^"X9Z/`.&>@N&?@.&>FN&>H.&?DN&>@N&>N.&>G^&?DN&>
MC^&>A.&?BP#AGI?AGK;AGI_AGK8`X9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9Z:X9Z*
MX9^2X9Z+XH"+X9Z4X9^2X9Z:X9Z'X9ZVX9Z2X9ZWX9Z4X9Z/X9^!X9Z9X9^2
MX9Z9XH"+X9Z4X9^2X9Z:X9Z'X9ZVX9Z8X9ZVX9Z3X9ZWX9Z/XH"+X9ZAX9ZV
MX9Z<`.&>H>&>MN&>C^&>G.&>N.&>F>&?B>&>M@#AGI3AGY+AGIOAGH3AGXOB
M@(L`X9Z;X9ZXX9Z4X9Z$X9^+`.&>AN&?DN&>G.&?@>&>A`#AGJ'AGX'AGI_A
MGKSAGH_AGKP`X9Z`X9Z8X9^2X9Z:X9ZWX9Z/`.&>F^&>N.&>E.&?@>&>FN&>
MN.&>F>&?B>&>M@#AGH7AGK;AGICAGXGAGK;AGJ+AGXKAGK?AGIKAGKCAGIGA
MGXGAGK;B@(OAGJ+AGK;AGIKAGXGAGK;AGI3AGXL@X9Z;X9ZXX9Z4X9^*X9ZX
M`.&>F^&>M^&>A>&>D>&?@>&>D^&>G^&?DN&>C^&?@N&>DP#AGH_AGX;AGHX`
MX9Z/X9^&X9Z.`.&>F^&>N.&>D>&>N^&>F>&>HN&>MN&>D^&>N`#AGH#AGX;A
MGI;AGKOAGH3B@(OAGI7AGY+AGI'AGKOAGH`N+BX`X9Z1X9ZXX9Z/X9ZVX9^&
MX9Z$`.&>A>&>O.&>FP#AGH7AGX'AGHD`X9Z%X9Z\X9Z;`.&>E^&>MN&>FN&>
M@.&>M^&>A>&?DN&>A>*`B^&>A>&>O.&>FP#AGI_AGX'AGH7AGH#AGY+AGH_A
MGKCB@(OAGI_AGY+AGIKAGJ'AGK;AGHGAGXL`X9Z1X9ZVX9Z4`.&>F^&>N^&>
MA>&>H.&?DN&>G^&?AN&>E.&>O>&>F@!-30#AGICAGXGAGK;AGH#AGK;AGIP`
MX9Z8X9^)X9ZVX9Z*X9ZVX9Z@X9^2X9Z`X9ZVX9Z?X9^2X9Z`X9ZVX9Z:`.&>
MG^&?AN&>E.&>N^&>C^&?DN&>F@#AGICAGXGAGK;AGJ'AGK;AGISAGX,`X9Z8
MX9^)X9ZVX9ZAX9^!X9Z?X9^*X9ZX`.&>F.&?B>&>MN&>F^&?B^&>C.&>N.&>
MG`#AGICAGXGAGK;AGIOAGK@`X9Z8X9^)X9ZVX9Z;X9^+X9Z/X9ZV`.&>F.&>
MN.&>D^&>M@#AGIKAGKGAGICB@(OAGI'AGX;AGI;AGY#AGIH`X9Z`X9^$X9^'
M($UA<G-H86QL`.&>F.&?B>&>MN&>FN&>D>&>N.&>D^&>N.&>@@#AGICAGXGA
MGKSAGIKAGKCAGH_AGK;AGI/AGK@`X9Z8X9^)X9Z\X9Z:X9ZXX9Z1X9Z[X9Z?
M`.&>I^&>G^&>E^&>M@#AGICAGX/AGJ+AGKSAGH_AGX$`X9Z?X9Z8X9ZVX9Z'
MX9ZWX9Z``.&>G^&>MN&>F@#AGISAGK?AGI+AGKCAGI_AGK;AGI_AGY+AGIKA
MGY+AGH\`X9Z8X9^)X9ZWX9Z%X9Z?X9^*X9ZWX9Z``.&>@.&>CN&?DN&>C^&>
MMN&>FP#AGI3AGY+AGIKAGI?AGX'AGI$@36EM90#AGH;AGY+AGIOAGKOAGX<`
MX9Z5X9^2X9Z?X9^!X9Z$X9^7XH"+`.&>F.&?B>&>O.&>CN&>MN&>@.&>O`#A
MGICAGXGAGKOAGH3AGJ#AGY+AGH+AGX3AGIOAGK@`X9Z!X9^"(.&>D^&>M^&>
MA"#AGH;AGY+AGI/AGK;AGX8`X9Z:X9ZVX9Z;X9^+XH"+X9Z!X9^"`.&>F.&?
MB>&>N^&>A.&>G^&?@>&>FN&?B>&>M@#AGICAGXGAGK;AGIKAGXGAGKOAGH``
MX9Z5X9^2X9Z;X9ZVX9Z?X9^+XH"+X9Z1X9ZXXH"+X9Z%X9Z[X9^'XH"+X9Z`
MX9^2X9Z:X9^$X9Z8`.&>E>&?DN&>F^&>MN&>G^&?B^*`B^&>D>&>N.*`B^&>
MD>&?A>*`B^&>AN&?DN&>G.&?@>&>A`#AGI7AGY+AGIOAGK;AGI_AGXOB@(OA
MGI'AGKCB@(OAGI'AGX7B@(OAGI_AGY+AGH_AGK;AGX8`X9Z5X9^2X9Z;X9ZV
MX9Z?X9^+XH"+X9Z1X9ZXXH"+X9ZAX9Z^X9Z$XH"+X9Z;X9Z^`.&>A>&>N^&?
MA^*`B^&>@.&?DN&>FN&?A.&>F`#AGJ'AGK[AGH3B@(OAGIOAGKX`X9Z8X9^)
MX9Z\X9Z@X9^2X9Z?X9ZVX9^&X9Z4X9^*X9ZWX9Z``.&>F.&>N.&>F>&?B>&>
MMN&>D^&?B^&>F.&?B>&>M@#AGHCAGY+AGICAGX3AGX<`X9Z.X9ZVX9Z8X9ZX
MX9Z4X9^*X9ZX`.&>CN&>O.&>FN&>NP#AGI/AGX'AGI3AGXGAGK;AGIOAGXL`
MXH"+X9Z@X9Z[X9Z;X9^2X9Z;X9Z$X9^+`.&>HN&>A.&?B^&>D>&>N.&>F>&?
MC>*`B^&>H.&>O.&>F^&?DN&>F^&>A.&?BP#AGI3AGH[AGY+AGH_AGK;AGHD`
MX9Z`X9Z[X9^&`.&>D^&>O.&>G.&?@N&>F^&>@.&>MN&>F^&?@>&>BN&>O.&>
MD^&>N`#AGI_AGK;AGIKB@(OAGI#AGY+AGICAGKCB@(OAGI'AGX4@)7,`X9Z3
MX9Z\X9Z<X9^"X9Z;X9Z@X9^*X9^2X9Z?X9^!X9ZAX9Z$X9^+`.&>EN&>MN&>
M@.&?DN&>F>*`B^&>G^&>F.&?DN&>A.&>MN&>C^&?B^*`B^&>D.&?DN&>F.&>
MN`#AGI;AGY#AGH_AGXSAGICAGK;AGI,`X9Z<X9^!X9Z1X9ZWX9Z`X9ZVXH"+
MX9Z6X9^0X9Z/X9^,X9Z8X9ZVX9Z3`.&>E.&>D^&?DN&>D>&>MN&>E.&?BP#A
MGI/AGKCAGH#AGK;AGIKAGXGAGK;AGJ#AGY+AGH+AGY#AGIH`X9Z3X9ZXX9Z@
MX9^2X9Z?X9^!X9Z:`.&>D^&>N.&>H.&?DN&>G^&?@>&>FN&>N.&>F>&?B>&>
MM@#AGIGAGI3AGXL`X9Z3X9ZXX9Z<`.&>D>&?@0#AGH+AGY+AGICAGK;AGI,`
MX9Z`X9^$X9^'XH"+X9Z.X9^)X9Z@X9^2X9Z<X9^)X9Z``.&>@.&?A.&?A^*`
MB^&>F.&?B>&>MN&>FN&?@.&>CN&>MN*`B^&>E^&>MN&>@N*`B^&>@>&>MN&>
MA.*`B^&>A^&>ON&>A`#AGI/AGY#AGIKAGISAGX+AGI\`X9Z%X9^&X9Z.X9ZV
MX9^&`.&>G.&>M^&>A>&?DN&>AN&>M^&>@.&>M@#AGIOAGX'AGH$`X9Z%X9^&
MX9Z3X9Z]X9Z3XH"+X9Z/X9Z]X9ZBX9Z`X9^2X9Z?X9Z:`.&>F>&>F^&?B^&>
MEN&?DN&>FN&>F`#AGISAGH_AGY+AGI#AGKL`X9Z/X9Z[X9Z;X9ZV`.&>@.&>
MMN&>FN&>M^&>F>&>MN&>F^&?D.&>F0#AGI;AGK;AGH#AGY+AGIGB@(OAGI_A
MGICAGY+AGH3AGK;AGH_AGXOB@(OAGH7AGK;AGI_AGXL`X9ZBX9Z\X9Z8X9^"
MX9Z3`.&>E.&>ON&>@.*`B^*`B^&>@.&?DN&>D^&>N^&>A.*`B^*`B^&>E.&>
MA.&?DN&>HN&>O>&>A>*`B^&>D.&?DN&>F.&>N`#AGI3AGY+AGIKAGI;AGY#A
MGI/AGY+AGI+B@(OAGI3AGY+AGIKAGH_AGK?AGI3AGH_AGY+AGH_AGK?AGH#A
MGK;AGIH`X9Z'X9Z8X9^2X9Z:X9Z^X9Z?XH"+`.&>E>&?DN&>G^&?@>&>A.&?
MEP#AGH7AGI/AGY+AGIOAGX3AGX<`X9Z4X9^)X9ZVX9Z"X9ZXX9Z?X9^2X9Z0
MX9ZVX9Z3`.&>E.&?B>&>MN&>H>&>O`#AGI3AGXGAGK;AGH[AGK;AGICAGXGA
MGK8`X9Z4X9^)X9ZVX9Z6X9Z\X9Z)X9Z\X9Z<X9Z@X9^2X9Z"X9ZXX9Z.X9^!
M`.&>E.&?B>&>MN&>FN&?B>&>MN&>H.&?DN&>@N&>MN&>F0#AGI;AGK;AGH#A
MGY+AGIGB@(OAGI_AGICAGY+AGH3AGK;AGH_AGXL`X9Z6X9ZVX9Z`X9^2X9Z9
MXH"+X9Z?X9Z8X9^2X9Z$X9ZVX9Z/X9^+PJ#AGY8`X9Z4X9ZWX9Z1X9Z7X9^2
MX9Z'X9ZVX9Z4X9^+`.&>E>&?DN&>F^&>O.&>G`#AGICAGI/AGKOAGI_AGY+A
MGI\`X9Z7X9ZVX9Z"X9Z:X9Z9`.&>DN&?DN&>G.&>ON*`B^&>E.&?DN&>FN&>
MC^&>M^&>E.&>C^&?DN&>C^&>M^&>@.&>MN&>FN*`B^&>C^&?AN&>H.&?@N&>
MD>&>MN&?AB#AGI;AGX'AGIOB@(OAGH7AGKSAGIL@/P#AGI_AGK?AGI'AGY+A
MGI+AGK<`X9Z?X9ZWX9Z1X9^2X9Z2X9ZW`.&>EN&?D.&>C^&?C.&>F.&>MN&>
MD^*`B^&>E>&?DN&>D>&>MN&>F^&?B^*`B^&>@>&?DN&>F^&>O>&>DP#AGI3A
MGXGAGX'AGIKAGXGAGKP`X9Z@X9^2X9Z<X9ZXX9Z;X9ZXX9Z6X9ZXX9Z3`.&>
MD>&>O.&>FN&>G^&?D.&>EN&?DN&>D0#AGI;AGKCAGH_AGH'AGK;AGIGAGIKA
MGK?AGI,`X9Z7X9ZXX9Z`X9Z?X9^"X9Z;`.&>E.&?B>&>O.&>H>&>O.&>B0#A
MGI;AGY#AGIKAGI'AGKOAGIGAGJ#AGY+AGH+AGK;AGIOAGXL`X9Z?X9Z8X9^2
MX9Z6X9ZVX9Z2`.&>F.&>ON&>F^*`B^&>A^&>MN*`B^*`B^*`B^&>F.&>N^&>
MDP#AGH+AGICAGY+AGIKAGX3AGH0`X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9Z?X9ZV
MX9Z2X9ZVX9Z:X9Z.X9^(`.&>EN&?D.&>FN&>C^&>O.&>FN&>N.&>@.&>O`#A
MGH#AGK;AGH_AGK8`X9Z?X9^&X9Z.X9Z]X9Z:XH"+`.&>@.&>O.&>C^&>M@#A
MGJ+AGK;AGI,`X9Z2X9^2X9Z<X9Z^XH"+X9ZRX9^2X9Z9XH"+X9Z?X9^2X9Z:
MX9Z?X9^+`.&>HN&>C^&?DN&>FN&>MN*`B^&>DN&?DN&>G.&>ON*`B^&>LN&?
MDN&>F>*`B^&>G^&?DN&>FN&>G^&?B\*@X9^6`.&>E>&?DN&>D>&>N^&>@.*`
MB^&>H>&>ON&>A.*`B^&>G.&>M^&>B0#AGH#AGX;AGH[AGH_AGXOB@(OAGI_A
MGICAGY+AGH+AGK;AGIOAGXL`X9Z9X9Z`XH"+X9Z%X9^!X9Z)`.&>@.&?AN&>
MCN&>C^&?B^*`B^&>H>&>ON&>A.*`B^&>G.&>M^&>B0#AGIOAGI'AGY+AGI+B
M@(OAGI7AGIL`X9Z/X9^2X9Z:X9ZAX9Z4X9^+XH"+X9Z1X9^%XH"+X9Z'X9Z8
MX9^2X9Z:X9Z^X9Z?`.&>FN&>N.&>HN&>N^&>F>&>D^&>N.&>F>&?B>&>N^&>
MA`#B@(OAGI_AGY+AGH_AGK;AGX8`X9Z/X9Z]X9Z3X9ZVX9Z1X9ZX`.&>FN&>
MO.&>F.&?B>&>MN&>D^&>N`#AGI3AGH3AGY+AGISAGK?AGIOB@(OAGI'AGX7B
M@(OAGH;AGY+AGISAGX'AGH0`X9Z4X9Z$X9^2X9Z<X9ZWX9Z;XH"+X9Z1X9^%
MXH"+X9Z?X9^2X9Z*X9ZVX9^&`.&>A^&>O>&>FN*`B^&>BN&?@>&>@,*@X9^6
M`.&>FN&>C^&?B^*`BP#AGI_AGJ#AGI;AGY#AGI/AGY+AGI+B@(OAGIKAGKOA
MGI_AGY+AGI_AGXKAGK@`X9Z:X9Z<X9^)X9ZVX9Z3X9^+X9Z*X9ZV`%-32`#A
MGI_AGH3AGXOB@(OAGJ#AGX'AGJ'AGX'AGH[AGK8`X9Z?X9Z$X9^+X9Z#X9ZX
MX9Z/(.&>D^&>M^&>A"#AGI/AGX'AGISAGKCAGI\`X9Z?X9Z$X9^+X9Z;X9Z\
MX9Z?X9^*X9ZXX9Z9X9^)X9ZV`.&>G^&>A.&?B^*`B^&>EN&?DN&>F>&?@N&>
MFB#AGI/AGK?AGH0@X9Z8X9ZXX9Z"X9Z[X9Z9X9ZBX9^!X9ZAX9Z[X9Z$`.&>
MG^&>A.&?B^&>G.&>MN&?AN&>A.&>G^&>A.&?BR#AGI/AGK?AGH0@XH"+X9Z@
MX9^2X9Z"X9^2X9Z:X9ZXX9Z.X9ZVX9Z,X9ZXX9Z3`.&>G^&>MN&>F.&>O.&>
MHN&>M@#AGI_AGK;AGI/AGXOAGICAGXGAGK;AGIKAGKCAGH[AGKP`4V%O(%1O
M;64@86YD(%!R:6YC:7!E`.&>HN&>MN&>FN&?B>&>MN&>E.&?B^*`B^&>E.&?
MBN&>N.&>G^&>MN&>HN&>O.&>C.&>N`#AGIKAGH#AGY+AGI_AGK;B@(OB@(OA
MGI'AGKOAGH#B@(OB@(L`X9Z:X9Z`X9^2X9Z?X9ZVXH"+X9Z1X9Z[X9Z`XH"+
M(.&>A^&>F.&?DN&>FN&>ON&>GP#AGI_AGY+AGISAGX+AGH3AGIKAGH``X9Z8
MX9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z?X9^2X9Z<X9^"X9Z$X9Z:X9Z``.&>
MA^&?DN&>FN&>ON&>G^*`B^&>@.&>MN&>F^&>E.&>FN&>M^&>A>&?DN&>AN&?
M@>&>D0#AGH?AGY+AGIKAGK[AGI_B@(OAGI'AGK;AGX;AGH3AGJ+AGI_AGXL`
MX9Z'X9^2X9Z:X9Z^X9Z?XH"+X9Z"X9^2X9Z8X9ZVX9Z3`.&>G^&?@>&>CN&?
M@>&>H.&?DN&>@N&>MN&>F^&?BP#AGH#AGHGAGY+AGHGAGK8`X9Z?X9^"X9Z4
MX9^*X9ZX(.&>D^&>M^&>A"#AGICAGXGAGKOAGH3AGH_AGX'AGH[AGX'AGJ#A
MGY+AGH#AGY+AGIKAGKP`X9Z;X9^!X9Z!XH"+X9Z?X9Z8X9^2X9Z"X9ZVX9Z;
MX9^+`.&>G^&>F.&?D.&>F0#AGH#AGX;AGH[AGH_AGXL`X9Z*X9^&X9ZAX9Z^
MX9Z$`.&>G^&>N.&>G^&?DN&>H.&?@N&>FP#AGI3AGH3AGY+AGJ#AGK;AGHD`
MX9Z4X9Z$X9^2X9Z:X9Z]X9Z)`.&>G^&?@>&>FN&?B>&>MN&>H>&?@>&>HN&>
MO.&>DP#AGJ#AGH_AGY+AGI#AGIOAGX'AGH'AGK8`X9Z?X9ZYX9Z$X9^2X9Z@
MX9Z4X9Z[X9Z:X9ZX`.&>D>&?AN&>H.&?A@#AGI_AGY+AGIOAGKSAGISAGXGA
MGK;AGH+AGK@`X9Z?X9^2X9Z;X9Z\X9Z<X9^)X9ZVX9Z3X9ZX`.&>@.&?A.&?
MA^*`B^&>G^&>O.&>H>&>O.&>F.&?B>&>O.&>DP#AGI_AGKSAGICAGXGAGK;A
MGIOAGK@`X9ZBX9ZVX9Z@X9^2X9Z:X9ZWX9Z`XH"+XH"+X9Z!X9ZVX9Z$XH"+
MX9Z/X9^2X9Z4X9Z\X9Z$`.&>H.&?DN&>G^&>@.&>H.&?DN&>G^&?BN&>N.*`
MB^&>@>&>MN&>A.*`B^&>C^&?DN&>E.&>O.&>A"#AGI/AGK?AGH0@X9Z`X9^$
MX9^'X9Z?X9ZVX9^&X9Z$X9Z<X9ZWX9Z%XH"+X9Z!X9ZVX9Z$XH"+X9Z/X9^2
MX9Z4X9Z\X9Z$`.&>@N&>F.&?DN&>F^&>MN&>CP#AGJ+AGX'AGI_AGXGAGY+A
MGI3AGK;AGHD`X9Z?X9ZVX9Z:XH"+X9ZEX9Z/XH"+X9Z4X9ZVX9Z3XH"+X9Z`
MX9ZVX9Z:`.&>G^&?DN&>FN&>N.&>F^&>A.&?DN&>@.&>M@#AGH'AGY+AGI/A
MGK;AGH_B@(OAGH+AGX;AGIKAGKP`X9Z?X9^2X9Z0X9ZVX9Z3X9Z7X9ZVX9Z6
M`.&>E.&>D^&?DN&>D>&>MN&>C^&?B^*`B^&>AN&>O.&>CP#AGI3AGY+AGIKA
MGI+AGK;AGI/B@(OAGI3AGI$`X9Z*X9ZVX9Z`X9^+XH"+X9Z?X9^2X9Z3X9Z^
M`.&>HN&>@.&?DN&>G^&>FN*`B^&>C^&>O.&>A>*`B^&>@.&?DN&>FN&?A.&>
MF`#AGH?AGX3AGH+AGH?AGY#AGID`X9Z?X9^*X9Z\X9Z*X9Z$X9^+`.&>G^&>
MA.&?DN&>@>&?@>&>E`#AGJ+AGH#AGY+AGI_AGIKB@(OAGH_AGKSAGH7B@(OA
MGIOAGKX`X9Z"X9ZVX9^&X9Z1X9^2X9Z:`.&>G^&?BN&>O.&>FN&>N.&>CN&>
MMN&>F.&>N`#AGI_AGY+AGISAGK;AGIOAGXOAGI3AGK;AGH\@X9Z3X9ZWX9Z$
M(.&>H.&?DN&>G^&>A.&?B^&>F.&?B>&>MN&>F>&?@>&>DP#AGI_AGY+AGISA
MGK;AGJ#AGY+AGI_AGXKAGKCAGJ'AGH3AGXL`X9Z?X9^*X9Z[X9Z9X9ZBX9^"
MX9Z*`.&>G^&?DN&>G.&?BN&>N.&>GP#AGI_AGK;AGI+AGK;AGIKAGH[AGIKA
MGHKAGY+AGHOB@(OAGJ+AGK;AGIKAGXGAGK;AGI3AGXL@X9Z?X9^*X9ZXX9Z:
MX9ZX`.&>C^&>MN&>FN&>MN&>A`#AGIOAGH#AGY+AGH'AGH[AGXCB@(OAGI_A
MGICAGY+AGI3AGH_AGY+AGH_AGK?B@(OAGH_AGK;AGIKAGK;AGH0`X9Z;X9Z`
MX9^2X9Z!X9Z.X9^(XH"+X9Z?X9Z8X9^2X9Z4X9Z/X9^2X9Z/X9ZWXH"+X9Z:
MX9Z4X9Z?X9^+XH"+XH"+X9Z/X9ZVX9Z:X9ZVX9Z$`.&>C^&?@^&>G.&?B>&>
MMN&>D^&?BP#AGH_AGK;AGHKAGJ#AGY+AGI_AGXKAGKCAGH+AGKCAGI_AGY+A
MGH_AGH3AGXL`X9Z7X9ZVX9Z:X9Z`X9ZWX9Z%X9^2X9Z%`.&>F^&?@>&>@>*`
MB^&>D>&>O.&>FN&>G^&?D.&>EN&?DN&>D0#AGI_AGKCAGH_AGKOAGH[AGY+A
MGJ#AGI?AGK;AGI8`X9ZBX9Z/X9^2X9Z0X9Z4X9Z1`.&>C^&?@N&>HN&>C^&?
MDN&>D.&>E.&>D0#AGI#AGX,`X9Z8X9ZVX9Z3XH"+X9Z`X9^&X9Z@X9Z[X9Z?
MXH"+X9Z8X9Z]X9Z9(.&>@.&?DN&>D^&>N^&>A.*`B^&>@.&>MN&>FN*`B^&>
ME.&>A.&?DN&>H.&>MN&>B>*`B^&>E>&?DN&>D^&?@N&>@.*`B^&>FN&>E.&>
MG^&?B^*`B^&>G^&>MN&>FN*`B^&>D^&?@>&?AP#AGI;AGX'AGIOB@(OAGISA
MGX'AGIOAGK;B@(L`X9Z1X9^2X9Z:X9Z$X9^+XH"+X9Z1X9^2X9Z:X9ZVX9Z9
MXH"+XH"+XH"+XH"+X9Z6X9^!X9Z;XH"+XH"+X9Z<X9^!X9Z;X9ZVXH"+`.&>
MA>&?AN&>CN&>A.*`B^&>A^&>ON&>A`#AGI'AGX4`X9Z0X9^2X9Z$X9^#XH"+
MX9Z3X9^!X9^'`.&>C^&>O.&>H.&?DN&>@N&?A`#AGH_AGKSAGH#AGX'AGJ'A
MGK;AGJ+AGXKAGKP`X9Z/X9Z[X9Z$X9Z@X9^2X9Z"X9^$`.&>@.&?AN&>EN&>
MO.&>FP#AGI'AGY+AGIKAGKCAGI/AGKCAGHKAGK;AGHH@X9Z3X9ZWX9Z$XH"+
MXH"+(.&>C^&>O.&>E.&>MN&>H.&?DN&>@N&?A`#AGI'AGKOAGIGAGH[AGX'A
MGI_AGXKAGK@`X9Z1X9Z]X9Z:X9Z"X9ZX`.&>D>&>O>&>FN&>@N&>N"`H25-/
M+3@X-3DM.2D`X9Z1X9Z]X9Z"X9Z8X9^!X9Z3X9ZXX9Z?X9^2X9Z/X9Z$X9^+
M`.&>@.&?A.&?A^*`B^&>D>&>O>&>@"#AGI/AGK?AGH3B@(L@X9Z`X9^#X9Z`
MX9Z\X9Z?`.&>D>&>N^&>F>&>G.&?B>&>MN&>F^&>N^&>F0!54DP`55),.@#A
MGJ+AGXKAGKSAGJ#AGY+AGH+AGH3AGXOAGHKAGK8`X9ZBX9^*X9Z[X9Z9X9Z`
MX9^2X9Z:X9^"X9Z3`.&>@N&>O.&>G^*`B^&>E.&>D^&?DN&>D>&>MN&>C^&?
MB^*`B^&>@.&?DN&>FN&?A.&>F`#AGICAGK?AGI/B@(OAGI3AGK;AGI/B@(OA
MGIKAGX#AGI3AGH7AGX8`X9Z9X9Z\X9Z3X9ZXX9Z`X9Z\X9Z*("A55$8M."D`
MX9ZBX9ZVX9Z:X9^)X9ZVX9Z4X9^+XH"+X9Z:X9Z]X9Z8`.&>A>&>@.&?DN&>
MFN*`B^&>E^&>EN*`B^&>HN&>A.&?B^&>@N&?DN&>F^&?@>&>GP#AGI_AGJ#A
MGIKAGHKAGY+AGHOAGJ+AGK;AGICAGX'AGIKAGK?AGH``X9Z`X9^$X9^'XH"+
MX9Z&X9^2X9Z$X9ZVX9Z9X9^7XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9Z@X9Z:
MX9Z*X9^2X9Z+XH"+X9ZBX9ZVX9Z8X9^!X9Z:X9ZWX9Z``.&>K^&>@.&>C^&>
MM@#AGICAGK?AGI/B@(OAGI_AGY+AGH+AGK;AGIOAGXL`X9Z"X9^2X9Z8X9ZV
MX9Z3XH"+X9Z(X9^2X9Z8X9^$X9^'`.&>DN&?DN&>G.&>ON*`B^&>LN&?DN&>
MF>*`B^&>D>&>MN&>D^&?B^*`B^&>G^&>F.&?D.&>F0#AGI7AGY+AGI'AGKOA
MGH#B@(OAGJ'AGK[AGH0`X9ZBX9^*X9Z[X9Z9X9Z:X9^)X9ZVX9Z@X9^2X9Z"
MX9ZVX9Z9`.&>HN&?DN&>D^&>@.*`B^&>E.&?DN&>FN&>O@#AGH#AGK;AGIKB
M@(OAGH+AGY+AGIKAGI3AGXOAGH+AGY+AGIKAGH3B@(OAGJ+AGY+AGI/AGH#B
M@(OAGI3AGY+AGIKAGKX`X9Z(X9^2X9Z8X9^$X9^'XH"+X9ZBX9^2X9Z3X9Z`
MXH"+X9Z4X9^2X9Z:X9Z^`.&>B.&?DN&>F.&?A.&?A^*`B^&>HN&?DN&>D^&>
M@.*`B^&>E.&?DN&>FN&>OL*@X9^6`.&>HN&?BN&>O.&>H.&?DN&>G^&>E.&?
M@>&>@N&>N.&>G^&?DN&>C^&>A.&?BP#AGI_AGKOAGI;AGIOAGI?AGK;AGI8`
MX9Z/X9Z8X9^2X9Z;X9^#`.&>G.&?B>&>MN&>D^&>N^&>F>&>HN&>MN&>D>&>
MN^&>F0#AGJ+AGI#AGX'AGIH`X9Z<X9^!X9Z.X9^!X9Z@X9^2X9Z?X9Z[X9Z9
MX9ZBX9^!X9ZAX9ZV`.&>@.&?AN&>CN&?@@#AGH#AGK;AGIKB@(OAGH_AGY+A
MGIKAGKWAGH_B@(OAGI;AGK?AGI/AGK?AGH_AGY+AGIGB@(OAGH#AGX;AGH[A
MGX(`X9Z8X9Z^X9Z;("5S`.&>@.&?A.&?A^*`B^&>G.&>N.&>A^&>N.&>DR#A
MGI_AGJ#AGIKAGHKAGY+AGHOB@(OAGJ+AGK;AGICAGX'AGIKAGK?AGH``X9Z<
MX9^)X9ZVX9Z;X9ZXX9Z?(.&>D^&>M^&>A"#AGJ#AGY+AGISAGXKAGKSB@(OA
MGI'AGKOAGIGAGH[AGK8`X9Z6X9^2X9Z:X9Z8X9ZVX9Z3`.&>G.&>M^&>E`#A
MGH_AGX;AGI3AGI/AGXOAGI3AGH[AGY+AGH_AGK;AGHD`X9Z:X9ZVX9Z;X9^+
MXH"+X9Z?X9Z4X9^2X9Z*X9ZVX9Z@X9^-`.&>G^&>O.&>F.*`B^&>G^&?DN&>
MG.&>MN&>@N&>F.&>D^&?C0#AGI_AGKSAGICB@(OAGI_AGY+AGISAGK;AGH+A
MGICAGI/AGXWB@(OAGICAGH#B@(OAGH#AGK;AGI/AGXL@)7,`X9Z?X9ZVX9Z@
MX9ZVX9Z:X9^)X9ZVXH"+X9Z!X9ZVX9Z$XH"+X9Z;X9ZWX9Z%`.&>D>&>D>&>
MN>&>A.*`BP#AGI'AGI'AGKGAGH0@X9^6`.&>E.&>B>&?DN&>A^&>N.*`B^&>
ME.&?DN&>FN&>MN&>D.&?DN&>D^&>M@#AGJ+AGK;AGI_AGIGAGHKAGY+AGHOA
MGK;AGI/B@(OAGH#AGI/AGY+AGIOAGX+AGH3B@(OAGI+AGY+AGISAGK[B@(OA
MGH#AGK;AGIH`X9Z1X9Z\X9Z:X9Z?X9^0X9Z6X9^2X9Z1XH"+XH"+XH"+X9Z`
MX9Z3X9^2X9Z;X9^"X9Z$XH"+XH"+XH"+X9Z2X9^2X9Z<X9Z^X9Z`X9ZVX9Z:
M`%E9`%E965D`X9Z4X9^2X9Z:X9Z%X9ZVX9^&X9Z&X9^2X9Z3X9ZVX9^&`.&>
MF>&?@>&>F.&?@N&>DP#AGI3AGK;AGI$OX9Z%X9ZVX9Z?`.&>B.&?DN&>F.&?
MA.&?A^*`B^&>FN&>E.&>G^&?B^&>HN&?DN&>D^&>@`#AGIGAGKSAGJ#AGY+A
MGH+AGX3AGI_AGY+AGIOAGK;AGISAGK@`X9Z?X9^#`.&>H.&?DN&>G^&>MN&?
MAN&>E.&?BN&>N`#AGJ#AGY+AGI_AGXKAGKCAGICAGI3AGK;AGISAGXGAGX$`
M7TSAGH7AGX'AGHD@`.&>F.&>M^&>D^*`B^&>G^&?DN&>@N&>MN&>F^&?B^*`
MB^&>HN&?DN&>D^&>@.*`B^&>D>&>D>&>O>&>F^*`B^&>G^&?AN&>E.&>N^&>
MC^&?DN&>F@#AGICAGK?AGI/B@(OAGJ+AGK;AGH7B@(OAGI3AGH3AGY+AGH#A
MGK[AGH_B@(OAGJ_AGH#AGI_AGK;AGIKB@(OAGIOAGI'AGY+AGI+AGI7AGIL`
MX9Z8X9ZWX9Z3XH"+X9ZBX9ZVX9Z%XH"+X9Z4X9Z^X9Z`XH"+X9Z6X9^0X9Z/
MX9^,X9Z8X9ZVX9Z3XH"+X9Z4X9Z)X9^2X9Z%X9Z\X9Z;`.&>@.&?AN&>H.&>
MN^&>G^*`B^&>@.&>MN&>FN*`B^&>E.&?DN&>FN&>ON*`B^&>E.&>D^&?DN&>
MD>&>MN&>C^&?B^*`B^&>EN&>MN&>@.&?DN&>F>&>E.&>B>&?DN&>A^&>M@#A
MGH#AGX;AGJ#AGKOAGI_B@(OAGH#AGK;AGIKB@(OAGH#AGX;AGH[AGH_AGXOB
M@(OAGIKAGH7AGI/AGK;AGI_AGICAGY+AGI;AGY#AGI/AGY+AGI(`X9Z4X9ZV
MX9Z/X9^+XH"+X9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z4X9^2X9Z:X9Z6X9^0X9Z3
MX9^2X9Z2XH"+X9Z?X9^&X9Z!X9ZVX9Z3X9^+XH"+X9Z4X9^&X9Z5X9Z[X9Z/
M`.&>@.&?AN&>H.&>N^&>G^*`B^&>D>&?DN&>FN&>A.&?B^&>D>&?DN&>FN&>
MMN&>F>*`B^&>D>&>M^&>D^&?DN&>D^&>D^&?D.&>F0#AGIKAGH#B@(OAGICA
MGK?AGI/B@(OAGH/AGK[AGHGB@(OAGI+AGK;AGH_AGKOB@(OAGI3AGHGAGY+A
MGH7AGKSAGIL`:&@`X9Z8X9ZWX9Z3XH"+X9Z?X9^2X9Z"X9ZVX9Z;X9^+XH"+
MX9Z(X9^2X9Z8X9^$X9^'XH"+X9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3`.&>@.&?
MAN&>H.&>N^&>G^*`B^&>E.&>B>&?DN&>A>&?@>&>B2_AGI3AGHGAGY+AGH7A
MGKSAGIL`X9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z`X9Z8X9^2X9Z8X9Z<X9ZWX9Z2
MX9ZXXH"+X9Z!X9ZVX9Z$XH"+X9Z`X9^2X9Z:X9^%`.&>F"[AGI@N`.&>B.&?
MDN&>F.&?A.&?AP#AGI_AGK?AGI'AGY+AGI+AGK?B@(OAGH_AGY+AGIKAGKSA
MGISB@(OAGI3AGK;AGI/B@(OAGI3AGHKAGK?AGI_AGX'AGI(`X9Z7X9ZXX9Z`
MX9Z?X9^"X9Z;`.&>@.&?AN&>H.&>N^&>G^*`B^&>EN&>N.*`B^&>A>&>F.&?
MDN&>A.&>MN&>F>*`B^&>@.&?DN&>D^&>N^&>A.*`B^&>EN&>M^&>DN&>N.&>
M@.&>MN&>F@#AGICAGK?AGI/B@(OAGJ+AGK;AGH7B@(OAGIKAGH#B@(OAGI_A
MGX'AGISAGK;B@(OAGI3AGK;AGI,`<W,`X9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z4
MX9^2X9Z:X9Z6X9^0X9Z3X9^2X9Z2`.&>E.&>FN&>MN&>A^&?D.&>F>*`B^&>
ME.&>CN&?DN&>BN&?A.&?A^&>HN&>MN&>G^&>D^&?DN&>DP#AGICAGK?AGI/B
M@(OAGI_AGY+AGH+AGK;AGIOAGXOB@(OAGH#AGX;AGJ#AGKOAGI\`X9Z"X9^2
MX9Z8X9ZVX9Z3XH"+X9Z(X9^2X9Z8X9^$X9^'`'9#87)D````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VMO
M7TM2+P``````````````````````````````````````````````````````
M```````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#4Q-30S,S<U,P`P,C`Q,C(`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L;V-A;&4O:V]?2U(O:&5L<"YX;6P`````````````````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,S(P`#$P-3$U-#,S-S4S`#`R,34W
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L
M92]K;U]+4B]H96QP+GAM;"QV(#$N,B`R,#`T+S`U+S(W(#(P.C(R.C$T(&IA
M;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)S=6UM87)Y(B!S=&%T
M93TB;F5W(CX*/'1I=&QE/E1H92!0;W)T86P@4&%G93PO=&ET;&4^"B`\<&%R
M83X*("!4:&ES('!O<G1A;"!P86=E('!R;W9I9&5S(&$@<75I8VL@<W5M;6%R
M>2!O9B!A;&P@>6]U<B!I;7!O<G1A;G0*("!I;F9O<FUA=&EO;BX@1F]R(&5X
M86UP;&4L(&ET(&UI9VAT('-H;W<@:&]W(&UA;GD@;F5W(&4M;6%I;"!M97-S
M86=E<R!Y;W4*("!H879E(&EN('EO=7(@24Y"3U@L('5P8V]M:6YG(&5V96YT
M<R!O;B!Y;W5R(&-A;&5N9&%R+"!T87-K<R!O;B!Y;W5R('1O+61O"B`@;&ES
M="P@:&5A9&QI;F5S(&9R;VT@<V5L96-T960@;F5W<R!S97)V:6-E<RP@86YD
M('-O(&]N+B`@36%N>2!O9B!T:&5S90H@('-U;6UA<FEE<R!W:6QL(&-O;G1A
M:6X@<75I8VL@<VAO<G1C=71S('1O(&-O;6UO;B!F=6YC=&EO;G,L('-U8V@@
M87,*("!C;VUP;W-I;F<@82!N97<@;6%I;"!M97-S86=E+"!C<F5A=&EN9R!A
M(&YE=R!C86QE;F1A<B!E=F5N="!O<B!T87-K+"!E=&,N"B`\+W!A<F$^"B`\
M<&%R83X*("!4:&4@8V]N=&5N=',@;V8@=&AI<R!P;W)T86P@<&%G92!A<F4@
M8W5S=&]M:7IA8FQE('9I82!T:&4@3&%Y;W5T(&)U='1O;BX*("!&;W(@97AA
M;7!L92P@>6]U(&-A;B!C:&]O<V4@=VAI8V@@:71E;7,@=&\@:6YC;'5D92!O
M;B!T:&ES('!O<G1A;"!P86=E(&%S"B`@=V5L;"!A<R!I;B!W:&EC:"!O<F1E
M<B!T:&5Y(&%R92!S:&]W;BX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@
M:60](FYA=F)A<B(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@07!P;&EC871I
M;VX@3F%V:6=A=&EO;B!"87(\+W1I=&QE/@H@/'!A<F$^"B`@070@=&AE(&QE
M9G0@:&%N9"!S:61E(&]F('1H92!W96(@<&%G92!I<R!T:&4@87!P;&EC871I
M;VX@;F%V:6=A=&EO;B!B87(N"B`@0VQI8VL@;VX@=&AE(&EC;VYS(&]N('1H
M:7,@;F%V:6=A=&EO;B!B87(@=&\@<75I8VML>2!A;F0@96%S:6QY('-W:71C
M:`H@(&)E='=E96X@=&AE(&%V86EL86)L92!A<'!L:6-A=&EO;G,N"B`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC
M92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT
M96YA;F-E.B!$;R!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@
M($EF('EO=2!W;W5L9"!L:6ME('1O('!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!O;B!L;V=I;BP@8VAE8VL@=&AI<R!B;W@N"B`@("`\+W!A<F$^
M"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC;VYF:7)M7VUA:6YT96YA
M;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I
M;G1E;F%N8V4Z($-O;F9I<FT@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A
M<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!C;VYF:7)M(&%L;"!M86EN
M=&5N86YC92!T87-K<R!B969O<F4@=&AE>2!A<F4@<G5N+"!C:&5C:R!T:&ES
M(&)O>"X@268@;&5F="!U;F-H96-K960L(&%L;"!M86EN=&5N86YC92!O<&5R
M871I;VYS('1H870@;F5E9"!T;R!B92!R=6X@=VEL;"!B92!P97)F;W)M960@
M875T;VUA=&EC86QL>2!W:71H(&YO(&-H86YC92!T;R!C86YC96P@;VX@;&]G
M:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&]C86QE+VMO7TM2+TQ#7TU%4U-!1T53+P``````````````````````
M```````````````````````````````````````````P,#`P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U,P`P,C$W,#<`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O:V]?2U(O3$-?34534T%'15,O
M:&]R9&4N;6\`````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#4Q,#4U`#$P-3$U
M-#,S-S4S`#`R,S,U,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#>$@25`````(L!```<````=`P``!T"``#,&````````$`A
M```/````02$```@```!1(0``"P```%HA```,````9B$``"@```!S(0``$@``
M`)PA```(````KR$```4```"X(0``$0```+XA```#````T"$```\```#4(0``
M"````.0A```(````[2$``!D```#V(0``!P```!`B```,````&"(```X````E
M(@``!0```#0B```%````.B(```H```!`(@```P```$LB```.````3R(```\`
M``!>(@``'P```&XB```%````CB(``#D```"4(@``!@```,XB```1````U2(`
M``H```#G(@``$````/(B```(`````R,```0````,(P``!@```!$C```1````
M&",```<````J(P``!````#(C```&````-R,```T````^(P``$P```$PC```(
M````8",```8```!I(P``%0```'`C```'````AB,```H```".(P``#P```)DC
M```-````J2,```\```"W(P``#0```,<C```)````U2,```8```#?(P``!@``
M`.8C```.````[2,```4```#\(P``*@````(D```3````+20```P```!!)```
M$````$XD```1````7R0```4```!Q)```!0```'<D```&````?20```<```"$
M)```$````(PD```$````G20```X```"B)```*0```+$D```&````VR0```T`
M``#B)```#@```/`D```-````_R0```,````-)0``#0```!$E```"````'R4`
M``4````B)0``!````"@E```.````+24```@````\)0``#P```$4E```/````
M524```<```!E)0``$````&TE```&````?B4```L```"%)0``#0```)$E```*
M````GR4``!D```"J)0``%@```,0E```4````VR4```L```#P)0``+P```/PE
M```)````+"8```\````V)@``)@```$8F``!#````;28```@```"Q)@``"P``
M`+HF```$````QB8``!<```#+)@``$0```.,F```*````]28```(`````)P``
M!0````,G```)````"2<```T````3)P``#@```"$G```8````,"<```4```!)
M)P``$````$\G```0````8"<```\```!Q)P``"P```($G```/````C2<```P`
M``"=)P``#P```*HG```.````NB<```@```#))P``'@```-(G```A````\2<`
M``,````3*```"````!<H```,````("@```<````M*```"@```#4H```&````
M0"@```0```!'*```!P```$PH```"````5"@```8```!7*```!````%XH```1
M````8R@``"(```!U*```#````)@H```*````I2@```4```"P*```#P```+8H
M```2````QB@```L```#9*```*0```.4H```D````#RD``"8````T*0``$@``
M`%LI```*````;BD```\```!Y*0``$````(DI```.````FBD```D```"I*0``
M"@```+,I```2````OBD``!````#1*0``$0```.(I```/````]"D``!0````$
M*@``#````!DJ```,````)BH```\````S*@``%0```$,J```I````62H``"H`
M``"#*@``)@```*XJ```G````U2H``"D```#]*@``*@```"<K```1````4BL`
M`!(```!D*P``$P```'<K```4````BRL``!8```"@*P``%P```+<K```0````
MSRL``!$```#@*P``$P```/(K```2````!BP```8````9+```!P```"`L```%
M````*"P``!8````N+```!````$4L```$````2BP```<```!/+```#@```%<L
M```,````9BP```P```!S+```#0```(`L```2````CBP```\```"A+```"```
M`+$L```.````NBP``!8```#)+```$0```.`L```&````\BP```0```#Y+```
M$````/XL```:````#RT```8````J+0``!P```#$M```+````.2T``!,```!%
M+0``$P```%DM```3````;2T```(```"!+0``!````(0M```-````B2T```4`
M``"7+0``!@```)TM```/````I"T```,```"T+0``"@```+@M```+````PRT`
M``<```#/+0``!@```-<M```*````WBT```<```#I+0``"0```/$M```'````
M^RT```0````#+@``!P````@N```%````$"X``!,````6+@``!````"HN```"
M````+RX``#,````R+@``,P```&8N```X````FBX```0```#3+@``!0```-@N
M```(````WBX``!$```#G+@``#@```/DN```'````""\``!\````0+P``!P``
M`#`O```.````."\```P```!'+P``#````%0O```%````82\``!$```!G+P``
M!P```'DO```(````@2\``!4```"*+P``!0```*`O```4````IB\```0```"[
M+P``!P```,`O```>````R"\``!0```#G+P``!0```/PO```&`````C```"@`
M```),```*0```#(P```'````7#```"$```!D,```#@```(8P```3````E3``
M`!<```"I,```"P```,$P```%````S3```!$```#3,```!0```.4P```2````
MZS````0```#^,```#@````,Q```.````$C$```4````A,0``$@```"<Q```$
M````.C$```P````_,0``!@```$PQ``!I````4S$``!H```"],0``%P```-@Q
M```7````\#$``!L````(,@``'P```"0R```3````1#(```D```!8,@``)0``
M`&(R```@````B#(``"0```"I,@``(````,XR```$````[S(``!````#T,@``
M'`````4S```H````(C,```<```!+,P``$P```%,S```7````9S,```H```!_
M,P``#````(HS```)````ES,```T```"A,P``"P```*\S```'````NS,```8`
M``##,P``"0```,HS```'````U#,```<```#<,P``"P```.0S```0````\#,`
M`!`````!-```!0```!(T```$````&#0```D````=-```"@```"<T```?````
M,C0``!L```!2-```/@```&XT```C````K30``!\```#1-```/0```/$T```A
M````+S4``!P```!1-0``!0```&XU```0````=#4```(```"%-0``$@```(@U
M```#````FS4``!````"?-0```P```+`U```O````M#4``"````#D-0``)```
M``4V```E````*C8``"````!0-@``)@```'$V```)````F#8```P```"B-@``
M%P```*\V```.````QS8```T```#6-@``&@```.0V```'````_S8```L````'
M-P``$P```!,W```3````)S<```P````[-P``"````$@W```4````43<```X`
M``!F-P``$````'4W```'````AC<```<```".-P``!@```)8W```'````G3<`
M``T```"E-P``"P```+,W```@````OS<``!P```#@-P``!0```/TW```2````
M`S@```H````6.```!@```"$X```,````*#@```H````U.````@```$`X```&
M````0S@```,```!*.```10```$XX```9````E#@``$4```"N.```,````/0X
M```F````)3D``"4```!,.0``,````'(Y```2````HSD``!,```"V.0``$```
M`,HY```)````VSD``',```#E.0``*P```%DZ```7````A3H``!8```"=.@``
M#P```+0Z``!`````Q#H``!\````%.P``$@```"4[```0````.#L``!,```!)
M.P``'0```%T[```/````>SL```\```"+.P``"P```)L[```%````ISL``!0`
M``"M.P``"````,([```/````RSL```@```#;.P``#P```.0[```4````]#L`
M``8````)/```!````!`\```'````%3P```8````=/```!P```"0\```%````
M+#P``%(!```R/```#````(4]```'````DCT```<```":/0``!P```*(]```7
M````JCT``!4```#"/0``!P```-@]```)````X#T```L```#J/0``!````/8]
M```3````^ST```\````//@``"P```!\^```4````*SX```0```!`/@``!@``
M`$4^```$````3#X```H```!1/@``!````%P^```%````83X```D```!G/@``
M"````'$^```'````>CX``!<```""/@```P```)H^```7````GCX```,```"V
M/@``#````+H^```$````QSX```D```#,/@``!````-8^```$````VSX```0`
M``#@/@``"0```.4^```$````[SX```0```#T/@``!````/D^```+````_CX`
M``P````*/P``!````!<_```$````'#\``!(````A/P``!````#0_```&````
M.3\```<```!`/P``!P```$@_```'````4#\```<```!8/P``!@```&`_```&
M````9S\```0```!N/P``#@```',_```$````@C\``!4```"'/P``%````)T_
M```'````LC\```T```"Z/P``"P```,@_```$````U#\```,```#9/P``!@``
M`-T_```$````Y#\```D```#I/P``!````/,_```$````^#\``"L```#]/P``
M!@```"E````+````,$````H````\0```"P```$=````&````4T````8```!:
M0````@```&%````$````9$````0```!I0```"0```&Y````$````>$````0`
M``!]0```"````()````$````BT````L```"00```!````)Q````'````H4``
M``<```"I0```!P```+%````,````N4````P```#&0```"0```--````%````
MW4```"H```#C0```"`````Y!```)````%T$``"<````A00``0P```$E!```(
M````C4$```L```"600``!````*)!```,````IT$```X```"T00``!P```,-!
M```"````RT$```8```#.00``"````-5!```)````WD$```L```#H00``#0``
M`/1!```$`````D(```D````'0@``"0```!%"```(````&T(```L````D0@``
M"0```#!"```$````.D(```,````_0@``#0```$-"```&````44(``!,```!8
M0@``$P```&Q"```$````@$(```,```"%0@``"P```(E"```$````E4(```D`
M``":0@``!@```*1"```$````JT(```0```"P0@``!````+5"```$````ND(`
M``8```"_0@``!@```,9"```>````S4(```<```#L0@``"P```/1"```%````
M`$,```8````&0P``"0````U#```%````%T,``!,````=0P``#@```#%#```3
M````0$,```X```!40P``!@```&-#```-````:D,```P```!X0P``#@```(5#
M```(````E$,```D```"=0P``#P```*=#```,````MT,``!````#$0P``"```
M`-5#```0````WD,```D```#O0P``!P```/E#```,`````40```X````.1```
M%P```!U$```7````-40``!<```!-1```%P```&5$```8````?40``!@```"6
M1```#````*]$```,````O$0```P```#)1```#````-9$```.````XT0```X`
M``#R1```#`````%%```,````#D4```X````;10``#@```"I%```(````.44`
M``,```!"10``!````$9%```4````2T4```,```!@10```P```&1%```$````
M:$4```L```!M10``"0```'E%```)````@T4```L```"-10``"````)E%```/
M````HD4```0```"R10``$0```+=%```@````R44``!,```#J10``"````/Y%
M```$````!T8```L````,1@``&P```!A&```&````-$8```@````[1@``#P``
M`$1&```-````5$8```L```!B1@``$````&Y&```"````?T8```0```""1@``
M$````(=&```#````F$8```@```"<1@``#0```*5&```#````LT8```D```"W
M1@``"0```,%&```&````RT8```8```#21@``"````-E&```$````XD8```L`
M``#G1@``"0```/-&```$````_48```@````"1P``"`````M'```-````%$<`
M``0````B1P``!@```"='```C````+D<``!P```!21P``(0```&]'```-````
MD4<```0```"?1P``!````*1'```'````J4<```<```"Q1P``!````+E'```1
M````OD<```@```#01P``"P```-E'```)````Y4<```0```#O1P``!````/1'
M```)````^4<```0````#2```!`````A(```9````#4@```8````G2```$P``
M`"Y(```$````0D@```8```!'2```$P```$Y(```)````8D@```@```!L2```
M!````'5(```A````>D@``!X```"<2```"````+M(```0````Q$@```D```#5
M2```"0```-](```0````Z4@```\```#Z2```"0````I)```1````%$D```8`
M```F20``#````"U)```$````.DD```<````_20``!P```$=)```#````3TD`
M`!(```!320``!````&9)```-````:TD```0```!Y20``.P```'Y)```3````
MNDD```X```#.20``#@```-U)```9````[$D``!\````&2@``&````"9*```#
M````/TH```X```!#2@``#@```%)*```.````84H``!````!P2@``!````(%*
M```-````ADH```8```"42@``&@```)M*```$````MDH```T```"[2@``#@``
M`,E*```'````V$H```<```#@2@``!P```.A*```(````\$H```L```#Y2@``
M!`````5+```$````"DL```@````/2P``!````!A+```$````'4L```8````B
M2P``!P```"E+```'````,4L```0````Y2P``!@```#Y+```$````14L```D`
M``!*2P``&````%1+```>````;4L``"T```",2P``'@```+I+```?````V4L`
M`#\```#Y2P``*0```#E,```8````8TP```0```!\3```#0```(%,```)````
MCTP```X```"93````@```*A,```1````JTP```,```"]3```+0```,%,```>
M````[TP``!L````.30``)````"I-```H````3TT``"$```!X30``!````)I-
M```1````GTT``!````"Q30``!````,)-```$````QTT``!4```#,30``"0``
M`.)-```)````[$T```T```#V30``$`````1.```/````%4X```@````E3@``
M$````"Y.```)````/TX```D```!)3@``!P```%-.```$````6TX```0```!@
M3@``!````&5.```6````:DX```X```"!3@``%P```)!.```7````J$X```0`
M``#`3@``"0```,5.```)````STX```4```#93@``"@```-].```-````ZDX`
M``(```#X3@``!````/M.```"`````$\``#T````#3P``%````$%/```^````
M5D\``"D```"53P``)0```+]/```E````Y4\``"P````+4```#````#A0```*
M````15````0```!04```!0```%50``!S````6U```"<```#/4```#````/=0
M```,````!%$```H````140``'P```!Q1```6````/%$```T```!340``#P``
M`&%1```,````<5$``!,```!^40``#@```))1```&````H5$```D```"H40``
M!@```+)1```.````N5$```H```#(40``#@```--1```*````XE$```T```#M
M40``#````/M1```#````"%(```0````,4@``!@```!%2```$````&%(```D`
M```=4@``!0```"=2```!````]P```&\!````````4P$```````!:````K```
M`!<!```@`````````#\````*````RP```(T```!G````Y````"P!``#=````
M`````&D```"Q````>@```*0`````````^0```(8```!B````6`$``!,!```X
M````````````````````'P$``#,!``#F````^P```+,`````````O```````
M``"C````W@`````````U````/@`````````2`0``@@$``"\```!;`0``1`$`
M`%\```!\`0``C@``````````````W````````````````````'X!``!=````
M````````````````````````````````I@```,@```!:`0``J0```$H```#U
M`````````,P`````````&P```!T!``">````%@````@!``"X````UP````(`
M````````F0```/(````#````TP```-0```#2````=`$``%<```#N``````$`
M`&T!``!'`0``R@```````````````````!`!``#J````BP```.P```!Q````
M)0$``,\`````````!P```"8!````````"````"L```"K````````````````
M````B@```$\!``"4````>`$``!H`````````$@```&T````]`0``5````&8`
M````````3P```#<!``!;````,@$``'T``````````````/P`````````J@``
M``````!5`0``%P```(4```!`````BP$``/H`````````H````%8````8`0``
MF````#P```!+`0``=@```$8```#$`````````#X!````````/0```.(```"`
M````:@$``&4`````````(0$``&4!````````@@```%P!````````[P``````
M``"&`0``00```$H!```4`0``OP```(@```!K`````````-D`````````S@``
M`&0`````````!@```.4```#C````3````$`!``"Y````&@$```````!?`0``
MYP````,!````````:P$``(<!````````2`````````"#````:`$````````[
M`0``'`$``.@```"R````U@```$<``````````````,T```"``0``_P```#H`
M``!^`````````"(`````````0@$``,D`````````40```%D!``"3````````
M`!$```#``````````'<!``!P````_@```+T`````````2`$```````!\````
M`````&D!``!>`0``B0``````````````+````!,``````````````(<```#"
M``````````````!]`0``+P$```0!```*`0``=@$```X!``!_`0```````/0`
M````````40$`````````````1@$``%(``````````````-L```#S````#@``
M`'0```#A`````````#H!``!0`0``Q0```)8`````````8P```.L````S````
M+@```-H````$````9@$`````````````80```",````"`0``H0```'D!``"#
M`0``M````%(!``"V````#````'@`````````&`````````"^````#`$```T!
M``"2````/`$````````/`0```````',```!.````'@$``!P`````````T```
M``````"1````(0````````#I````)````'4```#1````%@$`````````````
ME0`````````N`0``1````",!```P`0``$0$``"D!```4`````````#(`````
M`````````%````"Z````)P```(D!````````G````,<`````````-@$`````
M```T`0```````&P`````````!P$``%D```!>````A`$```$!``"%`0``&0``
M`&X!````````9P$`````````````M0````````!-`0```````'L```"(`0``
M3`$``&(!``!Z`0``7`````T```!.`0```````"T```!7`0```````#0`````
M````#P```'D````;`0````````````"P````%0$````````%````"0````4!
M```K`0``^`````8!````````9`$``#L```!W``````````````!A`0``````
M```````=````NP```&P!```5````20```"H!``"!````?P````````!Q`0``
M;P```*(````_`0````````````!"`````````&,!``!S`0``K@```!``````
M````K0```#8`````````,````"@!````````6````&H```"0````````````
M``#&`````````'`!````````*````%4```#]`````````'(````M`0``)0``
M``D!```G`0``I0````````#!````X```````````````V````"8`````````
MCP```/``````````>P$``)T`````````KP````````"W````=0$````````9
M`0``.0$``"`!```D`0```````#D`````````"P``````````````(@$``*<`
M``"$````F@```&`````>````,0$``(P```!@`0``*@```$,!``!-````20$`
M`%,```##````2P````L!`````````````$,```!6`0``J````#4!````````
MGP```#@!````````;@```/$```!4`0``*0```&@```#5`````````!\````Q
M````-P```)<```!=`0``@0$``'(!````````]@```$$!``#M````FP```$4!
M````````WP```$4```"*`0```"`H06-C97-S:V5Y("5S*0`@*'1O9&%Y*0`@
M*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`)7,@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!A;')E861Y(&5X:7-T<RX`,C0@:&]U
M<G,`04TO4$T`06)O=70@=&AI<R!E9&ET;W(`061D`$%D9"!A(&YE=R!U<V5R
M.@!!9&0@<&%I<@!!9&0@=7-E<@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N
M`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T<F%T:6]N`$%L:6%S`$%L
M:6=N`$%L:6=N;65N=#H`06QL`$%L;"!F;W5R('-I9&5S`$%L=&5R;F%T92!T
M97AT.@!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%P<FEL`$%S
M:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O
M<&5R871I;VYS/P!!=6=U<W0`079A:6QA8FQE(&9I96QD<SH`0F%C:V=R;W5N
M9`!"86-K9W)O=6YD($-O;&]R`$)I<G1H9&%Y`$)O;&0`0F]R9&5R`$)O<F1E
M<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]T:`!";W1T;VT`0G5L;&5T960@3&ES
M=`!#7V5L;"!0<F]P97)T:65S+BXN`$-A;&5N9&%R`$-A;F-E;`!#86YC96P@
M4')O8FQE;2!297!O<G0`0V%P=&EO;@!#96QL(%!H;VYE`$-E;&P@4')O<&5R
M=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I
M;F<Z`$-E;&QP:&]N90!#96YT97(`0VAA;F=E`$-H96-?:R!,:6YK+BXN`$-H
M:6YA`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S
M*0!#;&5A<B!-4T]F9FEC92!T86=S`$-L;W-E(%=I;F1O=P!#;VQL87!S92!3
M:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]R`$-O;',Z`$-O;6EC<P!#
M;VUP86YY`$-O;F9I<FT@4&%S<W=O<F0`0V]P>0!#;W!Y('-E;&5C=&EO;@!#
M;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#<F5A
M=&4`0W)E871E(&$@;&EN:P!#=7)R96YT(%523"!I<P!#=7)R96YT('-T>6QE
M`$-U=`!#=70@<V5L96-T:6]N`$1$`$1A:6QY`$1A=&4`1&5?;&5T92!#;VQU
M;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$
M969A=6QT`$1E9F%U;'0@261E;G1I='D`1&5L971E`$1E;&5T92!C96QL`$1E
M;&5T92!C;VQU;6X`1&5L971E(')O=P!$96QE=&4@=&AE(&-U<G)E;G0@8V]L
M=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5S8W)I8F4@=&AE(%!R;V)L
M96T`1&5S8W)I<'1I;VX`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T
M:&4@861M:6YI<W1R871O<BX`1&ER96-T;W)Y`$1I<W!L87D@3W!T:6]N<P!$
M;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H
M92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@
M8VAE8VL@=&AI<R!B;W@Z`$1O=VYL;V%D`$1O=VYL;V%D("5S`$5D:70`161I
M="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`16QE;65N
M="XN+@!%;0!%;6%I;`!%;6]T:6-O;G,`16UP='D@<F5S=6QT+@!%;FQA<F=E
M($5D:71O<@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`17)R;W(`179E<GD@
M,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%
M=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP
M;&4@=F%L=65S.@!%>'!A;F0@4VED96)A<@!&1R!#;VQO<@!&86EL960@<F5T
M<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!
M4"!S97)V97(N`$9A>`!&96)R=6%R>0!&:6QE($UA;F%G97(`1FEL=&5R<P!&
M;VYT($-O;&]R`$9R86UE<P!&<F]M`$=E<FUA;GD`1V\`2&5I9VAT`$AE;'``
M2&5L<"!U<VEN9R!E9&ET;W(`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H
M92!F:6QE.@!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;W)D90!(;W)I>F]N
M=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!M
M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY
M(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/P!)7VYS97)T(%)O=R!"969O<F4`26-O
M;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!);6%G
M92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!);7!O<G1E9"!F:65L
M9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-R
M96%S92!);F1E;G0`26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E
M`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@
M0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@
M;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N
M90!);G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E
M<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@
M<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R
M86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!C96QL(&%F
M=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN
M<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS
M97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@
M<F]W(&)E9F]R90!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@
M3&EN:P!)=&%L:6,`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M
M2E`I`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@
M1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+;W)E82P@4F5P=6)L
M:6,@;V8`2V]R96%N("A%54,M2U(I`$QA;F=U86=E`$QA<W0@;&]G:6XZ("5S
M`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%Y
M;W5T`$QE9G0`3&ES="!(96QP(%1O<&EC<P!,:7-T:6YG('5S97)S(&ES(&1I
M<V%B;&5D+@!,;V<@:6X`3&]G(&]U=`!,;V=I;B!487-K<P!,;W=E<B!G<F5E
M:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M
M8F5R<P!-30!-86EL`$UA:V4@;&EN7VLN+BX`36%R8V@`36%R9VEN`$UA=&-H
M:6YG(&9I96QD<P!-87D`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E
M`$UI9&1L90!-;V1I9GD@55),`$UO;G1H;'D`36]V92!$;W=N`$UO=F4@57``
M3F%M90!.971W;W)K`$YE=F5R`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5X=`!.
M;P!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO;F4`3F]T97,`3F]V96UB
M97(`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3V-T;V)E<@!/
M<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P=&EO;G,`3W!T:6]N
M<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/=&AE<@!/=&AE
M<B!);F9O<FUA=&EO;@!0861D:6YG`%!A<W-W;W)D`%!A<W-W;W)D<R!M=7-T
M(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E<F-E
M;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<G-O;F%L($EN
M9F]R;6%T:6]N`%!H;VYE`%!I>&5L<P!0;&5A<V4@<')O=FED92!A('-U;6UA
M<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA
M;64@86YD('!A<W-W;W)D`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@
M82!N97<@=VEN9&]W`%!R:6YT(&1O8W5M96YT`%!R;V)L96T@1&5S8W)I<'1I
M;VX`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5M;W9E('!A:7(`4F5S970`
M4F5T=7)N('1O($]P=&EO;G,`4FEG:'0`4F]?=R!0<F]P97)T:65S+BXN`%)O
M;&4`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4V%M92!F
M<F%M92`H7W-E;&8I`%-A=F4`4V%V92!/<'1I;VYS`%-E87)C:`!396QE8W0@
M=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N
M(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E
M>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H
M92!D871E(&9O<FUA=#H`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T
M('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!397!T96UB97(`4VAO=R!T
M:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L
M92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R
M=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`
M4VEZ90!3:VEP($UA:6YT96YA;F-E`%-P86-E(&)E='=E96X@861J86-E;G0@
M8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L
M;`!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!E8VEA;"!#:&%R86-T
M97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-T
M<FEK971H<F]U9V@`4W1Y;&4@6T-34UT`4W5B:F5C=`!3=6)M:70`4W5B<V-R
M:7!T`%-U8V-E<W,`4W5M;6%R>0!3=7!E<G-C<FEP=`!486)L92!0<F]P97)T
M:65S`%1A8FQE('!R;W!E<G1I97,`5&%S:W,`5&5X=`!497AT($]N;'D`5&5X
M="!A;&EG;@!4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92!F
M:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@
M:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@
M:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&5R92!A<F4@;F\@
M;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T
M:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AI<R!N=6UB
M97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@=F%L=64@;75S="!B92!A
M(&YU;6)E<BX`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;V=G;&4@2%1-
M3"!3;W5R8V4`5&]P`%1O<"!F<F%M92`H7W1O<"D`55),`%5N86)L92!T;R!C
M:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T
M;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!L;V%D('1H92!D
M969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D
M:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N
M86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N9&5R;&EN
M90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YI=&5D
M($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FQI;FL@=&AE(&-U<G)E;G0@96QE
M;65N=`!5;FYA;65D`%5N<V5T(&-O;&]R`%5P<&5R(&QA=&EN(&QE='1E<G,`
M57!P97(@<F]M86X@;G5M8F5R<P!5<V5R($]P=&EO;G,`57-E<FYA;64`57-E
M<G,@:6X@=&AE('-Y<W1E;3H`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D
M9&EN9P!6:65W("5S`%=A<FYI;F<`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T
M;R`E<P!796QC;VUE+"`E<P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C
M=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=I9'1H`%=I9'1H
M(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7;W)K($%D9')E<W,`
M5V]R:R!0:&]N90!960!996%R;'D`665S`%EO=2!A<F4@:6X@5$585"!-3T1%
M+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)
M5UE'+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!M=7-T(&1E<V-R
M:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L
M96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@
M;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O
M(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D
M+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A
M9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`
M66]U<B!);F9O<FUA=&EO;@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO
M;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@
M=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@
M<F5A<V]N+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E
M871U<F4N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I
M9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`
M66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!;2&ED92!1=6]T960@
M5&5X=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3
M:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?
M061M:6YI<W1R871I;VX`7T1E;&5T92!2;W<`7TAE;'``7TEM86=E(%!R;W!E
M<G1I97,N+BX`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]2
M96UO=F4@3&EN:RXN+@!?5&%B;&4@4')O<&5R=&EE<RXN+@!L:6YE<UT`;F%M
M90!P97)C96YT`'!I>&5L<P!U;FYA;65D`'9#87)D`%!R;VIE8W0M260M5F5R
M<VEO;CH@2&]R9&4@,RXP+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V
M0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ
M."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#$M,3$M,#D@,38Z
M,CDK,#DP,`I,87-T+51R86YS;&%T;W(Z($II;FAY;VL@2&5O(#QN;W9E;6)R
M94!O=7)N871U<F4N;W)G/@I,86YG=6%G92U496%M.B!I,3AN0&QI<W1S+FAO
M<F1E+F]R9PI-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O
M<&QA:6X[(&-H87)S970]155#+4M2"D-O;G1E;G0M5')A;G-F97(M16YC;V1I
M;F<Z(#AB:70*`"`HM-S#X,6P("5S*0`@*+_`M,,I`"`HL[O`SRD`("B^[L&F
M*0`E<R#`K\'VL/RXKB#`V[[W("T@R*[`S@`B)7,BM,(@P,RYS"#`UKW`M,^T
MV2X`,C0@O<.PHP"_P,#\+[_`R,0`P,P@OZ&U\,7-M,(`P]^PH0"[];?.O^X@
MN^>_Z\#:(,/?L*$Z`,;DONXH<&%I<BD@P]^PH0"[Y[_KP-H@P]^PH0"[Y[_K
MP-H@P]^PH2"[Y[_KOLC'U`#!UKS2`,'6O-*WSP"P_+BN`+[SMO/`S+[NO;H`
MP:2WQ`#!I+?$.@"X\+7.(+RQQ<,`N/"UYR`TN.D`M.O#O""QVP#`W[CXM<@@
MN:[`VK"A(,#6O<"TS[39+@`TO_D`P*_!]K#\N*Z]Q\?@P/P@R*[`SL?/L>(`
M.+_Y`+"AM,G'T2#'RK7E.@"YZ+#F`+GHL.8@N_:Q\@"[_<#/`+&]L-0`L.:P
MZ`"PYK#H(+7.LK(`L.:PZ`"X\+7.`+[&MZ$`L>+(HR"XKKVZQJX`7V6\OR"\
MT[RZ+BXN`+3>M\(`P^N\T@"_P+?Y(+JXL.W'S['B(,/KO-(`Q+B\QP#(WK3K
MQOD`O+\@O-.\N@"\OR#&Y+7Y`+R_(+S3O+H`O+\@L*.PW0#(WK3KQOD`L*&_
M[K6E`+JOL.8`7VNXM<6I(+#+N^<N+BX`P=^QN0"\^+RM(+BNO;K&KB#!OK?Y
M(+RQQ<,`35._P,?'O;H@Q=>QUR#!]K_LL>(`PZ(@M-VQX@"_WL+*N+>TZR"T
MW;'B`,?5P\3!^""PYK#H`+OVL?(`OZTZ`$-O;6EC<P#(N+OG`+[/R*,@R*[`
MS@"ZN;OG`+JYN^<`36%I;G1E;F%N8V5?5&%S:R"X\+7B("5S(+BF(+^M(+SV
M(+[XO<"TS[39+@"XN+7IL>(`N+7%J2"XN+7IL>(`Q_;`YR!54DS`N@#']L#G
M(+VZQ;C`SP#`VKBCL>(`P-JXH['B`$1$`,#/NK``LZ_"I0!?;+^M(+OHP:8`
M,3*_^0"\_<#:`+.[ONZ^LK'B`+'BNKL`L>*ZNR"]Q+JPP-H`N^C!I@"\OR"[
MZ,&F`+^M(+OHP:8`Q^`@N^C!I@#']L#G(+^M(,'VO_(`Q_;`YR#'X"#!]K_R
M`+_`M_D@O+.X[0"\L[CM.@"\O+K.P:2ZN+"A(+#\N*[`VKBF(,"GQ]@@L>*W
MS[7'ON[!L[W`M,^TV2X`M?"WNL7DN*X`R*VXZ2"\L\&D`&UA:6YT96YA;F-E
M+G!H<+^A(,'WP:(@P:*QV<?/P?8@N+:\O+_D+@##N;GXPK`@Q^#`NB#'U[CQ
M(,#,N*?`NR"PKK#M(,#6O<"TS['N/R"QU[>XM-FXZ2P@OZFQXKBF(,.\Q:G'
MS[R\O^0Z`+.[M\&YWK'B`"5S(+.[M\&YWK'B`+SVP:0`)7,@L<?'T2"\]L&D
M`+RQQ<.[Y\?7(+SVP:0Z`+_DO-(N+BX`96T`P,RXWL#/`,#,N/#&O,3<`+#A
ML/H@OOC`O0#&[<']L>(@R*ZTZP"QU[BR(%523"#`U+?"`+_`M_D`,36ZT""X
MMK39`#,PP\H@N+:TV0`UNM`@N+:TV0"X\+7G(+?.L=?`S@`S,+K0(+BVM-D`
MN,6ZT`"_N3H`O]["RKBWM.L@R*[`Y0#`_+#FN_8`R*^PYKRSP:0@P-"QXB"_
MP+?Y+@!,1$%0(+RMN?8@P:*\TR"]Q\;0`,;1O;H`,K_Y`,;$P,\@L/RXKL#:
M`,?*Q<T`L=O`VB"[]K'R`,?!M[G`TP#`I\2A`+6VP,\`L*&QX@"S],#,`+6U
MO_*XNP"UM;_RN+L`QL3`S\#'(+W#P-O`S""TV<"]L/H@L+"]P+3/M-DZ`,']
M(,'6O-(`P?T@P/S(K;GXR*,`2&]R9&4`O/;&\KRQ`+"AM\X@PZ2_\@"PH;?.
M.@#'U<2AL.T@O<W`NB"_K<#'(+SV`,?7N/$HOZTIP,<@O/8_`,?5Q*&P[2"]
MS<"Z(,?@P,<@O/8`7VZ^U;^A(,?@(,/?L*$`OL;`S,3<`+[&P,S$W+#Z(+FN
MP-H`O<2ZL,#:(,#,N*<Z`+'7N+(@N<RXKKJXL>(Z`+'7N+(@55),`+'7N+(@
M55),.@"PH<&NO\(@Q]>X\3H@)7,`L*'!KK_"(,?7N/$Z`%]SM-G`O;^A(,?@
M(,/?L*$`M>F_J;ZRL>(`7V^TV<"]OZ$@OZT@P]^PH0"QU[BR(,/?L*$`QZ4@
MP]^PH0#`I2"XM<6I(,/?L*$`7V.^U;^A(+^M(,/?L*$`Q_;`YR"_K2"UVK^A
M(+OU(+^M(,/?L*$`Q_;`YR"_K2"^U;^A(+OU(+^M(,/?L*$`Q_;`YR#'X""U
MVK^A(+OU(,?@(,/?L*$`Q_;`YR#'X""^U;^A(+OU(,?@(,/?L*$`Q_;`YR#!
M]L&A(+7:OZ$@M-RV]"##W["A`,?VP.<@P?;!H2"^U;^A(+3<MO0@P]^PH0"U
MVK^A(+R_(,/?L*$`OM6_H2"\OR##W["A`+7:OZ$@OZT@P]^PH0"^U;^A(+^M
M(,/?L*$`M=J_H2"TW+;T(,/?L*$`OM6_H2"TW+;T(,/?L*$`M=J_H2#'X"##
MW["A`+[5OZ$@Q^`@P]^PH0"QU[BR(,/?L*$OO/;!I`"XM<6I(,/?L*$OO/;!
MI`"QXK_OP,RQX@`QO_D`P,^ZNP#`S[J[ONX@*$E33RTR,#(R+4I0*0`WO_D`
M-K_Y`,&DM\0`L*&_[K6E(,&DM\0`ON?"RB#!I+?$`+_>PLH@P:2WQ`"_P+BE
MPLH@P:2WQ`"TZ\?1N<ZQN0#'T;&YONX@*$550RU+4BD`OO"^[@"XML'VN+<@
MM\ZQU\#..B`E<P"XML'VN+<@M\ZQU\#..B`E<RP@P:*\TR#`I\2A.B`E<P"X
MML'VN+<@M\ZQU\#..B"^^,"]`+>YP,R^QK_T`+_>PLH`M;6_\K[+(+CQPO<`
MN^>_Z\?2(+SV(+[XM,(@N^>_Z\#:(+CQM\\N`+?.L=?`S@"WSK'7OL:_]`"W
MSK'7P,X@O</`V\#;OO<`L=>XKKVZ(+S2N:[`V@"V\\:^(+S2N:[`V@"WSKBV
M(+S2N:[`VB"\_<#:`$U-`+C>P,\`7VNXM<6I(+BXM>FQXBXN+@`SO_D`L*'`
MY<#:N*X`P,_$H<?/M,(@Q]>X\0`UO_D`N-ZTNB"X\+7E`+R_(,?5Q*&QX@"X
MWKW#P?8`L*&_[K6E`%523""\]L&D`+C%O_D`OL:WH;?.(,#,M;\`P*>WSB#`
MS+6_`,#,N*<`L]?&KK_VQ:D`N^>_Z[[(Q]0`N_4@PZ(H7V)L86YK*0"TV<"]
M`+[&M,^_P`!&5%`@5D93N*8@P*?'T2"\L\&DP:2ZN+"A(+[XO<"TS[39+@!3
M44P@5D93(+RSP:3!I+JXL*$@OOB]P+3/M-DN`%-13"U&:6QE(%9&4R"\L\&D
MP:2ZN+"A(+[XO<"TS[39+@"\L<7#Q\_!]B"^RL"]`,+\P;8`,3&_^0"_K<#'
M(+SV`,?@P,<@O/8`,3"_^0"[]2##HK^A(+BUQ:D@OZVQX@"\L<7#N^?'UP`E
M<R"\L<7#N^?'UP"\_<#:(+CQM\\`M-S#O`"QXL6X`+'BQ;@@P:2ZN`#&Y+7Y
M`+[/R*,`OL_(H["A(,#/Q*''S\'V(+[*O<"TS[39+@"ZV<#,L>(`Q:RXL[JX
MM>6_H;RM(+K9P,RQX@"PYK?.`,;;O+[&K@#`K\'V(+#\N*X@P-N^]R"]Q\?@
M`+"SP,X@P:2ZN`#`_,BMN?C(HP#'R+R_`+FNP::_H2"TZ\?1(+_DON#`NR#`
MU+?"Q]@@P=:\O+_D+@"[Y[_KP-K`S+BGL/H@OL_(H[BF(,#4M\+'S[R\O^0`
MN<RXKKJXL>(`N_4@PZ*_H2"YS+BNNKBQX@"YKKRM(,#.O.(`N:[!IB"\L[CM
M`+BVP?:XMR"X[;?)(+G=NKD`QN2^[BAP86ER*2"[Z,&F`,#4M\(@P^N\T@"_
MR;S'P+BWSB"UN;[&L*&QX@"_P+BEPLH`7W?'X""\T[RZ+BXN`+^JQ](`Q^`@
MO-.\N@#'X""\T[RZ`,?@.@"PL,"Z(,?!M[G`TRA?<V5L9BD`P/K`Y0"\L<7#
MN^?'UR#`^L#E`+#+N_8`OL:WH2"[\\#:OZ&\K2#'RK_DQ]$@N:[`VKBF(+RQ
MQ</'S[#M(+JYN^?'S[^I(+K9OZFSUL"XO+R_Y"X`LZ_`VB"QN+K0QZ6]PR"\
ML<7#.@"SK\#:(,?\O<0@O+'%PP"]P["C(,?\O<0@O+'%PP"USK"SP,<@P,_$
MH<?/M,(@Q]>X\2"\L<7#`,#:P=:[Y[_KQ\^TPB"^\+[NN*8@O+'%P\?/O+R_
MY"X`N:[!IKG?N_T@NKBP[;RM(,#\O-O'S['B`#F_^0"\OR"\T[RZPZ(@NKBQ
MX@#'I2"\T[RZPZ(@NKBQX@"_K2"\T[RZPZ(@NKBQX@"QU[BR(+S3O+K#HB"Z
MN+'B`,6IL>(`P*_!]K#\N*X@N_VWJP"\O["CL-T`O+\@L.:PZ+_-(+.[O^L@
MN^?`S,#'(+"CL-T`L,6XK@"PQ;BNO\T@PZ2_[+'B`,:OO/8@N:[`VB#`U+?"
M`+R_(+K0Q](`OZT@NM#'T@#'X""ZT,?2`+"AO^ZUI<'9`+VZQ;C`SUM#4U-=
M`,&FN/$`P:;#X@"^QK>AP[?`V@"\NK#X`+_DON``P*W#M\#:`,>E(+S3O+H`
MQZ4@O-.\N@#`V[[W`+FNP-J_K0"YKL#:`+FNP-H@P:2WQ`"[Y[_KQ]C!UKS%
MO*T@L*B[Y\?5M,^TV2X`QL3`S[^A(+[&N:NWL2#`VK?AL*$@OOB]P+3/M-DN
M`+[&MZ&TPB#`S"!M97-S86=E+W)F8S@R,B#&[<'VP,<@N-.XM+B[P-2TS[39
M+@"]Q+JPP-H@(B5S(B"PH2"[Z,&FM<>^^KW`M,^TV2X`P,R_Z["AM,G'T2"\
ML<7#N^?'U\#,(+[XO<"TS[39+@#&Q,#/(+_#N*ZQXK^A(+FNP::PH2#`UKW`
MM,^TV2X@)7,@QL3`S\#,(+[WM\ZUY;7'P?8@OLJ^TKW`M,^TV2X`P,P@O/W`
MVK3"(,/6O-+'T2`QP-JXKB#`S+OSP,R^[K[?(,?5M,^TV2X`P,P@L*K`NB"\
M_<#:OZF^WR#'U;3/M-DN`,&FN/$`Q;C`S,:R*,7XQL$I.@"YWK3"(+OGMO<`
M2%1-3""\TKVZ(+JXL>(`P*<`N_/`IR#'P;>YP-,H7W1O<"D`55),`%9&4R#&
MQ,#/("5S+R5SP,<@QMNYS+S'P+L@NJ^PYL?2(+SV(+[XO<"TS[39+@!344P@
MO*VY]K^A(,&BO-/'TB"\]B"^^+W`M,^TV2X`)7,@P:3`Q[BF(,#0P+L@O/8@
MOOB]P+3/M-DN`'9F<W)O;W0@M?"WNL7DN*ZXIB#`T,"[(+SV(+[XO<"TS[39
M+@!61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN`,#,
M(+_VM>6YKKRMN*8@NJ^PYL?2(+SV(+[XO<"TS[39+@"YV,'9`+JOL.:[Y\?7
M(+7'M;FXKK'B`+BVP?:XMR"X[;?)(,/KO-(`O[6QN0"YS+&Y`,?VP.<@O^2\
MTK^A(+BUQ:D@P::PQ0#`S+BG(+[XP+T`N_:Q\B#!IK#%`+;SQKZ^[B"TZ[FN
MP-H`M\ZXMB"TZ[FNP-H@O/W`V@"[Y[_KP-H@O+'%P[OGQ]<`N^>_Z\#:N.T`
MO<.]NL7;P,<@N^>_Z\#:.@"\]L'W(,&DM\0`O/;!]R##I+_R`"5S(+JXL>(`
ML.:P[0"XQ<'6`,BOO[4`R*^_M<?5M,^TV2$@)7,@P-2TS[39+@#(K[^UQ]6T
MS[39+"`E<P"QN+K0(+FNP-JTPB"YJ[[YP-2TS['N/P#`SK_K(+K.R*.TPB"Y
MJ[[YP-2TS['N/P"SRKKQ`,>EP,<@L\JZ\0"SRKKQ(+3<P*<`L\JZ\3H`P??`
MY2#!UKS2.@#!]\#E(,#\R*VY^,BC`%E9`+C%L^(`O[D`5$585+CPM>7`U+3/
MM-DN(%L\/ET@N?;&L,"[(+2IN*.XZ2!765-)5UE'(+CPM>6WSB"UN;[&L*FT
MS[39+@"WSK'7OL:_]"#'S[^TO<"TS[39+@"YKL&F(+JXL.V\K;BF(+JXL[NQ
MXL#\OZ$@P,RYKL&FOZ$@M.O'T2"\L[CMP+L@P-2WPL?8OM\@Q]6TS[39+@#`
MS""XM<6IL*$@L*&XKL2AM,(@55),P+L@P-2WPL?8OM\@Q]6TS[39+@"[Z,&F
MQ](@N^>_Z\#:(,#,N*?`NR#`U+?"Q]B^WR#'U;3/M-DN`,/?L*''TB"[Y[_K
MP-H@P,RXI\"[(,#4M\+'V+[?(,?5M,^TV2X`)7,@O+R\Q\#,(+BXM^&UQ[[Z
MO<"TS[39+B"TV;W#(+?.L=?`SL?/O+R_Y"X`P,RXWL#/(,'6O-(Z`+C>P,\@
MP=:\TCH`P:2ZN`#`S+BG.@"TY[W%P,<@P,[!]<6LMO/`S+[PQJZPH2"[Y[_K
MP-H@N/&WS[JXL>*XIB#!]K_XQ\_!]B"^RKW`M,^TV2X@ML>TPB"TV;BE(,#,
MP*^WSB"[Y[_KP-H@N/&WS[JXL>*XIB"[Y[_KQ](@O/8@OOB]P+3/M-DN`+KJ
MMO._[,#ZL*$@P,P@L>*TR<"[(,'VO_C'S\'V(+[*O<"TS[39+@#']L#G(+W#
ML*.TZSH`L>*ZNR"]Q+JPP-HZ`,#\P[P@P,RXISH`P,P@O+R\QR"UO[[((+_)
MO,?`S"#`^L#EM<NTS[39+@"_R;S'P,P@P/K`Y;7'OOJ]P+3/M-DN`%O`SK_K
M(+S[L>*QXET`6[_`M_D@NKBP[<?/L>)=`%O`SK_K(+JXL>(@+0!;P,Z_ZR"Z
MN+'B("T@)7,@P=E=`%NV\\#.("5S("\@)7-=`%]!L/RXK@!?1,?@(,'VO_(`
MM;6_\KB[`%])L=>XLB"\T[RZ+BXN`%],M\ZQU[[&O_0`7VVXM<6I(+SVP:0N
M+BX`7T^\L<7#N^?'UP!?<KBUQ:D@N^C!IBXN`%]TQZ4@O-.\NBXN+@#!V5T`
MP,RXIP#&V[R^QJX`Q\B\OP#`S+BG(+[XP+T`=D-A<F0`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]L=%],5"\`
M````````````````````````````````````````````````````````````
M````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`U,34T,S,W-3,`,#(P,3,S`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&]C86QE+VQT7TQ4+VAE;'`N>&UL````````````````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,S,R,``Q,#4Q-30S,S<U,P`P,C$V,#,`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]X;6P@
M=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O;'1?
M3%0O:&5L<"YX;6PL=B`Q+C(@,C`P-"\P-2\R-R`R,#HR,CHQ-"!J86X@17AP
M("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4](FYE
M=R(^"CQT:71L93Y4:&4@4&]R=&%L(%!A9V4\+W1I=&QE/@H@/'!A<F$^"B`@
M5&AI<R!P;W)T86P@<&%G92!P<F]V:61E<R!A('%U:6-K('-U;6UA<GD@;V8@
M86QL('EO=7(@:6UP;W)T86YT"B`@:6YF;W)M871I;VXN($9O<B!E>&%M<&QE
M+"!I="!M:6=H="!S:&]W(&AO=R!M86YY(&YE=R!E+6UA:6P@;65S<V%G97,@
M>6]U"B`@:&%V92!I;B!Y;W5R($E.0D]8+"!U<&-O;6EN9R!E=F5N=',@;VX@
M>6]U<B!C86QE;F1A<BP@=&%S:W,@;VX@>6]U<B!T;RUD;PH@(&QI<W0L(&AE
M861L:6YE<R!F<F]M('-E;&5C=&5D(&YE=W,@<V5R=FEC97,L(&%N9"!S;R!O
M;BX@($UA;GD@;V8@=&AE<V4*("!S=6UM87)I97,@=VEL;"!C;VYT86EN('%U
M:6-K('-H;W)T8W5T<R!T;R!C;VUM;VX@9G5N8W1I;VYS+"!S=6-H(&%S"B`@
M8V]M<&]S:6YG(&$@;F5W(&UA:6P@;65S<V%G92P@8W)E871I;F<@82!N97<@
M8V%L96YD87(@979E;G0@;W(@=&%S:RP@971C+@H@/"]P87)A/@H@/'!A<F$^
M"B`@5&AE(&-O;G1E;G1S(&]F('1H:7,@<&]R=&%L('!A9V4@87)E(&-U<W1O
M;6EZ86)L92!V:6$@=&AE($QA>6]U="!B=71T;VXN"B`@1F]R(&5X86UP;&4L
M('EO=2!C86X@8VAO;W-E('=H:6-H(&ET96US('1O(&EN8VQU9&4@;VX@=&AI
M<R!P;W)T86P@<&%G92!A<PH@('=E;&P@87,@:6X@=VAI8V@@;W)D97(@=&AE
M>2!A<F4@<VAO=VXN"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)N
M879B87(B('-T871E/2)N97<B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N($YA
M=FEG871I;VX@0F%R/"]T:71L93X*(#QP87)A/@H@($%T('1H92!L969T(&AA
M;F0@<VED92!O9B!T:&4@=V5B('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N(&YA
M=FEG871I;VX@8F%R+@H@($-L:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES(&YA
M=FEG871I;VX@8F%R('1O('%U:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*("!B
M971W965N('1H92!A=F%I;&%B;&4@87!P;&EC871I;VYS+@H@/"]P87)A/@H\
M+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B('-T
M871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC
M93H@1&\@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y
M;W4@=V]U;&0@;&EK92!T;R!P97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@;VX@;&]G:6XL(&-H96-K('1H:7,@8F]X+@H@("`@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC92(@
M<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA
M;F-E.B!#;VYF:7)M($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@
M("`@268@>6]U('=O=6QD(&QI:V4@=&\@8V]N9FER;2!A;&P@;6%I;G1E;F%N
M8V4@=&%S:W,@8F5F;W)E('1H97D@87)E(')U;BP@8VAE8VL@=&AI<R!B;W@N
M($EF(&QE9G0@=6YC:&5C:V5D+"!A;&P@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<R!T:&%T(&YE960@=&\@8F4@<G5N('=I;&P@8F4@<&5R9F]R;65D(&%U=&]M
M871I8V%L;'D@=VET:"!N;R!C:&%N8V4@=&\@8V%N8V5L(&]N(&QO9VEN+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO
M8V%L92]L=%],5"],0U]-15-304=%4R\`````````````````````````````
M````````````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-3,`,#(Q-S(P`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&]C86QE+VQT7TQ4+TQ#7TU%4U-!1T53+VAO<F1E
M+FUO```````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#,S,C(T,@`Q,#4Q-30S,S<U
M,P`P,C,S-C0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````WA($E0````!T!@``'````+PS``";"```7&<```````#(B0``#@``
M`,F)```/````V(D```@```#HB0``#````/&)```$````_HD```P````#B@``
M#P```!"*```+````((H```X````LB@``!0```#N*```H````08H```H```!J
MB@``%0```'6*```2````BXH```L```">B@``#@```*J*```*````N8H```T`
M``#$B@``#@```-**```1````X8H```T```#SB@``#`````&+```-````#HL`
M``8````<BP``#P```".+```8````,XL```P```!,BP``#@```%F+```.````
M:(L```@```!WBP``+@```("+```:````KXL``#(```#*BP``.````/V+``!4
M````-HP``%$```"+C```6@```-V,``!7````.(T``#0```"0C0``"@```,6-
M```%````T(T```8```#6C0``$0```-V-```(````[XT```D```#XC0``"0``
M``*.```E````#(X``"`````RC@``$````%..```/````9(X```H```!TC@``
M`P```'^.```/````@XX``!0```"3C@``"0```*B.```-````LHX``!(```#`
MC@``#P```-..```*````XXX```\```#NC@``"````/Z.```D````!X\``!0`
M```LCP``%@```$&/```(````6(\``!D```!ACP``!P```'N/```,````@X\`
M`"P```"0CP``#@```+V/```#````S(\```L```#0CP``!P```-R/```'````
MY(\```4```#LCP``!0```/*/```*````^(\```,````#D```%P````>0```*
M````'Y````\````JD```#@```#J0```8````29```",```!BD```#@```(:0
M```4````E9```!<```"JD```%P```,*0```7````VI```!,```#RD```#P``
M``:1```.````%I$``!\````ED0``!P```$61```&````39$```@```!4D0``
M#P```%V1```&````;9$```H```!TD0``$P```'^1```+````DY$``!4```"?
MD0``%0```+61```'````RY$```4```#3D0``%0```-F1```1````[Y$```P`
M```!D@``.P````Z2```)````2I(```<```!4D@``%````%R2```#````<9(`
M``4```!UD@``$````'N2```)````C)(``!,```"6D@``.0```*J2```2````
MY)(``"<```#WD@``+````!^3```J````3),``"4```!WDP``"@```)V3```&
M````J),```D```"ODP``!P```+F3```O````P9,``#<```#QDP``+@```"F4
M``!5````6)0``"T```"NE```+0```-R4```M````"I4``$`````XE0``(P``
M`'F5```C````G94``"T```#!E0``,P```.^5```5````(Y8``!D````YE@``
M*0```%.6```D````?98``!$```"BE@``"@```+26```,````OY8```H```#,
ME@``$````->6```6````Z)8``!8```#_E@``!P```!:7```'````'I<``!0`
M```FEP``"@```#N7```(````1I<```@```!/EP``!P```%B7```'````8)<`
M``8```!HEP``!0```&^7```'````=9<```8```!]EP``"````(27```.````
MC9<```H```"<EP``!````*>7```'````K)<```D```"TEP``!@```+Z7```1
M````Q9<```<```#7EP``%@```-^7```$````]I<```@```#[EP``!@````28
M```-````"Y@```8````9F```'@```""8```1````/Y@```@```!1F```#0``
M`%J8```,````:)@```<```!UF````P```'V8```#````@9@``!<```"%F```
M$P```)V8```(````L9@```0```"ZF```"````+^8```(````R)@``$$```#1
MF```(````!.9```&````-)D```8````[F0``%0```$*9```8````6)D``"(`
M``!QF0``+@```)29```=````PYD``"$```#AF0``5`````.:```I````6)H`
M``H```""F@``!P```(V:```5````E9H```X```"KF@``"@```+J:```/````
MQ9H```T```#5F@``#P```..:```-````\YH```D````!FP``%`````N;```&
M````()L``!@````GFP``'0```$";```3````7IL``!0```!RFP``!````(>;
M```&````C)L``%0```"3FP``!````.B;```.````[9L```4```#\FP``!0``
M``*<```;````")P``!H````DG```$0```#^<```1````49P``!P```!CG```
M*@```("<```0````JYP``"$```"\G```!0```-Z<```3````Y)P``!(```#X
MG```"@````N=```/````%IT``!$````FG0``$P```#B=```,````3)T```8`
M``!9G0``!@```&"=```7````9YT``!$```!_G0``"````)&=```%````FIT`
M``P```"@G0``$````*V=```%````OIT```T```#$G0``!@```-*=```'````
MV9T```T```#AG0``!P```.^=```+````]YT```<````#G@``!P````N>```)
M````$YX```H````=G@``&0```"B>```,````0IX``!````!/G@``!0```&">
M```E````9IX``!(```",G@``$P```)^>```K````LYX``#L```#?G@``(```
M`!N?```V````/)\```@```!SGP``#````'R?```&````B9\```0```"0GP``
M#@```)6?```*````I)\```T```"OGP``'@```+V?```;````W)\``"$```#X
MGP``'@```!J@```9````.:```!X```!3H```&P```'*@```F````CJ```!L`
M``"UH```'@```-&@```<````\*```"8````-H0``,P```#2A```F````:*$`
M`"L```"/H0``.````+NA```O````]*$``!(````DH@``*0```#>B```2````
M8:(``*(```!TH@``%@```!>C```C````+J,``"@```!2HP``*0```'NC```H
M````I:,``!\```#.HP``(````.ZC```E````#Z0``"$````UI```'````%>D
M```F````=*0``$$```";I```#````-VD```'````ZJ0```<```#RI```!@``
M`/JD```-`````:4``!`````/I0``$@```""E```3````,Z4``!(```!'I0``
M!P```%JE```$````8J4```P```!GI0``#@```'2E```/````@Z4``!,```"3
MI0``#0```*>E```H````M:4```,```#>I0``#0```.*E```&````\*4``!$`
M``#WI0``%P````FF```;````(:8```X````]I@```@```$RF```%````3Z8`
M`!````!5I@``!````&:F```-````:Z8```X```!YI@```P```(BF```.````
MC*8```@```";I@``#P```*2F```/````M*8```T```#$I@``$````-*F```+
M````XZ8```8```#OI@``#````/:F```1`````Z<``!D````5IP``"P```"^G
M```-````.Z<``"(```!)IP``"@```&RG```8````=Z<``!D```"0IP``%@``
M`*JG```-````P:<```<```#/IP``%````->G```+````[*<``"(```#XIP``
M+P```!NH```+````2Z@```D```!7J```&0```&&H```+````>Z@``!<```"'
MJ```%P```)^H```)````MZ@``!8```#!J```#P```-BH```6````Z*@```X`
M``#_J```&`````ZI```(````)ZD```T````PJ0``)@```#ZI``!#````9:D`
M``@```"IJ0``$@```+*I```(````Q:D```L```#.J0``+P```-JI```.````
M"JH```4````9J@``!@```!^J```#````)JH```<````JJ@``!````#*J```*
M````-ZH```H```!"J@``#P```$VJ```0````7:H``!<```!NJ@``$0```(:J
M```7````F*H```D```"PJ@``!0```+JJ```+````P*H```H```#,J@```@``
M`->J```%````VJH```T```#@J@``&P```.ZJ```7````"JL```D````BJP``
M#@```"RK```-````.ZL``!(```!)JP``.````%RK```@````E:L```@```"V
MJP``#@```+^K``![````SJL``!@```!*K```$0```&.L```'````=:P```4`
M``!]K```&0```(.L```'````G:P```@```"EK```!@```*ZL```&````M:P`
M`!````"\K```#P```,VL```0````W:P```\```#NK```"P```/ZL```/````
M"JT```P````:K0``#P```">M```'````-ZT```8````_K0``#````$:M```H
M````4ZT```\```!\K0``"````(RM```(````E:T``!,```">K0``'@```+*M
M```A````T:T``"````#SK0``&0```!2N```7````+JX``"4```!&K@``%P``
M`&RN```$````A*X``!L```")K@``#0```*6N```#````LZX```@```"WK@``
M"@```,"N```,````RZX```L```#8K@``!````.2N```3````Z:X``!0```#]
MK@``#````!*O```)````'Z\```X````IKP``"P```#BO```;````1*\```<`
M``!@KP``!P```&BO```*````<*\```T```![KP``"0```(FO```$````DZ\`
M``4```"8KP```P```)ZO```8````HJ\```H```"[KP``!````,:O```F````
MRZ\```X```#RKP``?`````&P```5````?K````4```"4L```!P```)JP```,
M````HK````@```"OL```"@```+BP```&````P[````@```#*L````@```-.P
M```&````UK````8```#=L```%````.2P```-````^;```!`````'L0``&P``
M`!BQ```$````-+$```D````YL0``$````$.Q```)````5+$```D```!>L0``
M!0```&BQ```:````;K$```@```")L0``!@```)*Q```9````F;$```X```"S
ML0``!P```,*Q```'````RK$```4```#2L0``"0```-BQ```*````XK$```(`
M``#ML0``!@```/"Q```-````][$```D````%L@``!@````^R```2````%K(`
M``D````IL@``!P```#.R```4````.[(``!T```!0L@``!@```&ZR```*````
M=;(```0```"`L@``"0```(6R```(````C[(``!$```"8L@``"0```*JR```&
M````M+(```T```"[L@``!@```,FR```$````T+(``#D```#5L@``/0````^S
M```Z````3;,``!X```"(LP``!0```*>S```.````K;,```0```"\LP``!@``
M`,&S```A````R+,``!4```#JLP``!@````"T```$````![0``!$````,M```
M!@```!ZT```*````);0``"(````PM```!````%.T```%````6+0``!T```!>
MM```!````'RT```,````@;0```H```".M```"````)FT```)````HK0```4`
M``"LM```.@```+*T```P````[;0``#4````>M0``*0```%2U``!'````?K4`
M`#@```#&M0``*0```/^U```_````*;8``"X```!IM@``+0```)BV```?````
MQK8```\```#FM@``$@```/:V```+````";<``"8````5MP``*0```#RW```D
M````9K<``"8```"+MP``"````+*W```*````N[<```D```#&MP``!P```-"W
M```@````V+<``"````#YMP``)@```!JX```*````0;@``!D```!,N```*0``
M`&:X```6````D+@``!(```"GN```!P```+JX```*````PK@```\```#-N```
M$````-VX``!`````[K@``&8````ON0``#@```):Y```)````I;D```H```"O
MN0``$@```+JY```3````S;D```P```#AN0``!@```.ZY```/````];D``!(`
M```%N@``$````!BZ```1````*;H``!P````[N@``(P```%BZ``!J````?+H`
M``\```#GN@``!0```/>Z```0````_;H```D````.NP``!````!B[```+````
M';L``!0````INP``#````#Z[```,````2[L```\```!8NP``%0```&B[```I
M````?KL``"H```"HNP``)@```-.[```G````^KL``"D````BO```*@```$R\
M```9````=[P``$(```"1O```$0```-2\```2````YKP``!,```#YO```%```
M``V]```/````(KT``!8````RO0``%P```$F]```0````8;T``!$```!RO0``
M-````(2]```3````N;T``!(```#-O0``-0```."]```4````%KX```<````K
MO@``#````#.^```@````0+X``!0```!AO@``$0```':^```7````B+X``!P`
M``"@O@``$P```+V^```1````T;X``!H```#CO@``'@```/Z^```:````';\`
M`!$````XOP``%````$J_```7````7[\``!4```!WOP``"0```(V_```9````
ME[\```0```"QOP``!P```+:_```+````OK\``!$```#*OP``!@```-R_```&
M````X[\```8```#JOP``!0```/&_```'````][\```<```#_OP``!0````?`
M```6````#<````8````DP```!@```"O````$````,L````0````WP```!P``
M`#S````.````1,````P```!3P```#````&#````-````;<````H```![P```
M#@```(;````%````E<```"@```";P```#@```,3````,````T\````\```#@
MP```"@```/#````(````^\````D````$P0``*P````[!```$````.L$```@`
M```_P0``)@```$C!```2````;\$```\```""P0``!@```)+!```*````F<$`
M``<```"DP0``"````*S!```@````M<$```D```#6P0``#````.#!```-````
M[<$```X```#[P0``%@````K"```1````(<(```8````SP@```P```#K"```&
M````/L(``!D```!%P@``!P```%_"```$````9\(```L```!LP@``"P```'C"
M```'````A,(```<```",P@``%@```)3"```-````J\(```T```"YP@``"@``
M`,?"```0````TL(```\```#CP@``$0```//"```7````!<,```H````=PP``
M$0```"C#```(````.L,```0```!#PP``#P```$C#```Z````6,,```4```"3
MPP``#````)G#```>````IL,```X```#%PP``$````-3#```+````Y<,```P`
M``#QPP``"0```/[#```'````",0```H````0Q```"0```!O$```.````)<0`
M`!`````TQ```&@```$7$```*````8,0```D```!KQ```"@```'7$```,````
M@,0```\```"-Q```"````)W$```&````IL0```<```"MQ```"P```+7$``!'
M````P<0```T````)Q0``"0```!?%```$````(<4```,````FQ0``$P```"K%
M```3````/L4``!,```!2Q0``"@```&;%```"````<<4```0```!TQ0``)0``
M`'G%```#````G\4```4```"CQ0``*@```*G%```*````U,4```4```#?Q0``
M!````.7%```*````ZL4```T```#UQ0``!@````/&```(````"L8```@````3
MQ@``!````!S&```%````(<8``&@````GQ@``"0```)#&```,````FL8```4`
M``"GQ@``!@```*W&```;````M,8``"\```#0Q@``$`````#'```*````$<<`
M``\````<QP``"@```"S'```)````-\<``!,```!!QP``&P```%7'```8````
M<<<``!<```"*QP``#@```*+'```#````L<<```<```"UQP``"````+W'```'
M````QL<```H```#.QP``"P```-G'```'````Y<<``%$```#MQP``$````#_(
M```,````4,@```T```!=R```&@```&O(``!*````AL@```8```#1R```!@``
M`-C(```&````W\@``!\```#FR```!@````;)```)````#<D``!@````7R0``
M%P```##)```&````2,D```T```!/R0``(@```%W)``!7````@,D``!,```#8
MR0``(P```.S)```3````$,H```(````DR@``"P```"?*```(````,\H```T`
M```\R@``"@```$K*```'````5<H``!0```!=R@``!@```'+*```(````><H`
M``X```""R@``!P```)'*```*````F<H```L```"DR@``!P```+#*```,````
MN,H```T```#%R@``#````-/*```)````X,H```D```#JR@``"@```/3*```'
M````_\H```D````'RP``!P```!'+```*````&<L``!L````DRP``$@```$#+
M```*````4\L```D```!>RP``$````&C+```'````><L``!(```"!RP``!```
M`)3+```'````F<L```4```"ARP``!0```*?+```+````K<L``!0```"YRP``
M$0```,[+```:````X,L``!8```#[RP``%````!+,```7````)\P``!@````_
MS```'````%C,```9````=<P```<```"/S```!0```)?,```-````G<P```P`
M``"KS```"````+C,```7````P<P```L```#9S```$P```.7,```$````^<P`
M``H```#^S```!`````G-```,````#LT```D````;S0``!0```"7-```'````
M*\T```4````SS0``!````#G-```"````/LT``#@```!!S0``+````'K-```2
M````I\T``"D```"ZS0``,@```.3-```*````%\X``"P````BS@``+@```$_.
M```S````?LX``#,```"RS@``.````.;.```/````'\\``!@````OSP``$```
M`$C/```3````6<\``!0```!MSP``$@```(+/```4````E<\``!4```"JSP``
M+0```,#/```M````[L\``#$````<T```+@```$[0```O````?=```"P```"M
MT```8@```-K0```3````/=$```@```!1T0``"````%K1```K````8]$``"$`
M``"/T0``&@```+'1```)````S-$``$4```#6T0``00```!S2```$````7M(`
M`!,```!CT@``%````'?2```.````C-(``!,```";T@``&````*_2```&````
MR-(```D```#/T@``"@```-G2```/````Y-(``!````#TT@``!P````73```.
M````#=,```4````<TP``&P```"+3```(````/M,```8```!'TP``%````$[3
M```1````8],```X```!UTP``.````(33```"````O=,```8```#`TP``#@``
M`,?3```%````UM,```<```#<TP``#@```.33```&````\],```0```#ZTP``
M*0```/_3```7````*=0``!\```!!U```7````&'4```4````OM0``!\```#3
MU```$````//4```'````!-4```X````,U0``#````!O5```,````*-4``!,`
M```UU0``"@```$G5```=````5-4``!D```!RU0``!0```(S5```1````DM4`
M`!$```"DU0``)````+;5```5````V]4``!(```#QU0``#@````36```9````
M$]8```@````MU@``"0```#;6```-````0-8```H```!.U@``"P```%G6```*
M````9=8```<```!PU@``"````'C6```%````@=8``!\```"'U@``!@```*?6
M```0````KM8```@```"_U@``#0```,C6```(````UM8``!(```#?U@``+```
M`/+6```:````']<```D````ZUP``"@```$37```5````3]<```4```!EUP``
M%````&O7```$````@-<``!````"%UP``!@```);7```'````G=<``!X```"E
MUP``*````,37```*````[=<``!H```#XUP``%````!/8```$````*-@```0`
M```MV```"P```#+8```%````/M@```8```!$V```"````$O8```&````5-@`
M``H```!;V```&P```&;8```T````@M@``#0```"WV```(````.S8```I````
M#=D``"`````WV0``00```%C9```:````FMD``"@```"UV0``*0```-[9```B
M````"-H```8````KV@``"````#+:```%````.]H```@```!!V@``&0```$K:
M```9````9-H``"H```!^V@``(P```*G:```N````S=H``#0```#\V@``"```
M`#';```7````.ML```H```!2VP``!P```%W;```A````9=L``!````"'VP``
M#@```)C;```+````I]L```<```"SVP``$P```+O;```(````S]L```L```#8
MVP``"@```.3;```4````[]L``#(````$W```"P```#?<```%````0]P```4`
M``!)W```%P```$_<```/````9]P```0```!WW```"@```'S<```)````A]P`
M``L```"1W```#@```)W<```%````K-P```0```"RW```#0```+?<```R````
MQ=P``$4```#XW```%P```#[=```>````5MT``!0```!UW0``!0```(K=```4
M````D-T```<```"EW0``#@```*W=```J````O-T```8```#GW0``#````.[=
M```-````^]T``!$````)W@``"P```!O>```V````)]X```H```!>W@``(@``
M`&G>```+````C-X```\```"8W@``,@```*C>```%````V]X```X```#AW@``
M$P```/#>```'````!-\``!$````,WP``!P```![?```4````)M\``!@````[
MWP``!P```%3?```%````7-\```P```!BWP``#````&_?```2````?-\```0`
M``"/WP``!P```)3?```*````G-\```L```"GWP``#````+/?```.````P-\`
M``X```#/WP``!0```-[?```%````Y-\``"X```#JWP``)@```!G@```C````
M0.````,```!DX```$@```&C@```&````>^```!X```""X```&````*'@```E
M````NN````T```#@X```"0```.[@```#````^.````<```#\X```"@````3A
M```"````#^$```P````2X0``%0```!_A```+````->$``!D```!!X0``(```
M`%OA```2````?.$```4```"/X0``"@```)7A```5````H.$``!(```"VX0``
M#````,GA```$````UN$```<```#;X0``#````./A``!2````\.$``!<```!#
MX@``!P```%OB```&````8^(```X```!JX@``#````'GB```-````AN(``!4`
M``"4X@``$@```*KB```/````O>(``!0```#-X@``&P```.+B```0````_N(`
M`&D````/XP``&@```'GC```7````E.,``"<```"LXP``&@```-3C```7````
M[^,``!L````'Y```&0```"/D```?````/>0``!,```!=Y```"````''D```'
M````>N0```@```""Y```"0```(OD```5````E>0```T```"KY```$P```+GD
M```#````S>0``$8```#1Y```/P```!CE```W````6.4``%<```"0Y0``'P``
M`.CE```O````".8```H````XY@``"````$/F```-````3.8``"T```!:Y@``
M!````(CF``!/````C>8``"4```#=Y@``'`````/G```+````(.<``!\````L
MYP``'0```$SG```E````:N<``"````"0YP``)````+'G```@````UN<```L`
M``#WYP``!P````/H```-````"^@```P````9Z```!@```";H```Y````+>@`
M``P```!GZ```!P```'3H```)````?.@``!,```"&Z```"0```)KH```$````
MI.@``!````"IZ```"````+KH```(````P^@```L```#,Z```#````-CH```:
M````Y>@```\`````Z0``!P```!#I```-````&.D``!0````FZ0``#@```#OI
M```,````2ND``!L```!7Z0``+````'/I```3````H.D``!P```"TZ0``*```
M`-'I```&````^ND```<````!Z@``$P````GJ```%````'>H```0````CZ@``
M%P```"CJ```*````0.H```P```!+Z@``"0```%CJ```&````8NH```D```!I
MZ@``"````'/J```)````?.H```H```"&Z@``$0```)'J```&````H^H```X`
M``"JZ@``#@```+GJ```-````R.H```L```#6Z@``'0```.+J```+`````.L`
M``(````,ZP``!P````_K```&````%^L```D````>ZP``!P```"CK```[````
M,.L``"@```!LZP``%0```)7K```%````J^L```<```"QZP``"````+GK```'
M````PNL```4```#*ZP``!P```-#K```.````V.L```D```#GZP``!@```/'K
M```(````^.L```L````![```!P````WL```(````%>P```<````>[```%@``
M`";L```)````/>P```8```!'[```"P```$[L```<````6NP``!0```!W[```
M!P```(SL```(````E.P```@```"=[```!0```*;L```0````K.P``!````"]
M[```!@```,[L```9````U>P```H```#O[```'````/KL```'````%^T```4`
M```?[0``$````"7M```4````-NT```L```!+[0``#0```%?M```7````9>T`
M``0```!][0``"0```(+M```*````C.T```<```"7[0```@```)_M```.````
MHNT```@```"Q[0``'P```+KM```C````VNT``#@```#^[0``,0```#?N```G
M````:>X``&0```"1[@``%````/;N``!5````"^\``#@```!A[P``2@```)KO
M``!;````Y>\``"@```!!\```.````&KP```H````H_```"P```#,\```)P``
M`/GP```;````(?$``#X````]\0``J0$``'SQ```C````)O,``!<```!*\P``
M2````&+S``"%````J_,``#`````Q]```00```&+T``!;````I/0``$D`````
M]0``'0```$KU```8````:/4``"$```"!]0``'P```*/U```K````P_4``"$`
M``#O]0``'0```!'V```1````+_8``#,```!!]@``)0```'7V```G````F_8`
M`!\```##]@``,````./V``!I````%/<``#T```!^]P``90```+SW``!-````
M(O@``"\```!P^```+@```*#X```P````S_@``%0`````^0``6@```%7Y``!(
M````L/D``$H```#Y^0``,@```$3Z```O````=_H``"P```"G^@``+0```-3Z
M``!Q`````OL``&\```!T^P``LP```.3[```7````F/P``"4```"P_```,@``
M`-;\```I````"?T``#X````S_0``(@```'+]``!2````E?T``"4```#H_0``
M"P````[^``"Q````&OX``$4```#,_@``(0```!+_```P````-/\``"4```!E
M_P``'````(O_```Q````J/\```<```#:_P``!P```.+_```$````ZO\```T`
M``#O_P``"P```/W_```.````"0`!``L````8``$`!0```"0``0`0````*@`!
M``(````[``$`60```#X``0`%````F``!`!(```">``$`!````+$``0`'````
MM@`!``@```"^``$`!0```,<``0`#````S0`!`!````#1``$`#````.(``0`3
M````[P`!``T````#`0$``@```!$!`0`'````%`$!``8````<`0$`%````",!
M`0`,````.`$!`!@```!%`0$`!@```%X!`0`2````90$!``P```!X`0$``P``
M`(4!`0`J````B0$!``0```"T`0$`!@```+D!`0`'````P`$!`!\```#(`0$`
M-0```.@!`0`N````'@(!`"\```!-`@$`%P```'T"`0`@````E0(!`!L```"V
M`@$`&````-("`0`D````ZP(!`!\````0`P$`&@```#`#`0`@````2P,!`!H`
M``!L`P$`,@```(<#`0`O````N@,!`"L```#J`P$`'P```!8$`0`C````-@0!
M`!\```!:!`$`&@```'H$`0`E````E00!`"8```"[!`$`)0```.($`0`D````
M"`4!`!@````M!0$`'0```$8%`0`D````9`4!`!@```")!0$`(@```*(%`0`E
M````Q04!`#P```#K!0$`'P```"@&`0`C````2`8!`!\```!L!@$`(````(P&
M`0`:````K08!`!@```#(!@$`)@```.$&`0`>````"`<!`"D````G!P$`'@``
M`%$'`0`)````<`<!``P```!Z!P$`%P```(<'`0`O````GP<!`"0```#/!P$`
M!P```/0'`0`/````_`<!`!0````,"`$`#@```"$(`0`-````,`@!`"0````^
M"`$`!0```&,(`0`'````:0@!`"(```!Q"`$`)0```)0(`0`=````N@@!`!H`
M``#8"`$`!P```/,(`0#'````^P@!``L```##"0$`%0```,\)`0`&````Y0D!
M``D```#L"0$`"P```/8)`0`7`````@H!``8````:"@$`,P```"$*`0`3````
M50H!`!,```!I"@$`!P```'T*`0`/````A0H!``<```"5"@$`,@```)T*`0`A
M````T`H!`!,```#R"@$`#`````8+`0`1````$PL!`#(````E"P$`"````%@+
M`0`)````80L!``H```!K"P$`%````'8+`0`*````BPL!`!T```"6"P$`"```
M`+0+`0`?````O0L!``@```#="P$`&@```.8+`0`&`````0P!`!4````(#`$`
M!P```!X,`0`(````)@P!``D````O#`$`/P```#D,`0`'````>0P!``\```"!
M#`$`#@```)$,`0`0````H`P!``D```"Q#`$`"0```+L,`0`(````Q0P!`!,`
M``#.#`$`!P```.(,`0`9````Z@P!``H````$#0$`%P````\-`0`4````)PT!
M``H````\#0$`#````$<-`0`7````5`T!``0```!L#0$`*@```'$-`0`1````
MG`T!``<```"N#0$``@```+8-`0`0````N0T!`!@```#*#0$`"P```.,-`0`#
M````[PT!``@```#S#0$`!@```/P-`0`'`````PX!``T````+#@$`"P```!D.
M`0`4````)0X!`!4````Z#@$`#@```%`.`0`O````7PX!`"````"/#@$`'```
M`+`.`0`,````S0X!`#$```#:#@$`!0````P/`0`2````$@\!`#\````E#P$`
M$@```&4/`0`*````>`\!``8```"##P$`!````(H/`0`3````CP\!``4```"C
M#P$`!@```*D/`0`&````L`\!``0```"W#P$`#````+P/`0`*````R0\!``4`
M``#4#P$`&````-H/`0`9````\P\!`!\````-$`$`'0```"T0`0`1````2Q`!
M``(```!=$`$`!````&`0`0`*````91`!``8```!P$`$`!0```'<0`0`#````
M?1`!``P```"!$`$`10```(X0`0`:````U!`!`#4```#O$`$`*````"41`0!3
M````3A$!`!D```"B$0$`<@```+P1`0`@````+Q(!`#4```!0$@$`10```(82
M`0`P````S!(!`"@```#]$@$`*0```"83`0`F````4!,!`"4```!W$P$`*```
M`)T3`0`H````QA,!`"(```#O$P$`,````!(4`0`2````0Q0!`!,```!6%`$`
M$````&H4`0!Y````>Q0!``D```#U%`$`<P```/\4`0!\````<Q4!`"L```#P
M%0$`%P```!P6`0`6````-!8!``\```!+%@$`'P```%L6`0`?````>Q8!`!P`
M``";%@$`40```+@6`0`4````"A<!``H````?%P$`!0```"H7`0`&````,!<!
M``@````W%P$`!0```$`7`0`2````1A<!`!````!9%P$`$P```&H7`0`=````
M?A<!``\```"<%P$`#P```*P7`0`$````O!<!``D```#!%P$`"P```,L7`0`'
M````UQ<!``4```#?%P$`%````.47`0`'````^A<!``@````"&`$`#P````L8
M`0`(````&Q@!``P````D&`$`#P```#$8`0`&````01@!`!0```!(&`$`!@``
M`%T8`0`,````9!@!``@```!Q&`$`!````'H8`0`*````?Q@!``<```"*&`$`
M!````)(8`0`9````EQ@!``(```"Q&`$`"0```+08`0`&````OA@!``8```#%
M&`$`)P```,P8`0`$````]!@!``\```#Y&`$`$P````D9`0`'````'1D!``<`
M```E&0$`!@```"T9`0`&````-!D!`!`````[&0$`$@```$P9`0`&````7QD!
M``D```!F&0$`(@```'`9`0`'````DQD!``<```";&0$`"P```*,9`0`%````
MKQD!``(```"U&0$`"P```+@9`0!7`0``Q!D!`!(````<&P$`#@```"\;`0`+
M````/AL!``@```!*&P$``0```%,;`0`+````51L!`!$```!A&P$`#````',;
M`0`-````@!L!``4```".&P$`*0```)0;`0`/````OAL!``P```#.&P$`$@``
M`-L;`0`(````[AL!`!$```#W&P$`"@````D<`0`,````%!P!`!,````A'`$`
M$0```#4<`0`.````1QP!`!$```!6'`$`$````&@<`0`&````>1P!``X```"`
M'`$`%0```(\<`0`1````I1P!`!,```"W'`$`$P```,L<`0`+````WQP!`"P`
M``#K'`$`$@```!@=`0`]````*QT!`$D```!I'0$`90```+,=`0!F````&1X!
M`&@```"`'@$`:0```.D>`0!`````4Q\!``H```"4'P$`!0```)\?`0`&````
MI1\!`!(```"L'P$`!P```+\?`0`1````QQ\!`!,```#9'P$`*P```.T?`0`H
M````&2`!``L```!"(`$`$P```$X@`0`(````8B`!``<```!K(`$`#P```',@
M`0`0````@R`!`!````"4(`$`$P```*4@`0`5````N2`!`!H```#/(`$`$```
M`.H@`0`6````^R`!``P````2(0$`+0```!\A`0`:````32$!`!\```!H(0$`
M$0```(@A`0`<````FB$!``<```"W(0$`!P```+\A`0`Y````QR$!``@````!
M(@$`"`````HB`0`,````$R(!``@````@(@$`!P```"DB`0`(````,2(!``@`
M```Z(@$`"P```$,B`0`%````3R(!`!H```!5(@$`#````'`B`0`,````?2(!
M`!0```"*(@$`%````)\B`0`A````M"(!``X```#6(@$`'P```.4B`0`=````
M!2,!`"(````C(P$`'@```$8C`0`5````92,!`!0```![(P$`#@```)`C`0`;
M````GR,!``8```"[(P$`!@```,(C`0`'````R2,!`!D```#1(P$`"0```.LC
M`0`*````]2,!`!(`````)`$`!P```!,D`0`5````&R0!`!<````Q)`$`"P``
M`$DD`0`(````520!`!<```!>)`$`$P```'8D`0`9````BB0!`#,```"D)`$`
M"0```-@D`0`(````XB0!`!4```#K)`$`!0````$E`0`%````!R4!`!T````-
M)0$`"P```"LE`0`@````-R4!`"X```!8)0$`%0```(<E`0`H````G24!`"H`
M``#&)0$`*P```/$E`0`K````'28!``D```!))@$`"0```%,F`0`*````728!
M``@```!H)@$`+P```'$F`0`L````H28!`"X```#.)@$`4````/TF`0`M````
M3B<!`"T```!\)P$`+0```*HG`0`_````V"<!`"D````8*`$`*P```$(H`0`M
M````;B@!`#,```"<*`$`%````-`H`0`8````Y2@!`"H```#^*`$`)P```"DI
M`0`.````42D!``T```!@*0$`$0```&XI`0`%````@"D!``L```"&*0$`(0``
M`)(I`0`F````M"D!``<```#;*0$`"0```.,I`0`6````[2D!``H````$*@$`
M"@````\J`0`.````&BH!``L````I*@$`!P```#4J`0`'````/2H!``<```!%
M*@$`"````$TJ`0`'````5BH!``L```!>*@$`$````&HJ`0`+````>RH!``H`
M``"'*@$`"````)(J`0`'````FRH!``<```"C*@$`$````*LJ`0`'````O"H!
M`!8```#$*@$`!0```-LJ`0`(````X2H!``@```#J*@$`"@```/,J`0`)````
M_BH!`"`````(*P$`%0```"DK`0`)````/RL!`!$```!)*P$`#@```%LK`0`)
M````:BL!``,```!T*P$``P```'@K`0`7````?"L!`!0```"4*P$`"P```*DK
M`0`$````M2L!``@```"Z*P$`"0```,,K`0!/````S2L!`"H````=+`$`!@``
M`$@L`0`(````3RP!`!P```!8+`$`'````'4L`0`A````DBP!`"@```"T+`$`
M'P```-TL`0`I````_2P!`%@````G+0$`+````(`M`0`*````K2T!``L```"X
M+0$`"P```,0M`0`-````T"T!`!$```#>+0$`$````/`M`0`.`````2X!`!``
M```0+@$`$@```"$N`0`3````-"X!`!,```!(+@$`!@```%PN`0`<````8RX!
M`!X```"`+@$`$P```)\N`0`2````LRX!``4```#&+@$`"````,PN`0!B````
MU2X!``@````X+P$`%@```$$O`0`$````6"\!``8```!=+P$`'````&0O`0`;
M````@2\!`!8```"=+P$`&P```+0O`0`A````T"\!`"0```#R+P$`"P```!<P
M`0`/````(S`!``8````S,`$`&````#HP`0`=````4S`!`!L```!Q,`$`&P``
M`(TP`0`%````J3`!`!,```"O,`$`#@```,,P`0`)````TC`!``D```#<,`$`
M%@```.8P`0`;````_3`!``D````9,0$`!@```",Q`0`2````*C$!`!0````]
M,0$`"P```%(Q`0`5````7C$!``@```!T,0$`!P```'TQ`0`0````A3$!``H`
M``"6,0$`#@```*$Q`0`'````L#$!``D```"X,0$`#````,(Q`0`'````SS$!
M`!0```#7,0$`#P```.PQ`0`5````_#$!``8````2,@$`'````!DR`0`5````
M-C(!`!8```!,,@$`,0```&,R`0`^````E3(!`"<```#4,@$`,@```/PR`0`%
M````+S,!``H````U,P$`#@```$`S`0`)````3S,!`!4```!9,P$`"@```&\S
M`0`6````>C,!`!X```"1,P$`'P```+`S`0`A````T#,!`"(```#R,P$`'0``
M`!4T`0`H````,S0!`!\```!<-`$`*0```'PT`0`?````IC0!`"(```#&-`$`
M'@```.DT`0`J````"#4!`"L````S-0$`(P```%\U`0`I````@S4!`#````"M
M-0$`+P```-XU`0`6````#C8!`"X````E-@$`%0```%0V`0"W````:C8!`!(`
M```B-P$`(@```#4W`0`G````6#<!`"<```"`-P$`)0```*@W`0`<````SC<!
M`"````#K-P$`+P````PX`0`@````/#@!`"````!=.`$`+````'XX`0!'````
MJS@!``\```#S.`$`"`````,Y`0`&````##D!``<````3.0$`#P```!LY`0`4
M````*SD!`!0```!`.0$`$````%4Y`0`;````9CD!``@```"".0$`!````(LY
M`0`1````D#D!`!$```"B.0$`%@```+0Y`0`4````RSD!`!(```#@.0$`,P``
M`/,Y`0`(````)SH!`!0````P.@$`!@```$4Z`0`1````3#H!`!<```!>.@$`
M'P```'8Z`0`2````ECH!``(```"I.@$`!P```*PZ`0`7````M#H!``0```#,
M.@$`!0```-$Z`0`2````USH!``4```#J.@$`$@```/`Z`0`'`````SL!`!4`
M```+.P$`%0```"$[`0`2````-SL!`!0```!*.P$`"P```%\[`0`(````:SL!
M``X```!T.P$`#@```(,[`0`9````DCL!``T```"L.P$`$0```+H[`0`J````
MS#L!``\```#W.P$`&@````<\`0`4````(CP!`!,````W/`$`$0```$L\`0`&
M````73P!`!,```!D/`$`"0```'@\`0`N````@CP!`"T```"Q/`$`"````-\\
M`0`)````Z#P!`!T```#R/`$`"P```!`]`0`:````'#T!`!H````W/0$`"0``
M`%(]`0`:````7#T!`!4```!W/0$`%0```(T]`0`3````HST!`!P```"W/0$`
M"````-0]`0`(````W3T!`"H```#F/0$`(@```!$^`0`(````-#X!`!0````]
M/@$`"@```%(^`0`-````73X!`#0```!K/@$`&0```*`^`0`'````NCX!`!$`
M``#"/@$``P```-0^`0`)````V#X!``8```#B/@$`%P```.D^`0`/`````3\!
M`!`````1/P$`$````"(_`0`5````,S\!`!(```!)/P$`%0```%P_`0`'````
M<C\!``<```!Z/P$`"@```((_`0`,````C3\!``(```":/P$`"@```)T_`0`1
M````J#\!`!\```"Z/P$`(0```-H_`0`*````_#\!``X````'0`$`$P```!9`
M`0`;````*D`!`#L```!&0`$`)@```()``0`.````J4`!`!,```"X0`$`<@``
M`,Q``0`9````/T$!`!(```!900$`"````&Q!`0`&````=4$!``X```!\00$`
M!@```(M!`0`(````DD$!``<```";00$`!@```*-!`0`.````JD$!``T```"Y
M00$`$````,=!`0`-````V$$!`!L```#F00$`#@````)"`0`*````$4(!``L`
M```<0@$`!P```"A"`0`*````,$(!``\````[0@$`/````$M"`0`.````B$(!
M``H```"70@$`#0```*)"`0`<````L$(!`!T```#-0@$`*````.M"`0`G````
M%$,!`!T````\0P$`'````%I#`0`B````=T,!`!D```":0P$`!P```+1#`0`:
M````O$,!``P```#70P$`!@```.1#`0`'````ZT,!``H```#S0P$`#````/Y#
M`0`3````"T0!``8````?1`$`&0```"9$`0`<````0$0!``\```!=1`$`$0``
M`&U$`0`2````?T0!``\```"21`$`(@```*)$`0`'````Q40!``<```#-1`$`
M#````-5$`0`2````XD0!`!<```#U1`$`"P````U%`0`*````&44!``4````D
M10$`&0```"I%`0`-````1$4!``<```!210$`*0```%I%`0`2````A$4!`(<`
M``"710$`&@```!]&`0`&````.D8!``4```!!1@$`#````$=&`0`&````5$8!
M``@```!;1@$`"@```&1&`0`,````;T8!``4```!\1@$`"0```()&`0`*````
MC$8!`!8```"71@$`$@```*Y&`0`6````P48!`"````#81@$``P```/E&`0`$
M````_48!`!`````"1P$`"````!-'`0`-````'$<!``<````J1P$`-0```#)'
M`0`)````:$<!``<```!R1P$`%P```'I'`0`2````DD<!``<```"E1P$`"0``
M`*U'`0`$````MT<!``L```"\1P$`!@```,A'`0`&````ST<!``<```#61P$`
M#@```-Y'`0`+````[4<!``@```#Y1P$`%@````)(`0`+````&4@!``<````E
M2`$`%@```"U(`0`A````1$@!``8```!F2`$`"0```&U(`0`%````=T@!``D`
M``!]2`$`!P```(=(`0`-````CT@!``P```"=2`$`!P```*I(`0`.````LD@!
M``8```#!2`$`!````,A(`0`S````S4@!`#<````!20$`-@```#E)`0`@````
M<$D!``8```"120$`#P```)A)`0`%````J$D!``@```"N20$`'@```+=)`0`6
M````UDD!``<```#M20$`!P```/5)`0`@````_4D!``T````>2@$`"0```"Q*
M`0`;````-DH!``8```!22@$`"0```%E*`0`D````8TH!``@```"(2@$`#```
M`)%*`0`.````GDH!``@```"M2@$`"0```+9*`0`(````P$H!`#,```#)2@$`
M+P```/U*`0`R````+4L!`"8```!@2P$`1@```(=+`0`Z````SDL!`"H````)
M3`$`,@```#1,`0`R````9TP!`#,```":3`$`)0```,Y,`0`2````]$P!`!,`
M```'30$`#@```!M-`0`@````*DT!`!\```!+30$`'P```&M-`0`=````BTT!
M``D```"I30$`"P```+--`0`*````OTT!``@```#*30$`)P```---`0`H````
M^TT!`#`````D3@$`"@```%5.`0`9````8$X!`",```!Z3@$`#@```)Y.`0`7
M````K4X!``D```#%3@$`#P```,].`0`5````WTX!`!,```#U3@$`*`````E/
M`0!I````,D\!`!4```"<3P$`$````+)/`0`1````PT\!`!D```#53P$`&@``
M`.]/`0`5````"E`!``<````@4`$`%0```"A0`0`2````/E`!``X```!14`$`
M&````&!0`0`:````>5`!`#$```"44`$`HP```,90`0`5````:E$!``8```"`
M40$`%P```(=1`0`*````GU$!``L```"J40$`"P```+91`0`;````PE$!`!,`
M``#>40$`#P```/)1`0`/`````E(!`!D````24@$`+P```"Q2`0`N````7%(!
M`"P```"+4@$`*P```+A2`0`C````Y%(!`"(````(4P$`&P```"M3`0!!````
M1U,!`!(```")4P$`%@```)Q3`0`9````LU,!`!@```#-4P$`#P```.93`0`7
M````]E,!`!L````.5`$`%````"I4`0`8````/U0!`"\```!85`$`'0```(A4
M`0`9````IE0!`#$```#`5`$`$@```/)4`0`(````!54!``\````.50$`)```
M`!Y5`0`4````0U4!``\```!850$`&P```&A5`0`4````A%4!`!H```"950$`
M%0```+15`0`=````RE4!`",```#H50$`'@````Q6`0`7````*U8!`!0```!#
M5@$`'0```%A6`0`<````=E8!``L```"35@$`&@```)]6`0`&````NE8!``8`
M``#!5@$`"0```,A6`0`3````TE8!``@```#F5@$`"0```.]6`0`(````^58!
M``<````"5P$`!P````I7`0`&````$E<!``@````95P$`%P```")7`0`'````
M.E<!``D```!"5P$`!0```$Q7`0`(````4E<!``8```!;5P$`#P```&)7`0`.
M````<E<!`!````"!5P$`$0```))7`0`+````I%<!`!0```"P5P$`!@```,57
M`0`L````S%<!`!,```#Y5P$`#0````U8`0`/````&U@!``L````K6`$`"P``
M`#=8`0`2````0U@!`"<```!66`$`!@```'Y8`0`)````A5@!`"<```"/6`$`
M$@```+=8`0`5````RE@!``@```#@6`$`"0```.E8`0`+````\U@!``4```#_
M6`$`)0````59`0`*````*UD!`!0````V60$`"P```$M9`0`<````5UD!`"D`
M``!T60$`&````)Y9`0`'````MUD!``4```"_60$`"@```,59`0`P````T%D!
M``<````!6@$`!P````E:`0`1````$5H!`!,````C6@$`!P```#=:`0`(````
M/UH!`!8```!(6@$`#@```%]:`0`.````;EH!`!````!]6@$`%0```(Y:`0`7
M````I%H!``\```"\6@$`'0```,Q:`0`1````ZEH!`!(```#\6@$`"0````];
M`0`'````&5L!``H````A6P$`.0```"Q;`0`(````9EL!`!0```!O6P$`+P``
M`(1;`0`;````M%L!`!4```#06P$`%@```.9;`0`6````_5L!`!4````47`$`
M$````"I<`0`8````.UP!`!4```!47`$`'@```&I<`0`<````B5P!`!T```"F
M7`$`"@```,1<`0`'````SUP!``D```#77`$`$0```.%<`0`0````\UP!``4`
M```$70$`"P````I=`0`*````%ET!`!,````A70$`5````#5=`0`5````BET!
M``T```"@70$`!0```*Y=`0`(````M%T!`!H```"]70$`&@```-A=`0`:````
M\UT!``T````.7@$``@```!Q>`0`$````'UX!`"@````D7@$``P```$U>`0`%
M````45X!``H```!77@$`#````&)>`0`&````;UX!``8```!V7@$`#@```'U>
M`0`3````C%X!``<```"@7@$`"0```*A>`0`(````LEX!``4```"[7@$`!0``
M`,%>`0!7````QUX!``\````?7P$`$@```"]?`0`%````0E\!``<```!(7P$`
M(P```%!?`0`Q````=%\!``T```"F7P$`"0```+1?`0`/````OE\!``L```#.
M7P$`"@```-I?`0`4````Y5\!`"L```#Z7P$`&@```"9@`0`9````06`!`!``
M``!;8`$`!@```&Q@`0`&````<V`!``@```!Z8`$`!@```(-@`0`.````BF`!
M``X```"98`$`!@```*A@`0!,````KV`!`!(```#\8`$`#0````]A`0`+````
M'6$!`!8````I80$`1````$!A`0`'````A6$!``4```"-80$`!P```)-A`0`B
M````FV$!``@```"^80$`"@```,=A`0`9````TF$!`!H```#L80$`"0````=B
M`0`%````$6(!`",````78@$`20```#MB`0`0````A6(!`"<```"68@$`$```
M`+YB`0`%````SV(!``X```#58@$`"0```.1B`0`/````[F(!``H```#^8@$`
M!P````EC`0`3````$6,!``<````E8P$`"0```"UC`0`1````-V,!``H```!)
M8P$`"@```%1C`0`-````7V,!``<```!M8P$`$0```'5C`0`4````AV,!`!(`
M``"<8P$`#P```*]C`0`0````OV,!`!$```#08P$`$0```.)C`0`0````]&,!
M`!(````%9`$`"@```!AD`0`F````(V0!`!,```!*9`$`#0```%YD`0`-````
M;&0!`!<```!Z9`$`"0```))D`0`-````G&0!``8```"J9`$`"````+%D`0`&
M````NF0!``<```#!9`$`"P```,ED`0`2````U60!`!4```#H9`$`(0```/YD
M`0`?````(&4!`!@```!`90$`%@```%EE`0`<````<&4!`!X```"-90$`&@``
M`*QE`0`'````QV4!``<```#/90$`$@```-=E`0`0````ZF4!``X```#[90$`
M(P````IF`0`1````+F8!`!8```!`9@$`"0```%=F`0`/````868!``@```!Q
M9@$`$P```'IF`0`)````CF8!``<```"89@$`"````*!F`0`&````J68!``4`
M``"P9@$``@```+9F`0`E````N68!`"(```#?9@$`%P````)G`0`@````&F<!
M`#0````[9P$`#@```'!G`0`C````?V<!`"@```"C9P$`+0```,QG`0`M````
M^F<!`#(````H:`$`%````%MH`0`2````<&@!`!(```"#:`$`%````)9H`0`2
M````JV@!`!````"^:`$`$@```,]H`0`<````XF@!`"T```#_:`$`+0```"UI
M`0`Q````6VD!`"X```"-:0$`+P```+QI`0`L````[&D!`&`````9:@$`(```
M`'IJ`0`2````FVH!`!$```"N:@$`)````,!J`0`Q````Y6H!`!D````7:P$`
M#0```#%K`0!`````/VL!`$````"`:P$`"@```,%K`0`$````S&L!`!4```#1
M:P$`#@```.=K`0`2````]FL!`!@````);`$`"0```")L`0`(````+&P!``P`
M```U;`$`#````$)L`0`-````3VP!``H```!=;`$`#0```&AL`0`'````=FP!
M`"$```!^;`$`"0```*!L`0`'````JFP!`!$```"R;`$`$@```,1L`0`0````
MUVP!`#,```#H;`$``@```!QM`0`(````'VT!`!(````H;0$`"P```#MM`0`&
M````1VT!`!````!.;0$`!@```%]M`0`&````9FT!`"\```!M;0$`&````)UM
M`0`H````MFT!`%8```#?;0$`%P```#9N`0`C````3FX!`!(```!R;@$`"@``
M`(5N`0`-````D&X!`!,```">;@$`#````+)N`0`)````OVX!``P```#);@$`
M'P```-9N`0`7````]FX!``0````.;P$`$````!-O`0`1````)&\!`"4````V
M;P$`&````%QO`0`9````=6\!`!,```"/;P$`(0```*-O`0`)````Q6\!``<`
M``#/;P$`$0```-=O`0`)````Z6\!``H```#S;P$`"````/YO`0`-````!W`!
M``H````5<`$`!0```"!P`0`>````)G`!``8```!%<`$`%0```$QP`0`*````
M8G`!`!$```!M<`$`"P```']P`0`7````BW`!`"P```"C<`$`&P```-!P`0`,
M````['`!``T```#Y<`$`&P````=Q`0`&````(W$!`"L````J<0$`!@```%9Q
M`0`=````77$!``8```![<0$`"0```()Q`0`?````C'$!`#4```"L<0$`!@``
M`.)Q`0`6````Z7$!`!0`````<@$`!````!5R`0`'````&G(!``D````B<@$`
M"0```"QR`0`*````-G(!``D```!!<@$`"0```$MR`0`)````57(!`!L```!?
M<@$`-0```'MR`0`^````L7(!`!D```#P<@$`)P````IS`0`<````,G,!`#P`
M``!/<P$`&````(QS`0`4````I7,!`"X```"Z<P$`)@```.ES`0`'````$'0!
M``D````8=`$`"@```")T`0`+````+70!`!4````Y=`$`$0```$]T`0`I````
M870!`"````"+=`$`+@```*QT`0`S````VW0!``8````/=0$`%0```!9U`0`(
M````+'4!``@````U=0$`)````#YU`0`4````8W4!`!8```!X=0$`$````(]U
M`0`(````H'4!`!,```"I=0$`"0```+UU`0`0````QW4!``\```#8=0$`&```
M`.AU`0`J`````78!``P````L=@$`!P```#EV`0`'````078!`!X```!)=@$`
M%````&AV`0`&````?78!``L```"$=@$`#0```)!V`0`&````GG8!`!$```"E
M=@$`"````+=V`0`(````P'8!`!,```#)=@$`,````-UV`0!#````#G<!`!L`
M``!2=P$`)````&YW`0`:````DW<!``4```"N=P$`$````+1W`0`(````Q7<!
M`!````#.=P$`+````-]W`0`(````#'@!``\````5>`$`$P```"5X`0`6````
M.7@!``T```!0>`$`/````%YX`0`)````FW@!`"(```"E>`$`$@```,AX`0`6
M````VW@!`"P```#R>`$`"````!]Y`0`3````*'D!`!4````\>0$`"@```%)Y
M`0`3````77D!``@```!Q>0$`%P```'IY`0`<````DGD!``8```"O>0$`"```
M`+9Y`0`2````OWD!`!0```#2>0$`%@```.=Y`0`$````_GD!``@````#>@$`
M"P````QZ`0`.````&'H!``\````G>@$`$@```#=Z`0`2````2GH!``@```!=
M>@$`"0```&9Z`0`H````<'H!`!P```"9>@$`&@```+9Z`0`'````T7H!`!(`
M``#9>@$`!@```.QZ`0`.````\WH!`!D````">P$`)@```!Q[`0`+````0WL!
M``<```!/>P$``P```%=[`0`&````6WL!``@```!B>P$`!0```&M[`0`/````
M<7L!`!<```"!>P$`#0```)E[`0`=````IWL!`!T```#%>P$`&@```.-[`0`%
M````_GL!``L````$?`$`%````!!\`0`)````)7P!``T````O?`$`"0```#U\
M`0`,````1WP!`!0```!4?`$`5@```&E\`0`8````P'P!``<```#9?`$`!P``
M`.%\`0`'````Z7P!`!(```#Q?`$`$`````1]`0`1````%7T!`!L````G?0$`
M$P```$-]`0`5````5WT!`"0```!M?0$`$P```))]`0!B````IGT!`!L````)
M?@$`&@```"5^`0`I````0'X!`!L```!J?@$`&@```(9^`0`D````H7X!`!H`
M``#&?@$`&0```.%^`0`:````^WX!``H````6?P$`"0```"%_`0`+````*W\!
M``@````W?P$`%@```$!_`0`/````5W\!`!4```!G?P$`"````'U_`0!0````
MAG\!`$$```#7?P$`*````!F``0!/````0H`!`!L```"2@`$`*P```*Z``0`(
M````VH`!``H```#C@`$`$0```.Z``0`I`````($!``8````J@0$`30```#&!
M`0`E````?X$!`"$```"E@0$`$@```,>!`0`@````VH$!`!@```#[@0$`'```
M`!2"`0`?````,8(!`!X```!1@@$`(P```'""`0`4````E((!``8```"I@@$`
M"P```+""`0`-````O((!``D```#*@@$`*@```-2"`0`+````_X(!``P````+
M@P$`!P```!B#`0`1````((,!``H````R@P$`!0```#V#`0`6````0X,!``D`
M``!:@P$`"0```&2#`0`$````;H,!``X```!S@P$`&````(*#`0`.````FX,!
M``<```"J@P$`%0```+*#`0`>````R(,!`!````#G@P$`#````/B#`0`:````
M!80!`"@````@A`$`$0```$F$`0`1````6X0!`"8```!MA`$`!@```)2$`0`1
M````FX0!``8```"MA`$`"````+2$`0`&````O80!`!T```#$A`$`#@```.*$
M`0`2````\80!`!`````$A0$`!P```!6%`0`)````'84!``H````GA0$`#```
M`#*%`0`/````/X4!`!<```!/A0$`!@```&>%`0`2````;H4!``X```"!A0$`
M"0```)"%`0`.````FH4!`!@```"IA0$`#0```,*%`0`%````T(4!``0```#6
MA0$`!@```-N%`0`(````XH4!``@```#KA0$`5````/2%`0`T````288!`!D`
M``!^A@$`!P```)B&`0`'````H(8!``H```"HA@$`"@```+.&`0`'````OH8!
M``H```#&A@$`%0```-&&`0`,````YX8!``H```#TA@$`#````/^&`0`(````
M#(<!``P````5AP$`"0```"*'`0`'````+(<!`!@````TAP$`"P```$V'`0`'
M````68<!``H```!AAP$`)0```&R'`0`8````DH<!``<```"KAP$`"````+.'
M`0`*````O(<!``<```#'AP$`$P```,^'`0`3````XX<!``@```#WAP$`'```
M``"(`0`-````'8@!`!X````KB`$`"0```$J(`0`&````5(@!`!````!;B`$`
M%0```&R(`0`+````@H@!``T```".B`$`%P```)R(`0`'````M(@!``L```"\
MB`$`#P```,B(`0`.````V(@!``4```#GB`$`&````.V(`0`)````!HD!`!P`
M```0B0$`$0```"V)`0`S````/XD!`"8```!SB0$`(P```)J)`0![````OHD!
M`!0````ZB@$`/P```$^*`0`T````CXH!`$4```#$B@$`0P````J+`0`?````
M3HL!`&0```!NBP$`)@```-.+`0`S````^HL!`"H````NC`$`$P```%F,`0`8
M````;8P!`'T!``"&C`$`%P````2.`0`2````'(X!`#@````OC@$`@0```&B.
M`0`\````ZHX!`#<````GCP$`20```%^/`0!$````J8\!`!X```#NCP$`$P``
M``V0`0`8````(9`!`!D````ZD`$`)````%20`0`=````>9`!`",```"7D`$`
M%````+N0`0`;````T)`!`"$```#LD`$`%P````Z1`0`/````)I$!`#`````V
MD0$`6P```&>1`0`L````PY$!`%(```#PD0$`.0```$.2`0`C````?9(!`"8`
M``"AD@$`(P```,B2`0!'````[)(!`$<````TDP$`/0```'R3`0`\````NI,!
M`#````#WDP$`*@```"B4`0`J````4Y0!`"T```!^E`$`9P```*R4`0!E````
M%)4!`*L```!ZE0$`%@```":6`0`M````/98!`#$```!KE@$`,````)V6`0!)
M````SI8!`!X````8EP$`3@```#>7`0`6````AI<!``<```"=EP$`L0```*67
M`0!%````5Y@!`"@```"=F`$`,P```,:8`0`:````^I@!`!X````5F0$`+@``
M`#29`0`)````8YD!``@```!MF0$`!@```':9`0`.````?9D!``X```",F0$`
M$@```)N9`0`*````KID!``@```"YF0$`#````,*9`0`#````SYD!`&P```#3
MF0$`"````$":`0`0````29H!``4```!:F@$`!P```&":`0`%````:)H!``4`
M``!NF@$`!P```'2:`0`9````?)H!``@```"6F@$`%0```)^:`0`,````M9H!
M``4```#"F@$`!P```,B:`0`'````T)H!`!4```#8F@$`"@```.Z:`0`7````
M^9H!``8````1FP$`&P```!B;`0`/````-)L!``,```!$FP$`)@```$B;`0`$
M````;YL!``8```!TFP$`!P```'N;`0`B````@YL!`$$```"FFP$`*````.B;
M`0`J````$9P!`!8````\G`$`)P```%.<`0`@````>YP!`!\```"<G`$`(P``
M`+R<`0`>````X)P!`!L```#_G`$`(@```!N=`0`>````/IT!`"L```!=G0$`
M*0```(F=`0`K````LYT!`!\```#?G0$`(P```/^=`0`A````(YX!`!P```!%
MG@$`)@```&*>`0`G````B9X!`",```"QG@$`'@```-6>`0`<````])X!`"(`
M```1GP$`)0```#2?`0`=````6I\!`"4```!XGP$`)@```)Z?`0`Z````Q9\!
M`"$`````H`$`)0```"*@`0`C````2*`!`"0```!LH`$`'@```)&@`0`<````
ML*`!`"0```#-H`$`(````/*@`0`K````$Z$!`",````_H0$`"0```&.A`0`3
M````;:$!`!H```"!H0$`&@```)RA`0`:````MZ$!``H```#2H0$`$````-VA
M`0`9````[J$!`!(````(H@$`$P```!NB`0`B````+Z(!``@```!2H@$`"0``
M`%NB`0`D````9:(!`"<```"*H@$`+P```+*B`0`A````XJ(!``P````$HP$`
M^@```!&C`0`1````#*0!`!4````>I`$`"@```#2D`0`-````/Z0!`!0```!-
MI`$`'P```&*D`0`(````@J0!`#$```"+I`$`'````+VD`0`:````VJ0!``D`
M``#UI`$`%0```/^D`0`+````%:4!`$4````AI0$`+P```&>E`0`9````EZ4!
M`!0```"QI0$`%@```,:E`0`@````W:4!`!````#^I0$`$0````^F`0`2````
M(:8!`!L````TI@$`#````%"F`0`;````7:8!``D```!YI@$`&P```(.F`0`*
M````GZ8!`!P```"JI@$`"````,>F`0`C````T*8!``<```#TI@$`"0```/RF
M`0`)````!J<!`#$````0IP$`!P```$*G`0`0````2J<!`!0```!;IP$`$0``
M`'"G`0`+````@J<!``T```".IP$`"0```)RG`0`7````IJ<!``T```"^IP$`
M%@```,RG`0`2````XZ<!`!<```#VIP$`%0````ZH`0`)````)*@!``L````N
MJ`$`&0```#JH`0`$````5*@!`"H```!9J`$`#P```(2H`0`'````E*@!``4`
M``"<J`$`#````**H`0`2````KZ@!``L```#"J`$``P```,ZH`0`,````TJ@!
M``L```#?J`$`!@```.NH`0`2````\J@!``D````%J0$`$P````^I`0`4````
M(ZD!``X````XJ0$`*P```$>I`0`7````<ZD!`!8```"+J0$`#````**I`0`D
M````KZD!``8```#4J0$`$0```-NI`0!&````[:D!``\````TJ@$`#````$2J
M`0`'````4:H!``0```!9J@$`%````%ZJ`0`&````<ZH!``<```!ZJ@$`"```
M`(*J`0`&````BZH!``T```"2J@$`#P```*"J`0`%````L*H!`!X```"VJ@$`
M(@```-6J`0`:````^*H!`!T````3JP$`#P```#&K`0`"````0:L!``0```!$
MJP$`$````$FK`0`&````6JL!``<```!AJP$`!````&FK`0`0````;JL!`$<`
M``!_JP$`$0```,>K`0`I````V:L!`"0````#K`$`1````"BL`0`0````;:P!
M`&4```!^K`$`&P```.2L`0!8`````*T!`"X```!9K0$`%@```(BM`0`P````
MGZT!`#,```#0K0$`)`````2N`0`C````*:X!`"<```!-K@$`$P```'6N`0`P
M````B:X!`#````"ZK@$`%P```.NN`0`2`````Z\!`!0````6KP$`3P```"NO
M`0`3````>Z\!`&T```"/KP$`5````/VO`0`G````4K`!`!(```!ZL`$`&@``
M`(VP`0`4````J+`!`"(```"]L`$`&P```."P`0`:````_+`!`%P````7L0$`
M%@```'2Q`0`+````B[$!``8```"7L0$`!P```)ZQ`0`(````IK$!``H```"O
ML0$`&P```+JQ`0`6````UK$!`!H```#ML0$`)@````BR`0`1````+[(!``D`
M``!!L@$`!````$NR`0`.````4+(!`!````!?L@$`!P```'"R`0`(````>+(!
M`!L```"!L@$`#````)VR`0`+````JK(!`!$```"VL@$`"P```,BR`0`'````
MU+(!`!0```#<L@$`#@```/&R`0`7`````+,!``L````8LP$`#@```"2S`0`+
M````,[,!``4````_LP$`#0```$6S`0`&````4[,!``8```!:LP$`$0```&&S
M`0`"````<[,!``H```!VLP$`"````(&S`0`(````BK,!`"8```"3LP$`!@``
M`+JS`0`,````P;,!`!````#.LP$`#@```-^S`0`)````[K,!``D```#XLP$`
M!`````*T`0`0````![0!`!(````8M`$`!P```"NT`0`-````,[0!`",```!!
MM`$`"@```&6T`0`%````<+0!`!8```!VM`$`!0```(VT`0`"````D[0!``L`
M``"6M`$``0```!`#``"'`@``&@,``*L%````````'P(``$X!```U!```J`4`
M`$H"`````````````.<#````````D`0``*`!``"J`0```````,4"````````
M104```````"?!0```````&@$`````````````"D"```H`P``1P8``/0````O
M!@``,0(```,#`````````````/4````O!0``508``&4#````````;@,``!H!
M````````7`$```````"[````)@(``,P!````````9P0``'$$```\`0``NP$`
M``````#9`@``60(``",#``">`@``B@0``&$````````````````````S`P``
M``````````"I`P``OP0`````````````/@0``'X````^`0``^P``````````
M````*P,``.(%````````8````&$#``"F`0``JP(``.`$`````````````#H!
M```H!```T@(``-\%```2`P``600```````!R!@```````+,$```;`P``H04`
M````````````]@$```````",!````````$T$``!-!0``O`$`````````````
ME`4``.<%``````````````@"````````1P```%L$```R!``````````````I
M`````````+,!`````````0$``!T#````````6@8``*,```!)!0``D`(`````
M````````$P8``'\!````````_@$``)\#``!N!@``````````````````J0$`
M`(X`````````DP```&\$``#?!```&`0`````````````-@$``)L%````````
MS`(``($#````````'0(``"X!``""!```,P4``&,&````````SP4``.<!````
M`````````#<```!:````^00``*<"``!D`P``N0(```````"F`P``````````
M``"4`0``/P$``(D$``#'!```L@,``+P"````````X0```!D`````````6```
M````````````C@$``#,!````````O````#\$``"I`@``HP$```H"``"M````
M)08````````K!```E0````0"````````4@`````````M`````````$,&``!D
M`@``W`0``"T&````````MP,`````````````<@4``.X#``#"`P``````````
M````````````````````````?00```(!```,`P``/0(``)T#``"-!```````
M`)4!``#W`@``P0```$X%````````)@,``'P#``#M````A0$``/P"``#^`@``
M$@4````````*`0``L@``````````````LP4``,,"``!B!0``$P$``*X$``!(
M`@``3`0``,X````J!`````````@&```O````'@```%L&```F!0``=P,`````
M``#O`P``F04``-(!``#Z!0``1@4``-$!```0`@``.`8``%`"``"A`P``X04`
M`#(%```4`0``&`8``&D&```S!```C@,```($``!/!```6@0``(@"```V!0``
M1@,```("``!F!0``60,``%$&``!'`0``"P(``%,"```O!````````)(```#/
M`P``00$``/4$`````````````/X```"$````308``+<"```[`@```````,\!
M```&!````````-4#```%`0``VP0```````#1!0``P`$``'<%````````$0``
M`$X`````````S00``+H"````````1`8```D#````````*`(``'D%``"*`0``
M_P0``"T$```:!```704``.\"``!$`@```````*P!``!N`@``+P,``+P#```-
M!@``\P0``/P!``"C!0``O0(``(T!``"3!```8@(``#4#``!6`@``F`0``"($
M``"1`0``^````%8```#2!0``[0,``.4```#J````'@$``'8```![`P``5@,`
M```````R````>0```(4#``#X!```L`(``/(%````````G0$``&0````$`0``
MM@,``&4```#1````4`0``%D&```_````,@(``$L%``````````````````#3
M!```H`4````````&`P``J````'4#``#W!0``808``!P$``"3`@``4@0``!$"
M``"$`P```````"4```#_`P``````````````````(0,````````]!@``O04`
M`#<#```````````````````C`@``B04```L&````````W@```)L```!T````
M`````*0"```U`@``/@8```````!K!@``%08``$,"``"/`P``5P8``)X$````
M`````````&4&```?`P```````*X"```=`0``VP(``,`%```^`P``NP4``)``
M``#[`P``'@8```````#*`0``S``````````S`````````/,%``"N`0``````
M`-T%``!6`0````````````#4````+@8``)H`````````6P,``+@!````````
MA@(``)<$`````````````!P%``!4````#`0``.@```"O`@```````)($``!#
M`P``J04``+8"```\!```A00``'L`````````]@(``*4"``"$!```%@(``&P"
M``!"````Q`$```H&`````````````)8!````````700``#0"```@!0``````
M`!````!2`P```````*<%``!M`@``M`(``.D%``!_`P``.P0``%8$``!)`@``
M`````&,```!Q````20```,4!````````7````)L!``!T`@``;````/D!````
M````P`,``'<`````````\@0``&8!``"N!0``J@4``)X#````````>```````
M```\`@````````X%```!`P``4`$``$X$```Z!0``.@0```4#``!.!@``````
M`*(``````````````%,$``"-`P````````````#R`0```````/\%``"'`0``
MD`$``+$%``"+`P``(`````````#)`0``NP0``+0$``#+!0```````!\&``"=
M!0``7P(```````!O`@``9P$```````#>`@``C`````````#8`@``=`$``(P#
M``#R`@```````)H$``!G`P``1`0``/@!``#8!0````````(#``")````I0$`
M``````!K```````````````1!```+`,``!`$``#A`0``&`4```````"F`@``
M-P4``'X%``"^`P`````````$`````````````(X%``!@!```10```*L!``"+
M!```?````-<#``"V`````````&P!``"W````$`4`````````````OP,`````
M``!T!@``30(``.\$``"$`0``+`$````````T````Q`,``-$#````````,0,`
M`$@%``!3`0```````.X$``!O!0``W0$```,!```O`@``+````$<"````````
MZP(``!\!``#@`P``2@,``'("````````J@(``*T%``">!0````````H$``"_
M`@``%P8``&8"``!F`````````!8```"(`0``4P4``"4#``"T````0@0`````
M````````R`(``+4$```]````Y0,`````````````#`8``+`#``"2`P``U@``
M`$@$```9`@```````.0#````````*P(``)\!``#D!```%@8```````!L`P``
M#````+L"````````8@,``````````````````"P$```A````4@8``(D#````
M````"@,``&X!``"(`````````!<"``!1!0``#@`````````U````A0(`````
M``#D`@``;`4``'L$``!H````\0````````!X`0``\0(```````!<!0``E`0`
M`)P%``!(````W`4``-L````]!0```````/$$````````]P0````````8`@``
M6`,``%@%``"?````FP0```L$````````2@`````````O`0``DP$``"H%````
M``````````````"U!0```````*,"``"A!````````(T%````````7@8``'(!
M```\`P``V@,``.8%``!T`P``^P(``(,%``#C!````````"4"``!+`@``````
M`````````````````$4#````````_04``+@"```K````,0$``.T%``"7`@``
MI`4```````#.!```K`0````````.`@``B@(``"H#``#3`@```````/D%````
M`````````.,!``#$`@```````$L#```?!```WP```#8&``"]`0``4P8`````
M```````````````````1!@```````*@#```-`0``C`4``),#````````X`$`
M``````!@`P``7@$``,0%``"O`P``!P4``%T#``!5!```F@,```````!$`P``
M`````#H&``!D!@```````$T!````````#P$```\%``!'!```N@4``/,```#1
M`@``N0```!@#``#7`@``>@,``'P!```9`P``E`,``*\!``!=`0``3P```/(#
M``!X`@``8@8````````R`0``YP``````````````&P0```````"A`0````8`
M``````"S````F`$``/8#```````````````````9!```@P(```````!?`0``
M.`,``,L$```D!````````"<%``#V````^@```'8%``#R````M0,``,<#````
M``````````8&``#!`@``%00``%0$```Q!```8P,```````!<`P``7P```.D#
M``````````````````#+`@``U0```#,"``!``0``.`4``+H```!>````0`,`
M`,L```#@````[`0``-$$```H````\0,``(<#``!1`@``I04`````````````
M9@8``-@#``#5`0``*P$``.P%``!\!0``30,``!`!```@!@``.0(``,,%```>
M`P``8`$``&T%``"``P``8P$``(D"````````M0(``"<&``"]!````````)<%
M``!7!```````````````````G`(``&8#```T`P``%P```'@%````````$04`
M``````!R````(@,``,D"````````M`,``(@%``!Q`0``#0,``$<%``!:`P``
M`````!("``!&`@``)@$``"("``!0!0``IP````````"@`P``90$``.<$``#F
M`0``D0````````!J!```604``!0#```.`P``[````*<!```W`@``=0(`````
M````````<P$`````````````E@(```````#%!```R@,``(`"``!M`P``````
M`+`$````````<P8``/H"``!)!```30```.`"``!3````6P4``-(#```(`P``
M%@,```````"6!```W@4``,D```"C!````````.@"``"V`0````````````"\
M!```M0```(,```!G````5`8`````````````Y`4```````#-`0``50,``/P%
M````````.`0``%@"````````+@(``-X#``!^!``````````````@!```Q@$`
M`,`$``"L`@``U@0``+8$``#&````I`,``,T%``#S`0``(0$``,<%````````
M?0$````````M!0```````.(#```4`@``[`$``'4```#6`0``!P0``,D$``!4
M`0``0@$```````!;`0``J`(``!0`````````#`4`````````````+@``````
M```Z`@`````````````<`0``.@``````````````50(``'8"``"H`0``CP4`
M`$$#``!N!````````-T$```L!@``J@,``&\#```,`@``0P4``%X#``"2`0``
M20,``"8&```]`P``K@```&<%``#4`P````````````#T!0``S`4``"0"````
M````%`8``)$"````````J0```%<!``!A!```K0(```````#K`P``````````
M````````GP(`````````````I0````````"?!```V@$```0$```V`P``\`4`
M`+4!``#"!```]04``-8#``!6!0``K00``,$#``#8``````````X!``!Z!```
M`````$D!``#<`@````````````````````````````#&!0``D0,``%(!```_
M!0```````&`"````````X@$``%X$````````;`0``'`&```1`P``-@(``#``
M``"L````%@$````"``"Q````:@,``.$$````````,@,``",!````````<`,`
M`-,%`````````04````````C!````````````````````````!$!``!O`0``
ML````%P&``!U!0``%P,```````#3`0``X0(``+$"``!I`````P8``+P%```A
M!````````'@$``#0`0```````#P&``#B````IP,``.($````````MP$``)<!
M````````O@0``"@&``!`!```[00``!(```#E!`````````````#K!```````
M`)H"``````````````@$``#>`0````````````##!````````.L!``"N`P``
MXP```'`"``!,!@``'08````````6!0``D00``$H!``!S!```A`(``%4```#J
M`0````````````!R!```-P8``)D$``#J`P``+@0```,%``!'`P``7P0`````
M``"L`P``?@(``'L!``"Q!```?P```#D%``#&!```2`$``$("````````*08`
M`#8$``"*````[0$```````````````````````#H!0```````.8#```0!@``
MY04``($```#*!0````,``',#`````````P(``)`#``#_````2@0````````G
M````^P0``$$```"&`P``CP$``"0```"/````-@```,8"``!C`@``3`(``%4!
M``!Y`0``.`(``*L```![!0```````/T"````````3@,``),%``!M````]P,`
M`&\```#.`P``@0(``)@"`````````````#<!```-````SP```(4`````!0``
MH@0``%P$````````R0,``.P"``"8````*@(```\#`````````````%\&``#^
M!```&P8``+$#``"X````K0,``#D$```Z`P``VP4``+,#```%!@``S`0``+\`
M``#-````!P(``%$```#V!0``.P4```````"[`P``[P````````#N`@``>`,`
M````````````&0$```H%````````AP0``!,#``!_`@````````````"C`P``
M-`4``%4%```U!0``H@4```````!H`@``?`0``/\!```&````#@8``&4%``!R
M`P``````````````````ZP4``!H"````````&``````````M`@``:`,``%H!
M``!S!0```````%8&``#D`````@8`````````````2P8``,$$````````9P8`
M`+D$````````F`,``)P`````````)P$``$4$```'`0``PP$``$`&```$````
M@````'D"``!7````2`,```````"+`@``@@``````````````8@0```````#G
M`@``R````/4!```%!```40,``-4$````````B0$```8%``"6`P``@00``*\$
M````````C@0```````!M`0``QP$```D$``"^`0``+@4````````)!0``'@(`
M`&L"``"(!```70(``+0%````````!0````````!8`0``.0``````````````
MTP,``-0!`````````````*T!``#9`````````"D%``"4````=00``#$```#8
M`0``=P0````````;!0``:@(``,(`````````400``-<!``!!!@``H@(``"`#
M``!W`0``Z@(``/,#````````60$``-D$```D`P``]`,``(L```"^````````
M``L#``#/!```Z`0``"4%```;`0``R`,``$H&```Y`P``MP4``#0$``"6````
M.0$```````"+!0``<0,````````K!@``$P(``(\"``!(!@``60```$L!````
M````TP```",%``"O`````````"D#``!A`0``^`(``$D&```8`0``0@8``-T#
M````````10$```````"7`P````````````!1`0`````````````]`0``````
M`,$!``"D`0``A@```&0!``!`!0````````````!4`@``4`8``*D$``"*`P``
M``````````#9!0``C0````````!,`0```@4``#P`````````8`8``,,#``#.
M`@```````)H!````````JP0``%<%``!B`0```````/P#``"P`0``T@```+H!
M``#(!0``OP4``%T&``#I`````````!T$``!M!`````````````!4`P``````
M``\&``"4`@``I`0``&L%````````(08``+H$````````>@```/D"``!J!0``
MW0(``/4#````````1````(L!``"5!0``;08``(,$``"S`@```````)<```!!
M!````````)T$``"5`@``C`(``((%``#Z!`````````````!4!0``T`,`````
M``#H`P``"P4```````"#`P``UP```#L!````````F0,``"(&````````````
M`/<!``#O!0``:@$``,(%``"_`0``:@8``&$%```7!`````````````#F````
M;P8```4"``!Q!0``1@$``#@!````````[@4``+("``````````````````!U
M`0```````#<$````````@`4``#0&````````<`$``%@&``"X`P```````$X"
M```X````"0$``,4%`````````````+<$``!Y`P```````(`!``!,!0``!P,`
M`($%``!S`@``P04```````````````````````#]`0``Y@0```````!A`@``
M+@,``$\"``"Q`0``^P4```````"<`P```````%@$``#M`@``V@4``'8$``#0
M!```004``&@&``#-`P```````````````````````.,"``!Q`@``%`0``&X%
M``"A`@``3P8``,<"``"F!````````'T"``#9`P``:`$```````#6!0``````
M`&@%``!,````%0```)("```!!```I@4````!```P`@``[@$``-`"``"A````
MQP```!X$``!7`@``*`$``/H!``````````````@!```2!@```````)@%```:
M````H@,``'H%``#<`P``/@4``-D!``#+`0``&P(``.P#```P!@```````.,%
M`````````````,0$```B`0``R@0``-\"``!^`0``*P4```````!=````_0``
M`-<$``!]!0``O@(```X$```Q!@``?P4``!4!``"X!0``A@$```0#``#*````
M"P```)(%``"-`@``'P```/@#``#P`@```````'D$````````!P```,H"````
M````A@4``(<%``#@!0``4@4``!P```";`@``U@(``+D%``"9````.P8``%P"
M``!T!```1@```````````````````#D&``!W`@``J`0```````!P!```J@0`
M````````````(`(``!T%``!&!@```````/4"```_`P``E00`````````````
M``````````"P!0``-08``'\$``#D`0``V@```/0!```:!0``>@$``+0!``#;
M`P``Z0$```````"`!```Q````((!````````/P8```D&``!K`0``U04`````
M``"L!0```````(("```!!@``#P0````````;``````````4%```+`0``````
M`*4#````````.P,``/T$``#H`0``,`,``$,$``#4`@``'`,``-\#```*````
MJP,``/`!``!K`P```````&D!``#:`@``U`0```$"```9!@``S0(``"D!````
M`````````"`!````````)@0``&<"``#]`P``VP$``(H%``!/`0``S@$`````
M``#N````V@0````````)`@``=@,``$8$````````L@0``$\#```&`@``9@0`
M`!($``">`0```````%<#``"Z`P``/00``"<"````````(@4``/X%````````
M\`,``!T```!P````900``,8#````````0P$```T%```$!@```````(\$``!B
M````2P0```````"R`0``Z0(``/0"``!$!0``4````-($````````#0(```D`
M``!;`@``$P```+(%````````:0,``#0!```<`@``F0(```<&``!N````````
M`#X"``#Y`P``$P0``"4$``"@`@``3`,``!D%````````Z@0`````````````
M\04```````#E`0``ZP````(`````````%P4``'L"``#B`@``)P,``*H```"5
M`P``R`$```````"^!0``]P```$\%```5!0``4`,``"H```"]`P```````(8$
M``````````````````#0````WP$``"0&````````.P````````"=`@``(P``
M`"$"````````4P,``"H&``#"`@``N`0``!<!``"$!0``(@```'8!``#Z`P``
MN0,``&D"``":!0``<`4``/8$``#P!````````,4#````````)0$``$(%```P
M!````````````````````P````````";`P``P`(``"$%```R!@``)@```'T#
M``!D!``````````````(!0``B`,``````````````````*8```#_`@``````
M`$0!``!>!0``>@(``/@%```C!@``U`4``)P!```S!@```````&,$``!!`@``
M`````(,!``"G!`````````T$``!:!0`````````````6!```,04`````````
M````%`4``,L#``!``@``0````)$%```(````F0$``!4#``!?`P``\`````,$
M``#=````^0```$4&``!C!0``I````,X%``",`0``*00``*\%``#\````N0$`
M`,\"```3!0``Q0`````````/````=`4``+8%``#0!0``)P0`````````````
M`````,````!D!0``!`4``)T```#)!0``:04``#4!``!J````Y@(````````&
M`0``W@0``.,#``#\!````````"H!``!E`@``,`4``#`!```>!0``4@(``.D$
M``!Q!@``Y0(``)P$``!]```````````````<!@``]`0``,(!``">````<P``
M`%L```!?!0``_@,```````#5`@``W````.\!```/`@``/`4``-@$```_`@``
MC@(``!\%````````?`(``%H"```L`@``\P(```````#A`P``)`$```````##
M````+`4``!(!``!*!0``7@(``$(#``""`P``#`$`````````````H```````
M``#(!```S`,``$4"`````````````"T!``"0!0``Z@4``$L`````````````
M`"T#````````O0```)8%````````W`$``'X#``"%!0```````&P&```5`@``
M*`4``"0%``"B`0``\0$```````"@!```UP4``(<````^````8`4``&D$``"E
M!````````!H&``!#``````````````#[`0``:P0``($!```````````````@
M*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AT;V1A>2D`("AY97-T
M97)D87DI`"!A="``)60@)7,@86YD("5S`"5D+61A>2!F;W)E8V%S=``E<R`M
M($YO=&EC90`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/
M<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-I9VX@57``)7,@5&5R;7,@
M;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E
M<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@
M)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S
M($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`+"!G=7-T:6YG("5S("5S
M`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`,3(@2&]U
M<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`02!D871A8F%S92!B
M86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R
M<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D
M('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E
M<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!0
M1U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME
M>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R
M:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P
M<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E
M<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!3:&]W97)S`$%-+U!-
M`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`
M06)S;6ED9&QE`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R
M>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!0
M87-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($-H
M:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@
M3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!N97<@=7-E<CH`
M061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H92`E
M<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T;R!A9&1R97-S(&)O
M;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D:6YG('5S
M97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES
M=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES
M=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S
M`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S
M`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L
M;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R
M960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,
M;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5
M<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M
M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;65R:6-A;B!386UO80!!;B!I;&QE
M9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N9&]R<F$`06YG;VQA`$%N9W5I
M;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC80!!;G1I9W5A
M(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N(&ES(')E861Y
M+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<')I;`!!<F%B:6,@
M*%=I;F1O=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE
M`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R
M97%U97-T(&9O<B`E<R`_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!
M4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R
M=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E
M9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT
M(&-O;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O
M=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I
M;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N
M+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I
M8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!2
M97%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z
M($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`
M075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U
M=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M
M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@
M)7,`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I
M;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)
M55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE
M9"X`079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`
M0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S
M=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`
M0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E
M;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU
M=&%N`$)I<G1H9&%Y`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!"
M;VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R
M9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T
M=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N
M(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL971E
M9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),($1I<W1R
M:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#86QE;F1A<@!#
M86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@
M875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A
M;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;F%D80!#86YC96P`
M0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B
M+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P
M<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T
M(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI
M;&1R96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE
M<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@
M<W1O<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M
M8F5R+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%T96=O<FEE<R!A;F0@3&%B96QS
M`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E
M;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L
M;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L($%F
M<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`
M0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%D
M`$-H86YG90!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P
M;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL
M<RX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EL90!#:&EN80!#:&EN97-E(%-I
M;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`
M0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO
M=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF
M;W(@;W)D97)E9"!L:7-T<RD`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I
M;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@35-/9F9I8V4@
M=&%G<P!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R
M(&1A=&$`0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#
M;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L
M86YD<P!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!0
M:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O
M;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M
M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T97)S`$-O;F1I=&EO;G,`0V]N9FEG
M=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S
M=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@
M=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O
M;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N
M;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S
M;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`
M0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R
M97-S(&)O;VLN`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;V]K:64`0V]P>0!#
M;W!Y('-E;&5C=&EO;@!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@
M;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@<VEG;B!M
M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U
M;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N
M=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD
M(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`
M0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE
M=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@
M92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R
M97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I
M;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F
M(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@
M:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@)7,N`$-O
M=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD
M(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O
M<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A
M:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U
M;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S
M<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N
M("5S`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`
M0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V
M92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C
M;VYF:6=U871I;VXN`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R
M+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO
M>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN
M`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!A
M(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E
M871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)O871I80!#
M=6)A`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%=E871H
M97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ
M92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE
M8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD
M;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!2
M97!U8FQI8P!$1`!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&4`1&%T92!2
M96-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C
M96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A=6QT
M($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F:6YI=&EO;G,`1&5L971E`$1E
M;&5T92!'<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E
M(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X
M:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@<F]W`$1E;&5T92!S
M96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E
M;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L:79E<GD@=&EM90!$96YM87)K`$1E
M<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@
M:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT
M`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T
M:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER
M96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS
M`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S
M:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(&YO="!D96QE=&4`1&\@
M;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&]E<R!T:&4@
M9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H
M96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]W
M;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-
M86EL`$524@!%8W5A9&]R`$5D:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D
M:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO
M;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@
M9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN
M`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@
M;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N<P!%;7!T
M>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%
M;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE
M<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%
M;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T
M:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E
M<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@
M>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5Q=6%T;W)I
M86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@=VET:"!E;6%I;"!M97-S
M86=E+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@
M;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R
M>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y
M(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP96-T
M960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E
M<FT`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO
M860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A
M:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N
M;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N
M`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W
M(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I
M<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&
M87@`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E
M<G,`1FEJ:0!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I
M;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL
M92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`
M1FEN;&%N9`!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L
M:7``1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O
M;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G
M97,`1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H
M92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H
M=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E
M(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&
M;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R
M9',`1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5N
M8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E
M<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L
M;"!-;V]N`$9U;&P@3F%M90!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA9V4@
M9G)O;0!'86QL97)Y.@!'86UB:6$`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO
M;@!'96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L
M=&%R`$=I=F5N($YA;64`1V\`1V]E9&5L`$=O;V=L92!396%R8V@`1W)A>7-C
M86QE`$=R965C90!'<F5E:R`H25-/+3@X-3DM-RD`1W)E96YL86YD`$=R96YA
M9&$`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N
M;VXM96UP='D`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E
M<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN
M96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S
M97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@
M=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A=&EO;B!N;W0@
M9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE87)D
M($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96)R97<@*$E33RTX.#4Y
M+3@M22D`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE
M;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(
M:6=H`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO;64`
M2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO
M<F1E`$AO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E
M<F5D(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R
M<F5S<&]N9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@
M;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3
M=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@
M:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@
M97AT96YS:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!8
M34P@=')E92!F;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<F5M;W9E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T
M<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+
M;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D
M92]+;VQA8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(
M;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T
M(&AE<F4_("A0;&5A<V4@<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L
M9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS
M*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@
M;65R9V4_`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`
M24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X
M(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T
M:6]N(&9A:6QE9#H@)7,`25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I
M;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO
M8VLN`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E
M`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`261E;G1I='DG
M<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@
M=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!S964@=&AI<R!M
M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P
M;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!);6%G
M92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A
M;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S
M`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@
M9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T:6]N(&-O
M9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N
M`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y
M(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N
M965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA`$EN9&EV
M:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M871I;VX`26YS97)T
M($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L90!);G-E
M<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE
M=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C
M;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W
M(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E9F]R
M92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H
M92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@
M8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T
M(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H
M92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R="!C96QL
M(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@8F5F
M;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F=&5R`$EN
M<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`26YS97)T
M(')O=R!B969O<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE
M('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R
M="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@
M=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!)
M;G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED(%5$2"X@*%5S97(@1&%T82!(
M96%D97(I+@!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$
M+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N
M(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!M<V=?='EP
M92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S
M:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN
M=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@
M<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O
M<GD`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L
M92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L
M:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M
M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T
M:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@
M4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B97)O
M<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.97=B
M:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+
M97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO8W)A
M=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+
M;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,86YG
M=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T($AA
M;&8`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`
M3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V
M:6$`3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N
M;VX`3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QI8F5R
M:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT
M($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A
M:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU
M;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI
M;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@
M=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@
M0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A
M=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C
M:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,
M:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@=7-E<G,@
M:7,@9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`
M3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`
M3&]G(&]U=`!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R
M('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY
M+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E
M:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M
M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O
M;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R
M;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I
M;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA
M;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I
M97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A
M<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA
M<%%U97-T(&UA<`!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N
M(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O
M06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN
M9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E
M9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S
M="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@
M;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!M;V1E
M.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S
M<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T
M(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-
M971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R
M(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&AO9`!-971R:6,`365X:6-O
M`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@
M5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V
M(&AO=7)S.B``36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A
M8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO
M=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@
M=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG
M(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@
M240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D
M:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-
M;VYG;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O
M;B!0:&%S97,`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-
M;W-T;'D@4W5N;GD`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO
M=F4@57``36]V92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E
M;"!D<F]P(&1O=VX@;&ES=',`375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U
M;G0`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@22!$
M;R!.3U0@06=R964`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE<FQA
M;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE
M='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!5
M4DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!5
M4DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC
M871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K
M`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-;V]N`$YE
M=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!W:6YD;W<@
M*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="!O<'1I;VYS`$YI
M8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@879A:6QA
M8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O
M<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E
M<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@
M<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@
M9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R
M96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-1
M3"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA
M=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!L;V-A=&EO;B!I
M<R!S970N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D
M+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H
M96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O
M=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R
M:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!R
M=6QE<P!.;R!S:61E<P!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L
M92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT
M+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R
M<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`
M3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F
M;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA
M;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@
M9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R
M=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB
M97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU
M;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@
M=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE
M8W0@0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC
M90!/;6%N`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E
M<G,N`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D
M9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN
M:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES
M<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;G,@
M=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P
M=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO
M;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P
M;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/
M=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N<P!004T@
M875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$=0($1I9VET86P@
M4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!0
M1U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!0
M32!,:6=H="!286EN`%!-(%-H;W=E<G,`4$T@5"U3=&]R;7,`4%](4"!3:&5L
M;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R
M>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`
M4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!I;F-O<G)E8W0`4&%S
M<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S
M<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``
M4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O
M87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F
M;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC
M92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VYS
M($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T
M<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L
M871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C
M;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`
M4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E
M;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A
M<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@
M96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI
M9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H
M+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O=FED92!A
M('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@
M=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!T>7!E('1H92!N97<@8V%T
M96=O<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O
M<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T
M86)L90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!
M4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E9G-?
M;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F
M<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E
M.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`
M4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E($ME>0!0
M<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T('1E
M>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,O4')I
M=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R
M=&\@4FEC;P!1871A<@!1=65R>0!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2
M861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN
M(%-H;W=E<@!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@;65S<V%G
M97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E
M('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_
M(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E<R!Y;W5R
M(&QA<W0@86-T:6]N`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2
M969R97-H(%!O<G1A;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O=W-E
M<@!296UA<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W
M=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E
M;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M
M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E
M8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D
M;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S="!C
M;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5S
M970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-U;'1S
M`%)E='5R;B!T;R!/<'1I;VYS`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I
M;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG
M:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L
M90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT
M`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U
M;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@
M=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D
M97)A=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E
M`%,O34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N
M(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,(%-H96QL`%-3
M2`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI
M='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD($UI
M<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A;64@
M9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N9"!0
M<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA`%-A=F4`
M4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A
M<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!38VEE;F-E
M`%-E87)C:`!396%R8V@@16YG:6YE<P!396QE8W0@1FEL97,`4V5L96-T(&$@
M9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R
M`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@
M86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@
M=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N
M(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E
M>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H
M92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T
M;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T
M:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!3
M96QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YE
M9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`
M4V5R:6%L($YU;6)E<@!397-S:6]N($E$(&5X<&ER960N`%-E=`!3970@;W!T
M:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y
M;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T
M('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U
M<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO
M;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M
M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS
M+@!3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C
M871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL
M97,`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@
M8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&1I9F9E<F5N
M8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N
M97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H
M96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3
M:&]W('!I8VME<@!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H
M;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E
M;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE
M<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G
M`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D
M`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAR:6YK`%-H
M<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE
M('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`4VEG
M;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT96YA
M;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<@4VAO=V5R`%-N;W<@9&5P=&@Z
M(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`
M4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O
M=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/
M+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H
M($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D
M:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R
M(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3
M<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`
M4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T86YD
M87)D`%-T87(@5')E:P!3=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T
M871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O
M=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S
M`%-T>6QE(%M#4U-=`%-U`%-U8FIE8W0`4W5B;6ET`%-U8G-C<FEP=`!3=6-C
M97-S`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO
M860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@
M8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U
M;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O
M4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`
M4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@36%Y
M96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>6YT87@@97)R;W(@
M:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M4W1O<FT`
M5"U3=&]R;7,`5%-6(&9I;&4`5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!486)L
M92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA
M`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G
M970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R
M.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP;&%T92!!9&UI;FES
M=')A=&EO;@!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`
M5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AA;FL@>6]U(&9O<B!U<VEN9R!T
M:&4@<WES=&5M+@!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE
M+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T
M('-U<'!O<G0@(B5S(@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T
M(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO
M<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF
M:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@
M=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY
M`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE
M(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E
M<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@
M<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I
M<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@
M;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@
M9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R
M>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I
M;VXN`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`
M5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`
M5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F
M:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@
M:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@
M9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W
M:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H
M870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@
M97AP97)I96YC92!G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U
M;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO
M=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T
M('EO=2=L;"!G970@82`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@
M;F5E9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE
M87-E('!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L
M;"!S8W)E96X@961I=&]R+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D
M96QE=&5D+@!4:&4@;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@
M;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP
M=%]P9W`Z.B!C;&%S<RX`5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W
M:71H('-U8FIE8W0@(B5S(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@
M;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O
M<B!U;F1E<G-T;V]D+@!4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O
M('1H92!C;VUP;W-E('!A9V4`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I
M<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R
M969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@
M9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@
M<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@
M;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!R:6=H="!A;F0@;&5F="!S
M:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5R=F5R
M("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B
M965N('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N
M(')E;6]V960N`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+@!4
M:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL
M>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO
M=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D
M+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE
M<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R
M=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O
M;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT
M97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@
M)7,N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@
M;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY
M('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L
M87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE
M9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P
M97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I
M;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T
M<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI<R!)
M34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`
M5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV
M92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL
M92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB
M97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H
M:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V
M:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O
M;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL
M(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N
M:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A
M(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H
M:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M
M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA
M="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A
M9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA
M8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W
M:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE
M($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E
M;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@=V%S
M('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y
M;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H
M:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S
M+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@
M=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C
M86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME=',`
M5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N
M`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L
M96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#
M*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`
M5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG
M80!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`5')I;FED860@
M86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U
M<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I
M8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN
M9&5X.B``55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S
M(')E<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@
M5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R
M;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M
M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E
M('1O("5S+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B
M;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I
M;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B
M;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@
M5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N
M86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S
M(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE
M=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E
M8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N
M86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93
M(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT
M(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T
M86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA
M8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E
M<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E
M8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N
M(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N
M`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA
M=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL
M92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL
M960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YD97)L:6YE
M`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X
M<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FEC
M;V1E("A55$8M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D
M;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG
M($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@
M365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E
M($E$*2X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H
M92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T
M<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL
M>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E
M8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H
M;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N
M`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D
M871E("5S`%5P9&%T92!U<V5R`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P
M;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@
M=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N
M=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E(&EF
M(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`
M57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M:6YI
M<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@
M4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N
M`%5S97)N86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S
M>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES
M="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!6
M86QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU97,`5F%L
M=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA
M`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@
M8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!6
M97)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y
M($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)*0!6:65W("5S`%9I
M97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L
M86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y
M`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!
M4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!786QL
M:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A
M=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET
M90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E
M<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T
M97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y
M(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R
M/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H:6-H('!H87-E<P!7
M:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET
M;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@
M;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN
M*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`
M5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=O<FL`
M5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`6"U2968`6#4P.78S($)A<VEC($-O
M;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P.78S(%-U
M8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@261E
M;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA:&]O(2!M87``
M665A<FQY`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&%R92!I;B!415A4
M($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O
M(%=94TE764<N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C86X@
M;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N
M`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U
M(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE
M('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA=F4@
M8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E
M;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@
M)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U
M(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG
M=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU
M<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T
M:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE
M<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@<V5R
M=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M
M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D
M9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9
M;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M
M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U<B`E<R!S97-S:6]N
M(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@
M061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`
M66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B
M96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@
M<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U
M<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES
M=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@
M9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T
M;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S
M('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@
M;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H
M:7,@9F5A='5R92X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A
M=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!N97<@<&%S<W=O
M<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R
M9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN
M('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<F5M;W1E('-E<G9E<G,Z
M`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M(:61E
M(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!4
M97AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@
M;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?0TQ)`%]$871A5')E90!?1&5L971E
M(%)O=P!?1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN`%],;V<@
M:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S
M:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P97)T:65S
M+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`8V%L96YD87(`8V%L;0!C;&EC:R!H
M97)E`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&@Z
M`&EM;65D:6%T90!I;FQI;F4`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E
M9"!W:&EL92!M86MI;F<@25-/+@!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@
M>65T(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P:7AE;',`<FES:6YG
M`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-T96%D>0!T
M87-K(&QI<W0`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U
M;FEF:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC
M;VT`4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`M8W9S"E)E<&]R="U-
M<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO
M;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T
M93H@,C`P-"TQ,2TR.2`Q,CHU,BLP,C`P"DQA<W0M5')A;G-L871O<CH@5FEL
M:75S(%-U;7-K87,@/'9I;&EU<T!L;FLN;'0^"DQA;F=U86=E+51E86TZ($QI
M=&AU86YI86X@/'9I;&EU<T!L;FLN;'0^"DU)344M5F5R<VEO;CH@,2XP"D-O
M;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ,PI#
M;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"@`@*'!R:67P("5S(&1I
M96YA<RD`("AM>6=T=6MA<R`E<RD`("CP:6%N9&EE;BD`("AV86MA<BD`(``E
M9"`E<R!I<B`E<P`E9"UD:65N^"!P<F]G;F]ZZP`E<R`M('!A<W1A8F$`)7,@
M86YT<W!A=61A<P`E<R!+0@`E<R!P<F]F:6QA:W1I:V]S('9E:6MS;6%I("T@
M<&%T=FER=&EN:6UA<P`E<R!R96=I<W1R86-I:F$`)7,@;G5O<W1A=&]S`"5S
M(&IA=2!E9WII<W1U;VIA+@`E<R`E<R`E<P`E<R!Y<F$@<')I=F%L;VUA<P`E
M<R!M:6YU=.MS`"5S(&YE<F%S=&%S+@!N=6\@)7,@:6MI("5S(&GP("5S`"5S
M(&%D<F5S^"!K;GEG96SK`"5S(&MA;&5N9&]R:75S`"5S('7^<F'P^"!K;GEG
M96SK`"5S(&1A<F+X('/@<F'P87,`)7,Z("5S`"P@9_MS:6%I("5S("5S`"P@
M:VEN=&$@;G5O("5S(&EK:2`E<P`M+2!P87-I<FEN:VET92`M+0`Q,B!V86QA
M;F3X(&9O<FUA=&%S`#(T('9A;&%N9/@@9F]R;6%T87,`,C0@=F%L86YD;W,`
MT&EA;2!B;&]K=6D@<F5I:V%L:6YG82!V:65T82!D=6]M96[X(&)A>NMJ92X`
MP79Y:V\@<FEM=&$@:VQA:61A`$YO<NMD86UI('7^:V]D=6]T:2!L86GP:^`@
M<')I=F%L;W1E('1U<NMT:2!V:67PX&KA(%!'4"!R86MTX"X`3F]RZV1A;6D@
M<&%T:6MR:6YT:2!P87-I<F'P>73@(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I
M('9I9?#@:N$@4$=0(')A:W3@+@!.;W+K9&%M:2!A=&MO9'5O=&D@;&%I\&O@
M('!R:79A;&]T92!T=7+K=&D@=FEE\.!JX2!I<B!S;&%P=.!JX2!01U`@<F%K
M='5S+"!B96D@_FEN;W1I('-L87!TX&K@(&9R87KF+@!.;W+K9&%M:2!P87-I
M<F'P>71I(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I('9I9?#@:N$@:7(@<VQA
M<'3@:N$@4$=0(')A:W1U<RP@8F5I(/YI;F]T:2!S;&%P=.!JX"!F<F%ZYBX`
M3F]RZV1A;6D@871K;V1U;W1I(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I('9I
M9?#@:N$@:7(@<VQA<'3@:N$@4R]-24U%(')A:W1U<RP@8F5I(/YI;F]T:2!S
M;&%P=.!JX"!F<F%ZYBX`3F]RZV1A;6D@<&%S:7)A\'ET:2!L86GP:^`@<')I
M=F%L;W1E('1U<NMT:2!V:67PX&KA(&ER('-L87!TX&KA(%,O34E-12!R86MT
M=7,L(&)E:2#^:6YO=&D@<VQA<'3@:N`@9G)A>N8N`$YO<NMD86UI('7^:V]D
M=6]T:2!L86GP:^`@<')I=F%L;W1E('1U<NMT:2!V:67PX&KA(%,O34E-12!R
M86MTX"X`04T@<F]D>6UA<P!!32]030!!4$D@240`07!I92#PX2!R961A:W1O
M<FGX`$%P:64N+BX`5FES:?!K86D@87!AZ&EO:F4`5FES:?!K86D@<&5R('9I
M9'5RX0!3:7-T96UA(&YE='5R:2!T96ES:?@@<W5K=7)T:2!61E,@:V%T86QO
M9^`N`%-I<W1E;6$@;F5T=7)I('1E:7-I^"!S=6MU<G1I(%9&4R!F86ELX"X`
M4VQA<'1A_F]D:7,`4^!S:V%I=&$@=?[P86QD>71A+@!!<'-K86ET80!3=6MU
M<G1I`%-U:W5R=&D@<&]G<G5PX0!3=6MU<G1I('!O=&5I<V5S`$)L;VMO(.%T
M97)P:6UA<SH`4W5K=7)T:2!N875JX"!G<G5PY@!3=6MU<G1I(&YA=6IA<R!T
M96ES97,`3F%U:F\@=F%R=&]T;VIO('-U:_MR:6UA<SH`4')I9.MT:2!S='5L
M<&5LX0!.875J^"!N87)I^"!P<FEDZVII;6%S`%-U:W5R=&D@<&]RX`!0<FED
MZW1I("5S(&UE;FEU('!R:64@36]Z:6QO<R#A<F%N:VGX(&IU;W-T;W,`P71R
M875K=&D@X2!A9')E<_@@:VYY9V5LYCH`P71R875K=&D@X2!M86YO(&%D<F5S
M^"!K;GEG96SF.@!3=6MU<G1I('9A<G1O=&]JX`!687)T;W1O:O@@:_MR:6UA
M<R!I\&IU;F=T87,N`$%D<F5S87,`061R97-A:0!!9&UI;FES=')U;W1I("T@
M9V%L:2!N=7-T871Y=&D@=&5I<V5S(&MI=&EE;7,@=F%R=&]T;VIA;7,`5F%L
M9'EM87,`0F%N97)I86D`069G86YI<W1A;F%S`$%L8F%N:6IA`$%L_GER87,`
M4')A=F%R9.L`3'EG:75O=&D`3'EG:6%V:6UA<SH`5FES;W,`5FES:2!P<FES
M:6IU;F?F('9A<G1O=&]J86D`5FES;W,@9W)U<.MS`%9I<V]S('1E:7/K<P!6
M:7-O<R!K971U<FEO<R!P=7/K<P!,96ES=&D@:V5L973@(&%D<F5S^`!,96ES
M=&D@;F%U9&]T:2!S=7+[\&EU;W3@('/@<F'PX#\`2F%U(&5G>FES='5O:F$`
M06QT97)N871Y=G5S($E-4U`@<')I<VEJ=6YG:6UA<P!!;'1E<FYA='EV=7,@
M24U34"!S;&%P=&'^;V1I<P!!;'1E<FYA='EV=7,@24U34"!V87)T;W1O:F\@
M=F%R9&%S`$%L=&5R;F%T>79U<R!E;"X@<&'P=&\@861R97-A<P!!;'1E<FYA
M='EV^W,@\&%B;&]N86D`06QT97)N871Y=G5S('1E:W-T87,`06UE<FEK;W,@
M4V%M;V$`P79E9.MT92!N96QE:7-T:6[@(')E:6OP;>8N`$%N9&]R80!!;F=O
M;&$`06YG:6QA:0!!;F]N:6UI;FES('!R;WAY('-E<G9E<FES`$%T<V%K>6UA
M<P!!;G1A<FMT:61A`$%N=&EG=6$@:7(@0F%R8G5D80!-;V1U;&ES`$UO9'5L
M:7,@=F5I:VEA(&=E<F%I+@!0<FET86EK>71I(&ER('!O\&%K:6%M<P!0871V
M:7)T:6YT:0!"86QA;F1I<P!!<F%B:?!K82`H5VEN9&]W<RTQ,C4V*0!!<F-H
M>79O(&9A:6QO(&1Y9&ES`$%R8VAY=F\@9F%I;&\@<&%V861I;FEM87,`07(@
M=&EK<F%I(&YO<FET92!I\'1R:6YT:2`E<R!R96=I<W1R86-I:F]S('!R8?!Y
M;>`_`$%R9V5N=&EN80!!<FWK;FEJ80!!<FWK;FGP:V$@*$%235-#24DM."D`
M365N87,`07)U8F$`2W)I<W1A=7,@_F5N9VEM;R#A(&1A;F?X('-A;&$`06-S
M:6D@;65N87,`07II:F$O4F%M:6]J;R!V86YD96YY;F\@<F5G:6]N87,`07(@
M<')A\'ET:2!P871V:7)T:6YT:2!P<F]F:6QA:W1I:V]S('9E:6MS;75S/P!0
M<FES:WER:6UO('-T=6QP96QI86D`0F%N9&]T92!I\'1R:6YT:2!N965G>FES
M='5O:F%NZ&G@(&=R=7#F+@!"86YD;W1E(&GP=')I;G1I(&YE96=Z:7-T=6]J
M86[H:6%S('1E:7-E<RX`0F%N9&]T92!R961A9W5O=&D@;F5E9WII<W1U;VIA
M;NAI87,@=&5I<V5S+@!"86YD;W1E(')E9&%G=6]T:2!N965G>FES='5O:F%N
M=.$@96QE;65N=.`N`$%T<FEB=71A:0!2=6=P:OMT:7,`075S=')A;&EJ80!!
M=7-T<FEJ80!!=71H7V-Y<G-Q;#H@;F5R87-T87,@<F5I:V%L:6YG87,@24U!
M4"!M;V1U;&ES+@!!=71H7V-Y<G5S.B!C>7)U<R!N971U<FD@<F5I:VEA;?@@
M9V%L:6UY8FGX+@!!=71H7V-Y<G5S.B!N97)A<W1A<R!R96EK86QI;F=A<R!)
M34%0(&UO9'5L:7,N`$%U=&A?9G1P.B!N97)A<W1A<R!R96EK86QI;F=A<R!&
M5%`@;6]D=6QI<RX@4W5K;VUP:6QI=6]K:71E(%!(4"!S=2`M+65N86)L92UF
M='`N`$%U=&A?:6UA<#H@;F5R87-T87,@<F5I:V%L:6YG87,@24U!4"!M;V1U
M;&ES+@!!=71H7VMR8C4Z(&YE<F%S=&%S(')E:6MA;&EN9V%S(&MR8C4@;6]D
M=6QI<RX`075T:%]L9&%P.B!N97)A<W1A<R!R96EK86QI;F=A<R!,1$%0(&UO
M9'5L:7,N`$%U=&A?;&1A<#H@<W5K=7)T:2!V87)T;W1O:N`@)7,@;F5P879Y
M:V\N(%-E<G9E<FEO('!R86YE\&EM87,Z(`!!=71H7VQD87`Z(&GP=')I;G1I
M('9A<G1O=&]JX"`E<R!N97!A=GEK;P!!=71H7VQD87`Z(&%T;F%U:FEN=&D@
M=F%R=&]T;VK@("5S(&YE<&%V>6MO`$%U=&A?;6-A;#H@;F5R87-T87,@<F5I
M:V%L:6YG87,@34-!3"!M;V1U;&ES+@!!=71H7W-M8F%U=&@Z(&YE<F%S=&%S
M(')E:6MA;&EN9V%S('-M8F%U=&@@;6]D=6QI<RX`4')I<VEJ=6YG=&D@;F5P
M879Y:V\`4')I<VEJ=6YG=&D@;F5P879Y:V\N("5S`%)!1$E54R!S97)V97)I
M<R!N96QE:63^:6$@875T96YT:69I:W5O=&ES+@!0<FES:6IU;F=T:2!P<FEE
M($944"!S97)V97)I;R!N97!A=GEK;RX`1V%L:6UI(&QA=6MA:3H`07IE<F)A
M:63^86YA<P!"3T9((&%T<VEP<F'P>6UA:0!&;VYA<P!&;VYO('-P86QV80!.
M971E:7-I;F=A<R!K97)B97)O<R!S;&%P=&'^;V1I<RX`3F5T96ES:6YG87,@
M:V5R8F5R;W,@=F%R=&]T;VIO('9A<F1A<RX`0F%H86UA:0!"86AR96EN87,`
M0F%L=&GP:V$@*$E33RTX.#4Y+3$S*0!"86=L861E\&%S`$)A<F)A9&]S87,`
M4&%G<BX@;&EN:6IO:F4`0F%L=&%R=7-I:F$`0F5L9VEJ80!"96QI>F%S`$)E
M;FEN87,`0F5R;75D86D`0G5T86YA<P!':6UT861I96YI<P!";&]K;R!P87)A
M;65T<F%I`$)L;VMO('1I<&%S`%!A<W1O<FEN=&D`0F]L:79I:F$`073^>6UO
M<P!+<F'P=&%S`$MR8?!T;R!S=&]R=6UA<SH`2W)A\'1A:0!";W-N:6IA(&ER
M($AE<F-E9V]V:6YA`%9I<V]S`$)O='-V86YA`$%P8>AI;VIE`$)U=F5T('-A
M;&$`0G)A>FEL:6IA`$)R:73X($EN9&EJ;W,@=F%N9&5N>6YO('1E<FET;VIA
M`$)R=6[K:F%U<R!D87)U<V%L96UA<P!"=6QG87)I:F$`4W7^>6WK=&%S('/@
M<F'P87,`0G5R:VEN87,@1F%S87,`0G5R=6YD:6IA`%164P!#4D,`0U),('!A
M<VMI<G-T>6UO('!U;FMT86D`7T-E;.MS(&YU<W1A='EM86DN+BX`2V%L96YD
M;W)I=7,`4F%M=0!+86UB;V3^80!+86UE<OMN87,`3F5V96EK:6$@875T;VUA
M=&EN:7,@<VQA<'1A_F]D_FEO('!A:V5I=&EM87,L('-U<VES:65K:71E('-U
M(&%D;6EN:7-T<F%T;W)I=6UI+@!.96=A;&EU('!R:7-I:G5N9W1I('!R:64@
M24U!4"!S97)V97)I;SH@)7,`2V%N861A`$%T\&%U:W1I`$%T\&%U:W1I('!R
M;V)L96UO<R!P<F%N9?!I;>``3F5G86QI=2!I\'1R:6YT:2!F86EL;R`B)7,B
M+@!.96=A;&EU(')A<W1I(&QA:6MI;F]J;R!K871A;&]G;RX`3F5G86QI=2!A
M<&1O<F]T:2`G=&%R9V5T1FEL92<@<&%R86UE=')O+@!.96=A;&EU(&GP=')I
M;G1I(&MA=&%L;V=O("(E<R(N`$YE9V%L:74@:?!T<FEN=&DN($5G>FES='5O
M:F$@)60@<&_P86MI86DN`$YE9V%L:74@<&5R<OOP:75O=&DN(,%V97-T87,@
MX7)A\/@@<VMA:>AI=7,@;F5S=71A;7!A('-U(.%R8?#X('-K86GH:75M:2!D
M=6]M96[X(&)A>NMJ92X`3F5G86QI=2!N=6MR96EP=&D@_FEN=73K<R#A(&YU
M<F]D>73@(&YU;65RX2X`2V5I<'9E<F1I<P!0879A9&EN:6UA<P!+871E9V]R
M:6IO<P!+86EM86[X('-A;&]S`$UO8FEL=7,@=&5L969O;F%S`$-E;.MS(&YU
M<W1A='EM86D`5&%R<&%I(&-E;.MS93H`0V5LZW,@;G5S=&%T>6UA:0!487)P
M86D@=&%R<"!C96QI^#H`36]B:6QU<VES('1E;&5F;VYA<P!+96QT^"`H25-/
M+3@X-3DM,30I`$-E;G1R90!#96YT<FENZW,@069R:6MO<R!297-P=6)L:6MA
M`$-E;G1R:6[K<R!%=7)O<&]S("A)4T\M.#@U.2TR*0!397)T:69I:V%T;R!D
M971A;.MS`%-E<G1I9FEK871O('1E:7/K<P#(861A<P!086ME:7-T:0!*^W/X
M('9A<F1O(&ER(&%D<F5S;RP@:W5R:75O<R!M871Y<R#^;6]NZW,L('-K86ET
M86YT>7,@:7(@871S86MI;NMJ86YT>7,@X2!*^W/X(&QA:?!K=7,L(&ME:71I
M;6%S+@!3:6UB;VQI<P!085]T:6MR:6YT:2!N=6]R;V3@+BXN`,AI;.L`2VEN
M:6IA`$MI;FEE=&GP:V$@<&%P<F%S=&$@*$=",C,Q,BD`2VEN:65T:?!K82!T
M<F%D:6-I;NL@*$)I9S4I`%!A<VER:6YK:71E('-L87!T8?YO9.$`4&%S:7)I
M;FMI=&4@=F%R=&]T;VIO('9A<F3@`%!A<VER:6YK:71E(&MA:7`@=F%I>F1U
M;W1I(&1A=&%S.@!087-I<FEN:VET92!S=7+[\&EU;W1O('/@<F'P;R!S=&EL
M:?@`2V%LZV3X('-A;&$`2VQA<^MS("5S(&[K<F$N`$=I961R80!)\'1R:6YT
M:2!-4R!/9F9I8V4@_GEM97,`5F%R=&]T;VIO(&1U;VUE;O@@=F%L>6UA<SH@
M)7,`2?!V86QY=&D@=F%R=&]T;VIO(&1U;VUE;FES`$GP=F%L>71I('9A<G1O
M=&]J;R!D=6]M96YI<P!4YG-T:0!#;&EC:V%T96QL('!E<B!(5%10`%7^9&%R
M>71I(&QA;F?@`$1E8F5S=6]T80!$96)E<W5O=&$`2V]K;W-O("A+>6QI;F=O
M*2!S86QO<P!4=?#H:?@@8V5L:?@@:W)A\'3X(')O9'EM87,`2V]L=6UB:6IA
M`%-P86QV80!087-I<FEN:VET92!S<&%L=N``4W!A;'9O<R!P87-I<FEN:VEM
M87,`4W1U;'!E;&EA:3H`4W1U;'!E;&GX('!A=F%D:6YI;6%I`$MO;6EK<V%I
M`$MO;6%N9&$`2V]M86YD:6[K(&5I;'5TZP!+;VUE;G1A<F%S`%9A<F1A<R]P
M879A<F3K`$MO;6]R86D`2V]M<&%N:6IA`$MO;7!I=71E<FEA:0!3X&QY9V]S
M`$YU<W1A='EM^"!P86ME:71I;6%I`$MO;F9I9_MR=6]T:2`E<P!3;&%P=&'^
M;V1I<R!D87(@:V%R=.``2V]N9V%S`$1E;6]K<F%T:6[K($MO;F=O(%)E<W!U
M8FQI:V$`4')I<VEJ=6YG=&D@;F5P879Y:V\N`%!R:7-I:G5N9W1I(&YE<&%V
M>6MO.B``4')I<VEJ=6YG=&D@<')I92!V:67P^&KX(')A:W3X('-E<G9E<FEO
M(&YE<&%V>6MO+@!0<FES:6IU;F=T:2!P<FEE('9I9?#X:O@@<F%K=/@@<V5R
M=F5R:6\@;F5P879Y:V\L(&YE<SH@)7,@*"5S*0!0<FES:6IU;F=T:2!P<FEE
M($944"!S97)V97)I;R!N97!A=GEK;RX`2V]N:V%K=&%I('/K:VUI;F=A:2#A
M=')A=6MT:2#A($K[<_@@861R97/X(&MN>6=E;.8`5.9S=&D`2W5K;R!S86QO
M<P!,86EMZW,@_FEN=73K<P!+;W!I:G5O=&D`2V]P:6IU;W1I('!A<VER:6YK
M:6W@`$MO<W1A(%)I:V$`1')A;6)L:6\@2V%U;&\@2W)A;G1A<P!.97!A=GEK
M;R!U_FMO9'5O=&D@4$=0(&QA:?!K;RX`3F5P879Y:V\@<&%S:7)A\'ET:2!0
M1U`@;&%I\&MO+@!.97!A=GEK;R!U_FMO9'5O=&D@4R]-24U%(&QA:?!K;RX`
M3F5P879Y:V\@<&%S:7)A\'ET:2!3+TU)344@;&%I\&MO+@!.97!A=GEK;R!P
M<FEDZW1I(&MO;G1A:W1O+B`E<P!.97!A=GEK;R!A=71E;G1I9FEK=6]T:7,@
MX2!,1$%0('-E<G9E<N$N`$YE<&%V>6MO('!A=&EK<FEN=&D@8F%L86YS;RX@
M)7,`3F5P879Y:V\@<W5K=7)T:2!D:7-T<FEB=6-I:F]S('/@<F'P;RX@)7,`
M3F5P879Y:V\@871K;V1U;W1I(%!'4"!D=6]M96[X+@!.97!A=GEK;R!A=&MO
M9'5O=&D@4R]-24U%(&1U;VUE;O@N`$YE<&%V>6MO(&GP=')I;G1I(&MO;G1A
M:W1O+B`E<P!.97!A=GEK;R!I\'1R:6YT:2!D:7-T<FEB=6-I:F]S('/@<F'P
M;RX@)7,`3F5P879Y:V\@;G5S=&%T>71I(&=A=NMJ;R!E;"X@<&'P=&\@861R
M97-O+@!0879Y:V\@9V%U=&D@=FES;W,@861R97/X(&MN>6=E;.MS+@!.97!A
M=GEK;R!G875T:2!V:7-O(&1I<W1R:6)U8VEJ;W,@<^!R8?!O+@!.97!A=GEK
M;R!G875T:2!V:7-O(&1I<W1R:6)U8VEJ;W,@<^!R8?#X('/@<F'P;RX`3F5P
M879Y:V\@9V%U=&D@=FEE\&]J;R!R86MT;R!I\"!R86MT^"!S97)V97)I;RX`
M3F5P879Y:V\@871I9&%R>71I("5S+@!.97!A=GEK;R!A=&ED87)Y=&D@36%I
M;G1E;F%N8V5?5&%S:R!M;V1U;&EO("5S`$YE<&%V>6MO('-K86ET>71I("5S
M+@!.97!A=GEK;R!P86ME:7-T:2!S;&%P=&'^;V3^:6\@\&EA;2!V87)T;W1O
M:G5I+B!+86D@:W5R:2!A<F)A('9I<V$@:6YF;W)M86-I:F$@>7)A(&YE=&EK
M<VQI+B!086)A;F1Y:VET92!D87(@:V%R=.`@87)B82!S=7-I<VEE:VET92!S
M=2!S879O(&%D;6EN:7-T<F%T;W)I=6UI(&IE:6=U(')E:6MA;&EN9V$@<&%G
M86QB82X`3F5P879Y:V\@9V%U=&D@04-,`$YE<&%V>6MO(&=A=71I(&%D<F5S
M^"!K;GEG96SK<RX@)7,`3F5P879Y:V\@9V%U=&D@9&ES=')I8G5C:6IO<R!S
MX')A\&\N("5S`$YE<&%V>6MO(&=A=71I(&1I<W1R:6)U8VEJ;W,@<^!R8?#X
M+B`E<P!.97!A=GEK;R!N=7-T871Y=&D@<V5R=F5R:6\@9V%L:6UY8FGX`$YE
M<&%V>6MO(&%T:V5I<W1I(&YU<W1A='EM^"X`3F5P879Y:V\@:?!S875G;W1I
M("5S(&YU<W1A='EM^"X`3F5P879Y:V\@<&%D87)Y=&D@871S87)G:6[K<R!N
M=7-T871Y;?@@:V]P:6IO<RX`3F5P879Y:V\@<&%I9?!K82!,1$%0('-E<G9E
M<GEJ92X`3F5P879Y:V\@871N875J:6YT:2!K;VYT86MT;RX@)7,`3F5P879Y
M:V\@871N875J:6YT:2!D:7-T<FEB=6-I:F]S('/@<F'P;RX@)7,`3F5P879Y
M:V\@<F%S=&D@36]Z:6QO<R#A<F%N:VGX(&IU;W-T;W,N(,%S:71I:VEN:VET
M92P@:V%D(&II(&%T:61A<GET82X`4FEB;W1A<R!T96MS=&%S`%9A;'-T>6+K
M`$MU<G-A:0!3=6MU<G1I`%-U:W5R=&D@;G5O<F]DX`!3=6MU<G1I(&YA=6K@
M(&%P<F'PX`!3=6MU<G1I('!A:V%T86QO9VEU<P!3879I;FEN:V\@=&5I<^MS
M`$MR961I=&ENZW,@:V]R=&5LZW,@;G5M97)I<P!+<F]A=&EJ80!+=6)A`$1A
M8F%R=&EN:7,@;&%I:V%S`-!I=6\@;65T=2!54DP@>7)A`$1A8F%R=&ENZW,@
M;W)O('/@;'EG;W,`1&%B87)T:6[K<R!SX&QY9V]S.B``1&%B87)T:6YI<R!S
M=&EL:75S`%9E:6MS;?@L(&%T;&EE:V%M^"!P<FES:6IU;F=U<R!P<FEE("5S
M+"!N=7-T871Y;6%S+@!097)K96QT:0!097)K96QT:2!P87-I<FEN:VEMX`!+
M:7!R87,`2VER:6QI8V$@*$M/23@M4BD`2VER:6QI8V$@*%=I;F1O=W,M,3(U
M,2D`2VER:6QI8V$O56MR86EN:65T:?!K82`H2T])."U5*0#(96MI:F]S(%)E
M<W!U8FQI:V$`1$0`2V%S9&EE;@!$=6]M96[X(&UE9/YI;R!N87+P>6MLZP!$
M871A`$=A=71A`$1A=&]S('!A<VER:6YK:6UA<P!$:65N80!)\'1R:6YT:2!?
M<W1U;'!E;.$`1W)U;V1I<P!$9?!I;71A:6YI86D@<VMA:>AI86D`4W5M8?YI
M;G1I(&%T:71R875K:6W@`%-T86YD87)T:6[K('-P86QV80!3=&%N9&%R=&EN
M:7,@87!R8?!A<P!!<&EB<NO^:6UA:0!)\'1R:6YT:0!)\'1R:6YT:2!G<G5P
MY@!)\'1R:6YT:2!T96ESY@!6:7-I\&MA:2!I\'1R:6YT:2!L86GP:W5S`$GP
M=')I;G1I(&-E;.8`2?!T<FEN=&D@<W1U;'!E;.$`2?!T<FEN=&D@96=Z:7-T
M=6]J86YTX2!A;'1E<FYA='EV^"#P86)L;V[@`$GP=')I;G1I(&5I;'5TY@!)
M\'1R:6YT:2!P87-I<FEN:W3@(&%P<F'PX`!)\'1R:6YT:2#PX2!S='5L<&5L
MX0!)\'1R:6YT:2#P:>`@96EL=73F`%!R:7-T871Y;6\@;&%I:V%S`$1A;FEJ
M80!0<F]B;&5M;W,@87!R8?!Y;6%S`$%P<F'P>6UA<P!$971A;&EA=2`H=&%I
M<"!P870@_FG[<NMK:71E($AO<F1E(&QO9R!F86EL92DZ`$%D;6EN:7-T<F%T
M;W)I=6D@:?!S:?AS=&%S(&1E=&%L=7,@87!R8?!Y;6%S+@!6>7-T>6UA<P!$
M<NMG;G5M87,`1'+K9VYU;6%S('!A<VMU=&ENYB!V86QA;F3@.B``1'+K9VYU
M;6%S.B``2W)Y<'1I<R!I\"!K86ERZW,@X2!D9?!I;N8`2W)Y<'1I<R!I\"!D
M9?!I;NMS(.$@:V%I<N8`2V%T86QO9V%S`%)O9'ET:2`R-"UI^"!V86PN(&9O
M<FUA=.`_`%9A:7ID879I;6\@;G5S=&%T>6UA:0!2;V1Y=&D@<')O9W)O;N8@
M*%1!1BD`5F%I>F1A=FEM;R!F;W)M871A<P!,86GP:V\@<')I<W1A='EM;R!P
M<F%N9?!I;6%I`$3^:6)U=&ES`$YE=')I;G1I`$YE<VEK<F5I<&MI=&4@=&EE
M<VEO9VEA:2#A(&UA:6YT96YA;F-E+G!H<`!!<B!P:7)M87,@X7)A\&%S('ER
M82!L875K;R!V87)D86D_`$1O;6EN:6MA`$1O;6EN:6MO<R!297-P=6)L:6MA
M`$%T<VES:?AS=&D`071S:7-I^'-T:2`E<P!!='-I<VGX<W1I('-U9V5N97)U
M;W1U<R!N=7-T871Y;75S(&MA:7`@4$A0('-K<FEP=.`N`$GP<VES:VQE:63^
M:6%N=&ES('/@<F'P87,`5F%I<W1A:0!%;"X@<&'P=&\@861R97-A<P!%4E(`
M16MV861O<F%S`$ME:7-T:0!+96ES=&D@8FQO:V\@<&%R86UE=')U<P!2961A
M9W5O=&D@9W)U<.8`4F5D86=U;W1I('1E:7-E<P!2961A9W5O=&D@=&5I<V5S
M`"5S('1E:7-I^"!R961A9V%V:6UA<P!+96ES=&D@;G5S=&%T>6UU<SH`)7,@
M=&5I<VGX(')E9&%G879I;6%S`%5G9'EM87,`16=I<'1A<P!386QV861O<F%S
M`$5L96UE;G1A<RXN+@!%;0!%;"X@<&'P=&%S`$5L+B!P8?!T;R!A9')E<V%S
M`$5L+B!P8?!T;R!A9')E<V%I('1U<FD@<W5T87!T:2X`16PN('!A\'1O(&%D
M<F5S87,@<W4@<&%T=FER=&EN:6UU`-!Y<'-E;NMLZW,`WFEN=73K('1U\.AI
M82X`4F5Z=6QT871A<R!T=?#H:6%S+@!.96YU<F]DZW1E('!A:67P:V]S('1E
M<FUI;O@`3&5I<W1I('1E:W-T92#A=&5R<'1I('!A=F5I:W-LZVQI=7,@:?`@
M3G5O=')A=6OX(&=A;&5R:6IO<S\`P6IU;F=T:2!D9?!I;FEO:F\@<&5LZW,@
M;7EG='5K;R!M96YI=3\`1V%L:6YI86D@;65T86D`2?!P;.MS=&D@<F5D86MT
M;W)I^`#!<F'P>6MI=&4@:VQA=7-I;>`L(&MU<FES(&IU;7,@8G5S('7^9'5O
M=&%S(&IE:6=U('!A;6ER\&ET92!S879O('-L87!T8?YO9.$L('!V>BXZ("=K
M;VMS('ER82!*^W/X(&=Y=OMN;R!V87)D87,_)SH`P79E<VMI=&4@<&%V96EK
M<VSK;&EO(%523`!%:W9A=&]R:6[K($=V:6[K:F$`17)I='+K:F$`2VQA:61A
M`$ML86ED82!L86GP:V4N`$5S=&EJ80!%=&EO<&EJ80!%=&YI;NMS`$5U<F]P
M80!+87,@,34@;6EN=>AI^`!+87,@,B!M:6YU=&5S`$MA<R`S,"!S96MU;F3^
M:?@`2V%S(#4@;6EN=71E<P!+:65K=FEE;F\@<')I<VEJ=6YG:6UO(&UE='4`
M2V%S('!U<W9A;&%N9.$`2V%S(&UI;G5TY@!0879Y>F3^:75I.@!6>6MD>71I
M`$GP<VML96ES=&D`4F5I:V%L:6YG87,@)RDG`%)E:6MA;&EN9V%S(/YO9&ES
M(&%R8F$@:V%B=73K<V4@X7)A\'ET87,@<&%I9?!K;W,@:W)I=&5R:6IU<P!'
M86QI;VII;6\@9&%T80!%:W-P;VYE;G3K`%1E:W-T;R!S<&%L=F$`3G5S=&%T
M>6WX('-I=6YT:6UA<R!P97(@1E10+@!+;&%I9&$@;G5S:V%I=&%N="!N=7-T
M871Y;75S+@!.97!A=GEK;R!P<FES:6IU;F=T:2!P<FEE($Q$05`@<V5R=F5R
M:6\N`$YE<&%V>6MO('!R:7-I:G5N9W1I('!R:64@4TU"('-E<G9E<FEO+@!.
M97!A=GEK;R!N=6MO<&EJ=6]T:2!I\"`B)7,B+@!.97!A=GEK;R!N=6MO<&EJ
M=6]T:2#A("(E<R(N`$YE<&%V>6MO('-U:W5R=&D@;F%U:F\@4T%33"!R>?!I
M;RX`3F5P879Y:V\@<&5R:V5L=&D@X2`B)7,B+@#0=F5L;G5S`$9O;&ML86YD
M^"!S86QO<R`H36%L=FEN86DI`$9A<F5R^"!S86QO<P!&86MS87,`5F%S87)I
M<P!!=')O9&\@;'EG`$%T<F]D;R!L>6<Z(`!4<G5M<&%L86EK:7,@;&EE='5S
M`$9I9/YI<P!&86EL^"!S:V%IZ&EU<SH@)7,@9F%I;&%S`$9A:6SX('-K86GH
M:75S.B`E<R!F86EL86DH^"D`1F%I;/@@='9A<FMY;6%S`$9A:6QO('!A=F%D
M:6YI;6%S`$9A:6QO('!A<VER:6YK:6UA<P!&86EL;R!S:75N=&EM87,`3F%R
M\'EK;.L@;F5P86QA:6MO(&9A:6SX('-I=6YT:6UO+@!&:6QT<F%I`%-U;VUI
M:F$`4&ER;6]J:2!P=7/K`%!I<FUA<VES(&ME='9I<G1I<P!.=7-T871Y=&%S
M(&MO969I8VEE;G1A<P!!='9I<FOPZ&EA<P!)\&3K<W1Y;6%S`%+[:V%S`$MA
M=&%L;V=A<R`E<R!N965G>FES='5O:F$`5&5K<W1O('-P86QV80!-86ES=&%S
M`$YA<O!Y:VSK;7,L(&MU<FEO<R!N97!A;&%I:V\@<&%V96EK<VSK;&GX`$]R
M^"!P<F]G;F]ZZR`H5$%&*0!/<O@@<')O9VYO>NMS(&%P:6UT:7,@*.%S:63K
M;>MK:71E+"!K860@\&D@9G5N:V-I:F$@9W)A_FEN82!I<B!D:65N;W,@:7(@
M;F%K=&EE<R!P<F]G;F]ZYCL@<&5R(&1I9&5L:7,@<VMA:>AI=7,@9V%L:2!S
M=61A<FMY=&D@9&EZ86ENX"D`4&%M:7+P;W1E('-A=F\@<VQA<'1A_F]DX3\`
M1F]R;6]S`$9R87KK`$9R87II^"!T:7!A<P!&<F%ZZW,`1G)A>NMS(#(`1&ES
M:W5S:6IO<P!097)S:75N=&EM86D`4&5N:RX`2W)A\'1I;NMS`%!R86YC^WII
M:F$`4')A;F/[>FEJ82P@365T<F]P;VQI<P!0<F%N8_MZ:6IO<R!'=FEA;F$`
M4')A;F/[>FEJ;W,@4&]L:6YE>FEJ80!0<F%N8_MZ:6IO<R!P:65T:6[K<R!T
M97)I=&]R:6IO<P!.=6\`3G5O(`!0:6QN87,@87!R8?!Y;6%S`%!I;&YA=&ES
M`%!I;&YA<R!V87)D87,`1V%B;VYA<P!'86QE<FEJ82!I\"!K=7)I;W,@:?`@
M:W5R:6]S(&)U<R!R;V1O;6%S('!A=F5I:W-LZVQI<P!'86QE<FEJ83H`1V%M
M8FEJ80!'96YE<G5O=&D@)7,@;G5S=&%T>6UU<P!3=6=E;F5R=6]T87,@:V]D
M87,`1W)U>FEJ80!6;VMI971I:F$`1V%N80!':6)R86QT87)A<P!687)D87,`
M4F]D>71I`$=A9&5L:7,`1V]O9VQE('!A:67P:V$`3F5S<&%L=F]T87,`1W)A
M:6MI:F$`1W)A:6MI\&MA("A)4T\M.#@U.2TW*0!'<F5N;&%N9&EJ80!'<F5N
M861A`$=R=7!I^"!A9&UI;FES=')A=FEM87,`1W)U<.MS('9A<F1A<R!T=7)I
M(&+[=&D@;F5T=?#H:6%S`$=R=7#K<P!'=F%D96QU<.L`1W5A;6$`1W9A=&5M
M86QA`$=E<FYS:7,`4W9EZ&GX('1E:7/K<P!3=F7H:?@@:VYY9V$`1W9I;NMJ
M80!":7-S874M1W9I;NMJ80!'86IA;F$`2%1-3`!(5$U,07)E82!N96=A;&D@
M:?!T<FEN=&D@<&%S:W5T:6[K<R!C96SK<R!E:6QU=.MJ92X`2%1-3$%R96$@
M;F5G86QI(&GP<FEN=&D@<&%S:W5T:6YI;R!S='5L<&5L:6\@;&5N=&5LZVIE
M+@!(5$U,07)E82!N96=A;&D@:?!T<FEN=&D@<&%S:W5T:6[K<R!E:6QU=.MS
M(&QE;G1E;.MJ92X`4F5I:V%L:6YG82!(5%10(&%U=&5N=&EF:6MA8VEJ82X`
M2&%I=&ES`$AA<V@M06QG;W)I=&UA<P!-:6=L80!!;G1R8?!TZP!(97)D;R!S
M86QA(&ER($UA:V1O;F%L9&\@<V%L;W,`2&5B<F%J^"`H25-/+3@X-3DM."U)
M*0!!=6OP=&ES`%!A9V%L8F$`4F5D86MT;W)I875S(&YA=61O:FEM;W-I('!A
M9V%L8F$`4&%G86QB:6YI;FMA<P!(96UI<V9E<F$`T'1A:2#H:6$@>7)A(&9A
M:6QO('!R863^:6$Z`%-V87)B=0!?4&]R=&%L87,`T'9E;G1A<VES(%-O<W1A
M<R`H5F%T:6MA;F\@=F%L<W1I:F$I`%!O<G1A;&%S`$YA;?@@861R97-A<P!.
M86WX('1E;&5F;VYA<P!(;VYD^W)A<P!(;VYK;VYG87,`4&]R=&%L87,`2&]R
M9&4O2V]L86(Z(&YE=&5I<VEN9VD@)7,@6$U,(&1U;VUE;GES(/YI;G5TZVIE
M("5S`$AO<F1E+TMO;&%B.B!O8FIE:W1O("5S(&YE871I=&EN:V$@:F]K:6$@
M_FEN=73K`$AO<F1E+TMO;&%B.B!O8FIE:W1O('1I<&%S("5S(&YE<F%S=&%S
M(/YI;G5TZVIE("5S`$AO<F1E+TMO;&%B.B`E<R`B)7,B('/K:VUI;F%I(&GP
M=')I;G1A`$AO<F1E+TMO;&%B.B!I;G1E9W)A8VEJ;W,@=F%R:6ML:75K=6D@
M<F5I:V%L:6YG87,@)V1O;7AM;"<@4$A0(&UO9'5L:7,`2&]R9&4O2V]L86(Z
M(&YE<&%V>6MO('-U:W5R=&D@;F%U:F\@6$U,(&UE9/YI;R!O8FIE:W1U:2`E
M<P!(;W)D92]+;VQA8CH@;F5P879Y:V\@:?!T<FEN=&D@)7,@(B5S(CH@)7,`
M2&]R9&4O2V]L86(Z(&YE<&%V>6MO(&=A=71I($U)344@240@9&%L:6%I("5S
M('1I<&\`2&]R9&4O2V]L86(Z(&YE<&%V>6MO('-U<VEN8VAR;VYI>G5O=&D@
M)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(&YE<&%V>6MO('-U<VEN8VAR;VYI
M>G5O=&D@96QE;65N=/@Z("5S`$AO<F1E+TMO;&%B.B!N9?YI;F]M87,@96QE
M;65N=&%S("(E<R(`2&]R:7IO;G1A;&D@;&EN:6IA`$AO<FEZ;VYT86QU<R!T
M87)P87,`2&]R:7IO;G1A;&EA:3H`2V%I<"#H:6$@<&%T96MO=&4_("A0<F%N
M9?!K:71E(2D`2VEE:R!S='5L<&5L:?@@;F]R:71E('-U:G5N9W1I/P!+:65K
M(&QA=6OX("AS='5L<&5L:?@I('1E;B!Y<F$_`$MI96L@96EL=>AI^"!N;W)I
M=&4@<W5J=6YG=&D_`$1RZV=N=6UA<P!$<NMG;G5M87,Z(`!*=6UO<F5S:V]S
M`%9E;F=R:6IA`$YE<&%V>6MO('-U:W5R=&D@24U!4"!P8?!T;R!DZ_YU=.MS
M.B`E<P!.97!A=GEK;R!I\'1R:6YT:2!)34%0('!A\'1O(&3K_G5TZW,Z("5S
M`$YE<&%V>6MO(&YU<W1A='ET:2!)34%0('!A\'1O(&3K_G5TZW,@9'ED_FEO
M.B`E<P!)4"!A9')E<V%S`$YE<&%V>6MO(&=A=71I($E0(&%D<F5S;RX`25`@
M861R97-A<R!N971E:7-I;F=A;64@0TE$4B!B;&]K92X`25`@=?YR86MI;G1A
M<RX`7\%T97)P=&D@96EL=73F('9I<O!U:F4`27-L86YD:6IA`%1I:R!P:6MT
M;V=R86UO<P!0:6MT;V=R86UO<R!S=2!T96MS='4`07!R8?!O('!A=F%D:6YI
M;6%S.@!*96D@;F5G86QI=&4@<&5R<VMA:71Y=&D@\&EO(&QA:?!K;RP@)7,N
M`$IE:6=U(&UA=&]T92#P:>`@_FEN=73F('9I971O:B!P879E:6MS;.ML:6\L
M(&MU<N$@;F]R:71E(.%K96QT:2P@=&%I($K[<_@@;F%R\'EK;.L@;F5G86QI
M(&IO(&%T=F%I>F1U;W1I+@!0879E:6MS;.ML:6\@<&5R_FG[<F$`4&%V96EK
M<VSK;&EO(%523`!0879E:6MS;.ML:6\@55),.@!0879E:6MS;.ML:7,@:?`@
M9V%L97)I:F]S`%!A=F5I:W-LZVQI<R!I\"!G86QE<FEJ;W,Z`%!A=F5I:W-L
MZVQI;R#A:^ML:6UA<P!686EZ9&%I`,%KZVQI;6%S+"`E9"#^:6YG<VYI<P!,
M875K87,@X6ME;'1A<SH@)7,`P6ME;'1I(&QA=6MA:3H`P5]T97)P=&D@96EL
M=73F(&%P8>AI;VIE`$YE=&5I<VEN9V%S('9E:6MS;6\@:V]D87,N`$YE=&5I
M<VEN9V%S('9A<G1O=&]J;R!V87)D87,@:7(O87)B82!S;&%P=&'^;V1I<RX`
M3F5I=&5I<VEN9V%S('9A<G1O=&]J;R!V87)D87,@87)B82!A;'1E<FYA='EV
M=7,@96PN('!A\'1O(&%D<F5S87,N($)A;F1Y:VET92!D87(@:V%R=.`@87)B
M82!S=7-I<VEE:VET92!S=2!S879O(&%D;6EN:7-T<F%T;W)I=6UI(&IE:6=U
M(')E:6MA;&EN9V$@=&]L97-NZR!P86=A;&)A+@!0861I9&EN=&D@871I=')A
M=6MI;>``26YD:6IA`$EN9&EV:61U86S[<R!V87)T;W1O:F%I`$EN9&]N97II
M:F$`26YF;W)M86-I:F$`26YF;W)M86-I:F$`P71R875K=&D@<W1U;'!E;.$@
M7V1E\&ENZVIE`,%T97)P=&D@<&%V96EK<VSK;.$`P71E<G!T:2!L96YT96SF
M`,%T97)P=&D@;G5O<F]DX`#!=&5R<'1I('-T=6QP96SA(%]K86ERZVIE`,%T
M97)P=&D@;F%U:N`@<W1U;'!E;.$@97-A;6\@<W1U;'!E;&EO(&1E\&ENZVIE
M`,%T97)P=&D@;F%U:N`@<W1U;'!E;.$@97-A;6\@<W1U;'!E;&EO(&MA:7+K
M:F4`P71E<G!T:2!N875JX"!E:6QU=.8@97-A;6]S(&5I;'5TZW,@87!AZ&EO
M:F4`P71E<G!T:2!N875JX"!E:6QU=.8@97-A;6]S(&5I;'5TZW,@=FER\'5J
M90#!=&5R<'1I('!A<F%G<F%FX"!E;&5M96YT;R!A<&'H:6]J90#!=&5R<'1I
M('!A<F%G<F%GX"!E;&5M96YT;R!V:7+P=6IE`,%T97)P=&D@86QT97)N871Y
M=O@@\&%B;&]NX`#!<F'P>6MI=&4@96PN('!A\'1O(&%D<F5SX"P@X2!K=7+A
M(&YO<FET92!G875T:2!N875JX"!S;&%P=&'^;V3A.@#!=&5R<'1I(&-E;.8@
M<&\@=&\`P71E<G!T:2!C96SF('!R:67P('1A:0#!=&5R<'1I('-T=6QP96SA
M(&1E\&ENZVIE`,%T97)P=&D@<W1U;'!E;.$@:V%I<NMJ90#!=&5R<'1I(&QA
M:?!K=7,`P71E<G!T:2!P87)A9W)A9N`@<&\@=&\`P71E<G!T:2!P87)A9W)A
M9N`@<')I9?`@=&%I`,%T97)P=&D@96EL=73F('!O('1O`,%T97)P=&D@96EL
M=73F('!R:67P('1A:0#!<F'P>6MI=&4@<F5I:VEA;>`@871S86MY;>`@X2!K
M;&%U<VEMX"!V:7+P=6IE.@#!=&5R<'1I+W)E9&%G=6]T:2!P879E:6MS;.ML
MX0#!=&5R<'1I+U)E9&%G=6]T:2!N=6]R;V3@`$1I<W1R:6)U8VEJ;W,@<^!R
M8?!U:2!N=7-I^'-T:2!N977^=&5N:V$@:W)E9&ET;RX`3F5U_G1E;FMA(&MR
M961I=&\N`%-K86GH:75S`%-K86GH:?@@<^!R8?!A<P!.971E:7-I;F=A<R!5
M1$@N("A5<V5R($1A=&$@2&5A9&5R*2X`3F5T96ES:6YG87,@;6]D=6QI<RX`
M3F5T96ES:6YG87,@240N`,%V97-T:2!N971E:7-I;F=I(&1U;VUE;GES+@!.
M971E:7-I;F=A<R!A9')E<V%S+@!.971E:7-I;F=A<R!F86EL;R!F;W)M871A
M<P!.971E:7-I;F=A<R!M<V=?='EP92X`3F5T96ES:6YG87,@87)B82!NZW)A
M(&%P:5]I9"X`4&%R86UE=')A:2!N971E:7-I;F=I(&%R8F$@:O@@;NMR82X`
M3F5T96ES:6YG;W,@<&%V96QD:6UO<R!T96ESZW,N`$YE=&5I<VEN9V%S('!R
M;W1O:V]L87,N`$YE=&5I<VEN9V%S(&]B:F5K=&%S`$YE=&5I<VEN9V%S('-I
M=6YTZVIO(&%D<F5S87,N`$YE=&5I<VEN9VD@=6YI:V]D;R!D=6]M96YY<RX`
M26YV96YT;W)I=7,`27-L86UI\&MA($ER86YO(%)E<W!U8FQI:V$`27)A:V%S
M`$%I<FEJ80!-96YO('-A;&$`27IO;&EU;W1O<R!4+6%U9')O<P!)>G)A96QI
M<P!)\&1A=NMJ87,`2W5R<WEV87,`271A;&EJ80!*86UA:6MA`%-A=7-I<P!*
M87!O;FEJ80!*87!O;FGP:V$@*$E33RTR,#(R+4I0*0!$_F5R<VES`$IO<F1A
M;FEJ80!,:65P80!":7+^96QI<P!0:6QN86D`3'EG:75O=&D@8V5N=')E`$QY
M9W5O=&D@<&EL;F%I`$QY9VEU;W1I(&MA:7+K:F4`3'EG:75O=&D@9&7P:6[K
M:F4`2V%Z86MS=&%N87,`2?!S875G;W1I(&]R:6=I;F%LX#\`2V5N:6IA`$YE
M<&%V>6MO('!R:7-I:G5N9W1I('!R:64@2V5R8F5R;W,@<V5R=F5R:6\N`$)R
M86YD=6]L:6\@;F%U:F]K86D`4F%K=&\@:_MR:6UA<P!286MT;R!A='-P875D
M87,`4F%K=&\@:6QG:7,`4F%K=&\@=&EP87,`4F%K=&\@<&%N875D;VII;6%S
M`%)A:W1A<R!J874@>7)A('9I9?#X:O@@<F%K=/@@<V5R=F5R>6IE+@!686EK
M86D`2VER:6)A=&ES`$1E;6]K<F%T:6[K($MO<NMJ;W,@3&EA=61I97,@4F5S
M<'5B;&EK80!+;W+K:F]S(%)E<W!U8FQI:V$`2V]RZVII971I\&MA("A%54,M
M2U(I`$MU=F5I=&%S`$MI<F=I>FEJ80!?2?!DZW-T>6UA<P!+86QB80!,86]S
M;R!$96UO:W)A=&ENZR!,:6%U9&EE<R!297-P=6)L:6MA`$%N=')A('!U<^L`
M4&%S:W5T:6YI<R!K971V:7)T:7,`071N875J:6YT83H`4&%S:W5T:6YI<R!P
M<FES:6IU;F=I;6%S.B`E<P!087-K=71I;FES('!R:7-I:G5N9VEM87,Z("5S
M(&GP(&%D<F5S;R`E<P!0<FES:6IU;F?K=&4@<&ER;>`@:V%R=.``3&%T=FEJ
M80!496ESZP!)\&3K<W1Y;6%S`$IE:6=U(&YE;F]R:71E(&YE;F%U9&]T:2!K
M<F'P=/@L('!A;&EK:71E('1U\.AIX`!,:6)A;F%S`$MA:7+K:F4`2V%I<FEO
M:FD@86YT<F'P=.L`2V%I<FEO<VEO<R!R96EK\&WK<P!,97-O=&%S`$QI8F5R
M:6IA`$QI8FEJ;W,@07)A8O@@16UY<F%T86D`3&EC:'1E;O!T96EN87,`4VUU
M;&MU<R!L:65T=7,`3F5D:61E;&ES(&QI971U<P!.961I9&5L:7,@;&EE='5S
M(')Y=&4`3F5D:61E;&ES(&QI971U<R!V86MA<F4`3F5D:61E;.L@;&G[=&ES
M`$YE9&ED96QI<R!L:65T=7,@<W4@<&5R:_MN:6IA`$YE9&ED96QI<R!S;FEE
M9V%S`$YE9&ED96SK(/!L87!D<FEB80!,:6UE<FEK87,`3G5O<F]D80!.=6]R
M;V1A(.$Z`%!A9&%R>71I(&5L+B!P8?!T;R!A9')E<^`@;G5O<F]D82#A(&QA
M:?!K;R!R8?!Y;6\@<'5S;&%PX0!.=6]R;V1O<P!,:6YU>"!L86EMZW,@_FEN
M=73K<P!2;V1Y=&D@+2!V87)T;W1O:F%S(&=A;&D@;6%T>71I(&MA=&%L;V=O
M('1U<FENX0!2;V1Y=&D@9'5O;65N^"!B87II^"!SX')A\.``4F]D>71I('!A
M9V%L8F]S('1E;6%S`%)O9'ET:2!L96YT96QI^"!SX')A\.``2V]N9F5R96YC
M:6IO<R!A<F-H>79A<P!+;VYF97)E;F-I:F]S('!A9V%L8F$`2V]N9F5R96YC
M:6IO<R!)1`!+;VYF97)E;F-I:F]S('-A=FEN:6YK87,`4F'P>71I(.$@:V]N
M9F5R96YC:6K@`%!R:7-I:G5N9W1I('!R:64@:V]N9F5R96YC:6IO<P!!='-I
M:G5N9W1I(&YU;R!K;VYF97)E;F-I:F]S`%9A<G1O=&]J^"!SX')A\&%S('7^
M9')A=7-T87,N`$QI=&5R873[<F$`3&EE='5V80!+<F%U;F$N+BX`5FEE=&EN
M:7,@;&%I:V%S.B``3&]K86SK(&ER(&QA:6MA<P!6:65T80!0<FES:6IU;F=T
M:0!!='-I:G5N9W1I`%!R:7-I:G5N9VEM;R!D87)B86D`4')I<VEJ=6YG=&D@
M;F5P879Y:V\N($YE=&5I<VEN9V%S($K[<_@@;G5R;V1Y=&%S('9A<G1O=&]J
M;R!V87)D87,@:7(O87(@<VQA<'1A_F]D:7,N`%!R:7-I:G5N9W1I(&YE<&%V
M>6MO+@!);&=A<R!T96MS=&%S`$UE:6SK`$YE<W9A<F)U`$UA_F]S:6]S(&=R
M86EK:?!K;W,@<F%I9.MS`$UA_F]S:6]S(&QO='EN:?!K;W,@<F%I9.MS`$UA
M_FEE:FD@<F]MZVYI\&MI('-K86GH:6%I`$QI=6MS96UB=7)G87,`34T`34]4
M1`!0<FEK86)I;G1A;64@35,M5$Y%1B!F86EL92!NZW)A(&1U;VWK;O@N`$U3
M1P!-86MA;P!-86ME9&]N:6IA`$UA9&%G87-K87)A<P!-86=I:F$`4&'P=&%S
M`%!A\'1O('9A;&1Y;6%S`%-U:W5R=&D@7VYU;W)O9.`N+BX`36%L879I<P!-
M86QA:7II:F$`36%L9'EV86D`36%L:7,`36%L=&$`2V%T96=O<FEJ^"!SX')A
M\&\L(&MU<FEO;7,@<')I<VMI<FEA;6D@;V)J96MT86DL(&ER('-U(&IO;6ES
M('-U<VEJ=7-I^"!S<&%L=O@@:V5I=&EM87,N`$UA<#(T(/YE;>ML87!I<P!-
M87!1=65S="#^96WK;&%P:7,`2V]V87,`4&%R8?!TZP!08?YY;>MT:2!K86EP
M('-K86ET>71U<R]N97-K86ET>71U<P!08?YY;>MT:2!K:71A:7,@871R:6)U
M=&%I<R`H<'9Z+B!S=F%R8G4O871S86MY=&$I`$UA<O!A;&\@<V%L;W,`36%R
M=&EN:6MA`%-U:G5N9W1I(&QA=6MA:0!-875R:71A;FEJ80!-875R:6-I:G5S
M`$UA:W-I;6%L=7,@:W)E9&ET87,N`$UA:W-I;6%L=7,@_FEN=>AI^"!D86QI
M^"!K:65K:7,@:?!E:6MV;W1A<RX`36%K<RX@=&5M<"X@<&%S:RX@,C0@=F%L
M.B``36%K<RX@=&5M<"X@<&%S:RX@-B!V86PZ(`!-86MS:6UA;'5S(&EL9VES
M`$=E9W7^ZP!-;VIO=.L`365D:6-I;F$`3F%R:6%I`$UE;FEU(')E_FEM87,Z
M`%-U:G5N9W1I(&-E;&5S`-YI;G5TZP!,86GP:V%S('!A=FER=&EN=&%S+"!T
M8>AI874@;F5P871V:7)T:6YT87,@<&%S:7)A\&EU<VEO(&%S;65N<R!S97)T
M:69I:V%T87,N`-YI;G5TZR!N96GP<VGX<W1A+@#>:6YU=.MS('1I<&%S`$]R
M;R!S86QY9V]S`$]R;R!SX&QY9_@@8FQO:V\@;NMR82X`3W)O('/@;'EG^"!B
M;&]K;R!NZW)A+B!!9&UI;FES=')A=&]R:75I(&GP<VGX<W1A<R!D971A;'5S
M(&%P<F'P>6UA<RX`365T;V1A<P!-871A:0!-96MS:6MA`$UI:W)O;F5Z:6IO
M<R!&961E<F%C:6[K<R!686QS=&EJ;W,`5FED=7)Y:F4`34E-12!T:7!A<P!-
M:6XN('1E;7`N('!A<VLN(#(T('9A;#H@`$UI;BX@=&5M<"X@<&%S:RX@-B!H
M;W5R<SH@`$%T<W!I;F1Y<P!+:71O<P!.97)A<W1A<R!014%2($A45%!?4F5Q
M=65S="!P86ME=&%S+@!.=7-T871Y;?@@;NMR82X@2F5I9W4@;F]R:71E(&YA
M=61O=&D@\.$@;6]D=6SA+"!T=7)I=&4@:N$@<W5K;VYF:6?[<G5O=&DN`$[K
M<F$@_FEN=73K<R!)1"X`3F5R87-T87,@<F5I:V%L:6YG87,@4$5!4B!-86EL
M('!A:V5T87,N`$[K<F$@<V5S:6IO<R!)1"X`4&ER;2X`36]B:6QU<R!P8?!T
M87,`5FED=71I;FES`%)E9&%G879I;6\@9&%T80!+96ES=&D@55),`$UO9'5L
M:7,`36]L9&]V;W,@4F5S<'5B;&EK80!-;VYA:V%S`$UO;F=O;&EJ80!-ZVYE
M<VEA:2!I<B!M971A:0!+87,@;>MN97/A`$UO;G-E<F%T87,`3>MN=6QI;R!F
M87KK<P!-87)O:V%S`$1A=6=I875S:6$@9VEE9')A`$1A=6=I875S:6$@87!S
M:6YA=6OF`$1A=6=I875S:6$@<V%U;.MT80!097)K96QT:2#^96UI874`4&5R
M:V5L=&D@:V%I<FEA=0!097)K96QT:2!D9?!I;FEA=0!097)K96QT:2!A=6OP
MZ&EA=0!097)KZVQI;6%S(/YE;7EN`%!E<FOK;&EM87,@875K\'1Y;@!-;WIA
M;6)I:V%S`$ME;&5T;R!L>6=I^"!I\'-I<VML96ED_FEA;G1I<R!SX')A\&%S
M`$ME;&5T87,@<&%S:7)I;FMI;?@`36%N;R!SX'-K86ET80!-86YO('!O<G1A
M;&%S`$UA;F\@<&]R=&%L;R!I\&3K<W1Y;6%S`$UA:6YM87)A<P!.12P@3D53
M551)3DM5`%9A<F1A<P!.86UI8FEJ80!.875R87,`3F5P86QA<P!.>61E<FQA
M;F1A:0!.>61E<FQA;F3X($%N=&EL86D`3F5T<V-P87!E(&)A>FEN:7,@55),
M`$YE='-C<&%E('-E<FEF:6MA=&\@873P875K:6UO(%523`!.971S8W!A92!S
M97)T:69I:V%T;R!T96ES:?@@55),`$YE='-C87!E(&%T;F%U:FEN;VUO(%52
M3`!.971S8V%P92!A=/!A=6MI;6\@55),`$YE='-C87!E(%-33"!S97)V97)I
M;R!V87)D87,`3F5T<V-A<&4@<V5R=&EF:6MA=&\@87!R8?!Y;6%S`$YE='-C
M87!E('-E<G1I9FEK871O('1I<&%S`%1I;FML87,`3FEE:V%D80!.875J;VII
M($MA;&5D;VYI:F$`3F%U:F$@:V%T96=O<FEJ80!.875J87,@;>MN=6QI<P!.
M875J87,@=F%R=&]T;VIO('9A<F1A<R`H;F5B^W1I;F%S*0!.875J;VII(%IE
M;&%N9&EJ80!.875J86UE(&QA;F=E("A?8FQA;FLI`$YA=6II96YO<P!.875J
M:65N^"!G<G5PZW,`4V5K86YT:7,`4V5K86YT>7,@;G5S=&%T>6UA:0!.:6MA
M<F%G=F$`3FEG97)I<P!.:6=E<FEJ80!.86MT:7,`3FEU:NL`3F4`3F5U_G1E
M;FMA(&1U;VUE;O@@<VMI<G1U;?@@<&%R;V1Y;75I+@!.96YU<F]D>71A('-T
M<F%T96=I:F$@25-/(')A\'EM=6DN`$[K<F$@<W5DZW1I;FEO(/!A8FQO;F\N
M`$YU<F]D>71O:F4@<&]Z:6-I:F]J92!B;&]K;R!NZW)A`$YEX79E9.MT92!K
M86QE;F1O<FEA=7,@=F%R9&\@34-!3"!A=71E;G1I9FEK86-I:F]J92X`4VMI
M<G1U;?@@;NMR82X`T&EO<R!T96ESZW,@;F5G86QI('1U<NMT:2!P;W1E:7-I
M^"X`3NMR82!I;F9O<FUA8VEJ;W,@87!I92`E<R!K;VYF:6?[<F%C:6K@+@!.
MZW)A(&EN9F]R;6%C:6IO<R!A<&EE($944"!61E,@:V]N9FEG^W)A8VEJX"X`
M3NMR82!I;F9O<FUA8VEJ;W,@87!I92!344P@5D93(&MO;F9I9_MR86-I:N`N
M`$[K<F$@:6YF;W)M86-I:F]S(&%P:64@4U%,+49I;&4@5D93(&MO;F9I9_MR
M86-I:N`N`$MR961I=&%S(&GP96EK=F]T87,N`$YEX79E<W1A<R!G87;K:F%S
M+@!&86EL87,@;F5N=7-I^'-T87,`3F5N=7-T871Y=&$@=FEE=&]VZRX`3F7A
M<F'PZW1E(/YI;G5TZW,N`$YEX7)A\.MT92!V87)D;RX`3F7A<F'PZW1E(&YU
M;65R:6\N`$YE<F]D>71I(.'^96ED_FEA;NAI^"!F<F%Z:?@`3F7A=F5DZW1E
M('-L87!T8?YO9/YI;R!(5%10(&%U=&5N=&EF:6MA8VEJ86DN`$YEX79E9.MT
M92!S;&%P=&'^;V3^:6\@24U!4"!A=71E;G1I9FEK86-I:F%I+@!.9>%V963K
M=&4@<VQA<'1A_F]D_FEO($ME<F)E<F]S(&%U=&5N=&EF:6MA8VEJ86DN`$YE
MX79E9.MT92!S;&%P=&'^;V3^:6\@3&]G:6X@875T96YT:69I:V%C:6IA:2X`
M3F7A=F5DZW1E('-L87!T8?YO9/YI;R!005-35T0@875T96YT:69I:V%C:6IA
M:2X`3F7A=F5DZW1E('-L87!T8?YO9/YI;R!334(@875T96YT:69I:V%C:6IA
M:2X`3F7A=F5S=&%S(&ME;&EA<R!I:VD@3W!E;E-33"!P86=R:6YD:6YI^"!F
M86EL^"X@3W!E;E-33"!R96EK86QI;F=A(&1A<F)U:2!S=2!02T-3(#$R(&1U
M;VUE;FEM:7,N`$YE<&%T=FER=&EN=/@@<F5G:7-T<F%C:6KX(&[K<F$N`$YE
M;F%U9&]T:2!S:VER='5K^`!.ZR!V:65N;VIE('!U<^MJ90!3<&%R=&EN:6UU
M:2!NZW)A(&QA:6MI;F]J;R!K871A;&]G;RX`5F%R=&]T;VIO('9A<F1A<R!I
M<B]A<F)A('-L87!T8?YO9&ES(&YE;G5S:?AS=&%S+@!496ES:6YG^"!834P@
M9'5O;65N^"!NZW)A`$[K<F$@<F5I:_!M:?@`2V]N9FEG^W)A8VEN:6%M92!F
M86EL92!NZW)A('9E<G-I:F]S+B!097)G96YE<G5O:VET92!N=7-T871Y;75S
M+@!+;VYF:6?[<F%C:6YI86UE(&9A:6QE(&[K<F$@=F5R<VEJ;W,N(%!E<F=E
M;F5R=6]K:71E(&YU<W1A='EM=7,N`$YE;G5R;V1Y=&$`3NMR80#0:6%U<NMS
M("A)4T\M.#@U.2TQ,"D`3F]R9F]L:V\@<V%L;W,`T&EA=7)I;NL@:&5M:7-F
M97)A`-!I875R:6[K<R!-87)I:F%N^"!S86QO<P!.;W)V96=I:F$`3F4@<&\@
M=&\`3F4@<')I9?`@=&%I`$YE(&MA=&%L;V=A<P!.97)E86QI>G5O=&$N`$YE
M;G5R;V1Y=&$`3F5P86QA:6MO;6%S+@!5_G)A\&%I`$[K<F$@:^`@<&5R_FG[
M<NMT:2P@96EK:71E(&%T9V%L+@!,87!K<FET:7,`3G5M97)I<P!3:6UB;VQI
M^"!S:V%IZ&EU<P!3='5L<&5L:?@@<VMA:>AI=7,`16EL=>AI^"!S:V%IZ&EU
M<P!.9>%V97-T:2!D:7-T<FEB=6-I:F]S('/@<F'P;R!A=&YA=6II;FEM;R!S
M:V%IZ&EA:2X`3TL`3V)J96MT87,`3V)J96MT;R!S879I;FEN:V%S`$'P='5N
M=&%I;FES`%-P86QI<P#>:6%U<G5M;R!F:6QT<F%S`$]F:7-A<P!/;6%N87,`
M2V%T86QO9_@@9&%L:6II;>!S:2!P86QA:6MO('1I:R!)34%0('-E<G9E<FEA
M:2X`5&EK(.'^96ED_FEA;NAI;W,@9G)A>NMS`$QE:63^:6%M87,@=&EK('9I
M96YA<R!E;"X@<&'P=&\@861R97-A<RX`16QE;65N=&\@<V%V:6YI;FMO('1E
M:7-E<R!G86QI(&ME:7-T:2!T:6L@:F\@<V%V:6YI;FMA<R!A<F)A('-I<W1E
M;6]S(&%D;6EN:7-T<F%T;W)I=7,`071I9&%R>71I(&YA=6IA;64@;&%N9V4`
M071I9&%R>71I(/!IX"!N=6]R;V3@(&YA=6IA;64@;&%N9V4`3W!R86-I;NMS
M('-I<W1E;6]S`$YU<W1A='EM86D`)7,@;G5S=&%T>6UA:0!3=7+[\&EU;W1A
M<R!SX')A\&%S`$]R9V%N:7IA8VEJ80!0861A;&EN>7,`4VES=&5M:6YI;6%S
M`$]R:6=I;F%L=7,@87!L:6MA8VEJ;W,@\&%B;&]N87,`3W)I9VEN86SX<R#P
M86)L;VYA:2`E<SH`2VET80!+:71A(&EN9F]R;6%C:6IA`%-A=FEN:6YI:V\@
M=&5I<^MS`$[K<F$@4$%-(&%U=&5N=&EF:6MA8VEJ;W,@;65C:&%N:7IM;RX`
M4$=0('-K86ET;65N:6YI<R!P87)A\&%S`%!'4"!U_FMO9'5O=&$@:6YF;W)M
M86-I:F$`4$=0('9I9?!A<VES(')A:W1A<P!01U`@<&%S:7)A\'ET:2]U_FMO
M9'5O=&D@9'5O;65N>7,`4$A0(&MO9&%S`%!(4"!#3$D`4$T@;&5N9W9A<R!L
M:65T=7,`4$T@;&G[=&ES`%!-(%0M875D<F$`4%](4"!#3$D`5&%R<&%I(&-E
M;.MS90!086MI<W1A;F%S`%!A;&%U`%7^:6UT;VII(%!A;&5S=&EN;W,@=&5R
M:71O<FEJ80!086YA;6$`4&%P=6$@3F%U:F]J:2!'=FENZVIA`%!A<F%G=F%J
M=7,`1&%L:6YA:2!D96)E<W5O=&$`4VQA<'1A_F]D:7,`4VQA<'1A_F]D:7,@
M;F5T96ES:6YG87,`4D%$2553(&%U=&5N=&EF:6MA8VEJ86D@<F5I:VEA('-L
M87!T8?YO9/YI;RX`4VQA<'1A_F]D:7,@<W4@<&%T=FER=&EN:6UU`%-L87!T
M8?YO9&ES.@!3;&%P=&'^;V1I<SH@`%-L87!T8?YO9/YI86D@='5R:2!S=71A
M<'1I+@#!:V5L=&D`P6ME;'1I(&GP(&QA:6MI;F]S:6]S('-A=6=Y:VQO<R`H
M8VQI<&)O87)D*0!+96QI87,`3F5P871V:7)T:6YT;W,@<F5G:7-T<F%C:6IO
M<SH`WFUO;NMS`%!R;V-E;G1A:0!!=&QI:W1I('!R;V9I;&%K=&EN:75S('9E
M:6MS;75S`$%R(&%T;&EK=&D@<')O9FEL86MT:6YI=7,@=F5I:W-M=7,@<')I
M<VEJ=6YG:6UO(&UE='4_`%1E:7/K<P!496ES:?@@861M:6YI<W1R879I;6%S
M`$%S;65N:6[K(&EN9F]R;6%C:6IA`%!E<G4`1WEV^VYA:0!&:6QI<&EN86D`
M5&5L969O;F%S`$YU;W1R875K;W,`4&ET:W)A;F%S`%!I:W-E;&EA:0!"86YA
M;'EBZW,`2?!S:7)I;FMI=&4@:W5R:>`@;F]R<R!C96SF`%!A='9I<G1I;FMI
M=&4L(&%R('1I:W)A:2!N;W)I=&4@:?!T<FEN=&D@\.$@96QE;65N=.`Z`%!A
M='9I<G1I;FMI=&4L(&%R('1I:W)A:2!N;W)I=&4@:?!T<FEN=&D@\&EO(&5L
M96UE;G1O(&YU;W)O9.`N`,%V97-K:71E(&WK;F5SX2!I<B!M971U<RX`P79E
M<VMI=&4@;F%U:F]S(&MA=&5G;W)I:F]S('!A=F%D:6YI;>`Z`,%V97-K:71E
M('1E:7-I;F?@($E0(&%D<F5SX"X`P79E<VMI=&4@=&5I<VEN9^`@9&%TX"P@
M<&%T:6MR:6YK:71E(&1I96[X('-K86GH:?@@;>MN97-Y:F4N`,%V97-K:71E
M('1E:7-I;F?@(&QA:6O@+@!!<')A\'EK:71E('!R;V)L96W@+@!.=7)O9'EK
M:71E('-A=F\@=F%R=&]T;VIO('9A<F3@(&)E:2!S;&%P=&'^;V3A`,%V97-K
M:71E(&YA=6K@(&MA=&5G;W)I:F]S('!A=F%D:6YI;>`Z`$QE;FMI:F$`4&]L
M:71I:V%I`$)A;'-A=FEM86D`4&]R='5G86QI:F$`4&%V96EK<VSK;&EO('!O
M>FEC:6IA`$QE;G1E;.MS('!O>FEC:6IA`$GP<V%U9V]T:2#P:6%M92!K871A
M;&]G92`H;F5G86QI;VIA($E-05`I`$MR:71U;&EA:2!P87-K+B`E<R!V86QA
M;F3@*&%S*3H@`%!R969S7VQD87`Z(&YE<F%S=&%S(')E:6MA;&EN9V%S($Q$
M05`@;6]D=6QI<RX`4')E9G-?<V5S<VEO;CH@;F5R87-T87,@<F5I:V%L:6YG
M87,@<V5S:6KX(&UO9'5L:7,N`%-LZV=I<P!3;.MG:7,@:OMR;W,@;'EG>6IE
M.B``4VSK9VES.B``4&5R_FG[<F$`4&5R_FG[<NMT:2!P879E:6MS;.MLX2!N
M875J86UE(&QA;F=E`$%N:W-T97-N:2!N=7-T871Y;6%I`$%T<W!A=7-D:6YT
M:2!D;VMU;65N=.``4VQA<'1A<VES(')A:W1A<P!0<F]B;&5M80!0<F]B;&5M
M;W,@87!R8?!Y;6%S`%!R;VIE:W1A:0!0<F'P>6UA<R!T96MS='5I`%9I9?!A
M<VES(')A:W1A<P!6:67P;VIO(')A:W1O(&%L9V]R:71M87,`5FEE\&]J;R]S
M;&%P=&]J;R!R86MT^"!P;W)A(&YE<W5G96YE<G5O=&$N`%!U97)T;R!2:6MA
M<P!+871A<F%S`%-A:VEN>7,`4E-!('9I9?!A<VES(')A:W1A<R`H)60@8FET
M86DI`"=2861I;R<@<&%S:7)I;FMI;6%S`$QI971U<P!,:65T=7,@<GET90!,
M:65T=7,@=F%K87)E`$QI^W1I<P!!='-I=&EK=&ENZR!F<F%ZZP!386YT>6MI
M<P!3:V%I='ET:0!097)S:V%I='ET:2!L86GP:V%I`%1I:W)A:2!I\'1R:6YT
M:2`E<S\@1W)A_FEN=&D@871G86P@;F5B96=A;.MS:71E+@!4:6MR86D@:?!T
M<FEN=&D@=F%R=&]T;VIO("5S(&1U;VUE;FES/R!'<F'^:6YT:2!A=&=A;"!N
M96)E9V%LZW-I=&4N`%!A:V%R=&]T:2!A;FMS=&5S;N$@=F5I:W-MX`!!=&YA
M=6II;G1I(&MA:7)I;VIO(&UE;FEU(&5L96UE;G1U<SH`071N875J:6YT:2!P
M;W)T86QO('9A:7IDX#H`4F5G97@`4^!R>?!I^"!N87+P>6MLZP!087-T86)O
M<P!.=71O;.8@<V5R=F5R:6%I`$YU=&]LYG,@55),("AH='1P.B\O=W=W+G!A
M=GEZ9'ES+F-O;2]H;W)D92DZ`$GP=')I;G1I`%!A\&%L:6YT:2!B;&]KX`!0
M86YA:6MI;G1I('-T=6QP96SA`%!A;F%I:VEN=&D@9F]R;6%T879I;>``2?!T
M<FEN=&D@<&]RX`!)\'1R:6YT:2!A=&YA=6II;FEM;R!S:W)I<'3@(&GP('-E
M<G9E<FEO(&QA:6MI;F]J;R!K871A;&]G;RX`4&'P86QI;G1I`%!A\&%L:6YT
M:2#PX2!E;&5M96YTX"!I\"!D;VMU;65N=&\`2?!T<FEN=&D@=F%R=&]T;VK@
M`%9A<G1O=&]J;R!T<GEN:6UA<SH@)7,`3F5G86QI=2!A='-A:WET:2#A('7^
M:VQA=7/@+B!+;&%I9&]S(&MO9&%S.B``2?`@;F%U:F\`4&%K96ES=&D@<VQA
M<'1A_F]DX0!3;&%P=&'^;V3^:6\@:V5I=&EM87,`4F5Z=6QT871A:0!'<N'^
M=&D@X2!N=7-T871Y;75S`%)E:OMN:6IA`$%T<W1A='ET:2!K;VYF:6?[<F%C
M:6K@`$A434P@<F5D86MT;W)I875S(&YU<W1A='EM86D`3>%S;.MS`$1E\&EN
MZVIE`$1E\&EN:6]J:2!A;G1R8?!TZP!$9?!I;FEO<VEO<R!R96EK\&WK<P!?
M16EL=73K<R!N=7-T871Y;6%I+BXN`%)O;.L`4G5M=6YI:F$`4&%S=6MT:2`Q
M.#``4&%S=6MT:2!K86ERZVX`4&%S=6MT:2!D9?!I;NMN`$5I;'5TZW,@;G5S
M=&%T>6UA:0!%:6QU=.MS(&YU<W1A='EM86D`16EL=73K<SH`4VMI<G1U:V%I
M`%-K:7)T=6MA:2!T87)P('9I<_@@96EL=>AI^"!I<B!S='5L<&5L:?@`4VMI
M<G1U:V%I('1I:R!T87)P('-T=6QP96QI^`!3:VER='5K86D@=&EK('1A<G`@
M96EL=>AI^`!6>6MD>71I`%)U<VEJ;W,@1F5D97)A8VEJ80!2=6%N9&$`4R]-
M24U%('!A<F'P87,`4R]-24U%('7^:V]D=6]T87,@;&%I\&MA<P!.ZW)A(%-!
M4TP@875T96YT:69I:V%C:6IO<R!M96-H86YI>FUO+@!335,@_FEN=73K<P!3
M44P@0TQ)`%-32`!005992T\`4U]13"!#3$D`T&7P="X`T'9E;G1O:FD@2&5L
M96YA`%-A:6YT($MI='-A<R!I<B!.979I<V%S`%-A:6YT($QI=6-I:F$`T'9E
M;G1A<VES(%!E=')A<R!I<B!-:6=E;&]N87,`4V%I;G0@5FEN8V5N=&%S(&ER
M($=R96YA9&EN86D`5&%M92!P8>AI86UE(&QA;F=E("A?<V5L9BD`4V%M;V$`
M4V%N($UA<FEN87,`4V%O(%1O;64@:7(@4')I;F-I<.L`4&%L>61O=F%S`%-A
M=61O($%R86)I:F$`2?!S875G;W1I`$GP<V%U9V]T:2`E<P!)\'-A=6=O=&D@
M;G5S=&%T>6UU<P!)\'-A=6=O=&D@<W5G96YE<G5O='5S(&YU<W1A='EM=7,@
M:V%I<"!02%`@<VMR:7!TX"!J^W/X('-E<G9E<FEO(&QA:6MI;F%J86UE(&MA
M=&%L;V=E+@`E<R!N=7-T871Y;6%I(&GP<V%U9V]T:2X`36]K<VQA<P!)9?!K
M;W1I`%!A:67P:V$`4&%S:7)I;FMI=&4@9F%I;'5S`%!A<VER:6YK:71E(&1A
M=.``4&%S:7)I;FMI=&4@9W)U<.8`4&%S:7)I;FMI=&4@;F%U:N`@<V%V:6YI
M;FO@`%!A<VER:6YK:71E('-E<G9E<N$`4&%S:7)I;FMI=&4@=F%R=&]T;VK@
M`%!A<VER:6YK:71E('9I<W5S(&1A=&]S(&MO;7!O;F5N='5S+@!087-I<FEN
M:VET92!O8FIE:W3@`$GP(/YE;6EA=2!E<V%NZ&GX('/@<F'P^"!P87-I<FEN
M:VET92!R96EK:6%M=7,@<VEM8F]L:75S+B!6ZVQI874@9V%L:71E(&IU;W,@
M;G5K;W!I:G5O=&D@X2!L86GP:^`N`%!A<VER:6YK:71E(&1A=&]S('-K:7)T
M=6O@.@!087-I<FEN:VET92!D871O<R!F;W)M873@.@!087-I<FEN:VET92!A
M<')A\.`@:W5RX2!N;W)I=&4@<F5D86=U;W1I.@!087-I<FEN:VET92!L86EK
M;R!S:VER='5KX#H`4&%S:7)I;FMI=&4@;&%I:V\@9F]R;6%TX#H`4&%S:7)I
M;FMI=&4@9'4@871I=&EN:V%NZ&EU<R!L875K=7,N`%!A<VER:6YK:71E('-P
M86QV^"!D97)I;N$N`%!A<VER:6YK:71E(&YO<FEMX"!K86QBX#H`4VGX<W1I
M('!R;V)L96UO<R!P<F%N9?!I;>``4VGX<W1I(%--4P!396YE9V%L87,`4V5N
M<V]R:75S.B``4G5G<^MJ:7,`4V5R8FEJ82!I<B!-;VYT96YE9W)A<P!397)I
M:F]S(&YU;65R:7,`4V5S:6IO<R!)1"!P87-I8F%I9^LN`%)I;FMI;GES`$YU
M<W1A='EM86D@;&5I9/YI86YT>7,@2G5M<R!P87-I:V5I<W1I('-L87!T8?YO
M9.$L(&IE:6=U(&KA(&MA9&$@;F]R<R!P86UI<O!I=&4N`$YU=&]L=7-I^"!S
M97)V97)I^"P@:W5R:75O<R!N;W)I=&4@;6%T>71I(&GP('!O<G1A;&\L(&YU
M<W1A='EM86DN`$MA;&)O<RP@;&%I:V\@>F]N;W,@:7(@9&%T;W,@;G5S=&%T
M>6UA:2X`4'5S;&%P:6\@<W!A;';X+"!A='-I;F%U:FEN:6UO(&1A_FYU;6\@
M:7(@:VET^"!V86EZ9&%V:6UO('!A<F%M971R^"!N=7-T871Y;6%I+@!287-T
M87,@871N875J:6YI;6\@<VMR:7!T87,`4W4@\&EU;R!P87)A;65T<G4@9V%L
M:6UO<R!K96QI;W,@=FEE=&]VZW,Z(`!396GP96QA:0!087)D=6]T=7;K`%1R
M=6UP87,@87!R8?!Y;6%S`$%R(&YA=61O=&D@:VQA=FEA=/MR;W,@;7EG='5K
M=7,@=F%L9'EM=6D_`%)O9'ET:0!087)O9'ET:2!S:VER='5M=7,@=&%R<"!I
M\'-A=6=O=&\@:7(@:^`@=&EK('-U9V5N97)U;W1O(&MO;F9I9_MR86-I;FEO
M(&9A:6QO+@!2;V1Y=&D@<&%S:W5T:6YI;R!P<FES:6IU;F=I;6\@;&%I:^`_
M`%)O9'ET:2!G86QI;7EBYB!P86QI:W1I(&]R:6=I;F%LX`!2;V1Y=&D@<&%R
M:7-I;FMI;>``4F]D>71I(&QE;G1E;.MS(&]P97)A8VEJ^"!M96YI=3\`4F]D
M>71I("5S(&UE;FEU(&MA:7+K:F4_`%)O9'ET:2!C96SK<R!N=7-T871Y;?@@
M;&%N9^``4F]D>71I(&QE;G1E;.MS(&YU<W1A='EM^"!L86YGX`!2;V1Y=&D@
M96EL=73K<R!N=7-T871Y;?@@;&%N9^``4F]D>71I('!A=F5I:W-LZVQI;R!N
M=7-T871Y;?@@;&%N9^``4F]D>71I(&9A:6SX(.%KZVQI;>``3&G[=&ES`$QI
M^W1I<R!R>71E`$QI^W1I<R!V86MA<F4`4W5M8?YI;G1I`%-U;6'^:6YT:2!A
M<F)A('!A<W1U;71I(&MA:6UY;FEN:75S(&)L;VMU<P!3:65R82!,96]NZP!2
M96=I<W1R86-I:F$`4&%R8?!A<P!087)A\&\@86QG;W)I=&UA<P!3:6YG87#[
M<F%S`$1Y9&ES`%!R86QE:7-T:2!P<F]F:6QA:W1I:^``4VQO=F%K:6IA`%-L
M;W;K;FEJ80!0^V=A`%-N:65G;R!G>6QI<SH@`%-N:65G;R!K:65K:7,@=F%N
M9&5N:74Z(`!3;VQO;6]N;R!S86QO<P!3;VUA;&EA`$1A:6YO<R!I<B!%:6SK
M<F'PZ&EA:0!2^_!I879I;6\@='9A<FMO<R!P87-I<FEN:VEM87,`4VEU;G3K
M:F\@861R97-A<P!0:65T^"!!9G)I:V$`4&EE=/@@175R;W!O<R`H25-/+3@X
M-3DM,RD`4&EE=/@@1/YO<F3^:6IO<R!I<B!0:65T^"!386YD=FGH;R!S86QO
M<P!0:65T:6[K(&AE;6ES9F5R80!487)P87,@=&%R<"!C96QI^`!487)P87,@
M=&%R<"!C96SK<R!T=7)I;FEO(&ER(&MR8?!T:6[K<P!487)P87,`5&%R<&%I
M('1A<G`@8V5L:?@`5&%R<&%I`$ES<&%N:6IA`%-P86UA<P!3<&5C:69I;FGX
M('-I;6)O;&GX(.%T97)P:6UA<P!097)S:V5L=&D@8V5LY@!097)S:V5L=&D@
M<W1U;'!E;.$`4&5R<VME;'1I(&5I;'5TY@!3<&]R=&%S`-!R:2!,86YK80!3
M=&%N9&%R=&%S`%-T87(@5')E:R=A<P!0<F%D:6YI86D@;65T86D`4F%J;VYA
M<R!A<F)A('!R;W9I;F-I:F$`0OMS96YA`%-A=6=O:FEM;R!F;W)M871A<P!'
M871VZW,@861R97-A<P!5_F)R875K=&D`WF]D_FGX('/@<F'P87,`3G5I;71I
M(&1O;65NX"!N=6\@861R97-O`%-T:6QI=7,@6T-34UT`4V5K;2X`5&5M80#!
M=F5S=&D`26YD96MS87,`4^MK;6EN9V$`2V]N9FEG^W)A8VEJ82!A='-T871Y
M=&$@<^MK;6EN9V%I+B!097)K<F%U:VET92!P=7-L87#A+"!K860@<&%M871Y
M='5MZW1E('!A:V5I='5M=7,N`$%T<V%R9VENZR!K;VYF:6?[<F%C:6IO<R!K
M;W!I:F$@<^MK;6EN9V%I(&GP<V%U9V]T82X`)R5S)R!SZVMM:6YG86D@=?YR
M8?!Y=&%S+@!3=61A;F%S`%1U<FEN>7,`4V%U;.MT96MI<P!3875LZVQY9VES
M`%-A=6SK=&$`4V%U;.MT96MI<P!3875LZW1E:VES+U-A=6SK;'ED:7,`4V%U
M;.MT96MI<SH@`%-A=6SK;'EG:7,`4V%U;.ML>6=I<SH@`$QA:7!S;FES`$%P
M=&%R;F%V:6UA<P!3=7)I;F%M87,`4&%V87)DZP!3=F%L8F%R9&%S(&ER($3^
M86YM86EN87,`4W9A>FEL86YD87,`T'9E9&EJ80#0=F5I8V%R:6IA`%-I;G1A
M:W/K<R!K;&%I9&$@<&%I9?!K;W,@:W)I=&5R:6IU:F4`4VER:6IO<R!!<F%B
M^"!297-P=6)L:6MA`%0M875D<F$`5"UA=61R;W,`5%-6(&9A:6QA<P!,96YT
M96SK`$QE;G1E;.MS(&YU<W1A='EM86D`3&5N=&5LZW,@;G5S=&%T>6UA:0!4
M86EV86YA<P!486EV86YA<RP@2VEN:6IO<R!P<F]V:6YC:6IA`%1A9/YI:VES
M=&%N87,`2G5N9W1I;NL@5&%N>F%N:6IO<R!297-P=6)L:6MA`%1A:6MI;GES
M.@!$87)B86D`5&5L969O;F\@;G5M97)I<P!496UP+B!P87-K+B!V86QA;F3@
M.B``5&5M<&5R873[<F$`5&5M<&5R873[<F$Z(`#086)L;V[X(&%D;6EN:7-T
M<F%V:6UA<P!496MS=&%S`%1I:R!T96MS=&%S`$QY9VEU;W1I('1E:W-TX`!4
M96MS=&\@=FER\'5J90!+971V+@!486EL86YD:65T:?!K82`H5$E3+38R,"D`
M5&%I;&%N9&%S`$'H:?L@:V%D(&YA=61O:F%TZW,@<VES=&5M82X`3NMR82!&
M5%`@;6]D=6QI;RX`2&]R9&4O2V]L86(@:6YT96=R86-I:F]S('9A<FEK;&EU
M:V%S(&YE<&%L86EK;R`B)7,B`$YE<&%V>6MO('7^:W)A=71I($UA:6YT96YA
M;F-E.CH@:VQA<^MS`$YU<W1A='EM^"!L86YG87,@=?YD87)Y=&%S+B!)\&5I
M;G4N`$IE:6=U(&YO<FET92!N875D;W1I(&YU<W1A='EM=7,L('!A<')A\'EK
M:71E(&MA9"!A9&UI;FES=')A=&]R:75S('-U:V]N9FEG^W)U;W3X('!A<W1O
M=FG@(&1U;VUE;O@@8F%ZYB!N=7-T871Y;6%M<R!S875G;W1I+@!4:6L@87!A
M=&ENZVIE('!U<^MJ90!.9>%R8?#K=&4@8V]N=&%K=&\@240@;G5M97)I;R!A
M<F)A(&II<R!N97)A<W1A<R!D=6]M96[X(&)A>NMJ92X`2V]N=&%K=&%S('/K
M:VUI;F=A:2#A=')A=6MT87,@X2!*^W/X(&%D<F5S^"!K;GEG96SF+@!.;W+K
M9&%M:2!P871I:W)I;G1I(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I(&%T<VMI
M<N`@4$=0('!A<F'P;R!B;&]KX"X`3F7A<F'PZW1E(&1I<W1R:6)U8VEJ;W,@
M<^!R8?!O($E$(&%R8F$@:FES(&YE<F%S=&%S(&1U;VUE;O@@8F%ZZVIE+@!.
M9>%R8?#K=&4@9&ES=')I8G5C:6IO<R!SX')A\&\N`%!'4"!U_FMO9&%V:6UO
M(&=A;&EM>6+K(')E:6MA;&%U:F$@<V%U9V%U<R!P<FES:6IU;F=I;6\N($)A
M;F1Y:VET92!R8?!Y=&D@:'1T<',Z+R\@861R97-O('!R863^:6]J92X`1F%I
M;&%S("5S('!R:79A;&\@='5RZW1I("5S('!A<F%M971RX"X`1F%I;&%S("5S
M('!R:79A;&\@='5RZW1I(&MA:2!K=7)I=6]S("5S('!A<F%M971R=7,N`$9A
M:6QA<R!N96=A;&D@8OMT:2!N=6MO<&EJ=6]T87,@86YT('-A=N9S+@!&86EL
M92!NZW)A(&1U;VUE;O@N`%)&0S@X,B!L86GP:V\@86YT<F'P=.MS+@!*96EG
M=2!D:7)B871E($EN=&5R;F5T($5X<&QO<F5R(&YA<O!Y:VQE+"!P:6QN865K
M<F%N:7,@<F5D86MT;W)I875S(')E_FEM87,@9V%L:2!S=6ME;'1I('!R;V)L
M96WX+"!DZVP@\&EO<R!N87+P>6MLZW,@:VQA:63X+B!'86QI=&4@;F5M871Y
M=&D@:V%I(&MU<FGX(')E9&%K=&]R:6%U<R!E;&5M96YT^"X@2F5I9W4@;F%U
M9&]J871E(%=I;F1O=W,@.7@@3U,@9W)E:>AI875S:6%I(&K[<_@@:V]M<&EU
M=&5R:7,@<&%P<F'PZ&EA=7-I86D@;G5L=?`@<&%S:V5L8F1A;6%S(&%P:64@
M<&%G<FEN9&ENYB!K;&%I9.`N7&Y<;DK[<R!B=79O=&4@<&5R<W#K=&%S+B!*
M96EG=2!V:7-T:65K(&YO<FET92!I\&)A;F1Y=&D@<&EL;F%E:W)A;N$@<F7^
M:6W@('-P875S:VET92!/2RX`07!R8?!A<R`B)7,B(&GP=')I;G1A<RX`5&EK
M(&MA:7+K:F4@<'5SZVIE`$-R>7!T7W!Q<#HZ(&ML87-E:2!R96EK:6$@;G5R
M;V1Y=&D@:W5R('ER82!';G501R!F86EL86DN`$QA:?!K87,@:?!S:?AS=&%S
M("5S(&%D<F5S871U:2`E<R!T96UA("(E<R(@8G5V;R!P87)O9'ET87,N"E1A
MZ&EA=2!T86D@;F5G87)A;G1U;VIA(&MA9"!L86GP:V%S(&)U=F\@<&5R<VMA
M:71Y=&%S(&%R8F$@<W5P<F%S=&%S+@!0879A9&EN:6UA<R!K=7+A(&YA=61O
M<VET92!N=6]R;V1O:F4@X2!L86GP:V\@<F'P>6UO('!U<VQA<.$`2&]R9&5?
M0W)Y<'1?<VUI;64Z.B!K;&%S96D@<F5I:V%L:6YG87,@3W!E;E-33"!M;V1U
M;&ES+@!.96=A;&EU(&GP<V%U9V]T:2!N=7-T871Y;6\@(B5S(BP@;F5S(&1U
M;VUE;O@@9'ED:7,@=FER\'EJ82!L96ES=&ENX"!R:6+@`%!R;V=R86UA+"!S
M:VER=&$@<&5R_FG[<NMT:2#PX2!D=6]M96[X('1I<.`@*"5S*2P@;F5R87-T
M82!S:7-T96UO:F4N`%1I:R!K86ERZVIE(&ER(&1E\&ENZVIE('!U<^MS90!4
M:6L@9&7P:6[K:F4@<'5SZVIE`%-E<G9E<FES("(E<R(@:?!T<FEN=&%S+@!3
M97)V97)I<R`B)7,B(&GP<V%U9V]T87,N`"5S(')E9VES=')A8VEJ;W,@<')A
M\'EM87,@:?!T<FEN=&%S+@!.=7)O9'ET82!E:6QU=.L@;F5E9WII<W1U;VIA
M+@!4:6L@=FER\'5T:6[K:F4@:7(@87!A=&ENZVIE('!U<^MS90!4:6L@87!A
M=&ENZVIE('!U<^MJ90!.=7-I^'-T:2!D=6]M96YY<R!P<F%R87-T:2X`3F5G
M86QI=2!I\'-A=6=O=&D@;G5S:?AS=&\@9F%I;&\N`%=E871H97(N8V]M(&)L
M;VMO(&[K<F$N`$YU<W1A='EM^"!NZW)A+@!$86QI^"P@:W5R:6%S(&=A;&EM
M82!R;V1Y=&D@;&%I\&MO('1E:W-T92P@;NMR82X`T&EA;64@;&%U:V4@X79E
M<W1A('!E<B!D875G('-I;6)O;&GX+B!*^W,@X79E9.MT92`E<RP@;R!M86MS
M:6UA;'5S('-K86GH:75S("T@)7,@<VEM8F]L:6%I+@!0<F]B;&5M;W,@<W4@
M9F%I;/@@<VEU;G1I;74Z("5S(&YE;G5S:?AS=&%S+@!.=7-I^'-T:2!F86EL
M;R!N97!A=GEK;RX@1F%I;&%S("5S('ER82!D:61E<VYI<R!N96=U(&QE:63^
M:6%M87,@9'ED:7,@*"5D(&)A:71A:2DN`$YU<VGX<W1I(&9A:6QO(&YE<&%V
M>6MO+B!&86EL87,@)7,@=&EK(&1A;&EN86D@;G5S:?AS=&%S+@!.96=A;&EU
M('!A<F]D>71I(/!I;W,@;&%I\&MO(&1A;&EE<P!+;&%I9&$@X6ME;&EA;G0@
M:V]N=&%K=&EN:75S(&1U;VUE;FES+@!+;&%I9&$@X6ME;&EA;G0@:4-A;&5N
M9&%R(&1U;VUE;FES+@!+;&%I9&$@:V]N9FEG^W)A8VEJ;W,@9F]R;6]J92X@
M1W)E:>AI875S:6%I(&YE=?YP:6QDZW1E(')E:6MI86WX(&QA=6OX+@!+;&%I
M9&$@871L:65K86YT(&YU<F]D>73@(&%D<F5S^"!K;GEG96SK<R!F=6YK8VEJ
MX"X@4&%B86YD>6MI=&4@=NML:6%U+@!+;&%I9&$@871N875J:6YA;G0@:V]N
M=&%K=&EN:75S(&1U;VUE;FES+B!086)A;F1Y:VET92!VZVQI874N`$ML86ED
M82!A=&YA=6II;F%N="!D:7-T<FEB=6-I:F]S('/@<F'PX"X@4&%B86YD>6MI
M=&4@=NML:6%U+@#0:7,@24U!4"!S97)V97)I<R!N97!A;&%I:V\@:V%T86QO
M9_@@9&%L:6II;6]S:2X`071R;V1O+"!K860@=&%I(&YE='9A<FMI;F=A<R!2
M05(@87)C:'EV87,N`$%T<F]D;RP@:V%D('1A:2!N971V87)K:6YG87,@6DE0
M(&%R8VAY=F%S+@!!=')O9&\L(&MA9"!T86D@;F5T96ES:6YG87,@:V]R=&5L
MZW,@;G5M97)I<RX`T&D@='9A<FMY:VSK(&QE:63^:6$@<VGX<W1I(/YI;G5T
M97,@<&5R($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@<&%S
M:6YA=61O:F%N="!(5%10('!R;W1O:V]L=0#0:2!T=F%R:WEK;.L@;&5I9/YI
M82!S:?AS=&D@_FEN=71E<R!P97(@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M
M86EL+F-O;2D@<&%S:6YA=61O:F%N="!(5%10('!R;W1O:V]L=0#0:2!T=F%R
M:WEK;.L@;&5I9/YI82!S:?AS=&D@_FEN=71E<R!33510('!R;W1O:V]L=2!P
M97(@5F]D869O;F4@271A;&EJ;W,@=F%R='5S+"!T:6L@5F]D869O;F4@;G5M
M97)I86US+B!*:2!R96EK86QA=6IA(&5L+B!P8?!T;R!A9')E<V\@5F]D869O
M;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`T&ES(&QA=6MA<R!P<FEV
M86QO;6%S+@#0:6%M92!L875K92!G86QI(&+[=&D@=&EK('-V96EK:65J:2!S
M:V%IZ&EA:2X`T&EA;64@;&%U:V4@9V%L:2!B^W1I('1I:R!S:V%IZ&EA:2!I
M<B!D=FET8?!K:6%I+@#0:6%M92!L875K92!G86QI(&+[=&D@=&EK(&'P='5N
M=&%I;FEA:2!S:V%IZ&EA:2X`T&EA;64@;&%U:V4@='5R:2!B^W1I(&MA8FQE
M;&EA:7,@87)B82!T87)P86ES(&%T<VMI<G1I('-V96EK:65J:2!S:V%IZ&EA
M:0#0:2!R96EK\&WK('1U<FD@8OMT:2!S:V%IZ&EU<RX`T&EA;64@;&%U:V4@
M9V%L:2!B^W1I('1I:R!S<&%L=F]S(&MO9&%S(%)'0B!(97@@9F]R;6%T92P@
M<&%V>7ID_FEU:2`G(S$R,S1!1B<N`-!I(&9O<FUA(&IA=2!A<&1O<F]T82X`
M5&%I("5S+@!486D@2V]L86(@1W)O=7!W87)E(&]B:F5K=&%S+B!.;W+K9&%M
M:2!P97+^:?MRZW1I(&]B:F5K=.`@<')I=F%L;W1E('1U<NMT:2!E;"X@<&'P
M=&\@:VQI96YTX"P@:W5R:7,@<W5P<F%N=.`@\.$@9F]R;6%TX"X@5&]K:?@@
M96PN('!A\'1O(&ML:65N=/@@<^!R8?#@(&=A;&ET92!R87-T:2!A<'-I;&%N
M:^8@)7,`T&ES(&QA:?!K87,@8G5V;R!P87)A\'ET87,@)7,@:V]D=6]T92X@
M2OMS(&YA=61O:F%T92!K:71O:VG@(&MO9'5O=.8N`-!I<R!S:V%IZ&EU<R!T
M=7)I(&+[=&D@9&ED97-N:7,@=?X@;G5LX2X`T&ES('-E<G9E<FES(&YE9V%L
M:2!I\&%R8VAY=G5O=&D@>FEP(&ER(&=Z:7`@9F%I;/@N`-!I('-I<W1E;6$@
M9&%B87(@:?!J=6YG=&$N`-!I(')E:6OP;>L@='5R:2!B^W1I('-K86GH:75S
M+@#0X2!L86YGX"!R96EK:6$@871I9&%R:6[K=&D@:?`@;G5S=&%T>6WX(&QA
M;F=O`%!E<FO[;FEJ80!":6QI971A:0!,86EK87,`3&%I:V\@87!S:V%I=&$`
M3&%I:V\@9F]R;6%T87,`3&%I:V\@<&%S:7)I;FMI;6%S`%1I;6]R;&5S=.L`
M4&%R96EG;W,`4&%V861I;FEM87,Z`$MA;0!.;W+K9&%M:2!P87-I<FEN:W1I
M(&ME;&5TX"!E;&5M96YT^"P@;&%I:WEK:71E($-O;G1R;VP@*%!#*2!A<F)A
M($-O;6UN860@*$UA8RD@:VQA=FGPX"P@:7(@<&%S:7)I;FMI=&4@<&5L92X`
MT&EA;F1I96X`4F]D>71I($A434P@:V]DX`!4;V=A<P!4;VME;&%U`%)Y=&]J
M`%1O;F=A`%9I<O!U:F4`5FER\'5T:6YI86UE(&QA;F=E("A?=&]P*0!697)T
M:6UA:0!4<FEN:61A9&%S(&ER(%1O8F%G87,`5&%I<"!A<F)A(&YE`$%N='(N
M`%1U;FES87,`5'5R:VEJ80!4=7)K:?!K82`H25-/+3@X-3DM.2D`5'5R:VWK
M;FEJ80!4=7)K<V\@:7(@2V%I:V]S;R!S86QO<P!4=79A;'4`P79E<VMI=&4@
M<V%V;R!P87-I<FEN:VEMX#H@`%4N5BX@:6YD96MS87,Z(`!54DP`4VMR:7!T
M;R!P<FES=&%T>6UO('-T871U<V\@<F%P;W)T;R!54DP`55),.@!59V%N9&$`
M56MR86EN80!.97!A=GEK;R!P97)S:V%I='ET:2!61E,@:V%T86QO9V\N`$YE
M<&%V>6MO('!R:63K=&D@<&%P:6QD;VUO<R!V87)T;W1O:F\@<F5G:7-T<F%C
M:6IO<R!I;F9O<FUA8VEJ;W,N`$YE<&%V>6MO('!A:V5I<W1I(%9&4R!F86EL
M;R`B)7,B('1E:7-I^"X`3F5P879Y:V\@<&%K96ES=&D@=&5I<VGX(%9&4R!F
M86EL=6D@)7,O)7,N`$YE<&%V>6MO('!E<F5I=&D@X2`E<RX`3F5P879Y:V\@
M<')I<VEJ=6YG=&D@<')I92!344P@<V5R=F5R:6\N`$YE<&%V>6MO('!R:7-I
M:G5N9W1I(%-33"!R9?YI;74N`$YE<&%V>6MO(&YU:V]P:6IU;W1I(%9&4R!F
M86EL;RX`3F5P879Y:V\@<W5K=7)T:2!61E,@:V%T86QO9V\@(B5S(BX`3F5P
M879Y:V\@<W5K=7)T:2!61E,@:V%T86QO9V\N`$YE<&%V>6MO('-U:W5R=&D@
M5D93(&9A:6QO+@!.97!A=GEK;R!S=6MU<G1I('1U\.AI;R!61E,@9F%I;&\N
M`$YE<&%V>6MO(&GP87)C:'EV=6]T:2!D=6]M96[X+@!.97!A=GEK;R!I\'1R
M:6YT:2`B)7,B+"!K871A;&]G87,@;F5T=?#H:6%S`$YE<&%V>6MO(&GP=')I
M;G1I("5S+"!K871A;&]G87,@;F5T=?#H:6%S`$YE<&%V>6MO(')E:W5R<VGP
M:V%I(&GP=')I;G1I(%9&4R!K871A;&]G;RX`3F5P879Y:V\@:?!T<FEN=&D@
M5D93(&MA=&%L;V=O+@!.97!A=GEK;R!I\'1R:6YT:2!61E,@:V%T86QO9V\Z
M("5S+@!.97!A=GEK;R!I\'1R:6YT:2!61E,@9F%I;&\@(B5S(BX`3F5P879Y
M:V\@:?!T<FEN=&D@5D93(&9A:6QO+@!.97!A=GEK;R!R96MU<G-I\&MA:2!I
M\'1R:6YT:2!61E,Z("5S+@!.97!A=GEK;R!N=7-T871Y=&D@9&%B87)T:6YI
M;R!K871A;&]G;RX`3F5P879Y:V\@9V%U=&D@<V5R=&EF:6MA=&\@87!R8?!Y
M;6\`3F5P879Y:V\@=?YK<F%U=&D@)7,@87!R8?!Y;6\N`$YE<&%V>6MO('!E
M<FME;'1I(%9&4R!F86EL;RX`3F5P879Y:V\@871I9&%R>71I(%9&4R!F86EL
M;R`B)7,B+@!.97!A=GEK;R!A=&ED87)Y=&D@5D93(&9A:6QO(')A\'EM=6DN
M`$YE<&%V>6MO(&%T:61A<GET:2!61E,@9F%I;&\N`$YE<&%V>6MO(&%T:61A
M<GET:2!S=7-P875S=&\@87)C:'EV;RX`3F5P879Y:V\@<&5R<VMA:71Y=&D@
M=F9S<F]O="!K871A;&]G;RX`3F5P879Y:V\@<&5R=F%D:6YT:2`E<R#A("5S
M.B!T;VMS(&MA=&%L;V=A<R!J874@96=Z:7-T=6]J80!.97!A=GEK;R!P97)V
M861I;G1I(%9&4R!K871A;&]G;RX`3F5P879Y:V\@<&5R=F%D:6YT:2!61E,@
M:V%T86QO9V\Z("5S+@!.97!A=GEK;R!P97)V861I;G1I(%9&4R!F86EL;R`B
M)7,B+@!.97!A=GEK;R!P97)V861I;G1I(%9&4R!F86EL;R`E<R\E<RX`3F5P
M879Y:V\@<&5R=F%D:6YT:2!61E,@9F%I;&\N`$YE<&%V>6MO('!A;&5I<W1I
M("=M:VES;V9S)RX`3F5P879Y:V\@:?!V97)S=&D@\&EO(%=O<F0@9&]K=6UE
M;G1O`$YE<&%V>6MO(.%R8?!Y=&D@5D93(&9A:6QO("(E<R(N`$YE<&%V>6MO
M(.%R8?!Y=&D@5D93(&9A:6QO("AC;W!Y*"D@:VQA:61A*2X`3F5P879Y:V\@
MX7)A\'ET:2!61E,@9F%I;&\@9'5O;65N^"X`4&%B<F%U:W1I`$%T\&%U:W1I
M('!A:V5I=&EM=7,`073P875K=&D@86YK<W1E<V[A('9E:6MS;>``3F5T:6OK
M=&$@<V5R=F5R:6\@:VQA:61A.B``3F5T:6OK=&$@<V5R=F5R:6\@:VQA:61A
M.B``3F5N=7)O9'ET80!5;FEK;V1A<R`H551&+3@I`$IU;F=T:6YI86D@07)A
M8O@@16UY<F%T86D`2G5N9W1I;NL@2V%R86QY<W3K`$IU;F=T:6[K<R!686QS
M=&EJ;W,`2G5N9W1I;FGX(%9A;'-T>6KX($%T;VME<V[K<R!S86QO<P!6:65N
M971A:0!.9?YI;F]M87,`3F7^:6YO;6%S(&%P:6US9VED("A!4$D@365S<V%G
M92!)1"DN`$YE_FEN;VUA<R!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I
M+@!.9?YI;F]M87,@=F%R=&]T;VIO('9A<F1A<R!I<B]A<F)A('-L87!T8?YO
M9&ES+@!086YA:6MI;G1I(&YU;W)O9.`@\&EA;2!E;&5M96YT=6D`3F7A=F%R
M9&EN=&%S`%-A=6=U;6\@<W5M971I;6%I<R!N97!R:79I;&5G:6IU;W1I('-K
M<FEP=&%I(&YE9V%L:2!A=&QI:W1I(%!E<FOK;&EM;R]+;W!I:F%V:6UO+\%K
MZVQI;6\@<')O9W)A;6GP:V%I+B!.;W+K9&%M:2!P97+^:?MRZW1I('1E8VAN
M:6YE<R!D971A;&5S(&UO>FEL;&$N;W)G('1I;FML87!Y:F4L(&ER('-U_FEN
M;W1I(&MA:7`@<VMR:7!T86US(&QE:7-T:2!P<FEE:71I('!R:64@;&%I:VEN
M;W-I;W,@<V%U9WEK;&]S+"!P87-P875S:VET92!/2RX`3F5N875D;W1I('-P
M86QV;W,`4&SK=&EN>7,@;F5P86QA:6MO;6%S`$%T;F%U:FEN=&D`071N875J
M:6YT:2`E<P!!=&YA=6II;G1I('9A<G1O=&]JX`!!=&YA=6II;FEM;R!S:W)I
M<'1A<R!I\'1R:6YT87,N`$YU<VGX<W1I`%9I<VD@;6]D=6QI^"!A=&YA=6II
M;FEM;R!F86EL86D@X6ME;'1I(.$@<V5R=F5RX2X`1&ED_FEO<VEO<R!L;W1I
M;FGP:V]S(')A:63K<P!$:61I96II(')O;>MN:?!K:2!S:V%IZ&EA:0!5<G5G
M=F%J=7,`3F%U9&]T:2!D86)A<G1I;N8Z("5S`$YA=61O=&D@4U-,`$YA=61O
M=&D@:F5I9W4@=F%R=&]T;VIO('9A<F1A<R]S;&%P=&'^;V1I<R!)35-0('-E
M<G9E<FEU:2!Y<F$@:VET;VMS+@!687)T;W1O:F%S("5S(&YE875T;W)I>G5O
M=&%S('!R:>MJ:6UU:2!P<FEE("5S+@!687)T;W1O:O@@861M:6YI<W1R879I
M;6%S`%9A<G1O=&]J;R!N=7-T871Y;6%I`%9A<G1O=&]J^"!R96=I<W1R86-I
M:F$`5F%R=&]T;VKX(')E9VES=')A8VEJ82!I\&IU;F=T82X`5F%R=&]T;VIO
M('9A<F1A<P!687)T;W1O:F\@=F%R9&%S.@!687)T;W1O:F\@=F%R9&%S.B``
M5F%R=&]T;VIA:2#P:6]J92!S:7-T96UO:F4Z`%5Z8F5K:7-T86YA<P!61E,@
M:V%T86QO9V%S(&YE96=Z:7-T=6]J82X`071O<W1O9V]S`%)A<W1O<R!T96ES
M:6YG;W,@=FEE=&]VZW,Z(`!'86QI;VII;6%S`%)E:6OP;>L@;6EN=73K;6ES
M(&YU;R!D86)A<BX`4F5I:_!MZW,`4F5I:_!MZW,@:?`@:W5R:?@@9V%L:6UA
M('!A<VER:6YK=&D`5F%N=6%T=0!+:6YT86YT:7,`5F5N97-U96QA`%!A='9I
M<G1I;FEM87,@;F5B86EG=&%S("T@\&ES(&QA:?!K87,@<W5G861I;G1A<RX`
M5F5R<VEJ80!697)S:6KX(&MO;G1R;VSK`$QY9VEU;W1I('9E<G1I:V%L:6%I
M`%9E<G1I:V%L=7,@=&%R<&%S`%9E<G1I:V%L=7,Z`$QA8F%I(&1I9&5L:7,`
M5FEE=&YA;6%S`%9I971N86UI971I\&MA("A625-#24DI`%!E<OYI^W+K=&D@
M)7,`4F]D>71I(&GP;W)I;N$@<'5S;&%PX0!097+^:?MRZW1I(&MA:7`@)7,`
M0G)I=/@@5FER9/YI;FEJ;W,@<V%L;W,`2D%6(%9I<F3^:6YI:F]S('-A;&]S
M`$UA=&]M=6UA<P!-871O;75M87,Z(`!6;V1A9F]N92!)=&%L:6IA('!E<B!3
M3510`%=!4DX`1,M-15-)3R$A(2!005194R!)T%1224Y+251%(%-+4DE05,`@
M2=`@)7,N`%9A;&ES(&ER($9U='5N80!$ZVUE<VEO`%1R9>@N`$]R^"!P<F]G
M;F]ZZP!/<O@@<')O9VYO>NL@<&%G86P`5V5A=&AE<BYC;VT`5U=7`%=75R!P
M=7-L87!I<P!+87,@<V%V86ETY@!3=F5I:VD`4W9E:6MI(&%T=GEKYB#A("5S
M`$QA8F%S+"`E<P!686MA<O@@*$E33RTX.#4Y+3$I`%9A:V%R^"`H25-/+3@X
M-3DM,34I`%9A:V%R^"!386-H87)A`$MO:^$@;6]D=6SA("5S('1U<FD@<F]D
M>71I('!O('!R:7-I:G5N9VEM;S\`2V]K<R!S:VER='5K;R!S:6UB;VQI<S\`
M2V]K<R!K86)UZ&GX('-I;6)O;&ES/P!+=7)I;W,@9F%ZZW,`2%1-3"!R961A
M:W1O<FEA=7,@;6]D=6QI^"#A:G5N9VEM87,N`%!L;W1I<P!0;&]T:7,@0U-3
M(&UA=&%I<P`E<R!K86ER:6]J;R!M96YI=2!P;&]T:7,@*'!A:V5I=&EM86D@
M8G5S(&UA='ET:2!P;R!K:71O('!R:7-I:G5N9VEM;RDZ`$QE;G1E;.MS('!L
M;W1I<P!0;&_H:6\@;6%T87,`4&QO=&ES.@!7:6MI`%;K:F\@9W)E:71I<R!M
M87IG86ES`%;K:F%S.@!6ZVIA<SH@`$GP;6EN=&ES`$1A<F)A<P!$87)B;R!A
M9')E<V%S`$1A<F)O('1E;&5F;VYA<P!8+5)E9@!8-3`Y=C,@<&%G<FEN9&EN
M:6%I(&YU<W1A='EM86D`6#4P.78S(&GP<&SK<W1O(')A:W1O('!A;F%U9&]J
M:6UA<P!8-3`Y=C,@86QT97)N871Y=G5S('9A<F1A<P!8-3`Y=C,@<F%K=&\@
M:61E;G1I9FEK871O<FEU<P!8-3`Y=C,@;6]D=6QI86D`65D`65E960!986AO
M;R$@_F5MZVQA<&ES`$MA<VUE=`!*96UE;F%S`%1A:7``5&%I<"P@8?`@<W5T
M:6YK=0!*^W,@97-A=&4@5$5+4U1)3DE!344@4D7>24U%+B!.;W+K9&%M:2!G
M<N'^=&D@X2!765-)5UE'('-P875S:VET92!;/#Y=+@!*^W,@;F5P<FES:6IU
M;F?F+@!3879O('9A<F1E(&YE9V%L:71E(&YA=61O=&D@<VEM8F]L:6\@)UPG
M+@#!=F5DZW1E(&YE=&5I<VEN9^`@96PN('!A\'1O(&%D<F5SX"X`3F5P<FEJ
M=6YGZW1E(&IO:VGX(&QA=6OX(&GP(.%K96QI86UO(&9A:6QO('!R:64@)7,@
M871I=&EN:V%M^"!L875K^"X`2OMS(&%T<VEJ=6YGZW1E+@!4=7)I=&4@X79E
M<W1I('1E:7-I;F?@('1E;&5F;VYO(&YU;65RX2`H=&EK('-K86GH:75S(&ER
M("<K)RP@:F5I9W4@;F]R:71E(&YU<F]D>71I('1A<G!T875T:6[A(&MO9.`I
M+@#!=F5DZW1E(&YE=&5I<VEN9^`@<F5I:_!MYBX`3F]RZV1A;6D@;F%U9V]T
M:7,@<F5G:7-T<F%C:6IO<R!S:7-T96UA+"!T=7)I=&4@<W5K;VYF:6?[<G5O
M=&D@9'5O;65N^"!M963^:6\@<&]S:7-T96WF+@!0<FEE\"!S:?AS9&%M:2!P
M<F%N9?!I;>`L(&%P<F'P>6MI=&4@<')O8FQE;>`N`,%R8?!Y:VET92!N=6]R
M;V1O<R!54DP`5'5R:71E('!A<VER:6YK=&D@<V5R=F5RX2P@:W5RX2!N;W)I
M=&4@:?!T<FEN=&DN`$YU<F]D>6MI=&4@=F%R=&]T;VIO('9A<F3@+"!K=7)I
M;R!D=6]M96YI<R!T<FEN871E+@!.=7)O9'EK:71E('9A<G1O=&]J;R!V87)D
MX"!T<GEN:6UU:2X`3G5R;V1Y:VET92!K=7)I86UO('9A<G1O=&]J;R!V87)D
MX"X`3G5R;V1Y:VET92!A=&YA=6II;F%M;R!V87)T;W1O:F\@=F%R9.`N`$YU
M<F]D>6MI=&4@=F5I:W-MX"X`2OMS('1U<FET92#A=F5S=&D@;F%U:F]S(&MA
M=&5G;W)I:F]S('!A=F%D:6YI;>`N`"5S('-E<VEJ82!B86EGZW-I+B!0<F'P
M;VUE('!R:7-I:G5N9W1I(&GP(&YA=6IO+@!*^W/X(&5L+B!P8?!T;R!A9')E
M<V%S.@!%;"X@<&'P=&\@861R97-A<SH`26YF;W)M86-I:F$@87!I92!*=7,`
M3G5O("5S('-E<VEJ;W,@<')A9/YI;W,@:OMS^"!)4"!A9')E<V%S('!A<VEK
M96ETZRX@5'5R:71E('!R:7-I:G5N9W1I(&GP(&YA=6IO+@!*^W/X('9A<F1A
M<R]P879A<F3K`$K[<_@@875T96YT:69I:V%V:6UO('-I<W1E;6$@;F5P86QA
M:6MO('9A<G1O=&]J^"!SX')A\&\L(&%R8F$@\&D@9G5N:V-I:F$@=?YD<F%U
M<W1A(&3K;"!T86T@=&EK<O@@<')I9?YA<^AI^"X`3G5O("5S('-E<VEJ;W,@
M<')A9/YI;W,@:OMS^"!N87+P>6MLZW,@=&EP87,@<&%S:6ME:73K+B!4=7)I
M=&4@<')I<VEJ=6YG=&D@:?`@;F%U:F\N`$K[<_@@;F%R\'EK;.L@;F5P86QA
M:6MO(/!I;W,@9V%L:6UY8NMS+@!*^W/X(&QA:6MO(&IU;W-T83H`2OMS^"!S
M=&%N9&%R=&EN:7,@87!R8?!A<SH`2OMS^"!V87)D87,O<&%V87)DZSH`2OMS
M^"!N875J87,@)7,@<VQA<'1A_F]D:7,@>7)A.B`E<P!*^W/X(&YU<W1A='EM
M86D@871N875J:6YT:2X`2OMS^"!S;&%P=&'^;V1I<R!P86ME:7-T87,`2OMS
M^"!S;&%P=&'^;V1I<R!P86ME:7-T87,N(%!A<VET:6MR:6YK:71E('-A=F\@
M<&'P=.`@:7(@<')I<VEJ=6YK:71E('-U(&YA=6IU('-L87!T8?YO9/YI=2X`
M2OMS^"!N=71O;.8@<V5R=F5R:6%I.@!*=6=O<VQA=FEJ80!:86ER87,`6F%M
M8FEJ80!::6UB86)VZP!%;F5R9VEN9V]S`%M087-LZW!T:2!C:71U;VIA;>`@
M=&5K<W3@70!;4')O8FQE;6]S('!R86YE\&EM87-=`%M2;V1Y=&D@8VET=6]J
M86W@('1E:W-TX"`M`%M2;V1Y=&D@8VET=6]J86W@('1E:W-TX"`M("5S(&5I
M;'5T97-=`%ME:6QU=.L@)7,@:?`@)7-=`%]686QD>6UA<P!?0TQ)`%]$=6]M
M96[X(&UE9&ES`%])\'1R:6YT:2!E:6QU=.8`1U]R=7#K<P!085]G86QB80!?
M4&%V96EK<VSK;&EO(&YU<W1A='EM86DN+BX`4')I<VE?:G5N9W1I`$%T<VE?
M:G5N9W1I`%]+96ES=&D@;G5O<F]DX"XN`%].=7-T871Y;6%I`%]496ESZW,`
M7TGP=')I;G1I(&YU;W)O9.`N+BX`7TMO;F9I9_MR86-I:F$`7TQE;G1E;.MS
M(&YU<W1A='EM86DN+BX`5E]A<G1O=&]J86D`861R97/X(&MN>6=E;.L`2V%L
M96YD;W)I=7,`<F%M=7,`<W!A=7-K:71E(.AI80!K<F5N=&$`9F%I;&%S`&YU
M;R`E<R`H)7,I("5S("5S`&$Z`'1U;VIA=2!P870`<&%P<F%S=&D`96EL=71E
M<UT`;6MI<V]F<R!K;&%I9&]S(&MO9&%S("5D(&)E9&%R86YT($E33RX`=F%R
M9&%S`&YE<F5A;&EZ=6]T80!D87(@;F5R96%L:7IU;W1A`'7^<F'P^"!K;GEG
M96SK`'!R;V-E;G1A:0!P:6MS96QI86D`:WEL80!R;V1Y=&D@<VMI<G1U;75S
M`'-M<S)E;6%I;"!P97(@2%144`!S=&%B:6QI`&1A<F+X('/@<F'P87,`<VQA
M<'1A_F]DX2!T=7)I=&4@X7)A\'ET:2!D=2!K87)T=7,`=6YI9FEK=6]T:0!D
M86QI<P!V87)T;W1O:F\@<&%S:7)I;FMI;6%S`'9#87)D`'`Z`'=E871H97(N
M8V]M````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O;'9?3%8O````````````````
M````````````````````````````````````````````````````````````
M`````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,S-S4S`#`R,#$S-P`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]L
M=E],5B],0U]-15-304=%4R\`````````````````````````````````````
M````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`U,34T,S,W-3,`,#(Q-S(T`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&]C86QE+VQV7TQ6+TQ#7TU%4U-!1T53+VAO<F1E+FUO````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,S4W,0`Q,#4Q-30S,S<U,P`P,C,S
M-S$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MWA($E0````!D````'````#P#``")````7`8```````"`"```*````($(```(
M````J@@```4```"S"```"````+D(```'````P@@```4```#*"```'P```-`(
M```1````\`@```@````""0``"`````L)```5````%`D```H````J"0``#```
M`#4)```'````0@D``"D```!*"0```@```'0)```%````=PD``!````!]"0``
M%````(X)```O````HPD```\```#3"0``)@```.,)```%````"@H```T````0
M"@``!0```!X*```0````)`H``!`````U"@``#P```$8*```+````5@H```\`
M``!B"@``#````'(*```/````?PH``!X```"/"@``(0```*X*```#````T`H`
M``0```#4"@``#````-D*```*````Y@H```4```#Q"@``$@```/<*```0````
M"@L```@````;"P``$````"0+```&````-0L```<````\"P```@```$0+```$
M````1PL```\```!,"P``!P```%P+```'````9`L```0```!L"P``!0```'$+
M```%````=PL```<```!]"P``$0```(4+```(````EPL``!X```"@"P``!0``
M`+\+```H````Q0L``"D```#N"P``$P```!@,```+````+`P``!$````X#```
M!````$H,```,````3PP``!H```!<#```%P```'<,```7````CPP``!L```"G
M#```'P```,,,```3````XPP``!````#W#```%P````@-```'````(`T```4`
M```H#0``(0```"X-```<````4`T```4```!M#0```P```',-```@````=PT`
M`"8```"8#0``#````+\-```,````S`T```@```#9#0``!P```.(-```&````
MZ@T```T```#Q#0``"P```/\-```,````"PX```H````8#@```@```",.```&
M````)@X``$4````M#@``,````',.```0````I`X``!\```"U#@``$````-4.
M```/````Y@X```4```#V#@``5P$``/P.```J````5!````H```!_$```!0``
M`(H0```.````D!````8```"?$```#````*80```9````LQ```!````#-$```
M#P```-X0```)````[A```!L```#X$```$0```!01```,````)A$```@````S
M$0``*P```#P1```"````:!$```@```!K$0``$@```'01```3````AQ$``"\`
M``";$0``$@```,L1```B````WA$```<````!$@``$`````D2```%````&A(`
M`!$````@$@``$@```#(2```0````11(``!@```!6$@``#P```&\2```,````
M?Q(```X```",$@``'@```)L2```D````NA(```4```#?$@``"0```.42```,
M````[Q(```X```#\$@``!0````L3```4````$1,``!`````F$P``!@```#<3
M```:````/A,```L```!9$P``!0```&43```"````:Q,```4```!N$P``$```
M`'03```$````A1,```P```"*$P``!0```)<3```%````G1,```@```"C$P``
M!P```*P3```0````M!,```8```#%$P``'P```,P3```(````[!,``",```#U
M$P``+0```!D4```2````1Q0```P```!:%```%P```&<4```$````?Q0``!``
M``"$%```'@```)44```;````M!0``!H```#0%```(P```.L4```3````#Q4`
M`!P````C%0``$@```$`5```4````4Q4```<```!H%0``"````'`5```?````
M>14``!\```"9%0``"@```+D5```#````Q!4``"<```#(%0``*P```/`5```/
M````'!8``!$````L%@``#P```#X6```+````3A8```P```!:%@``$````&<6
M```0````>!8```P```")%@``#@```)86```"````I18```H```"H%@``+P``
M`+,6```\````XQ8``!`````@%P``&P```#$7```4````31<``!````!B%P``
M!0```',7```!````)`````````!.````'0```$\````7````10````<````B
M`````````$T````A`````````$L```!B````"@```!$`````````#````#(`
M``!3````,0`````````E````1@```%T`````````4@```$(```!5````````
M`$<````L````+P```%8```!1````-0```!`````(````/@```$$```!?````
M*P````\````Y````2@```",````8````,P```$`````H````8`````L`````
M`````````%0``````````````#T````)`````````"X```!(````7````#H`
M````````#@````````!9`````````#8`````````&P```#\````<````&@``
M``T````[``````````0````%`````````!(`````````$P````````!7````
M+0`````````F```````````````5````!@````````!;````-P```!D`````
M````7@`````````X````-`````````!)````'P```%H```!$`````````!X`
M`````````````&,`````````6````"D`````````,```````````````/```
M`&0```!0`````````!8````@``````````,```!A````0P```"H````G````
M3`````(`````````%``````E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@
M0V]N9FER;6%T:6]N`#(T(&AO=7)S`$%-+U!-`$%D9"!P86ER`$%D9')E<W,`
M06QI87,`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!=F%I;&%B
M;&4@9FEE;&1S.@!":7)T:&1A>0!#86QE;F1A<@!#86YC96P@4')O8FQE;2!2
M97!O<G0`0V5L;"!0:&]N90!#;&]S92!7:6YD;W<`0V]M<&%N>0!#;W5L9"!N
M;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!$1`!$86EL>0!$
M969A=6QT($ED96YT:71Y`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E=&%I;',@
M:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1I<W!L
M87D@3W!T:6]N<P!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E
M+G!H<`!%;6%I;`!%;7!T>2!R97-U;'0N`$5R<F]R`$5V97)Y(#$U(&UI;G5T
M97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G
M:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E
M<SH`1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C
M;VYN96-T('1O($Q$05`@<V5R=F5R+@!&87@`2&5L<`!(;VUE($%D9')E<W,`
M2&]M92!0:&]N90!(;W)D90!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@
M9FEE;&1S.@!,86YG=6%G90!,:7-T($AE;'`@5&]P:6-S`$QO9R!I;@!,;V<@
M;W5T`$U-`$UA:6P`36%T8VAI;F<@9FEE;&1S`$UE<W-A9V4`36]N=&AL>0!.
M86UE`$YE=F5R`$YO=&5S`$]P=&EO;G,`3W1H97(@26YF;W)M871I;VX`4&%S
M<W=O<F0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!H;VYE`%!L
M96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E
M('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4')O8FQE;2!$
M97-C<FEP=&EO;@!296UO=F4@<&%I<@!2971U<FX@=&\@3W!T:6]N<P!2;VQE
M`%-A=F4@3W!T:6]N<P!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE
M8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!3
M96QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-K:7`@36%I;G1E
M;F%N8V4`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W5C8V5S<P!487-K<P!4
M:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!V86QU92!M
M=7-T(&)E(&$@;G5M8F5R+@!4:71L90!54DP`56YA8FQE('1O(&-O;FYE8W0@
M=&\@4U%,('-E<G9E<BX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@
M9&]C=6UE;G0`56YD;R!#:&%N9V5S`%5S97(@3W!T:6]N<P!5<V5R;F%M90!7
M87)N:6YG`%=E96ML>0!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=O<FL@
M061D<F5S<P!7;W)K(%!H;VYE`%E9`%EE87)L>0!9;W4@;75S="!D97-C<FEB
M92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M
M(')E<&]R="X`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@
M;&]G:6X@86=A:6XN`%EO=7(@26YF;W)M871I;VX`66]U<B!O<'1I;VYS(&AA
M=F4@8F5E;B!U<&1A=&5D+@!;4')O8FQE;2!297!O<G1=`%ML:6YE("5S(&]F
M("5S70!V0V%R9`!0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#(N,0I297!O
M<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E
M871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N
M+41A=&4Z(#(P,#(M,3$M,C@@,30Z,#`K,#(P,`I,87-T+51R86YS;&%T;W(Z
M($MA<W!A<G,@2V%P96YI96MS(#QK87-P87)S0')C8RYL=CX*3&%N9W5A9V4M
M5&5A;3H@3&%T=FEA;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R
M<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U#
M4#$R-3<*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:70*`"5S(%5Z
M='5RY_!A;F%S(&]P97+B8VEJ87,@+2!A<'-T:7!R:6[B:G5M<P`R-"!S='5N
M9&%S`$%-+U!-`%!I979I96YO="!PXG)I`$%D<F5S90!!:7IS=.)J=N)R9',`
M3F]RXF3N=&$@;F5D97+N9V$@=N=R=.YB80!0:65E:F%M:64@;&%U:VDZ`$1Z
M:6WP86YA<R!D:65N80!+86QE;F3B<G,`071C96QT('!R;V)LYVUA<R!P:65T
M96EK=6UU`$UO8FEL86ES('3B;')U;FES`$%I>G;G<G0@;&]G=0!5>O+G;75M
M<P!.96EZ9&5VXG,@871VYW)T($UA:6YT96YA;F-E7U1A<VL@;6]D=6QI("5S
M`$1$`$EK9&EE;F%S`%!A<F%S=.(@:61E;G1I=.)T90!!<')A:W-T:65T('!R
M;V)LYVUU`%/N:^)K82!I;F9O<FWB8VEJ82!I<B!N;W/[=.YT82!A9&UI;FES
M=')A=&]R86TN`$5K<N)N82!I97-T873N:G5M:0!.878@=&EE\&%S('!I965J
M87,@;6%I;G1E;F%N8V4N<&AP`$4M<&%S=',`5'5K\',@<F5Z=6QTXG1S+@!+
M[_MD80!+871R87,@,34@;6EN^W1E<P!+871R87,@,S`@<V5K=6YD97,`2V%T
M<F%S(#4@;6EN^W1E<P!+871RXB!P:65S;.=G\&%NXG,@<F5I>N<`2V%T<G4@
M<'5S<W1U;F1U`$MA=')U(&UI;OMT:0!087)A=6=VYW)T[F)A<P!.96EZ9&5V
MXG,@<V'R96UT(&EE<W1A=.YJ=6UU<RX`3F5I>F1E=N)S('!I97-LYV=T:65S
M($Q$05`@<V5R=F5R:6TN`$9A:W-S`%!A;.YD>NYB80!-XFIA<R!A9')E<V4`
M3>)J87,@=&5L969O;G,`2&]R9&4`265LXF3G=&%I<R!L875K<SH@)7,`265L
MXF3G=&EE(&QA=6MI.@!686QO9&$`4&%RXF3N="!P86SN9'KN8F%S('1E;6%T
M=7,`4&EE<VSG9W1I97,`27II970`34T`4&%S=',`4V%S:V%N;_!I92!L875K
M:0!::?)A`$MA=')U(&WG;F5S:0!6XG)D<P!.96MA9`!0:65Z[FUE<P!/<&-I
M:F%S`$-I=&$@:6YF;W)MXF-I:F$`4&%R;VQE`$EZ<&EL9.YT('5Z='5RY_!A
M;F%S(&]P97+B8VEJ87,`5.)L<G5N:7,`3/MD>G4@;F]RXF1I970@<')O8FSG
M;6%S(&%N;W3B8VEJ=2X`3/MD>G4@;F]RXF1I970@<V%V=2!L:65T;W3B:F$@
M=N)R9'4@=6X@<&%R;VQI`%!R;V)LYVUA<R!A<')A:W-T<P!)>F1ZYW-T('#B
M<FD`071G<FEE>G1I97,@<&EE(&]P8VEJXFT`3&]M80!386=L86+B="!O<&-I
M:F%S`$EZ=N=L:65T:65S(&1A='5M82!A=&1A;.YTXFIU.@!)>G;G;&EE=&EE
M<R!D871U;6$@9F]R;>)T=3H`27IVYVQI971I97,@;&%I:V$@9F]R;>)T=3H`
M27IVYVQI971I97,@9&EV=7,@<V%D97+N9W5S(&QA=6MU<RX`27IVYVQI971I
M97,@=F%L;V1U.@!.;W/[=.YT('!R;V)LYVUA<R!P:65T96EK=6UU`$EZ;&%I
M<W0@=7IT=7+G\&%N=0#.<&'P;R!S:6UB;VQU(&EE=F%D90!696EK<VUE`%5Z
M9&5V=6UI`-!I;2!S:V%I=&QI;2!I<B!JXF+[="!V:7-M87H@,2X`T&%I(';G
M<G3N8F%I(&ER(&KB8OMT('-K86ET;&EM+@!6:7)S<F%K<W1S`%523`!.878@
M:65S<.=J86US('!I97-LYV=T:65S(%-13"!S97)V97)I;2X`3F%V(&EE<W#G
M:F%M<R!I;G1E<G!R973G="#P;R!7;W)D(&1O:W5M96YT=0!!=&-E;'0@:7IM
M86GR87,`3&EE=&]TXFIA(&]P8VEJ87,`3&EE=&]TXFIA(';B<F1S`$)R[F1I
M;N)J=6US`$MA=')U(&YE9.?O=0!,86EP;FD@;/MD>F%M("5S`$QA:7!N:2!L
M^V1Z;2P@)7,`1&%R8F$@861R97-E`$1A<F)A('3B;')U;FES`$='`$MA=')U
M(&=A9'4`07!R86MS=&EE="!P<F]B;.=M=2!P:7)M<R!P:65T96EK=6UA('/[
M=.[P86YA<RX`2OMS=2`E<R!S97-I:F$@:7(@8F5I9W5S:65S+B!,^V1Z=2!P
M:65S;.=D>FEE=&EE<R!A=&OB<G1O=&DN`$K[<W4@:6YF;W)MXF-I:F$`2OMS
M=2!O<&-I:F%S(&ER('-A9VQA8N)T87,N`%M0<F]B;.=M87,@>FGR;VIU;7-=
M`%MR:6YD82`E<R!N;R`E<UT`=D-A<F0`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L;V-A;&4O;6M?34LO````````````````````````````````````
M`````````````````````````````````````````````#`P,#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S4S`#`R,#$Q,P`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]M:U]-2R],0U]-15-304=%
M4R\`````````````````````````````````````````````````````````
M````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U
M,34T,S,W-3,`,#(Q-S`P`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE
M+VUK7TU++TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`Q,C8Q,``Q,#4Q-30S,S<U,P`P,C,S,S8`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````WA($E0````!8````'```
M`-P"``!_````G`4```````"8!P``*````)D'```(````P@<```4```#+!P``
M#P```-$'```(````X0<```@```#J!P``&0```/,'```'````#0@```X````5
M"```!0```"0(```1````*@@```@````\"```%0```$4(```*````6P@```P`
M``!F"```!P```',(```0````>P@``"D```","````@```+8(```%````N0@`
M`!````"_"```!@```-`(```4````UP@``"8```#L"```!0```!,)```-````
M&0D```4````G"0``"P```"T)```/````.0D``"$```!)"0```P```&L)```$
M````;PD```P```!T"0``"@```($)```%````C`D``!(```"2"0``$````*4)
M```0````M@D``!H```#'"0``!@```.()```'````Z0D```(```#Q"0``!```
M`/0)```/````^0D```<````)"@``!P```!$*```$````&0H```4````>"@``
M"````"0*```5````+0H``!X```!#"@``!0```&(*```H````:`H``"D```"1
M"@``$P```+L*```+````SPH```4```#;"@``$0```.$*```$````\PH```P`
M``#X"@``&@````4+```7````(`L``!<````X"P``&P```%`+```3````;`L`
M`!````"`"P``%P```)$+```'````J0L```4```"Q"P```P```+<+```@````
MNPL``"8```#<"P``#`````,,```(````$`P``!0````9#```!P```"X,```&
M````-@P```L````]#```#````$D,```*````5@P```(```!A#```!@```&0,
M``!%````:PP``"8```"Q#```)0```-@,``!S````_@P``!````!R#0``<0$`
M`(,-```B````]0X```<````8#P``!0```"`/```4````)@\```H````[#P``
M#P```$8/```G````5@\```8```!^#P``#@```(4/```%````E`\``!````":
M#P``"````*L/```5````M`\```<```#*#P``%0```-(/```%````Z`\```\`
M``#N#P``.P```/X/```"````.A````8````]$```%````$00```'````61``
M`!$```!A$```*@```',0```'````GA```!````"F$```!@```+<0```1````
MOA````<```#0$```)0```-@0```$````_A````4````#$0``#P````D1```/
M````&1$```4````I$0``%````"\1```3````1!$``!8```!8$0``)@```&\1
M```(````EA$```4```"?$0```@```*41```%````J!$``!8```"N$0``!@``
M`,41```'````S!$```,```#4$0``"0```-@1```'````XA$``!T```#J$0``
M'`````@2```'````)1(``"`````M$@``,````$X2```1````?Q(```P```"1
M$@``!0```)X2```1````I!(```4```"V$@``#0```+P2```<````RA(``!D`
M``#G$@``&0````$3```>````&Q,``!L````Z$P``$P```%83```=````:A,`
M``<```"($P``!@```)`3```#````EQ,``"H```";$P``*P```,83```3````
M\A,```X````&%```%@```!44```(````+!0```<````U%```#@```#T4```0
M````3!0``!$```!=%````@```&\4```'````<A0``#````!Z%```*P```*L4
M```I````UQ0``&X````!%0``%P```'`5```!````+````"H`````````5@``
M``L`````````&```````````````1````"@`````````%```````````````
M-0````4```!*`````@````,````[````2````!(`````````40```#X````S
M````(0```#(```!,````&@`````````O````(```````````````5P```!8`
M```K````$P````````!&````'P````8````Y````````````````````"@``
M`$(````G```````````````D````#P````P```!-````1P```#8`````````
M.@```"D```!+````!P```",```````````````````!3````0````!X````T
M````'``````````=`````````"(````1```````````````_````````````
M```7````0P```%0```!/````)0```!4````P````3@`````````.````/```
M`!````!8``````````````!%``````````T`````````&P````D````(````
M`````%`````9`````````"8````$````,0```#@````]````50```%(````M
M``````````````!)````00```#<`````````+@```````````````"5S($UA
M:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`,C0@:&]U<G,`
M04TO4$T`061D(&$@;F5W('5S97(Z`$%D9"!P86ER`$%D9"!U<V5R`$%D9&EN
M9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&UI;FES=')A=&EO;@!!
M;&EA<P!!=F%I;&%B;&4@9FEE;&1S.@!":7)T:&1A>0!#86YC96P@4')O8FQE
M;2!297!O<G0`0V5L;"!0:&]N90!#;&]S92!7:6YD;W<`0V]M<&%N>0!#;VYF
M:7)M(%!A<W-W;W)D`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@
M;6]D=6QE("5S`$1$`$1A:6QY`$1E9F%U;'0@261E;G1I='D`1&5L971E`$1E
M<V-R:6)E('1H92!0<F]B;&5M`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I
M;G1E;F%N8V4N<&AP`$5M86EL`$5M<'1Y(')E<W5L="X`17)R;W(`179E<GD@
M3&]G:6X`17AA;7!L92!V86QU97,Z`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$
M05`@<V5R=F5R+@!&87@`2&5L<`!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(
M;W)D90!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!,:7-T
M($AE;'`@5&]P:6-S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QO9R!I
M;@!,;V<@;W5T`$U-`$UA:6P`36%T8VAI;F<@9FEE;&1S`$UE<W-A9V4`36]N
M=&AL>0!.86UE`$YO=&5S`%!A<W-W;W)D`%!A<W-W;W)D<R!M=7-T(&UA=&-H
M+@!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&AO;F4`4&QE87-E
M('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O
M=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0<F]B;&5M($1E<V-R
M:7!T:6]N`%)E;6]V92!P86ER`%)E<V5T`%)E='5R;B!T;R!/<'1I;VYS`%)O
M;&4`4V%V92!/<'1I;VYS`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E
M;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z
M`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396YD(%!R;V)L96T@4F5P
M;W)T`%-K:7`@36%I;G1E;F%N8V4`4W!E8VEA;"!#:&%R86-T97(@26YP=70`
M4W5C8V5S<P!4:71L90!54DP`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E
M<G9E<BX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`
M56YD;R!#:&%N9V5S`%5S97)N86UE`%5S97)S(&EN('1H92!S>7-T96TZ`%=A
M<FYI;F<`5V5E:VQY`%=E;&-O;64L("5S`%=O<FL@061D<F5S<P!7;W)K(%!H
M;VYE`%E9`%EE87)L>0!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B
M969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W5R(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T
M:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R
M96%S;VXN`%M0<F]B;&5M(%)E<&]R=%T`4')O:F5C="U)9"U697)S:6]N.B!M
M:U]-2PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R
M9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/
M+5)E=FES:6]N+41A=&4Z(#(P,#,M,#8M,C8@,34Z,3@K,#(P,`I,87-T+51R
M86YS;&%T;W(Z(%-T;VIA;B!097-O=B`\<W-P0&5U<F5K82YC;VTN;6L^"DQA
M;F=U86=E+51E86TZ($UA8V5D;VYI86X@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G
M/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[
M(&-H87)S970]25-/+3@X-3DM-0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG
M.B`X8FET"E@M1V5N97)A=&]R.B!+0F%B96P@,2XP+C$*`"5S(+[?U>#0YMC8
M(-?0(-[4X-;CTM#ZU2`M(+_>XM+@U-``,C0@Y]#AT`!!32]030"TWM30U-@@
MW=[2(-K>X-CAW=C:.@"TWM30U-@@W]#@`+3>U-#4V"#:WN#8X=W8V@"TWM30
MTM#ZU>+>(-W0(-K>X-CAW=CFV"#5(-[=U=+>U]S>UM7=WBX`L-3@U>'0`+#4
MW-C=V.'BX-#FV/C0`$%L:6%S`+3>X>+0W]W8(-_>V]CZT#H`P-[4U=W4U=T`
MON+:T-;8(+_@WM';U=P@P-7?WN#B`+S>T=C;U=T`M]#BTM[@V"#3WB#?X-[7
MWN#5YM[B`,38X-S0`+_>XM+@U-@@V][7V-W:T`"\WM3CV][B(-W0(-?0U-#G
MT.+0(-?0(-[4X-;CTM#ZU2`E<R#=U2#<WM;5(-30(-'8U-4@WN+2WN#5W0!$
M1`"TW=72W=X`P>+0W=30X-35W2#8U-7=XMCBU>(`N-?1X-CHV`"^W]CA(-W0
M(-_@WM';U=S>X@"]U2#?X-CAXM#?X]+0^"#4V.#5VN+=WB#4WB!M86EN=&5N
M86YC92YP:'``U2W?WNCBT`"_X-#7U=T@X-77X]OBT.(N`+/@U>C:T`#!U=K>
MU2#?X-CXT-+CTM#ZU0"_X-C<U>`Z`+W5X^'?U>C=T"#:WMW5VN;8^-`@X=X@
M3$1!4"#AU>#2U>#>XBX`Q-#:X0"_WMS>Z`"TWMS0Z-W0(-#4X-7AT#H`M-[<
MT.C5W2#BU=O5Y-[=`$AO<F1E`+C<W][@XMC@T-W>(-_>V]4Z("5S`+C<W][@
MXMC@T-W8(-_>V]CZT#H`N-?;V.'BT/@@XM7<V"#7T"#?WMS>Z`"[V.'BT/K5
MXMX@W=`@VM[@V.'=V.;8(-4@WMW5TM[7W-[6U=W>+@"[WM/8X-#ZU0"XU]O5
MUP!-30"_WNCBT`"ZWN#5X=_>W=38X-#GVM@@W][;V/K0`+_>X-#:T`"\U>'5
MY]W>`+C<U0"WT-'5V]7HVM@`N][7V-W:T`"[WM?8W=K8XM4@W-[@T"#4T"#1
MV-30XB#8X>+8+@"XU]+@Z-@@WM_5X-#FV-@@U]`@WM3@UN/2T/K5`,+5V]7D
MWMT`LM4@W-[;V-S5(-W0TM74U>+5(-/>(-_@WM';U=S>XBX`LM4@W-[;V-S5
M(-W0TM74U>+5(-+0Z-4@VM[@V.'=V.?:WB#8W-4@V"#;WM?8W=K0`+[?V.$@
MW=`@W^#>T=O5W-[B`+[4X>+@T-W8(-_0X`!297-E=`"]T-?0U"#:WMT@WM_F
MV-CBU0##V][3T`"WT.?CTM#X(-[?YMC8`+C7T=7@V"#AU=_0X-#BWN`@U]`@
MU-#BX]S>XCH`N-?1U>#8(.3>X-S0XB#7T"#4T.+CW-[B.@"XU]'5X-@@Y-[@
MW-#B(-?0(-+@U=S5XMXZ`+C7T=7@V"#4TM4@WM33WM+0X-#GVM@@W][;V/K0
M+@"_X-#BV"#8U]+5Z.+0^"#7T"#?X-[1V]7<WN(`O^#5X=K>VMW8(-[4X-;C
MTM#ZU0"RW=7AX]+0^M4@W=`@X=_5YMCXT-O=V"#7W=#FV`##X=_5Z-W>`+W0
MX=O>T@!54DP`O=4@W-[6U=(@U-`@X=4@VM[=U=KBV.#0W"#AWB!344P@X=7@
MTM7@WN(N`+W5(-S>UM72(-30(-/>(-_@U=+5U-#<(-[2WO@@5V]R9"#4WMKC
MW-7=XBX`ON+:T-;8(-/8(-_@WMS5W=CBU0"ZWN#8X=W8Y]K>(-C<U0"ZWN#8
MX=W8YM@@TMX@X=CAXM7<WN(Z`++=V-S0W=C5`+W5U-7;W=X`M-[1X-74WOC4
MU2P@)7,`L-3@U>'0(-W0(.#0T=[BT`#"U=O5Y-[=(-W0(.#0T=[BT`"SLP"S
MWM38Z-W>`+[?V.C5XM4@T]X@W^#>T=O5W-[B(-_@U=0@U-`@V.'?X-#BU>+5
M(-C7TM7HXM#X+@"]T-+5U-7BU2#:WM4@VM[@V.'=V.?:WB#8W-4@U-`@X=4@
MWN+AXN#0W=@N`+W0TM74U>+5(-K>U2#:WN#8X=W8Y]K>(-C<U2#4T"#AU2#4
MWM30U-4N`++0Z-C>XB#0TN+>X-C7T.;8WMW5W2#?X-[BWMK>VR#=U2#?WM3@
MUN/2T"#;V.'BT/K5(-K>X-CAW=CFV"P@V-O8(.+0T"#<WM;=WN'B(-4@WMW5
MTM[7W-[6U=W0(-[4(-3@X]/8(-_@V.?8W=@N`%NXU]+5Z.+0^"#7T"#?X-[1
MV]7<WN)=````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VYB7TY/+P``````````````````
M````````````````````````````````````````````````````````````
M```P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,S<U,P`P,C`Q,3``(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O;F)?
M3D\O:&5L<"YX;6P`````````````````````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`S,S(P`#$P-3$U-#,S-S4S`#`R,34V,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/WAM;"!V97)S:6]N/2(Q+C`B
M/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L92]N8E].3R]H96QP+GAM;"QV
M(#$N,B`R,#`T+S`U+S(W(#(P.C(R.C$T(&IA;B!%>'`@)"`M+3X*/&AE;'`^
M"B`@/&5N=')Y(&ED/2)S=6UM87)Y(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H
M92!0;W)T86P@4&%G93PO=&ET;&4^"B`\<&%R83X*("!4:&ES('!O<G1A;"!P
M86=E('!R;W9I9&5S(&$@<75I8VL@<W5M;6%R>2!O9B!A;&P@>6]U<B!I;7!O
M<G1A;G0*("!I;F9O<FUA=&EO;BX@1F]R(&5X86UP;&4L(&ET(&UI9VAT('-H
M;W<@:&]W(&UA;GD@;F5W(&4M;6%I;"!M97-S86=E<R!Y;W4*("!H879E(&EN
M('EO=7(@24Y"3U@L('5P8V]M:6YG(&5V96YT<R!O;B!Y;W5R(&-A;&5N9&%R
M+"!T87-K<R!O;B!Y;W5R('1O+61O"B`@;&ES="P@:&5A9&QI;F5S(&9R;VT@
M<V5L96-T960@;F5W<R!S97)V:6-E<RP@86YD('-O(&]N+B`@36%N>2!O9B!T
M:&5S90H@('-U;6UA<FEE<R!W:6QL(&-O;G1A:6X@<75I8VL@<VAO<G1C=71S
M('1O(&-O;6UO;B!F=6YC=&EO;G,L('-U8V@@87,*("!C;VUP;W-I;F<@82!N
M97<@;6%I;"!M97-S86=E+"!C<F5A=&EN9R!A(&YE=R!C86QE;F1A<B!E=F5N
M="!O<B!T87-K+"!E=&,N"B`\+W!A<F$^"B`\<&%R83X*("!4:&4@8V]N=&5N
M=',@;V8@=&AI<R!P;W)T86P@<&%G92!A<F4@8W5S=&]M:7IA8FQE('9I82!T
M:&4@3&%Y;W5T(&)U='1O;BX*("!&;W(@97AA;7!L92P@>6]U(&-A;B!C:&]O
M<V4@=VAI8V@@:71E;7,@=&\@:6YC;'5D92!O;B!T:&ES('!O<G1A;"!P86=E
M(&%S"B`@=V5L;"!A<R!I;B!W:&EC:"!O<F1E<B!T:&5Y(&%R92!S:&]W;BX*
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](FYA=F)A<B(@<W1A=&4]
M(FYE=R(^"CQT:71L93Y4:&4@07!P;&EC871I;VX@3F%V:6=A=&EO;B!"87(\
M+W1I=&QE/@H@/'!A<F$^"B`@070@=&AE(&QE9G0@:&%N9"!S:61E(&]F('1H
M92!W96(@<&%G92!I<R!T:&4@87!P;&EC871I;VX@;F%V:6=A=&EO;B!B87(N
M"B`@0VQI8VL@;VX@=&AE(&EC;VYS(&]N('1H:7,@;F%V:6=A=&EO;B!B87(@
M=&\@<75I8VML>2!A;F0@96%S:6QY('-W:71C:`H@(&)E='=E96X@=&AE(&%V
M86EL86)L92!A<'!L:6-A=&EO;G,N"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$;R!-86EN=&5N
M86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME
M('1O('!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;BP@
M8VAE8VL@=&AI<R!B;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)P<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*
M("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($-O;F9I<FT@
M36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U
M;&0@;&EK92!T;R!C;VYF:7)M(&%L;"!M86EN=&5N86YC92!T87-K<R!B969O
M<F4@=&AE>2!A<F4@<G5N+"!C:&5C:R!T:&ES(&)O>"X@268@;&5F="!U;F-H
M96-K960L(&%L;"!M86EN=&5N86YC92!O<&5R871I;VYS('1H870@;F5E9"!T
M;R!B92!R=6X@=VEL;"!B92!P97)F;W)M960@875T;VUA=&EC86QL>2!W:71H
M(&YO(&-H86YC92!T;R!C86YC96P@;VX@;&]G:6XN"B`@("`\+W!A<F$^"CPO
M96YT<GD^"CPO:&5L<#X*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VYB7TY/+TQ#
M7TU%4U-!1T53+P``````````````````````````````````````````````
M```````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#4Q-30S,S<U,P`P,C$V-S4`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L;V-A;&4O;F)?3D\O3$-?34534T%'15,O:&]R9&4N;6\`````````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,38Q,#0S`#$P-3$U-#,S-S4S`#`R,S,T,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#>$@25````
M`%$#```<````I!H``'\$```L-0```````"A'``!(````*4<```X```!R1P``
M#P```(%'```-````D4<```@```"?1P``"P```*A'```,````M$<```0```#!
M1P``#````,9'```1````TT<``"4```#E1P``#P````M(```+````&T@``!$`
M```G2```#@```#E(```%````2$@``"@```!.2```"````'=(```*````@$@`
M`!4```"+2```$@```*%(```+````M$@``!0```#`2```)@```-5(```G````
M_$@``"8````D20``$P```$M)```.````7TD```H```!N20``#0```'E)```G
M````ATD``"````"O20``#@```-!)```7````WTD``"(```#W20``-0```!I*
M```1````4$H```T```!B2@``#````'!*```-````?4H```8```"+2@``&P``
M`))*```M````KDH``"0```#<2@``*0````%+```9````*TL``!@```!%2P``
M#````%Y+```.````:TL```X```!Z2P``"````(E+```N````DDL``!H```#!
M2P``,@```-Q+```X````#TP``%0```!(3```40```)U,``!:````[TP``%<`
M``!*30``-````*)-```%````UTT``!$```#=30``"````.]-```)````^$T`
M``D````"3@``#@````Q.```(````&TX``"4````D3@``(````$I.```0````
M:TX```\```!\3@``"@```(Q.```'````ETX```,```"?3@``#P```*-.```4
M````LTX```D```#(3@``#0```-).```2````X$X``!D```#S3@``'@````U/
M```/````+$\```H````\3P``#P```$=/```(````5T\``"0```!@3P``%P``
M`(5/```4````G4\``!8```"R3P``"````,E/``!.````TD\``"T````A4```
M'P```$]0```9````;U````<```")4```#````)%0```L````GE````X```#+
M4````P```-I0```%````WE````4```#D4```"@```.I0```#````]5```!<`
M``#Y4```"@```!%1```/````'%$```X````L40``&````#M1```C````5%$`
M``X```!X40``%````(=1```7````G%$``!<```"T40``%P```,Q1```3````
MY%$```\```#X40``'P````A2```/````*%(```8````X4@``"P```#]2```0
M````2U(``!4```!<4@``%0```')2```'````B%(``!````"04@``$0```*%2
M```,````LU(``#L```#`4@``.````/Q2```#````-5,```D````Y4P``.0``
M`$-3```2````?5,``#D```"04P``)P```,I3```L````\E,``"H````?5```
M)0```$I4```)````<%0```H```!Z5```!P```(54```O````C50``#<```"]
M5```+@```/54``!5````)%4``"T```!Z50``+0```*A5```M````UE4``$``
M```$5@``(P```$56```C````:58``"T```"-5@``,P```+M6```5````[U8`
M`!D````%5P``*0```!]7```D````25<``!$```!N5P``$0```(!7```,````
MDE<```H```"?5P``$````*I7```6````NU<``!8```#25P``!````.E7```G
M````[E<```@````66```!P```!]8```(````)U@``"D````P6```#@```%I8
M```*````:5@```0```!T6```"0```'E8```&````@U@``!$```"*6```!P``
M`)Q8```$````I%@```8```"I6```#0```+!8```#````OE@```,```#"6```
M%P```,98```3````WE@```@```#R6```!````/M8``!!`````%D``"````!"
M60``!@```&-9```&````:ED``!4```!Q60``&````(=9```B````H%D``"X`
M``##60``'0```/)9```A````$%H``%0````R6@``*0```(=:```'````L5H`
M`!4```"Y6@``"@```,]:```/````VEH```T```#J6@``#P```/A:```-````
M"%L```D````66P``!@```"!;```3````)UL``!0````[6P``#````%!;```&
M````75L``%0```!D6P``!````+E;```.````OEL``$0```#-6P``$0```!)<
M```1````)%P``!$````V7```'````$A<```J````95P``"$```"07```!0``
M`+)<```3````N%P``!(```#,7```"@```-]<```/````ZEP``!$```#Z7```
M$P````Q=```,````(%T```8````M70``!@```#1=```0````.UT``!$```!,
M70``!0```%Y=```,````9%T``!````!Q70``#0```()=```&````D%T```<`
M``"770``#0```)]=```0````K5T```D```"^70``!P```,A=```+````T%T`
M``L```#<70``!P```.A=```)````\%T``!0```#Z70``"0````]>```*````
M&5X``!D````D7@``'0```#Y>```,````7%X``!````!I7@``$@```'I>```3
M````C5X``"L```"A7@``.P```,U>```@````"5\``#8````J7P``$````&%?
M```(````<E\```8```![7P``!````()?```.````AU\``!````"67P``'@``
M`*=?```;````QE\``"$```#B7P``'@````1@```9````(V```!X````]8```
M&P```%Q@```N````>&```!<```"G8```)@```+]@```P````YF```!L````7
M80``'@```#-A```<````4F$``"8```!O80``*P```)9A```S````PF$``"8`
M``#V80``*P```!UB```X````26(``!T```""8@``%0```*!B```O````MF(`
M`!(```#F8@``(````/EB```I````&F,``!X```!$8P``$@```&-C``"B````
M=F,``!8````99```(P```#!D```H````5&0``"D```!]9```*````*=D```?
M````T&0``!4```#P9```(`````9E```E````)V4``"@```!-90``+0```'9E
M```P````I&4``)(```#590``(0```&AF```6````BF8``!P```"A9@``)@``
M`+YF```J````Y68``$$````09P``1````%)G```,````EV<```<```"D9P``
M!P```*QG```&````M&<```T```"[9P``$````,EG```2````VF<``!,```#M
M9P``$@````%H```-````%&@```P````B:```#P```"]H```3````/V@```T`
M``!3:```*````&%H```#````BF@```T```".:```!@```)QH```"````HV@`
M``4```"F:```!````*QH```0````L6@```0```#":```#0```,=H```.````
MU6@```,```#D:```#@```.AH```(````]V@```\`````:0``"````!!I```/
M````&6D```<````I:0``#0```#%I```0````/VD``!,```!0:0``$P```&1I
M```+````>&D``!$```"$:0``"0```)9I```&````H&D```P```"G:0``$0``
M`+1I```9````QFD```L```#@:0``#0```.QI```B````^FD``!L````=:@``
M-````#EJ```*````;FH``!@```!Y:@``&0```))J```6````K&H``"\```##
M:@``(@```/-J```-````%FL```<````D:P``#````"QK```F````.6L``!0`
M``!@:P``"P```'5K```B````@6L``"\```"D:P``"P```-1K```)````X&L`
M`!D```#J:P``"P````1L```7````$&P``!<````H;```"0```$!L```6````
M2FP```\```!A;```%@```'%L```.````B&P``!@```"7;```#0```+!L```F
M````OFP``$,```#E;```"````"EM```O````,FT```X```!B;0``!0```'%M
M```&````=VT```,```!^;0``!````()M```*````AVT```H```"2;0``#P``
M`)UM```0````K6T``!<```"^;0``$0```-9M```7````Z&T``!D`````;@``
M"0```!IN```*````)&X```(````O;@``!0```#)N```-````.&X``!L```!&
M;@``%P```&)N```)````>FX```X```"$;@``#0```)-N```2````H6X``#@`
M``"T;@``(````.UN```#````#F\```@````2;P``#@```!MO``![````*F\`
M`!@```"F;P``!0```+]O```8````Q6\``!D```#>;P``$P```/AO```'````
M#'````8````4<```$````!MP```/````+'```!`````\<```#P```$UP```+
M````77````\```!I<```#````'EP```/````AG````<```"6<```"@```)YP
M```&````J7````X```"P<```#````+]P```H````S'````\```#U<```"```
M``5Q```(````#G$``!,````7<0``'@```"MQ```A````2G$``"````!L<0``
M&0```(UQ```7````IW$``"4```"_<0``%P```.5Q```$````_7$```P````"
M<@```P````]R```(````$W(```H````<<@``#````"=R```+````-'(``!``
M``!`<@``#````%%R```3````7G(``!0```!R<@``#````(=R```)````E'(`
M``X```"><@``"P```*UR```;````N7(```<```#5<@``"@```-UR```-````
MZ'(```D```#V<@``!`````!S```%````!7,```,````+<P``&`````]S```*
M````*',```0````S<P``)@```#AS```.````7W,``'P```!N<P``%0```.MS
M```%`````70```<````'=```#`````]T```(````''0```H````E=```!@``
M`#!T```(````-W0``!8```!`=```$@```%=T```"````:G0```8```!M=```
M%0```'1T```/````BG0``!$```":=```&@```*QT```$````QW0```D```#,
M=```$````-9T```)````YW0```D```#Q=```&@```/MT```(````%G4``!D`
M```?=0``#@```#EU```.````2'4```H```!7=0```@```&)U```-````974`
M``D```!S=0``!@```'UU```)````A'4``!0```".=0``'0```*-U```1````
MP74```8```#3=0``$0```-IU```1````['4```D```#^=0```@````AV```$
M````"W8``#D````0=@``/0```$IV```Z````B'8``!X```##=@``#@```.)V
M```$````\78```8```#V=@``!@```/UV```$````!'<``!$````)=P``!@``
M`!MW```*````(G<``"(````M=P``!````%!W```E````57<```4```![=P``
M!````(%W```,````AG<```H```"3=P``!0```)YW```Z````I'<``#````#?
M=P``-0```!!X```I````1G@``"X```!P>```1P```)]X```X````YW@``"D`
M```@>0``/P```$IY```N````BGD``"T```"Y>0``'P```.=Y```/````!WH`
M`!(````7>@``"P```"IZ```F````-GH``"D```!=>@``)````(=Z```F````
MK'H```@```#3>@``"@```-QZ```)````YWH``"````#Q>@``(````!)[```F
M````,WL```H```!:>P``&0```&5[```I````?WL``!8```"I>P``$@```,![
M```*````TWL```P```#>>P``#P```.M[```0````^WL``$`````,?```<```
M`$U\``!F````OGP```X````E?0``"0```#1]```*````/GT``!(```!)?0``
M$P```%Q]```,````<'T```8```!]?0``#P```(1]```2````E'T``!````"G
M?0``"@```+A]```1````PWT``!P```#5?0``(P```/)]``!J````%GX```\`
M``"!?@``$````)%^```$````HGX```L```"G?@``%````+-^```,````R'X`
M``P```#5?@``#P```.)^```5````\GX``"D````(?P``*@```#)_```F````
M77\``"<```"$?P``*0```*Q_```J````UG\``!D````!@```0@```!N````1
M````7H```!(```!P@```$P```(.````4````EX````\```"L@```%@```+R`
M```7````TX```!````#K@```$0```/R````T````#H$``!,```!#@0``$@``
M`%>!```U````:H$``!0```"@@0``!P```+6!```K````O8$``"````#I@0``
M%`````J"```1````'X(``!<````Q@@``'````$F"```3````9H(``!$```!Z
M@@``&@```(R"```>````IX(``!H```#&@@``$0```.&"```7````\X(``!0`
M```+@P``%P```""#```5````.(,```D```!.@P``$0```%B#```&````:H,`
M``8```!Q@P``!P```'B#```$````@(,```0```"%@P``!P```(J#```.````
MDH,```X```"A@P``*````+"#```.````V8,```P```#H@P``#P```/6#```*
M````!80```@````0A```"0```!F$```K````(X0```0```!/A```!P```%2$
M```(````7(0```D```!EA```#````&^$```-````?(0```X```"*A```%@``
M`)F$```1````L(0```,```#"A```!@```,:$```9````S80```0```#GA```
M"P```.R$```+````^(0```T````$A0``"@```!*%```0````'84```\````N
MA0``$0```#Z%```7````4(4```H```!HA0``$0```'.%```(````A84```0`
M``".A0``#P```).%```Z````HX4```4```#>A0``#````.2%```>````\84`
M``X````0A@``$````!^&```+````,(8```P````\A@``"0```$F&```'````
M4X8```H```!;A@``"0```&:&```.````<(8``!````!_A@``&@```)"&```*
M````JX8``!0```"VA@``"@```,N&```,````UH8```\```#CA@``"````/.&
M```&````_(8```<````#AP``"P````N'``!'````%X<```T```!?AP``"0``
M`&V'```$````=X<```,```!\AP``$P```("'```3````E(<```(```"HAP``
M!````*N'```/````L(<``!0```#`AP``$P```-6'```0````Z8<```T```#Z
MAP``#@````B(```6````%X@```H````NB```!P```#F(```'````08@```D`
M``!)B```!P```%.(```$````6X@```P```!@B```!0```&V(```$````<X@`
M``0```!XB```"0```'V(```"````AX@```\```"*B```!````)J(```%````
MGX@```8```"EB````@```*R(```&````KX@``!0```"VB```!P```,N(```*
M````TX@``!$```#>B```"````/"(```>````^8@``"@````8B0``%````$&)
M```%````5HD``"@```!<B0``*0```(6)``!7````KXD``"P````'B@``!P``
M`#2*```-````/(H``!,```!*B@``(P```%Z*```+````@HH```L```".B@``
M(````)J*```G````NXH``"L```#CB@``%`````^+```%````)(L``!$````J
MBP``!````#R+```$````08L```P```!&BP``!@```%.+```-````6HL``!H`
M``!HBP``%P```(.+```7````FXL``!L```"SBP``'P```,^+```7````[XL`
M`!,````'C```&0```!N,```$````-8P``!`````ZC```%P```$N,```%````
M8XP```8```!IC```!P```'",```&````>(P```<```!_C```!P```(>,```%
M````CXP``!H```"5C```%````+",```)````Q8P``!P```#/C```*0```.R,
M```X````%HT``"\```!/C0``*P```'^-```J````JXT``#X```#6C0``'0``
M`!6.```C````,XX``"$```!7C@``'````'F.```%````EHX```(```"<C@``
M`P```)^.```@````HXX``"8```#$C@``#````.N.```?````^(X```<````8
MCP``&````""/```&````.8\```P```!`CP``"````$V/```)````5H\```<`
M``!@CP``"@```&B/```)````<X\```<```!]CP``!@```(6/```-````C(\`
M``L```":CP``#````*:/```*````LX\```(```"^CP``!@```,&/```#````
MR(\``$4```#,CP``,````!*0```0````0Y````D```!4D```4P```%Z0```?
M````LI```!````#2D```#P```..0```%````\Y````@```#YD```"`````*1
M```$````"Y$```4````0D0``:`$``!:1``!/````?Y(``!$```#/D@``$```
M`.&2```1````\I(```@````$DP``"P````V3```(````&9,```4````BDP``
M"P```"B3```1````-),``"D```!&DP``$````'"3```-````@9,``!$```"/
MDP``#@```*&3```%````L),``"@```"VDP``#P```-^3```/````[Y,```\`
M``#_DP``$P````^4```+````(Y0``!4````OE```1````$64```D````BI0`
M`"X```"OE```%@```-Z4```-````]90```L````#E0``#P````^5```S````
M'Y4``"$```!3E0``#0```'65```9````@Y4``"<```"=E0``.@```,65```2
M`````)8```\````3E@``$0```".6```3````-98```8```!)E@``'````%"6
M```L````;98``!\```":E@``)0```+J6```:````X)8``!H```#[E@``"@``
M`!:7```0````(9<``!`````REP``"````$.7```P````3)<``!H```!]EP``
M/````)B7``!$````U9<``&`````:F```70```'N8``!G````V9@``&0```!!
MF0``0````*:9```%````YYD``!$```#MF0``!0```/^9```0````!9H```T`
M```6F@``%````"2:```'````.9H``"X```!!F@``*@```'":```-````FYH`
M``T```"IF@``%0```+>:```*````S9H```@```#8F@``%````.&:```9````
M]IH```T````0FP``$@```!Z;```5````,9L``"````!'FP``(````&B;```3
M````B9L``!````"=FP``%@```*Z;```,````Q9L``"8```#2FP``%P```/F;
M```7````$9P``!H````IG```#P```$2<``!.````5)P``"H```"CG```'@``
M`,Z<```S````[9P```<````AG0``"P```"F=```P````-9T```X```!FG0``
M"````'6=```%````?IT```<```"$G0``"@```(R=```$````EYT``!D```"<
MG0``#````+:=```0````PYT```\```#4G0``%@```.2=```Q````^YT``!,`
M```MG@``%0```$&>```8````5YX``!L```!PG@``&0```(R>```1````IIX`
M`!$```"XG@``'0```,J>```,````Z)X```0```#UG@``!P```/J>```,````
M`I\``!0````/GP``-0```"2?```(````6I\``!0```!CGP``%P```'B?```)
M````D)\``$,```":GP``.P```-Z?```%````&J````L````@H```/@```"R@
M```0````:Z```$$```!\H```,````+Z@```S````[Z```#4````CH0``.```
M`%FA```)````DJ$```@```"<H0``"0```*6A```[````KZ$``#H```#KH0``
M.@```":B``!6````8:(``#D```"XH@``.0```/*B```Y````+*,``#@```!F
MHP``*````)^C```I````R*,``#D```#RHP``/P```"RD```4````;*0``!@`
M``"!I```)@```)JD```F````P:0``!,```#HI```#@```/RD```,````"Z4`
M``@````8I0``#@```"&E```6````,*4``!D```!'I0``!0```&&E```M````
M9Z4```H```"5I0``!@```*"E```'````IZ4``"X```"OI0``$P```-ZE```*
M````\J4```,```#]I0``"0````&F```%````"Z8```X````1I@``!@```""F
M```%````)Z8```0````MI@``"@```#*F```#````/:8```,```!!I@``&```
M`$6F```8````7J8```@```!WI@``!@```("F``!"````AZ8``"0```#*I@``
M!@```.^F```&````]J8``!4```#]I@``&P```!.G```?````+Z<``"\```!/
MIP``'P```'^G```D````GZ<``'4```#$IP``-P```#JH```&````<J@``!<`
M``!YJ```#````)&H```4````GJ@``!P```"SJ```%````-"H```2````Y:@`
M``P```#XJ```!@````6I```7````#*D``!X````DJ0``"0```$.I```%````
M3:D``$T```!3J0``!````*&I```.````IJD``"8```"UJ0``$````-RI```3
M````[:D```X````!J@``(````!"J```N````,:H``"@```!@J@``!0```(FJ
M```3````CZH``!````"CJ@``#````+2J```0````P:H``!4```#2J@``$P``
M`.BJ```*````_*H```4````'JP``!0````VK```5````$ZL``!$````IJP``
M!0```#NK```+````0:L```D```!-JP``#@```%>K```+````9JL```@```!R
MJP``#0```'NK```2````B:L```L```"<JP``"0```*BK```*````LJL```L`
M``"]JP``!0```,FK```&````SZL``!(```#6JP``#````.FK```&````]JL`
M`!P```#]JP``(@```!JL```-````/:P```\```!+K```%0```%NL```6````
M<:P``#,```"(K```0@```+RL```E````_ZP``"0````EK0``#@```$JM```(
M````6:T```8```!BK0``!@```&FM```3````<*T``!(```"$K0``'P```)>M
M```>````MZT``"D```#6K0``*`````"N```@````*:X``"(```!*K@``*@``
M`&VN```Y````F*X``!P```#2K@``)@```.^N```Q````%J\``"(```!(KP``
M)0```&NO```@````D:\``"L```"RKP``,0```-ZO```J````$+```"8````[
ML```)P```&*P```X````BK```",```##L```(P```.>P```X````"[$``!,`
M``!$L0``(@```%BQ```I````>[$``!\```"EL0``$@```,6Q``"Q````V+$`
M`!<```"*L@``(@```**R```J````Q;(``"H```#PL@``/0```!NS```F````
M6;,``"$```"`LP``(@```**S```I````Q;,``"P```#OLP``.````!RT```O
M````5;0``*````"%M```)P```":U```7````3K4``"````!FM0``+````(>U
M```L````M+4``#<```#AM0``/P```!FV```*````6;8```0```!DM@``!@``
M`&FV```'````<+8```\```!XM@``#0```(BV```3````EK8``!0```"JM@``
M$0```+^V```.````T;8```T```#@M@``#0```.ZV```4````_+8```X````1
MMP``,@```""W```(````4[<``!4```!<MP``!@```'*W```"````>;<```8`
M``!\MP``!````(.W```1````B+<```0```":MP``#````)^W```)````K+<`
M``,```"VMP``#0```+JW```(````R+<```L```#1MP``!P```-VW```/````
MY;<```@```#UMP``#@```/ZW```1````#;@``!0````?N```%````#2X```,
M````2;@``!````!6N```"````&>X```%````<+@```P```!VN```#P```(.X
M```8````D[@```L```"LN```#0```+BX```A````QK@``!L```#HN```-@``
M``2Y```)````.[D``!4```!%N0``%P```%NY```3````<[D``#,```"'N0``
M)@```+NY```,````XKD```<```#ON0``$0```/>Y```O````";H``!$````Y
MN@``"P```$NZ```B````5[H``"X```!ZN@``"0```*FZ```)````L[H``!\`
M``"]N@``"P```-VZ```=````Z;H``!T````'NP``!P```"6[```4````+;L`
M``P```!"NP``$P```$^[```.````8[L``!(```!RNP``"@```(6[```@````
MD+L``#H```"QNP``"````.R[```O````];L```X````EO```"0```#2\```&
M````/KP```,```!%O```!P```$F\```.````4;P```X```!@O```$P```&^\
M```2````@[P``!H```"6O```$0```+&\```:````P[P``!H```#>O```"0``
M`/F\```*`````[T```(````.O0``!@```!&]```-````&+T``!@````FO0``
M%@```#^]```(````5KT```P```!?O0``#@```&R]```1````>[T``$````"-
MO0``&0```,Z]```%````Z+T```@```#NO0``%````/>]``"0````#+X``"$`
M``"=O@``!````+^^```<````Q+X``!H```#AO@``&P```/R^```&````&+\`
M``8````?OP``$````":_```/````-[\``!````!'OP``#P```%B_```/````
M:+\```T```!XOP``#````(:_```0````D[\```0```"DOP``!P```*F_```%
M````L;\```T```"WOP``#0```,6_```N````T[\```H````"P```"0````W`
M```.````%\```!L````FP```(0```$+````B````9,```"$```"'P```'@``
M`*G````>````R,```"H```#GP```'0```!+!```(````,,$```P````YP0``
M`P```$;!```'````2L$```D```!2P0``"P```%S!```(````:,$```L```!Q
MP0``"P```'W!```6````B<$``!8```"@P0``#````+?!```'````Q,$```<`
M``#,P0``#@```-3!```A````X\$```8````%P@``#P````S"```0````',(`
M``P````MP@```P```#K"```$````/L(```0```!#P@``&0```$C"```)````
M8L(```,```!LP@``)@```'#"```/````E\(``(X```"GP@``$````#;#```(
M````1\,```T```!0PP``$@```%[#```.````<<,``!````"`PP``!P```)'#
M```,````F<,``!0```"FPP``$````+O#```"````S,,```8```#/PP``&0``
M`-;#```2````\,,``!D````#Q```(0```!W$```#````/\0```0```!#Q```
M$````$C$```(````6<0```H```!BQ```(P```&W$```(````D<0``!@```":
MQ```#0```+/$```-````P<0```D```#/Q````@```-G$```-````W,0```<`
M``#JQ```!@```/+$```(````^<0``!4````"Q0``'@```!C%```1````-\4`
M``<```!)Q0``%0```%'%```5````9\4```D```!]Q0```@```(?%```$````
MBL4``#,```"/Q0``-P```,/%```T````^\4``!\````PQ@``#@```%#&```#
M````7\8```0```!CQ@``!0```&C&```%````;L8``!@```!TQ@``!P```(W&
M```(````E<8``!P```">Q@```P```+O&```P````O\8```4```#PQ@``!```
M`/;&```-````^\8```X````)QP``!0```!C'```T````'L<``#$```!3QP``
M.0```(7'```<````O\<``"(```#<QP``/@```/_'```]````/L@``"H```!\
MR```.@```*?(```P````XL@``#@````3R0``)0```$S)```0````<LD``!(`
M``"#R0``"P```);)```J````HLD``"L```#-R0``)````/G)```H````'LH`
M``D```!'R@``"P```%'*```*````7<H``"<```!HR@``)@```)#*```P````
MM\H```H```#HR@``'0```//*```L````$<L``!4````^RP``%````%3+```*
M````:<L```T```!TRP``$````(++```2````D\L``#<```"FRP``D````-[+
M``!U````;\P``!D```#ES```#````/_,```-````#,T``!$````:S0``$@``
M`"S-```3````/\T```8```!3S0``%````%K-```3````;\T``!````"#S0``
M#````)3-```3````H<T``!@```"US0``)````,[-``"!````\\T```H```!U
MS@``%````(#.```$````E<X```L```":S@``%P```*;.```.````OLX```\`
M``#-S@``$````-W.```5````[LX``"H````$SP``*````"_/```F````6,\`
M`"0```!_SP``+0```*3/```K````TL\``!<```#^SP``0@```!;0```4````
M6=```!0```!NT```%@```(/0```4````FM```!(```"OT```&0```,+0```7
M````W-```!(```#TT```$`````?1```]````&-$``!<```!6T0``%@```&[1
M```[````A=$``!$```#!T0``!P```-/1```M````V]$``"`````)T@``$```
M`"K2```0````.](``!,```!,T@``&0```&#2```1````>M(``!0```",T@``
M'P```*'2```C````P=(``!4```#ET@``$@```/O2```6````#M,``!,````E
MTP``%````#G3```5````3M,```<```!DTP``%P```&S3```'````A-,```8`
M``",TP``!@```)/3```$````FM,```0```"?TP``!@```*33```)````J],`
M`!````"UTP``*@```,;3```2````\=,``!`````$U```$@```!74```-````
M*-0```L````VU```"@```$+4```\````3=0```0```"*U```"0```(_4```%
M````F=0```T```"?U```#0```*W4```2````N]0``!0```#.U```&P```./4
M```7````_]0```,````7U0``"````!O5```K````)-4```<```!0U0``#```
M`%C5```/````9=4```T```!UU0``"0```(/5```3````C=4``!4```"AU0``
M#P```+?5```4````Q]4```P```#<U0``#@```.G5```(````^-4```0````!
MU@``#P````;6```T````%M8```8```!+U@``#````%+6```=````7]8```X`
M``!]U@``#0```(S6```-````FM8```L```"HU@``"@```+36```(````O]8`
M``T```#(U@``"@```-;6```0````X=8``!H```#RU@``*P````W7```*````
M.=<``!4```!$UP``"0```%K7```*````9-<```P```!OUP``"````'S7```(
M````A=<```<```".UP``$P```);7``!&````JM<```T```#QUP``"@```/_7
M```*````"M@```,````5V```%````!G8```6````+M@```(```!%V```!P``
M`$C8```0````4-@```T```!AV```#P```&_8```/````?]@```@```"/V```
M#P```)C8```=````J-@```H```#&V```!P```-'8```)````V=@```D```#C
MV```"0```.W8```$````]]@``!````#\V```!0````W9```'````$]D```4`
M```;V0``"@```"'9```#````+-D```T````PV0``!0```#[9```'````1-D`
M``0```!,V0```@```%'9```&````5-D``!````!;V0``!````&S9```,````
M<=D``!$```!^V0``!P```)#9```=````F-D``"T```"VV0``%0```.39```'
M````^MD``"@````"V@``*````"O:``!8````5-H``#$```"MV@``#P```-_:
M```,````[]H``!(```#\V@``'P````_;```)````+]L```L````YVP``'@``
M`$7;```P````9-L``#0```"5VP``%0```,K;```)````X-L``!````#JVP``
M!0```/O;```)`````=P```H````+W````P```!;<```,````&MP``!0````G
MW```#P```#S<```0````3-P``!D```!=W```$@```'?<```6````BMP``!,`
M``"AW```(````+7<```)````UMP``!4```#@W```%0```/;<```%````#-T`
M``8````2W0``!````!G=```$````'MT```<````CW0``"@```"O=```(````
M-MT``!L````_W0``#P```%O=```)````:]T``!<```!UW0``.````(W=```O
M````QMT``#X```#VW0``-P```#7>```U````;=X``$X```"CW@``*````/+>
M```M````&]\``!T```!)WP``%@```&??```&````?M\```,```"%WP```P``
M`(G?```?````C=\``"@```"MWP``#P```-;?```@````YM\```D````'X```
M'````!'@```(````+N````H````WX```"@```$+@```+````3>````8```!9
MX```#````&#@```.````;>````@```!\X```"````(7@```0````CN````T`
M``"?X```#````*W@```,````NN````(```#'X```!0```,K@```"````T.``
M`#P```#3X```-@```!#A```/````1^$```H```!7X0``8@```&+A```=````
MQ>$``!````#CX0``$````/3A```%````!>(```<````+X@``!````!/B```$
M````&.(```4````=X@```0```,H"``#-````J````%L"``!/`0```````!`#
M````````U@```)L```#.````3@,``$0"``!$`0``````````````````````
M```````Q`P``'P```%0```#=`0``-@```,P!``"U`@``A0$```````"C`0``
M`````,\!```A`P```````(0!````````ZP(`````````````\P(``%$"```(
M`@```````#H#```G`0````````````""`@``#P(``(P!```6`@``M@```(T!
M``"2`@``/0$```````#V````]`(```````!&`0``:````&D"``#N````%P$`
M`*0```"Z`````P```(@!``!.`0``V`$```0!``````````````X"``#H`@``
M`````````````````````$4!``#W`````````+X!``!6````.P,```````"!
M`@``%`,````````E`@```````&L"``!#`P```````)P!```-`````@(``%``
M``#_````!P,``$`#```8`0```````-,````2````"0```%T"````````````
M`$D"``"9````4P```&8"``#W`0```````+<```!8`0``&@$``!8#``!S`0``
M````````````````Q`````L!```N`0``A@```*P```!4`0``WP``````````
M```````````````.`0``I@```!`"````````T0$```````````````````@`
M```Q`@``RP```&4```"L`0`````````````H`0``E0$``#,#``#D````)@,`
M`/X`````````\@```!T!``!E`0````````````#E`@``L0(```````"#````
MU`(``````````````````*X```!9````+P$````````E`P```0$``*@"```3
M`0``9`$``+T```!^````,P````````"Q`````````),!``#U`@``$@,``.4`
M``#L`@```P$``+`!```V`@``FP$``)T!````````#0,``,T"````````.@(`
M```````3`P``0P(```````#_`0``BP```!L"```1`````````#4"```0````
M`````%8"``````````````````!+`0```````!L```````````(``'`````:
M````#`$``(H!``#<````#`(``%4"``#3`0```````!<``````````````.`!
M``!(`````@$``"P```!F`````````!$#``!2``````````L#``!!`P``_`$`
M```````/`0``H`(``'P"``#'`0``/@```$(#````````.@$``*T!``!-`@``
MP@$````````A````UP```````````````````+(!```=`````````*P"``#^
M`@``,`$```````!<`@````````````!&`@```````,H!```M`0``D````$L"
M``##`0```````-`!```%`@``_`(``$4"``!@````;0`````````-`@``````
M`!0!``#%`````````+0```!R`0``NP$``%H!``"4`0``$P```%$!````````
M`````#0```!*````*0(``"T#``#_`@``;P(``#H```!!`@``>`(````````;
M`0``L@(`````````````"@,``/H"````````>````&H````Q`0``]```````
M``#G`@``3@```$D!``!5````'P$``(@```".````+@```$@!``!?````80(`
M``````!"`````````*<`````````V@$``$$```#Q`0``J0$``)@```"O````
M-0$``!\"``!P`0``AP$``(L!``"_`@````````````!2`0```````%D!```<
M`@````````````#]````Q@````$"``!H`@````$``*<"``#P`0``>P``````
M````````^0(``%X````W`0```````&`!``#:```````````````]`@``````
M`'H"````````E`(``!D#``"A`@``,P$``.H!``!5`0``D0$``$H"``!B````
M*0$```````"U`````````(8"``````````````````#[`0``0`````,"``"0
M`0````````````"C`````````*<!``"6`@``]@$``&0"```*````#0$``-D!
M``#G`0``XP(``)D!```X`0``@@$``*$```#.`@```````$D```!%````````
M``````!*`0``B0```-\!``"``````````!@`````````\````/@"```9`@``
M`````'8"``"<``````````@!``"J`@`````````````"````````````````
M````[0$``+X`````````;P$``'4"``#$`@``<0(``)`"``!T`0``40,``(0`
M`````````````)X!``"<`@``(P(``(H``````````````),```#8````8@(`
M`#@#``#,````5P```.L!``"%`@``R`$``*T"``!8````_0$``!H#```<`P``
M+@(``'T!```\`0``Z0$```8#````````F@```.,!``!,`@``30,```````"K
M`0`````````````````````````````M`@``X@````8"```@`0``````````
M``!T`@````````P```"F`@```````+@```##`@``L````(,!````````2@,`
M`,\```#&`0``1````!@#``#7`@``ZP````````"Y````;````',```#X````
MBP(``*H```!L`@``Q`$``)D"``"Y`0``D@``````````````9P```(X"```)
M`@``;`$``#@"````````Z@(```$#```R`0```@,``$4#```'`@```````!X#
M````````O@(``$<!``#5`0``-P,``"@```!;````````````````````4P(`
M`,$```"5````/`(``/X!``"E`0``K@(```````#W`@``D0```-4"```D`0``
M`````(`!``#I`````````%<"```E````70$``/P```"N`0````````0"```\
M````M@(``"````!/`P``OP$``!D````B`@``<`(``(D"````````(`(``%T`
M````````.0$``,L"``"@`0``&@(`````````````*@````````!9`@``V0(`
M`.8```!G`0```````+P!```[`0``N`(``"P"``"K````?`$``'@!````````
M`````+T!````````Y0$``,P"``!``0``%0```)T"````````8@$``,D!````
M`````````)\!```D`P``J@$```````#U`0``T`(``-L```#Z`````````!`!
M````````B0$``*(!``#3`@``CP$``*\"`````````````(\`````````8P$`
M``````!A````H````#\!```_`P``[P$````````C`P``'@(`````````````
ML`(``$X"```3`@``?`````````!6`0``MP(```````!;`0``&P,```H"``",
M````L0$````````K`0```````(X!``!"`0``"0,````````\`P``+P(``"H#
M```%````%0,``*0!``"5`@``$0$``+P"``"!`0``NP````````#;`@``&`(`
M``````"$`@``0@(``$<"``!H`0``1@,`````````````5`(``/,```!W`@``
M!`,``,$!``!-````````````````````W@(``(T```!<````[0```"L`````
M````X@$``"8"``#L````\`(```````"*`@``E@$``"D```"!`````````-0`
M`````````````)X``````P``3````(`"````````#P```*\!``!^`0``,```
M`,H````2`@``*P,``'("``"1`@``]@(````````5`@``XP````````!E`@``
MW`$``#L"``#/`@```````*$!```U`P``AP```/L"````````=@$``",!````
M````=P```'(``````````````"@"``!K`0``T0(``!X!````````"`,``'D`
M````````+P````````"U`0``F`(``+@!``"B`@``(0(``"H!``#]`@``````
M`%$```"H`0``W@$```````"(`@``'0(```````"%````^P```#T`````````
MZ@````````#6`0`````````````%`P``Z0(``(<"``!-`0``+@,``&X"``!_
M````'````-<!``"7`0``[P(``,`"``#.`0``0`(``````````````````-H"
M```A`0``^0````````"7````-P(``"<"``!7`0``J0(``-8"```D`@``O0(`
M`,@```!M`@``.0,``"L"``!J`@```````#(```"S`0``7`$``,("``!?`0``
M$0(``)X"```]`P``M@$``.<```!@`@``:0``````````````F@$``.@`````
M`````````/D!``"I````HP(````````.`P``\0(```````#-`0``[P``````
M````````2`,``.$"```G`P``+`,```````!_`@``M`(```````"?`@``:@$`
M````````````6@(``$,!``!8`@``7@$``.`"````````;@`````````6`0``
M`````.X"``#``0``WP(``"8```#>````,`(``((`````````VP$```````#0
M````"0$`````````````FP(```L````P`P``!P```,8"```2`0``+P,``"0`
M````````CP(``.X!```^`@``Y`(````````+`@``R`(``*4````7`P``1@``
M`#(#``"E`@`````````````Q````<0```#D"```B````?0```-D```!Y`@``
M`````!4!``!!`0````````````#)``````````````!,`P``\@$``.P!```B
M`P``'P,``#0"```&`0``%P(``+<!``"T`0`````````````#`P``X```````
M``##````K0```,(``````````````"@#````````NP(``&,````$````T@$`
M`.0!```T`P``7P(````````@`P``T0```````````````````#\"````````
M'`$``"4!``"D`@``/@,``/0!```^`0``@P(``*L"```,`P``=@```%X"```F
M`0``OP```.8!``!Z````-@,``&\```"6````Y@(``&,"``!'````W0(`````
M``!Y`0``\@(``.("``!_`0``:P```+D"````````-`$``-("````````#@``
M`,<`````````!P$``,<"````````````````````````;0$``+H!``"3`@``
M;@$``$D#``#4`0``1P,``#<``````````````#("``"=````'@```(P"``!U
M`0``/P```#8!```/`P``^@$``+(````9`0``'0,```````"4````Q0(``'H!
M```&````(@$``-(```#%`0```````/,!```U````=0`````````4````X0``
M`#D`````````[0(``"D#```S`@``9P(```````!^`@``P0(``&D!````````
M%`(``.$!```M````6@```%`"``!/```````````````%`0``.P```$L`````
M````3P(```````!Q`0``R0(``"<```"Z`@````````````"\````.````$P!
M````````>P$``&0`````````9@$```````#=````(P```*(```!(`@``4`$`
M`$L#```J`@``=P$``,````"&`0``V`(``!8`````````80$``*8!````````
M=````)@!``````````````H!``"-`@```````'T"``!$`P``\0``````````
M````>P(``"P!``#5````LP```%`#``"2`0``````````````````````````
M````````]0```%,!``!#````EP(``/@!``"S`@``4@(```````":`@``````
M``````#<`@``<P(``.@!````````RP$``)\`````("8C,34Q.R`E<R!I<R!R
M96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H
M96-K960@8F5L;W<N`"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@
M*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y
M*0`@870@`"5D("5S(&%N9"`E<P`E9"!B>71E<R!W<FET=&5N+@`E9"!O9B`E
M9"!E;G1R:65S(&UA<FME9"!A<R!U<"UT;RUD871E`"5D+61A>2!F;W)E8V%S
M=``E<R`M($YO=&EC90`E<R!!9&UI;FES=')A=&EO;@`E<R!&:6YG97)P<FEN
M=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T
M:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M96YT
M`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!H87,@8V%N8V5L
M;&5D("5S+@`E<R!H87,@<F5P;&EE9"!T;R!A(&9R964O8G5S>2!R97%U97-T
M+@`E<R!H87,@<F5P;&EE9"!T;R!T:&4@:6YV:71A=&EO;B!T;R`E<RX`)7,@
M:&%S('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`)7,@:7,@;F]T
M('=R:71A8FQE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F
M;W5N9"X`)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I;VXN
M`"5S(')E<75E<W1S('EO=7(@<')E<V5N8V4@870@)7,N`"5S('1O("5S(&]F
M("5S`"5S('=I<VAE<R!T;R!A9&0@=&\@)7,N`"5S('=I<VAE<R!T;R!M86ME
M('EO=2!A=V%R92!O9B`E<RX`)7,@=VES:&5S('1O(')E8V5I=F4@=&AE(&QA
M=&5S="!I;F9O<FUA=&EO;B!A8F]U="`E<RX`)7,G<R!!9&1R97-S($)O;VL`
M)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@
M)7,`)R5S)R!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"<E<R<@:7,@;F]T(&-O
M;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`G)7,G('=A<R!A9&1E
M9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`)R5S)R!W87,@861D960@=&\@=&AE
M('!E<FUI<W-I;VYS('-Y<W1E;2X`)R5S)R!W87,@;F]T(&-R96%T960Z("5S
M+@`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R($AO
M=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`$$@9&%T86)A<V4@
M8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E
M<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E
M9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R
M97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@
M4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K
M97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P
M<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@
M<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R
M97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04TO4$T`06)O=70@=&AI
M<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<'0@
M<F5Q=65S=`!!8V-E<'1E9`!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D
M:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C
M8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`06-T
M:6]N<P!!9&0`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N
M`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!
M9&0@82!C:&EL9"!G<F]U<"!T;R`G)7,G`$%D9"!A(&-H:6QD('!E<FUI<W-I
M;VX@=&\@)R5S)P!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W
M(&UE;6)E<G,`061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL
M82!3:61E8F%R`$%D9"!T:&ES('1O(&UY(&-A;&5N9&%R`$%D9"!T;R!A9&1R
M97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D
M960@)R5S)R!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I
M=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D("<E<R<@=&\@
M=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@;F5W(&9I
M;&5S('1O(')E<&]S:71O<GDZ`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`
M061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M:7-S
M:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%L:6%S
M`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S
M`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L
M;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R
M960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,
M;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5
M<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M
M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;B!I;&QE9V%L('9A;'5E('=A<R!S
M<&5C:69I960N`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`07!P;&EC871I;VX`
M07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@
M=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!<F-H
M:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W
M86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E
M('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92`G)7,G(&%N9"!A;GD@<W5B
M+6=R;W5P<S\`07)T`$%S8VEI($%R=`!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B
M969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N
M="!C;VQU;6YS`$%T=&%C:&5D(&ES(&%N(&E#86QE;F1A<B!F:6QE(')E<&QY
M('1O(&$@<F5Q=65S="!Y;W4@<V5N=`!!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N
M="!S:&%R92X`071T96YD965S`$%T=')I8G5T97,`075S=')I80!!=71H7V-Y
M<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I
M;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I
M=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE
M('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T
M92!U<V5R("5S`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE
M;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@
M8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E
M<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$%W86ET:6YG(%)E<W!O;G-E
M`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D
M(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A
M<F4`0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@)R5S)R!N;W0@9F]U;F0N`$)A
M<V5L:6YE`$)E;&=I=6T`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A
M=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP
M90!";VQD`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R
M9&5R<P!";W1H`$)O='1O;0!"=6QL971E9"!,:7-T`$--4P!#4D,`0U),($1I
M<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#86QE;F1A
M<@!#86QM`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@
M8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B=T(&-O;FYE8W0@=&\@
M24U!4"!S97)V97(Z("5S`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L96T@
M4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A
M('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I=&AO=70@
M)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O
M<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N`$-A
M;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@
M<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@
M<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!T:6]N`$-A
M=&5G;W)I97,@86YD($QA8F5L<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE
M<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z
M`$-E;&QP:&]N90!#96YT97(`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I
M8V%T92!0;VQI8VEE<P!#:&%I<B!097)S;VX`0VAA;F=E`$-H86YG92!T:&4@
M;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E
M860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%R`$-H96-?:R!,:6YK
M+BXN`$-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A
M;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`$-H;V]S92!A('!A<W-W;W)D
M`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!A;B!A8W1I;VXZ`$-H;V]S92!H
M;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H
M9F]R(&]R9&5R960@;&ES=',I`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T
M(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(&]U="!U
M<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&EC:R!T;R!#
M;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U
M9',`0VQO=61Y`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`
M0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L=6UN('1I
M=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UA;F0@;W!T
M:6]N<SH`0V]M;6%N9',Z`$-O;6UE;G0`0V]M;6ET=&EN9SH`0V]M;6]N($YA
M;64`0V]M<&%N>0!#;VUP;&5T960`0V]M<&]S92!-97-S86=E("@E<RD`0V]M
M<'5T97)S`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#
M;VYF:6=U<F%T:6]N(&YE961S('5P9&%T:6YG+@!#;VYF:6=U<F4@)7,`0V]N
M9FER;2!087-S=V]R9`!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F
M86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES
M97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E
M<B!F86EL960N`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT<R!O9B`G)7,G`$-O;G1I;G5E
M`$-O;VMI90!#;W!Y`$-O<'D@<V5L96-T:6]N`$-O<'EI;F<@)7,@=&\@)7,`
M0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@
M<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G
M92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A
M9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N
M`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C
M="!T;R!S97)V97(@)R5S)R!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C;W!Y
M("5S('1O("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S`$-O=6QD(&YO="!C<F5A=&4@;&]C86QE(&1I<F5C=&]R>2!F;W(@;&]C
M86QE("5S.@!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T
M(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C
M="X@)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`
M0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`G)7,G+@!#
M;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D
M<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`
M0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#
M;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T
M:6]N(&QI<W1S+@!#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`G)7,G+@!#;W5L
M9"!N;W0@;6MD:7(@)R5S)RX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y
M(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD
M(&YO="!O<&5N("<E<R<@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N($UA
M:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C
M=&]R>2`G)7,G+@!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T
M('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R
M(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I
M;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F
M=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T
M(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES
M=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R
M)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO
M;BX`0V]U;&0@;F]T(')M9&ER("<E<R<N`$-O=6QD(&YO="!S879E("5S(&-O
M;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A
M=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E
M<P!#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@)R5S
M)RX`0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I
M;&4@)7,N`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@
M<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE
M(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@
M<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK("<E<R<N`$-O=6QD(&YO="!U<&1A
M=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("<E
M<R<Z("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K
M92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E
M<B`G)7,G('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("<E
M<R<Z("5S`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R
M96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E
M<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W5R
M<F5N="!0:&%S90!#=7)R96YT(%1I;64`0W5R<F5N="!796%T:&5R`$-U<G)E
M;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@
M=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y
M<')U<P!$1`!$86EL>0!$871A`$1A=&%4<F5E($)R;W=S97(`1&%T90!$871E
M(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$
M96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C;&EN960`1&5C<F5A<V4@26YD
M96YT`$1E9F%U;'0`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E
M9F%U;'0@4&5R;6ES<VEO;G,`1&5F875L="!P97)M:7-S:6]N<P!$969I;FET
M:6]N<P!$96QE9V%T92!P;W-I=&EO;@!$96QE9V%T960`1&5L971E`$1E;&5T
M92!'<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE
M<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T
M:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@<&5R;6ES<VEO;G,@9F]R
M("<E<R<`1&5L971E('!E<FUI<W-I;VYS(&9O<B`G)7,G(&%N9"!A;GD@<W5B
M+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N
M=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R
M<F5N="!R;W<`1&5L971E('1H:7,@<&5R;6ES<VEO;B!A;F0@86YY('-U8BUP
M97)M:7-S:6]N<S\`1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="`G)7,G
M+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5N>2!R97%U97-T`$1E;GD@<F5Q
M=65S="!F;W(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N`$1E<V-R:6)E('1H92!0
M<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L
M;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F
M;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@
M<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L
M87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9F]R
M96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@3F]T:69I
M8V%T:6]N`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M
M86EN=&5N86YC92YP:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE
M(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;W=N;&]A
M9`!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R
M:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`15)2`$5D:70`161I
M="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI
M<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F
M;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D:70@<&5R;6ES<VEO;G,@
M9F]R("<E<R<`161U8V%T:6]N`$5L96UE;G0N+BX`16T`16UA:6P`16UA:6P@
M061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET
M:"!C;VYF:7)M871I;VX`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y
M(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E<G1I;VX@
M;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L
M92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N9`!%;F0@>65A<@!%;FQA
M<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO
M=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S
M<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`
M16YT97(@=&AE(&EM86=E(%523"!H97)E`$5R<F]R`$5R<F]R('-E;F1I;F<@
M<F5P;'DZ("5S+@!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R
M:71I;F<@)R5S)RX`17)R;W(Z(`!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%
M=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T
M97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%
M>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>&5C=71I;F<Z`$5X<&%N9`!%>'!A
M;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R
M('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`
M1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN
M9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V
M97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T
M;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I
M;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@
M;6]V92!T;R`B)7,B+@!&86ER`$9A=&%L($5R<F]R.@!&87@`1F5B<G5A<GD`
M1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@
M4VAO=V5R<P!&:65L9"!M871R:7@`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE
M($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@
M<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R
M=&5D+@!&:6QT97)S`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T
M:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O
M;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T
M(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E('1H
M870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD
M(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A
M('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T
M=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&
M;W)W87)D<P!&;W5N9"!A<'!L:6-A=&EO;G,Z("5S`$9O=6YD(&1I<F5C=&]R
M:65S.@!&<@!&<F%M97,`1G)E92]"=7-Y($EN9F]R;6%T:6]N`$9R964O0G5S
M>2!297!L>0!&<F5E+T)U<WD@4F5Q=65S=`!&<F5E+T)U<WD@4F5Q=65S="!2
M97-P;VYS90!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@
M36]O;@!&=6QL($YA;64`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L
M;&5R>3H`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D
M90!'971O<'0@17)R;W(Z(`!':79E;B!.86UE`$=O`$=O;V=L92!396%R8V@`
M1W)A>7-C86QE`$=R965C90!'<F5E;FQA;F0`1W)O=7`@061M:6YI<W1R871I
M;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7`@<&5R;6ES
M<VEO;G,`1W)O=7!S`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T('!E<FUI<W-I
M;VYS`$=U97-T8F]O:P!(2`!(5$U,`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S
M97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@
M=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A=&EO;B!N;W0@
M9F]U;F0N`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE:6=H=`!(96QP
M`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@
M=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(:7-T;W)Y(&5N=')Y
M(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$AO7VUE`$AO;64`2&]M92!!9&1R
M97-S`$AO;64@4&AO;F4`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@
M6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA
M8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O
M2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@
M)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`
M2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!S>6YC:')O;FES960@)7,@(B5S
M(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E
M<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA
M8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D
M92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+
M;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T
M(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES
M92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N
M:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S
M(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT
M86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO
M=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M
M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S
M('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@
M`$AU;6]R:7-T<P!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)
M34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@
M<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D9')E
M<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W
M960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T
M(%)O=R!"969O<F4`26-O;G,@3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET
M:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE
M9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)
M9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L
M;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X('1O('1U<FX@
M;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S964@=&AI<R!M97-S86=E
M(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C
M86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!);6%G92!0<F5V
M:65W.@!);6%G92!54DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`
M26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S`$EM<&]R
M="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S
M.@!);B!0<F]C97-S`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I
M;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S
M=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S
M+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@
M>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:79I
M9'5A;"!5<V5R<P!);F9O`$EN9F]R;6%T:6]N`$EN<V5R="!#7V]L=6UN($%F
M=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK
M`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F
M=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R
M92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@
M8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N
M;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D
M90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A
M9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W
M;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS
M97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@
M;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R
M87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E
M`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q
M=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI
M;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB
M=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G9A
M;&ED($%C=&EO;B!S96QE8W1E9"!F;W(@=&AI<R!C;VUP;VYE;G0N`$EN=F%L
M:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@87!P;&EC871I
M;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M:71T960N
M`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O
M<FUA=`!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I
M7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P
M87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!R
M96-I<&EE;G0Z("<E<R<`26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S
M;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R
M>0!)<V]L871E9"!4+5-T;W)M<P!)<W-U97(`271A;&EC`$IA;G5A<GD`2G5L
M>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2V5E<"!O<FEG:6YA;#\`
M2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N
M96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,
M96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O
M;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!,85]Y;W5T`$QA;F=U86=E
M`$QA<W0@2&%L9@!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO
M9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE
M=F5R`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,969T
M`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QI9VAT($1R:7IZ;&4`3&EG:'0@
M4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!2
M86EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W
M`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@
M=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G
M92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U
M<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE
M;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``
M3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,
M:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI
M=&5R871U<F4`3&]A9&EN9R!L:6)R87)I97,N+BX`3&]A9&EN9RXN+@!,;V-A
M;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@
M;W5T`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E
M<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO
M9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE
M='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!-30!-86EL`$UA=&-H:6YG(&9I
M96QD<P!-965T:6YG($-A;F-E;&QA=&EO;@!-965T:6YG($EN9F]R;6%T:6]N
M`$UE971I;F<@4')O<&]S86P`365E=&EN9R!297!L>0!-965T:6YG(%5P9&%T
M90!-965T:6YG(%5P9&%T92!297%U97-T`$UE;G4@;6]D93H`365S<V%G90!-
M;VYT:&QY`$UO=F4@9&]W;@!-;W9E('5P`$YA;64`3F5E9',@06-T:6]N`$YE
M=F5R`$YE=W,`3F5X=`!.97AT(%!A9V4`3F\`3F]N(%!A<G1I8VEP86YT`$YO
M;F4`3F]T97,`3F]T:6-E`$]+`$]F9FEC90!/<'1I;VYA;"!087)T:6-I<&%N
M=`!/<'1I;VYS`$]R9V%N:7II;F<`3W1H97(@26YF;W)M871I;VX`4&%S<W=O
M<F0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R<V]N86P@26YF;W)M
M871I;VX`4&AO;F4`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P
M<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S
M=V]R9`!0;&5A<V4@<F5V:65W('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VXL
M(&%N9"!T:&5N('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO
M=RX`4&QE87-E('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO
M=RX`4')E=FEE=P!0<F5V:6]U<R!086=E`%!R;V)L96T@1&5S8W)I<'1I;VX`
M4F5M96UB97(@=&AE(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`4F5M;W9E('!A
M:7(`4F5P;'D@4V5N="X`4F5P;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A
M9V4`4F5P;'D@=VET:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N`%)E
M<&QY('=I=&@@<F5Q=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`4F5Q
M=6ER960@4&%R=&EC:7!A;G0`4F5S970`4F5T=7)N('1O($]P=&EO;G,`4F]L
M90!3879E`%-A=F4@3W!T:6]N<P!396%R8V@`4V5L96-T(&$@9&%T90!396QE
M8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T
M.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG
M(&9I96QD<RX`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD
M($QA=&5S="!);F9O<FUA=&EO;@!396YD(%!R;V)L96T@4F5P;W)T`%-I9VX@
M=7`@:68@;F]T(')E9VES=&5R960`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-P
M96-I86P@0VAA<F%C=&5R($EN<'5T`%-T87)T`%-T871U<P!3=6)J96-T`%-U
M8FUI=`!3=6-C97-S`%-U;6UA<GD`5&%S:W,`5&5N=&%T:79E;'D@06-C97!T
M(')E<75E<W0`5&5N=&%T:79E;'D@06-C97!T960`5&5X="!/;FQY`%1H92!C
M86QE;F1A<B!D871A(&ES(&EN=F%L:60`5&AE('1A<VL@:&%S(&)E96X@861D
M960@=&\@>6]U<B!T87-K;&ES="X`5&AE('5S97(G<R!F<F5E+V)U<WD@:6YF
M;W)M871I;VX@=V%S('-U8V5S<V9U;&QY('-T;W)E9"X`5&AE<F4@=V%S(&%N
M(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S+@!4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!T87-K.B`E<RX`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N
M.B`E<RX`5&AI<R!A8W1I;VX@:7,@;F]T('-U<'!O<G1E9"X`5&AI<R!A8W1I
M;VX@:7,@;F]T('EE="!I;7!L96UE;G1E9"X`5&AI<R!N=6UB97(@;75S="!B
M92!A="!L96%S="!O;F4N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`
M5&ET;&4`5&\`55),`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N
M`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N9&\@
M0VAA;F=E<P!5;FAA;F1L960@8V]M<&]N96YT(&]F('1Y<&4Z("5S`%5N;F%M
M960`57!D871E(')E<W!O;F1E;G0@<W1A='5S`%5P;&]A9`!5<V5R($]P=&EO
M;G,`57-E<FYA;64`57-E<FYA;64Z`%9I97<@)7,`5FEE=R!E=F5N=`!6:65W
M('1A<VL`5V%R;FEN9P!7965K;'D`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E
M<P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!960!996%R;'D`665S`%EO=2!M
M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@
M=&AE('!R;V)L96T@<F5P;W)T+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER
M960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!);F9O<FUA=&EO;@!9;W5R
M($YA;64`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN
M="!O<'1I;VXN(%!R97-S($-O;G1R;VPO3W!T:6]N("L@4"!T;R!P<FEN="X`
M66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!;4')O8FQE;2!297!O
M<G1=`%ML:6YE("5S(&]F("5S70!?2&5L<`!?3&]G(&]U=`!?3W!T:6]N<P!N
M86UE`'9#87)D`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXP+C0*4F5P
M;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#4M,#4M,3@@,3(Z-#,K,#(P,`I03RU2979I<VEO
M;BU$871E.B`R,#`U+3`U+3$X(#$T.C,W*S`R,#`*3&%S="U4<F%N<VQA=&]R
M.B!'96ER($\N($AO9V)E<F<@/&AO<F1E0'-K>61I=F5R+FYO/@I,86YG=6%G
M92U496%M.B!.;W)W96=I86X@*$)O:VUA;"D@/&DQ.&Y`;&ES=',N:&]R9&4N
M;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA
M:6X[(&-H87)S970]:7-O+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N8V]D
M:6YG.B`X8FET"@`@)B,Q-3$[("5S(&5R(&ML87(@9F]R(.4@=71F^')E('9E
M9&QI:V5H;VQD<V]P97)A<VIO;F5N92!S;VT@97(@=F%L9W0@;F5D96YF;W(N
M`"`H)7,@9&%G97(@<VED96XI`"`H:'5R=&EG=&%S="`E<RD`("AI;FYE;B`E
M<R!D86=E<BD`("AI(&1A9RD`("AI(&UO<F=E;BD`("AI(&?E<BD`(&1E;B``
M)60@)7,@;V<@)7,`)60@8GET97,@<VMR979E="X`)60@878@)60@;W!P9OAR
M:6YG97(@;6%R:V5T('-O;2!O<'!D871E<G0`)60M9&%G97)S('9A<G-E;``E
M<R`M(%1I;"!I;F9O`"5S(&%D;6EN:7-T<F%S:F]N`"5S($9I;F=E<G!R:6YT
M`"5S($M"`"5S('9E9&QI:V5H;VQD<V]P97)A<VIO;F5R("T@0F5K<F5F=&5L
M<V4`)7,@:6YS=&EL;&EN9V5R`"5S(')E9VES=')E<FEN9P`E<R!A=G1A;&5V
M:6QKY7(`)7,@9FEN;F5S(&%L;&5R961E+@`E<R!PY2`E<R`E<P`E<R!H87(@
M:V%N<V5L;&5R="`E<RX`)7,@:&%R(&)E<W9A<G0@96X@9F]R97-P^')S96P@
M;VT@:6YF;W)M87-J;VX@86YGY65N9&4@;&5D:6<O;W!P=&%T="X`)7,@:&%R
M('-V87)T('#E(&EN=FET87-J;VYE;B!T:6P@)7,N`"5S(&AA<B!S96YD="!D
M96<@:6YF;W)M87-J;VX@;VT@;&5D:6<O;W!P=&%T="X`)7,@97(@<VMR:79E
M8F5S:WET=&5T+@`E<R!E<B!PY6MR979D`"5S(&UI;G5T=&5R`"5S(&EK:V4@
M9G5N;F5T+@`E<R!F;W)E<W#X<B!I;F9O<FUA<VIO;B!O;2!NY7(@9'4@97(@
M;&5D:6<O;W!T=&%T="X`)7,@9F]R97-P^'(@9&EN(&1E;'1A9V5L<V4@<.4@
M)7,N`"5S("T@)7,@878@)7,`)7,@^&YS:V5R(.4@;&5G9V4@=&EL("5S+@`E
M<R#X;G-K97(@Y2!G:OAR92!D96<@;W!P;65R:W-O;2!PY2`E<RX`)7,@^&YS
M:V5R(.4@;6]T=&$@9&5N('-I<W0@;W!P9&%T97)T92!I;F9O<FUA<VIO;F5N
M(&]M("5S+@!!9&1R97-S96)O:R!F;W(@)7,`2V%L96YD97(@9F]R("5S`$YO
M=&%T8FQO:VL@9F]R("5S`$]P<&=A=F5L:7-T92!F;W(@)7,`)7,Z("5S`"<E
M<R<@97(@:6MK92!E="!G>6QD:6<@=F%L9RX`)R5S)R!E<B!I:VME(&-O;F9I
M9W5R97)T(&D@2&]R9&4@4F5G:7-T97)E="X`)7,@8FQE(&QA9W0@=&EL(&=R
M=7!P97-Y<W1E;65T+@`G)7,G(&)L92!L86=T('1I;"!R971T:6=H971S<WES
M=&5M970N`"5S(&)L92!I:VME(&]P<')E='1E=#H@)7,N`"P@=F%R:6%B96P@
M;65L;&]M("5S(&]G("5S`"TM('9E;&<@+2T`,3(@5&EM97)S(&9O<FUA=``R
M-"!4:6UE<G,@9F]R;6%T`#(T('1I;65R`$5N(&1A=&%B87-E:V]B;&EN9R!E
M<B!PY6MR979D(&9O<B!D96YN92!B;&]K:V5N+@!%;B!F871A;"!F96EL(&AA
M<B!O<'!S=.5T=`!%;B!O9F9E;G1L:6<@4$=0+6[X:VME;"!E<B!PY6MR979D
M(&9O<B#E(&MR>7!T97)E(&UE;&1I;F=E;BX`16X@;V9F96YT;&EG(%!'4"UN
M^&MK96P@97(@<.5K<F5V9"!F;W(@Y2!V97)I9FES97)E('-I9VYE<G0@;65L
M9&EN9RX`16X@;V9F96YT;&EG(%!'4"UN^&MK96PL('!R:79A="!01U`M;OAK
M:V5L(&]G('!A<W-P:')A<V4@97(@<.5K<F5V9"!F;W(@Y2!D96MR>7!T97)E
M(&5N(&UE;&1I;F<N`$5N(&]F9F5N=&QI9R!01U`M;OAK:V5L+"!P<FEV870@
M4$=0+6[X:VME;"!O9R!P87-S<&AR87-E(&5R('#E:W)E=F0@9F]R(.4@<VEG
M;F5R92!E;B!M96QD:6YG+@!%;B!O9F9E;G1L:6<@4R]-24U%+6[X:VME;"P@
M<')I=F%T(%,O34E-12UN^&MK96PL(&]G('!A<W-P:')A<V4@97(@<.5K<F5V
M9"!F;W(@Y2!D96MR>7!T97)E(&5N(&UE;&1I;F<N`$5N(&]F9F5N=&QI9R!3
M+TU)344M;OAK:V5L+"!P<FEV870@4R]-24U%+6[X:VME;"P@;V<@<&%S<W!H
M<F%S92!E<B!PY6MR979D(&9O<B#E('-I9VYE<F4@96X@;65L9&EN9RX`16X@
M;V9F96YT;&EG(%,O34E-12UN^&MK96P@97(@<.5K<F5V9"!F;W(@Y2!K<GEP
M=&5R92!E;B!M96QD:6YG+@!!32]030!/;2!D96YN92!E9&ET;W)E;@!/;2XN
M+@!!8G-O;'5T="!N961E<G-T`$%B<V]L=71T(&UI9'0`1V]D:VIE;FX@9F]R
M97-P^')S96P`1V]D=&%T=`!4:6QG86YG(&YE:W1E="!V960@;W!P<F5T=&5L
M<V4@878@5D93(&MA=&%L;V<N`%1I;&=A;F<@;F5K=&5T('9E9"!O<'!R971T
M96QS92!A=B!61E,@9FEL+@!+;VYT;R!087-S;W)D`$MO;G1O(&9R^'-E="X`
M0F]K:&]L9&EN9R]!8V-O=6YT:6YG`$AA;F1L:6YG97(`3&5G9R!T:6P`3&5G
M9R!T:6P@=6YD97)G<G5P<&4`3&5G9R!T:6P@=6YD97)R971T:6=H971E<@!,
M96=G('1I;"!H97(Z`$QE9V<@=&EL(&YY(&=R=7!P90!,96=G('1I;"!N>2!R
M971T:6=H970`3&5G9R!T:6P@96X@=6YD97)G<G5P<&4@=&EL("<E<R<`3&5G
M9R!T:6P@=6YD97)R971T:6=H970@=&EL("<E<R<`3&5G9R!T:6P@;GD@8G)U
M:V5R.@!,96=G('1I;"!K;VQO;FYE`$QE9V<@=&EL(&YY92!M961L96UM97(`
M3&5G9R!T:6P@<&%R`$QE9V<@=&EL("5S(&UE;GEE;B!S;VT@36]Z:6QL82!3
M:61E8F%R`$QE9V<@=&EL(&D@;6EN(&MA;&5N9&5R`$QE9V<@=&EL(&D@861D
M<F5S<V5B;VLZ`$QE9V<@=&EL(&D@;6EN(&%D9')E<W-E8F]K`$QE9V<@=&EL
M(&)R=6ME<@!,82!T:6P@)R5S)R!I('-Y<W1E;65T+"!M96X@:W5N;F4@:6MK
M92!L96=G92!T:6P@96MS=')A(')E9VES=')E<FEN9W-I;F9O.B`E<RX`3&$@
M)R5S)R!T:6P@<WES=&5M970N($1U(&MA;B!L;V=G92!I;FX@;N4N`$QA('1I
M;"!N>64@9FEL97(@:2!R97!O<VET;W)Y.@!-=6QI9VAE="!F;W(@Y2!L96=G
M92!T:6P@;GEE(&)R=6ME<F4@97(@9&5A:W1I=F5R="X`061R97-S90!!9')E
M<W-E($)O:P!!9&UI;FES=')E<B`M('-E='0@<F5T=&EG:&5T97(@9F]R(&%N
M9')E(&)R=6ME<F4`061M:6YI<W1R87-J;VX`4F5K;&%M97(`06QI87,`2G5S
M=&5R90!*=7-T97)I;F<Z`$%L;&4`06QL92!A=71E;G1I<V5R=&4@8G)U:V5R
M90!!;&QE($=R=7!P97(`06QL92!R961D:6=H971E<@!!;&QE(&9I<F4@<VED
M97(`5&EL;&%T="!F;&5R92!A9')E<W-E<@!4:6QL871T(&5N9')I;F<@878@
M9F]R;6%T970@<.4@;G5M;65R97)T92!L:7-T97(_`$5K<VES=&5R97(@86QL
M97)E9&4`06QT97)N871I=B!)35-0($QO9VEN`$%L=&5R;F%T:79T($E-4U`@
M<&%S<V]R9`!!;'1E<FYA=&EV="!)35-0(&)R=6ME<FYA=FX`06QT97)N871I
M=B!E+7!O<W0@861R97-S90!!;'1E<FYA=&EV92!M86QE<@!!;'1E<FYA=&EV
M('1E:W-T.@!%;B!U;&]V;&EG('9E<F1I('9A<B!O<'!G:71T+@!!;F]N>6T@
M4')O>'D`4W9A<@!0<F]G<F%M`%!R;V=R86UL:7-T90!0<F]G<F%M;65T(&5R
M(&ML87)T+@!/<'!D871E<B!O9W/E(')E:W5R<VEV="!N961O=F5R(&9O<B!U
M;F1E<FUA<'!E<B]F:6QE<@!';V1K:F5N;@!/;71R96YT;&EG('-T^')R96QS
M90!&:6QS=/AR<F5L<V4@<.4@87)K:79E=`!!<FMI=FYA=FX`17(@9'4@4TE+
M2T52('#E(&%T(&1U('9I;"!F:F5R;F4@<F5G:7-T<F5R:6YG<V9O<F5S</AR
M<V5L96X@9F]R("5S/P!%<B!D=2!S:6MK97(@<.4@870@9'4@=FEL('-L971T
M92`G)7,G(&]G(&1E;G,@=6YD97)G<G5P<&5R/P!+=6YS=`!!<V-I:2!K=6YS
M=`!"92!O;2!B96MR969T96QS92!F^'(@9VIE;FYO;6;X<FEN9R!A=B!V961L
M:6ME:&]L9'-O<&5R87-J;VYE<@!+;VQO;FYE86YV:7-N:6YG`%9E9&QA9W0@
M:2!S=F%R970@97(@96X@:4-A;&5N9&%R(&9I;"!F;W(@96X@9F]R97-P^')S
M96P@9'4@<V5N9'1E`$9O<G/X:W1E(.4@<VQE='1E(&5N(&=R=7!P92!S;VT@
M:6MK92!E:W-I<W1E<F5R+@!&;W)S^&MT92#E('-L971T92!E;B!R971T:6=H
M970@<V]M(&EK:V4@96MS:7-T97)E<BX`1F]R<_AK=&4@Y2!R961I9V5R92!E
M;B!R971T:6=H970@<V]M(&EK:V4@96MS:7-T97)E<BX`1F]R<_AK=&4@Y2!R
M961I9V5R92!E;B!D96QT(')E<W-U<G,@<V]M(&EK:V4@96MS:7-T97)E<BX`
M1&5L=&%G97)E`$%T=')I8G5T`-AS=&5R<FEK90!!=71H7V-Y<G-Q;#H@2V%N
M(&EK:V4@9FEN;F4@9&5N(&[X9'9E;F1I9V4@24U!4"!U='9I9&5L<V5N+@!!
M=71H7V-Y<G5S.B!"86-K96YD(&EN;F5H87(@:6MK92!N^&1V96YD:6<@9G5N
M:W-J;VYA;&ET970N`$%U=&A?8WER=7,Z($MA;B!I:VME(&9I;FYE(&1E;B!N
M^&1V96YD:6=E($E-05`@=71V:61E;'-E;BX`075T:%]F='`Z($MA;B!I:VME
M(&9I;FYE(&1E;B!N^&1V96YD:6=E($944"!U='9I9&5L<V5N+B!+;VUP:6QE
M<B!02%`@;65D("TM96YA8FQE+69T<"X`075T:%]I;6%P.B!+86X@:6MK92!F
M:6YN92!D96X@;OAD=F5N9&EG92!)34%0('5T=FED96QS96XN`$%U=&A?:W)B
M-3H@2V%N(&EK:V4@9FEN;F4@9&5N(&[X9'9E;F1I9V4@:W)B-2!U='9I9&5L
M<V5N+@!!=71H7VQD87`Z($MA;B!I:VME(&9I;FYE(&1E;B!N^&1V96YD:6=E
M($Q$05`@=71V:61E;'-E;BX`075T:%]L9&%P.B!+=6YN92!I:VME(&QE9V=E
M('1I;"!B<G5K97(@)7,N(%-E<G9E<F5N('-A.B``075T:%]L9&%P.B!+=6YN
M92!I:VME(&9J97)N92!B<G5K97)E;B`E<P!!=71H7VQD87`Z($MU;FYE(&EK
M:V4@;W!P9&%T97)E(&)R=6ME<B`E<P!!=71H7VUC86PZ($MA;B!I:VME(&9I
M;FYE(&1E;B!N^&1V96YD:6=E($U#04P@=71V:61E;'-E;BX`075T:%]S;6)A
M=71H.B!+86X@:6MK92!F:6YN92!D96X@;OAD=F5N9&EG92!S;6)A=71H('5T
M=FED96QS96XN`$%U=&5N=&ES97)I;F<@9F5I;&5T`$%U=&5N=&ES97)I;F<@
M9F5I;&5T+B`E<P!!=71E;G1I<V5R:6YG(&YE:W1E="!A=B!2041)55,@=&IE
M;F5R+@!!=71E;G1I<V5R:6YG(&UO="!&5%`@=&IE;F5R96X@9F5I;&5T+@!4
M:6QG:F5N9V5L:6=E(&9E;'0Z`%9E;G1E<B!PY2!S=F%R`$)/1D@@17AC=7-E
M<P!"86MG<G5N;@!"86MG<G5N;G-F87)G90!&96EL(&ME<F)E<F]S('!A<W-O
M<F0N`$9E:6P@:V5R8F5R;W,@8G)U:V5R;F%V;BX`0FQA;FL`0F%S96MA=&%L
M;V<@9F]R(&=R869I:VL@)R5S)R!B;&4@:6MK92!F=6YN970N`$=R=6YN;&EN
M:F4`0F5L:6=A`$)U<G-D86<`0FQO:VL@(B5S(B!A=B!P<F]G<F%M;65T("(E
M<R(@8FQE(&EK:V4@9G5N;F5T+@!";&]K:R!I;FYS=&EL;&EN9V5R`$)L;VMK
M('1Y<&4`1F5T`$)O:VUE<FME<@!286UM90!286UM971Y:VME;'-E.@!286UM
M97(`0F5G9V4`0G5N;@!0=6YK=&QI<W1E`$--4P!#4D,`0U),($1I<W1R:6)U
M<VIO;G-P=6YK=&5R`$5G96YS:V%P97(@9F]R(&-?96QL92XN+@!+86QE;F1E
M<@!3=&EL;&4`2V%N(&EK:V4@;G5L;'-T:6QL92!P87-S;W)D(&%U=&]M871I
M<VLL(&MO;G1A:W0@9&EN(&%D;6EN:7-T<F%T;W(N`$MA;B!I:VME(&MO8FQE
M('1I;"!)34%0('1J96YE<F5N.B`E<P!+86YA9&$`079B<GET`$%V8G)Y="!P
M<F]B;&5M<F%P<&]R=`!+86X@:6MK92!S;&5T=&4@9FEL96X@(B5S(BX`2V%N
M(&EK:V4@9FEN;F4@96X@=&5M<"UK871A;&]G+@!+86X@:6MK92!F;W)T<V5T
M=&4@=71E;B`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!+86X@:6MK92!S;&5T
M=&4@:V%T86QO9V5N("(E<R(N`$MA;B!I:VME('-L971T92P@)60@8F%R;B!E
M:W-I<W1E<F5R+@!+86X@:6MK92!E;F1R92!R96MK96;X;&=E;BP@86YT86QL
M970@;W!P9OAR:6YG97(@=F%L9W0@9F]R(&]M<V]R=&5R:6YG('-T96UM97(@
M:6MK92!M960@86YT86QL970@;&%G<F5D92!O<'!F^')I;F=E<BX`2V%N(&EK
M:V4@<V5N9&4@;65L9&EN9V5N('1I;"!D970@<W!E<VEF:7-E<G1E(&YU;6UE
M<F5T+@!5=&1R86<`2V%T96=O<FEE<B!O9R!E=&EK971T97(`36]B:6QT96QE
M9F]N`$5G96YS:V%P97(@9F]R(&-E;&QE`$QU9G0@<G5N9'0@:6YN:&]L9"!A
M=B!C96QL93H`16=E;G-K87!E<B!F;W(@8V5L;&4`3'5F="!R=6YD="!C96QL
M96XZ`$UO8FEL=&5L969O;@!396YT97(`1&5T86QJ97(@9F]R('-E<G1I9FEK
M870`4F5T=&YI;F=S;&EN:F5R(&9O<B!S97)T:69I:V%T`$]R9'-T>7)E<@!%
M;F1R90!%;F1R92!N879N(&]G(&%D<F5S<V4@<V]M(&UO='1A:V5R92!S97(@
M;N5R(&1E(&QE<V5R(&]G('-V87)E<B!PY2!P;W-T96X@9&EN+@!496=N`%-J
M96M?:R!L:6YK+BXN`%9E;&<@9&4@;W!E<F%S:F]N96YE(&1U('9I;"!U=&;X
M<F4@;N4N`%9E;&<@971T('!A<W-O<F0`5F5L9R!E='0@8G)U:V5R;F%V;@!6
M96QG(&AA;F1L:6YG.@!696QG(&AV;W)D86X@9'4@=FEL('9I<V4@9&%T;V5R
M.@!696QG('-T:6P@<.4@;&ES=&5T>7!E("AF;W(@;G5M;65R97)T92!L:7-T
M97(I`$ML87-S961E9FEN:7-J;VX@9F]R("5S(&)L92!I:VME(&9U;FYE="X`
M2VQA<G0`1FIE<FX@35-/9F9I8V4@=&%G<P!&:F5R;B!B<G5K97(Z("5S`$9J
M97)N(&)R=6ME<@!&:F5R;B!B<G5K97)D871A`$ML:6MK(&9O<B#E(&9O<G1S
M971T90!#;&EC:V%T96QL('9I82!(5%10`$QU:VL@=FEN9'4`4VMY97(`4VMY
M970`4VSE('-A;6UE;B!S:61E;&EN:F5N`%-A;6UE;G-LY71T(')A;6UE`$9A
M<F=E`$9A<F=E=F5L9V5R`$9A<F=E=F%L9P!+;VQO;FYE+71I=&QE<@!496=N
M97-E<FEE<@!+;VUM86YD;P!+;VUM86YD;W9I;F1U`%9A;&<@9F]R(&MO;6UA
M;F1O.@!+;VUM86YD;V5R.@!+;VUM96YT87(`4VIE:VL@:6YN.@!686YL:6<@
M;F%V;@!&:7)M80!&97)D:6<`4VMR:78@;65L9&EN9R`H)7,I`$1A=&%M87-K
M:6YE<@!6:6QKY7(`1F]R<VMJ96QL97(@:2!I;FYS=&EL;&EN9V5N90!);FYS
M=&EL;&EN9V5R(&)E:/AV97(@;W!P9&%T97)I;F<N`$MO;F9I9W5R97(@)7,`
M0F5K<F5F="!P87-S;W)D`%1I;&MO8FQI;F<@;6ES;'EK=&5S+@!4:6QK;V)L
M:6YG(&UI<VQY:W1E<SH@`$MO8FQI;F=E;B!T:6P@9&5N(&]F9F5N=&QI9V4@
M;OAK:V5L=&IE;F5R96X@9F5I;&5T+@!+;V)L:6YG96X@=&EL(&1E;B!O9F9E
M;G1L:6=E(&[X:VME;'1J96YE<F5N(&9E:6QE="X@Q7)S86LZ("5S("@E<RD`
M2V]B;&EN9V5N('1I;"!&5%`@=&IE;F5R96X@;6ES;'EK=&5S+@!+;VYT86MT
M96YE(&)L92!L86=T('1I;"!A9')E<W-E8F]K96X`26YN:&]L9"!I("<E<R<`
M1F]R='-E='0`0V]O:VEE`$MO<&EE<@!+;W!I97(@=F%L9W0@;VURY61E`$MO
M<&EE<F5R("5S('1I;"`E<P!+=6YN92!I:VME(%!'4"UK<GEP=&5R92!M96QD
M:6YG`$MU;FYE(&EK:V4@4$=0+7-I9VYE<F4@;65L9&EN9P!+=6YN92!I:VME
M(&MR>7!T97)E(&UE;&1I;F=E;B!M960@4R]-24U%+@!+=6YN92!I:VME('-I
M9VYE<F4@;65L9&EN9V5N(&UE9"!3+TU)344N`$MU;FYE(&EK:V4@;&5G9V4@
M=&EL(&MO;G1A:W0Z("5S`%1I;&MO8FQI;F<@=&EL($Q$05`M<V5R=F5R(&9E
M:6QE="X`2W5N;F4@:6MK92!S:F5K:V4@=&EL9VIE;F=E;&EG(&MR961I='0N
M("5S`$ML87)T92!I:VME(.4@:V]B;&4@=&EL('1J96YE<F5N("<E<R<@=F5D
M(&)R=6L@878@1E10.B`E<P!+=6YN92!I:VME(&MO<&EE<F4@)7,@=&EL("5S
M`$MU;FYE(&EK:V4@;&%G92!D:7-T<FEB=7-J;VYS;&ES=&4N("5S`$MU;FYE
M(&EK:V4@;W!P<F5T=&4@;&]C86QE(&MA=&%L;V<@9F]R(&QO8V%L92`E<SH`
M2W5N;F4@:6MK92!D96MR>7!T97)E(%!'4"!M96QD:6YG+@!+=6YN92!I:VME
M(&1E:W)Y<'1E<F4@4R]-24U%(&UE;&1I;F<N`$ML87)T92!I:VME(.4@<VQE
M='1E(&MO;G1A:W0N("5S`$ML87)T92!I:VME(.4@<VQE='1E(&1I<W1R:6)U
M<VIO;G-L:7-T92X@)7,`2W5N;F4@:6MK92!S;&5T=&4@<V5T=7`@;W!P9W)A
M9&5R:6YG<W-C<FEP="`G)7,G+@!+=6YN92!I:VME(&9I;FYE(&UO='1A:V5R
M<R!E+7!O<W0@861R97-S92X`2W5N;F4@:6MK92!H96YT92!U="!H96QE(&%D
M<F5S<V5B;VME;BX`2W5N;F4@:6MK92!U="!H96QE(&1I<W1R:6)U<VIO;G-L
M:7-T96XN`$MU;FYE(&EK:V4@:&5N=&4@=70@:&5L92!L:7-T96X@;65D(&1I
M<W1R:6)U<VIO;G-L:7-T97(N`$MU;FYE(&EK:V4@;&%S=&4@:6YN('-T<F%T
M96=I("<E<R<N`$MU;FYE(&EK:V4@;W!P<F5T=&4@:V%T86QO9V5N("<E<R<N
M`$MU;FYE(&EK:V4@:&5N=&4@=70@;V9F96YT;&EG(&[X:VME;"!F<F$@;OAK
M:V5L=&IE;F5R96XN`$MU;FYE(&EK:V4@Y7!N92`E<RX`2W5N;F4@:6MK92#E
M<&YE("<E<R<@9F]R('-K<FEV:6YG+@!+86X@:6MK92#E<&YE($UA:6YT96YA
M;F-E7U1A<VLM;6]D=6QE;B`E<P!+=6YN92!I:VME(.5P;F4@:V%T86QO9V5N
M("<E<R<N`$MU;FYE(&EK:V4@;&5S92`E<P!+=6YN92!I:VME(&YU;&QS=&EL
M;&4@<&%S<V]R9&5T(&9O<B!D96X@9F]R97-P=7)T92!B<G5K97)E;BX@3F]E
M;B!E;&QE<B!A;&QE(&1E=&%L:F5N92!E<B!U<FEK=&EG92X@1F]R<_AK(&EG
M:F5N(&5L;&5R(&MO;G1A:W0@861M:6YI<W1R871O<F5N(&AV:7,@9'4@=')E
M;F=E<B!Y='1E<FQI9V5R92!H:F5L<"X`2W5N;F4@:6MK92!H96YT92!U="!!
M0TP`2W5N;F4@:6MK92!H96YT92!U="!A9')E<W-E8F]K+B`E<P!+=6YN92!I
M:VME(&AE;G1E('5T(&1I<W1R:6)U<VIO;G-L:7-T92X@)7,`2W5N;F4@:6MK
M92!H96YT92!U="!D:7-T<FEB=7-J;VYS;&ES=&4N("5S`$MU;FYE(&EK:V4@
M:&5N=&4@=70@:6YF;W)M87-J;VX@;VT@=&IE;F5R96YS(&9U;FMS:F]N86QI
M=&5T97(`2W5N;F4@:6MK92!R979E<G1E<F4@:V]N9FEG=7)A<VIO;F5N92X`
M2W5N;F4@:6MK92!F:F5R;F4@:V%T86QO9V5N("<E<R<N`$MU;FYE(&EK:V4@
M;&%G<F4@)7,@:V]N9FEG=7)A<VIO;BX`2W5N;F4@:6MK92!L86=R92!E;B!B
M86-K=7`@:V]N9FEG=7)A<VIO;BX`2W5N;F4@:6MK92!L86=R92!E;B!B86-K
M=7`@8V]N9FEG=7)A<VIO;CH@)7,`2W5N;F4@:6MK92!L86=R92!S971U<"!O
M<'!G<F%D97)I;F=S+7-C<FEP=&5T('1I;#H@)R5S)RX`2W5N;F4@:6MK92!L
M86=R92!B86-K=7`@:V]N9FEG=7)A<VIO;G-F:6QE;B`E<RX`2W5N;F4@:6MK
M92!L86=R92!K;VYF:6=U<F%S:F]N<V9I;&5N("5S+B!$=2!K86X@96YT96X@
M8F5N>71T92!D96<@878@96X@878@;75L:6=H971E;F4@9F]R(.4@;&%G<F4@
M9&%T82!T:6QB86ME('1I;"`E<R!E;&QE<B!K;W!I97)E(&MO9&5N('5N9&5R
M(&UA;G5E;'0@=&EL("5S+@!+=6YN92!I:VME('5T9OAR92!S^&L@<.4@3$1!
M4"!T:F5N97)E;BX`2W5N;F4@:6MK92!F:F5R;F4@)R5S)RX`2W5N;F4@:6MK
M92!O<'!D871E<F4@:V]N=&%K="X@)7,`2W5N;F4@:6MK92!O<'!D871E<F4@
M9&ES=')I8G5S:F]N<VQI<W1E;BX@)7,`2W5N;F4@:6MK92!S:W)I=F4@:V]N
M9FEG=7)A<VIO;B!F;W(@)R5S)SH@)7,`2W5N;F4@:6MK92!F:6YN92!-;WII
M;&QA(%-I9&5B87(N(%-J96MK(&%T(&1E;B!E<B#E<&5N+@!"<G5K97)E;B`G
M)7,G(&)L92!G:71T(&;X;&=E;F1E(')E='1I9VAE=&5R('1I;"!M87!P96X@
M)R5S)SH@)7,`5&%L="!T96MS=`!,86YD`$MU<G-E<@!/<'!R971T`$]P<')E
M='0@96X@;&EN:P!/<'!R971T(&5N(&YY`$]P<')E='0@=6YD97)M87!P97(`
M4F5T=&EG:&5T97(@9F]R(&5I97(`2W)E9&ET=&MO<G1N=6UM97(`1VIE;&1E
M;F1E(&9A<V4`1VIE;&1E;F1E('1I9`!':F5L9&5N9&4@=N9R`$=J96QD96YD
M92!U='-I:W1E<CH@`$=J96QD96YD92!S=&EL`%1I;'!A<W,@;W!P9V%V97(@
M<V]M(&MJ^')E<R!V960@:6YN;&]G9VEN9R!T:6P@)7,N`$ML:7!P('5T`$ML
M:7!P('5T('9A;&=T(&]M<N5D90!+>7!R;W,`1$0`1&%G;&EG`$1A=&$`1&%T
M851R92!U=&9O<G-K97(`1&%T;P!$871O($UO='1A='0`1&%T;R!V86QG`$1A
M9P!3;&5T="!K;VQO;FYE`$1E<V5M8F5R`$1E<VEM86QT86QL`$%V<VSE='0`
M4F5D=7-E<B!I;FYR>6MK`%-T86YD87)D`%-T86YD87)D(&9A<F=E`%-T86YD
M87)D:61E;G1I=&5T`%-T86YD87)D(')E='1I9VAE=&5R`%-T86YD87)D(')E
M='1I9VAE=&5R`$1E9FEN:7-J;VYE<@!$96QE9V5R('!O<VES:F]N`$1E;&5G
M97)T`%-L971T`%-L971T(&=R=7!P90!3;&5T="!R971T:6=H970`4VQE='0@
M;V<@9FIE<FX@;65L9&EN9V5R`%-L971T(&-E;&QE`%-L971T(&MO;&]N;F4`
M4VQE='0@96MS:7-T97)E;F1E(&%L=&5R;F%T:78@;6%L`$9J97)N(')E='1I
M9VAE=&5N92!T:6P@)R5S)P!&:F5R;B!R971T:6=H971E;F4@=&EL("<E<R<@
M;V<@86QL92!U;F1E<BUR971T:6=H971E<C\`4VQE='0@<F%D`%-L971T('9A
M;&=T(&ED96YT:71E=`!3;&5T="!G:F5L9&5N9&4@:V]L;VYN90!3;&5T="!G
M:F5L9&5N9&4@<F%D`%-L971T92!D96YN92!R971T:6=H971E;B!O9R!A;&QE
M('5N9&5R+7)E='1I9VAE=&5R/P!3;&5T="!S971U<"!O<'!G<F%D97)I;F=S
M+7-C<FEP="`G)7,G+@!,979E<FEN9W-T:60`1&%N;6%R:P!!=G-LY2!F;W)E
M<W#X<G-E;`!!=G-LY2!F;W)E<W#X<G-E;"!F;W(@;&5D:6<O;W!P=&%T="UI
M;F9O<FUA<VIO;@!"97-K<FEV('!R;V)L96UE=`!"97-K<FEV96QS90!$971A
M;&IE<B`H;V=SY2!I($AO<F1E)W,@;&]G9V9I;"DZ`$1E=&%L:F5R(&AA<B!B
M;&ET="!L;V=G970@9F]R(&%D;6EN:7-T<F%T;W)E;BX`571V:6ML:6YG`$1O
M9V=P=6YK=`!$;V=G<'5N:W0@9F]R(&1E;B!S:7-T92!T:6UE;CH@`$1O9V=P
M=6YK=#H@`%)E=&YI;F<@9G)A('9E;G-T<F4@;6]T(&CX>7)E`%)E=&YI;F<@
M9G)A(&CX>7)E(&UO="!V96YS=')E`$MA=&%L;V<`5FES(#(T+71I;65R<R!T
M:61E<C\`5FES;FEN9W-V86QG`%9I<R!F;W)V87)S96P@*%1!1BD`5FES;FEN
M9W-F;W)M870`365L9&EN9R!O;2!O<F1N:6YG`$EK:V4@<VQE='0`26MK92#E
M<&YE(&UA:6YE;F%N8V4N<&AP(&1I<F5K=&4`2W)Y<W,@878@:&5R(&AV:7,@
M9&5N(&;X<G-T92!R861E;B!I;FYE:&]L9&5R(&9E;'0M;F%V;F5T.@!,87-T
M(&YE9`!,87-T(&YE9"!G96YE<F5R="!K;VYF:6=U<F%S:F]N('-O;2!02%`@
M<V-R:7!T+@!.961T<F5K:W-L:7-T90!-961I<VEN97(`12UP;W-T`$524@!2
M961I9V5R`%)E9&EG97)E(&)L;VMK`%)E9&EG97(@1W)U<'!E`%)E9&EG97(@
M<F5T=&EG:&5T97(`4F5D:6=E<B!R971T:6=H=&5R`%)E9&EG97(@<F5T=&EG
M:&5T97(@9F]R("5S`%)E9&EG97(@=F%L9R!F;W(Z`%)E9&EG97(@<F5T=&EG
M:&5T97(@9F]R("5S`%)E9&EG97(@<F5T=&EG:&5T97(@9F]R("5S`$]P<&SF
M<FEN9P!%;&5M96YT+BXN`$5M`$4M<&]S=`!%+7!O<W1A9')E<W-E`$4M<&]S
M=&%D<F5S<V4@;>4@<W1E;6UE+@!%+7!O<W0@;65D(&)E:W)E9G1E;'-E`$;X
M;&5L<V5R`%1O;2!M96QD:6YG+@!4;VUT(')E<W5L=&%T+@!4^&T@<_AK96MR
M:71E<FEE<@!!:W1I=F5R(&UU;&EG:&5T(&9O<B#E('-E='1E(&EN;B!B:6QD
M97(@9G)A(&=A;&QE<FEE<B!I('1E:W-T96X_`$%K=&EV97)E(&CX>7)E:VQI
M:VL@;65N>3\`4VQU='0`Q7)S<VQU='0`1VKX<B!E9&ET;W)E;B!S=/AR<F4`
M4VMR:78@:6YN(&5T="!S:6MK97)H971S<W#X<G-MY6P@<V]M(&1U('9I;"!B
M;&D@<W!U<G0@;VT@:'9I<R!D=2#X;G-K97(@Y2!N=6QL<W1I;&QE('!A<W-O
M<F1E="!D:71T+"!F+F5K<RX@)VAV82!E<B!N879N970@<.4@:VKF;&5D>7)E
M="!D:71T/R<Z`%-K<FEV(&EN;B!A9')E<W-E;B!T:6P@8FEL9&5T(&AE<@!&
M96EL`$9E:6P@=F5D('-E;F1I;F<@878@<W9A<CH@)7,`1F5I;"!M960@92UP
M;W-T(&UE;&1I;F=E;BX`1F5I;"!V960@<VMR:79I;F<@=&EL("<E<R<N`$9E
M:6PZ(`!%=7)O<&$`2'9E<G0@,34N(&UI;G5T=`!(=F5R="`R+B!M:6YU='0`
M2'9E<G0@,S`N('-E:W5N9`!(=F5R="`U+B!M:6YU='0`2'9E<B!I;FYL;V=G
M:6YG`$AV97(@:&%L=G1I;64`2'9E<G0@;6EN=71T`$5K<V5M<&5L=F5R9&EE
M<CH`2VKX<@!+:OAR97(Z`%5T=FED`%5T=FED(%-I9&5B87(`1F]R=F5N=&5T
M("<I)P!&;W)V96YT970@8FQA;FMT(&]R9"!E;&QE<B!Q=6]T970@<_AK96MR
M:71E<FEE`%5T;/AP<V1A=&\`16MS<&]N96YT`$9O<F=R=6YN<V9A<F=E`$]P
M<&QA<W1I;F<@878@<V5T=7`@=FEA($944`!5=&AE;G1I;F<@878@:6YS=&EL
M;&EN9V5R(&9E:6QE="X`5&EL:V]B;&EN9R!T:6P@3$1!4"UT:F5N97(@9F5I
M;&5T+@!4:6QK;V)L:6YG('1I;"!334(M=&IE;F5R(&9E:6QE="X`1F5I;&5T
M('9E9"!K;W!I97)I;F<@9G)A("(E<R(N`$9E:6QE="!V960@:V]P:65R:6YG
M('1I;"`B)7,B+@!&96EL970@=F5D(&]P<')E='1E;'-E(&%V(&YY(%-!4TP@
M:V]B;&EN9RX`1F5I;&5T('9E9"!F;'ET=&EN9R!T:6P@(B5S(BX`4&5N="!V
MYG(`1F%T86P@1F5I;#H@`$9A>`!&96)R=6%R`$;X;&5S('-O;0!&^&QE<R!S
M;VTZ(`!&Y2!B>6=E<@!&Y2!S;OAB>6=E<@!&96QT;6%T<FES90!!;G1A;&P@
M9FEL97(Z("5S(&9I;&5R`$%N=&%L;"!F:6QE<CH@)7,@9FEL97(`1FEL8F5H
M86YD;&5R`$9I;&YA=FX`1FEL=F%L9P!,87-T(&]P<"!F:6QE<@!/<'!L87-T
M:6YG(&%V(&9I;&5R('-T^'1T97,@:6MK92X`1FEL=&5R`$;X<G-T92!H86QV
M;>5N90!&^')S=&4@:W9A<G1MY6YE`$9A<W0@9F]R:&]L9`!3;G4`1FQY=`!4
MY6ME`$UA<'!E;B`E<R!E:W-I<W1E<F5R(&EK:V4`1F]N=&9A<F=E`$UA=`!&
M;W(@;F5T=&QE<V5R92!S;VT@:6MK92!S=/AT=&5R(&)I;&1E<@!&;W)V87)S
M96P@*%1!1BD`06YT86QL(&1A9V5R<R!F;W)V87)S96P@*';F<B!O8G,@<.4@
M870@9&5T(')E='5R;F5R=&4@9F]R=F%R<VQE="!I;FYE:&]L9&5R(&+E9&4@
M9&%G(&]G(&YA='0[(&5N('-T;W(@=F5R9&D@:&5R(&MA;B!R97-U;'1E<F4@
M:2!E;B!S=&]R(&)L;VMK*0!';&5M="!P87-S;W)D970_`%-K:F5M865R`%-K
M:F5B;F4O;'EK:V4`5'EP92!S:VIE8FYE+VQY:VME`%-K:F5B;F5R+VQY:VME
M`%-K:F5B;F5R+VQY:VME(#(`1F]R=6UE<@!6:61E<F5S96YD=&4`1F%N="!P
M<F]G<F%M;65N93H@)7,`1F%N="!K871A;&]G96YE.@!&<@!286UM97(`3&5D
M:6<O;W!P=&%T="UI;F9O<FUA<VIO;@!,961I9R]O<'!T871T('-V87(`3&5D
M:6<O;W!P=&%T="!F;W)E<W#X<G-E;`!3=F%R('#E(&QE9&EG+V]P<'1A='0@
M9F]R97-P^')S96P`1G)A`$9R82``1G5L;"!B97-K<FEV96QS90!&=6QL;>5N
M90!&=6QL="!N879N`$=A;&QE<FD@9'4@^&YS:V5R(.4@:&5N=&4@8FEL9&4@
M9G)A`$=A;&QE<FDZ`$=E;F5R97(@)7,@:V]N9FEG=7)A<VIO;@!'96YE<F5R
M="!K;V1E`$=E=&]P="!&96EL.B``1VET="!.879N`$=O`%/X:R!PY2!';V]G
M;&4`1W+E=&]N90!(96QL87,`1W+X;FQA;F0`1W)U<'!E(&%D;6EN:7-T<F%S
M:F]N`$=R=7!P96YA=FX@:V%N(&EK:V4@=N9R92!T;VUM90!'<G5P<&5R971T
M:6=H971E<@!'<G5P<&5R`%)E='1I9VAE=&5R(&9O<B!G:F5S=`!2971T:6=H
M971E<B!F;W(@9VIE<W0`1VIE<W1E8F]K`$A(`$A434P`2%1-3$%R96$@;F5K
M=&5R(.4@<VQE='1E(&1E;B!S:7-T92!C96QL96X@:2!E;B!R860N`$A434Q!
M<F5A(&YE:W1E<B#E('-L971T92!D96X@<VES=&4@:V]L;VYN96X@:2!T86)E
M;&QE;BX`2%1-3$%R96$@;F5K=&5R(.4@<VQE='1E(&1E;B!S:7-T92!R861E
M;B!I('1A8F5L;&5N+@!(5%10(&%U=&5N=&ES97)I;F<@:6MK92!F=6YN970N
M`$AA<V@M86QG;W)I=&UE`$1I<P!(;V1E`$CX>61E`$AJ96QP`$AJ96QP('1I
M;"!B<G5K(&%V(&5D:71O<@!(:F5L<&5R`$AA;'9K=6QE`$AE<B!E<B!B96=Y
M;FYE;'-E;B!PY2!F:6QE;CH`2/AY`$AI<W1O<FEE;W!P9OAR:6YG97(@<.4@
M:&$@;F%V;B!S;VT@:6MK92!E<B!T;VUM90!(:F5?;0!(:F5M`$AJ96UM96%D
M<F5S<V4`5&5L969O;B!H:F5M;64`2&]R9&4`2&]R9&4O2V]L86(Z(%5G>6QD
M:6<@)7,@6$U,(&1A=&$@9G5N;F5T(&D@;65L9&EN9R`E<P!(;W)D92]+;VQA
M8CH@26YG96X@;65L9&EN9R!P87-S97(@;65D(&]B:F5K=&5T("5S`$AO<F1E
M+TMO;&%B.B!);G1E="!O8FIE:W0@878@='EP96X@)7,@9G5N;F5T(&D@;65L
M9&EN9R`E<P!(;W)D92]+;VQA8CH@1FIE<FYE="`E<R`B)7,B`$AO<F1E+TMO
M;&%B.B!3>6YK<F]N:7-E<G1E("5S("(E<R(`2&]R9&4O2V]L86(Z($EN=&5G
M<F%S:F]N<VUO=&]R96X@:W)E=F5R(%!(4"`G9&]M>&UL)R!U='9I9&5L<V4`
M2&]R9&4O2V]L86(Z($MU;FYE(&EK:V4@;W!P<F5T=&4@;GET="!834P@=')E
M(&9O<B!O8FIE:W1E="`E<P!(;W)D92]+;VQA8CH@2W5N;F4@:6MK92!F:F5R
M;F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($MU;FYE(&EK:V4@:&5N=&4@
M34E-12!)1"!F;W(@9&5L96X@878@='EP92`E<P!(;W)D92]+;VQA8CH@2W5N
M;F4@:6MK92!S>6YK<F]N:7-E<F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z
M($MU;FYE(&EK:V4@<WEN:W)O;FES97)E(&1E;'1E(')E<W-U<G-E<CH@)7,`
M2&]R9&4O2V]L86(Z(%5K:F5N="!D96QT(')E<W-U<G,@(B5S(@!(;W)I<V]N
M=&%L(&QI;FIE`$AO<FES;VYT86P@<&%D9&EN9P!(;W)I<V]N=&%L.@!(=F]R
M9&%N(&MO;2!D=2!H:70_("A696YN;&EG<W0@<F%P<&]R=&5R(2D`2'9O<B!M
M86YG92!K;VQO;FYE<B#X;G-K97(@9'4@Y2!S;.4@<V%M;65N/P!(=F]R(&UA
M;F=E(&9E;'1E<B`H:V]L;VYN97(I(&5R(&1E=#\`2'9O<B!M86YG92!R861E
M<B#X;G-K97(@9'4@Y2!S;.4@<V%M;65N/P!&=6MT:6=H970`1G5K=&EG:&5T
M.B``2'5M;W)I<W1E<@!/<'!R971T96QS92!A=B!)34%0('!O<W1B;VMS(&9E
M:6QE=#H@)7,`4VQE='1I;F<@878@24U!4"!P;W-T8F]K<V5N(&9E:6QE=#H@
M)7,`3W!P<F5T=&5L<V4@878@:W9O=&4@<.4@24U!4"!P;W-T8F]K<R!F96EL
M970Z("5S`$E0($%D<F5S<V4`25`@061R97-S92!I:VME('1I;&=J96YG96QI
M9RX`25`@061R97-S92!I:VME(&EN;F5N9F]R('1I;&%T=&4@0TE$4B!B;&]K
M:RX`0G)U9&0@<.4@25`@;&]C:V1O=VXN`%-?971T(&EN;B!N>2!R860@9OAR
M`$MU;B!I:V]N97(`26MO;F5R(&9O<B`E<P!):V]N97(@;65D('1E:W-T`$ED
M96YT:71E=&5N<R!N879N.@!(=FES(&1E;B!I:VME('9I<V5S(')I:W1I9RP@
M)7,@9F]R(.4@Y7!N92!I(&YY='0@=FEN9'4N`$AV:7,@9'4@:6MK92!S97(@
M;F]E;B!I:V]N97(@;N5R(&1U(&)E;GET=&5R($EN=&5R;F5T($5X<&QO<F5R
M+"!K86X@9&5T(&AE;F1E(&1U('1R96YG97(@Y2!K<GES<V4@878@9&5N;F4@
M8F]K<V5N(&9O<B#E('-K<G4@878@=')A;G-P87)E;G0@4$Y'+@!(=FES(&1U
M('-E<B!D96YN92!M96QD:6YG96X@;65N(&EN=&5T(&)I;&1E+"!K86X@9&5T
M(&AE;F1E(&%T(&)I;&1E="!D=2!V:6P@;&%S=&4@;W!P(&EK:V4@:V%N('9I
M<V5S(&D@9&EN(&YE='1L97-E<BX`1F]R:.5N9'-V:7-N:6YG(&%V(&)I;&1E
M.@!":6QD96%D<F5S<V4`0FEL9&5A9')E<W-E.@!":6QD92!F<F$@9V%L;&5R
M:0!":6QD92!F<F$@9V%L;&5R:3H`3W!P;&%S=&EN9R!A=B!B:6QD90!":6QD
M97(`26UP;W)T97)I;F<L('-T96<@)60`26UP;W)T97)T92!F96QT.B`E<P!)
M;7!O<G1E<G1E(&9E;'0Z`%5N9&5R(&%R8F5I9`!?4V5T="!I;FX@<F%D(&5T
M=&5R`$9E:6P@:&%N9&QI;F=S:V]D92!G:71T+@!59WEL9&EG(&)R=6ME<FYA
M=FX@;V<O96QL97(@<&%S<V]R9"X`1F5I;"!B<G5K97)N879N(&5L;&5R(&%L
M=&5R;F%T:78@861R97-S92X@5F5N;FQI9W-T(&9O<G/X:R!I9VIE;B!E;&QE
M<B!K;VYT86MT('-Y<W1E;6%D;6EN:7-T<F%T;W)E;B!D:6X@9F]R('ET=&5R
M;&EG97)E<F4@:&IE;'`N`-AK(&EN;G)Y:VL`26YD:79I9'5E;&QE(&)R=6ME
M<F4`26YF;P!);F9O<FUA<VIO;@!3971T(&EN;B!K7V]L;VYN92!E='1E<@!3
M971T(&EN;B!B:6QD90!3971T(&EN;B!T86)E;&P`4V5T="!I;FX@=V5B;&EN
M:P!3971T(&EN;B!?:V]L;VYN92!F^'(`4V5T="!I;FX@96X@;GD@:V]L;VYN
M92!E='1E<B!D96X@9VIE;&1E;F1E`%-E='0@:6YN(&5N(&YY(&MO;&]N;F4@
M9OAR(&1E;B!G:F5L9&5N9&4`4V5T="!I;FX@96X@;GD@<F%D(&5T=&5R(&1E
M;B!G:F5L9&5N9&4`4V5T="!I;FX@96X@;GD@<F%D(&;X<B!D96X@9VIE;&1E
M;F1E`%-E='0@:6YN(&QI;FIE<VMI9G0@971T97(@9&5N(&=J96QD96YD92!N
M;V1E;@!3971T(&EN;B!L:6YJ97-K:69T(&;X<B!D96X@9VIE;&1E;F1E(&YO
M9&5N`%-E='0@:6YN(&%L=&5R;F%T:78@;6%L`%-E='0@:6YN(&5N(&4M<&]S
M="!A9')E<W-E(&1U(/AN<VME<B#E(&UO='1A(&1E="!N>64@<&%S<V]R9&5T
M('#E.@!3971T(&EN;B!C96QL92!E='1E<@!3971T(&EN;B!C96QL92!E='1E
M<@!3971T(&EN;B!K;VQO;FYE(&5T=&5R`%-E='0@:6YN(&MO;&]N;F4@9OAR
M`%-E='0@:6YN(&UE;&1I;F=E<@!3971T(&EN;B!L:6YJ97-K:69T(&5T=&5R
M`%-E='0@:6YN(&QI;FIE<VMI9G0@9OAR`%-E='0@:6YN(')A9"!E='1E<@!3
M971T(&EN;B!R860@9OAR`%-E='0@:6YN(&1E="!PY6MR979D92!S=F%R970@
M=&EL(&;X;&=E;F1E('-I:VME<FAE='-S</AR<VWE;#H`4V5T="!I;FXO<F5D
M:6=E<F4@8FEL9&4`4V5T="!I;FXO<F5D:6=E<F4@;&EN:P!):VME(&YO:R!K
M<F5D:71T(&9O<B#E(&MU;FYE('-E;F1E('1I;"!D:7-T<FEB=7-J;VYS;&ES
M=&5N+@!):VME(&YO:R!K<F5D:71T+@!);G1E9V5R`%5G>6QD:6<@:&%N9&QI
M;F<@=F%L9W0@9F]R(&1E;FYE(&MO;7!O;F5N=&5N+@!59WEL9&EG(%5$2"X@
M*%5S97(@1&%T82!(96%D97(I+@!59WEL9&EG('!R;V=R86TN`%5G>6QD:6<@
M8F%T8V@@240`56=Y;&1I9R!D871A('-E;F1T+@!59WEL9&EG(&UO='1A:V5R
M(&%D<F5S<V4N`%5G>6QD:6<@9FEL9F]R;6%T`%5G>6QD:6<@;65L9&EN9W-T
M>7!E`%5G>6QD:6<@96QL97(@;6%N9VQE;F1E(&%P:5]I9"X`56=Y;&1I9R!E
M;&QE<B!M86YG;&5N9&4@<&%R86UE=&5R92X`56=Y;&1I9V4@<F5T=&EG:&5T
M97(N`%5G>6QD:6<@<')O=&]K;VQL+@!59WEL9&EG(&UO='1A:V5R.B`G)7,G
M`%5G>6QD:6<@9&5L="!O8FIE:W0`56=Y;&1I9R!K:6QD96%D<F5S<V4`56=Y
M;&1I9R!U;FEC;V1E(&1A=&$N`$EN;FAO;&0`27-O;&5R=&4@=&]R9&5N+7-T
M;W)M97(`571G:79E<@!+=7)S:78`2F%N=6%R`$IU;&D`2G5N:0!*=7-T97(`
M36ED='-T:6QL`$)E:&]L9&4@;W)G:6YA;#\`2V5R8F5R;W,@=&IE;F5R96X@
M879V:7-T92!A=71E;G1I<V5R:6YG96XN`$ME<FYE;"!.>6)E9WEN;F5R90!.
M^&MK96QG96YE<F5R:6YG`$[X:VME;"!F:6YG97)P<FEN=`!.^&MK96P@;&5N
M9V1E`$[X:VME;"!T>7!E`$[X:VME;&)R=6L`3OAK:V5L(&5K<VES=&5R97(@
M86QL97)E9&4@<.4@9&5N(&]F9F5N=&QI9V4@;OAK:V5L=&IE;F5R96XN`$)A
M<FX`571?<V5E;F1E`%-P<N5K`%-I<W1E(&AA;'1I;64`4VES=&4@:W9A<G1E
M<@!3:7-T92!O<'!D871E<FEN9SH`4VES=&4@:6YN;&]G9VEN9SH@)7,`4VES
M=&4@:6YN;&]G9VEN9SH@)7,@9G)A("5S`%-I<W1E(&EN;FQO9V=I;F<Z($%L
M9')I`$QO=@!5='-E96YD90#8;G-K97,@:6YG96X@<F%M;65R(&QA<B!D=2!F
M96QT970@=N9R92!T;VUT`%9E;G-T<F4`5F5N<W1R92!H;V1E`%9E;G-T<F4@
M=F5R9&EE<@!,971T(&1U<VMR96=N`$QE='0@<F5G;@!,971T(&9O<FUI9&1A
M9W-R96=N`$QE='0@971T97)M:61D86=S<F5G;@!,971T92!R96=N8GEG97(`
M3&5T="!R96=N(&UE9"!T;W)D96X`3&5T="!S;OAF86QL`$QE='1E('-N^&)Y
M9V5R`$QI;65R:6-K`$QI;FL`3&EN:R!P96ME<B!T:6PZ`$QI;FL@92UP;W-T
M(&%D<F5S<V5N('1I;"`G<VMR:78@;GDG+7-I9&4@=F5D('9I<VYI;F<`3&EN
M:V5R`$QI;G5X($-O;VMI90!,:7-T("T@8G)U:V5R96X@:V%N('-E(&UA<'!E
M;@!,:7-T(&1A=&%B87-E<@!%;6YE<B!I($AJ96QP`$QI<W0@=&%B96QL97(`
M3&ES=&4M87)K:78`3&ES=&5H:F5L<`!,:7-T92U)9`!%:65R(&%V(&QI<W1E
M`$QI<W1E+7!O<W0`06)B;VYE<B!PY2!L:7-T90!3=&]P<"!A8F)O;FYE;65N
M="!PY2!L:7-T90!-=6QI9VAE="!F;W(@Y2!L:7-T92!B<G5K97)E(&5R(&1E
M86MT:79E<G0N`$QI='1E<F%T=7(`3&%S=&5R(&)I8FQI;W1E:V5R+BXN`$QA
M<W1E<BXN+@!,;VMA;"!T:60Z`%-P<N5K(&]G('1I9`!,;VMA<VIO;@!,;V=G
M(&EN;@!,;V=G('5T`$EN;FQO9V=I;F=S;W!P9V%V97(`3&]G:6X@9F5I;&5T
M(&9O<F1I(&)R=6ME<FYA=FYE="!E;&QE<B!P87-S;W)D970@9'4@<VMR978@
M:6YN('9A<B!F96EL+@!,;V=I;B!F96EL970N`$QA;F<@=&5K<W0`2VKF<FQI
M9VAE=`!,878`4VWE(&=R97-K92!B;VMS=&%V97(`4VWE(&QA=&EN<VME(&)O
M:W-T879E<@!-30!);FYB;VMS`%-A;7-V87)E;F1E(&9E;'0`3?AT96%V;'ES
M;FEN9P!-^'1E:6YF;W)M87-J;VX`3?AT96EN;FMA;&QE;'-E`$WX=&5S=F%R
M`$WX=&5O<'!D871E<FEN9P!&;W)E<_AR<V5L(&]M(&WX=&5O<'!D871E<FEN
M9P!-96YY;6]D=7,Z`$UE;&1I;F<`3>5N961T;&EG`&9L>71T(&YE9`!F;'ET
M="!O<'``3F%V;@!4<F5N9V5R(&AA;F1L:6YG`$%L9')I`$YY:&5T97(`3F5S
M=&4`3F5S=&4@<VED90!.96D`26MK92!D96QT86=E<@!);F=E;@!.;W1A=&5R
M`$]B<R$`3TL`2V]N=&]R`%9A;&=F<FD@9&5L=&%G97(`5F%L9P!/<F=A;FES
M97)I;F<`06YN96X@:6YF;W)M87-J;VX`4&%S<V]R9`!5=&;X<B!V961L:6ME
M:&]L9'-O<&5R87-J;VYE<@!5=&;X<B!V961L:6ME:&]L9'-O<&5R87-J;VYE
M<B!V960@:6YN;&]G9VEN9S\`4&5R<V]N;&EG(&EN9F]R;6%S:F]N`%1E;&5F
M;VX`5F5N;FQI9W-T(&=I(&5T('-A;6UE;F1R86<@878@<')O8FQE;65T+@!6
M96YN;&ES="!S:W)I=B!I;FX@8G)U:V5R;F%V;B!O9R!P87-S;W)D`%9E;FYL
M:6=S="!S92!O=F5R(&1E;B!F^&QG96YD92!I;F9O<FUA<VIO;F5N+"!V96QG
M('/E(&5N(&AA;F1L:6YG(&9R82!M96YY96X@;F5D96YU;F1E<BX`5F5N;FQI
M9W-T('9E;&<@96X@:&%N9&QI;F<@9G)A(&UE;GEE;B!N961E;G5N9&5R+@!&
M;W)HY6YD<W9I<VYI;F<`1F]R<FEG92!S:61E`%!R;V)L96UB97-K<FEV96QS
M90!(=7-K(&QE9&EG+V]P<'1A='0M:6YF;W)M87-J;VXN`$9J97)N('!A<@!3
M=F%R('-E;F1T+@!3=F%R(&%T(&UE;&1I;F=E;B!I:VME('-T^'1T97,`4W9A
M<B!M960@;&5D:6<O;W!P=&%T="!F;W(@9&4@;F5S=&4@=&\@;>5N961E;F4N
M`%-V87(@;65D(&1E;B!F;W)E<W!U<G1E(&QE9&EG+V]P<'1A='0M:6YF;W)M
M87-J;VYE;BX`3V)L:6=A=&]R:7-K(&1E;'1A9V5R`$YU;&QS=&EL;`!4:6QB
M86ME('1I;"!686QG`%)O;&QE`$QA9W)E('-O;0!,86=R92!686QG`%/X:P!6
M96QG(&5N(&1A=&\`5F5L9R!D871O<VMI;&QE=&5G;CH`5F5L9R!D871O9F]R
M;6%T`%9E;&<@=&ED<V9O<FUA=#H`5F5L9R!T;R!S86US=F%R96YD92!F96QT
M+@!696QG(/AN<VME="!S<'+E:SH`4V5N9"!S:7-T92!I;F9O<FUA<VIO;@!3
M96YD('!R;V)L96UR87!P;W)T`%)E9VES=')E<B!D96<@;VT@:6MK92!R96=I
M<W1R97)T`%-T^')R96QS90!(;W!P(&]V97(@=F5D;&EK96AO;&0`4W!E<VEA
M;'1E9VYI;FYT87-T:6YG`%-T87)T`%-T871U<P!%;6YE`%-E;F0`4W5K<V5S
M<P!386UM96YD<F%G`$]P<&=A=F5R`$=O9'1A(&9O<F5S</AR<V5L(&9O<F5L
M^'!I9P!';V1T82!F;W)E;/AP:6<`2W5N('1E:W-T`$MA;&5N9&5R9&%T82!E
M<B!U9WEL9&EG`$AA;F1L:6YG96X@:&%R(&)L:71T(&QA9W0@=&EL(&1I;B!L
M:7-T92!O=F5R(&AA;F1L:6YG97(N`$)R=6ME<F5N<R!L961I9R]O<'!T871T
M(&EN9F]R;6%S:F]N(&)L92!L86=R970N`$1E="!O<'!S=&]D(&5N(&9E:6P@
M=6YD97(@9F]R<_AK('#E(.4@=FES92!D96YN92!M96QD:6YG<V1E;&5N`$1E
M="!O<'!S=&]D(&5N(&9E:6P@=6YD97(@:6UP;W)T97)I;F<@878@:&5N9&5L
M<V5N.B`E<RX`1&5T(&]P<'-T;V0@96X@9F5I;"!V960@:6UP;W)T97)I;F<@
M878@:&5N9&5L<V5N.B`E<RX`1&5T(&]P<'-T;V0@96X@9F5I;"!V960@:6UP
M;W)T97)I;F<@878@8G)U:V5R96YS(&QE9&EG+V]P<'1A='0M:6YF;W)M87-J
M;VXZ("5S`$1E;B!F;W)E<W!U<G1E(&]P<&=A=F5N(&5R(&EK:V4@<W1O='1E
M="X`1&5N(&9O<F5S<'5R=&4@;W!P9V%V96X@97(@:6MK92!I;7!L96UE;G1E
M<G0N`$1E='1E('1A;&QE="!MY2!VYG)E(&UI;G-T(#$N`$1E='1E(&WE(';F
M<F4@970@=&%L;"X`5&ET=&5L`%1I;`!54DP`2V%N(&EK:V4@:V]B;&4@=&EL
M(%-13'-E<G9E<F5N+@!+86X@:6MK92!O=F5R<V5T=&4@9&5T=&4@5V]R9"UD
M;VMU;65N=&5T`$%N9W)E(&5N9')I;F=E<@!5:.5N9'1E<G0@:V]M<&]N96YT
M(&%V('1Y<&5N.B`E<P!5=&5N(&YA=FX`3W!P9&%T97(@<W1A='5S('#E(&%V
M<V5N9&5R90!,87-T(&]P<`!,86=R92!686QG`$)R=6ME<FYA=FX`0G)U:V5R
M;F%V;CH`5FES("5S`%9I<R!H96YD96QS90!6:7,@:&%N9&QI;F=E<@!!9'9A
M<G-E;`!5:V5N=&QI9P!696QK;VUM96X@=&EL("5S`%9E;&MO;6UE;BP@)7,`
M1FER;6%A9')E<W-E`$9I<FUA=&5L969O;@#EY0#E<FQI9P!*80!$=2!MY2!B
M97-K<FEV92!P<F]B;&5M970@9OAR(&1U(&MA;B!S96YD92!E;B!P<F]B;&5M
M<F%P<&]R="X`1&EN("5S('1I;&MO8FEN9R!H87(@9^5T="!U="X@5F5N;FQI
M9W-T(&QO9R!I;FX@:6=J96XN`$1I;B!I;F9O<FUA<VIO;@!&=6QL="!N879N
M`$YE='1L97-E<F5N(&1I;B!S=/AT=&5R(&EK:V4@9&5N;F4@=71S:VEF='-O
M<&5R87-J;VYE;BX@5')Y:VL@2V]N=')O;&PO3W!S:F]N("L@4"!F;W(@Y2!S
M:W)I=F4@=70N`$1I;F4@=F%L9R!H87(@8FQI='0@;W!P9&%T97)T`%M0<F]B
M;&5M<F%P<&]R=%T`6VQI;FIE("5S(&%V("5S70!(:F5L<`!,;V=G('5T`%9A
M;&<`;F%V;@!V0V%R9```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]N;%].3"\`````````````
M````````````````````````````````````````````````````````````
M````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U
M,34T,S,W-3,`,#(P,3$W`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE
M+VYL7TY,+VAE;'`N>&UL````````````````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,S,R,``Q,#4Q-30S,S<U,P`P,C$U-C<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]X;6P@=F5R<VEO;CTB
M,2XP(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O;FQ?3DPO:&5L<"YX
M;6PL=B`Q+C(@,C`P-"\P-2\R-R`R,#HR,CHQ-"!J86X@17AP("0@+2T^"CQH
M96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4](FYE=R(^"CQT:71L
M93Y4:&4@4&]R=&%L(%!A9V4\+W1I=&QE/@H@/'!A<F$^"B`@5&AI<R!P;W)T
M86P@<&%G92!P<F]V:61E<R!A('%U:6-K('-U;6UA<GD@;V8@86QL('EO=7(@
M:6UP;W)T86YT"B`@:6YF;W)M871I;VXN($9O<B!E>&%M<&QE+"!I="!M:6=H
M="!S:&]W(&AO=R!M86YY(&YE=R!E+6UA:6P@;65S<V%G97,@>6]U"B`@:&%V
M92!I;B!Y;W5R($E.0D]8+"!U<&-O;6EN9R!E=F5N=',@;VX@>6]U<B!C86QE
M;F1A<BP@=&%S:W,@;VX@>6]U<B!T;RUD;PH@(&QI<W0L(&AE861L:6YE<R!F
M<F]M('-E;&5C=&5D(&YE=W,@<V5R=FEC97,L(&%N9"!S;R!O;BX@($UA;GD@
M;V8@=&AE<V4*("!S=6UM87)I97,@=VEL;"!C;VYT86EN('%U:6-K('-H;W)T
M8W5T<R!T;R!C;VUM;VX@9G5N8W1I;VYS+"!S=6-H(&%S"B`@8V]M<&]S:6YG
M(&$@;F5W(&UA:6P@;65S<V%G92P@8W)E871I;F<@82!N97<@8V%L96YD87(@
M979E;G0@;W(@=&%S:RP@971C+@H@/"]P87)A/@H@/'!A<F$^"B`@5&AE(&-O
M;G1E;G1S(&]F('1H:7,@<&]R=&%L('!A9V4@87)E(&-U<W1O;6EZ86)L92!V
M:6$@=&AE($QA>6]U="!B=71T;VXN"B`@1F]R(&5X86UP;&4L('EO=2!C86X@
M8VAO;W-E('=H:6-H(&ET96US('1O(&EN8VQU9&4@;VX@=&AI<R!P;W)T86P@
M<&%G92!A<PH@('=E;&P@87,@:6X@=VAI8V@@;W)D97(@=&AE>2!A<F4@<VAO
M=VXN"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B('-T
M871E/2)N97<B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG871I;VX@
M0F%R/"]T:71L93X*(#QP87)A/@H@($%T('1H92!L969T(&AA;F0@<VED92!O
M9B!T:&4@=V5B('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N(&YA=FEG871I;VX@
M8F%R+@H@($-L:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES(&YA=FEG871I;VX@
M8F%R('1O('%U:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*("!B971W965N('1H
M92!A=F%I;&%B;&4@87!P;&EC871I;VYS+@H@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@1&\@36%I
M;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@
M;&EK92!T;R!P97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G
M:6XL(&-H96-K('1H:7,@8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC92(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!#;VYF
M:7)M($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U
M('=O=6QD(&QI:V4@=&\@8V]N9FER;2!A;&P@;6%I;G1E;F%N8V4@=&%S:W,@
M8F5F;W)E('1H97D@87)E(')U;BP@8VAE8VL@=&AI<R!B;W@N($EF(&QE9G0@
M=6YC:&5C:V5D+"!A;&P@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!T:&%T(&YE
M960@=&\@8F4@<G5N('=I;&P@8F4@<&5R9F]R;65D(&%U=&]M871I8V%L;'D@
M=VET:"!N;R!C:&%N8V4@=&\@8V%N8V5L(&]N(&QO9VEN+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H\+VAE;'`^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]N;%].
M3"],0U]-15-304=%4R\`````````````````````````````````````````
M````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`U,34T,S,W-3,`,#(Q-S`T`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&]C86QE+VYL7TY,+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#0Q-3`P-P`Q,#4Q-30S,S<U,P`P,C,S-3$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````WA($
ME0````")!P``'````&0\```3"@``K'@```````#XH```#@```/F@```/````
M"*$```T````8H0``"````":A```+````+Z$```P````[H0``!````$BA```8
M````3:$``!L```!FH0``+0```(*A```=````L*$``"0```#.H0``*0```/.A
M```9````':(``"8````WH@``#````%ZB```D````:Z(```\```"0H@``"P``
M`*"B```.````K*(```4```"[H@``*````,&B```(````ZJ(```H```#SH@``
M%0```/ZB```2````%*,```L````GHP``A0```#.C```.````N:,```H```#(
MHP``#0```-.C```.````X:,``!$```#PHP``#0````*D```,````$*0```T`
M```=I```!@```"ND``"4````,J0```H```#'I```#P```-*D```8````XJ0`
M``P```#[I```#@````BE```.````%Z4```@````FI0``"0```"^E```N````
M.:4``!H```!HI0``,@```(.E```X````MJ4``%0```#OI0``40```$2F``!:
M````EJ8``%<```#QI@``-````$FG```)````?J<```T```"(IP``!P```):G
M```*````GJ<```\```"IIP``!0```+FG```&````OZ<``!$```#&IP``"```
M`-BG```)````X:<```D```#KIP``)0```/6G```@````&Z@``!,````\J```
M$````%"H```/````8:@```H```!QJ````P```'RH```/````@*@``!0```"0
MJ```"0```*6H```-````KZ@``!(```"]J```&0```-"H```>````ZJ@```\`
M```)J0``"@```!FI```/````)*D```@````TJ0``)````#VI```4````8JD`
M`!8```!WJ0``"````(ZI``!.````EZD``"T```#FJ0``&0```!2J```'````
M+JH```P````VJ@``+````$.J```.````<*H```,```!_J@``"P```(.J```'
M````CZH```<```"7J@``!0```)^J```%````I:H```H```"KJ@```P```+:J
M```7````NJH```H```#2J@``#P```-VJ```.````[:H``!@```#\J@``(P``
M`!6K```.````.:L``!0```!(JP``%P```%VK```7````=:L``!<```"-JP``
M$P```*6K```/````N:L```X```#)JP``'P```-BK```=````^*L```<````6
MK```!@```!ZL```(````):P```\````NK```!@```#ZL```*````1:P``!,`
M``!0K```"P```&2L```0````<*P``!4```"!K```%0```)>L```'````K:P`
M`!````"UK```!0```,:L```5````S*P``!$```#BK```#````/2L```[````
M`:T``#@````]K0``"0```':M```'````@*T``!0```"(K0```P```)VM```%
M````H:T``!````"GK0``"0```+BM```3````PJT``#D```#6K0``$@```!"N
M```G````(ZX``"P```!+K@``*@```'BN```E````HZX```H```#)K@``!@``
M`-2N```)````VZX```<```#EK@``+P```.VN```W````':\``"X```!5KP``
M50```(2O```M````VJ\``"T````(L```/0```#:P```_````=+```"T```"T
ML```0````.*P```C````([$``",```!'L0``0````&NQ```M````K+$``#,`
M``#:L0``)0````ZR```5````-+(``!D```!*L@``*0```&2R```D````CK(`
M`"@```"SL@``$0```-RR```*````[K(```P```#YL@``"@````:S```0````
M$;,``!8````BLP``%@```#FS```'````4+,```<```!8LP``%````&"S```*
M````=;,```@```"`LP``)P```(FS```(````L;,```<```"ZLP``!P```,*S
M```&````RK,```4```#1LP``!P```->S```&````W[,```@```#FLP``*0``
M`.^S```.````&;0```H````HM```!````#.T```'````.+0```D```!`M```
M!@```$JT```1````4;0```<```!CM```%@```&NT```$````@K0```@```"'
MM```!@```)"T```-````E[0```8```"EM```'@```*RT```1````R[0```@`
M``#=M```#0```.:T```,````]+0```<````!M0```P````FU```#````#;4`
M`!<````1M0``$P```"FU```=````/;4```@```!;M0``!````&2U```(````
M:;4```@```!RM0``00```'NU```:````O;4``"L```#8M0``(`````2V```5
M````);8```8````[M@``!@```$*V```5````2;8``!@```!?M@``(@```'BV
M```N````F[8``!T```#*M@``(0```.BV``!4````"K<``"D```!?MP``"@``
M`(FW```'````E+<```<```"<MP``%0```*2W```.````NK<```H```#)MP``
M#P```-2W```-````Y+<```\```#RMP``#0````*X```)````$+@``!0````:
MN```!@```"^X```8````-K@``!T```!/N```$P```&VX```1````@;@``!0`
M``"3N```!````*BX```&````K;@``!0```"TN```5````,FX``!D````'KD`
M``0```"#N0``#@```(BY```%````E[D```4```"=N0``&P```*.Y```:````
MO[D``!,```#:N0``$0```.ZY```1`````+H``!P````2N@``*@```"^Z```0
M````6KH``"$```!KN@``!0```(VZ```3````D[H```L```"GN@``$@```+.Z
M```*````QKH```\```#1N@``#0```.&Z```1````[[H``!,````!NP``#```
M`!6[```&````(KL```P````INP``!@```#:[```7````/;L``!````!5NP``
M$0```&:[```(````>+L```4```"!NP``#````(>[```0````E+L```4```"E
MNP``#0```*N[```&````N;L```<```#`NP``#0```,B[```'````UKL```L`
M``#>NP``!P```.J[```'````\KL```D```#ZNP``"0````2\```*````#KP`
M`!D````9O```/0```#.\```=````<;P```P```"/O```$````)R\```%````
MK;P``"4```"SO```$@```-F\```3````[+P``"L`````O0``.P```"R]```@
M````:+T```@```")O0``-@```)*]```A````R;T``!````#KO0``"````/R]
M```,````!;X```8````2O@``!````!F^```/````'KX```X````NO@``!P``
M`#V^```*````1;X```T```!0O@``'P```%Z^```<````?KX``"$```";O@``
M'@```+V^```9````W+X``!X```#VO@``&P```!6_```A````,;\``"X```!3
MOP``)@```(*_```<````J;\``!X```#&OP``'````.6_```F`````L```"L`
M```IP```,P```%7````F````B<```"L```"PP```.````-S````=````%<$`
M`!4````SP0``+P```$G!```@````><$``!(```":P0``*0```*W!```>````
MU\$``"````#VP0``$@```!?"``"B````*L(``!8```#-P@``(P```.3"```H
M````",,``"D````QPP``*````%O#```?````A,,``!4```"DPP``(````+K#
M```E````V\,``"@````!Q```+0```"K$```P````6,0``)(```")Q```(0``
M`!S%```6````/L4``!P```!5Q0``)@```'+%```J````F<4``$$```#$Q0``
M1`````;&```,````2\8```<```!8Q@``!P```&#&```&````:,8```T```!O
MQ@``$````'W&```2````CL8``!,```"AQ@``$@```+7&```'````R,8```0`
M``#0Q@``$````-7&```0````YL8```P```#WQ@``#@````3'```-````$\<`
M``\````AQP``$P```#''```-````1<<``"@```!3QP```P```'S'```-````
M@,<```8```".QP``$0```)7'```7````I\<``!L```"_QP``#@```-O'```"
M````ZL<``$D```#MQP``!0```#?(```0````/<@```\```!.R```!````%[(
M```-````8\@```X```!QR````P```(#(```.````A,@```@```"3R```#P``
M`)S(```/````K,@```<```"\R```#0```,3(```0````TL@```T```#CR```
M"P```/'(```&````_<@```L````$R0``#````!#)```*````'<D``!$````H
MR0``&0```#K)```+````5,D```T```!@R0``(@```&[)```/````D<D``!L`
M``"AR0``-````+W)```*````\LD``!@```#]R0``$@```!;*```9````*<H`
M`!8```!#R@``(@```%K*```-````?<H```<```"+R@``%````)/*```+````
MJ,H``"(```"TR@``+P```-?*```+````!\L```D````3RP``&0```!W+```+
M````-\L``!<```!#RP``%P```%O+```)````<\L``!8```!]RP``#P```)3+
M```9````I,L``!8```"^RP``#@```-7+```8````Y,L```@```#]RP``#0``
M``;,```F````%,P``$,````[S```"````'_,```2````B,P``!\```";S```
M"````+O,```+````Q,P``"\```#0S```#@````#-```%````#\T```8````5
MS0``10```!S-```#````8LT```<```!FS0``!````&[-```*````<\T```H`
M``!^S0``#P```(G-```0````F<T``!<```"JS0``$0```,+-```9````U,T`
M`!<```#NS0``"0````;.```%````$,X```L````6S@``"@```"+.```"````
M+<X```4````PS@``#0```#;.```;````1,X``!<```!@S@``%````'C.```)
M````C<X```X```"7S@``#0```*;.```2````M,X``#@```#'S@``(`````#/
M```(````(<\```X````JSP``>P```#G/```8````M<\``!@```#.SP``$0``
M`.?/```'````^<\```4````!T```&`````?0```>````(-```!L````_T```
M&0```%O0```;````==```!D```"1T```$P```*O0```'````O]````@```#'
MT```!@```-#0```&````U]```!````#>T```#P```._0```0````_]````\`
M```0T0``"P```"#1```/````+-$```P````\T0``#P```$G1```'````6=$`
M``8```!AT0``#@```&C1```,````=]$``"@```"$T0``#P```*W1```(````
MO=$```@```#&T0``$P```,_1```>````X]$``"$````"T@``(````"32```9
M````1=(``!<```!?T@``)0```'?2```7````G=(``!8```"UT@``!````,S2
M```;````T=(```T```#MT@``#````/O2```#````"-,```4````,TP``"```
M`!+3```*````&],```P````FTP``"P```#/3```0````/],```P```!0TP``
M#@```%W3```+````;-,```0```!XTP``!````'W3```3````@M,``!0```"6
MTP``#````*O3```)````N-,```X```#"TP``"P```-'3```;````W=,```<`
M``#YTP``!P````'4```*````"=0```T````4U```"0```"+4```$````+-0`
M``4````QU````P```#?4```8````.]0```H```!4U```!````%_4```F````
M9-0```X```"+U```?````)K4```5````%]4```4````MU0``!P```#/5```,
M````.]4```@```!(U0``"@```%'5```&````7-4```@```!CU0```@```&S5
M```&````;]4```8```!VU0``%````'W5```-````DM4``!````"@U0``&P``
M`+'5```$````S=4```D```#2U0``$````-S5```)````[=4```D```#WU0``
M!0````'6```:````!]8```@````BU@``!@```"O6```9````,M8```X```!,
MU@``!P```%O6```'````8]8```4```!KU@``"0```''6```*````>]8```X`
M``"&U@```@```)76```&````F-8```L```"?U@``#0```*O6```)````N=8`
M``8```##U@``$@```,K6```)````W=8```<```#GU@``%````._6```=````
M!-<``$(````BUP``)0```&77```E````B]<```8```"QUP``"@```+C7```$
M````P]<```D```#(UP``"````-+7```1````V]<```D```#MUP``!@```/?7
M```-````_M<```8````,V```!````!/8```Y````&-@``#T```!2V```.@``
M`)#8```>````R]@```4```#JV```#@```/#8```$````_]@```8````$V0``
M!P````O9```A````$]D```T````UV0``%0```$/9```&````6=D```0```!@
MV0``$0```&79```&````=]D```H```!^V0``(@```(G9```$````K-D```4`
M``"QV0``'0```+?9```$````U=D```P```#:V0``#@```.?9```*````]MD`
M``@````!V@``"0````K:```%````%-H``#H````:V@``,````%7:```U````
MAMH``"D```"\V@``1P```.;:```X````+ML``"D```!GVP``/P```)';```N
M````T=L``"T`````W```'P```"[<```/````3MP``!(```!>W```"P```''<
M```F````?=P``"D```"DW```)````,[<```F````\]P```@````:W0``"@``
M`"/=```)````+MT```<````XW0``(````$#=```@````8=T``"8```""W0``
M"@```*G=```9````M-T``"D```#.W0``%@```/C=```2````#]X```<````B
MW@``"@```"K>```,````-=X```\```!"W@``$````%+>``!`````8]X``'``
M``"DW@``9@```!7?```.````?-\```D```"+WP``"@```)7?```2````H-\`
M`!,```"SWP``#````,??```&````U-\```\```#;WP``$@```.O?```0````
M_M\``!$````/X```'````"'@```C````/N```&H```!BX```#P```,W@```%
M````W>```!````#CX```"0```/3@```$````_N````L````#X0``(`````_A
M```4````,.$```P```!%X0``#````%+A```/````7^$``!4```!OX0``*0``
M`(7A```J````K^$``"8```#:X0``)P````'B```I````*>(``"H```!3X@``
M&0```'[B``!"````F.(``!$```#;X@``$@```.WB```3`````.,``!0````4
MXP``#P```"GC```6````.>,``!<```!0XP``$````&CC```1````>>,``#0`
M``"+XP``$P```,#C```2````U.,``#4```#GXP``%````!WD```'````,N0`
M``P````ZY```(````$?D```0````:.0``!0```!YY```$0```([D```7````
MH.0``!P```"XY```$P```-7D```4````Z>0``!H```#^Y```$0```!GE```:
M````*^4``!X```!&Y0``&@```&7E```3````@.4``!4```"4Y0``$0```*KE
M```7````O.4``!0```#4Y0``%P```.GE```5`````>8```D````7Y@``$```
M`"'F```9````,N8```0```!,Y@``!P```%'F```+````6>8``!$```!EY@``
M!@```'?F```&````?N8```8```"%Y@``!0```(SF```'````DN8```<```":
MY@``!0```*+F```6````J.8```8```"_Y@``!@```,;F```$````S>8```0`
M``#2Y@``!P```-?F```.````W^8```P```#NY@``#````/OF```-````".<`
M``H````6YP``#@```"'G```%````,.<``"@````VYP``#@```%_G```,````
M;N<```\```![YP``"@```(OG```(````EN<```D```"?YP``*P```*GG```$
M````U><```@```#:YP``)@```./G```2````"N@```\````=Z```!@```"WH
M```*````-.@```<````_Z```"````$?H```@````4.@```D```!QZ```%```
M`'OH```,````D.@```T```"=Z```#@```*OH```6````NN@``!$```#1Z```
M!@```./H```#````ZN@```8```#NZ```&0```/7H```'````#^D```0````7
MZ0``"P```!SI```+````*.D```<````TZ0``!0```#SI```'````0ND``!8`
M``!*Z0``#0```&'I```-````;^D```H```!]Z0``$````(CI```/````F>D`
M`!$```"IZ0``%P```+OI```*````T^D``!$```#>Z0``"````/#I```$````
M^>D```\```#^Z0``.@````[J```%````2>H```P```!/Z@``'@```%SJ```.
M````>^H``!````"*Z@``"P```)OJ```,````I^H```D```"TZ@``!P```+[J
M```*````QNH```D```#1Z@``#@```-OJ```0````ZNH``!L```#[Z@``&```
M`!?K```:````,.L```H```!+ZP``"0```%;K```*````8.L```P```!KZP``
M#P```'CK```(````B.L```8```"1ZP``'````)CK```'````M>L```4```"]
MZP``"P```,/K``!'````S^L```T````7[```"0```"7L```$````+^P```,`
M```T[```$P```#CL```3````3.P``!,```!@[```"@```'3L```"````?^P`
M``0```""[```)0```(?L```#````K>P```4```"Q[```*@```+?L```*````
MXNP```4```#M[```!````//L```*````^.P```T````#[0``!@```!'M```(
M````&.T```@````A[0``!````"KM```%````+^T``&@````U[0``"0```)[M
M```,````J.T``!````"U[0``!0```,;M```&````S.T``!L```#3[0``+P``
M`._M```0````'^X```H````P[@``#P```#ON```*````2^X```D```!6[@``
M$P```&#N```;````=.X``!@```"0[@``%P```*GN```?````P>X```X```#A
M[@```P```/#N```'````].X```@```#\[@``!P````7O```*````#>\```L`
M```8[P``!P```"3O``!1````+.\``!````!^[P``#````(_O```-````G.\`
M`!H```"J[P``2@```,7O```9````$/````8````J\```&@```#'P```E````
M3/````8```!R\```!@```'GP```?````@/````8```"@\```"0```*?P```8
M````L?```!<```#*\```*````.+P```&````"_$```T````2\0``(@```"#Q
M``!7````0_$``!,```";\0``(P```*_Q```3````T_$```(```#G\0``"P``
M`.KQ```(````]O$```T```#_\0``"@````WR```'````&/(``!0````@\@``
M!@```#7R```(````//(```X```!%\@``!P```%3R```*````7/(```L```!G
M\@``,@```'/R```'````IO(```P```"N\@``#0```+OR```7````R?(```P`
M``#A\@``"0```.[R```)````^/(```H````"\P``!P````WS```)````%?,`
M``<````?\P``"@```"?S```;````,O,```\```!.\P``$@```%[S```*````
M<?,``!8```!\\P``"0```)/S```0````G?,```<```"N\P``$@```+;S```$
M````R?,```<```#.\P``!0```-;S```%````W/,```L```#B\P``%````.[S
M```1`````_0``!H````5]```%@```##T```4````1_0``!<```!<]```&```
M`'3T```<````C?0``!D```"J]```!P```,3T```%````S/0```T```#2]```
M#````.#T```(````[?0``!<```#V]```"P````[U```,````&O4``!\````G
M]0``&@```$?U```3````8O4```0```!V]0``"@```'OU```$````AO4```T`
M``"+]0``#````)GU```%````IO4```D```"L]0``!0```+;U```'````O/4`
M``4```#$]0``!````,KU```"````S_4``#@```#2]0``+`````OV```2````
M./8``"D```!+]@``,@```'7V```*````J/8``"P```"S]@``+@```.#V```S
M````#_<``#,```!#]P``.````'?W```/````L/<``!@```#`]P``$````-GW
M```/````ZO<``!,```#Z]P``%0````[X```4````)/@``!(````Y^```%```
M`$SX```5````8?@``"T```!W^```+0```*7X```Q````T_@``"X````%^0``
M+P```#3Y```L````9/D``&(```"1^0``$P```/3Y```-````"/H```@````6
M^@``%P```!_Z```(````-_H```P```!`^@``*P```$WZ```A````>?H``!H`
M``";^@``"0```+;Z``!%````P/H``$$````&^P``!````$C[```3````3?L`
M`!0```!A^P``#@```';[```3````A?L``!@```"9^P``!@```++[```)````
MN?L```H```##^P``#P```,[[```0````WOL```<```#O^P``#@```/?[```%
M````!OP``!L````,_```"````"C\```&````,?P``!0````X_```$0```$W\
M```.````7_P``#@```!N_````@```*?\```&````JOP```X```"Q_```!0``
M`,#\```'````QOP```X```#._```!@```-W\```H````Y/P```P````-_0``
M'````!K]```$````-_T``"D````\_0``%P```&;]```?````?OT``%P```">
M_0``%````/O]```^````$/X``!\```!/_@``$````&_^```'````@/X```X`
M``"(_@``#````)?^```,````I/X``!,```"Q_@``"@```,7^```=````T/X`
M`!D```#N_@``!0````C_```1````#O\``!$````@_P``)````#+_```2````
M5_\``!4```!J_P``$@```(#_```.````D_\``!D```"B_P``"````+S_```)
M````Q?\```T```#/_P``!P```-W_```*````Y?\```<```#P_P``#P```/C_
M```&````"``!``L````/``$`&@```!L``0`*````-@`!``<```!!``$`"```
M`$D``0`%````4@`!`!\```!8``$`!@```'@``0`0````?P`!``@```"0``$`
M#0```)D``0`(````IP`!`!X```"P``$`$@```,\``0`L````X@`!`!H````/
M`0$`"0```"H!`0`*````-`$!`!4````_`0$`!0```%4!`0`4````6P$!``0`
M``!P`0$`$````'4!`0`&````A@$!``<```"-`0$`'@```)4!`0`H````M`$!
M``H```#=`0$`'````.@!`0`1````!0(!``L````7`@$`&@```","`0`4````
M/@(!``0```!3`@$`!````%@"`0`+````70(!``4```!I`@$`!@```&\"`0`(
M````=@(!``8```!_`@$`"@```(8"`0`;````D0(!`#0```"M`@$`-````.("
M`0`@````%P,!`"D````X`P$`(````&(#`0!!````@P,!`!H```#%`P$`*```
M`.`#`0`I````"00!`%`````S!`$`(@```(0$`0`&````IP0!``@```"N!`$`
M!0```+<$`0`(````O00!`!D```#&!`$`&0```.`$`0`J````^@0!`",````E
M!0$`&0```$D%`0`N````8P4!`#0```"2!0$`"````,<%`0`7````T`4!``H`
M``#H!0$`!P```/,%`0`A````^P4!`!`````=!@$`#@```"X&`0`+````/08!
M``<```!)!@$`$P```%$&`0`(````908!``L```!N!@$`"@```'H&`0`4````
MA08!``\```":!@$`,@```*H&`0`+````W08!``X```#I!@$`!0```/@&`0`%
M````_@8!``4````$!P$`%P````H'`0`/````(@<!``0````R!P$`"@```#<'
M`0`)````0@<!``L```!,!P$`#0```%@'`0`,````9@<!``X```!S!P$`!0``
M`(('`0`$````B`<!``T```"-!P$`,@```)L'`0!%````S@<!`!<````4"`$`
M!P```"P(`0`>````-`@!`!0```!3"`$`!0```&@(`0`4````;@@!``8```"#
M"`$`!P```(H(`0`.````D@@!`"H```"A"`$`!@```,P(`0`,````TP@!``T`
M``#@"`$`$0```.X(`0`+``````D!`#8````,"0$`"@```$,)`0`B````3@D!
M``L```!Q"0$`#P```'T)`0`R````C0D!`"4```#`"0$`,````.8)`0`Q````
M%PH!`"T```!)"@$`#@```'<*`0`%````A@H!``X```","@$`$P```)L*`0`2
M````KPH!``<```#""@$`$0```,H*`0`3````W`H!``<```#P"@$`%````/@*
M`0`8````#0L!``<````F"P$`!0```"X+`0`,````-`L!``P```!!"P$`$@``
M`$X+`0`$````80L!``<```!F"P$`"@```&X+`0`+````>0L!``P```"%"P$`
M#@```)(+`0`.````H0L!``4```"P"P$`!0```+8+`0`N````O`L!`"8```#K
M"P$`(P```!(,`0`#````-@P!`!(````Z#`$`!@```$T,`0`>````5`P!`!@`
M``!S#`$`)0```(P,`0`-````L@P!``D```#`#`$`'P```,H,`0`#````Z@P!
M``<```#N#`$`"@```/8,`0`"`````0T!``P````$#0$`%0```!$-`0`+````
M)PT!`!D````S#0$`(````$T-`0`2````;@T!``4```"!#0$`"@```(<-`0`5
M````D@T!`!(```"H#0$`#````+L-`0`$````R`T!``D```#-#0$`!P```-<-
M`0`,````WPT!`%(```#L#0$`%P```#\.`0`D````5PX!`!(```!\#@$`!P``
M`(\.`0`&````EPX!``X```">#@$`#````*T.`0`-````N@X!`!4```#(#@$`
M$@```-X.`0`/````\0X!`!0````!#P$`"@```!8/`0`;````(0\!`!`````]
M#P$`"P```$X/`0!I````6@\!`!H```#$#P$`%P```-\/`0`G````]P\!`!H`
M```?$`$`%P```#H0`0`;````4A`!`!D```!N$`$`'P```(@0`0`3````J!`!
M``@```"\$`$`!P```,40`0`(````S1`!``D```#6$`$`%0```.`0`0`-````
M]A`!`",````$$0$`#0```"@1`0`3````-A$!``@```!*$0$``P```%,1`0!&
M````5Q$!`#\```">$0$`-P```-X1`0!7````%A(!``4```!N$@$`'P```'02
M`0`O````E!(!``H```#$$@$`"````,\2`0`-````V!(!`"T```#F$@$`!```
M`!03`0!/````&1,!`"4```!I$P$`'````(\3`0`+````K!,!`!\```"X$P$`
M'0```-@3`0`E````]A,!`"`````<%`$`)````#T4`0`@````8A0!``L```"#
M%`$`!P```(\4`0`-````EQ0!``P```"E%`$`%P```+(4`0`&````RA0!`#D`
M``#1%`$`#`````L5`0`'````&!4!``D````@%0$`$P```"H5`0`)````/A4!
M``0```!(%0$`$````$T5`0`(````7A4!``@```!G%0$`!````'`5`0`+````
M=14!``P```"!%0$`$@```(X5`0`1````H14!``P```"S%0$`&@```,`5`0`/
M````VQ4!``<```#K%0$`#0```/,5`0`4`````18!``X````6%@$`#````"46
M`0`;````,A8!`"P```!.%@$`$P```'L6`0`<````CQ8!`"@```"L%@$`!@``
M`-46`0`'````W!8!`!,```#D%@$`!0```/@6`0`$````_A8!`!<````#%P$`
M"@```!L7`0`,````)A<!``D````S%P$`!@```#T7`0`)````1!<!``@```!.
M%P$`"0```%<7`0`*````81<!`!$```!L%P$`!@```'X7`0`.````A1<!``X`
M``"4%P$`#0```*,7`0`+````L1<!`!T```"]%P$`"P```-L7`0`"````YQ<!
M`!P```#J%P$`!P````<8`0`&````#Q@!`&0````6&`$`"0```'L8`0`'````
MA1@!`"8```"-&`$`.````+08`0`:````[1@!`"H````(&0$`.P```#,9`0`H
M````;QD!`#0```"8&0$`&0```,T9`0`5````YQD!``4```#]&0$`!P````,:
M`0`(````"QH!``<````4&@$`!0```!P:`0`'````(AH!``X````J&@$`"0``
M`#D:`0`&````0QH!``@```!*&@$`"P```%,:`0`'````7QH!``@```!G&@$`
M!P```'`:`0`6````>!H!``D```"/&@$`!@```)D:`0`+````H!H!`!````"L
M&@$`!@```+T:`0`<````Q!H!`!0```#A&@$`!P```/8:`0`1````_AH!``@`
M```0&P$`#@```!D;`0`(````*!L!`!`````Q&P$`"0```$(;`0`0````3!L!
M``8```!=&P$`&0```&0;`0`*````?AL!`!P```")&P$`!P```*8;`0`%````
MKAL!`!````"T&P$`%````,4;`0`+````VAL!``T```#F&P$`*````/0;`0`8
M````'1P!`!<````V'`$`!````$X<`0`)````4QP!``H```!='`$`!P```&@<
M`0`"````<!P!``X```!S'`$`"````((<`0`C````BQP!`!\```"O'`$`.```
M`,\<`0`F````"!T!`#$````O'0$`)P```&$=`0!D````B1T!`!0```#N'0$`
M50````,>`0`X````61X!`$H```"2'@$`6P```-T>`0`H````.1\!`#@```!B
M'P$`*````)L?`0`L````Q!\!`"8```#Q'P$`&P```!@@`0`^````-"`!`*D!
M``!S(`$`(P```!TB`0`7````02(!`$@```!9(@$`A0```*(B`0`P````*",!
M`"4```!9(P$`00```'\C`0!;````P2,!`$D````=)`$`,0```&<D`0`=````
MF20!`!@```"W)`$`*P```-`D`0`A````_"0!`!\````>)0$`*P```#XE`0`F
M````:B4!`"<```"1)0$`.@```+DE`0`=````]"4!`!$````2)@$`,P```"0F
M`0`E````6"8!`"<```!^)@$`(````*8F`0`?````QR8!`#````#G)@$`:0``
M`!@G`0`Q````@B<!`$$```"T)P$`,P```/8G`0`E````*B@!`#T```!0*`$`
M90```(XH`0!-````]"@!`"\```!"*0$`+@```'(I`0`P````H2D!`%0```#2
M*0$`6@```"<J`0!(````@BH!`$H```#+*@$`,@```!8K`0`O````22L!`"P`
M``!Y*P$`+0```*8K`0!Q````U"L!`&8```!&+`$`;P```*TL`0"S````'2T!
M`!<```#1+0$`)0```.DM`0`R````#RX!`"D```!"+@$`/@```&PN`0`B````
MJRX!`%(```#.+@$`)0```"$O`0`+````1R\!`+$```!3+P$`10````4P`0`A
M````2S`!`#````!M,`$`)0```)XP`0`<````Q#`!`#$```#A,`$`!P```!,Q
M`0`'````&S$!``0````C,0$`#0```"@Q`0`+````-C$!``X```!",0$`"P``
M`%$Q`0`%````73$!`!````!C,0$``@```'0Q`0!9````=S$!``4```#1,0$`
M$@```-<Q`0`$````ZC$!``<```#O,0$`"````/<Q`0`%`````#(!`#`````&
M,@$``P```#<R`0`0````.S(!``P```!,,@$`$P```%DR`0`-````;3(!``(`
M``![,@$`!P```'XR`0`&````AC(!`!0```"-,@$`#````*(R`0`8````KS(!
M``8```#(,@$`$@```,\R`0`,````XC(!``,```#O,@$`*@```/,R`0`$````
M'C,!``8````C,P$`!P```"HS`0`?````,C,!`#4```!2,P$`+@```(@S`0`O
M````MS,!`!<```#G,P$`(@```/\S`0`E````(C0!`"````!(-`$`&P```&DT
M`0`8````A30!`"0```">-`$`'P```,,T`0`:````XS0!`"$```#^-`$`(```
M`"`U`0`:````034!`#(```!<-0$`&@```(\U`0`O````JC4!`"L```#:-0$`
M'P````8V`0`C````)C8!`!\```!*-@$`&@```&HV`0`A````A38!`"4```"G
M-@$`)@```,TV`0`E````]#8!`"0````:-P$`&````#\W`0`=````6#<!`"0`
M``!V-P$`&````)LW`0`B````M#<!`"P```#7-P$`+P````0X`0`5````-#@!
M`"4```!*.`$`/````'`X`0`?````K3@!`",```#-.`$`'P```/$X`0`@````
M$3D!`!H````R.0$`&````$TY`0`F````9CD!`!X```"-.0$`*0```*PY`0`>
M````UCD!`#$```#U.0$`"0```"<Z`0`,````,3H!`!<````^.@$`+P```%8Z
M`0`D````ACH!``<```"K.@$`#P```+,Z`0`4````PSH!``X```#8.@$`#0``
M`.<Z`0`D````]3H!``4````:.P$`!P```"`[`0`B````*#L!`"4```!+.P$`
M&@```'$[`0`=````C#L!`!H```"J.P$`!P```,4[`0#'````S3L!``L```"5
M/`$`%0```*$\`0`&````MSP!``D```"^/`$`"P```,@\`0`-````U#P!`!<`
M``#B/`$`!@```/H\`0`S`````3T!`!,````U/0$`$P```$D]`0`'````73T!
M``\```!E/0$`!P```'4]`0`R````?3T!``0```"P/0$`(0```+4]`0`3````
MUST!``P```#K/0$`$0```/@]`0`R````"CX!`!8````]/@$`"````%0^`0`=
M````73X!``D```![/@$`"@```(4^`0`4````D#X!``H```"E/@$`'0```+`^
M`0`(````SCX!`!\```#7/@$`"````/<^`0`:`````#\!`"<````;/P$`!@``
M`$,_`0`5````2C\!``<```!@/P$`"````&@_`0`)````<3\!`#\```![/P$`
M!P```+L_`0`/````PS\!``X```#3/P$`$````.(_`0`)````\S\!``D```#]
M/P$`"`````=``0`3````$$`!``<````D0`$`&0```"Q``0`*````1D`!`!<`
M``!10`$`%````&E``0`*````?D`!``P```")0`$`%P```)9``0`$````KD`!
M`"H```"S0`$`#````-Y``0`1````ZT`!``<```#]0`$``@````5!`0`0````
M"$$!`!@````900$`"P```#)!`0`#````/D$!``@```!"00$`!@```$M!`0`'
M````4D$!``T```!:00$`"P```&A!`0`4````=$$!`!4```")00$`#@```)]!
M`0`O````KD$!`"````#>00$`'````/]!`0`5````'$(!``P````R0@$`,0``
M`#]"`0`%````<4(!`!(```!W0@$`/P```(I"`0`2````RD(!``H```#=0@$`
M!@```.A"`0`$````[T(!``0```#T0@$`"@```/E"`0`3````!$,!``4````8
M0P$`!@```!Y#`0`&````)4,!``@````L0P$`!````#5#`0`,````.D,!``H`
M``!'0P$`.0```%)#`0`N````C$,!`"D```"[0P$`!0```.5#`0`8````ZT,!
M`!D````$1`$`'P```!Y$`0`=````/D0!`!$```!<1`$``@```&Y$`0`$````
M<40!``H```!V1`$`!@```(%$`0`%````B$0!``,```".1`$`#````))$`0!%
M````GT0!`#(```#E1`$`&@```!A%`0`T````,T4!`"@```!H10$`4P```)%%
M`0`9````Y44!`'(```#_10$`(````')&`0`U````DT8!`"$```#)1@$`10``
M`.M&`0`P````,4<!`"@```!B1P$`*0```(M'`0`F````M4<!`"4```#<1P$`
M*`````)(`0`H````*T@!`"(```!42`$`*P```'=(`0`P````HT@!`!(```#4
M2`$`$P```.=(`0`0````^T@!`'D````,20$`"0```(9)`0"A````D$D!`',`
M```R2@$`?````*9*`0`K````(TL!`%0```!/2P$`%P```*1+`0`G````O$L!
M`!8```#D2P$`#P```/M+`0`7````"TP!`!\````C3`$`0````$-,`0`?````
MA$P!`!P```"D3`$`40```,%,`0`:````$TT!`!0````N30$`"@```$--`0`%
M````3DT!``8```!430$`"````%M-`0`%````9$T!`!(```!J30$`$````'U-
M`0`3````CDT!`!T```"B30$`#P```,!-`0`/````T$T!``0```#@30$`"0``
M`.5-`0`+````[TT!``<```#[30$`!0````-.`0`4````"4X!``<````>3@$`
M"````"9.`0`/````+TX!``@````_3@$`#````$A.`0`/````54X!``8```!E
M3@$`%````&Q.`0`&````@4X!``P```"(3@$`$0```)5.`0`(````ITX!``0`
M``"P3@$`&0```+5.`0`1````STX!``H```#A3@$`&````.Q.`0`3````!4\!
M`!P````93P$`$0```#9/`0`$````2$\!``\```!-3P$`!P```%U/`0`$````
M94\!`!D```!J3P$`!P```(1/`0`"````C$\!``(```"/3P$`$0```))/`0`)
M````I$\!``8```"N3P$`$@```+5/`0`7````R$\!``8```#@3P$`)P```.=/
M`0`"````#U`!``0````24`$`#P```!=0`0`3````)U`!``<````[4`$`!P``
M`$-0`0`1````2U`!``8```!=4`$`&````&10`0`&````?5`!`!,```"$4`$`
M$````)A0`0`2````J5`!``(```"\4`$`!@```+]0`0`,````QE`!``D```#3
M4`$`$0```-U0`0`B````[U`!``<````240$`!P```!I1`0`+````(E$!``4`
M```N40$``@```#11`0`+````-U$!`&4!``!#40$`$P```*E2`0`/````O5(!
M`!(```#-4@$`"@```.!2`0`)````ZU(!``L```#U4@$`!`````%3`0`7````
M!E,!`!L````>4P$`,@```#I3`0`B````;5,!`"<```"04P$`)P```+A3`0`<
M````X%,!`"X```#]4P$`"P```"Q4`0`C````.%0!`!,```!<5`$`#@```'!4
M`0`/````?U0!``4```"/5`$`*````)54`0`,````OE0!``X```#+5`$`&0``
M`-I4`0`.````]%0!``L````#50$`CP````]5`0`-````GU4!``H```"M50$`
M$0```+A5`0`0````RE4!``X```#;50$`"P```.I5`0`0````]E4!``\````'
M5@$`!@```!=6`0"R````'E8!``T```#15@$`$@```-]6`0`8````\E8!`!``
M```+5P$`#P```!Q7`0`/````+%<!``<````\5P$`!P```$17`0`N````3%<!
M`"@```![5P$`/@```*17`0!-````XU<!`&@````Q6`$`:P```)I8`0!N````
M!ED!`'$```!U60$`0````.=9`0`8````*%H!`!L```!!6@$`%````%U:`0`4
M````<EH!`!H```"'6@$`!0```*):`0`&````J%H!`!````"O6@$`!P```,!:
M`0`)````R%H!``D```#26@$`,@```-Q:`0`P````#UL!`!$```!`6P$`$0``
M`%);`0`1````9%L!``X```!V6P$`"0```(5;`0`5````CUL!`!4```"E6P$`
M#P```+M;`0`6````RUL!`!4```#B6P$`(P```/A;`0`C````'%P!`!L```!`
M7`$`#P```%Q<`0`6````;%P!``X```"#7`$`+0```))<`0`7````P%P!`!L`
M``#87`$`$P```/1<`0!;````"%T!`#4```!D70$`*@```)I=`0`%````Q5T!
M``D```#+70$`,0```-5=`0`&````!UX!``P````.7@$`"@```!M>`0`'````
M)EX!``@````N7@$`!0```#=>`0`)````/5X!``L```!'7@$`!````%->`0`@
M````6%X!``P```!Y7@$`#````(9>`0`0````DUX!`!H```"D7@$`+````+]>
M`0`*````[%X!`!P```#W7@$`&P```!1?`0`@````,%\!`!<```!17P$`%@``
M`&E?`0`3````@%\!`!````"47P$`'P```*5?`0`K````Q5\!``<```#Q7P$`
M!@```/E?`0`(`````&`!``X````)8`$`"````!A@`0`*````(6`!`!(````L
M8`$`"@```#]@`0`1````2F`!`!4```!<8`$`&````')@`0`*````BV`!`!$`
M``"68`$`!0```*A@`0`7````KF`!`!8```#&8`$`"P```-U@`0!"````Z6`!
M`#P````L80$`"@```&EA`0`'````=&$!`!,```!\80$`!0```)!A`0`%````
MEF$!`!````"<80$`"P```*UA`0`5````N6$!`$4```#/80$`$0```!5B`0`R
M````)V(!`#$```!:8@$`+@```(QB`0`O````NV(!``H```#K8@$`"````/9B
M`0`)````_V(!``H````)8P$`,@```!1C`0`X````1V,!`#$```"`8P$`5P``
M`+)C`0`P````"F0!`#`````[9`$`4````&QD`0!2````O60!`#`````090$`
M1@```$%E`0`T````B&4!`#,```"]90$`40```/%E`0`P````0V8!`#8```!T
M9@$`)0```*MF`0`5````T68!`!D```#G9@$`+@````%G`0`D````,&<!`"<`
M``!59P$`$P```'UG`0`,````D6<!``P```">9P$`"P```*MG`0`0````MV<!
M`!@```#(9P$`'0```.%G`0`'````_V<!``<````':`$`%@````]H`0`*````
M)F@!``@````Q:`$`+P```#IH`0`)````:F@!``L```!T:`$`!@```(!H`0`&
M````AV@!``4```".:`$`!P```)1H`0`&````G&@!``H```"C:`$`+````*YH
M`0`0````VV@!``@```#L:`$``P```/5H`0`'````^6@!``D````!:0$`!```
M``MI`0`*````$&D!``8````;:0$`%0```")I`0`&````.&D!``@````_:0$`
M"0```$AI`0`-````4FD!``@```!@:0$`(0```&EI`0`1````BVD!``D```"=
M:0$`$0```*=I`0`,````N6D!``<```#&:0$``P```,YI`0`#````TFD!`!4`
M``#6:0$`%````.QI`0`E`````6H!``8````G:@$`!````"YJ`0`(````,VH!
M``@````\:@$`4@```$5J`0`D````F&H!`"<```"]:@$`)@```.5J`0`=````
M#&L!``8````J:P$`"````#%K`0`8````.FL!`"(```!3:P$`)0```'9K`0`P
M````G&L!`"0```#-:P$`*@```/)K`0!Z````'6P!`#4```"8;`$`"@```,YL
M`0`)````V6P!``8```#C;`$`%0```.IL`0`/`````&T!``T````0;0$`$```
M`!YM`0`1````+VT!`!````!!;0$`#@```%)M`0`-````86T!`!8```!O;0$`
M!@```(9M`0`=````C6T!`!X```"K;0$`$@```,IM`0`3````W6T!`!$```#Q
M;0$`!@````-N`0`(````"FX!`!0````3;@$`80```"AN`0!X````BFX!``@`
M```#;P$`$P````QO`0`%````(&\!``4````F;P$`'@```"QO`0`;````2V\!
M`!````!G;P$`$P```'AO`0`7````C&\!`!,```"D;P$`+````+AO`0`0````
MY6\!`"0```#V;P$`!@```!MP`0`4````(G`!``D````W<`$`$0```$%P`0`-
M````4W`!`!(```!A<`$`$````'1P`0`6````A7`!`!,```"<<`$`#````+!P
M`0`&````O7`!`!````#$<`$`!P```-5P`0`8````W7`!`!$```#V<`$`$0``
M``AQ`0`(````&G$!``4````C<0$`#0```"EQ`0`-````-W$!``D```!%<0$`
M"P```$]Q`0`&````6W$!``@```!B<0$`#0```&MQ`0`)````>7$!``T```"#
M<0$`!P```)%Q`0`'````F7$!``D```"A<0$`"````*MQ`0`)````M'$!`!L`
M``"^<0$`1P```-IQ`0`:````(G(!``\````]<@$`$P```$UR`0`%````87(!
M`"@```!G<@$`$P```)!R`0`4````I'(!`#@```"Y<@$`1P```/)R`0`B````
M.G,!``@```!=<P$`-0```&9S`0`H````G',!``\```#%<P$`"````-5S`0`-
M````WG,!``8```#L<P$`"````/-S`0`4````_',!`!`````1=`$`"0```")T
M`0`*````+'0!``D````W=`$`'@```$%T`0`C````8'0!`"````"$=`$`)0``
M`*5T`0`<````RW0!`"T```#H=`$`'P```!9U`0`C````-G4!`"X```!:=0$`
M(P```(EU`0`=````K74!`!\```#+=0$`'@```.MU`0`I````"G8!`"\````T
M=@$`,@```&1V`0`D````EW8!`"L```"\=@$`-P```.AV`0`>````('<!`!X`
M```_=P$`/0```%YW`0`D````G'<!`!,```#!=P$`*````-5W`0`?````_G<!
M`"$````>>`$`$@```$!X`0#$````4W@!`!0````8>0$`'@```"UY`0`E````
M3'D!`"<```!R>0$`(P```)IY`0`B````OGD!`"0```#A>0$`(0````9Z`0`D
M````*'H!`"<```!->@$`,````'5Z`0`R````IGH!`*8```#9>@$`(P```(![
M`0`:````I'L!`!P```"_>P$`)P```-Q[`0`P````!'P!`$<````U?`$`1```
M`'U\`0`-````PGP!``0```#0?`$`"0```-5\`0`%````WWP!``T```#E?`$`
M#P```/-\`0`.`````WT!``\````2?0$`$````")]`0`'````,WT!``0````[
M?0$`#P```$!]`0`/````4'T!``P```!@?0$`#@```&U]`0`2````?'T!``L`
M``"/?0$`$@```)M]`0`-````KGT!`"X```"\?0$`!P```.M]`0`0````\WT!
M``8````$?@$`$P````M^`0`9````'WX!`!L````Y?@$`%0```%5^`0`"````
M:WX!`$D```!N?@$`"0```+A^`0`0````PGX!`!,```#3?@$`!0```.=^`0`/
M````[7X!``X```#]?@$``P````Q_`0`0````$'\!``@````A?P$`$0```"I_
M`0`5````/'\!``D```!2?P$`#P```%Q_`0`4````;'\!``\```"!?P$`"@``
M`)%_`0`+````G'\!``T```"H?P$`$0```+9_`0`-````R'\!`!$```#6?P$`
M&@```.A_`0`-`````X`!``\````1@`$`*0```"&``0`3````2X`!`!P```!?
M@`$`-@```'R``0`-````LX`!`"0```#!@`$`$P```.:``0`:````^H`!`!@`
M```5@0$`)0```"Z!`0`+````5($!``H```!@@0$`%@```&N!`0`,````@H$!
M`"0```"/@0$`+0```+2!`0`,````XH$!``@```#O@0$`(0```/B!`0`*````
M&H(!`!D````E@@$`&@```#^"`0`)````6H(!`!4```!D@@$`#@```'J"`0`F
M````B8(!`!T```"P@@$`#P```,Z"`0`9````WH(!``@```#X@@$`$`````&#
M`0`F````$H,!`#T````Y@P$`"````'>#`0`6````@(,!`!L```"7@P$`"@``
M`+.#`0`-````OH,!`#(```#,@P$`#P```/^#`0`%````#X0!``8````5A`$`
M4P```!R$`0`#````<(0!``<```!TA`$`"````'R$`0`-````A80!``X```"3
MA`$`#@```**$`0`0````L80!`!D```#"A`$`%0```-R$`0`9````\H0!`!<`
M```,A0$`"0```"2%`0`&````+H4!``L````UA0$`"@```$&%`0`"````3(4!
M``8```!/A0$`"P```%:%`0`C````8H4!`!8```"&A0$`%P```)V%`0`)````
MM84!``T```"_A0$`#P```,V%`0`/````W84!`#X```#MA0$`)@```"R&`0`(
M````4X8!``\```!<A@$`BP```&R&`0`>````^(8!`!T````7AP$`$@```#6'
M`0`'````2(<!``0```!0AP$`&P```%6'`0`G````<8<!`"4```"9AP$`'P``
M`+^'`0`E````WX<!`!<````%B`$`'````!V(`0`'````.H@!``@```!"B`$`
M!P```$N(`0`&````4X@!``\```!:B`$`#@```&J(`0`0````>8@!``X```"*
MB`$`#P```)F(`0`,````J8@!``L```"VB`$`$0```,*(`0`)````U(@!``H`
M``#>B`$`$@```.F(`0`.````_(@!`"X````+B0$`"P```#J)`0`(````1HD!
M``X```!/B0$`%````%Z)`0`F````<XD!`"D```":B0$`*````,2)`0`=````
M[8D!`!X````+B@$`+````"J*`0`A````5XH!`!D```!YB@$`!````).*`0`<
M````F(H!``\```"UB@$`#````,6*`0`#````THH!``4```#6B@$`"````-R*
M`0`)````Y8H!``L```#OB@$`#````/N*`0`1````"(L!``H````:BP$`#@``
M`"6+`0`+````-(L!``0```!`BP$`!P```$6+`0`<````38L!`!X```!JBP$`
M#0```(F+`0`,````EXL!``X```"DBP$`#0```+.+`0`G````P8L!``<```#I
MBP$`!P```/&+`0`,````^8L!``\````&C`$`%0```!:,`0`'````+(P!``<`
M```TC`$`!````#R,`0`3````08P!``D```!5C`$`!P```%^,`0`P````9XP!
M`!<```"8C`$`@@```+",`0`7````,XT!``L```!+C0$`!P```%>-`0`+````
M7XT!``@```!KC0$`"@```'2-`0`&````?XT!``H```"&C0$``@```)&-`0`&
M````E(T!``D```";C0$`&0```*6-`0`,````OXT!``\```#,C0$`'````-R-
M`0`#````^8T!``<```#]C0$`%@````6.`0`*````'(X!``X````GC@$`!0``
M`#:.`0`S````/(X!``8```!PC@$`!@```'>.`0`8````?HX!`!$```"7C@$`
M!P```*F.`0`)````L8X!``4```"[C@$`"0```,&.`0`(````RXX!``X```#4
MC@$``@```...`0`&````YHX!``X```#MC@$`#0```/R.`0`+````"H\!``L`
M```6CP$`$P```"*/`0`)````-H\!``<```!`CP$`#````$B/`0`?````58\!
M`$,```!UCP$`,0```+F/`0`P````ZX\!``<````<D`$`"@```"20`0`$````
M+Y`!``D````TD`$`"````#Z0`0`,````1Y`!``H```!4D`$`!@```%^0`0`-
M````9I`!``8```!TD`$`!````'N0`0!`````@)`!`$0```#!D`$`0@````:1
M`0`A````29$!``4```!KD0$`#P```'&1`0`%````@9$!``,```"'D0$`!@``
M`(N1`0`A````DI$!`!````"TD0$`&````,61`0`&````WI$!``0```#ED0$`
M&P```.J1`0`&````!I(!``@````-D@$`(@```!:2`0`$````.9(!``4````^
MD@$`%P```$22`0`$````7)(!``T```!AD@$`#0```&^2`0`/````?9(!``@`
M``"-D@$`"0```):2`0`%````H)(!`#T```"FD@$`-@```.22`0`[````&Y,!
M`"H```!7DP$`.````(*3`0`Z````NY,!`"T```#VDP$`4@```"24`0`P````
M=Y0!`#D```"HE`$`*0```.*4`0`0````#)4!`!@````=E0$`#````#:5`0`D
M````0Y4!`"0```!HE0$`(@```(V5`0`A````L)4!``L```#2E0$`#0```-Z5
M`0`*````[)4!``D```#WE0$`(@````&6`0`H````))8!`"@```!-E@$`"```
M`':6`0`:````?Y8!`#,```":E@$`&````,Z6`0`2````YY8!``<```#ZE@$`
M$P````*7`0`4````%I<!`!8````KEP$`$````$*7`0!1````4Y<!`)$```"E
MEP$`A````#>8`0`7````O)@!``X```#4F`$`#P```..8`0`4````\Y@!`!4`
M```(F0$`$0```!Z9`0`,````,)D!`!,````]F0$`%0```%&9`0`5````9YD!
M``\```!]F0$`(@```(V9`0`I````L)D!`(T```#:F0$`%````&B:`0`%````
M?9H!`!8```"#F@$`"0```)J:`0`$````I)H!``H```"IF@$`(P```+2:`0`1
M````V)H!`!,```#JF@$`#@```/Z:`0`0````#9L!`!0````>FP$`)P```#.;
M`0`I````6YL!`"4```"%FP$`)0```*N;`0`P````T9L!`#`````"G`$`'0``
M`#.<`0!%````49P!``\```"7G`$`$0```*><`0`1````N9P!`!,```#+G`$`
M$@```-^<`0`5````\IP!`!<````(G0$`#P```""=`0`1````,)T!`#D```!"
MG0$`'0```'R=`0`7````FIT!`#H```"RG0$`$P```.V=`0`'`````9X!``T`
M```)G@$`(@```!>>`0`2````.IX!`!4```!-G@$`$@```&.>`0`9````=IX!
M`!D```"0G@$`%````*J>`0`:````OYX!`!P```#:G@$`$@```/>>`0`>````
M"I\!`"0````IGP$`%@```$Z?`0`4````99\!`!@```!ZGP$`$@```).?`0`9
M````II\!`!<```#`GP$`$P```-B?`0`7````[)\!``H````$H`$`$`````^@
M`0`@````(*`!``0```!!H`$`!P```$:@`0`*````3J`!`!@```!9H`$`!@``
M`'*@`0`(````>:`!``<```""H`$`!@```(J@`0`'````D:`!``<```"9H`$`
M!0```*&@`0`4````IZ`!``8```"\H`$`"````,.@`0`$````S*`!``0```#1
MH`$`"0```-:@`0`5````X*`!`!(```#VH`$`#P````FA`0`0````&:$!``H`
M```JH0$`$P```#6A`0`%````2:$!`"<```!/H0$`#@```'>A`0`-````AJ$!
M`!,```"4H0$`#0```*BA`0`+````MJ$!``X```#"H0$`,P```-&A`0`(````
M!:(!``@````.H@$`)P```!>B`0`4````/Z(!`!$```!4H@$`!P```&:B`0`)
M````;J(!``<```!XH@$`!````("B`0`@````A:(!``T```"FH@$`&P```+2B
M`0`0````T*(!`!(```#AH@$`%@```/2B`0`=````"Z,!`!D````IHP$`!P``
M`$.C`0`'````2Z,!``8```!3HP$`&````%JC`0`'````<Z,!``4```![HP$`
M"@```(&C`0`.````C*,!``<```";HP$`!@```*.C`0`'````JJ,!`!T```"R
MHP$`#0```-"C`0`,````WJ,!``P```#KHP$`$@```/BC`0`,````"Z0!``\`
M```8I`$`%P```"BD`0`-````0*0!`!````!.I`$`"````%^D`0`$````:*0!
M`!````!MI`$`00```'ZD`0`%````P*0!``P```#&I`$`(0```-.D`0`-````
M]:0!`!D````#I0$`"@```!VE`0`-````**4!``H````VI0$`"````$&E`0`.
M````2J4!``H```!9I0$`$0```&2E`0`2````=J4!`"@```")I0$`+````+*E
M`0`O````WZ4!``H````/I@$`"````!JF`0`(````(Z8!``P````LI@$`%@``
M`#FF`0`'````4*8!``D```!8I@$`'@```&*F`0`(````@:8!``D```"*I@$`
M#````)2F`0!.````H:8!`!,```#PI@$`"P````2G`0`&````$*<!``0````7
MIP$`%@```!RG`0`7````,Z<!`!@```!+IP$`"0```&2G`0`"````;J<!``0`
M``!QIP$`(@```':G`0`#````F:<!``4```"=IP$`,P```*.G`0`*````UZ<!
M``4```#BIP$`!@```.BG`0`-````[Z<!``T```#]IP$`!@````NH`0`(````
M$J@!``D````;J`$`!````"6H`0`%````*J@!`&(````PJ`$`"P```).H`0`-
M````GZ@!`!<```"MJ`$`!0```,6H`0`%````RZ@!`"8```#1J`$`-P```/BH
M`0`1````,*D!``H```!"J0$`%0```$VI`0`*````8ZD!``D```!NJ0$`'```
M`'BI`0`G````E:D!`"T```"]J0$`+````.NI`0`=````&*H!``X````VJ@$`
M`P```$6J`0`'````2:H!``L```!1J@$`!0```%VJ`0`*````8ZH!`!(```!N
MJ@$`!P```(&J`0!I````B:H!`!$```#SJ@$`"P````6K`0`*````$:L!`!\`
M```<JP$`30```#RK`0`:````BJL!``<```"EJP$`(0```*VK`0`U````SZL!
M``@````%K`$`!@````ZL`0`?````%:P!``8````UK`$`"0```#RL`0`M````
M1JP!`"P```!TK`$`+P```*&L`0`&````T:P!``H```#8K`$`)0```..L`0!A
M````":T!`!8```!KK0$`*````(*M`0`5````JZT!``(```#!K0$`#@```,2M
M`0`)````TZT!``\```#=K0$`"@```.VM`0`'````^*T!`!<`````K@$`!@``
M`!BN`0`(````'ZX!``T````HK@$`"P```#:N`0`*````0JX!``D```!-K@$`
M-P```%>N`0`'````CZX!`!8```"7K@$`%````*ZN`0`@````PZX!`!,```#D
MK@$`#````/BN`0`*````!:\!``L````0KP$`"@```!RO`0`,````)Z\!``H`
M```TKP$`"@```#^O`0`=````2J\!`!$```!HKP$`%````'JO`0`,````CZ\!
M`!0```"<KP$`#````+&O`0`2````OJ\!``4```#1KP$`)0```->O`0`$````
M_:\!``<````"L`$`!0````JP`0`%````$+`!``D````6L`$`$P```""P`0`2
M````-+`!`!H```!'L`$`%@```&*P`0`8````>;`!`!<```"2L`$`%P```*JP
M`0`>````PK`!`!@```#AL`$`!P```/JP`0`%`````K$!``\````(L0$`$```
M`!BQ`0`+````*;$!`"$````UL0$`#0```%>Q`0`0````9;$!`"0```!VL0$`
M)P```)NQ`0`5````P[$!``8```#9L0$`#0```."Q`0`(````[K$!`!````#W
ML0$`#P````BR`0`)````&+(!``D````BL@$`!0```"RR`0`'````,K(!``4`
M```ZL@$`!````$"R`0`#````1;(!`#\```!)L@$`.0```(FR`0`3````P[(!
M`"P```#7L@$`,@````2S`0`1````-[,!`#H```!)LP$`+@```(2S`0`S````
ML[,!`#,```#GLP$`.P```!NT`0`2````5[0!`!H```!JM`$`%0```(6T`0`;
M````F[0!`!T```"WM`$`%P```-6T`0`6````[;0!`!0````$M0$`%0```!FU
M`0`9````+[4!`#(```!)M0$`,@```'RU`0`U````K[4!`#,```#EM0$`-```
M`!FV`0`Q````3K8!`&L```"`M@$`'0```.RV`0`5````"K<!``X````@MP$`
M'P```"^W`0`+````3[<!`!8```!;MP$`,````'*W`0`O````H[<!`",```#3
MMP$`#````/>W`0!)````!+@!`$(```!.N`$`!````)&X`0`0````EK@!`!P`
M``"GN`$`#@```,2X`0`3````T[@!``@```#GN`$`"0```/"X`0`'````^K@!
M``D````"N0$`#@````RY`0`5````&[D!``X````QN0$`$0```$"Y`0`(````
M4KD!`!P```!;N0$`"````'BY`0`%````@;D!`!````"'N0$`#P```)BY`0`,
M````J+D!`#\```"UN0$``@```/6Y`0`&````^+D!``X```#_N0$`!@````ZZ
M`0`'````%;H!`!`````=N@$`!P```"ZZ`0`X````-KH!``\```!ON@$`'0``
M`'^Z`0`$````G;H!`#$```"BN@$`&P```-2Z`0`B````\+H!`%@````3NP$`
M&````&R[`0!(````A;L!`",```#.NP$`$````/*[`0`&`````[P!``X````*
MO`$`#P```!F\`0`,````*;P!`!,````VO`$`"P```$J\`0`=````5KP!`!H`
M``!TO`$`!@```(^\`0`1````EKP!``\```"HO`$`)@```+B\`0`2````W[P!
M`!D```#RO`$`$P````R]`0`4````(+T!`"`````UO0$`"````%:]`0`)````
M7[T!`!D```!IO0$`$@```(.]`0`2````EKT!`!,```"IO0$`&````+V]`0`0
M````UKT!`!D```#GO0$`&`````&^`0`*````&KX!``P````EO@$`"````#*^
M`0`%````.[X!`!T```!!O@$`!@```%^^`0`2````9KX!``@```!YO@$`%```
M`(*^`0`*````E[X!`"````"BO@$`$@```,.^`0`P````UKX!`!H````'OP$`
M"P```"*_`0`,````+K\!`"$````[OP$`!P```%V_`0`6````9;\!``,```!\
MOP$`&````("_`0`&````F;\!``<```"@OP$`(0```*B_`0`Q````RK\!``4`
M``#\OP$`&P````+``0`/````'L`!``<````NP`$`#0```#;``0`7````1,`!
M``0```!<P`$`"@```&'``0`,````;,`!``@```!YP`$`!@```(+``0`(````
MB<`!``8```"2P`$`"@```)G``0`7````I,`!`#0```"\P`$`-````/'``0`B
M````)L$!`#,```!)P0$`(````'W!`0!'````GL$!`!T```#FP0$`+@````3"
M`0`L````,\(!`&8```!@P@$`)0```,?"`0`%````[<(!``@```#SP@$`"0``
M`/S"`0`(````!L,!`"$````/PP$`'````#'#`0`P````3L,!`",```!_PP$`
M$@```*/#`0`Q````ML,!`#8```#HPP$`"0```!_$`0`8````*<0!``L```!"
MQ`$`"@```$[$`0`K````6<0!``T```"%Q`$`$@```)/$`0`-````IL0!``@`
M``"TQ`$`%````+W$`0`)````TL0!``P```#<Q`$`$````.G$`0`;````^L0!
M`!H````6Q0$`+````#'%`0`+````7L4!``T```!JQ0$`!@```'C%`0`%````
M?\4!``4```"%Q0$`'0```(O%`0`4````J<4!``4```"^Q0$`"P```,3%`0`*
M````T,4!``@```#;Q0$`#P```.3%`0`1````],4!``X````&Q@$`"@```!7&
M`0`%````(,8!``X````FQ@$`10```#7&`0!B````>\8!`!P```#>Q@$`"0``
M`/O&`0`C````!<<!`!D````IQP$`!0```$/'`0`4````2<<!``@```!>QP$`
M"P```&?'`0`2````<\<!`"X```"&QP$`"P```+7'`0`0````P<<!`!$```#2
MQP$`$@```.3'`0`0````]\<!`$D````(R`$`#````%+(`0`D````7\@!`!4`
M``"$R`$`%P```)K(`0`]````LL@!`"X```#PR`$`,````!_)`0`Q````4,D!
M`"T```""R0$`#````+#)`0`*````O<D!`!````#(R0$`$P```-G)`0`;````
M[<D!``H````)R@$`$0```!3*`0`<````)LH!``<```!#R@$`&````$O*`0`7
M````9,H!``@```!\R@$`!@```(7*`0`+````C,H!``\```"8R@$`%````*C*
M`0`#````O<H!``@```#!R@$`"P```,K*`0`2````ULH!`!,```#IR@$`$0``
M`/W*`0`1````#\L!``8````ARP$`"0```"C+`0`W````,LL!`#````!JRP$`
M+0```)O+`0`'````R<L!`!,```#1RP$`!@```.7+`0`C````[,L!`!@````0
MS`$`)P```"G,`0`-````4<P!``D```!?S`$`)P```&G,`0`#````D<P!``8`
M``"5S`$`"@```)S,`0`"````I\P!``D```"JS`$`$0```+3,`0`(````QLP!
M`!4```#/S`$`&P```.7,`0`4`````<T!``4````6S0$`"@```!S-`0`4````
M)\T!`!$````\S0$`#````$[-`0`'````6\T!``P```!CS0$`"@```'#-`0`.
M````>\T!`%T```"*S0$`&@```.C-`0`K`````\X!`!8````OS@$`"@```$;.
M`0`&````4<X!``P```!8S@$`#@```&7.`0`3````=,X!`"0```"(S@$`'0``
M`*W.`0`4````R\X!`"@```#@S@$`$`````G/`0`@````&L\!`!0````[SP$`
M$````%#/`0!T````8<\!`",```#6SP$`&P```/K/`0`L````%M`!`"(```!#
MT`$`&P```&;0`0`E````@M`!`!D```"HT`$`&P```,+0`0`9````WM`!``L`
M``#XT`$`!P````31`0`(````#-$!``D````5T0$`%````!_1`0`+````--$!
M`"0```!`T0$`#P```&71`0`3````==$!``<```")T0$`"0```)'1`0!>````
MF]$!`$<```#ZT0$`.````$+2`0!;````>](!``D```#7T@$`(0```.'2`0`R
M`````],!``H````VTP$`"````$'3`0`2````2M,!`#\```!=TP$`"0```)W3
M`0!H````I],!`#`````0U`$`)P```$'4`0`0````:=0!`"(```!ZU`$`)```
M`)W4`0`N````PM0!`"L```#QU`$`+@```!W5`0`Q````3-4!`!````!^U0$`
M!0```(_5`0`+````E=4!``H```"AU0$`%0```*S5`0`*````PM4!`"P```#-
MU0$`#````/K5`0`)````!]8!``P````1U@$`%P```![6`0`)````-M8!``<`
M``!`U@$`$P```$C6`0`)````7-8!``@```!FU@$`!@```&_6`0`+````=M8!
M``L```""U@$`$0```([6`0`0````H-8!``X```"QU@$`&P```,#6`0`0````
MW-8!``<```#MU@$`%0```/76`0`8````"]<!``D````DUP$`"P```"[7`0`:
M````.M<!`"D```!5UP$`$@```'_7`0`E````DM<!`"<```"XUP$`#P```.#7
M`0`*````\-<!`!H```#[UP$`!@```!;8`0`$````'=@!`!@````BV`$`#@``
M`#O8`0`0````2M@!``X```!;V`$`!0```&K8`0`)````<-@!``D```!ZV`$`
M"0```(38`0`)````CM@!`!(```"8V`$`!@```*O8`0`-````LM@!``4```#`
MV`$`"0```,;8`0`+````T-@!`!H```#<V`$`"P```/?8`0`"`````]D!`"``
M```&V0$`"0```"?9`0`*````,=D!`&T````\V0$`"0```*K9`0`&````M-D!
M`"L```"[V0$`/@```.?9`0`;````)MH!`"L```!"V@$`1````&[:`0`J````
ML]H!`#0```#>V@$`&@```!/;`0`8````+ML!``8```!'VP$`#````$[;`0`*
M````6]L!``T```!FVP$`!@```'3;`0`*````>]L!`!@```"&VP$`#````)_;
M`0`-````K-L!``\```"ZVP$`"P```,K;`0`-````UML!``@```#DVP$`"@``
M`.W;`0`8````^-L!``D````1W`$`!@```!O<`0`+````(MP!`!,````NW`$`
M!@```$+<`0`8````2=P!`!P```!BW`$`"@```'_<`0`8````BMP!``P```"C
MW`$`$@```+#<`0`+````P]P!`!(```#/W`$`"````.+<`0`2````Z]P!``8`
M``#^W`$`&P````7=`0`,````(=T!`"$````NW0$`!0```%#=`0`%````5MT!
M``X```!<W0$`(P```&O=`0`+````C]T!``T```";W0$`+````*G=`0`<````
MUMT!``X```#SW0$`!0````+>`0`,````"-X!``\````5W@$`#@```"7>`0`"
M````--X!``\````WW@$`"````$?>`0`D````4-X!`"D```!UW@$`+P```)_>
M`0`M````S]X!`"@```#]W@$`*````";?`0!=````3]\!`!,```"MWP$`60``
M`,'?`0`T````&^`!`%X```!0X`$`6P```*_@`0`F````"^$!`#T````RX0$`
M,P```'#A`0`W````I.$!`#4```#<X0$`'@```!+B`0`[````,>(!`.0!``!M
MX@$`(0```%+D`0`4````=.0!`%0```")Y`$`@@```-[D`0!"````8>4!`"D`
M``"DY0$`/P```,[E`0!R````#N8!`%(```"!Y@$`,@```-3F`0`@````!^<!
M`!4````HYP$`,@```#[G`0`=````<><!`!T```"/YP$`+0```*WG`0`C````
MV^<!`"@```#_YP$`00```"CH`0`=````:N@!`!,```"(Z`$`.@```)SH`0`H
M````U^@!`"D`````Z0$`(@```"KI`0`8````3>D!`$````!FZ0$`:0```*?I
M`0`[````$>H!`$X```!-Z@$`.P```)SJ`0`K````V.H!`#H````$ZP$`8P``
M`#_K`0!,````H^L!`#(```#PZP$`+0```"/L`0`Q````4>P!`%0```"#[`$`
M6P```-CL`0!-````-.T!`%$```""[0$`-````-3M`0`N````">X!`"X````X
M[@$`+@```&?N`0"(````ENX!`'T````?[P$`A@```)WO`0#0````)/`!`!,`
M``#U\`$`)@````GQ`0`Y````,/$!`"P```!J\0$`2````)?Q`0`K````X/$!
M`$P````,\@$`(````%GR`0`*````>O(!`,$```"%\@$`1P```$?S`0`F````
MC_,!`#4```"V\P$`)P```.SS`0`D````%/0!`#X````Y]`$`!@```'CT`0`'
M````?_0!``0```"']`$`#````(ST`0`+````F?0!``P```"E]`$`"P```++T
M`0`%````OO0!`!````#$]`$``P```-7T`0!G````V?0!``<```!!]0$`%0``
M`$GU`0`$````7_4!``<```!D]0$`!@```&SU`0`%````<_4!`#X```!Y]0$`
M"0```+CU`0`5````PO4!``L```#8]0$`$@```.3U`0`-````]_4!``(````%
M]@$`!P````CV`0`'````$/8!`!(````8]@$`#````"OV`0`8````./8!``8`
M``!1]@$`#@```%CV`0`,````9_8!``,```!T]@$`*P```'CV`0`$````I/8!
M``<```"I]@$`"````+'V`0`K````NO8!`$<```#F]@$`.@```"[W`0`[````
M:?<!`"(```"E]P$`-@```,CW`0`Y````__<!`"T````Y^`$`(P```&?X`0`F
M````B_@!`"H```"R^`$`)0```-WX`0`C`````_D!`"0````G^0$`+````$SY
M`0`A````>?D!`#P```";^0$`)@```-CY`0`Z````__D!`#4````Z^@$`*P``
M`'#Z`0`N````G/H!`"X```#+^@$`*0```/KZ`0`J````)/L!`"X```!/^P$`
M*P```'[[`0`P````JOL!`"X```#;^P$`*0````K\`0`I````-/P!`#,```!>
M_`$`)````)+\`0`N````M_P!`#@```#F_`$`.P```!_]`0`@````6_T!`"H`
M``!\_0$`0P```*?]`0`I````Z_T!`"P````5_@$`+````$+^`0`M````;_X!
M`"<```"=_@$`'0```,7^`0`K````X_X!`"P````/_P$`-P```#S_`0`L````
M=/\!`$$```"A_P$`#````./_`0`3````\/\!`"`````$``(`,0```"4``@`D
M````5P`"``D```!\``(`#P```(8``@`<````E@`"`!0```"S``(`$````,@`
M`@`Q````V0`"``@````+`0(`"````!0!`@`C````'0$"`"8```!!`0(`'```
M`&@!`@`G````A0$"`!\```"M`0(`"0```,T!`@#A````UP$"`!(```"Y`@(`
M&@```,P"`@`)````YP("``P```#Q`@(`%````/X"`@`0````$P,"`!H````D
M`P(`!@```#\#`@`W````1@,"`!4```!^`P(`%P```)0#`@`'````K`,"`!,`
M``"T`P(`"P```,@#`@`\````U`,"``D````1!`(`*P```!L$`@`0````1P0"
M`!````!8!`(`%0```&D$`@`T````?P0"`"````"T!`(`#@```-4$`@`?````
MY`0"``\````$!0(`$````!0%`@`:````)04"``L```!`!0(`&P```$P%`@`+
M````:`4"`"0```!T!0(`"@```)D%`@`;````I`4"`"L```#`!0(`!P```.P%
M`@`G````]`4"``<````<!@(`"0```"0&`@`)````+@8"`#L````X!@(`!@``
M`'0&`@`.````>P8"`!,```"*!@(`%@```)X&`@`*````M08"``@```#`!@(`
M!P```,D&`@`3````T08"``L```#E!@(`'````/$&`@`/````#@<"`!@````>
M!P(`%@```#<'`@`%````3@<"``<```!4!P(`%P```%P'`@`$````=`<"`#,`
M``!Y!P(`#````*T'`@`0````N@<"``P```#+!P(``@```-@'`@`1````VP<"
M`"(```#M!P(`"P```!`(`@`#````'`@"``<````@"`(`"0```"@(`@`&````
M,@@"``T````Y"`(`"@```$<(`@`4````4@@"`!4```!G"`(`$0```'T(`@`V
M````CP@"`!X```#&"`(`&@```.4(`@`7``````D"``L````8"0(`,P```"0)
M`@`'````6`D"`!<```!@"0(`2P```'@)`@`4````Q`D"``\```#9"0(`"```
M`.D)`@`$````\@D"``0```#W"0(`"@```/P)`@`6````!PH"``4````>"@(`
M!@```"0*`@`(````*PH"``D````T"@(`!````#X*`@`)````0PH"``X```!-
M"@(`/0```%P*`@`Q````F@H"`"X```#,"@(`!0```/L*`@`7`````0L"`"``
M```9"P(`(0```#H+`@`E````7`L"`!````"""P(``@```),+`@`$````E@L"
M``H```";"P(`"0```*8+`@`%````L`L"``(```"V"P(`'P```+D+`@!.````
MV0L"`#D````H#`(`'@```&(,`@`S````@0P"`"H```"U#`(`8````.`,`@`0
M````00T"`'P```!2#0(`)P```,\-`@!3````]PT"`"@```!+#@(`4@```'0.
M`@`X````QPX"`#,`````#P(`-````#0/`@`Y````:0\"`#@```"C#P(`/P``
M`-P/`@`_````'!`"`"T```!<$`(`,````(H0`@`S````NQ`"``X```#O$`(`
M#@```/X0`@`-````#1$"`(,````;$0(`"````)\1`@"Q````J!$"`(T```!:
M$@(`B````.@2`@`N````<1,"`%H```"@$P(`%````/L3`@`E````$!0"`!@`
M```V%`(`$@```$\4`@`:````8A0"`",```!]%`(`-P```*$4`@`:````V10"
M`!@```#T%`(`5@````T5`@`:````9!4"`!8```!_%0(`"P```)85`@`%````
MHA4"``8```"H%0(`"````*\5`@`%````N!4"`!L```"^%0(`$0```-H5`@`>
M````[!4"`!\````+%@(`$0```"L6`@`'````/18"``0```!%%@(`"0```$H6
M`@`.````5!8"``@```!C%@(`!0```&P6`@`<````<A8"``H```"/%@(`"0``
M`)H6`@`/````I!8"``<```"T%@(`"````+P6`@`2````Q18"``H```#8%@(`
M%@```.,6`@`+````^A8"``D````&%P(`%@```!`7`@`(````)Q<"``0````P
M%P(`'````#47`@`5````4A<"``D```!H%P(`&@```'(7`@`0````C1<"`"$`
M``">%P(`#P```,`7`@`(````T!<"`!0```#9%P(`!@```.X7`@`'````]1<"
M`!<```#]%P(`"````!48`@`"````'A@"``(````A&`(`$0```"08`@`+````
M-A@"``8```!"&`(`$0```$D8`@`4````6Q@"``<```!P&`(`+0```'@8`@`"
M````IA@"``0```"I&`(`$P```*X8`@`7````PA@"``L```#:&`(`!P```.88
M`@`/````[A@"``8```#^&`(`%P````49`@`(````'1D"`!@````F&0(`$```
M`#\9`@`2````4!D"``(```!C&0(`!P```&89`@`+````;AD"``H```!Z&0(`
M%0```(49`@`R````FQD"``<```#.&0(`"0```-89`@`1````X!D"``4```#R
M&0(``@```/@9`@`+````^QD"``$```#3!```'`0``#$%``!?`P```````)P!
M``!M`@``H`0```````"4`P``QP$``/L&``!\``````````````"&`@``*0<`
M``L!````````@0<``,$```!W!0``%00``/`%```L````VP,``,$&```C!P``
M"`(```$$``"\!0```@<``#$#````````I@(``.\%``!D`@``L@(```\$``"!
M`P```````````````````````-8$``!1!0``A00`````````````]@$``'`"
M`````````````'\"```N!````````",!``"D!0```````&('``#C!0``CP8`
M`"4!``!P!@``]00``&X"``!P`0``,P<``,(!``#1`@``+P0``&\#``!.!P``
M6@```*(!```S`0``B0<```````![`0``ZP```)8&``#`!0``7`<``$H%``#,
M!@```````)0$``!B`@``\@```"D"``!F`@```````-L$``"$!@``W04`````
M````````I0```````````````````)@#````````0````.0&````````S0$`
M``````"=!```2`(``+\%````````_0(``(@'````````#`4```````!/!```
MRP4``.P"```F!0``%P`````````T````6````+P!`````````````+4"``!:
M!```90,``&H#``!?`0``@@<``````````````````/H!``!D`P``;P```-8!
M````````?08````````(!P``D`````````!-`P``FP(````````<`P``708`
M`/0!``#?````*`,``-P!``#0`0``M@,``$<#````````&P<``!$'```E`P``
M\0```+`%``#2!`````````````"K`P``I`````````#*!0``80,``'D#``"5
M!```"@0```````"*!@``P`$```````#A!```>`<``-D#``#G`0```````/X%
M``!*!P``J0$``%@$``#D`0```````$\```"^`0``````````````````+P,`
M`&P'````````L@````````"8!0``9P0``*0&``#B`0``1@8````````J````
M^P$``&@!``!4!P``V@,``"@&``"C!```5`8``%8$``"O!@```````)T"``!;
M````D@8``(L#``"I`````````*P%``#3````H`,``'H!``!G`@``P@,``"@'
M``![`P``*P`````````V```````````````Q`@``@P```.0$````````]@0`
M`'D$``!$!P```````/<``````````````),"``"Z!0```````!<%``"J`P``
M*P(``'H'````````=`0``#L"`````````````)`"``".`0``B@0``-P```!\
M!P``5P4``)H#```#`@``.P<``%X#```&`0```````$4$````````+0<``)\#
M``"E`0````````````!G!0``<0$`````````````0@8``-L````]!P``2@``
M```````"`@```````"D!````````5@,```````"<!````````,P!``!A!```
M%@,````````G!```80``````````````)00``'<```#N`P``9@8```````"<
M!@``_P4``'L`````````&`8``+$$```#`````P<``-P%``"W!@``R0,``'P"
M```6!P``[```````````````8P$```````#N`@``F@```)(```">`P``````
M`)L!```K!0``<0(``/,#``!&`P``O@(``+H!``#=!```U@8``+0#``#C!```
MR@0``*H$````````&`<``!<"``"_!```&`$``+$"`````````````.(#``"/
M`@```````'X!``#]!0``:0$``!8&``#X`0``*@,``$L#``!R`P``1P0``)8!
M``!'````R`$``'$#``!.!@``.@```&`&``!3````U08``'8"````````+@4`
M`"8"``!S!@``[0````H&```$````Y`(``'X#``"#!0``B0$``),$``#^`@``
M9`<``.8%```7`0```````)\!```-!P``>P(``'X````%!```"0<``"T&```T
M!@```````%("``"_`````````'<#``#_`P````````L````S!0``````````
M``!F!P``)P8``-T`````````]`(``#\'````````V`,``-H$````````````
M`&@````-`@``<@8```````#3!@``Q08``'$```"@````_`8``$("````````
MFP0``+D#``#`````!`0```X&``!,`0``E`(``+D%``"@`0``P0$````````%
M`````````$P'``#6`@``8P````````#$````````````````````\@0`````
M``!`!0``;P<```````#-!@```````!<#``"!!@````````````!2!0``````
M``````#S!```=P0``*,&``!O!```"````%X```!(!P``N@,``'8%``#>````
MA`,``"0$```[!0``]P8``)P#``!W`@```````&H!```^`@``O@8``.T%``"^
M!````````&\&````````B0```*4"````````,P8````````<!P```````%4!
M```B!```.`$```````!M!````````(<"``!Y!0``@`4``-8`````````(0(`
M`$\&```W!```,P(`````````````EP,``/\$````!P``!P,``&D&````````
M\0$``,8```#P`P``CP```%L'`````````````.<&``"%`P````````````#=
M`@``+@,``%<!``#T!@```````.4!``#^````30```,T$```0!0```````#8!
M``"0`P``?0$``)<```!9!```?P0``',```"G!0``6`(``(("````````008`
M`'8!``#^`0```````.<$````````)`````````#X!```:P0``,8$``!9`0``
M(00```8```"?`@``7@(``````````````P8``)0%````````X08``(X#```^
M````*P$``!0"``#7`P``D08``$`'````````;`,```````".!```HP``````
M``#%`P``40```+T"```L!```(`0``.D$````````+`8``/8"```N!@``6`4`
M`````````````````*D"```D`P````````````"S`0```````'T````G`P``
M`````'('````````D00```````#.`0``\`8```@!````````````````````
M`0``3`4``#@&````````R`4``!$!``!?!```^@,``)P```"P`P``Q`$`````
M``!U!```<00``-<"``#)!0``?`$``(P!``````````````````#\!0``-00`
M```````^!P``I08``-`#``"H!@``[0$``*8`````````[P(`````````````
M`````*T$``#K`0``^00``-\#```H!````````&8$``"?````#P8``+D$``#J
M`P```````,D$``!;`@``C`0```````#$`@``O@4``$(%``!T!P``U04``),&
M````````8P<`````````````&P0```````#T`P``5````-D`````````2```
M`)8`````````5@(``#<````?!@``/`(``',"````````\P(````````(!```
MMP(``*4$``!W!P```````-H&```5`````````-D$````````_``````````?
M!0``BP4``/<!``#V!0``?`,``-@&``"T!0``E04```,%````````````````
M````````@P0``+\"``#.`@``#`<``)D#``#_`@```````/0$```_`@``4P$`
M``````#%!```,@$```````#+`@``C```````````````2P$`````````````
MN@8```D!``#>`0``)@0``*0#``#,!0``<P$``#,$```0!@``BP0``&(`````
M````+P```*`&```X`@``60(``'\'``!'!P``C04``!D`````````K0```.\#
M``#1!@``?`4``#(```"]!0``R@(```````#V!@``M@8``%L%``!$`0``````
M```````=`@``'@<``-L&````````#@4```````!@`0``.0(``$,"``"[`0``
M@`,````````J`0``1@```-`"```3!@```````'\```!"`P``-0<``"T!```Q
M!```X0$```````#1!0``M`(``.@!``!4`P``^`,``'T$````````H@,``-0"
M``!B`P``Z@4`````````````7P```!\"```R`P``_`(```````!S!```````
M`(`&```W!0``.@4``!@$````````=@```*,#````````EP4``&(%```2`@``
M;`$``"(!````````C@````````!J!0```````,4%```:`0``X`$```````"3
M`P``F`````````"%!0``&``````````L!0``A@0````````<````F08``&@&
M``#[`@``A0$```````!,`P``:`<``'H$```0!```90```%0%``#$!@``=`(`
M`.```````````````+<#``!U`P````````````````````````````!<`0``
M`````#@'``!^`@``;```````````````B`(```````#.!@``"P(```\%``!M
M`0``+0(``-\%``#G`@``3P,```T!``!@````9P````````"_!@``V0(``+D&
M``````````````````#J````L@0``"@`````````+P<```````#S````J@4`
M`/T!``#5!```&@```````````````````&($````````R`8``%\&``!.````
M`````!,"`````````````$H$```5!@``(P```#\```""!0``J`0``+@"``"1
M!0``Y````$($````````N`4``$$%```?`0``N`$```````";!0```````+4`
M```!!P``*P<`````````````L`0```````!I!P``>P4``&8`````````````
M``````#.!```!P$``%<&`````````````-\&``!@!P``.P$``#L$``!U`@``
MZP8``#D$```?!P``_08``'$&```,`0```````$<&``"=!@``O`0``&4&```)
M!0``10<``````````````````',#``"+````>0<``-(#```!`@``HP$``"P#
M````````LP0````````D!P```0,``.L"``!P````;08``-@````1!@``10,`
M`%T'``#R!0``Z`8``-$$```_`P```````/H%``!E!P``GP8``-("````````
M:P$``-$```")!@``,````,@"``"A!```[`$``.(```!J`@``I@$``%P"````
M````.`,```````!;!@``*P0``&`#``#@!0```````,\```"6!0``UP8``$4"
M`````````````)4!``````````````8&``!&!0``_@8```````!)`P``;`4`
M`%,'``#3`0``@`$`````````````````````````````_00``&P$```&!```
M/@,``!\$``#?!````````%P#``!^!```$0(``"L&``#+!```&P,```````!^
M!@``=0````4#``"1`0```````*P`````````!`(``'D!```I!```-`<`````
M``!Z````=```````````````8@$``%0!```-````/P$``-X#``"T!@``-P<`
M````````````)@```````````````````(@%``"/!````````$8$````!@``
M`````+,```!0`0``D`8``+(!```6`@``4`(``(<#``!N!P``]0(``+8```#R
M!@``\0,``%$!``#B!```[P0```````#/!@```````"\"````````"P<``%``
M````````5`(```````!+!@``@0(````````;!@```````/,&``"+!@``NP``
M`%P&````````^0$``(0```!%!@```````'4!`````````````$0"``!(`0``
M%0,````````D`0``60,``/4```":!0``4P4``-P&```Y`0``&0<```````"(
M`0``7`4``%<$``!!!P``F@(``#T#```1`P``K@4``$D!````````GP0`````
M```^`0``:@```'X%``"G`P``IP8``"``````````K@```$L````2````I@0`
M``$!``!X!@```````-4!``"Z````Y`,``+8!`````````````&@$````````
M`````+X```"Y````<@0````````1````7P4``.8$```@`P``JP$``.8````B
M`@``G@8``+T!``#R`0``.08``((&````````@0```!($``"[`@``/00``'\!
M```;````LP(```````"]`P``=04``&4"``"%`````````,T"``##!@``?P4`
M``````!7`@``GP4``/`!``"M`P```````(H%``!R`0``L0```($$````````
M[P8````````0!P``;P(```````#M`P```````!`"```4`0``+0,``$0$````
M````U0,``-\"````````>P8``$D%````````V@4``(<$````````L08``/<"
M``"O!```!0(````````A````^P4``'<!```\`P``"08``/,%``#P`@``<04`
M`+@#````````U`,``.@"``!8!@```````'L$``!!`P```````"H"``"<!0``
MQ@4``-D%``!A!0````````````#_!@``>@4``$<"```\````O```````````
M````#P,`````````````#P<``#8&```4!`````````````!A`@``!P<``#,#
M````````0`$``#T%````````F@8`````````````AP$``,D```#I`P``XP8`
M`+T```"+`0``O00````````V`P``-0(``!T%````````A@8``*X$```'`@``
MZP0``+\#``````````````````!)!```4`8``+4$``!S!0``Q`,```````!K
M`P``V@$``+`!````````DP4```````#)!@``H@4````````)`P``?0,``!,`
M```-!```Q0$```L$````````00(``%4```#B!0```````*P#```#`P``&00`
M``4&`````````````.H$``#K!0``"@,``*@%``"W!```%@```%0$```W`0``
M504``*0"``#Y`@```````(`"```C!0``^P,``$,!``!J!``````````````_
M!0``$P$```````#R`P``QP0``+T&````````2`,```````#-`P``704``'P$
M```\!@``^0```!X%``!&`0```````*L```!6`0``Z`0``(T`````````S@,`
M`#<&`````````````,L```"'````W0,`````````````S`0```````!1!P``
M`````!D%````````YP,``#$```#,`P``B04``!`!```.````:@<``*<```#/
M!```80<``!<&``#:````(0$``*("``"8`@``7@0``"T$```B!P``90$``'@"
M```3!P``'00``-@%``"<`@``70````````#@!```9@4``#X&``#F`@``````
M`+(%````````!`,``!X$```````````````````$!0```````),!``"%!@``
M=`,``*\#``#Y!@```````)($``"%`@``'08```````#<`P```````%L!``!:
M!P``%`,``/$"```R!P``=`4``*@#``!=`0``*@8``````````````````*X&
M``#@`P``3@,``/P$```Y!P``>`0````````O!0``9P8``-0```"@`@``^0,`
M```````H!0``A0<``.P%``!R`@```````"D`````````!@(````````*!P``
MY00```````!1!@`````````````F!P```08```````!&`@``````````````
M````UP$``,T````W`P``!`$````````J!P``<0<``&(&````````@04``&X!
M``"O`@``Q`0``"X"``!5!```````````````````A`4``!,$``"1`@``5@8`
M`-(```"N`P``2`8``#8'``![!P```````-`$```;!0```````+H$````````
M`````((!`````````````","``!:`0```````!H'```Q!P``(`(``*@"```E
M!P```````#H$``")`@``:P```/$&```Y!0``/`$``!$%````````Y`4``(H`
M```<`0``JP0``(D#```&!0```````"(%``!=`@```````.H!````````^@0`
M``````#?`0``1P4````````2!@``B````.D"```T!```Y0,``*L%``#-!0``
MQP,````````_!```````````````````Z@(``*$#``#^`P``&`4``#,```#U
M!0``=@<```````!N!@```````,L#``!O`0``'@,``%D%````````A@```(,!
M````````M````(\#``"$!```,`0``+<!``"9`@``H`4``+8"``#E`@``````
M`#($``"A````+`(``,@#```+`P```````(P%````````&@8``*P$````````
M``````````!K!0```````-@!````````#@0```<&````````)0```.$#``">
M``````````````!R!0``'@8````````5`0``/@4``!T```#,`@``G@4``(@&
M``".`@``(04``)8"````````/P8``$`&``"A`0``H04``"<"````````````
M`"T```!)!P``E0(``%($`````````````#0"``#W!0``=`$``%T#```U`0``
M`````$X$``!6!0``H@0```D```##!0``@P,```````!8`0``:0(``.P#```9
M`@```````,("``!9!P``0P,``#P$``"0`0``Y@$``.,#``!1!```````````
M``"L`@``#@(``!P"``!.`0``2`0```H`````````3`8``/P!```N````C0$`
M```````L!P``[0(``.D!``#/`0``;`(`````````````V@(``,,"```G````
MLP,``)(%````````;@```!``````````C00``!L!``!P!```=0<````#``#>
M!0``4@<``+(#```&!P``C0,```````"-`@``9P$``((#``"_`0``=@8``&X$
M``"J````3@(``&0%````````C`,``"X'``""!````````+P#```^!```&`(`
M```````W`@``D@,``((`````!```````````````````#P(``!4"``#"````
MNP,```````#0!@``,`4``.X```#!!0```````$@%```2!P``6`<```($``!>
M`0````````````#9`0``208``/$$``!L!@``.`4``#H'``":`0``X0```+P"
M``"^`P``%@0`````````````F04``.D%``#U`P```````$('```9`P``[`0`
M`)4#```"`P``"`8``(T&````````:P8``%\'```N`0``)08```````!D!@``
M:0,```````!>!@``M0,```H"``!)`@``'P````L&``!D`0````````````!/
M`@````````````"F!0``,`8``+$!```,!@``T@$``#4%``"&`0``7```````
M```Z!@``Y@,``!H%``"[!```K0(```````"`````>@,``(<&````````@P8`
M`-T!```U`P``[P$`````````````#````)8#``!C`@``G@(``/$%````````
M``````````!D!`````````````#I````M@4``*$&````````'@$``,$#```[
M!@``<`4``(0!``!K`@```````$T$``#F!@```````,8&``"/`0```````,,`
M```=!P```````&,$``!S!P````````T%```]`0``3P<``&T#```A!@``1```
M`!4'`````````````-@"``!)````.P,``!<$````````[P```&H&````````
M"@4``%,#```'!0``)`4``+4&``"I!```!P0``$<!``!#!@``````````````
M````(`4```````"P````KP```"\&``#N!@``XP`````````B!@``$@,``,$$
M``#9!@````````````!_`P``#`0``!@#``"L`0```````+D!``#B!@``S@``
M``````"2`0``?@<``,4"```"!0```````#0!````````J````"P!```.`P``
M`````)`$```9`0``H@```%`%````````Z08``-4"```````````````````)
M!```F0$``)L#``"J`0``#`(``-0%``#T!0``]0$```T#````````G0$``,4`
M````````Q@(``%<````X````*`(`````````````_0,``*<$``"[!0``````
M`,(%````````3P$``!T!``#L!@``^`8``)8$``!0!````````*T!````````
M`````*0!``"I!0``L`(``&,&````````U@,``!8%``"F`P```````!H"````
M!0```````(8'``"`!P``T`4``.,!``"L!@``XP(``,`&``"K`@``<`,``)`%
M``"O`0```````-(%``"B!@```````+4%````````S@4``&T%````````^`(`
M``````#=!@`````````````?`P``?0<``+0$``"F!@```````,0%``"G`0``
M0P```)T#```;`@```````$P$`````````@$``)<"``!/!0``0`,``'D&``#<
M`@```````$8'``!C!0``?P8``$0#``#E````304``,(&````````````````
M````````T````%L#``"W````>0(``$,%````````4@8``-8%``!*`@``/0``
M`"T%````````>@8``.`"``!@!```&@,``````````````````,,$````````
MTP,``.("``!X`P``E````(<'```:!````````````````````````$$$```9
M!@````````````!0!P```````"D#``#]````5P,`````````````(0<``%$#
M```Z`@``DP```/,!``!5`@`````````````-!@```````)D$````````0@$`
M`%\"``!+!```2P<``&X%``"Q`P```````(0"``!-!@```````"8!````````
MVP$```````"Q!0``<`<``-P$``!I!0``LP8``"<%```\!P``0P<``$H#``!I
M!```SP,```````!H`@``KP4``(`$``!V`P``T0,``%`#``"8`0``X0(``$P"
M``#"!````````(@$``!K!P``<@```````````````````/H"````````,@4`
M`&@#```%!P``(P,``'P&````````Z`,``)<$``"U`0``R@8``,\"```H`0``
MEP$``,L!````````5@<``%,"``!:`P``A@4````````P`@``^````)D`````
M````S````*X"```T!0```````-<`````````I04``````````````````"0&
M``"8!@``[@$``"$#```[````EP8``$$!``#&`P``C`(```0'```5!0``904`
M`````````````````"(#``"*`@``'@```(,'``!5!P``K04``$4```!U!@``
M.`0``,,!``#4`0``0@```&4$```G!P``;P4``/4&``!6````#@$``/D%``!-
M`@``_@0``%H"``"C!0``!`8``.@%```B````104```````!*!@``F`0``)L&
M``#!`@```P0`````````````O`8``&X#```4!@``[08```````!]!0``Z```
M`#0#``!:!0``$@4```\!```>`@```````&@%````````+P$``#T"``!-`0``
M,`$``"4"``#5`````````"4%``!F`P``]@```'H"``".!@````````````"C
M`@```````*X!``#\`P``80$``+@```"1````````````````````E0```"8#
M```/``````````````"*`P```````'T"``#'!0``Q@$```````"&`P``(`<`
M`)X!````````VP(``,D!```*`0``50,``'D```#4!```PP,```````#*`0``
M$P,``````````````````&T'``#P!```=@0```@#````````/08``-@$````
M````H0(``&T```"/!0``%P<```````!7!P``*@0```(```!@`@``'`4`````
M``#X!0``3@4```````#(````#`,``(L"````````I0,```@%````````.0,`
M`/\!```.!P``700```D"````````3````)H$``#1`0``*04``.<%````````
M>`````````!F`0``\````.X%``!+`@``MP4```4%````````4@```.L#``!+
M!0``U`8``#D```#(!```G04``,`"``!>!P```P$``'<&``!$!0``W@8`````
M````````!P```#8%```K`P``^@```,<&```4!P```@8``,H```!X`0``$@$`
M`/<#``#E!0``J@8``%,$``!2`0````````8#``"Y`@``30<``!0```"1`P``
MJ@(``%P$``#7!```.@,``#`#``#T````0`0```````#>`@``L`8`````````
M````VP4``&$&``#``P``R@,``.T$``!;!```E`$``(@#``!G!P``A`<`````
M````````$P4``(P&``"D!```,`<``(H!``!#!```FP```"`&``#R`@``=`8`
M````````````M@0````````0`P``Z@8``&`%````````^P0``)0&``#A!0``
M*08`````````````]P0```````"Z`@```````+0!``!$!@```````*T&``!5
M!@``/`4```````!!````-@0````````R`@````````$%````````C@4``!T#
M``"G`@````````````!2`P``)@8``-,%``#Z!@```````*@!``!C`P``$00`
M````````````4P8``"<!``"S!0```````.4&``#3`@```````(<%``"#`@``
MN`8``%@#``"!`0```````.X$```D`@``T@8````````U````NP8``,D"``"I
M`P``60`````````Q`0```````.`&``"R!@``"P4``$4!``!:!@``N`0``#4&
M````````608```````!D````(P8``,<"````````G0```/\````%`0``0`(`
M`(D$``!I````UP4``"`!``">!````````)("```4!0```````#H!``#/!0``
M`````!8!````````>`4``,<```#+!@````````````!>!0``(P0``/8#```J
M!0``YP```,`$``"I!@``'`8``$H!```Q!@````(``&<#``#>!```-@(`````
M````````^P```*L&``"5!@``40(````````R!@```"`H)7,@9&%Y<R!A9V\I
M`"`H06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M
M;W)R;W<I`"`H>65S=&5R9&%Y*0`@870@`"(E<R(@:7,@;F]T(&$@9&ER96-T
M;W)Y+@`B)7,B(&ES(&YO="!A('9A;&ED(&-H;VEC92X`(B5S(B!I<R!N;W0@
M8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"(E<R(@=')E92!R
M96YD97)E<B!N;W0@9F]U;F0N`"(E<R(@=V%S(&%D9&5D('1O('1H92!G<F]U
M<',@<WES=&5M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@
M<WES=&5M+@`B)7,B('=A<R!N;W0@8W)E871E9#H@)7,N`"4N,F9-0B!U<V5D
M(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I`"5D("5S(&%N9"`E<P`E9"!D
M87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RX`)60M9&%Y(&9O<F5C
M87-T`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT
M96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@
M4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES
M=',N`"5S(&%T("5S("5S`"5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE
M(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M
M(&%T('1H:7,@=&EM92X`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N
M;W0@9F]U;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S
M)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S
M`"5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA
M:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG(&%N>2!L:6YK<R!I;B!I
M="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA
M;"!I;F9O<FUA=&EO;BX`+"!G=7-T:6YG(``L(&=U<W1I;F<@)7,@)7,`+"!V
M87)I86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O
M<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\4')E=FEO=7,`02!D871A
M8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A
M=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E
M<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y
M(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U
M8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@
M4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K
M97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@
M:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y
M(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!#;&]U9',`
M04T@3&EG:'0@4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W
M97)S`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!
M8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93
M(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`
M06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@
M9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($-H
M:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE
M=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O("(E<R(`061D(&$@
M8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE=R!U<V5R.@!!9&0@
M8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE
M;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D9')E<W,@8F]O:SH`
M061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B('1O
M('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG
M;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@(B5S(B!T;R!T:&4@<WES=&5M
M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE
M9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M
M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%F
M9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE
M;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L
M;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A
M9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`
M06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E
M($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N
M871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA
M=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W87,@
M<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+@!!;F1O
M<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N
M=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L
M:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#
M:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R
M86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E
M($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG
M;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M(&1E;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`07)G96YT:6YA`$%R
M;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N<VEO
M;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O
M<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O(&1E;&5T92!A
M(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM
M97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X
M:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES
M=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R
M:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I
M<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT
M96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B
M;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N
M;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@
M4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I
M<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L
M92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A
M=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S
M=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@4F5Q
M=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z
M(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N
M=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO
M;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A
M=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO
M;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@=&\@=&AE
M(%--0B!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I
M:F%N`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`
M0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N
M`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D
M97-H`$)A<F)A9&]S`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E<R(@;F]T
M(&9O=6YD+@!"87-E;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN
M`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC
M871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y
M<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K
M;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T
M<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD
M:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I
M80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`
M0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#
M86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#86QM`$-A
M;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA
M=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B!N;W0@
M=W)I=&4@=&\@9FEL92`B)7,B`$-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@
M<V5S<VEO;B!H86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E
M<CH@)7,`0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#86YC96P`0V%N
M8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#
M86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C
M965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E
M;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R
M96X@97AI<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S
M=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O
M<F5D+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R
M+@!#87!E(%9E<F1E`$-A<'1I;VX`0V%R<FEE<@!#871E9V]R:65S(&%N9"!,
M86)E;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I
M97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG
M.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R
M86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U
M.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E
M<G1I9FEC871E(%!O;&EC:65S`$-H860`0VAA;F=E`$-H86YG92!9;W5R(%!A
M<W-W;W)D`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L
M92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS
M+@!#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET
M:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAI;&4`0VAI;F$`
M0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N
M86P@*$)I9S4I`$-H;V]S92!!<'!L:6-A=&EO;CH`0VAO;W-E(&$@<&%S<W=O
M<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A
M=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T
M<RD`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO
M="!F;W5N9"X`0VQE87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!1=65R
M>0!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A
M=&$`0VQE87)I;F<@3&%T90!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL
M('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO=61S($5A<FQY`$-L
M;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R
M`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME
M<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S
M`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O
M;6]R;W,`0V]M<&%N>0!#;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`
M0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N(&9O<B!S
M>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN`$-O
M;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O;F9I9W5R92`E<P!#;VYF
M:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U
M8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I
M;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V
M97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@
M9F%I;&5D+@!#;VYT86-T<P!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N="!T>7!E(&]F(&-O
M;7!R97-S960@9FEL93H@`$-O;G1E;G1S(&]F("(E<R(`0V]N=&EN=64`0V]O
M:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@9F%I;&5D.B`E<P!#;W!Y('-E
M;&5C=&EO;@!#;W-T($E$`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L
M9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@`$-O=6QD(&YO="!01U`@<VEG
M;B!M97-S86=E.B``0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N
M`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D
M(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#
M;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE8W0@
M=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B`B
M)7,B('5S:6YG($944#H@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I
M;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z(`!#;W5L
M9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C
M;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<P!#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T("(E
M<R(N`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I
M;"!A9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B
M;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI
M<W0N`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T
M<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y("(E<R(N
M`$-O=6QD(&YO="!M:V1I<B`B)7,B+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI
M8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B)7,B
M(&9O<B!W<FET:6YG+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P
M96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@
M9&ER96-T;W)Y("(E<R(N`$-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V
M97(N`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A
M<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F
M('1H92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@
M:&5L<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE
M=F4@861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I
M;VX@;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A
M8FEL:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L
M9"!N;W0@<FUD:7(@(B5S(BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A
M=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#
M;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD
M(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#;W5L
M9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`
M0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U
M(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H
M92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B
M96QO=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N
M`$-O=6QD(&YO="!U;FQI;FL@(B5S(BX`0V]U;&0@;F]T('5P9&%T92!C;VYT
M86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<P!#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@(B5S(CH@)7,`
M0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@
M=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R("(E<R(@
M=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@(B5S(CH@)7,`
M0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@
M;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A
M=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U
M8F$`0W5R<F5N="`T(%!H87-E<P!#=7)R96YT(%-E<W-I;VYS`$-U<G)E;G0@
M5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%5S97)S`$-U<G)E;G0@5V5A
M=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M
M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E
M;&5C=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I
M;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$-Z96-H
M(%)E<'5B;&EC`$1$`$133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N
M=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`1&%I
M;'D`1&%T851R964@0G)O=W-E<@!$871A8F%S92!,;V]K=7``1&%T90!$871E
M(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$
M96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT`$1E9F%U
M;'0`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@4VAE
M;&P`1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92!#96QL`$1E;&5T92!'<F]U
M<`!$96QE=&4@3&]G`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R
M9V4@;65S<V%G97,`1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@
M97AI<W1I;F<@86QT97)N871E('1E;7!L871E`$1E;&5T92!M97-S86=E<P!$
M96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI<W-I;VYS
M(&9O<B`B)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W
M`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@<W5B(&9O;&1E<G,`
M1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@
M<F]W`$1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L:79E
M<GD@=&EM90!$96YM87)K`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T
M:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL
M<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V
M96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``
M1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N
M(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE
M<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9&5T86EL960@9F]R96-A<W0`
M1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I
M=&EO;B!.;W1I9FEC871I;VX`1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$;R!N
M;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F
M:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE
M8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;VXG
M="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O=VYL;V%D`$1O=VYL;V%D
M("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S
M8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%36%I;"UT;RU3
M35,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E
M('1H:7,@<V5R=FEC92X`15)2`$5C=6%D;W(`161I=`!%9&ET($)L;V-K`$5D
M:70@1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I
M="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P
M97)M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%
M9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I
M;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%
M;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6%I;"UT;RU335,@1V%T97=A>0!%
M;6]T:6-O;G,`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S
M96%R8V@@=&5R;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0
M:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O
M;G1E>'0@;65N=3\`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@82!S
M96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y
M;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES
M('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@
M:&5R90!%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SH`17%U871O<FEA;"!'=6EN
M96$`17)I=')E80!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`17)R
M;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R(&1E;&5T:6YG('-Y
M;F,@;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S`$5R<F]R('5P
M9&%T:6YG('!A<W-W;W)D.B`E<P!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N
M`$5R<F]R('=R:71I;F<@(B5S(BX`17-T;VYI80!%=&AI;W!I80!%=&AN:6,`
M175R;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y
M(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y
M(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U
M=&4`17AP86YD`$5X<&%N9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%>'!E8W1E
M9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@
M1&%T90!%>'!O;F5N=`!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A
M:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C
M="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E
M<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P
M>2!T;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I
M;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!R971R:65V
M93H@)7,`1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@
M27-L86YD<P!&871A;"!%<G)O<CH`1F%X`$9A>&5S`$9E8G)U87)Y`$9E96QS
M($QI:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E
M<G,`1FEE;&0@;6%T<FEX`$9I9VQE="!#05!40TA!`$9I9VQE="!F;VYT`$9I
M:FD`1FEL90!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I
M;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL
M92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`
M1FEN;&%N9`!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L
M:7``1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O
M;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G
M97,`1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H
M92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H
M=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E
M(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&
M;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R
M9',`1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5N
M8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E
M<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L
M;"!-;V]N`$9U;&P@3F%M90!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA9V4@
M9G)O;0!'86QL97)Y.@!'86UB:6$`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO
M;@!'96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L
M=&%R`$=I=F5N($YA;64`1VQO8F%L($]P=&EO;G,`1V\`1V]E9&5L`$=O;V=L
M92!-87!S`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R965C90!'<F5E:R`H
M25-/+3@X-3DM-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R
M871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!?;&1A
M<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9#H@`$=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O
M=7`@)7,`1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<P!'
M<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S
M="!097)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`
M1W5Y86YA`$A434P`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE
M=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W
M(&EN('1A8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I
M=&D`2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5A9&5R<P!(96%R9"!)
M<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5A=GD@5"U3=&]R;0!(96)R
M97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET
M;W(`2&5L<&5R`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F
M('1H92!F:6QE.@!(:6=H`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@
M4W1A=&4I`$AO;64`2&]M92!!9&1R97-S`$AO;64@1&ER96-T;W)Y`$AO;64@
M4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!)
M;G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`
M2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T
M("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I
M;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E
M9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE
M(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T
M("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S
M`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@
M=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y
M;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S
M:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`
M2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P
M;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G
M93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M
M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU
M;6ED:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R96%T
M:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@
M)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@
M061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@
M;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I
M;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`26-O;G,@3VYL
M>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M
M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P
M96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I
M8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O
M(&-H96-K('1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN
M`$EF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM
M86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@
M>6]U<B!B<F]W<V5R+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@
M55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!)
M;6%G92!U<&QO860`26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F
M:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!)
M;F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M
M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E
M<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@
M26YD96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`
M26YF;W)M871I;VX`26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92X`
M26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L
M90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R
M="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A
M(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N
M97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W
M(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F
M=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R
M92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`
M26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E
M:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R
M="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU
M;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F
M=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`
M26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@
M=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E
M`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E
M;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E
M9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED(%5$2"X@*%5S97(@
M1&%T82!(96%D97(I+@!);G9A;&ED(%I)4"!D871A`$EN=F%L:60@87!P;&EC
M871I;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M:71T
M960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE
M(&9O<FUA=`!);G9A;&ED(&QI8V5N<V4@:V5Y+@!);G9A;&ED(&QO8V%T:6]N
M('!R;W9I9&5D+@!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I
M;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV
M86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P87)T;F5R(&ED+@!)
M;G9A;&ED('!R;V1U8W0@8V]D92X`26YV86QI9"!P<F]T;V-O;"X`26YV86QI
M9"!R96-I<&EE;G0Z("(E<R(`26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI
M9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N
M=&]R>0!);G9E<G0@<V5L96-T:6]N`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@
M;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS
M`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*
M87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L
M>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU
M<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG
M:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I
M8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E
M<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E
M861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I
M8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+
M;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G
M>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T
M:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@4&%S<W=O<F0@0VAA;F=E`$QA
M<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@
M;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA
M=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE
M9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,979E;`!,:6)E
M<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H
M="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!2
M86EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H
M=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,
M:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O
M('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X
M($-O;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$
M871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R
M8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`
M3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('-E<W-I
M;VYS(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!F86EL960Z("5S`$QI<W1I
M;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO
M861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO
M;@!,;V<@:6X`3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;@!,;V<@;W5T
M`$QO9VEN`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@
M=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN
M`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K
M(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB
M97)S`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N
M=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M
M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL
M`$UA:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`36%L
M9&EV97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE
M<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S
M<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M87``36%P
M475E<W0@;6%P`$UA<'!I;F=S('-T;W)E9"X`36%R8V@`36%R9VEN`$UA<FL@
M=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@
M*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA
M<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S
M`$UA>"!A;&QO=V5D(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D
M960N`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@
M:&]U<G,Z(`!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS`$UA>&EM
M=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!M
M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C
M8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@
M;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP
M90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE
M=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@;F]T(&-O
M;FYE8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B(&ES(&YO="!D969I;F5D`$UE
M=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,`365T<FEC`$UE
M>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L90!-
M:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA
M<W0@-B!H;W5R<SH@`$UI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T
M(&5X<&ER960`36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A
M8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO
M=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@
M=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG
M(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@
M240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D
M:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-
M;VYG;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O
M;B!0:&%S97,`36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H
M92!E>'!E8W1E9"`E9"X`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L
M;W5D>0!-;W-T;'D@0VQO=61Y(&%N9"!7:6YD>0!-;W-T;'D@4W5N;GD`36]V
M92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D;W=N
M`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES
M=',`375L=&EM87`@54L@;6%P`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O
M=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`37D@4&]R=&%L`$UY(%!O<G1A
M;"!,87EO=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`3F%M90!.86UI
M8FEA`$YA=7)U`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL
M;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I;VX@
M55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!5
M4DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E
M<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@
M8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`
M3F5W($-A=&5G;W)Y`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI
M`$YE=R!:96%L86YD`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E
M>'!I<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE=R!W
M:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T(%!H
M87-E<P!.97AT(&]P=&EO;G,`3F5X=#X`3FEC87)A9W5A`$YI9V5R`$YI9V5R
M:6$`3FEG:'0`3FEU90!.;P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D
M871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R
M871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T
M92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VX`
M3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A
M=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@
M=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`
M3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.;R!F
M:6QE('5P;&]A9&5D`$YO(&EC;VYS(&9O=6YD+@!.;R!L;V-A=&EO;B!I<R!S
M970N`$YO(&QO8V%T:6]N('!R;W9I9&5D+@!.;R!M97-S86=E('-U<'!L:65D
M+@!.;R!N86UE('-P96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@
M;V9F96YS:79E(&9O<G1U;F5S`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(
M5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO('!A=&@@=&\@=&AE
M($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@
M:7,@;F5C97-S87)Y('1O('=O<FL@=VET:"!02T-3(#$R(&1A=&$N`$YO('!E
M;F1I;F<@<VEG;G5P<RX`3F\@<75O=&$@<V5T+@!.;R!R=6QE<P!.;R!S97!A
M<F%T;W(@<W!E8VEF:65D+@!.;R!S:61E<P!.;R!S=6-H(&9I;&4`3F\@=&5M
M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A=&$@
M<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN
M86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.
M;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE
M<F%T92!C;VYF:6=U<F%T:6]N+@!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`
M3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@
M2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO
M="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M
M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN9R!T
M;R!B<F]W<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@
M8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!.
M=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U
M=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R96%T;W(`3V-T86P`3V-T
M;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VQD(&%N9"!N97<@<&%S<W=O
M<F1S(&UU<W0@8F4@9&EF9F5R96YT+@!/;&0@<&%S<W=O<F0`3VQD('!A<W-W
M;W)D(&ES(&YO="!C;W)R96-T+@!/;6%N`$]N;'D@24U!4"!S97)V97)S('-U
M<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S
M`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N
M97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H
M:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A
M(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@
M9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="X`3W!E;G,@=&AI<R!L:6YK
M(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO;G,`3W!T
M:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES
M871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@
M=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE
M<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC
M871I;VX@:7,@;F]T(&%V86EL86)L92X`4$5!4CHZ36%I;"!B86-K96YD`%!'
M4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U
M8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!0
M2%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!286EN`%!-(%-H;W=E<G,`4$T@
M4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!/4TE8
M(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!?2%`@4VAE;&P`4&%D9&EN9P!086MI
M<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D`%!A
M;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G1L>2!#;&]U9'D`
M4&%S<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN`%!A<W-W
M;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U
M=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S
M=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`
M4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E
M;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!0
M97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI
M<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D96QE=&5D+@!097)M:7-S:6]N
M($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO
M;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!E=',`4&AI;&EP<&EN97,`
M4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&%T:71U9&5S`%!L96%S
M92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO
M=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M
M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E
M(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M
M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@
M25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@
M=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R
M(&$@=F%L:60@=&EM92X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H
M92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P
M87-S=V]R9`!0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-
M55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0
M;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI
M=&EC<P!0;VQL<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E
M`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E
M<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA
M<W0@)7,@:&]U<BAS*3H@`%!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4`4')E
M9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0
M<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S
M=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD
M;W<`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E($ME
M>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T
M('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,@
M2V5Y($EN9F\`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D
M('-U8V-E<W-F=6QL>2X`4'5E<G1O(%)I8V\`4'5R9V4@;65S<V%G97,`46%T
M87(`475E<GD`475O=&$`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`4F%D:6\@
M<V5L96-T:6]N`%)A:6X`4F%I;B!%87)L>0!286EN($QA=&4`4F%I;B!3:&]W
M97(`4F%I;B!A;F0@4VYO=P!286EN('1O(%-N;W<`4F%N9&]M($9O<G1U;F4`
M4F%T:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_(%1H
M:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!R96UO=F4@
M=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@
M8F4@=6YD;VYE+@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H`%)E
M9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6
M:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O=W-E<@!296QO860`4F5M87)K
M<P!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP
M;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@8V]L
M=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!P86ER`%)E;6]V92!S879E
M9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!2
M96UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`
M4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E<75E<W0@8V]U;&1N)W0@
M8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<75E<W1E9"!S
M97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q=6ER960@(B5S(B!N;W0@
M<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@
M;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@
M(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN`%)E<75I<F5D
M($9I96QD`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O
M<F0`4F5S=&]R92!,87-T(%%U97)Y`%)E<W5L=',`4F5T=7)N('1O($]P=&EO
M;G,`4F5T>7!E(&YE=R!P87-S=V]R9`!2975N:6]N`%)E=F5R="!#;VYF:6=U
M<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT
M`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P97)T:65S+BXN
M`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2
M:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE
M<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU
M;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U
M;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N
M($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA
M='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%33"!A=71H96YT:6-A
M=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG`%-13"!3:&5L
M;`!344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S`%-32`!354-#15-3
M`%-?44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.
M979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD($UI<75E;&]N`%-A
M:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A;64@9G)A;64@*%]S
M96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3
M871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA`%-A=F4`4V%V92`B)7,B
M`%-A=F4@)7,`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R
M87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V960@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`%-C871T97)E9"!4+5-T
M;W)M<P!38VEE;F-E`%-E87)C:`!396%R8V@@16YG:6YE<P!396QE8W0@1FEL
M97,`4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T
M(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O
M(&%D9`!396QE8W0@86QL`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!3
M96QE8W0@86X@;V)J96-T`%-E;&5C="!N;VYE`%-E;&5C="!T:&4@8VAA<F%C
M=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T
M:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+@!3
M96QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R
M;6%T.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`
M4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O
M<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R
M(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E
M.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G86P`4V5N<V]R
M.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M
M8F5R`%-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N`%-E<W-I
M;VX@061M:6X`4V5S<VEO;B!)1"!E>'!I<F5D+@!397-S:6]N<P!3970`4V5T
M(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@
M:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E('-E<G9E<G,@
M=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T
M('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O
M<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S
M8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T
M:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L90!3
M979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z
M(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C
M8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO
M=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE
M(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G
M:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;W!T:6]N('1O(&ME97`@
M;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO=R!T86)L92!O<&5R871I;VYS(&UE
M;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H
M92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE
M(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T
M:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3
M:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E
M`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H<FEN:P!3:')I;FL@;W(@;6]V
M92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`
M4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O
M<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI
M80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W
M(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S($QA=&4`4VYO=R!D97!T:#H@
M`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@`%-O;&]M;VX@27-L86YD<P!3
M;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U
M<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O=71H($5U<F]P96%N("A)4T\M
M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@
M27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J
M86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@
M:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P
M86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3
M<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A
M<F0`4W1A<B!4<F5K`%-T87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A
M='5S`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U
M9V@`4W1R:6YG(&QI<W0`4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`
M4W1Y;&4@6T-34UT`4W4`4W5B9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!3
M=6)J96-T`%-U8FUI=`!3=6)M:71T960@<F5Q=65S="!T;R!A9&0@(B5S(B!T
M;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R(')E
M<75E<W0@:&%S(&)E96X@87!P<F]V960N`%-U8G-C<FEP=`!3=6-C97-S`%-U
M8V-E<W-F=6QL>2!A9&1E9"`B)7,B('1O('1H92!S>7-T96TN`%-U8V-E<W-F
M=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T
M96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL>2!R
M96UO=F5D("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@<F5V
M97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3
M=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E
M<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E
M<RX`4W5C8V5S<V9U;&QY('5P9&%T960@(B5S(@!3=6-C97-S9G5L;'D@=W)O
M=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U
M;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z
M(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A
M<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD
M`%-Y;F,@;&]G(&1E;&5T960`4WEN8TU,`%-Y;G1A>"!E<G)O<B!I;B!S96%R
M8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M
M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L>0!44U8@9FEL90!4
M86)L92!0<F]P97)T:65S`%1A8FQE(%-E=`!486)L92!P<F]P97)T:65S`%1A
M:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N
M>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A<VMS`%1E;&5P
M:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`
M5&5M<&5R871U<F4Z(`!496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S
M*2`F9&5G.R5S`%1E;7!L871E("(E<R(@;F]T(&9O=6YD+@!496UP;&%T92!!
M9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T
M;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AE($944"!E>'1E;G-I
M;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I
M<V%B;&5D+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O
M97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E
M(&EN:71I86QI>F5D+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T
M(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO
M<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF
M:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@
M=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY
M`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE
M(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E
M<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@
M<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I
M<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@
M;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@
M9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R
M>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I
M;VXN`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`
M5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`
M5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I
M;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H
M96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F
M=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I
M=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA
M="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E
M>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N
M8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U
M<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@
M>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N
M965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A
M<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL
M('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E
M;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O
M9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T
M7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I
M=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N
M;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R
M('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@
M=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E
M(&YU;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@
M=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E
M("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC
M965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@
M=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N
M9"!O;B!T:&4@<WES=&5M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@
M;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!R:6=H="!A;F0@;&5F="!S:61E
M<R!O;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5P87)A=&]R
M(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!S97)V97(@(B5S
M(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@
M<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M
M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="X`
M5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T
M97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE
M('-C<F5E;BX`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O
M<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@
M=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO
M="!B92!S879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I
M;&%B;&4N`%1H96UE<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%1H97)E
M(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S
M('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@
M;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R
M960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S
M+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T
M96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@
M=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L
M96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@
M82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE
M("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@
M*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`
M5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A
M<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D
M871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD
M87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T
M:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE
M;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I
M960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA
M=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@
M9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E
M('1R>2!A9V%I;B!L871E<BX`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S
M=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E
M87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M
M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@
M*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&=A=&5W87DL
M('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S
M;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@
M=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6
M;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT
M('=I=&@@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI
M<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M
M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O
M<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD
M(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT
M86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E
M>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@
M<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W
M87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D
M(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'
M<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@8VQI
M96YT<R!P;&5A<V4@=FES:70@)7,`5&AI<R!M97-S86=E('=A<R!W<FET=&5N
M(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN
M`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E
M<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S
M>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU
M<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R
M;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM
M92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,
M97-T90!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT
M:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M
M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(
M5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]O(&UA
M;GD@:6YV86QI9"!L;V=I;G,@9'5R:6YG('1H92!L87-T(&UI;G5T97,N`%1O
M<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@
M5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R:VES
M:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@
M27-L86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z
M(`!54DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P
M;W)T`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S<R!61E,@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I
M;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I
M;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES
M<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@
M)7,N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S(BX`56YA8FQE
M('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,O)7,B+@!5;F%B;&4@=&\@8V]N
M;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-3
M3"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@
M5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E
M8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C
M<F5A=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y
M(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@
M=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+@!5
M;F%B;&4@=&\@9&5L971E("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L971E("5S
M+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E
M(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD
M97(@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S
M+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B
M;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L
M;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@
M9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N
M86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN`%5N
M86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN
M`%5N86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S
M<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E
M<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C
M=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T
M;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET
M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O
M<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E
M9&5D+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@
M86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N
M;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z
M(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER871E
M<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@
M36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@
M87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H
M0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D
M+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U
M<G)E;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A
M;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O
M<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI
M8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T
M;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS
M970@8V]L;W(`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@
M)7,`57!D871E('5S97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D
M96QE=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P
M(&9I;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P
M97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@
M4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U3
M4"!S97)V97(N`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@
M)7,N`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G
M:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D
M(&9O<B!T:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA
M;64`57-E<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S
M97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@
M9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A
M=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T
M97,@9G)O;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H
M(&]F("5S+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`
M5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES
M(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N
M`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D
M:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H
M5DE30TE)*0!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE
M=R!A<R`E<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD
M<RP@52Y3+@!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L
M>2!V:6$@4TU44`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y5
M04Q,62!&4D]-("5S+@!724X@=FEA($A45%``5V%L;&ES(&%N9"!&=71U;F$`
M5V%R;FEN9P!790!796%T:&5R($9O<F5C87-T`%=E871H97(@9&%T82!P<F]V
M:61E9"!B>0!796%T:&5R+F-O;0!796(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O
M;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U
M.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA
M="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`
M5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@
M<75O=&4@8VAA<F%C=&5R/P!7:&5R96ES($%U<W1R86QI82!M87``5VAI8V@@
M<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!4
M97AT(&5D:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F
M('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X
M="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T
M:#H`5VEK:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7
M:6YD.@!7:6YD.B``5VES9&]M`%=I<VAL:7-T`%=O<FL`5V]R:R!!9&1R97-S
M`%=O<FL@4&AO;F4`5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D
M+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&YU;6)E<B!O9B!F:65L
M9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;V9F<V5T("5D('=H
M:6QE(')E861I;F<@82!61E,@9FEL92X`6"U2968`6#4P.78S($)A<VEC($-O
M;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P.78S(%-U
M8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@261E
M;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA:&]O(2!M87``
M665A<FQY`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&%R92!I;B!415A4
M($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O
M(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@
M=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO
M=2!C86YN;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@
M;F%M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S
M+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D
M(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@
M:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L
M:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I
M;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX
M+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C
M;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9
M;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU<W0@9&5S
M8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O
M8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI
M<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O
M(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C
M;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO
M=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U
M(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S
M="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y
M<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE960@=&\@<')O=FED92!A
M;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W5R("5S('-E<W-I;VX@:&%S(&5X
M<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S
M`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN
M=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN
M9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET
M>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E
M<G,N($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S
M97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="!A=71H96YT
M:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@
M9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R
M92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO
M=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@
M8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R
M('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S97(@
M9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N
M=')O;"]#;VUM86YD("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT('1I;64@
M>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N
M`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@
M;&]G:6X@:&%S(&5X<&ER960N`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I
M<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@
M9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B
M965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U
M<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A
M;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<&%S<W=O
M<F0@:&%S(&5X<&ER960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V
M:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!4
M97AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H
M;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!
M9&UI;FES=')A=&EO;@!?0TQ)`%]$871A5')E90!?1&5L971E(%)O=P!?1W)O
M=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN`%],;V<@:6X`7TQO9R!O
M=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M
M;W9E($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R
M<P!A9&1R97-S(&)O;VL`861D<F5S<V5E('5N:VYO=VX`8V%L96YD87(`8V%L
M;0!C86YN;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T
M`&-L:6-K(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R
M871I;VX@97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9P!D871A
M(&9O<FUA="!E<G)O<@!E9&ET`&5N=')Y(&YO="!F;W5N9`!F86QL:6YG`&9I
M;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&@Z`&AH`&AO
M<W0@;F%M92!U;FMN;W=N`&EM;65D:6%T90!I;FQI;F4`:6YP=70O;W5T<'5T
M(&5R<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R`&QI;F5S70!M:VES;V9S
M(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;6T`;F%M90!N;W0@
M:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`'!E<F-E
M;G0`<&5R;6ES<VEO;B!D96YI960`<&EX96QS`')E;6]T92!E<G)O<B!I;B!P
M<F]T;V-O;`!R:7-I;F<`<V5R=FEC92!U;F%V86EL86)L90!S:&]W(&1I9F9E
M<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S<P!S=&5A9'D`<WES=&5M(&5R
M<F]R`'1A<VL@;&ES=`!T96UP;W)A<GD@9F%I;'5R90!T>7!E('1H92!P87-S
M=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N:69I960`=6YN86UE9`!U<V5R('-E
M;&5C=`!V0V%R9`!W.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ
M($AO<F1E(#,N,2XQ+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI
M<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,RTQ,B`P
M,#HS,2LP,3`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#,M,3,@,C(Z-#`K
M,#$P,`I,87-T+51R86YS;&%T;W(Z($IA;B!+=6EP97)S(#QJ<FMU:7!E<G-`
M;&%U=V5R<V-O;&QE9V4N;FP^"DQA;F=U86=E+51E86TZ($1U=&-H(#QI,3AN
M0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4
M>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3$*0V]N=&5N="U4
M<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`("@E<R!D86=E;B!G96QE9&5N*0`@
M*%-N96QT;V5T<R`E<RD`("AB:6YN96X@)7,@9&%G96XI`"`H=F%N9&%A9RD`
M("AM;W)G96XI`"`H9VES=&5R96XI`"!O<"``(B5S(B!I<R!G965N(&1I<F5C
M=&]R>2X`(B5S(B!I<R!G965N(&=E;&1I9V4@:V5U>F4N`"(E<R(@:7,@;FEE
M="!G96-O;F9I9W5R965R9"!I;B!H970@2&]R9&4@<F5G:7-T97(N`"(E<R(@
M=')E92!W965R9V5V97(@;FEE="!G979O;F1E;BX`(B5S(B!A86X@:&5T(&=R
M;V5P96YS>7-T965M('1O96=E=F]E9V0N`"(E<R(@86%N(&AE="!R96-H=&5N
M<WES=&5E;2!T;V5G979O96=D+@`B)7,B(&ES(&YI970@86%N9V5M86%K=#H@
M)7,N`"4N,F9-0B!G96)R=6EK="!V86X@)2XR9DU"('1O96=E<W1A86X@*"4N
M,F8E)2D`)60@)7,@96X@)7,`)60@9&%G96X@=&]T('5W('=A8VAT=V]O<F0@
M=F5R=F%L="X`)60M9&%G('9O;W)U:71Z:6-H=``E<R`M($]P;65R:VEN9P`E
M<R!V:6YG97)A9F1R=6L`)7,@2T(`)7,@3VYD97)H;W5D<W=E<FMZ86%M:&5D
M96X@+2!"979E<W1I9VEN9P`E<R!);G-T96QL96X`)7,@:6YS8VAR:6IV96X`
M)7,@9V5B<G5I:V5R<V]V97)E96YK;VUS=``E<R!B97-T86%T(&%L+@`E<R!O
M<"`E<R`E<P`E<R!I<R!G97)E960@;VT@;VYD97)S=&%A;F1E(&=E<V5L96-T
M965R9&4@;VYD97)H;W5D<W=E<FMZ86%M:&5D96X@=6ET('1E('9O97)E;BX@
M5FEN:R!D92!B97=E<FMI;F<H96XI(&%A;B!D:64@=2!O<"!D:70@;6]M96YT
M('=I;'0@=6ET=F]E<F5N+@`E<R!I<R!V97)E:7-T`"5S(&UI;G5T96X`)7,@
M;FEE="!G979O;F1E;BX`)7,@=&]T("5S('9A;B`E<P`E<R=S(&%D<F5S8F]E
M:P`E<R=S(&%G96YD80`E<R=S(&YO=&ET:65B;V5K`"5S)W,@=&%K96YL:6IS
M=``E<SH@)7,`)7,Z($1I="!B97)I8VAT(&MO;70@;6ES<V-H:65N(&YI970@
M=F%N(&1E9V5N92!D:64@:&5T(&)E=V5E<G0@=&4@>FEJ;BX@5V5E<R!V;V]R
M>FEC:'1I9R!B:6H@:&5T(&ML:6MK96X@;W`@;&EN:W,@:6X@:&5T(&)E<FEC
M:'0@;V8@9&4@869Z96YD97(@<&5R<V]O;FQI:FME(&EN9F]R;6%T:64@=&4@
M<W1U<F5N+@`L('=I;F1V;&%G96X@`"P@=VEN9'9L86=E;B`E<R`E<P`L('9A
M<FEA8F5L('9A;B`E<R!T;W0@)7,`+2T@<V5L96-T97)E;B`M+0`Q,B!U=7)S
M=V5E<F=A=F4`,C0@=75R<W=E97)G879E`#(T('5U<G,`/%9O<FEG90!%96X@
M9&%T86)A<V4@8F%C:V5N9"!I<R!V97)E:7-T('9O;W(@9&ET(&)L;VLN`$5R
M(&AE969T('II8V@@965N(&9A=&%L92!F;W5T('9O;W)G961A86X`165N(&]P
M96YB87)E(%!'4"!S;&5U=&5L(&ES('9E<F5I<W0@;VT@965N(&)E<FEC:'0@
M=&4@8V]D97)E;BX`165N(&]P96YB87)E(%!'4"!S;&5U=&5L(&ES('9E<F5I
M<W0@;VT@965N(&]N9&5R=&5K96YD(&)E<FEC:'0@=&4@=F5R:69IZW)E;BX`
M165N(&]P96YB87)E(%!'4"!S;&5U=&5L+"!P<FEVZ2!01U`@<VQE=71E;"!E
M;B!W86-H='=O;W)D<F5G96P@>FEJ;B!V97)E:7-T(&]M(&5E;B!B97)I8VAT
M('1E(&1E8V]D97)E;BX`165N(&]P96YB87)E(%!'4"!S;&5U=&5L+"!P<FEV
MZ2!01U`@<VQE=71E;"!E;B!W86-H='=O;W)D<F5G96P@>FEJ;B!V97)E:7-T
M(&]M(&5E;B!B97)I8VAT('1E(&]N9&5R=&5K96YE;BX`165N(&]P96YB87)E
M(%,O34E-12!S;&5U=&5L+"!P<FEVZ2!3+TU)344@<VQE=71E;"!E;B!W86-H
M='=O;W)D<F5G96P@>FEJ;B!V97)E:7-T(&]M(&5E;B!B97)I8VAT('1E(&1E
M8V]D97)E;BX`165N(&]P96YB87)E(%,O34E-12!S;&5U=&5L+"!P<FEVZ2!3
M+TU)344@<VQE=71E;"!E;B!W86-H='=O;W)D<F5G96P@>FEJ;B!V97)E:7-T
M(&]M(&5E;B!B97)I8VAT('1E(&]N9&5R=&5K96YE;BX`165N(&]P96YB87)E
M(%--24U%('-L975T96P@:7,@=F5R96ES="!O;2!E96X@8F5R:6-H="!T92!C
M;V1E<F5N+@!"97=O;&MI;F<@=F]O<B`Q,BXP,"!U=7(`3&EC:'1E(')E9V5N
M('9O;W(@,3(N,#`@=75R`%)E9V5N('9O;W(@,3(N,#`@=75R`$)U:65N('9O
M;W(@,3(N,#`@=75R`%-N965U=V)U:65N('9O;W(@,3(N,#`@=75R`$%-+U!-
M`$%022!)1`!/=F5R(&1E>F4@961I=&]R`$]V97(N+BX`06)S8F]T=&]M`$%B
M<VUI9&1L90!4;V5G86YG(&=E=V5I9V5R9"!B:6H@:&5T(&UA:V5N('9A;B!6
M1E,@9&ER96-T;W)Y+@!4;V5G86YG(&=E=V5I9V5R9"!B:6H@:&5T(&UA:V5N
M('9A;B!61E,@8F5S=&%N9"X`06-C;W5N=&EN9F]R;6%T:64`06-C;W5N='=A
M8VAT=V]O<F0`06-C;W5N="!B979R;W)E;BX`5F5R86YT=V]O<F1I;F<`5&]E
M=F]E9V5N`$-H:6QD(&=R;V5P('1O979O96=E;@!#:&EL9"!R96-H="!T;V5V
M;V5G96X`2&EE<B!T;V5V;V5G96XZ`$YI975W92!G<F]E<"!T;V5V;V5G96X`
M3FEE=7<@<F5C:'0@=&]E=F]E9V5N`$5E;B`B8VAI;&1G<F]E<"(@86%N("(E
M<R(@=&]E=F]E9V5N`$5E;B`B8VAI;&1R96-H="(@86%N("(E<R(@=&]E=F]E
M9V5N`$YI975W92!G96)R=6EK97(@=&]E=F]E9V5N.@!+;VQO;2!T;V5V;V5G
M96X`3FEE=7=E(&QE9&5N('1O979O96=E;@!086%R('1O979O96=E;@!(970@
M)7,@;65N=2!T;V5V;V5G96X@86QS(&5E;B!-;WII;&QA(%-I9&5B87(`5F]E
M9R!T;V4@86%N(&%D<F5S8F]E:SH`5F]E9R!T;V4@86%N(&UI:FX@861R97-B
M;V5K`$=E8G)U:6ME<B!T;V5V;V5G96X`(B5S(B!A86X@:&5T('-Y<W1E96T@
M=&]E9V5V;V5G9"P@;6%A<B!K;VX@9V5E;B!E>'1R82!I;G-C:')I:G9I;F=S
M:6YF;W)M871I92!T;V5V;V5G96XZ("5S+@`B)7,B(&%A;B!H970@<WES=&5E
M;2!T;V5G979O96=D+B!5(&MU;G0@;G4@86%N;65L9&5N+@!4;V5V;V5G96X@
M=F%N(&=E8G)U:6ME<G,@:7,@=6ET9V5S8VAA:V5L9"X`061R97,`061R97-B
M;V5K`$)E:&5E<B`M(')E8VAT96X@=F]O<B!A;F1E<F4@9V5B<G5I:V5R<R!I
M;G-T96QL96X`0F5H965R`$%D=F5R=&5N=&EE<P!!9F=A;FES=&%N`$%L8F%N
M:>L`06QG97)I:F4`06QI87,`56ET;&EJ;F5N`%5I=&QI:FYI;F<Z`$%L;&4`
M06QL92!G96%U=&AE;G1I8V5E<F1E(&=E8G)U:6ME<G,`06QL92!G<F]E<&5N
M`$%L;&4@<F5C:'1E;@!!;&QE('9I97(@>FEJ9&5N`$UE97)D97)E(&%D<F5S
M<V5N('1O97-T86%N`$EN<W1E;&QE;B!V86X@9V5O<F1E;F1E(&QI:G-T('1Y
M<&4@=&]E<W1A86X_`$)E<W1A870@86P`06QT97)N871I979E($E-4U`@86%N
M;65L9&EN9P!!;'1E<FYA=&EE9B!)35-0('=A8VAT=V]O<F0`06QT97)N871I
M979E($E-4U`@9V5B<G5I:V5R<VYA86T`06QT97)N871I968@92UM86EL861R
M97,`06QT97)N871I979E('-J86)L;VYE;@!!;'1E<FYA=&EE=F4@=&5K<W0Z
M`$%M97)I:V%A;G,@4V%M;V$`165N(&]N9V5L9&EG92!W86%R9&4@;W!G96=E
M=F5N+@!%<B!H965F="!Z:6-H(&5E;B!O;F)E:V5N9&5F;W5T('9O;W)G961A
M86XN`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYI96UE('!R;WAY`$%N
M='=O;W)D`$%N=&%R8W1I8V$`06YT:6=U82!E;B!"87)B=61A`%1O97!A<W-I
M;F<`5&]E<&%S<VEN9V5N;&EJ<W0`5&]E<&%S<VEN9R!I<R!G97)E960N`$]P
M(&-H:6QD<VAA<F5S('1O97!A<W-E;@!';V5D:V5U<F5N`$=E<V-H871T92!G
M<F]O='1E`$%P<FEL`$%R86)I<V-H("A7:6YD;W=S+3$R-38I`$%R8VAI969B
M97-T86YD<V=R;V]T=&4`07)C:&EE9FYA86T`5V5E="!U('IE:V5R(&1A="!U
M(&AE="!A86YM96QD:6YG<W9E<GIO96L@=F%N("5S('=I;'0@=F5R=VEJ9&5R
M96X_`%=E970@=2!Z96ME<B!D870@=2`B)7,B(&5N(&%L;&4@<W5B9W)O97!E
M;B!W:6QT('9E<G=I:F1E<F5N/P!!<F=E;G1I;FGK`$%R;65N:>L`07)M965N
M<R`H05)-4T-)22TX*0!+=6YS=`!!<G5B80!!<V-E;G-I;VX@96EL86YD`$%S
M8VEI(&MU;G-T`$%Z:>LO4&%C:69I<V-H92!296=I;P!/;2!B979E<W1I9VEN
M9R!V<F%G96X@=F]O<B!H970@=6ET=F]E<F5N('9A;B!O;F1E<FAO=61S=V5R
M:WIA86UH961E;C\`3W!D<F%C:'0@:V]L;VUM96X`4&]G:6YG(&]M(&5E;B!N
M:65T(&)E<W1A86YD92!G<F]E<"!T92!V97)W:6ID97)E;BX`4&]G:6YG(&]M
M(&5E;B!N:65T(&)E<W1A86YD(')E8VAT('1E('9E<G=I:F1E<F5N+@!0;V=I
M;F<@;VT@965N(&YI970@8F5S=&%A;F0@<F5C:'0@=&4@8F5W97)K96XN`%!O
M9VEN9R!O;2!E96X@;FEE="!B97-T86%N9&4@<VAA<F4@=&4@8F5W97)K96XN
M`$%T=')I8G5T96X`075G=7-T=7,`075S=')A;&GK`$]O<W1E;G)I:FL`075T
M:%]C>7)S<6PZ('9E<F5I<W1E(&EM87`@97AT96YT:64@;FEE="!G979O;F1E
M;BX`075T:%]C>7)U<SH@8F%C:V5N9"!H965F="!N:65T(&1E('9E<F5I<W1E
M(&)E:W=A86UH961E;BX`075T:%]C>7)U<SH@=F5R96ES=&4@:6UA<"!E>'1E
M;G1I92!N:65T(&=E=F]N9&5N+@!!=71H7V9T<#H@=F5R96ES=&4@1E10(&5X
M=&5N=&EE(&YI970@9V5V;VYD96XN($-O;7!I;&5E<B!02%`@;65T(&1E("TM
M96YA8FQE+69T<"!O<'1I92X`075T:%]I;6%P.B!V97)E:7-T92!)34%0(&5X
M=&5N=&EE(&YI970@9V5V;VYD96XN`$%U=&A?:W)B-3H@=F5R96ES=&4@:W)B
M-2!E>'1E;G1I92!N:65T(&=E=F]N9&5N+@!!=71H7VQD87`Z('1O979O96=E
M;B!V86X@9V5B<G5I:V5R<R!W;W)D="!N:65T(&]N9&5R<W1E=6YD('9O;W(@
M06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%9E<G=I:F1E<F5N('9A;B!G
M96)R=6EK97)S('=O<F1T(&YI970@;VYD97)S=&5U;F0@=F]O<B!!8W1I=F4@
M1&ER96-T;W)Y`$%U=&A?;&1A<#H@=F5R96ES=&4@3$1!4"!E>'1E;G1I92!N
M:65T(&=E=F]N9&5N+@!!=71H7VQD87`Z($YI970@:6X@<W1A870@9V5B<G5I
M:V5R("5S('1O92!T92!V;V5G96XN($1E('-E<G9E<B!M96QD=#H@`$%U=&A?
M;&1A<#H@3FEE="!I;B!S=&%A="!G96)R=6EK97(@)7,@=&4@=F5R=VEJ9&5R
M96X`075T:%]L9&%P.B!.:65T(&EN('-T86%T(&=E8G)U:6ME<B`E<R!B:6H@
M=&4@=V5R:V5N`$%U=&A?;&1A<#H@0FEJ=V5R:V5N('9A;B!G96)R=6EK97)S
M('=O<F1T(&YI970@;VYD97)S=&5U;F0@=F]O<B!!8W1I=F4@1&ER96-T;W)Y
M+@!!=71H7VUC86PZ('9E<F5I<W1E($U#04P@97AT96YT:64@;FEE="!G979O
M;F1E;BX`075T:%]S;6)A=71H.B!V97)E:7-T92!S;6)A=71H(&5X=&5N=&EE
M(&YI970@9V5V;VYD96XN`$%U=&AE;G1I8V%T:64@;W`@24U!4"!S97)V97(@
M;6ES;'5K="X`075T:&5N=&EC871I92!M:7-L=6MT`$%U=&AE;G1I8V%T:64@
M;6ES;'5K="X@)7,`075T:&5N=&EC871I92!G97=E:6=E<F0@9&]O<B!D92!2
M041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EE(&]P($944"!S97)V97(@;6ES
M;'5K="X`075T:&5N=&EC871I92!O<"!D92!334(@<V5R=F5R(&UI<VQU:W0N
M`$)E<V-H:6MB87)E('9E;&1E;CH`07IE<F)A:61Z:F%N`$)/1D@@17AC=7-E
M<P!!8VAT97)G<F]N9`!!8VAT97)G<F]N9&ML975R`$9O=70@:V5R8F5R;W-W
M86-H='=O;W)D+@!&;W5T92!K97)B97)O<V=E8G)U:6ME<G-N86%M+@!"86AA
M;6%S`$)A:')E:6X`0F%L=&ES8V@@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H
M`$)A<F)A9&]S`$)A<VES(&%F8F5E;&1I;F=E;F1I<F5C=&]R>2`B)7,B(&YI
M970@9V5V;VYD96XN`$)A<VES;&EJ;@!7:70@<G5S;&%N9`!"96QG:>L`0F5L
M:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`%9E<FIA87)D86<`0FQO:R`B)7,B
M('9A;B!T;V5P87-S:6YG("(E<R(@;FEE="!G979O;F1E;BX`0FQO:VEN<W1E
M;&QI;F=E;@!";&]K='EP90!6970`0F]L:79I80!";V]K;6%R:W,`4F%N9`!2
M86YD9&EK=&4Z`%)A;F1E;@!";W-N:>L@96X@2&5R>F5G;W9I;F$`0F5I9&5N
M`$)O='-W86YA`$]N9&5R:V%N=`!";W5V970@96EL86YD`$)R87II;&GK`$)R
M:71S($EN9&ES8VAE($]C96%A;B!497)R:71O<FEU;0!"<G5N96D@1&%R=7-S
M86QA;0!"=6QG87)I:F4`3VYG96]R9&5N9&4@;&EJ<W0`0G5R:VEN82!&87-O
M`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:65P=6YT96X`0U]E;&5I
M9V5N<V-H87!P96XN+BX`0V%C:&4@:6YI=&EA;&ES871I92!I<R!N:65T(&%F
M9V5R;VYD+@!!9V5N9&$`2V%L;0!#86UB;V1J80!+86UE<F]E;@!+86X@=V%C
M:'1W;V]R9"!N:65T(&%U=&]M871I<V-H(')E<V5T=&5N+"!N965M(&-O;G1A
M8W0@;W`@;65T(&1E('-Y<W1E96UB96AE97)D97(N`$MA;B!N:65T(&YA87(@
M8F5S=&%N9"`B)7,B('-C:')I:G9E;@!+86X@9V5E;B!E>'1E<FYE('-E<W-I
M96AA;F1L97(@8F5H97)E;BX`2V%N(&YI970@=F5R8FEN9&5N(&UE="!)34%0
M('-E<G9E<CH@)7,`2V%N(&)E<W1A;F0@(B5S(B!N:65T(&]P96YE;BX`0V%N
M861A`$%F8G)E:V5N`%!R;V)L965M<F%P<&]R="!A9F)R96ME;@!+86X@8F5S
M=&%N9"`B)7,B(&YI970@=F5R=VEJ9&5R96XN`$MA;B!G965N('1I:F1E;&EJ
M:V4@9&ER96-T;W)Y('9I;F1E;BX`2V%N(&YI970@9&]O<F=A86X@>F]N9&5R
M("=T87)G971&:6QE)R!P87)A;65T97(N`$MA;B!D:7)E8W1O<GD@(B5S(B!N
M:65T('9E<G=I:F1E<F5N+@!+86X@;FEE="!V97)W:6ID97)E;CL@)60@8VAI
M;&1R96X@8F5S=&%A;BX`2V%N(&YI970@;W!N:65U=R!R86YG<V-H:6MK96XL
M(&AE="!A86YT86P@:6YV;V5R96X@;VT@;W!N:65U=R!T92!R86YG<V-H:6MK
M96X@:V]M="!N:65T(&]V97)E96X@;65T(&AE="!O<&=E<VQA9V5N(&%A;G1A
M;"X`2V%N(&)E<FEC:'0@;FEE="!N86%R(&AE="!O<&=E9V5V96X@;G5M;65R
M('9E<G-T=7)E;BX`2V%A<"!697)D90!/<'-C:')I9G0`1')A9V5R`$-A=&5G
M;W)I9>MN(&5N(&QA8F5L<P!#87EM86X@96EL86YD96X`5&5L+FYR+FUO8FEE
M;`!#96QE:6=E;G-C:&%P<&5N`$-E;"!V<FEJ92!R=6EM=&4Z`$-E;&5I9V5N
M<V-H87!P96X`0V5L<W!A=&GK<FEN9SH`5&5L+FYR+FUO8FEE;`!+96QT:7-C
M:"`H25-/+3@X-3DM,30I`$UI9&1E;@!#96YT<F%A;"!!9G)I:V%A;G-E(%)E
M<'5B;&EE:P!#96YT<F%A;"!%=7)O<&5E<R`H25-/+3@X-3DM,BD`0V5R=&EF
M:6-A871D971A:6QS`$-E<G1I9FEC86%T96EG96YA87(`0V5R=&EF:6-A871B
M96QE:60`5'-J86%D`%=I:GII9V5N`%=I:GII9R!U=R!W86-H='=O;W)D`%=I
M:GII9R!D92!N86%M+"!A9')E<R!E;B!O;F1E<G1E:V5N:6YG(&1I92!M96X@
M>FEE="!B:6H@:&5T(&QE>F5N(&5N(&)E86YT=V]O<F1E;B!V86X@=7<@92UM
M86EL<RX`5VEJ>FEG96X@=F%N('5W('=A8VAT=V]O<F0@=V]R9'0@;FEE="!O
M;F1E<G-T975N9"!D;V]R(&1E(&AU:61I9V4@8V]N9FEG=7)A=&EE+B!.965M
M(&-O;G1A8W0@;W`@;65T('5W('-Y<W1E96UB96AE97)D97(N`$MA<F%K=&5R
M`$-O;G1?<F]L965R(&QI;FLN+BX`0VAI;&D`0VAI;F$`0VAI;F5E<R!V97)E
M96YV;W5D:6=D("A'0C(S,3(I`$-H:6YE97,@=')A9&ET:6]N965L("A":6<U
M*0!+:65S('1O97!A<W-I;F<Z`$MI97,@965N('=A8VAT=V]O<F0`2VEE<R!E
M96X@9V5B<G5I:V5R<VYA86T`2VEE<R!D871U;7=E97)G879E.@!+:65S(&QI
M:G-T<W1I:FQT>7!E("AV;V]R(&=E;W)D96YD92!L:6IS=&5N*0!#:')I<W1M
M87,@96EL86YD`$-L87-S9&5F:6YI=&EE('9A;B`E<R!N:65T(&=E=F]N9&5N
M+@!(96QD97(`35-/9F9I8V4@=&%G<R!W:7-S96X`5VES('%U97)Y`%=I<R!G
M96)R=6EK97(Z("5S`%=I<R!G96)R=6EK97(`5VES(&=E8G)U:6ME<G-D871A
M`$QA=&4@;W!K;&%R:6YG96X`2VQI:R!O;2!V97)D97(@=&4@9V%A;@!#;&EC
M:V%T96QL('9I82!(5%10`%-L=6ET('-C:&5R;0!7;VQK96X`5G)O96=E(&)E
M=V]L:VEN9P!"97=O;&MT`$-O8V]S("A+965L:6YG*2!E:6QA;F1E;@!::6IB
M86QK(&EN:VQA<'!E;@!);F=E:VQA<'1E(')A;F1E;@!#;VQO;6)I80!+;&5U
M<@!+;&5U<F5N:VEE>F5R`$ML975R<V5L96-T:64`2V]L;VUM96XZ`$MO;&]M
M=&ET96QS`%-T<FEP<P!/<&1R86-H=`!/<&1R86-H='-H96QL`$]P;65R:VEN
M9P!!;&=E;65N92!N86%M`$-O;6]R96X`0F5D<FEJ9@!#;VUP=71E<G,`0V]N
M9&ET:64`0V]N9&ET:65S`%9E<G-C:&EL;&5N(&EN(&-O;F9I9W5R871I90!#
M;VYF:6=U<F%T:64@=F]O<B!H970@<WEN8VAR;VYI<V5R96X@;65T(%!$02=S
M+"!3;6%R='!H;VYE<R!E;B!/=71L;V]K+@!#;VYF:6=U<F%T:64@:7,@=F5R
M;W5D97)D+@`E<R!C;VYF:6=U<F5R96X`0F5V97-T:6<@=V%C:'1W;V]R9`!+
M;VYG;P!+;VYG;RP@1&4@1&5M;V-R871I<V-H92!297!U8FQI96L@=F%N(&1E
M`%9E<F)I;F1I;F<@;6ES;'5K="X`5F5R8FEN9&EN9R!M:7-L=6MT.B``5F5R
M8FEN9&EN9RP@;65T(&1E(&]P96YB87)E('-L975T96QS97)V97(L(&ES(&=E
M=V5I9V5R9"X`5F5R8FEN9&EN9RP@;65T(&1E(&]P96YB87)E('-L975T96QS
M97)V97(L(&ES(&=E=V5I9V5R9"X@4F5D96XZ("5S("@E<RD`5F5R8FEN9&EN
M9R!M970@1E10('-E<G9E<B!M:7-L=6MT+@!!9')E<W-E;@!!9')E<W-E;B!Z
M:6IN(&UE="!S=6-C97,@86%N('5W(&%D<F5S8F]E:R!T;V5G979O96=D+@!#
M;VYT96YT('1Y<&4@=F%N(&=E8V]M<')I;65E<F0@8F5S=&%N9#H@`$EN:&]U
M9"!V86X@(B5S(@!$;V]R9V%A;@!#;V]K(&5I;&%N9&5N`$-O;VMI90!+;W!I
MZW)E;@!+;W!IZW)E;B!M:7-L=6MT.B`E<P!+;W!I965R('-E;&5C=&EE`$MO
M<W1E;B!)1`!#;W-T82!2:6-A`$EV;V]R:W5S=`!+;VX@4$=0(&)E<FEC:'0@
M;FEE="!C;V1E<F5N.B``2V]N(%!'4"!B97)I8VAT(&YI970@;VYD97)T96ME
M;F5N.B``2V]N(&)E<FEC:'0@;FEE="!3+TU)344@8V]D97)E;BX`2V]N(&)E
M<FEC:'0@;FEE="!3+TU)344@;VYD97)T96ME;F5N+@!+;VX@861R97,@)7,@
M;FEE="!T;V5V;V5G96XN`$MO;B!G965N('9E<F)I;F1I;F<@;65T(&1E($Q$
M05`M<V5R=F5R(&UA:V5N+@!+;VX@=&5G;V5D("5S(&YI970@8V]N=')O;&5R
M96XN`$MO;B!N:65T('9E<F)I;F1E;B!M970@3$1!4"!S97)V97(N`$MO;B!N
M:65T('9E<F)I;F1E;B!M970@<V5R=F5R("(E<R(@;65T($944#H@)7,`2V]N
M(&=E96X@9&ES=')I8G5T:65L:6IS="`E<R!M86ME;BX`2V]N(%!'4"!D871A
M(&YI970@9&5C;V1E<F5N.B``2V]N(%,O34E-12!D871A(&YI970@9&5C;V1E
M<F5N+@!+;VX@861R97,@)7,@;FEE="!V97)W:6ID97)E;BX`2V]N(&1I<W1R
M:6)U=&EE;&EJ<W0@)7,@;FEE="!V97)W:6ID97)E;BX`2V]N('-E='5P('5P
M9W)A9&4@<V-R:7!T("(E<R(@;FEE="!V97)W:6ID97)E;BX`2V]N(&AE="!E
M+6UA:6QA9')E<R!V86X@9&4@;VYT=F%N9V5R(&YI970@8F5P86QE;BX`2V]N
M(&-O;7!L971E(&%D<F5S8F]E:R!N:65T(&]P:&%L96XN`$MO;B!C;VUP;&5T
M92!D:7-T<FEB=71I96QI:G-T(&YI970@;W!H86QE;BX`2V]N(&-O;7!L971E
M(&QI:G-T('9A;B!D:7-T<FEB=71I96QI:G-T96X@;FEE="!O<&AA;&5N+@!+
M;VX@<W1R871E9VEE("(E<R(@;FEE="!L861E;BX`2V]N(&1I<F5C=&]R>2`B
M)7,B(&YI970@;6%K96XN`$MO;B!D92!O<&5N8F%R92!S;&5U=&5L(&YI970@
M=F5R:W)I:F=E;B!V86X@9&4@<VQE=71E;'-E<G9E<BX`2V]N("(E<R(@;FEE
M="!O<&5N96X@=F]O<B!S8VAR:6IV96XN`$MO;B`E<R!N:65T(&]P96YE;BX`
M2V]N(&]N9&5R:&]U9'-T86ME;FUO9'5L92`E<R!N:65T(&]P96YE;@!+;VX@
M9&ER96-T;W)Y("(E<R(@;FEE="!O<&5N96XN`$MO;B!D92!,1$%0+7-E<G9E
M<B!N:65T(&)E<F5I:V5N+@!+;VX@)7,@;FEE="!L97IE;BX`2V]N(&AE="!W
M86-H='=O;W)D('9A;B!D92!G97=E;G-T92!G96)R=6EK97(@;FEE="!R97-E
M='1E;BX@4V]M;6EG92!O9B!A;&QE(&1E=&%I;',@>FEJ;B!N:65T(&IU:7-T
M+B!0<F]B965R(&]P;FEE=7<@;V8@;F5E;2!C;VYT86-T(&]P(&UE="!D92!S
M>7-T965M8F5H965R9&5R+"!W86YN965R('4@=F5R9&5R92!H=6QP(&YO9&EG
M(&AE969T+@!+;VX@04-,(&YI970@;W!H86QE;@!+;VX@861R97-B;V5K("5S
M(&YI970@;W!H86QE;BX`2V]N(&1I<W1R:6)U=&EE;&EJ<W0@)7,@;FEE="!O
M<&AA;&5N+@!+;VX@9&ES=')I8G5T:65L:6IS=&5N("5S(&YI970@;W!H86QE
M;BX`2V]N('-E<G9E<F)E:W=A86UH961E;B!N:65T(&]P:&%L96X`2V]N(&-O
M;F9I9W5R871I92!N:65T('1E<G5G>F5T=&5N+@!+;VX@9&ER96-T;W)Y("(E
M<R(@;FEE="!V97)W:6ID97)E;BX`2V]N(&-O;F9I9W5R871I92`E<R!N:65T
M(&]P<VQA86XN`$MO;B!G965N(&)A8VMU<&-O;F9I9W5R871I92!O<'-L86%N
M+@!+;VX@9V5E;B!B86-K=7!C;VYF:6=U<F%T:64@;W!S;&%A;CH@)7,`2V]N
M('-E='5P('5P9W)A9&4@<V-R:7!T(&YI970@;W!S;&%A;B!A;',Z("(E<R(N
M`$MO;B!H970@8F%C:W5P8V]N9FEG=7)A=&EE8F5S=&%N9"!N:65T(&]P<VQA
M86X@)7,N`$MO;B!H970@8V]N9FEG=7)A=&EE8F5S=&%N9"`E<R!N:65T(&]P
M<VQA86XN(%4@:W5N="!O9B#KZVX@=F%N(&1E(&]P=&EE<R!G96)R=6EK96X@
M;VT@9&4@8V]D92!T97)U9R!O<"!T92!S;&%A;B!O<"`E<R!O9B!O;F1E<G-T
M86%N9&4@8V]D92!H86YD;6%T:6<@;F%A<B`E<R!K;W!IZW)E;BX`2V]N(&1E
M($Q$05`M<V5R=F5R(&YI970@9&]O<GIO96ME;BX`2V]N("(E<R(@;FEE="!L
M;W-K;W!P96QE;BX`2V]N(&%D<F5S("5S(&YI970@8FEJ=V5R:V5N+@!+;VX@
M9&ES=')I8G5T:65L:6IS="`E<R!N:65T(&)I:G=E<FME;BX`2V]N(&-O;F9I
M9W5R871I92!V;V]R("(E<R(@;FEE="!W96=S8VAR:6IV96XZ("5S`$MO;B!D
M92!-;WII;&QA(%-I9&5B87(@;FEE="!V:6YD96XN(%IO<F<@97)V;V]R(&1A
M="!D92!S:61E8F%R(&]P96X@:7,N`$MO;B!G96)R=6EK97(@(B5S(B!D92!V
M;VQG96YD92!R96-H=&5N(&]P(&1E(&UA<"`B)7,B(&YI970@9V5V96XZ("5S
M`$=E=&5L9&4@=&5K<W0`3&%N9`!#=7)S=7-S96X`36%K96X`36%A:R!E96X@
M;&EN:P!-86%K(&5E;B!N:65U=V4`36%A:R!S=6)M87!P96X`16EG96YA87)R
M96-H=&5N`$-R961I=&-A<F1N=6UM97(`2W)O871IZP!#=6)A`$AU:61I9V4@
M-"!F87-E;@!(=6ED:6=E('-E<W-I97,`2'5I9&EG92!T:6ID`$AU:61I9V4@
M55),(&ES`$AU:61I9V4@9V5B<G5I:V5R<P!(=6ED:6<@=V5E<@!(=6ED:6=E
M(&-O;F1I=&EE.B``2'5I9&EG92!S=&EJ;`!!86YP87-S96X@=F%N('1A:V5N
M('1I:F1E;G,@86%N;65L9&EN9R!B:6H@)7,N`$MN:7!P96X`4V5L96-T:64@
M:VYI<'!E;@!#>7!R=7,`0WER:6QL:7-C:"`H2T])."U2*0!#>7)I;&QI<V-H
M("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&ES8V@O56MR86EN<R`H2T])."U5*0!4
M<VIE8VAI<V-H92!297!U8FQI96L`1$0`1%-.("AZ:64@:'1T<#HO+W!E87(N
M<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD
M<VXN<&AP*0!$86=E;&EJ:W,`1&%T851R964@8G)O=W-E<@!$871A8F%S92!D
M;V]R>F]E:V5N`$1A='5M`$1A='5M($]N='9A;F=E;@!$871U;2!S96QE8W1I
M90!$86<`5F5R7W=I:F1E<B!K;VQO;0!$96-E;6)E<@!$96-I;6%L92!G971A
M;&QE;@!);G-P<FEN9V5N('9E<FML96EN96X`4W1A;F1A87)D`%-T86YD86%R
M9"!K;&5U<@!3=&%N9&%A<F0@:61E;G1I=&5I=`!3=&%N9&%A<F0@<VAE;&P`
M1&5F:6YI=&EE<P!697)W:6ID97)E;@!697)W:6ID97(@8V5L`$=R;V5P('9E
M<G=I:F1E<F5N`%9E<G=I:F1E<B!L;V<`4F5C:'0@=F5R=VEJ9&5R96X`5F5R
M=VEJ9&5R(&5N('=I<R!B97)I8VAT96X`5F5R=VEJ9&5R(&-E;`!697)W:6ID
M97(@:V]L;VT`0F5S=&%A;F0@86QT97)N871I968@<VIA8FQO;VX@=F5R=VEJ
M9&5R96X`5F5R=VEJ9&5R(&)E<FEC:'1E;@!296-H=&5N('9A;B`B)7,B('9E
M<G=I:F1E<F5N`%)E8VAT96X@96X@979E;G1U96QE('-U8G)E8VAT96X@=F]O
M<B`B)7,B('9E<G=I:F1E<F5N/P!697)W:6ID97(@<FEJ`$=E<V5L96-T965R
M9&4@:61E;G1I=&5I="!V97)W:6ID97)E;@!697)W:6ID97(@<W5B;6%P<&5N
M`%9E<G=I:F1E<B!D92!H=6ED:6=E(&MO;&]M`%9E<G=I:F1E<B!D92!H=6ED
M:6=E(')I:@!3971U<"!U<&=R861E('-C<FEP="`B)7,B('9E<G=I:F1E<F0N
M`$%F;&5V97)T:6ID`$1E;F5M87)K96X`0F5S8VAR:6IF(&AE="!P<F]B;&5E
M;0!"97-C:')I:G9I;F<`1&5T86EL<R`H;V]K(&EN($AO<F1E)W,@;&]G8F5S
M=&%N9"DZ`$1E=&%I;',@>FEJ;B!G96QO9V0@=F]O<B!D92!S>7-T965M8F5H
M965R9&5R+@!/;G1W:6MK96QI;F<`1&%U=W!U;G0`1&%U=W!U;G0@=F]O<B!H
M970@869G96QO<&5N('5U<CH@`$1A=7=P=6YT.B``4FEC:'1I;F<@;&EN:W,@
M;F%A<B!R96-H=`!2:6-H=&EN9R!R96-H=',@;F%A<B!L:6YK<P!$:7)E8W1O
M<GD`,C0M=75R<R!T:6ID=V5E<F=A=F4_`%=E97)G879E;W!T:65S`$=E9&5T
M86EL;&5E<F1E('=E97)S=F]O<G-P96QL:6YG('1O;F5N`%=E97)S=F]O<G-P
M96QL:6YG('1O;F5N("A4048I`%=E97)G879E9F]R;6%A=`!6;V]R8F5R96ED
M:6YG<VYO=&EF:6-A=&EE`$1J:6)O=71I`$YI970@=F5R=VEJ9&5R96X`;6%I
M;G1E;F%N8V4N<&AP(&YI970@9&ER96-T(&%A;G-P<F5K96X`0F5V870@9&4@
M965R<W1E(')I:B!D92!V96QD;F%M96X_(%IO(&IA+"!D:70@:&]K:F4@86%N
M=FEN:V5N.@!$;VUI;FEC80!$;VUI;FEC86%N<V4@4F5P=6)L:65K`$=E96X@
M86-C;W5N=#\@4V-H<FEJ9B!U(&EN+@!$;W=N;&]A9&5N`"5S(&1O=VYL;V%D
M96X`1&]W;FQO860@9V5G96YE<F5E<F1E(&-O;F9I9W5R871I92!A;',@4$A0
M('-C<FEP="X`1')O<"!D;W=N(&QI:G-T`$1R=6=S`$4M36%I;`!%+6UA:6P@
M;F%A<B!335,@9V%T97=A>2!S='5U<G!R;V=R86UM82P@=F]O<B!D<F%G97)S
M(&1I92!D97IE('-E<G9I8V4@;VYD97)S=&5U;F5N+@!%4E(`16-U861O<@!"
M97=E<FME;@!";&]K(&)E=V5R:V5N`$=R;V5P(&)E=V5R:V5N`%)E8VAT(&)E
M=V5R:V5N`%)E8VAT96X@8F5W97)K96X`4F5C:'1E;B!V86X@)R5S)R!B97=E
M<FME;@!/<'1I97,@8F5W97)K96X@=F]O<CH`4F5C:'1E;B!V86X@(B5S(B!B
M97=E<FME;@!296-H=&5N('9A;B`E<R!B97=E<FME;@!/;F1E<G=I:G,`16=Y
M<'1E`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`12UM86EL`$4M;6%I;&%D
M<F5S`$4M;6%I;&%D<F5S<V5N(&UO971E;B!O=F5R965N:V]M96XN`$4M;6%I
M;"!M970@8F5V97-T:6=I;F<`12UM86EL(&YA87(@4TU3(&=A=&5W87D`16UO
M=&EC;VYS`$QE96<@8F5R:6-H="X`1V5E;B!R97-U;'1A870N`$QE9V4@>F]E
M:W1E<FUE;@!);G9O96=E;B!V86X@869B965L9&EN9V5N('5I="!F;W1O86QB
M=6US(&EN('1E:W-T(&EN<V-H86ME;&5N/P!296-H=&ML:6MK96X@8V]N=&5X
M="!M96YU(&EN<V-H86ME;&5N/P!%:6YD:F%A<@!697)G<F]O="!E9&ET;W(`
M1V5E9B!E96X@8F5V96EL:6=I;F=S=G)A86<@9&EE('4@9V5V<F%A9V0@=V]R
M9'0L('=A;FYE97(@:&5T(&YO9&EG(&ES(&]M('5W('=A8VAT=V]O<F0@=&4@
M<F5S971T96XL(&(N=BX@)W=A="!I<R!D92!N86%M('9A;B!U=R!H=6ES9&EE
M<C\G.@!6;V5R(&1E(&%F8F5E;&1I;F<@55),(&AI97(@:6X`5F]E<B!O;F1E
M<G-T86%N9&4@;&5T=&5R<R!I;CH`17%U871O<FEA86P@1W5I;F5E`$5R:71R
M96$`1F]U=`!&;W5T(&)I:B!M86ME;B!V86X@8FQO:SH@)7,`1F]U="!B:6H@
M=F5R=VEJ9&5R96X@=F%N('-Y;F,@86YK97(Z("5S`$9O=70@8FEJ('9E<G=I
M:F1E<F5N('9A;B!S>6YC(&QO9SH@)7,`1F]U="!B:6H@;W!H86QE;B!V86X@
M:6YH;W5D.B`E<P!&;W5T(&)I:B!B:6IW97)K96X@=F%N('=A8VAT=V]O<F0Z
M("5S`$9O=70@;65T(&4M;6%I;&)E<FEC:'0N`$9O=70@8FEJ('-C:')I:G9E
M;B!V86X@(B5S(BX`17-T;&%N9`!%=&AI;W!IZP!%=&YI<V-H`$5U<F]P80!%
M;&ME(#$U(&UI;G5T96X`16QK92`R(&UI;G5T96X`16QK92`S,"!S96-O;F1E
M;@!%;&ME(#4@;6EN=71E;@!%;&ME(&%A;FUE;&1I;F<`16QK(&AA;&8@=75R
M`$5L:V4@;6EN=75T`%9O;W)B965L9'=A87)D96XZ`%5I='9O97)E;@!5:71K
M;&%P<&5N`%II:F)A;&L@=6ET:VQA<'!E;@!697)W86-H='1E("<I)P!697)W
M86-H='1E(&5N:V5L('=O;W)D(&]F(&%A;F=E:&%A;&1E('IO96MT97)M`%9E
M<G9A;&1A='5M`$5X<&]N96YT`%9O;W)G<F]N9&ML975R`$944"!U<&QO860@
M=F%N('-E='5P`$]P:&%L96X@=F]O<FME=7)S:6YS=&5L;&EN9V5N(&UI<VQU
M:W0N`%9E<F)I;F1I;F<@;65T(&1E($Q$05`M<V5R=F5R(&ES(&UI<VQU:W0N
M`%9E<F)I;F1I;F<@;65T(&1E(%--0BUS97)V97(@:7,@;6ES;'5K="X`2V]P
M:>MR96X@=6ET("(E<R(@:7,@;6ES;'5K="X`2V]P:>MR96X@;F%A<B`B)7,B
M(&ES(&UI<VQU:W0N`$UA:V5N('9A;B!N:65U=V4@4T%33"!V97)B:6YD:6YG
M(&ES(&UI<VQU:W0N`%9E<G!L86%T<V5N(&YA87(@(B5S(B!I<R!M:7-L=6MT
M+@!/<&AA;&5N('9A;B`E<R!I<R!M:7-L=6MT`$UO;VD`1F%L:VQA;F0@96EL
M86YD96X@*$UA;'9I;F%S*0!&87)OZW(@96EL86YD96X`1F%T86QE(&9O=70Z
M`$9A>`!&87AE;@!&96)R=6%R:0!6;V5L="!A;',`5F]E;'0@86QS.B``16YK
M96QE(&)U:65N`$5N:6=E('-N965U=V)U:65N`%9E;&1M871R:7@`1FEG;&5T
M($-!4%1#2$$`1FEG;&5T(&9O;G0`1FEJ:0!"97-T86YD`$%A;G1A;"!B97-T
M86YD96XZ("5S(&)E<W1A;F0`06%N=&%L(&)E<W1A;F1E;CH@)7,@8F5S=&%N
M9&5N`$)E<W1A;F1B96AE97(`0F5S=&%N9'-N86%M`$)E<W1A;F0@:VEE>F5N
M`$)E<W1A;F1U<&QO860`0F5S=&%N9'5P;&]A9',@=V]R9&5N(&YI970@;VYD
M97)S=&5U;F0N`$9I;'1E<G,`1FEN;&%N9`!%97)S=&4@:&5L9G0`165R<W1E
M(&MW87)T86%L`%9E<FAO=61I;F<@:&5R<W1E;&QE;@!/;6ME<F5N`$1R:6IV
M96X`36ES=`!-87`@)7,@8F5S=&%A="!N:65T`$9O;G1K;&5U<@!6;V5D<V5L
M`%9O;W(@8G)O=W-E<G,@9&EE(&=E96X@869B965L9&EN9V5N(&]N9&5R<W1E
M=6YE;@!7965R<W9O;W)S<&5L;&EN9R`H5$%&*0!6;V]R=6ET>FEC:'1D86=E
M;B`H;65R:R!O<"!D870@:&5T(&=E9V5V96X@=F]O<G5I='II8VAT(&1A9V5N
M(&5N(&YA8VAT96X@9V5E9G0[(&5E;B!G<F]O="!A86YT86P@:V%N(')E<W5L
M=&5R96X@:6X@965N(&)R965D(&)L;VLI`%5W('=A8VAT=V]O<F0@=F5R9V5T
M96X_`$9O<FUU;&EE<F5N`$9O<G1U;F4`1F]R='5N971Y<&4`1F]R='5N97,`
M1F]R='5N97,@,@!&;W)U;7,`1&]O<G-T=7)E;@!6<@!&<F%M97,`1G)A;FMR
M:6IK`$9R86YK<FEJ:RP@2&]O9F1S=&5D96QI:FL`1G)A;G,@1W5Y86YA`$9R
M86YS(%!O;'EN97-IZP!&<F%N<V4@6G5I9&5L:6IK92!497)R:71O<FEA`%9A
M;@!686X@9&4@`%9O;&QE9&EG92!B97-C:')I:G9I;F<`5F]L;&4@;6%A;@!6
M;VQL961I9V4@;F%A;0!'86)O;@!!;&)U;2!W86%R=6ET(&1E(&%F8F5E;&1I
M;F<@9V5H86%L9"!D:65N="!T92!W;W)D96X`06QB=6TZ`$=A;6)I80!'96YE
M<F5E<B`E<R!C;VYF:6=U<F%T:64`1V5G96YE<F5E<F1E(&-O9&4`1V5O<F=I
MZP!$=6ET<VQA;F0`1VAA;F$`1VEB<F%L=&%R`%9O;W)N86%M`$=L;V)A;&4@
M;W!T:65S`$=A`$=O961E;`!';V]G;&4@:V%A<G1E;@!';V]G;&4@>F]E:V5N
M`$=R:6IS<V-H86%L`$=R:65K96YL86YD`$=R:65K<R`H25-/+3@X-3DM-RD`
M1W)O96YL86YD`$=R96YA9&$`1W)O97!S8F5H965R`$=R;V5P;F%M96X@;6]G
M96X@;FEE="!L965G('II:FX`1W)O=7!?;&1A<#H@3FEE="!I;B!S=&%A="!G
M<F]E<"`E<R!T;V4@=&4@=F]E9V5N+B!$92!S97)V97(@;65L9'0Z(`!'<F]U
M<%]L9&%P.B!.:65T(&EN('-T86%T(&=R;V5P("5S('1E('9E<G=I:F1E<F5N
M`$=R;W5P7VQD87`Z($YI970@:6X@<W1A870@9W)O97`@)7,@8FEJ('1E('=E
M<FME;@!'<F]E<&5N`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS
M97D`1V%S="!R96-H=&5N`$=A<W1E;F)O96L`1W5I;F5E`$=U:6YE92U":7-S
M874`1W5Y86YA`$A434P`2%1-3$%R96$@=V5I9V5R="!L868@;VT@9&4@;&%A
M='-T92!C96P@:6X@9&4@<FEJ('1E('9E<G=I:F1E<F5N+@!(5$U,07)E82!W
M96EG97)T(&QA9B!O;2!D92!L86%T<W1E(&MO;&]M(&EN(&1E('1A8F5L('1E
M('9E<G=I:F1E<F5N+@!(5$U,07)E82!W96EG97)T(&QA9B!O;2!D92!L86%T
M<W1E(')I:B!I;B!D92!T86)E;"!T92!V97)W:6ID97)E;BX`2%144"!A=71H
M96YT:6-A=&EE(&YI970@9V5V;VYD96XN`$AA:71I`$AA<V@M86QG;W)I=&AM
M90!.979E;`!+;W``2V]P<&5N`$AE87)D(&5I;&%N9"!E;B!-8T1O;F%L9"!E
M:6QA;F1E;@!:=V%R92!O;G=E97)S8G5I`$AE8G)E975W<R`H25-/+3@X-3DM
M."U)*0!(;V]G=&4`2&5L<`!(96QP(&)I:B!G96)R=6EK('9A;B!E9&ET;W(`
M2&5L<&5R`$AA;&9R;VYD`$AI97(@:7,@:&5T(&)E9VEN('9A;B!H970@8F5S
M=&%N9#H`2&]O9P!(;U]M90!(;VQY(%-E92`H5F%T:6-A86YS=&%D*0!(;VUE
M`$%D<F5S("AP<FEVZ2D`2&]M961I<F5C=&]R>0!496PN;G(N("AP<FEVZ2D`
M2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!/;F=E;&1I
M9V4@)7,@6$U,(&1A=&$@=&5G96YG96MO;65N(&EN(&)E<FEC:'0@)7,`2&]R
M9&4O2V]L86(Z($=E96X@8F5R:6-H="!C;W)R97-P;VYD965R="!M970@;V)J
M96-T("5S`$AO<F1E+TMO;&%B.B!'965N(&]B:F5C="!V86X@='EP92`E<R!G
M979O;F1E;B!I;B!B97)I8VAT("5S`$AO<F1E+TMO;&%B.B`E<R!M970@<W5C
M8V5S('9E<G=I:F1E<F0@(B5S(@!(;W)D92]+;VQA8CH@1&4@:6YT97)G<F%T
M:64@=F5R96ES="!D92`G9&]M>&UL)R!E>'1E;G-I90!(;W)D92]+;VQA8CH@
M2V%N(&=E96X@;FEE=7=E(%A-3"!B;V]M(&UA:V5N('9O;W(@;V)J96-T("5S
M`$AO<F1E+TMO;&%B.B!+86X@)7,@(B5S(B!N:65T('9E<G=I:F1E<F5N.B`E
M<P!(;W)D92]+;VQA8CH@3FEE="!I;B!S=&%A="!H970@34E-12!)1"P@=F]O
M<B!H970@9V5D965L=&4@;65T('1Y<&4@)7,L(&]P('1E(&AA;&5N`$AO<F1E
M+TMO;&%B.B!+86X@)7,@(B5S(B!N:65T('-Y;F-H<F]N:7-E<F5N.B`E<P!(
M;W)D92]+;VQA8CH@2V%N(&=E9&5E;&1E(&)R;VYN96X@;FEE="!S>6YC:')O
M;FES97)E;CH@)7,`2&]R9&4O2V]L86(Z($]N8F5K96YD92!G961E96QD92!B
M<F]N("(E<R(`2&]R:7IO;G1A;&4@;&EJ;@!(;W)I>F]N=&%L92!V<FEJ92!R
M=6EM=&4`2&]R:7IO;G1A86PZ`$AO92!K=V%M('4@:&EE<C\@*$=R86%G(')A
M<'!O<G1A9V4A*0!(;V5V965L(&MO;&]M;65N('=I;'0@=2!S86UE;G9O96=E
M;C\`2&]E=F5E;"!V96QD96X@*&MO;&]M;65N*2!Z:6IN(&5R/P!(;V5V965L
M(')I:F5N('=I;'0@=2!S86UE;G9O96=E;C\`5F]C:'1I9VAE:60`5F]C:'1I
M9VAE:60Z(`!(=6UO<FES=&5N`$AO;F=A<FEJ90!-86ME;B!V86X@24U!4"!M
M86EL8F]X(&UI<VQU:W0Z("5S`%9E<G=I:F1E<F5N('9A;B!)34%0(&UA:6QB
M;W@@;6ES;'5K=#H@)7,`36%K96X@=F%N($E-05`@;6%I;&)O>"!Q=6]T82!M
M:7-L=6MT.B`E<P!)4"!!9')E<P!)4"!A9')E<R!N:65T(&)E<V-H:6MB86%R
M+@!)4"!A9')E<R!V86QT(&YI970@8FEN;F5N(&AE="!T;V5G97-T86YE($-)
M1%(@8FQO:RX`25`@;&]C:V1O=VX@;W9E<G1R961I;F<N`%)I:B!I7VYV;V5G
M96X@=F]O<@!)2G-L86YD`$%L;&5E;B!P:6-T;V=R86UM96X`4&EC=&]G<F%M
M;65N('9O;W(@)7,`4&EC=&]G<F%M;65N(&UE="!T96MS=`!)9&5N=&ET96ET
M<VYA86TZ`%=A;FYE97(@:&5T(&YI970@9V]E9"!W;W)D="!W965R9V5G979E
M;BP@)7,@;VT@:&5T(&EN(&5E;B!N:65U=R!S8VAE<FT@=&4@;W!E;F5N+@!!
M;',@=2!G965N('!I8W1O9W)A;6UE;B!Z:65T+"!B:6H@9V5B<G5I:R!V86X@
M26YT97)N970@17AP;&]R97(L(&MA;B!H970@;F]D:6<@>FEJ;B!D:70@=F%K
M:F4@86%N('1E('9I;FME;B!O;2!03D<@=')A;G-P87)A=&EE('5I="!T92!S
M8VAA:V5L96XN`%=A;FYE97(@=2!D:70@8F5R:6-H="!Z:65T+"!M86%R(&=E
M96X@869B965L9&EN9RP@9&%N(&MA;B!D92!A9F)E96QD:6YG(&1I92!U('=I
M;'0@=7!L;V%D96X@;FEE="!D;V]R('5W(&)R;W=S97(@=V]R9&5N('=E97)G
M96=E=F5N+@!!9F)E96QD:6YG<V)E;V]R9&5L:6YG.@!!9F)E96QD:6YG(%52
M3`!!9F)E96QD:6YG(%523#H`069B965L9&EN9R!U:70@86QB=6T`069B965L
M9&EN9R!U:70@86QB=6TZ`$%F8F5E;&1I;F=S=7!L;V%D`$%F8F5E;&1I;F=E
M;@!);7!O<G1E<F5N+"!S=&%P("5D`$=E:6UP;W)T965R9"!V96QD.B`E<P!'
M96EM<&]R=&5E<F1E('9E;&1E;CH`4FEJ(&EN=F]E9V5N(&YA`$]N:G5I<W1E
M(&)E=V5R:VEN9W-C;V1E(&]P9V5G979E;BX`3VYJ=6ES=&4@9V5B<G5I:V5R
M<VYA86T@96XO;V8@=V%C:'1W;V]R9"X`3VYJ=6ES=&4@9V5B<G5I:V5R<VYA
M86T@;V8@86QT97)N871I968@861R97,N(%!R;V)E97(@;W!N:65U=R!O9B!N
M965M(&-O;G1A8W0@;W`@;65T(&1E('-Y<W1E96UB96AE97)D97(L('=A;FYE
M97(@=2!V97)D97)E(&AU;'`@;F]D:6<@:&5E9G0N`%9E<F=R;V]T(&EN<W!R
M:6YG:6YG`$EN9&EA`$EN9&EV:61U96QE(&=E8G)U:6ME<G,`26YD;VYE<VGK
M`$EN9F\`26YF;W)M871I90!);F9O<FUA=&EE(&YI970@;&%N9V5R(&)E<V-H
M:6MB86%R+@!+;VQO;2!I;G9O96=E;B!N80!!9F)E96QD:6YG(&EN=F]E9V5N
M`%1A8F5L(&EN=F]E9V5N`%=E8FQI;FL@:6YV;V5G96X`7TMO;&]M(&EN=F]E
M9V5N('9O;W(`165N(&YI975W92!K;VQO;2!I;G9O96=E;B!N82!D92!H=6ED
M:6=E`$5E;B!N:65U=V4@:V]L;VT@:6YV;V5G96X@=F]O<B!D92!H=6ED:6=E
M`$5E;B!N:65U=V4@<FEJ(&EN=F]E9V5N(&YA(&1E(&AU:61I9V4`165N(&YI
M975W92!R:6H@:6YV;V5G96X@;F$@9&4@:'5I9&EG90!%96X@;FEE=7=E('!A
M<F%G<F%A9B!I;G9O96=E;B!N82!D92!H=6ED:6=E(&YO9&4`165N(&YI975W
M92!P87)A9W)A868@:6YV;V5G96X@;F$@9&4@:'5I9&EG92!N;V1E`$%L=&5R
M;F%T:65F('-J86)L;V]N(&EN=F]E9V5N`$5E;B!E+6UA:6QA9')E<R!I;G9O
M96=E;BP@=V%A<B!U(&AE="!N:65U=V4@=V%C:'1W;V]R9"!K86X@;VYT=F%N
M9V5N.@!#96P@:6YV;V5G96X@;F$`0V5L(&EN=F]E9V5N('9O;W(`2V]L;VT@
M:6YV;V5G96X@;F$`2V]L;VT@:6YV;V5G96X@=F]O<@!"97)I8VAT96X@:6YV
M;V5G96X`4&%R86=R86%F(&EN=F]E9V5N(&YA`%!A<F%G<F%A9B!I;G9O96=E
M;B!V;V]R`%)I:B!I;G9O96=E;B!N80!2:6H@:6YV;V5G96X@=F]O<@!(970@
M9V5W96YS=&4@86YT=V]O<F0@=F]O<B!D92!B979E:6QI9VEN9W-V<F%A9R!I
M;G9O96=E;CH`069B965L9&EN9R!I;G9O96=E;B]A86YP87-S96X`3&EN:R!I
M;G9O96=E;B]A86YP87-S96X`3VYV;VQD;V5N9&4@:W)E9&EE="!O;2!N86%R
M(&1E(&1I<W1R:6)U=&EE;&EJ<W0@=&4@>F5N9&5N+@!/;G9O;&1O96YD92!K
M<F5D:65T`$EN=&5G97(`26YT96=E<B!L:6IS=`!/;F=E;&1I9V4@541(+B`H
M57-E<B!$871A($AE861E<BDN`$]N9V5L9&EG92!:25`@9&%T80!/;F=E;&1I
M9V4@=&]E<&%S<VEN9RX`3VYG96QD:6<@8F%T8V@@240N`$]N9V5L9&EG92!D
M871A(&]P9V5G979E;BX`3VYG96QD:6<@8F5S=&5M;6EN9V%D<F5S+@!/;F=E
M;&1I9R!T:6ID9F]R;6%A=`!/;F=E;&1I9V4@;&EC96YT:65S;&5U=&5L+@!/
M;F=E;&1I9V4@;&]C871I92!O<&=E9V5V96XN`$]N9V5L9&EG(&US9U]T>7!E
M+@!/;F=E;&1I9R!O9B!O;G1B<F5K96YD(&%P:5]I9"X`3VYG96QD:6=E(&]F
M(&]N=&)R96ME;F1E('!A<F%M971E<G,N`$]N9V5L9&EG('!A<F5N="!R96-H
M="X`3VYG96QD:6<@<&%R=&YE<B!I9"X`3VYG96QD:6=E('!R;V1U8W1I96-O
M9&4N`$]N9V5L9&EG('!R;W1O8V]L+@!/;F=E;&1I9V4@;VYT=F%N9V5R.B`B
M)7,B`$]N9V5L9&EG92!G961E96QD92!B<F]N`$]N9V5L9&EG(&)R;VYA9')E
M<RX`3VYG96QD:6=E('5N:6-O9&4@9&%T82X`26YV96YT87)I<P!396QE8W1I
M92!O;6ME<F5N`$ER86XL($ES;&%M:71I<V-H92!297!U8FQI96L@=F%N`$ER
M86L`265R;&%N9`!%:6QA;F0@36%N`$=E:7-O;&5E<F1E(&]N=V5E<G-B=6EE
M;@!)<W)AZVP`56ET9V5V97(`0W5R<VEE9@!)=&%L:>L`2F%M86EC80!*86YU
M87)I`$IA<&%N`$IA<&%N<R`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86YI
MZP!*=6QI`$IU;FD`=6ET;&EJ;F5N`$=E8V5N=')E97)D('5I=&QI:FYE;@!6
M;VQL961I9R!U:71L:6IN96X`3&EN:W,@=6ET;&EJ;F5N`%)E8VAT<R!U:71L
M:6IN96X`2V%Z86-H<W1A;@!/<FEG:6YE96P@8F5H;W5D96X_`$ME;FEA`$ME
M<F)E<F]S('-E<G9E<B!W96EG97)D92!A=71H96YT:6-A=&EE+@!+97)N96P@
M3F5W8FEE<P!3;&5U=&5L(&UA:V5N`%-L975T96QV:6YG97)A9F1R=6L`4VQE
M=71E;&QE;F=T90!3;&5U=&5L='EP90!3;&5U=&5L9V5B<G5I:P!$92!S;&5U
M=&5L(&)E<W1A870@86P@;W`@9&4@;W!E;F)A<F4@<VQE=71E;'-E<G9E<BX`
M2VEN9&5R96X`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:7-C:&4@5F]L:W-R
M97!U8FQI96L@=F%N`$MO<F5A+"!297!U8FQI96L@=F%N`$MO<F5A86YS("A%
M54,M2U(I`$MO97=E:70`2WER9VEE<VGK`$]?<&UA86L`5&%A;`!$96UO8W)A
M=&ES8VAE(%9O;&MS<F5P=6)L:65K($QA;P!,86%T<W1E(&AE;&9T`$QA871S
M=&4@=V%C:'1W;V]R9'=I:GII9VEN9P!,86%T<W1E(&MW87)T:65R`$QA871S
M="!B:6IG97=E<FMT.@!,86%T<W1E(&%A;FUE;&1I;F<Z("5S`$QA871S=&4@
M86%N;65L9&EN9SH@)7,@=F%N("5S`$QA871S=&4@86%N;65L9&EN9SH@3F]O
M:70`3&5T;&%N9`!296-H=&5N`$]P;6%A:P!,86%T(&QE96<@=F]O<B!G965N
M(')A;F0`3&EB86YO;@!,:6YK<P!,:6YK<V4@:V]P`$QI;FMS92!W86%R9&5N
M`$QE<V]T:&\`3FEV96%U`$QI8F5R:6$`3&EB:7-C:&4@07)A8FES8VAE($IA
M;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!:86-H="!B=6ET:F4`3&EC:'1E(')E
M9V5N`%9R;V5G(&QI8VAT92!R96=E;@!,:6-H=&4@<F5G96X`3&EC:'1E(')E
M9V5N8G5I`$QI8VAT92!R96=E;B!M970@;VYW965R`$QI8VAT92!S;F5E=7<`
M3&EC:'1E('-N965U=V)U:0!,:6UE<FEC:P!,:6YK`$QI;FL@=VEJ<W0@;F%A
M<CH`3&EN:R!H970@92UM86EL861R97,@86%N(&1E(&YI975W(&)E<FEC:'0@
M<&%G:6YA('1I:F1E;G,@=V5E<F=A=F4`3&EN:W,`3&EN=7@@0V]O:VEE`$QI
M:G-T("T@9V5B<G5I:V5R(&MA;B!D92!M87`@>FEE;@!$871A8F%S96QI:G-T
M`$QI:G-T('9A;B!H96QP(&]N9&5R9&5L96X`5&%B96QL:6IS=`!,:6IS="U!
M<F-H:65F`$QI:G-T+4AE;'``3&EJ<W0M260`3&EJ<W0M16EG96YA87(`3&EJ
M<W0M4&]S=`!,:6IS="U);G-C:')I:G9E;@!,:6IS="U5:71S8VAR:6IV96X`
M5V5E<F=E=F5N('9A;B!S97-S:65L:6IS="!I<R!M:7-L=6MT.B`E<P!7965R
M9V5V96X@=F%N(&=E8G)U:6ME<G-L:6IS="!I<R!M:7-L=6MT.B`E<P!7965R
M9V5V96X@=F%N(&=E8G)U:6ME<G-L:6IS="!I<R!U:71G97-C:&%K96QD+@!,
M:71E<F%T=75R`$QI=&]U=V5N`$QA9&5N+BXN`$QO:V%L92!T:6ID.@!,86YD
M:6YS=&5L;&EN9R!E;B!T:6ID`$QO8V%T:64`06%N;65L9&5N`$QO9R!V86X@
M=F]O<F=A86YD92!S>6YC('-E<W-I90!!9FUE;&1E;@!!86YM96QD96X`06%N
M;65L9'1A:V5N`$%A;FUE;&1I;F<@;6ES;'5K="!O;61A="!U=R!G96)R=6EK
M97)S;F%A;2!O9B!W86-H='=O;W)D(&]N:G5I<W0@:7,@:6YG979O97)D+@!!
M86YM96QD:6YG(&UI<VQU:W0N`$QA;F=E('1E:W-T`$QI969D90!,86%G`$=R
M:65K<V4@:VQE:6YE(&QE='1E<G,`3&%T:6IN<V4@:VQE:6YE(&QE='1E<G,`
M2VQE:6YE(%)O;65I;G-E(&=E=&%L;&5N`$QU>&5M8G5R9P!-30!-3U1$`$U3
M+51.148@8FEJ;&%G92!B979A='1E(&=E96X@9&%T82X`35-'`$UA8V%O`$UA
M8V5D;VYIZRP@1&4@=G)O96=E<F4@2F]E9V]S;&%V:7-C:&4@4F5P=6)L:65K
M('9A;@!-861A9V%S8V%R`$UA9VEE`$4M;6%I;`!-86EL8F5H965R9&5R`$UA
M86L@;&EN7VLN+BX`36%L87=I`$UA;&5I<VGK`$UA;&%D:79E;@!-86QI`$UA
M;'1A`$)E:&5E<B!U=R!L:6IS="!M970@8V%T96=O<FEEZVX@96X@9&4@8V]R
M<F5S<&]N9&5R96YD92!K;&5U<F5N+"!W86%R;65E(&]N9&5R9&5L96X@=V]R
M9&5N(&=E;&%B96QD`$UA<#(T(&MA87)T`$UA<%%U97-T:V%A<G0`2V]P<&5L
M:6YG96X@;W!G97-L86=E;BX`36%A<G0`36%R9V4`36%R:V5E<B!M970@1V5Z
M:65N+TYI970@1V5Z:65N('9L86=G96X`36%R:V5E<B!M970@86YD97)E('9L
M86=G96X@*&(N=BX@0F5L86YG<FEJ:R]"96%N='=O;W)D*0!-87)C:&%L;"!E
M:6QA;F1E;@!-87)T:6YI<75E`$]V97)E96YK;VUE;F1E('9E;&1E;@!-875R
M971A;FGK`$UA=7)I=&EU<P!-87AI;6%A;"!T;V5G97-T86%N(&MR961I970N
M`$UA>&EM=6T@8F5R:6-H=&]N9&5R9&5L96X@;W9E<G-C:')E9&5N+@!-87AI
M;75M('1E;7!E<F%T=75R('9A;B!D92!A9F=E;&]P96X@,C0@=75R.B``36%X
M:6UU;2!T96UP97)A='5U<B!V86X@9&4@869G96QO<&5N(#8@=75R.B``36%X
M:6UU;2!A86YT86P@<&]R=&%A;&)L;VMK96X`36%X:6UU;2!L96YG=&4`365I
M`$UA>6]T=&4`1V5N965S:W5N9&4`3&5D96X`365N=2!M;V1E.@!#96QL96X@
M<V%M96YV;V5G96X`0F5R:6-H=`!"97)I8VAT(&UE="!S=6-C97,@9V5V97)I
M9FEE97)D+"!M86%R(&AE="!C97)T:69I8V%A="!V86X@9&4@;VYD97)G971E
M:V5N9&4@:V]N(&YI970@=V]R9&5N(&=E=F5R:69I965R9"X`0F5R:6-H="!V
M97)L;W!E;BX`0F5R:6-H='1Y<&4`365T87(@5V5E<@!-151!4B!B;&]K(&ES
M(&YI970@8F5S8VAI:V)A87(N`$U%5$%2(&)L;VL@:7,@;FEE="!B97-C:&EK
M8F%A<BX@1&5T86EL<R!Z:6IN(&=E;&]G9"!V;V]R(&1E('-Y<W1E96UB96AE
M97)D97(N`$UE=&%R1$(@:7,@;FEE="!V97)B;VYD96XN`$UE=&AO9&4`365T
M:&]D92`B)7,B(&ES(&YI970@9V5D969I;FEE97)D`$UE=&AO9&4@:7,@;FEE
M="!G961E9FEN:65E<F0N($%A;F=E<F]E<&5N(&UE=&AO9&4Z("5S`$UE=')I
M<V-H`$UE>&EC;P!-:6-R;VYE<VGK+"!&961E<F%L92!3=&%T96X@=F%N`$UI
M9&1E;@!-:6UE('1Y<&4`36EN:6UU;2!T96UP97)A='5U<B!V86X@9&4@869G
M96QO<&5N(#(T('5U<CH@`$UI;FEM=6T@=&5M<&5R871U=7(@=F%N(&1E(&%F
M9V5L;W!E;B`V('5U<CH@`$UI;FEM=6T@=V%C:'1W;V]R9&QE969T:6ID(&ES
M(&YO9R!N:65T('9E<FQO<&5N`$UI<G)O<@!!;&QE<FAA;F1E`$]N=&)R96ME
M;F1E(%!%05(@;6]D=6QE($A45%!?4F5Q=65S="X`3VYT8G)E:V5N9&4@8V]N
M9FEG=7)A=&EE+B!5(&1I96YT(&1E>F4@;G4@=&4@9V5N97)E<F5N+"!W86YN
M965R('4@9&5Z92!T;V5P87-S:6YG('=I;'0@9V5B<G5I:V5N+@!/;G1B<F5K
M96YD(&)E<FEC:'0@240N`$]N=&)R96ME;F1E+"!V97)E:7-T92P@4$5!4B!M
M;V1U;&4@36%I;"X`3VYT8G)E:V5N9"!S97-S:64@240N`$UA`$UO8FEE;&4@
M92UM86EL`$=E;6ED9&5L9`!7:6IZ:6=I;F=S9&%T=6T`5VEJ>FEG(%523`!-
M;V1U;'5S`$UO;&1A=FGK+"!297!U8FQI96L@=F%N`$UO;F%C;P!-;VYG;VQI
MZP!-86%N9"!E;B!J86%R`$UA86YD96QI:FMS`$UO;G1S97)R870`36%A;F9A
M<V5N`$UE97(@=F5L9&5N(&EN(')E9V5L("5D(&=E=F]N9&5N+"!D86X@9&4@
M=F5R=V%C:'1T92`E9"X`36%R;VMK;P!6;V]R;F%M96QI:FL@;VYB97=O;&MT
M`%9O;W)N86UE;&EJ:R!B97=O;&MT`%9O;W)N86UE;&EJ:R!B97=O;&MT(&5N
M('=I;F1E<FEG`%9O;W)N86UE;&EJ:R!Z;VYN:6<`3F%A<B!B96YE9&5N`$YA
M87(@;&EN:W,`3F%A<B!R96-H=',`3F%A<B!B;W9E;@!.86%R(&)E;F5D96X`
M3F%A<B!B;W9E;@!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L
M:6IS=&5N`$UU;'1I;6%P(%9+(&MA87)T`$UE97)V;W5D:6=E('-E;&5C=&EE
M`$UI:FX@86-C;W5N=`!5=R!A8V-O=6YT:6YF;W)M871I90!-:6IN('!O<G1A
M86P`36EJ;B!P;W)T86%L;&%Y;W5T`$)I<FUA`$YE92P@:6L@86-C97!T965R
M(&1E('9O;W)W86%R9&5N($Y)150`3F%A;0!.86UI8FGK`$YA=7)U`$YE<&%L
M`$YE9&5R;&%N9`!.961E<FQA;F1S($%N=&EL;&5N`$YE='-C87!E($)A<VES
M(%523`!.971S8V%P92!#02!I;G1R96MK:6YG(%523`!.971S8V%P92!#02!B
M96QE:60@55),`$YE='-C87!E('9E<FYI975W:6YG(%523`!.971S8V%P92!I
M;G1R96MK:6YG(%523`!.971S8V%P92!34TP@<V5R=F5R;F%A;0!.971S8V%P
M92!C97)T:69I8V%A=&-O;6UE;G1A87(`3F5T<V-A<&4@8V5R=&EF:6-A871T
M>7!E`$YE='=E<FL`3F]O:70`3FEE=7<@0V%L961O;FGK`$YI975W92!C871E
M9V]R:64`3FEE=7=E(&UA86X`3FEE=7=E(&=E8G)U:6ME<G-N86%M("AO<'1I
M;VYE96PI`$YI975W(%IE96QA;F0`3FEE=7<@=V%C:'1W;V]R9`!.:65U=R!W
M86-H='=O;W)D('IA;"!V97)L;W!E;B!O<"`E>"X`3FEE=7=E(%=A8VAT=V]O
M<F1E;B!K;VUE;B!N:65T(&]V97)E96XN`$YI975W('-C:&5R;2`H7V)L86YK
M*0!.:65U=W,`3FEE=7=S9W)O97!E;@!6;VQG96YD90!6;VQG96YD92`T(&9A
M<V5N`%9O;&=E;F1E(&]P=&EE<P!6;VQG96YD93X`3FEC87)A9W5A`$YI9V5R
M`$YI9V5R:6$`3F%C:'0`3FEU90!.964`1V5E;B!B97-C:&EK8F%R92!C;VYF
M:6=U<F%T:65D871A(&]M('9E<G-C:&EL;&5N('1E(&QA=&5N('II96XN`$=E
M96X@8F5S8VAI:V)A<F4@<W1R871E9VEE('9O;W(@:&5T(&UA:V5N('9A;B!)
M4T\@:6UA9V5S+@!'965N(&)A=&-H<VIA8FQO;VXN`$5R(&)E<W1A870@9V5E
M;B!B;&]K(&]P(&1E(&=E=G)A86=D92!P;W-I=&EE`$=E96X@86=E;F1A;F%A
M;2!O<&=E9V5V96X@=F]O<B!-0T%,(&%U=&AE;G1I8V%T:64N`$=E96X@=VEJ
M>FEG:6YG96XN`$%A;B!D:70@<F5C:'0@:W5N;F5N(&=E96X@8VAI;&0@<F5C
M:'1E;B!W;W)D96X@=&]E9V5V;V5G9"X`1V5E;B!C;VYF:6=U<F%T:65I;F9O
M<FUA=&EE(&]P9V5G979E;B!V;V]R("5S+@!'965N(&-O;F9I9W5R871I96EN
M9F]R;6%T:64@;W!G96=E=F5N('9O;W(@1E10(%9&4RX`1V5E;B!C;VYF:6=U
M<F%T:65I;F9O<FUA=&EE(&]P9V5G979E;B!V;V]R(%-13"!61E,N`$=E96X@
M8V]N9FEG=7)A=&EE:6YF;W)M871I92!O<&=E9V5V96X@=F]O<B!344PM8F5S
M=&%N9"!61E,N`$=E96X@:W)E9&EE="!M965R+@!'965N(&)E<W1E;6UI;F<@
M;W!G96=E=F5N+@!'965N(&)E<W1A;F0@=7!L;V%D960`1V5E;B!P:6-T;V=R
M86UM96X@9V5V;VYD96XN`$5R(&ES(&=E96X@;&]C871I92!I;F=E<W1E;&0N
M`$=E96X@;&]C871I92!O<&=E9V5V96XN`$=E96X@8F5R:6-H="!G96QE=F5R
M9"X`1V5E;B!N86%M(&]P9V5G979E;BX`1V5E;B!G971A;"!O<&=E9V5V96XN
M`$=E96X@8F5L961I9V5N9&4@9F]R='5N97,`1V5E;B!W86-H='=O;W)D(&]P
M9V5G979E;B!V;V]R($A45%`@875T:&5N=&EC871I92X`1V5E;B!W86-H='=O
M;W)D(&]P9V5G979E;B!V;V]R($E-05`@875T:&5N=&EC871I92X`1V5E;B!W
M86-H='=O;W)D(&]P9V5G979E;B!V86X@2V5R8F5R;W,@875T:&5N=&EC871I
M92X`1V5E;B!W86-H='=O;W)D(&]P9V5G979E;B!V;V]R($QO9VEN(&%U=&AE
M;G1I8V%T:64N`$=E96X@=V%C:'1W;V]R9"!O<&=E9V5V96X@=F]O<B!005-3
M5T0@875T:&5N=&EC871I92X`1V5E;B!W86-H='=O;W)D(&]P9V5G979E;B!V
M;V]R(%--0B!A=71H96YT:6-A=&EE+@!'965N('!A9"!N86%R(&1E($]P96Y3
M4TP@8FEN87)Y(&]P9V5G979E;BX@1&4@3W!E;E-33"!B:6YA<GD@:7,@;F]D
M:6<@;VT@=&4@:W5N;F5N('=E<FME;B!M970@4$M#4R`Q,B!D871A+@!'965N
M(&AA;F=E;F1E(&EN<V-H<FEJ=FEN9V5N+@!'965N('%U;W1A(&EN9V5S=&5L
M9"X`1V5E;B!L:6YIZW)I;F<`1V5E;B!S8VAE:61I;F=S=&5K96X@;W!G96=E
M=F5N+@!'965N('II:F1E;@!'965N(&1E<F=E;&EJ:R!B97-T86YD`$=E96X@
M=&EJ9&5L:6IK(&1I<F5C=&]R>2!B97-C:&EK8F%A<B!V;V]R(&-A8VAE+@!'
M965N(&=E8G)U:6ME<G-N86%M(&5N+V]F('=A8VAT=V]O<F0@=F5R>F]N9&5N
M+@!'965N(&=E;&1I9V4@6$U,(&1A=&$@=&5R=6=G97-T=75R9`!'965N('=A
M87)D96X`1V5E;B!V97)S:64@9V5V;VYD96X@:6X@;W)I9VEN96QE(&-O;F9I
M9W5R871I92X@2&5R9V5N97)E97(@8V]N9FEG=7)A=&EE+@!'965N('9E<G-I
M92!G979O;F1E;B!I;B!U=R!C;VYF:6=U<F%T:64N($AE<F=E;F5R965R(&-O
M;F9I9W5R871I92X`1V5E;@!'965N("AV97)P;&EC:'0I`$YO;W)D($5U<F]P
M965S("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!E:6QA;F0`3F]O<F1E;&EJ:R!H
M86QF<F]N9`!-87)I86YE;@!.;V]R=V5G96X`3FEE="!N80!.:65T('9O;W(`
M1V5E;B!D:7)E8W1O<GD`3FEE="!G96EM<&QE;65N=&5E<F0N`$YI970@:6YG
M97-T96QD`$YI970@;VYD97)S=&5U;F0N`$YO=&ET:65S`$YI971S('1E(&)L
M861E<F5N+"!G82!T97)U9RX`3F]V96UB97(`1V5T86P`06%N=&%L(&MA<F%K
M=&5R<P!!86YT86P@:V]L;VUM96X`06%N=&%L(')I:F5N`$=E=&%L;&5N(&YI
M970@;W!G96=E=F5N('9O;W(@8FEJ=V5R:V5N(&EN(&5E;B!D:7-T<FEB=71I
M96QI:G-T+@!/2P!/8FIE8W0`3V)J96-T96EG96YA87(`3V-T86%L`$]K=&]B
M97(`0F5L961I9VEN9V9I;'1E<@!+86YT;V]R`$]U9&4@96X@;FEE=7=E('=A
M8VAT=V]O<F1E;B!D:65N96X@=F5R<V-H:6QL96YD('1E('II:FXN`$]U9&4@
M=V%C:'1W;V]R9`!/=61E('=A8VAT=V]O<F0@:7,@;FEE="!J=6ES=`!/;6%N
M`$%L;&5E;B!)34%0('-E<G9E<G,@;VYD97)S=&5U;F5N(&=E9&5E;&1E(&UA
M<'!E;BX`06QL965N(&)E;&5D:6=E;F1E(&9O<G1U;F5S`%-L96-H="#IZ6X@
M92UM86EL861R97,@=&]E9V5S=&%A;BX`06QL965N(&1E(&5I9V5N86%R(&]F
M(&5E;B!S>7-T965M8F5H965R9&5R(&UA9R!D92!E:6=E;F%A<G)E8VAT96X@
M=F%N(&5E;B!S:&%R92!W:6IZ:6=E;@!/<&5N(&EN(&5E;B!N:65U=R!S8VAE
M<FT`3W!E;E-33"!F;W5T.B!K;VX@9V5E;B!D871A('5I="!H970@;VYD97)T
M96ME;F1E(%,O34E-12!O;F1E<F1E96P@:&%L96XN`$]P96YT(&1E>F4@;&EN
M:R!I;B!E96X@;FEE=7<@<V-H97)M`$)E<W1U<FEN9W-S>71E96T`3W!T:65S
M`$]P=&EE<R!V;V]R("5S`$=E;W)D96YD92!L:6IS=`!/<F=A;FES=&%T:64`
M3W)G86YI<V%T:64@965N:&5I9`!/<F=A;FES97)E;@!/<FEG:6YE96P@=&]E
M<&%S<VEN9W-S:F%B;&]O;@!/<FEG:6YE;&4@<VIA8FQO;F5N(&EN("5S.@!!
M;F1E<F4`06YD97)E(&EN9F]R;6%T:64`16EG96YA87)R96-H=&5N`%!!32!A
M=71H96YT:6-A=&EE(&ES(&YI970@8F5S8VAI:V)A87(N`%!%05(Z.DUA:6P@
M8F%C:V5N9`!$:6=I=&%L92!01U`@:&%N9'1E:V5N:6YG`$=E8V]D965R9&4@
M4$=0(&1A=&$`3W!E;F)A<F4@4$=0('-L975T96P`3VYD97)T96ME;F1E+V=E
M8V]D965R9&4@4$=0(&1A=&$`4$A0(&-O9&4`4$A0('-H96QL`$QI8VAT92!R
M96=E;B!N82`Q,BXP,"!U=7(`4F5G96X@;F$@,3(N,#`@=75R`$)U:65N(&YA
M(#$R+C`P('5U<@!3;F5E=7<@;F$@,3(N,#`@=75R`%-N965U=V)U:65N(&YA
M(#$R+C`P('5U<@!:;VX@;F$@,3(N,#`@=75R`$]N=V5E<G-B=6EE;B!N82`Q
M,BXP,"!U=7(`4$]325@@97AT96YS:64@;VYT8G)E96MT`%!(4"!?4VAE;&P`
M5G)I:F4@<G5I;71E`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EJ;G,@5&5R<FET
M;W)I=6TL($)E>F5T`%!A;F%M80!087!U82!.:65U=R!'=6EN96$`4&%R86=U
M87D`1V5D965L=&5L:6IK(&)E=V]L:W0`5V%C:'1W;V]R9`!786-H='=O;W)D
M(&UE="!S=6-C97,@9V5W:6IZ:6=D+@!786-H='=O;W)D(&]N:G5I<W0`5V%C
M:'1W;V]R9"!I<R!V97)E:7-T('9O;W(@4D%$2553(&%U=&AE;G1I8V%T:64N
M`%=A8VAT=V]O<F0@;65T(&)E=F5S=&EG:6YG`%=A8VAT=V]O<F0Z`%=A8VAT
M=V]O<F0Z(`!786-H='=O;W)D96X@;6]E=&5N(&]V97)E96YK;VUE;BX`4&QA
M:VME;@!0;&%K:V5N('9A;F%F('!R:6MB;W)D`%!A9`!(86YG96YD92!I;G-C
M:')I:G9I;F=E;CH`365N<V5N`%!R;V-E;G0`3VYD97)H;W5D<W=E<FMZ86%M
M:&5D96X@=6ET=F]E<F5N`$]N9&5R:&]U9'-W97)K>F%A;6AE9&5N('5I='9O
M97)E;B!B:6H@86%N;65L9&EN9S\`4F5C:'0`4F5C:'0@(B5S(B!N:65T('9E
M<G=I:F1E<F0N`%)E8VAT(&=E=V5I9V5R9`!296-H=&5N`%)E8VAT96YB96AE
M97(`4&5R<V]O;FQI:FME(&EN9F]R;6%T:64`4&5R=0!(=6ES9&EE<F5N`%!H
M:6QI<'!I:FYE;@!496QE9F]O;@!&;W1O)W,`4&ET8V%I<FX`4&EX96QS`%!L
M871I='5D97,`2VQI:R!I;B!E96X@8V5L+"!A+G4N8BX`0F5V97-T:6<L(&1A
M="!U(&1I="!E;&5M96YT('=I;'0@=F5R=VEJ9&5R96XL(&$N=2YB.@!"979E
M<W1I9RP@9&%T('4@9&ET(&5L96UE;G0@=VEL="!L;W-K;W!P96QE;BP@82YU
M+F(N`$=E968@965N(&UA86YD(&5N(&5E;B!J86%R+"!A+G4N8BX`165N(&YA
M86T@=F]O<B!D92!N:65U=V4@8V%T96=O<FEE(&EN=F]E<F5N+"!A+G4N8BXZ
M`$=E968@965N(&=E;&1I9R!)4"!A9')E<RP@82YU+F(N`$=E968@965N(&=E
M;&1I9V4@9&%T=6T@82YU+F(N+"!C;VYT<F]L965R(&AE="!A86YT86P@9&%G
M96X@:6X@9&4@;6%A;F0N`$=E968@965N(&=E;&1I9V4@=&EJ9"P@82YU+F(N
M`$=E968@965N('-A;65N=F%T=&EN9R!V86X@:&5T('!R;V)L965M+"!A+G4N
M8BX`1V5E9B!U=R!G96)R=6EK97)S;F%A;2!E;B!W86-H='=O;W)D+"!A+G4N
M8BX`3&5E<R!D92!V;VQG96YD92!T96MS="P@82YU+F(N(%4@34]%5"!D92!V
M;V]R=V%A<F1E;B!T92!A8V-E<'1E<F5N(&]M(&AE="!S>7-T965M('1E(&MU
M;FYE;B!G96)R=6EK96XN`$=E968@9&4@;FEE=7=E(&-A=&5G;W)I96YA86TL
M(&$N=2YB+CH`4&]L96X`4&]L:71I96L`4&5I;&EN9V5N`%!O<G1U9V%L`%!O
M<VET:6]N97)I;F<@=F%N(&1E>F4@869B965L9&EN9P!0;W-I=&EO;F5R:6YG
M('9A;B!D97IE('1A8F5L`%-T=75R(&YA87(@9&5Z92!M87`@*&YI970@869G
M961W;VYG96X@9&]O<B!)34%0*0!.965R<VQA9R!V86X@9&4@869G96QO<&5N
M("5S('5R96XZ(`!.965R<VQA9SQB<B`O/FMA;G,`4')E9G-?;&1A<#H@=F5R
M96ES=&4@3$1!4"!E>'1E;G1I92!N:65T(&=E=F]N9&5N+@!0<F5F<U]S97-S
M:6]N.B!V97)E:7-T92!S97-S:64@97AT96YT:64@;FEE="!G979O;F1E;BX`
M3'5C:'1D<G5K`$QU8VAT9')U:R!O<"!Z965N:79E874Z(`!,=6-H=&1R=6LZ
M(`!"96]O<F1E;&5N`$)E;V]R9&5E;"!D92!A9F)E96QD:6YG(&EN(&5E;B!N
M:65U=R!S8VAE<FT`5F]R:6=E(&]P=&EE<P!$;V-U;65N="!A9F1R=6MK96X`
M4')I=F4@<VQE=71E;`!0<F]B;&5E;0!0<F]B;&5E;6)E<V-H<FEJ=FEN9P!0
M<F]J96-T96X`4')O;7!T('1E:W-T`$]P96YB87)E('-L975T96P`3W!E;F)A
M<F4@<VQE=71E;"!A;&=O<FET:&UE`$]P96YB87)E('-L975T96QI;F9O<FUA
M=&EE`$]P96YB86%R+U!R:79E('-L975T96QP86%R(&YI970@9V5G96YE<F5E
M<F0N`%!U97)T;R!2:6-O`%=I<R!B97)I8VAT96X`475A=&%R`%%U97)Y`%%U
M;W1A`%)302!O<&5N8F%R92!S;&5U=&5L("@E9"!B:70I`$ME=7IE<F]N9&IE
M('-E;&5C=&EE`%)E9V5N`%9R;V5G(')E9V5N`$QA870@<F5G96X`4F5G96YB
M=6D`4F5G96X@96X@<VYE975W`%)E9V5N(&YA87(@<VYE975W`%)A;F1O;2!&
M;W)T=6YE`%9E<FAO=61I;F<`3&5Z96X`3&5E<R!B97)I8VAT96X`)7,@96-H
M="!V97)W:6ID97)E;C\@1&5Z92!B97=E<FMI;F<@:V%N(&YI970@;VYG961A
M86X@9V5M86%K="!W;W)D96XN`$=E8G)U:6ME<G-D871A('9A;B!G96)R=6EK
M97(@)7,@96-H="!V97)W:6ID97)E;C\@1&5Z92!B97=E<FMI;F<@:V%N(&YI
M970@;VYG961A86X@9V5M86%K="!W;W)D96XN`$AE<FAA86QT('5W('9O<FEG
M92!B97=E<FMI;F<`5F5R=F5R<V5N`%9E<G9E<G,@9'EN86UI<V-H92!M96YU
M(&]N9&5R9&5L96XZ`%!O<G1A;'=E97)G879E('9E<G9E<G-E;CH`4F5G97@`
M0F5T<F5K:VEN9V5N(&)R;W=S97(`2&5R;&%D96X`3W!M97)K:6YG96X`4V5R
M=F5R<R!O<"!A9G-T86YD`%523"!O<"!A9G-T86YD("AH='1P.B\O=W=W+F5X
M86UP;&4N8V]M+VAO<F1E*3H`5F5R=VEJ9&5R96X`0FQO:R!V97)W:6ID97)E
M;@!+;VQO;2!V97)W:6ID97)E;@!/<&UA86L@=F5R=VEJ9&5R96X`4&%A<B!V
M97)W:6ID97)E;@!697)W:6ID97(@:&5T(&]P9V5S;&%G96X@<V-R:7!T('5I
M="!D92!T:6ID96QI:FME(&1I<F5C=&]R>2!O<"!D92!S97)V97(N`%9E<G=I
M:F1E<B!D90!697)W:6ID97(@9&5Z92!N;V1E('5I="!H970@9&]C=6UE;G0`
M1V5B<G5I:V5R('9E<G=I:F1E<F5N`%9E<G=I:F1E<B!G96)R=6EK97(Z("5S
M`%9E<GIO96L@:V]N(&YI970@=V]R9&5N(&)E86YT=V]O<F0N($=E<F5T;W5R
M;F5E<F1E(&9O=71C;V1E.B``1&4@9V5V<F%A9V1E('-E<G9I8V4@:V]N(&YI
M970@=V]R9&5N(&=E=F]N9&5N+@!697)E:7-T92`B)7,B(&YI970@;W!G96=E
M=F5N(&EN("5S(&-O;F9I9W5R871I92X`5F5R96ES=&4@(B5S(B!N:65T(&]P
M9V5G979E;B!I;B!61E,@8V]N9FEG=7)A=&EE+@!697)E:7-T92`B)7,B(&YI
M970@;W!G96=E=F5N(&EN(&-O;F9I9W5R871I92X`5F5R96ES="!V96QD`$AE
M<G-T96QL96X`4F5S970@=V%C:'1W;V]R9`!297-E="!U=R!W86-H='=O;W)D
M`%9O;W)G86%N9&4@<75E<GD@:&5R<W1E;&QE;@!297-U;'1A=&5N`%1E<G5G
M(&YA87(@;W!T:65S`%1Y<"!N:65U=R!W86-H='=O;W)D(&]P;FEE=7<`4F5U
M;FEO;@!#;VYF:6=U<F%T:64@=&5R=6=Z971T96X`4FEC:"!497AT($5D:71O
M<B!O<'1I97,`4F%A9'-E;',`4F5C:'1S`%)E8VAT<V4@:V]P`%)E8VAT<V4@
M=V%A<F1E;@!2:5]J96EG96YS8VAA<'!E;BXN+@!2;VP`4F]E;65N:>L`,3@P
M(&1R86%I96X`3F%A<B!L:6YK<R!D<F%A:65N`$YA87(@<F5C:'1S(&1R86%I
M96X`4FEJ(&5I9V5N<V-H87!P96X`4FEJ(&5I9V5N<V-H87!P96X`4FEJ96XZ
M`$QI;FGK<FEN9P!,:6YIZW)I;F<@>F%L('9E<G-C:&EJ;F5N('1U<W-E;B!A
M;&QE(')I:F5N(&5N(&MO;&]M;65N`$QI;FGK<FEN9R!Z86P@86QL965N('1U
M<W-E;B!K;VQO;6UE;B!V97)S8VAI:FYE;@!,:6YIZW)I;F<@>F%L(&%L;&5E
M;B!T=7-S96X@<FEJ96X@=F5R<V-H:6IN96X`4W1A<G1E;@!2=7-S:7-C:&4@
M1F5D97)A=&EE`%)W86YD80!#<GEP=&]G<F%F:7-C:&4@4R]-24U%(&AA;F1T
M96ME;FEN9P!3+TU)344@9V5C;V1E97)D(&)E<FEC:'0`4T%33"!A=71H96YT
M:6-A=&EE(&ES(&YI970@8F5S8VAI:V)A87(N`%--4R!V97)S='5R96X`4U%,
M('-H96QL`%-13"!S=&%T96UE;G0@=F]O<B!W86%R9&5Z;V5K;W!D<F%C:'1E
M;@!34T@`4U5#0T53`%-?44P@<VAE;&P`6F$`4W0@2&5L96YA`%-T($MI='1S
M(&5N($YE=FES`%-T($QU8VEA`%-T(%!I97)R92!E;B!-:7%U96QO;@!3="!6
M:6YC96YT(&5N(&1E($=R96YA9&EN97,`6F5L9F1E(&9R86UE("A?<V5L9BD`
M4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!E;B!0<FEN8VEP90!3871E;&QI
M971P<F]V:61E<@!3875D:2!!<F%B:>L`3W!S;&%A;@`B)7,B(&]P<VQA86X`
M)7,@;W!S;&%A;@!/<'1I97,@;W!S;&%A;@!'96=E;F5R965R9&4@8V]N9FEG
M=7)A=&EE(&%L<R!02%`@<V-R:7!T(&]P9V5S;&%G96X@:6X@9&4@=&EJ9&5L
M:6IK92!D:7)E8W1O<GD@=F%N('5W('-E<G9E<BX`)7,@8V]N9FEG=7)A=&EE
M(&]P9V5S;&%G96X`4V5T=7`@=7!G<F%D92!S8W)I<'0@;W!G97-L86=E;B!N
M86%R.B`B)7,B+@!'97-P<F5I9&4@;VYW965R<V)U:65N`%=E=&5N<V-H87``
M6F]E:V5N`%IO96MM86-H:6YE<P!+:65S(&)E<W1A;F1E;@!396QE8W1E97(@
M965N(&1A='5M`%-E;&5C=&5E<B!E96X@9W)O97`@;VT@=&]E('1E('9O96=E
M;@!396QE8W1E97(@965N(&YI975W92!E:6=E;F%A<@!396QE8W1E97(@965N
M('-E<G9E<@!396QE8W1E97(@965N(&=E8G)U:6ME<B!O;2!T;V4@=&4@=F]E
M9V5N`$%L;&5S('-E;&5C=&5R96X`4V5L96-T965R(&%L;&4@9&%T=6UC;VUP
M;VYE;G1E;BX`4V5L96-T965R(&5E;B!O8FIE8W0`3FEE=',@<V5L96-T97)E
M;@!396QE8W1E97(@9&4@8F5N;V1I9V1E(&MA<F%K=&5R<R!U:70@9&4@;VYD
M97)S=&%A;F1E('9A:VIE<RX@52!K=6YT(&1E>F4@9&%N(&MO<&GK<F5N(&5N
M('!L86MK96X@:6X@:&5T('1E:W-T9V5B:65D+@!396QE8W1E97(@:&5T(&1A
M='5M<V-H96ED:6YG<W1E:V5N.@!396QE8W1E97(@:&5T(&1A='5M9F]R;6%A
M=#H`4V5L96-T965R(&1E(&ED96YT:71E:70@9&EE('4@=VEL="!W:6IZ:6=E
M;CH`4V5L96-T965R(&AE="!T:6ID<V-H96ED:6YG<W1E:V5N.@!396QE8W1E
M97(@:&5T('1I:F1S9F]R;6%A=#H`4V5L96-T965R('1W964@;W9E<F5E;FMO
M;65N9&4@=F5L9&5N+@!396QE8W1E97(@=7<@:VQE=7)S8VAE;6$N`%-E;&5C
M=&5E<B!U=R!G97=E;G-T92!T86%L.@!0<F]B;&5E;7)A<'!O<G0@=F5R>F5N
M9&5N`%9E<GIE;F0@4TU3`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E
M<G9IZR!E;B!-;VYT96YE9W)O`%-E<FEE;G5M;65R`%-E<G9E<F1A=&$@9F]U
M="!O9B!N:65T(&)E<V-H:6MB86%R+@!397-S:65B96AE97)D97(`4V5S<VEE
M($E$('9E<FQO<&5N+@!397-S:65S`$EN<W1E;&QE;@!);G-T96QL96X@=F%N
M(&]P=&EE<R!O;2!U('1O92!T92!S=&%A;B!U=R!W86-H='=O;W)D('1E(')E
M<V5T=&5N+"!W86YN965R('4@9&ET(&)E;G0@=F5R9V5T96XN`$EN<W1E;&QE
M;B!V86X@<V5R=F5R<R!O<"!A9G-T86YD(&1I92!U('=I;'0@8F5N861E<F5N
M('9A;G5I="!U=R!P;W)T86PN`$EN<W1E;&QE;B!V86X@=7<@9V5W96YS=&4@
M=&%A;"P@=&EJ9'IO;F4@96X@9&%T=6UO<'1I97,N`$EN<W1E;&QE;B!V86X@
M=7<@;W!S=&%R='1O97!A<W-I;F<L(&ML975R<V-H96UA+"!P86=I;F%V97)V
M97)S:6YG(&5N(&%N9&5R92!W965R9V%V96]P=&EE<RX`26YS=&5L;&5N`%-E
M='5P('5P9W)A9&4@<V-R:7!T<R!B97-C:&EK8F%A<@!697)S8VAI;&QE;F1E
M(&QO8V%T:65S(&UO9V5L:6IK(&UE="!D92!P87)A;6%T97(Z(`!397EC:&5L
M;&5N`%=I;FME;&5N`$MO<G1E('-A;65N=F%T=&EN9P!$:65N96X@<VYE;'1O
M971S96X@=F]O<B!D92!M965S=&4@;&EN:W,@9V5D969I;FEE97)D('1E('=O
M<F1E;C\`5V5E<F=E=F5N`%9E<G-C:&EL;&5N(&QA=&5N('II96X@='5S<V5N
M(&1E(&AU:61I9V4@;W!G97-L86=E;B!C;VYF:6=U<F%T:64@96X@9&4@;FEE
M=7=E(&=E9V5N97)E97)D92!C;VYF:6=U<F%T:64N`$QA871S=&4@86%N;65L
M9&EN9W-T:6ID('=E97)G979E;B!B:6H@86%N;65L9&5N/P!/<'1I92!W965R
M9V5V96X@;VT@;W)I9VEN965L('1E(&)E=V%R96X`2VEE>F5R('=E97)G979E
M;@!486)E;&)E=V5R:VEN9W-T86%K8F%L:R!W965R9V5V96X_`"5S(&UE;G4@
M86%N(&1E(&QI;FME<FMA;G0@=V5E<F=E=F5N/P!486)E;&-E;&5I9V5N<V-H
M87!P96X@9&EA;&]O9W9E;G-T97(@=V5E<F=E=F5N`%1A8F5L96EG96YS8VAA
M<'!E;B!D:6%L;V]G=F5N<W1E<B!W965R9V5V96X`5&%B96QR:6IE:6=E;G-C
M:&%P<&5N(&1I86QO;V=V96YS=&5R('=E97)G979E;@!!9F)E96QD:6YG<V5I
M9V5N<V-H87!P96X@9&EA;&]O9W9E;G-T97(@=V5E<F=E=F5N`%5P;&]A9"!W
M965R9V5V96X`0G5I96X`0G5I96X@=G)O96<`0G5I96X@;&%A=`!"=6EE;B!I
M;B!D92!N86)I:FAE:60`5F5R:VQE:6YE;@!697)K;&5I;B!O9B!V97)P;&%A
M=',@;F%B=7)I9V4@8FQO:VME;B!E97)S=`!3:65R<F$@3&5O;F4`26YT96ME
M;F5N`$AA;F1T96ME;FEN9P!(86YD=&5K96YI;F<@86QG;W)I=&AM90!3:6YG
M87!O<F4`1W)O;W1T90!/;F1E<FAO=60@;W9E<G-L86%N`%-L;W=A:VEJ90!3
M;&]V96YIZP!3;F5E=7<`4VYE975W=FQA86<`4VYE975W8G5I96X`<VYE975W
M8G5I96X@=G)O96<`4VYE975W8G5I96X@;&%A=`!3;F5E=7=D:65P=&4Z(`!3
M;F5E=7=E<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO;B!E:6QA;F1E;@!3
M;VUA;&GK`$QI961E<F5N(&5N(&=E9&EC:'1E;@!3;W)T965R=F]L9V]R9&4@
M<V5L96-T:64`0G)O;F%D<F5S`%IU:60@069R:6MA`%IU:60@175R;W!E97,@
M*$E33RTX.#4Y+3,I`%IU:60@1V5O<F=IZR!E;B!D92!:=6ED(%-A;F1W:6-H
M(&5I;&%N9&5N`%IU:61E;&EJ:R!H86QF<F]N9`!3<&%T:>MR:6YG('1U<W-E
M;B!A86YG<F5N>F5N9&4@8V5L;&5N`%-P871IZW)I;F<@='5S<V5N(&EN:&]U
M9"!E;B!R86YD(&EN(&-E;`!38VAE:61I;F=S=&5K96X`4W!A=&GK<FEN9P!3
M<&%T:>MR:6YG(&5N('9R:6IE(')U:6UT90!3<&%N:F4`4W!A;0!3<&5C:6%A
M;"!K87)A:W1E<B!I;G9O97(`0V5L(&]P<W!L:71S96X`2V]L;VT@;W!S<&QI
M='-E;@!2:6H@;W!S<&QI='-E;@!3<&]R=`!3<FD@3&%N:V$`4W1A;F1A87)D
M`%-T87(@5')E:P!3=&%R=&IA87(`4W1A870@;V8@<')O=FEN8VEE`%-T871U
M<P!/<'-L86=F;W)M86%T`$%D<F5S`$1O;W)H86QE;@!3=')I;F=L:6IS=`!3
M=')I<"!D;VUE:6X@=F%N(&AE="!A9')E<P!3=&EJ;"!;0U-370!:;P!3=6)D
M:7)E8W1O<GD@(B5S(B!N:65T(&=E=F]N9&5N+@!/;F1E<G=E<G``0F5V97-T
M:6=E;@!697)Z;V5K('9E<G-T=75R9"!O;2`B)7,B(&%A;B!H970@<WES=&5E
M;2!T;V4@=&4@=F]E9V5N+B!5(&MU;G0@;FEE="!A86YM96QD96X@=&]T('5W
M('9E<GIO96L@:7,@9V]E9&=E:V5U<F0N`%-U8G-C<FEP=`!3=6-C97,`(B5S
M(B!M970@<W5C8V5S(&%A;B!H970@<WES=&5E;2!T;V5G979O96=D+@!$871A
M('9A;B!G96)R=6EK97(@(B5S(B!M970@<W5C8V5S('5I="!H970@<WES=&5E
M;2!V97)W:6ID97)D+@`B)7,B(&UE="!S=6-C97,@=F5R=VEJ9&5R9"X`(B5S
M(B!M970@<W5C8V5S('5I="!H970@<WES=&5E;2!V97)W:6ID97)D+@!#;VYF
M:6=U<F%T:64@;65T('-U8V-E<R!T97)U9V=E>F5T+B!697)N:65U=R!O;2!W
M:6IZ:6=I;F=E;B!T92!Z:65N+@!"86-K=7!C;VYF:6=U<F%T:64@;65T('-U
M8V-E<W,@;W!G97-L86=E;BX`0F%C:W5P8V]N9FEG=7)A=&EE8F5S=&%N9"`E
M<R!M970@<W5C8V5S<R!O<&=E<VQA9V5N+@`B)7,B(&UE="!S=6-C97,@8FEJ
M9V5W97)K=``E<R!M970@<W5C8V5S(&=E<V-H<F5V96X`4V]E9&%N`%-A;65N
M=F%T=&EN9P!:;VYS;W!G86YG`%IO;G-O;F1E<F=A;F<`6F]N;FEG`%IO;G-O
M<&=A;F<`6F]N<V]P9V%N9R]:;VYS;VYD97)G86YG`%IO;G-O<&=A;F<Z(`!:
M;VYS;VYD97)G86YG`%IO;G-O;F1E<F=A;F<Z(`!3=7!E<G-C<FEP=`!/;F1E
M<G-T975N:6YG`%-U<FEN86UE`$%C:'1E<FYA86T`4W!I='-B97)G96X@96X@
M2F%N($UA>65N`%-W87II;&%N9`!:=V5D96X`6G=I='-E<FQA;F0`4WEN8R!L
M;V<@=F5R=VEJ9&5R9`!3>6YC34P`4WEN=&%X9F]U="!I;B!Z;V5K=&5R;65N
M`%-Y<FES8VAE($%R86)I<V-H92!297!U8FQI96L`3VYW965R<V)U:0!/;G=E
M97)S8G5I96X@96X@=VEN9&5R:6<`3VYW965R<V)U:65N`$]N=V5E<G-B=6EE
M;B!V<F]E9P!44U8@8F5S=&%N9`!486)E;&5I9V5N<V-H87!P96X`5&%B96QS
M970`5&%B96QE:6=E;G-C:&%P<&5N`%1A:7=A;@!486EW86XL(%!R;W9I;F-I
M92!V86X@0VAI;F$`5&%D>FII:VES=&%N`%1A;GIA;FEA+"!697)E;FEG9&4@
M4F5P=6)L:65K('9A;@!$;V5L.@!486ME;@!496QE9F]O;FYU;6UE<@!496UP
M97)A='5U<B!V86X@:&5T(&%F9V5L;W!E;B!U=7(Z(`!496UP97)A='5U<@!4
M96UP97)A='5U<CH@`%1E;7!E<F%T=75R/&)R("\^*"5S2&]O9R5S+R5S3&%A
M9R5S*2`F9W)D.R5S`%-J86)L;V]N("(E<R(@;FEE="!G979O;F1E;BX`4VIA
M8FQO;VYB96AE97(`5&5K<W0`06QL965N('1E:W-T`%1E:W-T('5I=&QI:FYE
M;@!496MS=&)O=F5N:V%N=`!$;P!4:&%I<R`H5$E3+38R,"D`5&AA:6QA;F0`
M1&4@1E10(&5X=&5N=&EE(&ES(&YI970@8F5S8VAI:V)A87(N`$AE="!G97-C
M:&EE9&5N:7-S>7-T965M(&ES('5I=&=E<V-H86ME;&0N`$1E($AO<F1E+TMO
M;&%B(&EN=&5G<F%T:64@;VYD97)S=&5U;G0@(B5S(B!N:65T`$AE="!)35-0
M(&QO9R!K;VX@;FEE="!W;W)D96X@9V5I;FET:6%L:7-E97)D+@!$92!-86EN
M=&5N86YC93HZ(&-L87-S('=E<F0@;FEE="!G96QA9&5N`$AE="!/<'1I97-S
M8VAE<FT@:7,@9V5S;&]T96XN($%F<VQU:71E;BX`1&4@8F5H965R9&5R(&1I
M96YT(&5E;B!P97)M86YE;G0@<F5C:'1E;F)A8VME;F0@=&4@8V]N9FEG=7)E
M<F5N(&%L<R!U(')E8VAT96X@=VEL="!G96)R=6EK96XN`$%L;&5E;B!D92!O
M;F1E<FMA;G0`2&5T(&-O;G1A8W0@240@;G5M;65R(&ES(&YI970@;W!G96=E
M=F5N+"!L965G(&=E;&%T96X@;V8@:7,@;FEE="!G979O;F1E;B!I;B!D92!D
M871A8F%S92X`2&5T(&%D<F5S(&ES(&UE="!S=6-C97,@86%N('5W(&%D<F5S
M8F]E:R!T;V5G979O96=D+@!(970@;&]S9V5K;W!P96QD92!01U`@;VYD97)T
M96ME;FEN9W-B;&]K(&ES('9E<F5I<W0@;VT@:&5T(&]N9&5R=&5K96YD92!B
M97)I8VAT('1E('9E<FEF:>MR96XN`$AE="!D:7-T<G5B=71I96QI:G-T($E$
M(&ES(&YI970@;W!G96=E=F5N+"!L965G(&=E;&%T96X@;V8@:7,@;FEE="!G
M979O;F1E;B!I;B!D92!D871A8F%S92X`1&4@9&ES=')I8G5T:65L:6IS="!I
M<R!N:65T(&]P9V5G979E;BX`1&4@8V]D965R;6]G96QI:FMH961E;B!V97)E
M:7-E;B!E96X@8F5V96EL:6=D92!W96)V97)B:6YD:6YG+@!(970@8F5S=&%N
M9"`E<R!D:65N="!E96X@)7,@:6YS=&5L;&EN9R!T92!B979A='1E;BX`2&5T
M(&)E<W1A;F0@)7,@9&EE;G0@96YI9V4@)7,@:6YS=&5L;&EN9V5N('1E(&)E
M=F%T=&5N+@!(970@8F5S=&%N9"!K86X@;FEE="!N86%R('II8VAZ96QF(&=E
M:V]P:65E<F0@=V]R9&5N+@!(970@8F5S=&%N9"!B979A='1E(&=E96X@9&%T
M82X`2&5T('9O;&=E;F1E('II:FX@9&4@:V]P<&5N('9A;B!D:70@;65S<V%G
M92]R9F,X,C(@8F5R:6-H="X`5F%N(&1E('9O;&QE9&EG('-C:&5R;2!M;V1E
M(&ES(&)E:V5N9"P@9&%T(&1I="!P<F]B;&5M96X@:V%N('9E<F]O<GIA:V5N
M(&UE="!);G1E<FYE="!%>'!L;W)E<BP@=F%N=V5G92!B<F]W<V5R8G5G<R!W
M86%R('=I:B!N:65T(&]M:&5E;B!K=6YN96XN($AE="!I<R!M;V=E;&EJ:R!D
M870@=2!R;VUM96P@:6X@:&5T(&)E96QD<V-H97)M+"!G96)R96L@86%N(&5D
M:71O<F9U;F-T:65S(&5N+V]F(')A;F1O;2!B<F]W<V5R+2!C<F%S:&5S(&5R
M=F%A<G0N(%=A;FYE97(@=7<@<WES=&5E;2!7:6YD;W=S(#EX(&ES+"!I<R!H
M970@=V%A<G-C:&EJ;FQI:FL@9&%T('4@965N("=!;&=E;65N92!"979E:6QI
M9VEN9W,@1F]U="<@:W)I:F=T+"!E;B!O<&YI975W(&1I96YT('1E(&AE<G-T
M87)T96XN7&Y<;E4@8F5N="!G97=A87)S8VAU=V0N($1R=6L@;W`@3TL@=V%N
M;F5E<B!U('1O8V@@9&4@=F]L;&5D:6<@<V-H97)M(&5D:71O<B!W:6QT('!R
M;V)E<F5N+@!$92!I9&5N=&ET96ET("(E<R(@:7,@=F5R=VEJ9&5R9"X`06QL
M965N(&1E(&QI;FME<FMA;G0`1&4@<&QA871S('9A;B!H970@1VYU4$<@<')O
M9W)A;6UA(&1I96YT(&]P9V5G979E;B!T92!W;W)D96X@:6X@9&4@0W)Y<'1?
M<&=P.CH@8VQA<W,N`$AE="!B97)I8VAT('9E<G-T=75R9"!O<"`E<R!A86X@
M)7,@;65T(&]N9&5R=V5R<"`B)7,B(&ES('=E97)G96=E=F5N+@I$:70@:7,@
M9V5E;B!G87)A;G1I92!D870@:&5T(&)E<FEC:'0@:7,@9V5L97IE;B!O9B!B
M96=R97!E;BX`1&4@;F%A;2!D:64@9V5B<G5I:W0@=V]R9'0@8FEJ(&QI;FME
M;B!N86%R(&1E(&YI975W(&)E<FEC:'0@<&%G:6YA`$AE="!A86YT86P@=F5L
M9&5N(&1I96YT(&YU;65R:65K('1E('II:FXN`$1E(&]P96YS<VP@;6]D=6QE
M(&ES('9E<F5I<W0@=F]O<B!D92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S
M+@!$92!V;V]R:V5U<G-I;G-T96QL:6YG("(E<R(@:V]N(&YI970@=V]R9&5N
M(&]P9V5S;&%G96XL(&]M9&%T(&1E(&1A=&$@9&4@;6%X:6UU;2!T;V5L86%T
M8F%R92!G<F]O='1E(&]V97)S8VAR:6ID="X`2&5T('!R;V=R86UM82!O;2!D
M:70@9&%T871Y<&4@*"5S*2!T92!B96MI:FME;BP@=V5R9"!N:65T(&]P(&AE
M="!S>7-T965M(&=E=F]N9&5N+@!(970@86%N:&%L:6YG<W1E:V5N(&1I96YT
M(.OK;B!E;FME;"!T96ME;B!T92!Z:6IN+@!!;&QE96X@9&4@<F5C:'1E<BT@
M96X@;&EN:V5R:V%N=`!!;&QE96X@9&4@<F5C:'1E<FMA;G0`2&5T('-C:&5I
M9&EN9W-T96ME;B!D:65N="#KZVX@96YK96P@=&5K96X@=&4@>FEJ;BX`1&4@
M<V5R=F5R("(E<R(@:7,@=F5R=VEJ9&5R9"X`1&4@<V5R=F5R("(E<R(@:7,@
M;W!G97-L86=E;BX`2&5T(&%A;FUE;&1I;F=S=F5R>F]E:R!V;V]R("5S(&ES
M('9E<G=I:F1E<F0N`$1E(&]P9V5G979E;B!R:6H@*"5D*2!B97-T86%T(&YI
M970N`$AE="!T:6ID96QI:FL@8F5S=&%N9"`B)7,B(&)E<W1A870@;FEE="X`
M1&4@:6YG979O97)D92!T96MS="!K;VUT(&YI970@;W9E<F5E;B!M970@9&4@
M=&5K<W0@;W`@:&5T('-C:&5R;2X`06QL965N(&1E(&)O=F5N+2!E;B!O;F1E
M<FMA;G0`06QL965N(&1E(&)O=F5N:V%N=`!$92!U<&QO861E9"!D871A(&ES
M(&YA(&1E('9O;W)G86%N9&4@<W1A<"!V97)L;W)E;B!G96=A86XN`$AE="!U
M<&QO861E9"!B97-T86YD(&ES(&YI970@;W!G97-L86=E;BX`2&5T('=E871H
M97(N8V]M(&)L;VL@:7,@;FEE="!B97-C:&EK8F%A<BX`5&AE;6%D:7)E8W1O
M<GD@(B5S(B!N:65T(&=E=F]N9&5N+@!'965N(&]P=&EE<R!B97-C:&EK8F%A
M<BX`17(@>FEJ;B!G965N(&]N9&5R9&5L96XL('=E;&ME(&EN;&EN92!W965R
M9V5G979E;B!K=6YN96X@=V]R9&5N+@!%<B!Z:6IN('1E('9E96P@:V%R86MT
M97)S(&EN(&1I="!V96QD+B!5(&AE969T("5S(&MA<F%K=&5R<R!O<&=E9V5V
M96X[('4@9&EE;G0@;6EN9&5R(&1A;B`E<R!O<"!T92!G979E;BX`165N('!R
M;V)L965M(&UE="!H970@=&]E=F]E9V5N('9A;B`B)7,B(&%A;B!H970@<WES
M=&5E;3H@)7,`165N('!R;V)L965M(&UE="!H970@=F5R=VEJ9&5R96X@=F%N
M(&1A=&$@=F%N(&=E8G)U:6ME<B`B)7,B('5I="!H970@<WES=&5E;3H@`$5E
M;B!P<F]B;&5E;2!M970@:&5T('9E<G=I:F1E<F5N('9A;B`B)7,B('5I="!H
M970@<WES=&5E;3H@`$5E;B!P<F]B;&5E;2!M970@:&5T(&)I:G=E<FME;B!V
M86X@(B5S(CH@)7,`165N('!R;V)L965M(&UE="!D92!B97-T86YD<W5P;&]A
M9#H@1V5E;B`E<R!W97)D(&=E=7!L;V%D+@!%96X@<')O8FQE96T@;65T(&1E
M(&)E<W1A;F1S=7!L;V%D.B!(970@)7,@:7,@9W)O=&5R(&1A;B!D92!M87AI
M;75M('1O96QA871B87)E(&=R;V]T=&4@*"5D(&)Y=&5S*2X`165N('!R;V)L
M965M(&UE="!D92!B97-T86YD<W5P;&]A9#H@2&5T("5S(&ES('-L96-H=',@
M9V5D965L=&5L:6IK(&=E=7!L;V%D+@!%96X@9F]U="!B:6H@:&5T(&)E:VEJ
M:V5N('9A;B!D:70@8F5R:6-H=&]N9&5R9&5E;`!%96X@9F]U="!B:6H@:&5T
M(&EM<&]R=&5R96X@=F%N(&1E(&%D<F5S9&%T82X`165N(&9O=70@8FEJ(&AE
M="!I;7!O<G1E<F5N('9A;B!D92!I0V%L96YD87)D871A+@!%96X@9F]U="!I
M;B!H970@8V]N9FEG=7)A=&EE9F]R;75L:65R+B!-:7-S8VAI96X@8F5N="!U
M(&5E;B!V97)P;&EC:'0@=F5L9"!V97)G971E;BX`165N(&9O=70@8FEJ(&AE
M="!U:71V;V5R96X@=F%N(&1E(&]P9V5G979E;B!A9')E<V)O96MF=6YC=&EE
M+B!0<F]B965R(&QA=&5R(&]P;FEE=7<L(&$N=2YB+@!%96X@9F]U="!M970@
M:&5T(&)I:G=E<FME;B!V86X@9&4@861R97-D971A:6QS+B!0<F]B965R(&QA
M=&5R(&]P;FEE=7<L(&$N=2YB+@!%96X@9F]U="!M970@:&5T(&)I:G=E<FME
M;B!V86X@9&4@9&ES=')I8G5T:65L:6IS="X@4')O8F5E<B!L871E<B!O<&YI
M975W+"!A+G4N8BX`1&5Z92!)34%0('-E<G9E<B!O;F1E<G-T975N="!G965N
M(&1E;&EN9R!V86X@;6%P<&5N+@!$:70@;&EJ:W0@;FEE="!E96X@9V5L9&EG
M(')A<B!B97-T86YD('1E('II:FXN`$1I="!L:6IK="!N:65T(&5E;B!G96QD
M:6<@>FEP(&)E<W1A;F0@=&4@>FEJ;BX`1&ET(&QI:FMT(&YI970@965N(&=E
M;&1I9R!K86%R=&YU;6UE<B!T92!Z:6IN+@!$:70@<W1U=7)P<F]G<F%M;6$@
M9V5E9G0@9&4@;6]G96QI:FMH96ED(&]M(&)E<FEC:'1E;B!V:6$@9&4@0VQI
M8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y('1E('9E
M<GIE;F1E;BP@9"YM+G8N(&1E($A45%`@05!)`$1I="!S='5U<G!R;V=R86UM
M82!G965F="!D92!M;V=E;&EJ:VAE:60@;VT@8F5R:6-H=&5N('9I82!D92!7
M24X@*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y('1E('9E<GIE;F1E;BP@
M9"YM+G8N(&1E($A45%`@05!)`$1I="!S='5U<G!R;V=R86UM82!G965F="!D
M92!M;V=E;&EJ:VAE:60@;VT@8F5R:6-H=&5N('9I82!D92!S;7,R96UA:6P@
M*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y('1E('9E<GIE;F1E;BP@
M9"YM+G8N(&1E($A45%`@05!)`$1I="!S='5U<G!R;V=R86UM82!G965F="!D
M92!M;V=E;&EJ:VAE:60@;VT@8F5R:6-H=&5N('9I82!33510(&0N;2YV+B!D
M92!6;V1A9F]N92!)=&%L>2!G871E=V%Y('1E('9E<GIE;F1E;B!N86%R(%9O
M9&%F;VYE(&YU;6UE<G,N($AI97)V;V]R(&ES(&5E;B!6;V1A9F]N92!)=&%L
M>2!E+6UA:6QA9')E<R`H:'1T<#HO+W=W=RXQ.3`N:70I(&YO;V1Z86ME;&EJ
M:RX`1&ET('9E;&0@:7,@=F5R96ES=`!$:70@=F5L9"!M86<@86QL965N(&EN
M=&5G97)S(&)E=F%T=&5N+@!$:70@=F5L9"!M86<@86QL965N(&=E=&%L;&5N
M(&5N(&1E(&1U8F)E;&4@<'5N="!B979A='1E;BX`1&ET('9E;&0@;6%G(&%L
M;&5E;B!O8W1A86P@=V%A<F1E;B!B979A='1E;BX`1&ET('9E;&0@9&EE;G0@
M965N(&MO;6UA(&]F('-P871I92!G97-C:&5I9&5N(&QI:G-T(&UE="!I;G1E
M9V5R<R!T92!Z:6IN`$1E>F4@=V%A<F1E(&1I96YT(&5E;B!G96QD:6<@9V5T
M86P@=&4@>FEJ;BX`1&ET('9E;&0@9&EE;G0@965N(&ML975R8V]D92!I;B!2
M1T(@2$58+69O<FUA870@=&4@8F5V871T96XL(&(N=BX@)R,Q,C,T868G+@!$
M:70@9F]R;75L:65R(&ES(')E961S('9E<G=E<FMT+@!$:70@:7,@)7,N`$1I
M="!I<R!E96X@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@3VT@9&ET(&]B:F5C
M="!W965R('1E(&=E=F5N(&AE969T('4@965N(&4M;6%I;"!C;&EE;G0@;F]D
M:6<@9&EE(&AE="!+;VQA8B!'<F]U<'=A<F4@9F]R;6%A="!B96=R:6IP="X@
M5F]O<B!E96X@;&EJ<W0@;65T(&1E>F4@92UM86EL8VQI96YT<RP@8F5Z;V5K
M("5S+"!A+G4N8BX`1&ET(&)E<FEC:'0@:7,@:6X@965N(&%N9&5R92!K87)A
M:W1E<G-E="`H)7,I(&=E<V-H<F5V96XL(&1A;B!U=R!E:6=E;BX`1&ET(&=E
M=&%L(&1I96YT('1E;FUI;G-T92#IZ6X@=&4@>FEJ;BX`1&5Z92!S97)V97(@
M:V%N(&=E96X@>FEP(&5N(&=Z:7`@8F5S=&%N9&5N('5I='!A:VME;BX`2&5T
M('-Y<W1E96T@:7,@;6]M96YT965L('5I=&=E<V-H86ME;&0N`$1E>F4@=V%A
M<F1E(&1I96YT(&5E;B!G971A;"!T92!Z:6IN+@!$:70@<V-H97)M(&1I96YT
M(&%A;F=E<F]E<&5N('1E('=O<F1E;B!V86YU:70@965N($]P=&EE<W-C:&5R
M;0!/;G=E97(`5&EC:V5T<P!4:6ID`%1I:F1P;&%N;FEN9P!4:6ID9F]R;6%A
M=`!4:6ID<V5L96-T:64`5&EM;W(M3&5S=&4`5&ET96P`5&ET96P@*'1O;VQT
M:7`I.@!!86X`3VT@;65E<F1E<F4@;VYD97)D96QE;B!T92!S96QE8W1E<F5N
M+"!H;W5D(&1E($-O;G1R;VP@*%!#*2!O9B!#;VUM86YD("A-86,I('1O971S
M('9A<W0@=&EJ9&5N<R!K;&EK:V5N+@!686YD86%G`$A434P@8G)O;B!O;7-C
M:&%K96QE;@!4;V=O`%1O:V5L874`36]R9V5N`%1O;F=A`%1E('9E96P@;VYG
M96QD:6=E(&%A;FUE;&1I;F=E;B!G961U<F5N9&4@9&4@869G96QO<&5N(&UI
M;G5T96XN`$)O=F5N:V%N=`!";W9E;G-T92!F<F%M92`H7W1O<"D`5F5R=&%L
M:6YG96X`5')I;FED860@96X@5&]B86=O`%1R=64@;V8@9F%L<V4`1&D`5'5N
M97-IZP!4=7)K:6IE`%1U<FMS("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`
M5'5R:W,@96X@0V%I8V]S(&5I;&%N9&5N`%1U=F%L=0!4>7`@=7<@:V5U>F4Z
M(`!5+E8N(&EN9&5X.B``55),`%523"!V;V]R('5W(&%F;&5V97)I;F=S<W1A
M='5S<F%P<&]R="!S8W)I<'0`55),.@!/96=A;F1A`$]E:W)A[VYE`$YI970@
M:6X@<W1A870@5D93(&1I<F5C=&]R>2!A86X@=&4@<W!R96ME;BX`3FEE="!I
M;B!S=&%A="!E>'1R82!G96)R=6EK97)S:6YF;W)M871I92!T;V4@=&4@=F]E
M9V5N(&)I:B!I;G-C:')I:G9E;BX`3FEE="!I;B!S=&%A="!D92!R96-H=&5N
M('9A;B!61E,@8F5S=&%N9"`B)7,B('1E('=I:GII9V5N+@!.:65T(&EN('-T
M86%T(&1E(')E8VAT96X@=F%N(%9&4R!B97-T86YD("5S+R5S('1E('=I:GII
M9V5N+@!.:65T(&EN('-T86%T('1E('=I:GII9V5N(&YA87(@)7,N`$YI970@
M:6X@<W1A870@8F5S=&%N9'-G<F]O='1E('9A;B`B)7,B('1E(&-O;G1R;VQE
M<F5N+@!.:65T(&EN('-T86%T(&)E<W1A;F1S9W)O;W1T92!V86X@(B5S+R5S
M(B!T92!C;VYT<F]L97)E;BX`3FEE="!I;B!S=&%A="!M970@9&4@4U%,('-E
M<G9E<B!T92!V97)B:6YD96XN`$YI970@:6X@<W1A870@;65T(%-33"!T92!V
M97)B:6YD96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@:V]P:>MR
M96XN`$YI970@:6X@<W1A870@5D93(&1I<F5C=&]R>2`B)7,B('1E(&UA:V5N
M+@!.:65T(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@=&4@;6%K96XN`$YI970@
M:6X@<W1A870@5D93(&)E<W1A;F0@=&4@;6%K96XN`$YI970@:6X@<W1A870@
M5D93(&UA<"`B)7,B('1E(&UA:V5N+@!.:65T(&EN('-T86%T(&5E;B!L965G
M(%9&4R!B97-T86YD('1E(&UA:V5N+@!.:65T(&EN('-T86%T(&1A=&$@=6ET
M('1E('!A:VME;BX`3FEE="!I;B!S=&%A="`B)7,B('1E('9E<G=I:F1E<F5N
M+"!D92!D:7)E8W1O<GD@:7,@;FEE="!L965G`$YI970@:6X@<W1A870@(B5S
M(CH@)7,@=&4@=F5R=VEJ9&5R96XN`$YI970@:6X@<W1A870@)7,@=&4@=F5R
M=VEJ9&5R96XL(&1E(&1I<F5C=&]R>2!I<R!N:65T(&QE96<`3FEE="!I;B!S
M=&%A="!61E,@9&ER96-T;W)Y(')E8W5R<VEE9B!T92!V97)W:6ID97)E;BX`
M3FEE="!I;B!S=&%A="!61E,@9&ER96-T;W)Y('1E('9E<G=I:F1E<F5N+@!.
M:65T(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@)7,@=&4@=F5R=VEJ9&5R96XN
M`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@(B5S(B!T92!V97)W:6ID97)E
M;BX`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T92!V97)W:6ID97)E;BX`
M3FEE="!I;B!S=&%A="!61E,@;6%P("(E<R(@=&4@=F5R=VEJ9&5R96XN`$YI
M970@:6X@<W1A870@5D93("5S(')E8W5R<VEE9B!T92!V97)W:6ID97)E;BX`
M3FEE="!I;B!S=&%A="!H=6ED:6=E(&1I<F5C=&]R>2!T92!B97!A;&5N+@!.
M:65T(&EN('-T86%T(&-E<G1I9FEC86%T9&5T86EL<R!U:70@=&4@9FEL=&5R
M96X`3FEE="!I;B!S=&%A="!O;2!D92!D969I;FET:64@=F%N("5S('1E(&QA
M9&5N+@!.:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E('9E<G!L86%T<V5N
M+@!.:65T(&EN('-T86%T(%9&4R!B97-T86YD("(E<R(@=&4@;W!E;F5N+@!.
M:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E(&]P96YE;B!V;V]R('-C:')I
M:G9E;BX`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T92!O<&5N96XN`$YI
M970@:6X@<W1A870@:&5T(&EN9V5P86MT92!B97-T86YD('1E(&]P96YE;BX`
M3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T92!L97IE;B`H9FEL97-I>F4H
M*2!M:7-L=6MT*2X`3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T92!L97IE
M;B`H9V5T1FEL95-I>F4H*2!M:7-L=6MT*2X`3FEE="!I;B!S=&%A="!B97-T
M86YD('1E(&QE>F5N.B``3FEE="!I;B!S=&%A="!V9G-R;V]T(&1I<F5C=&]R
M>2!T92!O<&5N96XN`$YI970@:6X@<W1A870@;VT@)7,@=&4@:&5R;F]E;65N
M(&YA87(@)7,Z(&)E<W1E;6UI;F=S;6%P(&)E<W1A870@86P`3FEE="!I;B!S
M=&%A="!61E,@9&ER96-T;W)Y('1E(&AE<FYO96UE;BX`3FEE="!I;B!S=&%A
M="!61E,@9&ER96-T;W)Y("5S('1E(&AE<FYO96UE;BX`3FEE="!I;B!S=&%A
M="!61E,@8F5S=&%N9"`B)7,B('1E(&AE<FYO96UE;BX`3FEE="!I;B!S=&%A
M="!61E,@8F5S=&%N9"`E<R\E<R!T92!H97)N;V5M96XN`$YI970@:6X@<W1A
M870@5D93(&)E<W1A;F0@=&4@:&5R;F]E;65N+@!+86X@)VUK:7-O9G,G(&YI
M970@=6ET=F]E<F5N+@!.:65T(&EN('-T86%T(&1I="!7;W)D(&1O8W5M96YT
M('1E('9E<G1A;&5N`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@(B5S(B!T
M92!S8VAR:6IV96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@<V-H
M<FEJ=F5N("AC;W!Y*"D@9F%I;&5D*2X`3FEE="!I;B!S=&%A="!61E,@8F5S
M=&%N9'-D871A('1E('-C:')I:G9E;BX`3FEE="!I;B!S=&%A="!61E,@8F5S
M=&%N9"!T92!S8VAR:6IV96XL('%U;W1A('=O<F1T(&]V97)S8VAR961E;BX`
M3VYD97)S=')E<&5N`$AE<G-T96P@=VEJ>FEG:6YG96X`1&]E="!U=R!L86%T
M<W1E(&)E=V5R:VEN9R!T96YI970`3VYV97)W86-H="!A;G1W;V]R9"!V86X@
M9&4@<V5R=F5R(&]P('9E<F)I;F1I;F<Z(`!/;G9E<G=A8VAT(&%N='=O;W)D
M('9A;B!S97)V97(@86%N.B``3VYB96YO96UD`%5N:6-O9&4@*%541BTX*0!6
M97)E;FEG9&4@07)A8FES8VAE($5M:7)A=&5N`%9E<F5N:6=D($MO;FEN9VMR
M:6IK`%9E<F5N:6=D92!3=&%T96X`5F5R96YI9V1E(%-T871E;BP@:VQE:6YE
M(&)U:71E;B!L:6=G96YD92!E:6QA;F1E;@!%96YH961E;@!/;F)E:V5N9`!/
M;F)E:V5N9"!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!/;F)E:V5N9"!C
M;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!/;F)E:V5N9&4@;&]C871I
M92!O<&=E9V5V96XN`$]N8F5K96YD92!G96)R=6EK97)S;F%A;2!O9B!W86-H
M='=O;W)D+@!(970@:'5I9&EG92!E;&5M96YT(&QO<VMO<'!E;&5N`$]N8F5N
M;V5M9`!.:65T(&=E<F5C:'1I9V1E('-C<FEP=',@:W5N;F5N('!R;V=R86UM
M86UA=&EG(&YI970@2VYI<'!E;B]+;W!IZW)E;B]0;&%K:V5N+"!V86YW96=E
M(&)E=F5I;&EG:6YG<W)E9&5N96XN($ML:6L@;W`@3TL@;VT@965N('1E8VAN
M:7-C:&4@;W!M97)K:6YG(&]P(&UO>FEL;&$N;W)G('1E(&)E:VEJ:V5N(&AO
M92!U(&5E;B!S8W)I<'0@=&]E<W1A870@:&5T('!R:6MB;W)D('1E(&)E;F%D
M97)E;BX`2VQE=7(@=&5R=6=S=&5L;&5N`$YI970@;VYD97)S=&5U;F1E(&5X
M=&5N=&EE`$)I:G=E<FME;@`E<R!B:6IW97)K96X`1V5B<G5I:V5R(&)I:G=E
M<FME;BX`(B5S(B!B:6IG97=E<FMT+@!5<&=R861E('-C<FEP="!V97)W:6ID
M97)D+@!5<&QO860`06QL92!T;V5P87-S:6YG('-E='5P8F5S=&%N9&5N(&YA
M87(@9&4@<V5R=F5R(&=E=7!L;V%D+@!,871I:FYS92!H;V]F9&QE='1E<G,`
M1W)O=&4@4F]M96EN<V4@9V5T86QL96X`57)U9W5A>0!'96)R=6EK(&AU:61I
M9V4Z("5S`$=E8G)U:6L@4U-,`$=E8G)U:6ME;B!W86YN965R(&YA86TO=V%C
M:'1W;V]R9"!V97)S8VAI;'0@;65T($E-4U`@<V5R=F5R+@!'96)R=6EK97(`
M1V5B<G5I:V5R("5S(&ES(&YI970@9V5A=71O<FES965R9"!V;V]R("5S+@!'
M96)R=6EK97)S8F5H965R`$=E8G)U:6ME<G-O<'1I97,`1V5B<G5I:V5R<W)E
M9VES=')A=&EE`$=E8G)U:6ME<G-R96=I<W1R871I92!I<R!U:71G97-C:&%K
M96QD(&]P(&1E>F4@<VET92X`1V5B<G5I:V5R<V%C8V]U;G0@;FEE="!G979O
M;F1E;BX`1V5B<G5I:V5R<VYA86T`1V5B<G5I:V5R<VYA86T@(B5S(B!B97-T
M86%T(&%L+@!'96)R=6EK97)S;F%A;3H`1V5B<G5I:V5R<VYA86TZ(`!'96)R
M=6EK97)S(&EN(&AE="!S>7-T965M.@!/97IB96MI<W1A;@!61E,@9&ER96-T
M;W)Y(&)E<W1A870@;FEE="X`069W97II9VAE:60`1V5V;VYD96X@9V5L9&EG
M92!L;V-A=&EE<R!B979A='1E;CH@`$=E;&1I9VAE:60`5V%A<F1E(&EN(&UI
M;G5T96X@=F%N868@;G4N`%=A87)D92!L:6=T(&)O=F5N(&1E(&UA>&EM=6T@
M;&5N9W1E('9A;B`E<RX`5V%A<F1E;@!786%R9&5N('=A87)U:70@9V5S96QE
M8W1E97)D(&MA;B!W;W)D96X`5F%N=6%T=0!687)I86)E;&4`5F5N97IU96QA
M`%9E<FEF:6-A=&EE(&UI<VQU:W0@+2!E<B!K86X@;65T(&1I="!B97)I8VAT
M(&=E:VYO96ED('II:FXN`%9E<G-I90!697)S:65C;VYT<F]L90!697)T:6MA
M86P@=6ET;&EJ;F5N`%9E<G1I:V%L92!V<FEJ92!R=6EM=&4`5F5R=&EK86%L
M.@!%<F<@:&]O9P!6:65T;F%M`%9I971N86UE97,@*%9)4T-)22D`)7,@8F5K
M:6IK96X`0F5K:6IK(&5E;B!E>'1E<FYE('=E8G!A9VEN80!"96MI:FME;B!A
M;',@)7,`36%A9V1E;B!E:6QA;F1E;BP@0G)I='-E`$UA86=D96X@96EL86YD
M96XL(%8N4RX`6FEC:'0`6FEC:'0Z(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU4
M4`!705).`%=!05)30TA55TE.1R$A(2`@5D525TE*1$52(%-#4DE05"!(04Y$
M34%424<@54E4("5S+@!724X@=FEA($A45%``5V%L;&ES(&5N($9U='5N80!7
M86%R<V-H=7=I;F<`5V\`5V5E<G-V;V]R=6ET>FEC:'0`5V5E<F)E<FEC:'0@
M9V5G979E;G,@9V5L979E<F0@9&]O<@!796%T:&5R+F-O;0!796(`5V5B<VET
M90!796ME;&EJ:W,`5V5L:V]M`%=E;&MO;2!B:6H@)7,`5V5L:V]M+"`E<P!7
M97-T97)S("A)4T\M.#@U.2TQ*0!797-T97)S("A)4T\M.#@U.2TQ-2D`5V5S
M=&5L:6IK92!386AA<F$`5V5L:V4@=&]E<&%S<VEN9R!D:65N="`E<R!W965R
M('1E(&=E=F5N(&YA(&%A;FUE;&1I;F<_`%=A="!I<R!H970@<V-H96ED:6YG
M<VMA<F%K=&5R/P!7870@:7,@:&5T(&-I=&%A=&MA<F%K=&5R/P!7:&5R96ES
M($%U<W1R86QIZR!K86%R=`!796QK92!F87-E;@!796QK92!P;'5G:6YS('9O
M;W(@9&4@4FEC:"!497AT(&5D:71O<B!I;G-C:&%K96QE;BX`0G)E961T90!"
M<F5E9'1E(&EN($-34R!E96YH961E;@!"<F5E9'1E('9A;B!H970@)7,@;65N
M=2!A86X@9&4@;&EN:V5R:V%N="`H86MT:65F(&)I:B!V;VQG96YD92!A86YM
M96QD:6YG*3H`0G)E961T92!V86X@9&4@=&%B96P`0G)E961T92!E96YH96ED
M`$)R965D=&4Z`%=I:VD`5VEN9`!7:6YD('9R;V5G`%=I;F1S;F5L:&5I9"!I
M;B!K;F]P96X`5VEN9#H`5VEN9#H@`%=I:G-H96ED`%=E;G-L:6IS=`!797)K
M`%=E<FMA9')E<P!496PN;G(N("AW97)K*0!697)K965R9"!A86YT86P@=F5L
M9&5N(&EN(')E9V5L("5D+B!697)W86-H="`E9"P@9V5V;VYD96X@)60N`%9E
M<FME97)D(&%A;G1A;"!V96QD96XN(%9E<G=A8VAT("5D+"!G979O;F1E;B`E
M9"X`5F5R:V5E<F1E(&]F9G-E="`E9"!B:6H@;&5Z96X@=F%N(%9&4R!B97-T
M86YD+@!8+5)E9@!8-3`Y=C,@8F%S:7-B97!E<FMI;F=E;@!8-3`Y=C,@=6ET
M9V5B<F5I9"!S;&5U=&5L9V5B<G5I:P!8-3`Y=C,@86QT97)N871I979E(&]N
M9&5R=V5R<&YA86T`6#4P.78S(&]N9&5R=V5R<"!S;&5U=&5L:61E;G1I9FEC
M871O<@!8-3`Y=C,@97AT96YT:65S`$I*`$I*2DH`66%H;V\A(&UA<`!*86%R
M;&EJ:W,`2F5M96X`2F$`2F$L(&EK(&%C8V5P=&5E<B!D92!V;V]R=V%A<F1E
M;@!5(&)E;G0@:6X@5$5+4U0@34]$12X@1V5B<G5I:R!D92!;/#Y=(&MN;W`@
M;VT@;F%A<B!765-)5UE'('1E<G5G('1E('-C:&%K96QE;BX`2&5T(&ES('4@
M;FEE="!T;V5G97-T86%N(&]M(&UE97(@9&%N("5D(&)L;VMK96X@=&4@;6%K
M96XN`%4@8F5N="!N:65T(&=E875T:&5N=&EF:6-E97)D+@!5(&MU;G0@9V5E
M;B`G7"<@:V%R86MT97(@:6X@=7<@=F]L;&5G92!N86%M(&AE8F)E;BX`52!H
M965F="!G965N(&=E;&1I9R!E+6UA:6QA9')E<R!O<&=E9V5V96XN`%4@:&5E
M9G0@9V5E;B!V96QD96X@=6ET(&AE="!G96EM<&]R=&5E<F1E(&)E<W1A;F0@
M9V5K;W!P96QD(&UE="!D92!O=F5R965N:V]M<W1I9V4@=F5L9&5N(&EN("5S
M+@!5(&)E;G0@869G96UE;&0N`%4@9&EE;G0@965N(&=E;&1I9R!M;V)I96P@
M;G5M;65R(&EN('1E('9O97)E;BP@86QL965N(&-I:F9E<G,@;65T(&5E;B!O
M<'1I;VYE;&4@)RLG('9O;W(@:&5T(&EN=&5R;F%T:6]N86QE(&MI97-V;V]R
M=F]E9W-E;"X`52!D:65N="!E96X@9V5L9&EG92!W86%R9&4@;W`@=&4@9V5V
M96XN`%4@9&EE;G0@965N($1A=&%4<F5E(&)A8VME;F0@=&4@8V]N9FEG=7)E
M<F5N(&]M(&EN<V-H<FEJ=FEN9V5N('1E(&MU;FYE;B!G96)R=6EK96XN`%4@
M9&EE;G0@965N(%9&4R!B86-K96YD('1E(&-O;F9I9W5R97)E;BX`52!D:65N
M="!H970@<')O8FQE96T@=&4@8F5S8VAR:6IV96XL('9O;W)D870@=2!H970@
M<')O8FQE96UR87!P;W)T(&MU;G0@=F5R>F5N9&5N+@!5(&1I96YT(&5E;B!5
M4DP@:6X@=&4@=F]E<F5N('=A87)N86%R(&1E>F4@;&EN:R!V97)W:6IS=`!5
M(&1I96YT(&5E;B!S97)V97(@=&4@<V5L96-T97)E;B!O;2!T92!V97)W:6ID
M97)E;BX`52!D:65N="!E96X@9V5B<G5I:V5R<VYA86T@;W`@=&4@9V5V96X@
M;VT@=&4@=VES<V5N+@!5(&1I96YT(&5E;B!G96)R=6EK97)S;F%A;2!O<"!T
M92!G979E;B!O;2!T92!V97)W:6ID97)E;BX`52!D:65N="!E96X@9V5B<G5I
M:V5R<VYA86T@;W`@=&4@9V5V96X@;VT@=&]E('1E('9O96=E;BX`52!D:65N
M="!E96X@9V5B<G5I:V5R<VYA86T@;W`@=&4@9V5V96X@;VT@8FEJ('1E(&MU
M;FYE;B!W97)K96XN`%4@9&EE;G0@965N(&)E=V5R:VEN9R!O<"!T92!G979E
M;B!W96QK92!U:71G979O97)D(&UO970@=V]R9&5N+@!5(&1I96YT(&5E;B!N
M:65U=V4@8V%T96=O<FEE;F%A;2!O<"!T92!G979E;BX`52!D:65N="!E96X@
M271A;&EA86YS('1E;&5F;V]N;G5M;65R(&]P('1E(&=E=F5N`%5W("5S('-E
M<W-I92!I<R!V97)L;W!E;BX@3W!N:65U=R!A86YM96QD96XL(&$N=2YB+@!5
M=R!E+6UA:6QA9')E<P!5=R!686XZ(&%D<F5S.@!5=R!I;F9O<FUA=&EE`%5W
M(&EN=&5R;F5T861R97,@:7,@9V5W:6IZ:6=D('-I;F1S(&AE="!B96=I;B!V
M86X@=7<@)7,@<V5S<VEE+B!/;2!U=R!V96EL:6=H96ED('1E(&)E<V-H97)M
M96XL(&1I96YT('4@>FEC:"!O<&YI975W(&%A;B!T92!M96QD96XN`%5W(&YA
M86TZ`$AE="!T;V5V;V5G96X@=F%N(&=E8G)U:6ME<G,@=V]R9'0@;FEE="!O
M;F1E<G-T975N9"!D;V]R('5W(&%U=&AE;G1I8V%T:64@8F%C:V5N9"X@5V%N
M;F5E<B!U($AO<F1E(&=E8G)U:6ME<G,@=VEL="!B96AE<F5N+"!D:65N="!U
M(&5E;B!A;F1E<B!A=71H96YT:6-A=&EE(&)A8VME;F0@=&4@9V5B<G5I:V5N
M+@!(970@=V5E<F=E=F5N('9A;B!E96X@9V5B<G5I:V5R<VQI:G-T('=O<F1T
M(&YI970@;VYD97)S=&5U;F0@9&]O<B!U=R!A=71H96YT:6-A=&EE(&)A8VME
M;F0L(&]F(&1E>F4@;W!T:64@:7,@;VT@86YD97)E(')E9&5N96X@=6ET9V5S
M8VAA:V5L9"X`57<@8G)O=W-E<B!L:6IK="!T92!Z:6IN(&=E=VEJ>FEG9"!S
M:6YD<R!H970@8F5G:6X@=F%N('5W("5S('-E<W-I92X@3VT@=7<@=F5I;&EG
M:&5I9"!T92!B97-C:&5R;65N+"!D:65N="!U('II8V@@;W!N:65U=R!A86X@
M=&4@;65L9&5N+@!5=R!B<F]W<V5R(&]N9&5R<W1E=6YT(&1E>F4@;6]G96QI
M:FMH96ED(&YI970N`%5W(&)R;W=S97(@;VYD97)S=&5U;G0@9&5Z92!P<FEN
M=&]P=&EE(&YI970N($1R=6L@;W`@0V]N=')O;"]#;VUM86YD("L@4"!O;2!A
M9B!T92!D<G5K:V5N+@!5=R!H=6ED:6=E('1I:F1Z;VYE.@!5=R!S=&%N9&%A
M<F0@:61E;G1I=&5I="!I<R!G97=I:GII9V0N`%5W('-T86YD86%R9"!I9&5N
M=&ET96ET.@!5=R!V;VQL961I9V4@;F%A;3H`57<@86%N;65L9&EN9R!I<R!V
M97)L;W!E;BX`57<@;FEE=7=E('=A8VAT=V]O<F0@=F]O<B`E<R!I<SH@)7,`
M57<@;W!T:65S('II:FX@8FEJ9V5W97)K="!V;V]R(&1E(&1U=7(@=F%N(&1E
M>F4@<V5S<VEE+@!5=R!O<'1I97,@>FEJ;B!B:6IG97=E<FMT+@!5=R!W86-H
M='=O;W)D(&ES(&=E<F5S970`57<@=V%C:'1W;V]R9"!I<R!V97)N:65U=V0L
M(&-O;G1R;VQE97(@=7<@92UM86EL(&5N(&UE;&0@86%N(&UE="!U=R!N:65U
M=V4@=V%C:'1W;V]R9"X`57<@=V%C:'1W;V]R9"!I<R!V97)L;W!E;BX`57<@
M<V5R=F5R<R!O<"!A9G-T86YD.@!*;V5G;W-L879IZP!:8>]R90!:86UB:6$`
M6FEM8F%B=V4`6FEP<'D`6U9E<F)E<F<@86%N9V5H86%L9&4@=&5K<W1=`%M0
M<F]B;&5E;7)A<'!O<G1=`%M!86YG96AA86QD92!T96MS="!W965R9V5V96X@
M+0!;06%N9V5H86%L9&4@=&5K<W0@+2`E<R!R96=E;'-=`%MR96=E;"`E<R!V
M86X@)7-=`$)?96AE97(`7T-,20!?1&%T851R964`5F5R7W=I:F1E<B!R:6H`
M7T=R;V5P96X`7TAE;'``7T%F8F5E;&1I;F=S96EG96YS8VAA<'!E;BXN+@!?
M06%N;65L9&5N`%]!9FUE;&1E;@!?5VEJ>FEG(&QI;FLN+BX`7T]P=&EE<P!?
M4F5C:'1E;@!?5F5R=VEJ9&5R(&QI;FLN+BX`7TEN<W1E;&QE;@!?5&%B96QE
M:6=E;G-C:&%P<&5N+BXN`$=E7V)R=6EK97)S`$%D<F5S8F]E:P!'96%D<F5S
M<V5E<F1E(&]N8F5K96YD`$MA;&5N9&5R`$MA;&T`2V%N(&]U='!U=&)E<W1A
M;F0@;FEE="!M86ME;@!+86X@:6YP=70@;FEE="!O<&5N96X`2VQI:R!H:65R
M`$-O;6UA;F1O<F5G96P@9V5B<G5I:W-F;W5T`$-O;F9I9W5R871I969O=70`
M2W)I=&ES8V@@<WES=&5E;6)E<W1A;F0@;VYT8G)E96MT`$1A=&%F;W)M86%T
M9F]U=`!B97=E<FME;@!I;G9O97(@;FEE="!G979O;F1E;@!D86QE;F0`8F5S
M=&%N9`!V86X@9&4@)7,@*"5S*2!O<"`E<R`E<P!V;&%G97)I9P!H.@!H:`!H
M;W-T;F%A;2!O;F)E:V5N9`!O;FUI9&1E;&EJ:P!I;FQI;F4`:6YP=70O;W5T
M<'5T(&9O=70`:6YT97)N92!S;V9T=V%R969O=70`<F5G96QS70!M:VES;V9S
M(&9O=71C;V1E("5D(&)I:B!H970@86%N;6%K96X@=F%N($E33RX`;6T`;F%A
M;0!N:65T('9A;B!T;V5P87-S:6YG`$YO9R!N:65T('9A;B!T;V5P87-S:6YG
M`&YO=&ET:65B;V5K`'!R;V-E;G0`4F5C:'0@9V5W96EG97)D`'!I>&5L<P!2
M96UO=&4@9F]U="!I;B!P<F]T;V-O;`!S=&EJ9V5N9`!397)V:6-E(&YI970@
M8F5S8VAI:V)A87(`=&]O;B!V97)S8VAI;&QE;@!S;7,R96UA:6P@=FEA($A4
M5%``<W,`<W1A8FEE;`!S>7-T965M9F]U=`!T86ME;FQI:G-T`'1I:F1E;&EJ
M:V4@;6ES;'5K:VEN9P!6;V5R+"!T97(@8F5V97-T:6=I;F<L(&AE="!W86-H
M='=O;W)D('1W964@;6%A;"!I;@!U;FEF:65D`&]N8F5N;V5M9`!'96)R=6EK
M97)S96QE8W1I90!V0V%R9`!W.@!W96%T:&5R+F-O;0``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O;FY?3D\O````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-3$U-#,S-S4S`#`R,#$R-``@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L
M92]N;E].3R]H96QP+GAM;```````````````````````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#,S,C``,3`U,34T,S,W-3,`,#(Q-3<T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_>&UL('9E<G-I;VX]
M(C$N,"(_/@H\(2TM("1(;W)D93H@:&]R9&4O;&]C86QE+VYN7TY/+VAE;'`N
M>&UL+'8@,2XR(#(P,#0O,#4O,C<@,C`Z,C(Z,3,@:F%N($5X<"`D("TM/@H\
M:&5L<#X*("`\96YT<GD@:60](G-U;6UA<GDB('-T871E/2)N97<B/@H\=&ET
M;&4^5&AE(%!O<G1A;"!086=E/"]T:71L93X*(#QP87)A/@H@(%1H:7,@<&]R
M=&%L('!A9V4@<')O=FED97,@82!Q=6EC:R!S=6UM87)Y(&]F(&%L;"!Y;W5R
M(&EM<&]R=&%N=`H@(&EN9F]R;6%T:6]N+B!&;W(@97AA;7!L92P@:70@;6EG
M:'0@<VAO=R!H;W<@;6%N>2!N97<@92UM86EL(&UE<W-A9V5S('EO=0H@(&AA
M=F4@:6X@>6]U<B!)3D)/6"P@=7!C;VUI;F<@979E;G1S(&]N('EO=7(@8V%L
M96YD87(L('1A<VMS(&]N('EO=7(@=&\M9&\*("!L:7-T+"!H96%D;&EN97,@
M9G)O;2!S96QE8W1E9"!N97=S('-E<G9I8V5S+"!A;F0@<V\@;VXN("!-86YY
M(&]F('1H97-E"B`@<W5M;6%R:65S('=I;&P@8V]N=&%I;B!Q=6EC:R!S:&]R
M=&-U=',@=&\@8V]M;6]N(&9U;F-T:6]N<RP@<W5C:"!A<PH@(&-O;7!O<VEN
M9R!A(&YE=R!M86EL(&UE<W-A9V4L(&-R96%T:6YG(&$@;F5W(&-A;&5N9&%R
M(&5V96YT(&]R('1A<VLL(&5T8RX*(#PO<&%R83X*(#QP87)A/@H@(%1H92!C
M;VYT96YT<R!O9B!T:&ES('!O<G1A;"!P86=E(&%R92!C=7-T;VUI>F%B;&4@
M=FEA('1H92!,87EO=70@8G5T=&]N+@H@($9O<B!E>&%M<&QE+"!Y;W4@8V%N
M(&-H;V]S92!W:&EC:"!I=&5M<R!T;R!I;F-L=61E(&]N('1H:7,@<&]R=&%L
M('!A9V4@87,*("!W96QL(&%S(&EN('=H:6-H(&]R9&5R('1H97D@87)E('-H
M;W=N+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;F%V8F%R(B!S
M=&%T93TB;F5W(CX*/'1I=&QE/E1H92!!<'!L:6-A=&EO;B!.879I9V%T:6]N
M($)A<CPO=&ET;&4^"B`\<&%R83X*("!!="!T:&4@;&5F="!H86YD('-I9&4@
M;V8@=&AE('=E8B!P86=E(&ES('1H92!A<'!L:6-A=&EO;B!N879I9V%T:6]N
M(&)A<BX*("!#;&EC:R!O;B!T:&4@:6-O;G,@;VX@=&AI<R!N879I9V%T:6]N
M(&)A<B!T;R!Q=6EC:VQY(&%N9"!E87-I;'D@<W=I=&-H"B`@8F5T=V5E;B!T
M:&4@879A:6QA8FQE(&%P<&QI8V%T:6]N<RX*(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](G!R969S+61O7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W
M(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($1O($UA
M:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD
M(&QI:V4@=&\@<&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO
M9VEN+"!C:&5C:R!T:&ES(&)O>"X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](G!R969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B('-T871E/2)N
M97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@0V]N
M9FER;2!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO
M=2!W;W5L9"!L:6ME('1O(&-O;F9I<FT@86QL(&UA:6YT96YA;F-E('1A<VMS
M(&)E9F]R92!T:&5Y(&%R92!R=6XL(&-H96-K('1H:7,@8F]X+B!)9B!L969T
M('5N8VAE8VME9"P@86QL(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@=&AA="!N
M965D('1O(&)E(')U;B!W:6QL(&)E('!E<F9O<FUE9"!A=71O;6%T:6-A;&QY
M('=I=&@@;F\@8VAA;F-E('1O(&-A;F-E;"!O;B!L;V=I;BX*("`@(#PO<&%R
M83X*/"]E;G1R>3X*/"]H96QP/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O;FY?
M3D\O3$-?34534T%'15,O````````````````````````````````````````
M`````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-3$U-#,S-S4S`#`R,3<Q,0`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQO8V%L92]N;E].3R],0U]-15-304=%4R]H;W)D92YM;P``````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C,R,#$`,3`U,34T,S,W-3,`,#(S,S0U
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````-X2
M!)4`````F0```!P```#D!```TP```*P)````````^`P```L```#Y#```*```
M``4-```5````+@T```@```!$#0``!0```$T-```#````4PT```\```!7#0``
M"````&<-```(````<`T``!D```!Y#0``!P```),-```,````FPT```X```"H
M#0``!0```+<-```?````O0T``#D```#=#0``)P```!<.```L````/PX``"H`
M``!L#@``$0```)<.```(````J0X```@```"R#@``!@```+L.```5````P@X`
M``H```#8#@``$0```.,.```,````]0X```<````"#P``$`````H/```K````
M&P\``!X```!'#P``&P```&8/```;````@@\``#,```">#P``+P```-(/```I
M`````A````(````L$```!0```"\0```0````-1````8```!&$```%````$T0
M```O````8A````\```"2$```)@```*(0```$````R1````4```#.$```#0``
M`-00```%````XA```!````#H$```$````/D0```/````"A$```L````:$0``
M#P```"81```,````-A$```\```!#$0``'@```%,1```A````<A$```,```"4
M$0``#````)@1```4````I1$```8```"Z$0``!````,$1```,````QA$```H`
M``#3$0``!0```-X1```2````Y!$``!````#W$0``"`````@2```0````$1(`
M`!H````B$@``!@```#T2```'````1!(```(```!,$@``)0```$\2```$````
M=1(```\```!Z$@``!P```(H2```'````DA(```D```":$@``!P```*02```2
M````K!(```0```"_$@``!P```,02```%````S!(``#,```#2$@``&@````83
M```%````(1,```<````G$P``$0```"\3```(````01,``!4```!*$P``'@``
M`&`3```H````?Q,```L```"H$P``&@```+03```%````SQ,``"@```#5$P``
M*0```/X3```3````*!0``#(````\%```!````&\4```&````=!0```L```![
M%```!0```(<4```1````C10```0```"?%```#````*04```:````L10``!<`
M``#,%```%P```.04```;````_!0``!D````8%0``'P```#(5```3````4A4`
M``0```!F%0``$````&L5```7````?!4```<```"4%0``!0```)P5```Q````
MHA4``#@```#4%0``(0````T6```<````+Q8```4```!,%@```P```%(6```@
M````5A8``"8```!W%@``#````)X6```&````JQ8``!,```"R%@``#````,86
M```(````TQ8``!0```#<%@``!P```/$6```&````^18```T`````%P``"P``
M``X7```,````&A<```H````G%P```@```#(7```&````-1<```P````\%P``
M10```$D7```F````CQ<``"4```"V%P``,````-P7```0````#1@``',````>
M&```'P```)(8```0````LA@```\```##&```!0```-,8``!B`0``V1@```H`
M```\&@``*````$<:```4````<!H```@```"%&@``!0```(X:```(````E!H`
M`!,```"=&@``#````+$:```/````OAH``!X```#.&@``!P```.T:```*````
M]1H```X`````&P``!0````\;```C````%1L``#L````Y&P``+0```'4;```O
M````HQL``"X```#3&P``$P````(<```'````%AP```@````>'```!@```"<<
M```5````+AP```P```!$'```%@```%$<```.````:!P```4```!W'```$```
M`'T<```K````CAP``!T```"Z'```(````-@<```<````^1P``#`````6'0``
M-@```$<=```L````?AT```(```"K'0``!@```*X=```1````M1T```8```#'
M'0``$0```,X=```F````X!T``!$````''@``(P```!D>```%````/1X```8`
M``!#'@``#@```$H>```$````61X``!````!>'@``$````&\>```/````@!X`
M``\```"0'@``#P```*`>```,````L!X``!````"]'@``'P```,X>```C````
M[AX```0````2'P``#0```!<?```4````)1\```<````Z'P``!0```$(?```/
M````2!\```\```!8'P``!0```&@?```3````;A\``!````""'P``!0```),?
M```2````F1\``"````"L'P``"````,T?```'````UA\```(```#>'P``)0``
M`.$?```&````!R```!`````.(```"0```!\@```'````*2````D````Q(```
M"````#L@```5````1"````0```!:(```"````%\@```%````:"```#@```!N
M(```(````*<@```'````R"````H```#0(```$0```-L@```'````[2```!4`
M``#U(```'`````LA```L````*"$```<```!5(0``%@```%TA```'````="$`
M`"4```!\(0``)````*(A```6````QR$``"\```#>(0```P````XB```%````
M$B(```D````8(@``"0```"(B```6````+"(```4```!#(@``$````$DB```9
M````6B(```\```!T(@``#P```(0B```8````E"(``!````"M(@``$````+XB
M```3````SR(```,```#C(@``%0```.<B```:````_2(```<````8(P``"```
M`"`C```I````*2,``#4```!3(P``'@```(DC```>````J",```8```#'(P``
M`P```,XC```>````TB,``"@```#Q(P``#P```!HD```(````*B0``!0````S
M)```$````$@D```*````620``!0```!D)```"````'DD```)````@B0```\`
M``",)```#````)PD```/````J20```\```"Y)````@```,DD```%````S"0`
M``X```#2)```.@```.$D```J````'"4``"T```!')0``,@```'4E```/````
MJ"4``'D```"X)0``)@```#(F```0````628``!````!J)@``!0```'LF```!
M````;@````````"+````!@```````````````````&,````3````#0``````
M````````A@```(`````9````3P```!(````:````=0````D```!V````!```
M`"@````%`````````&T```!(````.````$(`````````80````P`````````
M`````($```"-````0P```&8````L````"``````````W````/@```((```!H
M`````````&H````\````9`````````!$````<0```#````!0````>0```%H`
M``"0````5P```!4`````````$0```)D`````````'`````,`````````AP``
M`#T```!]``````````````!X````:0```"L```")`````````"D`````````
M<``````````+````A0```````````````````(,```"*````````````````
M````>@``````````````)`````````!'````6````!````!*````*@```"8`
M```4``````````````!E````70```)<``````````````',```"4````C@``
M`(\``````````````#4```![````,@```'<``````````````"4```!-````
M50```"T```"$````(@```$8`````````-````%$`````````'P```%(````/
M``````````(````>``````````````"5````DP```$4```!T````C````'\`
M````````,P```'X`````````&````%8``````````````!T`````````````
M`#8`````````)P``````````````B````&\````Q````7P````H`````````
M5````%X````@`````````'(```!G````D@```$D````6````3@````X````[
M````0````$L```!B````&P```&P```"6````4P```#H```!\`````````&L`
M``!,````D0````<````A`````````%D````Y````F````#\````C````8```
M``````!<````%P```$$`````````6P```"X````O`````"5S("T@3F]T:6-E
M`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@
M5&5R;7,@;V8@06=R965M96YT`#(T(&AO=7)S`$%-+U!-`$%D9`!!9&0@82!N
M97<@=7-E<CH`061D('!A:7(`061D('5S97(`061D:6YG('5S97)S(&ES(&1I
M<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=')A=&EO;@!!
M;&EA<P!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%S:R!F;W(@
M8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I
M;VYS/P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`
M071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`
M071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%V
M86EL86)L92!F:65L9',Z`$)I<G1H9&%Y`$-A;&5N9&%R`$-A;F-E;`!#86YC
M96P@4')O8FQE;2!297!O<G0`0V5L;"!0:&]N90!#;&EC:R!T;R!#;VYT:6YU
M90!#;&]S92!7:6YD;W<`0V]M<&%N>0!#;VYF:7)M(%!A<W-W;W)D`$-O;FYE
M8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]U;&0@
M;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@<VEG;B!M
M97-S86=E+@!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T
M(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O
M=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N
M`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$1$
M`$1A:6QY`$1E9F%U;'0@261E;G1I='D`1&5L971E`$1E<V-R:6)E('1H92!0
M<F]B;&5M`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN
M:7-T<F%T;W(N`$1I<W!L87D@3W!T:6]N<P!$;R!N;W0@9&ER96-T;'D@86-C
M97-S(&UA:6YT96YA;F-E+G!H<`!%9&ET`$5M86EL`$5M<'1Y(')E<W5L="X`
M17)R;W(`179E<GD@,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y
M(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@
M;6EN=71E`$5X86UP;&4@=F%L=65S.@!&86EL960@<F5T<FEE=FEN9R!P<F5F
M97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A
M>`!&:6QE($UA;F%G97(`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7!S`$AE
M;'``2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]R9&4`26UP;W)T960@9FEE
M;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`3&%N9W5A9V4`3&ES="!(96QP(%1O
M<&EC<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,;V<@:6X`3&]G(&]U
M=`!-30!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$UA
M:6P`36%T8VAI;F<@9FEE;&1S`$UE;6)E<G,`365S<V%G90!-:6UE(%1Y<&4`
M36]N=&AL>0!.3RP@22!$;R!.3U0@06=R964`3F%M90!.971W;W)K`$YE=F5R
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44P@5D93+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;W1E<P!/<'1I
M;VYS`$]T:&5R($EN9F]R;6%T:6]N`%!A<W-W;W)D`%!A<W-W;W)D<R!M=7-T
M(&UA=&-H+@!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R
M;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N
M<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!0:&]N90!0;&5A<V4@<')O
M=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E
M('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!R;V)L96T@1&5S8W)I<'1I
M;VX`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E
M<W-F=6QL>2X`4F5A9`!296UO=F4`4F5M;W9E('!A:7(`4F5S970`4F5T=7)N
M('1O($]P=&EO;G,`4F]L90!3879E($]P=&EO;G,`4V5L96-T('1H92!D871E
M(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H
M92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E
M;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D
M(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-H;W<`4VMI<"!-86EN
M=&5N86YC90!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3=6-C97-S`%1A<VMS
M`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S
M9G5L;'D`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R
M92!W96(@8V]N;F5C=&EO;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S
M="!O;F4N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&ET;&4`55),
M`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!T
M<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N9&\@0VAA;F=E<P!5<&1A
M=&4`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<FYA;64`
M57-E<G,@:6X@=&AE('-Y<W1E;3H`5V%R;FEN9P!7965K;'D`5V5L8V]M92!T
M;R`E<P!796QC;VUE+"`E<P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!960!9
M96%R;'D`665S+"!)($%G<F5E`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B
M;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9
M;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S
M="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=7(@)7,@<V5S<VEO
M;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($EN9F]R
M;6%T:6]N`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S
M=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N
M(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!O<'1I;VYS
M(&AA=F4@8F5E;B!U<&1A=&5D+@!;4')O8FQE;2!297!O<G1=`%ML:6YE("5S
M(&]F("5S70!V0V%R9`!0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,"UC
M=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*
M4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2
M979I<VEO;BU$871E.B`R,#`R+3`V+3`X(#(R.C,P*S`Q,#`*3&%S="U4<F%N
M<VQA=&]R.B!097(M4W1I86X@5F%T;F4@/'!S=D!O<G-T82YO<F<^"DQA;F=U
M86=E+51E86TZ($YO<G=E9VEA;B!.>6YO<G-K(#QN>6YO<G-K0&]R<W1A+F]R
M9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN
M.R!C:&%R<V5T/6ES;RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN
M9SH@.&)I=`H`)7,@+2!.;W1I<P`E<R!V961L:6ME:&%L9'-O<&5R87-J;VYA
M<B`M(%-T861F97-T:6YG`"5S(%9I;&OE<B!F;W(@879T86QE`#(T('1I;6%R
M`$%-+U!-`$QE9V<@=&EL`$QE9V<@=&EL(&YY(&)R=6MA<CH`3&5G9R!T:6P@
M<&%R`$QE9V<@=&EL(&)R=6MA<@!,96=G('1I;"!B<G5K87)A<B!E<B!S;.5T
M="!A=BX`061R97-S90!!9')E<W-E8F]K`$%D;6EN:7-T<F5R:6YG`$%L:6%S
M`$5I;B!U;&]V;&5G('9E<F1I('9A<G0@<W!E<VEF:7-E<G0N`%-P^'(@;VT@
M<W1A9&9E<W1I;F<@9OAR(&OX>7)I;F<@878@=F5D;&EK96AA;&1S;W!E<F%S
M:F]N87(_`%!R^'9D92#E('-L971T92!E:2!I:VMJ92UE:W-I<W1E<F%N9&4@
M9W)U<'!E+@!0<OAV9&4@Y2!S;&5T=&4@96EN(&EK:VIE+65K<VES=&5R86YD
M92!T:6QG86YG+@!0<OAV9&4@Y2!E;F1R92!E:6X@:6MK:F4M96MS:7-T97)A
M;F1E('1I;&=A;F<N`%1I;&=J96YG96QE9V4@9F5L=#H`0G5R<V1A9P!+86QE
M;F1E<@!!=F)R>70`079B<GET('!R;V)L96UR87!P;W)T`$UO8FEL=&5L969O
M;@!+;&EK:R!F;W(@Y2!H86QD92!F<F%M`$QU:VL@=FEN9&%U9V5T`$9I<FUA
M`%-T861F97-T('!A<W-O<F0`3W!P:V]P;&EN9R!M;W0@;V9F96YT;&5G(&[X
M:VME;'1E;F%R(&YE:W1A+@!+=6YN92!I:VMJ92!01U`M:V]D92!M96QD:6YG
M+@!+=6YN92!I:VMJ92!01U`M<VEG;F5R92!M96QD:6YG+@!+=6YN92!I:VMJ
M92!D96MO9&4@4$=0+61A=&$N`$MU;FYE(&EK:VIE(&%V9VIE<F4@;6]T=&%K
M87)E;B!S:2!E+7!O<W1A9')E<W-E+@!+=6YN92!I:VMJ92!S:V%F9F4@;V9F
M96YT;&5G(&[X:VME;"!F<N4@;OAK:V5L=&5N87)E;BX`2W5N;F4@:6MK:F4@
M;W!N92!-86EN=&5N86YC95]487-K+6UO9'5L96X@)7,`1$0`1&%G;&5G`%-T
M86YD87)D:61E;G1I=&5T`%-L971T90!3:VEL9')E('!R;V)L96UE=`!$971A
M;&IA<B!E<B!L;V=G82!F;W(@861M:6YI<W1R871O<F5N+@!6:7-I;F=S86QT
M97)N871I=@!):VMJ92!B<G5K(&UA:6YT96YA;F-E+G!H<"!D:7)E:W1E+@!%
M;F1R90!%+7!O<W0`5&]M="!R97-U;'1A="X`1F5I;`!+=F%R="`Q-2X@;6EN
M=71T`$MV87)T(#,P+B!S96MU;F0`2W9A<G0@-2X@;6EN=71T`$MV87(@:6YN
M;&]G9VEN9P!+=F%R(&AA;'9E('1I;64`2W9A<G0@;6EN=71T`$5K<V5M<&5L
M=F5R9&EA<CH`2W5N;F4@:6MK:F4@:&5N=&4@:6YN<W1I;&QI;F=A<@!+=6YN
M92!I:VMJ92!K;W!L92!T:6P@3$1!4"UT96YA<F5N+@!&86MS`$9I;&AA;F1S
M86UI;F<`1W)U<'!E861M:6YI<W1R97)I;F<`1W)U<'!E<@!(:F5L<`!!9')E
M<W-E+"!P<FEV870`5&5L969O;BP@<')I=F%T`$AO<F1E`$EM<&]R=&5R=&4@
M9F5L=#H@)7,`26UP;W)T97)T92!F96QT.@!3<'+E:P!6:7,@96UN92!F<N4@
M2&IE;'``3&ES=&EN9R!A=B!B<G5K87)A<B!E<B!S;.5T="!A=BX`3&]G9R!I
M;FX`3&]G9R!U=`!-30!-4RU43D5&+79E9&QE9V<@:6YN96AE;&1T(&EN9V5N
M(&1A=&$N`$4M<&]S=`!386US=F%R86YD92!F96QT`$UE9&QE;6UA<@!-96QD
M:6YG`$U)344M='EP90!-Y6YA9&QE9P!.14DL(&5G(&5R($E+2TI%('-A;60`
M3F%M;@!.971T=F5R:P!!;&1R:0!);F=E;B!K;VYF:6=U<F%S:F]N<VEN9F]R
M;6%S:F]N('-P97-I9FES97)T(&9O<B!344P@5D93+@!);F=E;B!G>6QD:6=E
M(%A-3"UD871A(')E='5R;F5R=`!.;W1A=&%R`$%L=&5R;F%T:78`06YN86X@
M:6YF;W)M87-J;VX`4&%S<V]R9`!087-S;W)D82!MY2!S86US=F%R92X`2_AY
M<B!V961L:6ME:&%L9'-O<&5R87-J;VYA<@!+^'ER('9E9&QI:V5H86QD<V]P
M97)A<VIO;F%R('9E9"!I;FYL;V=G:6YG/P!4:6QG86YG`%1I;&=A;F=S861M
M:6YI<W1R97)I;F<`5&5L969O;@!3:W)I=B!I;FX@96ET('-A;6%N9')A9R!A
M=B!P<F]B;&5M970N`%-K<FEV(&EN;B!D:71T(&)R=6MA<FYA;6X@;V<@<&%S
M<V]R9`!3:VEL9')I;F<@878@<')O8FQE;65T`$]F9F5N=&QE9R]P<FEV870@
M;OAK:V5L<&%R('9A<G0@:6MK:F4@9V5N97)E<G0N`$QE<P!&:F5R;@!&:F5R
M;B!P87(`3G5L;'-T:6QL`%1I;&)A:V4@=&EL(&%L=&5R;F%T:78`4F]L;&4`
M3&%G<F4@86QT97)N871I=@!696P@<VMI;&IE=&5I:VX@9F]R(&1A=&\Z`%9E
M;"!D871O9F]R;6%T.@!696P@=&ED<V9O<FUA=#H`5F5L('1O('-A;7-V87)A
M;F1E(&9E;'0N`%9E;"!F87)G97-K:F5M82X`5F5L(/AN<VMA('-P<N5K.@!3
M96YD('!R;V)L96UR87!P;W)T`%9I<P!(;W!P(&]V97(@=F5D;&EK96AA;&0`
M26YN=&%S=&EN9R!A=B!S<&5S:6%L=&5I:VX`4W5K<V5S<P!/<'!GY79E<@!+
M;&%S<V$@36%I;G1E;F%N8V4Z.B!V87)T(&EK:VIE(&QA<W1A(&EN;@!+<GEP
M=&5R:6YG<V9U;FMS:F]N86YE(&MR978@96D@<VEK:V5R(&YE='1O<'!K;W!L
M:6YG+@!$971T92!T86QE="!MY2!V97)E(&UI;G-T(&5I;BX`1&5N;F4@=F5R
M9&EE;B!MY2!V97)E(&5I="!T86PN`%1I='1E;`!54DP`2V%N(&EK:VIE(&MO
M<&QE('1I;"!344PM=&5N87(N`$MA;B!I:VMJ92!O;7-E=&IE(&1E='1E(%=O
M<F0M9&]K=6UE;G1E="X`06YG<F4@96YD<FEN9V%R`$]P<&1A=&5R`$)R=6MA
M<F%D;6EN:7-T<F5R:6YG`$)R=6MA<F%L=&5R;F%T:78`0G)U:V%R;F%M;@!"
M<G5K87)A<B!I('-Y<W1E;65T.@#%='9A<FEN9P!+=F%R('9E:V4`5F5L:V]M
M96X@=&EL("5S`%9E;&MO;65N+"`E<P!!9')E<W-E+"!A<F)E:60`5&5L969O
M;BP@87)B96ED`,7%`,5R;&5G`$IA+"!E9R!E<B!S86UD`$1U(&WE('-K:6QD
M<F4@<')O8FQE;65T(&;X<B!D=2!K86X@<V5N9&4@<')O8FQE;7)A<'!O<G1E
M;BX`1'4@;>4@<W!E<VEF:7-E<F4@96ET(&)R=6MA<FYA;6X@Y2!F:F5R;F4N
M`$1U(&WE('-P97-I9FES97)E(&5I="!B<G5K87)N86UN(.4@;&5G9V4@=&EL
M+@#8:W1A(&1I("@E<RD@:&%R(&?E='0@=70@<.4@=&ED+B!,;V=G(&EN;B!P
MY2!N>71T+@!$:6X@:6YF;W)M87-J;VX`3&ES=&EN9R!A=B!B<G5K87)A<B!E
M<B!I:VMJ92!S=/AT=&$@878@8F%K<F4@875T96YT:7-E<FEN9RP@96QL97(@
M9G5N:W-J;VYE;B!H87(@878@96EN(&5L;&5R(&%N;F%N(&=R=6YN(&)L:71T
M('-LY71T(&%V+@!!;'1E<FYA=&EV82!D:6YE(&AA<B!B;&ET="!O<'!D871E
M<G1E+@!;4')O8FQE;7)A<'!O<G1=`%ML:6YJ92`E<R!A=B`E<UT`=D-A<F0`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQO8V%L92]P;%]03"\`````````````````````````````````````
M````````````````````````````````````````````,#`P,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-3,`,#(P,3(S`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W!L7U!,+VAE;'`N>&UL````
M````````````````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S,R,``Q,#4Q
M-30S,S<U,P`P,C$U-S,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E
M.B!H;W)D92]L;V-A;&4O<&Q?4$PO:&5L<"YX;6PL=B`Q+C(@,C`P-"\P-2\R
M-R`R,#HR,CHQ,R!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB
M<W5M;6%R>2(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@4&]R=&%L(%!A9V4\
M+W1I=&QE/@H@/'!A<F$^"B`@5&AI<R!P;W)T86P@<&%G92!P<F]V:61E<R!A
M('%U:6-K('-U;6UA<GD@;V8@86QL('EO=7(@:6UP;W)T86YT"B`@:6YF;W)M
M871I;VXN($9O<B!E>&%M<&QE+"!I="!M:6=H="!S:&]W(&AO=R!M86YY(&YE
M=R!E+6UA:6P@;65S<V%G97,@>6]U"B`@:&%V92!I;B!Y;W5R($E.0D]8+"!U
M<&-O;6EN9R!E=F5N=',@;VX@>6]U<B!C86QE;F1A<BP@=&%S:W,@;VX@>6]U
M<B!T;RUD;PH@(&QI<W0L(&AE861L:6YE<R!F<F]M('-E;&5C=&5D(&YE=W,@
M<V5R=FEC97,L(&%N9"!S;R!O;BX@($UA;GD@;V8@=&AE<V4*("!S=6UM87)I
M97,@=VEL;"!C;VYT86EN('%U:6-K('-H;W)T8W5T<R!T;R!C;VUM;VX@9G5N
M8W1I;VYS+"!S=6-H(&%S"B`@8V]M<&]S:6YG(&$@;F5W(&UA:6P@;65S<V%G
M92P@8W)E871I;F<@82!N97<@8V%L96YD87(@979E;G0@;W(@=&%S:RP@971C
M+@H@/"]P87)A/@H@/'!A<F$^"B`@5&AE(&-O;G1E;G1S(&]F('1H:7,@<&]R
M=&%L('!A9V4@87)E(&-U<W1O;6EZ86)L92!V:6$@=&AE($QA>6]U="!B=71T
M;VXN"B`@1F]R(&5X86UP;&4L('EO=2!C86X@8VAO;W-E('=H:6-H(&ET96US
M('1O(&EN8VQU9&4@;VX@=&AI<R!P;W)T86P@<&%G92!A<PH@('=E;&P@87,@
M:6X@=VAI8V@@;W)D97(@=&AE>2!A<F4@<VAO=VXN"B`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)N879B87(B('-T871E/2)N97<B/@H\=&ET;&4^
M5&AE($%P<&QI8V%T:6]N($YA=FEG871I;VX@0F%R/"]T:71L93X*(#QP87)A
M/@H@($%T('1H92!L969T(&AA;F0@<VED92!O9B!T:&4@=V5B('!A9V4@:7,@
M=&AE(&%P<&QI8V%T:6]N(&YA=FEG871I;VX@8F%R+@H@($-L:6-K(&]N('1H
M92!I8V]N<R!O;B!T:&ES(&YA=FEG871I;VX@8F%R('1O('%U:6-K;'D@86YD
M(&5A<VEL>2!S=VET8V@*("!B971W965N('1H92!A=F%I;&%B;&4@87!P;&EC
M871I;VYS+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M
M9&]?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E
M<F5N8V5S.B!-86EN=&5N86YC93H@1&\@36%I;G1E;F%N8V4\+W1I=&QE/@H@
M("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!P97)F;W)M(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6XL(&-H96-K('1H:7,@8F]X
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M8V]N
M9FER;5]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E
M9F5R96YC97,Z($UA:6YT96YA;F-E.B!#;VYF:7)M($UA:6YT96YA;F-E/"]T
M:71L93X*("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@8V]N
M9FER;2!A;&P@;6%I;G1E;F%N8V4@=&%S:W,@8F5F;W)E('1H97D@87)E(')U
M;BP@8VAE8VL@=&AI<R!B;W@N($EF(&QE9G0@=6YC:&5C:V5D+"!A;&P@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<R!T:&%T(&YE960@=&\@8F4@<G5N('=I;&P@
M8F4@<&5R9F]R;65D(&%U=&]M871I8V%L;'D@=VET:"!N;R!C:&%N8V4@=&\@
M8V%N8V5L(&]N(&QO9VEN+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]P;%]03"],0U]-15-304=%4R\`````
M````````````````````````````````````````````````````````````
M,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W
M-3,`,#(Q-S$P`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W!L7U!,
M+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#$T,3`Q-0`Q,#4Q-30S,S<U,P`P,C,S-3``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````WA($E0````!!`P``'````"0:``!=
M!```+#0```````"@10``2````*%%```.````ZD4```\```#Y10``#0````E&
M```(````%T8```L````@1@``#````"Q&```;````.48``"T```!51@``)```
M`(-&```I````J$8``!D```#21@``#````.Q&```+````^48``!$````%1P``
M#@```!='```%````)D<``"@````L1P``"````%5'```*````7D<``!(```!I
M1P``#@```'Q'```*````BT<```T```"61P``#@```*1'```1````LT<```T`
M``#%1P``#````--'```-````X$<```8```#N1P``#````/5'```.`````D@`
M``X````12```"````"!(```)````*4@``!H````S2```,@```$Y(```X````
M@4@``%0```"Z2```40````])``!:````84D``%<```"\20``-````!1*```%
M````24H``!$```!/2@``"````&%*```0````:DH```\```![2@``"@```(M*
M```#````EDH```D```":2@``#0```*1*```2````LDH```\```#%2@``"@``
M`-5*```/````X$H```@```#P2@``)````/E*```4````'DL``!8````S2P``
M"````$I+```M````4TL``!D```"!2P``!P```)M+```,````HTL```X```"P
M2P```P```+]+```+````PTL```<```#/2P``!P```-=+```%````WTL```,`
M``#E2P``%P```.E+```*`````4P```\````,3```&````!Q,```.````-4P`
M`!0```!$3```%P```%E,```7````<4P``!<```")3```#P```*%,```?````
ML4P```<```#13```!@```-E,```(````X$P```\```#I3```!@```/E,```*
M`````$T```L````+30``%0```!=-```'````+4T```4````U30``$0```#M-
M```,````34T```D```!:30``!P```&1-```%````;$T``#D```!R30``"@``
M`*Q-```&````MTT```D```"^30``!P```,A-```O````T$T``"X`````3@``
M50```"].```M````A4X``"T```"S3@``+0```.%.```C````#T\``",````S
M3P``+0```%=/```S````A4\``!4```"Y3P``&0```,]/```I````Z4\``"0`
M```34```$0```#A0```*````2E````P```!54```"@```&)0```0````;5``
M`!8```!^4```%@```)50```'````K%````<```"T4```%````+Q0```*````
MT5````<```#<4```!P```.10```&````[%````4```#S4```!P```/E0```&
M`````5$```@````(40``#@```!%1```*````(%$```<````K40``"0```#-1
M```6````/5$```0```!440``!@```%E1```(````8%$```,```!I40```P``
M`&U1```3````<5$```@```"%40``"````(Y1```(````EU$``$$```"@40``
M(````.)1```&`````U(```8````*4@``%0```!%2```8````)U(``"(```!`
M4@``'0```&-2```*````@5(``!4```",4@``"@```*)2```/````K5(```\`
M``"]4@``"0```,U2```4````UU(``!@```#L4@``'0````53```3````(U,`
M`!$````W4P``!````$E3```&````3E,``%0```!54P``#@```*I3``!$````
MN5,```4```#^4P``!0````14```1````"E0``!$````<5```'````"Y4```0
M````2U0``!$```!<5```#````&Y4```7````>U0``!````"35```"````*14
M```%````K50```P```"S5```$````,!4```-````T50```<```#?5```#0``
M`.=4```'````]50```<```#]5```!P````55```4````#54```D````B50``
M"@```"Q5```,````-U4``!````!$50``!0```%55```E````6U4``!(```"!
M50``$P```)15```K````J%4``#L```#450``(````!!6```V````,58``!``
M``!H5@``"````'E6```,````@E8```0```"/5@``#@```)16```>````HU8`
M`!L```#"5@``(0```-Y6```>`````%<``!X````?5P``+@```#Y7```;````
M;5<``!X```")5P``,P```*A7```O````W%<``"`````,6```$@```"U8```I
M````0%@``!X```!J6```%@```(E8``!!````H%@```<```#B6```!@```.I8
M```-````\5@``!````#_6```$@```!!9```'````(UD```0````K60``#```
M`#!9```H````/5D```,```!F60``!@```&I9```.````<5D```(```"`60``
M!0```(-9```$````B5D```X```".60``"````)U9```-````IED``!````"T
M60``$P```,59```3````V5D```8```#M60``#````/19```1`````5H``!D`
M```36@``"P```"U:```-````.5H``!L```!'6@``-````&-:```*````F%H`
M`!@```"C6@``&0```+Q:```6````UEH``"\```#M6@``!P```!U;```4````
M)5L``"\````Z6P``"0```&I;```6````=%L```\```"+6P``"````)M;```-
M````I%L``"8```"R6P``"````-E;```2````XEL```@```#U6P``"P```/Y;
M```%````"EP```8````07```!P```!=<```$````'UP```H````D7```#P``
M`"]<```0````/UP``!<```!07```$0```&A<```7````>EP```4```"27```
M"P```)A<```%````I%P```T```"J7```&P```+A<```)````U%P```X```#>
M7```#0```.U<```@````^UP``!$````<70``!P```"Y=```%````-ET``!,`
M```\70``!P```%!=```(````6%T```8```!A70``$````&A=```/````>5T`
M`!````")70``#P```)I=```+````JET```\```"V70``#````,9=```/````
MTUT```<```#C70``!@```.M=```.````\ET``"$````!7@``&0```"->```7
M````/5X``!<```!57@``&P```&U>```-````B5X```P```"77@```P```*1>
M```(````J%X```0```"Q7@``#````+9>```)````PUX```X```#-7@``"P``
M`-Q>```;````Z%X```<````$7P``!P````Q?```$````%%\``!4````97P``
M!@```"]?```-````-E\``!````!$7P``&P```%5?```$````<5\```4```!V
M7P``!@```'Q?```'````@U\```4```"+7P``"0```)%?```"````FU\```T`
M``">7P``!@```*Q?```)````LU\```<```"]7P``!@```,5?```*````S%\`
M``0```#77P``"0```-Q?```(````YE\```8```#O7P``#0```/9?```&````
M!&````0````+8```!0```!!@```A````%F````0````X8```!````#U@```%
M````0F```!T```!(8```!````&9@```,````:V````H```!X8```"````(-@
M```)````C&````4```"68```*0```)Q@```'````QF````<```#.8```"@``
M`-9@```/````X6```!````#Q8```!@````)A```2````"6$``!`````<80``
M!0```"UA```)````,V$```0````]80``#````$)A```7````3V$``!P```!G
M80``$P```(1A```4````F&$``!D```"M80``!````,=A```'````S&$```8`
M``#480``!@```-MA```%````XF$```<```#H80``!P```/!A```%````^&$`
M``8```#^80``!`````5B```$````"F(```H````/8@``!0```!IB```,````
M(&(```\````M8@``"@```#UB```(````2&(``"L```!18@``!````'UB```(
M````@F(``"8```"+8@``$@```+)B```&````Q6(```H```#,8@``!P```-=B
M```(````WV(``"````#H8@``#@````EC```6````&&,``!$````O8P``!@``
M`$%C```'````2&,```<```!08P``%@```%AC```-````;V,``!````!]8P``
M&@```(YC```)````J6,```H```"S8P``#````+YC```/````RV,```8```#;
M8P``!P```.)C```+````ZF,``$<```#V8P``#0```#YD```#````3&0```H`
M``!09````@```%MD```$````7F0```,```!C9```!0```&=D```J````;60`
M``H```"89```!````*-D```&````J&0```@```"O9```"````+AD```$````
MP60```4```#&9```:````,QD```%````-64```8````[90``$````$)E```*
M````4V4```\```!>90``"@```&YE```)````>64```,```"#90``!P```(=E
M```*````CV4```L```":90``!P```*9E```:````KF4``$H```#)90``!@``
M`!1F```)````&V8```T````E9@``"@```#-F```'````/F8``!0```!&9@``
M!@```%MF```(````8F8```<```!K9@``"@```'-F```+````?F8```<```"*
M9@``"0```))F```)````G&8```H```"F9@``!P```+%F```)````N68```<`
M``##9@``"@```,MF```*````UF8```D```#A9@``!P```.MF```$````\V8`
M``<```#X9@``!0````!G```%````!F<```L````,9P``%````!AG```'````
M+6<```4````U9P``#0```#MG```,````26<```L```!69P``!````&)G```$
M````9V<```P```!L9P``"0```'EG```%````@V<```<```")9P``!````)%G
M```*````EF<``"X```"A9P``$````-!G```M````X6<``"T````/:```,0``
M`#UH```M````;V@``"X```"=:```+P```,QH```L````_&@```0````I:0``
M#@```"YI```&````/6D``!````!$:0``!P```%5I```.````76D```4```!L
M:0``!@```')I```(````>6D``!$```"":0``#@```)1I```"````HVD```<`
M``"F:0``!@```*YI```$````M6D``!\```"Z:0``%````-II```'````[VD`
M``X```#W:0``#`````9J```3````$VH```H````G:@``!0```#)J```1````
M.&H``!$```!*:@``)````%QJ```5````@6H``!(```"7:@``#@```*IJ```9
M````N6H```@```#3:@``"0```-QJ```*````YFH```@```#Q:@``!0```/IJ
M```&`````&L``!`````':P``"````!AK```(````(6L``!(````J:P``&@``
M`#UK```)````6&L```H```!B:P``%0```&UK```%````@VL``!0```"):P``
M'@```)YK```H````O6L```H```#F:P``#P```/%K```4`````6P```0````6
M;```"P```!ML```%````)VP```@````M;```-````#9L```T````:VP``"``
M``"@;```&@```,%L```H````W&P``"D````%;0``!@```"]M```(````-FT`
M``<````_;0``"P```$=M```'````4VT``!,```!;;0``"@```&]M```4````
M>FT```\```"/;0``,@```)]M```+````TFT```4```#>;0``!0```.1M```7
M````ZFT``!X````";@``%````"%N```.````-FX```8```!%;@``#````$QN
M```-````66X```L```!G;@``"@```'-N```+````?FX```\```"*;@``!0``
M`)IN```.````H&X``!,```"O;@``!P```,-N```1````RVX```<```#=;@``
M&````.5N```$````_FX```<````#;P``"@````MO```+````%F\```P````B
M;P``#@```"]O```2````/F\```8```!1;P``&````%AO```E````<6\```D`
M``"7;P```P```*%O```*````I6\```P```"P;P``%0```+UO```+````TV\`
M`!D```#?;P``(````/EO```%````&G````H````@<```#````"MP```$````
M.'````D````]<```!P```$=P```,````3W````8```!<<```#````&-P```:
M````<'```!<```"+<```)P```*-P```:````RW```!<```#F<```&P```/YP
M```9````&G$``!\````T<0``$P```%1Q```'````:'$```D```!P<0``#0``
M`'IQ```#````B'$``#\```",<0``-P```,QQ``!7````!'(```4```!<<@``
M"@```&)R```-````;7(```0```![<@``)0```(!R```=````IG(```P```#$
M<@``&0```-%R```)````ZW(``!,```#U<@``"0````ES```$````$W,``!``
M```8<P``"````"ES```(````,G,```\````[<P``!P```$MS```,````4W,`
M`!L```!@<P``+````'QS```%````J7,```0```"O<P``%P```+1S```*````
MS',```P```#7<P``"0```.1S```)````[G,``!$```#X<P``!@````IT```.
M````$70```<````@=```!@```"AT```'````+W0``"8````W=```.````%YT
M```:````EW0``"H```"R=```&0```-UT```%````]W0```X```#]=```"```
M``QU```)````%74```8````?=0``"P```"9U```4````,G4```8```!'=0``
M&0```$YU```*````:'4``!P```!S=0``!0```)!U```0````EG4```D```"G
M=0``"````+%U```?````NG4``",```#:=0``(0```/YU```?````('8``"<`
M``!`=@``'P```&AV```Q````B'8``$$```"Z=@``,P```/QV```E````,'<`
M`"\```!6=P``,````(9W```O````MW<``"P```#G=P``%P```!1X```B````
M+'@``$4```!/>```,````)5X```$````QG@```L```#+>```!0```-=X```"
M````W7@``%D```#@>```!0```#IY```$````0'D```<```!%>0``"````$UY
M```%````5GD``!,```!<>0``#0```'!Y```'````?GD```8```"&>0``%```
M`(UY```,````HGD```8```"O>0```P```+9Y```$````NGD```8```"_>0``
M!P```,9Y```7````SGD``"````#F>0``&@````=Z```F````(GH```P```!)
M>@``%````%9Z```.````:WH```T```!Z>@``!P```(AZ```'````D'H``!4`
M``"8>@``!@```*YZ```&````M7H```<```"\>@``#````,1Z```1````T7H`
M``@```#C>@``'0```.QZ```)````"GL```H````4>P``%````!][```*````
M-'L```@````_>P``!P```$A[```)````4'L```<```!:>P``"````&)[```'
M````:WL``!D```!S>P``"@```(U[```7````F'L``!0```"P>P``$0```,5[
M```'````UWL```,```#?>P``!@```.-[```'````ZGL```T```#R>P``"P``
M``!\```4````#'P``!4````A?```#@```#=\```O````1GP``#$```!V?```
M/P```*A\```,````Z'P```H```#U?````@````!]```$`````WT```8````(
M?0``!0````]]```#````%7T```P````9?0``&0```"9]``!%````0'T``"8`
M``"&?0``)0```*U]```2````TWT``!,```#F?0``$````/I]``!Y````"WX`
M``D```"%?@``<@```(]^``!S`````G\``!<```!V?P``%@```(Y_```/````
MI7\``!\```"U?P``0````-5_```?````%H```!0````V@```"@```$N````%
M````5H````8```!<@```"````&.````0````;(````\```!]@```!````(V`
M```+````DH````<```">@```!0```*:````'````K(````@```"T@```#P``
M`+V````(````S8````P```#6@```#P```..````&````\X````8```#Z@```
M#`````&!```(````#H$```0````7@0``!````!R!```'````(8$```<````I
M@0``!0```#&!``!3`0``-X$``$,```"+@@``#@```,^"```2````WH(``!$`
M``#Q@@``!P````.#```(````"X,```H````4@P``(@```!^#```O````0H,`
M`!T```!R@P``(@```)"#```>````LX,```H```#2@P``"@```-V#```0````
MZ(,```\```#Y@P``!0````F$```G````#X0```\````WA```#@```$>$```0
M````5H0``!````!GA```"````'B$```1````@80```T```"3A```$P```*&$
M```,````M80```L```#"A```#@```,Z$```&````W80```T```#DA```$@``
M`/*$```2````!84```@````8A0``"@```"&%```7````+(4``#\```!$A0``
M2````(2%``!<````S84``%D````JA@``8@```(2&``!?````YX8``$$```!'
MAP``!0```(F'```.````CX<```X```">AP``#@```*V'```2````O(<```4`
M``#/AP``!0```-6'```,````VX<``!````#HAP``%@```/F'```9````$(@`
M``T````JB```%0```#B(```*````3H@``!X```!9B```&P```'B(```@````
ME(@``!$```"UB```+0```,>(```F````]8@```4````<B0``$````"*)```-
M````,XD```<```!!B0``"@```$F)```'````5(D```@```!<B0``!0```&6)
M```(````:XD``",```!TB0``#P```)B)```5````J(D``!<```"^B0``#```
M`-:)```7````XXD``!<```#[B0``(P```!.*```8````-XH``!,```!0B@``
M)0```&2*```&````BHH```8```"1B@``"````)B*```/````H8H```D```"Q
MB@``"@```+N*```)````QHH``!````#0B@``"0```.&*```(````ZXH``!$`
M``#TB@``#@````:+```)````%8L```<````?BP``!0```">+```]````+8L`
M``@```!KBP``"````'2+```)````?8L```<```"'BP``.````(^+```X````
MR(L``%L````!C```-P```%V,```W````E8P``#<```#-C```+@````6-```R
M````-(T``#<```!GC0``/0```)^-```A````W8T``"4```#_C0``+P```"6.
M```Q````58X```X```"'C@``"P```):.```,````HHX```,```"OC@``"0``
M`+..```4````O8X``!\```#2C@``#````/*.```'````_XX``!8````'CP``
M"@```!Z/```(````*8\```8````RCP``!@```#F/```%````0(\```<```!&
MCP``!@```$Z/```.````58\``!````!DCP``"0```'6/```'````?X\```@`
M``"'CP``%````)"/```#````I8\```@```"ICP``"````+*/```#````NX\`
M``,```"_CP``&P```,./```)````WX\```@```#ICP``!P```/*/``!/````
M^H\``"T```!*D```!@```'B0```&````?Y```!D```"&D```'0```*"0```L
M````OI```"````#KD```&0````R1```6````)I$```D````]D0``$P```$>1
M```3````6Y$```D```!OD0``%@```'F1```:````D)$``!\```"KD0``%0``
M`,N1```6````X9$```0```#XD0``!0```/V1``!&`````Y(```\```!*D@``
M,P```%J2```%````CI(```4```"4D@``"P```)J2```7````II(``"````"^
MD@``%P```-^2```6````]Y(```P````.DP``&0```!N3```-````-9,```@`
M``!#DP``!0```$R3```-````4I,```P```!@DP``#0```&V3```'````>Y,`
M``<```"#DP``"0```(N3```&````E9,```4```"<DP``%0```**3```)````
MN),```<```#"DP``#@```,J3```/````V9,```4```#IDP``'0```.^3```<
M````#90``!T````JE```+````$B4```[````=90``"D```"QE```/@```-N4
M```.````&I4```@````IE0``"P```#*5```'````/I4```T```!&E0``*P``
M`%25```H````@)4``"X```"IE0``*P```-B5```J````!)8``#D````OE@``
M)0```&F6```H````CY8``"T```"XE@``,P```.:6```F````&I<``!8```!!
MEP``+0```%B7```@````AI<``"(```"GEP``10```,J7```$````$)@```8`
M```5F```"P```!R8```+````*)@``!8````TF```"0```$N8```$````59@`
M``L```!:F```-P```&:8```&````GI@```0```"EF```#P```*J8```"````
MNI@```H```"]F```!````,B8```-````S9@```@```#;F```#@```.28```2
M````\Y@``!0````&F0``%````!N9```$````,)D```H````UF0``$````$"9
M```9````49D```P```!KF0``#````'B9```;````A9D``#H```"AF0``"P``
M`-R9```8````Z)D``!4````!F@``%````!>:```T````+)H```4```!AF@``
M#0```&>:```P````=9H```<```"FF@``)@```*Z:```2````U9H```<```#H
MF@``"0```/":```N````^IH``!T````IFP``(P```$>;```(````:YL```L`
M``!TFP``"0```(";```&````BIL```<```"1FP``!@```)F;```*````H)L`
M`!$```"KFP``$0```+V;```8````SYL``!4```#HFP``&````/Z;```%````
M%YP```@````=G```!0```":<```+````+)P``"4````XG```"0```%Z<```0
M````:)P``!````!YG```-@```(J<```0````P9P```<```#2G```!````-J<
M```7````WYP```<```#WG```!P```/^<```&````!YT``!$````.G0``$0``
M`""=```2````,IT``!````!%G0``%````%:=```4````:YT```\```"`G0``
M%0```)"=```'````IIT```8```"NG0``#````+6=```J````PIT``!\```#M
MG0``(`````V>```B````+IX``!,```!1G@``"P```&6>```0````<9X```0`
M``""G@``!````(>>```%````C)X```\```"2G@``"P```**>```+````KIX`
M``\```"ZG@``)@```,J>```&````\9X```D```#XG@``"`````*?```2````
M"Y\```<````>GP``$````":?```3````-Y\``"X```!+GP```@```'J?```%
M````?9\```8```"#GP``!@```(J?```%````D9\```D```"7GP```P```*&?
M```3````I9\```8```"YGP``"@```,"?```'````RY\``!````#3GP``"0``
M`.2?```$````[I\```D```#SGP``"````/V?```&````!J````T````-H```
M!@```!N@```$````(J````4````GH```%P```"V@```%````1:````8```!+
MH```!@```%*@```<````6:````@```!VH```#````'^@```)````C*````@`
M``"6H```"````)^@```%````J*```"4```"NH```!0```-2@```(````VJ``
M``L```#CH```#P```.^@```1````_Z````<````1H0``%````!FA```1````
M+J$```4```!`H0``"0```$:A```$````4*$```T```!5H0``&P```&.A```=
M````?Z$``!H```"=H0``'0```+BA```$````UJ$```0```#;H0``"````."A
M```&````Z:$```<```#PH0``!@```/BA```'````_Z$```<````'H@``!P``
M``^B```&````%Z(```8````>H@``"````"6B```*````+J(```4````YH@``
M$````#^B```-````4*(```X```!>H@``"@```&VB```Q````>*(```8```"J
MH@``"````+&B```H````NJ(```\```#CH@``!@```/.B```)````^J(```L`
M```$HP``!0```!"C```$````%J,``!8````;HP``&P```#*C```9````3J,`
M``4```!HHP``!P```&ZC```'````=J,```4```!^HP``#0```(2C```6````
MDJ,``"<```"IHP``!0```-&C```,````UZ,```X```#DHP``&0```/.C```'
M````#:0```<````5I```%@```!VD``!7````-*0``!L```",I```!0```*BD
M```*````KJ0```(```"YI```!````+RD```#````P:0```4```#%I```"0``
M`,ND```*````U:0```8```#@I```!@```.>D```'````[J0```@```#VI```
M!````/^D```%````!*4``%L````*I0``!@```&:E```(````;:4```\```!V
MI0``"0```(:E```-````D*4```H```">I0``"0```*FE```#````LZ4```<`
M``"WI0``"@```+^E```.````RJ4```D```#9I0``'P```..E``!:`````Z8`
M``8```!>I@``"````&6F```4````;J8```H```"#I@``"````(ZF```2````
MEZ8```8```"JI@``"````+&F```*````NJ8```H```#%I@``#0```-"F```&
M````WJ8```T```#EI@``#@```/.F```/`````J<```X````2IP``#@```"&G
M```.````,*<```@````_IP``!0```$BG```*````3J<```4```!9IP``"```
M`%^G```'````:*<```4```!PIP``!0```':G```(````?*<``!,```"%IP``
M!````)FG```%````GJ<```X```"DIP``#@```+.G```-````PJ<```H```#0
MIP``"````-NG```.````Y*<```D```#SIP``!0```/VG```'`````Z@```0`
M```+J```"@```!"H```9````&Z@``!`````UJ```*P```$:H```K````<J@`
M`"\```">J```*P```,ZH```L````^J@``"T````GJ0``*@```%6I```%````
M@*D```<```"&J0``"````(ZI```5````EZD```P```"MJ0``#@```+JI```%
M````R:D```4```#/J0``"````-6I```-````WJD```X```#LJ0```@```/NI
M```+````_JD```4````*J@``!````!"J```G````%:H``!0````]J@``!0``
M`%*J```(````6*H```L```!AJ@``%P```&VJ```+````A:H```0```"1J@``
M#P```):J```0````IJH``"<```"WJ@``$@```-^J```:````\JH``!,````-
MJP``+````"&K```'````3JL```L```!6JP``#````&*K```(````;ZL```4`
M``!XJP``!@```'ZK```1````A:L```@```"7JP``!0```*"K```3````IJL`
M`!8```"ZJP``!@```-&K```'````V*L``!,```#@JP``!0```/2K```0````
M^JL``!H````+K```+0```":L```+````5*P```\```!@K```$P```'"L```$
M````A*P```@```")K```!P```)*L```(````FJP``"0```"CK```(````,BL
M```?````Z:P``!L````)K0``%@```"6M```F````/*T```8```!CK0``"@``
M`&JM```'````=:T```X```!]K0``!P```(RM```-````E*T```\```"BK0``
M&P```+*M```>````SJT``#H```#MK0``"0```"BN```%````,JX```D````X
MK@``'@```$*N```A````8:X``!8```"#K@``#@```)JN```$````J:X```D`
M``"NK@``#````+BN```)````Q:X```0```#/K@``$````-2N```6````Y:X`
M``4```#\K@``#0````*O```3````$*\```8````DKP``#P```"NO```'````
M.Z\``!D```!#KP``"@```%VO```'````:*\``!(```!PKP``#````(.O```-
M````D*\``!P```">KP``!0```+NO```&````P:\``!T```#(KP``*````.:O
M```+````#[````,````;L```#````!^P```-````++```!,````ZL```"P``
M`$ZP```7````6K```!D```!RL```!0```(RP```*````DK```!````"=L```
M!@```*ZP```+````M;````D```#!L```#````,NP```&````V+````T```#?
ML```&P```.VP```4````";$``!P````>L0``&P```#NQ```5````5[$``!H`
M``!ML0``&````(BQ```?````H;$``!D```#!L0``!P```-NQ```(````X[$`
M``T```#LL0``!0```/JQ```^`````+(``#4````_L@``5@```'6R```,````
MS+(```@```#9L@``"P```.*R```%````[K(``#,```#TL@``%P```"BS```,
M````0+,``#````!-LP``!@```'ZS```0````A;,```@```"6LP``"````)^S
M```8````J+,```@```#!LP``"````,JS```.````T[,```<```#BLP``$0``
M`.JS```A````_+,``!(````>M```"0```#&T```$````.[0``!D```!`M```
M#P```%JT```/````:K0```X```!ZM```"0```(FT```4````D[0```8```"H
MM```#````*^T```%````O+0```8```#"M```"@```,FT```@````U+0``"``
M``#UM```%@```!:U```@````+;4``!D```!.M0``!0```&BU```4````;K4`
M``<```"#M0``!0```(NU```'````D;4```H```"9M0``!0```*2U```&````
MJK4```8```"QM0``"P```+BU```(````Q+4```<```#-M0``#@```-6U```+
M````Y+4```D```#PM0``)````/JU```@````'[8``!P```!`M@``'````%VV
M```C````>K8``"````">M@``,P```+^V``!'````\[8``"X````[MP``+```
M`&JW```X````E[<``#,```#0MP``*@````2X```J````+[@``!8```!:N```
M(0```'&X``!"````D[@``#@```#6N```!`````^Y```,````%+D```4````A
MN0```@```">Y``!>````*KD```0```")N0``!````(ZY```'````D[D```4`
M``";N0``!0```*&Y```1````I[D``!````"YN0``!P```,JY```&````TKD`
M`!0```#9N0``#````.ZY```&````^[D```,````"N@``!`````:Z```&````
M"[H```<````2N@``&@```!JZ```I````-;H``",```!?N@``+0```(.Z```-
M````L;H``!P```"_N@``#P```-RZ```#````[+H```@```#PN@``"0```/FZ
M```;`````[L```H````?NP``!P```"J[```'````,KL``!$````ZNP``%P``
M`$R[```1````9+L``"8```!VNP``$@```)V[```3````L+L``!<```#$NP``
M"@```-R[```'````Y[L```<```#ONP``"0```/>[```&`````;P```<````(
MO```"````!"\```0````&;P```T````JO```&@```#B\```D````4[P```\`
M``!XO```"P```(B\```#````E+P```H```"8O```!@```*.\```+````JKP`
M``H```"VO```%0```,&\```6````U[P``!````#NO```,P```/^\```W````
M,[T``$\```!KO0``#@```+N]```-````RKT```(```#8O0``!````-N]```&
M````X+T```4```#GO0```P```.V]```0````\;T``!`````"O@``)P```!.^
M```S````.[X``#(```!OO@``$0```**^```.````M+X``!````##O@``@0``
M`-2^```*````5K\``%T```!AOP``7@```+^_```<````'L```!,````[P```
M'````$_````@````;,```$````"-P```)@```,[````5````]<````H````+
MP0``!````!;!```&````&\$```@````BP0``%````"O!```.````0,$```0`
M``!/P0``#````%3!```&````8<$```8```!HP0``"````&_!```(````>,$`
M``T```"!P0``!@```(_!```,````EL$```P```"CP0``#0```+#!```,````
MOL$``!````#+P0``"0```-S!```$````YL$```@```#KP0``"````/3!```)
M````_<$```4````'P@```0```*H``````````````%@`````````O`$`````
M``#:````"@```&@````T`P``G`(``!(````^`@``PP$``)4```"5`0``````
M`$<!``!-`0````````````"R`@``P0(``!4```!#`@``R@$``,8```!P````
M;P$``%T"```*`P``EP(```````"9``````````````!?````\0```$8"````
M````,`$``&4!``#3`@```````,L!````````I0```)8```!<````A0(```T!
M``"V`@````````````!V````!`(```````"O````_`(```````"0````S0``
M`'(!``#5`````````+L````"`@``N`(````````1`````````,P"``!T````
M=0(``(H````Z````X0$```4"``!>`````````#4````F`@```````"<#``"F
M`@```@```"$#```#`P``Y````#8!````````=0`````````,`0``J`$``*L`
M``#:`@``MP(``%\!``"V````8`$``"`#```C`P``J0```/0!````````'`$`
M``\"````````]0$``!T#``!@`@``B0```*\!````````0@$``!("```U`P``
M$`,``-\!````````T````$`!``!0`@``:@$```````#%````]P```%8!````
M`````````%$`````````9@`````````J`P``&0,``)`"````````6@```/L`
M```4`0``^@$``,$``````````````*4"```[`0```````.X```#[`@``````
M``````"C`0``=P$`````````````Z@(``-@"````````Q@$``$\```!Z`0``
M`````%\"``!/`0````````````!O`@``10(``"@"``"?`@``P@$``#@#````
M````90````T"`````````````#8```!7`@```````%(````Z`P``4P(`````
M``!`````_@$``#$```"L`@``:P$``/\"````````80````````!9`0``*@(`
M``````!D````!P$```````#[`0``*0$```````#I````-`(``/X"``"#`0``
MN`$````````B`P``/@```!<"``#+````W0(``'H"`````````````,<"``#=
M`0``"@(``,<`````````?`````P#``#C`@``P@(``.(`````````:@``````
M``"E`0``M@$```````#<`0``*0,``#T"``".`````````$L"````````QP$`
M``````"^`0``SP$``/4"``"A``````````````">`0``G@(``,D!``#6````
M`0$```````#+`@``-0(``,X"``!(````&P(``'$``````````````"8!``"'
M`0``)0,````````M`@``H`(``*<!``````````````````!+`0``Z`$``$P`
M```^`P```````$,!```%````OP```!H#``!.`0``````````````````8@(`
M`+0```"8````%@(``#\"```_`0``F@(``+`!``!M`````````$T```"$`0``
M:0(``!0```#)`@`````````````Y`0```````'\!``#Z````H@$``'P!``#;
M````F0(`````````````=@$``'$"``#B`0``.P(``)D!````````'`(`````
M```:`@``ZP$```````#S`@````````$"``"`````O0(``.L"``#S`0``UP(`
M`!`"````````'0(``!$!``!%````[P(``*0````V`P``@@$``#("````````
M-P```&X"``!(`@``&P,``.X"```P````_`$```8!````````\````#@`````
M````HP(``)T"``!8`0``1P```#D```#Q`@``+`(```````"[`@``*P```$$`
M``````````````D"````````D@$``````````````````/,```#T`@``UP$`
M`(T`````````:P(``"T```#W`0``&@$``/D"``!4`@``)P$``$(```"+`@``
M$P$``%("``!]````[0(`````````````$0,```````",````````````````
M````'P``````````````]0````0```#=````2P```&P"````````XP$`````
M``!P`@``+`,``(D"````````4P$``#X!````````^0````@"``!.````G`$`
M``````!&`````````(L````7`P````````````#G`0```````'T"````````
M`````($```#(`@``O0``````````````N````"(```#G````8P$````````\
M````M0(``,@!``""`@``L`(``#(```"@`0``D@(```````"Y`0```````)T!
M``#>````&0(``"$`````````00,``+<```"Y`````````#$"``"8`0``,P``
M``````"M`0``SP```'8"``!6`@``%@,```````"(`@``````````````````
M!@(```````![`@``1````%D"`````P``#P```"`"```N`@```````&<```!:
M`@``-P$```T```!/`@``,@,``"\```!8`@``K@`````````C`@``/`$`````
M``#;`@````````<````*`0``)`$``(8"``#E`````````&D!``!*````>P$`
M`.$```"H````A@````````"Z````N@(``%P!```>`0``?@(```````#)````
M`````-0!````````'@```-X!````````ZP```),```"A`@``(P````````#1
M`0``T@`````````C`0```````(H"````````)0(``$`"``"4`@``"````$X"
M````````A0```$,```#$`0``V@$``'\````9````Y`$```0#``!,`0``$@$`
M````````````4`$``+P"````````UP````<#```S`0``DP(``#P#``#_`0``
M70````,!```9`0``HP```)H```#&`@```````%$!```T````)P```"L"``"W
M`0``J@$``!H````E````A0$``!`!``!F`@``,@$``*0!```.`@```````#T#
M````````1P(``)$`````````-P,``/("````````G@```/T!```.`0``+`$`
M`$D```!Z````.P,``-P```"$`@````````````##````E`````0!````````
M*0```'D"``#L`0``B0$``+P```!O````&P``````````````\@$````````+
M`@``*P$``(T"``",`@``N@$```````#D`@``#@```.`!``!E`@``"P$``)<!
M``#;`0``(````-4!````````M0$``/X```!J`@``?@$``"8```"5`@``:0``
M`/<"``#J`0```````!(#``!Q`0````````D!``!M`@``P`$``'P"``"2````
ML@`````````7`0``.@$````````,`@``S@```````````````````"T#````
M````K`$``*L!```+`````0,``#$!````````,`(``-`"``#Q`0```````#@"
M``#Z`@``V0(``"@#``#X`@``U``````!``#*``````````````"M````Y0$`
M`(<"```6````"`$``',`````````*@$````````&`P``[`(```````"7````
M'`,``*``````````]@````````#O````;`$```\!````````)`,``-@!````
M````Z0(``.```````````````````````````````!0#``!Y`````````-D`
M``"(`0``\`$``+````!G`0``SP(``%T!```A`@````````````#``@``````
M`#,#```3`P``S@$``*<"``!G`@``-`$````````>`P``J0(``)$"````````
M'P,``'0!``!]`0``%0$```````#F````.`$``'<```"6`@``!0,``%D```!U
M`0``T`$``-$`````````.@(``',!`````````````,P!````````7@$``&$"
M``!5`0``[0```.<"```G`@``L@$``&X```!1`@``,0,``+\"````````9`(`
M`!T!``#F`0``1`(``)P```"^````C0$``%4``````@```````*T"``!!`@``
MY@(``#4!```5`@``@0$``/T``````````````%4"`````````````.H```#C
M````=`(``-X"``!M`0``S0$``+,!``!*`@``0`,`````````````$0(``$P"
M``#!`0``+P(``````````````````!<````[````U0(``"D"```+`P``*`$`
M`)T`````````X`(``,0```"#`@````````````!>`@``````````````````
MC@$```````"O`@``!0$``"L#`````````````.D!````````>`(``.$"``!L
M````Z````(X"``!7````'@(``!\"``!@````6P(``%<!```J````<P(`````
M``"!`@```````,4!``"T`@``DP$``'("``"6`0``'0```-("```8`@``````
M`,T"``":`0``A@$```,`````````T0(``/8"`````````````"0```"G````
MA`````````!R````:P````,"```A`0``>P````````!)`@```````*(```"/
M`0``P````+,"``#(`````````$H!``!N`0``$P````\#````````4````)L!
M``"_`0``)0$``&@"```6`0``9@$``)$!```<````]@$``*X!``"?````FP``
M``````#3`0``(@(``(L!```4`@``/0````(#`````````````#\#````````
MM`$``$8!```O`0``_0(``(P!``##`@``)@,``-,````8`0``6P```)L"``"J
M`@``CP```*X"````````I`(``-\"```N``````````````!A`0``D`$``&,"
M````````&````-D!``#6`@``6P$``+,```"H`@``9`$``"`!````````@`$`
M`-(!````````=P(```T#``#8````L0(``#T!``#H`@``7`(``"\#``"U````
M[0$``*$!````````X@(``````````````````+X"``!X`0````````X#````
M````-@(``+$!`````````````((```!!`0```````/@```!Y`0``P@```&(`
M``````````````````!4````O0$```````"B`@``\@```-\`````````[```
M`#P"``!P`0``1`$``*P```"?`0``)`(```````!X`````````'X```!B`0``
MQ0(```````#X`0``NP$`````````````$P(```````"8`@``6@$``!\!```B
M`0``&P$````````Y`@````````````!6````"`,``%0!```L````I@$``!4#
M````````^0$``(,````_``````````````"Y`@``30(``$4!````````````
M`(`"``"/`@```````)0!``#<`@``_````"X#``#T````,P(``$D!``!H`0``
MQ`(``%,`````````4@$``(H!```0````?P(`````````````Y0(```````!"
M`@``!@```-8!``"K`@```````#D#```N`0```````(@`````````R@(``/\`
M```H````U`(``````````````````.X!```)````AP````<"````````8P``
M`/`"```)`P``2`$```P```"I`0```````#<"``"Q`````````,P````"`0``
M[P$``#`#`````````````!@#```M`0``I@`````@)B,Q-3$[("5S(&ES(')E
M861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE
M8VME9"!B96QO=RX`("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H
M:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI
M`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF
M:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!W87,@861D960@
M=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P
M97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`
M)60@)7,@86YD("5S`"5S("T@3F]T:6-E`"5S($%D;6EN:7-T<F%T:6]N`"5S
M($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@
M+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E<R!A;')E861Y
M(&5X:7-T<RX`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U
M;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L
M96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"TM('-E
M;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R
M<P`\4')E=FEO=7,`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L
M:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`
M02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N
M960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE
M<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!
M('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`
M02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@
M<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S
M<V%G92X`04TO4$T`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06-C;W5N
M="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D
M($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A
M(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I
M<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O
M(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E
M<@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO
M=RX`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@
M0F]O:P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB86YI80!!
M;&=E<FEA`$%L:6%S`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@
M1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S
M97,`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N
M871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT
M97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E>'0Z`$%N(&EL;&5G
M86P@=F%L=64@=V%S('-P96-I9FEE9"X`06YD;W)R80!!;F=O;&$`06YG=6EL
M;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%P<&QI8V%T
M:6]N`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!R;W9E`$%P<FEL`$%R8VAI
M=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F=E;G1I;F$`07)M96YI80!!
M<G5B80!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<S\`071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA
M`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T
M<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R
M("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?
M;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE
M9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E
M<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%V86EL
M86)L92!F:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8VMG<F]U
M;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A
M9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H
M25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F5L87)U<P!"96QG:75M`$)E;&EZ
M90!"96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!";&]C:R!3971T:6YG
M<P!";&]C:R!4>7!E`$)O;&EV:6$`0F]O:VUA<FMS`$)O<VYI82!A;F0@2&5R
M>F5G;W9I;F$`0F]T:`!"<F%Z:6P`0G5L9V%R:6$`0TU3`$-20P!#7V5L;"!0
M<F]P97)T:65S+BXN`$-A;&5N9&%R`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N
M;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z
M("5S`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO
M="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D
M:7)E8W1O<GDN`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A<&4@
M5F5R9&4`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-E;&P@4&AO;F4`0V5L;"!0
M<F]P97)T:65S`$-E;&P@<')O<&5R=&EE<P!#96QL<&AO;F4`0V5L=&EC("A)
M4T\M.#@U.2TQ-"D`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@
M175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R
M=&EF:6-A=&4@3W=N97(`0VAA9`!#:&%N9V4`0VAA;F=E('1H92!N86UE(&%N
M9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@
M<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H96-?:R!,:6YK+BXN`$-H96-K('1H
M92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R
M;2!A="!T:&ES('1I;64N`$-H:6QE`$-H:6YA`$-H;V]S92!A('!A<W-W;W)D
M`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E
M<SH`0VAR:7-T;6%S($ES;&%N9`!#;&EC:R!T;R!#;VYT:6YU90!#;&]S92!7
M:6YD;W<`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4@4VED96)A
M<@!#;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO
M;@!#;VQU;6X@=&ET;&5S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT
M`$-O;6]R;W,`0V]M<&%N>0!#;VUP;W-E($UE<W-A9V4@*"5S*0!#;VUP=71E
M<G,`0V]N9&ET:6]N<P!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#
M;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O
M;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I
M;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO
M;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S
M("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C
M=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O
M;VLN`$-O;G1E;G1S(&]F("(E<R(`0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O
M<'D`0V]P>2!S96QE8W1I;VX`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A
M9V4N`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@4R]-
M24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE
M<W-A9V4N`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N
M;W0@8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O=6QD
M(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N;W0@9&5C<GEP="!3+TU)
M344@9&%T82X`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@
M92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F
M<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R
M:71I;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN
M=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O
M<GD@(B5S(BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#;W5L9&XG="!F:6YD
M('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I
M<R!O<&5N+@!#;W5N=')Y`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A
M(&YE=R!O;F4`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R
M96YT(%1I;64`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O
M("5S+@!#=70`0WEP<G5S`$-Z96-H(%)E<'5B;&EC`$1$`$1A:6QY`$1A=&4`
M1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5F875L="!#;VQO<@!$969A=6QT
M($ED96YT:71Y`$1E9F%U;'0@4&5R;6ES<VEO;G,`1&5F875L="!P97)M:7-S
M:6]N<P!$96QE=&4`1&5L971E($=R;W5P`$1E;&5T92!097)M:7-S:6]N`$1E
M;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L971E(&-E;&P`1&5L971E(&-O
M;'5M;@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI
M<W-I;VYS(&9O<B`B)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE
M=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U
M<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E('1H
M:7,@<&5R;6ES<VEO;B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5N;6%R
M:P!$97-C<FEB92!T:&4@4')O8FQE;0!$971A:6QS(&AA=F4@8F5E;B!L;V=G
M960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$:7)E8W1O<GD`1&ES<&QA>2`R
M-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&II8F]U=&D`1&\@;F]T
M(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H
M<`!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]W;FQO860`1&]W;FQO
M860@)7,`1')U9W,`12U-86EL`$5C=6%D;W(`161I=`!%9&ET($=R;W5P`$5D
M:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO
M;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@
M9F]R("5S`$5G>7!T`$5L(%-A;'9A9&]R`$5M86EL`$5M86EL($%D9')E<W,`
M16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M;W1I8V]N<P!%;7!T>2!M
M97-S86=E+@!%;7!T>2!R97-U;'0N`$5N86)L92!R:6=H="!C;&EC:R!C;VYT
M97AT(&UE;G4_`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R
M;W(@=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5U<F]P90!%=F5R
M>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S
M`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`
M179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%
M>'!A;F0@4VED96)A<@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E
M<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T
M;R`B)7,B+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86QK;&%N9"!)<VQA
M;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X
M`$9E8G)U87)Y`$9I:FD`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E
M;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E
M9"X`1FEL=&5R<P!&:6YL86YD`$9O;V0`1F]R9V]T('EO=7(@<&%S<W=O<F0_
M`$9R86YC90!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H
M(%-O=71H97)N(%1E<G)I=&]R:65S`$9R;VT`1V%B;VX`1V%M8FEA`$=E<FUA
M;GD`1VAA;F$`1VEB<F%L=&%R`$=O`$=O;V=L92!396%R8V@`1W)E96-E`$=R
M965N;&%N9`!'<F5N861A`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M
M86QA`$=U97)N<V5Y`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,
M`$AA:71I`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96QP
M`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M
M90!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`
M2&]R9&4`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E
M<R(`2'5N9V%R>0!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@=VET:"!T97AT
M`$ED96YT:71Y)W,@;F%M93H`26UA9V5S`$EM<&]R=&5D(&9I96QD.B`E<P!)
M;7!O<G1E9"!F:65L9',Z`$EN9&EA`$EN9&]N97-I80!);F9O`$EN<V5R="!)
M;6%G90!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T
M:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!L:6-E
M;G-E(&ME>2X`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA
M;F0`27-R865L`$ES<W5E<@!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`
M2F]R9&%N`$IU;'D`2G5N90!+87IA:VAS=&%N`$ME;GEA`$ME>2!#<F5A=&EO
M;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@86QR
M96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER
M:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`
M2V]R96$L(%)E<'5B;&EC(&]F`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`
M3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S
M="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN
M.B!.979E<@!,871V:6$`3&5S;W1H;P!,:6)E<FEA`$QI8GEA;B!!<F%B($IA
M;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:7-T($AE;'`@5&]P:6-S`$QI<W1I
M;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO
M8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]G(&EN`$QO9R!O=70`3&]G
M:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O
M<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I
M;&5D+@!,;W<`3'5X96UB;W5R9P!-30!-3U1$`$U31P!-86-A;P!-86-E9&]N
M:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A
M<@!-86EL`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA
M;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L
M(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E
M(&-A=&5G;W)I97,N`$UA<F-H`$UA<F=I;@!-87)S:&%L;"!)<VQA;F1S`$UA
M<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S
M`$UA>0!-87EO='1E`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G90!-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A
M:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI
M;FES=')A=&]R+@!-97AI8V\`36EM92!4>7!E`$UO9&EF:65D($1A=&4`36]D
M:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-
M;VYG;VQI80!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R;V-C
M;P!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E
M(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UY($%C8V]U;G0`37D@4&]R=&%L
M`$UY86YM87(`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE<FQA;F1S
M`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='=O<FL`3F5V97(`3F5W($-A;&5D
M;VYI80!.97<@0V%T96=O<GD`3F5W(%IE86QA;F0`3F5W<P!.97AT`$YE>'0@
M;W!T:6]N<P!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:75E`$YO(&-H86YG
M92X`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M("5S+@!.;R!F:6QE('5P;&]A9&5D`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@3$1!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;VYE`$YO<F9O
M;&L@27-L86YD`$YO<G=A>0!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T
M('-U<'!O<G1E9"X`3F]T97,`3F]T:6-E`$YO=F5M8F5R`$YU;6)E<B!O9B!C
M;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$]+`$]C=&]B97(`3V9F:6-E`$]M86X`
M3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/<&5N(&EN(&$@;F5W
M('=I;F1O=P!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9V%N:7-A=&EO;@!/
M<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W1H97(`3W1H97(@26YF
M;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N
M(&ES(&YO="!A=F%I;&%B;&4N`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@
M16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R
M>7!T960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`4%](4"!3:&5L;`!086MI
M<W1A;@!086QA=0!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!0
M87-S=V]R9`!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@=VET:"!C;VYF
M:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@
M;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!E<F9O<FT@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;G,@9F]R`%!E
M<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&AI;&EP<&EN97,`4&AO;F4`4&ET
M8V%I<FX`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@
M=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O
M('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A('9A;&ED($E0
M(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P
M<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I
M9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&]L86YD`%!O<G1U9V%L
M`%!R979I97<`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T
M:6]N`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME
M>2!);F9O`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S
M=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%%A=&%R`%%U97)Y`%)302!0=6)L
M:6,@2V5Y("@E9"!B:70I`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S
M.@!2969R97-H(%!O<G1A;"!6:65W.@!296UO=&4@4V5R=F5R<P!296UO=F4`
M4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E('!A:7(`4F5M;W9E
M('1H90!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5S970`4F5S970@
M4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-U;'1S`%)E='5R;B!T
M;R!/<'1I;VYS`%)E=6YI;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)O
M;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H
M=`!2;W<@<')O<&5R=&EE<P!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O
M34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES
M(&YO="!A=F%I;&%B;&4N`%-13"!3:&5L;`!34T@`4U]13"!3:&5L;`!386EN
M="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A
M:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE
M($=R96YA9&EN97,`4V%M;V$`4V%N($UA<FEN;P!3875D:2!!<F%B:6$`4V%V
M90!3879E("(E<R(`4V%V92`E<P!3879E($]P=&EO;G,`4V5A<F-H`%-E;&5C
M="!&:6QE<P!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE
M(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O
M(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H
M92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E
M;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D
M(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F5G86P`4V5P=&5M
M8F5R`%-E<FEA;"!.=6UB97(`4V5T`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T
M:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@
M>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P
M=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C
M:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I
M;VYS+@!3971U<`!397EC:&5L;&5S`%-H;W)T(%-U;6UA<GD`4VAO=P!3:&]W
M(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@=&AE("5S
M($UE;G4@;VX@=&AE(&QE9G0_`%-I97)R82!,96]N90!3:6=N('5P(&EF(&YO
M="!R96=I<W1E<F5D`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I
M;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N
M:6$`4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]U=&@@069R:6-A`%-O=71H
M($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@
M4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3<&%I;@!3<&%M`%-P96-I86P@0VAA
M<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O
M=P!3<FD@3&%N:V$`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T<F5E="!!
M9&1R97-S`%-U8FIE8W0`4W5B;6ET`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D
M9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R960@
M9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U
M;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S(B!F
M<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!U<&1A=&5D("(E<R(`4W5D
M86X`4W5N<FES92]3=6YS970`4W5R:6YA;64`4W=A>FEL86YD`%-W961E;@!3
M=VET>F5R;&%N9`!3>7)I86X@07)A8B!297!U8FQI8P!486EW86X`5&%I=V%N
M+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET
M960@4F5P=6)L:6,@;V8`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!497AT($]N
M;'D`5&AA:6QA;F0`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4
M:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R
M("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B
M965N('-A=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL
M86)L92X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!W
M87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T96TZ("5S`%1H
M97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B
M(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I
M;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M
M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y
M:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&ES(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P
M<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&9I96QD(&ES(')E
M<75I<F5D+@!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H
M:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S
M*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES('-E<G9E<B!C86XG="!U;F-O
M;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&EM90!4:6UE(&9O<FUA=`!4
M:71L90!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T
M:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L
M:6-K:6YG+@!4;V1A>0!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5')I
M;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U;FES:6$`5'5R:V5Y
M`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=79A;'4`55),
M`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&-H86YG92!T;R`E<RX`
M56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&1E
M8V]M<')E<W,@9&%T82X`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@
M9&]C=6UE;G0`56YD;R!#:&%N9V5S`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N
M:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YK;F]W;@!5;FYA;65D`%5N
M<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!L;V%D`%5R=6=U87D`57-E
M<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97)N86UE`%5S97)N86UE
M("(E<R(@86QR96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S
M97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5F%C871I;VX`5F%N=6%T
M=0!696YE>G5E;&$`5F5R<VEO;@!6:65T($YA;0!6:65W("5S`%9I97<@86X@
M97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L86YD<RP@
M0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!786QL:7,@86YD($9U='5N
M80!787)N:6YG`%=E8@!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E
M;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX
M.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L
M9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&EC:"!P;'5G:6YS('1O(&5N
M86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H(&]F('1H92`E
M<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M
M:6XI.@!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!960!965E9`%EE87)L>0!9
M96UE;@!997,`665S+"!)($%G<F5E`%EO=2!H879E(&)E96X@;&]G9V5D(&]U
M="X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C
M86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T('-P96-I9GD@
M82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S
M97)N86UE('1O(&%D9"X`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@
M861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E
M<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S
M('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@
M;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,L(&]R('1H92!F
M96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O
M;BX`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O
M<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES
M86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&-U<G)E;G0@=&EM
M92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE
M.@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N
M<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@
M<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R
M(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB
M86)W90!;4')O8FQE;2!297!O<G1=`%]!9&UI;FES=')A=&EO;@!?0TQ)`%]$
M96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TQO9R!I;@!?3&]G(&]U=`!?36]D
M:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN
M:RXN+@!?4V5T=7``7U5S97)S`&%D9')E<W,@8F]O:P!C86QE;F1A<@!F:6QE
M`&YA;64`;F]T97!A9`!U;FYA;65D`'9#87)D`%!R;VIE8W0M260M5F5R<VEO
M;CH@2&]R9&4@,RXP+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI
M<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,2TR-"`R
M,#HU-BLP,3`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#4M,3$M,C0@,C$Z-#8K
M,#$P,`I,87-T+51R86YS;&%T;W(Z($MR>GES>G1O9B!+;WIL;W=S:VD@/&MO
M>FEK,4!O,BYP;#X*3&%N9W5A9V4M5&5A;3H@4&]L:7-H(#QP;$!L:2YO<F<^
M"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@
M8VAA<G-E=#UI<V\M.#@U.2TR"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z
M(#@M8FET"@`E<R`M(&=O=&]W>2!D;R!W>6MO;F%N:6$@8WEK;&EC>FYY8V@@
M;W!E<F%C:FD@>F%Z;F%C>F]N>6-H('!O;FF_96HN`"`H)7,@9&YI('1E;74I
M`"AK;'5C>B!D;W-TZG!U("5S*0`@*'<@8VFQ9W4@)7,@9&YI*0`@*&1Z:;8I
M`"`H:G5T<F\I`"`H=V-Z;W)A:BD`(B5S(B!N:64@:F5S="!P<F%W:62S;W=Y
M;2!W>6)O<F5M+@`B)7,B(&YI92!J97-T('-K;VYF:6=U<F]W86YY('<@<F5J
M97-T<GIE($AO<F1E+@!59&&S;R!S:>H@9&]D8>8@(B5S(B!D;R!G<G5P+@!5
M9&&S;R!S:>H@9&]D8>8@(B5S(B!D;R!U<')A=VYI9?$N`"(E<R(@;FEE('IO
M<W1ALR!U='=O<GIO;GDZ("5S+@`E9"`E<R!I("5S`"5S("T@57=A9V$`061M
M:6YI<W1R86-J82`E<P`E<R!O9&-I<VL@<&%L8V$`)7,@:T(`)7,@+2!O<&5R
M86-J92!C>6ML:6-Z;F4@+2!P;W1W:65R9'IE;FEE`$MO;F9I9W5R86-J82`E
M<P!296IE<W1R86-J82`E<P`E<R!J=;\@:7-T;FEE:F4N`"5S(&IE<W0@=WEM
M86=A;GD`)7,@;6EN=70`)7,@;FEE>FYA;&5Z:6]N>2X`)7,@9&\@)7,@>B`E
M<P!+<VFQOVMA(&%D<F5S;W=A("5S`$MA;&5N9&%R>B`E<P!.;W1A=&YI:R`E
M<P!,:7-T82!Z861A\2`E<P`E<SH@)7,`+2T@=WEB:65R>B`M+0`Q,BUG;V1Z
M:6YN>2!F;W)M870`,C0M9V]D>FEN;GD@9F]R;6%T`#(T(&=O9'HN`#Q0;W!R
M>F5D;FD`3F%S=+%P:;,@8K.Q9"!K<GET>6-Z;GD`4&]T<GIE8FYY(&IE<W0@
M:VQU8WH@<'5B;&EC>FYY(%!'4"!D;R!Z87-Z>69R;W=A;FEA('=I861O;6^V
M8VDN`%!O=')Z96)N>2!J97-T(&ML=6-Z('!U8FQI8WIN>2!01U`@9&\@<W!R
M87=D>F5N:6$@<&]D<&ES86YE:B!W:6%D;VUOMF-I+@!0;W1R>F5B;F4@<[$@
M:VQU8WH@<'5B;&EC>FYY(%!'4"P@:VQU8WH@<')Y=V%T;GD@4$=0(&]R87H@
M:&%SLV\@9&\@;V1S>GEF<F]W86YI82!W:6%D;VUOMF-I+@!0;W1R>F5B;F4@
M<[$@:VQU8WH@<'5B;&EC>FYY(%!'4"P@:VQU8WH@<')Y=V%T;GD@4$=0(&]R
M87H@:&%SLV\@9&\@<&]D<&ES86YI82!W:6%D;VUOMF-I+@!0;W1R>F5B;F4@
M<[$@:VQU8WH@<'5B;&EC>FYY(%,O34E-12P@:VQU8WH@<')Y=V%T;GD@4R]-
M24U%(&]R87H@:&%SLV\@9&\@;V1S>GEF<F]W86YI82!W:6%D;VUOMF-I+@!0
M;W1R>F5B;F4@<[$@:VQU8WH@<'5B;&EC>FYY(%,O34E-12P@:VQU8WH@<')Y
M=V%T;GD@4R]-24U%(&]R87H@:&%SLV\@9&\@<&]D<&ES86YI82!W:6%D;VUO
MMF-I+@!0;W1R>F5B;GD@:F5S="!K;'5C>B!P=6)L:6-Z;GD@4TU)344@9&\@
M>F%S>GEF<F]W86YI82!W:6%D;VUOMF-I+@!!32]030!/('1Y;2!E9'ET;W)Z
M90!/('!R;V=R86UI92XN+@!(87.S;R!D;R!K;VYT80!+;VYT;R!Z86)L;VMO
M=V%N92X`2V]N=&$`1&]D86H`1&]D86H@='5T86HZ`$1O9&%J(&YO=[$@9W)U
M<.H`1&]D86H@;F]W92!U<')A=VYI96YI90!$;V1A:B!N;W=E9V\@=;]Y=&MO
M=VYI:V$Z`$1O9&%J(&MO;'5M;NH`1&]D86H@;F]W>6-H(&-ZLV]N:_-W`$1O
M9&%J('!A<NH`1&]D86H@;65N=2`E<R!D;R!P87-K82!-;WII;&QI`$1O9&%J
M(&1O(&MS:;&_:VD@861R97-O=V5J.@!$;V1A:B!D;R!M;VIE:B!K<VFQ>FMI
M(&%D<F5S;W=E:@!$;V1A:B!UOWET:V]W;FEK80!$;V1A;F\@(B5S(B!D;R!S
M>7-T96UU+B!-;[]E<WH@<VGJ('IA;&]G;W=AYBX`1&]D87=A;FEE('6_>71K
M;W=N:6OS=R!J97-T('=YLV%C>F]N92X`061R97,`2W-IL;]K82!A9')E<V]W
M80!!9&UI;FES=')A8VIA`%)E:VQA;7D`069G86YI<W1A;@!!;&)A;FEA`$%L
M9VEE<FEA`$%L:6%S`%=S>GES=&MO`%=S>GES8WD@=7=I97)Z>71E;&YI96YI
M('6_>71K;W=N:6-Y`%=S>GES=&MI92!G<G5P>0!7<WIY<W1K:64@=7!R87=N
M:65N:6$`4&]Z=_-L(&YA('=I96QE(&%D<F5S\W<`2G6_(&ES=&YI96IE`$%L
M=&5R;F%T>7=N>2!L;V=I;B!)35-0`$%L=&5R;F%T>7=N>2!H87.S;R!)35-0
M`$%L=&5R;F%T>7=N82!N87IW82!UOWET:V]W;FEK82!)35-0`$%L=&5R;F%T
M>7=N>2!A9')E<R!E;6%I;`!!;'1E<FYA='EW;GD@=&5K<W0Z`%IO<W1ALV$@
M<&]D86YA(&YI97!R87=I9+-O=V$@=V%R=&^VYBX`06YD;W)A`$%N9V]L80!!
M;F=U:6QL80!!;F]N:6UO=V4@4')O>'D`3V1P;W=I962\`$%N=&%R:W1Y9&$`
M07!L:6MA8VIA`$%P;&EK86-J82!G;W1O=V$`6F%T=VEE<F2\`$MW:65C:67Q
M`%=I96QK;[;F(&%R8VAI=W5M`$YA>G=A(&%R8VAI=W5M`$%R9V5N='EN80!!
M<FUE;FEA`$%R=6)A`%!O<')OMB!O('!O='=I97)D>F5N:64@<')Z960@=WEK
M;VYA;FEE;2!O<&5R86-J:2!C>6ML:6-Z;GEC:#\`071R>6)U='D`4VEE<G!I
M9?$`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)U<SH@3FEE('IN86QE>FEO
M;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@:6UA<"X`075T:%]C>7)U<SH@
M3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@:6UA<"X`
M075T:%]F='`Z($YI92!Z;F%L97II;VYO('=Y;6%G86YE9V\@<F]Z<WIE<GIE
M;FEA($944"X@4VMO;7!I;'5J(%!(4"!Z('!A<F%M971R96T@+2UE;F%B;&4@
M+@!!=71H7VEM87`Z($YI92!Z;F%L97II;VYO('=Y;6%G86YE9V\@<F]Z<WIE
M<GIE;FEA($E-05`N`$%U=&A?:W)B-3H@3FEE('IN86QE>FEO;F\@=WEM86=A
M;F5G;R!R;WIS>F5R>F5N:6$@:W)B-2X`075T:%]L9&%P.B!.:64@>FYA;&5Z
M:6]N;R!W>6UA9V%N96=O(')O>G-Z97)Z96YI82!,1$%0+@!!=71H7VQD87`Z
M($YI92!U9&&S;R!S:>H@=7-U;K'F('6_>71K;W=N:6MA("5S`$%U=&A?;&1A
M<#H@3FEE('5D8;-O('-IZB!U86MT=6%L;FGF('6_>71K;W=N:6MA("5S`$%U
M=&A?;6-A;#H@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N
M:6$@34-!3"X`075T:%]S;6)A=71H.B!.:64@>FYA;&5Z:6]N;R!W>6UA9V%N
M96=O(')O>G-Z97)Z96YI82!S;6)A=71H+@!5=VEE<GIY=&5L;FEE;FEE(&YI
M92!P;W=I;V2S;R!S:>H`57=I97)Z>71E;&YI96YI92!N:64@<&]W:6]DLV\@
M<VGJ+B`E<P!5=VEE<GIY=&5L;FEE;FEE(&]D<GIU8V]N92!P<GIE>B!S97)W
M97(@4D%$2553+@!5=VEE<GIY=&5L;FEE;FEE(&1O('-E<G=E<F$@1E10(&YI
M92!P;W=I;V2S;R!S:>HN`$1O<W3J<&YE('!O;&$Z`$%Z97)B96IDOV%N`%=Y
M;?-W:VD@0D]&2`!4LV\`2V]L;W(@=+-A`%JS92!H87.S;R!+97)B97)O<V$N
M`%JS82!N87IW82!UOWET:V]W;FEK82!+97)B97)O<V$`5WES<'D@0F%H86UA
M`$)A:')A:FX`0F&S='EC:VD@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-Z`$)I
M8;-O<G6V`$)E;&=I80!"96QI>F4`0F5N:6X`0F5R;75D>0!":'5T86X`1&%T
M82!U<F]D>F5N:6$`57-T87=I96YI82!B;&]K=0!4>7`@8FQO:W4`0F]L:7=I
M80!:86NS861K:0!";[9N:6$@:2!(97)C96=O=VEN80!/8F$`0G)A>GEL:6$`
M0G6S9V%R:6$`0TU3`$-20P!7LV&V8VEW;[9C:2!K;VWS<FMI+BXN("A?8RD`
M2V%L96YD87)Z`$MA;6)O9+]A`$MA;65R=6X`3FEE('5D8;-O('-IZB!Z<F5S
M971O=V'F(&AA<[-A(&%U=&]M871Y8WIN:64L('-K;VYT86MT=6H@<VGJ('H@
M861M:6YI<W1R871O<F5M+@!"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@
M<V5R=V5R96T@24U!4#H@)7,`2V%N861A`$%N=6QU:@!!;G5L=6H@<F%P;W)T
M(&\@<')O8FQE;6EE`$YI92!M;[]N82!S:V%S;W=AYB!P;&EK=2`B)7,B`$YI
M92!U9&&S;R!S:>H@>FYA;&6\YB!K871A;&]G=2!T>6UC>F%S;W=E9V\N`$YI
M92!M;[]N82!S:V%S;W=AYB!K871A;&]G=2`B)7,B`%=Y<W!Y(%II96QO;F5G
M;R!0<GIY;+%D:V$`2V%T96=O<FEE(&D@;WIN86-Z96YI80!496PN(&MO;2X`
M5[-AMF-I=V^V8VD@:V]M\W)K:0!7LV&V8VEW;[9C:2!K;VWS<FMI`%1E;"X@
M:V]M+@!#96QT>6-K:2`H25-/+3@X-3DM,30I`%)E<'5B;&EK82"F<F]D:V]W
M96H@069R>6MI`*9R;V1K;W=O975R;W!E:G-K:2`H25-/+3@X-3DM,BD`4WIC
M>F5G\[-Y(&-E<G1Y9FEK871U`%>S8;9C:6-I96P@8V5R='EF:6MA='4`0WIA
M9`!:;6EE\0!:;6EE\2!I;6GJ+"!N87IW:7-K;R!I(&%D<F5S+"!K=/-R>2!I
M;FYI('=I9'JQ('<@5'=O:6-H(&QI<W1A8V@@96UA:6PN`%-P<F%W9+P@;&EN
M:RXN+@!:87IN86-Z('!O>GEC:NH@9&QA(&MT\W)E:B!C:&-E<WH@=WEK;VYA
MYB!O<&5R86-JZBX`0VAI;&4`0VAI;GD`4&]D86H@:&%SLV\`4&]D86H@;F%Z
M=^H@=;]Y=&MO=VYI:V$`5WEB:65R>B!S<&]S\V(@=WFV=VEE=&QA;FEA(&1A
M=#H`5WES<&$@0F^_96=O($YA<F]D>F5N:6$`2VQI:VYI:B!B>2!K;VYT>6YU
M;W=AY@!:86UK;FEJ(&]K;F\`5WES<'D@2V]K;W-O=V4@*$ME96QI;F=A*0!3
M8VAO=V%J('!A<V5K`$MO;'5M8FEA`$MO;&]R`%=Y8FEE<GH@:V]L;W(`5WEB
M\W(@:V]L;W)U`%1Y='6S>2!K;VQU;6X`2V]M96YD80!0;W>S;VMA`$MO;65N
M=&%R>@!+;VUO<GD`1FER;6$`4W1W\W)Z('=I861O;6^VYB`H)7,I`$MO;7!U
M=&5R>0!787)U;FMI`%-K;VYF:6=U<G5J("5S`%!O='=I97)DO"!H87.S;P!+
M;VYG;P!$96UO:W)A='EC>FYA(%)E<'5B;&EK82!+;VYG;P!0;[.Q8WIE;FEE
M(&YI92!P;W=I;V2S;R!S:>HN`%!OL[%C>F5N:64@;FEE('!O=VEO9+-O('-I
MZCH@`$]D;?-W:6]N;R!P;[.Q8WIE;FEA(&1O('!U8FQI8WIN96=O('-E<G=E
M<F$N`$]D;?-W:6]N;R!P;[.Q8WIE;FEA(&1O('!U8FQI8WIN96=O('-E<G=E
M<F$N(%!O=_-D.B`E<R`H)7,I`$*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@
M>B!S97)W97)E;2!&5%`N`$MO;G1A:W1Y('IO<W1ALWD@<&]M>;9L;FEE(&1O
M9&%N92!D;R!4=V]J96H@:W-IL;]K:2!A9')E<V]W96HN`%IA=V%R=&^VYB`B
M)7,B`$MO;GEN=75J`%=Y<W!Y($-O;VMA`%-K;W!I=6H`4VMO<&EU:B!W>6+S
M<@!.:64@=61ALV\@<VGJ('IA<WIY9G)O=V'F("A01U`I('=I861O;6^V8VDN
M`$YI92!U9&&S;R!S:>H@<&]D<&ES8>8@*%!'4"D@=VEA9&]M;[9C:2X`3FEE
M('5D8;-O('-IZB!Z87-Z>69R;W=AYB`H4R]-24U%*2!W:6%D;VUOMF-I+@!.
M:64@=61ALV\@<VGJ('!O9'!I<V'F("A3+TU)344I('=I861O;6^V8VDN`$*S
ML60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!,1$%0+@!"L[%D
M('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@(B5S(B!P;W!R>F5Z
M($944#H@)7,`3FEE('5D8;-O('-IZB!O9'-Z>69R;W=AYB!D86YY8V@@4$=0
M+@!.:64@=61ALV\@<VGJ(&]D<WIY9G)O=V'F(&1A;GEC:"!3+TU)344N`$YI
M92!U9&&S;R!S:>H@=7-T86QIYB!A9')E<W4@92UM86EL(&]D8FEO<F-Y+@!.
M:64@=61ALV\@<VGJ('5Z>7-K8>8@>B!S97)W97)A(&ML=6-Z82!P8G5L:6-Z
M;F5G;RX`3FEE('5D8;-O('-IZB!O='=O<GIYYB`B)7,B(&1O('IA<&ES=2X`
M3FEE(&UOOVYA(&]T=V]R>GGF("5S+@!.:64@;6^_;F$@;W1W;W)Z>>8@;6]D
M=;-U($UA:6YT96YA;F-E7U1A<VL@)7,`3FEE(&UOOVYA(&]T=V]R>GGF(&MA
M=&%L;V=U("(E<R(`3FEE('5D8;-O('-IZB!S:V%S;W=AYB!P;&EK=2`B)7,B
M+@!.:64@=61ALV\@<VGJ('IN86QEO.8@<&%S:V$@36]Z:6QL:2X@57!E=VYI
M:B!S:>HL(+]E(&IE<W0@;VX@;W1W87)T>2X`2W)A:@!3='?S<GH`4W1W\W)Z
M(&QI;FL`4W1W\W)Z(&YO=[$`3G5M97(@:V%R='D@:W)E9'ET;W=E:@!#:&]R
M=V%C:F$`2W5B80!/8F5C;GD@8WIA<P!3<&5R<V]N86QI>G5J('IA9&%N:6$@
M=7)U8VAA;6EA;F4@<')Z>2!L;V=O=V%N:74@9&\@)7,N`%=Y=&YI:@!#>7!R
M`%)E<'5B;&EK82!#>F5C:`!$1`!#;V1Z:65N;FEE`$1A=&$`7U5S=?$@:V]L
M=6UNZ@!'<G5D>FEE\0!$;VUYMFQN>2!K;VQO<@!$;VUYMFQN82!T;[]S86UO
MMN8`1&]M>;9L;F4@=7!R87=N:65N:6$`1&]M>;9L;F4@=7!R87=N:65N:6$`
M57-U\0!5<W7Q($=R=7#J`%5S=?$@=7!R87=N:65N:6$`57-U\2!I('=Y8WIY
MMN8@=VEA9&]M;[9C:0!5<W7Q(&MO;?-R:^H`57-U\2!K;VQU;6[J`%-K87-U
M:B!U<')A=VYI96YI82!D;&$@(B5S(@!3:V%S;W=AYB!U<')A=VYI96YI82!D
M;&$@(B5S(B!I('=S>GES=&MI92!P;V0M=7!R87=N:65N:6$_`%5S=?$@=VEE
M<G-Z`%-K87-U:B!W>6)R86ZQ('1OOW-A;6^VY@!5<W7Q(&%K='5A;&ZQ(&MO
M;'5M;NH`57-U\2!A:W1U86QN>2!W:65R<WH`4VMA<V]W8>8@=&\@=7!R87=N
M:65N:64@:2!W<WIY<W1K:64@<&]D+75P<F%W;FEE;FEA/P!$86YI80!/<&ES
M>B!P<F]B;&5M`%-Z8WIE9_.S>2!Z;W-T8;-Y('IA;&]G;W=A;F4@9&QA(&%D
M;6EN:7-T<F%T;W)A+@!+871A;&]G`%=YMG=I971L(&-Z87,@=R!F;W)M86-I
M92`R-"UG;V1Z:6YN>6T_`%5S=&%W:65N:6$@=WEG;+%D=0!$OVEB=71I`$YI
M92!K87-U:@!"<F%K(&)E>G!OMG)E9&YI96=O(&1O<W3J<'4@9&\@;6%I;G1E
M;F%N8V4N<&AP`$1O;6EN:6MA("A7<W#S;&YO=&$@1&]M:6YI:VDI`$1O;6EN
M:6MA;F$@*%)E<'5B;&EK82!$;VUI;FEK8?%S:V$I`*9C:;%G;FEJ`*9C:;%G
M;FEJ("5S`$YA<FMO='EK:0!%+6UA:6P`16MW861O<@!%9'EC:F$`57-U\2!'
M<G5PZ@!:;6EE\2!U<')A=VYI96YI90!:;6EE\2!U<')A=VYI96YI80!:;6EE
M\2!U<')A=VYI96YI82!D;&$@)7,`6FUI9?$@=7-T87=I96YI82!D;&$Z`%IM
M:67Q('5P<F%W;FEE;FEA(&1L82`E<P!%9VEP=`!386QW861O<@!%;6%I;`!!
M9')E<R!E;6%I;`!!9')E<WD@96UA:6P@;75S>K$@9&\@<VEE8FEE('!A<V]W
M8>8N`$5M;W1I:V]N>0!0=7-T82!W:6%D;VUOMN8N`$)R86L@<F5Z=6QT873S
M=RX`5[.Q8WIYYB!M96YU(&MO;G1E:W-T;W=E('!O9"!P<F%W>6T@<')Z>6-I
M<VMI96T@;7ES>GD_`$=W:6YE82!2\W=N:6MO=V$`17)Y=')E80!"L[%D`$*S
ML60@<')Z>2!Z87!I<VEE("(E<R(N`$5S=&]N:6$`171I;W!I80!%=7)O<&$`
M0V\@:V&_9&4@,34@;6EN=70`0V\@:V&_9&4@,B!M:6YU='D`0V\@:V&_9&4@
M,S`@<V5K=6YD`$-O(&MAOV1E(#4@;6EN=70`0V\@:V&_9&4@>F%L;V=O=V%N
M:64`0V\@:V&_9&4@</.S(&=O9'II;GD`0V\@:V&_9+$@;6EN=73J`%!R>GEK
MLV%D;W=E('=A<G1OMF-I.@!7>6MO;F%J`%)O>G=I\0!2;WIW:?$@<&%S96L`
M0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M($Q$05`N`$*S
ML60@<&]D8WIA<R!K;W!I;W=A;FEA('H@(B5S(BX`0K.Q9"!P;V1C>F%S(&MO
M<&EO=V%N:6$@9&\@(B5S(BX`0K.Q9"!P;V1C>F%S('!R>F5N;W-Z96YI82!D
M;R`B)7,B+@!&86QK;&%N9'D@*$UA;'=I;GDI`%=Y<W!Y($]W8WIE`$*SL60@
M:W)Y='EC>FYY.B``1F%K<P!,=71Y`$9I9+]I`$UE;F5DOV5R('!L:6OS=P!.
M87IW82!P;&EK=0!7>6+S<B!P;&EK=0!79W)Y=V%N:64@<&QI:W4`5V=R>7=A
M;FEE('!L:6OS=R!N:64@:F5S="!O8G.S=6=I=V%N92X`1FEL=')Y`$9I;FQA
M;F1I80!*961Z96YI90!:87!O;6YI8;-EMB!H87.S83\`1G)A;F-J80!'=6IA
M;F$@1G)A;F-U<VMA`%!O;&EN97IJ82!&<F%N8W5S:V$`1G)A;F-U<VMI92!4
M97)Y=&]R:6$@4&^S=61N:6]W92!I($%N=&%R:W1Y8WIN90!/9`!'86)O;@!'
M86UB:6$`3FEE;6-Y`$=H86YA`$=I8G)A;'1A<@!)9+P`5WES>G5K:7=A<FMA
M($=O;V=L90!'<F5C:F$`1W)E;FQA;F1I80!'<F5N861A`$=R=7!Y(&1Y<VMU
M<WEJ;F4`1W=A9&5L=7!A`$=U86T`1W=A=&5M86QA`$=U97)N<V5Y`$=W:6YE
M80!'=VEN96$@0FES<V%U`$=U:F%N80!(5$U,`$AA:71I`%=Y<W!Y($AE87)D
M(&D@36-$;VYA;&1A`%!O;6]C`%=Y<V]K:0!?4W1A<G0`5V%T>6MA;B`H4W1O
M;&EC82!!<&]S=&]L<VMA*0!0;V-ZL71E:P!!9')E<R!D;VUO=WD`5&5L+B!D
M;VTN`$AO;F1U<F%S`$AO;F=+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!59&&S
M;R!S:>H@=7-U;K'F("5S("(E<R(`5^IG<GD`27-L86YD:6$`5'EL:V\@:6MO
M;GD`26MO;GD@>B!T96MS=&5M`$YA>G=A('1OOW-A;6^V8VDZ`$=R869I:V$`
M26UP;W)T;W=A;F4@<&]L93H@)7,`26UP;W)T;W=A;F4@<&]L83H`26YD:64`
M26YD;VYE>FIA`$EN9F\`5VML96H@;V)R87IE:P!7>7.S86YE(&YI97!R87=I
M9+-O=V4@9&%N92X`3FEE<')A=VEDLV]W>2!A9')E<R!D;V-E;&]W>2X`3FEE
M<')A=VEDLV]W>2!F;W)M870@<&QI:W4`3FEE<')A=VEDLV]W>2!K;'5C>B!L
M:6-E;F-J:2X`27)A;@!)<F%K`$ER;&%N9&EA`$EZ<F%E;`!7>61A=V-A`%>S
M;V-H>0!*86UA:FMA`%-T>6-Z9?$`2F%P;VYI80!*;W)D86X`3&EP:65C`$-Z
M97)W:65C`$MA>F%C:'-T86X`2V5N:6$`5'=O<GIE;FEE(&ML=6-Z80!/9&-I
M<VL@:VQU8WIA`$2S=6=OMN8@:VQU8WIA`%1Y<"!K;'5C>F$`2VQU8WH@:G6_
M(&ES=&YI96IE(&YA('!U8FQI8WIN>6T@<V5R=V5R>F4@:VQU8WIY+@!$>FEE
M8VD`2VER:6)A=&D`2V]R96'Q<VMA(%)E<'5B;&EK82!,=61O=V\M1&5M;VMR
M871Y8WIN80!297!U8FQI:V$@2V]R96D`2W5W96IT`$MI<F=I<W1A;@!7>6=L
ML60@*%]Y*0!*ZGIY:P!,86]S`$]S=&%T;FEE(&QO9V]W86YI93H@)7,`3W-T
M871N:64@;&]G;W=A;FEE.B`E<R!Z("5S`$]S=&%T;FEE(&QO9V]W86YI93H@
M;FEG9'D`HV]T=V$`3&5S;W1H;P!,:6)E<FEA`$QI8FEA`$QI96-H=&5N<W1E
M:6X`5WFV=VEE=&P@=&5M871Y('!O;6]C>0!,:7-T;W=A;FEE('6_>71K;W=N
M:6OS=R!J97-T('=YL[%C>F]N92X`3&ET=V$`HV%D;W=A;FEE+BXN`$-Z87,@
M;&]K86QN>3H@`%5S=&%W:65N:6$@;&]K86QN92!I(&-Z87,`6F%L;V=U:@!7
M>6QO9W5J`%IA9&%N:6$@<')Z>2!L;V=O=V%N:74`3&]G;W=A;FEE(&YI92!P
M;W=I;V2S;R!S:>HL('!O;FEE=V&_('!O9&&S9;8@;FEE<')A=VEDLV]W92!H
M87.S;R!L=6(@;F%Z=^H@=;]Y=&MO=VYI:V$N`$QO9V]W86YI92!N:64@<&]W
M:6]DLV\@<VGJ+@!.:7-K:0!,=6MS96UB=7)G`$U-`$U/5$0`35-'`$UA:V%U
M`$UA8V5D;VYI80!-861A9V%S:V%R`%!O8WIT80!-86QA=VD`36%L97IJ80!-
M86QE9&EW>0!-86QI`$UA;'1A`%IA<GJQ9'IA:B!L:7-TL2!K871E9V]R:6DL
M(&MT\W)Y;6D@8NID>FEE<WH@;WIN86-Z8;,@<&]Z>6-J92P@:2!K;VQO<F%M
M:2!Z(&YI;6D@>G=IL7IA;GEM:2X`36%R>F5C`$UA<F=I;F5S`%=Y<W!Y($UA
M<G-H86QL80!-87)T>6YI:V$`4&%S=6JQ8V4@<&]L80!-875R971A;FEA`$UA
M=7)I=&EU<P!-86H`36%J;W1T80!4<GEB(&UE;G4Z`%!OL[%C>B!K;VWS<FMI
M`%=I861O;6^VY@!";&]K(")-971A<B(@;FEE(&IE<W0@9&]S=.IP;GDN`$)L
M;VL@(DUE=&%R(B!N:64@:F5S="!D;W-TZG!N>2X@4WIC>F5G\[-Y('ID87)Z
M96YI82!Z;W-T8;-Y('IA;&]G;W=A;F4@9&QA(&%D;6EN:7-T<F%T;W)A+@!-
M96MS>6L`5'EP($UI;64`3W-T871N:6$@;6]D>69I:V%C:F$`6FUI9?$@;&EN
M:P!-;[-D87=I80!297!U8FQI:V$@36^S9&%W:6D`36]N86MO`$UO;F=O;&EA
M`$-O(&UI97-IL6,`36]N='-E<G)A=`!&87IY(&MS:>J_>6-A`$UA<F]K;P!0
M<GIE<W7Q('<@9/.S`%!R>F5S=?$@=R!L97=O`%!R>F5S=?$@=R!P<F%W;P!0
M<GIE<W7Q('<@9_-RZ@!0<GIE;FEEMB!W(&3SLP!0<GIE<W7Q('<@9_-RZ@!-
M;WIA;6)I:P!+;VYT;P!-\VH@<&]R=&%L`$)I<FUA`$YA>G=I<VMO`$YA;6EB
M:6$`3F%U<G4`3F5P86P`2&]L86YD:6$`06YT>6QE($AO;&5N9&5R<VMI90!3
M:67F`$YI9V1Y`$YO=V$@2V%L961O;FEA`$YO=V$@:V%T96=O<FEA`$YO=V$@
M6F5L86YD:6$`5VEA9&]M;[9C:0!.87-TZG!N90!.87-TZG!N92!O<&-J90!.
M:6MA<F%G=6$`3FEG97(`3FEG97)I80!.:75E`$)E>B!Z;6EA;BX`0G)A:R!K
M;VYF:6=U<F%C:FD@9&QA("5S+@!.:64@=V=R86YO('!L:6MU`$YI92!P;V1A
M;F\@:&%SLV$@9&QA('5W:65R>GET96QN:65N:6$@2%144"X`3FEE('!O9&%N
M;R!H87.S82!D;&$@=7=I97)Z>71E;&YI96YI82!)34%0+@!.:64@<&]D86YO
M(&AA<[-A(&1L82!U=VEE<GIY=&5L;FEE;FEA($ME<F)E<F]S+@!.:64@<&]D
M86YO(&AA<[-A(&1L82!U=VEE<GIY=&5L;FEE;FEA($Q$05`N`$YI92!P;V1A
M;F\@:&%SLV$@9&QA('5W:65R>GET96QN:65N:6$@3$]'24XN`$YI92!P;V1A
M;F\@:&%SLV$@9&QA('5W:65R>GET96QN:65N:6$@4$%34U=$+@!.:64@<&]D
M86YO(&AA<[-A(&1L82!U=VEE<GIY=&5L;FEE;FEA(%--0BX`KV%D;F$`3F]R
M9F]L:P!.;W)W96=I80!.:64@>F%I;7!L96UE;G1O=V%N;RX`3FEE=7-T87=I
M;VYE`$YI96]B<[-U9VEW86YE`%5W86=I`%5W86=A`$QI<W1O<&%D`$QI8WIB
M82!K;VQU;6X`3&EC>F)A('=I97)S>GD`3TL`4&&\9'II97)N:6L`0FEU<F\`
M3VUA;@!4=_-J(&IE9&5N(&%D<F5S(&4M;6%I;"!J97-T(&1O>G=O;&]N>2X`
M3W1W\W)Z('<@;F]W>6T@;VMN:64`3W!C:F4`3W!C:F4@)7,`3W)G86YI>F%C
M:F$`2F5D;F]S=&MA(&]R9V%N:7IA8WEJ;F$`3W)G86YI>F%T;W(`26YN90!)
M;FYE(&EN9F]R;6%C:F4`26YN92!U<')A=VYI96YI80!5=VEE<GIY=&5L;FEE
M;FEE(%!!32!N:64@:F5S="!D;W-TZG!N92X`0WEF<F]W>2!P;V1P:7,@4$=0
M`%=I861O;6^VYB!Z87-Z>69R;W=A;F$@4$=0`$ML=6-Z('!U8FQI8WIN>2!0
M1U``5VEA9&]M;[;F('IA<WIY9G)O=V%N82]P;V1P:7-A;F$@:VQU8WIE;2!0
M1U``2V]D(%!(4`!0;W>S;VMA(%!(4`!0;W>S;VMA(%!?2%``4&%K:7-T86X`
M4&%L874`4&%N86UA`%!A<'5A+4YO=V$@1W=I;F5A`%!A<F%G=V%J`$AA<[-O
M`$AA<[-O(&YI97!R87=I9+-O=V4`2&%SLV\@>B!P;W1W:65R9'IE;FEE;0!(
M87.S;SH`2&%SLV\Z(`!(87.S;R!M=7-I('!A<V]W8>8N`%=K;&5J`%=K;&5J
M('IE('-C:&]W:V$`5WEK;VYA:B!C>6ML:6-Z;F4@;W!E<F%C:F4`5WEK;VYA
M:B!C>6ML:6-Z;F4@;W!E<F%C:F4@<&]D8WIA<R!L;V=O=V%N:6$_`%5P<F%W
M;FEE;FEE`%5P<F%W;FEE;FEA(&1L80!);F9O<FUA8VIE(&]S;V)I<W1E`%!E
M<G4`1FEL:7!I;GD`5&5L969O;@!0:71C86ER;@!.82!P97=N;R!U<W5NL>8@
M=&5N('=Y8G)A;GD@96QE;65N=#H`3F$@<&5W;F\@=7-U;K'F('=Y8G)A;GD@
M96QE;65N=#H`4')O<WKJ('!O9&'F('!O<')A=VYY(&%D<F5S($E0+@!0<F]S
M>NH@<&]D8>8@<&]P<F%W;GD@8WIA<RX`4')O<WKJ(&]P:7-AYB!P<F]B;&5M
M+@!0<F]S>NH@<&]D8>8@;F%Z=^H@=;]Y=&MO=VYI:V$@:2!H87.S;P!0;VQS
M:V$`4&]R='5G86QI80!0;V1G;+%D`$ML=6-Z('!R>7=A=&YY`%!R;V)L96T`
M3W!I<R!P<F]B;&5M=0!+;'5C>B!P=6)L:6-Z;GD`06QG;W)Y=&T@:VQU8WIA
M('!U8FQI8WIN96=O`$EN9F]R;6%C:F4@;R!K;'5C>G4@<'5B;&EC>FYY;0!0
M87)A(&ML=6-Z>2!O<V]B:7-T>6-H(&YI92!Z;W-T8;-A('=Y9V5N97)O=V%N
M82!P;VUYMFQN:64N`%!O<G1O<GEK;P!+871A<@!:87!Y=&%N:64`2VQU8WH@
M<'5B;&EC>FYY(%)302`H)60@8FET\W<I`$]DMG=I9;\@9'EN86UI8WIN92!E
M;&5M96YT>2!M96YU.@!/9+9W:66_('=I9&]K('-E<G=I<W4Z`%ID86QN92!S
M97)W97)Y`%5S=?$`57-U\2!B;&]K`%5S=?$@:V]L=6UNZ@!5<W7Q('!A<NH`
M57-U\0!5<W7Q('6_>71K;W=N:6MA`%ID86QN92!UOWET:V]W;FEK83H@)7,`
M2V%S=6H`5WEC>GFVYB!H87.S;P!7>6-Z>;;F(%1W;VIE(&AA<[-O`%=Y;FEK
M:0!0;W=R\W0@9&\@;W!C:FD`4F5U;FEO;@!2;WIB=61O=V%N>2!E9'ET;W(@
M=&5K<W1U`%-T86YO=VES:V\`4G5M=6YI80!/8G+SYB!O(#$X,"!S=&]P;FD`
M3V)R\^8@=R!L97=O`$]B<O/F('<@<')A=V\`5[-AMF-I=V^V8VD@<GKJ9'4@
M4')O<&5R=&EE<P!2;W-J80!2=6%N9&$`5VEA9&]M;[;F('IA<WIY9G)O=V%N
M82!3+TU)344`57=I97)Z>71E;&YI96YI92!305-,(&YI92!J97-T(&1O<W3J
M<&YE+@!0;W=L;VMA(%-13`!34T@`4&]WLV]K82!37U%,`*9W:>IT82!(96QE
M;F$`4V%I;G0@2VET=',@:2!.979I<P!386EN="!,=6-I80!386EN="U0:65R
M<F4@:2!-:7%U96QO;@!386EN="!6:6YC96YT(&D@1W)E;F%D>6YY`%-A;6]A
M`%-A;B!-87)I;F\`07)A8FEA(%-A=61Y:G-K80!:87!I<WH`6F%P:7-Z("(E
M<R(`6F%P:7-Z("5S`%IA<&ES>B!O<&-J90!3>G5K86H`5WEB:65R>B!P;&EK
M:0!7>6)I97)Z('IN86L@<&]D>FEALW4@9&%T>3H`5WEB:65R>B!F;W)M870@
M9&%T>3H`5WEB:65R>B!T;[]S86UOMN8@9&\@>FUI86YY.@!7>6)I97)Z('IN
M86L@<&]D>FEALW4@9&%T>3H`5WEB:65R>B!F;W)M870@8WIA<W4Z`%=Y8FEE
M<GH@9'=A('!A<W5JL6-E('!O;&$N`%=Y8FEE<GH@<V-H96UA="!K;VQO<O-W
M+@!7>6)I97)Z('1W\VH@<')E9F5R;W=A;GD@:NIZ>6LZ`%=YMFQI:B!R87!O
M<G0@;R!P<F]B;&5M:64`4V5N96=A;`!7<GIE<VEE\0!.=6UE<B!S97)Y:FYY
M`%5S=&%W`%5S=&%W('ID86QN92!S97)W97)Y+"!D;R!K=/-R>6-H(&-H8V5S
M>B!M:67F(&1O<W3J<"!Z('-E<G=I<W4N`%5S=&%W('!R969E<F]W86YY(&KJ
M>GEK+"!S=')E9NH@8WIA<V]WL2!I(&]P8VIE(&1A='DN`%5S=&%W('5SLW5G
MZB!P;V-ZL71K;W>Q+"!S8VAE;6%T(&MO;&]R\W<L(&]DMG=I9;]A;FEE('-T
M<F]N>2!I(&EN;F4@;W!C:F4@=WFV=VEE=&QA;FEA`$MO;F9I9W5R86-J80!3
M>F5S>F5L90!+<O-T:VD@;W!I<P!0;VMAOP!0;VMA>GEW8>8@8WIA<R!O<W1A
M=&YI96=O('IA;&]G;W=A;FEA('!O(&QO9V]W86YI=3\`4&]K8;\@;65N=2`E
M<R!P;R!L97=E:C\`4VEE<G)A($QE;VYE`%IA<F5J97-T<G5J('-IZBP@:F6V
M;&D@:F5S>F-Z92!T96=O(&YI92!Z<F]B:;-EM@!0;V1P:7,`06QG;W)Y=&T@
M<&]D<&ES=0!3:6YG87!U<@!7:65L:V^VY@!0;VUI\2!O<&5R86-J92!C>6ML
M:6-Z;F4`4[-O=V%C:F$`4[-O=V5N:6$`5WES<'D@4V%L;VUO;F$`4V]M86QI
M80!0;[-U9&YI;W=A($%F<GEK80!0;[-U9&YI;W=O975R;W!E:G-K:2`H25-/
M+3@X-3DM,RD`1V5O<F=I82!0;[-U9&YI;W=A`$AI<WIP86YI80!3<&%M`$5D
M>6-J82!Z;F%K\W<@<W!E8VIA;&YY8V@`4&]D>FEE;"!K;VWS<FOJ`%!O9'II
M96P@:V]L=6UNZ@!0;V1Z:65L('=I97)S>@!3<FD@3&%N:V$`5V]J97?S9+QT
M=V\@;'5B('-T86X`4W1A='5S`$%D<F5S(&1O;6]W>0!496UA=`!7>;9L:6H`
M4&]W;V1Z96YI90!59&&S;R!S:>H@9&]D8>8@(B5S(B!D;R!S>7-T96UU+@!5
M9&&S;R!S:>H@=7-U;K'F("(E<R(@>B!S>7-T96UU+@!59&&S;R!S:>H@=7-U
M;K'F("(E<R(N`%5D8;-O('-IZB!U<W5NL>8@(B5S(B!Z('-Y<W1E;74N`%5D
M8;-O('-IZB!U86MT=6%L;FGF("(E<R(`4W5D86X`5W-C:/-D+WIA8VCS9"!S
MLV_Q8V$`4W5R:6YA;0!3=6%Z:0!3>G=E8VIA`%-Z=V%J8V%R:6$`4WER:6$`
M5&%J=V%N`%1A:G=A;@!4862_>6MI<W1A;@!486YZ86YI80!:861A;FEA`$YU
M;65R('1E;&5F;VYU`%1Y;&MO('1E:W-T`%1A:FQA;F1I80!$>FGJ:W5J96UY
M('IA(&MO<GIY<W1A;FEE('H@<V5R=VES=2X`5&^_<V%M;[;F("(E<R(@>F]S
M=&&S82!U<W5N:>IT82X`4V5R=V5R("(E<R(@>F]S=&&S('5S=6YIZG1Y+@!3
M97)W97(@(B5S(B!Z;W-T8;,@>F%P:7-A;GDN`$)L;VL@=V5A=&AE<BYC;VT@
M;FEE(&IE<W0@9&]S=.IP;GDN`$YI92!M82"_861N>6-H(&1O<W3J<&YY8V@@
M;W!C:FDN`%=Y<W2Q<&FS('!R;V)L96T@<')Z>2!D;V1A=V%N:74@(B5S(B!D
M;R!S>7-T96UU.B`E<P!7>7-TL7!ILR!P<F]B;&5M('!R>GD@=7-U=V%N:74@
M9&%N>6-H(&1L82!UOWET:V]W;FEK82`B)7,B('<@<WES=&5M:64Z(`!7>7-T
ML7!ILR!P<F]B;&5M('!R>GD@=7-U=V%N:74@(B5S(B!Z('-Y<W1E;74N`%=Y
M<W2Q<&FS('!R;V)L96T@<')Z>2!U86MT=6%L;FEA;FEU("(E<R(Z("5S`%=Y
M<W2Q<&FS(&*SL60@<&]D8WIA<R!W>;9W:65T;&%N:6$@=&5J(&-ZZK9C:2!W
M:6%D;VUOMF-I`%=Y<W2Q<&FS(&*SL60@<&]C>F%S(&EM<&]R=&]W86YI82!D
M86YY8V@@:4-A;&5N9&%R+@!0;&EK(&YI92!W>6=LL61A(&YA('!O<')A=VYE
M(&%R8VAI=W5M(%)!4BX`4&QI:R!N:64@=WEG;+%D82!N82!P;W!R87=N92!A
M<F-H:7=U;2!:25`N`%1O('!O;&4@:F5S="!W>6UA9V%N92X`5&\@<&]L92!M
M=7-I(&)YYB!P;W!R87=NL2!L:6-Z8K$N`%=I861O;6^VYB!Z;W-T8;-A(&YA
M<&ES86YA('<@:6YN96H@;FF_('1W;VIA('-T<F]N:64@:V]D;W=E:B`H)7,I
M+@!496X@<V5R=V5R(&YI92!P;W1R869I(')O>G!A:V]W>7=AYB!A<F-H:7?S
M=R!Z:7`@:2!G>FEP+@!#>F%S`$9O<FUA="!C>F%S=0!4>71ULP!$;P!!8GD@
M=WEB<F'F('=I96QO:W)O=&YE('!O;&$@<')Z>71R>GEM86H@<')Z>6-I<VL@
M0W1R;"`H4$,I(&QU8B!#;VUM86YD("A-86,I('!O9&-Z87,@:VQI:V%N:6$N
M`$1Z:;8`5&]G;P!4;VME;&%U`$IU=')O`%1O;F=A`%1R>6YI9&%D(&D@5&]B
M86=O`%!R87=D82!L=6(@9F&S<WH`5'5N97IJ80!4=7)C:F$`5'5R96-K:2`H
M25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U=F%L=0!54DP`55),.@!59V%N
M9&$`56MR86EN80!"L[%D('!O9&-Z87,@>FUI86YY(&1O("5S+@!"L[%D('!O
M9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+@!"L[%D('!O9&-Z
M87,@<F]Z<&%K;W=Y=V%N:6$@9&%N>6-H+@!.:64@;6^_;F$@<')Z972S=6UA
M8WIYYB!T96=O(&1O:W5M96YT=2!7;W)D+6$`0V]F;FEJ('IM:6%N>0!::F5D
M;F]C>F]N92!%;6ER871Y($%R86)S:VEE`%=I96QK82!"<GET86YI80!54T$`
M3FEE>FYA;F4`0F5Z(&YA>G=Y`$YI96]B<[-U9VEW86YE(')O>G-Z97)Z96YI
M90!586MT=6%L;FEJ`%IALV%D=6H`57)U9W=A:@!/<&-J92!UOWET:V]W;FEK
M80!296IE<W1R86-J82!UOWET:V]W;FEK80!.87IW82!UOWET:V]W;FEK80!5
MOWET:V]W;FEK(&\@;F%Z=VEE("(E<R(@:G6_(&ES=&YI96IE+@!.87IW82!U
MOWET:V]W;FEK83H`3F%Z=V$@=;]Y=&MO=VYI:V$Z(`!5OWET:V]W;FEC>2!W
M('-Y<W1E;6EE.@!5>F)E:VES=&%N`%=A:V%C:F4`5F%N=6%T=0!796YE>G5E
M;&$`5V5R<VIA`%=I971N86T`5VED;VL@)7,`4&]K8;\@<W1R;V[J(%=75P!0
M;VMAOR!J86MO("5S`$)R>71Y:G-K:64@5WES<'D@1'II97=I8WIE`%=Y<W!Y
M($1Z:65W:6-Z92!3=&%N\W<@6FIE9&YO8WIO;GEC:`!786QL:7,@:2!&=71U
M;F$`3W-T<GIEOV5N:64`5U=7`$-O('1Y9'II9?$`5VET86UY`%=I=&%M>2!W
M("5S`%=I=&%M>2P@)7,`6F%C:&]D;FD@*$E33RTX.#4Y+3$I`%IA8VAO9&YI
M("A)4T\M.#@U.2TQ-2D`4V%H87)A(%IA8VAO9&YI80!*86NQ(&%P;&EK86-J
MZB!M82`E<R!W>;9W:65T;&'F('!O('IA;&]G;W=A;FEU('-IZC\`2F%K:64@
M=W1Y8WIK:2!A:W1Y=V]W8>8@=R!2;WIB=61O=V%N>6T@961Y=&]R>F4@=&5K
M<W1U+@!3>F5R;VMOMN8@;&5W96=O(&UE;G4@)7,@*'IM:6%N82!Z86-Z;FEE
M(&]B;W=IL7IY=V'F('!R>GD@;F%S=.IP;GEM(&QO9V]W86YI=2DZ`$%D<F5S
M(&1O('!R86-Y`%1E;"X@9&\@<')A8WD`4E(`4E)24@!#;R!R;VL`2F5M96X`
M5&%K`%1A:RP@>F=A9'IA;2!S:>H`5WEL;V=O=V&S9;8@<VGJ+@!-=7-I<WH@
M;W!I<V'F('!R;V)L96T@>F%N:6T@9V\@=WFV;&5S>BX`375S:7-Z(&]K<F6V
M;&GF('6_>71K;W=N:6MA+"!K=/-R96=O(&-H8V5S>B!U<W5NL>8N`$UU<VES
M>B!O:W)EMFQIYB!UOWET:V]W;FEK82P@:W3S<F5G;R!C:&-E<WH@9&]D8>8N
M`%1W\VH@861R97,@92UM86EL`%1W\VH@861R97,@3V0Z`%1W;VIE(&EN9F]R
M;6%C:F4`5'?S:B!A9')E<R!I;G1E<FYE=&]W>2!S:>H@>FUI96YILR!O9"!P
M;V-ZL71K=2!S97-J:2`E<RX@5R!Z=VFQ>FMU('H@8F5Z<&EE8WIE\7-T=V5M
M(%1W;VIE9V\@:V]N=&$@;75S:7-Z('IA;&]G;W=AYB!S:>H@<&]N;W=N:64N
M`%1W;VIE(&EM:>H`5&5N('-Y<W1E;2!A=71E;G1Y:V%C:FD@;FEE(&]B<[-U
M9W5J92!D;V1A=V%N:6$@=;]Y=&MO=VYI:_-W+"!L=6(@=&$@;W!C:F$@>F]S
M=&&S82!W>;.Q8WIO;F$N`%1E;B!S>7-T96T@875T96YT>6MA8VII(&YI92!O
M8G.S=6=U:F4@;&ES=&]W86YI82!UOWET:V]W;FEK\W<L(&QU8B!T82!O<&-J
M82!Z;W-T8;-A('=YL[%C>F]N82X`5'=O:F$@;V)E8VYA('-T<F5F82!C>F%S
M;W=A.@!$;VUYMFQN82!T;[]S86UOMN8Z`%1W;VIE('!ELVYE(&EM:>H@:2!N
M87IW:7-K;SH`5'=O:6T@;F]W>6T@:&%SLV5M('<@)7,@:F5S=#H@)7,`5'=O
M:F4@=7-T87=I96YI82!Z;W-T8;-Y('5A:W1U86QN:6]N92!N82!C>F%S('1R
M=V%N:6$@=&5J('-E<VII+@!4=V]J92!U<W1A=VEE;FEA('IO<W1ALWD@=6%K
M='5A;&YI;VYE+@!4=V]J92!Z9&%L;F4@<V5R=V5R>3H`2G5G;W.S87=I80!:
M86ER`%IA;6)I80!::6UB86)W90!;4F%P;W)T(&\@<')O8FQE;6EE70!?061M
M:6YI<W1R86-J80!?0TQ)`%]5<W7Q('=I97)S>@!?1W)U<'D`7U!O;6]C`%]:
M86QO9W5J`%]7>6QO9W5J`%IM:67Q(&QI;FLN+BX`7T]P8VIE`%]5<')A=VYI
M96YI80!5<W7Q(&QI;FLN+BX`7TMO;F9I9W5R86-J80!?5;]Y=&MO=VYI8WD`
M:W-IL;]K82!A9')E<V]W80!K86QE;F1A<GH`<&QI:P!.87IW:7-K;P!N;W1A
M=&YI:P!B97H@;F%Z=WD`=D-A<F0`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&]C86QE+W!T7T)2+P``````````````````````````````````
M```````````````````````````````````````````````P,#`P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U,P`P,C`Q,C,`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O<'1?0E(O:&5L<"YX;6P`
M````````````````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,S(P`#$P
M-3$U-#,S-S4S`#`R,34W,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R
M9&4Z(&AO<F1E+VQO8V%L92]P=%]"4B]H96QP+GAM;"QV(#$N,B`R,#`T+S`U
M+S(W(#(P.C(R.C$S(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED
M/2)S=6UM87)Y(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!0;W)T86P@4&%G
M93PO=&ET;&4^"B`\<&%R83X*("!4:&ES('!O<G1A;"!P86=E('!R;W9I9&5S
M(&$@<75I8VL@<W5M;6%R>2!O9B!A;&P@>6]U<B!I;7!O<G1A;G0*("!I;F9O
M<FUA=&EO;BX@1F]R(&5X86UP;&4L(&ET(&UI9VAT('-H;W<@:&]W(&UA;GD@
M;F5W(&4M;6%I;"!M97-S86=E<R!Y;W4*("!H879E(&EN('EO=7(@24Y"3U@L
M('5P8V]M:6YG(&5V96YT<R!O;B!Y;W5R(&-A;&5N9&%R+"!T87-K<R!O;B!Y
M;W5R('1O+61O"B`@;&ES="P@:&5A9&QI;F5S(&9R;VT@<V5L96-T960@;F5W
M<R!S97)V:6-E<RP@86YD('-O(&]N+B`@36%N>2!O9B!T:&5S90H@('-U;6UA
M<FEE<R!W:6QL(&-O;G1A:6X@<75I8VL@<VAO<G1C=71S('1O(&-O;6UO;B!F
M=6YC=&EO;G,L('-U8V@@87,*("!C;VUP;W-I;F<@82!N97<@;6%I;"!M97-S
M86=E+"!C<F5A=&EN9R!A(&YE=R!C86QE;F1A<B!E=F5N="!O<B!T87-K+"!E
M=&,N"B`\+W!A<F$^"B`\<&%R83X*("!4:&4@8V]N=&5N=',@;V8@=&AI<R!P
M;W)T86P@<&%G92!A<F4@8W5S=&]M:7IA8FQE('9I82!T:&4@3&%Y;W5T(&)U
M='1O;BX*("!&;W(@97AA;7!L92P@>6]U(&-A;B!C:&]O<V4@=VAI8V@@:71E
M;7,@=&\@:6YC;'5D92!O;B!T:&ES('!O<G1A;"!P86=E(&%S"B`@=V5L;"!A
M<R!I;B!W:&EC:"!O<F1E<B!T:&5Y(&%R92!S:&]W;BX*(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](FYA=F)A<B(@<W1A=&4](FYE=R(^"CQT:71L
M93Y4:&4@07!P;&EC871I;VX@3F%V:6=A=&EO;B!"87(\+W1I=&QE/@H@/'!A
M<F$^"B`@070@=&AE(&QE9G0@:&%N9"!S:61E(&]F('1H92!W96(@<&%G92!I
M<R!T:&4@87!P;&EC871I;VX@;F%V:6=A=&EO;B!B87(N"B`@0VQI8VL@;VX@
M=&AE(&EC;VYS(&]N('1H:7,@;F%V:6=A=&EO;B!B87(@=&\@<75I8VML>2!A
M;F0@96%S:6QY('-W:71C:`H@(&)E='=E96X@=&AE(&%V86EL86)L92!A<'!L
M:6-A=&EO;G,N"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F
M<RUD;U]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E
M9F5R96YC97,Z($UA:6YT96YA;F-E.B!$;R!-86EN=&5N86YC93PO=&ET;&4^
M"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O('!E<F9O<FT@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;BP@8VAE8VL@=&AI<R!B
M;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC
M;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0
M<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($-O;F9I<FT@36%I;G1E;F%N8V4\
M+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!C
M;VYF:7)M(&%L;"!M86EN=&5N86YC92!T87-K<R!B969O<F4@=&AE>2!A<F4@
M<G5N+"!C:&5C:R!T:&ES(&)O>"X@268@;&5F="!U;F-H96-K960L(&%L;"!M
M86EN=&5N86YC92!O<&5R871I;VYS('1H870@;F5E9"!T;R!B92!R=6X@=VEL
M;"!B92!P97)F;W)M960@875T;VUA=&EC86QL>2!W:71H(&YO(&-H86YC92!T
M;R!C86YC96P@;VX@;&]G:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L
M<#X*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W!T7T)2+TQ#7TU%4U-!1T53+P``
M````````````````````````````````````````````````````````````
M```P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,S<U,P`P,C$W,3``(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O<'1?
M0E(O3$-?34534T%'15,O:&]R9&4N;6\`````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P-#$U,34Q`#$P-3$U-#,S-S4S`#`R,S,U-0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#>$@25`````(8'```<````3#P`
M`!,*``!\>````````,B@```.````R:````\```#8H```#0```.B@```(````
M]J````L```#_H```#`````NA```$````&*$``!@````=H0``&P```#:A```M
M````4J$``!T```"`H0``)````)ZA```I````PZ$``!D```#MH0``)@````>B
M```,````+J(``"0````[H@``#P```&"B```+````<*(```X```!\H@``!0``
M`(NB```H````D:(```@```"ZH@``"@```,.B```5````SJ(``!(```#DH@``
M"P```/>B``"%`````Z,```X```")HP``"@```)BC```-````HZ,```X```"Q
MHP``$0```,"C```-````TJ,```P```#@HP``#0```.VC```&````^Z,``)0`
M```"I```"@```)>D```/````HJ0``!@```"RI```#````,ND```.````V*0`
M``X```#GI```"````/:D```)````_Z0``"X````)I0``&@```#BE```R````
M4Z4``#@```"&I0``5````+^E``!1````%*8``%H```!FI@``5P```,&F```T
M````&:<```D```!.IP``#0```%BG```'````9J<```H```!NIP``#P```'FG
M```%````B:<```8```"/IP``$0```):G```(````J*<```D```"QIP``"0``
M`+NG```E````Q:<``"````#KIP``$P````RH```0````(*@```\````QJ```
M"@```$&H```#````3*@```\```!0J```%````&"H```)````=:@```T```!_
MJ```$@```(VH```9````H*@``!X```"ZJ```#P```-FH```*````Z:@```\`
M``#TJ```"`````2I```D````#:D``!0````RJ0``%@```$>I```(````7JD`
M`$X```!GJ0``+0```+:I```9````Y*D```<```#^J0``#`````:J```L````
M$ZH```X```!`J@```P```$^J```+````4ZH```<```!?J@``!P```&>J```%
M````;ZH```4```!UJ@``"@```'NJ```#````AJH``!<```"*J@``"@```**J
M```/````K:H```X```"]J@``&````,RJ```C````Y:H```X````)JP``%```
M`!BK```7````+:L``!<```!%JP``%P```%VK```3````=:L```\```")JP``
M#@```)FK```?````J*L``!T```#(JP``!P```.:K```&````[JL```@```#U
MJP``#P```/ZK```&````#JP```H````5K```$P```""L```+````-*P``!``
M``!`K```%0```%&L```5````9ZP```<```!]K```$````(6L```%````EJP`
M`!4```"<K```$0```+*L```,````Q*P``#L```#1K```.`````VM```)````
M1JT```<```!0K0``%````%BM```#````;:T```4```!QK0``$````'>M```)
M````B*T``!,```"2K0``.0```*:M```2````X*T``"<```#SK0``+````!NN
M```J````2*X``"4```!SK@``"@```)FN```&````I*X```D```"KK@``!P``
M`+6N```O````O:X``#<```#MK@``+@```"6O``!5````5*\``"T```"JKP``
M+0```-BO```]````!K```#\```!$L```+0```(2P``!`````LK```",```#S
ML```(P```!>Q``!`````.[$``"T```!\L0``,P```*JQ```E````WK$``!4`
M```$L@``&0```!JR```I````-+(``"0```!>L@``*````(.R```1````K+(`
M``H```"^L@``#````,FR```*````UK(``!````#AL@``%@```/*R```6````
M";,```<````@LP``!P```"BS```4````,+,```H```!%LP``"````%"S```G
M````6;,```@```"!LP``!P```(JS```'````DK,```8```":LP``!0```*&S
M```'````I[,```8```"OLP``"````+:S```I````O[,```X```#ILP``"@``
M`/BS```$`````[0```<````(M```"0```!"T```&````&K0``!$````AM```
M!P```#.T```6````.[0```0```!2M```"````%>T```&````8+0```T```!G
MM```!@```'6T```>````?+0``!$```";M```"````*VT```-````MK0```P`
M``#$M```!P```-&T```#````V;0```,```#=M```%P```.&T```3````^;0`
M`!T````-M0``"````"NU```$````-+4```@````YM0``"````$*U``!!````
M2[4``!H```"-M0``*P```*BU```@````U+4``!4```#UM0``!@````NV```&
M````$K8``!4````9M@``&````"^V```B````2+8``"X```!KM@``'0```)JV
M```A````N+8``%0```#:M@``*0```"^W```*````6;<```<```!DMP``!P``
M`&RW```5````=+<```X```"*MP``"@```)FW```/````I+<```T```"TMP``
M#P```,*W```-````TK<```D```#@MP``%````.JW```&````_[<``!@````&
MN```'0```!^X```3````/;@``!$```!1N```%````&.X```$````>+@```8`
M``!]N```%````(2X``!4````F;@``&0```#NN```!````%.Y```.````6+D`
M``4```!GN0``!0```&VY```;````<[D``!H```"/N0``$P```*JY```1````
MOKD``!$```#0N0``'````.*Y```J````_[D``!`````JN@``(0```#NZ```%
M````7;H``!,```!CN@``"P```'>Z```2````@[H```H```"6N@``#P```*&Z
M```-````L;H``!$```"_N@``$P```-&Z```,````Y;H```8```#RN@``#```
M`/FZ```&````!KL``!<````-NP``$````"6[```1````-KL```@```!(NP``
M!0```%&[```,````5[L``!````!DNP``!0```'6[```-````>[L```8```")
MNP``!P```)"[```-````F+L```<```"FNP``"P```*Z[```'````NKL```<`
M``#"NP``"0```,J[```)````U+L```H```#>NP``&0```.F[```]`````[P`
M`!T```!!O```#````%^\```0````;+P```4```!]O```)0```(.\```2````
MJ;P``!,```"\O```*P```-"\```[````_+P``"`````XO0``"````%F]```V
M````8KT``"$```"9O0``$````+N]```(````S+T```P```#5O0``!@```.*]
M```$````Z;T```\```#NO0``#@```/Z]```'````#;X```H````5O@``#0``
M`""^```?````+KX``!P```!.O@``(0```&N^```>````C;X``!D```"LO@``
M'@```,:^```;````Y;X``"$````!OP``+@```"._```F````4K\``!P```!Y
MOP``'@```):_```<````M;\``"8```#2OP``*P```/F_```S````)<```"8`
M``!9P```*P```(#````X````K,```!T```#EP```%0````/!```O````&<$`
M`"````!)P0``$@```&K!```I````?<$``!X```"GP0``(````,;!```2````
MY\$``*(```#ZP0``%@```)W"```C````M,(``"@```#8P@``*0````'#```H
M````*\,``!\```!4PP``%0```'3#```@````BL,``"4```"KPP``*````-'#
M```M````^L,``#`````HQ```D@```%G$```A````[,0``!8````.Q0``'```
M`"7%```F````0L4``"H```!IQ0``00```)3%``!$````UL4```P````;Q@``
M!P```"C&```'````,,8```8````XQ@``#0```#_&```0````3<8``!(```!>
MQ@``$P```''&```2````A<8```<```"8Q@``!````*#&```0````I<8``!``
M``"VQ@``#````,?&```.````U,8```T```#CQ@``#P```/'&```3`````<<`
M``T````5QP``*````"/'```#````3,<```T```!0QP``!@```%['```1````
M9<<``!<```!WQP``&P```(_'```.````J\<```(```"ZQP``20```+W'```%
M````!\@``!`````-R```#P```![(```$````+L@```T````SR```#@```$'(
M```#````4,@```X```!4R```"````&/(```/````;,@```\```!\R```!P``
M`(S(```-````E,@``!````"BR```#0```+/(```+````P<@```8```#-R```
M"P```-3(```,````X,@```H```#MR```$0```/C(```9````"LD```L````D
MR0``#0```##)```B````/LD``!L```!AR0``-````'W)```*````LLD``!@`
M``"]R0``&0```-;)```6````\,D``"(````'R@``#0```"K*```'````.,H`
M`!0```!`R@``"P```%7*```B````8<H``"\```"$R@``"P```+3*```)````
MP,H``!D```#*R@``"P```.3*```7````\,H``!<````(RP``"0```"#+```6
M````*LL```\```!!RP``&0```%'+```6````:\L```X```""RP``&````)'+
M```(````JLL```T```"SRP``)@```,'+``!#````Z,L```@````LS```$@``
M`#7,```?````2,P```@```!HS```"P```'',```O````?<P```X```"MS```
M!0```+S,```&````PLP``$4```#)S````P````_-```'````$\T```0````;
MS0``"@```"#-```*````*\T```\````VS0``$````$;-```7````5\T``!$`
M``!OS0``&0```('-```7````F\T```D```"SS0``!0```+W-```+````P\T`
M``H```#/S0```@```-K-```%````W<T```T```#CS0``&P```/'-```7````
M#<X``!0````ES@``"0```#K.```.````1,X```T```!3S@``$@```&'.```X
M````=,X``"````"MS@``"````,[.```.````U\X``'L```#FS@``&````&+/
M```8````>\\``!$```"4SP``!P```*;/```%````KL\``!@```"TSP``'@``
M`,W/```;````[,\``!D````(T```&P```"+0```9````/M```!,```!8T```
M!P```&S0```(````=-````8```!]T```!@```(30```0````B]````\```"<
MT```$````*S0```/````O=````L```#-T```#P```-G0```,````Z=````\`
M``#VT```!P````;1```&````#M$```X````5T0``#````"31```H````,=$`
M``\```!:T0``"````&K1```(````<]$``!,```!\T0``'@```)#1```A````
MK]$``"````#1T0``&0```/+1```7````#-(``"4````DT@``%P```$K2```6
M````8M(```0```!YT@``&P```'[2```-````FM(```P```"HT@```P```+72
M```%````N=(```@```"_T@``"@```,C2```,````T](```L```#@T@``$```
M`.S2```,````_=(```X````*TP``"P```!G3```$````)=,```0````JTP``
M$P```"_3```4````0],```P```!8TP``"0```&73```.````;],```L```!^
MTP``&P```(K3```'````IM,```<```"NTP``"@```+;3```-````P=,```D`
M``#/TP``!````-G3```%````WM,```,```#DTP``&````.C3```*`````=0`
M``0````,U```)@```!'4```.````.-0``'P```!'U```%0```,34```%````
MVM0```<```#@U```#````.C4```(````]=0```H```#^U```!@````G5```(
M````$-4```(````9U0``!@```!S5```&````(]4``!0````JU0``#0```#_5
M```0````3=4``!L```!>U0``!````'K5```)````?]4``!````")U0``"0``
M`)K5```)````I-4```4```"NU0``&@```+35```(````S]4```8```#8U0``
M&0```-_5```.````^=4```<````(U@``!P```!#6```%````&-8```D````>
MU@``"@```"C6```.````,]8```(```!"U@``!@```$76```+````3-8```T`
M``!8U@``"0```&;6```&````<-8``!(```!WU@``"0```(K6```'````E-8`
M`!0```"<U@``'0```+'6``!"````S]8``"4````2UP``)0```#C7```&````
M7M<```H```!EUP``!````'#7```)````==<```@```!_UP``$0```(C7```)
M````FM<```8```"DUP``#0```*O7```&````N=<```0```#`UP``.0```,77
M```]````_]<``#H````]V```'@```'C8```%````E]@```X```"=V```!```
M`*S8```&````L=@```<```"XV```(0```,#8```-````XM@``!4```#PV```
M!@````;9```$````#=D``!$````2V0``!@```"39```*````*]D``"(````V
MV0``!````%G9```%````7MD``!T```!DV0``!````(+9```,````A]D```X`
M``"4V0``"@```*/9```(````KMD```D```"WV0``!0```,'9```Z````Q]D`
M`#`````"V@``-0```#/:```I````:=H``$<```"3V@``.````-O:```I````
M%-L``#\````^VP``+@```'[;```M````K=L``!\```#;VP``#P```/O;```2
M````"]P```L````>W```)@```"K<```I````4=P``"0```![W```)@```*#<
M```(````Q]P```H```#0W```"0```-O<```'````Y=P``"````#MW```(```
M``[=```F````+]T```H```!6W0``&0```&'=```I````>]T``!8```"EW0``
M$@```+S=```'````S]T```H```#7W0``#````.+=```/````[]T``!````#_
MW0``0````!#>``!P````4=X``&8```#"W@``#@```"G?```)````.-\```H`
M``!"WP``$@```$W?```3````8-\```P```!TWP``!@```('?```/````B-\`
M`!(```"8WP``$````*O?```1````O-\``!P```#.WP``(P```.O?``!J````
M#^````\```!ZX```!0```(K@```0````D.````D```"AX```!````*O@```+
M````L.```"````"\X```%````-W@```,````\N````P```#_X```#P````SA
M```5````'.$``"D````RX0``*@```%SA```F````A^$``"<```"NX0``*0``
M`-;A```J`````.(``!D````KX@``0@```$7B```1````B.(``!(```":X@``
M$P```*WB```4````P>(```\```#6X@``%@```.;B```7````_>(``!`````5
MXP``$0```";C```T````..,``!,```!MXP``$@```('C```U````E.,``!0`
M``#*XP``!P```-_C```,````Y^,``"````#TXP``$````!7D```4````)N0`
M`!$````[Y```%P```$WD```<````9>0``!,```""Y```%````);D```:````
MJ^0``!$```#&Y```&@```-CD```>````\^0``!H````2Y0``$P```"WE```5
M````0>4``!$```!7Y0``%P```&GE```4````@>4``!<```"6Y0``%0```*[E
M```)````Q.4``!````#.Y0``&0```-_E```$````^>4```<```#^Y0``"P``
M``;F```1````$N8```8````DY@``!@```"OF```&````,N8```4````YY@``
M!P```#_F```'````1^8```4```!/Y@``%@```%7F```&````;.8```8```!S
MY@``!````'KF```$````?^8```<```"$Y@``#@```(SF```,````F^8```P`
M``"HY@``#0```+7F```*````P^8```X```#.Y@``!0```-WF```H````X^8`
M``X````,YP``#````!OG```/````*.<```H````XYP``"````$/G```)````
M3.<``"L```!6YP``!````(+G```(````A^<``"8```"0YP``$@```+?G```/
M````RN<```8```#:YP``"@```.'G```'````[.<```@```#TYP``(````/WG
M```)````'N@``!0````HZ```#````#WH```-````2N@```X```!8Z```%@``
M`&?H```1````?N@```8```"0Z````P```)?H```&````F^@``!D```"BZ```
M!P```+SH```$````Q.@```L```#)Z```"P```-7H```'````X>@```4```#I
MZ```!P```._H```6````]^@```T````.Z0``#0```!SI```*````*ND``!``
M```UZ0``#P```$;I```1````5ND``!<```!HZ0``"@```(#I```1````B^D`
M``@```"=Z0``!````*;I```/````J^D``#H```"[Z0``!0```/;I```,````
M_.D``!X````)Z@``#@```"CJ```0````-^H```L```!(Z@``#````%3J```)
M````8>H```<```!KZ@``"@```'/J```)````?NH```X```"(Z@``$````)?J
M```;````J.H``!@```#$Z@``&@```-WJ```*````^.H```D````#ZP``"@``
M``WK```,````&.L```\````EZP``"````#7K```&````/NL``!P```!%ZP``
M!P```&+K```%````:NL```L```!PZP``1P```'SK```-````Q.L```D```#2
MZP``!````-SK```#````X>L``!,```#EZP``$P```/GK```3````#>P```H`
M```A[````@```"SL```$````+^P``"4````T[````P```%KL```%````7NP`
M`"H```!D[```"@```(_L```%````FNP```0```"@[```"@```*7L```-````
ML.P```8```"^[```"````,7L```(````SNP```0```#7[```!0```-SL``!H
M````XNP```D```!+[0``#````%7M```0````8NT```4```!S[0``!@```'GM
M```;````@.T``"\```"<[0``$````,SM```*````W>T```\```#H[0``"@``
M`/CM```)`````^X``!,````-[@``&P```"'N```8````/>X``!<```!6[@``
M'P```&[N```.````CNX```,```"=[@``!P```*'N```(````J>X```<```"R
M[@``"@```+KN```+````Q>X```<```#1[@``40```-GN```0````*^\```P`
M```\[P``#0```$GO```:````5^\``$H```!R[P``&0```+WO```&````U^\`
M`!H```#>[P``)0```/GO```&````'_````8````F\```'P```"WP```&````
M3?````D```!4\```&````%[P```7````=_```"@```"/\```!@```+CP```-
M````O_```"(```#-\```5P```/#P```3````2/$``",```!<\0``$P```(#Q
M```"````E/$```L```"7\0``"````*/Q```-````K/$```H```"Z\0``!P``
M`,7Q```4````S?$```8```#B\0``"````.GQ```.````\O$```<````!\@``
M"@````GR```+````%/(``#(````@\@``!P```%/R```,````6_(```T```!H
M\@``#````';R```)````@_(```D```"-\@``"@```)?R```'````HO(```D`
M``"J\@``!P```+3R```*````O/(``!L```#'\@``#P```./R```2````\_(`
M``H````&\P``%@```!'S```)````*/,``!`````R\P``!P```$/S```2````
M2_,```0```!>\P``!P```&/S```%````:_,```4```!Q\P``"P```'?S```4
M````@_,``!$```"8\P``&@```*KS```6````Q?,``!0```#<\P``%P```/'S
M```8````"?0``!P````B]```&0```#_T```'````6?0```4```!A]```#0``
M`&?T```,````=?0``!$```""]```"````)3T```7````G?0```L```"U]```
M#````,'T```?````SO0``!H```#N]```$P````GU```$````'?4```H````B
M]0``!````"WU```-````,O4```P```!`]0``!0```$WU```)````4_4```4`
M``!=]0``!P```&/U```%````:_4```0```!Q]0```@```';U```X````>?4`
M`"P```"R]0``$@```-_U```I````\O4``#(````<]@``"@```$_V```L````
M6O8``"X```"']@``,P```+;V```S````ZO8``#@````>]P``#P```%?W```8
M````9_<``!````"`]P``#P```)'W```3````H?<``!4```"U]P``%````,OW
M```2````X/<``!0```#S]P``%0````CX```M````'O@``"T```!,^```,0``
M`'KX```N````K/@``"\```#;^```+`````OY``!B````./D``!,```";^0``
M#0```*_Y```(````O?D``!<```#&^0``"````-[Y```,````Y_D``"L```#T
M^0``(0```"#Z```:````0OH```D```!=^@``10```&?Z``!!````K?H```0`
M``#O^@``$P```/3Z```4````"/L```X````=^P``$P```"S[```8````0/L`
M``8```!9^P``"0```&#[```*````:OL```\```!U^P``$````(7[```'````
MEOL```X```">^P``!0```*W[```;````L_L```@```#/^P``!@```-C[```4
M````W_L``!$```#T^P``#@````;\```X````%?P```(```!._```!@```%'\
M```.````6/P```4```!G_```!P```&W\```.````=?P```8```"$_```*```
M`(O\```,````M/P``!P```#!_```!````-[\```I````X_P``!<````-_0``
M'P```"7]``!<````1?T``!0```"B_0``/@```+?]```?````]OT``!`````6
M_@``!P```"?^```.````+_X```P````^_@``#````$O^```3````6/X```H`
M``!L_@``'0```'?^```9````E?X```4```"O_@``$0```+7^```1````Q_X`
M`"0```#9_@``$@```/[^```5````$?\``!(````G_P``#@```#K_```9````
M2?\```@```!C_P``"0```&S_```-````=O\```<```"$_P``"@```(S_```'
M````E_\```\```"?_P``!@```*__```+````MO\``!H```#"_P``"@```-W_
M```'````Z/\```@```#P_P``!0```/G_```?````__\```8````?``$`$```
M`"8``0`(````-P`!``T```!```$`"````$X``0`>````5P`!`!(```!V``$`
M+````(D``0`:````M@`!``D```#1``$`"@```-L``0`5````Y@`!``4```#\
M``$`%`````(!`0`$````%P$!`!`````<`0$`!@```"T!`0`'````-`$!`!X`
M```\`0$`*````%L!`0`*````A`$!`!P```"/`0$`$0```*P!`0`+````O@$!
M`!H```#*`0$`%````.4!`0`$````^@$!``0```#_`0$`"P````0"`0`%````
M$`(!``8````6`@$`"````!T"`0`&````)@(!``H````M`@$`&P```#@"`0`T
M````5`(!`#0```")`@$`(````+X"`0`I````WP(!`"`````)`P$`00```"H#
M`0`:````;`,!`"@```"'`P$`*0```+`#`0!0````V@,!`"(````K!`$`!@``
M`$X$`0`(````500!``4```!>!`$`"````&0$`0`9````;00!`!D```"'!`$`
M*@```*$$`0`C````S`0!`!D```#P!`$`+@````H%`0`T````.04!``@```!N
M!0$`%P```'<%`0`*````CP4!``<```":!0$`(0```*(%`0`0````Q`4!``X`
M``#5!0$`"P```.0%`0`'````\`4!`!,```#X!0$`"`````P&`0`+````%08!
M``H````A!@$`%````"P&`0`/````008!`#(```!1!@$`"P```(0&`0`%````
MD`8!``4```"6!@$`!0```)P&`0`7````H@8!``\```"Z!@$`!````,H&`0`*
M````SP8!``D```#:!@$`"P```.0&`0`-````\`8!``P```#^!@$`#@````L'
M`0`%````&@<!``0````@!P$`#0```"4'`0`R````,P<!`$4```!F!P$`%P``
M`*P'`0`'````Q`<!`!X```#,!P$`%````.L'`0`%``````@!`!0````&"`$`
M!@```!L(`0`'````(@@!``X````J"`$`*@```#D(`0`&````9`@!``P```!K
M"`$`#0```'@(`0`1````A@@!``L```"8"`$`-@```*0(`0`*````VP@!`"(`
M``#F"`$`"P````D)`0`/````%0D!`#(````E"0$`)0```%@)`0`P````?@D!
M`#$```"O"0$`+0```.$)`0`.````#PH!``4````>"@$`#@```"0*`0`3````
M,PH!`!(```!'"@$`!P```%H*`0`1````8@H!`!,```!T"@$`!P```(@*`0`4
M````D`H!`!@```"E"@$`!P```+X*`0`%````Q@H!``P```#,"@$`#````-D*
M`0`2````Y@H!``0```#Y"@$`!P```/X*`0`*````!@L!``L````1"P$`#```
M`!T+`0`.````*@L!``X````Y"P$`!0```$@+`0`%````3@L!`"X```!4"P$`
M)@```(,+`0`C````J@L!``,```#."P$`$@```-(+`0`&````Y0L!`!X```#L
M"P$`&`````L,`0`E````)`P!``T```!*#`$`"0```%@,`0`?````8@P!``,`
M``""#`$`!P```(8,`0`*````C@P!``(```"9#`$`#````)P,`0`5````J0P!
M``L```"_#`$`&0```,L,`0`@````Y0P!`!(````&#0$`!0```!D-`0`*````
M'PT!`!4````J#0$`$@```$`-`0`,````4PT!``0```!@#0$`"0```&4-`0`'
M````;PT!``P```!W#0$`4@```(0-`0`7````UPT!`"0```#O#0$`$@```!0.
M`0`'````)PX!``8````O#@$`#@```#8.`0`,````10X!``T```!2#@$`%0``
M`&`.`0`2````=@X!``\```")#@$`%````)D.`0`*````K@X!`!L```"Y#@$`
M$````-4.`0`+````Y@X!`&D```#R#@$`&@```%P/`0`7````=P\!`"<```"/
M#P$`&@```+</`0`7````T@\!`!L```#J#P$`&0````80`0`?````(!`!`!,`
M``!`$`$`"````%00`0`'````71`!``@```!E$`$`"0```&X0`0`5````>!`!
M``T```".$`$`(P```)P0`0`-````P!`!`!,```#.$`$`"````.(0`0`#````
MZQ`!`$8```#O$`$`/P```#81`0`W````=A$!`%<```"N$0$`!0````82`0`?
M````#!(!`"\````L$@$`"@```%P2`0`(````9Q(!``T```!P$@$`+0```'X2
M`0`$````K!(!`$\```"Q$@$`)0````$3`0`<````)Q,!``L```!$$P$`'P``
M`%`3`0`=````<!,!`"4```".$P$`(````+03`0`D````U1,!`"````#Z$P$`
M"P```!L4`0`'````)Q0!``T````O%`$`#````#T4`0`7````2A0!``8```!B
M%`$`.0```&D4`0`,````HQ0!``<```"P%`$`"0```+@4`0`3````PA0!``D`
M``#6%`$`!````.`4`0`0````Y10!``@```#V%`$`"````/\4`0`$````"!4!
M``L````-%0$`#````!D5`0`2````)A4!`!$````Y%0$`#````$L5`0`:````
M6!4!``\```!S%0$`!P```(,5`0`-````BQ4!`!0```"9%0$`#@```*X5`0`,
M````O14!`!L```#*%0$`+````.85`0`3````$Q8!`!P````G%@$`*````$06
M`0`&````;18!``<```!T%@$`$P```'P6`0`%````D!8!``0```"6%@$`%P``
M`)L6`0`*````LQ8!``P```"^%@$`"0```,L6`0`&````U18!``D```#<%@$`
M"````.86`0`)````[Q8!``H```#Y%@$`$0````07`0`&````%A<!``X````=
M%P$`#@```"P7`0`-````.Q<!``L```!)%P$`'0```%47`0`+````<Q<!``(`
M``!_%P$`'````((7`0`'````GQ<!``8```"G%P$`9````*X7`0`)````$Q@!
M``<````=&`$`)@```"48`0`X````3!@!`!H```"%&`$`*@```*`8`0`[````
MRQ@!`"@````'&0$`-````#`9`0`9````91D!`!4```!_&0$`!0```)49`0`'
M````FQD!``@```"C&0$`!P```*P9`0`%````M!D!``<```"Z&0$`#@```,(9
M`0`)````T1D!``8```#;&0$`"````.(9`0`+````ZQD!``<```#W&0$`"```
M`/\9`0`'````"!H!`!8````0&@$`"0```"<:`0`&````,1H!``L````X&@$`
M$````$0:`0`&````51H!`!P```!<&@$`%````'D:`0`'````CAH!`!$```"6
M&@$`"````*@:`0`.````L1H!``@```#`&@$`!0```,D:`0`0````SQH!``D`
M``#@&@$`$````.H:`0`&````^QH!`!D````"&P$`"@```!P;`0`<````)QL!
M``<```!$&P$`!0```$P;`0`0````4AL!`!0```!C&P$`"P```'@;`0`-````
MA!L!`"@```"2&P$`&````+L;`0`7````U!L!``0```#L&P$`"0```/$;`0`*
M````^QL!``<````&'`$``@````X<`0`.````$1P!``@````@'`$`(P```"D<
M`0`?````31P!`#@```!M'`$`)@```*8<`0`Q````S1P!`"<```#_'`$`9```
M`"<=`0`4````C!T!`%4```"A'0$`.````/<=`0!*````,!X!`%L```!['@$`
M*````-<>`0`X`````!\!`"@````Y'P$`+````&(?`0`F````CQ\!`!L```"V
M'P$`/@```-(?`0"I`0``$2`!`",```"[(0$`%P```-\A`0!(````]R$!`(4`
M``!`(@$`,````,8B`0`E````]R(!`$$````=(P$`6P```%\C`0!)````NR,!
M`#$````%)`$`'0```#<D`0`8````520!`"L```!N)`$`(0```)HD`0`?````
MO"0!`"L```#<)`$`)@````@E`0`G````+R4!`#H```!7)0$`'0```)(E`0`1
M````L"4!`#,```#")0$`)0```/8E`0`G````'"8!`"````!$)@$`'P```&4F
M`0`P````A28!`&D```"V)@$`,0```"`G`0!!````4B<!`#,```"4)P$`)0``
M`,@G`0`]````[B<!`&4````L*`$`30```)(H`0`O````X"@!`"X````0*0$`
M,````#\I`0!4````<"D!`%H```#%*0$`2````"`J`0!*````:2H!`#(```"T
M*@$`+P```.<J`0`L````%RL!`"T```!$*P$`<0```'(K`0!F````Y"L!`&\`
M``!++`$`LP```+LL`0`7````;RT!`"4```"'+0$`,@```*TM`0`I````X"T!
M`#X````*+@$`(@```$DN`0!2````;"X!`"4```"_+@$`"P```.4N`0"Q````
M\2X!`$4```"C+P$`(0```.DO`0`P````"S`!`"4````\,`$`'````&(P`0`Q
M````?S`!``<```"Q,`$`!P```+DP`0`$````P3`!``T```#&,`$`"P```-0P
M`0`.````X#`!``L```#O,`$`!0```/LP`0`0`````3$!``(````2,0$`60``
M`!4Q`0`%````;S$!`!(```!U,0$`!````(@Q`0`'````C3$!``@```"5,0$`
M!0```)XQ`0`#````I#$!`!````"H,0$`#````+DQ`0`3````QC$!``T```#:
M,0$``@```.@Q`0`'````ZS$!``8```#S,0$`%````/HQ`0`,````#S(!`!@`
M```<,@$`!@```#4R`0`2````/#(!``P```!/,@$``P```%PR`0`J````8#(!
M``0```"+,@$`!@```)`R`0`'````ES(!`!\```"?,@$`-0```+\R`0`N````
M]3(!`"\````D,P$`%P```%0S`0`B````;#,!`"4```"/,P$`(````+4S`0`;
M````UC,!`!@```#R,P$`)`````LT`0`?````,#0!`!H```!0-`$`(0```&LT
M`0`@````C30!`!H```"N-`$`,@```,DT`0`:````_#0!`"\````7-0$`*P``
M`$<U`0`?````<S4!`",```"3-0$`'P```+<U`0`:````US4!`"$```#R-0$`
M)0```!0V`0`F````.C8!`"4```!A-@$`)````(<V`0`8````K#8!`!T```#%
M-@$`)````.,V`0`8````"#<!`"(````A-P$`+````$0W`0`O````<3<!`!4`
M``"A-P$`)0```+<W`0`\````W3<!`!\````:.`$`(P```#HX`0`?````7C@!
M`"````!^.`$`&@```)\X`0`8````NC@!`"8```#3.`$`'@```/HX`0`I````
M&3D!`!X```!#.0$`,0```&(Y`0`)````E#D!``P```">.0$`%P```*LY`0`O
M````PSD!`"0```#S.0$`!P```!@Z`0`/````(#H!`!0````P.@$`#@```$4Z
M`0`-````5#H!`"0```!B.@$`!0```(<Z`0`'````C3H!`"(```"5.@$`)0``
M`+@Z`0`:````WCH!`!T```#Y.@$`&@```!<[`0`'````,CL!`,<````Z.P$`
M"P````(\`0`5````#CP!``8````D/`$`"0```"L\`0`+````-3P!``T```!!
M/`$`%P```$\\`0`&````9SP!`#,```!N/`$`$P```*(\`0`3````MCP!``<`
M``#*/`$`#P```-(\`0`'````XCP!`#(```#J/`$`!````!T]`0`A````(CT!
M`!,```!$/0$`#````%@]`0`1````93T!`#(```!W/0$`%@```*H]`0`(````
MP3T!`!T```#*/0$`"0```.@]`0`*````\CT!`!0```#]/0$`"@```!(^`0`=
M````'3X!``@````[/@$`'P```$0^`0`(````9#X!`!H```!M/@$`)P```(@^
M`0`&````L#X!`!4```"W/@$`!P```,T^`0`(````U3X!``D```#>/@$`/P``
M`.@^`0`'````*#\!``\````P/P$`#@```$`_`0`0````3S\!``D```!@/P$`
M"0```&H_`0`(````=#\!`!,```!]/P$`!P```)$_`0`9````F3\!``H```"S
M/P$`%P```+X_`0`4````UC\!``H```#K/P$`#````/8_`0`7`````T`!``0`
M```;0`$`*@```"!``0`,````2T`!`!$```!80`$`!P```&I``0`"````<D`!
M`!````!U0`$`&````(9``0`+````GT`!``,```"K0`$`"````*]``0`&````
MN$`!``<```"_0`$`#0```,=``0`+````U4`!`!0```#A0`$`%0```/9``0`.
M````#$$!`"\````;00$`(````$M!`0`<````;$$!`!4```")00$`#````)]!
M`0`Q````K$$!``4```#>00$`$@```.1!`0`_````]T$!`!(````W0@$`"@``
M`$I"`0`&````54(!``0```!<0@$`!````&%"`0`*````9D(!`!,```!Q0@$`
M!0```(5"`0`&````BT(!``8```"20@$`"````)E"`0`$````HD(!``P```"G
M0@$`"@```+1"`0`Y````OT(!`"X```#Y0@$`*0```"A#`0`%````4D,!`!@`
M``!80P$`&0```'%#`0`?````BT,!`!T```"K0P$`$0```,E#`0`"````VT,!
M``0```#>0P$`"@```.-#`0`&````[D,!``4```#U0P$``P```/M#`0`,````
M_T,!`$4````,1`$`,@```%)$`0`:````A40!`#0```"@1`$`*````-5$`0!3
M````_D0!`!D```!210$`<@```&Q%`0`@````WT4!`#4`````1@$`(0```#9&
M`0!%````6$8!`#````">1@$`*````,]&`0`I````^$8!`"8````B1P$`)0``
M`$E'`0`H````;T<!`"@```"81P$`(@```,%'`0`K````Y$<!`#`````02`$`
M$@```$%(`0`3````5$@!`!````!H2`$`>0```'E(`0`)````\T@!`*$```#]
M2`$`<P```)])`0!\````$TH!`"L```"02@$`5````+Q*`0`7````$4L!`"<`
M```I2P$`%@```%%+`0`/````:$L!`!<```!X2P$`'P```)!+`0!`````L$L!
M`!\```#Q2P$`'````!%,`0!1````+DP!`!H```"`3`$`%````)M,`0`*````
ML$P!``4```"[3`$`!@```,%,`0`(````R$P!``4```#13`$`$@```-=,`0`0
M````ZDP!`!,```#[3`$`'0````]-`0`/````+4T!``\````]30$`!````$U-
M`0`)````4DT!``L```!<30$`!P```&A-`0`%````<$T!`!0```!V30$`!P``
M`(M-`0`(````DTT!``\```"<30$`"````*Q-`0`,````M4T!``\```#"30$`
M!@```-)-`0`4````V4T!``8```#N30$`#````/5-`0`1`````DX!``@````4
M3@$`!````!U.`0`9````(DX!`!$````\3@$`"@```$Y.`0`8````64X!`!,`
M``!R3@$`'````(9.`0`1````HTX!``0```"U3@$`#P```+I.`0`'````RDX!
M``0```#23@$`&0```-=.`0`'````\4X!``(```#Y3@$``@```/Q.`0`1````
M_TX!``D````13P$`!@```!M/`0`2````(D\!`!<````U3P$`!@```$U/`0`G
M````5$\!``(```!\3P$`!````']/`0`/````A$\!`!,```"43P$`!P```*A/
M`0`'````L$\!`!$```"X3P$`!@```,I/`0`8````T4\!``8```#J3P$`$P``
M`/%/`0`0````!5`!`!(````64`$``@```"E0`0`&````+%`!``P````S4`$`
M"0```$!0`0`1````2E`!`"(```!<4`$`!P```']0`0`'````AU`!``L```"/
M4`$`!0```)M0`0`"````H5`!``L```"D4`$`I0$``+!0`0`0````5E(!`!4`
M``!G4@$`#0```'U2`0`'````BU(!``D```"34@$`"````)U2`0`#````IE(!
M`!@```"J4@$`'@```,-2`0`O````XE(!`"L````24P$`*0```#Y3`0`M````
M:%,!`!D```"64P$`*@```+!3`0`*````VU,!`!X```#F4P$`$@````54`0`*
M````&%0!`!<````C5`$`!0```#M4`0`H````050!`!(```!J5`$`#@```'U4
M`0`3````C%0!``T```"@5`$`"@```*Y4`0"2````N50!`!````!,50$`"@``
M`%U5`0`2````:%4!``T```![50$`&P```(E5`0`,````I54!``\```"R50$`
M%@```,)5`0`&````V54!`)D```#@50$`"````'I6`0`-````@U8!`!@```"1
M5@$`#P```*I6`0`0````NE8!`!````#+5@$`"````-Q6`0`0````Y58!`#P`
M``#V5@$`%0```#-7`0!#````25<!`$D```"-5P$`50```-=7`0!-````+5@!
M`'(```![6`$`:@```.Y8`0!&````65D!`!````"@60$`%@```+%9`0`.````
MR%D!`!````#760$`$@```.A9`0`%````^UD!``8````!6@$`$0````A:`0`(
M````&EH!``D````C6@$`"0```"U:`0`E````-UH!`",```!=6@$`$````(%:
M`0`.````DEH!`!$```"A6@$`!@```+-:`0`)````NEH!`!L```#$6@$`(0``
M`.!:`0`.`````EL!`!0````16P$`&````"9;`0`E````/UL!`"H```!E6P$`
M&@```)!;`0`0````JUL!`!<```"\6P$`#0```-1;`0`U````XEL!`",````8
M7`$`)@```#Q<`0`1````8UP!`%@```!U7`$`-@```,Y<`0`E````!5T!``@`
M```K70$`%0```#1=`0`W````2ET!``T```""70$`"````)!=`0`+````F5T!
M``<```"E70$`!P```*U=`0`'````M5T!``<```"]70$`#````,5=`0`%````
MTET!`!L```#870$`#````/1=`0`0`````5X!`!(````27@$`'````"5>`0`O
M````0EX!``D```!R7@$`%@```'Q>`0`6````DUX!`!@```"J7@$`'@```,->
M`0`4````XEX!`!(```#W7@$`#P````I?`0`A````&E\!`!T````\7P$`!P``
M`%I?`0`&````8E\!``@```!I7P$`#0```')?`0`(````@%\!``D```")7P$`
M$@```)-?`0`)````IE\!`!,```"P7P$`&````,1?`0`J````W5\!``<````(
M8`$`$@```!!@`0`%````(V`!`!8````I8`$`$@```$!@`0`/````4V`!`$(`
M``!C8`$`.@```*9@`0`)````X6`!``<```#K8`$`$P```/-@`0`$````!V$!
M``4````,80$`#0```!)A`0`*````(&$!`!<````K80$`0P```$-A`0`5````
MAV$!`"0```"=80$`*P```,)A`0`J````[F$!`#`````98@$`"0```$IB`0`&
M````5&(!``D```!;8@$`!P```&5B`0`[````;6(!`#T```"I8@$`.@```.=B
M`0!?````(F,!`#D```""8P$`.0```+QC`0!%````]F,!`$4````\9`$`.0``
M`()D`0!2````O&0!`"H````/90$`+````#IE`0!)````9V4!`#D```"Q90$`
M/P```.ME`0`E````*V8!`!4```!19@$`&0```&=F`0`L````@68!`"8```"N
M9@$`)@```-5F`0`3````_&8!``H````09P$`$0```!MG`0`%````+6<!``P`
M```S9P$`&0```$!G`0`;````6F<!``<```!V9P$`!P```'YG`0`5````AF<!
M``H```"<9P$`"````*=G`0`T````L&<!`!````#E9P$`"@```/9G`0`'````
M`6@!``8````):`$`!0```!!H`0`(````%F@!``4````?:`$`"P```"5H`0`R
M````,6@!`!8```!D:`$`#0```'MH`0`'````B6@!``<```"1:`$`"0```)EH
M`0`%````HV@!`!$```"I:`$`!@```+MH`0`4````PF@!``4```#7:`$`"```
M`-UH`0`&````YF@!``L```#M:`$`!@```/EH`0`B`````&D!``8````C:0$`
M"````"II`0`4````,VD!``P```!(:0$`!P```%5I`0`#````76D!``,```!A
M:0$`&@```&5I`0`:````@&D!`"T```";:0$`!@```,EI`0`%````T&D!``@`
M``#6:0$`"````-]I`0!:````Z&D!`"$```!#:@$`/````&5J`0`L````HFH!
M`"$```#/:@$`!@```/%J`0`(````^&H!`!X````!:P$`)@```"!K`0`Q````
M1VL!`#8```!Y:P$`*````+!K`0`O````V6L!`&T````);`$`.@```'=L`0`*
M````LFP!``8```"];`$`"0```,1L`0`2````SFP!``P```#A;`$`$````.YL
M`0`6````_VP!`!$````6;0$`%@```"AM`0`6````/VT!`!````!6;0$`%0``
M`&=M`0`&````?6T!`!L```"$;0$`&P```*!M`0`7````O&T!`!L```#4;0$`
M&````/!M`0`&````"6X!``<````0;@$`$````!AN`0!<````*6X!`&````"&
M;@$`!````.=N`0`2````[&X!``4```#_;@$`!0````5O`0`<````"V\!`!D`
M```H;P$`%````$)O`0`1````5V\!`!(```!I;P$`&@```'QO`0`Z````EV\!
M``\```#2;P$`+P```.)O`0`&````$G`!`!0````9<`$`#P```"YP`0`3````
M/G`!``\```!2<`$`&````&)P`0`2````>W`!`!4```".<`$`$P```*1P`0`-
M````N'`!``8```#&<`$`$@```,UP`0`'````X'`!``X```#H<`$`%@```/=P
M`0`/````#G$!``@````><0$``P```"=Q`0`0````*W$!``X````\<0$`!0``
M`$MQ`0`3````47$!``H```!E<0$`!P```'!Q`0`0````>'$!``@```")<0$`
M!````))Q`0`'````EW$!``<```"?<0$`#````*=Q`0`(````M'$!``D```"]
M<0$`&@```,=Q`0`^````XG$!`"8````A<@$`#0```$AR`0`0````5G(!``4`
M``!G<@$`'P```&UR`0`1````C7(!`!(```"?<@$`,@```+)R`0!"````Y7(!
M`"$````H<P$`"````$IS`0!'````4W,!`"@```";<P$`$````,1S`0`)````
MU7,!``H```#?<P$`!@```.IS`0`&````\7,!`!(```#X<P$`#@````MT`0`+
M````&G0!``H````F=`$`#P```#%T`0`L````070!`"<```!N=`$`-````)9T
M`0`O````RW0!`"8```#[=`$`*P```")U`0`F````3G4!`"4```!U=0$`/0``
M`)MU`0`R````V74!`"D````,=@$`+P```#9V`0`F````9G8!`#0```"-=@$`
M1@```,)V`0!!````"7<!`#T```!+=P$`/0```(EW`0!'````QW<!`"P````/
M>`$`*````#QX`0!&````97@!`"H```"L>`$`&@```-=X`0`U````\G@!`"@`
M```H>0$`+````%%Y`0`8````?GD!`,D```"7>0$`'````&%Z`0`R````?GH!
M`#(```"Q>@$`-````.1Z`0`Q````&7L!`"D```!+>P$`*@```'5[`0`J````
MH'L!`#(```#+>P$`-0```/Y[`0!)````-'P!`#L```!^?`$`J0```+I\`0`L
M````9'T!`"4```"1?0$`*````+=]`0`V````X'T!`#(````7?@$`60```$I^
M`0!.````I'X!``T```#S?@$`!`````%_`0`&````!G\!``4````-?P$`#0``
M`!-_`0`.````(7\!`!`````P?P$`%0```$%_`0`;````5W\!``<```!S?P$`
M!````'M_`0`.````@'\!``X```"/?P$`"@```)Y_`0`-````J7\!`!,```"W
M?P$`"P```,M_`0`0````UW\!``P```#H?P$`-@```/5_`0`&````+(`!``X`
M```S@`$`!@```$*``0`1````28`!`!<```!;@`$`&P```'.``0`0````CX`!
M``(```"@@`$`2@```*.``0`+````[H`!`!4```#Z@`$`&@```!"!`0`$````
M*X$!`!,````P@0$`#P```$2!`0`#````5($!``\```!8@0$`"````&B!`0`0
M````<8$!`!````""@0$`!@```).!`0`*````FH$!`!$```"E@0$`#````+>!
M`0`*````Q($!``<```#/@0$`#@```->!`0`-````YH$!``L```#T@0$`$0``
M``""`0`:````$H(!``X````M@@$`#@```#R"`0`C````2X(!`!P```!O@@$`
M/````(R"`0`-````R8(!`!X```#7@@$`%@```/:"`0`5````#8,!`#0````C
M@P$`#P```%B#`0`)````:(,!`!,```!R@P$`"0```(:#`0`U````D(,!`#<`
M``#&@P$`#P```/Z#`0`0````#H0!`"4````?A`$`$@```$6$`0`@````6(0!
M`"````!YA`$`"0```)J$`0`;````I(0!`!(```#`A`$`&0```-.$`0`5````
M[80!``X````#A0$`&0```!*%`0`'````+(4!``L````TA0$`)@```$"%`0!(
M````9X4!``H```"PA0$`%````+N%`0`?````T(4!``8```#PA0$`"0```/>%
M`0`P`````88!`!`````RA@$`!@```$.&`0`'````2H8!`%0```!2A@$``P``
M`*>&`0`'````JX8!``8```"SA@$`#````+J&`0`,````QX8!`!````#4A@$`
M$0```.6&`0`9````]X8!`!$````1AP$`&0```".'`0`9````/8<!``@```!7
MAP$`!0```&"'`0`+````9H<!``L```!RAP$``@```'Z'`0`&````@8<!`!(`
M``"(AP$`)P```)N'`0`8````PX<!`!D```#<AP$`"0```/:'`0`3`````(@!
M`!0````4B`$`'````"F(`0!&````1H@!`"\```"-B`$`#````+V(`0`/````
MRH@!`(H```#:B`$`'````&6)`0`8````@HD!`!````";B0$`"````*R)`0`$
M````M8D!`!<```"ZB0$`*P```-*)`0`H````_HD!`!H````GB@$`'0```$**
M`0`1````8(H!`!,```!RB@$`!P```(:*`0`'````CHH!``8```"6B@$`!@``
M`)V*`0`/````I(H!``X```"TB@$`$````,.*`0`.````U(H!``P```#CB@$`
M#@```/"*`0`+````_XH!`!,````+BP$`"````!^+`0`(````*(L!`!8````Q
MBP$`#````$B+`0`U````58L!`!$```"+BP$`"````)V+`0`5````IHL!`"4`
M``"\BP$`&P```.*+`0`C````_HL!`"(````BC`$`&````$6,`0`:````7HP!
M`"4```!YC`$`&0```)^,`0`2````N8P!``4```#,C`$`&0```-*,`0`+````
M[(P!``L```#XC`$``P````2-`0`%````"(T!``D````.C0$`$````!B-`0`2
M````*8T!`!$````\C0$`"@```$Z-`0`/````68T!``X```!IC0$`#````'B-
M`0`$````A8T!``<```"*C0$`(````)*-`0`A````LXT!`!<```#5C0$`#P``
M`.V-`0`2````_8T!`!`````0C@$`(@```"&.`0`'````1(X!``D```!,C@$`
M#P```%:.`0`/````9HX!``D```!VC@$`!0```(".`0`*````AHX!``4```"1
MC@$`$P```)>.`0`,````JXX!``8```"XC@$`*0```+^.`0`.````Z8X!`(,`
M``#XC@$`$0```'R/`0`+````CH\!``4```":CP$`#0```*"/`0`&````KH\!
M``@```"UCP$`!@```+Z/`0`1````Q8\!``,```#7CP$`!P```-N/`0`&````
MXX\!`!0```#JCP$`#P```/^/`0`2````#Y`!`!P````BD`$``@```#^0`0`%
M````0I`!`!(```!(D`$`"0```%N0`0`-````99`!``4```!SD`$`(````'F0
M`0`(````FI`!``8```"CD`$`&@```*J0`0`-````Q9`!``<```#3D`$`"```
M`-N0`0`$````Y)`!``D```#ID`$`#0```/.0`0`.`````9$!``(````0D0$`
M!@```!.1`0`,````&I$!`!,````GD0$`$````#N1`0`&````3)$!`!(```!3
MD0$`"@```&:1`0`'````<9$!`!<```!YD0$`*0```)&1`0!*````NY$!`"<`
M```&D@$`*0```"Z2`0`&````6)(!``D```!?D@$`!````&F2`0`)````;I(!
M``@```!XD@$`%P```(&2`0`0````F9(!``4```"JD@$`#````+"2`0`&````
MO9(!``0```#$D@$`00```,F2`0!"````"Y,!`$$```!.DP$`(0```)"3`0`%
M````LI,!``X```"XDP$`!P```,>3`0`)````SY,!``D```#9DP$`&P```..3
M`0`0````_Y,!`!4````0E`$`!@```":4`0`%````+90!``\````SE`$`"@``
M`$.4`0`*````3I0!`!X```!9E`$`!````'B4`0`'````?90!`"0```"%E`$`
M!@```*J4`0`4````L90!`!$```#&E`$`$````-B4`0`(````Z90!``D```#R
ME`$`!0```/R4`0`[`````I4!`#8````^E0$`0P```'65`0`I````N94!`$(`
M``#CE0$`0@```":6`0`K````:98!`$H```"5E@$`+P```."6`0`Y````$)<!
M`"\```!*EP$`$````'J7`0`1````BY<!``L```"=EP$`+0```*F7`0`I````
MUY<!`"$````!F`$`*````".8`0`'````3)@!``D```!4F`$`"@```%Z8`0`'
M````:9@!`"0```!QF`$`)@```):8`0`M````O9@!``L```#KF`$`&P```/>8
M`0`M````$YD!`!@```!!F0$`$P```%J9`0`(````;ID!``X```!WF0$`#@``
M`(:9`0`.````E9D!`!,```"DF0$`1````+B9`0!^````_9D!`'$```!\F@$`
M&P```.Z:`0`-````"IL!``X````8FP$`$0```">;`0`2````.9L!``\```!,
MFP$`!P```%R;`0`2````9)L!`!,```!WFP$`$@```(N;`0`3````GIL!`"@`
M``"RFP$`'@```-N;`0"$````^IL!`!(```!_G`$`!0```)*<`0`4````F)P!
M``D```"MG`$`"@```+><`0`*````PIP!`!\```#-G`$`%````.V<`0`.````
M`IT!``X````1G0$`$P```""=`0`5````-)T!`"0```!*G0$`)@```&^=`0`C
M````EIT!`"4```"ZG0$`(0```."=`0`C`````IX!`!T````FG@$`10```$2>
M`0`3````BIX!`!0```">G@$`$P```+.>`0`4````QYX!`!$```#<G@$`%@``
M`.Z>`0`7````!9\!`!(````=GP$`$P```#"?`0`\````1)\!`!8```"!GP$`
M%````)B?`0`^````K9\!`!4```#LGP$`#@````*@`0`1````$:`!`"T````C
MH`$`$P```%&@`0`3````9:`!`"````!YH`$`'0```)J@`0`?````N*`!`!T`
M``#8H`$`&P```/:@`0`A````$J$!`!P````TH0$`(P```%&A`0`A````=:$!
M`"````"7H0$`(````+BA`0`=````V:$!`!,```#WH0$`&P````NB`0`=````
M)Z(!`!L```!%H@$`&````&&B`0`*````>J(!`!````"%H@$`&@```):B`0`&
M````L:(!``<```"XH@$`#0```,"B`0`4````SJ(!``8```#CH@$`!P```.JB
M`0`'````\J(!``8```#ZH@$`!P````&C`0`'````":,!``4````1HP$`%0``
M`!>C`0`&````+:,!``@````THP$`!0```#VC`0`%````0Z,!``H```!)HP$`
M$0```%2C`0`*````9J,!`!(```!QHP$`$0```(2C`0`+````EJ,!`!(```"B
MHP$`!@```+6C`0`J````O*,!`!$```#GHP$`$````/FC`0`:````"J0!`!``
M```EI`$`#0```#:D`0`,````1*0!`"\```!1I`$`"````(&D`0`(````BJ0!
M`"@```"3I`$`%````+RD`0`0````T:0!``8```#BI`$`"P```.FD`0`'````
M]:0!``8```#]I`$`(0````2E`0`-````)J4!`!`````TI0$`#0```$6E`0`3
M````4Z4!`!````!GI0$`'P```'BE`0`3````F*4!``<```"LI0$``P```+2E
M`0`&````N*4!`!\```"_I0$`!@```-^E`0`(````YJ4!`!(```#OI0$`$P``
M``*F`0`&````%J8!``0````=I@$`!P```"*F`0`6````*J8!``T```!!I@$`
M#0```$^F`0`+````7:8!`!0```!II@$`%@```'ZF`0`7````E:8!`!D```"M
MI@$`"@```,>F`0`-````TJ8!``8```#@I@$`!````.>F`0`1````[*8!`#L`
M``#^I@$`!0```#JG`0`/````0*<!`"$```!0IP$`%@```'*G`0`7````B:<!
M``X```"AIP$`#````+"G`0`)````O:<!``<```#'IP$`"@```,^G`0`)````
MVJ<!``X```#DIP$`$````/.G`0`@````!*@!`"$````EJ`$`)P```$>H`0`*
M````;Z@!``@```!ZJ`$`#0```(.H`0`,````D:@!`!(```">J`$`!@```+&H
M`0`(````N*@!`"<```#!J`$`"P```.FH`0`(````]:@!`!(```#^J`$`/```
M`!&I`0`/````3JD!``L```!>J0$`!````&JI`0`%````;ZD!`!L```!UJ0$`
M'````)&I`0`<````KJD!``H```#+J0$``@```-:I`0`$````V:D!`"$```#>
MJ0$``P````"J`0`%````!*H!`"D````*J@$`"@```#2J`0`&````/ZH!``<`
M``!&J@$`&````$ZJ`0`.````9ZH!``8```!VJ@$`!P```'VJ`0`(````A:H!
M``0```".J@$`!0```).J`0`\````F:H!`!````#6J@$`$P```.>J`0`5````
M^ZH!``4````1JP$`!@```!>K`0`>````'JL!`#,````]JP$`#@```'&K`0`)
M````@*L!`!8```"*JP$`"@```*&K`0`(````K*L!`!D```"UJP$`+````,^K
M`0`I````_*L!`"@````FK`$`(0```$^L`0`.````<:P!``0```"`K`$`!P``
M`(6L`0`(````C:P!``<```"6K`$`#0```)ZL`0`/````K*P!``@```"\K`$`
M5P```,6L`0`2````':T!`!`````PK0$`"P```$&M`0`;````3:T!`%````!I
MK0$`'0```+JM`0`&````V*T!`!T```#?K0$`)P```/VM`0`'````):X!``8`
M```MK@$`(````#2N`0`$````5:X!``D```!:K@$`*0```&2N`0`H````CJX!
M`"<```"WK@$`!P```-^N`0`(````YZX!`"(```#PK@$`60```!.O`0`8````
M;:\!`"8```"&KP$`%@```*VO`0`#````Q*\!``T```#(KP$`!P```-:O`0`/
M````WJ\!``L```#NKP$`!@```/JO`0`5`````;`!``8````7L`$`"````!ZP
M`0`)````)[`!``L````QL`$`"@```#VP`0`,````2+`!`#T```!5L`$`"```
M`).P`0`2````G+`!`!0```"OL`$`%P```,2P`0`,````W+`!`!````#IL`$`
M#P```/JP`0`+````"K$!``8````6L0$`!0```!VQ`0`*````([$!`"4````N
ML0$`%P```%2Q`0`0````;+$!``L```!]L0$`$````(FQ`0`*````FK$!`!0`
M``"EL0$`"````+JQ`0`4````P[$!``0```#8L0$`!P```-VQ`0`%````Y;$!
M``4```#KL0$`!P```/&Q`0`3````^;$!`!0````-L@$`(@```"*R`0`B````
M1;(!`!P```!HL@$`'````(6R`0`@````HK(!`"4```##L@$`'P```.FR`0`$
M````";,!``4````.LP$`#@```!2S`0`.````([,!`!4````RLP$`"````$BS
M`0`7````4;,!``T```!ILP$`"@```'>S`0`:````@K,!`!\```"=LP$`%```
M`+VS`0`(````TK,!`!(```#;LP$`!P```.ZS`0`0````]K,!``\````'M`$`
M"````!>T`0`)````(+0!``4````JM`$`!P```#"T`0`%````.+0!``0````^
MM`$``P```$.T`0!!````1[0!`#4```")M`$`%P```+^T`0`I````U[0!`#D`
M```!M0$`$@```#NU`0`X````3K4!`#@```"'M0$`/0```,"U`0`]````_K4!
M`$(````\M@$`&````'^V`0`9````F+8!`!8```"RM@$`&````,FV`0`@````
MXK8!`"`````#MP$`&P```"2W`0`9````0+<!`!L```!:MP$`%````':W`0`Q
M````B[<!`#$```"]MP$`-0```.^W`0`R````);@!`#,```!8N`$`,````(RX
M`0!W````O;@!`!D````UN0$`%@```$^Y`0`*````9KD!`"(```!QN0$`"0``
M`)2Y`0`3````GKD!`#0```"RN0$`)0```.>Y`0`@````#;H!``L````NN@$`
M40```#JZ`0!-````C+H!``<```#:N@$`%P```.*Z`0`5````^KH!``P````0
MNP$`$````!V[`0`6````+KL!``<```!%NP$`"````$V[`0`)````5KL!`!(`
M``!@NP$`$0```'.[`0`/````A;L!``X```"5NP$`"0```*2[`0`8````KKL!
M``@```#'NP$`!@```-"[`0`4````U[L!`!$```#LNP$`$````/Z[`0!"````
M#[P!``(```!2O`$`!@```%6\`0`1````7+P!``4```!NO`$`!P```'2\`0`/
M````?+P!``H```",O`$`*@```)>\`0`,````PKP!`!X```#/O`$``P```.Z\
M`0`W````\KP!`!@````JO0$`*````$.]`0"&````;+T!`!@```#SO0$`00``
M``R^`0`A````3KX!`!,```!PO@$`!@```(2^`0`,````B[X!``X```"8O@$`
M"P```*>^`0`6````L[X!``L```#*O@$`'````-:^`0`6````\[X!``4````*
MOP$`$@```!"_`0`:````([\!`"4````^OP$`$P```&2_`0`6````>+\!`!P`
M``"/OP$`$0```*R_`0`F````OK\!``H```#EOP$`%````/"_`0`6````!<`!
M`!`````<P`$`$@```"W``0`/````0,`!`!(```!0P`$`#P```&/``0`5````
M<\`!`!X```")P`$`%0```*C``0`&````OL`!``D```#%P`$`!0```,_``0`=
M````U<`!``8```#SP`$`$````/K``0`(````"\$!`!0````4P0$`!0```"G!
M`0`;````+\$!``\```!+P0$`+0```%O!`0`5````B<$!``8```"?P0$`!P``
M`*;!`0`8````KL$!``4```#'P0$`'@```,W!`0`$````[,$!`!0```#QP0$`
M!P````;"`0`+````#L(!`"`````:P@$`+0```#O"`0`)````:<(!`!P```!S
MP@$`$````)#"`0`*````H<(!`!L```"LP@$`%````,C"`0`$````W<(!`!0`
M``#BP@$`"0```/?"`0`(`````<,!``4````*PP$`"````!##`0`&````&<,!
M``8````@PP$`(0```"?#`0`W````2<,!`#\```"!PP$`(@```,'#`0`P````
MY,,!`"@````5Q`$`10```#[$`0`B````A,0!`"@```"GQ`$`)0```-#$`0!5
M````]L0!`"H```!,Q0$`!P```'?%`0`(````?\4!``<```"(Q0$`"````)#%
M`0`4````F<4!`!0```"NQ0$`,````,/%`0`M````],4!`!@````BQ@$`-0``
M`#O&`0`]````<<8!``<```"OQ@$`&0```+?&`0`)````T<8!`!````#;Q@$`
M(@```.S&`0`1````#\<!`!(````AQP$`#0```#3'`0`(````0L<!`!4```!+
MQP$`"````&''`0`+````:L<!``T```!VQP$`&@```(3'`0`-````G\<!`#P`
M``"MQP$`"@```.K'`0`%````]<<!``D```#[QP$`!0````7(`0`:````"\@!
M`!$````FR`$`!0```#C(`0`.````/L@!`!````!-R`$`$0```%[(`0`,````
M<,@!``\```!]R`$`#P```(W(`0`'````G<@!``,```"ER`$`#0```*G(`0`Z
M````M\@!`$X```#RR`$`%0```$')`0`)````5\D!`"8```!AR0$`'0```(C)
M`0`%````ILD!`!4```"LR0$``P```,+)`0`+````QLD!`!(```#2R0$`*@``
M`.7)`0`'````$,H!``T````8R@$`#@```";*`0`2````-<H!``L```!(R@$`
M.P```%3*`0`)````D,H!`!P```":R@$`#P```+?*`0`3````Q\H!`#\```#;
MR@$`+@```!O+`0`Y````2LL!`#H```"$RP$`-@```+_+`0`1````]LL!``8`
M```(S`$`$`````_,`0`0````(,P!``T````QS`$`"@```#_,`0`1````2LP!
M`!T```!<S`$`!P```'K,`0`5````@LP!`!H```"8S`$`"````+/,`0`'````
MO,P!`!$```#$S`$`$@```-;,`0`9````Z<P!``8````#S0$`!P````K-`0`/
M````$LT!`!4````BS0$`%````#C-`0`5````3<T!`!4```!CS0$`!P```'G-
M`0`&````@<T!`#$```"(S0$`)P```+K-`0`F````XLT!``@````)S@$`#P``
M`!+.`0`&````(LX!`!\````IS@$`(0```$G.`0`F````:\X!``L```"2S@$`
M%````)[.`0`F````L\X!``,```#:S@$`!P```-[.`0`5````YLX!``,```#\
MS@$`#`````#/`0`1````#<\!``L````?SP$`%````"O/`0`8````0,\!`!0`
M``!9SP$`!0```&[/`0`*````=,\!`!,```!_SP$`%````)//`0`.````J,\!
M``8```"WSP$`"0```+[/`0`)````R,\!``T```#2SP$`6@```.#/`0`6````
M.]`!`#4```!2T`$`%````(C0`0`'````G=`!``D```"ET`$`%````*_0`0`5
M````Q-`!`!(```#:T`$`(0```.W0`0`8````#]$!`!4````HT0$`(P```#[1
M`0`0````8M$!`"<```!ST0$`$P```)O1`0`5````K]$!`'````#%T0$`(0``
M`#;2`0`<````6-(!`"T```!UT@$`(0```*/2`0`<````Q=(!`"8```#BT@$`
M'P````G3`0`?````*=,!`!P```!)TP$`"@```&;3`0`'````<=,!``@```!Y
MTP$`"````(+3`0`3````B],!``\```"?TP$`+0```*_3`0`7````W=,!`!4`
M``#UTP$`!P````O4`0`'````$]0!`$\````;U`$`20```&O4`0`^````M=0!
M`&8```#TU`$`#````%O5`0`R````:-4!`#````";U0$`"0```,S5`0`'````
MUM4!``8```#>U0$`0````.75`0`&````)M8!`$`````MU@$`-````&[6`0`C
M````H]8!``X```#'U@$`+0```-;6`0`<````!-<!`#,````AUP$`*````%77
M`0`R````?M<!`"@```"QUP$`#0```-K7`0`&````Z-<!``\```#OUP$`$@``
M`/_7`0`5````$M@!``<````HV`$`0@```##8`0`*````<]@!``D```!^V`$`
M"@```(C8`0`7````D]@!``D```"KV`$`!P```+78`0`2````O=@!``H```#0
MV`$`"0```-O8`0`$````Y=@!``<```#JV`$`"````/+8`0`/````^]@!`!0`
M```+V0$`%@```"#9`0`=````-]D!``T```!5V0$`!P```&/9`0`0````:]D!
M``\```!\V0$`$@```(S9`0`-````G]D!`!@```"MV0$`*````,;9`0`.````
M[]D!`!\```#^V0$`*0```![:`0`)````2-H!``L```!2V@$`%````%[:`0`'
M````<]H!``0```![V@$`'P```(#:`0`.````H-H!``X```"OV@$`#0```+[:
M`0`(````S-H!``D```#5V@$`!@```-_:`0`)````YMH!``L```#PV@$`$P``
M`/S:`0`(````$-L!`!@````9VP$`"P```#+;`0`'````/ML!`!X```!&VP$`
M)@```&7;`0`,````C-L!``,```"9VP$`(0```)W;`0`'````O]L!``8```#'
MVP$`=````,[;`0`*````0]P!``<```!.W`$`)P```%;<`0!`````?MP!`!H`
M``"_W`$`)0```-K<`0!$`````-T!`"D```!%W0$`/0```&_=`0`;````K=T!
M`!8```#)W0$`!0```.#=`0`&````YMT!``D```#MW0$`"@```/?=`0`*````
M`MX!``D````-W@$`%````!?>`0`+````+-X!``H````XW@$`#````$/>`0`,
M````4-X!``<```!=W@$`"````&7>`0`)````;MX!`!0```!XW@$`"P```(W>
M`0`&````F=X!``4```"@W@$`"P```*;>`0`&````LMX!`"8```"YW@$`&```
M`.#>`0`*````^=X!`!8````$WP$`"P```!O?`0`4````)]\!``L````\WP$`
M!@```$C?`0`6````3]\!``8```!FWP$`%@```&W?`0`&````A-\!`!H```"+
MWP$`"P```*;?`0`6````LM\!``4```#)WP$`!P```,_?`0`2````U]\!`"``
M``#JWP$`"P````O@`0`-````%^`!`"T````EX`$`&P```%/@`0`8````;^`!
M``4```"(X`$`#0```([@`0`4````G.`!`!<```"QX`$``P```,G@`0`3````
MS>`!``D```#AX`$`(P```.O@`0`I````#^$!`#,````YX0$`)0```&WA`0`T
M````D^$!`"<```#(X0$`:0```/#A`0`7````6N(!`&<```!RX@$`0@```-KB
M`0!4````'>,!`&X```!RXP$`+0```.'C`0`[````#^0!`#,```!+Y`$`.```
M`'_D`0`N````N.0!`!L```#GY`$`-`````/E`0#7`0``..4!`!\````0YP$`
M%P```##G`0!*````2.<!`'<```"3YP$`,P````OH`0`E````/^@!`$$```!E
MZ`$`7````*?H`0!:````!.D!`"H```!?Z0$`(P```(KI`0`6````KND!`"@`
M``#%Z0$`'0```.[I`0`:````#.H!`"T````GZ@$`)0```%7J`0`E````>^H!
M`#H```"AZ@$`(P```-SJ`0`6`````.L!`#@````7ZP$`)0```%#K`0`J````
M=NL!`"T```"AZP$`'P```,_K`0`X````[^L!`&T````H[`$`,0```);L`0!"
M````R.P!`"X````+[0$`)P```#KM`0!`````8NT!`&,```"C[0$`2`````?N
M`0`N````4.X!`"X```!_[@$`,````*[N`0!?````W^X!`&\````_[P$`6```
M`*_O`0!9````"/`!`#4```!B\`$`*@```)CP`0`J````P_`!`"\```#N\`$`
M:P```![Q`0!Q````BO$!`'$```#\\0$`N0```&[R`0`9````*/,!`"\```!"
M\P$`,````'+S`0`M````H_,!`%(```#1\P$`)0```"3T`0!3````2O0!`"(`
M``">]`$`"@```,'T`0#8````S/0!`%@```"E]0$`(P```/[U`0`X````(O8!
M`"@```!;]@$`'@```(3V`0`Y````H_8!``0```#=]@$`"````.+V`0`$````
MZ_8!`!D```#P]@$`#P````KW`0`/````&O<!``L````J]P$`!@```#;W`0`/
M````/?<!``0```!-]P$`6````%+W`0`$````J_<!`!<```"P]P$`!````,CW
M`0`'````S?<!``8```#5]P$`!0```-SW`0`$````XO<!`!4```#G]P$`"0``
M`/WW`0`1````!_@!`!,````9^`$``P```"WX`0`'````,?@!``<````Y^`$`
M$@```$'X`0`-````5/@!`!0```!B^`$`!@```'?X`0`:````?O@!``T```"9
M^`$``P```*?X`0`K````J_@!``0```#7^`$`!@```-SX`0`'````X_@!`"$`
M``#K^`$`0`````WY`0`Q````3OD!`#(```"`^0$`&P```+/Y`0`R````S_D!
M`#4````"^@$`)````#CZ`0`C````7?H!`!X```"!^@$`)````*#Z`0`?````
MQ?H!`!T```#E^@$`)0````/[`0`C````*?L!`!X```!-^P$`-````&S[`0`<
M````H?L!`#$```"^^P$`,@```/#[`0`A````(_P!`"4```!%_`$`)````&O\
M`0`?````D/P!`"0```"P_`$`*@```-7\`0`H`````/T!`"H````I_0$`)@``
M`%3]`0`?````>_T!`"(```";_0$`*P```+[]`0`=````ZOT!`"0````(_@$`
M+P```"W^`0`R````7?X!`!H```"0_@$`)P```*O^`0`\````T_X!`"0````0
M_P$`)@```#7_`0`E````7/\!`"8```""_P$`(````*G_`0`>````RO\!`"<`
M``#I_P$`(P```!$``@`N````-0`"`"<```!D``(`+@```(P``@`*````NP`"
M`!,```#&``(`%@```-H``@`S````\0`"`"8````E`0(`#0```$P!`@`/````
M6@$"`!8```!J`0(`"P```($!`@`.````C0$"`"P```"<`0(`"````,D!`@`,
M````T@$"`"<```#?`0(`*@````<"`@`@````,@("`!\```!3`@(`'````',"
M`@`(````D`("`-0```"9`@(`#0```&X#`@`6````?`,"``D```"3`P(`#0``
M`)T#`@`1````JP,"`!````"]`P(`'P```,X#`@`&````[@,"`$L```#U`P(`
M'````$$$`@`<````7@0"``<```![!`(`$@```(,$`@`,````E@0"`#8```"C
M!`(`"````-H$`@`G````XP0"`!D````+!0(`$@```"4%`@`4````.`4"`#(`
M``!-!0(`'P```(`%`@`'````H`4"`!<```"H!0(`"````,`%`@`)````R04"
M`!0```#3!0(`"P```.@%`@`;````]`4"``8````0!@(`*@```!<&`@`(````
M0@8"`",```!+!@(`*P```&\&`@`'````FP8"`!<```"C!@(`!P```+L&`@`(
M````PP8"``D```#,!@(`/@```-8&`@`&````%0<"`!(````<!P(`%````"\'
M`@`/````1`<"``D```!4!P(`"@```%X'`@`&````:0<"`!,```!P!P(`!@``
M`(0'`@`A````BP<"`!(```"M!P(`&0```,`'`@`5````V@<"``P```#P!P(`
M#@```/T'`@`:````#`@"``<````G"`(`+0```"\(`@`,````70@"``\```!J
M"`(`!P```'H(`@`#````@@@"`!$```"&"`(`'````)@(`@`+````M0@"``,`
M``#!"`(`"````,4(`@`,````S@@"``D```#;"`(`#P```.4(`@`-````]0@"
M`!8````#"0(`%P```!H)`@`0````,@D"`"\```!#"0(`'0```',)`@`<````
MD0D"`!H```"N"0(`"P```,D)`@`P````U0D"``<````&"@(`%P````X*`@!%
M````)@H"`!$```!L"@(`$@```'X*`@`(````D0H"``0```":"@(`!0```)\*
M`@`1````I0H"`!H```"W"@(`!@```-(*`@`'````V0H"``D```#A"@(`$```
M`.L*`@`(````_`H"`!(````%"P(`#@```!@+`@!%````)PL"`#8```!M"P(`
M*0```*0+`@`%````S@L"`!D```#4"P(`)````.X+`@`B````$PP"`"@````V
M#`(`$````%\,`@`"````<`P"``0```!S#`(`"P```'@,`@`*````A`P"``4`
M``"/#`(``P```)4,`@`0````F0P"`$\```"J#`(`,P```/H,`@`:````+@T"
M`"L```!)#0(`+P```'4-`@!3````I0T"`!8```#Y#0(`A0```!`.`@`D````
ME@X"`$(```"[#@(`)0```/X.`@!'````)`\"`"L```!L#P(`,P```)@/`@`N
M````S`\"`"X```#[#P(`,````"H0`@`P````6Q`"`"T```",$`(`,@```+H0
M`@`T````[1`"`#<````B$0(`%@```%H1`@`@````<1$"`!````"2$0(`?```
M`*,1`@`(````(!("`'`````I$@(`<@```)H2`@"`````#1,"`"8```".$P(`
M7@```+43`@`7````%!0"`",````L%`(`%@```%`4`@`2````9Q0"`!0```!Z
M%`(`'````(\4`@!`````K!0"`!X```#M%`(`&0````P5`@!0````)A4"`!(`
M``!W%0(`&````(H5`@`*````HQ4"``4```"N%0(`!@```+05`@`(````NQ4"
M``4```#$%0(`%@```,H5`@`7````X14"`!8```#Y%0(`(0```!`6`@`0````
M,A8"``X```!#%@(`!````%(6`@`)````5Q8"``\```!A%@(`!P```'$6`@`&
M````>18"`!H```"`%@(`"0```)L6`@`,````I18"`!````"R%@(`!P```,,6
M`@`+````RQ8"`!````#7%@(`"P```.@6`@`:````]!8"``D````/%P(`%0``
M`!D7`@`5````+Q<"``8```!%%P(`!0```$P7`@`C````4A<"`!D```!V%P(`
M"P```)`7`@`C````G!<"`!0```#`%P(`*P```-47`@`9`````1@"``8````;
M&`(`%P```"(8`@`%````.A@"``<```!`&`(`&P```$@8`@`%````9!@"``(`
M``!J&`(``@```&T8`@`;````<!@"``@```",&`(`"P```)48`@`5````H1@"
M`!@```"W&`(`!P```-`8`@`S````V!@"``(````,&0(`!`````\9`@`0````
M%!D"`!8````E&0(`#@```#P9`@`+````2QD"``D```!7&0(`!@```&$9`@`8
M````:!D"``@```"!&0(`%````(H9`@`1````GQD"`!(```"Q&0(``@```,09
M`@`'````QQD"``\```#/&0(`$````-\9`@`0````\!D"`"P````!&@(`"0``
M`"X:`@`(````.!H"`!(```!!&@(`!0```%0:`@`"````6AH"``L```!=&@(`
M`0```-`$```:!```+@4``%T#````````G`$``&L"``">!````````)(#``#%
M`0``^`8``'P``````````````(0"```F!P``"P$```````!^!P``P0```'0%
M```3!```[@4``"P```#8`P``O@8``"`'```&`@``_P,``+D%``#_!@``+P,`
M``````"D`@``[04``&("``"P`@``#00``'\#````````````````````````
MTP0``$X%``"#!`````````````#T`0``;@(`````````````?0(``"P$````
M````(P$``*$%````````7P<``.$%``",!@``)0$``&T&``#R!```;`(``'`!
M```P!P``P`$``,\"```M!```;0,``$L'``!:````H@$``#,!``"&!P``````
M`'L!``#K````DP8``+T%``!9!P``1P4``,D&````````D@0``&`"``#R````
M)P(``&0"````````V`0``($&``#;!0````````````"E````````````````
M````E@,```````!`````X08```````#+`0```````,L%``!&`@``O`4`````
M``#[`@``A0<````````)!0```````$T$``#)!0``Z@(``",%```7````````
M`#0```!8````NP$`````````````LP(``%@$``!C`P``:`,``%\!````````
M````````````````^`$``&(#``!O````U`$```````!Z!@````````4'``"0
M`````````$L#``"9`@```````!H#``!:!@``\@$``-\````F`P``V@$``,X!
M``"T`P``10,````````8!P``#@<``",#``#Q````K04``,\$````````````
M`*D#``"D`````````,@%``!?`P``=P,``),$```(!````````(<&``"^`0``
M`````-X$``!U!P``U@,``.4!````````_`4``$<'``"I`0``5@0``.(!````
M````3P```)L$```````````````````M`P``:0<```````"R`````````)4%
M``!E!```H08``.`!``"N!@```````"H```#Y`0``:`$``%$'``#7`P``)@8`
M`*$$``!1!@``5`0``*P&````````FP(``%L```"/!@``B0,``*D`````````
MJ04``-,```">`P``>@$``&4"``#``P``)0<``'D#```K`````````#8`````
M`````````"\"``"#````X00```````#S!```=P0``$$'````````]P``````
M````````D0(``+<%````````%`4``*@#```I`@``=P<```````!R!```.0(`
M````````````C@(``(X!``"(!```W````'D'``!4!0``F`,```$"```X!P``
M7`,```8!````````0P0````````J!P``G0,``*4!`````````````&0%``!Q
M`0````````````!`!@``VP```#H'``!*```````````"````````*0$`````
M``!4`P```````)H$````````R@$``%\$```4`P```````"4$``!A````````
M```````C!```=P```.L#``!C!@```````)D&``#]!0``>P`````````6!@``
MKP0```,`````!P``V@4``+0&``#'`P``>@(``!,'``#L``````````````!C
M`0```````.P"``":````D@```)P#````````FP$``"@%``!O`@``\`,``$0#
M``"\`@``N0$``-H$``#3!@``L@,``.`$``#'!```J`0````````5!P``%0(`
M`+T$```8`0``KP(`````````````WP,``(T"````````?@$``/L%``!I`0``
M%`8``/8!```H`P``20,``'`#``!%!```E@$``$<```#&`0``;P,``$L&```Z
M````708``%,```#2!@``=`(````````K!0``)`(``'`&``#M````"`8```0`
M``#B`@``?`,``(`%``")`0``D00``/P"``!A!P``Y`4``!<!````````GP$`
M``H'``!Y`@``?@````,$```&!P``*P8``#(&````````4`(``+\`````````
M=0,``/T#````````"P```#`%`````````````&,'```E!@``W0````````#R
M`@``/`<```````#5`P``UP0`````````````:`````L"``!O!@```````-`&
M``#"!@``<0```*````#Y!@``0`(```````"9!```MP,``,`````"!```#`8`
M`$P!``"2`@``M@4``*`!``"_`0````````4`````````20<``-0"``!C````
M`````,0```````````````````#O!````````#T%``!L!P```````,H&````
M````%0,``'X&`````````````$\%`````````````/`$``!U!```H`8``&T$
M```(````7@```$4'``"X`P``<P4``-X```""`P``(@0``#@%``#T!@``F@,`
M`'4"````````:@$``#P"``"[!@``ZP4``+P$````````;`8```````")````
MHP(````````Q!@```````!D'````````50$``"`$```X`0```````&L$````
M````A0(``'8%``!]!0``U@`````````?`@``3`8``#4$```Q`@``````````
M``"5`P``_`0``/T&```%`P``9@8```````#O`0``Q@```.T#``"/````6`<`
M````````````Y`8``(,#`````````````-L"```L`P``5P$``/$&````````
MXP$``/X```!-````R@0```T%````````-@$``(X#``!]`0``EP```%<$``!]
M!```<P```*0%``!6`@``@`(````````_!@``=@$``/P!````````Y`0`````
M```D`````````/4$``!I!````````%D!```?!```!@```)T"``!<`@``````
M```````!!@``D04```````#>!@``C`,``#X````K`0``$@(``-0#``".!@``
M/0<```````!J`P```````(P$``"C`````````,,#``!1````NP(``"H$```>
M!```Y@0````````J!@``]`(``"P&``!5!0``````````````````IP(``"(#
M`````````````+,!````````?0```"4#````````;P<```````"/!```````
M`,P!``#M!@``"`$````````````````````!``!)!0``-@8```````#&!0``
M$0$``%T$``#X`P``G````*X#``#"`0```````',$``!O!```U0(``,<%``!\
M`0``C`$``````````````````/H%```S!````````#L'``"B!@``S@,``*4&
M``#K`0``I@````````#M`@``````````````````JP0``.D!``#V!```W`,`
M`"8$````````9`0``)\````-!@``MP0``.<#````````Q@0``%D"``"*!```
M`````,("``"[!0``/P4``'$'``#3!0``D`8```````!@!P`````````````9
M!````````/$#``!4````V0````````!(````E@````````!4`@``-P```!T&
M```Z`@``<0(```````#Q`@````````8$``"U`@``HP0``'0'````````UP8`
M`!4`````````U@0```````#\`````````!P%``"(!0``]0$``/0%``!Z`P``
MU08``+$%``"2!0````4```````````````````````"!!```O0(``,P"```)
M!P``EP,``/T"````````\00``#T"``!3`0```````,,$```R`0```````,D"
M``",``````````````!+`0````````````"W!@``"0$``-P!```D!```H@,`
M`,H%``!S`0``,00```X&``")!```8@`````````O````G08``#8"``!7`@``
M?`<``$0'``"*!0``&0````````"M````[`,``,X&``!Y!0``,@```+H%``#(
M`@```````/,&``"S!@``6`4``$0!`````````````!L"```;!P``V`8`````
M```+!0```````&`!```W`@``00(``+H!``!^`P```````"H!``!&````S@(`
M`!$&````````?P```$`#```R!P``+0$``"\$``#?`0```````,\%``"R`@``
MY@$``%(#``#U`P``>P0```````"@`P``T@(``&`#``#H!0````````````!?
M````'0(``#`#``#Z`@```````'$$````````?08``#0%```W!0``%@0`````
M``!V````H0,```````"4!0``7P4``!`"``!L`0``(@$```````".````````
M`&<%````````P@4``!H!``#>`0```````)$#``"8`````````((%```8````
M`````"D%``"$!````````!P```"6!@``908``/D"``"%`0```````$H#``!E
M!P``>`0```X$``!E````404``,$&``!R`@``X```````````````M0,``',#
M`````````````````````````````%P!````````-0<``'P"``!L````````
M``````"&`@```````,L&```)`@``#`4``&T!```K`@``W04``.4"``!-`P``
M#0$``&````!G`````````+P&``#7`@``M@8``````````````````.H```"P
M!```*``````````L!P```````/,```"G!0``^P$``-($```:````````````
M````````8`0```````#%!@``7`8``$X`````````$0(`````````````2`0`
M`!,&```C````/P```'\%``"F!```M@(``(X%``#D````0`0```````"U!0``
M/@4``!\!``"X`0```````)@%````````M0```/X&```H!P````````````"N
M!````````&8'``!X!0``9@```````````````````,L$```'`0``5`8`````
M````````W`8``%T'```[`0``.00``',"``#H!@``-P0``!P'``#Z!@``;@8`
M``P!````````1`8``)H&``"Z!```8@8```8%``!"!P``````````````````
M<0,``(L```!V!P``T`,``/\!``"C`0``*@,```````"Q!````````"$'``#_
M`@``Z0(``'````!J!@``V`````\&``!#`P``6@<``/`%``#E!@``S@0``#T#
M````````^`4``&('``"<!@``T`(```````!K`0``T0```(8&```P````Q@(`
M`)\$``#J`0``X@```&@"``"F`0``6@(````````V`P```````%@&```I!```
M7@,``-X%````````SP```),%``#4!@``0P(`````````````E0$`````````
M````!`8``$,%``#[!@```````$<#``!I!0``4`<``-$!``"``0``````````
M``````````````````#Z!```:@0```0$```\`P``'00``-P$````````6@,`
M`'P$```/`@``*08``,@$```9`P```````'L&``!U`````P,``)$!````````
MK``````````"`@``>0$``"<$```Q!P```````'H```!T``````````````!B
M`0``5`$```T````_`0``VP,``+$&```T!P`````````````F````````````
M````````A04``(T$````````1`0``/X%````````LP```%`!``"-!@``L@$`
M`!0"``!.`@``A0,``&L'``#S`@``M@```.\&``#N`P``40$``-\$``#L!```
M`````,P&````````+0(````````(!P``4`````````!2`@```````$@&``!_
M`@```````!D&````````\`8``(@&``"[````608```````#W`0``A````$,&
M````````=0$`````````````0@(``$@!```3`P```````"0!``!7`P``]0``
M`)<%``!0!0``V08``#D!```6!P```````(@!``!9!0``500``#X'``"8`@``
M.P,```\#``"K!0``20$```````"=!````````#X!``!J````>P4``*4#``"D
M!@``(`````````"N````2P```!(```"D!````0$``'4&````````TP$``+H`
M``#A`P``M@$`````````````9@0`````````````O@```+D```!P!```````
M`!$```!<!0``XP0``!X#``"K`0``Y@```"`"``";!@``O`$``/`!```W!@``
M?P8```````"!````$`0``+D"```[!```?P$``!L```"Q`@```````+L#``!R
M!0``8P(``(4`````````RP(``,`&``!\!0```````%4"``"<!0``[@$``*L#
M````````AP4``'(!``"Q````?P0```````#L!@````````T'``!M`@``````
M`.H#````````#@(``!0!```K`P``0@0```````!_!P``W0(```````!X!@``
M1@4```````#8!0``A00```````!;!P``]0(``*T$```#`@```````"$```#Y
M!0``=P$``#H#```'!@``\04``.X"``!N!0``M@,```````#2`P``Y@(``%4&
M````````>00``#\#````````*`(``)D%``##!0``UP4``%X%````````````
M`/P&``!W!0``10(``#P```"\```````````````-`P`````````````,!P``
M-`8``!($`````````````%\"```$!P``,0,```````!``0``.@4```````"7
M!@````````````"'`0``R0```.8#``#@!@``O0```(L!``"[!````````#0#
M```S`@``&@4```````"#!@``K`0```4"``#H!```O0,`````````````````
M`$<$``!-!@``LP0``'`%``#"`P```````&D#``#8`0``L`$```````"0!0``
M`````,8&``"?!0````````<#``![`P``$P````L$``##`0``"00````````_
M`@``50```.`%````````J@,```$#```7!````P8`````````````YP0``.D%
M```(`P``I04``+4$```6````4@0``#<!``!2!0``H@(``/<"````````?@(`
M`"`%``#Y`P``0P$``&@$`````````````#P%```3`0```````.\#``#$!```
MN@8```````!&`P```````,L#``!:!0``>@0``#H&``#Y````&P4``$8!````
M````JP```%8!``#E!```C0````````#,`P``-08`````````````RP```(<`
M``#:`P````````````#)!````````$X'````````%@4```````#D`P``,0``
M`,H#``"&!0``$`$```X```!G!P``IP```,P$``!>!P``%08``-H````A`0``
MH`(``)8"``!<!```*P0``!\'``!E`0``=@(``!`'```;!```U@4``)H"``!=
M`````````-T$``!C!0``/`8``.0"````````KP4````````"`P``'`0`````
M``````````````$%````````DP$``((&``!R`P``K0,``/8&````````D`0`
M`(,"```;!@```````-D#````````6P$``%<'```2`P``[P(``"\'``!Q!0``
MI@,``%T!```H!@``````````````````JP8``-T#``!,`P``^00``#8'``!V
M!````````"P%``!D!@``U````)X"``#W`P```````"4%``""!P``Z@4``'`"
M````````*0`````````$`@````````<'``#B!````````$X&````````````
M`",'``#_!0```````$0"``````````````````#5`0``S0```#4#```$`0``
M`````"<'``!N!P``7P8```````!^!0``;@$``*T"``#"!```+`(``%,$````
M``````````````"!!0``$00``(\"``!3!@``T@```*P#``!%!@``,P<``'@'
M````````S00``!@%````````N`0`````````````@@$`````````````(0(`
M`%H!````````%P<``"X'```>`@``I@(``"('````````.`0``(<"``!K````
M[@8``#8%```\`0``#@4```````#B!0``B@```!P!``"I!```AP,```,%````
M````'P4``%L"````````Z`$```````#W!````````-T!``!$!0```````!`&
M``"(````YP(``#($``#B`P``J`4```H&``#%`P```````#T$````````````
M``````#H`@``GP,``/P#```5!0``,P```/,%``!S!P```````&L&````````
MR0,``&\!```<`P``5@4```````"&````@P$```````"T````C0,``(($```N
M!```MP$``)<"``"=!0``M`(``.,"````````,`0``*$````J`@``Q@,```D#
M````````B04````````8!@``J@0``````````````````&@%````````U@$`
M```````,!```!08````````E````W@,``)X``````````````&\%```<!@``
M`````!4!```[!0``'0```,H"``";!0``A08``(P"```>!0``E`(````````]
M!@``/@8``*$!``">!0``)0(`````````````+0```$8'``"3`@``4`0`````
M````````,@(``/4%``!T`0``6P,``#4!````````3`0``%,%``"@!```"0``
M`,`%``"!`P```````%@!``!G`@``Z0,``!<"````````P`(``%8'``!!`P``
M.@0``)`!``#D`0``X`,``$\$`````````````*H"```,`@``&@(``$X!``!&
M!```"@````````!)!@``^@$``"X```"-`0```````"D'``#K`@``YP$``,T!
M``!J`@````````````#8`@``P0(``"<```"Q`P``CP4```````!N````$```
M``````"+!```&P$``&X$``!R!P``_@(``-P%``!/!P``L`,```,'``"+`P``
M`````(L"``!G`0``@`,``+T!``!S!@``;`0``*H```!,`@``804```````"*
M`P``*P<``(`$````````N@,``#P$```6`@```````#4"``"0`P``@@```/X#
M```````````````````-`@``$P(``,(```"Y`P```````,T&```M!0``[@``
M`+X%````````104```\'``!5!P````0``%X!`````````````-<!``!&!@``
M[@0``&D&```U!0``-P<``)H!``#A````N@(``+P#```4!`````````````"6
M!0``YP4``/(#````````/P<``!<#``#I!```DP,````#```&!@``B@8`````
M``!H!@``7`<``"X!```C!@```````&$&``!G`P```````%L&``"S`P``"`(`
M`$<"```?````"08``&0!`````````````$T"`````````````*,%```N!@``
ML0$```````#0`0``,@4``(8!``!<`````````#@&``#C`P``%P4``+D$``"K
M`@```````(````!X`P``A`8``,4%``"`!@``VP$``#,#``#M`0``````````
M```,````E`,``&$"``"<`@``[P4``````````````````&($````````````
M`.D```"S!0``G@8````````>`0``OP,``#D&``!M!0``A`$``&D"````````
M2P0``.,&````````PP8``(\!````````PP```!H'````````800``'`'````
M````"@4``#T!``!,!P``:P,``!\&``!$````$@<`````````````U@(``$D`
M```Y`P``%00```````#O````9P8````````'!0``40,```0%```A!0``L@8`
M`*<$```%!```1P$``$$&```````````````````=!0```````+````"O````
M+08``.L&``#C`````````"`&```0`P``OP0``-8&`````````````'T#```*
M!```%@,``*P!`````````````-\&``#.`````````)(!``![!P``PP(``/\$
M````````-`$```````"H````+`$```P#````````C@0``!D!``"B````304`
M``````#F!@``TP(```````````````````<$``"9`0``F0,``*H!```*`@``
MT@4``/(%``#S`0``"P,```````"=`0``Q0````````#$`@``5P```#@````F
M`@````````````#[`P``I00``+@%````````OP4```````!/`0``'0$``.D&
M``#U!@``E`0``$X$````````K0$`````````````I`$``*8%``"N`@``8`8`
M``````#3`P``$P4``*0#````````&`(``/T$````````@P<``'T'``#.!0``
MX0$``*D&``#A`@``O08``*D"``!N`P``C04``*\!````````T`4``)\&````
M````L@4```````#,!0``:@4```````#V`@```````-H&`````````````!T#
M``!Z!P``L@0``*,&````````P04``*<!``!#````FP,``!D"````````2@0`
M```````"`0``E0(``$P%```^`P``=@8``-H"````````0P<``&`%``!\!@``
M0@,``.4```!*!0``OP8```````````````````````#0````60,``+<```!W
M`@``0`4```````!/!@``U`4``$@"```]````*@4```````!W!@``W@(``%X$
M```8`P``````````````````P00```````#1`P``X`(``'8#``"4````A`<`
M`!@$````````````````````````/P0``!<&`````````````$T'````````
M)P,``/T```!5`P`````````````>!P``3P,``#@"``"3````\0$``%,"````
M````]@,```L&````````EP0```````!"`0``70(``$D$``!(!P``:P4``*\#
M````````@@(``$H&````````)@$```````#9`0```````*X%``!M!P``V00`
M`&8%``"P!@``)`4``#D'``!`!P``2`,``&<$``#-`P```````&8"``"L!0``
M?@0``'0#``#/`P``3@,``)@!``#?`@``2@(``,`$````````A@0``&@'``!R
M````````````````````^`(````````O!0``9@,```('```A`P``>08`````
M``#E`P``E00``+4!``#'!@``S0(``"@!``"7`0``R0$```````!3!P``40(`
M`%@#``"#!0```````"X"``#X````F0````````#,````K`(``#$%````````
MUP````````"B!0``````````````````(@8``)4&``#L`0``'P,``#L```"4
M!@``00$``,0#``"*`@```0<``!(%``!B!0``````````````````(`,``(@"
M```>````@`<``%('``"J!0``10```'(&```V!```P0$``-(!``!"````8P0`
M`"0'``!L!0``\@8``%8````.`0``]P4``$L"``#[!```6`(``*`%```"!@``
MY@4``"(```!"!0```````$<&``"6!```F`8``+\"```!!`````````````"Y
M!@``;`,``!(&``#J!@```````'H%``#H````,@,``%<%```/!0``#P$``!P"
M````````904````````O`0``.P(``$T!```P`0``(P(``-4`````````(@4`
M`&0#``#V````>`(``(L&`````````````*$"````````K@$``/H#``!A`0``
MN````)$```````````````````"5````)`,```\``````````````(@#````
M````>P(``,0%``#$`0```````(0#```=!P``G@$```````#9`@``QP$```H!
M``!3`P``>0```-$$``#!`P```````,@!```1`P``````````````````:@<`
M`.T$``!T!```!@,````````[!@``U00```````"?`@``;0```(P%```4!P``
M`````%0'```H!````@```%X"```9!0```````/8%``!+!0```````,@````*
M`P``B0(```````"C`P``!04````````W`P``_0$```L'``!;!```!P(`````
M``!,````F`0``,\!```F!0``Y04```````!X`````````&8!``#P````[`4`
M`$D"``"T!0```@4```````!2````Z`,``$@%``#1!@``.0```,4$``":!0``
MO@(````````#`0``=`8``$$%``#;!@`````````````'````,P4``"D#``#Z
M````Q`8``!$'````!@``R@```'@!```2`0``]`,``.,%``"G!@``400``%(!
M````````!`,``+<"``!*!P``%````(\#``"H`@``6@0``-0$```X`P``+@,`
M`/0````^!````````-P"``"M!@````````````#9!0``7@8``+X#``#(`P``
MZ@0``%D$``"4`0``A@,``&0'``"!!P`````````````0!0``B08``*($```M
M!P``B@$``$$$``";````'@8``/`"``!Q!@````````````"T!`````````X#
M``#G!@``704```````#X!```D08``-\%```G!@````````````#T!```````
M`+@"````````M`$``$(&````````J@8``%(&```Y!0```````$$````T!```
M`````#`"````````_@0```````"+!0``&P,``*4"`````````````%`#```D
M!@``T04``/<&````````J`$``&$#```/!`````````````!0!@``)P$``+`%
M````````X@8``-$"````````A`4``($"``"U!@``5@,``($!````````ZP0`
M`"("``#/!@```````#4```"X!@``QP(``*<#``!9`````````#$!````````
MW08``*\&```(!0``10$``%<&``"V!```,P8```````!6!@```````&0````A
M!@``Q0(```````"=````_P````4!```^`@``AP0``&D```#5!0``(`$``)P$
M````````D`(``!$%````````.@$``,T%````````%@$```````!U!0``QP``
M`,@&`````````````%L%```A!```\P,``"<%``#G````O@0``*8&```:!@``
M2@$``"\&``#^`0``90,``-L$```T`@````````````#[````J`8``)(&``!/
M`@```````#`&````("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H
M:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI
M`"!A="``(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E<R(@:7,@;F]T(&$@
M=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(
M;W)D92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"X`
M(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S
M(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO
M="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@
M*"4N,F8E)2D`)60@)7,@86YD("5S`"5D(&1A>7,@=6YT:6P@>6]U<B!P87-S
M=V]R9"!E>'!I<F5S+@`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@
M1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M
M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F
M($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@
M:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T
M:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@`E<R!I
M<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@
M;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO
M=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`)7,Z(%1H:7,@;65S<V%G92!M
M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O
M9B!F;VQL;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T
M:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+@`L(&=U
M<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@
M)7,`+2T@<V5L96-T("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T
M`#(T(&AO=7)S`#Q0<F5V:6]U<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q
M=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R
M<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R
M:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A
M=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E
M8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'
M4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@
M;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M
M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC
M<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D<P!!32!,:6=H="!286EN`$%-(%)A
M:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`05!)($E$`$%B
M;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M:61D;&4`
M06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@
M9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT($EN9F]R;6%T:6]N
M`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`
M061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@
M2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@
M8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O
M("(E<R(`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M96UB
M97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED
M96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B
M;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O
M=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S
M+@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO
M=RX`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@
M0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U
M<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB86YI80!!
M;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT
M:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F
M;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T
M:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E
M<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E
M<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!
M;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;65R:6-A;B!3
M86UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N('5N:VYO
M=VX@97)R;W(@:&%S(&]C8W5R960N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA
M`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC80!!;G1I9W5A(&%N
M9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC
M871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E
M`$%P<')O>&EM871E(%-I>F4`07!R:6P`07)A8FEC("A7:6YD;W=S+3$R-38I
M`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U<F4@
M>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@
M/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("(E<R(@86YD(&%N
M>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA;B`H05)-
M4T-)22TX*0!!<G0`07)U8F$`07-C96YS:6]N($ES;&%N9`!!<V-I:2!!<G0`
M07-I82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O
M<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N="!C
M;VQU;6YS`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P
M+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N
M+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`
M071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1R:6)U
M=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q
M=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"
M86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U
M=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#
M;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H
M7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C
M=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N
M;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@
M4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z
M(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S
M`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;&1A
M<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E
M($1I<F5C=&]R>2X`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!A="!)34%0('-E
M<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A
M=&EO;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!
M1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I
M;&5D+@!!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N
M`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A
M8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O
M<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A
M;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S92!G
M<F%P:&EC<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`$)A<V5L:6YE`$)E
M;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER
M=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N
M9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV:6$`0F]O
M:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI
M82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!";W1T;VT`0F]U=F5T
M($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y
M`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R
M:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O
M:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A8VAE(&EN:70@=V%S(&YO="!C
M;VUP;&5T960N`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N
M(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<BX`0V%N(&YO="!W<FET92!T;R!F:6QE("(E<R(`
M0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+@!#
M86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#86XG="!O<&5N(&9I
M;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`
M0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R
M87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T
M1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B
M+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E
M;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R
M(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M
M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO
M;@!#87)R:65R`$-A=&5G;W)I97,@86YD($QA8F5L<P!#87EM86X@27-L86YD
M<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E
M;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#96QT:6,@
M*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC
M`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E
M=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A=&4@4&]L:6-I97,`
M0VAA9`!#:&%N9V4`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E('1H92!N
M86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A
M9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG:6YG('EO=7(@<&%S
M<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I
M9W5R871I;VXN("!#;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0VAA<@!#
M:&5C7VL@3&EN:RXN+@!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L:69I960@
M*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E($%P
M<&QI8V%T:6]N.@!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M
M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T
M>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:')I<W1M87,@27-L86YD
M`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A
M<B!-4T]F9FEC92!T86=S`$-L96%R(%%U97)Y`$-L96%R(&]U="!U<V5R.B`E
M<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L
M:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN
M9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O8V]S("A+965L:6YG
M*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`
M0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`
M0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H
M96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;7!U
M=&5R<P!#;VYD:71I;VX`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E
M<F5N8V5S`$-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3
M;6%R='!H;VYE<R!A;F0@3W5T;&]O:RX`0V]N9FEG=7)A=&EO;B!I<R!O=70@
M;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`
M0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T
M:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E
M9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F
M=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I
M`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S`$-O
M;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S
M<R!B;V]K+@!#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N
M=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O
M<'D`0V]P>2!F86EL960Z("5S`$-O<'D@<V5L96-T:6]N`$-O<W0@240`0V]S
M=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M
M97-S86=E.B``0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#;W5L9"!N
M;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S
M:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@
M;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C:R!B86QA
M;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`0V]U
M;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#
M;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N
M;W0@9&5C<GEP="!01U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T(%,O34E-
M12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO
M="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE
M=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T(&1E=&5R
M;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO
M="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C
M:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H
M('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U
M;&0@;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E
M<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES
M97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N`$-O=6QD
M(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K
M(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U
M;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(')E860@
M)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U
M97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO
M="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T
M<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S
M`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U
M;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@
M;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@
M<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`B)7,B+@!#
M;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V
M92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C
M:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S879E('1H92!B86-K
M=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE
M(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O
M<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N
M;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN:R`B
M)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U
M<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W<FET92!C
M;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E<P!#;W5L9&XG="!F:6YD('1H92!-
M;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N
M+@!#;W5L9&XG="!G:79E('5S97(@(B5S(B!T:&4@9F]L;&]W:6YG(')I9VAT
M<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R
M>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O
M;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E
M9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(#0@4&AA<V5S
M`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES
M`$-U<G)E;G0@57-E<G,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET
M:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P
M;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I
M;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI
M8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1%-.("AS
M964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A
M8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!$86EL>0!$871A5')E92!"<F]W<V5R
M`$1A=&%B87-E($QO;VMU<`!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE
M8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M
M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E
M9F%U;'0@261E;G1I='D`1&5F875L="!3:&5L;`!$969I;FET:6]N<P!$96QE
M=&4`1&5L971E($-E;&P`1&5L971E($=R;W5P`$1E;&5T92!,;V<`1&5L971E
M(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@
M8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@
M=&5M<&QA=&4`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P
M97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`
M1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('1H
M92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T
M960@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L:79E<GD@=&EM90!$
M96YM87)K`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I
M;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`
M1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT
M.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O
M(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA
M>2!/<'1I;VYS`$1I<W!L87D@9&5T86EL960@9F]R96-A<W0`1&ES<&QA>2!F
M;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I
M9FEC871I;VX`1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T
M;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F:7)S="!R;W<@
M8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B
M;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;VXG="!H879E(&%N
M(&%C8V]U;G0_(%-I9VX@=7`N`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL
M;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R
M;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%36%I;"UT;RU335,@9V%T97=A
M>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R
M=FEC92X`15)2`$5C=6%D;W(`161I=`!%9&ET($)L;V-K`$5D:70@1W)O=7``
M161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S
M:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M:7-S:6]N
M<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C871I;VX`
M16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%;6%I;"!!
M9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W:71H
M(&-O;F9I<FUA=&EO;@!%;6%I;"UT;RU335,@1V%T97=A>0!%;6]T:6-O;G,`
M16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R
M;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL
M97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N
M=3\`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U<FET>2!Q
M=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T
M;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE
M(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%;G1E
M<B!T:&4@;&5T=&5R<R!B96QO=SH`17%U871O<FEA;"!'=6EN96$`17)I=')E
M80!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`17)R;W(@9&5L971I
M;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E
M<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S`$5R<F]R('5P9&%T:6YG('!A
M<W-W;W)D.B`E<P!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R
M:71I;F<@(B5S(BX`17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E`$5V
M97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N
M9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U
M<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AP86YD
M`$5X<&%N9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E('=O
M<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%>'!O
M;F5N=`!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R
M:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0
M('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I
M;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B
M+@!&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE
M9"!T;R!M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!R971R:65V93H@)7,`1F%I
M<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&
M871A;"!%<G)O<CH`1F%X`$9A>&5S`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E
M;',@;&EK93H@`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEE;&0@
M;6%T<FEX`$9I9VQE="!#05!40TA!`$9I9VQE="!F;VYT`$9I:FD`1FEL90!&
M:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@
M36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`
M1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1FEN;&%N9`!&
M:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``1FQO870`
M1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`
M1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R96-A
M<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE
M9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G
M92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*0!&
M;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y
M<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`1G(`1G)A
M;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5N8V@@1W5I86YA
M`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S
M`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U
M;&P@3F%M90!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;0!'86QL
M97)Y.@!'86UB:6$`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T
M960@0V]D90!'96]R9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N
M($YA;64`1VQO8F%L($]P=&EO;G,`1V\`1V]E9&5L`$=O;V=L92!-87!S`$=O
M;V=L92!396%R8V@`1W)A>7-C86QE`$=R965C90!'<F5E:R`H25-/+3@X-3DM
M-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7`@061M:6YI<W1R871I;VX`1W)O
M=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`1W)O=7!?;&1A<#H@56YA8FQE
M('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9#H@`$=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,`1W)O
M=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<P!'<F]U<',`1W5A
M9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'=65S="!097)M:7-S
M:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A4
M34P`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA
M<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE
M+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!
M;&=O<FET:&T`2&%Z90!(96%D97(`2&5A9&5R<P!(96%R9"!)<VQA;F0@86YD
M($UC1&]N86QD($ES;&%N9',`2&5A=GD@5"U3=&]R;0!(96)R97<@*$E33RTX
M.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R
M`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE
M.@!(:6=H`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO
M;64`2&]M92!!9&1R97-S`$AO;64@1&ER96-T;W)Y`$AO;64@4&AO;F4`2&]N
M9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!);G9A;&ED("5S
M(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L
M86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S`$AO<F1E
M+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E
M("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B)7,B
M`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S
M('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S`$AO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@
M;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E
M("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI
M<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92`B)7,B
M`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A
M;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2D`2&]W
M(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA
M;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@
M=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU;6ED:71Y.B``
M2'5M;W)I<W1S`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE
M9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M
M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@061D<F5S<P!)
M4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI
M;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`
M25]N<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N<R!F
M;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@
M:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@
M82!N97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN
M9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H
M:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S
M964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W
M86YT('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W
M<V5R+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!);6%G
M92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO
M860`26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`
M26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@
M86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@
M<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D
M<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN
M9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M871I
M;VX`26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92X`26YS97)T($-?
M;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L90!);G-E<G0@
M5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C
M;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU
M;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&%F
M=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E9F]R92!T
M:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C
M=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R
M<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N
M(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N
M97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R="!C96QL(&)E
M9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E
M`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R
M="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T97(`26YS97)T(')O
M=R!B969O<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E
M8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-
M;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE
M(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E
M9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D
M97(I+@!);G9A;&ED(%I)4"!D871A`$EN=F%L:60@87!P;&EC871I;VXN`$EN
M=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L
M:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA=`!)
M;G9A;&ED(&QI8V5N<V4@:V5Y+@!);G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D
M+@!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED
M+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E
M;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P87)T;F5R(&ED+@!);G9A;&ED('!R
M;V1U8W0@8V]D92X`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!R96-I<&EE
M;G0Z("(E<R(`26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S;W5R8V4@
M861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R>0!);G9E
M<G0@<V5L96-T:6]N`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)
M<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)
M<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A
M;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU
M<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F
M=`!*=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N
M>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+
M97)N96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME
M>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T
M<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E
M82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P
M=6)L:6,@;V8`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA
M7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L
M:6,`3&%S="!(86QF`$QA<W0@4&%S<W=O<F0@0VAA;F=E`$QA<W0@475A<G1E
M<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S
M(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,87EO=70`
M3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F="!H
M96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,979E;`!,:6)E<FEA`$QI8GEA
M;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$<FEZ>FQE
M`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`
M3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG
M:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK`$QI;FL@
M<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP
M;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,
M:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`
M3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES
M="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S
M8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('-E<W-I;VYS(&9A:6QE
M9#H@)7,`3&ES=&EN9R!U<V5R<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@
M:7,@9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`
M3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`
M3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;@!,;V<@;W5T`$QO9VEN`$QO
M9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@
M;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A
M:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E<G,`
M3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU>&5M
M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO
M(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L
M878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@061M
M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L
M:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V
M92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@
M=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M87``36%P475E<W0@;6%P
M`$UA<'!I;F=S('-T;W)E9"X`36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N
M+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP
M;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`
M36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO
M=V5D(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T
M96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-
M87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS`$UA>&EM=6T@;&5N9W1H
M`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!M;V1E.@!-97)G
M92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY
M(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E
M<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-971A<B!7
M96%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K
M(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@
M=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"X`
M365T:&]D`$UE=&AO9"`B)7,B(&ES(&YO="!D969I;F5D`$UE=&AO9"!N;W0@
M9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,`365T<FEC`$UE>&EC;P!-:6-R
M;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`
M36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R
M<SH@`$UI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960`
M36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A8VMA9V4@2%14
M4%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O
M(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L
M:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E<75I<F5D
M(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO
M8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y(%523`!-
M;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-
M;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`
M36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E
M9"`E9"X`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T
M;'D@4W5N;GD`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@
M57``36]V92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT:2UL979E;"!D
M<F]P(&1O=VX@;&ES=',`375L=&EM87`@54L@;6%P`$UU;'1I<&QE('-E;&5C
M=&EO;@!->2!!8V-O=6YT`$UY($%C8V]U;G0@26YF;W)M871I;VX`37D@4&]R
M=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R
M964`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE
M<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!
M(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A
M<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A
M<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE
M;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE
M=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-97-S86=E('1O("5S`$YE
M=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE
M=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N`$YE
M=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE=R!W:6YD;W<@*%]B;&%N:RD`
M3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T(%!H87-E<P!.97AT(&]P=&EO
M;G,`3F5X=#X`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.
M;P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF
M9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN
M9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI
M<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M
M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E
M+@!.;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N
M`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO
M(&EC;VYS(&9O=6YD+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&QO8V%T:6]N
M('!R;W9I9&5D+@!.;R!M97-S86=E('-U<'!L:65D+@!.;R!N86UE('-P96-I
M9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@;V9F96YS:79E(&9O<G1U
M;F5S`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A
M=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@
M875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@
M875T:&5N=&EC871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y
M('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O
M('=O<FL@=VET:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`
M3F\@<75O=&$@<V5T+@!.;R!R=6QE<P!.;R!S97!A<F%T;W(@<W!E8VEF:65D
M+@!.;R!S:61E<P!.;R!S=6-H(&9I;&4`3F\@=&5M<&]R87)Y(&1I<F5C=&]R
M>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R;F%M92!A;F0O;W(@<&%S
M<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L
M=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO
M;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD
M(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T
M:6]N+@!.;VYE`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U
M.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T
M:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F
M;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT960N`$YO="!S970`
M3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A
M8VLN`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB
M97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C
M:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/
M8FIE8W0`3V)J96-T($-R96%T;W(`3V-T86P`3V-T;V)E<@!/9F9E;G-E(&9I
M;'1E<@!/9F9I8V4`3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF
M9F5R96YT+@!/;&0@<&%S<W=O<F0`3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R
M96-T+@!/;6%N`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O
M;&1E<G,N`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL
M(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D
M;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R
M;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E
M;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE
M9"!3+TU)344@<&%R="X`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O
M=P!/<&5R871I;F<@4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D
M97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R
M9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN
M86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/
M=VYE<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V
M86EL86)L92X`4$5!4CHZ36%I;"!B86-K96YD`%!'4"!$:6=I=&%L(%-I9VYA
M='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I
M9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG
M:'0@4F%I;@!032!286EN`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H
M;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!/4TE8(&5X=&5N<VEO;B!I<R!M
M:7-S:6YG`%!?2%`@4VAE;&P`4&%D9&EN9P!086MI<W1A;@!086QA=0!086QE
M<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@
M1W5I;F5A`%!A<F%G=6%Y`%!A<G1L>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O
M<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN`%!A<W-W;W)D(&EN8V]R<F5C=`!0
M87-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!0
M87-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z
M(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP
M8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E
M<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO
M;B`B)7,B(&YO="!D96QE=&5D+@!097)M:7-S:6]N($1E;FEE9`!097)M:7-S
M:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O
M<FUA=&EO;@!097)U`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I
M=&-A:7)N`%!I>&5L<P!0;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O
M;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V
M92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@
M=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@
M86YD(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C
M871E9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE
M87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D
M87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`
M4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A
M<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@
M<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@
M=&AE('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@='EP92!T:&4@
M;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T
M=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F
M('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D
M(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@
M`%!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4`4')E9G-?;&1A<#H@4F5Q=6ER
M960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N.B!2
M97%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S=7)E
M`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0
M<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@;W!T
M:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L
M96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T('1E>'0`4'5B;&EC($ME
M>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,@2V5Y($EN9F\`4'5B;&EC
M+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`
M4'5E<G1O(%)I8V\`46%T87(`475E<GD`475O=&$`4E-!(%!U8FQI8R!+97D@
M*"5D(&)I="D`4F%D:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%87)L>0!286EN
M($QA=&4`4F%I;B!3:&]W97(`4F%I;B!A;F0@4VYO=P!286EN('1O(%-N;W<`
M4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E86QL
M>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N
M`%)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P
M97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2961O97,@>6]U<B!L87-T(&%C
M=&EO;@!2969R97-H`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.@!2
M969R97-H(%!O<G1A;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O=W-E
M<@!296QO860`4F5M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH
M='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!"
M;&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!P
M86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A
M<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@9G)O
M;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E
M<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D
M93H@`%)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q
M=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN
M`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A
M=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R
M871I;VXN`%)E<75I<F5D($9I96QD`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E
M<V5T(%EO=7(@4&%S<W=O<F0`4F5S=&]R92!,87-T(%%U97)Y`%)E<W5L=',`
M4F5T=7)N('1O($]P=&EO;G,`4F5T>7!E(&YE=R!P87-S=V]R9`!2975N:6]N
M`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N
M<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?
M=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T
M92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R
M=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L
M;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@
M8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O
M;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP
M=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`
M4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S
M<V%G:6YG`%-13"!3:&5L;`!344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K
M=7!S`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A
M:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@
M86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S
M`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE
M(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA
M`%-A=F4`4V%V92`B)7,B`%-A=F4@)7,`4V%V92!/<'1I;VYS`%-A=F4@9V5N
M97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@
M<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG
M=7)A=&EO;BX`4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N
M`%-C871T97)E9"!4+5-T;W)M<P!38VEE;F-E`%-E87)C:`!396%R8V@@16YG
M:6YE<P!396QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U
M<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!3
M96QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL`%-E;&5C="!A;&P@9&%T
M92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C="!N;VYE`%-E
M;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B
M96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T
M:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE
M8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W
M86YT('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L
M96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L
M9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E
M9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3
M`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N
M96=R;P!397)I86P@3G5M8F5R`%-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A
M=F%I;&%B;&4N`%-E<W-I;VX@061M:6X`4V5S<VEO;B!)1"!E>'!I<F5D+@!3
M97-S:6]N<P!3970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T
M('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@
M<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y
M;W5R('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE
M>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI
M8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T
M:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I
M<'1S(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H
M('1H92!P87)A;65T97(Z(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T(%-U
M;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@
M;&EN:W,_`%-H;W<`4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L
M>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N
M+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@
M;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO=R!T86)L
M92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H
M92!L969T/P!3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G
M`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A
M8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P
M97)T:65S(&1I86QO9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R
M;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H<FEN
M:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F
M('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E
M`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN
M=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N
M;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S($QA
M=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@`%-O
M;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!O<F1E
M<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O=71H
M($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@
M4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P
M86-E(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT
M96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG
M(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP
M=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3
M<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE87(`4W1A=&4@
M;W(@4')O=FEN8V4`4W1A='5S`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R
M97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R:7`@9&]M86EN(&9R
M;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B9&ER96-T;W)Y("(E
M<R(@;F]T(&9O=6YD+@!3=6)J96-T`%-U8FUI=`!3=6)M:71T960@<F5Q=65S
M="!T;R!A9&0@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I
M;B!U;G1I;"!Y;W5R(')E<75E<W0@:&%S(&)E96X@87!P<F]V960N`%-U8G-C
M<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!A9&1E9"`B)7,B('1O('1H92!S
M>7-T96TN`%-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@(B5S
M(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N
M`%-U8V-E<W-F=6QL>2!R96UO=F5D("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3
M=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O
M('-E92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I
M9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I
M9W5R871I;VX@9FEL92`E<RX`4W5C8V5S<V9U;&QY('5P9&%T960@(B5S(@!3
M=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3
M=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@
M`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE
M`%-U<FYA;64`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E
M9&5N`%-W:71Z97)L86YD`%-Y;F,@;&]G(&1E;&5T960`4WEN8TU,`%-Y;G1A
M>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`
M5"U3=&]R;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%
M87)L>0!44U8@9FEL90!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE(%-E
M=`!486)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F
M($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O
M9@!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S
M="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP97)A='5R
M93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E("(E<R(@
M;F]T(&9O=6YD+@!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E>'0@
M3VYL>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA
M:6QA;F0`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE
M($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+@!4:&4@2&]R9&4O2V]L86(@
M:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@
M24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@36%I;G1E
M;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/
M<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI
M<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES
M<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N
M`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C;VYT86-T($E$(&YU;6)E<B!W
M87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD
M(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL
M>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'
M4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S
M:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E
M:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@
M:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO
M="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@
M82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L9"!C
M;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A
M:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE
M9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H
M92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O
M<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N
M('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U
M92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R
M:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA
M>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O
M=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I
M="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R
M;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA
M=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL
M('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N
M=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED
M92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@
M8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G
M92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N
M(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S
M<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O
M('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;G5M
M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H92!O<&5N<W-L(&UO
M9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@
M8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D
M(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A
M8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T
M>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<75O
M=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H
M92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH86YD('-I
M9&4@;VYL>0!4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R
M86-T97(N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@
M<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S
M="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@
M*"5D*2!D;V5S(&YO="!E>&ES="X`5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@
M9&]E<R!N;W0@97AI<W0N`%1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@
M;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BX`5&AE('1O<"!A;F0@8F]T
M=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D
M(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U
M<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE('=E871H97(N
M8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H96UE<R!D:7)E8W1O<GD@
M(B5S(B!N;W0@9F]U;F0N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L
M92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I
M;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@
M9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU
M<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D
M9&EN9R`B)7,B('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L
M96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E
M;3H@`%1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H
M92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z
M("5S`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@
M;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY
M('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L
M87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE
M9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P
M97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I
M;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T
M<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI<R!)
M34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`
M5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV
M92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL
M92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB
M97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO
M+W=I;G!L8RYC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H
M92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A
M;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U
M:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@*&AT
M='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD
M(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I
M96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O
M9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N
M`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@
M4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F
M;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4
M:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES
M(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N
M9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L
M:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`5&AI
M<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I
M(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@
M;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A
M;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T
M:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN
M9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU
M;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4
M:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O;'1I
M<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H
M92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI
M8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`
M5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871I
M;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI
M<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`
M5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO
M:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E
M;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR86EN90!5;F%B
M;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT
M<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T
M;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE
M('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA
M8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ
M92!O9B`B)7,B+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R\E
M<R(N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T
M;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`
M56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T
M;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@
M9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R("(E<R(N`%5N86)L
M92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R
M97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R
M>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N
M86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T
M;R!D96QE=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&
M4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N
M="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E
M=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N
M86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`
M56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R
M97-S960@87)C:&EV92X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S
M:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I
M;&53:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@9FEL93H@`%5N86)L
M92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E
M;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI
M<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!6
M1E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S
M+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M
M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE
M;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W
M<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET
M92!61E,@9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U
M;W1A('=I;&P@8F4@97AC965D960N`%5N9&5R;&EN90!5;F1O($-H86YG97,`
M56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F
M<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS
M92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N
M:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T
M97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S
M`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5
M;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@
M;&]C871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O
M<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV
M:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P
M<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/
M2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC
M:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T
M:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E;G-I
M;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N
M`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@
M87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@
M;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E
M($-U<G)E;G0Z("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@
M9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R("5S(&ES(&YO
M="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R
M($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@
M:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<B!A8V-O=6YT
M(&YO="!F;W5N9`!5<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L<F5A9'D@97AI
M<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M
M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A
M8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I
M='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=64@:7,@;W9E<B!T
M:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E<P!686QU97,@=&\@<V5L
M96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T
M:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E
M<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L
M:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T
M($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E
M<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET
M:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET
M>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!2
M14U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=)3B!V:6$@2%144`!7
M86QL:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`
M5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@
M4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S
M`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!7
M97-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P
M;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C
M=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H97)E:7,@075S
M=')A;&EA(&UA<`!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B
M;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!I;B!#
M4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A
M:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L
M90!7:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD
M('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5VES:&QI<W0`
M5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7<F]N9R!N=6UB97(@;V8@
M9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O
M;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+@!7
M<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+@!8+5)E
M9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D($ME
M>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV
M,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9
M`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@22!!9W)E
M90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@
M=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@86QL;W=E
M9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RX`66]U(&%R92!N;W0@
M875T:&5N=&EC871E9"X`66]U(&-A;FYO="!H879E('1H92`G7"<@8VAA<F%C
M=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A
M;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@
M9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F
M:65L9',@:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA
M=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@
M;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N
M86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@
M=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@
M=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K
M96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U
M(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@
M=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E
M;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A
M('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E
M<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R
M9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W4@
M;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R`%EO=7(@
M)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9
M;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN
M9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S
M:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O
M=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U
M<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S
M=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@=7-E($AO<F1E
M('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@
M9&EF9F5R96YT(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0N`%EO=7(@875T:&5N
M=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E
M<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE
M(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C
M:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N
M+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G
M86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U
M<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@
M;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R:6YT+@!9
M;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='D@
M:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R
M(&9U;&P@;F%M93H`66]U<B!L;V=I;B!H87,@97AP:7)E9"X`66]U<B!N97<@
M<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO
M=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H
M87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C
M:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S
M=V]R9"X`66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"X`66]U<B!R96UO=&4@
M<V5R=F5R<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP
M<'D`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@
M475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;
M;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4<F5E
M`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N
M+BX`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`
M7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4V5T=7``7U1A8FQE(%!R
M;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!A9&1R97-S964@=6YK
M;F]W;@!C86QE;F1A<@!C86QM`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4`
M8V%N;F]T(&]P96X@:6YP=70`8VQI8VL@:&5R90!C;VUM86YD(&QI;F4@=7-A
M9V4@97)R;W(`8V]N9FEG=7)A=&EO;B!E<G)O<@!C<FET:6-A;"!S>7-T96T@
M9FEL92!M:7-S:6YG`&1A=&$@9F]R;6%T(&5R<F]R`&5D:70`96YT<GD@;F]T
M(&9O=6YD`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S
M`&=U<W1I;F<`:#H`:&@`:&]S="!N86UE('5N:VYO=VX`:6UM961I871E`&EN
M;&EN90!I;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A<F4@97)R
M;W(`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@
M25-/+@!M;0!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N
M=&5D`&YO=&5P860`<&5R8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`
M<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L`')I<VEN9P!S97)V:6-E('5N879A
M:6QA8FQE`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-S
M`'-T96%D>0!S>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL
M=7)E`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE
M9`!U;FYA;65D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R
M;VIE8W0M260M5F5R<VEO;CH@2&]R9&4*4F5P;W)T+4US9VED+4)U9W,M5&\Z
M(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M
M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`V+3`R+3$U
M(#$V.C4P+3`R,#`*3&%S="U4<F%N<VQA=&]R.B!&86)I;R!';VUE<R`\9FQG
M;VUS0'5O;"YC;VTN8G(^"DQA;F=U86=E+51E86TZ($)R87II;&EA;B!0;W)T
M=6=U97-E(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q
M+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y
M+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`I8+4=E;F5R871O
M<CH@2T)A8F5L(#$N,RXQ"E!L=7)A;"U&;W)M<SH@(&YP;'5R86QS/3([('!L
M=7)A;#TH;B`^(#$I.PH`("@E<R!D:6%S(&%T<N%S*0`@*%1E8VQA(&1E($%T
M86QH;R`E<RD`("AE;2`E<R!D:6%S*0`@*&AO:F4I`"`H86UA;FCC*0`@*&]N
M=&5M*0`@82``(B5S(B!.XV\@Z2!U;2!D:7)E=/-R:6\N`"<E<R<@;N-O(.D@
M=6UA(&5S8V]L:&$@=N%L:61A+@`G)7,G(&[C;R!E<W3A(&-O;F9I9W5R861O
M(&YO(%)E9VES=')O(&1O($AO<F1E+@!R96YD97)I>F%D;W(@9&4@X7)V;W)E
M("(E<R(@;N-O(&5N8V]N=')A9&\N`"(E<R(@9F]I(&%D:6-I;VYA9&\@86\@
M<VES=&5M82!D92!G<G5P;W,N`"(E<R(@9F]I(&%D:6-I;VYA9&\@86\@<VES
M=&5M82!D92!P97)M:7-S]65S+@`B)R5S(B!NXV\@9F]I(&-R:6%D;SH@)7,N
M`"4N,F9-0B!U<V%D;W,@9&4E+C)F34(@<&5R;6ET:61O<R`H)2XR9B4E*0`E
M9"`E<R!E("5S`"5D(&1I87,@873I('-U82!S96YH82!E>'!I<F%R+@`E9"!P
M<F5V:7/C;R!D;R!D:6$`)7,@+2!!=FES;P!);7!R97-SXV\@1&EG:71A;"!D
M92`E<P`E<R!+0@`E<R!/<&5R8>?U97,@9&4@36%N=71E;N?C;R`M($-O;F9I
M<FUAY^-O`$-O;F9I9W5R8>?C;R!D92`E<P!#861A<W1R;R!D92`E<P`E<R!4
M97)M;W,@9&\@06-O<F1O`"5S(&KA(&5X:7-T92X`)7,@82`E<R`E<P`E<R!E
M<W3A('!R;VYT;R!P87)A(&5X96-U=&%R(&%S(&]P97)AY_5E<R!D92!M86YU
M=&5NY^-O(&UA<F-A9&%S(&%B86EX;RX@36%R<75E(&$@8V%I>&$@<&%R82!Q
M=6%L<75E<B!O<&5R8>?C;R!Q=64@=F]CZB!Q=65I<F$@97AE8W5T87(@9&5S
M=&$@=F5Z+@`E<R#I(&]B<FEG873S<FEO`"5S(&UI;G5T;W,`)7,@;N-O(&5N
M8V]N=')A9&\N`"5S(&$@)7,@9&4@)7,`0V%TX6QO9V\@9&4@16YD97)EYV]S
M(&1E("5S`$%G96YD82!D92`E<P!!;F]T8>?U97,@9&4@)7,`3&ES=&$@9&4@
M5&%R969A<R!D92`E<P`E<SH@)7,`)7,Z($5S=&$@;65N<V%G96T@<&]D92!N
MXV\@<V5R(&1E('%U96T@96QA(&1I>B!S97(N(%1O;64@8W5I9&%D;R!C;VT@
M<75A;'%U97(@;&EN:R!P<F5S96YT92!N96QA(&]U(&5M(&9O<FYE8V5R(&%O
M(')E;65T96YT92!Q=6%L<75E<B!I;F9O<FUAY^-O('!E<W-O86PN`"P@8G)I
M<V$@`"P@8G)I<V$@)7,@)7,`+"!V87)IX79E;"!D92`E<R!P87)A("5S`"TM
M('-E;&5C:6]N92`M+0!&;W)M871O(#$R($AO<F%S`$9O<FUA=&\@,C0@2&]R
M87,`,C0@:&]R87,`/%#A9VEN82!!;G1E<FEO<@!5;2!C;VYE8W1O<B!D92!B
M86YC;R!D92!D861O<R#I(&]B<FEG873S<FEO('!A<F$@97-T92!B;&]C;RX`
M56T@97)R;R!F871A;"!O8V]R<F5U`%5M82!C:&%V92!P^F)L:6-A(%!'4"#I
M(&]B<FEG873S<FEA('!A<F$@8W)I<'1O9W)A9F%R('5M82!M96YS86=E;2X`
M56UA(&-H879E('#Z8FQI8V$@4$=0(.D@;V)R:6=A=/-R:6$@<&%R82!V97)I
M9FEC87(@=6UA(&UE;G-A9V5M(&%S<VEN861A+@!5;6$@8VAA=F4@<')I=F%D
M82!01U`@92!U;6$@<V5N:&$@<^-O(&]B<FEG873S<FEA<R!P87)A(&1E<V-R
M:7!T;V=R869A<B!U;6$@;65N<V%G96TN`%5M82!C:&%V92!P<FEV861A(%!'
M4"!E('5M82!S96YH82!SXV\@;V)R:6=A=/-R:6%S('!A<F$@87-S:6YA<B!U
M;6$@;65N<V%G96TN`%5M82!C:&%V92!P^F)L:6-A(%,O34E-12P@=6UA(&-H
M879E('!R:79A9&$@4R]-24U%(&4@=6UA('-E;FAA('/C;R!O8G)I9V%T\W)I
M87,@<&%R82!D97-C<FEP=&]G<F%F87(@=6UA(&UE;G-A9V5M+@!5;6$@8VAA
M=F4@</IB;&EC82!3+TU)344L('5M82!C:&%V92!P<FEV861A(%,O34E-12!E
M('5M82!S96YH82!SXV\@;V)R:6=A=/-R:6%S('!A<F$@87-S:6YA<B!U;6$@
M;65N<V%G96TN`%5M82!C:&%V92!P^F)L:6-A(%,O34E-12#I(&]B<FEG873S
M<FEA('!A<F$@8W)I<'1O9W)A9F%R('5M82!M96YS86=E;2X`3G5V96YS(&UA
M='5T:6YA<P!#:'5V82!&<F%C82!697-P97)T:6YA`$-H=79A(&UA='5T:6YA
M`$-H=79A<R!M871U=&EN87,`3F5V87-C87,@36%T=71I;F%S`$%-+U!-`$%0
M22!)1`!3;V)R92!E<W1E(&5D:71O<@!3;V)R92XN+@!!8G-B;W1T;VT`06)S
M;6ED9&QE`$%C97-S;R!N96=A9&\@86\@8W)I87(@9&ER973S<FEO(%9&4RX`
M06-E<W-O(&YE9V%D;R!A;R!C<FEA<B!A<G%U:79O(%9&4RX`4W5A<R!);F9O
M<FUAY_5E<P!396YH82!D82!#;VYT80!#;VYT82!D97-A=&EV861A+@!#;VYT
M87,`061I8VEO;F%R`$%D:6-I;VYA<B!'<G5P;R!3=6)O<F1I;F%D;P!!9&EC
M:6]N87(@4&5R;6ES<_5E<R!3=6)O<F1I;F%D87,`061I8VEO;F4@07%U:3H`
M061I8VEO;F%R($YO=F\@1W)U<&\`061I8VEO;F%R($YO=F$@4&5R;6ES<^-O
M`$%D:6-I;VYA<B!U;2!G<G5P;R!S=6)O<F1I;F%D;R!A("<E<R<`061I8VEO
M;F%R('5M82!P97)M:7-SXV\@<W5B;W)D:6YA9&$@82`G)7,G`$%D:6-I;VYA
M<B!U;2!N;W9O('5S=>%R:6\Z`$%D:6-I;VYA<B!C;VQU;F$`061I8VEO;F%R
M(&YO=F]S(&UE;6)R;W,`061I8VEO;F%R('!A<@!!9&EC:6]N87(@;R!-96YU
M("5S(&-O;6\@=6UA($)A<G)A($QA=&5R86P@9&\@36]Z:6QL80!!9&EC:6]N
M87(@86\@8V%TX6QO9V\@9&4@96YD97)EYV]S.@!!9&EC:6]N87(@86\@;65U
M(&-A=.%L;V=O(&1E(&5N9&5R9>=O<P!!9&EC:6]N87(@=7-UX7)I;P`G)7,G
M(&%D:6-I;VYA9&\@86\@<VES=&5M82P@;6%S(&[C;R!P=61E(&EN8VQU:7(@
M:6YF;W)M8>?U97,@861I8VEO;F%I<R!D;R!C861A<W1R;SH@)7,N`"5S(&%D
M:6-I;VYA9&\@86\@<VES=&5M82X@5F]CZB!P;V1E('-E(&-O;F5C=&%R(&%G
M;W)A+@!!9&GGXV\@9&4@=7-UX7)I;W,@97-TX2!D97-A8FEL:71A9&$N`$5N
M9&5R9>=O`$-A=.%L;V=O(&1E($5N9&5R9>=O<P!!9&UI;FES=')A<B`M(&-O
M;F9I9W5R82!P97)M:7-S]65S('!A<F$@;W5T<F]S('5S=>%R:6]S`$%D;6EN
M:7-T<F'GXV\`06[Z;F-I;W,`069E9V%N:7-TXV\`06QBXFYI80!!<F?I<FEA
M`$%P96QI9&\`06QI;FAA<@!!;&EN:&%M96YT;SH`5&]D;W,`5&]D;W,@57-U
MX7)I;W,@075T96YT:6-A9&]S`%1O9&]S($=R=7!O<P!4;V1A<R!097)M:7-S
M]65S`%1O9&]S('%U871R;R!L861O<P!097)M:71I<B!M^FQT:7!L;W,@96YD
M97)EYV]S`%!E<FUI=&ER(&-O;F9I9W5R87(@;R!T:7!O(&1E(&QI<W1A<R!O
M<F1E;F%D87,_`$KA(&5X:7-T90!,;V=I;B!)35-0($%L=&5R;F%T:79O`%-E
M;FAA($E-4U`@06QT97)N871I=F$`57-UX7)I;R!)35-0($%L=&5R;F%T:79O
M`$5N9&5R9>=O(&1E(&4M;6%I;"!A;'1E<FYA=&EV;P!-;V1E;&]S(&%L=&5R
M;F%T:79O<P!497AT;R!A;'1E<FYA=&EV;SH`4V%M;V$@06UE<FEC86YA`%5M
M('9A;&]R(&EL96=A;"!F;VD@97-P96-I9FEC861O+@!/8V]R<F5U('5M(&5R
M<F\@9&5S8V]N:&5C:61O+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!0<F]X
M>2!A;O1N:6UO`%)E<W!O<W1A`$%N=.%R=&ED80!!;G1I9W5A(&4@0F%R8F%D
M;W,`07!L:6-AY^-O`$QI<W1A(&1E($%P;&EC8>?U97,`02!A<&QI8V'GXV\@
M97-TX2!P<F]N=&$N`$%P;&EC87(@86]S($-O;7!A<G1I;&AA;65N=&]S(%-U
M8F]R9&EN861O<P!!<')O=F%R`%1A;6%N:&\@07!R;WAI;6%D;P!!8G)I;`!!
M<N%B:6-O("A7:6YD;W=S+3$R-38I`%1A;6%N:&\@9&\@07)Q=6EV;P!.;VUE
M(&1O($%R<75I=F\`5F]CZB!T96T@8V5R=&5Z82!Q=64@<75E<B!R96UO=F5R
M(&$@<V]L:6-I=&'GXV\@9&4@8V%D87-T<F\@9&4@)7,_`%9O8^H@=&5M(&-E
M<G1E>F$@<75E(&1E<V5J82!E>&-L=6ER("<E<R<@92!S975S('-U8F=R=7!O
M<S\`07)G96YT:6YA`$%R;>IN:6$`07)MZFYI;R`H05)-4T-)22TX*0!!<G1E
M`$%R=6)A`$EL:&$@07-C96YSXV\`07)T92!!<V-I:0#!<VEA+U)E9VGC;R!D
M;R!086/M9FEC;P!3;VQI8VET87(@8V]N9FER;6'GXV\@86YT97,@9&4@97AE
M8W5T87(@87,@;W!E<F'G]65S(&1E(&UA;G5T96[GXV\_`$-O;'5N87,@9&4@
M9&5S:6=N8>?C;P!496YT;W4@97AC;'5I<B!U;2!G<G5P;R!I;F5X:7-T96YT
M92X`5&5N=&]U(&5X8VQU:7(@=6UA('!E<FUI<W/C;R!NXV\@97AI<W1E;G1E
M+@!496YT;W4@961I=&%R('5M82!P97)M:7-SXV\@;N-O(&5X:7-T96YT92X`
M5&5N=&]U(&5D:71A<B!U;2!C;VUP87)T:6QH86UE;G1O(&[C;R!E>&ES=&5N
M=&4N`$%T<FEB=71O<P!!9V]S=&\`075S='+A;&EA`,%U<W1R:6$`075T:%]C
M>7)S<6PZ($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O(&EM87`@;F5C
M97-SX7)I82X`075T:%]C>7)U<SH@3R!C;VYE8W1O<B!NXV\@<&]S<W5I(&%S
M(&-A<&%C:61A9&5S(&YE8V5S<^%R:6%S+@!!=71H7V-Y<G5S.B!.XV\@9F]I
M(&5N8V]N=')A9&$@82!E>'1E;G/C;R!I;6%P(&YE8V5S<^%R:6$N`$%U=&A?
M9G1P.B!.XV\@9F]I(&5N8V]N=')A9&$@82!E>'1E;G/C;R!&5%`@;F5C97-S
MX7)I82X@0V]M<&EL92!O(%!(4"!C;VT@82!O<.?C;R`M+65N86)L92UF='`N
M`$%U=&A?:6UA<#H@3N-O(&9O:2!E;F-O;G1R861A(&$@97AT96YSXV\@:6UA
M<"!N96-E<W/A<FEA+@!!=71H7VMR8C4Z($[C;R!F;VD@96YC;VYT<F%D82!A
M(&5X=&5N<^-O(&MR8C4@;F5C97-SX7)I82X`075T:%]L9&%P.B!);F-L=7/C
M;R!D92!U<W7A<FEO<R!NXV\@Z2!S=7!O<G1A9&$@<&%R82!!8W1I=F4@1&ER
M96-T;W)Y`$%U=&A?;&1A<#H@17AC;'5SXV\@9&4@=7-UX7)I;W,@;N-O(.D@
M<W5P;W)T861A('!A<F$@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z($[C
M;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O($Q$05`@;F5C97-SX7)I82X`
M075T:%]L9&%P.B!);7!O<W/M=F5L(&%D:6-I;VYA<B!O('5S=>%R:6\@)7,N
M($ES=&\@9F]I(&\@<75E(&\@<V5R=FED;W(@<F5P;W)T;W4Z(`!!=71H7VQD
M87`Z($EM<&]S<^UV96P@<F5M;W9E<B!O('5S=>%R:6\@)7,`075T:%]L9&%P
M.B!);7!O<W/M=F5L(&%T=6%L:7IA<B!O('5S=>%R:6\@)7,`075T:%]L9&%P
M.B!!='5A;&EZ8>?C;R!D92!U<W7A<FEO<R!NXV\@Z2!S=7!O<G1A9&$@<&%R
M82!!8W1I=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ($[C;R!F;VD@96YC;VYT
M<F%D82!A(&5X=&5N<^-O($U#04P@;F5C97-SX7)I82X`075T:%]S;6)A=71H
M.B!.XV\@9F]I(&5N8V]N=')A9&$@82!E>'1E;G/C;R!S;6)A=71H(&YE8V5S
M<^%R:6$N`$%U=&5N=&EC8>?C;R!N;R!S97)V:61O<B!)34%0(&9A;&AO=2X`
M1F%L:&$@;F$@875T96YT:6-AY^-O`$9A;&AA(&YA(&%U=&5N=&EC8>?C;SH@
M)7,`075T96YT:6-AY^-O(')E:F5I=&%D82!P96QO('-E<G9I9&]R(%)!1$E5
M4RX`02!A=71E;G1I8V'GXV\@;F\@<V5R=FED;W(@1E10(&9A;&AO=2X`02!A
M=71E;G1I8V'GXV\@;F\@<V5R=FED;W(@4TU"(&9A;&AO=2X`0V%M<&]S(&1I
M<W!O;NUV96ES.@!!>F5R8F%I:N-O`$1E<V-U;'!A<R!D;R!"3T9(`$9U;F1O
M`$-O<B!D92!&=6YD;P!396YH82!K97)B97)O<R!I;F-O<G)E=&$N`%5S=>%R
M:6\@:V5R8F5R;W,@:6YC;W)R971O+@!"86AA;6%S`$)A:')A:6X`0N%L=&EC
M;R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`3N-O(&9O:2!E
M;F-O;G1R861O(&\@9&ER973S<FEO(&)A<V4@9&4@:6UA9V5N<R`G)7,G+@!,
M:6YH82!D92!087)T:61A`$)E;&]R^G-S:6$`0NEL9VEC80!"96QI>F4`0F5N
M:6X`0F5R;75D87,`0G5TXV\`06YI=F5R<^%R:6\`3N-O(&9O:2!E;F-O;G1R
M861O(&\@8FQO8V\@(B5S(B!D82!A<&QI8V'GXV\@(B5S(BX`0V]N9FEG=7)A
MY_5E<R!D;R!";&]C;P!4:7!O(&1E($)L;V-O`$YE9W)I=&\`0F]L[79I80!&
M879O<FET;W,`0F]R9&$`3&%R9W5R82!D82!B;W)D83H`0F]R9&%S`$+S<VYI
M82!E($AE<GIE9V]V:6YA`$%M8F]S`$)O='-U86YA`%)O9&%PZ0!);&AA($)O
M=79E=`!"<F%S:6P`5&5R<FET\W)I;R!D;R!/8V5A;F\@S6YD:6-O($EN9VSJ
M<P!"<G5N96D`0G5L9^%R:6$`3&ES=&$@8V]M($UA<F-A9&]R97,`0G5R:VEN
M82!&87-O`$)U<G5N9&D`0TU3`$-20P!0;VYT;W,@9&4@1&ES=')I8G5IY^-O
M($-23`!0<F]P<FEE9&%D97,@9&$@0^E?;'5L82XN+@!!(&QI<W1A(&1E(&1I
M<W1R:6)U:>?C;R!NXV\@9F]I(&5S<&5C:69I8V%D82X`06=E;F1A`$-A;&UO
M`$-A;6)O9&IA`$-A;6%R]65S`$[C;R#I('!O<W/M=F5L(&=E<F%R('5M82!N
M;W9A('-E;FAA(&%U=&]M871I8V%M96YT92P@96YT<F4@96T@8V]N=&%T;R!C
M;VT@;R!A9&UI;FES=')A9&]R+@!.XV\@8V]N<VEG;R!G<F%V87(@;R!A<G%U
M:79O("(E<R(`3N-O(.D@<&]S<^UV96P@861M:6YI<W1R87(@9V5R96YC:6%D
M;W)E<R!E>'1E<FYO<R!D92!S97-SXV\N`$[C;R#I('!O<W/M=F5L(&-O;F5C
M=&%R(&%O('-E<G9I9&]R($E-05`Z("5S`$[C;R!C;VYS:6=O(&%B<FER(&\@
M87)Q=6EV;R`B)7,B+@!#86YA9.$`0V%N8V5L87(`0V%N8V5L87(@4F5L873S
M<FEO(&1E(%!R;V)L96UA`$[C;R#I('!O<W/M=F5L(&5X8VQU:7(@;R!A<G%U
M:79O("(E<R(N`$[C;R#I('!O<W/M=F5L(&5N8V]N=')A<B!U;2!D:7)E=/-R
M:6\@=&5M<&]RX7)I;RX`3N-O(.D@<&]S<^UV96P@8V]N=&EN=6%R('-E;2!O
M('!A<N)M971R;R`G=&%R9V5T1FEL92<N`$[C;R#I('!O<W/M=F5L(&5X8VQU
M:7(@;R!D:7)E=/-R:6\@(B5S(BX`3N-O(.D@<&]S<^UV96P@97AC;'5I<BP@
M)60@<&]S<W5I('-U8F]R9&EN861O<RX`3N-O(.D@<&]S<^UV96P@<F5O<F1E
M;F%R+"!N^FUE<F\@9&4@<F5G:7-T<F]S(&9O<FYE8VED;W,@<&%R82!R96]R
M9&5N87(@;N-O(&-O<G)E<W!O;F1E(&%O(&[Z;65R;R!A<FUA>F5N861O+@!.
MXV\@Z2!P;W-S[79E;"!R;W1E87(@;65N<V%G96T@<&%R82!O(&[Z;65R;R!E
M<W!E8VEF:6-A9&\N`$-A8F\@5F5R9&4`5.UT=6QO`$]P97)A9&]R80!#871E
M9V]R:6%S(&4@3F]M97,`26QH87,@0V%Y;6%N`%1E;&5F;VYE($-E;'5L87(`
M4')O<')I961A9&5S(&1A($/I;'5L80!-87)G96T@9&$@8^EL=6QA.@!0<F]P
M<FEE9&%D97,@9&$@0^EL=6QA`$5S<&'G86UE;G1O(&1A(&/I;'5L83H`5&5L
M969O;F4@8V5L=6QA<@!#Z6QT:6-O("A)4T\M.#@U.2TQ-"D`0V5N=')O`%)E
M</IB;&EC82!D82#!9G)I8V$@0V5N=')A;`!%=7)O<&$@0V5N=')A;"`H25-/
M+3@X-3DM,BD`1&5T86QH97,@9&\@0V5R=&EF:6-A9&\`4')O<')I973A<FEO
M(&1O($-E<G1I9FEC861O`%!O;.UT:6-A<R!D;R!#97)T:69I8V%D;P!48VAA
M9&4`06QT97)A<@!!;'1E<F4@4W5A(%-E;FAA`$%L=&5R87(@;R!N;VUE(&4@
M;R!E;F1E<F7G;R!Q=64@87,@<&5S<V]A<R!VZF5M('%U86YD;R!E;&%S(&SJ
M96T@92!R97-P;VYD96T@<W5A<R!M96YS86=E;G,N`$%L=&5R8>?C;R!D92!S
M96YH82!NXV\@Z2!S=7!O<G1A9&$@;F$@8V]N9FEG=7)AY^-O(&%T=6%L+B`@
M16YT<F4@96T@8V]N=&%T;R!C;VT@;R!A9&UI;FES=')A9&]R+@!#:&%R`%9E
M<FEF:6-A<B!,:6Y?:RXN+@!#:&EL90!#:&EN80!#:&ENZG,@4VEM<&QI9FEC
M861O("A'0C(S,3(I`$-H:6[J<R!4<F%D:6-I;VYA;"`H0FEG-2D`17-C;VQH
M82!A($%P;&EC8>?C;SH`17-C;VQH82!U;6$@<V5N:&$`17-C;VQH82!U;2!U
M<W7A<FEO`$5S8V]L:&$@8V]M;R!E>&EB:7(@9&%T87,Z`$5S8V]L:&$@;R!T
M:7!O(&1E(&5S=&EL;R!D92!L:7-T87,@*'!A<F$@;&ES=&%S(&]R9&5N861A
M<RD`26QH87,@0VAR:7-T;6%S`$[C;R!F;VD@96YC;VYT<F%D82!A(&1E9FEN
M:>?C;R!D92!C;&%S<V4@9&4@)7,N`$QI;7!A<@!,:6UP87(@=&%G<R!-4T]F
M9FEC90!%>&-L=6ER('5S=>%R:6\`17AC;'5I<B!U<W7A<FEO.B`E<P!%>&-L
M=6ER('5S=>%R:6\`17AC;'5I<B!D861O<R!D;R!U<W7A<FEO`$/I=2!A8F5R
M=&\@82!487)D90!#;&EQ=64@<&%R82!#;VYT:6YU87(`0VQI8VMA=&5L;"!V
M:6$@2%144`!&96-H87(@2F%N96QA`$YU=F5N<P!.=6)L861O('!E;&$@36%N
M:.,`3G5B;&%D;P!);&AA<R!D92!#;V-O<P!#;VYT<F%I<B!"87)R82!,871E
M<F%L`$-O;G1R86ER(&)O<F1A<P!#;VST;6)I80!#;W(`4&%L:&5T82!D92!#
M;W)E<P!396QEY^-O(&1E($-O<@!#;VQS.@!4[71U;&]S(&1A<R!#;VQU;F%S
M`%%U861R:6YH;W,`0V]M86YD;P!,:6YH82!D92!#;VUA;F1O`$-O;65N=&%R
M`$YO;64`0V]M;W)O<P!%;7!R97-A`$-O;7!U=&%D;W)E<P!#;VYD:>?C;P!#
M;VYD:>?U97,`1&EF97)E;N=A<R!D92!#;VYF:6=U<F'GXV\`0V]N9FEG=7)A
MY^-O(&1E('-I;F-R;VYI>F'GXV\@8V]M(%!$07,L(%-M87)T<&AO;F5S(&4@
M3W5T;&]O:RX`0V]N9FEG=7)AY^-O(&YE8V5S<VET82!D92!A='5A;&EZ8>?C
M;RX`0V]N9FEG=7)A<B`E<P!#;VYF:7)M92!A(%-E;FAA`$-O;F=O`$-O;F=O
M+"!297#Z8FQI8V$@1&5M;V-RX71I8V$@9&\`1F%L:&$@;F$@8V]N97CC;RX`
M1F%L:&$@;F$@8V]N97CC;SH@`$-O;F5XXV\@<F5C=7-A9&$@<&5L;R!S97)V
M:61O<B!D92!C:&%V97,@</IB;&EC87,N`$-O;F5XXV\@<F5C=7-A9&$@<&5L
M;R!S97)V:61O<B!D92!C:&%V97,@</IB;&EC87,N($UO=&EV;SH@)7,@*"5S
M*0!!(&-O;F5XXV\@86\@<V5R=FED;W(@1E10(&9A;&AO=2X`0V]N=&%T;W,`
M3W,@8V]N=&%T;W,@9F]R86T@861I8VEO;F%D;W,@8V]M('-U8V5S<V\@86\@
M<V5U(&-A=.%L;V=O(&1E(&5N9&5R9>=O<RX`5&EP92!D92!C;VYT9?ID;R!D
M;R!A<G%U:79O(&-O;7!R:6UI9&\Z(`!#;VYT9?ID;R!D92`G)7,G`$-O;G1I
M;G5A<@!);&AA<R!#;V]K`$-O;VMI90!#;W!I87(`1F%L:&$@;F$@8_-P:6$Z
M("5S`$-O<&EA<B!S96QEY^-O`$E$(&1E($-U<W1O`$-O<W1A(%)I8V$`0V]S
M=&$@9&\@36%R9FEM`$EM<&]S<^UV96P@8W)I<'1O9W)A9F%R(&$@;65N<V%G
M96T@8V]M(%!'4#H@`$EM<&]S<^UV96P@87-S:6YA<B!A(&UE;G-A9V5M(&-O
M;2!01U`Z(`!.XV\@9F]I('!O<W/M=F5L(&-R:7!T;V=R869A<B!A(&UE;G-A
M9V5M(&-O;2!3+TU)344N`$[C;R!F;VD@<&]S<^UV96P@87-S:6YA<B!A(&UE
M;G-A9V5M(&-O;2!3+TU)344N`$[C;R!F;VD@<&]S<^UV96P@861I8VEO;F%R
M(&-O;G1A=&\N("5S`$[C;R!F;VD@<&]S<^UV96P@8V]N96-T87(@86\@<V5R
M=FED;W(@3$1!4"X`3N-O(&9O:2!P;W-S[79E;"!V97)I9FEC87(@;R!S86QD
M;RX@)7,`26UP;W-S[79E;"!C;VYE8W1A<B!A;R!S97)V:61O<B!,1$%0+@!.
MXV\@9F]I('!O<W/M=F5L(&-O;F5C=&%R(&%O('-E<G9I9&]R("<E<R<@=71I
M;&EZ86YD;R!&5%`Z("5S`$[C;R!F;VD@<&]S<^UV96P@8W)I87(@82!L:7-T
M82!D92!D:7-T<FEB=6GGXV\N("5S`$EM<&]S<^UV96P@9&5S8W)I<'1O9W)A
M9F%R(&]S(&1A9&]S(%!'4#H@`$[C;R!F;VD@<&]S<^UV96P@9&5S8W)I<'1O
M9W)A9F%R(&\@9&%D;R!3+TU)344N`$[C;R!F;VD@<&]S<^UV96P@97AC;'5I
M<B!O(&-O;G1A=&\N("5S`$[C;R!F;VD@<&]S<^UV96P@97AC;'5I<B!A(&QI
M<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!E>&-L
M=6ER(&\@<V-R:7!T(&1E(&%T=6%L:7IAY^-O(&1E(&-O;F9I9W5R8>?C;R`G
M)7,G+@!.XV\@9F]I('!O<W/M=F5L(&1E=&5R;6EN87(@;R!E;F1E<F7G;R!D
M92!E+6UA:6P@9&\@9&5S=&EN873A<FEO+@!.XV\@9F]I('!O<W/M=F5L(&]B
M=&5R(&-O;7!L971A;65N=&4@;R!C873A;&]G;R!D92!E;F1E<F7G;W,N`$[C
M;R!F;VD@<&]S<^UV96P@;V)T97(@8V]M<&QE=&%M96YT92!A(&QI<W1A(&1E
M(&1I<W1R:6)U:>?C;RX`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!C;VUP;&5T
M86UE;G1E(&$@;&ES=&$@9&4@;&ES=&%S(&1E(&1I<W1R:6)U:>?C;RX`3N-O
M(&9O:2!P;W-S[79E;"!C87)R96=A<B!A(&5S=')A=.EG:6$@)R5S)RX`3N-O
M(&9O:2!P;W-S[79E;"!C<FEA<B!O(&1I<F5T\W)I;R`G)7,G+@!.XV\@9F]I
M('!O<W/M=F5L(&]B=&5R(&$@8VAA=F4@</IB;&EC82!A('!A<G1I<B!D;R!S
M97)V:61O<B!D92!C:&%V97,N`$[C;R!F;VD@<&]S<^UV96P@86)R:7(@)R5S
M)R!P87)A(&=R879AY^-O+@!.XV\@9F]I('!O<W/M=F5L(&%B<FER("5S+@!.
MXV\@9F]I('!O<W/M=F5L(&%B<FER(&\@;?-D=6QO("=-86EN=&5N86YC95]4
M87-K)R`E<P!.XV\@9F]I('!O<W/M=F5L(&%B<FER(&\@9&ER973S<FEO("<E
M<R<N`$[C;R!F;VD@<&]S<^UV96P@<&5S<75I<V%R(&YO('-E<G9I9&]R($Q$
M05`N`$[C;R!F;VD@<&]S<^UV96P@;&5R("5S+@!.XV\@9F]I('!O<W/M=F5L
M(&=E<F%R('5M82!N;W9A('-E;FAA('!A<F$@;R!U<W7A<FEO('-O;&EC:71A
M9&\N($%L9W5N<R!O=2!T;V1O<R!O<R!D971A;&AE<R!NXV\@97-TXV\@8V]R
M<F5T;W,N(%1E;G1E(&YO=F%M96YT92!O=2!E;G1R92!E;2!C;VYT871O(&-O
M;2!O(&%D;6EN:7-T<F%D;W(@<V4@=F]CZB!N96-E<W-I=&$@9&4@;6%I<R!A
M:G5D82X`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!A($%#3`!.XV\@9F]I('!O
M<W/M=F5L(&]B=&5R(&\@8V%TX6QO9V\@9&4@96YD97)EYV]S+B`E<P!.XV\@
M9F]I('!O<W/M=F5L(&]B=&5R(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B`E
M<P!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&%S(&QI<W1A<R!D92!D:7-T<FEB
M=6GGXV\N("5S`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@87,@8V%P86-I9&%D
M97,@9&\@<V5R=FED;W(`3N-O(&9O:2!P;W-S[79E;"!R979E<G1E<B!A(&-O
M;F9I9W5R8>?C;RX`3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&\@9&ER973S
M<FEO("<E<R<N`$[C;R!F;VD@<&]S<^UV96P@<V%L=F%R(&$@8V]N9FEG=7)A
MY^-O("5S+@!.XV\@9F]I('!O<W/M=F5L('-A;'9A<B!U;2!B86-K=7`@9&$@
M8V]N9FEG=7)AY^-O+@!.XV\@9F]I('!O<W/M=F5L('-A;'9A<B!U;2!B86-K
M=7`@9&$@8V]N9FEG=7)AY^-O.B`E<P!.XV\@9F]I('!O<W/M=F5L('-A;'9A
M<B!O('-C<FEP="!D92!A='5A;&EZ8>?C;R!D92!C;VYF:6=U<F'GXV\@96TZ
M("<E<R<N`$[C;R!C;VYS96=U:2!S86QV87(@;R!B86-K=7`@9&\@87)Q=6EV
M;R!D92!C;VYF:6=U<F'GXV\@)7,N`$[C;R!C;VYS96=U:2!S86QV87(@;R!A
M<G%U:79O(&1E(&-O;F9I9W5R8>?C;R`E<RX@5F]CZB!P;V1E(&]U('5T:6QI
M>F%R('5M82!D87,@;W#G]65S('!A<F$@<V%L=F%R(&\@8_-D:6=O(&1E('9O
M;'1A(&5M("5S(&]U(&-O<&EA<B!M86YU86QM96YT92!O(&/S9&EG;R!A8F%I
M>&\@<&%R82`E<RX`3N-O(&9O:2!P;W-S[79E;"!P97-Q=6ES87(@;F\@<V5R
M=FED;W(@3$1!4"X`3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&\@;&EN:R`G
M)7,G+@!.XV\@9F]I('!O<W/M=F5L(&%T=6%L:7IA<B!O(&-O;G1A=&\N("5S
M`$[C;R!F;VD@<&]S<^UV96P@871U86QI>F%R(&$@;&ES=&$@9&4@9&ES=')I
M8G5IY^-O+B`E<P!.XV\@9F]I('!O<W/M=F5L(&=R879A<B!A(&-O;F9I9W5R
M8>?C;R!D92`G)7,G.B`E<P!.XV\@9F]I('!O<W/M=F5L(&5N8V]N=')A<B!A
M($)A<G)A($QA=&5R86P@9&\@36]Z:6QL82X@0V5R=&EF:7%U92US92!Q=64@
M96QA(&5S=.$@86)E<G1A+@!.XV\@9F]I('!O<W/M=F5L(&1A<B!A;R!U<W7A
M<FEO("5S(&]S('-E9W5I;G1E<R!D:7)E:71O<R!P87)A(&$@<&%S=&$@)R5S
M)SH@)7,`5&5X=&\@8V]N=&%D;P!08>US`$-U<G-O<P!#<FEA<@!#<FEA<B!U
M;2!L:6YK`$-R:6%R('5M82!N;W9A`$-R:6%R('-U8B!P87-T87,`4&5R;6ES
M<_5E<R!D;R!C<FEA9&]R`$[Z;65R;R!D;R!C87)TXV\@9&4@8W+I9&ET;P!#
M<F_A8VEA`$-U8F$`-"!&87-E<R!!='5A:7,`4V5S<_5E<R!!='5A:7,`2&]R
M82!!='5A;`!!(%523"!A='5A;"#I`%5S=>%R:6]S(&YO(&UO;65N=&\`0VQI
M;6$@071U86P`0V]N9&GGXV\@871U86PZ(`!%<W1I;&\@871U86P`0W5S=&]M
M:7IA('1A<F5F87,@82!S97)E;2!E>&5C=71A9&%S(&%O(&-O;F5C=&%R(&$@
M)7,N`$-O<G1A<@!#;W)T87(@<V5L9>?C;P!#:&EP<F4`0VER[6QI8V\@*$M/
M23@M4BD`0VER[6QI8V\@*%=I;F1O=W,M,3(U,2D`0VER[6QI8V\O56-R86YI
M86YO("A+3TDX+54I`%)E</IB;&EC82!48VAE8V$`1$0`1%-.("AV96IA(&AT
M='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N
M9&(N:6YT<F\M9'-N+G!H<"D`1&EA<FEA;65N=&4`3F%V96=A9&]R(&1E($1A
M=&%4<F5E`%!E<W%U:7-A(&YO($)A;F-O(&1E($1A9&]S`$1A=&$`1&%T82!D
M92!296-E8FEM96YT;P!396QEY^-O(&1E(&1A=&$`1&EA`$5?>&-L=6ER($-O
M;'5N80!$97IE;6)R;P!.^FUE<F]S(&1E8VEM86ES`%)E8W5A<B!)9&5N=&'G
MXV\`4&%D<N-O`$-O<B!0861RXV\`261E;G1I9&%D92!0861RXV\`4VAE;&P@
M4&%D<N-O`$1E9FEN:>?U97,`17AC;'5I<@!%>&-L=6ER(&/I;'5L80!%>&-L
M=6ER($=R=7!O`$5X8VQU:7(@3&]G`$5X8VQU:7(@4&5R;6ES<^-O`$5X8VQU
M:7(@92!P=7)G87(@;65N<V%G96YS`$5X8VQU:7(@8^EL=6QA`$5X8VQU:7(@
M8V]L=6YA`$5X8VQU:7(@;6]D96QO('-U8G-T:71U=&\@97AI<W1E;G1E`$5X
M8VQU:7(@<&5R;6ES<_5E<R!P87)A("<E<R<`17AC;'5I<B!P97)M:7-S]65S
M('!A<F$@)R5S)R!E('%U86QQ=65R(&]U=')A('-U8BUP97)M:7-SXV\_`$5X
M8VQU:7(@;&EN:&$`17AC;'5I<B!I9&5N=&ED861E('-E;&5C:6]N861A`$5X
M8VQU:7(@82!C;VQU;F$@871U86P`17AC;'5I<B!A(&QI;FAA(&%T=6%L`%-C
M<FEP="!D92!A='5A;&EZ8>?C;R!D92!C;VYF:6=U<F'GXV\@)R5S)R!E>&-L
M=>UD;RX`2&]R82!D92!E;G1R96=A`$1I;F%M87)C80!$97-C<F5V82!O('!R
M;V)L96UA`$1E<V-R:>?C;P!$971A;&AE<R`H=&%M8NEM(&YO(')E9VES=')O
M(&1E(&%T:79I9&%D97,@9&\@2&]R9&4I.@!/<R!D971A;&AE<R!F;W)A;2!G
M<F%V861O<R!E;2!L;V<@<&%R82!O(&%D;6EN:7-T<F%D;W(N`$1E<V5N=F]L
M=FEM96YT;P!0;VYT;R!D92!/<G9A;&AO`%!O;G1O(&1E($]R=F%L:&\@<&%R
M82!A(/IL=&EM82!H;W)A.B``4&]N=&\@9&4@3W)V86QH;SH@`$1I<F7GXV\@
M9&$@97-Q=65R9&$@<&%R82!D:7)E:71A`$1I<F7GXV\@9&$@9&ER96ET82!P
M87)A(&5S<75E<F1A`$1I<F5T\W)I;P!%>&EB:7(@96T@9F]R;6%T;R`R-"!H
M;W)A<S\`3W#G]65S(&1E($5X:6)IY^-O`$5X:6)I<B!P<F5V:7/C;R!D971A
M;&AA9&$`17AI8FER('!R979I<^-O("A4048I`$5X:6)I<B!F;W)M871O`$YO
M=&EF:6-AY^-O(&1E($1I<W!O<VGGXV\`1&II8G5T:0!.XV\@97AC;'5I<@!.
MXV\@86-E<W-E(&1I<F5T86UE;G1E(&UA:6YT96YA;F-E+G!H<`!!('!R:6UE
M:7)A(&QI;FAA(&-O;G3I;2!O<R!N;VUE<R!D;W,@8V%M<&]S/R!392!S:6TL
M(&-L:7%U92!N97-T82!C86EX83H`1&]M:6YI8V%N80!297#Z8FQI8V$@1&]M
M:6YI8V%N80!.XV\@=&5M('5M82!C;VYT83\@0V%D87-T<F4M<V4N`$)A:7AA
M<@!"86EX87(@)7,`0F%I>&%R(&$@8V]N9FEG=7)AY^-O(&=E<F%D82!C;VUO
M('5M('-C<FEP="!02%`N`$QI<W1A(&1E('-E;&7GXV\`1')O9V%S`$-O<G)E
M:6\`0V]N96-T;W(@9&\@9V%T97=A>2!%36%I;"UP87)A+5--4RP@<&%R82!O
M<&5R861O<F%S('%U92!D:7-P;VYI8FEL:7IA;2!E<W1E('-E<G9IYV\N`$52
M4@!%<75A9&]R`$5D:71A<@!%9&ET87(@0FQO8V\`161I=&%R($=R=7!O`$5D
M:71A<B!097)M:7-SXV\`161I=&%R(%!E<FUI<W/U97,`161I=&%R(%!E<FUI
M<W/U97,@<&%R82`E<P!%9&ET87(@;W#G]65S(&1E.@!%9&ET87(@<&5R;6ES
M<_5E<R!P87)A("5S`$5D:71A<B!P97)M:7-S]65S('!A<F$@)7,`161U8V'G
MXV\`16=I=&\`16P@4V%L=F%D;W(`16QE;65N=&\N+BX`16T`12UM86EL`$5N
M9&5R9>=O(&1E($4M36%I;`!/(&5N9&5R9>=O(&1E(&4M;6%I;"!D979E(&-O
M<G)E<W!O;F1E<BX`365N<V%G96T@8V]M(&-O;F9I<FUAY^-O`$=A=&5W87D@
M9&4@14UA:6PM<&%R82U335,`16UO=&EC;VYS`$UE;G-A9V5M(&5M(&)R86YC
M;RX`4F5S=6QT861O(&5M(&)R86YC;RX`5&5R;6]S(&1E('!E<W%U:7-A(&5M
M(&)R86YC;P!(86)I;&ET87(@:6YS97+GXV\@9&4@:6UA9V5N<R!A('!A<G1I
M<B!D82!'86QE<FEA(&1E($EM86=E;G,@;F\@=&5X=&\_`$AA8FEL:71A<B!M
M96YU(&1E(&-O;G1E>'1O(&-O;2!O(&)O=.-O(&1I<F5I=&\_`$9I;F%L(&1O
M(&%N;P!!=6UE;G1A<B!%9&ET;W(`1F]R;F7G82!U;6$@<&5R9W5N=&$@9&4@
M<V5G=7)A;N=A(&$@<75A;"!V;V/J('-E<N$@<&5R9W5N=&%D;R!S92!V;V/J
M(&YE8V5S<VET87(@9V5R87(@=6UA(&YO=F$@<V5N:&$L(&5X+B`G<75A;"!O
M(&YO;64@9&\@<V5U(&-A8VAO<G)O/R<Z`$9O<FYEYV$@82!54DP@9&$@:6UA
M9V5M(&%Q=6D`1&EG:71E(&%S(&QE=')A<R!A8F%I>&\Z`$=U:6[I($5Q=6%T
M;W)I86P`17)I='+I:6$`17)R;P!%<G)O(&%O(&-R:6%R(&)L;V-O.B`E<P!%
M<G)O(&%O(&5X8VQU:7(@XFYC;W)A(&1E('-I;F-R;VYI>F'GXV\Z("5S`$5R
M<F\@86\@97AC;'5I<B!L;V<@9&4@<VEN8W)O;FEZ8>?C;SH@)7,`17)R;R!A
M;R!O8G1E<B!C;VYT9?ID;SH@)7,`17)R;R!A;R!A='5A;&EZ87(@82!S96YH
M83H@)7,`17)R;R!N82!M96YS86=E;2X`17)R;R!G<F%V86YD;R`G)7,G+@!%
M<W3T;FEA`$5T:?-P:6$`R71N:6-O`$5U<F]P80!#861A(#$U(&UI;G5T;W,`
M0V%D82`R(&UI;G5T;W,`0V%D82`S,"!S96=U;F1O<P!#861A(#4@;6EN=71O
M<P!#861A($-O;F5XXV\`0V%D82!M96EA(&AO<F$`0V%D82!M:6YU=&\`5F%L
M;W)E<R!D92!E>&5M<&QO.@!%>&5C=71A<@!%>'!A;F1I<@!%>'!A;F1I<B!"
M87)R82!,871E<F%L`$5S<&5R861O("<I)P!%<W!E<F%D;R!U;6$@<&%L879R
M82!O=2!T97)M;R!D92!P97-Q=6ES82!E;G1R92!A<W!A<P!$871A(&1E($5X
M<&ER8>?C;P!%>'!O96YT90!#;W(@9&\@<')I;65I<F\@<&QA;F\`0V]N9FEG
M=7)AY^-O(&1E(&5N=FEO(&1E(&%R<75I=F]S($944`!&86QH82!O8G1E;F1O
M('!R969E<NIN8VEA<RX`1F%L:&$@86\@8V]N96-T87(@86\@<V5R=FED;W(@
M3$1!4"X`1F%L:&$@86\@8V]N96-T87(@86\@<V5R=FED;W(@4TU"+@!&86QH
M82!A;R!C;W!I87(@9&4@(B5S(BX`1F%L:&$@86\@8V]P:6%R('!A<F$@(B5S
M(BX`1F%L:&$@86\@8W)I87(@=6UA(&YO=F$@8V]N97CC;R!305-,+@!&86QH
M82!A;R!M;W9E<B!P87)A("(E<R(N`$9A;&AA(&%O(&]B=&5R.B`E<P!*=7-T
M;P!);&AA<R!&86QK;&%N9"`H36%L=FEN87,I`$EL:&%S($9A<F]E`$5R<F\@
M1F%T86PZ`$9A>`!&87AE<P!&979E<F5I<F\`4V5N<V'GXV\@5.ER;6EC80!3
M96YS8>?C;R!TZ7)M:6-A.B``4&%N8V%D87,@9&4@0VAU=F$`3F5V92!&<F%C
M80!-871R:7H@9&\@8V%M<&\`1FEG;&5T($-!4%1#2$$`1F]N=&4@1FEG;&5T
M`$9I:FD`87)Q=6EV;P!#;VYT86=E;2!D92!!<G%U:79O<SH@)7,@87)Q=6EV
M;P!#;VYT86=E;2!D92!!<G%U:79O<SH@)7,@87)Q=6EV;W,`1V5R96YC:6%D
M;W(@9&4@07)Q=6EV;W,`3F]M92!D;R!!<G%U:79O`%-E;&7GXV\@9&4@87)Q
M=6EV;P!%;G9I;R!D92!A<G%U:79O`$5N=FEO(&1E(&%R<75I=F]S(&[C;R#I
M('-U<&]R=&%D;RX`1FEL=')O<P!&:6YLXFYD:6$`4')I;65I<F$@365T861E
M`%!R:6UE:7)O(%%U87)T;P!487AA(&9I>&$`1VER87(`1&ES<&]S:>?C;P!.
MZ79O80!087-T82`E<R!NXV\@97AI<W1E`$-O<B!D82!&;VYT90!#;VUI9&$`
M4&%R82!N879E9V%D;W)E<R!Q=64@;N-O('-U<&]R=&%M(&EM86=E;G,`4')E
M=FESXV\@*%1!1BD`1&EA<R!0<F5V:7-T;W,@*$YO=&4@<75E(&$@<')E=FES
MXV\@<F5T;W)N861A(&5X:6)E(&%M8F]S(&1I82!E(&YO:71E.R!U;2!N^FUE
M<F\@;75I=&\@86QT;R!A<75I('!O9&4@<F5S=6QT87(@96T@=6T@8FQO8V\@
M97AT96YS;RD`17-Q=65C974@82!S96YH83\`1F]R;75LX7)I;W,`4V]R=&4`
M5&EP;R!D92!3;W)T90!3;W)T97,`4V]R=&5S(#(`1O-R=6YS`%)E9&ER96-I
M;VYA;65N=&]S`%-E>`!1=6%D<F]S`$9R86[G80!&<F%NYV$@365T<F]P;VQI
M=&%N80!'=6EA;F$@1G)A;F-E<V$`4&]L:6[I<VEA($9R86YC97-A`%1E<G)I
M=/-R:6]S($9R86YC97-E<R!D;R!3=6P`1&4`1&\H82D`1&5S8W)IY^-O($-O
M;7!L971A`$QU82!#:&5I80!.;VUE($-O;7!L971O`$=A8N-O`$=A;&5R:6$@
M9&4@;VYD92!O8G1E<B!A<R!I;6%G96YS`$=A;&5R:6$Z`$?B;6)I80!'97)A
M<B!A($-O;F9I9W5R8>?C;R!D92`E<P!#\V1I9V\@1V5R861O`$=E\W)G:6$`
M06QE;6%N:&$`1V%N80!':6)R86QT87(`4')I;65I<F\@3F]M90!/<.?U97,@
M1VQO8F%I<P!)<@!';V5D96P`1V]O9VQE($UA<&%S`%!E<W%U:7-A<B!N;R!'
M;V]G;&4`17-C86QA(&1E($-I;GIA<P!'<NEC:6$`1W)E9V\@*$E33RTX.#4Y
M+3<I`$=R;V5LXFYD:6$`1W)A;F%D80!!9&UI;FES=')AY^-O(&1E($=R=7!O
M<P!.;VUE<R!D92!G<G5P;W,@;N-O(&1E=F5M(&5S=&%R(&5M(&)R86YC;P!'
M<F]U<%]L9&%P.B!);7!O<W/M=F5L(&%D:6-I;VYA<B!G<G5P;R`E<RX@27-T
M;R#I(&\@<75E(&\@<V5R=FED;W(@9&ES<V4Z(`!'<F]U<%]L9&%P.B!);7!O
M<W/M=F5L(&5X8VQU:7(@9W)U<&\@)7,`1W)O=7!?;&1A<#H@26UP;W-S[79E
M;"!A='5A;&EZ87(@9W)U<&\@)7,`1W)U<&]S`$=U861A;'5P90!'=6%M`$=U
M871E;&%M80!'=65R;G-E>0!097)M:7-S]65S(&1E($-O;G9I9&%D;P!,:79R
M;R!D92!6:7-I=&%S`$=U:6[I`$=U:6[I+4)I<W-A=0!'=6EA;F$`2%1-3`!(
M5$U,07)E82!S92!N96=A(&-O=F%R9&5M96YT92!A(&5X8VQU:7(@82#Z;'1I
M;6$@8^EL=6QA(&1A(&QI;FAA+@!(5$U,07)E82!S92!N96=A(&-O=F%R9&5M
M96YT92!A(&5X8VQU:7(@82#Z;'1I;6$@8V]L=6YA(&1A('1A8F5L82X`2%1-
M3$%R96$@<V4@;F5G82!C;W9A<F1E;65N=&4@82!E>&-L=6ER(&$@^FQT:6UA
M(&QI;FAA(&1A('1A8F5L82X`075T96YT:6-AY^-O($A45%`@;N-O(&5N8V]N
M=')A9&$N`$AA:71I`$%L9V]R:71M;R!(87-H`$YE8FQI;F$`0V%B9>=A;&AO
M`$-A8F7G86QH;P!);&AA($AE87)D(&4@26QH87,@36-$;VYA;&0`5&5M<&5S
M=&%D92!&;W)T90!(96)R974@*$E33RTX.#4Y+3@M22D`06QT=7)A`$%J=61A
M`$%J=61A(&1O(&5D:71O<@!!<W-I<W1E;G1E`$AE;6ES9NER:6\`07%U:2!E
M<W3A(&\@:6[M8VEO(&1O(&%R<75I=F\Z`$%L=&$`25]N[6-I;P!386YT82!3
MZ2`H0VED861E+45S=&%D;R!D;R!6871I8V%N;RD`26[M8VEO`$5N9&5R9>=O
M(%)E<VED96YC:6%L`$1I<F5T\W)I;R!097-S;V%L`$9O;F4@4F5S:61E;F-I
M86P`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!$861O
M(%A-3"`E<R!I;G;A;&ED;R!E;F-O;G1R861O(&YA(&UE;G-A9V5M("5S`$AO
M<F1E+TMO;&%B.B!.96YH=6UA(&UE;G-A9V5M(&-O<G)E<W!O;F1E(&%O(&]B
M:F5T;R`E<P!(;W)D92]+;VQA8CH@3F5N:'5M(&]B:F5T;R!D;R!T:7!O("5S
M(&9O:2!E;F-O;G1R861O(&YA(&UE;G-A9V5M("5S`$AO<F1E+TMO;&%B.B!2
M96UO=FED;R!C;VT@<W5C97-S;R`E<R`B)7,B`$AO<F1E+TMO;&%B.B!!(&5N
M9VEN92!D92!I;G1E9W)AY^-O(')E<75E<B!A(&5X=&5N<^-O(%!(4"`G9&]M
M>&UL)P!(;W)D92]+;VQA8CH@26UP;W-S[79E;"!C<FEA<B!U;6$@;F]V82#A
M<G9O<F4@6$U,('!A<F$@;R!O8FIE=&\@)7,`2&]R9&4O2V]L86(Z($EM<&]S
M<^UV96P@<F5M;W9E<B`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@26UP;W-S
M[79E;"!O8G1E<B!A(&ED96YT:69I8V'GXV\@34E-12!P87)A(&$@<&%R=&4@
M9&\@=&EP;R`E<P!(;W)D92]+;VQA8CH@26UP;W-S[79E;"!S:6YC<F]N:7IA
M<B`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@26UP;W-S[79E;"!S:6YC<F]N
M:7IA<B!C;VUP87)T:6QH86UE;G1O<SH@)7,`2&]R9&4O2V]L86(Z($-O;7!A
M<G1I;&AA;65N=&\@9&5S8V]N:&5C:61O("(E<R(`3&EN:&$@2&]R:7IO;G1A
M;`!-87)G96T@:&]R:7IO;G1A;`!(;W)I>F]N=&%L.@!#;VUO('9O8^H@8VAE
M9V]U(&%Q=6D_("A0;W(@9F%V;W(@8V]M=6YI<75E(2D`475A;G1A<R!C;VQU
M;F%S('9O8^H@9V]S=&%R:6$@9&4@;65S8VQA<C\`475A;G1O<R!C86UP;W,@
M*&-O;'5N87,I(&5X:7-T96T_`%%U86YT87,@;&EN:&%S('9O8^H@9V]S=&%R
M:6$@9&4@;65S8VQA<C\`56UI9&%D90!5;6ED861E.B``2'5M;W)I<W1A<P!(
M=6YG<NUA`$9A;&AA(&%O(&-R:6%R(&-A:7AA('!O<W1A;"!)34%0.B`E<P!&
M86QH82!A;R!E>&-L=6ER(&-A:7AA('!O<W1A;"!)34%0.B`E<P!&86QH82!A
M;R!C<FEA<B!Q=6]T82!D82!C86EX82!P;W-T86P@24U!4#H@)7,`16YD97)E
MYV\@25``16YD97)EYV\@25`@;N-O(&1I<W!O;NUV96PN`$5N9&5R9>=O($E0
M(&[C;R!E<W3A(&YO(&)L;V-O('!E<FUI=&ED;R!#2412+@!6:6]L8>?C;R!D
M;R!B;&]Q=65I;R!)4"X`25]N<VER82!,:6YH82!!;G1E<P!)<VSB;F1I80!3
M;VUE;G1E(,UC;VYE<P#-8V]N97,@<&%R82`E<P#-8V]N97,@92!T97AT;P!.
M;VUE(&1A(&ED96YT:61A9&4Z`%-E(&[C;R!F;W(@97AI8FED;R!C;W)R971A
M;65N=&4L("5S('!A<F$@86)R[2UL;R!E;2!U;6$@;F]V82!J86YE;&$N`%-E
M('9O8^H@;N-O(';J(&YE;FAU;2#M8V]N92!A;R!U=&EL:7IA<B!O($EN=&5R
M;F5T($5X<&QO<F5R+"!V;V/J('!O9&4@8VAE8V%R(&5S=&$@8V%I>&$@<&%R
M82!D97-A8FEL:71A<B!A('1R86YS<&%RZFYC:6$@4$Y'+@!392!V;V/J(';J
M(&5S=&$@;65N<V%G96T@;6%S(&[C;R!A(&EM86=E;2P@82!I;6%G96T@<75E
M('9O8^H@<75E<B!E;G9I87(@;N-O('!O9&4@<V5R(&5X:6)I9&$@<&5L;R!S
M974@;F%V96=A9&]R+@!0<NDM=FES=6%L:7IAY^-O(&1A($EM86=E;3H`55),
M(&1A($EM86=E;0!54DP@9&$@26UA9V5M.@!);6%G96T@9&$@9V%L97)I80!)
M;6%G96T@9&$@9V%L97)I83H`16YV:6\@9&4@26UA9V5M`$EM86=E;G,`26UP
M;W)T87(L(%!A<W-O("5D`$-A;7!O(&EM<&]R=&%D;SH@)7,`0V%M<&]S(&EM
M<&]R=&%D;W,Z`$EN7W-E<FER($QI;FAA($%P\W,`0_-D:6=O(&1E(&'GXV\@
M9F]R;F5C:61O(&5S=.$@:6YC;W)R971O+@!5<W7A<FEO(&4O;W4@<V5N:&$@
M:6YC;W)R971O<RX`57-UX7)I;R!O=2!E;F1E<F7G;R!A;'1E<FYA=&EV;R!I
M;F-O<G)E=&]S+B!496YT92!N;W9A;65N=&4@;W4@96YT<F4@96T@8V]N=&%T
M;R!C;VT@;R!A9&UI;FES=')A9&]R('-E('9O8^H@;F5C97-S:71A(&1E(&UA
M:7,@86IU9&$N`$%U;65N=&%R($ED96YT8>?C;P#-;F1I80!5<W7A<FEO<R!I
M;F1I=FED=6%I<P!);F1O;NES:6$`26YF;W)M8>?C;P!);F9O<FUAY^-O`$[C
M;R!E>&ES=&5M(&]PY_5E<R!D:7-P;V[M=F5I<RX`26YS97)I<B!#7V]L=6YA
M($%P\W,`26YS97)I<B!);6%G96T`26YS97)I<B!486)E;&$`26YS97)I<B!,
M:6YK(&1A(%=E8@!);G-E<FER(%]#;VQU;F$@06YT97,`26YS97)I<B!U;6$@
M;F]V82!C;VQU;F$@87#S<R!A(&%T=6%L`$EN<V5R:7(@=6UA(&YO=F$@8V]L
M=6YA(&%N=&5S(&1A(&%T=6%L`$EN<V5R:7(@=6UA(&YO=F$@;&EN:&$@87#S
M<R!A(&%T=6%L`$EN<V5R:7(@=6UA(&YO=F$@;&EN:&$@86YT97,@9&$@871U
M86P`26YS97)I<B!U;2!P87+A9W)A9F\@87#S<R!O(&%T=6%L`$EN<V5R:7(@
M=6T@<&%RX6=R869O(&%N=&5S(&1O(&%T=6%L`$EN<V5R:7(@=6T@;6]D96QO
M(&%L=&5R;F%T:79O`$9O<FYEYV$@=6T@96YD97)EYV\@9&4@92UM86EL(&YO
M('%U86P@=F]CZB!P;V1E(')E8V5B97(@82!N;W9A('-E;FAA.@!);G-E<FER
M(&/I;'5L82!A</-S`$EN<V5R:7(@8^EL=6QA(&%N=&5S`$EN<V5R:7(@8V]L
M=6YA(&%P\W,`26YS97)I<B!C;VQU;F$@86YT97,`26YS97)I<B!M96YS86=E
M;G,`26YS97)I<B!P87+A9W)A9F\@87#S<P!);G-E<FER('!A<N%G<F%F;R!A
M;G1E<P!);G-E<FER(&QI;FAA(&%P\W,`26YS97)I<B!L:6YH82!A;G1E<P!&
M;W)N9>=A(&$@<F5S<&]S=&$@;V)R:6=A=/-R:6$@<&%R82!A('!E<F=U;G1A
M(&1E('-E9W5R86[G83H`26YS97)I<B]!;'1E<F%R($EM86=E;0!);G-E<FER
M+T%L=&5R87(@3&EN:P!#<NED:71O(&EN<W5F:6-I96YT92!P87)A(&5N=FEA
M<B!P87)A(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+@!#<NED:71O(&EN<W5F
M:6-I96YT92X`3OIM97)O($EN=&5I<F\`3&ES=&$@9&4@26YT96ER;W,`0T15
M("A#86)EYV%L:&\@9&4@1&%D;W,@9&4@57-UX7)I;RD@:6YVX6QI9&\N`$1A
M9&]S(%I)4"!I;G;A;&ED;W,`07!L:6-AY^-O(&EN=N%L:61A+@!)9&5N=&EF
M:6-AY^-O(&1O(&)A=&-H(&EN=N%L:61A+@!$861O<R!E;G9I861O<R!SXV\@
M:6YVX6QI9&]S+@!%;F1E<F7G;R!D92!D97-T:6YO(.D@:6YVX6QI9&\N`$9O
M<FUA=&\@9&\@87)Q=6EV;R#I(&EN=N%L:61O`$[Z;65R;R!D92!L:6-E;N=A
M(&EN=N%L:61O+@!,;V-A;&EZ8>?C;R!F;W)N96-I9&$@Z2!I;G;A;&ED82X`
M5&EP;R!D82!M96YS86=E;2#I(&EN=N%L:61O+@!!<&E?:60@Z2!I;G;A;&ED
M;R!O=2!E<W3A(&9A;'1A;F1O+@!087+B;65T<F]S(&EN=N%L:61O<R!O=2!F
M86QT86YD;RX`4&5R;6ES<_5E<R!D;R!P86D@<^-O(&EN=N%L:61A<RX`4&5R
M;6ES<_5E<R!D;R!P86D@<^-O(&EN=N%L:61A<RX`0_-D:6=O(&1O('!R;V1U
M=&\@Z2!I;G;A;&ED;RX`4')O=&]C;VQO(&EN=N%L:61O+@!$97-T:6YA=.%R
M:6\@:6YVX6QI9&\Z("<E<R<`3V)J971O(&-O;7!A<G1I;&AA9&\@:6YVX6QI
M9&\`1F]N=&4@9&\@96YD97)EYV\@:6YVX6QI9&$N`$1A9&]S('5N:6-O9&4@
M:6YVX6QI9&]S+@!);G9E;G3A<FEO`$EN=F5R=&5R('-E;&7GXV\`27+C+"!2
M97#Z8FQI8V$@27-LXFUI8V$@9&\`27)A<75E`$ER;&%N9&$`26QH82!D;R!(
M;VUE;0!496UP97-T861E<R!)<V]L861A<P!)<W)A96P`16UI<W-O<@!)=.%L
M:6-O`$ETX6QI80!*86UA:6-A`$IA;F5I<F\`2F%PXV\`2F%P;V[J<R`H25-/
M+3(P,C(M2E`I`$IE<G-E>0!*;W)DXFYI80!*=6QH;P!*=6YH;P!*=7-T:69I
M8V%R`$%L:6YH87(@86\@0V5N=')O`$IU<W1I9FEC87(`06QI;FAA<B#@($5S
M<75E<F1A`$%L:6YH87(@X"!$:7)E:71A`$-A>F%Q=6ES=.-O`$UA;G1E<B!O
M(&]R:6=I;F%L/P!1=>IN:6$`4V5R=FED;W(@:V5R8F5R;W,@<F5J96ET;W4@
M82!A=71E;G1I8V'GXV\N`$YO=F%T;W,@9&4@2V5R;F5L`$-R:6'GXV\@9&4@
M0VAA=F4`26UP<F5S<^-O($1I9VET86P@9&$@0VAA=F4`5&%M86YH;R!D82!#
M:&%V90!4:7!O(&1A($-H879E`%5S;R!D82!#:&%V90!#:&%V92!JX2!E>&ES
M=&4@;F\@<V5R=FED;W(@9&4@8VAA=F5S('#Z8FQI8V%S+@!#<FEA;N=A<P!+
M:7)I8F%T:0!#;W+I:6$L(%)E</IB;&EC82!0;W!U;&%R($1E;6]C<N%T:6-A
M(&1A`$-O<NEI82P@4F5P^F)L:6-A(&1A`$-O<F5A;F\@*$550RU+4BD`2W5W
M86ET`%%U:7)G=6ES=.-O`$QA7WEO=70`261I;VUA`$QA;R!297#Z8FQI8V$@
M1&5M;V-RX71I8V$@4&]P=6QA<@#:;'1I;6$@365T861E`$=E<F%R($YO=F$@
M4V5N:&$`VFQT:6UO(%%U87)T;P#:;'1I;6$@071U86QI>F'GXV\Z`-IL=&EM
M;R!L;V=I;CH@)7,`VFQT:6UO(&QO9VEN.B`E<R#@('!A<G1I<B!D92`E<P#:
M;'1I;6\@;&]G:6XZ($YU;F-A`$QE=/1N:6$`3&5I`$QA>6]U=`!$96EX82!V
M87II;R!S92!Q=6ES97(@<V5M(&)O<F1A`$SM8F%N;P!%<W%U97)D80!#86)E
MYV%L:&\@97-Q=65R9&\`5F%L;W)E<R!D82!E<W%U97)D80!,97-O=&\`06UO
M<@!,:6+I<FEA`$SM8FEA(,%R86)E($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I
M;@!#:&EV:7-C;T9R86-O`$-H=79A($9R86-A`$-H=79A($9R86-A($UA='5T
M:6YA`$-H=79A($9R86-A(%9E<W!E<G1I;F$`3&5V97,@4&%N8V%D87,@9&4@
M0VAU=F$`0VAU=F%S($9R86-A<R!C;VT@5')O=O5E<P!.979E($9R86-A`$)R
M979E($YE=F%S8V$`4&_J;6%S`$QI;FL`3&EN:R!A<&]N=&$@<&%R83H`3&EG
M87(@;R!E;F1E<F7G;R!D92!E+6UA:6P@X"!PX6=I;F$@9&4@8V]M<&]S:>?C
M;R!A;R!E>&EB:7(`3&EN:W,`0V]O:VEE(&1O($QI;G5X`$QI<W1A<B`M('5S
M=>%R:6\@<&]D92!V97(@82!P87-T80!,:7-T87(@0F%N8V]S(&1E($1A9&]S
M`$QI<W1A<B!4\W!I8V]S(&1E($%J=61A`$QI<W1A<B!486)E;&%S`$QI<W0M
M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S
M=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$$@;&ES=&%G96T@
M9&4@<V5S<_5E<R!F86QH;W4Z("5S`$$@;&ES=&%G96T@9&4@=7-UX7)I;W,@
M9F%L:&]U.B`E<P!,:7-T86=E;2!D92!U<W7A<FEO<R!E<W3A(&1E<V%B:6QI
M=&%D82X`3&ET97)A='5R80!,:71UXFYI80!#87)R96=A;F1O+BXN`$AO<F$@
M;&]C86PZ(`!,;V-A;&EZ8>?C;R!E($AO<F$`4F5G:>-O`$-O;F5C=&%R`$QO
M9R!D82!S97-SXV\@9&4@<VEN8W)O;FEZ8>?C;R!A;G1E<FEO<@!$97-C;VYE
M8W1A<@!#;VYE8W1A<@!487)E9F%S(&1E($-O;F5XXV\`3R!L;V=I;B!F86QH
M;W4@<&]R<75E('-E=2!U<W7A<FEO(&]U('-E;FAA(&5S=&%V82!I;F-O<G)E
M=&$N`$9A;&AA(&1E($QO9VEN+@!497AT;R!L;VYG;P!!;6]R`$)A:7AA`$%L
M9F%B971O(&=R96=O(&5M(&UI;OIS8W5L;P!!;&9A8F5T;R!L871I;F\@96T@
M;6EN^G-C=6QO`$[Z;65R;W,@<F]M86YO<R!E;2!M:6[Z<V-U;&\`3'5X96UB
M=7)G;P!-30!-3U1$`$\@86YE>&\@35,M5$Y%1B!NXV\@8V]N=.EM(&1A9&]S
M+@!-4T<`36%C86\`36%C961O;FEA+"!!;G1I9V$@4F5P^F)L:6-A($EU9V]S
M;.%V:6$@9&$`36%D86=A<V-A<@!-X6=I8V\`0V]R<F5I;P!!9&UI;FES=')A
M9&]R(&1O($-O<G)E:6\`0W)I87(@;&EN7VLN+BX`36%L87=I`$UA;.%S:6$`
M36%L9&EV87,`36%L:0!-86QT80!'97)E;F-I82!A(&QI<W1A(&1E(&-A=&5G
M;W)I87,@92!A<R!C;W)E<R!A<W-O8VEA9&%S(&$@96QA<RX`36%P96%M96YT
M;R!-87`R-`!-87!E86UE;G1O($UA<%%U97-T`$UA<&5A;65N=&]S(&=R879A
M9&]S+@!-87+G;P!-87)G96T`36%R8V%R(&-O;2!F;&%G<R!,:61A+T[C;R!,
M:61A`$UA<F-A<B!C;VT@;W5T<F]S(&9L86=S("AE>"X@26UP;W)T86YT92]2
M97-P;VYD:61A*0!);&AA<R!-87)S:&%L;`!-87)T:6YI8V$`0V%M<&]S(&-O
M<G)E<W!O;F1E;G1E<P!-875R:73B;FEA`$UA=7+M8VEO`$-RZ61I=&\@;>%X
M:6UO('!E<FUI=&ED;RX`3OIM97)O(&WA>&EM;R!D92!P87)T97,@9&$@;65N
M<V%G96T@97AC961E=2X`5&5M<&5R871U<F$@;>%X:6UA(&YA<R#Z;'1I;6%S
M(#(T(&AO<F%S.B``5&5M<&5R871U<F$@;>%X:6UA(&YA<R#Z;'1I;6%S(#8@
M:&]R87,Z(`!.^FUE<F\@3>%X:6UO(&1E($)L;V-O<R!D92!0;W)T86P`5&%M
M86YH;R!MX7AI;6\`36%I;P!-87EO='1E`$UE9&EC:6YA`$UE;6)R;W,`36]D
M;R!D;R!M96YU.@!-97-C;&%R(&/I;'5L87,`365N<V%G96T`365N<V%G96T@
M5F5R:69I8V%D82!C;VT@4W5C97-S;R!M87,@;R!C97)T:69I8V%D;R!D;R!A
M<W-I;F%N=&4@;N-O('#T9&4@<V5R('9E<FEF:6-A9&\N`$UE;G-A9V5M(&5X
M<&ER861A+@!4:7!O(&1E(&UE;G-A9V5M`$-L:6UA($UE=&%R`$)L;V-O($UE
M=&%R(&[C;R!D:7-P;V[M=F5L+@!";&]C;R!-971A<B!NXV\@9&ES<&]N[79E
M;"X@1&5T86QH97,@9F]R86T@9W)A=F%D;W,@96T@;&]G('!A<F$@;R!A9&UI
M;FES=')A9&]R+@!/($UE=&%R1$(@;N-O(&5S=.$@8V]N96-T861O+@!-Z71O
M9&\`3>ET;V1O("<E<R<@;N-O(&5S=.$@9&5F:6YI9&\`3>ET;V1O(&[C;R!D
M969I;FED;RX@3>ET;V1O(&-H86UA9&\Z("5S`$WI=')I8V$`3>EX:6-O`$UI
M8W)O;NES:6$L($5S=&%D;W,@1F5D97)A9&]S(&1A`$UE:6\`5&EP;R!-:6UE
M`%1E;7!E<F%T=7)A(&WM;FEM82!N87,@^FQT:6UA<R`R-"!H;W)A<SH@`%1E
M;7!E<F%T=7)A(&WM;FEM82!N87,@^FQT:6UA<R`V(&AO<F%S.B``261A9&4@
M;>UN:6UA(&1A('-E;FAA(&%I;F1A(&[C;R!E>'!I<F]U`$5S<&5L:&\`1&EV
M97)S;W,`4&%C;W1E(%!%05(@2%144%]297%U97-T(&9A;'1A;F1O+@!#;VYF
M:6=U<F'GXV\@9F%L=&%N9&\N(%9O8^H@=&5M('%U92!G97)A<B!E;&$@86=O
M<F$@<V4@=F]CZB!Q=65R('5T:6QI>F%R(&5S=&$@87!L:6-AY^-O+@!)1"!D
M82!M96YS86=E;2!F86QT86YD;RX`4&%C;W1E(&]B<FEG873S<FEO(%!%05(@
M36%I;"!F86QT86YD;RX`240@9&$@<V5S<^-O(&9A;'1A;F1O+@!396<`0V]R
M<F5I;R!-\W9E;`!-;V1E<F%R`$1A=&$@36]D:69I8V%D80!!;'1E<F%R(%52
M3`!-\V1U;&\`36]L9&]V82P@4F5P^F)L:6-A(&1A`$WT;F%C;P!-;VYG\VQI
M80!-ZG,@92!A;F\`365N<V%L;65N=&4`36]N='-E<G)A=`!&87-E<R!D82!,
M=6$`36%I<R!C86UP;W,@96YC;VYT<F%D;W,@;F$@;&EN:&$@)60@<75E(&\@
M;OIM97)O(&5S<&5R861O("5D+@!-87)R;V-O<P!'<F%N9&4@4&%R=&4@3&EM
M<&$`1W)A;F1E(%!A<G1E($YU8FQA9&\`1W)A;F1E(%!A<G1E($5N<V]L87)A
M9&\`36]V97(@06)A:7AO`$UO=F5R(.`@17-Q=65R9&$`36]V97(@X"!$:7)E
M:71A`$UO=F5R($%C:6UA`$%B86EX;P!!8VEM80!-;^=A;6)I<75E`$QI<W1A
M<R!D92!S96QEY^-O(&1E(&WZ;'1I<&QO<R!N[79E:7,`36%P87,@26YG;&5S
M97,@375L=&EM87``4V5L9>?C;R!M^FQT:7!L80!-:6YH82!#;VYT80!3=6%S
M($EN9F]R;6'G]65S`$UE=2!0;W)T86P`365U($QA>6]U="!D92!0;W)T86P`
M0FER;>)N:6$`3L-/+"!%=2!.PT\@0V]N8V]R9&\`3F]M90!.86WM8FEA`$YA
M=7)U`$YE<&%L`$AO;&%N9&$`06YT:6QH87,@2&]L86YD97-A<P!54DP@0F%S
M92!D;R!.971S8V%P90!54DP@9&4@4F5V;V=AY^-O(&1E($-!(&1O($YE='-C
M87!E`%523"!D92!P;VSM=&EC87,@9&4@0T$@9&\@3F5T<V-A<&4`55),(&1E
M(%)E;F]V8>?C;R!D;R!.971S8V%P90!54DP@9&4@4F5V;V=AY^-O(&1O($YE
M='-C87!E`$YO;64@9&\@<V5R=FED;W(@4U-,(&1O($YE='-C87!E`$-O;65N
M=.%R:6\@9&\@8V5R=&EF:6-A9&\@9&\@3F5T<V-A<&4`5&EP;R!D92!C97)T
M:69I8V%D;R!D;R!.971S8V%P90!2961E`$YU;F-A`$YO=F$@0V%L963T;FEA
M`$YO=F$@0V%T96=O<FEA`$YO=F$@365N<V%G96T@<&%R82`E<P!,=6$@3F]V
M80!.;W9O(%5S=>%R:6\@*&]P8VEO;F%L*0!.;W9A(%IE;.)N9&EA`$YO=F$@
M<V5N:&$`3F]V82!S96YH82!E>'!I<F%RX2!E;2`E>"X`07,@;F]V87,@<V5N
M:&%S(&[C;R!SXV\@:6=U86ES+@!.;W9A(&IA;F5L82`H7V)L86YK*0!.;W3M
M8VEA<P!'<G5P;W,@9&4@3F]T[6-I87,`4'+S>&EM80!0<O-X:6UA<R`T($9A
M<V5S`%!R\WAI;6%S(&]PY_5E<P!0<O-X:6UA/@!.:6-A<N%G=6$`3FEG97(`
M3FEGZ7)I80!.;VET90!.:75E`$[C;P!.96YH=6T@9&%D;R!D92!C;VYF:6=U
M<F'GXV\@9&ES<&]N[79E;"!P87)A(&5X:6)I<B!A<R!D:69E<F5NYV%S+@!.
M96YH=6UA(&5S=')A=.EG:6$@9&ES<&]N[79E;"!P87)A(&-R:6%R(&EM86=E
M;G,@25-/+@!.96YH=6T@;6]D96QO(&1E(&)A=&-H+@!.96YH=6T@8FQO8V\@
M97AI<W1E(&YA('!O<VGGXV\@<V]L:6-I=&%D80!.96YH=6T@;F]M92!D92!A
M9V5N9&$@9F]R;F5C:61O('!A<F$@82!A=71E;G1I8V'GXV\@34-!3"X`3F5N
M:'5M82!A;'1E<F'GXV\N`$YE;FAU;2!S=6)O<F1I;F%D;R!P;V1E('-E<B!A
M9&EC:6]N861O(&$@97-T82!P97)M:7-SXV\N`$YE;FAU;6$@:6YF;W)M8>?C
M;R!D92!C;VYF:6=U<F'GXV\@97-P96-I9FEC861A('!A<F$@)7,N`$YE;FAU
M;6$@:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@97-P96-I9FEC861A('!A
M<F$@1E10(%9&4RX`3F5N:'5M82!I;F9O<FUAY^-O(&1E(&-O;F9I9W5R8>?C
M;R!E<W!E8VEF:6-A9&$@<&%R82!344P@5D93+@!.96YH=6UA(&EN9F]R;6'G
MXV\@9&4@8V]N9FEG=7)AY^-O(&5S<&5C:69I8V%D82!P87)A(%-13"U&:6QE
M(%9&4RX`3F5N:'5M(&-RZ61I=&\@<F5S=&%N=&4N`$YE;FAU;2!D97-T:6YO
M(&9O<FYE8VED;RX`3F5N:'5M(&%R<75I=F\@96YV:6%D;P!.96YH=6T@[6-O
M;F4@96YC;VYT<F%D;RX`3F5N:'5M82!L;V-A;&EZ8>?C;R!C;VYF:6=U<F%D
M82X`3F5N:'5M82!L;V-A;&EZ8>?C;R!C;VYF:6=U<F%D82X`3F5N:'5M82!M
M96YS86=E;2!F;W)N96-I9&$N`$YE;FAU;2!N;VUE(&5S<&5C:69I8V%D;RX`
M3F5N:'5M(&[Z;65R;R!E<W!E8VEF:6-A9&\N`%-E;2!S;W)T97,@;V9E;G-I
M=F%S`$YE;FAU;6$@<V5N:&$@9F]R;F5C:61A('!A<F$@82!A=71E;G1I8V'G
MXV\@2%144"X`3F5N:'5M82!S96YH82!F;W)N96-I9&$@<&%R82!A(&%U=&5N
M=&EC8>?C;R!)34%0+@!.96YH=6UA('-E;FAA(&9O<FYE8VED82!P87)A(&$@
M875T96YT:6-AY^-O($ME<F)E<F]S+@!.96YH=6UA('-E;FAA(&9O<FYE8VED
M82!P87)A(&$@875T96YT:6-AY^-O($QO9VEN+@!.96YH=6UA('-E;FAA(&9O
M<FYE8VED82!P87)A(&$@875T96YT:6-AY^-O(%!!4U-71"X`3F5N:'5M82!S
M96YH82!F;W)N96-I9&$@<&%R82!A(&%U=&5N=&EC8>?C;R!334(N`$YE;FAU
M;2!P871H('!A<F$@;R!B:6[A<FEO(&1O($]P96Y34TP@9F]I(&9O<FYE8VED
M;RX@3R!B:6[A<FEO(&1O($]P96Y34TP@Z2!N96-E<W/A<FEO('!A<F$@;6%N
M:7!U;&%R(&]S(&1A9&]S(%!+0U,@,3(N`$YE;FAU;2!C861A<W1R;R!P96YD
M96YT92X`475O=&$@;N-O(&-O;F9I9W5R861A+@!396T@;&EN:&%S`$YE;FAU
M;2!S97!A<F%D;W(@9F]I(&5S<&5C:69I8V%D;RX`4V5M(&QA9&]S`$%R<75I
M=F\@:6YE>&ES=&5N=&4`3F5N:'5M(&1I<F5T\W)I;R!T96UP;W+A<FEO(&1I
M<W!O;NUV96P@<&%R82!O(&-A8VAE+@!.96YH=6T@=7-UX7)I;R!E+V]U('-E
M;FAA(&9O<FYE8VED;W,N`$YE;FAU;2!D861O(%A-3"!VX6QI9&\@<F5T;W)N
M861O`%-E;2!V86QO<F5S`$YE;FAU;2!V97)SXV\@96YC;VYT<F%D82!N82!C
M;VYF:6=U<F'GXV\@;W)I9VEN86PN($=E<F4@;F]V86UE;G1E(&$@8V]N9FEG
M=7)AY^-O+@!.96YH=6UA('9E<G/C;R!E;F-O;G1R861A(&YA('-U82!C;VYF
M:6=U<F'GXV\N($=E<F4@;F]V86UE;G1E(&$@8V]N9FEG=7)AY^-O+@!.96YH
M=6UA`$YE;FAU;6$@*'5S;R!I;7!L[6-I=&\I`$[S<F1I8V\@*$E33RTX.#4Y
M+3$P*0!);&AA($YO<F9O;&L`2&5M:7-FZ7)I;R!.;W)T90!);&AA<R!-87)I
M86YA(&1O($YO<G1E`$YO<G5E9V$`3N-O($%P\W,`3N-O($%N=&5S`$[C;R#I
M('5M(&1I<F5T\W)I;P!.XV\@26UP;&5M96YT861O+@!.XV\@8V]N9FEG=7)A
M9&\`3N-O('-U<&]R=&%D;RX`06YO=&'G]65S`$YA9&$@<&%R82!E>&EB:7(L
M('9O;'1E+@!.;W9E;6)R;P!.^FUE<F\`3OIM97)O(&1E(&-A<F%C=&5R97,`
M3OIM97)O(&1E(&-O;'5N87,`3OIM97)O(&1E(&QI;FAA<P!.^FUE<F\@;N-O
M(&5S<&5C:69I8V%D;R!P87)A(&%T=6%L:7IAY^-O(&YA(&QI<W1A(&1E(&1I
M<W1R:6)U:>?C;RX`3TL`3V)J971O`$-R:6%D;W(@9&\@3V)J971O`$]C=&%L
M`$]U='5B<F\`1FEL=')O(&]F96YS:79O`$5S8W)I=/-R:6\`4V5N:&%S(&%N
M=&EG82!E(&YO=F$@9&5V96T@<V5R(&1I9F5R96YT97,N`%-E;FAA(&%N=&EG
M80!396YH82!A;G1I9V$@;N-O(&5S=.$@8V]R<F5T82X`3VWC`%-O;65N=&4@
M<V5R=FED;W)E<R!)34%0('-U<&]R=&%M('!A<W1A<R!C;VUP87)T:6QH861A
M<RX`4V]M96YT92!S;W)T97,@;V9E;G-I=F%S`%-O;65N=&4@=6T@96YD97)E
MYV\@9&4@92UM86EL('!E<FUI=&ED;RX`4V]M96YT92!O('!R;W!R:65TX7)I
M;R!O=2!O(&%D;6EN:7-T<F%D;W(@9&\@<VES=&5M82!P;V1E;2!A;'1E<F%R
M(&%S('!E<FUI<W/U97,@9&4@<')O<')I961A9&4@;W4@<')O<')I973A<FEO
M(&1E('5M(&-O;7!A<G1I;&AA;65N=&\`06)R:7(@96T@=6UA(&YO=F$@:F%N
M96QA`$5R<F\@9&\@3W!E;E-33#H@3N-O('!U9&4@97AT<F%I<B!D861O<R!D
M82!P87)T92!A<W-I;F%D82!3+TU)344N`$%B<F4@97-T92!L:6YK(&5M('5M
M82!N;W9A(&IA;F5L80!3:7-T96UA($]P97)A8VEO;F%L`$]PY_5E<P!/<.?U
M97,@9&4@)7,`3&ES=&$@3W)D96YA9&$`3W)G86YI>F'GXV\`56YI9&%D92!/
M<F=A;FEZ86-I;VYA;`!/<F=A;FEZ86YD;P!-;V1E;&\@;W)I9VEN86P@9&4@
M87!L:6-AY^-O`$UO9&5L;R!O<FEG:6YA;"!E;2`E<SH`3W5T<F\`3W5T<F%S
M($EN9F]R;6'G]65S`%!E<FUI<W/U97,@9&\@4')O<')I973A<FEO`$%U=&5N
M=&EC8>?C;R!004T@;N-O(&5S=.$@9&ES<&]N[79E;"X`0V]N96-T;W(@4$5!
M4CHZ36%I;`!!<W-I;F%T=7)A($1I9VET86P@4$=0`$1A9&]S($-R:7!T;V=R
M869A9&]S(&-O;2!01U``0VAA=F4@4/IB;&EC82!01U``1&%D;W,@07-S:6YA
M9&]S+T-R:7!T;V=R869A9&]S(&-O;2!01U``0_-D:6=O(%!(4`!,:6YH82!D
M92!#;VUA;F1O(%!(4`!#:'5V82!&<F%C82!697-P97)T:6YA`$-H=79A(%9E
M<W!E<G1I;F$`0VAU=F%S(%9E<W!E<G1I;F%S`$YE=F4@5F5S<&5R=&EN80!.
M979A<V-A(%9E<W!E<G1I;F$`3F5V92!697-P97)T:6YA`%1R;W9O861A<R!6
M97-P97)T:6YA<P!%<W3A(&9A;'1A;F1O(&$@97AT96YSXV\@4$]325@`3&EN
M:&$@9&4@0V]M86YD;R!07TA0`$UA<F=E;0!087%U:7-TXV\`4&%L874`4&%L
M97-T:6YO+"!497)R:73S<FEO($]C=7!A9&\`4&%N86WA`%#A<'5A($YO=F$@
M1W5I;ND`4&%R86=U86D`4&%R8VEA;&UE;G1E($YU8FQA9&\`4V5N:&$`4V5N
M:&$@86QT97)A9&$@8V]M('-U8V5S<V\N`%-E;FAA(&EN8V]R<F5T80!396YH
M82!O8G)I9V%T\W)I82!P87)A(&$@875T96YT:6-AY^-O(%)!1$E54RX`4V5N
M:&$@8V]M(&-O;F9I<FUAY^-O`%-E;FAA.@!396YH83H@`%-E;FAA<R!D979E
M;2!S97(@:6=U86ES+@!#;VQA<@!#;VQA<B!D82#A<F5A(&1E('1R86YS9F5R
MZFYC:6$`4&%T:`!#861A<W1R;W,@4&5N9&5N=&5S.@!097-S;V%S`%!O<F-E
M;G1A9V5M`$5X96-U=&%R($]P97)AY_5E<R!D92!-86YU=&5NY^-O`$5X96-U
M=&%R(&]P97)AY_5E<R!D92!M86YU=&5NY^-O(&%O(&-O;F5C=&%R/P!097)M
M:7-SXV\`4&5R;6ES<^-O("(E<R(@;N-O(&5X8VQU[61A+@!097)M:7-SXV\@
M3F5G861A`%!E<FUI<W/U97,`061M:6YI<W1R8>?C;R!D92!097)M:7-S]65S
M`$EN9F]R;6'G]65S(%!E<W-O86ES`%!E<G4`06YI;6%I<R!D92!%<W1I;6'G
MXV\`1FEL:7!I;F%S`%1E;&5F;VYE`$9O=&]S`%!I=&-A:7)N`%!I>&5L<P!#
M;&EC:.D`4&]R(&9A=F]R(&-L:7%U92!E;2!A;&=U;6$@8^EL=6QA`%!O<B!F
M879O<B!C;VYF:7)M92!Q=64@=F]CZB!Q=65R(')E;6]V97(@97-T92!E;&5M
M96YT;SH`4&]R(&9A=F]R(&-O;F9I<FUE('%U92!V;V/J('%U97(@<F5M;W9E
M<B!O(&QI;FL@9&5S=&4@96QE;65N=&\N`%!O<B!F879O<B!F;W)N9>=A('5M
M(&WJ<R!E('5M(&%N;RX`4&]R(&9A=F]R(&9O<FYEYV$@=6T@;F]M92!P87)A
M(&$@;F]V82!C871E9V]R:6$Z`%!O<B!F879O<B!F;W)N9>=A('5M(&5N9&5R
M9>=O($E0(';A;&ED;RX`4&]R(&9A=F]R(&9O<FYEYV$@=6UA(&1A=&$@=N%L
M:61A+"!V97)I9FEQ=64@;R!N^FUE<F\@9&4@9&EA<R!N;R!MZG,N`%!O<B!F
M879O<B!F;W)N9>=A('5M82!H;W)A(';A;&ED82X`4&]R(&9A=F]R(&9O<FYE
MYV$@=6T@<F5S=6UO(&1O('!R;V)L96UA+@!0;W(@9F%V;W(@9F]R;F7G82!S
M974@=7-UX7)I;R!E('-E;FAA`%!O<B!F879O<B!L96EA(&\@=&5X=&\@82!S
M96=U:7(N(%9O8^H@1$5612!C;VYC;W)D87(@8V]M(&]S('1E<FUO<R!D92!U
M<V\@9&\@<VES=&5M82X`4&]R(&9A=F]R(&1I9VET92!O(&YO;64@9&$@;F]V
M82!C871E9V]R:6$Z`%!O;/1N:6$`4&]L[71I8V$`16YQ=65T90!0;W)T=6=A
M;`!0;W-IY^-O(&1E<W1A(&EM86=E;0!0;W-IY^-O(&1E<W1A('1A8F5L80!%
M;G9I92!P87)A(&5S=&$@<&%S=&$@*&[C;R#I(&]B<FEG861O('!E;&\@24U!
M4"D`4')E8VEP:71AY^-O('!A<F$@82AS*2#Z;'1I;6$H<RD@)7,@:&]R82AS
M*3H@`%!R96-I<&ET8>?C;SQB<B`O/F-H86YC90!0<F5F<U]L9&%P.B!%>'1E
M;G/C;R!,1$%0(&]B<FEG873S<FEA(&[C;R!E;F-O;G1R861A+@!0<F5F<U]S
M97-S:6]N.B!%>'1E;G/C;R!D92!S97-SXV\@;V)R:6=A=/-R:6$@;N-O(&5N
M8V]N=')A9&$N`%!R97-SXV\`4')E<W/C;R!E;2!N[79E;"!D;R!M87(Z(`!0
M<F5S<^-O.B``4'+I+79I<W5A;&EZ8>?C;P!0<F5V97(@82!I;6%G96T@96T@
M=6UA(&YO=F$@:F%N96QA`$]PY_5E<R!A;G1E<FEO<F5S`$EM<')I;6ER(&1O
M8W5M96YT;P!#:&%V92!0<FEV861A`%!R;V)L96UA`$1E<V-R:>?C;R!D;R!0
M<F]B;&5M80!0<F]J971O<P!497AT;R!B<F5V90!#:&%V92!0^F)L:6-A`$%L
M9V]R:71M;R!D82!#:&%V92!0^F)L:6-A`$-H879E(%#Z8FQI8V$`4&%R(&1E
M(&-H879E<R!0^F)L:6-A+U!R:79A9&$@;N-O(&9O<F%M(&=E<F%D;W,@8V]M
M('-U8V5S<V\N`%!O<G1O(%)I8V\`46%T87(`0V]N<W5L=&%R`%%A=&%R`$-H
M879E(%#Z8FQI8V$@4E-!("@E9"!B:70I`$)O=/5E<R!D92!S96QEY^-O`$-H
M=79A`$-H=79A($UA='5T:6YA`$-H=79A(%9E<W!E<G1I;F$`4&%N8V%D87,@
M9&4@0VAU=F$`0VAU=F$@92!.979E`$-H=79A('!A<F$@3F5V90!3;W)T92!!
M;&5A=/-R:6$`4F5L8>?C;P!,97(`3&5R(&UE;G-A9V5N<P!%>&-L=6ER(')E
M86QM96YT92`E<S\@17-T82!O<&5R8>?C;R!NXV\@<&]D92!S97(@9&5S9F5I
M=&$N`%)E;6]V97(@<F5A;&UE;G1E(&]S(&1A9&]S(&1O('5S=>%R:6\@)7,_
M($5S=&$@;W!E<F'GXV\@;N-O('!O9&4@<V5R(&1E<V9E:71A+@!2969A>B!S
M=6$@^FQT:6UA(&'GXV\`071U86QI>F%R`$%T=6%L:7IA<B!-96YU(&1E($5L
M96UE;G1O<R!$:6[B;6EC;W,Z`$%T=6%L:7IA<B!%>&EB:>?C;R!D;R!0;W)T
M86PZ`%)E9V5X`$YA=F5G861O<B!D92!296QAY_5E<P!,97(`3V)S97)V8>?U
M97,`4V5R=FED;W)E<R!296UO=&]S`%523"!296UO=&$@*&AT='`Z+R]W=W<N
M97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F5R`%)E;6]V97(@0FQO8V\`4F5M
M;W9E<B!C;VQU;F$`4F5M;W9E<B!F;W)M871AY^-O`%)E;6]V97(@<&%R`%)E
M;6]V97(@<V-R:7!T(&=R879A9&\@;F\@9&ER973S<FEO('1E;7!O<N%R:6\@
M9&\@<V5R=FED;W(N`%)E;6]V97(@;P!296UO=F5R(&5S=&4@;O,@9&\@9&]C
M=6UE;G1O`%)E;6]V97(@=7-UX7)I;P!296UO=F5R('5S=>%R:6\Z("5S`%-O
M;&EC:71AY^-O(&[C;R!P]&1E('-E<B!R97-P;VYD:61A+B!#\V1I9V\@9&4@
M97)R;R!R971O<FYA9&\Z(`!/('-E<G9IYV\@<F5Q=6ES:71A9&\@;N-O('!O
M9&4@<V5R(&5N8V]N=')A9&\N`"<E<R<@;V)R:6=A=/-R:6\@;N-O(&9O:2!E
M<W!E8VEF:6-A9&\@;F$@8V]N9FEG=7)AY^-O("5S+@`G)7,G(&]B<FEG873S
M<FEO(&[C;R!F;VD@97-P96-I9FEC861O(&YA(&-O;F9I9W5R8>?C;R!61E,N
M`"<E<R<@;V)R:6=A=/-R:6\@;N-O(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N
M9FEG=7)AY^-O+@!#86UP;R!/8G)I9V%T\W)I;P!,:6UP87(`1V5R87(@3F]V
M82!396YH80!'97)A<B!.;W9A(%-E;FAA`-IL=&EM;R!1=6%R=&\`4F5S=6QT
M861O<P!2971O<FYA<B#@($]PY_5E<P!$:6=I=&4@82!N;W9A('-E;FAA(&YO
M=F%M96YT90!2975N:>-O`%)E=F5R=&5R($-O;F9I9W5R8>?C;P!/<.?U97,@
M9&\@161I=&]R(%)I8V@@5&5X=`!#:&%R861A<P!$:7)E:71A`$-A8F7G86QH
M;R!D:7)E:71O`%9A;&]R97,@9&$@9&ER96ET80!0<F]P<FEE9&%D97,@9&$@
M7TQI;FAA+BXN`$9U;N?C;P!2;VWJ;FEA`$=I<F%R(#$X,"!G<F%U<P!':7)A
M<B!P87)A(&$@17-Q=65R9&$`1VER87(@<&%R82!A($1I<F5I=&$`4')O<')I
M961A9&5S(&1A($QI;FAA`%!R;W!R:65D861E<R!D82!L:6YH80!,:6YH87,Z
M`$QI;FAA<P!,:6YH87,@87!A<F5C97+C;R!E;G1R92!T;V1A<R!A<R!L:6YH
M87,@92!C;VQU;F%S`$QI;FAA<R!A<&%R96-E<N-O('-O;65N=&4@96YT<F4@
M8V]L=6YA<P!,:6YH87,@87!A<F5C97+C;R!S;VUE;G1E(&5N=')E(&QI;FAA
M<P!%>&5C=71A<@!&961E<F'GXV\@4G5S<V$`4G5A;F1A`$%S<VEN871U<F$@
M0W)I<'1O9W+A9FEC82!3+TU)344`365N<V%G96T@0W)I<'1O9W)A9F%D82!C
M;VT@4R]-24U%`$%U=&5N=&EC8>?C;R!305-,(&[C;R!E<W3A(&1I<W!O;NUV
M96PN`$-O<G)E:6\@4TU3`$QI;FAA(&1E(&-O;6%N9&\@4U%,`%-E;G1E;N=A
M(%-13"!P87)A('!E<W%U:7-A<R!D92!V86QO<F5S`%-32`!354-%4U-/`$QI
M;FAA(&1E(&-O;6%N9&\@4U]13`!386(`4V%N=&$@2&5L96YA`%/C;R!+:71T
M<R!E($YE=FES`%-A;G1A($QU>FEA`%/C;R!0961R;R!E($UI<75E;&]N`%/C
M;R!6:6-E;G1E(&4@1W)A;F%D:6YA<P!-97-M;R!Q=6%D<F\@*%]S96QF*0!3
M86UO80!386X@36%R:6YO`%/C;R!4;VWI(&4@4'+M;F-I<&4`4')O=F5D;W(@
M9&4@4V%TZ6QI=&4`07+A8FEA(%-A=61I=&$`4V%L=F%R`%-A;'9A<B`E<P!3
M86QV87(@)7,`4V%L=F%R($]PY_5E<P!386QV87(@8V]N9FEG=7)AY^-O(&=E
M<F%D82!C;VUO('5M('-C<FEP="!02%`@<&%R82!O(&1I<F5T\W)I;R!T96UP
M;W+A<FEO(&1O('-E=2!S97)V:61O<BX`0V]N9FEG=7)AY^-O("5S('-A;'9A
M+@!38W)I<'0@9&4@871U86QI>F'GXV\@9&4@8V]N9FEG=7)AY^-O('-A;'9O
M(&5M.B`G)7,G+@!496UP97-T861E<R!)<V]L861A<P!#:>IN8VEA`%!E<W%U
M:7-A<@!%;F=I;F5S(&1E(%!E<W%U:7-A(`!396QE8VEO;F4@;W,@07)Q=6EV
M;W,`4V5L96-I;VYE('5M82!D871A`%-E;&5C:6]N92!U;2!G<G5P;R!P87)A
M(&%D:6-I;VYA<@!396QE8VEO;F4@=6T@;F]V;R!M96UB<F\`4V5L96-I;VYE
M('5M('-E<G9I9&]R`%-E;&5C:6]N92!U;2!U<W7A<FEO('!A<F$@861I8VEO
M;F%R`%-E;&5C:6]N87(@=&]D;W,`4V5L96-I;VYE('1O9&]S(&]S(&-O;7!O
M;F5N=&5S(&1E(&1A=&$N`%-E;&5C:6]N92!U;2!O8FIE=&\`3N-O('-E;&5C
M:6]N87(@;F5N:'5M`%-E;&5C:6]N92!O<R!C87)A8W1E<F5S('%U92!V;V/J
M('!R96-I<V$@;F$@8V%I>&$@86)A:7AO+B!6;V/J('!O9&4@96YTXV\@8V]P
M:>$M;&]S(&4@8V]LX2UL;W,@;F$@X7)E82!D92!T97AT;RX`4V5L96-I;VYE
M('5M(&1E;&EM:71A9&]R(&1E(&1A=&$Z`%-E;&5C:6]N92!O(&9O<FUA=&\@
M9&4@9&%T83H`4V5L96-I;VYE(&$@:61E;G1I9&%D92!Q=64@=F]CZB!Q=65R
M(&%L=&5R87(Z`%-E;&5C:6]N92!U;2!D96QI;6ET861O<B!D92!H;W)A.@!3
M96QE8VEO;F4@;R!F;W)M871O(&1E(&AO<F$Z`%-E;&5C:6]N92!D;VES(&-A
M;7!O<R!C;W)R97-P;VYD96YT97,N`%-E;&5C:6]N92!S974@97-Q=65M82!D
M92!C;W)E<RX`4V5L96-I;VYE('-E=2!I9&EO;6$@<')E9F5R:61O.@!%;G9I
M87(@4F5L873S<FEO(&1E(%!R;V)L96UA`$5N=FEA<B!335,`4V5N96=A;`!3
M96YS;W(Z(`!3971E;6)R;P!397)V:6$@92!-;VYT96YE9W)O`$[Z;65R;R!D
M92!3Z7)I90!$861O<R!D;R!S97)V:61O<B!E<G)A9&]S(&]U(&[C;R!D:7-P
M;V[M=F5I<RX`061M:6YI<W1R861O<B!D92!397-SXV\`240@9&$@4V5S<^-O
M(&5X<&ER;W4N`%-E<W/U97,`06IU<W1A<@!#;VYF:6=U<F$@87,@;W#G]65S
M('!A<F$@<&5R;6ET:7(@=F]CZB!G97)A<B!U;6$@;F]V82!S96YH82!S92!V
M;V/J(&5S<75E8^HM;&$N`$-O;F9I9W5R82!O<R!S97)V:61O<F5S(')E;6]T
M;W,@<75E('9O8^H@<75E<B!A8V5S<V%R(.`@<&%R=&ER(&1O('!O<G1A;"X`
M0V]N9FEG=7)A('-E=2!I9&EO;6$@<')E9F5R:61O+"!F=7-O(&AO<N%R:6\@
M92!O<.?U97,@9&4@9&%T82X`0V]N9FEG=7)A('-U82!A<&QI8V'GXV\@:6YI
M8VEA;"P@97-Q=65M82!D92!C;W)E<RP@871U86QI>F'GXV\@9&4@<.%G:6YA
M<R!E(&]U=')A<R!O<.?U97,@9&4@97AI8FGGXV\N`$-O;F9I9W5R8>?C;P!3
M8W)I<'1S(&1E(&%T=6%L:7IAY^-O(&1E(&-O;F9I9W5R8>?C;R!D:7-P;V[M
M=F5I<P!$:79E<G-A<R!L;V-A;&ED861E<R!P;W-S[79E:7,@8V]M(&\@<&%R
MXFUE=')O.B``4V5I8VAE;&5S`$-O;7!R87,`4F5S=6UO`%1E8VQA<R!D92!A
M=&%L:&\@9&5V97+C;R!S97(@9&5F:6YI9&%S('!A<F$@82!M86EO<FEA(&1O
M<R!L:6YK<S\`17AI8FER`$5X:6)I<B!A<R!D:69E<F5NYV%S(&5N=')E(&$@
M8V]N9FEG=7)AY^-O(&%T=6%L(&4@82!N;W9A(&=E<F%D82X`17AI8FER(&1A
M=&$@92!H;W)A(&1A(/IL=&EM82!C;VYE>.-O(&%O('-E(&-O;F5C=&%R/P!%
M>&EB:7(@82!O<.?C;R!D92!M86YT97(@;R!O<FEG:6YA;`!%>&EB:7(@<V5L
M971O<@!%>&EB:7(@8F%R<F$@9&4@;65N=2!C;VT@;W!E<F'G]65S(&1E('1A
M8F5L83\`17AI8FER(&\@365N=2`E<R#@(&5S<75E<F1A/P!%>&EB:7(@9&GA
M;&]G;R!D92!0<F]P<FEE9&%D97,@9&4@0^EL=6QA<R!D82!486)E;&$`17AI
M8FER(&1IX6QO9V\@9&4@4')O<')I961A9&5S(&1A(%1A8F5L80!%>&EB:7(@
M9&GA;&]G;R!D92!0<F]P<FEE9&%D97,@9&4@3&EN:&%S(&1A(%1A8F5L80!%
M>&EB:7(@9&GA;&]G;R!D92!P<F]P<FEE9&%D97,@9&4@:6UA9V5M`$5X:6)I
M<B!U<&QO860`0VAU=F%S`$-H=79A<R!M871I;F%I<P!#:'5V87,@5F5S<&5R
M=&EN87,`0VAU=F%S(&YA<R!R961O;F1E>F%S`%)E9'5Z:7(`4')I;65I<F%M
M96YT92!R961U>F$@;W4@=&ER92!D;R!C86UI;FAO(&\H<RD@8FQO8V\H<RD@
M861J86-E;G1E*',I`%-E<G)A($QE;V$`4F5G:7-T<F%R`$%S<VEN871U<F$`
M06QG;W)I=&UO(&1A($%S<VEN871U<F$`0VEN9V%P=7)A`%1A;6%N:&\`26=N
M;W)A<B!-86YU=&5NY^-O`$5S;&]VX7%U:6$`17-L;W9E;FEA`$YE=F4`3F5V
M87-C80!.979A<V-A<P!#:'5V87,@;6%T:6YA:7,`3F5V87-C87,@5F5S<&5R
M=&EN87,`4')O9G5N9&ED861E(&1A($YE=F4Z(`!%<75I=F%L96YT92!D92!N
M979E(&5M(.%G=6$Z(`!);&AA<R!386QO;>-O`%-O;>%L:6$`0V%NY_5E<R`F
M(%!O96UA<P!/<F1E;F%R('-E;&7GXV\`16YD97)EYV\@9&4@;W)I9V5M`,%F
M<FEC82!D;R!3=6P`4W5L($5U<F]P974@*$E33RTX.#4Y+3,I`%-U;"!D82!'
M96]R9VEA(&4@4W5L(&1A<R!);&AA<R!386YD=>UC:&4`2&5M:7-FZ7)I;R!3
M=6P`17-P8>=O(&5N=')E(&/I;'5L87,@861J86-E;G1E<P!%<W!AYV\@96YT
M<F4@;R!C;VYT9?ID;R!E(&)O<F1A(&1A(&/I;'5L80!%<W!AYV%D;W(`17-P
M8>=A;65N=&\`17-P8>=A;65N=&\@92!M87)G96T`17-P86YH80!3<&%M`$5N
M=')A9&$@9&4@0V%R86-T97)E<R!%<W!E8VEA:7,`1&EV:61I<B!CZ6QU;&$`
M1&EV:61I<B!C;VQU;F$`1&EV:61I<B!L:6YH80!%<W!O<G1E<P!3<FD@3&%N
M:V$`4&%D<N-O`%-T87(@5')E:P!!;F\@:6YI8VEA;`!%<W1A9&\@;W4@4')O
M=NUN8VEA`%-I='5AY^-O`$9O<FUA=&\@9&\@87)M87IE;F%M96YT;P!.;VUE
M(&1A(%)U80!4<F'G861O`$QI<W1A(&1E(&-A9&5I87,@9&4@8V%R86-T97)E
M<P!2971I<F%R(&$@<&%R=&4@9&\@9&]M[6YI;R!D;R!E;F1E<F7G;P!%<W1I
M;&\@6T-34UT`1&]M`%-U8F1I<F5T\W)I;R`G)7,G(&[C;R!E;F-O;G1R861O
M+@!!<W-U;G1O`$5N=FEA<@!%;G9I861A(&$@<V]L:6-I=&'GXV\@9&4@861I
M8VEO;F%R("(E<R(@86\@<VES=&5M82X@5F]CZB!NXV\@<&]D92!C;VYE8W1A
M<BUS92!A=.D@<75E('-U82!S;VQI8VET8>?C;R!S96IA(&%P<F]V861A+@!3
M=6)S8W)E=F5R`%-U8V5S<V\`)R5S)R!A9&EC:6]N861O(&-O;2!S=6-E<W-O
M(&%O('-I<W1E;6$N`$]S(&1A9&]S(&1O('5S=>%R:6\@)R5S)R!F;W)A;2!R
M96UO=FED;W,@9&\@<VES=&5M82!C;VT@<W5C97-S;RX`)R5S)R!E>&-L=>UD
M;R!C;VT@<W5C97-S;RX`17AC;'7M9&\@)R5S)R!D;R!S:7-T96UA(&-O;2!S
M=6-E<W-O+@!#;VYF:6=U<F'GXV\@<F5V97)T:61A(&-O;2!S=6-E<W-O+B!!
M='5A;&EZ92!P87)A('9E<B!A<R!A;'1E<F'G]65S+@!"86-K=7`@9&$@8V]N
M9FEG=7)AY^-O('-A;'9A(&-O;2!S=6-E<W-O+@!/(&)A8VMU<"!D;R!A<G%U
M:79O(&1E(&-O;F9I9W5R8>?C;R`E<R!F;VD@<V%L=F\@8V]M('-U8V5S<V\N
M`"<E<R<@871U86QI>F%D;R!C;VT@<W5C97-S;P`E<R!G<F%V861O(&-O;2!S
M=6-E<W-O`%-U9.-O`%)E<W5M;P!!;6%N:&5C97(`4/1R+61O+5-O;`!%;G-O
M;&%R861O`$%M86YH96-E<@!!;6%N:&5C97(O4/1R+61O+5-O;`!!;6%N:&5C
M97(Z(`!0]'(M9&\M4V]L`%#T<BUD;RU3;VPZ(`!3;V)R97-C<F5V97(`4W5P
M;W)T90!3=7)I;F%M90!3;V)R96YO;64`4W9A;&)A<F0@92!*86X@36%Y96X`
M4W5A>FELXFYD:6$`4W7I8VEA`%-U[>=A`$[C;R!E>&-L=6ER`%-Y;F--3`!%
M<G)O(&1E('-I;G1A>&4@;F]S('1E<FUO<R!D82!P97-Q=6ES80!297#Z8FQI
M8V$@P7)A8F4@9&$@4^UR:6$`5&5M<&5S=&%D90!496UP97-T861E<R!E(%9E
M;G1A;FEA`%1E;7!E<W1A9&5S`%1E;7!E<W1A9&5S($UA=&EN86ES`$%R<75I
M=F\@5%-6`%1A8F5L80!0<F]P<FEE9&%D97,@9&$@5&%B96QA`%1A8F5L80!0
M<F]P<FEE9&%D97,@9&$@=&%B96QA`%1A:7=A;@!486EW86XL(%!R;W;M;F-I
M82!D82!#:&EN80!486II<75I<W3C;P!486YZXFYI82P@4F5P^F)L:6-A(&1A
M`$%L=F\Z`%1A<F5F87,`3OIM97)O(&1E(%1E;&5F;VYE`%1E;7!E<F%T=7)A
M('!A<F$@82#Z;'1I;6$@:&]R83H@`%1E;7!E<F%T=7)A`%1E;7!E<F%T=7)A
M.B``5&5M<&5R871U<F$\8G(@+SXH)7-!;'1A)7,O)7-"86EX825S*2`F9&5G
M.R5S`$UO9&5L;R`G)7,G(&[C;R!E;F-O;G1R861O+@!!9&UI;FES=')AY^-O
M(&1E($UO9&5L;W,`5&5X=&\`4V]M96YT92!497AT;P!!;&EN:&%M96YT;R!D
M92!497AT;P!";W)D82!S=7!E<FEO<B!D;R!497AT;P!1=6D`5&%I;&%N9.IS
M("A425,M-C(P*0!486ELXFYD:6$`02!E>'1E;G/C;R!&5%`@;N-O(&5S=.$@
M9&ES<&]N[79E;"X`3R!H:7-T\W)I8V\@9&\@<VES=&5M82!E<W3A(&1E<V%B
M:6QI=&%D;RX`02!E;F=I;F4@9&4@:6YT96=R8>?C;R!(;W)D92]+;VQA8B!N
MXV\@<W5P;W)T82`B)7,B`$\@;&]G($E-4U`@;N-O('!O9&4@<V5R(&EN:6-I
M86QI>F%D;RX`02!C;&%S<V4@(DUA:6YT96YA;F-E(B!NXV\@9F]I(&-A<G)E
M9V%D82!C;VT@<W5C97-S;P!!(&IA;F5L82!D92!/<.?U97,@9F]I(&9E8VAA
M9&$N(%-A:6YD;RX`3R!A9&UI;FES=')A9&]R('!R96-I<V$@8V]N9FEG=7)A
M<B!U;2!C;VYE8W1O<B!P97)M86YE;G1E(&1E(%!E<FUI<W/U97,@<V4@=F]C
MZB!Q=65R('5T:6QI>F%R(%!E<FUI<W/U97,N`%-O;65N=&4@;R!L861O(&1E
M(&)A:7AO`$\@;OIM97)O($E$(&1O(&-O;G1A=&\@;N-O(&9O:2!E<W!E8VEF
M:6-A9&\L(&1E:7AA9&\@96T@8G)A;F-O(&]U(&[C;R!F;VD@96YC;VYT<F%D
M;R!N;R!B86YC;R!D92!D861O<RX`3R!C;VYT871O(&9O:2!A9&EC:6]N861O
M(&-O;2!S=6-E<W-O(&%O('-E=2!C873A;&]G;R!D92!E;F1E<F7G;W,N`%!A
M<F$@=F5R:69I8V%R(&$@;65N<V%G96T@87-S:6YA9&$@Z2!N96-E<W/A<FEO
M('5M(&)L;V-O('-E<&%R861O(&1A(&%S<VEN871U<F$@4$=0+@!/($E$(&1A
M(&QI<W1A(&1E(&1I<W1R:6)U:>?C;R!NXV\@9F]I(&5S<&5C:69I8V%D;RP@
M9&5I>&%D;R!E;2!B<F%N8V\@;W4@;N-O(&9O:2!E;F-O;G1R861O(&YO(&)A
M;F-O(&1E(&1A9&]S+@!!(&QI<W1A(&1E(&1I<W1R:6)U:>?C;R!NXV\@9F]I
M(&5S<&5C:69I8V%D82X`07,@9G5NY_5E<R!D92!C<FEP=&]G<F%F:6$@<F5Q
M=65R96T@=6UA(&-O;F5XXV\@=V5B('-E9W5R82X`3R!A<G%U:79O("5S(&1E
M=F5R:6$@8V]N=&5R('5M82!C;VYF:6=U<F'GXV\@9&4@)7,N`$\@87)Q=6EV
M;R`E<R!D979E<FEA(&-O;G1E<B!A;&=U;6%S(&-O;F9I9W5R8>?U97,@9&4@
M)7,N`$\@87)Q=6EV;R!NXV\@<&]D92!S97(@8V]P:6%D;R!P87)A(&5L92!M
M97-M;RX`3R!A<G%U:79O(&[C;R!C;VYTZ6T@9&%D;W,N`%-E9W5E;2!O<R!C
M86)EYV%L:&]S(&1E<W1A(&UE;G-A9V5M+VUE;G-A9V5M(')F8S@R,BX`R2!S
M86)I9&\@<75E(&\@;6]D;R!T96QA(&-H96EA(&-A=7-A('!R;V)L96UA<R!C
M;VT@;R!);G1E<FYE="!%>'!L;W)E<BP@96T@=FER='5D92!D92!B=6=S(&1O
M(&YA=F5G861O<B!Q=64@;O-S(&[C;R!E<W1A;6]S(&%P=&]S(&$@8V]N=&]R
M;F%R+B!6;V/J('!O9&4@;V)S97)V87(@97)R;W,@9&4@97AI8FGGXV\L(&9A
M;'1A(&1E(&9U;N?U97,@9&\@961I=&]R(&4O;W4@=')A=F%M96YT;W,@86QE
M873S<FEO<R!D;R!N879E9V%D;W(N(%-E('-E=2!S:7-T96UA(.D@5VEN9&]W
M<R`Y>"#I(&UU:71O('!R;W;A=F5L('%U92!V;V/J(')E8V5B82!U;2!E<G)O
M(&1E("=&86QH82!'97)A;"!D92!0<F]T9>?C;R<@92!P<F5C:7-A<N$@<F5I
M;FEC:6%R+B!<;EQN(%9O8^H@9F]I(&%V:7-A9&\N(%!O<B!F879O<B!P<F5S
M<VEO;F4@3TL@<V4@=F]CZB!A:6YD82!Q=65R('1E;G1A<B!U<V%R(&\@961I
M=&]R(&1E('1E;&$@8VAE:6$N`$$@:61E;G1I9&%D92`B)7,B(&9O:2!E>&-L
M=>UD82X`4V]M96YT92!O(&QA9&\@97-Q=65R9&\`02!L;V-A;&EZ8>?C;R!D
M;R!B:6[A<FEO(&1O($=N=5!'(&1E=F4@<V5R(&9O<FYE8VED82#@(&-L87-S
M92`B0W)Y<'1?<&=P(BX`02!M96YS86=E;2!E;G9I861A(&5M("5S('!A<F$@
M)7,@8V]M(&\@87-S=6YT;R`B)7,B(&9O:2!E>&EB:61A+@I)<W1O(&[C;R!G
M87)A;G1E('%U92!A(&UE;G-A9V5M(&9O:2!L:61A(&]U(&5N=&5N9&ED82X`
M3R!N;VUE('5T:6QI>F%D;R!A;R!V:6YC=6QA<B!A('#A9VEN82!D92!C;VUP
M;W-IY^-O`$\@;OIM97)O(&1E(&-A;7!O<R!D979E('-E<B!N=6WI<FEC;RX`
M3R!M\V1U;&\@;W!E;G-S;"#I(&]B<FEG873S<FEO('!A<F$@82!C;&%S<V4@
M(DAO<F1E7T-R>7!T7W-M:6UE(BX`02!P<F5F97+J;F-I82`B)7,B(&[C;R!P
M;V1E('-E<B!S86QV82!P;W)Q=64@<V5U<R!D861O<R!E>&-E9&5R86T@;R!T
M86UA;FAO(&WA>&EM;R!P97)M:71I9&\`3R!P<F]G<F%M82!U=&EL:7IA9&\@
M<&%R82!V:7-U86QI>F%R(&5S=&4@=&EP;R!D92!D861O("@E<RD@;N-O(&9O
M:2!E;F-O;G1R861O(&YO('-I<W1E;6$N`$\@8V%R86-T97)E('!A<F$@8VET
M8>?C;R!D92!S97(@87!E;F%S('5M+@!3;VUE;G1E(&]S(&QA9&]S(&1I<F5I
M=&\@92!E<W%U97)D;P!3;VUE;G1E(&\@;&%D;R!D:7)E:71O`$\@<V5P87)A
M9&]R(&1E=F4@<V5R('5M(/IN:6-O(&-A<F%C=&5R92X`3R!S97)V:61O<B`B
M)7,B(&9O:2!E>&-L=>UD;RX`3R!S97)V:61O<B`B)7,B(&9O:2!S86QV;RX`
M02!S;VQI8VET8>?C;R!D92!C861A<W1R;R!D92`E<R!F;VD@97AC;'7M9&$N
M`$$@;&EN:&$@97-P96-I9FEC861A("@E9"D@;N-O(&5X:7-T92X`3R!A<G%U
M:79O('1E;7!O<N%R:6\@(B5S(B!NXV\@97AI<W1E+@!/('1E>'1O('%U92!V
M;V/J(&1I9VET;W4@;N-O(&-O<G)E<W!O;F1E(&%O('1E>'1O(&YA('1E;&$N
M`%-O;65N=&4@;W,@;&%D;W,@9&4@8VEM82!E(&1E(&)A:7AO`%-O;65N=&4@
M;R!L861O(&1E(&-I;6$`3W,@9&%D;W,@96YV:6%D;W,@9F]R86T@<&5R9&ED
M;W,@9&5S9&4@;R!P87-S;R!A;G1E<FEO<BX`3R!A<G%U:79O(&5N=FEA9&\@
M;N-O('#T9&4@<V5R('-A;'9O+@!/(&)L;V-O(")W96%T:&5R+F-O;2(@;N-O
M(&5S=.$@9&ES<&]N[79E;"X`3R!D:7)E=/-R:6\@9&4@=&5M87,@)R5S)R!N
MXV\@9F]I(&5N8V]N=')A9&\N`$[C;R!E>&ES=&5M(&]PY_5E<R!D:7-P;V[M
M=F5I<RX`3N-O(&5X:7-T96T@<&%R=&5S('%U92!P;W-S86T@<V5R(&5X:6)I
M9&%S(&EN8V]R<&]R861A<RX`17AI<W1E;2!M=6ET;W,@8V%R86-T97)E<R!N
M97-T92!C86UP;RX@5F]CZB!P<F5E;F-H974@8V]M("5S(&-A<F%C=&5R97,[
M('9O8^H@9&5V92!P<F5E;F-H97(@8V]M("5S(&]U(&UE;F]S+@!(;W5V92!U
M;2!P<F]B;&5M82!A9&EC:6]N86YD;R`G)7,G(&%O('-I<W1E;6$Z("5S`$AO
M=79E('5M('!R;V)L96UA(&%O(&5X8VQU:7(@9&\@<VES=&5M82!O<R!D861O
M<R!D;R!U<W7A<FEO("<E<R<Z(`!(;W5V92!U;2!P<F]B;&5M82!A;R!E>&-L
M=6ER("<E<R<@9&\@<VES=&5M83H@`$AO=79E('5M('!R;V)L96UA(&%O(&%T
M=6%L:7IA<B`G)7,G.B`E<P!(;W5V92!U;2!P<F]B;&5M82!C;VT@;R!E;G9I
M;R!D;R!A<G%U:79O.B!.96YH=6T@)7,@9F]I(&5N=FEA9&\N`$AO=79E('5M
M('!R;V)L96UA(&-O;2!O(&5N=FEO(&1O(&%R<75I=F\N($\@)7,@97)A(&UA
M:6]R('%U92!O('1A;6%N:&\@;>%X:6UO('!E<FUI=&ED;R`H)60@8GET97,I
M+@!(;W5V92!U;2!P<F]B;&5M82!C;VT@;R!E;G9I;R!D;R!A<G%U:79O+B!/
M("5S(&9O:2!E;G9I861O('!A<F-I86QM96YT92X`2&]U=F4@=6T@97)R;R!A
M;R!E>&EB:7(@97-T82!P87)T92!D82!M96YS86=E;0!(;W5V92!U;2!E<G)O
M(&%O(&EM<&]R=&%R(&]S(&1A9&]S(&1O(&-O;G1A=&\N`$AO=79E('5M(&5R
M<F\@86\@:6UP;W)T87(@;W,@9&%D;W,@9&\@:4-A;&5N9&%R+@!(;W5V92!U
M;2!E<G)O(&YO(&9O<FUU;.%R:6\@9&4@8V]N9FEG=7)AY^-O+B!486QV97H@
M=F]CZB!D96EX;W4@=6T@8V%M<&\@;V)R:6=A=/-R:6\@96T@8G)A;F-O+@!(
M;W5V92!U;2!E<G)O(&%O(&5X96-U=&%R(&$@9G5NY^-O(&1E(&-A=.%L;V=O
M(&1E(&5N9&5R9>=O<R!E<W!E8VEF:6-A9&$N(%!O<B!F879O<B!T96YT92!N
M;W9A;65N=&4@;6%I<R!T87)D92X`2&]U=F4@=6T@97)R;R!A;R!A='5A;&EZ
M87(@;W,@9&5T86QH97,@9&\@8V]N=&%T;RX@4&]R(&9A=F]R('1E;G1E(&YO
M=F%M96YT92!M86ES('1A<F1E+@!(;W5V92!U;2!E<G)O(&%O(&%T=6%L:7IA
M<B!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@4&]R(&9A=F]R('1E;G1E(&YO
M=F%M96YT92!M86ES('1A<F1E+@!%<W1E('-E<G9I9&]R($E-05`@;N-O('-U
M<&]R=&$@<&%S=&%S(&-O;7!A<G1I;&AA9&%S+@!%<W1E(&[C;R!P87)E8V4@
M<V5R('5M(&%R<75I=F\@<F%R(';A;&ED;RX`17-T92!NXV\@<&%R96-E('-E
M<B!U;2!A<G%U:79O('II<"!VX6QI9&\N`$5S=&4@;N-O('!A<F5C92!S97(@
M=6T@;OIM97)O(&1E(&-A<G3C;R!VX6QI9&\N`$5S=&4@8V]N96-T;W(@<&5R
M;6ET92!E;G9I87(@;65N<V%G96YS(&%T<F%VZ7,@9&\@0VQI8VMA=&5L;"`H
M:'1T<#HO+V-L:6-K871E;&PN8V]M*2P@=71I;&EZ86YD;R!A($%022!(5%10
M`$5S=&4@8V]N96-T;W(@<&5R;6ET92!E;G9I87(@;65N<V%G96YS(&%T<F%V
MZ7,@9&\@9V%T97=A>2!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M
M*2P@=71I;&EZ86YD;R!O($%022!(5%10`$5S=&4@8V]N96-T;W(@<&5R;6ET
M92!E;G9I87(@;65N<V%G96YS(&%T<F%VZ7,@9&\@9V%T97=A>2!S;7,R96UA
M:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2P@=71I;&EZ86YD;R!O($%022!(
M5%10`$5S=&4@8V]N96-T;W(@<&5R;6ET92!E;G9I87(@=6UA(&UE;G-A9V5M
M('9I82!33510(&%T<F%VZ7,@9&\@5F]D869O;F4@271A;&EA;F\L('-O;65N
M=&4@<&%R82!N^FUE<F]S(%9O9&%F;VYE+B#)(&]B<FEG873S<FEO('!O<W-U
M:7(@=6UA(&-O;G1A(&YO(%9O9&%F;VYE($ET86QI86YO("AH='1P.B\O=W=W
M+C$Y,"YI="DN`$5S=&4@8V%M<&\@Z2!O8G)I9V%T\W)I;RX`17-T92!C86UP
M;R!P;V1E(&-O;G1E<B!A<&5N87,@;OIM97)O<R!I;G1E:7)O<RX`17-T92!C
M86UP;R!P;V1E(&-O;G1E<B!A<&5N87,@;OIM97)O<R!E(';M<F=U;&$N`$5S
M=&4@8V%M<&\@<&]D92!C;VYT97(@87!E;F%S('9A;&]R97,@;V-T86ES+@!%
M<W1E(&-A;7!O(&1E=F4@<V5R('5M82!L:7-T82!D92!N^FUE<F]S(&EN=&5I
M<F]S('-E<&%R861A('!O<B!V[7)G=6QA<R!O=2!E<W!AYV]S`$5S=&4@8V%M
M<&\@9&5V92!S97(@=6T@;OIM97)O(';A;&ED;RX`17-T92!C86UP;R!D979E
M(&-O;G1E<B!U;2!C\V1I9V\@9&4@8V]R(&5M(&9O<FUA=&\@4D="($AE>&$L
M('!O<B!E>&5M<&QO("<C,3(S-&%F)RX`17-T92!F;W)M=6SA<FEO(&KA(&9O
M:2!P<F]C97-S861O+@!)<W1O(.D@)7,N`$5S=&4@Z2!U;2!O8FIE=&\@2V]L
M86(@1W)O=7!W87)E+B!087)A('9I<W5A;&EZ87(@97-T92!O8FIE=&\@=F]C
MZB!P<F5C:7-A<N$@9&4@=6T@8VQI96YT92!D92!C;W)R96EO('%U92!E;G1E
M;F1A(&\@9F]R;6%T;R!+;VQA8B!'<F]U<'=A<F4N(%!A<F$@=6UA(&QI<W1A
M(&1E(&-L:65N=&5S(&1E(&-O<G)E:6\@8V]M(&5S=&%S(&9U;N?U97,@<&]R
M(&9A=F]R('9I<VET92`E<P!%<W1A(&UE;G-A9V5M(&9O:2!E<V-R:71A(&5M
M('5M(&-O;FIU;G1O(&1E(&-A<F%C=&5R97,@*"5S*2!Q=64@;N-O(.D@;R!M
M97-M;R!Q=64@;R!S974N`$5S=&4@;OIM97)O(&1E=F4@<V5R('!E;&\@;65N
M;W,@=6TN`$5S=&4@<V5R=FED;W(@;N-O('!O9&4@9&5S8V]M<')I;6ER(&%R
M<75I=F]S('II<"!E(&=Z:7`N`$5S=&4@<VES=&5M82!E<W3A(&%T=6%L;65N
M=&4@9&5S871I=F%D;RX`17-T92!V86QO<B!D979E('-E<B!U;2!N^FUE<F\N
M`$5S=&$@:F%N96QA(&1E=F4@<V5R(&-H86UA9&$@82!P87)T:7(@9&$@:F%N
M96QA(&1E($]PY_5E<P!286EO`$)I;&AE=&5S`$AO<F$`06-O;7!A;FAA;65N
M=&\@9&4@2&]RX7)I;P!&;W)M871O(&1E(&AO<F$`4V5L9>?C;R!D92!H;W)A
M`%1I;6]R($QE<W1E`%3M='5L;P!!<W-U;G1O("AD:6-A*3H`4&%R80!087)A
M('-E;&5C:6]N87(@;?IL=&EP;&]S(.UT96YS+"!S96=U<F4@82!T96-L82!#
M;VYT<F]L("A00RD@;W4@0V]M;6%N9"`H36%C*2!A;R!C;&EC87(N`$AO:F4`
M5')O8V%R('!A<F$@8_-D:6=O($A434P`5&]G;P!4;VME;&%U`$%M86YHXP!4
M;VYG80!4;W!O`%%U861R;R!D;R!4;W!O("A?=&]P*0!4<F%D=>?U97,`5')I
M;F1A9&4@92!4;V)A9V\`5F5R9&%D96ER;R!O=2!F86QS;P!497(`5'5N[7-I
M80!4=7)Q=6EA`%1U<F-O("A)4T\M.#@U.2TY*0!4=7)C;VUE;FES=.-O`$EL
M:&%S(%1U<FMS(&4@0V%I8V]S`%1U=F%L=0!0<F5E;F-H82!C;VT@<W5A(&5S
M8V]L:&$Z(`#-;F1I8V4@52Y6+CH@`%523`!54DP@9&\@<V5U(')E;&%T\W)I
M;R!D92!S:71U8>?C;R!D92!E;G1R96=A`%523#H`56=A;F1A`%5C<N)N:6$`
M26UP;W-S[79E;"!A8V5S<V%R(&1I<F5T\W)I;R!61E,N`$EM<&]S<^UV96P@
M861I8VEO;F%R(&EN9F]R;6'G]65S(&5X=')A<R!D92!U<W7A<FEO(&%O(')E
M9VES=')A<BX`26UP;W-S[79E;"!A;'1E<F%R('!E<FUI<W/C;R!D;R!A<G%U
M:79O(%9&4R`B)7,B+@!);7!O<W/M=F5L(&%L=&5R87(@<&5R;6ES<^-O(&1O
M(&%R<75I=F\@5D93("5S+R5S+@!);7!O<W/M=F5L(&%L=&5R87(@<&%R82`E
M<RX`26UP;W-S[79E;"!V97)I9FEC87(@;R!T86UA;FAO(&1O(&%R<75I=F\@
M9&4@(B5S(BX`26UP;W-S[79E;"!V97)I9FEC87(@;R!T86UA;FAO(&1O(&%R
M<75I=F\@9&4@(B5S+R5S(BX`26UP;W-S[79E;"!C;VYE8W1A<B!A;R!S97)V
M:61O<B!344PN`$EM<&]S<^UV96P@8V]N96-T87(@=71I;&EZ86YD;R!34TPN
M`$EM<&]S<^UV96P@8V]P:6%R(&%R<75I=F\@5D93+@!);7!O<W/M=F5L(&-R
M:6%R(&1I<F5T\W)I;R!61E,@(B5S(BX`26UP;W-S[79E;"!C<FEA<B!D:7)E
M=/-R:6\@5D93+@!);7!O<W/M=F5L(&-R:6%R(&%R<75I=F\@5D93+@!);7!O
M<W/M=F5L(')E;F]M96%R(&%R<75I=F\@5D93("(E<R(N`$EM<&]S<^UV96P@
M8W)I87(@87)Q=6EV;R!61E,@=F%Z:6\N`$EM<&]S<^UV96P@9&5S8V]M<')I
M;6ER(&1A9&]S+@!);7!O<W/M=F5L(&5X8VQU:7(@(B5S(BP@;R!D:7)E=/-R
M:6\@;N-O(&5S=.$@=F%Z:6\N`$EM<&]S<^UV96P@97AC;'5I<B`B)7,B.B`E
M<RX`26UP;W-S[79E;"!E>&-L=6ER("5S+"!O(&1I<F5T\W)I;R!NXV\@97-T
MX2!V87II;P!);7!O<W/M=F5L(&5X8VQU:7(@<F5C=7)S:79A;65N=&4@;R!D
M:7)E=/-R:6\@5D93+@!);7!O<W/M=F5L(&5X8VQU:7(@9&ER973S<FEO(%9&
M4RX`26UP;W-S[79E;"!E>&-L=6ER(&1I<F5T\W)I;R!61E,Z("5S+@!);7!O
M<W/M=F5L(&5X8VQU:7(@87)Q=6EV;R!61E,@(B5S(BX`26UP;W-S[79E;"!E
M>&-L=6ER(&%R<75I=F\@5D93+@!);7!O<W/M=F5L(&5X8VQU:7(@87)Q=6EV
M;R!61E,@(B5S(BX`26UP;W-S[79E;"!E>&-L=6ER(%9&4R!R96-U<G-I=F%M
M96YT93H@)7,N`$EM<&]S<^UV96P@9&5T97)M:6YA<B!O(&1I<F5T\W)I;R!A
M='5A;"X`26UP;W-S[79E;"!E>'1R86ER(&1E=&%L:&5S(&1O(&-E<G1I9FEC
M861O`$EM<&]S<^UV96P@8V%R<F5G87(@82!D969I;FGGXV\@9&4@)7,N`$EM
M<&]S<^UV96P@;6]V97(@;R!A<G%U:79O(%9&4RX`26UP;W-S[79E;"!A8G)I
M<B!A<G%U:79O(%9&4R`B)7,B+@!);7!O<W/M=F5L(&%B<FER(&%R<75I=F\@
M5D93('!A<F$@9W)A=F'GXV\N`$EM<&]S<^UV96P@86)R:7(@87)Q=6EV;R!6
M1E,N`$EM<&]S<^UV96P@86)R:7(@87)Q=6EV;R!C;VUP<FEM:61O+@!);7!O
M<W/M=F5L(&QE<B!A<G%U:79O(%9&4R`H9FEL97-I>F4H*2!F86QH;W4I+@!)
M;7!O<W/M=F5L(&QE<B!A<G%U:79O(%9&4R`H9V5T1FEL95-I>F4H*2!F86QH
M;W4I+@!);7!O<W/M=F5L(&QE<B!O(&%R<75I=F\Z(`!);7!O<W/M=F5L(&QE
M<B!A(')A:7H@9&\@9&ER973S<FEO(%9&4RX`26UP;W-S[79E;"!R96YO;65A
M<B`E<R!P87)A("5S.B!A('!A<W1A(&1E(&1E<W1I;F\@:N$@97AI<W1E`$EM
M<&]S<^UV96P@<F5N;VUE87(@;R!D:7)E=/-R:6\@5D93+@!);7!O<W/M=F5L
M(')E;F]M96%R(&1I<F5T\W)I;R!61E,Z("5S+@!);7!O<W/M=F5L(')E;F]M
M96%R(&%R<75I=F\@5D93("(E<R(N`$EM<&]S<^UV96P@<F5N;VUE87(@87)Q
M=6EV;R!61E,@)7,O)7,N`$EM<&]S<^UV96P@<F5N;VUE87(@87)Q=6EV;R!6
M1E,N`$EM<&]S<^UV96P@97AE8W5T87(@)VUK:7-O9G,G+@!);7!O<W/M=F5L
M('1R861U>FER(&5S=&4@9&]C=6UE;G1O(%=O<F0`26UP;W-S[79E;"!G<F%V
M87(@87)Q=6EV;R!61E,@(B5S(BX`26UP;W-S[79E;"!G<F%V87(@87)Q=6EV
M;R!61E,@*&-O<'DH*2!F86QH;W4I+@!);7!O<W/M=F5L(&=R879A<B!D861O
M<R!D;R!A<G%U:79O(%9&4RX`26UP;W-S[79E;"!G<F%V87(@87)Q=6EV;R!6
M1E,L('%U;W1A(&5X8V5D97+A+@!3=6)L:6YH861O`$1E<V9A>F5R($%L=&5R
M8>?U97,`1&5S9F%Z('-U82#Z;'1I;6$@8>?C;P!297-P;W-T82!I;F5S<&5R
M861A(&1O('-E<G9I9&]R(&1U<F%N=&4@82!C;VYE>.-O.B``4F5S<&]S=&$@
M:6YE<W!E<F%D82!D;R!S97)V:61O<B!P87)A.B``4V5M(&-A=&5G;W)I80!5
M;FEC;V1E("A55$8M."D`16UI<F%D;W,@P7)A8F5S(%5N:61O<P!296EN;R!5
M;FED;P!%<W1A9&]S(%5N:61O<P!);&AA<R!097)I9NER:6-A<R!-96YO<F5S
M(&1O<R!%<W1A9&]S(%5N:61O<P!5;FED861E<P!$97-C;VYH96-I9&\`87!I
M;7-G:60@9&5S8V]N:&5C:61O("A!4$D@365S<V%G92!)1"DN`&-L:6US9VED
M(&1E<V-O;FAE8VED;R`H0VQI96YT($UE<W-A9V4@240I+@!.96YH=6UA(&QO
M8V%L:7IAY^-O(&-O;F9I9W5R861A+@!5<W7A<FEO(&]U('-E;FAA(&1E<V-O
M;FAE8VED;W,N`$1E<W9I;F-U;&%R(&\@96QE;65N=&\@871U86P`4V5M($YO
M;64`4V-R:7!T<R!NXV\@<')I=FEL96=I861O<R!NXV\@<&]D96T@=71I;&EZ
M87(@0V]R=&%R+T-O<&EA<B]#;VQA<B!P;W(@<F%Z]65S(&1E('-E9W5R86[G
M82X@0VQI<75E(&5M($]+('!A<F$@=F5R(&$@;F]T82!TZ6-N:6-A(&5M(&UO
M>FEL;&$N;W)G(&$@<75A;"!E;G-I;F$@8V]M;R!P97)M:71I<B!S8W)I<'1S
M(&%C97-S87)E;2!A(.%R96$@9&4@=')A;G-F97+J;F-I82X`1&5S;6%R8V%R
M(&-O<@!%>'1E;G/C;R!.XV\@4W5P;W)T861A`$%T=6%L:7IA<@`E<R!A='5A
M;&EZ861O`$%T=6%L:7IA<B!U<W7A<FEO`"<E<R<@871U86QI>F%D;RX`4V-R
M:7!T(&1E(&%T=6%L:7IAY^-O(')E;6]V:61O+@!%;G9I87(`5&]D;W,@87)Q
M=6EV;W,@9&4@(&-O;F9I9W5R8>?U97,@9&%S(&%P;&EC8>?U97,@9F]R86T@
M96YV:6%D;W,@86\@<V5R=FED;W(N`$%L9F%B971O(&QA=&EN;R!E;2!M86GZ
M<V-U;&\`3OIM97)O<R!R;VUA;F]S(&5M(&UA:?IS8W5L;P!5<G5G=6%I`%5T
M:6QI>F%R($%T=6%L.B`E<P!5=&EL:7IA<B!34TP`571I;&EZ87(@<V4@;R!N
M;VUE+W-E;FAA(.D@9&EF97)E;G1E(&YO('-E<G9I9&]R($E-4U`N`%5S=>%R
M:6]S`%5S=>%R:6\@)7,@;N-O(&5S=.$@875T;W)I>F%D;R!P87)A("5S+@!!
M9&UI;FES=')AY^-O(&1E(%5S=>%R:6]S`$]PY_5E<R!D92!5<W7A<FEO<P!2
M96=I<W1R;R!D92!5<W7A<FEO<P!296=I<W1R;R!D92!5<W7A<FEO<R!E<W3A
M(&1E<V%B:6QI=&%D;R!N97-T92!S:71E+@!#;VYT82!D92!U<W7A<FEO(&[C
M;R!E;F-O;G1R861A`%5S=>%R:6\`57-UX7)I;R`G)7,G(&KA(&5X:7-T92X`
M57-UX7)I;SH`57-UX7)I;SH@`%5S=>%R:6]S(&YO('-I<W1E;6$Z`%5Z8F5Q
M=6ES=.-O`$\@9&ER973S<FEO(%9&4R!NXV\@97AI<W1E+@!&Z7)I87,`3&]C
M86QI>F'G]65S(';A;&ED87,@96YC;VYT<F%D87,@:6YC;'5E;3H@`%9A;&ED
M861E`%9A;&]R(&5M(&UI;G5T;W,@82!P87)T:7(@9&4@86=O<F$N`$\@=F%L
M;W(@97-TX2!A8VEM82!D;R!T86UA;FAO(&WA>&EM;R!D92`E<RX`5F%L;W)E
M<P!686QO<F5S('!A<F$@<V5L96-I;VYA<@!686YU871U`%9A<FGA=F5L`%9E
M;F5Z=65L80!&86QH82!N82!V97)I9FEC8>?C;R`M(&5S=&$@;65N<V%G96T@
M<&]D92!T97(@<VED;R!A9'5L=&5R861A+@!697)SXV\`0V]N=')O;&4@9&4@
M5F5R<^-O`$%L:6YH86UE;G1O('9E<G1I8V%L`$UA<F=E;2!V97)T:6-A;`!6
M97)T:6-A;#H`375I=&\@06QT80!6:65T;N,`5FEE=&YA;6ET82`H5DE30TE)
M*0!697(@)7,`5FES=6%L:7IA<B!U;6$@<.%G:6YA('=E8B!E>'1E<FYA`%9I
M<W5A;&EZ87(@8V]M;R`E<P!);&AA<R!6:7)G96YS+"!"<FETXFYI8V%S`$EL
M:&%S(%9I<F=E;G,L($4N52Y!+@!6:7-I8FEL:61A9&4`5FES:6)I;&ED861E
M.B``5F]D869O;F4@271A;&EA;F\@=FEA(%--5%``051%3L?#3P!!5$5.Q\-/
M(2$A(%)%34]602!/(%-#4DE05"!-04Y504Q-14Y412!$12`E<RX`5TE.('9I
M82!(5%10`%=A;&QI<R!E($9U='5N80!!=&5NY^-O`%%U80!0<F5V:7/C;R!D
M;R!496UP;P!$861O<R!D;R!#;&EM82!F;W)N96-I9&\@<&]R`%=E871H97(N
M8V]M`%=E8@!3:71E(%=E8@!396UA;F%L;65N=&4`0F5M+79I;F1O`$)E;2UV
M:6YD;R!A;R`E<P!"96TM=FEN9&\L("5S`$]C:61E;G1A;"`H25-/+3@X-3DM
M,2D`3V-I9&5N=&%L("A)4T\M.#@U.2TQ-2D`4V%H87)A($]C:61E;G1A;`!1
M=64@87!L:6-AY^-O("5S(&1E=F5R:6$@97AI8FER(&%P\W,@82!C;VYE>.-O
M/P!1=6%L(&\@8V%R86-T97)E(&1E;&EM:71A9&]R/P!1=6%L(&\@8V%R86-T
M97)E(&1E(&-I=&'GXV\_`$UA<&%S($%U<W1R86QI86YO<R!7:&5R96ES`%%U
M86ES(&9A<V5S`%%U86ES('!L=6=I;G,@:&%B:6QI=&%R('!A<F$@;R!E9&ET
M;W(@4FEC:"!497AT+@!,87)G=7)A`$QA<F=U<F$@96T@=6YI9&%D97,@0U-3
M`$QA<F=U<F$@9&\@;65N=2`E<R!D;R!L861O(&5S<75E<F1O("AT97+A(&5F
M96ET;R!N82!P<O-X:6UA(&-O;F5XXV\I.@!,87)G=7)A(&1A('1A8F5L80!5
M;FED861E(&1E($QA<F=U<F$`3&%R9W5R83H`5VEK:0!696YT;P!696YT;W,@
M<&5L82!M86YHXP!696QO8VED861E(&1O('9E;G1O(&5M(&[S<P!696YT;SH`
M5F5N=&\Z(`!386)E9&]R:6$`3&ES=&$@9&4@<&5D:61O<P!4<F%B86QH;P!%
M;F1E<F7G;R!#;VUE<F-I86P`1F]N92!#;VUE<F-I86P`3OIM97)O(&EN8V]R
M<F5T;R!D92!C86UP;W,@;F$@;&EN:&$@)60N($5S<&5R861O<R`E9"P@96YC
M;VYT<F%D;W,@)60N`$[Z;65R;R!E<G)A9&\@9&4@8V%M<&]S+B!%<W!E<F%D
M;W,@)60L(&5N8V]N=')A9&]S("5D+@!/9F9S970@)60@:6YC;W)R971O(&%O
M(&QE<B!O(&%R<75I=F\@5D93+@!8+5)E9@!297-T<FGG]65S($+A<VEC87,@
M6#4P.78S`%5T:6QI>F'GXV\@9&4@0VAA=F4@17AT96YD:61A(%@U,#EV,P!.
M;VUE($%L=&5R;F%T:79O(&1E($%S<W5N=&\@6#4P.78S`$ED96YT:69I8V%D
M;W(@9&$@0VAA=F4@9&4@07-S=6YT;R!8-3`Y=C,`17AT96YS]65S(%@U,#EV
M,P!!00!!04%!`$UA<&$@66%H;V\A`$%N=6%L;65N=&4`3.IM96X`4VEM`%-I
M;2P@174@0V]N8V]R9&\`5F]CZB!E<W3A(&5M($U/1$\@5$585$\N("!5=&EL
M:7IA(&\@8F]TXV\@6SP^72!P87)A('9O;'1A<B!P87)A(&\@;6]D;R!765-)
M5UE'+@!6;V/J(&[C;R!E<W3A(&%U=&]R:7IA9&\@82!C<FEA<B!M86ES(&1E
M("5D(&)L;V-O<RX`5F]CZB!NXV\@97-TX2!A=71E;G1I8V%D;RX`5F]CZB!N
MXV\@<&]D92!T97(@;R!C87)A8W1E<B!<(&YO('-E=2!N;VUE+@!6;V/J(&[C
M;R!F;W)N96-E=2!U;2!E;F1E<F7G;R!D92!E+6UA:6P@=N%L:61O+@!6;V/J
M(&[C;R!M87!E;W4@;F5N:'5M(&-A;7!O(&1O(&%R<75I=F\@:6UP;W)T861O
M(&%O<R!C86UP;W,@8V]R<F5S<&]N9&5N=&5S(&5M("5S+@!6;V/J(&9O:2!D
M97-C;VYE8W1A9&\N`%9O8^H@9&5V92!P<F5E;F-H97(@=6T@;OIM97)O(&1E
M('1E;&5F;VYE(&-E;'5L87(@=N%L:61O+"!S;VUE;G1E(&3M9VET;W,@8V]M
M('5M(&]P8VEO;F%L("<K)R!P87)A(&1I<V-A9V5M(&1E('!R969I>&\@:6YT
M97)N86-I;VYA;"X`5F]CZB!D979E('!R965N8VAE<B!U;2!V86QO<B!VX6QI
M9&\N`%9O8^H@9&5V92!C;VYF:6=U<F%R('5M(&-O;F5C=&]R($1A=&%4<F5E
M('!A<F$@=71I;&EZ87(@0V%D87-T<F]S+@!6;V/J(&1E=F4@8V]N9FEG=7)A
M<B!U;2!C;VYE8W1O<B!61E,N`%9O8^H@9&5V92!D97-C<F5V97(@;R!P<F]B
M;&5M82!A;G1E<R!D92!E;G9I87(@;R!R96QA=/-R:6\@9&4@<')O8FQE;6$N
M`%9O8^H@9&5V92!F;W)N96-E<B!A(%523"!O;F1E(&\@;&EN:R!A<&]N=&$`
M5F]CZB!D979E('-E;&5C:6]N87(@=6T@<V5R=FED;W(@<&%R82!S97(@97AC
M;'7M9&\N`%9O8^H@9&5V92!E<W!E8VEF:6-A<B!U;2!U<W7A<FEO('!A<F$@
M97AC;'5I<BX`5F]CZB!D979E(&5S<&5C:69I8V%R('5M('5S=>%R:6\@<&%R
M82!R96UO=F5R+@!6;V/J(&1E=F4@97-P96-I9FEC87(@=6T@=7-UX7)I;R!P
M87)A(&%D:6-I;VYA<BX`5F]CZB!D979E(&5S<&5C:69I8V%R('5M('5S=>%R
M:6\@<&%R82!A='5A;&EZ87(N`%9O8^H@9&5V92!E<W!E8VEF:6-A<B!U;6$@
M8>?C;R!P87)A(&5X96-U=&%R+@!6;V/J(&1E=F4@<')E96YC:&5R('5M(&YO
M;64@<&%R82!A(&YO=F$@8V%T96=O<FEA+@!6;V/J('!R96-I<V$@9F]R;F5C
M97(@=6T@;OIM97)O(&1E('1E;&5F;VYE(&ET86QI86YO`%-U82!S97-SXV\@
M)7,@97AP:7)O=2X@4&]R(&9A=F]R+"!C;VYE8W1E+7-E(&YO=F%M96YT92X`
M4V5U($5N9&5R9>=O(&1E($4M;6%I;`!3974@16YD97)EYV\@9&4@4F5M971E
M;G1E("A$93HI.@!3=6%S($EN9F]R;6'G]65S`%-E=2!%;F1E<F7G;R!D92!)
M;G1E<FYE="!M=61O=2!D97-D92!O(&EN[6-I;R!D92!S=6$@<V5S<^-O("5S
M+B!087)A('!R;W1E9V5R('-U82!S96=U<F%NYV$@=F]CZB!D979E(&-O;F5C
M=&%R+7-E(&YO=F%M96YT92X`4V5U($YO;64`4V5U(&)A8VME;F0@9&4@875T
M96YT:6-AY^-O(&[C;R!S=7!O<G1A(&%D:>?C;R!D92!U<W7A<FEO<RP@;W4@
M82!F=6[GXV\@9F]I(&1E<V%B:6QI=&%D82!P;W(@86QG=6UA(&]U=')A(')A
M>N-O+@!3974@8F%C:V5N9"!D92!A=71E;G1I8V'GXV\@;N-O('-U<&]R=&$@
M;&ES=&%G96T@9&4@=7-UX7)I;W,L(&]U(&$@9G5NY^-O(&9O:2!D97-A8FEL
M:71A9&$@<&]R(&%L9W5M82!O=71R82!R87KC;RX`4V5U(&YA=F5G861O<B!P
M87)E8V4@=&5R(&%L=&5R861O(&1E<V1E(&\@:6[M8VEO(&1E('-U82!S97-S
MXV\@)7,N(%!A<F$@<')O=&5G97(@<W5A('-E9W5R86[G82P@=F]CZB!D979E
M(&-O;F5C=&%R+7-E(&YO=F%M96YT92X`4V5U(&YA=F5G861O<B!NXV\@<W5P
M;W)T82!E<W1A(&9U;N?C;RX`4V5U(&YA=F5G861O<B!NXV\@<W5P;W)T82!E
M<W1A(&]PY^-O(&1E(&EM<')E<W/C;RX@4')E<W-I;VYE($-O;G1R;VPO3W!T
M:6]N("L@4"!P87)A(&EM<')I;6ER+@!3974@9G5S;R!H;W+A<FEO(&%T=6%L
M.@!3=6$@:61E;G1I9&%D92!P861RXV\@9F]I(&%L=&5R861A+@!3=6$@:61E
M;G1I9&%D92!P861RXV\Z`%-E=2!N;VUE(&-O;7!L971O.@!3=6$@8V]N97CC
M;R!E>'!I<F]U+@!3=6$@;F]V82!S96YH82!P87)A("5S(.DZ("5S`%-U87,@
M;W#G]65S(&9O<F%M(&%T=6%L:7IA9&%S('!O<B!C875S82!D82!D=7)AY^-O
M(&1E<W1A('-E<W/C;RX`4W5A<R!O<.?U97,@9F]R86T@871U86QI>F%D87,N
M`%-U82!N;W9A('-E;FAA(&9O:2!G97)A9&$`4W5A(&YO=F$@<V5N:&$@9F]I
M(&=E<F%D82P@=F5R:69I<75E('-E=2!E+6UA:6P@92!C;VYE8W1E+7-E(&-O
M;2!S=6$@;F]V82!S96YH82X`4W5A('-E;FAA(&5X<&ER;W4N`%-E=7,@<V5R
M=FED;W)E<R!R96UO=&]S.@!)=6=O<VSA=FEA`%IA:7)E`%KB;6)I80!::6UB
M86)W90!::7!P>0!;3V-U;'1A<B!497AT;R!#:71A9&]=`%M296QA=/-R:6\@
M9&4@4')O8FQE;6%=`%M%>&EB:7(@5&5X=&\@0VET861O("T`6T5X:6)I<B!4
M97AT;R!#:71A9&\@+2`E<R!L:6YH87-=`%ML:6YH82`E<R!D92`E<UT`7T%D
M;6EN:7-T<F'GXV\`7T-,20!$871A7U1R964`15]X8VQU:7(@0V]L=6YA`%]'
M<G5P;W,`05]J=61A`%!R;W!R:65D861E<R!D82!?26UA9V5M+BXN`%]#;VYE
M8W1A<@!?1&5S8V]N96-T87(`05]L=&5R87(@3&EN:RXN+@!?3W#G]65S`%]0
M97)M:7-S]65S`%]296UO=F5R($QI;FLN+BX`0V]N9FEG=7)A7W(`4')O<')I
M961A9&5S(&1A(%]486)E;&$N+BX`7U5S=>%R:6]S`&-A=.%L;V=O(&1E(&5N
M9&5R9>=O<P!C873A;&]G;R!D92!E;F1E<F7G;W,`86=E;F1A`&-A;&UO`&EM
M<&]S<^UV96P@8W)I87(@87)Q=6EV;R!D92!D97-T:6YO`&EM<&]S<^UV96P@
M86)R:7(@82!O<FEG96T`8VQI<75E(&%Q=6D`97)R;R!D92!S:6YT87AE(&1A
M(&QI;FAA(&1E(&-O;6%N9&\`97)R;R!D92!C;VYF:6=U<F'GXV\`=6T@87)Q
M=6EV;R!C<NUT:6-O(&1O('-I<W1E;6$@97-TX2!F86QT86YD;P!E<G)O(&YO
M(&9O<FUA=&\@9&]S(&1A9&]S`&5D:71A<@!R96=I<W1R;R!NXV\@96YC;VYT
M<F%D;P!Q=65D80!A<G%U:79O`&$@<&%R=&ER(&1E("5S("@E<RD@X"`E<R`E
M<P!B<FES80!H.@!H:`!N;VUE(&1O(&AO<W0@Z2!D97-C;VYH96-I9&\`:6UE
M9&EA=&\`:6YC;W)P;W)A9&\`97)R;R!D92!E;G1R861A+W-A[61A`&5R<F\@
M:6YT97)N;R!D;R!P<F]G<F%M80!L:6YH87-=`&/S9&EG;R!D92!E<G)O("5D
M(&1O(&UK:7-O9G,@96YQ=6%N=&\@9V5R879A(&$@25-/+@!M;0!N;VUE`&[C
M;R!I;7!L96UE;G1A9&\`;N-O(&EM<&QE;65N=&%D;R!A:6YD80!B;&]C;R!D
M92!N;W1A<P!P;W)C96YT86=E;0!097)M:7-SXV\`<&EX96QS`&5R<F\@<F5M
M;W1O(&YO('!R;W1O8V]L;P!N87-C96YT90!S97)V:>=O(&EN9&ES<&]N[79E
M;`!E>&EB:7(@9&EF97)E;N=A<P!S;7,R96UA:6P@=FEA($A45%``<W,`97-T
MX79E;`!E<G)O(&1E('-I<W1E;6$`;&ES=&$@9&4@=&%R969A<P!F86QH82!T
M96UP;W+A<FEA`'!R965N8VAA('-U82!S96YH82!D=6%S('9E>F5S('!A<F$@
M8V]N9FER;6%R`'5N:69I8V%D;P!S96T@;F]M90!S96QEY^-O(&1E('5S=>%R
M:6\`=D-A<F0`=SH`=V5A=&AE<BYC;VT`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQO8V%L92]P=%]05"\`````````````````````````````````
M````````````````````````````````````````````````,#`P,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-3,`,#(P,30S
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W!T7U!4+VAE;'`N>&UL
M````````````````````````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S8T-@`Q
M,#4Q-30S,S<U,P`P,C$V,C8`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]X;6P@=F5R<VEO;CTB,2XP(B!E;F-O9&EN9STB
M:7-O+3@X-3DM,2(_/@H\(2TM("1(;W)D93H@:&]R9&4O;&]C86QE+W!T7U!4
M+VAE;'`N>&UL+'8@,2XR+C$P+C$@,C`P-B\P-R\R-R`Q,SHU,3HP,2!J86X@
M17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4]
M(G5P=&]D871E(B!M9#4](C8X8V$S,V8W9C!C.6%A931C,3`S96(T-S0Y,F-D
M8S$U(CX*/'1I=&QE/D$@4.%G:6YA(&1O(%!O<G1A;#PO=&ET;&4^"B`\<&%R
M83X*17-T82!PX6=I;F$@9F]R;F5C92!U;2!B<F5V92!S=6WA<FEO(&1E('1O
M9&$@82!S=6$@:6YF;W)M8>?C;R!I;7!O<G1A;G1E+@I0;W(@97AE;7!L;RP@
M<&]D92!M;W-T<F%R('%U86YT87,@;65N<V%G96YS(&YO=F%S(&1E(&4M;6%I
M;"!E>&ES=&5M(&YA('-U82!)3D)/6"P@"F]S(&5V96YT;W,@86=E;F1A9&]S
M(&YO('-E=2!C86QE;F3A<FEO+"!T87)E9F%S(&YA('-U82!L:7-T82!D92!A
M9F%Z97)E<RQO<R!C86)EYV%L:&]S(&1O<R`*<V5R=FGG;W,@9&4@;F]T[6-I
M87,@<V5L96-C:6]N861O<RP@92!M=6ET;R!M86ES+@I-=6ET;W,@9&5S=&5S
M('-U;>%R:6]S(&-O;G3J;2!A=&%L:&]S('+A<&ED;W,@<&%R82!A<R!F=6[G
M]65S(&UA:7,@8V]M=6YS+"!C;VUO(&-O;7!O<VGGXV\*9&4@=6UA(&YO=F$@
M;65N<V%G96T@9&4@92UM86EL+"!C<FEAY^-O(&1E('5M(&YO=F\@8V%L96YD
MX7)I;R!D92!E=F5N=&]S(&]U('1A<F5F87,L(&5T8RX*("`@/"]P87)A/@H@
M/'!A<F$^"D]S(&-O;G1E^F1O<R!D97-T92!P;W)T86P@<^-O('!E<G-O;F%L
M:7KA=F5I<R!A=')A=NES(&1E('5M(&)O=.-O(&1E($QA>6]U="X*4&]R(&5X
M96UP;&\L('!O9&4@97-C;VQH97(@<75A:7,@;W,@:71E;7,@82!I;F-L=6ER
M(&YE<W1E('!O<G1A;"!E(&$@<W5A(&]R9&5M(&1E(&%P<F5S96YT8>?C;PH@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;F%V8F%R(B!S=&%T93TB
M=7!T;V1A=&4B(&UD-3TB8CAC9C!A93$Y934W9&9A,&,R8CDV,F4U,38W.#)F
M-#<B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG871I;VX@0F%R/"]T
M:71L93X*(#QP87)A/@I.;R!L861O(&5S<75E<F1O(&1A('#A9VEN82!W96(@
M97-TX2!A(&)A<G)A(&1E(&YA=F5G8>?C;RX*0VQI<75E(&YO<R#M8V]N97,@
M9&5S=&$@8F%R<F$@9&4@;F%V96=AY^-O('!A<F$@<N%P:61A(&4@9N%C:6QM
M96YT92!E<V-O;&AE<B`*87,@87!L:6-AY_5E<R!D:7-P;V[M=F5I<RX@"B`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N
M86YC92(@<W1A=&4](G5P=&]D871E(B!M9#4](F1D.35D9C`W83`S,#,Q,C,R
M8F%E83DQ.3(X.&(R9#`P(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I
M;G1E;F%N8V4Z($1O($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@I3
M92!P<F5T96YD97(@<F5A;&EZ87(@;W!E<F'G]65S(&1E(&UA;G5T96[GXV\@
M;F\@;&]G:6XL('-E;&5C8VEO;F4@97-T82!C86EX82X*(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!R969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B
M('-T871E/2)U<'1O9&%T92(@;60U/2)A,C$Q-C)C9&9F,V(Q9#AF865A9&(W
M,CDV,C0P,#,V92(^"B`@("`\=&ET;&4^4')E9F5RZFYC:6%S.B!-86YU=&5N
MY^-O.B!#;VYF:7)M87(@36%N=71E;N?C;SPO=&ET;&4^"B`@("`\<&%R83X*
M4V4@<')E=&5N9&5R(&-O;F9I<FUA<B!T;V1A<R!A<R!T87)E9F%S(&1E(&UA
M;G5T96[GXV\@86YT97,@9&4@<V5R96T@87!L:6-A9&%S+"!S96QE8V-I;VYE
M(&5S=&$@8V%I>&$N"E-E(&[C;R!S96QE8V-I;VYA<B!E<W1A(&-A:7AA+"!T
M;V1A<R!A<R!O<&5R8>?U97,@9&4@;6%N=71E;N?C;R!S97+C;R!R96%L:7IA
M9&%S(&%U=&]MX71I8V%M96YT92!S96T@82!O<.?C;R!D90IC86YC96QA<B!N
M;R!L;V=I;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]P=%]05"],0U]-15-304=%4R\`
M````````````````````````````````````````````````````````````
M````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T
M,S,W-3,`,#(Q-S,P`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W!T
M7U!4+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#0R-S,R-P`Q,#4Q-30S,S<U,P`P,C,T,#4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````WA($E0````!S!P``'````+0[
M``#O"0``3'<````````(GP``30````F?``"_````5Y\``&0````7H```O@``
M`'R@``"0````.Z$``$,```#,H0``/````!"B```K````3:(``"X```!YH@``
M*0```*BB```H````TJ(``$4```#[H@``1P```$&C``!*````B:,``$<```#4
MHP``10```!RD``!(````8J0``#D```"KI```1@```.6D``!(````+*4``#``
M``!UI0``10```*:E``!&````[*4``$P````SI@``-````("F```R````M:8`
M`&D```#HI@``,````%*G```E````@Z<``(@```"IIP``0````#*H``#V````
M<Z@``$H```!JJ0``+````+6I``"%````XJD``$@```!HJ@``#@```+&J```/
M````P*H```T```#0J@``"````-ZJ```+````YZH```P```#SJ@``!`````"K
M```;````!:L``"T````AJP``'0```$^K```D````;:L``"D```"2JP``&0``
M`+RK```,````UJL``!$```#CJP``)0```/6K```/````&ZP```L````KK```
M$0```#>L```.````2:P```4```!8K```*````%ZL```(````AZP```H```"0
MK```%0```)NL```2````L:P```L```#$K```$P```-"L```.````Y*P```H`
M``#SK```#0```/ZL```N````#*T```X````[K0``$0```$JM```-````7*T`
M``P```!JK0``#0```'>M```&````A:T```H```",K0``#P```)>M```8````
MIZT```P```#`K0``&P```,VM```.````Z:T```X```#XK0``"`````>N```)
M````$*X``$(````:K@``+@```%VN```:````C*X``#(```"GK@``.````-JN
M``!4````$Z\``%$```!HKP``6@```+JO``!7````%;```#0```!ML```"0``
M`**P```-````K+````<```"ZL```"@```,*P```/````S;````4```#=L```
M!@```..P```1````ZK````@```#\L```"0````6Q```)````#[$``"4````9
ML0``(````#^Q```0````8+$```\```!QL0``"@```(&Q```#````C+$```\`
M``"0L0``%````*"Q```)````M;$```T```"_L0``$@```,VQ```9````X+$`
M`!X```#ZL0``#P```!FR```*````*;(```\````TL@``"````$2R```D````
M3;(``!0```!RL@``%@```(>R```(````GK(``$X```"GL@``+0```/:R```?
M````)+,``!D```!$LP``!P```%ZS```,````9K,``"P```!SLP``#@```*"S
M```#````K[,```L```"SLP``!P```+^S```'````Q[,```4```#/LP``!0``
M`-6S```*````V[,```,```#FLP``%P```.JS```*`````K0```\````-M```
M#@```!VT```8````++0``",```!%M```#@```&FT```4````>+0``!<```"-
MM```%P```*6T```7````O;0``!,```#5M```#P```.FT```.````^;0``!\`
M```(M0``'0```"BU```'````1K4```8```!.M0``"````%6U```/````7K4`
M``8```!NM0``"@```'6U```3````@+4```L```"4M0``%0```*"U```5````
MMK4```<```#,M0``$````-2U```%````Y;4``!4```#KM0``$0````&V```,
M````$[8``#L````@M@``.````%RV```)````E;8```<```"?M@``%````*>V
M```#````O+8```4```#`M@``$````,:V```)````U[8``!,```#AM@``.0``
M`/6V```2````+[<``"<```!"MP``+````&JW```J````E[<``"4```#"MP``
M"@```.BW```&````\[<```D```#ZMP``!P````2X```O````#+@``#<````\
MN```+@```'2X``!5````H[@``"T```#YN```+0```">Y```M````5;D``$``
M``"#N0``(P```,2Y```C````Z+D``"T````,N@``,P```#JZ```5````;KH`
M`!D```"$N@``*0```)ZZ```D````R+H``!$```#MN@``"@```/^Z```,````
M"KL```H````7NP``$````"*[```6````,[L``!8```!*NP``!P```&&[```'
M````:;L``!0```!QNP``"@```(:[```(````D;L```@```":NP``!P```*.[
M```'````J[L```8```"SNP``!0```+J[```'````P+L```8```#(NP``"```
M`,^[```I````V+L```X````"O```"@```!&\```$````'+P```<````AO```
M"0```"F\```&````,[P``!$````ZO```!P```$R\```6````5+P```0```!K
MO```"````'"\```&````>;P```T```"`O```!@```(Z\```>````E;P``!$`
M``"TO```(@```,:\```6````Z;P```@`````O0``#0````F]```,````%[T`
M``<````DO0```P```"R]```#````,+T``!<````TO0``$P```$R]```=````
M8+T```@```!^O0``!````(>]```(````C+T```@```"5O0``00```)Z]```@
M````X+T```8````!O@``!@````B^```5````#[X``!@````EO@``(@```#Z^
M```N````8;X``!T```"0O@``(0```*Z^``!4````T+X``"D````EOP``"@``
M`$^_```'````6K\``!4```!BOP``#@```'B_```*````A[\```\```"2OP``
M#0```**_```/````L+\```T```#`OP``"0```,Z_```4````V+\```8```#M
MOP``&````/2_```=````#<```!,````KP```$0```#_````4````4<````0`
M``!FP```!@```&O```!4````<L````0```#'P```#@```,S```!$````V\``
M``4````@P0``!0```";!```;````+,$``!H```!(P0``$0```&/!```1````
M=<$``!P```"'P0``*@```*3!```0````S\$``"$```#@P0``)0````+"```9
M````*,(```4```!"P@``$P```$C"```2````7,(```H```!OP@``#P```'K"
M```-````BL(``!$```"8P@``$P```*K"```,````OL(```8```#+P@``#```
M`-+"```&````W\(``!<```#FP@``$````/["```1````#\,```@````APP``
M!0```"K#```,````,,,``!`````]PP``!0```$[#```-````5,,```8```!B
MPP``!P```&G#```-````<<,``!````!_PP``"0```)##```'````FL,```L`
M``"BPP``"P```*[#```'````NL,```<```#"PP``%````,K#```)````W\,`
M``D```#IPP``"@```//#```9````_L,``!T````8Q```#````#;$```0````
M0\0```4```!4Q```)0```%K$```2````@,0``!,```"3Q```*P```*?$```[
M````T\0``"`````/Q0``-@```##%```A````9\4``!````")Q0``"````)K%
M```,````H\4```8```"PQ0``!````+?%```.````O,4``!````#+Q0``"@``
M`-S%```-````Y\4``!X```#UQ0``&P```!3&```A````,,8``!X```!2Q@``
M&0```''&```>````B\8``!L```"JQ@``+@```,;&```7````]<8``"8````-
MQP``,````#3'```;````9<<``!X```"!QP``'````*#'```F````O<<``"L`
M``#DQP``,P```!#(```F````1,@``"L```!KR```.````)?(```=````T,@`
M`!4```#NR```+P````3)```@````-,D``!(```!5R0``*0```&C)```>````
MDLD``!(```"QR0``H@```,3)```6````9\H``",```!^R@``*````*+*```I
M````R\H``"@```#UR@``'P```![+```5````/LL``"````!4RP``)0```'7+
M```H````F\L``"T```#$RP``,````/++``"2````(\P``"$```"VS```%@``
M`-C,```<````[\P``"8````,S0``*@```#/-``!!````7LT``$0```"@S0``
M#````.7-```'````\LT```<```#ZS0``!@````+.```-````"<X``!`````7
MS@``$@```"C.```3````.\X``!(```!/S@``!P```&+.```$````:LX``!``
M``!OS@``#````(#.```.````C<X```\```"<S@``$P```*S.```-````P,X`
M`"@```#.S@```P```/?.```-````^\X```8````)SP``$0```!#/```7````
M(L\``!L````ZSP``#@```%;/```"````9<\```4```!HSP``$````&[/```$
M````?\\```T```"$SP``#@```)+/```#````H<\```X```"ESP``"````+3/
M```/````O<\```\```#-SP``!P```-W/```-````Y<\``!````#SSP``$P``
M``30```3````&-````L````LT```!@```#C0```,````/]```!$```!,T```
M&0```%[0```+````>-````T```"$T```(@```)+0```;````M=```#0```#1
MT```"@````;1```8````$=$``!D````JT0``%@```$31```O````6]$``"(`
M``"+T0``#0```*[1```'````O-$``!0```#$T0``"P```-G1```B````Y=$`
M`"\````(T@``"P```#C2```)````1-(``!D```!.T@``"P```&C2```7````
M=-(``!<```",T@``"0```*32```6````KM(```\```#%T@``&0```-72```6
M````[](```X````&TP``&````!73```(````+M,```T````WTP``)@```$73
M``!#````;-,```@```"PTP``$@```+G3```(````S-,```L```#5TP``+P``
M`.'3```.````$=0```4````@U```!@```";4```#````+=0```<````QU```
M!````#G4```*````/M0```H```!)U```#P```%34```0````9-0``!<```!U
MU```$0```(W4```9````G]0``!<```"YU```"0```-'4```%````V]0```L`
M``#AU```"@```.W4```"````^-0```4```#[U```#0````'5```;````#]4`
M`!<````KU0``"0```$/5```.````3=4```T```!<U0``$@```&K5```X````
M?=4``"````"VU0``"````-?5```.````X-4``'L```#OU0``&````&O6``!`
M````A-8``!$```#%U@``!P```-?6```%````W]8``!D```#EU@``$P```/_6
M```'````$]<```<````;UP``"````"/7```&````+-<```8````SUP``$```
M`#K7```/````2]<``!````!;UP``#P```&S7```+````?-<```\```"(UP``
M#````)C7```/````I=<```<```"UUP``"@```+W7```&````R-<```X```#/
MUP``#````-[7```H````Z]<```\````4V```"````"38```6````+=@```@`
M``!$V```$P```$W8```>````8=@``"$```"`V```(````*+8```9````P]@`
M`!<```#=V```)0```/78```7````&]D```0````SV0``&P```#C9```-````
M5-D```P```!BV0```P```&_9```(````<]D```H```!\V0``#````(?9```+
M````E-D``!````"@V0``#````+'9```$````OMD``!,```##V0``%````-?9
M```,````[-D```D```#YV0``#@````/:```+````$MH``!L````>V@``!P``
M`#K:```'````0MH```H```!*V@``#0```%7:```)````8]H```0```!MV@``
M!0```'+:```#````>-H``!@```!\V@``"@```)7:```$````H-H``"8```"E
MV@``#@```,S:``!\````V]H``!4```!8VP``!0```&[;```'````=-L```P`
M``!\VP``"````(G;```*````DML```8```"=VP``"````*3;```6````K=L`
M`!(```#$VP```@```-?;```&````VML```8```#AVP``%````.C;```-````
M_=L``!`````+W```&P```!S<```$````.-P```D````]W```$````$?<```)
M````6-P```D```!BW```!0```&S<```%````<MP``!H```!XW```"````)/<
M```&````G-P``!D```"CW```#@```+W<```B````S-P```<```#OW```!P``
M`/?<```.````_]P```4````.W0``"0```!3=```*````'MT```(````IW0``
M!@```"S=```-````,]T```D```!!W0``!@```$O=```2````4MT```D```!E
MW0``!P```&_=```4````=]T``!T```",W0``$0```*K=```&````O-T```H`
M``##W0``!````,[=```)````T]T```@```#=W0``$0```.;=```1````^-T`
M``D````*W@``!@```!3>```-````&]X```8````IW@``!````##>```Y````
M-=X``#T```!OW@``.@```*W>```>````Z-X```4````'WP``#@````W?```$
M````'-\```8````AWP``(0```"C?```-````2M\``!4```!8WP``!@```&[?
M```$````==\``!$```!ZWP``!@```(S?``"@````D]\```H````TX```(@``
M`#_@```$````8N```"4```!GX```!0```(W@```=````D^````0```"QX```
M#````+;@```*````P^````@```#.X```"0```-?@```%````X>```!L```#G
MX```.@````/A```P````/N$``#4```!OX0``*0```*7A```N````S^$``$<`
M``#^X0``.````$;B```I````?^(``#\```"IX@``+@```.GB```M````&.,`
M`!\```!&XP``#P```&;C```2````=N,```L```")XP``)@```)7C```I````
MO.,``"0```#FXP``)@````OD```(````,N0```H````[Y```"0```$;D```'
M````4.0``"````!8Y```(````'GD```F````FN0```H```#!Y```&0```,SD
M```I````YN0``!8````0Y0``$@```"?E```'````.N4```H```!"Y0``#P``
M`$WE```0````7>4``$````!NY0``<````*_E``!F````(.8```X```"'Y@``
M"0```);F```*````H.8``!(```"KY@``$P```+[F```,````TN8```8```#?
MY@``#P```.;F```2````]N8``!`````)YP``$0```!KG```<````+.<``",`
M``!)YP``:@```&WG```/````V.<```4```#HYP``$````.[G```)````_^<`
M``0````)Z```"P````[H```@````&N@``!H````[Z```%````%;H```,````
M:^@```P```!XZ```#P```(7H```5````E>@``"D```"KZ```*@```-7H```F
M`````.D``"<````GZ0``*0```$_I```J````>>D``!D```"DZ0``0@```+[I
M```1`````>H``!(````3Z@``$P```";J```4````.NH```\```!/Z@``%@``
M`%_J```7````=NH``!````".Z@``$0```)_J```T````L>H``!,```#FZ@``
M$@```/KJ```U````#>L``!0```!#ZP``!P```%CK```,````8.L``"````!M
MZP``$````([K```4````G^L``!$```"TZP``%P```,;K```<````WNL``!,`
M``#[ZP``%`````_L```:````).P``!$````_[```&@```%'L```>````;.P`
M`!H```"+[```$P```*;L```5````NNP``!$```#0[```%P```.+L```4````
M^NP``!<````/[0``%0```"?M```)````/>T``!D```!'[0``!````&'M```'
M````9NT```L```!N[0``$0```'KM```&````C.T```8```"3[0``!@```)KM
M```%````H>T```<```"G[0``!P```*_M```%````M^T``!8```"][0``!@``
M`-3M```&````V^T```0```#B[0``!````.?M```'````[.T```X```#T[0``
M#`````/N```,````$.X```T````=[@``"@```"ON```.````-NX```4```!%
M[@``*````$ON```.````=.X```P```"#[@``#P```)#N```*````H.X```@`
M``"K[@``"0```+3N```K````ONX```0```#J[@``"````._N```F````^.X`
M`!(````?[P``#P```#+O```&````0N\```H```!)[P``!P```%3O```(````
M7.\``"````!E[P``"0```(;O```,````D.\```T```"=[P``#@```*OO```6
M````NN\``!$```#1[P``!@```./O```#````ZN\```8```#N[P``&0```/7O
M```'````#_````0````7\```"P```!SP```+````*/````<````T\```!P``
M`#SP```6````1/````T```!;\```#0```&GP```*````=_```!````""\```
M#P```)/P```1````H_```!<```"U\```"@```,WP```1````V/````@```#J
M\```!````//P```/````^/```#H````(\0``!0```$/Q```,````2?$``!X`
M``!6\0``#@```'7Q```0````A/$```L```"5\0``#````*'Q```)````KO$`
M``<```"X\0``"@```,#Q```)````R_$```X```#5\0``$````.3Q```:````
M]?$```H````0\@``"0```!OR```4````)?(```H````Z\@``#````$7R```/
M````4O(```@```!B\@``!@```&OR```'````<O(```L```!Z\@``1P```(;R
M```-````SO(```D```#<\@``!````.;R```#````Z_(``!,```#O\@``$P``
M``/S```3````%_,```H````K\P```@```#;S```$````.?,``"4````^\P``
M`P```&3S```%````:/,``"H```!N\P``"@```)GS```%````I/,```0```"J
M\P``"@```*_S```-````NO,``$````#(\P``$P````GT```&````'?0```@`
M```D]```"````"WT```$````-O0```4````[]```:````$'T```)````JO0`
M``P```"T]```!0```,'T```&````Q_0``!L```#.]```+P```.KT```0````
M&O4```H````K]0``#P```#;U```*````1O4```D```!1]0``$P```%OU```;
M````;_4``!@```"+]0``%P```*3U```.````O/4```,```#+]0``!P```,_U
M```(````U_4```<```#@]0``"@```.CU```+````\_4``"T```#_]0``%0``
M`"WV```P````0_8``"0```!T]@``!P```)GV``!1````H?8``!````#S]@``
M#`````3W```-````$?<``!H````?]P``2@```#KW```9````A?<```8```"?
M]P``&@```*;W```&````P?<```8```#(]P``'P```,_W```&````[_<```D`
M``#V]P``&`````#X```7````&?@```8````Q^```#0```#CX```B````1O@`
M`%<```!I^```$P```,'X```C````U?@``!,```#Y^````@````WY```+````
M$/D```@````<^0``#0```"7Y```*````,_D```8````^^0``!P```$7Y```4
M````3?D```8```!B^0``"````&GY```.````<OD```<```"!^0``"@```(GY
M```+````E/D```<```"@^0``#````*CY```-````M?D```P```##^0``"0``
M`-#Y```)````VOD```H```#D^0``!P```._Y```)````]_D```<````!^@``
M"@````GZ```;````%/H``!(````P^@``"@```$/Z```)````3OH``!````!8
M^@``!P```&GZ```2````<?H```0```"$^@``!P```(GZ```%````D?H```4`
M``"7^@``"P```)WZ```4````J?H``!$```"^^@``&@```-#Z```6````Z_H`
M`!0````"^P``%P```!?[```8````+_L``!P```!(^P``&0```&7[```'````
M?_L```4```"'^P``#0```(W[```,````F_L```@```"H^P``%P```+'[```+
M````R?L``!,```#5^P``!````.G[```*````[OL```0```#Y^P``#0```/[[
M```,````#/P```4````9_```"0```!_\```%````*?P```<````O_```!0``
M`#?\```$````/?P```(```!"_```.````$7\```L````?OP``!(```"K_```
M*0```+[\```R````Z/P```H````;_0``-@```";]```L````7?T``!4```"*
M_0``+@```*#]```S````S_T``#,````#_@``.````#?^```/````</X``!@`
M``"`_@``.P```)G^```0````U?X``!0```#F_@``$P```/O^```5````#_\`
M`!0````E_P``$@```#K_```4````3?\``!4```!B_P``+0```'C_```M````
MIO\``#$```#4_P``+0````8``0`N````-``!`"\```!C``$`+````),``0!B
M````P``!`!,````C`0$`"````#<!`0`(````0`$!`"L```!)`0$`(0```'4!
M`0`:````EP$!``D```"R`0$`10```+P!`0!!`````@(!``0```!$`@$`$P``
M`$D"`0`4````70(!``X```!R`@$`$P```($"`0`8````E0(!``8```"N`@$`
M"0```+4"`0`*````OP(!``\```#*`@$`$````-H"`0`'````ZP(!``X```#S
M`@$`!0````(#`0`;````"`,!``8````D`P$`"````"L#`0`&````-`,!`!0`
M```[`P$`$0```%`#`0`.````8@,!`#@```!Q`P$``@```*H#`0`&````K0,!
M``X```"T`P$`&@```,,#`0`%````W@,!``<```#D`P$`#@```.P#`0`&````
M^P,!``0````"!`$`*0````<$`0`7````,00!`!\```!)!`$`7````&D$`0`4
M````Q@0!`#X```#;!`$`'P```!H%`0`0````.@4!``<```!+!0$`#@```%,%
M`0`(````8@4!``P```!K!0$`#````'@%`0`3````A04!``H```"9!0$`'0``
M`*0%`0`9````P@4!``4```#<!0$`$0```.(%`0`1````]`4!`"0````&!@$`
M%0```"L&`0`2````008!``X```!4!@$`&0```&,&`0`(````?08!``D```"&
M!@$`#0```)`&`0`*````G@8!``<```"I!@$`#P```+$&`0`&````P08!``L`
M``#(!@$`"@```-0&`0`'````WP8!``@```#G!@$`!0```/`&`0`?````]@8!
M``8````6!P$`$````!T'`0`(````+@<!``T````W!P$`"````$4'`0`2````
M3@<!`"P```!A!P$`&@```(X'`0`)````J0<!``H```"S!P$`%0```+X'`0`%
M````U`<!`!0```#:!P$`!````.\'`0`0````]`<!``8````%"`$`!P````P(
M`0`>````%`@!`"@````S"`$`"@```%P(`0`<````9P@!`!H```"$"`$`#P``
M`)\(`0`4````KP@!``0```#$"`$`!````,D(`0`+````S@@!``4```#:"`$`
M!@```.`(`0`(````YP@!``8```#P"`$`"@```/<(`0`;`````@D!`#0````>
M"0$`-````%,)`0`@````B`D!`"D```"I"0$`(````-,)`0!!````]`D!`!H`
M```V"@$`*````%$*`0`I````>@H!`%$```"D"@$`+P```/8*`0`B````)@L!
M``8```!)"P$`"````%`+`0`%````60L!``@```!?"P$`&0```&@+`0`9````
M@@L!`"H```"<"P$`(P```,<+`0`9````ZPL!`"X````%#`$`-````#0,`0`(
M````:0P!`!<```!R#`$`"@```(H,`0`'````E0P!`"$```"=#`$`$````+\,
M`0`.````T`P!``L```#?#`$`!P```.L,`0`3````\PP!``@````'#0$`"P``
M`!`-`0`*````'`T!`!0````G#0$`#P```#P-`0`R````3`T!``L```!_#0$`
M!0```(L-`0`%````D0T!`!<```"7#0$`#P```*\-`0`$````OPT!``H```#$
M#0$`"0```,\-`0`+````V0T!``T```#E#0$`#````/,-`0`.``````X!``4`
M```/#@$`!````!4.`0`-````&@X!`#(````H#@$`10```%L.`0`7````H0X!
M`!X```"Y#@$`%````-@.`0`%````[0X!`!0```#S#@$`!P````@/`0`.````
M$`\!`"H````?#P$`!@```$H/`0`,````40\!``T```!>#P$`$0```&P/`0`+
M````?@\!`#8```"*#P$`"@```,$/`0`B````S`\!``L```#O#P$`#P```/L/
M`0`R````"Q`!`"4````^$`$`,````&00`0`Q````E1`!`"T```#'$`$`#@``
M`/40`0`%````!!$!``X````*$0$`$P```!D1`0`'````+1$!`!H````U$0$`
M"````%`1`0`1````61$!``<```!K$0$`%````',1`0`8````B!$!``<```"A
M$0$`!0```*D1`0`,````KQ$!``P```"\$0$`$@```,D1`0`$````W!$!``<`
M``#A$0$`"@```.D1`0`+````]!$!``P`````$@$`#@````T2`0`.````'!(!
M``4````K$@$`!0```#$2`0`N````-Q(!`"8```!F$@$`(P```(T2`0`#````
ML1(!`!(```"U$@$`!@```,@2`0`>````SQ(!`!@```#N$@$`)0````<3`0`-
M````+1,!``D````[$P$``P```$43`0`'````21,!``H```!1$P$``@```%P3
M`0`,````7Q,!`!4```!L$P$`"P```((3`0`9````CA,!`"````"H$P$`$@``
M`,D3`0`%````W!,!``H```#B$P$`%0```.T3`0`2`````Q0!``P````6%`$`
M!````",4`0`'````*!0!``D````P%`$`#````#H4`0!2````1Q0!`!<```":
M%`$`)````+(4`0`2````UQ0!``<```#J%`$`!@```/(4`0`.````^10!`"(`
M```(%0$`'0```"L5`0`,````214!``T```!6%0$`%0```&05`0`2````>A4!
M``\```"-%0$`%````)T5`0`;````LA4!`!````#.%0$`:0```-\5`0`:````
M218!`!<```!D%@$`)P```'P6`0`:````I!8!`!<```"_%@$`&P```-<6`0`9
M````\Q8!`!\````-%P$`$P```"T7`0`(````01<!``<```!*%P$`"````%(7
M`0`)````6Q<!`!4```!E%P$`#0```'L7`0`C````B1<!`!,```"M%P$``P``
M`,$7`0!&````Q1<!`#\````,&`$`-P```$P8`0!7````A!@!``4```#<&`$`
M'P```.(8`0`O`````AD!``H````R&0$`"````#T9`0`-````1AD!`"T```!4
M&0$`!````((9`0!/````AQD!`"4```#7&0$`'````/T9`0`+````&AH!`!\`
M```F&@$`'0```$8:`0`E````9!H!`"````"*&@$`)````*L:`0`@````T!H!
M``L```#Q&@$`!P```/T:`0`-````!1L!``P````3&P$`%P```"`;`0`&````
M.!L!`#D````_&P$`#````'D;`0`'````AAL!`!D```".&P$`"0```*@;`0`3
M````LAL!``D```#&&P$`!````-`;`0`0````U1L!``H```#F&P$`"````/$;
M`0`(````^AL!``0````#'`$`"P````@<`0`,````%!P!`!(````A'`$`$0``
M`#0<`0`,````1AP!`!H```!3'`$`#P```&X<`0`'````?AP!``T```"&'`$`
M%````)0<`0`.````J1P!``P```"X'`$`&P```,4<`0`L````X1P!`!,````.
M'0$`'````"(=`0`H````/QT!``8```!H'0$`!P```&\=`0`3````=QT!``4`
M``"+'0$`!````)$=`0`7````EAT!``H```"N'0$`#````+D=`0`)````QAT!
M``8```#0'0$`"0```-<=`0`(````X1T!``D```#J'0$`"@```/0=`0`1````
M_QT!``8````1'@$`&````!@>`0`.````,1X!``X```!`'@$`#0```$\>`0`+
M````71X!`!T```!I'@$`"P```(<>`0`"````DQX!``<```"6'@$`!@```)X>
M`0!E````I1X!``D````+'P$`!P```!4?`0`F````'1\!`#@```!$'P$`&@``
M`'T?`0`J````F!\!`#L```##'P$`*````/\?`0`T````*"`!`!D```!=(`$`
M%0```'<@`0`%````C2`!``<```"3(`$`"````)L@`0`'````I"`!``4```"L
M(`$`!P```+(@`0`.````NB`!``D```#)(`$`!@```-,@`0`(````VB`!``L`
M``#C(`$`!P```.\@`0`(````]R`!``<`````(0$`%@````@A`0`)````'R$!
M``8````I(0$`"P```#`A`0`<````/"$!`!0```!9(0$`!P```&XA`0`1````
M=B$!``@```"((0$`#@```)$A`0`(````H"$!``4```"I(0$`$````*\A`0`0
M````P"$!``8```#1(0$`&0```-@A`0`*````\B$!`!P```#](0$`!P```!HB
M`0`%````(B(!`!`````H(@$`%````#DB`0`+````3B(!``T```!:(@$`*```
M`&@B`0`8````D2(!`!<```"J(@$`!````,(B`0`)````QR(!``H```#1(@$`
M!P```-PB`0`"````Y"(!``X```#G(@$`"````/8B`0`?````_R(!`#X````?
M(P$`(P```%XC`0`X````@B,!`"8```"[(P$`,0```.(C`0`G````%"0!`&0`
M```\)`$`%````*$D`0!5````MB0!`#@````,)0$`2@```$4E`0!;````D"4!
M`"@```#L)0$`.````!4F`0`H````3B8!`"P```!W)@$`)P```*0F`0`;````
MS"8!`#X```#H)@$`J0$``"<G`0`H````T2@!`",```#Z*`$`%P```!XI`0!(
M````-BD!`(4```!_*0$`,`````4J`0!!````-BH!`%L```!X*@$`20```-0J
M`0`=````'BL!`!@````\*P$`(0```%4K`0`?````=RL!`"L```"7*P$`(0``
M`,,K`0`G````Y2L!`!T````-+`$`$0```"LL`0`S````/2P!`"4```!Q+`$`
M)P```)<L`0`?````ORP!`#````#?+`$`:0```!`M`0`K````>BT!`#$```"F
M+0$`00```-@M`0`S````&BX!`"4```!.+@$`/0```'0N`0!E````LBX!`$T`
M```8+P$`+P```&8O`0`N````EB\!`#````#%+P$`5````/8O`0"#````2S`!
M`%H```#/,`$`2````"HQ`0!*````<S$!`#(```"^,0$`+P```/$Q`0`L````
M(3(!`"T```!.,@$`<0```'PR`0!O````[C(!`+,```!>,P$`%P```!(T`0`E
M````*C0!`#(```!0-`$`*0```(,T`0`^````K30!`"(```#L-`$`4@````\U
M`0`E````8C4!``L```"(-0$`L0```)0U`0!%````1C8!`"$```",-@$`+@``
M`*XV`0`P````W38!`"4````.-P$`'````#0W`0`Q````43<!``<```"#-P$`
M!P```(LW`0`$````DS<!``T```"8-P$`"P```*8W`0`.````LC<!``L```#!
M-P$`!0```,TW`0`0````TS<!``(```#D-P$`60```.<W`0`%````03@!`!(`
M``!'.`$`!````%HX`0`'````7S@!``@```!G.`$`!0```'`X`0`#````=C@!
M`!````!Z.`$`"@```(LX`0`,````EC@!`!,```"C.`$`#0```+<X`0`"````
MQ3@!``<```#(.`$`!@```-`X`0`4````US@!``P```#L.`$`&````/DX`0`&
M````$CD!`!(````9.0$`#````"PY`0`#````.3D!`"H````].0$`!````&@Y
M`0`&````;3D!``<```!T.0$`'P```'PY`0`U````G#D!`"X```#2.0$`+P``
M``$Z`0`7````,3H!`"````!).@$`&P```&HZ`0`8````ACH!`"0```"?.@$`
M'P```,0Z`0`:````Y#H!`"````#_.@$`&@```"`[`0`R````.SL!`!H```!N
M.P$`+P```(D[`0`K````N3L!`!\```#E.P$`(P````4\`0`?````*3P!`!H`
M``!)/`$`)0```&0\`0`F````BCP!`"4```"Q/`$`)````-<\`0`8````_#P!
M`!T````5/0$`)````#,]`0`8````6#T!`"(```!Q/0$`%0```)0]`0`E````
MJCT!`#P```#0/0$`'P````T^`0`C````+3X!`!\```!1/@$`(````'$^`0`:
M````DCX!`!@```"M/@$`)@```,8^`0`>````[3X!`"D````,/P$`'@```#8_
M`0`)````53\!``P```!?/P$`%P```&P_`0`O````A#\!`"0```"T/P$`!P``
M`-D_`0`/````X3\!`!0```#Q/P$`#@````9``0`-````%4`!`"0````C0`$`
M!0```$A``0`'````3D`!`"(```!60`$`)0```'E``0`3````GT`!`!H```"S
M0`$`'0```,Y``0`:````[$`!``<````'00$`QP````]!`0`+````UT$!`!4`
M``#C00$`#````/E!`0`&````!D(!``D````-0@$`"P```!="`0`-````(T(!
M`!T````Q0@$`%P```$]"`0`&````9T(!`#,```!N0@$`$P```*)"`0`3````
MMD(!``<```#*0@$`!@```-)"`0`/````V4(!``<```#I0@$`,@```/%"`0`A
M````)$,!`!,```!&0P$`#````%I#`0`1````9T,!`#(```!Y0P$`$````*Q#
M`0`(````O4,!`!T```#&0P$`"0```.1#`0`*````[D,!``4```#Y0P$`%```
M`/]#`0`*````%$0!`!T````?1`$`"````#U$`0`?````1D0!``@```!F1`$`
M&@```&]$`0`G````BD0!``8```"R1`$`%0```+E$`0`'````ST0!``@```#7
M1`$`"0```.!$`0`_````ZD0!``<````J10$`#P```#)%`0`.````0D4!`!``
M``!110$`"0```&)%`0`)````;$4!``@```!V10$`$P```']%`0`'````DT4!
M`!D```";10$`"@```+5%`0`7````P$4!`!0```#810$`"@```.U%`0`,````
M^$4!`!<````%1@$`!````!U&`0`J````(D8!`!$```!-1@$`!P```%]&`0`)
M````9T8!``(```!Q1@$`$````'1&`0`8````A48!``L```">1@$``P```*I&
M`0`(````KD8!``8```"W1@$`!P```+Y&`0`-````QD8!``L```#41@$`%```
M`.!&`0`5````]48!``X````+1P$`+P```!I'`0`@````2D<!`!P```!K1P$`
M#````(A'`0`Q````E4<!``4```#'1P$`$@```,U'`0`_````X$<!`!(````@
M2`$`"@```#-(`0`&````/D@!``0```!%2`$`!````$I(`0`*````3T@!`!,`
M``!:2`$`!0```&Y(`0`&````=$@!``8```![2`$`"0```()(`0`$````C$@!
M``P```"12`$`"@```)Y(`0`@````J4@!``4```#*2`$`&````-!(`0`9````
MZ4@!`!\````#20$`'0```"-)`0`1````04D!``(```!320$`!````%9)`0`*
M````6TD!``8```!F20$`!0```&U)`0`#````<TD!``P```!W20$`10```(1)
M`0`:````RDD!`#4```#E20$`*````!M*`0!3````1$H!`!D```"82@$`<@``
M`+)*`0`@````)4L!`#4```!&2P$`(0```'Q+`0!%````GDL!`#````#D2P$`
M*````!5,`0`I````/DP!`"8```!H3`$`)0```(],`0`H````M4P!`"@```#>
M3`$`(@````=-`0`K````*DT!`#````!630$`$@```(=-`0`3````FDT!`!``
M``"N30$`>0```+]-`0`)````.4X!`'(```!#3@$`<P```+9.`0!\````*D\!
M`"L```"G3P$`5````--/`0`7````*%`!`!8```!`4`$`#P```%=0`0!E````
M9U`!`!\```#-4`$`0````.U0`0`?````+E$!`!P```!.40$`40```&M1`0`4
M````O5$!``H```#240$`!0```-U1`0`&````XU$!``@```#J40$`!0```/-1
M`0`2````^5$!`!`````,4@$`$P```!U2`0`=````,5(!``\```!/4@$`#P``
M`%]2`0`$````;U(!``D```!T4@$`"P```'Y2`0`'````BE(!``4```"24@$`
M%````)A2`0`'````K5(!``@```"U4@$`#P```+Y2`0`(````SE(!``P```#7
M4@$`#P```.12`0`&````]%(!`!0```#[4@$`!@```!!3`0`,````%U,!`!4`
M```D4P$`"````#I3`0`$````0U,!``H```!(4P$`!````%-3`0`&````6%,!
M``<```!?4P$`!````&=3`0`'````;%,!`!D```!T4P$`!P```(Y3`0`"````
MEE,!``(```"94P$`"0```)Q3`0`&````IE,!``8```"M4P$`)P```+13`0`"
M````W%,!``0```#?4P$`"P```.13`0`)````\%,!``\```#Z4P$`$P````I4
M`0`'````'E0!``<````F5`$`!@```"Y4`0`&````-50!`!`````\5`$`$@``
M`$U4`0`"````8%0!``8```!C5`$`"0```&I4`0`S````=%0!`"(```"H5`$`
M!P```,M4`0`'````TU0!``<```#;5`$`"P```.-4`0`%````[U0!``(```#U
M5`$`"P```/A4`0!B`0``!%4!`',```!G5@$`N````-M6`0!"````E%<!`,``
M``#75P$`D````)A8`0!&````*5D!`#<```!P60$`,P```*A9`0`V````W%D!
M`"\````36@$`+@```$-:`0!H````<EH!`&4```#;6@$`9P```$%;`0!E````
MJ5L!`&<````/7`$`;P```'=<`0`_````YUP!`&0````G70$`0P```(Q=`0`O
M````T%T!`$T`````7@$`1````$Y>`0!*````DUX!`#,```#>7@$`.````!)?
M`0!N````2U\!`"X```"Z7P$`+0```.E?`0"(````%V`!`&(```"@8`$`#P$`
M``-A`0!.````$V(!`#0```!B8@$`BP```)=B`0!0````(V,!`!````!T8P$`
M%0```(5C`0`4````FV,!``<```"P8P$`"0```+AC`0`(````PF,!``4```#+
M8P$`'@```-%C`0`N````\&,!`"P````?9`$`*0```$QD`0`N````=F0!`!@`
M``"E9`$`"@```+YD`0`1````R60!`"L```#;9`$`$P````=E`0`0````&V4!
M`!`````L90$`%````#UE`0`%````4F4!`"@```!890$`#0```(%E`0`-````
MCV4!`!,```"=90$`#0```+%E`0`+````OV4!`!L```#+90$`$````.=E`0`*
M````^&4!`!8````#9@$`/P```!IF`0`-````6F8!``\```!H9@$`$````'AF
M`0`+````B68!``T```"59@$`!@```*-F`0`-````JF8!`!,```"X9@$`%0``
M`,QF`0`-````XF8!`!L```#P9@$`&P````QG`0`3````*&<!``@````\9P$`
M"0```$5G`0!8````3V<!`#0```"H9P$`%0```-UG`0`]````\V<!`$X````Q
M:`$`:@```(!H`0!I````ZV@!`'````!5:0$`;P```,9I`0!"````-FH!``\`
M``!Y:@$`$@```(EJ`0`.````G&H!`!,```"K:@$`#P```+]J`0`%````SVH!
M``8```#5:@$`$P```-QJ`0`)````\&H!``\```#Z:@$`$0````IK`0`A````
M'&L!`",````^:P$`%@```&)K`0`0````>6L!``T```"*:P$`"0```)AK`0`5
M````HFL!`!D```"X:P$`$0```-)K`0`5````Y&L!`!@```#Z:P$`'P```!-L
M`0`D````,VP!`!H```!8;`$`$````'-L`0`7````A&P!`!(```"<;`$`+@``
M`*]L`0`8````WFP!`!P```#W;`$`%````!1M`0!9````*6T!`"H```"#;0$`
M*@```*YM`0`J````V6T!``@````$;@$`"0````UN`0`W````%VX!``T```!/
M;@$`"````%UN`0`+````9FX!``<```!R;@$`!P```'IN`0`'````@FX!``<`
M``"*;@$`#````))N`0`$````GVX!`"(```"D;@$`#P```,=N`0`3````UVX!
M`!<```#K;@$`'`````-O`0`P````(&\!``D```!1;P$`&````%MO`0`>````
M=&\!`",```"3;P$`$0```+=O`0`4````R6\!`!(```#>;P$`#P```/%O`0`C
M`````7`!`!T````E<`$`!P```$-P`0`&````2W`!``<```!2<`$`&@```%IP
M`0`(````=7`!``H```!^<`$`$0```(EP`0`)````FW`!`!$```"E<`$`&@``
M`+=P`0`'````TG`!`!(```#:<`$`!0```.UP`0`6````\W`!`!X````*<0$`
M#P```"EQ`0`_````.7$!`#L```!Y<0$`"0```+5Q`0`'````OW$!`!,```#'
M<0$`!````-MQ`0`%````X'$!`!````#F<0$`"@```/=Q`0`4`````G(!`#P`
M```7<@$`%0```%1R`0`M````:G(!`#(```"8<@$`,0```,MR`0`P````_7(!
M``D````N<P$`!@```#AS`0`)````/W,!``<```!)<P$`.P```%%S`0`[````
MC7,!`#H```#)<P$`7P````1T`0`Y````9'0!`#D```">=`$`.0```-AT`0!+
M````$G4!`"T```!>=0$`,````(QU`0`Y````O74!`#\```#W=0$`%0```#=V
M`0`9````378!`#(```!G=@$`)@```)IV`0`3````P78!``H```#5=@$`$```
M`.!V`0`%````\78!``P```#W=@$`'@````1W`0`C````(W<!``8```!'=P$`
M!0```$YW`0`5````5'<!``L```!J=P$`"````'9W`0`*````?W<!``P```"*
M=P$`!P```)=W`0`&````GW<!``4```"F=P$`!P```*QW`0`%````M'<!``L`
M``"Z=P$`,@```,9W`0`7````^7<!``T````1>`$`!P```!]X`0`'````)W@!
M``H````O>`$`!0```#IX`0`3````0'@!``8```!4>`$`$@```%MX`0`%````
M;G@!``@```!T>`$`!````'UX`0`+````@G@!``8```".>`$`)0```)5X`0`1
M````NW@!`"L```#->`$`'@```/EX`0`(````&'D!``X````A>0$`#0```#!Y
M`0`'````/GD!``,```!&>0$``P```$IY`0`:````3GD!`"````!I>0$`*P``
M`(IY`0`*````MGD!``4```#!>0$`"````,=Y`0`(````T'D!`%X```#9>0$`
M*````#AZ`0`&````87H!``@```!H>@$`'P```'%Z`0`D````D7H!`"\```"V
M>@$`,@```.9Z`0`F````&7L!`"8```!`>P$`70```&=[`0`^````Q7L!`!<`
M```$?`$`!P```!Q\`0`2````)'P!``P````W?`$`$````$1\`0`8````57P!
M`!<```!N?`$`&````(9\`0`8````GWP!``D```"X?`$`%0```,)\`0`'````
MV'P!`!D```#@?`$`&P```/I\`0`9````%GT!`!,````P?0$`&````$1]`0`2
M````77T!``<```!P?0$`6P```'A]`0`)````U'T!`!4```#>?0$`-@```/1]
M`0`2````*WX!`!H````^?@$`'0```%E^`0`9````=WX!`!<```"1?@$`'0``
M`*E^`0`>````QWX!`#(```#F?@$`#0```!E_`0`L````)W\!`"<```!4?P$`
M'0```'Q_`0`&````FG\!`!P```"A?P$`'@```+Y_`0`:````W7\!`!H```#X
M?P$`"P```!.``0`5````'X`!`!,````U@`$`#0```$F``0`&````5X`!``\`
M``!>@`$`"````&Z``0`5````=X`!`!8```"-@`$`$0```*2``0`5````MH`!
M``4```#,@`$`!@```-*``0`1````V8`!``@```#K@`$`$P```/2``0`"````
M"($!``<````+@0$`$P```!.!`0`2````)X$!``D````Z@0$`"@```$2!`0`)
M````3X$!``H```!9@0$`!P```&2!`0`'````;($!``T```!T@0$`#````(*!
M`0`(````CX$!``D```"8@0$`&@```**!`0`B````O8$!``T```#@@0$`&```
M`.Z!`0`>````!X(!`!X````F@@$`#P```$6"`0`0````58(!`#````!F@@$`
M/P```)>"`0`A````UX(!`#P```#Y@@$`*````#:#`0`.````7X,!``D```!N
M@P$`"@```'B#`0`.````@X,!``8```"2@P$`#P```)F#`0`6````J8,!`!<`
M``#`@P$`'````-B#`0`N````]8,!`"P````DA`$`,````%&$`0`O````@H0!
M`"D```"RA`$`*0```-R$`0`F````!H4!`#D````MA0$`(@```&>%`0`P````
MBH4!`$(```"[A0$`,0```/Z%`0`R````,(8!`"4```!CA@$`,@```(F&`0`Y
M````O(8!`$X```#VA@$`-0```$6'`0`X````>X<!`$,```"TAP$`)````/B'
M`0`6````'8@!`$\````TB`$`*0```(2(`0`:````KH@!`#L```#)B`$`(@``
M``6)`0`8````*(D!`-4```!!B0$`&@```!>*`0`M````,HH!`#````!@B@$`
M,0```)&*`0`R````PXH!`"D```#VB@$`%@```""+`0`N````-XL!`#<```!F
MBP$`.@```)Z+`0`]````V8L!`#H````7C`$`F@```%*,`0`K````[8P!`!\`
M```9C0$`*````#F-`0`W````8HT!`#8```":C0$`5@```-&-`0!9````*(X!
M``T```""C@$`!````)".`0`&````E8X!``4```"<C@$`$0```**.`0`.````
MM(X!`!````##C@$`%0```-2.`0`;````ZHX!`!0````&CP$`$0```!N/`0`6
M````+8\!``D```!$CP$`#@```$Z/`0`/````78\!`!$```!MCP$`#0```'^/
M`0!#````C8\!``8```#1CP$`$0```-B/`0`3````ZH\!`!$```#^CP$`%P``
M`!"0`0`;````*)`!``\```!$D`$``@```%20`0`+````5Y`!`!P```!CD`$`
M!````("0`0`0````A9`!`!````"6D`$``P```*>0`0`/````JY`!``@```"[
MD`$`$````,20`0`2````U9`!``L```#HD`$`#P```/20`0`1````!)$!`!8`
M```6D0$`%@```"V1`0`*````1)$!``<```!/D0$`#0```%>1`0`1````99$!
M`!H```!WD0$`#@```)*1`0`.````H9$!`"0```"PD0$`&@```-61`0`X````
M\)$!``T````ID@$`'P```#>2`0`9````5Y(!`!@```!QD@$`-@```(J2`0`G
M````P9(!`!(```#ID@$`"0```/R2`0`3````!I,!``D````:DP$`,````"23
M`0`[````59,!``\```"1DP$`$````*&3`0`A````LI,!`!(```#4DP$`(P``
M`.>3`0`C````"Y0!``H````OE`$`'````#J4`0`6````5Y0!`!X```!NE`$`
M%@```(V4`0`7````I)0!`!D```"\E`$`!P```-:4`0`+````WI0!`"H```#J
ME`$`2@```!65`0`(````8)4!`!0```!IE0$`!P```'Z5`0`*````AI4!`#<`
M``"1E0$`$P```,F5`0`&````W94!`!,```#DE0$``P```/B5`0`4````_)4!
M``8````1E@$`#````!B6`0`,````)98!`!$````RE@$`$0```$26`0`7````
M5I8!`!$```!NE@$`&0```("6`0`7````FI8!``@```"RE@$`!@```+N6`0`8
M````PI8!``L```#;E@$``@```.>6`0`3````ZI8!`!\```#^E@$`'P```!Z7
M`0`8````/I<!`!(```!7EP$`#P```&J7`0`/````>I<!`!4```"*EP$`/@``
M`*"7`0`R````WY<!``H````2F`$`#P```!V8`0"B````+9@!`!X```#0F`$`
M30```.^8`0`0````/9D!`!(```!.F0$`!````&&9`0`H````9ID!`!8```"/
MF0$`!@```*:9`0`4````K9D!`"@```#"F0$`!0```.N9`0`&````\9D!``\`
M``#XF0$`#@````B:`0`0````%YH!``X````HF@$`#````#>:`0`.````1)H!
M``L```!3F@$`$````%^:`0`(````<)H!``L```!YF@$`"````(6:`0`5````
MCIH!``P```"DF@$`/P```+&:`0`1````\9H!``@````#FP$`$P````R;`0`5
M````()L!`"L````VFP$`)P```&*;`0`B````BIL!`"$```"MFP$`&````,^;
M`0`:````Z)L!`"4````#G`$`&0```"F<`0`#````0YP!`!D```!'G`$`"P``
M`&&<`0`+````;9P!``,```!YG`$`"0```'V<`0`(````AYP!``H```"0G`$`
M$0```)N<`0`-````K9P!`!````"[G`$`!````,R<`0`@````T9P!`"$```#R
MG`$`$P```!2=`0`/````*)T!`!,````XG0$`%P```$R=`0`N````9)T!``<`
M``"3G0$`"0```)N=`0`0````I9T!`!````"VG0$`"P```,>=`0`(````TYT!
M``D```#<G0$`"````.:=`0`6````[YT!``P````&G@$`!@```!.>`0`I````
M&IX!``X```!$G@$`B0```%.>`0`=````W9X!``<```#[G@$`!0````.?`0`-
M````"9\!``4````7GP$`!P```!V?`0`&````)9\!``@````LGP$`)````#6?
M`0`3````6I\!``(```!NGP$`"````'&?`0`2````>I\!`!4```"-GP$`#P``
M`*.?`0`2````LY\!`"<```#&GP$``@```.Z?`0`#````\9\!`!(```#UGP$`
M"0````B@`0`-````$J`!``<````@H`$`$@```"B@`0`@````.Z`!``@```!<
MH`$`$P```&6@`0`5````>:`!``T```"/H`$`(````)V@`0`'````OJ`!`!T`
M``#&H`$`#P```.2@`0`1````]*`!``D````&H0$`#````!"A`0`"````':$!
M``4````@H0$`#P```":A`0`2````-J$!``8```!)H0$`$@```%"A`0`+````
M8Z$!``<```!OH0$`%P```'>A`0`F````CZ$!`!,```"VH0$`!@```,JA`0`)
M````T:$!``0```#;H0$`%@```."A`0`(````]Z$!`!8`````H@$`%@```!>B
M`0`0````+J(!``4````_H@$`#````$6B`0`@````4J(!``0```!SH@$`10``
M`'BB`0!&````OJ(!`$4````%HP$`)0```$NC`0`2````<:,!`!,```"$HP$`
M!P```)BC`0`)````H*,!`!8```"JHP$`$````,&C`0`5````TJ,!``8```#H
MHP$`!0```.^C`0`4````]:,!``4````*I`$`G````!"D`0`*````K:0!`!X`
M``"XI`$`!````->D`0`S````W*0!``4````0I0$`'````!:E`0`$````,Z4!
M`!`````XI0$`$````$FE`0`6````6J4!``P```!QI0$`!0```'ZE`0`:````
MA*4!`#(```"?I0$`-P```-*E`0!`````"J8!`"P```!+I@$`,@```'BF`0!!
M````JZ8!`$H```#MI@$`,0```#BG`0!%````:J<!`#4```"PIP$`-P```.:G
M`0`G````'J@!`!````!&J`$`%0```%>H`0`+````;:@!`"@```!YJ`$`(```
M`**H`0`A````PZ@!`!\```#EJ`$`"`````6I`0`*````#JD!``H````9J0$`
M%````"2I`0`I````.:D!`"<```!CJ0$`,````(NI`0`+````O*D!`!D```#(
MJ0$`*0```.*I`0`:````#*H!`!0````GJ@$`%````#RJ`0`-````4:H!`!``
M``!?J@$`$P```'"J`0!$````A*H!`'T```#)J@$`@@```$>K`0`3````RJL!
M``T```#>JP$`#@```.RK`0`1````^ZL!`!(````-K`$`%@```""L`0`'````
M-ZP!`!(````_K`$`$P```%*L`0`2````9JP!`!4```!YK`$`+````(^L`0`L
M````O*P!`&T```#IK`$`%0```%>M`0`2````;:T!`!@```"`K0$`%@```)FM
M`0`*````L*T!``H```"[K0$`(0```,:M`0`=````Z*T!`!8````&K@$`#@``
M`!VN`0`.````+*X!`!4````[K@$`%0```%&N`0`J````9ZX!`"D```"2K@$`
M*0```+RN`0`H````YJX!`"<````/KP$`*0```#>O`0`:````8:\!`%4```!\
MKP$`$P```-*O`0`5````YJ\!`!4```#\KP$`%````!*P`0`1````)[`!`!<`
M```YL`$`%P```%&P`0`4````:;`!`!,```!^L`$`.@```)*P`0`8````S;`!
M`!D```#FL`$`/@````"Q`0`5````/[$!``<```!5L0$`$0```%VQ`0`@````
M;[$!`!,```"0L0$`$P```*2Q`0`>````N+$!`"(```#7L0$`'0```/JQ`0`;
M````&+(!`!H````TL@$`(@```$^R`0`2````<K(!`!P```"%L@$`(0```**R
M`0`<````Q+(!`!@```#AL@$`&P```/JR`0`3````%K,!`!L````JLP$`'```
M`$:S`0`<````8[,!`!@```"`LP$`"@```)FS`0`:````I+,!`!,```"_LP$`
M%````-.S`0`+````Z+,!`!0```#TLP$`$`````FT`0`'````&K0!``<````B
MM`$`$@```"JT`0`'````/;0!``<```!%M`$`!0```$VT`0`5````4[0!``8`
M``!IM`$`&P```'"T`0`%````C+0!``4```"2M`$`"@```)BT`0`'````H[0!
M``H```"KM`$`%0```+:T`0`4````S+0!`!@```#AM`$`%0```/JT`0`3````
M$+4!`"P````DM0$`$P```%&U`0`0````9;4!`!H```!VM0$`%````)&U`0`-
M````IK4!`!,```"TM0$`,0```,BU`0`&````^K4!``D````!M@$`)P````NV
M`0`3````,[8!`!````!'M@$`!@```%BV`0`3````7[8!``L```!SM@$`!@``
M`'^V`0`A````AK8!`!(```"HM@$`$@```+NV`0`4````SK8!`!(```#CM@$`
M&````/:V`0`5````#[<!`!0````EMP$``P```#JW`0`*````/K<!`"$```!)
MMP$`!@```&NW`0`(````<K<!`!4```![MP$`$@```)&W`0`&````I+<!``<`
M``"KMP$`,P```+.W`0`,````Y[<!`!,```#TMP$`"0````BX`0`2````$K@!
M`!4````EN`$`$0```#NX`0`5````3;@!``T```!CN`$`!````'&X`0`*````
M=K@!``<```"!N`$`%````(FX`0!)````GK@!``@```#HN`$`#P```/&X`0`E
M`````;D!`!4````GN0$`&````#VY`0`.````5KD!`!````!EN0$`#@```':Y
M`0`+````A;D!``T```"1N0$`$P```)^Y`0`3````L[D!`!<```#'N0$`+```
M`-^Y`0`+````#+H!`!4````8N@$`&0```"ZZ`0`-````2+H!``P```!6N@$`
M&@```&.Z`0`+````?KH!``8```"*N@$`!````)&Z`0`2````EKH!`%8```"I
MN@$`%@````"[`0`+````%[L!``0````CNP$`!0```"B[`0`8````+KL!`!D`
M``!'NP$`&@```&&[`0`*````?+L!``(```"'NP$`!````(J[`0`C````C[L!
M``,```"SNP$`!0```+>[`0`H````O;L!``H```#FNP$`!0```/&[`0`'````
M][L!`!@```#_NP$`$0```!B\`0!1````*KP!`!(```!\O`$`!@```(^\`0`'
M````EKP!``@```">O`$`!````*>\`0`%````K+P!`&0```"RO`$`"@```!>]
M`0`-````(KT!``4````PO0$`!@```#:]`0`9````/;T!`#@```!7O0$`#@``
M`)"]`0`)````G[T!`!<```"IO0$`"@```,&]`0`(````S+T!`!D```#5O0$`
M+P```.^]`0`I````'[X!`"@```!)O@$`$@```'*^`0`$````A;X!``<```"*
MO@$`"````)*^`0`'````F[X!``T```"CO@$`#````+&^`0`V````OKX!`!\`
M``#UO@$`,0```!6_`0`E````1[\!``@```!MOP$`60```':_`0`1````T+\!
M`!````#BOP$`$@```/._`0`9````!L`!`$X````@P`$`'0```&_``0`&````
MC<`!`!\```"4P`$`!P```+3``0`&````O,`!`"````##P`$`!@```.3``0`)
M````Z\`!`"<```#UP`$`)@```!W!`0`'````1,$!``H```!,P0$`)0```%?!
M`0!+````?<$!`!@```#)P0$`'0```.+!`0`6`````,(!``(````7P@$`#0``
M`!K"`0`(````*,(!`!,````QP@$`#0```$7"`0`&````4\(!``8```!:P@$`
M%````&'"`0`4````=L(!``@```"+P@$`"0```)3"`0`+````GL(!``H```"J
MP@$`"P```+7"`0`1````P<(!``\```#3P@$`$@```./"`0`3````]L(!``8`
M```*PP$`%0```!'#`0`4````)\,!``4````\PP$`!@```$+#`0`%````2<,!
M`!<```!/PP$`(````&?#`0`1````B,,!``T```":PP$`#````*C#`0`4````
MM<,!`!````#*PP$`$0```-O#`0`$````[<,!`!0```#RPP$`!0````?$`0`%
M````#<0!`!<````3Q`$`$P```"O$`0`4````/\0!`!P```!4Q`$`(0```''$
M`0`9````D\0!`!D```"MQ`$`'0```,?$`0`B````Y<0!`!P````(Q0$`!```
M`"7%`0`%````*L4!``X````PQ0$`#@```#_%`0`(````3L4!`"(```!7Q0$`
M#0```'K%`0`4````B,4!``@```"=Q0$`$@```*;%`0`'````N<4!`!````#!
MQ0$`#P```-+%`0`(````XL4!`!8```#KQ0$`$@````+&`0`<````%<8!``4`
M```RQ@$`!````#C&`0`#````/<8!`%$```!!Q@$`/P```)/&`0`>````T\8!
M`"0```#RQ@$`00```!?'`0`1````6<<!`#X```!KQP$`+@```*K'`0`<````
MV<<!`#H```#VQP$`2@```#'(`0!7````?,@!`%P```#4R`$`$````#')`0`B
M````0LD!`$<```!ER0$`%0```*W)`0`A````P\D!`!X```#ER0$`(P````3*
M`0`?````*,H!`!D```!(R@$`&P```&+*`0`3````?LH!`#D```"2R@$`.0``
M`,S*`0`]````!LL!`#D```!$RP$`.@```'[+`0`[````N<L!`#@```#URP$`
M<0```"[,`0`=````H,P!``H```"^S`$`"0```,G,`0`P````T\P!`#L````$
MS0$`*0```$#-`0`+````:LT!`$L```!VS0$`1@```,+-`0`'````"<X!`!<`
M```1S@$`%0```"G.`0`/````/\X!`!````!/S@$`%P```&#.`0`0````>,X!
M``\```")S@$`#@```)G.`0`3````J,X!`!$```"\S@$`#````,[.`0`.````
MV\X!``4```#JS@$`(P```/#.`0`$````%,\!``@````9SP$`!@```"+/`0`4
M````*<\!`!$````^SP$`$````%#/`0!2````8<\!``(```"TSP$`!P```+?/
M`0`2````O\\!`"````#2SP$`!0```///`0`'````^<\!`!L````!T`$`"```
M`!W0`0`0````)M`!`#(````WT`$`%@```&K0`0`R````@=`!`'8```"TT`$`
M%0```"O1`0!.````0=$!`"(```"0T0$`$0```+/1`0`&````Q=$!``P```#,
MT0$`!P```-G1`0`.````X=$!``L```#PT0$`%@```/S1`0`+````$](!`!P`
M```?T@$`&````#S2`0`%````5=(!`!(```!;T@$`$@```&[2`0`E````@=(!
M`!8```"GT@$`%0```+[2`0`1````U-(!`",```#FT@$`"@````K3`0`,````
M%=,!`!0````BTP$`$P```#?3`0`,````2],!``X```!8TP$`"P```&?3`0`3
M````<],!``T```"'TP$`"@```)73`0`?````H-,!`!(```#`TP$`%P```-/3
M`0`&````Z],!`!````#RTP$`%0````/4`0`6````&=0!``T````PU`$`&```
M`#[4`0`Q````5]0!`!T```")U`$`#@```*?4`0`/````MM0!`"0```#&U`$`
M!0```.O4`0`1````\=0!``<````#U0$`%@````O5`0`'````(M4!``L````J
MU0$`(````#;5`0`T````5]4!``D```",U0$`(@```);5`0`;````N=4!``T`
M``#5U0$`%````./5`0`$````^-4!`!0```#]U0$`"0```!+6`0`(````'-8!
M``L````EU@$`#@```#'6`0`&````0-8!``H```!'U@$`(0```%+6`0`_````
M=-8!`$````"TU@$`)````/76`0`M````&M<!`"H```!(UP$`1P```'/7`0`D
M````N]<!`#,```#@UP$`0P```!38`0!A````6-@!`#0```"ZV`$`+0```._8
M`0`'````'=D!``@````EV0$`"0```"[9`0`4````.-D!`!L```!-V0$`&P``
M`&G9`0`P````A=D!`"4```"VV0$`(@```-S9`0`Z````_]D!`$(````ZV@$`
M!P```'W:`0`9````A=H!``D```"?V@$`"````*G:`0`@````LMH!`!$```#3
MV@$`%````.7:`0`-````^MH!``@````(VP$`%0```!';`0`)````)]L!``\`
M```QVP$`#0```$';`0`:````3]L!`!@```!JVP$`.P```(/;`0`*````O]L!
M``\```#*VP$`!@```-K;`0`:````X=L!`!````#\VP$`!0````W<`0`-````
M$]P!`!`````AW`$`"0```#+<`0`,````/-P!``P```!)W`$`#@```%;<`0`'
M````9=P!``,```!MW`$`#0```''<`0`V````?]P!`$@```"VW`$`&````/_<
M`0`E````&-T!`"$````^W0$`$0```&#=`0`5````<MT!``L```"(W0$`$@``
M`)3=`0`I````I]T!``<```#1W0$`#0```-G=`0`.````Y]T!`!(```#VW0$`
M"P````G>`0`\````%=X!``D```!2W@$`'````%S>`0`2````>=X!`!8```",
MW@$`0````*/>`0`D````Y-X!`#P````)WP$`.@```$;?`0`V````@=\!`!$`
M``"XWP$`!@```,K?`0`7````T=\!`!P```#IWP$`"@````;@`0`=````$>`!
M``L````OX`$`$````#O@`0`'````3.`!`!4```!4X`$`%0```&K@`0`)````
M@.`!``<```"*X`$`%````)+@`0`1````I^`!`!D```"YX`$`!0```-/@`0`'
M````V>`!``D```#AX`$`$````.O@`0`/````_.`!`!4````,X0$`%0```"+A
M`0`'````..$!``8```!`X0$`,0```$?A`0`I````>>$!`"4```"CX0$`"```
M`,GA`0`/````TN$!`!,```#BX0$`'P```/;A`0`>````%N(!`!\````UX@$`
M#0```%7B`0`,````8^(!``,```!PX@$`!P```'3B`0`-````?.(!``(```"*
MX@$`#````(WB`0`1````FN(!``L```"LX@$`%````+CB`0`8````S>(!`!4`
M``#FX@$`'````/SB`0`C````&>,!`!,````]XP$`%@```%'C`0`.````:.,!
M``<```!WXP$`"@```'_C`0`,````BN,!``X```"7XP$`6@```*;C`0`8````
M`>0!`"P````:Y`$`%0```$?D`0`'````7>0!``@```!EY`$`$@```&[D`0`K
M````@>0!`"0```"MY`$`%````-+D`0`3````Y^0!`"$```#[Y`$`&````!WE
M`0`6````-N4!`"0```!-Y0$`*````'+E`0`5````F^4!`%\```"QY0$`(0``
M`!'F`0`=````,^8!`"T```!1Y@$`(P```'_F`0`=````H^8!`"0```#!Y@$`
M(````.;F`0`B````!^<!`!T````JYP$`"@```$CG`0`4````4^<!``D```!H
MYP$`"````'+G`0`3````>^<!``\```"/YP$`*P```)_G`0`5````R^<!``@`
M``#AYP$`8````.KG`0`_````2^@!`%````"+Z`$`<````-SH`0`*````3>D!
M`"4```!8Z0$`+P```'[I`0`)````KND!``<```"XZ0$`#0```,#I`0`^````
MSND!``<````-Z@$`20```!7J`0`M````7^H!`"<```"-Z@$`#@```+7J`0`W
M````Q.H!`!T```#\Z@$`00```!KK`0`V````7.L!`#\```"3ZP$`-0```-/K
M`0`4````">P!``H````>[`$`$P```"GL`0`6````/>P!`!@```!4[`$`"```
M`&WL`0`Q````=NP!``H```"H[`$`"@```+/L`0`F````ONP!``H```#E[`$`
M%P```/#L`0`6````".T!``<````?[0$`$0```"?M`0`1````.>T!``H```!+
M[0$`%@```%;M`0`$````;>T!``4```!R[0$`!@```'CM`0`/````?^T!`!(`
M``"/[0$`$````*+M`0`=````L^T!``T```#1[0$`!P```-_M`0`0````Y^T!
M`"````#X[0$`$@```!GN`0`-````+.X!`!H````Z[@$`)@```%7N`0`.````
M?.X!`!\```"+[@$`+P```*ON`0`)````V^X!``L```#E[@$`&````/'N`0`0
M````"N\!`!8````;[P$`&0```#+O`0`.````3.\!`!````!;[P$`#0```&SO
M`0`)````>N\!`"T```"$[P$`!@```++O`0`)````N>\!``T```##[P$`$P``
M`-'O`0`&````Y>\!`!P```#L[P$`&`````GP`0`/````(O`!``@````R\`$`
M'@```#OP`0`;````6O`!``P```!V\`$``@```(/P`0`'````AO`!``@```".
M\`$`;@```)?P`0`0````!O$!``<````7\0$`)P```!_Q`0!&````1_$!`!P`
M``".\0$`)P```*OQ`0!$````T_$!`#$````8\@$`0````$KR`0`<````B_(!
M`!8```"H\@$`$@```+_R`0`&````TO(!``T```#9\@$`"@```.?R`0`)````
M\O(!``T```#\\@$`$0````KS`0`/````'/,!``H````L\P$`#````#?S`0`0
M````1/,!``<```!5\P$`"````%WS`0`'````9O,!`!0```!N\P$`%````(/S
M`0`/````F/,!``4```"H\P$`)0```*[S`0`5````U/,!``H```#J\P$`%```
M`/7S`0`+````"O0!`!0````6]`$`"P```"OT`0`&````-_0!`!8````^]`$`
M%@```%7T`0`'````;/0!``<```!T]`$`&0```'ST`0`(````EO0!``4```"?
M]`$`!P```*7T`0`2````K?0!`!L```#`]`$`"P```-ST`0`-````Z/0!`"T`
M``#V]`$`(0```"3U`0`8````1O4!``4```!?]0$`#````&7U`0`4````<O4!
M``T```"']0$``@```)7U`0`3````F/4!`!(```"L]0$`'P```+_U`0!`````
MW_4!`",````@]@$`-````$3V`0`Q````>?8!`#0```"K]@$`(@```.#V`0!B
M`````_<!`!8```!F]P$`;@```'WW`0`[````[/<!`%8````H^`$`<0```'_X
M`0`M````\?@!`#P````?^0$`*P```%SY`0`P````B/D!`#````"Y^0$`'```
M`.KY`0`Z````!_H!`+\!``!"^@$`*P````+\`0`?````+OP!`!8```!._`$`
M5@```&7\`0",````O/P!`#,```!)_0$`0````'W]`0!:````OOT!`%`````9
M_@$`(@```&K^`0`5````C?X!`!T```"C_@$`'0```,'^`0`J````W_X!`!P`
M```*_P$`)0```"?_`0`C````3?\!`!8```!Q_P$`-P```(C_`0`J````P/\!
M`"@```#K_P$`&@```!0``@`P````+P`"`&(```!@``(`+0```,,``@`T````
M\0`"`$4````F`0(`,@```&P!`@`K````GP$"`$<```#+`0(`90```!,"`@!:
M````>0("`#$```#4`@(`+@````8#`@`L````-0,"`%D```!B`P(`E0```+P#
M`@!L````4@0"`%P```"_!`(`6@```!P%`@`R````=P4"`"4```"J!0(`)0``
M`-`%`@`K````]@4"`&X````B!@(`:P```)$&`@#`````_08"`!D```"^!P(`
M)P```-@'`@`^``````@"`"T````_"`(`40```&T(`@`G````OP@"`%P```#G
M"`(`'@```$0)`@`*````8PD"`-X```!N"0(`.P```$T*`@`I````B0H"`$(`
M``"S"@(`/0```/8*`@`E````-`L"`"````!:"P(`/P```'L+`@`(````NPL"
M``@```#$"P(`"0```,T+`@`3````UPL"`!````#K"P(`$@```/P+`@`+````
M#PP"``8````;#`(`#@```"(,`@`$````,0P"`%P````V#`(`!````),,`@`1
M````F`P"`!(```"J#`(`"````+T,`@`&````Q@P"``X```#-#`(`!````-P,
M`@`6````X0P"``H```#X#`(`"0````,-`@`1````#0T"`!,````?#0(``@``
M`#,-`@`4````-@T"`!0```!+#0(`$@```&`-`@`.````<PT"`!4```""#0(`
M!@```)@-`@`6````GPT"``T```"V#0(``P```,0-`@`T````R`T"``0```#]
M#0(`$P````(.`@`'````%@X"`"0````>#@(`4````$,.`@`Y````E`X"`#H`
M``#.#@(`'P````D/`@`G````*0\"`"(```!1#P(`)@```'0/`@`H````FP\"
M`",```#$#P(`)0```.@/`@`L````#A`"`"<````[$`(`.P```&,0`@`B````
MGQ`"`#@```#"$`(`-````/L0`@`E````,!$"`"D```!6$0(`+````(`1`@`G
M````K1$"`"P```#5$0(`+0````(2`@`U````,!("`"$```!F$@(`)0```(@2
M`@`J````KA("`#(```#9$@(`)0````P3`@`L````,A,"`!L```!?$P(`)0``
M`'L3`@!"````H1,"`"8```#D$P(`*@````L4`@`M````-A0"`"X```!D%`(`
M)@```),4`@`D````NA0"`"X```#?%`(`*P````X5`@`X````.A4"`!T```!S
M%0(`"@```)$5`@`3````G!4"`!D```"P%0(`+````,H5`@`C````]Q4"``T`
M```;%@(`#P```"D6`@`6````.18"``L```!0%@(`&0```%P6`@`J````=A8"
M``@```"A%@(`#````*H6`@`A````MQ8"`#(```#9%@(`&`````P7`@`K````
M)1<"`"L```!1%P(`)````'T7`@`(````HA<"`.8```"K%P(`$0```)(8`@`6
M````I!@"``P```"[&`(`"0```,@8`@`-````TA@"`!4```#@&`(`$0```/88
M`@`I````"!D"`"(````R&0(`!@```%49`@!%````7!D"`!P```"B&0(`'0``
M`+\9`@`=````W1D"``L```#[&0(`$P````<:`@`)````&QH"`%(````E&@(`
M*@```'@:`@`=````HQH"`!0```#!&@(`%P```-8:`@`H````[AH"`!@````7
M&P(`$@```#`;`@`D````0QL"`!,```!H&P(`%````'P;`@`,````D1L"`!@`
M``">&P(`&````+<;`@`7````T!L"``@```#H&P(`+````/$;`@`)````'AP"
M`"D````H'`(`*````%(<`@`'````>QP"`!L```"#'`(`!P```)\<`@`(````
MIQP"``D```"P'`(`/````+H<`@`&````]QP"`!,```#^'`(`%````!(=`@`.
M````)QT"``D````V'0(`"@```$`=`@`@````2QT"`!,```!L'0(`#0```(`=
M`@`6````CAT"`!(```"E'0(`&````+@=`@`8````T1T"``P```#J'0(`#@``
M`/<=`@`8````!AX"``0````?'@(`+P```"0>`@`/````5!X"``4```!D'@(`
M!P```&H>`@`"````<AX"`!$```!U'@(`(P```(<>`@`+````JQX"``,```"W
M'@(`!@```+L>`@`,````PAX"``P```#/'@(`$0```-P>`@`0````[AX"`!8`
M``#_'@(`%P```!8?`@`%````+A\"`"\````T'P(`'P```&0?`@`>````A!\"
M``D```"C'P(`*0```*T?`@`'````UQ\"`!<```#?'P(`/@```/<?`@`1````
M-B`"`!(```!((`(`"````%L@`@`$````9"`"``4```!I(`(`#0```&\@`@`:
M````?2`"``8```"8(`(`!P```)\@`@`)````IR`"`!$```"Q(`(`"````,,@
M`@`2````S"`"`!(```#?(`(`,````/(@`@`4````(R$"`!D````X(0(`)```
M`%(A`@`B````=R$"`"4```":(0(`$````,`A`@`"````T2$"``0```#4(0(`
M"P```-DA`@`*````Y2$"``4```#P(0(``P```/8A`@`-````^B$"`$<````(
M(@(`%0```%`B`@`R````9B("`#D```"9(@(`4@```-,B`@`/````)B,"`'8`
M```V(P(`(@```*TC`@!.````T","`"\````?)`(`-@```$\D`@`]````AB0"
M`"D```#$)`(`)P```.XD`@`P````%B4"`#0```!')0(`+0```'PE`@`I````
MJB4"`"P```#4)0(`+@````$F`@`Q````,"8"`"8```!B)@(`%````(DF`@`0
M````GB8"`'L```"O)@(`"@```"LG`@!X````-B<"`'H```"O)P(`>0```"HH
M`@`P````I"@"`&$```#5*`(`%````#<I`@`2````3"D"``T```!?*0(`@P``
M`&TI`@`F````\2D"`#D````8*@(`(@```%(J`@`@````=2H"`&L```"6*@(`
M&P````(K`@`*````'BL"``4````I*P(`!@```"\K`@`(````-BL"``4````_
M*P(`%P```$4K`@`9````72L"`!<```!W*P(`(@```(\K`@`0````LBL"``X`
M``##*P(`"````-(K`@`'````VRL"``X```#C*P(`!P```/(K`@`&````^BL"
M`!<````!+`(`!P```!DL`@`%````(2P"`!(````G+`(`!P```#HL`@`+````
M0BP"`!,```!.+`(`#0```&(L`@`7````<"P"``T```"(+`(`"0```)8L`@`0
M````H"P"``H```"Q+`(`!0```+PL`@`+````PBP"``4```#.+`(`!@```-0L
M`@`*````VRP"``@```#F+`(`#````.\L`@`3````_"P"``<````0+0(``@``
M`!@M`@`"````&RT"``@````>+0(`"````"<M`@`'````,"T"`"P````X+0(`
M`@```&4M`@`$````:"T"``X```!M+0(`#@```'PM`@`0````BRT"`!4```"<
M+0(`$````+(M`@`+````PRT"``8```#/+0(`!P```-8M`@`2````WBT"`!(`
M``#Q+0(``@````0N`@`'````!RX"`!`````/+@(`*@```"`N`@`V````2RX"
M``D```""+@(`"````(PN`@`+````E2X"`!P```"A+@(`!0```+XN`@`&````
MQ"X"``L```#++@(``0```,X%``#7`@``X04``*<"```'!```:@8```````!3
M!@``Y`4``#($``#&````;@,``+D&````````NP$``'L%````````,P,``#H&
M``!M`0``O`4```````"&`0``"0(``.0#```3!@```````#8"``#L````````
M`&(%``"!!0``,P8```````!9`@``P`0``'0#`````0``Y00```D````'````
MMP4```````#?!@````````````#,`0``"````&@````-`@```````/X$``#I
M````\P4``/$%````````T0$``!`&````````````````````````;`$``-@`
M````````D@8``!,`````````1@(``)\!````````X`(``-,````J!0``;@``
M``````#5!0``>`(``+\$```?`@``PP0``($"``#_`0```````,,&``!K`@``
M70```)`%````````40,``"0!``"D````2P4``)D!``!C`0``)P,````````L
M`P``30(``*(&``"9````T`4``-@#````````)P$``,X```#!!@```````,<&
M``!\````C0````````"E!`````````````!S`0``?08``.D!``!#`P``&0(`
M``````!+!```Y@(``#,!``#`!@``+`````````#4!@``H04````````?`0``
M``````P```!'````]P,``$X"``#[!````````"`!``"8!@``4@$``#H"```Y
M`P``*`,``-X!``"6`P```````)P%``!+`0````````(!``"/`0``X`$``(H$
M``#+`P```````+P!```:!```?04``/4#``">!@```````%T#````````[04`
M`&\%``#R`0``"@4````````>`@``"0$``/X#``#)`0``U`0``$8!``#A`@``
M``````````#>`P``>````%L$``#*````20$`````````````TP8``,X#````
M````J0,``"@%``"S``````````T%``"*!0``>0```&\!```>`0``&04`````
M``"Q`0``3`8``````````````````'`#`````````````&\"``""!```%`8`
M`+T%``"?!0```````.X```!@!P``X@0``(@$``!?`P``[P8```````"$!0``
M<@<``$\'```Z!P``QP,``,L"`````````````,0#``#S`0```````)`#``#?
M`````````/X%````````@@$``!8%``"B!0``Z08`````````````(`(`````
M``"_`P``TP$``.`&``!:````]P(```````#I`@```````'X!```\!0``M`4`
M`)L"```U!P```````/P$``"Q````H@```-H"``!O!P``$P4``-<`````````
MYP8``$H"``#K`@``=@0``+\&``#_`@``4@0``!8'``!!````8````','``!Z
M!```I0```!$"``#2````+@,``*\&```!`P```P0`````````````2P```-T#
M`````````````(H#```=!0``\@0``&,`````````%0,``!(%```L!0``M0,`
M`-8```"Q`P``/P<``(0&````````Q0(```````#S`@```````.D#```Y`@``
MJP0```````!@`P``,04``!$&``#Q`P``A0```,\$``""`@``RP```(4!``!5
M!0``7`$``.<$```/!P``"P$```````!P`0``M04``!X$``#A`P```````&(!
M``"+!@`````````````<`@``[08```````!Q``````````````#-!```O@4`
M``````#=`0``2`<``,L$```P!0``90$``(0````3`@``G`$````````3!```
M`````,$#``#^!@``$0<```````!0!0``,0$``*P!``#"!```C04``*4"```E
M````T`0`````````````[`$```````!8!0``_P0``)`&``#G`0``<@0``.L&
M``!+`@````````T$``"`!0``=`(``(\#``")`0``^0```$D%``!6`@``F0(`
M````````````D@`````````H!P``5@0``*0"`````````````%\"``!]````
M!`4`````````````"P````````"@`P``"08``"L'````````>`0``!L&``"L
M!@```@```+\"````````9@```)L%``#T!0``X@8`````````````N00`````
M``"F`@``]04``(<$```````````````````I!P```````"T&``"5`0``N`0`
M`/$!``"[!0``&@8```````!I`0``V@4```````#<````+P0``/4&````````
M-0```+4```#]`P``I@$```````!J!P``U08```````!%`0``(P```#@"````
M````\P```#\!````````C08``(8"``"#!```3@8``$$!``"1`P``F`(`````
M````````KP4``````````````````-P#``"1!@``[@(```$!``#O`0``*`0`
M``````!_`0``'P0``$T#``!W`0``-`,``"4%``"*````#08``$<'``#[`P``
MI08`````````````?P```.0$````````,@```-X&````````3@$``$H&````
M`````````"<$``#J````Z@4``)\$``"L``````````X%`````````````,$%
M````````B`4``-8#``#.!```G0,```````!%!0``J0````````#T````I`$`
M`!D#````````,@(``.`#`````````````#H$```U`@``K`4````````]`0``
M5`0``/D"``!O````#P,``(,%``!G!````````&T%``"H!0``#@<`````````
M````PP,```````!/!0``]@```#P#``"'````^P```%T!```[`@``A0(``+D"
M``"P`0``T08``#L$``#*`@```````,0!``!9`P```04``/`!``#``0``````
M``````#T!@```````"P"``!/`@``60$``-0!``".`P``9P,``#@!````````
M904``*D"``!]`0``+0,`````````````0@0``+D```#P!@``4@```%\!``!V
M!0``1`(``!(!````````)`4``,4```"S!```BP(```````"]!@``;`````D%
M````````,P<```````!>`@``8P8``+L&``!I`P``6`8``&4&````````T`(`
M``@"``#F`0```````'X````U`0``V0,``"H$````````*00``"`$````````
M1@`````````Z!0``.P,``.4!````````I@8``$H#``!M``````````````"N
M`````````%L'``!8!P``+00``"`#``"C!@```````)@```!>`0``!0(``+<`
M``"Y`P``/@4``/0"``#S!```M08``)(%````````O`,```````#P````W00`
M`*T&```Y!```50$``#(%``".`@``_@`````````+!@``_04```````"2`0``
MI`,``&4$```D````C@```'`"``!-````BP4``$T'``#6!0``6`,```````#A
M`0``L`4``!\&```P`@``F`0```````!0`0```````%$!```-`0``````````
M``"N`P``````````````````[`,``!@&```7`@``IP8``%`#``"1!0``````
M`$8%`````````````,T!```*`0````````````"0`@``M`(``-4#``#2`@``
M`````&\&``#M`````````````````````````*\````L!@``3@0```````"%
M!0```````/\````\!@``*P0``"X!````````U0```),$``"D!0``J@8``.4%
M``!Z`@``(@(``#0```#-!@``108```<!````````?@8``$D$``#O````````
M`#@&``!R!0``>@,``&D'````````!0,``)H%``#8!0``'`4``)X!```A`P``
M`````'0$````````Y0```&0"```Q`@``````````````````C`(``!8```!D
M`P``(P4``(L`````````C`0``)L```"T````YP```)("``!Y!@``5`,``,T%
M``!L!@``]@4```\"````````````````````````7@```-(!```E`P``4P``
M`)<"``"7````7`````````!\!@```````&4"``"3!@``C@$``'<%``#1!0``
M`````,("``!`!P``,0``````````````I@4``!4```!#`@``>@````````!5
M!P``A00``($```"``0```````%4`````````G@,``"8$````````*0$`````
M`````````````-<!``!@`@``/`(``!`#``".!@``O````$T!``!I`@``7P4`
M`&0%``!G!@``+04``)8!````````K`,``!<#``"M!`````````8!```C!@``
MRP4``!L"```@`````````$,%````````6P,``````````````````+`&``!7
M`P``[`(```@'``",````$`4``(4&````````1`0``,`#````````M@(`````
M``#,!```HP0``$X``````````````","``#\!@``6P````H&``!"!0``````
M`.,$````````Q`8``*H!````````F0,``#P'``````````````````!5`P``
MXP`````````,!P``L00``$@$``#N`P``#P$``)4&``"C`P```````/P!``!"
M!P``A`0``(L!````````!@8``!4&```V!0```````(@&``#.!@``F@```$,'
M```7!@```````",'``!)`````````/<%``"Q!@``9@,```````#/!0``M@8`
M``X$```;````,@<``!X%````````[@0```<'````````A@,```````"T!```
M``````````#X`@``OP4`````````````4P<``!4"``"7!0``3`(``,(&```I
M!@``T00``%D&`````````````(8$``"5`P``]P````````!X`0``I@0``,4$
M````````%`(``(H"```V`P``#`8``.L```!!!@```````.0"````````W@``
M`($#``!S`P``0`,``-L&```[!@``+0```&L$````````T`8``'L$```W!```
M``0``#H#``"]!```.@$```````!^!```6`$``%<'``#0`````````(X%``":
M`0``^@8``&4'````````)08``````````````````,<$``"'`P``404`````
M````````8@(``"<"``#Z!```D00````````B````H0```-H$``!K````-0,`
M`+<#```H````(@,``&`&``"(`P``208```0!``!1````H00```````!!`P``
MR````#@#```A!```B`(``.D%``"D!```````````````````=P(``%T%```$
M!`````````8'```J`P``O@(``&T$``!D````````````````````^`0``#\$
M````````[@8``"4$````````:@(```````"9!0``&`$```````#9!0``````
M`*`!```0!P``D````/L!``#M`0``%P<``,8"``"-!```P@4``#8'```J`@``
M0`4```,'``#P`@``DP4``/T$````````H@(``!T#``#?`0``/@0``"T'``!Q
M!```0`0````````6`@``G`(```T'``#U`@``7`8``(0"``````````````,`
M``#4`P``<P```````````````P,``&(&``#/`0``0`8````````^`0``````
M`&0$``#E`@``Y0,````````B!P``'`,``$<#``!F!@```````'<#````````
MVP4``%\$``#2`P``````````````````6P(``#8!``#C`@``/@8``+(```#6
M`@``U0$````````X````5`4```````";`P``EP0``,P`````````6@<``!$!
M````!@``$`(```````!+`P``W0```"<`````````MP(````````-`P``L@(`
M`(@```"F````?`$``.\#````````=@```'\$``#'`0``90,``"$&```F`@``
ML`(``-<$````````B08```````!S!```G00```````"Q`@``R08``!`!````
M````Q04``,8&```U!@``0`(``&X"````````HP4``#,%```Y!P``P0```'X%
M```J`0``004``!H#````````?@,````````+`@``O0(`````````````````
M`````````````````&<"``"K`P``8`$``*D$```X!0``/P````````"@!```
M.`<```<"``"``P``````````````````*P$```````#/!@```````$0'``#-
M`@``.@``````````````T@8``$(```!.`P````````````!V!@``M@4``&8"
M``#<!@``B@$```````#9!```D`0``'8!``!/!@``LP$`````````````TP(`
M``````"``@``B0````````!U`@``O0```#,```"5!```8P0``.8#````````
M/0```/@!````````B`$``$4#``#[`@``1````)L!`````````````+@```#2
M!0``-`4``!D'``"&!@``%`,``,@#``"X`P```````%`'``"<````7@,``#8$
M``"_`0```````-@"`````````````-<#``":`@```````-8!````````````
M`$P'```(!```*P(``(P%``"<`P``;08``-\$`````````````/0!````````
M`````,4&``#7!@``EP8``"X```!6`0``[P4``(P#``#,`@```````+0&```P
M!@``Z@8``!@'````````O0$``*L%````````R@8``/T```!'!0``@00``"L#
M````````:P,``'D!```E!P`````````````!!```&P,````````^````?P,`
M`/`$``#D`0```P4``+(!``"`!```]P$``.L!``#V`0```````!D!``"S`P``
M6P4``/\%``#.`0```````!0!``"-`P``[@$``*(#```4````J04``!X````B
M!@``$@0``!\````0!````````&<'``"#`0```````.$```#B````800``&$%
M``"#`P``W`(`````````````H`(``"L%```@!0``^@4``%<!``"=`@``M@``
M`!T!```!!@```````!P&``#<`0``A`$``"0$``"B!```J`,```<%``#J!```
MXP,``,(#``"S!@``]0$```````!R!@``V0``````````````6`0```````!P
M!P``7@0``,P&``!W!@``*0(```````#-`````````&$"``#)!```6P$``&@"
M```W`@``YP(``"\```"9!@``NP0``,L&``!``0``-`$``,@"````````&`4`
M``````"3`0``1P8```(#```_`P```````&D$``#;!```VP(`````````````
MK@0``)T!```1`````````,$$``!4!P````````````"=!0```0(``%$'``#M
M!```"@<```````#X`P``O@,``*<#````!P``5@,``"X"```X!```````````
M``"'`0``2`8``*\"```P!P``B04`````````````&`0```````!B````/@(`
M`!P$``!L!```^`8```````!U`P``T`,``$T&``#=`@```````(D#````````
M9P4``%`&``"+!```X`4``'$%``#Z`P``T0,``-4"```5!P```````)@%```V
M````H`4```````#R```````````````L!P``:@,``'P"``!@!0````````@&
M``!*!````````!@"`````````````#0'```#`0``=P0``/$```!S`@``T0(`
M``````#$````L04``'X"``"U!```JP(``#$$```[!0``ZP0``/`#````!0``
MH`````````"L!```"@0``'P%```)!````````&L'```R!@``6@,``,D"````
M````W@0```````!Y!```)`8```````#W!```6@(``)0"``!&!@``B@8``!D$
M````````10```"@&``!"!@``708``%@`````````K0$``$@!````````````
M`````````````````/("```F`0``<0(```D#`````````````/@%````````
MN@````````!H!`````````````"8`P````````````"T`0``8P4``$,```!B
M`P``!`(``#P!``!A!P``````````````````%`4``!H````*`P```````(D$
M```N!0```````+,%```A````J@(``/@``````````````'L#```$````+P(`
M`!D````7!0```````$H%```A`0``5P(``%P$``!R`@``4@4`````````````
M9`<``!H!``#H`````````#,$``![!@``H0$``%D$``#S!@``DP```.,%```%
M!P```````/P#``#H`0``Z`(``#<```"L`@``-P4```````#J`P```````!T$
M``!<!P```````%P#```>!P``<`8```````"/!0``R@0``&$```!A`P``VP,`
M`(,"``#"````NP(````````2`P``H`8``(8```!/!```+P4``(P&```8````
M'0(``,````#K`P``&P4``!8!``!(`@``U````-,%````````?`0`````````
M````^00`````````````\@4`````````````6`(``#D%````````QP(`````
M``!\`P````````P$```,!0``)P8``!('```F`P```````*<$``#\!0``G@``
M`%T'``"J!`````````````!1`@``I04``!\#`````````````%4&````````
M7@4`````````````[`0``,`%```V!@``_````!,'```````````````"```U
M!```+P8``$$'``"O!```CP````````"`!@``N@,````````G!0``S`,`````
M``!<!0``>0(```\&`````````````+H"``"9!```L````),#``"E`P``60<`
M`+0#```"!0``V0$``&,"``"4`P``\00``*<```!Z!@``/08``$P%``!)`P``
MV`$``"($`````````````)T```"D!@``;`<``/(#``!/`P`````````````(
M`P``+@0``*X!````````O@8``'0&```L!```#`,``,8%``"C````@P8``,4!
M``"'!0``@@,``"@!``#\`@``0P8``#<'`````````````*L````R`P``7@8`
M`%0!``!4````FP8``-,$``#(`0``/P(``+X````=!P``'@,```````":!```
ML@8``.(#`````````````$,!````````=P`````````N!P```````((```!_
M`@```````",#``!D`0``;P,``$T$````````+0(```````#1````V@``````
M````````:`8``-\%```F!@``:`,``'\&``!F`0``'`````````"=!@``````
M``````#A!@``RP$``&D````^`P```````-`!``#F!```>0,```````#F````
MMP$````````Y````>P```/X!``#W!@``J`0``#T#``#@!````````)P$```2
M````M@$``%H!``!N!````````$@#``#@````%04``/D#``#Q`@``KP$```($
M``"\!```"0<```````!J````&`,```````!2!P``:08``)($``!S!0``````
M``````!B!P``$````,0%```Q!P````````````#:`0``MP8```0#```/!0``
M>@4``+@!````````!0$``````````````````+@"```Y!@``NP,``$H'```(
M!0``10<```X"```F````9P$``(0#````````4P(```````!N`0``-P$``)H#
M````````808``*@!``````````````````!?!P```````%`"````````H0,`
M``````#_`P``O`(``/0#```F!0``(P0``%,%``!]`@`````````````P````
M(@$``/L&``"R!```:@4``.\"````````U@8``.("``"^`0``408``&L!``#Z
M````2`4``%0"``!P````=08``#T"``!M!P``DP(``!("```#!@``````````
M``"?````#@8``/4````Y`0``UP4````````J````!`8``!X&````````[0(`
M`'(!``#*`0``>04``.@%``"R`P``5@<`````````````9@<``/4$``"K`0``
MCP0``*T#``!T`````````%("``#4`@``IP$``/D!````````X@4``$H````]
M!0``500``*,!``#H!@``7@<```````#-`P``60```+L```";!```50(`````
M``!7`````````($&```W!@``GP8``````````````````"\#````````P@$`
M`(T"``````````````````!+!@``N@8``)\"```_!0````````````!J!```
M6@4```````#L!0``L`,`````````````,P(``-P$```]!```20(```````"X
M!@```````/8&``#$!```XP$``$P#``"Y!0```````'(```!2`P``(04`````
M``"4!```VP$``````````````````+H%``!F!0``4P$``*X%``!0!```700`
M`-T%``!G````-`0```4&`````````````)X$``!#!```:P4```````!_!0``
M"P,``-X%````````A0,``+@%``#V`P``@@8``"D%````````X@$`````````
M````````````````````Q@0``,<%``"4````:`4```````"-`0``*@8``!0$
M``"6!0``8@0``,4#```H`@``5@4```````#T!```E0(``!H%``"O`P``ZP4`
M``````"7`0``D0```)(#``#P!0````````@!``!A`0``+`$`````````````
M_08``%````#*!0``00(`````````````!@(`````````````20<````````7
M````5P0``(L#```&`P```````%$$```\!```2P<``(\&``!&!P```````!P'
M```%````K0(``%H&``!9!0``8P,```<#`````````````"0"``!J`0``MP0`
M`#L'``!Q`P``K04```````!H!P``H@$```````!V`P```````(``````````
M1`$``'4```#&`0```````)0%``!6!@```````!<$``!%`@``6@0``-H#``#5
M!````````,@&```:!P``(@4```("``"4`0``)0$``.8&``!!!```L@4`````
M````````4P0``)4%``#9`@````````````#)!0``_@(``/8"``#<!0``HP(`
M```#``!,`0``LP(``*X"``#V!```(0<``)4```!U`0``;P0``,8#````````
MD`$``&X&``#M`P```````!,!``![`0``'08``/T"``#/`@``G`8``(P!````
M````8P<``&`$``#$`@``V@8```\````R`0``>@$``"H'````````J08``'`%
M``!6````_0$```````#Q!@``O@0``,\````T`@``D0$```H"````````````
M`%(&```#`@```````'4$````````[`8``+P&````````K0```$<!````````
MZ@$``,X"````````1`4````````1`P``*P````````#;````&08``",!```?
M!P``1`8``.X%````````E@0``!8$``!R`P``+P$```8%````````)0(``(X$
M````````!00``*X&``"G!0``U@0``$``````````Z`0``/L%``#!`0``+@8`
M`(\"````````,0,``!4$````````<`0``,@$````````T@0``.4&````````
M"P0``-\#``!&!```5P4``!8#````````#@,``````````````````&P#```P
M!```&@(```$'````````PP(```````!&`P``:`$``,\#``"F`P``N0$`````
M``!T`0``^04``/H!``#!`@``<0$``&X%````````3@4``"D`````````/0<`
M``````!'`@``$04``,,!``#Z`@```````($!``!S!@```````!<!``"'!@``
M&P$``,`"```T!@``/````%,#``"J`P```````.D$````````L`0``"<'````
M````@P```.\$``#D````1P0``&P%````````0@(```L%```*`````````/,#
M````````F@8``!0'``#)`````````#L```!"`P```````"$"```5`0``3P$`
M`%<&``!X!0``M0$``/D&```_!@``?00``)X%`````````````-X"````````
M``````````#R!@``Y@4```\$```%!0``YP4```L'``!"`0``=04``)8"```2
M!@``=@(```````#_!@``,08``*L&````````<0<``)8``````````````"L&
M```'!@``(`<```````#4!0``)`<```````"'`@``*0,``$P`````````>`,`
M`+8$``!/````6P8``!\%````````100````````<`0``1`,``*@&``#)`P``
M<08```````````````````````#8!@``&P0``%\&``"V`P``.P$``(D"```M
M`0``J@```%P"```-````XP8``&0&``!E````,`,``+H$````````Z`,```0'
M``#A!```R`4``*4!``"H`@``2````"\'``#8!```;0(```````"]`P``9@0`
M``````!N!P``:04``*H%``#9!@``:P8```````"I`0``R@,```8```"A`@``
MN@$``.<#``"1`@``H08``+\```!=`@``TP,``!T````"!@``3`0``,,````&
M!```F`$``'@&``!]`P``WP(```P"```.`0```````.H"````````$00`````
M``""!0``A@4```````!*`0``(`8````````3`P``E`8```('``">`@``#@``
M`"8'``!4!@```````!8&``!-!0```````'L"``!L`@``/@<``-T&``"6!@``
MPP4``'0%```U!0``QP```.0&``````````````````!.!P``GP,``"0#````
M````,`$``&T#```,`0``-P,``%\```"U`@```````)<#`````````````,P%
M``"H`````````!L'````("`M32P@+2UM97-S86=E/4U%4U-!1T4@(%5S92!T
M:&ES(&-O;6UI="!M97-S86=E(&EN<W1E860@;V8@=&AE(&1E9F%U;'0@;VYE
M<RX`("`M82P@+2UA9&0]1DE,12`@("`@("`@061D('1H:7,@4$\@9FEL92!T
M;R!T:&4@8V]M<&5N9&EU;2X@57-E9G5L('1O"B`@("`@("`@("`@("`@("`@
M("`@("`@(&EN8VQU9&4@82!C;VUP96YD:75M(&9R;VT@82!D:69F97)E;G0@
M8G)A;F-H('1O"B`@("`@("`@("`@("`@("`@("`@("`@('1H92!G96YE<F%T
M960@8V]M<&5N9&EU;2X`("`M8BP@+2UB87-E/2]0051(("!&=6QL('!A=&@@
M=&\@=&AE("A(;W)D92D@8F%S92!D:7)E8W1O<GD@=&AA="!S:&]U;&0@8F4*
M("`@("`@("`@("`@("`@("`@("!U<V5D+@`@("UC+"`M+6-O;7!E;F1I=6T]
M1DE,12`@365R9V4@;F5W('1R86YS;&%T:6]N<R!T;R!T:&ES(&-O;7!E;F1I
M=6T@9FEL90H@("`@("`@("`@("`@("`@("`@("`@("`@:6YS=&5A9"!O9B!T
M:&4@9&5F875L="!O;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE"B`@("`@("`@
M("`@("`@("`@("`@("`@("!H;W)D92]P;R!D:7)E8W1O<GDN`"`@+6,L("TM
M8V]M<&5N9&EU;3U&24Q%("!5<V4@=&AI<R!C;VUP96YD:75M(&9I;&4@:6YS
M=&5A9"!O9B!T:&4@9&5F875L=`H@("`@("`@("`@("`@("`@("`@("`@("`@
M;VYE("AC;VUP96YD:75M+G!O(&EN('1H92!H;W)D92]P;R!D:7)E8W1O<GDI
M+@`@("UD+"`M+61E8G5G("`@("`@(%-H;W<@97)R;W(@;65S<V%G97,@9G)O
M;2!T:&4@97AE8W5T960@8FEN87)I97,N`"`@+60L("TM9&ER96-T;W)Y/41)
M4B`@($-R96%T92!C;VUP96YD:75M(&EN('1H:7,@9&ER96-T;W)Y+@`@("UH
M+"`M+6AE;'`@("`@("`@(%-H;W<@=&AI<R!H96QP(&UE<W-A9V4N`"`@+6PL
M("TM;&]C86QE/6QL7T-#("`@("!5<V4@;VYL>2!T:&ES(&QO8V%L92X`("`M
M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S92!T:&ES(&QO8V%L92X`("`M;"P@
M+2UL;V-A;&4];&Q?0T,@("`@57-E('1H:7,@;&]C86QE+@`@("UM+"`M+6UO
M9'5L93U-3T153$4@("`@0G5I;&0@34\@9FEL97,@;VYL>2!F;W(@=&AI<R`H
M2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($-L96%N
M=7`@4$\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M
M;2P@+2UM;V1U;&4]34]$54Q%("`@($-O;6UI="!T<F%N<VQA=&EO;G,@;VYL
M>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$
M54Q%("`@($-R96%T92!A(%!/(&9I;&4@;VYL>2!F;W(@=&AI<R`H2&]R9&4I
M(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($UE<F=E(%!/(&9I
M;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D
M=6QE/4U/1%5,12`@("!5<&1A=&4@:&5L<"!F:6QE<R!O;FQY(&9O<B!T:&ES
M("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO9'5L93U-3T153$4@("`@57!D
M871E(&]N;'D@=&AI<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]
M34]$54Q%("!'96YE<F%T92!03U0@9FEL92!O;FQY(&9O<B!T:&ES("A(;W)D
M92D@;6]D=6QE+@`@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@1&]N)W0@;65R
M9V4@;F5W('1R86YS;&%T:6]N<R!T;R!T:&4@8V]M<&5N9&EU;2X`("`M;BP@
M+2UN;RUC;VUP96YD:75M("`@($1O;B=T('5S92!A(&-O;7!E;F1I=6TN`"`@
M+7,L("TM<W1A=&ES=&EC<R`@("`@("!3879E('1R86YS;&%T:6]N('-T871I
M<W1I8W,@:6X@82!L;V-A;"!F:6QE+@`@("UT+"`M+71E<W0@("`@("`@(%-H
M;W<@=&AE(&5X96-U=&5D(&-O;6UA;F1S(&)U="!D;VXG="!R=6X@86YY=&AI
M;F<N`"`@8VQE86YU<"`@("`@0VQE86YS('1H92!03R!F:6QE<R!U<"!F<F]M
M('5N=')A;G-L871E9"!A;F0@;V)S;VQE=&4@96YT<FEE<RX`("!C;VUM:70@
M("`@("!#;VUM:70@=')A;G-L871I;VYS('1O('1H92!#5E,@<V5R=F5R+@`@
M(&-O;6UI="UH96QP($-O;6UI="!H96QP(&9I;&5S('1O('1H92!#5E,@<V5R
M=F5R+@`@(&-O;7!E;F1I=6T@(%)E8G5I;&0@=&AE(&-O;7!E;F1I=6T@9FEL
M92X@5V%R;FEN9SH@5&AI<R!O=F5R=W)I=&5S('1H90H@("`@("`@("`@("`@
M(&-U<G)E;G0@8V]M<&5N9&EU;2X`("!E>'1R86-T("`@("!'96YE<F%T92!0
M3R!T96UP;&%T92`H+G!O="D@9FEL97,N`"`@:&5L<"`@("`@("`@4VAO=R!T
M:&ES(&AE;'`@;65S<V%G92X`("!I;FET("`@("`@("!#<F5A=&4@;VYE(&]R
M(&UO<F4@4$\@9FEL97,@9F]R(&$@;F5W(&QO8V%L92X@5V%R;FEN9SH@5&AI
M<PH@("`@("`@("`@("`@(&]V97)W<FET97,@=&AE(&5X:7-T:6YG(%!/(&9I
M;&5S(&]F('1H:7,@;&]C86QE+@`@(&UA:V4@("`@("`@($)U:6QD(&)I;F%R
M>2!-3R!F:6QE<R!F<F]M('1H92!S<&5C:69I960@4$\@9FEL97,N`"`@;6%K
M92UH96QP("`@36%R:R!A;&P@96YT<FEE<R!I;B!T:&4@6$U,(&AE;'`@9FEL
M92!B96EN9R!U<"UT;RUD871E(&%N9`H@("`@("`@("`@("`@('!R97!A<F4@
M=&AE(&9I;&4@9F]R('1H92!N97AT(&5X96-U=&EO;B!O9B!U<&1A=&4M:&5L
M<"X@66]U"B`@("`@("`@("`@("`@<VAO=6QD(&]N;'D@<G5N(&UA:V4M:&5L
M<"!!1E1%4B!U<&1A=&4M:&5L<"!A;F0@<F5V:7-I;F<@=&AE"B`@("`@("`@
M("`@("`@:&5L<"!F:6QE+@`@(&UE<F=E("`@("`@($UE<F=E('1H92!C=7)R
M96YT(%!/(&9I;&4@=VET:"!T:&4@8W5R<F5N="!03R!T96UP;&%T92!F:6QE
M+@`@('5P9&%T92`@("`@(%)U;B!E>'1R86-T(&%N9"!M97)G92!S97%U96YT
M+@`@('5P9&%T92UH96QP($5X=')A8W0@86QL(&YE=R!A;F0@8VAA;F=E9"!E
M;G1R:65S(&9R;VT@=&AE($5N9VQI<V@@6$U,(&AE;'`*("`@("`@("`@("`@
M("!F:6QE(&%N9"!M97)G92!T:&5M('=I=&@@=&AE(&5X:7-T:6YG(&]N97,N
M`"`F(S$U,3L@)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+@`@*"5S(&1A>7,@86=O*0`@
M*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R
M<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``B)7,B(&ES(&YO="!A('9A;&ED(&-H
M;VEC92X`(B5S(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G
M:7-T<GDN`"(E<R(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N`"(E<R(@=V%S
M(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`B)7,B('=A<R!A9&1E9"!T
M;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`B)7,B('=A<R!N;W0@8W)E871E
M9#H@)7,N`"5D("5S(&%N9"`E<P`E9"!B>71E<R!W<FET=&5N+@`E9"!O9B`E
M9"!E;G1R:65S(&UA<FME9"!A<R!U<"UT;RUD871E`"5D+61A>2!F;W)E8V%S
M=``E<R`M($YO=&EC90`E<R!!9&UI;FES=')A=&EO;@`E<R!&:6YG97)P<FEN
M=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T
M:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M96YT
M`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!I<R!N;W0@=W)I
M=&%B;&4N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD
M+@`E<R!N;W0@9F]U;F0N(%)U;B`G=')A;G-L871I;VX@97AT<F%C="<@9FER
M<W0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L
M96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"P@9W5S
M=&EN9R``+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E
M<P`M+2!S96QE8W0@+2T`+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM`#$R
M($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U
M<P`\9V5T=&5X=#X@=&%G(&YO="!C;&]S960@:6X@9FEL92`E<RX*3W!E;FEN
M9R!T86<@9F]U;F0@:6X@;&EN92`E9"X`02!D871A8F%S92!B86-K96YD(&ES
M(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O
M8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y
M<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O
M('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P
M<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T
M92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG
M;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-
M24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y
M<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O
M34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N
M(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+@!!32!#;&]U9',`04T@3&EG:'0@4F%I;@!!
M32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-`$%022!)
M1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED
M9&QE`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C
M97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!087-S=V]R
M9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($-H:6QD($=R
M;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R
M;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`B
M)7,B`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!9&0@82!N97<@
M=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D
M('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T;R!A9&1R
M97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D
M960@(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I
M=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D("(E<R(@=&\@
M=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@;F5W(&9I
M;&5S('1O(')E<&]S:71O<GDZ`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`
M061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M:7-S
M:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%F9VAA
M;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z
M`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!0
M97)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R
M97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR
M96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-
M4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E
M(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@
M=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W87,@<W!E
M8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+@!!;F1O<G)A
M`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R
M8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A
M=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`
M07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`
M07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_
M`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY
M('-U8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU3
M0TE)+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!
M<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R
M92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O
M;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N
M`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN
M`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T
M97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U
M:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A
M8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T
M:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O
M;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?
M:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E
M('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`
M075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@
M9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@
M<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`
M079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`0F%C
M:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R
M9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%L
M=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E;&EN
M90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N
M`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@
M9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!";VQI=FEA
M`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!"
M;W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T=&]M`$)O
M=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I
M=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6EL9&EN9R!-3R!F:6QE<R!F;W(@
M;6]D=6QE("5S+BXN`$)U:6QD:6YG(&QO8V%L92`E<RXN+B``0G5L9V%R:6$`
M0G5L;&5T960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$-2
M3"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`0V%C
M:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%L;0!#86UB
M;V1I80!#86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I
M8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86XG="!C;VYN
M96-T('1O($E-05`@<V5R=F5R.B`E<P!#86YA9&$`0V%N8V5L`$-A;F-E;"!0
M<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T
M(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W
M:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@
M9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X
M:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI
M960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`
M0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P
M92!697)D90!#87!T:6]N`$-A=&5G;W)I97,@86YD($QA8F5L<P!#87EM86X@
M27-L86YD<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I
M;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#
M96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N=')A;"!!9G)I8V%N(%)E
M<'5B;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC
M871E($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A=&4@4&]L
M:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S
M('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@
M>6]U<B!E;6%I;',N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAE8VL@=&AE(&)O
M>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T
M('1H:7,@=&EM92X`0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D("A'
M0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S92!A('!A
M<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA
M>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@
M;&ES=',I`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E
M<R!N;W0@9F]U;F0N`$-L96%N:6YG('5P(%!/(&9I;&5S(&9O<B!M;V1U;&4@
M)7,N+BX`0VQE86YI;F<@=7`@;&]C86QE("5S+BXN(`!#;&5A<@!#;&5A<B!-
M4T]F9FEC92!T86=S`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L
M96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L:6-K('1O($-O;G1I;G5E
M`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U
M9',@16%R;'D`0VQO=61Y`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA
M<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`
M0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I
M=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UA;F0@;W!T
M:6]N<SH`0V]M;6%N9',Z`$-O;6UE;G0`0V]M;6ET=&EN9SH`0V]M;6]N($YA
M;64`0V]M;W)O<P!#;VUP86YY`$-O;7!O<V4@365S<V%G92`H)7,I`$-O;7!U
M=&5R<P!#;VYD:71I;VX`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E
M<F5N8V5S`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O;F9I9W5R
M92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R
M871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE
M8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI
M8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($94
M4"!S97)V97(@9F%I;&5D+@!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N="!T>7!E(&]F(&-O
M;7!R97-S960@9FEL93H@`$-O;G1E;G1S(&]F("(E<R(`0V]N=&EN=64`0V]O
M:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@<V5L96-T:6]N`$-O<'EI;F<@
M)7,@=&\@)7,`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!0
M1U`@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G
M92X`0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO
M="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N
M("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@
M8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R
M("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8V]P>2`E<R!T;R`E<P!#
M;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N
M;W0@8W)E871E(&QO8V%L92!D:7)E8W1O<GD@9F]R(&QO8V%L92`E<SH`0V]U
M;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D96-R>7!T(%,O
M34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD
M(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D
M96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T(&1E
M=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD
M(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F
M971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E
M=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`
M0V]U;&0@;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER
M("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K
M97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N`$-O
M=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]4
M87-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`
M0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O
M<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE
M(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP
M+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A
M9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I
M;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L
M:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI
M=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO
M="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N
M+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD
M(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T
M('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO
M="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L
M9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N
M(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O
M9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W
M('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U
M;&0@;F]T('5N;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N
M("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O
M=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E<P!#;W5L
M9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@
M<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S(B!T:&4@
M9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E<P!#;W5N
M=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK
M`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@
M4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#
M=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#
M=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T
M>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`
M0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y
M<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])
M."U5*0!#>F5C:"!297!U8FQI8P!$1`!$86EL>0!$871A5')E92!"<F]W<V5R
M`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T
M92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN
M9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$
M969A=6QT(%!E<FUI<W-I;VYS`$1E9F%U;'0@<&5R;6ES<VEO;G,`1&5F:6YI
M=&EO;G,`1&5L971E`$1E;&5T92!'<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$
M96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C
M;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI<W-I;VYS(&9O
M<B`G)7,G(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E
M;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L
M=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E('1H:7,@<&5R;6ES
M<VEO;B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E9"!S971U<"!U
M<&=R861E('-C<FEP="`B)7,B+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S
M8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I
M;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`
M1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I
M;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E
M8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`
M1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4
M048I`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$
M:FEB;W5T:0!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@
M;6%I;G1E;F%N8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H
M92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI
M8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O
M=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N
M`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%4E(`16-U861O<@!%9&ET
M`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!0
M97)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO
M;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES
M<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M
M96YT+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S
M(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N
M<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T
M97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A
M;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M
M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y
M('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D
M('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA
M;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5N
M=')I97,Z("5D('1O=&%L+"`E9"!U<"UT;RUD871E+"`E9"!N97<L("5D(&-H
M86YG960L("5D('5N:VYO=VX`17%U871O<FEA;"!'=6EN96$`17)I=')E80!%
M<G)O<@!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R:71I;F<@
M(B5S(BX`17)R;W(Z(`!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`
M179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C
M;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H
M;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>&5C
M=71I;F<Z`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP
M96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T
M:6]N($1A=&4`17AP;VYE;G0`17AT<F%C=&EN9R!F<F]M("5S+BXN(`!&1R!#
M;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG('!R
M969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`
M1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O
M<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@
M=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E
M('1O("(E<R(N`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A
M<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&96)R=6%R>0!&965L<R!,
M:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S
M`$9I96QD(&UA=')I>`!&:6II`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#
M;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E
M;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E
M9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&
M:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X
M:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S
M=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN
M;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D
M87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L
M="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M
M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O
M<G5M<P!&;W)W87)D<P!&;W5N9"!A<'!L:6-A=&EO;G,Z("5S`$9O=6YD(&1I
M<F5C=&]R:65S.@!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI
M=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U
M=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP
M=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$9U>GIY`$=A8F]N`$=A;&QE<GD@
M=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E
M<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;F5R871I;F<@<W1A
M='5S(&9O<B!M;V1U;&4@)7,N+BX`1V5O<F=I80!'97)M86YY`$=E=&]P="!%
M<G)O<CH@`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=O`$=O961E;`!'
M;V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y
M+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R
M;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P('!E<FUI<W-I;VYS
M`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U
M97-T(%!E<FUI<W-I;VYS`$=U97-T('!E<FUI<W-I;VYS`$=U97-T8F]O:P!'
M=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!C;W=A
M<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`
M2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@
M8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O
M(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T:&5N=&EC
M871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(87IE`$AE
M861E<@!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5A=GD@
M5"U3=&]R;0!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L
M<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;'!E<B!A<'!L:6-A=&EO;B!T;R!C
M<F5A=&4@86YD(&UA:6YT86EN('1R86YS;&%T:6]N<R!F;W(@=&AE($AO<F1E
M"F9R86UE=V]R:R!A;F0@:71S(&%P<&QI8V%T:6]N<RX*1F]R(&%N(&EN=')O
M9'5C=&EO;B!R96%D('1H92!F:6QE(%)%041-12!I;B!T:&ES(&1I<F5C=&]R
M>2X`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I
M;&4Z`$AI9V@`2&ES=&]R>2!E;G1R>2!N86UE<R!M=7-T(&)E(&YO;BUE;7!T
M>0!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO
M;64@061D<F5S<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D
M90!(;W)D92!T<F%N<VQA=&EO;B!G96YE<F%T;W(`2&]R9&4O2V]L86(Z($EN
M=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(
M;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@
M)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN
M(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D
M("5S("(E<R(`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!S>6YC:')O;FES
M960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN
M92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+
M;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C
M="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E
M<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R
M('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S
M>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O
M('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@
M<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG
M`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E
M<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R
M9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@
M;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(
M=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A
M=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z
M("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0
M($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S
M(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V
M:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N
M;'D`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@
M;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N
M97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!)
M;G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@
M8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S964@
M=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT
M('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R
M+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA9V4@55),.@!);6%G92!F
M<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`
M26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`26UP
M;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T
M:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S
M<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S
M<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF
M('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA
M`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN9F\`26YF;W)M871I;VX`
M26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92X`26YI=&EA;&EZ:6YG
M(&UO9'5L92`E<RXN+B``26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM
M86=E`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU
M;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT
M(&]N90!);G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!)
M;G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T
M(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@
M<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E
M<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI
M8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C
M96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F
M=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E
M<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN
M<V5R="!R;W<@869T97(`26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R
M97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E
M<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE
M;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!)
M;G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A
M;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!);G9A;&ED(%I)4"!D871A
M`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L
M:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S
M<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&QI8V5N<V4@:V5Y+@!)
M;G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+@!);G9A;&ED(&US9U]T>7!E+@!)
M;G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@
M<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI
M9"!P87)T;F5R(&ED+@!);G9A;&ED('!R;V1U8W0@8V]D92X`26YV86QI9"!P
M<F]T;V-O;"X`26YV86QI9"!R96-I<&EE;G0Z("(E<R(`26YV86QI9"!S:&%R
M92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC
M;V1E(&1A=&$N`$EN=F5N=&]R>0!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F
M`$ER87$`27)E;&%N9`!)<VQE(&]F($UA;@!)<V]L871E9"!4+5-T;W)M<P!)
M<W)A96P`27-S=65R`$ET86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P
M86X`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`
M2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T
M:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN
M86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A
M=&EO;BX`2V5R;F5L($YE=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P
M<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D
M>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A
M=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R
M96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ
M<W1A;@!,85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC
M(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D
M.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@
M;&]G:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O
M<B!N;R!B;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L
M=65S`$QE<V]T:&\`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI
M96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A
M:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI
M9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3
M:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@
M96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA
M>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES="`M('5S97(@8V%N('-E92!T
M:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES
M="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M
M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I
M8F4`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H
M=6%N:6$`3&]A9&EN9R!L:6)R87)I97,N+BX`3&]A9&EN9RXN+@!,;V-A;"!T
M:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;W5T
M`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA
M;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN
M(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E
M<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QU
M>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D
M(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M97(@675G
M;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL`$UA:6P@
M061M:6X`36%K92!L:6Y?:RXN+@!-86ME('-U<F4@=&AA="!Y;W4@:&%V92!0
M14%2(&EN<W1A;&QE9"!A;F0@:6X@>6]U<B!I;F-L=61E('!A=&@N`$UA:VEN
M9R!D:7)E8W1O<GD@)7,`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`
M36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@
M=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I
M=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-
M87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@
M=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA
M<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U
M<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S
M<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@
M`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@;&5N9W1H`$UA>0!-
M87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!M;V1E.@!-97)G92!C96QL
M<P!-97)G:6YG(&%L;"`E<RYP;R!F:6QE<R!T;R!T:&4@8V]M<&5N9&EU;2XN
M+B``365R9VEN9R!L;V-A;&4@)7,N+BX@`$UE<F=I;F<@=&AE(%!/(&9I;&4@
M9F]R("5S('1O('1H92!C;VUP96YD:75M+BXN(`!-97)G:6YG('1R86YS;&%T
M:6]N(&9O<B!M;V1U;&4@)7,N+BX`365S<V%G90!-97-S86=E(%9E<FEF:65D
M(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O
M=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E
M('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE
M+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E
M;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971A<D1"(&ES(&YO
M="!C;VYN96-T960N`$UE=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE
M9`!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@
M;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``
M36EN('1E;7`@;&%S="`V(&AO=7)S.B``36ER<F]R`$UI<V-E;&QA;F5O=7,`
M36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O
M;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y
M;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S
M86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-
M:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO
M9&EF:65D($1A=&4`36]D:69Y(%523`!-;V1U;&4`36]D=6QU<P!-;VQD;W9A
M+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE87(`
M36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F]C8V\`36]S=&QY
M($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W;@!-
M;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P
M`$UO>F%M8FEQ=64`375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I
M<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY(%!O<G1A;`!->2!0;W)T86P@
M3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F%M:6)I
M80!.875R=0!.97!A;`!.971H97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE
M<P!.971S8V%P92!"87-E(%523`!.971S8V%P92!#02!2979O8V%T:6]N(%52
M3`!.971S8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@55),
M`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE='-C87!E(%-33"!S97)V97(@
M;F%M90!.971S8V%P92!C97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E(&-E
M<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE
M=R!#871E9V]R>0!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.
M97<@6F5A;&%N9`!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P
M<P!.97AT`$YE>'0@-"!0:&%S97,`3F5X="!O<'1I;VYS`$YE>'0^`$YI8V%R
M86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@879A:6QA8FQE
M(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`
M3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`
M3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q
M=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R
M($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&0@<&5R
M;6ES<VEO;G,@87)E('1O(&)E(&%D9&5D(&)E;&]W('1H:7,@;&5V96PN`$YO
M(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO
M(&-O;6UA;F0@<W!E8VEF:65D+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&
M4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.
M;R!E;G1R>2!W:71H('1H92!I9"`B)7,B(&5X:7-T<R!I;B!T:&4@;W)I9VEN
M86P@:&5L<"!F:6QE+@!.;R!F:6QE('5P;&]A9&5D`$YO(&QO8V%L92!S<&5C
M:69I960N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C871I;VX@<')O=FED
M960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.
M;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,1$%0(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N
M=&EC871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I
M9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@
M=VET:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<G5L
M97,`3F\@<VED97,`3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@
M9F]R(&-A8VAE+@!.;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`
M3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I
M;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T
M92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N
M9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VYE`$YO
M;F4@*'5S92!I;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L
M:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA
M($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I
M<F5C=&]R>0!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E
M9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=&EC90!.
M;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F
M(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D
M(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T
M`$]B:F5C="!#<F5A=&]R`$]B:F5C="!C<F5A=&]R('!E<FUI<W-I;VYS`$]C
M=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]M86X`3VYL>2!)
M34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O9F9E
M;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D
M+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@
M8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S
M:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L
M9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/
M<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T
M96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<'1I;VYS.@!/<F1E<F5D($QI
M<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN
M9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP
M;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E
M<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE
M+@!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'
M4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O
M9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W
M`%!-(%-N;W<@4VAO=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`4%](4"!3:&5L
M;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R
M>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`
M4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!I;F-O<G)E8W0`4&%S
M<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S
M<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``
M4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O
M87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F
M;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC
M92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@
M(B5S(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`
M4&5R;6ES<VEO;G,@9F]R`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T
M<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L
M871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C
M;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`
M4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E
M;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A
M<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@
M96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI
M9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H
M+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O=FED92!A
M('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@
M=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I
M;F<@=&5X="X@(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S
M92!T:&4@<WES=&5M+@!0;&5A<V4@<F5P;W)T(&%N>2!B=6=S('1O(&DQ.&Y`
M;&ES=',N:&]R9&4N;W)G+@!0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y
M(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T=6=A;`!0;W-I=&EO
M;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`
M4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!R
M96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R96-I<&ET871I
M;VX\8G(@+SYC:&%N8V4`4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S
M:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T
M('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I
M;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D
M;V-U;65N=`!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I
M;VX`4')O:F5C=',`4')O;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y
M($%L9V]R:71H;0!0=6)L:6,@2V5Y($EN9F\`4'5B;&EC+U!R:79A=&4@:V5Y
M<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4'5E<G1O(%)I8V\`
M46%T87(`475E<GD`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`4F%D:6\@<V5L
M96-T:6]N`%)A:6X`4F%I;B!%87)L>0!286EN($QA=&4`4F%I;B!3:&]W97(`
M4F%I;B!A;F0@4VYO=P!286EN('1O(%-N;W<`4F%N9&]M($9O<G1U;F4`4F%T
M:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@
M;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E
M<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H($1Y;F%M
M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`
M4F5L871I;VYS:&EP($)R;W=S97(`4F5M87)K<P!296UO=&4@4V5R=F5R<P!2
M96UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M
M;W9E`%)E;6]V92!";&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T
M:6YG`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V
M97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T
M:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E
M('5S97(Z("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R
M;F5D(&5R<F]R8V]D93H@`%)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B
M92!F;W5N9"X`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O
M;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!6
M1E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D
M(&EN(&-O;F9I9W5R871I;VXN`%)E<75I<F5D($9I96QD`%)E<V5T`%)E<V5T
M(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S=6QT<P!297-U;'1S
M("AI;F-L=61I;F<@2&]R9&4I.@!297-U;'1S.@!2971U<FX@=&\@3W!T:6]N
M<P!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET
M;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V
M86QU97,`4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@
M,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2
M;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O
M34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D
M($UE<W-A9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE
M+@!335,@365S<V%G:6YG`%-13"!3:&5L;`!34T@`4U5#0T534P!37U%,(%-H
M96QL`%-A`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I
M;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC
M96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M
M;V$`4V%N($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E
M(%!R;W9I9&5R`%-A=61I($%R86)I80!3879E`%-A=F4@)7,`4V%V92`G)7,G
M`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S
M(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E
M8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P
M9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I
M96YC90!396%R8V@`4V5A<F-H($5N9VEN97,`4V5A<F-H:6YG($AO<F1E(&%P
M<&QI8V%T:6]N<R!I;B`E<P!396%R8VAI;F<@9V5T=&5X="!B:6YA<FEE<RXN
M+@!396QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U<"!T
M;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE
M8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`
M4V5L96-T(&%N(&]B:F5C=`!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE
M960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N
M9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D
M871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T
M('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@
M=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C
M="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE
M;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B
M;&5M(%)E<&]R=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E
M<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V97(@
M9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397-S:6]N($E$(&5X<&ER
M960N`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U
M<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO
M=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@
M<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE
M(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I
M;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@
M9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP=',@
M879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE
M('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@4W5M;6%R
M>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK
M<S\`4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A
M=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H
M;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I
M;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A8FQE(&]P
M97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE
M9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO
M=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@
M4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I
M97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3
M:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAR:6YK`%-H
M<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE
M('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N('5P(&EF(&YO
M="!R96=I<W1E<F5D`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I
M;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VMI<'!E9"XN+@!3;&]V
M86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3
M;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S($QA=&4`4VYO=R!D97!T
M:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@`%-O;&]M;VX@27-L86YD
M<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!O<F1E<B!S96QE8W1I;VX`
M4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O=71H($5U<F]P96%N("A)
M4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I
M8V@@27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@
M861J86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D
M97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG
M`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L
M;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A
M;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`
M4W1A='5S`%-T871U<R!F;W(@;&]C86QE("5S+BXN(`!3=&]R86=E(&9O<FUA
M=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T
M<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U
M8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B('1O
M('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R(')E
M<75E<W0@:&%S(&)E96X@87!P<F]V960N`%-U8G-C<FEP=`!3=6-C97-S`%-U
M8V-E<W-F=6QL>2!A9&1E9"`B)7,B('1O('1H92!S>7-T96TN`%-U8V-E<W-F
M=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T
M96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL>2!R
M96UO=F5D("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@<F5V
M97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3
M=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E
M<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E
M<RX`4W5C8V5S<V9U;&QY('5P9&%T960@(B5S(@!3=6-C97-S9G5L;'D@=W)O
M=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U
M;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z
M(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A
M<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD
M`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P
M=6)L:6,`5"U3=&]R;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T;W)M<P!4+5-T
M;W)M<R!%87)L>0!44U8@9FEL90!486)L90!486)L92!0<F]P97)T:65S`%1A
M8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI
M;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A
M<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO
M=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R
M("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@
M9F]U;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY
M`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N
M9`!4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92`E<R!H96QP
M(&9I;&4@9F]R("5S(&1O97-N)W0@>65T(&5X:7-T+B!#<F5A=&EN9R!A(&YE
M=R!O;F4N`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H
M92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P
M<&]R="`B)7,B`%1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ
M960N`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C
M97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I
M;F<N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E
M<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S
M92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A
M8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R
M('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W
M87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4
M:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T
M;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK
M(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I
M;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A
M='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I
M;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E
M<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C
M86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I
M;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O
M<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL('-C<F5E
M;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N
M970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E
M;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E
M(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N
M9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@
M:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E
M="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E
M8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@
M3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E
M9&ET;W(N`%1H92!H96QP(&9I;&4@)7,@9&ED;B=T('-T87)T('=I=&@@/#]X
M;6P`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE
M9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B
M:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N
M`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E
M<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T
M:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`
M5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P
M86=E`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO
M<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@
M8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@
M=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T
M;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T
M:&4@<WES=&5M+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@
M<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N
M(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE
M('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@
M<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="X`5&AE('1E;7!O<F%R>2!F
M:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T;W`@86YD(&)O='1O;2!S
M:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U<&QO861E9"!D871A
M('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D
M960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W96%T:&5R+F-O;2!B
M;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A
M=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P
M;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I
M;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[
M('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@9&]E<VXG="!Y
M970@97AI<W0@82!H96QP(&9I;&4@9F]R("5S+@!4:&5R92!W87,@82!P<F]B
M;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A<R!A
M('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE
M('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F
M<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG
M("(E<R(Z("5S`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA
M;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A
M<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R
M(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S
M(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@
M>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E
M<G)O<B!O<&5N:6YG('1H92!F:6QE("5S+B!4<GD@<G5N;FEN9R!T<F%N<VQA
M=&EO;BYP:'`@=VET:"!T:&4@9FQA9R`M9"!T;R!S964@86YY(&5R<F]R(&UE
M<W-A9V5S(&9R;VT@=&AE('AM;"!P87)S97(N`%1H97)E('=A<R!A;B!E<G)O
M<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T
M:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R
M;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A
M9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D
M:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI
M<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R
M<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C
M:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@
M9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N
M=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O
M;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I
M;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(
M5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E=V%Y
M+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M
M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ
M.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B
M92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S
M`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L
M9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O
M<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L
M<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+
M;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO
M=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@
M=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C
M:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@
M=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA
M;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N
M`%1H:7,@<V-R:7!T(&UU<W0@8F4@<G5N(&9R;VT@=&AE(&-O;6UA;F0@;&EN
M92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@
M9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`
M5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T
M(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC
M:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE
M8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4
M;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O
M;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4
M;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W
M`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T960`5')A;G-L
M871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4
M=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T
M86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@
M8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T
M(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR86EN90!5
M;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@
M97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L
M92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`
M56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-O;FYE8W0@=&\@
M4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L
M92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E
M8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(&5M
M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B
M;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M+@!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L971E
M("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T
M;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R
M96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D
M:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I
M;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L
M92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA
M8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S
M960@87)C:&EV92X`56YA8FQE('1O(')E860@9FEL93H@`%5N86)L92!T;R!R
M96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E
M<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N
M86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M
M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S
M)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!6
M1E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@
M9FEL92!D871A+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R
M(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@
M;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V
M97(@=&\Z(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%
M;6ER871E<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3
M=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N
M:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM
M<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&-O;6UA;F0Z("5S
M`%5N:VYO=VX@;&]C871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@
M;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M
M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P
M>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N
M("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA
M+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O
M(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E
M9"!%>'1E;G-I;VX`56YT<F%N<VQA=&5D`%5P9&%T90!5<&1A=&4@)7,`57!D
M871E('5S97(`57!D871E9"`B)7,B+@!5<&1A=&EN9R`E<R!H96QP(&9I;&4@
M9F]R("5S+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D
M960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N
M`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<G5G
M=6%Y`%5S86=E.@!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M
M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R
M("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A
M=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I
M<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E
M<B!P97)M:7-S:6]N<P!5<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L<F5A9'D@
M97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<P!5<V5R<R!I;B!T
M:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@
M97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E
M.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=64@
M:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E<P!686QU
M97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`
M5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B
M965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E
M<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@
M2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<@)7,`5FEE
M=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)<VQA
M;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`
M5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%2
M3DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=A;&QI
M<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V%R;FEN9SH@`%=E`%=E871H97(@1F]R
M96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E
M8@!796(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O
M;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y
M+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E
M<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@
M8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H:6-H
M('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@
M5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O
M9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE
M>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED
M=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`
M5VEN9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES=',`5V]R:P!7;W)K($%D9')E
M<W,`5V]R:R!0:&]N90!7<FET:6YG('5P9&%T960@:&5L<"!F:6QE('1O("5S
M+@!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N
M9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE
M`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I
M;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@
M22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B
M=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@
M875T:&5N=&EC871E9"X`66]U(&-A;B!N;W0@:&%V92!T:&4@)UPG(&-H87)A
M8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I9"!N;W0@96YT97(@82!V
M86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S
M(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@
M9FEE;&1S(&EN("5S+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S
M(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO
M;F%L(&1I86QI;F<@<')E9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED
M('9A;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD
M('1O('5S92!3:6=N=7!S+@!9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C
M:V5N9"X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO
M=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R
M('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S
M96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I
M9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@
M82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S
M97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E
M<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U
M(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W5R
M("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`
M66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!)
M;F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@
M<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R
M;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO
M=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@
M<W5P<&]R="!A9&1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N
M(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!A=71H96YT
M:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R
M<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@
M;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H
M86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN
M(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A
M:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R
M92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O
M<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@=&\@<')I;G0N`%EO
M=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>3H`
M66]U<B!F=6QL(&YA;64Z`%EO=7(@9V5T=&5X="!V97)S:6]N(&ES('1O;R!O
M;&0@86YD(&1O97,@;F]T('-U<'!O<G0@4$A0(&YA=&EV96QY+@I.;W0@86QL
M('-T<FEN9W,@=VEL;"!B92!E>'1R86-T960N`%EO=7(@;F5W('!A<W-W;W)D
M(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D
M(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO
M;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@
M<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U
M<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO
M=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II
M;6)A8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O
M<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E
M<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?0TQ)
M`%]$871A5')E90!?1&5L971E(%)O=P!?1W)O=7!S`%](96QP`%]);6%G92!0
M<F]P97)T:65S+BXN`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN
M`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P
M`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`86X@
M97)R;W(@:&%S(&]C8W5R960Z`&-A;&5N9&%R`&-A;&T`8VQI8VL@:&5R90!D
M;VYE`&9A:6QE9`!F86QL:6YG`&9I;&4`9F]U;F0Z(`!F<F]M('1H92`E<R`H
M)7,I(&%T("5S("5S`&=U<W1I;F<`:#H`:&@`:6UM961I871E`&EN;&EN90!L
M:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N
M`&UM`&YA;64`;F]T(&-H86YG960`;F]T(&9O=6YD`&YO="!I;7!L96UE;G1E
M9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P:7AE;',`
M<FES:6YG`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-S
M`'-T96%D>0!T87-K(&QI<W0`=&AE($AO<F1E(%!/(&9I;&4@9F]R('1H92!L
M;V-A;&4@)7,@9&]E<R!N;W0@97AI<W0Z`'1Y<&4@=&AE('!A<W-W;W)D('1W
M:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5P9&%T960`=7-E<B!S
M96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S:6]N
M.B!(;W)D92`S+C`M8W9S"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES
M=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$Q+3(T(#`Q
M.C$X*S`P,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P,BTP,2TR,2`Q.#HR,BTP
M,#`P"DQA<W0M5')A;G-L871O<CH@3G5N;R!,;W5R96ER;R`\;G5N;T!E=&@N
M<'0^"DQA;F=U86=E+51E86TZ(%!O<G1U9V%L(%!O<G1U9W5E<V4@/&1E=D!L
M:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP
M93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ"D-O;G1E;G0M5')A
M;G-F97(M16YC;V1I;F<Z(#AB:70*`"`@+4TL("TM;65S<V%G93U-14Y304=%
M32!5<V%R(&5S=&$@;65N<V%G96T@9&4@8V]M971I;65N=&\@96T@=F5Z(&1A
M"B`@("`@("`@("`@("`@("`@("`@("`@("!M96YS86=E;2!P;W(@;VUI<W/C
M;RX`("`M82P@+2UA9&0]05)154E63R`@("`@061I8VEO;F%R(&5S=&4@87)Q
M=6EV;R!03R!A;R!C;VUPZFYD:6\N(%5T:6P@<&%R80H@("`@("`@("`@("`@
M("`@("`@("`@("!I;F-L=6ER('5M(&-O;7#J;F1I;R!D92!U;2!R86UO(&1I
M9F5R96YT92!N;PH@("`@("`@("`@("`@("`@("`@("`@("!C;VUPZFYD:6\@
M9V5R861O+@`@("UB+"`M+6)A<V4]+T-!34D@($-A;6EN:&\@<&%R82!O(&1I
M<F5C=/-R:6\@8F%S92`H2&]R9&4I(&$@=7-A<BX`("`M8RP@+2UC;VUP96YD
M:75M/4%2454@($EN=&5G<F%R(&YO=F%S('1R861UY_5E<R!A(&5S=&4@87)Q
M=6EV;R!D92!C;VUPZFYD:6\*("`@("`@("`@("`@("`@("`@("`@("`@(&4@
M;N-O(&%O(&-O;7#J;F1I;R!P;W(@;VUI<W/C;R`H8V]M<&5N9&EU;2YP;R!N
M80H@("`@("`@("`@("`@("`@("`@("`@("`@<&%S=&$@:&]R9&4O<&\N`"`@
M+6,L("TM8V]M<&5N9&EU;3U!4E%5("!5<V%R(&5S=&4@87)Q=6EV;R!D92!C
M;VUPZFYD:6\@96T@=F5Z(&1O(&%R<75I=F\*("`@("`@("`@("`@("`@("`@
M("`@("`@('!O<B!O;6ES<^-O("AC;VUP96YD:75M+G!O(&YA('!A<W1A(&AO
M<F1E+W!O+@`@("UD+"`M+61E8G5G("`@("`@($UO<W1R87(@;65N<V%G96YS
M(&1E(&5R<F\@9&]S(&)I;N%R:6]S(&5X96-U=&%D;W,N`"`@+60L("TM9&ER
M96-T;W)Y/5!!4U1!($-R:6%R('5M(&-O;7#J;F1I;R!N97-T82!P87-T82X`
M("`M:"P@+2UH96QP("`@("`@("!-;W-T<F%R(&5S=&$@;65N<V%G96T@9&4@
M86IU9&$N`"`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V%R(&%P96YA<R!E
M<W1A(&QO8V%L:7IAY^-O+@`@("UL+"`M+6QO8V%L93UL;%]#0R`@("`@57-A
M<B!E<W1A(&QO8V%L:7IAY^-O+@`@("UL+"`M+6QO8V%L93UL;%]#0R`@("!5
M<V%R(&5S=&$@;&]C86QI>F'GXV\N`"`@+6TL("TM;6]D=6QE/4W31%5,3R`@
M("!#;VYS=')U:7(@87)Q=6EV;W,@34\@87!E;F%S('!A<F$@97-T92!M\V1U
M;&\*("`@("`@("`@("`@("`@("`@("`@("`@("A(;W)D92DN`"`@+6TL("TM
M;6]D=6QE/4W31%5,3R`@("!,:6UP87(@87)Q=6EV;W,@4$\@87!E;F%S('!A
M<F$@97-T92!M\V1U;&\*("`@("`@("`@("`@("`@("`@("`@("`@("A(;W)D
M92DN`"`@+6TL("TM;6]D=6QE/4W31%5,3R`@("!#;VUE=&5R(&%S('1R861U
MY_5E<R!A<&5N87,@<&%R82!E<W1E(&WS9'5L;PH@("`@("`@("`@("`@("`@
M("`@("`@("`@*$AO<F1E*2X`("`M;2P@+2UM;V1U;&4]3=-$54Q/("`@($-R
M:6%R(&\@87)Q=6EV;R!03R!A<&5N87,@<&%R82!E<W1E(&WS9'5L;PH@("`@
M("`@("`@("`@("`@("`@("`@("`@*$AO<F1E*2X`("`M;2P@+2UM;V1U;&4]
M3=-$54Q/("`@($EN=&5G<F%R(&%R<75I=F]S(%!/(&%P96YA<R!P87)A(&5S
M=&4@;?-D=6QO"B`@("`@("`@("`@("`@("`@("`@("`@("`H2&]R9&4I+@`@
M("UM+"`M+6UO9'5L93U-TT153$\@("`@06-T=6%L:7IA<B!A<G%U:79O<R!D
M92!A:G5D82!A<&5N87,@<&%R82!E<W1E"B`@("`@("`@("`@("`@("`@("`@
M("`@("!M\V1U;&\@*$AO<F1E*2X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@
M($%C='5A;&EZ87(@87!E;F%S(&5S=&4@;?-D=6QO("A(;W)D92DN`"`@+6TL
M("TM;6]D=6QE/4U/1%5,12`@("!'97)A<B!A<F-H:79O(%!/5"!A<&5N87,@
M<&%R82!E<W1E(&WS9'5L;PH@("`@("`@("`@("`@("`@("`@("`@("`@*$AO
M<F1E*2X`("`M;BP@+2UN;RUC;VUP96YD:75M("`@($[C;R!I;G1E9W)A<B!N
M;W9A<R!T<F%D=>?U97,@;F\@8V]M<.IN9&EO+@`@("UN+"`M+6YO+6-O;7!E
M;F1I=6T@("`@3N-O('5S87(@=6T@8V]M<.IN9&EO+@`@("US+"`M+7-T871I
M<W1I8W,@("`@("`@1W5A<F1A<B!E<W1A=.US=&EC87,@9&4@=')A9'7GXV\@
M;G5M(&9I8VAE:7)O(&QO8V%L+@`@("UT+"`M+71E<W0@("`@("`@($UO<W1R
M87(@;W,@<')O9W)A;6%S(&$@97AE8W5T87(@;6%S(&[C;R!O(&9A>F5R+@`@
M(&-L96%N=7`@("`@($QI;7!A<B!O9B!A<G%U:79O<R!03R!D92!E;G1R861A
M<R!P;W(@=')A9'5Z:7(@;W4@;V)S;VQE=&%S+@`@(&-O;6UI="`@("`@($-O
M;65T97(@87,@=')A9'7G]65S(&YO('-E<G9I9&]R($-64RX`("!C;VUM:70M
M:&5L<"!#;VUE=&5R(&%R<75I=F]S(&1E(&%J=61A(&YO('-E<G9I9&]R($-6
M4RX`("!C;VUP96YD:75M("!296-O;G-T<G5I<B!O(&%R<75I=F\@9&4@8V]M
M<.IN9&EO+B!!=&5NY^-O.B!/(&YO=F\@87)Q=6EV;PH@("`@("`@("`@("`@
M('-O8G)E</5E+7-E(&%O(&%N=&EG;RX`("!E>'1R86-T("`@("!'97)A<B!A
M<G%U:79O<R!M;V1E;&\@4$\@*"YP;W0I+@`@(&AE;'`@("`@("`@($UO<W1R
M87(@97-T82!M96YS86=E;2!D92!A:G5D82X`("!I;FET("`@("`@("!#<FEA
M<B!U;2!O=2!M86ES(&%R<75I=F]S(%!/('!A<F$@=6UA(&YO=F$@;&]C86QI
M>F'GXV\N"B`@("`@("`@("`@("`@071E;N?C;SH@3W,@;F]V;W,@87)Q=6EV
M;W,@<V]P<F5P]65M+7-E(&%O<R!A;G1I9V]S+@`@(&UA:V4@("`@("`@($-O
M;G-T<G5I<B!A<G%U:79O<R!B:6[A<FEO<R!-3R!A('!A<G1I<B!D;W,@87)Q
M=6EV;W,*("`@("`@("`@("`@("!03R!E<W!E8VEF:6-A9&]S+@`@(&UA:V4M
M:&5L<"`@($UA<F-A<B!T;V1A<R!A<R!E;G1R861A<R!N;R!A<G%U:79O(%A-
M3"!D92!A:G5D82!C;VUO(&5S=&%N9&\*("`@("`@("`@("`@("!A8W1U86QI
M>F%D87,@92!P<F5P87)A<B!O(&%R<75I=F\@<&%R82!A('!R\WAI;6$@97AE
M8W7GXV\*("`@("`@("`@("`@("!D92!U<&1A=&4M:&5L<"X@1&5V92US92!E
M>&5C=71A<B!M86ME+6AE;'`@1$503TE3(&1E"B`@("`@("`@("`@("`@=7!D
M871E+6AE;'`@92!D92!R979E<B!O(&%R<75I=F\@9&4@86IU9&$N`"`@;65R
M9V4@("`@("`@26YT96=R87(@;R!A<G%U:79O(%!/(&-O<G)E;G1E(&-O;2!O
M(&%R<75I=F\@;6]D96QO(%!/(&-O<G)E;G1E+@`@('5P9&%T92`@("`@($5X
M96-U=&%R(&5X=')A8W0@92!M97)G92!E;2!S97%UZFYC:6$N`"`@=7!D871E
M+6AE;'`@17AT<F%I<B!T;V1A<R!A<R!E;G1R861A<R!N;W9A<R!E(&UO9&EF
M:6-A9&%S(&1O(&%R<75I=F\@9&4*("`@("`@("`@("`@("!A:G5D82!834P@
M96T@:6YG;.IS(&4@:6YT96=RX2UL87,@8V]M(&%S(&5X:7-T96YT92X`("8C
M,34Q.R`E<R!E<W3A('!R;VYT;R!P87)A(&5F96-T=6%R(&%S(&]P97)AY_5E
M<R!D92!M86YU=&5NY^-O(&UA<F-A9&%S(&%B86EX;RX`("@E<R!D:6%S(&%T
M<N%S*0`@*$-H879E(&1E(&%C97-S;R`E<RD`("AD96YT<F\@9&4@)7,@9&EA
M<RD`("AH;VIE*0`@*&%M86YHXRD`("AO;G1E;2D`(&-O;2``(B5S(B!NXV\@
MZ2!U;6$@97-C;VQH82!VX6QI9&$N`"(E<R(@;N-O(&5S=.$@8V]N9FEG=7)A
M9&\@;F\@4F5G:7-T;R!D;R!(;W)D92X`(B5S(B!R97!R97-E;G1A9&]R(&1E
M(.%R=F]R92!NXV\@96YC;VYT<F%D;RX`(B5S(B!F;VD@861I8VEO;F%D;R!A
M;R!S:7-T96UA(&1E(&=R=7!O<RX`(B5S(B<@9F]I(&%D:6-I;VYA9&\@86\@
M<VES=&5M82!D92!P97)M:7-S]65S+@`B)7,B(&[C;R!F;VD@8W)I861O.B`E
M<RX`)60@)7,@92`E<P`E9"!B>71E<R!E<V-R:71O<P`E9"!D92`E9"!E;G1R
M861A(&UA<F-A9&%S(&-O;6\@86-T=6%L:7IA9&%S`'!R979I<^-O(&1E("5D
M(&1I87,`)7,@+2!.;W1I9FEC8>?C;P`E<R!!9&UI;FES=')AY^-O`"5S($EM
M<')E<W/C;R!$:6=I=&%L`"5S($M"`"5S($]P97)AY_5E<R!D92!-86YU=&5N
MY^-O("T@0V]N9FER;6'GXV\`0V]N9FEG=7)A<B`E<P`E<R!3=6)S8W)E=F5R
M`"5S(%1E<FUO<R!D;R!!8V]R9&\`)7,@:N$@97AI<W1E+@`E<R!E;2`E<R`E
M<P!NXV\@<V4@<&]D92!E<V-R979E<B!E;2`E<RX`)7,@Z2!O8G)I9V%T\W)I
M;P`E<R!M:6YU=&]S`"5S(&[C;R!F;VD@96YC;VYT<F%D;RX`)7,@;N-O(&9O
M:2!E;F-O;G1R861O+B!%>&5C=71A<B`G=')A;G-L871I;VX@97AT<F%C="<@
M<')I;65I<F\N`"5S(&$@)7,@9&4@)7,`0V]N=&%C=&]S(&1E("5S`$-A;&5N
M9.%R:6\@9&4@)7,`3F]T87,@9&4@)7,`5&%R969A<R!D92`E<P`E<SH@)7,`
M+"!C;VT@<F%J861A<P`L(&-O;2!R86IA9&%S("5S("5S`"P@=F%R:>%V96P@
M9&4@)7,@82`E<P`M+2!E<V-O;&AA("TM`"TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+0!&;W)M871O(&1E(#$R(&AO<F%S("A!32]032D`1F]R;6%T;R!D
M92`R-"!H;W)A<P`R-"!H;W)A<P`\06YT97)I;W(`971I<75E=&$@/&=E='1E
M>'0^('!O<B!F96-H87(@;F\@9FEC:&5I<F\@)7,N"D%B<FEN9&\@82!E=&EQ
M=65T82!E;F-O;G1R861A(&YA(&QI;FAA("5D+@!%<W1E(&)L;V-O(&5X:6=E
M('5M(&UE8V%N:7-M;R!U<V%N9&\@8F%S97,@9&4@9&%D;W,N`$]C;W)R974@
M=6T@97)R;R!F871A;`#)(&YE8V5S<^%R:6$@=6UA(&-H879E('#Z8FQI8V$@
M4$=0('!A<F$@96YC<FEP=&%R(&$@;65N<V%G96TN`,D@;F5C97-SX7)I82!U
M;6$@8VAA=F4@</IB;&EC82!01U`@<&%R82!V97)I9FEC87(@82!A<W-I;F%T
M=7)A(&1E('5M82!M96YS86=E;0!087)A(&1E8VEF<F%R('5M82!M96YS86=E
M;2!SXV\@;F5C97-SX7)I87,@=6UA(&-H879E('#Z8FQI8V$@4$=0+"!U;6$@
M8VAA=F4@<')I=F%D82!01U`@92!U;6$@9G)A<V4M<&%S<V4N`%!A<F$@87-S
M:6YA<B!U;6$@;65N<V%G96T@<^-O(&YE8V5S<^%R:6%S('5M82!C:&%V92!P
M^F)L:6-A(%!'4"P@=6UA(&-H879E('!R:79A9&$@4$=0(&4@=6UA(&9R87-E
M+7!A<W-E+@!087)A(&1E8VEF<F%R('5M82!M96YS86=E;2!SXV\@;F5C97-S
MX7)I87,@=6UA(&-H879E('#Z8FQI8V$@4R]-24U%+"!U;6$@8VAA=F4@<')I
M=F%D82!3+TU)344@92!U;6$@9G)A<V4M<&%S<V4N`%!A<F$@87-S:6YA<B!U
M;6$@;65N<V%G96T@<^-O(&YE8V5S<^%R:6%S('5M82!C:&%V92!P^F)L:6-A
M(%,O34E-12P@=6UA(&-H879E('!R:79A9&$@4R]-24U%(&4@=6UA(&9R87-E
M+7!A<W-E+@#)(&YE8V5S<^%R:6$@=6UA(&-H879E('#Z8FQI8V$@4R]-24U%
M('!A<F$@96YC<FEP=&%R('5M82!M96YS86=E;2X`3OIV96YS(&1E(&UA;FCC
M`$-H=79I<V-O<R!D92!-86YHXP!#:'5V82!D92!M86YHXP!!9W5A8V5I<F]S
M(&1E(&UA;FCC`$YE=O5E<R!D92!M86YHXP!!32]030!!4$D@240`06-E<F-A
M(&1E<W1E(&5D:71O<@!!8V5R8V$N+BX`0F%S97,@86QI;FAA9&%S`$-E;G1R
M;W,@86QI;FAA9&]S`$%C97-S;R!N96=A9&\@86\@8W)I87(@<&%S=&$@5D93
M+@!!8V5S<V\@;F5G861O(&%O(&-R:6%R(&%R<75I=F\@5D93+@!086QA=G)A
M+5!A<W-E(&1A($-O;G1A`$-O;G1A(&-O;F=E;&%D82X`0V]N=&%B:6QI9&%D
M90!!9&EC:6]N87(`061I8VEO;F%R($=R=7!O($9I;&AO`$%D:6-I;VYA<B!0
M97)M:7-SXV\@1FEL:&$`06-R97-C96YT87(@07%U:3H`061D:6-I;VYA<B!.
M;W9O($=R=7!O`$%D:6-I;VYA<B!.;W9A(%!E<FUI<W/C;P!!9&EC:6]N87(@
M=6T@9W)U<&\@9FEL:&\@82`B)7,B`$%D:6-I;VYA<B!U;6$@<&5R;6ES<^-O
M(&9I;&AA(&$@(B5S(@!!9&EC:6]N87(@;F]V;R!U=&EL:7IA9&]R.@!!9&EC
M:6]N87(@8V]L=6YA`$%D:6-I;VYA<B!N;W9O<R!M96UB<F]S`$%D:6-I;VYA
M<B!P87)C96ER;P!!9&EC:6]N87(@;R!-96YU("5S(&-O;6\@0F%R<F$@3&%T
M97)A;"!-;WII;&QA`$%D:6-I;VYA<B!A;W,@0V]N=&%C=&]S.@!!9&EC:6]N
M87(@86]S(&UE=7,@8V]N=&%C=&]S`$%D:6-I;VYA<B!U=&EL:7IA9&]R`$%D
M:6-I;VYE:2`B)7,B(&%O('-I<W1E;6$L(&UA<R!NXV\@<'5D92!A9&EC:6]N
M87(@:6YF;W)M8>?C;R!D92!S=6)S8W)IY^-O(&%D:6-I;VYA;#H@)7,N`$%D
M:6-I;VYE:2`B)7,B(&%O('-I<W1E;6$N($KA('!O9&4@96YT<F%R+@!!9&EC
M:6]N86YD;R!N;W9O<R!A<G%U:79O<R!A;R!R97!O<VET\W)I;SH`02!A9&GG
MXV\@9&4@=71I;&EZ861O<F5S(&5S=.$@9&5S86-T:79A9&$N`$5N9&5R9>=O
M`$-O;G1A8W1O<P!!9&UI;FES=')A<B`M(&%T<FEB=6ER('!E<FUI<W/U97,@
M82!O=71R;W,@=71I;&EZ861O<F5S`$%D;6EN:7-T<F'GXV\`06[Z;F-I;W,`
M069E9V%N:7-TXV\`06QBXFYI80!!<F?I;&EA`$%L8W5N:&$`06QI;FAA<@!!
M;&EN:&%M96YT;SH`5'5D;P!4;V1O<R!O<R!5=&EL:7IA9&]R97,@075T96YT
M:6-A9&]S`%1O9&]S(&]S($=R=7!O<P!4;V1A<R!A<R!097)M:7-S]65S`%1O
M9&]S(&]S("AQ=6%T<F\I(&QA9&]S`%!E<FUI=&ER(&WZ;'1I<&QO<R!E;F1E
M<F7G;W,`4&5R;6ET:7(@871R:6)U:>?C;R!D;R!T:7!O(&1E(&QI<W1A<R!O
M<F1E;F%D87,_`$KA(&5X:7-T90!%;G1R861A($E-4U`@06QT97)N871I=F$`
M4&%L879R82U087-S92!)35-0($%L=&5R;F%T:79A`$YO;64@9&4@571I;&EZ
M861O<B!)35-0($%L=&5R;F%T:79O`$5N9&5R9>=O(&EN=N%L:61O`$UO9&5L
M;W,@86QT97)N871I=F]S`%1E>'1O(&%L=&5R;F%T:79O.@!386UO82!!;65R
M:6-A;F$`1F]I(&5S<&5C:69I8V%D;R!U;2!V86QO<B!I;G;A;&ED;RX`3V-O
M<G)E=2!U;2!E<G)O(&1E<V-O;FAE8VED;RX`06YD;W)R80!!;F=O;&$`06YG
M=6EL80!%;G1R97!O<W1O("AP<F]X>2D@06[S;FEM;P!297-P;W-T80!!;G3A
M<F-T:6-O`$%N=.UG=6$@92!"87)B=61A`$%P;&EC8>?C;P!!<&QI8V'GXV\@
M<')O;G1A+@!!<&QI8V%R(&$@4&%R=&EL:&%S($9I;&AA<P!!<')O=F%R`%1A
M;6%N:&\@07!R;WAI;6%D;P!!8G)I;`!!<N%B:6-O("A7:6YD;W=S+3$R-38I
M`%1A;6%N:&\@9&\@1FEC:&5I<F\@9&4@07)Q=6EV;P!.;VUE(&1O($%R<75I
M=F\`5&5M(&$@8V5R=&5Z82!Q=64@<75E<B!R96UO=F5R(&\@<&5D:61O(&1E
M('-U8G-C<FGGXV\@<&%R82`E<R`_`%1E;2!A(&-E<G1E>F$@<75E('%U97(@
M<F5M;W9E<B`B)7,B(&4@<75A:7-Q=65R('-U8BUG<G5P;W,_`$%R9V5N=&EN
M80!!<FWI;FEA`$%R;>EN:6\@*$%235-#24DM."D`07)T90!!<G5B80!);&AA
M(&1E($%S8V5N<^-O`$%R=&4@05-#24D`4F5G:>-O(,%S:6$O4&%C[69I8V\`
M4&5D:7(@8V]N9FER;6'GXV\@86YT97,@9&4@<F5A;&EZ87(@;W!E<F'G]65S
M(&1E(&UA;G5T96[GXV\_`$-O;'5N87,@9&4@871R:6)U:>?C;P!496YT871I
M=F$@9&4@<F5M;^?C;R!D92!U;2!G<G5P;R!I;F5X:7-T96YT92X`5&5N=&%T
M:79A(&1E(')E;6_GXV\@9&4@=6UA('!E<FUI<W/C;R!I;F5X:7-T96YT92X`
M5&5N=&%T:79A(&1E(&5D:>?C;R!D92!U;6$@<&5R;6ES<^-O(&EN97AI<W1E
M;G1E+@!496YT871I=F$@9&4@961IY^-O(&1E('5M82!P87)T:6QH82!I;F5X
M:7-T96YT92X`071R:6)U=&]S`$%G;W-T;P!!=7-T<N%L:6$`P75S=')I80!!
M=71H7V-Y<G-Q;#H@02!E>'1E;G/C;R!I;6%P(&YE8V5S<^%R:6$@;N-O(&9O
M:2!E;F-O;G1R861A+@!!=71H7V-Y<G5S.B!/(&UE8V%N:7-M;R!NXV\@=&5M
M(&%S(&-A<&%C:61A9&5S(&YE8V5S<^%R:6%S+@!!=71H7V-Y<G5S.B!!(&5X
M=&5N<^-O(&EM87`@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N`$%U
M=&A?9G1P.B!!(&5X=&5N<^-O($944"!N96-E<W/A<FEA(&[C;R!F;VD@96YC
M;VYT<F%D82X@0V]M<&EL92!O(%!(4"!C;VT@82!O<.?C;R`M+65N86)L92UF
M='`N`$%U=&A?:6UA<#H@02!E>'1E;G/C;R!)34%0(&YE8V5S<^%R:6$@;N-O
M(&9O:2!E;F-O;G1R861A+@!!=71H7VMR8C4Z($$@97AT96YSXV\@:W)B-2!N
M96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D82X`075T:%]L9&%P.B!!(&5X
M=&5N<^-O($Q$05`@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N`$%U
M=&A?;&1A<#H@26UP;W-S[79E;"!A9&EC:6]N87(@=71I;&EZ861O<B`E<RX@
M16ES(&\@<75E(&\@<V5R=FED;W(@9&ES<V4Z(`!!=71H7VQD87`Z($EM<&]S
M<^UV96P@<F5M;W9E<B!O('5T:6QI>F%D;W(@)7,`075T:%]L9&%P.B!);7!O
M<W/M=F5L(&%C='5A;&EZ87(@;R!U=&EL:7IA9&]R("5S`$%U=&A?;6-A;#H@
M02!E>'1E;G/C;R!-0T%,(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O;G1R861A
M+@!!=71H7W-M8F%U=&@Z($$@97AT96YSXV\@<VUB875T:"!N96-E<W/A<FEA
M(&[C;R!F;VD@96YC;VYT<F%D82X`02!A=71E;G1I8V'GXV\@9F%L:&]U`$$@
M875T96YT:6-AY^-O(&9A;&AO=2X@)7,`02!A=71E;G1I8V'GXV\@9F]I(')E
M:F5I=&%D82!P96QO('-E<G9I9&]R(%)!1$E54RX`02!A=71E;G1I8V'GXV\@
M;F\@<V5R=FED;W(@1E10(&9A;&AO=2X`0V%M<&]S(&1I<W!O;NUV96ES.@!!
M>F5R8F%I:N-O`$1E<V-U;'!A<R`B0D]&2"(`1G5N9&\`0V]R(&1O($9U;F1O
M`%!A;&%V<F$M4&%S<V4@:V5R8F5R;W,@97)R861A+@!.;VUE(&1E(%5T:6QI
M>F%D;W(@:V5R8F5R;W,@97)R861O+@!"86%M87,`0F%RZ6T`0N%L=&EC;R`H
M25-/+3@X-3DM,3,I`$)A;F=L861E8VAE`$)A<F)A9&]S`$QI;FAA(&)A<V4`
M0FEE;&]R<OIS<VEA`$+I;&=I8V$`0F5L:7IE`$)E;FEM`$)E<FUU9&$`0G5T
MXV\`06YI=F5R<^%R:6\`3R!B;&]C;R`B)7,B(&1A(&%P;&EC8>?C;R`B)7,B
M(&[C;R!F;VD@96YC;VYT<F%D;RX`0V]N9FEG=7)AY_5E<R!D92!";&]C;W,`
M5&EP;R!D92!";&]C;P!.96=R:71O`$)O;.UV:6$`36%R8V%D;W)E<P!";W)D
M80!%<W!E<W-U<F$@9&$@8F]R9&$Z`$)O<F1A<P!"\W-N:6$M2&5R>F5G;W9I
M;F$`06UB87,`0F]T<W5A;F$`0F%S90!);&AA($)O=79E=`!"<F%S:6P`5&5R
M<FET\W)I;R!"<FETXFYI8V\@9&\@3V-E86YO(,UN9&EC;P!"<G5N96D@1&%R
M=7-S86QA;0!#;VYS=')U:6YD;R!A<G%U:79O<R!-3R!P87)A(&\@;?-D=6QO
M("5S+BXN`$-O;G-T<G5I;F1O(&QO8V%L:7IAY^-O("5S+BXN(`!"=6QGX7)I
M80!,:7-T($ET96UI>F%D80!"=7)Q=6EN82!&87-O`$)U<OIN9&D`0TU3`$-2
M0P!0;VYT;W,@9&4@1&ES=')I8G5IY^-O($-23`!0<F]P<FEE9&%D97,@9&$H
M<RD@0^E?;'5L82AS*2XN+@!);FEC:6%L:7IAY^-O(&1A(")C86-H92(@;N-O
M(&9O:2!C;VYC;'7M9&$N`$-A;&5N9.%R:6\`0V%L;6\`0V%M8F]D:F$`0V%M
M87+U97,`3N-O('!O<W-O(')E:6YI8VEA<B!A('!A;&%V<F$M<&%S<V4@875T
M;VUA=&EC86UE;G1E+"!C;VYT86-T92!O('-E=2!A9&UI;FES=')A9&]R(&1E
M('-I<W1E;6%S+@!);7!O<W/M=F5L(&-O;F5C=&%R(&%O('-E<G9I9&]R($E-
M05`Z("5S`$-A;F%DX0!#86YC96QA<@!#86YC96QA<B!296QA=/-R:6\@9&4@
M4')O8FQE;6%S`$[C;R!C;VYS:6=O(')E;6]V97(@;R!F:6-H96ER;R`B)7,B
M+@!.XV\@8V]N<VEG;R!E;F-O;G1R87(@=6T@9&ER96-T\W)I;R!T96UP;W+A
M<FEO+@!);7!O<W/M=F5L(&-O;G1I;G5A<B!S96T@;R!P87+B;65T<F\@)W1A
M<F=E=$9I;&4G+@!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@82!P87-T82`B
M)7,B+@!);7!O<W/M=F5L(')E;6]V97(L(&5X:7-T96T@)60@9FEL:&]S+@!.
MXV\@Z2!P;W-S[79E;"!R96]R9&5N87(Z(&\@;OIM97)O(&1E(&5N=')A9&%S
M(&9O<FYE8VED87,@;N-O(&-O<G)E<W!O;F1E(&%O(&[Z;65R;R!G=6%R9&%D
M;RX`3N-O(&9O:2!P;W-S[79E;"!E;F-A;6EN:&%R(&$@;65N<V%G96T@<&%R
M82!O(&[Z;65R;R!I;F1I8V%D;RX`4F5P^F)L:6-A(&1E($-A8F\@5F5R9&4`
M3&5G96YD80!#871E9V]R:6%S(&4@0V]R97,`26QH87,@0V%I;>-O`%1E;&5F
M;VYE($-E;'5L87(`4')O<')I961A9&5S(&1A<R!#Z6QU;&%S`$5N8VAI;65N
M=&\@9&%S($/I;'5L87,Z`%!R;W!R:65D861E<R!D87,@8^EL=6QA<P!%<W!A
MYV%M96YT;R!D87,@8^EL=6QA<SH`5&5L96WS=F5L`$/I;'1I8V\@*$E33RTX
M.#4Y+3$T*0!#96YT<F%R`%)E</IB;&EC82!#96YT<F\@069R:6-A;F$`175R
M;W!A($-E;G1R86P@*$E33RTX.#4Y+3(I`%!O<FUE;F]R97,@9&\@0V5R=&EF
M:6-A9&\`1&]N;R!D;R!#97)T:69I8V%D;P!0;VSM=&EC87,@9&4@0V5R=&EF
M:6-A9&\`4F5P^F)L:6-A(&1O($-H861E`$%L=&5R87(`06QT97)E(&\@;F]M
M92!E(&5N9&5R9>=O('%U92!A<R!P97-S;V%S('9E<N-O('%U86YD;R!L97)E
M;2!E(')E<W!O;F1E<F5M(.!S('-U87,@;65N<V%G96YS+@!#87)A8W1E<F4`
M5F5R:5]F:6-A<B!,:6=AY^-O+BXN`$UA<G%U92!A<R!O<&5R8>?U97,@<75E
M(&1E<V5J82!E>&5C=71A<B!N97-T92!M;VUE;G1O+@!297#Z8FQI8V$@9&\@
M0VAI;&4`4F5P^F)L:6-A(%!O<'5L87(@9&$@0VAI;F$`0VAI;NIS(%-I;7!L
M:69I8V%D;W,@*$=",C,Q,BD`0VAI;NIS(%1R861I8VEO;F%L("A":6<U*0!%
M<V-O;&AA(&$@<&%L879R82UP87-S90!%<V-O;&AA('5M($YO;64@9&4@571I
M;&EZ861O<@!%<V-O;&AA(&-O;6\@;6]S=')A<B!A<R!D871A<SH`17-C;VQH
M82!O(&5S=&EL;R!D87,@;&ES=&$@*'!A<F$@;&ES=&%S(&]R9&5N861A<RD`
M26QH82!D;R!.871A;`!.XV\@9F]I(&5N8V]N=')A9&$@82!D969I;FGGXV\@
M9&$@8VQA<W-E("5S+@!,:6UP86YD;R!O<R!A<G%U:79O<R!03R!D;R!M\V1U
M;&\@)7,N+BX`3&EM<&%N9&\@82!L;V-A;&EZ8>?C;R`E<RXN+B``3&EM<&%R
M`$QI;7!A<B!E=&EQ=65T87,@9&\@35-/9F9I8V4`3&EM<&%R(&1A9&]S(&1O
M('5T:6QI>F%D;W(Z("5S`$QI;7!A<B!D861O<R!D;R!U=&EL:7IA9&]R`$QI
M;7!A<B!D861O<R!D;R!U=&EL:7IA9&]R`$QI;7!A(%1A<F1E`$-L:7%U92!P
M87)A($-O;G1I;G5A<@!#;&EC:V%T96QL('9I82!(5%10`$9E8VAA<B!J86YE
M;&$`3OIV96YS`$[Z=F5N<R!-871I;F%I<P!%;F5V;V%D;P!);&AA<R!#;V-O
M<R`H2V5E;&EN9RD`0V]L87!S87(@0F%R<F$@3&%T97)A;`!";W)D87,@0V]L
M87!S861A<P!297#Z8FQI8V$@9&$@0V]L]&UB:6$`0V]R97,`4&%L971E`%-E
M;&5CY^-O(&1E(&-O<F5R`$-O;'5N87,Z`%3M='5L;W,@9&%S(&-O;'5N87,`
M0D0`0V]M86YD;P!#;VYS;VQA(&1E($-O;6%N9&]S`$]PY_5E<R!D;R!C;VUA
M;F1O.@!#;VUA;F1O<SH`0V]M96YTX7)I;P!#;VUE=&5N9&\`3F]M92!#;VUU
M;0!#;VUO<F]S`$5M<')E<V$`17-C<F5V97(@*"5S*0!#;VUP=71A9&]R97,`
M0V]N9&GGXV\`0V]N9&GG]65S`$1I9F5R96[G87,@9&4@0V]N9FEG=7)AY^-O
M`$$@8V]N9FEG=7)AY^-O(&5S=.$@9&5S86-T=6%L:7IA9&$`0V]N9FEG=7)A
M<B`E<P!#;VYF:7)M92!A(%!A;&%V<F$M4&%S<V4`4F5P^F)L:6-A($1E;6]C
M<N%T:6-A(&1O($-O;F=O`%)E</IB;&EC82!$96UO8W+A=&EC82!D;R!#;VYG
M;P!#;VYE>.-O(&9A;&AO=2X`0V]N97CC;R!F86QH;W4Z(`!#;VYE>.-O(&%O
M('-E<G9I9&]R(&1E(&-H879E<R!P^F)L:6-A<R!R96-U<V%D82X`0V]N97CC
M;R!A;R!S97)V:61O<B!D92!C:&%V97,@</IB;&EC87,@<F5C=7-A9&$N(%)A
M>N-O.B`E<R`H)7,I`$-O;F5XXV\@86\@<V5R=FED;W(@1E10(')E8W5S861A
M+@!#;VYT86-T;W,@861I8VEO;F%D;W,@8V]M('-U8V5S<V\@86\@<V5U(&QI
M=G)O(&1E(&5N9&5R9>=O<RX`5&EP;R!D92!C;VYT9?ID;R!D;R!A<G%U:79O
M(&-O;7!R:6UI9&\Z(`!#;VYT9?ID;R!D92`E<P!#;VYT:6YU87(`26QH87,@
M0V]O:P!";VQI;FAO(&-H:6[J<P!#;W!I87(`0V]P:6%R('-E;&5CY^-O`$-O
M<&EA;F1O(&1E("5S('!A<F$@)7,`4F5P^F)L:6-A(&1A($-O<W1A(%)I8V$`
M4F5P^F)L:6-A(&1A($-O<W1A(&1O($UA<F9I;0!.XV\@9F]I('!O<W/M=F5L
M(&5N8W)I<'1A<B!A(&UE;G-A9V5M(&-O;2!01U`N`$[C;R!F;VD@<&]S<^UV
M96P@87-S:6YA<B!A(&UE;G-A9V5M(&-O;2!01U`N`$[C;R!F;VD@<&]S<^UV
M96P@96YC<FEP87(@82!M96YS86=E;2!C;VT@4R]-24U%+@!.XV\@9F]I('!O
M<W/M=F5L(&%S<VEN87(@82!M96YS86=E;2!C;VT@4R]-24U%+@!.XV\@9F]I
M('!O<W/M=F5L(&%D:6-I;VYA<B!O(&-O;G1A8W1O+B`E<P!&86QH82!N82!L
M:6=AY^-O("AB:6YD*2!A;R!S97)V:61O<B!,1$%0+@!.XV\@9F]I('!O<W/M
M=F5L('9E<FEF:6-A<B!O('-A;&1O+B`E<P!.XV\@9F]I('!O<W/M=F5L(&-O
M;F5C=&%R(&%O('-E<G9I9&]R("(E<R(@=7-A;F1O($944#H@)7,`3N-O(&9O
M:2!P;W-S[79E;"!C;W!I87(@)7,@<&%R82`E<P!.XV\@9F]I('!O<W/M=F5L
M(&-R:6%R(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,`3N-O(&9O:2!P;W-S
M[79E;"!C<FEA<B!P87-T82!D92!L;V-A;&EZ8>?C;R!P87)A(&$@;&]C86QI
M>F'GXV\@)7,Z`$[C;R!F;VD@<&]S<^UV96P@9&5S96YC<FEP=&%R(&]S(&1A
M9&]S(&-O;2!O(%!'4"X`3N-O(&9O:2!P;W-S[79E;"!D97-E;F-R:7!T87(@
M;W,@9&%D;W,@8V]M(%,O34E-12X`3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R
M(&-O;G1A8W1O+B`E<P!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@;&ES=&$@
M9&4@9&ES=')I8G5IY^-O+B`E<P!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@
M;R`B<V-R:7!T(B!D92!A8W1U86QI>F'GXV\@(B5S(BX`3N-O(&9O:2!P;W-S
M[79E;"!D971E<FUI;F%R(&\@96YD97)EYV\@9&4@8V]R<F5I;R!E;&5C='+S
M;FEC;R!D;R!D97-T:6YA=.%R:6\N`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@
M;R!L:79R;R!D92!E;F1E<F7G;W,@8V]M<&QE=&\N`$[C;R!F;VD@<&]S<^UV
M96P@;V)T97(@82!L:7-T82!D92!D:7-T<FEB=6GGXV\@8V]M<&QE=&$N`$[C
M;R!F;VD@<&]S<^UV96P@;V)T97(@82!L:7-T82!C;VUP;&5T82!D87,@;&ES
M=&%S(&1E(&1I<W1R:6)U:>?C;RX`26UP;W-S[79E;"!C87)R96=A<B!E<W1R
M873I9VEA("(E<R(N`$EM<&]S<^UV96P@;6MD:7(@(B5S(BX`3N-O(&9O:2!P
M;W-S[79E;"!O8G1E<B!A(&-H879E('#Z8FQI8V$@82!P87)T:7(@9&\@<V5R
M=FED;W(@9&4@8VAA=F5S('#Z8FQI8V%S+@!.XV\@9F]I('!O<W/M=F5L(&%B
M<FER("(E<R(@<&%R82!E<V-R:71A+@!.XV\@9F]I('!O<W/M=F5L(&%B<FER
M("5S+@!.XV\@9F]I('!O<W/M=F5L(&%B<FER(&\@;?-D=6QO(&1E($UA;G5T
M96[GXV\@9&4@5&%R969A<R`E<P!.XV\@9F]I('!O<W/M=F5L(&%B<FER('!A
M<W1A("(E<R(N`$[C;R!F;VD@<&]S<^UV96P@;&5R("5S+@!.XV\@9F]I('!O
M<W/M=F5L(')E:6YI8VEA<B!A('!A;&%V<F$M<&%S<V4@9&\@=71I;&EZ861O
M<B!I;F1I8V%D;RX@06QG=6T@;W4@=&]D;W,@;W,@<&]R;65N;W)E<R!NXV\@
M97-T879A;2!C;W)R96-T;W,N(%!O<B!F879O<B!T96YT92!D92!N;W9O(&]U
M(&-O;G1A8W1E(&\@<V5U(&%D;6EN:7-T<F%D;W(@9&4@<VES=&5M87,@<V4@
M<')E8VES87(@9&4@;6%I<R!A:G5D82X`3N-O(&9O:2!P;W-S[79E;"!O8G1E
M<B!!0TP`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!L:79R;R!D92!E;F1E<F7G
M;W,N("5S`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@;&ES=&$@9&4@9&ES=')I
M8G5IY^-O+B`E<P!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&QI<W1A<R!D92!D
M:7-T<FEB=6GGXV\N("5S`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@87,@8V]M
M<&5TZFYC:6%S(&1O('-E<G9I9&]R`$[C;R!F;VD@<&]S<^UV96P@<F5V97)T
M97(@82!C;VYF:6=U<F'GXV\N`$EM<&]S<^UV96P@<FUD:7(@(B5S(BX`3N-O
M(&9O:2!P;W-S[79E;"!G=6%R9&%R(&$@8V]N9FEG=7)AY^-O(&1E("5S+@!.
MXV\@9F]I('!O<W/M=F5L(&=U87)D87(@82!C;VYF:6=U<F'GXV\@9&4@<V%L
M=F%G=6%R9&$N`$[C;R!F;VD@<&]S<^UV96P@9W5A<F1A<B!A(&-O;F9I9W5R
M8>?C;R!D92!S86QV86=U87)D83H@)7,`3N-O(&9O:2!P;W-S[79E;"!G=6%R
M9&%R(&\@(G-C<FEP="(@9&4@86-T=6%L:7IAY^-O(&5M.B`B)7,B+@!.XV\@
M9F]I('!O<W/M=F5L(&=U87)D87(@82!C;VYF:6=U<F'GXV\@9&4@<V%L=F%G
M=6%R9&$@)7,N`$[C;R!F;VD@<&]S<^UV96P@9W5A<F1A<B!O(&%R<75I=F\@
M9&4@8V]N9FEG=7)AY^-O("5S+B!0;V1E('5S87(@=6UA(&1A<R!O<.?U97,@
M<&%R82!G=6%R9&%R(&\@8_-D:6=O(&5M("5S(&]U(&-O<&EA<B!M86YU86QM
M96YT92!O(&/S9&EG;R!A8F%I>&\@<&%R82`E<RX`3N-O(&9O:2!P;W-S[79E
M;"!P<F]C=7)A<B!N;R!S97)V:61O<B!,1$%0+@!.XV\@9F]I('!O<W/M=F5L
M(&1E<VQI9V%R("(E<R(N`$[C;R!F;VD@<&]S<^UV96P@86-T=6%L:7IA<B!C
M;VYT86-T;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!A8W1U86QI>F%R(&$@;&ES
M=&$@9&4@9&ES=')I8G5IY^-O+B`E<P!.XV\@9F]I('!O<W/M=F5L(&5S8W)E
M=F5R(&$@8V]N9FEG=7)AY^-O('!A<F$@(B5S(CH@)7,`3N-O(&5N8V]N=')E
M:2!A($)A<G)A($QA=&5R86P@9&\@36]Z:6QL82X@07-S96=U<F4M<V4@<75E
M(&$@8F%R<F$@;&%T97)A;"!E<W3A(&%B97)T82X`3N-O(&9O:2!P;W-S[79E
M;"!A=')I8G5I<B!A;R!U=&EL:7IA9&]R("(E<R(@;W,@<V5G=6EN=&5S(&1I
M<F5I=&]S('-O8G)E(&$@<&%S=&$@(B5S(CH@)7,`5&5X=&\@0V]N=&%D;P!0
M8>US`$-U<G-O<P!#<FEA<@!#<FEA<B!U;6$@;&EG8>?C;P!#<FEA<B!U;6$@
M;F]V80!#<FEA<B!S=6(M<&%S=&%S`%!E<FUI<W/U97,@9&\@0W)I861O<@!.
M^FUE<F\@9&\@8V%R=.-O(&1E(&-RZ61I=&\`4F5P^F)L:6-A(&1A($-R;^%C
M:6$`4F5P^F)L:6-A(&1E($-U8F$`475A=')O(&9A<V5S(&-O<G)E;G1E<P!$
M871A+TAO<F$`55),(&-O<G)E;G1E(.D`17-T861O(&1O(%1E;7!O`%-I='5A
MY^-O(&%C='5A;#H@`$5S=&EL;R!A8W1U86P`4&5R<V]N86QI>F%R(&%S('1A
M<F5F87,@<75E('-E<N-O(&5X96-U=&%D87,@87%U86YD;R!O(&QO9VEN(&YO
M("5S+@!#;W)T87(`0V]R=&%R(&$@<V5L96/GXV\`4F5P^F)L:6-A(&1E($-H
M:7!R90!#:7+M;&EC;R`H2T])."U2*0!#:7+M;&EC;R`H5VEN9&]W<RTQ,C4V
M*0!#:7+M;&EC;R]58W)A;FEA;F\@*$M/23@M52D`4F5P^F)L:6-A($-H96-A
M`$1$`$1I87)I86UE;G1E`$YA=F5G861O<B!D92#!<G9O<F4@9&4@1&%D;W,`
M1&%T80!$871A(&1E(%)E8V5PY^-O`%-E;&5CY^-O(&1E(&1A=&$`1&EA`%)E
M;6]V97(@0V]?;'5N80!$97IE;6)R;P!.^FUE<F]S(&1E8VEM86ES`%)E9'5Z
M:7(@:6YD96YT8>?C;P!0;W(@3VUI<W/C;P!#;W(@4&]R($]M:7-SXV\`261E
M;G1I9&%D92!0861RXV\`4&5R;6ES<_5E<R!0;W(@3VUI<W/C;P!097)M:7-S
M]65S('!O<B!O;6ES<^-O`$1E9FEN:>?U97,`4F5M;W9E<@!296UO=F5R($=R
M=7!O`%)E;6]V97(@4&5R;6ES<^-O`%)E;6]V97(@92!P=7)G87(@;65N<V%G
M96YS`%)E;6]V97(@8^EL=6QA`%)E;6]V97(@8V]L=6YA`%)E;6]V97(@;6]D
M96QO(&%L=&5R;F%T:79O(&5X:7-T96YT90!296UO=F5R('!E<FUI<W/U97,@
M9&4@(B5S(@!296UO=F5R('!E<FUI<W/U97,@<&%R82`G)7,G(&4@<75A:7-Q
M=65R('-U8BUP97)M:7-S]65S/P!296UO=F5R(&QI;FAA`%)E;6]V97(@:61E
M;G1I9&%D92!S96QE8V-I;VYA9&$`4F5M;W9E<B!A(&-O;'5N82!C;W)R96YT
M90!296UO=F5R(&$@;&EN:&$@8V]R<F5N=&4`4F5M;W9E<B!E<W1A('!E<FUI
M<W/C;R!E('1O9&%S(&%S('-U87,@<W5B+7!E<FUI<W/U97,_`")38W)I<'0B
M(&1E(&%C='5A;&EZ8>?C;R`B)7,B(')E;6]V:61O+@!-;VUE;G1O(&1E(&5N
M=')E9V$`1&EN86UA<F-A`$1E<V-R979A(&\@4')O8FQE;6$`1&5S8W)IY^-O
M`%!O<FUE;F]R97,@*'1A;6+I;2!N;R!R96=I<W1O+"`B;&]G(BP@9&\@2&]R
M9&4I.@!/<R!D971A;&AE<R!F;W)A;2!E;G9I861O<R!P87)A(&\@861M:6YI
M<W1R861O<B!D;R!S:7-T96UA+@!$97-E;G9O;'9I;65N=&\`4&]N=&\@9&4@
M3W)V86QH;P!0;VYT;R!D92!/<G9A;&AO(&YA(/IL=&EM82!H;W)A.B``4&]N
M=&\@9&4@;W)V86QH;SH@`$1I<F5CY^-O(&1A(&5S<75E<F1A('!A<F$@82!D
M:7)E:71A`$1I<F5CY^-O(&1A(&1I<F5I=&$@<&%R82!A(&5S<75E<F1A`$1I
M<F5C=/-R:6\`36]S=')A<B!T96UP;W,@8V]M(#(T(&AO<F%S/P!/<.?U97,@
M9&4@5FES=6%L:7IAY^-O`$UO<W1R87(@<')E=FESXV\@<&]R;65N;W)I>F%D
M80!-;W-T<F%R('!R979I<^-O("A4048I`$9O<FUA=&\@9&4@=FES=6%L:7IA
MY^-O`$YO=&EF:6-AY^-O(&1E($1I<W!O<VGGXV\`1&II8G5T:0!.XV\@<F5M
M;W9E<@!.XV\@=71I;&EZ92!O(&UA:6YT96YA;F-E+G!H<"!D:7)E8W1A;65N
M=&4`02!P<FEM96ER82!L:6YH82!C;VYTZ6T@;W,@;F]M97,@9&]S(&-A;7!O
M<S\@4V4@<VEM+"!A<W-I;F%L87(@97-T82!C86EX83H`1&]M:6YI8V$`4F5P
M^F)L:6-A($1O;6EN:6-A;F$`4F5C96)E<@!296-E8F5R("5S`$1E<V-A<G)E
M9V%R(&$@8V]N9FEG=7)AY^-O(&=E<F%D82!C;VUO('5M(")S8W)I<'0B(%!(
M4"X`3&ES=&$@9&4@9&5S96YR;VQA<@!$<F]G87,`0V]R<F5I;R!E;&5C='+S
M;FEC;P!%4E(`4F5P^F)L:6-A(&1O($5Q=6%D;W(`161I=&%R`$5D:71A<B!"
M;&]C;P!%9&ET87(@1W)U<&\`161I=&%R(%!E<FUI<W/U97,`161I=&%R(%!E
M<FUI<W/U97,`161I=&%R('!E<FUI<W/U97,@9&4@)7,`161I=&%R(&]PY_5E
M<R!D93H`161I=&%R('!E<FUI<W/U97,@9&4@(B5S(@!%9&ET87(@<&5R;6ES
M<_5E<R!D92`E<P!%9'5C8>?C;P!%9VEP=&\`4F5P^F)L:6-A(&1E($5L(%-A
M;'9A9&]R`$5L96UE;G1O+BXN`$5M`$-O<G)E:6\@16QE8W1R\VYI8V\`16YD
M97)EYV\@9&4@0V]R<F5I;R!%;&5C='+S;FEC;P!/<R!E;F1E<F7G;W,@=.IM
M('%U92!C;VEN8VED:7(N`$UE;G-A9V5M(&-O;2!C;VYF:7)M8>?C;P!3[6UB
M;VQO<R!D92!%;6_GXV\`365N<V%G96T@=F%Z:6$N`%-E;2!R97-U;'1A9&]S
M+@!396T@=&5R;6]S(&1E('!R;V-U<F$`06-T:79A<B!I;G-E<N?C;R!D92!I
M;6%G96YS(&1E($=A;&5R:6%S($9O=&]G<N%F:6-A<R!N;R!T97AT;S\`06-T
M:79A<B!M96YU(&1E(&-O;G1E>'1O(&YO(&)O=.-O(&1I<F5I=&\@9&\@<F%T
M;S\`06YO(&1E(&9I;0!!=6UE;G1A<B!%9&ET;W(`26YT<F]D=7IA('5M82!P
M97)G=6YT82!D92!S96=U<F%NYV$@<75E('-E<N$@8V]N=FED861O(&$@<F5S
M<&]N9&5R('-E('!R96-I<V%R(&1E(')E:6YI8VEA<B!A('-U82!P86QA=G)A
M+7!A<W-E+"!E+F<N+"`G8V]M;R!S92!C:&%M82!O('-E=2!A;FEM86P@9&4@
M97-T:6UAY^-O/R<Z`$EN=')O9'5Z82!O(%523"!D82!I;6%G96T@87%U:0!%
M;G1R861A<SH@)60@=&]T86PL("5D(&%C='5A;&EZ861A<RP@)60@;F]V87,L
M("5D(&%L=&5R861A<RP@)60@9&5S8V]N:&5C:61A<P!'=6ENZ2!%<75A=&]R
M:6%L`$5S=&%D;R!D82!%<FET<F5I80!%<G)O`$5R<F\@;F$@;65N<V%G96T@
M9&4@8V]R<F5I;R!E;&5C='+S;FEC;RX`17)R;R!A;R!E<V-R979E<B`B)7,B
M+@!%<G)O.B``4F5P^F)L:6-A(&1A($5S=/-N:6$`4F5P^F)L:6-A($1E;6]C
M<N%T:6-A($9E9&5R86P@9&$@171I\W!I80#)=&EC;P!%=7)O<&$`0V%D82`Q
M-2!M:6YU=&]S`$-A9&$@,B!M:6YU=&]S`$-A9&$@,S`@<V5G=6YD;W,`0V%D
M82`U(&UI;G5T;W,`0V%D82!%;G1R861A`$-A9&$@;65I82!H;W)A`$-A9&$@
M;6EN=71O`%9A;&]R97,@97AE;7!L;SH`17AE8W5T87(`17AE8W5T86YD;SH`
M17AP86YD:7(`36]S=')A<B!"87)R82!,871E<F%L`"<I)R!E<W!E<F%D;P!%
M<W!E<F%V82!U;6$@<VEM<&QE<R!P86QA=G)A(&]U('5M('1E<FUO(&1E('!R
M;V-U<F$@96YT<F4@87-P87,`1&%T82!D92!%>'!I<F'GXV\`17AP;V5N=&4`
M17AT<F%I;F1O(&1E("5S+BXN(`!#;W(@9&\@4')I;65I<F\@4&QA;F\`0V%R
M<F5G87(@8V]N9FEG=7)AY^-O(&1E(&EN<W1A;&'GXV\@<&]R($944`!.XV\@
M9F]I('!O<W/M=F5L('!U>&%R(&%S('!R969E<NIN8VEA<RX`1F%L:&$@;F$@
M;&EG8>?C;R!A;R!S97)V:61O<B!,1$%0+@!&86QH82!N82!L:6=AY^-O(&%O
M('-E<G9I9&]R(%--0BX`1F%L:&$@86\@8V]P:6%R(&1E("(E<R(N`$9A;&AA
M(&%O(&-O<&EA<B!P87)A("(E<R(N`$9A;&AA(&%O(&-R:6%R('5M82!N;W9A
M(&-O;F5XXV\@4T%33"X`1F%L:&$@86\@;6]V97(@<&%R82`B)7,B+@!";VT`
M26QH87,@1F%L:VQA;F0@*$UA;'9I;F%S*0!);&AA<R!&87)O90!%<G)O($9A
M=&%L.@!&87@`1F5V97)E:7)O`$%P87)E;G1A`$%P87)E;G1A.B``06QG=6YS
M($%G=6%C96ER;W,`06QG=6YS($YE=O5E<P!-871R:7H@9&4@8V%M<&]S`$9I
M:FD`0V]N=&%G96T@9&4@07)Q=6EV;W,Z("5S(&%R<75I=F\`0V]N=&%G96T@
M9&4@07)Q=6EV;W,Z("5S(&%R<75I=F]S`$=E<W3C;R!D92!&:6-H96ER;W,`
M3F]M92!D;R!!<G%U:79O`%-E;&5CY^-O(&1O(&%R<75I=F\`0V%R<F5G86UE
M;G1O(&1E(&%R<75I=F\`0V%R<F5G86UE;G1O<R!D92!F:6-H96ER;W,@;N-O
M('/C;R!S=7!O<G1A9&]S+@!&:6QT<F]S`$9I;FSB;F1I80!1=6%R=&\@0W)E
M<V-E;G1E`%%U87)T;R!#<F5S8V5N=&4`1FEX87(@<N%C:6\`26YV97)T97(`
M1FQU='5A;G1E`$YE=F]E:7)O`$$@<&%S=&$@)7,@;N-O(&5X:7-T92X`0V]R
M(&1O(%1E>'1O`$-O;6ED80!087)A(&YA=F5G861O<F5S('%U92!NXV\@<W5P
M;W)T86T@:6UA9V5N<P!0<F5V:7/C;R`H5$%&*0!$:6%S(&1E(%!R979I<^-O
M("AN;W1E+7-E('%U92!A<R!P<F5V:7/U97,@:6YC;'5E;2!T86YT;R!D:6%S
M(&-O;6\@;F]I=&5S.R!U;2!V86QO<B!D96UA<VEA9&\@9W)A;F1E('!O9&4@
M<F5S=6QT87(@;G5M(&)L;V-O(&UU:71O(&QA<F=O*0!%<W%U96-E=2US92!D
M82!P86QA=G)A+7!A<W-E/P!-;V1E;&]S`$1I=&]S`%1I<&\@9&4@9&ET;W,`
M1&ET;W,`1&ET;W,@,@!&\W)U;G,`4F5E;G9I;W,`07!L:6-AY_5E<R`H;?-D
M=6QO<RD@96YC;VYT<F%D87,Z("5S`%!A<W1A<R!E;F-O;G1R861A<SH`-JH`
M36]L9'5R87,`4F5P^F)L:6-A($9R86YC97-A`$9R86[G82P@365T<F]P;VQI
M=&%N80!'=6EA;F$@1G)A;F-E<V$`4&]L:6[I<VEA($9R86YC97-A`%1E<G)A
M<R!!=7-T<F%I<R!E($%N=.%R8W1I8V%S($9R86YC97-A<P!$90!$92``1&5S
M8W)IY^-O($-O;7!L971A`$QU82!#:&5I80!.;VUE($-O;7!L971O`$1I9G5S
M87,`4F5P^F)L:6-A($=A8F]N97-A`$=A;&5R:6$@9&4@;VYD92!R971I<F%R
M(&$@:6UA9V5M`$=A;&5R:6$Z`%)E</IB;&EC82!D82!'XFUB:6$`1V5R87(@
M0V]N9FEG=7)AY^-O("5S`$/S9&EG;R!'97)A9&\`1V5R86YD;R!O(&5S=&%D
M;R!D;R!M\V1U;&\@)7,N+BX`1V7S<F=I80!297#Z8FQI8V$@1F5D97)A;"!D
M82!!;&5M86YH80!%<G)O(&5M(&=E=&]P=#H`4F5P^F)L:6-A(&1O($=A;F$`
M1VEB<F%L=&%R`$YO;64@4'+S<')I;P!)<@!']F1E;`!097-Q=6ES82!';V]G
M;&4`3NUV96ES(&1E(&-I;GIE;G1O`$=RZ6-I80!'<F5G;R`H25-/+3@X-3DM
M-RD`1W)O;F5LXFYD:6$`1W)A;F%D80!!9&UI;FES=')AY^-O(&1E($=R=7!O
M<P!.;VUE<R!D92!G<G5P;W,@;N-O('!O9&5M(&5S=&%R('9A>FEO<P!097)M
M:7-S]65S(&1E(&=R=7!O`$=R=7!O<P!'=6%D86QU<&4`1W5A;0!297#Z8FQI
M8V$@9&$@1W5A=&5M86QA`$=U97)N<V5Y`%!E<FUI<W/U97,@9&%S(%9I<VET
M87,`4&5R;6ES<_5E<R!D87,@5FES:71A<P!,:79R;R!D92!6:7-I=&%S`$=U
M:6[I`$=U:6[I+4)I<W-A=0!297#Z8FQI8V$@0V\M;W!E<F%T:79A(&1A($=U
M:6%N80!(5$U,`$\@2%1-3$%R96$@<F5C=7-A+7-E(&-O8F%R9&5M96YT92!A
M(')E;6]V97(@82#Z;'1I;6$@8^EL=6QA(&1A(&QI;FAA+@!/($A434Q!<F5A
M(')E8W5S82US92!C;V)A<F1E;65N=&4@82!R96UO=F5R(&$@^FQT:6UA(&-O
M;'5N82!D82!T86)E;&$N`$\@2%1-3$%R96$@<F5C=7-A+7-E(&-O8F%R9&5M
M96YT92!A(')E;6]V97(@82#Z;'1I;6$@;&EN:&$@9&$@=&%B96QA+@!!=71E
M;G1I8V'GXV\@2%104"!NXV\@9F]I(&5N8V]N=')A9&$N`%)E</IB;&EC82!D
M;R!(86ET:0!!;&=O<FET;6\@9&4@(DAA<V@B`$YE8FQI;F$`0V%B9>=A;&AO
M`$EL:&%S($AE87)D(&4@36-$;VYA;&0`5&5M<&]R86PM5"!&;W)T90!(96)R
M974@*$E33RTX.#4Y+3@M22D`06QT=7)A`$%J=61A`$%J=61A('-O8G)E(&\@
M961I=&]R`$%J=61A`$%P;&EC8>?C;R!A=7AI;&EA<B!P87)A(&-R:6%R(&4@
M;6%N=&5R('1R861UY_5E<R!D82!P;&%T869O<FUA"DAO<F1E(&4@9&%S('-U
M87,@87!L:6-AY_5E<R`H;?-D=6QO<RDN"E!A<F$@=6UA(&EN=')O9'7GXV\@
M;&5R(&\@9FEC:&5I<F\@4D5!1$U%(&YE<W1A('!A<W1A+@!(96UI<V;I<FEO
M`$%Q=6D@97-TX2!O(&EN[6-I;R!D;R!A<G%U:79O.@!!;'1A`$YO;65S(&1A
M<R!E;G1R861A<R!H:7-T\W)I87,@;N-O('!O9&5M(&5S=&%R('9A>FEO<P!#
M85]S80!%<W1A9&\@9&$@0VED861E(&1O(%9A=&EC86YO`$-A<V$`16YD97)E
MYV\@9&4@0V%S80!496QE9F]N92!D92!#87-A`%)E</IB;&EC82!D87,@2&]N
M9'5R87,`2&]N9W5E8V]N9W5E`$AO<F1E`$=E<F%D;W(@9&4@=')A9'7G]65S
M($AO<F1E`$AO<F1E+TMO;&%B.B!$861O<R!834P@)7,@:6YVX6QI9&]S(&YA
M(&UE;G-A9V5M("5S`$AO<F1E+TMO;&%B.B!.96YH=6UA(&UE;G-A9V5M(&-O
M<G)E<W!O;F1E(&%O(&]B:F5C=&\@)7,`2&]R9&4O2V]L86(Z($YE;FAU;2!O
M8FIE8W1O(&1O('1I<&\@)7,@96YC;VYT<F%D;R!N82!M96YS86=E;2`E<P!(
M;W)D92]+;VQA8CH@4F5M;^?C;R!D92`E<R`B)7,B('1E=F4@<W5C97-S;P!(
M;W)D92]+;VQA8CH@4VEN8W)O;FEZ8>?C;R!D92`E<R`B)7,B('1E=F4@<W5C
M97-S;P!(;W)D92]+;VQA8CH@3R!M;W1O<B!D92!I;G1E9W)AY^-O(')E<75E
M<B!A(&5X=&5N<^-O(%!(4"`G9&]M>&UL)P!(;W)D92]+;VQA8CH@3N-O(&9O
M:2!P;W-S[79E;"!C<FEA<B!U;6$@;F]V82#A<G9O<F5S(%A-3"!P87)A(&\@
M;V)J96-T;R`E<P!(;W)D92]+;VQA8CH@3N-O(&9O:2!P;W-S[79E;"!R96UO
M=F5R("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!.XV\@9F]I('!O<W/M=F5L
M(&]B=&5R(&\@240@34E-12!P87)A(&$@<&%R=&4@9&4@=&EP;R`E<P!(;W)D
M92]+;VQA8CH@3N-O(&9O:2!P;W-S[79E;"!S:6YC<F]N:7IA<B`E<R`B)7,B
M.B`E<P!(;W)D92]+;VQA8CH@3N-O(&9O:2!P;W-S[79E;"!S:6YC<F]N:7IA
M<B!P87)T:6QH87,Z("5S`$AO<F1E+TMO;&%B.B!087)T:6QH82`B)7,B(&1E
M<V-O;FAE8VED80!4<F'G;R!(;W)I>F]N=&%L`$5N8VAI;65N=&\@:&]R:7IO
M;G1A;`!(;W)I>F]N=&%L.@!#;VUO(&-H96=O=2!A<75I/R`H4&]R(&9A=F]R
M(')E<&]R=&4M;R$I`%%U86YT87,@8V]L=6YA<R!P<F5T96YD92!J=6YT87(_
M`%%U86YT;W,@8V%M<&]S("AC;VQU;F%S*2!E>&ES=&5M/P!1=6%N=&%S(&QI
M;FAA<R!P<F5T96YD92!J=6YT87(_`$AU;6ED861E`$AU;6ED861E.B``2'5M
M;W)I<W1A<P!297#Z8FQI8V$@9&$@2'5N9W)I80!!(&-R:6'GXV\@9&$@8V%I
M>&$@<&]S=&%L($E-05`@9F%L:&]U.B`E<P!296UOY^-O(&1A(&-A:7AA('!O
M<W1A;"!)34%0(&9A;&AO=3H@)7,`0W)I8>?C;R!D92!Q=6]T82!D92!C86EX
M82!P;W-T86P@24U!4"!F86QH;W4Z("5S`$5N9&5R9>=O($E0`$5N9&5R9>=O
M($E0(&EN9&ES<&]N[79E;"X`16YD97)EYV\@25`@9F]R82!D;R!B;&]C;R!#
M2412('!E<FUI=&ED;RX`5FEO;&'GXV\@9&4@8FQO<75E:6\@9&4@25``25]N
M<V5R:7(@3&EN:&$@06YT97,`4F5P^F)L:6-A(&1A($ES;.)N9&D`07!E;F%S
M(,UC;VYE<P#-8V]N97,@8V]M(%1E>'1O`$YO;64@9&$@:61E;G1I9&%D93H`
M4V4@;N-O(&9O<B!M;W-T<F%D;R!C;W)R96-T86UE;G1E+"`E<R!P87)A(&\@
M86)R:7(@;G5M82!N;W9A(&IA;F5L82X`4V4@;N-O('9I<B!Q=6%L<75E<B#M
M8V]N92!A;R!U<V%R(&\@26YT97)N970@17AP;&]R97(L('!O9&4@<')E8VES
M87(@9&4@<V5L96-C:6]N87(@97-T82!C86EX82!P87)A(&1E<VQI9V%R(&$@
M=')A;G-P87+J;F-I82X`4V4@=FER(&5S=&$@;65N<V%G96T@;FUA<R!NXV\@
M82!I;6%G96T@<')O<')I86UE;G1E(&1I=&$L(&$@:6UA9V5M('%U92!P<F5T
M96YD92!C87)R96=A<B!NXV\@<&]D92!S97(@;6]S=')A9&$@<&5L;R!S974@
M;F%V96=A9&]R+@!0<F5V:7/C;R!D82!);6%G96TZ`%523"!D82!I;6%G96T`
M55),(&1A(&EM86=E;3H`26UA9V5M(&1E(&=A;&5R:6$`26UA9V5M(&1E(&=A
M;&5R:6$Z`$-A<G)E9V%M96YT;R!D82!I;6%G96T`26UA9V5N<P!);7!O<G1A
M<BP@4&%S<V\@)60`0V%M<&\@:6UP;W)T861O.B`E<P!#86UP;W,@:6UP;W)T
M861O<SH`26Y?<V5R:7(@3&EN:&$@1&5P;VES`$/S9&EG;R!D92!A8^?C;R!I
M;G1R;V1U>FED;R!E<W3A(&EN8V]R<F5C=&\N`$YO;64@9&4@=71I;&EZ861O
M<B!O=2!P86QA=G)A+7!A<W-E(&5R<F%D;W,N`$YO;64@9&4@=71I;&EZ861O
M<B!O=2!E;F1E<F7G;R!A;'1E<FYA=&EV;R!E<G)A9&]S+B!#;VYT86-T92!O
M('-E=2!A9&UI;FES=')A9&]R(&1E('-I<W1E;6$@<&%R82!O8G1E<B!A:G5D
M82X`075M96YT87(@82!);F1E;G1AY^-O`%)E</IB;&EC82!D82#-;F1I80!5
M=&EL:7IA9&]R97,@26YD:79I9'5A:7,`4F5P^F)L:6-A(&1A($EN9&]NZ7-I
M80!);F9O<FUAY^-O`$EN9F]R;6'GXV\`26YF;W)M8>?C;R!JX2!NXV\@97-T
MX2!D:7-P;V[M=F5L`$EN:6-I86QI>F%N9&\@;R!M\V1U;&\@)7,N+BX@`$EN
M<V5R:7(@0U]O;'5N82!$97!O:7,`26YS97)I<B!);6%G96T`26YS97)I<B!4
M86)E;&$`26YS97)I<B!,:6=AY^-O(.`@5V5B`$EN<V5R:7(@7T-O;'5N82!!
M;G1E<P!);G-I<FER('5M82!N;W9A(&-O;'5N82!D97!O:7,@9&$@8V]R<F5N
M=&4`26YS:7)I<B!U;6$@;F]V82!C;VQU;F$@86YT97,@9&$@8V]R<F5N=&4`
M26YS:7)I<B!U;6$@;F]V82!L:6YH82!D97!O:7,@9&$@8V]R<F5N=&4`26YS
M:7)I<B!U;6$@;F]V82!L:6YH82!A;G1E<R!D82!C;W)R96YT90!);G-E<FER
M('5M('!A<N%G<F%F;R!A</-S(&\@;O,@8V]R<F5N=&4`26YS97)I<B!U;2!P
M87+A9W)A9F\@86YT97,@9&\@;O,@8V]R<F5N=&4`26YS:7)I<B!M;V1E;&\@
M86QT97)N871I=F\`26YT<F]D=7IA('5M(&5N9&5R9>=O(&1E(&-O<G)E:6\@
M96QE8W1R\VYI8V\@;VYD92!P;W-S82!R96-E8F5R(&$@;F]V82!P86QA=G)A
M+7!A<W-E.@!);G-I<FER(&/I;'5L82!A</-S`$EN<V5R:7(@8^EL=6QA<R!A
M;G1E<P!);G-E<FER(&/I;'5L82!D97!O:7,`26YS97)I<B!C;VQU;F$@86YT
M97,`26YS97)I<B!M96YS86=E;G,`26YS97)I<B!P87+A9W)A9F\@86YT97,`
M26YS97)I<B!P87+A9W)A9F\@86YT97,`26YS97)I<B!L:6YH82!D97!O:7,`
M26YS97)I<B!L:6YH82!A;G1E<P!);G1R;V1U>F$@82!R97-P;W-T82!E>&EG
M:61A('!A<F$@82!P97)G=6YT82!D92!S96=U<F%NYV$Z`$EN<V5R:7(O36]D
M:69I8V%R($EM86=E;0!);G-E<FER+TUO9&EF:6-A<B!,:6=AY^-O`$-RZ61I
M=&\@:6YS=69I8VEE;G1E('!A<F$@96YV:6%R('!A<F$@82!L:7-T82!D92!D
M:7-T<FEB=6GGXV\N`$-RZ61I=&\@:6YS=69I8VEE;G1E+@!);G1E:7)O`$QI
M<W1A(&1E(&EN=&5I<F]S`%5$2"`H57-E<B!$871A($AE861E<BD@:6YVX6QI
M9&\N`$1A9&]S(%I)4"!I;G;A;&ED;W,`07!L:6-AY^-O(&EN=N%L:61A+@!)
M1"!D92!L;W1E("@B8F%T8V@B*2!I;G;A;&ED;RX`3W,@9&%D;W,@<W5B;65T
M:61O<R!SXV\@:6YVX6QI9&]S+@!%;F1E<F7G;R!D92!D97-T:6YO(&EN=N%L
M:61O+@!&;W)M871O(&1O(&%R<75I=F\@:6YVX6QI9&\`0VAA=F4@9&$@;&EC
M96[G82!I;G;A;&ED82X`3&]C86QI>F'GXV\@:6YVX6QI9&$@97-P96-I9FEC
M861A+@!M<V=?='EP92!I;G;A;&ED;RX`87!I7VED(&EN=N%L:61O(&]U(&5M
M(&9A;'1A+@!087+B;65T<F]S(&EN=N%L:61O<R!O=2!E;2!F86QT82X`4&5R
M;6ES<^-O('!A<F5N=&%L(&EN=N%L:61A+@!)1"!D92!P87)C96ER;R!I;G;A
M;&ED;RX`0_-D:6=O(&1E('!R;V1U=&\@:6YVX6QI9&\N`%!R;W1O8V]L;R!I
M;G;A;&ED;RX`1&5S=&EN873A<FEO(&EN=N%L:61O.B`B)7,B`$]B:F5C=&\@
M9&4@<&%R=&EL:&$@:6YVX6QI9&\`16YD97)EYV\@9&$@;W)I9V5M(&EN=N%L
M:61O+@!$861O<R!U;FEC;V1E(&EN=N%L:61O<RX`26YV96YTX7)I;P!297#Z
M8FQI8V$@27-LXFUI8V$@9&\@27+C;P!297#Z8FQI8V$@9&\@27)A<75E`%)E
M</IB;&EC82!D82!)<FQA;F1A`$EL:&$@9&4@36%N`%1E;7!O<F%I<RU4($ES
M;VQA9&]S`$5S=&%D;R!D92!)<W)A96P`16UI<W-O<@!)=.%L:6-O`%)E</IB
M;&EC82!)=&%L:6%N80!*86UA:6-A`$IA;F5I<F\`2F%PXV\`2F%P;V[J<R`H
M25-/+3(P,C(M2E`I`$IE<G-E>0!296EN;R!(87-H96UI=&$@9&$@2F]R9.)N
M:6$`2G5L:&\`2G5N:&\`2G5S=&EF:6-A<@!#96YT<F%R`$IU<W1I9FEC87(`
M2G5S=&EF:6-A<B#@($5S<75E<F1A`$IU<W1I9FEC87(@X"!$:7)E:71A`%)E
M</IB;&EC82!D;R!#87IA<75I<W3C;P!0<F5S97)V87(@;R!O<FEG:6YA;#\`
M4F5P^F)L:6-A(&1O(%%UZ6YI80!/('-E<G9I9&]R($ME<F)E<F]S(')E:F5I
M=&]U(&$@875T96YT:6-AY^-O+@!.;W9A=&]S(&YO(")+97)N96PB`$-R:6'G
MXV\@9&$@0VAA=F4`26UP<F5S<^-O(&1I9VET86P@9&$@8VAA=F4`0V]M<')I
M;65N=&\@9&$@8VAA=F4`5&EP;R!D82!#:&%V90!5=&EL:7IAY^-O(&1A($-H
M879E`$$@8VAA=F4@:N$@97AI<W1E(&YO('-E<G9I9&]R(&1E(&-H879E<R!P
M^F)L:6-A<RX`36GZ9&]S`%%U:7)I8F%T:0!297#Z8FQI8V$@4&]P=6QA<B!$
M96UO8W+A=&EC82!D82!#;W)E:6$`4F5P^F)L:6-A(&1A($-O<F5I80!#;W)E
M86YO("A%54,M2U(I`$MU=V%I=`!297#Z8FQI8V$@475I<F=U:7IE`%]$:7-P
M;W-IY^-O`$ED:6]M80!297#Z8FQI8V$@4&]P=6QA<B!$96UO8W+A=&EC82!,
M86\`475A<G1O($1E8W)E<V-E;G1E`%%U87)T;R!$96-R97-C96YT90#:;'1I
M;6$@06-T=6%L:7IAY^-O.@#:;'1I;6$@96YT<F%D83H@)7,`VFQT:6UA(&5N
M=')A9&$Z("5S(&1E("5S`-IL=&EM82!E;G1R861A.B!.=6YC80!297#Z8FQI
M8V$@9&$@3&5T\VYI80!,96D`1&ES<&]S:>?C;P!$96EX87(@=F%Z:6\@<&%R
M82!F:6-A<B!S96T@8F]R9&$`3.UB86YO`$5S<75E<F1A`$-A8F7G86QH;R!D
M82!E<W%U97)D80!686QO<F5S(.`@97-Q=65R9&$`3&5S;W1O`$QI8NER:6$`
M1W)A;F1E($IA;6%H:7)I>6$@4V]C:6%L:7-T82!0;W!U;&%R(,%R86)E(&1A
M($SM8FEA`$QI<W1E;G-T86EN90!#:'5V82`B36]L:&$M5&]L;W,B`$-H=79I
M<V-O<P!#:'5V:7-C;W,@36%T:6YA:7,`0VAU=FES8V]S(%9E<W!E<G1I;F]S
M`%!E<75E;F\@06=U86-E:7)O`$-H=79I<V-O(&-O;2!4<F]V;V%D80!1=65D
M82!D92!.979E`$YE=F4`(DQI;65R:6-K(@!,:6=AY^-O`$QI9V'GXV\@87!O
M;G1A('!A<F$Z`$QI9V%R(&\@96YD97)EYV\@9&4@8V]R<F5I;R!E;&5C='+S
M;FEC;R#@('#A9VEN82!D92!C;VUP;W-IY^-O(&%O(&UO<W1R87(`3&EG8>?U
M97,`0F]L:6YH;R!L:6YU>.IS`$QI<W1A("T@;R!U=&EL:7IA9&]R('!O9&4@
M=F5R(&$@<&%S=&$`3&ES=&%R($)A<V5S(&1E($1A9&]S`$UO<W1R87(@5/-P
M:6-O<R!D92!!:G5D80!,:7-T87(@5&%B96QA<P!,:7-T86=E;2U!<G%U:79O
M`$QI<W1A9V5M+4%J=61A`$E$(&1A($QI<W1A`$QI<W1A9V5M+41O;F\`3&ES
M=&%G96TM4W5B;6ES<_5E<P!,:7-T86=E;2U3=6)S8W)I=&%S`$QI<W1A9V5M
M+4[C;R!S=6)S8W)I=&%S`$$@;&ES=&%G96T@9&4@=71I;&EZ861O<F5S(&5S
M=.$@9&5S86-T:79A9&$N`$QI=&5R871U<F$Z`%)E</IB;&EC82!D82!,:71U
MXFYI80!#87)R96=A;F1O(&)I8FQI;W1E8V%S+BXN`$-A<G)E9V%N9&\N+BX`
M5&5M<&\@;&]C86PZ`$QO8V%L:7IAY^-O(&4@1G5S;R!(;W+A<FEO`$QO8V%L
M:7IAY^-O`$5N=')A<@!386ER`%1A<F5F87,@9&4@16YT<F%D80!!(&%U=&5N
M=&EC8>?C;R!F86QH;W4@<&]R(&\@3F]M92!D92!5=&EL:7IA9&]R(&]U(&$@
M4&%L879R82U087-S92!E<W1A<F5M(&EN8V]R<F5C=&]S+@!!(&%U=&5N=&EC
M8>?C;R!F86QH;W4N`%1E>'1O(&QO;F=O`$%M;W(`0F%I>&\`3&5T<F%S(&=R
M96=A<R!M:6[Z<V-U;&%S`$QE=')A<R!L871I;F%S(&UI;OIS8W5L87,`3OIM
M97)O<R!R;VUA;F]S(&UI;OIS8W5L;W,`3'5X96UB=7)G;P!-30!-3U1$`$\@
M86YE>&\@35,M5$Y%1B!NXV\@8V]N=&EN:&$@9&%D;W,N`$U31P!-86-A=0!-
M86-E9/-N:6$L($%N=&EG82!297#Z8FQI8V$@2G5G;W-L879A(&1A`$UA9&%G
MX7-C87(`36%G:6$`0V]R<F5I;P!!9&UI;FES=')AY^-O(&1E($-O<G)E:6\`
M1F%Z97(@;&E?9V'GXV\N+BX`07-S96=U<F4M<V4@9&4@<75E('1E;2!O(%!%
M05(@:6YS=&%L861O(&4@;F\@8V%M:6YH;R!D92!I;F-L=7/U97,@*&EN8VQU
M9&4@<&%T:"DN`$-R:6%N9&\@82!P87-T82`E<P!-86QA=6D`36%LX7-I80!-
M86QD:79A<P!-86QI`$UA;'1A`$=I<F$@82!L:7-T82!D92!C871E9V]R:6%S
M('%U92!P;V1E(&%T<FEB=6ER(&%O<R!I=&5N<RP@8F5M(&-O;6\@87,@8V]R
M97,@<75E(&QH97,@97-TXV\@87-S;V-I861A<RX`36%P82!-87`R-`!-87!A
M($UA<%%U97-T`$UA<N=O`$UA<F=E;0!-87)C87(@8V]M;R!,:61A+T[C;R!L
M:61A`$UA<F-A<B!D92!O=71R87,@9F]R;6%S("AE+F<N+"!);7!O<G1A;G1E
M+U!O<B!R97-P;VYD97(I`$EL:&%S($UA<G-H86QL`$UA<G1I;FEC80!#86UP
M;W,@<75E(&-O<G)E<W!O;F1E;0!-875R:73B;FEA`$UA=7+M8VEO`$WA>&EM
M;R!C<NED:71O('!E<FUI=&ED;RX`3>%X:6UO(&[Z;65R;R!D92!P87)T97,@
M;G5M82!M96YS86=E;2!E>&-E9&ED;RX`5&5M<&5R871U<F$@;>%X:6UA(&YA
M<R#Z;'1I;6%S(#(T(&AO<F%S.B``5&5M<&5R871U<F$@;>%X:6UA(&YA<R#Z
M;'1I;6%S(#8@:&]R87,Z(`!#;VUP<FEM96YT;R!MX7AI;6\`36%I;P!-87EO
M='1E`$UE9&EC:6YA`$UE;6)R;W,`36]D;R!D;R!M96YU.@!5;FER(&/I;'5L
M87,`26YT96=R86YD;R!T;V1O<R!O<R!F:6-H96ER;W,@)7,N<&\@8V]M(&\@
M8V]M<.IN9&EO+BXN`$EN=&5G<F%N9&\@82!L;V-A;&EZ8>?C;R`E<RXN+B``
M26YT96=R86YD;R!O(&%R<75I=F\@4$\@9&4@)7,@8V]M(&\@8V]M<.IN9&EO
M+BXN(`!);G1E9W)A;F1O(&$@=')A9'7GXV\@9&\@;?-D=6QO("5S+BXN`$UE
M;G-A9V5M`$UE;G-A9V5N(%9E<FEF:6-A9&$@8V]M(%-U8V5S<V\L(&UA<R!O
M(&-E<G1I9FEC861O(&1O('-U8G-C<FET;W(@;N-O('#T9&4@<V5R('9E<FEF
M:6-A9&\N`$UE;G-A9V5M(&5X<&ER;W4N`%1I<&\@9&4@;65N<V%G96T`365T
M96]R;VQO9VEA($U%5$%2`$)L;V-O($U%5$%2(&EN9&ES<&]N[79E;"X`0FQO
M8V\@345405(@:6YD:7-P;V[M=F5L+B!/<R!P;W)M96YO<F5S(&9O<F%M(')E
M9VES=&%D;W,@<&%R82!O(&%D;6EN:7-T<F%D;W(N`$$@365T87)$0B!NXV\@
M97-TX2!C;VYE8W1A9&$N`$WI=&]D;P!/(&WI=&]D;R`B)7,B(&[C;R!E<W3A
M(&1E9FEN:61O`$WI=')I8V\`3>EX:6-O`$UI8W)O;NES:6$L($5S=&%D;W,@
M1F5D97)A9&]S(&1A`$-E;G1R;P!4:7!O($U)344`5&5M<&5R871U<F$@;>UN
M:6UA(&YA<R#Z;'1I;6%S(#(T(&AO<F%S`%1E;7!E<F%T=7)A(&WM;FEM82!N
M87,@^FQT:6UA<R`V(&AO<F%S`$5S<&5L:&\`36ES8V5LXFYE80!086-O=&4@
M2%144%]297%U97-T(&1O(%!%05(@96T@9F%L=&$N`$-O;F9I9W5R8>?C;R!E
M;2!F86QT82X@5&5RX2!D92!A(&=E<F%R(&%G;W)A('-E('%U:7-E<B!U<V%R
M(&5S=&$@87!L:6-AY^-O+@!)1"!D82!M96YS86=E;2!E;2!F86QT82X`4&%C
M;W1E($UA:6P@9&\@4$5!4B!E;2!F86QT82X`240@9&$@<V5S<^-O(&5M(&9A
M;'1A+@`RJ@!#;W)R96EO($WS=F5L`$UO9&5R861O`$1A=&$@9&4@36]D:69I
M8V'GXV\`36]D:69I8V%R(%523`!-\V1U;&\`3?-D=6QO`%)E</IB;&EC82!D
M82!-;VQD;W9A`%!R:6YC:7!A9&\@9&\@3?-N86-O`$UO;F?S;&EA`$WJ<R!E
M(&%N;P!-96YS86QM96YT90!-;VYT<V5R<F%T`$9A<V4@9&$@3'5A`%)E:6YO
M(&1E($UA<G)O8V]S`%-O8G)E='5D;R!,:6UP;P!3;V)R971U9&\@16YE=F]A
M9&\`4V]B<F5T=61O(%-O;&%R96YG;P!$97-C97(`36]V97(@<&%R82!A($5S
M<75E<F1A`$UO=F5R('!A<F$@82!$:7)E:71A`%-U8FER`$1E<V-E<@!3=6)I
M<@!297#Z8FQI8V$@9&4@36_G86UB:7%U90!,:7-T87,@9&4@9&5S96YR;VQA
M<B!M=6QT:2UN[79E;`!396QE8^?C;R!M^FQT:7!L80!!($UI;FAA($-O;G1A
M`$\@365U(%!O<G1A;`!$:7-P;W-IY^-O(&1O(%!O<G1A;`!5;FGC;R!D92!-
M>6%N;6%R`$[C;RP@;N-O(&-O;F-O<F1O`$YO;64`4F5P^F)L:6-A(&1A($YA
M;>UB:6$`3F%U<G4`3F5P86P`4F5I;F\@9&]S(%!A[7-E<R!"86EX;W,`06YT
M:6QH87,@2&]L86YD97-A<P!54DP@9&4@0F%S92!.971S8V%P90!54DP@9&4@
M4F5V;V=AY^-O($-!($YE='-C87!E`%523"!C;VT@82!P;VSM=&EC82!D92!#
M02!.971S8V%P90!54DP@9&4@4F5N;W9AY^-O($YE='-C87!E`%523"!D92!2
M979O9V'GXV\@3F5T<V-A<&4`3F]M92!D;R!S97)V:61O<B!34TP@3F5T<V-A
M<&4`0V]M96YTX7)I;R!D92!C97)T:69I8V%D;R!.971S8V%P90!4:7!O(&1E
M(&-E<G1I9FEC861O($YE='-C87!E`%)E9&4`3G5N8V$`3F]V82!#86QE9/-N
M:6$`3F]V82!#871E9V]R:6$`3'5A($YO=F$`3F]V;R!.;VUE(&1E(%5T:6QI
M>F%D;W(@*&]P8VEO;F%L*0!.;W9A(%IE;.)N9&EA`$YO=F$@:F%N96QA("A?
M8FQA;FLI`$YO=.UC:6%S`$=R=7!O<R!D92!.;W3M8VEA<P!0<O-X:6UA`%!R
M\WAI;6%S(#0@1F%S97,`4'+S>&EM87,@;W#G]65S`%!R\WAI;6$^`%)E</IB
M;&EC82!D82!.:6-A<N%G=6$`4F5P^F)L:6-A(&1O($[M9V5R`%)E</IB;&EC
M82!&961E<F%L(&1A($YI9V5R:6$`3F]I=&4`3FEU90!.XV\`3N-O(&CA(&1A
M9&]S(&1E(&-O;F9I9W5R8>?C;R!D:7-P;V[M=F5I<R!E;2!R96QAY^-O(&%O
M<R!Q=6%I<R!M;W-T<F%R(&1I9F5R96[G87,N`$[C;R!HX2!N96YH=6UA(&5S
M=')A=.EG:6$@9&ES<&]N[79E;"!P87)A(')E86QI>F%R(&EM86=E;G,@25-/
M+@!.XV\@:.$@;6]D96QO(&1E(&QO=&4@(F)A=&-H(BX`3N-O(&5X:7-T92!B
M;&]C;R!N82!P;W-IY^-O(&EN9&EC861A`$[C;R!F;VD@9F]R;F5C:61O('5M
M(&YO;64@9&4@8V%L96YDX7)I;R!P87)A(&$@875T96YT:6-AY^-O($U#04PN
M`%-E;2!M;V1I9FEC8>?U97,N`$[C;R!S92!P;V1E(&%D:6-I;VYA<B!P97)M
M:7-S]65S(&1E(&9I;&AO<R!A8F%I>&\@9&5S=&4@;NUV96PN`$[C;R!S92!P
M;V1E(&%D:6-I;VYA<B!F:6QH;W,@82!E<W1A('!E<FUI<W/C;RX`3F5N:'5M
M(&-O;6%N9&\@97-P96-I9FEC861O+@!.XV\@9F]I(&5S<&5C:69I8V%D82!A
M(&EN9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O('!A<F$@)7,N`$[C;R!F;VD@
M97-P96-I9FEC861A(&$@:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@<&%R
M82!61E,@8F%S96%D;R!E;2!&5%`N`$[C;R!F;VD@97-P96-I9FEC861A(&$@
M:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@;F5C97-SX7)I82!P87)A(&\@
M5D93(&)A<V5A9&\@96T@4U%,+@!.XV\@9F]I(&5S<&5C:69I8V%D82!A(&EN
M9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O(&YE8V5S<^%R:6$@<&%R82!O(%9&
M4R!B87-E861O(&5M(%-13"U&:6QE+@!#<NED:71O(&5S9V]T;W4N`$YE;FAU
M;2!D97-T:6YA=.%R:6\@9F]I(&9O<FYE8VED;RX`3N-O(&5X:7-T92!Q=6%L
M<75E<B!E;G1R861A(&-O;2!O(&ED("(E<R(@;F\@87)Q=6EV;R!D92!A:G5D
M82!O<FEG:6YA;"X`3N-O('-E(&-A<G)E9V]U(&YA9&$N`$YE;FAU;6$@;&]C
M86QI>F'GXV\@97-P96-I9FEC861A+@!&86QT82!I;F1I8V%R('5M82!L;V-A
M;&EZ8>?C;RX`02!L;V-A;&EZ8>?C;R!NXV\@9F]I(&5S<&5C:69I8V%D82X`
M3F5N:'5M82!M96YS86=E;2!F;VD@9F]R;F5C:61A+@!.96YH=6T@;F]M92!E
M<W!E8VEF:6-A9&\N`$YE;FAU;2!N^FUE<F\@97-P96-I9FEC861O+@!396T@
M9&ET;W,@;V9E;G-I=F]S`$[C;R!F;VD@9F]R;F5C:61A('!A;&%V<F$M<&%S
M<V4@<&%R82!A(&%U=&5N=&EC8>?C;R!(5%10+@!.XV\@9F]I(&9O<FYE8VED
M82!P86QA=G)A+7!A<W-E('!A<F$@82!A=71E;G1I8V'GXV\@24U!4"X`3N-O
M(&9O:2!F;W)N96-I9&$@<&%L879R82UP87-S92!P87)A(&$@875T96YT:6-A
MY^-O($ME<F)E<F]S+@!.XV\@9F]I(&9O<FYE8VED82!P86QA=G)A+7!A<W-E
M('!A<F$@82!A=71E;G1I8V'GXV\@3$1!4"X`3N-O(&9O:2!F;W)N96-I9&$@
M<&%L879R82UP87-S92!P87)A(&$@875T96YT:6-AY^-O($QO9VEN+@!.XV\@
M9F]I(&9O<FYE8VED82!P86QA=G)A+7!A<W-E('!A<F$@82!A=71E;G1I8V'G
MXV\@4$%34U=$+@!.XV\@9F]I(&9O<FYE8VED82!P86QA=G)A+7!A<W-E('!A
M<F$@82!A=71E;G1I8V'GXV\@4TU"+@!.XV\@9F]I(&EN9&EC861O(&-A;6EN
M:&\@<&%R82!O(&)I;N%R:6\@3W!E;E-33"X@3R!B:6[A<FEO($]P96Y34TP@
MZ2!N96-E<W/A<FEO('!A<F$@=')A8F%L:&%R(&-O;2!D861O<R!02T-3(#$R
M+@!.XV\@:.$@<W5B<V-R:>?U97,@<&5N9&5N=&5S+@!396T@=')AYV]S`%-E
M;2!L861O<P!.XV\@:.$@<&%S=&$@=&5M<&]RX7)I82!D:7-P;V[M=F5L('!A
M<F$@(F-A8VAE(BX`3N-O(&9O<F%M(&5N=FEA9&]S(&\@;F]M92!D;R!U=&EL
M:7IA9&]R(&]U(&$@<&%L879R82UP87-S92X`3N-O(&9O<F%M(')E=&]R;F%D
M;W,@9&%D;W,@96T@6$U,(';A;&ED;W,`4V5M('9A;&]R97,`3N-O(&9O:2!E
M;F-O;G1R861A('9E<G/C;R!N82!C;VYF:6=U<F'GXV\@;W)I9VEN86PN(%)E
M9V5N97)A<B!C;VYF:6=U<F'GXV\N`$[C;R!F;VD@96YC;VYT<F%D82!V97)S
MXV\@;F$@<W5A(&-O;F9I9W5R8>?C;RX@4F5G96YE<F%R(&-O;F9I9W5R8>?C
M;RX`3F5N:'5M80!.96YH=6T@*'5S87(@:6UP;.UC:71O*0!.\W)D:6-O("A)
M4T\M.#@U.2TQ,"D`26QH82!D92!.;W)F;VQK`$AE;6ES9NER:6\@3F]R=&4`
M26QH87,@36%R:6%N87,@9&\@3F]R=&4`4F5I;F\@9&$@3F]R=65G80!.=6YC
M82!$97!O:7,@9&4`3G5N8V$@06YT97,@9&4`3N-O(.D@=6T@9&ER96-T\W)I
M;P!.XV\@:6UP;&5M96YT861A+@!0;W(@871R:6)U:7(`3N-O('-U<&]R=&%D
M;RX`3F]T87,`3F%D82!P87)A(&YA=F5G87(L('9O;'1E('!A<F$@='+A<RX`
M3F]T80!.;W9E;6)R;P!.^FUE<F\`3OIM97)O(&1E(&-A<F%C=&5R97,`3OIM
M97)O(&1E(&-O;'5N87,`3OIM97)O(&1E(&QI;FAA<P!.82!L:7-T82!D92!D
M:7-T<FEB=6GGXV\@:.$@;OIM97)O<R!Q=64@;N-O(&9O<F%M(&5S<&5C:69I
M8V%D;W,@<&%R82!A8W1U86QI>F'GXV\N`$]+`$]B:F5C=&\`0W)I861O<B!D
M;R!/8FIE8W1O`%!E<FUI<W/U97,@9&\@8W)I861O<B!D;R!O8FIE8W1O`$]C
M=&%L`$]U='5B<F\`1FEL=')O(&1E(&UA=&5R:6%L(&]F96YS:79O`$=A8FEN
M971E`%-U;'1A;F%T;R!D;R!/;>,`4_,@;W,@<V5R=FED;W)E<R!)34%0('-U
M<&]R=&%M('!A<W1A<R!P87)T:6QH861A<RX`07!E;F%S(&1I=&]S(&]F96YS
M:79O<P!3\R#I('!E<FUI=&ED;R!U;2!E;F1E<F7G;R!D92!C;W)R96EO(&5L
M96-T<O-N:6-O+@!!<&5N87,@;R!D;VYO(&]U('5M(&%D;6EN:7-T<F%D;W(@
M9&4@<VES=&5M87,@<&]D92!A;'1E<F%R(&$@=&ET=6QA<FED861E(&1E('5M
M82!P87)T:6QH82!O=2!A<R!P97)M:7-S]65S(&1O('-E=2!D;VYO`$%B<F4@
M;G5M82!N;W9A(&IA;F5L80!%<G)O($]P96Y34TPZ($[C;R!F;VD@<&]S<^UV
M96P@97AT<F%I<B!D861O<R!D92!U;6$@<&%R=&4@87-S:6YA9&$@8V]M(%,O
M34E-12X`06)R92!E<W1A(&QI9V'GXV\@;G5M82!N;W9A(&IA;F5L80!3:7-T
M96UA($]P97)A=&EV;P!/<.?U97,`3W#G]65S(&1O("5S`$]PY_5E<SH`3&ES
M=&$@3W)D96YA9&$`3W)G86YI>F'GXV\`56YI9&%D92!/<F=A;FEZ86-I;VYA
M;`!/<F=A;FEZ8>?C;P!-;V1E;&\@;W)I9VEN86P@9&$@87!L:6-AY^-O`$UO
M9&5L;W,@;W)I9VEN86ES(&5M("5S.@!/=71R;P!/=71R87,@26YF;W)M8>?U
M97,`4&5R;6ES<_5E<R!D;R!$;VYO`$%U=&5N=&EC8>?C;R!004T@;N-O(&5S
M=.$@9&ES<&]N[79E;"X`07-S:6YA='5R82!$:6=I=&%L(%!'4`!$861O<R!E
M;F-R:7!T861O<R!01U``0VAA=F4@4/IB;&EC82!01U``1&%D;W,@07-S:6YA
M9&]S+T5N8W)I<'1A9&]S(&-O;2!01U``0_-D:6=O(%!(4`!#;VUA;F1O<R!0
M2%``0VAU=FES8V]S('!E;&$@5&%R9&4`06=U86-E:7)O<R!D92!487)D90!.
M979E(.`@5&%R9&4`3F5V]65S(.`@5&%R9&4`4V]L(.`@5&%R9&4`5&5M<&]R
M86ES+50@X"!487)D90!#;VUA;F1O<R!07TA0`$5N8VAI;65N=&\`4F5P^F)L
M:6-A($ES;.)M:6-A(&1O(%!A<75I<W3C;P!297#Z8FQI8V$@9&4@4&%L874`
M5&5R<FET\W)I;R!086QE<W1I;FEA;F\`4&%N86WA`%!A<'5A($YO=F$@1W5I
M;ND`4F5P^F)L:6-A(&1O(%!A<F%G=6%I`%!A<F-I86QM96YT92!%;F-O8F5R
M=&\`4&%L879R82U087-S90!086QA=G)A+5!A<W-E(&EN8V]R<F5C=&$`4&%L
M879R82U087-S92!N96-E<W/A<FEA('!A<F$@875T96YT:6-AY^-O(%)!1$E5
M4P!086QA=G)A+5!A<W-E(&-O;2!C;VYF:7)M8>?C;P!086QA=G)A+5!A<W-E
M.@!086QA=G)A+5!A<W-E.B``07,@<&%L879R87,M<&%S<V4@=.IM(&1E('-E
M<B!I9W5A:7,N`$-O;&%R`$-O;&%R(&1E(')E8V]R=&5S`$-A;6EN:&\`4W5B
M<V-R:>?U97,@4&5N9&5N=&5S.@!097-S;V%S`%!E<F-E;G1A9V5M`$5X96-U
M=&%R($]P97)AY_5E<R!D92!-86YU=&5NY^-O`$5X96-U=&%R(&]P97)AY_5E
M<R!D92!M86YU=&5NY^-O(&%Q=6%N9&\@9&$@96YT<F%D83\`4&5R;6ES<^-O
M`$$@<&5R;6ES<^-O("(E<R(@;N-O(&9O:2!R96UO=FED82X`061M:6YI<W1R
M8>?C;R!D92!097)M:7-S]65S`%!E<FUI<W/U97,@9&4`26YF;W)M8>?U97,@
M4&5S<V]A:7,`4&5R^@!!;FEM86ES(&1E($5S=&EM8>?C;P!&:6QI<&EN87,`
M5&5L969O;F4`1F]T;V=R869I87,`26QH87,@4&ET8V%I<FX`4.UX96ES`%!L
M871I='5D97,`4&]R(&9A=F]R(&-L:7%U92!S;V)R92!U;6$@8^EL=6QA`%!O
M<B!F879O<B!C;VYF:7)M92!S92!R96%L;65N=&4@<')E=&5N9&4@<F5M;W9E
M<B!E<W1E(&5L96UE;G1O.@!0;W(@9F%V;W(@8V]N9FER;64@<V4@<F5A;&UE
M;G1E('!R971E;F1E(&1E<VQI9V%R(&5S=&4@96QE;65N=&\N`%!O<B!F879O
M<B!I;G1R;V1U>F$@=6T@;>IS(&4@=6T@86YO+@!0;W(@9F%V;W(@:6YT<F]D
M=7IA(&\@;F]M92!D82!N;W9A(&-A=&5G;W)I83H`4&]R(&9A=F]R(&EN=')O
M9'5Z82!U;2!E;F1E<F7G;R!)4"!VX6QI9&\N`%!O<B!F879O<B!I;G1R;V1U
M>F$@=6UA(&1A=&$@=N%L:61A.R!V97)I9FEQ=64@;R!N^FUE<F\@9&4@9&EA
M<R!D;R!MZG,N`%!O<B!F879O<B!I;G1R;V1U>F$@=6UA(&AO<F$@=N%L:61A
M+@!0;W(@9F%V;W(L(&9O<FYEYV$@=6UA(&)R979E(&1E<V-R:>?C;R!D;R!P
M<F]B;&5M82X`4&]R(&9A=F]R+"!I;G1R;V1U>F$@;R!S974@3F]M92!D92!5
M=&EL:7IA9&]R(&4@82!S=6$@4&%L879R82U087-S90!0;W(@9F%V;W(@;&5I
M82!O('1E>'1O('-E9W5I;G1E+B!496T@9&4@0T].0T]21$%2(&-O;2!O<R!T
M97)M;W,@9&5S=&4@86-O<F1O('!A<F$@=7-A<B!O('-I<W1E;6$N`%!O<B!F
M879O<B!R97!O<G1E(&]S(&5R<F]S('!A<F$@:3$X;D!L:7-T<RYH;W)D92YO
M<F<`4&]R(&9A=F]R(&EN=')O9'5Z82!O(&YO;64@9&$@;F]V82!C871E9V]R
M:6$Z`%!O;/-N:6$`4&]L[71I8V$`4V]N9&%G96YS`%)E</IB;&EC82!0;W)T
M=6=U97-A`%!O<VEC:6]N86UE;G1O(&1E<W1A(&EM86=E;0!0;W-I8VEO;F%M
M96YT;R!D97-T82!T86)E;&$`(E!O<W0B('!A<F$@97-T82!P87-T82`H;N-O
M(.D@<F5Q=6ES:71O(&1O($E-05`I`%!R96-I<&ET8>?C;R!N87,@^FQT:6UA
M<R`E<R!H;W)A*',I.B``4')O8F%B:6QI9&%D92!D93QB<B`O/E!R96-I<&ET
M8>?C;P!0<F5F<U]L9&%P.B!!(&5X=&5N<^-O($Q$05`@;F5C97-SX7)I82!N
MXV\@9F]I(&5N8V]N=')A9&$N`%!R969S7W-E<W-I;VXZ($$@97AT96YSXV\@
M9&4@<V5S<^-O(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O;G1R861A+@!0<F5S
M<^-O`%!R97-SXV\@86\@;NUV96P@9&\@;6%R.B``4')E<W/C;SH@`%!R979I
M<^-O`%!R979E<B!A(&EM86=E;2!N=6UA(&YO=F$@:F%N96QA`$]PY_5E<R!A
M;G1E<FEO<F5S`$EM<')I;6ER(&\@9&]C=6UE;G1O`$-H879E(%!R:79A9&$`
M4')O8FQE;6$`1&5S8W)IY^-O(&1O(%!R;V)L96UA`%!R;VIE8W1O<P!-96YS
M86=E;2UP<F]N=&\`0VAA=F4@4/IB;&EC80!!;&=O<FET;6\@9&4@0VAA=F4@
M4/IB;&EC80!);F9O<FUAY^-O(%-O8G)E(&$@0VAA=F4`3R!P87(@9&4@8VAA
M=F5S(%!U8FQI8V$O4')I=F%D82!NXV\@9F]I(&=E<F%D82!C;VT@<W5C97-S
M;RX`4&]R=&\@4FEC;P!%<W1A9&\@9&\@46%T87(`4&5D:61O`$-H879E(%#Z
M8FQI8V$@4E-!("@E9"!B:70I`%-E;&5CY^-O(")RX61I;R(`0VAU=F$`0VAU
M=F$@36%T:6YA;`!#:'5V82!697-P97)T:6YA`$%G=6%C96ER;P!#:'5V82!E
M($YE=F4`0VAU=F$@82!.979E`$1I=&\@06QE873S<FEO`%)E;&'GXV\`3&5R
M`$QE<B!M96YS86=E;G,`475E<B!M97-M;R!R96UO=F5R("5S/R!%<W1A(&]P
M97)AY^-O(&[C;R!T96T@<F5G<F5S<V\N`%)E;6]V97(@;65S;6\@;W,@9&%D
M;W,@9&\@=71I;&EZ861O<B`E<S\@17-T82!O<&5R8>?C;R!NXV\@=&5M(')E
M9W)E<W-O+@!2969A>B!A('-U82#Z;'1I;6$@86/GXV\`4F5F<F5S8V%R($5L
M96UE;G1O<R!D92!-96YU($1I;N)M:6-O.@!2969R97-C87(@5FES=6%L:7IA
MY^-O(&1O(%!O<G1A;#H`17AP<F5S<^-O(%)E9W5L87(`3F%V96=A9&]R(&1E
M(%)E;&'G]65S`$]B<V5R=F'G]65S`%-E<G9I9&]R97,@4F5M;W1O<P!54DP@
M4F5M;W1O("AH='1P.B\O=W=W+F5X96UP;&\N<'0O:&]R9&4I.@!296UO=F5R
M`%)E;6]V97(@0FQO8V\`4F5M;W9E<B!C;VQU;F$`4F5M;W9E<B!F;W)M871A
MY^-O`%)E;6]V97(@<&%R`%)E;6]V97(@;R`B<V-R:7!T(B!G=6%R9&%D;R!D
M82!P87-T82!T96UP;W+A<FEA(&1O('-E<G9I9&]R+@!296UO=F5R(&\`4F5M
M;W9E<B!E<W1E(&[S(&1O(&1O8W5M96YT;P!296UO=F5R(%5T:6QI>F%D;W(`
M4F5M;W9E<B!U=&EL:7IA9&]R.B`E<P!.XV\@9F]I('!O<W/M=F5L(')E<W!O
M;F1E<B!A;R!P961I9&\N($/S9&EG;R!D92!E<G)O(&1E=F]L=FED;SH@`$\@
M<V5R=FGG;R!P961I9&\@;N-O(&9O:2!E;F-O;G1R861A+@`B)7,B(&]B<FEG
M873S<FEO(&[C;R!F;VD@97-P96-I9FEC861O(&YA(&-O;F9I9W5R8>?C;R!D
M92`E<RX`(B5S(B!O8G)I9V%T\W)I;R!NXV\@9F]I(&5S<&5C:69I8V%D;R!N
M82!C;VYF:6=U<F'GXV\@5D93+@`B)7,B(&]B<FEG873S<FEO(&[C;R!F;VD@
M97-P96-I9FEC861O(&YA(&-O;F9I9W5R8>?C;RX`0V%M<&\@3V)R:6=A=/-R
M:6\`3&EM<&%R`%)E:6YI8VEA<B!086QA=G)A+5!A<W-E`%)E:6YI8VEE(&$@
M4W5A(%!A;&%V<F$M4&%S<V4`4F5S=6QT861O<P!297-U;'1A9&]S("AI;F-L
M=6EN9&\@2&]R9&4I.@!297-U;'1A9&]S.@!6;VQT87(@X',@3W#G]65S`%)E
M=6YIXV\`4D5V97)T97(@0V]N9FEG=7)AY^-O`$]PY_5E<R!D92!%9&GGXV\@
M4FEC80!!9&EV:6YH87,`1&ER96ET80!#86)EYV%L:&\@9&$@9&ER96ET80!6
M86QO<F5S(.`@9&ER96ET80!0<F]P<FEE9&%D97,@9&$@3&EN7VAA+BXN`%)E
M9W)A`%)O;>EN:6$`4F]D87(@,3@P`%)O9&%R(.`@17-Q=65R9&$`4F]D87(@
MX"!D:7)E:71A`%!R;W!R:65D861E<R!D82!,:6YH80!0<F]P<FEE9&%D97,@
M9&$@;&EN:&$`3&EN:&%S.@!4<F'G;W,`5')AYV]S(&%P87)E8V5RXV\@96YT
M<F4@=&]D87,@87,@;&EN:&%S(&4@8V]L=6YA<P!4<F'G;W,@87!A<F5C97+C
M;R!A<&5N87,@96YT<F4@87,@8V]L=6YA<P!4<F'G;W,@87!A<F5C97+C;R!A
M<&5N87,@96YT<F4@;&EN:&%S`$5X96-U=&%R`$9E9&5R8>?C;R!2=7-S80!2
M97#Z8FQI8V$@9&\@4G5A;F1A`$%S<VEN871U<F$@0W)I<'1O9W+A9FEC82!3
M+TU)344`365N<V%G96T@16YC<FEP=&%D82!C;VT@4R]-24U%`$%U=&5N=&EC
M8>?C;R!305-,(&EN9&ES<&]N[79E;"X`365N<V%G96YS(%--4P!#;VUA;F1O
M<R!344P`4U-(`%-50T534T\`0V]M86YD;W,@4U]13`!SX0!386YT82!(96QE
M;F$`4^-O($MI='1S(&4@3F5V:7,`4V%N=&$@3/IC:6$`4^-O(%!E9')O(&4@
M36EQ=65L;VX`4^-O(%9I8V5N=&4@92!'<F5N861I;F5S`$UE<VUA(&UO;&1U
M<F$@*%]S96QF*0!%<W1A9&\@26YD97!E;F1E;G1E(&1A(%-A;6]A`%)E</IB
M;&EC82!397)E;NUS<VEM82!D92!3XV\@36%R:6YO`%/C;R!4;VWI(&4@4'+M
M;F-I<&4`1F]R;F5C961O<B!D;R!3873I;&ET90!!<N%B:6$@4V%U9&ET80!'
M=6%R9&%R`$=U87)D87(@)7,`1W5A<F1A<B`G)7,G`$=U87)D87(@3W#G]65S
M`$=U87)D87(@8V]N9FEG=7)AY^-O(&=E<F%D82!C;VUO('5M(")S8W)I<'0B
M(%!(4"!N;R!D:7)E8W3S<FEO('1E;7!O<N%R:6\@9&\@<V5U('-E<G9I9&]R
M+@!'=6%R9&5I(&-O;F9I9W5R8>?C;R`E<RX`1W5A<F1E:2!O(")S8W)I<'0B
M(&1E(&%C='5A;&EZ8>?C;R!E;3H@(B5S(BX`5&5M<&]R86ES+50@1&ES<&5R
M<V]S`$-IZFYC:6$`4')O8W5R87(`36]T;W)E<R!D92!0<F]C=7)A`%!R;V-U
M<F%N9&\@87!L:6-AY_5E<R`H;?-D=6QO<RD@2&]R9&4@96T@)7,`4')O8W5R
M86YD;R!O<R!B:6[A<FEO<R!D92!G971T97AT+BXN`%-E;&5C8VEO;F%R($%R
M<75I=F]S`%-E;&5C8VEO;F4@=6UA(&1A=&$`4V5L96-C:6]N92!U;2!G<G5P
M;R!A(&%C<F5S8V5N=&%R`%-E;&5C8VEO;F%R('5M(&YO=F\@9&]N;P!396QE
M8V-I;VYE('5M('-E<G9I9&]R`%-E;&5C8VEO;F4@=6T@=71I;&EZ861O<B!A
M(&%D:6-I;VYA<@!396QE8V-I;VYE('1O9&]S(&]S(&-O;7!O;F5N=&5S(&1A
M(&1A=&$N`%-E;&5C8VEO;F4@=6T@;V)J96-T;P!396QE8V-I;VYE(&]S(&-A
M<F%C=&5R97,@;F%S(&-A:7AA<R!A8F%I>&\N(%!O9&5RX2!E;G3C;R!C;W!I
MX2UL;W,@92!C;VSA+6QO<R!N82#A<F5A(&1E('1E>'1O+@!396QE8V-I;VYE
M(&\@9&5L:6UI=&%D;W(@9&$@9&%T83H`4V5L96-C:6]N92!O(&9O<FUA=&\@
M9&$@9&%T83H`4V5L96-C:6]N92!A(&ED96YT:61A9&4@<75E('!R971E;F1E
M(&%L=&5R87(Z`%-E;&5C8VEO;F4@;R!D96QI;6ET861O<B!D87,@:&]R87,Z
M`%-E;&5C8VEO;F4@;R!F;W)M871O(&1A(&AO<F$Z`%-E;&5C8VEO;F4@9&]I
M<R!C86UP;W,@<F5L86-I;VYA9&]S+@!%<V-O;&AA(&\@<V5U(&-O;FIU;G1O
M(&1E(&-O<F5S+@!396QE8V-I;VYE(&\@<V5U(&ED:6]M82!P<F5F97)I9&\Z
M`$5N=FEA<B!296QA=/-R:6\@9&4@4')O8FQE;6%S`$5N=FEA<B!335,`4F5P
M^F)L:6-A(&1O(%-E;F5G86P`(%-E;G-O<CH@`%-E=&5M8G)O`%/I<G9I82!E
M($UO;G1E;F5G<F\`3OIM97)O(&1E(%/I<FEE`$1A9&]S(&1O('-E<G9I9&]R
M(&5R<F%D;W,@;W4@:6YD:7-P;V[M=F5I<RX`240@9&4@<V5S<^-O(&5X<&ER
M;W4N`$%T<FEB=6ER`$5S=&%B96QEYV$@;W#G]65S('%U92!L:&4@<&5R;6ET
M86T@<F5I;FEC:6%R(&$@<W5A('!A;&%V<F$M<&%S<V4@<V4@86QG=6UA('9E
M>B!D96QA('-E(&5S<75E8V5R+@!%<W!E8VEF:6-A<B!S97)V:61O<F5S(')E
M;6]T;W,@<75E(&1E<V5J82!A8V5D97(@;F\@<V5U('!O<G1A;"X`4V5L96-C
M:6]N92!O('-E=2!I9&EO;6$@<')E9F5R:61O+"!O('-E=2!F=7-O(&AO<N%R
M:6\@92!A<R!S=6%S(&]PY_5E<R!D92!D871A<RX`17-C;VQH82!A('-U82!A
M<&QI8V'GXV\@:6YI8VEA;"P@;R!E<W%U96UA(&1E(&-O<F5S+"!O(')E9G)E
M<V-A;65N=&\@9&4@<.%G:6YA<R!E(&]U=')A<R!O<.?U97,@9&4@=FES=6%L
M:7IAY^-O+@!#;VYF:6=U<F%R`")38W)I<'1S(B!D92!A8W1U86QI>F'GXV\@
M9&ES<&]N[79E:7,`5N%R:6%S(&QO8V%L:7IAY_5E<R!P;W-S[79E:7,@8V]M
M(&\@<&%RXFUE=')O.B``4V5I8VAE;&5S`$-O;7!R87,`0G)E=F4@4W5MX7)I
M;P!$979E;2US92!D969I;FER('1E8VQA<R!D92!A8V5S<V\@<&%R82!A(&UA
M:6]R:6$@9&%S(&QI9V'G]65S/P!-;W-T<F%R`$UO<W1R87(@9&EF97)E;N=A
M<R!E;G1R92!A(&-O;F9I9W5R8>?C;R!G=6%R9&%D82!E(&%Q=64@9F]I(&%G
M;W)A(&=E<F%D82X`36]S=')A<B!M;VUE;G1O(&1A(/IL=&EM82!E;G1R861A
M(&YO('-I<W1E;6$_`$UO<W1R87(@;W#GXV\@<&%R82!P<F5S97)V87(@;R!O
M<FEG:6YA;`!-;W-T<F%R('!A;&5T90!-;W-T<F%R(&$@8F%R<F$@9&4@;65N
M=2!C;VT@87,@;W!E<F'G]65S('-O8G)E('1A8F5L87,_`$UO<W1R87(@;R!-
M96YU("5S(.`@97-Q=65R9&$_`$UO<W1R87(@82!C86EX82!D92!D:>%L;V=O
M(&1A<R!0<F]P<FEE9&%D97,@9&4@0^EL=6QA<R!D92!486)E;&$_`$UO<W1R
M87(@82!C86EX82!D92!D:>%L;V=O(&1A<R!0<F]P<FEE9&%D97,@9&4@5&%B
M96QA<P!-;W-T<F%R(&$@8V%I>&$@9&4@9&GA;&]G;R!D87,@4')O<')I961A
M9&5S(&1E($QI;FAA<R!D92!486)E;&$`36]S=')A<B!A(&-A:7AA(&1E(&1I
MX6QO9V\@9&%S(%!R;W!R:65D861E<R!D92!);6%G96T`36]S=')A<B!C87)R
M96=A;65N=&\`06=U86-E:7)O<P!!9W5A8V5I<F]S($UA=&EN86ES`$%G=6%C
M96ER;W,@5F5S<&5R=&EN;W,`06=U86-E:7)O<R!N82!6:7II;FAA;N=A`$5N
M8V]L:&5R`$5N8V]L:&$@;W4@;6]V82!O*',I(&)L;V-O*',I('9I>FEN:&\H
M<RD@<')I;65I<F\`4V5R<F$@3&7C;P!3=6)S8W)E=F5R`%-U8G-C<F5V82P@
M<V4@86EN9&$@;N-O(&5S=.$@<F5G:7-T861O`$%S<VEN871U<F$`06QG;W)I
M=&UO(&1E($%S<VEN871U<F$`4F5P^F)L:6-A(&1E(%-I;F=A<'5R80!486UA
M;FAO`%-A;'1A<B!-86YU=&5NY^-O`$[C;R!P<F]C97-S861O+BXN`$5S;&]V
MX7%U:6$`4F5P^F)L:6-A(&1A($5S;&]VZ6YI80!.979E`$YE=N-O`$YE=O5E
M<P!.97;U97,@36%T:6YA:7,`3F5V]65S(%9E<W!E<G1I;F]S`$%L='5R82!D
M92!N979E.B``36]S=')A<B!E<75I=F%L96YT92!N82#A9W5A.B``26QH87,@
M4V%L;VWC;P!3;VWA;&EA`$-A;N?U97,@92!0;V5M87,`4V5L96/GXV\@9&\@
M<V5N=&ED;R!D82!O<F1E;F'GXV\`16YD97)EYV\@9&4@;W)I9V5M`,%F<FEC
M82!D;R!3=6P`175R;W!A(&1O(%-U;"`H25-/+3@X-3DM,RD`1V7S<F=I82!D
M;R!3=6P@92!);&AA<R!386YD=VEC:"!D;R!3=6P`2&5M:7-FZ7)I;R!3=6P`
M17-P8>=O(&5N=')E(&/I;'5L87,@861J86-E;G1E<P!%<W!AYV\@96YT<F4@
M;R!C;VYT9?ID;R!E(&$@8F]R9&$@9&4@=6UA(&/I;'5L80!%<W!AYV%D;W(`
M17-P8>=A;65N=&\`17-P8>=A;65N=&\@92!E;F-H:6UE;G1O`%)E:6YO(&1E
M($5S<&%N:&$`0V]R<F5I;R!NXV\@<V]L:6-I=&%D;P!);G-E<FER($-A<F%C
M=&5R($5S<&5C:6%L`$1I=FED:7(@8^EL=6QA`$%D:6-I;VYA<B!C;VQU;F$`
M1&EV:61I<B!L:6YH80!$97-P;W)T;W,`4F5P^F)L:6-A($1E;6]C<N%T:6-A
M(%-O8VEA;&ES=&$@9&\@4W)I($QA;FMA`%!A9'+C;P!3=&%R(%1R96L`06YO
M(&1E(&EN[6-I;P!%<W1A9&\@;W4@4')O=NUN8VEA`%-T871U<P!%<W1A9&\@
M9&$@;&]C86QI>F'GXV\@)7,N+BX@`$9O<FUA=&\@9&4@87)M87IE;F%M96YT
M;P!%;F1E<F7G;R!D92!2=6$`4F%S=7)A9&\`3&ES=&$@9&4@8V%D96EA<R!D
M92!C87)A8W1E<F5S`%)E=&ER87(@9&]M[6YI;R!D;R!E;F1E<F7G;P!%<W1I
M;&\@6T-34UT`9&\`07-S=6YT;P!3=6)M971E<@!&;VD@<W5B;65T:61O('!E
M9&ED;R!P87)A(&%D:6-I;VYA<B`B)7,B(&%O('-I<W1E;6$N($[C;R!P;V1E
M<N$@96YT<F%R(&5N<75A;G1O(&\@<V5U('!E9&ED;R!NXV\@9F]R(&%P<F]V
M861O+@!);F9E<FEO<B#@(&QI;FAA`%-U8V5S<V\`(B5S(B!A9&EC:6]N861O
M(&-O;2!S=6-E<W-O(&%O('-I<W1E;6$N`$QI;7!E>F$@9&\@<VES=&5M82!D
M;W,@9&%D;W,@9&\@=71I;&EZ861O<B`B)7,B(')E86QI>F%D82!C;VT@<W5C
M97-S;RX`4F5M;^?C;R!D92`B)7,B(&-O;2!S=6-E<W-O+@!296UOY^-O(&1E
M("(E<R(@9&\@<VES=&5M82!C;VT@<W5C97-S;RX`0V]N9FEG=7)AY^-O(')E
M=F5R=&ED82!C;VT@<W5C97-S;RX@4F5C87)R96=U92!P87)A('9E<B!A<R!M
M=61A;N=A<RX`0V]N9FEG=7)AY^-O(&1E('-A;'9A9W5A<F1A(&=U87)D861A
M(&-O;2!S=6-E<W-O+@!&:6-H96ER;R!D92!C;VYF:6=U<F'GXV\@9&4@<V%L
M=F%G=6%R9&$@)7,@9W5A<F1A9&\@8V]M('-U8V5S<V\N`"(E<R(@86-T=6%L
M:7IA9&\@8V]M('-U8V5S<V\`)7,@97-C<FET;R!C;VT@<W5C97-S;P!297#Z
M8FQI8V$@9&\@4W5DXV\`4F5S=6UO`$YA<V-E<B!D;R!3;VP`4/1R(&1O(%-O
M;`!3;VQA<F5N9V\`3F%S8V5R(&1O(%-O;`!.87-C97(O4/1R(&1O(%-O;`!.
M87-C97(@9&\@4V]L.B``4/1R(&1O(%-O;`!0]'(@9&\@4V]L.B``4W5P97)I
M;W(@X"!L:6YH80!3=7!O<G1E`%-U<FEN86UE`$%P96QI9&\`4W9A;&)A<F0@
M92!*86X@36%Y96X`4F5I;F\@9&$@4W5A>FELXFYD:6$`4F5I;F\@9&$@4W7I
M8VEA`%-U[>=A`$5R<F\@9&4@<VEN=&%X92!N;W,@=&5R;6]S(&1E('!R;V-U
M<F$`4F5P^F)L:6-A(,%R86)E(%/M<FEA`%1E;7!O<F%L+50`5&5M<&]R86PM
M5"!E(%9E;G1O<V\`5&5M<&]R86ES+50`5&5M<&]R86ES+50@36%T:6YA:7,`
M07)Q=6EV;R!44U8`5&%B96QA`%!R;W!R:65D861E<R!D82!486)E;&$`4')O
M<')I961A9&5S(&1A('1A8F5L80!&;W)M;W-A`$9O<FUO<V$`4F5P^F)L:6-A
M(&1O(%1A9&II<75I<W3C;P!486YZXFYI80!!;'9O.@!487)E9F%S`$[Z;65R
M;R!D92!496QE9F]N90!496UP97)A='5R82!D82#Z;'1I;6$@:&]R83H`5&5M
M<&5R871U<F$`5&5M<&5R871U<F$Z(`!496UP97)A='5R83QB<B`O/B@E<T%L
M=&$E<R\E<T)A:7AA)7,I("9D96<[)7,`3R!M;V1E;&\@(B5S(B!NXV\@9F]I
M(&5N8V]N=')A9&\N`$%D;6EN:7-T<F'GXV\@9&4@36]D96QO<P!497AT;P!!
M<&5N87,@5&5X=&\`06QI;FAA;65N=&\@9&\@=&5X=&\`5&]P;R!D;R!T97AT
M;P`UJ@!486EL86YDZG,@*%1)4RTV,C`I`%)E:6YO(&1A(%1A:6SB;F1I80!/
M8G)I9V%D;R!P;W(@=7-A<B!E<W1E('-I<W1E;6$N`$\@87)Q=6EV;R!D92!A
M:G5D82`E<R!P87)A("5S(&[C;R!E>&ES=&4@86EN9&$N($-R:6%N9&\@=6T@
M;F]V;RX`02!E>'1E;G/C;R!&5%`@;N-O(&5S=.$@9&ES<&]N[79E;"X`3R!E
M;F=E;FAO(&1E(&EN=&5G<F'GXV\@2&]R9&4O2V]L86(@;N-O('-U<&]R=&$@
M(B5S(@!/(')E9VES=&\@*")L;V<B*2!)35-0(&[C;R!P]&1E('-E<B!I;FEC
M:6%L:7IA9&\N`$$@8VQA<W-E($UA:6YT96YA;F-E.CH@;N-O(&9O:2!C87)R
M96=A9&$@8V]M('-U8V5S<V\`02!J86YE;&$@9&4@3W#G]65S(&9E8VAO=2X@
M4V'M;F1O+@!/(&%D;6EN:7-T<F%D;W(@=&5M(&1E(&-O;F9I9W5R87(@=6T@
M;65C86YI<VUO(&1E('!E<FUI<W/U97,@<&5R;6%N96YT92!S92!Q=6ES97(@
M=7-A<B!097)M:7-S]65S+@!!<&5N87,@;R!L861O(&EN9F5R:6]R`$\@;OIM
M97)O(&1E($E$(&1O(&-O;G1A8W1O(&[C;R!F;VD@97-P96-I9FEC861O+"!F
M;VD@9&5I>&%D;R!E;2!B<F%N8V\@;W4@;N-O(&9O:2!E;F-O;G1R861O(&YA
M(&)A<V4@9&4@9&%D;W,N`$\@8V]N=&%C=&\@9F]I(&%D:6-I;VYA9&\@X"!L
M:7-T82!D92!C;VYT86-T;W,@8V]M('-U8V5S<V\N`$\@8FQO8V\@9&4@87-S
M:6YA='5R82!01U`@9&5S=&%C861O(.D@;F5C97-SX7)I;R!P87)A('9E<FEF
M:6-A<B!U;6$@;65N<V%G96T@87-S:6YA9&$N`$\@240@9&$@;&ES=&$@9&4@
M9&ES=')I8G5IY^-O(&[C;R!F;VD@97-P96-I9FEC861O+"!F;VD@9&5I>&%D
M;R!E;2!B<F%N8V\@;W4@;N-O(&9O:2!E;F-O;G1R861O(&YA(&)A<V4@9&4@
M9&%D;W,N`$$@;&ES=&$@9&4@9&ES=')I8G5IY^-O(&[C;R!F;VD@97-P96-I
M9FEC861A+@!!<R!F=6YC:6]N86QI9&%D97,@9&4@96YC<FEP=&'GXV\@97AI
M9V5M('5M82!L:6=AY^-O('-E9W5R82X`3R!A<G%U:79O("5S(&1E=F5R:6$@
M8V]N=&5R('5M(&%T<FEB=71O("5S+@!/(&%R<75I=F\@)7,@9&5V97)I82!C
M;VYT97(@86QG=6YS(&%T<FEB=71O<R`E<RX`3R!F:6-H96ER;R!NXV\@<&]D
M92!S97(@8V]P:6%D;R!P87)A('-I('!R\W!R:6\N`$\@9FEC:&5I<F\@;N-O
M(&-O;G3I;2!D861O<RX`06)A:7AO(&5S=.-O(&]S(&-A8F7G86QH;W,@9&5S
M=&$@;65N<V%G96TO;65N<V%G96T@<F9C.#(R+@!/(&UO9&\@9&4@96-RXR!I
M;G1E:7)O(&-A=7-A('!R;V)L96UA<R!N;R!);G1E<FYE="!%>'!L;W)E<BP@
M9&5V:61O(&$@97)R;W,@;F\@;F%V96=A9&]R('%U92!NXV\@8V]N<V5G=6EM
M;W,@=6QT<F%P87-S87(N("!0;V1E('-U<F=I<B!L:7AO+"!P;V1E;2!D97-A
M<&%R96-E<B!F=6YC:6]N86QI9&%D97,@9&\@961I=&]R(&4O;W4@;R!S974@
M;F%V96=A9&]R('!O9&4@86)O<G1A<BX@4V4@;R!S974@<VES=&5M82#I('5M
M(%=I;F1O=W,@.7@L(.D@;75I=&\@<')O=N%V96P@<75E(&]B=&5N:&$@=6T@
M)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@92!P<F5C:7-E(&1E(')E:6YI
M8VEA<B!O('-I<W1E;6$N7&Y<;D9O:2!A=FES861O+B`@4&]R(&9A=F]R('!R
M97-S:6]N92!/2R!S92!A:6YD82!A<W-I;2!Q=6ES97(@97AP97)I;65N=&%R
M(&\@961I=&]R(&1E(&5C<N,@:6YT96ER;RX`3R!F:6-H96ER;R!D92!A:G5D
M82`E<R!NXV\@8V]M9>=A(&-O;2`\/WAM;`!!(&ED96YT:61A9&4@(B5S(B!F
M;VD@<F5M;W9I9&$N`$%P96YA<R!O(&QA9&\@97-Q=65R9&\`02!L;V-A;&EZ
M8>?C;R!D;R!A<G%U:79O(&5X96-U=.%V96P@9&4@1VYU4$<@=&5M(&1E('-E
M<B!I;F1I8V%D82#@(&-L87-S92!#<GEP=%]P9W`Z.BX`02!M96YS86=E;2!E
M;G9I861A(&5M("5S('!A<F$@)7,@8V]M(&%S<W5N=&\@(B5S(B!F;VD@;6]S
M=')A9&$N"D[C;R!HX2!G87)A;G1I82!D92!Q=64@82!M96YS86=E;2!T96YH
M82!S:61O(')E86QM96YT92!L:61A(&]U(&-O;7!R965N9&ED82X`3R!N;VUE
M(&$@=7-A<B!Q=6%N9&\@;&EG86YD;R#@('#A9VEN82!D92!C;VUP;W-IY^-O
M`$\@;?-D=6QO(&]P96YS<VP@Z2!N96-E<W/A<FEO('!A<F$@82!C;&%S<V4@
M2&]R9&5?0W)Y<'1?<VUI;64Z.BX`02!O<.?C;R`B)7,B(&[C;R!P]&1E('-E
M<B!G=6%R9&%D82P@<&]I<R!O<R!S975S(&1A9&]S(&5X8V5D96T@82!D:6UE
M;G/C;R!MX7AI;6$@<&5R;6ET:61A`$\@<')O9W)A;6$@=7-A9&\@<&%R82!V
M97(@97-T92!T:7!O(&1E(&1A9&]S("@E<RD@;N-O(&9O:2!E;F-O;G1R861O
M(&YO('-I<W1E;6$N`$%P96YA<R!O<R!L861O<R!E<W%U97)D;R!E(&1I<F5I
M=&\`07!E;F%S(&\@;&%D;R!D:7)E:71O`$\@<V5R=FED;W(@(B5S(B!F;VD@
M<F5M;W9I9&\N`$\@<V5R=FED;W(@(B5S(B!F;VD@9W5A<F1A9&\N`$\@<&5D
M:61O(&1E('-U8G-C<FGGXV\@9&4@)7,@9F]I(')E;6]V:61O+@!!(&QI;FAA
M(&EN9&EC861A(&[C;R!E>&ES=&4N`$\@87)Q=6EV;R!T96UP;W+A<FEO("(E
M<R(@;N-O(&5X:7-T92X`07!E;F%S(&]S(&QA9&]S('-U<&5R:6]R(&4@:6YF
M97)I;W(`07!E;F%S(&\@;&%D;R!S=7!E<FEO<@!/<R!D861O<R!C87)R96=A
M9&]S('!E<F1E<F%M+7-E(&1E<V1E(&\@<&%S<V\@86YT97)I;W(N`$\@87)Q
M=6EV;R!C87)R96=A9&\@;N-O('#T9&4@<V5R(&=U87)D861O+@!/(&)L;V-O
M('=E871H97(N8V]M(&[C;R!E<W3A(&1I<W!O;NUV96PN`$[C;R!HX2!O<.?U
M97,@9&ES<&]N[79E:7,N`$[C;R!HX2!P87)T97,@<75E('!O<W-A;2!S97(@
M;6]S=')A9&%S(&5M(&QI;FAA+@!(X2!D96UA<VEA9&]S(&-A<F%C=&5R97,@
M;F5S=&4@8V%M<&\N($EN=')O9'5Z:74@)7,@8V%R86-T97)E<SL@=&5M(&1E
M(&EN=')O9'5Z:7(@;65N;W,@9&\@<75E("5S+@!.XV\@97AI<W1E(&%I;F1A
M('5M(&%R<75I=F\@9&4@86IU9&$@<&%R82`E<RX`3V-O<G)E=2!U;2!P<F]B
M;&5M82!N82!A9&GGXV\@9&4@(B5S(B!A;R!S:7-T96UA.B`E<P!/8V]R<F5U
M('5M('!R;V)L96UA(&%O(&QI;7!A<B!O<R!D861O<R!D;R!U=&EL:7IA9&]R
M("(E<R(@9&\@<VES=&5M82X`3V-O<G)E=2!U;2!P<F]B;&5M82!N82!R96UO
MY^-O(&1E("(E<R(@9&\@<VES=&5M82X`3V-O<G)E=2!U;2!P<F]B;&5M82!A
M;R!A8W1U86QI>F%R("(E<R(Z("5S+@!(;W5V92!U;2!P<F]B;&5M82!C;VT@
M;R!C87)R96=A;65N=&\@9&\@9FEC:&5I<F\Z("5S(&[C;R!F;VD@8V%R<F5G
M861O+@!/8V]R<F5U('5M('!R;V)L96UA(&-O;2!O(&-A<G)E9V%M96YT;R!D
M;R!A<G%U:79O.B!/("5S(&5X8V5D92!O('1A;6%N:&\@;>%X:6UO('!E<FUI
M=&ED;R`H)60@8GET97,I+@!/8V]R<F5U('5M('!R;V)L96UA(&-O;2!O(&-A
M<G)E9V%M96YT;R!D;R!A<G%U:79O.B!/("5S(&9O:2!A<&5N87,@<&%R8VEA
M;&UE;G1E(&-A<G)E9V%D;RX`3V-O<G)E=2!U;2!E<G)O(&%O(&UO<W1R87(@
M97-T82!P87)T92!D82!M96YS86=E;0!/8V]R<F5U('5M(&5R<F\@86\@:6UP
M;W)T87(@9&%D;W,@9&4@8V]N=&%C=&\N`$]C;W)R974@=6T@97)R;R!A;R!I
M;7!O<G1A<B!D861O<R!I0V%L96YD87(N`$]C;W)R974@=6T@97)R;R!N;R!F
M;W)M=6SA<FEO(&1E(&-O;F9I9W5R8>?C;RX@5&%L=F5Z('1E;FAA(&]M:71I
M9&\@=6T@8V%M<&\@;V)R:6=A=/-R:6\N`$]C;W)R974@=6T@97)R;R!A;R!A
M8G)I<B!O(&%R<75I=F\@)7,N($5X<&5R:6UE;G1E(&5X96-U=&%R('1R86YS
M;&%T:6]N+G!H<"!C;VT@82!O<.?C;R`M9"!P87)A(&-O;G-E9W5I<B!V97(@
M87,@;65N<V%G96YS(&1E(&5R<F\@9&\@86YA;&ES861O<B!834PN`$]C;W)R
M974@=6T@97)R;R!A;R!R96%L:7IA<B!A(&9U;N?C;R!D92!L:79R;R!D92!E
M;F1E<F7G;W,@97-P96-I9FEC861A+B!0;W(@9F%V;W(@=&5N=&4@9&4@;F]V
M;R!M86ES('1A<F1E+@!/8V]R<F5U('5M(&5R<F\@86\@86-T=6%L:7IA<B!O
M<R!P;W)M96YO<F5S(&1O(&-O;G1A8W1O+B!0;W(@9F%V;W(@=&5N=&4@9&4@
M;F]V;R!M86ES('1A<F1E+@!/8V]R<F5U('5M(&5R<F\@86\@86-T=6%L:7IA
M<B!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@4&]R(&9A=F]R('1E;G1E(&1E
M(&YO=F\@;6%I<R!T87)D92X`17-T92!S97)V:61O<B!)34%0(&[C;R!S=7!O
M<G1A('!A<G1I;&AA(&1E('!A<W1A<RX`3N-O('!A<F5C92!S97(@=6T@87)Q
M=6EV;R!R87(@=N%L:61O+@!.XV\@<&%R96-E('-E<B!U;2!A<G%U:79O('II
M<"!VX6QI9&\N`$[C;R!P87)E8V4@<V5R('5M82!N^FUE<F\@9&4@8V%R=.-O
M(';A;&ED;RX`17-T92!C;VYT<F]L861O<B!P97)M:71E(&\@96YV:6\@9&4@
M;65N<V%G96YS(&%T<F%VZ7,@9&\@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K
M871E;&PN8V]M*2P@=7-A;F1O(&$@05!)($A45%``17-T92!C;VYT<F]L861O
M<B!P97)M:71E(&\@96YV:6\@9&4@;65N<V%G96YS(&%T<F%VZ7,@9&\@<VUS
M,FUA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2P@=7-A;F1O(&$@05!)($A4
M5%``17-T92!C;VYT<F]L861O<B!P97)M:71E(&\@96YV:6\@9&4@;65N<V%G
M96YS('9I82!33510(&%T<F%VZ7,@9&$@5F]D869O;F4@273A;&EA(&4@87!E
M;F%S('!A<F$@;OIM97)O<R!6;V1A9F]N92X@17AI9V4@=6UA(&-O;G1A(&1E
M(&-O<G)E:6\@96QE8W1R\VYI8V\@;F$@5F]D869O;F4@273A;&EA("AH='1P
M.B\O=W=W+C$Y,"YI="DN`$5S=&4@8V%M<&\@Z2!O8G)I9V%T\W)I;RX`17-T
M92!C86UP;R!P;V1E(&-O;G1E<B!A<&5N87,@:6YT96ER;W,N`$5S=&4@8V%M
M<&\@<&]D92!A<&5N87,@8V]N=&5R(&[Z;65R;W,@92!O('/M;6)O;&\@9&]I
M<RUP;VYT;W,N`$5S=&4@8V%M<&\@<&]D92!C;VYT97(@87!E;F%S('9A;&]R
M97,@;V-T86ES+@!%<W1E(&-A;7!O('1E;2!D92!C;VYT97(@=6UA(&QI<W1A
M(&1E(&EN=&5I<F]S('-E<&%R861O<R!P;W(@97-P8>=O<R!O=2!V[7)G=6QA
M<RX`17-T92!C86UP;R!T96T@9&4@<V5R('5M(&[Z;65R;R!VX6QI9&\N`$5S
M=&4@8V%M<&\@=&5M(&1E(&-O;G1E<B!U;2!C\V1I9V\@9&4@8V]R(&YO(&9O
M<FUA=&\@4D="(&AE>&%D96-I;6%L+"!P;W(@97AE;7!L;R`G(S$R,S1A9B<N
M`$5S=&4@;6]D96QO(&KA(&9O:2!P<F]C97-S861O+@!)<W1O(.D@)7,N`$5S
M=&4@Z2!U;2!O8FIE8W1O($MO;&%B($=R;W5P=V%R92X@4&%R82!V97(@97-T
M92!O8FIE8W1O('!R96-I<V$@9&4@=6T@8VQI96YT92!D92!C;W)R96EO(&5L
M96-T<O-N:6-O('%U92!C;VYH9>=A(&\@9F]R;6%T;R!+;VQA8B!'<F]U<'=A
M<F4N(%!A<F$@=6UA(&QI<W1A(&1E(&-L:65N=&5S(&1E(&-O<G)E:6\@96QE
M8W1R\VYI8V\@;F5S<V%S(&-I<F-U;G-TXFYC:6%S('9I<VET92`E<P!%<W1A
M(&UE;G-A9V5M(&9O:2!E<V-R:71A(&YU;2!C\V1I9V\@*"5S*2!D:69E<F5N
M=&4@9&\@<V5U+@!%<W1E(&[Z;65R;R!P<F5C:7-A(&1E('-E<B!P96QO(&UE
M;F]S('5M+@!%<W1E(")S8W)I<'0B('1E;2!S97(@97AE8W5T861O(&$@<&%R
M=&ER(&1E('5M82!L:6YH82!D92!C;VUA;F1O<RX`17-T92!S97)V:61O<B!N
MXV\@8V]N<V5G=64@9&5S8V]M<')I;6ER(&%R<75I=F]S('II<"!O=2!G>FEP
M+@!%<W1E('-I<W1E;6$@96YC;VYT<F$M<V4@9&5S86-T:79A9&\N`$5S=&$@
M=F%L;W(@=&5M(&1E('-E<B!U;2!N^FUE<F\N`$5S=&$@:F%N96QA('1E;2!D
M92!S97(@8VAA;6%D82!A('!A<G1I<B!D92!U;6$@:F%N96QA(&1E($]PY_5E
M<P!4<F]V;V%D80!":6QH971E<P!$871A+TAO<F$`4V5G=6EM96YT;R!496UP
M;W)A;`!&;W)M871O(&1O('1E;7!O`%-E;&5CY^-O(&1A=&$O:&]R80!4:6UO
M<BU,97-T90!4[71U;&\`5.UT=6QO("AD:6-A*3H`4&%R80!087)A('-E;&5C
M8VEO;F%R(&WZ;'1I<&QO<R!I=&5N<RP@8V%R<F5G=64@96T@0V]N=')O;"`H
M4$,I(&]U($-O;6UA;F0@*$UA8RD@96YQ=6%N=&\@8VQI8V%R+@!(;VIE`%1R
M;V-A<B!&;VYT92!(5$U,`%)E</IB;&EC82!4;V=O;&5S80!4;W%U96QA=0!!
M;6%N:.,`4F5I;F\@9&\@5&]N9V$`5&]P;P!-;VQD=7)A(&1E('1O<&\@*%]T
M;W`I`%1R861U>FED87,`5')A9'7G]65S`%1R:6YD861E(&4@5&]B86=O`%9E
M<F1A9&5I<F\@;W4@9F%L<V\`,ZH`4F5P^F)L:6-A(&1A(%1U;NUS:6$`4F5P
M^F)L:6-A(&1A(%1U<G%U:6$`5'5R8V\@*$E33RTX.#4Y+3DI`%1U<G%U96UE
M;FES=.-O`$EL:&%S(%1U<F-A<R!E($-A:6-O<P!4=79A;'4`17-C<F5V82!A
M('-U82!E<V-O;&AA.@#-;F1I8V4@52Y6+CH@`%523`!54DP@9&\@<V5U(')E
M;&%T\W)I;R!D92!E<W1A9&\@9&\@96YV:6\@9&4@(G-C<FEP=',B`%523#H`
M4F5P^F)L:6-A(&1O(%5G86YD80!58W+B;FEA`$[C;R!F;VD@<&]S<^UV96P@
M86-E9&5R(.`@<&%S=&$@5D93+@!.XV\@9F]I('!O<W/M=F5L(&%D:6-I;VYA
M<B!I;F9O<FUAY^-O(&1E('5T:6QI>F%D;W(@97AT<F$@87%U86YD;R!D82!S
M=6)S8W)IY^-O+@!.XV\@9F]I('!O<W/M=F5L(&UU9&%R(&%S('!E<FUI<W/U
M97,@9&\@87)Q=6EV;R!61E,@(B5S(BX`3N-O(&9O:2!P;W-S[79E;"!M=61A
M<B!A<R!P97)M:7-S]65S(&1O(&%R<75I=F\@5D93("5S+R5S+@!.XV\@9F]I
M('!O<W/M=F5L(&UU9&%R('!A<F$@)7,N`$[C;R!F;VD@<&]S<^UV96P@;&EG
M87(@86\@<V5R=FED;W(@4U%,+@!.XV\@9F]I('!O<W/M=F5L(&QI9V%R('5S
M86YD;R!34TPN`$[C;R!F;VD@<&]S<^UV96P@8V]P:6%R(&\@87)Q=6EV;R!6
M1E,N`$[C;R!F;VD@<&]S<^UV96P@8W)I87(@82!P87-T82!61E,@(B5S(BX`
M3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!A('!A<W1A(%9&4RX`3N-O(&9O:2!P
M;W-S[79E;"!C<FEA<B!O(&%R<75I=F\@5D93+@!.XV\@9F]I('!O<W/M=F5L
M(&-R:6%R('5M(&%R<75I=F\@5D93('9A>FEO+@!.XV\@9F]I('!O<W/M=F5L
M(&1E<V-O;7!R:6UI<B!O<R!D861O<RX`3N-O(&9O:2!P;W-S[79E;"!R96UO
M=F5R("(E<R(L('!O:7,@82!P87-T82!NXV\@97-TX2!V87II82X`3N-O(&9O
M:2!P;W-S[79E;"!R96UO=F5R("(E<R(Z("5S+@!.XV\@9F]I('!O<W/M=F5L
M(')E;6]V97(@)7,L('!O:7,@82!P87-T82!NXV\@97-TX2!V87II80!.XV\@
M9F]I('!O<W/M=F5L(')E;6]V97(@82!P87-T82!61E,@<F5C=7)S:79A;65N
M=&4N`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!A('!A<W1A(%9&4RX`3N-O
M(&9O:2!P;W-S[79E;"!R96UO=F5R(&$@<&%S=&$@5D93.B`E<RX`3N-O(&9O
M:2!P;W-S[79E;"!R96UO=F5R(&\@87)Q=6EV;R!61E,@(B5S(BX`3N-O(&9O
M:2!P;W-S[79E;"!R96UO=F5R(&\@87)Q=6EV;R!61E,N`$[C;R!F;VD@<&]S
M<^UV96P@<F5M;W9E<B!R96-U<G-I=F%M96YT93H@)7,N`$[C;R!F;VD@<&]S
M<^UV96P@9&5T97)M:6YA<B!A('!A<W1A(&-O<G)E;G1E+@!.XV\@9F]I('!O
M<W/M=F5L(&5X=')A:7(@;W,@<&]R;65N;W)E<R!D;R!C97)T:69I8V%D;P!)
M;7!O<W/M=F5L(&QE<B!A(&1E9FEN:>?C;R!D92`E<RX`3N-O(&9O:2!P;W-S
M[79E;"!M;W9E<B!O(&%R<75I=F\@5D93+@!.XV\@9F]I('!O<W/M=F5L(&%B
M<FER(&\@87)Q=6EV;R!61E,@(B5S(BX`3N-O(&9O:2!P;W-S[79E;"!A8G)I
M<B!O(&%R<75I=F\@5D93('!A<F$@97-C<FET82X`3N-O(&9O:2!P;W-S[79E
M;"!A8G)I<B!O(&%R<75I=F\@5D93+@!.XV\@9F]I('!O<W/M=F5L(&%B<FER
M(&\@87)Q=6EV;R!C;VUP<FEM:61O+@!.XV\@8V]N<VEG;R!L97(@;R!A<G%U
M:79O.B``3N-O(&9O:2!P;W-S[79E;"!L97(@82!P87-T82!V9G-R;V]T+@!.
MXV\@9F]I('!O<W/M=F5L(')E;F]M96%R("5S(&-O;6\@)7,Z(&$@<&%S=&$@
M9&4@9&5S=&EN;R!JX2!E>&ES=&4`3N-O(&9O:2!P;W-S[79E;"!R96YO;65A
M<B!A('!A<W1A(%9&4RX`3N-O(&9O:2!P;W-S[79E;"!R96YO;65A<B!A('!A
M<W1A(%9&4SH@)7,N`$[C;R!F;VD@<&]S<^UV96P@<F5N;VUE87(@;R!A<G%U
M:79O(%9&4R`B)7,B+@!.XV\@9F]I('!O<W/M=F5L(')E;F]M96%R(&\@87)Q
M=6EV;R!61E,@)7,O)7,N`$[C;R!F;VD@<&]S<^UV96P@<F5N;VUE87(@87)Q
M=6EV;R!61E,N`$[C;R!F;VD@<&]S<^UV96P@97AE8W5T87(@)VUK:7-O9G,G
M+@!.XV\@9F]I('!O<W/M=F5L(&-O;G9E<G1E<B!E<W1E(&1O8W5M96YT;R!7
M;W)D`$[C;R!F;VD@<&]S<^UV96P@97-C<F5V97(@87)Q=6EV;R!61E,@(B5S
M(BX`3N-O(&9O:2!P;W-S[79E;"!E<V-R979E<B!O(&%R<75I=F\@5D93("AC
M;W!Y*"D@9F%L:&]U*2X`3N-O(&-O;G-I9V\@<F5M;W9E<B`G)7,G.B`E<RX`
M4W5B;&EN:&%D;P!$97-F87IE<B!!;'1E<F'G]65S`$1E<V9A>B!A('-U82#Z
M;'1I;6$@86/GXV\`4F5S<&]S=&$@:6YE<W!E<F%D82!D;R!S97)V:61O<B!N
M82!C;VYE>.-O.B``4F5S<&]S=&$@:6YE<W!E<F%D82!D;R!S97)V:61O<B!A
M.B``4V5M(&-A=&5G;W)I80!5;FEC;V1E("A55$8M."D`16UI<F%D;W,@P7)A
M8F5S(%5N:61O<P!296EN;R!5;FED;P!%<W1A9&]S(%5N:61O<R!D82!!;>ER
M:6-A`$EL:&%S($UE;F]R97,@1&ES=&%N=&5S(&1O<R!%<W1A9&]S(%5N:61O
M<P!5;FED861E<P!$97-C;VYH96-I9&\`87!I;7-G:60@*$E$(&1E($UE;G-A
M9V5M(&1E($%022DN`&-L:6US9VED(&1E<V-O;FAE8VED;R`H240@9&4@365N
M<V%G96T@9&4@0VQI96YT92DN`$-O;6%N9&\@9&5S8V]N:&5C:61O.B`E<P!&
M;VD@9F]R;F5C:61A('5M82!L;V-A;&EZ8>?C;R!D97-C;VYH96-I9&$N`$YO
M;64@9&4@=71I;&EZ861O<B!O=2!P86QA=G)A+7!A<W-E(&5R<F%D;W,`4F5M
M;W9E<B!L:6=AY^-O(&1O(&5L96UE;G1O(&-O<G)E;G1E`%-E;2!N;VUE`%!O
M<B!R87KU97,@9&4@<V5G=7)A;N=A+"`B<V-R:7!T<R(@<V5M('!R:79I;.EG
M:6\@;N-O('!O9&5M(&%C961E<B!A($-O<G1A<B]#;W!I87(O0V]L87(@<')O
M9W)A;6%T:6-A;65N=&4N($-A<G)E9W5E(&5M($]+('!A<F$@=F5R('5M82!N
M;W1A('3I8VYI8V$@96T@;6]Z:6QL82YO<F<@<75E(&QH92!M;W-T<F%RX2!C
M;VUO(&%U=&]R:7IA<B!U;2`B<V-R:7!T(B!A(&%C961E<B!A;W,@<F5C;W)T
M97,N`%)E;6]V97(@8V]L;W)AY^-O`$5X=&5N<^-O(&[C;R!3=7!O<G1A9&$`
M4&]R('1R861U>FER`$UO9&EF:6-A<@!!8W1U86QI>F%R("5S`$%C='5A;&EZ
M87(@=71I;&EZ861O<@`B)7,B(&%C='5A;&EZ861O+@!!8W1U86QI>F%N9&\@
M87)Q=6EV;R!D92!A:G5D82`E<R!P87)A("5S+@`B4V-R:7!T(B!D92!A8W1U
M86QI>F'GXV\@<F5M;W9I9&\N`%5P;&]A9`!#87)R96=A9&]S(&YO('-E<G9I
M9&]R('1O9&]S(&]S(&%R<75I=F]S(&1E(&EN<W1A;&'GXV\@9&4@87!L:6-A
MY_5E<RX`3&5T<F%S(&QA=&EN87,@96T@;6%I^G-C=6QA<P!.^FUE<F]S(')O
M;6%N;W,@96T@;6%I^G-C=6QA<P!297#Z8FQI8V$@3W)I96YT86P@9&\@57)U
M9W5A:0!5=&EL:7IAY^-O.@!5<V%R(&\@0V]R<F5N=&4Z("5S`%5S87(@4U-,
M+@!5<V%R('-E(&\@;F]M92!D92!U=&EL:7IA9&]R(&]U(&$@<&%L879R82UP
M87-S92!F;W)E;2!D:69E<F5N=&5S(&YO('-E<G9I9&]R($E-4U`N`%5T:6QI
M>F%D;W(@)7,@;N-O(&5S=.$@875T;W)I<V%D;R!P87)A("5S+@!!9&UI;FES
M=')AY^-O(&1E(%5T:6QI>F%D;W)E<P!/<.?U97,@9&\@571I;&EZ861O<@!2
M96=I<W1O(&1E(%5T:6QI>F%D;W)E<P!/(%)E9VES=&\@9&4@571I;&EZ861O
M<F5S(&5S=.$@:6YA8W1I=F\N`%!E<FUI<W/U97,@9&\@=71I;&EZ861O<@!.
M;VUE(&1E(%5T:6QI>F%D;W(`3R!.;VUE(&1E(%5T:6QI>F%D;W(@(B5S(B!J
MX2!E>&ES=&4N`$YO;64@9&4@571I;&EZ861O<CH`3F]M92!D92!5=&EL:7IA
M9&]R.B``571I;&EZ861O<F5S`%5T:6QI>F%D;W)E<R!D;R!S:7-T96UA.@!2
M97#Z8FQI8V$@9&\@57IB97%U:7-TXV\`02!P87-T82!61E,@;N-O(&5X:7-T
M92X`075SZFYC:6$`07,@;&]C86QI>F'G]65S(';A;&ED87,@96YC;VYT<F%D
M87,@:6YC;'5E;3H`5F%L:61A9&4N`%9A;&]R(&5M(&UI;G5T;W,@82!P87)T
M:7(@9&5S=&4@:6YS=&%N=&4N`%9A;&]R(&5X8V5D92!O(&-O;7!R:6UE;G1O
M(&WA>&EM;R!D92`E<RX`5F%L;W)E<P!0;W-S[79E;"!V86QO<F5S(&$@97-C
M;VQH97(`5F%N=6%T=0!687)IX79E;`!696YE>G5E;&$`5F5R:69I8V'GXV\@
M9F%L:&]U("T@97-T82!M96YS86=E;2!P;V1E('1E<B!S:61O(&%D=6QT97)A
M9&$N`%9E<G/C;P!#;VYT<F]L;R!D92!697)S]65S`$%L:6YH86UE;G1O(%9E
M<G1I8V%L`$-A;.=O(%9E<G1I8V%L`%9E<G1I8V%L.@!-=6ET;R!!;'1O`%)E
M</IB;&EC82!3;V-I86QI<W1A(&1O(%9I971N86UE`%9I971N86UI=&$@*%9)
M4T-)22D`5FES=6%L:7IA<B`E<P!697(@=6UA('#A9VEN82!E>'1E<FYA`%9I
M<W5A;&EZ87(@8V]M;R`E<P!);&AA<R!6:7)G96YS($)R:73B;FEC87,`26QH
M87,@5FER9V5N<R!!;65R:6-A;F%S`%9I<VEB:6QI9&%D90!6:7-I8FEL:61A
M9&4Z(`!6;V1A9F]N92!)=.%L:6$@=FEA(%--5%``059)4P!!5$5.Q\-/(2$A
M(%)%34]602!/(")30U))4%0B($U!3E5!3$U%3E1%($1%("5S+@!786QL:7,@
M92!&=71U;F$`079I<V\`079I<V\Z(``TJ@!0<F5V:7/C;R!D;R!496UP;P!$
M861O<R!M971E;W)O;/-G:6-O<R!F;W)N96-I9&]S('!O<@!796%T:&5R+F-O
M;0!796(`4.%G:6YA`%-E;6%N86QM96YT90!"96TM=FEN9&$H;RD`0F5M+79I
M;F1A*&\I(&$@)7,`0F5M+79I;F1A*&\I+"`E<P!/8VED96YT86P@*$E33RTX
M.#4Y+3$I`$]C:61E;G1A;"`H25-/+3@X-3DM,34I`%-A87)A`%%U92!A<&QI
M8V'GXV\@9&5V92!O("5S(&UO<W1R87(@87#S<R!A(&5N=')A9&$_`%%U86P@
MZ2!O(&-A<F%C=&5R92!D96QI;6ET861O<C\`475A;"#I(&\@8V%R86-T97)E
M(&1E(&-I=&'GXV\_`%%U92!F87-E<P!1=64@(G!L=6=I;G,B(&%C=&EV87(@
M<&%R82!A($5D:>?C;R!2:6-A+@!,87)G=7)A`$QA<F=U<F$@96T@=6YI9&%D
M97,@0U-3`$QA<F=U<F$@9&\@365N=2`E<R#@(&5S<75E<F1A("AT96T@969E
M:71O(&YA('!R\WAI;6$@96YT<F%D82DZ`$QA<F=U<F$@9&$@=&%B96QA`%5N
M:61A9&4@9&4@;&%R9W5R80!,87)G=7)A.@!7:6MI`%9E;G1O`%9E;G1O($UA
M=&EN86P`5F5L;V-I9&%D92!D;R!V96YT;R!E;2!N\W,`5F5N=&\Z`%9E;G1O
M.B``4V%B961O<FEA`$QI<W1A<R!D92!$97-E:F]S`%1R86)A;&AO`$5N9&5R
M9>=O("A%;7!R96=O*0!496QE9F]N92`H16UP<F5G;RD`17-C<F5V96YD;R!A
M<G%U:79O(&1E(&%J=61A(&%C='5A;&EZ861O('!A<F$@)7,N`%)E9F5RZFYC
M:6%S(&-R=7IA9&%S`%)E<W1R:>?U97,@0N%S:6-A<R!8-3`Y=C,`571I;&EZ
M8>?C;R!D92!#:&%V92!%>'1E;F1I9&$@6#4P.78S`$YO;64@06QT97)N871I
M=F\@9&4@4W5J96ET;R!8-3`Y=C,`261E;G1I9FEC861O<B!#:&%V92!D92!3
M=6IE:71O(%@U,#EV,P!%>'1E;G/U97,@6#4P.78S`$%!`$%!04$`36%P82!9
M86AO;R$`06YU86QM96YT90!)Z6UE;@!3:6T`4VEM+"!#;VYC;W)D;P!%<W3A
M(&5M($U/1$\@9&4@5$585"X@(%5S92!O(&)O=.-O(%L\/ET@<&%R82!T<F]C
M87(@<&%R82!O(&UO9&\@5DE354%,+@!.XV\@97-TX2!A=71E;G1I8V%D;RX`
M3N-O('!O9&4@=&5R(&\@8V%R86-T97)E("=<)R!N;R!S974@;F]M92!C;VUP
M;&5T;RX`3N-O(&EN=')O9'5Z:74@=6T@96YD97)EYV\@9&4@8V]R<F5I;R!E
M;&5C='+S;FEC;R!VX6QI9&\N`$[C;R!M87!E;W4@;F5N:'5M(&-A;7!O(&1O
M(&%R<75I=F\@:6UP;W)T861O('!A<F$@;W,@8V%M<&]S(&-O<G)E<W!O;F1E
M;G1E<R!E;2`E<RX`06-A8F]U(&1E('-A:7(N`%1E;2!D92!I;G1R;V1U>FER
M('5M(&[Z;65R;R!D92!T96QE;?-V96P@=N%L:61O+"!S\R!C;VT@9.UG:71O
M<RP@;6%S(&-O;2!U;2`G*R<@;W!C:6]N86P@<&%R82!O('!R969I>&\@:6YT
M97)N86-I;VYA;"X`5&5M(&1E(&EN=')O9'5Z:7(@=6T@=F%L;W(@=N%L:61O
M+@!496T@9&4@8V]N9FEG=7)A<B!U;2!M96-A;FES;6\@8N%S:6-O('!A<F$@
M1&%T851R964@<V4@<75I<V5R('5S87(@4W5B<V-R:>?U97,`5&5M(&1E(&-O
M;F9I9W5R87(@=6T@;65C86YI<VUO(&)A<V4@<&%R82!O(%9&4RX`1&5V92!D
M97-C<F5V97(@;R!P<F]B;&5M82!A;G1E<R!D92!E;G9I87(@;R!R96QA=/-R
M:6\N`%1E;2!D92!I;G1R;V1U>FER(&\@55),(&1O(')E8W5R<V\@<75E(&5S
M=&$@;&EG8>?C;R!S92!R969E<F4`5&5M(&1E('-E;&5C8VEO;F%R('5M('-E
M<G9I9&]R(&$@<F5M;W9E<BX`1&5V92!E<W!E8VEF:6-A<B!O('5T:6QI>F%D
M;W(@82!L:6UP87(N`$1E=F4@97-P96-I9FEC87(@;R!N;VUE(&1O('5T:6QI
M>F%D;W(@82!R96UO=F5R+@!496T@9&4@97-P96-I9FEC87(@;R!N;VUE(&1O
M('5T:6QI>F%D;W(@82!A9&EC:6]N87(N`%1E;2!D92!E<W!E8VEF:6-A<B!O
M('5T:6QI>F%D;W(@82!A8W1U86QI>F%R+@!496T@9&4@97-P96-I9FEC87(@
M82!A8^?C;R!A(&1E<V5M<&5N:&%R+@!496T@9&4@:6YT<F]D=7II<B!U;2!N
M;W9O(&YO;64@9&4@8V%T96=O<FEA+@!496T@9&4@9F]R;F5C97(@=6T@;OIM
M97)O(&1E('1E;&5F;VYE(&ET86QI86YO`$$@<W5A('-E<W/C;R`E<R!E>'!I
M<F]U+B!0;W(@9F%V;W(@96YT<F4@9&4@;F]V;RX`3R!S974@16YD97)EYV\@
M9&4@0V]R<F5I;R!%;&5C='+S;FEC;SH`3R!S974@96YD97)EYV\@(D1E.B(`
M02!S=6$@26YF;W)M8>?C;P!/('-E=2!E;F1E<F7G;R!)4"!P87)E8V4@=&5R
M(&UU9&%D;R!D97-D92!O(&EN[6-I;R!D82!S97-SXV\@)7,N(%!A<F$@9V%R
M86YT:7(@82!S=6$@<V5G=7)A;N=A+"!D979E(&%U=&5N=&EC87(M<V4@9&4@
M;F]V;RX`3R!3974@3F]M90!/('-E=2!M96-A;FES;6\@9&4@875T96YT:6-A
MY^-O(&[C;R!S=7!O<G1A(&%D:>?C;R!D92!U=&EL:7IA9&]R97,@;W4@97-T
M82!O<.?C;R!F;VD@9&5S86-T:79A9&$@<&]R(&%L9W5M(&]U=')O(&UO=&EV
M;RX`3R!S974@;65C86YI<VUO(&1E(&%U=&5N=&EC8>?C;R!NXV\@<W5P;W)T
M82!L:7-T86=E;2!D92!U=&EL:7IA9&]R97,@;W4@97-T82!O<.?C;R!F;VD@
M9&5S86-T:79A9&$@<&]R(&%L9W5M(&]U=')O(&UO=&EV;RX`3R!S974@;F%V
M96=A9&]R('!A<F5C92!T97(@;75D861O(&1E<V1E(&\@:6[M8VEO(&1A('-E
M<W/C;R`E<RX@4&%R82!G87)A;G1I<B!A('-U82!S96=U<F%NYV$L(&1E=F4@
M875T96YT:6-A<BUS92!D92!N;W9O+@!/('-E=2!N879E9V%D;W(@;N-O('-U
M<&]R=&$@97-T82!F=6YC:6]N86QI9&%D92X`3R!S974@;F%V96=A9&]R(&[C
M;R!S=7!O<G1A(&5S=&$@;W#GXV\@9&4@:6UP<F5S<^-O+B!0<F5S<VEO;F4@
M0V]N=')O;"]#;VUM86YD("L@4"!P87)A(&EM<')I;6ER+@!&=7-O(&AO<N%R
M:6\@86-T=6%L.@!)9&5N=&ED861E('!A9'+C;SH`3F]M92!C;VUP;&5T;P!!
M('-U82!V97)SXV\@9&\@9V5T=&5X="#I(&1E;6%S:6%D;R!A;G1I9V$L(&[C
M;R!S=7!O<G1A;F1O(%!(4"!D92!F;W)M82!N871I=F$N($YE;2!T;V1A<R!A
M<R!C861E:6%S(&1E(&-A<F%C=&5R97,@<V5RXV\@97AT<F'M9&%S+@!!('-U
M82!N;W9A('!A;&%V<F$M<&%S<V4@<&%R82`E<R#I.B`E<P!!<R!S=6%S(&]P
MY_5E<R!F;W)A;2!A;'1E<F%D87,@873I(&%O(&9I;F%L(&1E<W1A('-E<W/C
M;RX`07,@<W5A<R!O<.?U97,@9F]R86T@86-T=6%L:7IA9&%S+@!!('-U82!P
M86QA=G)A+7!A<W-E(&9O:2!R96-R:6%D80!!('-U82!P86QA=G)A+7!A<W-E
M(&9O:2!R96-R:6%D82P@=F5R:69I<75E(&\@<V5U(&-O<G)E:6\@96QE8W1R
M\VYI8V\@92!E;G1R92!C;VT@82!S=6$@;F]V82!P86QA=G)A+7!A<W-E+@!/
M<R!S975S('-E<G9I9&]R97,@<F5M;W1O<SH`2G5G;W-LX79I80!:86ER90!:
MXFUB:6$`6FEM8F%B=>D`6FEP<'D`6T5S8V]N9&5R(%1E>'1O($-I=&%D;UT`
M6U)E;&%T\W)I;R!D92!0<F]B;&5M87-=(`!;36]S=')A<B!497AT;R!#:71A
M9&\@+0!;36]S=')A<B!497AT;R!#:71A9&\@+2`E<R!L:6YH87-=`%ML:6YH
M82`E<R!D92`E<UT`7T%D;6EN:7-T<F'GXV\`7T-O;G-O;&$`P7)?=F]R90!?
M4F5M;W9E<B!,:6YH80!?1W)U<&]S`$%?:G5D80!0<F]P<FEE9&%D97,@9&$@
M7TEM86=E;0!?16YT<F%R`%]386ER`%]-;V1I9FEC87(@3&EG8>?C;P!?3W#G
M]65S`%]097)M:7-S]65S`%]296UO=F5R($QI9V'GXV\N+BX`7T-O;F9I9W5R
M8>?C;P!0<F]P<FEE9&%D97,@9&$@7U1A8F5L80!?571I;&EZ861O<F5S`&-O
M;G1A8W1O<P!O8V]R<F5U('5M(&5R<F\Z`&-A;&5N9.%R:6\`8V%L;6\`8VQI
M<75E(&%Q=6D`9F5I=&\`9F%L:&]U`&1I;6EN=6EN9&\`9FEC:&5I<F\`96YC
M;VYT<F%D;SH@`&1O("5S("@E<RD@X',@)7,@)7,`<F%J861A<P!H.@!H:`!I
M;65D:6%T;P!E;2!L:6YH80!L:6YH87-=`$5R<F\@;6MI<V]F<R!C;VT@8_-D
M:6=O("5D(&%O(&-O;G-T<G5I<B!)4T\N`&UM`&YO;64`<V5M(&%L=&5R8>?U
M97,`;N-O(&5N8V]N=')A9&\`;N-O(&EM<&QE;65N=&%D80!A:6YD82!P;W(@
M:6UP;&5M96YT87(`8V%D97)N;R!D92!N;W1A<P!P97)C96YT86=E;0!P[7AE
M:7,`<W5B:6YD;P!M;W-T<F%R(&1I9F5R96[G87,`<VUS,F5M86EL('9I82!(
M5%10`'-S`&5S=.%V96P`;&ES=&$@9&4@=&%R969A<P!/(&9I8VAE:7)O(%!/
M('!A<F$@;R!L;V-A;&4@)7,@;N-O(&5X:7-T92X`:6YT<F]D=7IA(&$@<&%L
M879R82UP87-S92!D=6%S('9E>F5S+"!P87)A(&-O;F9I<FUAY^-O`'5N:69I
M8V%D;P!S96T@;F]M90!A8W1U86QI>F%D;P!S96QE8V-I;VYA9&$@<&5L;R!U
M=&EL:7IA9&]R`'9#87)D`%)E96YC.@!W96%T:&5R+F-O;0``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO
M8V%L92]R;U]23R\`````````````````````````````````````````````
M````````````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-30`,#(P,3,V`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&]C86QE+W)O7U)/+TQ#7TU%4U-!1T53+P``````
M```````````````````````````````````````````````````````````P
M,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U
M-``P,C$W,C,`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O<F]?4D\O
M3$-?34534T%'15,O:&]R9&4N;6\`````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#$S-S$U`#$P-3$U-#,S-S4T`#`R,S,W,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#>$@25`````&0````<````/`,``(D`
M``!<!@```````(`(```H````@0@```@```"J"```!0```+,(```(````N0@`
M``<```#""```!0```,H(```?````T`@``!$```#P"```"`````()```(````
M"PD``!4````4"0``"@```"H)```,````-0D```<```!""0``*0```$H)```"
M````=`D```4```!W"0``$````'T)```4````C@D``"\```"C"0``#P```-,)
M```F````XPD```4````*"@``#0```!`*```%````'@H``!`````D"@``$```
M`#4*```/````1@H```L```!6"@``#P```&(*```,````<@H```\```!_"@``
M'@```(\*```A````K@H```,```#0"@``!````-0*```,````V0H```H```#F
M"@``!0```/$*```2````]PH``!`````*"P``"````!L+```0````)`L```8`
M```U"P``!P```#P+```"````1`L```0```!'"P``#P```$P+```'````7`L`
M``<```!D"P``!````&P+```%````<0L```4```!W"P``!P```'T+```1````
MA0L```@```"7"P``'@```*`+```%````OPL``"@```#%"P``*0```.X+```3
M````&`P```L````L#```$0```#@,```$````2@P```P```!/#```&@```%P,
M```7````=PP``!<```"/#```&P```*<,```?````PPP``!,```#C#```$```
M`/<,```7````"`T```<````@#0``!0```"@-```A````+@T``!P```!0#0``
M!0```&T-```#````<PT``"````!W#0``)@```)@-```,````OPT```P```#,
M#0``"````-D-```'````X@T```8```#J#0``#0```/$-```+````_PT```P`
M```+#@``"@```!@.```"````(PX```8````F#@``10```"T.```P````<PX`
M`!````"D#@``'P```+4.```0````U0X```\```#F#@``!0```/8.``!;`0``
M_`X``"@```!8$```"0```($0```%````BQ````\```"1$```!@```*$0```%
M````J!```",```"N$```%````-(0```/````YQ````@```#W$```$0`````1
M```-````$A$``!$````@$0``"````#(1```H````.Q$```(```!D$0``!@``
M`&<1```4````;A$``!````"#$0``,0```)01```2````QA$``"<```#9$0``
M!0````$2```9````!Q(```8````A$@``$P```"@2```4````/!(``!,```!1
M$@``%````&42```3````>A(``!````".$@``$@```)\2```9````LA(``"8`
M``#,$@```P```/,2```$````]Q(```\```#\$@``$@````P3```%````'Q,`
M`!$````E$P``$@```#<3```%````2A,``!H```!0$P``"0```&L3```+````
M=1,```(```"!$P``#0```(03```=````DA,```4```"P$P``!0```+83```$
M````O!,```D```#!$P``!````,L3```'````T!,```\```#8$P``!@```.@3
M```B````[Q,```<````2%```)P```!H4```P````0A0``!0```!S%```#P``
M`(@4```1````F!0``!````"J%```#P```+L4```4````RQ0``!P```#@%```
M&P```/T4```B````&14``!L````\%0``&````%@5```5````<14``!8```"'
M%0``!@```)X5```'````I14``!8```"M%0``*````,05```%````[14```,`
M``#S%0``(@```/<5```N````&A8``!0```!)%@``$@```%X6```*````<18`
M``<```!\%@``"@```(06```<````CQ8``!$```"L%@``$@```+X6```3````
MT18```(```#E%@``!0```.@6```Z````[A8``#L````I%P``%@```&47```:
M````?!<``!$```"7%P``$0```*D7```1````NQ<```$````D`````````$X`
M```=````3P```!<```!%````!P```"(`````````30```"$`````````2P``
M`&(````*````$0`````````,````,@```%,````Q`````````"4```!&````
M70````````!2````0@```%4`````````1P```"P````O````5@```%$````U
M````$`````@````^````00```%\````K````#P```#D```!*````(P```!@`
M```S````0````"@```!@````"P``````````````5```````````````/0``
M``D`````````+@```$@```!<````.@`````````.`````````%D`````````
M-@`````````;````/P```!P````:````#0```#L`````````!`````4`````
M````$@`````````3`````````%<````M`````````"8``````````````!4`
M```&`````````%L````W````&0````````!>`````````#@````T````````
M`$D````?````6@```$0`````````'@``````````````8P````````!8````
M*0`````````P```````````````\````9````%``````````%@```"``````
M`````P```&$```!#````*@```"<```!,`````@`````````4`````"5S($UA
M:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`,C0@:&]U<G,`
M04TO4$T`061D('!A:7(`061D<F5S<P!!;&EA<P!!;B!I;&QE9V%L('9A;'5E
M('=A<R!S<&5C:69I960N`$%V86EL86)L92!F:65L9',Z`$)I<G1H9&%Y`$-A
M;&5N9&%R`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#96QL(%!H;VYE`$-L;W-E
M(%=I;F1O=P!#;VUP86YY`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A
M<VL@;6]D=6QE("5S`$1$`$1A:6QY`$1E9F%U;'0@261E;G1I='D`1&5S8W)I
M8F4@=&AE(%!R;V)L96T`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T
M:&4@861M:6YI<W1R871O<BX`1&ES<&QA>2!/<'1I;VYS`$1O(&YO="!D:7)E
M8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$5M86EL`$5M<'1Y(')E<W5L
M="X`17)R;W(`179E<GD@,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V
M97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E
M<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!&86EL960@<F5T<FEE=FEN9R!P
M<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N
M`$9A>`!(96QP`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$EM<&]R
M=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$QA;F=U86=E`$QI<W0@
M2&5L<"!4;W!I8W,`3&]G(&EN`$QO9R!O=70`34T`36%I;`!-871C:&EN9R!F
M:65L9',`365S<V%G90!-;VYT:&QY`$YA;64`3F5V97(`3F]T97,`3W!T:6]N
M<P!/=&AE<B!);F9O<FUA=&EO;@!087-S=V]R9`!097)F;W)M($UA:6YT96YA
M;F-E($]P97)A=&EO;G,`4&AO;F4`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y
M(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE
M(&%N9"!P87-S=V]R9`!0<F]B;&5M($1E<V-R:7!T:6]N`%)E;6]V92!P86ER
M`%)E='5R;B!T;R!/<'1I;VYS`%)O;&4`4V%V92!/<'1I;VYS`%-E;&5C="!T
M:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E
M;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE
M;&1S+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O
M8FQE;2!297!O<G0`4VMI<"!-86EN=&5N86YC90!3<&5C:6%L($-H87)A8W1E
M<B!);G!U=`!3=6-C97-S`%1A<VMS`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@
M;&5A<W0@;VYE+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1I=&QE
M`%523`!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@
M=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F1O($-H86YG97,`
M57-E<B!/<'1I;VYS`%5S97)N86UE`%=A<FYI;F<`5V5E:VQY`%=E;&-O;64@
M=&\@)7,`5V5L8V]M92P@)7,`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`65D`
M665A<FQY`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y
M;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W5R("5S('-E<W-I
M;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!);F9O
M<FUA=&EO;@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%M0<F]B
M;&5M(%)E<&]R=%T`6VQI;F4@)7,@;V8@)7-=`'9#87)D`%!R;VIE8W0M260M
M5F5R<VEO;CH@2$]21$4@,BXQ"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`
M;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X
M(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P,BTP."TP,2`P.3HS
M-"LP,CHP,`I,87-T+51R86YS;&%T;W(Z($-O<FYE;&EU($U54T%4(#QC;75S
M871`:V5Y<WES+G)O/@I,86YG=6%G92U496%M.B!23TU!3DE!3B`\:3$X;D!L
M:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP
M93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ"D-O;G1E;G0M5')A
M;G-F97(M16YC;V1I;F<Z(#AB:70*`"5S($]P97)A=&EU;FD@9&4@;65N=&5N
M86YT82`M($-O;F9I<FUA<F4`,C0@9&4@;W)E`$%-+U!-`$%D875G82!P97)E
M8VAE80!!9')E<V$`06QI87,`4RUA('-P96-I9FEC870@;R!V86QO87)E(&EN
M8V]R96-T82X`0VEM<'5R:2!D:7-P;VYI8FEL93H`6FEU82!D92!N87-T97)E
M`$-A;&5N9&%R`%)E;G5N=&$@;&$@4F%P;W)T`%1E;&5F;VX@36]B:6P`26YC
M:&ED92!F97)E87-T<F$`0V]M<&%N:6$`3G4@<&]T(&1E<V-H:61E(&UO9'5L
M=6P@9&4@365N=&5N86YT82`E<P!:6@!::6QN:6,`261E;G1I=&%T92!);7!L
M:6-I=&$`1&5S8W)I92!P<F]B;&5M80!$971A;&EI(&EN<F5G:7-T<F%T92!I
M;B!,3T<@<&5N=')U(&%D;6EN:7-T<F%T;W(N`$]P=&EU;FD@9&4@069I<V%R
M90!492!R;V<@;G4@86-C97-A(&1I<F5C="!M86EN=&5N86YC92YP:'``16UA
M:6P`16UP='D@<F5S=6QT+B`M(&1E('1R861U<P!%<F]A<F4`3R!D871A(&QA
M(#$U(&UI;G5T90!/(&1A=&$@;&$@,S`@<V5C=6YD90!,82!F:65C87)E(#4@
M;6EN=71E`$QA(&9I96-A<F4@0V]N96-T87)E`$\@9&%T82!L82`S,"!M:6YU
M=&4`26X@9FEE8V%R92!M:6YU=`!%>&5M<&QE(&1E('9A;&]R:3H`3G4@<&]T
M(&-I=&D@<')E9F5R:6YT96QE+@!.=2!M82!P;W0@8V]N96-T82!L82!S97)V
M97)U;"!D92!,1$%0+@!&87@`2&5L<`!!9')E<V$@9&4@86-A<V$`5&5L969O
M;G5L(&1E(&%C87-A`$AO<F1E`$-I;7`@:6UP;W)T870Z("5S`$-I;7!U<FD@
M:6UP;W)T871E.@!,:6UB80!,:7-T82!S=6)I96-T96QO<B!D:6X@2&5L<`!#
M;VYE8W1A<F4`1&5C;VYE8W1A<F4`3$P`0V]R97-P;VYD96YT80!#:6UP=7)I
M('!O=')I=FET92`M(&1E('1R861U<P!-97-A:@!,=6YA<@!.=6UE`$YI8VEO
M9&%T80!.;W1E`$]P=&EU;FD`06QT92!I;F9O<FUA=&EI`%!A<F]L80!%>&5C
M=71A($]P97)A=&EU;FEL92!D92!-96YT96YA;G1A`%1E;&5F;VX`5&4@<F]G
M('-P96-I9FEC82!U;B!S=6UA<B!A;"!P<F]B;&5M96DN`%1E(')O9R!I;G1R
M;V1U('5N(&YU;64@9&4@=71I;&EZ871O<B!S:2!O('!A<F]L80!$97-C<FEE
M<F5A('!R;V)L96UE:0!3=&5R9V4@<&5R96-H96$`26YA<&]I(&QA(&]P=&EU
M;FD`4F]L92`M(&1E('1R861U<P!386QV87IA($]P=&EU;FD`1&5L:6UI=&%T
M;W(@9&4@9&%T83H`1F]R;6%T=6P@9&4@869I<V%R92!A(&1A=&5I.@!&;W)M
M871U;"!D92!A9FES87)E(&$@;W)E:3H`4V5L96-T96%Z82!D;W5A(&-I;7!U
M<FD@<&]T<FEV:71E+@!396QE8W1E87IA(&QI;6)A('!R969E<F%T83H`5')I
M;6ET92!287!O<G0@9&4@17)O87)E`%-A<FD@<&5S=&4@365N=&5N86YT80!#
M87)A8W1E<F4@4W!E8VEA;&4@+BXN`%-U8V-E<P!387)C:6YI`%9A;&]A<F5A
M(&UI;FEM82!E<W1E(#$`06-E87-T82!V86QO87)E('1R96)U:64@<V$@9FEE
M(&YU;65R:6-A+@!4:71L=0!54DP`3G4@;6$@<&]T(&-O;F5C=&$@;&$@<V5R
M=F5R=6P@4U%,+@!.=2!P;W0@=')A9'5C92!A8V5S="!D;V-U;65N="!7;W)D
M("T@9&4@=')A9'5S`$%N=6QE87IA(%-C:&EM8F%R:6QE`$]P=&EU;FD@571I
M;&EZ871O<@!5=&EL:7IA=&]R`$%T96YT:64`4V%P=&%M:6YA;`!":6YE(&%I
M('9E;FET(&EN('-I<W1E;75L("5S`$)I;F4@86D@=F5N:70L("5S`$%D<F5S
M82!L82!397)V:6-I=0!496QE9F]N(&QA(%-E<G9I8VEU`$%!`$%N=6%L`%1R
M96)U:64@<V$@9&5S8W)I:2!P<F]B;&5M82!I;F%I;G1E(&1E(&$@=')I;6ET
M92!R87!O<G1U;"X`4V5S:75N96$@=&$@9&4@)7,@82!E>'!I<F%T+B!492!R
M;V<@<V$@9F%C:2!,;V<@26X@9&EN(&YO=2X`26YF;W)M871I:2!D97-P<F4@
M=&EN90!/<'1I=6YI;&4@874@9F]S="!S86QV871E+@!;4F%P;W)T(%!R;V)L
M96UA70!;;&EN:6$@)7,@9&EN("5S70!V0V%R9"`M(&1E('1R861U<P``````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]R=5]252\`````
M````````````````````````````````````````````````````````````
M````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`U,34T,S,W-30`,#(P,34R`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&]C86QE+W)U7U)5+VAE;'`N>&UL````````````````````````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,S,R,``Q,#4Q-30S,S<U-``P,C$V,C(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]X;6P@=F5R
M<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O<G5?4E4O
M:&5L<"YX;6PL=B`Q+C(@,C`P-"\P-2\R-R`R,#HR,CHQ,R!J86X@17AP("0@
M+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4](FYE=R(^
M"CQT:71L93Y4:&4@4&]R=&%L(%!A9V4\+W1I=&QE/@H@/'!A<F$^"B`@5&AI
M<R!P;W)T86P@<&%G92!P<F]V:61E<R!A('%U:6-K('-U;6UA<GD@;V8@86QL
M('EO=7(@:6UP;W)T86YT"B`@:6YF;W)M871I;VXN($9O<B!E>&%M<&QE+"!I
M="!M:6=H="!S:&]W(&AO=R!M86YY(&YE=R!E+6UA:6P@;65S<V%G97,@>6]U
M"B`@:&%V92!I;B!Y;W5R($E.0D]8+"!U<&-O;6EN9R!E=F5N=',@;VX@>6]U
M<B!C86QE;F1A<BP@=&%S:W,@;VX@>6]U<B!T;RUD;PH@(&QI<W0L(&AE861L
M:6YE<R!F<F]M('-E;&5C=&5D(&YE=W,@<V5R=FEC97,L(&%N9"!S;R!O;BX@
M($UA;GD@;V8@=&AE<V4*("!S=6UM87)I97,@=VEL;"!C;VYT86EN('%U:6-K
M('-H;W)T8W5T<R!T;R!C;VUM;VX@9G5N8W1I;VYS+"!S=6-H(&%S"B`@8V]M
M<&]S:6YG(&$@;F5W(&UA:6P@;65S<V%G92P@8W)E871I;F<@82!N97<@8V%L
M96YD87(@979E;G0@;W(@=&%S:RP@971C+@H@/"]P87)A/@H@/'!A<F$^"B`@
M5&AE(&-O;G1E;G1S(&]F('1H:7,@<&]R=&%L('!A9V4@87)E(&-U<W1O;6EZ
M86)L92!V:6$@=&AE($QA>6]U="!B=71T;VXN"B`@1F]R(&5X86UP;&4L('EO
M=2!C86X@8VAO;W-E('=H:6-H(&ET96US('1O(&EN8VQU9&4@;VX@=&AI<R!P
M;W)T86P@<&%G92!A<PH@('=E;&P@87,@:6X@=VAI8V@@;W)D97(@=&AE>2!A
M<F4@<VAO=VXN"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)N879B
M87(B('-T871E/2)N97<B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG
M871I;VX@0F%R/"]T:71L93X*(#QP87)A/@H@($%T('1H92!L969T(&AA;F0@
M<VED92!O9B!T:&4@=V5B('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N(&YA=FEG
M871I;VX@8F%R+@H@($-L:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES(&YA=FEG
M871I;VX@8F%R('1O('%U:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*("!B971W
M965N('1H92!A=F%I;&%B;&4@87!P;&EC871I;VYS+@H@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B('-T871E
M/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@
M1&\@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@
M=V]U;&0@;&EK92!T;R!P97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M;VX@;&]G:6XL(&-H96-K('1H:7,@8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC92(@<W1A
M=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E
M.B!#;VYF:7)M($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@
M268@>6]U('=O=6QD(&QI:V4@=&\@8V]N9FER;2!A;&P@;6%I;G1E;F%N8V4@
M=&%S:W,@8F5F;W)E('1H97D@87)E(')U;BP@8VAE8VL@=&AI<R!B;W@N($EF
M(&QE9G0@=6YC:&5C:V5D+"!A;&P@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!T
M:&%T(&YE960@=&\@8F4@<G5N('=I;&P@8F4@<&5R9F]R;65D(&%U=&]M871I
M8V%L;'D@=VET:"!N;R!C:&%N8V4@=&\@8V%N8V5L(&]N(&QO9VEN+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L
M92]R=5]252],0U]-15-304=%4R\`````````````````````````````````
M````````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-30`,#(Q-S,W`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&]C86QE+W)U7U)5+TQ#7TU%4U-!1T53+VAO<F1E+FUO
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T,C,W-0`Q,#4Q-30S,S<U-``P
M,C,T,3``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````WA($E0`````C`0``'````#0)``"%`0``3!(```````!@&```*````&$8
M```.````BA@```X```"9&```"````*@8```%````L1@``!,```"W&````P``
M`,L8```)````SQ@```@```#9&```)````.(8```'````!QD```P````/&0``
M+````!P9```.````21D```4```!8&0``%P```%X9```*````=AD```\```"!
M&0``(P```)$9```4````M1D``!<```#*&0``%P```.(9```?````^AD```L`
M```:&@``%0```"8:```Y````/!H``"P```!V&@``*@```*,:```1````SAH`
M``@```#@&@``#@```.D:```*````^!H```@````#&P``!@````P;```5````
M$QL``!4````I&P``"@```#\;``!4````2AL``$0```"?&P``$P```.0;```<
M````^!L```P````5'```$````"(<```'````,QP``!T````['```*0```%D<
M```&````@QP``!````"*'```$P```)L<```,````KQP``"@```"\'````@``
M`.4<```%````Z!P```0```#N'```#0```/,<```0`````1T```8````2'0``
M&````!D=```4````,AT``"\```!''0``"0```'<=```6````@1T```\```"8
M'0``)@```*@=``!#````SQT```@````3'@``"P```!P>```$````*!X```H`
M```M'@``%P```#@>```1````4!X```4```!B'@``#0```&@>```@````=AX`
M``4```"7'@``$````)T>```/````KAX``!````"^'@``#P```,\>```+````
MWQX```\```#K'@``#````/L>```/````"!\```8````8'P``'@```!\?```A
M````/A\```,```!@'P``!````&0?```,````:1\```<```!V'P``$````'X?
M```.````CQ\```(```">'P``#0```*$?```&````KQ\``!$```"V'P``!P``
M`,@?```$````T!\```H```#5'P``(@```.`?```%`````R````0````)(```
M#`````X@```*````&R````4````F(```"@```"P@```/````-R```!````!'
M(```!@```%@@```/````7R```!(```!O(```$````((@```0````DR````<`
M``"D(```"````*P@```.````M2```!8```#$(```$0```-L@```&````[2``
M`!````#T(```#P````4A```(````%2$```8````>(0``!P```"4A```%````
M+2$```L````S(0```@```#\A```$````0B$``&@```!'(0``#P```+`A```*
M````P"$```<```#+(0``!P```-,A```+````VR$```D```#G(0``"0```/$A
M```*````^R$```<````&(@``"0````XB```'````&"(```H````@(@``%@``
M`"LB```$````0B(```4```!'(@``#````$TB```$````6B(```0```!?(@``
M#````&0B```"````<2(```D```!T(@``!````'XB```3````@R(```4```"7
M(@```@```)TB```'````H"(```X```"H(@``"@```+<B```1````PB(```@`
M``#4(@``"0```-TB```*````YR(``!X```#R(@``*````!$C```*````.B,`
M``L```!%(P``%````%$C```%````9B,``"D```!L(P``*````)8C```I````
MOR,``!````#I(P``!P```/HC```3`````B0```0````6)```!P```!LD```>
M````(R0``!0```!")```#@```%<D```J````9B0```8```"1)```#````)@D
M```+````I20```4```"Q)```$0```+<D```8````R20```0```#B)```!```
M`.<D```,````["0```8```#Y)```#P`````E```*````$"4```L````;)0``
M&@```"<E```7````0B4``"<```!:)0``%P```((E```;````FB4``!D```"V
M)0``'P```-`E```3````\"4``#\````$)@``-P```$0F``!7````?"8```4`
M``#4)@``#0```-HF```M````Z"8```0````6)P``)0```!LG```?````02<`
M`!T```!A)P``!@```'\G```$````AB<``!````"+)P``$P```)PG```7````
ML"<```8```#()P``!P```,\G```&````UR<```<```#>)P``-````.8G```5
M````&R@```X````Q*```!0```$`H```)````1B@``"$```!0*```'P```'(H
M```?````DB@``#````"R*```+P```.,H```A````$RD``!P````U*0``!P``
M`%(I```+````6BD```4```!F*0```@```&PI``!9````;RD```,```#)*0``
M(````,TI```D````[BD``"8````3*@``#````#HJ```'````1RH```8```!/
M*@``,@```%8J```$````B2H```P```".*@``"````)LJ```)````I"H```H`
M``"N*@``!P```+DJ```9````P2H```<```#;*@```P```.,J```&````YRH`
M``T```#N*@``"P```/PJ```O````""L```P````X*P``,0```$4K```_````
M=RL```P```"W*P``"@```,0K```"````SRL```8```#2*P```P```-DK```9
M````W2L``$4```#W*P``,````#TL```2````;BP``!,```"!+```$````)4L
M```)````IBP``!<```"P+```%@```,@L```/````WRP``!\```#O+```%```
M``\M```0````)"T```\````U+0``#P```$4M```'````52T```4```!=+0``
M"````&,M```(````;"T```P```!U+0``!@```((M```&````B2T```0```"0
M+0``!P```)4M```%````G2T``%H!``"C+0``)0```/XN```*````)"\```H`
M```O+P``!P```#HO```%````0B\```X```!(+P``"````%<O```)````8"\`
M``T```!J+P``&````'@O```%````D2\```X```"7+P``,P```*8O```*````
MVB\```D```#E+P``#````.\O```*````_"\```D````',```'@```!$P```3
M````,#````<```!$,```%@```$PP```C````8S````H```"',```"0```)(P
M``!"````G#```"0```#?,```*@````0Q```/````+S$```T````_,0``"@``
M`$TQ```*````6#$```D```!C,0``!@```&TQ```8````=#$``!$```"-,0``
M%````)\Q```A````M#$``#X```#6,0``%````!4R```8````*C(```P```!#
M,@``"P```%`R```(````7#(``!4```!E,@``*@```'LR```'````IC(``!4`
M``"N,@``"0```,0R```-````SC(``"(```#<,@```@```/\R```)`````C,`
M``0````,,P``$0```!$S```4````(S,```<````X,P``&0```$`S```0````
M6C,``#8```!K,P``!P```*(S```F````JC,``!````#1,P``+````.(S``!!
M````#S0```D```!1-```#````%LT```.````:#0```T```!W-```%0```(4T
M```)````FS0```4```"E-```$@```*LT```N````OC0```8```#M-```#P``
M`/0T```/````!#4``!`````4-0``#@```"4U```4````-#4```X```!)-0``
M#0```%@U```0````9C4```D```!W-0``(P```($U```E````I34```0```#+
M-0``!````-`U```)````U34```<```#?-0``&0```.<U```&`````38```<`
M```(-@``#@```!`V```&````'S8```4````F-@``"0```"PV```)````-C8`
M``D```!`-@``-````$HV```&````?S8```8```"&-@``#@```(TV```0````
MG#8```8```"M-@``#0```+0V```0````PC8```P```#3-@``"````.`V```.
M````Z38``!8```#X-@``$P````\W```,````(S<```D````P-P``!````#HW
M```7````/S<``"<```!7-P``'P```'\W```%````GS<``!D```"E-P``"P``
M`+\W```,````RS<```0```#8-P``!0```-TW```.````XS<```0```#R-P``
M`@```/<W```%````^C<``#(`````.```$````#,X```+````1#@```D```!0
M.```"@```%HX```)````93@``!````!O.```$0```(`X```2````DC@``!$`
M``"E.```$````+<X```1````R#@```X```#:.```#P```.DX```#````^3@`
M``<```#].```#P````4Y```'````%3D```4````=.0``$@```",Y```#````
M-CD```T````Z.0``"P```$@Y```2````5#D```<```!G.0```@```&\Y```)
M````<CD``!$```!\.0``"@```(XY```1````F3D```8```"K.0``!@```+(Y
M```&````N3D``"````#`.0``-````.$Y```%````%CH```T````<.@``!@``
M`"HZ```'````,3H``"$````Y.@``(P```%LZ```R````?SH``!,```"R.@``
M"0```,8Z```1````T#H```8```#B.@``"````.DZ```C````\CH``!4````6
M.P``$````"P[```G````/3L```<```!E.P``#````&T[```,````>CL```@`
M``"'.P``%@```)`[```?````ISL```@```#'.P``"0```-`[```3````VCL`
M``4```#N.P``#P```/0[```+````!#P```X````0/```(````!\\```5````
M0#P``!\```!6/```)````'8\```>````FSP``!,```"Z/```$````,X\```<
M````WSP``$T```#\/```10```$H]``!,````D#T```H```#=/0``$@```.@]
M```F````^ST```@````B/@``*0```"L^```B````53X``!D```!X/@``!@``
M`)(^```&````F3X``!0```"@/@``#P```+4^```3````Q3X```8```#9/@``
M!````.`^```&````Y3X```<```#L/@``*````/0^```B````'3\``!0```!`
M/P``!@```%4_```,````7#\``!0```!I/P``%````'X_```7````DS\``#<`
M``"K/P``*P```.,_```G````#T```"`````W0```!P```%A````2````8$``
M``D```!S0```!````'U```!#````@D````,```#&0```)@```,I````D````
M\4```"L````600``$@```$)!```&````54$```D```!<00``2````&9!```,
M````KT$``!8```"\00``$````--!```0````Y$$``!````#U00``"P````9"
M```5````$D(```@````H0@```P```#%"```+````-4(``!4```!!0@``%```
M`%="```E````;$(```0```"20@``,0```)="```Z````R4(```T````$0P``
M#P```!)#```"````(D,```@````E0P```@```"Y#```4````,4,``$@```!&
M0P``00```(]#```*````T4,``!8```#<0P``#P```/-#```)`````T0```P`
M```-1```&0```!I$```)````-$0``!X````^1```$0```%U$```6````;T0`
M`!$```"&1```"@```)A$```&````HT0```8```"J1```!0```+%$```)````
MMT0```4```#!1```"@```,=$```,````TD0```<```#?1```#P```.=$```%
M````]T0```$```!:`````````)0`````````7``````````-`0``"@$``.L`
M``##````&P````````#5````=0``````````````/P````````#7````````
M`$4```"C````"P```)<```"5````KP```!4`````````!P$``",!``#3````
M2P```+$`````````2@```/0````R````.@```&8```"'````/````!H!````
M````T0```'X`````````A0```"8```"@````C0```(````!D`````````)@`
M``#V``````````@`````````V0````````!/`````````&<```![````````
M``````",````7P````,!``"^````I````"``````````T@```((`````````
M`````&\```!V````7@```($````X`````````+L```!7````#P$```````!'
M````G@````P```!J````IP`````````=`0``M0```,8```#I````````````
M````````!`$``!L!````````T````+T```#:````'@$``+8````7``````$`
M`.\````9`0``,0```!X```!X````30```.T````3`0``5@```!0```!A````
M_`````````#N`````````!````!C`````````"@```#"`````````#`````8
M`0````````````"2````/0``````````````40```)D```!8````(0````(!
M``#D````&@```*P````S````%0$``#8`````````W0````````"Y````#@$`
M`&P```!]````N`````X```!;````'`$`````````````70```$X```#8````
M`````'0```#U``````````````";`````````.4````0`0```````!<!``!R
M````*0```(D```":````$@```/````"=````Q````,H````)`0``D0``````
M```=````MP```)8```!P````4@```"<```#W````J0```.,````&`0``````
M`````````````````.@```#B````(`$``(,````?````SP```-0```"3````
M1@`````````#````S0```&(````E````I0```&D```!_`````````(8```#,
M`````````"H``````````````,<```"?````/@````4`````````=P```#D`
M``"$````^````$,````N````R0```,4`````````+P````````#Z````````
M`&X```"T````_@`````````?`0``%`$``!@````)````LP````````!4````
MC@``````````````JP```&````"H````<0```/T```"J````^0```/$```!K
M````WP```-P`````````$P````<````(`0``+0``````````````X0``````
M````````"@```!$!``!0````OP`````````6`0``^P```.P```#;````````
M``T```#6```````````````D`````````.<```"P````_P````0```"(````
M`@```"(!```C`````````.````!$````20```%,```!S````K0```)P```"B
M````#P````````"+`````````(H`````````$0```&T``````````````,$`
M``#>````%@````L!``!"````2````!P```#.````CP```+(`````````````
M```````9````.P```%D`````````-P`````````%`0``D````'P```!,````
M>0```.8`````````H0```+P```!E````:````"(````A`0```````/,```!5
M````>@````````"N`````````/(`````````0`````8````,`0``$@$``#0`
M``````````````````"F````P````"P````K````RP```#4`````````00``
M`,@```#J`````````````````````0$```````"Z`````"5S($UA:6YT96YA
M;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`,3(@2&]U<B!&;W)M870`
M,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`04TO4$T`06-C;W5N="!);F9O<FUA
M=&EO;@!!9&0`061D($AE<F4Z`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A
M<R!A($UO>FEL;&$@4VED96)A<@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI
M;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI
M;FES=')A=&EO;@!!;&EA<P!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@
M1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R
M960@;&ES="!T>7!E/P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@
M24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;B!I;&QE
M9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%P<&QI8V%T:6]N`$%P<&QI8V%T
M:6]N(&ES(')E861Y+@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I
M;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`071T96UP="!T;R!D96QE=&4@
M82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@
M;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%V86EL86)L92!F:65L9',Z`$)I
M<G1H9&%Y`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0V%L96YD87(`0V%N
M8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#871E9V]R:65S(&%N9"!,86)E
M;',`0V5L;"!0:&]N90!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA
M="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R
M(&5M86EL<RX`0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y
M;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`0VAO;W-E($%P<&QI
M8V%T:6]N.@!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-L;W-E(%=I
M;F1O=P!#;VQL87!S92!3:61E8F%R`$-O;7!A;GD`0V]N9FEG=7)A=&EO;B!I
M<R!O=70@;V8@9&%T92X`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S
M:R!M;V1U;&4@)7,`0W)E871E`$-R96%T92!A(&YE=R!O;F4`0W)E871O<B!0
M97)M:7-S:6]N<P!#=7)R96YT(%1I;64`0W5S=&]M:7IE('1A<VMS('1O(')U
M;B!U<&]N(&QO9V]N('1O("5S+@!$1`!$86EL>0!$871E`$1E9F%U;'0@0V]L
M;W(`1&5F875L="!)9&5N=&ET>0!$96QE=&4`1&5L971E('-E;&5C=&5D(&ED
M96YT:71Y`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1I<F5C=&]R>0!$:7-P
M;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$;R!N;W0@9&ER
M96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F:7)S="!R
M;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI
M<R!B;W@Z`$1O=VYL;V%D`$1O=VYL;V%D("5S`$5D:70`161I="!";&]C:P!%
M9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%;6%I
M;`!%;7!T>2!R97-U;'0N`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE
M;G4_`$5R<F]R`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V
M97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V
M97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X
M<&%N9`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O
M(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A>`!&:6QE`$9I;&4@36%N86=E
M<@!&:6QT97)S`$9U;&P@1&5S8W)I<'1I;VX`1VQO8F%L($]P=&EO;G,`1V\`
M1V]O9VQE(%-E87)C:`!'<F]U<',`1W5E<W0@4&5R;6ES<VEO;G,`2&5A9&5R
M<P!(96QP`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H
M92!F:6QE.@!(;U]M90!(;VUE`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO
M<F1E`$EC;VYS($]N;'D`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M
M93H`26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`
M26UP;W)T960@9FEE;&1S.@!);F1I=FED=6%L(%5S97)S`$QA7WEO=70`3&%N
M9W5A9V4`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,
M87-T(&QO9VEN.B!.979E<@!,87EO=70`3&ES="!(96QP(%1O<&EC<P!,;V-A
M;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X`3&]G
M:6X@5&%S:W,`34T`36%I;`!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE
M<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S
M<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-871C:&EN9R!F:65L
M9',`365N=2!M;V1E.@!-97-S86=E`$UO;G1H;'D`36]O;B!0:&%S97,`36]V
M92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D;W=N
M`$UO=F4@=7``37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N`$YA
M;64`3F5V97(`3F5W($-A=&5G;W)Y`$YE=W,`3F5X=`!.97AT(&]P=&EO;G,`
M3F\`3F\@=F%L=65S`$YO;F4`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W1E<P!/
M2P!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9V%N:7II;F<`3W1H97(@26YF
M;W)M871I;VX`4&%S<W=O<F0`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&5R9F]R
M;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N<P!0
M97)S;VYA;"!);F9O<FUA=&EO;@!0:&]N90!0;&5A<V4@96YT97(@82!N86UE
M(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@<')O=FED92!A('-U;6UA
M<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA
M;64@86YD('!A<W-W;W)D`%!R979I;W5S(&]P=&EO;G,`4')O8FQE;0!0<F]B
M;&5M($1E<V-R:7!T:6]N`%)E860`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@
M365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5M;W1E(%-E
M<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D
M92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E('!A:7(`4F5S970`4F5T
M=7)N('1O($]P=&EO;G,`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)O;&4`
M4V%V90!3879E($]P=&EO;G,`4V5A<F-H`%-E;&5C="!A('-E<G9E<@!396QE
M8W0@86QL`%-E;&5C="!N;VYE`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z
M`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@
M>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!3
M96QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@
M<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@
M4')O8FQE;2!297!O<G0`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U
M('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`
M4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P
M86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E
M='5P`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN
M960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!L87-T(&QO9VEN('1I;64@
M=VAE;B!L;V=G:6YG(&EN/P!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B
M87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H<FEN:P!3:7IE
M`%-K:7`@36%I;G1E;F%N8V4`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&5C:6%L
M($-H87)A8W1E<B!);G!U=`!3=&%T=7,`4W5B:F5C=`!3=6)M:70`4W5C8V5S
M<P!3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=6YR:7-E+U-U;G-E
M=`!487-K<P!497AT($]N;'D`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E
M;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE<F4@
M87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@
M=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@=V%S(&%N(&5R
M<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AI<R!N=6UB97(@
M;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@=F%L=64@;75S="!B92!A(&YU
M;6)E<BX`5&EC:V5T<P!4:6UE(&9O<FUA=`!4:71L90!4;P!4;R!S96QE8W0@
M;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R
M($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!54DP`56YA8FQE
M('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&QO860@=&AE
M(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7
M;W)D(&1O8W5M96YT`%5N9&\@0VAA;F=E<P!5;F9I;&5D`%5P9&%T90!5<V4@
M:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R
M+@!5<V5R`%5S97(@3W!T:6]N<P!5<V5R;F%M90!5<V5R;F%M93H`57-E<FYA
M;64Z(`!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5V%R;FEN
M9P!796(`5V5E:VQY`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5VAA="!A
M<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAI
M8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC
M:"!497AT(&5D:71O<BX`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE
M9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=O<FL@061D<F5S
M<P!7;W)K(%!H;VYE`%E9`%EE87)L>0!997,`66]U(&AA=F4@8F5E;B!L;V=G
M960@;W5T+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@
M>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U<B`E<R!S97-S
M:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA
M:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I
M;VX`66]U<B!.86UE`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F
M875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;W!T:6]N<R!H
M879E(&)E96X@=7!D871E9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`6U!R;V)L
M96T@4F5P;W)T70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]'
M<F]U<',`7TAE;'``7TQO9R!O=70`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]3
M971U<`!?57-E<G,`961I=`!U;FYA;65D`'9#87)D`%!R;VIE8W0M260M5F5R
M<VEO;CH@2&]R9&4@=C,N,2U20S,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E
M=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#(M
M,#<@,3$Z,3`K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`V+3`R+3$W(#$W
M.C`P*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!!;&5X97D@6F%K:&%R;W8@/&)A
M8F5R0&UO<V=A+FYE=#X*3&%N9W5A9V4M5&5A;3H@4G5S<VEA;B`\:3$X;D!L
M:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP
M93H@=&5X="]P;&%I;CL@8VAA<G-E=#U#4#$R-3$*0V]N=&5N="U4<F%N<V9E
M<BU%;F-O9&EN9SH@.&)I=`H`SN_E\.#VZ/\@[^[DY.7PYNKH("5S("T@S^[D
M\N+E\.;DY>WHY0`Q,BWWX/'NXN[I`#(T+??@\>[B[ND`,C0@]^#QX`!!32]0
M30#3]^7R[>#_(.?@[^CQ_`#$[N'@XNCR_`#$[N'@XNCR_#H`Q.[AX.+H\OP@
M[^#P\P#$[N'@XNCR_"!-;WII;&QA(%-I9&5B87(`P.3PY?$`P.3PY?'MX/\@
MZNWHX^``S>#Q\O#NZ>KH("T@\_'RX.WNXNK@(._PX.(@Y.O_(.3P\^/H]2#O
M[NO\Y^[BX/+EZ^7I`-/O\.#BZ^7MZ.4`S_'EXN3N[>CL`,+QY2#B[OCEY/CH
MY0#"\>4@X_#S[^_[`,+QY2#O\.#BX`#0X.?PY?CH\OP@[N_E\.#VZ.@@\>X@
M\>_H\>K@[.@`P.O\\N7P[>#RZ.+M^^D@25--4`#/X/#NZ_PZ`,CL_R#O[NO\
MY^[BX/+EZ_\@25--4#H`P?OK[B#SZN#GX.WN(.WEZN[P\.7J\NWNY2#G[>#W
MY>WHY2X`S_#HZ^[FY>WHY0#-X/'R\.[E[>X`Q^#O\.#XZ.+@\OP@[^[D\N+E
M\.;DY>WHY2#OY?#EY"#B^^_NZ^WE[>CE["#N[^7PX/;HZ2#NX?'K\^;HXN#M
MZ/\_`,_N[_ORZN`@\^3@Z^CR_"#MY?'S^>7Q\N+S_OGHY2#O\.#BX`#/[N_[
M\NK@(/#EY.#J\NCP[N+@\OP@[>7Q\_GE\?+B\_[YZ.4@[_#@XN``Q.[Q\O/O
M[?OE(._NZ_\Z`,3E[?P@\.[FY.7MZ/\`S>#Q\O#NZ>K@.@#0X/'XZ/#E[>CE
M`,K@Z^7MY.#P_`#.\NSE[>``SO+LY>W@(.[R]^7RX"#N(._P[N'KY>SE`,K@
M\N7C[O#HZ"#H(.SE\NKH`,KKY?+N]^W@_R#PX.3H[O'B_^?\`,W@\?+P[NGJ
MZ"#H[.7MZ"P@X.3PY?'@+"#O[N3OZ/'H+@#.\NSE\OSRY2#TZ^#FZN#LZ"#N
M[^7PX/;H_BCHZ"DL(.KN\N[P^^4@POL@]>[RZ/+E(.[Q\_GE\?+BZ/+\+@#"
M^^'E\.CRY2#O\.CK[N;E[>CE.@#4[O#LX/(@[O+NX?#@YN7MZ/\@Y.#R^SH`
MQ^#J\/OR_"#NZNWN`-/A\.#R_"#LY>W^`,KN[._@[>C_`,KN[?3HX_/PX/;H
M_R#S\?+@\.7KX`#-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E
M7U1A<VL@)7,`T>[GY.#R_`#1[N?DX/+\(.WNXOOI(._P[O3HZ_P`T>[GY.#R
MY>O\`-+EZO/YY>4@XO#E[/\`Q^#DX/?H+"#GX._S\>K@Y>S[Y2#O\.@@XO7N
MY.4@XB`E<P#$Q`#%YN7D[>7B[>X`Q.#RX`#6XN7R(._N(//L[NOWX.WH_@#/
M\.[TZ.O\(._N(//L[NOWX.WH_@#3Y.#KZ/+\`-/DX.OH\OP@XOOA\.#M[?OI
M(._P[O3HZ_P`SN_H^.CRY2#O\.[AZ^7L\P#/[N3P[N'M[O'RZ"#A^^OH(.?@
M[^CQX.W[(.(@YO/P[>#K(.3K_R#@Y.SH[>CQ\O#@\N[PX"X`RN#RX.ONXP#.
M\N[A\.#FX/+\(.+PY>S_(.(@,C0M]^#Q[N+N["#T[O#LX/+E/P#$\//CZ.4@
M[>#Q\O#NZ>KH`,WE(.+[Y_OBX.GRY2!M86EN=&5N86YC92YP:'`@[>7O[O'P
MY>3Q\N+E[>WN`,(@[^7PXN[I(/'R\.[JY2#SZN#GX.W[(.CLY>W@(._NZ^7I
M/R#%\>OH(.3@+"#O[O'RX.+\\N4@X^#K[O?J\SH@`,?@X_#SY^CR_`#'X./P
M\^?H\OP@)7,`T.7DX.KRZ/#NXN#MZ.4`T.7DX.KRZ/#NXN#R_`#3\?+@[>[B
MZN`@[_#@XB#DZ_\@)7,`S>#Q\O#NZ>KH`$5M86EL`,WSZ^7B[ND@\.7G\^O\
M\N#R+@#*[NWRY>KQ\NWNY2#LY>W^(._N(.W@YN#RZ.@@[_#@XN[I(.KM[N_J
MZ"#L^_CH`,[XZ.'JX`#*X.;D^^4@,34@[.CM\_(`RN#FY/OE(#(@[.CM\_+[
M`,K@YN3[Y2`S,"#QY>KS[>0`RN#FY/OE(#4@[.CM\_(`RN#FY/OI(/#@YR#O
M\.@@XO7NY.4`RN#FY/OE(._NZ_?@\>``RN#FY//^(.SH[?/R\P#/\.CLY?`@
MY^W@]^7MZ.DZ`-#@\?CH\.CR_`#"[O'Q\N#M[N+KY>WHY2#MX/'R\.[EZB#M
MY2#SY.#K[O'\+@#-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$
M05`N`-3@ZO$`U.#IZP#5\.#MZ.OH^>``U.CK_/+P^P#/[NOM[N4@[N_H\>#M
MZ.4@[_#NX>OE[/LZ`,_N\/+@ZP#/Y?#EZ?+H`,_NZ/'J(.(@1V]O9VQE`,/P
M\^_O^P##[O'R_`#'X./NZ^[BZN@`S^[D\>K@Y^K@`,_NZ_/XX/#HY0#-Z.;E
M(._PY>3Q\N#BZ^7MX"#H[?3N\.S@]NC_(.CG(/'@[.[C[B#MX/?@Z^`@].#I
MZ^`Z`,_N\/+@ZP#/[O#RX.L`Q.[LX/CMZ.D@X.3PY?$`Q.[LX/CMZ.D@\N7K
MY?3N[0#/[O#RX.L`TN[K_.KN(.CJ[NWJZ`#(ZN[MZN@@\2#RY>KQ\N[L`,CL
M_R#O\.[TZ.O_.@#*X/#RZ.WJZ`#([._N\/(L(/C@XR`E9`#([._N\/+H\.[B
MX.WN(._NZ^4Z("5S`,CL[^[P\NCP[N+@[?L@[^[K_SH`S^[K_.?NXN#RY>OH
M`-#@\>KKX.3JX`#?Y_OJ`,_PY>3[Y//YZ.D@XO7NY"#A^^LZ("5S`,_PY>3[
MY//YZ.D@XO7NY"#A^^LZ("5S(/$@ZN[L[_S^\N7PX"`E<P#/\.7D^^3S^>CI
M(.+U[N0@[>4@Y^#TZ.KQZ/#NXN#M`,+[]>[D`-'OZ/'NZB#PX.?DY>ONXB#O
M[N3QZN#GZN@`R^[JX.OHY^#VZ/\`T.#Q[^[K[N;E[>CE`,+U[N0`POOU[N0`
MT_?E\NW@_R#GX._H\?P`PO7NY`#,S`#/[O?RX`#-X/'R\.[IZN`@\>_H\>K@
M(.K@\N7C[O#HZ2#H(/;BY?+NXB#H]2#N\N[A\.#FY>WH_P#1[N+OX.3@_OGH
MY2#O[NO_`-#EYNCL(.SE[?XZ`-'N[N'YY>WHY0#%YN7LY?'_]^WN`-3@Y_L@
MR_/M^P#OY?#E[.7Q\NCR_"#B[>CG`._E\.7LY?'RZ/+\(.+KY>+N`._E\.7L
MY?'RZ/+\(.+O\.#B[@#OY?#E[.7Q\NCR_"#BXN7P]0#OY?#E[.7Q\NCR_"#B
M[>CG`._E\.7LY?'RZ/+\(.+BY?#U`-/WY?+MX/\@Y^#OZ/'\`,+@^.`@Z.WT
M[O#LX/;H_P#([/\`S>CJ[N/DX`#-[N+@_R#JX/+EX^[PZ/\`S>[B[O'RZ`#$
MX.OEY0#1Z^7D\_[YX/\@\?+PX.WH]N``S>7R`,WE(.[O\.7DY>OE[>X`+>WE
M(.+[X?#@[2T`T>7BY?#M[N4@[^[K\_C@\.CE`,?@[.7RZN@`3TL`S>#Q\O#N
MZ>KH`,W@\?+P[NGJZ"#DZ_\Z("5S`,[PX^#MX.GGY?``S_#N]^#_(.CM].[P
M[.#VZ/\`S^#P[NO\`,_@\.[K_`#/X/#NZ_P`SO'S^>7Q\N+KY>WHY2#N[^7P
MX/;HZ2#O[N3DY?#FZN@`POOO[NOMZ/+\(.[OY?#@]NCH(.[A\>OSYNCBX.WH
M_R#O\.@@XO7NY.4@XB#QZ/'RY>SS/P#/\.#BX`#/\.#BX"#D[O'R\^_@`,OH
M]^W[Y0#2Y>OE].[M`,+BY>3H\N4@[>#GXN#MZ.4@[>[B[ND@ZN#RY>/N\.CH
M.@#/[N;@Z_/I\?+@+"#Q[N[A^>CRY2#Q\_+\(._P[N'KY>S[+@#/[N;@Z_/I
M\?+@+"#BXN7DZ/+E(,+@^.@@Z.S_(._NZ_SG[N+@\N7K_R#H(._@\.[K_`#/
M\.7D^^3S^>#_(/'R\.#MZ/;@`,_P[N'KY>S@/P#.[^CQX.WHY2#O\.[AZ^7L
M^P#7Z/+@\OP`SN'M[N+H\OP`SN'M[N+K__+\(.3H[>#LZ/?E\>KHY2#O\^WJ
M\OL@[.7M_CH`SN'M[N+K__+\(.CM].[P[.#VZ/XZ`,_N]_+NXOOE(/'E\.+E
M\.``P.3PY?$@\>7PXN7PX"`H[>#O\.CLY?`@:'1T<#HO+VUA:6PN<G4I`-/D
MX.OH\OP`T^3@Z^CR_"#AZ^[J`-/DX.OH\OP@[^#P\P#1X?#N\>CR_`#"Y?#M
M\_+\\?\@ZB#MX/'R\.[IZN#L`,W@\?+P[NGJZ"#BZ.?SX.O\[>[C[B#PY>3@
MZO+N\.``T?;E[>#PZ.D`T>[U\.#MZ/+\`-'N]?#@[>CR_"#MX/'R\.[IZN@`
MS^[H\>H`POOAY?#H\N4@\>7PXN7P`,+[X?#@\OP@XO'E`,[R[.7MZ/+\(.+[
MX>[P`,+[X>7PZ/+E(/#@Y^3EZ^CRY>O\(._NZ^7I(.3@\OLZ`,+[X>7PZ/+E
M(/3N\.S@\B#DX/+[.@#"^^'E\.CRY2#O\.[TZ.O\(.3K_R#MX/'R\.[IZN@Z
M`,+[X>7PZ/+E(.[R[N'PX.;E[>C_(/3N\.S@\B#B\.7LY>WH.@#"^^'E\.CR
MY2#DXN`@\>[B[^#DX/[YZ/4@[^[K_RX`PN#XX"#VXN7R[N+@_R#Q]>7LX`#?
MY_OJ(.[R[N'PX.;E[>C_`,_N\>O@\OP@\>[NX?GE[>CE(.X@[_#NX>OE[.4`
MQ.[O[NOMZ/+EZ_SM^^4@[^[W\N[B^^4@\>7PXN7PX"P@ZB#J[O+N\/OL(.+[
M(/7N\NCRY2#H[.7R_"#D[O'R\^\@Z.<@S^[P\N#KX"X`T_'RX.WNXNK@(/_G
M^^K@(.+[XN[DX"P@XO#E[.7M[>[I(.?N[?L@Z"#T[O#LX/+@(.[R[N'PX.;E
M[>C_(.+PY>SE[>@N`-/Q\N#M[N+JX"#O\.CK[N;E[>C_(._N(//L[NOWX.WH
M_BP@]N+E\N[B[ND@\?7E[/L@Z"#O\.[WZ/4@[N_VZ.D@[O+NX?#@YN7MZ/\`
MS_#HZ^[FY>WH_P#*\.#RZN[E(.[A[N'YY>WHY3H`SN_PY>3EZ^CR_"#A^_'R
M\/OE(.KKX.+H^.@@Y.O_(/'Q^^ONZC\`S^[JX.?@\OP`S^[JX.?[XN#R_"#H
M[?3N\.S@]NC^(.X@[_#EY/OD\_GE["#B]>[DY3\`S^[JX.?@\OP@[.7M_B#N
M[^7PX/;HZ2#Q(/+@X>OH]N#LZ`#.\N[A\.#FX/+\(.SE[?X@)7,@\>OEXN`_
M`-'SY^CR_`#0X.?LY?``S_#N[_/Q\NCR_"#O[N3DY?#FZO,`WN;M[N4@[^[K
M\_C@\.CE`-'OY?;HX.O\[?OE(/'H[.+NZ_L`T?+@\O/Q`-+E[.``R/'JX/+\
M`-/Q[^7X[>X`T?+@\.#_(.KN[?3HX_/PX/;H_R#Q[O7PX.WE[>`@XB#TX.GK
M.B`E<P#-[N+@_R#J[NWTZ./S\.#VZ/\@\>[U\.#MY>W@(.(Z("5S`,+PY>S_
M(.+N\?7NY.`OY^#JX/+@`,?@Y.#WZ`#2[NO\ZNX@\N7J\?(`T>7PXN7P("5S
M(.'[ZR#SY.#KY>T`T>7PXN7P("5S(.'[ZR#Q[N?DX.T`S>7R(.3N\?+S[^W[
M]2#MX/'R\.[EZBX`T>[NX?GE[>CE(.(@[>7BY?#M[NP@].[P[.#RY2#H(.WE
M(.SNYN7R(.'[\OP@[O+NX?#@YN7M[@#.^.CAZN`@[_#H(.[R[N'PX.;E[>CH
M(/WR[ND@]^#Q\N@@\>[NX?GE[>C_`-WR[B#WZ/'K[B#MY2#L[N;E\B#A^_+\
M(.SE[?SXY2#EY.CMZ/;[+@#=\NX@Y^W@]^7MZ.4@Y.[KYNWN(.'[\OP@]^CQ
MZ^[L+@#'X._P[O'[`-3N\.S@\B#N\N[A\.#FY>WH_P#'X./NZ^[B[NH`RN[L
M\P#7\N[A^R#B^^'PX/+\(.WE\>KNZ_SJ[B#]Z^7LY>WR[N(L(//DY?#FZ.+@
MZ?+E(.W@YN#R[ND@ZNO@XNCF\R!#=')L`%523`#-Y>+NY^SNYNWN(/'NY>3H
M[>CR_/'_(/$@4U%,(/'E\.+E\.[L+@#-Y>+NY^SNYNWN(.?@X_#SY^CR_"#N
M[_#EY.7KY>WHY2`E<RX`W?+N\B#D[NKS[.7M\B!7;W)D(.WE(.SNYN7R(.'[
M\OP@[^7PY>+EY.7M+@#.\NSE[>CR_"#HY^SE[>7MZ/\`S_/Q\N[I`,_PZ.SE
M[>CR_`#(\>_NZ_SG\^7R\?\@Y?'KZ"#BX/CH(.CL_R_OX/#NZ_P@Y.O_($E-
M4U`@\>7PXN7PX"#N\NOH]^#^\O'_(.[R(/+EZO/YZ/4`S^[K_.?NXN#RY>O\
M`,W@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_\`R.S_(._NZ_SG[N+@\N7K_P#([/\@
M[^[K_.?NXN#RY>O_`,CL_R#O[NO\Y^[BX/+EZ_\`S_#N\>SN\O`@)7,`S^[J
MX.?@\OP@XN7A+?'R\.#MZ/;S`,+MZ.S@[>CE`,+EX0#%YN7MY>3EZ_SM[@#$
M[N'P[B#O[N;@Z^[BX/+\(.(@)7,`Q.[A\.X@[^[FX.ONXN#R_"P@)7,`U_+N
M(.[R[N'PX.;@\OP@[^[QZ^4@XO7NY.`@XB#QZ/'RY>SS.@#4X.?@`,K@ZNCE
M(.[O]NCH(.'SY//R(.3N\?+S[^W[(.(@XNCG\^#K_.WN["#PY>3@ZO+N\.4`
MV.CPZ.W@(.SE[?X@)7,@\>OEXN`@*.'SY.7R(._PZ.SE[>7MX"#O\.@@\>OE
MY//^^>7L(.+U[N3E*0#0X.'N]^CI(.#D\.7Q`-#@X>[WZ.D@\N7KY?3N[0##
MPP#%YN7C[N3M[@#$X`#"^R#B^_CKZ"#HYR#QZ/'RY>S[+@#"^R#D[NOF[?L@
M[N_H\>#R_"#O\.[AZ^7L^RP@[_#EYN3E(/?E["#Q[.[FY?+E(.[R[O'KX/+\
M(/'N[N'YY>WHY2#N(.WEZ2X`PN#XX"`E<R#QY?'QZ/\@Y^#J[NWWZ.O@\?PN
M(,_NYN#K\^GQ\N`L(.+NZ>3H\N4@XB#QZ/'RY>SS(.?@[>[B[BX`PN#X($5M
M86EL.@#"X/@@X.3PY?$@[O+O\.#BZ/+EZ_\Z`,+@^.`@Z.WT[O#LX/;H_P#"
MX/CE(.CL_SH`U^#Q[N+NZ2#O[O_Q`,+@^"#O\.[TZ.O\(._N(//L[NOWX.WH
M_CH`PN#XY2#H[/\Z`,+@^.@@[>#Q\O#NZ>KH(.'[Z^@@[N'M[N+KY>W[+@#1
M\N[P[NWMZ.D@\>7PXN7P.@!;T>[NX?GE[>CE(.X@[_#NX>OE[.5=`%OQ\O#N
MZN`@)7,@Z.<@)7-=`-/O\.#BZ^7MZ.4`P_#S[^_[`,_N[.[Y_`#"^_7NY`#-
MX/'R\.[IZN@`S_#@XN``S_#HZ^[FY>WH_P#/[NO\Y^[BX/+EZ^@`S_#@XNCR
M_`#RY>KQ\B#Q[N[A^>7MZ/\`=D-A<F0`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE
M+W-K7U-++P``````````````````````````````````````````````````
M```````````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U-``P,C`Q,S``(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L;V-A;&4O<VM?4TLO:&5L<"YX;6P`````````````````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,S(P`#$P-3$U-#,S-S4T`#`R
M,38P,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO
M8V%L92]S:U]32R]H96QP+GAM;"QV(#$N,B`R,#`T+S`U+S(W(#(P.C(R.C$S
M(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)S=6UM87)Y(B!S
M=&%T93TB;F5W(CX*/'1I=&QE/E1H92!0;W)T86P@4&%G93PO=&ET;&4^"B`\
M<&%R83X*("!4:&ES('!O<G1A;"!P86=E('!R;W9I9&5S(&$@<75I8VL@<W5M
M;6%R>2!O9B!A;&P@>6]U<B!I;7!O<G1A;G0*("!I;F9O<FUA=&EO;BX@1F]R
M(&5X86UP;&4L(&ET(&UI9VAT('-H;W<@:&]W(&UA;GD@;F5W(&4M;6%I;"!M
M97-S86=E<R!Y;W4*("!H879E(&EN('EO=7(@24Y"3U@L('5P8V]M:6YG(&5V
M96YT<R!O;B!Y;W5R(&-A;&5N9&%R+"!T87-K<R!O;B!Y;W5R('1O+61O"B`@
M;&ES="P@:&5A9&QI;F5S(&9R;VT@<V5L96-T960@;F5W<R!S97)V:6-E<RP@
M86YD('-O(&]N+B`@36%N>2!O9B!T:&5S90H@('-U;6UA<FEE<R!W:6QL(&-O
M;G1A:6X@<75I8VL@<VAO<G1C=71S('1O(&-O;6UO;B!F=6YC=&EO;G,L('-U
M8V@@87,*("!C;VUP;W-I;F<@82!N97<@;6%I;"!M97-S86=E+"!C<F5A=&EN
M9R!A(&YE=R!C86QE;F1A<B!E=F5N="!O<B!T87-K+"!E=&,N"B`\+W!A<F$^
M"B`\<&%R83X*("!4:&4@8V]N=&5N=',@;V8@=&AI<R!P;W)T86P@<&%G92!A
M<F4@8W5S=&]M:7IA8FQE('9I82!T:&4@3&%Y;W5T(&)U='1O;BX*("!&;W(@
M97AA;7!L92P@>6]U(&-A;B!C:&]O<V4@=VAI8V@@:71E;7,@=&\@:6YC;'5D
M92!O;B!T:&ES('!O<G1A;"!P86=E(&%S"B`@=V5L;"!A<R!I;B!W:&EC:"!O
M<F1E<B!T:&5Y(&%R92!S:&]W;BX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT
M<GD@:60](FYA=F)A<B(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@07!P;&EC
M871I;VX@3F%V:6=A=&EO;B!"87(\+W1I=&QE/@H@/'!A<F$^"B`@070@=&AE
M(&QE9G0@:&%N9"!S:61E(&]F('1H92!W96(@<&%G92!I<R!T:&4@87!P;&EC
M871I;VX@;F%V:6=A=&EO;B!B87(N"B`@0VQI8VL@;VX@=&AE(&EC;VYS(&]N
M('1H:7,@;F%V:6=A=&EO;B!B87(@=&\@<75I8VML>2!A;F0@96%S:6QY('-W
M:71C:`H@(&)E='=E96X@=&AE(&%V86EL86)L92!A<'!L:6-A=&EO;G,N"B`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N
M86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA
M:6YT96YA;F-E.B!$;R!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*
M("`@($EF('EO=2!W;W5L9"!L:6ME('1O('!E<F9O<FT@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!O;B!L;V=I;BP@8VAE8VL@=&AI<R!B;W@N"B`@("`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC;VYF:7)M7VUA:6YT
M96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@
M36%I;G1E;F%N8V4Z($-O;F9I<FT@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!C;VYF:7)M(&%L;"!M
M86EN=&5N86YC92!T87-K<R!B969O<F4@=&AE>2!A<F4@<G5N+"!C:&5C:R!T
M:&ES(&)O>"X@268@;&5F="!U;F-H96-K960L(&%L;"!M86EN=&5N86YC92!O
M<&5R871I;VYS('1H870@;F5E9"!T;R!B92!R=6X@=VEL;"!B92!P97)F;W)M
M960@875T;VUA=&EC86QL>2!W:71H(&YO(&-H86YC92!T;R!C86YC96P@;VX@
M;&]G:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&]C86QE+W-K7U-++TQ#7TU%4U-!1T53+P``````````````````
M```````````````````````````````````````````````P,#`P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U-``P,C$W,34`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O<VM?4TLO3$-?34534T%'
M15,O:&]R9&4N;6\`````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-#`T,3<S`#$P
M-3$U-#,S-S4T`#`R,S,V-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#>$@25`````&,'```<````-#L``-D)``!,=@``````
M`+"=```.````L9T```\```#`G0``#0```-"=```(````WIT```L```#GG0``
M#````/.=```$`````)X``!@````%G@``&P```!Z>```M````.IX``!T```!H
MG@``)````(:>```I````JYX``!D```#5G@``)@```.^>```,````%I\``"0`
M```CGP``#P```$B?```+````6)\```X```!DGP``!0```'.?```H````>9\`
M``@```"BGP``"@```*N?```5````MI\``!(```#,GP``"P```-^?``"%````
MZY\```X```!QH```"@```("@```-````BZ````X```"9H```$0```*B@```-
M````NJ````P```#(H```#0```-6@```&````XZ```)0```#JH```"@```'^A
M```/````BJ$``!@```":H0``#````+.A```.````P*$```X```#/H0``"```
M`-ZA```)````YZ$``"X```#QH0``&@```""B```R````.Z(``#@```!NH@``
M5````*>B``!1````_*(``%H```!.HP``5P```*FC```T`````:0```D````V
MI```#0```$"D```'````3J0```H```!6I```#P```&&D```%````<:0```8`
M``!WI```$0```'ZD```(````D*0```D```"9I```"0```*.D```E````K:0`
M`"````#3I```$P```/2D```0````"*4```\````9I0``"@```"FE```#````
M-*4```\````XI0``%````$BE```)````7:4```T```!GI0``$@```'6E```9
M````B*4``!X```"BI0``#P```,&E```*````T:4```\```#<I0``"````.RE
M```D````]:4``!0````:I@``%@```"^F```(````1J8``$X```!/I@``+0``
M`)ZF```9````S*8```<```#FI@``#````.ZF```L````^Z8```X````HIP``
M`P```#>G```+````.Z<```<```!'IP``!P```$^G```%````5Z<```4```!=
MIP``"@```&.G```#````;J<``!<```!RIP``"@```(JG```/````E:<```X`
M``"EIP``&````+2G```C````S:<```X```#QIP``%`````"H```7````%:@`
M`!<````MJ```%P```$6H```3````7:@```\```!QJ```#@```(&H```?````
MD*@``!T```"PJ```!P```,ZH```&````UJ@```@```#=J```#P```.:H```&
M````]J@```H```#]J```$P````BI```+````'*D``!`````HJ0``%0```#FI
M```5````3ZD```<```!EJ0``$````&VI```%````?JD``!$```"$J0``#```
M`):I```[````HZD``#@```#?J0``"0```!BJ```'````(JH```,````JJ@``
M!0```"ZJ```0````-*H```D```!%J@``$P```$^J```Y````8ZH``"<```"=
MJ@``+````,6J```J````\JH``"4````=JP``"@```$.K```&````3JL```D`
M``!5JP``!P```%^K```O````9ZL``#<```"7JP``+@```,^K``!5````_JL`
M`"T```!4K```+0```(*L```]````L*P``#\```#NK```+0```"ZM``!`````
M7*T``",```"=K0``(P```,&M``!`````Y:T``"T````FK@``,P```%2N```E
M````B*X``!4```"NK@``&0```,2N```I````WJX``"0````(KP``*````"VO
M```1````5J\```H```!HKP``#````'.O```*````@*\``!````"+KP``%@``
M`)RO```6````LZ\```<```#*KP``!P```-*O```*````VJ\```@```#EKP``
M)P```.ZO```(````%K````<````?L```!P```">P```&````+[````4````V
ML```!P```#RP```&````1+````@```!+L```*0```%2P```.````?K````H`
M``"-L```!````)BP```'````G;````D```"EL```!@```*^P```1````MK``
M``<```#(L```%@```-"P```$````Y[````@```#LL```!@```/6P```-````
M_+````8````*L0``'@```!&Q```1````,+$```@```!"L0``#0```$NQ```,
M````6;$```<```!FL0```P```&ZQ```#````<K$``!<```!VL0``$P```(ZQ
M```=````HK$```@```#`L0``!````,FQ```(````SK$```@```#7L0``00``
M`."Q```:````(K(``"L````]L@``(````&FR```5````BK(```8```"@L@``
M!@```*>R```5````KK(``!@```#$L@``(@```-VR```N`````+,``!T````O
MLP``(0```$VS``!4````;[,``"D```#$LP``"@```.ZS```'````^;,``!4`
M```!M```#@```!>T```*````)K0```\````QM```#0```$&T```/````3[0`
M``T```!?M```"0```&VT```&````=[0``!@```!^M```$P```)>T```1````
MJ[0``!0```"]M```!````-*T```&````U[0``!0```#>M```5````/.T``!D
M````2+4```0```"MM0``#@```+*U```%````P;4```4```#'M0``$P```,VU
M```1````X;4``!$```#SM0``'`````6V```J````(K8``!````!-M@``(0``
M`%ZV```%````@+8``!,```"&M@``"P```)JV```2````IK8```H```"YM@``
M#P```,2V```-````U+8``!$```#BM@``$P```/2V```,````"+<```8````5
MMP``#````!RW```&````*;<``!<````PMP``$````$BW```1````6;<```@`
M``!KMP``!0```'2W```,````>K<``!````"'MP``!0```)BW```-````GK<`
M``8```"LMP``!P```+.W```-````N[<```<```#)MP``"P```-&W```'````
MW;<```<```#EMP``"0```.VW```)````][<```H````!N```&0````RX```]
M````)K@``!T```!DN```#````(*X```0````C[@```4```"@N```)0```*:X
M```2````S+@``!,```#?N```*P```/.X```[````'[D``"````!;N0``"```
M`'RY```V````A;D``"$```"\N0``$````-ZY```(````[[D```P```#XN0``
M!@````6Z```$````#+H```\````1N@``#@```"&Z```*````,+H```T````[
MN@``'P```$FZ```<````:;H``"$```"&N@``'@```*BZ```9````Q[H``!X`
M``#AN@``'0````"[```;````'KL``"`````ZNP``+@```%N[```F````BKL`
M`!P```"QNP``'@```,Z[```<````[;L``"8````*O```*P```#&\```S````
M7;P``"8```"1O```*P```+B\```X````Y+P``!T````=O0``%0```#N]```O
M````4;T``"````"!O0``$@```**]```I````M;T``!X```#?O0``(````/Z]
M```2````'[X``*(````RO@``%@```-6^```C````[+X``"@````0OP``*0``
M`#F_```H````8[\``!\```",OP``%0```*R_```@````PK\``"4```#COP``
M*`````G````M````,L```#````!@P```D@```)'````A````),$``!8```!&
MP0``'````%W!```F````>L$``"H```"AP0``00```,S!``!$````#L(```P`
M``!3P@``!P```&#"```'````:,(```8```!PP@``#0```'?"```0````A<(`
M`!(```"6P@``$P```*G"```2````O<(```<```#0P@``!````-C"```0````
MW<(``!````#NP@``#````/_"```.````#,,```T````;PP``#P```"G#```3
M````.<,```T```!-PP``*````%O#```#````A,,```T```"(PP``!@```);#
M```.````G<,```(```"LPP``20```*_#```%````^<,``!````#_PP``#P``
M`!#$```$````(,0```T````EQ```#@```#/$```#````0L0```X```!&Q```
M"````%7$```/````7L0```\```!NQ```!P```'[$```-````AL0``!````"4
MQ```#0```*7$```+````L\0```8```"_Q```"P```,;$```,````TL0```H`
M``#?Q```$0```.K$```9````_,0```L````6Q0``#0```"+%```B````,,4`
M`!L```!3Q0``-````&_%```*````I,4``!@```"OQ0``&0```,C%```6````
MXL4``"(```#YQ0``#0```!S&```'````*L8``!0````RQ@``"P```$?&```B
M````4\8``"\```!VQ@``"P```*;&```)````LL8``!D```"\Q@``"P```-;&
M```7````XL8``!<```#ZQ@``"0```!+'```6````',<```\````SQP``&0``
M`$/'```6````7<<```X```!TQP``&````(/'```(````G,<```T```"EQP``
M)@```+/'``!#````VL<```@````>R```$@```"?(```?````.L@```@```!:
MR```"P```&/(```O````;\@```X```"?R```!0```*[(```&````M,@```,`
M``"[R```!P```+_(```$````Q\@```H```#,R```"@```-?(```/````XL@`
M`!````#RR```%P````/)```1````&\D``!D````MR0``%P```$?)```)````
M7\D```4```!IR0``"P```&_)```*````>\D```(```"&R0``!0```(G)```-
M````C\D``!L```"=R0``%P```+G)```4````T<D```D```#FR0``#@```/#)
M```-````_\D``!(````-R@``.````"#*```@````6<H```@```!ZR@``#@``
M`(/*``![````DLH``!@````.RP``&````"?+```1````0,L```<```!2RP``
M!0```%K+```8````8,L``!X```!YRP``&P```)C+```9````M,L``!L```#.
MRP``&0```.K+```3````!,P```<````8S```"````"#,```&````*<P```8`
M```PS```$````#?,```/````2,P``!````!8S```#P```&G,```+````><P`
M``\```"%S```#````)7,```/````HLP```<```"RS```!@```+K,```.````
MP<P```P```#0S```*````-W,```/````!LT```@````6S0``"````!_-```3
M````*,T``!X````\S0``(0```%O-```@````?<T``!D```">S0``%P```+C-
M```E````T,T``!<```#VS0``%@````[.```$````)<X``!L````JS@``#0``
M`$;.```,````5,X```,```!AS@``!0```&7.```(````:\X```H```!TS@``
M#````'_.```+````C,X``!````"8S@``#````*G.```$````MLX```0```"[
MS@``$P```,#.```4````U,X```P```#IS@``"0```/;.```.`````,\```L`
M```/SP``&P```!O/```'````-\\```<````_SP``"@```$?/```-````4L\`
M``D```!@SP``!````&K/```%````;\\```,```!USP``&````'G/```*````
MDL\```0```"=SP``)@```*+/```.````R<\``'P```#8SP``%0```%70```%
M````:]````<```!QT```#````'G0```(````AM````H```"/T```!@```)K0
M```(````H=````(```"JT```!@```*W0```&````M-```!0```"[T```#0``
M`-#0```0````WM```!L```#OT```!`````O1```)````$-$``!`````:T0``
M"0```"O1```)````-=$```4````_T0``&@```$71```(````8-$```8```!I
MT0``&0```'#1```.````BM$```<```"9T0``!P```*'1```%````J=$```D`
M``"OT0``"@```+G1```"````Q-$```8```#'T0``"P```,[1```-````VM$`
M``D```#HT0``!@```/+1```)````^=$```<````#T@``%`````O2```=````
M(-(``$(````^T@``)0```('2```E````I](```8```#-T@``"@```-32```$
M````W](```D```#DT@``"````.[2```1````]](```D````)TP``!@```!/3
M```-````&M,```8````HTP``!````"_3```Y````--,``#T```!NTP``.@``
M`*S3```>````Y],```4````&U```#@````S4```$````&]0```8````@U```
M!P```"?4```A````+]0```T```!1U```!@```%_4```$````9M0``!$```!K
MU```!@```'W4```*````A-0``"(```"/U```!````++4```%````M]0``!T`
M``"]U```!````-O4```,````X-0```X```#MU```"@```/S4```(````!]4`
M``D````0U0``!0```!K5```Z````(-4``#````!;U0``-0```(S5```I````
MPM4``$<```#LU0``.````#36```I````;=8``#\```"7U@``+@```-?6```M
M````!M<``!\````TUP``#P```%37```2````9-<```L```!WUP``)@```(/7
M```I````JM<``"0```#4UP``)@```/G7```(````(-@```H````IV```"0``
M`#38```'````/M@``"````!&V```(````&?8```F````B-@```H```"OV```
M&0```+K8```I````U-@``!8```#^V```$@```!79```'````*-D```H````P
MV0``#````#O9```/````2-D``!````!8V0``0````&G9``!P````JMD``&8`
M```;V@``#@```(+:```)````D=H```H```";V@``$@```*;:```3````N=H`
M``P```#-V@``!@```-K:```/````X=H``!(```#QV@``$`````3;```1````
M%=L``!P````GVP``(P```$3;``!J````:-L```\```#3VP``!0```./;```0
M````Z=L```D```#ZVP``!`````3<```+````"=P``"`````5W```%````#;<
M```,````2]P```P```!8W```#P```&7<```5````==P``"D```"+W```*@``
M`+7<```F````X-P``"<````'W0``*0```"_=```J````6=T``!D```"$W0``
M0@```)[=```1````X=T``!(```#SW0``$P````;>```4````&MX```\````O
MW@``%@```#_>```7````5MX``!````!NW@``$0```'_>```T````D=X``!,`
M``#&W@``$@```-K>```U````[=X``!0````CWP``!P```#C?```,````0-\`
M`"````!-WP``$````&[?```4````?]\``!$```"4WP``%P```*;?```<````
MOM\``!,```#;WP``%````._?```:````!.```!$````?X```&@```#'@```>
M````3.```!H```!KX```$P```(;@```5````FN```!$```"PX```%P```,+@
M```4````VN```!<```#OX```%0````?A```)````'>$``!`````GX0``&0``
M`#CA```$````4N$```<```!7X0``"P```%_A```1````:^$```8```!]X0``
M!@```(3A```&````B^$```4```"2X0``!P```)CA```'````H.$```4```"H
MX0``!@```*[A```&````M>$```0```"\X0``!````,'A```'````QN$```X`
M``#.X0``#````-WA```,````ZN$```T```#WX0``"@````7B```.````$.(`
M``4````?X@``*````"7B```.````3N(```P```!=X@``#P```&KB```*````
M>N(```@```"%X@``"0```([B```K````F.(```0```#$X@``"````,GB```F
M````TN(``!(```#YX@``!@````SC```*````$^,```<````>XP``"````";C
M```@````+^,```D```!0XP``%````%KC```,````;^,```T```!\XP``#@``
M`(KC```6````F>,``!$```"PXP``!@```,+C```#````R>,```8```#-XP``
M&0```-3C```'````[N,```0```#VXP``"P```/OC```+````!^0```<````3
MY```!0```!OD```'````(>0``!8````IY```#0```$#D```-````3N0```H`
M``!<Y```$````&?D```/````>.0``!$```"(Y```%P```)KD```*````LN0`
M`!$```"]Y```"````,_D```$````V.0```\```#=Y```.@```.WD```%````
M*.4```P````NY0``'@```#OE```.````6N4``!````!IY0``"P```'KE```,
M````AN4```D```"3Y0``!P```)WE```*````I>4```D```"PY0``#@```+KE
M```0````R>4``!L```#:Y0``&````/;E```:````#^8```H````JY@``"0``
M`#7F```*````/^8```P```!*Y@``#P```%?F```(````9^8```8```!PY@``
M'````'?F```'````E.8```4```"<Y@``"P```*+F``!'````KN8```T```#V
MY@``"0````3G```$````#N<```,````3YP``$P```!?G```3````*^<``!,`
M```_YP``"@```%/G```"````7N<```0```!AYP``)0```&;G```#````C.<`
M``4```"0YP``*@```);G```*````P><```4```#,YP``!````-+G```*````
MU^<```T```#BYP``!@```/#G```(````]^<```@`````Z```!`````GH```%
M````#N@``&@````4Z```"0```'WH```,````A^@``!````"4Z```!0```*7H
M```&````J^@``!L```"RZ```+P```,[H```0````_N@```H````/Z0``#P``
M`!KI```*````*ND```D````UZ0``$P```#_I```;````4^D``!@```!OZ0``
M%P```(CI```?````H.D```X```#`Z0```P```,_I```'````T^D```@```#;
MZ0``!P```.3I```*````[.D```L```#WZ0``!P````/J``!1````"^H``!``
M``!=Z@``#````&[J```-````>^H``!H```")Z@``2@```*3J```9````[^H`
M``8````)ZP``&@```!#K```E````*^L```8```!1ZP``!@```%CK```?````
M7^L```8```!_ZP``"0```(;K```8````D.L``!<```"IZP``*````,'K```&
M````ZNL```T```#QZP``(@```/_K``!7````(NP``!,```!Z[```(P```([L
M```3````LNP```(```#&[```"P```,GL```(````U>P```T```#>[```"@``
M`.SL```'````]^P``!0```#_[```!@```!3M```(````&^T```X````D[0``
M!P```#/M```*````.^T```L```!&[0``,@```%+M```'````A>T```P```"-
M[0``#0```)KM```,````J.T```D```"U[0``"0```+_M```*````R>T```<`
M``#4[0``"0```-SM```'````YNT```H```#N[0``&P```/GM```2````%>X`
M``H````H[@``%@```#/N```)````2NX``!````!4[@``!P```&7N```2````
M;>X```0```"`[@``!P```(7N```%````C>X```4```"3[@``"P```)GN```4
M````I>X``!$```"Z[@``&@```,SN```6````Y^X``!0```#^[@``%P```!/O
M```8````*^\``!P```!$[P``&0```&'O```'````>^\```4```"#[P``#0``
M`(GO```,````E^\``!$```"D[P``"````+;O```7````O^\```L```#7[P``
M#````./O```?````\.\``!H````0\```$P```"OP```$````/_````H```!$
M\```!````$_P```-````5/````P```!B\```!0```&_P```)````=?````4`
M``!_\```!P```(7P```%````C?````0```"3\````@```)CP```X````F_``
M`"P```#4\```$@````'Q```I````%/$``#(````^\0``"@```''Q```L````
M?/$``"X```"I\0``,P```-CQ```S````#/(``#@```!`\@``#P```'GR```8
M````B?(``!````"B\@``#P```+/R```3````P_(``!4```#7\@``%````.WR
M```2`````O,``!0````5\P``%0```"KS```M````0/,``"T```!N\P``,0``
M`)SS```N````SO,``"\```#]\P``+````"WT``!B````6O0``!,```"]]```
M#0```-'T```(````W_0``!<```#H]```"`````#U```,````"?4``"L````6
M]0``(0```$+U```:````9/4```D```!_]0``10```(GU``!!````S_4```0`
M```1]@``$P```!;V```.````*O8``!,````Y]@``&````$WV```&````9O8`
M``D```!M]@``"@```'?V```/````@O8``!````"2]@``!P```*/V```.````
MJ_8```4```"Z]@``&P```,#V```(````W/8```8```#E]@``%````.SV```1
M`````?<```X````3]P``.````"+W```"````6_<```8```!>]P``#@```&7W
M```%````=/<```<```!Z]P``#@```(+W```&````D?<``"@```"8]P``#```
M`,'W```<````SO<```0```#K]P``*0```/#W```7````&O@``!\````R^```
M7````%+X```4````K_@``#X```#$^```'P````/Y```0````(_D```<````T
M^0``#@```#SY```,````2_D```P```!8^0``$P```&7Y```*````>?D``!T`
M``"$^0``&0```*+Y```%````O/D``!$```#"^0``$0```-3Y```D````YOD`
M`!(````+^@``%0```![Z```2````-/H```X```!'^@``&0```%;Z```(````
M</H```D```!Y^@``#0```(/Z```*````D?H```<```"<^@``#P```*3Z```&
M````M/H```L```"[^@``&@```,?Z```*````XOH```<```#M^@``"````/7Z
M```%````_OH``!\````$^P``!@```"3[```0````*_L```@````\^P``#0``
M`$7[```(````4_L``!X```!<^P``$@```'O[```L````COL``!H```"[^P``
M"0```-;[```*````X/L``!4```#K^P``!0````'\```4````!_P```0````<
M_```$````"'\```&````,OP```<````Y_```'@```$'\```H````8/P```H`
M``")_```'````)3\```1````L?P```L```##_```&@```,_\```4````ZOP`
M``0```#__```!`````3]```+````"?T```4````5_0``!@```!O]```(````
M(OT```8````K_0``&P```#+]```T````3OT``#0```"#_0``(````+C]```I
M````V?T``"`````#_@``00```"3^```:````9OX``"@```"!_@``*0```*K^
M``!0````U/X``"(````E_P``!@```$C_```(````3_\```4```!8_P``"```
M`%[_```9````9_\``!D```"!_P``*@```)O_```C````QO\``!D```#J_P``
M+@````0``0`T````,P`!``@```!H``$`%P```'$``0`*````B0`!``<```"4
M``$`(0```)P``0`0````O@`!``X```#/``$`"P```-X``0`'````Z@`!`!,`
M``#R``$`"`````8!`0`+````#P$!``H````;`0$`%````"8!`0`/````.P$!
M`#(```!+`0$`"P```'X!`0`%````B@$!``4```"0`0$`!0```)8!`0`7````
MG`$!``\```"T`0$`!````,0!`0`*````R0$!``D```#4`0$`"P```-X!`0`-
M````Z@$!``P```#X`0$`#@````4"`0`%````%`(!``0````:`@$`#0```!\"
M`0`R````+0(!`$4```!@`@$`%P```*8"`0`'````O@(!`!X```#&`@$`%```
M`.4"`0`%````^@(!`!0``````P$`!@```!4#`0`'````'`,!``X````D`P$`
M*@```#,#`0`&````7@,!``P```!E`P$`#0```'(#`0`1````@`,!``L```"2
M`P$`-@```)X#`0`*````U0,!`"(```#@`P$`"P````,$`0`/````#P0!`#(`
M```?!`$`)0```%($`0`P````>`0!`#$```"I!`$`+0```-L$`0`.````"04!
M``4````8!0$`#@```!X%`0`3````+04!`!(```!!!0$`!P```%0%`0`1````
M7`4!`!,```!N!0$`!P```((%`0`4````B@4!`!@```"?!0$`!P```+@%`0`%
M````P`4!``P```#&!0$`#````-,%`0`2````X`4!``0```#S!0$`!P```/@%
M`0`*``````8!``L````+!@$`#````!<&`0`.````)`8!``X````S!@$`!0``
M`$(&`0`%````2`8!`"X```!.!@$`)@```'T&`0`C````I`8!``,```#(!@$`
M$@```,P&`0`&````WP8!`!X```#F!@$`&`````4'`0`E````'@<!``T```!$
M!P$`"0```%('`0`?````7`<!``,```!\!P$`!P```(`'`0`*````B`<!``(`
M``"3!P$`#````)8'`0`5````HP<!``L```"Y!P$`&0```,4'`0`@````WP<!
M`!(`````"`$`!0```!,(`0`*````&0@!`!4````D"`$`$@```#H(`0`,````
M30@!``0```!:"`$`"0```%\(`0`'````:0@!``P```!Q"`$`4@```'X(`0`7
M````T0@!`"0```#I"`$`$@````X)`0`'````(0D!``8````I"0$`#@```#`)
M`0`,````/PD!``T```!,"0$`%0```%H)`0`2````<`D!``\```"#"0$`%```
M`),)`0`*````J`D!`!L```"S"0$`$````,\)`0`+````X`D!`&D```#L"0$`
M&@```%8*`0`7````<0H!`"<```")"@$`&@```+$*`0`7````S`H!`!L```#D
M"@$`&0`````+`0`?````&@L!`!,````Z"P$`"````$X+`0`'````5PL!``@`
M``!?"P$`"0```&@+`0`5````<@L!``T```"("P$`(P```)8+`0`-````N@L!
M`!,```#("P$`"````-P+`0`#````Y0L!`$8```#I"P$`/P```#`,`0`W````
M<`P!`%<```"H#`$`!0`````-`0`?````!@T!`"\````F#0$`"@```%8-`0`(
M````80T!``T```!J#0$`+0```'@-`0`$````I@T!`$\```"K#0$`)0```/L-
M`0`<````(0X!``L````^#@$`'P```$H.`0`=````:@X!`"4```"(#@$`(```
M`*X.`0`D````SPX!`"````#T#@$`"P```!4/`0`'````(0\!``T````I#P$`
M#````#</`0`7````1`\!``8```!<#P$`.0```&,/`0`,````G0\!``<```"J
M#P$`"0```+(/`0`3````O`\!``D```#0#P$`!````-H/`0`0````WP\!``@`
M``#P#P$`"````/D/`0`$`````A`!``L````'$`$`#````!,0`0`2````(!`!
M`!$````S$`$`#````$40`0`:````4A`!``\```!M$`$`!P```'T0`0`-````
MA1`!`!0```"3$`$`#@```*@0`0`,````MQ`!`"P```#$$`$`$P```/$0`0`<
M````!1$!`"@````B$0$`!@```$L1`0`'````4A$!`!,```!:$0$`!0```&X1
M`0`$````=!$!`!<```!Y$0$`"@```)$1`0`,````G!$!``D```"I$0$`!@``
M`+,1`0`)````NA$!``@```#$$0$`"0```,T1`0`*````UQ$!`!$```#B$0$`
M!@```/01`0`.````^Q$!``X````*$@$`#0```!D2`0`+````)Q(!`!T````S
M$@$`"P```%$2`0`"````71(!`!P```!@$@$`!P```'T2`0`&````A1(!`&0`
M``",$@$`"0```/$2`0`'````^Q(!`"8````#$P$`.````"H3`0`:````8Q,!
M`"H```!^$P$`.P```*D3`0`H````Y1,!`#0````.%`$`&0```$,4`0`5````
M710!``4```!S%`$`!P```'D4`0`(````@10!``<```"*%`$`!0```)(4`0`'
M````F!0!``X```"@%`$`"0```*\4`0`&````N10!``@```#`%`$`"P```,D4
M`0`'````U10!``@```#=%`$`!P```.84`0`6````[A0!``D````%%0$`!@``
M``\5`0`+````%A4!`!`````B%0$`!@```#,5`0`<````.A4!`!0```!7%0$`
M!P```&P5`0`1````=!4!``@```"&%0$`#@```(\5`0`(````GA4!``4```"G
M%0$`$````*T5`0`0````OA4!``8```#/%0$`&0```-85`0`*````\!4!`!P`
M``#[%0$`!P```!@6`0`%````(!8!`!`````F%@$`%````#<6`0`+````3!8!
M``T```!8%@$`*````&86`0`8````CQ8!`!<```"H%@$`!````,`6`0`)````
MQ18!``H```#/%@$`!P```-H6`0`"````XA8!``@```#E%@$`(P```.X6`0`X
M````$A<!`"8```!+%P$`,0```'(7`0`G````I!<!`&0```#,%P$`%````#$8
M`0!5````1A@!`#@```"<&`$`2@```-48`0!;````(!D!`"@```!\&0$`.```
M`*49`0`H````WAD!`"P````'&@$`)@```#0:`0`;````6QH!`#X```!W&@$`
MJ0$``+8:`0`C````8!P!`!<```"$'`$`2````)P<`0"%````Y1P!`#````!K
M'0$`)0```)P=`0!!````PAT!`%L````$'@$`20```&`>`0`Q````JAX!`!T`
M``#<'@$`&````/H>`0`K````$Q\!`"$````_'P$`'P```&$?`0`K````@1\!
M`"$```"M'P$`)P```,\?`0`Z````]Q\!`!T````R(`$`$0```%`@`0`S````
M8B`!`"4```"6(`$`)P```+P@`0`@````Y"`!`!\````%(0$`,````"4A`0!I
M````5B$!`#$```#`(0$`00```/(A`0`S````-"(!`"4```!H(@$`/0```(XB
M`0!E````S"(!`$T````R(P$`+P```(`C`0`N````L",!`#````#?(P$`5```
M`!`D`0!:````920!`$@```#`)`$`2@````DE`0`R````5"4!`"\```"')0$`
M+````+<E`0`M````Y"4!`'$````2)@$`9@```(0F`0!O````ZR8!`+,```!;
M)P$`%P````\H`0`E````)R@!`#(```!-*`$`*0```(`H`0`^````JB@!`"(`
M``#I*`$`4@````PI`0`E````7RD!``L```"%*0$`L0```)$I`0!%````0RH!
M`"$```")*@$`,````*LJ`0`E````W"H!`!P````"*P$`,0```!\K`0`'````
M42L!``<```!9*P$`!````&$K`0`-````9BL!``L```!T*P$`#@```(`K`0`+
M````CRL!``4```";*P$`$````*$K`0`"````LBL!`%D```"U*P$`!0````\L
M`0`2````%2P!``0````H+`$`!P```"TL`0`(````-2P!``4````^+`$``P``
M`$0L`0`0````2"P!``P```!9+`$`$P```&8L`0`-````>BP!``(```"(+`$`
M!P```(LL`0`&````DRP!``P```":+`$`&````*<L`0`&````P"P!`!(```#'
M+`$`#````-HL`0`#````YRP!`"H```#K+`$`!````!8M`0`&````&RT!``<`
M```B+0$`'P```"HM`0`U````2BT!`"X```"`+0$`+P```*\M`0`7````WRT!
M`"(```#W+0$`)0```!HN`0`@````0"X!`!L```!A+@$`&````'TN`0`D````
MEBX!`!\```"[+@$`&@```-LN`0`A````]BX!`"`````8+P$`&@```#DO`0`R
M````5"\!`!H```"'+P$`+P```*(O`0`K````TB\!`!\```#^+P$`(P```!XP
M`0`?````0C`!`!H```!B,`$`(0```'TP`0`E````GS`!`"8```#%,`$`)0``
M`.PP`0`D````$C$!`!@````W,0$`'0```%`Q`0`D````;C$!`!@```"3,0$`
M(@```*PQ`0`L````SS$!`"\```#\,0$`%0```"PR`0`E````0C(!`#P```!H
M,@$`'P```*4R`0`C````Q3(!`!\```#I,@$`(`````DS`0`:````*C,!`!@`
M``!%,P$`)@```%XS`0`>````A3,!`"D```"D,P$`'@```,XS`0`Q````[3,!
M``D````?-`$`#````"DT`0`7````-C0!`"\```!.-`$`)````'XT`0`'````
MHS0!`!0```"K-`$`#@```,`T`0`-````SS0!``4```#=-`$`!P```.,T`0`B
M````ZS0!`"4````.-0$`&@```#0U`0`=````3S4!`!H```!M-0$`!P```(@U
M`0#'````D#4!``L```!8-@$`%0```&0V`0`&````>C8!``D```"!-@$`"P``
M`(LV`0`-````ES8!`!<```"E-@$`!@```+TV`0`S````Q#8!`!,```#X-@$`
M$P````PW`0`'````(#<!``\````H-P$`!P```#@W`0`R````0#<!``0```!S
M-P$`(0```'@W`0`3````FC<!``P```"N-P$`$0```+LW`0`R````S3<!`!8`
M````.`$`"````!<X`0`=````(#@!``D````^.`$`"@```$@X`0`4````4S@!
M``H```!H.`$`'0```',X`0`(````D3@!`!\```":.`$`"````+HX`0`:````
MPS@!`"<```#>.`$`!@````8Y`0`5````#3D!``<````C.0$`"````"LY`0`)
M````-#D!`#\````^.0$`!P```'XY`0`/````ACD!``X```"6.0$`$````*4Y
M`0`)````MCD!``D```#`.0$`"````,HY`0`'````TSD!`!D```#;.0$`"@``
M`/4Y`0`7`````#H!`!0````8.@$`"@```"TZ`0`,````.#H!`!<```!%.@$`
M!````%TZ`0`J````8CH!``P```"-.@$`$0```)HZ`0`'````K#H!``(```"T
M.@$`$````+<Z`0`8````R#H!``L```#A.@$``P```.TZ`0`(````\3H!``8`
M``#Z.@$`!P````$[`0`-````"3L!``L````7.P$`#@```",[`0`O````,CL!
M`"````!B.P$`'````(,[`0`5````H#L!``P```"V.P$`,0```,,[`0`%````
M]3L!`!(```#[.P$`/P````X\`0`2````3CP!``H```!A/`$`!@```&P\`0`$
M````<SP!``0```!X/`$`"@```'T\`0`3````B#P!``4```"</`$`!@```*(\
M`0`&````J3P!``@```"P/`$`!````+D\`0`,````OCP!``H```#+/`$`.0``
M`-8\`0`N````$#T!`"D````_/0$`!0```&D]`0`8````;ST!`!D```"(/0$`
M'P```*(]`0`=````PCT!`!$```#@/0$``@```/(]`0`$````]3T!``H```#Z
M/0$`!@````4^`0`%````##X!``,````2/@$`#````!8^`0!%````(SX!`#(`
M``!I/@$`&@```)P^`0`T````MSX!`"@```#L/@$`4P```!4_`0`9````:3\!
M`'(```"#/P$`(````/8_`0`U````%T`!`"$```!-0`$`10```&]``0`P````
MM4`!`"@```#F0`$`*0````]!`0`F````.4$!`"4```!@00$`*````(9!`0`H
M````KT$!`"(```#800$`*P```/M!`0`P````)T(!`!(```!80@$`$P```&M"
M`0`0````?T(!`'D```"00@$`"0````I#`0"A````%$,!`',```"V0P$`?```
M`"I$`0`K````IT0!`%0```#31`$`%P```"A%`0`G````0$4!`!8```!H10$`
M#P```']%`0`7````CT4!`!\```"G10$`0````,=%`0`?````"$8!`!P````H
M1@$`40```$5&`0`:````ET8!`!0```"R1@$`"@```,=&`0`%````TD8!``8`
M``#81@$`"````-]&`0`%````Z$8!`!(```#N1@$`$`````%'`0`3````$D<!
M`!T````F1P$`#P```$1'`0`/````5$<!``0```!D1P$`"0```&E'`0`+````
M<T<!``<```!_1P$`!0```(='`0`4````C4<!``<```"B1P$`"````*I'`0`/
M````LT<!``@```##1P$`#````,Q'`0`/````V4<!``8```#I1P$`%````/!'
M`0`&````!4@!``P````,2`$`$0```!E(`0`(````*T@!``0````T2`$`&0``
M`#E(`0`1````4T@!``H```!E2`$`&````'!(`0`3````B4@!`!P```"=2`$`
M$0```+I(`0`/````S$@!``<```#<2`$`!````.1(`0`9````Z4@!``<````#
M20$``@````M)`0`"````#DD!`!$````120$`"0```"-)`0`&````+4D!`!(`
M```T20$`%P```$=)`0`&````7TD!`"<```!F20$``@```(Y)`0`$````D4D!
M``\```"620$`$P```*9)`0`'````NDD!``<```#"20$`$0```,I)`0`&````
MW$D!`!@```#C20$`!@```/Q)`0`3`````TH!`!`````72@$`$@```"A*`0`"
M````.TH!``8````^2@$`#````$5*`0`)````4DH!`!$```!<2@$`(@```&Y*
M`0`'````D4H!``<```"92@$`"P```*%*`0`%````K4H!``(```"S2@$`"P``
M`+9*`0!)`0``PDH!`!`````,3`$`%P```!U,`0`+````-4P!``8```!!3`$`
M"0```$A,`0`(````4DP!``H```!;3`$`%````&9,`0`9````>TP!`"T```"5
M3`$`)0```,-,`0`E````Z4P!`",````/30$`'P```#--`0`M````4TT!``H`
M``"!30$`*@```(Q-`0`3````MTT!``T```#+30$`"P```-E-`0`%````Y4T!
M`"T```#K30$`#0```!E.`0`=````)TX!`!4```!%3@$`#P```%M.`0`1````
M:TX!`'0```!]3@$`#@```/).`0`(`````4\!`!$````*3P$`#0```!Q/`0`6
M````*D\!`!<```!!3P$`%P```%E/`0`:````<4\!``8```",3P$`OP```)-/
M`0`+````4U`!`!(```!?4`$`'0```')0`0`0````D%`!`!(```"A4`$`$@``
M`+10`0`(````QU`!``\```#04`$`,````.!0`0`9````$5$!`#8````K40$`
M/0```&)1`0!0````H%$!`$\```#Q40$`6````$%2`0!6````FE(!`#@```#Q
M4@$`%````"I3`0`7````/U,!`!$```!74P$`%0```&E3`0`=````?U,!``@`
M``"=4P$`!@```*93`0`/````K5,!``0```"]4P$`$````,)3`0`/````TU,!
M`#(```#C4P$`,````!94`0`1````1U0!``X```!95`$`$0```&A4`0`)````
M>E0!``8```"$5`$`&0```(M4`0`7````I50!``<```"]5`$`#@```,54`0`1
M````U%0!`!X```#F5`$`'`````55`0`3````(E4!``T````V50$`#0```$15
M`0`*````4E4!`"8```!=50$`$P```(15`0`8````F%4!`!(```"Q50$`5```
M`,15`0`W````&58!`"0```!15@$`!@```'96`0`'````?58!`#8```"%5@$`
M#0```+Q6`0`'````RE8!``H```#25@$`"````-U6`0`(````YE8!``4```#O
M5@$`"````/56`0`+````_E8!``8````*5P$`(P```!%7`0`.````-5<!``P`
M``!$5P$`$P```%%7`0`6````95<!`"L```!\5P$`"P```*A7`0`D````M%<!
M`!<```#95P$`)````/%7`0`=````%E@!`!0````T6`$`$@```$E8`0`.````
M7%@!`!P```!K6`$`%@```(A8`0`'````GU@!``8```"G6`$`"````*Y8`0`.
M````MU@!``<```#&6`$`"@```,Y8`0`1````V5@!``D```#K6`$`$````/58
M`0`8````!ED!`"H````?60$`"````$I9`0`1````4UD!``4```!E60$`#P``
M`&M9`0`,````>UD!`#$```"(60$`+P```+I9`0`)````ZED!``@```#T60$`
M!@```/U9`0`%````!%H!`!`````*6@$`#````!M:`0`5````*%H!`#0````^
M6@$`*````'-:`0`G````G%H!`"0```#$6@$`,0```.E:`0`(````&UL!``8`
M```D6P$`"0```"M;`0`'````-5L!`#<````]6P$`+P```'5;`0`V````I5L!
M`%X```#<6P$`-0```#M<`0`U````<5P!`$H```"G7`$`2P```/)<`0`U````
M/ET!`$(```!T70$`,0```+==`0`T````Z5T!`$P````>7@$`-0```&M>`0`[
M````H5X!`"P```#=7@$`%@````I?`0`:````(5\!`"8````\7P$`*P```&-?
M`0`K````CU\!`!$```"[7P$`"P```,U?`0`,````V5\!``<```#F7P$`#0``
M`.Y?`0`7````_%\!`"0````48`$`!@```#E@`0`'````0&`!``D```!(8`$`
M"````%)@`0`H````6V`!``\```"$8`$`"@```)1@`0`(````GV`!``8```"H
M8`$`!0```*]@`0`'````M6`!``4```"]8`$`"@```,-@`0`G````SF`!`!``
M``#V8`$`"0````=A`0`%````$6$!``<````780$`!P```!]A`0`%````)V$!
M``T````M80$`!@```#MA`0`3````0F$!``,```!680$`"````%IA`0`&````
M8V$!``T```!J80$`"````'AA`0`@````@6$!`!$```"B80$`"0```+1A`0`2
M````OF$!``P```#180$`!P```-YA`0`#````YF$!``,```#J80$`%````.YA
M`0`4`````V(!`#(````88@$`"````$MB`0`)````5&(!``@```!>8@$`!P``
M`&=B`0!+````;V(!`"0```"[8@$`+0```.!B`0`H````#F,!`"$````W8P$`
M!@```%EC`0`&````8&,!`!@```!G8P$`(0```(!C`0`D````HF,!`"X```#'
M8P$`)0```/9C`0`M````'&0!`&````!*9`$`+@```*MD`0`2````VF0!``<`
M``#M9`$`$P```/5D`0`1````"64!``\````;90$`$````"ME`0`0````/&4!
M`!````!-90$`$````%YE`0`/````;V4!``D```!_90$`%P```(EE`0`A````
MH64!`!0```##90$`&````-AE`0`#````\64!``8```#U90$`$0```/QE`0!5
M````#F8!`%P```!D9@$`!````,%F`0`6````QF8!``4```#=9@$`!````.-F
M`0`2````Z&8!``\```#[9@$`'`````MG`0`D````*&<!`#````!-9P$`#P``
M`'YG`0`C````CF<!``4```"R9P$`&@```+AG`0`-````TV<!`!D```#A9P$`
M%0```/MG`0`;````$6@!`!$````M:`$`&0```#]H`0`3````66@!``T```!M
M:`$`!@```'MH`0`,````@F@!``<```"/:`$`%P```)=H`0`2````KV@!``X`
M``#":`$`"````-%H`0`%````VF@!``L```#@:`$`"P```.QH`0`'````^&@!
M``\`````:0$`!@```!!I`0`&````%VD!`!4````>:0$`"````#1I`0`*````
M/6D!``8```!(:0$`"@```$]I`0`(````6FD!``0```!C:0$`!````&AI`0`7
M````;6D!`$P```"%:0$`)````-)I`0`/````]VD!``X````':@$`!0```!9J
M`0`<````'&H!`!$````Y:@$`$@```$MJ`0`N````7FH!`#T```"-:@$`(```
M`,MJ`0`(````[&H!`#````#U:@$`&@```"9K`0`*````06L!``H```!,:P$`
M#P```%=K`0`&````9VL!``D```!N:P$`%P```'AK`0`/````D&L!``D```"@
M:P$`$@```*IK`0`M````O6L!`"L```#K:P$`+P```!=L`0`M````1VP!`"$`
M``!U;`$`)@```)=L`0`E````OFP!`"D```#D;`$`*0````YM`0`U````.&T!
M`"L```!N;0$`)````)IM`0`F````OVT!`"$```#F;0$`*@````AN`0`Z````
M,VX!`"X```!N;@$`)````)UN`0`P````PFX!`#D```#S;@$`)0```"UO`0`A
M````4V\!`#0```!U;P$`)0```*IO`0`9````T&\!`"\```#J;P$`(P```!IP
M`0`F````/G`!`!H```!E<`$`L0```(!P`0`2````,G$!`"````!%<0$`*0``
M`&9Q`0`I````D'$!`#$```"Z<0$`(@```.QQ`0`A````#W(!`"4````Q<@$`
M*0```%=R`0`L````@7(!`#H```"N<@$`+````.ER`0"3````%G,!`"4```"J
M<P$`&P```-!S`0`F````[',!`"\````3=`$`+P```$-T`0!&````<W0!`$0`
M``"Z=`$`#0```/]T`0`'````#74!``4````5=0$`"````!MU`0`.````)'4!
M``T````S=0$`%0```$%U`0`,````5W4!`!4```!D=0$`"@```'IU`0`$````
MA74!``\```"*=0$`$````)IU`0`,````JW4!``\```"X=0$`%0```,AU`0`0
M````WG4!`!0```#O=0$`#0````1V`0!"````$G8!``H```!5=@$`$````&!V
M`0`&````<78!``\```!X=@$``@```(AV`0!+````BW8!``4```#7=@$`(P``
M`-UV`0`7`````7<!``4````9=P$`#@```!]W`0`,````+G<!``,````[=P$`
M$0```#]W`0`(````47<!`!````!:=P$`$0```&MW`0`-````?7<!`!,```"+
M=P$`&P```)]W`0`C````NW<!``D```#?=P$`!P```.EW`0`-````\7<!``\`
M``#_=P$`#@````]X`0`-````'G@!`!H````L>`$`#0```$=X`0`.````57@!
M`"<```!D>`$`%@```(QX`0`K````HW@!``X```#/>`$`&````-YX`0`7````
M]W@!`!<````/>0$`,0```"=Y`0`-````67D!``8```!G>0$`#P```&YY`0`%
M````?GD!`"L```"$>0$`+````+!Y`0`%````W7D!``D```#C>0$`'@```.UY
M`0`+````#'H!`!(````8>@$`$@```"MZ`0`'````/GH!`"8```!&>@$`%0``
M`&UZ`0`;````@WH!`!@```"?>@$`$0```+AZ`0`5````RGH!``D```#@>@$`
M"0```.IZ`0`C````]'H!`#T````8>P$`"````%9[`0`6````7WL!`!X```!V
M>P$`"````)5[`0`+````GGL!`#(```"J>P$`$````-U[`0`%````[GL!``8`
M``#T>P$``P```/M[`0`'````_WL!``<````'?`$`#`````]\`0`/````''P!
M``T````L?`$`#0```#I\`0`4````2'P!`!<```!=?`$`%@```'5\`0`4````
MC'P!``L```"A?`$`!0```*U\`0`(````LWP!``H```"\?`$``@```,=\`0`%
M````RGP!`!````#0?`$`(P```.%\`0`3````!7T!`!(````9?0$`"0```"Q]
M`0`/````-GT!`!$```!&?0$`&@```%A]`0`M````<WT!`"L```"A?0$`"P``
M`,U]`0`.````V7T!`'8```#H?0$`$P```%]^`0`?````<WX!`!````"3?@$`
M!P```*1^`0`%````K'X!`!T```"R?@$`,0```-!^`0`O`````G\!`!X````R
M?P$`(````%%_`0`:````<G\!`!H```"-?P$`"````*A_`0`'````L7\!``<`
M``"Y?P$`!@```,%_`0`0````R'\!``X```#9?P$`$0```.A_`0`/````^G\!
M`!4````*@`$`#P```""``0`,````,(`!``H````]@`$`!P```$B``0`(````
M4(`!`!0```!9@`$`#@```&Z``0`W````?8`!``\```"U@`$`"````,6``0`+
M````SH`!`!H```#:@`$`(````/6``0`J````%H$!`"D```!!@0$`'P```&N!
M`0`@````BX$!`"H```"L@0$`'P```->!`0`8````]X$!``4````0@@$`'0``
M`!:"`0`/````-((!``X```!$@@$``P```%."`0`$````5X(!``<```!<@@$`
M#0```&2"`0`/````<H(!``L```""@@$`%0```(Z"`0`+````I((!``4```"P
M@@$`!0```+:"`0`7````O((!`!D```#4@@$`#P```.Z"`0`+````_H(!``P`
M```*@P$`#P```!>#`0`F````)X,!``8```!.@P$`!@```%6#`0`-````7(,!
M``H```!J@P$`"P```'6#`0`&````@8,!``X```"(@P$`!````)>#`0`7````
MG(,!``L```"T@P$`!P```,"#`0`J````R(,!``\```#S@P$`@P````.$`0`2
M````AX0!``D```":A`$`!P```*2$`0`+````K(0!``<```"XA`$`"0```,"$
M`0`$````RH0!``T```#/A`$``P```-V$`0`%````X80!``H```#GA`$`$P``
M`/*$`0`2````!H4!`!0````9A0$`&@```"Z%`0`"````284!``D```!,A0$`
M"P```%:%`0`$````8H4!``H```!GA0$`!0```'*%`0`F````>(4!``@```"?
MA0$`!@```*B%`0`G````KX4!``X```#7A0$`!P```.:%`0`'````[H4!``4`
M``#VA0$`"0```/R%`0`+````!H8!``<````2A@$`!@```!J&`0`+````(88!
M`!`````MA@$`#0```#Z&`0`&````3(8!``<```!3A@$`!P```%N&`0`4````
M8X8!`!T```!XA@$`/P```):&`0`L````UH8!`#$````#AP$`!P```#6'`0`*
M````/8<!``0```!(AP$`"0```$V'`0`(````5X<!`!T```!@AP$`"0```'Z'
M`0`&````B(<!``T```"/AP$`!@```)V'`0`$````I(<!`#(```"IAP$`-```
M`-R'`0`T````$8@!`",```!&B`$`!0```&J(`0`=````<(@!``0```".B`$`
M"````).(`0`(````G(@!`"0```"EB`$`"P```,J(`0`%````UH@!``@```#<
MB`$`'P```.6(`0`(````!8D!``@````.B0$`%@```!>)`0`&````+HD!``8`
M```UB0$`!P```#R)`0`%````1(D!``T```!*B0$`$````%B)`0`-````:8D!
M``@```!WB0$`"0```(")`0`%````BHD!`#L```"0B0$`.````,R)`0`\````
M!8H!`"<```!"B@$`.````&J*`0!`````HXH!`#````#DB@$`.@```!6+`0`U
M````4(L!`#X```"&BP$`*0```,6+`0`2````[XL!`!8````"C`$`#0```!F,
M`0`J````)XP!`!P```!2C`$`'0```&^,`0`<````C8P!``<```"JC`$`"0``
M`+*,`0`)````O(P!``@```#&C`$`*````,^,`0`G````^(P!`"4````@C0$`
M"0```$:-`0`:````4(T!`"\```!KC0$`)@```)N-`0`1````PHT!``8```#4
MC0$`"0```-N-`0`,````Y8T!``P```#RC0$`#P```/^-`0`V````#XX!`((`
M``!&C@$`=@```,F.`0`/````0(\!``L```!0CP$`#````%R/`0`1````:8\!
M`!(```![CP$`$````(Z/`0`'````GX\!``\```"GCP$`%````+>/`0`2````
MS(\!``\```#?CP$`'P```.^/`0`J````#Y`!`(8````ZD`$`$0```,&0`0`%
M````TY`!`!<```#9D`$`"0```/&0`0`$````^Y`!``H`````D0$`'@````N1
M`0`1````*I$!``X````\D0$`#@```$N1`0`,````6I$!`!,```!GD0$`'@``
M`'N1`0`@````FI$!`!X```"[D0$`(````-J1`0`?````^Y$!`"$````;D@$`
M&P```#V2`0`X````69(!``\```"2D@$`$0```**2`0`0````M)(!`!(```#%
MD@$`#0```-B2`0`2````YI(!`!0```#YD@$`$`````Z3`0`2````'Y,!`#(`
M```RDP$`%@```&63`0`4````?),!`#T```"1DP$`%````,^3`0`*````Y),!
M`!,```#ODP$`00````.4`0`;````190!`!,```!AE`$`$@```'64`0`=````
MB)0!`!@```"FE`$`%@```+^4`0`7````UI0!`!X```#NE`$`&@````V5`0`H
M````*)4!`",```!1E0$`&@```'65`0`5````D)4!`!8```"FE0$`$0```+V5
M`0`7````SY4!`!D```#GE0$`&0````&6`0`7````&Y8!``@````SE@$`$```
M`#R6`0`$````398!``0```!2E@$`!0```%>6`0`+````798!``\```!IE@$`
M!@```'F6`0`)````@)8!``<```"*E@$`"0```)*6`0`'````G)8!``8```"D
ME@$`"````*N6`0`&````M)8!``8```"[E@$``P```,*6`0`#````QI8!``@`
M``#*E@$`$@```-.6`0`1````YI8!``X```#XE@$`#P````>7`0`*````%Y<!
M`!(````BEP$`!````#67`0`H````.I<!`!(```!CEP$`$````':7`0`8````
MAY<!``L```"@EP$`"0```*R7`0`.````MI<!`"T```#%EP$`!````/.7`0`(
M````^)<!`"(````!F`$`$@```"28`0`&````-Y@!``D````^F`$`!P```$B8
M`0`%````4)@!``0```!6F`$`$0```%N8`0`4````;9@!``X```""F`$`%@``
M`)&8`0`8````J)@!`!T```#!F`$`&P```-^8`0`(````^Y@!``4````$F0$`
M!@````J9`0`A````$9D!``<````SF0$`!0```#N9`0`.````09D!``T```!0
MF0$`!P```%Z9`0`&````9ID!``<```!MF0$`!0```'69`0`/````>YD!``\`
M``"+F0$`"@```)N9`0`/````IID!`!$```"VF0$`%@```,B9`0`4````WYD!
M``X```#TF0$`%@````.:`0`(````&IH!``4````CF@$`$0```"F:`0`V````
M.YH!``4```!RF@$`#````'B:`0`C````A9H!`!8```"IF@$`%````,":`0`7
M````U9H!``P```#MF@$`"0```/J:`0`'````!)L!``H````,FP$`"0```!>;
M`0`.````(9L!`!`````PFP$`'0```$&;`0`C````7YL!`"X```"#FP$`"@``
M`+*;`0`%````O9L!``X```##FP$`#0```-*;`0`1````X)L!``@```#RFP$`
M"P```/N;`0`F````!YP!``@````NG`$`"P```#><`0`4````0YP!`%$```!8
MG`$`%````*J<`0`)````OYP!``4```#)G`$`!0```,^<`0`3````U9P!`!4`
M``#IG`$`$P```/^<`0`+````$YT!``(````?G0$`"@```"*=`0`J````+9T!
M``,```!8G0$`!0```%R=`0`*````8IT!``H```!MG0$`!0```'B=`0`%````
M?IT!`!X```"$G0$`$@```*.=`0`&````MIT!``@```"]G0$`"````,:=`0`$
M````SYT!``4```#4G0$`80```-J=`0`*````/)X!``T```!'G@$`$@```%6>
M`0`%````:)X!``4```!NG@$`)P```'2>`0`T````G)X!`!,```#1G@$`"```
M`.6>`0`,````[IX!``H```#[G@$`"0````:?`0`:````$)\!`"P````KGP$`
M*@```%B?`0`I````@Y\!`!X```"MGP$`#P```,R?`0`#````W)\!``<```#@
MGP$`"````.B?`0`(````\9\!`!````#ZGP$`#`````N@`0`&````&*`!`$D`
M```?H`$`&0```&F@`0`*````@Z`!``T```".H`$`'````)R@`0!-````N:`!
M`"`````'H0$`!@```"BA`0`=````+Z$!`"@```!-H0$`"````':A`0`&````
M?Z$!`!T```"&H0$`!0```*2A`0`(````JJ$!`"H```"SH0$`*0```-ZA`0`N
M````"*(!`!$````WH@$`!0```$FB`0`>````3Z(!`%T```!NH@$`$````,RB
M`0`A````W:(!`!$```#_H@$``P```!&C`0`,````%:,!``8````BHP$`%0``
M`"FC`0`+````/Z,!``<```!+HP$`"0```%.C`0`&````7:,!``D```!DHP$`
M#````&ZC`0`'````>Z,!``H```"#HP$`#````(ZC`0`Y````FZ,!``8```#5
MHP$`#@```-RC`0`0````ZZ,!`!````#\HP$`#0````VD`0`.````&Z0!``\`
M```JI`$`#0```#JD`0`-````2*0!``T```!6I`$`"````&2D`0`>````;:0!
M`!$```",I`$`"@```)ZD`0`7````J:0!``H```#!I`$`%````,RD`0`'````
MX:0!`!````#II`$`!````/JD`0`'````_Z0!``4````'I0$`!0````VE`0`)
M````$Z4!`!`````=I0$`%0```"ZE`0`M````1*4!`!P```!RI0$`,0```(^E
M`0`J````P:4!`!D```#LI0$`'0````:F`0`8````)*8!``0````]I@$`!0``
M`$*F`0`.````2*8!``X```!7I@$`$@```&:F`0`#````>:8!`",```!]I@$`
M"P```*&F`0`*````K:8!`"````"XI@$`&@```-FF`0`2````]*8!``0````'
MIP$`$`````RG`0`%````':<!`!(````CIP$`$0```#:G`0`,````2*<!``D`
M``!5IP$`!0```%^G`0`'````9:<!``,```!MIP$`!````'&G`0`#````=J<!
M`%(```!ZIP$`0````,VG`0`=````#J@!`"X````LJ`$`-0```%NH`0`-````
MD:@!`#8```"?J`$`(@```-:H`0`G````^:@!`"<````AJ0$`+````$FI`0`.
M````=JD!`"0```"%J0$`%````*JI`0`<````OZD!`!H```#<J0$`%P```/>I
M`0`<````#ZH!`"$````LJ@$`&P```$ZJ`0`7````:JH!`"P```""J@$`+```
M`*^J`0`P````W*H!`"T````-JP$`+@```#NK`0`K````:JL!`%X```"6JP$`
M(````/6K`0`7````%JP!``@````NK`$`'@```#>L`0`)````5JP!``\```!@
MK`$`0````'"L`0`Q````L:P!`!\```#CK`$`#@````.M`0!5````$JT!`$P`
M``!HK0$`!@```+6M`0`B````O*T!``X```#?K0$`$````.ZM`0`9````_ZT!
M``8````9K@$`"@```""N`0`,````*ZX!``X````XK@$`%@```$>N`0`+````
M7JX!`!,```!JK@$`"````'ZN`0`B````AZX!``@```"JK@$`!0```+.N`0`,
M````N:X!``T```#&K@$`#0```-2N`0`^````XJX!``(````AKP$`!@```"2O
M`0`-````*Z\!``D````YKP$`!P```$.O`0`1````2Z\!``H```!=KP$`)0``
M`&BO`0`+````CJ\!`"(```":KP$`!````+VO`0`N````PJ\!`!0```#QKP$`
M*`````:P`0!J````+[`!`!0```":L`$`1````*^P`0`?````]+`!``\````4
ML0$`"@```"2Q`0`-````+[$!``\````]L0$`"P```$VQ`0`4````6;$!``T`
M``!NL0$`&0```'RQ`0`5````EK$!``,```"LL0$`$0```+"Q`0`/````PK$!
M`",```#2L0$`$0```/:Q`0`4````"+(!`!T````=L@$`$````#NR`0`G````
M3+(!``<```!TL@$`"0```'RR`0`4````AK(!`!(```";L@$`$@```*ZR`0`:
M````P;(!`!(```#<L@$`#P```.^R`0`6````_[(!``H````6LP$`"0```"&S
M`0`(````*[,!`!`````TLP$`$@```$6S`0`&````6+,!`!$```!?LP$`"```
M`'&S`0`1````>K,!``4```",LP$`&P```)*S`0`/````KK,!`"X```"^LP$`
M$@```.VS`0`&`````+0!``<````'M`$`&`````^T`0`&````*+0!`!(````O
MM`$`!0```$*T`0`9````2+0!``4```!BM`$`!P```&BT`0`7````<+0!`"<`
M``"(M`$`!0```+"T`0`;````MK0!`!(```#2M`$`!0```.6T`0`2````Z[0!
M`!$```#^M`$`!````!"U`0`/````%;4!``@````EM0$`!P```"ZU`0`*````
M-K4!``@```!!M0$`!0```$JU`0`@````4+4!`#,```!QM0$`/````*6U`0`<
M````XK4!`"<```#_M0$`(````">V`0`^````2+8!`!H```"'M@$`(````**V
M`0`O````P[8!`%@```#SM@$`)P```$RW`0`&````=+<!``@```![MP$`!@``
M`(2W`0`+````B[<!`!D```"7MP$`&0```+&W`0`L````R[<!`!\```#XMP$`
M&P```!BX`0`V````-+@!`#P```!KN`$`!````*BX`0`5````K;@!``8```##
MN`$`!@```,JX`0`D````T;@!`!D```#VN`$`$0```!"Y`0`-````(KD!``<`
M```PN0$`#@```#BY`0`(````1[D!`!8```!0N0$`#````&>Y`0`:````=+D!
M`!L```"/N0$`.````*NY`0`)````Y+D!``4```#NN0$`!0```/2Y`0`%````
M^KD!`!L`````N@$`$@```!RZ`0`$````+[H!``D````TN@$`"P```#ZZ`0`0
M````2KH!``X```!;N@$`'0```&JZ`0`/````B+H!``4```"8N@$`!0```)ZZ
M`0`,````I+H!`#4```"QN@$`60```.>Z`0`>````0;L!``<```!@NP$`(@``
M`&B[`0`;````B[L!``\```"GNP$`$@```+>[`0`-````RKL!``@```#8NP$`
M$0```.&[`0`M````\[L!``D````AO`$`#@```"N\`0`0````.KP!`!8```!+
MO`$`#0```&*\`0`Z````<+P!``D```"KO`$`'P```+6\`0`5````U;P!`!D`
M``#KO`$`.P````6]`0`F````0;T!`#X```!HO0$`/P```*>]`0`[````Y[T!
M``P````CO@$`$````#"^`0`-````0;X!`!(```!/O@$`%@```&*^`0`(````
M>;X!`!0```""O@$`$@```)>^`0`'````JKX!`!,```"RO@$`*````,:^`0`'
M````[[X!``8```#WO@$`#P```/Z^`0`.````#K\!`!4````=OP$`!````#._
M`0`(````.+\!``P```!!OP$`#````$Z_`0`-````6[\!`!$```!IOP$`$0``
M`'N_`0`'````C;\!``4```"5OP$`-````)N_`0`D````T+\!`"0```#UOP$`
M!P```!K``0`/````(L`!``8````RP`$`'````#G``0`A````5L`!`"0```!X
MP`$`#@```)W``0`)````K,`!`!X```"VP`$``P```-7``0`&````V<`!``H`
M``#@P`$``@```.O``0`,````[L`!`!,```#[P`$`"P````_!`0`5````&\$!
M`!D````QP0$`%@```$O!`0`%````8L$!``H```!HP0$`$P```'/!`0`6````
MA\$!``X```">P0$`!@```*W!`0`+````M,$!``D```#`P0$`$0```,K!`0!5
M````W,$!`!T````RP@$`,0```%#"`0`/````@L(!``0```"2P@$`!@```)?"
M`0`+````GL(!``X```"JP@$`#0```+G"`0`;````Q\(!`!@```#CP@$`#@``
M`/S"`0`?````"\,!``X````KPP$`(````#K#`0`.````6\,!``P```!JPP$`
M:@```'?#`0`D````XL,!`!8````'Q`$`)@```![$`0`B````1<0!`!0```!H
MQ`$`&0```'W$`0`9````E\0!``X```"QQ`$`&````,#$`0`*````V<0!``<`
M``#DQ`$`"````.S$`0`)````]<0!`!0```#_Q`$`#0```!3%`0`T````(L4!
M`!0```!7Q0$`'0```&S%`0`'````BL4!``X```"2Q0$`.P```*'%`0!.````
MW<4!`"\````LQ@$`>````%S&`0`*````U<8!`"@```#@Q@$`-P````G'`0`(
M````0<<!``@```!*QP$`#````%/'`0`V````8,<!``@```"7QP$`20```*#'
M`0`Y````ZL<!`"@````DR`$`(````$W(`0`G````;L@!`"$```"6R`$`+```
M`+C(`0`F````Y<@!`"T````,R0$`)@```#K)`0`0````8<D!``@```!RR0$`
M#0```'O)`0`/````B<D!``X```"9R0$`!P```*C)`0`T````L,D!``P```#E
MR0$`$````/+)`0`&`````\H!`!(````*R@$`"````!W*`0`'````)LH!`!``
M```NR@$`"0```#_*`0`)````2<H!``@```!3R@$`$````%S*`0`0````;<H!
M`!4```!^R@$`%P```)3*`0`-````K,H!`"(```"ZR@$`$@```-W*`0`(````
M\,H!``X```#YR@$`%0````C+`0`/````'LL!``P````NRP$`)@```#O+`0`.
M````8LL!`!\```!QRP$`)0```)'+`0`)````M\L!``8```#!RP$`$@```,C+
M`0`*````V\L!``0```#FRP$`&P```.O+`0`.````!\P!``\````6S`$`#P``
M`";,`0`&````-LP!``D````]S`$`"@```$?,`0`)````4LP!``X```!<S`$`
M%````&O,`0`$````@,P!``\```"%S`$`"````)7,`0`+````GLP!``\```"J
MS`$`&0```+K,`0`*````U,P!``(```#?S`$`(````.+,`0`'`````\T!``<`
M```+S0$`<@```!/-`0`+````ALT!``8```"2S0$`)@```)G-`0`^````P,T!
M`!P```#_S0$`)P```!S.`0!1````1,X!`"$```"6S@$`,@```+C.`0`?````
MZ\X!`!0````+SP$`!0```"#/`0`%````)L\!``P````LSP$`"P```#G/`0`'
M````1<\!``P```!-SP$`$@```%K/`0`.````;<\!``L```!\SP$`#0```(C/
M`0`+````EL\!``<```"BSP$`!P```*K/`0`*````LL\!`!0```"]SP$`"0``
M`-+/`0`'````W,\!``L```#DSP$`(0```/#/`0`&````$M`!`"@````9T`$`
M!0```$+0`0`%````2-`!``\```!.T`$`!0```%[0`0`*````9-`!``D```!O
MT`$`!P```'G0`0`2````@=`!`!(```"4T`$`!@```*?0`0`6````KM`!``L`
M``#%T`$`"````-'0`0`%````VM`!``4```#@T`$`#P```.;0`0`<````]M`!
M``<````3T0$`"0```!O1`0`F````)=$!`!P```!,T0$`#0```&G1`0`$````
M=]$!``@```!\T0$`$````(71`0`)````EM$!``(```"@T0$`!P```*/1`0`?
M````J]$!`"<```#+T0$`(0```//1`0`J````%=(!`"D```!`T@$`6@```&K2
M`0`1````Q=(!`%\```#7T@$`+@```#?3`0!)````9M,!`&P```"PTP$`'@``
M`!W4`0`P````/-0!`"@```!MU`$`,0```);4`0`K````R-0!`!\```#TU`$`
M.@```!35`0#+`0``3]4!`!P````;UP$`#P```#C7`0`_````2-<!`'P```"(
MUP$`0P````78`0`:````2=@!`#(```!DV`$`7@```)?8`0!(````]M@!`"$`
M```_V0$`%P```&'9`0`0````>=D!`!X```"*V0$`&0```*G9`0`8````P]D!
M`"<```#<V0$`(`````3:`0`>````)=H!`#$```!$V@$`&0```';:`0`0````
MD-H!`#0```"AV@$`(P```-;:`0`A````^MH!`"$````<VP$`(@```#[;`0`Y
M````8=L!`%0```";VP$`+P```/#;`0!'````(-P!`#````!HW`$`)P```)G<
M`0!!````P=P!`%X````#W0$`10```&+=`0`P````J-T!`"P```#9W0$`*P``
M``;>`0!6````,MX!`$\```")W@$`2@```-G>`0!)````)-\!`#,```!NWP$`
M+````*+?`0`L````S]\!`"T```#\WP$`90```"K@`0!:````D.`!`&,```#K
MX`$`G0```$_A`0`5````[>$!`",````#X@$`+P```"?B`0`O````5^(!`$$`
M``"'X@$`(````,GB`0!4````ZN(!`"$````_XP$`"P```&'C`0"U````;>,!
M`$@````CY`$`'P```&SD`0`V````C.0!`"(```##Y`$`'@```.;D`0`L````
M!>4!``<````RY0$`!P```#KE`0`#````0N4!``T```!&Y0$`"P```%3E`0`*
M````8.4!``L```!KY0$`!P```'?E`0`9````?^4!``,```"9Y0$`6P```)WE
M`0`$````^>4!`"<```#^Y0$`!````";F`0`'````*^8!``8````SY@$`!0``
M`#KF`0`$````0.8!`!,```!%Y@$`"````%GF`0`1````8N8!`!4```!TY@$`
M`@```(KF`0`'````C>8!``<```"5Y@$`#````)WF`0`.````JN8!``8```"Y
MY@$`%````,#F`0`,````U>8!``,```#BY@$`)P```.;F`0`$````#N<!``8`
M```3YP$`"````!KG`0`P````(^<!`$<```!4YP$`+@```)SG`0`O````R^<!
M`!L```#[YP$`+P```!?H`0`R````1^@!`"0```!ZZ`$`(0```)_H`0`C````
MP>@!`"@```#EZ`$`(P````[I`0`A````,ND!`"H```!4Z0$`*0```'_I`0`B
M````J>D!`#,```#,Z0$`'P````#J`0`P````(.H!`"T```!1Z@$`(@```'_J
M`0`F````HNH!`"4```#)Z@$`(````._J`0`I````$.L!`"D````ZZP$`)0``
M`&3K`0`O````BNL!`!P```"ZZP$`(0```-?K`0`E````^>L!`"D````?[`$`
M(````$GL`0`J````:NP!`#X```"5[`$`00```-3L`0`=````%NT!`"0````T
M[0$`0````%GM`0`E````FNT!`"D```#`[0$`*````.KM`0`I````$^X!`",`
M```][@$`(````&'N`0`J````@NX!`"4```"M[@$`.0```-/N`0`G````#>\!
M`#4````U[P$`#````&OO`0`,````>.\!`!0```"%[P$`+P```)KO`0`C````
MRN\!``L```#N[P$`%P```/KO`0`.````$O`!`!8````A\`$`"````#CP`0`'
M````0?`!`"(```!)\`$`)0```&SP`0`>````DO`!`"<```"Q\`$`)0```-GP
M`0`,````__`!`.L````,\0$`#P```/CQ`0`8````"/(!``P````A\@$`#P``
M`"[R`0`8````/O(!`!\```!7\@$`'P```'?R`0`&````E_(!`#4```">\@$`
M%@```-3R`0`4````Z_(!``<`````\P$`$P````CS`0`*````'/,!`#P````G
M\P$`"@```&3S`0`H````;_,!`!,```"8\P$`&````*SS`0`7````Q?,!`#@`
M``#=\P$`(````!;T`0`2````-_0!`"0```!*]`$`$P```&_T`0`4````@_0!
M`!4```"8]`$`"@```*[T`0`7````N?0!``D```#1]`$`'0```-OT`0`(````
M^?0!`!P````"]0$`)@```!_U`0`'````1O4!`",```!.]0$`!P```'+U`0`(
M````>O4!``D```"#]0$`-````(WU`0`&````PO4!`!````#)]0$`%0```-KU
M`0`4````\/4!``L````%]@$`#````!'V`0`'````'O8!``L````F]@$`'```
M`#+V`0`/````3_8!`!@```!?]@$`&0```'CV`0`+````DO8!``T```">]@$`
M%P```*SV`0`)````Q/8!`"L```#.]@$`#````/KV`0`/````!_<!``D````7
M]P$``@```"'W`0`1````)/<!`!@````V]P$`"P```$_W`0`#````6_<!``L`
M``!?]P$`"````&OW`0`'````=/<!``L```!\]P$`"P```(CW`0`.````E/<!
M`"T```"C]P$`&@```-'W`0`:````[/<!`"$````'^`$`"@```"GX`0`Z````
M-/@!``4```!O^`$`%@```'7X`0`W````C/@!``T```#$^`$`#@```-+X`0`&
M````X?@!``0```#H^`$`!@```.WX`0`+````]/@!`!<`````^0$`!P```!CY
M`0`(````(/D!``<````I^0$`"````#'Y`0`%````.OD!``\```!`^0$`$```
M`%#Y`0`^````8?D!`#$```"@^0$`)````-+Y`0`%````]_D!`!H```#]^0$`
M(0```!CZ`0`A````.OH!`",```!<^@$`$0```(#Z`0`"````DOH!``0```"5
M^@$`"@```)KZ`0`%````I?H!``4```"K^@$``P```+'Z`0`)````M?H!`$P`
M``"_^@$`)0````S[`0`8````,OL!`"T```!+^P$`)0```'G[`0!?````G_L!
M`!,```#_^P$`>0```!/\`0`<````C?P!`%,```"J_`$`(@```/[\`0`_````
M(?T!`#0```!A_0$`+````);]`0`V````P_T!`#8```#Z_0$`-0```#'^`0`S
M````9_X!`"@```";_@$`(@```,3^`0`F````Y_X!`$P````._P$`%````%O_
M`0`T````</\!``\```"E_P$`;P```+7_`0`)````)0`"`*(````O``(`>P``
M`-(``@!P````3@$"`"@```"_`0(`5````.@!`@`:````/0("`"D```!8`@(`
M%P```(("`@`*````F@("`!T```"E`@(`'0```,,"`@`T````X0("`",````6
M`P(`&````#H#`@!4````4P,"`!X```"H`P(`%P```,<#`@`*````WP,"``0`
M``#J`P(`!@```.\#`@`(````]@,"``4```#_`P(`%0````4$`@`3````&P0"
M`!D````O!`(`)0```$D$`@`0````;P0"``X```"`!`(`!````(\$`@`)````
ME`0"``\```">!`(`"````*X$`@`)````MP0"`!8```#!!`(`#0```-@$`@`,
M````Y@0"`!$```#S!`(`"P````4%`@`&````$04"`!,````8!0(`"P```"P%
M`@`6````.`4"``T```!/!0(`!P```%T%`@`/````904"``@```!U!0(`"0``
M`'X%`@`E````B`4"`!L```"N!0(`#````,H%`@`D````UP4"`!(```#\!0(`
M'@````\&`@`4````+@8"`!$```!#!@(`!0```%4&`@`%````6P8"`"$```!A
M!@(`"````(,&`@`"````C`8"``(```"/!@(`%@```)(&`@`(````J08"``@`
M``"R!@(`%````+L&`@`6````T`8"``@```#G!@(`+0```/`&`@`"````'@<"
M``0````A!P(`$````"8'`@`7````-P<"``\```!/!P(`!P```%\'`@`2````
M9P<"``4```!Z!P(`&P```(`'`@`%````G`<"`!8```"B!P(`$0```+D'`@`2
M````RP<"``(```#>!P(`"````.$'`@`/````Z@<"``L```#Z!P(`#0````8(
M`@`D````%`@"``L````Y"`(`#````$4(`@`3````4@@"``4```!F"`(``@``
M`&P(`@`+````;P@"``$```!_!```FP(```````!&`P``:0(``"\$```?!@``
M`````%,!``!3``````0```,!````````?`$``-@$``!]!```00<``$D%```V
M`P``)0,```X#``!W`P``,P0``*<!`````````````"T`````````````````
M``#/!````````+L```#-`0``!04``-4#```-`@``````````````````W08`
M`'D!``"M!@``N@$```````#J`0``I`0``%("```L`0``O@4``%\%````````
M-04``-$%``!]`0``7`0``",'````````]0$``&D%```6`P``M@,````````9
M!0``YP$``"X&``!J`@``C04```````!A`@``N04``(```````````````+\"
M```[`@``JP4``'0"```U`P``'04``)P!``"_!0``V0$``#X%``"Q`@``D04`
M``````#G!0``+`````````!C`P``%0```)L!``!Z`P``TP$``$T!``!,!@``
MXP```.T#``!F`0``QP(``,@"```Z!P``&0,`````````````1P4``$4&``"&
M`0``"P0``(T$````````"P```!<!```>`@```````'8&````````]`8`````
M``#,`@``-P<````````S`````````+0"``#S!0```````#8%``"8!0``:@$`
M`,X!````````$P<``%P```"Q`P``>P8```````!]````C08```````!9`0``
M30(``/L!```&````T@``````````````V````!$&````````[P``````````
M`````````$,"``"B!@```````.,#``!J!```)P4``!`%``"L!0``1```````
M``!)````8@(``-L%```[!P```````%@%``"I!0``%`(``($!````````````
M`!X&``"]`````````&$'``"<!@```````!T"``!(!0``T`8``#8````F!0``
M``$``+@!``"Q`0```````.0&``!3!P```````&0``````````````/0#``!5
M`P``Z@4````````%`0``P@(``$,&````````>@8``.@%````````3@(``#L$
M``#2`@``$0`````````]`0``>P0``&(#``".!@``````````````````````
M`&`%``#X!@``&`0``*L!``"&!0```````*D```"W`@``````````````````
M&`,``)<&``#?`P``^@0```````#D````\00``*\$``!<!0``^0(```<!```!
M!P``4`4```````!'`P```````.0%``"T!```@0````8$``"E!@``'P4`````
M````````V00``&4!``!0!```]0,``!$"```'!```Z`(```````!\!```S@4`
M`)T%````````\`$``&H%```(`0``:`4``*\#````````'P,``$<!``!C!@``
ME`,`````````````?`,``+T$``!6!```VP```/($````````M08```L'``#1
M!```:00``*`!``":!0``L@,``$H#``#R!0``7@8``'$````<!````````$@&
M``#/`0``X`$````````H`@``9@(``,0!````````Z0```-@"``":`P``````
M`!X%````````$`$``"L!``#K````UP4```````!1`P``U08``#$!```<!P``
M;`$``$4#```V`@``E``````````Q````FP8``+4$``!L!@``M`,```````"4
M!0``]04``$@$`````````````"P'``#U!@``.0<``$T````I!P``+04``"<!
M````````6@,```````#7!@``)@,```````#7!```0@````````#\`@``N00`
M`',&``!F!0``>P,```\$```2!@``%`,```````!M`P```````*$&````````
M`````-4"``"!!0``308``!L#```/`@```````'X$```(`@``;0$```````#^
M!0``.@,```````````````````````#B````CP$``!D!``">`````````/`$
M`````````````$D$```1`0``N`````D$``"(!0``````````````````/@``
M`"T&``!"!```P@0``````````````````$<$````````W`,``(8#````````
MY`(```````"X`@``)`,``'8!``"+`0```@(``'@$```_!0``#P,```````"6
M`@``_P8``#,&``!H`@``(`,``!0`````````KP(``+P$``"5````1`4``#T&
M``#6````%0$``-8$``#A!@````````````!!`P``\P,``-P"````````T@4`
M`-0%````````!@$``),``````````````/$%```$````!0,``#`````T!@``
M*08``#4&``!I`P``/`,``+<&``#-!```G@4``.$%```4!````````'<!``#+
M!@``&`<```````!E`@```````)P%````````"`<``)0$`````````````(X!
M``#L!0``*0```'L%``!C````F@(``,T#``!1````I`,```````"_!```;P8`
M`)\%```@`@```````-X$``""`P``!P(``,L%``"@!@``S0```%8&```>`P``
MD@(``#T$````````>@4``"H%``"S````=0```$X#``!``P``;@4````````*
M````[`,``````````````````"('````````F0$`````````````I`8``%<%
M``!%!P```````/(```"K`P``$@$````````C!```<P(```````#@!@``K@(`
M`$D!``!I!@``+0<``'P```"$`@``T0$``&`#`````````````$4```#T`@``
M`````.X!``!Q`P``*@```+0!````````_`$``.D"``"C!```OP$```````"J
M````/`<``,T&````````,@(```P'``"V!```:@```&<"```Y!0````````@#
M````````0@$``(0&````````&@$``"\%``"R!@``%0(``/4"````````QP``
M`&$&``"V!@``Q@```(@$```>!````````(4!``#Q!@``X````#,'``"'!@``
MXP(`````````````J`(``/T"``!?`@``*P4````````U!```/`0``%D"``"R
M!```F00``"H"``#F!@``2`,`````````````R`4`````````````N@4``%@&
M``"G`P`````````````-!0```````)@!``#L``````8``!H%````````?P4`
M`/P#``"6`P``.P8```````#Y!0```````/0`````````@`4```H'``!M!```
M@@8```````#F!``````````````W!@``@P4```````#N`@``N0$``)4$``#X
M`P``MP4``&X!``#^`````````)$&``"7!0```````&0&```A!@````````T`
M```@!```@`8````````A!P```````*@#```=`P``GP````````!.!```````
M`(P````A!```SP4``*<&``#6!@``C`(``````````````````"P%``#-!0``
M1@0``!L!`````````````%(!``"M`0``K@$``/L&``#V`0``K@8``$H````2
M!0``100```````!L`P``-@0``'X%```Z`0``/@(``&<!```H!@``6@(`````
M```/````R@4``#P```````````````````#+`0``S@````````#Z!0``DP8`
M`"`'``#G`P```````#(!`````````````*$#``#H`P``!0(```0#``"@!0``
M`````!4&``"S!````````/<$``"V`0```````$(#``";`P``9`,``,4"``"L
M`0`````````````;`@``,0<``!P%```W!0``3P```.0!``"A````&`4``"0$
M````````DP(```````"Q!@``5````,P$````````$P(``)$!``!1!0``1`0`
M`'(%``!+!0``$@0``+(%``!<!@``6P8``%\$```!!@``/`8``+`!``"$!```
MG0```&(```#R`@``\0,``&T`````````R`,``!8!```:`@``_P0``%8'````
M````+`,```````"X!@``SP,``(\"``!/!@``QP$``````````````````)<!
M````````F0,``'0&````````F`(``'D```#!`P``)P(``#(%```0!@``9`(`
M`/T%``#+!````````"P$``##`0``&`(``'D%``"7`P``:P````P$````````
M60```#T%``#9`````````%L!```-`0``<00`````````````"`8```````!H
M````B@```%0"````````O@(``*,&```3````FP4``&0!``#7`0``)`(``*L&
M``";!```!`8``````````````````&('``#"!0```````#`"```X!0``(P8`
M`(,!```!`P``2@$``*@%``#%````'````#4```#O!@``(P(```````"E`@``
M"0,``),!````````AP```!L$`````````````(\#````````+P```$8&````
M`````````%H'``"I!``````````````A`@``30<``+@#```K!```V@``````
M```>`0``G0,``!H$```\`0``#@8``%H$````````````````````````)04`
M`)D%````````U`0```````!9`P``(`4````````X`P```````%L'````````
MU````+\```"H````,P4```````"?`0``!P8``(8&``!!`````````!@!```_
M`@```````'@&```7!```/P<``+H$``"X!0``'0`````````J!```5P0`````
M``#0````!`$``(T```"D````C0(``(($`````````````*\&```Y!@``O@$`
M``4```!N`P``L@```"L"```6!```D00``%`"``#C!```YP(``-H"```Z````
M`@0``"D#``!3`P```````.0#``#>`@``^@$``/X"````````R00``!8"````
M````^@(``+<!``#1````=@4````````V!@``V`,``-,$``"Y````%`8``.D$
M``"!!`````````````"Y!@```````.8```!]!@```````&P```"``0``(@4`
M`,P!``#,!@```````!L&``!.!0```````+,&``!<!P```````$L```"I!@``
M*04``&X````S`@````````0%``!Q!@```````$H%``!9!@``&0```(0!``#5
M!0``.P,```$"````````'@```'("``!H`P``P`0``'($``#E!0``H0$`````
M``!,!```Y0```(P!```*`0```````"T"```_!```R04``.$$```2`@``$0,`
M```````Q`P```````+0`````````!@8````````.`0``(P````````!=`0``
MW0,```````````````````````"J`P``\P```)X$``"8````604```````!!
M`@```````)X#````````;P(``%8!``"A`@```````"X$``#'!````````+X$
M````````?P8``/@$````````[@0```````"V````K`(```,%```T!P``%@<`
M`,0$```C`P``-`,``!<```!.!@``*0(``-<"``#[`P``UP,``#4"``#E!```
MJ`8````````<!@``[@````````#*``````````````!5!```)@(``!<"``#=
M``````````````#?``````````````"O`0``4@````H"````````]@4`````
M``!&````C0$``'X&```Z!0````````````#;`0``(0,```````#6`P``````
M`$X'``"F`@``+00``,@$``#B`0``,`,``%0%``##`P``,@<``"0&````````
M:`0```````#O`0``6P(``#$%```6`````````'`&``!=!0``#`8``+H"``!/
M`P``RP,``$P#``!V````KP```!L```#J!@``908``.@!```5!```J0(`````
M``"2`0``4@4``-X#```T`0``I04``'(#```T!```W`````````"[!0``````
M````````````@P0``*H%```$!P``]`$``#<```"?`P``\P$`````````````
MC`4```````#\````E0$```````!F`P``!P<```````!O`P``A@0``)\$``!\
M`@``I0,````````K`P``*@<``'D#``"1`P``K@0``%$!``!``@```````-P!
M``#S`@``IP```$8%``"@!````````/@!``#M!@``1`(``!X'``#*!```;P$`
M`.<$``#C`0``_0`````````0`@``C@,``!,&``!8`0``(@(```````"%!0``
M9P0``.$"``"'!0``5P,``"8$``!<`0```````!T'``":!```G`,``((!``!0
M`0``+@4```````#(`0``0`4```H#````````*P```&X"``"C`P``>@(``)D&
M````````70(``,D````X````A@```!`'```P`0``?@,``/(&``!N!```PP(`
M````````````B@8```<```#I!@```````,P#````````N0(``!('``!K`@``
MT@8``*(!````````*00``!\```"%`@``C@```#,#```N!P``20,````````R
M!@```P```,`&````````V`$``%$$``#$!@```````(0%```_!@``T`4``/4`
M``````````````````")!```:@8``%(&``!I`0```````&`'````````HP4`
M`#4'````````\`````````#G!@``[P,``)<```"'`@```````%T`````````
M#@4``!0!`````````````*<"````````1P````````#)`@``0`8````````K
M!P```````/8#``!"!0``2P8``$<"``#=!0``300``-$"``".!````````/<%
M````````6`,``'T%```Q!````````&`$``#2`0``K@,``"@'``"*`P``````
M``````!L!````````/L```#7````"0<``/<&``!A`0``50<``"@%````````
MEP(``&4`````````Y0(``$4"````````&@,``.P"``!E`P``R0$``-T!``"\
M!0``D`0```````!X!0``2`(`````````````X0```)T$``!!`0``I`4`````
M````````2P(``/D&``!S`0``*0$``*P&``!/`0``/P,``(L"``!8!P``````
M`,4$````````]`4```````!+`P```````&`!`````````````/<#````````
MD@4``'0$``#K!@``,`<``(D```!K`P``Z04```````#4`0``>P```&@&````
M````A08``-L&````````@P(``%(#```"`````````.T$````````S@0``*X`
M```O!@```````!T&``"G!```PP```&$`````````4`8``)H!``!0`P``)0``
M`+`&``"'`P``/@<``$D&``"0`@``.`<````````-!P``&@```'`"``"D`@``
MBP0``+4%``!F````WP$``%8#``#O!```E`(``"`&```P!```;P```(P#```B
M!```H@4``!P#``!"!@``XP4```X`````````=@(`````````````"`4``%X`
M````````3@$``(@&``!,`````````"<``````````````'(!````!0``<0$`
M`/`"``"_`P``A`,`````````````P@8``)`#````````"````"<'``!8`@``
M7@$``'`!``!S!```2`$```````#1!@``.`0``%`'``!K!0```````%0'````
M`````````'X```#Q`0``V@,``%8```!>!P``)08````````)`@``WP4```$$
M``!E!```20<```P#``"^!@``Y08```0$``!1!P``:P0``)`!```.`@``````
M`/8"````````7P8```````!]`@``[P(```````!*!```YP```(4$``#Y````
M3P<``-\$``"=!@```````&X&``#J`P``^@8``-@%`````````````+T%````
M``````````````!=`P``7@0`````````````Q08``*8#````````!08`````
M````````I@8````````N`0``Q`,``/<!````````Q@$``+L#```#!P``````
M`$H'``"'!````````/`#``````````````````"O!0```````%X%``!P!```
MR0,``',```#``P``$````-X```!2!```4P(```````#/`@``R@,``.X&```%
M!P````````````!4`P``/0(``/X&```H!```E@8``"(`````````!@<``%4`
M```W!```W00``-L"``"M`@```````!(#``#M`@``&0<``&T"``#.!@``.`8`
M`+P#``!?`P```````%D'```L`@```````,P%``#*`@``XP8``"@````7!P``
M`````/\```![`@``"04````````V`0``HP(``+8"``!%`0``F0```*L"```<
M`@````````,"`````````````+`%``!T````BP```````````````````)P$
M``!7!@``U0$``*8```!``0``Y@4``#8'````````W0(`````````````````
M`%H```!4!@```````"<$``"M!0``C`0```````!_`@``I@0``+,%```Q!@``
M,`8``(H"``!6`@``B@4``',#``!0````T`,```,#``"`!```````````````
M````_@,```P```"5`@``3`<``)`%``"T!0```````(T#````````=P```.T!
M``!'!@``F`,``%8%````````````````````````C@(``,4%``#%`P``2P<`
M`-P&```1!0``:`$``*,````F!@``W@4``$\"`````````````,H&`````@``
M=0$```````!$!P``^0$``.T```#)!@``(P$```````#I`P``A0```%4!``!D
M!```L`(```\&```6!0``O`$````````T`@```@4``(0`````````P0$``(4#
M``#H!```EP0```````"4!@``E08``&4%``#V!```;`4``+,!```7!0``.00`
M``````#P!@``20(```````"P!``````````````+`0``>@$``-H$``!#!0``
M"P8``)8!``#?!@```````!0%``!#!P``+0,```\%````````9P```-`"````
M`````````'`%```+`@``G`(```````#3````:P8``&`&````````````````
M`````````````(,&`````````````,X#``!T`P``"@4``*`#````````TP4`
M`"(#``"<`````````)\"```\!0``N@,``.($```9`@``>`,```````#]`0``
M`````&(%``"H`0``P```````````````7P```*P$``!C!P``(0`````````"
M`0``#`(``+L$```6!@``Y@(```8"``#`!0``Q@,``'`````S`0``WP(``$T%
M`````````````)0!````````7`,``)($``!K`0````````````#P!0``````
M````````````.`(``'4"````````8`(``&H#``!"!P````````````"Z````
M"0```"$%````````?`4``)T!``#N`P```````/@````^`0``2````/4$``"C
M`0``6@$``+<#```=!``````````````F`0``T`0``(("```,`0``600``'L!
M```^!@``\0```-H!``!?`0``]@```+L"``#;`P````````````#A`0``.0(`
M`#H"```-!````````/P$````````,@,``$L!``#H!@``,@0````````;!P``
MJP0``'`#``!!!```B`$``%4%```F!P```````'D"``!U`P``MP```,@```":
M!@``@08``/D$```T!0``8P$``,0%``"I`0``0`0```````#J`@``804``&T&
M``"J!@```````&8&````````W@8``&8$````````E@4```8#```^!```)```
M``````"/!```CP4``"\#``#T!```3P0```````"M`````````'4&````````
M$P0````````?`@``````````````````$P$``$8'``#A`P``=P(```4$````
M````Q@(``*($``!:!0``-`````````"Z!@``&P4``)\&``!!!0``%0,``$L$
M``"U````SP````````"&`@``@@```,,&```)!@```````/D#``!Z````/@,`
M`,$```````````````````!O!```Q@4````````8!@``>08``,0```"#````
MO0,```<#``"D`0``L00``+<$```E`@``6P```-`!``!S!0``Y@,``'\`````
M`````````-0"``"``@``ZP,``$P%``##!```ZP4``)4%````````0@(``'@!
M`````````````"$!````````(````&(&```!`0``$@````````"@`@``)`$`
M`,8&``"M!```[@4``$4%``"\``````````````#J````L0````(&``"M`P``
ME@0``,<%``!_`P````````````"[`0``5P<``*@$````````$`0``!\$```5
M!0```````-L$``#_!0```````'$%```W`P``H04```````#B`@``*@,``'H$
M``#Z`P``+@````````#J!```508````````@`0``8P4``(\&````````Q@0`
M`%L%````````9`4``%T$```3`P``(@$``-(#``#H`````````.8!``!;!```
M)`<``&<%``"``P``E@```!D&``"+!0```````+$%``#4!@``_@0``'8$``#'
M!@```````)T"``":````C@4``$H&``"U`0````````````"E`0``(@8``$$&
M``#6`@``1@$``&<#``!1!@``_`8``$,```#B`P````````````"B`P``M@4`
M`)(&``!.`````````'<%``!4`0``B@$``*H!````````8P0``#H$```O!P``
M`````#$"``#_`P``0P,``/\"``!3!0``B@0``%$"```?!P``M`8``.P!```[
M`0``B04``+T&``"L`P``Y0,``'8#``!=!P``5P```/(!````````TP(```T#
M```D!0``.P4``.4!```L!@``8````.L!```W`@```````+P"``!_`0``V@8`
M`.(&``#<!0````````````````````````````"@`````````$P"````````
M.@8``/T$``"F!0``%0<``'0%``#S!```BP,```````"(`@``50(``)(#``#_
M`0``RP(```````!>`P``U00```@$``"0````%`<``(L&````````%P,``%@$
M``!]`P``>`(```X$````````[`0`````````````H@(``"\"````!P``*P8`
M`!`#``#R`P``?`8``$````"J!```9P8``*D#````````/0```!$'``#3`P``
M``````H$``#K!```V04````````9!```DP0``),%``"R`@``V@4``!<&``#W
M`@```````+L&`````````@<``$0#```'!0``O`8``+``````````#P$``&\%
M````````R@$`````````````^`4``$,!```J!@```````&,"``#``0``U0``
M`-8%````````P@$`````````````=`$``.`$`````````````.`"````````
M8@0``#T'```-!@``Y`0``&P"`````````````"T!```+`P``_08``",%``")
M`0``&@<``'D$````````0P0`````````````S0(``%T&``"S`P``/P```/L"
M``````````````````#>`0``1`8``,4!````````V`8``#`%``!8````4P8`
M`+`#````````F`8```````!?!P``D0(``$H"``#9`@``80,``&$$``"J`@``
MG@8`````````````"@8``/$"``#@!0``D@```%0$```+!0```````"@!``"U
M`P``O@,``+T!``"8!`````````````#!!0``.0$``*4```#@`P````,``(D&
M``#!!```+@(```D!``"(`P``SP8``($#````````:0```+T"``#!!@``1P<`
M`/@"```!!0``)P8``"H!````````'0$``(@```#9!@``L@$`````````````
M`````'4$`````````````%('``#"````Q`(`````````````C`8``/L%````
M````M0(``"\!````````G@$``-,&``">`@```````/P%``""!0````````P%
M``!W!````````$`'`````````````-$#````````OP8``)$````E!P``3P4`
M`.L"``"B````#@<``-P$``"G!0``D`8`````````````````````````````
M`````#4!````````+@,``"4$```/!P``N`0``#T#``#L!@``_0,```0"``"^
M````T@0```````#V!@````````````#M!0```````,X"```[````K````#(`
M``"#`P```````,$"``!U!0``K@4``#\!````````)@```'@`````````LP(`
M`-0#``!:!@``<0(```````!R````;04``$P!````````[P4``'X!```1!```
M`````%P"````````@0(``,`"```<`0``I00``$@'``#^`0``R`8``(<!``"9
M`@```````(\``````````````-D#```W`0``?@(``#@!``#6`0```````%<!
M````````JP```)4#``#'`P``<@8```8%````````/`(``$8"``#W````1`$`
M`!@```!7`@```````&(!``#+````Z0$``*8!```H`P``^P0``$T#``#Z````
MX@4```````")`@``$P4```````#"`P````````````";```````````````Y
M````&@8```,&``!3!````````),#````````7@(`````````````H00```(#
M```Y`P``'P$````````#!```=P8``"<#```E`0```````/,&````````S```
M`,,%``")`P``N0,``%L#````("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@
M)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T
M97)D87DI`"!A="``(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E<R(@:7,@
M;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D(&EN
M('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO="!F
M;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E
M<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@
M=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S960@;V8@)2XR9DU"(&%L
M;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D(&1A>7,@=6YT:6P@>6]U
M<B!P87-S=V]R9"!E>'!I<F5S+@`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I
M8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E
M<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@
M)7,`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@
M;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE
M+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@
M=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E
M<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`)7,Z(%1H:7,@;65S
M<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E
M=V%R92!O9B!F;VQL;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I
M9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N
M+@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@
M)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@
M1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P!!(&1A=&%B87-E(&)A8VME;F0@
M:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S
M(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC
M<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV
M871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S
M:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3
M+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C
M<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@
M4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I
M9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@
M=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D<P!!32!,:6=H="!286EN
M`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`05!)
M($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M
M:61D;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!
M8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT($EN9F]R
M;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U
M;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO
M;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`
M061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P97)M:7-S
M:6]N('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE
M=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL
M;&$@4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D
M<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@
M8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I
M;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G
M(&EN(&YO=RX`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D
M9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O
M=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB
M86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!
M=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS
M`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO
M=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T
M<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R
M9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D
M<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;65R
M:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N
M('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N9&]R<F$`06YG;VQA`$%N
M9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC80!!;G1I
M9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`
M07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!
M<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`07)C:&EV92!&:6QE(%-I
M>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO
M=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y
M;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U8BUG<F]U<',_`$%R
M9V5N=&EN80!!<FUE;FEA`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S
M8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T
M:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!='1E
M;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T
M;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T
M;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`
M075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S
M(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!2
M97%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!2
M97%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@
M=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U
M:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q
M=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D
M9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T
M;W)Y`$%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$
M05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@
M861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!
M=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z
M(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN
M`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D
M+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D
M+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R
M+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N
M=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@
M9FEE;&1S.@!!>F5R8F%I:F%N`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A
M8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R
M8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86YG;&%D97-H`$)A
M<F)A9&]S`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD
M+@!"87-E;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU
M9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@
M(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L
M9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`
M0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`
M0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C
M96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL
M971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),($1I
M<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#86-H92!I
M;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#86QM`$-A;6)O9&EA
M`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL
M>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B!N;W0@=W)I=&4@
M=&\@9FEL92`B)7,B`$-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO
M;B!H86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`
M0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#86YC96P`0V%N8V5L(%!R
M;V)L96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@
M9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I
M=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D
M:7)E8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI
M<W0N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE
M9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#
M86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E
M(%9E<F1E`$-A<'1I;VX`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)
M<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN
M9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E
M;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5R=&EF:6-A=&4@1&5T
M86EL<P!#97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#
M:&%D`$-H86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE(&YA
M;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D
M(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S
M=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG
M=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H
M96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA`$-H;V]S92!!<'!L:6-A=&EO;CH`
M0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO
M=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T>7!E("AF
M;W(@;W)D97)E9"!L:7-T<RD`0VAR:7-T;6%S($ES;&%N9`!#;&%S<R!D969I
M;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@35-/9F9I8V4@
M=&%G<P!#;&5A<B!1=65R>0!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E
M<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#;&EC:R!T;R!#;VYT
M:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`
M0VQO=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#
M;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O
M;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M
M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT
M`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP=71E<G,`0V]N9&ET
M:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF
M:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@
M86YD($]U=&QO;VLN`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O
M;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@
M1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N
M`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE
M('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N
M('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T<P!#;VYT86-T<R!W97)E
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N
M=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@`$-O;G1E;G1S(&]F("(E
M<R(`0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O<'D@9F%I
M;&5D.B`E<P!#;W!Y('-E;&5C=&EO;@!#;W-T82!2:6-A`$-O=&4@9"=)=F]I
M<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z(`!#;W5L9"!N;W0@
M4$=0('-I9VX@;65S<V%G93H@`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M
M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@
M;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E
M<G9E<BX`0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(`0V]U;&0@;F]T
M(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@
M<V5R=F5R`$-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B`B)7,B('5S:6YG
M($944#H@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z(`!#;W5L9"!N;W0@9&5C
M<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E
M<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L
M9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD
M(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S
M+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L
M9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD
M(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@
M;&ES=',N`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y("(E<R(N`$-O=6QD(&YO
M="!M:V1I<B`B)7,B+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O
M;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B)7,B(&9O<B!W<FET
M:6YG+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E
M;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y
M("(E<R(N`$-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD
M(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O
M<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A
M:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U
M;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S
M<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N
M("5S`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`
M0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<FUD
M:7(@(B5S(BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U
M;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@
M<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO="!S879E
M('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#;W5L9"!N;W0@<V%V
M92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T
M('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H
M97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A
M8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E
M<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO
M="!U;FQI;FL@(B5S(BX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#
M;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N
M;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@(B5S(CH@)7,`0V]U;&1N)W0@
M9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B
M87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R("(E<R(@=&AE(&9O;&QO
M=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@(B5S(CH@)7,`0V]U;G1E9"!T
M97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A
M=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI
M<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N
M="`T(%!H87-E<P!#=7)R96YT(%-E<W-I;VYS`$-U<G)E;G0@5&EM90!#=7)R
M96YT(%523"!I<P!#=7)R96YT(%5S97)S`$-U<G)E;G0@5V5A=&AE<@!#=7)R
M96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS
M('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#
M>7!R=7,`0WIE8V@@4F5P=6)L:6,`1$0`1%-.("AS964@:'1T<#HO+W!E87(N
M<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD
M<VXN<&AP*0!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&%B87-E($QO;VMU
M<`!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE
M=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!)
M;F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`
M1&5F875L="!3:&5L;`!$969I;FET:6]N<P!$96QE=&4`1&5L971E($-E;&P`
M1&5L971E($=R;W5P`$1E;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`1&5L
M971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L
M=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E
M('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@
M(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE
M=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT(&-O;'5M
M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T960@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@(B5S(BX`1&5L:79E<GD@=&EM90!$96YM87)K`$1E<V-R:6)E
M('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R
M9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T
M:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0
M;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE
M9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y
M`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L
M87D@9&5T86EL960@9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$
M:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II8F]U
M=&D`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT
M96YA;F-E+G!H<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE
M;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O
M;6EN:6-A;B!297!U8FQI8P!$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@
M=7`N`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C
M;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R
M=6=S`$4M36%I;`!%4E(`16-U861O<@!%9&ET`$5D:70@0FQO8VL`161I="!'
M<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E
M<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI
M<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A
M=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M
M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL
M('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'871E=V%Y`$5M;W1I
M8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C
M:"!T97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O
M($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X
M="!M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R
M:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N
M965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE
M(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E
M`$5N=&5R('1H92!L971T97)S(&)E;&]W.@!%<75A=&]R:6%L($=U:6YE80!%
M<FET<F5A`$5R<F]R`$5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%<G)O<B!D
M96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!L
M;V<Z("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@=7!D871I
M;F<@<&%S<W=O<F0Z("5S`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`17)R
M;W(@=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O
M<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@
M<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L
M9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%
M>'!A;F0`17AP86YD(%-I9&5B87(`17AP96-T960@)RDG`$5X<&5C=&5D(&)A
M<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E
M`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D
M(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O
M($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R
M+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O
M("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`
M1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E
M<P!&86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA
M;F1S`$9A=&%L($5R<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`1F5E;',@3&EK
M90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&
M:65L9"!M871R:7@`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL
M92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE
M('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O
M<G1E9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E
M<@!&:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T
M(&5X:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG
M="!S=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES
M("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T
M:"!D87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E
M<W5L="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&
M;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R
M`$9O<G5M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T
M<F]P;VQI=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N
M8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``1G5L;"!$
M97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$=A8F]N`$=A;&QE<GD@
M=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E
M<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N
M>0!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!';P!';V5D96P`1V]O9VQE
M($UA<',`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E96-E`$=R965N;&%N
M9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU
M<W0@8F4@;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O
M=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R;W5P7VQD87`Z(%5N
M86)L92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U861E;&]U<&4`1W5A
M;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B
M;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@
M<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S
M97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H
M96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA
M>F4`2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)
M<VQA;F1S`$AE879Y(%0M4W1O<FT`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E
M9&ET;W(`2&5L<&5R`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG
M(&]F('1H92!F:6QE.@!(:6=H`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I
M='D@4W1A=&4I`$AO;64`2&]M92!!9&1R97-S`$AO;64@1&ER96-T;W)Y`$AO
M;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B
M.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@
M)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J
M96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N
M9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M
M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG
M:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J
M96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z
M("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F
M;W(@=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O
M('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W
M;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I
M;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@
M<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M
M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO
M=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y
M`$AU;6ED:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R
M96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE
M9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`
M25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E
M<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N
M('9I;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA;F0`26-O;G,@
M3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@
M;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O
M(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N
M>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D
M('1O(&-H96-K('1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N
M8WDN`$EF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE
M(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92!D:7-P;&%Y960@
M8GD@>6]U<B!B<F]W<V5R+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA
M9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y
M.@!);6%G92!U<&QO860`26UA9V5S`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E
M9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T(%)O=R!!9G1E
M<@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A
M;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A
M<V4@26YD96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE<VEA`$EN
M9F\`26YF;W)M871I;VX`26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L
M92X`26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!4
M86)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN
M<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R
M="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@
M82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@
M<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H
M(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E
M9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA
M=&4`26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R
M96-E:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN
M<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C
M;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R86=R87!H
M(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R;W<@869T
M97(`26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R97%U:7)E9"!A;G-W
M97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D:69Y($EM
M86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E9&ET('1O
M('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@
M8W)E9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED(%5$2"X@*%5S
M97(@1&%T82!(96%D97(I+@!);G9A;&ED(%I)4"!D871A`$EN=F%L:60@87!P
M;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M
M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F
M:6QE(&9O<FUA=`!);G9A;&ED(&QI8V5N<V4@:V5Y+@!);G9A;&ED(&QO8V%T
M:6]N('!R;W9I9&5D+@!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI
M<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`
M26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P87)T;F5R(&ED
M+@!);G9A;&ED('!R;V1U8W0@8V]D92X`26YV86QI9"!P<F]T;V-O;"X`26YV
M86QI9"!R96-I<&EE;G0Z("(E<R(`26YV86QI9"!S:&%R92!O8FIE8W0`26YV
M86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN
M=F5N=&]R>0!);G9E<G0@<V5L96-T:6]N`$ER86XL($ES;&%M:6,@4F5P=6)L
M:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O
M<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R
M>0!*87!A;@!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I
M9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2
M:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S
M('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I
M97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME
M>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U
M8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T
M:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MU
M=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S
M($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@4&%S<W=O<F0@
M0VAA;F=E`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ
M("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`
M3&%T=FEA`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,
M96)A;F]N`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,
M979E;`!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS
M=&5I;@!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L
M>0!,:6=H="!286EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I
M;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,
M:6UE<FEC:P!,:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A
M9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI
M;FMS`$QI;G5X($-O;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD
M97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE
M<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,
M:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T
M:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!F86EL960Z
M("5S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U<F4`3&ET
M:'5A;FEA`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM
M90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO
M;@!,;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A
M=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC
M;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO
M=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R
M;VUA;B!N=6UB97)S`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C
M:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L
M(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-
M86=I8P!-86EL`$UA:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L
M87ES:6$`36%L9&EV97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@
M8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@
M8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R
M-"!M87``36%P475E<W0@;6%P`$UA<'!I;F=S('-T;W)E9"X`36%R8V@`36%R
M9VEN`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H
M97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)
M<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`
M36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I="X`36%X(&UE<W-A9V4@<&%R
M=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M
M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO
M8VMS`$UA>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E
M<G,`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R
M:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A
M=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE
M<W-A9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A=F%I
M;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V
M92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R1$(@
M:7,@;F]T(&-O;FYE8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B(&ES(&YO="!D
M969I;F5D`$UE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,`
M365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F
M`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI
M;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI;FEM=6T@<&%S<W=O<F0@86=E(&AA
M<R!N;W0@>65T(&5X<&ER960`36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN
M9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R
M871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N
M="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$
M+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG
M('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D
M($1A=&4`36]D:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F
M`$UO;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S
M97)R870`36]O;B!0:&%S97,`36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E
M9"!T:&%N('1H92!E>'!E8W1E9"`E9"X`36]R;V-C;P!-;W-T;'D@0VQE87(`
M36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`36]V92!$;W=N`$UO=F4@3&5F
M=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``36]Z86UB
M:7%U90!-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EP;&4@<V5L
M96-T:6]N`$UY($%C8V]U;G0`37D@06-C;W5N="!);F9O<FUA=&EO;@!->2!0
M;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!
M9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T
M:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@
M0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S
M8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S
M8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M
M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`
M3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($UE<W-A9V4@=&\@)7,`
M3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`
M3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"X`
M3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"X`3F5W('=I;F1O=R`H7V)L86YK
M*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S`$YE>'0@;W!T
M:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E
M`$YO`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D
M:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K
M:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E
M>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N
M86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N
M9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I
M;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F
M="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D960`
M3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C871I
M;VX@<')O=FED960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E
M8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R
M='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-7
M1"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--
M0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA
M<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@
M=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S
M+@!.;R!Q=6]T82!S970N`$YO(')U;&5S`$YO('-E<&%R871O<B!S<&5C:69I
M960N`$YO('-I9&5S`$YO('-U8V@@9FEL90!.;R!T96UP;W)A<GD@9&ER96-T
M;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P
M87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V
M86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T
M:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U
M;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R
M871I;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)F;VQK($ES;&%N
M9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD
M<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y
M`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E
M<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R
M`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E
M<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@
M:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O
M<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@86YD
M(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P87-S=V]R
M9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`3VYL>2!)34%0
M('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O9F9E;G-I
M=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/
M;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA
M;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R
M90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N
M;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/<&5N
M<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`
M3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T
M:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A
M<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z
M`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!
M32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!014%2.CI-86EL
M(&)A8VME;F0`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@
M1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A
M`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-(%-H;W=E<G,`
M4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!/
M4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!?2%`@4VAE;&P`4&%D9&EN9P!0
M86MI<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D
M`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G1L>2!#;&]U
M9'D`4&%S<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN`%!A
M<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553
M(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!0
M87-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S
M=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z
M`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E
M<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D96QE=&5D+@!097)M:7-S
M:6]N($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A
M=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!E=',`4&AI;&EP<&EN
M97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&5A<V4@8VQI8VL@
M:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO
M=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A
M(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H
M92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E
M<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB
M97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED
M('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE
M;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`
M4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E
M92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y
M<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L
M;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO
M;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E
M;F9O<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO
M=7(H<RDZ(`!0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z
M(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S
M<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0
M<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R
M979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I
M;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE
M;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U
M8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O
M`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S
M9G5L;'DN`%!U97)T;R!2:6-O`%%A=&%R`%%U97)Y`%%U;W1A`%)302!0=6)L
M:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R
M;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T
M;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E
M<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@
M5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S('EO=7(@
M;&%S="!A8W1I;VX`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@365N=2!%;&5M
M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I;VYS:&EP
M($)R;W=S97(`4F5L;V%D`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E
M(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!2
M96UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!2
M96UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@
M=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N
M;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R
M.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E
M<G)O<F-O9&4Z(`!297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U
M;F0N`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U
M<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@5D93(&-O
M;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!C
M;VYF:6=U<F%T:6]N+@!297%U:7)E9"!&:65L9`!297-E=`!297-E="!087-S
M=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W1O<F4@3&%S="!1=65R>0!2
M97-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E='EP92!N97<@<&%S<W=O<F0`
M4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R
M($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L
M=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X
M,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W
M('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)
M344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-
M97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`
M4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U%,('-T871E;65N="!F;W(@=F%L
M=64@;&]O:W5P<P!34T@`4U5#0T534P!37U%,(%-H96QL`%-A`%-A:6YT($AE
M;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@
M4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E
M;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!3
M86\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I
M($%R86)I80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@3W!T:6]N<P!3
M879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T
M;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S
M(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O
M.B`B)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`4V5A
M<F-H($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T
M(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S
M97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;`!396QE8W0@
M86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@
M;F]N90!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@
M8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M
M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E
M<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET
M>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET
M97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI
M;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y
M;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!3
M96YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD
M($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V97(@9&%T82!W<F]N9R!O
M<B!N;W0@879A:6QA8FQE+@!397-S:6]N($%D;6EN`%-E<W-I;VX@240@97AP
M:7)E9"X`4V5S<VEO;G,`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T
M;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`
M4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S
M(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G
M92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U
M<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L
M(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A
M9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB
M;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN9P!3
M:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O
M<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C
M=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG
M=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN
M/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H
M;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N
M=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S
M(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W
M('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA
M9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W
M97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET
M>0!3:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I
M(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I
M9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K
M:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H
M;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO
M=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T
M97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O
M<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC
M80!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD
M<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J86-E;G0@
M8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L
M;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P86EN`%-P
M86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C
M;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A
M<B!4<F5K`%-T87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T
M;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1R
M:6YG(&QI<W0`4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`4W1Y;&4@
M6T-34UT`4W4`4W5B9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!3=6)J96-T
M`%-U8FUI=`!3=6)M:71T960@<F5Q=65S="!T;R!A9&0@(B5S(B!T;R!T:&4@
M<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R(')E<75E<W0@
M:&%S(&)E96X@87!P<F]V960N`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F
M=6QL>2!A9&1E9"`B)7,B('1O('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!C
M;&5A<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U
M8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL>2!R96UO=F5D
M("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@<F5V97)T960@
M8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S
M9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL
M>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C
M8V5S<V9U;&QY('5P9&%T960@(B5S(@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`
M4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`
M4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E
M<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD
M($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y;F,@
M;&]G(&1E;&5T960`4WEN8TU,`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R
M;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M(&%N9"!7
M:6YD>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L>0!44U8@9FEL90!486)L90!4
M86)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A
M;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI
M=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E
M<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R
M93H@`%1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`
M5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N`%1E;7!L871E($%D;6EN:7-T<F%T
M:6]N`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I
M;&%N9`!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@
M2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O
M<G0@(B5S(@!4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D
M+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S
M<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG
M+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M
M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@
M4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C;VYT86-T
M($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W
M87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@=V%S
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`5&AE
M(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO;B!L
M:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O
M<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E871U
M<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!F:6QE
M("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@)7,@
M<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@8V%N
M;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D
M(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T
M:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL('-C<F5E;B!M
M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@
M17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T
M(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A
M<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O
M<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@
M5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A
M("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O
M="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@
M:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET
M;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L
M969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@
M8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S
M+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B
M)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@
M=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N
M`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@
M<&%G90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H
M92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R
M>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@
M;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA
M>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W
M('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES
M=&5M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C
M:&%R86-T97(N`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R
M:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE
M('-I;F=L92!C:&%R86-T97(N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D
M96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S
M:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P
M96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP;W)A<GD@9FEL
M92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!Y;W4@96YT97)E9"!D
M:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN`%1H92!T;W`@
M86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U
M<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P
M+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W
M96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5M97,@9&ER
M96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A
M=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P
M;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I
M;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[
M('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O
M8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W87,@
M82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H
M92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG("(E<R(@
M9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN
M9R`B)7,B.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H
M86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W
M87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O
M<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A
M<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S
M('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@
M97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F
M=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N
M`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O
M;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R
M(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@
M>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A
M<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L
M;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E
M<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@
M*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F
M;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@
M270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET
M86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER
M960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO
M;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`
M5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D
M(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@
M;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@
M:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N
M`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I
M<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I
M97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@
M=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@
M1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E('9I<VET
M("5S`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S
M970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T
M(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S
M<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L
M>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4
M:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN
M9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F
M;W)M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@
M*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@
M9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H
M:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4
M;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R
M86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`
M5'4`5'5N:7-I80!4=7)K97D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC
M;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD
M97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@
M<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S<R!6
M1E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M
M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R
M;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@
M=&\@)7,N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S(BX`56YA
M8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,O)7,B+@!5;F%B;&4@=&\@
M8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H
M(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A
M=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D
M:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T
M;R!C<F5A=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@8W)E871E(&5M
M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B
M;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M+@!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L971E
M("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T
M;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F
M;VQD97(@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ
M("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L92!T
M;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!6
M1E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE
M('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N
M`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN
M`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE
M9"DN`%5N86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B;&4@=&\@<F5A9"!T:&4@
M=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z
M(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@
M<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I
M<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L
M92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W
M<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@
M*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T
M82X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X
M8V5E9&5D+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA
M<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@
M8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@
M=&\Z(`!5;F9I;&5D`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG
M9&]M`%5N:71E9"!3=&%T97,`56YI=',`56YK;F]W;@!5;FMN;W=N(&%P:6US
M9VED("A!4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N
M="!-97-S86=E($E$*2X`56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"X`56YK
M;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT
M(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@
M86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C
M=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N
M;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL
M;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O
M;&]R`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P
M9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!G<F%D92!S8W)I<'0@9&5L971E
M9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE
M<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O
M;6%N(&YU;6)E<G,`57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5
M<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R
M=F5R+@!5<V5R`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5
M<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A
M=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M=&AI<R!S:71E+@!5<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N86UE`%5S
M97)N86UE("(E<R(@86QR96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M
M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C
M=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS
M(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R
M;VT@;F]W+@!686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E
M<RX`5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A<FEA
M8FQE`%9E;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S
M86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S
M:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!6
M97)T:6-A;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I97<@)7,`5FEE=R!A;B!E
M>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"
M<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I
M;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%23DE.1R$A
M(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=)3B!V:6$@2%14
M4`!786QL:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A
M<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!7
M96(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L
M("5S`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S
M(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C
M:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAE<F5I
M<R!!=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O
M(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H
M(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F
M="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE
M('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY
M`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7:7-H
M;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%=R;VYG(&YU;6)E
M<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D
M+@!7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@
M)60N`%=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N
M`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@17AT96YD
M960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64`
M6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X=&5N<VEO
M;G,`65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE;@!997,`665S+"!)
M($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U
M='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO="!A
M;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+@!9;W4@87)E
M(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N;F]T(&AA=F4@=&AE("=<)R!C
M:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@;F]T(&5N=&5R
M(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@86YY(&9I
M96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD
M:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9
M;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I
M9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N
M871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C
M:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93
M(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R
M92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E
M;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU
M<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S
M<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C
M:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H
M92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N
M86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T
M;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N
M`%EO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(`
M66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A
M:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO
M=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N
M9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4
M;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN
M+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@
M;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R!U<V4@
M2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U
M<V4@82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C:V5N9"X`66]U<B!A
M=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN
M9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R
M('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H
M879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E
M<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G
M:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P
M<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@=&\@<')I
M;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N
M=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ
M`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+@!9;W5R
M(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO
M;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W
M;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S
M970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W
M('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+@!9;W5R(')E
M;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W
M90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P;W)T70!;
M4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN
M97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T-,20!?1&%T
M851R964`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R
M=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?3W!T
M:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]3971U<`!?5&%B
M;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`&%D9')E<W-E
M92!U;FMN;W=N`&-A;&5N9&%R`&-A;&T`8V%N;F]T(&-R96%T92!O=71P=70@
M9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H97)E`&-O;6UA;F0@;&EN
M92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R`&-R:71I8V%L('-Y
M<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M870@97)R;W(`96YT<GD@;F]T
M(&9O=6YD`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S
M`&=U<W1I;F<`:#H`:&@`:&]S="!N86UE('5N:VYO=VX`:6UM961I871E`&EN
M;&EN90!I;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A<F4@97)R
M;W(`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@
M25-/+@!M;0!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N
M=&5D`&YO=&5P860`<&5R8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`
M<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L`')I<VEN9P!S97)V:6-E('5N879A
M:6QA8FQE`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-S
M`'-T96%D>0!S>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL
M=7)E`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE
M9`!U;FYA;65D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R
M;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXQ"E)E<&]R="U-<V=I9"U"=6=S
M+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R
M,#`V+3`Q+3`V(#$T.C$P*S`Q,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP
M,2TS,"`R,3HR-BLP,C`P"DQA<W0M5')A;G-L871O<CH@279A;B!.;W)I<R`\
M=FEX0'9A>FMA+G-K/@I,86YG=6%G92U496%M.B!3;&]V86L@/'9I>$!V87IK
M82YS:SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L
M86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3(*0V]N=&5N="U4<F%N<V9E<BU%;F-O
M9&EN9SH@."UB:70*`"`H<')E9"`E<R!D\F%M:2D`("A+;.%V97-O=N$@<VMR
M871K82`E<RD`("AO("5S(&1N[2D`*&1N97,I`"`H>F%J=')A*0`@*';H97)A
M*0`@<OUC:&QO<[L@`"(E<R(@;FEE(&IE(&%D<F5SX7(N`"(E<R(@;FEE(&IE
M('!L871NX2!V;[5B82X`(B5S(B!N:64@:F4@;F%K;VYF:6=U<F]V86[I('8@
M<F5G:7-T<FD@2&]R9&4N`'IO8G)A>F]V8>@@<W1R;VUU("(E<R(@;F5B;VP@
M;N%J9&5N_2X`4VMU<&EN82`B)7,B(&)O;&$@<')I9&%NX2!D;R!S>7-TZ6UU
M+@!0<N%V;R`B)7,B(&)O;&\@<')I9&%NZ2!D;R!S>7-TZ6UU+@`B)7,B(&YE
M8F]L;R!M;[YNZ2!V>71V;W)INSH@)7,N`%!O=;YI=/UC:"`E+C)F34(@>B!D
M;W9O;&5N_6-H("4N,F9-0B`H)2XR9B4E*0`E9"`E<R!A("5S`"5D(&1N[2!D
M;R!V>7!RN6%N:6$@<&QA=&YO<W1I(%;AN6AO(&AE<VQA+@!P<F5D<&]V9>\@
M;F$@)60@9&[M`"5S("T@4&]Z;N%M:V$`3V1T;&'H;VL@)7,`)7,@2T(`3W!E
M<N%C:64@^F1ROF)Y('!R92!A<&QI:^%C:74@)7,@+2!0;W1V<F1E;FEE`$YA
M<W1A=F5N:64@)7,`4F5G:7-T<F]V86YI92!D;R!A<&QI:^%C:64@)7,`4&]D
M;6EE;FMY('!O=;YI=&EA("5S`"5S('6^(&5X:7-T=6IE+@`E<R!V;R!V_;EK
M92`E<R`E<P!!<&QI:^%C:6$@)7,@:F4@<')I<')A=F5NX2!N82!V>6MO;F%N
M:64@;W!E<N%C:>T@^F1ROF)Y+D]Z;F'H=&4@N71V;W+H96L@<')I(&]P97+A
M8VGA8V@L(&MT;W+I(&-H8V5T92!V>6MO;F&[('1E<F%Z+@!0;[YA9'5J92!S
M82`E<P`E<R!M:6[Z=``E<R!N96)O;"!NX6ID96[]+@`E<R!AOB`E<R!Z("5S
M`$%D<F5SX7(@<&]UONUV871EM6$@)7,`2V%L96YDX7(@<&]UONUV871EM6$@
M)7,`4&]Z;N%M:WD@<&]UONUV871EM6$@)7,`6F]Z;F%M(/IL;V@@<&]UONUV
M871EM6$@)7,`)7,Z("5S`"5S.B!4X71O('-P<N%V82!N96UU<^T@8GF[(&]D
M(&]D;W-I96QA=&6U82P@:W1O<OT@<V$@>F]B<F%Z=6IE(&%K;R!O9&]S:65L
M871EM2!S<'+A=GDN(%IA8VAO=F%J=&4@;W!A=')N;W.[('!R:2!K;&EK86[M
M(&YA(&QI;FMY('8@<W!RX79E(&%L96)O('!O<VMY=&]V86[M(&]S;V)N_6-H
M(&EN9F]R;>%C:>T@;V1O<VEE;&%T9;5O=FDN`"P@;N%R87IO=OT@`"P@=B!N
MX7)A>F]C:"`E<R`E<P`L('!R96UE;F[A('8@<F]Z<V%H=2`E<R!AOB`E<P`M
M+2!V>6)E<G1E('-I("TM`#$R+6AO9&EN;W;](&9O<FWA=``R-"UH;V1I;F]V
M_2!F;W)MX70`,C0@:&]D[6X`/%!R961C:.%D>F%J^F-A`%!R92!T96YT;R!B
M;&]K(&IE('!OOF%D;W9A;OT@9&%T86+A>F]V_2!B86-K96YD+@!6>7-K>71L
M82!S82!ZX79AOF[A(&-H>6)A`$YA('IAN6EF<F]V86YI92!S<'+A=GD@:F4@
M<&^^861O=F%N_2!V97)E:F[](%!(4"!KM?KH+@!.82!O=F5R96YI92!P;V1P
M[7-A;F5J('-P<N%V>2!J92!P;[YA9&]V86[]('9E<F5J;OT@4$=0(&NU^N@N
M`$YA(&1EN6EF<F]V86YI92!S<'+A=GD@<_H@<&]T<F5B;NDZ('9E<F5J;OT@
M4$=0(&NU^N@L('!R:7;A=&YY(%!'4"!KM?KH(&$@:&5S;&\N`$YA('!O9'#M
M<V%N:64@<W!RX79Y('/Z('!OOF%D;W9A;NDZ('9R96IN_2!01U`@:[7ZZ"P@
M<')I=N%T;GD@4$=0(&NU^N@@82!H97-L;RX`3F$@9&6Y:69R;W9A;FEE('-P
M<N%V>2!S^B!P;[YA9&]V86[I.B!V97)E:F[](%,O34E-12!KM?KH+"!P<FEV
MX71N>2!3+TU)344@:[7ZZ"!A(&AE<VQO+@!.82!P;V1P[7-A;FEE('-P<N%V
M>2!S^B!P;[YA9&]V86[I.B!V97)E:F[](%,O34E-12!KM?KH+"!P<FEVX71N
M>2!3+TU)344@:[7ZZ"!A(&AE<VQO+@!.82!Z8;EI9G)O=F%N:64@<W!RX79Y
M(&IE('!OOF%D;W9A;OT@=F5R96IN_2!334E-12!KM?KH+@!0<F5D<&]L=61N
M[6T@;V)L8>AN;P!0<F5D<&]L=61N[6T@M6%H:_T@9.&^[P!0<F5D<&]L=61N
M[6T@9.&^[P!0<F5D<&]L=61N[6T@<')E:.%N:WD`4')E9'!O;'5D;NUM('-N
M96AO=ND@<')E:.%N:WD`,3(@:&]D[6X`05!)($E$`$\@=&]M=&\@961I=&]R
M90!/+BXN`$%B<V]L^G1N>2!S<&]D;VL`06)S;VSZ=&YY('-T<F5D`%!R:2!V
M>71VX7)A;NT@5D93(&%D<F5SX7)A(&)O;"!Z86UI971N=73]('!R[7-T=7`N
M`%!R:2!V>71VX7)A;NT@5D93('/Z8F]R=2!B;VP@>F%M:65T;G5T_2!P<NUS
M='5P+@!);F9O<FWA8VEE(&\@^NAT90!(97-L;R!P<F4@^NAE=`#:Z&5T('IA
M8FQO:V]V86[]+@#:Z'1O=F%N:64`4')I9&&[`%!R:61ANR!P;V1R:6%D96[Z
M('-K=7!I;G4`4')I9&&[('!O9')I861E;ND@<'+A=F\`4')I9&&[.@!0<FED
M8;L@<VMU<&EN=0!0<FED8;L@;F]VZ2!P<N%V;P!0<FED8;L@9&/I<G-K=2!S
M:W5P:6YU(&1O("(E<R(`4')I9&&[(&1CZ7)S:V4@<'+A=F\@9&\@(B5S(@!0
M<FED8;L@<&]UONUV871EM6$Z`%!R:61ANR!S=.5P96,`4')I9&&[(.AL96YO
M=@!0<FED8;L@<.%R`%!R:61ANR!M96YU("5S(&%K;R!";^AN_2!P86YE;"!-
M;WII;&QY`%!R:61ANR!D;R!A9')E<^%R83H`4')I9&&[(&1O(&WT:FAO(&%D
M<F5SX7)A`%!R:61ANR!P;W6^[79A=&6U80`B)7,B(&)O;"!P<FED86[](&1O
M('-Y<W3I;74L(&%L92!N96UOOFYO('!R:61ANR#O86RY:64@<')I:&QA<V]V
M86-I92!I;F9O<FWA8VEE.B`E<RX`(B5S(B!B;VP@<')I9&%N_2!D;R!S>7-T
MZ6UU+B!497)A>B!S82!M]+YE=&4@<')I:&SA<VF[+@!0<FEDX79A;FEE('!O
M=;[M=F%T9;5O=B!J92!Z86OA>F%NZ2X`061R97-A`$%D<F5SX7(`061M:6YI
M<W1RX6-I82`M(&YA<W1A=F5N:64@<'+A=B!P<F4@:6[]8V@@<&]UONUV871E
MM6]V`$%D;6EN:7-T<N%C:6$`4F5K;&%M>0!!9F=A;FES=&%N`$%L8N%N<VMO
M`$%LONUR<VMO`$%L:6%S`%IA<F]V;F&[`%IA<F]V;F%N:64Z`%:Y971K>0!6
MN65T8VD@875T96YT:69I:V]V86[M('!O=;[M=F%T96QI80!6N65T:WD@<VMU
M<&EN>0!6N65T:WD@<'+A=F$`5KEE=&MY(+ET>7)I('-T<F%N>0!0;W9O;&F[
M('9I86-E<ND@861R97-Y`%!O=F]L:;L@;F%S=&%V96YI92!T>7!U('IO<F%D
M96[I:&\@>F]Z;F%M=3\`5;X@97AI<W1U:F4`06QT97)N873M=FYE('!R:6AL
M87-O=F%C:64@;65N;R!)35-0`$%L=&5R;F%T[79N92!H97-L;R!)35-0`$%L
M=&5R;F%T[79N92!P;W6^[79A=&6U<VOI(&UE;F\@24U34`!!;'1E<FYA=.UV
M;F$@92UM86EL;W;A(&%D<F5S80!!;'1E<FYA=.UV;F4@N6%B;/-N>0!!;'1E
M<FYA=.UV;GD@=&5X=#H`06UE<FEC:^$@4V%M;V$`0F]L82!Z861A;N$@;F5P
M;&%T;N$@:&]D;F]T80!.87-T86QA(&YE>F[A;6$@8VAY8F$N`$%N9&]R<F$`
M06YG;VQA`$%N9W5I;&QA`$%N;VYY;6[I('!R;WAY`$]D<&]V9>\`06YT87)K
M=&EK80!!;G1I9W5A(&$@0F%R8G5D80!!<&QI:^%C:6$`6F]Z;F%M(&%P;&EK
MX6-I[0!!<&QI:^%C:6$@:F4@<')I<')A=F5NX2X`07!L:6MO=F&[(&YA('!O
M9')I861E;ND@>F1I9;5A;ND@<')I9>AI;FMY`%-C:';A;&F[`%!R:6)L:;YN
MX2!V9;5K;W.[`$%P<NUL`%9EM6MO<[L@87)C:.UV=0!-96YO(&%R8VCM=G4`
M3F%O>F%J(&-H8V5T92!V>6UA>F&[(+YI861O<[L@;R!P<FEH;.%S96YI92`G
M)7,G/P!.86]Z86H@8VAC971E('9Y;6%Z8;L@(B5S(B!A(':Y971K>2!P;V1S
M:W5P:6YY/P!!<F=E;G3M;F$`07)MZ6YS:V\`56UE;FEE`$%R=6)A`$]S=')O
M=B!!<V-E;G-I;VX`07-C:6D@=6UE;FEE`,%Z:6$O4&%C:69I8VO](')E9VGS
M;@!6>;YA9&]V8;L@<&]T=G)D96YI92!P<F5D('9Y:V]N86[M;2!O<&5RX6-I
M[2#Z9'*^8GD_`%!O:W5S(&\@=GEM87IA;FEE(&YE97AI<W1U:OIC96H@<VMU
M<&EN>2X`4&]K=7,@;R!V>6UA>F%N:64@;F5E>&ES='5J^F-E:&\@<'+A=F$N
M`%!O:W5S(&\@^G!R879U(&YE97AI<W1U:OIC96AO('!RX79A+@!0;VMU<R!O
M(/IP<F%V=2!N965X:7-T=6KZ8V5H;R!Z9&EEM6%NZ6AO(&]B:F5K='4N`$%T
M<FEB^G1Y`$%U9W5S=`!!=7-T<N%L:6$`4F%K^G-K;P!!=71H7V-Y<G-Q;#H@
M4&^^861O=F%NZ2!R;WJY[7)E;FEE(&EM87`@;F5B;VQO(&[A:F1E;NDN`$%U
M=&A?8WER=7,Z(&)A8VME;F0@;F5MX2!P;[YA9&]V86[I('-C:&]P;F]S=&DN
M`$%U=&A?8WER=7,Z('!OOF%D;W9A;ND@<F]ZN>UR96YI92!I;6%P(&YE8F]L
M;R!NX6ID96[I+@!!=71H7V9T<#H@<&^^861O=F%NZ2!R;WJY[7)E;FEE($94
M4"!N96)O;&\@;N%J9&5NZ2X@4VMO;7!I;'5J=&4@4$A0(',@<')E<.UN8>AO
M;2`M+65N86)L92UF='`N`$%U=&A?:6UA<#H@<&^^861O=F%NZ2!R;WJY[7)E
M;FEE($E-05`@;F5B;VQO(&[A:F1E;NDN`$%U=&A?:W)B-3H@<&^^861O=F%N
MZ2!R;WJY[7)E;FEE(&MR8C4@;F5B;VQO(&[A:F1E;NDN`$%U=&A?;&1A<#H@
M<')I9.%V86YI92!P;W6^[79A=&6U;W8@;FEE(&IE('!O9'!O<F]V86[I('!R
M92!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@=GEM87KA=F%N:64@<&]U
MONUV871EM6]V(&YI92!J92!P;V1P;W)O=F%NZ2!P<F4@06-T:79E($1I<F5C
M=&]R>0!!=71H7VQD87`Z('!OOF%D;W9A;ND@<F]ZN>UR96YI92!,1$%0(&YE
M8F]L;R!NX6ID96[I+@!!=71H7VQD87`Z($YE<&]D87)I;&\@<V$@<')I9&&[
M('!O=;[M=F%T9;5A("5S+B!397)V97(@;V1P;W9E9&%L.B``075T:%]L9&%P
M.B!N97!O9&%R:6QO('-A(&]D<W1RX6YINR!P;W6^[79A=&6U82`E<P!!=71H
M7VQD87`Z(&YE<&]D87)I;&\@<V$@86MT=6%L:7IO=F&[('!O=;[M=F%T9;5A
M("5S`$%U=&A?;&1A<#H@86MT=6%L:7KA8VEA('!O=;[M=F%T9;5O=B!N:64@
M:F4@<&]D<&]R;W9A;N$@<')E($%C=&EV92!$:7)E8W1O<GD`075T:%]M8V%L
M.B!P;[YA9&]V86[I(')O>KGM<F5N:64@34-!3"!N96)O;&\@;N%J9&5NZ2X`
M075T:%]S;6)A=71H.B!P;[YA9&]V86[I(')O>KGM<F5N:64@<VUB875T:"!N
M96)O;&\@;N%J9&5NZ2X`075T96YT:69I:^%C:6$@<&]M;V-O=2!)34%0('-E
M<G9E<F$@>FQY:&%L82X`075T96YT:69I:^%C:6$@>FQY:&%L80!!=71E;G1I
M9FEKX6-I82!Z;'EH86QA+B`E<P!397)V97(@4D%$2553('IA;6EE=&]L(&%U
M=&5N=&EF:6OA8VEU+@!!=71E;G1I9FEKX6-I82!P;VUO8V]U($944"!S97)V
M97)A('IL>6AA;&$N`$%U=&5N=&EF:6OA8VEA('!O;6]C;W4@4TU"('-E<G9E
M<F$@>FQY:&%L82X`1&]S='5P;ND@<&]L;[YK>3H`07IE<F)A:F2^86X`0D]&
M2"!%>&-U<V5S`%!O>F%D:64`1F%R8F$@<&]Z861I80!:;.D@:&5S;&\@<')E
M(&ME<F)E<F]S+@!:;.D@<&]UONUV871EM7-KZ2!M96YO('!R92!K97)B97)O
M<RX`0F%H86UY`$)A:')A:FX`0F%N9VQA9.FY`$)A<F)A9&]S`%!R:67H:6YO
M:R!S(&=R869I:V]U("(E<R(@;F5B;VP@;N%J9&5N_2X`6N%K;&%D;OT@<FEA
M9&]K`$)I96QO<G5S:V\`0F5L9VEC:V\`0F5L:7IE`$)E;FEN`$)E<FUU9'D`
M0G5TX6X`3F%R;V1E;FEN>0!";&]K("(E<R(@87!L:6OA8VEE("(E<R(@;F5B
M;VP@;N%J9&5N_2X`3F%S=&%V96YI82!B;&]K=0!4>7`@8FQO:W4`5'7H;ND`
M0F]L[79I80!:X6QOOFMY`$]K<F%J`*GM<FMA(&]K<F%J83H`3VMR86IE`$)O
M<VYA(&$@2&5R8V5G;W9I;F$`3V)E`$)O='-W86YA`$)O='1O;0!";W5V970@
M27-L86YD`$)R87KM;&EA`$)R:71S:^D@^GIE;6EE('8@26YD:6-K;VT@;V-E
MX6YE`$)R=6YE:2!$87)U<W-A;&%M`$)U;&AA<G-K;P!:;WIN86T@<R!O9'+A
MOFMA;6D`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!$:7-T<FEB=>AN
MZ2!B;V1Y($-23`!6;&%S=&YO<W1I(%]B=6YK>2XN+@!);F-I86QI>N%C:6$@
M=GER;W9NX79A8V5J('!A;>1T:2!N96)O;&$@9&]K;V[H96[A+@!+86QE;F3A
M<@!"97IV971R:64`2V%M8F]DOF$`2V%M97)U;@!.97!O9&%R:6QO('-A(&%U
M=&]M871I8VMY(&]B;F]V:;L@:&5S;&\L(&MO;G1A:W1U:G1E('-V;VIH;R!A
M9&UI;FES='+A=&]R82X`3F5P;V1A<FEL;R!S82!Z87#M<V&[(&1O('/Z8F]R
M=2`B)7,B`$YE;6^^;F\@861M:6ES=')O=F&[(&5X=&5R;ND@;W9LX61AZ&4@
M<V5D96[M+@!.97!O9&%R:6QO('-A('-P;VIINR!S($E-05`@<V5R=F5R;VTZ
M("5S`$YE<&]D87)I;&\@<V$@;W1V;W)INR!S^F)O<B`B)7,B+@!+86YA9&$`
M6G)UN6F[`%IR=;EINR!S<'+A=G4@;R!P<F]B;.EM90!.97!O9&%R:6QO('-A
M('9Y;6%Z8;L@<_IB;W(@(B5S(BX`3F5P;V1A<FEL;R!S82!NX6ISNR!D;^AA
M<V[](&%D<F5SX7(N`$YE;6^^;F\@<&]K<F'H;W9ANR!B97H@<&%R86UE=')A
M("=T87)G971&:6QE)RX`3F5P;V1A<FEL;R!S82!O9'-T<N%N:;L@861R97/A
M<B`B)7,B+@!.96UOOFYO(&]D<W1RX6YINRP@97AI<W1U:F4@)60@;F%S;&5D
M;W9N[6MO=BX`3F5M;[YN;R!P<F5U<W!O<FEA9&&[+"!P;^AE="!P;VQOOFEE
M:R!P<F4@<')E=7-P;W)I861A;FEE(&YE<_IH;&%S[2!S('!OZ'1O;2!U;&^^
M96[]8V@@<&]L;[YI96LN`$YE<&]D87)I;&\@<V$@<VUE<F]V8;L@<W!RX79U
M(&YA('5RZ&5NZ2#H[7-L;RX`2V%P=F5R9'-KZ2!O<W1R;W9Y`%1I='5L;VL`
M2V%T96?S<FEE(&$@<&]P:7-K>0!+86IM86YS:^D@;W-T<F]V>0!-;V)I;&[]
M('1E;&5F\VX`5FQA<W1N;W-T:2!B=6YK>0!6>7!L;F5N:64@8G5N:WDZ`%9L
M87-T;F]S=&D@8G5N:WD`4F]Z;W-T=7`@8G5N:65K.@!-;V)I;&[]('1E;&5F
M\VX`1&\@<W1R961U`%-T<F5D;V%F<FEC:^$@<F5P=6)L:6MA`%!O9')O8F[I
M(&EN9F]R;>%C:64@;R!C97)T:69I:^%T90!6;&%S=&[M:R!C97)T:69I:^%T
M=0!0;VQI=&EK>2!P<F4@8V5R=&EF:6OA='D`R&%D`%IM96YINP!:;65N:;L@
M5F&Y92!H97-L;P!.87-T879E;FEE(&UE;F$@82!A9')I97,L(&MT;W+I('9I
M9&EA(+5U9&EA+"!K9>\@Z.UT86KZ(&$@;V1P;W9E9&%J^B!N82!68;EE(&4M
M;6%I;'DN`%IM96YA(&AE<VQA(&YI92!J92!V(&%K='7A;&YE:B!K;VYF:6=U
M<N%C:6D@<&]D<&]R;W9A;N$N("!+;VYT86MT=6IT92!S=F]J:&\@861M:6YI
M<W1RX71O<F$N`%IN86L`4U]K;VYT<F]L;W9ANR!L:6YK=2XN+@!#:&EL90#(
M[6YA`%9Y8F5R=&4@87!L:6OA8VEU.@!:=F^U=&4@<VD@:&5S;&\`6G9OM71E
M('-I('!O=;[M=F%T9;5S:^D@;65N;P!6>6)E<G1E('-P]'-O8B!Z;V)R87IO
M=F%N:6$@9.%T=6UO=CH`5GEB97)T92!T>7`@N73];'4@>F]Z;F%M=2`H<')E
M('IO<F%D96[I('IO>FYA;7DI`%9I86YOZ&[](&]S=')O=@!$969I;NUC:6$@
M=')I961Y("5S(&YE8F]L82!NX6ID96[A+@!*87-N;P!/9'-T<N%N:;L@<'+M
M:V%Z>2!-4T]F9FEC90!6>6UA>F&[(&1O=&%Z`$]D<W1RX6YINR!P;W6^[79A
M=&6U83H@)7,`3V1S='+A;FF[('!O=;[M=F%T9;5A`%9Y;6%Z8;L@<&]UONUV
M871EM7-KZ2#Z9&%J90!.97-K]'(@=GEJ87-N96YI90!+;&EK;FET92!P<F4@
M<&]K<F'H;W9A;FEE`$-L:6-K871E;&P@8V5Z($A45%``6F%T=F]R:;L@;VMN
M;P!/8FQA:WD`4N%N;R!O8FQAZ&YO`$]B;&'H;F\`0V]C;W,@*$ME96QI;F<I
M($ES;&%N9',`6F)A;&F[($)OZ&[]('!A;F5L`%IB86QE;ND@;VMR86IE`$MO
M;'5M8FEA`$9A<F)A`%;]8F5R(&9A<F)Y`%;]8F5R(&9A<F)Y`%-TY7!C93H`
M3F%D<&ES>2!S=.5P8V]V`$MO;6EK<P!0<NUK87H`4'+M:V%Z;W;](&EN=&5R
M<')E=&5R`$MO;65N=.%R`$)EOF[I(&UE;F\`2V]M;W)Y`%-P;VQOZ&YO<[L`
M4&_H[71AZ&4`4W1A=@!3=&%V`%)O>F1I96QY('8@:V]N9FEG=7+A8VEI`$MO
M;F9I9W5RX6-I82!P<F4@<WEN8VAR;VYI>N%C:74@<R!01$$L(&EN=&5L:6=E
M;G1N_6UI('1E;&5F\VYM:2!A($]U=&QO;VMO;2X`2V]N9FEG=7+A8VEA('!O
M=')E8G5J92!A:W1U86QI>N%C:74N`$MO;F9I9W5R;W9ANR`E<P!0;W1V<N]T
M92!H97-L;P!+;VYG;P!$96UO:W)A=&EC:^$@<F5P=6)L:6MA($MO;F=O`%-P
M;VIE;FEE('IL>6AA;&\N`%-P;VIE;FEE('IL>6AA;&\Z(`!+M?KH(&)O;"!Z
M86UI971N=73]('-E<G9E<F]M('9E<F5J;OUC:"!KM?KH;W8N`$NU^N@@8F]L
M('IA;6EE=&YU=/T@<V5R=F5R;VT@=F5R96IN_6-H(&NU^NAO=BX@1/1V;V0Z
M("5S("@E<RD`4W!O:F5N:64@<R!&5%`@<V5R=F5R;VT@>FQY:&%L;RX`2V]N
M=&%K='D`2V]N=&%K='D@8F]L:2#Z<W!EN6YE('9L;[YE;N$@9&\@5N&Y:&\@
M861R97/A<F$N`%1Y<"!K;VUP<FEM;W9A;NEH;R!S^F)O<G4Z`$]B<V%H("(E
M<R(`4&]K<F'H;W9ANP!#;V]K;W9E(&]S=')O=GD`0V]O:VEE`$MO<.UR;W9A
MNP!+;W#M<F]V86YI92!Z;'EH86QO.B`E<P!+;W#M<F]V8;L@=OUB97(`2V]S
M=&%R:6MA`%!O8G)EOFEE('-L;VYO=FEN>0!.97!O9&%R:6QO('-A('IAN6EF
M<F]V8;L@<W!RX79U('!O;6]C;W4@4$=0.B``3F5P;V1A<FEL;R!S82!P;V1P
M[7-ANR!S<'+A=G4@<&]M;V-O=2!01U`Z(`!.97!O9&%R:6QO('-A('IAN6EF
M<F]V8;L@<W!RX79U('!O;6]C;W4@4R]-24U%+@!.97!O9&%R:6QO('-A('!O
M9'#M<V&[('-P<N%V=2!P;VUO8V]U(%,O34E-12X`3F5P;V1A<FEL;R!S82!P
M<FED8;L@:V]N=&%K="X@)7,N`$YE<&]D87)I;&\@<V$@<')I<&]J:;L@:R!,
M1$%0('-E<G9E<G4N`$YE<&]D87)I;&\@<V$@<')I<&]J:;L@:R!,1$%0('-E
M<G9E<G4`3F5P;V1A<FEL;R!S82!O=F5R:;L@>F]S=&%T;VL@;F$@^NAT92X@
M)7,`3F%S=&%L82!C:'EB82!P<FD@<'+M<W1U<&4@:R!,1$%0('-E<G9E<G4`
M3F5P;V1A<FEL;R!S82!P<FEP;VIINR!K('-E<G9E<G4@(B5S(B!P;VUO8V]U
M($944#H@)7,`3F5P;V1A<FEL;R!S82!V>71V;W)INR!Z;WIN86T@<'+M:F5M
M8V]V+B`E<P!.97!O9&%R:6QO('-A(&1EN6EF<F]V8;L@4$=0(/ID86IE.B``
M3F5P;V1A<FEL;R!S82!D9;EI9G)O=F&[(%,O34E-12#Z9&%J92X`3F5P;V1A
M<FEL;R!S82!V>6UA>F&[(&MO;G1A:W0N("5S`$YE<&]D87)I;&\@<V$@=GEM
M87IANR!Z;WIN86T@<'+M:F5M8V]V+B`E<P!.97!O9&%R:6QO('-A('9Y;6%Z
M8;L@<VMR:7!T(&YA('5P9W)A9&4@:V]N9FEG=7+A8VEE("(E<R(N`$YE<&]D
M87)I;&\@<V$@=7+H:;L@92UM86EL;W;Z(&%D<F5S=2!P<NUJ96UC=2X`3F5P
M;V1A<FEL;R!S82!S=&EA:&YUNR!C96S](&%D<F5SX7(N`$YE<&]D87)I;&\@
M<V$@>NUS:V&[(&MO;7!L971N_2!Z;WIN86T@<'+M:F5M8V]V+@!.97!O9&%R
M:6QO('-A('KM<VMANR!K;VUP;&5T;OT@>F]Z;F%M('IO>FYA;6]V('!R[6IE
M;6-O=BX`3F5P;V1A<FEL;R!S82!N8>CM=&&[('-T<F%TZ6=I=2`B)7,B+@!.
M97!O9&%R:6QO('-A('-P=7-T:;L@;6MD:7(@(B5S(BX`3F5P;V1A<FEL;R!S
M82!Z[7-K8;L@=F5R96IN_2!KM?KH('IO('-E<G9E<F$@:[7ZZ&]V+@!.97!O
M9&%R:6QO('-A(&]T=F]R:;L@(B5S(B!P<F4@>N%P:7,N`$YE<&]D87)I;&\@
M<V$@;W1V;W)INR`E<RX`3F5P;V1A<FEL;R!S82!O='9O<FF[(&UO9'5L($UA
M:6YT96YA;F-E7U1A<VL@)7,`3F5P;V1A<FEL;R!S82!O='9O<FF[(&%D<F5S
MX7(@(B5S(BX`3F5P;V1A<FEL;R!S82!P<FEP;VIINR!N82!,1$%0('-E<G9E
M<BX`3F5P;V1A<FEL;R!S82!P<F7H[71ANR`E<RX`3F5P;V1A<FEL;R!S82!O
M8FYO=FF[(&AE<VQO('IA9&%NZ6AO('!O=;[M=F%T9;5A+B!.:65K=&]RZ2!A
M;&5B;R!VN65T:WD@<&]D<F]B;F]S=&D@;FEE('/Z('-P<N%V;F4N(%-K^G-T
M92!T;R!Z;F]V=2!A;&5B;R!K;VYT86MT=6IT92!6X;EH;R!A9&UI;FES='+A
M=&]R82P@86L@<&]T<F5B=6IE=&4@<&]M;V,N`$YE;6^^;F\@>NUS:V&[($%#
M3`!.97!O9&%R:6QO('-A('KM<VMANR!A9')E<^%R+B`E<P!.97!O9&%R:6QO
M('-A('KM<VMANR!Z;WIN86T@<'+M:F5M8V]V+B`E<P!.97!O9&%R:6QO('-A
M('KM<VMANR!Z;WIN86UY('!R[6IE;6-O=B`E<P!.96UOOFYO('KM<VMANR!I
M;F9O<FWA8VEE(&\@=FQA<W1N;W-T:6%C:"!S97)V97)A`$YE<&]D87)I;&\@
M<V$@=G+A=&F[(&MO;F9I9W5RX6-I=2X`3F5P;V1A<FEL;R!S82!S<'5S=&F[
M(')M9&ER("(E<R(N`$YE<&]D87)I;&\@<V$@=6QOOFF[(&MO;F9I9W5RX6-I
M=2`E<RX`3F5P;V1A<FEL;R!S82!U;&^^:;L@>N%L;VAU(&MO;F9I9W5RX6-I
M92X`3F5P;V1A<FEL;R!S82!U;&^^:;L@>N%L;VAU(&MO;F9I9W5RX6-I93H@
M)7,`3F5P;V1A<FEL;R!S82!U;&^^:;L@<VMR:7!T(&YA('5P9W)A9&4@;F%S
M=&%V96[M(&1O.B`B)7,B+@!.97!O9&%R:6QO('-A('5L;[YINR!ZX6QO:'4@
M:V]N9FEG=7+A8VEE("5S+@!.97!O9&%R:6QO('-A('IA<.US8;L@:V]N9FEG
M=7)AZ&[]('/Z8F]R("5S+B!-]+YE=&4@<&]UOFF[(&YI96MT;W+Z('H@;6^^
M;F]S=.T@;F$@>N%P:7,@:_-D=2!N82`E<R!A;&5B;R!S:V]P[7)O=F&[(')U
MZ&YE(&OS9"!U=F5D96[](&YIOKEI92!D;R`E<RX`3F5P;V1A<FEL;R!S82!H
MM6%D8;L@;F$@3$1!4"!S97)V97)I+@!.97!O9&%R:6QO('-A('9Y;6%Z8;L@
M(B5S(BX`3F5P;V1A<FEL;R!S82!A:W1U86QI>F]V8;L@:V]N=&%K="X@)7,`
M3F5P;V1A<FEL;R!S82!A:W1U86QI>F]V8;L@>F]Z;F%M('!R[6IE;6-O=BX@
M)7,`3F5P;V1A<FEL;R!S82!Z87#M<V&[(&MO;F9I9W5RX6-I=2!P<F4@(B5S
M(CH@)7,`3F5M;[YN;R!NX6ISNR!";^AN_2!P86YE;"!-;WII;&QY+B!3:V]N
M=')O;'5J=&4L(+YE(&IE('!A;F5L(&]T=F]R96[]+@!0;W6^[79A=&6U;W9I
M("(E<R(@<V$@;F5P;V1A<FEL;R!P<FED8;L@<'+A=F$@<')E('!R:67H:6YO
M:R`B)7,B.B`E<P!0;^CM=&%N_2!T97AT`$MR86II;F$`2W5R>GD`5GET=F]R
M:;L`5GET=F]R:;L@;&EN:W4`5GET=F]R:;L@;F]V_0!6>71V;W)INR!P;V1P
M<FEEZ&EN;VL`4'+A=F$@='9O<F-U`,CM<VQO(&MR961I=&YE:B!K87)T>0!#
M:&]R=N%T<VMO`$MU8F$`06MT=>%L;F4@-"!FX7IY`$%K='7A;&YE('-E9&5N
M:6$`06MT=>%L;GD@Z&%S`$%K='7A;&YA(%523"!J90!!:W1UX6QN:2!P;W6^
M[79A=&5L:6$`06MT=>%L;F4@<&_H87-I90!!:W1UX6QN92!P;V1M:65N:WDZ
M(`!!:W1UX6QN>2"Y=/UL`$YA<W1A=F5N:64@^FQO:"P@:W1O<ND@<V$@<W#Z
MN;MA:OH@<')I('!R:6ALX7-E;NT@9&\@87!L:6OA8VEE("5S+@!6>7-T<FEH
M;OJ[`%9Y<W1R:6AN^KL@=OUB97(`0WEP<G5S`,AE<VOA(')E<'5B;&EK80!$
M1`!$4TX@*'!O>G)I(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A
M8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`1&5N;F4`4')E>F5R
M8>@@9.%T;W;I:&\@<W1R;VUU("A$871A5')E92D`5GEHM6%DX79A;FEE('8@
M9&%T86+A>F4`1.%T=6T`1.%T=6T@<')I:F%T:6$`5OUB97(@9.%T=6UU`$1E
M\@!/7V1S='+A;FF[('-TY7!E8P!$96-E;6)E<@!$97-I871K;W;I(.CM<VQA
M`%IM96ZY:;L@;V1S861E;FEE`%!R961N87-T879E;ND`4')E9&YA<W1A=F5N
MX2!F87)B80!68;EA('!R961N87-T879E;N$@:61E;G1I=&$`4')E9&YA<W1A
M=F5N_2!P<NUK87IO=OT@:6YT97)P<F5T97(`1&5F:6[M8VEE`%9Y;6%Z8;L`
M5GEM87IANR!B=6YK=0!6>6UA>F&[('-K=7!I;G4`5GEM87IANR!ZX7IN86T`
M5GEM87IANR!P<N%V;P!6>6UA>F&[(&$@;V1S='+A;FF[('-P<N%V>0!6>6UA
M>F&[(&)U;FMU`%9Y;6%Z8;L@<W3E<&5C`%9Y;6%Z8;L@97AI<W1U:OIC=2!A
M;'1E<FYA=.UV;G4@N6%B;/-N=0!6>6UA>F&[('!RX79A('!R92`B)7,B`$-H
M8V5T92!V>6UA>F&[("(E<R(@82!VN65T:WD@:F5H;R!P;V1P<N%V83\`5GEM
M87IANR!R:6%D;VL`5GEM87IANR!V>6)R86[Z(&ED96YT:71U`%9Y;6%Z8;L@
M86MT=>%L;GD@<W3E<&5C`%9Y;6%Z8;L@86MT=>%L;GD@<FEA9&]K`%-K<FEP
M="!N82!U<&=R861E(&MO;F9I9W5RX6-I92`B)7,B(&)O;"!V>6UA>F%N_2X`
MR&%S(&1O<G7H96YI80!$X6YS:V\`4&]P[;ET92!P<F]B;.EM`%!O<&ES`%!O
M9')O8FYO<W1I("AT:66^('8@;&]G;W9A8V]M('/Z8F]R92!(;W)D92D`1&5T
M86EL>2!B;VQI('IA>FYA;65N86[I('!R92!A9&UI;FES='+A=&]R82X`5OUV
M;VH`4F]S;OT@8F]D`%)O<V[](&)O9"!Z82!P;W-L961N^B!H;V1I;G4Z(`!2
M;W-N_2!B;V0Z(`!3;65R('JU879A(&1O<')A=F$`4VUE<B!S<')A=F$@9&^U
M879A`$%D<F5SX7(`6F]B<F%Z;W9ANR#H87,@=B`R-"UH;V1I;F]V;VT@9F]R
M;>%T93\`3F%S=&%V96YI92!Z;V)R87IE;FEA`%IO8G)A>FF[('!O9')O8F[Z
M('!R961P;W9E[P!:;V)R87IINR!P<F5D<&]V9>\@*%1!1BD`1F]R;>%T('IO
M8G)A>F5N:6$`4&]T=G)D96YI92!O(&1O<G7H96[M`$2^:6)U='-K;P!.979Y
M;6%Z8;L`3F5P;W6^[79A:G1E('!R:6%M;R!M86EN=&5N86YC92YP:'``3V)S
M86AU:F4@<')V_2!R:6%D;VL@;N%Z=GD@<&]L[3\@06L@X6YO+"!Z8;EK<G1N
M:71E('!O;.WH:V\Z(`!$;VUI;FEC80!$;VUI;FEKX6YS:V$@<F5P=6)L:6MA
M`$YE;>%T92#ZZ&5T/R!:87)E9VES=')U:G1E('-A+@!3=&EA:&YUNP!3=&EA
M:&YUNR`E<P!3=&EA:&YUNR!V>6=E;F5R;W9A;OH@:V]N9FEG=7+A8VEU(&%K
M;R!02%`@<VMR:7!T+@!:;WIN86T@<R!V_6)E<F]M`$1R;V=Y`$4M;6%I;`!%
M4E(`16MVX61O<@!5<')A=FF[`%5P<F%V:;L@8FQO:P!5<')A=FF[('-K=7!I
M;G4`57!R879INR!P<N%V;P!5<')A=FF[('!RX79A`%5P<F%V:;L@<'+A=F$@
M<')E("5S`%5P<F%V:;L@;F%S=&%V96YI82!P<F4Z`%5P<F%V:;L@<'+A=F$@
M<')E("(E<R(`57!R879INR!P<N%V82!P<F4@)7,`5GID96SA=F%N:64`16=Y
M<'0`4V%L=N%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%;6%I;&]VX2!A9')E
M<V$Z`$4M;6%I;&]VZ2!A9')E<WD@;75S:6$@8GF[(')O=FYA:^DN`$4M;6%I
M;"!S('!O='9R9&5N[6T`0G+A;F$@16UA:6PM;F$M4TU3`$5M;W1I:V]N>0!0
M<N%Z9&YA('-P<N%V82X`4'+A>F1N>2!V_7-L961O:RX`4'+A>F1N92!P;V1M
M:65N:WD@:+5A9&%N:6$`4&]V;VQINR!V;&^^96YI92!O8G+A>FMO=B!Z($=A
M;.ER:>T@9&\@=&5X='4_`%!O=F]L:;L@:V]N=&5X=&]VZ2!M96YU('!R92!P
M<F%VZ2!T;&'H:61L;S\`2V]N:65C(')O:V$`6G;DZ+EINR!E9&ET;W(`6F%D
M86IT92!B97IP9>AN;W-T;OH@;W3A>FMU+"!N82!K=&]R^B!B=61E=&4@;75S
M:66[(&]D<&]V961ANR!A:R!Z86)U9&YE=&4@:&5S;&\L(&YA<'(N("=A:V\@
M<V$@=F]LX2!M;VIE('IV:65R871K;S\G.@!:861A:G1E(%523"!O8G+A>FMA
M`%IA9&%J=&4@<.US;65NX2!U=F5D96[I(&YIOKEI93H`4F]V;NUK;W;A($=U
M:6YE80!%<FET<F5A`$-H>6)A`$-H>6)A('!R:2!V>71VX7)A;NT@8FQO:W4Z
M("5S`$-H>6)A('!R:2!V>6UA>N%V86[M('5K;W1V96YI82!S>6YC:')O;FEZ
MX6-I93H@)7,`0VAY8F$@<')I('9Y;6%ZX79A;NT@>N%Z;F%M=2!S>6YC:')O
M;FEZX6-I93H@)7,`0VAY8F$@<')I('KM<VMA=F%N[2!O8G-A:'4Z("5S`$-H
M>6)A('!R:2!A:W1U86QI>N%C:6D@:&5S;&$Z("5S`$-H>6)A('8@92UM86EL
M;W9E:B!S<'+A=F4N`$-H>6)A('!R:2!Z87!I<V]V86[M("(E<R(N`$5S=/-N
M<VMO`$5T:?-P:6$`171N:6-KZ0!%=7+S<&$`2V&^9/UC:"`Q-2!M:6[Z=`!+
M8;YDZ2`R(&UI;OIT>0!+8;YD_6-H(#,P('-E:_IN9`!+8;YD_6-H(#4@;6EN
M^G0`4')I(&MAOF1O;2!P<FEH;.%S96[M`$MAOF3Z('!O;&AO9&EN=0!+8;YD
M^B!M:6[Z='4`3F%P<NUK;&%D.@!3<'5S=&F[`%)O>F)A;&F[`%)O>F)A;&F[
M($)OZ&[]('!A;F5L`$_H86OA=F$@<V$@)RDG`$_H86OA=F$@<V$@<VQO=F\@
M86QE8F\@<&]D;6EE;FMA(&BU861A;FEA('8@^G9O9'IO=FOA8V@`1.%T=6T@
M97AP:7+A8VEE`$5X<&]N96YT`$9A<F)A('1E>'1U`$YA:')ANR!K;VYF:6=U
M<N%C:74@;F$@1E10`$YE<&]D87)I;&\@<V$@>NUS:V&[(&YA<W1A=F5N:6$N
M`$YA<W1A;&$@8VAY8F$@<')I('-P;VIE;NT@<R!,1$%0('-E<G9E<F]M+@!.
M87-T86QA(&-H>6)A('!R:2!P<NUS='5P92!K(%--0B!S97)V97)U+@!.97!O
M9&%R:6QO('-A(&MO<.UR;W9ANR!Z("(E<R(N`$YE<&]D87)I;&\@<V$@:V]P
M[7)O=F&[(&1O("(E<R(N`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@;F]VZ2!3
M05-,('-P;VIE;FEE+@!.97!O9&%R:6QO('-A('!R97-U;OJ[(&1O("(E<R(N
M`$YE<&]D87)I;&\@<V$@>NUS:V&[.B`E<P!$;V)RZ0!&86QK;&%N9'-KZ2!O
M<W1R;W9Y("A-86QV[6YY*0!&865R<VOI(&]S=')O=GD`6N%V8;YNX2!C:'EB
M83H`1F%X`$9A>'D`1F5B<G7A<@!0;V-I="!T97!L;W1Y`%!O8VET('1E<&QO
M='DZ(`!-86SI('IRX;YK>0!-86SI('-N96AO=ND@<')E:.%N:WD`36%T:6-A
M('!O;.T`1FEDOFD`4_IB;W(`4&_H970@<_IB;W)O=CH@)7,@<_IB;W(`4&_H
M970@<_IB;W)O=CH@)7,@<_IB;W)O=@!3<'+A=F-A('/Z8F]R;W8`365N;R!S
M^F)O<G4`5OUB97(@<_IB;W)U`$YA:')A=&EE('/Z8F]R=0!.86ARX79A;FEE
M('/Z8F]R;W8@;FEE(&IE('!O9'!O<F]V86[I+@!&:6QT<F4`1NUN<VMO`%!R
M=N$@<&]L;W9I8V$`4')VX2"Y='9RNP!0979N_2!P;VUE<@!/=&_H:;L`4&SA
M=F%J^F-I('1E>'0`2&UL80!0<FEEZ&EN;VL@)7,@;F5E>&ES='5J90!&87)B
M82!P[7-M80!0;W1R879A`%!R92!P<F5H;&EA9&'H92P@:W1O<ND@;F5P;V1P
M;W)U:OH@;V)RX7IK>0!0<F5D<&]V9>\@*%1!1BD`4')E9'!O=F7O(&YA('5V
M961E;OT@<&_H970@9&[M("AP86WD=&%J=&4@;F$@=&\L(+YE('!R961P;W9E
M[R!J92!P<F4@9&YI(&%J(&YO8VD@82!T86L@;?2^92!V9;5KZ2#H[7-L;R!V
M>71V;W)INR!V9;5M:2"Y:7)O:_T@8FQO:RD`6F%B=61L:2!S=&4@:&5S;&\_
M`$9O<FUU;.%R90!&;W)T=6YA`%1Y<"!F;W)T=6YY`$9O<G1U;GD`1F]R='5N
M>2`R`$;S<F$`4')E<VUE<F]V86YI80!0:6$`4N%M8V4`1G)A;F/Z>G-K;P!&
M<F%N8_IZ<VMO("A%=7+S<&$I`$9R86YC^GIS:V$@1W5A>6%N80!&<F%N8_IZ
M<VMA(%!O;'ENZ7II80!&<F%N8_IZ<VME(&IUOF[I('1E<FET\W)IX0!/9`!:
M;R!S;65R=2``VG!L;OT@<&]P:7,`4W!L;@!#96SI(&UE;F\Z`$=A8G5N`$=A
M;.ER:6$L('H@:W1O<F5J(&-H8V5T92!V>FEANR!O8G+A>F]K`$=A;.ER:6$Z
M`$=A;6)I80!'96YE<F]V8;L@:V]N9FEG=7+A8VEU('!R92!A<&QI:^%C:74@
M)7,`1V5N97)O=F%N_2!K\V0`1V5O<F=I80!.96UE8VMO`$=H86YA`$=I8G)A
M;'3A<@!+<G-T;ND@;65N;P!/9&]S;&&[`$=O961E;`!';V]G;&4@36%P<P!(
MM6%D8;L@;F$@1V]O9VQE`$]D=&EE;F4@N65D96H`1W+I8VMO`$=R\VYS:V\`
M1W)E;F%D80!!9&UI;FES='+A8VEA('-K=7#M;@!-96[A('-K=7#M;B!N97-M
M^B!B>;L@<'+A>F1N90!'<F]U<%]L9&%P.B!.97!O9&%R:6QO('-A('!R:61A
MNR!S:W5P:6YU("5S+B!397)V97(@;V1P;W9E9&%L.B``1W)O=7!?;&1A<#H@
M;F5P;V1A<FEL;R!S82!V>6UA>F&[('-K=7!I;G4@)7,`1W)O=7!?;&1A<#H@
M;F5P;V1A<FEL;R!S82!A:W1U86QI>F]V8;L@<VMU<&EN=2`E<P!3:W5P:6YY
M`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`4'+A=F$@86YO
M;GEM;OUC:"!P;W6^[79A=&6U;W8`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M
M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&YE9&]V;VSM('9Y;6%Z8;L@
M<&]S;&5D;OH@8G5N:W4@=B!R:6%D:W4N`$A434Q!<F5A(&YE9&]V;VSM('9Y
M;6%Z8;L@<&]S;&5D;OT@<W3E<&5C('8@=&%B=;5K92X`2%1-3$%R96$@;F5D
M;W9O;.T@=GEM87IANR!P;W-L961N_2!R:6%D;VL@=B!T86)UM6ME+@!(5%10
M(&%U=&5N=&EF:6OA8VEA(&YE8F]L82!NX6ID96[A+@!(86ET:0!!;&=O<FET
M;75S(&AA<VAO=F%C96H@9G5N:V-I90!/<&%R`$AL879IZ&MA`$AL879IZ&MY
M`$AE87)D;W8@;W-T<F]V(&$@36-$;VYA;&1O=F4@;W-T<F]V>0!3:6QNX2!B
M^G)K80!6_;EK80!0;VUO8V[M:P!0;VUO8V[M:R!P<F4@<&]UONUV86YI92!E
M9&ET;W)A`%!O;6]C;NUK`%!O;&]G=;5A`%1U(&IE('IAZ&EA=&]K('/Z8F]R
M=3H`5GES;VOA`$1O7VUO=@!6871I:^%N`$1O;6]V`$1O;>%C82!A9')E<V$`
M1&]MX6-I('!R:67H:6YO:P!496QE9O-N(&1O;6]V`$AO;F1U<F%S`$AO;F<@
M2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@=B!S<'+A=F4@)7,@8F]L:2!NX6ID
M96[I(&YE<&QA=&[I("5S(%A-3"#Z9&%J90!(;W)D92]+;VQA8CH@<R!O8FIE
M:W1O;2`E<R!N96MO<F6Y<&]N9'5J92"^:6%D;F$@<W!RX79A+@!(;W)D92]+
M;VQA8CH@=B!S<'+A=F4@)7,@;F5B;VP@;N%J9&5N_2"^:6%D96X@;V)J96MT
M('1Y<'4@)7,`2&]R9&4O2V]L86(Z(/IS<&6Y;F4@;V1S='+A;F5NZ2`E<R`B
M)7,B`$AO<F1E+TMO;&%B.B!I;G1E9W+A8VEA('9YOF%D=6IE(%!(4"!R;WJY
M[7)E;FEE("=D;VUX;6PG`$AO<F1E+TMO;&%B.B!N97!O9&%R:6QO('-A('9Y
M='9O<FF[(&YO=OT@6$U,('-T<F]M('!R92!O8FIE:W0@)7,`2&]R9&4O2V]L
M86(Z(&YE<&]D87)I;&\@<V$@;V1S='+A;FF[("5S("(E<R(Z("5S`$AO<F1E
M+TMO;&%B.B!N97!O9&%R:6QO('-A('KM<VMANR!-24U%($E$('!R92#H87.[
M('1Y<'4@)7,`2&]R9&4O2V]L86(Z(&YE<&]D87)I;&\@<V$@<WEN8VAR;VYI
M>F]V8;L@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(&YE<&]D87)I;&\@<V$@
M<WEN8VAR;VYI>F]V8;L@>F1I9;5A;ND@;V)J96MT>3H@)7,`2&]R9&4O2V]L
M86(Z(&YE>F[A;7D@>F1I9;5A;OT@;V)J96MT("(E<R(`2&]R:7IO;G3A;&YA
M(.AI87)A`$AO<FEZ;VYTX6QN92!V>7!L;F5N:64`2&]R:7IO;G3A;&YE.@!!
M:V\@<W1E('-A('-E;2!D;W-T86QI/R`H4')O<^UM(&YA:&SA<W1E(2D`2V^U
M:V\@<W3E<&-O=B!C:&-E=&4@>FSZZ&F[/P!:861A:G1E('!OZ&5T('!O;.T@
M*'-TY7!C;W8I/P!+;[5K;R!R:6%D:V]V(&-H8V5T92!Z;/KH:;L_`%9L:&MO
M<[L`5FQH:V]SNSH@`$AU;6]R:7-T:0!-8>]A<G-K;P!.97!O9&%R:6QO('-A
M('9Y='9O<FF[($E-05`@<V-H<N%N:W4Z("5S`$YE<&]D87)I;&\@<V$@=GEM
M87IANR!)34%0('-C:'+A;FMU.B`E<P!.97!O9&%R:6QO('-A('9Y='9O<FF[
M($E-05`@:W;S='4Z("5S`$E0(&%D<F5S80!)4"!A9')E<V$@;FEE(&IE(&1O
M<W1U<&[A+@!)4"!A9')E<V$@;FEE(&IE('8@<N%M8VD@9&]V;VQE;NEH;R!#
M2412(&)L;VMU+@!0;W)UN65N:64@<')A=FED;&$@;R!P979N96H@25`@861R
M97-E+@!6;&^^:;L@:[7ZZ"!?<')E9`!)<VQA;F0`26)A(&EK;VYY`$EK;VYY
M('!R92`E<P!):V]N>2!A('1E>'0`3N%Z;W8@:61E;G1I='DZ`$%K('-A(&YE
M>F]B<F%Z[2!K;W)E:W1N92P@)7,@82!O='9O<NT@<V$@=B!N;W9O;2!O:VYE
M+@!!:R!N979I9.UT92!P<FD@<&]UOFET[2!);G1E<FYE="!%>'!L;W)E<F$@
MOFEA9&YE(&EK;VYY+"!P;W1R96)U:F5T92!Z8;EK<G1N^KL@=/IT;R!V;[5B
M=2!P<F4@=GEP;G5T:64@<')I97-V:71N;W-T:2!03D<@;V)RX7IK;W8N`$%K
M('9I9.UT92!T^G1O('-P<N%V=2!A(&YE=FED[71E(&]B<N%Z;VLL(&]B<N%Z
M;VLL(&MT;W+]('-T92!C:&-E;&D@;F%H<F&[+"!N96WTOF4@8GF[('IO8G)A
M>F5N_2!V;R!68;EO;2!P<F5H;&EA9&'H:2X`56OAOFMA(&]B<N%Z:V$Z`%52
M3"!O8G+A>FMA`%523"!O8G+A>FMA.@!/8G+A>F]K('H@9V%LZ7)I90!/8G+A
M>F]K('H@9V%LZ7)I93H`3F%H<F%T:64@;V)RX7IK=0!/8G+A>FMY`$EM<&]R
M="P@:W)O:R`E9`!);7!O<G1O=F%NZ2!P;VQE.B`E<P!);7!O<G1O=F%NZ2!P
M;VQI83H`5FQOOFF[(&NU^N@@7WIA`$)O;"!Z861A;OT@;F5S<'+A=FYY(&OS
M9"!A:V-I92X`3F5S<'+A=FYE('!O=;[M=F%T9;5S:^D@;65N;R!A+V%L96)O
M(&AE<VQO`$YE<W!RX79N92!P;W6^[79A=&6U<VOI(&UE;F\@86QE8F\@86QT
M97)N873M=FYA(&%D<F5S82X@4VOZ<W1E('1O('IN;W9U(&%L96)O(&MO;G1A
M:W1U:G1E('-P<N%V8W4@5N&Y:&\@<WES=.EM=2P@86L@<&]T<F5B=6IE=&4@
M<&]M;V,N`%IVY.BY:;L@;V1S861E;FEE`$EN9&EA`$IE9&YO=&QI=NT@<&]U
MONUV871E;&EA`$EN9&]NZ7II80!);F9O`$EN9F]R;>%C:64`26YF;W)MX6-I
M92!UOB!N:64@<_H@9&]S='5P;NDN`%9L;[YINR!?<W3E<&5C('IA`%9L;[YI
MNR!O8G+A>F]K`%9L;[YINR!T86)UM6MU`%9L;[YINR!L:6YK=0!6;&^^:;L@
M7W-TY7!E8R!P<F5D`%9L;[YINR!N;W;]('-TY7!E8R!Z82!A:W1UX6QN>0!6
M;&^^:;L@;F]V_2!S=.5P96,@<')E9"!A:W1UX6QN>0!6;&^^:;L@;F]V_2!R
M:6%D;VL@>F$@86MT=>%L;GD`5FQOOFF[(&YO=OT@<FEA9&]K('!R960@86MT
M=>%L;GD`5FQOOFF[(&]D<W1A=F5C('IA(&%K='7A;&YY(&)O9`!6;&^^:;L@
M;V1S=&%V96,@<')E9"!A:W1UX6QN>2!B;V0`5FQOOFF[(&%L=&5R;F%T[79N
M=2"Y86)L\VYU`%IA9&%J=&4@92UM86EL;W;Z(&%D<F5S=2P@;F$@:W1O<OH@
M9&]S=&%N971E(&YO=ND@:&5S;&\Z`%9L;[YINR!B=6YK=2!Z80!6;&^^:;L@
M8G5N:W4@<')E9`!6;&^^:;L@<W3E<&5C('IA`%9L;[YINR!S=.5P96,@<')E
M9`!6;&^^=&4@<W!RX79Y`%9L;[YINR!O9'-T879E8R!Z80!6;&^^:;L@;V1S
M=&%V96,@<')E9`!6;&^^:;L@<FEA9&]K('IA`%9L;[YINR!R:6%D;VL@<')E
M9`!:861A:G1E('!OOF%D;W9A;OH@;V1P;W9E[R!N82!B97IP9>AN;W-T;OH@
M;W3A>FMU.@!6;&^^:;LO=7!R879INR!O8G+A>F]K`%9L;[YINR]U<')A=FF[
M(&QI;FMU`$YA(&]D;W-I96QA;FEE('!R92!Z;WIN86T@<'+M:F5M8V]V(&YE
M;>%T92!D;W-T871OZ&[](&MR961I="X`3F5D;W-T871OZ&[](&MR961I="X`
M0V5LZ2#H[7-L;P!:;WIN86T@8V5L_6-H(.AI<V5L`$YE<&QA9&[I(%5$2"`H
M57-E<B!$871A($AE861E<BP@2&QA=FGH:V$@<&]UONUV871EM7-K_6-H(/ID
M86IO=BDN`$YE<&QA=&[I(/ID86IE(&9O<FWA='4@6DE0+@!.97!L871NX2!A
M<&QI:^%C:6$N`$YE<&QA=&[I($E$(&3A=FMY+@!";VQI(&]D;W-L86[I(&YE
M<&QA=&[I(/ID86IE+@!.97!L871NX2!C:66U;W;A(&%D<F5S82X`3F5P;&%T
M;OT@9F]R;>%T('/Z8F]R=0!.97!L871N_2!L:6-E;NAN_2!KM?KH+@!";VQA
M('IA9&%NX2!N97!L871NX2!L;VMA;&ET82X`3F5P;&%T;N$@:&]D;F]T82!M
M<V=?='EP92X`3F5P;&%T;N$@86QE8F\@8VC]8F%J^F-A(&AO9&YO=&$@87!I
M7VED+@!.97!L871NZ2!A;&5B;R!C:/UB86KZ8V4@<&%R86UE=')E+@!.97!L
M871NZ2!R;V1IZ&]V<VOI('!RX79O+@!.97!L871NZ2!I9"!P87)T;F5R82X`
M3F5P;&%T;OT@:_-D('!R;V1U:W1U+@!.97!L871N_2!P<F]T;VMO;`!.97!L
M871N_2!P<NUJ96UC83H@(B5S(@!.97!L871N_2!O8FIE:W0@>F1I9;5A;FEA
M`$YE<&QA=&[A('ID<F]J;W;A(&%D<F5S82X`3F5P;&%T;ND@^F1A:F4@=6YI
M8V]D92X`26YV96YTX7(`26YV97)T;W9ANR!V_6)E<@!)<N%N`$ER86L`S7)S
M:V\`27-L92!O9B!-86X`3VIE9&EN96SI(&+Z<FMY`$EZ<F%E;`!6>61A=F%T
M9;4`2W5R>NUV80!486QI86YS:V\`2F%M86IK80!*86YUX7(`2F%P;VYS:V\`
M2F5R<V5Y`$IO<F3A;@!*^FP`2OIN`%IA<F]V;F&[`%IA<F]V;F&[(&1O('-T
M<F5D=0!:87)O=FYANR!D;R!B;&]K=0!:87)O=FYANR!VM6%V;P!:87)O=FYA
MNR!V<')A=F\`2V%Z86-H<W1A;@!0;VYE8VAANR!O<FEG:6[A;#\`2V7R80!+
M97)B97)O<R!S97)V97(@>F%M:65T;VP@875T96YT:69I:^%C:74N`$ME<FYE
M;"UN;W;AZ&EK;W9I80!6>71V;W)E;FEE(&NU^NAA`$1I9VETX6QN>2!O9'1L
M8>AO:R!KM?KH80!$Y;YK82!KM?KH80!4>7`@:[7ZZ&$`4&]UOFET:64@:[7Z
MZ&$`2[7ZZ"!UOB!E>&ES='5J92!N82!S97)V97)I('9E<F5J;OUC:"!KM?KH
M;W8N`$1E=&D`2VER:6)A=&D`I75D;W9O9&5M;VMR871I8VOA(')E<'5B;&EK
M82!+\W)E80!+\W)E:G-KX2!R97!U8FQI:V$`2W5V86IT`$MI<F=IN7-K;P!6
M>E]HM6%D`$IA>GEK`$QA;W,`4&]S;&5D;N$@<&]L;W9I8V$`4&]S;&5D;N$@
M>FUE;F$@:&5S;&$`4&]S;&5D;N$@N71V<KL`4&]S;&5D;N$@86MT=6%L:7KA
M8VEA.@!0;W-L961NZ2!P<FEH;.%S96YI93H@)7,`4&]S;&5D;ND@<')I:&SA
M<V5N:64Z("5S('H@)7,`4&]S;&5D;ND@<')I:&SA<V5N:64Z(&YI:V1Y`$QO
M='FY<VMO`%!RX79O`%9Z:+5A9`!.96-H86IT92!P<N%Z9&YE('!R92"^:6%D
M96X@;VMR86H`3&EB86YO;@!6M6%V;P!(;&%V:>AK82!VM6%V;P!(;V1N;W1Y
M(':U879O`$QE<V]T:&\`VG)O=F7R`$QI8NER:6$`3.UB>6$`3&EC:'1E;KET
M86IN<VMO`*5A:&OI(&UR:&]L96YI90"E86AK_2!DX;[O`%+A;F\@M6%H:_T@
M9.&^[P!.97-K]'(@M6%H:_T@9.&^[P"E86AKZ2!D8;[O;W;I('!R96CA;FMY
M`*5A:&O](&3AON\@<R!H<FUE;NUM`*5A:&OI('-N9;YE;FEE`*5A:&OI('-N
M96AO=ND@<')E:.%N:WD`3&EM97)I8VL`3&EN:V$`3&EN:V$@=6MA>G5J92!N
M83H`4')E<&]J:;L@92UM86EL;W;Z(&%D<F5S=2!S;R!S='+A;FMO=2!N82!P
M[7-A;FEE('!ON71Y`$QI;FMY`$QI;G5X($-O;VMI90!:;WIN86T@+2!P;W6^
M[79A=&6U('5V:63M('!R:67H:6YO:P!6>7#M<V&[('IO>FYA;2!D871A8N%Z
M`%IO>FYA;2!TZ6T@4&]M;V-N[6MA`%9Y<.US8;L@>F]Z;F%M('1A8G5L:65K
M`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI
M<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`%IO8G)A
M>F5N:64@<V5D96[M('IL>6AA;&\Z("5S`%IO8G)A>F5N:64@<&]UONUV871E
MM6]V('IL>6AA;&\Z("5S`%IO8G)A>F]V86YI92!Z;WIN86UU('!O=;[M=F%T
M9;5O=B!J92!Z86OA>F%NZ2X`3&ET97)A=/IR80!,:71V80!.8>CM=&%V82!S
M82XN+@!-:65S=&YY(.AA<SH@`$QO:V%L:7KA8VEA(&$@Z&%S`$QO:V%L:71A
M`%!R:6ALX7-E;FEE`%KA>FYA;7D@<')E9&-HX61Z86KZ8V5J('-Y;F-H<F]N
M:7KA8VEE`$]D:&SA<VF[`%!R:6ALX7-E;FEE`-IL;VAY('!R:2!P<FEH;.%S
M96[M`%!R:6ALX7-E;FEE('IL>6AA;&\L('!R971OOF4@<W1E('IA9&%L:2!N
M97-P<N%V;F4@<&]UONUV871EM7-KZ2!M96YO(&%L96)O(&AE<VQO+@!0<FEH
M;.%S96YI92!Z;'EH86QO+@!$;&C]('1E>'0`3.%S:V$`3NUZ:V$`36%LZ2!G
M<NEC:V4@<.US;65NX0!-86SI(&QA=&EN<VOI('#M<VUE;N$`36%LZ2!R[6US
M:V4@Z.US;&EC90!,=7AE;6)U<G-K;P!-30!3<'+A=F$@9/)A`%!R[6QO:&$@
M35,M5$Y%1B!N96]B<V%H;W9A;&$@OFEA9&YE(/ID86IE+@!-4T<`36%C86\`
M36%C963S;G-K;P!-861A9V%S:V%R`$WA9VEA`%!ON71A`%!O<VQANR!E+6UA
M:6P@861M:6YI<W1RX71O<F]V:0!6>71V;W)INR!L:6Y?:W4N+BX`36%L87=I
M`$UA;&%J>FEA`$UA;&5D:79Y`$UA;&D`36%L=&$`4W!R879O=F&[('IO>FYA
M;2!K871E9_-R:>TL(',@:W1O<OUM:2!O>FYAZ'5J971E('!O;&^^:WD@82!F
M87)B>2!A<V]C:6]V86[I(',@=/UM:71O(&MA=&5G\W)I86UI+@!-87!A($UA
M<#(T`$UA<&$@36%P475E<W0`36%P;W9A;FEA('5L;[YE;NDN`$UA<F5C`$]K
M<F%J`$]Z;F'H:;L@<'+M>FYA:VUI(%!R9>CM=&%NZ2].97!R9>CM=&%NZ0!/
M>FYAZ&F[(&EN_6UI('!R[7IN86MM:2`H;F%P<BX@1/1L9;YI=.DO6F]D<&]V
M961A;NDI`$UA<G-H86QL;W9E(&]S=')O=GD`36%R=&EN:6L`6FAO9&[I('!O
M;&EA`$UA=7)E=.%N:6$`36%U<NUT:75S`$UA>&EMX6QN>2!P;W9O;&5N_2!K
M<F5D:70N`$)O;"!P<F5K<F_H96[](&UA>&EMX6QN>2!P;^AE="#H87-T[2!S
M<'+A=GDN`$YA:G9YN;EI82!T97!L;W1A('IA('!O<VQE9&[]8V@@,C0@:&]D
M[6XZ(`!.86IV>;FY:6$@=&5P;&]T82!Z82!P;W-L961N_6-H(#8@:&]D[6XZ
M(`!-87AI;>%L;GD@<&_H970@8FQO:V]V('!O<G3A;'4`36%X:6WA;&YA(&3E
MOFMA`$WA:@!-87EO='1E`$UE9&EC[6YA`,AL96YO=FEA`%IO8G)A>F5N:64@
M;65N=3H`6FSZZ&F[(&)U;FMY`%-P<N%V80!3<'+A=F$@8F]L82#Z<W!EN6YE
M(&]V97)E;N$L(&%L92!C97)T:69I:^%T('!O9'!I<W4@<V$@;F5P;V1A<FEL
M;R!O=F5R:;LN`%!L871N;W.[('-P<N%V>2!V>7!RN6%L82X`5'EP('-P<N%V
M>0!0;^AA<VEE($UE=&%R`-ID86IE($UE=&%R(&YI92!S^B!D;W-T=7!NZ2X`
MVF1A:F4@365T87(@;FEE('/Z(&L@9&ES<&]Z[6-I:2X@1&5T86EL>2!B;VQI
M('IA>FYA;65N86[I('!R92!A9&UI;FES='+A=&]R82X`4WES=.EM($UE=&%R
M1$(@;FEE(&IE('!R:7!O:F5N_2X`365T\V1A`$UE=/-D82`B)7,B(&YI92!J
M92!D969I;F]V86[A`$YE9&5F:6YO=F%NX2!M973S9&$N(%9O;&%NZ2!Z(&UE
M=/-D>3H@)7,`365T<FEC:^D`365X:6-O`$UI:W)O;NEZ<VME(&9E9&5R873M
M=FYE(+ETX71Y`%-T<F5D`%1Y<"!-:6UE`$YA:FYIOKEI82!T97!L;W1A('IA
M('!O<VQE9&[]8V@@,C0@:&]D[6XZ(`!.86IN:;ZY:6$@=&5P;&]T82!Z82!P
M;W-L961N_6-H(#8@:&]D[6XZ(`!-:6YI;>%L;F$@9&]B82!P;&%T;F]S=&D@
M:&5S;&$@9;ET92!N979Y<'*Y86QA`%IR:V%D;&]V;R!O8G+A=&F[`%+T>FYE
M`$-H_6)A(&)A;.UK(%!%05(@2%144%]297%U97-T+@!#:/UB82!K;VYF:6=U
M<N%C:6$N($%K(&-H8V5T92!P;W6^[79ANR!T^G1O(&%P;&EKX6-I=2P@;75S
M[71E('1E<F%Z('9Y9V5N97)O=F&[(&MO;F9I9W5RX6-I=2X`0VC]8F$@240@
M<W!RX79Y+@!#:/UB82!P;[YA9&]V86[](%!%05(@8F%L[6L@36%I;"X`0VC]
M8F$@240@<F5LX6-I92X`4&]N`$UO8FEL;OT@;6%I;`!-:65R;GD`1.%T=6T@
M<&]S;&5D;F5J('IM96YY`%5P<F%V:;L@55),`$UO9'5L=7,`36]L9&%V<VMO
M`$UO;F%K;P!-;VYG;VQS:V\`365S:6%C(&$@<F]K`$UE<V'H;F4`36]N='-E
M<G)A=`!-97-AZ&[I(&;A>GD`3F$@<FEA9&MU("5D(&)O;&\@;N%J9&5N_6-H
M('9I86,@<&]L[2!A:V\@;^AA:^%V86[]8V@@)60N`$UA<F]K;P!0<F5V8;YN
M92!J87-N;P!0<F5V8;YN92!O8FQAZ&YO`%!R979AOFYE('-L;F7H;F\`4')E
M<W5N^KL@9&]L=0!0<F5S=6[ZNR!VM6%V;P!0<F5S=6[ZNR!V<')A=F\`4')E
M<W5N^KL@:&]R90!0<F5S=6[ZNR!D;VQU`%!R97-U;OJ[(&AO<F4`36]Z86)M
M:6L`5FEA8_IR;W;R;W;I('9Y8F5R86-I92!Z;WIN86UY`%9I86-NX7-O8F[]
M(';]8F5R`$UO:F4@:V]N=&\`26YF;W)MX6-I92!O(&UO:F]M(/KH=&4`3?1J
M('!O<G3A;`!6>FBU860@;?1J:&\@<&]R=.%L=0!->6%N;6%R`$YI92P@3D53
MVDA,05/-32X`365N;P!.86WM8FEA`$YA=7)U`$YE<.%L`$AO;&%N9'-K;P!(
M;VQA;F1S:^D@06YT:6QY`%KA:VQA9&[A(%523"!.971S8V%P90!54DP@<')E
M('IN97!L871N96YI92!C97)T:69I:^%T;W8@0T$@3F5T<V-A<&4`55),('!R
M92!P;VQI=&EK=2!#02!.971S8V%P90!54DP@<')E(&]B;F]V96YI92!P;&%T
M;F]S=&D@8V5R=&EF:6OA=&]V($YE='-C87!E`%523"!P<F4@>FYE<&QA=&YE
M;FEE(&-E<G1I9FEKX71O=B!.971S8V%P90!-96YO(%-33"!S97)V97)A($YE
M='-C87!E`$MO;65N=.%R(&-E<G1I9FEKX71U($YE='-C87!E`%1Y<"!C97)T
M:69I:^%T=2!.971S8V%P90!3:66[`$YI:V1Y`$YO=N$@2V%L963S;FEA`$YO
M=N$@:V%T96?S<FEA`$YO=N$@<W!RX79A('!R92`E<P!.;W8`3F]VZ2!P;W6^
M[79A=&6U<VOI(&UE;F\@*&YE<&]V:6YNZ2D`3F]V_2!:Z6QA;F0`3F]VZ2!H
M97-L;P!0;&%T;F]SNR!N;W;I:&\@:&5S;&$@=GEP<KGM("5X+@!.;W;I(&AE
M<VSA(&YI92!S^B!R;W9N86OI+@!.;W;I(&]K;F\@*%]B;&%N:RD`3F5W<P!$
M:7-K=7-NZ2!S:W5P:6YY`,]A;&5J`$YA<VQE9'5J^F-E(#0@9N%Z>0#/86RY
M:64@;F%S=&%V96YI80!.87-L961U:OIC83X`3FEK87)A9W5A`$YI9V5R`$YI
M9^ER:6$`3F]C`$YI=64`3FEE`$YI92!S^B!D;W-T=7!NZ2"^:6%D;F4@:V]N
M9FEG=7)AZ&[I(/ID86IE+"!P<F4@:W1O<ND@8GD@<V$@9&%L:2!Z;V)R87II
MNR!R;WID:65L>2X`4')E('9Y=';A<F%N:64@25-/(&]B<F%Z;W8@;FEE(&IE
M(&L@9&ES<&]Z[6-I:2"^:6%D;F$@<W1R873I9VEA+@!.965X:7-T=6IE(+EA
M8FSS;F$@<')E(&3A=FMU+@!.82!P;[YA9&]V86YE:B!P;WKM8VEI(&YE97AI
M<W1U:F4@OFEA9&5N(&)L;VLN`%!R92!-0T%,(&%U=&5N=&EF:6OA8VEU(&YE
M8F]L;R!Z861A;ND@;65N;R!K86QE;F3A<F$N`*YI861N82!Z;65N82X`2R!T
M;VUU=&\@<'+A=G4@;F5M;[YN;R!P<FED8;L@OFEA9&YE('!O9')I861E;ND@
M<'+A=F$N`%!R92`E<R!N96)O;&$@=7+H96[A(&MO;F9I9W5RX6-I82X`4')E
M($944"!61E,@;F5B;VQA('5RZ&5NX2!K;VYF:6=U<N%C:6$N`%!R92!344P@
M5D93(&YE8F]L82!U<NAE;N$@:V]N9FEG=7+A8VEA+@!0<F4@4U%,+49I;&4@
M5D93(&YE8F]L82!U<NAE;N$@:V]N9FEG=7+A8VEA+@"N:6%D96X@:W)E9&ET
M+@!.96)O;&\@N7!E8VEF:6MO=F%NZ2!M:65S=&\@=7+H96YI82X`4_IB;W(@
M;F5B;VP@;F%H<F%N_2X`3F5B;VQI(&[A:F1E;ND@OFEA9&YE(&EK;VYY+@!.
M:64@:F4@;F%S=&%V96[A(&QO:V%L:71A+@!.96)O;&$@>F%D86[A(&QO:V%L
M:71A+@!.96)O;&$@>F%D86[A(+YI861N82!S<'+A=F$N`$YE8F]L;R"Y<&5C
M:69I:V]V86[I(+YI861N92!M96YO+@!.96)O;&\@N7!E8VEF:6MO=F%NZ2#H
M[7-L;RX`KFEA9&YE('5RX;YL:7;I(&9O<G1U;GD`4')E($A45%`@875T96YT
M:69I:^%C:74@;F5B;VQO('IA9&%NZ2!H97-L;RX`4')E($E-05`@875T96YT
M:69I:^%C:74@;F5B;VQO('IA9&%NZ2!H97-L;RX`4')E($ME<F)E<F]S(&%U
M=&5N=&EF:6OA8VEU(&YE8F]L;R!Z861A;ND@:&5S;&\N`%!R92!,;V=I;B!A
M=71E;G1I9FEKX6-I=2!N96)O;&\@>F%D86[I(&AE<VQO+@!0<F4@4$%34U=$
M(&%U=&5N=&EF:6OA8VEU(&YE8F]L;R!Z861A;ND@:&5S;&\N`%!R92!334(@
M875T96YT:69I:^%C:74@;F5B;VQO('IA9&%NZ2!H97-L;RX`3F5B;VQA('IA
M9&%NX2!C97-T82!K('!R;V=R86UU($]P96Y34TPN(%!R;V=R86T@3W!E;E-3
M3"!J92!P;W1R96)N_2!N82!P<N%C=2!S(/ID86IM:2!02T-3(#$R+@"N:6%D
M;F4@<')E8FEE:&%J^F-E('!R:6ALX7-E;FEA+@!+=O-T82!N:64@:F4@;F%S
M=&%V96[A+@!"97H@Z&EA<@!.96)O;""Y<&5C:69I:V]V86[](&]D9&6U;W9A
MZ"X`0F5Z('-T<N%N`%/Z8F]R(&YE;N%J9&5N_0!0<F4@=GER;W9NX79A8VEU
M('!A;>2[(&YI92!J92!D;W-T=7!N_2"^:6%D96X@9&_H87-N_2!P<FEEZ&EN
M;VLN`$YE8F]L;R!O9&]S;&%NZ2!P;W6^[79A=&6U<VOI(&UE;F\@82]A;&5B
M;R!H97-L;RX`3F5B;VQI('9RX71E;ND@<&QA=&[I(%A-3"#Z9&%J90"N:6%D
M;F4@:&]D;F]T>0!6('#T=F]D;F5J(&MO;F9I9W5RX6-I:2!N96)O;&$@;N%J
M9&5NX2"^:6%D;F$@=F5R>FEA+B!6>6=E;F5R=6IT92!Z;F]V=2!K;VYF:6=U
M<N%C:74N`%8@:V]N9FEG=7+A8VEI(&YE8F]L82!NX6ID96[A(+YI861N82!V
M97)Z:6$N(%9Y9V5N97)U:G1E('IN;W9U(&MO;F9I9W5RX6-I=2X`KFEA9&5N
M`*YI861N92`H<&]UOFF[(&EM<&QI8VET;OH@:&]D;F]T=2D`3W-T<F]V($YO
M<F9O;&L`4V5V97)NX2!P;VQO9W6U80!3979E<F[I($UA<FGA;G-K92!O<W1R
M;W9Y`$[S<G-K;P!.97!L873M('!O`$YE<&QA=.T@<')E9`!.:64@:F4@861R
M97/A<@!.:64@:F4@:6UP;&5M96YT;W9A;NDN`$YE;F%S=&%V96[I`$YI92!J
M92!P;V1P;W)O=F%NZ2X`4&]Z;N%M:WD`3FGH(&YA('!R97IE<F%N:64L('9R
MX;MT92!S82!S<.2[+@!.;W9E;6)E<@#([7-L;P!0;^AE="!Z;F%K;W8`4&_H
M970@<W3E<&-O=@!0;^AE="!R:6%D:V]V`%!R92!A:W1U86QI>N%C:74@>F]Z
M;F%M=2!P<NUJ96UC;W8@;F5B;VQI(+EP96-I9FEK;W9A;ND@Z.US;&$N`$]+
M`$]B:F5K=`!!=71O<B!O8FIE:W1U`$]S;6GH:V]V_0!/:W3S8F5R`$9I;'1E
M<B!N82!N863A=FMY`%!R86-O=FES:V\`4W1A<ND@82!N;W;I(&AE<VQO(&UU
M<VEA(&)YNR!O9&QIN6[I+@!3=&%RZ2!H97-L;P!3=&%RZ2!H97-L;R!N96)O
M;&\@>F%D86[I('-P<N%V;F4N`$]MX6X`26)A($E-05`@<V5R=F5R>2!P;V1P
M;W)U:OH@>F1I9;5A;ND@<')I9>AI;FMY+@!)8F$@=7+AOFQI=ND@9F]R='5N
M>0!*92!P<NUP=7-T;N$@:6)A(&IE9&YA(&4M;6%I;&]VX2!A9')E<V$N`%9L
M87-T;NUK82!A;&5B;R!P<N%V82!V;&%S=&[M:V$@<')E('ID:66U86[](&]B
M:F5K="!M]+YE('IM96YINR!I8F$@=FQA<W1N[6L@86QE8F\@<WES=.EM;W;]
M(&%D;6EN:7-T<N%T;W(`3W1V;W)INR!V(&YO=F]M(&]K;F4`0VAY8F$@3W!E
M;E-33#H@;F5P;V1A<FEL;R!S82!Z[7-K8;L@^F1A:F4@>B!P;V1P[7-A;F5J
M(.AA<W1I(%,O34E-12X`3W1V;W)INR!T^G1O(&QI;FMU('8@;F]V;VT@;VMN
M90!/<&5R8>AN_2!S>7-TZ6T`3F%S=&%V96YI80!.87-T879E;FEA("5S`%IO
M<F%D96[]('IO>FYA;0!/<F=A;FEZX6-I80!/<F=A;FEZ8>ANX2!J961N;W1K
M80!/<F=A;FEZ;W9A;FEE`%#T=F]D;N$@N6%B;/-N82!A<&QI:^%C:64`4/1V
M;V1NZ2"Y86)L\VYY('8@)7,Z`$ENZ0#/86RY:64@:6YF;W)MX6-I90!0<N%V
M82!V;&%S=&[M:V$`4$%-(&%U=&5N=&EF:6OA8VEA(&YI92!J92!D;W-T=7!N
MX2X`4$5!4CI-86EL(&)A8VME;F0`1&EG:73A;&YY('!O9'!I<R!01U``VF1A
M:F4@>F&Y:69R;W9A;ND@<&]M;V-O=2!01U``4$=0('9E<F5J;OT@:[7ZZ`#:
M9&%J92!P;V1P[7-A;NDO>F&Y:69R;W9A;ND@<&]M;V-O=2!01U``4$A0(&OS
M9`!02%`@4VAE;&P`4&]P;VQU9&[M(+5A:&O](&3AON\`4&]P;VQU9&[M('!R
M96CA;FMY`%!O<&]L=61N[2!S;F6^96YI90!0;W!O;'5D;NT@<VYE:&]VZ2!P
M<F5HX6YK>0!0;W!O;'5D;NT@<VYEOF5N:64`4&]P;VQU9&[M(&+Z<FMY`$-H
M_6)A(')O>KGM<F5N:64@4$]325@`4%](4"!3:&5L;`!6>7!L;F5N:64`4&%K
M:7-T86X`4&%L875S:^D@;W-T<F]V>0!086QE<W3M;G-K92#Z>F5M:64`4&%N
M86UA`%!A<'5A($YO=N$@1W5I;F5A`%!A<F%G=6%Y`,AI87-T;^AN92!O8FQA
MZ&YO`$AE<VQO`$AE<VQO(&)O;&\@^G-P9;EN92!Z;65N96[I+@!.97-P<N%V
M;F4@:&5S;&\`4')E(&%U=&5N=&EF:6OA8VEU(%)!1$E54R!J92!V>;YA9&]V
M86[I(&AE<VQO+@!(97-L;R!S('!O='9R9&5N[6T`2&5S;&\Z`$AE<VQO.B``
M2&5S;.$@;75S:6$@8GF[(')O=FYA:^DN`%9L;[YINP!6;&^^:;L@>F\@<V-H
M<N%N:WD`0V5S=&$`4')E8FEE:&%J^F-E(')E9VES='+A8VEE.@"E=61I80!0
M97)C96YT`%9Y:V]N8;L@;W!E<N%C:64@^F1ROF)Y`%9Y:V]N8;L@;W!E<N%C
M:64@^F1ROF)Y('!R:2!P<FEH;.%S96[M/P!0<N%V;P!0<N%V;R`B)7,B(&YE
M8F]L;R!V>6UA>F%NZ2X`4'+M<W1U<"!Z86UI971N=73]`%!RX79A`$%D;6EN
M:7-T<N%C:6$@<'+A=@!/<V]B;ND@:6YF;W)MX6-I90!097)U`$1O;>%C92!Z
M=FEE<F%TX0!&:6QI<.UN>0!496QE9O-N`$9O=&]G<F%F:64`4&ET8V%I<FX`
M0F]D;W8`2VQI:VYI=&4@<')O<^UM(&1O(&YE:F%K96H@8G5N:WD`4&]T=G+O
M=&4@<')O<^UM+""^92!C:&-E=&4@;V1S='+A;FF[('1E;G1O(&5L96UE;G0Z
M`%!O='9R[W1E('!R;W/M;2P@OF4@8VAC971E(&]D<W1RX6YINR!L:6YK=2!Z
M('1O:'1O(&5L96UE;G1U+@!:861A:G1E('!R;W/M;2!M97-I86,@82!R;VLN
M`%IA9&%J=&4@<')O<^UM(&UE;F\@<')E(&YO=OH@:V%T96?S<FEU.@!:861A
M:G1E('!R;W/M;2!P;&%T;OH@25`@861R97-U+@!:861A:G1E('!R;W/M;2!P
M;&%T;OT@9.%T=6TL('-K;VYT<F]L=6IT92!P;^AE="!D;NT@=B!M97-I86-I
M+@!:861A:G1E('!R;W/M;2!P;&%T;OT@Z&%S+@!0<F]S[6T@=79E[W1E('IH
M<FYU=&EE('!R;V)LZ6UU+@!0<F]S[6T@>F%D86IT92!S=F]J92!P;W6^[79A
M=&6U<VOI(&UE;F\@82!H97-L;P!0<F7H[71A:G1E('-I('!R;W/M;2!N87-L
M961U:OIC:2!T97AT+B!-55/-5$4@<_IH;&%S:;L@<R!P;V1M:65N:V%M:2!P
M;W6^[79A;FEA('-Y<W3I;74N`%IA9&%J=&4@<')O<^UM(&UE;F\@<')E(&YO
M=OH@:V%T96?S<FEU.@!0;[5S:V\`4&]L:71I:V$`06YK971Y`%!O<G1U9V%L
M<VMO`%5M:65S=&YE;FEE('1O:'1O(&]B<N%Z:W4`56UI97-T;F5N:64@=&5J
M=&\@=&%B=;5K>0!/9&]S;&&[(&1O('1O:'1O('!R:67H:6YK82`H;F5V>6YU
M8W5J92!)34%0*0!:<N&^:WD@>F$@<&]S;&5D;OUC:"`E<R!H;V3M;CH@`%!R
M879D97!O9&]B;F]SNSQB<B`O/GIRX;YO:P!0<F5F<U]L9&%P.B!P;[YA9&]V
M86[I(')O>KGM<F5N:64@3$1!4"!N96)O;&\@;N%J9&5NZ2X`4')E9G-?<V5S
M<VEO;CH@<&^^861O=F%NZ2!R;WJY[7)E;FEE('-E<W-I;VX@;F5B;VQO(&[A
M:F1E;NDN`%1L86L`5&QA:R!N82#Z<F]V;FD@;6]R83H@`%1L86LZ(`!5:^&^
M:V$`6F]B<F%Z:;L@=6OAOFMU(&]B<N%Z:W4@=B!N;W9O;2!O:VYE`%!R961C
M:.%D>F%J^F-E(&YA<W1A=F5N:6$`5GET;&'H:;L@9&]K=6UE;G0`4')I=N%T
M;GD@:[7ZZ`!0<F]B;.EM`%!O<&ES('!R;V)LZ6UU`%!R;VIE:W1Y`%;]>G9A
M(&YA('IA9&%N:64@=&5X='4`5F5R96IN_2!KM?KH`$%L9V]R:71M=7,@=F5R
M96INZ6AO(&NU^NAA`$EN9F]R;>%C:64@;R!V97)E:FYO;2!KM?KH:0!697)E
M:F[]+W!R:7;A=&YY(&NU^NAO=OT@<.%R(&YE8F]L(/IS<&6Y;F4@=GEG96YE
M<F]V86[]+@!0;W)T;W)I:V\`2V%T87(`1&]T87H`2W;S=&$`4E-!('9E<F5J
M;OT@:[7ZZ"`H)60@8FET;W8I`%!R97#M;F'H(',@=OUB97)O;0!$X;[O`%+A
M;F\@9.&^[P!.97-K]'(@9.&^[P!$8;[O;W;I('!R96CA;FMY`$3AON\@<V\@
M<VYE:&]M`$3AON\@<')E8VCA9'IA:OIC:2!V('-N9;YE;FEE`$[A:&]D;N$@
M9F]R='5N80!0;VUE<@#([71ANP#([71ANR!S<'+A=GD`3F%O>F%J('9Y;6%Z
M8;L@)7,_(%3Z=&\@;W!E<N%C:74@;F5M;[YN;R!V<N%T:;L@<W#DNRX`3F%O
M>F%J('9Y;6%Z8;L@<&]UONUV871EM7-KZ2#Z9&%J92!P<F4@<&]UONUV871E
MM6$@)7,_(%3Z=&\@;W!E<N%C:74@;F5M;[YN;R!V<N%T:;L@<W#DNRX`5G+A
M=&D@<W#DNR!68;EU('!O<VQE9&[Z(&%K8VEU`$]B;F]V:;L`3V)N;W9INR!E
M;&5M96YT>2!D>6YA;6EC:^EH;R!M96YU.@!/8FYO=FF[('IO8G)A>F5N:64@
M<&]R=.%L=3H`4F5G=6SA<FYY(';]<F%Z`%!R96AL:6%D8>@@=GJ[86AO=@!:
M;F]V=2!N8>CM=&&[`%!O<W1R96AY`%9Z9&EA;&5NZ2!S97)V97)Y`%9Z9&EA
M;&5NX2!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!/9'-T
M<N%N:;L`3V1S='+A;FF[(&)L;VL`3V1S='+A;FF[('-TY7!E8P!/9'-T<N%N
M:;L@9F]R;>%T;W9A;FEE`$]D<W1RX6YINR!PX7(`3V1S='+A;FF[('5L;[YE
M;OT@<VMR:7!T('H@9&_H87-NZ6AO('!R:67H:6YK82!N82!S97)V97)I+@!/
M9'-T<N%N:;L`3V1S='+A;FF[('1E;G1O(&)O9"!Z(&1O:W5M96YT=0!/9'-T
M<N%N:;L@<&]UONUV871EM6$`3V1S='+A;FF[('!O=;[M=F%T9;5A.B`E<P!.
M82!P;[YI861A=FMU(&YE8F]L;R!M;[YNZ2!O9'!O=F5D8;LN($[A=G)A=&]V
M_2!K\V0@8VAY8GDZ(`!0;[YA9&]V86[Z('-L=;YB=2!S82!N97!O9&%R:6QO
M(&[A:G.[+@!6(&MO;F9I9W5RX6-I:2`E<R!N:64@:F4@N7!E8VEF:6MO=F%N
MX2!P;[YA9&]V86[A('!O;&^^:V$@(B5S(@!6(&MO;F9I9W5RX6-I:2!61E,@
M;FEE(&IE(+EP96-I9FEK;W9A;N$@<&^^861O=F%NX2!P;VQOOFMA("(E<R(`
M5B!K;VYF:6=U<N%C:6D@;FEE(&IE(+EP96-I9FEK;W9A;N$@<&^^861O=F%N
MX2!P;VQOOFMA("(E<R(`4&]V:6YNZ2!P;VQE`%9Y;6%Z8;L@9F]R;75LX7(`
M3V)N;W9INR!H97-L;P!/8FYO=FF[(%9AN64@:&5S;&\`3V)N;W9INR!P;W-L
M961N_2!D;W1A>@!6_7-L961K>0!.X79R870@;F$@;F%S=&%V96YI80!:861A
M:G1E(&YO=ND@:&5S;&\`4F5U;FEO;@!6<N%T:;L@:V]N9FEG=7+A8VEU`$YA
M<W1A=F5N:6$@<F]ZN>UR96[I:&\@=&5X=&]VZ6AO(&5D:71O<G4`2.%D86YK
M>0!6<')A=F\`2&QA=FGH:V$@=G!R879O`$AO9&YO='D@=G!R879O`%9L87-T
M;F]S=&D@7W)I861K82XN+@!2;VQA`%)U;75N<VMO`$]T;^AINR!O(#$X,`!/
M=&_H:;L@=K5A=F\`3W1OZ&F[('9P<F%V;P!6;&%S=&YO<W1I(')I861K80!6
M;&%S=&YO<W1I(')I861K80!2:6%D:WDZ`,AI87)Y`,AI87)Y('-A('IO8G)A
M>FEA(&UE9'II(':Y971K_6UI(')I861K86UI(&$@<W3E<&-A;6D`R&EA<GD@
M<V$@>F]B<F%Z:6$@:6)A(&UE9'II('-TY7!C86UI`,AI87)Y('-A('IO8G)A
M>FEA(&EB82!M961Z:2!R:6%D:V%M:0!3<'5S=&F[`%)U<VOA(&9E9&5RX6-I
M80!2=V%N9&$`4R]-24U%(&MR>7!T;V=R869I8VO]('!O9'!I<P!3<'+A=F$@
M>F&Y:69R;W9A;N$@<&]M;V-O=2!3+TU)344`4T%33"!A=71E;G1I9FEKX6-I
M82!N:64@:F4@9&]S='5P;N$N`%!O<VEE;&%N:64@4TU3`%-13"!3:&5L;`!3
M44P@<'+M:V%Z('!R92!HM6%D86YI92!H;V1N]'0`4U-(`-I34$5#2`!37U%,
M(%-H96QL`%-O`%-VY'3A($AE;&5N80!3=N1T_2!+:71T<R!A($YE=FES`%-V
MY'3A($QU8VEA`%-V+B!0:65R<F4@82!-:7%U96QO;@!3=N1T_2!6:6YC96YT
M(&$@1W)E;F%D:6YY`%1E;B!I<W3]('+A;65C("A?<V5L9BD`4V%M;V$`4V%N
M($UA<FEN;P!386\@5&]M92!A(%!R:6YC:7!E`%-A=&5L:71N_2!P;W-K>71O
M=F%T9;4`4V%U9'-KX2!!<N%B:6$`56QOOFF[`%5L;[YINR`B)7,B`%5L;[YI
MNR`E<P!5;&^^:;L@;F%S=&%V96YI80!5;&^^:;L@=GEG96YE<F]V86[Z(&MO
M;F9I9W5RX6-I=2!A:V\@4$A0('-K<FEP="!D;R!D;^AA<V[I:&\@<')I9>AI
M;FMA(%;AN6AO('-E<G9E<F$N`$MO;F9I9W5RX6-I82`E<R!B;VQA('5L;[YE
M;N$N`%-K<FEP="!N82!U<&=R861E(&YA<W1A=F5N[2!B;VP@=6QOOF5N_2!D
M;SH@(B5S(BX`3VIE9&EN96SI(&+Z<FMY`%9E9&$`2+5A9&&[`%9Y:+5A9.%V
M8>AE`%9Y8F5R=&4@<_IB;W)Y`%9Y8F5R=&4@9.%T=6T`5GEB97)T92!S:W5P
M:6YU(&YA('!R:61A;FEE`%9Y8F5R=&4@;F]VZ6AO('9L87-T;NUK80!6>6)E
M<G1E('-E<G9E<@!6>6)E<G1E('!O=;[M=F%T9;5A(&YA('!R:61A;FEE`%9Y
M8F5R=&4@=KEE=&MY`%9Y8F5R=&4@=KEE=&MY(&MO;7!O;F5N='D@9.%T=6UU
M`%9Y8F5R=&4@;V)J96MT`%IR=;EINR!V_6)E<@!6>6)E<G1E('IN86MY+"!K
M=&]RZ2!P;W1R96)U:F5T92P@>B!O:VEE;F]K(&YIOKEI92X@4&]T;VT@:6-H
M(&WTOF5T92!S:V]P[7)O=F&[(&$@=FQOOFF[('H@=&5X=&]VZ6AO('!OM6$N
M`%9Y8F5R=&4@;V1D9;5O=F'H('9O(&9O<FWA=&4@9.%T=6UU.@!6>6)E<G1E
M(&9O<FWA="!DX71U;74Z`%9Y8F5R=&4@:61E;G1I='4L(&MT;W+Z(&-H8V5T
M92!Z;65N:;LZ`%9Y8F5R=&4@;V1D9;5O=F'H('9O(&9O<FWA=&4@Z&%S=3H`
M5GEB97)T92!F;W)MX70@Z&%S=3H`5GEB97)T92!D=F4@>FAO9&[I('!O;&EA
M+@!6>6)E<G1E('-I(&9A<F5B;OH@<V-HZ6UU`%9Y8F5R=&4@:F%Z>6LZ`%!O
M<VQANR!S<'+A=G4@;R!P<F]B;.EM90!0;W-L8;L@4TU3`%-E;F5G86P`4V5N
M>F]R.B``4V5P=&5M8F5R`%-R8G-K;R!A(,AI97)N82!H;W)A`%/I<FEO=ND@
MZ.US;&\`VF1A:F4@>F\@<V5R=F5R82!S^B!N97-P<N%V;F4@86QE8F\@;FEE
M('/Z(&1O<W1U<&[I+@!!9&UI;FES='+A8VEA('-E9&5N[0!0;&%T;F]SNR!)
M1"!S961E;FEA('9Y<'*Y86QA+@!3961E;FEA`$UN;[YI;F$@:&]D;O1T`$YA
M<W1A=G1E(&UOOFYO<W1I(&YA(&]B;F]V96YI92!6X;EH;R!H97-L82!A:R!H
M;R!Z86)U9&YE=&4N`$YA<W1A=F5N:64@=GID:6%L96[]8V@@<V5R=F5R;W8L
M(&MU(&MT;W+];2!C:&-E=&4@<')I<W1U<&]V8;L@>B!6X;EH;R!P;W)TX6QU
M+@!6>6)E<G1E(&IA>GEK+"#H87-O=OH@>O-N=2!A(&YA<W1A=F5N:6$@9.%T
M=6UU+@!.87-T879E;FEE(&%P;&EKX6-I92!S</JYNV%N96H@<')I(+ET87)T
M92P@9F%R96)N96H@<V-HZ6UY+"!I;G1E<G9A;'4@;V)N;W9O=F%N:6$@<W1R
MX6YK>2!A(&EN_6-H('9L87-T;F]S=.T@>F]B<F%Z96YI82X`3F%S=&%V96YI
M90!3^B!D;W-T=7!NZ2!S:W)I<'1Y(&YA('5P9W)A9&4@;F%S=&%V96[M`$1O
M(/IV86AY('!R:6-HX61Z82!N:65K;[5K;R!L;VMA;.UT('!O;6]C;W4@<&%R
M86UE=')A.B``4V5Y8VAE;'D`4VAO<'!I;F<`2W+A=&MY('/Z:')N`$UA:OH@
M<V$@<')E(';DZ+EI;G4@;&EN:65K('9Y='9O<FF[('-K<F%T:V]VZ2!K;.%V
M97-Y/P!:;V)R87IINP!:;V)R87IINR!R;WID:65L>2!M961Z:2!P<N%V92!U
M;&^^96YO=2!A(&YO=F]V>6=E;F5R;W9A;F]U(&MO;F9I9W5RX6-I;W4N`$WA
M('-A('!R:2!P<FEH;.%S96[M('IO8G)A>FF[(.AA<R!P;W-L961NZ6AO('!R
M:6ALX7-E;FEA/P!:;V)R87IINR!M;[YN;W.[(&YA('!O;F5C:&%N:64@;W)I
M9VENX6QU`%IO8G)A>FF[(&[A<W1R;VH@;F$@=OUB97(@9F%R:65B`%IO8G)A
M>FF[(&UE;G4@<')E(&]P97+A8VEE(',@=&%B=;5K86UI/P!:;V)R87IINR!M
M96YU("5S(&YA(+5A=F5J('-T<F%N93\`6F]B<F%Z:;L@9&EA;/-G(',@=FQA
M<W1N;W.[86UI(&)U;FMY('1A8G6U:WD`6F]B<F%Z:;L@9&EA;/-G(',@=FQA
M<W1N;W.[86UI('1A8G6U:WD`6F]B<F%Z:;L@9&EA;/-G(',@=FQA<W1N;W.[
M86UI(')I861K=2!T86)UM6MY`%IO8G)A>FF[(&1I86SS9R!S('9L87-T;F]S
MNV%M:2!O8G+A>FMU`%IO8G)A>FF[(&YA:')A;ND`4')E:.%N:WD`4N%N;R!P
M<F5HX6YK>0!.97-K]'(@<')E:.%N:WD`6G+AOFMY('8@;VMO;.T`6FUE;KEI
MNP!.86IP<G8@;75S[71E('IM96ZY:;L@86QE8F\@<')E<W5N^KL@<W5S961N
M_2!B;&]K*'DI`%-I97)R82!,96]N90!:87)E9VES=')O=F&[('-A`%!O9'!I
M<P!!;&=O<FET;75S('!O9'!I<W4`4VEN9V%P=7(`5F6U:V]SNP!0<F5S:V_H
M:;L@^F1ROF)U`%-L;W9E;G-K;P!3;&]V:6YS:V\`4VYEOF5N:64`4VYE:&]V
MX2!P<F5HX6YK80!3;F5H;W;I('!R96CA;FMY`%+A;F\@<VYE:&]VZ2!P<F5H
MX6YK>0!.97-K]'(@<VYE:&]VZ2!P<F5HX6YK>0!(Y6)K82!S;F5H=3H@`$UN
M;[YS='9O('9O9'D@96MV:79A;&5N=&[I('-N96AU.B``J6%L86WZ;F]V92!O
M<W1R;W9Y`%-O;>%L<VMO`%!I97-N92!A(&+A<VYE`%;]8F5R('-M97)U('1R
M:65D96YI80!:9')O:F]VX2!A9')E<V$`2G6^;N$@069R:6MA`$IUOF[A($=E
M;W)G:6$@82!3;W5T:"!386YD=VEC:"!)<VQA;F1S`$IUOF[A('!O;&]G=;5A
M`$UE9'IE<F$@;65D>FD@<W5S961N_6UI(&)U;FMA;6D`365D>F5R82!M961Z
M:2!O8G-A:&]M(&$@;VMR86IO;2!B=6YK>0!/9&1EM6]V8>@`3V1S='5P`$]D
M<W1U<"!A('9Y<&QN96YI90"I<&%N:65L<VMO`%-P86T`5FQOOF5N:64@N7!E
M8VGA;&YY8V@@>FYA:V]V`%)O>F1E;&F[(&)U;FMU`%)O>F1E;&F[('-TY7!E
M8P!2;WID96QINR!R:6%D;VL`J7!O<G1Y`%-R[2!,86YK80"I=&%N9&%R9&[I
M`%-T87(@5')E:P!0;^AI871OZ&[](')O:P"I=.%T(&%L96)O('!R;W9I;F-I
M80!3=&%V`$9O<FWA="!U;&^^96YI80!">61L:7-K;P!0<F6Y:W)T;G5TZ0!:
M;WIN86T@<F6[87IC;W8`3V1S='+A;FF[(&1O;>EN=2!Z(&%D<F5S>0"I=/UL
M(%M#4U-=`$YE`%!O9'!R:67H:6YO:R`B)7,B(&YE8F]L(&[A:F1E;OTN`%!R
M961M970`3V1O<VQANP!0;[YI861A=FMA(&YA('!R:61A;FEE("(E<R(@9&\@
M<WES=.EM=2!B;VQA(&]D;W-L86[A+B!.96WTOF5T92!S82!P<FEH;.%S:;LL
M(&O];2!N96)U9&4@5F&Y82!P;[YI861A=FMA('-C:';A;&5NX2X`1&]L;OT@
M:6YD97@`VG-P96-H`%!R:61A;FEE("(E<R(@9&\@<WES=.EM=2!B;VQO(/IS
M<&6Y;NDN`%9Y;6%Z86YI92#Z9&%J;W8@>F\@<WES=.EM=2!P<F4@<&]UONUV
M871EM6$@(B5S(B!B;VQO(/IS<&6Y;NDN`%9Y;6%Z86YI92`B)7,B(&)O;&\@
M^G-P9;ENZ2X`5GEM87IA;FEE("(E<R(@>F\@<WES=.EM=2!B;VQO(/IS<&6Y
M;NDN`$[A=G)A="!K=2!K;VYF:6=U<N%C:6D@8F]L(/IS<&6Y;OTN(%!R92!Z
M;V)R87IE;FEE('IM:65N('IN;W9U(&YAZ.UT86IT92!S='+A;FMU+@!:X6QO
M:&$@:V]N9FEG=7+A8VEE(&)O;&$@=6QOOF5NX2X`6N%L;[YN_2!K;VYF:6=U
M<F'H;OT@<_IB;W(@)7,@8F]L(/IS<&6Y;F4@=6QOOF5N_2X`06MT=6%L:7KA
M8VEA("(E<R(@8F]L82#Z<W!EN6[A+@!:X7!I<R`E<R!B;VP@^G-P9;EN_0!3
M=63A;@!3^FAR;@!6_6-H;V0@<VQN:V$`6N%P860@<VQN:V$`4VQN9>AN;P!6
M_6-H;V0@<VQN:V$`5OUC:&]D+WKA<&%D('-L;FMA`%;]8VAO9"!S;&YK83H@
M`%KA<&%D('-L;FMA`%KA<&%D('-L;FMA.B``2&]R;OT@:6YD97@`4&]D<&]R
M80!3=7)I;F%M`%!R:65Z=FES:V\`4W9A;&)A<F0@82!*86X@36%Y96X`4W9A
M>FEJ<VMO`*EVZ61S:V\`J79A:NAI87)S:V\`6N%Z;F%M>2!O('-Y;F-H<F]N
M:7KA8VEI('9Y;6%Z86[I`%-Y;F--3`!3>6YT86MT:6-KX2!C:'EB82!V('!O
M9&UI96YK86-H(&BU861A;FEA`%/]<FEA`$+Z<FMA`$+Z<FMA(&$@=F5T97)N
M;P!"^G)K>0!2X6YO(&+Z<FMY`%135B!S^F)O<@!486)UM6MA`%9L87-T;F]S
M=&D@=&%B=;5K>0!6;&%S=&YO<W1I('1A8G6U:WD`5&%I=V%N`%1A:7=A;BP@
M<')O=FEN8VEA(,CM;GD`5&%DOFEK:7-T86X`5&%N>N%N:6$`0VEEM3H`VFQO
M:'D`5&5L96;S;FYE(.CM<VQO`%1E<&QO=&$@>F$@<&]S;&5D;OH@:&]D:6YU
M.B``5&5P;&]T80!497!L;W1A.B``5&5P;&]T83QB<B`O/B@E<TUA>"5S+R5S
M36EN)7,I("9D96<[)7,`J6%B;/-N82`B)7,B(&YE8F]L82!NX6ID96[A+@!3
M<'+A=F$@N6%B;/-N`%1E>'0`26)A('1E>'0`6F%R;W9N86YI92!T97AT=0!4
M97AT(&AO<F4`J70`5&AA:G-K;P!2;WJY[7)E;FEE($944"!N:64@:F4@9&]S
M='5P;NDN`$EN=&5G<N%C:6$@2&]R9&4O2V]L86(@;F5P;V1P;W)U:F4@(B5S
M(@!)35-0('KA>FYA;2!S82!N97!O9&%R:6QO('5L;[YINRX`5')I961A($UA
M:6YT96YA;F-E.CH@<V$@;F5N8>CM=&%L82#Z<W!EN6YE`$]K;F\@<R!N87-T
M879E;FEA;6D@<V$@>F%T=F]R:6QO+B!+;VYI96,N`$%D;6EN:7-T<N%T;W(@
M;75S[2!N86MO;F9I9W5R;W9ANR!P97)M86YE;G1N_2!B86-K96YD('!R92!0
M<N%V82P@86L@8VAC971E('!O=;[M=F&[(%!RX79A+@!)8F$@<W!O9&[A('-T
M<F%N80!)1"#H[7-L;R!K;VYT86MT=2!N96)O;&\@N7!E8VEF:6MO=F%NZ2P@
M8F]L;R!P;VYE8VAA;ND@<'+A>F1N92!A;&5B;R!N96)O;&\@;N%J9&5NZ2!V
M(&1A=&%BX7IE+@!+;VYT86MT(&)O;"#Z<W!EN6YE('9L;[YE;OT@9&\@5N&Y
M:&\@861R97/A<F$N`$YA(&]V97)E;FEE('!O9'#M<V%N96H@<W!RX79Y(&IE
M('!OOF%D;W9A;OT@;V1D96QE;OT@8FQO:R!S(%!'4"!P;V1P:7-O;2X`240@
M>F]Z;F%M=2!P<NUJ96UC;W8@8G7O(&YE8F]L;R"Y<&5C:69I:V]V86[I+"!A
M;&5B;R!B;VQO('!O;F5C:&%NZ2!P<N%Z9&YE(&%L96)O(&YE8F]L;R!NX6ID
M96[I('8@9&%T86+A>F4N`$YE8F]L('5RZ&5N_2!Z;WIN86T@<'+M:F5M8V]V
M+@"I:69R;W9A;FEE('9YOF%D=6IE(&)E>G!EZ&[I('!R:7!O:F5N:64@*&AT
M='!S*2X`4_IB;W(@)7,@8GD@;6%L(&]B<V%H;W9ANR!N87-T879E;FEE("5S
M+@!3^F)O<B`E<R!B>2!M86P@;V)S86AO=F&[(&YI96MT;W+I(&YA<W1A=F5N
M:6$@)7,N`%ID<F]J;W;](&$@8VEEM6]V_2!S^F)O<B!M=7-I82!B>;L@;V1L
M:;ENZ2X`4_IB;W(@;F5O8G-A:&]V86P@OFEA9&YE(/ID86IE+@!.87-L961U
M:OH@:&QA=FGH:WD@=&5J=&\@<W!RX79Y('9O(&9O<FWA=&4@;65S<V%G92]R
M9F,X,C(N`$-E;&]O8G)A>F]V:V]V_2!R9;YI;2!S</1S;V)U:F4@<')O8FSI
M;7D@=B!);G1E<FYE="!%>'!L;W)E<FD@:W;T;&D@8VAY8N%M('!R96AL:6%D
M8>AA+"!K=&]RZ2!S82!NX6T@;F5P;V1A<FEL;R!O8NUSNRX@3?2^=2!S82!P
M<F5J879INR!N97-P<N%V;GEM('IO8G)A>F5N[6TL(&-H_6)A:OIC:6UI(&9U
M;FMC:6%M:2!E9&ET;W)A(&$O86QE8F\@;N%H;V1N_6UI('#A9&UI('!R96AL
M:6%D8>AA+B!!:R!J92!6X;D@<WES=.EM(%=I;F1O=W,@.7@L(&IE('9EM6UI
M('!R879D97!O9&]B;NDL(+YE('-A('IO8G)A>NT@8VAY8F$@)T=E;F5R86P@
M4')O=&5C=&EO;B!&875L="<@82!B=61E=&4@;75S:66[(')EN71A<G1O=F&[
M('!OZ.UT8>@N7&Y<;E9A<F]V86QI('-M92!6X7,N(%-T;&'H=&4@<')O<^UM
M($]+(&%K(&YA;WIA:B!C:&-E=&4@<&]UOFF[(&5D:71O<B!V(&-E;&]O8G)A
M>F]V:V]V;VT@<F6^:6UE+@!)9&5N=&ET82`B)7,B(&)O;&$@=GEM87IA;N$N
M`$EB82"U87;A('-T<F%N80!4<FEE9&$@0W)Y<'1?<&=P.CH@<&]T<F5B=6IE
M('!O>FYANR!U;6EE<W1N96YI92!P<F]G<F%M=2!';G501RX`4W!RX79A(&]D
M;W-L86[A("5S('!R92`E<R!S('!R961M971O;2`B)7,B(&)O;&$@>F]B<F%Z
M96[A+@I.965X:7-T=6IE(':Y86L@>N%R=6MA+""^92!S<'+A=F$@8F]L82!P
M<F7H[71A;N$@86QE8F\@<&]C:&]P96[A+@!-96YO+"!K=&]RZ2!S82!MX2!P
M;W6^:;L@<')I(&QI;FMO=F%N[2!N82!S='+A;FMU(&YA('#M<V%N:64@<W!R
MX78@`%!OZ&5T('!O;.T@;75S[2!B>;L@Z.US;&\N`%1R:65D82!(;W)D95]#
M<GEP=%]S;6EM93HZ('9YOF%D=6IE(&UO9'5L(&]P96YS<VPN`$YA<W1A=F5N
M:64@(B5S(B!S82!N97!O9&%R:6QO('5L;[YINRP@<')E=&^^92!J96AO(/ID
M86IE('!R96MR8>AU:OH@;6%X:6WA;&YU('!O=F]L96[Z('9EM6MO<[L`4')O
M9W)A;2!P;W6^[79A;OT@;F$@>F]B<F%Z96YI92!T;VAT;R#Z9&%J;W;I:&\@
M='EP=2`H)7,I(&YE8F]L(&[A:F1E;OTN`%IN86L@8VETX6-I92!M=7/M(&)Y
MNR!J961E;B!Z;F%K+@!)8F$@<')A=N$@82"U87;A('-T<F%N80!)8F$@<')A
M=N$@<W1R86YA`$]D9&6U;W9AZ"!M=7/M(&)YNR!J961E;B!Z;F%K+@!397)V
M97(@(B5S(B!B;VP@=GEM87IA;OTN`%-E<G9E<B`B)7,B(&)O;"!U;&^^96[]
M+@"N:6%D;W.[(&\@<')I:&SA<V5N:64@)7,@8F]L82!V>6UA>F%NX2X`J7!E
M8VEF:6MO=F%N_2!R:6%D;VL@;F5E>&ES='5J92X`1&_H87-N_2!S^F)O<B`B
M)7,B(&YE97AI<W1U:F4N`%IA9&%N_2!T97AT(&YI92!J92!R;W9N86O](&%K
M;R!T97AT(&YA(&]B<F%Z;W9K92X`26)A(&AO<F[A(&$@<W!O9&[A('-T<F%N
M80!)8F$@:&]R;N$@<W1R86YA`$YA:')A;ND@^F1A:F4@<V$@;V0@<')E9&-H
MX61Z86KZ8V5H;R!K<F]K=2!S=')A=&EL:2X`3F%H<F%N_2!S^F)O<B!S82!N
M97!O9&%R:6QO('5L;[YINRX`0FQO:R!W96%T:&5R+F-O;2!N:64@:F4@9&]S
M='5P;OTN`%!R:67H:6YO:R!TZ6T@(B5S(B!N96)O;"!NX6ID96[]+@"N:6%D
M;F4@;F%S=&%V96YI82!N:64@<_H@9&]S='5P;NDN`*YI861N92!A;'1E<FYA
M=.UV;F4@Z&%S=&D@;F5M;[YN;R!Z;V)R87IINR!V('1E;&4@<W!RX79Y+@!6
M('1O;71O('!O;&D@:F4@<'+M;&FY('9EM6$@>FYA:V]V+B!:861A;&D@<W1E
M("5S('IN86MO=CL@;75S[71E('IA9&&[(&UE;F5J(&%K;R`E<RX`3F%S=&%L
M82!C:'EB82!P<FD@<')I9.%V86[M("(E<R(@9&\@<WES=.EM=3H@)7,`3F%S
M=&%L82!C:'EB82!P<FD@;V1S=')A\F]V86[M('!O=;[M=F%T9;5S:_UC:"#Z
M9&%J;W8@(B5S(B!Z;R!S>7-TZ6UU.B``3F%S=&%L82!C:'EB82!P<FD@;V1S
M=')A\F]V86[M("(E<R(@>F\@<WES=.EM=3H@`$YA<W1A;&$@8VAY8F$@<')I
M(&%K='5A;&EZX6-I:2`B)7,B.B`E<P!6>7-K>71O;"!S82!P<F]B;.EM(',@
M;F%H<N%V86[M;2!S^F)O<G4Z(*YI861E;B`E<R!N96)O;"!N86AR86[]+@!6
M>7-K>71O;"!S82!P<F]B;.EM(',@;F%H<N%V86[M;2!S^F)O<G4Z("5S(&)O
M;"!VY.BY[2!A:V\@;F%J=N3HN>T@<&]V;VQE;OT@;&EM:70@*"5D(&)A:G1O
M=BDN`%9Y<VMY=&]L('-A('!R;V)LZ6T@<R!U:VQA9&%N[6T@<_IB;W)U.B`E
M<R!B;VP@;F%H<F%N_2!L96X@Z&EA<W1OZ&YE+@!.87-T86QA(&-H>6)A('!R
M:2!Z;V)R87IO=F%N[2!T96IT;R#H87-T:2!S<'+A=GD`3F%S=&%L82!C:'EB
M82!P<FD@:6UP;W)T92#Z9&%J;W8@;R!K;VYT86MT92X`3F%S=&%L82!C:'EB
M82!P<FD@:6UP;W)T92#Z9&%J;W8@:4-A;&5N9&%R+@!.87-T86QA(&-H>6)A
M('8@:V]N9FEG=7)AZ&YO;2!F;W)M=6SA<FDN(%!R879D97!O9&]B;F4@<W1E
M(&YE=GEP;&YI;&D@<&^^861O=F%NZ2!P;VQE+@!.87-T86QA(&-H>6)A('!R
M:2!V>6MO;N%V86[M('5RZ&5N96H@9G5N:V-I92!A9')E<^%R82X@4')O<^UM
M('-K^G-T92!T;R!N97-K]'(N`$YA<W1A;&$@8VAY8F$@<')I(&%K='5A;&EZ
MX6-I:2!D971A:6QO=B!K;VYT86MT=2X@4')O<^UM('-K^G-T92!T;R!N97-K
M]'(N`$YA<W1A;&$@8VAY8F$@<')I(&%K='5A;&EZX6-I:2!Z;WIN86UU('!R
M[6IE;6-O=BX@4')O<^UM('-K^G-T92!T;R!Z;F]V=2X`5&5N=&\@24U!4"!S
M97)V97(@;F5P;V1P;W)U:F4@>F1I9;5A;FEE('!R:67H:6YK;W8N`%1O=&\@
M<')A=F1E<&]D;V)N92!N:64@:F4@<&QA=&[](&%R8VCM=B!R87(N`%1O=&\@
M<')A=F1E<&]D;V)N92!N:64@:F4@<&QA=&[](&%R8VCM=B!Z:7`N`%1O=&\@
M<')A=F1E<&]D;V)N92!N:64@:F4@<&QA=&[I(.CM<VQO(&MA<G1Y+@!496YT
M;R!O=FSA9&'H('5M;[[R=6IE('!O<VEE;&%N:64@<W!RX78@8V5Z(&)RX6YU
M($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@<&]M;V-O=2!(
M5%10($%020!496YT;R!O=FSA9&'H('5M;[[R=6IE('!O<VEE;&%N:64@<W!R
MX78@8V5Z(&)RX6YU(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI('!O;6]C;W4@
M2%144"!!4$D`5&5N=&\@;W9LX61AZ"!U;6^^\G5J92!P;W-I96QA;FEE('-P
M<N%V(&-E>B!B<N%N=2!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M
M*2!P;VUO8V]U($A45%`@05!)`%1E;G1O(&]V;.%D8>@@=6UOOO)U:F4@<&]S
M:65L8;L@<W!RX79Y(&-E>B!33510(&-E>B!B<N%N=2!6;V1A9F]N92!)=&%L
M>2`H:6)A(&YA(.CM<VQA(%9O9&%F;VYE*2X@5GF^861U:F4@92UM86EL;W;]
M(/KH970@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&]T
M;R!P;VQE(&IE('!O=FEN;NDN`%1O=&\@<&]L92!M]+YE(&]B<V%H;W9ANR!I
M8F$@Z.US;&$N`%1O=&\@<&]L92!M]+YE(&]B<V%H;W9ANR!I8F$@Z.US;&$@
M82!D=F]J8F]D:W4N`%1O=&\@<&]L92!M]+YE(&]B<V%H;W9ANR!I8F$@;W-M
M:>AK;W;I(&AO9&YO='DN`%1O=&\@<&]L92!M=7/M(&)YNR!Z;WIN86T@Z.US
M96P@;V1D96QE;OUC:"#H:6%R:V]U(&%L96)O(&UE9'IE<F]U`%1O=&\@<&]L
M92!M=7/M(&)YNR!P;&%T;ND@Z.US;&\N`%1O=&\@<&]L92!M=7/M(&]B<V%H
M;W9ANR!K\V0@9F%R8GD@=B"Y97-T;N%S=&MO=F]M(&9O<FWA=&4@4D="+"!N
M87!R[6ML860@)R,Q,C,T868G+@!496YT;R!F;W)M=6SA<B!UOB!B;VP@<W!R
M86-O=F%N_2X`5&]T;R!J92`E<RX`5&]T;R!J92!O8FIE:W0@2V]L86(@1W)O
M=7!W87)E+B!0<F4@>F]B<F%Z96YI92!T;VAT;R!O8FIE:W1U('!O=')E8G5J
M971E(&4M;6%I;&]VZ6AO(&ML:65N=&$L(&MT;W+](')O>G5M:64@9F]R;>%T
M=2!+;VQA8B!'<F]U<'=A<F4N(%!R92!Z;WIN86T@=&%K_6-H=&\@:VQI96YT
M;W8@;F%VN73M=G1E('!R;W/M;2`E<P!4X71O('-P<N%V82!B;VQA(&YA<.US
M86[A('8@:6YE:B!A:V\@5F%M:2!P;W6^[79A;F5J('IN86MO=F5J('-A9&4@
M*"5S*2X`5&]T;R#H[7-L;R!M=7/M(&)YNR!N86IM96YE:B`Q+@!496YT;R!S
M97)V97(@;F5D;VOAOF4@9&5K;VUP<FEM;W9ANR!S^F)O<GD@>FEP(&$@9WII
M<"X`4WES=.EM(&IE(&UO;65N=.%L;F4@9&5A:W1I=F]V86[]+@!4X71O(&AO
M9&YO=&$@;75S[2!B>;L@Z.US96QNX2X`5&]T;R!O:VYO(&UU<^T@8GF[('IA
M=F]L86[I('H@;VMN82!.87-T879E;NT`2')M96YI90!4:6-K971S`,AA<P!4
M:6UE(%1R86-K:6YG`$9O<FWA="#H87-U`%;]8F5R(.AA<W4`5&EM;W(M3&5S
M=&4`5&ET=6QO:P!.861P:7,@*&)U8FQI;F]V_2!V_7!I<RDZ`%!R90!0<F4@
M=OUB97(@=FEA8V5R_6-H('!O;&^^:65K(&1ROG1E('!OZ&%S(&ML:6MA;FEA
M(&MLX79E<W4@0V]N=')O;"`H4$,I(&%L96)O($-O;6UA;F0@*$UA8RDN`$1N
M97,`4')E<&[ZNR!Z;V)R87IE;FEE('ID<F]J;W;I:&\@:_-D=2!(5$U,`%1O
M9V\`5&]K96QA=0!:86IT<F$`5&]N9V$`5G)C:`!6<F-H;OT@<N%M96,@*%]T
M;W`I`%!R96ML861Y`%1R:6YI9&%D(&$@5&]B86=O`%!R879D82!A;&5B;R!N
M97!R879D80!5=`!4=6YI<VMO`%1U<F5C:V\`5'5R:VUE;FES=&%N`%1U<FMS
M(&$@0V%I8V]S`%1U=F%L=0!:861A:G1E(%9AN74@=F^U8G4Z(`!5+E8N(&EN
M9&5X.B``55),`%523"!6X;EH;R!S:W)I<'1U('!R92!S<'+A=G4@;R!D;W)U
MZ&5N[0!54DPZ`%5G86YD80!5:W)A:FEN80!.97!O9&%R:6QO('-A('5S:W5T
M;^AN:;L@<'+M<W1U<"!K(%9&4R!A9')E<^%R=2X`3F5P;V1A<FEL;R!S82!P
M<FED8;L@[V%LN6EE(&EN9F]R;>%C:64@;R!P;W6^[79A=&6U;W9I('!R:2!R
M96=I<W1RX6-I:2X`3F5P;V1A<FEL;R!S82!Z;65N:;L@<'+A=F\@<')E(%9&
M4R!S^F)O<B`B)7,B+@!.97!O9&%R:6QO('-A('IM96YINR!P<N%V;R!P<F4@
M5D93('/Z8F]R("5S+R5S+@!.97!O9&%R:6QO('-A('IM96YINR!N82`E<RX`
M3F5P;V1A<FEL;R!S82!S:V]N=')O;&]V8;L@=F6U:V]SNR!S^F)O<G4@(B5S
M(BX`3F5P;V1A<FEL;R!S82!S:V]N=')O;&]V8;L@=F6U:V]SNR!S^F)O<G4@
M(B5S+R5S(BX`3F5P;V1A<FEL;R!S82!S<&]J:;L@<R!344P@<V5R=F5R;VTN
M`$YE<&]D87)I;&\@<V$@<W!O:FF[('!O;6]C;W4@4U-,+@!.97!O9&%R:6QO
M('-A('-K;W#M<F]V8;L@5D93('/Z8F]R+@!.97!O9&%R:6QO('-A('9Y='9O
M<FF[(%9&4R!A9')E<^%R("(E<R(N`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@
M5D93(&%D<F5SX7(N`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@5D93('/Z8F]R
M+@!.97!O9&%R:6QO('-A('9Y='9O<FF[(%9&4R!P<FEEZ&EN;VL@(B5S(BX`
M3F5P;V1A<FEL;R!S82!V>71V;W)INR!P<N%Z9&YY(%9&4R!S^F)O<BX`3F5P
M;V1A<FEL;R!S82!D96MO;7!R:6UO=F&[(/ID86IE+@!.97!O9&%R:6QO('-A
M('9Y;6%Z8;L@(B5S(BP@861R97/A<B!N:64@:F4@<'+A>F1N>2X`3F5P;V1A
M<FEL;R!S82!V>6UA>F&[("(E<R(Z("5S+@!.97!O9&%R:6QO('-A('9Y;6%Z
M8;L@)7,L(&%D<F5SX7(@;FEE(&IE('!RX7ID;GD`3F5P;V1A<FEL;R!S82!R
M96MU<GKM=FYE('9Y;6%Z8;L@5D93(&%D<F5SX7(N`$YE<&]D87)I;&\@<V$@
M=GEM87IANR!61E,@861R97/A<BX`3F5P;V1A<FEL;R!S82!V>6UA>F&[(%9&
M4R!A9')E<^%R.B`E<RX`3F5P;V1A<FEL;R!S82!V>6UA>F&[(%9&4R!S^F)O
M<B`B)7,B+@!.97!O9&%R:6QO('-A('9Y;6%Z8;L@5D93('/Z8F]R+@!.97!O
M9&%R:6QO('-A('9Y;6%Z8;L@5D93('!R:67H:6YO:R`B)7,B+@!.97!O9&%R
M:6QO('-A(')E:W5R>NUV;F4@=GEM87IANR!61E,Z("5S+@!.97!O9&%R:6QO
M('-A('5RZ&F[(&%K='7A;&YY(&%D<F5SX7(N`$YE<&]D87)I;&\@<V$@>FES
M=&F[('!O9')O8FYO<W1I(&\@8V5R=&EF:6OA=&4N`$YE;6^^;ND@;F%H<F&[
M(&1E9FEN[6-I=2`E<RX`3F5P;V1A<FEL;R!S82!P<F5S=6[ZNR!61E,@<_IB
M;W(N`$YE<&]D87)I;&\@<V$@;W1V;W)INR!61E,@<_IB;W(@(B5S(BX`3F5P
M;V1A<FEL;R!S82!O='9O<FF[(%9&4R!S^F)O<B!N82!ZX7!I<RX`3F5P;V1A
M<FEL;R!S82!O='9O<FF[(%9&4R!S^F)O<BX`3F5P;V1A<FEL;R!S82!O='9O
M<FF[(&MO;7!R:6UO=F%N_2!A<F-H[78N`$YE<&]D87)I;&\@<V$@<')EZ.UT
M8;L@5D93('/Z8F]R("AF=6YK8VEA(&9I;&5S:7IE*"D@>FQY:&%L82DN`$YE
M<&]D87)I;&\@<V$@<')EZ.UT8;L@5D93('/Z8F]R("AF=6YK8VEA(&=E=$9I
M;&53:7IE*"D@>FQY:&%L82DN`$YE<&]D87)I;&\@<V$@<')EZ.UT8;L@<_IB
M;W(Z`$YE<&]D87)I;&\@<V$@Z.UT8;L@861R97/A<B!V9G-R;V]T+@!.97!O
M9&%R:6QO('-A('!R96UE;F]V8;L@)7,@;F$@)7,Z(&-I9;5O=OT@<')I9>AI
M;F]K('6^(&5X:7-T=6IE`$YE<&]D87)I;&\@<V$@<')E;65N;W9ANR!61E,@
M861R97/A<BX`3F5P;V1A<FEL;R!S82!P<F5M96YO=F&[(%9&4R!A9')E<^%R
M.B`E<RX`3F5P;V1A<FEL;R!S82!P<F5M96YO=F&[(%9&4R!S^F)O<B`B)7,B
M+@!.97!O9&%R:6QO('-A('!R96UE;F]V8;L@5D93('/Z8F]R("5S+R5S+@!.
M97!O9&%R:6QO('-A('!R96UE;F]V8;L@5D93('/Z8F]R+@!.97!O9&%R:6QO
M('-A('-P=7-T:;L@)VUK:7-O9G,G+@!.97!O9&%R:6QO('-A('!R96QOOFF[
M('1E;G1O(&1O:W5M96YT(%=O<F0`3F5P;V1A<FEL;R!S82!Z87#M<V&[(%9&
M4R!S^F)O<B`B)7,B+@!.97!O9&%R:6QO('-A('IA<.US8;L@5D93('/Z8F]R
M("AF=6YK8VEA(&-O<'DH*2!Z;'EH86QA*2X`3F5P;V1A<FEL;R!S82!Z87#M
M<V&[(/ID86IE(%9&4R!S^F)O<G4N`$YE<&]D87)I;&\@<V$@>F%P[7-ANR!6
M1E,@<_IB;W(L(&MV\W1A(&IE('!R96MR;^AE;N$N`%!O9.AI87)K;G5TZ0!:
M<G6Y:;L@>FUE;GD`6G)UN>T@<&]S;&5D;OH@86MC:74`3F5OZ&%KX79A;N$@
M;V1P;W9E[R!O9"!S97)V97)A('!OZ&%S('-P;VIE;FEA.B``3F5OZ&%KX79A
M;N$@;V1P;W9E[R!O9"!S97)V97)A(&YA.B``3F5N87-T879E;N$`4W!O:F5N
MZ2!A<F%B<VOI(&5M:7+A='D`5F6U:^$@0G)I=.%N:6$`4W!O:F5NZ2"Y=.%T
M>2!!;65R:6-KZ0!*961N;W1K>0!.97INX6UE`$YE>F[A;64@87!I;7-G:60@
M*$%022!-97-S86=E($E$*2X`3F5Z;N%M92!C;&EM<V=I9"`H0VQI96YT($UE
M<W-A9V4@240I+@!";VQA('IA9&%NX2!N97!L871NX2!L;VMA;&ET82X`3F5Z
M;N%M92!P;W6^[79A=&6U<VOI(&UE;F\@86QE8F\@:&5S;&\N`$]D<W1RX6YI
MNR!L:6YK=2!Z(&%K='7A;&YE:&\@96QE;65N='4`3F5P;VUE;F]V86[A`$YE
M<')I=FEL96=O=F%NZ2!S:W)I<'1Y(&YE;6%J^B!Z(&)E>G!EZ&YO<W1N_6-H
M(&3T=F]D;W8@<'+M<W1U<"!K('9OM6+A;2!6>7-T<FEH;OJ[+TMO<.UR;W9A
MNR]6;&^^:;LN($ML:6MN:71E(&YA($]+(&$@>F]B<F%Z[2!S82!T96-H;FEC
M:^$@:6YF;W)MX6-I82!N82!S='+A;FME(&UO>FEL;&$N;W)G+"!K=&]RX2!6
MX7,@:6YF;W)M=6IE+"!A:V\@=6UOOFYINR!S:W)I<'1U('!R[7-T=7`@:R!S
M8VARX6YK92X`3V1S='+A;FF[(&9A<F)U`$YE<&]D<&]R;W9A;ND@<F]ZN>UR
M96YI90!!:W1U86QI>N%C:6$`06MT=6%L:7IO=F&[("5S`$%K='5A;&EZ;W9A
MNR!P;W6^[79A=&6U80!!:W1U86QI>N%C:6$@(B5S(B!B;VQA(/IS<&6Y;N$N
M`%-K<FEP="!N82!U<&=R861E(&)O;"!V>6UA>F%N_2X`3F%H<F&[`%:Y971K
M>2!S^F)O<GD@<R!K;VYF:6=U<N%C:6]U(&)O;&D@;F%H<F%NZ2!N82!S97)V
M97(N`%9EM6OI(&QA=&EN<VOI('#M<VUE;N$`5F6U:^D@<NUM<VME(.CM<VQI
M8V4`57)U9W5A>0!0;W6^:;L@86MT=>%L;F4Z("5S`%!O=;YINR!34TP`4&]U
MOFET92!V('!R[7!A9&4L(+YE(&IE(&UE;F\O:&5S;&\@;V1L:;ENZ2!P<F4@
M24U34"!S97)V97(N`%!O=;[M=F%T9;4`4&]UONUV871EM2`E<R!N:64@:F4@
M875T;W)I>F]V86[](&YA("5S+@!3<'+A=F$@<&]UONUV871EM6]V`%!O=;[M
M=F%T9;5S:^D@;F%S=&%V96YI80!296=I<W1RX6-I82!P;W6^[79A=&6U80!2
M96=I<W1RX6-I82!P;W6^[79A=&6U;W8@8F]L82!P<F4@=&5N=&\@<WES=.EM
M('IA:^%Z86[A+@!0;W6^[79A=&6U<VO](/KH970@;F5B;VP@;N%J9&5N_0!0
M;W6^[79A=&6U<VOI(&UE;F\`4&]UONUV871EM7-KZ2!M96YO("(E<R(@=;X@
M97AI<W1U:F4N`%!O=;[M=F%T9;5S:^D@;65N;SH`4&]UONUV871EM7-KZ2!M
M96YO.B``4&]UONUV871E;&EA('-Y<W3I;74Z`%5Z8F5K:7-T86X`5D93(&%D
M<F5SX7(@;F5E>&ES='5J92X`1&]V;VQE;FMA`%!L871NZ2!U;6EE<W1N96YI
M82!Z86C@\F%J^CH@`%!L871N;W.[`%!L871N;W.[('8@;6EN^G1A8V@@;V1T
M97)A>BX`2&]D;F]T82!P<F5K<F_H:6QA(&UA>&EMX6QN=2!DY;YK=2`E<RX`
M2&]D;F]T>0!(;V1N;W1Y+"!Z(&MT;W+]8V@@<VD@;?2^971E('9Y8G)ANP!6
M86YU871U`%!R96UE;F[A`%9E;F5Z=65L80!/=F5R96YI92!Z;'EH86QO("T@
M=.%T;R!S<'+A=F$@;6]H;&$@8GF[('-F86RY;W9A;N$N`%9E<GII80!-86YA
MOFUE;G0@=F5R>FGM`%9E<G1I:^%L;F4@>F%R;W9N86YI90!697)T:6OA;&YE
M('9Y<&QN96YI90!697)T:6OA;&YE.@!69;5M:2!V>7-O:^$`5FEE=&YA;0!:
M;V)R87IINR`E<P!:;V)R87IINR!E>'1E<F[Z('=W=R!S='+A;FMU`%IO8G)A
M>FF[(&%K;R`E<P!"<FET<VOI(%!A;F5N<VOI(&]S=')O=GD`06UE<FEC:^D@
M4&%N96YS:^D@;W-T<F]V>0!6:61I=&6U;F]SNP!6:61I=&6U;F]SNSH@`%9O
M9&%F;VYE($ET86QY(&-E>B!33510`%9!4D]604Y)10!54$]:3U).14Y)12$A
M(2!/1%-44L'25$4@4TM225!4(%H@)7,@4E7(3D4N`%=)3B!C97H@2%144`!7
M86QL:7,@82!&=71U;F$`5F%R;W9A;FEE`%-T`%!R961P;W9E[R!P;^AA<VEA
M`-ID86IE(&\@<&_H87/M('!O<VMY='5J90!796%T:&5R+F-O;0!796(`5U=7
M('-T<N%N:V$`5/V^9&5N;F4`5FET86IT90!6[71A(%;A<R`E<P!6:71A:G1E
M+"`E<P!:X7!A9&[A(%-A:&%R80!+=&]R^B!A<&QI:^%C:74@;>$@)7,@>F]B
M<F%Z:;L@<&\@<')I:&SA<V5N[3\`06O](&IE('IN86L@<')E(&]D9&6U;W9A
MZ#\`06O](&IE('IN86L@<')E(/IV;V1Z;W9K=3\`36%P82!!=7-T<N%L:64@
M<')E('-L=;YB=2!7:&5R96ES`$MT;W+I(&;A>GD`2W1O<ND@>N%S=79NZ2!M
M;V1U;'D@<&]V;VQINR!P<F4@<F]ZN>UR96[]('1E>'1O=OT@961I=&]R+@"I
M[7)K80"I[7)K82!V(&IE9&YO=&OA8V@@0U-3`*GM<FMA(&UE;G4@)7,@=K5A
M=F\@*'!R96IA=NT@<V$@<')I(.]A;+EO;2!P<FEH;.%S96[M*3H`J>UR:V$@
M=&%B=;5K>0!*961N;W1K82"Y[7)K>0"I[7)K83H`5VEK:0!6:65T;W(`4N%N
M;R!V:65T;W(`4OUC:&QO<[L@=F5T<F$@=B!U>FQO8V@`5FEE=&]R.@!6:65T
M;W(Z(`!-^F1R;W.[`%=I<VAL:7-T`%!RX6-A`$%D<F5S82!D;R!P<N%C90!4
M96QE9O-N(&1O('!RX6-E`$YE<W!RX79N>2!P;^AE="!P;VSM(&YA(')I861K
M=2`E9"X@3^AA:^%V82!S82`E9"P@;F&Y;&\@<V$@)60N`$YE<W!RX79N>2!P
M;^AE="!P;VSM+B!/Z&%KX79A('-A("5D+"!N8;EL;R!S82`E9"X`6FS](&]F
M9G-E="`E9"!P<FD@Z.UT86[M(%9&4R!S^F)O<G4N`%@M4F5F`%KA:VQA9&[I
M(&]B;65D>F5N:6$@6#4P.78S`%!O=;YI=&EE(')O>KGM<F5NZ6AO(&NU^NAA
M(%@U,#EV,P!!;'1E<FYA=.UV;F4@;65N;R!S=6)J96MT=2!8-3`Y=C,`261E
M;G1I9FEKX71O<B!KM?KH82!S=6)J96MT=2!8-3`Y=C,`6#4P.78S(')O>KGM
M<F5N:6$`65D`65E960!986AO;R$@;6%P`%)OZ&YE`$IE;65N`$%N;P!3^FAL
M87/M;2X`4W1E('8@5$585$]63TT@4D6N24U%+B!0;W6^:71E('1L8>AI9&QO
M(%L\/ET@;F$@<')E<&YU=&EE(&YA<W#DNR!D;R!765-)5UE'+@!.96WTOF5T
M92!V>71V;W)INR!V:6%C(&%K;R`E9"!B;&]K;W8N`$YI92!S=&4@875T96YT
M:69I:V]V86[]+@!6;R!68;EO;2!P;&YO;2!M96YE(&YE;?2^971E('!O=;YI
MNR!Z;F%K("=<)RX`3F5Z861A;&D@<W1E('!L871N^B!E+6UA:6QO=OH@861R
M97-U+@!.975RZ&EL:2!S=&4@=GJ[86@@;65D>FD@OFEA9&YY;6D@<&]L:6%M
M:2!Z(&EM<&]R=&]V86[I:&\@<_IB;W)U(&$@>F]D<&]V961A:OIC:6UI('!O
MM6%M:2!V("5S+@!";VQI('-T92!O9&ALX7-E;OTN`$UU<^UT92!Z861ANR!P
M;&%T;ND@Z.US;&\@;6]B:6QNZ6AO('1E;&5F\VYU+"!K=&]RZ2!O8G-A:'5J
M92!I8F$@Z.US;&$@<R!V;VQI=&6U;OUM('!R969I>&]M("<K)R!P<F4@;65D
M>FENX7)O9&[](&9O<FWA="X`375S[71E('IA9&&[('!L871N^B!H;V1N;W1U
M+@!!8GD@<W1E(&UO:&QI('!O=;[M=F&[(%)E9VES='+A8VEE+"!M=7/M=&4@
M;F%J<VOT<B!N86MO;F9I9W5R;W9ANR!$871A5')E92!B86-K96YD+@!-=7/M
M=&4@;F%K;VYF:6=U<F]V8;L@5D93(&)A8VME;F0N`$UU<^UT92!P;W#M<V&[
M('!R;V)LZ6T@<')E9'3];2P@86MO(&]D;[EL971E('-P<N%V=2!O('!R;V)L
MZ6UE+@!-=7/M=&4@>F%D8;L@55),(&%D<F5S=2P@;F$@:W1O<OH@=.%T;R!L
M:6YK82!U:V%Z=6IE`$UU<^UT92!V>6)R8;L@<V5R=F5R+"!K=&]R_2!MX2!B
M>;L@=GEM87IA;OTN`$UU<^UT92!U<NAINR!M96YO('!O=;[M=F%T9;5A+"!K
M=&]RZ6AO(&-H8V5T92!V>6UA>F&[+@!-=7/M=&4@=7+H:;L@;65N;R!P;W6^
M[79A=&6U82P@:W1O<NEH;R!C:&-E=&4@=GEM87IANRX`375S[71E('5RZ&F[
M(&UE;F\@<&]UONUV871EM6$L(&MT;W+I:&\@8VAC971E('!R:61ANRX`375S
M[71E('5RZ&F[('!O=;[M=F%T9;5A+"!K=&]R_2!S82!MX2!A:W1U86QI>F]V
M8;LN`$UU<^UT92!U<NAINR!A:V-I=2P@:W1O<N$@<V$@;>$@=GEK;VYANRX`
M375S[71E('IA9&&[(&UE;F\@;F]V96H@:V%T96?S<FEE+@!-=7/M=&4@>F%D
M8;L@=&%L:6%N<VME('1E;&5F\VYN92#H[7-L;P!0;&%T;F]SNR!68;EE:B!R
M96SA8VEE('!R92!A<&QI:^%C:74@)7,@=GEP<KEA;&$N(%!R;W/M;2!P<FEH
M;.%S=&4@<V$@>FYO=G4N`%9AN6$@16UA:6QO=N$@861R97-A`%9AN6$@16UA
M:6QO=N$@861R97-A('!O=;YI=.$@<')E(&]D8VCA9'IA:OIC=2!P;[ET=3H`
M5F&Y92!I;F9O<FWA8VEE`%9AN6$@:6YT97)N971O=N$@861R97-A('-A('IM
M96YI;&$@;V0@>F'H:6%T:W4@5F&Y96H@<F5LX6-I92`E<RX@4')E(%9AN74@
M8F5Z<&7H;F]SNR!S82!M=7/M=&4@>FYO=G4@<')I:&SA<VF[+@!68;EE(&UE
M;F\`5N&Y(&%U=&5N=&EF:6MAZ&[](&UO9'5L(&YE<&]D<&]R=6IE('!R:63A
M=F%N:64@<&]UONUV871EM6]V+B!!:R!S:2"^96SA=&4@<&]UOFF[($AO<F1E
M(&YA('-P<N%V=2!P;W6^[79A=&6U<VO]8V@@^NAT;W8L(&UU<^UT92!P;W6^
M:;L@:6[](&%U=&5N=&EF:6MAZ&[](&)A8VME;F0N`%;AN2!A=71E;G1I9FEK
M8>AN_2!M;V1U;"!N97!O9'!O<G5J92!Z;V)R87IO=F%N:64@>F]Z;F%M=2!P
M;W6^[79A=&6U;W8L(&%L96)O(&)O;&$@=.%T;R!M;[YN;W.[('H@;F5J86OI
M:&\@9/1V;V1U('IA:^%Z86[A+@!:9.$@<V$L(+YE(%;AN2!P<F5H;&EA9&'H
M('-A('IM96YI;"!O9"!Z8>AI871K=2!68;EE:B!R96SA8VEE("5S+B!0<F4@
M5F&Y=2!B97IP9>AN;W.[('-A(&UU<^UT92!Z;F]V=2!P<FEH;.%S:;LN`%;A
MN2!P<F5H;&EA9&'H(&YE<&]D<&]R=6IE('3Z=&\@9G5N:V-I=2X`5N&Y('!R
M96AL:6%D8>@@;F5P;V1P;W)U:F4@=/IT;R!F=6YK8VEU('1L8>AE+B!3=&QA
MZ'1E($-O;G1R;VPO0V]M;6%N9"`K(%`@<')E('1L8>@N`%9AN6$@86MT=>%L
M;F$@Z&%S;W;A('KS;F$Z`%9AN6$@<')E9&YA<W1A=F5NX2!I9&5N=&ET82!B
M;VQA('IM96YE;N$N`%!R961N87-T879E;N$@:61E;G1I=&$Z`%9AN64@;65N
M;SH`4&QA=&YO<[L@5N&Y:&\@^NAT=2!V>7!RN6%L82X`5F&Y92!N;W;I(&AE
M<VQO('!R92`E<R!J93H@)7,`5F&Y92!N87-T879E;FEA(&)O;&D@86MT=6%L
M:7IO=F%NZ2!P<F4@=&]T;R!S961E;FEE+@!68;EE(&YA<W1A=F5N:6$@8F]L
M:2!A:W1U86QI>F]V86[I+@!68;EE(&AE<VQO(&)O;&\@;V)N;W9E;ND`5F&Y
M92!H97-L;R!B;VQO(&]B;F]V96[I+"!S:V]N=')O;'5J=&4@<VD@<&^Y='4@
M82!P<FEH;.%S=&4@<V$@<R!68;GM;2!N;W;];2!H97-L;VTN`%!L871N;W.[
M(%;AN6AO(&AE<VQA('9Y<'*Y86QA+@!68;EE('9Z9&EA;&5NZ2!S97)V97)Y
M.@!*=6AO<VSA=FEA`%IA:7(`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M3:W)Y
MNR!C:71O=F%N_2!T97AT70!;4W!RX79A(&\@<')O8FSI;65=`%M:;V)R87II
MNR!C:71O=F%N_2!T97AT("T`6UIO8G)A>FF[(&-I=&]V86[]('1E>'0@+2`E
M<R!R:6%D:V]V70!;<FEA9&]K("5S('H@)7-=`%]!9&UI;FES='+A8VEA`%]#
M3$D`7T1A=&%4<F5E`%]6>6UA>F&[(')I861O:P!?4VMU<&EN>0!?4&]M;V-N
M[6L`5FQA<W1N;W-T:2!?;V)RX7IK=2XN+@!?4')I:&SA<VF[('-A`%]/9&AL
MX7-INR!S80!?57!R879INR!L:6YK=2XN+@!?3F%S=&%V96YI80!?4'+A=F$`
M3V1S=%]RX6YINR!L:6YK=2XN+@!.85]S=&%V96YI90!6;&%S=&YO<W1I(%]T
M86)UM6MY+BXN`%!O7W6^[79A=&5L:6$`861R97/A<@!A9')E<^%T(&YE>F[A
M;7D`:V%L96YDX7(`8F5Z=F5T<FEE`&YE<&]D87)I;&\@<V$@=GET=F]R:;L@
M=OUS='5P;OT@<_IB;W(`;F5P;V1A<FEL;R!S82!O='9O<FF[('9S='5P`&ML
M:6MN:71E('-E;0!C:'EB82!P<FD@<&]UOFET[2!P<NUK87IO=NEH;R!R:6%D
M:W4`8VAY8F$@:V]N9FEG=7+A8VEE`&-H_6)A(&3T;&6^:73]('-Y<W3I;6]V
M_2!S^F)O<@!C:'EB82!F;W)MX71U(/ID86IO=@!P;VQOOFMA(&YE;N%J9&5N
MX0!K;&5SX0!S^F)O<@!Z;R!S;65R=2`E<R`H)7,I('+]8VAL;W.[;W4@)7,@
M)7,`;N%R87IO=OT`=CH`:&@`;F5Z;N%M92!M96YO(&AO<W1I=&6U80!O:V%M
MOFET90!V('-P<N%V90!C:'EB82!V<W1U<'4O=OUS='5P=0!I;G1E<F[A(&-H
M>6)A('-O9G1VZ7)U`')I861K;W9=`'!OZ&%S('9Y=';A<F%N:6$@25-/(&YA
M<W1A;&$@8VAY8F$@;6MI<V]F<R`E9`!M;0!M96YO`&YE:6UP;&5M96YT;W9A
M;ND`>F%T:6&U(&YE:6UP;&5M96YT;W9A;ND`<&]Z;N%M:V]V_2!B;&]K`'!E
M<F-E;G0`<'+M<W1U<"!Z86UI971N=73]`&)O9&]V`'9Z9&EA;&5NX2!C:'EB
M82!V('!R;W1O:V]L90!S=/IP80!S;'6^8F$@;FEE(&IE(&1O<W1U<&[A`'IO
M8G)A>FF[(')O>F1I96QY`'-M<S)E;6%I;"!C97H@2%144`!S<P!U<W3A;&5N
M_0!S>7-TZ6UO=N$@8VAY8F$`>F]Z;F%M(/IL;V@`9&_H87-NX2!C:'EB80!P
M<F4@<&]T=G)D96YI92!Z861A:G1E(&AE<VQO(&1V86MRX70`=6YI9FEK;W9A
M;ND`;F5P;VUE;F]V86[A`&1E9FEN=6IE('!O=;[M=F%T9;4`=D-A<F0`N3H`
M=V5A=&AE<BYC;VT`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]S;%]322\`````````````
M````````````````````````````````````````````````````````````
M````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U
M,34T,S,W-30`,#(P,3(W`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE
M+W-L7U-)+VAE;'`N>&UL````````````````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,S,R,``Q,#4Q-30S,S<U-``P,C$U-S<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]X;6P@=F5R<VEO;CTB
M,2XP(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O<VQ?4TDO:&5L<"YX
M;6PL=B`Q+C(@,C`P-"\P-2\R-R`R,#HR,CHQ,R!J86X@17AP("0@+2T^"CQH
M96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4](FYE=R(^"CQT:71L
M93Y4:&4@4&]R=&%L(%!A9V4\+W1I=&QE/@H@/'!A<F$^"B`@5&AI<R!P;W)T
M86P@<&%G92!P<F]V:61E<R!A('%U:6-K('-U;6UA<GD@;V8@86QL('EO=7(@
M:6UP;W)T86YT"B`@:6YF;W)M871I;VXN($9O<B!E>&%M<&QE+"!I="!M:6=H
M="!S:&]W(&AO=R!M86YY(&YE=R!E+6UA:6P@;65S<V%G97,@>6]U"B`@:&%V
M92!I;B!Y;W5R($E.0D]8+"!U<&-O;6EN9R!E=F5N=',@;VX@>6]U<B!C86QE
M;F1A<BP@=&%S:W,@;VX@>6]U<B!T;RUD;PH@(&QI<W0L(&AE861L:6YE<R!F
M<F]M('-E;&5C=&5D(&YE=W,@<V5R=FEC97,L(&%N9"!S;R!O;BX@($UA;GD@
M;V8@=&AE<V4*("!S=6UM87)I97,@=VEL;"!C;VYT86EN('%U:6-K('-H;W)T
M8W5T<R!T;R!C;VUM;VX@9G5N8W1I;VYS+"!S=6-H(&%S"B`@8V]M<&]S:6YG
M(&$@;F5W(&UA:6P@;65S<V%G92P@8W)E871I;F<@82!N97<@8V%L96YD87(@
M979E;G0@;W(@=&%S:RP@971C+@H@/"]P87)A/@H@/'!A<F$^"B`@5&AE(&-O
M;G1E;G1S(&]F('1H:7,@<&]R=&%L('!A9V4@87)E(&-U<W1O;6EZ86)L92!V
M:6$@=&AE($QA>6]U="!B=71T;VXN"B`@1F]R(&5X86UP;&4L('EO=2!C86X@
M8VAO;W-E('=H:6-H(&ET96US('1O(&EN8VQU9&4@;VX@=&AI<R!P;W)T86P@
M<&%G92!A<PH@('=E;&P@87,@:6X@=VAI8V@@;W)D97(@=&AE>2!A<F4@<VAO
M=VXN"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B('-T
M871E/2)N97<B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG871I;VX@
M0F%R/"]T:71L93X*(#QP87)A/@H@($%T('1H92!L969T(&AA;F0@<VED92!O
M9B!T:&4@=V5B('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N(&YA=FEG871I;VX@
M8F%R+@H@($-L:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES(&YA=FEG871I;VX@
M8F%R('1O('%U:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*("!B971W965N('1H
M92!A=F%I;&%B;&4@87!P;&EC871I;VYS+@H@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@1&\@36%I
M;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@
M;&EK92!T;R!P97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G
M:6XL(&-H96-K('1H:7,@8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC92(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!#;VYF
M:7)M($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U
M('=O=6QD(&QI:V4@=&\@8V]N9FER;2!A;&P@;6%I;G1E;F%N8V4@=&%S:W,@
M8F5F;W)E('1H97D@87)E(')U;BP@8VAE8VL@=&AI<R!B;W@N($EF(&QE9G0@
M=6YC:&5C:V5D+"!A;&P@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!T:&%T(&YE
M960@=&\@8F4@<G5N('=I;&P@8F4@<&5R9F]R;65D(&%U=&]M871I8V%L;'D@
M=VET:"!N;R!C:&%N8V4@=&\@8V%N8V5L(&]N(&QO9VEN+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H\+VAE;'`^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]S;%]3
M22],0U]-15-304=%4R\`````````````````````````````````````````
M````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`U,34T,S,W-30`,#(Q-S$T`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&]C86QE+W-L7U-)+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#,U,#`S,P`Q,#4Q-30S,S<U-``P,C,S-38`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````WA($
ME0````"<!@``'````/PT``#;"```W&D```````!(C0``#@```$F-```/````
M6(T```T```!HC0``"````':-```+````?XT```P```"+C0``!````)B-```8
M````G8T``!L```"VC0``+0```-*-```=`````(X``"0````>C@``*0```$..
M```9````;8X``"8```"'C@``#````*Z.```D````NXX```\```#@C@``"P``
M`/".```.````_(X```4````+CP``*````!&/```(````.H\```H```!#CP``
M%0```$Z/```2````9(\```L```!WCP``A0```(./```.````"9````H````8
MD```#0```".0```.````,9```!$```!`D```#0```%*0```,````8)````T`
M``!MD```!@```'N0``"4````@I````H````7D0``#P```"*1```8````,I$`
M``P```!+D0``#@```%B1```.````9Y$```@```!VD0``"0```'^1```N````
MB9$``!H```"XD0``,@```-.1```X````!I(``%0````_D@``40```)22``!:
M````YI(``%<```!!DP``-````)F3```)````SI,```T```#8DP``!P```.:3
M```*````[I,```\```#YDP``!0````F4```&````#Y0```@````6E```)0``
M`!^4```@````190``!,```!FE```$````'J4```/````BY0```H```";E```
M`P```*:4```/````JI0``!0```"ZE```"0```,^4```-````V90``!(```#G
ME```&0```/J4```>````%)4```\````SE0``"@```$.5```/````3I4```@`
M``!>E0``)````&>5```4````C)4``!8```"AE0``"````+B5``!.````P94`
M`"T````0E@``&0```#Z6```'````6)8```P```!@E@``+````&V6```.````
MFI8```,```"IE@``"P```*V6```'````N98```<```#!E@``!0```,F6```#
M````SY8``!<```#3E@``"@```.N6```/````]I8``!@````&EP``(P```!^7
M```.````0Y<``!0```!2EP``%P```&>7```7````?Y<``!<```"7EP``$P``
M`*^7```.````PY<``!\```#2EP``'0```/*7```'````$)@```8````8F```
M"````!^8```/````*)@```8````XF```"@```#^8```3````2I@```L```!>
MF```$````&J8```5````>Y@``!4```"1F```!P```*>8```%````KY@``!4`
M``"UF```$0```,N8```,````W9@``#L```#JF```.````":9```)````7YD`
M``<```!IF0``%````'&9```#````AID```4```"*F0``"0```)"9```3````
MFID``#D```"NF0``$@```.B9```G````^YD``"P````CF@``*@```%":```E
M````>YH```H```"AF@``!@```*R:```)````LYH```<```"]F@``+P```,6:
M```W````]9H``"X````MFP``50```%R;```M````LIL``"T```#@FP``/0``
M``Z<```_````3)P``"T```",G```0````+J<```C````^YP``",````?G0``
M0````$.=```M````A)T``#,```"RG0``)0```.:=```5````#)X``!D````B
MG@``*0```#R>```D````9IX``"@```"+G@``$0```+2>```*````QIX```P`
M``#1G@``%@```-Z>```6````]9X```<````,GP``!P```!2?```4````')\`
M``H````QGP``"````#R?```G````19\```<```!MGP``!P```'6?```&````
M?9\```4```"$GP``!P```(J?```&````DI\```@```"9GP``*0```**?```.
M````S)\```H```#;GP``!P```.:?```)````[I\``!8```#XGP``!`````^@
M```(````%*````T````=H```!@```"N@```>````,J```!$```!1H```"```
M`&.@```,````;*````<```!YH````P```(&@```#````A:```!<```")H```
M'0```*&@```(````OZ````0```#(H```"````,V@```(````UJ```"L```#?
MH```(`````NA```5````+*$```8```!"H0``!@```$FA```5````4*$``#H`
M``!FH0``&````*&A```B````NJ$``#,```#=H0``+@```!&B```=````0*(`
M`"$```!>H@``5````("B``!`````U:(``"D````6HP``&0```$"C```*````
M6J,```<```!EHP``%0```&VC```.````@Z,```H```"2HP``"0```)VC```4
M````IZ,``!@```"\HP``'0```-6C```3````\Z,``!$````'I```%````!FD
M```$````+J0```8````SI```%````#JD``!4````3Z0``&0```"DI```!0``
M``FE```%````#Z4``!L````5I0``&@```#&E```3````3*4``!$```!@I0``
M$0```'*E```<````A*4``!````"AI0``(0```+*E```%````U*4```L```#:
MI0``$@```.:E```*````^:4```\````$I@``#0```!2F```1````(J8``!,`
M```TI@``#````$BF```&````5:8```P```!<I@``!@```&FF```7````<*8`
M`!````"(I@``"````)FF```%````HJ8```P```"HI@``$````+6F```-````
MQJ8```8```#4I@``!P```-NF```-````XZ8```<```#QI@``"P```/FF```'
M````!:<```<````-IP``"0```!6G```)````'Z<```H````IIP``&0```#2G
M```]````3J<``!T```",IP``#````*JG```0````MZ<```4```#(IP``)0``
M`,ZG```2````]*<``!,````'J```*P```!NH```[````1Z@``"````"#J```
M"````*2H```V````K:@``"$```#DJ```$`````:I```(````%ZD```P````@
MJ0``!@```"VI```/````-*D```<```!$J0``"@```$RI```-````5ZD``!\`
M``!EJ0``'````(6I```A````HJD``!X```#$J0``&0```..I```>````_:D`
M`!L````<J@``(0```#BJ```N````6JH``"8```")J@``'````+"J```>````
MS:H``!P```#LJ@``)@````FK```K````,*L``#,```!<JP``)@```)"K```K
M````MZL``#@```#CJP``'0```!RL```5````.JP``"\```!0K```(````("L
M```2````H:P``"D```"TK```'@```-ZL```@````_:P``!(````>K0``H@``
M`#&M```6````U*T``",```#KK0``*`````^N```I````.*X``"@```!BK@``
M'P```(NN```5````JZX``"````#!K@``)0```.*N```H````"*\``"T````Q
MKP``,````%^O``"2````D*\``"$````CL```%@```$6P```<````7+```"8`
M``!YL```*@```*"P``!!````R[```$0````-L0``#````%*Q```'````7[$`
M``<```!GL0``!@```&^Q```0````=K$``!(```"'L0``$P```)JQ```2````
MKK$```<```#!L0``!````,FQ```0````SK$``!````#?L0``#````/"Q```-
M````_;$```\````+L@``$P```!NR```H````+[(```8```!8L@``$0```%^R
M```7````<;(``!L```")L@``#@```*6R```"````M+(``$D```"WL@``!0``
M``&S```0````![,```\````8LP``!````"BS```-````+;,```X````[LP``
M`P```$JS```(````3K,```<```!7LP``#0```%^S```0````;;,```T```!^
MLP``"P```(RS```&````F+,```P```"?LP``"@```*RS```1````M[,``!D`
M``#)LP``(@```..S```/````!K0``!L````6M```-````#*T```8````9[0`
M`!(```"`M```(@```).T```-````MK0```<```#$M```%````,RT```+````
MX;0``"(```#MM```+P```!"U```+````0+4```D```!,M0``&0```%:U```+
M````<+4```D```!\M0``%@```(:U```/````G;4``!D```"MM0``%@```,>U
M```.````WK4``!@```#MM0``"`````:V```-````#[8``"8````=M@``0P``
M`$2V```(````B+8``!(```"1M@``'P```*2V```+````Q+8``"\```#0M@``
M#@````"W```%````#[<```8````5MP``10```!RW```#````8K<```<```!F
MMP``!````&ZW```*````<[<```H```!^MP``#P```(FW```0````F;<``!<`
M``"JMP``$0```,*W```9````U+<``!<```#NMP``"0````:X```%````$+@`
M``L````6N```!0```"*X```-````*+@``!L````VN```%P```%*X```4````
M:K@```D```!_N```#@```(FX```-````F+@``!(```"FN```.````+FX```@
M````\K@```@````3N0``>P```!RY```8````F+D``!$```"QN0``!P```,.Y
M```%````R[D``!@```#1N0``'@```.JY```;````";H``!D````EN@``&P``
M`#^Z```9````6[H``!,```!UN@``!P```(FZ```(````D;H```8```":N@``
M!@```*&Z```0````J+H```\```"YN@``$````,FZ```/````VKH```L```#J
MN@``#P```/:Z```,````!KL```\````3NP``!P```".[```&````*[L```P`
M```RNP``*````#^[```/````:+L```@```!XNP``$P```(&[```>````E;L`
M`"$```"TNP``(````-:[```9````][L``!<````1O```)0```"F\```7````
M3[P``!8```!GO```!````'Z\```;````@[P```T```"?O```#````*V\```#
M````NKP```4```"^O```"````,2\```*````S;P```P```#8O```"P```.6\
M```0````\;P```P````"O0``#@````^]```+````'KT```0````JO0``!```
M`"^]```3````-+T``!0```!(O0``#````%V]```)````:KT```X```!TO0``
M"P```(.]```;````C[T```<```"KO0``!P```+.]```*````N[T```T```#&
MO0``"0```-2]```$````WKT```,```#CO0``&````.>]```$`````+X```X`
M```%O@``?````!2^```5````D;X```4```"GO@``!P```*V^```,````M;X`
M``@```#"O@``"@```,N^```&````UKX```@```#=O@```@```.:^```&````
MZ;X``!0```#PO@``#0````6_```0````$[\``!L````DOP``!````$"_```)
M````1;\``!````!/OP``"0```&"_```)````:K\```4```!TOP``!@```'J_
M```9````@;\```X```";OP``!P```*J_```'````LK\```4```"ZOP``"0``
M`,"_```*````RK\```X```#5OP```@```.2_```+````Y[\```T```#SOP``
M"0````'````&````"\```!(````2P```"0```"7````'````+\```!0````W
MP```'0```$S```!"````:L```"4```"MP```)0```-/````&````^<````H`
M````P0``!`````O!```)````$,$```@````:P0``$0```"/!```)````-<$`
M``8````_P0``#0```$;!```&````5,$```0```!;P0``'@```&#!```%````
M?\$```X```"%P0``!````)3!```&````F<$```<```"@P0``(0```*C!```-
M````RL$``!4```#8P0``!@```.[!```$````]<$```8```#ZP0``"@````'"
M```B````#,(```0````OP@``!0```#3"```=````.L(```P```!8P@``#@``
M`&7"```*````=,(```@```!_P@``"0```(C"```%````DL(``#H```"8P@``
M,````-/"```U````!,,``"D````ZPP``1P```&3#```X````K,,``"D```#E
MPP``/P````_$```N````3\0``"T```!^Q```'P```*S$```D````S,0```@`
M``#QQ```"@```/K$```)````!<4```<````/Q0``(````!?%```@````.,4`
M`"8```!9Q0``"@```(#%```9````B\4``"D```"EQ0``%@```,_%```'````
MYL4```H```#NQ0``#````/G%```/````!L8``!`````6Q@``0````"?&``!F
M````:,8```P```#/Q@``!@```-S&```/````X\8``!(```#SQ@``$`````;'
M```<````%\<``",````TQP``:@```%C'```%````P\<``!````#)QP``"0``
M`-K'```+````Y,<``"````#PQP``&0```!'(``!"````*\@```\```!NR```
M-````'[(```U````L\@``!0```#IR```!P```/[(```,````!LD``"`````3
MR0``$````#3)```4````1<D``!$```!:R0``%P```&S)```<````A,D``!,`
M``"AR0``%````+7)```:````RLD``!$```#ER0``&@```/?)```>````$LH`
M`!H````QR@``$P```$S*```5````8,H``!$```!VR@``%P```(C*```4````
MH,H``!<```"UR@``%0```,W*```)````X\H``!````#MR@``&0```/[*```$
M````&,L```<````=RP``$0```"7+```&````-\L```8````^RP``!0```$7+
M```'````2\L```<```!3RP``!0```%O+```6````8<L```8```!XRP``!@``
M`'_+```$````ALL```0```"+RP``"@```)#+```.````F\L```4```"JRP``
M*````+#+```.````V<L```P```#HRP``#P```/7+```*````!<P```@````0
MS```"0```!G,```K````(\P```0```!/S```"````%3,```F````7<P``!(`
M``"$S```#P```)?,```&````I\P```H```"NS```"````+G,```@````PLP`
M``D```#CS```%````.W,```,`````LT```T````/S0``#@```!W-```6````
M+,T``!$```!#S0``!@```%7-```#````7,T```<```!@S0``"P```&C-```+
M````=,T```<```"`S0``!0```(C-```'````CLT``!8```"6S0``#0```*W-
M```-````N\T```H```#)S0``$````-3-```/````Y<T``!$```#US0``%P``
M``?.```*````'\X``!$````JS@``!````#S.```Z````0<X```4```!\S@``
M#````(+.```>````C\X```X```"NS@``$````+W.```+````SLX```P```#:
MS@``"0```.?.```'````\<X```H```#YS@``"0````3/```.````#L\``!``
M```=SP``&P```"[/```8````2L\``!H```!CSP``"@```'[/```)````B<\`
M``H```"3SP``#````)[/```/````J\\```@```"[SP``!@```,3/```<````
MR\\```<```#HSP``!0```/#/```+````]L\``$<````"T```#0```$K0```)
M````6-````0```!BT````P```&?0```*````:]````(```!VT```!````'G0
M```E````?M````,```"DT```!0```*C0```J````KM````H```#9T```!0``
M`.30```$````ZM````H```#OT```!@```/K0```(`````=$```@````*T0``
M!````!/1```%````&-$``&@````>T0``"0```(?1```,````D=$``!````">
MT0``!0```*_1```;````M=$``"\```#1T0``$`````'2```*````$M(```\`
M```=T@``"@```"W2```)````.-(``!,```!"T@``&P```%;2```8````<M(`
M`!<```"+T@``'P```*/2```.````P](```,```#2T@``!P```-;2```(````
MWM(```<```#GT@``"@```._2```'````^M(``%$````"TP``$````%33```,
M````9=,```T```!RTP``&@```(#3``!*````F],``!D```#FTP``!@````#4
M```:````!]0``"4````BU```!@```$C4```&````3]0``!\```!6U```"0``
M`';4```8````@-0``!<```"9U```*````+'4```&````VM0```T```#AU```
M(@```._4```3````$M4``",````FU0``$P```$K5```"````7M4```L```!A
MU0``"````&W5```-````=M4```<```"$U0``%````(S5```&````H=4```@`
M``"HU0``#@```+'5```'````P-4```H```#(U0``"P```-/5```R````W]4`
M``<````2U@``#````!K6```-````)]8``!<````UU@``#````$W6```)````
M6M8```D```!DU@``"@```&[6```'````>=8```D```"!U@``!P```(O6```*
M````D]8``!L```">U@``#P```+K6```2````RM8```H```#=U@``%@```.C6
M```)````_]8``!`````)UP``!P```!K7```2````(M<```0````UUP``!P``
M`#K7```%````0M<```4```!(UP``"P```$[7```4````6M<``!$```!OUP``
M&@```('7```6````G-<``!0```"SUP``%P```,C7```8````X-<``!P```#Y
MUP``&0```!;8```'````,-@```4````XV```#0```#[8```,````3-@```@`
M``!9V```%P```&+8```+````>M@```P```"&V```'P```)/8```:````L]@`
M``0```#.V```"@```-/8```$````WM@```T```#CV```#````/'8```%````
M_M@```D````$V0``!0````[9```'````%-D```4````<V0``!````"+9```"
M````)]D``#@````JV0``+````&/9```2````D-D``"D```"CV0``,@```,W9
M```*`````-H``"P````+V@``+@```#C:```S````9]H``#,```";V@``.```
M`,_:```/````"-L``!@````8VP``$````#';```/````0ML``!,```!2VP``
M%0```&;;```4````?-L``!(```"1VP``%````*3;```5````N=L``&(```#/
MVP``$P```#+<```-````1MP``!<```!4W```#````&S<```K````>=P``"$`
M``"EW```&@```,?<```)````XMP``$4```#LW```00```#+=```$````=-T`
M`!0```!YW0``#@```([=```3````G=T``!@```"QW0``!@```,K=```)````
MT=T```H```#;W0``#P```.;=```0````]MT```X````'W@``!0```!;>```;
M````'-X```@````XW@``!@```$'>```4````2-X``!$```!=W@``#@```&_>
M```X````?MX```8```"WW@``#@```+[>```%````S=X```<```#3W@``!@``
M`-O>```H````XMX```P````+WP``'````!C?```$````-=\``"D````ZWP``
M%P```&3?```?````?-\``%P```"<WP``%````/G?```^````#N```!````!-
MX```!P```%[@```.````9N````P```!UX```$P```(+@```*````EN```!T`
M``"AX```&0```+_@```%````V>```!$```#?X```$0```/'@```D`````^$`
M`!(````HX0``%0```#OA```2````4>$```X```!DX0``&0```'/A```(````
MC>$```D```"6X0``#0```*#A```'````KN$```H```"VX0``!P```,'A```/
M````R>$```8```#9X0``"P```.#A```:````[.$```H````'X@``"````!+B
M```%````&^(``!\````AX@``!@```$'B```0````2.(```@```!9X@``#0``
M`&+B```(````<.(``!X```!YX@``$@```)CB```L````J^(``!H```#8X@``
M"0```//B```*````_>(``!4````(XP``!0```![C```0````).,```8````U
MXP``'@```#SC```H````6^,```H```"$XP``'````(_C```1````K.,```L`
M``"^XP``&@```,KC```4````Y>,```0```#ZXP``!````/_C```+````!.0`
M``4````0Y```!@```!;D```(````'>0``"`````FY```*0```$?D```@````
M<>0``$$```"2Y```&@```-3D```H````[^0``"D````8Y0``4````$+E```B
M````D^4```8```"VY0``"````+WE```%````QN4```@```#,Y0``*@```-7E
M```C`````.8``!D````DY@``+@```#[F```(````;>8``!<```!VY@``"@``
M`([F```'````F>8``!````"AY@``"P```++F```'````ON8``!,```#&Y@``
M"````-KF```+````X^8```H```#OY@``%````/KF```/````#^<``#(````?
MYP``"P```%+G```.````7N<```4```!MYP``!0```'/G```%````>><``!<`
M``!_YP``#P```)?G```$````I^<```H```"LYP``"0```+?G```+````P><`
M``T```#-YP``#````-OG```.````Z.<```4```#WYP``!````/WG```-````
M`N@``#(````0Z```10```$/H```'````B>@``!X```"1Z```%````+#H```%
M````Q>@``!0```#+Z```!@```.#H```'````Y^@```X```#OZ```*@```/[H
M```&````*>D```T````PZ0``"P```#[I```V````2ND```L```"!Z0``#P``
M`(WI```R````G>D``"4```#0Z0``,````/;I```Q````)^H``"T```!9Z@``
M#@```(?J```%````ENH```X```"<Z@``$P```*OJ```2````O^H```<```#2
MZ@``$0```-KJ```3````[.H```<`````ZP``%`````CK```8````'>L```<`
M```VZP``#````#[K```,````2^L```0```!8ZP``!P```%WK```*````9>L`
M``L```!PZP``#````'SK```#````B>L``!(```"-ZP``!@```*#K```>````
MI^L``!@```#&ZP``)0```-_K```-````!>P```D````3[```'P```!WL```#
M````/>P```<```!![```"@```$GL```"````5.P```P```!7[```%0```&3L
M```+````>NP``!D```"&[```(````*#L```%````P>P```H```#'[```%0``
M`-+L```2````Z.P```P```#[[```!`````CM```)````#>T```<````7[0``
M#````!_M``!2````+.T``!<```!_[0``)````)?M```2````O.T```<```#/
M[0``!@```-?M```.````WNT```P```#M[0``#0```/KM```5````".X``!(`
M```>[@``#P```#'N```4````0>X```H```!6[@``&P```&'N```0````?>X`
M``L```".[@``:0```)KN```:````!.\``!<````?[P``)P```#?O```:````
M7^\``!<```!Z[P``&P```)+O```9````KN\``!\```#([P``$P```.CO```(
M````_.\```<````%\```"`````WP```)````%O```!4````@\```#0```#;P
M```C````1/````T```!H\```$P```';P```(````BO````,```"3\```1@``
M`)?P```_````WO```#<````>\0``5P```%;Q```%````KO$``!\```"T\0``
M+P```-3Q```*````!/(```@````/\@``#0```!CR```M````)O(```0```!4
M\@``3P```%GR```E````J?(``!P```#/\@``"P```.SR```?````^/(``!T`
M```8\P``"P```#;S```'````0O,```T```!*\P``#````%CS```7````9?,`
M``8```!]\P``.0```(3S```,````OO,```<```#+\P``"0```-/S```3````
MW?,```D```#Q\P``!````/OS```0`````/0```@````1]```"````!KT```$
M````(_0```L````H]```#````#3T```2````0?0``!$```!4]```#````&;T
M```:````<_0```\```".]```!P```)[T```-````IO0``!0```"T]```#@``
M`,GT```,````V/0``!L```#E]```+`````'U```3````+O4```8```!"]0``
M!0```$GU```$````3_4``!<```!4]0``!@```&SU```)````<_4```@```!]
M]0``"0```(;U```*````D/4``!$```";]0``!@```*WU```.````M/4```X`
M``##]0``"P```-+U```=````WO4```(```#\]0``'````/_U```'````'/8`
M``8````D]@``9````"OV```'````D/8``"8```"8]@``.````+_V```:````
M^/8``"H````3]P``.P```#[W```H````>O<``#0```"C]P``&0```-CW```5
M````\O<```4````(^```"`````[X```'````%_@```4````?^```!P```"7X
M```.````+?@```D````\^```!@```$;X```(````3?@```<```!6^```"```
M`%[X```'````9_@``!8```!O^```"0```(;X```&````D/@```L```"7^```
M$````*/X```&````M/@``!P```"[^```%````-CX```'````[?@``!$```#U
M^```"`````?Y```(````$/D```D````9^0``!@```"/Y```9````*OD```H`
M``!$^0``'````$_Y```%````;/D``!````!R^0``%````(/Y```+````F/D`
M``T```"D^0``*````++Y```8````V_D``!<```#T^0``!`````SZ```)````
M$?H```(````;^@``"````![Z```C````)_H``!\```!+^@``.````&OZ```F
M````I/H``#$```#+^@``)P```/WZ``!D````)?L``%4```"*^P``.````.#[
M``!*````&?P``%L```!D_```*````,#\```X````Z?P``"@````B_0``+```
M`$O]```;````>/T``",```"4_0``2````+C]``"%`````?X``#````"'_@``
M)0```+C^``!!````WOX``%L````@_P``20```'S_```Q````QO\``"L```#X
M_P``(0```"0``0`?````1@`!`"8```!F``$`.@```(T``0`S````R``!`"4`
M``#\``$`)P```"(!`0`@````2@$!`!\```!K`0$`,````(L!`0!I````O`$!
M`#$````F`@$`00```%@"`0`S````F@(!`"4```#.`@$`/0```/0"`0!E````
M,@,!`$T```"8`P$`+P```.8#`0`N````%@0!`#````!%!`$`5````'8$`0!:
M````RP0!`$@````F!0$`2@```&\%`0`R````N@4!`"\```#M!0$`+````!T&
M`0`M````2@8!`'$```!X!@$`9@```.H&`0!O````40<!`+,```#!!P$`%P``
M`'4(`0`E````C0@!`#(```"S"`$`*0```.8(`0`^````$`D!`"(```!/"0$`
M4@```'()`0`E````Q0D!``L```#K"0$`L0```/<)`0!%````J0H!`"$```#O
M"@$`,````!$+`0`E````0@L!`!P```!H"P$`,0```(4+`0`'````MPL!``<`
M``"_"P$`!````,<+`0`-````S`L!``L```#:"P$`#@```.8+`0`%````]0L!
M``(```#["P$`60```/X+`0`%````6`P!``0```!>#`$`!P```&,,`0`(````
M:PP!``4```!T#`$`,````'H,`0`,````JPP!`!,```"X#`$`#0```,P,`0`"
M````V@P!``<```#=#`$`!@```.4,`0`4````[`P!``P````!#0$`&`````X-
M`0`&````)PT!`!(````N#0$`#````$$-`0`#````3@T!`"H```!2#0$`!@``
M`'T-`0`'````A`T!`!\```",#0$`+@```*P-`0`O````VPT!`!<````+#@$`
M(@```",.`0`E````1@X!`!L```!L#@$`&````(@.`0`D````H0X!`!\```#&
M#@$`&@```.8.`0`A`````0\!`"`````C#P$`&@```$0/`0`R````7P\!`!H`
M``"2#P$`+P```*T/`0`K````W0\!`!\````)$`$`(P```"D0`0`?````31`!
M`!H```!M$`$`(0```(@0`0`E````JA`!`"8```#0$`$`)0```/<0`0`D````
M'1$!`!@```!"$0$`'0```%L1`0`D````>1$!`!@```">$0$`(@```+<1`0`L
M````VA$!`!4````'$@$`)0```!T2`0`\````0Q(!`!\```"`$@$`(P```*`2
M`0`?````Q!(!`"````#D$@$`&@````43`0`8````(!,!`"8````Y$P$`*0``
M`&`3`0`>````BA,!`"D```"I$P$`'@```-,3`0`Q````\A,!``P````D%`$`
M+P```#$4`0`D````810!``<```"&%`$`#P```(X4`0`4````GA0!``X```"S
M%`$`#0```,(4`0`D````T!0!``4```#U%`$`!P```/L4`0`B`````Q4!`"4`
M```F%0$`&@```$P5`0`=````9Q4!``<```"%%0$`%0```(T5`0`&````HQ4!
M``D```"J%0$`"P```+05`0`-````P!4!`!<```#.%0$`!@```.85`0`S````
M[14!``<````A%@$`#P```"D6`0`'````.18!`#(```!!%@$`!````'06`0`A
M````>18!`!,```";%@$`#````*\6`0`1````O!8!`#(```#.%@$`%@````$7
M`0`(````&!<!`!T````A%P$`"0```#\7`0`*````21<!`!0```!4%P$`"@``
M`&D7`0`=````=!<!``@```"2%P$`'P```)L7`0`(````NQ<!`!H```#$%P$`
M)P```-\7`0`&````!Q@!`!4````.&`$`!P```"08`0`(````+!@!``D````U
M&`$`/P```#\8`0`'````?Q@!``\```"'&`$`"0```)<8`0`(````H1@!`!,`
M``"J&`$`!P```+X8`0`9````QA@!`!<```#@&`$`%````/@8`0`*````#1D!
M``P````8&0$`%P```"49`0`$````/1D!`"H```!"&0$`#````&T9`0`1````
M>AD!``<```",&0$``@```)09`0`0````EQD!`!@```"H&0$`"P```,$9`0`#
M````S1D!``@```#1&0$`!@```-H9`0`'````X1D!``T```#I&0$`"P```/<9
M`0`4`````QH!`!4````8&@$`#@```"X:`0`O````/1H!`"````!M&@$`'```
M`(X:`0`5````JQH!``P```#!&@$`,0```,X:`0`2`````!L!`#\````3&P$`
M!````%,;`0`$````6!L!``H```!=&P$`$P```&@;`0`%````?!L!``8```""
M&P$`!@```(D;`0`(````D!L!``0```"9&P$`#````)X;`0`*````JQL!`#D`
M``"V&P$`+@```/`;`0`I````'QP!``4```!)'`$`&````$\<`0`9````:!P!
M`!\```""'`$`'0```*(<`0`1````P!P!``(```#2'`$`!````-4<`0`*````
MVAP!``8```#E'`$`!0```.P<`0`#````\AP!``P```#V'`$`,@````,=`0`:
M````-AT!`#0```!1'0$`*````(8=`0!3````KQT!`!D````#'@$`<@```!T>
M`0`@````D!X!`#4```"Q'@$`(0```.<>`0!%````"1\!`"@```!/'P$`*0``
M`'@?`0`F````HA\!`"4```#)'P$`*````.\?`0`H````&"`!`"(```!!(`$`
M*P```&0@`0`P````D"`!`!(```#!(`$`$P```-0@`0`0````Z"`!`'D```#Y
M(`$`"0```',A`0"A````?2$!`',````?(@$`?````),B`0`K````$",!`%0`
M```\(P$`%P```)$C`0`G````J2,!`!8```#1(P$`#P```.@C`0`7````^",!
M`!\````0)`$`0````#`D`0`?````<20!`!P```"1)`$`40```*XD`0`:````
M`"4!`!0````;)0$`"@```#`E`0`%````.R4!``8```!!)0$`"````$@E`0`2
M````424!`!````!D)0$`$P```'4E`0`=````B24!``\```"G)0$`!````+<E
M`0`)````O"4!``<```#&)0$`!0```,XE`0`'````U"4!``@```#<)0$`"```
M`.4E`0`,````[B4!``8```#[)0$`!@````(F`0`,````"28!`!$````6)@$`
M"````"@F`0`$````,28!`!D````V)@$`$0```%`F`0`*````8B8!`!@```!M
M)@$`$P```(8F`0`<````FB8!`!$```"W)@$`!````,DF`0`/````SB8!``<`
M``#>)@$`!````.8F`0`9````ZR8!``<````%)P$``@````TG`0`"````$"<!
M`!$````3)P$`"0```"4G`0`&````+R<!`!(````V)P$`%P```$DG`0`&````
M82<!`"<```!H)P$``@```)`G`0`$````DR<!``\```"8)P$`$P```*@G`0`'
M````O"<!`!$```#$)P$`&````-8G`0`&````[R<!`!,```#V)P$`$`````HH
M`0`2````&R@!``(````N*`$`!@```#$H`0`,````."@!``D```!%*`$`$0``
M`$\H`0`B````82@!``<```"$*`$`!P```(PH`0`+````E"@!``4```"@*`$`
M`@```*8H`0`+````J2@!`#$!``"U*`$`$````.<I`0`4````^"D!``P````-
M*@$`!P```!HJ`0`&````(BH!``D````I*@$`!````#,J`0`.````."H!`!D`
M``!'*@$`(P```&$J`0`@````A2H!`"4```"F*@$`)P```,PJ`0`6````]"H!
M`#$````+*P$`"P```#TK`0`:````22L!`!$```!D*P$`%0```'8K`0`(````
MC"L!``4```"5*P$`(````)LK`0`(````O"L!``H```#%*P$`"0```-`K`0`/
M````VBL!``L```#J*P$`AP```/8K`0`.````?BP!``@```"-+`$`#````)8L
M`0`.````HRP!``D```"R+`$`"@```+PL`0`+````QRP!``L```#3+`$`!@``
M`-\L`0"I````YBP!``D```"0+0$`#@```)HM`0`;````J2T!``P```#%+0$`
M#````-(M`0`,````WRT!``4```#L+0$`$@```/(M`0`W````!2X!`!L````]
M+@$`,P```%DN`0`V````C2X!`%,```#$+@$`3P```!@O`0!5````:"\!`%4`
M``"^+P$`.````!0P`0`(````33`!`!,```!6,`$`#0```&HP`0`.````>#`!
M`!<```"',`$`!0```)\P`0`&````I3`!``<```"L,`$`*P```+0P`0`N````
MX#`!``T````/,0$`#````!TQ`0`'````*C$!``<````R,0$`!0```#HQ`0`3
M````0#$!`!<```!4,0$`"@```&PQ`0`2````=S$!`!4```"*,0$`&````*`Q
M`0`<````N3$!`!@```#6,0$`#0```.\Q`0`1````_3$!``D````/,@$`'P``
M`!DR`0`/````.3(!`!,```!),@$`$````%TR`0!3````;C(!`"T```#",@$`
M)@```/`R`0`&````%S,!``8````>,P$`)0```"4S`0`+````2S,!``<```!7
M,P$`"@```%\S`0`(````:C,!``D```!S,P$`!P```'TS`0`#````A3,!`!<`
M``"),P$`"P```*$S`0`.````K3,!`!H```"\,P$`$P```-<S`0`-````ZS,!
M`"````#Y,P$`%0```!HT`0`@````,#0!`!T```!1-`$`$0```&\T`0`1````
M@30!`"4```"3-`$`%0```+DT`0`&````SS0!``8```#6-`$`"````-TT`0`.
M````YC0!``<```#U-`$`"@```/TT`0`2````"#4!``H````;-0$`$````"8U
M`0`:````-S4!`!D```!2-0$`!@```&PU`0`%````<S4!`!8```!Y-0$`&```
M`)`U`0`*````J34!`$(```"T-0$`0````/<U`0`)````.#8!``@```!"-@$`
M%````$LV`0`(````8#8!``4```!I-@$`#@```&\V`0`6````?C8!`#(```"5
M-@$`$````,@V`0`D````V38!`"D```#^-@$`*@```"@W`0`E````4S<!``D`
M``!Y-P$`!@```(,W`0`*````BC<!``@```"5-P$`,@```)XW`0`O````T3<!
M`#$````!.`$`6P```#,X`0`G````CS@!`#````"W.`$`/0```.@X`0!"````
M)CD!`#````!I.0$`00```)HY`0`L````W#D!`"T````).@$`0````#<Z`0`P
M````>#H!`#L```"I.@$`)0```.4Z`0`4````"SL!`!<````@.P$`)@```#@[
M`0`E````7SL!`"4```"%.P$`$P```*L[`0`-````OSL!``\```#-.P$`&```
M`-T[`0`C````]CL!``8````:/`$`!P```"$\`0`4````*3P!``H````^/`$`
M"````$D\`0`P````4CP!``H```"#/`$`!P```(X\`0`&````ECP!``4```"=
M/`$`#P```*,\`0`%````LSP!``L```"Y/`$`*@```,4\`0`3````\#P!``P`
M```$/0$`"````!$]`0`,````&CT!`!0````G/0$`!0```#P]`0`'````0CT!
M`!$```!*/0$`"0```%P]`0`E````9CT!``8```",/0$`"0```),]`0`,````
MG3T!``<```"J/0$``P```+(]`0`#````MCT!`!D```"Z/0$`*@```-0]`0`'
M````_ST!``<````'/@$`"0````\^`0`'````&3X!`"@````A/@$`-0```$H^
M`0`A````@#X!``8```"B/@$`!P```*D^`0`@````L3X!`#8```#2/@$`(0``
M``D_`0`;````*S\!`#<```!'/P$`-P```'\_`0`?````MS\!`"<```#7/P$`
M50```/\_`0`]````54`!`#0```"30`$`&0```,A``0`0````XD`!``L```#S
M0`$`%````/]``0`/````%$$!``\````D00$`#P```#1!`0`5````1$$!`!P`
M``!:00$`'````'=!`0`4````E$$!`!````"I00$`$````+I!`0`#````RT$!
M``@```#/00$`%@```-A!`0!Y````[T$!`%0```!I0@$`!0```+Y"`0`(````
MQ$(!`",```#-0@$`(0```/%"`0`2````$T,!``P````F0P$`%P```#-#`0`6
M````2T,!``\```!B0P$`)````')#`0`%````ET,!`!,```"=0P$`(@```+%#
M`0`3````U$,!`!L```#H0P$`#@````1$`0`7````$T0!`!8````K1`$`"@``
M`$)$`0`&````340!`!````!41`$`"````&5$`0`.````;D0!`!4```!]1`$`
M"0```)-$`0`%````G40!``X```"C1`$`#@```+)$`0`/````P40!``8```#1
M1`$`!````-A$`0`-````W40!``@```#K1`$`"@```/1$`0`'````_T0!``<`
M```'10$`#`````]%`0`*````'$4!``H````G10$`$@```#)%`0`I````144!
M`"(```!O10$`"@```))%`0`,````G44!``4```"J10$`'@```+!%`0`3````
MST4!`!,```#C10$`,@```/=%`0!"````*D8!`"4```!M1@$`!0```)-&`0`M
M````F48!`!T```#'1@$`#@```.5&`0`(````]$8!``T```#]1@$`"0````M'
M`0`7````%4<!``L````M1P$`"0```#E'`0`6````0T<!`"(```!:1P$`'@``
M`'U'`0`H````G$<!`"0```#%1P$`'0```.I'`0`G````"$@!`"(````P2`$`
M)P```%-(`0!"````>T@!`"X```"^2`$`)0```.U(`0`G````$TD!`!T````[
M20$`+P```%E)`0`Y````B4D!`#8```##20$`)P```/I)`0`X````(DH!`#\`
M``!;2@$`)0```)M*`0`;````P4H!`#L```#=2@$`(P```!E+`0`6````/4L!
M`#4```!42P$`(````(I+`0`C````JTL!`!<```#/2P$`N0```.=+`0`:````
MH4P!`"(```"\3`$`,P```-],`0`S````$TT!`!H```!'30$`,0```&)-`0`=
M````E$T!`"4```"R30$`,P```-A-`0`V````#$X!`#T```!#3@$`0````(%.
M`0"5````PDX!`",```!83P$`)@```'Q/`0`?````HT\!`"\```##3P$`+0``
M`/-/`0`P````(5`!`$,```!24`$`$P```)90`0`'````JE`!``<```"R4`$`
M!P```+I0`0`,````PE`!``\```#/4`$`#P```-]0`0`;````[U`!``@````+
M40$`!````!11`0`:````&5$!``P````T40$`#````$%1`0`2````3E$!``T`
M``!A40$`#P```&]1`0`\````?U$!``4```"\40$`$````,)1`0`7````TU$!
M`!P```#K40$`$0````A2`0`"````&E(!`$P````=4@$`!@```&I2`0`A````
M<5(!`!<```"34@$`!0```*M2`0`-````L5(!``T```"_4@$``P```,U2`0`(
M````T5(!``@```#:4@$`#@```.-2`0`3````\E(!``\````&4P$`"P```!93
M`0`'````(E,!``\````J4P$`#P```#I3`0`2````2E,!`"````!=4P$`)P``
M`'Y3`0`3````IE,!`!L```"Z4P$`,@```-93`0`;````"50!`!$````E5`$`
M.@```#=4`0`,````<E0!``8```!_5`$`$````(94`0`$````EU0!`"H```"<
M5`$`+P```,=4`0`&````]U0!``D```#^5`$`&P````A5`0`*````)%4!``8`
M```O50$`(P```#95`0`7````6E4!`!D```!R50$`%@```(Q5`0`1````HU4!
M`!X```"U50$`"````-15`0`*````W54!`"D```#H50$`/P```!)6`0`(````
M4E8!`!8```!;5@$`)@```')6`0`*````F58!`#,```"D5@$`#@```-A6`0`(
M````YU8!`!(```#P5@$`1P````-7`0`#````2U<!``<```!/5P$`!0```%=7
M`0`-````75<!``T```!K5P$`$````'E7`0`0````BE<!`!<```";5P$`$P``
M`+-7`0`8````QU<!`!8```#@5P$`#@```/=7`0`%````!E@!``@````,6`$`
M$@```!58`0`2````*%@!`",````[6`$`(````%]8`0`0````@%@!``<```"1
M6`$`$P```)E8`0`0````K5@!``\```"^6`$`,P```,Y8`0`>`````ED!``H`
M```A60$`A@```"Q9`0`6````LUD!`!0```#*60$`"````-]9`0`&````Z%D!
M`"(```#O60$`,````!):`0`P````0UH!`!L```!T6@$`(0```)!:`0`B````
MLEH!`!@```#56@$`"````.Y:`0`(````]UH!``@`````6P$`!@````E;`0`/
M````$%L!``X````@6P$`$````"];`0`.````0%L!``T```!/6P$`#0```%U;
M`0`,````:UL!`!$```!X6P$`!@```(I;`0`(````D5L!``\```":6P$`.@``
M`*I;`0`0````Y5L!``D```#V6P$`&@````!<`0`A````&UP!`"8````]7`$`
M)0```&1<`0`=````BEP!`!T```"H7`$`*0```,9<`0`;````\%P!`!<````,
M70$`"````"1=`0`1````+5T!``T````_70$`#````$U=`0`#````6ET!``0`
M``!>70$`!P```&-=`0`0````:UT!`!$```!\70$`#0```(Y=`0`7````G%T!
M``T```"T70$`#@```,)=`0`-````T5T!``8```#?70$`"````.9=`0`;````
M[UT!`!L````+7@$`$@```"=>`0`,````.EX!`!````!'7@$`$````%A>`0`;
M````:5X!``8```"%7@$`!@```(Q>`0`-````DUX!``X```"A7@$`$````+!>
M`0`%````P5X!``4```#'7@$`$P```,U>`0`%````X5X!``T```#G7@$`+@``
M`/5>`0`9````)%\!``8````^7P$`!@```$5?`0`&````3%\!``8```!37P$`
M"````%I?`0`/````8U\!``T```!S7P$``@```(%?`0`(````A%\!`!X```"-
M7P$`$@```*Q?`0`5````OU\!`!L```#57P$``@```/%?`0`#````]%\!``H`
M``#X7P$`"@````-@`0`)````#F`!``4````88`$`!P```!Y@`0`5````)F`!
M``X````\8`$`!P```$M@`0`(````4V`!``0```!<8`$`"0```&%@`0`(````
M:V`!`!(```!T8`$`!0```(=@`0`-````C6`!`!````";8`$`$````*Q@`0`'
M````O6`!`!,```#%8`$`"P```-E@`0`'````Y6`!`!@```#M8`$`(0````9A
M`0`^````*&$!`"@```!G80$`*0```)!A`0`'````NF$!``H```#"80$`!```
M`,UA`0`)````TF$!``@```#<80$`$P```.5A`0`-````^6$!``<````'8@$`
M#@````]B`0`'````'F(!``0````F8@$`'0```"MB`0`%````26(!``X```!/
M8@$`!P```%YB`0`%````9F(!``4```!L8@$`(0```')B`0`.````E&(!`!@`
M``"C8@$`!P```+QB`0`&````Q&(!``H```#+8@$`!P```-9B`0`;````WF(!
M``8```#Z8@$`!0````%C`0`'````!V,!``X````/8P$`!@```!YC`0`/````
M)6,!``@````U8P$`"0```#YC`0`%````2&,!`#T```!.8P$`.0```(QC`0`\
M````QF,!`"@````#9`$`0@```"QD`0`S````;V0!`"P```"C9`$`/@```-!D
M`0`P````#V4!`"T```!`90$`(0```&YE`0`=````D&4!``D```"N90$`"P``
M`+AE`0`)````Q&4!``H```#.90$`*@```-EE`0`G````!&8!`#$````L9@$`
M"0```%YF`0`:````:&8!`"8```"#9@$`#0```*IF`0`)````N&8!``H```#"
M9@$`"P```,UF`0`1````V68!`!4```#K9@$`-@````%G`0!U````.&<!``L`
M``"N9P$`!0```+IG`0`.````P&<!`!(```#/9P$`#P```.)G`0`;````\F<!
M`"D````.:`$`B@```#AH`0`&````PV@!`!4```#*:`$`"@```.!H`0`6````
MZV@!`"$````":0$`&@```"1I`0!"````/VD!`!,```"":0$`,@```)9I`0!`
M````R6D!`!\````*:@$`#0```"IJ`0`4````.&H!`",```!-:@$`&````'%J
M`0`6````BFH!`!0```"A:@$`)0```+9J`0`=````W&H!`!P```#Z:@$`'```
M`!=K`0`8````-&L!`!,```!-:P$`(0```&%K`0`E````@VL!`!\```"I:P$`
M&0```,EK`0`8````XVL!`!0```#\:P$`&@```!%L`0`<````+&P!`!H```!)
M;`$`&@```&1L`0`/````?VP!``L```"/;`$`&````)ML`0`$````M&P!``4`
M``"Y;`$`$0```+]L`0`&````T6P!``H```#8;`$`!P```.-L`0`'````ZVP!
M``8```#S;`$`"````/IL`0`6`````VT!``8````:;0$`"0```"%M`0`%````
M*VT!``4````Q;0$`"0```#=M`0`2````06T!``8```!4;0$`)````%MM`0`.
M````@&T!``\```"/;0$`#0```)]M`0`0````K6T!``P```"^;0$`$````,MM
M`0`R````W&T!``8````/;@$`"0```!9N`0`H````(&X!`!(```!);@$`$0``
M`%QN`0`'````;FX!``H```!V;@$`!0```(%N`0`D````AVX!``\```"L;@$`
M&````+QN`0`0````U6X!`!,```#F;@$`$P```/IN`0`8````#F\!`!8````G
M;P$`"````#YO`0`%````1V\!``<```!-;P$`#0```%5O`0`1````8V\!``8`
M``!U;P$`!0```'QO`0`(````@F\!``<```"+;P$`#@```)-O`0`,````HF\!
M``H```"O;P$`$0```+IO`0`0````S&\!``4```#=;P$`$````.-O`0`*````
M]&\!``X```#_;P$`"`````YP`0!#````%W`!``@```!;<`$`#P```&1P`0`B
M````='`!`!8```"7<`$`$P```*YP`0`,````PG`!``\```#/<`$`#P```-]P
M`0`1````[W`!`!$````!<0$`#@```!-Q`0`.````(G$!``T````Q<0$`(```
M`#]Q`0`A````8'$!`!T```""<0$`"@```*!Q`0`&````JW$!``H```"R<0$`
M#0```+UQ`0`,````RW$!``4```#8<0$`!P```-YQ`0`=````YG$!``8````$
M<@$`!P````MR`0`3````$W(!`$$````G<@$`$0```&ER`0`.````>W(!``@`
M``"*<@$`!0```)-R`0`*````F7(!``(```"D<@$`$````*=R`0`G````N'(!
M``,```#@<@$`!0```.1R`0`L````ZG(!``H````7<P$`"````")S`0`2````
M*W,!`!0````^<P$`!@```%-S`0`(````6G,!``<```!C<P$`!````&MS`0`%
M````<',!`&0```!V<P$`#P```-MS`0`2````ZW,!`!(```#^<P$`!0```!%T
M`0`E````%W0!`#D````]=`$`$P```'=T`0`*````BW0!``T```"6=`$`"P``
M`*1T`0`)````L'0!`!@```"Z=`$`*````--T`0`E````_'0!`"0````B=0$`
M(@```$=U`0`3````:G4!``,```!^=0$`!P```()U`0`3````BG4!``8```">
M=0$`"P```*5U`0`*````L74!`%\```"\=0$`%@```!QV`0`.````,W8!``L`
M``!"=@$`&P```$YV`0`O````:G8!`!,```":=@$`"````*YV`0`:````MW8!
M`"D```#2=@$`"0```/QV`0`&````!G<!`"`````-=P$`#````"YW`0`D````
M.W<!`",```!@=P$`)@```(1W`0`(````JW<!``T```"T=P$`)````,)W`0`9
M````YW<!`"\````!>`$`$P```#%X`0`"````17@!``X```!(>`$`!@```%=X
M`0`/````7G@!``8```!N>`$`%````'5X`0`&````BG@!``D```"1>`$`#0``
M`)MX`0`(````J7@!``H```"R>`$`"P```+UX`0`S````R7@!``8```#]>`$`
M#P````1Y`0`2````%'D!`!X````G>0$`$0```$9Y`0`.````6'D!`!$```!G
M>0$`$@```'EY`0`.````C'D!``X```";>0$`#@```*IY`0`(````N7D!`!T`
M``#">0$`%@```.!Y`0`1````]WD!``H````)>@$`%@```!1Z`0`*````*WH!
M`!<````V>@$`!P```$YZ`0`2````5GH!``,```!I>@$`"````&UZ`0`%````
M=GH!``4```!\>@$`"@```()Z`0`1````C7H!`!0```"?>@$`&P```+1Z`0`;
M````T'H!`!D```#L>@$`&`````9[`0`;````'WL!`!@````[>P$`&````%1[
M`0`(````;7L!``8```!V>P$`#P```'U[`0`/````C7L!``D```"=>P$`%0``
M`*=[`0`.````O7L!``H```#,>P$`&0```-=[`0`7````\7L!``8````)?`$`
M$P```!!\`0`)````)'P!`!,````N?`$`$@```$)\`0`*````57P!``D```!@
M?`$`!0```&I\`0`(````<'P!``4```!Y?`$`!````']\`0`'````A'P!`#P`
M``",?`$`+0```,E\`0`3````]WP!`"4````+?0$`)@```#%]`0`.````6'T!
M`"\```!G?0$`-````)=]`0`B````S'T!`",```#O?0$`+````!-^`0`5````
M0'X!``X```!6?@$`%@```&5^`0`/````?'X!`!4```",?@$`%0```*)^`0`>
M````N'X!`!P```#7?@$`(0```/1^`0`9````%G\!`'0````P?P$`'@```*5_
M`0`?````Q'\!`!D```#D?P$`$````/Y_`0`I````#X`!`#4````Y@`$`(P``
M`&^``0`.````DX`!`$\```"B@`$`2@```/*``0`'````/8$!`!8```!%@0$`
M$````%R!`0`/````;8$!`!<```!]@0$`"0```)6!`0`*````GX$!``<```"J
M@0$`"0```+*!`0`,````O($!``L```#)@0$`!P```-6!`0`N````W8$!``@`
M```,@@$`"````!6"`0`/````'H(!`!$````N@@$`#P```$""`0!#````4((!
M``8```"4@@$`%0```)N"`0`(````L8(!``<```"Z@@$`!P```,*"`0`J````
MRH(!``L```#U@@$`&`````&#`0`$````&H,!`#(````?@P$`%````%*#`0`E
M````9X,!`%X```"-@P$`$@```.R#`0!$````_X,!`!$```!$A`$`"0```%:$
M`0`/````8(0!``P```!PA`$`%````'V$`0`,````DH0!`!H```"?A`$`%@``
M`+J$`0`%````T80!`!(```#7A`$`$P```.J$`0`3````_H0!`!8````2A0$`
M%````"F%`0`4````/H4!``\```!3A0$`'@```&.%`0`(````@H4!``H```"+
MA0$`$P```):%`0`-````JH4!``\```"XA0$`#@```,B%`0`8````UX4!``X`
M``#PA0$`$````/^%`0`;````$(8!``H````LA@$`"````#>&`0`%````0(8!
M`!X```!&A@$`!@```&6&`0`2````;(8!``@```!_A@$`#@```(B&`0`%````
MEX8!`!H```"=A@$`$````+B&`0`F````R88!`!(```#PA@$`!@````.'`0`'
M````"H<!`!8````2AP$`!P```"F'`0`2````,8<!``8```!$AP$`&0```$N'
M`0`F````98<!``H```",AP$`'0```)>'`0`8````M8<!``H```#.AP$`%@``
M`-F'`0`2````\(<!``0````#B`$`#`````B(`0`(````%8@!``<````>B`$`
M"P```":(`0`(````,H@!`"(````[B`$`*````%Z(`0`G````AX@!`$0```"O
MB`$`(@```/2(`0`G````%XD!`#(````_B0$`9@```'*)`0`D````V8D!``<`
M``#^B0$`"`````:*`0`&````#XH!``L````6B@$`)@```"**`0`;````28H!
M`!0```!EB@$`,````'J*`0`$````JXH!`!<```"PB@$`!@```,B*`0`)````
MSXH!`!,```#9B@$`#@```.V*`0`'````_(H!`!4````$BP$`"````!J+`0`3
M````(XL!``P````WBP$`&0```$2+`0`;````7HL!`#4```!ZBP$`"0```+"+
M`0`4````NHL!``4```#/BP$`"0```-6+`0`%````WXL!`!L```#EBP$`#@``
M``&,`0`$````$(P!``P````5C`$`#0```"*,`0`%````,(P!``P````VC`$`
M"P```$.,`0`&````3XP!``@```!6C`$`!````%^,`0`/````9(P!`$<```!T
MC`$`:0```+R,`0`'````)HT!`"(````NC0$`#P```%&-`0`%````88T!`!$`
M``!GC0$`#P```'F-`0`(````B8T!`!0```"2C0$`+````*>-`0`(````U(T!
M`!````#=C0$`#````.Z-`0`X````^XT!`!,````TC@$`&````$B.`0`T````
M88X!`!X```"6C@$`.````+6.`0`Y````[HX!`"4````HCP$`$@```$Z/`0`)
M````88\!``\```!KCP$`%P```'N/`0`9````DX\!``<```"MCP$`%````+6/
M`0`;````RH\!``\```#FCP$`%````/:/`0`J````"Y`!``8````VD`$`#0``
M`#V0`0`/````2Y`!``@```!;D`$`"````&20`0`,````;9`!``T```!ZD`$`
M#@```(B0`0`'````EY`!``8```"?D`$`!@```*:0`0`<````K9`!`!H```#*
MD`$`&````.60`0`.````_I`!``H````-D0$`(0```!B1`0`#````.I$!``4`
M```^D0$`"@```$21`0`"````3Y$!``P```!2D0$`%@```%^1`0`+````=I$!
M`!H```""D0$`&@```)V1`0`%````N)$!``H```"^D0$`%````,F1`0`6````
MWI$!``\```#UD0$`!@````62`0`+````#)(!``H````8D@$`$````".2`0!>
M````-)(!`!H```"3D@$`,P```*Z2`0`=````XI(!``<`````DP$`!@````B3
M`0`)````#Y,!``\````9DP$`#````"F3`0`E````-I,!`!8```!<DP$`$```
M`'.3`0`G````A),!``H```"LDP$`$P```+>3`0`.````RY,!``T```#:DP$`
M:@```.B3`0`6````4Y0!`!4```!JE`$`+P```("4`0`4````L)0!`!(```#%
ME`$`'P```-B4`0`A````^)0!``\````:E0$`&P```"J5`0`+````1I4!``<`
M``!2E0$`!P```%J5`0`)````8I4!`!0```!LE0$`$@```(&5`0`R````E)4!
M`!,```#'E0$`$P```-N5`0`$````[Y4!``<```#TE0$`3P```/R5`0!*````
M3)8!`"P```"7E@$`/0```,26`0`'`````I<!`#$````*EP$`)0```#R7`0`(
M````8I<!``L```!KEP$`#P```'>7`0`H````AY<!``<```"PEP$`3````+B7
M`0`H````!9@!`"4````NF`$`'````%28`0`J````<9@!`"$```"<F`$`#P``
M`+Z8`0`%````SI@!``T```#4F`$`#@```.*8`0`0````\9@!``8````"F0$`
M+@````F9`0`,````.)D!``H```!%F0$`!@```%"9`0`4````5YD!``@```!L
MF0$`"````'69`0`6````?ID!``D```"5F0$`"0```)^9`0`$````J9D!``T`
M``"NF0$`#0```+R9`0`5````RID!`!8```#@F0$`#@```/>9`0`B````!IH!
M`!`````IF@$`"````#J:`0`0````0YH!`!8```!4F@$`"P```&N:`0`-````
M=YH!`!P```"%F@$`)P```**:`0`.````RIH!``L```#9F@$`"````.6:`0`2
M````[IH!`!4````!FP$`!P```!>;`0`*````'YL!``H````JFP$`#0```#6;
M`0`-````0YL!`!0```!1FP$`!@```&:;`0`1````;9L!``P```!_FP$`%```
M`(R;`0`;````H9L!``(```"]FP$`%@```,";`0`&````UYL!``D```#>FP$`
M7P```.B;`0`%````2)P!`"(```!.G`$`)P```'&<`0`;````F9P!`"<```"U
MG`$`3P```-V<`0`R````+9T!`#T```!@G0$`(0```)Z=`0`8````P)T!``4`
M``#9G0$`#0```-^=`0`-````[9T!``<```#[G0$`#0````.>`0`3````$9X!
M``T````EG@$`#0```#.>`0`.````09X!``<```!0G@$`!P```%B>`0`'````
M8)X!`!4```!HG@$`!0```'Z>`0`(````A)X!``8```"-G@$`(0```)2>`0`.
M````MIX!`"(```#%G@$`&@```.B>`0`'`````Y\!`!P````+GP$`$@```"B?
M`0`,````.Y\!`!$```!(GP$`!@```%J?`0`8````89\!``P```!ZGP$`'@``
M`(>?`0`(````II\!`!0```"OGP$`&0```,2?`0`+````WI\!``T```#JGP$`
M*````/B?`0`6````(:`!`!,````XH`$`"````$R@`0`-````5:`!``(```!C
MH`$`!@```&:@`0`3````;:`!`!D```"!H`$`)P```)N@`0`G````PZ`!`"X`
M``#KH`$`*P```!JA`0`W````1J$!`$$```!^H0$`1P```,"A`0!.````"*(!
M`#X```!7H@$`&````):B`0`S````KZ(!`"X```#CH@$`+P```!*C`0`E````
M0J,!`!\```!HHP$`/0```(BC`0!Z````QJ,!`#0```!!I`$`(````':D`0`W
M````EZ0!`%\```#/I`$`/@```"^E`0`S````;J4!`#$```"BI0$`'P```-2E
M`0`;````]*4!`"`````0I@$`,````#&F`0`^````8J8!`"<```"AI@$`&```
M`,FF`0`:````XJ8!`!H```#]I@$`'@```!BG`0!6````-Z<!`#4```".IP$`
M-@```,2G`0`V````^Z<!`#`````RJ`$`2````&.H`0!P````K*@!`$8````=
MJ0$`*@```&2I`0`N````CZD!`"X```"^J0$`6````.VI`0!@````1JH!`$\`
M``"GJ@$`20```/>J`0`D````0:L!`!D```!FJP$`'````("K`0`C````G:L!
M`$0```#!JP$`/0````:L`0!#````1*P!`(T```"(K`$`%````!:M`0`H````
M*ZT!`"X```!4K0$`(P```(.M`0!&````IZT!`"````#NK0$`2P````^N`0`?
M````6ZX!``D```![K@$`N@```(6N`0!#````0*\!`!\```"$KP$`,0```*2O
M`0`>````UJ\!`"````#UKP$`*````!:P`0`%````/[`!``<```!%L`$`!```
M`$VP`0`-````4K`!``P```!@L`$`#````&VP`0`&````>K`!``(```"!L`$`
M;0```(2P`0`#````\K`!``0```#VL`$`!P```/NP`0`'`````[$!``4````+
ML0$`+````!&Q`0`,````/K$!`!(```!+L0$`"0```%ZQ`0`#````:+$!``@`
M``!LL0$`!P```'6Q`0`4````?;$!``P```"2L0$`%P```)^Q`0`&````M[$!
M`!@```"^L0$`#````->Q`0`#````Y+$!`"\```#HL0$`!@```!BR`0`(````
M'[(!`!T````HL@$`,0```$:R`0`L````>+(!`!H```"EL@$`'````,"R`0`I
M````W;(!`!L````'LP$`'P```".S`0`@````0[,!`!\```!DLP$`(````(2S
M`0`@````I;,!`"````#&LP$`'````.>S`0`H````!+0!`!P````MM`$`*```
M`$JT`0`;````<[0!`!L```"/M`$`(P```*NT`0`A````S[0!`"````#QM`$`
M(0```!*U`0`;````-+4!`"4```!0M0$`*````':U`0`:````G[4!`"$```"Z
MM0$`'@```-RU`0`P````^[4!`!X````LM@$`)0```$NV`0`I````<;8!`",`
M``";M@$`*````+^V`0`N````Z+8!`"(````7MP$`)@```#JW`0`H````8;<!
M`"D```"*MP$`(P```+2W`0`:````V+<!`"L```#SMP$`,P```!^X`0`D````
M4[@!`"H```!XN`$`*@```*.X`0`T````SK@!`!0````#N0$`,0```!BY`0`R
M````2KD!``P```!]N0$`#@```(JY`0`9````F;D!`!0```"SN0$`$0```,BY
M`0`F````VKD!``4````!N@$`"0````>Z`0`G````$;H!`#$````YN@$`%0``
M`&NZ`0`C````@;H!``H```"EN@$`%0```+"Z`0`(````QKH!``L```#/N@$`
M%0```-NZ`0`1````\;H!`"`````#NP$`!P```"2[`0`Y````++L!``<```!F
MNP$`$P```&Z[`0`+````@KL!`$,```".NP$`"0```-*[`0`?````W+L!`!0`
M``#\NP$`%P```!&\`0`7````*;P!`#@```!!O`$`'0```'J\`0`0````F+P!
M`"<```"IO`$`$@```-&\`0`2````Y+P!`!P```#WO`$`"@```!2]`0`6````
M'[T!``D````VO0$`(0```$"]`0`*````8KT!`"(```!MO0$`*````)"]`0`)
M````N;T!`!L```##O0$`!P```-^]`0`*````Y[T!``D```#RO0$`0````/R]
M`0`*````/;X!``H```!(O@$`"P```%.^`0`'````7[X!`!,```!GO@$`"0``
M`'N^`0`?````A;X!`!H```"EO@$`%````,"^`0`*````U;X!``L```#@O@$`
M&@```.R^`0`)````![\!`"P````1OP$`#@```#Z_`0`0````3;\!``D```!>
MOP$``@```&B_`0`1````:[\!`!H```!]OP$`"P```)B_`0`%````I+\!``T`
M``"JOP$`"````+B_`0`+````P;\!`"L```#-OP$`#P```/F_`0`4````"<`!
M`!0````>P`$`#@```#/``0`N````0L`!`!D```!QP`$`&0```(O``0`<````
MI<`!`!````#"P`$`,@```-/``0`4````!L$!`$`````;P0$`!````%S!`0`'
M````8<$!`!````!IP0$`%@```'K!`0`&````D<$!``<```"8P0$`!P```*#!
M`0`,````J,$!``<```"UP0$`$````+W!`0`1````SL$!`$$```#@P0$`-@``
M`"+"`0`K````6<(!``4```"%P@$`%P```(O"`0`B````H\(!`!X```#&P@$`
M'@```.7"`0`2````!,,!``(````7PP$`!````!K#`0`0````'\,!``4````P
MPP$`!0```#;#`0`#````/,,!`!````!`PP$`+P```%'#`0`1````@<,!`"(`
M``"3PP$`,````+;#`0!2````Y\,!`!0````ZQ`$`;P```$_$`0`B````O\0!
M`$(```#BQ`$`'@```"7%`0!*````1,4!`"D```"/Q0$`/@```+G%`0!`````
M^,4!`#P````YQ@$`0````';&`0`J````M\8!`!X```#BQ@$`+@````''`0!(
M````,,<!`!@```!YQP$`#````)+'`0`-````G\<!`&T```"MQP$`"@```!O(
M`0"K````)L@!`',```#2R`$`<0```$;)`0`F````N,D!`&P```#?R0$`&P``
M`$S*`0`N````:,H!`!,```"7R@$`"@```*O*`0`9````MLH!`!T```#0R@$`
M-@```.[*`0`F````)<L!`"(```!,RP$`90```&_+`0`7````U<L!`!H```#M
MRP$`"P````C,`0`$````%,P!``<````9S`$`"````"',`0`9````*LP!`!0`
M``!$S`$`'````%G,`0`G````=LP!`!(```">S`$`!````+',`0`)````MLP!
M``@```#`S`$`!@```,G,`0`'````T,P!``8```#8S`$`"0```-_,`0`*````
MZ<P!``@```#TS`$`"P```/W,`0`&````"<T!`!`````0S0$`!P```"'-`0`%
M````*<T!`",````OS0$`%@```%/-`0`)````:LT!`"````!TS0$`%@```)7-
M`0`F````K,T!`!8```#3S0$`!0```.K-`0`;````\,T!``@````,S@$`"```
M`!7.`0`2````'LX!``8````QS@$``@```#C.`0`"````.\X!`!8````^S@$`
M!0```%7.`0`-````6\X!`!4```!IS@$`&0```'_.`0`'````F<X!`"\```"A
MS@$``@```-'.`0`#````U,X!``T```#8S@$`#@```.;.`0`(````]<X!`!@`
M``#^S@$`'````!?/`0`+````-,\!`!,```!`SP$`#P```%3/`0`4````9,\!
M``(```!YSP$`"````'S/`0`1````A<\!``\```"7SP$`$````*?/`0`D````
MN,\!``8```#=SP$`"@```.3/`0`2````[\\!``D````"T`$``@````S0`0`+
M````#]`!``$```#M````UP,``&D```!M`0```````/<%```H!@``1P$``$L#
M``#H!0```````-L#``#A!0``:@```*$$````````9P,``!D$``!#!0``K04`
M`&<!```A!@````````````"1`0``DP4````````"`0``R`4``&L$````````
MU`0``+4%``"_````)0$``#,$``#3!```00````H&``"?````8@$``"8!``"F
M`0```````(P$``"S``````````````!(`0```````$X"`````````````(X!
M`````````````%D&`````````````````````````````$````!L!0``^04`
M````````````A0$``#8$```@!````````'<!``!C!0```````(H&``#>!0``
M5@8``!D"`````````@,`````````````&P$``(D"``#B`0``:0,```````"J
M`@```````!\%``#&!0``NP0``#T```#F!```30,``)X```!=!0``````````
M```H````-@(```````"@````7P$``#\&```<`@``````````````````;0(`
M`'L%````````5`,``-H"``"!`@``2P8````````H`0``50,``(H#```G!@``
M[`$``````````````````'<&```T````I`$````%``"@`@``:`$```````!F
M!```C`$```````"S`P```````#D!``#M!0``)P$``,D!```W!0``4@,``%,#
M``"[`P``KP0``"<%```7````LP0``%$&````````/@$``/D$``!N`0``.@8`
M`"T#``!6````_0$``'8!```"!```7P```/$```!<!@``\0$```````#4`@``
MO@,``!L%``!]`@``9`0``'<%`````````````.X"``#L!```OP,``#H"````
M````;P0```P%```E````7`0``#L```!T!0``P00``.\!```C!@``.04``,P"
M```V!@``R0``````````````Z`(`````````````G`0``/0$``!^````````
M`+P"``"H`````````$<```!J!@``<@```(4%````````A@4``%P%``#9````
MB`4``#X```#O!```*00``)<`````````T@```%X````>!````````$0"````
M````GP4```````!!`@``O0$```````#&`0``+@(``,$"``!K!@``+0(`````
M````````\@4```````!W`@``N`,```````!.`P``!0```#8!``!4`0``B00`
M`&8#``"I!0```````$L```"5!@``:@$``&$#````````400```4&````````
M```````````*!````````+4$``",`@```````*D#``!&`P``.@```%@!````
M````AP8``(T!``"M!```?08``)D!```O`P```````/0"``"6`@```````,4"
M``"M````208````````A`P``Q`````````"4!@``]P0```("```F`P``L@4`
M`'T`````````IP0``$,&``"\!```(P```"H%````````O`,``$,"``!6`@``
M`````&@"``!E!````````*`#``!%!0``0`0``%4$``"E!```#0````$#``"D
M`@``7P,``+0%```#`@``=0,```````!V`P``#@,``,<"``!G!````P4``#<!
M``"9!@``C@4``*P%``!8!```?P8```````#+````K@```,<!````````Y0(`
M`````````````````-T!``!C````_@,``,`#````````2@(``#8%````````
M`````/X!````````E`4````````Z!0```````/\```#H`P``>`8``$\!``"(
M`@``;`8``)4#``#G`0`````````````2!```<P4``+0!``#R`0``$@``````
M```F````-`,```8"``"6!```(P4``````````````````.,"```T!@``PP,`
M``0$````````6@8``/H!````````'`,````````/`P``I`0```````!I!```
MB@```.$"``"I````S`````````!Y!```?P0```````#C````G``````````T
M`0```````"\&```%`@``H`$``!@"```D`@``<@,``)T%``#Y`0``#`(`````
M```K`@``T00``%(`````````BP,```````#)`@``?@,``#("```*!0``?00`
M`(@$`````````````),"``!-!```K@(``,P%``"6!@``;@```*<"````````
M/@,``*8$``#.!0``%@,````````<`0``T0,``(<````1````AP4``!,$````
M````C0`````````<!0``;00``'8"``"B`0```````%,````X````6P(``'("
M``!6!0```````+$%``#3````SP```&P#```J`@````````````!,!0``-`0`
M`/,`````````)P```(X#````````$`$````````B`@``*04```````"Y````
M``````4%````````&@8``%,%````````>````.(```#N!0```````$T`````
M````!0,``````````````````/P#``!'!0``]`$``!X```#(!```C@8`````
M``"#````508``/8#``#Z`P``W@0``'L$``"^!0``'P$`````````````G`$`
M``````!,`@``2@8``!P```#?!```/@4``*H$``"8`@``T`$``/<"``![`0``
M?@4``"X````E`P``5P,``$@$````````LP$``!<$````````,P```,\$``"0
M`0``CP4```````#(````/0(``&P"```G`P```````/4#``!]`P```````$L%
M``!@!@``Z0(``'P#```3`P``EP4``.T"``#6!0``R`(```````!N`@``````
M`/L$```)`0``&@,```T%````````108```````"W`````````.0"``#9`0``
MD`(``'\%``!9`@```````%(&```$!@``\`4``!`````9`0``T`(``.P```#Q
M!```70```.L```!1`@```````)L"````````W`(```````#.`0``T@0``"X$
M`````````````*<%``"L````K`0````````=`@``%@8``,("``!O`@``````
M`+@!````````Y@(``/@%``#E`P``\@```,4!``#[!0``A@8```````#7!```
M`````'X!```Z`P````````````!<````I@,``.<$````````U04```````!0
M`@```````#X"``#`!0``/04```````#2`0```````,T$```E!0``F@```%("
M``"=`0``P`0``)X!``!K`0``B@$``!H"``"+!0``&`,``)T"``"1````;0``
M``````"`!```.0,`````````````%04``.0$```@!@``!`,``'L#``#J!0``
M^`$```````!S`@```````.T!``!A!```5P(``"@"``"E`P``I04``,T#``!,
M`P````````````!X!````````&<```!4!@``@@8``%$%````````.P$`````
M```'`0``40$````````L!@``-`4```````"_`0``'`8``,`!``!5`@``#P4`
M```````.````*@8``.X#```?`P``W@(```````#]`P``B04``,$#``#0`P``
M(`4```T#``!:!```Z`0``+P%``"/!````````#\!```)````3@$``#L&``!3
M`@```````.4```"?!```Z@(``&@#``#6`@``;@4``+X```"4!```H@4`````
M````````>@,``(T&``!6!````````+D!````````A@(```0!``!/````3`8`
M`"H#``#)!0``FP,```````!@````C0(``!4````N!@``2@$```````!'!```
M`````-0````W!@``<`(``-$"``"8`0``_P(``'H"``!"!```T@,``$8%``!#
M`0```````/<`````````,@4``/\$``"7!@``N@0``.$$``!``0``T`4`````
M``"R`P```````#4#``",!@```````-H$``#I````V0(``'(&```\!```J@``
M``````#G`P``700``!8"``!T!@``;P4``'\"``"*!0```````)$%``#/`@``
M90(``*@!``"?`0````````$$``!P`P``$00``'($``"$`@``X`4``(X$``".
M`@`````````````+`````````",$````````%P8``#<$````````9`4``"0`
M``#K!```"P(``````````````````!,&````````3`0````````,!```B`$`
M`($&````````I0(```````"P!0``008```````#F!0``AP$``)@```"O````
MY@$````````[!0``(0```/X$````````V0,```````!8`@``R`$``$,$``#X
M`@``M@4``#(&``#;`@``5P$```L&````````-00``````````````````-$!
M```O`@````````(```#B!````````/,$``!F!0```````.P"````````,P8`
M`)X$``"6````^P(``),!`````````````/X```"*!```@`4``'P"````````
M`````%@%``#\!0``#`$```````"V`@``0@`````````O!```<P8``$$$````
M`````````",#````````BP8``+8$``#8`@``G0````````#V`0``0`,```<`
M`````````````(\#```N`0``&0,``#P```"2`P````````````",````````
M`+($``!]`0``G`,``'@#``!U!0``E````)4```!Q!@``/0$``(<$``"K!```
M`````%,!```````````````$``#6`P````````0%`````````````(0```">
M`@``I0```((!```&`0``S`0```@#```#````OP(```,$``#:`0``J@,``%L`
M``!@!````P,``(@&``">`P``8P0``($`````````3P,``+H`````````````
M`-T#```W`P``'P8````````:`0``:`0``#0"``#C`0``!@8``&`%``#K`P``
MH@,``/L!````````?@(``',````K`P``_P$``+8!``#Z!0``ZP(````````M
M!0```````+L%``!N!@``R@0``+<%`````````````$0&````````8@0``!,!
M``!*`P``<P0``+$"````````W`,``#@#```L`@```````,$%``"#`0``)`4`
M``````#Y`@``7@0``%L&```!!@``9`````````#D`P``C00``%````!8!@``
M`````)`&``"'`@``0P,``/4```"I`0``]P,```````"A````E04``(4#``!7
M````W@```%`!````````U`4``.0```!O`P``7@8``*,%```/!```BP$``)X%
M``#=!0```````!`"``!/!@``X0$``)L&````````A08``(,%``#V````[00`
M``X!````````2P0``)(!``"C!```,08````````*`````````$`"``#J`P``
M<P,``$L!``#Y`````````+<#``"1`P``UP(``&`!````````9P8``&D"``#`
M`@``RP,``#$!``````````````````#I!```#@4``$<"``#K!0``.@$``-(%
M``"!`0``Z0$``/H````/`@`````````````Q`@```````+0#````````````
M`&$&````````RP0``($#``"#`P````````````#`````6@4```````#'````
M``(````````A`@``JP4```````"X!0``H04``"P$``#C!0``(@0``%D%``"Y
M!```%@4``'`%``!\````-P(`````````````:````,H"````````_0```)P"
M``!;`0``&`0``"D#````````B`,``!("``!(````K`(``,H`````````````
M`$8```!$!0``"`4``````````````P$``#`$````````F00```````!Z`0``
M)00``,0#``!%`0``;P`````````;`````````#P%``#3`@```````'L&``";
M````]`4``!H```!)````100````````B!@``S@``````````````+@4``/$%
M`````````````%H"````````:P```%\%````````>P```/<!````````]0$`
M`-D$``"H!``````````````2`0```````/````!(!0``D@````````!Q````
M9@```)H$````````D@(``$T&`````````````````````````````(8$``#7
M!0``+P4``!,```"7!```]`````````"O`@``A`0``%D$``#R`P``,`,`````
M````````#@0``.("``#D!0``8`,``"(#````````W0(``+$$```>`@``+```
M`"H$``"H!0```0$``+P```"K`0``8@4````````"!0``````````````````
M,P(```````!A````JP(``(4$``!.!0``!@4`````````````<`0``/T$``#<
M````FP0``!0$```5`@``]00``((```"C````W@$```````"4`P``+00``*<#
M``!^!@``+`$``,($``#E`0``,````'@%``"``P``0@8``#\"``#E!```!P4`
M`((%``!G!0````````````!)!```&`8```````!6`0``TP$```\&``"0!0``
M`````)(&``##!```WP(``,(!``"I!`````,``&D&``"P!```D0(``'4&```6
M````8@(``"4&`````````````#$````*`P``G`8```````!;!0``?`4`````
M``!"`@```P8```````#T`P```````,<#`````````````#8#````````K0,`
M`,H%``"7`0``Y04`````````````@@,``)``````````[@0````````Z!```
M`````*X%``"-!0``M`````````!(!@``2`,```````!F`@```````+H#``!B
M!@``X`(``/H$````````K@$``-H%```G!```%````)4"````````_````(T#
M``!"`P``CP8```````"O!0``3`$``(0#``#^`@``U`,``&$"```(````````
M`)H#````````L`(``"4"``!&`0```````#4&````````=0`````````\`0``
M8P,``,D#````````A@````````#I!0``*@````````!K`P``H@```*0%``!%
M````.`(``*P!``!2!```A0(``%T"`````````````!L&```F!```F04``-P%
M``"/`@````````````"&`P``2@0``$0````4`P`````````````D`P``````
M`%X!``"K`P``J@$```````!Y`0````````````!T`P``#0$``'$$````````
M&P0```````#6!`````````````!E!@``'P```````````````````"$!``":
M!@``_`0``'(%`````````````&\&```^!```F0(``,0"``#+`@``'04``,4%
M`````````````&0!``"*`@``:`4``.L!``"R`0``T0```+`#``!Y`@``$0,`
M`/H"``!?!@`````````````J`0``7`,```````#"`````````-T$``#Q`P``
M-P```,$````1!@``,@```!8!````````3P4``%,&````````HP(```````!+
M`@``60,``!8$````````(@4``*`$``!J!0``C`,````````L!0``]@(`````
M``"Q`P`````````````Y!````````#\$``"D````)`$``(L`````````O0(`
M`-,%``"8!```904``/L`````````6`,```L#``!Z!0``6@``````````````
M`````-\!``"^!````````+@````/`0``L0`````````C`0```````#,!````
M````*0(``)`$``!5`0``````````````````H0(``)\"``!D`@``Y`$``'\!
M````````KP$``+L"``!K!0```````&D%````````!@```$,````I`0``S@0`
M`-\#``!`!0``&P,``'D#``#-`0``AP,```````!.!@``?P```%(%``"9````
M]0(``+8`````````````````````````,`(`````````````I@```!4#``#J
M`0``&````$0$`````````````(`!```4!0``X`,``&H#``"G`0``'08```L%
M``!:`P``3````"L&````````\P(``+4#``!&!```4`,``-@```!P`0``/`,`
M``````")````:@0```````````````````@$``"N`P``V04``-8`````````
M`````+(`````````(04``,$!`````````````)$$``#"!0``<0,``.@!```)
M!0``R`,``-L!``#8!```9@8``(("``!C`@```````),&``#?````5`(``-\%
M``!)`0```````&8!``!<`0``60```%(!``!1`P``-0(``'P!``"Y!0``K`,`
M`&(#````````SP$``)8!````````_0(``,0$``"]````V`$``%X#```'`P``
M`04``+````#O!0```````+@"``#J````*`4``````````````````)0!```1
M`@``,@$``$$!``#=````^`,``+D"```1!0```````*T!``"2!```-0$``$T%
M``!$`P``````````````````S@(``#@%````````)@8``*T"````````N@(`
M`&T#````````'00``$$#````````V@```.,$``!1````'P(``-0!```&!```
MDP,``.,#``!'!@``E@,````````B`````````'@!```'!@``(`,```8#``"U
M`0``V@,``)H"``!Q`0``L`$``%T!````````90$``$X````Q!```_`$`````
M```]!````````+<"````````7P0```@"``!_`P``,P4``,H#````````HP,`
M``````#'!0``I0$``%,$```3!0``TP,``$D%``"K````.P0```````!8````
M`````$D#````````N0,``&P!``"W`0``.08``)L%``!D`P``4`4```````#R
M`@``PP$````````'!```EP,``"L`````````?@0```@!`````````````*<`
M``![`@``[P,```H!```Q!0``=P,``(8!```,!@``"P0``,,%````````````
M`)<"``"!!```Q0,````````)!@``A0```+H%``"+`@``=`(``#\````S`P``
MC@```,8`````````\@0``#L#``"S!0``8@```!0"````````2@```"L$``!N
M`P``\0(``/`$````````?`0``'<````9!0``PP````````!.!```G0,``&4#
M``"_!0``90```&T%```Y`@```````+0$```M````"0(`````````````9`8`
M`%<%``!X`@``/P,``/\#``!O`0``D@4``-L````*`@``U0(````````B`0``
M``````````"A`P`````````&``#<!```=````+4````C`@``R@$``-4!``!C
M!@```````($%``"^`@```@8``'<$````````$`4``%8#``#[`P``X```````
M```$`@```````-````"V`P```````*($``!:`0``1`$``&L"```,````$0$`
M`),```!S`0``BP0````````X!@``NP```!D&```M`0```````'H```#]!0``
MQ`4``!(&````````#@(``.D#``#X!```804``)H%```'`@``W@,`````````
M`````````'0$````````B0$```````";`0``504``*D"`````````````!,"
M````````PP(``#D````%!```5P8``&<"`````````````+4"``#G!0``QP0`
M``````!>`@``004``!X%``"X!```F0,````````=`P``'`0```````"]!0``
M80$```\```#$`0``X@4``!0&``#L`P```````+H!````````?04``!<%```.
M!@``0@$``#T&``"$!@``W`$``-<!````````%P(``$T!```0`P```````!@%
M````````J`,``+,"```X`0``HP$``+P!```D!@``,`8````````2`P``D08`
M`'8$````````(`$``(0%`````````````*("``#G````MP0```````!%`P``
M<`8``*8%```5!@``^````"D&```0!@``&`$```````!9`0``/`8``/P"``#S
M`0``)@4``,T```````````````$"``!%`@``30(```````!L!````````),$
M````````;08``/X%```$````)P(`````````````VP4``)4!``#8`P``6P,`
M`+0"``"8`P``=@8````````-`@``%`$``.@```#P`P``[0,``!X&``!R`0``
M`````"`"``#J!````````$8&```D!```X0,``````````````````-8!```-
M!```7@4``"`````>`0``"P$``+\$``!0!@``%00``#(#``!\!@``VP0``)4$
M``!=!@``&P(``,\#``"]!```%0$``.$```"[`0```````$`&``!V!0``J`(`
M`.`!``!/`@`````````````7`P```````'H$````````\P,```````#N`0``
M``````````"=!```U0```#L"````````$@4```````!L`````````,L%``"#
M!```70,``!T!```)`P``U00``!H%``!U`@``X@,``.X````L`P``'P0``*8"
M`````0``R00``,P!`````````````$8"``"8!0``+P```(P%```F`@``@`8`
M`.P%````````@P8``#@$``#2`@``B08``#`!``#&`@``'0```'$%``!7!```
M`````"@$````````J@4``+("```M!@```````````````````````/`"````
M``````````````!;!```=`$``#8```!(`@``CP```#X&``#U!0``RP$``'D`
M``#-`@``-04``/,%``#V!0``\`$``&`"````````A`$``)\#```0!```````
M`#($``"D`P``E@4````````(!@````````````"N!```UP```!H$````````
M``````````!U!```/`(``&D!``"``````````+$!``````````````````#.
M`P``#08```````!H!@``2@4``,8$``"/`0``U0,``%`$````````O@$``'H&
M```)!```T`0``#`%````````3P0``"D```!Q`@``D`,``)H!````````````
M`#T#`````````````"L%```N`P```````.`$```,`P``@@0``(`"````````
ME`(``)P%`````````````````````````````&,!``"A`0``5`0``'D&```>
M`P``O0,``"$$``!4````````````````````[P(``-$%``!V````S`,``/\%
M``#F````/P4```````#F`P```````,(#`````````````$(%````````@P(`
M`/D#````````7`(``$D"``#8!0```````)@&````````B0,``(@```!N!```
M7P(``"L!```7`0``Q@,``,\%``!J`@``KP,````````U````Q00``!D```#%
M````5`4``*`%````````!0$``'``````````*`,``'D%``#-!0```````"\!
M``#G`@``,0,``.\```!'`P``50```'4!``#V!````"`H)7,@9&%Y<R!A9V\I
M`"`H06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M
M;W)R;W<I`"`H>65S=&5R9&%Y*0`@870@`"(E<R(@:7,@;F]T(&$@9&ER96-T
M;W)Y+@`B)7,B(&ES(&YO="!A('9A;&ED(&-H;VEC92X`(B5S(B!I<R!N;W0@
M8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"(E<R(@=')E92!R
M96YD97)E<B!N;W0@9F]U;F0N`"(E<R(@=V%S(&%D9&5D('1O('1H92!G<F]U
M<',@<WES=&5M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@
M<WES=&5M+@`B)7,B('=A<R!N;W0@8W)E871E9#H@)7,N`"4N,F9-0B!U<V5D
M(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I`"5D("5S(&%N9"`E<P`E9"!D
M87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RX`)60M9&%Y(&9O<F5C
M87-T`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT
M96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``)7,@
M4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES
M=',N`"5S(&%T("5S("5S`"5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE
M(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M
M(&%T('1H:7,@=&EM92X`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N
M;W0@9F]U;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S
M)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S
M`"5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA
M:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG(&%N>2!L:6YK<R!I;B!I
M="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA
M;"!I;F9O<FUA=&EO;BX`+"!G=7-T:6YG(``L(&=U<W1I;F<@)7,@)7,`+"!V
M87)I86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O
M<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\4')E=FEO=7,`02!D871A
M8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A
M=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E
M<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y
M(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U
M8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@
M4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K
M97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@
M:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y
M(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!#;&]U9',`
M04T@3&EG:'0@4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W
M97)S`$%-+U!-`$%022!)1`!!8F]U="XN+@!!8V-E<W,@9&5N:65D(&-R96%T
M:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93
M(&9I;&4N`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N="!087-S=V]R9`!!
M8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($-H:6QD($=R;W5P
M`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P
M`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`B)7,B
M`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!9&0@82!N97<@=7-E
M<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H
M92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T;R!A9&1R97-S
M(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D('5S97(`061D960@
M(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO
M;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D("(E<R(@=&\@=&AE
M('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I;F<@=7-E<G,@:7,@
M9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S
M970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N
M`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QL`$%L
M;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I
M;VYS`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F
M(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@
M24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@
M24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA
M=&4@=&5M<&QA=&5S`$%M97)I8V%N(%-A;6]A`$%N(&EL;&5G86P@=F%L=64@
M=V%S('-P96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"X`
M06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E
M<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`07!P;&EC871I;VX`
M07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@
M=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!R:6P`07)A8FEC("A7:6YD;W=S
M+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U
M('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F
M;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("(E<R(@
M86YD(&%N>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA
M;B`H05)-4T-)22TX*0!!<G0`07)U8F$`07-C:6D@07)T`$%S:6$O4&%C:69I
M8R!296=I;VX`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E
M;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T
M;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T
M;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`
M075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S
M(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!2
M97%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!2
M97%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@
M=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U
M:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q
M=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D
M9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T
M;W)Y`$%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$
M05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@
M861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!
M=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z
M(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN
M`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D
M+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D
M+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R
M+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N
M=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@
M9FEE;&1S.@!!>F5R8F%I:F%N`$)/1D@@17AC=7-E<P!"860@:V5R8F5R;W,@
M<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR
M86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`
M0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`$)E;&%R
M=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD
M87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`
M0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQI=FEA`$)O;VMM87)K<P!"
M;W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]U=F5T($ES
M;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R
M=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U<FMI;F$@1F%S;P!"=7)U;F1I
M`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0V%C:&4@:6YI="!W
M87,@;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE
M<F]O;@!#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE
M<G,N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;B=T(&]P
M96X@9FEL92`B)7,B+@!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E
M<&]R=`!#86YN;W0@8V]P>2!F:6QE*',I("T@<V]U<F-E(&%N9"!D97-T:6YA
M=&EO;B!A<F4@=&AE('-A;64N`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#
M86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!M;W9E
M(&9I;&4H<RD@+2!D97-T:6YA=&EO;B!I<R!W:71H:6X@<V]U<F-E+@!#86YN
M;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A
M;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D
M(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N
M=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M
M8F5R('-T;W)E9"X`0V%N;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L
M;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86YN;W0@<F]U=&4@
M;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#86YN;W0@=W)I=&4@=&\@
M9FEL92`B)7,B`$-A<&4@5F5R9&4`0V%R<FEE<@!#871E9V]R:65S(&%N9"!,
M86)E;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QL<&AO;F4`0V5L
M=&EC("A)4T\M.#@U.2TQ-"D`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E
M;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I
M;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA
M9`!#:&%N9V4`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E('1H92!N86UE
M(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A
M;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG:6YG('EO=7(@<&%S<W=O
M<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R
M871I;VXN("!#;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0VAI;&4`0VAI
M;F$`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET
M:6]N86P@*$)I9S4I`$-H;V]S92!!<'!L:6-A=&EO;CH`0VAO;W-E(&$@<&%S
M<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y
M(&1A=&5S.@!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@
M)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!1=65R>0!#;&5A<B!O=70@=7-E
M<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T
M90!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E
M(%=I;F1O=P!#;&]U9',`0VQO=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E
M;&EN9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&]M8FEA`$-O;&]R
M`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;'5M;B!T:71L97,`
M0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.
M86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I
M=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N
M(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO
M;VLN`$-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N`$-O;F9I9W5R92`E
M<P!#;VYF:7)M(%!A<W-W;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I
M8R!297!U8FQI8R!O9B!T:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I
M;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K
M97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S
M97)V97(@9F%I;&5D+@!#;VYT86-T<P!#;VYT86-T<R!W97)E('-U8V-E<W-F
M=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N="!T>7!E
M(&]F(&-O;7!R97-S960@9FEL93H@`$-O;G1E;G1S(&]F("(E<R(`0V]N=&EN
M=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y(&9A:6QE9#H@)7,`0V]S="!)
M1`!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R
M>7!T(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@`$-O
M=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-
M24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#
M;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K
M(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R
M+@!#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z
M("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O
M=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B``0V]U;&0@;F]T(&1E8W)Y<'0@
M4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U
M;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T
M(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@
M9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U
M;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T
M(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@
M9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S
M+@!#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@;6MD
M:7(@(B5S(BX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE
M(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`
M0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E
M7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B
M+@!#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@
M<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE
M(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A
M<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M
M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO
M="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O
M:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#
M;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD
M(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER("(E
M<R(N`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@
M82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S971U
M<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@=&AE
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E
M('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S
M92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N
M("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O
M=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=6YL
M:6YK("(E<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@
M;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T('=R
M:71E(&-O;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I;F0@
M=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES
M(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`B)7,B('1H92!F;VQL;W=I;F<@
M<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(Z("5S`$-O=6YT960@=&5X=`!#
M;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!A(&YE=R!O;F4`0W)E871E
M('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@
M;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@
M4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@57-E<G,`0W5R<F5N="!7
M96%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5S=&]M:7IE('1A<VMS('1O
M(')U;B!U<&]N(&QO9V]N('1O("5S+@!#>7!R=7,`0WER:6QL:6,@*$M/23@M
M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N
M("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$133B`H<V5E(&AT='`Z+R]P
M96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT
M<F\M9'-N+G!H<"D`1&%I;'D`1&%T851R964@0G)O=W-E<@!$871A8F%S92!,
M;V]K=7``1&%T90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$
M96-E;6)E<@!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET
M>0!$969A=6QT(%-H96QL`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@1W)O
M=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U
M<F=E(&UE<W-A9V5S`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA
M=&4`1&5L971E(&UE<W-A9V5S`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S
M(@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(@86YD(&%N>2!S=6(M<&5R
M;6ES<VEO;G,_`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@<W5B
M(&9O;&1E<G,`1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!$
M96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S
M8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO
M=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I
M;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S
M=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I<W!O
M<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N;W0@9&5L971E`$1O
M(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O97,@=&AE
M(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C
M:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O
M;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W;FQO860@)7,`1&]W
M;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`
M1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$5-86EL+71O+5--4R!G871E
M=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S
M97)V:6-E+@!%4E(`16-U861O<@!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U
M<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI
M<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I
M;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A=&EO
M;@!%9WEP=`!%;"!386QV861O<@!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL
M(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO
M;@!%;6%I;"UT;RU335,@1V%T97=A>0!%;6]T:6-O;G,`16UP='D@;65S<V%G
M92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE(&EN
M<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X
M=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YD('EE87(`
M16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A
M<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N
M("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!L
M971T97)S(&)E;&]W.@!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R
M`$5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC
M(&%N8VAO<CH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R
M(&=E='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z
M("5S`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`17)R;W(@=W)I=&EN9R`B
M)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@
M;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R
M>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y
M(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP96-T
M960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E
M<FT`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$944"!U<&QO860@;V8@<V5T
M=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C
M;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!3
M34(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T
M;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N
M;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E
M=')I979E.B`E<P!&86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&
M87)O92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`
M1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@
M4VAO=V5R<P!&:65L9"!M871R:7@`1FEG;&5T($-!4%1#2$$`1FEG;&5T(&9O
M;G0`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@
M)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO
M;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL
M=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T
M:6\`1FQI<`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;V0`1F]R
M96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U
M<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L
M87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K
M*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE
M('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`1G(`
M1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R96YC:"!'=6EA;F$`1G)E
M;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O
M;0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.
M86UE`$=A8F]N`$=A;6)I80!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E
M;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`
M1VEV96X@3F%M90!';&]B86P@3W!T:6]N<P!';P!';V]G;&4@36%P<P!';V]G
M;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I
M`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P
M(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L92!T
M;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z
M(`!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R;W5P
M7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U861E
M;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO
M;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,
M`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L
M9V]R:71H;0!(87IE`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@
M36-$;VYA;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE8G)E=R`H25-/+3@X
M-3DM."U)*0!(96EG:'0`2&5L<`!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES
M('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9V@`2&]?;64`2&]L>2!3
M964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M92!!9&1R97-S`$AO;64@1&ER
M96-T;W)Y`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO
M<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN
M(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N
M9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP
M92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S
M9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R
M871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS
M:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E
M92!F;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E
M("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@
M34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA
M8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN
M<RD@87)E('1H97)E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(
M=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@
M;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T
M82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N
M;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#
M2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$EC96QA;F0`26-O
M;G,@3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y
M)W,@;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S
M('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@<V5E('1H:7,@
M;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U
M<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA
M9V4@=7!L;V%D`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP;W)T960@9FEE
M;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26YC;W)R96-T(&%C=&EO;B!C;V1E
M(&=I=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!)
M;F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A
M9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E
M9"!F=7)T:&5R(&AE;'`N`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD;VYE
M<VEA`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B
M;&4N`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M86EL
M(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S
M<W=O<F0Z`$EN<V5R="!M97-S86=E<P!);G-E<G0@=&AE(')E<75I<F5D(&%N
M<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<W5F9FEC:65N="!C
M<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F
M9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@
M541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV
M86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D
M871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!)
M;G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS92!K97DN`$EN=F%L
M:60@;&]C871I;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L
M:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A
M;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!A
M<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED('!R;W1O
M8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H87)E(&]B
M:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@
M9&%T82X`26YV96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`27)A;BP@27-L86UI
M8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-O;&%T960@5"U3=&]R;7,`
M27-R865L`$ES<W5E<@!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P
M86YE<V4@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!+
M87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E
M<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I97,`2V5Y
M($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E
M`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K
M97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O
M<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H
M155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,86YG=6%G90!,86\@4&5O<&QE
M)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T($AA;&8`3&%S="!087-S=V]R
M9"!#:&%N9V4`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I
M;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E
M<@!,871V:6$`3&%W`$QE8F%N;VX`3&5F="!H96%D97(`3&5F="!V86QU97,`
M3&5S;W1H;P!,979E;`!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`
M3&EE8VAT96YS=&5I;@!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@
M4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`
M3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W
M(%-H;W=E<@!,:6YK`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O
M;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE
M`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E
M<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,
M:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U
M8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@<V5S<VEO;G,@9F%I
M;&5D.B`E<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R
M<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A9&EN9RXN
M+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I
M;@!,;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N`$QO9R!O=70`3&]G:6X`
M3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M
M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@
M9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3'5X96UB;W5R9P!-30!-3U1$
M`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA
M8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O
M9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86QA=VD`36%L
M87ES:6$`36%L9&EV97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@
M8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@
M8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R
M-"!M87``36%P475E<W0@;6%P`$UA<'!I;F=S('-T;W)E9"X`36%R8V@`36%R
M:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G
M<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`
M36%R=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I
M=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E
M961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@
M-B!H;W5R<SH@`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,`36%X
M:6UU;2!L96YG=&@`36%Y`$UA>6]T=&4`365D:6-I;F4`365M8F5R<P!-96YU
M(&UO9&4Z`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@
M8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R
M:69I960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&%R(%=E
M871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@
M;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T
M:&4@861M:6YI<W1R871O<BX`365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+@!-
M971H;V0`365T:&]D("(E<R(@:7,@;F]T(&1E9FEN960`365T:&]D(&YO="!D
M969I;F5D+B!#86QL960@;65T:&]D.B`E<P!-971R:6,`365X:6-O`$UI8W)O
M;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`36EM92!4>7!E`$UI;B!T96UP
M(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:6YI
M;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D`$UI<G)O<@!-
M:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S
M="X`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@
M<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-
M86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D=6QU<P!-;VQD;W9A+"!2
M97!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE87(`36]N
M=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F4@9FEE;&1S(&9O=6YD
M(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N`$UO<F]C8V\`36]S
M=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY($-L;W5D>2!A;F0@5VEN
M9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H
M=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`375L=&DM
M;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I;6%P(%5+(&UA<`!-=6QT:7!L
M92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N
M`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@
M3D]4($%G<F5E`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.971H97)L86YD
M<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S
M8V%P92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),
M`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),
M`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I8V%T
M92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.
M979E<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@36]O;@!.97<@
M57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@<&%S<W=O<F0`
M3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+@!.97<@<&%S<W=O<F1S
M(&1O;B=T(&UA=&-H+@!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA
M<V5S`$YE>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I
M80!.:6=H=`!.:75E`$YO`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A
M=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A
M=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L871E
M+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.
M;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T
M:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T
M:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.
M;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&9I
M;&4@=7!L;V%D960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E
M="X`3F\@;&]C871I;VX@<')O=FED960N`$YO(&UE<W-A9V4@<W5P<&QI960N
M`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O
M9F9E;G-I=F4@9F]R='5N97,`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA
M<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@
M=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S
M+@!.;R!Q=6]T82!S970N`$YO('-E<&%R871O<B!S<&5C:69I960N`$YO('-U
M8V@@9FEL90!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@
M8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V
M86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F
M;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U
M<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]R9&EC
M("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P
M:&5R90!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E
M<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT960N
M`$YO="!S=7!P;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B
M86-K+@!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M
M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E
M8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3V)J
M96-T`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F:6-E`$]L9"!A
M;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="X`3VQD('!A<W-W
M;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VUA;@!/;FQY($E-
M05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N
M<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N
M`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C
M:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H
M87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD
M(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P
M97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F=A;FES
M871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L
M(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E
M<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`
M4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!%05(Z.DUA
M:6P@8F%C:V5N9`!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E
M9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A
M=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@4F%I;@!0
M32!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U;@!032!4
M+5-T;W)M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!07TA0(%-H96QL
M`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I
M960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R=&QY($-L
M;W5D>0!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`
M4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)
M55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N
M`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!0
M87-T90!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)F;W)M($UA:6YT96YA
M;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS
M(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@(B5S(B!N;W0@9&5L
M971E9"X`4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO;G,`4&5R;6ES<VEO
M;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0
M971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0;&5A<V4@
M96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE
M(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)
M4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T
M:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@
M82!V86QI9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE
M('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A
M<W-W;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U5
M4U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L
M96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`4&]L86YD`%!O;&ET
M:6-S`%!O;&QS`%!O<G1U9V%L`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E
M;F9O<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO
M=7(H<RDZ(`!0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z
M(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`
M4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R
M979I;W5S(&]P=&EO;G,`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E
M<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B
M;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV
M871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T
M;R!2:6-O`%!U<F=E(&UE<W-A9V5S`%%A=&%R`%%U97)Y`%%U;W1A`%)302!0
M=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@
M16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I
M;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S
M86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@
M8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E
M<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5F<F5S:`!2
M969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@
M5FEE=SH`4F5G97@`4F5L871I;VYS:&EP($)R;W=S97(`4F5L;V%D`%)E;6%R
M:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M
M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@8V]L=6UN`%)E;6]V92!P
M86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A
M<GD@9&ER96-T;W)Y+@!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q
M=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E
M.B``4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+@!297%U
M:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`
M4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T
M:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A
M=&EO;BX`4F5Q=6ER960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S
M970@66]U<B!087-S=V]R9`!297-T;W)E($QA<W0@475E<GD`4F5S=6QT<P!2
M971U<FX@=&\@3W!T:6]N<P!2971Y<&4@;F5W('!A<W-W;W)D`%)E=6YI;VX`
M4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS
M`%)I9&1L97,`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2;VQE`%)O;6%N
M:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4G5N`%)U
M<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@
M4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U=&AE
M;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,
M(%-H96QL`%-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',`4U-(`%-5
M0T-%4U,`4U]13"!3:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@2VET=',@
M86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L
M;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M;V$`4V%N
M($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I
M9&5R`%-A=61I($%R86)I80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@
M3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0
M('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN
M`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@
M<V-R:7!T('1O.B`B)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!3
M96%R8V@`4V5A<F-H($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A
M=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!3
M96QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L
M;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C
M=`!396QE8W0@;F]N90!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@
M9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P
M87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E
M(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H
M92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM
M92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T
M=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N
M`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M
M(%)E<&]R=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!3
M97)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V97(@9&%T
M82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397-S:6]N($%D;6EN`%-E<W-I
M;VX@240@97AP:7)E9"X`4V5S<VEO;G,`4V5T`%-E="!O<'1I;VYS('1O(&%L
M;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O
M<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@
M=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO
M=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E
M9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E
M='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO
M;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3
M:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D
M969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@
M8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T
M960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L
M;V=G:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@
M<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T
M:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!U<&QO860`4VAO=V5R<P!3
M:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I
M;FET>0!3:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K
M*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P
M`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE
M`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W
M(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@
M4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@
M=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US
M`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F
M<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I
M82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M
M:7-P:&5R90!3<&%C97(`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!)
M;G!U=`!3<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R
M="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA
M=`!3=')E970@061D<F5S<P!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O
M;2!T:&4@861D<F5S<P!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N
M`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B
M('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@
M<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5C8V5S<P!3=6-C97-S9G5L
M;'D@861D960@(B5S(B!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE
M87)E9"!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C
M97-S9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B
M)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O
M;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U
M;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@
M<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E
M<W-F=6QL>2!U<&1A=&5D("(E<R(`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U
M9&%N`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U
M;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<'!O<G0`4W5R:6YA
M;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3
M=V5D96X`4W=I='IE<FQA;F0`4WEN8R!L;V<@9&5L971E9`!3>6YC34P`4WEN
M=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI
M8P!4+5-T;W)M`%0M4W1O<FT@86YD(%=I;F1Y`%0M4W1O<FUS`%135B!F:6QE
M`%1A8FQE(%-E=`!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!4
M86II:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8`5&%S:W,`
M5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A
M='5R90!496UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E
M<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N`%1E;7!L
M871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1H`%1H86EL86YD
M`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(:7-T
M;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"X`5&AE($AO<F1E+TMO;&%B(&EN=&5G
M<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE($E-4U`@
M;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"X`5&AE($UA:6YT96YA;F-E
M.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N
M<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%D;6EN:7-T<F%T
M;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS
M(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+@!4:&4@
M8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA
M;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT
M86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O
M;VLN`%1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I
M<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB
M=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@
M8FQA;FL@;W(@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO
M;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4
M:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F
M:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F
M:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4:&4@:61E;G1I='D@(B5S(B!H87,@
M8F5E;B!D96QE=&5D+@!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R
M>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE
M(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H
M87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@
M=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@
M;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4`
M5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+@!4:&4@;W!E
M;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S
M;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B
M92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M
M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES
M(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`
M5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C
M=&5R+@!4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T
M97(N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R
M=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S<&5C:69I960@<F]W("@E
M9"D@9&]E<R!N;W0@97AI<W0N`%1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N
M;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BX`5&AE('5P;&]A9&5D
M(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U
M<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE('=E871H97(N
M8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H96UE<R!D:7)E8W1O<GD@
M(B5S(B!N;W0@9F]U;F0N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L
M92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I
M;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@
M9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU
M<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D
M9&EN9R`B)7,B('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L
M96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E
M;3H@`%1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H
M92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z
M("5S`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@
M;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY
M('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L
M87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE
M9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P
M97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I
M;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T
M<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI<R!)
M34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`
M5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV
M92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL
M92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB
M97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO
M+W=I;G!L8RYC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H
M92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A
M;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U
M:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@*&AT
M='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD
M(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I
M96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O
M9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N
M`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@
M4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F
M;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4
M:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES
M(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N
M9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L
M:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`5&AI
M<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I
M(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@
M;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A
M;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T
M:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN
M9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU
M;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4
M:6UE('-E;&5C=&EO;@!4:71L90!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E
M;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA
M8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=O`%1O:V5L874`5&]M
M;W)R;W<`5&]N9V$`5&]O(&UA;GD@:6YV86QI9"!L;V=I;G,@9'5R:6YG('1H
M92!L87-T(&UI;G5T97,N`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B
M86=O`%1R=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H
M25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L
M86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!5
M4DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T
M`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R
M>2X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE
M("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8VAE
M8VL@9FEL92!S:7IE(&]F("(E<R(N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I
M>F4@;V8@(B5S+R5S(BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N
M86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D
M:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E
M(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@
M9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E
M;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE
M('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE
M(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N
M`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E
M;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R("(E
M<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA
M8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O
M(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T
M:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N
M`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@
M=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+@!5;F%B;&4@
M=&\@<F5A9"!F:6QE.B``56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER
M96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO
M;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O(')E;F%M92!61E,@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S
M+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B;&4@=&\@=')A;G-L
M871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@=')I9V=E<B!F<F5E
M+V)U<WD@=7!D871E(&9O<B`E<P!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D
M*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W
M<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"X`56YD;R!#
M:&%N9V5S`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N
M;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z
M(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER871E
M<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@
M36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@
M87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H
M0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D
M+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FYA;65D`%5N<W5P
M<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!U<V5R
M`%5P9&%T960@(B5S(BX`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D
M`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@
M<V5R=F5R+@!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I
M9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N
M`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@
M061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N
M`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES
M('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA;64`57-E<FYA
M;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N86UE.B``
M57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y
M(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U
M;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N
M;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+@!6
M86QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`
M5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@
M;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@
M0V]N=')O;`!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)
M*0!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FER9VEN($ES
M;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET
M>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!7
M05).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.
M('9I82!(5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE
M<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC
M;VT`5V5B`%=E8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`
M5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/
M+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO
M=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM
M:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`
M5VAE<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G
M:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H
M(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F
M="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VEK:0!7:6YD`%=I
M;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES
M9&]M`%=I<VAL:7-T`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`5W)O
M;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@
M9F]U;F0@)60N`%=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D
M+"!F;W5N9"`E9"X`5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!6
M1E,@9FEL92X`6"U2968`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV
M,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I
M=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@
M97AT96YS:6]N<P!960!965E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE
M<P!997,L($D@06=R964`66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@
M;6]R92!T:&%N("5D(&)L;V-K<RX`66]U(&%R92!N;W0@875T:&5N=&EC871E
M9"X`66]U(&-A;FYO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@
M9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D
M9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP
M;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N
M`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT97(@
M82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N
M(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P
M<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M
M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU
M<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S
M="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H
M92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T
M;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@
M8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M
M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO
M=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU
M<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T
M>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO=2!N965D('1O('!R;W9I9&4@
M86X@271A;&EA;B!P:&]N92!N=6UB97(`66]U<B`E<R!S97-S:6]N(&AA<R!E
M>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S
M<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!)
M;G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI
M;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I
M='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H
M96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S
M97)S+B!)9B!Y;W4@=VES:"!T;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U
M<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@875T:&5N
M=&EC871I;VX@8F%C:V5N9"X`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD
M(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U
M<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9
M;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE
M(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U
M<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E
M<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O
M;G1R;VPO0V]M;6%N9"`K(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE
M('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D
M+@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R
M(&QO9VEN(&AA<R!E>'!I<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@
M:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE
M(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@
M8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO
M=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@
M86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W
M;W)D(&AA<R!E>'!I<F5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA
M=FEA`%IA:7)E`%IA;6)I80!::6UB86)W90!;2&ED92!1=6]T960@5&5X=%T`
M6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U
M;W1E9"!497AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?0TQ)`%]$
M871A5')E90!?1W)O=7!S`%](96QP`%],;V<@:6X`7TQO9R!O=70`7T]P=&EO
M;G,`7U!E<FUI<W-I;VYS`%]3971U<`!?57-E<G,`861D<F5S<R!B;V]K`&%D
M9')E<W-E92!U;FMN;W=N`&-A;&5N9&%R`&-A;&T`8V%N;F]T(&-R96%T92!O
M=71P=70@9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H97)E`&-O;6UA
M;F0@;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R`&-R:71I
M8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M870@97)R;W(`961I
M=`!E;G1R>2!N;W0@9F]U;F0`9F%L;&EN9P!F:6QE`&9R;VT@=&AE("5S("@E
M<RD@870@)7,@)7,`9W5S=&EN9P!H.@!H:`!H;W-T(&YA;64@=6YK;F]W;@!I
M;6UE9&EA=&4`:6YL:6YE`&EN<'5T+V]U='!U="!E<G)O<@!I;G1E<FYA;"!S
M;V9T=V%R92!E<G)O<@!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H
M:6QE(&UA:VEN9R!)4T\N`&UM`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y
M970@:6UP;&5M96YT960`;F]T97!A9`!P97)M:7-S:6]N(&1E;FEE9`!R96UO
M=&4@97)R;W(@:6X@<')O=&]C;VP`<FES:6YG`'-E<G9I8V4@=6YA=F%I;&%B
M;&4`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W,`<W1E
M861Y`'-Y<W1E;2!E<G)O<@!T87-K(&QI<W0`=&5M<&]R87)Y(&9A:6QU<F4`
M='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N
M;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`4')O:F5C
M="U)9"U697)S:6]N.B`N"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES
M=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`W+3(U(#$Q
M.C,P*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP-"TS,"`Q,#HS,BLP
M,3`P"DQA<W0M5')A;G-L871O<CH@9'5C:T!O8F%L82YN970*3&%N9W5A9V4M
M5&5A;3H@<VQ?4TD@/&1U8VM`;V)A;&$N;F5T/@I-24U%+59E<G-I;VXZ(#$N
M,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]=71F+3@*0V]N
M=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`("AP<F5D("5S(&1N979I
M*0`@*$1O<W1O<&YA('1I<&MA("5S*0`@*'8@)7,@9&YE:"D`*&1A;F5S*0!*
M=71R:2``*';$C65R86HI`"!O8B``(B5S(B!N:2!I;65N:6L`(B5S(B!J92!N
M979E;&IA=FYA(&EZ8FER80`B)7,B(&YE('IA>FYA;2!V($AO<F1O=F5M(')E
M9VES=')U(``G)7,G(&YE(&YA:F1E;2!D<F5V97-A('IA(&EZ<FES+@`G)7,G
M(&IE(&)I;"!D;V1A;B!S:W5P:6YS:V5M=2!S:7-T96UU`"<E<R<@:F4@8FEL
M(&1O9&%N(&L@9&]P=7-T;F5M=2!S:7-T96UU+@`G)7,G(&YI('5S='9A<FIE
M;CH@)7,@`%5P;W)A8FQJ96YI:"`E+C)F34(@;V0@)2XR9DU"(&1O=F]L:F5N
M:6@@*"4N,F8E)2D`)60@)7,@:6X@)7,`Q:!E("5D(&1N:2!D;R!P;W1E:V$@
M9V5S;&$`)60M9&YE=FYA(&YA<&]V960`)7,@XH"3($)O9&ET92!P;WIO<FYI
M`"5S($]D=&ES`"5S($M"`"5S(%9Z9'+%OF5V86QN82!D96QA("T@4&]T<F1I
M=&5V`"5S("`@("`@`"5S('!R:6IA=F$`)7,@4&]G;VII`"5S(,6^92!O8G-T
M86IA+@`E<R!O8B`E<R`E<P`E<R!J92!P<FEP<F%V;&IE;B!N82!I>G9A:F%N
M:F4@=GID<L6^979A;&YI:"!O<&5R86-I:BP@<')E=F5R:2!S<&]D86HN4')E
M=F5R:2!N86)I<F%L;FEK('IA('9S92!O<&5R86-I:F4L(&MI(&)I(&II:"!R
M860@;W!R879I;"!S961A:BX`4&]T<F5B=6IE;2`E<R``)7,@;6EN=70`)7,@
M;F4@;F%J9&5M`"5S(&]B("5S(&]D("5S`$EM96YI:R`E<P!+;VQE9&%R("5S
M`$)E;&7%OFMA("5S`"5S($]P<F%V:6QA`"5S.B`E<P`E<SH@=&\@<W!O<F_$
MC6EL;R!M;V=OQ(UE(&YI(&]D('!OQ:%I;&IA=&5L:F$L(&MA=&5R:2!P<F%V
M:2!D82!J92X@4&%Z:71E('-E(&MA=&5R:6AK;VQI('!O=F5Z878@=B!S<&]R
M;\2-:6QU(&%L:2!P;V1A:F%N:G4@:V%T97)I:"!K;VQI(&]S96)N:6@@:6YF
M;W)M86-I:B!N82!T82!N87-L;W8N`"P@9V]S=&EM(``L(&=O<W1I;2`E<R`E
M<P`L('-P<F5M96YL:FEV:V$@;V0@)7,@9&\@)7,`+2T@:7IB97)I("TM`#$R
M('5R(&9O<FUA=``R-"!U<B!F;W)M870`,C0@=7(`4')E:L6A;FIA(&UOQ;YN
M;W-T`%IA('1A(&)L;VL@:F4@<&]T<F5B;F$@<&]V97IA=F$@;F$@<&]D871K
M;W9N:2!S=')EQ;YN:6L`4&]J879I;&$@<V4@:F4@:'5D82!N87!A:V$N`%IA
M(&MO9&ER871I('-P;W)OQ(UI;&\@<&]T<F5B=6IE;2!J879N:2!01U`@:VQJ
M=<2-+@!*879N:2!01U`@:VQJ=<2-(&IE('!O=')E8F5N('IA(&]D:VQE<&%N
M:F4@<W!O<F_$C6EL82X`2F%V;FD@4$=0(&ML:G7$C2P@>F%S96)N:2!01U`@
M:VQJ=<2-(&EN(&=E<VQO('-O('!O=')E8FYI('IA(&]D:VQE<&%N:F4@<W!O
M<F_$C6EL82X`2F%V;FD@4$=0(&ML:G7$C2P@>F%S96)N:2!01U`@:VQJ=<2-
M(&EN(&=E<VQO('-O('!O=')E8FYI('IA('!O9'!I<R!S<&]R;\2-:6QA+@!*
M879N:2!3+TU)344@:VQJ=<2-+"!Z87-E8FYI(%,O34E-12!K;&IUQ(T@:6X@
M9V5S;&\@<V\@<&]T<F5B;FD@>F$@<&]D<&ES('-P;W)OQ(UI;&$N`$IA=FYI
M(%,O34E-12!K;&IUQ(TL('IA<V5B;FD@4R]-24U%(&ML:G7$C2!I;B!G97-L
M;R!S;R!P;W1R96)N:2!Z82!P;V1P:7,@<W!O<F_$C6EL82X`($IA=FYI(%--
M24U%(&ML:G5E(&IE('!O=')E8F5N('IA(&]D:VQE<&%N:F4@<W!O<F_$C6EL
M82``3V)L8<2-;F\`2G5T<F%N:FD@4F%H96P@9&7%O@!*=71R86YJ:2!D9<6^
M`$IU=')A;FII(&YA;&EV`$IU=')A;FII('-N9<6^;FD@;65T9<6^`$%-+U!-
M`$%022!)1`!/<&ES+BXN`%!R97!O=F5D86X@9&]S=&]P('IA('5S='9A<FIA
M;FIE(&UA<&4@5D93+B``4')E<&]V961A;B!D;W-T;W`@>F$@=7-T=F%R:F%N
M:F4@9&%T;W1E:V4@5D93+@!68<6A:2!P;V1A=&MI`%!O=')D:2!G97-L;P!)
M>G9A:F%M`$EZ=F%J86T`1&]D86H`1&]D86H@<VMU<&EN;R!O=')O:P!$;V1A
M:B!D;W9O;&IE;FIA(&]T<F]K80!$961A:B!S96TZ`$1O9&%J(&YO=F\@<VMU
M<&EN;P!$;V1A:B!N;W9A(&1O=F]L:F5N:F$`1&]D86H@<VMU<&EN;R!O=')O
M:R`B)7,B`$1O9&%J(&1O=F]L:F5N:F4@;W1R;VMA("(E<R(`1&]D86H@;F]V
M96=A('5P;W)A8FYI:V$Z`$1O9&%J('-T;VQP96,`1&]D86H@;F]V92#$C6QA
M;F4`1&]D86H@<&%R`$1O9&%J("5S($UE;G4@=B!-;WII;&QA(%-I9&5B87(`
M1&]D86H@=B!I;65N:6LZ`$1O9&%J('8@;6]J(&EM96YI:SH`1&]D86H@=7!O
M<F%B;FEK80`@1&]D86P@)R5S)R!S:7-T96UU+"!V96YD87(@8F\@;F5M;V=O
MQ(UE(&1O9&%J86YJ92!D;V1A=&YI:"!V<&ES;FEH(&EN9F]R;6%C:6HZ("5S
M+@!$;V1A;B`G)7,G('-I<W1E;74N(%-E9&%J('-E(&QA:&MO('!R:6IA=FET
M92X`1&]D86IA;FIE('5P;W)A8FYI:V]V(&IE(&]N96UO9V_$C65N;RX`3F%S
M;&]V`$EM96YI:P!5<F5D:2!D;W9O;&IE;FIA('IA(&]S=&%L92!U<&]R86)N
M:6ME`%5P<F%V;&IA;FIE`%)E:VQA;64`069H86YI<W1A;@!!;&)A;FEJ80!!
M;,6^:7)I:F$`3WII<F]M80!6<V4`5G-I(&]V97)J96YI('5P;W)A8FYI:VD`
M5G-E('-K=7!I;F4`5G-A($1O=F]L:F5N:F$`1&]V;VQI(&UN;V=O:W)A=&YE
M(&YA<VQO=F4`1&]V;VQI(&YA<W1A=FET=F4@(`##@L6]92!O8G-T86IA`$YA
M9&]M97-T;F\@24U34"!U<&]R86)N:<6A:V\@:6UE`$YA9&]M97-T;F\@24U3
M4"!G97-L;P!.861O;65S=&YO($E-4U`@=7!O<F%B;FG%H6MO(&EM90!.861O
M;65S=&YI(&5L96MT<F]N<VMI(&YA<VQO=@!.861O;65S=&YI('9Z;W)C:0`@
M06UE<FG%H6MA(%-A;6]A(`!.879E9&5N82!J92!B:6QA(&YE>F%K;VYI=&$@
M=G)E9&YO<W0N`'!O:F%V:6QA('-E(&IE(&YA<&%K80!!;F1O<F$`06YG;VQA
M`$%N9W5I;&QA`$%N;VYI;65N(%!R;WAY`$]D9V]V;W(`06YT87)K=&EC80!!
M;G1I9W5A(&EN($)A<F)U9&$`07!L:6MA8VEJ80!397IN86T@87!L:6MA8VEJ
M`$%P;&EK86-I:F$@:F4@<')I<')A=FQJ96YA`%!R:6IA=FD@;W1R;VMO=F4@
M9&5L;FEC92``4&]T<F1I`$%P<FEL`$%R86)S:VD@*%=I;F1O=W,M,3(U-BD`
M5F5L:6MO<W0@9&%T;W1E:V4@07)H:78@`$EM92!!<FAI=F$`4W1E('!R97!R
M:<2-86YI+"!D82#%OF5L:71E('!R96ML:6-A=&D@>F%H=&5V;R!Z82!P<FEJ
M879O('IA("5S(#\@`%-T92!P<F5P<FG$C6%N:2P@9&$@Q;YE;&ET92!I>F)R
M:7-A=&D@)R5S)R!I;B!O<W1A;&4@<&]D<VMU<&EN93\`07)G96YT:6YA`$%R
M;65N:6IA`$%R;65N<VMI("A!4DU30TE)+3@I`%5M971N;W-T`$%R=6)A`%5M
M971N;W-T:2#$C7)K`$%Z:6$O4&%C:69IQ:%K92!R96=I:F4`5G!R8<6A86H@
M>F$@<&]T<F1I=&5V('!R960@:7IV86IA;FIE;2!V>F1RQ;YE=F%N:F$`1&]D
M96QJ96YE(&MO;&]N90!0;W-K=7,@:7IB<FES82!N96]B<W1O:F7$C64@<VMU
M<&EN92X`4&]S:W5S(&EZ8G)I<V$@;F5O8G-T;VIEQ(UE9V$@9&]V;VQJ96YJ
M82X`4&]S:W5S('5R961I='9E(&YE;V)S=&]J9<2-96=A(&1O=F]L:F5N:F$N
M`%!O<VMU<R!U<F5D:71V92!N96]B<W1O:F7$C64@9&5L;FEC92X`3&%S=&YO
M<W1I`$%V9W5S=`!!=G-T<F%L:6IA`$%V<W1R:6IA`"!!=71H7V-Y<G5S.B!:
M86AT979A;F\@:6UA<"#%H6ER:71E=B!N:7-E;2!N8<6A96PN`$%U=&A?8WER
M=7,Z($)A8VME;F0@;FEM82!Z86AT979A;FEH('IM;\6^;F]S=&DN`$%U=&A?
M8WER=7,Z(%IA:'1E=F%N;R!I;6%P(,6A:7)I=&5V(&YI<V5M(&YAQ:%E;"X`
M075T:%]F='`Z(%IA:'1E=F%N;R!&5%`@Q:%I<FET978@;FES96T@;F'%H65L
M+B!)>G!O;&YI(%!(4"!Z("UO;F5M;V=OQ(UE;F\M(&9T<"!Z86UE;FIA=F\N
M(`!!=71H7VEM87!H=&5V86YO($E-05!I=&5V(&YI<V5M(&YAQ:%E;"X`075T
M:%]K<F(U.B!:86AT979A;F\@:W)B-2#%H6ER:71E=B!N:7-E;2!N8<6A96PN
M`$%U=&A?;&1A<#H@3FD@;6_%OFYO(&1O9&%J86YJ92!U<&]R86)N:6MO=B!V
M($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!.:2!M;\6^;F\@;V1S=')A
M;FIE=F%N:F4@=7!O<F%B;FEK;W8@=B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?
M;&1A<#H@6F%H=&5V86YO($Q$05`@Q:%I<FET978@;FES96T@;F'%H65L+@!!
M=71H7VQD87`Z($YE(&UO<F5M(&1O9&%T:2!U<&]R86)N:6MA("5S+B!3<&]R
M;\2-:6QO('-T<F7%OFYI:V$Z(`!!=71H7VQD87`Z($YE(&UO<F5M(&]D<W1R
M86YI=&D@=7!O<F%B;FEK82`E<P!!=71H7VQD87`Z($YE(&UO<F5M(&YA9&=R
M861I=&D@=7!O<F%B;FEK82`E<R``075T:%]L9&%P.B!N92!M;W)E;2!N861G
M<F%J979A=&D@=7!O<F%B;FEK;W8@=B!!8W1I=F4@1&ER97-T;W)Y+@!!=71H
M7VUC86PZ(%IA:'1E=F%N;R!-0T%,(,6A:7)I=&5V(&YI<V5M(&YAQ:%E;"X`
M075T:%]S;6)A=71H.B!:86AT979A;F5G82!S;6)A=71H('IA(,6A:7)I=&5V
M(&YI<V5M(&YAQ:%E;"X`3W9E<FIA;FIE('IA($944"!S=')EQ;YN:6L@;FD@
M=7-P96QO+@!/=F5R:F%N:F4@;FD@=7-P96QO+@!/=F5R:F%N:F4@;FD@=7-P
M96QO+B`E<P!/=F5R:F%N:F4@:F4@>F%V<FYI;"!2041)55,@<W1R9<6^;FEK
M+@!/=F5R:F%N:F4@>F$@1E10('-T<F7%OFYI:R!N:2!U<W!E;&\N`$]V97)J
M86YJ92!Z82!334(@<W1R9<6^;FEK(&YI('5S<&5L;RX`4&]L:F$@;F$@<F%Z
M<&]L86=O.@!!>F5R8F%J9,6^86X@`$YE=6UN:2!I>F=O=F]R:0!.87!AQ(UN
M;R!K97)B97)O<R!G97-L;RX`3F%P8<2-;F\@:V5R8F5R;W,@=7!O<F%B;FG%
MH6MO(&EM92X`0F%H86UI`$)A:')A:6X`0F%L=&EK("A)4T\M.#@U.2TQ,RD`
M0F%N9VQA9&7%H0!"87)B861O<P!.:7-E;2!N8<6A96P@;W-N;W9N96=A(&=R
M869IQ(UN96=A(&EM96YI:V$@(B5S(BX`0F5L;W)U<VEJ80!"96QG:6IA`$)E
M;&EZ90!"96YI;@!"97)M=61S:VD@;W1O:VD`0G5T86X`4F]J<W1N:2!D86X`
M3FES96T@;F'%H65L(&)L;VMA("(E<R(L(&%P;&EK86-I:F4@(B5S(B`N`%IA
M=7-T879I($YA<W1A=FET=F4`6F%U<W1A=FD@5&EP`$)O;&EV:6IA`%!R:6QJ
M=6)L:F5N90!";W-N82!I;B!(97)C96=O=FEN80!/8F]J:0!";V-V86YA`$)O
M=79E=&]V;R!O=&_$C6IE`$)R87II;&EJ80`@0G)I=&%N<VMO(&]Z96UL:F4@
M26YD:6IS:V5G82!O8V5A;F$@`$)R=6YE:0!";VQG87)I:F$`0G5R:VEN82!&
M87-O`$)U<G5N9&D`35-'`$-20P`@0U),(')A>F1E;&ET=F5N92!T;\2-:V4@
M`$YA<W1A=FQJ86YJ92!P<F5D<&]M;FEL;FEK82!N:2!D;VMO;L2-86YO+@!+
M;VQE9&%R`%IB<FG%H6D`2V%M8F]DQ;YA`$MA;65R=6X`3F4@;6]R96IO('5P
M<F%V;&IA=&D@>G5N86YJ:2!U<')A=FQJ86QC:0!.92!M;W)E;2!V>G!O<W1A
M=FET:2!P;W9E>F%V92!Z($E-05`@<W1R9<6^;FEK;VTZ("5S(`!.:2!M;V=O
MQ(UE(&]D<')E=&D@(B5S(B!D871O=&5K92X`2V%N861A`%IB<FG%H6D`<&]R
M;\2-:6QO(&\@=&7%OF%V86@@>B!B<FES86YJ96T`3F4@;6]R96T@:V]P:7)A
M=&D@9&%T;W1E:R`H92D@+2!V:7(@:6X@8VEL:F$@<W1A(&ES=&$N`$YE(&UO
M<F5M(&EZ8G)I<V%T:2!D871O=&5K92`B)7,B+@!.92!N86ID96T@>F'$C6%S
M;F4@9&%T;W1E:RX`3F4@;6]R96T@<')E;6%K;FET:2!D871O=&5K("AE*2`M
M(&-I;&H@:F4@>FYO=')A:B!V:7)A+@!.92!M;W)E;2!N861A;&IE=F%T:2!B
M<F5Z('!A<F%M971R;W8@)V-I;&IN92!D871O=&5K92<N`"(E<R(@26UE;FEK
M82!N92!M;W)E;2!Z8G)I<V%T:2X`3F4@;6]R96T@;V1S=')A;FET:3L@;V)S
M=&%J82`E9"!P;V1V96QJ`$YE(&UO<F5M('!O;F]V;F\@=7)E9&ET:2P@Q:%T
M979I;&\@9&%N:6@@=FYO<V]V('-E(&YE('-K;&%D82!S(,6A=&5V:6QO;2`@
M<VAR86YJ96YI:"X`3F4@;6]R96T@879T;VUA='-K;R!P;VYA<W1A=FET:2!G
M97-L82P@;V)R;FET92!S92!N82!S:W)B;FEK80!.92!M;W)E;2!P<F5U<VUE
M<FET:2!S<&]R;\2-:6QA(&YA=F5D96YE;74@Q:%T979I;'4N`$-A;FYO="!W
M<FET92!T;R!F:6QE("(E<R(`2V%P=F5R9'-K:2!O=&]K:0!0<FEN8<6A86QE
M8P!+871E9V]R:6IE(&EN('IN86UK90!+87EM86YS:VD@;W1O:VD`36]B:6QN
M:2!T96QE9F]N`$UO8FEL;FD@=&5L969O;@!+96QT<VMI("A)4T\M.#@U.2TQ
M-"D`0V5N=')A;&YO($%F<FG%H6MA(%)E<'5B;&EK80!3<F5D;FIE979R;W!S
M:VD@*$E33RTX.#4Y+3(I`%!O9')O8FYO<W1I('!O=')D:6QA`$QA<W1N:6L@
M<&]T<F1I;&$`4')A=FEL82!P;W1R9&EL80!%860`4W!R96UE;FD`<W!R96UE
M;FET92!V8<6A92!G97-L;P!3<')E;65N:71E(&EM92!I;B!N87-L;W8@=F'%
MH65G82!E;&5K=')O;G-K96=A(&YA<VQO=F$L(&MI(&=A('9I9&EJ;W!R96IE
M;6YI:VD@;V(@8G)A;FIU(&EN(&]D9V]V87)J86YJ=2!N82!V8<6A;R!P;\6A
M=&\N`%8@=')E;G5T;FD@:V]N9FEG=7)A8VEJ92!N92!M;W)E=&4@<W!R96UE
M;FET:2!G97-L82X@2V]N=&%K=&ER86IT92!V8<6A96=A('-K<F)N:6MA+@#$
MC6EL90!+:71A:G-K80!0;V5N;W-T879L:F5N82!K:71A:L6AQ(UI;F$H1T(R
M,S$R*0!4<F%D:6-I;VYA;&YA(&MI=&%JQ:'$C6EN82`H0FEG-2D`27IB97)I
M(&%P;&EK86-I:F\Z`$EZ8F5R:2!G97-L;P!)>F)E<FD@=7!O<F%B;FG%H6MO
M(&EM90!+86MO('!R:6MA>F%T:2!D871U;64Z`$)OQ;YIQ(UN:2!O=&]K:0!.
M:7-E;2!N8<6A96P@9&5F:6YI8VEJ92!V<G-T92!Z82`E<RX`2F%S;F\`4')E
MQ(UI<W1I('!O:7IV961B90!/9'-T<F%N:2!Z=6YA;FIE9V$@=7!O<F%B;FEK
M83H@)7,@`$]D<W1R86YI('5P;W)A8FYI:V$`27IB<FG%H6D@<&]D871E:R!U
M<&]R86)N:6MA`&EZ8G)IQ:%I('!O=&5M`$ML:6MN:2!Z82!N861A;&IE=F%N
M:F4@`$-L:6-K871E;&P@<')O=&]M($A45%``6F%P<FD@;VMN;P!/8FQA:VD`
M6FIU=')A:B!/8FQAQ(UN;P!/8FQAQ(UN;P!+;VMO<V]V:2!O=&]K:0!:9')U
MQ;YI('-T<F%N<VMO(&]K;F\`2V]L=6UB:6IA`$)A<G9A`$EZ8FER86QE8R!B
M87)V`"!)>F)I<F$@0F%R=F4@`$YA<VQO=B!S=&]L<&EC80!3=')I<&D`56MA
M>@!5:V%Z;F$@;'5P:6YA`$MO;65N=&%R`%-K=7!N;R!I;64`2V]M;W)I(`!$
M<G7%OF)A`%)AQ(UU;F%L;FEK:0!.87-T879I=&5V`$YA<W1A=FET=F4`4F%Z
M;&EK92!N87-T879I='9E`$YA<W1A=FET=F4@>F$@<VEN:W)O;FEZ86-I:F%O
M(&1L86[$C6YI:V]V`$YA<W1A=FET=F4@<&]T<F5B=6IE:F\@8<6^=7)I<F%N
M:F4`3F%S=&%V:2`E<P!0;W1R9&D@9V5S;&\`2V]N9V\`2V]N9V\L($1E;6]K
M<F%T:<2-;F$@<F5P=6)L:6MA`%!O=F5Z879A(&YI('5S<&5L82X`4&]V97IA
M=F$@;FD@=7-P96QA.@!:879R;FIE;F$@<&]V97IA=F$@>B!J879N:6T@:VQJ
M=<2-;FEM('-T<F7%OFYI:V]M+@!:879R;FIE;F$@<&]V97IA=F$@>B!J879N
M:6T@:VQJ=<2-;FEM('-T<F7%OFYI:V]M+B!287IL;V<Z("5S("@E<RD`4&]V
M97IA=F$@<R!&5%`@<W1R9<6^;FEK;VT@;FD@=7-P96QA+@!3=&EK:0!3=&EK
M(&IE(&)I;"!U<W!EQ:%N;R!D;V1A;B!K('9AQ:%I;2!N87-L;W9O;2X`5&EP
M('-T:6MA('-T:7-N:F5N92!D871O=&5K93H`5G-E8FEN92!O9"(E<R(`3F%D
M86QJ=6H`0V]O:V]V:2!O=&]K:0!0:<6A:V]T96L`2V]P:7)A;FIE(&YI('5S
M<&5L;SH@)7,`240@<W1R;\6A96L`2V]S=&%R:6MA`"!3;&]N;VMOQ:'$C65N
M82!O8F%L82``4$=0(&YE(&UO<F4@Q:%I9G)I<F%T:2!S<&]R;\2-:6QA.@!.
M:2!M;V=O92!01U`@<&]D<&ES('-P;W)O96EL82X`3FD@;6]G;\2-92!3+TU)
M344@Q:%I9G)I<F%T:2!S<&]R;\2-:6QA+@!.:2!M;V=OQ(UE(%,O34E-12!P
M;V1P:7,@<W!O<F_$C6EL82X`3FD@;6]G;\2-92!D;V1A=&D@<W1I:V]V+B`E
M<RX`4&]V97IA=F$@>B!,1$%0('-T<F7%OFYI:V]M(&YI(&UO9V_$C6$N`$YI
M(&UO9V_$C64@:V]N=')O;&ER871I(#\_/S\_/R`E<RX`4&]V97IA=F$@>B!,
M1$%0('-T<F7%OFYI:V]M(&YI(&UO9V_$C6$N`$YE(&UO<F5M('9Z<&]S=&%V
M:71I('!O=F5Z879E(',@<W1R9<6^;FEK;VT@(B5S(B!Z('5P;W)A8F\@1E10
M.B`E<P!.92!M;W)E;2!U<W1V87)I=&D@<V5Z;F%M82!Z82!D:7-T<FEB=6-I
M:F\N("5S`$YI(&UO9V_$C64@9&7%H6EF<FER871I(%!'4"!P;V1A=&MO=CH`
M3FD@;6]G;\2-92!D9<6A:69R:7)A=&D@4R]-24U%('!O9&%T:V4N`$YE(&UO
M<F5M(&EZ8G)I<V%T:2!S=&EK;W8N("5S`$YE(&UO<F5M(&EZ8G)I<V%T:2!D
M:7-T<FEB=6-I:G-K96=A('-E>FYA;6$N("5S`$YE(&UO<F5M(&EZ8G)I<V%T
M:2!N87-T879I='9E;F4@8<6^=7)A8VEJ<VME('-K<FEP=&4@(B5S(@!.:2!M
M;V=OQ(UE(&1O;&_$C6ET:2!E;&5K=')O;G-K96=A(&YA<VQO=F$@<')E:F5M
M;FEK82X`3FD@;6]G;\2-92!D;VQOQ(UI=&D@8V5L;W1N96=A(&EM96YI:V$N
M`$YI(&UO9V_$C64@9&]L;\2-:71I(&-E;&]T;F5G82!D:7-T<FEB=6-I:G-K
M96=A('-E>FYA;6$N`$YI(&UO9V_$C64@9&]L;\2-:71I(&-E;&]T;F5G82!S
M97IN86UA(&1I<W1R:6)U8VEJ<VMI:"!S97IN86UO=@!.:2!M;V=OQ(UE(&YA
M;&_%OFET:2!S=')A=&5G:6IE("(E<R(N`$YE(&UO<F5M('1V;W)I=&D@;6%P
M92`B)7,B+@!.:2!M;V=OQ(UE(&1O8FET:2!J879N96=A(&ML:G7$C6$@;V0@
M:VQJ=<2-;F5G82!S=')EQ;YN:6MA+@!.:2!M;V=OQ(UE(&]D<')E=&D@(B5S
M(B!Z82!P:7-A;FIE+@!.:2!M;V=OQ(UE(&]D<')E=&D@)7,N`$YI(&UO9V_$
MC64@;V1P<F5T:2!M;V1U;&$@;R!O<')A=FEL=5]V>F1RQ;YE=F%N:F$@)7,@
M`$YI(&UO9V_$C64@<')E8G)A=&D@:6UE;FEK("(E<R(N`$YI(&UO9V_$C64@
M9&]S9<2-:2!,1$%0('-T<F7%OFYI:V$N`$YI(&UO9V_$C64@<')E8G)A=&D@
M)7,N`$YI(&UOQ;YN;R!P;VYA<W1A=FET:2!G97-L82!Z82!Z86AT979A;F5G
M82!U<&]R86)N:6MA+B!.96MA=&5R92!A;&D@=G-E<&]D<F]B;F]S=&D@;FES
M;R!P<F%V:6QN92X@4&]S:W5S:71E('IN;W9A(&%L:2!K;VYT86MT:7)A:G1E
M('9AQ:%E9V%U<')A=FET96QJ82P@Q(UE('!O=')E8G5J971E(&YA9&%L:FYJ
M;R!P;VUOQ(TN`$YI('5S<&5L;R!V>G!O<W1A=FET:3H@)7,@`$YI('5S<&5L
M;R!V>G!O<W1A=FET:2!I;65N:6MA.B`E<R``3FD@=7-P96QO('9Z<&]S=&%V
M:71I(&1I<W1R:6)U8VEJ<VME9V$@<V5Z;F%M83H@)7,@`$YI('5S<&5L;R!V
M>G!O<W1A=FET:2!D:7-T<FEB=6-I:G-K96=A('-E>FYA;6$Z("5S(`!.:2!U
M<W!E;&\@=GIP;W-T879I=&DZ("5S(`!:86AT979A;FD@)R5S)R!N:2!P;V1R
M;V)N;R!O8FQI:V]V86X@=B`E<R!P;V1O8FDN`$YE(&UO<F5M(&EZ8G)I<V%T
M:2!M87!E("(E<R(N`"5S(&MO;F9I9W5R86-I:F4@;FD@;6]G;\2-92!S:')A
M;FET:2X`2V]N9FEG=7)A8VEJ92!V87)N;W-T;F4@:V]P:6IE(&YI(&UO9V_$
MC64@<VAR86YI=&DN`$MO;F9I9W5R86-I:F4@=F%R;F]S=&YE(&MO<&EJ92!N
M:2!M;V=OQ(UE('-H<F%N:71I.B`E<P!.92!M;W)E;2!S:')A;FET:2!N87-T
M879I='9E;F4@8<6^=7)A8VEJ<VME('-K<FEP=&4@;F$Z("(E<R(N`$YE(&UO
M<F5M('-H<F%N:71I(&MO;F9I9W5R86-I:G-K;R!D871O=&5K;R`E<RP@=F%R
M;F]S=&YE(&MO<&EJ92X`3F4@;6]R96T@<VAR86YI=&D@(&MO;F9I9W5R86-I
M:G-K92!D871O=&5K92`E<RX@3&%H:V\@=7!O<F%B:71E(&%L:2!E;F\@;V0@
M;W!C:6H@>F$@<VAR86YI=&D@:V]D;R!Z861A:B!N82`E<R!A;&D@<F_$C6YO
M(&MO<&ER871E('-P;V1N:F\@:V]D;R!N82`E<RX`3FD@;6]G;\2-92!I<VMA
M;FIE($Q$05`@<W1R9<6^;FEK82X`3FD@;6]G;\2-92!O9'-T<F%N:71I('!O
M=F5Z879E('H@(B5S(BX`3FD@;6]G;\2-92!AQ;YU<FER871I('-T:6LN("5S
M+@!.:2!M;V=OQ(UE(&'%OG5R:7)A=&D@9&ES=')I8G5C:6IS:VD@<V5Z;F%M
M+B`E<P!.:2!M;V=OQ(UE(&YA<&ES871I(&MO;F9I9W5R86-I:F4@>F$@(B5S
M(CH@)7,`3F4@;F%J9&5M($UO>FEL;&$@4VED96)A<BX@4')E=F5R:2!A;&D@
M:F4@;V1P<G0N`"(E<R(@=7!O<F%B;FEK=2!N92!M;W)E;2!D;V1E;&ET:2!S
M;&5D9<2-:6@@<')A=FEC('IA(&UA<&\@(B5S(CH@)7,`4')EQ:%T971O(&)E
M<V5D:6QO(`!$<L6^879A`%1EQ(UA:FD`57-T=F%R:0!5<W1V87)I(&YO=F\`
M57-T=F%R:2!P;V1M87!E`$%V=&]R(&1O=F]L:F5N:@#%H'1E=FEL:V$@:W)E
M9&ET;F4@:V%R=&EC92``2')V8<6A:V$`2W5B80!3961A;FIE(#0@<F%Z=F]J
M;F4@<W1O<&YJ90!3961A;FIE('-E:F4`4V5D86YJ:2#$C6%S`%-E9&%N:FD@
M=7!O<F%B;FEK:0!3961A;FIE('9R96UE`%-E9&%N:F4@<W1A;FIE.@!.87-T
M879I=&4@86MT:79N;W-T:2P@:VD@<V4@8F]D;R!I>G9RQ:%I;&4@;V(@<')I
M:F%V:2!N82`E<RX`0VEP97(`0VER:6QI8V$H2T])."U2*0!#:7)I;&EC82`H
M5VEN9&]W<RTQ,C4Q*0!#:7)I;&EC82]5:W)A:FEN<VMI("A+3TDX+54I`,2-
M9<6A:V$@<F5P=6)L:6MA`$1$`$1.4R`H<&]G;&5J(&AT='`Z+R]P96%R+G!H
M<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N
M+G!H<"D`1&YE=FYO`%!R96=L961O=F%L;FEK(&1R979E<VYE('-T<G5K='5R
M90!0;VEZ=F5D8F$@8F%Z92!P;V1A=&MO=@!$871U;0!$871U;2!P<F5J96UA
M`$EZ8FER82!D871U;6$`1&%N`$1E8V5M8F5R`%!R:79Z971O`%!R:79Z971A
M($)A<G9A`%!R:79Z971A(&ED96YT:71E=&$`4')I=GIE=&$@;'5P:6YA`$]P
M<F5D96QI='9E`%IB<FG%H6D`6F)R:<6A:2!S:W5P:6YO`%IB<FG%H6D@9&YE
M=FYI:P!:8G)IQ:%I(&1O=F]L:F5N:F4`27IB<FG%H6D@:6X@<')EQ(UI<W1I
M('-P;W)OQ(UI;&$`27IB<FG%H6D@;V)S=&]J9<2-:2!A;'1E<FYA=&EV;FD@
M=GIO<F5C`$EZ8G)IQ:%I('-P;W)OQ(UI;&$`27IB<FG%H6D@9&]V;VQJ96YJ
M82!Z82`B)7,B`$EZ8G)IQ:%E;2!D;W9O;&IE;FIE('IA("(E<R(@:6X@=G-A
M('!O9&1O=F]L:F5N:F$_`$EZ8G)IQ:%I(&EZ8G)A;F\@:61E;G1I=&5T;P!)
M>F)R:<6A:2!P;V0@;6%P90!.92!M;W)E;2!I>F)R:7-A=&D@;F%S=&%V:71V
M96YE(&'%OG5R86-I:G-K92!S:W)I<'1E("(E<R(N`,2,87,@9&]S=&%V90!$
M86YS:V$`3W!IQ:%I=&4@=&7%OF%V;P!/<&ES`%!O9')O8FYO<W1I("AT=61I
M('8@2&]R9&]V:2!L;V<@9&%T;W1E:VDI.@!0;V1R;V)N;W-T:2!S;R!B:6QE
M('!R:6IA=FQJ96YE('IA('5P<F%V;&IA;&-A+@!287IV;VH`4F]S:<6AQ(UE
M`%)O<VG%H<2-92!Z82!P<F5JQ:%N:F\@=7)O.@!2;W-IQ:'$C64Z`$EM96YI
M:P!0<FEK8<6^96T@Q(UA<R!P;R`R-"!U<FYE;2!S:7-T96UU/P!.87-T879I
M='9E('!R:6MA>F]V86YJ80!0<FEK8<6^:2!P;V1R;V)N;R!N87!O=F5D`%!R
M:6MAQ;YI(&YA<&]V960@*%1!1BD`4')I:V'%OFD@=F5L:6MO<W0`3V)V97-T
M:6QO(&\@9&]S=&%V;&IE;FD@<&_%H71I`$3%OFEB=71I`$YE('IB<FG%H6D`
M3F4@9&]S=&]P86H@;F5P;W-R961N;R!D;R!O:')A;FIA;FIA+G!H<"``06QI
M('!R=F$@=G)S=&$@=G-E8G5J92!I;65N82!P;VQJ/R#$C64@:FEH+"!P<F5V
M97)I(&YA8FER86QN:6LZ`$1O;6EN:6-A`$1O;6EN:6MA;G-K82!297!U8FQI
M:V$`3FES=&4@<F5G:7-T<FER86YI/R!296=I<W1R:7)A:G1E('-E+B``4')E
M;F5S:2`E<P!0<F5N97-I=&4@9V5N97)I<F%N;R!K;VYF:6=U<F%C:6IO(&MO
M="!02%`@<VMR:7!T;RX`4&%D86IOQ(UI(&UE;FD`6F1R879I;&$`16QE:W1R
M;VYS:VD@;F%S;&]V`%!R96YO<R!E;&5K=')O;G-K:6@@<W!O<F_$C6EL('8@
M4TU3+6IE('IA(&]P97)A=&5R:F4L(&MI('1O(&]M;V=OQ(UA:F\N`$524@!%
M:W9A9&]R`%5R961I`%5R961I('-T;VQP96,`57)E9&D@<VMU<&EN;P!5<F5D
M:2!D;W9O;&IE;FIE`%5R961I(&1O=F]L:F5N:F$`57)E9&D@9&]V;VQJ96YJ
M82!Z82`E<R``57)E9&D@;6_%OFYO<W1I('IA.@!5<F5D:2!D;W9O;&IE;FIA
M('IA("(E<R(`57)E9&D@9&]V;VQJ96YJ82!Z82`E<P!)>F]B<F'%OF5V86YJ
M90!%9VEP=`!386QV861O<@!%;&5K=')O;G-K82!P;\6A=&$`16QE:W1R;VYS
M:VD@;F%S;&]V`$5L96MT<F]N<VMI(&YA<VQO=B!S92!M;W)A('5J96UA=&DN
M`$5L96MT<F]N<VMA('!OQ:%T82!S('!O=')D:71V:6IO`$5M86EL+5--4R!0
M<F5H;V0`4VUEQ:%K:0!0<F%Z96YO('-P;W)OQ(UI;&\N`%!R87IE;B!R97IU
M;'1A="X`4')A>F5N(&ES:V%L;FEK`$EZ:VQO<&EM('9S=&%V;&IA;FIE('-L
M:6L@:7H@1F]T;R!'86QE<FEJ92!V('1E:W-T/P!)>FML;W!I;2!M96YI('H@
M9&5S;FEM(&ML:6MO;3\`2V]N96,@;&5T80!6;F5S:71E('9A<FYO<W1N;R!V
M<')AQ:%A;FIE+"!K:2!B;R!P;W-T879L:F5N;RP@Q(UE(&)O<W1E('!O=')E
M8F]V86QI<&]N87-T879I=&D@=F'%H64@9V5S;&\L(&YP<BX@PX+B@)YI;64@
M=F'%H65G82!L:G5B;&IE;L2-:V$@:F4_.@!6;F5S:71E('-P;V1N:F4@Q(UR
M:V4Z`$5K=F%T;W)I86QN82!'=FEN96IA`$5R:71R96IA`$YA<&%K80!.87!A
M:V$@<')I('5S='9A<FIA;FIU('-T;VQP83H@)7,N`$YA<&%K82!P<FD@8G)I
M<V%N:G4@<&]V97IA=F4@<VEN:')O;B!I>F%C:6IE.B`E<P!.87!A:V$@<')I
M(&)R:7-A;FIU(&1N979N:6MA('-I;FAR;VYI>F%C:6IE.B`E<RX`3F%P86MA
M('!R:2!P;W9E>F]V86YJ=3H@)7,N`$YA<&%K82!P<FD@8<6^=7)I<F%N:G4@
M9V5S;&$Z("5S+@!.87!A:V$@>B!E;&5K=')O;G-K:6T@<W!O<F_$C6EL;VTN
M`$YA<&%K82!P<FD@<&ES86YJ=2`B)7,B+@!%<W1O;FEJ80!%=&EO<&EJ80!%
M<W1O;FEJ80!%=G)O<&$`5G-A:VEH(#$U(&UI;G5T`%9S86MI(#(@;6EN=71I
M`%9S86MI:"`S,"!S96MU;F0`5G-A:VEH(#4@;6EN=70`5G-A:V$@<')I:F%V
M80!6<V%K92!P;VP@=7)E`%9S86MO(&UI;G5T;P!0<FEM97(@=G)E9&YO<W1I
M.@!)>G9E9&D`4&]V9<2-86H`4')IQ(UA:V]V86X@)RDG`%!R:<2-86MO=F%N
M82!J92!B:6QA(&)E<V5D82!A;&D@8F5S961N82!Z=F5Z82!V(&YA=F5D;FEC
M86@`1&%T=6T@>F%P861L;W-T:0!:87-T;W!N:6L`1E10(&YA;&_%OFET978@
M;F%M97-T:71V92X`3FD@=7-P96QO('9Z<&]S=&%V:71I('!R969E<F5N8V4N
M`%!O=F5Z879A('H@3$1!4"!S=')EQ;YN:6MO;2!N:2!U<W!E;&$N`%!O=F5Z
M879A(',@4TU"('-T<F7%OFYI:V]M(&YI('5S<&5L82``2V]P:7)A;FIE(&EZ
M("(E<R(L(&YI('5S<&5L;RX`2V]P:7)A;FIE(&YA("(E<R(L(&YI('5S<&5L
M;RX`3FD@=7-P96QO('9Z<&]S=&%V:71I(&YO=F\@4T%33"!P;W9E>F%V;RX`
M3FD@=7-P96QO('!R96UA:VYI=&D@:SH@)7,@`$YE;6]G;\2-92!P<F5B<F%T
M:3H@)7,@`$]D9&%L:FYO`$9A;&ML86YD<VMI(&]T;VMI`$9E<G-K:2!O=&]K
M:2``2'5D82!N87!A:V$A`$9A>`!&87AI`$9E8G)U87(`4&_$C75T:71I('-E
M(&MO=`!0;\2-=71I=&D@<V4@:V]T.@!.96MA:B!N86QI=F]V`$YE:V%J('-N
M9<6^;FEH(&UE=&7%OF5V`$UA=')I8V$@<&]L:F$`1FEG;&5T($-!4%1#2$$`
M1FEG;&5T('!I<V%V80!&:63%OFD`1&%T;W1E:V$`Q:!T971J92!$871O=&5K
M.B`E<R!D871O=&5K`,6@=&5T:F4@1&%T;W1E:SH@)7,@9&%T;W1E:P!5<')A
M=FET96QJ(&1A=&]T96L`26UE(&1A=&]T96ME`$EZ8FER82!D871O=&5K92X`
M3F%L;\6^:2!D871O=&5K;P!$;V1A;F$@9&%T;W1E:V$@;FD@<&]D<')T82X`
M1FEL=')I`$9I;G-K80!0<G9A('!O;&]V:6-A`%!R=F$@Q(UE=')T:6YA`%-T
M86QN92!V96QI:V]S=&D`3V)R;FD`365G;&$`)7,@;6%P82!N92!O8G-T86IA
M(`!(<F%N80!.87!O=F5D("A4048I`$1N979I(&YA<&]V961I+B`H3F%P;W9E
M9&$@;&4@;&%H:V\@>F5L;R!D;VQG82D`4W1E('!O>F%B:6QI('9AQ:%E(&=E
M<VQO/P!O8FQI:V4`4W)EQ(UA`%-R9<2-90!3<F7$C64`4W)EQ(UE(#(`5&%B
M;&$@<&]G;W9O<F]V`%!R975S;65R:71E=F4`1G(`1G)A;F-I:F$`1G)A;F-I
M:F$L($MO;&]N:6%L;F$@;65T<F]P;VQA`$9R86YC;W-K82!'=F%J86YA(`!&
M<F%N8V]S:V$@4&]L:6YE>FEJ82``1G)A;F-O<VMI(&IUQ;YN:2!T97)I=&]R
M:6H@`$]D`$]D(`!0;VQN($]P:7,Z`%!O;&YA(&QU;F$`4&]L;F\@:6UE`$=A
M8F]N`$=A;6)I:F$`57-T=F%R:2`E<R!.87-T879I='9E`$=E;F5R:7)A:B!K
M;V1O`$=R=7II:F$`3F5MQ(UI:F$`1V%N80!':6)R86QT87(`1&%N;R!I;64`
M4W!L;\6A;F4@36_%OFYO<W1I`%!O:F1I`$=O;V=L;W9E(&UA<&4`2<6AQ(UI
M('H@1V]O9VQO;0!,97-T=FEC82!S:79I;F4@`$=RQ(UI:F$`1W+%H6MI("A)
M4T\M.#@U.2TW*0!'<F5N;&%N9&EJ80!'<F5N861A`%-K=7!I;G-K82!A9&UI
M;FES=')A8VEJ80!);65N82!3:W5P:6X@;F4@<VUE:F\@8FET:2!P<F%Z;F$`
M075T:%]L9&%P.B!.92!M;W)E;2!D;V1A=&D@<VMU<&EN92`E<RX@4W!O<F_$
MC6EL;R!S=')EQ;YN:6MA.B``4VMU<%]L9&%P.B!.92!M;W)E;2!I>F)R:7-A
M=&D@<VMU<&EN92`E<P!3:W5P7VQD87`Z($YE(&UO<F5M(&YA9&=R861I=&D@
M<VMU<&EN92`E<P!3:W5P:6YE`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`
M1W5E<FYS97D`1&]V;VQJ96YJ82!Z82!G;W-T90!+;FII9V$@9V]S=&]V`$=V
M:6YE:F$`1W9I;F5J82U":7-S86\`1W9A:F%N80!(5$U,`$]V97)J96YE9V$@
M2%144"!.:7-E;2!N8<6A96PN`$AA:71I`$AA<V@@06QG;W)I=&5M`$UE9VQI
M8V$`1VQA=F$`1VQA=F4`2&5A<F0@;W1O:R!I;B!-8T1O;F%L9&]V;R!O=&_$
MC6IE`$UOQ(UN82!N979I:'1A`$AE8G)E:G-K:2`H25-/+3@X-3DM."U)*0!6
M:<6A:6YA`%!O;6_$C0!0;VUOQ(UL;FEK`%!O;&]B;&$`5'5K86H@:F4@>F'$
MC65T96L@9&%T;W1E:V4Z`%9I<V]K;P!$;VUO=@!6871I:V%N`$1O;6'$C6D@
M;F%S;&]V`$EM96YI:P!$;VUAQ(UI('1E;&5F;VX`2&]N9'5R87,`2&]N9R!+
M;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!.979E;&IA=F5N("5S(%A-3"!P;V1A
M=&5K(&YA:F1E;B!V('-P;W)OQ(UI;'4@)7,`2&]R9&4O2V]L86(Z($YO8F5N
M;R!S<&]R;\2-:6QO('-E(&YE('5J96UA(',@<')E9&UE=&]M("5S`$AO<F1E
M+TMO;&%B.B!6('-P;W)OQ(UI;'4@)7,@;FD@;F%J9&5N(&YO8F5N('!R961M
M970@=&EP82`E<P!(;W)D92]+;VQA8CH@57-P9<6A;F\@;V1S=')A;FIE;B`E
M<R`B)7,B`$AO<F1E+TMO;&%B.B!);G1E9W)A8VEJ<VMA(&YA<')A=F$@>F%H
M=&5V82`G9&]M>&UL)R!02%`@96MS=&5N>FEJ;P!(;W)D92]+;VQA8CH@3F4@
M;6]R92!U<W1V87)I=&D@;F]V;R!834P@9')E=F\@>F$@)7,`2&]R9&4O2V]L
M86(Z($YE(&UO<F5M(&]D<W1R86YI=&D@)7,@(B5S(CH@)7,`2&]R9&4O2V]L
M86(Z($YE(&UO<F5M('!O:7IV961E=&D@>F$@34E-12!)1"!Z82!D96P@;V0@
M=G)S=&4@)7,`2&]R9&4O2V]L86(Z($YE(&UO<F5M('-I;FAR;VYI>FER871I
M("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!.92!M;W)E;2!S:6YH<F]N:7II
M<F%T:2!D96QE.B`E<P!(;W)D92]+;VQA8CH@3F5Z;F%N82!D96QI=&5V("(E
M<R(`2V]L:6MO('!O;&H@*'-T;VQP8V5V*6IE('1A;3\`5FQAQ;YN;W-T`%9L
M8<6^;F]S=#H@`$AU;6]R:7-T:0!-863%OF%R<VMA`%5S='9A<FIA;FIE($E-
M05`@;F%B:7)A;&YI:V$@;FD@=7-P96QO.B`E<P!"<FES86YJ92!)34%0(&YA
M8FER86QN:6MA(&YI('5S<&5L;SH@)7,`57-T=F%R:F%N:F4@:W9O=&4@24U!
M4"!N86)I<F%L;FEK82P@;FD@=7-P96QO.B`E<P!)4"!.87-L;W8`25`@3F%S
M;&]V(&YI(&YA(')A>G!O;&%G;RX`25`@3F%S;&]V(&YI('8@9&]V;VQJ96YI
M($-)1%(@<VMU<&EN:2X`6F%K;&5N:F5N($E0+@!)<VQA;F1I:F$`4V%M;R!I
M:V]N90!):V]N92!Z82`E<P!):V]N92!Z(&)E<V5D:6QO;0!)9&5N=&EF:6MA
M8VEJ<VMO(&EM93H`)7,@>F$@;V1P<F5T:2!V(&YO=F5M(&]K;G4L(,2-92!N
M:2!P<F%V:6QN;R!P<FEK87IA;F\N`,2-92!V:61I=&4@=&\@<W!O<F_$C6EL
M;R!I;B!S;&G$C6EC92!N92P@<&]M96YI+"!D82!V8<6A(&)R<VMA;&YI:R!N
M92!M;W)E(&]D<')E=&D@<VQIQ(UI8V4L(&MI(&IO(,6^96QI=&4@;F%L;\6^
M:71I+@!$;V1A:B!S;&EK;P!3;&EK90!6;F]S+"!+;W)A:R`E9`!6;F7%H65N
M;R!P;VQJ93H@)7,`5FYEQ:%E;F$@<&]L:F$Z`%!O<W)E9&]V86X@;F5P<F%V
M:6QE;B!U:V%Z+@!.97!R879I;&YO('5P;W)A8FYIQ:%K;R!I;64@:6XO86QI
M(&=E<VQO+@!.97!R879I;&YO('5P;W)A8FYIQ:%K;R!I;64@86QI(&%L=&5R
M;F%T:79E;B!N87-L;W8N(%!O<VMU<VET92!Z;F]V82!A;&D@:V]N=&%K=&ER
M86IT92!V8<6A96=A('-K<F)N:6MA+"#$C64@<&]T<F5B=6IE=&4@;F%D86QJ
M;FIO('!O;6_$C2X`26YD:6IA`%!O<V%M97IN:2!5<&]R86)N:6MI(`!);F1O
M;F5Z:6IA`$EN9F]R;6%C:6IE(&\@<V5S=&%N:W4`26YF;W)M86-I:F4@;FES
M;R!V9<2-(&1O<V5G;&II=F4N`%9S=&%V:2!A;'1E<FYA=&EV96X@=GIO<F5C
M`%9S=&%V:71E(&5L96MT<F]N<VMI(&YA<VQO=B!N82!K871E<F5G82!L86AK
M;R!P<F5J;65T92!N;W9O(&=E<VQO.@!6<W1A=FET92!S<&]R;\2-:6QO`%9P
M:<6A:71E('IA:'1E=F%N(&]D9V]V;W(@;F$@=F%R;F]S=&YO('9P<F'%H6%N
M:F4Z`%-T86YJ92!N82!R8<2-=6YU(&YE('IA9&]S='5J92!Z82!P;\6A:6QJ
M86YJ92!N82#%OF5L:F5N('-P:7-E:RX`4W1A;FIE(&YA(')AQ(UU;G4@;F4@
M>F%D;W-T=6IE+@!#96QO(,6A=&5V:6QO`%-E>FYA;2!C96QI:"#%H71E=FEL
M`$YE=F5L:F%V96X@541(+B`H57-E<B!$871A($AE861E<BDN`$YE=F5L:F%V
M96X@6DE0('!O9&%T96LN(`!.979E;&IA=FYA(&%P;&EK86-I:F$N`$YE=F5L
M:F%V;FD@240@<&%K970N`$YE=F5L:F%V;FD@<&]D871K:2!S;R!B:6QI(&]D
M<&]S;&%N:2X`3F5V96QJ879E;B!N87-L;W8@;F%S;&]V;FEK82X`($YE=F5L
M:F%V;F$@;V)L:6MA(&1A=&]T96ME(`!.979E;&IA=F5N(&QI8V5NQ(UN:2!K
M;&IUQ(TN`$]D<F5J96X@;F5V96QJ879E;B!K<F%J+@!.979E;&IA=F5N('1I
M<%]M<V<N`$YE=F5L:F%V96X@86QI(&UA;FIK86IOQ(T@87!I7VED+@!.979E
M;&IA=FYI(&%L:2!M86YJ:V%J;\2-:2!P87)A;65T<FDN`$YE=F5L:F%V;F\@
M9&]V;VQJ96YJ92!S=&%RQ:%E=BX`3F5V96QJ879E;B!P87)T;F5R:F5V(&ED
M+@!.979E;&IA=FYA(&MO9&$@87)T:6ML82X`3F5V96QJ879E;B!P<F]T;VMO
M;"X`3F5V96QJ879E;B!N87-L;W9N:6LZ("(E<R(`($YE=F5L:F%V96X@;V)J
M96MT(&1E;&IE;FIA(`!.979E;&IA=F5N(&EZ=F]R;FD@;F%S;&]V+@`@3F5V
M96QJ879E;B!U;FEK;V0@<&]D871E:P!);G9E;G1U<F$O<&]P:7,`3V)R;FD@
M:7IB;W(`27)A;BP@27-L86US:V$@4F5P=6)L:6MA`$ER86L`27)S:V$`4&]S
M86UE>FYE(&YE=FEH=&4`27IR865L`$EZ9&%J871E;&H`271A;&EJ80!*86UA
M:FMA`$IA;G5A<@!*87!O;G-K80!*87!O;G-K:2`H25-/+3(P,C(M2E`I`$IE
M<G-E>0!*;W)D86YI:F$`2G5L:6H`2G5N:6H`2V%Z86AS=&%N`$]B9'+%OFEM
M(&EZ=FER;FEK/P!+96YI:F$`2V5R8F5R;W,@<W1R9<6^;FEK('IA=G)N:6P@
M;W9E<FET978N`$ME<FYE;"!N;W9I;F-I`%5S='9A<FD@2VQJ=<2-(`!/9'1I
M<R!+;&IUQ(UA`$1O;,6^:6YA($ML:G7$C6$`5&EP($ML:G7$C6$@`%5P;W)A
M8F$@2VQJ=<2-82``2VQJ=<2-(,6^92!O8G-T86IA(&YA(&IA=FYE;2!K;&IU
MQ(UN96T@<W1R9<6^;FEK=2X`3W1R;V-I`$MI<FEB871I(`!+;W)E:F$L($1E
M;6]K<F%T:<2-;F$@;&IU9'-K82!R97!U8FQI:V$@`$MO<F5J82P@4F5P=6)L
M:6MA(`!+;W)E:G-K:2`H155#+4M2*0!+=79A:G0@`$MI<F=I>FEJ82``2F5Z
M:6L`3&%O<R!L:G5D<VMA(&1E;6]K<F%T:<2-;F$@<F5P=6)L:6MA`%IA9&YJ
M82!P;VQO=FEC80!:861N:F$@<W!R96UE;6)A(&=E<VQA.B``6F%D;FIA(,2-
M971R=&EN80!:861N:F4@8<6^=7)I<F%N:F4Z`%IA9&YJ82!P<FEJ879A.B`E
M<R``6F%D;FIA('!R:6IA=F$Z("5S(&EZ("5S`%IA9&YJ82!P<FEJ879A.B!.
M:6MO;&D`3&%T=FEJ82``4')A=F\`3&EB86YO;@!,979O(&]G;&%V;&IE`%9R
M961N;W-T:2!N82!L979I`$QE<V]T;P!2879E;@!,:6)E<FEJ80!,:6)I:F$@
M`$QI96-H=&5N<W1E:6X@`%)A:&5L('!RQ:%E8P!286AE;"!D9<6^`%IG;V1A
M:B!R86AE;"!D9<6^`%!O>FYO(')A:&5L(&1EQ;X`4&QO:&$`4&QO:&$@>B!G
M<FUE;FIE;0!286AE;"!S;F5G`%-N9<6^;FD@;65T9<6^`%!O=F5Z879A`%!O
M=F7%OFD@92UN87-L;W8@<R!O8G)A>F-E;2!Z82!S97-T879O(&YO=F4@<&_%
MH71O(&UE('!R:6MA>F]V86YJ96T`4&]V97IA=F4`3&EN=7@@<&G%H6MO=&5K
M`%-E>FYA;2`M('5P;W)A8FYI:R!L86AK;R!V:61I(&UA<&\`4V5Z;F%M('!O
M9&%T:V]V;FEH(&)A>@!397IN86T@5&5M(%!O;6_$C6D@`%-E>FYA;2!T86)E
M;``@4V5Z;F%M($%R:&EV82``4V5Z;F%M(%!O;6_$C6D@`%-E>FYA;2!)9&5N
M=&ET970@`%-E>FYA;2!,87-T;FEK;W8@`%-E>FYA;2!0;\6A=&4@`%-E>FYA
M;2!0<FEJ878@`%-E>FYA;2!/9&IA=B``4W!I<V5K('-E>FYA;6$@<V5J(&YI
M('5S<&5L.B`E<RX`4V5Z;F%M('5P;W)A8FYI:V]V(&YI(&UO9V_$C64Z("5S
M`%-E>FYA;2!U<&]R86)N:6MO=B!N:2!M;V=OQ(TN`$QI=&5R871U<F$`3&ET
M=F$@`$YA;&%G86TN+BX`3&]K86QN:2#$C6%S.@!,;VMA;&EZ86-I:F$`365S
M=&\`4')I:F%V80!/9&IA=F$@<R!P<F5D:&]D;F4@<WEN8R!S96IE(`!/9&IA
M=F$`4')I:F%V80!0<FEJ879A(&YA(&]P<F%V:6QA`%!R:6IA=F$@;FD@=7-P
M96QA+B!5<&]R86)N:<6A:V\@:6UE(&%L:2!G97-L;R!N97!R879I;&YO('9N
M9<6A96YO`%!R:6IA=F$@;FD@=7-P96QA`$1O;&=O($)E<V5D:6QO`$QJ=6)E
M>F5N`$YI>F5K`$QU:W-E;6)U<F<`34T`4W!O<F_$C6EL;R!D;F5V80!-4RU4
M3D5&(%!R:7!O;FMA(&YI('9S96)O=F%L82!P;V1A=&MO=BX`35-'`$UA8V%U
M`$UA:V5D;VYI:F$L(&9O<FUA;&YA($IU9V]S;&]V86YS:V$@<F5P=6)L:6MA
M`$UA9&%G87-K87(`Q(UA<F]B96X`16QE:W1R;VYS:VD@;F%S;&]V`$%D;6EN
M:7-T<F%T;W(@<&_%H71E`$UA;&%V:0!-86QE>FEJ80!-86QD:79I`$UA;&D`
M36%L=&$`57)E9&ET92!S97IN86T@:V%T96=O<FEJ(',@:V%T97)I;6D@8F]S
M=&4@;WIN8<2-:6QI('!O<W1A=FME(&EN('!R:7!A9&%J;\2-92!B87)V92!Z
M82!T92!K871E9V]R:6IE+@!:96UL:F5V:60@36%P,C0`6F5M;&IE=FED($UA
M<%%R97-T`%-H<F%N:F5N92!P;W9E>F%V90!-87)E8P!/>FYAQ(UI('H@>F%S
M=&%V:6-A;6D@5FED96YO+TYE=FED96YO`$]Z;F'$C6D@>B!O<W1A;&EM:2!Z
M87-T879I8V%M:2AN<'(N(%!O;65M8FYO+T]D9V]V;W)J96YO*0!-87)S:&%L
M;&]V;R!O=&_$C6IE`$UA<G1I;FEQ=64`56IE;6%N:F4@<&]L:@!-879R971A
M;FEJ80!-879R:6-I=7,`3F5J=F7$C2!D;W9O;&IE;FD@>FYE<V5K`$UA:W-I
M;6%L;FD@9&5L:2!S<&]R;\2-:6QA('!R96MO<F'$C65N:2X`36%K<VEM86QN
M82!T96UP97)A='5R82!Z861N:FEH(#(T('5R.@!-86MS:6UA;&YA('1E;7!E
M<F%T=7)A('IA9&YJ:6@@-B!U<CH`36%K<VEM86QN;R#%H71E=FEL;R!B;&]K
M;W8@<&]R=&%L80!-86MS:6UA;&YA(&1O;,6^:6YA`$UA:@!-87EO='1E`%ID
M<F%V:6QO("A-961I8VEN82D`Q(UL86YI`%1I<"!M96YI:F$Z`%-P;W)OQ(UI
M;&\`4W!O<F_$C6EL;R!J92!B:6QO('5S<&7%H6YO('!R979E<FIE;F\L('1O
M9&$@<&]D<&ES;FEK;W9E9V$@<&]T<F1I;&$@;FD@8FEL;R!M;V=OQ(UE('!R
M979E<FET:2X`4W!O<F_$C6EL;R!J92!P;W1E:VQO+@!4:7`@4W!O<F_$C6EL
M80!-971A<B!V<F5M90!-971A<B!B;&]K(&YI(&YA(')A>G!O;&%G;RX`4&]D
M<F]B;F]S=&D@<V\@8FEL92!P<FEJ879L:F5N92!Z82!U<')A=FQJ86QC82X`
M365T87)$0B!N:2!P;W9E>F%N+@!0;W-T;W!E:P`G)7,G('!O<W1O<&5K(&YI
M(&1O;&_$C65N+@!0;W-T;W!E:R!N:2!D;VQOQ(UE;BX@4&]S=&]P96L@8V5L
M:6-E.B`E<P!-971R:<2-;FD`365H:6MA`$UI:W)O;F5Z:6IA+"!&961E<F%T
M:79N82!D<L6^879A`%1I<"!D871O=&5K90!-:6YI;6%L;F$@=&5M<&5R871U
M<F$@>F%D;FII:"`R-"!U<CH`36EN:6UA;&YA('1E;7!E<F%T=7)A('IA9&YJ
M:6@@-B!U<CH`36EN:6UA;&YA('-T87)O<W0@9V5S;&$@Q:%E(&YI('!O=&5K
M;&$`3V=L961A;&\`36YO9V]S=')A;G-K80!0;V=R9<6A86X@4$5!4B!P86ME
M="P@2%144"!Z86AT979A;BX`4&]G<F7%H6%N;R!)1"!S<&]R;\2-:6QO+@!0
M;V=R9<6A86YO('-P;W)OQ(UI;&\@;R!Z86AT979A;F5M(%!%05(@<&%K971U
M+@!0;V=R9<6A86YA($E$('-E:F$N`%!O`$UO8FEL;F$@<&_%H71A`%IM97)N
M;P!$871U;2!S<')E;65M8F4`36]D=6QI`$UO;&1A=FEJ82P@<F5P=6)L:6MA
M`$UO;F%K;P!-;VYG;VQI:F$`365S96,@:6X@;&5T;P!-97-EQ(UN;P!-;VYT
M<V5R<F%T`$QU;FEN92!M96YE`%8@=G)S=&D@)60@:F4@;F%J9&5N:6@@=F7$
MC2!P;VQJ(&]D('!R961V:61E;FEH("5D+@!-87)O:V\`4')E=&7%OFYO(&IA
M<VYO`%!R971EQ;YN;R!O8FQAQ(UN;P!0<F5T9<6^;F\@;V)L8<2-;F\@:6X@
M=F5T<F]V;F\`4')E=&7%OFYO('-O;L2-;F\`4&]M86MN:2!S92!D;VP`4&]M
M86MN:2!S92!V(&QE=F\`4&]M86MN:2!S92!V(&1E<VYO`%!O;6%K;FD@<V4@
M9V]R`%!O;6%K;FD@<V4@9&]L`%!O;6%K;FD@<V4@9V]R`$UO>F%M8FEK`%9E
MQ(T@;FEV;VIN:2!P861A:F_$C6D@<W!I<VMI`$UU;'1I;6%P(%5+('IE;6QJ
M979I9"X`36YO9V]K<F%T96X@:7IB;W(`36]J(')AQ(UU;@!0;V1A=&MI(&UO
M:F5G82!R8<2-=6YA`$UO:B!P;W)T86P`3V)L:6MA(&UO:F4@<')V92!S=')A
M;FD`36IA;FUA<@!.92P@<V4@;F4@<W1R:6YJ86T`26UE`$YA;6EB:6IA`$YA
M=7)U`$YE<&%L`$YI>F]Z96US:V$`3FEZ;WIE;7-K:2!!;G1I;&D`3F5T<V-A
M<&4@;W-N;W9N:2!54DP`($YE='-C87!E($-!(%523"!Z82!P<F5K;&EC`$YA
M<VQO=B!.971S8V%P92!C97)T:69I:V%T80`@3F5T<V-A<&4@;V)N;W9I='9E
M;FD@55),`"!.971S8V%P92!54DP@>F$@<')E:VQI8P!.971S8V%P92!34TP@
M:6UE('-T<F7%OFYI:V$`3F5T<V-A<&4@=7)A9&YI(&MO;65N=&%R`%1I<"!.
M971S8V%P92!C97)T:69I:V%T80!/;7)EQ;YJ90!.:6MO;&D`3F]V82!+86QE
M9&]N:6IA`$YO=F$@:V%T96=O<FEJ80!.;W9A($QU;F$`3F]V;R!U<&]R86)N
M:<6A:V\@:6UE`$YO=F$@6F5L86YD:6IA`$YO=F\@9V5S;&\`3F]V;R!G97-L
M;R!B;R!P;W1E:VQO("5X+@!.;W9O(&=E<VQO('-E(&YE('5J96UA+@!.;W9I
M8V4`3F]V:<2-87)S:V$@<VMU<&EN80!.87-L961N:FD`3F%S;&5D;FIE(#0@
M<W1O<&YJ90!.87-L961N:F$@;6_%OFYO<W0`3F%S;&5D;FII/@!.:6MA<F%G
M=F$`3FEG97(`3FEG97)I:F$`3FEG97(`3FEU90!.;V)E9&5N`$YI(&1O<W1O
M<&YI:"!P;V1A=&MO=B!O(&MO;F9I9W5R86-I:FD@9&$@8FD@<&]K87IA;"!R
M87IL:6ME+@!3=')A=&5G:6IA('IA(&EZ9&5L879O($E33R!S;&EK+"!N:2!D
M;W-T;W!N82X`3FD@<&%K971N92!P<F5D;&]G90!.82#%OF5L96YE;2!M97-T
M(&)E;&7%OFMA(&YE(&]B<W1A:F$N`%IA($U#04P@;W9E<FET978@;FD@:V]L
M961A<G-K96=A(&EM96YA`&YI('-P<F5M96YJ96YO`$YA('1E:B!S=&]P;FII
M(&YE(&1O9&%J86UO(&]T<F_%H6MI:"!D;W9O;&IE;FHN`%IA("5S(&YI('-P
M96-I9FEC:7)A;FEH(&MO;F9I9W5R86-I:G-K:6@@:6YF;W)M86-I:BX`6F$@
M1E10(%9&4R!N:2!P;W-E8FYI:"!I;F9O<FUA8VEJ+@`@6F$@4U%,(%9&4R!N
M:2!P;W-E8FYI:"!I;F9O<FUA8VEJ+@`@6F$@9&%T;W1E:V\M4U%,(%9&4R!N
M:2!P;W-E8FYI:"!I;F9O<FUA8VEJ+@!.:2!S=&%N:F$@;F$@<F'$C75N=2X`
M3FD@9&5S=&EN86-I:F4`3FD@;F%L;\6^96YI:"!D871O=&5K+@!.92!N86ID
M96T@:6MO;BX`365S=&\@;FD@;F%S=&%V;&IE;F\N`$UE<W1O(&YI(&YA<W1A
M=FQJ96YO+@!.;V)E;F\@<W!O<F_$C6EL;R!D;W-T879L:F5N;RX`3FD@<W!E
M8VEF:6-I<F%N;R!N;V)E;F\@:6UE+@!.:2!S<&5C:69I8VER86YO(&YO8F5N
M;R#%H71E=FEL;RX`3F]B96YI:"!O9F5N>FEV;FEH('-R9<2-+@!0;W0@9&\@
M8FEN87)N92!D871O=&5K92!/<&5N4U-,(&YI(&)I;&$@;F%S=&%V;&IE;F$N
M($]P96Y34TP@8FEN87)N82!D871O=&5K82!J92!P;W1R96)N82!Z82!D96QO
M(',@4$M#4R`Q,B!P;V1A=&MI+@!.92!S<')E:F5M86UO('IAQ(UA<VYI:"!P
M<FEJ878`2W9O=&$@;FD@;F%S=&%V;&IE;F$O9&]L;\2-96YA+@!.:2!S<&5C
M:69I8VER86YO(&QOQ(UI;&\N`$YI('1A:V4@9&%T;W1E:V4`3F4@;F%J9&5M
M('IAQ(UA<VYE(&UA<&4@>F$@<')E9'!O;6YI;&YI:RX`3F]B96YO('5P;W)A
M8FYIQ:%K;R!I;64@:6XO86QI(&=E<VQO(&YI(&)I;&\@<&]S;&%N;RX`4&]V
M<F%T;FEH('9E;&IA=FYI:"!834P@<&]D871K;W8@;FD`0G)E>B!V<F5D;F]S
M=&D`5B!O<FEG:6YA;&YI(&MO;F9I9W5R86-I:FD@;F4@;F%J9&5M(&YO8F5N
M92!R87IL:<2-:6-E+B!/8FYO=FET:2!K;VYF:6=U<F%C:6IO+@!6('9AQ:%I
M(&MO;F9I9W5R86-I:FD@;F4@;F%J9&5M(&YO8F5N92!R87IL:<2-:6-E+B!/
M8FYO=FET92!K;VYF:6=U<F%C:6IO+@!.;V)E9&5N`$YO<F1I:G-K:2`H25-/
M+3@X-3DM,3``3F]R9F]LQ:%K:2!O=&]K:0!3979E<FYA('!O;&]B;&$`4V5V
M97)N:2!-87)I86YS:VD@;W1O:VD`3F]R=F7%H6MA`$YE(&MA<VYE:F4`3F4@
M<')E:@!.:2!I;65N:6L`3FD@:7IV961E;F\N`$YE('!O9'!I<F%M`%IA<&ES
M:VD`3FD@=G!I<V%N:6@@8F5S960@>F$@:7-K86YJ92P@=G)N:71E('-E(&YA
M>F%J+@!.;W9E;6)E<@#%H'1E=FEL;P#%H'1E=FEL;R!Z;F%K;W8`Q:!T979I
M;&\@<W1O;'!C978`Q:!T979I;&\@=G)S=&EC`$YI('-P96-I9FEC:7)A;FEH
M(,6A=&5V:6QK('IA(&'%OG5R:7)A;FIE(&EN(&1I<W1R:6)U8VEJ<VMI('-E
M>FYA;2X`6F%D979A`%5S='9A<FIA;&5C('!R961M971O=@!/<VUIQ:%K:0!/
M:W1O8F5R`%!I<V%R;F$`4W1A<F\@:6X@;F]V;R!G97-L;R!M;W)A=&$@8FET
M:2!R87IL:<2-;F$N`%-T87)O($=E<VQO`%-T87)O(&=E<VQO(&YI('!R879I
M;&YO+@!/;6%N`$UA<&4@=B!S:W5P;FD@=7!O<F%B:2!P;V1P:7)A('-A;6\@
M24U!4"!S=')EQ;YN:6LN`%-A;6\@;F5S<F%M;F4@:7IJ879E`$1O=F]L:F5N
M(&IE(&QE(&5N(&5L96MT<F]N<VMI(&YA<VQO=BX`3&4@;&%S=&YI:R!A;&D@
M=7!R879N:6L@<VES=&5M82!L86AK;R!Z86UE;FIA(&QA<W1N:<6A='9O(&%L
M:2!L87-T;FEK;W9O(&1O=F]L:F5N:F4@>F$@9&5L9<6^+@!/9'!R:2!V(&YO
M=F5M(&]K;G4`3V1P<G1A4U-,(&YA<&%K83H@3F4@;6]R96T@<&]V>F5T:2!D
M871U;6$@:7H@;WIN8<2-96YE9V$@4R]-24T@9&5L82X`3W!E<F%T:79N:2!S
M:7-T96T`36_%OFYO<W1I`$UOQ;YN;W-T:2!Z82`E<P!/<F=A;FEZ86-I:F$`
M3W)G86YI>F%C:6IS:V$@96YO=&$`3W)G86YI>F%C:6IA`$EZ=FER;F4@Q:%A
M8FQO;F4@87!L:6MA8VEJ`$EZ=FER;FD@Q:%A8FQO;F4@=B`E<SH`1')U9V\`
M3W-T86QE(&EN9F]R;6%C:6IE`$1O=F]L:F5N:F$@;&%S=&YI:V$`3W9E<FIE
M;FIE(&YI('5S<&5L;P!014%2.CH@9V]N:6QN:6L@4&_%H71E`$1I9VET86QE
M;B!P;V1P:7,@4$=0`$MO9&ER86YI(%!'4"!P;V1A=&MI`$IA=FYI(&ML:G5E
M(%!'4`!0;V1P:7-A;FDO:V]D:7)A;FD@4$=0('!O9&%T:VD`4$A0(&MO9&$`
M4$A0(&QU<&EN80!0;W!O;&1N92!R86AE;"!D9<6^`%!O<&]L9&YE(&1EQ;X`
M4&]P;VQD;F4@;F%L:79I`%!O<&]L9&YE('-N96<N`%!O<&]L9&YE('-N9<6^
M;FD@;65T9<6^:0!0;W!O;&1N92!S;VYC90!0;W!O;&1N92!N979I:'1E`%!O
M9W)EQ:%A;F$@4$]325@@96MS=&5N>FEJ80!02%`@;'5P:6YA`%!A:VES=&%N
M`%!A;&%U`%!A;&5S=&EN:VD@;VMU<&ER86YI('1E<FET;W)I:@!086YA;6$`
M4&%P=6$@3F]V82!'=FEN96IA`%!A<F%G=F%J`$1E;&YO(&]B;&'$C6YO`$=E
M<VQO`$=E<VQO('5S<&7%H6YO('-P<F5M96YJ96YO`$YE<')A=FEL;F\@9V5S
M;&\`6F$@4D%$2553(&]V97)I=&5V(&IE('IA:'1E=F%N;R!G97-L;RX`1V5S
M;&\@:6X@<&]T<F1I=&5V`$=E<VQO.@!'97-L;SH@`$=E<VQO('-E(&UO<F$@
M=6IE;6%T:2X`4')I;&5P:0!.97!O=')J96YE('!R:6IA=F4`3&IU9&IE`$EZ
M=G+%H6D@=GID<L6^979A;&YA(&1E;&$`27IV<L6A:6T@=GID<L6^979A;&YA
M(&1E;&$@;V(@<')I:F%V:3\`1&]V;VQJ96YJ90`B)7,B(&1O=F]L:F5N:F4@
M;FD@:7IB<FES86YO+@!$;W9O;&IE;FIE(&IE('IA=G)N:F5N;RX`1&]V;VQJ
M96YJ80!5<')A=FYIQ:%K82!D;W9O;&IE;FIA`$]S96)N92!I;F9O<FUA8VEJ
M90!097)U`$QJ=6)L:F5NQ(UK:0!&:6QI<&EN:0!496QE9F]N`$9O=&]G<F%F
M:6IE`%!I=&-A:7)N`%!R;W-I;6\L(&1A('9N97-E=&4@;65S96,@:6X@;&5T
M;RX`4')O<VEM;RP@9&$@=FYE<V5T92!I;64@;F]V92!K871E9V]R:6IE.@!0
M<F]S:6UO+"!D82!V;F5S971E('9E;&IA=F5N($E0(&YA<VQO=BX`4')O<VEM
M;RP@9&$@=FYE<V5T92!V96QJ879E;B!D871U;3H@<')E=F5R:71E(,6A=&5V
M:6QO(&1N:2!V(&UE<V5C=2X`4')O<VEM;RP@9&$@=FYE<V5T92!P<F%V:6QE
M;B#$C6%S+@!0<F]S:6UO+"!D82!P<FEP<F%V:71E('!O=GIE=&5K('1EQ;YA
M=BX`4')O<VEM;RP@9&$@<VD@:7IB97)E=&4@=7!O<F%B;FG%H6MO(&EM92!I
M;B!G97-L;RX`4')O<VEM;RP@<')E8F5R:71E('-L961EQ(UE(&)E<V5D:6QO
M+B#$C64@Q;YE;&ET92!U<&]R86)L:F%T:2!T82!S:7-T96TL('-E(&UO<F%T
M92!S=')I;FIA=&D@<R!P;V=O:FDN`%!R;W-I;2P@=FYE<VET92!I;64@;F]V
M92!K871E9V]R:6IE.@!0;VQJ<VMA`%!O;&ET:6MA`$%N:V5T90!0;W)T=6=A
M;'-K80!/9&1A:B!V('1O(&UA<&\@*&YI('IA:'1E=F%N;R!O9"!)34%0*0!0
M861A=FEN92!V('IA9&YJ:6@@)7,@=7)A:#H`4&%D879I;F4\8G(@+SYC:&%N
M8V4`(%!R969S7VQD87`Z('IA:'1E=F%N96=A($Q$05`@<F%Z=&5G82!N92!N
M86ID96TN`%1L86L`5&QA:R!N82!M;W)S:VD@=FG%H6EN:3H`5&QA:SH@`%!R
M961O9VQE9`!0<F5JQ:%N:F4@;6_%OFYO<W1I`%IA<V5B96X@:VQJ=<2-`%!R
M;V)L96T`6B!O<&ES;VT@<V\@=&7%OF%V92XN`%!R;VIE:W1I`%1A:V]JQ:%N
M:F4@8F5S961I;&\`2F%V;FD@:VQJ=<2-`$%L9V]R:71E;2!J879N96=A(&ML
M:G7$C6$`26YF;W)M86-I:F4@:F%V;F5G82!K;&IUQ(UA`$IA=FYI+WIA<V5B
M;FD@<&%R(&ML:G7$C65V(&YI(&)I;"!U<W!EQ:%N;R!G96YE<FER86XN`%!O
M<G1O<FEK;P!0<F7$C6ES=&D@<W!O<F_$C6EL80!+871A<@!0;VEZ=F5D8F$`
M2W9O=&$`4E-!(&IA=FYI(&ML:G7$C2`H)60@8FET;W8I`$EZ8F5R:71E(')A
M9&EO`$1EQ;X`1&7%OB!Z:G5T<F%J`$1EQ;X@<&]P;VQD;F4`3F%L:78`1&7%
MOB!I;B!S;F5G`$1EQ;X@=B!S;F5G`%-R9<2-80!287IM97)J90!"97)I`$)E
M<FD@<W!O<F_$C6EL;P!3=&4@<')E<')IQ(UA;FDL(&1A(,6^96QI=&4@>F)R
M:7-A=&D@)7,_($EZ8G)I<V$@;FD@;6]G;\2-92!P<F5K;&EC871I+@!3=&4@
M<')E<')IQ(UA;FDL(&1A(,6^96QI=&4@>F)R:7-A=&D@=7!O<F%B;FEK;W9E
M('!O9&%T:V4@>F$@=7!O<F%B;FEK825S/R!)>F)R:7-A(&YI(&UO9V_$C64@
M<')E:VQI8V%T:2X`3W-V9<6^:0!/<W9EQ;YI(&1I;F%M:<2-;FD@;65N:2!E
M;&5M96YT;W8Z`$]S=F7%OFD@<&]R=&%L.@!296=E>`!)<VMA;&YI:R!R87IM
M97)I:@!0;VYO=FYO(&YA;&_%OFD`4')I<&]M8F4`3V1D86QJ96YI('-T<F7%
MOFYI:VD`3V1D86QJ96X@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO
M<F1E*3H`3V1S=')A;FD`3V1S=')A;FD@<W1O;'!E8P!/9'-T<F%N:2!P87(`
M3V1S=')A;FD@<VAR86YJ96YO('-K<FEP=&\@:7H@<W1R9<6^;FEK;W9E('IA
MQ(UA<VYE(&UA<&4`3V1S=')A;FD@=7!O<F%B;FEK80!/9'-T<F%N:2!U<&]R
M86)N:6MA.B`E<R``6F%H=&5V:2!N92!M;W)E;2!U9V]D:71I+B!6<FYJ96YA
M(&IE(&YA<&'$C6YA(&MO9&$Z(`!.92!N86ID96T@>F%H=&5V86YE9V$@<V5R
M=FES82X`6F%H=&5V86YI("(E<R(@;FD@<&]D<F]B;F\@;V)L:6MO=F%N('8@
M)7,@:V]N9FEG=7)A8VEJ:2X`6F%H=&5V86YI("(E<R(@;FD@<&]D<F]B;F\@
M;V)L:6MO=F%N('8@5DA3(&MO;F9I9W5R86-I:FDN`%IA:'1E=F%N:2`G)7,G
M(&YI('!O9')O8FYO(&]B;&EK;W9A;BX`6F%H=&5V86YA(&1A=&]T96MA`%!O
M;F%S=&%V:0!0;VYA<W1A=FD@9V5S;&\`4&]N87-T879I=&4@=F'%H64@9V5S
M;&\`3V)N;W9I=&4@>F%D;FIO('!O:7IV961B;P!:861E=&MI`%9R;FD@<V4@
M;F$@36_%OFYO<W1I`%!O;F]V;F\@=G!IQ:%I=&4@;F]V;R!G97-L;P!0;VYO
M=FYO('ID<G7%OFD`4&]V<FYI(&MO;F9I9W5R86-I:F\`5G)N:2!S92!N82!M
M;\6^;F]S=&D@=7)E:F5V86QN:6MA(&)E<V5D:6QA`$5N:6=M90!$97-N;R!O
M9VQA=FIE`$1E<VYE('9R961N;W-T:0!&=6YK8VEJ80!2;VUU;FEJ80!/8G)N
M:2!Z82`Q.#``3V)R;FD@;F$@;&5V;P!/8G)N:2!N82!D97-N;P!:8<6^96YI
M`%)U<VEJ80!2=6%N9&$`(%,O34E-12!K<FEP=&]G<F%F<VMI('!O9'!I<P!3
M+TU)344@:V]D:7)A;F\@<W!O<F_$C6EL;P!305-,($]V97)J86YJ92!N:2!U
M<W!E;&\`4TU3('-P;W)OQ(UI;&\`4U%,(&QU<&EN80!344P@<W1A=F5K('IA
M('!O:7IV961B;R!V<F5D;F]S=&D`4U-(`%534$5(`%-13"!L=7!I;F$`4V$`
M4W9E=&$@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<R``4V%I;G0@3'5C
M:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B``4V%I;G0@5FEN8V5N="!I
M;B!'<F5N861I;F4`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!I;B!0<FEN
M8VEP90!3871E;&ET<VMI(&]S:W)B;W9A;&5C`%-A=61S:V$@07)A8FEJ80!3
M:')A;FD`4VAR86YI("(E<R(`4VAR86YI("5S(`!3:')A;FD@36_%OFYO<W1I
M`%-H<F%N:71E(&=E;F5R:7)A;F\@:V]N9FEG=7)A8VEJ;R!K;W0@4$A0('-K
M<FEP=&\@;F$@>F'$C6%S;FD@;6%P:2!V8<6A96=A<W1R9<6^;FEK861I<F5C
M=&]R>2X`4VAR86YJ96YA("5S(&MO;F9I9W5R86-I:F$`4VAR86YJ96YA(&YA
M<W1A=FET=F5N92!S:W)I<'1A(&YA9&=R861N:F4@;F$Z("(E<R(N`%)A>F1I
M=FIA;F$@;F5V:6AT82!Z(&=R;65N:F5M`%IN86YO<W0`2<6AQ(UI`$ES:V%L
M;FEK:0!)>F)E<FD@9&%T;W1E:V\`27IB97)I(&1A='5M`$EZ8F5R:2!S:W5P
M:6YO+"!K:2!J;R#%OF5L:<6A(&1O9&%T:2X`27IB97)I(&YO=F5G82!L87-T
M;FEK80!)>F)E<FD@<W1R9<6^;FEK`$EZ8F5R:2!U<&]R86)N:6MA+"!K:2!G
M82#%OF5L:<6A(&1O9&%T:0!)>F)E<FD@=G-E`$EZ8F5R:2!P;W!O;&X@9&%T
M=6T`27IB97)I('!R961M970`3V1K;&IU:V%J('9S90!:;F%K92P@:VD@:FEH
M('!O=')E8G5J971E(&EZ8F5R:71E(&EZ(&]K=FER:F5V('-P;V1A:BX@3F%T
M;R!J:6@@;&%H:V\@:V]P:7)A=&4@:6X@<')I;&5P:71E('8O:7H@8F5S961I
M;&$N`$1O;&_$C6D@:V]NQ(UN:2!D871U;3H`27IB97)I(&]B;&EK;R!D871U
M;6$Z`$EZ8F5R:71E(&ED96YT:71E=&\L(&MA=&5R;R#%OF5L:71E('-P<F5M
M96YI=&DZ`$1O;&_$C6D@:V]NQ(UN;R!U<F\Z`$EZ8F5R:2!O8FQI:V\@=7)E
M.@!)>F)E<FD@9'9E('5J96UA:F_$C6D@<V4@<&]L:FDZ`$EZ8F5R:71E('9A
MQ:%E(&)A<G9N;R!K;VUB:6YA8VEJ;P!)>F)E<FET92!J97II:SH`4&_%H6QJ
M:2!P;W)OQ(UI;&\@;R!N87!A:V%H`%!OQ:%L:FD@4TU3`%-E;F5G86P`4V5N
M>F]R.@!397!R96UB97(`4W)B:6IA(&EN(,2-<FYA(&=O<F$`4V5R:6IS:V$@
MQ:%T979I;&MA`%-T<F7%OFYI:V]V(&1A='5M(&IE(&YA<&'$C65N(&%L:2!N
M:2!N82!R87IP;VQA9V\N`$%D;6EN:7-T<F%C:6IA('-E:F4`240@<V5J92!J
M92!P;W1E:VQA+@!396IE`$YA;65S=&D`3F%S=&%V:2!O<&-I:F\L(&1A('8@
M<')I;65R=2P@9&$@<&]Z86)I=&4@=F'%H64@9V5S;&\L(&QA:&MO('!O;F%S
M=&%V:71E(&QE+71O+@!5<F5D:71E(&]D9&%L:F5N92!S=')EQ;YN:6ME(&YA
M(&MA=&5R92#%OF5L:71E(&1O<W1O<&%T:2!Z('9AQ:%E9V$@<&]R=&%L80!.
M87-T879I=&4@<')I=GIE="!J97II:R!I;B!N87-T879I='9E(&1A='5M80!5
M<F5D:2!Z8<2-971N92!B87)V;F4@<VAE;64L(&%P;&EK86-I:F4L(&]S=F7%
MOFET=F4@<W1R86YI+BXN`$YA;65S=&D`3F%S=&%V:2!S:W)I<'1O('IA(&]S
M=F7%OFET978@:V]T(')A>G!O;&_%OFQJ:79O+@!-;\6^;FEH(&IE('9EQ(T@
M;&]K86-I:B!S('!A<F%M971R;VTZ`%-E:L6A96QI`$YA:W5P;W9A;FIE`$MR
M871E:R!P;W9Z971E:P!.871A=FEM('1I<&MA<G-K92!B;&G%OFYI8V4@;F$@
M<&]V97IA=F4_`%!O:V'%OFD`4&]K8<6^:2!R87IL:6ME(&UE9"!S961A:B!S
M:')A;FIE;F\@:6X@;F%J;F]V96K%H6\@9V5N97)I<F%N;R!K;VYF:6=U<F%C
M:6IO+@!0<FEK8<6^:2!D871U;2!Z861N:F4@<')I:F%V92!P;R!V<W1O<'4_
M`%!R:6MAQ;YI(&]P8VEJ92!Z82!O8F1RQ;YA=&D@;W)I9VEN86P`4&]K8<6^
M:2!T:7-T96=A+"!K:2!S<')E:F5M80!0<FEK8<6^:2!M96YI:G-K;R!V<G-T
M:6-O(&1E;&]V86YJ82!T86)E;&4`4')I:V'%OF5M("5S(&UE;FD@;F$@;&5V
M:2!S=')A;FD_`$1O9&%J(&YA;&%G86YJ90!0;&]H90!::G5T<F%J('!L;VAE
M`%!O<&]L9&YE('!L;VAE`%8@8FQIQ;YI;FD@<&QO:&4`4VMRQ(UI`$YA:G!R
M96H@<VMRQ(UI(&%L:2!P<F5M86MN:2!S;W-E9&YJ92!B96QEQ;YK92X`4VEE
M<G)A($QE;VYE`%!R:6IA=FD@<V4`4&]D<&ES`$%L9V]R:71M:<2-96X@<&]D
M<&ES`%-I;F=A<'5R`%9E;&EK;W-T`%!R97-K;\2-:2!V>F1RQ;YE=F%N:F4`
M4VQO=F'%H6MA`%-L;W9E;FEJ80!3;F5G`%-N9<6^;F$@<&QO:&$`4VYEQ;YN
M92!P;&]H90!::G5T<F%J('-N9<6^;F4@<&QO:&4`4&]P;VQD;F4@<VYEQ;YN
M92!P;&]H90!6:<6A:6YA('-N96=A.@!3;F5G=2!E:W9I=F%L96YT;F$@:V]L
M:<2-:6YA('9O9&4Z`%-A;&]M;VYO=FD@;W1O:VD`4V]M86QI:F$`4&5S;6D@
M:6X@<&]E>FEJ90!6<G-T82!U<F5J96YE9V$@:7IB;W)A`$YA<VQO=B!V:7)A
M`$IUQ;YN82!!9G)I:V$`2G7%OFYO+65V<F]P<VMI("A)4T\M.#@U.2TS*0!*
M=<6^;F$@1V5O<F=I82!I;B!O=&]K:2!*=<6^;FD@4V%N9'=I8V@`2G7%OFYA
M('!O;&]B;&$`4')E<VQE9&YI8V$`Q:!P86YI:F$`3F5Z8<6^96QE;F$@<&_%
MH71A`%9H;V0@>F$@<&]S96)N92!Z;F%K90#%H'!O<G1I`,6@<FD@3&%N:V$`
M4W1A;F1A<F1E;@!:=F5Z9&YE('-T97IE`%IAQ(UE=&YO(&QE=&\`1'+%OF%V
M82!A;&D@<')O=FEN8V$`4W1A='5S`$]B;&EK82!P;VUN:6QN:6MA`$YA<VQO
M=B!U;&EC90!3<&ES96L@8F5S961N:6@@>G9E>@`_/S\_/S\_/S\_9&]M96YA
M(&EZ(&YA<VQO=F$`3F4`3F4@;F%J9&5M('!O9&UA<&4@(B5S(@!:861E=F$`
M4')E9&QOQ;YI`%-P<F5J96QI('-M;R!Z86AT979E:R!Z82!V<&ES("(E<R(N
M($YE(&UO<F5T92!S92!P<FEJ879I=&D@9&]K;&5R('9AQ:%A('IA:'1E=F5K
M(&YE('!O('!O=')J96XN`%5S<&5H`"(E<R(@<V5M('5S<&7%H6YO(&1O9&%L
M(&L@<VES=&5M=2X`)R5S)R!S96T@=7-P9<6A;F\@;V1S=')A;FEL(&EZ('-I
M<W1E;6$N`"(E<R(@<V5M('5S<&7%H6YO(&EZ8G)I<V%L+@`B)7,B('-E;2!U
M<W!EQ:%N;R!O9'-T<F%N:6P@:7H@<VES=&5M82X`57-P9<6A;F\@;V)R;FIE
M;F$@:V]N9FEG=7)A8VEJ82X@Q(UE(,6^96QIQ:$@=FED971I('-P<F5M96UB
M92P@<&]N;W9N;R!N86QOQ;YI+@!5<W!EQ:%N;R!S:')A;FIE;F$@=F%R;F]S
M=&YA(&MO<&EJ82!K;VYF:6=U<F%C:6IE+@!5<W!EQ:%N;R!S:')A;FIE;F$@
M=F%R;F]S=&YA(&MO<&EJ82!K;V9I9W5R86-I:F4@9&%T;W1E:V4@)7,N`"(E
M<R(@:F4@8FEL('5S<&7%H6YO('!O<V]D;V)L:F5N+@`E<R!S96T@=7-P9<6A
M;F\@>F%P:7-A;"X`4W5D86X`4V]NQ(UN:2!V>FAO9`!3;V[$C6YI('IA:&]D
M`%-O;L2-;F\`4V]NQ(UN:2!V>FAO9`!3;V[$C6YI('9Z:&]D+WIA:&]D`%-O
M;L2-;FD@=GIH;V0`4V]NQ(UN:2!Z86AO9`!3;V[$C6YI('IA:&]D.@!0;V1P
M;W)A`%-U<FEN86T`4')I:6UE:P!3=F%L8F%R9"!I;B!*86X@36%Y96X`4W9A
M>FD`Q:!V961S:V$`Q:!V:6-A`$EZ8G)I<V%N('-I;FMR;VYI>F%C:6IS:VD@
M9&YE=FYI:P!3:6YK<F]N:7IA8VEJ80!.87!A:V$@=B!S:6YT86MS:2!I<VMA
M;&YI:"!P;V=O:F5V`%-I<FEJ<VMA(&%R86)S:V$@<F5P=6)L:6MA`$=R;65N
M:F4`3F5V:6AT82!Z(&=R;65N:F5M(&EN('9E=')O;0!.979I:'1A('H@9W)M
M96YJ96T`5%-6(&1A=&]T96MA`$YA<W1A=FET978@=&%B96QE`%1A:G9A;@!4
M86EW86XL(&1EQ;YE;&$@2VET86IS:V4`5&%DQ;YI:VES=&%N`%1A;GIA;FEJ
M82P@6F1R=<6^96YA(')E<'5B;&EK80!/<')A=FEL80!496QE9F]N<VMA(,6A
M=&5V:6QK80!496UP97)A='5R82!V('IA9&YJ:2!U<FDZ`%1E;7!E<F%T=7)A
M`%1E;7!E<F%T=7)A.B``5&5M<&5R871U<F$\8G(@+SXH)7-(:25S+R5S3&\E
M<RD@)F1E9SLE<P`B)7,B('9Z;W)C82!N92!N86ID96TN`%5R96IE=F%L;FEK
M(,6A86)L;VX`0F5S961I;&\`4V%M;R!"97-E9&EL;P!4;P!486IS:V$`3W9E
M<FIE;FIE(&YI('5S<&5L;P!:9V]D;W9I;F$@:F4@:7IK;&]P;&IE;F$N`$AO
M<F1E+TMO;&%B(&EN=&5G<F%C:6IA(&YE('!O9'!I<F$@(B5S(@!0;W-O9&]B
M;&IE;B!D871O=&5K92!N92!M;W)E;2!S:')A;FET:2X`5GID<L6^979A;FIE
M.B!R87IR960@;FD@8FEL('5S<&7%H6YO(&YA;&_%OF5N+@!/:VYO($UOQ;YN
M;W-T:2!J92!B:6QO('IA<')T;RX@6F%K;&IU975J96TN`$%D;6EN:7-T<F%T
M;W(@;6]R82!N86IP<F5J(&YA<W1A=FET:2!S:7-T96T@>F$@<')A=FEC92X`
M2V]N=&%K=&YI($E$(&YI(&)I;"!P;W-R961O=F%N(&%L:2!N:2!B:6P@;F%J
M9&5V('8@8F%Z:2!P;V1A=&MO=BX`4W1I:R!J92!B:6P@=7-P9<6A;F\@9&]D
M86X@:R!V8<6A:6T@;F%S;&]V;VTN($ML:6MN:71E('-P;V1A:B!Z82!O9VQE
M9#H`4&]T<F5B=6IE;2!L;\2-96YO(%!'4"!P;V1P:7-A;F\@8F5L9<6^;FEC
M;RP@9&$@<')E=FER:6T@<&]D<&ES86YO('-P;W)OQ(UI;&\N`$E$('-E>FYA
M;6$@;FD@8FEL('!O<W)E9&]V82!A;&D@;FD@8FEL(&YA:F1E;B!V(&)A>FD@
M<&]D871K;W8N`%1O(&1E:F%N:F4@;FEM82!P;V1P;W)E+@!+;V1I<F%N82!V
M<V5B:6YA('IA:'1E=F$@=F%R;F\@:6YT97)N971N;R!P;W9E>F%V;RX`)7,@
M9&%T;W1E:V$@8FD@;6]R86QA('9S96)O=F%T:2`E<R!N87-T879I='9R+@`E
M<R!D871O=&5K82!B:2!M;W)A;&$@=G-E8F]V871I("5S(&YA<W1A=FET=F4N
M(`!$871O=&5K82!N92!V<V5B=6IE(&YO8F5N:6@@<&]D871K;W8N`%-T<F7%
MOFYI:R`B)7,B(&IE(&)I;"!I>F)R:7-A;BX`365S=&\@1VYU4$<@<')O9W)A
M;6$@;6]R82!B:71I('!O<W)E9&]V86YO(')A>G)E9'4@0W)Y<'1?<&=P+@!3
M<&]R;\2-:6QO('!O<VQA;F\@9&YE("5S('IA("5S('H@;F%S;&]V;VT@(B5S
M(B!J92!B:6P@<')E8G)A;BX*3FD@>F%G;W1O=FEL82!D82!J92!B:6QO(&1E
M:F%N<VMO('!R96)R86YO(&%L:2!R87IU;6QJ96YO+@!);64@>F$@<&]V97IA
M=F\@;F$@<W1R86X@>F$@<V5S=&%V;&IA;FIE('-P;W)OQ(UI;&$N`%1A('9R
M961N;W-T(&UO<F$@8FET:2#%H71E=FEL:V$N`%!O=')E8G5J96T@;W!E;G-S
M;"!M;V1U;"!Z82!(;W)D95]#<GEP=%]S;6EM93HZ(')A>G)E9"X`3F%S=&%V
M:65N92!D871O=&5K92`B)7,B(&YE(&UO<F4@<VAR86YI=&DL(&ME<B!N:F5N
M:2!P;V1A=&MI('!R97-E9V%J;VYA:G9EQ(UJ:2!D;W9O;&IE;B!O8G-E9RX`
M4')O9W)A;6$L(&MI(&]D<&ER82!P;V1A=&ME('1E('9R<W1E("@E<RD@;F4@
M;F%J9&5M('8@<VES=&5M=2X`4F%Z;65J:71E=B!M;W)A(&)I=&D@<V5S=&%V
M;&IE;F$@;&4@:7H@96YE9V$@>FYA:V$N`$QOQ(UI=&5V(&UO<F$@8FET:2!S
M97-T879L:F5N82!L92!I>B!E;F5G82!Z;F%K82X`4W1R9<6^;FEK("(E<R(@
M:F4@8FEL(&EZ8G)I<V%N+@!3=')EQ;YN:6L@(B5S(B!J92!S:')A;FIE;BX`
M27IB<F%N82!V<G-T:6-A("@E9"D@;F4@;V)S=&%J82X`5FYEQ:%E;F\@8F5S
M961I;&\@;F4@=7-T<F5Z82!B97-E9&EL;R!N82!E:W)A;G4N`%!O<V]D;V)L
M:F5N:2!P;V1A=&MI('-O(&)I;&D@:7IG=6)L:F5N:2!P<FD@<')E:L6A;FIE
M;2!K;W)A:W4N`%!O<V]D;V)L:F5N(&1A=&]T96ME(&YE(&UO<F5M('-H<F%N
M:71I+@!W96%T:&5R+F-O;2!N:2!N82!V;VQJ;RX`3F4@;F%J9&5M(&UA<&4@
M;V)L:6L@(B5S(BX`3FD@;6_%OFYO<W1I(&YA(')A>G!O;&%G;RX`1&5L:2!N
M92!M;W)E:F\@8FET:2!P<FEK87IA;FDN`%8@<&]L:G4@:F4@<')E=F7$C2!Z
M;F%K;W8N(%9T:7!K86QI('-T92`E<R!Z;F%K;W8N(%9T:7!K871I(&UO<F%T
M92!M86YJ(&MO="`E<R!Z;F%K;W8N`%!R:<6A;&\@:F4@9&\@;F%P86ME('!R
M:2!D;V1A:F%N:G4@)R5S)R!K('-I<W1E;74Z("5S`%!R:<6A;&\@:F4@9&\@
M;F%P86ME('!R:2!O9'-T<F%N:F%N:G4@)R5S)R!I>B!S:7-T96UA+@!0<FG%
MH6QO(&IE(&1O(&YA<&%K92!P<FD@;V1S=')A;FIA;FIU("<E<R<@:7H@<VES
M=&5M82X`4')IQ:%L;R!J92!D;R!N87!A:V4@<')I('!O<V]D86)L:F%N:G4@
M)R5S)SH@)7,@`%!R:2!N86QA9V%N:G4@9&%T;W1E:V4@:F4@<')IQ:%L;R!D
M;R!N87!A:V4N($YO8F5D96X@)7,@;FD@8FEL(&YA;&_%OF5N+@!0<FD@;F%L
M86=A;FIU(&1A=&]T96ME(&IE('!R:<6A;&\@9&\@;F%P86ME+B`E<R!Z87-E
M9&$@=F7$C2!P<F]S=&]R82P@:V]T(&IE(&1O=F]L:F5N;RX@1&]V;VQJ96YO
M(&IE("@E9"!B>71O=BDN`%!R:2!N86QA9V%N:G4@9&%T;W1E:V4@:F4@<')I
MQ:%L;R!D;R!N87!A:V4N("5S(&IE(&QE(&1E;&YO(&YA;&_%OF5N82X`5B!S
M<&]R;V5I;'4@<V4@:F4@<&]J879I;&$@;F5Z;F%N82!N87!A:V$N`%!R:2!S
M<')E:F5M86YJ=2!K;VYT86MT82!J92!P<FG%H6QO(&1O(&YA<&%K92X`4')I
M('-P<F5J96UA;FIU(&MO;G1A:W1A(&IE('!R:<6A;&\@9&\@;F%P86ME+@!+
M;VYF:6=U<F%C:6IS:VD@;V)R87IE8R!V<V5B=6IE(&YA<&%K;RX@5F5R:F5T
M;F\@<W1E('!O>F%B:6QI(&YA<W1A=FET:2!Z86AT979A;F\@<&]L:F4N`%!R
M:<6A;&\@:F4@9&\@;F%P86ME('!R:2!P<F]C97-I<F%N:G4@:7IB<F%N96=A
M(&EM96YI:V$N(%!R;W-I;6\@<&]S:W5S:71E('IN;W9A;F5K;VQI:V\@:V%S
M;F5J90!0<FD@<W!R96IE;6%N:G4@:V]N=&%K=&$@:F4@<')IQ:%L;R!D;R!N
M87!A:V4N(%!R;W-I;6\@<&]S:W5S:71E('IN;W9A(&MA<VYE:F4N`%!R:2!S
M<')E:F5M86YJ=2!K;VYT86MT82!J92!P<FG%H6QO(&1O(&YA<&%K92X@4')O
M<VEM;R!P;W-K=7-I=&4@:V%S;F5J92X`5F'%H2!B<G-K86QN:6L@;F4@<&]D
M<&ER82!T92!P;W1E>F4N`%1O(&YI('9E;&IA=F5N(%)!4B!A<FAI=BX`5&\@
M;FD@=F5L:F%V;F$@>FEP(&1A=&]T96MA+@#$@N*`FL6@=&5V:6QK82!K87)T
M:6-E(&YI('9E;&IA=FYA+@!';VYI;&YI:R!O;6]G;\2-92!P;\6A:6QJ86YJ
M92!S<&]R;\2-:6P@<')E:V\@;W!E<F%T97)J82!#;&EC:V%T96QL+@!';VYI
M;&YI:R!O;6]G;\2-92!P;\6A:6QJ86YJ92!S<&]R;\2-:6P@<')E:V\@;W!E
M<F%T97)J82!724XN`$=O;FEL;FEK(&]M;V=OQ(UE('!OQ:%I;&IA;FIE('-P
M;W)OQ(UI;"!P<F5K;R!O<&5R871E<FIA('-M<S)E;6%I;"X`1V]N:6QN:6L@
M;VUO9V_$C64@<&_%H6EL:F%N:F4@<W!O<F_$C6EL('!R96MO(&ET86QJ86YS
M:V5G82!O<&5R871E<FIA(%9O9&]A9F]N92Y:82!P;\6A:6QJ86YJ92!M;W)E
M=&4@:6UE=&D@<F5G:7-T<FER86YI(&YA(&AT='`Z+R]W=W<N,3DP+FET`%!O
M=')E8G5J96T@=&\@<&]L:F4N`%1O('!O;&IE(&QA:&MO('9S96)U:F4@;&4@
M8V5L82#%H71E=FEL82X`5&\@<&]L:F4@;&%H:V\@=G-E8G5J92!L92#%H71E
M=FEL82!I;B!S=&]L<&5C+@!4;R!P;VQJ92!L86AK;R!V<V5B=6IE(&QE(,6A
M=&5V:6QA+@!0;VQJ92!M;W)A('9S96)O=F%T:2!S97IN86T@Q:%T979I;"P@
M;&_$C65N:6@@>B!V96II8V\@86QI('!R97-L961K;VTN`%1A('9R961N;W-T
M(&UO<F$@8FET:2#%H71E=FEL:V$N`%1O('!O;&IE(&UO<F$@=G-E8F]V871I
M(&)A<G9N;R!K;V1O('8@4D="($AE>"!F;W)M871U+"!N82!P<FEM97(@)R,Q
M,C,T868G+@!482!O8FQI:V$@:F4@8FEL82#%OF4@;V)D96QA;F$N`%1O(&IE
M("5S+@!4;R!J92!P;V1A=&5K('-K=7!I;G-K82!U<')A=FQJ86YJ92!+;VQA
M8BX@6F$@<')E9VQE9"!T96=A('!O9&%T:V$@<&]T<F5B=6IE=&5P<F5G;&5D
M;&]V86QN:6LL(&MI('!O9'!I<F$@;F'$C6EN('IA<&ES82!+;VQA8B!'<F]U
M<'=A<F4N(%IA('-E>FYA;2!O9&IE;6%L8V5V:VD@=&\@<&]D<&ER86IO(&]B
M:<6AQ(UI=&4@)7,`4W!O<F_$C6EL;R!J92!B:6QO(&YA<&ES86YO('8@:V]D
M;FD@=&%B96QI(&1R=6=AQ(UN92!O9"!V8<6A92`H)7,I+@!4;R#%H71E=FEL
M;R!M;W)A(&)I=&D@=G-A:B!E;F$N`%1A('-T<F7%OFYI:R!N92!M;W)E(&]D
M<')E=&D@>FEP(&EN(&=Z:7`@9&%T;W1E:RX`4VES=&5M(&IE('1R96YU=&YO
M(&YE86MI=&EV96XN`%1A('9R961N;W-T(&UO<F$@8FET:2#%H71E=FEL:V$N
M`%1O(&]K;F\@;6]R871E('!O9VYA=&D@>B!O:VYA($UOQ;YN;W-T:2X`0FQI
M<VL`4')I:F%V90#$C6%S`%-L961N:F4@Q(UA<V$`3V)L:6MA(,2-87-A`$EZ
M8FER82!E87-A+@!.87-L;W8`6F$`9<2-(,6^96QI=&4@:7IB<F%T:2!V9<2-
M('!R961M971O=BP@<')I=&ES;FET92!#;VYT<F]L("A00RD@86QI($-O;6UA
M;F0@*$UA8RD@=&EP:V\L(&UE9'1E;2!K;R!N86YJ92!K;&EK871E+@!D86X`
M5&]G;P!4;VME;&%U`$MO;6]R:2``5&]N9V$`4')E=F7$C2!N975S<&5L:6@@
M<&]V97IA=B!V('IA9&YJ:6@@;6EN=71A:"X`3W)G86YI>F%C:6IA`%1R:6YI
M9&%D(&EN(%1O8F%G;P!$82!A;&D@;F4`Q(QE`%1U;FEZ:6IA`%1U<F5I:F$`
M5'5RQ:%K:2`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<L6A:VD@:6X@
M0V%I8V]S(&]T;VMI`%1U=F%L=0!6=&EP:V%J=&4@=F'%H6\@:7IB:7)O.B``
M52Y6+B!I;F1E:W,Z`%523`!54DP@=F'%H64@<VMR:7!T92!Z82!P;W)OQ(UA
M;FIE('-T871U<V$@9&]S=&%V90!59V%N9&$`56MR86II;F$`3FEM86T@9&]S
M=&]P82!D;R!61E,@:6UE;FEK82X`3F4@;6]R96T@<W!R96UE;FET:2!P<F%V
M:6-E('IA(%9&4R!D871O=&5K;R`B)7,B+@!$;W9O;&IE;FIA('IA(%9&4R`E
M<R\E<R!N92!M;W)E;2!S<')E;65N:71I+@!.92!M;W)E;2!S<')E;65N:71I
M(&YA("5S+@!.92!M;W)E;2!S<')E;65N:71I(&YA("(E<R(N`$YE(&UO<F5M
M('!R96EM96YO=F%T:2!61E,@9&%T;W1E:V4@)7,O)7,N`$YE(&UO<F5M('-E
M('!O=F5Z871I(',@4U-,+@!61E,@9&%T;W1E:V4@;F4@;6]R96T@:V]P:7)A
M=&DN`$YE(&UO<F5M('5S=&%V<FET:2!I;65N:6MA("(E<R(N`%9&4R!I;65N
M:6MA(&YE(&UO<F5M('5S=&%V<FET:2X`5D93(&1A=&]T96ME(&YE(&UO<F5M
M('5S='9A<FET:2X`3F4@;7)O96T@=7-T=F%R:71I(&EM96YI:V$@(B5S(BX`
M5D93(&1A=&]T96ME(&YE(&UO<F5M('5S='9A<FET:2X`4&]D871K;W8@;F4@
M;6]R96T@<W!R;W-T:71I+@!.92!M;W)E;2!I>F)R:7-A=&D@)7,L(&EM96YI
M:R!N:2!P<F%Z96XN`$YE(&UO<F5M(&EZ8G)I<V%T:2`G)7,G.B`E<RX`3F4@
M;6]R96T@:7IB<FES871I("5S+"!I;65N:6L@;FD@<')A>F5N+@!.92!M;W)E
M;2!I>F)R:7-A=&D@:6UE;FEK82X`3F4@;6]R96T@:7IB<FES871I(&EM96YI
M:V$N`$YE(&UO<F5M(&EZ8G)I<V%T:2!61E,@:6UE;FEK83H@)7,@`$YE(&UO
M<F5M(&EZ8G)I<V%T:2!D871O=&5K92XB)7,B+@!.92!M;W)E;2!I>F)R:7-A
M=&D@5D93(&1A=&]T96ME+@!.92!M;W)E;2!I>F)R:7-A=&D@9&%T;W1E:V4@
M(B5S(BX`3F4@;6]R96T@:7IB<FES871I(%9&4SH@)7,@`$YE(&UO<F5M(&1O
M;&_$C6ET:2!S961A;FIE9V$@:6UE;FEK82X`3F4@;6]R96T@:7IP:7-A=&D@
M<&]T<FIE;FEH('!O9')O8FYO<W1I+@!.92!M;W)E;2!S<')E;65N:71I(&YA
M("5S+@!.92!M;W)E;2!P<F5M86MN:71I(%9&4R!D871O=&5K92X`3F4@;6]R
M96T@;V1P<F5T:2!D871O=&5K92(E<R(N`$YE(&UO<F5M(&]D<')E=&D@5D93
M(&1A=&]T96ME(&YA;65N:F5N92!P:7-A;FIU+@!.92!M;W)E;2!O9'!R971I
M(%9&4R!D871O=&5K92X`3F4@;6]R96T@;V1P<F5T:2!Z9V_%H<2-96YE9V$@
M87)H:79A+@!.92!M;W)E;2!P<F5I;65N;W9A=&D@5D93(&1A=&]T96ME("5S
M+R5S+@!.92!M;W)E;2!P<F5I;65N;W9A=&D@5D93(&1A=&]T96ME+@!.92!M
M;W)E;2!P<F5B<F%T:2!61E,@;W-N;W9N96=A(&EM96YI:V$N`$YE(&UO<F5M
M('!R96EM96YO=F%T:2`E<R!V("5S.B!M87!A(,6^92!O<W1A:F$`3F4@;6]R
M96T@<')E:6UE;F]V871I(%9&4R!I;65N:6MA+@!.92!M;W)E;2!P<F5I;65N
M;W9A=&D@5D93(&EM96YI:V$Z("5S+@!.92!M;W)E;2!P<F5I;65N;W9A=&D@
M5D93(&1A=&]T96ME("(E<R(N`$YE(&UO<F5M('!R96EM96YO=F%T:2!61E,@
M9&%T;W1E:V4@)7,O)7,N`$YE(&UO<F5M('!R96EM96YO=F%T:2!61E,@9&%T
M;W1E:V4N`$YE(&UO<F5M('-P<F5M96YI=&D@;F$@)7,N`$YE(&UO<F5M('!R
M979E<W1I('1E9V$@5V]R9&]V96=A(&1O:W5M96YT82X`3F4@;6]R96T@<W!R
M;\6^:71I('!R;W-T;R]Z87-E9&5N;R!P;W-O9&]B:71E('IA("5S`$YE(&UO
M<F5M(&YA<&ES871I(%9&4R!D871O=&5K92`B)7,B+@!.92!M;W)E;2!N87!I
M<V%T:2!61E,@<&]D871K;W9N:6@@9&%T;W1E:RX`3F4@;6]R96T@;F%P:7-A
M=&D@5D93('!O9&%T:V]V;FEH(&1A=&]T96LN`$YE(&UO<F5M(&YA<&ES871I
M(%9&4R!D871O=&5K92P@:W9O=&$@8F\@<')E<V7%OF5N82X`4F%Z=F5L:F%V
M:2!S<')E;65M8F4`3F5P<FG$C6%K;W9A;B!O9&=O=F]R(',@<W1R9<6^;FEK
M82!V('!O=F5Z;W9A;FIU.@!.97!R:<2-86MO=F%N(&YE<')IQ(UA:V]V86X@
M;V1G;W9O<B!S=')EQ;YN:6MA('IA.@!.96EZ<&]L;FIE;F\`56YI:V]D("A5
M5$8M."D`6F1R=<6^96YI(&%R86)S:VD@96UI<F%T:0!:9')UQ;YE;F\@:W)A
M;&IE<W1V;P!:9')UQ;YE;F4@9'+%OF%V90!:9')UQ;YE;F4@9'+%OF%V92!/
M=&]K:2!-:6YO<B!/=71L>6EN9P!%;F]T90!.97!O>FYA;F\`3F5P;WIN86YA
M(&%P:6US9VED("A)1"!!4$D@<W!O<F_$C6EL82DN`$YE<&]Z;F%N82!C;&EM
M<V=I9"`H240@=7!O<F%B;FG%H6ME9V$@<W!O<F_$C6EL82D`365S=&\@;FD@
M;F%S=&%V;&IE;F\N`$YE>FYA;F\@=7!O<F%B;FG%H6MO(&EM92!A;&D@9V5S
M;&\N`$)R97H@:6UE;F$`3F5P;V1P<G1A(')A>L6A:7)I=&5V`%!O<V]D;V)I
M`%!O<V]D;V)I("5S`%!O<V]D;V)L:F5N('5P;W)A8FYI:P!0;W-O9&]B;&IE
M;B`G)7,G+@!)>F)R:7-A;F$@<VMR:7!T82!Z82!N861G<F%D;FIO+@!.86QA
M9V%M`$YA;&_%OFD@;F$@<W1R9<6^;FEK('9S92!N86UE<W1I='9E;F4@9&%T
M;W1E:V4@87!L:6MA8VEJ+@!5<G5G=F%J`%5P;W)A8FD@<V5D86YJ:3H@)7,`
M57!O<F%B:2!34TP`57!O<F%B:2P@Q(UE(&IE('5P;W)A8FYIQ:%K;R!I;64O
M9V5S;&\@9')U9V'$C6YO(&]D($E-4U`@<W1R9<6^;FEK80!5<&]R86)N:6L`
M57!O<F%B;FEK("5S(&YI;6$@9&]S=&]P82!D;R`E<P!5<')A=F$@>F$@=7!O
M<F%B;FEK90!5<&]R86)N:<6A:V4@;F%S=&%V:71V90!296=I<W1R86-I:F$@
M=7!O<F%B;FEK80!296=I<W1R:7)A;FIE('5P;W)A8FYI:V]V(&IE(&YA('1E
M:B!S=')A;FD@;VYE;6]G;\2-96YO+@!.92!N86ID96T@=7!O<F%B;FEK;W8@
M<F'$C75N+@!5<&]R86)N:<6A:V\@:6UE`%5P;W)A8FYIQ:%K;R!I;64@(B5S
M(B!J92#%OF4@=B!U<&]R86)I+@!5<&]R86)N:<6A:V\@:6UE.B``57!O<F%B
M;FG%H6MO(&EM93H@`%5P;W)A8FYI:VDL(&MI('-O('8@<VES=&5M=3H`57IB
M96MI<W1A;@!61E,@:6UE;FEK(&YE(&]B<W1A:F$N`$]D<V]T;F]S=`!.86ID
M96YA('9E;&IA=FYA(&QO:V%C:6IA('IA:F5M83H`5F5L:F%V;F]S=`!6<F5D
M;F]S="!V(&UI;G5T86@@;V0@<V5D86H@9&%L:F4N`%9R961N;W-T('!R97-E
M9V$@;6%K<VEM86QN;R!D;VS%OFEN;R`E<RX`5G)E9&YO<W1I`%9R961N;W-T
M:2!O9"!K;V1E<B!I>F)I<F%T:0!686YU871U`%9A<FEA8FEL;F\`5F5N97IU
M96QA`%!R979E<FIA;FIE(&YE=7-P9<6A;F\@+2!M;V=OQ(UE(&IE(&)I;&\@
M<W!O<F_$C6EL;R!S<')E;65N:F5N;RX`4F%Z;&G$C6EC80!287IL:<2-:6-A
M`%IE;&\@=FES;VMO`%9I971N86T`5FEE=&YA;7-K:2`H5DE30TE)*0!0;V=L
M96H@)7,`4&]G;&5D(&YA('IU;F%N:F\@<W!L971N;R!S=')A;@!$979IQ:%K
M:2!O=&]K:2`H8G)I=&%N<VMI*0!$979IQ:%K:2!O=&]K:2`H6D1!*0!6:61L
M:FEV;W-T`%9I9&QJ:79O<W0Z`%9O9&%F;VX@271A;&EJ82!P<F5K;R!33510
M`$]03UI/4DE,3P!/4$]:3U))3$\A(2$@4D_$C4Y/($]$4U1204Y)32!32U))
M4%1/($E:("5S+@!724X@<')E:V\@2%144`!786QL:7,@:6X@1G5T=6YA`$]P
M;WIO<FEL;P!-:0!6<F5M96YS:V$@;F%P;W9E9`!6<F5M96YS:VD@<&]D871K
M:2!S('-P;&5T80!W96%T:&5R+F-O;0!3<&QE=`!3<&QE=&YA('-T<F%N`%1E
M9&5N<VMO`$1O8G)O9&_%H6QI`$1O8G)O9&_%H6QI(&YA('-P;&5T;FEH('-T
M<F%N96@@<')O9W)A;6$@)7,`1&]B<F]D;\6A;&DL("5S`%IA:&]D;FD@*$E3
M3RTX.#4Y+3$I`%IA:&]D;FD@*$E33RTX.#4Y+3$U`%IA:&]D;F$@4V%H87)A
M`$MA=&5R;R!A<&QI:V%C:6IO(&YA:B!P<FEK8<6^92`E<RP@<&\@<')I:F%V
M:3\`2V%KQ:%E;B!J92!L;\2-:6QN:2!Z;F%K/P!+86O%H65N(&IE(&YA=F5D
M96YI('IN86L_`%IE;6QJ979I9"`@5VAE<F5I<R!!=7-T<F%L:6$`4F%Z=F]J
M;F$@<W1O<&YJ80!+871E<F4@9&]D871K92!N86H@;VUO9V_$C6EM('!R:2!U
M<F5J86YJ=2!B97-E9&EL+@#%H&ER:6YA('8@96YO=&%H($-34P#%H&ER:6YA
M("5S(&UE;FEJ82!N82!L979I("AO9')A>FEL82!S92!B;R!O8B!N87-L961N
M:FD@<')I:F%V:2DZ`%=I:VD`5F5T97(Z(`!*=71R86YJ:2!V971E<CH@`$AI
M=')O<W0@=F5T<F$@=B!V;WIL:6@`5F5T97(Z`%9E=&5R.B``36]D<F]S=`!,
M:7-T82#%OF5L:F$`4VQUQ;YB80!3;'7%OF)E;FD@;F%S;&]V`%-L=<6^8F5N
M:2!T96QE9F]N`$YA<&'$C6YO(,6A=&5V:6QO('!O;&H@=B`E9"!V<G-T:2X@
M4')IQ(UA:V]V86YI:"`E9"P@;F%J9&5N:6@@)60N`$YA<&'$C6YO(,6A=&5V
M:6QO('!O;&HN(%!R:<2-86MO=F%N:6@@)60L(&YA:F1E;FEH("5D+@!.87!A
MQ(UE;B!O9&UI:R`E9"!M960@8G)A;FIE;2!D871O=&5K92!61E,N`%@M4F5F
M`%@U,#EV,R!O<VYO=FYA(&]M96II=&5V`%@U,#EV,R!287K%H6ER:F5N82!U
M<&]R86)A(&ML:G7$C6$`6#4P.78S(%IA9&5V82!A;'1E<FYA=&EV;F\@:6UE
M`%@U,#EV,R!+:G5E('IA(&1O;&]E:71I('IA9&5V;P!8-3`Y=C,@<F%ZQ:%I
M<FET978`3$P`3$Q,3`!986AO;R$@>F5M;&IE=FED`$QE=&YO`$IE;65N`$1A
M+@!$82P@<V4@<W1R:6YJ86TN`$YI;6%T92!D;W9O;&IE;FIA('5S='9A<FET
M:2!V9<2-(&MO="`E9"!B;&]K;W8N`$YI<W1E('!R:6IA=FQJ96YI`%8@:6UE
M;G4@;F4@;6]R971E(&EM971I('IN86MO=B`G7"<`3FES=&4@=G-T879I;&D@
M=F5L:F%V;F5G82!E;&5K=')O;G-K96=A(&YA<VQO=F$N`$UE9"!S<')E:F5T
M:6UI(&1A=&]T96MA;6D@;FES=&4@;WIN8<2-:6QI(&YO8F5N96=A('!O;&IA
M+"!K:2!S92!U:F5M82!S('!O;&II('8E<RX`0FEL:2!S=&4@;V1J879L:F5N
M:2X`5FYE<W1I(&UO<F%T92!V96QJ879N;R!G<VT@Q:%T979I;&MO+D1V;VQJ
M96YI('IN86MI('-O(&QE(,6A=&5V:6QK92!I;B`G*R<@:V]T('!R961P;VYA
M(&UE9&YA<F]D;FEM(,6A=&5I=FQK86TN`%9S=&%V:71I(&UO<F%T92!V96QJ
M879N;R!V<F5D;F]S="X`3V)L:6MO=F%T:2!M;W)A=&4@4VEG;G5P(&)A8VME
M;F0L(,6A96QE(&YA=&\@<V4@;&%H:V\@<')I:F%V;&IA=&4N`$]B;&EK;W9A
M=&D@;6]R871E(%9&4R!B86-K96YD+@!.86IP<F5J(&]P:<6A:71E('1EQ;YA
M=F4L(,6A96QE(&YA=&\@;&%H:V\@<&_%H6QJ971E('!O<F_$C6EL;R!O('1E
MQ;YA=F%H+@!)>F)R871I(&UO<F%T92!S=')EQ;YN:6LL(&MI(&)O(&EZ8G)I
M<V%N+@!.871A;L2-;F5J92!N879E9&ET92!U<&]R86)N:<6A:V\@:6UE+"!K
M:2!G82#%OF5L:71E(&EZ8G)I871I+@!.871A;L2-;F5J92!N879E9&ET92!U
M<&]R86)N:<6A:V\@:6UE+"!K:2!G82#%OF5L:71E(&]D<W1R86YI=&DN`$YA
M=&%NQ(UN96IE(&YA=F5D:71E('5P;W)A8FYIQ:%K;R!I;64L(&MI(&=A(,6^
M96QI=&4@9&]D871I+@!.871A;L2-;F5J92!N879E9&ET92!U<&]R86)N:<6A
M:V\@:6UE+"!K:2!G82#%OF5L:71E('!O<V]D;V)I=&DN`$YA=&%NQ(UN96IE
M(&YA=F5D:71E(&MA:B#%OF5L:71E(&YA<F5D:71I+@!6=&EP:V%J=&4@:6UE
M(&YO=F4@:V%T96=O<FEJ92X`5FYE<W1I(&UO<F%T92!I=&%L:6IA;G-K;R!T
M96QE9F]N<VMO(,6A=&5V:6QK;P!68<6A82!P<FEJ879I='9E;F$@<V5J82`E
M<R!J92!P;W1E:VQA+B!0<F]S:6UO+"!D82!S92!P;VYO=FYO('!R:6IA=FET
M92X`5F'%H2!E;&5K=')O;G-K:2!N87-L;W8Z`%9AQ:$@;F%S;&]V.@!68<6A
M:2!P;V1A=&MI`$]D('IAQ(UE=&MA("5S('-E:F4L('-E(&IE('9AQ:$@<W!L
M971N:2!N87-L;W8@<W!R96UE;FEL+B!)>B!V87)N;W-T;FEH<F%Z;&]G;W8L
M('-E(&UO<F%T92!P;VYO=FYO('!R:6IA=FET:2X`5F'%H64@:6UE.@!68<6A
M92!O>F%D:F4@>F$@;W9E<FIE;F4@;F4@<&]D<&ER82!D;V1A:F%N:F$@=7!O
M<F%B;FEK;W8N(,2-92#%OF5L:71E('5P;W)A8FET:4AO<F1E('IA(&%D;6EN
M:7-T<FER86YJ92!U<&]R86)N:<6A:VEH(')AQ(UU;F]V+"!M;W)A=&4@=7!O
M<F%B:71I(&1R=6=O(&]Z861J92!Z86]V97)J86YJ92X`5F'%H64@;WIA9&IE
M('IA(&]V97)J86YJ92!N92!P;V1P:7)A(&YA=F%J86YJ82!U<&]R86)N:6MO
M=B!A;&D@<&$@:F4@8FEL82!M;\6^;F]S="!O;F5M;V=OQ(UE;F$@:7H@9')U
M9VEH(')A>FQO9V]V+@!+8<6^92P@9&$@<V4@:F4@;V0@>F'$C65T:V$@)2!S
M96IE+"!V8<6A(&)R<VMA;&YI:R!S<')E;65N:6PN($EZ=F%R;F]S=&YI:"!R
M87IL;V=O=BP@<V4@;6]R871E('!O;F]V;F\@<')I:F%V:71I+@!68<6A(&)R
M<VMA;&YI:R!N92!P;V1P:7)A('1E(&9U;FMC:6IE+@!68<6A(&)R<VMA;&YI
M:R!N92!P;V1P:7)A(&1O;&_$C65N:6@@;6_%OFYO<W1I('!R:2!P<FEN=&%N
M:G4N(%IA('!R:6YT86YJ92!P<FET:7-N:71E($-O;G1R;VPO36_%OFYO<W1I
M("L@4"X`5F'%H2!T<F5N=71N:2#$C6%S;W9N:2!P87,Z`%9AQ:%A('!R:79Z
M971A(&ED96YT:71E=&$@:F4@8FEL82!S<')E;65N:F5N82X`4')I=GIE=&$@
M:61E;G1I=&5T80!68<6A92!I;64Z`%9AQ:%A('!R:6IA=F$@:F4@<&]T96ML
M82X`5F'%H64@;F]V92!G97-L;R!Z82`E<R!J93H@)7,`5F'%H64@;F%S=&%V
M:71V92!S;R!B:6QE('!O<V]D;V)L:F5N92!Z82#$C6%S('1E('-E:F4N`%9A
MQ:%E(&YA<W1A=FET=F4@<V\@8FEL92!P;W-O9&]B;&IE;F4N`%9AQ:%E(&=E
M<VQO(&IE(&)I;&\@<&]N87-T879L:F5N;RX`5F'%H64@9V5S;&\@:F4@8FEL
M;R!P;VYA<W1A=FQJ96YO+B!.82!V8<6A(&4M;F%S;&]V('-M;R!V86T@<&]S
M;&%L:2!N;W9O9V5S;&\@<R!K871E<FEM('-E('!R:6IA=FET92X`5F'%H64@
M9V5S;&\@:F4@<&]T96ML;RX`5F'%H6D@<&]S<F5D;FD@<W1R9<6^;FEK:3H`
M2G5G;W-L879I:F$`6F%I<@!:86UB:6IA`%II;6)A8G9E`%M3:W)I:B!C:71I
M<F%N;R!B97-E9&EL;UT`6W!O<F_$C6EL;R!O(&YA<&%K:5T`6U!O:V'%OFD@
M8VET:7)A;F\@8F5S961I;&\@+0!;4&]K8<6^:2!C:71I<F%N;R!B97-E9&EL
M;R`M("5S('9R<W1I8UT`6R5S('9R<W1I8V$@;V0@)7-=`%]#3$D`1')E=F5S
M;F$@`%]3:W5P:6YE`%!O;6_$C0!0<FEJ879A`$]D:F%V80!-;\6^;F]S=&D`
M1&]V;VQJ96YJ80!?3F%M97-T:0!?57!O<F%B;FEK:0!);65N:6L`3F%S;&]V
M;FEK(&YE>FYA;@!+;VQE9&%R`$UI<FYO`$YE(&UO<F5M('5S='9A<FET:2!I
M>FAO9&YE(&1A=&]T96ME`$YE(&UO<F5M(&]D<')E=&D@=FAO9&$`:VQI:VYI
M('1U`&YA<&%K82!V('5P;W)A8FYI('5K87IN92!V<G-T:6-E`$YA<&%K82!V
M(&MO;F9I9W5R86-I:FD`3F4@;F%J9&5M('IA:'1E=F%N92!S:7-T96US:V4@
M9&%T;W1E:V4`3F%P8<2-;F$@;V)L:6MA(&1A='5M80!5<F5D:0!.92!N86ID
M96T@=FYE<V5N:6@@<&]D871K;W8`4&%D879I;F4`9&%T;W1E:V$`:7H@)7,@
M*"5S*2!K("5S("5S`&=O<W1I;0!H.@!H:`!.97IN86YO(&EM92!G;W-T:71E
M;&IA`'1A:V]J`$UE9"!V<G-T:6-A;6D`5FAO9&YA+VEZ:&]D;F$@;F%P86MA
M`$EN=&5R;F$@;F%P86MA('8@<')O9W)A;74`=G)S=&EC90!M:VES;V9S(&YA
M<&%K82!K;V1E("5D+"!M960@<')I<')A=FQJ86YJ96T@25-/+@!M;0!I;64`
M;FD@9&]K;V[$C6%N;P#%H64@;FD@<&]D<')T80!"96QEQ;YK80!$;W9O;&IE
M;FIE(&IE('IA=G)N:F5N;RX`;F%P86MA('8@;V1D;&IE;F5M('!R;W1O:V]L
M=0!V>FAA:F%J;\2-90!397)V:7,@;FD@;F$@=F]L:F\N`%!O:V'%OFD@<F%Z
M;&EK90!S;7,R96UA:6P@<')E:V\@2%144`!S<P!3=&%B:6QN;P!3:7-T96US
M:V$@;F%P86MA+@!397IN86T@;W!R879I;"X`>F'$C6%S;F$@;V1P;W9E9`!Z
M82!P;W1R9&ET978@=G1I<&MA:G1E(&=E<VQO(&1V86MR870`96YO=&5N`&)R
M97H@:6UE;F$`27IB:7)A('5P;W)A8FYI:V$@`'8@2V%R=&EC80!W.@!W96%T
M:&5R+F-O;0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W-V7U-%+P``````````
M````````````````````````````````````````````````````````````
M```````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#4Q-30S,S<U-``P,C`Q,S4`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A
M;&4O<W9?4T4O:&5L<"YX;6P`````````````````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`S,S(P`#$P-3$U-#,S-S4T`#`R,38P-0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/WAM;"!V97)S:6]N
M/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L92]S=E]312]H96QP
M+GAM;"QV(#$N,B`R,#`T+S`U+S(W(#(P.C(R.C$R(&IA;B!%>'`@)"`M+3X*
M/&AE;'`^"B`@/&5N=')Y(&ED/2)S=6UM87)Y(B!S=&%T93TB;F5W(CX*/'1I
M=&QE/E1H92!0;W)T86P@4&%G93PO=&ET;&4^"B`\<&%R83X*("!4:&ES('!O
M<G1A;"!P86=E('!R;W9I9&5S(&$@<75I8VL@<W5M;6%R>2!O9B!A;&P@>6]U
M<B!I;7!O<G1A;G0*("!I;F9O<FUA=&EO;BX@1F]R(&5X86UP;&4L(&ET(&UI
M9VAT('-H;W<@:&]W(&UA;GD@;F5W(&4M;6%I;"!M97-S86=E<R!Y;W4*("!H
M879E(&EN('EO=7(@24Y"3U@L('5P8V]M:6YG(&5V96YT<R!O;B!Y;W5R(&-A
M;&5N9&%R+"!T87-K<R!O;B!Y;W5R('1O+61O"B`@;&ES="P@:&5A9&QI;F5S
M(&9R;VT@<V5L96-T960@;F5W<R!S97)V:6-E<RP@86YD('-O(&]N+B`@36%N
M>2!O9B!T:&5S90H@('-U;6UA<FEE<R!W:6QL(&-O;G1A:6X@<75I8VL@<VAO
M<G1C=71S('1O(&-O;6UO;B!F=6YC=&EO;G,L('-U8V@@87,*("!C;VUP;W-I
M;F<@82!N97<@;6%I;"!M97-S86=E+"!C<F5A=&EN9R!A(&YE=R!C86QE;F1A
M<B!E=F5N="!O<B!T87-K+"!E=&,N"B`\+W!A<F$^"B`\<&%R83X*("!4:&4@
M8V]N=&5N=',@;V8@=&AI<R!P;W)T86P@<&%G92!A<F4@8W5S=&]M:7IA8FQE
M('9I82!T:&4@3&%Y;W5T(&)U='1O;BX*("!&;W(@97AA;7!L92P@>6]U(&-A
M;B!C:&]O<V4@=VAI8V@@:71E;7,@=&\@:6YC;'5D92!O;B!T:&ES('!O<G1A
M;"!P86=E(&%S"B`@=V5L;"!A<R!I;B!W:&EC:"!O<F1E<B!T:&5Y(&%R92!S
M:&]W;BX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](FYA=F)A<B(@
M<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@07!P;&EC871I;VX@3F%V:6=A=&EO
M;B!"87(\+W1I=&QE/@H@/'!A<F$^"B`@070@=&AE(&QE9G0@:&%N9"!S:61E
M(&]F('1H92!W96(@<&%G92!I<R!T:&4@87!P;&EC871I;VX@;F%V:6=A=&EO
M;B!B87(N"B`@0VQI8VL@;VX@=&AE(&EC;VYS(&]N('1H:7,@;F%V:6=A=&EO
M;B!B87(@=&\@<75I8VML>2!A;F0@96%S:6QY('-W:71C:`H@(&)E='=E96X@
M=&AE(&%V86EL86)L92!A<'!L:6-A=&EO;G,N"B`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$;R!-
M86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L
M9"!L:6ME('1O('!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L
M;V=I;BP@8VAE8VL@=&AI<R!B;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)P<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB
M;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($-O
M;F9I<FT@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y
M;W4@=V]U;&0@;&EK92!T;R!C;VYF:7)M(&%L;"!M86EN=&5N86YC92!T87-K
M<R!B969O<F4@=&AE>2!A<F4@<G5N+"!C:&5C:R!T:&ES(&)O>"X@268@;&5F
M="!U;F-H96-K960L(&%L;"!M86EN=&5N86YC92!O<&5R871I;VYS('1H870@
M;F5E9"!T;R!B92!R=6X@=VEL;"!B92!P97)F;W)M960@875T;VUA=&EC86QL
M>2!W:71H(&YO(&-H86YC92!T;R!C86YC96P@;VX@;&]G:6XN"B`@("`\+W!A
M<F$^"CPO96YT<GD^"CPO:&5L<#X*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W-V
M7U-%+TQ#7TU%4U-!1T53+P``````````````````````````````````````
M```````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#4Q-30S,S<U-``P,C$W,C(`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L;V-A;&4O<W9?4T4O3$-?34534T%'15,O:&]R9&4N;6\`````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-#$S-30V`#$P-3$U-#,S-S4T`#`R,S,W
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#>
M$@25`````.0'```<````/#\``(4*``!<?@```````'"H``!(````<:@```X`
M``"ZJ```#P```,FH```,````V:@```T```#FJ```"````/2H```+````_:@`
M``P````)J0``!````!:I```8````&ZD``!L````TJ0``+0```%"I```=````
M?JD``"0```"<J0``*0```,&I```9````ZZD``"8````%J@``#````"RJ```D
M````.:H```\```!>J@``"P```&ZJ```.````>JH```4```")J@``*````(^J
M```(````N*H```H```#!J@``%0```,RJ```2````XJH```L```#UJ@``%```
M``&K```F````%JL``"<````]JP``)@```&6K``"%````C*L```X````2K```
M"@```"&L```-````+*P``"<````ZK```(````&*L```.````@ZP``!<```"2
MK```(@```*JL```U````S:P``!$````#K0``#0```!6M```,````(ZT```T`
M```PK0``!@```#ZM``"4````1:T```H```#:K0``#P```.6M```8````]:T`
M``P````.K@``#@```!NN```.````*JX```@````YK@``"0```$*N```N````
M3*X``!H```![K@``,@```):N```X````R:X``%0````"KP``40```%>O``!:
M````J:\``%<````$L```-````%RP```)````D;````T```";L```!P```*FP
M```*````L;````\```"\L```!0```,RP```&````TK```!$```#9L```"```
M`.NP```)````]+````D```#^L```#@````BQ```(````%[$``"4````@L0``
M(````$:Q```3````9[$``!````![L0``#P```(RQ```*````G+$```<```"G
ML0```P```*^Q```&````L[$```\```"ZL0``%````,JQ```)````W[$```T`
M``#IL0``$@```/>Q```9````"K(``!X````DL@``#P```$.R```*````4[(`
M``\```!>L@``"````&ZR```D````=[(``!<```"<L@``%````+2R```6````
MR;(```@```#@L@``3@```.FR```M````.+,``!D```!FLP``!P```("S```,
M````B+,``"P```"5LP``#@```,*S```#````T;,```L```#5LP``!P```.&S
M```'````Z;,```4```#QLP``!0```/>S```*````_;,```,````(M```%P``
M``RT```*````)+0```\````OM```#@```#^T```8````3K0``",```!GM```
M#@```(NT```4````FK0``!<```"OM```%P```,>T```7````W[0``!,```#W
MM```#P````NU```.````&[4``"D````JM0``'P```%2U```=````=+4```<`
M``"2M0``!@```)JU```(````H;4```\```"JM0``!@```+JU```*````P;4`
M`!,```#,M0``"P```."U```0````[+4``!4```#]M0``%0```!.V```'````
M*;8``!`````QM@``!0```$*V```5````2+8``!$```!>M@``#````'"V```[
M````?;8``#@```"YM@``"0```/*V```'````_+8``!0````$MP```P```!FW
M```%````';<``!`````CMP``"0```#2W```3````/K<``#D```!2MP``$@``
M`(RW```Y````G[<``"<```#9MP``+`````&X```J````+K@``"4```!9N```
M"0```'^X```*````B;@```8```"4N```"0```)NX```'````I;@``"\```"M
MN```-P```-VX```N````%;D``%4```!$N0``+0```)JY```M````R+D``#T`
M``#VN0``/P```#2Z```M````=+H``$````"BN@``(P```..Z```C````![L`
M`$`````KNP``+0```&R[```S````FKL``"4```#.NP``%0```/2[```9````
M"KP``"D````DO```)````$Z\```H````<[P``!$```"<O```$0```*Z\```*
M````P+P```0```#+O```#````-"\```*````W;P``!````#HO```%@```/F\
M```6````$+T```<````GO0``!P```"^]```4````-[T```H```!,O0``"```
M`%>]```(````8+T```@```!IO0``!@```'*]```G````>;T```@```"AO0``
M!P```*J]```'````LKT```8```"ZO0``!0```,&]```'````Q[T```8```#/
MO0``"````-:]```I````W[T```X````)O@``"@```!B^```)````([X```X`
M```MO@``!````#R^```'````0;X```D```!)O@``!@```%.^```1````6KX`
M``<```!LO@``%@```'2^```$````B[X```@```"0O@``!@```)F^```-````
MH+X```8```"NO@``'@```+6^```%````U+X``!$```#:O@``"````.R^```-
M````];X```P````#OP``#````!"_```'````';\```,````EOP```P```"F_
M```7````+;\``!,```!%OP``'0```%F_```(````=[\```0```"`OP``"```
M`(6_```(````CK\```H```"7OP``00```**_```:````Y+\``"L```#_OP``
M(````"O````5````3,````8```!BP```!@```&G````5````<,```!@```"&
MP```(@```)_````N````PL```!T```#QP```(0````_!```I````,<$```H`
M``!;P0``!P```&;!```'````;L$``!4```!VP0``#@```(S!```*````F\$`
M``\```"FP0``#0```+;!```/````Q,$```T```#4P0``"0```.+!```4````
M[,$```8````!P@``&`````C"```=````(<(``!,````_P@``$0```%/"```4
M````9<(```0```!ZP@``#````'_"```&````C,(``!0```"3P@``%P```*C"
M``!4````P,(``&0````5PP``!````'K#```.````?\,``$0```".PP``!0``
M`-/#```%````V<,``!L```#?PP``&@```/O#```3````%L0``!$````JQ```
M$0```#S$```1````3L0``!P```!@Q```*@```'W$```0````J,0``"$```"Y
MQ```!0```-O$```3````X<0```L```#UQ```$@````'%```*````%,4```\`
M```?Q0``#0```"_%```1````/<4``!,```!/Q0``#````&/%```&````<,4`
M``P```!WQ0``!@```(3%```7````B\4``!````"CQ0``$0```+3%```(````
MQL4```4```#/Q0``#````-7%```0````XL4```4```#SQ0``#0```/G%```&
M````!\8```<````.Q@``#0```!;&```'````),8```L````LQ@``!P```#C&
M```'````0,8```D```!(Q@``%````%+&```)````9\8```D```!QQ@``"@``
M`'O&```9````AL8``#T```"@Q@``'0```-[&```,````_,8``!`````)QP``
M!0```!K'```E````(,<``!(```!&QP``$P```%G'```K````;<<``#L```"9
MQP``(````-7'```(````]L<``#8```#_QP``(0```#;(```0````6,@```@`
M``!IR```#````'+(```&````?\@```0```"&R```#P```(O(```.````F\@`
M``H```"JR```!P```+7(```*````O<@```T```#(R```'@```-;(```?````
M]<@``!L````5R0``'````#')```A````3LD``!X```!PR0``&0```(_)```>
M````J<D``!L```#(R0``(0```.3)```N````!LH``"8````UR@``&P```%S*
M```<````>,H``!X```"5R@``'````+3*```F````T<H``"L```#XR@``,P``
M`"3+```F````6,L``"L```!_RP``.````*O+```=````Y,L``!T````"S```
M%0```"#,```5````-LP``"\```!,S```(````'S,```2````G<P``"````"P
MS```*0```-',```>````^\P``!X````:S0``(````#G-```2````6LT``*(`
M``!MS0``%@```!#.```C````)\X``"@```!+S@``*0```'3.```H````GLX`
M`!\```#'S@``%0```.?.```5````_<X``"`````3SP``)0```#3/```H````
M6L\``"T```"#SP``,````+'/``"2````XL\``"$```!UT```%@```)?0```6
M````KM```!P```#%T```)@```.+0```J````"=$``$$````TT0``1````';1
M```,````N]$```<```#(T0``!P```-#1```&````V-$```T```#?T0``$```
M`.W1```2````_M$``!,````1T@``$@```"72```'````.-(```0```!`T@``
M$````$72```0````5M(```P```!GT@``#@```'32```-````@](```\```"1
MT@``$P```*'2```-````M=(``"@```##T@```P```.S2```-````\-(```8`
M``#^T@``$0````73```7````%],``!L````OTP``#@```$O3```"````6M,`
M``4```!=TP``$````&/3```/````=-,```0```"$TP``#0```(G3```.````
ME],```,```"FTP``#@```*K3```(````N=,```\```#"TP``"````-+3```/
M````V],```<```#KTP``#0```//3```0`````=0```T````2U```"P```"#4
M```1````+-0```D````^U```!@```$C4```+````3]0```P```!;U```"@``
M`&C4```1````<]0``!D```"%U```"P```)_4```-````J]0``"(```"YU```
M#P```-S4```;````[-0``#0````(U0``"@```#W5```8````2-4``!(```!A
MU0``&0```'35```6````CM4``!````"EU0``(@```+;5```-````V=4```<`
M``#GU0``#````._5```F````_-4``!0````CU@``"P```#C6```B````1-8`
M`"\```!GU@``"P```)?6```)````H]8``!D```"MU@``"P```,?6```7````
MT]8``!<```#KU@``"0````/7```6````#=<```\````DUP``&0```#37```6
M````3M<```X```!EUP``!P```'37```(````?-<```T```"%UP``)@```)/7
M``!#````NM<``!(```#^UP``'P```!'8```(````,=@```L````ZV```+P``
M`$;8```.````=M@```4```"%V```!@```(O8``!%````DM@```,```#8V```
M!P```-S8```$````Y-@```H```#IV```"@```/38```/````_]@``!`````/
MV0``%P```"#9```1````.-D``!D```!*V0``%P```&39```)````?-D```4`
M``"&V0``"P```(S9```*````F-D```(```"CV0``!0```*;9```-````K-D`
M`!L```"ZV0``%P```-;9```4````[MD```D````#V@``#@````W:```-````
M'-H``!(````JV@```P```#W:```(````0=H```X```!*V@``&````%G:```8
M````<MH```4```"+V@``&````)':```>````JMH``!L```#)V@``&0```.7:
M```8````_]H``!L````8VP``$P```#3;```3````2-L```<```!<VP``"```
M`&3;```&````;=L```8```!TVP``$````'O;```/````C-L``!````"<VP``
M#P```*W;```+````O=L```\```#)VP``#````-G;```/````YML```<```#V
MVP``!@```/[;```.````!=P```P````4W```*````"'<```/````2MP```@`
M``!:W```"````&/<```3````;-P``!X```"`W```(0```)_<```@````P=P`
M`!D```#BW```%P```/S<```E````%-T``!<````ZW0``%@```%+=```$````
M:=T``!L```!NW0``#0```(K=```,````F-T```,```"EW0``!0```*G=```(
M````K]T```H```"XW0``#````,/=```+````T-T``!````#<W0``#````.W=
M```.````^MT```L````)W@``!````!7>```$````&MX``!,````?W@``%```
M`#/>```,````2-X```D```!5W@``#@```%_>```+````;MX``!L```!ZW@``
M!P```);>```'````GMX```H```"FW@``#0```+'>```8````O]X```H```#8
MW@``!````./>```F````Z-X```X````/WP``?````![?```5````F]\```4`
M``"QWP``!P```+??```,````O]\```@```#,WP``"@```-7?```&````X-\`
M``@```#GWP```@```/#?```&````\]\```8```#ZWP``%`````'@```5````
M%N````\````LX```$0```#S@```:````3N````T```!IX```$````'?@```;
M````B.````0```"DX```"0```*G@```0````L^````D```#$X```"0```,[@
M```%````V.```!H```#>X```"````/G@```&`````N$``!D````)X0``#@``
M`"/A```'````,N$```<````ZX0``!0```$+A```)````2.$```H```!2X0``
M#@```%WA```"````;.$```8```!OX0``"P```';A```-````@N$```D```"0
MX0``!@```)KA```%````H>$```D```"GX0``!P```+'A```$````N>$``!0`
M``"^X0``0@```-/A```E````%N(``"4````\X@``!@```&+B```$````:>(`
M``D```!NX@``"````'CB```1````@>(```X```"3X@``"0```*+B```&````
MK.(```T```"SX@``!@```,'B```$````R.(``#D```#-X@``/0````?C```Z
M````1>,``!X```"`XP``!0```)_C```.````I>,```0```"TXP``!@```+GC
M```'````P.,``"$```#(XP``#0```.KC```5````^.,```8````.Y```$@``
M`!7D```$````*.0``!$````MY```!@```#_D```*````1N0``"(```!1Y```
M!````'3D```%````>>0```0```!_Y```#````(3D```.````D>0```H```"@
MY```"````*OD```)````M.0```4```"^Y```.@```,3D```P````_^0``#4`
M```PY0``*0```&;E``!'````D.4``#@```#8Y0``*0```!'F```_````.^8`
M`"X```![Y@``+0```*KF```?````V.8```\```#XY@``$@````CG```+````
M&^<``"8````GYP``*0```$[G```D````>.<``"8```"=YP``"````,3G```*
M````S><```D```#8YP``!P```.+G```@````ZN<``"`````+Z```)@```"SH
M```*````4^@``!D```!>Z```*0```'CH```6````HN@``!(```"YZ```!P``
M`,SH```*````U.@```P```#?Z```#P```.SH```0````_.@``$`````-Z0``
M<````$[I``!F````O^D```X````FZ@``"0```#7J```*````/^H``!(```!*
MZ@``$P```%WJ```,````<>H```8```!^Z@``#P```(7J```2````E>H``!``
M``"HZ@``"@```+GJ```1````Q.H``!P```#6Z@``(P```//J``!J````%^L`
M``\```""ZP``!0```)+K```0````F.L```D```"IZP``!````+/K```+````
MN.L``"````#$ZP``%````.7K```,````^NL```P````'[```#P```!3L```5
M````).P``"D````Z[```*@```&3L```F````C^P``"<```"V[```*0```-[L
M```J````".T``!D````S[0``$0```$WM```2````7^T``!,```!R[0``%```
M`(;M```/````F^T``!8```"K[0``%P```,+M```0````VNT``!$```#K[0``
M-````/WM```3````,NX``!(```!&[@``-0```%GN```4````C^X```<```"D
M[@``#````*SN```K````N>X``"````#E[@``$`````;O```4````%^\``!$`
M```L[P``%P```#[O```<````5N\``!,```!S[P``%````(?O```:````G.\`
M`!$```"W[P``&@```,GO```>````Y.\``!H````#\```$P```![P```5````
M,O```!$```!(\```%P```%KP```4````<O```!<```"'\```%0```)_P```)
M````M?```!````"_\```&0```-#P```$````ZO````<```#O\```"P```/?P
M```1`````_$```8````5\0``!@```!SQ```&````(_$```4````J\0``!P``
M`##Q```'````./$```4```!`\0``%@```$;Q```&````7?$```8```!D\0``
M!````&OQ```$````</$```<```!U\0``#@```'WQ```,````C/$```P```"9
M\0``#0```*;Q```%````M/$``"@```"Z\0``#````./Q```/````\/$```H`
M````\@``"`````OR```)````%/(``"L````>\@``!````$KR```(````3_(`
M``4```!8\@``)@```%[R```2````A?(```\```"8\@``!@```*CR```*````
MK_(```<```"Z\@``"````,+R```@````R_(```D```#L\@``%````/;R```,
M````"_,```T````8\P``#@```";S```6````-?,``!$```!,\P``!@```%[S
M```(````9?,```,```!N\P``!@```'+S```9````>?,```<```"3\P``!```
M`)OS```+````H/,```L```"L\P``!P```+CS```%````P/,```<```#&\P``
M%@```,[S```-````Y?,```H```#S\P``#0```/[S```*````#/0``!`````7
M]```#P```"CT```1````./0``!<```!*]```"@```&+T```1````;?0```@`
M``!_]```!````(CT```/````C?0``#H```"=]```!0```-CT```,````WO0`
M`!X```#K]```#@````KU```0````&?4```L````J]0``#````#;U```)````
M0_4```<```!-]0``"@```%7U```)````8/4```X```!J]0``$````'GU```;
M````BO4``!@```"F]0``&@```+_U```*````VO4```D```#E]0``"@```._U
M```,````^O4```\````']@``"````!?V```&````(/8```<````G]@``!0``
M`"_V```+````-?8``$<```!!]@``#0```(GV```)````E_8```0```"A]@``
M`P```*;V```3````JO8``!,```"^]@``$P```-+V```&````YO8```L```#M
M]@``"@```/GV```"````!/<```0````']P``)0````SW```#````,O<```4`
M```V]P``*@```#SW```*````9_<```4```!R]P``!````'CW```*````??<`
M``T```"(]P``!@```);W```(````G?<```@```"F]P``!````*_W```%````
MM/<``&@```"Z]P``"0```"/X```,````+?@``!`````Z^```!0```$OX```&
M````4?@``!L```!8^```+P```'3X```0````I/@```H```"U^```#P```,#X
M```*````T/@```D```#;^```$P```.7X```;````^?@``!@````5^0``%P``
M`"[Y```?````1OD```X```!F^0```P```'7Y```'````>?D```@```"!^0``
M%````(KY```3````G_D``!````"S^0``#0```,3Y```.````TOD``!8```#A
M^0``!P```/CY```*`````/H```L````+^@``!P```!?Z``!1````'_H``!``
M``!Q^@``#````(+Z```-````C_H``!H```"=^@``2@```+CZ```9`````_L`
M``8````=^P``&@```"3[```E````/_L```8```!E^P``!@```&S[```?````
M<_L```8```"3^P``"0```)K[```8````I/L``!<```"]^P``*````-7[```&
M````_OL```T````%_```(@```!/\``!7````-OP``!,```"._```(P```*+\
M```3````QOP```(```#:_```"P```-W\```(````Z?P```T```#R_```"@``
M``#]```'````"_T``!0````3_0``!@```"C]```(````+_T```X````X_0``
M!P```$?]```*````3_T```L```!:_0``,@```&;]```'````F?T```P```"A
M_0``#0```*[]```,````O/T```D```#)_0``"0```-/]```*````W?T```<`
M``#H_0``"0```/#]```'````^OT```H````"_@``!P````W^```;````%?X`
M``\````Q_@``$@```$'^```*````5/X``!8```!?_@``"0```';^```0````
M@/X```<```"1_@``$@```)G^```$````K/X```<```"Q_@``!0```+G^```$
M````O_X```P```#$_@``!0```-'^```+````U_X``!0```#C_@``$0```/C^
M```4````"O\``!<````?_P``&````#?_```<````4/\``!D```!M_P``!P``
M`(?_```%````C_\```T```"5_P``#````*/_```1````L/\```@```#"_P``
M%P```,O_```+````X_\```P```#O_P``'P```/S_```:````'``!`!,````W
M``$`!````$L``0`*````4``!``0```!;``$`#0```&```0`,````;@`!``4`
M``![``$`"0```($``0`%````BP`!``<```"1``$`!0```)D``0`$````GP`!
M``(```"D``$`.````*<``0`L````X``!`!(````-`0$`*0```"`!`0`R````
M2@$!``H```!]`0$`+````(@!`0`N````M0$!`#,```#D`0$`,P```!@"`0`X
M````3`(!``\```"%`@$`%````)4"`0`8````J@(!`!````##`@$`#P```-0"
M`0`3````Y`(!`!4```#X`@$`%`````X#`0`2````(P,!`!0````V`P$`%0``
M`$L#`0`M````80,!`"T```"/`P$`,0```+T#`0`N````[P,!`"\````>!`$`
M+````$X$`0`3````>P0!``P```"/!`$`#0```)P$`0`(````J@0!`!<```"S
M!`$`"````,L$`0`,````U`0!`"L```#A!`$`(0````T%`0`:````+P4!``D`
M``!*!0$`10```%0%`0!!````F@4!``\```#<!0$`!````.P%`0`3````\04!
M``X````%!@$`$P```!0&`0`8````*`8!``8```!!!@$`"0```$@&`0`*````
M4@8!``\```!=!@$`$````&T&`0`'````?@8!``X```"&!@$`!0```)4&`0`;
M````FP8!``8```"W!@$`"````+X&`0`&````QP8!`!0```#.!@$`$0```.,&
M`0`.````]08!`#@````$!P$``@```#T'`0`&````0`<!``X```!'!P$`!0``
M`%8'`0`'````7`<!``X```!D!P$`!@```','`0`H````>@<!``P```"C!P$`
M'````+`'`0`$````S0<!`"D```#2!P$`%P```/P'`0`?````%`@!`%P````T
M"`$`%````)$(`0`^````I@@!`!\```#E"`$`$`````4)`0`4````%@D!``<`
M```K"0$`#@```#,)`0`,````0@D!``P```!/"0$`$P```%P)`0`*````<`D!
M`!T```!["0$`&0```)D)`0`%````LPD!`!$```"Y"0$`$0```,L)`0`D````
MW0D!`!(````""@$`%0```!4*`0`2````*PH!``X````^"@$`&0```$T*`0`(
M````9PH!``D```!P"@$`#0```'H*`0`'````B`H!``H```"0"@$`!P```)L*
M`0`/````HPH!``8```"S"@$`"P```+H*`0`:````Q@H!``H```#A"@$`!P``
M`.P*`0`(````]`H!``4```#]"@$`'P````,+`0`&````(PL!`!`````J"P$`
M"````#L+`0`-````1`L!``@```!2"P$`'@```%L+`0`2````>@L!`"P```"-
M"P$`&@```+H+`0`)````U0L!``H```#?"P$`%0```.H+`0`%``````P!`!0`
M```&#`$`!````!L,`0`0````(`P!``8````Q#`$`!P```#@,`0`>````0`P!
M`"@```!?#`$`"@```(@,`0`<````DPP!`!$```"P#`$`"P```,(,`0`:````
MS@P!`!0```#I#`$`!````/X,`0`$`````PT!``L````(#0$`!0```!0-`0`&
M````&@T!``@````A#0$`!@```"H-`0`*````,0T!`!L````\#0$`-````%@-
M`0`T````C0T!`"````#"#0$`*0```.,-`0`@````#0X!`$$````N#@$`&@``
M`'`.`0`H````BPX!`"D```"T#@$`40```-X.`0!0````,`\!`%<```"!#P$`
M+````-D/`0`B````!A`!``8````I$`$`"````#`0`0`%````.1`!``@````_
M$`$`&0```$@0`0`9````8A`!`"H```!\$`$`"````*<0`0`C````L!`!`!D`
M``#4$`$`+@```.X0`0`T````'1$!``@```!2$0$`%P```%L1`0`*````<Q$!
M``<```!^$0$`(0```(81`0`0````J!$!``X```"Y$0$`"P```,@1`0`'````
MU!$!`!,```#<$0$`"````/`1`0`+````^1$!``H````%$@$`%````!`2`0`/
M````)1(!`#(````U$@$`"P```&@2`0`.````=!(!``4```"#$@$`!0```(D2
M`0`%````CQ(!`!<```"5$@$`#P```*T2`0`$````O1(!``H```#"$@$`"0``
M`,T2`0`+````UQ(!``T```#C$@$`#````/$2`0`.````_A(!``4````-$P$`
M!````!,3`0`-````&!,!`#(````F$P$`10```%D3`0`7````GQ,!``<```"W
M$P$`'@```+\3`0`4````WA,!``4```#S$P$`%````/D3`0`&````#A0!``<`
M```5%`$`(P```!T4`0`.````010!`"H```!0%`$`!@```'L4`0`,````@A0!
M``T```"/%`$`$0```)T4`0`7````KQ0!``L```#'%`$`-@```-,4`0`*````
M"A4!`"(````5%0$`"P```#@5`0`/````1!4!``L```!4%0$`(````&`5`0`G
M````@14!`"L```"I%0$`"0```-45`0`R````WQ4!`"4````2%@$`,````#@6
M`0`Q````:18!`"T```";%@$`#@```,D6`0`4````V!8!``4```#M%@$`#@``
M`/,6`0`3`````A<!`!(````6%P$`!P```"D7`0`1````,1<!`!,```!#%P$`
M!P```%<7`0`4````7Q<!`!@```!T%P$`!P```(T7`0`%````E1<!``P```";
M%P$`#````*@7`0`2````M1<!``0```#(%P$`!P```,T7`0`*````U1<!``L`
M``#@%P$`#````.P7`0`.````^1<!``X````(&`$`!0```!<8`0`%````'1@!
M`"X````C&`$`)@```%(8`0`C````>1@!``,```"=&`$`$@```*$8`0`&````
MM!@!`!X```"[&`$`&````-H8`0`E````\Q@!``T````9&0$`"0```"<9`0`?
M````,1D!``,```!1&0$`!P```%49`0`*````71D!``(```!H&0$`#````&L9
M`0`5````>!D!``L```".&0$`&0```)H9`0`@````M!D!`!(```#5&0$`!0``
M`.@9`0`*````[AD!`!4```#Y&0$`$@````\:`0`,````(AH!``0````O&@$`
M"0```#0:`0`'````/AH!``P```!&&@$`4@```%,:`0`7````IAH!`"0```"^
M&@$`$@```.,:`0`'````]AH!``8```#^&@$`#@````4;`0`,````%!L!``T`
M```A&P$`%0```"\;`0`2````11L!``\```!8&P$`%````&@;`0`*````?1L!
M`!L```"(&P$`$````*0;`0`+````M1L!`&D```#!&P$`&@```"L<`0`7````
M1AP!`"<```!>'`$`&@```(8<`0`7````H1P!`!L```"Y'`$`&0```-4<`0`?
M````[QP!`!<````/'0$`$P```"<=`0`(````.QT!``<```!$'0$`"````$P=
M`0`)````51T!`!4```!?'0$`#0```'4=`0`C````@QT!``T```"G'0$`$P``
M`+4=`0`(````R1T!``,```#2'0$`1@```-8=`0`_````'1X!`#<```!='@$`
M5P```)4>`0`%````[1X!`!\```#S'@$`+P```!,?`0`*````0Q\!``@```!.
M'P$`#0```%<?`0`M````91\!``0```"3'P$`3P```)@?`0`E````Z!\!`!P`
M```.(`$`"P```"L@`0`?````-R`!`!T```!7(`$`)0```'4@`0`@````FR`!
M`"0```"\(`$`(````.$@`0`+`````B$!``<````.(0$`#0```!8A`0`,````
M)"$!`!<````Q(0$`!@```$DA`0`Y````4"$!``P```"*(0$`!P```)<A`0`)
M````GR$!`!,```"I(0$`!P```+TA`0`)````Q2$!``0```#/(0$`$````-0A
M`0`(````Y2$!``@```#N(0$`!````/<A`0`+````_"$!``P````((@$`$@``
M`!4B`0`1````*"(!``P````Z(@$`&@```$<B`0`/````8B(!``<```!R(@$`
M#0```'HB`0`4````B"(!``X```"=(@$`#````*PB`0`L````N2(!`!,```#F
M(@$`'````/HB`0`H````%R,!``8```!`(P$`!P```$<C`0`3````3R,!``4`
M``!C(P$`!````&DC`0`7````;B,!``H```"&(P$`#````)$C`0`)````GB,!
M``8```"H(P$`"0```*\C`0`(````N2,!``D```#"(P$`!0```,PC`0`*````
MTB,!`!$```#=(P$`!@```.\C`0`.````]B,!``X````%)`$`#0```!0D`0`+
M````(B0!`!T````N)`$`"P```$PD`0`"````6"0!`!P```!;)`$`!P```'@D
M`0`&````@"0!`&0```"')`$`"0```.PD`0`'````]B0!`"8```#^)`$`.```
M`"4E`0`:````7B4!`"H```!Y)0$`.P```*0E`0`H````X"4!`#0````))@$`
M&0```#XF`0`5````6"8!``4```!N)@$`!P```'0F`0`(````?"8!``<```"%
M)@$`!0```(TF`0`'````DR8!``X```";)@$`"0```*HF`0`&````M"8!``@`
M``"[)@$`"P```,0F`0`'````T"8!``@```#8)@$`!P```.$F`0`6````Z28!
M``D`````)P$`!@````HG`0`+````$2<!`!`````=)P$`!@```"XG`0`<````
M-2<!`!0```!2)P$`!P```&<G`0`1````;R<!``@```"!)P$`#@```(HG`0`(
M````F2<!``4```"B)P$`$````*@G`0`)````N2<!`!````##)P$`!@```-0G
M`0`9````VR<!``H```#U)P$`'``````H`0`'````'2@!``4````E*`$`!```
M`"LH`0`0````,"@!`!0```!!*`$`"P```%8H`0`-````8B@!`"@```!P*`$`
M&````)DH`0`7````LB@!`!H```#**`$`%````.4H`0`$````^B@!``D```#_
M*`$`"@````DI`0`'````%"D!``(````<*0$`#@```!\I`0`(````+BD!`!\`
M```W*0$`(P```%<I`0`C````>RD!`!\```"?*0$`.````+\I`0`F````^"D!
M`#$````?*@$`)P```%$J`0!D````>2H!`!0```#>*@$`'````/,J`0!5````
M$"L!`#@```!F*P$`2@```)\K`0!;````ZBL!`"@```!&+`$`.````&\L`0`J
M````J"P!`"@```#3+`$`+````/PL`0`G````*2T!`"8```!1+0$`&P```'@M
M`0`^````E"T!`",```#3+0$`%P```/<M`0`9````#RX!`$@````I+@$`A0``
M`'(N`0`P````^"X!`"4````I+P$`00```$\O`0!;````D2\!`$D```#M+P$`
M,0```#<P`0`=````:3`!`!@```"',`$`*P```*`P`0`A````S#`!`!\```#N
M,`$`*P````XQ`0`F````.C$!`"$```!A,0$`*0```(,Q`0`G````K3$!`#H`
M``#5,0$`'0```!`R`0`1````+C(!`#,```!`,@$`)0```'0R`0`X````FC(!
M`"<```#3,@$`(````/LR`0`?````'#,!`#`````\,P$`:0```&TS`0`Q````
MUS,!`$$````)-`$`,P```$LT`0`E````?S0!`#T```"E-`$`90```.,T`0!-
M````234!`"\```"7-0$`+@```,<U`0`K````]C4!`#`````B-@$`*@```%,V
M`0`^````?C8!`%0```"]-@$`6@```!(W`0!(````;3<!`$H```"V-P$`,@``
M``$X`0`=````-#@!`",```!2.`$`+P```'8X`0`L````IC@!`"T```#3.`$`
M<0````$Y`0!F````<SD!`&\```#:.0$`LP```$HZ`0`7````_CH!`"4````6
M.P$`,@```#P[`0`I````;SL!`#X```"9.P$`(@```-@[`0!2````^SL!`"4`
M``!./`$`"P```'0\`0!%````@#P!`"$```#&/`$`,````.@\`0`E````&3T!
M`!P````_/0$`,0```%P]`0`'````CCT!``<```"6/0$`!````)X]`0`-````
MHST!``L```"Q/0$`#@```+T]`0`+````S#T!``4```#8/0$`$````-X]`0`"
M````[ST!`%D```#R/0$`!0```$P^`0`2````4CX!``0```!E/@$`!P```&H^
M`0`(````<CX!``4```![/@$``P```($^`0`0````A3X!``P```"6/@$`$P``
M`*,^`0`-````MSX!``(```#%/@$`!P```,@^`0`&````T#X!`!0```#7/@$`
M#````.P^`0`8````^3X!``8````2/P$`$@```!D_`0`,````+#\!``,````Y
M/P$`*@```#T_`0`$````:#\!``8```!M/P$`!P```'0_`0`?````?#\!`#4`
M``"</P$`+@```-(_`0`O`````4`!`!<````Q0`$`'P```$E``0`B````:4`!
M`"4```",0`$`(````+)``0`;````TT`!`!@```#O0`$`)`````A!`0`?````
M+4$!`!H```!-00$`(0```&A!`0`@````BD$!`!H```"K00$`,@```,9!`0`:
M````^4$!`"\````40@$`*P```$1"`0`?````<$(!`",```"00@$`'P```+1"
M`0`:````U$(!`"$```#O0@$`)0```!%#`0`F````-T,!`"4```!>0P$`)```
M`(1#`0`8````J4,!`!T```#"0P$`)````.!#`0`8````!40!`"(````>1`$`
M+````$%$`0`O````;D0!`!4```">1`$`)0```+1$`0`\````VD0!`!\````7
M10$`(P```#=%`0`?````6T4!`"````![10$`&@```)Q%`0`8````MT4!`"8`
M``#010$`'@```/=%`0`I````%D8!`!X```!`1@$`,0```%]&`0`)````D48!
M``P```";1@$`%P```*A&`0`O````P$8!`"0```#P1@$`!P```!5'`0`?````
M'4<!``\````]1P$`%````$U'`0`.````8D<!``T```!Q1P$`)````']'`0`%
M````I$<!``<```"J1P$`(@```+)'`0`E````U4<!`!H```#[1P$`'0```!9(
M`0`:````-$@!``<```!/2`$`QP```%=(`0`+````'TD!`!4````K20$`!@``
M`$%)`0`)````2$D!`!@```!220$`"P```&M)`0`-````=TD!`!<```"%20$`
M!@```)U)`0`S````I$D!`!,```#820$`$P```.Q)`0`'`````$H!``\````(
M2@$`!P```!A*`0`R````($H!``0```!32@$`(0```%A*`0`3````>DH!``P`
M``".2@$`$0```)M*`0`R````K4H!`!8```#@2@$`"````/=*`0`=`````$L!
M``D````>2P$`"@```"A+`0`4````,TL!``H```!(2P$`'0```%-+`0`(````
M<4L!`!\```!Z2P$`"````)I+`0`:````HTL!`"<```"^2P$`!@```.9+`0`5
M````[4L!``<````#3`$`"`````M,`0`)````%$P!`#\````>3`$`!P```%Y,
M`0`/````9DP!``X```!V3`$`$````(5,`0`)````EDP!``D```"@3`$`"```
M`*I,`0`3````LTP!``<```#'3`$`&0```,],`0`*````Z4P!``H```#T3`$`
M"0```/],`0`7````"4T!`!0````A30$`"@```#9-`0`,````04T!`!<```!.
M30$`!````&9-`0`J````:TT!``P```"630$`$0```*--`0`'````M4T!``(`
M``"]30$`$````,!-`0`8````T4T!``L```#J30$``P```/9-`0`(````^DT!
M`!,````#3@$`%P```!=.`0`&````+TX!``<````V3@$`#0```#Y.`0`+````
M3$X!`!0```!83@$`%0```&U.`0`.````@TX!`"\```"23@$`(````,).`0`<
M````XTX!`!4`````3P$`#````!9/`0`Q````(T\!``4```!53P$`$@```%M/
M`0`_````;D\!`!(```"N3P$`"@```,%/`0`&````S$\!``0```#33P$`!```
M`-A/`0`*````W4\!`!,```#H3P$`!0```/Q/`0`&`````E`!``8````)4`$`
M"````!!0`0`$````&5`!``P````>4`$`"@```"M0`0`Y````-E`!`"X```!P
M4`$`*0```)]0`0`%````R5`!`!D```#/4`$`$0```.E0`0`"````^U`!``0`
M``#^4`$`"@````-1`0`&````#E$!``4````540$``P```!M1`0`,````'U$!
M`$4````L40$`,@```')1`0`:````I5$!`#4```#`40$`-````/91`0`H````
M*U(!`!D```!44@$`<@```&Y2`0`@````X5(!`#4````"4P$`(0```#A3`0!%
M````6E,!`#````"@4P$`*````-%3`0`I````^E,!`"8````D5`$`)0```$M4
M`0`H````<50!`"@```":5`$`(@```,-4`0`K````YE0!`#`````250$`$@``
M`$-5`0`3````5E4!`!````!J50$`>0```'M5`0`)````]54!`*$```#_50$`
M<P```*%6`0!\````%5<!`"L```"25P$`5````+Y7`0`7````$U@!`"<````K
M6`$`%@```%-8`0`/````:E@!`!<```!Z6`$`'P```))8`0!`````LE@!`!\`
M``#S6`$`'````!-9`0!1````,%D!`!H```""60$`%````)U9`0`*````LED!
M``4```"]60$`!@```,-9`0`(````RED!``4```#360$`$@```-E9`0`0````
M[%D!`!,```#]60$`'0```!%:`0`/````+UH!``\````_6@$`!````$]:`0`)
M````5%H!``L```!>6@$`!P```&I:`0`%````<EH!`!0```!X6@$`!P```(U:
M`0`(````E5H!``\```">6@$`"````*Y:`0`,````MUH!``\```#$6@$`!@``
M`-1:`0`4````VUH!``8```#P6@$`#````/=:`0`1````!%L!``@````66P$`
M!````!];`0`9````)%L!`!$````^6P$`"@```%!;`0`%````6UL!`!@```!A
M6P$`$P```'I;`0`<````CEL!`!$```"K6P$`!````+U;`0`/````PEL!``<`
M``#26P$`!````-I;`0`9````WUL!``<```#Y6P$``@````%<`0`"````!%P!
M`!$````'7`$`"0```!E<`0`&````(UP!`!(````J7`$`%P```#U<`0`&````
M55P!`"<```!<7`$``@```(1<`0`$````AUP!``\```",7`$`$P```)Q<`0`'
M````L%P!``<```"X7`$`$0```,!<`0`&````TEP!`!@```#97`$`!@```/)<
M`0`3````^5P!`!`````-70$`$@```!Y=`0`"````,5T!``8````T70$`#```
M`#M=`0`)````2%T!`!$```!270$`(@```&1=`0`'````AUT!``<```"/70$`
M"P```)==`0`%````HUT!``(```"I70$`"P```*Q=`0!B`0``N%T!`$P````;
M7P$`$0```&A?`0`2````>E\!``\```"-7P$`#@```)U?`0`'````K%\!``H`
M``"T7P$`!P```+]?`0`$````QU\!`!@```#,7P$`'0```.5?`0`L`````V`!
M`!T````P8`$`(````$Y@`0`F````;V`!`!<```"68`$`*````*Y@`0`,````
MUV`!`"L```#D8`$`#@```!!A`0`1````'V$!`!(````Q80$`!0```$1A`0`C
M````2F$!``@```!N80$`"@```'=A`0`3````@F$!``\```"680$`"P```*9A
M`0`5````LF$!`$,```#(80$`(@````QB`0`Q````+V(!`&\```!A8@$`"```
M`-%B`0`*````VF(!``H```#E8@$`-P```/!B`0`B````*&,!`!````!+8P$`
M&P```%QC`0`@````>&,!`#````"98P$`$````,IC`0`/````VV,!`!,```#K
M8P$`$````/]C`0`&````$&0!`(D````79`$`"P```*%D`0`1````K60!`!T`
M``"_9`$`"@```-UD`0`0````Z&0!`!````#Y9`$`"0````IE`0`+````%&4!
M`"P````@90$`'````$UE`0`[````:F4!`$4```"F90$`5@```.QE`0!3````
M0V8!`%D```"79@$`5@```/%F`0`^````2&<!``X```"'9P$`$P```)9G`0`.
M````JF<!`!````"Y9P$`&````,IG`0`%````XV<!``8```#I9P$`"@```/!G
M`0`%````^V<!``8````!:`$`!@````AH`0`1````#V@!``H````A:`$`)0``
M`"QH`0`D````4F@!`!````!W:`$`$@```(AH`0`,````FV@!``8```"H:`$`
M"````*]H`0`)````N&@!``P```#":`$`%````,]H`0`9````Y&@!``X```#^
M:`$`$@````UI`0`7````(&D!`!X````X:0$`(P```%=I`0`:````>VD!`!``
M``"6:0$`%P```*=I`0`-````OVD!`"H```#-:0$`&````/AI`0`6````$6H!
M`!D````H:@$`$P```$)J`0!/````5FH!`#$```"F:@$`)````-AJ`0`&````
M_6H!``D````$:P$`-`````YK`0`.````0VL!``8```!2:P$`"@```%EK`0`(
M````9&L!``@```!M:P$`!0```'9K`0`'````?&L!``H```"$:P$`!````(]K
M`0`<````E&L!``P```"Q:P$`$0```+YK`0`/````T&L!`!4```#@:P$`)@``
M`/9K`0`+````'6P!`!H````I;`$`'0```$1L`0`A````8FP!`!@```"$;`$`
M#P```)UL`0`0````K6P!`!$```"^;`$`+P```-!L`0`;`````&T!`!L````<
M;0$`!P```#AM`0`&````0&T!``@```!';0$`#````%!M`0`$````76T!``D`
M``!B;0$`$P```&QM`0`+````@&T!`!$```",;0$`%@```)YM`0`?````M6T!
M``<```#5;0$`$@```-UM`0`%````\&T!`!8```#V;0$`#P````UN`0`,````
M'6X!`#$````J;@$`0@```%QN`0`)````GVX!``@```"I;@$`%````+)N`0`%
M````QVX!``4```#-;@$`$````--N`0`+````Y&X!`!D```#P;@$`.P````IO
M`0`2````1F\!`$8```!9;P$`+P```*!O`0`T````T&\!`"X````%<`$`+0``
M`#1P`0`)````8G`!``@```!L<`$`!P```'5P`0`*````?7`!``D```"(<`$`
M(P```))P`0`T````MG`!`"(```#K<`$`1@````YQ`0`A````57$!`"$```!W
M<0$`0P```)EQ`0!"````W7$!`!\````@<@$`0````$!R`0`G````@7(!`"H`
M``"I<@$`0P```-1R`0`A````&',!`"<````Z<P$`+````&)S`0`:````CW,!
M`!X```"J<P$`*@```,ES`0`K````]',!`"L````@=`$`$@```$QT`0`.````
M7W0!``H```!N=`$`!P```'ET`0`-````@70!``@```"/=`$`#0```)AT`0`?
M````IG0!`",```#&=`$`!P```.IT`0`'````\G0!`!4```#Z=`$`"@```!!U
M`0`&````&W4!``8````B=0$`"````"EU`0`&````,G4!`"D````Y=0$`"```
M`&-U`0`+````;'4!``<```!X=0$`!@```(!U`0`%````AW4!``<```"-=0$`
M!@```)5U`0`*````G'4!`"<```"G=0$`$@```,]U`0`(````XG4!``@```#K
M=0$`#@```/1U`0`#`````W8!``<````'=@$`"0````]V`0`#````&78!``D`
M```==@$`!0```"=V`0`7````+78!``0```!%=@$`"````$IV`0`&````4W8!
M``T```!:=@$`"0```&AV`0`G````<G8!``0```":=@$`!@```)]V`0`)````
MIG8!``H```"P=@$`#````+MV`0`,````R'8!``<```#5=@$``P```-UV`0`#
M````X78!`!<```#E=@$`%@```/UV`0`D````%'<!``@````Y=P$`!0```$)W
M`0`(````2'<!``<```!1=P$`"@```%EW`0!%````9'<!`!T```"J=P$`.```
M`,AW`0`B`````7@!`!<````D>`$`!@```#QX`0`&````0W@!`!4```!*>`$`
M%0```&!X`0`?````=G@!`"L```"6>`$`&@```,)X`0`C````W7@!`#$````!
M>0$`"0```#-Y`0`&````/7D!``@```!$>0$`%P```$UY`0`.````97D!``P`
M``!T>0$`$0```(%Y`0`.````DWD!`!$```"B>0$`#@```+1Y`0`,````PWD!
M`!4```#0>0$`"0```.9Y`0`<````\'D!`!T````->@$`$@```"MZ`0`/````
M/GH!`!(```!.>@$`!0```&%Z`0`*````9WH!``4```!R>@$`$P```'AZ`0`7
M````C'H!`%4```"D>@$`8@```/IZ`0`#````77L!`!,```!A>P$`*0```'5[
M`0`%````GWL!``0```"E>P$`'````*I[`0`>````QWL!`!$```#F>P$`#0``
M`/A[`0`1````!GP!``P````8?`$`&P```"5\`0`D````07P!``4```!F?`$`
M'@```&Q\`0`%````BWP!`!4```"1?`$`"P```*=\`0`3````LWP!``\```#'
M?`$`$@```-=\`0`3````ZGP!`!@```#^?`$`$P```!=]`0`-````*WT!``0`
M```Y?0$`"P```#Y]`0`(````2GT!`!<```!3?0$`%0```&M]`0`2````@7T!
M``@```"4?0$`!````)U]`0`-````HGT!``<```"P?0$`"0```+A]`0`/````
MPGT!``L```#2?0$`"````-Y]`0`/````YWT!``D```#W?0$`!`````%^`0`'
M````!GX!``<````.?@$`"````!9^`0`5````'WX!``<````U?@$`!0```#U^
M`0`%````0WX!`!@```!)?@$`4````&)^`0`A````LWX!``X```#5?@$`$0``
M`.1^`0`%````]GX!``4```#\?@$`&0````)_`0`:````''\!`"P````W?P$`
M-````&1_`0`H````F7\!``D```#"?P$`)0```,Q_`0`B````\G\!``\````5
M@`$`"````"6``0`,````+H`!``8````[@`$`!P```$*``0`:````2H`!`!$`
M``!E@`$`"@```'>``0`+````@H`!``H```".@`$`#P```)F``0`A````J8`!
M`"(```#+@`$`(````.Z``0`A````#X$!`"0````Q@0$`(P```%:!`0`?````
M>H$!`"8```":@0$`(0```,&!`0`D````XX$!`"D````(@@$`)0```#*"`0`=
M````6((!`!X```!V@@$`(````)6"`0`;````MH(!`"8```#2@@$`+0```/F"
M`0`K````)X,!`"(```!3@P$`*P```':#`0`W````HH,!`!T```#:@P$`'0``
M`/B#`0`9````%H0!`!D````PA`$`,````$J$`0`A````>X0!`!(```"=A`$`
M(0```+"$`0`H````TH0!`!H```#[A`$`&````!:%`0`>````+X4!`!$```!.
MA0$`M@```&"%`0`2````%X8!`!P````JA@$`)0```$>&`0`F````;88!`"``
M``"4A@$`)````+6&`0`:````VH8!`!H```#UA@$`)````!"'`0`D````-8<!
M`"L```!:AP$`+````(:'`0`G````LX<!`(P```#;AP$`'P```&B(`0`5````
MB(@!`!4```">B`$`'@```+2(`0`I````TX@!`"D```#]B`$`1````">)`0!$
M````;(D!``L```"QB0$`!````+V)`0`&````PHD!``4```#)B0$`"@```,^)
M`0`(````VHD!``\```#CB0$`%@```/.)`0`1````"HH!``@````<B@$`!```
M`"6*`0`0````*HH!``\````[B@$`"P```$N*`0`.````5XH!`!````!FB@$`
M#@```'>*`0`2````AHH!``P```"9B@$`-@```*:*`0`(````W8H!``L```#F
MB@$`!@```/**`0`2````^8H!`!@````,BP$`&P```"6+`0`(````08L!``(`
M``!*BP$`!@```$V+`0`2````5(L!``X```!GBP$`!0```':+`0`.````?(L!
M``@```"+BP$``P```)2+`0`.````F(L!``@```"GBP$`"0```+"+`0`&````
MNHL!``T```#!BP$`!P```,^+`0`,````UXL!`!$```#DBP$`#````/:+`0`,
M`````XP!`!$````0C`$`"0```"*,`0`&````+(P!``L````SC`$`#````#^,
M`0`+````3(P!`!$```!8C`$`'````&J,`0`+````AXP!``T```"3C`$`'P``
M`*&,`0`4````P8P!`!H```#6C`$`,0```/&,`0`*````(XT!`!4````NC0$`
M$@```$2-`0`5````5XT!`!(```!MC0$`%0```("-`0`D````EHT!``L```"[
MC0$`!P```,>-`0`-````SXT!`"L```#=C0$`$0````F.`0`+````&XX!`"(`
M```GC@$`+P```$J.`0`*````>HX!``D```"%C@$`'@```(^.`0`+````KHX!
M`!L```"ZC@$`&P```-:.`0`'````\HX!`!<```#ZC@$`%0```!*/`0`<````
M*(\!`!<```!%CP$`#@```%V/`0`*````;(\!``@```!WCP$`"P```("/`0`B
M````C(\!`#D```"OCP$`%P```.F/`0`C`````9`!``4````ED`$`"````"N0
M`0`M````-)`!``H```!BD`$`!@```&V0`0`&````=)`!`%8```![D`$``P``
M`-*0`0`'````UI`!``4```#>D`$`"P```.20`0`+````\)`!`!````#\D`$`
M$@````V1`0`9````()$!`!@````ZD0$`&P```%.1`0`;````;Y$!``H```"+
MD0$`!P```):1`0`+````GI$!``H```"JD0$``@```+61`0`&````N)$!``P`
M``"_D0$`)0```,R1`0`@````\I$!`!8````3D@$`#````"J2`0`0````-Y(!
M``X```!(D@$`$````%>2`0`$````:)(!``<```!MD@$`#P```'62`0`A````
MA9(!`!@```"GD@$``P```,"2`0`=````Q)(!`"P```#BD@$`*P````^3`0`<
M````.Y,!`"D```!8DP$`(P```(*3`0`7````II,!`!H```"^DP$`!P```-F3
M`0`(````X9,!``8```#JDP$`!@```/&3`0`.````^),!``X````'E`$`#P``
M`!:4`0`-````)I0!`!`````TE`$`#P```$64`0`+````590!`!(```!AE`$`
M`P```'24`0`)````>)0!`!(```""E`$`#@```)64`0`O````I)0!``T```#4
ME`$`"````.*4`0`-````ZY0!`"````#YE`$`)0```!J5`0`F````0)4!`"4`
M``!GE0$`(P```(V5`0`C````L94!`"L```#5E0$`(@````&6`0`:````))8!
M``,````_E@$`#@```$.6`0`(````4I8!``L```!;E@$``P```&>6`0`%````
M:Y8!``@```!QE@$`"0```'J6`0`+````A)8!``\```"0E@$`$@```*"6`0`*
M````LY8!``X```"^E@$`#@```,V6`0`$````W)8!``,```#AE@$`$P```.66
M`0`5````^98!``P````/EP$`!P```!R7`0`&````))<!``X````KEP$`&@``
M`#J7`0`&````59<!``<```!<EP$`#0```&27`0`.````<I<!`!<```"!EP$`
M"````)F7`0`#````HI<!`"4```"FEP$`#0```,R7`0!.````VI<!`!0````I
MF`$`"````#Z8`0`*````1Y@!`!$```!2F`$`"@```&28`0`,````;Y@!``4`
M``!\F`$`#@```(*8`0`"````D9@!``4```"4F`$`"0```)J8`0`3````I)@!
M`!H```"XF`$`$P```-.8`0`8````YY@!`"``````F0$`#@```"&9`0`2````
M,)D!`!D```!#F0$`!````%V9`0`)````8ID!`!<```!LF0$`"````(29`0`1
M````C9D!``4```"?F0$`&````*69`0`(````OID!``8```#'F0$`'0```,Z9
M`0`-````[)D!``@```#ZF0$`"`````.:`0`%````#)H!``D````2F@$`!P``
M`!R:`0`5````))H!``(````ZF@$`!@```#V:`0`,````1)H!``T```!1F@$`
M"````%^:`0`4````:)H!``0```!]F@$`"````(*:`0`'````BYH!``,```"3
MF@$`$P```)>:`0`]````JYH!`"8```#IF@$`*0```!";`0`'````.IL!``0`
M``!"FP$`"0```$>;`0`(````49L!`!````!:FP$`$P```&N;`0`'````?YL!
M``8```"'FP$`#0```(Z;`0`&````G)L!``0```"CFP$`,0```*B;`0`V````
MVIL!`#,````1G`$`&@```$6<`0`%````8)P!``P```!FG`$`!0```'.<`0`&
M````>9P!``@```"`G`$`&````(F<`0`2````HIP!`!<```"UG`$`!````,V<
M`0`-````TIP!``4```#@G`$`$0```.:<`0`-````^)P!``@````&G0$`%P``
M``^=`0`#````)YT!``0````KG0$``P```#"=`0`+````-)T!``H```!`G0$`
M#````$N=`0`(````6)T!``D```!AG0$`!0```&N=`0`]````<9T!`#$```"O
MG0$`/P```.&=`0`=````(9X!`$$````_G@$`-P```(&>`0`H````N9X!`#D`
M``#BG@$`+@```!R?`0`R````2Y\!`"$```!^GP$`$0```*"?`0`5````LI\!
M``P```#(GP$`+P```-6?`0`D````!:`!`"0````JH`$`(P```$^@`0`)````
M<Z`!``H```!]H`$`"@```(B@`0`&````DZ`!`"4```":H`$`)@```,"@`0`P
M````YZ`!``D````8H0$`'@```"*A`0`J````0:$!`!H```!LH0$`$````(>A
M`0`&````F*$!``T```"?H0$`#0```*VA`0`/````NZ$!`!(```#+H0$`.P``
M`-ZA`0"1````&J(!`&0```"LH@$`%0```!&C`0`*````)Z,!``L````RHP$`
M$0```#ZC`0`2````4*,!``X```!CHP$`!@```'*C`0`2````>:,!`!0```",
MHP$`$0```*&C`0`(````LZ,!`!$```"\HP$`)````,ZC`0`J````\Z,!`&X`
M```>I`$`"@```(VD`0`&````F*0!`!8```"?I`$`"@```+:D`0`$````P:0!
M``L```#&I`$`)P```-*D`0`4````^J0!``L````/I0$`#0```!NE`0`/````
M*:4!`!,````YI0$`)0```$VE`0`D````<Z4!`!P```"8I0$`'@```+6E`0`A
M````U*4!`"````#VI0$`%@```!>F`0`1````+J8!`!````!`I@$`$P```%&F
M`0`2````9:8!`!(```!XI@$`%0```(NF`0`4````H:8!`!````"VI@$`#P``
M`,>F`0`I````UZ8!`!$````!IP$`$0```!.G`0`[````):<!`!0```!AIP$`
M!@```':G`0`,````?:<!`"<```"*IP$`(0```+*G`0`6````U*<!`!4```#K
MIP$`$@````&H`0`6````%*@!`!P````KJ`$`$P```$BH`0`5````7*@!`!H`
M``!RJ`$`&````(VH`0`=````IJ@!`"$```#$J`$`(0```.:H`0`5````"*D!
M`!0````>J0$`%````#.I`0`8````2*D!`!H```!AJ0$`&````'RI`0`6````
ME:D!``L```"LJ0$`#P```+BI`0`$````R*D!``0```#-J0$`!@```-*I`0`+
M````V:D!`!$```#EJ0$`!@```/>I`0`+````_JD!``8````*J@$`!P```!&J
M`0`'````&:H!``<````AJ@$`!0```"FJ`0`5````+ZH!``8```!%J@$`"0``
M`$RJ`0`$````5JH!``0```!;J@$`!P```&"J`0`-````:*H!``P```!VJ@$`
M#@```(.J`0`,````DJH!``4```"?J@$`*0```*6J`0`-````SZH!``L```#=
MJ@$`"P```.FJ`0`)````]:H!`!````#_J@$`,````!"K`0`$````0:L!``@`
M``!&JP$`!0```$^K`0`)````5:L!``@```!?JP$`$0```&BK`0`&````>JL!
M``D```"!JP$`!P```(NK`0`%````DZL!``0```"9JP$`#````)ZK`0`1````
MJZL!``\```"]JP$`$@```,VK`0`6````X*L!`!X```#WJP$`&@```!:L`0`(
M````,:P!``@````ZK`$``P```$.L`0`&````1ZP!`"4```!.K`$`!P```'2L
M`0`'````?*P!``T```"$K`$`#0```)*L`0`'````H*P!``0```"HK`$`!P``
M`*VL`0`&````M:P!``T```"\K`$`!P```,JL`0`(````TJP!``D```#;K`$`
M$P```.6L`0`5````^:P!``T````/K0$`$@```!VM`0`(````,*T!``P````Y
MK0$`"````$:M`0`$````3ZT!`!````!4K0$`0@```&6M`0`&````J*T!``0`
M``"OK0$`'P```+2M`0`.````U*T!``\```#CK0$`#@```/.M`0`,`````JX!
M``D````/K@$`!P```!FN`0`*````(:X!``D````LK@$`#@```#:N`0`0````
M1:X!`"4```!6K@$`)0```'RN`0`B````HJX!``H```#%K@$`!P```-"N`0`)
M````V*X!``L```#BK@$`"0```.ZN`0`%````^*X!``@```#^K@$`"`````>O
M`0`%````$*\!`!`````6KP$`3@```">O`0`8````=J\!``D```"/KP$`!@``
M`)FO`0`#````H*\!`!````"DKP$`$````+6O`0`4````QJ\!``8```#;KP$`
M"@```.*O`0`)````[:\!``(```#WKP$`!````/JO`0`C````_Z\!``,````C
ML`$`!0```">P`0`*````+;`!``H````XL`$`!@```$.P`0`&````2K`!``L`
M``!1L`$`#0```%VP`0`&````:[`!``@```!RL`$`"@```'NP`0`$````AK`!
M``4```"+L`$`=@```)&P`0`+````"+$!``X````4L0$`%P```".Q`0`$````
M.[$!``@```!`L0$`%0```$FQ`0`O````7[$!``T```"/L0$`"@```)VQ`0`.
M````J+$!``L```"WL0$`"0```,.Q`0`4````S;$!`#,```#BL0$`*````!:R
M`0`G````/[(!`!H```!GL@$`#0```(*R`0`#````D+(!``<```"4L@$`!P``
M`)RR`0`+````I+(!`!````"PL@$`#@```,&R`0`)````T+(!`!````#:L@$`
M&P```.NR`0`)````![,!``D````1LP$`#P```!NS`0`*````*[,!`$T````V
MLP$`'@```(2S`0`-````H[,!``H```"QLP$`(0```+RS`0!,````WK,!`!D`
M```KM`$`!0```$6T`0`?````2[0!`"X```!KM`$`!P```)JT`0`&````HK0!
M``L```"IM`$`!@```+6T`0`'````O+0!`"<```#$M`$`)@```.RT`0`J````
M$[4!``8````^M0$`!P```$6U`0`O````3;4!`%4```!]M0$`%0```-.U`0`G
M````Z;4!`!,````1M@$``@```"6V`0`,````*+8!``@````UM@$`#````#ZV
M`0`*````2[8!``<```!6M@$`"0```%ZV`0`&````:+8!``D```!OM@$`#```
M`'FV`0`(````AK8!``D```"/M@$`"````)FV`0`R````HK8!``<```#5M@$`
M#P```-VV`0`1````[;8!`!````#_M@$`"@```!"W`0`.````&[<!``P````J
MMP$`"@```#>W`0`*````0K<!``H```!-MP$`"@```%BW`0`'````8[<!``X`
M``!KMP$`'````'JW`0`'````E[<!``H```"?MP$`%````*JW`0`*````O[<!
M`!````#*MP$`!P```-NW`0`8````X[<!``0```#\MP$`!P````&X`0`%````
M";@!``0````/N`$`#@```!2X`0`%````([@!``T````IN`$`%P```#>X`0`/
M````3[@!`!8```!?N`$`&0```':X`0`7````D+@!`!P```"HN`$`%@```,6X
M`0`'````W+@!``8```#DN`$`#@```.NX`0`+````^K@!`!<````&N0$`!@``
M`!ZY`0`<````);D!``L```!"N0$`#0```$ZY`0`B````7+D!`!H```!_N0$`
M%0```)JY`0`'````L+D!``T```"XN0$`!0```,:Y`0`0````S+D!`!,```#=
MN0$`!@```/&Y`0`)````^+D!``4````"N@$`!P````BZ`0`$````$+H!``0`
M```5N@$``P```!JZ`0`[````'KH!`#,```!:N@$`$@```(ZZ`0`O````H;H!
M`#(```#1N@$`#@````2[`0`\````$[L!`"\```!0NP$`-````("[`0`T````
MM;L!`#@```#JNP$`$@```".\`0`3````-KP!`!@```!*O`$`$P```&.\`0`5
M````=[P!`!(```"-O`$`$@```*"\`0`;````L[P!`!,```#/O`$`%0```..\
M`0`:````^;P!`"X````4O0$`+@```$.]`0`R````<KT!`"\```"EO0$`,```
M`-6]`0`M````!KX!`!T````TO@$`$P```%*^`0`4````9KX!``L```![O@$`
M&0```(>^`0`*````H;X!``\```"LO@$`+````+R^`0`N````Z;X!`"(````8
MOP$`"P```#N_`0!5````1[\!`$8```"=OP$`#@```.2_`0`%````\[\!`!P`
M``#YOP$`#````!;``0`0````(\`!`!(````TP`$`!0```$?``0`*````3<`!
M``D```!8P`$`#P```&+``0`1````<L`!``H```"$P`$`"P```(_``0`,````
MF\`!`"````"HP`$``P```,G``0`(````S<`!``8```#6P`$`#````-W``0`.
M````ZL`!``L```#YP`$`0@````7!`0`"````2,$!``8```!+P0$`#0```%+!
M`0`%````8,$!``<```!FP0$`&0```&[!`0`&````B,$!`"X```"/P0$`$```
M`+[!`0`=````S\$!``0```#MP0$`*@```/+!`0`<````'<(!`"`````ZP@$`
M60```%O"`0`4````M<(!`$<```#*P@$`&0```!+#`0`.````+,,!`!P````[
MPP$`#0```%C#`0`4````9L,!``X```![PP$`#````(K#`0`2````E\,!``H`
M``"JPP$`'````+7#`0`9````TL,!``4```#LPP$`$P```/+#`0`0````!L0!
M`"8````7Q`$`$P```#[$`0`5````4L0!`!(```!HQ`$`$0```'O$`0`9````
MC<0!``<```"GQ`$`"````*_$`0`3````N,0!``X```#,Q`$`$@```-O$`0`/
M````[L0!`!H```#^Q`$`#P```!G%`0`:````*<4!`!0```!$Q0$`"0```%G%
M`0`*````8\4!``@```!NQ0$`!0```'?%`0`)````?<4!``8```"'Q0$`$```
M`([%`0`(````G\4!``X```"HQ0$`"````+?%`0`2````P,4!`!(```#3Q0$`
M*````.;%`0`8````#\8!``D````HQ@$`"@```#+&`0`9````/<8!``H```!7
MQ@$`(@```&+&`0`&````A<8!`!@```",Q@$`"0```*7&`0`'````K\8!`!H`
M``"WQ@$`*P```-+&`0`*````_L8!`!\````)QP$`#0```"G'`0`,````-\<!
M`!D```!$QP$`%0```%['`0`$````=,<!``<```!YQP$`#````(''`0`'````
MCL<!``4```"6QP$`"````)S'`0`&````I<<!``@```"LQP$`&````+7'`0`F
M````SL<!`"T```#UQP$`&@```"/(`0`@````/L@!`!\```!?R`$`1````'_(
M`0`<````Q,@!`!T```#AR`$`)````/_(`0!;````),D!`%L```"`R0$`2@``
M`-S)`0`B````)\H!`!<```!*R@$`!0```&+*`0`'````:,H!``X```!PR@$`
M"````'_*`0`7````B,H!`!D```"@R@$`+@```+K*`0`(````Z<H!`"(```#R
MR@$`&````!7+`0`?````+LL!`#L```!.RP$`!0```(K+`0`5````D,L!``L`
M``"FRP$`#P```+++`0`C````PLL!`!@```#FRP$`$0```/_+`0`.````$<P!
M``<````@S`$`$@```"C,`0`'````.\P!``0```!#S`$`#0```$C,`0`5````
M5LP!`!@```!LS`$`+P```(7,`0`+````M<P!`!$```#!S`$`!0```-/,`0`%
M````V<P!``4```#?S`$`'````.7,`0`+`````LT!``0````.S0$`"P```!/-
M`0`)````'\T!``H````IS0$`#````#3-`0`-````0<T!`!<```!/S0$`"P``
M`&?-`0`#````<\T!``\```!WS0$`.0```(?-`0!*````P<T!`!P````,S@$`
M"0```"G.`0`@````,\X!`!,```!4S@$`!0```&C.`0`1````;LX!``@```"`
MS@$`"P```(G.`0`G````E<X!``P```"]S@$`(P```,K.`0`'````[LX!``T`
M``#VS@$`#@````3/`0`3````$\\!`!D````GSP$`"P```$'/`0`S````3<\!
M``<```"!SP$`(````(G/`0`1````JL\!`!4```"\SP$`#0```-+/`0`<````
MX,\!`$$```#]SP$`,P```#_0`0`(````<]`!`#````!\T`$`+````*W0`0`V
M````VM`!`#<````1T0$`,````$G1`0`3````>M$!`!8```".T0$`"0```*71
M`0`2````K]$!`!(```#"T0$`&````-71`0`(````[M$!`!L```#WT0$`$@``
M`!/2`0`'````)M(!`!<````NT@$`(@```$;2`0`%````:=(!``4```!OT@$`
M"P```'72`0`+````@=(!`!0```"-T@$`!````*+2`0`(````I](!``H```"P
MT@$`#@```+O2`0`,````RM(!`!````#7T@$`$````.C2`0`&````^=(!``8`
M````TP$`*P````?3`0`C````,],!`"````!7TP$``P```'C3`0`(````?-,!
M``8```"%TP$`#P```(S3`0`;````G-,!`"<```"XTP$`#P```.#3`0`(````
M\-,!`"$```#YTP$``P```!O4`0`&````']0!``D````FU`$``@```##4`0`,
M````,]0!`!4```!`U`$`"P```%;4`0`9````8M0!`!X```!\U`$`$0```)O4
M`0`%````K=0!``H```"SU`$`%0```+[4`0`2````U-0!``P```#GU`$`!0``
M`/34`0`*````^M0!``@````%U0$`$P````[5`0!,````(M4!`!T```!OU0$`
M)0```(W5`0`1````L]4!``D```#%U0$``P```,_5`0`*````T]4!``H```#>
MU0$`#@```.G5`0`9````^-4!``T````2U@$`"P```"#6`0`=````+-8!``D`
M``!*U@$`%@```%36`0`/````:]8!``H```![U@$`8````(;6`0`:````Y]8!
M`!$````"UP$`'0```!37`0`8````,M<!`!````!+UP$`&````%S7`0`5````
M==<!`!D```"+UP$`'````*77`0`5````PM<!``H```#8UP$`!P```./7`0`(
M````Z]<!``D```#TUP$`%@```/[7`0`+````%=@!`#,````AV`$`%@```%78
M`0`8````;-@!``D```"%V`$`!````(_8`0!)````E-@!`#X```#>V`$`.0``
M`!W9`0!;````5]D!``4```"SV0$`-````+G9`0`E````[MD!``P````4V@$`
M!@```"':`0`.````*-H!`#8````WV@$`!````&[:`0!,````<]H!`"L```#`
MV@$`*0```.S:`0`+````%ML!`"$````BVP$`'@```$3;`0`7````8]L!`!,`
M``![VP$`$P```(_;`0`B````H]L!`!````#&VP$`!@```-?;`0`-````WML!
M``L```#LVP$`$0```/C;`0`)````"MP!`"\````4W`$`#````$3<`0`*````
M4=P!``@```!<W`$`$````&7<`0`'````=MP!``D```!^W`$`!P```(C<`0`0
M````D-P!``D```"AW`$`"0```*O<`0`#````M=P!``<```"YW`$`"0```,'<
M`0`0````R]P!``X```#<W`$`"0```.O<`0`:````]=P!``P````0W0$`!P``
M`!W=`0`1````)=T!`!8````WW0$`"@```$[=`0`)````6=T!`"(```!CW0$`
M$````(;=`0`C````E]T!`"L```"[W0$`"0```.?=`0`)````\=T!`!<```#[
MW0$`!P```!/>`0`$````&]X!`!T````@W@$`"0```#[>`0`+````2-X!``@`
M``!4W@$`!P```%W>`0`)````9=X!``@```!OW@$`"0```'C>`0`%````@MX!
M``<```"(W@$`$0```)#>`0`&````HMX!``X```"IW@$`"@```+C>`0`,````
MP]X!``L```#0W@$`&P```-S>`0`*````^-X!``(````#WP$`(0````;?`0`&
M````*-\!``8````OWP$`<P```#;?`0`(````JM\!``8```"SWP$`&P```+K?
M`0`G````UM\!``\```#^WP$`'0````[@`0!(````+.`!`!P```!UX`$`'P``
M`)+@`0`2````LN`!``@```#%X`$`!0```,[@`0`/````U.`!``H```#DX`$`
M"@```._@`0`&````^N`!``H````!X0$`$@````SA`0`,````'^$!``H````L
MX0$`#````#?A`0`'````1.$!``<```!,X0$`"````%3A`0`)````7>$!`!8`
M``!GX0$`"0```'[A`0`'````B.$!``<```"0X0$`&@```)CA`0`&````L^$!
M`!<```"ZX0$`!@```-+A`0`'````V>$!`!4```#AX0$`"0```/?A`0`0````
M`>(!``<````2X@$`!@```!KB`0`3````(>(!`!$````UX@$`$P```$?B`0`&
M````6^(!``8```!BX@$`"@```&GB`0`(````=.(!``0```!]X@$`"0```(+B
M`0`$````C.(!``T```"1X@$`(@```)_B`0`*````PN(!``P```#-X@$`*0``
M`-KB`0`7````!.,!`!8````<XP$`&P```#/C`0`6````3^,!``0```!FXP$`
M"P```&OC`0`-````=^,!``<```"%XP$``@```(WC`0`.````D.,!``@```"?
MXP$`(@```*CC`0`?````R^,!`",```#KXP$`(`````_D`0`U````,.0!`"$`
M``!FY`$`)P```(CD`0`K````L.0!`&0```#<Y`$`$@```$'E`0`A````5.4!
M`#X```!VY0$`(P```+7E`0!/````V>4!`$@````IY@$`)@```'+F`0`_````
MF>8!`"$```#9Y@$`+P```/OF`0`N````*^<!`"<```!:YP$`)P```(+G`0`A
M````JN<!`#8```#,YP$`&P````/H`0`1````'^@!`!8````QZ`$`2P```$CH
M`0!P````E.@!`#@````%Z0$`*@```#[I`0`U````:>D!`&(```"?Z0$`5```
M``+J`0`K````5^H!`!P```"#Z@$`#P```*#J`0`A````L.H!`!8```#2Z@$`
M%0```.GJ`0`M````_^H!`!P````MZP$`&P```$KK`0`M````9NL!`!T```"4
MZP$`/0```++K`0`9````\.L!``T````*[`$`+@```!CL`0`G````1^P!`#8`
M``!O[`$`*0```*;L`0`<````T.P!`"````#M[`$`-@````[M`0!0````1>T!
M`#$```"6[0$`0P```,CM`0`L````#.X!`",````Y[@$`-P```%WN`0!C````
ME>X!`$P```#Y[@$`,P```$;O`0`>````>N\!`"````"9[P$`(0```+KO`0`@
M````W.\!`#0```#][P$`7P```#+P`0!1````DO`!`#P```#D\`$`/P```"'Q
M`0`J````8?$!`!H```",\0$`*````*?Q`0`M````T/$!`"T```#^\0$`%0``
M`"SR`0"#````0O(!`'<```#&\@$`@````#[S`0#(````O_,!`!D```"(]`$`
M(P```*+T`0`N````QO0!`"<```#U]`$`1P```!WU`0`B````9?4!`%````"(
M]0$`)````-GU`0`.````_O4!`$$````-]@$`)````$_V`0`N````=/8!`"<`
M``"C]@$`)````,OV`0`Z````\/8!``0````K]P$`!P```##W`0`#````./<!
M``\````\]P$`"@```$SW`0`'````5_<!``@```!?]P$`!@```&CW`0`1````
M;_<!``0```"!]P$`6P```(;W`0`$````XO<!``\```#G]P$`!````/?W`0`'
M````_/<!``<````$^`$`!0````SX`0`#````$O@!`!`````6^`$`#@```"?X
M`0`3````-O@!`!$```!*^`$``@```%SX`0`(````7_@!``<```!H^`$`%```
M`'#X`0`,````A?@!`!8```"2^`$`!@```*GX`0`/````L/@!``H```#`^`$`
M`P```,OX`0`H````S_@!``0```#X^`$`!@```/WX`0`'````!/D!`!<````,
M^0$`2````"3Y`0`I````;?D!`"P```"7^0$`%P```,3Y`0`E````W/D!`"8`
M```"^@$`*0```"GZ`0`=````4_H!`!H```!Q^@$`&0```(SZ`0`;````IOH!
M`!@```#"^@$`%P```-OZ`0`=````\_H!`!L````1^P$`&````"W[`0`G````
M1OL!`!@```!N^P$`)P```(?[`0`C````K_L!`!D```#3^P$`'0```.W[`0`;
M````"_P!`!@````G_`$`'@```$#\`0`B````7_P!`!T```""_`$`)@```*#\
M`0`B````Q_P!`!@```#J_`$`&@````/]`0`E````'OT!`!<```!$_0$`(0``
M`%S]`0`P````?OT!`#,```"O_0$`$P```./]`0`F````]_T!`#X````>_@$`
M'P```%W^`0`C````??X!`"$```"A_@$`)````,/^`0`>````Z/X!`!@````'
M_P$`(0```"#_`0`@````0O\!`#,```!C_P$`(@```)?_`0`W````NO\!``P`
M``#R_P$`#P```/__`0`9````#P`"`"D````I``(`'P```%,``@`0````<P`"
M`"(```"$``(`#P```*<``@`5````MP`"``X```#-``(`$````-P``@`;````
M[0`"``<````)`0(`!0```!$!`@`I````%P$"`"0```!!`0(`%P```&8!`@`B
M````?@$"`"0```"A`0(`!P```,8!`@#4````S@$"``P```"C`@(`%````+`"
M`@`)````Q0("``P```#/`@(`'````-P"`@`3````^0("`!$````-`P(`&P``
M`!\#`@`)````.P,"`#(```!%`P(`"````'@#`@`0````@0,"``<```"2`P(`
M$@```)H#`@`*````K0,"`#8```"X`P(`"0```.\#`@`D````^0,"`!8````>
M!`(`%0```#4$`@`4````2P0"`"8```!@!`(`'````(<$`@`,````I`0"`!P`
M``"Q!`(`#0```,X$`@`.````W`0"`!4```#K!`(`"@````$%`@`8````#`4"
M``@````E!0(`*0```"X%`@`)````6`4"``\```!B!0(`*@```'(%`@`&````
MG04"`!4```"D!0(`!P```+H%`@`(````P@4"``D```#+!0(`.P```-4%`@`'
M````$08"`!`````9!@(`$@```"H&`@`2````/08"``D```!0!@(`"P```%H&
M`@`'````9@8"`!4```!N!@(`!P```(0&`@`7````C`8"``L```"D!@(`#0``
M`+`&`@`,````O@8"`!<```#+!@(`&0```.,&`@`$````_08"``4````"!P(`
M&0````@'`@`$````(@<"`"P````G!P(`#````%0'`@`1````80<"``<```!S
M!P(``@```'L'`@`,````?@<"``X```"+!P(`"P```)H'`@`$````I@<"``D`
M``"K!P(`$P```+4'`@`6````R0<"``@```#@!P(`"0```.D'`@`1````\P<"
M``T````%"`(`&0```!,(`@`:````+0@"``T```!("`(`,@```%8(`@`>````
MB0@"`",```"H"`(`%P```,P(`@`+````Y`@"`#,```#P"`(`!0```"0)`@`1
M````*@D"`$(````\"0(`"P```'\)`@`*````BPD"``8```"6"0(`!````)T)
M`@`$````H@D"``H```"G"0(`%````+()`@`%````QPD"``8```#-"0(`!@``
M`-0)`@`*````VPD"``8```#F"0(`#@```.T)`@`/````_`D"`#0````,"@(`
M*@```$$*`@`G````;`H"``4```"4"@(`'@```)H*`@`.````N0H"``(```#(
M"@(`!````,L*`@`*````T`H"``4```#;"@(`!0```.$*`@`"````YPH"`!$`
M``#J"@(`0P```/P*`@`N````0`L"`!@```!O"P(`(P```(@+`@`C````K`L"
M`"8```#0"P(`#P```/<+`@!>````!PP"`"````!F#`(`1P```(<,`@`D````
MSPP"`$$```#T#`(`*````#8-`@`J````7PT"`#````"*#0(`,0```+L-`@`U
M````[0T"`#0````C#@(`*@```%@.`@`D````@PX"`"H```"H#@(`,@```-,.
M`@`0````!@\"`!$````7#P(`#P```"D/`@!L````.0\"``D```"F#P(`J0``
M`+`/`@!?````6A`"`'<```"Z$`(`+@```#(1`@!8````81$"`!4```"Z$0(`
M(P```-`1`@`7````]!$"`!<````,$@(`&P```"02`@`?````0!("`#D```!@
M$@(`(P```)H2`@`C````OA("`%@```#B$@(`&@```#L3`@`2````5A,"``L`
M``!I$P(`!0```'43`@`&````>Q,"``@```""$P(`!0```(L3`@`2````D1,"
M``P```"D$P(`%````+$3`@`>````QA,"``X```#E$P(`#P```/03`@`$````
M!!0"``D````)%`(`"P```!,4`@`(````'Q0"``8````H%`(`%0```"\4`@`)
M````110"``D```!/%`(`#@```%D4`@`.````:!0"``T```!W%`(`$````(44
M`@`&````EA0"`!<```"=%`(`"@```+44`@`)````P!0"``\```#*%`(`"```
M`-H4`@`%````XQ0"`!0```#I%`(`%0```/X4`@`*````%!4"``8````?%0(`
M#P```"85`@`1````-A4"`!@```!(%0(`#0```&$5`@`%````;Q4"`!@```!U
M%0(`"````(X5`@`#````EQ4"`!D```";%0(`"0```+45`@`"````OQ4"``(`
M``#"%0(`#P```,45`@`&````U14"``8```#<%0(`#P```.,5`@`7````\Q4"
M``8````+%@(`%@```!(6`@`"````*18"``0````L%@(`$@```#$6`@`2````
M1!8"`!````!7%@(`!P```&@6`@`-````<!8"``8```!^%@(`#````(46`@`(
M````DA8"`!H```";%@(`#P```+86`@`2````QA8"``(```#9%@(`!P```-P6
M`@`)````Y!8"``T```#N%@(`#P```/P6`@`K````#!<"``0````X%P(`!P``
M`#T7`@`+````11<"``4```!1%P(``@```%<7`@`+````6A<"``$```!M`P``
M`````!($````````:`8``%P#``"M`@``;0<``+L!``!C`P``O0```,0%````
M`````````(L"``#\!@`````````````'````O0$``!P%``#&`P``W`(``.,`
M``!N````]@```"H%```!!@```````-`#``#0!```)@(``(4```#^`@``I0,`
M`-4!````````M`0``$<!```S!@``SP4``&$'``!$!```U`$```````#:`0``
M'@```/P!``!2`@```````-````!0`@```````!T%```V`P``"0```(T&````
M````P@,````````H`P``%````($!```]`P````````````"H!0``K@$``!0!
M``#6!```B0<``.`'`````````````/\!`````````````(0$``"O!```RP$`
M`,(&````````Y04```````#T`@```````(,&````````,`8``'@'``!0!P``
M'P(``&4$````````C`8``&<!````````;P````<'``#=!```K@8```````".
M!P``JP$``*T'``"=!0```````,X#``!;````:P8``&T%``"#`0``-0``````
M``!6!P```````/L$``"(!@````````````!6!0```````"($``#I`0``````
M`#X&```J`P``XP0````````W`0``P00````````3`0````````````!U`P``
MK`$```@"````````;@4``'P'``"=`0``PP8```````!R`````````+T"```:
M!P``[@(``-8&````````V00``$8%``#P`@``+@4``.X````6`@``B@$``',#
M``":````?`4``*L'`````````````,<&````````V0(``#4'``!:`@``TP``
M`$@!````````8P`````````M!P``<`,``"$$`````````````#P%````````
M!@,``-X&````````B@0``(<%```P!P``_P8`````````````;`$``/`&````
M````N0<````````U`P``I@$``.0%````````:`$```L'````````````````
M``#B!@```````!,"``"T!0```````(`&``!Q!P```````"D"```'`0``#`4`
M````````````WP(``$4'```2`0``DP<``.T"``#M!```7`(``%D```#K!@``
MTP0``&T!````!0``T0$```````#3!@```````/8%``#``P```````)(%```\
M!```(`8````````S!```W04``+(`````````0`,```````":!```IP0``.T&
M```Q`@```````!D'```_`P``80```(T'``"6`@``5P$`````````````"@0`
M``````#0!0``>P,``)D!``#S!````````&@```#>!```<@0``%\'``!W````
MOP8``%,$```^`@``$08```````!5`@``$0```*$%````````8@8``%P%````
M`````````-@```!8!0``)P(``,L```##`0`````````````0!0```````-X`
M``#!!@```````$0%````````@P(``*0```#[!@``D`4````````=!@``V@4`
M`$4%``"3!@``H0<``'`%``#Y!```Y@0``+<'``````````````````!6`@``
M3P<`````````````90(``$D#```C!@``0P4``/$&``"\````X0,`````````
M````!P(``$T"``#:`P``.P,```````!D!P``@`4```````!G!```+P0``*,'
M````````;0(``'H&```F`0``1P,```````"X`@``O@,``&8"``!\!@``Q`0`
M`(4!``!"!```!0(``)4"``"$````7`0```````""````(0```*<'``"J!0``
M@`,``-8!``"V!@``"@,```````#,`@``^P(``)8!``"X`````0,``)P!```S
M`0``#@8``!D#``#(`0``1P(``$H%````````P`4``$T'``"2!P``*04``,@"
M``````````````````!B`P``&0$``/$"``!P`````````.4!``"N`P``2P``
M`*D"```[`0``+@,``$,#``"_`0```````#0!``"Q`P``204``/T````(`P``
MB08``$@#``#V`0``W`$```````#2`0```````)D$````````H@<``,X'````
M`````````#L%``!)!```DP0```````!3!P```````(<!```:`0``(P0``#P!
M```=!P``_@0``,H'``"Q!@``CP```!X%``#Q!0``&@,```````#-````JP4`
M`"4#``"`````_`4```````#A!@```````"\%``#%!0``@P4````````M`P``
M;@$``-('``#%`@``W0```,L$`````````````*<````>`@``*P$`````````
M`````````*\```"@!@``.`0``%8&``!N`P``]`0``!@'``#(````I`<``,(`
M````````!0<``#T$``"P!@```@<``(T#```Y!@``Y@```#0"``!'````$`,`
M`+`%````````J`(``"<%```W!````````&$#``#>!P``:04```````"P!P``
M`````)<%````````B0(``-P$``!G!@``)P<````'``"U`@``/0$``+D%````
M````.00```D"``"=!P```````+@#```&````S@8``#P```!>`0``704``(`!
M``#7`P``T`$``$X`````````:08``%,&```;!0``00(``(D```"O!@``'P``
M````````````SP0``(0!``#)````&P,``/D&````````Q`````````"Q`0``
M`````.\"``!5`P```````$@'````````0@<``)@&``#$`P```````!`$``!4
M!P`````````````#!P```````,,`````````S00```````"2!@``S`,`````
M``";!@``[@$``(@"``!@!0``:@(``)<&```C`P````````````"Y!```+P<`
M``L%``"H!P``YP0``)0!````````Z@$``*8"```+`@``T0````0!``#+`P``
M`````.<#```X!P``P````.T!``!H!``````````````2````<@$``%,"````
M````D@```````````````````,X"``"@`@```````*\%```%`````````.$!
M````````/`8``$X#``!4!```M0<```````!3!0``)`<`````````````````
M`#\'```-!````````%H%````````)P,``)@#```Y`@``(P<``!,'``"0````
M6P$``$8&``#:!P``````````````````>@0```````"3````3`0``.X%````
M`````````)0"````````Z04``,0"```X````/08``'$!``"5`P```````,$`
M````````"@8``)X!``!)!@``F04``+X'````````!@$```````!X`@``````
M`%`!``"Y`@``504``(L&``"<!0``600``-<'```L`@``S`4````````,!P``
MH0$``-8'````````.P(``$P#``",`@``P`0`````````````^P,```````!.
M`0``IP(``%8!``!U`0``/P8`````````````6@,``.`%````````1P4``*0%
M``#;!P``H@$``&H'``!,!@``F`(`````````````:P$``"P'```8!0``#@,`
M`*D'``"J!````````)L!``"J`@``]`8```````!"!@```````$T&``"<!```
MR0$``#,'````````S`$``,H&``!(!0````````````!.!P``W0,``!`'``""
M!@``T@,``$0#````````0P<``#`$`````````````,$!``#(!0```````+,$
M````````>00``/4$```A!P``HP0``#H'``#-`0``PP<``-($````````[0``
M`(D$`````````````#$%``!5!P````````````#8!```?@0``'D'``"-!```
MZ````!(#````````H@```+0&```K!P```````+8#``#_`@``2@$``.D```!B
M!P``>`8```````"%!P```````#\"``!-`0``@P<``+`"````````(@,``&\!
M``#5````?04``&T&```U!```!@<``!("```B!@``A04````````P`@``O`(`
M`"P%``!8`@```@4```````"U!@``%@<```H%``""`0````````````"N!0``
M3`(``*`!``!B````#````#8"``!E`````````+H$````````SP```",`````
M````;`4`````````````B`0```````#]!@``=00```````"C`0```````+\$
M``#?`P``%@4``'L'````````O`8``/`!````````W0<``(0&``#H!0``[@,`
M``````!1!0``:P,``*H`````````(@<``.4&```W`P``U`,``#$&````````
M304``*L`````````9P(````````Q`0```P0``%@!``!L!@`````````````?
M!0``0`(``(<#````````:0<``$T#`````````````(L%```$!0``FP<``-$%
M``!"`0``%0(``"\&`````````````&`$``!W!```WP```,L&````````````
M`````````````````````````````````.$$```M`0``]P(``#\```"C!@``
M;`<``#X#``"?!0``9P<```````"R`P``,@4``#\%`````````````#\$``"P
M`0```````.0`````````5P<``,<`````````608``/T%````````;0```!@&
M````````+@$``!(%``!9!P``^P```'`$``!_````B`$``.4$``#2````Z`8`
M`'T#``"*!@```````#4&````````Z00``',%``"+`P``0`0``,P&```=!```
M`````,,$``!]`0``W@4`````````````X0```+L&```3!@``7P4``'\&``!7
M`@``P@0``#H%```,`@``7P0````````0`@``2P(``+D&``#O!0``ZP0``(4&
M``#H`@``S@0``&$&``!&`P```````%X'``!:````%P8``'("``#H`0``Z0,`
M`#<```"=`@``C@$```,!``!0`P```````($'````````P`$``)0$``#T`P``
M```````````B!0``.@8```````"+!```\@8```````"R`@``F@8``.`#````
M````#P$```T'`````````````,X!``"_`P``_@4``.H%````````:`4``/`$
M``"B!0``$````)($``!^!0``-04``&P`````````+00``$$%````````````
M`'L```!2!@```````+8$````````:`(``*<&``"`!```8P(``)L"````````
M&`$``"`$``!8!P``6@8``&\&``"L!P``9`8``)(#``#@`0````````````"X
M!@``*@(``'8"``!.!0```````&H&``#F`P``:P`````````?!P``*0``````
M```W!P```````$@"```6!``````````````F`P``TP$``!0"``#%`0``VP``
M`"X&````````$P0```````!W!0``Z@,``)X'```@!0``#0(``#`!``"S!0``
MO`4``!<#``"U!```#@```)P````G`0``\00````````[!P``7````",!```=
M````Z`,``*,#```E`0``00````<%``!O`P```````+H'``"2`0``(`<```<#
M```P!0``*@$``"8&``"T`P``J04```````!;!@``U`8``,@'``!U!@``"```
M`-`'`````````````,4#``"=````#@(``'0$````````20<```````#C!0``
M7P8``#(&``!*!@``;P0`````````````B`<``"8```#*````^@0```8%``";
M!0``]P4``'$&````````````````````````-`,``(0"````````F0(``$,$
M``````````````````#C`P```````(X&``#*`0``8`$``$8!``!1`P``Q00`
M`.<!``!V!```#P0``)\'``!^`@``````````````````]P$```\%````````
M>@$``$`'``````````````````"D!```6@<``````````````04``.8"````
M````M0```/\$`````````````.P#```L`0``%`8```````!F`P``F`<``.(%
M````````?@<``.(```#\`@``E0$```````"]!0``ZP,````````^!```````
M`,4`````````9@<``)@!```E!```:@0``#<"```B`@``=P$```````!B`@``
M]P0``*$"``!=`P``*@8``(H#```5!```/@```+X```#'!P```````#4!``#@
M!@``.P```.X&````````#0````````"``@``O`,``+`#``#:!@``?P$`````
M```X`0``I0```+\%`````````````.,&``!R!P``G`(``(@%``#\!```^@(`
M`&8%````````5@,``%4````N!P``@P,``-`"```F!0``H@(```D#``#4!```
M!04``+P'````````[`8``)<#````````E04```````"E`@```P(```````#4
M!0``%P$```X%``#*`P``$P,```````"J`P``8`<``(P$```F!````````(8$
M`````````````&0```!E`P``M@4``!D`````````9`$``+0'````````````
M``8"``"=!```70```/,#``#;!0``:0`````````E!P```````+,'``#T`0``
M``````````#$`0``\0,``$$#```<`0``C`$``.("``!>!```^04`````````
M`````````%0#`````````````/$````Z`0``T@8``+H#``";````^0(``-4&
M``"[`@``K`0``$8$```;!P``9`0```````"9`````````/@$``"!!```.0``
M```````:!@``^0,```````#I`@``2@```)$$`````````````'X#``!``0``
M6@$```0&```5`P``-@$``%X````#`P``EP<``$$$```G``````````````#3
M`@``_````$<$``"-!0``<P0```````"/!0``+08``+\`````````>`$``-H"
M````````XP(``(8&``!?`P``K08``````````````````$P!````````````
M`"@!```'!@``\`4``+('````````I@4``````````````````#T"``"J!@``
M#`,```````"V`0```````$("``#T!0``V0,``'$$``!K!P``5@0``-\$```)
M!```SP$``+<%``"W!```<P```+<#``!A!`````````<$````````G@``````
M``!7````904``)0#``"1````'@$``%X%``#8`0``T0,``(8```#S`@``4@4`
M```````X`@``B@<```\#````````E`4``&,$````````300```````#;`P``
ME@0`````````````I`$``#8'``#)`P``)P8``!L&``!T!@``AP0``+L```#-
M`@``SP8``)4&``"!!@``8@$``$$'```A`0``^0$``!P$````````O@(``+0!
M``#U`P``_P,``*@!``````````````P!``!&`@``<@,``$(`````````)0(`
M`/`````C!0``'@<```\&``">`P``7P(``&D!````````F@4``"D&``#3!0``
M/0<```D'````````.`8``"0"``"&`@``[P8``#P#``"X`0``.@,``%L"````
M````<0,``)H#``!/`0```````(4#````````00$``"P````<`@``XP<`````
M``",`P````````L```#'!```M@(``+,"````````708``+X$``!+!0``0```
M`.(#`````````0(``!\$````````I@,``&L%``"D`P``60(```````"C`@``
M40<````````R`@``]@,`````````````?`$``)X"```3!0```````-4'```<
M`P``M0$``,L%``"@!```,@````@!```R`P``_0,`````````````````````
M``"E!0```````+H!``"R!@``3@8``"L"```!`0``=@$``,8$``!I`@``&04`
M`$H$``#D!@``+0(``#('``"W`0``XP$``"4```#9!0``=`,``$L&````````
M?P,``"0#`````````````'`'```L!@````````````````````$``(T```#(
M`P``D0$``.4"````````9`(``#````",!0``!@8```````"7`0``"@``````
M``!;!P``LP```,4'```4!```JP8``&X"``#%!@``ZP```%,!``!,!0``Q`<`
M``````#)!P``T0<``,H$``!^`0``&`(``-("``!/!@```````/X&````````
MBP<```````"M`0``]P8``!D$```L`P````````````#2!0``@0,```D%``#R
M`@``%`4``'T"``"<!P```````+$"```H`@````````````#X````W0$``*8`
M``"Q!```D0,``(`'``"&`0``-````-H$``!8!@`````````````#!@``````
M``````#E`````````*P&``!R!0``$`8```H!````````40```"\!````````
M``````````"$!0```````*4$``""!P``VP0``)H"```````````````````>
M`P``@@,```T%``!B!0``G@8``'D```#7!```7P$``.\!````!@``>`4``.0"
M``"4!@``(@```"4%``#1!@``8P$``-4%```````````````````O`@``V0<`
M`.0$```I!P``B`,``"@$```O````4@$``&0%````````K`,``"$&```V!0``
M.`,``.4#``#G`@``3@0``"$#```S`P```````+H%```K!@``_0(```P$``!+
M`P``400``$$&``!T`0``MP(``)H!``#A`@``;P(``,0&````````````````
M``"D!@``D04``*@$``!N!@``V`,``+D!``"R!0```````*H'```%!@``0`8`
M`&L"``#?!@``P@<``.P!``!P!@```````,`&``"3!0``%08``/P#``#;`0``
M'@0```$$``!<!P```````"0!````````I@<```\"``#7`@```````$0'``!<
M`0``100``.0#``!A!0``H@0``(8%````````&P```(($````````&@``````
M``!J`P``%@8````````K!```DP(``#($````````ZP(``-$"``#L````=P<`
M````````````>@(`````````````=`````````````````````````#*!0``
M;@<```````#D`0``EP````````#-!P```````+,!``#U!@```0<``-<&````
M````EP0``,D&````````_@```/0```"P!```R`8```````!S!@``HP``````
M```/!P``V0```&<#``##`@``,00``(H"``!2!```KP,``-P'````````0@4`
M`/H&```S`@``*0$``-P%``#A!0```````%4$``!]````CP8``)\&```1`P``
M=0```)T&``!2`P````````````#&`0``S`<``(P```!0!@``L@$``+X%``"K
M!````````*4&``"K`P``=P,``%X#``!G`````````&8$`````````````&D#
M``#J!@```````*`'``"1!P``(````$,!```^`0``_@$````````2!P``````
M`$4!```7!```>`,``,$'``#@!```"`0``"L#``#L!0``1P<``-,'``!9!0``
M$0(``(\#````````10```&X$``!V!0``$P````````!E`0``+@```(H%````
M````3P(``````````````````+D````R`0``60$```````!H`P``M@<``/@"
M``!]!P``KP<``'X````M!0``B@````````#J!```5P,``,D"````````````
M`'L"``!O!0``@04``.T%````````=`(``#D%````````<P$``!8```#B!```
MW`,``'8```#]`0``-P4```````#5`@``]0$``/@#``"M`P``CP<```````#>
M`0``I@0``,`'``````````````````"G`P```@,`````````````U00``&@'
M```X!0```````*L"``"6!0``(`(```````#W`P``A@<`````````````=`4`
M`+L%``#5`P``=@8``#P'``#1!```CP0``)X%``#4````)P0``-@&````````
M'0$``*4'``#)!0``S@``````````````E0```'<"``#Z!0```````+$````(
M!0```````(X#``!/!```%P```(D#``#P`P``>04``%0&``"0`0```````"0&
M```I`P``C`<``+0```````````````````#0!@```````,H"````````````
M`(<"``"0!P``"`8``+T$``#<!@``!`(``-8"``!R!@``-@```*4!```0`0``
MO08``*D&```@`0``8P<``%L#```-`P``V`<``!D"``!W!@``Y@8```````#,
M``````````````#'`P``\@0``.H```#!`P``2P0``$,```#K!0``"P0`````
M```%`P``ZP$``%`$``!4````D`,````````Q`P````(``*`%``"2`@``N`0`
M`.\$``#]!```$0$````````J!P```````,\#``!2!P```````,$"````````
M^@$``*P```!9`P``]@(``/,%``#!!0``W0(``)0'```+`0``E@8```````!L
M`@``N@8``%\`````````"0$``"@&``"0!````````$\```"_!P``#0$``!8!
M````````Q@<```````"$`P``*P```$<&````````H00``#H"``!L!```````
M`,,%``".!```=@,``(X%`````````````-8%`````````@(```X$``![!```
M```````````P`P```````)X$``#L!`````````````#=!@```````+$'``!J
M`0```````!P&``"+`0``!````+T'````````RP<``+4%```=`@``:P0``#\!
M``"^!@``F````"4&``"Z````S@4``#D#``!3`P``WP4``.('````````9@8`
M````````````?@8``*(&``#_!0``\P8``````````````````"\#``!\`P``
M\@,```````!5!@```````-D&```I!````````&H%``"%`@``\0$``,,#``#O
M````=0(``*D`````````F`0``/\`````````WP$```````!8````````````
M``"^`0``3@(``-X"``#8`@``80$````````.`0``@0```-<!``!U!0``3P,`
M`%T$``!Q````H`,``````````````````*@&``!5`0``U@````````"'!@``
M]P````@'``!=`@``E@```'D&``"W!@``H0,``*T$``"\`0````````````!&
M`````````&P#``".`@```````#<&````````6P4``'D#``#I!@``2@<``$\%
M``#G````0@,`````````````>P4``-<````5`0``KP$``/,!```$!```F`4`
M`#0%```U`@``Y@4```````#J`@``(P(``*D!``#;`@``/`(``&\'``!0````
M`````!\!````````?`````````#4`@``Q@(``','``"S`P````````````#L
M`@```````'\%``!,````K04``.\#``!*`P``!@0``#0'```>!@``%P(``,<"
M``!>`@``&````'$%``"Y`P``(0(``/(`````````.@0````#````````L```
M`,8%````````#P```.@$```2!@``,0```)`&````````!`<```````!+`0``
M@@(``$8'```#````>0(````````8`P```````)$&``!$````-`0````````Q
M!P``^0```%,```#7!0``#`8```````!7!@``2`0```````!]!```>```````
M``"\!````````*D#``#Z`P``+@0``+T#````````>@<```````"#````?P0`
M`'L!``#X`0```````"8'````````,P4``````````````````*,%```M````
M`````*@```!C!0``40$``"H$``!G!0``L@0``*P"``"(````(@$``!P```"Q
M!0````````````!Q`@``Q@````L&``#-`P````````````"X!P``?P<``#D'
M```^!P``FP,```````"/`@``E0<``(,$``#^`P``"@(``/H```"U`P``6`0`
M`*D$``#R`0``/@4``+L#`````````````&`#``"H`P``1`(``,L"``#>`P``
M90<```T&``#&!@```````-D!``#M`P``K0```'8'``"S!@``108```````"_
M`@``&P0``&D$````````NP<```````!`!0``E@,``#,```"N!P```````#T`
M``!]!@```````-P```!,!P```````#8&``"N`````````.<&````````U@,`
M``````"@`````````````````````````"P$````````K@0``'P"``"N`@``
M9@$``.(!``#X!@``U`<``!$'``!B!```C@```,D$``!U!P```````$D````N
M`@``H08````````"!@```````%`%``!X!```2`8``)H'````````7`8``/L%
M``"-`@```````)L$```D!```70$``)D'```4!P``$00``*H!``!E!@``P@4`
M```````.!P``1`8``%0!``#;!@```````.````"?`@``GP,``#0&````````
M`````$@```!@!@``1`$``.8!```D!0``.P0``!L"```:`@```````%8```"'
M!P``I`(``&`"````````.P8``(D!```"`0``S`0``+8```!M!````````+L$
M``"+````G`,``(D%``````````````````!7!0```````)$"```+`P``````
M`*\"``"W``````````````![!@``P`(````````1!0````````````#(!```
ME@<``$4#````````GP0````````5````!00``*<%````````&@4```($````
M````TP,```````!1`@``%`,``"0`````````^P$``/4%``!)`0``A`<``,\"
M``!2````QP$````````8!```.@```%0"``"'````!`,``-@%````````"@<`
M`!L!````````]@0``%X&``"4````:@```'\"``"A````%04``)4$``#U````
M<`$``"@%````````H@,``&````!7!```?`0``%H$``````````````````"0
M`@``YP4```````!F`````````)D#```:!```]@8``!P'````````(`,`````
M````````%P<``&$"``"?`0``P@(``.$'``!%`@```````!8#``#/!P``EP(`
M`),#````````(04```4!``"9!@```````$,&``!8`P````````````!;!```
MG`8``*8&```J````%0<``(T!``#X!0```````+H"``"=`P``]0(``.0'````
M````5`4```````#-!0``S08``,<%````````.0$``$H"``""!0``%P4``'H`
M``!S`@``P@$``*<!``!C!@``&08``"@'````````'P,``+0"``!D`P``[@0`
M`$L'``"L!0````0``'D!``!#`@``"08``/,```"X!0```````/(%```H````
M`````($"```V!````@````````!Z`P```P4``'H%```]!0``=`<``(4$````
M`````````)\````?!@``A@,``.`"``!-`````````-H`````````WP<``"L%
M``"3`0```````$D"``!=!P````````````!P`@``'0,``%$&````````CP$`
M`````````````"`F(S$U,3L@)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+@`@*"5S(&1A
M>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("A296%D(&]N;'DI`"`H:6X@)7,@
M9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI`"!A="``
M(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E<R(@:7,@;F]T(&$@=F%L:60@
M8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!2
M96=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S(B!W
M87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D
M('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A
M=&5D.B`E<RX`)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E
M)2D`)60@)7,@86YD("5S`"5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E
M>'!I<F5S+@`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R
M<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I
M<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E
M;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@:&%S(&-A
M;F-E;&QE9"`E<RX`)7,@:&%S(')E<&QI960@=&\@82!F<F5E+V)U<WD@<F5Q
M=65S="X`)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I;VX@=&\@)7,N
M`"5S(&AA<R!S96YT('EO=2!F<F5E+V)U<WD@:6YF;W)M871I;VXN`"5S(&ES
M(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO
M;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`)7,@:7,@
M<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S(')E<75E<W1S
M('EO=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@`E<R!R97%U97-T<R!Y;W5R
M('!R97-E;F-E(&%T("5S+@`E<R!T;R`E<R!O9B`E<P`E<R!W:7-H97,@=&\@
M861D('1O("5S+@`E<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@)7,N
M`"5S('=I<VAE<R!T;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M871I;VX@
M86)O=70@)7,N`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G
M<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"5S.B!4:&ES(&UE<W-A
M9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A
M<F4@;V8@9F]L;&]W:6YG(&%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I
M;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BX`
M+"!G=7-T:6YG(``L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S
M('1O("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O
M<FUA=``R-"!H;W5R<P`\4')E=FEO=7,`02!D871A8F%S92!B86-K96YD(&ES
M(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O
M8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y
M<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O
M('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P
M<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T
M92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG
M;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-
M24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y
M<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O
M34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N
M(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+@!!32!#;&]U9',`04T@3&EG:'0@4F%I;@!!
M32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-`$%022!)
M1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED
M9&QE`$%C8V5P="!R97%U97-T`$%C8V5P=&5D`$%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!6
M1E,@9FEL92X`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D
M`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%C=&EO;G,`061D`$%D9"`E
M<P!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE
M<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H
M:6QD(&=R;W5P('1O("(E<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B
M)7,B`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R
M<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B
M87(`061D('1H:7,@=&\@;7D@8V%L96YD87(`061D('1O(&%D9')E<W,@8F]O
M:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B
M('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@
M<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@(B5S(B!T;R!T:&4@<WES
M=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P
M97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S
M`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG
M;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S
M`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L
M92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP
M93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N
M871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT
M97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E
M<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@97)R;W(@;V-C=7)R960@
M9F]L;&]W:6YG('1H:7,@;&EN:SH@)7,`06X@:6QL96=A;"!V86QU92!W87,@
M<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+@!!;F1O
M<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N
M=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L
M:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#
M:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R
M86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E
M($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG
M;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M(&1E;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`07)G96YT:6YA`$%R
M;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N<VEO
M;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O
M<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1A8VAE9"!I<R!A;B!I0V%L
M96YD87(@9FEL92!R97!L>2!T;R!A(')E<75E<W0@>6]U('-E;G0`071T96UP
M="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@
M9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D
M:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=&5N9&5E<P!!='1R:6)U=&5S
M`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER
M960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K
M96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?
M8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP
M:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM
M87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K
M<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV
M92!$:7)E8W1O<GD`075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@
M<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5Q
M=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N
M86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U
M=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;&1A<#H@
M57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I
M<F5C=&]R>2X`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E
M<B!F86EL960N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO
M;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E5
M4R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D
M+@!!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N`$%V
M86EL86)L92!F:65L9',Z`$%W86ET:6YG(%)E<W!O;G-E`$%Z97)B86EJ86X`
M07IU<@!"3T9(($5X8W5S97,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R
M`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE
M+@!"86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA
M9&5S:`!"87(@5&EM90!"87(@=&EM90!"87)B861O<P!"87)B:64`0F%S92!G
M<F%P:&EC<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`$)A<V5L:6YE`$)E
M;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER
M=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N
M9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";'5E($UO;VX`0FQU92!A
M;F0@5VAI=&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R
M('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O
M=&@`0F]T<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I
M<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<F]W;@!"<G5N96D@1&%R=7-S
M86QA;0!"=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)N
M="!/<F%N9V4`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I
M;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`0V%C:&4@:6YI="!W87,@;F]T(&-O
M;7!L971E9"X`0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86UO
M=69L86=E`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@
M8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B!N;W0@=W)I=&4@=&\@
M9FEL92`B)7,B`$-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H
M86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N
M)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L
M96T@4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN
M9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I=&AO
M=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E
M8W1O<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N
M`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A
M<&4@5F5R9&4`0V%P=&EO;@!#87)R:65R`$-A=&5G;W)I97,@86YD($QA8F5L
M<P!#87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#
M96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E
M;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N=')A;"!!
M9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I
M`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF
M:6-A=&4@4&]L:6-I97,`0VAA9`!#:&%I<B!097)S;VX`0VAA;F=E`$-H86YG
M92!9;W5R(%!A<W-W;W)D`$-H86YG92!D969A=6QT(&ED96YT:71Y`$-H86YG
M92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T
M:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9VEN9R!Y
M;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N
M="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N
M`$-H87(`0VAE8U]K($QI;FLN+BX`0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P
M97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`
M0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE
M<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H;V]S92!!<'!L:6-A=&EO;CH`0VAO
M;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&%N(&%C
M=&EO;CH`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES
M="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAR:7-T;6%S($ES
M;&%N9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`
M0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!1=65R>0!#;&5A<B!O=70@=7-E
M<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T
M90!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E
M(%=I;F1O=P!#;&]U9',`0VQO=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E
M;&EN9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D
M97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T
M:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N
M9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#
M;VUP;&5T960`0V]M<&]S92!-97-S86=E("@E<RD`0V]M<'5T97)S`$-O;F1I
M=&EO;@!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N
M9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S
M(&%N9"!/=71L;V]K+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#
M;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE
M($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D
M+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO
M;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',`0V]N=&%C=',@=V5R
M92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O
M;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O9B`B
M)7,B`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y(&9A
M:6QE9#H@)7,`0V]P>2!S96QE8W1I;VX`0V]R;F9L;W=E<@!#;W-T($E$`$-O
M<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@
M;65S<V%G92X`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z(`!#;W5L
M9"!N;W0@4$=0('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE
M<W-A9V4Z(`!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U
M;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N
M=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD
M(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!,
M1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@
M=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T
M(&1E8W)Y<'0@4$=0(&1A=&$Z(`!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@
M9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@
M9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5L971E
M('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD(&YO="!D971E<FUI
M;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@
M9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@
M8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C:"!T
M:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD
M(&YO="!L;V%D('-T<F%T96=Y("(E<R(N`$-O=6QD(&YO="!L;V%D('-T<F%T
M96=Y("<E<R<N`$-O=6QD(&YO="!M:V1I<B`B)7,B+@!#;W5L9"!N;W0@;6MD
M:7(@)R5S)RX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE
M(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`
M0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N("<E<R<@9F]R('=R
M:71I;F<N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE
M("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#;W5L9"!N;W0@
M;W!E;B!D:7)E8W1O<GD@)R5S)RX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0
M('-E<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T
M:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A
M;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@
M;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R
M=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R
M971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R
M:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S
M(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN
M`$-O=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@<FUD:7(@)R5S)RX`
M0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A
M=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A
M8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO="!S879E('-E='5P('5P
M9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C
M:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE
M(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N
M92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@
M;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@
M;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U;FQI;FL@
M(B5S(BX`0V]U;&0@;F]T('5N;&EN:R`G)7,G+@!#;W5L9"!N;W0@=7!D871E
M(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B
M.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@
M<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@
M(B5S(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B
M.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A
M=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S
M`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T
M:6$`0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@4V5S<VEO;G,`0W5R
M<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@57-E<G,`0W5R<F5N
M="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#
M=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#
M=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI
M8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`
M0WIE8V@@4F5P=6)L:6,`1$0`1&%I;'D`1&%T851R964@0G)O=W-E<@!$871A
M8F%S92!,;V]K=7``1&%T90!$871E(%)E8V5I=F5D`$1A=&4@<V5L96-T:6]N
M`$1A>0!$95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`
M1&5C;&EN960`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0`1&5F875L="!#;VQO
M<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@4VAE;&P`1&5F:6YI=&EO;G,`
M1&5L96=A=&4@<&]S:71I;VX`1&5L96=A=&5D`$1E;&5T90!$96QE=&4@0V5L
M;`!$96QE=&4@1W)O=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES<VEO;@!$
M96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C
M;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE
M=&4@;65S<V%G97,`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T
M92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N
M<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E
M('-U8B!F;VQD97)S`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E
M('1H92!C=7)R96YT(')O=P!$96QE=&4@=&AI<R!L:6YK`$1E;&5T960@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L:79E<GD@=&EM90!$96YM87)K
M`$1E;GD@<F5Q=65S=`!$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O
M<FUA=&EO;@!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A
M:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B
M965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT
M`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN
M=#H@`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T
M;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L
M87D@3W!T:6]N<P!$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T`$1I<W!L87D@
M9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&EV:61E<@!$:FEB;W5T
M:0!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E
M;F%N8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L
M9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V%N(%)E
M<'5B;&EC`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W;FQO
M860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I
M;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL
M`$5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H
M:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+@!%4E(`16-U861O<@!%9&ET`$5D
M:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M
M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@
M9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO
M;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT
M+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU
M<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--
M4R!'871E=V%Y`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U
M;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F0`16YD('EE87(`16YL87)G92!%
M9&ET;W(`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5N=&5R('1H92!L971T
M97)S(&)E;&]W.@!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`17)R
M;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R(&1E;&5T:6YG('-Y
M;F,@;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S`$5R<F]R('-E
M;F1I;F<@<F5P;'DZ("5S+@!%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,`
M17)R;W(@=W)I=&EN9R`B)7,B+@!%<G)O<B!W<FET:6YG("<E<R<N`$5S=&]N
M:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V
M97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E
M<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X
M86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%
M>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R
M8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L;W(`1E10
M('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E
M<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T
M;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@
M(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T
M92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B
M+@!&86EL960@=&\@<F5T<FEE=F4Z("5S`$9A:7(`1F%L:VQA;F0@27-L86YD
M<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&
M87AE<P!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO
M=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6=L970@0T%0
M5$-(00!&:6=L970@9F]N=`!&:6II`$9I;&4`1FEL92!#;W5N=#H@)7,@9FEL
M90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE
M`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@
M<W5P<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1
M=6%R=&5R`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O
M;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R
M96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U
M<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L
M87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K
M*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE
M('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`1G(`
M1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5E+T)U<WD@
M26YF;W)M871I;VX`1G)E92]"=7-Y(%)E<&QY`$9R964O0G5S>2!297%U97-T
M`$9R964O0G5S>2!297%U97-T(%)E<W!O;G-E`$9R96YC:"!'=6EA;F$`1G)E
M;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O
M;0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.
M86UE`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ
M`$=A;6)I80!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#
M;V1E`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV96X@3F%M
M90!';&]B86P@3W!T:6]N<P!';P!';V5D96P`1V]O9VQE($UA<',`1V]O9VQE
M(%-E87)C:`!'<F%Y<V-A;&4`1W)E96-E`$=R965N`$=R965N;&%N9`!'<F5N
M861A`$=R97D`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7!?;&1A<#H@56YA
M8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9#H@`$=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,`
M1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<P!'<F]U<',`
M1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E
M<W0@4V5R=FEC97,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U
M>6%N80!(5$U,`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E
M('1H92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!
M<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I
M;B!T86)L92X`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I
M`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE861E<G,`2&5A<F0@27-L
M86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE879Y(%0M4W1O<FT`2&5B<F5W
M("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96EG:'0@*&EN('!I>&5L<RD`2&5L
M<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES
M('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9V@`2&]?;64`2&]M90!(
M;VUE($%D9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(;VYD=7)A
M<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,
M(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@
M3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L
M86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`
M2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R
M9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE
M("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T
M>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@
M(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S
M:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R
M:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(
M;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@;6%N
M>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F
M:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L
M9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO
M<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E
M<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB
M;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D
M9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L
M;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS
M97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E
M<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N
M;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE
M=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN
M=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B
M;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T
M:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@
M=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N
M`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R
M;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!)
M;6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O
M<G1E9"!F:65L9',Z`$EN(%!R;V-E<W,`26Y?<V5R="!2;W<@069T97(`26YC
M;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@
M86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N
M871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN
M9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I80!);F9O`$EN
M9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N`$EN
M<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`
M26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@
M82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N
M97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W
M(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B
M969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E
M<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@
M=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN
M<V5R="!C96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L
M=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S86=E
M<P!);G-E<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F
M;W)E`$EN<V5R="!R;W<@869T97(`26YS97)T(')O=R!B969O<F4`26YS97)T
M('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N
M.@!);G-E<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U
M9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L
M:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES
M=`!);G9A;&ED($%C=&EO;B!S96QE8W1E9"!F;W(@=&AI<R!C;VUP;VYE;G0N
M`$EN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@6DE0
M(&1A=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`
M26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A
M9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS92!K
M97DN`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y
M<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES
M<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!)
M;G9A;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A
M;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED
M('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED
M('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`27)A
M;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-
M86X`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A
M;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*
M4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E
M;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`
M2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N
M+@!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y
M(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;VQA8@!+;W)E82P@1&5M
M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@
M;V8`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`
M3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S
M="!(86QF`$QA<W0@4&%S<W=O<F0@0VAA;F=E`$QA<W0@475A<G1E<@!,87-T
M(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@
M)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=F5N9&5R`$QA=P!,87EO
M=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F
M="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,979E;`!,:6)E<FEA`$QI
M8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!";'5E
M`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI
M9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I
M=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R
M:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E
M<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`
M3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,
M:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI
M<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M
M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@
M<V5S<VEO;G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`
M3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N
M:6$`3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO
M8V%T:6]N`$QO9R!I;@!,;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS`$QO9VEN
M(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S
M(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT
M`$QO=F4`3&]W`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T
M=&5R<P!,;W=E<B!R;VUA;B!N=6UB97)S`$QO>6]L80!,;WEO;&$@0FQU90!,
M=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE
M9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU
M9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I;`!-86EL
M($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S
M`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U
M(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA
M=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T
M(&UA<`!-87!P:6YG<R!S=&]R960N`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@
M4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N
M($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI
M<75E`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@
M86QL;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-
M87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S
M.B``36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87AI;75M(&QE
M;F=T:`!-87D`36%Y;W1T90!-961I8VEN90!-965T:6YG($-A;F-E;&QA=&EO
M;@!-965T:6YG($EN9F]R;6%T:6]N`$UE971I;F<@4')O<&]S86P`365E=&EN
M9R!297!L>0!-965T:6YG(%5P9&%T90!-965T:6YG(%5P9&%T92!297%U97-T
M`$UE;6)E<G,`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A
M9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R
M=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER
M960N`$UE<W-A9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO
M="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I
M;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE
M=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B(&ES
M(&YO="!D969I;F5D`$UE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO
M9#H@)7,`365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A
M=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R
M<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI;FEM=6T@<&%S<W=O<F0@
M86=E(&AA<R!N;W0@>65T(&5X<&ER960`36ER<F]R`$UI<V-E;&QA;F5O=7,`
M36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O
M;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y
M;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S
M86=E($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-
M:7-S:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO
M9&EF:65D($1A=&4`36]D:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B
M;&EC(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY
M`$UO;G1S97)R870`36]O;B!0:&%S97,`36]R92!F:65L9',@9F]U;F0@:6X@
M;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"X`36]R;V-C;P!-;W-T;'D@
M0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`36]V92!$;W=N`$UO
M=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``
M36]Z86UB:7%U90!-;WII;&QA`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T
M<P!-=6QT:6UA<"!52R!M87``375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U
M;G0`37D@06-C;W5N="!);F9O<FUA=&EO;@!->2!0;W)T86P`37D@4&]R=&%L
M($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;6EB
M:6$`3F%U<G4`3F585`!.965D<R!!8W1I;VX`3F5P86P`3F5T:&5R;&%N9',`
M3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A
M<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A
M<&4@4U-,('-E<G9E<B!N86UE`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE
M;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE
M=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!-97-S86=E('1O("5S`$YE
M=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE
M=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N`$YE
M=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N`$YE=R!W:6YD;W<@*%]B;&%N:RD`
M3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T(%!H87-E<P!.97AT(&]P=&EO
M;G,`3F5X=#X`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.
M;P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF
M9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN
M9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI
M<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M
M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E
M+@!.;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N
M`$YO(&1E<V-R:7!T:6]N(&9O=6YD`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D
M+@!.;R!F:6QE('5P;&]A9&5D`$YO(&EC;VYS(&9O=6YD+@!.;R!L;V-A=&EO
M;B!I<R!S970N`$YO(&QO8V%T:6]N('!R;W9I9&5D+@!.;R!M97-S86=E('-U
M<'!L:65D+@!.;R!N86UE('-P96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE
M9"X`3F\@;V9F96YS:79E(&9O<G1U;F5S`$YO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO('!E;F1I
M;F<@<VEG;G5P<RX`3F\@<75O=&$@<V5T`$YO('%U;W1A('-E="X`3F\@<G5L
M97,`3F\@<V5P87)A=&]R('-P96-I9FEE9"X`3F\@<VED97,`3F\@<W5C:"!F
M:6QE`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H
M92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9A;&ED
M(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD
M(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG
M=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I
M;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N(%!A<G1I8VEP86YT
M`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)F;VQK($ES;&%N9`!.;W)T
M:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W
M87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I
M;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1H
M:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]T:6-E`$YO=F5M8F5R`$YU;6)E
M<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB
M97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG
M(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R96%T
M;W(`3V-T86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VQD(&%N
M9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+@!/;&0@<&%S<W=O
M<F0`3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+@!/;6%N`$]N;'D@24U!
M4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@;V9F96YS
M:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`
M3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H
M86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA
M<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@
M;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="X`3W!E
M;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M
M`$]P=&EO;F%L(%!A<G1I8VEP86YT`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`
M3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET
M`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I
M9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO
M;@!/=VYE<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T
M(&%V86EL86)L92X`4$5!4CHZ36%I;"!B86-K96YD`%!'4"!$:6=I=&%L(%-I
M9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0
M(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`4$T@
M3&EG:'0@4F%I;@!032!286EN`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W
M(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!/4TE8(&5X=&5N<VEO;B!I
M<R!M:7-S:6YG`%!?2%`@4VAE;&P`4&%D9&EN9P!086MI<W1A;@!086QA=0!0
M86QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.
M97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G1L>2!#;&]U9'D`4&%S<W=O<F0`4&%S
M<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN`%!A<W-W;W)D(&EN8V]R<F5C
M=`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N
M+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O
M<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C
M;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT
M`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES
M<VEO;B`B)7,B(&YO="!D96QE=&5D+@!097)M:7-S:6]N($1E;FEE9`!097)M
M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!)
M;F9O<FUA=&EO;@!097)U`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S
M`%!I=&-A:7)N`%!I>&5L<P!0;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O
M('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E
M;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A
M;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N
M=&@@86YD(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE
M=R!C871E9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`
M4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O
M9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM
M92X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0
M;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A
M<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N("!9;W4@35535"!A9W)E92!W
M:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E(')E860@
M=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T
M97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E(')E=FEE=R!T:&4@9F]L
M;&]W:6YG(&EN9F]R;6%T:6]N+"!A;F0@=&AE;B!S96QE8W0@86X@86-T:6]N
M(&9R;VT@=&AE(&UE;G4@8F5L;W<N`%!L96%S92!S96QE8W0@86X@86-T:6]N
M(&9R;VT@=&AE(&UE;G4@8F5L;W<N`%!L96%S92!T>7!E('1H92!N97<@8V%T
M96=O<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O
M<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T
M86)L90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!
M4"D`4&]S=&YU:V4`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I
M.B``4')E8VEP:71A=&EO;CQB<B`O/F-H86YC90!0<F5F<U]L9&%P.B!297%U
M:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ
M(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U
M<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W
M`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O
M<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O
M8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@
M2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L
M:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY
M+@!0=65R=&\@4FEC;P!0=7)G92!M97-S86=E<P!1871A<@!1=65R>0!1=6]T
M80!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I
M;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3
M;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E
M860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@
M8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R
M('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E
M9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@`4F5F<F5S:"!$>6YA;6EC
M($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E
M;&%T:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!296UA<FMS`%)E;65M8F5R('1H
M92!F<F5E+V)U<WD@:6YF;W)M871I;VXN`%)E;6]T92!397)V97)S`%)E;6]T
M92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`
M4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`
M4F5M;W9E(&9R;VT@;7D@8V%L96YD87(`4F5M;W9E('!A:7(`4F5M;W9E('-A
M=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN
M`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N
M=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5P;'D@4V5N="X`4F5P
M;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4`4F5P;'D@=VET:"!F<F5E
M+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N`%)E<&QY('=I=&@@<F5Q=65S=&5D
M(&9R964O8G5S>2!I;F9O<FUA=&EO;BX`4F5P;'DZ("5S`%)E<75E<W0@8V]U
M;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<75E
M<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q=6ER960@(B5S
M(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D
M("(E<R(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q
M=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN`%)E
M<75I<F5D($9I96QD`%)E<75I<F5D(%!A<G1I8VEP86YT`%)E<V5T`%)E<V5T
M(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S=&]R92!,87-T(%%U
M97)Y`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5T>7!E(&YE=R!P87-S
M=V]R9`!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%
M9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H
M="!V86QU97,`4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A
M=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE
M<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A
M`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP
M=&5D($UE<W-A9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA
M8FQE+@!335,@365S<V%G:6YG`%-13"!3:&5L;`!344P@<W1A=&5M96YT(&9O
M<B!V86QU92!L;V]K=7!S`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I
M;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!3
M86EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H
M92!'<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R
M:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`
M4V%U9&D@07)A8FEA`%-A=F4`4V%V92`B)7,B`%-A=F4@)7,`4V%V92!/<'1I
M;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R
M:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V
M960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V960@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@=&\Z("(E<R(N`%-C871T97)E9"!4+5-T;W)M<P!38VEE;F-E`%-E87)C
M:`!396%R8V@@16YG:6YE<P!396QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!3
M96QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C
M="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL`%-E
M;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E
M;&5C="!N;VYE`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M
M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E
M('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L
M:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED
M96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E
M;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M
M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L
M96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD($QA=&5S="!);F9O
M<FUA=&EO;@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G86P`
M4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I
M86P@3G5M8F5R`%-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N
M`%-E<W-I;VX@061M:6X`4V5S<VEO;B!)1"!E>'!I<F5D+@!397-S:6]N<P!3
M970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S
M<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E('-E
M<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A
M;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@
M9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C
M;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L
M87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL
M86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A
M;65T97(Z(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO
M=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H
M;W<`4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A
M;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA
M<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;W!T:6]N('1O
M(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO=R!T86)L92!O<&5R871I
M;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3
M:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE
M(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0
M<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I
M86QO9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R
M<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H<FEN:P!3:')I;FL@
M;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@
M9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R
M92!!;&=O<FET:&T`4VEM<&QE>`!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT
M96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO
M=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T
M90!3;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L
M;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&]R9&5R
M('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@
M1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE
M<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P
M86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R
M`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I
M86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P
M;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3
M=&%R=`!3=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R
M86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN
M9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#
M4U-=`%-U`%-U8F1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`4W5B:F5C=`!3
M=6)M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@861D("(E<R(@=&\@=&AE('-Y
M<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA
M<R!B965N(&%P<')O=F5D+@!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L
M;'D@861D960@(B5S(B!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE
M87)E9"!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C
M97-S9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B
M)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O
M;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U
M;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@
M<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E
M<W-F=6QL>2!U<&1A=&5D("(E<R(`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U
M9&%N`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U
M;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S
M8W)I<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*
M86X@36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>6YC(&QO
M9R!D96QE=&5D`%-Y;F--3`!3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS
M`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3=&]R;2!A;F0@5VEN
M9'D`5"U3=&]R;7,`5"U3=&]R;7,@16%R;'D`5%-6(&9I;&4`5&%B;&4`5&%B
M;&4@4')O<&5R=&EE<P!486)L92!3970`5&%B;&4@<')O<&5R=&EE<P!486EW
M86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA
M;FEA+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K<P!496%L`%1E
M;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U
M<F4`5&5M<&5R871U<F4Z(`!496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,
M;R5S*2`F9&5G.R5S`%1E;7!L871E("(E<R(@;F]T(&9O=6YD+@!496UP;&%T
M92!!9&UI;FES=')A=&EO;@!496YT871I=F5L>2!!8V-E<'0@<F5Q=65S=`!4
M96YT871I=F5L>2!!8V-E<'1E9`!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N
M`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AA;FL@>6]U
M(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4:&4@)7,@;&EN:R!T;R`E<R!H87,@
M8F5E;B!R96UO=F5D+@!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA
M8FQE+@!4:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L960N`%1H92!(;W)D
M92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B
M)7,B`%1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N`%1H
M92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L
M;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H
M92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N
M="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M
M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-A;&5N9&%R(&1A
M=&$@:7,@:6YV86QI9`!4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S
M<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@
M9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@
M=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!D971A8VAE9"!01U`@<VEG;F%T
M=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE
M<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO
M="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN('1H92!D
M871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF
M:65D+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E
M('=E8B!C;VYN96-T:6]N+@!4:&4@979E;G0@:&%S(&)E96X@861D960@=&\@
M>6]U<B!C86QE;F1A<BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E
M<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S
M('-E='1I;F=S+@!4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET
M<V5L9BX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`
M5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E
M('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N
M`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T
M+6AA;F0@<VED92!O;FQY`%1H92!L:6YK(&AA<R!B965N(')E;6]V960`5&AE
M(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T
M;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S86=E('-E;G0@;VX@
M)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES<&QA>65D
M+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B
M965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H96X@
M;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!N=6UB97(@;V8@9FEE
M;&1S(&UU<W0@8F4@;G5M97)I8RX`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E
M<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE
M('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I
M=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4
M:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W
M87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!Q=6]T92!C:&%R86-T
M97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE(')I9VAT(&%N
M9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H
M92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE
M('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S
M(B!H87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H
M87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@
M;F]T(&5X:7-T+@!4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="X`
M5&AE('1A<VL@:&%S(&)E96X@861D960@=&\@>6]U<B!T87-K;&ES="X`5&AE
M('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T97AT
M('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C
M<F5E;BX`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S
M:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE
M('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B
M92!S879E9"X`5&AE('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VX@=V%S
M('-U8V5S<V9U;&QY('-T;W)E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES
M(&YO="!A=F%I;&%B;&4N`%1H96UE<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U
M;F0N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E
M(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E
M(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H
M879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S
M<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O
M('1H92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@
M9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A
M<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4
M:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U
M<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P
M;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO
M=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U
M<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M
M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!E=F5N=#H@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('1H92!T87-K.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!U
M<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E<RX`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U
M(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O
M<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T
M:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R
M;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A
M9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D
M:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI
M<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R
M<RX`5&AI<R!A8W1I;VX@:7,@;F]T('-U<'!O<G1E9"X`5&AI<R!A8W1I;VX@
M:7,@;F]T('EE="!I;7!L96UE;G1E9"X`5&AI<R!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E
M87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M
M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@
M*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&=A=&5W87DL
M('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S
M;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@
M=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6
M;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT
M('=I=&@@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI
M<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M
M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O
M<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD
M(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT
M86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E
M>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@
M<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&UE<W-A9V4@=V%S('=R:71T
M96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W
M;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@<V5R
M=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES
M('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@
M;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@
M9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME=',`5&EM90!4
M:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I;6]R
M+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T(&UU
M;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#
M;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G9VQE
M($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4;W``
M5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`5')I;FED860@86YD(%1O
M8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@
M*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES
M;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``
M55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R
M=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N
M('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N
M(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I
M;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S
M+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE("5S+R5S`%5N86)L92!T;R!C
M:&5C:R!F:6QE('-I>F4@;V8@(B5S(BX`56YA8FQE('1O(&-H96-K(&9I;&4@
M<VEZ92!O9B`B)7,O)7,B+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R
M=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O
M<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B
M)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T
M;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E
M<B`B)7,B+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@9&5L971E("(E<R(L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E
M("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@
M<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O
M(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE
M('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T
M97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C
M97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET
M:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O
M(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@
M9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D(%9&
M4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(%9&
M4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D
M(&9I;&4Z(`!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN
M`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E
M<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O
M<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M92!6
M1E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`56YA
M8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI
M<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+@!5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+@!5;F1E<FQI;F4`
M56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:&%N
M9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,`56YI8V]D92`H551&+3@I`%5N
M:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T
M97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S
M`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5
M;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@
M;&]C871I;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O
M<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV
M:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P
M<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/
M2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC
M:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T
M:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E;G-I
M;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@<F5S<&]N9&5N="!S=&%T=7,`
M57!D871E('5S97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D96QE
M=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I
M;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@
M<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,
M`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S
M97)V97(N`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N
M`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T
M<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O
M<B!T:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA;64`
M57-E<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N
M86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER
M96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO
M;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@
M9G)O;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F
M("5S+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R
M:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE
M<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E
M<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG
M`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE3
M0TE)*0!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A
M<R`E<P!6:65W(&5V96YT`%9I97<@=&%S:P!6:7)G:6X@27-L86YD<RP@0G)I
M=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y`%9I<VEB:6QI
M='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)3D<A(2$@
M4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!724X@=FEA($A45%``
M5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!790!796%T:&5R($9O<F5C87-T
M`%=E871H97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`5V5B
M(%-I=&4`5V5B8G!L871S96X@+2!3;V)E<@!796)B<&QA='-E;B`M(%-O8F5R
M($Y%5P!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S
M`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!7
M97-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P
M;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C
M=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H97)E:7,@075S
M=')A;&EA(&UA<`!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B
M;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!I;B!#
M4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A
M:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L
M90!7:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD
M('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5VES:&QI<W0`
M5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7<F]N9R!N=6UB97(@;V8@
M9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O
M;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+@!7
M<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+@!8+5)E
M9@!8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!E>'1E;G-I;VYS
M`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@22!!
M9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T
M;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@86QL
M;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RX`66]U(&%R92!N
M;W0@875T:&5N=&EC871E9"X`66]U(&-A;B!N;W0@:&%V92!T:&4@)UPG(&-H
M87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&-A;FYO="!H879E('1H
M92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO
M="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!H879E(&)E96X@
M;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO
M;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F
M;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A
M($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O
M;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@
M<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R
M="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I
M;G1S('1O`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E
M9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`
M66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@
M=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C
M871E9V]R>2!N86UE+@!9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@
M<&AO;F4@;G5M8F5R`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE
M87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M
M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D
M<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@
M)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U
M('=I<V@@=&\@=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT
M<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0N`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S
M=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N
M(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R
M(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL
M('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@
M<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S
M=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA
M;F0@*R!0('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R
M(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D969A
M=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L;V=I;B!H87,@
M97AP:7)E9"X`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R
M(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O
M9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E
M9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D
M(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@
M=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!P87-S=V]R9"!H87,@97AP
M:7)E9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER90!:
M86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B
M;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@
M5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T
M:6]N`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``
M7TEM86=E(%!R;W!E<G1I97,N+BX`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y
M($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN
M+@!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@
M8F]O:P!A9&1R97-S964@=6YK;F]W;@!C86QE;F1A<@!C86QM`&-A;FYO="!C
M<F5A=&4@;W5T<'5T(&9I;&4`8V%N;F]T(&]P96X@:6YP=70`8VQI8VL@:&5R
M90!C;&]C:P!C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(`8V]N9FEG=7)A=&EO
M;B!E<G)O<@!C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG`&1A=&$@9F]R
M;6%T(&5R<F]R`&5D:70`96YT<GD@;F]T(&9O=6YD`&9A;&QI;F<`9FEL90!F
M<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&=U<W1I;F<`:#H`:&@`:&]S="!N
M86UE('5N:VYO=VX`:6UM961I871E`&EN;&EN90!I;G!U="]O=71P=70@97)R
M;W(`:6YT97)N86P@<V]F='=A<F4@97)R;W(`;&EN97-=`&UK:7-O9G,@97)R
M;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+@!M;0!N86UE`&YO="!I;7!L
M96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P
M97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5M;W1E(&5R<F]R(&EN('!R;W1O
M8V]L`')I<VEN9P!S97)V:6-E('5N879A:6QA8FQE`'-H;W<@9&EF9F5R96YC
M97,`<VUS,F5M86EL('9I82!(5%10`'-S`'-T96%D>0!S>7-T96T@97)R;W(`
M=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E`'1Y<&4@=&AE('!A<W-W;W)D
M('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L96-T
M`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R
M9&4@,RXQ"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N
M;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`R+3$U(#$Q.C(Q*S`Q,#`*
M4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP,BTQ-B`P,#HR-BLP,3`P"DQA<W0M
M5')A;G-L871O<CH@2F]A<75I;2!(;VUR:6=H875S96X@/&IO:&]`=V5B8G!L
M871S96XN<V4^"DQA;F=U86=E+51E86TZ(%-W961I<V@@/&DQ.&Y`;&ES=',N
M:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E
M>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,0I#;VYT96YT+51R86YS9F5R
M+45N8V]D:6YG.B`X8FET"@`@)B,Q-3$[("5S(&MO;6UE<B!A='0@=71F]G)A
M(&1E('5N9&5R:.5L;'-A:W1I=FET971E<FYA('-O;2!M87)K97)A=',@;F5D
M86XN`"`H)7,@9&%G87(@<V5D86XI`"`H<VYA8F)T86YG96YT("5S*0`@*%-K
M<FEV<VMY9&1A9"D`("AO;2`E<R!D86=A<BD`("AI9&%G*0`@*&EM;W)G;VXI
M`"`H:6?E<BD`(&ML(``G)7,G(.1R(&EN=&4@96X@:V%T86QO9RX`)R5S)R#D
M<B!I;G1E(&5T="!G;V1KY&YT('9A;"X`)R5S)R#D<B!I;G1E(&MO;F9I9W5R
M97)A="!I($AO<F1E<F5G:7-T<F5R="X`5'+D9&AA;G1E<F%R96X@9O9R("5S
M('-A:VYA<RX`)R5S)R!L861E<R!T:6QL(&D@9W)U<'!S>7-T96UE="X`)R5S
M)R!L861E<R!T:6QL(&D@8F5H]G)I9VAE='-S>7-T96UE="X`)R5S)R!S:V%P
M861E<R!I;G1E.B`E<RX`)2XR9DU"(&%N=N1N="!A=B`E+C)F34(@=&EL;.5T
M970@*"4R9B4E*0`E9"`E<R!O8V@@)7,`1&ET="!L]G-E;F]R9"!U<'!H]G(@
M871T(&?D;&QA(&]M("5D(&1A9V%R+@`E9"UD86=S<')O9VYO<P`E<R`M($;V
M<B!KY&YN961O;0!&:6YG97)P<FEN="!F]G(@)7,`)7,@2T(`)7,@56YD97)H
MY6QL<V9U;FMT:6]N("T@0F5K<N1F=&5L<V4`)7,@4V5T=7``)7,@86YMY&QA
M;@!4:N1N<W1E879T86P@9O9R("5S`"5S(&9I;FYS(')E9&%N+@`E<R!K;"`E
M<R`E<P`E<R!H87(@86YN=6QL97)A="`E<RX`)7,@:&%R('-V87)A="!PY2!E
M;B!B96?D<F%N(&]M(&EN9F]R;6%T:6]N(&%N9^5E;F1E(&QE9&EG+W5P<'1A
M9V5N+@`E<R!H87(@<W9A<F%T('#E(&EN8FIU9&%N('1I;&P@)7,N`"5S(&AA
M<B!S:VEC:V%T(&1I9R!I;F9O<FUA=&EO;B!O;2!L961I9R]U<'!T86=E;BX`
M)7,@:V]M;65R(&%T="!U=&;V<F$@9&4@=6YD97)HY6QL<V%K=&EV:71E=&5R
M;F$@<V]M(&UA<FME<F%T<R!N961A;BX@36%R:V5R82!D92!A:W1I=FET971E
M<B!S;VT@9'4@=FEL;"!U=&;V<F$N`"5S(&MRY'9S`"5S(&UI;G5T97(`)7,@
M<V%K;F%S+@`E<R!E9G1E<F9RY6=A<B!I;F9O<FUA=&EO;B!O;2!NY'(@9'4@
MY'(@;&5D:6<O=7!P=&%G96XN`"5S(&5F=&5R9G+E9V%R(&1I;B!NY')V87)O
M('9I9"`E<RX`)7,@=&EL;"`E<R!A=B`E<P`E<R!V:6QL(&SD9V=A('1I;&P@
M=&EL;"`E<RX`)7,@=FEL;"!G]G)A(&1I9R!M961V971E;B!O;2`E<RX`)7,@
M=FEL;"!E<FCE;&QA(&1E;B!S96YA<W1E(&EN9F]R;6%T:6]N96X@;VT@)7,N
M`$%D<F5S<V)O:R!F]G(@)7,`2V%L96YD97(@9O9R("5S`$%N=&5C:VYI;F=A
M<B!F]G(@)7,`57!P9VEF=&5R(&;V<B`E<P`E<SH@)7,`)7,Z($UE9&1E;&%N
M9&5T(&MA;G-K92!I;G1E(.1R(&9RY6X@9&5N('-O;2!D970@=F5R:V%R+B!6
M87(@9O9R<VEK=&EG(&UE9"!A='0@9O9L:F$@;.1N:V%R(&5L;&5R('-K:6-K
M82!A=G/D;F1A<F5N('!E<G-O;FQI9R!I;F9O<FUA=&EO;BX`+"!S=&]R;6)Y
M87(`+"!S=&]R;6)Y87(@)7,@)7,`+"!V87)I97)A;F1E(&UE;&QA;B`E<R!O
M8V@@)7,`+2T@=N1L:B`M+0`Q,BUT:6UM87)S9F]R;6%T`#(T+71I;6UA<G-F
M;W)M870`,C0@=&EM;6%R`#Q&]G)E9^5E;F1E`$5N(&1A=&%B87-K;W!P;&EN
M9R!K<N1V<R!F]G(@86MT=65L;'0@8FQO8VLN`$5T="!F871A;'0@9F5L(&AA
M<B!I;G1RY&9F870`16X@<'5B;&EK(%!'4"UN>6-K96P@:W+D=G,@9O9R(&%T
M="!K<GEP=&5R82!E='0@;65D9&5L86YD92X`16X@<'5B;&EK(%!'4"UN>6-K
M96P@:W+D=G,@9O9R(&%T="!V97)I9FEE<F$@971T('-I9VYE<F%T(&UE9&1E
M;&%N9&4N`$5N('!U8FQI:R!O8V@@<')I=F%T(%!'4"UN>6-K96P@<V%M="!L
M]G-E;F]R9"!K<N1V<R!F]G(@871T(&1E:W)Y<'1E<F$@971T(&UE9&1E;&%N
M9&4N`$5N('!U8FQI:R!O8V@@<')I=F%T(%!'4"UN>6-K96P@<V%M="!L]G-E
M;F]R9"!K<N1V<R!F]G(@871T('-I9VYE<F$@971T(&UE9&1E;&%N9&4N`$5N
M('!U8FQI:R!O8V@@<')I=F%T(%,O34E-12UN>6-K96P@<V%M="!L]G-E;F]R
M9"!K<N1V<R!F]G(@871T(&1E:W)Y<'1E<F$@971T(&UE9&1E;&%N9&4N`$5N
M('!U8FQI:R!O8V@@<')I=F%T(%,O34E-12UN>6-K96P@<V%M="!L]G-E;F]R
M9"!K<N1V<R!F]G(@871T('-I9VYE<F$@971T(&UE9&1E;&%N9&4N`$5N('!U
M8FQI:R!3+TU)344M;GEC:V5L(&MRY'9S(&;V<B!A='0@:W)Y<'1E<F$@971T
M(&UE9&1E;&%N9&4N`$;V<FUI9&1A9W-M;VQN`$SD='0@9O9R;6ED9&%G<W)E
M9VX`1O9R;6ED9&%G<W)E9VX`1O9R;6ED9&%G<W-K=7)A<@!&]G)M:61D86=S
M<VMU<F%R(&UE9"!S;O8`04TO4$T`05!)($E$`$]M(&5D:71O<FX`3VTN+BX`
M0F]T=&5N`$UI='1E;@!!8V-E<'1E<F$@8F5GY')A;@!!8V-E<'1E<F%D`$)E
M:/9R:6=H970@<V%K;F%S(&%T="!S:V%P82!61E,M;6%P<"X`0F5H]G)I9VAE
M="!S86MN87,@871T('-K87!A(%9&4RUF:6PN`$MO;G1O:6YF;W)M871I;VX`
M3/9S96YO<F0@9O9R(&MO;G1O`$MO;G1O="!F<GES=`!"=61G970`Q71GY')D
M97(`3.1G9R!T:6QL`$SD9V<@=&EL;"`E<P!,Y&=G('1I;&P@=6YD97)G<G5P
M<`!LY&=G('1I;&P@=6YD97)B96CV<FEG:&5T`$SD9V<@=&EL;"!HY'(Z`$SD
M9V<@=&EL;"!N>2!G<G5P<`!,Y&=G('1I;&P@;GD@8F5H]G)I9VAE=`!,Y&=G
M('1I;&P@=6YD97)G<G5P<"!T:6QL("<E<R<`3.1G9R!T:6QL('5N9&5R8F5H
M]G)I9VAE="!T:6QL("<E<R<`3.1G9R!T:6QL(&5N(&YY(&%N=N1N9&%R93H`
M3.1G9R!T:6QL(&MO;'5M;@!,Y&=G('1I;&P@;GEA(&UE9&QE;6UA<@!,Y&=G
M('1I;&P@<&%R`$SD9V<@=&EL;"!M96YY;B!F]G(@)7,@<V]M($UO>FEL;&$@
M4VED96)A<@!,Y&=G('1I;&P@:2!M:6X@:V%L96YD97(`3.1G9R!T:6QL(&D@
M861R97-S8F]K.@!,Y&=G('1I;&P@:2!M:6X@861R97-S8F]K`$SD9V<@=&EL
M;"!A;G;D;F1A<F4`3&%D92!T:6QL("<E<R<@=&EL;"!S>7-T96UE="P@;65N
M(&MU;F1E(&EN=&4@;.1G9V$@=&EL;"!E>'1R82`@:6YF;W)M871I;VXZ("5S
M+@!,861E('1I;&P@)R5S)R!T:6QL('-Y<W1E;65T+B!$=2!K86X@;&]G9V$@
M:6X@;G4N`%5P<&SD9V<@878@86YVY&YD87)E(.1R(&EN86MT:79E<F%T+@!!
M9')E<W,`061R97-S8F]K`$%D;6EN:7-T<F%T:6]N("T@86YG92!B96CV<FEG
M:&5T(&;V<B!A;F1R82!A;G;D;F1A<F4`061M:6YI<W1R871I;VX`4F5K;&%M
M`$%F9V%N:7-T86X`06QB86YI96X`06QG97)I970`06QI87,`2G5S=&5R80!*
M=7-T97)I;F<Z`$%L;&$`06QL82!A=71E;G1I<V5R861E(&%N=N1N9&%R90!!
M;&QA(&=R=7!P97(`06QL82!B96CV<FEG:&5T97(`06QL82!F>7)A('-I9&]R
M`%1I;&SE="!F;&5R82!A9')E<W-E<@!4:6QLY70@:6YS=.1L;&YI;F<@9O9R
M('-O<G1E<F%D(&QI<W1A/P!&:6YN<R!R961A;@!!;'1E<FYA=&EV($E-4U`M
M:6YL;V=G;FEN9P!!;'1E<FYA=&EV="!L]G-E;F]R9"!F]G(@24U34`!!;'1E
M<FYA=&EV="!A;G;D;F1A<FYA;6X@9O9R($E-4U``06QT97)N871I=B!E+7!O
M<W0@861R97-S`$%L=&5R;F%T:78@;6%L;`!!;'1E<FYA=&EV('1E>'0Z`$%M
M97)I:V%N<VMA(%-A;6]A`$5T="!F96P@=7!P<W1O9"!NY'(@;.1N:V5N("@E
M<RD@<VMU;&QE(&%N=N1N9&%S`$5T="!F96QA:W1I9W0@=N1R9&4@86YG879S
M+@!%='0@;VOD;G0@9F5L(&AA<B!I;G1RY&9F870`06YD;W)R80!!;F=O;&$`
M06YG=6EL;&$`06YO;GEM('!R;WAY`%-V87(`06YT87)K=&ES`$%N=&EG=6$@
M;V-H($)A<F)U9&$`07!P;&EK871I;VX`07!P;&EK871I;VYS;&ES=&$`07!P
M;&EK871I;VYE;B#D<B!K;&%R+@!697)K<W3D;&P@=&EL;"!U;F1E<G5T9&5L
M;FEN9V%R`$=O9&OD;FX`56YG96;D<FQI9R!S=&]R;&5K`&%P<FEL`$%R86)I
M<VL@*%=I;F1O=W,M,3(U-BD`07)K:79F:6QS=&]R;&5K`$%R:VEV9FEL;F%M
M;@#$<B!D970@<^1K97)T(&%T="!D=2!V:6QL('1A(&)O<G0@8F5GY')A;B!F
M]G(@)7,_`,1R(&1E="!SY&ME<G0@871T(&1U('9I;&P@<F%D97)A("<E<R<@
M;V-H(&5V96YT=65L;&$@=6YD97)G<G5P<&5R/P!!<F=E;G1I;F$`07)M86YI
M96X`07)M96YI<VL@*$%235-#24DM."D`2V]N<W0`07)U8F$`07-C96YS:6]N
M($ES;&%N9`!!<V-I:2!K;VYS=`!!<VEE;B]3=&EL;&$@:&%V<W)E9VEO;F5N
M`$9RY6=A(&5F=&5R(&)E:W+D9G1E;'-E(&EN;F%N('5N9&5R:.5L;'-A:W1I
M=FET971E<B!U=&;V<G,_`%1I;&QD96QN:6YG<VMO;'5M;@!":69O9V%D(.1R
M(&5N(&E#86QE;F1E<B!F:6P@;65D(&5T="!S=F%R('#E(&5N(&)E9^1R86X@
M<V]M(&1U('-K:6-K870L`$;V<G/V:R!T:6QL(&%T="!R861E<F$@96X@9W)U
M<'`@<V]M(&EN=&4@9FEN;G,N`$;V<G/V:R!T:6QL(&%T="!R861E<F$@96X@
M8F5H]G)I9VAE="!S;VT@:6YT92!F:6YN<RX`1O9R<_9K(&%T="#D;F1R82!E
M;B!B96CV<FEG:&5T('-O;2!I;G1E(&9I;FYS+@!&]G)S]FL@871T(.1N9')A
M(&5N('5T9&5L;FEN9R!S;VT@:6YT92!F:6YN<RX`1&5L=&%G87)E`$%T=')I
M8G5T`&%U9W5S=&D`075S=')A;&EE;@#6<W1E<G)I:V4`075T:%]C>7)S<6PZ
M($E-05`M97AT96YS:6]N('-A:VYA<RX`075T:%]C>7)S<6PZ($MO<'!L:6YG
M96X@<V%K;F%R(&9U;FMT:6]N97(@<V]M(&MRY'9S+@!!=71H7V-Y<G5S.B!)
M34%0+65X=&5N<VEO;B!S86MN87,N`$%U=&A?9G1P.B!&5%`M=&EL;.1G9R!S
M86MN87,N($MO;7!I;&5R82!02%`@;65D('-W:71C:&5N("TM96YA8FQE+69T
M<"X`075T:%]I;6%P.B!)34%0+65X=&5N<VEO;B!S86MN87,N`$%U=&A?:W)B
M-3H@:W)B-2UE>'1E;G-I;VX@<V%K;F%S+@!!=71H7VQD87`Z($1E="!GY7(@
M:6YT92!A='0@;.1G9V$@=&EL;"!A;G;D;F1A<F4@:2!!8W1I=F4@1&ER96-T
M;W)Y`$%U=&A?;&1A<#H@1&5T(&?E<B!I;G1E(&%T="!R861E<F$@86YVY&YD
M87)E(&9RY6X@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z($Q$05`M=&EL
M;.1G9R!S86MN87,N`$%U=&A?;&1A<#H@2V%N(&EN=&4@;.1G9V$@=&EL;"!A
M;G;D;F1A<F4@)R5S)RX@4V5R=F5R;B!S=F%R861E.B``075T:%]L9&%P.B!+
M86X@:6YT92!R861E<F$@86YVY&YD87)E("5S`$%U=&A?;&1A<#H@2V%N(&EN
M=&4@=7!P9&%T97)A(&%N=N1N9&%R92`E<P!!=71H7VQD87`Z($1E="!GY7(@
M:6YT92!A='0@=7!P9&%T97)A(&%N=N1N9&%R92!I($%C=&EV92!$:7)E8W1O
M<GDN`$%U=&A?;6-A;#H@34-!3"UE>'1E;G-I;VX@<V%K;F%S+@!!=71H7W-M
M8F%U=&@Z('-M8F%U=&@M97AT96YS:6]N('-A:VYA<RX`075T96YT:7-E<FEN
M9R!T:6QL($E-05`M<V5R=F5R(&UI<W-L>6-K861E<RX`075T96YT:7-E<FEN
M9R!M:7-S;'EC:V%D97,`075T96YT:7-E<FEN9R!M:7-S;'EC:V%D97,N("5S
M`$%U=&5N=&ES97)I;F<@879V:7-A9&5S(&%V(%)!1$E54RUS97)V97)N+@!!
M=71E;G1I<V5R:6YG('1I;&P@1E10+7-E<G9E<B!M:7-S;'EC:V%D97,N`$%U
M=&5N=&ES97)I;F<@=&EL;"!334(M<V5R=F5R(&UI<W-L>6-K861E<RX`5&EL
M;&?D;F=L:6=A(&;D;'0Z`%;D;G1A<B!PY2!S=F%R`$%Z97)B86EJ86X`07IU
M<F)LY0!"3T9(+75R<^1K=&5R`$)A:V=R=6YD`$)A:V=R=6YD<V;D<F<`1F5L
M86MT:6=T(&SV<V5N;W)D(&;V<B!+97)B97)O<P!&96QA:W1I9W0@86YVY&YD
M87)N86UN(&;V<B!+97)B97)O<P!"86AA;6%S`$)A:')A:6X`0F%L=&ES:R`H
M25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R=&ED`%)A9'1I9`!"87)B861O
M<P!"87)B:64`0F%S:V%T86QO9R`G)7,G(&;V<B!B:6QD97(@:&ET=&%D97,@
M:6YT92X`0F%S;&EN:F4`5FET<GES<VQA;F0`0F5L9VEE;@!"96QI>F4`0F5N
M:6X`0F5R;75D80!":'5T86X`1O9D96QS961A9P!";&]C:R`G)7,G(&;V<B!A
M<'!L:6MA=&EO;B`G)7,G('-A:VYA<RX`0FQO8VMI;G-TY&QL;FEN9V%R`$)L
M;V-K='EP`$)LY2!MY6YE`$)LY71T(&]C:"!V:71T`$9E=`!";VQI=FEA`$)O
M:VWD<FME;@!286T`4F%M8G)E9&0Z`%)A;6%R`$)O<VYI96X@;V-H($AE<GIE
M9V]V:6YA`$+E9&$`0F]T<W=A;F$`0F]T=&5N`$)O=79E="!)<VQA;F0`0G)A
M<VEL:65N`$)R:71T:7-K82!T97)R:71O<FEE="!I($EN9&ES:V$@;V-E86YE
M;@!"<G5N`$)R=6YE:0!"=6QG87)I96X`4'5N:W1L:7-T80!"=7)K:6YA($9A
M<V\`0G+D;F0@3W)A;F=E`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T
M:6]N(%!O:6YT<P!#7V5L;"!I;G-TY&QL;FEN9V%R+BXN`$-A8VAE:6YI=&EE
M<FEN9R#D<B!I;G1E(&9U;&QS=.1N9&EG+@!+86QE;F1E<@!,=6=N=`!+86UB
M;V1J80!+86UE<G5N`$MA;6]U9FQA9V4`2V%N(&EN=&4@;F]L;'-TY&QL82!L
M]G-E;F]R9"!A=71O;6%T:7-K="P@:V]N=&%K=&$@9&EN(&%D;6EN:7-T<F%T
M]G(N`$MA;B!I;G1E('-K<FEV82!T:6QL(&9I;"`G)7,G`$1E="!GY7(@:6YT
M92!A='0@861M:6YI<W1R97)A(&5X=&5R;F$@<V5S<VEO;G-H86YT97)A<F4N
M`$MA;B!I;G1E(&MO;G1A:W1A($E-05`M<V5R=F5R;CH@)7,`2V%N(&EN=&4@
M]G!P;F$@9FEL("<E<R<`2V%N861A`$%V8G)Y=`!!=F)R>70@<')O8FQE;7)A
M<'!O<G0`2V%N(&EN=&4@<F%D97)A("<E<R<N`$MA;B!I;G1E(&AI='1A(&5N
M('1E;7!RY'(@;6%P<"X`2V%N(&EN=&4@9F]R='/D='1A('5T86X@)VWE;&9I
M;"<M<&%R86UE=&5R+@!+86X@:6YT92!R861E<F$@;6%P<"`G)7,G+@!+86X@
M:6YT92!R861E<F$[("5D(&)A<FX@97AI<W1E<F%R+@!+86X@:6YT92!D:7)I
M9V5R82!M961D96QA;F1E('1I;&P@86YG:79E="!N=6UM97(N`$MA<"!697)D
M90!2=6)R:6L`3W!E<F%T]G(`2V%T96=O<FEE<B!O8V@@<G5B<FEK97(`0V%Y
M;6%N($ES;&%N9',`36]B:6QT96QE9F]N`$-E;&QI;G-TY&QL;FEN9V%R`$-E
M;&QU=&9Y;&QN860Z`$-E;&QI;G-TY&QL;FEN9V%R`$-E;&QM96QL86YR=6TZ
M`$UO8FEL=&5L969O;@!#96QT:7-K("A)4T\M.#@U.2TQ-"D`0V5N=')E<F%D
M`$-E;G1R86QA9G)I:V%N<VMA(')E<'5B;&EK96X`0V5N=')A;&5U<F]P96ES
M:R`H25-/+3@X-3DM,BD`0V5R=&EF:6MA=&1E=&%L:F5R`$-E<G1I9FEK873D
M9V%R90!#97)T:69I:V%T<&]L:6-I97,`5&-H860`3W)D9O9R86YD90#$;F1R
M80#$;F1R82!D:71T(&SV<V5N;W)D`,1N9')A(&;V<G9A;&0@:61E;G1I=&5T
M`,1N9')A(&YA;6X@;V-H(&%D<F5S<R!S;VT@;6]T=&%G87)N82!S97(@;N1R
M(&1E(&SD<V5R(&]C:"!S=F%R87(@<.4@9&EN82!M961D96QA;F1E;BX`071T
M(&)Y=&$@;/9S96YO<F0@<W3V9',@:6YT92!M960@9&5N(&YU=F%R86YD92!K
M;VYF:6=U<F%T:6]N96XN("!687(@9V]D(&MO;G1A:W1A(&%D;6EN:7-T<F%T
M]G)E;BX`5&MN`$MO;G1R;VQL97)A(&SD;FLN+BX`36%R:V5R82!D92!A:W1I
M=FET971E<B!D=2!V:6QL('5T9O9R82!N=2X`0VAI;&4`2VEN80!+:6YE<VES
M:W0@9O9R96YK;&%T("A'0C(S,3(I`$MI;F5S:7-K="!T<F%D:71I;VYE;&QT
M("A":6<U*0!6Y&QJ(&%P<&QI:V%T:6]N.@!6Y&QJ(&SV<V5N;W)D`%;D;&H@
M86YVY&YD87)N86UN`%;D;&H@Y71GY')D.@!6Y&QJ(&AU<B!D871U;2!S:V%L
M;"!V:7-A<SH`5N1L:B!L:7-T<W1I;"`H9O9R('-O<G1E<F%D92!L:7-T;W(I
M`$IU;/9N`$ML87-S9&5F:6YI=&EO;B!F]G(@)7,@<V%K;F%S+@!296YS80!2
M96YS82!-4T]F9FEC92UT86=G87(`4F5N<V$@9G+E9V$`4F5N<V$@86YVY&YD
M87)E.B`E<P!296YS82!A;G;D9&YA<F4`4F5N<V$@86YVY&YD87)D871A`%-E
M;F%R92!U<'!K;&%R;F%N9&4`2VQI8VMA(&;V<B!A='0@9F]R='/D='1A`$-L
M:6-K871E;&P@=FEA($A45%``4W3D;F<@9O9N<W1E<@!-;VQN`%1I9&EG82!M
M;VQN`$UO;&YI;F=T`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$MO;7!R:6UE
M<F$@<VED;V;D;'1E=`!+;VUP<FEM97)A9&4@<F%M87(`2V]L;VUB:6$`1N1R
M9P!&Y')G:&%N=&5R87)E`$;D<F=V86P`2V]L=6UN97(Z`$MO;'5M;B!R=6)R
M:6ME<@!,=7-T:6=H971E<@!+;VUM86YD;P!+;VUM86YD;V;V;G-T97(`2V]M
M;65N=&%R`$YA;6X`0V]M;W)O<P!&]G)E=&%G`%-L=71F]G)D`%-K<FEV(&UE
M9&1E;&%N9&4@*"5S*0!$871O<F5R`%;D9&5R`%;D9&5R`$MO;F9I9W5R871I
M;VYS<VMI;&QN861E<@!);G-TY&QL;FEN9V%R(&;V<B!A='0@<WEN:W)O;FES
M97)A(&UE9"!H86YD9&%T;W)E<BP@<VUA<G1A('1E;&5F;VYE<B!O8V@@3W5T
M;&]O:P!+;VYF:6=U<F%T:6]N(&)E:/9V97(@=7!P9&%T97)A<RX`2V]N9FEG
M=7)E<F$@)7,`0F5K<N1F=&$@;/9S96YO<F0`2V]N9V\`2V]N9V\`1O9R8FEN
M9&5L<V4@;6ES<VQY8VMA9&5S+@!&]G)B:6YD96QS92!M:7-S;'EC:V%D97,Z
M(`!&]G)B:6YD96QS92!M960@<'5B;&EK(&YY8VME;'-E<G9E<B!N96MA9&5S
M+@!&]G)B:6YD96QS92!M960@<'5B;&EK(&YY8VME;'-E<G9E<B!N96MA9&5S
M.B`E<R`H)7,I`$;V<F)I;F1E;'-E(&UE9"!&5%`M<V5R=F5R(&UI<W-L>6-K
M861E<RX`2V]N=&%K=&5R`$MO;G1A:W1E<B!L861E<R!T:6QL(&D@9&EN(&%D
M<F5S<V)O:RX`26YN96CE;&QS='EP(&;V<B!K;VUP<FEM97)A9"!F:6PZ(`!)
M;FYE:.5L;"!I("<E<R<`1F]R='/D='0`0V]O:R!)<VQA;F1S`$-O;VMI90!+
M;W!I97)A`$MO<&EE<FEN9R!M:7-S;'EC:V%D97,Z("5S`$MO<&EE<F$@;6%R
M:V5R:6YG`$UA:G-B;&]M;6$`2V]S=&YA9',M240`0V]S=&$@4FEC80!%;&9E
M;F)E;G-K=7-T96X`2V%N(&EN=&4@4$=0+6MR>7!T97)A(&UE9&1E;&%N9&4N
M`$MA;B!I;G1E(%!'4"UK<GEP=&5R82!M961D96QA;F1E.B``2V%N(&EN=&4@
M4$=0+7-I9VYE<F$@;65D9&5L86YD92X`2V%N(&EN=&4@4$=0+7-I9VYE<F$@
M;65D9&5L86YD93H@`$MA;B!I;G1E(%,O34E-12UK<GEP=&5R82!M961D96QA
M;F1E+@!+86X@:6YT92!3+TU)344M<VEG;F5R82!M961D96QA;F1E+@!+86X@
M:6YT92!LY&=G82!T:6QL(&MO;G1A:W0N("5S`$UI<W-L>6-K861E<R!A='0@
M:V]N=&%K=&$@3$1!4"!S97)V97(N`$MA;B!I;G1E('9E<FEF:65R82!K;VYT
M;W-A;&1O+B`E<P!+=6YD92!I;G1E(&%N<VQU=&$@=&EL;"!,1$%0+7-E<G9E
M<BX`2V%N(&EN=&4@:V]N=&%K=&$@<V5R=F5R("<E<R<@=FEA($944#H@)7,`
M2V%N(&EN=&4@<VMA<&$@9&ES=')I8G5T:6]N<VQI<W1A+B`E<P!+86X@:6YT
M92!D96MR>7!T97)A(%!'4"UD871A+@!+86X@:6YT92!D96MR>7!T97)A(%!'
M4"UD871A.B``2V%N(&EN=&4@9&5K<GEP=&5R82!3+TU)344M9&%T82X`2V%N
M(&EN=&4@<F%D97)A(&MO;G1A:W0N("5S`$MA;B!I;G1E(')A9&5R82!D:7-T
M<FEB=71I;VYS;&ES=&$N("5S`$MA;B!I;G1E(')A9&5R82!U<'!G<F%D97)I
M;F=S<V-R:7!T('1I;&PZ("5S+@!+86X@:6YT92!B97-TY&UM82!M;W1T86=A
M<F5N<R!E4&]S="UA9')E<W,N`$MA;B!I;G1E(&CD;71A(&MO;7!L971T(&%D
M<F5S<V)O:RX`2V%N(&EN=&4@:.1M=&$@:V]M<&QE='0@9&ES=')I8G5T:6]N
M<VQI<W1A+@!+86X@:6YT92!HY&UT82!K;VUP;&5T="!L:7-T82#V=F5R(&1I
M<W1R:6)U=&EO;G-L:7-T;W(N`$MA;B!I;G1E(&QA9&1A('-T<F%T96=I("<E
M<R<N`$MA;B!I;G1E(&QA9&1A('-T<F%T96=I("<E<R<N`$MA;B!I;G1E('-K
M87!A(&UA<'`@)R5S)RX`2V%N(&EN=&4@<VMA<&$@;6%P<"`G)7,G+@!+86X@
M:6YT92!HY&UT82!P=6)L:6L@;GEC:V5L(&9RY6X@;GEC:V5L<V5R=F5R;BX`
M2V%N(&EN=&4@]G!P;F$@)R5S)R!F]G(@<VMR:79I;F<N`$MA;B!I;G1E(/9P
M<&YA("5S+@!+86X@:6YT92#V<'!N82`G)7,G(&;V<B!S:W)I=FEN9RX`2V%N
M(&EN=&4@]G!P;F$@36%I;G1E;F%N8V5?5&%S:R!M;V1U;"`E<P!+86X@:6YT
M92#V<'!N82!M87!P96X@)R5S)P!+86X@:6YT92#V<'!N82!M87!P("<E<R<`
M2V%N(&EN=&4@:V]N=&%K=&$@3$1!4"!S97)V97(N`$MA;B!I;G1E(&SD<V$@
M)7,N`$1E="!G:6-K(&EN=&4@871T(.5T97)S=.1L;&$@;/9S96YO<F1E="!F
M]G(@9&5N(&%N9VEV;F$@86YVY&YD87)E;BX@3N5G;VX@96QL97(@;N5G<F$@
M878@=7!P9VEF=&5R;F$@Y'(@:6YT92!K;W)R96MT82X@1O9R<_9K(&EG96X@
M96QL97(@:V]N=&%K=&$@861M:6YI<W1R873V<F5N(&]M(&1U(&)E:/9V97(@
M:&KD;'`N`$MA;B!I;G1E(&CD;71A($%#3`!+86X@:6YT92!HY&UT82!A9')E
M<W-B;VLN("5S`$MA;B!I;G1E(&CD;71A(&1I<W1R:6)U=&EO;G-L:7-T82X@
M)7,`2V%N(&EN=&4@:.1M=&$@9&ES=')I8G5T:6]N<VQI<W1O<BX@)7,`2V%N
M(&EN=&4@:.1M=&$@9'-E<G9E<F9U;FMT:6]N97(`2V%N(&EN=&4@Y71E<G-T
MY&QL82!K;VYF:6=U<F%T:6]N96XN`$MA;B!I;G1E(')A9&5R82!M87!P("<E
M<R<N`$MA;B!I;G1E(')A9&5R82!M87!P("<E<R<N`$MA;B!I;G1E('-P87)A
M(&MO;F9I9W5R871I;VX@9O9R("5S+@!+86X@:6YT92!S<&%R82!B86-K=7`M
M:V]N9FEG=7)A=&EO;BX`2V%N(&EN=&4@<W!A<F$@96X@8F%C:W5P+6MO;F9I
M9W5R871I;VXZ("5S+@!+86X@:6YT92!S<&%R82!U<'!G<F%D97)I;F=S<V-R
M:7!T('1I;&PZ("5S+@!+86X@:6YT92!S<&%R82!B86-K=7`M:V]N9FEG=7)A
M=&EO;B`E<RX`2V%N(&EN=&4@<W!A<F$@:V]N9FEG=7)A=&EO;G-F:6QE;B`E
M<RX@1'4@:V%N(&%N=&EN9V5N(&%N=N1N9&$@96X@878@86QT97)N871I=F5N
M(&%T="!S<&%R82!K;V1E;B!T:6QL("5S(&5L;&5R(&MO<&EE<F$@:V]D96X@
M;F5D86X@=&EL;"`E<RX`2V%N(&EN=&4@<_9K82!I($Q$05`M:V%T86QO9V5N
M+@!+86X@:6YT92!R861E<F$@)R5S)RX`2V%N(&EN=&4@<F%D97)A("<E<R<N
M`$MA;B!I;G1E('5P<&1A=&5R82!K;VYT86MT+B`E<P!+86X@:6YT92!U<'!D
M871E<F$@9&ES=')I8G5T:6]N<VQI<W1A+B`E<P!+86X@:6YT82!S<&%R82!K
M;VYF:6=U<F%T:6]N(&;V<B`G)7,G.B`E<P!+86X@:6YT92!H:71T82!-;WII
M;&QA<R!S:61O9N1L="X@5F5R:69I97)A(&%T="!S:61O9N1L=&5T(.1R(/9P
M<&5T+@!+86X@:6YT92!G92!A;G;D;F1A<F5N("<E<R<@86YG:79N82!RY'1T
M:6=H971E<B!T:6QL(&UA<'!E;B`G)7,G.B`E<P!2Y&MN860@=&5X=`!,86YD
M`$MU<G-E<@!3:V%P80!3:V%P82!LY&YK`%-K87!A(&YY`%-K87!A('5N9&5R
M;6%P<`!"96CV<FEG:&5T97(@9O9R(.1G87)A`$MR961I=&MO<G1S;G5M;65R
M`$MR;V%T:65N`$MU8F$`06MT=65L;&$@-"!F87-E<@!!:W1U96QL('-E<W-I
M;VX`06MT=65L;"!T:60`06MT=65L;"!54DP@Y'(`06MT:79A(&%N=N1N9&%R
M90!!:W1U96QL="!VY&1E<@!!:W1U96QL82!V:6QL:V]R.B``06MT=65L;"!S
M=&EL`%-K<N1D9&%R<WD@86MT:79I=&5T97(@<V]M(&OV<G,@=FED(&EN;&]G
M;FEN9R!T:6QL("5S+@!+;&EP<"!U=`!+;&EP<"!U<G9A;`!#>7!E<FX`2WER
M:6QL:7-K("A+3TDX+5(I`$MY<FEL;&ES:R`H5VEN9&]W<RTQ,C4Q*0!+>7)I
M;&QI<VLO56MR86EN<VL@*$M/23@M52D`5&IE8VMI96X`1$0`1&%G;&EG`$1A
M=&%4<F5E(&)LY&1D<F%R90!$871A8F%S=7!P<VQA9P!$871U;0!$871U;2!M
M;W1T86=E=`!$871U;79A;`!$86<`7U)A9&5R82!K;VQU;6X`9&5C96UB97(`
M1&5C:6UA;&5R`$%V8O9J=`!-:6YS:V$@:6YD<F%G`$;V<G9A;'0`1O9R=F%L
M9"!FY')G`$;V<G9A;&0@:61E;G1I=&5T`$;V<G9A;'0@<VMA;`!$969I;FET
M:6]N97(`1&5L96=E<F$@<&]S:71I;VX`1&5L96=E<F%D`%)A9&5R80!2861E
M<F$@8V5L;`!2861E<F$@9W)U<'``4F%D97)A(&QO9V<`4F%D97)A(&)E:/9R
M:6=H970`4F%D97)A(&]C:"!R96YS82!M961D96QA;F1E;@!2861E<F$@8V5L
M;`!2861E<F$@:V]L=6UN`%)A9&5R82!B969I;G1L:6<@86QT97)N871I=FUA
M;&P`4F%D97)A9&4@;65D9&5L86YD96X`4F%D97)A(&)E:/9R:6=H970@9O9R
M("<E<R<`4F%D97)A(&)E:/9R:6=H970@9O9R("<E<R<@;V-H('5N9&5R8F5H
M]G)I9VAE=&5R/P!2861E<F$@<F%D`%)A9&5R82!V86QD(&ED96YT:71E=`!2
M861E<F$@=6YD97)M87!P87(`4F%D97)A(&%K='5E;&P@:V]L=6UN`%)A9&5R
M82!A:W1U96QL(')A9`!2861E<F$@9&5N(&CD<B!LY&YK96X`4F%D97)A9&4@
M=7!P9W)A9&5R:6YG<W-C<FEP=&5T("<E<R<N`$QE=F5R86YS=&ED`$1A;FUA
M<FL`079S;.4@8F5GY')A;@!!=G-LY2!B96?D<F%N(&]M(&QE9&EG+W5P<'1A
M9V5N+6EN9F]R;6%T:6]N`$)E<VMR:78@<')O8FQE;65T`$)E<VMR:79N:6YG
M`$1E=&%L:F5R("AO8VMSY2!I($AO<F1E<R!L;V=G9FEL*3H`1&5T86QJ97(@
M:&%R(&QO9V=A=',@9O9R('-Y<W1E;6%D;6EN:7-T<F%T]G)E;BX`571V96-K
M;&EN9P!$86=G<'5N:W0`1&%G9W!U;FMT(&;V<B!S96YA<W1E('1I;6UE;CH@
M`$1A9V=P=6YK=#H@`%)I:W1N:6YG(';D;G-T97(@=&EL;"!H]F=E<@!2:6MT
M;FEN9R!H]F=E<B!T:6QL(';D;G-T97(`2V%T86QO9P!6:7-A(#(T+71I;6UA
M<G,@:VQO8VMA/P!6:7-N:6YG<VEN<W3D;&QN:6YG87(`5FES82!D971A;&IE
M<F%D(&;V<G5T<^1G96QS90!6:7-A(&;V<G5T<^1G96QS92`H5$%&*0!6:7-N
M:6YG<V9O<FUA=`!!=G-K:6QJ87)E`$1J:6)O=71I`%)A9&5R82!I;G1E`$%N
M=N1N9"!I;G1E(&UA:6YT96YA;F-E+G!H<"!D:7)E:W0`26YN96CE;&QE<B!F
M]G)S=&$@<F%D96X@9N1L=&YA;6YE;C\@3VT@)VIA)RP@;6%R:V5R82!HY'(Z
M`$1O;6EN:6MA;G-K82!R97!U8FQI:V5N`$AA<B!D=2!I;F=E="!K;VYT;S\@
M4F5G:7-T<F5R82!D:6<N`$CD;71A`$CD;71A("5S`$CD;71A(&=E;F5R97)A
M9"!K;VYF:6=U<F%T:6]N('-O;2!02%`M<VMR:7!T+@!$<F]P<&QI<W1A`$1R
M;V=E<@!%+7!O<W0`1')I=G)U=&EN(&;V<B!%+7!O<W0@=&EL;"!335,M8G)Y
M9V=A.R!F]G(@;W!E<F%T]G)E<B!S;VT@=&EL;&AA;F1A:.5L;&5R(&1E;FYA
M('1JY&YS="X`1D5,`$5K=6%D;W(`Q&YD<F$`Q&YD<F$@8FQO8VL`Q&YD<F$@
M9W)U<'``Q&YD<F$@8F5H]G)I9VAE=`#$;F1R82!B96CV<FEG:&5T97(`Q&YD
M<F$@8F5H]G)I9VAE=&5R(&;V<B`E<P#$;F1R82!I;G-TY&QL;FEN9V%R(&;V
M<CH`Q&YD<F$@8F5H]G)I9VAE=&5R(&;V<B`G)7,G`,1N9')A(&)E:/9R:6=H
M971E<B!F]G(@)R5S)P!5=&)I;&1N:6YG`$5G>7!T96X`16P@4V%L=F%D;W(`
M16QE;65N="XN+@!%;0!%+7!O<W0`12UP;W-T861R97-S`$4M<&]S=&%D<F5S
M<V5R(&WE<W1E('-TY&UM82#V=F5R<F5N<RX`12UP;W-T;65D9&5L86YD92!M
M960@8F5K<N1F=&5L<V4`12UP;W-T('1I;&P@4TU3+6)R>6=G80!+Y&YS;&]I
M:V]N97(`5&]M="!M961D96QA;F1E+@!4;VUT(')E<W5L=&%T+@!4;VUT('/V
M:VMR:71E<FEA`%-L=70`4VQU="#E<@!&]G)S=&]R82!E9&ET;W(`06YG92!S
M]FMVY&<@*%523"D@=&EL;"!B:6QD96X@:.1R`%-+<FEV(&)O:W-TY'9E<FYA
M(&YE9&%N.@!&96P`1F5L('9I9"!S:V%P86YD92!A=B!B;&]C:SH@)7,`1F5L
M('9I9"!R861E<FEN9R!A=B!S>6YK<F]N:7-E<FEN9W-MY')K93H@)7,`1F5L
M('9I9"!R861E<FEN9R!A=B!S>6YK<F]N:7-E<FEN9W-L;V=G.B`E<P!&96P@
M;N1R(&EN;F5HY6P@:.1M=&%D97,Z("5S`$9E;"!U;F1E<B!SY&YD;FEN9R!A
M=B!S=F%R<VUE9&1E;&%N9&4Z("5S`$9E;"!V:60@=7!P9&%T97)I;F<@878@
M;/9S96YO<F0Z("5S`$9E;"!V:60@<VMR:79N:6YG("<E<R<N`$9E;"!V:60@
M<VMR:79N:6YG(&%V("<E<R<N`$5S=&QA;F0`171I;W!I96X`171N:7-K`$5U
M<F]P80!687(@,34Z92!M:6YU=`!687)A;FYA;B!M:6YU=`!687(@,S`Z92!S
M96MU;F0`5F%R(#4Z92!M:6YU=`!687)J92!I;FQO9V=N:6YG`%9A<FIE(&AA
M;'9T:6UM90!687)J92!M:6YU=`!%>&5M<&5L('#E(';D<F1E;CH`2_9R`$5X
M<&%N9&5R80!%>'!A;F1E<F$@<VED;V;D;'0`1O9R=N1N=&%D92`G*2<`1O9R
M=N1N=&%D92!E;G-K:6QT(&]R9"!E;&QE<B!C:71E<F%T('/V:V)E9W)E<'``
M1O9R9F%L;&]D871U;0!%>'!O;F5N=`!&]G)G<G5N9'-FY')G`$QA9&1A('5P
M<"!K;VYF:6=U<F%T:6]N('9I82!&5%`N`$UI<W-L>6-K861E<R!A='0@:.1M
M=&$@:6YS=.1L;&YI;F=A<BX`36ES<VQY8VMA9&5S(&%T="!K;VYT86MT82!,
M1$%0('-E<G9E<BX`36ES<VQY8VMA9&5S(&%T="!K;VYT86MT82!334(@<V5R
M=F5R+@!-:7-S;'EC:V%D97,@871T(&MO<&EE<F$@9G+E;B`G)7,G+@!-:7-S
M;'EC:V%D97,@871T(&MO<&EE<F$@=&EL;"`G)7,G+@!-:7-S;'EC:V%D97,@
M871T('-K87!A(&YY(%-!4TPM9O9R8FEN9&5L<V4N`$UI<W-L>6-K861E<R!A
M='0@9FQY='1A('1I;&P@)R5S)RX`36ES<VQY8VMA9&5S(&%T="!HY&UT83H@
M)7,`0G)A`$9A;&ML86YD<_9A<FYA`$;D<O9A<FYA`$9A=&%L="!F96PZ`$9A
M>`!&87AA<@!F96)R=6%R:0!+Y&YN<R!S;VT`2^1N;G,@<V]M.B``1N5T86QI
M9V$@<VMU<F%R`$;E=&%L:6=A('-N]G-K=7)A<@!&Y&QT;6%T<FES`$9I9VQE
M="!#05!40TA!`$9I9VQE='1Y<'-N:71T`$9I:FD`1FEL`$%N=&%L(&9I;&5R
M.B`E<R!F:6P`06YT86P@9FEL97(Z("5S(&9I;&5R`$9I;&AA;G1E<F%R90!&
M:6QN86UN`$9I;'9A;`!&:6QU<'!L861D;FEN9P!&:6QU<'!L861D;FEN9R!S
M=/9D<R!I;G1E+@!&:6QT97(`1FEN;&%N9`!&]G)S=&$@:&%L=F%N`$;V<G-T
M82!K=F%R=&5N`$UA<'`@)7,@97AI<W1E<F%R(&EN=&4N`$9O;G1FY')G`$UA
M=`!&]G(@=V5B8FSD<V%R92!S;VT@:6YT92!S=/9D97(@8FEL9&5R`%!R;V=N
M;W,@*%1!1BD`06YT86P@9&%G87(@9O9R('!R;V=N;W,@*'9A<FIE(&1A9R!B
M971Y9&5R(&5N('!R;V=N;W,@9O9R(&1A9R!O8V@@96X@9O9R(&YA='0I`$=L
M]FUT(&1I='0@;/9S96YO<F0_`$9O<FUU;.1R`%9I<VAE='-O<F0`5'EP(&%V
M('9I<VAE='-O<F0`5FES:&5T<V]R9`!6:7-H971S;W)D(#(`1F]R=6T`5FED
M87)B969O<F1R87(`1G(`4F%M87(`1G)A;FMR:6ME`$9R86YK<FEK92P@365T
M<F]P;VP`3&5D:6<O57!P=&%G96X@:6YF;W)M871I;VX`3&5D:6<O57!P=&%G
M96X@<W9A<@!,961I9R]U<'!T86=E;BUF]G)F<N5G86X`4W9A<B!PY2!L961I
M9R]U<'!T86=E;BUF]G)F<N5G86X`1G)A;G-K82!'=6EA;F$`1G)A;G-K82!0
M;VQY;F5S:65N`$9R86YS:V$@<_9D<F$@=&5R<FET;W)I97(`1G+E;@!&<N5N
M(&1E;B``1G5L;'-TY&YD:6<@8F5S:W)I=FYI;F<`1G5L;&WE;F4`1G5L;'-T
MY&YD:6=T(&YA;6X`1V%B;VX`1V%L;&5R:2!A='0@=&$@8FEL9"!F<N5N`$=A
M;&QE<FDZ`$=A;6)I80!'96YE<F5R82!K;VYF:6=U<F%T:6]N(&;V<B`E<P!'
M96YE<F5R860@:V]D`$=E;W)G:65N`%1Y<VML86YD`$=H86YA`$=I8G)A;'1A
M<@!&]G)N86UN`$=L;V)A;&$@:6YS=.1L;&YI;F=A<@!/2P!';V5D96P`1V]O
M9VQE:V%R=&]R`$=O;V=L97/V:VYI;F<`1W+E<VMA;&$`1W)E:VES:R`H25-/
M+3@X-3DM-RD`1W+V;@!'<O9N;&%N9`!'<F%N861A`$=RY0!'<G5P<&%D;6EN
M:7-T<F%T:6]N`$=R;W5P7VQD87`Z($MA;B!I;G1E(&SD9V=A('1I;&P@9W)U
M<'`@)R5S)RX@4V5R=F5R;B!S=F%R861E.B``1W)O=7!?;&1A<#H@2V%N(&EN
M=&4@<F%D97)A(&=R=7!P("<E<R<`1W)O=7!?;&1A<#H@2V%N(&EN=&4@=7!P
M9&%T97)A(&=R=7!P("<E<R<`1W)U<'!E<@!'=6%M`$=U871E;6%L80!'=65R
M;G-E>0!'Y'-T8F5H]G)I9VAE=&5R`%1JY&YS=&5R(&;V<B!GY'-T97(`1^1S
M=&)O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=6EN96$`2%1-3`!(5$U,07)E
M82!VY&=R87(@871T(')A9&5R82!S:7-T82!C96QL96X@:2!E;B!R860N`$A4
M34Q!<F5A(';D9W)A<B!A='0@<F%D97)A('-I<W1A(&MO;'5M;F5N(&D@96X@
M=&%B96QL+@!(5$U,07)E82!VY&=R87(@871T(')A9&5R82!S:7-T82!R861E
M;B!I(&5N('1A8F5L;"X`2%144"!!=71E;G1I<V5R:6YG('-A:VYA<RX`2&%I
M=&D`2&%S:&%L9V]R:71M`$1I;6UA`%)U8G)I:P!2=6)R:6ME<@!(96%R9"T@
M;V-H($UC1&]N86QD]F%R;F$`2W)A9G1I9V$@Y7-K<VMU<F%R`$AE8G)E:7-K
M("A)4T\M.#@U.2TX+4DI`$CV:F0`2/9J9"`H<&EX;&%R*0!(:N1L<`!(:N1L
M<"!M960@961I=&]R;@!(:N1L<&9U;FMT:6]N`$AE;6ES9N1R`$CD<B#D<B!B
M]G)J86X@878@9FEL96XZ`$CV9P!(95]M`$AE;0!!9')E<W,L(&AE;0!(96UK
M871A;&]G`%1E;&5F;VXL(&AE;0!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`
M2&]R9&4O2V]L86(Z($]G:6QT:6=T("5S(%A-3"UD871A('#E='+D9F9A9&5S
M(&D@;65D9&5L86YD92`E<P!(;W)D92]+;VQA8CH@26YG970@;65D9&5L86YD
M92!M871C:&%R(&]B:F5K=&5T("5S`$AO<F1E+TMO;&%N.B!);F=E="!O8FIE
M:W0@878@='EP96X@)7,@:&ET=&%D97,@:2!M961D96QA;F1E="`E<P!(;W)D
M92]+;VQA8CH@4F%D97)A9&4@)7,@)R5S)P!(;W)D92]+;VQA8CH@26YT96=R
M871I;VYS;6]T;W)N(&MRY'9E<B`G9&]M>&UL)RUT:6QLY&=G970@9O9R(%!(
M4`!(;W)D92]+;VQA8CH@2V%N(&EN=&4@<VMA<&$@;GET="!834PM='+D9"!F
M]G(@;V)J96MT("5S`$AO<F1E+TMO;&%B.B!+86X@:6YT92!R861E<F$@)7,@
M)R5S)SH@)7,`2&]R9&4O2V]L86(Z($MA;B!I;G1E(&CD;71A($U)341%+4E$
M(&;V<B!D96QE;B!M960@='EP("5S`$AO<F1E+TMO;&%B.B!+86X@:6YT92!S
M>6YK<F]N:7-E<F$@)7,@)R5S)SH@)7,`2&]R9&4O2V]L86(Z($MA;B!I;G1E
M('-Y;FMR;VYI<V5R82!U=&1E;&YI;F=A<CH@)7,`2&]R9&4O2V]L86(Z($]K
MY&YD('5T9&5L;FEN9R`G)7,G`$AO<FES;VYT96QL(&QI;FIE`$AO<FES;VYT
M96QL('5T9GEL;&YA9`!(;W)I<V]N=&5L;#H`2'5R(&AA;6YA9&4@9'4@:.1R
M/R`H5F%R(&=O9"!R87!P;W)T97)A(&1E='1A(2D`2'5R(&WE;F=A(&MO;'5M
M;F5R('9I;&P@9'4@<VSE(&EH;W`_`$AU<B!MY6YG82!FY&QT("AK;VQU;6YE
M<BD@9FEN;G,@9&5T/P!(=7(@;>5N9V$@<F%D97(@=FEL;"!D=2!S;.4@<V%M
M;6%N/P!&=6MT:6=H970`1G5K=&EG:&5T.@!(=6UO<FES=&5R`%5N9V5R;@!3
M:V%P86YD92!A=B!)34%0+6UA<'`@;6ES<VQY8VMA9&4Z("5S`%)A9&5R:6YG
M(&%V($E-05`M;6%P<"!M:7-S;'EC:V%D97,Z("5S`%-K87!A;F1E(&%V('%U
M;W1A(&;V<B!)34%0+6UA<'`@;6ES<VQY8VMA9&5S.B`E<P!)4"UA9')E<W,`
M25`M861R97-S(.1R(&EN=&4@=&EL;&?D;F=L:6<N`$E0+6%D<F5S<R#D<B!I
M;G1E(&EN;VT@9V]D:^1N="!#2412+6)L;V-K+@!&]G)S]FL@871T(&MR:6YG
M9^4@25`M;.5S+@!)7VYF;V=A(')A9"!F]G)E`$ES;&%N9`!%;F)A<G0@:6MO
M;F5R`$EK;VYE<B!F]G(@)7,`26MO;F5R(&UE9"!T97AT`$ED96YT:71E=&5N
M<R!N86UN.@!/;2!D970@:6YT92!V:7-A<R!K;W)R96MT+"`E<R!F]G(@871T
M(/9P<&YA(&D@;GET="!F]FYS=&5R+@!/;2!D=2!I;G1E('-E<B!NY6=R82!I
M:V]N97(@;N1R(&1U(&%N=N1N9&5R($EN=&5R;F5T($5X<&QO<F5R+"!SY2!K
M86X@9'4@8F5H]G9A(&UA<FME<F$@9&5N;F$@<G5T82!F]G(@871T('-TY&YG
M82!A=B!G96YO;7-K:6YL:6=A(%!.1RUB:6QD9FEL97(N`$]M(&1U('-E<B!D
M96YN82!T97AT(&UE;B!I;F=E;B!B:6QD+"!SY2!K86X@:6YT92!D:6X@=V5B
M8FSD<V%R92!V:7-A(&1E;B!B:6QD(&1U(&;V<G/V:V5R(&QA9&1A('5P<"X`
M1O9R:&%N9'-G<F%N<VMA(&)I;&0Z`$)I;&1A9')E<W,`0FEL9&%D<F5S<SH`
M0FEL9"!F<N5N(&=A;&QE<FD`0FEL9"!F<N5N(&=A;&QE<FDZ`$QA9&1A('5P
M<"!B:6QD`$)I;&1E<@!);7!O<G1E<F$L('-T96<@)60`26UP;W)T97)A9&4@
M9N1L=#H@)7,`26UP;W)T97)A9&4@9N1L=#H`4.5GY65N9&4`26Y?9F]G82!R
M860@969T97(`1F5L86MT:78@86MT:79I=&5T<VMO9"!S<&5C:69I8V5R860N
M`$9E;&%K=&EG="!A;G;D;F1A<FYA;6X@;V-H+V5L;&5R(&SV<V5N;W)D+@!/
M9VEL=&EG="!A;G;D;F1A<FYA;6X@96QL97(@86QT97)N871I=B!A9')E<W,N
M($;V<G/V:R!I9V5N(&5L;&5R(&MO;G1A:W1A(&%D;6EN:7-T<F%T]G)E;B!O
M;2!D=2!B96CV=F5R(&AJY&QP+@#6:V$@:6YD<F%G`$EN9&EE;@!);F1I=FED
M=65L;&$@86YVY&YD87)E`$EN9&]N97-I96X`26YF;P!);F9O<FUA=&EO;@!)
M;F9O<FUA=&EO;B#D<B!I;G1E('1I;&QGY&YG;&EG(&SD;F=R92X`26YF;V=A
M(&M?;VQU;6X@969T97(`26YF;V=A(&)I;&0`26YF;V=A('1A8F5L;`!);F9O
M9V$@=V5B8FSD;FL`26YF;V=A(%]K;VQU;6X@9O9R90!);F9O9V$@;GD@:V]L
M=6UN(&5F=&5R(&%K='5E;&P@:V]L=6UN`$EN9F]G82!N>2!K;VQU;6X@9O9R
M92!A:W1U96QL(&MO;'5M;@!);F9O9V$@<F%D(&5F=&5R(&%K='5E;&P@<F%D
M`$EN9F]G82!N>2!R860@9O9R92!E:W1U96QL(')A9`!);F9O9V$@<&%R86=R
M868@969T97(@86MT=65L;"!N;V0`26YF;V=A('!A<F%G<F%F(&;V<F4@86MT
M=65L;"!N;V0`26YF;V=A(&%L=&5R;F%T:78@;6%L;`!);F9O9V$@8V5L;"!E
M9G1E<@!);F9O9V$@8V5L;"!F]G)E`$EN9F]G82!K;VQU;6X@969T97(`26YF
M;V=A(&MO;'5M;B!F]G)E`$EN9F]G82!M961D96QA;F1E;@!);F9O9V$@<&%R
M86=R868@969T97(`26YF;V=A('!A<F%G<F%F(&;V<F4`26YF;V=A(')A9"!E
M9G1E<@!);F9O9V$@<F%D(&;V<F4`06YG92!E<F9O<F1R870@<W9A<B!T:6QL
M('/D:V5R:&5T<V9RY6=A;CH`26YF;V=A+\1N9')A(&)I;&0`26YF;V=A+\1N
M9')A(&SD;FL`3W1I;&QRY&-K;&EG(&MR961I="!F]G(@871T('-K:6-K82!T
M:6QL(&1I<W1R:6)U=&EO;G-L:7-T82X`3W1I;&QRY&-K;&EG(&MR961I="X`
M2&5L=&%L`$AE;'1A;'-L:7-T80!/9VEL=&EG(.5T9^1R9"!F]G(@9&5N(&CD
M<B!K;VUP;VYE;G1E;BX`3V=I;'1I9R!51$@@*"=U<V5R(&1A=&$@:&5A9&5R
M)RDN`$]G:6QT:6=T(%I)4"UA<FMI=F1A=&$`1F5L86MT:6<@87!P;&EK871I
M;VXN`$9E;&%K=&EG="!B871C:"U)1`!&96QA:W1I9R!D871A('-K:6-K860N
M`$9E;&%K=&EG(&1E<W1I;F%T:6]N<V%D<F5S<RX`1F5L86MT:6=T(&9I;&9O
M<FUA=`!/9VEL=&EG(&QI8V5N<VYY8VME;"X`1F5L86MT:6<@;W)T('-P96-I
M9FEC97)A9"X`1F5L86MT:6<@;65D9&5L86YD95]T>7`N`$9E;&%K=&EG(&5L
M;&5R('-A:VYA9"!A<&E?:60N`$9E;&%K=&EG="!E;&QE<B!S86MN860@<&%R
M86UE=&5R+@!&96QA:W1I9R#V=F5R;&EG9V%N9&4@8F5H]G)I9VAE="X`1F5L
M86MT:6=T('!A<G1N97(M:60N`$9E;&%K=&EG('!R;V1U:W1K;V0N`$9E;&%K
M=&EG="!P<F]T;VMO;&PN`$9E;&%K=&EG(&UO='1A9V%R93H@)R5S)P!&96QA
M:W1I9W0@=71D96QN:6YG<V]B:F5K=`!&96QA:W1I9R!A=G/D;F1A<F%D<F5S
M<RX`1F5L86MT:6=T('5N:6-O9&4M9&%T80!);G9E;G1A<FEE<@!);G9E<G1E
M<F$@=7)V86P`27)A;@!)<F%K`$ER;&%N9`!)<VQE(&]F($UA;@!%;G-T86MA
M(.5S:W-K=7)A<@!)<W)A96P`571FY')D870@878`2W5R<VEV`$ET86QI96X`
M2F%M86EC80!J86YU87)I`$IA<&%N`$IA<&%N<VL@*$E33RTR,#(R+4I0*0!*
M97)S97D`2F]R9&%N:65N`&IU;&D`:G5N:0!*=7-T97)A`$-E;G1E<FIU<W1E
M<F$`2G5S=&5R82!JY&UT`%;D;G-T97)J=7-T97)A`$CV9V5R:G5S=&5R80!+
M96YY80!+97)B97)O<W-E<G9E<FX@879V:7-A9&4@875T96YT:7-E<FEN9V5N
M+@!.>6-K96P@<VMA<&%D`$9I;F=E<G!R:6YT`$YY8VME;&SD;F=D`$YY8VME
M;'1Y<`!.>6-K96QA;G;D;F1A;F1E`$YY8VME;"!F:6YN<R!R961A;B!PY2!D
M96X@<'5B;&EK82!N>6-K96QS97)V97)N+@!"87)N`$MI<FEB871I`$MO;&%B
M`$YO<F1K;W)E80!3>61K;W)E80!+;W)E86YS:R`H155#+4M2*0!+=7=A:70`
M2VER9VES=&%N`$QA7WEO=70`4W!RY6L`3&%O<P!3:7-T82!H86QV86X`3/9S
M96YO<F0@Y&YD<F%D97,`4VES=&$@:W9A<G1A;&5T`%-E;F%S="!U<'!D871E
M<F%D.@!396YA<W1E(&EN;&]G9VYI;F<Z("5S`%-E;F%S=&4@:6YL;V=G;FEN
M9SH@)7,@9G+E;B`E<P!396YA<W1E(&EN;&]G9VYI;F<Z($%L9')I9P!,971T
M;&%N9`!,879E;F1E<@!,86<`3&%Y;W5T`$SD;6YA('1O;2!F]G(@871T('-T
MY&YG82!A=B!K86YT;&EN:F4`3&EB86YO;@!6Y&YS=&5R`%;D;G-T97)R=6)R
M:6L`5N1N<W1E<G;D<F1E;@!,97-O=&AO`$YI=N4`3&EB97)I80!,:6)Y96X`
M3&EE8VAT96YS=&5I;@!,:G5S8FSE`$1U9V=R96=N`$SD='0@<F5G;@!,Y'1T
M(&;V<FUI9&1A9W-R96=N`$SD='0@969T97)M:61D86=S<F5G;@!,Y'1T(')E
M9VYS:W5R`$SD='0@<F5G;B!M960@Y7-K80!,Y'1T('-N]@!,Y'1T('-N]G-K
M=7(`3&EM97)I8VL`3.1N:P!,Y&YK96X@<&5K87(@<.4Z`$SD;FMA(&4M<&]S
M=&%D<F5S<V5N('1I;&P@9G5N:W1I;VYE;B!F]G(@871T('-K87!A(&YY='0@
M;65D9&5L86YD90!,Y&YK87(`2V%K80!,:7-T82`M(&%N=N1N9&%R92!K86X@
M<V4@;6%P<&5N`%9I<V$@9&%T86)A<V5R`%9I<V$@:&KD;'#D;6YE;@!,:7-T
M82!T86)E;&QE<@!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES
M="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C
M<FEB90!$970@9VEC:R!I;G1E(&%T="!L:7-T82!S97-S:6]N97(Z("5S`$1E
M="!G:6-K(&EN=&4@871T(&QI<W1A(&%N=N1N9&%R93H@)7,`3&ES=&YI;F<@
M878@86YVY&YD87)E(&%V86MT:79E<F%D+@!,:71T97)A='5R`$QI=&%U96X`
M3&%D9&%R+BXN`$QO:V%L('1I9#H@`%)E9VEO;F%L=`!0;&%T<P!,;V=G82!I
M;@!,;V=G82!U=`!,;V=I;@!,;V=I;F%K=&EV:71E=&5R`$EN;&]G9VYI;F<@
M;6ES<VQY8VMA9&5S+B!4<F]L:6=T=FES('9A<B!A;G;D;F1A<FYA;6X@96QL
M97(@;/9S96YO<F0@9F5L86MT:6=T+@!);FQO9V=N:6YG(&UI<W-L>6-K861E
M<RX`3.5N9R!T97AT`$OD<FQE:P!,Y6<`1W)E:VES:V$@9V5M96YE<@!,871I
M;G-K82!G96UE;F5R`%-MY2!R;VUE<G-K82!S:69F<F]R`$QO>6]L80!,;WEO
M;&$@0FSE`$QU>&5M8G5R9P!-30!-3U1$`$U3+51.148@8FEL86=A(&EN;F5H
M]FQL(&EN9V5N(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:65N`$UA9V%G87-K
M87(`36%G:7-K`$4M<&]S=`!%+7!O<W1A9&UI;@!3:V%P82!LY&YK+BXN`$UA
M;&%W:0!-86QA>7-I80!-86QD:79E<FYA`$UA;&D`36%L=&$`56YD97)HY6QL
M(&QI<W1A;B!M960@:V%T96=O<FEE<B!D=2!A;G;D;F1E<B!F]G(@871T(&MA
M=&5G;W)I<V5R82!P;W-T97(@;65D(&]C:"!FY')G97)N82!S;VT@=&EL;&CV
M<B!D97-S82!K871E9V]R:65R+@!-87`R-"UK87)T80!-87!1=65S="UK87)T
M80#6=F5R<^1T=&YI;F=A<B!S<&%R861E+@!M87)S`$UA<F=I;F%L`$9L86=G
M82!S;VT@;.1S="]O;.1S=`!&;&%G9V$@;65D(&%N;F%N('-T871U<R`H="!E
M>"!V:6MT:6=T+V)E<W9A<F%T*0!-87)S:&%L;/9A<FYA`$UA<G1I;FEQ=64`
M36%T8VAA;F1E(&;D;'0`36%U<FET86YI96X`36%U<FET:75S`$UA>"!T:6QL
MY71E;B!K<F5D:70N`$=RY&YS(&;V<B!M87@@86YT86P@9&5L87(@:2!M961D
M96QA;F1E(/9V97)S:W)I9&5N+@!(]F=S=&$@=&5M<&5R871U<F4@<V5N87-T
M92`R-"!T:6UM87)N83H@`$CV9W-T82!T96UP97)A='5R92!S96YA<W1E(#8@
M=&EM;6%R;F$Z(`!-87AI;6%L="!A;G1A;"!P;W)T86QB;&]C:P!-87AI;6%L
M(&SD;F=D`&UA:@!-87EO='1E`$UE9&EC:6X`079B;VMA(&WV=&4`3?9T97-I
M;F9O<FUA=&EO;@!-]G1E<V;V<F9RY6=A;@!-]G1E<W-V87(`3?9T97-U<'!D
M871E<FEN9P!5<'!D871E<FEN9W-B96?D<F%N(&]M(&WV=&4`365D;&5M;6%R
M`$UE;GELY&=E.@!3;.4@:6AO<"!C96QL97(`365D9&5L86YD90!-961D96QA
M;F1E="!V97)I9FEE<F%D97,@;65N(&1E;B!S:6=N97)A9&5S(&-E<G1I9FEK
M870@:W5N9&4@:6YT92!V97)I9FEE<F%S+@!-961D96QA;F1E(&?D;&QE<B!I
M;G1E(&SD;F=R92X`365D9&5L86YD971Y<`!-971A<G;D9&5R`$UE=&%R8FQO
M8VME="#D<B!I;G1E('1I;&QGY&YG;&ET+@!-971A<BUB;&]C:R!E:B!T:6QL
M9^1N9VQI9W0N($1E=&%L:F5R(&AA<B!L;V=G871S(&;V<B!S>7-T96UA9&UI
M;FES=')A=/9R96XN`$UE=&%R1$(@Y'(@:6YT92!A;G-L=71E;BX`365T;V0`
M365T;V1E;B`G)7,G(.1R(&EN=&4@9&5F:6YI97)A9`!-971O9&5N(&AA<B!I
M;G1E(&1E9FEN97)A=',N($%N<F]P860@;65T;V0Z("5S`$UE=')I<VL`365X
M:6MO`$UI:W)O;F5S:65N`$UI='1E;@!-:6UE='EP`$SD9W-T82!T96UP97)A
M='5R('-E;F%S=&4@,C0@=&EM;6%R;F$Z(`!,Y&=S=&$@=&5M<&5R871U<B!S
M96YA<W1E(#8@=&EM;6%R;F$Z(`!-:6YS=&$@;/9S96YO<F1SY6QD97(@:&%R
M(&EN=&4@=7!P;N5T=',@Y&X`4W!E9VQA`$1I=F5R<V4`3V)L:6=A=&]R:7-K
M="!P86ME="!S86MN87,@*%!%05(@2%144%]297%U97-T*2X`2V]N9FEG=7)A
M=&EO;B!S86MN87,N($1U(&WE<W1E('-K87!A(&1E;B!N=2!O;2!D=2!V:6QL
M(&%N=N1N9&$@9&5N(&CD<B!A<'!L:6MA=&EO;F5N+@!386MN87(@;65D9&5L
M86YD92U)1"X`3V)L:6=A=&]R:7-K="!P86ME="!S86MN87,@*%!%05(@36%I
M;"DN`%-A:VYA<B!S97-S:6]N<RU)1"X`3>4`36]B:6P@92UP;W-T`$UO9&5R
M97)A`,1N9')A9"!D871U;0#$;F1R82!LY&YK`$UO9'5L=7,`36]L9&%V:65N
M`$UO;F%C;P!-;VYG;VQI970`3>5N860@;V-H(.5R`$WE;F%T;&EG`$UO='-E
M<G)A=`!-Y6YF87-E<@!&;&5R(&;D;'0@:&ET=&%D97,@<.4@<F%D("5D(.1N
M(&1E="!F]G)VY&YT861E("5D+@!-87)O8VMO`$UE<W1A9&5L<R!K;&%R=`!-
M97-T861E;',@;6]L;FEG=`!-97-T861E;',@<V]L:6=T`$9L>71T82!N960`
M1FQY='1A(';D;G-T97(`1FQY='1A(&CV9V5R`$9L>71T82!U<'``1FQY='1A
M(&YE9`!&;'ET=&$@=7!P`$UOYV%M8FEQ=64`36]Z:6QL80!&;&5R;FEVY7-L
M:7-T80!-=6QT:6UA<"!3=&]R8G)I=&%N;FEE;FMA<G1A`$9L97)V86P`36ET
M="!K;VYT;P!-:6X@:V]N=&]I;F9O<FUA=&EO;@!-:6X@<&]R=&%L`$UI;B!P
M;W)T86QL87EO=70`37EA;FUA<@!.14HL($IA9R!A8V-E<'1E<F%R(&EN=&4`
M3F%M;@!.86UI8FEA`$YA=7)U`$YE6%0`0F5H]G9E<B#E=&?D<F0`3F5P86P`
M3F5D97)LY&YD97)N80!.961E<FSD;F1S:V$@06YT:6QL97)N80!.97-C87!E
M(&)A<RU54DP`3F5T<V-A<&4@9O9R;GEE;'-E+5523`!.971S8V%P92#E=&5R
M:V%L;&5L<V4M55),`$YE='-C87!E(%-33"US97)V97)N86UN`$YE='-A<&4@
M8V5R=&EF:6MA='-K;VUM96YT87(`3F5T<V%P92!C97)T:69I:V%T<W1Y<`!.
MY'1V97)K`$%L9')I9P!.>6$@2V%L961O;FEE;@!.>2!K871E9V]R:0!.>71T
M(&UE9&1E;&%N9&4@=&EL;"`E<P!.>6WE;F4`3GET="!A;G;D;F1A<FYA;6X@
M*'9A;&9R:71T*0!.>6$@6F5E;&%N9`!.>71T(&SV<V5N;W)D`$YY='0@;/9S
M96YO<F0@:V]M;65R(&%T="!GY2!U="`E>"X`3/9S96YO<F0@;>5S=&4@=F%R
M82!S86UM82X`3GET="!F]FYS=&5R("A?8FQA;FLI`$YY:&5T97(`3GEH971S
M9W)U<'!E<@!.Y'-T80!+;VUM86YD92`T(&9A<V5R`$[D<W1A(&EN<W3D;&QN
M:6YG87(`3N1S=&$^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YA='0`3FEU
M90!.96H`1&5T(&9I;FYS(&EN9V5T(&MO;F9I9W5R871I;VYS9&%T82!A='0@
M=FES82!S:VEL;&YA9&5R(&;V<BX`26YG96X@=&EL;&?D;F=L:6<@<W1R871E
M9VD@9O9R(&%T="!S:V%P82!)4T\M:6UA9V4N`$EN=&4@96X@8F%T8VAM86QL
M+@!$970@9FEN;G,@:6YG970@8FQO8VL@<.4@9&5N(&)E9^1R9&$@<&]S:71I
M;VYE;@!);F=E="!K86QE;F1E<FYA;6X@9O9R($U#04P@875T96YT:7-E<FEN
M9R!A;F=I=F5T+@!);F=E;B#D;F1R:6YG+@!);F=A('5N9&5R8F5H]G)I9VAE
M=&5R(&MA;B!LY&=G87,@=&EL;"!D96X@:.1R(&)E:/9R:6=H971E;BX`26YG
M96X@:V]N9FEG=7)E<FEN9W-I;F9O<FUA=&EO;B!A;F=I=F5N(&;V<B`E<RX`
M26YG96X@:V]N9FEG=7)E<FEN9W-I;F9O<FUA=&EO;B!A;F=I=F5N(&;V<B!&
M5%`@5D93+@!);F=E;B!K;VYF:6=U<F5R:6YG<VEN9F]R;6%T:6]N(&%N9VEV
M96X@9O9R(%-13"!61E,N`$EN9V5N(&MO;F9I9W5R97)I;F=S:6YF;W)M871I
M;VX@86YG:79E;B!F]G(@4U%,+69I;"!61E,N`$EN9V5N(&MR961I="!K=F%R
M+@!"97-K<FEV;FEN9R!S86MN87,N`$EN9V5N(&UO='1A9V%R92!A;F=I=F5N
M+@!);F=E;B!F:6P@=7!P;&%D9&%D`$EN9V$@:6MO;F5R(&AI='1A9&5S+@!)
M;F=E;B!O<G0@86YG:79E;BX`26YG96X@;W)T(&%N9VEV96XN`$EN9V5T(&UE
M9&1E;&%N9&4@8FEF;V=A9&5S+@!);F=E="!N86UN(&%N9VEV970N`$EN9V5N
M(&YU;6UE<B!A;F=I=F5T+@!);F=A(&]F]G)S:^1M9&$@=FES:&5T<V]R9`!)
M;F=E="!L]G-E;F]R9"!F]G(@2%144"UA=71E;G1I<V5R:6YG(&%N9VEV970N
M`$EN9V5T(&SV<V5N;W)D(&;V<B!)34%0+6%U=&5N=&ES97)I;F<@86YG:79E
M="X`26YG970@;/9S96YO<F0@9O9R($ME<F)E<F]S+6%U=&5N=&ES97)I;F<@
M86YG:79E="X`26YG970@;/9S96YO<F0@9O9R($QO9VEN+6%U=&5N=&ES97)I
M;F<@86YG:79E="X`26YG970@;/9S96YO<F0@9O9R(%!!4U-71"UA=71E;G1I
M<V5R:6YG(&%N9VEV970N`$EN9V5T(&SV<V5N;W)D(&;V<B!334(M875T96YT
M:7-E<FEN9R!A;F=I=F5T+@!);F=A(';D;G1A;F1E(')E9VES=')E<FEN9V%R
M+@!);F=E;B!K=F]T82!A;F=I=F5N`$EN9V5N(&MV;W1A(&%N9VEV96XN`$EN
M9V$@<F5G;&5R`$EN9V5N(&%V9W+D;G-A<F4@86YG:79E;BX`26YG82!S:61O
M<@!);F=E;B!SY61A;B!F:6P`26YG96X@=&5M<&]RY')K871A;&]G('1I;&QG
MY&YG;&EG(&;V<B!C86-H92X`26YG970@86YVY&YD87)N86UN(&]C:"]E;&QE
M<B!L]G-E;F]R9"!S:VEC:V%T+@!);F=E="!G:6QT:6<@6$U,+61A=&$@<F5T
M=7)N97)A9&5S`$EN9V$@=N1R9&5N`$EN9V5N('9E<G-I;VX@:&ET=&%D97,@
M:2!D96X@=7)S<')U;F=L:6=A(&MO;F9I9W5R871I;VYE;BX@Q71E<G-K87!A
M(&MO;F9I9W5R871I;VYE;BX`26YG96X@=F5R<VEO;B!H:71T861E<R!I(&1I
M;B!K;VYF:6=U<F%T:6]N+B#%=&5R<VMA<&$@:V]N9FEG=7)A=&EO;F5N+@!)
M8VME+61E;'1A9V%R90!);F=E;@!);F=E;B`H86YVY&YD('5N9&5R9O9R<W3E
M9&0I`$YO<F9O;&OV87)N80!.;W)R82!H96UI<V;D<F5N`$YO<G)A($UA<FEA
M;F'V87)N80!.;W)G90!);G1E(&5F=&5R`$EN=&4@9O9R90!);G1E(&5N(&MA
M=&%L;V<`16H@:6UP;&5M96YT97)A9"X`16H@86YG:79E;@!3=/9D<R!I;G1E
M+@!!;G1E8VMN:6YG87(`26YG96YT:6YG(&%T="!V:7-A+"!GY2!T:6QL8F%K
M82X`3T)3`&YO=F5M8F5R`$YU;6UE<@!!;G1A;"!T96-K96X`06YT86P@:V]L
M=6UN97(`06YT86P@<F%D97(`3G5M;65R(&EN=&4@<W!E8VEF:6-E<F%D92!F
M]G(@871T('5P<&1A=&5R82!I(&1I<W1R:6)U=&EO;G-L:7-T86XN`$]+`$]B
M:F5K=`!/8FIE:W1S:V%P87)E`$]K=&%L`&]K=&]B97(`1FEL=&5R(&;V<B!O
M9O9R<VOD;61H971E<@!+;VYT;W(`1V%M;6%L="!O8V@@;GET="!L]G-E;F]R
M9"!FY7(@:6YT92!V87)A('-A;6UA+@!'86UM86QT(&SV<V5N;W)D`$=A;6UA
M;'0@;/9S96YO<F0@Y'(@9F5L86MT:6=T`$]M86X`1&5L861E(&UA<'!A<B!S
M=/9D<R!E;F)A<G0@878@24U!4"US97)V<F%R`$5N8F%R="!O9O9R<VOD;61A
M('9I<VAE='-O<F0`16YD87-T(&5N(&4M<&]S=&%D<F5S<R!T:6QLY71E;BX`
M16YD87-T(.1G87)E(&5L;&5R('-Y<W1E;6%D;6EN:7-T<F%T]G(@:V%N(.1N
M9')A(.1G87)E(&5L;&5R(&)E:/9R:6=H971E<B!PY2!E;B!U=&1E;&YI;F<`
MUG!P;F$@:2!N>71T(&;V;G-T97(`3W!E;E-33"UF96PZ($1E="!G:6-K(&EN
M=&4@871T(&5X=')A:&5R82!D871A(&9RY6X@<VEG;F5R860@4R]-24U%+61E
M;"X`UG!P;F$@;.1N:R!I(&YY='0@9O9N<W1E<@!/<&5R871I=G-Y<W1E;0!)
M8VME(&]B;&EG871O<FES:V$@9&5L=&%G87)E`$EN<W3D;&QN:6YG87(`26YS
M=.1L;&YI;F=A<B!F]G(@)7,`4V]R=&5R860@;&ES=&$`3W)G86YI<V%T:6]N
M`$]R9V%N:7-A=&EO;G-E;FAE=`!/<F=A;FES97)A`%5R<W!R=6YG;&EG(&%P
M<&QI:V%T:6]N<VUA;&P`57)S<')U;F=L:6=A(&UA;&QA<B!I("5S.@!!;FYA
M;@!!;F1R82!I;G-TY&QL;FEN9V%R`,1G87)B96CV<FEG:&5T97(`4$%-+4%U
M=&5N=&ES97)I;F<@Y'(@:6YT92!T:6QL9^1N9VQI9RX`4$5!4CHZ36%I;"UK
M;W!P;&EN9P!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$
M871A`%!U8FQI:R!01U`M;GEC:V5L`%!'4"!3:6=N960O16YC<GEP=&5D($1A
M=&$`4$A0+6MO9`!02%`M<VMA;`!,Y'1T(&;V<FUI9&1A9W-R96=N`$;V<FUI
M9&1A9W-R96=N`$5F=&5R;6ED9&%G<W-K=7)A<@!%9G1E<FUI9&1A9W-S;O8`
M169T97)M:61D86=S<VMU<F%R(&UE9"!S;O8`169T97)M:61D86=S<V]L`,5S
M:W-K=7)A<B!PY2!E9G1E<FUI9&1A9V5N`%!/4TE8+71I;&SD9V<@<V%K;F%S
M`%!?2%`M<VMA;`!5=&9Y;&QN860Z`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN
M80!086YA;6$`4&%P=6$M3GEA($=U:6YE80!087)A9W5A>0!$96QV:7,@;6]L
M;FEG=`!,]G-E;F]R9`!,]G-E;F]R9"#D;F1R861E<RX`3/9S96YO<F0@9F5L
M86MT:6=T`$SV<V5N;W)D(&MRY'9S(&;V<B!2041)55,@875T96YT:7-E<FEN
M9RX`3/9S96YO<F0@;65D(&)E:W+D9G1E;'-E`$SV<V5N;W)D.@!,]G-E;F]R
M9#H@`$SV<V5N;W)D(&WE<W1E('9A<F$@;&EK82X`2VQI<W1R82!I;@!+;&ES
M=')A(&EN(&9RY6X@=7)K;&EP<'-H86YT97)A<F5N`%/V:W;D9P!6Y&YT86YD
M92!R96=I<W1R97)I;F=A<CH`3>1N;FES:V]R`%!R;V-E;G0`571F]G(@=6YD
M97)HY6QL<V9U;FMT:6]N97(`571F]G(@=6YD97)HY6QL<V%K=&EV:71E=&5R
M('9I9"!I;FQO9V=N:6YG/P!"96CV<FEG:&5T`$)E:/9R:6=H970@)R5S)R!R
M861E<F%D97,@:6YT92X`Q71K;VUS="!N96MA9`!B96CV<FEG:&5T97(`0F5H
M]G)I9VAE='-A9&UI;FES=')A=&EO;@!097)S;VYL:6<@:6YF;W)M871I;VX`
M4&5R=0!(=7-D:G5R`$9I;&EP<&EN97)N80!496QE9F]N`$9O=&]N`%!I=&-A
M:7)N`%!I>&QA<@!+;&EC:.EE<@!687(@9V]D(&ML:6-K82!I(&5N(&-E;&P`
M0F5K<N1F=&$@871T(&1U('9I;&P@<F%D97)A('9A;&0@<&]S=#\`0F5K<N1F
M=&$@871T(&1U('9I;&P@<F%D97)A(&%K='5E;&QT(&5L96UE;G0N`%9A<B!G
M;V0@86YG92!MY6YA9"!O8V@@Y7(N`%9A<B!G;V0@86YG92!N86UN(&;V<B!K
M871E9V]R:6XZ`%9A<B!G;V0@86YG92!G;V1KY&YD($E0+6%D<F5S<RX`5F%R
M(&=O9"!A;F=E(&5T="!G:6QT:6=T(&1A='5M.R!K;VYT<F]L;&5R82!A;G1A
M;&5T(&1A9V%R(&D@;>5N861E;BX`5F%R(&=O9"!A;F=E(&5N(&=O9&OD;F0@
M=&ED+@!687(@9V]D('-U;6UE<F$@9&ET="!P<F]B;&5M+@!!;F=E(&1I='0@
M86YVY&YD87)N86UN(&]C:"!L]G-E;F]R9"X`5F%R(&=O9"!LY',@:6=E;F]M
M(&;V;&IA;F1E('1E>'0N($1U($W%4U1%('-A;71Y8VMA(&UE9"!V:6QL:V]R
M96X@9O9R(&%T="!A;G;D;F1A('-Y<W1E;65T+@!687(@9V]D(&SD<R!I9V5N
M;VT@9O9L:F%N9&4@=&5X="X@1'4@3<535$4@<V%M='EC:V$@;65D('9I;&QK
M;W)E;B!F]G(@871T(&%N=N1N9&$@<WES=&5M970N`$MO;G1R;VQL97)A(&;V
M;&IA;F1E(&EN9F]R;6%T:6]N(&]C:"!VY&QJ('-E9&%N(&5N(&AA;F1L:6YG
M(&D@;65N>6X*;F5D86XN`%;D;&H@96X@:&%N9&QI;F<@9G+E;B!M96YY;B!N
M961A;BX`06YG92!N>71T(&MA=&5G;W)I;F%M;CH`4&]L96X`4&]L:71I:P!5
M;F1E<G/V:VYI;F=A<@!0;W)T=6=A;`!0;W-I=&EO;F5R:6YG(&%V(&)I;&1E
M;@!0;W-I=&EO;F5R:6YG(&%V('1A8F5L;&5N`%-K<FEV('1I;&P@9&5N(&CD
M<B!M87!P96X@*&5J('1V:6YG870@878@24U!4"D`4&]S=&YU:V4`3F5D97)B
M]G)D(&1E('-E;F%S=&4@)7,@=&EM;6%R;F$Z(`!#:&%N<R!T:6QL/&)R+SYN
M961E<F+V<F0`075T:%]L9&%P.B!,1$%0+71I;&SD9V<@<V%K;F%S+@!0<F5F
M<U]S97-S:6]N.B!/8FQI9V%T;W)I<VMT('-E<W-I;VYS=&EL;.1G9R!H:71T
M861E<R!I;G1E+@!4<GEC:P!,=69T=')Y8VL@=FED(&AA=F5T.B``3'5F='1R
M>6-K.B``1O9R:&%N9'-V:7-N:6YG`$;V<FAA;F1S9W)A;G-K82!B:6QD(&D@
M;GET="!F]FYS=&5R`$;V<F5GY65N9&4@:6YS=.1L;&YI;F=A<@!3:W)I=B!U
M="!D;VMU;65N=`!0<FEV871A(&YY8VME;`!0<F]B;&5M`%!R;V)L96UB97-K
M<FEV;FEN9P!0<F]J96MT`%1E>'0`4'5B;&EK(&YY8VME;`!0=6)L:6L@;GEC
M:V5L86QG;W)I=&T`4'5B;&EK(&YY8VME;&EN9F]R;6%T:6]N`$9E;"!V:60@
M9V5N97)E<FEN9R!A=B!P=6)L:6MT+W!R:79A="!N>6-K96QP87(N`%!U97)T
M;R!2:6-O`%)E;G-A(&UE9&1E;&%N9&5N`%%A=&%R`$9RY6=A`$MV;W1A`%!U
M8FQI:R!24T$M;GEC:V5L("@E9"!B:71A<BD`16YS:VEL="!V86P`4F5G;@!4
M:61I9W0@<F5G;@!396YT(')E9VX`4F5G;G-K=7)A<@!296=N(&]C:"!S;O8`
M4F5G;B!T:6QL('-N]@!3;'5M<&WD<W-I9W0@=FES:&5T<V]R9`!&]G)HY6QL
M86YD90!,Y',`3.1S(&UE9&1E;&%N9&5N`%/D:V5R="!A='0@9'4@=FEL;"!R
M861E<F$@)7,_(%)A9&5R:6YG96X@:V%N(&EN=&4@Y6YG<F%S+@!3Y&ME<G0@
M871T(&1U('9I;&P@<F%D97)A(&%N=N1N9&%R9&%T82!F]G(@)7,_(%)A9&5R
M:6YG96X@:V%N(&EN=&4@Y6YG<F%S+@!']G(@;VT@9&EN('-E;F%S=&4@:6YM
M871N:6YG`%5P<&1A=&5R80!5<'!D871E<F$@9'EN86UI<VMA(&UE;GEE;&5M
M96YT.@!5<'!D871E<F$@<&]R=&%L=GDZ`%)E9V5X`%9I<V$@9O9R:.5L;&%N
M9&5N`$QA9&1A(&]M`$MO;6UE;G1A<F5R`$MO;2!I:.5G(&EN9F]R;6%T:6]N
M(&]M(&QE9&EG+W5P<'1A9V5N+@!&:N1R<G-E<G9R87(`55),("AH='1P.B\O
M=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`5&$@8F]R=`!482!B;W)T(&)L;V-K
M`%1A(&)O<G0@:V]L=6UN`%1A(&)O<G0@9F]R;6%T97)I;F<`5&$@8F]R="!F
M<N5N(&UI;B!K86QE;F1E<@!482!B;W)T('!A<@!2861E<F$@<W!A<F%T('-K
M<FEP="!F<N5N('-E<G9E<FYS('1E;7!O<N1R:V%T86QO9RX`5&$@8F]R=`!2
M861E<F$@9&5N;F$@;F]D(&9RY6X@9&]K=6UE;G1E=`!482!B;W)T(&%N=N1N
M9&%R90!482!B;W)T(&%N=N1N9&%R93H@)7,`4W9A<B!S:VEC:V%T+@!3=F%R
M82!A='0@8F5GY')A;B!I;G1E('-T]F1S`%-V87)A(&UE9"!I;F9O<FUA=&EO
M;B!O;2!L961I9R]U<'!T86=E;B!F]G(@:V]M;6%N9&4@=';E(&WE;F%D97(N
M`%-V87)A(&UE9"!D96X@8F5GY')D82!L961I9R]U<'!T86=E;BUI;F9O<FUA
M=&EO;F5N+@!3=F%R.B`E<P!"96?D<F%N(&MU;F1E(&EN=&4@8F5S=F%R87,N
M(%)E='5R;F5R860@9F5L:V]D.B``1&5N(&5F=&5R9G+E9V%D92!T:N1N<W1E
M;B!K=6YD92!I;G1E(&AI='1A<RX`17)F;V1R860@)R5S)R#D<B!I;G1E(&%N
M9VEV96X@:2!K;VYF:6=U<F%T:6]N96X@878@)7,N`$5R9F]D<F%D("<E<R<@
MY'(@:6YT92!A;F=I=F5N(&D@:V]N9FEG=7)E<FEN9V5N(&%V(%9&4RX`17)F
M;V1R860@)R5S)R#D<B!I;G1E(&%N9VEV96X@:2!K;VYF:6=U<F5R:6YG96XN
M`$]B;&EG871O<FES:W1T(&;D;'0`3V)L:6=A=&]R:7-K(&1E;'1A9V%R90#%
M=&5R<W3D;&P`Q71E<G-TY&QL(&SV<V5N;W)D`,5T97)S=.1L;"!L]G-E;F]R
M9`#%<W1E<G3D;&P@<V5N87-T92!F<N5G86X`4F5S=6QT870`Q71E<G;D;F0@
M=&EL;"!I;G-TY&QL;FEN9V%R`$%N9V4@;GET="!L]G-E;F]R9`!2Z75N:6]N
M`,5T97)S=.1L;"!K;VYF:6=U<F%T:6]N`$EN<W3D;&QN:6YG87(@9O9R(%)I
M8V@@5&5X="!%9&ET;W(`1^5T;W(`2/9G97(`2/9G97)R=6)R:6L`2/9G97)V
MY')D96X`4F%?9&EN<W3D;&QN:6YG87(N+BX`4F]L;`!2=6WD;FEE;@!2;W1E
M<F$@,3@P`%)O=&5R82!VY&YS=&5R`%)O=&5R82!H]F=E<@!2861I;G-TY&QL
M;FEN9V%R`%)A9&EN<W3D;&QN:6YG87(`4F%D97(Z`$QI;FIE<@!,:6YJ97(@
M=FES87,@;65L;&%N(&%L;&$@<F%D97(@;V-H(&MO;'5M;F5R`$QI;FIE<B!V
M:7-A<R!E;F)A<G0@;65L;&%N(&MO;'5M;F5R`$QI;FIE<B!V:7-A<R!E;F)A
M<G0@;65L;&%N(')A9&5R`$OV<@!2>7-S;&%N9`!2=V%N9&$`4R]-24U%('-I
M9VYA='5R`%,O34E-12UK<GEP=&5R870@;65D9&5L86YD90!305-,+6%U=&5N
M=&ES97)I;F<@Y'(@:6YT92!T:6QL9^1N9VQI9RX`4TU3(&UE9&1E;&%N9&5N
M`%-13"US:V%L`%-13"US96MV96YS(&;V<B!U<'!S;&%G(&%V(';D<F1E;@!3
M4T@`3%E#2T%4`%-?44PM<VMA;`!,]@!386EN="!(96QE;F$`4V%I;G0@2VET
M=',@;V-H($YE=FES`%-A:6YT($QU8VEA`%-A:6YT+5!I97)R92!O8V@@36EQ
M=65L;VX`4V%I;G0@5FEN8V5N="!O8V@@1W)E;F%D:6YE<FYA`%-A;6UA(')A
M;2`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@;V-H(%!R:6YC
M:7!E`%-A='1E;&ET;&5V97)A;G3V<@!3875D:6%R86)I96X`4W!A<F$`4W!A
M<F$@)R5S)P!3<&%R82`E<P!3<&%R82!I;G-TY&QL;FEN9V%R`%-P87)A(&=E
M;F5R97)A9"!K;VYF:6=U<F%T:6]N('-O;2!02%`M<VMR:7!T('1I;&P@9&EN
M('-E<G9E<G,@('1E;7`M:V%T86QO9RX`4W!A<F%D92!K;VYF:6=U<F%T:6]N
M(&;V<B`E<RX`4W!A<F%D92!U<'!G<F%D97)I;F=S<V-R:7!T('1I;&PZ("5S
M+@!3<')I9&1A(.5S:W-K=7)A<@!6971E;G-K87``4_9K`%/V:VUO=&]R97(`
M5N1L:B!F:6QE<@!6Y&QJ(&5T="!D871U;0!6Y&QJ(&=R=7!P(&%T="!LY&=G
M82!T:6QL`%;D;&H@;GD@Y&=A<F4`5N1L:B!S97)V97(`5N1L:B!A;G;D;F1A
M<F4@871T(&SD9V=A('1I;&P`5N1L:B!A;&QA`%;D;&H@9&%T=6UK;VUP;VYE
M;G1E<BX`5N1L:B!E='0@;V)J96MT`%;D;&H@:6YG96X`06YG92!D92!T96-K
M96X@9'4@8F5H]G9E<B!I(')U=&]R;F$@;F5D86XN($1U(&MA;B!S961A;B!K
M;W!I97)A(&]C:"!K;&ES=')A(&EN(&1E;2!I('1E>'1A<G5T86XN`%;D;&H@
M879G<N1N<V%R92!F]G(@9&%T=6TZ`%;D;&H@9&%T=6UF;W)M870Z`%;D;&H@
M:61E;G1I=&5T(&1U('9I;&P@Y&YD<F$Z`%;D;&H@879G<N1N<V%R92!F]G(@
M=&ED.@!6Y&QJ('1I9'-F;W)M870Z`%;D;&H@=';E(&UA=&-H86YD92!FY&QT
M.@!6Y&QJ(&1I='0@9N1R9W-C:&5M82X`06YG92!D:71T(&;V<G9A;&1A('-P
M<N5K.@!3:VEC:V$@<V5N87-T92!I;F9O<FUA=&EO;F5N`%-K:6-K82!P<F]B
M;&5M<F%P<&]R=`!3:VEC:V$@4TU3`%-E;F5G86P`4V5N<V]R.B``<V5P=&5M
M8F5R`%-E<F)I96X@;V-H($UO;G1E;F5G<F\`4V5R:65N=6UM97(`4V5R=F5R
M:6YS=.1L;&YI;F=A<B!F96QA:W1I9V$@96QL97(@:6YA:W1I=B!S97)V97(N
M`%-E<W-I;VYS861M:6YI<W1R871I;VX`4V5S<VEO;G,M240@:&%R(&?E='0@
M=70N`%-E<W-I;VYE<@!3Y'1T`$MO;F9I9W5R97)A(&%L=&5R;F%T:78@<V]M
M(&WV:FQI9V?V<B#E=&5R<W3D;&QN:6YG(&%V(&)O<G1G;/9M="!L]G-E;F]R
M9"X`2V]N9FEG=7)E<F$@9FKD<G)S97)V<F%R('-O;2!D=2!V:6QL(&MO;6UA
M(.5T(&9RY6X@9&EN('!O<G1A;"X`06YG92!D:71T(&;V<G9A;&1A('-P<N5K
M+"!T:61S>F]N(&-O:"!D871U;6EN<W3D;&QN:6YG87(N`%/D='0@9&ET="!I
M;FET:6%L82!A<'!L:6MA=&EO;BP@9N1R9W-C:&5M82P@<VED=7!P9&%T97)I
M;F<@;V-H(&%N9')A('9I<VYI;F=S:6YS=.1L;&YI;F=A<BX`4V5T=7``2V]N
M9FEG=7)A=&EO;G-U<'!G<F%D97)I;F=S<VMR:7!T(&9I;FYS('1I;&QGY&YG
M;&EG80!$970@9FEN;G,@9FQE<F$@;W)T97(@;65D('!A<F%M971E<FXZ`%-E
M>6-H96QL97)N80!(86YD96P`2V]R="!S=6UM97)I;F<`4VMA;&P@9V5N=N1G
M<W1A;F=E;G1E<B!D969I;F5R87,@9O9R(&1E(&9L97-T82!LY&YK87(_`%9I
M<V$`5FES82!S:VEL;&YA9&5R(&UE;&QA;B!D96X@86MT=65L;&$@;V-H(&1E
M;B!N>6QI9V5N('-K87!A9&4@:V]N9FEG=7)A=&EO;F5N+@!6:7-A('-E;F%S
M=&4@:6YL;V=G;FEN9W-T:60@=FED(&EN;&]G9VYI;F<_`%9I<V$@:6YS=.1L
M;&YI;F<@9O9R(&%T="!B96CE;&QA(&]R:6=I;F%L`%9I<V$@<&%L971T`%9I
M<V$@)W1A8F5L;&%K=&EV:71E=&5R)R!I(&UE;GEN/P!6:7-A(&UE;GD@9O9R
M("5S('1I;&P@=N1N<W1E<C\`5&%B96QL8V5L;&EN<W3D;&QN:6YG87(`5&%B
M96QL:6YS=.1L;&YI;F=A<@!486)E;&QI;G-TY&QL;FEN9V%R`%9I<V$@9&EA
M;&]G<G5T82!F]G(@8FEL9&5G96YS:V%P97(`5FES82!U<'!L861D;FEN9P!3
M:W5R87(`5&ED:6=A('-K=7)A<@!396YA('-K=7)A<@!3:W5R87(@:2!NY')H
M971E;@!&]G)M:6YS:V$`2W)Y;7`@96QL97(@9FQY='1A(&)O<G0@;N1R;&EG
M9V%N9&4@8FQO8VL@9O9R<W0`4VEE<G)A($QE;VYE`%)E9VES=')E<F$`4VEG
M;F%T=7(`4VEG;F%T=7)A;&=O<FET;0!3:6UP;&5X`%-I;F=A<&]R90!3=&]R
M;&5K`$%V8G)Y="!U;F1E<FCE;&P`4VQO=F%K:65N`%-L;W9E;FEE;@!3;O8`
M4V[V<VMU<@!3;O9S:W5R87(`5&ED:6=A('-N]G-K=7)A<@!396YA('-N]G-K
M=7)A<@!3;O9D:G5P.B``36]T<W9A<F%N9&4@<V[V(&D@=F%T=&5N.B``4V%L
M;VUO;O9A<FYA`%-O;6%L:6$`4^5N9V5R(&]C:"!D:6MT97(`4V]R=&5R:6YG
M<VEO<F1N:6YG<W9A;`!KY&QL861R97-S`%-Y9&%F<FEK80!3]F1R82!'96]R
M9VEA(&]C:"!3>7-S86YD=VEC:/9A<FYA`%/D9')A(&AE;6ES9N1R96X`571R
M>6UM92!M96QL86X@:6YT:6QL:6=G86YD92!C96QL97(`571R>6UM92!M96QL
M86X@:6YN96CE;&P@;V-H(&MA;G1E;B!I(&-E;&QE;@!-96QL86YR=6T`365L
M;&%N<G5M`$UE;&QA;G)U;2!O8V@@=71JY&UN:6YG`%-P86YI96X`4W!A;0!)
M;FUA=&YI;F<@878@<W!E8VEE;&QA('1E8VME;@!$96QA(&-E;&P`1&5L82!K
M;VQU;6X`1&5L82!R860`4W!O<G1E<@!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A
M<B!4<F5K`%-T87)T`%-T87)TY7(`4W1A="!E;&QE<B!R96=I;VX`4W1A='5S
M`$QA9W)I;F=S9F]R;6%T`$=A='5A9')E<W,`1V5N;VUS=')U:V5N`%-T<N1N
M9VQI<W1A`%1A(&)O<G0@9&]MY&X@9G+E;B!A9')E<W-E;@!3=&EL(%M#4U-=
M`%/V`$MA;B!I;G1E(&AI='1A('5N9&5R:V%T86QO9R`G)7,G+@#$<F5N9&4`
M4VMI8VMA`$1I;B!B96?D<F%N(&%T="!LY&=G82!T:6QL("(E<R(@=&EL;"!S
M>7-T96UE="!H87(@<VMI8VMA=',N($1U(&MA;B!I;G1E(&QO9V=A(&EN(&EN
M;F%N(&1I;B!B96?D<F%N(&AA<B!A8V-E<'1E<F%T<RX`3F5D<^1N:W0`3'EC
M:V%T`"<E<R<@;&%D97,@=&EL;"!I('-Y<W1E;65T+@!2861E<F%D92!I;F9O
M<FUA=&EO;B!O;2!A;G;D;F1A<F4@)R5S)RX`)R5S)R!R861E<F%D97,N`"<E
M<R<@=&]G<R!B;W)T(&9RY6X@<WES=&5M970N`$MO;F9I9W5R871I;VYE;B!H
M87(@Y71E<G-TY&QL=',N($QA9&1A(&]M('-I9&%N(&;V<B!A='0@<V4@9O9R
MY&YD<FEN9V%R+@!3<&%R861E(&)A8VMU<&MO;F9I9W5R871I;VXN`%-P87)A
M9&4@8F%C:W5P:V]N9FEG=7)A=&EO;B`E<RX`)R5S)R!U<'!D871E<F%D97,N
M`%-K<F5V("5S`%-U9&%N`%-A;6UA;G-TY&QL;FEN9P!3;VQU<'!GY6YG`%-O
M;&YE9&?E;F<`4V]L:6=T`%-O;'5P<&?E;F<`4V]L=7!P9^5N9R]N961GY6YG
M`%-O;'5P<&?E;F<Z(`!3;VQN961GY6YG`%-O;&YE9&?E;F<Z(`!5<'!H]FID
M`%-U<'!O<G0`4W5R:6YA;64`169T97)N86UN`%-V86QB87)D(&]C:"!*86X@
M36%Y96X`4W=A>FEL86YD`%-V97)I9V4`4V-H=V5I>@!3>6MR;VYI<V5R:6YG
M<VQO9V<@<F%D97)A9`!3>6YC34P`4WEN=&%X9F5L(&D@<_9K:W)I=&5R:6$`
M4WER:65N`,5S:W-K=7(`Q7-K<VMU<F%R(&]C:"!B;.5S:6=T`,5S:W-K=7)A
M<@!4:61I9V$@Y7-K<VMU<F%R`%135BUF:6P`5&%B96QL`%1A8F5L;&EN<W3D
M;&QN:6YG87(`5&%B96QL=7!P<^1T=&YI;F<`5&%B96QL:6YS=.1L;&YI;F=A
M<@!486EW86X`5&%I=V%N`%1A:FEK:7-T86X`5&%N>F%N:6$`3>5L.@!5<'!G
M:69T97(`5&5A;`!496QE9F]N;G5M;65R`$CV9W-T82!T96UP97)A='5R('-E
M;F%S=&4@=&EM;65N.B``5&5M<&5R871U<@!496UP97)A='5R.B``5&5M<&5R
M871U<CQB<B`O/B@E<TUA>"5S+R5S36EN)7,I("9D96<[)7,`2V%N(&EN=&4@
M:&ET=&$@;6%L;"`E<RX`06YVY&YD87)A9&UI;FES=')A=&EO;@!';V1KY&YN
M(&)E9^1R86X@<')E;&EM:6[D<G0`4')E;&EM:6[D<G0@86-C97!T97)A=`!4
M97AT`$5N8F%R="!T97AT`%1E>'1J=7-T97)I;F<`5&5X='1O<`!4;P!4:&%I
M("A425,M-C(P*0!4:&%I;&%N9`!486-K(&;V<B!A='0@9'4@86YVY&YD97(@
M<WES=&5M970N`$SD;FME;B`E<R!T:6QL("5S(&AA<B!R861E<F%T<RX`1E10
M+71I;&SD9V=E="#D<B!I;G1E('1I;&QGY&YG;&EG="X`2&ES=&]R:6MS>7-T
M96UE="#D<B!A=F%K=&EV97)A="X`2&]R9&4O2V]L86(M:6YT96=R871I;VYS
M9W+D;G-S;FET=&5T('-T]F1E<B!I;G1E("(E<R(`24U34"UL;V=G96X@:W5N
M9&4@:6YT92!I;FET:65R87,N`$ML87-S96X@36%I;G1E;F%N8V4Z.B!K=6YD
M92!I;G1E(&QA9&1A<P!);G-TY&QL;FEN9W-F]FYS=')E="!H87(@<W3D;F=T
M<RX@079S;'5T87(N`$%D;6EN:7-T<F%T]G)E;B!MY7-T92!K;VYF:6=U<F5R
M82!E;B!P97)M86YE;G0@0F5H]G)I9VAE=',M:V]P<&QI;F<@;VT@9'4@=FEL
M;"!A;G;D;F1A($)E:/9R:6=H971E<BX`16YB87)T(&YE9')E('-I9&%N`$MA
M;&5N9&5R:6YF;W)M871I;VYE;B#D<B!F96QA:W1I9P!+;VYT86MT96YS($E$
M(&%N9V%V<R!I;G1E(&5L;&5R(&MU;F1E(&EN=&4@:&ET=&%S(&D@9&%T86)A
M<V5N+@!+;VYT86MT96X@;&%D97,@=&EL;"!I(&%D<F5S<V)O:V5N+@!$96X@
M;/9S9VIO<F1A(%!'4"US:6=N871U<F5N(&MRY'9S(&;V<B!A='0@=F5R:69I
M97)A(&1E="!S:6=N97)A9&4@;65D9&5L86YD970N`$1I<W1R:6)U=&EO;G-L
M:7-T86YS($E$(&%N9V%V<R!I;G1E(&5L;&5R(&MU;F1E(&EN=&4@:&ET=&%S
M(&D@9&%T86)A<V5N+@!$:7-T<FEB=71I;VYS;&ES=&%N(&AA<B!I;G1E(&%N
M9VEV:71S+@!+<GEP=&5R:6YG<V9U;FMT:6]N97)N82!K<N1V97(@96X@<^1K
M97(@=V5B9O9R8FEN9&5L<V4@*$A45%!3*2X`2.1N9&5L<V5N(&QA9&5S('1I
M;&P@:2!K86QE;F1E<FXN`$9I;&5N("5S('-K86QL(&EN;F5HY6QL82!E;B!I
M;G-TY&QL;FEN9R!F]G(@)7,N`$9I;&5N("5S('-K86QL(&EN;F5HY6QL82!I
M;G-TY&QL;FEN9V%R(&;V<B`E<RX`1FEL96X@:V%N(&EN=&4@:V]P:65R87,@
M=&EL;"!S:6<@<VKD;'8N`$9I;&5N(&MA;B!I;G1E(&MO<&EE<F%S('1I;&P@
M<VEG('-JY&QV+@!&:6QE;B!I;FYE:/9L;"!I;F=E;B!I;F9O<FUA=&EO;BX`
M2'5V=61FY&QT(&;V<B!D971T82!M961D96QA;F1E+W)F8S@R,FUE9&1E;&%N
M9&4@9O9L:F5R`$ED96YT:71E=&5N("<E<R<@<F%D97)A9&5S+@!"87)A(';D
M;G-T97(@<VED80!,Y&YK96X@:&%R('1A9VET<R!B;W)T`%/V:W;D9V5N('1I
M;&P@1VYU4$<M<')O9W)A;6UE="!MY7-T92!V87)A(&%N9VEV96X@=&EL;"!K
M;&%S<V5N($-R>7!T7W!G<#HZ+@!-961D96QA;F1E="!S:VEC:V%T("5S('1I
M;&P@)7,@;65D(.1R96YD92`B)7,B(&AA<B!V:7-A=',N"D1E='1A(.1R(&EN
M9V5N(&=A<F%N=&D@9O9R(&%T="!M961D96QA;F1E="!H87(@;.1S=',N`$YA
M;6YE="!S;VT@<VMA;&P@86YVY&YD87,@9O9R(&%T="!LY&YK82!T:6QL('-K
M87!A+7-I9&%N`$%N=&%L(&;D;'0@;>5S=&4@=F%R82!E='0@;G5M97)I<VMT
M(';D<F1E+@!-;V1U;&5N(&]P96YS<VP@:W+D=G,@878@:VQA<W-E;B!(;W)D
M95]#<GEP=%]S;6EM93HZ+@!);G-TY&QL;FEN9V5N("(E<R(@:W5N9&4@:6YT
M92!S<&%R87,@<.4@9W)U;F0@878@871T(&1A=&%MY&YG9&5N(/9V97)S:W)I
M=F5R(&1E;B!M87AI;6%L="!T:6QLY71N80!0<F]G<F%M;65T('-O;2!A;G;D
M;F1S(&;V<B!A='0@=FES82!D96X@:.1R(&UE9&1E;&%N9&5T>7!E;B`H)7,I
M('-A:VYA<R!PY2!S>7-T96UE="X`5&5C:VYE="!F]G(@8VET97)I;F<@;>5S
M=&4@=F%R82!E='0@=&5C:V5N+@!"87)A(&CV9V5R(&]C:"!VY&YS=&5R('-I
M9&]R`$)A<F$@:/9G97(@<VED80!397!A<F%T;W)N(&WE<W1E('9A<F$@971T
M('1E8VME;BX`4V5R=F5R("<E<R<@<F%D97)A9&5S+@!397)V97(@)R5S)R!S
M<&%R861E<RX`4')E;G5M97)A=&EO;G-B96?D<F%N(&;V<B`E<R!H87(@=&%G
M:71S(&)O<G0N`$%N9VEV96X@<F%D("@E9"D@9FEN;G,@:6YT92X`06YG:79E
M;B!R860@97AI<W1E<F%R(&EN=&4N`%5P<&=I9G1E;B!H87(@;&%G=',@=&EL
M;"!I(&1I;B!U<'!G:69T<VQI<W1A+@!496UP;W+D<B!F:6P@)R5S)R!F:6YN
M<R!I;G1E+@!497AT96X@9'4@;6%T870@:6X@<W3D;6UE<B!I;G1E(/9V97)E
M;G,@;65D('1E>'1E;B!PY2!S:^1R;65N`$)A<F$@=&]P<"!O8V@@8F]T=&5N
M('-I9&$`0F%R82!T;W!P<VED80!5<'!L861D870@9&%T82!F]G)S=F%N;B!S
M961A;B!F]G)E9^5E;F1E('-T96<N`$1E;B!U<'!L861D861E(&9I;&5N(&MU
M;F1E(&EN=&4@<W!A<F%S+@!,961I9R]U<'!T86=E;BUI;F9O<FUA=&EO;B!F
M]G(@86YVY&YD87)E;B!H87(@<W!A<F%T<RX`5V5A=&AE<BYC;VTM8FQO8VME
M="#D<B!I;G1E('1I;&QGY&YG;&EG="X`5&5M86MA=&%L;V<@)R5S)R!F:6YN
M<R!I;G1E+@!);F=A(&EN<W3D;&QN:6YG87(@=&EL;&?D;F=L:6=A+@!$970@
M9FEN;G,@:6YG82!A;'1E<FYA=&EV82!D96QA<B!S;VT@:V%N('9I<V%S(&EN
M;&EN92X`1O9R(&WE;F=A('1E8VME;B!I(&;D;'1E="X@1'4@:&%R(&%N9V5T
M="`E<R!T96-K96X[(&UA>&EM86QT(&%N=&%L('1E8VME;B#D<B`E<RX`4')O
M8FQE;2!M960@871T(&SD9V=A('1I;&P@)R5S)R!T:6QL('-Y<W1E;65T.B`E
M<P!0<F]B;&5M(&UE9"!A='0@<F5N<V$@:6YF;W)M871I;VX@;VT@86YVY&YD
M87)E("<E<R<@9G+E;B!S>7-T96UE=#H@`%!R;V)L96T@;65D(&%T="!T82!B
M;W)T("<E<R<@9G+E;B!S>7-T96UE=#H@`%!R;V)L96T@=FED('5P<&1A=&5R
M:6YG(&%V("<E<R<Z("5S`%!R;V)L96T@=FED('5P<&QA9&1N:6YG(&%V(&9I
M;&5N+B!);F=A("5S(&QA9&1A9&5S('5P<"X`1&5T('5P<'-T;V0@<')O8FQE
M;2!V:60@=7!P;&%D9&YI;F<@878@9FEL96XZ("5S(.1R('-T]G)R92#D;B!M
M87AI;6%L="!T:6QLY71E;B!S=&]R;&5K("@E9"!B>71E<RDN`$1E="!U<'!S
M=&]D('!R;V)L96T@=FED('5P<&QA9&1N:6YG(&%V(&9I;&5N.B`E<R!L861D
M861E<R!E;F)A<G0@=7!P(&1E;'9I<RX`1&5T('5P<'-T;V0@971T(&9E;"!V
M:60@=FES;FEN9R!A=B!M961D96QA;F1E9&5L96XN`$9E;"!V:60@:6UP;W)T
M(&%V(&MO;G1A:W1D871A+@!&96P@=FED(&EM<&]R="!A=B!HY&YD96QS96XZ
M("5S+@!&96P@=FED(&EM<&]R="!A=B!I0V%L96YD87(@9&%T82X`1F5L('9I
M9"!I;7!O<G0@878@=7!P9VEF=&5N.B`E<RX`1F5L('9I9"!I;7!O<G0@878@
M:6YF;W)M871I;VX@;VT@;&5D:6<O=7!P=&%G96XZ("5S+@!%='0@9F5L('#E
M='+D9F9A9&5S(&D@9F]R;75LY')E="X@2V]N=')O;&QE<F$@871T(&1U(&EN
M=&4@9VSV;70@9GEL;&$@:2!E='0@;V)L:6=A=&]R:7-K="!FY&QT+@!$970@
M9VEC:R!I;G1E(&%T="!U=&;V<F$@9&5N(&)E9^1R9&$@861R97-S8F]K<V9U
M;FMT:6]N96XN(%9A<B!G;V0@9O9R<_9K('-E;F%R92X`1F5L('9I9"!U<'!D
M871E<FEN9R!A=B!K;VYT86MT=7!P9VEF=&5R+B!&]G)S]FL@:6=E;B!S96YA
M<F4N`$9E;"!V:60@=7!P9&%T97)I;F<@878@9&ES=')I8G5T:6]N<VQI<W1A
M;BX@1O9R<_9K(&EG96X@<V5N87)E+@!$:6X@24U!4"US97)V97(@<W3V9&5R
M(&EN=&4@9&5L861E(&UA<'!A<BX`1&5N;F$@:&%N9&QI;F<@<W3V9',@:6YT
M92X`1&5N;F$@9G5N:W1I;VX@Y'(@:6YT92!I;7!L96UE;G1E<F%D(.1N+@!&
M:6QE;B!V97)K87(@:6YT92!V87)A(&5T="!G:6QT:6=T(%)!4BUA<FMI=BX`
M1FEL96X@=F5R:V%R(&EN=&4@=F%R82!E='0@9VEL=&EG="!:25`M87)K:78N
M`$9E;&%K=&EG="!K;W)T;G5M;65R+@!$96YN82!D<FEV<G5T:6X@9_9R(&1E
M="!M]FIL:6=T(&%T="!S:VEC:V$@;65D9&5L86YD96X@=FEA($-L:6-K871E
M;&PM8G)Y9V=A;B`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G96YO;2!A='0@
M86YVY&YD82!(5%10($%023IT+@!$96YN82!D<FEV<G5T:6X@9_9R(&1E="!M
M]FIL:6=T(&%T="!S:VEC:V$@;65D9&5L86YD96X@=FEA(%=)3BUB<GEG9V%N
M("AH='1P.B\O=VEN<&QC+F-O;2D@9V5N;VT@871T(&%N=N1N9&$@2%144"!!
M4$DZ=`!$96YN82!D<FEV<G5T:6X@9_9R(&1E="!M]FIL:6=T(&%T="!S:VEC
M:V$@;65D9&5L86YD96X@=FEA('-M<S)E;6%I;"UB<GEG9V%N("AH='1P.B\O
M<VUS,F5M86EL+F-O;2D@9V5N;VT@871T(&%N=N1N9&$@2%144"!!4$DZ=`!$
M96YN82!D<FEV<G5T:6X@9_9R(&1E="!M]FIL:6=T(&%T="!S:VEC:V$@;65D
M9&5L86YD96X@=FEA(%--5%`@9V5N;VT@5F]D869O;F4@271A;&EE;BUB<GEG
M9V%N("AE;F)A<G0@=&EL;"!6;V1A9F]N;G5M;65R*2X@1')I=G)U=&EN96X@
M:W+D=F5R(&5T="!E+7!O<W1K;VYT;R!H;W,@5F]D869O;F4@271A;&EE;B`H
M:'1T<#HO+W=W=RXQ.3`N:70I+@!&Y&QT970@;>5S=&4@=F%R82!I9GEL;'0N
M`$;D;'1E="!FY7(@96YB87)T(&EN;F5HY6QL82!H96QT86PN`$;D;'1E="!F
MY7(@96YB87)T(&EN;F5HY6QL82!S:69F<F]R(&]C:"!K;VQO;BX`1N1L=&5T
M(&;E<B!E;F)A<G0@:6YN96CE;&QA(&]K=&%L82!T86PN`$;D;'1E="!S:V%L
M;"!V87)A(&5N(&MO;6UA+2!E;&QE<B!M96QL86YS;&%G<W-E<&%R87)A9"!L
M:7-T82!M960@:&5L=&%L`$;D;'1E="!MY7-T92!V87)A(&5T="!G;V1KY&YT
M('1A;"X`1&5T=&$@9N1L="!MY7-T92!I;FYE:.5L;&$@96X@4D="+6;D<F=K
M;V0@:2!H97AA9&5C:6UA;'0@9F]R;6%T+"!T(&5X("<C,3(S-&%F)RX`1&5T
M=&$@9F]R;75LY'(@:&%R(')E9&%N(&)E87)B971A=',N`$1E="!HY'(@Y'(@
M)7,N`$UE9&1E;&%N9&5T('-K<F5V<R!I(&5N(&%N;F%N('1E8VME;G5P<'/D
M='1N:6YG("@E<RD@Y&X@9&EN(&5G96XN`$1E="!HY'(@;G5M<F5T(&WE<W1E
M('9A<F$@;6EN<W0@971T+@!397)V97)N(&MA;B!I;G1E('!A8VMA('5P<"!Z
M:7`@;V-H(&=Z:7`@9FEL97(N`%-Y<W1E;65T(.1R(&;V<B!T:6QL9N1L;&5T
M(&%V86MT:79E<F%T+@!$970@:.1R(';D<F1E="!MY7-T92!V87)A(&YU;65R
M:7-K="X`1&5T=&$@9O9N<W1E<B!MY7-T92!A;G)O<&%S(&9RY6X@971T(&MO
M;F9I9W5R871I;VYS9O9N<W1E<@#%<VMA`,1R96YD96X`5&ED`%1I9'-R961O
M=FES;FEN9P!4:61S9F]R;6%T`%1I9'-V86P`UG-T=&EM;W(`4G5B<FEK`%)U
M8G)I:R`H=&]O;'1I<"DZ`%1I;&P`1O9R(&%T="!M87)K97)A(&9L97)A('9A
M;"P@:.5L;"!N960@0W1R;"`H4$,I(&5L;&5R($-O;6UA;F0@*$UA8RD@=&%N
M9V5N=&5N(&[D<B!D=2!K;&EC:V%R+@!)9&%G`%9I<V$@2%1-3"UKY&QL80!4
M;V=O`%1O:V5L874`26UO<F=O;@!4;VYG80!4;W``5&]P(&9R86UE("A?=&]P
M*0#6=F5R<^1T=&YI;F=A<@!4<FEN:61A9"!O8V@@5&]B86=O`%-A;G0@96QL
M97(@9F%L<VMT`%1I`%1U;FES:65N`%1U<FMI970`5'5R:VES:R`H25-/+3@X
M-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS+2!O8V@@0V%I8V]S]F%R;F$`5'5V
M86QU`$%N9V4@9&ET="!V86PZ(`!55BUI;F1E>#H@`%523`!54DP@9O9R(&1I
M='0@;&5V97)A;G-R87!P;W)T97)I;F=S<VMR:7!T`%523#H`56=A;F1A`%5K
M<F%I;F$`2V%N(&EN=&4@;.1S82!61E,M;6%P<"X`1&5T(&=I8VL@:6YT92!A
M='0@;.1G9V$@=&EL;"!U=/9K860@86YVY&YD87)I;F9O<FUA=&EO;B!V:60@
M<F5G:7-T97)I;F<N`$MA;B!I;G1E(.1N9')A(&)E:/9R:6=H970@9O9R(%9&
M4RUF:6P@)7,N`$MA;B!I;G1E(.1N9')A(&)E:/9R:6=H970@9O9R(%9&4RUF
M:6P@)7,O)7,N`$MA;B!I;G1E(.1N9')A('1I;&P@)7,N`$MA;B!I;G1E(&MO
M;G1R;VQL97)A(&9I;'-T;W)L96L@)7,O)7,`2V%N(&EN=&4@:V]N=')O;&QE
M<F$@9FEL<W1O<FQE:R!PY2`E<RX`2V%N(&EN=&4@:V]N=')O;&QE<F$@9FEL
M<W1O<FQE:R!PY2`E<R\E<RX`2V%N(&EN=&4@:V]N=&%K=&$@4U%,+7-E<G9E
M<BX`2V%N(&EN=&4@:V]N=&%K=&$@=FEA(%-33"X`2V%N(&EN=&4@:V]P:65R
M82!61E,M9FEL+@!+86X@:6YT92!S:V%P82!61E,M;6%P<"`E<RX`2V%N(&EN
M=&4@<VMA<&$@5D93+6UA<'`N`$MA;B!I;G1E('-K87!A(%9&4RUF:6PN`$MA
M;B!I;G1E('-K87!A(%9&4RUM87!P("<E<R<N`$MA;B!I;G1E('-K87!A('1O
M;2!61E,M9FEL+@!+86X@:6YT92!P86-K82!U<'`@9&%T82X`2V%N(&EN=&4@
M<F%D97)A("5S+"!M87!P96X@Y'(@:6YT92!T;VTN`$MA;B!I;G1E(')A9&5R
M82`G)7,G.B`E<P!+86X@:6YT92!R861E<F$@)7,L(&UA<'!E;B#D<B!I;G1E
M('1O;2X`2V%N(&EN=&4@<F%D97)A(%9&4RUM87!P(')E:W5R<VEV="X`2V%N
M(&EN=&4@<F%D97)A(%9&4RUM87!P+@!+86X@:6YT92!R861E<F$@5D93+6UA
M<'`Z("5S+@!+86X@:6YT92!R861E<F$@5D93+69I;"`E<RX`2V%N(&EN=&4@
M<F%D97)A(%9&4RUF:6PN`$MA;B!I;G1E(')A9&5R82!61E,M;6%P<"`G)7,G
M+@!+86X@:6YT92!R861E<F$@5D93(')E:W5R<VEV=#H@)7,N`$MA;B!I;G1E
M(&%V9_9R82!A:W1U96QL(&UA<'`N`$MA;B!I;G1E(&5X=')A:&5R82!#97)T
M:69I:V%T<V1E=&%L:F5R`$MA;B!I;G1E(&QA9&1A(&1E9FEN:71I;VYE;B!A
M=B`E<RX`2V%N(&EN=&4@9FQY='1A(%9&4RUF:6PN`$MA;B!I;G1E(/9P<&YA
M(%9&4RUF:6P@)7,N`$MA;B!I;G1E(/9P<&YA(%9&4RUF:6P@9O9R('-K<FEV
M;FEN9RX`2V%N(&EN=&4@]G!P;F$@5D93+69I;"X`2V%N(&EN=&4@]G!P;F$@
M:V]M<')I;65R870@87)K:78N`$MA;B!I;G1E(&SD<V$@5D93+69I;"`H9FEL
M97-I>F4H*2!M:7-S;'EC:V%D97,I+@!+86X@:6YT92!LY'-A(%9&4RUF:6P@
M*&=E=$9I;&53:7IE*"D@;6ES<VQY8VMA9&5S*2X`2V%N(&EN=&4@;.1S82!F
M:6PZ(`!+86X@:6YT92!LY'-A(&MA=&%L;V=E;B!F]G(@)W9F<W)O;W0G+@!+
M86X@:6YT92!B>71A(&YA;6X@<.4@)7,@=&EL;"`E<SH@9&5S=&EN871I;VYS
M;6%P<"!F:6YN<R!R961A;@!+86X@:6YT92!B>71A(&YA;6X@<.4@5D93+6UA
M<'`N`$MA;B!I;G1E(&)Y=&$@;F%M;B!PY2!61E,M;6%P<#H@)7,N`$MA;B!I
M;G1E(&)Y=&$@;F%M;B!PY2!61E,M9FEL("5S+@!+86X@:6YT92!B>71A(&YA
M;6X@<.4@5D93+69I;"`E<R\E<RX`2V%N(&EN=&4@8GET82!N86UN('#E(%9&
M4RUF:6PN`$MA;B!I;G1E(&OV<F$@)VUK:7-O9G,G+@!+86X@:6YT92#V=F5R
M<^1T=&$@5V]R9&1O:W5M96YT970`2V%N(&EN=&4@<VMR:79A('1I;&P@5D93
M+69I;"`E<RX`2V%N(&EN=&4@<VMR:79A('1I;&P@5D93+69I;"`H8V]P>2@I
M(&UI<W-L>6-K861E<RDN`$MA;B!I;G1E('-K<FEV82!D871A('1I;&P@5D93
M+69I;"X`2V%N(&EN=&4@<VMR:79A('1I;&P@5D93+69I;"P@:W9O=&$@<VMU
M;&QE(/9V97)S:W)I9&%S+@!5;F1E<G-T<G5K96X`Q6YG<F$@Y&YD<FEN9V%R
M`,5N9W)A<B!D:6X@<V5N87-T92#E=&?D<F0`3W;D;G1A="!S=F%R(&9RY6X@
M<V5R=F5R('#E(&;V<F)I;F1E;'-E.B``3W;D;G1A="!S=F%R(&9RY6X@<V5R
M=F5R('1I;&PZ(`!%:B!K871E9V]R:7-E<F%D`$EC:V4@:&%N=&5R860@:V]M
M<&]N96YT(&%V('1Y<#H@)7,`56YI8V]D92`H551&+3@I`$;V<F5N861E($%R
M86)E;6ER871E;@!3=&]R8G)I=&%N;FEE;@!&]G)E;G1A(%-T871E<FYA`$%M
M97)I:V%N<VMA(%-T:6QL86AA=G/V87)N80!%;FAE=&5R`$]KY&YD`$]KY&YT
M(&=RY&YS<VYI='1S;65D9&5L86YD96ED("AA<&EM<V=I9"DN`$]KY&YT(&ML
M:65N=&UE9&1E;&%N9&5I9"`H8VQI;7-G:60I+@!/:^1N9"!O<G0@<W!E8VEF
M:6-E<F%D+@!/:^1N="!A;G;D;F1A<FYA;6X@96QL97(@;/9S96YO<F0N`%1A
M(&)O<G0@;.1N:V5N(&9RY6X@;G5V<F%N9&4@96QE;65N=`!.86UN;/9S`$EC
M:V4M<')I=FEL:6=E<F%D92!S:W)I<'0@:V%N(&EN=&4@:V]M;6$@Y70@2VQI
M<'`@=70O2V]P:65R82]+;&ES=')A+69U;FMT:6]N97)N82!A=B!SY&ME<FAE
M='-S:^1L+B!+;&EC:V$@3TL@9O9R(&%T="!S92!E;B!T96MN:7-K(&)E<VMR
M:79N:6YG(&9RY6X@;6]Z:6QL82YO<F<@;VT@:'5R(&1U(&MA;B!T:6QLY71A
M(&%T="!S:W)I<'0@:V]M;65R(.5T('5R:VQI<'`N`%1A(&)O<G0@9N1R9P!4
M:6QLY&=G970@<W3V9',@:6YT90!5<'!D871E<F$`57!P9&%T97)A("5S`%5P
M<&1A=&5R82!S=&%T=7,@<.4@<W9A<F%N9&4`57!P9&%T97)A(&%N=N1N9&%R
M90!5<'!D871E<F%D92`G)7,G+@!5<'!D871E<FEN9W-S8W)I<'0@<F%D97)A
M="X`3&%D9&$@=7!P`$QA9&1A9&4@=7!P(&%L;&$@:V]N9FEG=7)A=&EO;G-F
M:6QE<B!T:6QL('-E<G9E<FXN`%9E<G-A;&5R`%)O;65R<VMA('-I9F9R;W(`
M57)U9W5A>0!!;G;D;F0@86MT=65L;#H@)7,`06YVY&YD(%-33`!!;G;D;F0@
M;VT@;F%M;B]L]G-E;F]R9"#D<B!A;FYO<FQU;F1A(&;V<B!)35-0+7-E<G9E
M<BX`06YVY&YD87)E`$%N=N1N9&%R92`E<R#D<B!I;G1E(&)E:/9R:6<@9O9R
M("5S+@!!;G;D;F1A<F%D;6EN:7-T<F%T:6]N`$%N=N1N9&%R:6YS=.1L;&YI
M;F=A<@!!;G;D;F1A<G)E9VES=')E<FEN9P!!;G;D;F1A<G)E9VES=')E<FEN
M9R!H87(@879A:W1I=F5R871S+@!!;G;D;F1A<FMO;G1O="!H:71T861E<R!I
M;G1E`$%N=N1N9&%R;F%M;@!!;G;D;F1A<FYA;6X@)7,@9FEN;G,@<F5D86XN
M`$%N=N1N9&%R;F%M;CH`06YVY&YD87)N86UN.B``06YVY&YD87)E(&D@<WES
M=&5M970Z`%5Z8F5K:7-T86X`5D93+6UA<'`@97AI<W1E<F%R(&EN=&4N`%-E
M;65S=&5R`$=I;'1I9V$@<&QA='-E<B!S;VT@:&ET=&%D97,@:6YK;'5D97)A
M<CH@`$=I;'1I9VAE=`!-:6YU=&5R(&9RY6X@;G4`5N1R9&5T(/9V97)S=&EG
M97(@9&5T(&CV9W-T82!T:6QLY71N82`H)7,I`%;D<F1E;@!6Y')D96X@871T
M(';D;&IA(&9RY6X`5F%N=71A=0!687)I86)E;`!696YE>G5E;&$`5F5R:69I
M97)I;F<@;6ES<VQY8VMA9&5S("T@;65D9&5L86YD970@:V%N(&AA(&UA;FEP
M=6QE<F%T<RX`5F5R<VEO;@!697)S:6]N:&%N=&5R:6YG`%9E<G1I:V%L(&IU
M<W1E<FEN9P!697)T:6MA;"!U=&9Y;&QN860`5F5R=&EK86PZ`%;D;&1I9W0@
M:/9G`%9I971N86T`5FEE=&YA;65S:7-K("A625-#24DI`%9I<V$@)7,`5FES
M82!E;B!E>'1E<FX@=V5B8G-I9&$`5FES82!S;VT@)7,`5FES82!HY&YD96QS
M90!6:7-A('5P<&=I9G0`2G5N9V9R=?9A<FYA+"!"<FET=&ES:V$`2G5N9V9R
M=?9A<FYA+"!!;65R:6MA;G-K80!3:6MT`%-I:W0Z`%9O9&%F;VYE($ET86QI
M96X@=FEA(%--5%``5D%23@!605).24Y'(2$A(%)!1$5202!32U))4%1%5"!-
M04Y514Q,5"!&4L5.("5S+@!724X@=FEA($A45%``5V%L;&ES(&]C:"!&=71U
M;F$`5F%R;FEN9P!/;@!6Y&1E<G!R;V=N;W,`5N1D97)D871A(&9RY6X`=V5A
M=&AE<BYC;VT`5V5B8@!796)B<&QA=',`5V5B8G!L871S96X@+2!3;V)E<@!7
M96)B<&QA='-E;B`M(%-O8F5R($Y9`%9E8VMO=FES`%;D;&MO;6UE;@!6Y&QK
M;VUM96X@=&EL;"`E<P!6Y&QK;VUM96XL("5S`%;D<W1E<FSD;F1S:R`H25-/
M+3@X-3DM,2D`5N1S=&5R;.1N9'-K("A)4T\M.#@U.2TQ-2D`5N1S=')A(%-A
M:&%R80!6:6QK96X@87!P;&EK871I;VX@<VMA;&P@)7,@=FES82!E9G1E<B!I
M;FQO9V=N:6YG/P!6:6QK96X@Y'(@879G<N1N<VYI;F=S=&5C:VYE=#\`5FEL
M:V5T(.1R('1E8VMN970@9O9R(&-I=&5R860@=&5X=#\`5VAE<F5I<R!!=7-T
M<F%L:65N:V%R=&$`5FEL:V$@9F%S97(`5FEL:V$@<&QU9VEN('-K86QL(&%K
M=&EV97)A<R!F]G(@4FEC:"!497AT(&5D:71O<FXN`$)R961D`$)R961D(&D@
M0U-3+75N:71S`$)R961D('#E(&UE;GEN(&;V<B`G)7,G('1I;&P@=N1N<W1E
M<B`H9^1L;&5R(&9RY6X@;N1S=&$@:6YL;V=G;FEN9P!486)E;&QB<F5D9`!"
M<F5D9&5N:&5T`$)R961D.@!7:6MI`%9I;F0`5&ED:6<@=FEN9`!6:6YD:&%S
M=&EG:&5T(&D@:VYO<`!6:6YD.@!6:6YD.B``5FES9&]M`-9N<VME;&ES=&$`
M07)B971E`$%D<F5S<RP@87)B971E`%1E;&5F;VXL(&%R8F5T90!&96P@86YT
M86P@9N1L="!PY2!R860@)60N($;V<G;D;G1A9&4@)60L(&AI='1A9&4@)60N
M`$9E;"!A;G1A;"!FY&QT+B!&]G)VY&YT861E("5D+"!H:71T861E("5D+@!&
M96P@<&]S:71I;VX@)60@=FED(&SD<VYI;F<@878@5D93+69I;"X`6"U2968`
M6#4P.58S(%5T]FMA9"!N>6-K96QA;G;D;F1N:6YG`%@U,#E6,RUT:6QLY&=G
M`%E9`%E965D`66%H;V\A(&UA<`#%<FQI9P!996UE;@!*80!*82P@:F%G('-A
M;71Y8VME<@!$=2!H87(@86MT:79E<F%T('1E>'1LY&=E+B!!;G;D;F0@6SP^
M72!F]G(@871T(.5T97)GY2!T:6QL(%=94TE764<N`$1U(&AA<B!I;G1E(&)E
M:/9R:6=H970@<VMA<&$@9FQE<B#D;B`E9"!B;&]C:RX`1'4@Y'(@:6YT92!A
M=71E;G1I<V5R860N`$1U(&MA;B!I;G1E(&%N=N1N9&$@)UPG(&D@9&ET="!N
M86UN`$1U(&MA;B!I;G1E(&%N=N1N9&$@)UPG(&D@9&ET="!N86UN`$1U(&%N
M9V%V(&EN=&4@96X@9V]D:^1N9"!E+7!O<W1A9')E<W,N`$1U(.1R('5T;&]G
M9V%D+@!$=2!MY7-T92!A;F=E(&5T="!G:6QT:6=T(&UO8FEL;G5M;65R.R!E
M;F)A<G0@<VEF9G)O<B!O8V@@971T("<K)R!F]G)E(&EN=&5R;F%T:6]N96QL
M="!P<F5F:7@N`$1U(&%N9V%V(&EN=&4@971T(&=O9&OD;G0@=N1R9&4N`$1U
M(&WE<W1E(&MO;F9I9W5R97)A(&5N($1A=&%4<N1D<RUK;W!P;&EN9R!F]G(@
M871T(&%N=N1N9&$@<F5G:7-T<F5R:6YG`$1U(&WE<W1E(&MO;F9I9W5R97)A
M(&5N(%9&4RUK;W!P;&EN9P!$=2!MY7-T92!B97-K<FEV82!P<F]B;&5M96XL
M(&EN;F%N(&1U(&MA;B!R87!P;W)T97)A(&5T="!P<F]B;&5M+@!$=2!MY7-T
M92!A;F=E(&5N(%523"!S;VT@;.1N:V5N('!E:V%R('#E`$1U(&WE<W1E(&%N
M9V4@96X@<V5R=F5R('-O;2!S:V%L;"!R861E<F%S+@!$=2!MY7-T92!A;F=E
M(&5T="!A;G;D;F1A<FYA;6X@<V]M('-K86QL(')E;G-A<RX`1'4@;>5S=&4@
M86YG92!E='0@86YVY&YD87)N86UN('-O;2!S:V%L;"!R861E<F%S+@!$=2!M
MY7-T92!A;F=E(&5T="!A;G;D;F1A<FYA;6X@<V]M('-K86QL(&SD9V=A<R!T
M:6QL+@!$=2!MY7-T92!A;F=E(&5T="!A;G;D;F1A<FYA;6X@<V]M('-K86QL
M('5P<&1A=&5R87,N`$1U(&WE<W1E(&%N9V4@96X@Y71GY')D('-O;2!S:V%L
M;"!U=&;V<F%S+@!$=2!MY7-T92!A;F=E(&5T="!N>71T(&MA=&5G;W)I;F%M
M;BX`1'4@;>5S=&4@86YG92!E='0@:71A;&EE;G-K="!T96QE9F]N;G5M;65R
M`$1I;B`E<R!S97-S:6]N(&AA<B!U<'!H]G)T+B!687(@9V]D(&QO9V=A(&EN
M(&EG96XN`$1I;B!E+7!O<W1A9')E<W,`1&EN($9RY6XZ(&%D<F5S<SH`1&EN
M(&EN9F]R;6%T:6]N`$1I;B!I;G1E<FYE=&%D<F5S<R!H87(@Y&YD<F%T<R!E
M9G1E<B!A='0@9'4@;&]G9V%T(&EN('1I;&P@)R5S)RX@1O9R(&%T="!S:WED
M9&$@9&EG+"!MY7-T92!D=2!L;V=G82!I;B!I9V5N+@!$:71T(&YA;6X`1&EN
M(&%U=&5N=&ES97)I;F=S:V]P<&QI;F<@<W3V9&5R(&EN=&4@=7!P;.1G9R!A
M=B!A;G;D;F1A<F4N($]M(&1U('9I;&P@86YVY&YD82!(;W)D92!F]G(@871T
M(&%D;6EN:7-T<F5R82!A;G;D;F1A<F4@<^4@;>5S=&4@9'4@86YVY&YD82!E
M;B!A;FYA;B!A=71E;G1I<V5R:6YG<VMO<'!L:6YG+@!$:71T(&%U=&5N=&ES
M97)I;F=S:V]P<&QI;F<@<W3V9&5R(&EN=&4@;&ES=&YI;F<@878@86YVY&YD
M87)E+"!E;&QE<B!SY2#D<B!F=6YK=&EO;F5N(&%V<W3D;F=D+@!$:6X@=V5B
M8FSD<V%R92]I;G1E<FYE=&%D<F5S<R!H87(@Y&YD<F%T<R!E9G1E<B!A='0@
M9'4@;&]G9V%T(&EN('1I;&P@)R5S)RX@1O9R(&%T="!S:WED9&$@9&EG+"!M
MY7-T92!D=2!L;V=G82!I;B!I9V5N+@!$:6X@=V5B8FSD<V%R92!S=/9D97(@
M:6YT92!D96X@:.1R(&9U;FMT:6]N96XN`$1I;B!W96)B;.1S87)E('-T]F1E
M<B!I;G1E('5T<VMR:69T<V9U;FMT:6]N96XN(%1R>6-K($-T<FPO3W!T:6]N
M("L@4"!F]G(@871T('-K<FEV82!U="X`1&EN(&%K='5E;&QA('1I9'-Z;VXZ
M`$1I;B!F]G)V86QD82!I9&5N=&ET970@:&%R(.1N9')A=',N`$1I;B!F]G)V
M86QD82!I9&5N=&ET970Z`$1I='0@9G5L;'-TY&YD:6=A(&YA;6XZ`$1I;B!I
M;FQO9V=N:6YG(&AA<B!GY71T('5T+@!$:71T(&YY82!L]G-E;F]R9"!F]G(@
M)7,@Y'(Z("5S`$1I;F$@:6YS=.1L;&YI;F=A<B!H87(@=7!P9&%T97)A=',@
M9O9R(&1E;B!HY'(@<V5S<VEO;F5N+@!$:6YA(&EN<W3D;&QN:6YG87(@:&%R
M('5P<&1A=&5R871S+@!$:71T(&SV<V5N;W)D(&AA<B!B;&EV:70@Y71E<G-T
MY&QL=`!$:71T(&SV<VYO<F0@:&%R(.5T97)S=.1L;'1S+"!K;VYT<F]L;&5R
M82!D:6X@92UP;W-T(&]C:"!L;V=G82!I;B!M960@9&ET="!N>6$@;/9S96YO
M<F0N`$1I='0@;/9S96YO<F0@:&%R(&?E='0@=70N`$1I;F$@9FKD<G)S97)V
M<F%R.@!*=6=O<VQA=FEE;@!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`
M6T?V;2!C:71E<F%D('1E>'1=`%M&96QR87!P;W)T70!;5FES82!C:71E<F%D
M('1E>'0@+0!;5FES82!C:71E<F%D('1E>'0@+2`E<R!R861E<ET`6W)A9"`E
M<R!A=B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4<N1D`%]2861E
M<F$@<F%D`%]'<G5P<&5R`%](:N1L<`!?0FEL9&EN<W3D;&QN:6YG87(N+BX`
M7TQO9V=A(&EN`%],;V=G82!U=`#$7VYD<F$@;.1N:RXN+@!?26YS=.1L;&YI
M;F=A<@!?0F5H]G)I9VAE=&5R`%]482!B;W)T(&SD;FLN+BX`7U-E='5P`%]4
M86)E;&QI;G-TY&QL;FEN9V%R+BXN`%]!;G;D;F1A<F4`861R97-S8F]K`&]K
MY&YD(&UO='1A9V%R90!K86QE;F1E<@!L=6=N=`!K86X@:6YT92!S:V%P82!U
M=&9I;`!K86X@:6YT92#V<'!N82!I;F1A=&$`:VQI8VMA(&CD<@!K;&]C:V$`
M:V]M;6%N9&]R861S9F5L`&MO;F9I9W5R871I;VYS9F5L`&MR:71I<VL@<WES
M=&5M9FEL('-A:VYA<P!D871A9F]R;6%T9F5L`.1N9')A`'!O<W1E;B!K=6YD
M92!I;G1E(&AI='1A<P!F86QL86YD90!F:6P`9G+E;B!D96X@)7,@*"5S*2!K
M;"`E<R`E<P!S=&]R;6)Y87(`:#H`:&@`;VOD;F0@=N1R9&1A=&]R`&=E;F%S
M=`!I;FQI;F4`8F5A<F)E=&YI;F=S9F5L`$EN=&5R;G0@87!P;&EK871I;VYS
M9F5L`')A9&5R70!F96QK;V0@)60@9G+E;B!M:VES;V9S`&UM`&YA;6X`:6YT
M92!I;7!L96UE;G1E<F%D`&EN=&4@:6UP;&5M96YT97)A9`!A;G1E8VMN:6YG
M<V)L;V-K`'!R;V-E;G0`Y71K;VUS="!N96MA9`!P:7AL87(`<')O=&]K;VQL
M9F5L`'-T:6=A;F1E`%1JY&YS=&5N(.1R(&5J('1I;&QGY&YG;&EG`'9I<V$@
M<VMI;&QN861E<@!S;7,R96UA:6P@=FEA($A45%``<W,`<W1A9&EG=`!S>7-T
M96UF96P`=7!P9VEF='-L:7-T80!T:6QL9N1L;&EG="!F96P`86YG92!L]G-E
M;F]R9&5T('1VY2!GY6YG97(@9O9R(&%T="!B96MRY&9T80!E;F%D`&YA;6YL
M]G,`86YVY&YD87)V86P`=D-A<F0`=SH`=V5A=&AE<BYC;VT`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W1R
M7U12+P``````````````````````````````````````````````````````
M```````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#4Q-30S,S<U-``P,C`Q-3``(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L;V-A;&4O=')?5%(O:&5L<"YX;6P`````````````````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-C(P`#$P-3$U-#,S-S4T`#`R,38R
M-@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2)I<V\M.#@U.2TY(C\^"CPA
M+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O=')?5%(O:&5L<"YX;6PL=B`Q+C$N
M,BXQ(#(P,#4O,3`O,3@@,3$Z,S,Z-#8@:F%N($5X<"`D("TM/@H\:&5L<#X*
M"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)S=6UM87)Y(CX*/'1I
M=&QE/E1H92!0;W)T86P@4&%G93PO=&ET;&4^"B`\<&%R83X*("!4:&ES('!O
M<G1A;"!P86=E('!R;W9I9&5S(&$@<75I8VL@<W5M;6%R>2!O9B!A;&P@>6]U
M<B!I;7!O<G1A;G0*("!I;F9O<FUA=&EO;BX@1F]R(&5X86UP;&4L(&ET(&UI
M9VAT('-H;W<@:&]W(&UA;GD@;F5W(&4M;6%I;"!M97-S86=E<R!Y;W4*("!H
M879E(&EN('EO=7(@24Y"3U@L('5P8V]M:6YG(&5V96YT<R!O;B!Y;W5R(&-A
M;&5N9&%R+"!T87-K<R!O;B!Y;W5R('1O+61O"B`@;&ES="P@:&5A9&QI;F5S
M(&9R;VT@<V5L96-T960@;F5W<R!S97)V:6-E<RP@86YD('-O(&]N+B`@36%N
M>2!O9B!T:&5S90H@('-U;6UA<FEE<R!W:6QL(&-O;G1A:6X@<75I8VL@<VAO
M<G1C=71S('1O(&-O;6UO;B!F=6YC=&EO;G,L('-U8V@@87,*("!C;VUP;W-I
M;F<@82!N97<@;6%I;"!M97-S86=E+"!C<F5A=&EN9R!A(&YE=R!C86QE;F1A
M<B!E=F5N="!O<B!T87-K+"!E=&,N"B`\+W!A<F$^"B`\<&%R83X*("!4:&4@
M8V]N=&5N=',@;V8@=&AI<R!P;W)T86P@<&%G92!A<F4@8W5S=&]M:7IA8FQE
M('9I82!T:&4@3&%Y;W5T(&)U='1O;BX*("!&;W(@97AA;7!L92P@>6]U(&-A
M;B!C:&]O<V4@=VAI8V@@:71E;7,@=&\@:6YC;'5D92!O;B!T:&ES('!O<G1A
M;"!P86=E(&%S"B`@=V5L;"!A<R!I;B!W:&EC:"!O<F1E<B!T:&5Y(&%R92!S
M:&]W;BX*(#PO<&%R83X*/"]E;G1R>3X*+2T^"CQE;G1R>2!I9#TB<W5M;6%R
M>2(@;60U/2(V.&-A,S-F-V8P8SEA864T8S$P,V5B-#<T.3)C9&,Q-2(@<W1A
M=&4](G5P=&]D871E(CX*/'1I=&QE/D=I<FG^(%-A>69A<_T\+W1I=&QE/@H\
M<&%R83X*1VER:?X@<V%Y9F%S_2!S:7IE(/9N96UL:2!B:6QG:6QE<FEN:7II
M;B!K_7-A(/9Z971I;FD@=F5R:7(N(-9R;F7P:6XL(&=E;&5N(&MU='5N=7ID
M82!K8><@=&%N92!Y96YI(&5L96MT<F]N:6L@<&]S=&$@;VQD=?!U;G4L('1A
M:W9I;6EN:7ID96MI('EA:VQA_F%N(&]L87EL87+]+"!Y87#];&%C86ML87(@
M;&ES=&5S:6YD96MI(&G^;&5R:6YI>FDL('-EYVEL:2!H86)E<B!S97)V:7-I
M;F1E:VD@8F'^;/UK;&%R_2!V<RX@9_9S=&5R:7(N($)U(/9Z971L97)I;B#G
M;_!U(&=E;F5L(&9O;FMS:7EO;FQA<B!IYVEN(&O]<V%Y;VQL87(@:>=E<F5C
M96MT:7(L("!Y96YI('!O<W1A(&]L=?YT=7)M86LL('EE;FD@=&%K=FEM(&]L
M87G]('EA(&1A(&G^:2!O;'7^='5R;6%K(&=I8FDN"CPO<&%R83X*/'!A<F$^
M"D=I<FG^('-A>69A<_UN_6X@:>=E<FGP:2!D_'IE;FQE;64@='7^=2!I;&4@
M:7-T9?!E('5Y87)L86YA8FEL:7(N("+6<FYE\&EN+"!G:7)I_B!S87EF87/]
M;OUN(&AA;F=I(/;P96QE<FD@:>=E<F5C9?!I;FEN('EA;OUN9&$@8G4@]O!E
M;&5R:6X@9_9S=&5R:6QM92!S_7)A;&%R_2!D82!S9>=I;&5B:6QI<BX*/"]P
M87)A/@H\+V5N=')Y/@H*"CPA+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED
M/2)N879B87(B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG871I;VX@
M0F%R/"]T:71L93X*(#QP87)A/@H@($%T('1H92!L969T(&AA;F0@<VED92!O
M9B!T:&4@=V5B('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N(&YA=FEG871I;VX@
M8F%R+@H@($-L:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES(&YA=FEG871I;VX@
M8F%R('1O('%U:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*("!B971W965N('1H
M92!A=F%I;&%B;&4@87!P;&EC871I;VYS+@H@/"]P87)A/@H\+V5N=')Y/@HM
M+3X*"CQE;G1R>2!I9#TB;F%V8F%R(B!M9#4](F(X8V8P864Q.64U-V1F83!C
M,F(Y-C)E-3$V-S@R9C0W(B!S=&%T93TB=7!T;V1A=&4B/@H\=&ET;&4^57EG
M=6QA;6$@1&]L8?[];2#'=6)U\'4\+W1I=&QE/@H\<&%R83X*57EG=6QA;6$@
M9&]L8?[];2#G=6)U\'4@=V5B('-A>69A<_UN_6X@<V]L(&ME;F%R_63]<BX@
M365V8W5T('5Y9W5L86UA;&%R(&%R87/];F1A("!H_7IL_2!V92!K;VQA>6-A
M(&=E>FEN96)I;&UE:R!IYVEN('5L8?[];2#G=6)U\'5N9&%K:2!S:6UG96QE
M<FD@=/UK;&%Y_6[]>BX*/"]P87)A/@H\+V5N=')Y/@H*"CPA+2T@16YG;&ES
M:"!E;G1R>3H*/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(^"B`@
M("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$;R!-86EN=&5N
M86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME
M('1O('!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;BP@
M8VAE8VL@=&AI<R!B;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"BTM/@H*/&5N
M=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(@;60U/2)D9#DU9&8P-V$P
M,S`S,3(S,F)A96$Y,3DR.#AB,F0P,"(@<W1A=&4](G5P=&]D871E(CX*/'1I
M=&QE/E1E<F-I:&QE<CH@0F%K_6TZ($)A:_UM(%EA<&UA/"]T:71L93X*/'!A
M<F$^"E-I<W1E;64@9VER97)K96X@8F%K_6T@:?YL96UL97)I('EA<&UA:R!I
M<W1E<G-E;FEZ(&)U(&MU='5Y=2!I_F%R971L97EI;FEZ+@H\+W!A<F$^"CPO
M96YT<GD^"@H\(2TM($5N9VQI<V@@96YT<GDZ"CQE;G1R>2!I9#TB<')E9G,M
M8V]N9FER;5]M86EN=&5N86YC92(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z
M($UA:6YT96YA;F-E.B!#;VYF:7)M($UA:6YT96YA;F-E/"]T:71L93X*("`@
M(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@8V]N9FER;2!A;&P@
M;6%I;G1E;F%N8V4@=&%S:W,@8F5F;W)E('1H97D@87)E(')U;BP@8VAE8VL@
M=&AI<R!B;W@N($EF(&QE9G0@=6YC:&5C:V5D+"!A;&P@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!T:&%T(&YE960@=&\@8F4@<G5N('=I;&P@8F4@<&5R9F]R
M;65D(&%U=&]M871I8V%L;'D@=VET:"!N;R!C:&%N8V4@=&\@8V%N8V5L(&]N
M(&QO9VEN+@H@("`@/"]P87)A/@H\+V5N=')Y/@HM+3X*"CQE;G1R>2!I9#TB
M<')E9G,M8V]N9FER;5]M86EN=&5N86YC92(@;60U/2)A,C$Q-C)C9&9F,V(Q
M9#AF865A9&(W,CDV,C0P,#,V92(@<W1A=&4](G5P=&]D871E(CX*/'1I=&QE
M/E1E<F-I:&QE<CH@0F%K_6TZ($)A:_UM($1O\')U;&%M83PO=&ET;&4^"CQP
M87)A/@I"86O];2!G]G)E=FQE<FEN:2#G86S]_FUA>6$@8F'^;&%M861A;B#V
M;F-E(&1O\')U;&%M86L@:7-T:7EO<G-A;OUZ(&)U(&MU='5Y=2!I_F%R971L
M97EI;FEZ+B!%\&5R(&MU='4@:?YA<F5T;&5N;65M:?X@:7-E(.=A;/W^;6%S
M_2!G97)E:V5N(&+\=/QN(&)A:_UM(&G^;&5M;&5R:6YI>B!S:7-T96UE(&=I
M<F5R:V5N("QI<'1A;"!E=&UE(/YA;G/];OUZ(&]L;6%D86X@;W1O;6%T:6L@
M;VQA<F%K(&=E<N=E:VQE_F5C96MT:7(N"CPO<&%R83X*/"]E;G1R>3X*"CPO
M:&5L<#X*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&]C86QE+W1R7U12+TQ#7TU%4U-!1T53+P``````````````
M```````````````````````````````````````````````````P,#`P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U-``P,C$W
M,S4`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O=')?5%(O3$-?3453
M4T%'15,O:&]R9&4N;6\`````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,S,V,3`P
M`#$P-3$U-#,S-S4T`#`R,S,W-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#>$@25`````)H&```<````[#0``-L(``"\:0``
M`````"B-```.````*8T```\````XC0``#0```$B-```(````5HT```L```!?
MC0``#````&N-```$````>(T```P```!]C0``#P```(J-```+````FHT```X`
M``"FC0``!0```+6-```H````NXT```@```#DC0``"@```.V-```5````^(T`
M`!(````.C@``"P```"&.```.````+8X```H````\C@``#0```$>.```.````
M58X``!$```!DC@``#0```':.```,````A(X```T```"1C@``!@```)^.```/
M````IHX``!@```"VC@``#````,^.```.````W(X```X```#KC@``"````/J.
M```N`````X\``!H````RCP``,@```$V/```X````@(\``%0```"YCP``40``
M``Z0``!:````8)```%<```"[D```-````!.1```'````2)$```H```!0D0``
M#P```%N1```%````:Y$```8```!QD0``$0```'B1```(````BI$```D```"3
MD0``"0```)V1```E````IY$``"````#-D0``$````.Z1```/````_Y$```H`
M```/D@```P```!J2```/````'I(``!0````ND@``"0```$.2```-````39(`
M`!(```!;D@``#P```&Z2```*````?I(```\```")D@``"````)F2```D````
MHI(``!0```#'D@``%@```-R2```(````\Y(``!D```#\D@``!P```!:3```,
M````'I,``"P````KDP``#@```%B3```#````9Y,```L```!KDP``!P```'>3
M```'````?Y,```4```"'DP``!0```(V3```*````DY,```,```">DP``%P``
M`**3```*````NI,```\```#%DP``#@```-63```8````Y),``",```#]DP``
M#@```"&4```4````,)0``!<```!%E```%P```%V4```7````=90``!,```"-
ME```#P```*&4```.````L90``!\```#`E```!P```."4```&````Z)0```@`
M``#OE```#P```/B4```&````")4```H````/E0``$P```!J5```+````+I4`
M`!`````ZE0``%0```$N5```5````894```<```!WE0``$````'^5```%````
MD)4``!4```"6E0``$0```*R5```,````OI4``#L```#+E0``"0````>6```'
M````$98``!0````9E@```P```"Z6```%````,I8``!`````XE@``"0```$F6
M```3````4Y8``#D```!GE@``$@```*&6```G````M)8``"P```#<E@``*@``
M``F7```E````-)<```H```!:EP``!@```&67```)````;)<```<```!VEP``
M+P```'Z7```W````KI<``"X```#FEP``50```!68```M````:Y@``"T```"9
MF```+0```,>8``!`````]9@``",````VF0``(P```%J9```M````?ID``#,`
M``"LF0``%0```."9```9````]ID``"D````0F@``)````#J:```1````7YH`
M``H```!QF@``#````'R:```*````B9H``!````"4F@``%@```*6:```6````
MO)H```<```#3F@``!P```-N:```4````XYH```H```#XF@``"`````.;```(
M````#)L```<````5FP``!P```!V;```&````)9L```4````LFP``!P```#*;
M```&````.IL```@```!!FP``*0```$J;```.````=)L```H```"#FP``!```
M`(Z;```'````DYL```D```";FP``!@```*6;```1````K)L```<```"^FP``
M%@```,:;```$````W9L```@```#BFP``!@```.N;```-````\IL```8`````
MG```'@````><```1````)IP```@````XG```#0```$&<```,````3YP```<`
M``!<G````P```&2<```#````:)P``!<```!LG```$P```(2<```(````F)P`
M``0```"AG```"````*:<```(````KYP``$$```"XG```(````/J<```&````
M&YT```8````BG0``%0```"F=```8````/YT``"(```!8G0``+@```'N=```=
M````JIT``"$```#(G0``5````.J=```I````/YX```H```!IG@``!P```'2>
M```5````?)X```X```"2G@``"@```*&>```/````K)X```T```"\G@``#P``
M`,J>```-````VIX```D```#HG@``%````/*>```&````!Y\``!@````.GP``
M'0```">?```3````19\``!0```!9GP``!````&Z?```&````<Y\``%0```!Z
MGP``!````,^?```.````U)\```4```#CGP``!0```.F?```;````[Y\``!H`
M```+H```$0```":@```1````.*```!P```!*H```*@```&>@```0````DJ``
M`"$```"CH```!0```,6@```3````RZ```!(```#?H```"@```/*@```/````
M_:```!$````-H0``$P```!^A```,````,Z$```8```!`H0``!@```$>A```7
M````3J$``!````!FH0``$0```'>A```(````B:$```4```"2H0``#````)BA
M```0````I:$```4```"VH0``#0```+RA```&````RJ$```<```#1H0``#0``
M`-FA```'````YZ$```L```#OH0``!P```/NA```'`````Z(```D````+H@``
M"@```!6B```9````(*(```P````ZH@``$````$>B```%````6*(``"4```!>
MH@``$@```(2B```3````EZ(``"L```"KH@``.P```->B```@````$Z,``#8`
M```THP``"````&NC```,````=*,```8```"!HP``!````(BC```.````C:,`
M``H```"<HP``#0```*>C```>````M:,``!L```#4HP``(0```/"C```>````
M$J0``!D````QI```'@```$ND```;````:J0``"8```"&I```&P```*VD```>
M````R:0``!P```#HI```)@````6E```S````+*4``"8```!@I0``*P```(>E
M```X````LZ4``"\```#LI0``$@```!RF```I````+Z8``!(```!9I@``H@``
M`&RF```6````#Z<``",````FIP``*````$JG```I````<Z<``"@```"=IP``
M'P```,:G```@````YJ<``"4````'J```*````"VH```P````5J@``)(```"'
MJ```(0```!JI```<````/*D``"8```!9J0``00```("I```,````PJD```<`
M``#/J0``!P```->I```&````WZD```T```#FJ0``$````/2I```2````!:H`
M`!,````8J@``$@```"RJ```'````/ZH```0```!'J@``#````$RJ```.````
M6:H```\```!HJ@``$P```'BJ```-````C*H``"@```":J@```P```,.J```-
M````QZH```8```#5J@``$0```-RJ```7````[JH``!L````&JP``#@```"*K
M```"````,:L```4````TJP``$````#JK```$````2ZL```T```!0JP``#@``
M`%ZK```#````;:L```X```!QJP``"````("K```/````B:L```\```"9JP``
M!P```*FK```-````L:L``!````"_JP``"P```-"K```&````W*L```P```#C
MJP``$0```/"K```9`````JP```L````<K```#0```"BL```B````-JP```H`
M``!9K```&````&2L```9````?:P``!8```"7K```#0```*ZL```'````O*P`
M`!0```#$K```"P```-FL```B````Y:P``"\````(K0``"P```#BM```)````
M1*T``!D```!.K0``"P```&BM```7````=*T``!<```",K0``"0```*2M```6
M````KJT```\```#%K0``%@```-6M```.````[*T``!@```#[K0``"````!2N
M```-````':X``"8````KK@``0P```%*N```(````EJX``!(```"?K@``"```
M`+*N```+````NZX``"\```#'K@``#@```/>N```%````!J\```8````,KP``
M`P```!.O```'````%Z\```0````?KP``"@```"2O```*````+Z\```\````Z
MKP``$````$JO```7````6Z\``!$```!SKP``%P```(6O```)````G:\```4`
M``"GKP``"P```*VO```*````N:\```(```#$KP``!0```,>O```-````S:\`
M`!L```#;KP``%P```/>O```)````#[````X````9L```#0```"BP```2````
M-K```#@```!)L```(````(*P```(````H[````X```"LL```>P```+NP```8
M````-[$``!$```!0L0``!P```&*Q```%````:K$``!D```!PL0``!P```(JQ
M```(````DK$```8```";L0``!@```**Q```0````J;$```\```"ZL0``$```
M`,JQ```/````V[$```L```#KL0``#P```/>Q```,````![(```\````4L@``
M!P```"2R```&````++(```X````SL@``#````$*R```H````3[(```\```!X
ML@``"````(BR```(````D;(``!,```":L@``'@```*ZR```A````S;(``"``
M``#OL@``&0```!"S```7````*K,``"4```!"LP``%P```&BS```$````@+,`
M`!L```"%LP``#0```*&S```,````K[,```,```"\LP``"````,"S```*````
MR;,```P```#4LP``"P```.&S```0````[;,```P```#^LP``!`````NT```3
M````$+0``!0````DM```#````#FT```)````1K0```X```!0M```"P```%^T
M```;````:[0```<```"'M```!P```(^T```*````E[0```T```"BM```"0``
M`+"T```$````NK0```4```"_M````P```,6T```8````R;0```H```#BM```
M!````.VT```F````\K0```X````9M0``?````"BU```5````I;4```4```"[
MM0``!P```,&U```,````R;4```@```#6M0``"@```-^U```&````ZK4```@`
M``#QM0```@```/JU```&````_;4```8````$M@``%`````NV```-````(+8`
M`!`````NM@``&P```#^V```$````6[8```D```!@M@``$````&JV```)````
M>[8```D```"%M@``!0```(^V```:````E;8```@```"PM@``!@```+FV```9
M````P+8```X```#:M@``!P```.FV```'````\;8```4```#YM@``"0```/^V
M```*````";<```(````4MP``!@```!>W```-````'K<```D````LMP``!@``
M`#:W```2````/;<```D```!0MP``!P```%JW```4````8K<``!T```!WMP``
M!@```)6W```*````G+<```0```"GMP``"0```*RW```(````MK<``!$```"_
MMP``"0```-&W```&````V[<```T```#BMP``!@```/"W```$````][<``#D`
M``#\MP``/0```#:X```Z````=+@``!X```"ON```!0```,ZX```.````U+@`
M``0```#CN```!@```.BX```A````[[@``!4````1N0``!@```">Y```$````
M+KD``!$````SN0``!@```$6Y```*````3+D``"(```!7N0``!````'JY```%
M````?[D``!T```"%N0``!````*.Y```,````J+D```H```"UN0``"````,"Y
M```)````R;D```4```#3N0``.@```-FY```P````%+H``#4```!%N@``*0``
M`'NZ``!'````I;H``#@```#MN@``*0```":[```_````4+L``"X```"0NP``
M+0```+^[```?````[;L```\````-O```$@```!V\```+````,+P``"8````\
MO```*0```&.\```D````C;P``"8```"RO```"````-F\```*````XKP```D`
M``#MO```!P```/>\```@````_[P``"`````@O0``)@```$&]```*````:+T`
M`!D```!SO0``*0```(V]```6````M[T``!(```#.O0``!P```.&]```*````
MZ;T```P```#TO0``#P````&^```0````$;X``$`````BO@``<````&.^``!F
M````U+X```X````[OP``"0```$J_```*````5+\``!(```!?OP``$P```'*_
M```,````AK\```8```"3OP``#P```)J_```2````JK\``!````"]OP``$0``
M`,Z_```<````X+\``",```#]OP``:@```"'````/````C,````4```"<P```
M$````*+````)````L\````0```"]P```"P```,+````4````SL````P```#C
MP```#````/#````/````_<```!4````-P0``*0```"/!```J````3<$``"8`
M``!XP0``)P```)_!```I````Q\$``"H```#QP0``&0```!S"``!"````-L(`
M`!$```!YP@``$@```(O"```3````GL(``!0```"RP@``#P```,?"```6````
MU\(``!<```#NP@``$`````;#```1````%\,``#0````IPP``$P```%[#```2
M````<L,``#4```"%PP``%````+O#```'````T,,```P```#8PP``(````.7#
M```4````!L0``!$````;Q```%P```"W$```<````1<0``!,```!BQ```$0``
M`';$```:````B,0``!X```"CQ```&@```,+$```1````W<0``!0```#OQ```
M%P````3%```5````',4```D````RQ0``&0```#S%```$````5L4```<```!;
MQ0``"P```&/%```1````;\4```8```"!Q0``!@```(C%```&````C\4```4`
M``"6Q0``!P```)S%```'````I,4```4```"LQ0``%@```++%```&````R<4`
M``8```#0Q0``!````-?%```$````W,4```<```#AQ0``#@```.G%```,````
M^,4```P````%Q@``#0```!+&```*````(,8```X````KQ@``!0```#K&```H
M````0,8```X```!IQ@``#````'C&```/````A<8```H```"5Q@``"````*#&
M```)````J<8``"L```"SQ@``!````-_&```(````Y,8``"8```#MQ@``$@``
M`!3'```/````)\<```8````WQP``"@```#['```'````2<<```@```!1QP``
M(````%K'```)````>\<```P```"%QP``#0```)+'```.````H,<``!8```"O
MQP``$0```,;'```&````V,<```,```#?QP``!@```./'```9````ZL<```<`
M```$R```!`````S(```+````$<@```L````=R```!P```"G(```'````,<@`
M`!8````YR```#0```%#(```-````7L@```H```!LR```$````'?(```/````
MB,@``!$```"8R```%P```*K(```*````PL@``!$```#-R```"````-_(```$
M````Z,@```\```#MR```.@```/W(```%````.,D```P````^R0``'@```$O)
M```.````:LD``!````!YR0``"P```(K)```,````ELD```D```"CR0``!P``
M`*W)```*````M<D```D```#`R0``#@```,K)```0````V<D``!H```#JR0``
M"@````7*```)````$,H```H````:R@``#````"7*```/````,LH```@```!"
MR@``!@```$O*```'````4LH```L```!:R@``1P```&;*```-````KLH```D`
M``"\R@``!````,;*```#````R\H``!,```#/R@``$P```./*```3````]\H`
M``H````+RP```@```!;+```$````&<L``"4````>RP```P```$3+```%````
M2,L``"H```!.RP``"@```'G+```%````A,L```0```"*RP``"@```(_+```-
M````FLL```8```"HRP``"````*_+```(````N,L```0```#!RP``!0```,;+
M``!H````S,L```D````US```#````#_,```%````3,P```8```!2S```&P``
M`%G,```O````=<P``!````"ES```"@```+;,```/````P<P```H```#1S```
M"0```-S,```3````YLP``!L```#ZS```&````!;-```7````+\T```X```!'
MS0```P```%;-```'````6LT```@```!BS0``!P```&O-```*````<\T```L`
M``!^S0``!P```(K-``!1````DLT``!````#DS0``#````/7-```-`````LX`
M`!H````0S@``2@```"O.```&````=LX```8```!]S@``!@```(3.```?````
MB\X```8```"KS@``"0```++.```8````O,X``!<```#5S@``!@```.W.```-
M````],X``"(````"SP``5P```"7/```3````?<\``",```"1SP``$P```+7/
M```"````R<\```L```#,SP``"````-C/```-````X<\```H```#OSP``!P``
M`/K/```4`````M````8````7T```"````![0```.````)]````<````VT```
M"@```#[0```+````2=````<```!5T```#````%W0```-````:M````P```!X
MT```"0```(70```)````C]````H```"9T```!P```*30```)````K-````<`
M``"VT```"@```+[0```;````R=```!(```#ET```"@```/C0```)`````]$`
M`!`````-T0``!P```![1```2````)M$```0````YT0``!P```#[1```%````
M1M$```4```!,T0``"P```%+1```4````7M$``!$```!ST0``&@```(71```6
M````H-$``!0```"WT0``%P```,S1```8````Y-$``!P```#]T0``&0```!K2
M```'````--(```4````\T@``#0```$+2```,````4-(```@```!=T@``%P``
M`&;2```+````?M(``!,```"*T@``!````)[2```*````H](```0```"NT@``
M#````+/2```)````P-(```4```#*T@``!P```-#2```%````V-(```0```#>
MT@```@```./2```X````YM(``"P````?TP``$@```$S3```I````7],``#(`
M``")TP``"@```+S3```L````Q],``"X```#TTP``,P```"/4```S````5]0`
M`#@```"+U```#P```,34```8````U-0``!````#MU```#P```/[4```3````
M#M4``!0````BU0``$@```#?5```4````2M4``!4```!?U0``+0```'75```M
M````H]4``#$```#1U0``+@````/6```O````,M8``"P```!BU@``8@```(_6
M```3````\M8```@````&UP``"`````_7```K````&-<``"$```!$UP``&@``
M`&;7```)````@=<``$4```"+UP``00```-'7```$````$]@``!,````8V```
M%````"S8```.````0=@``!,```!0V```&````&38```&````?=@```D```"$
MV```"@```([8```/````F=@``!````"IV```!P```+K8```.````PM@```4`
M``#1V```&P```-?8```(````\]@```8```#\V```%`````/9```1````&-D`
M``X````JV0``.````#G9```"````<MD```8```!UV0``#@```'S9```%````
MB]D```<```"1V0``#@```)G9```&````J-D```0```"OV0``*0```+39```7
M````WMD``!\```#VV0``7````!;:```4````<]H``#X```"(V@``'P```,?:
M```0````Y]H```<```#XV@``#@````#;```,````#]L```P````<VP``$P``
M`"G;```*````/=L``!T```!(VP``&0```&;;```%````@-L``!$```"&VP``
M$0```)C;```D````JML``!4```#/VP``$@```.7;```.````^-L``!D````'
MW```"````"'<```)````*MP```T````TW```"@```$+<```'````3=P```\`
M``!5W```"P```&7<```*````<=P```<```!\W```"````(3<```%````C=P`
M`!\```"3W```!@```+/<```0````NMP```@```#+W```#0```-3<```(````
MXMP``!(```#KW```+````/[<```:````*]T```D```!&W0``"@```%#=```5
M````6]T```4```!QW0``%````'?=```$````C-T``!````"1W0``!@```*+=
M```'````J=T``!X```"QW0``*````-#=```*````^=T``!H````$W@``%```
M`!_>```$````--X```0````YW@``"P```#[>```%````2MX```8```!0W@``
M"````%?>```&````8-X```H```!GW@``&P```'+>```T````CMX``#0```##
MW@``(````/C>```I````&=\``"````!#WP``00```&3?```:````IM\``"@`
M``#!WP``*0```.K?```B````%.````8````WX```"````#[@```%````1^``
M``@```!-X```&0```%;@```9````<.```"H```"*X```(P```+7@```N````
MV>```#0````(X0``"````#WA```7````1N$```H```!>X0``!P```&GA```A
M````<>$``!````"3X0``#@```*3A```+````L^$```<```"_X0``$P```,?A
M```(````V^$```L```#DX0``"@```/#A```4````^^$``#(````0X@``"P``
M`$/B```%````3^(```4```!5X@``%P```%OB```/````<^(```0```"#X@``
M"@```(CB```)````D^(```L```"=X@``#0```*GB```,````M^(```X```#$
MX@``!0```-/B```$````V>(```T```#>X@``,@```.SB``!%````'^,``!<`
M``!EXP``'@```'WC```4````G.,```4```"QXP``%````+?C```'````S.,`
M``X```#4XP``*@```./C```&````#N0```P````5Y```#0```"+D```1````
M,.0```L```!"Y```-@```$[D```*````A>0``"(```"0Y```"P```+/D```/
M````O^0``#(```#/Y```#@````+E```%````$>4```X````7Y0``$P```";E
M```'````.N4``!$```!"Y0``!P```%3E```4````7.4``!@```!QY0``!P``
M`(KE```%````DN4```P```"8Y0``#````*7E```2````LN4```0```#%Y0``
M!P```,KE```*````TN4```L```#=Y0``#````.GE```.````]N4```X````%
MY@``!0```!3F```%````&N8``"X````@Y@``)@```$_F```C````=N8```,`
M``":Y@``$@```)[F```&````L>8``!X```"XY@``&````-?F```E````\.8`
M``T````6YP``"0```"3G```#````+N<```<````RYP``"@```#KG```"````
M1><```P```!(YP``%0```%7G```+````:^<``!D```!WYP``(````)'G```2
M````LN<```4```#%YP``"@```,OG```5````UN<``!(```#LYP``#````/_G
M```$````#.@```<````1Z```#````!GH``!2````)N@``!<```!YZ```!P``
M`)'H```&````F>@```X```"@Z```#````*_H```-````O.@``!4```#*Z```
M$@```.#H```/````\^@``!0````#Z0``&P```!CI```0````-.D``&D```!%
MZ0``&@```*_I```7````RND``"<```#BZ0``&@````KJ```7````)>H``!L`
M```]Z@``&0```%GJ```?````<^H``!,```"3Z@``"````*?J```'````L.H`
M``@```"XZ@``"0```,'J```5````R^H```T```#AZ@``$P```._J```#````
M`^L``$8````'ZP``/P```$[K```W````CNL``%<```#&ZP``!0```![L```?
M````).P``"\```!$[```"@```'3L```(````?^P```T```"([```+0```);L
M```$````Q.P``$\```#)[```)0```!GM```<````/^T```L```!<[0``'P``
M`&CM```=````B.T``"4```"F[0``(````,SM```D````[>T``"`````2[@``
M"P```#/N```'````/^X```T```!'[@``#````%7N```7````8NX```8```!Z
M[@``.0```('N```,````N^X```<```#([@``"0```-#N```3````VNX```D`
M``#N[@``!````/CN```0````_>X```@````.[P``"````!?O```$````(.\`
M``L````E[P``#````#'O```2````/N\``!$```!1[P``#````&/O```:````
M<.\```\```"+[P``!P```)OO```-````H^\``!0```"Q[P``#@```,;O```,
M````U>\``!L```#B[P``+````/[O```3````*_```!P````_\```*````%SP
M```&````A?````<```",\```$P```)3P```%````J/````0```"N\```%P``
M`+/P```*````R_````P```#6\```"0```./P```&````[?````D```#T\```
M"````/[P```)````!_$```H````1\0``$0```!SQ```&````+O$```X````U
M\0``#@```$3Q```-````4_$```L```!A\0``'0```&WQ```+````B_$```(`
M``"7\0``!P```)KQ```&````HO$```D```"I\0``!P```+/Q```[````N_$`
M`"@```#W\0``-````"#R```5````5?(```4```!K\@``!P```''R```(````
M>?(```<```""\@``!0```(KR```'````D/(```X```"8\@``"0```*?R```&
M````L?(```@```"X\@``"P```,'R```'````S?(```@```#5\@``!P```-[R
M```6````YO(```D```#]\@``!@````?S```+````#O,``!P````:\P``%```
M`#?S```'````3/,```@```!4\P``"````%WS```%````9O,``!````!L\P``
M$````'WS```&````CO,``!D```"5\P``"@```*_S```<````NO,```<```#7
M\P``!0```-_S```0````Y?,``!0```#V\P``"P````OT```-````%_0``!<`
M```E]```!````#WT```)````0O0```H```!,]```!P```%?T```"````7_0`
M``X```!B]```"````''T```?````>O0``",```":]```.````+[T```Q````
M]_0``"<````I]0``9````%'U```4````MO4``%4```#+]0``.````"'V``!*
M````6O8``%L```"E]@``*`````'W```X````*O<``"@```!C]P``+````(SW
M```G````N?<``!L```#A]P``/@```/WW``"I`0``//@``",```#F^0``%P``
M``KZ``!(````(OH``(4```!K^@``,````/'Z``!!````(OL``%L```!D^P``
M20```,#[```=````"OP``!@````H_```(0```$'\```?````8_P``"L```"#
M_```(0```*_\```G````T?P``!T```#Y_```$0```!?]```S````*?T``"4`
M``!=_0``)P```(/]```?````J_T``#````#+_0``:0```/S]```]````9OX`
M`&4```"D_@``30````K_```O````6/\``"X```"(_P``,````+?_``!4````
MZ/\``%H````]``$`2````)@``0!*````X0`!`#(````L`0$`+P```%\!`0`L
M````CP$!`"T```"\`0$`<0```.H!`0!O````7`(!`+,```#,`@$`%P```(`#
M`0`E````F`,!`#(```"^`P$`*0```/$#`0`^````&P0!`"(```!:!`$`4@``
M`'T$`0`E````T`0!``L```#V!`$`L0````(%`0!%````M`4!`"$```#Z!0$`
M,````!P&`0`E````308!`!P```!S!@$`,0```)`&`0`'````P@8!``<```#*
M!@$`!````-(&`0`-````UP8!``L```#E!@$`#@```/$&`0`+``````<!``4`
M```,!P$`$````!('`0`"````(P<!`%D````F!P$`!0```(`'`0`2````A@<!
M``0```"9!P$`!P```)X'`0`(````I@<!``4```"O!P$``P```+4'`0`0````
MN0<!``P```#*!P$`$P```-<'`0`-````ZP<!``(```#Y!P$`!P```/P'`0`&
M````!`@!`!0````+"`$`#````"`(`0`8````+0@!``8```!&"`$`$@```$T(
M`0`,````8`@!``,```!M"`$`*@```'$(`0`$````G`@!``8```"A"`$`!P``
M`*@(`0`?````L`@!`#4```#0"`$`+@````8)`0`O````-0D!`!<```!E"0$`
M(````'T)`0`;````G@D!`!@```"Z"0$`)````-,)`0`?````^`D!`!H````8
M"@$`(````#,*`0`:````5`H!`#(```!O"@$`+P```*(*`0`K````T@H!`!\`
M``#^"@$`(P```!X+`0`?````0@L!`!H```!B"P$`)0```'T+`0`F````HPL!
M`"4```#*"P$`)````/`+`0`8````%0P!`!T````N#`$`)````$P,`0`8````
M<0P!`"(```"*#`$`)0```*T,`0`\````TPP!`!\````0#0$`(P```#`-`0`?
M````5`T!`"````!T#0$`&@```)4-`0`8````L`T!`"8```#)#0$`'@```/`-
M`0`I````#PX!`!X````Y#@$`"0```%@.`0`,````8@X!`!<```!O#@$`+P``
M`(<.`0`D````MPX!``<```#<#@$`#P```.0.`0`4````]`X!``X````)#P$`
M#0```!@/`0`D````)@\!``4```!+#P$`!P```%$/`0`B````60\!`"4```!\
M#P$`'0```*(/`0`:````P`\!``<```#;#P$`QP```.,/`0`+````JQ`!`!4`
M``"W$`$`!@```,T0`0`)````U!`!``L```#>$`$`%P```.H0`0`&`````A$!
M`#,````)$0$`$P```#T1`0`3````41$!``<```!E$0$`#P```&T1`0`'````
M?1$!`#(```"%$0$`(0```+@1`0`3````VA$!``P```#N$0$`$0```/L1`0`R
M````#1(!``@```!`$@$`"0```$D2`0`*````4Q(!`!0```!>$@$`"@```',2
M`0`=````?A(!``@```"<$@$`'P```*42`0`(````Q1(!`!H```#.$@$`!@``
M`.D2`0`5````\!(!``<````&$P$`"`````X3`0`)````%Q,!`#\````A$P$`
M!P```&$3`0`/````:1,!``X```!Y$P$`$````(@3`0`)````F1,!``D```"C
M$P$`"````*T3`0`3````MA,!``<```#*$P$`&0```-(3`0`*````[!,!`!<`
M``#W$P$`%`````\4`0`*````)!0!``P````O%`$`%P```#P4`0`$````5!0!
M`"H```!9%`$`$0```(04`0`'````EA0!``(```">%`$`$````*$4`0`8````
MLA0!``L```#+%`$``P```-<4`0`(````VQ0!``8```#D%`$`!P```.L4`0`-
M````\Q0!``L````!%0$`%`````T5`0`5````(A4!``X````X%0$`+P```$<5
M`0`@````=Q4!`!P```"8%0$`#````+45`0`Q````PA4!``4```#T%0$`$@``
M`/H5`0`_````#18!`!(```!-%@$`"@```&`6`0`&````:Q8!``0```!R%@$`
M!````'<6`0`*````?!8!`!,```"'%@$`!0```)L6`0`&````H18!``8```"H
M%@$`!````*\6`0`,````M!8!``H```#!%@$`!0```,P6`0`8````TA8!`!D`
M``#K%@$`'P````47`0`=````)1<!`!$```!#%P$``@```%47`0`$````6!<!
M``H```!=%P$`!@```&@7`0`%````;Q<!``,```!U%P$`#````'D7`0!%````
MAA<!`!H```#,%P$`-0```.<7`0`H````'1@!`%,```!&&`$`&0```)H8`0!R
M````M!@!`"`````G&0$`-0```$@9`0`A````?AD!`$4```"@&0$`,````.89
M`0`H````%QH!`"D```!`&@$`)@```&H:`0`E````D1H!`"@```"W&@$`*```
M`.`:`0`B````"1L!`#`````L&P$`$@```%T;`0`3````<!L!`!````"$&P$`
M>0```)4;`0`)````#QP!`',````9'`$`?````(T<`0`K````"AT!`!<````V
M'0$`%@```$X=`0`/````91T!`!\```!U'0$`0````)4=`0`?````UAT!`!P`
M``#V'0$`40```!,>`0`4````91X!``H```!Z'@$`!0```(4>`0`&````BQX!
M``@```"2'@$`!0```)L>`0`2````H1X!`!````"T'@$`$P```,4>`0`=````
MV1X!``\```#W'@$`#P````<?`0`$````%Q\!``D````<'P$`"P```"8?`0`'
M````,A\!``4````Z'P$`%````$`?`0`'````51\!``@```!='P$`#P```&8?
M`0`(````=A\!``P```!_'P$`#P```(P?`0`&````G!\!`!0```"C'P$`!@``
M`+@?`0`,````OQ\!``@```#,'P$`!````-4?`0`*````VA\!``<```#E'P$`
M!````.T?`0`9````\A\!``(````,(`$`"0````\@`0`&````&2`!``8````@
M(`$`)P```"<@`0`$````3R`!``\```!4(`$`$P```&0@`0`'````>"`!``<`
M``"`(`$`!@```(@@`0`&````CR`!`!````"6(`$`$@```*<@`0`&````NB`!
M``D```#!(`$`(@```,L@`0`'````[B`!``<```#V(`$`"P```/X@`0`%````
M"B$!``(````0(0$`"P```!,A`0!K`0``'R$!``X```"+(@$`%````)HB`0`+
M````KR(!``@```"[(@$`"````,0B`0`&````S2(!``@```#4(@$`"P```-TB
M`0`6````Z2(!``T`````(P$`#0````XC`0`%````'",!`!T````B(P$`"@``
M`$`C`0`(````2R,!`!0```!4(P$`#0```&DC`0`+````=R,!`!$```"#(P$`
M"0```)4C`0`.````GR,!``T```"N(P$`$````+PC`0`)````S2,!``X```#7
M(P$`$````.8C`0`&````]R,!`!$```#^(P$`$@```!`D`0`)````(R0!`!<`
M```M)`$`%P```$4D`0`'````720!`#,```!E)`$`%P```)DD`0`]````L20!
M`$T```#O)`$`9````#TE`0!<````HB4!`&L```#_)0$`8P```&LF`0`_````
MSR8!``D````/)P$`"0```!DG`0`,````(R<!``4````P)P$`!@```#8G`0`4
M````/2<!``P```!2)P$`!0```%\G`0`&````92<!`"@```!L)P$`*@```)4G
M`0`.````P"<!`!$```#/)P$`#````.$G`0`$````[B<!``T```#S)P$`#0``
M``$H`0`,````#R@!``X````<*`$`#@```"LH`0`4````.B@!``H```!/*`$`
M#0```%HH`0`*````:"@!`"P```!S*`$`%0```*`H`0`4````MB@!``X```#+
M*`$`(P```-HH`0`%````_B@!``T````$*0$`,@```!(I`0`'````12D!``,`
M``!-*0$`"@```%$I`0`*````7"D!``<```!G*0$`"````&\I`0`&````>"D!
M``H```!_*0$`!````(HI`0`<````CRD!``L```"L*0$`"P```+@I`0`,````
MQ"D!`!@```#1*0$`-````.HI`0`)````'RH!`!$````I*@$`$P```#LJ`0`8
M````3RH!`!T```!H*@$`#P```(8J`0`,````EBH!``X```"C*@$`&@```+(J
M`0`&````S2H!``8```#4*@$`"````-LJ`0`,````Y"H!``4```#Q*@$`"0``
M`/<J`0`2`````2L!``@````4*P$`$````!TK`0`.````+BL!`!<````]*P$`
M!@```%4K`0`.````7"L!``4```!K*P$`%0```'$K`0`5````ARL!``P```"=
M*P$`.@```*HK`0`(````Y2L!``H```#N*P$`%````/DK`0`%````#BP!``4`
M```4+`$`$0```!HL`0`,````+"P!`!0````Y+`$`+P```$XL`0`/````?BP!
M`"4```".+`$`)````+0L`0`I````V2P!`"T````#+0$`#````#$M`0`'````
M/BT!``L```!&+0$`"0```%(M`0`O````7"T!`"P```",+0$`+0```+DM`0!?
M````YRT!`"P```!'+@$`+````'0N`0`L````H2X!`"X```#.+@$`)````/TN
M`0`H````(B\!`"P```!++P$`,@```'@O`0`9````JR\!`!P```#%+P$`,P``
M`.(O`0`H````%C`!`!,````_,`$`"@```%,P`0`1````7C`!``<```!P,`$`
M#0```'@P`0`7````AC`!`!P```">,`$`"0```+LP`0`'````Q3`!`!0```#-
M,`$`"0```.(P`0`(````[#`!``T```#U,`$`"P````,Q`0`'````#S$!``8`
M```7,0$`!0```!XQ`0`'````)#$!``8````L,0$`"0```#,Q`0`Q````/3$!
M``T```!O,0$`"0```'TQ`0`$````AS$!``<```",,0$`"@```)0Q`0`%````
MGS$!`!````"E,0$`"````+8Q`0`,````OS$!``D```#,,0$`"````-8Q`0`#
M````WS$!``X```#C,0$`"````/(Q`0`>````^S$!``8````:,@$`"P```"$R
M`0`0````+3(!``P````^,@$`!P```$LR`0`#````4S(!``,```!7,@$`%0``
M`%LR`0`5````<3(!``8```"',@$`!@```(XR`0`(````E3(!``<```">,@$`
M3````*8R`0`?````\S(!``8````3,P$`!0```!HS`0`7````(#,!`!@````X
M,P$`&````%$S`0`Q````:C,!`!H```"<,P$`'P```+<S`0!W````US,!`"P`
M``!/-`$`"@```'PT`0`&````AS0!`!@```".-`$`#@```*<T`0`,````MC0!
M`!$```##-`$`$P```-4T`0`1````Z30!`!$```#[-`$`#`````TU`0`4````
M&C4!``0````O-0$`%P```#0U`0`8````3#4!`!@```!E-0$`%@```'XU`0`#
M````E34!``@```"9-0$`:P```*(U`0`(````#C8!`!8````7-@$`!````"XV
M`0`#````,S8!`!\````W-@$`%P```%<V`0`,````;S8!`!,```!\-@$`)P``
M`)`V`0`S````N#8!`!$```#L-@$`&@```/XV`0`'````&3<!`!\````A-P$`
M%P```$$W`0`1````63<!`!@```!K-P$`&0```(0W`0`7````GC<!``\```"V
M-P$`"````,8W`0`'````SS<!``T```#7-P$`%0```.4W`0`4````^S<!``D`
M```0.`$`!````!HX`0`+````'S@!``L````K.`$`"0```#<X`0`0````03@!
M``4```!2.`$`!0```%@X`0`,````7C@!``@```!K.`$`"0```'0X`0`'````
M?C@!``8```"&.`$`#0```(TX`0`(````FS@!`!4```"D.`$`#0```+HX`0`0
M````R#@!``4```#9.`$`'````-\X`0`8````_#@!`!@````5.0$`+````"XY
M`0`[````6SD!`"4```"7.0$`-P```+TY`0`%````]3D!``P```#[.0$`!0``
M``@Z`0`'````#CH!``X````6.@$`"@```"4Z`0`-````,#H!`!P````^.@$`
M&P```%LZ`0`?````=SH!`!X```"7.@$`'P```+8Z`0`>````UCH!`!@```#U
M.@$`(`````X[`0`A````+SL!`"0```!1.P$`'P```'8[`0`>````ECL!`"\`
M``"U.P$`(P```.4[`0`E````"3P!`#$````O/`$`+@```&$\`0`-````D#P!
M`"4```">/`$`#0```,0\`0"9````TCP!`!````!L/0$`'P```'T]`0`A````
MG3T!`",```"_/0$`)````.,]`0`A````"#X!`!X````J/@$`)0```$D^`0`H
M````;SX!`"P```"8/@$`HP```,4^`0`8````:3\!`",```""/P$`(@```*8_
M`0!+````R3\!``X````50`$`!````"1``0`'````*4`!``4````Q0`$`#@``
M`#=``0`*````1D`!``\```!10`$`$0```&%``0`3````<T`!``L```"'0`$`
M!````)-``0`/````F$`!``T```"H0`$`%0```+9``0`2````S$`!`!(```#?
M0`$`,````/)``0`#````(T$!`!,````G00$`!@```#M!`0`.````0D$!`!0`
M``!100$`%@```&9!`0`/````?4$!``(```"-00$`!@```)!!`0`5````ET$!
M``4```"M00$`#````+-!`0`,````P$$!``,```#-00$`"P```-%!`0`&````
MW4$!``\```#D00$`#P```/1!`0`*````!$(!``\````/0@$`$0```!]"`0`(
M````,4(!``,````Z0@$`"````#Y"`0`(````1T(!`!@```!00@$`"0```&E"
M`0`)````<T(!`!D```!]0@$`"@```)="`0`4````HD(!`!0```"W0@$`%```
M`,Q"`0`-````X4(!``D```#O0@$`$0```/E"`0`(````"T,!`#P````40P$`
M,@```%%#`0`'````A$,!``L```",0P$`&@```)A#`0`-````LT,!`!$```#!
M0P$`$0```--#`0`%````Y4,!`"````#K0P$`%P````Q$`0`>````)$0!`!(`
M``!#1`$`#P```%9$`0`&````9D0!``@```!M1`$`+0```'9$`0`^````I$0!
M``<```#C1`$`$P```.M$`0`%````_T0!``@````%10$`,P````Y%`0`2````
M0D4!``<```!510$`!P```%U%`0`#````944!``<```!I10$`!P```'%%`0`,
M````>44!``P```"&10$`#````)-%`0`0````H$4!`!@```"Q10$`%````,I%
M`0`8````WT4!``8```#X10$`!0```/]%`0`+````!48!``8````11@$``@``
M`!A&`0`0````&T8!`!<````L1@$`)0```$1&`0`7````:D8!`!````""1@$`
M"@```)-&`0`*````GD8!`!,```"I1@$`3@```+U&`0`J````#$<!``H````W
M1P$`%@```$)'`0!R````64<!`!T```#,1P$`#@```.I'`0`&````^4<!``0`
M````2`$`(`````5(`0`'````)D@!``@````N2`$`!0```#=(`0`&````/4@!
M``T```!$2`$`#````%)(`0`-````7T@!``P```!M2`$`"P```'I(`0`.````
MAD@!``H```"52`$`#P```*!(`0`(````L$@!``@```"Y2`$`%P```,)(`0`.
M````VD@!`"\```#I2`$`%0```!E)`0`#````+TD!``T````S20$`&@```$%)
M`0`@````7$D!`",```!]20$`(@```*%)`0`D````Q$D!`"(```#I20$`)```
M``Q*`0`?````,4H!``H```!12@$`&@```%Q*`0`-````=TH!``T```"%2@$`
M!````)-*`0`%````F$H!``P```">2@$`#@```*M*`0`-````NDH!`!(```#(
M2@$`#````-M*`0`$````Z$H!`!8```#M2@$`%@````1+`0`0````&TL!``D`
M```L2P$`#````#9+`0`-````0TL!`!T```!12P$`"0```&]+`0`*````>4L!
M``@```"$2P$`"@```(U+`0`-````F$L!``4```"F2P$`!0```*Q+`0`#````
MLDL!``T```"V2P$`"@```,1+`0`%````STL!`"H```#52P$`#`````!,`0![
M````#4P!`!<```")3`$`!P```*%,`0`%````J4P!``H```"O3`$`"````+I,
M`0`*````PTP!``@```#.3`$`#@```-=,`0`"````YDP!``H```#I3`$`!@``
M`/1,`0`4````^TP!`!`````030$`$P```"%-`0`5````-4T!``8```!+30$`
M!@```%)-`0`-````64T!``<```!G30$`!P```&]-`0`%````=TT!`!T```!]
M30$`!P```)M-`0`'````HTT!`!L```"K30$`#P```,=-`0`)````UTT!``<`
M``#A30$`!````.E-`0`+````[DT!``H```#Z30$``P````5.`0`&````"4X!
M``P````03@$`"P```!U.`0`*````*4X!`!0````T3@$`"````$E.`0`'````
M4DX!``T```!:3@$`'````&A.`0`'````A4X!``@```"-3@$`!````)9.`0`)
M````FTX!``@```"E3@$`#@```*Y.`0`-````O4X!``0```#+3@$`#````-!.
M`0`&````W4X!``0```#D3@$`,@```.E.`0`S````'$\!`#,```!03P$`(```
M`(1/`0`%````I4\!`!````"K3P$`"0```+Q/`0`&````QD\!`!\```#-3P$`
M%P```.U/`0`)````!5`!``8````/4`$`&P```!90`0`(````,E`!``@````[
M4`$`%0```$10`0`&````6E`!``D```!A4`$`!P```&M0`0`(````<U`!``D`
M``!\4`$`"P```(90`0`(````DE`!``D```";4`$`!0```*50`0!(````JU`!
M`#<```#T4`$`.P```"Q1`0`G````:%$!`$D```"040$`.P```-I1`0`C````
M%E(!`#<````Z4@$`(P```')2`0`:````EE(!`!@```"Q4@$`"P```,I2`0`0
M````UE(!``8```#G4@$`*P```.Y2`0`J````&E,!`!4```!%4P$`*@```%M3
M`0`#````AE,!``4```"*4P$`"@```)!3`0`*````FU,!`"0```"F4P$`(```
M`,M3`0`K````[%,!``D````85`$`&````")4`0`O````.U0!`!0```!K5`$`
M%P```(!4`0`'````F%0!``\```"@5`$`$````+!4`0`;````P50!``T```#=
M5`$`10```.M4`0!J````,54!`($```"<50$`$````!Y6`0`+````+U8!``P`
M```[5@$`$````$A6`0`1````658!`!````!K5@$`"@```'Q6`0`4````AU8!
M`!@```"<5@$`&````+56`0`3````SE8!`!H```#B5@$`)````/U6`0!H````
M(E<!`!````"+5P$`"0```)Q7`0`5````IE<!``D```"\5P$`!0```,97`0`%
M````S%<!`!,```#25P$`$0```.97`0`1````^%<!`!@````*6`$`$@```"-8
M`0`N````-E@!`"\```!E6`$`,````)58`0`O````QE@!`#,```#V6`$`,@``
M`"I9`0`6````75D!`$,```!T60$`&P```+A9`0`:````U%D!`!H```#O60$`
M&0````I:`0`)````)%H!`!T````N6@$`'````$Q:`0`:````:5H!`!D```"$
M6@$`&@```)Y:`0`<````N5H!`!L```#66@$`+@```/):`0`.````(5L!``<`
M```P6P$`#P```#A;`0`M````2%L!`!(```!V6P$`%P```(E;`0`9````H5L!
M`!8```"[6P$`%0```-);`0`1````Z%L!`!T```#Z6P$`)````!A<`0`2````
M/5P!`!L```!07`$`&0```&Q<`0`7````AEP!`!@```">7`$`!````+=<`0`6
M````O%P!``0```#37`$`!P```-A<`0`/````X%P!`"````#P7`$`!@```!%=
M`0`'````&%T!``8````@70$`!@```"==`0`'````+ET!``0````V70$`!P``
M`#M=`0`5````0UT!``8```!970$`!0```&!=`0`&````9ET!``<```!M70$`
M!0```'5=`0`,````>UT!``T```"(70$`"@```)9=`0`*````H5T!``H```"L
M70$`&````+==`0`%````T%T!`"4```#670$`$@```/Q=`0`-````#UX!`!$`
M```=7@$`$````"]>`0`,````0%X!`!$```!-7@$`*P```%]>`0`(````BUX!
M``@```"47@$`"@```)U>`0`*````J%X!``\```"S7@$`!@```,->`0`+````
MREX!``T```#67@$``P```.1>`0`?````Z%X!``H````(7P$`"0```!-?`0`/
M````'5\!``T````M7P$`&@```#M?`0`/````5E\!``<```!F7P$`!````&Y?
M`0`%````<U\!`!T```!Y7P$`!@```)=?`0`#````GE\!`!(```"B7P$`$```
M`+5?`0`'````QE\!``<```#.7P$`!0```-9?`0`-````W%\!``D```#J7P$`
M#````/1?`0`<`````6`!`!H````>8`$`%0```#E@`0`:````3V`!``D```!J
M8`$`$@```'1@`0`,````AV`!``@```"48`$`$0```)U@`0!!````KV`!``L`
M``#Q8`$`#````/U@`0`D````"F$!`!@````O80$`&0```$AA`0`3````8F$!
M``T```!V80$`#@```(1A`0`*````DV$!``T```">80$`&@```*QA`0`5````
MQV$!`!T```#=80$`)@```/MA`0`(````(F(!``@````K8@$`#0```#1B`0`,
M````0F(!``P```!/8@$``P```%QB`0`%````8&(!``4```!F8@$`#P```&QB
M`0!#````?&(!`!4```#`8@$`"@```-9B`0`#````X6(!``4```#E8@$`%```
M`.MB`0`4`````&,!`!0````58P$`"@```"IC`0`"````-6,!``0````X8P$`
M(````#UC`0`#````7F,!``4```!B8P$`"0```&AC`0`*````<F,!``0```!]
M8P$`!0```()C`0`0````B&,!`!(```"98P$`!@```*QC`0`'````LV,!``D`
M``"[8P$`!````,5C`0`%````RF,!`&,```#08P$`#@```#1D`0`1````0V0!
M``0```!59`$`#0```%ID`0`A````:&0!`#\```"*9`$`$````,ID`0`(````
MVV0!``\```#D9`$`"0```/1D`0`(````_F0!`!T````'90$`)@```"5E`0`D
M````3&4!`",```!Q90$`$0```)5E`0`%````IV4!``<```"M90$``P```+5E
M`0`&````N64!``H```#`90$`$P```,ME`0`%````WV4!`$@```#E90$`%0``
M`"YF`0`*````1&8!``L```!/9@$`)P```%MF`0!,````@V8!``8```#09@$`
M!@```-=F`0`'````WF8!``H```#F9@$`!````/%F`0`)````]F8!`",`````
M9P$`(@```"1G`0`%````1V<!``@```!-9P$`)@```%9G`0!@````?6<!`!(`
M``#>9P$`)P```/%G`0`8````&6@!``,````R:`$`#````#9H`0`%````0V@!
M``X```!):`$`#````%AH`0`*````96@!``@```!P:`$`!@```'EH`0`*````
M@&@!``D```"+:`$`!0```)5H`0`*````FV@!``L```"F:`$``P```+)H`0`/
M````MF@!`!(```#&:`$`$@```-EH`0`*````[&@!``D```#W:`$`"0````%I
M`0`+````"VD!``H````7:0$`"P```")I`0`(````+FD!`"$````W:0$`"P``
M`%EI`0`'````96D!``@```!M:0$`#@```'9I`0`'````A6D!``\```"-:0$`
M`@```)UI`0`'````H&D!``4```"H:0$`!0```*YI`0`(````M&D!`!(```"]
M:0$`$@```-!I`0`5````XVD!`!4```#Y:0$`%`````]J`0`2````)&H!`!<`
M```W:@$`(````$]J`0`:````<&H!``(```"+:@$`!````(YJ`0`.````DVH!
M``T```"B:@$`!P```+!J`0`<````N&H!``T```#5:@$`$P```.-J`0`(````
M]VH!``X`````:P$`!P````]K`0`2````%VL!``D````J:P$`!P```#1K`0`'
M````/&L!``0```!$:P$`!````$EK`0`%````3FL!`$,```!4:P$`.@```)AK
M`0`2````TVL!`"L```#F:P$`.````!)L`0`.````2VP!`"D```!:;`$`,0``
M`(1L`0`V````MFP!`#8```#M;`$`.P```"1M`0`*````8&T!`"<```!K;0$`
M&````)-M`0`8````K&T!`!@```#%;0$`&````-YM`0`0````]VT!`!0````(
M;@$`&````!UN`0`G````-FX!`"<```!>;@$`*P```(9N`0`H````LFX!`"D`
M``#;;@$`)@````5O`0!@````+&\!`!P```"-;P$`"0```*IO`0`'````M&\!
M`"8```"\;P$`*@```.-O`0`@````#G`!``D````O<`$`0P```#EP`0!&````
M?7`!``<```#$<`$`&0```,QP`0`<````YG`!``T````#<0$`#P```!%Q`0`5
M````(7$!``8````W<0$`$````#YQ`0`/````3W$!``L```!?<0$`$P```&MQ
M`0`-````?W$!``\```"-<0$`!@```)UQ`0`D````I'$!``4```#)<0$`!```
M`,]Q`0`/````U'$!``P```#D<0$`#````/%Q`0!`````_G$!``0````_<@$`
M!0```$1R`0`0````2G(!``\```!;<@$`!````&MR`0`4````<'(!``0```"%
M<@$`!0```(IR`0`]````D'(!`!D```#.<@$`.````.AR`0!=````(7,!`!$`
M``!_<P$`10```)%S`0`?````UW,!``\```#W<P$`"@````=T`0`2````$G0!
M`!`````E=`$`!P```#9T`0`.````/G0!``D```!-=`$`%@```%=T`0`<````
M;G0!``4```"+=`$`#@```)%T`0`.````H'0!`!T```"O=`$`$````,UT`0`4
M````WG0!`!$```#S=`$`(P````5U`0`(````*74!``H````R=0$`#P```#UU
M`0`.````374!``8```!<=0$`$@```&-U`0`8````=G4!``L```"/=0$`"@``
M`)MU`0`(````IG4!``4```"O=0$`'@```+5U`0`&````U'4!``\```#;=0$`
M"````.MU`0`.````]'4!``8````#=@$`#0````IV`0`M````&'8!``T```!&
M=@$`!P```%1V`0`'````7'8!`!X```!D=@$`"````(-V`0`0````C'8!``,`
M``"==@$`$P```*%V`0`(````M78!``4```"^=@$`'@```,1V`0`M````XW8!
M``0````1=P$`#0```!9W`0`0````)'<!``0````U=P$`#P```#IW`0`*````
M2G<!``<```!5=P$`"P```%UW`0`(````:7<!``P```!R=P$`#0```']W`0`>
M````C7<!`#$```"L=P$`-@```-YW`0`?````%7@!`"0````U>`$`(P```%IX
M`0`_````?G@!`!\```"^>`$`(0```-YX`0`H`````'D!`"$````I>0$`!P``
M`$MY`0`(````4WD!``D```!<>0$`"````&9Y`0`9````;WD!`!D```")>0$`
M,P```*-Y`0`J````UWD!`"T````">@$`,@```#!Z`0`&````8WH!`!L```!J
M>@$`!P```(9Z`0`(````CGH!`!\```"7>@$`$0```+=Z`0`.````R7H!``P`
M``#8>@$`!0```.5Z`0`1````ZWH!``@```#]>@$`$@````9[`0`,````&7L!
M`!@````F>P$`,0```#][`0`*````<7L!``4```!\>P$`!0```()[`0`:````
MB'L!``P```"C>P$`!@```+![`0`6````MWL!`!0```#.>P$`#0```.-[`0`-
M````\7L!`!4```#_>P$`#@```!5\`0`$````)'P!``4````I?`$`#0```"]\
M`0!(````/7P!`&,```"&?`$`$P```.I\`0`?````_GP!`!D````>?0$`#0``
M`#A]`0`/````1GT!``L```!6?0$`$@```&)]`0`L````=7T!``,```"B?0$`
M"0```*9]`0`*````L'T!``\```"[?0$`"P```,M]`0`R````UWT!``,````*
M?@$`&@````Y^`0`-````*7X!`!,````W?@$`)P```$M^`0`,````<WX!``<`
M``"`?@$`$````(A^`0`5````F7X!``@```"O?@$`$0```+A^`0`'````RGX!
M`!H```#2?@$`)@```.U^`0`*````%'\!``,````??P$`$@```"-_`0`.````
M-G\!`!4```!%?P$`!0```%M_`0`'````87\!`!$```!I?P$`"P```'M_`0`+
M````AW\!`!$```"3?P$`$0```*5_`0`)````MW\!``@```#!?P$`-````,I_
M`0`N````_W\!`"X````N@`$`"````%V``0`1````9H`!``8```!X@`$`%P``
M`'^``0`<````EX`!`!X```"T@`$`#@```-.``0`*````XH`!``,```#M@`$`
M"````/&``0`+````^H`!``,````&@0$`#`````J!`0`4````%X$!``L````L
M@0$`&````#B!`0`;````48$!`!<```!M@0$`!0```(6!`0`*````BX$!`!0`
M``"6@0$`#@```*N!`0`/````NH$!``8```#*@0$`"0```-&!`0`2````VX$!
M`$X```#N@0$`'0```#V"`0`%````6X(!``4```!A@@$`#P```&>"`0`-````
M=X(!``\```"%@@$`&P```)6"`0`1````L8(!`!````##@@$`(````-2"`0`?
M````]8(!``\````5@P$`;@```"6#`0`<````E(,!`!4```"Q@P$`)@```,>#
M`0`;````[H,!`!0````*A`$`&````!^$`0`6````.(0!`!P```!/A`$`$P``
M`&R$`0`*````@(0!``<```"+A`$`"P```).$`0`%````GX0!`!<```"EA`$`
M#0```+V$`0`?````RX0!``8```#KA`$`2@```/*$`0`Q````/84!`$0```!O
MA0$`8P```+2%`0`'````&(8!`#0````@A@$`*````%6&`0`&````?H8!``H`
M``"%A@$`"0```)"&`0`R````FH8!``8```#-A@$`6P```-2&`0`K````,(<!
M`"4```!<AP$`#P```(*'`0`P````DH<!`!\```##AP$`)P```..'`0`A````
M"X@!`"<````MB`$`(P```%6(`0`0````>8@!``<```"*B`$`%P```)*(`0`5
M````JH@!``\```#`B`$`!@```-"(`0`O````UX@!``P````'B0$`!@```!2)
M`0`$````&XD!`!`````@B0$`"````#&)`0`%````.HD!``L```!`B0$`"```
M`$R)`0`(````58D!``,```!>B0$`#````&*)`0`/````;XD!`!\```!_B0$`
M'0```)^)`0`/````O8D!`!8```#-B0$`#P```.2)`0`&````](D!`!(```#[
MB0$`%@````Z*`0`-````)8H!``P````SB@$`&0```$"*`0`G````6HH!``\`
M``""B@$`(@```)**`0`K````M8H!`!$```#AB@$`#@```/.*`0`<`````HL!
M``<````?BP$`$````">+`0`4````.(L!``L```!-BP$`"@```%F+`0`*````
M9(L!``<```!OBP$`"0```'>+`0`(````@8L!``D```"*BP$`#@```)2+`0`.
M````HXL!``4```"RBP$`#P```+B+`0`,````R(L!``P```#5BP$`#0```.*+
M`0`:````\(L!``L````+C`$``P```!>,`0`$````&XP!``8````@C`$`"```
M`">,`0`&````,(P!`%0````WC`$`*````(R,`0`S````M8P!`!4```#IC`$`
M!0```/^,`0`$````!8T!``H````*C0$`"@```!6-`0`'````((T!``H````H
MC0$`%0```#.-`0`,````28T!``H```!6C0$`#````&&-`0`(````;HT!``8`
M``!WC0$`!P```'Z-`0`&````AHT!`!4```"-C0$`"0```*.-`0`%````K8T!
M``<```"SC0$`(@```+N-`0`&````WHT!`!4```#EC0$`&````/N-`0`+````
M%(X!``<````@C@$`$P```"B.`0`3````/(X!``8```!0C@$`$P```%>.`0`*
M````:XX!``@```!VC@$`!@```'^.`0`(````AHX!`!````"/C@$`&````*".
M`0`(````N8X!``H```#"C@$`#P```,V.`0`%````W8X!``P```#CC@$`$```
M`/".`0`+`````8\!``,````-CP$`#0```!&/`0`'````'X\!`"P````GCP$`
M*@```%2/`0`Y````?X\!`"0```"YCP$`+0```-Z/`0!?````#)`!`!````!L
MD`$`5P```'V0`0`U````U9`!`%H````+D0$`4P```&:1`0`>````NI$!`$(`
M``#9D0$`(````!R2`0`C````/9(!`"$```!AD@$`%0```(.2`0`_````F9(!
M`-(!``#9D@$`%````*R4`0`0````P90!`$$```#2E`$`>0```!25`0`Q````
MCI4!`#P```#`E0$`4P```/V5`0!/````498!`!H```"AE@$`$````+R6`0`6
M````S98!`!D```#DE@$`(P```/Z6`0`A````(I<!`"(```!$EP$`&@```&>7
M`0`0````@I<!`#,```"3EP$`'0```,>7`0`A````Y9<!`!P````'F`$`+@``
M`"28`0!=````4Y@!`#D```"QF`$`6P```.N8`0!$````1YD!`#(```",F0$`
M/@```+^9`0`R````_ID!`%`````QF@$`;P```(*:`0!=````\IH!`%$```!0
MFP$`-````**;`0`@````UYL!`"$```#XFP$`(P```!J<`0!O````/IP!`&D`
M``"NG`$`OP```!B=`0`7````V)T!`"````#PG0$`/````!&>`0`\````3IX!
M`#L```"+G@$`)0```,>>`0!%````[9X!`!8````SGP$`!@```$J?`0#%````
M49\!`$$````7H`$`(P```%F@`0`P````?:`!`"(```"NH`$`'````-&@`0`R
M````[J`!``T````AH0$`"````"^A`0`%````.*$!``P````^H0$`#````$NA
M`0`,````6*$!``L```!EH0$`!@```'&A`0`2````>*$!``0```"+H0$`3@``
M`)"A`0`%````WZ$!`!0```#EH0$`!````/JA`0`'````_Z$!``4````'H@$`
M!0````VB`0`#````$Z(!`!(````7H@$`"0```"JB`0`2````-*(!`!$```!'
MH@$``@```%FB`0`%````7*(!``<```!BH@$`$P```&JB`0`,````?J(!`!<`
M``"+H@$`!@```*.B`0`1````JJ(!``T```"\H@$``P```,JB`0`R````SJ(!
M``0````!HP$`!@````:C`0`'````#:,!`!P````5HP$`+0```#*C`0`N````
M8*,!`"\```"/HP$`$P```+^C`0`>````TZ,!`!<```#RHP$`&P````JD`0`>
M````)J0!`!D```!%I`$`&@```%^D`0`>````>J0!`!8```"9I`$`*0```+"D
M`0`?````VJ0!`"<```#ZI`$`%P```"*E`0`;````.J4!`!T```!6I0$`&```
M`'2E`0`D````C:4!`"8```"RI0$`)P```-FE`0`7`````:8!`!@````9I@$`
M'````#*F`0`B````3Z8!`!<```!RI@$`'@```(JF`0`:````J:8!`#X```#$
MI@$`)`````.G`0`G````**<!`"H```!0IP$`*P```'NG`0`E````IZ<!`!L`
M``#-IP$`(````.FG`0`=````"J@!`#`````HJ`$`'0```%FH`0`*````=Z@!
M`!8```""J`$`$@```)FH`0`H````K*@!`!T```#5J`$`#0```/.H`0`/````
M`:D!`!D````1J0$`$````"NI`0`;````/*D!`#$```!8J0$`"````(JI`0`*
M````DZD!`"(```">J0$`)@```,&I`0`E````Z*D!`!D````.J@$`!P```"BJ
M`0#"````,*H!`!H```#SJ@$`%0````ZK`0`(````)*L!``P````MJP$`%```
M`#JK`0`:````3ZL!``4```!JJP$`-0```'"K`0`4````IJL!`!0```"[JP$`
M!P```-"K`0`*````V*L!``H```#CJP$`0````.ZK`0`E````+ZP!`!(```!5
MK`$`%0```&BL`0`/````?JP!`#(```".K`$`#0```,&L`0`.````SZP!``\`
M``#>K`$`&````.ZL`0`*````!ZT!``\````2K0$`!0```"*M`0`?````**T!
M``H```!(K0$`'P```%.M`0`(````<ZT!`!4```!\K0$`!P```)*M`0`(````
MFJT!``H```"CK0$`.P```*ZM`0`%````ZJT!``T```#PK0$`"@```/ZM`0`0
M````":X!``8````:K@$`"@```"&N`0`'````+*X!`!(````TK@$`#````$>N
M`0`=````5*X!`!,```!RK@$`'@```(:N`0`R````I:X!``4```#8K@$`!@``
M`-ZN`0`<````Y:X!``0````"KP$`*@````>O`0`0````,J\!``4```!#KP$`
M`P```$FO`0`,````3:\!`!<```!:KP$`"P```'*O`0`#````?J\!``H```""
MKP$`"````(VO`0`+````EJ\!``X```"BKP$`#P```+&O`0`1````P:\!`!(`
M``#3KP$`"@```.:O`0`P````\:\!`!L````BL`$`&````#ZP`0`*````5[`!
M`$@```!BL`$`"````*NP`0`6````M+`!`$(```#+L`$`%`````ZQ`0`/````
M([$!``D````SL0$`!````#VQ`0`&````0K$!`!8```!)L0$`&@```&"Q`0`'
M````>[$!``@```"#L0$`"````(RQ`0`"````E;$!``D```"8L0$`"P```**Q
M`0`%````KK$!`!H```"TL0$`)@```,^Q`0`5````]K$!`!X````,L@$`$0``
M`"NR`0`"````/;(!``0```!`L@$`#P```$6R`0`&````5;(!``4```!<L@$`
M!````&*R`0`4````9[(!`$D```!\L@$`$0```,:R`0`E````V+(!`"\```#^
ML@$`6````"ZS`0`1````A[,!`&D```"9LP$`'P````.T`0`\````([0!`"8`
M``!@M`$`.0```(>T`0`N````P;0!`"<```#PM`$`-0```!BU`0`Q````3K4!
M`#$```"`M0$`-0```+*U`0`M````Z+4!`!\````6M@$`-@```#:V`0`:````
M;;8!``X```"(M@$`#````)>V`0!S````I+8!``8````8MP$`=0```!^W`0!J
M````E;<!`"L`````N`$`$````"RX`0`6````/;@!``L```!4N`$`&@```&"X
M`0`U````>[@!`!L```"QN`$`%0```,VX`0!7````X[@!`!<````[N0$`"@``
M`%.Y`0`%````7KD!``8```!DN0$`"````&NY`0`%````=+D!`!0```!ZN0$`
M$````(^Y`0`6````H+D!`"````"WN0$`"P```-BY`0`(````Y+D!``0```#M
MN0$`"@```/*Y`0`+````_;D!``@````)N@$`!P```!*Z`0`7````&KH!``8`
M```RN@$`!@```#FZ`0`7````0+H!``L```!8N@$`!P```&2Z`0`2````;+H!
M``@```!_N@$`%P```(BZ`0`-````H+H!``T```"NN@$`!@```+RZ`0`&````
MP[H!``\```#*N@$`!P```-JZ`0`%````XKH!`!0```#HN@$``@```/VZ`0`$
M`````+L!``P````%NP$`"0```!*[`0`B````'+L!``(````_NP$`$@```$*[
M`0`8````5;L!``L```!NNP$`!0```'J[`0`,````@+L!``H```"-NP$`#P``
M`)B[`0`6````J+L!``4```"_NP$`#0```,6[`0`G````T[L!``X```#[NP$`
M#P````J\`0`0````&KP!``4````KO`$``@```#&\`0`+````-+P!``$```#C
M````J0$``%L```!0`0``N`(``"$%```W!@``#0,``%`#``#U!0```````#X&
M``#O!0``7```````````````:0,``"`$``!6!0``NP4``$D!```J`0``````
M``````"<`@``I@4```````#W````U@4``'<$````````W`0``,(%``"P````
M%P$``#D$``#;!```-0```!H&``"0````10$``!@!``"*`0``4`4``)4$``"C
M```````````````R`0```````"X"`````````````',!`````````````&,&
M`````````````````````````````#(```!Z!0``4@0`````````````:@$`
M`#P$```G!````````%L!``!Q!0```````"X&``#L!0``808``/<!``!Q`0``
M````````````````#P$``'<"``#``0``:P,``````````````````"X%````
M````:P0``"X```#V!```4P,``(\```!K!0`````````````D`P``%@(`````
M``"1````0P$``%4!``#Z`0``````````````````40(``(T%``"E`P``````
M`/$```!M`@``608``'\"````````6@,``(@#```V!@``S`$`````````````
MBP(````````G````B`$``!H#``"@`@``2P$``'````!R!```;P$```````"V
M`P```````"@!``#Z!0``&0$``*P!````````6`,``%D#``!:!0``U@0``#4%
M```.````<`0``$P"````````*P$```4%``##`@``2@8``#,#``!'````VP$`
M`%H!``#[!```3@```.8```!F!@````$```````#7`@``P@,``"8%``!C`@``
M:00``(@%`````````````/4"``#\!```PP,``!H"````````>@0``!8%```;
M````7P0``"P```"%!0``R00``,\!```R!@``F`8``-`"````````OP``````
M````````*0(```````!Y`@``HP0```````!Q`````````+\"``"7````````
M`#H```!Z!@``9````)<%````````F`4````````$!```FP4``"\````&`P``
M`````(H```#@!0``R````$T``````````````"$"``"^!`````````````""
M`0``GP$```````"^````#P(``,0"````````#@(``)8&```!!````@8`````
M``!<`@``1`8```````!4`P``!0```"4!```[`0```````&@#``#7!0``````
M`#X`````````30$``&4#````````R`4```````"H`P```````+<$```+!```
M````````````````3P0``(0"``!+`P```````#X!````````700``'`!``"Q
M!````````'P!```U`P```````/L"``#P`@``]P0``,@"``"=`````08`````
M```H`P``N0```,0%``#/`@``[@$``-X!```M`P``P`4``&\`````````JP0`
M`%(&``#$!```&0```#@%````````P`,``"`"```U`@```````$<"``!Q!```
M`````)T#```-!0``1@0``%H$``"I!`````````4#``"B`@``8P,``'T"``!E
M!```=P,```````!X`P``%`,``,H"``"R!```?`8``"8!``#:`@``*`4``+H%
M``!<!`````````````#!````G@```&4!````````Z@(``$$&``"[`@``````
M`+L!``!4`````P0``,X!````````)P(``$<%``#I!````````-P!````````
M``````````!.`@```````/0```!`!````````#8!``!V`@``?08```````#&
M`0`````````````8!```6P4``)<!``#2`0``>``````````<````.P,``.$!
M``"=!```,`4``````````````````.@"``!#!@````````4$````````9`8`
M`-@!````````C@,````````5`P````````````!U!```?0```&L"``"A!```
MP@```!`&``"%!```B@0```````"(!@``/P$```````!9`0```````(`"``#@
M`0``A0$``/8!```#`@``=`,``*X%``"L`P``YP$``-8````,`@``V00``$,`
M````````B0,``$T#``#,`@``@`,```($```5!0``)04``)$$````````````
M`)8"``#7`P``JP(``-P%``"4!@``8````*0"``#`!```0P,``*H$````````
M%P,````````0`0``JP,``'D````)````F@4`````````````@``````````G
M!0``/04``%L"``"A!0``L`$``$0````K````.@(``%<"``!E!0``\00``+\%
M``!J!0``Q0```&X#```+`@``1@8````````.!```.@0``.<`````````]0,`
M`(P#````````!`$````````!`@``-P4```````"I````6`8``!(%````````
M+08``&(%````````:@```-0```#[!0```````(4#```9!@``"`,`````````
M``````````````")!@``TP$``!0```#0!`````````````!_!0``:@0``/<#
M``#[`P```````(<$``#,!0``$0$``#X%````````?P$````````L`@``(08`
M`!,```#N!```4@4``*X$``":`@``M`$``"\&````````W04``"(````L`P``
M7`,``$X$````````Q`,``!P$````````)@```-<$````````C`8```````"]
M````D@0``$L"```N`P```````/8#``!_`P``A`4``*`%``!K!@``X`,``'X#
M```9`P```````/0"``#F!0``RP(```````!3`@````````<%``""!```(0,`
M`!<%```I!@``5`8```````"G`````````.D"``"W`0``D0(``)$%````````
MV@```&$````4!@````8``&H"```.`0``TP(``.(```#]!```3````.$````P
M`@```````)T"````````X0(``'`&```E`@``VP```#4$``".!@``$0,``+<%
M``![````L`0```````#[`0``Y`0``,4"``!4`@```````)L!``!\`@``ZP(`
M``````#H`P`````````````,!@```````````````````````+0%```A!```
M``````````!+`````````/@$```.`P`````````````Y!0``H@,``!<$``#.
M!0``[`0``-T```#(`0```````-4$```R!0``C0```%8$``"``0``R`0``($!
M``!.`0``;@$``/@!``"?!0``'P,```````"$````7P```'0!``!-!```,08`
M`.H$````````(@4``/,$````````!P,``'T#``#*`P``LP0```````!8`@``
MLP```,T!``!F!```-@(```<"``!S!@``]@4``-`#``!2`P````````````"$
M!````````%D```!?!@```````&`%``````````````````#[````.`$``!\&
M```[!@``104``,<%``"A`0``"P8``*(!```S`@``&P4```````"J````.08`
M`/`#```F`P``XP(`````````````G`4``,8#``#4`P``@@4``!,#``#Q`0``
M0`4``,H%``"7!````````"P!``!-`@``-0$``$L&```Q`@````````````"F
M!```\0(``&H#``#9`@``?`4``*X```";!```L@4````````>!```?`,``*($
M``"-!````````)P!````````<P(``.T#``!``````````#`#``#9!0``F0,`
M``````!/````A@(```P````]!@``,P$```````!,!```G04``,H```!N!```
M<@$``-0"``![`0``!`,``&`"``!(!```U@,``,P$```O`0```````.P`````
M````1`4``&@&``"5!@``P@0``/`$```M`0``WP4```````!L!````````#P#
M````````,P4``.8$``#>````WP(``%$%``!"!```F`````````#J`P``*@(`
M`/0!````````?04``&8"``">!0``*`(``*0%````````1`(``(P!``"$`0``
M7@(``+P$```4`@``!`8``'T$``!P`@``[@4``)8$``"'`@```````/(%````
M`````````"P$````````*@8``#T$``!@!```<@4``!H```#^`P``Y@$`````
M````````````````````````500````````2!```;`$``(8&```:!0``````
M`-4%``"^!0````````````!$!```-@0``(L```"?````Q`$````````)!@``
M%P````H%````````W@,``%`"```W`@``JP$``-$$``#]`@``PP0```H&``!G
M!@``/0$``!L&````````.P0``````````````````+4!```0`@````````(`
M``!A!````````/\$``#)!0```````(\"``!M!@``0@8``*4$``")``````,`
M`(X!`````````````/,```"3!```D@4``&("`````````````&8%```C!@``
M_P````````"T`@``-@```#D!``".!````````$<$````````````````````
M`````````+H$``#>`@``C@````````#5`0``10,```<``````````````(T#
M```=`0``(`,``"T```"0`P```````,L#``!_````/P8``+8$``!@`0``F@,`
M`'H#``"&!0``AP```(@`````````M0,``)`$``!@!@```````#H!````````
M`````)`"``!)`P``DP8``!$%`````````````'8```">`@``E````&0!``#Z
M````U`0```L#```#````P@(``)`%``"X`0``#`,``$H`````````?@(`````
M````````:`0``'0`````````>P(``"4$````````6P8``.$#```=!@``````
M`%T&```5!@``=`0``-($``#!`0``%@8``&X%``#L`P``GP,``-D!````````
M9`(``&4````Q`P``'@$``)D!``#N`@``\@(````````[!0```````*D#``!^
M!@``.P(``$L%``#H!````````%,&````````9P0```@!``!/`P``?@0``*\"
M````````5P$``#X#```-`@```````,\%``!F`0``,04```````#^`@``8@0`
M`&4&````````50````````#?!```-````$$```!1`P````````````!T`@``
M1P,``.H```"-`0``^`,````````0!0``````````````````T0```#<!```D
M!0``D`$``-4```!Q`P``:08``-,$```5!````````*\%``!"!0```````.L!
M```8!0``OP$``)D&````````?P8``)4%``#K``````````(!```?!```YP0`
M`'4!``"H!`````````````!D!```!0$``!T"````````=0,``+(`````````
M@0(```````!3````[P$``$0!``"#`@``=08``$@"``"O!```S@,``"`!````
M`````````+T$``#Y!````````"0"``#X!0```````.,%``!C`0``BP4``.X`
M``#J`0``OP0``"D%```2`@``!08``+<#````````C08``&P&``"9!0``B@(`
M``P%````````_0,```````"Q````:`4```````"\````R`,`````````````
MN04```````#=`@``L04``,L$````````*P0``&<%``#!!```(P4```````!N
M````%P(`````````````6@```.D`````````\@```+(!``!``0``'00`````
M````````A@,``.`````[````J`(``,````#$`````````#D`````````$P4`
M`*`#```>!0``^```````````````H`0```````!>`0``+@0``,D#```Q`0``
M8@```#\%```2````8@8```````#6`@``3`8``.`$``!=`P```````!$````\
M````2@0``-,#````````IP4`````````````=P4``.$%````````>08``#D"
M````````70```&T%````````;0```-8!````````U`$``.4$````````````
M```````'`0```````.4```!7!0``A0`````````J`P``5P````````#^!0``
ME0(``/D#`````````````%$&```@!0``Z````+P"``"D`0``M04```H```">
M!```T`$```````"L`@```````+L#``#T`P``-P,`````````````6P,``.<"
M``#;`P``9`,``"D#```T!0``X@(``+4$``#\`0``(````#($``"X!0``]@``
M`*P```"/`0``<`4````````/!0`````````````9!0``$P(```````!0````
MIP(```````!=!0````````````#!`@``>P0``.\"````````HP$``!D$``#S
M`0````4``'4```"3````O`$```````"2`P``-`0``(0&````````&P$``,H$
M``##`0``(P````````"I!0``4@$```````!*!0``$00``)0%``!U!0``````
M``````!0!```*P8``"4&``"#`P``OP,```T$``"C!0```````)(&````````
MY`(``*8!``"M!````````'@&``"T!```E`(```,%```-````00(``#0&````
M`````````"0```!E`@``F@8```````!I!0``C@4``(("```?`@``$P8`````
M``#*`0``````````````````@`8``'4"``!7!@``KP,``,T%``!Z`0``=@4`
M``````!I`@``@@,``(,`````````H0,```````"O`````````+P%``#%`P``
M`````/\%``"7!@``"@(```````!%`@```````+X#``!N!@``Y0(```8%````
M````D@$``.H%```P!```"P```)@"````````\````(L#``!&`P``B@4`````
M``"]!0``7`8``(0#```#`P``V0,``$`"```(`````````)@#````````K0(`
M``0"``"\`P``````````````````9P`````````I`0``:`$``,P#````````
M,0```-T!``!,!0``'@````````!M`P``D@```%4&```X````&`(``%<$```)
M`@``<@(````````````````````````O!```J@4``.L%``",`@``````````
M``!-!0``400``#<````;`P``208````````K`P``3P4``!L"``"M`P``0P(`
M`&\$``!=`0``=@8``+H"``!V`P```0$``'P$``````````````````#>!```
M``````````!R!@``%0``````````````L0,``!,!````````"`4`````````
M`````````)8%``"1!@``FP(``,<"``#.`@``*@4``-,%````````Z`4``$8!
M``!X`@``M````,L!``#7`0``QP```+,#``!?`@``9P(``/\"``!J!@``CP0`
M`"H$``")!0``8`,```````"V`````````*0#``#S`P``*@```+4````@!@``
M)0````L!```D!@``7@4``%X&````````N@,````````K`@``_0$``!L$``#%
M`0```````*<$``!X!0``B@,````````Z!0``#P8``(\&``"T`P``````````
M```_!````````$4$````````%@$``'X`````````P`(``.0%``"?!```<P4`
M`.\```"`!0``9P$``"(!``",!0``20````````"!!```=@$``+T!``#&!```
M`````*@````#`0``H0`````````5`0```````#,&````````"`(````````\
M`0``````````````````H0(``)\"```M!0``P@$``&$!````````DP$``+X"
M``!Y!0``````````````````!@```',$```:`0```````.,#````````(@,`
M`'L#``"Q`0``$@8`````````````<@```&$%``",````_`(``*8````?!0``
MV`4`````````````$0(`````````````E0```!P#``#)`0``#P```$D$``!/
M!@``.`,``&(!``"%`@``0@,``&P#``"+`0``,P```'0%``!>`P``/P```#H&
M````````^@(``+@#``!+!```5@,``,T```!1`0``0`,```````!\````=@0`
M`-P#``````````````D$``"P`P``Z04``,L``````````````*(`````````
M+P4``*4!`````````````)@$``#0!0``<P,``,<!```4!0``L`4``+D!``#B
M!````````&X"``!"`@````````````#2````,@(``.T%```X`@``204``$@!
M``!!`0``2````)H```!7`P``%0(``%\!``#&!0``K@,``),#````````LP$`
M`'D!`````````@,``-P"``"M````Y0$``&(#```*`P``#@4``*````#\!0``
M`````+8"``#?````-@4`````````````80,``!`#``#M`0``(0$```````#0
M````@P$``+<"```=!0```````)$!``"9!```)`$``%P%``!(`P``4@(``-4#
M````````T@(`````````````-08``*D"````````5`0``&\#````````)`0`
M`.T$````````S@```$4&``!"````_@$``*8#````````D0,``.<#``!6!@``
ME`,``-$!```8`````````%P!```7!@``)P,```D#``"8`0``WP,```P$````
M````E`$``$(!````````1P$````````W!```V@$``!\!``!#!```(P$``+4"
M````````8P0``.,!``!/`@```@4``,T#````````_P,```````#4!0``B0$`
M`!T#``#F`@``V`,``%@%``"9````000``*L%````````N0(``$X#``!!!0``
MO0,``$\!``":`0``2`8``*P%``!G`P````````````#Y`@``IP$````````(
M!```E0,``!\`````````B00``/P``````````````)8```!A`@``\0,``/T`
M``!#!0``>0,``&L!```<!@``P04``-$%````````!P8``)D"``",!```CP,`
M``````"3`@``=P```(,&``!Z`@``60(``#`````Z`P``@0```+L```![!@``
M_@0``#\#````````40```/(!``#:!```/0```#,$``!P`P``^`(`````````
M````B`0``&D```!?!0``MP```%@$````````FP,```````"2`@``5@```'L%
M``!;!````````+@$```A````Y`$`````````````<08```@&``!=`@``6```
M`/,"```'!```I04``,\```!(!0``V`(````````4`0``I`````````">`P``
M<0(```D%``#K!```9@```*4````"`@``K0$```````!O!@```````#P&``"(
M`@``4`8``(,$````````'`4``,T"``#\`P``TP````````#?`0```````,8`
M``"Y`P````````````"6`0``,`$``$H"``!C!0``!@$``(8```!4`0``E`0`
M``````!'!@``JP```"P&```<`0```````&P````-!@``T@4``"(&````````
MZ0$``.L#```$!0``;P4``%(```#B`0``X@,``````````````````'\$````
M````;0$```````!^`0``9`4``*8"`````````````/`!````````Q@(``.(%
M```&!````````$8"````````0`8``+,"``!T!@``SP0````````]`@``5`4`
M`"P%``!3!```EP,````````C`P``(@0``"8&``#+!0``FP````````"H`0``
M\`4``"<&``#N`P``504``)T!````````G````.0#```>!@``+@$``$T&``"'
M!@``N@$``+8!````````]0$````"```6`P``````````````````J@,``+$"
M```G`0``AP$`````````````]0```````````````````*H"````````$@$`
M`#0"`````````````!@#``#8`````````&T$``!*`P``=P$``+8%```H!@``
M[0```#@&```>`@``#0$``.4%``#<````3@4```$#````````-@,``,,`````
M`````````),%```B`@``+0(```````!X!````````)H$````````B@8```X&
M```$````!@(``,D`````````"P4``'@!``!8`0``7P,``+("``"6`P``````
M``````#H`0``"0$``-D```#R`P``[P,``#`&``!3`0```````/\!``#Z!```
M```````````M!```Y0,``````````````````+T"```3!```;`4``!8`````
M````_@```,<$````````&@0``#D#`````````````)P$````````^0$``-(#
M``#%!```"@$``.<%``">`0```````"@$``"'!0``I0(``+X!```O`@``````
M```````>`P``]P4``(8$````````[`(````````T`0``?@4```````"D!```
M```````$````````C0(``&@"``!>````<@,``-L%```0!```50(``!$&```/
M`P``W00``(,%``!:`@``Y@,``&P"```R`P``)@0``*,"`````````````*\!
M````````XP0``","``#:!0`````````````%`@``A08``/D%``##!0``````
M`#X$``#5`@``BP8``+L$``#)`@```````($%``#Q!0```````#$$```K!0``
M6@8``+`"`````````````````````````````/<"``#]!0````````````!>
M!```5@$``"D`````````@@```$X&```&!@``]00``&L```#1`@``1@4```,&
M``".`@``&0(``#\"````````:0$``)P#```6!````````#@$``"G`P``J`4`
M```````8!@````````````"!`P``S````$H!``!$`P````````````"`!```
M'`(``$P!``!S`````````)4!``")`@````````````#1`P```````*H!``!W
M!@``604``,X$``#@`@``V@,``*P$````````H`$``((&```*!```V`0```\$
M````````\@0``!T```"X`````````'T!`````````````$$#``#T!0``````
M`(L$```T`P``9@,``.\$```2`P``N00```````!6`@``EP(``*T%````````
M``````````!5`P```````(\%``"&`0``600``($&```E`P``P0,``"D$``!%
M````\P4`````````````]@(``/0$``!H````SP,``-T#``#7````4P4`````
M``#I`P```````,<#``#;`@```````#P%````````;P(``/H#```]`P``/`(`
M`"8"``"S!0```````.$$``!Y!```AP,``'H````4!```/@(``*(%```,`0``
M`````-X%``!)`@``L@,````````H````S00``!````"Z````D`8````````C
M!```^0```&,```#%!0``+P,``.P!`````````````*X!``#M`@``K@(``.0`
M``!,`P``1@```*,#```!!0```"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y
M("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S
M=&5R9&%Y*0`@870@`"5D("5S(&%N9"`E<P`E9"UD87D@9F]R96-A<W0`)7,@
M+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P
M`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@
M870@)7,@)7,`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U
M;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L
M96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"P@9W5S
M=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T
M("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`$$@
M9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`
M02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I
M<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0
M(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`
M02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)
M344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-
M24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%
M(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T@4F%I
M;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O
M=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!
M8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D
M96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@4&%S<W=O<F0`06-C
M;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!
M9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!
M9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`
M061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A
M($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@
M;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P
M97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S
M`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG
M;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S
M`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L
M92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP
M93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N
M871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT
M97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E
M<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W
M87,@<W!E8VEF:65D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO
M=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D
M80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES
M(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI
M;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E
M($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT
M('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)G96YT
M:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S
M8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`
M07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O(&1E
M;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@
M82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@
M;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO
M;BUE>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA
M`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E
M(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I
M;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&
M5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@
M+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B
M-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%)E<75I<F5D($Q$
M05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@
M861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!
M=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z
M(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VUC86PZ(%)E<75I<F5D
M($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U
M:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T
M:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I
M8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T
M:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!
M>F5R8F%I:F%N`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@
M0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E
M<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"
M86YG;&%D97-H`$)A<F)A9&]S`$)A<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"
M96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0FQO8VL@(B5S
M(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN
M9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!"
M;W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I
M;F$`0F]T:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`
M0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A
M;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N
M9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P
M97)T:65S+BXN`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N
M(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO
M=7(@861M:6YI<W1R871O<BX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E
M<CH@)7,`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N
M;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y
M(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL
M92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#
M86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D
M97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O
M97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S
M86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#
M871E9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N
M90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I
M97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ
M-"D`0V5N=&5R`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U
M<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I
M9FEC871E(%!O;&EC:65S`$-H860`0VAA;F=E`$-H86YG92!T:&4@;F%M92!A
M;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD
M(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%R`$-H96-?:R!,:6YK+BXN`$-H
M:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E
M(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@
M82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S
M92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:')I<W1M
M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#
M;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(&]U="!U<V5R.B`E<P!#
M;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&EC:R!T;R!#;VYT:6YU90!#
M;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO=61Y
M`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L
M;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O
M;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M
M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O
M<P!#;VUP86YY`$-O;7!U=&5R<P!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@
M1&EF9F5R96YC97,`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N
M9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN
M96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N
M(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@
M<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H
M)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S
M('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!S96QE
M8W1I;VX`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@
M96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`
M0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3
M+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S
M`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE
M8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO
M="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A
M8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S
M`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A
M9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K
M+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N
M`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB
M=71I;VX@;&ES=',N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M
M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@
M;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@<F5A
M9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E
M<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@
M;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R
M971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@
M)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L
M9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO
M="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N
M9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T
M:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S
M`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A
M=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C
M;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E
M<G9E<BX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@
M=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9&XG="!F:6YD('1H
M92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O
M<&5N+@!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A
M=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S
M`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T
M:6$`0W5B80!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!7
M96%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T
M;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@
M<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H
M5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE
M8V@@4F5P=6)L:6,`1$0`1&%I;'D`1&%T851R964@0G)O=W-E<@!$871E`$1A
M=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN
M`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F
M875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F:6YI=&EO
M;G,`1&5L971E`$1E;&5T92!'<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE
M=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU
M;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@
M<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E
M;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L:79E<GD@=&EM
M90!$96YM87)K`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E
M=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E
M(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE
M;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O
M:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT
M('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES
M<&QA>2!/<'1I;VYS`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F
M;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(&YO
M="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP
M:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S
M/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@
M4F5P=6)L:6,`1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI
M<W0`1')U9W,`12U-86EL`$524@!%8W5A9&]R`$5D:70`161I="!";&]C:P!%
M9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D
M:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@
M<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O
M<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D
M<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M
M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E
M87)C:"!T97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H
M;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N
M=&5X="!M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E
M8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO
M=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@
M=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H
M97)E`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@=VET
M:"!E;6%I;"!M97-S86=E+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O
M<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@
M<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L
M9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%
M>'!A;F0`17AP86YD(%-I9&5B87(`17AP96-T960@)RDG`$5X<&5C=&5D(&)A
M<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E
M`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D
M(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O
M($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R
M+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O
M("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`
M1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I<@!&86QK;&%N9"!)<VQA;F1S
M("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X`$9E
M8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9E
M=R!3;F]W(%-H;W=E<G,`1FEE;&0@;6%T<FEX`$9I:FD`1FEL92!#;W5N=#H@
M)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL
M92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D
M<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&
M:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O9P!&;VQD97(@
M)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R
M<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O
M<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@
M<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE
M<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@
M<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S
M`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE<P!&<F%N8V4`
M1G)A;F-E+"!-971R;W!O;&ET86X`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L
M>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]M`$9R;VT@
M=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1V%B
M;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA
M`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5O
M<F=I80!'97)M86YY`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=O`$=O
M961E;`!';V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E3
M3RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T
M:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P<P!'=6%D
M96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I
M;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-
M3`!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D
M96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A
M<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N
M`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L
M9V]R:71H;0!(87IE`$AE861E<@!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD
M($ES;&%N9',`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE
M;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE
M(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY(%-E92`H
M5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE(%!H
M;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@26YV
M86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO
M<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E
M<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@
M;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@
M)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R
M97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA
M8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E
M<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(
M;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H
M92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC
M:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y
M;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA
M<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO
M<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R
M="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_
M`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N
M>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI
M9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A=&EO
M;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S
M`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D
M9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO
M="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L
M871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`
M26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z
M`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N
M(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O
M;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C
M:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)
M9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G
M92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO
M=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%52
M3#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA
M9V4@=7!L;V%D`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP;W)T960@9FEE
M;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@069T97(`26YC
M;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@
M86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N
M871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN
M9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I80!);F9O`$EN
M9F]R;6%T:6]N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!)
M;G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E
M9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N
M90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`
M26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T
M(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A
M<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G
M<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E
M('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO
M=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A
M9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!)
M;G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS97)T('!A
M<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@
M<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER
M960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO
M9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R
M961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F
M:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!5
M1$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!A<'!L:6-A=&EO;BX`
M26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV
M86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T
M`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N
M`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N
M="!P97)M:7-S:6]N+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED('-H87)E
M(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O
M9&4@9&%T82X`26YV96YT;W)Y`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`
M27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M4W1O<FUS`$ES
M<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A
M;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*
M=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I
M9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA
M;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T
M:6]N+@!+97)N96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R
M:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y
M(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T
M:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9@!+;W)E
M82P@4F5P=6)L:6,@;V8`2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS
M=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@
M4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z
M`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L
M;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R
M(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU
M97,`3&5S;W1H;P!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE
M8VAT96YS=&5I;@!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I
M;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG
M:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H
M;W=E<@!,:6UE<FEC:P!,:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E
M;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y
M:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H
M92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T
M(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/
M=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB
M90!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU
M86YI80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`
M3&]C871I;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X@5&%S:W,`3&]G:6X@9F%I
M;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT
M97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V
M90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S
M`$QO=V5R(')O;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.
M148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA
M8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A
M9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA
M;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@
M;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I
M=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I
M97,N`$UA<#(T(&UA<`!-87!1=65S="!M87``36%R8V@`36%R9VEN`$UA<FL@
M=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@
M*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA
M<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S
M`$UA>"!A;&QO=V5D(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D
M960N`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@
M:&]U<G,Z(`!-87AI;75M(&QE;F=T:`!-87D`36%Y;W1T90!-961I8VEN90!-
M96UB97)S`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G90!-97-S86=E
M(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I
M9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D
M+@!-97-S86=E('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@
M879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS
M(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971H
M;V0`365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S
M(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@
M`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI<G)O<@!-:7-C96QL86YE;W5S
M`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C
M;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@
M>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S
M<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`
M36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-
M;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D=6QU<P!-;VQD;W9A+"!297!U
M8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE87(`36]N=&AL
M>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F]C8V\`36]S=&QY($-L96%R
M`$UO<W1L>2!#;&]U9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W;@!-;W9E($QE
M9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M
M8FEQ=64`375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I<&QE('-E
M;&5C=&EO;@!->2!!8V-O=6YT`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T
M`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F%M:6)I80!.875R
M=0!.97!A;`!.971H97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S
M8V%P92!"87-E(%523`!.971S8V%P92!#02!2979O8V%T:6]N(%523`!.971S
M8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C
M87!E(%)E=F]C871I;VX@55),`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.
M971S8V%P92!C97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC
M871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!#871E
M9V]R>0!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A
M;&%N9`!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT
M`$YE>'0@;W!T:6]N<P!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.
M:75E`$YO`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO
M=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@
M;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C
M:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A
M<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C
M:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI
M<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@
M;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D
M960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;65S
M<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S
M<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.
M;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P
M96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q
M,B!D871A+@!.;R!P96YD:6YG('-I9VYU<',N`$YO(')U;&5S`$YO('-I9&5S
M`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`
M3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-
M3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN
M(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A
M=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN
M(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@:6UP
M;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD`$YO
M<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO
M<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T
M(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&5S`$YO
M=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W9E;6)E<@!.=6UB97(`3G5M
M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F
M(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D
M:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]C
M=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]M86X`3VYL>2!)
M34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O9F9E
M;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D
M+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@
M8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S
M:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L
M9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/
M<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T
M96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI
M<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA
M;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@
M)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS
M`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!01U`@1&EG
M:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@
M2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H
M96QL`%!-($QI9VAT(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@
M4VAO=V5R<P!032!4+5-T;W)M<P!07TA0(%-H96QL`%!A9&1I;F<`4&%K:7-T
M86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!086YA
M;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@0VQO=61Y`%!A
M<W-W;W)D`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F
M;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I
M<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M
M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG
M(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@
M;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`
M4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H
M;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E<P!0;&5A<V4@
M8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@
M=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T
M:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E
M;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@
M9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0
M(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H
M92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A
M('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@
M<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S
M<W=O<F0`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA
M;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI
M<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI
M<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N
M(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5F<U]L9&%P.B!297%U:7)E9"!,
M1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I
M<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E
M<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I
M97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O<'1I;VYS
M`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$
M97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U
M8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T
M(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%%A=&%R`%%U
M97)Y`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!2
M86EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD
M(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`
M4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO
M;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F
M;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`
M4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:"!$>6YA;6EC($UE;G4@
M16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N
M<VAI<"!"<F]W<V5R`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%52
M3"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO
M=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO
M=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M
M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E
M(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E
M<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O
M<F-O9&4Z(`!297%U:7)E9"!&:65L9`!297-E=`!297-E="!087-S=V]R9`!2
M97-E="!9;W5R(%!A<W-W;W)D`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`
M4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R
M($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L
M=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X
M,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W
M('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)
M344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-
M97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`
M4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U-(`%-50T-%4U,`4U]13"!3:&5L
M;`!380!386EN="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT
M($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N
M="!A;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A
M`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0
M<F]V:61E<@!3875D:2!!<F%B:6$`4V%V90!3879E("5S`%-A=F4@3W!T:6]N
M<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP
M="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D
M("5S(&-O;F9I9W5R871I;VXN`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I
M;F5S`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P
M('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E
M;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S
M+@!396QE8W0@86X@;V)J96-T`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@
M;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@
M86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE
M(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE
M8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H
M92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L
M96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C
M:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R
M;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M
M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E<W-I
M;VX@240@97AP:7)E9"X`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T
M;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`
M4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S
M(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G
M92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U
M<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L
M(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A
M9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB
M;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&]P<&EN9P!3
M:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O
M<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C
M=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG
M=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN
M/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H
M;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N
M=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S
M(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W
M('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA
M9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W
M97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET
M>0!3:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I
M(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I
M9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K
M:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H
M;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO
M=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T
M97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O
M<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC
M80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A
M;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P
M:&5R90!3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E
M96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`
M4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C
M=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3
M<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R="!Y96%R
M`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E
M970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O
M;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8FIE8W0`
M4W5B;6ET`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!R979E<G1E
M9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E
M<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U
M;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3
M=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3
M=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@
M`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE
M`%-U<FYA;64`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E
M9&5N`%-W:71Z97)L86YD`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`
M4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M<P!44U8@9FEL
M90!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%I
M=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ
M86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H
M;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!4
M96UP97)A='5R93H@`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X
M="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4
M:&%I;&%N9`!4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92!&
M5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(;W)D92]+;VQA
M8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H
M92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L
M;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H
M92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N
M="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M
M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@240@
M;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N
M;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T
M86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I
M9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@
M240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO
M="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES
M="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@
M<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@
M<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U
M;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C86X@;F]T
M(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO
M(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES
M(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E
M(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP
M;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B
M;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A
M9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R
M86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN
M9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='
M96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<
M;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@
M>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N
M`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T
M+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN
M87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4
M:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B)7,B
M(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@=&AA
M="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N`%1H
M92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G
M90!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D
M95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O
M=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H
M92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@
M=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE
M('-Y<W1E;2X`5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I
M9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D
M96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S
M:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P
M96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP;W)A<GD@9FEL
M92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED
M97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W
M87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D
M(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO
M8VL@:7,@;F]T(&%V86EL86)L92X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A
M:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA
M>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@
M=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y
M;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE
M("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@
M*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`
M5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A
M<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D
M871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD
M87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T
M:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE
M;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I
M960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA
M=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@
M9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E
M('1R>2!A9V%I;B!L871E<BX`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S
M=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E
M87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M
M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@
M*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI
M(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO
M=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6
M;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E
M<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N
M92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E
M<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N
M`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@
M8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU
M97,N`%1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R
M871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A
M;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C
M;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T
M868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H
M:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4
M;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI
M96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M
M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V
M:7-I="`E<P!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T
M97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@
M;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M
M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R
M96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E
M<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS
M('=I;F1O=P!4:'5N9&5R`%1I8VME=',`5&EM90!4:6UE(%1R86-K:6YG`%1I
M;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I
M=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H
M;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME
M>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O
M9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4;W``5&]P(&9R86UE("A?=&]P
M*0!4<F%N<VQA=&EO;G,`5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A
M;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U
M<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y
M<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%523"!F;W(@>6]U
M<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G86YD80!5
M:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE
M('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U
M<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE
M("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8V]N
M;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-3
M3"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@
M5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E
M8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C
M<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A
M=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N
M;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@
M:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R
M96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I
M;&4N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA
M8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O
M(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T
M:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N
M`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@
M=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA
M;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T
M<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R
M96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O(')U;B`G;6MI
M<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT
M`%5N86)L92!T;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@9&%T82X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@
M>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R
M=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@
M<V5R=F5R('1O.B``56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=&5D($%R
M86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FET
M960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK;F]W
M;@!5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N:VYO=VX@
M8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W;B!U<V5R;F%M
M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN
M86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#
M;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N
M<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL
M;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@
M=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R
M=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!U<V5R`%5P
M9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P
M;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T
M:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U
M<G)E;G0Z("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF
M9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E<B`E<R!I<R!N;W0@875T:&]R
M:7-E9"!F;W(@)7,N`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS
M`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N
M(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S97)N86UE`%5S97)N86UE.@!5
M<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93
M(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C
M871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU
M=&5S(&9R;VT@;F]W+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A
M;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@
M+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!6
M97)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A
M;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA
M;65S92`H5DE30TE)*0!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A
M9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@
M27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N
M92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE0
M5"!-04Y504Q,62!&4D]-("5S+@!786QL:7,@86YD($9U='5N80!787)N:6YG
M`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y
M`%=E871H97(N8V]M`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M90!796QC
M;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E
M<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI
M8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES
M('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C
M:&%R86-T97(_`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L
M92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN($-3
M4R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K
M97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE
M`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@
M<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7;W)K`%=O<FL@
M061D<F5S<P!7;W)K(%!H;VYE`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A
M:6YT<P!8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T
M($%L=&5R;F%T:79E($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I
M97(`6#4P.78S(&5X=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE87)L
M>0!996UE;@!997,`665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%
M+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)
M5UE'+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N(&YO="!H
M879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@
M9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N
M)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T
M:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E96X@
M;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO
M;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F
M;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A
M($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O
M;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@
M<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R
M="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I
M;G1S('1O`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E
M9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`
M66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@
M=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C
M871E9V]R>2!N86UE+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L
M96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O
M;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D
M9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R
M("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T
M:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R
M96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S
M:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O
M=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U
M<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R
M(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO
M=7(@9G5L;"!N86UE.@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S
M`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T
M:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U
M<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S
M<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO
M9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R(')E;6]T92!S97)V
M97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W90!::7!P>0!;
M2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T
M960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=`%ML:6YE
M("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T-,20!?1&%T851R964`7T1E
M;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA9V4@4')O<&5R=&EE<RXN+@!?
M3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN+@!?3W!T:6]N<P!?4&5R
M;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]3971U<`!?5&%B;&4@4')O<&5R
M=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`&-A;&5N9&%R`&-A;&T`8VQI
M8VL@:&5R90!F86QL:6YG`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E
M<P!H.@!I;6UE9&EA=&4`:6YL:6YE`&QI;F5S70!M:VES;V9S(&5R<F]R(&-O
M9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;F%M90!N;W0@:6UP;&5M96YT960`
M;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`'!E<F-E;G0`<&EX96QS`')I
M<VEN9P!S:&]W(&1I9F9E<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S=&5A
M9'D`=&%S:R!L:7-T`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I
M<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H
M97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&5V,RXP+C0*4F5P;W)T
M+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T
M:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$
M871E.B`R,#`U+3`V+3(X(#$T.C0X*S`S,#`*3&%S="U4<F%N<VQA=&]R.B!!
M=71O;6%T:6-A;&QY(&=E;F5R871E9`I,86YG=6%G92U496%M.B!I,3AN0&QI
M<W1S+FAO<F1E+F]R9PI-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z
M('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM.0I#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X8FET"E!L=7)A;"U&;W)M<SH@;G!L=7)A;',],3L@
M<&QU<F%L/3`["@`@*"5S(&?\;B#V;F-E*0`H17)I_FEM($%N86AT87+]("5S
M*0`@*"5S(&?\;F1E*0`@*&)U9_QN*0`@*'EA<OUN*0`@*&3\;BD`(&1E*&1A
M*2``)60@)7,@=F4@)7,`)60M9_QN;/QK(&AA=F$@=&%H;6EN:0`E<R`M($)I
M;&1I<FEM`"5S(%!A<FUA:R#=>FD`)7,@2T(`)7,@0F%K_6T@W?YL96UL97)I
M("T@3VYA>6QA;6$`)7,@07EA<FQA<@`E<R!':7)I_@`E<R!!;FQA_FUA($MO
M_G5L;&%R_0`E<R!Z871E;B!V87(N`"5S(&1E("5S("5S`"5S(&ES=&5N;65K
M=&5D:7(N`"5S(&1A:VEK80`E<R!B=6QU;F%M863]+@`E<R`M("5S("\@)7,@
M`"5S($%D<F5S($1E9G1E<FD`)7,@5&%K=FEM`"5S($YO="!$969T97)I`"5S
M($?V<F5V($QI<W1E<VD`)7,Z("5S`"P@9OUR=/UN86S]("5S("5S`"P@9&7P
M:?YI;2`E<R`M/B`E<P`M+2!39><@+2T`,3(@4V%A=&QI:R!:86UA;B!":>=I
M;6D`,C0@4V%A=&QI:R!:86UA;B!":>=I;6D`,C0@<V%A=`!"=2#V8F5K(&GG
M:6X@=F5R:71A8F%N_2!S;VX@=7IA;G3]<_T@9V5R96MM96MT961I<BX`3VYU
M;&UA>B!B:7(@:&%T82!O;'7^='4`W6QE=&EY:2#^:69R96QE>65B:6QM96L@
M:>=I;B!01U`@8>?]:R!A;F%H=&%R_2!G97)E:VUE:W1E9&ER+@#=;7IA;&%N
M;?W^(&EL971I>6D@9&_P<G5L=?!U;G4@<V'P;&%M86L@:>=I;B!01U`@8>?]
M:R!A;F%H=&%R_2!G97)E:VUE:W1E9&ER+@#=;&5T:6YI;B#^:69R97-I;FD@
MY_9Z;65K(&GG:6X@8>?]:R!01U`@86YA:'1A<OTL]GIE;"!01U`@86YA:'1A
M<OT@=F4@9V7G:?X@=/QM8V5C:?!I(&=E<F5K;65K=&5D:7(N`-UL971I>6D@
M:6UZ86QA;6%K(&GG:6X@8>?]:R!01U`@86YA:'1A<OTL]GIE;"!01U`@86YA
M:'1A<OT@=F4@9V7G:?X@=/QM8V5C:?!I(&=E<F5K;65K=&5D:7(N`-UL971I
M;FEN(/YI9G)E<VEN:2#G]GIM96L@:>=I;B!AY_UK(%,O34E-12!A;F%H=&%R
M_2P@]GIE;"!3+TU)344@86YA:'1A<OT@=F4@9V7G:?X@=/QM8V5C:?!I(&=E
M<F5K;65K=&5D:7(N`-UL971I>6D@:6UZ86QA;6%K(&GG:6X@8>?]:R!3+TU)
M344@86YA:'1A<OTL(/9Z96P@4R]-24U%(&%N86AT87+]('9E(&=EYVG^('3\
M;6-E8VGP:2!G97)E:VUE:W1E9&ER+@#=;&5T:7EI(/YI9G)E;&5Y96)I;&UE
M:R!IYVEN(&'G_6L@4TU)344@86YA:'1A<OT@9V5R96MM96MT961I<BX`UM8@
M66'P;75R`-;6(%-A\&YA:P#6UB!(869I9B!+87(`UM8OUE,`05!)($E$`$3\
M>F5N;&5Y:6-I(&AA:VO];F1A`$AA:VO];F1A+BXN+@!%;F%L=`!/<G1A>6$`
M5D93(&1I>FEN:2!Y87)A=/UR:V5N(&5R:?YI;2!E;F=E;&QE;F1I+@!61E,@
M9&EZ:6YI('EA<F%T_6S]<FME;B!E<FG^:6T@96YG96QL96YD:2X`2&5S87`@
M4&%R86QO<_T`2&5S87`@1&]N9'5R=6QD=2X`2&5S87!L86[]>6]R`$5K;&4`
M06QT($=R=7`@14ML90!!;'0@W7II;B!%2VQE`$)U<F%Y82!%:VQE.@!996YI
M($=R=7`@16ML90!996YI(-UZ:6X@16ML90!996YI(&MU;&QA;OUC_2!E:VQE
M.@!+;VQO;B!%:VQE`%EE;FD@_'EE(&5K;&4`W6MI;&D@16ML90`E<R!-96[\
M<_QN_"!-;WII;&QA($ME;F%R(,=U8G7P=2!/;&%R86L@16ML90!!9')E<R!D
M969T97)I;F4@96ML93H`061R97,@9&5F=&5R:6UE(&5K;&4`2W5L;&%N_6/]
M($5K;&4`2W5L;&%N_6/](&5K;&5M92!S9>=I;&5M97H@:_UL_6YD_2X`061R
M97,`061R97,@1&5F=&5R:0!9]FYE=&EM+2U$:?!E<B!K=6QL86[];&%R(&GG
M:6X@:7II;FQE<FD@8F5L:7)L97EI;@!9]FYE=&EM`$%D<P!!9F=A;FES=&%N
M`$%R;F%V=71L=6L`0V5Z87EI<@#6=&5K:2!A9`!(:7IA;&$`2&EZ86QA;6%K
M.@!4_&W\`%3\;2!$;_!R=6QA;FW]_B!+=6QL86[]8_UL87(`5/QM($=R=7!L
M87(`5/QM(-UZ:6YL97(`5/QM(&3V<G0@>?QZ`,=O:VQU(&%D<F5S;&5R92!I
M>FEN('9E<@!3_7)A;&%N;?W^(&QI<W1E('3\<OQN_"!A>6%R;&%M87EA(&EZ
M:6X@=F5R:6QS:6X@;6D_`%IA=&5N('9A<@#6=&5K:2!)35-0($=I<FG^:0#6
M=&5K:2!)35-0(%!A<F]L87/]`-9T96MI($E-4U`@2W5L;&%N_6/]($%D_0#6
M=&5K:2!E;&5K=')O;FEK('!O<W1A(&%D<F5S:0#6=&5K:2!T87-L86ML87(`
MUG1E:VD@;65T:6XZ`$%M97)I:V%N(%-A;6]A`$=EYV5R<VEZ(&1E\&5R(&)E
M;&ER=&EL9&DN`$%N9&]R80!!;F=O;&$`06YG=6EL;&$`06YO;FEM(%!R;WAY
M`$-E=F%P`$%N=&%R=&EK80!!;G1I9W5A('9E($)A<F)U9&$`57EG=6QA;6$`
M57EG=6QA;6$@3&ES=&5S:0!5>6=U;&%M82!(87K]<@!!;'0@<&%Y;&'^_6UL
M87)A('5Y9W5L80!/;F%Y;&$`66%K;&'^_6L@0F]Y=70`3FES86X`07)A<.=A
M("A7:6YD;W=S+3$R-38I`$)E;&=E;&EK($1O<WEA($)U>75T=0!"96QG96QI
M:R!!9/T`)7,@:>=I;B!G:7)I_B!I<W1E\&EN:2!K86QD_7)M86L@:7-T961I
M\&EN>F4@96UI;B!M:7-I;FEZ/P!!<FIA;G1I;@!%<FUE;FES=&%N`$5R;65N
M:6-E("A!4DU30TE)+3@I`%-A;F%T`$%R=6)A`$%S8V5N<VEO;B!!9&%L87+]
M`$%S8VEI(%-A;F%T_0!!<WEA+U!A<VEF:6L@0O9L9V5S:0!"86O];2!I_FQE
M;6QE<FEN9&5N(/9N8V4@9&_P<G5L86UA('-O<G5L<W5N(&UU/P!!=&%M82!+
M;VQO;FQA<OT`5F%R(&]L;6%Y86X@8FER(&=R=6)U('-I;&UE(&=I<FG^:6UI
M+@!687(@;VQM87EA;B!B:7(@:7IN:2!S:6QM92!G:7)I_FEM:2X`5F%R(&]L
M;6%Y86X@8FER(&=R=6)U(&3\>F5N;&5M92!G:7)I_FEM:2X`5F%R(&]L;6%Y
M86X@8FER('!A>6QA_OUM_2!D_'IE;FQE;64@9VER:?YI;6DN`-9Z;FET96QI
M:VQE<@!!\'5S=&]S`$%V=7-T=7)A;'EA`$%V=7-T=7)Y80!!=71H7V-Y<G-Q
M;#H@W7-T96YE;B!I;6%P('5Z871A=/US_2!B=6QU;F%M863]+@!!=71H7V-Y
M<G5S.B#=<W1E;F5N('EE=&5N96ML97)E('-A:&EP(&1E\&EL+@!!=71H7V-Y
M<G5S.B#=<W1E;F5N(&EM87`@=7IA;G3]<_T@8G5L=6YA;6%D_2X`075T:%]F
M='`Z(-US=&5N96X@1E10('5Z86YT_7/](&)U;'5N86UA9/TN(%!(4"=Y:2`M
M+65N86)L92UF='`@<W=I=&-H(&1E\&G^=&ER9V5S:7EL92!D97)L97EI;BX`
M075T:%]I;6%P.B#=<W1E;F5N($E-05`@=7IA;G3]<_T@8G5L=6YA;6%D_2X`
M075T:%]K<F(U.B#=<W1E;F5N(&MR8C4@=7IA;G3]<_T@8G5L=6YA;6%D_2X`
M075T:%]L9&%P.B#=<W1E;F5N($Q$05`@=7IA;G3]<_T@8G5L=6YA;6%D_2X`
M075T:%]I;6%P.B`E<R!K=6QL86[]8_US_2!E:VQE;F5M961I+B!3=6YU8W4Z
M(`!!=71H7VQD87`Z("5S(&MU;&QA;OUC_7/]('-I;&EN96UE9&D`075T:%]L
M9&%P.B`E<R!K=6QL86[]8_US_2!G_&YC96QL96YE;65D:0!!=71H7VUC86PZ
M(-US=&5N96X@34-!3"!U>F%N=/US_2!B=6QU;F%M863]+@!!=71H7W-M8F%U
M=&@Z(-US=&5N96X@<VUB875T:"!U>F%N=/US_2!B=6QU;F%M863]+@!$;_!R
M=6QA;6$@8F'^87+]<_UZ(&]L9'4N`$1O\')U;&%M82!B8?YA<OUS_7H@;VQD
M=2X@)7,`1&_P<G5L86UA(%)!1$E54R!S=6YU8W5S=2!T87)A9OUN9&%N(&=E
M<FD@YV5V<FEL9&DN`$944"!S=6YU8W5S=6YA(&1O\')U;&%M82!B8?YA<OUS
M_7H@;VQD=2X`2W5L;&%N_6S]<B!A;&%N;&%R.@!!>F5R8F%Y8V%N`$)/1D@@
M0>?]:VQA;6%L87+]`$%R=&%L86X`07)T86QA;B!296YG:0!+]G3\(&ME<F)E
M<F]S('!A<F]L87/]+@!+]G3\(&ME<F)E<F]S(&MU;&QA;OUC_2!A9/TN`$)A
M:&%M86QA<@!"86AR97EN`$)A;'3]:R`H25-/+3@X-3DM,3,I`$)A;F=L861E
M_@!"87)B861O<P!486)A;B#G:7IG:7-I`$)E>6%Z(%)U<WEA`$)E;.=I:V$`
M0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$1O\'5M9_QN_`!5>6=U;&%M
M82`B)7,B('-A:&EP(&]L9'7P=2`B)7,B(/9B9?!I(&)U;'5N86UA9/TN`-9B
M96L@07EA<FQA<OT`UF)E:R!4_'+\`$MO>74`0F]L:79Y80!997(@W6UL97)I
M`%/];OUR`%/];OUR($MA;/UN;/WP_3H`4_UN_7)L87(`0F]S;F$@2&5R<V5K
M`$AE<B!):VES:0!";W1S=F%N80!!;'0`0F]U=F5T($%D86QA<OT`0G)E>FEL
M>6$`0G)I=&%N>6$@2&EN="!/:WEA;G5S=2!"]FQG97-I`$)R=6YE:0!"=6QG
M87)I<W1A;@!-861D92#=;6QI($QI<W1E`$)U<FMI;F$@1F%S;P!"=7)U;F1I
M`$--4P!#4E,`0U),($1A\/UT_6T@3F]K=&%L87+]`%](_&-R92#6>F5L;&EK
M;&5R:2XN+@!486MV:6T`1'5R9W5N`$MA;6)OYWEA`$MA;65R=6X`4&%R;VQA
M(/9Z9&5V:6YI;6QI(&]L87)A:R!S_6;]<FQA;F%M86UA:W1A9/UR+"!L_'1F
M96X@>?9N971I8VEN:7IL92!G]G+\_OQN+@!)34%0('-U;G5C=7-U;F$@8F'P
M;&%N_6QA9/TZ("5S`$MA;F%D80#=<'1A;`!3;W)U;B!287!O<G5N=2#=<'1A
M;"!%=``B)7,B(&1O<WEA<_T@<VEL:6YE;65D:2X`1V7G:6-I(&1I>FEN(&)U
M;'5N86UA9/TN`"=T87)G971&:6QE)R!D9?!I_G1I<F=E<VD@;VQM861A;B!D
M979A;2!E9&EL96UE>BX`(B5S(B!D:7II;FD@:V%L9/UR_6QA;6%D_2X`2V%L
M9/UR_6QA;6%D_2`L)60@86QT('EA</T@=F%R+@!996YI9&5N(&3\>F5N;&5M
M961I+"!Y96YI9&5N(&3\>F5N;&5M92!IYVEN('-A\&QA;F%N(&MA>?UT;&%R
M_6X@<V%Y_7/](&EL92!D97!O;&%N;?W^(&]L86YL87+];B!S87G]<_T@9?YL
M9?YM96UE:W1E9&ER+@!"96QI<G1I;&UI_B!N=6UA<F%Y82!I;&5T:2!Y]FYL
M96YD:7)I;&5M961I+@!#87!E(%9E<F1E`$)A_FS]:P!+871E9V]R:6QE<B!V
M92!%=&EK971L97(`0V%Y;6%N($%D86QA<OT`0V5P(%1E;&5F;VYU`$C\8W)E
M(-9Z96QL:6ML97)I`$C\8W)E('EA<W3]:VQA;6%S_3H`2/QC<F4@UGIE;&QI
M:VQE<FD`2/QC<F4@0F_^;'5K;&%R_3H`0V5P(%1E;&5F;VYU`$ME;'1I:R`H
M25-/+3@X-3DM,30I`$]R=&$`3W)T82!!9G)I:V$@0W5M:'5R:7EE=&D`3W)T
M82!!=G)U<&$@*$E33RTX.#4Y+3(I`$]N87D@0F5L9V5S:2!!>7+];G3];&%R
M_0!/;F%Y($)E;&=E<VD@2W5R86QL87+]`,=A9`!$9?!I_G1I<@#=;G-A;FQA
M<OUN('-I>F1E;B!G96QE;B!E;&5K=')O;FEK('!O<W1A;&%R_2!O:W5R:V5N
M('9E(&-E=F%P;&%R:V5N(&?V<F3\:VQE<FD@860@=F4@861R97-I;FEZ:2!D
M9?!I_G1I<FEN+@!+87)A:W1E<@!"8?!L86YT_7G]($1E7VYE=&QE+BXN`-YI
M;&D`QVEN`$)A<VET;&7^=&ER:6QM:?X@QVEN8V4@*$=",C,Q,BD`1V5L96YE
M:W-E;"#':6YC92`H0FEG-2D`4&%R;VQA('-EYVEN`$MU;&QA;OUC_2!A9/T@
M<V7G:6X`5&%R:6AL97)I;B!N87/];"!G]G-T97)I;&5C9?!I;FD@<V7G:6XZ
M`$QI<W1E($)IYV5M(%3\<OQN_"!39>=I;B`H<_UR86QA;FW]_B!L:7-T96QE
M<B!IYVEN*0!#:')I<W1M87,@061A;&%S_0!3_6[]9B!T86[];?T@8G5L=6YA
M;6%D_3HE<P!496UI>FQE`$U33V9F:6-E(&)IYVEM(&EM;&5R:6YI('1E;6EZ
M;&4`2W5L;&%N_6/]>?T@=&5M:7IL93H@)7,`2W5L;&%N_6/]('1E;6EZ;&4`
M2W5L;&%N_6/]('9E<FES:2!T96UI>FQE`$1E=F%M(&5T;65K(&GG:6X@=/UK
M;&%Y_6X`2%144"!Y;VQU>6QA($-L:6-K871E;&P`4&5N8V5R97EI($MA<&%T
M`$)U;'5T;&%R`$)U;'5T;'4`0V]C;W,@061A;&%R_0!+96YA<B#'=6)U\'5N
M=2!$87)A;'0`1&%R86QT_6QM_?X@4_UN_7)L87(`2V]L;VUB:7EA`%)E;FL`
M4F5N:R!39>=I8VD`4F5N:R!39>=I;6D`2V]L;VYL87(Z`$MO;&]N($)A_FS]
M:VQA<OT`2V]M:6L`2V]M=70`2V]M=70@2V%B=?!U`$'G_6ML86UA`$]R=&%K
M($%D_0!#;VUO<F]S`-YI<FME=`!":6QG:7-A>6%R;&%R`$MO_G5L;&%R`%EA
M</UL86YD_7)M82!&87)K;&%R_0!987#];&%N9/UR.B5S`%!A<F%L;WG]($1O
M\')U;&$`2V]N9V\`1&5M;VMR871I:R!+;VYG;R!#=6UH=7)I>65T:0!"8?!L
M86YT_2!B8?YA<OUS_7H@;VQD=2X`0F'P;&%N=/T@8F'^87+]<_UZ(&]L9'4Z
M`$'G_6L@86YA:'1A<B!S=6YU8W5S=6YA(&)A\&QA;G3](')E9&1E9&EL9&DN
M`$'G_6L@86YA:'1A<B!S=6YU8W5S=6YA(&)A\&QA;G3](')E9&1E9&EL9&DN
M(%-E8F5B.B`E<R`H)7,I`$944"!S=6YU8W5N82!B8?!L86YT_2!B8?YA<OUS
M_7H@;VQD=2X`W6QE=&G^:6T@;F]K=&%L87+](&)A_F%R_7EL82!A9')E<R!D
M969T97)I;FEZ92!E:VQE;F1I+@!$979A;0!#;V]K($%D86QA<OT`QV5R97H`
M2V]P>6%L80!39>=I;6D@2V]P>6%L80!+;W-T82!2:6MA`$-O=&4@9"=)=F]I
M<F4`W6QE=&D@4$=0(&EL92#^:69R96QE;F5M961I+@#=;&5T:2!01U`@:6QE
M(&EM>F%L86YA;6%D_2X`W6QE=&D@4R]-24U%(&EL92!S:69R96QE;F5M961I
M+@#=;&5T:2!3+TU)344@:6QE(&EM>F%L86YA;6%D_2X`W6QE=&G^:6T@;F]K
M=&%S_2!E:VQE;F5M961I+B`E<P!,1$%0('-U;G5C=7-U;F$@8F'P;&%N_6QA
M;6%D_2X`0F%K:7EE(&1E;F5T;&5N96UE9&DN("5S`$1A\/UT_6T@;&ES=&5S
M:2!Y87)A=/UL86UA9/TN("5S`%!'4"!V97)I<VEN:6X@_FEF<F5S:2#G]GK\
M;&5M961I+@!3+TU)344@=F5R:7-I;FEN(/YI9G)E<VD@Y_9Z_&QE;65D:2X`
MW6QE=&G^:6T@;F]K=&%S_2!S:6QI;F5M961I+B`E<P!$8?#]=/UM(&QI<W1E
M<VD@<VEL:6YE;65D:2X@)7,`06S]8_UN_6X@96QE:W1R;VYI:R!P;W-T82!A
M9')E<VD@8F5L:7)L96YE;65D:2X`061R97,@9&5F=&5R:2!T86UA;65N(&=E
M=&ER:6QE;65D:2X`1&'P_73];2!L:7-T97-I('1A;6%M96X@9V5T:7)I;&5M
M961I+@!$8?#]=/UM(&QI<W1E;&5R:6YI;B!L:7-T97-I('1A;6%M96X@9V5T
M:7)L96UE9&DN`$%N86AT87(@<W5N=6-U<W5N9&%N(&'G_6L@86YA:'1A<B!E
M9&EN:6QE;65D:2X`)7,@8>?];&%M863]+@!-86EN=&5N86YC95]487-K(&)I
M<FEM:2`E<R!AY_UL86UA9/TN`"5S(&]K=6YA;6%D_2X`W7-T96YE;B!K=6QL
M86YC_2!IYVEN('!A<F]L82!S_6;]<FQA;F%M863]+B!"87K]('EA9&$@=/QM
M(&%Y<OUN=/UL87(@9&_P<G4@9&7P:6PN(%EE;FED96X@9&5N97EI;B!Y861A
M(&1A:&$@9F%Z;&$@>6%R9/UM(&GG:6X@<VES=&5M('GV;F5T:6YI>FQE(&?V
M<OS^_&XN`$%#3"!E<FG^:6QE;65D:2X`061R97,@9&5F=&5R:6YE(&5R:?YI
M;&5M961I+B`E<P!$8?#]=/UM(&QI<W1E<VEN92!E<FG^:6QE;65D:2X@)7,`
M1&'P_73];2!L:7-T96QE<FEN92!E<FG^:6QE;65D:2X@)7,`4W5N=6-U;G5N
M('EE=&5N96ML97)I;F4@97)I_FEL96UE9&DN`%EA</UL86YD_7)M82!G97)I
M(&3V;F3\<OQL96UE9&DN+@`E<R!Y87#];&%N9/UR;6$@:V%Y9&5D:6QE;65D
M:2X`665D96L@8FER('EA</UL86YD_7)M82!K87ED961I;&5M961I+@!9961E
M:R!B:7(@>6%P_6QA;F3]<FUA(&MA>61E9&EL96UE9&DZ("5S`%EE9&5K('EA
M</UL86YD_7)M82!D;W-Y87/]("5S(&MA>61E9&EL96UE9&DN`%EA</UL86YD
M_7)M82!D;W-Y87/]("5S(&MA>61E9&EL96UE9&DN($)U(&1U<G5M9&$L(&MO
M9'4@=&5K<F%R("5S(&GG:6YE(&MA>61E=&UE:R!Y861A('1A:VEP(&5D96X@
M:V]D=2!E;"!I;&4@)7,@:>=I;F4@:V]P>6%L86UA:RP@<V7G96YE:VQE<FEN
M:2!K=6QL86YA8FEL:7)S:6YI>BX`3$1!4"!S=6YU8W5S=2!A<F%N86UA9/TN
M`-UL971I_FEM(&YO:W1A<_T@9_QN8V5L;&5N96UE9&DN("5S`$1A\/UT_6T@
M;&ES=&5S:2!G_&YC96QL96YE;65D:2X@)7,`36]Z:6QL82!K96YA<B#G=6)U
M\'4@8G5L=6YA;6%D_2X@2V5N87(@YW5B=?!U;G5N(&'G_6L@;VQD=?!U;F1A
M;B!E;6EN(&]L=6XN`%-A>?UL;?W^(&UE=&EN`-QL:V4`1&5R<VQE<@!987)A
M=`!"8?!L86YT_2!Y87)A=`!996YI(%EA<F%T`$%L="!D:7II;B!Y87)A=`!9
M87)A=/UC_2#=>FEN;&5R:0!+<F5D:2!K87)T(&YU;6%R87/]`$C]<G9A=&ES
M=&%N`$O\8F$`WG4@06YD86MI(%IA;6%N`-YU(&%N9&%K:2!54DP`WG4@06YD
M86MI($AA=F$@1'5R=6UU`-YU($%N9&%K:2#>87)T;&%R.@!9_'+\<FS\:W1E
M:VD@<VET:6P`)7,@92!G:7)I_G1E(.=A;/W^86-A:R!G]G)E=FQE<FD@:VG^
M:7-E;&QE_G1I<FEN`$ME<P#>9>=I;&D@;VQA;FQA<OT@:V5S`$O]8G+]<P!+
M:7)I;"`H2T])."U2*0!+:7)I;"`H5VEN9&]W<RTQ,C4Q*0!+:7)I;"]5:W)A
M>6YA("A+3TDX+54I`,=E:R!#=6UH=7)I>65T:0!'1P!'_&YL_&L`5F5R:2!!
M\&%C_2!487)A>?UC_7/]`%1A<FEH`$=E;&G^(%1A<FEH:0!487)I:"!39>=I
M;6D`1_QN`$M?;VQO;G4@4VEL`$%R86S]:P!/;F1A;/UK('-A>?UL87(`1VER
M:6YT:7EI($%Z86QT`-9N('1A;OUM;/T`UFX@5&%N_6UL_2!296YK`-9N(%1A
M;OUM;/T@2VEM;&EK`%1A;OUM;&%R`%-I;`!'<G5P(%-I;`#=>FEN(%-I;`#=
M;&5T:6QE<FD@<VEL('9E('1E;6EZ;&4`2/QC<F4@4VEL`$MO;&]N(%-I;`!6
M87)O;&%N(/9T96MI('1A<VQA\/T@<VEL`%-A=/UR_2!S:6P`4V7G:6QM:?X@
M:VEM;&GP:2!S:6P`WG4@86YD86MI(&MO;&]N=2!S:6P`WG4@86YD86MI('-A
M=/UR_2!S:6P`5&5S;&EM('IA;6%N_0!$86YI;6%R:V$`4V]R=6YU(%1A;OUM
M;&%Y_6X`0>?]:VQA;6$`07ER_6YT_6QA<B`H07EN_2!Z86UA;F1A($AO<F1E
M)W5N(&?\;FS\:R!D;W-Y87/];OUN(&GG:6YD92DZ`$%Y<OUN=/UL87(@>?9N
M971I8VD@:>=I;B!G_&YL_&L@;VQA<F%K(&MA>61E9&EL9&DN`$=E;&G^:6T`
M3F5M($UI:W1A<OT`4V]N('-A871T96MI(&YE;2!M:6MT87+].B``3F5M(&UI
M:W1A<OTZ(`!3;VQD86X@<V'P82!Y]FYL_`!38?!D86X@<V]L82!Y]FYL_`!$
M:7II;@`R-"!S86%T;&EK('IA;6%N(&W](&?V<W1E<FEL<VEN/P!']G+\;G3\
M;&5M92!39>=E;F5K;&5R:0!(879A('1A:&UI;FEN:2!G]G+\;G3\;&4@*%1!
M1BD`1_9R_&YT_&QE;64@0FGG:6UI`$3\>F5N($)I;&1I<FEM:0!#:6)U=&D`
M4VEL;65Y:6X`;6%I;G1E;F%N8V4N<&AP(&1O<WEA<_UN82!D;_!R=61A;B!E
M<FG^;65Y:6XN`-UL:R!S873]<B!A;&%N(&%D;&%R_6[](&GG97)I>6]R(&UU
M/R!%=F5T(&ES92!B=2!K=71U>74@<V7G:6XZ`$1O;6EN:6L`1&]M:6YI:R!#
M=6UH=7)I>65T:0#=;F1I<@`E<R#=;F1I<@!/;'7^='5R=6QA;B!Y87#];&%N
M9/UR;6%Y_2!02%`@8F5T:?!I(&]L87)A:R!I;F1I<BX`0?YA\/T@8>?];/UR
M(&QI<W1E`-UL8>=L87(`12U0;W-T80!%4E(`16MV871O<@!$_'IE;FQE`$)L
M;VL@1/QZ96YL90!'<G5P($3\>F5N;&4`W7II;B!$_'IE;FQE`-UZ:6YL97)I
M($3\>F5N;&4`)7,@W>=I;B#=>FEN;&5R:2!$_'IE;FQE`%-EYV5N96ML97)I
M(&3\>F5N;&4Z`"5S(&GG:6X@:7II;FQE<FD@9/QZ96YL90!%\&ET:6T`3?US
M_7(`16P@4V%L=F%D;W(`UO!E+BXN`$5M`$5L96MT<F]N:6L@4&]S=&$`16QE
M:W1R;VYI:R!0;W-T82!!9')E<VD`16QE:W1R;VYI:R!P;W-T82!A<W)E<VQE
M<FD@9?YL9?YM96QI+@!/;F%Y;/T@96QE:W1R;VYI:R!P;W-T80!$=7EG=2!S
M:6UG97)L97)I`$)O_B!I;&5T:2X`0F_^('-O;G7G+@!";_X@87)A;6$@=&5R
M:6UL97)I`$9O=&_P<F%F($=A;&5R:7-I;F1E;B!M971I;FQE<FEN(&GG97)I
M<VEN92!G]G+\;G3\(&5K;&5M92!E=&MI;FQE_G1I<FEL<VEN(&UI/P!38?`@
M=/UK(&GG97)I:R!M96[\<_P@971K:6YL9?YT:7)I;'-I;B!M:3\`0FET:?X@
M>?UL_0!$_'IE;FQE>6EC:7EI($=E;FG^;&5T`%!A<F]L86[]>OT@<_UF_7)L
M86UA:R!I<W1E9&GP:6YI>F1E('-O<G5L;6%K(/QZ97)E(&)I<B!G_'9E;FQI
M:R!S;W)U<W4@9VER:6XL(-9R+B`G179C:6P@:&%Y=F%N_6[]>OUN(&%D_2!N
M961I<C\G.@!']G+\;G3\(&%D<F5S:6YI(&)U<F%Y82!G:7)I;@!%:W9A=&]R
M($=I;F5S:0!%<FET<F4`2&%T80!%;&5T<F]N:6L@<&]S=&$@9/9N9&5R;65D
M92!H871A+@!%<W1O;GEA`$5T:7EO<'EA`$5T;FEK`$%V<G5P80!(97(@,34@
M9&%K:6MA`$AE<B`R(&1A:VEK80!(97(@,S`@<V%N:7EE`$AE<B`U(&1A:VEK
M80!(97(@1VER:?YT90!(97(@>6%R_6T@<V%A=`!(97(@9&%K:6MA`-9R;F5K
M(&1E\&5R;&5R.@#'86S]_G3]<@!'96YI_FQE=`!+96YA<B#'=6)U\'5N=2!'
M96YI_FQE=``G*2<@0F5K;&5N:7EO<@!3861E(&ME;&EM92!V97EA(&%L_6YT
M_2!A<F%M82!T97)I;6D@8F5K;&5N:7EO<@!'9>=E<FQI;&EK(%-O;B!487)I
M:&D`W'-T`-9N($%L86X@4F5N9VD`07EA<FQA<B!IYVEN($944"!Y_&ML96UE
M<VD`5&5R8VEH;&5R:6X@9V5T:6QM97-I(&)A_F%R_7/]>BX`3$1!4"!S=6YU
M8W5S=6YA(&)A\&QA;G3](&)A_F%R_7/]>BX`4TU"('-U;G5C=7-U;F$@8F'P
M;&%N=/T@8F'^87+]<_UZ+@`B)7,B(&MO;G5M=6YD86X@:V]P>6%L86UA(&)A
M_F%R_7/]>BX`(B5S(B!K;VYU;75N82!K;W!Y86QA;6$@8F'^87+]<_UZ+@!9
M96YI(%-!4TP@8F'P;&%N=/US_2!O;'7^='5R=6QA;6%D_2X`(B5S(B!K;VYU
M;75N82!T8?[];6$@8F'^87+]<_UZ+@!5>6=U;B!(879A`$9A;&ML86YD($%D
M86QA<OT@*$UA;'9I;F$I`$9A<F]E($%D86QA<OT`3VYU;&UA>B!(871A.@!&
M86MS`-YU8F%T`$AI<W-E9&EL:7EO<@!(:7-S961I;&EY;W(Z(`!(869I9B!3
M8?!A;F%K`$AA9FEF($MA<B!38?!A;F'P_0!!;&%N(&UA=')I<VD`1FEJ:0!$
M;W-Y82!387G]<_TZ("5S(&1O<WEA`$1O<WEA(%-A>?US_3H@)7,@9&]S>6$`
M1&]S>6$@6?9N971I8VES:0!$;W-Y82!!9/T`1&]S>6$@<V7G:6UI`$1O<WEA
M('G\:VQE;64`1&]S>6$@>?QK;&5M92!D97-T96ML96YM:7EO<BX`4_QZ9V7G
M;&5R`$9I;FQA;F1I>6$`W6QK(%EA<OT`W6QK(,=E>7)E:P!/<F%N_2!S86)I
M=&QE`,=E=FER`$MA>6%N`%-I<P`E<R!D:7II;FD@>6]K`%EA>OT@4F5N9VD`
M665M96L`1_9R_&YT_&QE<FD@9&5S=&5K;&5M97EE;B!T87)A>?UC_6QA<B!I
MYVEN`%1A:&UI;B`H5$%&*0!486AM:6X@1_QN;&5R:2`H3F]T.B!'97)I(&3V
M;OQL96-E:VQE<B!H96T@9_QN(&AE;2!G96-E(&]L87)A:R!D]F[\;&5C96L[
M("EB_'G\:R!B:7(@<V%Y_2!G96YI_B!B:7(@]F)E:VQE('-O;G7G;&%N86-A
M:W3]<BD`4&%R;VQA;OUZ_2!M_2!U;G1T=6YU>C\`1F]R;6QA<@!$97EI_@!$
M97EI_B!T_'+\`$1E>6G^;&5R`$1E>6G^;&5R(#(`1F]R=6UL87(`6?9N;&5N
M9&ER;65L97(`0W4`QV5RYV5V96QE<@!&<F%N<V$`1G)A;G-A+"!-97)T;W!O
M;&ET86X`1G)A;G/]>B!'=7EA;F%S_0!&<F%N<_UZ(%!O;&EN97IY87/]`$9R
M86YS_7H@1_QN97D@0O9L9V5S:0!+:6UD96X`2VEM9&5N`%1A;2!"971I;6QE
M;64`1&]L=6YA>0!!Y_UK($%D`$=A8F]N`$?V<OQN=/QL97)I;B!A;/UN86-A
M\/T@9V%L97)I`$=A;&5R:3H`1V%M8FEY80`E<R!987#];&%N9/UR;6%S_6[]
M($]L=?YT=7(`3VQU_G1U<G5L86X@2V]D`$?\<F-I<W1A;@!!;&UA;GEA`$=A
M;F$`0V5B96QI=&%R_6L`5F5R:6QE;B!!9`!':70`1V]E9&5L`$=O;V=L92!!
M<F%M80!3:7EA:"!"97EA>@!9=6YA;FES=&%N`%EU;F%N8V$@*$E33RTX.#4Y
M+3<I`$=R]FYL86YD`$=R96YA9&$`1W)U<"!9]FYE=&EM:0!'<G5P(&ES:6UL
M97)I(&1O;'4@;VQM86S]9/UR`$=R=7!L87(`1W5A9&%L=7``1W5A;0!'=6%T
M96UA;&$`1W5E<FYS97D`2V]N=6L@W7II;FQE<FD`2V]N=6L@1&5F=&5R:0!'
M:6YE`$=U:6YE($)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!S873]<F1A
M:VD@<V]N(&C\8W)E>6D@<VEL;65Y:2!R961D961I>6]R+@!(5$U,07)E82#G
M:7IE;&=E9&5K:2!S;VX@:V]L;VYU('-I;&UE>6D@<F5D9&5D:7EO<BX`2%1-
M3$%R96$@YVEZ96QG961E:VD@<V]N('-A=/UR_2!S:6QM97EI(')E9&1E9&EY
M;W(N`$A45%`@2VEM;&EK($1E;F5T:6UI(&)U;&%N86UA9/TN`$AA:71I`$AA
M<V@@06QG;W)I=&UA<_T`2&%F:68@4VES`$)A_FS]:P!(96%R9"!!9&%S_2!V
M92!-8T1O;F%L9"!!9&%L87+]`-UB<F%N:6-E("A)4T\M.#@U.2TX+4DI`%G\
M:W-E:VQI:P!987)D_6T`1/QZ96YL97EI8VD@:W5L;&%R86L@>6%R9/UM`%EA
M<F3];6/]`%EA<OUK_')E`$1O<WEA;OUN(&)A_FQA;F?]8_TZ(`!9_&MS96L`
M7T%N87-A>69A`%9A=&EK86X`06YA<V%Y9F$`178@061R97-I`$5V(%1E;&5F
M;VYU`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@0G4@
M;65S86H@:>=I;F1E(&=EYV5R<VEZ("5S(%A-3"!V97)I<VD@:6QE(&MA<O[]
M;&'^_6QD_3H@)7,`2&]R9&4O2V]L86(Z("5S(&YE<VYE<VD@:6QE(&EL9VEL
M:2!B:7(@:6QE=&D@8G5L=6YA;6%D_0!(;W)D92]+;VQA8CH@)7,@=/QR_&YD
M92!H:><@8FER(&YE<VYE("5S(&UE<V%J_2!IYVEN9&4@>6]K+@!(;W)D92]+
M;VQA8CH@)7,@(B5S(B!B8?YA<OT@:6QE('-I;&EN9&D`2&]R9&4O2V]L86(Z
M($+\=/QN;&5M92!M;W1O<G4@)V1O;7AM;"<@4$A0('5Z86YT_7/];F$@:6AT
M:7EAYR!D=7EM86MT863]<@!(;W)D92]+;VQA8CH@)7,@;F5S;F5S:2!IYVEN
M('EE;FD@6$U,(&'P86/](&]L=?YT=7)U;&%M_7EO<@!(;W)D92]+;VQA8CH@
M4VEL:6YE;65D:2`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@)7,@=/QR_&YD
M96MI(&O]<_UM(&GG:6X@34E-12!)1"!B=6QU;F%M863]`$AO<F1E+TMO;&%B
M.B!%_FQE;F5M961I("5S("(E<R(Z("5S`%!A>6QA_OUM;&%R(&7^;&5N96UE
M9&DZ("5S`$)I;&EN;65Y96X@<&%Y;&'^_6T@(B5S(@!9871A>2#':7IG:0!9
M871A>2!Y87-T_6ML86UA`%EA=&%Y.@!"=7)A>6$@;F%S_6P@9V5L9&EN:7H_
M("A,_'1F96X@<F%P;W(@961I;B$I`$MAYR!A9&5T(&MO;&]N=2!B:7)L9?YT
M:7)M96L@:7-T:7EO<G-U;G5Z/P!+8><@86QA;B`H:V]L;VXI('9A<C\`2V'G
M(&%D970@<V%T_7+](&)I<FQE_G1I<FUE:R!I<W1I>6]R<W5N=7H_`$YE;0!.
M96TZ(`!-:7IA:.?];&%R`$UA8V%R:7-T86X`24U!4"!P;W-T82!K=71U<W4@
M;VQU_G1U<G5L86UA9/TZ("5S`$E-05`@<&]S=&$@:W5T=7-U('-I;&EN96UE
M9&DZ("5S`$E-05`@<&]S=&$@:W5T=7-U(&MO=&%S_2!O;'7^='5R=6QA;6%D
M_3H@)7,`25`@061R97-I`$E0(&%D<F5S:2!M979C=70@9&7P:6PN(`!)4"!!
M9')E<VD@:7II;B!V97)I;&5N($-)1%(@8FQO\'4@:>=I;F1E(&1E\&EL+@!)
M4"!K:6QI=&QE;64@:6AL86QI+@#6;E]C97EE(%-A=/UR(%EE<FQE_G1I<@#=
M>FQA;F1A`%-A9&5C92!3:6UG96QE<@`E<R!IYVEN('-I;6=E;&5R`$UE=&EN
M(&EL92!B:7)L:6MT92!S:6UG96QE<@!+:6UL:?!I;B!A9/TZ`$7P97(@9&_P
M<G4@9_9R_&YT_&QE;F5M:7EO<G-A+"!Y96YI('!E;F-E<F5D92!AYVUA:R!I
MYVEN('3]:VQA>?UN("5S+@!%\&5R($EN=&5R;F5T($5X<&QO<F5R(&EL92!S
M:6UG96QE<FD@9_9R96UI>6]R<V%N_7H@8G4@:W5T=7EU('-EYV5R96L@4$Y'
M('-A>61A;6S]\/UN_2!K87!A=&UA;OUZ(&=E<F5K:7(N`$?V<OQN=/QL97)I
M(&?V<F5M:7EO<B!F86MA="!B=2!M97-A:OT@9_9R96)I;&ER>6]R<V%N_7HL
M('G\:VQE;65K(&ES=&5D:?!I;FEZ(&?V<OQN=/P@=&%R87G]8_UN_7H@=&%R
M86;];F1A;B!G]G-T97)I;&5M96UE:W1E9&ER+@!']G+\;G3\(-9N:7IL96UE
M`$?V<OQN=/P@55),`$?V<OQN=/P@55),.@!397)G:61E;B!G]G+\;G3\`%-E
M<F=I9&5N(&?V<OQN=/PZ`$?V<OQN=/P@>?QK;&5M96L`1_9R_&YT_&QE<@#=
MYV5R:2!!:W1A<BP@063];2`E9`#=YV5R:2!A:W1A<OUL86X@86QA;CH@)7,`
MW>=E<FD@86MT87+];&%N(&%L86YL87(Z`%-O;E]R87EA(%-A=/UR($5K;&4`
M66%N;/W^(&5Y;&5M(&MO9'4@9VER:6QD:2X`66%N;/W^(&MU;&QA;OUC_2!A
M9/T@=F4O=F5Y82!P87)O;&$N`%EA;FS]_B!K=6QL86[]8_T@863]('9E>6$@
M]G1E:VD@861R97,N665N:61E;B!D96YE>6EN('9E>6$@9&%H82!F87IL82!Y
M87)D_6T@:>=I;B!Y]FYE=&EC:6YI>FQE(&?V<OS^_&XN`$=I<FEN=&EY:2!!
M<G1T_7(`2&EN9&ES=&%N`$)I<F5Y<V5L($MU;&QA;OUC_6QA<@!%;F1O;F5Z
M>6$`0FEL9VD`0FEL9VD`4V]N<F%Y82!+;U]L;VX@16ML90!']G+\;G3\(%EE
M<FQE_G1I<@#':7IE;&=E(%EE<FQE_G1I<@!796(@0F'P;&%N=/US_2!997)L
M9?YT:7(`UFYC97EE($MO;&]?;B!%:VQE`%EE;FD@:V]L;VYU(/YU(&%N9&%K
M:2!K;VQO;F1A;B!S;VYR82!Y97)L9?YT:7(`665N:2!K;VQO;G4@_G4@86YD
M86MI(&MO;&]N9&%N(/9N8V5Y92!Y97)L9?YT:7(`665N:2!S873]<OT@_G4@
M86YD86MI('-A=/UR9&%N('-O;G)A>6$@>65R;&7^=&ER`%EE;FD@<V%T_7+]
M(/YU(&%N9&%K:2!S873]<F1A;B#V;F-E>64@>65R;&7^=&ER`%EE;FD@<&%R
M86=R86;](/YU(&%N9&%K:2!D_/#\;61E;B!S;VYR87EA('EE<FQE_G1I<@!9
M96YI('!A<F%G<F%F_2#^=2!A;F1A:VD@9/SP_&UD96X@]FYC97EE('EE<FQE
M_G1I<@#6=&5K:2!T87-L86L@>65R;&7^=&ER`%EE;FD@8FER('!A<F%L;WG]
M(&%L86)I;&5C9?!I;FEZ(&)I<B!E;&5K=')O;FEK('!O<W1A(&%D<F5S:2!G
M:7)I;CH`2/QC<F5Y:2!S;VYR87/];F$@>65R;&7^=&ER`$C\8W)E>6D@]FYC
M97-I;F4@>65R;&7^=&ER`$MO;&]N=2!S;VYR87/];F$@>65R;&7^=&ER`$MO
M;&]N=2#V;F-E<VEN92!Y97)L9?YT:7(`365S86H@9VER`%!A<F%G<F%F_2!S
M;VYR87/];F$@>65R;&7^=&ER`%!A<F%G<F%F_2#V;F-E<VEN92!Y97)L9?YT
M:7(`4V%T_7+]('-O;G)A<_UN82!Y97)L9?YT:7(`4V%T_7+](/9N8V5S:6YE
M('EE<FQE_G1I<@!'_'9E;FQI:R!S;W)U<W5N=6X@8V5V86+].@!']G+\;G3\
M>?P@665R;&7^=&ER+T1E\&G^=&ER`$)A\&QA;G3](%EE<FQE_G1I<B]$9?!I
M_G1I<@!$8?#]=/UM(&QI<W1E<VD@9_9N9&5R;65K(&GG:6X@>65T97)S:7H@
M:W)E9&DN`%EE=&5R<VEZ(&MR961I`%1A;7-A>?T`5&%M<V%Y_2!L:7-T97-I
M`$=EYV5R<VEZ(%5$2"X@*$MU;&QA;OUC_2!697)I($)A_FS]:R!":6QG:7-I
M*0!'9>=E<G-I>B!U>6=U;&%M82X`1V7G97)S:7H@>?WP_6X@:VEM;&GP:2X`
M1V7G97)S:7H@=F5R:2!G]FYD97)I;&1I+@!'9>=E<G-I>B!T97-L:6T@861R
M97-I`$=EYV5R<VEZ(&1O<WEA(&)IYVEM:0!'9>=E<G-I>B!M<V=?='EP90!'
M9>=E<G-I>B!Y861A(&%T;&%N;?W^(&%P:5]I9`!'9>=E<G-I>B!Y861A(&%T
M;&%N;?W^(&1E\&G^=&ER9V5L97(`1V7G97)S:7H@_'-T(&EZ:6XN`$=EYV5R
M<VEZ(&EL971I_FEM(&MU<F%L;&%R_0!'9>=E<G-I>B!P87EL8?[];&%N(&YE
M<VYE`$=EYV5R<VEZ(&MA>6YA:R!A9')E<VDN`$=EYV5R<VEZ('5N:6-O9&4@
M=F5R:7-I+@!3=&]K`-UR86X@W7-L86T@0W5M:'5R:7EE=&D`27)A:P#=<FQA
M;F1A`$UA;B!!9&$@1&5V;&5T:0!986S]=/UL;?W^(&?V:R!G_'+\;'3\;/P@
M9OUR=/UN80#=<W)A:6P`Q_UK87)A;@#==&%L:6L`W71A;'EA`$IA;6%I:V$`
M3V-A:P!*87!O;GEA`$IA<&]N8V$@*$E33RTR,#(R+4I0*0!*97)S97D`W')D
M_&X`5&5M;75Z`$AA>FER86X`66%S;&$`3W)T87EA(%EA<VQA`%1A;6%M96X@
M66%S;&$`4V]L82!987-L80!38?!A(%EA<VQA`$MA>F%K:7-T86X`UGIG_&X@
M;VQA;B!S86ML86YS_6X@;?T_`$ME;GEA`$ME<F)E<F]S('-U;G5C=2!D;_!R
M=6QA;6%Y_2!R961D971T:2X`QV5K:7)D96L@06-E;6EL97)I`$%N86AT87(@
M66%R870`06YA:'1A<B!087)M86MI>FD`06YA:'1A<B!5>G5N;'7P=0!!;F%H
M=&%R(%1I<&D`06YA:'1A<B!+=6QL86[];?T`0>?]:R!A;F%H=&%R('-U;G5C
M=7-U;F1A(&%N86AT87(@>F%T96X@=F%R+@#';V-U:VQA<@!+:7)I8F%T:0!+
M=7IE>2!+;W)E`$?\;F5Y($MO<F4`2V]R96-E("AE=6,M2U(I`$MU=F5Y=`!+
M_7)G_7II<W1A;@!387EF82!?1/QZ96YI`$1I;`!,86\@1&5M;VMR871I8R!(
M86QK($-U;6AU<FEY971I`%-O;B!$]G)D_&X`WFG^:VEN($%Y`%-O;B!'_&YC
M96QL96UE.@!3;VX@1VER:?XZ("5S`%-O;B!':7)I_CH@)7,@_'IE<FEN9&5N
M("5S`%-O;B!':7)I_CH@07-L80!,971O;GEA`%EA<V$`1/QZ96X`2&GG8FER
M('/];OUR(&GG:6X@8F_^(&+]<F%K;6$`3/QB;F%N`%-O;`!3;VP@8F'^;/UK
M(&)I;&=I<VD`4V]L9&%K:2!D9?!E<FQE<@!,97-O=&AO`$QI8F5R>6$`3&EB
M>6$`3&EE8VAT96YS=&5I;@#':7-E;&EY;W(`2&%F:68@66'P;75R`$5R:V5N
M(%-A871L97)D92!(869I9B!98?!M=7(`1V7G(%-A871L97)D92!(869I9B!9
M8?!M=7(`2&%F:68@66'P;75R(%-A\&%N8?#]`$?V:R!G_'+\;'3\;/P@:&%F
M:68@>6'P;75R`$AA9FEF($MA<@!(869I9B!+87(@4V'P86YA\/T`3OQK=&5L
M:2#>:6ER`$)A\&QA;G3]`$)A\&QA;G3](&YO:W1A<_TZ`$?V<OQN=/QL97)K
M96X@96QE:W1R;VYI:R!P;W-T82!A9')E<VEN:2!O;'7^='5R;6$@<V%Y9F%S
M_6YA(&)A\&QA`$)A\&QA;G3];&%R`$QI;G5X(,=E<F5Z:0!,:7-T96QE("T@
M:W5L;&%N_6/](&1I>FEN:2!G]G)E8FEL:7(`5F5R:2!486)A;FQA<OUN_2!,
M:7-T96QE`%EA<F3];2!+;VYU;&%R_6[]($QI<W1E;&4`QVEZ96QG96QE<FD@
M3&ES=&5L90!,:7-T96QE+4%R_FEV`$QI<W1E;&4M66%R9/UM`$QI<W1E;&4M
M260`3&ES=&5L92U386AI<`!,:7-T96QE+4?V;F1E<FEL;6G^(-;P96QE<@!,
M:7-T96QE+5/\<F3\<OQM8_QL97(`3&ES=&5L92U3_')D_'+\;6/\($]L;6%Y
M86YL87(`2W5L;&%N_6/](&QI<W1E;&5M92!S9>=I;&5M97H@:_UL_6YD_2X`
M161E8FEY870`3&ET=F%N>6$`6?QK;&5N:7EO<BXN+@!997)E;"!Z86UA;CH`
M665R('9E(%IA;6%N`%EE<@!':7)I_@#'_6O]_@!':7)I_B!']G)E=FQE<FD`
M2W5L;&%N_6/](&%D_2!V97EA('!O<F]L82!D;_!R=2!O;&UA9/WP_2!IYVEN
M(&=I<FG^(&)A_F%R_7/]>B!O;&1U+@!':7)I_B!B8?YA<OUS_7H@;VQD=2X`
M57IU;B!M971I;@!!_FL`1/S^_&L`2_SG_&L@>75N86X@:&%R9FQE<FD`2_SG
M_&L@;&%T:6X@:&%R9FQE<FD`2_SG_&L@<F]M82!R86MA;6QA<OT`3/QK<V5M
M8G5R9P!!00!-3U1$`$U3+51.148@16MI('9E<FD@:>=E<FUE;65K=&5D:7(N
M`$U31P!-86-A;P!-86ME9&]N>6$`36%D86=A<VMA<@!"_'G\`%!O<W1A`%!O
M<W1A(%GV;F5T:6-I<VD`0F'P;&%?;G3](%EA<F%T+BXN`$UA;&%V:0!-86QE
M>GEA`$UA;&1I=FQE<@!-86QI`$UA;'1A`-;P96QE<FD@971I:V5T;&5Y96-E
M\&EN:7H@:V%T96=O<FD@;&ES=&5S:6YI('9E(&MA=&5G;W)I;&5R:2!I;&G^
M:VEL96YD:7)E8V7P:6YI>B!R96YK;&5R:2!Y]FYE=&EN+@!-87`R-"!H87)I
M=&%S_0!-87!1=65S="!H87)I=&%S_0!-87)T`$ME;F%R(&)O_FQU\'4`3VMU
M;FUU_B]/:W5N;6%M_?X@;VQA<F%K(&G^87)E=&QE`$1I\&5R(&EL971I(&G^
M87)E=&QE<FEY;&4@:?YA<F5T;&4@*/9R;F5K.B#6;F5M;&DO0V5V87!L86YM
M_?XI(`!-87)S:&%L;"!!9&%L87+]`$UA<G1I;FEK`$7^;&5L96X@86QA;FQA
M<@!-;W)I=&%N>6$`36%U<FET=7,`W7II;B!V97)I;&5N(&5N('G\:W-E:R!K
M<F5D:2X`16X@>?QK<V5K(&UE<V%J('!A<N=A<_T@<V%Y_7/](&'^_6QD_2X`
M4V]N(#(T('-A871T96MI(&5N('G\:W-E:R!S_6-A:VS]:SH@`%-O;B`V('-A
M871T96MI(&5N('G\:W-E:R!S_6-A:VS]:SH@`$5N('G\:W-E:R!U>G5N;'5K
M`$UA>?US`$UA>6]T=&4`5/UP`-QY96QE<@!-96[\($MI<&DZ`$C\8W)E;&5R
M:2!B:7)L9?YT:7(`W6QE=&D`W6QE<FD@8F'^87+]>6QA(&1O\')U;&%N9/T@
M86UA(&EM>F%L87G]8_UN_6X@;VYA>2!B96QG97-I(&1O\')U;&%N86UA9/TN
M`$UE<V%J_6X@<_QR97-I(&)I='1I+@!-97-A:B!T:7!I`$AA=F$@4F%P;W)U
M`$AA=F$@<F%P;W)U(/9B9?!I(&MU;&QA;OUL86)I;&ER(&1E\&EL+@!(879A
M(')A<&]R=2#V8F7P:2!K=6QL86[];&%B:6QI<B!D9?!I;"X@07ER_6YT_6QA
M<B!Y]FYE=&EC:2!IYVEN(&?\;FS\:VQE;F1I`%GV;G1E;0!-971R:6L`365K
M<VEK80!-:6MR;VYE<WEA`$]R=&$`36EM92!4_'+\`%-O;B`R-"!S86%T=&5K
M:2!E;B!D_/[\:R!S_6-A:VS]:SH@`%-O;B`V('-A871T96MI(&5N(&3\_OQK
M('/]8V%K;/UK.B``66%N<_T`375H=&5L:68`0G5L=6YA;6%Y86X@4$5!4B!P
M86ME=&DZ($A45%!?4F5Q=65S="X`071L86YM_?X@>6%P_6QA;F3]<FUA+B!"
M=2!U>6=U;&%M87G](&MU;&QA;FUA:R!I<W1I>6]R<V%N_7H@>6%P_6QA;F3]
M<FUA>?T@_')E=&UE:R!Z;W)U;F1A<_UN_7HN`$%T;&%N;?W^(&UE<V%J($E$
M+@!!=&QA;FW]_B!O;&%N(&=E<F5K;&D@4$5!4B!P86ME=&D@36%I;"X`071L
M86YM_?X@;W1U<G5M82!A:70@240N`%!Z=`!'97II8VD@4&]S=&$`4V%K:6X`
M1&7P:?YI;2!487)I:&D`1&7P:?YT:7(Z55),`$UO9"!486)A;OT`36]L9&]V
M>6$`36]N86-O`$UO\&]L:7-T86X`07D@=F4@>?UL`$%Y;/UK`$UO;G1S97)R
M870`07D@179R96QE<FD`1F%S`$=E;F5L;&EK;&4@0>?]:P!'96YE;&QI:VQE
M($)U;'5T;'4`1V5N96QL:6ML92!'_&YE_FQI`$'^8?#](%1A_OT`4V]L82!4
M8?[]`%-A\&$@5&'^_0!9=6MA<OT@5&'^_0!!_F'P_2!T8?[]`%EU:V%R_2!T
M8?[]`$UO>F%M8FEK`,=O:VQU(&3\>F5Y(&'^8?#](&'G_6S]<B!L:7-T96QE
M<@#';VML=2!39>=I;0!(97-A8OUM`%!O<G1A;/UM`%!O<G1A;"!$_'IE;FEM
M`$UY86YM87(`2V%B=6P@151-25E/4E5-`$%D`$YA;6EB>6$`3F%U<G4`3F5P
M86P`2&]L;&%N9&$`2&]L;&%N9&$@06YT:6QL97)I`$YE='-C87!E(%1A8F%N
M(%523`!.971S8V%P92!#02#=<'1A;"!54DP`3F5T<V-A<&4@0T$@:W5R86P@
M55),`$YE='-C87!E(%EE;FEL96UE(%),`$YE='-C87!E(-UP=&%L(%523`!.
M971S8V%P92!34TP@<W5N=6-U(&%D_0!.971S8V%P92!O;F%Y(&)E;&=E<VD@
M8>?]:VQA;6%S_0!.971S8V%P92!O;F%Y(&)E;&=E<VD@=/QR_`!!\`!!<VQA
M`%EE;FD@2V%L961O;GEA`%EE;FD@2V%T96=O<FD`665N:2!!>0!996YI($MU
M;&QA;OUC_2!!9/T@*%-EYVEM;&DI`%EE;FD@6F5L;&%N9&$`665N:2!096YC
M97)E("A?8F_^*0!(86)E<FQE<@!(86)E<B!'<G5P;&%R_0!3;VYR86MI`%-O
M;G)A:VD@4V7G96YE:VQE<@!.:6MA<F%G=6$`3FEJ97)Y80!.:6IE<GEA`$=E
M8V4`3FEU90!(87G]<@!&87)K;&%R_6X@9_9S=&5R:6QE8FEL96-E\&D@:W5L
M;&%N_6QA8FEL:7(@>6%P_6QA;F3]<FUA('9E<FES:2!Y;VLN`$E33R!I;6%J
M;&%R_2!O=?YT=7)M86L@:>=I;B!K=6QL86[];&%B:6QI<B!B:7(@>?9N=&5M
M('EO:RX`6?WP_6X@=&%S;&'P_2!Y;VLN`-US=&5N96X@:V]N=6UD82!H:>=B
M:7(@]F)E:R!B=6QU;FUA;6%K=&%D_7(`34-!3"!D;_!R=6QA;6%S_2!IYVEN
M(&AIYV)I<B!T86MV:6T@863]('-A\&QA;FUA;?W^=/UR+B``1&7P:?YI:VQI
M:R!9;VL`0G4@:7IN92!H:>=B:7(@86QT(&EZ:6X@96ML96YE;65Y96-E:W1I
M<BX`)7,@:>=I;B!H:>=B:7(@>6%P_6QA;F3]<FUA(&)I;&=I<VD@8F5L:7)T
M:6QM961I+@!&5%`@5D93(&GG:6X@:&GG8FER('EA</UL86YD_7)M82!B:6QG
M:7-I(&)E;&ER=&EL;65D:2X`4U%,(%9&4R!IYVEN(&AIYV)I<B!Y87#];&%N
M9/UR;6$@8FEL9VES:2!B96QI<G1I;&UE9&DN`%-13"U&:6QE(%9&4R!IYVEN
M(&AIYV)I<B!Y87#];&%N9/UR;6$@8FEL9VES:2!B96QI<G1I;&UE9&DN`$MR
M961I('EO:RX`2&GG8FER('1E<VQI;2!N;VMT87/](&)E;&ER=&EL;65M:?YT
M:7(N`$AIYV)I<B!D;W-Y82!Y_&ML96YE;65D:0!(:>=B:7(@<VEM9V4@8G5L
M=6YA;6%D_2X`2&GG8FER('EE<B!B96QI<G1I;&UE9&DN`$AIYV)I<B!M97-A
M:B!S8?!L86YM863]+@!!9"!B96QI<G1I;&UE9&DN`$YU;6%R82!B96QI<G1I
M;&UE9&DN`%-A;&3]<F=A;B!D97EI_B!K=6QL86YM80!(5%10(&1O\')U;&%M
M87/](&GG:6X@<&%R;VQA(&=I<FEL;65D:2X`24U!4"!D;_!R=6QA;6%S_2!I
MYVEN('!A<F]L82!G:7)I;&UE9&DN`$ME<F)E<F]S(&1O\')U;&%M87/](&GG
M:6X@<&%R;VQA(&=I<FEL;65D:2X`3&]G:6X@9&_P<G5L86UA<_T@:>=I;B!P
M87)O;&$@9VER:6QM961I+@!005-35T0@9&_P<G5L86UA<_T@:>=I;B!P87)O
M;&$@9VER:6QM961I+@!334(@9&_P<G5L86UA<_T@:>=I;B!P87)O;&$@9VER
M:6QM961I+@!/<&5N4U-,(&EK:6QI<VEN92!H:>=B:7(@>6]L(&)U;'5N86UA
M9/TN3W!E;E-33"!I:VEL:7-I(%!+0U,@,3(@=F5R:7-I>6QE(&-A;/W^;6%K
M(&GG:6X@9V5R96ML:2X`W'EE(&]L;6%K(&GG:6X@8F5K;&5Y96X@>6]K+@!+
M=7)A;"!Y;VL`66%N('EO:P#6;F)E;&QE:R!IYVEN(&=EYVEC:2!D:7II;B!B
M=6QU;F%M863]+@!+=6QL86[]8_T@863]('9E+W9E>6$@<&%R;VQA(&?V;F1E
M<FEL;65D:2X`1V7G97)L:2!834P@=F5R:7-I(&=E<FD@9/9N;65D:2X`1&7P
M97(@>6]K`-9Z9_QN('EA</UL86YD_7)M861A('/\<OQM(&)U;'5N86UA9/TN
M66%P_6QA;F3]<FUA>?T@=&5K<F%R(/QR971I;BX`UGIG_&X@>6%P_6QA;F3]
M<FUA;OUZ9&$@<_QR_&T@8G5L=6YA;6%D_2Y987#];&%N9/UR;6%Y_2!T96MR
M87(@_')E=&EN+@!(:>=B:7)I`$AIYV)I<FD@*-9R=/QL_"!K=6QL86[];BD`
M2W5Z97D@079R=7!A;/T@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($%D87/]`$MU
M>F5Y(%EA<OUM:_QR90!+=7IE>2!-87)I86YA($%D86QA<OT`3F]R=F7G`%-O
M;G)A<_UN9&$@1&7P:6P`UFYC97-I;F1E($1E\&EL`$1I>FEN(&1E\&EL`$=E
M<N=E:VQE_G1I<FEL;65M:?X`0F5L:7)T:6QM96UI_@!$97-T96ML96YM:7EO
M<BX`3F]T;&%R`$?V>B!A=/UL86-A:R!B:7+^97D@>6]K+"!G97)I(&3V;OQN
M+@!+87/];0!387G]`$MA<F%K=&5R('-A>?US_0!+;VQO;B!S87G]<_T`4V%T
M_7(@<V%Y_7/]`$1A\/UT_6T@;&ES=&5L97)I;FEN(&?\;F-E;&QE;FUE<VD@
M:>=I;B!N=6UA<F%L87(@8F5L:7)T:6QM96UI_BX`179E=`!.97-N90!.97-N
M92!987)A=/UC_7/]`%-E:VEZ;&EK(%-I<W1E;0!%:VEM`%-A;&3]<F=A;FS]
M:R!S_'IG96-I`$]F:7,`56UM86X`4V%D96-E($E-05`@<W5N=6-U;&%R_2!P
M87EL8?[];&%N(&1I>FEN;&5R:2!D97-T96ML96UE:W1E9&ER+@!3861E8V4@
M<V%L9/UR9V%N(&1E>6G^;&5R`%-A9&5C92!B:7(@96QE:W1R;VYI:R!P;W-T
M82!A9')E<VEN92!I>FEN('9E<FEL;65K=&5D:7(N`$)I<B!P87EL8?[];?UN
M('-A:&EP;&GP:6YI('9E>6$@<V%H:6)I;FD@<V%D96-E('-I<WEE;2!Y]FYE
M=&EC:7-I('9E>6$@<V%H:6)I(&1E\&G^=&ER96)I;&ER+@!996YI('!E;F-E
M<F5D92!AYP!/<&5N4U-,(&AA=&%S_3K=;7IA;&%N;?W^(%,O34E-12!P87+G
M87/];F1A;B!V97)I('-EYVEP(.?]:V%T_6QA;6%D_2X`0G4@8F'P;&%N=/UY
M_2!Y96YI('!E;F-E<F5D92!AYP#=_FQE=&EM(%-I<W1E;6D`4V7G96YE:VQE
M<@`E<R!IYVEN('-EYV5N96ML97(`4_UR86QA;FW]_B!,:7-T90!+=7)U;'7^
M`$MU<G5M<V%L($)I<FEM`$3\>F5N;&5M90#6>F?\;B!U>6=U;&%M82!T87-L
M8?#]`"5S(&GG:6YD96MI(/9Z9_QN('1A<VQA:VQA<CH`1&GP97(`1&GP97(@
M0FEL9VEL97(`4V%H:7`@:7II;FQE<FD`4$%-(&1O\')U;&%M87/](&UE=F-U
M="!D9?!I;"X`4$=0(%-A>?US86P@W6UZ80!01U`@WFEF<F5L96YM:?X@5F5R
M:0!01U`@0>?]:R!!;F%H=&%R_0!01U`@:6QE(-UM>F%L86YM_?XOWFEF<F5L
M96YM:?X@5F5R:0!02%`@2V]D=0!02%`@2V%B=?!U`-93($AA9FEF(%EA\&UU
M<@#64R!38?!A;F%K;&%R_0#64R!+87(`UE,@2V%R(%-A\&%N86ML87+]`-93
M($?V:R!G_'+\;'3\;/P@9OUR=/UN80!07TA0($MA8G7P=0!987-T_6ML86UA
M`%!A:VES=&%N`%!A;&%U`-W^9V%L($5D:6QM:?X@1FEL:7-T:6X@0O9L9V5S
M:0!086YA;6$`4&%P=6$@665N:2!':6YE`%!A<F%G=6%Y`$O]<VUE;B!"=6QU
M=&QU`%!A<F]L80!986YL_?X@<&%R;VQA`%)!1$E54R!D;_!R=6QA;6%S_2!I
MYVEN('!A<F]L82!G97)E:VUE:W1E9&ER+@!/;F%Y;/T@4&%R;VQA`%!A<F]L
M83H`4&%R;VQA.@!087)O;&%L87(@9?YL9?YM96L@>F]R=6YD863]<BX`66%P
M_?YT_7(`4&%N;V1A;B!Y87#]_G3]<@!9;VP`0F5K;&5Y96X@W'EE;&EK;&5R
M.@#=;G-A;FQA<@!9_'ID90!"86O];2#=_FQE;6QE<FEN:2!'97+G96ML9?YT
M:7(`0F%K_6T@:?YL96UL97)I(&=I<FG^=&4@9V5RYV5K;&7^=&ER:6QS:6X@
M;6D_`-UZ:6X`W7II;B!9]FYE=&EM:0!+:?YI<V5L($)I;&=I;&5R`%!E<G4`
M179C:6P@2&%Y=F%N;&%R`$9I;&EP:6YL97(`5&5L969O;@!&;W1O\')A9FQA
M<@!0:71C86ER;@!297-I;2!":7)I;6D`0F5Y;&EK(%/V>FQE<@!,_'1F96X@
M8FER:V'G(&C\8W)E>64@=/UK;&%Y_6X`3/QT9F5N(&)U(/;P97EI(.?]:V%R
M;6%K(&ES=&5D:?!I;FEZ:2!D;_!R=6QA>?UN.@!,_'1F96X@8G4@]O!E;FEN
M(&)A\/UN_2#G]GIM96L@:7-T961I\&EN:7H@9&_P<G5L87G];BX`3/QT9F5N
M(&)I<B!A>2!V92!B:7(@>?UL(&=I<FEN+@!,_'1F96X@>65N:2!K871E9V]R
M:6YI;B!A9/UN_2!G:7)I;CH`3/QT9F5N(&=EYV5R;&D@8FER($E0(&%D<F5S
M:2!G:7)I;BX`3/QT9F5N(&=EYV5R;&D@8FER(&?\;B!G:7)I;BP@87ED86MI
M(&?\;B!S87G]<_UN_2!K;VYT<F]L(&5D:6XN`$S\=&9E;B!G9>=E<FQI(&)I
M<B!Z86UA;B!G:7)I;BX`3/QT9F5N('-O<G5N=6X@8FER(/9Z971I;FD@>6%P
M_6XN`$S\=&9E;B!K=6QL86[]8_T@863]('9E('!A<F]L86[]>OT@9VER:6X`
M3/QT9F5N('EE;FD@:V%T96=O<FEN:2!A9/T@9VER:6XZ`%!O;&]N>6$`4&]L
M:71I:V$`3WEL86UA;&%R`%!O<G1E:VEZ`$?V<OQN=/P@:V]N=6UL86YD_7+]
M;/UY;W(`QVEZ96QG92!K;VYU;6QA;F3]<OUL_7EO<@!"=2!D:7II;F4@9_9N
M9&5R("A)34%0('1A<F%F_6YD86X@>F]R;&%N;6%M86MT863]<BD`4V]N("5S
M('-A871T92!D_/YE;B!Y8?!M=7(@=F4@:V%R(&UI:W1A<OTZ`%!R969S7VQD
M87`Z(-US=&5N96X@3$1!4"!U>F%N=/US_2!B=6QU;F%M863]+@!0<F5F<U]S
M97-S:6]N.B#=<W1E;F5N(&]T=7)U;2!U>F%N=/US_2!B=6QU;F%M863]+@!"
M87/];N<`1&5N:7H@<V5V:7EE<VEN9&5K:2!B87/];N<Z`$)A<_UNYSH`UFYI
M>FQE;64`1_9R_&YT_'G\('EE;FD@<&5N8V5R961E(/9N:7IL90#6;F-E:VD@
M<V7G96YE:VQE<@!"96QG97EI('EA>F3]<@#6>F5L($%N86AT87(`4V]R=6X`
M4V]R=6X@5&%N_6UL86UA<_T`4')O:F5L97(`365T:6X@8FEL9VD@:7-T96UI
M`$'G_6L@06YA:'1A<@!!Y_UK($%N86AT87(@86QG;W)I=&UA<_T`0>?]:R_6
M>F5L(&%N86AT87(@:6MI;&ES:2!B8?YA<OUY;&$@>6%R873];&%M863]+@!0
M;W)T;R!2:6MO`$MA=&%R`%-O<F=U`%)302!!Y_UK($%N86AT87+]("@E9"!B
M:70I`%)A9'EO(%-EYVEM:0!98?!M=7(`17)K96X@4V%A=&QE<F1E(%EA\&UU
M<@!'9><@4V%A=&QE<F1E(%EA\&UU<@!38?!A;F%K(%EA\/W^`%EA\&UU<B!V
M92!+87(`2V%R82!D]F[\_F5C96L@>6'P;75R`%)A<W1G96QE($1E>6G^`$]R
M86X`3VMU;6$`W6QE=&EL97)I($]K=0!3:6QM96L@:7-T961I\&EN:7IE(&=E
M<N=E:W1E;B!E;6EN(&UI<VEN:7H_*$)U(&G^;&5M(&=E<FD@YV5V<FEL96UE
M>BDZ)7,`2W5L;&%N_6/]("5S(&4@86ET(&MU;&QA;OUC_2!V97)I;&5R:6YI
M('-I;&UE:R!I<W1E9&GP:6YI>F4@96UI;B!M:7-I;FEZ+B!"=2!I_FQE;2!G
M97)I(.=E=G)I;&5M97HN`%-O;B!E>6QE;6D@=&5K<F%R;&$`1&5V:6YG96X@
M365N_"#6\&5L97)I;FD@5&%Z96QE.@!0;W)T86P@1_9R_&[\;?QN_"!487IE
M;&4Z`$3\>F5N;&D@W69A9&4`W6QI_FMI(%1A<F%Y_6/]`$'G_6ML86UA;&%R
M`%5Z86MT86MI(%-U;G5C=6QA<@!5>F%K=&%K:2!54DP@*&AT='`Z+R]W=W<N
M97AA;7!L92YC;VTO:&]R9&4I.@!3:6P`UF)E\&D@4VEL`$MO;&]N=2!3:6P`
M0FGG:6UL96UE>6D@4VEL`$EK:6QI>6D@4VEL`$MA>61E9&EL;6G^(&)E=&GP
M:2!S=6YU8W5N=2!G9>=I8VD@9&EZ:6YI;F1E;B!S:6PN`%-I;`!"=2!P87+G
M87G](&)E;&=E9&5N(.?]:V%R=`!+=6QL86[]8_T@4VEL`$MU;&QA;OUC_7G]
M('-I;#H@)7,`W7-T96L@8V5V87!L86YA;6%D_2Y$]F[\;&5N(&AA=&$@:V]D
M=3H@`$=E<F5K96X@06QA;@!496UI>FQE`%!A<F]L87G]('/]9OUR;&$`4&%R
M;VQA;OUZ_2!S_6;]<FQA>?UN`%-O;G7G;&%R`%-EYV5N96ML97)E($3V;OQN
M`%)E=6YI;VX`66%P_6QA;F3]<FUA>?T@1V5R:2!$]FYD_'(`6F5N9VEN($UE
M=&EN($3\>F5N;&5Y:6-I<VD@4V7G96YE:VQE<FD`0FEL;65C96QE<@!38?``
M4V'P(&)A_FS]:R!B:6QG:7-I`$1O\')U(&1E\&5R;&5R`%-A7W3]<B#6>F5L
M;&EK;&5R:2XN+@!']G)E=@!2;VUA;GEA`#$X,"!D97)E8V4@9/9N9/QR`%-O
M;&$@1/9N9/QR`%-A\&$@1/9N9/QR`%-A=/UR(-9Z96QL:6ML97)I`%-A=/UR
M(/9Z96QL:6ML97)I`%-A=/UR;&%R.@#':7IG:6QE<@#':7IG:6QE<B!T_&T@
M<V%T_7(@=F4@:V]L;VYL87(@87)A<_UN9&$@8F5L:7)E8V5K=&ER`,=I>F=I
M;&5R('-A9&5C92!K;VQO;FQA<B!A<F%S_6YD82!B96QI<F5C96MT:7(`QVEZ
M9VEL97(@<V%D96-E('-A=/UR;&%R(&%R87/];F1A(&)E;&ER96-E:W1I<@#'
M86S]_G3]<@!2=7-Y82!&961E<F%S>6]N=0!2=6%N9&$`4R]-24U%(-YI9G)E
M;&5M92#=;7IA<_T`4R]-24U%(&EL92#>:69R96QE;FUI_B#=;&5T:0!305-,
M(&1O\')U;&%M87/](&UE=F-U="!D9?!I;"X`4TU3($UE<V%J;&'^;6$`4U%,
M($MA8G7P=0!34T@`0D'>05))3$D`4U]13"!+86)U\'4`0W1S`%-A:6YT($AE
M;&5N80!386EN="!+:71T<R!V92!.979I<P!386EN="!,=6-I80!386EN="!0
M:65R<F4@=F4@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!V92!'<F5N861I;F5S
M`$%Y;OT@YV5RYV5V92`H:V5N7V1I<VDI`%-A;6]A`%-A;B!-87)I;F\`4V%O
M(%1O;64@=F4@4')I;F-I<&4`57ED=2!38?!L87G]8_T`4W5U9&D@07)A8FES
M=&%N`$MA>61E=`!+87ED970@)7,`4V7G96YE:VQE<FD@2V%Y9&5T`$]L=?YT
M=7)U;&%N('EA</UL86YD_7)M87G](%!(4"!B971I\&D@;VQA<F%K('-U;G5C
M=6YU;B!G9>=I8VD@9&EZ:6YI;F4@:V%Y9&5T+@`E<R!Y87#];&%N9/UR;6%S
M_2!K87ED961I;&1I+@!":6QI;0!!<F%M80!!<F%M82!-;W1O<FQA<OT`1&]S
M>6%L87+](%-EYP!":7(@=&%R:6@@<V7G:6X`16ML96UE:R!IYVEN(&)I<B!G
M<G5P('-EYVEN`%EE;FD@<V%H:6)I('-EYVEN`$)I<B!S=6YU8W4@<V7G:6X`
M16ML96UE:R!IYVEN(&)I<B!K=6QL86[]8_T@<V7G:6X`0OQT_&X@=&%R:6@@
M8FEL9?YE;FQE<FEN:2!S9>=I;@!":7(@;F5S;F4@<V7G:6X`W7-T961I\&YI
M>B!K87)A:W1E<FQE<FD@8?YA\/UD86MI(&MU='5L87)D86X@<V7G:6XN($1A
M:&$@<V]N<F$@;65T:6X@86QA;OUN9&%N(&MO<'EA;&%Y_7`@>6%P_?YT_7)A
M8FEL:7)S:6YI>BX`5&%R:6@@<_UN_7)L87G]8_US_6[]('-EY_UN.@!487)I
M:"!B:>=I;6EN:2!S9>=I;CH`1&7P:?YT:7)M96L@:7-T961I\&EN:7H@:VEM
M;&GP:2!S9>=I;CH`4V%A="!S_6[]<FQA>?UC_7/];OT@<V7G:6XZ`%-A870@
M8FGG:6UI;FD@<V7G:6XZ`$7^;&7^96X@:6MI(&%L86[]('-EYVEN+@!296YK
M(&3\>F5N:6YI>FD@<V7G:6XN`%1E<F-I:"!E='1I\&EN:7H@9&EL:2!S9>=I
M;CH`4V]R=6X@4F%P;W)U($?V;F1E<@!335,@1_9N9&5R`%-E;F5G86P`06QG
M_6QA>?UC_3H`17EL_&P`4_UR8FES=&%N('9E($UO;G1E;F5G<F\`4V5R:2!.
M=6UA<F%S_0!/='5R=6T@:VEM;&GP:6YI;B!S_')E<VD@9&]L9'4N`$)E;&ER
M=`!087)O;&%N_7K];OT@=6YU='5R<V%N_7H@<_UF_7)L86UA;OUZ82!I>FEN
M('9E<F5C96L@<V7G96YE:VQE<FD@8F5L:7)T:6XN(`!5;&'^;6%K(&ES=&7P
M:6YI>B!U>F%K=&%K:2!S=6YU8W5L87+](&)E;&ER;&5Y:6XN`%1E<F-I:"!E
M='1I\&EN:7H@9&EL+"!S86%T(&1I;&EM:2!V92!T87)I:"!S9>=E;F5K;&5R
M:6YI(&)E;&ER;&5Y:6XN`$)A_FQA;F?]YR!U>6=U;&%M86[]>OTL(')E;FL@
M9/QZ96YI;FEZ:2P@<V%Y9F$@=&%Z96QE;64L('9E(&1I\&5R(&?V<OQN=/P@
M<V7G96YE:VQE<FEN:2!B96QI<FQE>6EN+@!!>6%R;&%R`$MU<G5L=6T@9_QN
M8V5L;&5M92!B971I:VQE<FD@:W5L;&%N_6QA8FEL:7(@9'5R=6UD82X`1&7P
M:?YT:7)G92!I;&4@8FER9&5N(&9A>FQA('EE<B!M_&UK_&XZ(`!397G^96P`
M06S]_B!V97)I_@!+_7-A(-9Z970`QV_P=2!B8?!L86YT_2!IYVEN(&5R:?YI
M;2!A;F%H=&%R_2!T86[];6QA;G/];B!M_3\`1_9S=&5R`$AA;&5N(&MA>?UT
M;/T@;VQA;B!Y87#];&%N9/UR;6$@:6QE('EE;FD@>6%R873];&%N('EA</UL
M86YD_7)M82!A<F%S_6YD86MI(&9A<FML87+](&?V<W1E<BX`1VER:?YT92!E
M;B!S;VX@9VER:?X@=&%R:6AI(&?V<W1E<FEL<VEN(&UI/P#6>F?\;B!O;&%N
M_2!S86ML86UA('-EYV5N9?!I;FD@9_9S=&5R`%-EYVEC:7EI(&?V<W1E<@#'
M:7IE;&=E(&G^;&5M;&5R:2!M96[\(.=U8G7P=6YD82!G]G-T97)I;'-I;B!M
M:3\`)7,@365N_'/\('-O;&1A(&?V<W1E<FEL<VEN(&UI/P!486)L;R!(_&-R
M92#6>F5L;&EK;&5R:2!+=71U<W5N=2!G]G-T97(`5&%B;&\@UGIE;&QI:VQE
M<FD@2W5T=7-U;G4@9_9S=&5R`%1A8FQO(%-A=/UR(-9Z96QL:6ML97)I($MU
M='5S=6YU(&?V<W1E<@!']G+\;G3\(/9Z96QL:6ML97)I(&MU='5S=6YU(&?V
M<W1E<@!9_&ML96UE>6D@9_9S=&5R`%-A\&%N86L`17)K96X@4V%A=&QE<F1E
M(%-A\&%N86L`1V7G(%-A871L97)D92!38?!A;F%K`,=E=G)E9&4@4V'P86YA
M:P!+_.?\;'0`W6QK(&]L87)A:R!K;VW^=2#V\&5L97(@:_SG_&QT<_QN('EA
M9&$@=&'^_6YS_6X`4VEE<G)A($QE;VYE`-QY92!O;`#=;7IA`-UM>F$@06QG
M;W)I=&UA<_T`4VEN9V%P=7(`0F]Y=70`0F%K_6W]($%T;&$`4VQO=F%K>6$`
M4VQO=F5N>6$`2V%R`$MA<B!38?!A;F'P_0!+87(@4V'P86YA:VQA<OT`17)K
M96X@4V%A=&QE<F1E($MA<B!38?!A;F%K;&%R_0!'9><@4V%A=&QE<F1E($MA
M<B!38?!A;F%K;&%R_0!+87(@1&5R:6YL:?!I.B``66'P86X@:V%R_6X@<W4@
M9?YI=&DZ(`!3;VQO;6]N($%D86QA<OT`4V]M86QI`-YA<FO];&%R("8@WFEI
M<FQE<@!3_7)A;&%M82!D_'IE;FD@<V7G:6UI`$MA>6YA:R!A9')E<VD`1_QN
M97D@069R:6MA`$?\;F5Y($%V<G5P82`H25-/+3@X-3DM,RD`1_QN97D@1V5O
M<F=I82!V92!'_&YE>2!386YD=VEC:"!!9&%L87+]`$?\;F5Y(%EA<OUM:_QR
M90!":71I_FEK(&C\8W)E;&5R(&%R87/];F1A:VD@8F_^;'5K`$C\8W)E9&5K
M:2!S_6[]<B!V92!IYV5R:6L@87)A<_UN9&%K:2!B;_YL=6L`0F_^;'5K($%Y
M87)L87G]8_T`07)A;/UK(&+]<F%K;6$`07)A;/UK(&+]<F%K;6$@=F4@>6%S
M=/UK;&%M80#=<W!A;GEA`-US=&5N;65Y96X@W6QE=&D`UGIE;"!+87)A:W1E
M<B!':7)I_FD`2/QC<F5Y:2!B]FP`2V]L;VYU(&+V;`!3873]<OT@8O9L`%-P
M;W)L87(`4W)I($QA;FMA`%-T86YD87)T`%5Z87D@66]L=0!"8?YL86YG_><@
M>?UL_0!%>6%L970@=F5Y82#=;`!$=7)U;0!$97!O;&%M82!B:>=I;6D`4V]K
M86L@061R97-I`-QS=/P@YVEZ9VEL:0!$:7IG:2!L:7-T97-I`$%D<F5S=&5N
M(&%L86X@863];OT@Y_UK87)T`%-I=&EL(%M#4U-=`%!Z<@!+;VYU`$?V;F1E
M<@!!;'1S:6UG90!"8?YA<OT`66%P_6QA;F3]<FUA(&)A_F%R_7EL82!G97)I
M(&3V;F3\<OQL9/PN($1E\&G^:6ML:6ML97)I(&?V<FUE:R!IYVEN('EE;FED
M96X@>?QK;&5Y:6XN`%EE9&5K('EA</UL86YD_7)M82!B8?YA<OUY;&$@:V%Y
M9&5D:6QD:2X`665D96L@>6%P_6QA;F3]<FUA(&1O<WEA<_T@)7,@8F'^87+]
M>6QA(&MA>61E9&EL9&DN`"5S(&)A_F%R_7EL82!Y87K];&3]+@!3=61A;@#6
M>F5T`$?\;B!$;_!U;74`1_QN(&)A=/UM_0!'_&YE_FQI`$?\;B!D;_!U;74`
M1_QN(&1O\'5M=2]'_&X@8F%T_6W]`$?\;B!D;_!U;74Z(`!'_&X@8F%T_6W]
M`$?\;B!B873];?TZ(`#<<W1S:6UG90!$97-T96L`4W5R:6YA;0!3;WEA9/T`
M4W9A;&)A<F0@=F4@2F%N($UA>65N`%-V87II;&%N9`#=<W9EYP#=<W9IYW)E
M`$%R86UA('1E<FEM;&5R:6YD92!S]GID:7II;2!H871A<_T`4W5R:7EE`$?V
M:R!G_'+\;'3\;/P@9OUR=/UN80!']FL@9_QR_&QT_&S\(&;]<G3];F%L87(`
M5%-6(&1O<WEA<_T`QVEZ96QG90#'27IE;&=E(-9Z96QL:6ML97)I`,=I>F5L
M9V4@]GIE;&QI:VQE<FD`5&%Y=F%N`%1A>79A;BP@QVEN(&5Y86QE=&D`5&%C
M:6MI<W1A;@!486YZ86YY80!(961E9CH`1_9R979L97(`5&5L969O;B!.=6UA
M<F%S_0!3;VX@<V%A="!IYVEN('/]8V%K;/UK.B``4_UC86ML_6L`4_UC86ML
M_6LZ(`!487-L86L@6?9N971I;6D`365T:6X`4V%D96-E($UE=&EN`$UE=&EN
M(&AI>F%L86UA<_T`365T;FEN(-QS=/P`4'+^`%1A:2`H5$E3+38R,"D`5&%Y
M;&%N9`!3:7-T96UI(&MU;&QA;OUD_?#];OUZ(&GG:6X@=&7^96MK_'(@961E
M<FEZ+@!&5%`@=7IA;G3]<_T@:W5L;&%N_6QA8FEL:7(@9'5R=6UD82!D9?!I
M;"X`2&]R9&4O2V]L86(@8OQT_&YL9?YT:7)M92!M;W1O<G4@9&5S=&5K;&5M
M96UE:W1E9&ER.B`B)7,B`$)A:_UM.CH@<_UN_68@8F'^87+]>6QA('G\:VQE
M;F5M961I+@#>9>=E;F5K;&5R('!E;F-E<F5S:2!K87!A;F3]+L?]:_W^('EA
M</UL_7EO<BX`1?!E<B!I>FEN;&5R:2!K=6QL86YM86L@:7-T:7EO<G-A;OUZ
M('GV;F5T:6-I;FEZ:6X@W7II;B!S:7-T96UI;FD@>6%P_6QA;F3]<FUA<_T@
M9V5R96MM96MT961I<BX`4V%D96-E(&%L="!T87)A9@#=;&5T:?YI;2!N;VMT
M87/];OUN($E$)W-I(&)E;&ER;&5N96UE9&DL(&)O_B!B_7)A:_UL;?W^('9E
M>6$@=F5R:2!T86)A;OUN9&$@8G5L=6YA;6%D_2X`W6QE=&G^:6T@;F]K=&%S
M_2!B8?YA<OUY;&$@861R97,@9&5F=&5R:6YI>F4@96ML96YD:2X`Q_UK87)T
M_6QM_?X@4$=0(&EM>F$@]F)E\&D@:6UZ86QA;FW]_B!I;&5T:6YI;B!D;_!R
M=6QU\'5N=6X@<V'P;&%N;6%S_2!IYVEN(&=E<F5K;65K=&5D:7(N`$1A\/UT
M_6T@;&ES=&5S:2!)1"=S:2!B96QI<FQE;F5M961I+"!B;_X@8OUR86O];&W]
M_B!V97EA('9E<FD@=&%B86[];F1A(&)U;'5N86UA9/TN`$1A\/UT_6T@;&ES
M=&5S:2!B96QI<FQE;F5M961I+@#>:69R96QE;64@]GIE;&QI:VQE<FD@9_QV
M96YL:2!B:7(@=V5B(&)A\&QA;G3]<_T@9V5R96MT:7)M96MT961I<BX`)7,@
M9&]S>6%S_2`E<R!A>6%R_2!IYV5R;65L:61I<BX`)7,@9&]S>6%S_2`E<R!A
M>6%R;&%R_2!IYV5R;65L:61I<BX`1&]S>6$@:V5N9&D@_'IE<FEN92!K;W!Y
M86QA;F%M87HN`$1O<WEA('9E<FD@:>=E<FUI>6]R+@!486MI<"!E9&5N;&5R
M(&)U(&EL971I+W)F8S@R,B!I;&5T:7-I(&GG:6X@8F'^;/UK(&)I;&=I;&5R
M:61I<BX`0?YA;6%D_?#];?UZ('1A<F%Y_6/](&AA=&%L87+]('-E8F5B:7EL
M92!T86T@96MR86X@:VEP:6YI;B!);G1E<FYE="!%>'!L;W)E<B=L82!B:7)L
M:6MT92!S;W)U;B#G_6MA<F3]\/T@8FEL:6YM96MT961I<BX@06YL86US_7H@
M9_9R_&YT_&QE<FQE+"#G86S]_FUA>6%N(&UE=&EN(&3\>F5N;&5Y:6-I(&G^
M;&5R:7EL92!V92]V97EA('1A<F%Y_6/];OUN(')A<W1G96QE(.?V:VUE<VEY
M;&4@:V%R_OUL8?YA8FEL:7)S:6YI>BX@1?!E<B!S:7-T96UI;FEZ(%=I;F1O
M=W,@.7@@:7-E('G\:W-E:R!I:'1I;6%L("='96YE<F%L(%!R;W1E8W1I;VX@
M1F%U;'0G(&AA=&%S_2!A;/UP('-I<W1E;6D@>65N:61E;B!B8?YL871M86[]
M>B!G97)E:V5C96LN7&Y<;D)U(&)I<B!U>6%R_7ED_2X@1?!E<B!H86QA('1A
M;2!E:W)A;B!M971I;B!D_'IE;FQE>6EC:7-I;FD@9&5N96UE:R!I<W1I>6]R
M<V%N_7H@179E="=I('3]:VQA>?UN+@!+:6UL:6L@(B5S(B!S:6QI;F1I+@!3
M861E8V4@<V]L('1A<F%F`$-R>7!T7W!G<#HZ('/];OUF_6YA($=N=5!'(&EK
M:6QI<VEN:6X@:V]N=6UU('9E<FEL;65K('IO<G5N9&%D_7(N`"5S('1A<FEH
M:6YD92`E<R!E(&?V;F1E<FEL96X@(B5S(B!K;VYU;'4@:6QE=&D@9_9R_&YT
M_&QE;F1I+@I"=2!I;&5T:6YI;B!O:W5N9'7P=2!V97EA(&%N;&'^_6QD_?#]
M;OT@9V%R86YT:6QE;65M96MT961I<BX`3VQU_G1U<B!P96YC97)E<VEN92!B
M8?!L86[]<FME;B!K=6QL86[];&%C86L@:7-I;0!(;W)D95]#<GEP=%]S:6UE
M.CH@<_UN_6;](&]P96YS<VP@8FER:6UI(&GG:6X@9V5R96MM96MT961I<BX`
M(B5S(B!T97)C:6AI('9E<FES:2!I>FEN('9E<FEL96X@96X@>?QK<V5K(&)O
M>75T=2!G9>=T:?!I(&GG:6X@:V%Y9&5D:6QE;65M96MT961I<BX`0G4@=F5R
M:2!Y87!S_6[]*"5S*2!G]G-T97)M96L@:>=I;B!K=6QL86[];&%N('!R;V=R
M86T@<VES=&5M9&4@8G5L=6YM86UA:W1A9/UR+@!3861E8V4@<V]L('9E('-A
M\"!T87)A9FQA<@!3861E8V4@<V'P('1A<F%F`"(E<R(@<W5N=6-U<W4@<VEL
M:6YD:2X`(B5S(B!S=6YU8W5S=2!K87ED961I;&1I+@`E<R!IYVEN(&]L86X@
M_'EE;&EK(&ES=&7P:2!S:6QI;F1I+@!"96QI<G1I;&5N('-A=/UR(&)U;'5N
M;6%M86MT863]<BX`1V7G:6-I(&1O<WEA("(E<R(@8G5L=6YM86UA:W1A9/UR
M+@!3861E8V4@_'-T('9E(&%L="!T87)A9FQA<@!3861E8V4@_'-T('1A<F%F
M`$)I<B#V;F-E:VD@863];2!S_7)A<_UN9&$@>?QK;&5N96X@=F5R:2!K87EB
M961I;&1I+@!9_&ML96YE;B!D;W-Y82!K87ED961I;&5M961I+@!W96%T:&5R
M+F-O;2!K=6QL86[];&%B:6QI<B!D9?!I;"X`2&GG8FER('-EYV5N96L@;65V
M8W5T(&1E\&EL+@!-971N92!G]FW\;/P@;VQA<F%K(&?V<W1E<FEL96)I;&5C
M96L@:_US_6T@>6]K`$)U(&%L86YD82#G;VL@9F%Z;&$@:V%R86MT97(@=F%R
M+B5S('1A;F4@:V%R86MT97(@9VER9&EN:7H[("5S('1A;F5D96X@87H@9VER
M;65N:7H@9V5R96MI<F1I+@!$;W-Y82`H:V%R_OUD86XI('G\:VQE;FUE<VEN
M9&4@<V]R=6X@=F%R.B`E<R!Y_&ML96YE;65D:2X`1&]S>6$@>?QK;&5N:7)K
M96X@8FER('-O<G5N(&]L=?YT=3H@)7,@96X@8OQY_&L@:7II;B!V97)I;&5N
M(&)O>75T=&%N("@E9"!B>71E*2!D86AA(&+\>?QK+@!$;W-Y82!Y_&ML96YI
M<FME;B!B:7(@<V]R=6X@;VQU_G1U.B`E<R!S861E8V4@:_US;6D@;VQA<F%K
M('G\:VQE;F1I+@!);&5T:6YI;B!B=2!K_7-M_6[](&?V<OQN=/QL96YM97-I
M;F1E(&AA=&$@;VQU_G1U+@#=;&5T:?YI;2!N;VMT87/];OUN('9E<FEL97)I
M("AIYV5R:2D@86MT87+];/UR:V5N(&AA=&$@;VQU_G1U+@!I0V%L96YD87(@
M=F5R:7-I("AIYV5R:2D@86MT87+];/UR:V5N(&AA=&$@;VQU_G1U+@!987#]
M;&%N9/UR;6$@9F]R;75N9&$@8FER(&AA=&$@=F%R+B!'97)E:VQI(&)I<B!A
M;&%N_2!D;VQD=7)M86W]_B!O;&%B:6QI<G-I;FEZ+@!"96QI<G1I;&5N(&%D
M<F5S(&1E9G1E<FD@:?YL979I;FEN(&=E<N=E:VQE_G1I<FEL;65S:2!S_7)A
M<_UN9&$@<V]R=6X@;VQU_G1U+B!,_'1F96X@9&%H82!S;VYR82!T96MR87(@
M9&5N97EI;BX`W6QE=&G^:6T@;F]K=&%S_6[];B!A>7+];G3];&%R_6[](&?\
M;F-E;&QE<FME;B!H871A(&]L=?YT=2X@3/QT9F5N(&1A:&$@<V]N<F$@=&5K
M<F%R(&1E;F5Y:6XN`$1A\/UT_6T@;&ES=&5S:6YI(&?\;F-E;&QE<FME;B!B
M:7(@:&%T82!O;'7^='4N($S\=&9E;B!D86AA('-O;G)A('1E:W)A<B!D96YE
M>6EN+@!"=2!)34%0('-U;G5C=7-U('!A>6QA_OUL86X@9&EZ:6YL97)I(&1E
M<W1E:VQE;6EY;W(N`$)U(&=EYV5R;&D@8FER(')A<B!A<OYI=FD@9&7P:6PN
M`$)U(&=EYV5R;&D@8FER('II<"!D;W-Y87/](&1E\&EL+@!"=2!G9>=E<FQI
M(&)I<B!K87)T(&YU;6%R87/](&1E\&EL+@!"=2!S_'+\8_P@0VQI8VMA=&5L
M;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!A\"!G9>=I9&D@_'IE<FEN9&5N
M($A45%`@05!)(&MU;&QA;F%R86L@;65S86H@871M86[]>F$@:7II;B!V97)I
M<BX`0G4@<_QR_&/\('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"D@8?`@
M9V7G:61I(/QZ97)I;F1E;B!(5%10($%022!K=6QL86YA<F%K(&UE<V%J(&%T
M;6%N_7IA(&EZ:6X@=F5R:7(N`$)U('/\<OQC_"!33510('EO;'5Y;&$@5F]D
M869O;F4@271A;'D@8?`@9V7G:61I(/QZ97)I;F1E;BP@<V%D96-E(%9O9&5F
M;VYE(&YU;6%R86QA<OUN82!M97-A:B!A=&UA;OUZ82!I>FEN('9E<FER+B!6
M;V1E9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I(&5L96MT<F]N:6L@
M<&]S=&$@861R97-I(&=E<F5K=&ER;65K=&5D:7(N`$)U(&=E<F5K;&D@8FER
M(&%L86YD_7(N`$)U(&%L86X@<V%D96-E('-A>?T@:>=E<FUE;&ED:7(N`$)U
M(&%L86X@<V%D96-E('-A>?T@=F4@:6MI(&YO:W1A(/QS=/QS=&4@:?YA<F5T
M:2!IYV5R96)I;&ER+@!"=2!A;&%N('-A9&5C92!S96MI>FQI:R!S87G]('-I
M<W1E;6EN9&5N(&1E\&5R;&4@:>=E<F5B:6QI<BX`0G4@86QA;B!V:7)G_&P@
M=F5Y82!B;_YL=6ML82!A>7+];&W]_B!S87G](&QI<W1E(&]L;6%L_63]<BX`
M0G4@86QA;B!G9>=E<FQI(&)I<B!N=6UA<F$@;VQM86S]9/UR+@!"=2!A;&%N
M(%)'0B!(97@@8FGG:6UI;F1E(&)I<B!R96YK(&MO9'4@:>=E<FUE;&ED:7(L
M(/9R;F5K.B`G(S$R,S1A9B<`0G4@9F]R;2!Z871E;B!I_FQE;F1I+@!"=2`E
M<RX`0G4@8FER($MO;&%B($=R;W5P=V%R92!N97-N97-I9&ER+B!"=2!N97-N
M97EI(&?V<F5B:6QM96L@:>=I;B!+;VQA8B!'<F]U<'=A<F4@8FGG:6UI;FD@
M86YL87EA8FEL96X@8FER(&5L96MT<F]N:6L@<&]S=&$@:7-T96UC:7-I;F4@
M9V5R96L@=F%R+D)U(&5L96MT<F]N:6L@:7-T96UC:2!L:7-T97-I(&GG:6X@
M)7,@861R97-I;F4@=?!R87G];BX`0G4@:6QE=&D@<VEZ:6X@:V%R86MT97(@
M:_QM96YI>F1E;B!F87)K;/T@;VQA<F%K*"5S*2!Y87K];&W]_G3]<BX`0G4@
M;G5M87)A(&5N(&%Z_6YD86X@8FER(&]L;6%L_63]<BX`0G4@<W5N=6-U('II
M<"!V92!G>FEP(&1O<WEA;&%R_6[](&'G86UA;6%K=&%D_7(N`%-I<W1E;6EN
M(&5T:VEN;&GP:2!K86QD_7+];&W]_G3]<BX`0G4@9&7P97(@8FER('-A>?T@
M;VQM86S]9/UR+@!"=2!P96YC97)E(%-EYV5N96ML97(@<&5N8V5R97-I;F1E
M;B#G8?!R_6QM86S]9/UR+@!']FL@9_QR_&QT_'/\`$)I;&5T;&5R`%IA;6%N
M`%IA;6%N(-UZ;&5M90!:86UA;B!":>=I;6D`6F%M86X@4V7G:6UI`%1I;6]R
M+4QE<W1E`$)A_FS]:P!"8?YL_6L@*&'G_6ML86UA*3H`2VEM90#';VML=2#V
M\&4@<V7G:6UI(&GG:6XL('3]:VQA<FME;B!#;VYT<F]L("A00RD@=F5Y82!#
M;VUM86YD("A-86,I('1U_G5N82!B87/];BX`0G5G_&X`2%1-3"!+87EN8?#]
M;F$@1V7G:6X`5&]G;P!4;VME;&%U`%EA<OUN`%1O;F=A`-QS=`#<<W0@QV5R
MYV5V92`HW%]S="D`QV5V:7)I;&5R`%1R:6YI9&%D('9E(%1O8F%G;P!$;_!R
M=2!V97EA(%EA;FS]_@!380!4=6YU<P!4_')K:7EE`%3\<FOG92`H25-/+3@X
M-3DM.2D`5/QR:VUE;FES=&%N`%1U<FMS('9E($-A:6-O<R!!9&%L87+]`%1U
M=F%L=0!39>=I;6EN:7II(&=I<FEN.@!5+E8N(&5N9&5K<SH@`%523`!"971I
M:VQE<FEN(&1U<G5M(')A<&]R;&%R_6[];B!T97-L:6T@961I;&5C9?!I(%52
M3`!54DPZ`%5G86YD80!5:W)A>6YA`%9&4R!D:7II;FEN92!E<FG^:6QE;65M
M:7EO<BX`W'EE(&]L=7)K96X@96L@:W5L;&%N_6/](&)I;&=I<VD@96ML96YE
M;6EY;W(N`"(E<R(@5D93(&1O<WEA<_UN_6X@:7II;FQE<FD@9&7P:?YT:7)I
M;&5M:7EO<BX`)7,O)7,@5D93(&1O<WEA<_UN_6X@:7II;FQE<FD@9&7P:?YT
M:7)I;&5M:7EO<BX`)7,@9&7P:?YT:7)I;&5M961I+@!344P@<W5N=6-U<W5N
M82!B8?!L86[];&%M_7EO<BX`4U-,(&EL92!B8?!L86[];&%M_7EO<BX`5D93
M(&1O<WEA<_T@:V]P>6%L86YA;?UY;W(N`"(E<R(@5D93(&1I>FEN:2!Y87)A
M=/UL86W]>6]R+@!61E,@9&EZ:6YI('EA<F%T_6QA;?UY;W(N`%9&4R!D;W-Y
M87/]('EA<F%T_6QA;?UY;W(N`$)O_B!61E,@9&]S>6%S_2!Y87)A=/UL86W]
M>6]R+@!697)I('/]:_W^=/UR_6QA;?UY;W(N`"(E<R(@9&EZ:6YI('-I;&EN
M96UI>6]R+"!D:7II;B!B;_X@9&7P:6PN`"5S('-I;&EN96UI>6]R+"!D:7II
M;B!B;_X@9&7P:6P`5D93(&1I>FEN:2#V>GEI;F5L:2!O;&%R86L@<VEL:6YE
M;6EY;W(N`%9&4R!D:7II;FD@<VEL:6YE;6EY;W(N`%9&4R!D:7II;FD@<VEL
M:6YE;6EY;W(Z("5S+@!61E,@9&]S>6%S_2`B)7,B('-I;&EN96UI>6]R+@!6
M1E,@9&]S>6%S_2!S:6QI;F5M:7EO<BX`5D93(/9Z>6EN96QI(&]L87)A:R!S
M:6QI;F5M:7EO<CH@)7,N`%G\<OQR;/QK=&5K:2!D:7II;F4@:V%R87(@=F5R
M:6QE;6EY;W(N`$]N87D@8F5L9V5S:2!A>7+];G3];&%R_2#G_6MA<G3];&%M
M_7EO<@!486[];?T@>?QK;&5N96UI>6]R.B`E<P!61E,@9&]S>6%S_2!T8?[]
M;F%M_7EO<BX`5D93(&1O<WEA<_T@(B5S(B!AY_UL86W]>6]R+@!61E,@9&]S
M>6%S_2!Y86UA:R!IYVEN(&'G_6QA;?UY;W(N`%9&4R!D;W-Y87/](&'G_6QA
M;?UY;W(N`%/]:_W^=/UL_6W]_B!A<OYI=B!AY_UL86W]>6]R+@!69G-R;V]T
M(&1I>FEN:2!O:W5N86W]>6]R+@`E<RT^)7,@;VQA<F%K('EE;FED96X@861L
M86YD_7+];&%M_7EO<CH@:&5D968@9&EZ:6X@>F%T96X@=F%R+@!61E,@9&EZ
M:6YI('EE;FED96X@861L86YD_7+];&%M_7EO<BX`5D93(&1I>FEN:2!Y96YI
M9&5N(&%D;&%N9/UR_6QA;?UY;W(Z("5S`%9&4R!D;W-Y87/]("(E<R(@>65N
M:61E;B!A9&QA;F3]<OUL86W]>6]R+@`E<R\E<R!61E,@9&]S>6%S_2!Y96YI
M9&5N(&%D;&%N9/UR_6QA;?UY;W(N`%9&4R!D;W-Y87/]('EE;FED96X@861L
M86YD_7+];&%M_7EO<BX`)VUK:7-O9G,G(.=A;/W^=/UR_6QA;?UY;W(N`$)U
M(%=O<F0@8F5L9V5S:2#G979I<FEL:6QE;6EY;W(N`%9&4R!D;W-Y87/]("(E
M<R(@>6%Z_6QA;?UY;W(N`%9&4R!D;W-Y87/]('EA>OUL86W]>6]R("AC;W!Y
M*"D@8F'^87+]<_UZ(&]L9'4I+@!61E,@9&]S>6$@=F5R:7-I('EA>OUL86W]
M>6]R+@!!;'3];OT@YVEZ`$1E\&G^:6ML:6ML97)I($=E<FD@06P`4V]N(&5Y
M;&5M:2!G97)I(&%L`$)A\&QA;G3]9&$@<W5N=6-U9&%N(&)E:VQE;FUE>65N
M('EA;OUT.B``4W5N=6-U9&%N(&)E:VQE;FUE>65N('EA;OUT.B``1&]L9'5R
M=6QM86W]_@!5;FEC;V1E("A55$8M."D`0FER;&7^:6L@07)A<"!%;6ER;&EK
M;&5R:0!":7)L9?YI:R!+<F%L;/UK`$%M97)I:V$@0FER;&7^:6L@1&5V;&5T
M;&5R:0!!;65R:6MA($)I<FQE_FEK($1E=FQE=&QE<FEN:6X@2_SG_&L@57IA
M:R!!9&%L87+]`$)I<FEM;&5R`$)I;&EN;65Y96X`0FEL:6YM97EE;B!A<&EM
M<V=I9"`H05!)($UE<V%J($E$*0!":6QI;FUE>65N(&-L:6US9VED("C=<W1E
M;6-I(&UE<V%J($E$*0!":6QI;FUE>65N(&MU;&QA;OUC_2!A9/T@=F5Y82!P
M87)O;&$N`-YU(&%N:VD@]O!E;FEN(&)A\/UN_2#G]GH`W7-I;7-I>@!!>7+]
M8V%L_6MS_7H@8F5T:6ML97(@<')O9W)A;7-A;"!O;&%R86L@2V5S+TMO<'EA
M;&$O66%P_?YT_7(G82!G_'9E;FQI:R!N961E;FEY;&4@97)I_F5M97IL97(N
M($)E=&EK;&5R:6X@<&%N;WEA(&YA<_UL('5L8?YA8V'P_6[](&?V<W1E<F5N
M(&UO>FEL;&$N;W)G('1E:VYI:R!N;W1U;G4@9_9R;65K(&GG:6X@159%5"!I
M('3]:VQA>?UN+@!"96QI<G1I;&UI_B!R96YK=&5N('9A>F=EYP!$97-T96ML
M96YM97EE;B!5>F%N=/T`1_QN8V5L;&4`1_QN8V5L;&4Z("5S`$MU;&QA;OUC
M_7G](&?\;F-E;&QE`%G\:W-E;'1M92!B971I\&D@<VEL:6QN9&DN`%G\:VQE
M`$+\=/QN('5Y9W5L86UA;&%R_6X@87EA<B!D;W-Y86QA<OT@<W5N=6-U>6$@
M>?QK;&5N9&DN`$+\>?QK(&QA=&EN(&AA<F9L97)I`$+\>?QK(')O;6$@<F%K
M86UL87+]`%5R=6=U87D`2W5L;&%N.B`E<P!34TP@:W5L;&%N`$MU;&QA;OUC
M_2!A9/UN_7HO<&%R;VQA;OUZ($E-4U`@<W5N=6-U(&GG:6X@9F%R:VS](&ES
M92!K=6QL86[];BX`)7,@:W5L;&%N_6/]<_T@)7,@:>=I;B!D;_!R=6QA;F%M
M863]+@!+=6QL86[]8_T@6?9N971I;6D`2W5L;&%N_6/](%-EYV5N96ML97)I
M`$MU;&QA;OUC_2!+87G]=`!"=2!S:71E(&GG:6X@:W5L;&%N_6/](&MA>63]
M('-EYVEL;65Z(&O];/UN;?W^=/UR+@!+=6QL86[]8_T@063]`$MU;&QA;OUC
M_2!!9/TZ`$MU;&QA;OUC_2!A9/TZ(`!3:7-T96UD96MI(&MU;&QA;OUC_6QA
M<CH`UGIB96MI<W1A;@!61E,@9&EZ:6YI('EO:RX`5&%T:6P`1V7G97)L:2!K
M;VYU;6QA<OUN(&GG97)D:6ML97)I.@!'9>=E<FQI;&EK`-YU(&%N9&%N(&ET
M:6)A<F5N(&1A:VEK82!D9?!E<FD`1&7P97)L97(`1&7P97)L97)I;B!S9>=I
M;&5C9?!I`%9A;G5A='4`1&7P:?YK96X`5F5N97IU96QL80!$;_!R=6QA;6$@
M8F'^87+]<_UZ(&]L9'4@+2!B=2!I;&5T:2!K=7)C86QA;FW]_B!O;&%B:6QI
M<BX@(`!3_'+\;0!3_'+\;2!+;VYT;VS\`$3\_F5Y($AI>F$`1/S^97D@>6%S
M=/UK;&%M80!$_/YE>3H`QV]K(%G\:W-E:P!6:65T;F%M`%9I971N86UC82`H
M5DE30TE)*0!']G+\;G3\;&4@)7,`0FER(&3]_B!W96(@<V%Y9F%S_2!G]G+\
M;G3\;&4`)7,@;VQA<F%K(&?V<OQN=/QL90!"<FET86YY82=Y82!A:70@5FER
M9VEN($%D86QA<OT`06UE<FEK82!":7)L97+^:6L@1&5V;&5T;&5R:2=N92!A
M:70@5FER9VEN($%D86QA<OT`1_9R_/X`1_9R_/XZ`%--5%`@>6]L=7EL82!6
M;V1A9F]N92#==&%L>6$`5T%23@!564%222$A(25S(-W'W4Y$14X@0D54W=#=
M($5,(-U,12#'24M!4E1)3BX`5V%L;&ES('9E($9U='5N80!5>6%R_0#'<OX`
M2&%V82!486AM:6YI`$AA=F$@=F5R:7-I('-A\&QA>?UC_7/]`%=E871H97(N
M8V]M`%=E8@!796(@4VET97-I`$AA9G1A;/UK`$AO_F=E;&1I;FEZ`"5S($AO
M_F=E;&1I;FEZ`$AO_F=E;&1I;FEZ+"`E<P!"873]("A)4T\M.#@U.2TQ*0!"
M873]("A)4T\M.#@U.2TQ-2D`0F%T_2!386AR80`E<R!G:7)I_G1E;B!S;VYR
M82!H86YG:2!U>6=U;&%M87G](&?V<OQN=/QL97-I;C\`4_UN_7)L87G]8_T@
M:V%R86MT97(@;F5D:7(_`$%K=&%R_6T@:V%R86MT97)I(&YE9&ER/P!(86YG
M:2!%=G)E`%IE;F=I;B!-971I;B!D_'IE;FQE>6EC:7-I(&GG:6X@:&%N9VD@
M=7EU;6QU(&5K;&5R('-EYVEL96)I;&ER(&O];/UN<_UN+@!'96YI_FQI:P!#
M4U,@8FER:6UI>6QE(&=E;FG^;&EK`%-O;&1A:VD@)7,@;65N_'/\;OQN(&=E
M;FG^;&GP:2`H8FER('-O;G)A:VD@9VER:?YT92!E=&MI;B!O;&%C86LI.@#'
M:7IE;&=E;FEN(&=E;FG^;&GP:0!'96YI_FQI:R!B:7)I;6D`1V5N:?YL:6LZ
M`%=I:VD`4OQZ9V%R`$5R:V5N(%-A871L97)D92!2_'IG87(`2VYO="!B:7)I
M;6EN9&4@<OQZ9V%R(&C]>OT`4OQZ9V%R.@!2_'IG87(Z(`!":6QG96QI:P#=
M_@#=_B!!9')E<VD`W?X@5&5L969O;G4`6"U2968`6#4P.78S(%1E;65L($O]
M<_UT;&%M86QA<OT`6#4P.78S($=E;FG^;&5T:6QM:?X@06YA:'1A<B!+=6QL
M86[];?T`6#4P.78S(-9T96MI($MO;G4@063]`%@U,#EV,R!+;VYU($%N86AT
M87(@5&%N_73]8_US_0!8-3`Y=C,@=7IA;G3];&%R_0!960!965E9`%EA:&]O
M(2!H87)I=&%S_0!9_6QL_6L`665M96X`179E=`!%=F5T+"!+86)U;"!%9&EY
M;W)U;0!-153=3B!-3T153D1!4TE.25HN(%L\/ET@9/SP;65L97)I;FD@:W5L
M;&%N87)A:R!765-)5UE'(&?V<OQN_&W\;F4@9/9N_&XN`$1O\')U;&%N86UA
M9/UN_7HN`"=<)R!K87)A:W1E<FD@=&%M(&%D_6[]>F1A(&)U;'5N86UA>BX`
M1V7G97)L:2!B:7(@96QE:W1R;VYI:R!P;W-T82!A9')E<VD@9VER;65D:6YI
M>BX`)7,@:>=I;F1E(&MA<O[];/UK(&=E;&5N(&%L86YL87)L82`H:>=E<FDI
M(&%K=&%R_6QA;B!D;W-Y861A:VD@86QA;FQA<OT@9?YL9?YT:7)M961I;FEZ
M+@#'_6O]_B!Y87!M863];OUZ+@!'9>=E<FQI(&)I<B!C97`@=&5L969O;G4@
M;G5M87)A<_T@9VER;65L:7-I;FEZ+"!S87G];&%R('9E('-EYV5N96ML:2!O
M;&%R86L@=6QU<VQA<F%R87/](&%R86UA(/9N96MI("<K)R``1V7G97)L:2!B
M:7(@9&7P97(@9VER;65L:7-I;FEZ+@#<>64@:V%Y9/T@>6%P86)I;&UE:R!I
MYVEN(&)I<B!697)I0?!A8_T@>6%P_6QA;F3]<FUA;/US_6[]>BX`5D93('-O
M;B!A_F%M87/];OT@>6%P_6QA;F3]<FUA;/US_6[]>BX`4')O8FQE;2!R87!O
M<G4@9_9N9&5R;65D96X@]FYC92!S;W)U;G4@=&%R9FD@971M96QI<VEN:7HN
M`$)U(&)A\&QA;G3];OUN(&?V<W1E<F1I\&D@8FER(%523"!G:7)M96QI<VEN
M:7H`4VEL:6YM97-I(&GG:6X@8FER('-U;G5C=2!S9>=M96QI<VEN:7HN`%1E
M;6EZ;&5N;65S:6X@:>=I;B!B:7(@:W5L;&%N_6/](&%D_2!B96QI<G1M96QI
M<VEN:7HN`%-I;&EN;65S:2!IYVEN(&)I<B!K=6QL86[]8_T@863](&)E;&ER
M=&UE;&ES:6YI>BX`16ML96YM97-I(&GG:6X@8FER(&MU;&QA;OUC_2!A9/T@
M8F5L:7)T;65L:7-I;FEZ+@!'_&YC96QL96YM97-I(&GG:6X@8FER(&MU;&QA
M;OUC_2!A9/T@8F5L:7)T;65L:7-I;FEZ+@!'97+G96ML9?YT:7)I;&5C96L@
M8FER(&5Y;&5M(&)E;&ER=&UE;&ES:6YI>BX`665N:2!K871E9V]R>2!A9/T@
M9VER;65L:7-I;FEZ+@`E<R!O='5R=6UU;G5N('/\<F5S:2!D;VQD=2X@3/QT
M9F5N('1E:W)A<B!G:7)I_B!Y87#];BX`16QE:W1R;VYI:R!0;W-T82!!9')E
M<VEN:7H`2VEM9&5N.B!A9')E<SH`0FEL9VEL97)I;FEZ`"5S(&]T=7)U;75N
M=7IU;B!B8?YL86YG_6/];F1A(-UN=&5R;F5T($%D<F5S:6YI;FEZ(&1E\&G^
M=&DN($?\=F5N;&GP:6YI>FD@:V]R=6UA:R!IYVEN+"!Y96YI9&5N(&=I<FG^
M('EA<&UA;/US_6[]>BX`063];OUZ`$MI;6QI:R!D96YE=&EM:6YI>B!K=6QL
M86[]8_T@;&ES=&5L96UE>6D@9&5S=&5K;&5M96UE:W1E9&ER('9E>6$@8G4@
M]GIE;&QI:R!B:7(@;F5D96X@>?QZ_&YD96X@<V7G:6QE;65Z(&O];/UN;?W^
M=/UR+@`E<R!O='5R=6UU;G5Z=6X@8F'^;&%N9_UC_6YD82!T87)A>?UC_6[]
M>B!D9?!I_G1I+B!'_'9E;FQI\&EN:7II(&MO<G5M86L@:>=I;BP@>65N:61E
M;B!G:7)I_B!Y87!M86S]<_UN_7HN`%1A<F%Y_6/];OUZ(&)U(/9Z96QL:?!I
M(&1E<W1E:VQE;65M96MT961I<BX`6F%M86X@1&EL:6UI;FEZ.@#6;B!T86[]
M;6S](&MI;6QI\&EN:7HZ`%1A;2!!9/UN_7HZ`"5S(&GG:6X@>65N:2!P87)O
M;&%N_7HZ("5S`%-EYV5N96ML97)I;FEZ(&)U(&]T=7)U;75N('/\<F5S:2!I
MYVEN9&4@9_QN8V5L;&5N9&DN`%-EYV5N96ML97)I;FEZ(&?\;F-E;&QE;F1I
M+@!087)O;&%N_7H@<_UF_7)L86YD_2X`4&%R;VQA;OUZ('/]9OUR;&%N9/TL
M(&5L96MT<F]N:6L@<&]S=&%N_7K](&MO;G1O;"!E9&EN('9E('EE;FD@<&%R
M;VQA;OUZ;&$@9VER:?X@>6%P_6XN`%5Z86MT86MI('-U;G5C=6QA<OUN_7HZ
M`%EU9V]S;&%V>6$`6F%I<F4`6F%M8FEA`%II;6)A8G9E`$C]>FS]`%M!;/UN
M=/T@365T;FD@4V%K;&%=`%M0<F]B;&5M(%)A<&]R=5T`6T%L_6YT_2!-971N
M:2!']G-T97(@+0!;06S];G3]($UE=&YI($?V<W1E<B`M("5S('-A=/UR70`E
M<R\E<R!S873]<@!?6?9N971I;0!?0TQ)`%]697)I0?!A8_T`4V%T_7+](%]3
M:6P`7T=R=7!L87(`66%R7V3];0!']G+\;G3\(-9?>F5L;&EK;&5R:2XN+@!'
M:5]R:?X`Q_U?:_W^`%]"8?!L86YT_7G]($1E\&G^=&ER+BXN`%]39>=E;F5K
M;&5R`%](86ML87(`0F'P;&%?;G3]>?T@4VEL+BXN`%]!>6%R;&%R`,=I>F5?
M;&=E(-9Z96QL:6ML97)I+BXN`$M?=6QL86[]8_UL87(`861R97,@9&5F=&5R
M:0!T86MV:6T`_6S];6S]`&)U<F%Y82!T_6ML87G];@!D_/[\>6]R`&1O<WEA
M`"5S("@E<RD@9&5N("5S("5S(&1E`&@Z`$%C:6P`365T;F4@9_9M_&S\`'-A
M=/UR;&%R70!M:VES;V9S($E33R!Y87!A<FME;B!H871A(&MO9'4Z)60N`&%D
M`&=E<N=E:VQE_G1I<FEL;65D:0!H96[\>B!G97+G96ML9?YT:7)I;&UE9&D`
M;F]T(&1E9G1E<FD`>?QZ9&4`<F5S:6T@8FER:6UI`'G\:W-E;&EY;W(`9F%R
M:VQA<OT@9_9S=&5R`$A45%`@>6]L=7EL82!S;7,R96UA:6P`<V%B:70`9_9R
M978@;&ES=&5S:0!P87)O;&%Y_2!D;_!R=6QA;6%K(&GG:6X@:6MI(&1E9F$@
M9VER:6X`8FER;&7^=&ER:6QM:?X`861L86YD_7+];&UA;?W^`&MU;&QA;OUC
M_2!S9>=I;6D`=D-A<F0`=SH`=V5A=&AE<BYC;VT`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&]C86QE+W5K7U5!+P``````````````````````````````
M```````````````````````````````````````````````````P,#`P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U-``P,C`Q
M,C(`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O=6M?54$O:&5L<"YX
M;6P`````````````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,S(P
M`#$P-3$U-#,S-S4T`#`R,34W,@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D
M2&]R9&4Z(&AO<F1E+VQO8V%L92]U:U]502]H96QP+GAM;"QV(#$N,B`R,#`T
M+S`U+S(W(#(P.C(R.C$R(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y
M(&ED/2)S=6UM87)Y(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!0;W)T86P@
M4&%G93PO=&ET;&4^"B`\<&%R83X*("!4:&ES('!O<G1A;"!P86=E('!R;W9I
M9&5S(&$@<75I8VL@<W5M;6%R>2!O9B!A;&P@>6]U<B!I;7!O<G1A;G0*("!I
M;F9O<FUA=&EO;BX@1F]R(&5X86UP;&4L(&ET(&UI9VAT('-H;W<@:&]W(&UA
M;GD@;F5W(&4M;6%I;"!M97-S86=E<R!Y;W4*("!H879E(&EN('EO=7(@24Y"
M3U@L('5P8V]M:6YG(&5V96YT<R!O;B!Y;W5R(&-A;&5N9&%R+"!T87-K<R!O
M;B!Y;W5R('1O+61O"B`@;&ES="P@:&5A9&QI;F5S(&9R;VT@<V5L96-T960@
M;F5W<R!S97)V:6-E<RP@86YD('-O(&]N+B`@36%N>2!O9B!T:&5S90H@('-U
M;6UA<FEE<R!W:6QL(&-O;G1A:6X@<75I8VL@<VAO<G1C=71S('1O(&-O;6UO
M;B!F=6YC=&EO;G,L('-U8V@@87,*("!C;VUP;W-I;F<@82!N97<@;6%I;"!M
M97-S86=E+"!C<F5A=&EN9R!A(&YE=R!C86QE;F1A<B!E=F5N="!O<B!T87-K
M+"!E=&,N"B`\+W!A<F$^"B`\<&%R83X*("!4:&4@8V]N=&5N=',@;V8@=&AI
M<R!P;W)T86P@<&%G92!A<F4@8W5S=&]M:7IA8FQE('9I82!T:&4@3&%Y;W5T
M(&)U='1O;BX*("!&;W(@97AA;7!L92P@>6]U(&-A;B!C:&]O<V4@=VAI8V@@
M:71E;7,@=&\@:6YC;'5D92!O;B!T:&ES('!O<G1A;"!P86=E(&%S"B`@=V5L
M;"!A<R!I;B!W:&EC:"!O<F1E<B!T:&5Y(&%R92!S:&]W;BX*(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](FYA=F)A<B(@<W1A=&4](FYE=R(^"CQT
M:71L93Y4:&4@07!P;&EC871I;VX@3F%V:6=A=&EO;B!"87(\+W1I=&QE/@H@
M/'!A<F$^"B`@070@=&AE(&QE9G0@:&%N9"!S:61E(&]F('1H92!W96(@<&%G
M92!I<R!T:&4@87!P;&EC871I;VX@;F%V:6=A=&EO;B!B87(N"B`@0VQI8VL@
M;VX@=&AE(&EC;VYS(&]N('1H:7,@;F%V:6=A=&EO;B!B87(@=&\@<75I8VML
M>2!A;F0@96%S:6QY('-W:71C:`H@(&)E='=E96X@=&AE(&%V86EL86)L92!A
M<'!L:6-A=&EO;G,N"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P
M<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$;R!-86EN=&5N86YC93PO=&ET
M;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O('!E<F9O
M<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;BP@8VAE8VL@=&AI
M<R!B;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F
M<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L
M93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($-O;F9I<FT@36%I;G1E;F%N
M8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T
M;R!C;VYF:7)M(&%L;"!M86EN=&5N86YC92!T87-K<R!B969O<F4@=&AE>2!A
M<F4@<G5N+"!C:&5C:R!T:&ES(&)O>"X@268@;&5F="!U;F-H96-K960L(&%L
M;"!M86EN=&5N86YC92!O<&5R871I;VYS('1H870@;F5E9"!T;R!B92!R=6X@
M=VEL;"!B92!P97)F;W)M960@875T;VUA=&EC86QL>2!W:71H(&YO(&-H86YC
M92!T;R!C86YC96P@;VX@;&]G:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO
M:&5L<#X*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W5K7U5!+TQ#7TU%4U-!1T53
M+P``````````````````````````````````````````````````````````
M```````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q
M-30S,S<U-``P,C$W,#<`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O
M=6M?54$O3$-?34534T%'15,O:&]R9&4N;6\`````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#$Q,3$P`#$P-3$U-#,S-S4T`#`R,S,S-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#>$@25`````%`````<````
MG`(``&L````<!0```````,@&```H````R08```@```#R!@``#P```/L&```(
M````"P<```@````4!P``&0```!T'```'````-P<```X````_!P``!0```$X'
M```1````5`<```@```!F!P``%0```&\'```*````A0<```P```"0!P``!P``
M`)T'```0````I0<```(```"V!P``!0```+D'```0````OP<```8```#0!P``
M%````-<'```%````[`<```T```#R!P``!0`````(```+````!@@```\````2
M"````P```"((```$````)@@```P````K"```"@```#@(```%````0P@``!(`
M``!)"```$````%P(```0````;0@``!H```!^"```!@```)D(```'````H`@`
M``(```"H"```!````*L(```/````L`@```<```#`"```!P```,@(```$````
MT`@```4```#5"```"````-L(```5````Y`@``!X```#Z"```!0```!D)```H
M````'PD``"D```!("0``$P```'()```+````A@D```4```"2"0``$0```)@)
M```$````J@D```P```"O"0``&@```+P)```7````UPD``!<```#O"0``$P``
M``<*```0````&PH``!<````L"@``!P```$0*```%````3`H```,```!2"@``
M#````%8*```(````8PH``!0```!L"@``!P```($*```&````B0H```L```"0
M"@``#````)P*```*````J0H```(```"T"@``!@```+<*``!%````O@H``"8`
M```$"P``)0```"L+```0````40L``&<!``!B"P``.@```,H,```)````!0T`
M`!H````/#0``"P```"H-```2````-@T``"(```!)#0``!@```&P-```/````
M<PT```D```"##0``#@```(T-```/````G`T``!\```"L#0``%````,P-```-
M````X0T```@```#O#0``%````/@-```"````#0X```<````0#@``$````!@.
M```'````*0X``!`````Q#@``!P```$(.```3````2@X```<```!>#@``#0``
M`&8.```2````=`X```0```"'#@``"````(P.```.````E0X``!````"D#@``
M!0```+4.```4````NPX``!$```#0#@``&0```.(.```I````_`X```8````F
M#P``!0```"T/```"````,P\```H````V#P``#P```$$/```$````40\```@`
M``!6#P``!````%\/```'````9`\```8```!L#P``&````',/```?````C`\`
M``<```"L#P``*0```+0/```N````W@\```T````-$```#````!L0```(````
M*!```!0````Q$```!````$80```.````2Q```!D```!:$```%0```'00```5
M````BA```",```"@$```%P```,00```9````W!````<```#V$```!0```/X0
M```#````!!$```\````($0``$0```!@1```6````*A$```4```!!$0``!P``
M`$<1```-````3Q$```T```!=$0``#P```&L1```"````>Q$```<```!^$0``
M10```(81```Q````S!$``#$```#^$0``%P```#`2```!`````````$T````=
M````10```!4````(````(@```#D``````````````!P```!'`````````!0`
M```N`````````#L````V````20```"8````Q````````````````````)P``
M`!X````M````#0`````````I``````````(`````````3P```"4```!"````
M3```````````````*````#X````8````'P```!8````;````(P````D````P
M````-0````0````+````!0````P````/````+P```$`````:````1@```$L`
M``!.````,@```$,````]````!@```"L``````````````#\```!(````.```
M``H````````````````````\``````````X`````````$P```!$````@````
M$````"$```!*``````````,```!0````$@```#0`````````````````````
M````%P```$$````S````&0```"H`````````)``````````'````-P```$0`
M```Z````+``````E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER
M;6%T:6]N`#(T(&AO=7)S`$%D9"!A(&YE=R!U<V5R.@!!9&0@<&%I<@!!9&0@
M=7-E<@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061M:6YI
M<W1R871I;VX`06QI87,`079A:6QA8FQE(&9I96QD<SH`0FER=&AD87D`0V%N
M8V5L(%!R;V)L96T@4F5P;W)T`$-E;&P@4&AO;F4`0VQO<V4@5VEN9&]W`$-O
M;7!A;GD`0V]N9FER;2!087-S=V]R9`!$1`!$86EL>0!$969A=6QT($ED96YT
M:71Y`$1E;&5T90!$97-C<FEB92!T:&4@4')O8FQE;0!%;6%I;`!%;7!T>2!R
M97-U;'0N`$5R<F]R`$5V97)Y($QO9VEN`$5X86UP;&4@=F%L=65S.@!&87@`
M2&5L<`!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;W)D90!);7!O<G1E9"!F
M:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!,:7-T($AE;'`@5&]P:6-S`$QI
M<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QO9R!I;@!,;V<@;W5T`$U-`$UA
M:6P`36%T8VAI;F<@9FEE;&1S`$UE<W-A9V4`36]N=&AL>0!.86UE`$YO=&5S
M`%!A<W-W;W)D`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!097)F;W)M($UA:6YT
M96YA;F-E($]P97)A=&EO;G,`4&AO;F4`4&QE87-E('!R;W9I9&4@82!S=6UM
M87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N
M86UE(&%N9"!P87-S=V]R9`!0<F]B;&5M($1E<V-R:7!T:6]N`%)E;6]V92!P
M86ER`%)E<V5T`%)E='5R;B!T;R!/<'1I;VYS`%)O;&4`4V%V92!/<'1I;VYS
M`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F
M;W)M870Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;F0@4')O8FQE;2!2
M97!O<G0`4VMI<"!-86EN=&5N86YC90!3<&5C:6%L($-H87)A8W1E<B!);G!U
M=`!3=6-C97-S`%1I=&QE`%523`!5;F1O($-H86YG97,`57-E<FYA;64`57-E
M<G,@:6X@=&AE('-Y<W1E;3H`5V%R;FEN9P!7965K;'D`5V5L8V]M92P@)7,`
M5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`65D`665A<FQY`%EO=2!M=7-T(&1E
M<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R
M;V)L96T@<F5P;W)T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@
M<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N
M`%M0<F]B;&5M(%)E<&]R=%T`4')O:F5C="U)9"U697)S:6]N.B!(;W)D92!V
M,BXQ"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G
M"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M
M4F5V:7-I;VXM1&%T93H@,C`P,BTP,2TP-2`Q-CHQ-2LP,C`P"DQA<W0M5')A
M;G-L871O<CH@06YD<FEY($MO<'ES='EA;G-K>2`\86YR:4!P;VQY;F5T+FQV
M:78N=6$^"DQA;F=U86=E+51E86TZ(%5K<F%I;FEA;B`\=V5B;6%S=&5R0'!O
M;'EN970N;'9I=BYU83X*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E
M.B!T97AT+W!L86EN.R!C:&%R<V5T/4M/23@M50I#;VYT96YT+51R86YS9F5R
M+45N8V]D:6YG.B`X+6)I=`H`[]#%TL'#IM$@T-+/QJ;,P<O4R=[.S\?/(,_"
MT\S5Q\_7U=?!SL[1("5S("T@\*;$U-?%TL36Q<[.T0`R-"#'S\3)SLD`Y,_$
MP=3)(,[/U\_'SR#+S]+)T]35U\'>P3H`Y,_$P=3)(-#!TM4`Y,_$P=3)(,O/
MTLG3U-77P=[!`.3/Q,'7P<[.T2#+S]+)T]35U\'>IM<@VL'"S]+/SL7.Q2X`
MX<32Q=/!`.'$S:;.IM/4TM77P<[.T0#PT\77Q,_.ILT`Y,_3U-70SJ8@T,_,
MT3H`Y,7.V"#.P=+/Q-;%SL[1`/>FQ,VFSLG4R2#0S]>FQ,_-S,7.SM$@T-+/
MPLS%S<D`\]2FS-C.R<O/U\G*(-3%S,7&S\X`^L'+TLG4R2#7ILO.SP#KS\W0
MP<ZFT0#PIL34U\72Q-;%SL[1(-#!TL_,P`#DY`#]S\3%SL[/`._3SL_7SL$@
MIM#/T]3!T]@`]\G4Q=+4R0#OT,G;IM38(-#2S\+,Q<W5`.4MT,_;U,$`\,_2
MS];.ILH@TL7:U<S8U,'4+@#PS\W)S,O!`.O/UL[/Q\\@U\C/Q-4`Y,'.IB#$
MS-$@T-+)R\S!Q-4Z`.;!R],`Y,_0S\W/Q\$`Y,_-P=O.T2#!Q-+%T\$`Y,_-
MP=O.ILH@U,7,Q<;/S@!(;W)D90"VS=#/TM3/U\'.Q2#0S\S%.B`E<P"VS=#/
MTM3/U\'.IB#0S\S1.@#PQ=+%S*;+(-+/VL2FS*;7(.3/T,_-S\?)`/#%TL7'
MS-'$(-/0R=/+U2#+S]+)T]35U\'>IM<@VL'"S]+/SL7.R<HN`/?7ILK4R0#W
MR<K4R0#M[0!)35`MT,_2U,',`/>FQ-#/UZ;$SJ8@T,_,T0#LR=/4`/W/S:;3
MT</1`+;-8-$`[L_4P=3+R0#PP=+/S-@`\,'2S\S8(,W5T\G4V"#3T*;7T,'3
MU,DN`/?)R\_.P=3)(-#2S\:FS,'+U,G>SJ8@S]#%TL'#IJ<`],7,Q<;/S@#B
MU<38+<S!T\O!+"#$P<K4Q2#+S]+/U,O)RB#/T,G3(-#2S\+,Q<W)+@#BU<38
M+<S!T\O!+"#7R\'6IM38(,[!VM?5(,O/TLG3U-77P=[!(*8@T,'2S\S8`._0
MR=,@T-+/PLS%S<D`]\G4Q=+4R2#0P=+5`._>R=/4R=3)`/#/U\72SM74R=/1
M(,3/(._0PZ;*`/+/S-@`^L+%TL7'U,D@S]##IJ<`]\G"Q=*FU-@@TL_:Q*;,
MP-?!WB#$P=3).@#WR<+%TJ;4V"#&S]+-P=0@Q,'4R3H`]\G"Q=*FU-@@QL_2
MS<'4(-[!T]4Z`/>FQ*;3S,'4R2#0S]>FQ,_-S,7.SM$@T-+/(-#2S\+,Q<W5
M`/#2S]#5T]3)U,D@T-+/QJ;,P<O4R<O5`/?7IL0@\]#%PZ;!S-C.R<@@T\G-
MU\_,IM<`]=/0IMO.SP#TR=35S`!54DP`\\O!T]77P=3)(-K-IL[)`.[!VM?!
M(,O/TLG3U-77P=[!`.O/TLG3U-77P=ZF(-<@T\G3U,7-ICH`]=?!Q\$`_<_4
MR=;.T0#WIM3!P"#WP=,L("5S`/+/PL_>P2#!Q-+%T\$`\L_"S][)RB#4Q<S%
MQL_.`/+R`/W/TJ;>SL\`]\D@T,_7R<[.IB#/T,G3P=3)(-#2S\+,Q<W5+"#0
MQ=+;(,ZFUB#7IL33R<S!U,D@T,_7IL3/S<S%SL[1(-#2SR#.Q:<N`/?!S2#3
MS*;$(-?+P=K!U,D@SL':U]4@R\_2R=/4U=?!WL$@Q,S1(-?)Q,',Q<[.T2X`
M]\'-(-/,IL0@U\O!VL'4R2#.P=K7U2#+S]+)T]35U\'>P2#$S-$@Q,_$P=?!
MSL[1+@!;\,_7IL3/S<S%SL[1(/#2S\+,Q<W)70``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&]C86QE+WIH7T-.+P``````````````````````````````````````````
M```````````````````````````````````````P,#`P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U-``P,C`Q,3<`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L;V-A;&4O>FA?0TXO:&5L<"YX;6P`````````
M````````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,S(P`#$P-3$U-#,S
M-S4T`#`R,34V-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z(&AO
M<F1E+VQO8V%L92]Z:%]#3B]H96QP+GAM;"QV(#$N,B`R,#`T+S`U+S(W(#(P
M.C(R.C$R(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)S=6UM
M87)Y(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!0;W)T86P@4&%G93PO=&ET
M;&4^"B`\<&%R83X*("!4:&ES('!O<G1A;"!P86=E('!R;W9I9&5S(&$@<75I
M8VL@<W5M;6%R>2!O9B!A;&P@>6]U<B!I;7!O<G1A;G0*("!I;F9O<FUA=&EO
M;BX@1F]R(&5X86UP;&4L(&ET(&UI9VAT('-H;W<@:&]W(&UA;GD@;F5W(&4M
M;6%I;"!M97-S86=E<R!Y;W4*("!H879E(&EN('EO=7(@24Y"3U@L('5P8V]M
M:6YG(&5V96YT<R!O;B!Y;W5R(&-A;&5N9&%R+"!T87-K<R!O;B!Y;W5R('1O
M+61O"B`@;&ES="P@:&5A9&QI;F5S(&9R;VT@<V5L96-T960@;F5W<R!S97)V
M:6-E<RP@86YD('-O(&]N+B`@36%N>2!O9B!T:&5S90H@('-U;6UA<FEE<R!W
M:6QL(&-O;G1A:6X@<75I8VL@<VAO<G1C=71S('1O(&-O;6UO;B!F=6YC=&EO
M;G,L('-U8V@@87,*("!C;VUP;W-I;F<@82!N97<@;6%I;"!M97-S86=E+"!C
M<F5A=&EN9R!A(&YE=R!C86QE;F1A<B!E=F5N="!O<B!T87-K+"!E=&,N"B`\
M+W!A<F$^"B`\<&%R83X*("!4:&4@8V]N=&5N=',@;V8@=&AI<R!P;W)T86P@
M<&%G92!A<F4@8W5S=&]M:7IA8FQE('9I82!T:&4@3&%Y;W5T(&)U='1O;BX*
M("!&;W(@97AA;7!L92P@>6]U(&-A;B!C:&]O<V4@=VAI8V@@:71E;7,@=&\@
M:6YC;'5D92!O;B!T:&ES('!O<G1A;"!P86=E(&%S"B`@=V5L;"!A<R!I;B!W
M:&EC:"!O<F1E<B!T:&5Y(&%R92!S:&]W;BX*(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](FYA=F)A<B(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@
M07!P;&EC871I;VX@3F%V:6=A=&EO;B!"87(\+W1I=&QE/@H@/'!A<F$^"B`@
M070@=&AE(&QE9G0@:&%N9"!S:61E(&]F('1H92!W96(@<&%G92!I<R!T:&4@
M87!P;&EC871I;VX@;F%V:6=A=&EO;B!B87(N"B`@0VQI8VL@;VX@=&AE(&EC
M;VYS(&]N('1H:7,@;F%V:6=A=&EO;B!B87(@=&\@<75I8VML>2!A;F0@96%S
M:6QY('-W:71C:`H@(&)E='=E96X@=&AE(&%V86EL86)L92!A<'!L:6-A=&EO
M;G,N"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD;U]M
M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC
M97,Z($UA:6YT96YA;F-E.B!$;R!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\
M<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O('!E<F9O<FT@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;BP@8VAE8VL@=&AI<R!B;W@N"B`@
M("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC;VYF:7)M
M7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E
M;F-E<SH@36%I;G1E;F%N8V4Z($-O;F9I<FT@36%I;G1E;F%N8V4\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!C;VYF:7)M
M(&%L;"!M86EN=&5N86YC92!T87-K<R!B969O<F4@=&AE>2!A<F4@<G5N+"!C
M:&5C:R!T:&ES(&)O>"X@268@;&5F="!U;F-H96-K960L(&%L;"!M86EN=&5N
M86YC92!O<&5R871I;VYS('1H870@;F5E9"!T;R!B92!R=6X@=VEL;"!B92!P
M97)F;W)M960@875T;VUA=&EC86QL>2!W:71H(&YO(&-H86YC92!T;R!C86YC
M96P@;VX@;&]G:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&]C86QE+WIH7T-.+TQ#7TU%4U-!1T53+P``````````
M```````````````````````````````````````````````````````P,#`P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U-``P
M,C$W,#0`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O>FA?0TXO3$-?
M34534T%'15,O:&]R9&4N;6\`````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3<W
M-3,Q`#$P-3$U-#,S-S4T`#`R,S,V,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#>$@25`````'L$```<````]",``/L%``#,
M1P```````+A?```.````N5\```\```#(7P``"````-A?```,````X5\```0`
M``#N7P``#P```/-?```+`````V````X````/8```!0```!Y@```H````)&``
M``H```!-8```%0```%A@```2````;F````L```"!8```#@```(U@```*````
MG&````T```"G8```#@```+5@```&````Q&````\```#+8```&````-M@```,
M````]&````@````!80``+@````IA```:````.6$``#(```!480``.````(=A
M``!4````P&$``%$````58@``6@```&=B``!7````PF(``#0````:8P``!0``
M`$]C```&````56,``!$```!<8P``"````&YC```E````=V,``"````"=8P``
M#P```+YC```*````SF,```,```#98P``#P```-UC```4````[6,```D````"
M9```#0````QD```2````&F0```\````M9```#P```#UD```(````360``"0`
M``!69```"````'MD```9````A&0```<```">9```#````*9D```L````LV0`
M``X```#@9````P```.]D```+````\V0```<```#_9```!P````=E```%````
M#V4``!<````590``"@```"UE```/````.&4``!@```!(90``#@```&%E```4
M````<&4``!<```"%90``%P```)UE```3````M64```X```#)90``'P```-AE
M```'````^&4```8`````9@``"`````=F```/````$&8```H````@9@``$P``
M`"MF```+````/V8``!4```!+9@``%0```&%F```'````=V8```4```!_9@``
M%0```(5F```1````FV8```P```"M9@``.P```+IF```)````]F8```<`````
M9P``%`````AG```%````'6<``!`````C9P``$P```#1G```Y````2&<``"<`
M``""9P``+````*IG```J````UV<``"4````":```"@```"AH```&````,V@`
M``D````Z:```!P```$1H```O````3&@``#<```!\:```+@```+1H``!5````
MXV@``"T````Y:0``+0```&=I```M````E6D``$````##:0``(P````1J```C
M````*&H``"T```!,:@``,P```'IJ```5````KFH``!D```#$:@``*0```-YJ
M```D````"&L``!$````M:P``"@```#]K```0````2FL``!8```!;:P``%@``
M`')K```'````B6L```<```"1:P``%````)EK```*````KFL```@```"Y:P``
M!P```,)K```'````RFL```8```#2:P``!0```-EK```'````WVL```8```#G
M:P``"````.YK```.````]VL```H````&;```!````!%L```'````%FP```D`
M```>;```%@```"AL```(````/VP```T```!(;```!@```%9L```>````76P`
M`!$```!\;```"````(YL```-````EVP```P```"E;```!P```+)L```#````
MNFP```,```"^;```%P```,)L```(````VFP```0```#C;```"````.AL```(
M````\6P``"````#Z;```!@```!MM```&````(FT``!4````I;0``&````#]M
M```=````6&T``%0```!V;0``*0```,MM```*````]6T```X`````;@``"@``
M``]N```4````&FX``!@````O;@``'0```$AN```3````9FX``!0```!Z;@``
M!````(]N```&````E&X```4```";;@``!0```*%N```;````IVX``!H```##
M;@``$0```-YN```1````\&X``!P````";P``$````!]O```A````,&\``!$`
M``!2;P``#````&1O```&````<6\``!<```!X;P``"````)!O```%````F6\`
M``P```"?;P``!@```*QO```'````LV\```T```"[;P``!P```,EO```+````
MT6\```<```#=;P``!P```.5O```*````[6\```P```#X;P``$`````5P```%
M````%G```"4````<<```$P```$)P```[````5G```"````"2<```#````+-P
M```.````P'````H```#/<```#0```-IP```>````Z'```!L````'<0``(0``
M`"-Q```>````17$``!X```!D<0``&P```(-Q```>````GW$``#,```"^<0``
M+P```/)Q```2````(G(``"D````U<@``$@```%]R```6````<G(``"@```")
M<@``(````+)R```A````TW(``$$```#U<@``!P```#=S```&````/W,``!(`
M``!&<P``$P```%ES```2````;7,```<```"`<P``!````(AS```,````C7,`
M``\```":<P``$P```*IS```-````OG,```T```#,<P``!@```-IS```1````
MX7,``!<```#S<P``&P````MT```.````)W0```(````V=```!0```#ET```$
M````/W0```T```!$=```#@```%)T```#````870```@```!E=```#P```&YT
M```0````?G0```8```"/=```#````)9T```1````HW0``!D```"U=```#0``
M`,]T```'````W70``!0```#E=```"P```/IT```B````!G4``"\````I=0``
M"P```%EU```)````974``!D```!O=0``"P```(EU```7````E74``!<```"M
M=0``"0```,5U```6````SW4```\```#F=0``#@```/9U```(````!78```T`
M```.=@``)@```!QV``!#````0W8```@```"'=@``$@```)!V```(````HW8`
M``L```"L=@``+P```+AV```.````Z'8```8```#W=@```P```/YV```'````
M`G<```0````*=P``"@````]W```*````&G<```\````E=P``$````#5W```7
M````1G<``!$```!>=P``%P```'!W```%````B'<```L```".=P``!0```)IW
M```-````H'<``!L```"N=P``%P```,IW```)````XG<```X```#L=P``#0``
M`/MW```(````"7@```X````2>```$0```"%X```'````,W@```4````[>```
M!P```$%X```(````27@```8```!2>```$````%EX```0````:G@```\```![
M>```"P```(MX```/````EW@```P```"G>```#P```+1X```'````Q'@```8`
M``#,>```#P```--X```(````XW@``!,```#L>```'@````!Y```A````'WD`
M`"````!!>0``&0```&)Y```7````?'D``"4```"4>0``%P```+IY```;````
MTGD```T```#N>0```P```/QY```(`````'H```H````)>@``#````!1Z```$
M````(7H``!,````F>@``%````#IZ```,````3WH```D```!<>@``"P```&9Z
M```;````<GH```<```".>@``!P```)9Z```*````GGH```T```"I>@``"0``
M`+=Z```$````P7H``!@```#&>@``"@```-]Z``!\````ZGH```4```!G>P``
M!P```&U[```,````=7L```@```"">P``!@```(M[```(````DGL```(```";
M>P``!@```)Y[```-````I7L``!````"S>P``!````,1[```)````R7L``!``
M``#3>P``"0```.1[```)````[GL```4```#X>P``!@```/Y[```9````!7P`
M``<````??```!P```"=\```%````+WP```D````U?```"@```#]\```"````
M2GP```T```!-?```"0```%M\```&````97P``!(```!L?```"0```']\```'
M````B7P``!0```"1?```'0```*9\```&````Q'P```H```#+?```!````-9\
M```)````VWP```@```#E?```$0```.Y\```)`````'T```8````*?0``#0``
M`!%]```&````'WT```0````F?0``'@```"M]```%````2GT```X```!0?0``
M!@```%]]```A````9GT``!4```"(?0``!````)Y]```1````HWT```8```"U
M?0``(@```+Q]```=````WWT```0```#]?0``#`````)^```*````#WX```@`
M```:?@``"0```"-^```%````+7X```\````S?@``)````$-^```(````:'X`
M``H```!Q?@``!P```'Q^```@````A'X``"````"E?@``)@```,9^```9````
M[7X``"D````'?P``!P```#%_```*````.7\```\```!$?P``#````%1_```&
M````87\```\```!H?P``$@```'A_```0````BW\``!P```"<?P``#P```+E_
M```%````R7\``!````#/?P``"0```.!_```$````ZG\```L```#O?P``#```
M`/M_```/````"(```!D````8@```#P```#*````3````0H```!(```!6@```
M!P```&F````,````<8```"````!^@```%````)^````1````M(```!<```#&
M@```'````-Z````3````^X```!$````/@0``&@```"&!```>````/($``!H`
M``!;@0``$0```':!```7````B($``!4```"@@0``&0```+:!```$````T($`
M``<```#5@0``"P```-V!```&````Z8$```8```#P@0``!@```/>!```%````
M_H$```<````$@@``!P````R"```%````%((``!8````:@@``!@```#&"```&
M````.((```0````_@@``!````$2"```.````28(```P```!8@@``#````&6"
M```-````<H(```H```"`@@``#@```(N"```%````FH(``"@```"@@@``#```
M`,F"```/````UH(```H```#F@@``"````/&"```)````^H(``"L````$@P``
M"````#"#```F````.8,``!(```!@@P``#P```'.#```&````@X,```H```"*
M@P``"````)6#```@````GH,```D```"_@P``#````,F#```-````UH,```X`
M``#D@P``%@```/.#```1````"H0```8````<A```!@```".$```'````*H0`
M``<````RA```!P```#J$```6````0H0```T```!9A```!````&>$```%````
M;(0``!X```!RA```$````)&$```,````HH0```D```"OA```!P```+F$```*
M````P80```D```#,A```#@```-:$```0````Y80``!H```#VA```"@```!&%
M```)````'(4```P````FA0``#P```#.%```(````0X4```8```!,A0``!P``
M`%.%```%````6X4``$<```!AA0``#0```*F%```*````MX4```(```#"A0``
M!````,6%```E````RH4```,```#PA0``!0```/2%```J````^H4```H````E
MA@``!````#"&```*````-88```8```!`A@``"````$>&```(````4(8```0`
M``!9A@``!0```%Z&```%````9(8``!L```!JA@``+P```(:&```0````MH8`
M``H```#'A@``#P```-*&```*````XH8```D```#MA@``&P```/>&```8````
M$X<``!<````LAP``#@```$2'```#````4X<```<```!7AP``!P```%^'```*
M````9X<```<```!RAP``40```'J'```0````S(<```P```#=AP``&@```.J'
M``!*````!8@```8```!0B```!@```%>(```&````7H@``!\```!EB```"0``
M`(6(```8````CX@``!<```"HB```!@```,"(``!7````QX@``!,````?B0``
M$P```#.)```"````1XD```L```!*B0``#0```%:)```'````9(D``!0```!L
MB0``!@```(&)```(````B(D```X```"1B0``!P```*")```*````J(D```L`
M``"SB0``!P```+^)```)````QXD```D```#1B0``"@```-N)```'````YHD`
M``D```#NB0``!P```/B)```*`````(H``!(````+B@``"@```!Z*```)````
M*8H``!`````SB@``!P```$2*```2````3(H```0```!?B@``!P```&2*```%
M````;(H```4```!RB@``"P```'B*```4````A(H``!$```"9B@``&````*N*
M```<````Q(H``!D```#AB@``!P```/N*```%`````XL```T````)BP``"```
M`!>+```7````((L```L````XBP``$P```$2+```$````6(L```0```!=BP``
M#````&*+```)````;XL```4```!YBP``!P```'^+```%````AXL```0```"-
MBP``*0```)*+```R````O(L``"X```#OBP``,P```!Z,```S````4HP``#@`
M``"&C```$````+^,```3````T(P``"T```#DC```+0```!*-```Q````0(T`
M`"X```!RC0``+P```*&-```L````T8T``!,```#^C0``*P```!*.```:````
M/HX```D```!9C@``10```&..``!!````J8X```0```#KC@``%````/".```.
M````!8\``!,````4CP``&````"B/```&````08\```D```!(CP``"@```%*/
M```/````78\```X```!MCP``!0```'R/```(````@H\```8```"+CP``%```
M`)*/```1````IX\```X```"YCP```@```,B/```.````RX\```4```#:CP``
M!P```."/```&````Z(\```0```#OCP``*0```/2/```?````'I```%P````^
MD```%````)N0```'````L)````X```"XD```#````,>0```,````U)```!,`
M``#AD```'0```/60```9````$Y$```4````MD0``$0```#.1```1````19$`
M`"0```!7D0``%0```'R1```2````DI$```X```"ED0``&0```+21```(````
MSI$```D```#7D0``"````.&1```%````ZI$``!\```#PD0``!@```!"2```0
M````%Y(```@````HD@``"````#&2```L````.I(``!H```!GD@``"0```(*2
M```*````C)(``!4```"7D@``!0```*V2```4````LY(```0```#(D@``$```
M`,V2```>````WI(``"@```#]D@``"@```":3```1````,9,```L```!#DP``
M&@```$^3```4````:I,```0```!_DP``"P```(23```%````D),```8```"6
MDP``"````)V3```@````II,``$$```#'DP``&@````F4```H````))0``"D`
M``!-E```!@```'>4```%````?I0```@```"$E```*@```(V4```C````N)0`
M`"X```#<E```-`````N5```(````0)4``!<```!)E0``"@```&&5```'````
M;)4``!````!TE0``"P```(65```3````D94```@```"EE0``"P```*Z5```*
M````NI4``!0```#%E0``,@```-J5```+````#98```4````9E@``%P```!^6
M```/````-Y8```4```!'E@``!````$V6```-````4I8``#(```!@E@``%P``
M`).6```4````JY8```4```#`E@``!P```,:6```.````SI8``"H```#=E@``
M!@````B7```,````#Y<```L````<EP``-@```"B7```+````7Y<```\```!K
MEP``,@```'N7```%````KI<```<```"TEP``$0```+R7```'````SI<```0`
M``#6EP``!P```-N7```*````XY<```L```#NEP``#````/J7```#````!Y@`
M`!(````+F```!@```!Z8```>````)9@``!@```!$F```)0```%V8```-````
M@Y@```D```"1F````P```)N8```'````GY@```(```"GF```#````*J8```5
M````MY@```L```#-F```&0```-F8```@````\Y@``!(````4F0``!0```">9
M```*````+9D``!4````XF0``$@```$Z9```,````89D```0```!NF0``!P``
M`'.9```,````>YD``%(```"(F0``%P```-N9```&````\YD```T```#ZF0``
M%0````B:```2````'IH```\````QF@``%````$&:```;````5IH``&D```!R
MF@``&@```-R:```7````]YH``!H````/FP``%P```"J;```;````0IL``!D`
M``!>FP``'P```'B;```3````F)L```<```"LFP``"````+2;```)````O9L`
M`!4```#'FP``#0```-V;```3````ZYL```,```#_FP``/P````.<```W````
M0YP``%<```![G```+P```-.<```*`````YT```@````.G0``#0```!>=```M
M````)9T```0```!3G0``)0```%B=```+````?IT``!T```"*G0``!@```*B=
M```,````KYT```<```"\G0``"0```,2=```3````SIT```D```#BG0``!```
M`.R=```0````\9T```@````"G@``"`````N>```,````%)X```\````AG@``
M!P```#&>```4````.9X```X```!.G@``#````%V>```;````:IX``"P```"&
MG@``$P```+.>```%````QYX```0```#-G@``%P```-*>```)````ZIX```@`
M``#TG@``"@```/V>```1````")\```8````:GP``#@```"&?```.````,)\`
M``T````_GP``"P```$V?```"````69\```<```!<GP``!@```&2?```)````
M:Y\```<```!UGP``%0```'V?```%````DY\```<```"9GP``"````*&?```'
M````JI\```<```"RGP``#@```+J?```)````R9\```8```#3GP``"````-J?
M```+````XY\```<```#OGP``"````/>?```'`````*```!8````(H```"0``
M`!^@```&````*:````L````PH```%````#R@```(````4:````8```!:H```
M&0```&&@```*````>Z```!P```"&H```!P```*.@```%````JZ```!````"Q
MH```%````,*@```+````UZ````T```#CH```%P```/&@```$````":$```D`
M```.H0```@```!BA```.````&Z$```@````JH0``'P```#.A```C````4Z$`
M`#$```!WH0``)P```*FA``!*````T:$``#@````<H@``*````%6B```L````
M?J(``!L```"KH@``/@```,>B``!(````!J,``$$```!/HP``6P```)&C``!)
M````[:,``"$````WI```'P```%FD```K````>:0``"$```"EI```,P```,>D
M```E````^Z0``"<````AI0``,````$FE``!I````>J4``#T```#DI0``90``
M`"*F``!-````B*8``"\```#6I@``+@````:G``!4````-:<``#(```"*IP``
M+P```+VG```L````[:<``"T````:J```%P```$BH```E````8*@``#(```"&
MJ```*0```+FH```^````XZ@``"(````BJ0``4@```$6I```E````F*D```L`
M``"^J0``(0```,JI```P````[*D``"4````=J@``'````$.J```Q````8*H`
M``0```"2J@``#0```)>J```+````I:H```X```"QJ@``"P```,"J```%````
MS*H```(```#2J@``60```-6J```%````+ZL``!(````UJP``!````$BK```'
M````3:L```@```!5JP``!0```%ZK```3````9*L```T```!XJP```@```(:K
M```'````B:L```8```"1JP``%````)BK```,````K:L``!@```"ZJP``!@``
M`-.K```2````VJL```P```#MJP```P```/JK```$````_JL```8````#K```
M!P````JL```?````$JP``#4````RK```+@```&BL```O````EZP``!<```#'
MK```(````-^L```;`````*T``!@````<K0``)````#6M```?````6JT``!H`
M``!ZK0``&@```)6M```O````L*T``"L```#@K0``'P````RN```C````+*X`
M`!\```!0K@``&@```'"N```E````BZX``"8```"QK@``)0```-BN```D````
M_JX``!@````CKP``'0```#RO```D````6J\``!@```!_KP``(@```)BO```E
M````NZ\``!\```#AKP``(P````&P```?````);```"````!%L```&@```&:P
M```F````@;```!X```"HL```'@```,>P```)````YK````P```#PL```%P``
M`/VP```O````%;$``"0```!%L0``#P```&JQ```4````>K$```X```"/L0``
M#0```)ZQ```D````K+$```4```#1L0``!P```->Q```=````W[$``!4```#]
ML0``!@```!.R```)````&K(```L````DL@``%P```#"R```&````2+(``#,`
M``!/L@``!P```(.R```A````B[(``!,```"ML@``#````,&R```1````SK(`
M`#(```#@L@``"````!.S```)````'+,```H````FLP``%````#&S```*````
M1K,``!T```!1LP``"````&^S```?````>+,```@```"8LP``&@```*&S```&
M````O+,```<```##LP``"````,NS```)````U+,``#\```#>LP``!P```!ZT
M```/````)K0```@````VM```$P```#^T```'````4[0``!D```!;M```"@``
M`'6T```7````@+0``!0```"8M```"@```*VT```,````N+0``!<```#%M```
M!````-VT```J````XK0``!$````-M0``!P```!^U```"````)[4``!`````J
MM0```P```#NU```(````/[4```8```!(M0``!P```$^U```-````5[4```L`
M``!EM0``%````'&U```5````AK4```X```"<M0``+P```*NU```@````V[4`
M`!P```#\M0``$P```!FV```%````+;8```8````SM@``#````#JV```*````
M1[8``!$```!2M@```@```&2V```$````9[8```H```!LM@``!@```'>V```%
M````?K8```P```"$M@``10```)&V```H````U[8``%,`````MP``&0```%2W
M```@````;K<``#4```"/MP``10```,6W```P````"[@``"@````\N```)@``
M`&6X```E````C+@``"@```"RN```*````-NX```P````!+D``!(````UN0``
M$````$BY``!Y````6;D```D```#3N0``<P```-VY``!\````4;H``"L```#.
MN@``%P```/JZ```?````$KL``!0````RNP``"@```$>[```%````4KL```8`
M``!8NP``"````%^[```0````:+L```\```!YNP``!````(F[```9````CKL`
M``(```"HNP``"0```*N[```$````M;L```\```"ZNP``$P```,J[```B````
MWKL```<````!O```"P````F\```%````%;P```(````;O```"P```!Z\``!/
M`0``*KP```H```!ZO0``#````(6]```'````DKT```<```":O0```@```**]
M```2````I;T```L```"XO0``!P```,2]```%````S+T``!(```#2O0``!P``
M`.6]```+````[;T```D```#YO0``"P````.^```)````#[X```4````9O@``
M"@```!^^```/````*KX```8````ZO@``#````$&^```2````3KX```H```!A
MO@``"0```&R^```=````=KX``!0```"4O@``)0```*F^```M````S[X``#P`
M``#]O@``0````#J_``!`````>[\``$8```"\OP``)P````/````%````*\``
M``@````QP```#@```#K````'````2<```!L```!1P```&P```&W````+````
MB<````0```"5P```!````)K````*````G\````P```"JP```"@```+?````*
M````PL````@```#-P```#0```-;````-````Y,````8```#RP```'P```/G`
M```(````&<$``!D````BP0``!````#S!```&````0<$``!\```!(P0``!```
M`&C!```(````;<$```8```!VP0``"@```'W!```*````B,$```0```"3P0``
M$````)C!```*````J<$```@```"TP0``%````+W!```&````TL$```X```#9
MP0``#@```.C!```.````]\$```@````&P@``"@````_"```5````&L(```8`
M```PP@``!@```#?"```&````/L(```@```!%P@``!@```$["```0````5<(`
M``@```!FP@``#@```&_"```2````?L(```0```"1P@``!````);"```7````
MF\(```P```"SP@``#````,#"```:````S<(```8```#HP@``"````._"```6
M````^,(```8````/PP``"@```!;#```/````(<,``!T````QPP``&P```$_#
M```9````:\,``!L```"%PP``&0```*'#```$````N\,```0```#`PP``"```
M`,7#```&````SL,``"H```#5PP``(P````#$```I````),0``&L```!.Q```
M*````+K$```H````X\0``"@````,Q0``)P```#7%```:````7<4``!H```!X
MQ0``*````)/%```N````O,4```D```#KQ0``#````/7%```0`````L8```T`
M```3Q@``"P```"'&```(````+<8```@````VQ@``$@```#_&```4````4L8`
M``H```!GQ@``!````'+&```8````=\8```@```"0Q@``"````)G&```(````
MHL8```8```"KQ@``!@```++&```$````N<8```H```"^Q@``!````,G&```$
M````SL8```@```#3Q@``"````-S&```$````Y<8```@```#JQ@``!````//&
M```4````^,8```@````-QP``"````!;'```$````'\<```X````DQP``!```
M`#/'```(````.,<```@```!!QP``"@```$K'```&````5<<```P```!<QP``
M`P```&G'```*````;<<```0```!XQP``!@```'W'```&````A,<```8```"+
MQP``&@```)+'```&````K<<```0```"TQP``#````+G'```2````QL<``!(`
M``#9QP``,0```.S'```9````'L@```8````XR```"````#_(```(````2,@`
M`!8```!1R```"@```&C(```1````<\@```@```"%R```"````([(```$````
ME\@```0```"<R```!````*'(```$````IL@``!$```"KR```#P```+W(```(
M````S<@```X```#6R```#0```.7(```&````\\@``!4```#ZR```#````!#)
M```(````'<D```0````FR0``"@```"O)```(````-LD```0````_R0``!@``
M`$3)```$````2\D```0```!0R0``"````%7)```$````7LD```8```!CR0``
M!@```&K)```$````<<D```0```!VR0``!P```'O)```(````@\D```0```",
MR0``"@```)')```*````G,D``"L```"GR0``&@```-/)```(````[LD```@`
M``#WR0``"@````#*```(````"\H``!0````4R@``&````"G*```7````0LH`
M`!<```!:R@``%````'+*```2````A\H``!4```":R@``'0```+#*```=````
MSLH```P```#LR@``%P```/G*```,````$<L``!<````>RP``&````#;+```3
M````3\L``!8```!CRP``,````'K+```$````J\L```0```"PRP``#````+7+
M```,````PLL```H```#/RP``"````-K+```$````X\L```@```#HRP``"```
M`/'+```*````^LL```@````%S```"`````[,```(````%\P``!$````@S```
M%P```#+,```:````2LP```H```!ES````@```'#,```$````<\P```0```!X
MS```"````'W,```(````ALP```0```"/S```!@```)3,```(````F\P```P`
M``"DS```!````+',```*````MLP```@```#!S```#@```,K,```(````V<P`
M``0```#BS```"````.?,```$````\,P``!T```#US```%P```!/-```$````
M*\T```@````PS0``%@```#G-```*````4,T```@```!;S0``"````&3-```$
M````;<T``!$```!RS0``"````(3-```(````C<T```8```"6S0``!@```)W-
M```<````I,T``"D```#!S0``"````.O-```.````],T```0````#S@``!P``
M``C.```>````$,X```@````OS@``"````#C.```$````0<X```@```!&S@``
M!````$_.```(````5,X```H```!=S@``"````&C.```(````<<X```X```!Z
MS@``"````(G.```.````DLX```0```"AS@``"````*;.```(````K\X```P`
M``"XS@``%0```,7.```,````V\X```@```#HS@``"0```/'.```)````^\X`
M``0````%SP``"@````K/```*````%<\```H````@SP``!````"O/```(````
M,,\```H````YSP``!````$3/```*````2<\```H```!4SP``"0```%_/```(
M````:<\```H```!RSP``"0```'W/```'````A\\```0```"/SP``!````)3/
M```&````F<\```8```"@SP``#0```*?/```0````M<\``!4```#&SP``%```
M`-S/```0````\<\``!`````"T```&P```!/0```0````+]```!T```!`T```
M"````%[0```$````9]````0```!LT```"````''0```*````>M````0```"%
MT```$P```(K0```1````GM````H```"PT```"````+O0```(````Q-```!4`
M``#-T```!@```./0```$````ZM````8```#OT```!@```/;0```(````_=``
M``0````&T0``#@````O1```(````&M$``$X````CT0``!````'+1```$````
M=]$```@```!\T0``!````(71```$````BM$```@```"/T0``!@```)C1```$
M````G]$```H```"DT0``#@```*_1```&````OM$```(```#%T0``"````,C1
M```$````T=$```0```#6T0``!````-O1```&````X-$``!(```#GT0``"```
M`/K1```$`````](```0````(T@``"`````W2```"````%M(```0````9T@``
M"P```![2```$````*M(```0````OT@``$P```#32```&````2-(```@```!/
MT@``"@```%C2```2````8](```8```!VT@``"@```'W2```$````B-(```@`
M``"-T@``"````);2```(````G](```@```"HT@``!@```+'2```0````N-(`
M``8```#)T@``!````-#2```1````U=(```0```#GT@``"0```.S2```$````
M]M(``!````#[T@``%P````S3```$````)-,```X````ITP``!````#C3```1
M````/=,```8```!/TP``!````%;3```(````6],```@```!DTP``"````&W3
M```(````=M,```4```!_TP``!@```(73```-````C-,```0```":TP``!@``
M`)_3```&````IM,``!4```"MTP``%0```,/3```=````V=,``!````#WTP``
M(`````C4```$````*=0```@````NU```"@```#?4```(````0M0```0```!+
MU```#0```%#4```,````7M0```D```!KU```$P```'74```(````B=0```0`
M``"2U```"````)?4```*````H-0```0```"KU```!````+#4```(````M=0`
M``P```"^U```#@```,O4```(````VM0```T```#CU```$0```/'4```$````
M`]4```8````(U0``&0````_5```/````*=4```\````YU0``#P```$G5```.
M````6=4``!````!HU0``$````'G5```6````BM4``!,```"AU0``#P```+75
M```/````Q=4```\```#5U0``$0```.75```0````]]4```8````(U@``!@``
M``_6```$````%M8```8````;U@``!@```"+6```$````*=8```8````NU@``
M!@```#76```$````/-8```P```!!U@``$@```$[6```&````8=8```0```!H
MU@``!````&W6```$````<M8```0```!WU@``"````'S6```(````A=8```@`
M``".U@``"@```)?6```*````HM8```8```"MU@``$@```+36```(````Q]8`
M``@```#0U@``"````-G6```(````XM8```@```#KU@``*````/36```.````
M'=<```0````LUP``!````#'7```-````-M<```8```!$UP``"@```$O7```$
M````5M<```0```!;UP``!@```&#7```&````9]<```D```!NUP``#@```'C7
M```4````A]<``!8```"<UP``"````+/7```(````O-<```8```#%UP``!@``
M`,S7```(````T]<```8```#<UP``"@```./7```$````[M<```0```#SUP``
M'0```/C7```,````%M@``!$````CV```#P```#78```3````1=@``!$```!9
MV```$0```&O8```/````?=@``!,```"-V```%````*'8```$````MM@```8`
M``"[V```"@```,+8```*````S=@```0```#8V```!````-W8```$````XM@`
M``0```#GV```*P```.S8```)````&-D```8````BV0```@```"G9```(````
M+-D``!L````UV0```P```%'9```(````5=D```P```!>V0``#````&O9```$
M````>-D```@```!]V0``!@```(;9```(````C=D```@```"6V0``!````)_9
M```&````I-D```0```"KV0``$@```+#9```D````P]D```H```#HV0``"@``
M`//9```,````_MD```H````+V@``"````!;:```7````']H``!@````WV@``
M%P```%#:```,````:-H```0```!UV@``"@```'K:```$````A=H```D```"*
MV@``!````)3:```L````F=H```L```#&V@``"````-+:```3````V]H``"L`
M``#OV@``!````!O;```$````(-L```8````EVP``$@```"S;```)````/]L`
M`!@```!)VP``%P```&+;```$````>ML``#<```!_VP``$````+?;```0````
MR-L```8```#9VP``"````.#;```(````Z=L```0```#RVP``"````/?;```&
M`````-P```0````'W```!@````S<```$````$]P```H````8W```"````"/<
M```&````+-P```0````SW```!````#C<```$````/=P```0```!"W```!```
M`$?<```$````3-P```@```!1W```!````%K<```(````7]P```@```!HW```
M$````''<```$````@MP```L```"'W```!````)/<```(````F-P```0```"A
MW```!@```*;<```$````K=P```P```"RW```$P```+_<```7````T]P``!,`
M``#KW```$0```/_<```$````$=T```0````6W0``#````!O=```$````*-T`
M`!$````MW0``!@```#_=```/````1MT```0```!6W0``!@```%O=```*````
M8MT```@```!MW0``!@```';=```(````?=T```0```"&W0``!@```(O=```:
M````DMT``!\```"MW0``%P```,W=```<````Y=T``!L````"W@``(````![>
M```*````/]X``!````!*W@``&P```%O>```;````=]X``!\```"3W@``'```
M`+/>```=````T-X``!H```#NW@``$P````G?```3````'=\``!D````QWP``
M!@```$O?```O````4M\``#$```""WP```@```+3?```6````M]\```@```#.
MWP``!@```-??```.````WM\```0```#MWP``!@```/+?```&````^=\```P`
M````X```"`````W@```&````%N````8````=X```!````"3@```&````*>``
M``@````PX```!````#G@```"````/N````H```!!X```!@```$S@```$````
M4^````8```!8X```!````%_@```C````9.```!,```"(X```)@```)S@```.
M````P^````0```#2X```"0```-?@```(````X>````0```#JX```"````._@
M```0````^.```!0````)X0``!````![A```(````(^$```H````LX0``#0``
M`#?A```,````1>$```P```!2X0``#````%_A```6````;.$```P```"#X0``
M"````)#A```(````F>$```0```"BX0``$````*?A```&````N.$```X```"_
MX0``!@```,[A```$````U>$``!T```#:X0``"````/CA```%`````>(```8`
M```'X@``#0````[B```$````'.(```0````AX@``!````";B```*````*^(`
M``P````VX@``$P```$/B```$````5^(```@```!<X@``!````&7B```(````
M:N(```0```!SX@``!````'CB```&````?>(```0```"$X@``!````(GB```(
M````CN(``!4```"7X@``)@```*WB```1````U.(``!$```#FX@``%@```/CB
M```$````#^,```0````4XP``!@```!GC```K````(.,``!8```!,XP``*0``
M`&/C```O````C>,```0```"]XP``#````,+C```&````S^,```0```#6XP``
M"@```-OC```(````YN,```@```#OXP``!````/CC```(````_>,```@````&
MY```#`````_D```:````'.0```@````WY```!@```$#D```4````1^0```0`
M``!<Y```!````&'D```$````9N0```@```!KY```)0```'3D```(````FN0`
M``T```"CY```"@```+'D```$````O.0```H```#!Y```*````,SD```$````
M]>0```@```#ZY```!@````/E```G````"N4```@````RY0``#````#OE```7
M````2.4```0```!@Y0``!````&7E```(````:N4``!(```!SY0``!````(;E
M```2````B^4```L```">Y0``"````*KE```(````L^4```0```"\Y0``&P``
M`,'E```/````W>4```\```#MY0``%@```/WE```.````%.8```0````CY@``
M"@```"CF```*````,^8```0````^Y@``!@```$/F```*````2N8```X```!5
MY@``"@```&3F```4````;^8``!(```"$Y@``$@```)?F```&````JN8```@`
M``"QY@``$````+KF```*````R^8```H```#6Y@``!````.'F```'````YN8`
M``@```#NY@``.@```/?F```/````,N<```0```!"YP``#````$?G```6````
M5.<``!(```!KYP``#@```'[G```4````C><``!$```"BYP``0P```+3G```-
M````^.<``!$````&Z```#0```!CH```1````)N@``!<````XZ```$````%#H
M```-````8>@```P```!OZ```$@```'SH```(````C^@```0```"8Z```+```
M`)WH```$````RN@```\```#/Z```!````-_H```A````Y.@``",````&Z0``
M.@```"KI```<````9>D``!,```""Z0``!````);I```(````F^D``"$```"D
MZ0``!````,;I```@````R^D```H```#LZ0``$P```/?I```$````"^H``!<`
M```0Z@``!````"CJ```$````+>H```@````RZ@``$@```#OJ```$````3NH`
M``@```!3Z@``$P```%SJ```5````<.H```H```"&Z@``'````)'J```2````
MKNH```P```#!Z@``"````,[J```3````U^H``!$```#KZ@``+````/WJ```&
M````*NL```X````QZP``"````$#K```,````2>L``!0```!6ZP``!````&OK
M```(````<.L```(```!YZP``!````'SK```(````@>L```0```"*ZP``!@``
M`(_K```(````ENL```8```"?ZP``!````*;K```$````J^L```0```"PZP``
M!````+7K```-````NNL```P```#(ZP``!````-7K```$````VNL```0```#?
MZP``!````.3K```)````Z>L```8```#SZP``!````/KK```&````_^L```0`
M```&[```!`````OL```1````$.P```0````B[```%@```"?L```4````/NP`
M``T```!3[```$@```&'L```=````=.P``!````"2[```!````*/L```$````
MJ.P``!4```"M[```)P```,/L```%````Z^P```@```#Q[```"````/KL```2
M`````^T```0````6[0``!@```!OM```(````(NT```0````K[0``!@```##M
M```&````-^T```X````^[0``#P```$WM```1````7>T``!@```!O[0``'```
M`(CM```6````I>T``"@```"\[0``&P```.7M```=`````>X``!T````?[@``
M$0```#WN```9````3^X``#(```!I[@``+P```)SN```Q````S.X``"\```#^
M[@``%P```"[O```7````1N\``!8```!>[P``$P```'7O```?````B>\``!,`
M``"I[P``&0```+WO```1````U^\``$(```#I[P``)````"SP```Y````4?``
M`"\```"+\```%P```+OP```;````T_```#@```#O\```)0```"CQ```>````
M3O$``!X```!M\0``&P```(SQ```1````J/$``!D```"Z\0``&P```-3Q```;
M````\/$``"0````,\@``#P```#'R```]````0?(``!,```!_\@``"````)/R
M```3````G/(``"T```"P\@``%P```-[R```/````]O(``"0````&\P``!```
M`"OS```(````,/,```@````Y\P``"````$+S```+````2_,```0```!7\P``
M!@```%SS``!/````8_,```0```"S\P``#0```+CS```$````QO,```H```#+
M\P``!````-;S```$````V_,``!````#@\P``!@```/'S```&````^/,```8`
M``#_\P``!@````;T```5````#?0```H````C]```$@```"[T```&````0?0`
M``X```!(]```#````%?T```$````9/0```4```!I]```!@```&_T```&````
M=O0``!(```!]]```'0```)#T```>````KO0``!\```#-]```#@```.WT```6
M````_/0``!(````3]0``$@```";U```7````.?4``!(```!1]0``$@```&3U
M```1````=_4``!H```")]0``$0```*3U```2````MO4``!8```#)]0``%P``
M`.#U```2````^/4``!4````+]@``$P```"'V```0````-?8``!<```!&]@``
M$@```%[V```7````<?8``!(```")]@``$@```)SV```1````K_8``!8```#!
M]@``&````-CV```6````\?8``!X````(]P``'P```"?W```8````1_<``!(`
M``!@]P``%P```'/W```6````B_<```8```"B]P``"````*GW```$````LO<`
M`!X```"W]P``&P```-;W```.````\O<``!`````!^```!````!+X```$````
M%_@``"0````<^```!````$'X```&````1O@``!,```!-^```#@```&'X```$
M````</@```<```!U^```"````'WX```/````AO@```0```"6^```)0```)OX
M```&````P?@``!T```#(^```"````.;X```(````[_@```@```#X^```&P``
M``'Y```&````'?D```<````D^0``!@```"SY```-````,_D```P```!!^0``
M$0```$[Y```$````8/D``!(```!E^0``!@```'CY```8````?_D```(```"8
M^0``"````)OY```$````I/D```@```"I^0``)````++Y```$````U_D```@`
M``#<^0``!````.7Y```/````ZOD```<```#Z^0``#`````+Z```*````#_H`
M``X````:^@``#````"GZ```&````-OH```@````]^@``'0```$;Z```$````
M9/H``!L```!I^@``$````(7Z```$````EOH```8```";^@``"````*+Z```$
M````J_H```0```"P^@``!````+7Z```$````NOH```D```"_^@``"````,GZ
M```1````TOH``!(```#D^@``"````/?Z```C`````/L```\````D^P``#0``
M`#3[```(````0OL```4```!+^P``!@```%'[```*````6/L```H```!C^P``
M#0```&[[```"````?/L```(```!_^P``#````(+[```$````C_L```0```"4
M^P``"P```)G[```]````I?L``"$```#C^P``)0````7\```+````*_P``!<`
M```W_```/P```$_\```A````C_P``!P```"Q_```%0```,[\```3````Y/P`
M`!,```#X_```$P````S]```3````(/T``!X````T_0``$````%/]```(````
M9/T``%$```!M_0``"````+_]```K````R/T``%$```#T_0``&P```$;^```3
M````8OX```\```!V_@``#P```(;^```(````EOX```8```"?_@``!@```*;^
M```(````K?X```H```"V_@``%````,'^```$````UOX``!,```#;_@```P``
M`._^```$````\_X```0```#X_@``"0```/W^```)````!_\``!H````1_P``
M!@```"S_```(````,_\```4````\_P``!0```$+_```0````2/\```$````J
M`P``^`$``!P#``"8`@``[0,```````!P`P``Q@(```@#```$!```5P(``)0"
M````````G@$``%(!``!3`P``K@$``+(````]!```"0(`````````````H0$`
M`.0#``"<`P``)0$``)4!``"9`P```````*X"````````4@,``(@!``#X`P``
M`````!<$`````````````#P!```[`@``-P(``!<#``!B`P``#P$``/(!``#$
M````P````)D!``!/`@``````````````````7`````````!(`P``8P0`````
M````````Z@,``&T#```Y`P``P`$``+4```#E`P``'@0```````!K`@``'P,`
M```````,`@````````````!G`0``U0,```````")````@P(``'0$``!?````
MZ@````,!````````50```+4"``````````````````!F`@``K0(````````<
M`0``5`(```````#C`P``F`````````"*````"@(```8```#O````@@``````
M``!%`P``!0(``-P"`````````````#@"````````%@0```````!G!```J@``
M`!T"```P`0```````-$#``#C`````````.(```!:````B`,```````#U````
M)@,``(L!``#M````$P(````````S````<@(``&,"```8`0``7P0``$H"``"R
M`P``E@,``(0#``!$`0``400``%````!7!```.`````````!F`````@(`````
M``!'`@``@0$``(<!``#[`P``````````````````60```&`"```3`0``````
M`)D```#L`P``_P$```P#``!J`0``7`0``(`````K`P``800``)$```!Z`P``
M>`0``.\!``#-````TP```#@#``#\`0``T`(``&X#```*`P``H0,``.$`````
M`````````%H!```A`P``N`(``/H``````````````,\!``"[````:@,``+<"
M```_`P``80$``*\"```L`@```````/0````````````````````<````$@$`
M``````"B````/````+H#```7`@``>````!X"``!%!```'P$````````B````
M``````L"``#=`````````*P!``````````````````!Y````\0``````````
M````V`,`````````````;P,````````T!```0@````````!I`P``+00``/D`
M``#0`0``!P0``(\!``"C`P```````-("``".`0``/@,``"8!``"D`P``````
M```````@````20$``#0"``"4````$0(``'$#```-`@``)@(``'4"```7````
M=0```.X"````````UP(``)T!````````JP,``*4"````````(P0````#```7
M`0``:@(```````!9`@``>0,`````````````*P0````````W````/@(``"0$
M```8````S0$``,T"````````I@(``'0"``!.`P``XP$````````C````````
M`&X"``!>!````````"T#```4!```RP,``*$````#`@``,0,``#(```!"`0``
M:`````````````````````````#A`P````````````#*`P``J@(``$8"````
M````!`,``%H$``!8`0```````+P"``#1`0``-`$``$`"``!S!```Z`,``#8$
M```:`@``3@```*T```#;`P``)P0``*\#```K````6P0``)`"``#V`0``%`$`
M`"X!``#Y`@``-0,``"X"``!,`P``>@```)L`````````2P```,4!``#K````
M@`(``/`#``"L`P``^@$``'X#````````QP(``%\"````````,`0``#\$``!2
M!```&P$``$L"``":`````````)<!````````80,``!0#```S!````````%L!
M````````-P$``/P#````````2P,`````````````5@```'`$``!?`P``````
M`"$"``!Q!```<`$``/H#``#=`P``.`0``-P#`````````@$``/@"````````
M+P(``,P#``!<`@``)0(``%L"```!`0``0P0``%0`````````;P$``*X````9
M````R0(``/,"````````,0$``.(#``"T````0````/,```!P````````````
M``"=`@``D0(``%L```#;`@``GP```.X!``#1`````````$@"``#)`0``````
M`"H$````````G`(``'H!``#K`@``+`0``-4"``#^`@``CP(`````````````
M70`````````A`0``*P(``$L!``"Q`0``%0,``)`!``!0!```]`(```````!&
M````S@(``'T```!S`P``200``(X"``![`P``_P,``(("``!.`@``X0$``$@$
M````````L`(``#L!``!1`0``H`,``$,"````````A@$```````"C````````
M`$0#``!F!```YP,``$H!``"B`0``C@```$4`````````1P````````!?`0``
M`````!$$``"T`@``(00``,P"```9!````````#P"``#=`0```````*<"````
M````;`,``&0"``!`!```Y`(````````/!```N0,``(L```"C`@``````````
M````````!@$``'8$``!^`@``MP```)<"````````>`$````!``!(`0``````
M``````#[`0``#@0``&,#``#W````.P0```````!1`P```````,L"```#!```
M`````(,#``!V`@``[P(``(H!````````M`$``,(```!/`0``)````$T!````
M````.00`````````````B0$``'$!```H````?@$``$@`````````````````
M```P````,0```'T!``"Q`P``*0,``$0$```+`0``G`$``(,!```^!```9`,`
M`(4#``#>`````````/T"````````P0$````````]`@``P`(``!`!```1`P``
M``````````!-!```R`(``"`#```%`P``6@(```````#"`0``$P,``$`!``"X
M`P``!@,``"@"``#B`0``6`(``.X#````````I@,``/8"``!/`P``?````$,#
M``#'````A`````````"8`0``5@,``.0!``!6`@``"````.4"````````"P,`
M`/D#``#!`P``U@,``$8$`````````````,D```"&````9P````L$```F````
MC0$``/(#``!_````_`(``.D!````````5P$```T!``#W`P``O0(``%0#``#+
M`0``.@,```````!U!```/`0``+\"```8!```IP,```````#Q`P``8@0`````
M```Y`0``(@(``"($``!D!```U@(``/@```!5`P``B`(``"4$```)`P``I0,`
M`$T````$`@```````/H"``#&`0``G0```'@"```Y``````````````!5`@``
M-P,``,X``````````````$`#````````&@0``!@#````````[P,``,<#``!T
M`P``!@(``-0```!<`P```````'$````P`P``````````````````'@$``'8#
M``!8````%0(``(H"````````_P```#D"``"O`0````````````"+`@``Z@(`
M```````%!```SP````````!K`0``!@0``/$"``!Y`@``"`0``!X#``#[````
M`````*@#``#9````#@$``+L"``#L`0``/0$``&,!``````````````````"D
M`@``AP```.L#````````'0```%0!````````?`,``!@"``"0````*0(`````
M```R`P```````"T"``!1````,P(```````#(`P``I`$``'P"``#7`P``Q0,`
M``````!=`@``Q`$``.`````$````:0```'\#``"4`0``)P,``-\#````````
M`````&8#``"^`P``(`$``!T!``#P````20``````````````\`$``,("``#:
M`P``AP,``!L#``!9!````````*@!``#L`@``+P0``%X!```>````+P$`````
M``"5`@``````````````````R@```,L``````````````%@#``#K`0``````
M``````#>`0``N@```.8#`````````@,``+(!``````````````````![`@``
M`````)(!````````N0```%P!````````=@```(P!````````:P,```````#$
M`@``@0(``+T```!$````V`$``(\````I`0``%@$``#T```##`0```````(8#
M``"5`P``K`(``)(`````````HP$```````"^`0```````,X!````````+P,`
M`+,!````````70$```T#``#]`P``UP```+H!``#>`P```````)8````V`@``
M``````````"]`P``700``)\"``"D````_`````````":`0```````&@"``"]
M`0```````!8#``"V`````````"X````H!````````,8```!Z!```*`$``),`
M``"?`P```````.D`````````;`$``#H!```[`````````$\````0!```,0(`
M`&,````;`@``Z0(```````"[`0``,P$```P$```Z!```7@,``,P!````````
MIP$```P```"I`@``00`````````#`P``````````````````H@(``+D"``!L
M`@``-0````````"?`0```````/,!`````````````%(```!5`0``````````
M````````?P$```````"2`P``#0````````"$`0``/P``````````````"00`
M`'<#````````3P0```````#I`P```````%`#``#9`0``*`,``#X!``!.`0``
M`````-H```#%`@``L@(``!P"````````G@```!("``")`@``$P```#4$```J
M`0``000``-8`````````$0``````````````I@```#P#````````1P0`````
M``#[`@``'00``.0````K`0``U0````````!3`@``E`,```````!!`0``````
M`$($``#W`@````````P!`````````````+8#``#F````<P```&@#````````
MO@``````````````````````````````3@0```($``!&`0``$@```)H"``!E
M`@``T@$```````#C`@``_0````\#```*!```D`,``&H$````````'0,``#,#
M```R`0```@```/<!```'`0``(0```!\"``"K`0```````#L#``!B`0``7@``
M`$P!``#=`@``!`$``)$#````````900``*`"``";`0````````H`````````
MG````-D#``"K`@``C`,``(P"``"H`````````&X`````````(@$``.`!````
M``````````X````5`````````#H"``!'`0``+@,``-4!````````T`,``$(#
M``!,`@``S````!H!````````SP,``&`#``````````````````"_````*0``
M`*X#``!G`@``)P```"<!````````30(````````5!```10$``-L```#3`P``
MC@,``)$!````````:0$``)@#``"%`@```````*8!``##````DP,``/D!````
M````JP```+\#``"!`````````),!``"2`@``%@(```````![!```00,``'P!
M``"P`0``60$``-\"``"Q`@``4@(``!4!``"=`P```````*\```!7`P``70,`
M`````````````````(T````R`@``-@$``/("``"!`P```````'@#``#R````
M`````&T$``#@`@```````!0"````````4`$``"P```#1`@``AP(``+<#``#3
M`0``V0(```````#3`@```````"0"``#(````)0```&0!``"\````/P$```\`
M``![````WP````````!;`P``E@$`````````````Z````%8$``#:`0``FP(`
M``````"6`@``P@,```````!)`@``-@````````#V````J@$``)X#``#;`0``
M``(``(\#``#.`P``[@`````````2!```0P```/4#``"&`@``)`$``"`$````
M````T@```/8#``!]`P``?@```````````````````*$"`````````````+D!
M``#M`@``X@(``",!````````'`0`````````````N`$``"(#```!`P``*00`
M``````"V`@```````',!``!R````_@``````````````=0,``*T#``!U`0``
M`````+P#````````&0(``+`#``!3````_@,``,$`````````$`,``+0#``#E
M`0```````&X!``"I`P``-````'<$``!$`@``-`,``+4#``!I!```Q0``````
M````````IP````<```#!`@``8`0```````!H`0``:P```%4$````````H@,`
M`/$!``#]`0```````(0"``"E````E0````````#>`@``>0$``&<#````````
M0@(``*P```!O!```<P(```@"``!)`P```````'0!``!1`@``LP(``'($``#`
M`P``O@(``"T!``#<`0``=P```#T#````````B@,``!8```!L!````````(`#
M``!3`0``#@(``!0````U`@``M0$``(4!``!Y!````````.`#```M````````
M````````````J@,``$H```#0`````````%,$```!`@``H`````@!``#4`P``
M8`$```````!,````WP$``"0#``#*`@````````D!````````:`0``,,#````
M````5@$```````#^`0``QP$``#8#``````````````````![`0``&0,``-(#
M``#/`@``]0(``#$$``#G````#@,``,T#```!!````````)D"``"\`0``M@$`
M`+,```!:`P``$````.P````F!```'P````````#F`@`````````````)````
M6`0``&(````?!```10(``&X$````````;0$``+H"``#T`P``90$```````#)
M`P```````)H#````````C0(``"`"``!O`@``/P(``&P```"[`P``````````
M``!'`P``&P````````"+`P``=````&$"``"H`@``Q`,```````#G`@``````
M`'`"``!V`0``#00```````#<````$0$``&H`````````&@```%X"```U`0``
M`````,8#````````<0(``(T#``!M`@``(P(``'H"`````````````$P$````
M````[0$```<"``"P````PP(``/,#``#8`@```````'<!```G`@``````````
M`````````````.$"``#F`0``G@(``-<!``!!`@``@`$```````#J`0``?0(`
M`#@!```9`0```````/4!``!9`P``2@,``!(#````````)0,``$L$```#````
M+@0```````"_`0````````````"3`@``B`````````!W`@````````L```#_
M`@``8@(``&D"```*`0``90,``-H"``"S`P``R@$``%<```!0`@``5`0``)L#
M``#4`0``B0,``$,!``"E`0``;P````````!@````,`(``+@```!M````````
M`"P#```%````90```"P!```/`@``V```````````````U`(``(P`````````
MEP,``!L$``#G`0```````!H#````````*@(``&8!```%`0``U@$``(,```"I
M````K0$``(4```!R`0````0``*D!``!&`P``-P0``$H$````````/@```"\`
M``"7````*@````````""`0``$P0``#($```'`P```````.@"``"@`0``````
M`((#```0`@``(P,``/`"``#E````.@````````!R`P``30,`````````````
M?P(``+$```!D`````````+<!``#H`0``]`$```````#(`0``80```&L$````
M("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H=&]D87DI`"`H>65S
M=&5R9&%Y*0`@870@`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&
M:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@
M0V]N9FER;6%T:6]N`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M96YT
M`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!I<R!R97%U:7)E
M9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,Z
M("5S`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`
M+2T@<V5L96-T("TM`#(T(&AO=7)S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R
M97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C
M=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@
M4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@
M82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92X`04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I
M=&]R`$%B;W5T+BXN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C
M=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N
M="!F<F]Z96XN`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@
M0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@
M3F5W(%!E<FUI<W-I;VX`061D(&$@;F5W('5S97(Z`$%D9"!N97<@;65M8F5R
M<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B
M87(`061D('5S97(`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S
M`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O
M<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`
M06QB86YI80!!;&=E<FEA`$%L:6%S`$%L;"!!=71H96YT:6-A=&5D(%5S97)S
M`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;&]W(&UU;'1I<&QE(&%D
M9')E<W-E<P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!
M;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M
M90!!;'1E<FYA=&4@=&5M<&QA=&5S`$%M97)I8V%N(%-A;6]A`$%N(&EL;&5G
M86P@=F%L=64@=V%S('-P96-I9FEE9"X`06YD;W)R80!!;F=O;&$`06YG=6EL
M;&$`06YO;GEM;W5S(%!R;WAY`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R
M8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@
M=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!R:6P`07)A8FEC("A7:6YD;W=S
M+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U
M('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F
M;W(@)7,@/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA;B`H05)-4T-)22TX
M*0!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S:6$O4&%C:69I8R!296=I;VX`
M07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,_`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M
M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES
M<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!
M='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q
M;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y
M<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET
M97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H
M+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O
M(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U
M<V5R("5S`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I
M8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@
M4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0F%C:V=R;W5N
M9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U
M<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I
M`$)A;F=L861E<V@`0F%R8F%D;W,`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"
M96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!";&]C:R!3971T:6YG<P!"
M;&]C:R!4>7!E`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]S;FEA(&%N9"!(
M97)Z96=O=FEN80!";W1S=V%N80!";W5V970@27-L86YD`$)R87II;`!"<FET
M:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T`
M0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#
M35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-A;&5N9&%R`$-A;&T`
M0V%M8F]D:6$`0V%M97)O;VX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E
M<CH@)7,`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N
M;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y
M("(E<R(N`$-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P
M;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D
M+@!#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#
M87!E(%9E<F1E`$-A>6UA;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L=&EC("A)
M4T\M.#@U.2TQ-"D`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@
M175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R
M=&EF:6-A=&4@4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAI;&4`0VAI;F$`0VAI
M;F5S92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@
M*$)I9S4I`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H
M;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAR:7-T;6%S($ES;&%N9`!#
M;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQI8VL@=&\@0V]N
M=&EN=64`0VQO<V4@5VEN9&]W`$-L;W5D<P!#;V-O<R`H2V5E;&EN9RD@27-L
M86YD<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]M:6-S`$-O;6UA
M;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`
M0V]M<&%N>0!#;VYD:71I;VYS`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W
M;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T
M:&4`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@
M=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T
M:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;V]K($ES;&%N9',`0V]P>2!S
M96QE8W1I;VX`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!0
M1U`@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G
M92X`0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO
M="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0
M('-E<G9E<BX`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO
M="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H
M92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&]B=&%I
M;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P
M96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE
M("5S`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,
M`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U
M;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-E87)C
M:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@
M4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6YT
M<GD`0W)E871E`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I
M;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="!4
M:6UE`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E
M;G0@<W1Y;&4`0W5T('-E;&5C=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/23@M
M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N
M("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$1A:6QY`$1A=&4`1&%T92!2
M96-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5C96UB97(`1&5C<F5A<V4@
M26YD96YT`$1E9F%U;'0@261E;G1I='D`1&5L971E`$1E;&5T92!'<F]U<`!$
M96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E
M;&EV97)Y('1I;64`1&5N;6%R:P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C
M<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U
M<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C
M=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@
M=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&9O<FUA=`!$:FEB;W5T
M:0!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E
M;F%N8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L
M9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M
M:6YI8V%N(%)E<'5B;&EC`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@
M9&]W;B!L:7-T`$4M36%I;`!%4E(`16-U861O<@!%9&ET`$5D:70@0FQO8VL`
M161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%
M9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET
M('!E<FUI<W-I;VYS(&9O<B`E<P!%9WEP=`!%;"!386QV861O<@!%;6%I;`!%
M;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I
M;"!W:71H(&-O;F9I<FUA=&EO;@!%;6]T:6-O;G,`16UP='D@;65S<V%G92X`
M16UP='D@<F5S=6QT+@!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%<75A=&]R
M:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5S=&]N:6$`171H:6]P:6$`175R
M;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U
M(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI
M;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP:7)A=&EO
M;B!$871E`$5X<&]N96YT`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E
M=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$
M05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&
M86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E
M<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I
M;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN
M87,I`$9A<F]E($ES;&%N9',`1F%X`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E
M;',@;&EK93H@`$9I:FD`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT
M.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@=7!L;V%D
M`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`
M1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9O;&1E
M<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O<F5C87-T($1A>7,@
M*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H
M(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S
M=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y
M<&4`1F]R='5N97,`1F]R=6US`$9O<G=A<F1S`$9R`$9R86YC90!&<F5N8V@@
M1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)O;0!&<F]M('1H92``1G5L;"!$
M97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$=A8F]N`$=A;6)I80!'
M96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;W)G:6$`1V5R;6%N>0!':&%N
M80!':6)R86QT87(`1VEV96X@3F%M90!';P!';V]G;&4@4V5A<F-H`$=R87ES
M8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N
M861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@
M;F]N+65M<'1Y`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U
M97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I
M;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5%10($%U=&AE;G1I8V%T:6]N(&YO
M="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&5A9&5R`$AE87)D($ES
M;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96)R97<@*$E33RTX.#4Y+3@M
M22D`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5R92!I<R!T:&4@
M8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(;VQY(%-E92`H5F%T:6-A;B!#:71Y
M(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO;F1U<F%S
M`$AO;F<@2V]N9P!(;W)D90!(;W)I>F]N=&%L(%)U;&4`2&]W(&UA;GD@9FEE
M;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AU;6ED:71Y`$AU;6ED:71Y.B``
M2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0
M(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O
M=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B
M;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN
M`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N<R!W:71H('1E>'0`26UA9V4@=7!L
M;V%D`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP;W)T960@9FEE;&0Z("5S
M`$EM<&]R=&5D(&9I96QD<SH`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N
M+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O
M;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);G-E<G0@5&%B;&4`26YS97)T(%=E
M8B!,:6YK`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T(&UE<W-A
M9V5S`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN
M=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE
M861E<BDN`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N
M`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@
M861D<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&US9U]T>7!E
M+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I
M;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV
M86QI9"!P<F]T;V-O;"X`26YV86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI
M9"!U;FEC;V1E(&1A=&$N`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A
M<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES<F%E;`!)<W-U97(`271A;&EC`$ET
M86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M
M2E`I`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD@0V5N=&5R`$IU
M<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+87IA:VAS
M=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R96IE
M8W1E9"!A=71H96YT:6-A=&EO;BX`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P
M<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D
M>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI<FEB871I`$MO
M<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!2
M97!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`
M3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S
M="!(86QF`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ
M("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`
M3&%T=FEA`$QA>6]U=`!,96)A;F]N`$QE<V]T:&\`3&EB97)I80!,:6)Y86X@
M07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EN:P!,:6YK<P!,:7-T
M("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!(96QP(%1O<&EC<P!,
M:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T
M+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG
M('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V-A
M;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@
M;W5T`$QO9VEN`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@
M;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A
M:6QE9"X`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H;65N="!C
M;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O
M<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA:6P`36%I
M;"!!9&UI;@!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-86QT80!-
M87)C:`!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T
M:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@
M27-L86YD<P!-87)T:6YI<75E`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA
M`$UA=7)I=&EU<P!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E
M;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA
M>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE;6)E<G,`365N=2!M;V1E.@!-
M97-S86=E`$UE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@
M<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-
M97-S86=E(&5X<&ER960N`$UE<W-A9V4@='EP90!-971A<B!B;&]C:R!N;W0@
M879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS
M(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971H
M;V0`365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S
M(&]F`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E
M;7`@;&%S="`V(&AO=7)S.B``36ER<F]R`$UI<W-I;F<@8V]N9FEG=7)A=&EO
M;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O
M('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI
M<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D:69I960@1&%T
M90!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-;VYG;VQI
M80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S
M97,`36]R;V-C;P!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V
M92!5<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I<&QE('-E
M;&5C=&EO;@!->2!!8V-O=6YT`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T
M`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F%M:6)I80!.875R
M=0!.97!A;`!.971H97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S
M8V%P92!"87-E(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A
M<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T
M>7!E`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI80!.97<@36]O;@!.97<@
M57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@=VEN9&]W("A?
M8FQA;FLI`$YE=W,`3F5X=`!.97AT(&]P=&EO;G,`3FEC87)A9W5A`$YI9V5R
M`$YI9V5R:6$`3FEG:'0`3FEU90!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E
M<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O
M<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE
M(%9&4RX`3F\@9FEL92!U<&QO861E9`!.;R!L;V-A=&EO;B!I<R!S970N`$YO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N
M=&EC871I;VXN`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@=&5M<&]R87)Y(&1I
M<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!V86QI9"!834P@9&%T
M82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG
M:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN
M`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E
M;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]R9&EC("A)4T\M.#@U.2TQ
M,"D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R
M;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E
M`$YO="!A(&1I<F5C=&]R>0!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W9E;6)E
M<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M
M;G,`3G5M8F5R(&]F(')O=W,`3TL`3V)J96-T($-R96%T;W(`3V-T86P`3V-T
M;V)E<@!/9F9I8V4`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H
M87)E9"!F;VQD97)S+@!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N
M`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C
M:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H
M87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P=&EO;G,`3W!T:6]N<R!F;W(@
M)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5
M;FET`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E
M;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@
M4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B
M;&4N`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`
M4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@
M0V]D90!02%`@4VAE;&P`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R
M<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A
M9W5A>0!087-S=V]R9`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U
M=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S
M=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`
M4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E
M<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO
M;B!$96YI960`4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R871I
M;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0:&EL:7!P:6YE<P!0:&]N
M90!0:&]T;W,`4&ET8V%I<FX`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@
M>65A<BX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU
M;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L
M:60@=&EM92X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B
M;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R
M9`!0;VQA;F0`4&]L;',`4&]R='5G86P`4&]S="!T;R!T:&ES(&9O;&1E<B`H
M;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@
M)7,@:&]U<BAS*3H@`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS
M:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO
M;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S
M96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEO=7,@;W!T:6]N
M<P!0<FEV871E($ME>0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R
M;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B
M;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL
M>2X`4'5E<G1O(%)I8V\`46%T87(`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`
M4F%D:6\@<V5L96-T:6]N`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L
M;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE
M+@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H(%!O<G1A;"!6:65W
M.@!296=E>`!296UA<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT
M='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L
M;V-K`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V
M97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=7-E<@!296UO=F4@
M=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N
M960@97)R;W)C;V1E.B``4F5S970`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N
M<P!2975N:6]N`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T
M`%)O=&%T92!2:6=H=`!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3
M+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E
M9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L
M92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U-(`%-50T-%4U,`4V$`4V%I
M;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!3
M86EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H
M92!'<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R
M:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`
M4V%U9&D@07)A8FEA`%-A=F4`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U
M<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF
M:6=U<F%T:6]N+@!396%R8V@`4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U
M<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!3
M96QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT
M<RX`4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O
M>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F
M<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z
M`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@=&EM92!D96QI
M;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T
M8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C
M="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R
M=`!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E
M;F5G<F\`4V5R:6%L($YU;6)E<@!397-S:6]N($E$(&5X<&ER960N`%-E=`!3
M970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@
M9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E
M+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P
M(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@
M86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5V97)A;"!L;V-A=&EO;G,@
M<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&]P
M<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I
M;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@;&%S="!L;V=I;B!T:6UE
M('=H96X@;&]G9VEN9R!I;C\`4VAO=R!P:6-K97(`4VAO=R!T:&4@)7,@365N
M=2!O;B!T:&4@;&5F=#\`4VAR:6YK`%-I97)R82!,96]N90!3:6=N('5P`%-I
M9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K
M:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=R!D97!T:#H@
M`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O<G0@;W)D97(@<V5L96-T:6]N
M`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H
M25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W
M:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%I;@!3<&%M`%-P
M96-I86P@0VAA<F%C=&5R($EN<'5T`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R
M="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA
M=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-U
M`%-U8FIE8W0`4W5B;6ET`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL
M>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N
M<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@
M`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R
M9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`
M4WER:6%N($%R86(@4F5P=6)L:6,`5%-6(&9I;&4`5&%I=V%N`%1A:7=A;BP@
M4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D
M(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!4
M96UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@
M`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1H`%1H
M86D@*%1)4RTV,C`I`%1H86EL86YD`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE
M('-Y<W1E;2X`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`
M5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F
M=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`
M5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&5N8W)Y<'1I;VX@
M9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL
M92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL
M92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE
M861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&QO
M8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T
M:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R
M97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H
M92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@
M:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`
M5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@
M=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<V5R=F5R("(E<R(@
M:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A
M=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V
M960N`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@=7!L
M;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`
M5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A
M=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE<F4@87)E(&YO
M('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R
M92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E
M(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T
M:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@
M=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@
M;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!D
M:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE
M9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H:7,@24U!4"!S97)V97(@9&]E
M<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@
M87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N
M;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&9I96QD
M(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT
M96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N
M9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A
M;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E
M('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B
M92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C
M;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@
M)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S
M960N`%1H:7,@:7,@)7,N`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@
M;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII
M<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D
M+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU
M<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&EM90!4:6UE
M(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I;6]R+4QE
M<W1E`%1I=&QE`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D
M;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI
M;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O
M:V5L874`5&]M;W)R;W<`5&]N9V$`5')I;FED860@86YD(%1O8F%G;P!4<G5E
M(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y
M+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V
M86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%523#H`
M56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S
M:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&
M4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@
M5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L
M92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T
M('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O
M(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@
M5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA
M8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`E<RP@
M=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!6
M1E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@
M)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S
M:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N
M86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@
M;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`
M56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R
M8VAI=F4N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!T<F%N<VQA=&4@
M=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YD97)L:6YE
M`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X
M<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YI8V]D92`H551&
M+3@I`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E
M9"!3=&%T97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S
M`%5N:71S`%5N:VYO=VX`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`
M56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D871E
M('5S97(`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P;&]A9&5D
M(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5
M<G5G=6%Y`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R
M($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO
M;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI
M<R!S:71E+@!5<V5R;F%M90!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I
M;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N
M;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L
M=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L
M=65S`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F
M86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W
M:71H+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!6:65T($YA;0!6:65T;F%M
M97-E("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G
M90!6:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)
M<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE
M($ET86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4
M($U!3E5!3$Q9($923TT@)7,N`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`
M5V4`5V5A=&AE<B!&;W)E8V%S=`!796(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O
M;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U
M.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA
M="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`
M5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@
M<75O=&4@8VAA<F%C=&5R/P!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I
M;F0Z(`!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!8-3`Y=C,@97AT96YS:6]N
M<P!960!965E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<RP@22!!9W)E
M90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@
M=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&1I9"!N;W0@96YT97(@
M82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE
M;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I
M;F<@9FEE;&1S(&EN("5S+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO
M=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I
M9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M
M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@
M=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H
M97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&%N('-E
M<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA
M;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T
M92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9
M;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I
M;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@26YF;W)M871I;VX`66]U<B!)
M;G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI
M;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I
M='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H
M96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U
M<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O
M;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E
M(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I
M;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@
M86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A
M='5R92X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!O<'1I;VYS(&AA
M=F4@8F5E;B!U<&1A=&5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA
M=FEA`%IA:7)E`%IA;6)I80!::6UB86)W90!;4')O8FQE;2!297!O<G1=`%ML
M:6YE("5S(&]F("5S70!F:6QE`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`
M:#H`:6UM961I871E`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP
M;&5M96YT960`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U
M;FYA;65D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE
M8W0M260M5F5R<VEO;CH@2&]R9&4@,BXP"E)E<&]R="U-<V=I9"U"=6=S+51O
M.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U
M+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P,2TP-BTQ
M."`R,CHP-2LP.#`P"DQA<W0M5')A;G-L871O<CH@;&EA;V)I;B`\;&EA;V)I
M;D!J:71E+FYE=#X*3&%N9W5A9V4M5&5A;3H@0VAI;F5S92`\:3$X;D!L:7-T
M<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@
M=&5X="]P;&%I;CL@8VAA<G-E=#U'0C(S,3(*0V]N=&5N="U4<F%N<V9E<BU%
M;F-O9&EN9SH@."UB:70*`"`H)7,@S.S'L"D`("B_[+W=O/P@)7,I`"`HO?',
M["D`("C7\LSL*0#3V@#7[KW\("5D(,SLQOC/\]2DL:@`)7,@+2"QN,W\PKP`
M)7,@UKC.Q@`E<R!+0@`E<R#.K+NDLMG7]R`M(,BWR,\`)7,@UZ*RX0`E<R#-
MK-+BS^[$OP`E<R#2T;3FU-H`)7,@U-H@)7,@)7,`L=C0Z-*J("5S`"5S(+?6
M`-72LKNUO2`E<RX`("5S(+6]("5S(+FR("5S`"5S.B`E<P`L(-7SM^<@)7,@
M)7,`++'DNZ_!O[33("5S(+6]("5S`"TM(-&AU/$@+2T`,C0@T*'*L=;&`+3+
MQ_B_Z;'8T.O2JM:XMJC*_;[=O^*W_L[QMLLN`+>BR?K!R]*[N/;1S];8M<2T
M[<[S`-/[O-/#W-/*O/XLN[G0Z-*JT]#2N[CV(%!'4""YJ[^JP]S4ORX`T_O1
MZ=:DTM''J</[M<33RKS^++NYT.C2JM/0TKNX]B!01U`@N:N_JL/<U+\N`-/[
MO>+#W-/*O/XLN[G0Z-*JT]#2N[CVN:N_JB!01U`@P]S4ORS+O</<(%!'4"##
MW-2_+-+4O+"_VL'N+@#3^]:TT-#3RKS^QZG#^RR[N=#HTJK3T-*[N/:YJ[^J
M(%!'4"##W-2_+,N]P]P@4$=0(,/<U+\LTM2\L+_:P>XN`-/[O>+#W-/*O/XL
MN[G0Z-*JT]#2N[CVN:N_JB!334E-12##W-2_+,N]P]P@4TU)344@P]S4ORS2
MU+RPO]K![BX`T_O6M-#0T\J\_L>IP_LLN[G0Z-*JT]#2N[CVN:N_JB!3+TU)
M344@P]S4ORS+O</<(%,O34E-12##W-2_+-+4O+"_VL'N+@#3^[S3P]S3RKS^
M++NYT.C2JM/0TKNX]B!334E-12"YJ[^JP]S4ORX`04TO4$T`05!)(+'@NL4`
MN=C3VM7BN/:QX+RMQO<`N=C3VBXN+@#(J,_>LKO7XRS.WK>HO:C!HB!61E,@
MQ+_"O"X`R*C/WK*[U^,LSMZWJ+VHP:(@5D93(,[$O/XN`-7+NL72T;:SO>$N
M`+WAU<H`T,+4]@#0PM3VS\*\MM?I`-#"U/;/PKRVR*C/W@#4VK3+T,+4]J.Z
M`-#"U/;3P[NGU^D`T,+4]LBHS]X`T,+4]M*[N/;3P[NG.@#0PM3VTKNX]K/)
MU+$Z`-#"U/:VU`#0PM3V("5S(,ZJ($UO>FEL;&$@4VED96)A<B"RR[6E`-#"
MU/;3P[NG`-#"U/;3P[NGM<2YIL3<M;''L+&[N=BQU2X`M=C6MP#-J-&VLKX`
ML\G.JKG<P.W4L2`M(,ZJQN3+_-/#NZ?%Y-;#R*C/W@"YW,#M`+GCN.:YW,#M
M`+"BN+NZN0"PHK;[L,W$X=''`+"BMON\L,#[T<<`L?##^P#+^=/0TM'1Z=:D
MM<33P[NG`,OYT]#3P[NGU^D`R_G3T,BHS]X`U,K0[;;@N/:UY]?3T\J\_K78
MUK<`TM&TYM3:`+'DN/P@24U34""UQ\*\`+'DN/P@24U34"##W,+K`+'DN/P@
M24U34"#3P[NG`+'DN/S$H[#F`,/`RO3(^,2FT<<`TKNX]K*[NL^WJ+7$UK6Q
MN\JYT\,N`+"RM<"V^P"PLKCGP*T`L+*YY\"M`,3DP_NT^L#M`,3/O*O6W@"P
MLLSAN<^\L+#-MONRO+3O`-.FT\.SS-#R`-.FT\.SS-#RTM&^S=#W`-.FT\.U
MO<OYT]#/PKRVN;+/[0#%^M>\`,O$U,(`L*+`K;*NSL0@*%=I;F1O=W,M,3(U
M-BD`T;G+]<[$O/ZT\]"A`-&YR_7.Q+S^P_NSQ@#$^LBWMJC2JLF^L_T@)7,@
MM<37HK+APO`@/P"PHKCYS:(`T<?#P,3AT<<`T<?#P,3AT<?.Q"`H05)-4T-)
M22TX*0"PHL*SL,T`L*+)K<O)R+JUN@#1Q];>+\RKQKW1\[78Q_@`UK30T,ZL
MNZ2RV=?WQ[#/U,J^R+?(S[;4N["_\C\`RM3-O,F^L_W2N[CVLKNTYM3:M<33
MP[NGU^DN`,K4S;S)OK/]TKNX]K*[M.;4VK7$R*C/WBX`RM3-O+'@O*W2N[CV
MLKNTYM3:M<33P[NGU^DN`,K4S;RQX+RMTKNX]K*[M.;4VK7$N;+/[2X`RO30
MU`"PR]3"`+#$M//`^]''`+#"M=C`^P!!=71H7V-R>7-Q;#H@U=*RN[6]R_G0
MZ-*JM<0@:6UA<"#`J=6YU^F\_BX`075T:%]C>7)U<SH@M_[.\;;+LJ+.M,SA
MN:FXP\_NUJ>SUBX`075T:%]C<GEU<SH@U=*RN[6]R_G0Z-*JM<0@:6UA<"#`
MJ=6YU^F\_BX`075T:%]F='`Z(-72LKNUO<OYT.C2JK7$($944"#`J=6YU^F\
M_B['Z];8T,*QX-+K(%!(4""RHL?2O-/(ZR`M+65N86)L92UF='`@T:'/[BS`
M_<CG(&-O;F9I9W5R92`M+65N86)L92UF='``075T:%]I;6%P.B#5TK*[M;W+
M^=#HTJJUQ"!)34%0(,"IU;G7Z;S^+@!!=71H7VMR8C4Z(-72LKNUO<OYT.C2
MJK7$(&MR8C4@P*G5N=?IO/XN`$%U=&A?;&1A<#H@U=*RN[6]R_G0Z-*JM<0@
M3$1!4"#`J=6YU^F\_BX`075T:%]L9&%P.B#.WK>HT,+4]M/#NZ<@)7,N(+?^
MSO'&][O8TZ8Z`$%U=&A?;&1A<#H@SMZWJ,F^L_W3P[NG("5S`$%U=&A?;&1A
M<#H@SMZWJ+C\T,+3P[NG("5S`$%U=&A?;6-A;#H@U=*RN[6]R_G0Z-*JM<0@
M34-!3"#`J=6YU^F\_BX`075T:%]S;6)A=71H.B#5TK*[M;W+^=#HTJJUQ"!S
M;6)A=71H(,"IU;G7Z;S^+@#1Z=:DRJ>PW"X`T>G6I,JGL-PN("5S`%)!1$E5
M4R#1Z=:DM.W.\RX`1E10(-'IUJ2T[<[S+@"_R=/#M<37UK;..@"PHLC[L-V]
MK@"QL[ZPT=7)JP!K97)B97)O<R##W,+KM.W.\RX`:V5R8F5R;W,@T\.[I\/[
MM.W.\RX`L,VY_L+MR+JUN@"PS<'6`+*HPMZUQ+JCSL0@*$E33RTX.#4Y+3$S
M*0##S[S3P*VY^@"PS;#-MN#+N0"PU[;MPM[+N0"QR,#[RK$`LJ[`^]?(`+&T
MQ/X`L-G$O;3SR+JUN@"RN[6D`,GZR-4`Q_B_Z<7DUL,`Q_B_Z<#@T,T`M-;,
MY0"RH\#[SJS1QP#*Z<>I`+*HR[G$X=''NLVZVLC[N.?.K,3'`+*IM,3-W\3)
M`+*HSJS,V+6Z`+#-SO<`TZ+*]-.AMLC1\\'LM=@`SL3`LP"QH[S3P/O1QP#/
M[L2_M_NZQ0"RO+RJQ,FWJ,OW`+*\PJ&USP#$VLC=N=S`[<^US;,`0U)#`$-2
M3""WUK*\M>,`R-7`^@#!X[RVM^<`O.W&TM6O`+^FPO/"H0#.WK>HP:J[^M;!
M($E-05`@M_[.\<;W.B`E<P"\T\3#M/,`R*'/^P#(H<_[SLK,XK&HN.8`SMZW
MJ,F^L_W.Q+S^("(E<R(N`,[>MZC)OK/]Q+_"O"`B)7,B+@#.WK>HUMC7Z:&C
MR_G,X;FIM<2\Q\*\ROW$O]/KS\C'L,OYL:.TYK7$ROV^W;*[M_LN`,[>MZBT
MJ\O-T,7/HK6]UKBVJ+7$NL7"ZRX`M_"UP[W'`+^JPOS(NK6Z`-+&MJ^UY[NP
M`,C[MOO,V,[$("A)4T\M.#@U.2TQ-"D`UM"WQ[FRNLVY^@#6T,6W("A)4T\M
M.#@U.2TR*0#&OM:DS[B]V@#&OM:DLM_"U`#5I[7#`+C\N,0`UL?`^P#6T+GZ
M`+SRS.76T,[$("A'0C(S,3(I`+>QS.76T,[$("A":6<U*0#1H=3QP]S"ZP#1
MH=3QTKNX]M/#NZ?#^P#(U<;:S]3*OK>]RKTZ`,JEM:ZUN@#5TK*[M;T@)7,@
MM<3`X+'PMJC2Y2X`L+3*\['JO/R\S-#X`+G8L=6TL+_:`-3&P;\`O\:_QLNY
MR+JUN@"XY\+7L<C1QP#1U<FK`+7WR:O%S`"_J,VH`,/\P>X`P_S![KW%L;X`
MQL#"VP#-J-/#P_L`O\;$IL+>`+FKR[X`S/6\_@#%Y-;#("5S`,BWR,_#W,+K
M`+C5N?L`N-6Y^[FRNLVY^@#!K+W3RJ>PW#H@`,&LO=/6P;FKOZK#W-2_M_[.
M\<;WRK'4XK[<OO@N(-2MTO(Z("5S("@E<RD`P:R]T];!($944"#.Q+S^M_[.
M\<;WRJ>PW"X`O^*_R\BZM;H`N+36QM&AU/$`N.?+N;3OP.B\TP"_QLS8M<_-
MWP#.WK>HTM0@4$=0(+S3P]S3RKS^+@#.WK>HSJH@4$=0(-:TT-#3RKS^QZG#
M^RX`SMZWJ-+4(%,O34E-12"\T\/<T\J\_BX`SMZWJ,ZJ(%,O34E-12#3RKS^
MQZG#^RX`SMZWJ+#SMJ@@3$1!4""W_L[QQO<`SMZWJ+WBP]P@4$=0(,K]OMTN
M`,[>MZB]XL/<(%,O34E-12#*_;[=+@#.WK>HOO:VJ,K5O/[(R[7$M>?7T]/*
MO/ZUV-:W+@#.WK>HU]3#W-2_M_[.\<;WR*&UP[FKOZK#W-2_+@#.WK>HM/*_
MJB`E<RX`SMZWJ+3ROZK.K+NDN:37]\2CO^D@)7,`SMZWJ+;!R*$@)7,N`,[>
MMZBVP<BAM.;(H;_8UL:Q[2A!0TPI`,[>MZBVP<BAM_[.\<;WM<3/X+G8S-C0
MU`#.WK>HL:.TYB`E<R"UQ,7DUL,N`,[>MZBRZ=72($Q$05`@(+?^SO'&]RX`
MU=*RN[6]($UO>FEL;&$@4VED96)A<BX@Q^O(M\C/('-I9&5B87(@RL>W\;3R
MOZHN`+GZO-(`O:C!H@"]J,&BU]/.Q+S^O-``O:C!HM7?M<3(J,_>`-#%T\._
MJ+K%PNL`O\O"WK78T<<`N<6PS0"UL<>PRK&\Y`"UL<>PS.S&^`"UL<>PU[2_
M]CH@`+6QQ["WY[CQ`+STQ]#1H=3Q`,C[QM;"M\NY`,[WP.^V^\[$("A+3TDX
M+5(I`,[WP.^V^\[$("A7:6YD;W=S+3$R-3$I`,[WP.^V^\[$+\[:O\O`O,[$
M("A+3TDX+54I`+W=O\NYLKK-N?H`R-4`P[_(U0#(U<;:`,K5M;W(U<;:`-&A
MU/'(U<;:`+#7S.P`RJZV_M3"`+SUR=G+]<7%`,2LR,_)[;?=RK:Q\`#)OK/]
M`,F^L_W3P[NGU^D`R;ZS_<BHS]X`R;ZS_:&BQ^6_U=/*O/X`M=W+S<JQO.0`
MM:3"\P#.RLSBP^C*]@##Z,KV`,^XO=H@*,?KLLZ_O"!(;W)D92"\Q\*\SL2\
M_BDZ`,^XO=K'Z[+.O[S/M<VSN=S`[;7'PKPN`-'0MZ(`PK:UX\["ML@`U^ZZ
M\]*[T*'*L;7$PK:UX\["ML@Z(`#"MK7CSL*VR#H@`+33U_/6P=/2`+33T]+6
MP=?S`,2_PKP`TM0@,C0@T*'*L=;&S]3*OC\`S]3*OM&AS^X`S]3*OKCQRKT`
MO*JRO,SA`+*[R;ZS_0"RN]*JUK&]T[3FR*$@;6%I;G1E;F%N8V4N<&AP`+7:
MTKNQRKS'PKS*Q[?QL/RZK-?6ML[#^[/&/R#(Y[G[RL?'Z]&AU/$N`+;@P]?$
MX;S3`+;@P]?$X;S3N;*ZS;GZ`,_"U-@`S\+4V"`E<P#/PM38R?JSR;7$Q>36
MP\[$O/[.JB!02%`@L\S0\BX`S\+`K;++M:4`M>?7T]/*O/X`M.W.\P"V\KG/
MMN"V^P"QX+RM`+'@O*W'^+_I`+'@O*W3P[NGU^D`L>"\K<BHS]X`L>"\K<BH
MS]X`L>"\K2`E<R"UQ,BHS]X`L>"\K=&AS^X`L>"\K2`E<R"UQ,BHS]X`L*.\
ML`#(^+;[S=^VX`"UY]?3T\J\_@"UY]?3T\J\_K78UK<`M>?7T]/*O/ZUV-:W
ML=C0Z\['NL\N`+7GU]/3RKS^R+?(SP"Q[<?IM_NZQ0"_U;#7T,6\_BX`O]6P
MU[WAN?LN`,3JM=<`M\6T\['@O*W&]P"SX+7`O+C$VM''`+;RP:+,V,#OT<<`
MM.W.\P"PKLFSQ.'1QP"PH\C[MNVQR-''`,6WUMX`P[\@,34@M];6TP##OR`S
M,"##Z];3`,._(#4@M];6TP##O[3.M<?"O`##OR`S,""WUM;3`,._(#$@M];6
MTP"WML#]UK4Z`-:TT-``U;F_J@"UO<;:R-4`O>++M=2Q`$944"#)S[2KQ>36
MPRX`ML'(H<:KNL/%Y-;#RJ>PW`#.WK>HP:R]TR!,1$%0(+?^SO'&]RX`SMZW
MJ,&LO=,@4TU"(+?^SO'&]RX`N+36QLJGL-S7U"`B)7,B+@"XM-;&RJ>PW+6]
M("(E<R(N`,[>MZB]J,&BTKNX]M#"M<0@4T%33"#!K+W3+@#2QK:OM;T@(B5S
M(LJGL-PN`+>HP+R_R[BCR+JUNB`HPNVV^\ZLQ,G+N<BZM;HI`+>HPM[(NK6Z
M`+2KU>8`MO[4P@"XT+[US_'*QP"XT+[US_'*QSH@`.RSO,,`SL2\_LK]Q+\Z
M("5S(+CVSL2\_@#.Q+S^ROW$OSH@)7,@SL2\_@#.Q+S^N=S`[<;W`,[$O/[#
M^[/&`,[$O/[)S[2K`,[$O/[)S[2KN:;$W,ZTL;O6I[/6+@"Y_<++QO<`M]+`
MO`#)S[#KU,(`R<_/TM3"`+G,MJBQR,#]`+>MUZH`Q+_"O"`E<R"RN[3FU-H`
MU];0S='5R:L`U*2QJ,SLROT@*-2DL:C,[,K]L/S`J+#7S.S2U+RPTKF\Y+7$
MROV^W3O(Y[G[U*2QJ,SLROV]S[.DO:O5O-/#L<B]S[_MM_FUQ+#FP^8I`+2P
MS.4`R^/#_`#+X\/\P.#0S0#+X\/\`,+;S+,`U]2VK]>JT,4`T,?&VL[E`+>H
MN?H`MZC*]+GGT<?$QP"WJ,KTLJ/`^\3ASO?1QP"\Q+S^R,L`M-,`S>K5^\/H
MRO8`POK4P@#(J\/[`+S3Q>X`N-2QR-''`++ZR?H@)7,@M<3/M<VSQ>36PP"X
M\<*SO*K1QP"UPKGZ`.7(Q,D`UK&RO,+>S=,`P_L`UZJUO0!';V]G;&4@R]'+
M]P"[TK;(`,^CP+``SZ/`L,[$("A)4T\M.#@U.2TW*0"X\<'JP+P`N/'!UL3)
MM.\`T\.[I]?IN=S`[0#3P[NGU^G#^[/&LKNUP[_5L-<`T\.[I]?I`+G/M<+"
MWL;5M;H`N=BUN@#.H[78PNW`K0"X\;;WSO>UN@"WP[_-R*C/W@"WP[_-P?31
MU`"\N,3:T<<`O+C$VM''L<C)W+FRNLVY^@"YY]''Q,<`2%1-3`#5TK*[M;T@
M2%144"#1Z=:D+@"ZH[78`-33M-4MR^.WJ`"Q[<VW`+K5M<*ZS<+TM;'`S<BZ
MM;H`SZ.RKL"TSL0@*$E33RTX.#4Y+3@M22D`L._6^@"QX+RMQO?*N=/#L._6
M^@"P[];Z`-7BP._*Q\[$O/ZUQ+^JRKPZ`.CSM=FXU`#*U]*S`,K7TK.UV-:W
M`,K7TK.UY[NP`+KIMKS`K<NY`-;0N?K/X[C;`$AO<F1E`,NNQKW/WP#7UK;.
MROW$O[FRO,8_`,JJML@`RJJVR#H@`-#9T<#`^P!)34%0(-/*S^2]J,&BRJ>P
MW#H@)7,`24U!4"#3RL_DR;ZS_<JGL-PZ("5S`$E-05`@T\K/Y+3%Q<S%Y-;#
MO:C!HLJGL-PZ("5S`$E0(+78UK?.WK>HRKG3PRX`25`@M=C6M[*BLKO4VB!#
M2412(+7$O=/*W,?XO^G6T"X`L?FUN@#6N]/0S;RQZ@#-O+'JO+#.Q-?6`,G/
MM*O-O,:L`,V\QJP`N^/(ZRP@LKW6Z"`E9`"[X\CKU]:VSCH@)7,`N^/(Z]?6
MMLXZ`,KDR.NRN]7]R+>UQ-?WT\/"ZRX`U/:\T\OUQ<4`TZ&VR`"X]K'PT\.[
MIP#3H;;(Q.'.]]''`-#%SZ(`T,7/H@"RY<CKL>VX\0"RY<CKS?C"Y\&LO=,`
MLN7(Z[_)S.:T^L2CL.8`LN7(Z]/*O/X`LN7(ZR^QY+C\S;S&K`"RY<CK+['D
MN/S-^,+GP:R]TP#5^\K]`-7[ROW!T`#.WM"GM<0@541(*-/#NZ?*_;[=L>W-
MMRDN`,[>T*>UQ-.FT\.SS-#R+@#.WM"GM<3%^K3.NL7"ZRX`S.&]N[7$ROV^
MW<[>T*<N`,[>T*>UQ,2_L>K7H=:W`+*[NL^WJ+7$SL2\_KCQRKT`SM[0I[7$
M(&US9U]T>7!E+@#.WM"GM<2[\M72LKNUO2!A<&E?:60N`,[>T*>UQ+ORU=*R
MN[6]LL[*_2X`LKNZS[>HM<2XN,BHS]XN`,[>T*>UQ,VHT;;0K=+I+@#.WM"G
MM<3`M-2TUZ'6MRX`SM[0I[7$S?+3P\+KROV^W2X`TL'`RM+!R[G`O+FRNLVY
M^@#2P<"MO\L`L*ZV^\"\`,+\M;H`TM3)J\'0`,>IMZ+5WP#0L<SE`-+BM//`
M^P#1P,+RO-,`TKO4P@!*87!A;B`HR-6QOBD`R-7.Q"`H25-/+3(P,C(M2E`I
M`-3SSO>UN@#4O+6I`,;?U,(`P?G4P@#6P];0`-?ST]*VU,;K`+^_U_.VU,;K
M`+^_T]*VU,;K`+G^R/B_R\NYS+D`L:/!]-2MT?D@/P"_S\3AT<<`2V5R8F5R
M;W,@R,_6I+3MSO,N`,/<U+^]J,&B`,/<U+_,V-7W`,/<U+^SI+;(`,/<U+_`
MX-#-`,/<U+_3[[>H`+6QQ["UQ+FKOZK#W-2_M_[.\<;WUM`LTM&^K;3FU-K$
M^K7$P]S4ORX`N_G`[[#-R[FYLKK-N?H`LZ_/R@"ZJ[GZ`+JKSL0@*$550RU+
M4BD`O\;-_LS8`+RJMON\JLNYS+D`T^_1U`#`S\[.`,_"L.O4P@#/PL_2U,(`
MR<^TSKC\T,(Z`,G/TKNTSK7'PKPZ("5S`,G/TKNTSK7'PKPZ("5S(-?4("5S
M`,G/TKNTSK7'PKPZ(+7:TKNTSK7'PKP`P*W-T<ZLT<<`L.;#YL7DUL,`P.BP
MS<3;`,"SR_?-T`#`^['(P._1QP#`^['(T<<`P=#6I[;8RK^UQP#!K+W3`,&L
MO=,`P="S]B`M(-/#NZ>_R=+4O[2UO=7BN/;.Q+S^O-``P="S]LNUP_>QZLSB
M`,S6PMO3P[NGU^DMSL2\_KGQ`,S6PMO3P[NGU^DMQ_/6^@#,UL+;T\.[I]?I
M+<JVL?"ZQ<+K`,S6PMO3P[NGU^DMT[73T-7?`,S6PMO3P[NGU^DMO,2\_LC+
M`,S6PMO3P[NGU^DMMJG4Q`#,UL+;T\.[I]?I+<BAS_NVJ=3$`,'0L_;3P[NG
MM<2YIL3<L;NYV+'5`,[$T:<`P:+,U<WP`+6QM=C*L;SD.B``M=C'^-/KRK&\
MY`"UV,?X`+7'PKP`UZ+/^@"UQ\*\`+7'PKS*I[#<+"#'Z[SLLNG$^K7$T\.[
MI\/[NLW#W,+K+"#(N[KSUMC*U"X`M<?"O,JGL-PN`,*LR:VQI`#4P@##O\C5
MT,7/H@!-4RU43D5&(+B]O-/.Q+S^UM##N]/0ROV^W2X`35-'`-;0N?JPQ,/%
M`,+MQN2VV;FRNLVY^@#"[;3OO-/+N;S3M;H`T\J\_@#3RKS^N=S`[0#"[<"M
MS?X`PNW`M,[WT<<`PNVV^[3ZM_(`PNW`^P#"[;;ZR_L`R/W4P@"QZKS'L\D@
MO[2Y_2_.M+^TN?T`L>J\Q[/)QN3+_+7$RK:Q\"`HP/W(YRX@UMC2JB_2T;O8
MN+0I`,+MR=RV^\BZM;H`PNW,X<3AO\NUN@#5_=3:QJ7%Y-?6MLX`PZO`[\O^
MQ.'1QP##J\#OQ_/+N0"XO;S^ROW$O]+1LZRS]KW3RMS)S\_>+@#7[KW\(#(T
M(-"ARK&UQ-?NN-_.PK;(.B``U^Z]_"`V(-"ARK&UQ-?NN-_.PK;(.B``O=/*
MW-?NM/.SI+;(`,[EU,(`PNW4O,S8R+JUN@"SR=2Q`-&AM:7$H\J].@#3RKS^
M`-/*O/[1Z=:DTM'-ZK/)++6KRL?3P[NGM<3'J</[R+3.WK>HS:BY_='IUJ0N
M`-#%SZ+2T;G]QMHN`-#%SZ+`X-#-`$UE=&%R(,?XO^G.WK>HRKG3PRX`365T
M87(@Q_B_Z<[>MZC*N=/#+B#/N+W:Q^NRSK^\S[7-L[G<P.VUQ\*\+@"WO;>H
M`+FKUL8`Q*O.][CG`,/<O\O"WL3ASO?1Q\&JL.ZY^@!-:6UE(,#@T,T`U^Z]
M_"`R-"#0H<JQM<37[K7-SL*VR#H@`-?NO?P@-B#0H<JQM<37[KC?SL*VR#H@
M`-.SR>0`Q>36P\[$O/[2Q<JG+B#(Y[G[TJK*N=/#U>*X]M.FT\.SS-#RQ/JQ
MV-#KS];4VK[-LOK)^LO[+@#5TK*[M;W0Q<^BM<0@240N`-72LKNUO;OAQMJU
MQ"!)1"X`T,?&VM*[`-#0MJ_3RKS^`+C\T,+(U<;:`,2CO^D`Q*:V^[;@S=\`
MQ*;$R;CG`,/)N<4`U,*ZS<3J`,._U,(`P\G,V,C[P*W,V`#4PL'!TZ^_]P#$
MIL+EN.<`S\+2Q@#7\]+&`-/2TL8`R<_2Q@#/PM+&`,G/TL8`Q*K)H['(O\L`
MN+31H0#.TK7$U<NZQ0#.TK7$P\6[IP#.TK7$P\6[I]*SP^;%Y-;#`,/EM>D`
MLKLLSM*RN\VLTN(`P_NSQ@#$R</7L<C1QP#HI\*S`,3ALK2V^P"ZR<"\`+K)
MRO2PLK78P=#+N0"[^=/:3F5T<V-A<&4@M<3-^-:W`$YE='-C87!E(%-33""W
M_L[QQO?#^[/&`$YE='-C87!E(,C/UJ2UQ,7ZUZ(`3F5T<V-A<&4@R,_6I,#@
MT,T`S?C"YP"TT\ZT`-#"OZ;`[[;@Q.'1QP#0PM3"`-#"T\.[I\/[("BWQ['8
MTJHI`-#"SO?`O`#0PK2PO]H@*%]B;&%N:RD`T,+.Q0#/PM*[LKT`S\+2N[CV
MT:'/[@#$X;S3P*VYSP#$X<C5MOL`Q.'(U<#[T<<`S>W)SP#%IK"CM;H`R_G6
MN+:HM<3.N];#R<_#N]/0Q_B_Z;3FU-H`P[O3T,SAN:G(U<#ZP_NSQM+4N:D@
M34-!3"#1Z=:D+@##N]/0UKBVJ+7$("5S(,7DUL/0Q<^B+@##N]/0UKBVJ+7$
M($944"!61E,@Q>36P]#%SZ(N`,.[T]#6N+:HM<0@4U%,(%9&4\7DUL/0Q<^B
M+@##N]/0UKBVJ+7$(%-13"U&:6QE(%9&4\7DUL/0Q<^B+@#.Q+S^SK3)S[2K
M`,Z[UL/0Q<^BR=#.M,7DUL,`P[O3T-:XMJC#W,+KTM2YJ2!(5%10(-'IUJ0N
M`,.[T]#6N+:HP]S"Z]+4N:D@24U!4"#1Z=:D+@##N]/0UKBVJ,/<PNO2U+FI
M($ME<F)E<F]S(-'IUJ0N`,.[T]#6N+:HP]S"Z]+4N:D@3&]G:6X@T>G6I"X`
MP[O3T-:XMJC#W,+KTM2YJ2!005-35T0@T>G6I"X`P[O3T-:XMJC#W,+KTM2Y
MJ2!334(@T>G6I"X`P[O3T+3]R?.UQ->BLN')ZL?K+@#.WM3=M.;$O\*\O\FY
MJ;_LR*$N`,.[T]"ZS[>HM<0@6$U,(,K]OMVQN[2KN]@`O]6PU]:U`-2MRKS%
MY-;#SL2\_M;0U=*RN[6]L.:QOM#%SZ(N(-;8T,*R^LGZQ>36P\[$O/XN`-3:
MQ/JUQ,7DUL/.Q+S^UM#5TK*[M;VPYK&^T,7/HBX@UMC0PK+ZR?K%Y-;#SL2\
M_BX`SMX`R-6V^L+\SL0@*$E33RTX.#4Y+3$P*0#%M;BCO\NUN@"QL;#KQ_(`
ML;'"[<#OT<?$R<BZM;H`Q;+-_@"WQ]:NNO,`M\?6KL>P`+*[RL?2N[CVQ+_"
MO`#.M+&[UJ>SU@"QN,W\PKP`RJ[2N]3"`,K]U]8`U]:W^\K]`-?6ML[*_<2_
M`+'*ROT`3TL`MM3/\[VHP:+5WP"PR[WXSKL`RJ[4P@"P[+FKRM(`L*+"_`#6
MN]/0($E-05`@M_[.\<;WUJ>SUL[$O/Z\T+FRS^VYIL3<+@#6N[W3RMS2N[CV
MT\J\_K78UK<N`-:[T]#3M=/0U=_3Z\^US;.YW,#MU+&_R=+4L>2X_+FRS^W(
MJ,_>`-3:T,*TL+_:UM"T\K^J`-&AS^X`)7,@M<31H<_N`,_NQ+^QX+K%`-?I
MUJ\`U^G6K[6ESKL`U*W*O-.FT\.SS-#RQ*.PY@#4VB`E<SH@UM"UQ-2MRKS$
MH[#F+@#&Y,O\`,;DR_S0Q<^B`-.UT]#5W\BHS]X`4$%-(-'IUJ3.WM"G+@!0
M1U`@ROW7UL>IP_L`4$=0(+S3P]S7RL'/`%!'4""YJ[^JP]S4OP!01U`@TM''
MJ</[+]+1O-/#W"#7RL'/`%!(4""SS-#RM/K"ZP!02%`@O<6QO@"PS;OYR[G,
MN0#%P<#-`+#-P-7+N<RYL;O5O,'LQ_@`L,W$P\+M`+#-LKS1Q]#"O+C$VM''
M`+#-P*VYYP##W,+K`,.[T]#6N+:HP]S"Z]+4N:D@4D%$2553(-'IUJ0N`,/<
MPNO(M\C/`,/<PNLZ`,/<PNLZ(`##W,+KL=C0Z\['NL\N`,SYR<\`S/G)SP#"
MM[ZV`+3]R?.UQ\*\H[H`UK30T,ZLNZ2RV=?W`+7'PKRZ\]:TT-#.K+NDLMG7
M]S\`R*C/W@"TYLBAU.*^W`#(J,_>`,BHS]ZYW,#M`,[2M<0`P]C"LP"WQL+)
ML?8`M>>[L`#5U<:L`,:DS-B_M;6Z`,?KRN3(Z]*[N/;4PK?=O+#$ZK?=+@#'
MZ\KDR.O2N[CVNL^WJ+7$R-7&VCO1H=3QM,O4PK?=M<3(U<;:+@#'Z\KDR.NZ
MS[>HM<3*L;SD+@#'Z\SAN:G.RLSBM<35JM*J+@#'Z\KDR.O$^K7$T\.[I\/[
MO+##W,+K`+*HP+P`S;;&L0#&S\S1T<``M=W+S=/*O/ZUO=7BN/;.Q+S^O-`@
M*&YO="!E;F9O<F-E9"!B>2!)34%0*0#7[KW\("5S(-"ARK&UQ+VUT^K!OSH@
M`%!R969S7VQD87`Z(-72LKNUO<OYT.C2JK7$($Q$05`@P*G5N=?IO/XN`%!R
M969S7W-E<W-I;VXZ(-72LKNUO<OYT.C2JK7$('-E<W-I;VX@P*G5N=?IO/XN
M`,;XT;D`NJ/&O</FQOC1N3H@`,;XT;DZ(`#4I,#``,G/TKNX]M&AS^X`R[W#
MW,/<U+\`SLK,XL/HRO8`UZBPN`#,X<J^Q-K(W0"YJ[^JP]S4OP"YJ[^JP]S4
MO]'=R^,`N:N_JB_+O</<P]S4O[;4LJ+.M+&[LOK)^BX`LJBVX,#HN/<`OZC+
M_K;[`%)302"YJ[^JP]S4OR`H)60@SKLI`+6ET:$`L<C"R@"VP<BA`+;!R*'3
MRKS^`-7FM<32JLF^L_T@)7,@PO`_(-7BS^ZRV=?WO:O.WK>HN]:XM"X`R*'/
M^[BTU*T`RZ+0PL/%NZ?*T\V\.@"YYM3RL>VT[\J]`,;`PML`U+:SS+?^SO'&
M]P#4MK/,S?C6MR`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`,F^
ML_T`R;ZS_<?XO^D`R;ZS_;;4`-?4M_[.\<;WU-VTYL2_PKS6T,F^L_W2T;&C
MM.:UQ,7DUL.SS-#R+@#)OK/]T\.[IP#)OK/]T\.[ISH@)7,`T.C'\\ZTL;O/
M[-.F.B"T[<[SNL7"ZSH`UMC)Z`"]X;G[`+>UN]C1H<_N`%)E=6YI;VX@*,'T
MQ.'-^K6Z*0"]Q\FK`%)O;6%N:6$@*,+>PNW$X=''*0#0_=>J(#$X,""VR`#/
M\M?ST/W7J@#/\M/2T/W7J@#6M-#0`%)U<W-I86X@1F5D97)A=&EO;B`HMNW"
MWLNY*0!2=V%N9&$@*,*LL+*T[RD`4R]-24U%(+S3P]S'J</[`-/*O/[2T<JY
MT\,@4R]-24U%(+S3P]P`4T%33"#1Z=:DSM[0IRX`T,7/H@#*_;[=O^*]Q;&^
M`+S3P]S6U;;+N_H`L\FYI@#0Q\;:P?D`RJ6ZU<#5Q,.UN@#*I;OYM<*ZS<'0
MSJS+N0#*I<*LSO?1Q[6Z`,JEQJ2PH[;[NLW"\[_+PM?(NK6Z`,JESL3)K<S8
MNLVX\<'6Q,FT[P#-K-*[N/:TL+_:("A?<V5L9BD`R/C$IM''`,JEPNW!IL6U
M`,JEMN##P+K-QM7!UL[WL<@`SL#0Q\SAN:G5WP#)L\S8L*+`K;*N`+&CM.8`
ML:.TYB`E<P"QH[3FT:'/[@"]J[+ZR?JUQ,7DUL/.Q+S^TM0@4$A0(-/OT=2X
M\<J]L:.TYK6]Q/JUQ+?^SO'&]]3=M.;$O\*\UM`N`,7DUL,@)7,@TM&QH[3F
M+@#+T=&P`-&AU/'2N[CVR-7&V@#1H=3QTKNX]M/#NZ?7Z=/#TM30PM3V`-&A
MU/'2N\Z[T,*UQ-.UT]#5WP#1H=3QTKNRO[?^SO'&]P#1H=3QTKO.N]/#NZ?3
MP]+4T,+4]@#1H=3QR_G3T,C5QMK7Z;S^+@#3VM+4S\*UQ+2PO]K6T-&AR*'$
M^M*JM<37UK?[+M+4RO.QZKBTUL;+^=&ASL37UBS(N[KSS/G)S\[$O/ZQX+RM
MQ_@N`-&AU/'(U<;:M]:X]#H`T:'4\<C5QMK(U<;:N/'*O3H`T:'4\<JQO.2W
MUKCT.@#1H=3QR-7&VLJQO.2X\<J].@#1H=3QS^"[I<:EQ>2UQ+;^N/;7UK;.
M+@#1H=3QQ/JUQ-'5R:O%Y-;#`-&AU/'&J[K#T^_1U#H`M*O+S<[*S.*WM-.F
M`%-E;F5G86P@*,C[Q-J\T[;[*0"TJ[C0QO<Z(`"^Q=3"`%-E<F)I82!A;F0@
M36]N=&5N96=R;R`HR/NV^\ZLT<?3Z\/)S-C$X;CGPMXI`-#RNL4`N^'&VB!)
M1"#2T;G]QMHN`,7DUL,`Q>36P]2VL\RW_L[QQO?)S\KTT]K$^K7$N/;(R]6^
MS*@N`,7DUL/$^K7$QJNZP]/OT=0L(,JQQ_C2U+RPR-7&VKCQRKTN`,7DUL/$
M^K7$QO3*O-.FT\.SS-#R+-'5R:O%Y-;#+-*SP^:X_-#"QK7"RBR\L,;DR_S/
MU,J^T:'/[BX`T]"ZP[RXN/:UV+7CNLW5XKCVLL[*_=/0N=@Z(`!397EC:&5L
M;&5S("C(^\[TMOLI`+FZSN\`O/*VS-6JTJH`RL>W\<ZJM/.RO[?=M<3!K+W3
MMJC2Y;_LO=VYIL3<O/P_`,_4RKX`P[^TSK7'PKRZ\\_4RK[)S]*[M,ZUQ+7'
MPKS*L;SD(#\`S]3*OK7CT:'&]P#3VM?SL=_/U,J^("5S(+++M:4_`,K5R_4`
M4VEE<G)A($QE;VYE("C*J-?3R;VY^BD`UZ*RX0#'J</[`,>IP_O1W<OC`%-I
M;F=A<&]R92`HT,*\T\;"*0"T\]"A`,+4N?W.K+ND`%-L;W9A:VEA("C+N<+E
MMZ6_RRD`4VQO=F5N:6$@*,NYPN6WI<3AT<<I`+O]T:G)[K;(.B``4V]L;VUO
M;B!)<VQA;F1S("C+]\+>P\7(NK6Z*0!3;VUA;&EA("C+]\+MP/O1QRD`Q<7!
MT+>]S_+1H=3Q`,"TU+2UV-:W`%-O=71H($%F<FEC82`HQ,^WQRD`Q,_%MR`H
M25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W
M:6-H($ES;&%N9',`Q,^PZ\?R`%-P86EN("C.][#@T<`I`,"LN_C3RKS^`,S8
MRN+7UK?[RN3(ZP!3<FD@3&%N:V$@*,NYP._`O+^H*0"QZM>\`,;TRKS$ZK?=
M`,JA`->TS*P`L:.TYKCQRKT`O=:UP`#)OK/]S]\`U]:W^[2NP=``T,?&VLSL
M`-;WUKP`S.&]NP#/PK'J`+/)N:8`TM&SR;FFN+*XQR`E<P!3=61A;B`HR]6U
MI"D`U:K2J@#(U;/V`,C5PN0`R-6S]@#(U;/V+\C5PN0`R-6S]CH@`,C5PN0`
MR-7"Y#H@`,G/L>H`UJ>SU@!3=7)I;F%M92`HR]7`^\3/*0"TPKK%`%-V86QB
M87)D(&%N9"!*86X@36%Y96X`4W=A>FEL86YD("C*M\W?O,/`O"D`4W=E9&5N
M("C(\+7D*0!3=VET>F5R;&%N9"`HR/#*ORD`4WER:6%N($%R86(@4F5P=6)L
M:6,@*-#PP/O1QRD`5$%"(+?6N/2X\<J]SL2\_@#,J,WE`,RHS>4`5&%J:6MI
M<W1A;B`HR_Z\JLNYS+DI`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8@
M*,RYR=#$X=''*0#$O['J.@"T_;#LRL+/[@"UY[NPNL7"ZP#7[KW\TKO0H<JQ
MM<3.PK;(.B``SL*VR`#.PK;(.B``Q*.PYKG<P.T`Q-K(W0"TO\[$U]8`T,?&
MVLO$`,RISL0@*%1)4RTV,C`I`%1H86EL86YD("C,J;GZ*0#0N]"[Q/K*N=/#
ML;[/M<VS+@!&5%`@T=/)["AE>'1E;G-I;VXISM[0IRX`36%I;G1E;F%N8V4@
MP."Q\+*BSK2SR;FFU-C(ZP#1H<_NM+"_VM+4N=BQU2[`Z[^JUM`N`-'IUJ33
MRKS^QZG#^]#HTJK3T-*[N/;2T;WBOZJUQ"!01U`@Q_B_Z2X`T.C2JM*[N/:^
MK;G]O-/#W+7$S?C"Y\&LO=,N`,[$O/X@)7,@TZ:XP[#\NJS2N[CV("5S(,7D
MUL,N`,[$O/X@)7,@TZ:XP[#\NJS2N]"I("5S(,7DUL,N`+3+SL2\_M;0P[O3
MT,K]OMTN`-+4S\+*QR!R9F,X,C(@T\J\_K7$L>W-MRX`1VYU4$<@MO[4JL[$
MO/ZUQ,*WOK:QV-#KMJC2Y=3:($-R>7!T7W!G<#HZ(,#@L?#6T"X`2&]R9&5?
M0W)Y<'1?<VUI;64Z.B#`X+'P++'8T.C2JM/0(&]P96YS<VP@Q*._Z2X`M,O&
MJ[K#("(E<R(@ROV^W=+RSJJSK+G]U^ZT\[W3RMS6M2S+^=+4SMZWJ+&[L:.T
MY@#3P]+4O.S*T[3+ROV^W<#@T,T@*"5S*2"UQ+/,T/*RHK*[M.;4VM/:S[7-
ML\G/+@"TR[?^SO'&]R`B)7,B(-+1L;O)OK/]+@"TR[?^SO'&]R`B)7,B(-+1
ML;NQH[3F+@`E<R"UQ->BLN'0Z,?STM&QN\F^L_TN`-:XMJBUQ+S'PKRRHK*[
MM.;4VBX`M-/)S]*[N/:RO=;HUJZZ\\G/M*NUQ,K]OMW2Q<JG+@#)S[2KSL2\
M_K*BSK2QN[&CM.8N`'=E871H97(N8V]M(,?XO^G.WK>HRKG3PRX`SMZXO;S^
MO\G6L;W3M/*_JBX`M,O7UK;.UM"P_+JLS*NVX+7$U];*_2[$^M+1RN3(ZR`E
M<R"X]M?6ROT[Q/K*Y,CKM<37ULK]L=C0Z]"AT]H@)7,N`,G/M*O.Q+S^RK&W
MHLGZTKNX]L[*S.(Z("5S(,ZTL;O)S[2K+@#)S[2KSL2\_LJQMZ+)^M*[N/;.
MRLSB.B`E<R"T\]"ALZRY_;W3RMS7[K3SUK4@*"5D(&)Y=&5S*2X`R<^TJ\[$
MO/[*L;>BR?K2N[CVSLK,XCH@O?:RO[?6M<0@)7,@SL2\_K&[R<^TJRX`O.S*
MT]/*O/[*L;>BR?K2N[CVM.W.\RX`N^/(Z[3+S:C1MK*^ROV^W<JQMZ+)^K3M
MSO,N`-3:Q>36P[2PS.76T+>BR?K!R]*[N/:T[<[S+M/0O\G$W,3ZTL7"J<'+
ML=C0Z\SNT+2UQ-?6MLXN`+3+($E-05`@M_[.\<;WLJ+.M-:GL];.Q+S^O-"W
MUL_MN:;$W"X`U>++QKKULKO*Q]7]R+>UQ"!R87(@T;G+]<[$O/XN`-7BR\:Z
M];*[RL?5_<BWM<0@>FEP(-&YR_7.Q+S^+@#5XLO&NO6RN\K'U?W(M[7$T,73
MP[^HNL7"ZRX`M,O7UK;.RL>QV-#HTJJUQ"X`M,O7UK;.Q-K(W=:[O=/*W-7[
MROW*_=?6+@"TR]?6ML[$VLC=UKN]T\K<ROW7UKRPP["ZQ2X`M,O7UK;.Q-K(
MW=:[O=/*W+#+O?C6QLK]UK4N`+3+U]:VSL3:R-VQV-#KSJJVNKK%N_*_U;#7
MM]:X]+7$ROW7U@"QV-#KRL?2N[CVROW7UBX`M,O7UK;.Q-K(W;'8T.NP_+JL
MTKO7Z<JNP?F]^-;&M<0@4D="(-'5R:NT^L+K+,#]R.<@)R,Q,C,T868G+@#5
MXKCVM+#,Y=+1L;NTIL#MN?TN`-7BRL<@)7,N`+3+ROW6M=?NR=FQV-#KRL<@
M,2X`M,NW_L[QQO?.WK>HMM0@>FEP(+RP(&=Z:7`@N/'*O<[$O/Z]^-#0O>+1
MN<OU`+3+S[7-L[6QQ[#*Q\VCT\.UQ->TS*PN`+'8T.O*Q]*[N/;*_=?6+@"T
MR[2PO]JQV-#KTJK3R=&AS^ZTL+_:*$]P=&EO;BG+^;KTO=``RK&\Y`#*L;SD
MU[?7V0#*L;SDN/'*O0#*L<?XT:'4\0!4:6UO<BU,97-T90"QZLSB`,K5O/[(
MRP#(Y[G[TJJXM-&A+,?KU-JUX]&ARO.QZK7$S:S*L;"T($-O;G1R;VR\_"BX
M]LC+O,;+X[OZ*2"[\B!#;VUM86YDO/PHQKNY^[S&R^.[^BDN`+WQS.P`2%1-
M3"#4K<J\SL2\_@"VX+CG`,W0O\O`S<BZM;H`P_?,[`#,P+S3`,S8P:+$X;3O
MNLVVX+#-N.<`U>:[\KS9`-#'QMJV_@#-N\3AR[D`S<&V^L;D`,W!MOK&Y,[$
M("A)4T\M.#@U.2TY*0#-P;_BPOS+N<RY`,S8O\O+N;K-OZV_QLNYR+JUN@#-
MO,W?PJP`RN3(Z\3ZM<31H=3Q.B``U\_-XL_?UKC*_3H@`,WXUK<`S?C6MSH`
MSMJXR;3O`,[:O\O`O`#.WK>HM.;(H2!61E,@Q+_"O"X`UZ*RX<JQSMZWJ-3V
MO-.V[LWBM<33P[NGT,7/HBX`SMZWJ+C$L>0@5D93(,[$O/X@(B5S(B"UQ,BH
MS]XN`,[>MZBQY+C\(%9&4R#.Q+S^("5S+R5S(+7$R*C/WBX`SMZWJ+'DN/S.
MJB`E<RX`SMZWJ,&LO=/6P2!344P@M_[.\<;W+@#.WK>HRKG3PR!34TP@P:R]
MTRX`SMZWJ+BTUL8@5D93(,[$O/XN`,[>MZB]J,&B(%9&4R#$O\*\("(E<R(N
M`,[>MZB]J,&B(%9&4R#$O\*\+@#.WK>HO:C!HB!61E,@SL2\_BX`SMZWJ+VK
MROV^W;WBT;G+]2X`SMZWJ,F^L_T@)7,LM,O$O\*\LJ*WQ[_5L-<`SMZWJ+7=
MN>G)OK/]Q+_"O"X`SMZWJ,F^L_T@5D93(,2_PKPN`,[>MZC)OK/](%9&4R#$
MO\*\.B`E<RX`SMZWJ,F^L_T@5D93(,[$O/X@(B5S(BX`SMZWJ,F^L_T@5D93
M(,[$O/XN`,[>MZBUW;GIR;ZS_2!61E,Z("5S+@#.WK>HQ="VS[6QQ["UQ,2_
MPKPN`,[>MZB]XK^JQK[6I,^XO=H`SMZWJ+S3U-@@)7,@M<2VJ-+EROV^W2X`
MSMZWJ-+&MJ\@5D93(,[$O/XN`,[>MZBT\K^J(%9&4R#.Q+S^("(E<R(N`,[>
MMZC0M,CK(%9&4R#.Q+S^+@#.WK>HM/*_JB!61E,@SL2\_BX`SMZWJ+3ROZK1
MN<OUSL2\_BX`SMZWJ+;!R*$@=F9S<F]O="#$O\*\+@#.WK>HL>2X_"!61E,@
MQ+_"O+7$P_NSQBX`SMZWJ,F^L_T@5D93(,2_PKPZ("5S+@#.WK>HL>2X_"!6
M1E,@SL2\_B`B)7,B(+7$P_NSQBX`SMZWJ+'DN/P@5D93(,[$O/X@)7,O)7,@
MM<3#^[/&+@#.WK>HL>2X_"!61E,@SL2\_K7$P_NSQBX`SMZWJ->JN[L@5V]R
M9"#.Q+S^`,[>MZC0M,CK(%9&4R`B)7,B(,[$O/XN`,[>MZC0M,CK(%9&4R#.
MQ+S^ROV^W2X`S\*[KL_?`,BAS_NX_+C$`+BTU*T`M_[.\<;WP:R]T\JQMZ+)
M^LZTU*3&VK7$N]C3ICH@`+>BR?K.M-2DQMJUQ+O8TZ8LT\FW_L[QQO<Z(`#-
M\M/#PNL@*%541BTX*0"PHL"MLJ[!JKK/Q_6SI+GZ`-.BN?H`P\"Y^@!5;FET
M960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`M:74J@#.M-:JM<0`
MSK36JK7$T\.[I\/[N_+#W,+K+@#.M-:GL]:UQ,"IU;G#^P"QY+C\`+C\T,(@
M)7,`N/S0PM/#NZ<`N/S0PK/,T/+2T<F^L_TN`,G/M*L`TM')S[2KR_G3T-.F
MT\.SS-#RM<3%Y-;#SL2\_K6]M_[.\<;W+@#.VL"MN><`T\.[IR`E<R#.M,VH
MN?T@)7,@M<3*VLBHT>G6I"X`T\.[I[G<P.T`T\.[I]&AS^X`T\.[I]>BLN$`
MM,O5OLRHM<33P[NGUZ*RX<^US;/2T<VCT\,N`-/#NZ?#^P#3P[NGP_LZ`-/#
MNZ<Z(`#/M<VSUM"UQ-/#NZ<Z`,[:U\BQ\+_+R[G,N0!61E,@Q+_"O+*BLKNT
MYM3:+@"\V<;:`-+1U=*UO=/0T*>UQ+78M>,Z(`#3T-"GT-0`TM2WUM;3SJJU
MI<Z[*+33S];4VL;PR^,I`-:U`,W?PK.PHLV\`+'DNZ\`SJ_$VLCPP*T`T>G6
MI,JGL-P@+2"TR]/*O/Z_R<3<TM'4XLC+R</7U+3;N,0N`+#FL;X`L.:QOK_8
MUL8`U+W$SP#4O<3/SL0@*%9)4T-)22D`O.S*TR`E<P#4VM#"M+"_VK3ROZH`
MTM0@)7,@LNF_M`#3HLKTSJRV^[ZIR+JUN@##P,KTSJR^J<BZM;H`Q-R\^[;(
M`,3<O/NVR#H@`-+BM//`^[?\M<*WY[7GT,6YJ\N^S;BY_2!33510`+ZON.8`
MOJ^XYB$A(2"TTR`E<R#*UK:OR;ZS_;/,T/(N`,W?P/O+N;K-N+O-O,BZM;H`
MOJ^XY@#0Q\;:R/T`S.S&^-2DLN(`S?C5O@#-^-6^`,._UMP`N[;3K0"[MM.M
MM;T@)7,`N[;3K2P@)7,`SO?%MR`H25-/+3@X-3DM,2D`SO?%MR`H25-/+3@X
M-3DM,34I`,[WR/:Y_L"M`+7'PKRZ\].FN,//R,_4RKX@)7,@Q,32N[CVTZ;3
MP[/,T/(_`-?6MLZUQ+?6N/37UK?[/P#2_<KVM<3'L+6\M_L_`+?GR]DHO=HI
M`+?GR]DZ`+?GR]DZ(`"P[+FKRM*UV-:W`+#LN:O*TK7GN[``6#4P.78S(,"I
MU;G#^P#$Z@#$Z@!986AO;R`A(+78S;P`P[_$Z@#2LL/%`,K'M<0LSM+-K-+B
M`,3ZM;''L,JYT\.TO\[$U]:QX-"TQ*/*O2X@RKG3PR!;/#Y=(+"TQ:6_R<?0
MN[O.JLWXTK.QX-"TQ*/*O2X`Q/JRHLZTRN3(Z]*[N/:ZS[>HM<2UY]?3T\J\
M_K78UK<N`,3ZLJ+.M-/)M;S(Z[7$SL2\_M;0MM33L\C.NL[7UK;.M;T@)7,`
MQ/K2T;ZMUZ+/^BX`Q/JQV-#KRN3(Z]*[N/:ZS[>HM<36M2X`Q/JQV-#KS\BY
MYKNNNL/*_;[=RO<H1&%T851R964IM_[.\;;+LL7$W+S,T/C*N=/#T,+3P[NG
MUZ*RX;?^SO$N`,?KP^C*]L[*S.*CK-3:Q/JTJ\O-SLK,XK&HN.;6KL>P+@#$
M^K'8T.O*Y,CKM,O!K+W3R_G6N,_RM<3-^-:W`,?KUKBVJ-*JR;ZS_;7$M_[.
M\<;W+@#'Z]:XMJC2JLF^L_VUQ-/#NZ<N`,?KUKBVJ-*JT,+4]K7$T\.[IRX`
MQ^O6N+:HTJJX_-#"M<33P[NG+@#'Z]:XMJC2JM:TT-"UQ-?WT\,N`,3ZM<0@
M)7,@N^'&VM+1N?W*L2['Z];8T,*UQ\*\+@#$^K7$M>?7T]/*O/ZUV-:W`,3Z
MM<30Q<^B`-?4M-/$^K7$("5S(+OAQMJ_JLJ\TM3`M,3ZM<32\LS8S?BUV-:W
MTM&QY+C\+B#.JK&CNZ3$^K7$L++(J\;PO/NCK,3ZL=C0Z];8T,*UQ\*\+@#$
M^K7$T-7#^P#$^K7$T>G6I+;+LJ+.M-:GL];!T+/VT\.[I[ORN,.YIL3<TM&Q
MN[G8L=4N`-?4M-/$^K7$("5S(+OAQMJ_JLJ\TM3`M,3ZM<3DK\#`QO?+QKKU
MTM&QY+C\+B#.JK&CNZ3$^K7$L++(J\;PO/NCK,3ZL=C0Z];8T,*UQ\*\+@#$
M^K7$Y*_`P,;WLJ+.M-:GL];5XKCVN:;$W"X`Q/JUL<>PR_G%Y-;#M<3*L<?X
M.@#$^K7$T:'/[M+1N/S0PBX`Q/JUQ-2VL\RW_L[QQO<Z`,3/R[G`K;?R`-3Z
MTL&V^P#4WK'(T<<`O?*PS;*\SJ0`6\[*S.*QJ+CF70!;SKO3VM#0("5S(+FR
M("5S(-#070#.Q+S^`+33("5S("@E<RD@T]H@)7,@)7,`RK$Z`,&BO+0`P_NS
MQ@#)T,ZTRK7/UBX`R=#.M,JUS]8N`-39M,[*Y,CKQ/JUQ,/<PNO2U,BWR,_.
MWL[S`,ZTP_S#^P#3P[NGT:'4\0!V0V%R9`#0Q\;:.@!W96%T:&5R+F-O;2#-
M^-6^````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L;V-A;&4O>FA?5%<O````````````````````
M````````````````````````````````````````````````````````````
M`#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S
M-S4T`#`R,#$U,0`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]Z:%]4
M5R]H96QP+GAM;```````````````````````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(U-#``,3`U,34T,S,W-30`,#(Q-C(T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_>&UL('9E<G-I;VX](C$N,"(@
M96YC;V1I;F<](D))1S4B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L92]Z
M:%]45R]H96QP+GAM;"QV(#$N,RXQ,"XQ(#(P,#8O,#(O,3`@,30Z,#$Z,C,@
M:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](G-U;6UA<GDB(&UD
M-3TB-CAC83,S9C=F,&,Y86%E-&,Q,#-E8C0W-#DR8V1C,34B('-T871E/2)U
M<'1O9&%T92(^"CQT:71L93ZD2J1FK;:ML3PO=&ET;&4^"B`\<&%R83X*(""S
M;ZW3K;:ML;2CJ-&ITJ:SP_:I\Z=!JKJMJ\))NDNM;KCJL%2A0ZC2IG"A0:6F
MI6FE2,7CI=RE6*9BIT&JNJ:LI?.]8Z2DI=BK9::SM%BKRK=SMFRE\Z%#IN:H
MQK[DI*2G6;%.J-.H[*JZJ,:QH:%!I4Z_[,.OI*2JNJ:SK?ZHQZO=O^RHQK:U
MH4&W<[M$JD&PR*JZL\RW<Z[XKJ>UI;6EH4.FT[-OJ,>Z2ZUNIE"NR:1=I5VG
M=*1&I]:QMJ5<K^"A0<2TIG"V;*7SO&>G0*%!J]BEW[=SJKJFYJC&ON2HQJ7S
MM:6UI:%#"B`\+W!A<F$^"B`\<&%R83X*(*;3LV^HQ[I+K6ZJNJ2ZKF6E::5(
MQ?VG0;AGI=&JJ:VQL'2X;:OVMG.FVZ;FIG>QQJ%#J-*F<*%!IT&E::5(O^^^
MW*UNI5ND2JW^I$"HQ[:UI=BH[*1*I&:MMJVQI*2HP['&ID.HY+:VI\>A0PH@
M/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B(&UD-3TB
M8CAC9C!A93$Y934W9&9A,&,R8CDV,F4U,38W.#)F-#<B('-T871E/2)U<'1O
M9&%T92(^"CQT:71L93[`LZ7.M7NFH;[)Q/VF0SPO=&ET;&4^"B`\<&%R83X*
M(""F8JVVK;&SS*6JP^2JNJ1`L<:YSZ[7NMFLL,"SI<ZU>Z:AOLG$_:9#H4/"
M2;_OI%>ML:JZI?2D0*W3I'"YSZ7<L4ZE:;NTJ?:GUK-TJKJDP;2KJ?.DHZ90
MJKK`LZ7.M7NFH:%#"B`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!R969S+61O7VUA:6YT96YA;F-E(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB
M9&0Y-61F,#=A,#,P,S$R,S)B865A.3$Y,C@X8C)D,#`B/@H@("`@/'1I=&QE
M/K"^IFZS7:EW.B"Z^\5`.B"P]:;FNOO%0#PO=&ET;&4^"B`@("`\<&%R83X*
M("`@(*3$O^^FN:1`MK6EV*%!IG"J1Z=!I\:QYJ9BM6ZD2JJZIE"NR;#UIN:Z
M^\5`I'6G0*%#"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!R969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B('-T871E/2)U<'1O9&%T92(@
M;60U/2)A,C$Q-C)C9&9F,V(Q9#AF865A9&(W,CDV,C0P,#,V92(^"B`@("`\
M=&ET;&4^L+ZF;K-=J7<Z(+K[Q4`Z(+U4NWNP]:;FNOO%0#PO=&ET;&4^"B`@
M("`\<&%R83X*("`@(*3$O^^FN:1`MK6EV*%!IG"J1Z=!I\:QYJ9BL/6FYKK[
MQ4"D=:=`JV6[W:9!IKB\>*A$IT&JNJ90MTZA0Z=?JVBITJ:SNOO%0*1UIT"Q
M3JGSM6ZD2JOAIMNPRK#UIN:A0PH@("`@/"]P87)A/@H@(#PO96YT<GD^"CPO
M:&5L<#X*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&]C86QE+WIH7U17+TQ#7TU%4U-!1T53+P``````````
M```````````````````````````````````````````````````````P,#`P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U-``P
M,C$W,S8`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O>FA?5%<O3$-?
M34534T%'15,O:&]R9&4N;6\`````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,S0Q
M,#8S`#$P-3$U-#,S-S4T`#`R,S0P,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#>$@25`````$T'```<````A#H``,<)``#L
M=`````````B<```.````"9P```\````8G```#0```"B<```(````-IP```L`
M```_G```#````$N<```$````6)P``!@```!=G```&P```':<```M````DIP`
M`!T```#`G```)````-Z<```I`````YT``!D````MG0``)@```$>=```,````
M;IT``"0```![G0``#P```*"=```+````L)T```X```"\G0``!0```,N=```H
M````T9T```@```#ZG0``"@````.>```5````#IX``!(````DG@``"P```#>>
M``"%````0YX```X```#)G@``"@```-B>```-````XYX```X```#QG@``$0``
M``"?```-````$I\```P````@GP``#0```"V?```&````.Y\``)0```!"GP``
M"@```->?```/````XI\``!@```#RGP``#`````N@```.````&*````X````G
MH```"````#:@```)````/Z```"X```!)H```&@```'B@```R````DZ```#@`
M``#&H```5````/^@``!1````5*$``%H```"FH0``5P````&B```T````6:(`
M``D```".H@``#0```)BB```'````IJ(```H```"NH@``#P```+FB```%````
MR:(```8```#/H@``$0```-:B```(````Z*(```D```#QH@``"0```/NB```E
M````!:,``"`````KHP``$P```$RC```0````8*,```\```!QHP``"@```(&C
M```#````C*,```\```"0HP``%````*"C```)````M:,```T```"_HP``$@``
M`,VC```9````X*,``!X```#ZHP``#P```!FD```*````*:0```\````TI```
M"````$2D```D````3:0``!0```!RI```%@```(>D```(````GJ0``$X```"G
MI```+0```/:D```9````)*4```<````^I0``#````$:E```L````4Z4```X`
M``"`I0```P```(^E```+````DZ4```<```"?I0``!P```*>E```%````KZ4`
M``4```"UI0``"@```+NE```#````QJ4``!<```#*I0``"@```.*E```/````
M[:4```X```#]I0``&`````RF```C````):8```X```!)I@``%````%BF```7
M````;:8``!<```"%I@``%P```)VF```3````M:8```\```#)I@``#@```-FF
M```?````Z*8``!T````(IP``!P```":G```&````+J<```@````UIP``#P``
M`#ZG```&````3J<```H```!5IP``$P```&"G```+````=*<``!````"`IP``
M%0```)&G```5````IZ<```<```"]IP``$````,6G```%````UJ<``!4```#<
MIP``$0```/*G```,````!*@``#L````1J```.````$VH```)````AJ@```<`
M``"0J```%````)BH```#````K:@```4```"QJ```$````+>H```)````R*@`
M`!,```#2J```.0```.:H```2````(*D``"<````SJ0``+````%NI```J````
MB*D``"4```"SJ0``"@```-FI```&````Y*D```D```#KJ0``!P```/6I```O
M````_:D``#<````MJ@``+@```&6J``!5````E*H``"T```#JJ@``+0```!BK
M```]````1JL``#\```"$JP``+0```,2K``!`````\JL``",````SK```(P``
M`%>L``!`````>ZP``"T```"\K```,P```.JL```E````'JT``!4```!$K0``
M&0```%JM```I````=*T``"0```">K0``*````,.M```1````[*T```H```#^
MK0``"@````FN```0````%*X``!8````EK@``%@```#RN```'````4ZX```<`
M``!;K@``%````&.N```*````>*X```@```"#K@``)P```(RN```(````M*X`
M``<```"]K@``!P```,6N```&````S:X```4```#4K@``!P```-JN```&````
MXJX```@```#IK@``*0```/*N```.````'*\```H````KKP``!````#:O```'
M````.Z\```D```!#KP``!@```$VO```1````5*\```<```!FKP``%@```&ZO
M```$````A:\```@```"*KP``!@```).O```-````FJ\```8```"HKP``'@``
M`*^O```1````SJ\```@```#@KP``#0```.FO```,````]Z\```<````$L```
M`P````RP```#````$+```!<````4L```$P```"RP```=````0+````@```!>
ML```!````&>P```(````;+````@```!UL```00```'ZP```:````P+```"``
M``#;L```%0```/RP```&````$K$```8````9L0``%0```""Q```8````-K$`
M`"(```!/L0``+@```'*Q```=````H;$``"$```"_L0``5````.&Q```I````
M-K(```H```!@L@``!P```&NR```5````<[(```X```")L@``"@```)BR```/
M````H[(```T```"SL@``#P```,&R```-````T;(```D```#?L@``%````.FR
M```&````_K(``!@````%LP``'0```!ZS```3````/+,``!$```!0LP``%```
M`&*S```$````=[,```8```!\LP``%````(.S``!4````F+,``&0```#MLP``
M!````%*T```.````5[0```4```!FM```!0```&RT```;````<K0``!H```".
MM```$P```*FT```1````O;0``!$```#/M```'````.&T```J````_K0``!``
M```IM0``(0```#JU```%````7+4``!,```!BM0``"P```':U```2````@K4`
M``H```"5M0``#P```*"U```-````L+4``!$```"^M0``$P```-"U```,````
MY+4```8```#QM0``#````/BU```&````!;8``!<````,M@``$````"2V```1
M````-;8```@```!'M@``!0```%"V```,````5K8``!````!CM@``!0```'2V
M```-````>K8```8```"(M@``!P```(^V```-````E[8```<```"EM@``"P``
M`*VV```'````N;8```<```#!M@``"0```,FV```)````T[8```H```#=M@``
M&0```.BV```]`````K<``!T```!`MP``#````%ZW```0````:[<```4```!\
MMP``)0```(*W```2````J+<``!,```"[MP``*P```,^W```[````^[<``"``
M```WN```"````%BX```V````8;@``"$```"8N```$````+JX```(````R[@`
M``P```#4N```!````.&X```/````YK@```X```#VN```"@````6Y```-````
M$+D``!\````>N0``'````#ZY```A````6[D``!X```!]N0``&0```)RY```>
M````MKD``!T```#5N0``&P```/.Y```@````#[H``"X````PN@``)@```%^Z
M```<````AKH``!X```"CN@``'````,*Z```F````W[H``"L````&NP``,P``
M`#*[```F````9KL``"L```"-NP``.````+F[```=````\KL``!4````0O```
M+P```":\```@````5KP``!(```!WO```*0```(J\```>````M+P``"````#3
MO```$@```/2\``"B````![T``!8```"JO0``(P```,&]```H````Y;T``"D`
M```.O@``*````#B^```?````8;X``!4```"!O@``(````)>^```E````N+X`
M`"@```#>O@``+0````>_```P````-;\``)(```!FOP``(0```/F_```6````
M&\```!P````RP```)@```$_````J````=L```$$```"AP```1````./````,
M````*,$```<````UP0``!P```#W!```&````1<$```T```!,P0``$````%K!
M```2````:\$``!,```!^P0``$@```)+!```'````I<$```0```"MP0``$```
M`++!```,````P\$```X```#0P0``#0```-_!```/````[<$``!,```#]P0``
M#0```!'"```H````'\(```,```!(P@``#0```$S"```&````6L(``!$```!A
MP@``%P```'/"```;````B\(```X```"GP@```@```+;"``!)````N<(```4`
M```#PP``$`````G#```/````&L,```0````JPP``#0```"_#```.````/<,`
M``,```!,PP``#@```%##```(````7\,```\```!HPP``#P```'C#```'````
MB,,```T```"0PP``$````)[#```-````K\,```L```"]PP``!@```,G#```+
M````T,,```P```#<PP``"@```.G#```1````],,``!D````&Q```"P```"#$
M```-````+,0``"(````ZQ```&P```%W$```T````><0```H```"NQ```&```
M`+G$```9````TL0``!8```#LQ```(@````/%```-````)L4```<````TQ0``
M%````#S%```+````4<4``"(```!=Q0``+P```(#%```+````L,4```D```"\
MQ0``&0```,;%```+````X,4``!<```#LQ0``%P````3&```)````',8``!8`
M```FQ@``#P```#W&```9````3<8``!8```!GQ@``#@```'[&```8````C<8`
M``@```"FQ@``#0```*_&```F````O<8``$,```#DQ@``"````"C'```2````
M,<<``!\```!$QP``"````&3'```+````;<<``"\```!YQP``#@```*G'```%
M````N,<```8```"^QP```P```,7'```'````R<<```0```#1QP``"@```-;'
M```*````X<<```\```#LQP``$````/S'```7````#<@``!$````ER```&0``
M`#?(```7````4<@```D```!IR```!0```'/(```+````><@```H```"%R```
M!0```)#(```-````EL@``!L```"DR```%P```,#(```4````V,@```D```#M
MR```#@```/?(```-````!LD``!(````4R0``.````"?)```@````8,D```@`
M``"!R0``#@```(K)``![````F<D``!@````5R@``$0```"[*```'````0,H`
M``4```!(R@``&````$[*```>````9\H``!L```"&R@``&0```*+*```;````
MO,H``!,```#8R@``!P```.S*```(````],H```8```#]R@``!@````3+```0
M````"\L```\````<RP``$````"S+```/````/<L```L```!-RP``#P```%G+
M```,````:<L```\```!VRP``!P```(;+```&````CLL```X```"5RP``#```
M`*3+```/````L<L```@```#!RP``"````,K+```3````T\L``!X```#GRP``
M(0````;,```@````*,P``!D```!)S```%P```&/,```E````>\P``!<```"A
MS```%@```+G,```$````T,P``!L```#5S```#0```/',```,````_\P```,`
M```,S0``!0```!#-```(````%LT```H````?S0``#````"K-```+````-\T`
M`!````!#S0``#````%3-```$````8<T``!,```!FS0``%````'K-```,````
MC\T```D```"<S0``#@```*;-```+````M<T``!L```#!S0``!P```-W-```'
M````Y<T```H```#MS0``#0```/C-```)````!LX```0````0S@``!0```!7.
M```#````&\X``!@````?S@``"@```#C.```$````0\X``"8```!(S@``#@``
M`&_.``!\````?LX``!4```#[S@``!0```!'/```'````%\\```P````?SP``
M"````"S/```*````-<\```8```!`SP``"````$?/```"````4,\```8```!3
MSP``!@```%K/```4````8<\```T```!VSP``$````(3/```;````E<\```0`
M``"QSP``"0```+;/```0````P,\```D```#1SP``"0```-O/```%````Y<\`
M``@```#KSP``!@```/3/```9````^\\```X````5T```!P```"30```'````
M+-````4````TT```"0```#K0```*````1-````(```!/T```!@```%+0```+
M````6=````T```!ET```"0```'/0```&````?=```!(```"$T```"0```)?0
M```'````H=```!0```"IT```'0```+[0``!"````W-```"4````?T0``)0``
M`$71```&````:]$```H```!RT0``!````'W1```)````@M$```@```",T0``
M$0```)71```)````I]$```8```"QT0``#0```+C1```&````QM$```0```#-
MT0``'@```-+1```%````\=$```X```#WT0``!`````;2```&````"](```<`
M```2T@``(0```!K2```-````/-(``!4```!*T@``!@```&#2```$````9](`
M`!$```!LT@``!@```'[2```*````A=(``"(```"0T@``!````+/2```%````
MN-(``!T```"^T@``!````-S2```,````X=(```X```#NT@``"@```/W2```(
M````"-,```D````1TP``!0```!O3```Z````(=,``#````!<TP``-0```(W3
M```I````P],``$<```#MTP``.````#74```I````;M0``#\```"8U```+@``
M`-C4```M````!]4``!\````UU0``#P```%75```2````9=4```L```!XU0``
M)@```(35```I````J]4``"0```#5U0``)@```/K5```(````(=8```H````J
MU@``"0```#76```'````/]8``"````!'U@``(````&C6```F````B=8```H`
M``"PU@``&0```+O6```I````U=8``!(```#_U@``!P```!+7```*````&M<`
M``P````EUP``#P```#+7```0````0M<``$````!3UP``<````)37``!F````
M!=@```X```!LV```"0```'O8```*````A=@``!(```"0V```$P```*/8```,
M````M]@```8```#$V```#P```,O8```2````V]@``!````#NV```$0```/_8
M```<````$=D``",````NV0``:@```%+9```/````O=D```4```#-V0``$```
M`-/9```)````Y-D```0```#NV0``"P```//9```@````_]D``!0````@V@``
M#````#7:```,````0MH```\```!/V@``%0```%_:```I````==H``"H```"?
MV@``)@```,K:```G````\=H``"D````9VP``*@```$/;```9````;ML``$(`
M``"(VP``$0```,O;```2````W=L``!,```#PVP``%`````3<```/````&=P`
M`!8````IW```%P```$#<```0````6-P``!$```!IW```-````'O<```3````
ML-P``!(```#$W```-0```-?<```4````#=T```<````BW0``#````"K=```@
M````-]T``!````!8W0``%````&G=```1````?MT``!<```"0W0``'````*C=
M```3````Q=T``!0```#9W0``&@```.[=```1````"=X``!H````;W@``'@``
M`#;>```:````5=X``!,```!PW@``%0```(3>```1````FMX``!<```"LW@``
M%````,3>```7````V=X``!4```#QW@``"0````??```0````$=\``!D````B
MWP``!````#S?```'````0=\```L```!)WP``$0```%7?```&````9]\```8`
M``!NWP``!@```'7?```%````?-\```<```""WP``!P```(K?```%````DM\`
M`!8```"8WP``!@```*_?```&````MM\```0```"]WP``!````,+?```'````
MQ]\```X```#/WP``#````-[?```,````Z]\```T```#XWP``"@````;@```.
M````$>````4````@X```*````";@```.````3^````P```!>X```#P```&O@
M```*````>^````@```"&X```"0```(_@```K````F>````0```#%X```"```
M`,K@```F````T^```!(```#ZX```#P````WA```&````'>$```H````DX0``
M!P```"_A```(````-^$``"````!`X0``"0```&'A```4````:^$```P```"`
MX0``#0```(WA```.````F^$``!8```"JX0``$0```,'A```&````T^$```,`
M``#:X0``!@```-[A```'````Y>$```0```#MX0``"P```/+A```+````_N$`
M``<````*X@``!P```!+B```6````&N(```T````QX@``#0```#_B```*````
M3>(``!````!8X@``#P```&GB```1````>>(``!<```"+X@``"@```*/B```1
M````KN(```@```#`X@``!````,GB```/````SN(``#H```#>X@``!0```!GC
M```>````'^,```X````^XP``$````$WC```+````7N,```P```!JXP``"0``
M`'?C```'````@>,```H```")XP``"0```)3C```.````GN,``!````"MXP``
M&P```+[C```8````VN,``!H```#SXP``"@````[D```)````&>0```H````C
MY```#````"[D```/````.^0```@```!+Y```!@```%3D```'````6^0```4`
M``!CY```"P```&GD``!'````=>0```T```"]Y```"0```,OD```$````U>0`
M``,```#:Y```$P```-[D```3````\N0``!,````&Y0``"@```!KE```"````
M)>4```0````HY0``)0```"WE```#````4^4```4```!7Y0``*@```%WE```*
M````B.4```4```"3Y0``!````)GE```*````GN4```T```"IY0``!@```+?E
M```(````ON4```@```#'Y0``!````-#E```%````U>4``&@```#;Y0``"0``
M`$3F```,````3N8```4```!;Y@``!@```&'F```;````:.8``"\```"$Y@``
M$````+3F```*````Q>8```\```#0Y@``"@```.#F```)````Z^8``!,```#U
MY@``&P````GG```8````)><``!<````^YP``'P```%;G```.````=N<```,`
M``"%YP``!P```(GG```(````D><```<```":YP``"@```*+G```+````K><`
M``<```"YYP``40```,'G```0````$^@```P````DZ```&@```#'H``!*````
M3.@``!D```"7Z```!@```+'H```:````N.@``"4```#3Z```!@```/GH```&
M`````.D``!\````'Z0``!@```"?I```)````+ND``!@````XZ0``%P```%'I
M```H````:>D```8```"2Z0``#0```)GI```B````I^D``%<```#*Z0``$P``
M`"+J```C````-NH``!,```!:Z@```@```&[J```+````<>H```@```!]Z@``
M#0```(;J```*````E.H```<```"?Z@``%````*?J```&````O.H```@```##
MZ@``#@```,SJ```'````V^H```H```#CZ@``"P```.[J```R````^NH```<`
M```MZP``#````#7K```-````0NL```P```!0ZP``"0```%WK```)````9^L`
M``H```!QZP``!P```'SK```)````A.L```<```".ZP``"@```);K```;````
MH>L``!(```"]ZP``"@```-#K```6````V^L```D```#RZP``$````/SK```'
M````#>P``!(````5[```!````"CL```'````+>P```4````U[```!0```#OL
M```+````0>P``!0```!-[```$0```&+L```:````=.P``!8```"/[```%```
M`*;L```7````N^P``!@```#3[```'````.SL```9````">T```<````C[0``
M!0```"OM```-````,>T```P````_[0``$0```$SM```(````7NT``!<```!G
M[0``"P```'_M```,````B^T``!\```"8[0``&@```+CM```3````T^T```0`
M``#G[0``"@```.SM```$````]^T```P```#\[0``!0````GN```)````#^X`
M``4````9[@``!P```!_N```%````)^X```0````M[@```@```#+N```X````
M->X``"P```!N[@``$@```)ON```I````KNX``#(```#8[@``"@````OO```L
M````%N\``"X```!#[P``,P```'+O```S````IN\``#@```#:[P``#P```!/P
M```8````(_```!`````\\```#P```$WP```3````7?```!4```!Q\```%```
M`(?P```2````G/```!0```"O\```+0```,3P```M````\O```#$````@\0``
M+@```%+Q```O````@?$``"P```"Q\0``8@```-[Q```3````0?(```T```!5
M\@``"````&/R```7````;/(```@```"$\@``#````(WR```K````FO(``"$`
M``#&\@``&@```.CR```)`````_,``$4````-\P``00```%/S```$````E?,`
M`!,```":\P``%````*[S```.````P_,``!,```#2\P``&````.;S```&````
M__,```D````&]```"@```!#T```/````&_0``!`````K]```!P```#ST```.
M````1/0```4```!3]```&P```%GT```(````=?0```8```!^]```%````(7T
M```1````FO0```X```"L]```.````+OT```"````]/0```8```#W]```#@``
M`/[T```%````#?4```<````3]0``!@```!OU```H````(O4```P```!+]0``
M'````%CU```$````=?4``"D```!Z]0``'P```*3U``!<````Q/4``!0````A
M]@``/@```#;V```?````=?8``!````"5]@``!P```*;V```.````KO8```P`
M``"]]@``#````,KV```3````U_8```H```#K]@``'0```/;V```9````%/<`
M``4````N]P``$0```#3W```1````1O<``"0```!8]P``$@```'WW```5````
MD/<``!(```"F]P``#@```+GW```9````R/<```@```#B]P``"0```.OW```-
M````]?<```H````#^```!P````[X```/````%O@```8````F^```"P```"WX
M```:````.?@```H```!4^```!P```%_X```(````9_@```4```!P^```'P``
M`';X```&````EO@``!````"=^```"````*[X```-````M_@```@```#%^```
M'@```,[X```2````[?@``"P`````^0``&@```"WY```)````2/D```H```!2
M^0``%0```%WY```%````<_D``!0```!Y^0``!````([Y```0````D_D```8`
M``"D^0``!P```*OY```>````L_D``"@```#2^0``"@```/OY```<````!OH`
M`!$````C^@``"P```#7Z```:````0?H``!0```!<^@``!````''Z```$````
M=OH```L```![^@``!0```(?Z```&````C?H```@```"4^@``!@```)WZ```;
M````I/H``#0```#`^@``-````/7Z```@````*OL``"D```!+^P``(````'7[
M``!!````EOL``!H```#8^P``*````//[```I````'/P``%````!&_```(@``
M`)?\```&````NOP```@```#!_```!0```,K\```(````T/P``!D```#9_```
M&0```//\```J````#?T``",````X_0``&0```%S]```N````=OT``#0```"E
M_0``"````-K]```7````X_T```H```#[_0``!P````;^```A````#OX``!``
M```P_@``#@```$'^```+````4/X```<```!<_@``$P```&3^```(````>/X`
M``L```"!_@``"@```(W^```4````F/X```\```"M_@``,@```+W^```+````
M\/X```4```#\_@``!0````+_```%````"/\``!<````._P``#P```";_```$
M````-O\```H````[_P``"0```$;_```+````4/\```T```!<_P``#````&K_
M```.````=_\```4```"&_P``!````(S_```-````D?\``#(```"?_P``10``
M`-+_```7````&``!``<````P``$`'@```#@``0`4````5P`!``4```!L``$`
M%````'(``0`&````AP`!``<```".``$`#@```)8``0`J````I0`!``8```#0
M``$`#````-<``0`-````Y``!`!$```#R``$`"P````0!`0`V````$`$!``H`
M``!'`0$`(@```%(!`0`+````=0$!``\```"!`0$`,@```)$!`0`E````Q`$!
M`#````#J`0$`,0```!L"`0`M````30(!``X```![`@$`!0```(H"`0`.````
MD`(!`!,```"?`@$`$@```+,"`0`'````Q@(!`!$```#.`@$`$P```.`"`0`'
M````]`(!`!0```#\`@$`&````!$#`0`'````*@,!``4````R`P$`#````#@#
M`0`,````10,!`!(```!2`P$`!````&4#`0`'````:@,!``H```!R`P$`"P``
M`'T#`0`,````B0,!``X```"6`P$`#@```*4#`0`%````M`,!``4```"Z`P$`
M+@```,`#`0`F````[P,!`",````6!`$``P```#H$`0`2````/@0!``8```!1
M!`$`'@```%@$`0`8````=P0!`"4```"0!`$`#0```+8$`0`)````Q`0!``,`
M``#.!`$`!P```-($`0`*````V@0!``(```#E!`$`#````.@$`0`5````]00!
M``L````+!0$`&0```!<%`0`@````,04!`!(```!2!0$`!0```&4%`0`*````
M:P4!`!4```!V!0$`$@```(P%`0`,````GP4!``0```"L!0$`"0```+$%`0`'
M````NP4!``P```##!0$`4@```-`%`0`7````(P8!`"0````[!@$`$@```&`&
M`0`'````<P8!``8```![!@$`#@```((&`0`,````D08!``T```">!@$`%0``
M`*P&`0`2````P@8!``\```#5!@$`%````.4&`0`*````^@8!`!L````%!P$`
M$````"$'`0`+````,@<!`&D````^!P$`&@```*@'`0`7````PP<!`"<```#;
M!P$`&@````,(`0`7````'@@!`!L````V"`$`&0```%((`0`?````;`@!`!,`
M``","`$`"````*`(`0`'````J0@!``@```"Q"`$`"0```+H(`0`5````Q`@!
M``T```#:"`$`(P```.@(`0`-````#`D!`!,````:"0$`"````"X)`0`#````
M-PD!`$8````["0$`/P```(()`0`W````P@D!`%<```#Z"0$`!0```%(*`0`?
M````6`H!`"\```!X"@$`"@```*@*`0`(````LPH!``T```"\"@$`+0```,H*
M`0`$````^`H!`$\```#]"@$`)0```$T+`0`+````<PL!`!\```!_"P$`'0``
M`)\+`0`E````O0L!`"````#C"P$`)`````0,`0`@````*0P!``L```!*#`$`
M!P```%8,`0`-````7@P!``P```!L#`$`%P```'D,`0`&````D0P!``P```"8
M#`$`!P```*4,`0`)````K0P!`!,```"W#`$`"0```,L,`0`$````U0P!`!``
M``#:#`$`"````.L,`0`(````]`P!``0```#]#`$`"P````(-`0`,````#@T!
M`!(````;#0$`$0```"X-`0`,````0`T!``\```!-#0$`!P```%T-`0`-````
M90T!`!0```!S#0$`#@```(@-`0`,````EPT!`!L```"D#0$`+````,`-`0`3
M````[0T!``8````!#@$`!P````@.`0`3````$`X!``4````D#@$`!````"H.
M`0`7````+PX!``H```!'#@$`#````%(.`0`)````7PX!``8```!I#@$`"0``
M`'`.`0`(````>@X!``D```"##@$`"@```(T.`0`1````F`X!``8```"J#@$`
M#@```+$.`0`.````P`X!``T```#/#@$`"P```-T.`0`=````Z0X!``L````'
M#P$``@```!,/`0`<````%@\!``<````S#P$`!@```#L/`0!D````0@\!``D`
M``"G#P$`!P```+$/`0`F````N0\!`#@```#@#P$`&@```!D0`0`J````-!`!
M`#L```!?$`$`*````)L0`0`T````Q!`!`!D```#Y$`$`%0```!,1`0`%````
M*1$!``<````O$0$`"````#<1`0`'````0!$!``4```!($0$`!P```$X1`0`.
M````5A$!``D```!E$0$`!@```&\1`0`(````=A$!``L```!_$0$`!P```(L1
M`0`(````DQ$!``<```"<$0$`%@```*01`0`)````NQ$!``8```#%$0$`"P``
M`,P1`0`0````V!$!``8```#I$0$`'````/`1`0`4````#1(!``<````B$@$`
M$0```"H2`0`(````/!(!``X```!%$@$`"````%02`0`%````71(!`!````!C
M$@$`$````'02`0`&````A1(!`!D```",$@$`"@```*82`0`<````L1(!``<`
M``#.$@$`!0```-82`0`0````W!(!`!0```#M$@$`"P````(3`0`-````#A,!
M`"@````<$P$`&````$43`0`7````7A,!``0```!V$P$`"0```'L3`0`*````
MA1,!``<```"0$P$``@```)@3`0`.````FQ,!``@```"J$P$`(P```+,3`0`X
M````UQ,!`"8````0%`$`,0```#<4`0`G````:10!`&0```"1%`$`%````/84
M`0!5````"Q4!`#@```!A%0$`2@```)H5`0!;````Y14!`"@```!!%@$`.```
M`&H6`0`H````HQ8!`"P```#,%@$`)@```/D6`0`;````(!<!`#X````\%P$`
M(P```'L7`0`7````GQ<!`$@```"W%P$`A0`````8`0`P````AA@!`"4```"W
M&`$`00```-T8`0!;````'QD!`$D```![&0$`,0```,49`0`=````]QD!`!@`
M```5&@$`*P```"X:`0`A````6AH!`!\```!\&@$`*P```)P:`0`A````R!H!
M`"<```#J&@$`.@```!(;`0`=````31L!`!$```!K&P$`,P```'T;`0`E````
ML1L!`"<```#7&P$`(````/\;`0`?````(!P!`#````!`'`$`:0```'$<`0`Q
M````VQP!`$$````-'0$`,P```$\=`0`E````@QT!`#T```"I'0$`90```.<=
M`0!-````31X!`"\```";'@$`+@```,L>`0`P````^AX!`%0````K'P$`6@``
M`(`?`0!(````VQ\!`$H````D(`$`,@```&\@`0`O````HB`!`"P```#2(`$`
M+0```/\@`0`7````+2$!`"4```!%(0$`,@```&LA`0`I````GB$!`#X```#(
M(0$`(@````<B`0!2````*B(!`"4```!](@$`"P```*,B`0"Q````KR(!`$4`
M``!A(P$`(0```*<C`0`P````R2,!`"4```#Z(P$`'````"`D`0`Q````/20!
M``<```!O)`$`!P```'<D`0`$````?R0!``T```"$)`$`"P```)(D`0`.````
MGB0!``L```"M)`$`!0```+DD`0`0````OR0!``(```#0)`$`60```-,D`0`%
M````+24!`!(````S)0$`!````$8E`0`'````2R4!``@```!3)0$`!0```%PE
M`0`#````8B4!`!````!F)0$`$P```'<E`0`-````BR4!``(```"9)0$`!P``
M`)PE`0`&````I"4!`!0```"K)0$`#````,`E`0`8````S24!``8```#F)0$`
M$@```.TE`0`,`````"8!``,````-)@$`!````!$F`0`&````%B8!``<````=
M)@$`'P```"4F`0`U````128!`"X```![)@$`+P```*HF`0`7````VB8!`"(`
M``#R)@$`)0```!4G`0`@````.R<!`!L```!<)P$`&````'@G`0`D````D2<!
M`!\```"V)P$`&@```-8G`0`A````\2<!`"`````3*`$`&@```#0H`0`R````
M3R@!`!H```""*`$`+P```)TH`0`K````S2@!`!\```#Y*`$`(P```!DI`0`?
M````/2D!`!H```!=*0$`(0```'@I`0`E````FBD!`"8```#`*0$`)0```.<I
M`0`D````#2H!`!@````R*@$`'0```$LJ`0`D````:2H!`!@```".*@$`(@``
M`*<J`0`L````RBH!`"\```#W*@$`%0```"<K`0`E````/2L!`#P```!C*P$`
M'P```*`K`0`C````P"L!`!\```#D*P$`(`````0L`0`:````)2P!`!@```!`
M+`$`)@```%DL`0`>````@"P!`"D```"?+`$`'@```,DL`0`Q````Z"P!``D`
M```:+0$`#````"0M`0`7````,2T!`"\```!)+0$`)````'DM`0`'````GBT!
M``\```"F+0$`%````+8M`0`.````RRT!``T```#:+0$`)````.@M`0`%````
M#2X!``<````3+@$`(@```!LN`0`E````/BX!`!H```!D+@$`'0```'\N`0`:
M````G2X!``<```"X+@$`QP```,`N`0`+````B"\!`!4```"4+P$`!@```*HO
M`0`)````L2\!``L```"[+P$`#0```,<O`0`7````U2\!``8```#M+P$`,P``
M`/0O`0`3````*#`!`!,````\,`$`!P```%`P`0`/````6#`!``<```!H,`$`
M,@```'`P`0`$````HS`!`"$```"H,`$`$P```,HP`0`,````WC`!`!$```#K
M,`$`,@```/TP`0`6````,#$!``@```!',0$`'0```%`Q`0`)````;C$!``H`
M``!X,0$`%````(,Q`0`*````F#$!`!T```"C,0$`"````,$Q`0`?````RC$!
M``@```#J,0$`&@```/,Q`0`&````#C(!`!4````5,@$`!P```"LR`0`(````
M,S(!``D````\,@$`/P```$8R`0`'````AC(!``\```".,@$`#@```)XR`0`0
M````K3(!``D```"^,@$`"0```,@R`0`(````TC(!`!,```#;,@$`!P```.\R
M`0`9````]S(!``H````1,P$`%P```!PS`0`4````-#,!``H```!),P$`#```
M`%0S`0`7````83,!``0```!Y,P$`*@```'XS`0`,````J3,!`!$```"V,P$`
M!P```,@S`0`"````T#,!`!````#3,P$`&````.0S`0`+````_3,!``,````)
M-`$`"`````TT`0`&````%C0!``<````=-`$`#0```"4T`0`+````,S0!`!0`
M```_-`$`%0```%0T`0`.````:C0!`"\```!Y-`$`(````*DT`0`<````RC0!
M`!4```#G-`$`#````/TT`0`Q````"C4!``4````\-0$`$@```$(U`0`_````
M534!`!(```"5-0$`"@```*@U`0`&````LS4!``0```"Z-0$`!````+\U`0`*
M````Q#4!`!,```#/-0$`!0```.,U`0`&````Z34!``8```#P-0$`"````/<U
M`0`$`````#8!``P````%-@$`"@```!(V`0`Y````'38!`"X```!7-@$`&0``
M`(8V`0`?````H#8!`!T```#`-@$`$0```-XV`0`"````\#8!``0```#S-@$`
M"@```/@V`0`&`````S<!``4````*-P$``P```!`W`0`,````%#<!`$4````A
M-P$`,@```&<W`0`:````FC<!`#0```"U-P$`*````.HW`0!3````$S@!`!D`
M``!G.`$`<@```($X`0`@````]#@!`#4````5.0$`(0```$LY`0!%````;3D!
M`#````"S.0$`*````.0Y`0`I````#3H!`"8````W.@$`)0```%XZ`0`H````
MA#H!`"@```"M.@$`(@```-8Z`0`K````^3H!`#`````E.P$`$@```%8[`0`3
M````:3L!`!````!].P$`>0```(X[`0`)````"#P!`*$````2/`$`<P```+0\
M`0!\````*#T!`"L```"E/0$`5````-$]`0`7````)CX!`"<````^/@$`%@``
M`&8^`0`/````?3X!`!<```"-/@$`'P```*4^`0!`````Q3X!`!\````&/P$`
M'````"8_`0!1````0S\!`!H```"5/P$`%````+`_`0`*````Q3\!``4```#0
M/P$`!@```-8_`0`(````W3\!`!(```#F/P$`$````/D_`0`3````"D`!`!T`
M```>0`$`#P```#Q``0`/````3$`!``0```!<0`$`"0```&%``0`+````:T`!
M``<```!W0`$`!0```']``0`4````A4`!``<```":0`$`"````*)``0`/````
MJT`!``@```"[0`$`#````,1``0`/````T4`!``8```#A0`$`%````.A``0`&
M````_4`!``P````$00$`"````!%!`0`9````&D$!`!$````T00$`"@```$9!
M`0`8````44$!`!,```!J00$`'````'Y!`0`1````FT$!``\```"M00$`!```
M`+U!`0`9````PD$!``<```#<00$``@```.1!`0`"````YT$!`!$```#J00$`
M"0```/Q!`0`&````!D(!`!(````-0@$`%P```"!"`0`&````.$(!``(````_
M0@$`!````$)"`0`/````1T(!`!,```!70@$`!P```&M"`0`'````<T(!`!$`
M``![0@$`!@```(U"`0`8````E$(!``8```"M0@$`$P```+1"`0`0````R$(!
M`!(```#90@$``@```.Q"`0`&````[T(!``P```#V0@$`"0````-#`0`1````
M#4,!`"(````?0P$`!P```$)#`0`'````2D,!``L```!20P$`!0```%Y#`0`"
M````9$,!``L```!G0P$`80$``'-#`0`*````U40!``P```#@1`$`"@```.U$
M`0`'````^$0!``<`````10$`!P````A%`0`"````$$4!`!$````310$`&```
M`"5%`0`K````/D4!`!H```!J10$`'0```(5%`0`3````HT4!`!$```"W10$`
M*0```,E%`0`-````\T4!`!L````!1@$`$@```!U&`0`+````,$8!``<````\
M1@$`!0```$1&`0`2````2D8!``<```!=1@$`!P```&5&`0`+````;48!``D`
M``!Y1@$`"P```(-&`0`\````CT8!``D```#,1@$`!0```-9&`0`*````W$8!
M``\```#G1@$`"@```/=&`0`*`````D<!``H````-1P$`"@```!A'`0`&````
M(T<!`%D````J1P$`!P```(1'`0`,````C$<!`!(```"91P$`"@```*Q'`0`)
M````MT<!``D```#!1P$`"0```,M'`0`&````U4<!`!T```#<1P$`%````/I'
M`0`E````#T@!`"T````U2`$`0````&-(`0!$````I$@!`$0```#I2`$`2@``
M`"Y)`0`G````>4D!``@```"A20$`"````*I)`0`(````LTD!``@```"\20$`
M"````,5)`0`)````SDD!``@```#820$`#@```.%)`0`'````\$D!``8```#X
M20$`!@```/])`0`;````!DH!`!L````B2@$`"````#Y*`0`*````1TH!``L`
M``!22@$`!````%Y*`0`$````8TH!``H```!H2@$`"@```'-*`0`)````?DH!
M``@```"(2@$`"````)%*`0`1````FDH!`!````"L2@$`#P```+U*`0`(````
MS4H!``T```#62@$`!@```.1*`0`9````ZTH!``\````%2P$`$````!5+`0`*
M````)DL!`#,````Q2P$`*P```&5+`0`;````D4L!``0```"M2P$`!@```+)+
M`0`A````N4L!``0```#;2P$`!````.!+`0`4````Y4L!`!0```#Z2P$`%```
M``],`0`(````)$P!``0````M3`$`"0```#),`0`$````/$P!`!(```!!3`$`
M"````%1,`0`(````74P!``8```!F3`$`%@```&U,`0`7````A$P!``8```"<
M3`$`#@```*-,`0`.````LDP!`!````#!3`$`$````-),`0`(````XTP!``@`
M``#L3`$`'0```/5,`0`3````$TT!`!4````G30$`$````#U-`0`/````3DT!
M`!,```!>30$`#````')-`0`$````?TT!`!4```"$30$`*@```)I-`0`(````
MQ4T!``P```#.30$`#@```-M-`0`2````ZDT!``0```#]30$`"`````).`0`$
M````"TX!`!<````03@$`"@```"A.`0`*````,TX!`!H````^3@$`)````%E.
M`0`2````?DX!`!(```"13@$`%@```*1.`0`$````NTX!`!````#`3@$`$```
M`-%.`0`(````XDX!``\```#K3@$`&P```/M.`0`(````%T\!`!D````@3P$`
M&0```#I/`0`9````5$\!`!D```!N3P$`!````(A/`0`$````C4\!`!0```"2
M3P$`$````*=/`0`J````N$\!`",```#C3P$`*0````=0`0!K````,5`!`"@`
M``"=4`$`*````,90`0`Q````[U`!`#$````A40$`*````%-1`0`I````?%$!
M`!P```"F40$`'````,-1`0`Q````X%$!`"@````24@$`+@```#M2`0`4````
M:E(!``D```!_4@$`#````(E2`0`0````EE(!``T```"G4@$`#0```+52`0`+
M````PU(!`!4```#/4@$`!````.52`0`(````ZE(!`!(```#S4@$`&`````93
M`0`0````'U,!``X````P4P$`&````#]3`0`3````6%,!`!$```!L4P$`%```
M`'Y3`0`$````DU,!``<```"84P$`$````*!3`0`/````L5,!``P```#!4P$`
M$````,Y3`0`-````WU,!``0```#M4P$`(0```/)3`0`(````%%0!``@````=
M5`$`!````"94`0`2````*U0!``0````^5`$`!````$-4`0`(````2%0!``0`
M``!15`$`+0```%94`0`$````A%0!`!$```")5`$`!````)M4`0`-````H%0!
M``T```"N5`$`'@```+Q4`0`8````VU0!`!,```#T5`$`"`````A5`0`9````
M$54!`!`````K50$`"````#Q5`0`#````154!``H```!)50$`#P```%15`0`3
M````9%4!``8```!X50$`!@```']5`0`1````AE4!`!$```"850$`)@```*I5
M`0`1````T54!`!H```#C50$`$@```/Y5`0`/````$58!``0````A5@$`#```
M`"96`0`2````,U8!``\```!&5@$`(P```%96`0`2````>E8!`!H```"-5@$`
M,0```*A6`0`9````VE8!`!,```#T5@$`"`````A7`0`*````$5<!`!D````<
M5P$`"````#97`0`*````/U<!``L```!*5P$`"@```%97`0`+````85<!``@`
M``!M5P$`%@```'97`0`$````C5<!`"4```"25P$`$0```+A7`0`(````RE<!
M``H```#35P$`"````-Y7`0`+````YU<!``0```#S5P$`#````/A7`0`;````
M!5@!`"T````A6`$`!````$]8`0`-````5%@!``P```!B6`$`#````&]8`0`1
M````?%@!``\```".6`$`#0```)Y8`0`(````K%@!`!(```"U6`$`#0```,A8
M`0`2````UE@!`!D```#I6`$`%0````-9`0`"````&5D!`!0````<60$`"```
M`#%9`0`.````.ED!``H```!)60$`$````%19`0`&````95D!``X```!L60$`
M%````'M9`0`(````D%D!``0```"960$`!@```)Y9`0`"````I5D!`!<```"H
M60$`"@```,!9`0`(````RUD!`!,```#460$`!````.A9`0`&````[5D!``X`
M``#T60$``P````-:`0`(````!UH!``0````06@$`!````!5:`0`(````&EH!
M``0````C6@$`!````"A:`0`0````+5H!``0````^6@$`!````$-:`0`$````
M2%H!``0```!-6@$`!````%):`0`T````5UH!``T```",6@$`!P```)I:`0`(
M````HEH!``P```"K6@$`,@```+A:`0`)````ZUH!``H```#U6@$`&P````!;
M`0`I````'%L!`!H```!&6P$`!@```&%;`0`?````:%L!`!0```"(6P$`#0``
M`)U;`0`$````JUL!`!<```"P6P$`!````,A;`0`,````S5L!``0```#:6P$`
M%P```-];`0`8````]UL!`!4````07`$`&0```"9<`0`7````0%P!`!<```!8
M7`$`$@```'!<`0`4````@UP!`!0```"87`$`$````*U<`0`6````OEP!`"(`
M``#57`$`%````/A<`0`3````#5T!`!4````A70$`$@```#==`0`4````2ET!
M`!8```!?70$`'0```'9=`0`5````E%T!`!<```"J70$`&0```,)=`0`2````
MW%T!`!(```#O70$`'0````)>`0`5````(%X!``P````V7@$`%P```$->`0`2
M````6UX!`!8```!N7@$`#````(5>`0!+````DEX!`"<```#>7@$`$@````9?
M`0`4````&5\!`!0````N7P$`&````$-?`0`-````7%\!`!(```!J7P$`$P``
M`'U?`0`1````D5\!`!4```"C7P$`&0```+E?`0`4````TU\!`$P```#H7P$`
M%@```#5@`0`.````3&`!`!(```!;8`$`%````&Y@`0`9````@V`!`"H```"=
M8`$`+0```,A@`0`&````]F`!``0```#]8`$`!`````)A`0`$````!V$!``P`
M```,80$`#````!EA`0`,````)F$!``P````S80$`"@```$!A`0`2````2V$!
M``L```!>80$`"````&IA`0`(````<V$!``@```!\80$`#````(5A`0`(````
MDF$!``P```";80$`"@```*AA`0`?````LV$!``0```#380$`!````-AA`0`1
M````W6$!`!$```#O80$`%P````%B`0`:````&6(!`!L````T8@$``@```%!B
M`0!5````4V(!``0```"I8@$`#````*YB`0`*````NV(!``0```#&8@$`"```
M`,MB`0`(````U&(!``0```#=8@$`"@```.)B`0`&````[6(!``H```#T8@$`
M"````/]B`0`$````"&,!``@````-8P$`#@```!9C`0`5````)6,!``0````[
M8P$`!````$!C`0`*````16,!``@```!08P$`"````%EC`0`(````8F,!``X`
M``!K8P$`"@```'IC`0`(````A6,!`!(```".8P$`#@```*%C`0`@````L&,!
M``8```#18P$`&````-AC`0`.````\6,!``P`````9`$`%0````UD`0`(````
M(V0!``X````L9`$`"````#MD`0`$````1&0!`!T```!)9`$`%P```&=D`0`$
M````?V0!``@```"$9`$`%@```(UD`0`*````I&0!``@```"O9`$`"````+AD
M`0`$````P60!`!$```#&9`$`"````-AD`0`.````X60!``X```#P9`$`"```
M`/]D`0`(````"&4!`!$````190$`!@```"-E`0`<````*F4!`"D```!'90$`
M$P```'%E`0`C````A64!`!,```"I90$`!````+UE`0`'````PF4!`!P```#*
M90$`"@```.=E`0`$````\F4!``@```#W90$`!`````!F`0`2````!68!``0`
M```89@$`"````!UF`0`(````)F8!``@````O9@$`"````#AF`0`,````068!
M``@```!.9@$`#@```%=F`0`,````9F8!``0```!S9@$`#````'AF`0`6````
MA68!``<```"<9@$`"````*1F`0`,````K68!`!4```"Z9@$`#````-!F`0`3
M````W68!``@```#Q9@$`"0```/IF`0`)````!&<!``P````.9P$`*@```!MG
M`0`3````1F<!``@```!:9P$`"@```&-G`0`\````;F<!`!(```"K9P$`'@``
M`+YG`0`4````W6<!``0```#R9P$`%````/=G`0`;````#&@!`!L````H:`$`
M%@```$1H`0`7````6V@!`!4```!S:`$`$@```(EH`0`3````G&@!``0```"P
M:`$`#0```+5H`0`*````PV@!``D```#.:`$`"@```-AH`0`)````XV@!``@`
M``#M:`$`"@```/9H`0`)`````6D!``<````+:0$`!````!-I`0`$````&&D!
M``H````=:0$`"````"AI`0`&````,6D!``8````X:0$`"````#]I`0`-````
M2&D!`!````!6:0$`%P```&=I`0`6````?VD!`!````"6:0$`$````*=I`0`;
M````N&D!`!````#4:0$`#````.5I`0`$````\FD!`"X```#W:0$`#0```"9J
M`0`)````-&H!``0````^:@$`!````$-J`0`$````2&H!``0```!-:@$`!@``
M`%)J`0`&````66H!``@```!@:@$`"````&EJ`0`+````<FH!`!,```!^:@$`
M$0```))J`0`(````I&H!``@```"M:@$`"````+9J`0`(````OVH!`!4```#(
M:@$`!@```-YJ`0`.````Y6H!``8```#T:@$`!````/MJ`0`(`````&L!``@`
M```):P$`!````!)K`0`"````%VL!``X````::P$`"````"EK`0`$````,FL!
M`!L````W:P$`#@```%-K`0!.````8FL!``H```"Q:P$`!````+QK`0`$````
MP6L!``@```#&:P$`!````,]K`0`&````U&L!``0```#;:P$`"````.!K`0`&
M````Z6L!``0```#P:P$`#0```/5K`0`4`````VP!`!H````8;`$`(0```#-L
M`0`;````56P!``8```!Q;`$``@```'AL`0`(````>VP!``0```"$;`$`!```
M`(EL`0`,````CFP!``4```";;`$`#P```*%L`0`2````L6P!`!````#$;`$`
M%@```-5L`0`.````[&P!``P```#[;`$`%`````AM`0`$````'6T!``0````B
M;0$`!@```"=M`0`+````+FT!``L````Z;0$`!````$9M`0`-````2VT!`!,`
M``!9;0$`%````&UM`0`2````@FT!``@```"5;0$`$````)YM`0`I````KVT!
M`!L```#9;0$`&P```/5M`0`$````$6X!`!4````6;@$`"P```"QN`0`4````
M.&X!``@```!-;@$`"````%9N`0`(````7VX!``\```!H;@$`(````'AN`0`/
M````F6X!``P```"I;@$`$0```+9N`0`,````R&X!``D```#5;@$``@```-]N
M`0`$````XFX!``0```#G;@$`(0```.QN`0`&````#F\!`!<````5;P$`!```
M`"UO`0`$````,F\!``X````W;P$`!````$9O`0`$````2V\!`!$```!0;P$`
M`@```&)O`0`$````96\!`!$```!J;P$``@```'QO`0`(````?V\!``8```"(
M;P$`"````(]O`0`3````F&\!`!````"L;P$`!0```+UO`0`P````PV\!`!X`
M``#T;P$`+````!-P`0`A````0'`!`"X```!B<`$`)@```)%P`0`A````N'`!
M`#$```#:<`$`(0````QQ`0`=````+G$!`!P```!,<0$`!@```&EQ`0`(````
M<'$!``4```!Y<0$`%@```']Q`0`5````EG$!``T```"L<0$`$0```+IQ`0`$
M````S'$!``8```#1<0$`"````-AQ`0`0````X7$!`!4```#R<0$`%0````AR
M`0`=````'G(!``<````\<@$`$````$1R`0`@````57(!``X```!V<@$`#@``
M`(5R`0`&````E'(!``@```";<@$`"@```*1R`0`/````KW(!`#````"_<@$`
M:0```/!R`0`^````6G,!``D```"9<P$`"````*-S`0`)````K',!``P```"V
M<P$`#0```,-S`0`(````T7,!``0```#:<P$`#0```-]S`0`,````[7,!``D`
M``#Z<P$`#@````1T`0`3````$W0!`!H````G=`$`1@```$)T`0`(````B70!
M``P```"2=`$`"@```)]T`0`0````JG0!``0```"[=`$`!````,!T`0`-````
MQ70!`!````#3=`$`"````.1T`0`(````[70!``P```#V=`$`$`````-U`0`<
M````%'4!`!P````Q=0$`&````$YU`0`8````9W4!`!H```"`=0$`&@```)MU
M`0`.````MG4!`!L```#%=0$`$````.%U`0`0````\G4!``X````#=@$`#@``
M`!)V`0`(````(78!``X````J=@$`#@```#EV`0`,````2'8!``P```!5=@$`
M#P```&)V`0`-````<G8!`!$```"`=@$`(0```))V`0`)````M'8!``0```"^
M=@$`!@```,-V`0`;````RG8!`!````#F=@$`#P```/=V`0`/````!W<!``\`
M```7=P$`#@```"=W`0`.````-G<!``T```!%=P$`"P```%-W`0`0````7W<!
M`!8```!P=P$`$P```(=W`0`-````FW<!`!$```"I=P$`#0```+MW`0`/````
MR7<!`!$```#9=P$`#P```.MW`0`/````^W<!`!$````+>`$`!````!UX`0`(
M````(G@!`"`````K>`$`#0```$QX`0`0````6G@!`!(```!K>`$`"````'YX
M`0`/````AW@!``8```"7>`$`!````)YX`0`.````HW@!`!````"R>`$`!```
M`,-X`0`,````R'@!`!(```#5>`$`!@```.AX`0`-````[W@!``0```#]>`$`
M!`````)Y`0`$````!WD!``0````,>0$`"````!%Y`0`(````&GD!``@````C
M>0$`"@```"QY`0`*````-WD!``P```!">0$`$@```$]Y`0`(````8GD!``@`
M``!K>0$`"````'1Y`0`(````?7D!``@```"&>0$`"````(]Y`0`H````F'D!
M``0```#!>0$`$P```,9Y`0`M````VGD!`!D````(>@$`#0```")Z`0`/````
M,'H!``H```!`>@$`"@```$MZ`0`$````5GH!`"<```!;>@$`!@```(-Z`0`2
M````BGH!``8```"=>@$`"0```*1Z`0`.````KGH!`!0```"]>@$`%@```-)Z
M`0`1````Z7H!``0```#[>@$`"`````![`0`0````"7L!``0````:>P$`"```
M`!][`0`&````*'L!`!`````O>P$`$@```$![`0`?````4WL!`!H```!S>P$`
M!````(Y[`0`$````DWL!``@```"8>P$`"````*%[`0`&````JGL!``@```"Q
M>P$`!````+I[`0`&````OWL!``8```#&>P$`!````,U[`0`)````TGL!`"``
M``#<>P$`!````/U[`0`?`````GP!``H````B?`$`#````"U\`0`(````.GP!
M``\```!#?`$`#0```%-\`0`1````87P!``\```!S?`$`#P```(-\`0`-````
MDWP!`!$```"A?`$`$````+-\`0`2````Q'P!`!8```#7?`$`!````.Y\`0`2
M````\WP!``D````&?0$`"@```!!]`0`*````&WT!``0````F?0$`!````"M]
M`0`$````,'T!``0````U?0$`"````#I]`0`M````0WT!``D```!Q?0$`!```
M`'M]`0`$````@'T!``(```"%?0$`#````(A]`0`,````E7T!``P```"B?0$`
M$P```*]]`0`"````PWT!``@```#&?0$`&P```,]]`0`#````ZWT!``P```#O
M?0$`.0```/Q]`0`7````-GX!``0```!.?@$`!````%-^`0`(````6'X!``T`
M``!A?@$`#P```&]^`0`3````?WX!`!,```"3?@$`"P```*=^`0`.````LWX!
M`"````#"?@$`"@```.-^`0`-````[GX!``0```#\?@$`!`````%_`0`2````
M!G\!`"0````9?P$`'0```#Y_`0`7````7'\!``H```!T?P$`%P```']_`0`4
M````EW\!``\```"L?P$`%P```+Q_`0`8````U'\!`!<```#M?P$`#`````6`
M`0`,````$H`!``0````?@`$`$@```"2``0`$````-X`!``0````\@`$`"0``
M`$&``0`*````2X`!``0```!6@`$`+@```%N``0`+````BH`!``@```"6@`$`
M$P```)^``0`K````LX`!`!$```#?@`$`!````/&``0`2````]H`!`!H````)
M@0$`!````"2!`0`/````*8$!`"X````Y@0$`!````&B!`0`)````;8$!`!@`
M``!W@0$`%P```)"!`0`4````J($!``0```"]@0$`!````,*!`0`>````QX$!
M`#4```#F@0$`$````!R"`0`<````+8(!`!````!*@@$`!@```%N"`0`(````
M8H(!``0```!K@@$`"````'""`0`(````>8(!``0```""@@$`'P```(>"`0`/
M````IX(!``\```"W@@$`!@```,>"`0`$````SH(!``@```#3@@$`!````-R"
M`0`C````X8(!``8````%@P$`"`````R#`0`(````%8,!``@````>@P$`!```
M`">#`0`$````+(,!``0````Q@P$`!````#:#`0`$````.X,!``0```!`@P$`
M%0```$6#`0`0````6X,!``0```!L@P$`"````'&#`0`,````>H,!``@```"'
M@P$`$````)"#`0`.````H8,!``L```"P@P$`!````+R#`0`2````P8,!``P`
M``#4@P$`#@```.&#`0`2````\(,!`",````#A`$`%0```">$`0`5````/80!
M`!4```!3A`$`$0```&F$`0`1````>X0!`!<```"-A`$`$P```*6$`0`1````
MN80!``@```#+A`$`!````-2$`0`<````V80!``@```#VA`$`"0```/^$`0`$
M````"84!`!4````.A0$`%````"2%`0`&````.84!`!$```!`A0$`#0```%*%
M`0`/````8(4!``0```!PA0$`"````'6%`0`&````?H4!``H```"%A0$`!@``
M`)"%`0`4````EX4!``P```"LA0$`$@```+F%`0`$````S(4!``T```#1A0$`
M`@```-^%`0`9````XH4!`!H```#\A0$`#0```!>&`0`:````)88!`"$```!`
MA@$`"0```&*&`0`;````;(8!`!<```"(A@$`'````*"&`0`;````O88!`"``
M``#9A@$`"P```/J&`0`+````!H<!``H````2AP$`"P```!V'`0`0````*8<!
M`!$````ZAP$`"P```$R'`0`+````6(<!``L```!DAP$`&P```'"'`0`;````
MC(<!`!\```"HAP$`'````,B'`0`=````Y8<!`!H````#B`$`2````!Z(`0`3
M````9X@!``X```![B`$`!@```(J(`0`5````D8@!``8```"GB`$`"````*Z(
M`0`3````MX@!`!<```#+B`$`%P```..(`0`&````^X@!`"L````"B0$`+0``
M`"Z)`0`"````7(D!`!$```!?B0$`%@```'&)`0`9````B(D!``8```"BB0$`
M&````*F)`0`-````PHD!``8```#0B0$`!@```->)`0`,````WHD!``T```#K
MB0$`!@```/F)`0`(`````(H!``8````)B@$`$@```!"*`0`&````(XH!``0`
M```JB@$`!@```"^*`0`(````-HH!``0````_B@$`&0```$2*`0`"````7HH!
M``0```!AB@$`"@```&:*`0`&````<8H!``0```!XB@$`!@```'V*`0`7````
MA(H!``8```"<B@$`#````*.*`0`+````L(H!`",```"\B@$`$P```."*`0`F
M````](H!``X````;BP$`+0```"J+`0`2````6(L!``@```!KBP$`!````'2+
M`0`&````>8L!``@```"`BP$`!````(F+`0`(````CHL!``0```"7BP$`$```
M`)R+`0`4````K8L!``0```#"BP$`"````,>+`0`*````T(L!``T```#;BP$`
M$````.F+`0`,````^HL!``P````'C`$`#````!2,`0`6````(8P!``H````X
MC`$`"````$.,`0`(````3(P!``@```!5C`$`"````%Z,`0`(````9XP!``8`
M``!PC`$`"````'>,`0`4````@(P!``H```"5C`$`!````*",`0`3````I8P!
M``P```"YC`$`,````,:,`0`/````]XP!`"$````'C0$`$0```"F-`0`$````
M.XT!``0```!`C0$`#0```$6-`0`*````4XT!`!T```!>C0$`"````'R-`0`%
M````A8T!``8```"+C0$`#0```)*-`0`$````H(T!``0```"EC0$`!````*J-
M`0`*````KXT!``0```"ZC0$`!@```+^-`0`,````QHT!`!,```#3C0$`!```
M`.>-`0`3````[(T!``@`````C@$`!`````F.`0`(````#HX!``0````7C@$`
M"P```!R.`0`$````*(X!`!0````MC@$`!````$*.`0`$````1XX!``@```!,
MC@$`!````%6.`0`0````6HX!`!,```!KC@$`&P```'^.`0`5````FXX!`!4`
M``"QC@$`&````,>.`0`F````X(X!`!4````'CP$`$0```!V/`0`:````+X\!
M`"X```!*CP$`$P```'F/`0`-````C8\!``0```";CP$`!````*"/`0`1````
MI8\!``@```"WCP$`"````,"/`0`K````R8\!`!8```#UCP$`#@````R0`0`I
M````&Y`!`"\```!%D`$`!````'60`0`,````>I`!``8```"'D`$`!````(Z0
M`0`2````DY`!``H```"FD`$`"````+&0`0`(````NI`!``0```##D`$`"```
M`,B0`0`$````T9`!``@```#6D`$`"````-^0`0`,````Z)`!``P```#UD`$`
M&@````*1`0`6````'9$!``P````TD0$`!````$&1`0`(````1I$!`!8```!/
MD0$`!@```&:1`0`"````;9$!``8```!PD0$`!@```'>1`0`$````?I$!``8`
M``"#D0$`!@```(J1`0`(````D9$!``0```":D0$`!````)^1`0`(````I)$!
M`"4```"MD0$`,@```-.1`0`(````!I(!``@````/D@$`%0```!B2`0`5````
M+I(!``H```!$D@$`"@```$^2`0`$````6I(!``0```!?D@$`"@```&22`0`H
M````;Y(!``0```"8D@$`"````)V2`0`(````II(!``@```"OD@$`!@```+B2
M`0`G````OY(!``0```#GD@$`%````.R2`0`*`````9,!``X````,DP$`%P``
M`!N3`0`1````,Y,!`!H```!%DP$`%P```&"3`0`5````>),!``@```".DP$`
M!````)>3`0`(````G),!``T```"EDP$`$````+.3`0`$````Q),!``@```#)
MDP$`#@```-*3`0`2````X9,!``@```#TDP$`#@```/V3`0`$````#)0!``0`
M```1E`$`"````!:4`0`&````'Y0!``L````FE`$`!````#*4`0`2````-Y0!
M``L```!*E`$`$````%:4`0`0````9Y0!``8```!XE`$`!@```'^4`0`"````
MAI0!``0```")E`$`#````(Z4`0`(````FY0!``8```"DE`$`!````*N4`0`;
M````L)0!``\```#,E`$`#P```-R4`0`6````[)0!``X````#E0$`!````!*5
M`0`*````%Y4!``H````BE0$`!````"V5`0`,````,I4!``8````_E0$`%P``
M`$:5`0`L````7I4!`!8```"+E0$`&0```**5`0`S````O)4!`!(```#PE0$`
M$@````.6`0`5````%I8!`"@````LE@$`"@```%66`0`;````8)8!``0```!\
ME@$`"0```(&6`0`'````BY8!``@```"3E@$`.````)R6`0`/````U98!`!<`
M``#EE@$`"````/V6`0`$````!I<!``0````+EP$`"````!"7`0`(````&9<!
M``P````BEP$`%````"^7`0`2````1)<!``X```!7EP$`%@```&:7`0`(````
M?9<!`!$```"&EP$`#````)B7`0`&````I9<!`$,```"LEP$`#0```/"7`0`1
M````_I<!`!4````0F`$`#0```":8`0`1````-)@!`!<```!&F`$`$````%Z8
M`0`-````;Y@!``P```!]F`$`"````(J8`0`2````DY@!``@```"FF`$`!```
M`*^8`0`L````M)@!``0```#AF`$`&P```.:8`0`(`````ID!``\````+F0$`
M!````!N9`0`(````()D!`"@````IF0$`(0```%*9`0`C````=)D!`#H```"8
MF0$`!````-.9`0`,````V)D!`!P```#EF0$`$P````*:`0`$````%IH!``@`
M```;F@$`(0```"2:`0`$````1IH!`!\```!+F@$`(````&N:`0`*````C)H!
M`!0```"7F@$`%0```*R:`0`6````PIH!`!0```#9F@$`$@```.Z:`0`4````
M`9L!``@````6FP$`"````!^;`0`(````*)L!``@````QFP$`"@```#J;`0`$
M````19L!`!<```!*FP$`!````&*;`0`$````9YL!``@```!LFP$`$@```'6;
M`0`$````B)L!``@```"-FP$`$P```):;`0`5````JIL!``(```#`FP$`!```
M`,.;`0`$````R)L!``@```#-FP$`"````-:;`0`*````WYL!`!P```#JFP$`
M$@````><`0`&````&IP!``P````AG`$`"````"Z<`0`3````-YP!`!$```!+
MG`$`+````%V<`0`&````BIP!``8```"1G`$`!````)B<`0`*````G9P!``X`
M``"HG`$`"````+><`0`,````P)P!``@```#-G`$`"````-:<`0`&````WYP!
M``0```#FG`$`%````.N<`0`$`````)T!``H````%G0$`"````!"=`0`"````
M&9T!``0````<G0$`"````"&=`0`$````*IT!``8````OG0$`!@```#:=`0`8
M````/9T!``H```!6G0$`!@```&&=`0`1````:)T!``0```!ZG0$`!````'^=
M`0`_````A)T!``0```#$G0$`!````,F=`0`9````SIT!`"4```#HG0$`#P``
M``Z>`0`8````'IX!`"4````WG@$`%0```%V>`0`8````<YX!``\```",G@$`
M#P```)R>`0`,````K)X!``0```"YG@$`!````+Z>`0`$````PYX!``(```#(
MG@$`!````,N>`0`)````T)X!``8```#:G@$`!````.&>`0`&````YIX!``0`
M``#MG@$`!````/*>`0`1````]YX!``0````)GP$`%@````Z?`0`4````)9\!
M``T````ZGP$`$@```$B?`0`.````6Y\!``P```!JGP$`%````'>?`0`=````
MC)\!``0```"JGP$`"````*^?`0`$````N)\!``P```"]GP$`$````,J?`0`$
M````VY\!``@```#@GP$`"````.F?`0`$````\I\!``0```#WGP$`%0```/R?
M`0`G````$J`!``4````ZH`$`"````$"@`0`(````2:`!`!(```!2H`$`!```
M`&6@`0`&````:J`!`"$```!QH`$`$````).@`0`(````I*`!``0```"MH`$`
M!@```+*@`0`(````N:`!``P```#"H`$`!@```,^@`0`.````UJ`!``\```#E
MH`$`&````/6@`0`A````#J$!`!0````PH0$`'````$6A`0`6````8J$!`#L`
M``!YH0$`!@```+6A`0`F````O*$!`!\```#CH0$`*`````.B`0`Z````+*(!
M``\```!GH@$`&P```'>B`0`=````DZ(!`!T```"QH@$`$P```,^B`0`1````
MXZ(!`!D```#UH@$`%0````^C`0`&````):,!`#`````LHP$`90```%VC`0`>
M````PZ,!``\```#BHP$`+P```/*C`0`Q````(J0!`"\```!4I`$`%0```(2D
M`0`(````FJ0!``8```"CI`$`&0```*JD`0`7````Q*0!`!<```#<I`$`%@``
M`/2D`0`3````"Z4!`!,````?I0$`'0```#.E`0`(````4:4!``8```!:I0$`
M'P```&&E`0`3````@:4!`!D```"5I0$`&````*^E`0`-````R*4!`!$```#6
MI0$`0@```.BE`0`D````*Z8!`"4```!0I@$`'P```':F`0`<````EJ8!`"0`
M``"SI@$`.0```-BF`0`O````$J<!`!<```!"IP$`&P```%JG`0`B````=J<!
M`#@```"9IP$`,0```-*G`0`K````!*@!`"D````PJ`$`)0```%JH`0`>````
M@*@!`!X```"?J`$`&P```+ZH`0`1````VJ@!`!D```#LJ`$`&P````:I`0`;
M````(JD!`"0````^J0$`#P```&.I`0`]````<ZD!`!,```"QJ0$`"````,6I
M`0!J````SJD!`#,````YJ@$`$P```&VJ`0`M````@:H!`!<```"OJ@$`#P``
M`,>J`0`D````UZH!``(```#\J@$`"````/^J`0`$````"*L!``@````-JP$`
M"````!:K`0`(````'ZL!``L````HJP$`!````#2K`0`/````.:L!``8```!)
MJP$`2P```%"K`0`$````G*L!``L```"AJP$`"P```*VK`0`'````N:L!``0`
M``#!JP$`#````,:K`0`$````TZL!`!$```#8JP$`#@```.JK`0`&````^:L!
M``8`````K`$`$@````>L`0`/````&JP!`!4````JK`$`#````$"L`0`8````
M3:P!``\```!FK`$`#@```':L`0`,````A:P!``0```"2K`$`!0```)>L`0`/
M````G:P!`!````"MK`$`$@```+ZL`0`?````T:P!`!X```#QK`$`'P```!"M
M`0`.````,*T!`!8````_K0$`&0```%:M`0`4````<*T!`!(```"%K0$`$@``
M`)BM`0`7````JZT!`!(```##K0$`$@```-:M`0`7````Z:T!`!@````!K@$`
M$0```!JN`0`=````+*X!`!$```!*K@$`&@```%RN`0`1````=ZX!`!(```")
MK@$`%@```)RN`0`7````LZX!`!(```#+K@$`%P```-ZN`0`5````]JX!`!,`
M```,KP$`$````""O`0`1````,:\!`!(```!#KP$`%P```%:O`0`2````;J\!
M`!(```"!KP$`#P```)2O`0`F````I*\!`"D```#+KP$`#@```/6O`0`6````
M!+`!`"<````;L`$`&````$.P`0`6````7+`!`!X```!SL`$`'P```)*P`0`8
M````LK`!`!,```#+L`$`$@```-^P`0`7````\K`!`"(````*L0$`%@```"VQ
M`0`@````1+$!``0```!EL0$`"````&JQ`0`$````<[$!`!X```!XL0$`&P``
M`)>Q`0`&````L[$!``X```"ZL0$`)P```,FQ`0`5````\;$!`!0````'L@$`
M)````!RR`0`$````0;(!``8```!&L@$`)0```$VR`0`D````<[(!``\```"8
ML@$`%P```*BR`0`2````P+(!``8```#3L@$`C0```-JR`0`(````:+,!``X`
M``!QLP$`!````("S`0`'````A;,!``H```"-LP$`"P```)BS`0`/````I+,!
M``0```"TLP$`(P```+FS`0`,````W;,!``P```#JLP$`$````/>S`0`.````
M"+0!``@````7M`$`-0```""T`0`&````5K0!`!\```!=M`$`"@```'VT`0`*
M````B+0!``H```"3M`$`'0```)ZT`0`0````O+0!``H```#-M`$`%P```-BT
M`0`+````\+0!``@```#\M`$`#P````6U`0`5````%;4!`!$````KM0$`!```
M`#VU`0`2````0K4!``8```!5M0$`&````%RU`0`"````=;4!``@```!XM0$`
M$@```(&U`0`$````E+4!`!0```"9M0$`)````*ZU`0`$````T[4!``@```#8
MM0$`"````.&U`0`(````ZK4!``4```#SM0$`!@```/FU`0`/`````+8!``\`
M```0M@$`!P```""V`0`,````*+8!``H````UM@$`)@```$"V`0`C````9[8!
M``8```"+M@$`"````)*V`0`=````F[8!``0```"YM@$`&P```+ZV`0`-````
MVK8!`!$```#HM@$`!````/JV`0`&````_[8!``@````&MP$`#`````^W`0`0
M````'+<!``0````MMP$`!````#*W`0`$````-[<!``0````\MP$`"0```$&W
M`0`(````2[<!`!$```!4MP$`$@```&:W`0`9````>;<!`",```"3MP$`#P``
M`+>W`0`/````Q[<!`!8```#7MP$`"````.ZW`0`B````][<!``0````:N`$`
M$P```!^X`0`C````,[@!``@```!7N`$`"````&"X`0`%````:;@!``@```!O
MN`$``@```'BX`0`&````>[@!``@```""N`$`!0```(NX`0`&````D;@!``0`
M``"8N`$`"````)VX`0`$````IK@!``H```"KN`$`"@```+:X`0`X````P;@!
M`#````#ZN`$`$P```"NY`0`3````/[D!`!4```!3N0$`#0```&FY`0`"````
M=[D!``(```!ZN0$`#````'VY`0`$````BKD!``P```"/N0$``@```)RY`0`+
M````G[D!`#T```"KN0$`&0```.FY`0`+`````[H!`"$````/N@$`(0```#&Z
M`0`E````4[H!``L```!YN@$`4P```(6Z`0`7````V;H!`$$```#QN@$`*```
M`#.[`0`A````7+L!`!P```!^NP$`%0```)N[`0`5````L;L!`!4```#'NP$`
M%0```-V[`0`5````\[L!`!,````)O`$`%P```!V\`0`B````-;P!`!X```!8
MO`$`$````'>\`0`7````B+P!``@```"@O`$`4P```*F\`0`(````_;P!`%8`
M```&O0$`+0```%V]`0!1````B[T!`!L```#=O0$`-@```/F]`0`3````,+X!
M`!D```!$O@$`$P```%Z^`0`)````<KX!``\```!\O@$`&````(R^`0`;````
MI;X!``\```#!O@$`$@```-&^`0`Z````Y+X!``\````?OP$`#P```"^_`0`5
M````/[\!``P```!5OP$`#P```&*_`0`1````<K\!``H```"$OP$`"@```(^_
M`0`+````FK\!`!(```"FOP$`%````+F_`0`&````SK\!``@```#5OP$`"@``
M`-Z_`0`(````Z;\!``8```#ROP$`!@```/F_`0`-`````,`!``8````.P`$`
M!@```!7``0`-````',`!``8````JP`$`!@```#'``0`/````.,`!``8```!(
MP`$`#0```$_``0`(````7<`!``8```!FP`$`!@```&W``0`0````=,`!``P`
M``"%P`$`!````)+``0`.````E\`!``@```"FP`$`$@```*_``0`,````PL`!
M``H```#/P`$`!````-K``0`3````W\`!``0```#SP`$``P```/C``0`"````
M_,`!`!(```#_P`$`!````!+!`0`0````%\$!``T````HP0$`#````#;!`0`#
M````0\$!``(```!'P0$`!````$K!`0`)````3\$!``D```!9P0$`!@```&/!
M`0`&````:L$!``@```!QP0$`!````'K!`0`0````?\$!``0```"0P0$`#```
M`)7!`0`(````HL$!`!,```"KP0$``@```+_!`0`$````PL$!``@```#'P0$`
M!@```-#!`0`,````U\$!`!H```#DP0$`!````/_!`0`&````!,(!``H````+
MP@$`!0```!;"`0`%````',(!`!`````BP@$``0```$T%````````\`8``($%
M``!-!```.P8``,(```"6`@``I`0``,@%```U!```E@$````````V````````
M`````````````````+`!``!]`P``%00``&,"``";`````````.T!``"O!```
MS0```+@&````````X`$``&\$``#Q`````````-4``````````````.0!````
M````HP4``%P!``!O!@```````$D'``!3!@``_P(```````"D!0``%`$`````
M``#O`0``3````(8%```````````````'````!```]P0``'0!```C!@``FP8`
M`((%````````I@8``$($``"N`P``/P(``'4!```#!0``_08``,<`````````
MY00``$<#```G`P``E`$``#\%```A!P``/@(``+D&``""!@``=@0``'@&``!,
M`@```0,``&4```"#````\@,``',"``!J`@```````-@&```&`P``B08`````
M```+````Y`8```````!Y!0```````/L"```A`P``YP8```@```"H`P``````
M`&\```!>!0``````````````````2`8```````"@`@```````"<%``"V!@``
M+`0``$P#```2`@```````/($````````'@0``*\%```;!P``U0$``"\"``!4
M!0``S`$```````!@`@```````/0&``"<`P``:@8`````````````!04`````
M````````Z`4``"<&`````````````!@``````````````+0#``#E!0``D0(`
M````````````40$``*H!``"O!@``>@```!`$``#=!```'`0```<&``![`P``
M1`(``(H$```W!```604``+4"``!%!0``R0````````#Z!````@<``(T!``!O
M`P``T`0``#4!``!F````$@8```````"_!0``K08```````"5!@``SP$``/D&
M``"L`0``W`,``$@'``"3`@``_`(``-H$``#:`P``%@4```````!``@``;P4`
M`#<%``!G!@``D````%8#``#(!```^`4````````2!`````````4"````````
MH@(``#0#``!L`````````((#``#^`0```````%D$``"$`P``!`````````!C
M!@```````,H`````````DP0``'P%``!\`````0(``-@%```Q`````````!4'
M```A!@```````,H$``````````````````!"`````````#P$``!L!0``_P8`
M`)`%```P!0```````,D"``!A!0````(``)\&```W`P```````%$$```M!0``
MC`$``#``````````A04``$,&```.!0``D0,``,8&``#&!0``9`$``)H%````
M`````````+$&```*!```8@8``.($````````)@$`````````````_0```/X%
M``":`P``YP```&L```"A`````````&L&```5!@``A`$``"(`````````\`,`
M`.P$``!M`P``4`,`````````````E`8`````````````P@8``,4&```U`P``
MI`8```\%```8`0``+@<````````"`0``Z`0```````!,`0``D@,``&L$```.
M!`````````````"-!```&0```#0!``#K`P``EP,```D#``"T`0``2`0```<$
M``!7`@``!@(``'@%``#D`@``20```+0%``!E!@`````````````#````C0(`
M````````````1`,``"4#```O!0`````````````Q!P``CP0```,'``#7````
M=`0``%4&````````Q`0``$4```#U!@``:@````H#``!2`P``P`8``-$````T
M!0```````&$#``#J`@``[@```%\```!7!@```````$<"```_!P``,`(`````
M````````)`,``(P%``!P````%P4```````#8!```$`$``#8&``!+`P``$@4`
M`($#``!<`````````/D!```3!@``'P8```````````````````````!^`P``
MR`(``#X#````````@P(``-P!``#$`0``'@,``+T```!6````CP(``*8"```3
M`P``EP8```````!*!P``V04```````!"`P```````+<%``!X`0```````,X"
M``!&`P``E````#\````O!@``F@$``-$$```\!0````````````#>`P``!@8`
M`'@```"%`P``-@0``.T#`````````````!,```"_`P```````!T"````````
M```````````5`0``A`8```L$````````?00``-,%````````\@4``"D'``!L
M!@``000``/L#``#?`P``Z@0``$$%``"I`@``#0<``.,!````````*@4``,<#
M```9`P``O04``-\&``"Y!0```````#("``#B`@``-0<``/P&````````_`$`
M`!P"````````>@$```````!Z`P``'@(```````!B!0``:08```````"K!0``
M`````,T%`````````````,D#```-!0```````)P"````````C`,``'8#``#B
M`0``I@$```````#3`0```````(4"````````K04```D%`````````````/X`
M````````<0$```\```#E!@```````/H#``"X!````````+T&````````````
M`*\#``".!@``Y@0``)\$``"'`@```````"`'`````````@4``(($````````
M`````)`!``#4!@``X08``)(&`````````````!H#``#2!```X`````4````@
M`0``208``#D#``#R!@``LP8````````B`0``9@4``#`'``"!!@``%`<`````
M``#W!0``-@4``$P%``!_`@``E0$``$<$```)````'0````````!W````'@8`
M``````#]`0``HP(```````!-`0``%`,```````!.`0``````````````````
M(`,```````!Q!```\@(``!0%```C`0```````'4&```J`@```````.,$````
M`````````.0%```0`P``F04```````!Q!0```````.D!````````G0$`````
M```'`P``4@8```D$``"+`@```````+@"`````````````%(````(`@``90(`
M```````9!@``+@(``%\&````````,`$``(,&```Q!0```````(L$````````
M``````````"T````C04``!$!``"<!0``G0,``*\!``!^`0``)`8``#X```!S
M!0``@@(``%4#````````9@,``%P&``"*!@``40```*`$``"A`0```````'8`
M``"U!````````!T'````````+`$```````"G`P````````````"Q!0``0P$`
M```````?````Q0$``!0$``#6!```$```````````````%04``$(&````````
MA@(``/8`````````Y@```/,`````````0`0``"`"````````P@4``(L&``#?
M!````````,P#``#F!@``JP,``"$"````````9@(```````#-!@``100``-X$
M``!E!```>P$```,!``")`0``\P$`````````````M@4```````!,!```N0``
M`/X$``!>!@```````#T'`````````````!H!```W`````````+@````P!```
MM`(```````#O`P````````````"M`@````````````!Y`````````,<&``#)
M!@``-08``+P!````````^@8``"P#``#J!0``R`,``/0$``"0!```=00`````
M```?`P``Q@(``,4#``".````UP0``"T$`````````````,\```#X!@``*`4`
M`#T"```T!````````#,```#P`0``X@````````")!````````-`%``"B!```
MD`,``*$&``"[!```*`<``$X#``!W!@```````+8"``!@`P``]```````````
M````Q`(``,X#```$!P``D00``!P&```L`@``8`4``!P%``#`````2P0``!X`
M``"8````JP````````"U!@``````````````````B@$```````#+`0``````
M``H```"^`0```````/D#``"J`@``TP8```````!9````RP```.(&````````
MYP$```````!>`0``V0```$H!``"P!```J08````````F`P``````````````
M````@P,```````"`!0``PP``````````````H`4``%\#``"(!````````#P&
M``#V`0``]0$```````!.!```2@```(D%``#G!0``$`4```````!0!0``````
M`/P%```^!0``S`````````!!`@```````(<```!8!0``80```%\!``!J!0``
M`````/T#```I`0``>P```%($``````````````````#[!```+`8```````"O
M````>@0``-$#````````[@$``#@&```6!@``\P8``,\%``#"!```]P$``/<&
M````````[`,``#P`````````Z`$``!<&``"``@```````%0!``!P!@``````
M`%H$``#=`@``L`,``*@&```0`@``M0,``-8````I````:0$``(@#````````
MI@,``````````````````+$$``"N!@```````!H$```-````6P,``$H$``#,
M!```5P,``(4$``#O!```DP$``%@"``"<`0``(P,```````#P`@``6`$`````
M``#'!```.`4``,`#``"1!@``)@8``-8%``"?!0```````"H&``!D!0``00``
M```````<`P```````*`!```'!P``)`4``````````````````-D"``!C!0``
MY0(``"\#``#S`P``X@,``$,```"L!@``<0(``%\"``!E`P```````-$!```R
M`0````````````##!```R`$```````!3!0```````-P````B`P``*```````
M``#4`@```````/H!```)!P``=P$``&@`````````````````````````MP(`
M``````!`!@``JP0``+L&```R!````P0````%``"N```````````````#`@``
MC0,```````#K`@````````4&``!C`0``*`$```````!7!`````````````!H
M`0```````$X````(`P``504````````H!@``#`0``+`%````````9@0`````
M```S`P``V08```````!.`@```````#L$``!T`@``EP```',```!9`0``X`4`
M`$("``!1`P``10,``$````#=`````````&X!``!\!```"P,``!$$``#,`@``
M@00``!\!``!3`0``E04`````````````J0```#$#``!_!```;@0```````"K
M`0``C@,``"L````[`P``3P,``)<!``!%`@```````!\%````````VP(`````
M`````````````$T"``#*!@``P0$``)X#``!_````G@```*<&``!2!0``````
M`.`#``!:````0@$``#(%``#*`0``F0```/H%``"X`0``CP```&$!```,`@``
MI0,``!D'````````\P(``!('``#I!0``8``````````A````9@$````````6
M`P```````````````````````!L#``!R!```>`(``*T$````````308```8%
M```]!0```````&L#``#E````V@8``!D!``"S`@``_P,``)P$``"X!0``````
M``0#``!B!```)08```````!]`0``)@0``"8%```P`P``(P<``,$%```(!P``
M````````````````&`4``"@"```J!P``2`4```````#Q!@``60,``%4!``"C
M`0``&P4``(L!``"E!0````````````"W```````````````+!0```````'$&
M``"X`P``L@4```````#2`0``OP$```````",!@``UP4````````4````@P0`
M`$H"```B!@``5`8``"T!```Z!@``X04``&`&``#8`0``#`4``)8%``#P````
M`````),%````````;@,``)D!``"0`@``C@0`````````````!`(````````?
M!P```````)<"````````1@0``/D```!U!0````````\!``"[````:@$``+P%
M``#G`P``00,``+P&````````8@```/L```#A`@``9P4``",$``!1`@``&P(`
M````````````%P<```$&``!:`@``7`(```````"4`@```````%L%```3`@``
M*@```+H$``!D`@``.00``'T````/!```IP(``#$!```3`0````````````"M
M````#@,```````!_!@```````#\&```@!0``/0,``$`%```I!```J`0``*@!
M``!/`0``SP8```````!3````CP$``````````````````*,$``"J!```````
M``````!"!0``!P$``$@"````````'````)\"``#.!0``&0(``'(!````````
M`````"\```!6`0``&`0``"D#``!>`@``+0(``)`&``#<`@``S@8`````````
M````#P,```````"B!@``708``%0"```J`P```````'8%``!D````U@(`````
M``#;````#@8```````!L`0``:@0``+T$``#4`0```````*D!``!Y!```.`,`
M`%@$``!Z!@``_`0``.D```#6!@``1@(``.@```"Y!````````/0"```!!P``
M%@<````````M`````````"0!``!R````)````)8```!)`0```````)T%``"(
M`@``3P```(@&``"S`P``^````+H!``#O````,P4``!4"``#C!0```````&@#
M``"'`P``T`(``,`%``!L`@``"`0``!,%```=!@``\0(``-T#``#3`@``6P$`
M`"@#```X`0``7@```$L&``!;!@```````)(`````````Q@```%4$``#J`P``
MJ`(``"0"````````\@$``$X&````````&`8``"L$``````````````````"I
M`P``HP```/8%````````'00``#T&```*!@``_@,```$%``"U````Y@4``,@&
M``!#!0``8P0``(0%``#K`0``[@,``-H```"*`P``,`8```0&````````1P<`
M```````,!P``\00``+\&```*!0``V@4``#<'``"&`````````&0&````````
M50```-\!```$!`````````````#E`P``/`<```````#=!@```````&P$``"Z
M`@``?`8`````````````YP(``````````````````$D%``#$!0``GP$`````
M``![!0``*P4``$,"``#U`@``008``%H#`````````````-4$```X`@``+P0`
M`)($````````>@(``.\"``#I`P``&P$``,("``"P`````````!L$````````
M[`8````````X!P``]00``)@&```,````FP0```````"J`P``SP(``-X```#2
M!@``%P0``%<%```A!````````!<#````````<`0```````"3````D@(`````
M``#9`P```````!(#``"S!0``,08``%T"```O!P``<`(``*<!``"G!0``#P8`
M````````````V`(``*P#``#_````&P8``.<$``#_!```O0$```````"``0``
M608``&L!``".!0``^@(``%L```!4`P``]P,``$0```"Y`0``.P(``*0#``!P
M`0```````&4%```9!```Z`,```````#T!0``P00``"<$``#[`0``KP(``/,%
M``".`@``G0```&("``"A`@``[`$``!@'```>!P``<@4``.T$```^!@``````
M`'D&``!=````NP$``$P&``#O!@``$P<```````#F`0```````&T%```Q!```
M8P,```(&````````-`<``"L#`````````````*X"`````````````+X"``#1
M!@``2P$``(L`````````1`0```````!)`P``F0,``*(````W!@``T@,``+T#
M``"B`P``!P```-L!````````,@8``"4%````````!@````````#2`@``N0,`
M`-L#```5````J`4``","```-`0```````$<%````````:`0``(P$``"`!```
M```````````+!P``1@```#H'```M!@``4`8````````[!0``T`8``.\%``#K
M````NP(``#X$``!H!0``10$``%L$``!&!@``M`8``'4#````````J````,H"
M``!=!0```````!<```#J`0``5@0``&D%``#:`@``C`(``&,`````````````
M``P&``"]`@```````-4"``#X!````````.P%```U````;0$```````!S`P``
MS@$``"($``!P`P``.@````````"^`````````',!``#4````00$````````:
M`@``9P0``*(%```"````2@8```````"2`0``ZP0```````"@````I0````L&
M````````/P$``'<#``!?!0``P0(```````!:!@``R@4``(@%```\`@``'04`
M`(<$``!7`````````)L!``#)!```W@(```````!J`P````````````!Q`P``
MF08``&$"``!M`@``(````.X%````````,P<```````"M`P``Y0$``#D'```V
M`P``"`4``,0```!2`@``M@,``/$!``#-!````````%`!```V!P```````"0$
M``#9`0``P0,``.0#```A`0``4`0``),#``#5!@``6`8``.D&``#-`P``)`<`
M`````````````````$0'``!Q`````````#$"``#2!0``/@$``)H$```Z!0``
M!0<```````#6`P``N@8``$0%```N!@``S`4``)L%````````H`,``'<%````
M````60(``&T$`````````````#,!````````P0````````!G`P``@@```%4"
M``"N!```@P4``*,#``"<````*04``.D"``"E`@``I`(``$T'```K`0``P`0`
M`*$%`````````````)T"```/!P``0P<``$@```!R`P``R````&<!``#X`P``
MI@0``"D&````````\0,```````"7!`````````<%``"8!0```````-X&````
M````108```X!````````G@4``$`!`````````````)L#```1`@``-04``(D`
M```&`0``+@,```("``!'````E`0``"<!````````PP,``+`&````````Z@8`
M`-@```"Q`0``*@$````````R````9`0``*D%```0!P``R@,``%X#````````
M``````````"B`0```````"T#```X!```D0``````````````QP$``+(#``"M
M`0``[04```````!0`@``20(``*X%``#@!@``A@$``%8"`````````````",%
M``"C!@``I`$``$H%``#;!```H`8``%0$``"&`P``AP4``)\#``#/!```````
M```````W`@``Z@````````">`@``R04```````!:`0````````````#+!@``
MI08`````````````/P,``"(%``":````A08``'\!````````````````````
M`````````$<!````````?`$``)@"````````(`0``.0`````````%@0``!@"
M```6````%`(``!<"``"%`0``TP0``/P#``#^!@````````````#L`@``````
M````````````;@```!(!````````U`,``)L"`````P```````-\%``#P!0``
M``````````"!`````````#P!``!+````MP0``(8$``"^!0``M0$``%P%``!O
M`@``'`$``-D$````````!@<``/$%``!K`@``M@$```````#1`@``"08``#X'
M````````CP4```````!(`0``L@(``(T`````````Y`0```````#H`@``9`,`
M`/@"````````JP(``(H"````````\`0``'L&````````O@,````````!!```
MG00``*4!``"'`0``U04``/8"``!B`P``4````*8```#V`P``RP(``,,"``"W
M`P``]`$``-P%``#+`P``;08````````>!0``*P<``"X$`````````````$0&
M``````````````````!?!```Q`8``.`"````````[``````````G````1@<`
M``````#A````+`<``"`&``!"!P``3P4``'\%``#%!```E0,```````!%!P``
M3`<``*P%``#^`@``H0,``.8#``!^`@``^00``-<!``!4````L`(`````````
M````Q04``#,&``"D````O@8``*H&``!T````#08``'D"```+`@``:`(``,,&
M``!1!@``_````(X!``!3`@``EP4``!H%``"?````(P```#0"``!Z!0``/0$`
M`(0$```X````W@$```````!O`0``+@````````#[!@``70,````````,`P``
MNP4``&D```!=`0`````````````E!```H00``-<"``"[`P``_00``+$"```-
M`P``_0(``.X"``#>!0````````T$````````F0(````````(`0``7`0`````
M``!Y`P``C```````````````"@<`````````````?`(``(<&``!I!```;@4`
M`,(!`````````````/<"``!N`@``<@(``)P&``#<!```0`<````````*`@``
M1@$`````````````CP,``````````````````"P````U`@``ZP8``*D$```W
M`0``X00``&D"``!3`P``F`0```````#C````P08``"("``!1!0``$04``.@&
M```1!P``M@```)@#````````00<``+0$````````B@```(L%``#.!```I@4`
M``````!A!@``$0```,0#``#Y`@``A`(``"8```"R``````````````!<`P``
M-@$``,,%````````]0,`````````````X0,``)H&``!#!````````'0#``!T
M!@``-@(```````"``P``6P(````````5`P```````-``````````$`8``*<`
M```G`@```P8``+H%```!`0``T04``)X&```)`@``VP8``#,$``````````8`
M`+,!``!S!@``800````````N!0```````#H#``!#`P``9P(``$\$```.`@``
MXP(``.X$``#/`P``)0(``#L!`````````````-(`````````W0$``'X&``#<
M!@``L0```!\"``"K!@``Q0(``.D$``#B!0``%P$``*<$```2````]0```%X$
M`````````````+H`````````>P0```````!N!@``OP```/4%```%`0``2@,`
M`*P`````````/0```"8'``#'!0``Q@0``(@```!S!```+P$``-0%````````
MG08`````````````XP,```(#```1`P```````+H#```G!P``M@0```````"_
M!```*`0``(@!``!W`@```````$L'``!``P``A@8``%T$```.!P``[0```#0`
M```#`P``F@(``,8!``!_`P```````$L%``#:`0``?0(``/H`````````````
M```````F`@``=`4``($"``#V!```'`<``/(````?!```>`,``*4$````````
M/`,``(D#``"!`0```````*P"``#N!@``M04``#H!``"N`0```````/\!````
M````8`0``````````````````"('``"R!```/P0``(4```!)!```E00``)$%
M``#]!0``@`8``,L$``"W!@``L@$``&4!``!.!0````````T"``"-!@``U`0`
M`%8%```4!@``?08``*H%``">!```.P<``#H$``"8`0``:P4```4#``"#`0``
M8@$``#D"``"W`0``$08``'8&```````````````````/`@``A````-<&````
M```````````````.````1P8``(H%``!$`0```````/@!``#M`@``)0<``,<"
M```+`0``.0$``(L#``#Y!0``E@,``&D#``"1`0```````)0#``"9!```````
M`(\&````````>`0```($```J!````````'D!``#A`0```````'T%``#-`@``
M>P(````````[````Y@(``#D`````````#`$``!,$``")`@````````````!M
M`````````!@#``"Y`@``P`$``````````````````+P"``"Q`P``\P0`````
M```]!```'0$````````$`0``U@$```````#-`0``T`,````````T!@``D@4`
M`+P$``#"`P``?@````````#7`P``4@$```D!```&!```5P$``&<```"L!```
M`````'4"``!V`0``<`4``/L%```L!0``Q0```"T'``!+`@``@```````````
M`````````-4#``!3!```T`$``$\&```:!@``!`4``+P#``#M!@``)0$`````
M`````````````"D"``!6!@``,@<``!T#``#&`P``!00``,`"```'`@``(04`
M`%@#``#K!0``WP(``!X!``#W`````````+X$``#@!```2`,``#(#``!/`@``
M``````````!^!````````&`!````````V`,``#,"`````````````)8&````
M````S`8```````"6!````````)0%````````DP8```````#?````:`8``'X%
M``!-````&04```````#C!@``O````!H```!L`P``R0$```````!V`@``)0``
M`'4`````````+@$``-T%```*`0```````!L````K`@``G@$``%@````:!P``
M30,``-,````Z`@```````$8%`````0```````'P#``#V!@```````#D%``"5
M`````````+(&``#_!0```````,,!``#+!0``LP0`````````````E0(``!8!
M````````%@(``&8&````````6@4``*H````(!@``S@`````````Y!@``````
M`-,#``!R!@`````````````K!@``LP```((!``!W!```VP4```````#T`P``
MOP(````@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D
M87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``B
M)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S(B!I<R!N;W0@82!V86QI9"!C
M:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E
M9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B('=A
M<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@
M=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R96%T
M960Z("5S+@`E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E
M*0`E9"`E<R!A;F0@)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X
M<&ER97,N`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&:6YG97)P
M<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER
M;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M
M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!I<R!R96%D
M>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K
M960@8F5L;W<N($-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@
M>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`"5S(&ES(')E<75I
M<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E
M<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E
M<R=S(%1A<VML:7-T`"5S.B`E<P`E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@
M8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO
M=VEN9R!A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD
M97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN`"P@9W5S=&EN9R``
M+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S
M96QE8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U
M<G,`/%!R979I;W5S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F
M;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P
M=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S
M:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E
M+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G
M92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N
M`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@
M;65S<V%G92X`04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3
M:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI
M<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<W,@
M9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@
M8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N
M="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D
M($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!
M9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G
M<F]U<"!T;R`B)7,B`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!
M9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D
M('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D
M9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`061D
M('5S97(`061D960@(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T
M(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)7,N`$%D9&5D
M("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+@!!9&1I
M;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D
M;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D
M;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`
M06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@
M57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED
M97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@
M;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)
M35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)
M35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T
M92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A`$%N
M(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O
M<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO;GEM
M;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U
M9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I
M<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X
M:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C:&EV
M92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y
M;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@86YY('-U8BUG
M<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)+3@I
M`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R=`!!<VEA+U!A
M8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN
M9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`
M071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M
M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M
M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`075G
M=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I
M;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@
M9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C>7)U
M<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T
M<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@
M4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@
M4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z
M(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P
M.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I
M<F5C=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P
M;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!297%U:7)E
M9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE
M('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,`075T:%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]L9&%P.B!5<&1A
M=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T
M;W)Y+@!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A
M:6QE9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A
M:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E
M<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$%U
M=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"X`079A:6QA
M8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"86-K9W)O=6YD`$)A8VMG<F]U;F0@
M0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E
M<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"
M86YG;&%D97-H`$)A<F)A9&]S`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E
M<R(@;F]T(&9O=6YD+@!"87-E;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE
M`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@
M87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L
M;V-K(%1Y<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R
M('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O
M=&@`0F]T<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I
M<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"
M=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--
M4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE
M<RXN+@!#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#
M86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@
M875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A
M;B!N;W0@=W)I=&4@=&\@9FEL92`B)7,B`$-A;B=T(&-O;FYE8W0@=&\@24U!
M4"!S97)V97(Z("5S`$-A;B=T(&]P96X@9FEL92`B)7,B+@!#86YA9&$`0V%N
M8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@
M(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN
M;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A
M;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D
M(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N
M=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M
M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D
M(&YU;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A=&5G;W)I97,@86YD($QA
M8F5L<P!#87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE
M<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z
M`$-E;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N=')A
M;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y
M+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R
M=&EF:6-A=&4@4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E(%EO=7(@4&%S
M<W=O<F0`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE
M('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N
M`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H
M('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("!#;VYT86-T('EO=7(@861M
M:6YI<W1R871O<BX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EL90!#:&EN80!#
M:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA
M;"`H0FEG-2D`0VAO;W-E($%P<&QI8V%T:6]N.@!#:&]O<V4@82!P87-S=V]R
M9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T
M97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S
M*0!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T
M(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(%%U97)Y
M`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T
M80!#;&5A<FEN9R!,871E`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@
M=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO
M=61Y`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`
M0V]L;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R
M`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`
M0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M
M;W)O<P!#;VUP86YY`$-O;7!U=&5R<P!#;VYD:71I;VX`0V]N9&ET:6]N<P!#
M;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@9F]R('-Y
M;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RX`0V]N
M9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O;F9I
M<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B
M;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL
M960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V
M97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N`$-O;G1A8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D
M9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT('1Y<&4@;V8@8V]M
M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#;V]K
M($ES;&%N9',`0V]P>0!#;W!Y(&9A:6QE9#H@)7,`0V]P>2!S96QE8W1I;VX`
M0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP
M="!M97-S86=E.B``0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#;W5L
M9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-
M12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U
M;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!B:6YD('1O
M(&QD87`@<V5R=F5R`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L
M9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<@!#;W5L9"!N;W0@8V]N;F5C
M="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S`$-O=6QD(&YO="!C<F5A
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96-R>7!T(%!'
M4"!D871A.B``0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD
M(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R
M861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I
M<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L
M971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I
M<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E
M(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;&]A9"!S
M=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@(B5S(BX`0V]U;&0@;F]T
M(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@
M;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U;&0@;F]T(&]P96X@)7,N
M`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O
M=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#;W5L9"!N;W0@<F5A8V@@
M=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T
M(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3
M;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R
M>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@
M;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U
M;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E
M=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE
M=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@
M<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N9FEG
M=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER("(E<R(N`$-O=6QD(&YO="!S879E
M("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O
M;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T
M:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T
M;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO
M;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L
M;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE
M($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK("(E<R(N`$-O=6QD(&YO
M="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@
M9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A
M<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I
M=F4@=7-E<B`B)7,B('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L
M9&5R("(E<R(Z("5S`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E
M871E`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B
M(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB
M97(`0W)O871I80!#=6)A`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N="!4:6UE
M`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@57-E<G,`0W5R<F5N="!796%T:&5R
M`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@
M=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T
M:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W
M<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P
M=6)L:6,`1$0`1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO
M96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!$86EL>0!$
M871A5')E92!"<F]W<V5R`$1A=&%B87-E($QO;VMU<`!$871E`$1A=&4@4F5C
M96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M
M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L=`!$
M969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!3:&5L;`!$
M969I;FET:6]N<P!$96QE=&4`1&5L971E($-E;&P`1&5L971E($=R;W5P`$1E
M;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M
M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES
M=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E('!E<FUI<W-I;VYS(&9O
M<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U
M8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E
M;G1I='D`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U
M<G)E;G0@<F]W`$1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`
M1&5L:79E<GD@=&EM90!$96YM87)K`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E
M<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H
M;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER
M96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U
M<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9&5T86EL960@9F]R
M96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$
M:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II8F]U=&D`1&\@;F]T(&1E;&5T
M90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S
M('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE
M<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI
M8P!$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O=VYL;V%D`$1O
M=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S
M(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%4E(`
M16-U861O<@!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI
M<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E
M<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B
M`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!3
M86QV861O<@!%;&5M96YT+BXN`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@
M861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N
M`$5M86EL+71O+5--4R!'871E=V%Y`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E
M+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@:6YS
M97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT
M/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@>65A<@!%
M;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H
M('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@
M<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_
M)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5Q=6%T;W)I86P@1W5I;F5A
M`$5R:71R96$`17)R;W(`17)R;W(@8W)E871I;F<@8FQO8VLZ("5S`$5R<F]R
M(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC
M(&QO9SH@)7,`17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<P!%<G)O<B!U<&1A
M=&EN9R!P87-S=V]R9#H@)7,`17)R;W(@=W)I=&EN9R`B)7,B+@!%<W1O;FEA
M`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R
M>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`
M179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M
M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP
M96-T960@)RDG`$5X<&ER871I;VX@1&%T90!%>'!O;F5N=`!&1R!#;VQO<@!&
M5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N
M8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D
M('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O
M;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@=&\@8W)E
M871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E
M<R(N`$9A:6QE9"!T;R!R971R:65V93H@)7,`1F%I<@!&86QK;&%N9"!)<VQA
M;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X
M`$9A>&5S`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3
M:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEE;&0@;6%T<FEX`$9I:FD`1FEL
M92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA
M;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I
M;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`1FER
M<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O
M9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O
M<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T
M("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@
M9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@
M;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R
M9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E
M`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE
M<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E;F-H($=U:6%N80!&
M<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&
M<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL
M($YA;64`1V%B;VX`1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I
M9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=H86YA
M`$=I8G)A;'1A<@!':79E;B!.86UE`$=O`$=O961E;`!';V]G;&4@36%P<P!'
M;V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y
M+3<I`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R
M;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L
M92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60Z(`!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R
M;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U
M861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES
M<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(
M5$U,`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H
M+4%L9V]R:71H;0!(87IE`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A
M;F0@36-$;VYA;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE8G)E=R`H25-/
M+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP
M97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I
M;&4Z`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`
M2&]M90!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(
M;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@
M)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+
M;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R
M9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A
M9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E
M<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER
M97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R
M="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI
M<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O
M;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E
M<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N
M=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(
M;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@
M;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ
M(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I
M;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0
M(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S
M`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET
M:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25]N<V5R="!2;W<@0F5F;W)E`$EC
M96QA;F0`26-O;G,@3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT
M`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R
M96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@
M9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@
M>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X('1O('1U<FX@;V9F(%!.
M1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N
M;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B
M92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!);6%G92!0<F5V:65W.@!)
M;6%G92!54DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@
M9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S`$EM<&]R="P@4W1E
M<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S
M97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN
M8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U
M<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@
M:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`
M26YD;VYE<VEA`$EN9F\`26YF;W)M871I;VX`26YF;W)M871I;VX@;F\@;&]N
M9V5R(&%V86EL86)L92X`26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM
M86=E`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU
M;6X@0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT
M(&]N90!);G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!)
M;G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T
M(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@
M<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E
M<FYA=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI
M8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C
M96QL(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F
M=&5R`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E
M<G0@<&%R86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN
M<V5R="!R;W<@869T97(`26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R
M97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E
M<G0O36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE
M;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!)
M;G-U9F9I8VEE;G0@8W)E9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A
M;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!);G9A;&ED(%I)4"!D871A
M`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L
M:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S
M<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&QI8V5N<V4@:V5Y+@!)
M;G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+@!);G9A;&ED(&US9U]T>7!E+@!)
M;G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@
M<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI
M9"!P87)T;F5R(&ED+@!);G9A;&ED('!R;V1U8W0@8V]D92X`26YV86QI9"!P
M<F]T;V-O;"X`26YV86QI9"!R96-I<&EE;G0Z("(E<R(`26YV86QI9"!S:&%R
M92!O8FIE8W0`26YV86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC
M;V1E(&1A=&$N`$EN=F5N=&]R>0!);G9E<G0@<V5L96-T:6]N`$ER86XL($ES
M;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES
M;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA
M;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE
M<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`
M2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K
M:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E
M:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+97D@0W)E
M871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y
M(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G
M<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N("A%54,M
M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E
M;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@4&%S
M<W=O<F0@0VAA;F=E`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@
M;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@
M3F5V97(`3&%T=FEA`$QA=P!,87EO=70`3&5B86YO;@!,969T`$QE9G0@:&5A
M9&5R`$QE9G0@=F%L=65S`$QE<V]T:&\`3&EB97)I80!,:6)Y86X@07)A8B!*
M86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!2
M86EN`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A
M:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`
M3&EG:'0@4VYO=R!3:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK('!O:6YT<R!T
M;SH`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E
M('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,:7-T("T@=7-E<B!C86X@<V5E('1H
M92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T
M(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/
M=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB
M90!,:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!F
M86EL960Z("5S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U
M<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A
M;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;@!,;V=I;B!4
M87-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A
M<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N
M`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R
M(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,=7AE;6)O=7)G
M`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A
M+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E
M<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I;`!-86EL($%D;6EN`$UA
M:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L
M=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@
M;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@
M=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87)C
M:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET
M:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H
M86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U<FET
M86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G
M92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA
M>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A
M;"!";&]C:W,`36%X:6UU;2!L96YG=&@`36%Y`$UA>6]T=&4`365D:6-I;F4`
M365M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G
M92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T
M:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E
M9"X`365S<V%G92!T>7!E`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N`$UE
M=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R1$(@:7,@;F]T(&-O
M;FYE8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B(&ES(&YO="!D969I;F5D`$UE
M=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,`365T<FEC`$UE
M>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L90!-
M:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA
M<W0@-B!H;W5R<SH@`$UI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T
M(&5X<&ER960`36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A
M8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO
M=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@
M=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG
M(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@
M240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF:65D($1A=&4`36]D
M:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO;F%C;P!-
M;VYG;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO;G1S97)R870`36]O
M;B!0:&%S97,`36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H
M92!E>'!E8W1E9"`E9"X`36]R;V-C;P!-;W-T;'D@0VQE87(`36]S=&QY($-L
M;W5D>0!-;W-T;'D@4W5N;GD`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I
M9VAT`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!-=6QT
M:2UL979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EP;&4@<V5L96-T:6]N`$UY
M($%C8V]U;G0`37D@06-C;W5N="!);F9O<FUA=&EO;@!->2!0;W)T86P`37D@
M4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE
M`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@
M06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A
M=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE
M=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!34TP@
M<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S
M8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A;&5D
M;VYI80!.97<@0V%T96=O<GD`3F5W($UE<W-A9V4@=&\@)7,`3F5W($UO;VX`
M3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W('!A<W-W
M;W)D`$YE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"X`3F5W('!A<W-W
M;W)D<R!D;VXG="!M871C:"X`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE
M=W-G<F]U<',`3F5X=`!.97AT(&]P=&EO;G,`3F5X=#X`3FEC87)A9W5A`$YI
M9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;R!A=F%I;&%B;&4@8V]N9FEG
M=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I
M;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C
M:"!T96UP;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@
M<&]S:71I;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A
M=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9')E;B!C86X@8F4@
M861D960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&
M:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L
M:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO(&EC;VYS(&9O=6YD+@!.;R!L;V-A
M=&EO;B!I<R!S970N`$YO(&QO8V%T:6]N('!R;W9I9&5D+@!.;R!M97-S86=E
M('-U<'!L:65D+@!.;R!N86UE('-P96-I9FEE9"X`3F\@;G5M8F5R('-P96-I
M9FEE9"X`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-7
M1"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--
M0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA
M<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@
M=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S
M+@!.;R!Q=6]T82!S970N`$YO(')U;&5S`$YO('-E<&%R871O<B!S<&5C:69I
M960N`$YO('-I9&5S`$YO('-U8V@@9FEL90!.;R!T96UP;W)A<GD@9&ER96-T
M;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P
M87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V
M86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T
M:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U
M;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R
M871I;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX
M.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO
M<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"
M969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T('-E
M=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@
M8F%C:RX`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU
M;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P
M96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+
M`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9FEC90!/
M;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P
M87-S=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`3VYL
M>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O
M;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S
M>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O
M=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I
M;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R
M;VT@<VEG;F5D(%,O34E-12!P87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N
M97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O
M<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L
M(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T
M90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R
M;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I
M<R!N;W0@879A:6QA8FQE+@!014%2.CI-86EL(&)A8VME;F0`4$=0($1I9VET
M86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME
M>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L
M;`!032!,:6=H="!286EN`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H
M;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!/4TE8(&5X=&5N<VEO;B!I<R!M
M:7-S:6YG`%!?2%`@4VAE;&P`4&%D9&EN9P!086MI<W1A;@!086QA=0!086QE
M<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@
M1W5I;F5A`%!A<F%G=6%Y`%!A<G1L>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O
M<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN`%!A<W-W;W)D(&EN8V]R<F5C=`!0
M87-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!0
M87-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z
M(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP
M8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E
M<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO
M;B`B)7,B(&YO="!D96QE=&5D+@!097)M:7-S:6]N($1E;FEE9`!097)M:7-S
M:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O
M<FUA=&EO;@!097)U`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I
M=&-A:7)N`%!I>&5L<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE
M87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M
M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T
M:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N
M`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L
M96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A
M('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@
M;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V
M:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@
M>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E860@=&AE(&9O
M;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T
M;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R
M>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S:71I
M;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE
M`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0
M<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C:7!I=&%T
M:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT
M96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S
M<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A
M="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@
M:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`4')I;G0@
M9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T
M:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME
M>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME
M>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O
M`%%A=&%R`%%U97)Y`%%U;W1A`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A
M9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@
M4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T
M=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M
M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N
M;F]T(&)E('5N9&]N92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S
M:`!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T
M86P@5FEE=SH`4F5G97@`4F5L871I;VYS:&EP($)R;W=S97(`4F5L;V%D`%)E
M;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE
M>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E
M(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@
M<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R
M>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M
M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297%U97-T(&-O=6QD
M;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U97-T
M960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N`%)E<75I<F5D("(E<R(@
M;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B
M)7,B(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I
M<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U
M:7)E9"!&:65L9`!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A
M<W-W;W)D`%)E<W1O<F4@3&%S="!1=65R>0!297-U;'1S`%)E='5R;B!T;R!/
M<'1I;VYS`%)E='EP92!N97<@<&%S<W=O<F0`4F5U;FEO;@!2979E<G0@0V]N
M9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2
M:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE
M<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A
M=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`
M4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@
M8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL
M>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S
M<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3
M:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N
M=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@
M4VAE;&P`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN="!(96QE;F$`
M4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R
M92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN
M97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O
M;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B
M:6$`4V%V90!3879E("(E<R(`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U
M<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF
M:6=U<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S
M(BX`4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%
M;F=I;F5S`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R
M;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R
M`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D
M871E(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&YO;F4`
M4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S
M(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M
M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E
M;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U
M('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!3
M96QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I
M96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P
M<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!3
M35,`4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT
M96YE9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T
M(&%V86EL86)L92X`4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N
M`%-E<W-I;VYS`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S
M970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U
M<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M
M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I
M;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P
M;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@
M;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C
M<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I
M=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@
M4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S
M="!L:6YK<S\`4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N
M=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I
M;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO
M=R!P:6-K97(`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W
M('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H92!486)L92!#96QL
M(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@
M9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3
M:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3:&]W('5P;&]A9`!3
M:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@
M=&AE(%9I8VEN:71Y`%-H<FEN:P!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N
M871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP
M($UA:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W
M97(`4VYO=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E
M<G,@3&%T90!3;F]W(&1E<'1H.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`
M4V]N9W,@)B!0;V5M<P!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D
M<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I
M`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S
M`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A
M;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T
M`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I
M($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R="!Y96%R`%-T871E(&]R
M(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S
M<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M
M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U8F1I<F5C=&]R>2`B)7,B
M(&YO="!F;W5N9"X`4W5B:F5C=`!3=6)M:70`4W5B;6ET=&5D(')E<75E<W0@
M=&\@861D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@
M=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B965N(&%P<')O=F5D+@!3=6)S8W)I
M<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@861D960@(B5S(B!T;R!T:&4@<WES
M=&5M+@!3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R("(E<R(@
M9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@9&5L971E9"`B)7,B+@!3
M=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C
M8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S
M964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U
M<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U
M<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!U<&1A=&5D("(E<R(`4W5C
M8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U;6UA<GD`4W5N(%)I<V4`4W5N
M(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3
M=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P<&]R=`!3=7)I;F%M90!3
M=7)N86UE`%-V86QB87)D(&%N9"!*86X@36%Y96X`4W=A>FEL86YD`%-W961E
M;@!3=VET>F5R;&%N9`!3>6YC(&QO9R!D96QE=&5D`%-Y;F--3`!3>6YT87@@
M97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E<'5B;&EC`%0M
M4W1O<FT`5"U3=&]R;2!A;F0@5VEN9'D`5"U3=&]R;7,`5"U3=&]R;7,@16%R
M;'D`5%-6(&9I;&4`5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!486)L92!P<F]P
M97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK
M:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A
M<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M
M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP97)A='5R93QB<B`O/B@E<TAI
M)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E("(E<R(@;F]T(&9O=6YD+@!4
M96UP;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!497AT(&%L
M:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AE($94
M4"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($AO<F1E+TMO;&%B
M(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE
M($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"X`5&AE($UA:6YT
M96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@
M3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%D;6EN
M:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI
M<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS
M+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V]N=&%C="!)1"!N=6UB97(@
M=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N
M9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!D971A8VAE9"!0
M1U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@
M<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@
M96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD
M(&EN('1H92!D871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N
M;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E
M(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT
M86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A;FYO="!B92!C;W!I
M960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+@!4
M:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E
M+W)F8S@R,B!M97-S86=E+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D
M96QE=&5D+@!4:&4@;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@
M;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP
M=%]P9W`Z.B!C;&%S<RX`5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W
M:71H('-U8FIE8W0@(B5S(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@
M;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O
M<B!U;F1E<G-T;V]D+@!4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O
M('1H92!C;VUP;W-E('!A9V4`5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B
M92!N=6UE<FEC+@!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R
M('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC
M92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X
M8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M
M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U
M;F0@;VX@=&AE('-Y<W1E;2X`5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E
M(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED
M97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E<&%R871O
M<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<V5R=F5R("(E
M<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N
M('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E
M;6]V960N`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+@!4:&4@
M=&5M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('1E>'0@
M>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R
M965N+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I
M9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@
M<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E
M('-A=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L
M92X`5&AE;65S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`5&AE<F4@87)E
M(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA
M="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY
M(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E
M<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H
M97)E('=A<R!A('!R;V)L96T@861D:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@
M)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R
M("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!R
M96UO=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R
M;V)L96T@=7!D871I;F<@(B5S(CH@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@
M=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@
M8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R
M92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N
M`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D
M871A+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@
M9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`
M5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A
M9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N
M`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A
M:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R
M;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y
M(&%G86EN(&QA=&5R+@!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O
M<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B
M92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@
M8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!F:65L9"!I<R!R97%U:7)E
M9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N
M+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4
M:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@
M;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N
M=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I
M;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`
M5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES
M("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE
M=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T
M:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&
M;W(@82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@
M)7,`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E
M="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@
M8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S
M('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY
M(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H
M:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD
M;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O
M<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H
M=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D
M;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI
M;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O
M:V5L874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')I
M;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R
M:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A
M;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5
M+E8N(&EN9&5X.B``55),`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O
M(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S
M97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA
M;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C
M:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T
M;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@
M(B5S(BX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,O)7,B+@!5
M;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N
M;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L
M92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E
M871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N
M`%5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@
M8W)E871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D
M871A+@!5;F%B;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@
M;F]T(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S+@!5;F%B;&4@
M=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L
M92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!6
M1E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@<F5C
M=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER
M96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS
M`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@
M=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D
M(&%R8VAI=F4N`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I
M(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ
M92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B;&4@=&\@
M<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@
M)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F
M<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N
M86)L92!T;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@9&%T82X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W
M:6QL(&)E(&5X8V5E9&5D+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E
M<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S
M97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O
M;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET960@
M07)A8B!%;6ER871E<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N
M:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN
M;W=N`%5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W
M;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T
M:6]N('!R;W9I9&5D+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5
M;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E
M9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A
M;6%T:6-A;&QY(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@
M<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO
M=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L
M:7!B;V%R9"X`56YS970@8V]L;W(`56YS=7!P;W)T960@17AT96YS:6]N`%5P
M9&%T90!5<&1A=&4@)7,`57!D871E('5S97(`57!D871E9"`B)7,B+@!5<&=R
M861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI
M8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN
M(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R
M96YT.B`E<P!5<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E
M<F5N="!F;W(@24U34"!S97)V97(N`%5S97(`57-E<B`E<R!I<R!N;W0@875T
M:&]R:7-E9"!F;W(@)7,N`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I
M;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B
M965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@
M9F]U;F0`57-E<FYA;64`57-E<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`
M57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB
M96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO
M;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A
M;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E<P!686QU97,@=&\@<V5L
M96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T
M:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E
M<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L
M:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T
M($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E
M<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET
M:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET
M>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!2
M14U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=)3B!V:6$@2%144`!7
M86QL:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`
M5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@
M4VET90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S
M`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!7
M97-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P
M;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C
M=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H97)E:7,@075S
M=')A;&EA(&UA<`!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B
M;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!I;B!#
M4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A
M:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L
M90!7:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD
M('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5VES:&QI<W0`
M5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!7<F]N9R!N=6UB97(@;V8@
M9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O
M;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+@!8
M-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R
M;F%T:79E($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P
M.78S(&5X=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE
M;@!997,`665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E
M('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9
M;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO
M8VMS+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N;F]T(&AA
M=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D
M:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG
M="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H
M92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA=F4@8F5E;B!L
M;V=G960@;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N
M92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O
M<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@
M1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N
M9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P
M<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T
M+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN
M=',@=&\`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D
M+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9
M;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S
M="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I
M9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W
M:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A
M=&5G;W)Y(&YA;64N`%EO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P
M:&]N92!N=6UB97(`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A
M<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ
M(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R
M97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E
M<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T
M(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B
M86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@
M=VES:"!T;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S
M+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C
M:V5N9"X`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U
M<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@
M9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@
M87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O
M9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@
M>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S
M=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U
M<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N
M9"`K(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@
M9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U
M;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA<R!E
M>'!I<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F
M('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D
M+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@
M:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W
M:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I
M<F5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA
M;6)I80!::6UB86)W90!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P
M;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@
M)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T-,
M20!?1&%T851R964`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA9V4@
M4')O<&5R=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN
M+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]3971U
M<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`&-A
M;&5N9&%R`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4`8V%N;F]T(&]P96X@
M:6YP=70`8VQI8VL@:&5R90!C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(`8V]N
M9FEG=7)A=&EO;B!E<G)O<@!C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG
M`&1A=&$@9F]R;6%T(&5R<F]R`&5N=')Y(&YO="!F;W5N9`!F:6QE`&9R;VT@
M=&AE("5S("@E<RD@870@)7,@)7,`9W5S=&EN9P!H.@!H:`!H;W-T(&YA;64@
M=6YK;F]W;@!I;6UE9&EA=&4`:6YL:6YE`&EN<'5T+V]U='!U="!E<G)O<@!I
M;G1E<FYA;"!S;V9T=V%R92!E<G)O<@!L:6YE<UT`;6T`;F%M90!N;W0@:6UP
M;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`'!E<F-E;G0`
M<&5R;6ES<VEO;B!D96YI960`<&EX96QS`')E;6]T92!E<G)O<B!I;B!P<F]T
M;V-O;`!R:7-I;F<`<V5R=FEC92!U;F%V86EL86)L90!S:&]W(&1I9F9E<F5N
M8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S<P!S=&5A9'D`<WES=&5M(&5R<F]R
M`'1A<VL@;&ES=`!T96UP;W)A<GD@9F%I;'5R90!T>7!E('1H92!P87-S=V]R
M9"!T=VEC92!T;R!C;VYF:7)M`'5N:69I960`=6YN86UE9`!U<V5R('-E;&5C
M=`!V0V%R9`!W.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ($AO
M<F1E(#,N,"UC=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH
M;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#$M,#4@,34Z,#0K
M,#@P,`I03RU2979I<VEO;BU$871E.B`R,#`Q+3$R+3(P(#$R.C`P*S`X,#`*
M3&%S="U4<F%N<VQA=&]R.B!$879I9"!#:&%N9R`\9&%V:61`=&UV+F=O=BYT
M=SX*3&%N9W5A9V4M5&5A;3H@5')A9&ET:6]N86P@0VAI;F5S92`\:3$X;D!L
M:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP
M93H@=&5X="]P;&%I;CL@8VAA<G-E=#U"24<U"D-O;G1E;G0M5')A;G-F97(M
M16YC;V1I;F<Z(#@M8FET"@`@*"5S(*31JV4I`"`HI]:QML'D("5S*0`@*"5S
M(*31I+HI`"`HI+6DT2D`("BI^J31*0`@**Q1I-$I`*GS`"(E<R(@I*.L3Z1`
MK=.EV+_]`"(E<R(@I*.L3Z1`K=.FLZ[$JKJ_[[[<+@`B)7,B(*E\I;RF8B!(
M3U)$12"JNK7YI57`R2A296=I<W1R>2FDI+-=J7<N`*?DI*.H["`B)7,B('1R
M964@<F5N9&5R97(N`"(E<R*D=Z:HI5RJNJ5;I$JH[+ASLM6H=++.I*0N`"(E
M<R*D=Z5;I$K%=JVMJ'2RSBX`(B5S(JC#I;RKV*7?.B`E<RX`I'>HSZ7.("4N
M,F9-0B`LKF6V<2`E+C)F34(@++/1OFP@*"4N,F8E)2D`)60@)7,@I4BDSB`E
M<P"SS*KQI$"FN+%+O5C%W*?SJ?,@)60@I-&K92X`L\RJ\2`E9""DT:[PMDBY
M=[/X`"5S("T@L\:GT;_]`"5S(*O\K[X`)7,@2T(`)7,@NOO%0+[>IT`@+2"]
M5+M[`"5S(+-=J7<`)7,@M?FE50`E<R"F4+=.MK6EV``E<R"D=Z9SIF(`)7,@
MIF(@)7,@)7,`)7,@I'>T3J15ID.HQK:UJKJZ^\5`OMZG0+1.NOPN(+W0J?.F
MN:[)I,2_[Z=!MU&M;K[>IT"JNK:UI=@N`*6RN]VM;B`E<P`E<R"DP`"GY*2C
MJ.P@)7,N`"`E<R"H["`E<R"F0"`E<P`E<ZJZLW&P5+_]`"5SJKJFYJC&ON0`
M)7.JNK/&I]&__0`E<ZJZJ]V_[,.O`"5S.B`E<P`E<SH@LV^KRJM(I?.DHZ1`
MJ7>O=:71JTBDI*JZL4BE\Z1(J=*Q2+5O+B"]T*I@MTZD5:9#J=*FLZJZNO2X
M]+-SM;*FLZ5IK^"LJKI\IT&JNJW3I$BXZJ[&+@`L(+!]K;<@`"P@L'VMMR`E
M<R`E<P`LQ=RDQK9QL7$@)7,@J.P@)7,`+2T@O^^^W"`M+0`Q,B"D<*[)J.X`
M,C0@I'"NR:CN`#(T(*1PKLFH[@"D5Z1`K;8`IKFPS[;TI;*VMZUNJ_RI=[CJ
MKL:N=Z;XJD&ZW2X`M6^ES:1&I$"MT\19K:NJNK_YNWX`L?VE6[%+MFRE\RS!
MV;O=K6ZFLZ1`K=,@4$=0(*2]MGVJ]\9?+@"Q_<7GP]*D=\.QL[FJNK9LI?,L
MP=F[W:UNIK.D0*W3(%!'4""DO;9]JO?&7RX`L?VXT;%+MFRE\RS!V;O=K6ZF
MLZ1`K=.DO;9](%!'4""J]\9?+*APL4L@4$=0(*KWQE\LI4BDSK-QP_:D9J5/
M+@"Q_;#UIN:V;*7SP[&SN2S!V;O=K6ZFLZ1`K=.DO;9](%!'4""J]\9?+*AP
ML4L@4$=0(*KWQE\LI4BDSK-QP_:D9J5/+@"Q_;C1L4NV;*7S+,'9N]VM;J:S
MI$"MTZ2]MGT@4TU)344@JO?&7RRH<+%+(%--24U%(*KWQE\LI4BDSK-QP_:D
M9J5/+@"Q_;#UIN:V;*7SP[&SN2S!V;O=K6ZFLZ1`K=.DO;9](%,O34E-12"J
M]\9?+*APL4L@4R]-24U%(*KWQE\LI4BDSK-QP_:D9J5/+@"Q_:5;L4NV;*7S
M+,'9N]VM;J:SI$"MTR!334E-12"DO;9]JO?&7RX`I,BK9::SMK,`I,BK9:1P
MJT(`I,BK9::SJT(`I,BK9;!]JT(`I,BK9;!]L[<`I,BK92^DR*OA`$%022"]
M<[BY`,/VJ?.S;ZW3O7._Z+ZY`,/VJ?,N+BX`I;^D5:3H`*6_I*2EH0#%=JVM
MI*.HK"RU3*IKJ]BEWR!61E,@I=B__2X`Q7:MK:2CJ*PLM4RJ:ZO8I=\@5D93
M(,#)KM<N`+%BN+FXZK!4`+%BN+F[4+%+O5@`L6*XN:1WK>&ULBX`M;*Q8@"W
M<[Q7`+=SO%>FN+ASLM4`MW.\5Z1LQ7:MK0"F8J:YMW.\5SH`MW.\5[ASLM4`
MMW.\5\5VK:T`MW.\5Z:XN'.RU:CL("(E<R(`MW.\5Z:XQ7:MK:;<(B5S(@"W
M<[Q7I$"MTZC/I<ZJS#H`MW.\5\3FINP`MW.\5Z1`K=.FJ*W[.@"W<[Q7N>\`
MMW.\5R`E<R"LL"!-;WII;&QA(*JZI,"MM@"W<[Q7J.RJNK-QL%2__3H`MW.\
M5ZCLI]JJNK-QL%2__0"W<[Q7J,^ESJK,`*1WMW.\5R`B)7,B(*CLJ'2RSJ2D
M+B"F_;5,JFNW<[Q7PT*E?JJZM?FE5;CJL%0Z("5S+@"D=[=SO%<@(B5S(B"H
M[*ATLLZDI"X@IT&R>Z9BI6FE2+9IIN:U;J1*I$8N`+=SO%>HSZ7.JLRJNJ5<
MK^"EV*MELU'#]K.L+@"F8:=]`+-QL%2__0"FJ*RPNMZR>JW[("T@K+"HY*5,
MJ,^ESJK,LUVI=\5VK:T`NMZR>@"\<Z=I`$%F9VAA;FES=&%N("BJ_+1)IKTI
M`$%L8F%N:6$@**K\NKBDVJ6GJ,@I`$%L9V5R:6$@**K\NKBDSJ=1J,@I`+9L
MI?.G3Z97`+GON_0`N>^[]*3HIJ$Z`*G2IK,`J=*FLZ1WQ>?#TJJZJ,^ESJK,
M`*G2IK.X<[+5`*G2IK/%=JVM`*5^KMB]=0"DN;-<IFZT6*W3N7&D;+9LI?.F
M8:=]`*2YLUS%W*?SMK6EV+USN+FJNJNLND$_`*1WIG.F8@#%W*?S($E-4U`@
MM6ZD2@#%W*?S($E-4U`@L4N]6`#%W*?S($E-4U`@J,^ESJK,`,7<I_.Y<:1L
MMFRE\Z;MIWT`Q=RG\[S+JD\`M,"E3J3EIG(`06UE<FEC86X@4V%M;V$@**S\
MQ%*P[<+$O*^HR"D`I$"MT[5,KL2JNJW(LU&HSZ7.+@"U;Z7-I$:D0*W3I;RJ
MOJJZO_F[?BX`06YD;W)R82`HIG>Y1*;5*0!!;F=O;&$@**9WK?2IU"D`06YG
M=6EL;&$@**9WIF.IU*YQ*0"PSJ97I4ZR>J9SJ/H`M:JNUP!!;G1A<F-T:6-A
M("BK;K>EI&JSL"D`06YT:6=U82!A;F0@0F%R8G5D82`HIG>THZ7*KG&DSJ3:
MNKBEK+E&KG$I`,"SI<ZU>Z:A`,"SI<ZU>Z:ALDVSY@#`LZ7.M7NFH:1WM$ZZ
M_`"N3:7.J.RITJ:SJKJFN*9`J,D`I^6MXP"Y=Z;TI&JD<`"E?*3K`*K\J=2G
M0J3E("A7:6YD;W=S+3$R-38I`,"CP5G`R:1JI'``P*/!6<#)IE>ZV0"G0;U4
MJ7>M;J=2L*,@)7,@JKJU^:55MMP@/P"G0;U4J7>M;J=2L*,@(B5S(B"E2*3.
MI?2F\ZJZIKBX<[+5(#\`07)G96YT:6YA("BJ_*[:I\HI`$%R;65N:6$@**C(
MK/REIZC(*0"HR*S\I:>HR*3E("A!4DU30TE)+3@I`,/`LTX`07)U8F$@**K\
MOGRDVJYQ*0!!<V-E;G-I;VX@27-L86YD`*3EIG+#P+-.`*C(K'<OI-.EK:QV
MIF&PSP"P]:;FOMZG0+K[Q4"K9<7CI=R]5+M[N>^XW#\`I,"P=,3FINP`P'RX
MU:=2L*.D0*W3I*.F<Z9BJKJX<[+5+@#`?+C5IU*PHZ1`K=.DHZ9SIF*JNL5V
MK:TN`,!\N-6]<[_HI$"MTZ2CIG.F8JJZN'.RU2X`P'RXU;USO^BD0*W3I*.F
M<Z9BJKJF0*C)+@#$W:G*`*1+I.L`075S=')A;&EA("B_1*1JIU&HR"D`075S
M=')I82`HMOBF8:=1*0!!=71H7V-R>7-Q;#H@I^2DHZCLJ=*[W:UNJKH@:6UA
M<""IM:;YKDVE\RX`075T:%]C>7)U<SH@IOBJ0;K=J,.EO+2CJ-&XT[:UI.2T
MJ2X`075T:%]C<GEU<SH@I^2DHZCLJ=*[W:UNJKH@:6UA<""IM:;YKDVE\RX`
M075T:%]F='`Z(*?DI*.H[*G2N]VM;JJZ($944""IM:;YKDVE\RZ]T*VKMW.]
M<\2V(%!(4""HPZ5"I5ND2B`M+65N86)L92UF='`@O^^VM2RHTJ9P(&-O;F9I
M9W5R92`M+65N86)L92UF='``075T:%]I;6%P.B"GY*2CJ.RITKO=K6ZJNB!)
M34%0(*FUIOFN3:7S+@!!=71H7VMR8C4Z(*?DI*.H[*G2N]VM;JJZ(&MR8C4@
MJ;6F^:Y-I?,N`$%U=&A?;&1A<#H@MW.\5ZC/I<ZJS+-OMK6E7*_@I=BK9:C#
MI*.DY+2II=B__:I!L,@`075T:%]L9&%P.B"G4K"CJ,^ESJK,LV^VM:5<K^"E
MV*MEJ,.DHZ3DM*FEV+_]JD&PR`!!=71H7VQD87`Z(*?DI*.H[*G2N]VM;JJZ
M($Q$05`@J;6F^:Y-I?,N`$%U=&A?;&1A<#H@M4RJ:[=SO%>HSZ7.JLP@)7,N
M(*;XJD&^N:9>P+,Z`$%U=&A?;&1A<#H@M4RJ:[*^L*.HSZ7.JLP@)7,`075T
M:%]L9&%P.B"U3*IKI_.W<ZC/I<ZJS"`E<P!!=71H7VQD87`Z(*?SMW.HSZ7.
MJLRS;[:UI5ROX*78JV6HPZ2CI.2TJ:78O_VJ0;#(`$%U=&A?;6-A;#H@I^2D
MHZCLJ=*[W:UNJKH@34-!3""IM:;YKDVE\RX`075T:%]S;6)A=71H.B"GY*2C
MJ.RITKO=K6ZJNB!S;6)A=71H(*FUIOFN3:7S+@!)34%0(*;XJD&^N<7GP]*_
M^;M^+@#%Y\/2I:*QT2X`Q>?#TJ6BL=$N("5S`%)!1$E54R#%Y\/2O_F[?BX`
M1E10(,7GP]*_^;M^+@!334(@Q>?#TK_YNWXN`*5II<ZJNL3FINPZ`$%Z97)B
M86EJ86X@**C(MNNK]+5-*0"M2;2Z`*U)M+K#0Z;B`&ME<F)E<F]S(+%+O5B_
M^;M^+@!K97)B97)O<R"HSZ7.JLRF5[K9O_F[?BX`0F%H86UA<R`HI-JKHK"H
M*0!"86AR86EN("BDVJI,*0"J:<.YJKJN_*3E("A)4T\M.#@U.2TQ,RD`0F%N
M9VQA9&5S:"`HJ7.E6ZG4*0!"87)B861O<R`HI-JHJ:9H*0"GY*2CJ.RYSZ7<
MI=B__2`B)7,B+@"P\KUU`$)E;&%R=7,`0F5L9VEU;2`HI/&G4:[)*0!"96QI
M>F4@**BIJ+VTM2D`0F5N:6X@**BIN><I`$)E<FUU9&$@**;*O'VY1BD`0FAU
M=&%N("BDHZ2F*0"ES:3I`*?DI*.H[,"SI<ZU>Z:A(B4R)',BJKJPS[;T(B4Q
M)',B+@"PS[;TLUVI=P"PS[;TJZRZ00"RRL7I`$)O;&EV:6$@**S!IU&Z^ZC(
M*0"NT<72`*[8O74`KMB]=:1JI'``KMB]=0!";W-N:6$@86YD($AE<GIE9V]V
M:6YA("BJ::1HI:>HR*3.ML+!R:WTNONHNBD`I?ZSH0!";W1S=V%N82`HJFFE
MOJBZ*0"IL[.A`$)O=79E="!)<VQA;F0`0G)A>FEL("BDVJ;H*0!"<FET:7-H
M($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T@**A:
MM=PI`$)U;&=A<FEA("BK3Z5;IU&HR"D`MK6EV++%N+D`0G5R:VEN82!&87-O
M("BEK+18K\>J:Z_!*0!"=7)U;F1I("B[6K:IIF$I`*JIK;&ZWK)Z`$-20P!#
M4DP@I,"SH<))`,!XIG.NYJ2ZKF4N+BY?90"GUJCZJNRI;*3&J7REO*>YIJ@N
M`*;FJ,:^Y`"Y<Z_%K;<`0V%M8F]D:6$@**Q:KDBYZRD`0V%M97)O;VX@*+/8
ML\&VJ2D`M4RJ:Z;;L,JMJ[AML4N]6"R]T,%PM;BG0:JZJ'2RSKK>LGJM^RX`
MM4RJ:[QGI$K`R:[7("(E<R(`M4RJ:[-SO76FW"!)34%0(*;XJD&^N3H@)7,`
MM4RJ:[9]L=+`R:[7("(E<R(N`$-A;F%D82`HI5NNLZ1J*0"H^J[X`*CZKOBP
MW<-$IEZS^`"U3*IKIU*PH\#)KM<@(B5S(BX`I^2DHZCLO,BF<Z78O_TN`*_*
MI-8@)W1A<F=E=$9I;&4G(+#1O,:U3*IKQ'[$\K-"LGHN`+5,JFNROK"CI=B_
M_2`B)7,B+@"U3*IKLKZPHSL@)60@K=.D;+:PI'>F<Z9B+@"U3*IKK:NRU:%#
MJ=*THZC1JKJP3[_]O,:EV+M0I?VK9:G2P'BF<ZJZN.JNQJ2CLL4N`+5,JFNV
MQ[!EPK*P5*CLJ_RI=ZJZN+F]6"X`0V%P92!697)D92`HNON\=ZBD*0"[H:GZ
MI.6F<@"DP,/^NU"\T,72`$-A>6UA;B!)<VQA;F1S("BV?;#2N'.N<2D`IN:P
MRKEQN-P`P'BF<Z[FI+JN90#`>*9SKN:YU*52.@#`>*9SKN:DNJYE`,!XIG.N
MYK:AMEHZ`*;FL,JY<;C<`+;KNKBO4Z3E("A)4T\M.#@U.2TQ-"D`N&VDI`!#
M96YT<F%L($%F<FEC86X@4F5P=6)L:6,@**2DJT2F0*E-L.HI`*2DO-H@*$E3
M3RTX.#4Y+3(P`+[,P]*RT[A@`+[,P]*^UJ:SJLP`OLS#TJQ&M:8`0VAA9"`H
MK&2\=RD`I_.G[P"G\Z?OIT&JNK%+O5@`I_.G[Z=!JKJJNJ7^IE>E2*3.IEZV
M;*9AIWTN`*78JV6JNK-=J7>HPZ6\I.2TJ;%+O5C%W*?S+B"]T,%PM;BG0:JZ
MNMZR>JW[+@"F<J2X`,#+K&2S<[6R+BXN7VL`0VAI;&4@*+2\IU$I`$-H:6YA
M("BDI+#J*0#"LL7II*2DY2`H1T(R,S$R*0"EO\7II*2DY2`H0FEG-2D`O^^^
MW,"SI<ZU>Z:A.@"_[[[<L4N]6`"_[[[<I$"MTZC/I<ZJS*97NMD`I.FTP<7C
MI=RDZ*:A.@"_[[[<MK6EV*NLND&JNJVWKN8`0VAR:7-T;6%S($ES;&%N9"`H
MN'2]SZYQ*0"GY*2CJ.P@)7,@JKK#_J=/J7>X<2X`M+@`LDVPH[=,LVX@3V9F
M:6-E(+S0Q=(`LDVPHZQDN-\`LDVPHZC/I<ZJS#H@)7,`LDVPHZC/I<ZJS`"R
M3;"CJ,^ESJK,JKJXZJ[&`+'?PN"TN`"K]K?&N:O!Y*5(Q'[$\@!#;&EC:V%T
M96QL(+-ZN4P@2%144`##]K.LM?BUH0"VL[9Q`*:MIFBVLP"SL0!#;V-O<R`H
M2V5E;&EN9RD@27-L86YD<P"GZ<5\N.JNQJ>H`*?IQ7S#Y*S)`$-O;&]M8FEA
M("BM]*W;I/&HR"D`PT.FX@"]U:;BO4P`,3:V::;LPT.FXJ5.O5@`Q.8Z`,3F
MINR\T,-$`*5DLW$`J5*E3P"GY::XJ5*E3P"U^[W7`+K9J4D`0V]M;W)O<R`H
MK.R\K\.Y*0"DO:5Q`+EQN*,`P/2YT@"Q^*7S`*YTLJ<`NU`@4$1!(+1XI%>K
MK+EQN*,LM+R\>JNLI.*^]Z5(I,X@3W5T;&]O:R"JNJ90J$*S7:EW+@"S7:EW
MN.JNQKE,M,$N`+-=J7<@)7,`O52[>[%+O5@`0V]N9V\@**WHJD<I`$-O;F=O
M+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4@**WHJD>F0*E-L.HI
M`+-SM;*EHK'1+@"S<[6RI:*QT3H@`+-SM;*FW*2]MGVJ]\9?IOBJ0;ZYKLF^
M1*G:+@"S<[6RIMRDO;9]JO?&7Z;XJD&^N:[)OD2IVBX@K>RF73H@)7,@*"5S
M*0"S<[6RIMP@1E10(,#)KM>F^*I!OKFEHK'1+@"S<[6XI$@`L$^__:1WIJBE
M7*9AMW.\5Z;<IT&JNK-QL%2__:2D+@#`H\%9P,FNUZJZI+JN9:NLND$Z(``B
M)7,B(,#)KM>DNJYE`,1^Q/(`0V]O:R!)<VQA;F1S("BL[*=*N'.N<2D`O<:[
M<P"]QKMSI:*QT3H@)7,`O<:[<P!#;W-T82!2:6-A("BM]+2UI&J^I*5;*0!#
M;W1E(&0G279O:7)E("BV2*3ZKORII"D`M4RJ:Z5((%!'4""E6[%+MFRE\SH@
M`+5,JFNE2"!01U`@L/6FYK9LI?/#L;.Y.B``M4RJ:Z5((%,O34E-12"E6[%+
MMFRE\RX`M4RJ:ZRP(%,O34E-12"V;*7SP[&SN2X`M4RJ:[=SO%>S<[6XI$@N
M("5S`+5,JFO#M+6R($Q$05`@IOBJ0;ZY`+5,JFO#M+6R(&QD87`@IOBJ0;ZY
M`+5,JFO`RZQDMVRO<2X@)7,`M4RJ:[-SM;*FW"!L9&%P(*;XJD&^N0"U3*IK
MLW.ULJ;<IOBJ0;ZY("(E<R(@J,^ESB!&5%`Z("5S`+5,JFNKV*7?L'2X;;AS
MLM4N("5S`+5,JFNXT;%+(%!'4""XZJ[&.B``M4RJ:[C1L4L@4R]-24U%(+CJ
MKL8N`+5,JFNG4K"CLW.UN*1(+B`E<P"U3*IKIU*PH[!TN&VR3;/F+B`E<P"U
M3*IKIU*PHZ?SMW.U>Z:A("(E<R(N`+5,JFNH3:EWIJRE\Z1(JKJY<:1LMFRE
M\Z;LIWTN`+5,JFO`\JCZI[F^XZJZLW&P5+_]+@"U3*IKP/*H^J>YON.JNK!T
MN&VR3;/F+@"U3*IKP/*H^K!TN&VR3;/FI*2JNKASLM4N`+5,JFNX_*1*M::R
MI"`B)7,B+@"U3*IKJ]BEWZ78O_T@(B5S(BX`M4RJ:Z;;JO?&7Z;XJD&^N:CZ
ML6^DO;9]JO?&7RX`M4RJ:[9]L=(@(B5S(B"E2+QGI$HN`+5,JFNV?;'2("5S
M+@"U3*IKMGVQTKK[Q4"D=:=`O-*RU2`E<P"U3*IKMGVQTJ78O_T@(B5S(BX`
MM4RJ:[-SL;4@3$1!4"`@IOBJ0;ZY+@"U3*IKQ:JH^B`E<RX`M4RJ:ZVKMW.S
M7:EWJ,^ESJK,JKJQ2[U8+B"SH:3`JKJRT[A@I*.EO[U4+B"]T,%PM;BG0:JZ
MJ'2RSKK>LGJM^Z5(J/.G5;-"LGHN`+5,JFO%JJCZIG.H^K&QJ.ZJ[2A!8V-E
M<W,@0V]N=')O;"!,:7-T*0"U3*IKQ:JH^K-QL%2__2X@)7,`M4RJ:\6JJ/JP
M=+AMLDVE52X@)7,`M4RJ:\6JJ/JP=+AMLDVE52X@)7,`M4RJ:\6JJ/JF^*I!
MOKFJNJS;P_:O4ZG*`+5,JFNF7K1?LUVI=RX`M4RJ:Z=2L*.EV+_]("(E<R(N
M`+5,JFO`>*9S("5S(*JZLUVI=RX`M4RJ:\!XIG.SQJ7WLUVI=RX`M4RJ:\!X
MIG.SQJ7WLUVI=SH@)7,N`+5,JFO`>*9SI_.W<[5[IJ&H[#H@(B5S(BX`M4RJ
M:\!XIG.SQJ7WLUVI=R`E<RX`M4RJ:\!XIG.S7:EWP,DE<RX@IT&E::5(J,^E
MSB5SI*2JNJCDI4RE7*_@P'BF<[-=J7>ISJ3BL,J]QKMSI%6ML;5[IJ&]6*CL
M("5S+@"U3*IKMVJT32!,1$%0(""F^*I!OKDN`+5,JFNG4K"C("(E<R(N`+5,
MJFNG\[=SLW.UN*1(+B`E<P"U3*IKI_.W<[!TN&VR3:55+B`E<P"U3*IKPM"\
M9R`B)7,B.B`E<R"JNK-=J7<N`*?DI*.H["!-;WII;&QA(*JZI,"MMBX@O="]
M5+M[I,"MMJQ/IU^V?;'2+@"U3*IKO>&DJ:C/I<ZJS"`B)7,B(*15ID/%=JVM
MJ.RK2*7SIU@@(B5S(CH@)7,`I]ZS3J5Y`+#JKF$`O=*J[0"KV*7?`*O8I=^D
M0*W3LW.UL@"KV*7?I$"MT[=SJKH`J]BEWZ:XJTBE\Z=8`*O8I=^JS*JZQ7:M
MK0"K2*7.I62XN;U8`$-R;V%T:6$@**=*P[FFZ*C(*0!#=6)A("BE:J3:*0"E
MV*MEMWRTP0"EV*MEKLFVH0"EV*MENO2G?0"EV*MEJKJHSZ7.JLP`I=BK9:31
MKO``I=BK9:JZJJRJ<#H@`*78JV6JNJVWKN8`IMNM<:1`J,>U;J1*)7.KX:G2
MK6ZP]:;FJKJD=:=`+@"PQ:15`+#%I%4`0WEP<G5S("C!R;2VL,>TM2D`INBH
MO;JXI.4@*$M/23@M4BD`INBHO;JXI.4@*%=I;F1O=W,M,3(U,2D`INBHO;JX
MI.4OKU&G2L3UI.4@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,@*+&VITJF0*E-
ML.HI`*3I`+CJKL:HT[>]IE>ZV2`HO="PT:;2(&AT='`Z+R]P96%R+G!H<"YN
M970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H
M<"D`J$.DZ0"^\*JLN.JNQL)SQ/T`N.JNQJYWMVJT30"DZ;3!`*:LJ.RDZ;3!
M`+_OOMRDZ;3!`*75I-$`IU*PH\3FINQ?;`"D4:1'I.L`I%&V::;LO,:F<@"T
M[J36P5FQQ@"Y=[-=`+EWLUW#0Z;B`+EWLUVJNJBMI??#T:=/`+EWLUVI4J5/
MN-&J4KZY*%-H96QL*0"I=[AQ`*=2L*,`IU*PH\!XIG.NY@"G4K"CN'.RU0"G
M4K"CK/:__0"G4K"CQ7:MK0"G4K"CH4*R3:K%MFRE\P"G4K"CP'BF<Z[F`*=2
ML*/$YJ;L`*=2L*.R>Z9SJKJTP*5.O,NJ3P"G4K"C(B5S(JJZQ7:MK0"]5*EW
MK6ZG4K"C(B5S(JJZQ7:MK:5(I,ZFN,5VK:T@/P"G4K"CID,`IU*PHZG2O^^^
MW*JZJ*VE]\/1IT^XZJ[&`*=2L*.EV*MEJKK$YJ;L`*=2L*.EV*MEJKJF0P"G
M\[=SM7NFH2`B)7,B(*1WIU*PHRX`N[RP9:[)MJ$`1&5N;6%R:R`HI*:SP2D`
ML-W#1+1YK7H`M'FM>@"RT[A@("B]T+#1IM(@2&]R9&4@L$^__<#)KM<I.@"R
MT[A@O="PT:;2J'2RSKK>LGJU;K_]+@"LX[5O`,53PDFWQ:O7`+/,J^&D0*1P
MKLFJNL53PDFWQ:O7.B``Q5/"2;?%J]<Z(`"Q<:6JIMRE:P"Q<:5KIMREJ@"E
MV+_]`*5((#(T(*1PKLFH[L7CI=P_`,7CI=R_[[:U`,7CI=RXU++3JKJY=[/X
M`,7CI=RY=[/X("A4048I`,7CI=RNYJ:A`+;'L&6F7K'X`$1J:6)O=71I("BF
M3J6LIF$I`*2CIU*PHP"DHZUNJKVQM:9SJ/H@;6%I;G1E;F%N8V4N<&AP`++$
MI$"UI[!/O_VL3Z=?I5VG=,3FINRF5[K9/R"F<*I'K$^]T*3$O^\N`$1O;6EN
M:6-A("BF:*GZI:>E6RD`1&]M:6YI8V%N(%)E<'5B;&EC("BF:*GZI:>E6Z9`
MJ4VPZBD`P=FH4Z:SL6*XN;;</R"U^:55+@"D5;C\`*15N/P@)7,`I%6X_+-=
MJ7?`R:[7I72F<ZRP(%!(4""U>Z:A+@"D5:G4I5ROX*KM`,/$JWX`N7&D;+9L
MI?,`O_F[?@!%8W5A9&]R("BDS*7*IFBZN"D`O7._Z`"]<[_HL,^V]`"]<[_H
MN'.RU0"]<[_HQ7:MK0"]<[_HQ7:MK0"]<[_H)7.JNL5VK:T`O7._Z+_OMK4`
MO7._Z"(E<R*JNL5VK:T`O7._Z"5SJKK%=JVM`+'0J'P`16=Y<'0@**Y*I,XI
M`$5L(%-A;'9A9&]R("C"Q+JXI<NF:"D`I+BE\RXN+@"Y<:1LMFRE\P"Y<:1L
MMFRE\Z;MIWT`N7&D;+9LI?.F[:=]I;*VMZ=KIE@N`+EQI&RV;*7SO52[>P!%
M;6%I;"UT;RU335,@N6BY1+ZY`*KML:&RQ;BY`*K%I=6K2*7S+@"JQ:75M;*J
M1RX`JL6EU;=JM$VVM:78`*2YLURFV\/`M%FTH:1*M].D^:CLJTBE\Z2D*+KT
MK;:]<[QGO-*FH2D@/P"QTK#*M\:YJZ5KP>2E7*_@JNT_`+6RI_2F?J7W`*GQ
MI&J]<[_HOKD`IG"J1Z=!N]VM;JVKLUVQ2[U8++W0O^FD2J1`K=.F=Z7^L-VE
M>2RHTJ9P(">G0<-DJJNJNJ97NMD@/R<Z`*9BIKF_Z:1*O':YLZJZNO2G?0!%
M<75A=&]R:6%L($=U:6YE82`HJ*JY1+18I+JHR"D`17)I=')E82`HI,REWZ]3
MJ+VF=RD`O_F[?@"KV*7?L,^V]"5SKLFU;Z7-O_F[?@"G4K"CIE"H0L'CPDDZ
M("5S(*[)M6^ES;_YNWX`IU*PHZ90J$*P3[_].B`E<R"NR;5OI<V_^;M^`,6J
MJ/JDNJYE.B5S(*[)M6^ES;_YNWX`I_.W<[%+O5@Z("5S(*[)M6^ES;_YNWX`
MO&>D2B`B)7,B(*[)M6^ES;_YNWXN`$5S=&]N:6$@*+=2J$:EIZC(*0!%=&AI
M;W!I82`HIN>OP:3QJ,@I`+K8L=H`175R;W!E("B\VJQW*0"H0R`Q-2"DP,3!
M`*A#(#(@I,#$P0"H0R`S,""L[<3!`*A#(#4@I,#$P0"H0Z:XM6ZD2@"H0R`S
M,""DP,3!`*A#(#$@I,#$P0"]9*C2K<@Z`+#UIN8`KFFV?0"N:;9]N.JNQJ>H
M`*UNJ$0@)RDG`*CLM,&DZ0"XT;NAK?L`JV6TNL-#IN(`1E10(*17ML>S7:EW
M+@#%JJCZL+ZF;K-=J7>EHK'1`+5,JFNS<[UUIMP@3$1!4""F^*I!OKDN`+5,
MJFNS<[UUIMP@4TU"(*;XJD&^N2X`O<:[<Z6BL=&FVR`B)7,B+@"]QKMSI:*Q
MT:CL("(E<R(N`+5,JFNKV*7?I$"MT[=SJKH@4T%33""S<[&U+@"W:+*^I:*Q
MT:CL("(E<R(N`,)>J/JEHK'1.B`E<P"TMK-Q`$9A;&ML86YD($ES;&%N9',@
MJFO$]:=*NM:X<ZYQ("BPJ+JXNONOQ[2UN'.N<2D`1F%R;V4@27-L86YD<P#$
M6:VKO_F[?CH`ML>O=0"VQZ]U`*1'I.L`MU#$L0"W4,2Q.B``I/*D\JM"`+5U
MO,BP?;.W`,3FINRP?:9#`$9I:FD@*+2TP-DI`,#)KM>\QJ78.B`E<R"MT\#)
MKM<`P,FNU[S&I=@Z("5S(,#)KM<`P,FNU\%@NMX`P,FNUZ97NMD`P,FNU[_O
MOMP`P,FNUZ17ML<`P,FNUZ17ML>E7*_@I;RS4:3DM*DN`+E,PF^^N0!&:6YL
M86YD("BJXL3U*0"D5Z5BI.L`I%>IM@"I5*EWI/&HT@"D5Z15Q$&MRP"O0K#*
M`,/Z`*78O_T@)7,@I*.F<Z9B`*9RJZS#0Z;B`*VYJJL`IEVLL,)SQ/V^N:C#
MI;RDY+2IO':YLZ5<K^`N`*[PMDBY=[/X("A4048I`+EWL_BDT;S&("BY=[/X
MI-&\QJ5=K$&EU:31I4BDSJE=MJ&JNKCJKL8[IG"J1[EWL_BDT;S&N/NJ^+%.
MIONESJ3QN/N\9;14JKJJJ:VQ*0"GT;!/L4N]6"`_`*KML^8`I'"[>0"D<+MY
MP_ZKK`"D<+MY`*1PNWD@,@"]U[["`*;;L,K"X*M(`*Q0M,&DK0"NV*Q;`$9R
M86YC92`HJFNPZBD`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E;F-H($=U:6%N
M82`HJFO$W;M<J,BHNBD`1G)E;F-H(%!O;'EN97-I82`HJFO$W:S!IU&EIZ;H
MJ,@I`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P"Q2*7SI$@`L7$`I[F^
MX[1YK7H`NJ&DZP"E_J97`$=A8F]N("BE6[1>*0##P+19.@!'86UB:6$@**7,
MI/&HR"D`LJ.ES2`E<R"MTZATLLZS7:EW`*1WLJ.ES:JZLUVI=[CJKL8`1V5O
M<F=I82`HL^RJ=JC(ID"I3;#J*0!'97)M86YY("B\=[#J*0!':&%N82`HK7NO
MQRD`1VEB<F%L=&%R("BJO:6LP[FJ^RD`IE>ZV0"K9:FY`*WTO'>ZN`!';V]G
M;&4@IF&YSP!';V]G;&4@MVJT30"FQ[:E`$=R965C92`HI\;#OBD`I\;#OJ3E
M("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0@**[FLZ[$]:YQ*0!G<F5N861A("BN
MYK?GK\>Y1BD`N'.RU;K>LGH`N'.RU:97NMFDH[%OJL6EU0!'<F]U<%]L9&%P
M.B"U3*IKMW.\5[ASLM4@)7,N(*;XJD&^N:9>P+,Z(`!'<F]U<%]L9&%P.B"U
M3*IKIU*PH[ASLM4@)7,`1W)O=7!?;&1A<#H@M4RJ:Z?SMW.X<[+5("5S`+AS
MLM4`1W5A9&5L;W5P92`HK?2\=ZREM+8I`$=U86T@*,/VKG$I`$=U871E;6%L
M82`HI<JF8;"HJ=0I`*[FKJ:FZ*YQ`*C3NZO%=JVM`+-8J\BO9*BE`$=U:6YE
M82`HM%BDNJC(*0!'=6EN96$M0FES<V%U("BT6*2ZJ,BD\:_!ID"I3;#J*0!'
M=7EA;F$@*+M<J,BHNBD`ME>DY;-SM;*[>:BE`*?DI*.H["!(5%10(,7GP](N
M`$AA:71I("BN_*9A*0#"^+3J+;ITNN(`QD<`JNW`60"J[<!9`$AE87)D($ES
M;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P"D:KEPJT(`I\:G0JC3I.4@*$E3
M3RTX.#4Y+3@M22D`L*JKUP"[H:GZ`+USO^B^N:C/I<Z[H:GZ`+NAJ?H`I6*R
M>0"S;[C,K$_`R:[7JKJV?:EL.@"PJ@"N85]M`$AO;'D@4V5E("BQZ[_-J:,I
M`*YA`*;MKF&F8:=]`*YAI=B__0"F[:YAN7&XW`!(;VYD=7)A<R`HI[NSHZG4
MM+4I`$AO;F<@2V]N9R`HK;NTY"D`2&]R9&4`2&]R9&4O2V]L86(Z(+9LI?,@
M)3(D<R"DI+E*J.RU3*[$JKH@)3$D<R!834RXZJ[&`$AO<F1E+TMO;&%B.B"U
M3+9LI?.^0:98JJNE\R`E<P!(;W)D92]+;VQA8CH@MFRE\R`E,B1S(*2DI^2D
MHZCLJJNE\ZNLND$@)3$D<P!(;W)D92]+;VQA8CH@I'>FJ*5<JKJROK"C("5S
M("(E<R(`2&]R9&4O2V]L86(Z(+[CIEBD=;5[N]VM;B`G9&]M>&UL)R"JNB!0
M2%`@J;6F^0!(;W)D92]+;VQA8CH@M4RJ:ZO8I=\@)7,@JJNE\ZJZ(%A-3""^
M\`!(;W)D92]+;VQA8CH@M4RJ:[*^L*,@)7,@(B5S(CH@)7,`2&]R9&4O2V]L
M86(Z(+5,JFO`\JCZLZ&E]R`E<R"KK+I!JKH@34E-12##T:=/N+F]6`!(;W)D
M92]+;VQA8CH@M4RJ:Z90J$(@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(+5,
MJFNF4*A"I,"HR3H@)7,`2&]R9&4O2V]L86(Z(*6\JKZJNJ3`J,D@(B5S(@"D
M]*6MO74`I/2EK;G4I5(`I/2EK3H`IT&F<*;SJ.RFN2`_("B]T+'4K7HA*0"G
M0:UNIEBHUJ9HI-:MT\3FINRI3S\`Q.:F[+S&I=BF0*UP/P"G0:UNIEBHUJ9H
MI-:F0ZE//P"WPZO7`+?#J]<Z(`"WQKU=I&JN=@!(=6YG87)Y("BF2:3ZIU$I
M`$E-05`@MFR]8ZO8I=^EHK'1.B`E<P!)34%0(+9LO6.G4K"CI:*QT3H@)7,`
M24U!4""V;+UCNL^ZT+!TN&VKV*7?I:*QT3H@)7,`25`@INRG?0!)4""F[*=]
MM4RJ:ZC/I<XN`$E0(*;LIWVHPZ2CIF(@0TE$4B"JNJ2YLURPS[;TI*0N`*9B
MJ^&ML;2AI$JF0U]N`$EC96QA;F0@**9"KG$I`*_"N<^EW``E<ZJZN<^EW`"Y
MSZ7<I,ZDY:9R`*BMI??#T:=/JKJF5[K9.@"F<*I'M4RJ:Z6_O52F8<7CI=PL
M("5S(*5(I72V?;'2MFRE\ZGSMW.U^+6AM^VDI"X`J,^ESB!);G1E<FYE="!%
M>'!L;W)E<B#"<\3]OKFNR:9PJD>H4Z:SK-VH[*7TIO.JNJ1PN<^EW"P@IT&E
M::_@N]VM;J3$O^^S;ZW3MK6EV*5(P_:SK"!03D<@O':YLZJZP?3"PZ[$JD<N
M`*9PJD>LW:CLLV^K:*A3IK.\=KFSJKJP5*ZG++-OJNVEW*=!JKK"<\3]OKFU
M3*IKQ>.EW*17ML>JNKQVN;,N`+QVN;.Y=\3].@"\=KFSNO2G?0"\=KFSNO2G
M?3H`O':YLZC3IMO#P+19`+QVN;.HTZ;;P\"T63H`I%>VQ[QVN;,`O':YLP"V
MUZ1*+""H0L9*("5D`+;7I$K$YJ;L.B`E<P"VUZ1*Q.:F[#H`IF*KX:VQM*&D
M2J9#7W,`O^FD2J2CI;^]5*JZIT"ESKU8+@"]T,#+K&2G0:JZJ,^ESJK,IE>Z
MV:3.L4N]6`"HSZ7.JLRF5[K9I*.EO[U4J<ZJS+EQI&RV;*7SINVG?:1WQ=RG
M\RZ]T,%PM;BG0:JZJ'2RSKK>LGJM^Z5(J/.G5;-"LGHN`+Q7I5O!6;'&`$EN
M9&EA("BF3*O7*0"MTZ=/J,^ESJK,`$EN9&]N97-I82`HIDREIRD`N.JP5`"X
MZK!4`+5,I6FESJJZN.JP5"X`IF*KX:VQM*&D2L3FINQ?;P"TH:1*N<^D^0"T
MH:1*JNVNY@"TH:1*NO2X]+-SM;(`IF*K9:VQM*&D2L3FINQ?0P"F8J78JV7$
MYJ;LJ^&ML;2AI$JD0*W3MW/$YJ;L`*9BI=BK9<3FINRK9:VQM*&D2J1`K=.W
M<\3FINP`IF*EV*MEID.KX:VQM*&D2J1`K=.W<Z9#`*9BI=BK9:9#JV6ML;2A
MI$JD0*W3MW.F0P"F8J78JV6X8,))J^&ML;2AI$JD0*W3K'&XJ`"F8J78JV6X
M8,))JV6ML;2AI$JD0*W3K'&XJ`"TH:1*I6FTP*5.O,NJ3P"W<[%+O5BQ3K%(
MM6^H[+-OK=.V;*7SIF&G?3H`IF*KX:VQM*&D2L!XIG.NY@"F8JMEK;&TH:1*
MP'BF<Z[F`*9BJ^&ML;2AI$K$YJ;L`*9BJV6ML;2AI$K$YJ;L`+2AI$JV;*7S
M`*9BJ^&ML;2AI$JL<;BH`*9BJV6ML;2AI$JL<;BH`*9BJ^&ML;2AI$JF0P"F
M8JMEK;&TH:1*ID,`IG>E_K#=I7FJNK6JKM<Z`+2AI$HOQ=RG\[QVN;,`M*&D
M2B_%W*?SNO2X]+-SM;(`PDF\QJ2CJ*RE2*;<J?.U3*IKML>P9;6YL'2X;;AS
MLM4N`,))O,:DHZBL+@"^X[S&`+[CO,:F0P"U3*[$JKH@541(**C/I<ZJS+CJ
MKL:J[<!9*2X`M4RNQ*JZ(%I)4""XZJ[&+@"U3*[$JKK`LZ7.M7NFH2X`M4RN
MQ*JZI^6FN+BYO5@N`+!EI5BJNKCJKL:U3*[$+@"U3*[$JKJEV+S0INVG?0"U
M3*[$JKK`R:[7KN:FH0"U3*[$JKJQPL5VO5@N`+5,KL2JNJ9AL,\N`+5,KL2J
MNB!M<V=?='EP92X`M4RNQ*JZJ<ZGY*2CJ.P@87!I7VED+@"U3*[$JKJISJ?D
MI*.H[+#1O,8N`+5,KL2JNJ3WQ7:MK2X`M4RNQ*JZN=FF\</1IT^]6"X`M4RN
MQ*JZLJ.K?KU8+@"U3*[$JKJS<;!4J/.I=RX`M4RNQ*JZIJRE\Z1(.B(E<R(`
MM4RNQ*JZI,"HR:JKI?,N`+5,KL2JNJC3M[VF[:=]+@"U3*[$JKJX5;#JO5BX
MZJ[&+@"XZK*C`*9>M%^_[[[<`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8@
M**7LKM0I`$ER87$@**7LJ=2G2BD`27)E;&%N9"`HMU*ZN,3U*0!)<VQE(&]F
M($UA;B`HL-*N<2D`I[VSH;EPJT(`27-R865L("BE2*;BID,I`,.QM6^JS`"Q
MU\7I`$ET86QY("BX<:1JIU$I`$IA;6%I8V$@**3ZME*E6RD`I$"DZP!*87!A
M;B`HI.FENRD`I.FDY2`H25-/+3(P,C(M2E`I`+]!INBN<0!*;W)D86X@**SY
MI;DI`*1#I.L`I+NDZP"Y[[OT`+AMI*0`I:JE:[GON_0`OF&EJKGON_0`OF&E
M:[GON_0`2V%Z86MH<W1A;@"K3Z]DK>R\RR`_`$ME;GEA("BJUJC(*0!+97)B
M97)O<R"[>\/2O_F[?BX`KM:DW[=SI.(`JO?&7ZO8I=\`JO?&7Z]3O'@`JO?&
M7ZKXJ]<`JO?&7ZNLND$`JO?&7[MYJFL`I=BK9:JZI+VV?:KWQE^F^*I!OKFD
MI"RD=[AGIG.F8J=!JKJJ]\9?+@"HX+6C`$MI<FEB871I("BP\JB]I-JTM2D`
M2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8@**5?P?HI
M`$MO<F5A+"!297!U8FQI8R!O9B`HJV[!^BD`P?JDY2`H155#+4M2*0!+=7=A
M:70@**SLJ\*O4RD`2WER9WEZ<W1A;@"JJ:VQL'2X;5]Y`+MYJ*4`3&%O(%!E
M;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,@*+QDL.HI`*15I6*DZP"SS*KQ
MI$"FN+%+O5C%W*?SJ?,`I%6IMJ3K`*17IKBG\[=S.@"D5Z1`IKBU;J1*.B`E
M<P"D5Z1`IKBU;J1*.B`E<R"FVR`E<P"D5Z1`IKBU;J1*.B"RQ*1`IKBU;J1*
M`$QA='9I82`HJ=2RYKK[J,@I`*IKJ]\`JJFML;!TN&T`3&5B86YO;B`HOJ2D
MVKG@*0"EJL/D`*6JP^2J[<!9`*6JP^2MR`!,97-O=&AO("B_X*_!IJLI`$QI
M8F5R:6$@*+_@I/&WYZC(*0!,:6)Y86X@07)A8B!*86UA:&ER:7EA("BG4:3Q
MJ,@I`$QI96-H=&5N<W1E:6X@**9#I.2TL+2UM6XI`+=,JT(`I'"K0@"FK::S
MI'"K0@"QWZ:SI'"K0@"D<+!]JT(`I'"K0J:SN7``I'"SMP"D<+!]L[<`I;2J
M;[C6`+-SM;(`LW.ULL))J.PZ`,7CI=RNR;-SM;*V;*7SINVG?:CLO7.\9[9L
MI?.MMJVQ`+-SM;(`ID.E6"`M(*C/I<ZJS*5II4BLW:CLLV^MTZM(I?.G6`"F
M0Z58N.JNQJYW`*9#I5B[H:GZO-##1`"F0Z58JNVNY@"P4;W7N'.RU2W`R:[7
MPF0`L%&]U[ASLM4MJ$2G50"P4;W7N'.RU2W#T:=/N+F]6`"P4;W7N'.RU2V^
MUJ:SJLP`L%&]U[ASLM4ML4BE\Z1(`+!1O=>X<[+5+:UQOEP`L%&]U[ASLM4M
MJ/JN^*UQOEP`ID.E6+=\M,&EHK'1.B`E<P"F0Z58J,^ESJK,I:*QT3H@)7,`
MID.E6*C/I<ZJS*JZI5ROX+-1P_:SK`"DY;['`$QI=&AU86YI82`HI=^SLZE[
M*0"X_*1*I*0N+BX`M^VF8:[)MJ$Z(`"F8;#/NU"NR;:A`*9AL,\`M6ZD2@"U
M;J58`+5NI$H`M6ZD2J1UIT``M6ZD2J6BL=$L(+W0P,NL9+O5I%6JNJ7.I.&F
M5ZE-L4N]6"P@M4VKX:VKN-4N`+5NI$JEHK'1+@"J^*5Y`+=2L:$`IT,`I'"\
M9Z?&P[Z\QJ9R`*1PO&>IU*1"O,:F<@"D<+QGP[FPJ+S&IG(`3'5X96UB;W5R
M9R`HOV.TR[/Y*0"DZP"H0Z3IL%2NIP!-4RU43D5&(*K^I5O`R:[7I*2H4Z:S
MN.JNQBX`35-'`$UA8V%O("B_1*KY*0!-86-E9&]N:6$L(%1H92!&;W)M97(@
M675G;W-L878@4F5P=6)L:6,@;V8@*+"HJ.2Y>:9`J4VPZBD`36%D86=A<V-A
M<B`HL*BY1J5;M+6E6RD`Q5VS3@"V;*7S`+9LI?.ZWK)Z`*O8I=^S<[6R7VLN
M+BX`36%L87=I("BPJ*G4J\(I`$UA;&%Y<VEA("BPJ*C3INBHR"D`36%L9&EV
M97,@*+"HNKBF8:32*0!-86QI("BPJ*=1*0!-86QT82`HL*BZN*5,*0"ZWK)Z
MIT&JNJ3`P_XLJ,.E0JRPI,##_K-=J7?#0Z;B+@!-87`R-""F8;G/`$UA<%%U
M97-T(*9AN<\`I%2DZP##Y*S)`+S0L$^FJ""LW;E,+Z6\K-VY3`"\T+!/IJBH
MY*5,JKK#T:=/("BHTJ9P+B"MJZUN+Z1WIE["T"D`36%R<VAA;&P@27-L86YD
M<R`HL*BN3+JXN'.N<2D`36%R=&EN:7%U92`HL*BTHZ6GITJN<2D`I,>P=,3F
MINRDI`!-875R:71A;FEA("BM5*=1MO"EIZC(*0!-875R:71I=7,@*+ROJ+VF
MZ+2U*0"DN;-<JKJSS*1JPDF\QBX`JOZE\[S&I=BD=[97I5BDN;-<I%>MK2X`
ML\RJ\2`R-""D<*[)JKJSS+"JM\6KUSH@`+/,JO$@-B"D<*[)JKJSS+"JM\6K
MUSH@`+#/MO2D5ZVMO,:EV`"DN;-<L\RD:JKXJ]<`I*VDZP!-87EO='1E("BP
MJ*SYKU.N<2D`PN6^QP"FJ*W[`+_OL^:\TJ:A.@"F6*C6P'BF<Z[F`+9LI?,`
MMFRE\\7GP]*D=Z>YIJ@LIOVL3ZC/I<ZJS*JZP[&SN:MOM4RJ:[-QN4S%Y\/2
M+@#"LK!4I'>Y3+3!+@#"LK!4JZRZ00!-971A<B"PS[;TM4RJ:ZC/I<XN`$UE
M=&%R(+#/MO2U3*IKJ,^ESBX@LM.X8+W0L-&FTJATLLZZWK)ZM6Z__2X`365T
M87)$0B"I?*6\LW.QM2X`I.BJ:P"DZ*IK("(E<R(@I;RS4:EWN'$`I.BJ:Z6\
MJ7>X<2X@I4BI2:5SI.BJ:SH@)7,`I+VH[@!-97AI8V\@*+ZEINBM]"D`36EC
M<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B`HL4NG2L.YI:>FZ*C(*0"D
MI+:A`$UI;64@JZRZ00"SS*KQ(#(T(*1PKLFJNK/,IT.WQ:O7.B``L\RJ\2`V
M(*1PKLFJNK/,L*JWQ:O7.B``L\RU=;%+O5BNQ+3!J7REO*CLM,$`K$VN9P#"
M^+:U`*?DI*.H["!014%2(*5=N,L@2%144%]297%U97-T+@"S7:EWP,F_\J6B
M+B"F<*I'K6ZHSZ7.LV^MT\"SI<ZU>Z:AIT&ELK:WLGNF8K1.LJ.ES:5,+@"G
MY*2CJ.S"LK!4JKH@240N`*?DI*.H[*6RMK>JNB!014%2(*5=N,L@36%I;"X`
MI^2DHZCLMWRTP:JZ($E$+@"L4+3!I$``IN:PRK9LI?,`M\6I30"G\[=SI.FT
MP0"MUZ?ONO2G?0"\TK+5`$UO;&1O=F$L(%)E<'5B;&EC(&]F("B\K[JXIFBE
MRRD`36]N86-O("B\KZ_'K?0I`$UO;F=O;&EA("B[6*5J*0"DZZ3.IGX`J$.D
MZP"[6+;KJ=2O4P"DZZS;`*9BLL0E9*;FI^2H[*JZQ.:F[+S&I=BD=[97I5BY
M=[3!)60N`+ROK*6M]`"F:+:SKLFTN`"F:+:SKLFSL0"TN*[)IFBVLP"D5;*^
M`*6JLKX`I6NRO@"D5[*^`*15LKX`I%>RO@!-;WIA;6)I<75E("BR]J14I/&G
M2BD`O<:_[Z:AI%6IU*5<K^"J[0"]QK_O`*?:JKJQ8KBY`*?:JKJQ8KBYN.JP
M5`"MTZ1(K[BE>`"MTZ1(K[BE>*VVK;&P=+AM`$UY86YM87(@*+UQJ&PI`*2C
M+*?:I*.F4+=.`*97NMD`3F%M:6)I82`HJ+JFS*3QJ,@I`$YA=7)U("B_U;Y\
M*0!.97!A;"`HI:>J>;JX*0!.971H97)L86YD<R`HLOS$]2D`3F5T:&5R;&%N
M9',@06YT:6QL97,@*++\Q-VF=Z9AID.TM2D`3F5T<V-A<&4@K+"P\L*FJKJZ
M]*=]`$YE='-C87!E(+[,P]*G0+QONO2G?0!.971S8V%P92"^S,/2K$:UIKKT
MIWT`3F5T<V-A<&4@I_.W<[KTIWT`3F5T<V-A<&4@IT"\;[KTIWT`3F5T<V-A
M<&4@4U-,(*;XJD&^N:97NMD`3F5T<V-A<&4@OLS#TJJZM?FXT0!.971S8V%P
M92"^S,/2JZRZ00"Z]+CTI'6HXP"Q<:6\`$YE=R!#86QE9&]N:6$@*+=SL]BH
MO:9HI:>HR"D`MW.\5Z3`P_X`O&>K2+6Y("5S`+=SI.L`MW.HSZ7.JLRF5[K9
M("BK1*6RK6XI`$YE=R!:96%L86YD("BOPZ;HQ/4I`+=SL4N]6`"W<[%+O5BQ
M3JGS)7BH[+3!+@"W<[%+O5BDH[+%IE@N`+=SM?BUH2`H7V)L86YK*0"W<[M$
M`+=SNT2X<[+5`*15I$"H0@"D5:1`K=._[[:U`*15I$"MM@!.:6-A<F%G=6$@
M**6GI5NIU*7**0!.:6=E<B`HI:>DZ2D`3FEG97)I82`HJ6"DSJ=1J,@I`+'?
MI%<`3FEU92`HK\.N2JYQ*0"G7P"U3*5IJ-'%XZ7<KG2RIZJZLUVI=[CJKL8N
M`+5,I6FESJJZM::RI*O8LWD@25-/(+QVN;,N`*A3IK.GY::XO,NFH2X`J=*K
M_*EWJKJF[+AMI%>H4Z:SL,^V]*9SIF(`J%.FL[2CJ-&FYJC&ON2F5[K9I4BH
MT2!-0T%,(,7GP](N`*A3IK/%W*?S+@"U3*IKIF*EV*MEQ7:MK:2DO%>E6Z:X
MQ7:MK2X`J%.FLZO\J7>JNB`E<R"S7:EWN.JP5"X`J%.FLZO\J7>JNB!&5%`@
M5D93(+-=J7>XZK!4+@"H4Z:SJ_RI=ZJZ(%-13"!61E.S7:EWN.JP5"X`J%.F
MLZO\J7>JNB!344PM1FEL92!61E.S7:EWN.JP5"X`M4RST;YLPDF\QBX`I;RT
MHZC1I=BJNBX`P,FNUZ6\I%>VQP"GY*2CJ.RYSZ7<+@"F[+AMN.JP5*E\I;RS
M7:EW`*E\I;RTHZC1INRX;;CJL%0N`*6\M*.HT<*RL%0N`*6\J_RI=Z97NMDN
M`*6\J_RI=[BYO5@N`*A3IK.K_*EWL4N]6*5(J-$@2%144"#%Y\/2+@"H4Z:S
MJ_RI=[%+O5BE2*C1($E-05`@Q>?#TBX`J%.FLZO\J7>Q2[U8I4BHT2!+97)B
M97)O<R#%Y\/2+@"H4Z:SJ_RI=[%+O5BE2*C1($QO9VEN(,7GP](N`*A3IK.K
M_*EWL4N]6*5(J-$@4$%34U=$(,7GP](N`*A3IK.K_*EWL4N]6*5(J-$@4TU"
M(,7GP](N`*6\O^FD2B!/<&5N4U-,(*1'I+BP]:;FP,FJNJ7^N/2N?"X@4$M#
M4R`Q,B"S5Z[FJKJE6[%+N.JNQKO=K6ZESJCLN-.U>Z:A+@"H4Z:SJ]V\9JJZ
MM?FE5:73O=`N`+K/NM"P=,-"I;RS7:EW`+5,KN:]=0"I?*6\J_RI=\3FINRD
MP+EJIG*DN"X`M4RNV+UU`+5,IKG`R:[7`+5,O,BF<Z78O_VE::C1I]:H^BX`
MI;RVQ[!EJ,^ESJK,IE>ZV:G.L4N]6"X`M4RE::7.JKH@6$U,(+CJKL:S4;;'
MIEX`JL6EU:W(`*WLJ6RS7:EWP,FDI*?DI*.H[*JII;NXZK!4+B"MJ[=SLJ.E
MS;-=J7?`R2X`IF*G0:JZLUVI=\#)I*2GY*2CJ.RJJ:6[N.JP5"X@K:NW<[*C
MI<VS7:EWP,DN`+5,`+5,("AU<V4@:6UP;&EC:70I`*3IIM6PTJ3E("A)4T\M
M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0@*+_5NM:G2JYQ*0"E7Z5BLGD`3F]R
M=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A>2`HKK^KPBD`JT2DIZOA`*M$
MI*>K90"DHZQ/I$"MTZ78O_T`M7NFH:E\I;RGN::H+@"DH[-=J7<`I;RS4:3D
MM*D`L\:GT;_]`*A3IK.E:<)SQ/VJNBRF7J5H+@"D4:1`I.L`O,:F<@"F<J2X
MO,8`IG*DN+QEJ]<`IN:\Q@"G\[=SL'2X;;ASLM6NR:6\J_RI=[S&I=@N`$]+
M`*JKI?,`JJNE\ZO8I=^JS`"D2[9IINP`I%&DZP"_[*2]J\<`MW.Q2[U8I;*V
MM[M0PL*Q2[U8I*.F4"X`PL*Q2[U8`,+"L4N]6*2CI;^]5`!/;6%N("BJ_+#2
M*0"E=::S($E-05`@IOBJ0;ZYI.2TJ:M(I?.G6*3`J,FE7*_@+@"E=:2YLURD
M0*W3MFRE\Z;MIWTN`*5UIK.^UJ:SJLR[4*ATLLZZWK)ZK?NE::5(Q=RG\Z9`
MJ,G%=JVM`*9BMW.JNK7XM:&V?;'2`$]P96Y34TP@O_F[?CH@M4RJ:[%Q(%,O
M34E-12##L;.YJOZE\[C1MGVXZJ[&+@"F8K=SJKJU^+6AMGVQTK-SM;(`IT"W
M?JATLLX`O^^VM0`E<[_OMK4`MK6EV+USN+D`LM7"M`"RU<*TL^:F[`"RU<*T
M`*WLJ6S`LZ7.M7NFH;S+JD\`IF(@)7,Z(*2DJKJM[*ELO,NJ3RX`J.2E3`"H
MY*5,N.JP5`"^UJ:SJLS%=JVM`%!!32#%Y\/2M4RNQ"X`4$5!4CHZMFRE\Z;X
MJD&ZW0!01U`@O,:F[,.QL[D`4$=0(*5;L4NXZJ[&`%!'4""DO;9]JO?&7P!0
M1U`@I'?#L;.Y+Z1WI5NQ2R"XZJ[&`%!(4""U>Z:AO5@`4$A0(*_SO5H`I,BK
MX:1PJT(`I,BKX;!]JT(`I,BKX::SL[<`I,BKX;!]L[<`I,BKX;2X`*3(J^&Y
M<*M"`%!/4TE8(&5X=&5N<VEO;B"_\J6B`%!(4""O\[U:7T@`N=2E4@!086MI
M<W1A;B`HI-JP\K2UJ5HI`%!A;&%U("BIK:];*0!086QE<W1I;FEA;B!497)R
M:71O<GDL($]C8W5P:65D("BDVK#'M+6I6J;[N^*PSRD`4&%N86UA("BDVJZS
ML*@I`%!A<'5A($YE=R!'=6EN96$@**3:I:RHR+=SM%BDNJC(*0!087)A9W5A
M>2`HI-JIU*9C*0"F:+:S`+%+O5@`L4N]6,7<I_.GN::H+@"Q2[U8I*.EO[U4
M`*A3IK.K_*EWL4N]6*5(J-$@4D%$2553(,7GP](N`+%+O5B]5+M[`+%+O5@Z
M`+%+O5@Z(`"Q2[U8I;*VMZ=KIE@N`+9+I%<`MDND5P"X]*Y\`*O=O&:U;K_]
MH4<`IJBM^P"FRJ3`I/$`L/6FYKK[Q4"^WJ=``+5NI$JKX;#UIN:Z^\5`OMZG
M0#\`Q7:MK0`B)7,BJKK%=JVMI;RS4:=2L*,N`*9SJ/J^1*G:`,5VK:T`Q7:M
MK;K>LGH`I]JJN@!097)U("BOM;Y\*0##9*JK`%!H:6QI<'!I;F5S("BUX:O?
MNZLI`+EQN-P`P\"T60!0:71C86ER;@"YLZ_``+W0MFFD2L!XIG.NYL))O^\`
MO="]5*EWK6ZROK"CIKFDN*7S.@"]T+U4J7>G0:UNI*3"7Z:YI+BE\ZJZLW.U
MLBX`O="_Z:1*I$"MTZ3KI?>DSJ9^I?<N`+W0O^FD2K=SO%>DP,/^JKJF5[K9
M.@"]T+_II$JD0*W3IK.NQ*JZ($E0(*;LIWT`O="_Z:1*I$"MTZ:SKL2JNJ3I
MM,$[I,2_[Z:YI.NE]ZJZI.FTP2X`O="_Z:1*I$"MTZ:SKL2JNJ[)MJ$N`+W0
MM*.HT;#=PT2JNKI+K6XN`+W0O^FD2J=!JKJHSZ7.JLRF5[K9I,ZQ2[U8`+W0
MOES%JJ15ID.DNJYE+J=!I;*VMZ90MTZS;ZC'J,:VM:1^K^"HSZ7.J'2RSBX`
MO="_Z:1*MW.JNJ3`P_ZF5[K9.@!0;VQA;F0@**IIQ/4I`*Q&JG8`I^NRO`!0
M;W)T=6=A;"`HN+*UY:3Z*0"\=KFSINRX;0"J[:[FINRX;0"[O+!EMFRE\ZCL
MLV^MTZM(I?.G6"`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`+/,JO$@)7,@I'"N
MR:JZK;"K0K9Q.B``K;"K0CQB<B`O/K[WLG8`4')E9G-?;&1A<#H@I^2DHZCL
MJ=*[W:UNJKH@3$1!4""IM:;YKDVE\RX`4')E9G-?<V5S<VEO;CH@I^2DHZCL
MJ=*[W:UNJKH@<V5S<VEO;B"IM:;YKDVE\RX`KO#`HP"N_*6MK;&N\,"C.B``
MKO#`HSH@`+EWQ/T`IF*W<ZJZM?BUH;EWQ/V\=KFS`*17I$"MT[_OMK4`ID.F
M3*3EI?,`J'"Q2ZKWQE\`L-W#1`"PW<-$M'FM>@"Q3:[7`+2CI=RDNJYE`*2]
MMGVJ]\9?`*2]MGVJ]\9?NG2ZX@"DO;9]JO?&7[CJL%0`I+VV?2^H<+%+JO?&
M7[GOJ,.EO+-1LJ.ES2X`4'5E<G1O(%)I8V\@**IIIFB^I*95*0!1871A<B`H
MI62Y1BD`K&2XWP"ZS[K0L'2X;0!24T$@I+VV?:KWQE\@*"5D(*;LI+@I`+_O
MOMRV<P"K0@"FK::SJT(`L=^FLZM"`+!]JT(`JT*FL[.W`*M"PN"SMP#`2+[W
MI'"[>0"D\;)V`,6JJ/H`Q:JH^K9LI?,`KW6JNJUNIU*PHR`E<R"VW#\@LV^V
MM;[>IT"Q3K5,JFNK[+1?+@"O=:JZK6ZR3;"CJ,^ESJK,("5S(*JZN.JNQK;<
M(#\@LV^VM;[>IT"Q3K5,JFNK[+1?+@"H^J[XM%^M[`"MJ[=SON.R>@"MJ[=S
MON.R>K#*ND&EV+_]I+BE\SH`K:NW<[[CLGJMTZ1(K[BE>*2ZKF4Z`+%@LU>J
M[:7<IJ$`P_;!<,)SQ/V^N0"MJ\6J`+7[O=<`N[>ZW:;XJD&^N0"[M[K=NO2G
M?2`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`+*^L*,`LKZPH[#/
MMO0`LKZPH\3FINP`I6BPHZ[FIJ$`LKZPH[GO`*;;IOBJ0;ZYO,BF<Z78O_VD
MI+*^L*.D=\!XIG.JNK-=J7>U>Z:A+@"ROK"C`*;;I.6E\Z2DLKZPHZ:YI$"X
M8,))`+*^L*.HSZ7.JLP`LKZPHZC/I<ZJS#H@)7,`N]VH1*6\LU&F7L"S.B"_
M^;M^N+F]6#H`I^2DHZCLJ=*[W:JZJD&PR"X`)3(D<R"JNK-=J7>ELK:WJ_RI
M=R`B)3$D<R(`5D93(*JZLUVI=Z6RMK>K_*EW("(E<R(`LUVI=[CJKL:ELK:W
MJ_RI=R`B)7,B`*6RMK?$YJ;L`*VKLUT`K:NS7;%+O5@`K:NS7:=!JKJQ2[U8
M.@"F7J9SL\RKX:1`K=.L9+C?`+6RJD<`JO"F7K_OMK4`ID&FN+_II$JW<[%+
MO5@`4F5U;FEO;B`HKV2EIZGTKG$I`*9>M%^S7:EW`+KTK;:]<[_HOKF_[[:U
M`,&\NWD`I6O#Y`"E:\/DJNW`60"E:\/DK<@`ID.DNJYE7W<N+BX`J*2FX@!2
M;VUA;FEA("C#N;"HI:>HR"D`L=O"X"`Q.#`@J]<`L&:NR;!W(#DP(*O7L=O"
MX`"VMJ[)L'<@.3`@J]>QV\+@`*9#I+JN90"F0Z2ZKF4`ID,`KN:]=0#$YJ;L
MNU"F0Z[FO74`Q.:F[*[FO74`ID.NYKUU`+#UIN8`4G5S<VEA;B!&961E<F%T
M:6]N("BK6,.YM+4I`%)W86YD82`HOV.F=[E&*0!3+TU)344@I5NQ2\.QL[D`
MMFRE\Z1WJ,^ESB!3+TU)344@I5NQ2P!305-,(,7GP]*U3*[$+@#"LK!4`+CJ
MKL:N=Z_SO5H`I5NQ2[+7NMV^]P"FJ*5<`+CJKL:N=Z_SO5I?40"L4+3!I+L`
M4V%I;G0@2&5L96YA("BX=+NNL,>OQRD`4V%I;G0@2VET=',@86YD($YE=FES
M("BX=*=*J+VTM:9HNM:DSJ6GNONTM2D`4V%I;G0@3'5C:6$@*+ATQ5.FZ*C(
M*0!386EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD
M('1H92!'<F5N861I;F5S("BX=*3EM,NDSJ[FM^>HNJ1"*0"F4*1`K=.U^+6A
M("A?<V5L9BD`4V%M;V$@*,+$O*^HR+ASKG$I`%-A;B!-87)I;F\@*+ATL*BG
M4;_5*0!386\@5&]M92!A;F0@4')I;F-I<&4@*+ATIFBL_*3.M+:J3*;HI/$I
M`+W#K%"THZC1JLP`4V%U9&D@07)A8FEA("BH1J]1IF&J_*G4IT(I`,!XIG,`
MP'BF<R`B)7,B`,!XIG,@)7,`P'BF<[_OMK4`L4ZRHZ7-JKJS7:EWP,FE2"!0
M2%`@NWFHI:[FIJ'`>*9SJ.RG0:JZIOBJ0;ZYO,BF<Z78O_VDI"X`LUVI=R`E
M<R"D=\!XIG,N`*?SMW.U>Z:AI'?`>*9SJ.PZ("(E<R(N`+ESK%"Y<*M"`*SL
MOL<`MVJT30"W:K1-I-[`N@"_[[[<P,FNUP"_[[[<I$"MTZ3IM,$`O^^^W*1`
MK=.X<[+5I<ZE2+=SO%<`O^^^W*1`INRW<ZJZOM:FLZK,`+_OOMRD0+.AIOBJ
M0;ZY`+_OOMRD0*;LJ,^ESJK,I<ZE2+=SO%<`O^^^W*G2IK,`O^^^W*G2IK.D
MZ;3!I+BE\RX`O^^^W*1`K=.JJZ7S`*2CO^^^W`"I\Z5(I%6JNK7XM:&DI+_O
MJ/JG0:UNJKJF<J2X+J5(M\:YJ[W&NW.ITK_OI.6F<BRU3:OAMDND5Z3EI?.]
M<[_HL,\N`+_OOMRDZ;3!I,"Y:CH`O^^^W*3IM,&DZ;3!KN:FH3H`O^^^W+']
MQ=RG\ZJZJ*VE]\/1IT\Z`+_OOMRNR;:AI,"Y:CH`O^^^W*3IM,&NR;:AKN:F
MH3H`O^^^W*S;I*RDQ[!TJKJD1ZW3Q.:F["X`O^^^W*=!JKK#0Z;BL'2X;0"_
M[[[<L+ZF;KMYJ*4Z`+;'L&6PW<-$I,_`LP"VQ[!EPK*P5`!396YE9V%L("BV
MZZ2ZI5NZN"D`MU"T^KZY.B``I$6DZP!397)B:6$@86YD($UO;G1E;F5G<F\@
M*+;KNKBZ^ZC(NU"[6*]3I:>M],.Y*0"GQ[BY`*;XJD&^N;CJKL:_^;M^J<ZJ
MS+5,JFNHSZ7.+@"W?+3!NMZR>@"W?+3!($E$(*1WN4RTP2X`MWRTP0"NUJCZ
MI.BV]`"DN;-<IT&I\Z?1L$^Q2[U8JKJNR:W4+*5II4BFVZ;FK:NS7;%+O5@N
M`+-=J7>[M[K=IOBJ0;ZYI%?$W:GSIT&JNJW3I$BON*5X+@"S7:EWIT&JNK"^
MIFZ[>:BE+""NR;#/I4BDSJ3IM,&NYJ:A+@"S7:EWIT&JNK'2J6S`LZ7.M7NF
MH2S#0Z;BL'2X;2RMMJVQI_.W<\!7LG8LI,ZHY*5,Q>.EW+_OMK4N`+-=J7<`
MI_.W<[5[IJ&T3KK\`*:SIFZT6*W3IF'"2:E-LV^MT[#1O,:FL\/V.B``4V5Y
M8VAE;&QE<R`HMNNI];JX*0#!RJJK`,*RM76Z2ZUN`*Q/IU^LL*1JLZ&E]ZJZ
MLW.ULJEWN'&GUK&VI5ROX,'D/P#%XZ7<`,7CI=RW<[*CI<V[4*WLP'BF<[-=
MJ7?`R:JZKG2RIRX`J$.FN+5NI$JKX<7CI=RD5Z1`IKBJNK5NI$JNR;:A(#\`
MQ>.EW,))O^^^N0#%XZ7<JNVNYK[>IT"E7*_@JNT@/P"I\Z6JP^3%XZ7<("5S
M(*5<K^"J[3\`Q>.EW,!XIG.NYJ2ZKF6Y[[C<I.BV]`#%XZ7<JNVNYJ2ZKF6Y
M[[C<I.BV]`#%XZ7<ID.DNJYEN>^XW*3HMO0`Q>.EW+QVN;.DNJYEN>^XW*3H
MMO0`Q>.EW*17ML<`J_G$\K!]JT(`IJVFL[!]JT(`L=^FL[!]JT(`N[>DZ*:S
ML'VK0@"FK,%9`%-I97)R82!,96]N92`HM^"D;*1SL.HI`+7YI54`P[&SN0##
ML;.YNG2ZX@!3:6YG87!O<F4@*+=SI5NI62D`I&JD<`"RI+E,NOO%0`!3;&]V
M86MI82`HM+6LI:7OITHI`%-L;W9E;FEA("BTM:REI>^EIZC(*0"SMP"P?;.W
M`+!]L[<`IJVFL[!]L[<`L=^FL[!]L[<`OVZSM[)@J]<Z(`!3;VQO;6]N($ES
M;&%N9',@**_!P[FJ^;ASKG$I`%-O;6%L:6$@**_!L*BG4:C(*0"Z<;M0N-8`
ML<:F0Z3HIE:_[[[<`*C3M[VF8:=]`%-O=71H($%F<FEC82`HJVZK1"D`JVZ\
MVB`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A
M;F1W:6-H($ES;&%N9',`JVZE8K)Y`*K%I=6FY@"VH;9:`+:AMEJ[4+G4I5(`
M4W!A:6X@**;HKUJD^BD`J56GH[9LI?,`KU.N[:9RI+B_Z:1*`*3`L\[`>*9S
M`*3`L\[$YJ;L`*3`L\ZF0P"Y0K#*`%-R:2!,86YK82`HM+6HO<3UI60I`+S0
MM\<`K%"[VJJGQ5&^U`"QTJELIGZE]P"LV0"JK+I!`,!XIG.NYJ:A`+7SN40`
MIU*PH[UU`*9RINJF0P"FV[9LI?.F8:=]I*2E:+"CNO2P[*97NMD`O,NFH2!;
M0U-370"L4+3!I-$`I^2DHZCLIKBEV+_]("(E<R(`I42FK@"P9:58`+Q7I5L@
M(B5S(B"H[*ATLLZJNJ73O="D=[!EI5@N(*=!I;*VM[6EJ.RXTZ73O="S4:[6
MK>.KX:1^K^"U;J1*+@"D5;S0`*:HI5P`IJBE7*JZI5ND2B`B)7,B(*CLJ'2R
MSJ2D+@"FJ*5<JKJFVZATLLZDI+)-L*.HSZ7.JLP@(B5S(B"JNKCJKL8N`"(E
M<R*D=Z=2L*.GN::H+@"FJ*5<JKJFVZATLLZDI+*^L*,@(B5S(BX`I'>FJ*5<
MJKJF7K1?LUVI=RX@O="MJ[=SN/RD2L#+M?BN=+*G+@"D=Z:HI5RJNK/&I?>S
M7:EWN.JNQBX`I'>FJ*5<JKJSQJ7WLUVI=[CJKL8@)7,N`*:HI5RJNJ?SMW,@
M(B5S(@"D=Z:HI5RJNL+0O&<@)7,`4W5D86X@*,2LI*8I`+I+K6X`I.FE6`"D
MZ;BH`+2X`*3II5@`I.FE6"^DZ;BH`*3II5@Z(`"DZ;BH`*3IN*@Z(`"D5[S0
M`*3DM*D`4W5R:6YA;64@*,2LIU&K;BD`NN^XN0!3=F%L8F%R9"!A;F0@2F%N
M($UA>65N`%-W87II;&%N9"`HI7:ER\#9Q/4I`%-W961E;B`HM^>HY2D`4W=I
M='IE<FQA;F0@*+?GI&@I`*90J$*P3[_]I'>G4K"C`*90J$*FYK#*N,NX;0"W
M:K1-MK6EV*2DJKJ[>:IKO_F[?@!3>7)I86X@07)A8B!297!U8FQI8R`HL=2G
M4:C(*0"Y<*M"`+EPJT*FLZVW`+EPJT(`IJVFLZOYQ/*Y<*M"`%1!0B"DP+EJ
MKN:FH<#)KM<`JNVSY@"J[:[FI+JN90"J[:[FI+JN90"E>,97`*5XQE<`5&%J
M:6MI<W1A;B`HMO"F3K2UJ5HI`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@
M;V8@**E:J7REIZC(*0"EV+S0.@"KW;_LJ,:VM0"Y<;C<N+F]6`"SS*KQI$"D
M<*[)JKJWQ:O7.B``M\6KUP"WQ:O7.B``M\6KUSQB<B`O/B@E<["J)7,O)7.G
M0R5S*2`F9&5G.R5S`*?DI*.H[+S+JD\@(B5S(BX`O,NJ3[K>LGH`I+JN90"O
MPJ3EIG(`N>^[]*3EIG(`N>^[]*3EIG*SN[K=`*Q0M,&E?`"N]:3E("A425,M
M-C(P*0!4:&%I;&%N9"`HKO6PZBD`1E10(*FUIODH97AT96YS:6]N*;5,KL0N
M`$AO<F1E+TMO;&%B(+[CIEBD=;5[J,.EO*3DM*D@(B5S(@!)35-0(*SVO_VU
M3*IKLU&J[*EL+@!-86EN=&5N86YC92##_J=/J,.EO*:HI5RX_*1*`+_OMK6U
M^+6AI4C#]K.L+L+WMGVDI"X`IT&JNJATLLZZWK)ZK?NELK:WI?VS7:EWIFZD
M0*W3Q7:MK:OANMVD?J_@Q?VG0:C/I<[%=JVMJ'2RSBX`J;.NV+UU`,%PM;BX
MN;U8I;RK_*EW+*K%I=6ISJ9BN.JNQJYWI*2GY*2CJ.PN`*1WIJBE7*JZL4[!
M<+6XI$BW<[Q7IMRS<;!4O_VDI"X`Q>?#TK9LI?/#L;.YN]VM;J:SI$"MTZ1W
MN-&V?:JZ(%!'4""PS[;T+@"P=+AMN'.RU:JZP]&G3[BYO5@H240II*.L3Z6\
MJ_RI=RRT3JQ/JL6EU:G.JLRDHZ9BN.JNQJYWI*0N`+!TN&VX<[+5I;RK_*EW
M+@"[W:UNI$"MT[AGN4RE6[%+JKJZ]+CTLW.ULBX`P,FNUR`E<R#`L[C3I5VG
M=*1`K=,@)7,@LUVI=RX`P,FNUR`E<R#`L[C3I5VG=*1`J,<@)7,@LUVI=RX`
MM4RJ:[W&NW.H[*;;J*W`R:[7+@"FN<#)KM>DI*A3IK.XZJ[&+@"E2*15K$\@
M<F9C.#(R(+9LI?.JNJKMP%DN`*BMI??#T:=/("5S(*1WLU&G4K"C+@"EJJ[8
MO74`1VYU4$<@I$>DN,#)JKJX]*Y\I;*VMZEWN'&F8B!#<GEP=%]P9W`Z.B##
M_J=/I*0N`*=!M+^I\R`E<R"Q2+6Y("5S(*1`J\JE1*:NK+`@(B5S(B"JNJM(
MI?.D=[-1MGVQTBX*IOVS;ZC#I*.OX*M/P]*XTZM(I?.JNJ2ZKF6D=Z>YI?ZS
M4::LI?.D2*S=I[FISJ1&N-$N`+-SM;*H[+USO&>V;*7SK;:ML:G2J,^ESJJZ
MIE>ZV0"ELK:WK$^D0*W3O,:F<BX`2&]R9&5?0W)Y<'1?<VUI;64Z.B##_J=/
M+*6RN]VM;J:S(&]P96YS<VP@O-*RU2X`IKFPOJ9N("(E<R(@N.JNQJ9=K+"V
M5[E,L\RD:J2YLURMR"RITJ5(M4RJ:[-1P'BF<P"ESJ5(P,NU^*:YN.JNQL/^
MJZP@*"5S*2"JNK5[IJ&HPZ2CIG.F8JGSJ'2RSJ17+@"DWJUZIG*ELK:WK+"S
MYJ1`IG*DN"X`I:JE:Z[8O74`I6NNV+UU`,3FINRDP+EJIG*ELK:WK+"SYJ1`
MIG*DN"X`IKFF^*I!OKD@(B5S(B"D=[-1IU*PHRX`IKFF^*I!OKD@(B5S(B"D
M=[-1P'BF<RX`)7,@JKJU^:55N]VH1*1WLU&ROK"C+@"K_*EWJKJP3[_]J,.D
MHZ9SIF(N`+S(IG/`R:[7(B5S(J2CIG.F8BX`IT&ITK_II$JJNKCJKL:[4+5E
MK;&XZJ[&I*.RQ2X`I%>D5:[8O74`I%>NV+UU`+%QI%>D0*W3J$+&2J2GJ^&D
M5[;'JKJXZJ[&O_*EHBX`I%>VQ\#)KM>HPZ6\LU'`>*9S+@!W96%T:&5R+F-O
M;2"PS[;TM4RJ:ZC/I<XN`*?DI*.H[+S+IJ&P=+AMI=B__2`B)7,B+@"U3*5I
MI<ZJNK_OMK4N`+5,JOZE\Z5IJKVQM;9]L=(N`*:YQ.:F[*2DI5VG=*33IFBJ
MNJ9RO,8NIT&D=[_II$H@)7,@K=.F<KS&.Z=!O^FD2JJZIG*\QJ6RMK>D<*GS
M("5S+@"W<[Q7("(E<R(@J.RH=++..B`E<R"NR;5OI<VD0*W3L-W#1"X`IMNH
M=++.LDVPHR`B)7,B(*JZN.JNQJ[)M6^ES:1`K=.PW<-$.@"FVZATLLZROK"C
M("(E<R(@KLFU;Z7-I$"MT[#=PT0Z`*?SMW,@(B5S(CH@)7,@KLFU;Z7-I$"M
MT[#=PT0`I%>VQ\#)KM>NR;5OI<VD0*W3L-W#1#H@)7,@I;RS4:17ML<N`*17
MML?`R:[7KLFU;Z7-I$"MT[#=PT0Z("5S(*1JI'"V5[E,I+FS7+/,I&JMR"`H
M)60@8GET97,I+@"D5[;'P,FNUZ[)M6^ES:1`K=.PW<-$.B"VR+.AI,"JNB`E
M<R#`R:[7LU&D5[;'+@#`R[7XMFRE\Z[)M6^ES:1`K=._^;M^+@"VUZ1*IKFS
M<;!4O_VXZJ[&KLFU;Z7-O_F[?BX`MM>D2B!I0V%L96YD87(@N.JNQJ[)M6^E
MS:1`K=._^;M^+@"F8K-=J7>J[;/FI*2U;Z7-I$:D0*W3O_F[?BZFLZ5IK^"G
M0;_RNGRD1J6RMK>V\;QGJKK$YJ;L+@"P]:;FLW&P5+_]J_RI=Z5<K^"NR;5O
MI<VD0*W3O_F[?BX@O="U>:OAID&XU:1`IK@N`*?SMW/!<+6XI$BXZJ[&KLFU
M;Z7-I$:D0*W3O_F[?BX@O="U>:OAID&XU2X`I_.W<[!TN&VX<[+5KLFU;Z7-
MI$:D0*W3O_F[?BX@O="U>:OAID&XU2X`IKD@24U!4""F^*I!OKFHPZ6\I.2T
MJ:M(I?.G6*3`J,FE7*_@+@"S;Z;\I4>DHZQ/I;^]5*JZ(')A<B#`H\%9P,FN
MURX`LV^F_*5'I*.L3Z6_O52JNB!Z:7`@P*/!6<#)KM<N`+-OIORE1Z2CK$^E
MO[U4JKJK2*7.I62XN;U8+@"FN<3FINRL3Z6RN]VM;JJZ+@"FN<3FINRDNJYE
MI76DN;-<ON.\QKS&IG(N`*:YQ.:F[*2ZKF6E=:2YLUR\QJ9RI,ZK7[BY+@"F
MN<3FINRDNJYEI76DN;-<I$NV::;LO,:MR"X`IKG$YJ;LI+JN9:6RMK>LL+-R
MN+FISJK%I=6DP+EJJKJ\QJ9R`*6RMK>L3Z1`K=.\QJ9R+@"FN<3FINRDNJYE
MI;*VMZ5=IW2D0++5I%&DN[9IINRJNB!21T(@PT.FXJ5.O5@LJ-*F<"`G(S$R
M,S1A9B<N`+-OK=.J[;/FI'>S4;-"LGJY3"X`LV^L3R`E<RX`LV^L3R!+;VQA
M8B"X<[+5JKJD0*W3JJNE\RX@L?W`R[7XIKFJJZ7SN]VM;J_@I.2TJ4MO;&%B
M(+ASLM6NYJ:AJKJY<:1LMFRE\[-NQ>DNO="PT:;2("5S(*5(I$:XT;-OJ,>V
M;*7SLV[%Z0"S;ZO*MFRE\ZC#JT2E2*=!ND2ESJJZIG*DN+:PIM.L3ZC/I<X@
M*"5S*2"NT;QGIM.FJ"X`IKF\QJW(L\RDUJ6RMK>L3R`Q+@"FN:;XJD&^N;5,
MJFNY[R!Z:7`@I,X@9WII<""NYJ:AP,FNU[9IIN:XT<"CP5D`IKFH=++.I=BK
M9:Q/L+&ESJJZJJRZ02X`I;*VMZQ/I$"MT[S&IG(N`*:YM?BUH:6RMK>M;J71
MO^^VM;7XM:$H3W!T:6]N*:G2J4FE<P"Y<`"PW<-$L&S"W`"NR;:A`*[)MJ&K
M_*MN`*[)MJ&NYJ:A`*[)L,^_[[[<`%1I;6]R+4QE<W1E`+S0PT0`O-##1"`H
M=&]O;'1I<"DZ`*:LI?.D2`"F<*I'K6Z]QK_O++W0IF+"2;_OM\:YJZJZIE"N
MR:OV($-O;G1R;VS!Y"BMTZ1(N7&XHRD@J<X@0V]M;6%N9,'D*,2KJD>Y<;BC
M*2X`I+6DT0!(5$U,(*WLJ6S`R0!4;V=O("BF:*WT*0!4;VME;&%U`*GZI-$`
M5&]N9V$@**I&I5LI`+.[LZ$`L\RD5[QHKMBL6R`H7W1O<"D`I&2HO;E&I,ZF
MJZBIK?0`KW6ISK"P`*Q0M,&D1P!4=6YI<VEA("BL\*6GINBHR"D`5'5R:V5Y
M("BD9Z;5J.0I`*1GIM6HY*3E("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`
M5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=2`HI&>ER[Y\*0"_Z:1*
MIT&JNK_OOMPZ(`"UM:5^O76K_+S&.B``NO2G?0"Z]*=].@!59V%N9&$@**]1
MI'JY1BD`56MR86EN92`HKU&G2L3U*0"U3*IKIG.H^B!61E,@I=B__2X`M?FE
M5:[)M4RJ:[Q7I5O#0J5^JKJHSZ7.JLRXZK!4+@"U3*IKI^_%W"!61E,@P,FN
MUR`B)7,B(*JZQ7:MK2X`M4RJ:\7<I_,@5D93(,#)KM<@)7,O)7,@JKK%=JVM
M+@"U3*IKQ=RG\ZRP("5S+@"U3*IKP,NL9,#)KM>D:J1P("(E<R(N`+5,JFO`
MRZQDP,FNUZ1JI'`@(B5S+R5S(BX`M4RJ:[-SM;(@4U%,(*;XJD&^N2X`M4RJ
M:ZC/I<X@4U-,(+-SM;(N`+5,JFN]QKMS(%9&4R#`R:[7+@"U3*IKJ]BEWR!6
M1E,@I=B__2`B)7,B+@"U3*IKJ]BEWR!61E,@I=B__2X`M4RJ:ZO8I=\@5D93
M(,#)KM<N`+5,JFNKV*7?(%9&4R"EV+_]("(E<R(N`+5,JFNKV*7?JL6EU:JZ
M(%9&4R#`R:[7+@"U3*IKL4ZXZJ[&N-'`H\%9+@"U3*IKIU*PHR`B)7,B+*:Y
MI=B__:C#JT2JQ:75+@"U3*IKIU*PHR`B)7,B.B`E<P"U3*IKIU*PHR`E<RRF
MN:78O_VHPZM$JL6EU0"U3*IKN[RP:J=2L*.EV+_]+@"U3*IKIU*PHR!61E,@
MI=B__2X`M4RJ:Z=2L*,@5D93(*78O_TZ("5S+@"U3*IKIU*PHR!61E,@P,FN
MUR`B)7,B+@"U3*IKIU*PHR!61E,@P,FNURX`M4RJ:Z=2L*,@5D93(*78O_T@
M(B5S(BX`M4RJ:[N\L&JG4K"C(%9&4SH@)7,N`+5,JFNG4,)?I=BK9:JZI=B_
M_2X`M4RJ:[C1MGV^S,/2LM.X8`"U3*IKN/RD2B5SJKJI=[AQ+@"U3*IKMVBR
MOB!61E,@P,FNURX`M4RJ:[9]L=(@5D93(,#)KM<@(B5S(BX`M4RJ:[QGI$H@
M5D93(,#)KM<N`+5,JFNV?;'2(%9&4R#`R:[7+@"U3*IKMGVQTL"CP5G`R2X`
MM4RJ:\6JJ/H@5D93(,#)KM<@*&9I;&5S:7IE*"D@9F%I;&5D*2X`M4RJ:\6J
MJ/H@5D93(,#)KM<@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2X`M4RJ:\6JJ/K`
MR:[7.B``M4RJ:\6JJ/H@=F9S<F]O=""EV+_]+@"U3*IKI_.F5R`E<R"LL"`E
M<SH@IEVLL*78O-"K2*7SIUBD=Z9SIF(`M4RJ:\7<I_,@5D93(*78O_VJNJ97
MNMDN`+5,JFNROK"C(%9&4R"EV+_].B`E<RX`M4RJ:\7<I_,@5D93(,#)KM<@
M(B5S(B"JNJ97NMDN`+5,JFO%W*?S(%9&4R#`R:[7("5S+R5S(*JZIE>ZV2X`
MM4RJ:\7<I_,@5D93(,#)KM>JNJ97NMDN`+5,JFNP]:;F("=M:VES;V9S)RX`
MM4RJ:\+@M*L@5V]R9""DY:7S`+5,JFN\9Z1*(%9&4R`B)7,B(,#)KM<N`+5,
MJFN\9Z1*(%9&4R#`R:[7("AC;W!Y*"D@9F%I;&5D*2X`M4RJ:[QGI$H@5D93
M(,#)KM>XZJ[&+@"U3*IKO&>D2B!61E,@P,FNURP@NL^ZT+!TPT*D=[JA+@"I
ML[UU`*CZKOBG\Z?O`+1?K>P`IOBJ0;ZYLW.ULJ[)M6^ES:6\N7>TP:JZIE[`
MLSH@`+5OI<VEO+EWM,&JNJ9>P+,LI=&F^*I!OKDZ(`"EO*3`P_X`N%6PZKU8
M("A55$8M."D`56YI=&5D($%R86(@16UI<F%T97,@**K\J=2G0L%PIEBD:J2]
ML.HI`%5N:71E9"!+:6YG9&]M("BM7K#J*0!5;FET960@4W1A=&5S("BL_+#J
M*0!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`L^:F[`"E
MO*J^JKH`I;RJOJJZ($%022"P5*ZGO7.XN2`H05!)($UE<W-A9V4@240I+@"E
MO*J^JKJKR*3AL%2NI[USN+D@*$%022!-97-S86=E($E$*2X`I;RJOJJZINRX
M;;CJL%0N`*6\JKZJNJC/I<ZJS*97NMFISK%+O5@N`*2DPE^EV*MEI+BE\ZJZ
MLW.UL@"EO*E2IE<`IEVF=Z7^Q56\>Z2CI+FS7*6\L<+%=JJZM7NFH;#UIN:P
MQ:15+[W&NW,OMDND5RX@PDF_[[U4J7>E2,#+M?@@;6]Z:6QL82YO<F<@J=*T
MHZC1JKJLV\/VI]ZS3J3EI?,LQ?VG0:5II4BXT;"CIKFD0*VMJ.ZHPZ;;IN:V
M?:GQM7NFH:9SJ/JPQ;9+PZ\N`*CZKOC#0Z;B`*6\I.2TJ:JZL,;`R:97`,7<
MI_,`I_.W<R`E<P"G\[=SJ,^ESJK,`"(E<R*D=Z?SMW,N`*?SMW.U>Z:AI'>G
M4K"C+@"D5[;'`*1WI%>VQZG2IK/`LZ7.M7NFH:JZLUVI=\#)J.RF^*I!OKDN
M`*1JO&>IU*1"O,:F<@"D:KQGP[FPJ+S&IG(`57)U9W5A>2`HKU&IU*9C*0"H
MSZ7.I=BK9:JZ.B`E<P"HSZ7.(%-33`"F<*I'IT&JNJC/I<ZJS*97NMDOL4N]
M6+M0($E-4U`@IOBJ0;ZYI*.F4"RE::9BIKFS7:EW+@"HSZ7.JLP`J,^ESJK,
M("5S(*6\LW&Y3"`E<R"JNK'"Q7;%Y\/2+@"HSZ7.JLRZWK)Z`*C/I<ZJS+_O
MMK4`J,^ESJK,M?FE50"FN:^XI7BJNJC/I<ZJS+7YI56H=++.I'>PL:7.+@"G
MY*2CJ.RHSZ7.JLRQ8KBY`*C/I<ZJS*97NMD`J,^ESJK,IE>ZV2`B)7,B(*1W
MIG.F8BX`J,^ESJK,IE>ZV3H`J,^ESJK,.B``J'2RSJ2DJKJHSZ7.JLPZ`%5Z
M8F5K:7-T86X@**]1K_>G3Z=**0!61E,@I=B__:C#I*.F<Z9B+@"PLK3!`*1W
MI^2H[*:SKL2JNJ9APDDZ(`"FLZ[$J<H`I4BDP,3!K+"SYJ;L*+%QLGNF8K!?
MNN(I`*W(`+_OJ/JMR*;;`%9A;G5A='4@**7+I:.J_+G/*0#%W*3&`%9E;F5Z
M=65L82`HJ66DNK?GJ=0I`,7GP]*EHK'1("T@IKFV;*7SI6FOX*1WOD2D2+[5
MIMN_>:?O+@"JJ:6[`*JII;NQL:CN`*NKJKVY[[OT`*NKJKVYU*52`*NKJKTZ
M`*M$L6"PJ@!6:65T($YA;2`HME:K;BD`ME:K;J3E("A625-#24DI`,#+M?@@
M)7,`IF*W<[7XM:&V?;'2`*5(("5S(,#+M?@`5FER9VEN($ES;&%N9',L($)R
M:71I<V@@**U>Q-VZ^ZC*N'.N<2D`5FER9VEN($ES;&%N9',L(%4N4RX@**S\
MQ-VZ^ZC*N'.N<2D`K^"HHZO7`*_@J*.KUSH@`+AQI&JG4:7QO'>MM[EQJTBD
MO:5QLWJY3"!33510`,2UIVD`Q+6G:2$A(2"Q<2`E<R"DXK#*LKZPH[5[IJ$N
M`%=)3B"X9Z71($A45%``5V%L;&ES(&%N9"!&=71U;F$`Q+6G:0"L4+3!I%0`
MI-&N\+EWM/H`KO"V2+CJKL:THZC1`'=E871H97(N8V]M(+KTK[@`NO2ON`"Z
M]*^X`*A#MF<`Q7>J[P#%=ZKOJ.P@)7,`Q7>J[RP@)7,`INB\VB`H25-/+3@X
M-3DM,2D`INB\VB`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A("BFZ+R[
MJZ*IU"D`M6ZD2JOAP+.XTZ7]Q>.EW"`E<R"M_J1`K=/`LZ7.M7NFH3\`Q.:F
M[*JZI,"Y:J9RI+@_`*3>K7JJNJMEN&VF<J2X/P!7:&5R96ES($%U<W1R86QI
M82"F8;G/`*W^K=.DZZS;`+KTK;:]<[_HOKFJNK2AI?,H<&QU9VEN<RFQTK#*
ML;&H[BX`O&6KUP"E2"!#4U,@K+"SYJ;LJKJ\9:O7`*6JP^0E<Z5<K^"J[:JZ
MO&6KURBD5::XM6ZD2JELI<VNQ"DZ`*KMKN:\9:O7`+QEJ]>SYJ;L`+QEJ]<Z
M`+:PQ>FST*=``*VW`*:MIK.MMP"MM[-T*+A@*0"MM[-T.@"MM[-T.B``M+R\
M>@"TP:O=PJ>JJP"D=:=``+_LI+VKQZ9AIWT`O^RDO:O'N7&XW`"RQ"5DIN:J
MNL3FINR\QJ78I*.EO[U4+B#`L[C3K6ZFLR5DK=/$YJ;L+*5UI^2H["5DK=/$
MYJ;L+@#$YJ;LO,:EV*2CI;^]5"X@P+.XTZUNIK,E9*W3Q.:F["RE=:?DJ.PE
M9*W3Q.:F["X`6#4P.78S(*FUIOFJ]\9?NWFJ:P!8-3`Y=C,@I42FKK3`I4ZF
M5[K9`%@U,#EV,R"E1*:NJO?&7\/1IT^JS`!8-3`Y=C,@L,;`R:97`*9^`*9^
M`%EA:&]O("$@IF&YSP"H0Z9^`%EE;65N("BXK:KY*0"L3P"L3ZJZ+*?:IE"W
M3@"G0:78JV6HSZ7.K\*DY:9RO7.\9[S2IJ$N(*C/I<X@6SP^72"K]K9SI6FD
MP;2KK+"Z]*VVO7.\9[S2IJ$N`*2CI+FS7*=!J]BEWR5DI4BD5ZJZL,^V]"X`
MIT&EO+-1L<+%=BX`IT&JNJ7^IE>DI*2CI6FFLR`G7"<@LV^\RZJZIG*DN"X@
M`*=!J,.EO+_II$JD0*W3IK.NQ*JZN7&D;+9LI?.F[*=]+@"G0:C#I;RET;;7
MI$JJNL#)KM>DI+GOK$VE]*;SQ.:F[*CL("5S`*=!I'>X9[5NI5@N`+W0O^FD
M2J1`K=.FLZ[$JKJY<;C<N+F]6"RPZKO:N7&XW+BYO5BVR*5UI+FS7+S&IG*X
MN;U8+*C#M?BQH:IPI6FI\ZMEK;&F0:5;I$"MTR`G*R<N`*=!I;*VM[_II$JD
M0*W3IK.NQ*JZK<@N`*=!I;*VMZ7]LU>YNJ9NOO"JK+CJKL8H1&%T851R964I
MIOBJ0;K=I'ZOX,1^Q/*HSZ7.MW.ESJ3AM?FE5:I!L,@N`*=!I;*VMZ7]LU>Y
MNJ1`K=.UZL#`P,FNUZATLLXH5D93*:;XJD&ZW2X`O="T>:UZL-W#1*%!IF*G
M0;;'L&6PW<-$L_BG::2GJV4N`*=!I;*VM[_II$JFN;-SM;*ITJO\IE:JNKKT
MIWT`O="K_*EWK6ZG4K"CJKJF^*I!OKDN`+W0J_RI=ZUNLDVPHZJZJ,^ESJK,
M+@"]T*O\J7>M;K*^L*.JNJC/I<ZJS"X`O="K_*EWK6ZW<[Q7JKJHSZ7.JLPN
M`+W0J_RI=ZUNI_.W<ZJZJ,^ESJK,+@"]T*O\J7>M;K#UIN:JNJ=`I<XN`*=!
MI;*VM[_II$JW<Z3`P_ZJNJ97NMDN`*=!I;*VM[2CJ-&D0*W3N'&D:J=1N=*D
MNJJZN7&XW+BYO5@`IT&JNB`E<R"W?+3!I'>Y3*[)+KW0K:NW<[5NI$HN`*=!
MJKJY<:1LMFRE\Z;MIWT`IT&JNK%(I?.D2+EQI&RV;*7SINVG?3H`IT&JNKCJ
ML%0`IMNQ<:=!JKH@)7,@MWRTP;9]J6RE2*C3IT&JNKKTN]JZ]+CTINRG?:1W
MQ=RG\RX@K+"K3\5`IT&JNJ9WI?ZP7ZBCH4&G0:6RMK>MJ[=SM6ZD2BX`IT&J
MNJ97NMD`IT&JNL7GP]*F^*I!NMVHPZ2CI.2TJ;=SO%>HSZ7.JLPN(*9PJD>G
M0:?&L>:ZWK)ZJ,^ESJK,L6*XN2RG0:6RMK>E=+_OJ.2E3*JZQ>?#TJ;XJD&Z
MW2X`IT&JNL7GP]*ZW:C#I;RDY+2IID.E6*C/I<ZJS*G.N-.E7*_@I'>S4</V
MLZPN`*;;L7&G0:JZ("5S(+=\M,&V?:ELI4BHTZ=!JKK"<\3]OKFF_*5'I'?%
MW*?S+B"LL*M/Q4"G0:JZIG>E_K!?J*.A0:=!I;*VMZVKMW.U;J1*+@"G0:JZ
MPG/$_;ZYJ,.EO*3DM*FS;ZW3I5ROX"X`IT&JNL)SQ/V^N:C#I;RDY+2IID.F
M3+_OMK4NO="K]B!#5%),+T-O;6UA;F0@*R!0(*9#IDPN`*=!I=BK9:G2LUVI
M=ZJZKLFPSSH`N]6D5;EWLUVJNJBMI??#T:=/I'?%W*?S+@"[U:15N7>S7:JZ
MJ*VE]\/1IT\Z`*=!JKJE_J97.@"G0:JZM6ZD2J1WJ.RTP2X`IT&F8B`E<R"D
MI*JZMW.Q2[U8K$\Z("5S`*=!IF*U;J1*M,&VH:JZO^^VM:1WLU&G\[=S+@"G
M0:JZO^^VM:1WI_.W<RX`IT&JNK%+O5BD=ZVKMW.S7:EW`+%+O5BD=[-1K:NW
M<[-=J7<LMW.JNK%+O5BD=[-ZN4RY<:1LMFRE\[%(M6^]T*5(N-.Q2[U8M6ZD
M2BX`IT&JNK%+O5BD=ZCLM,$N`*=!JKJ[M[K=IOBJ0;ZY.@!9=6=O<VQA=FEA
M("BK;K2UJ=2DTBD`6F%I<F4@*,+$I>PI`%IA;6)I82`HJ7RD\:C(*0!::6UB
M86)W92`HJ*^DVJO"*0!;P?3"PZ3>K7I=`%NPW<-$I,^L35T`6\7CI=RDWJUZ
M("T`6\7CI=RDWJUZ("T@)7,@IN9=`%NF[*GSIN8@)7,@ID`@)7,@IN9=`+K>
MLGI?00"I4J5/ID-?0P"^\*JLN.JNQE]$`*=2L*.F0U]$`+ASLM5?1P"[H:GZ
M7T@`O':YLZ2ZKF5?22XN+@"U;J1*7TP`M6ZE6%],`*W7I^^S<[6R7TTN+BX`
MO^^VM5]/`,5VK:U?4`"ROK"CN>^S<[6R7U(N+BX`LUVI=U]3`*KMKN:DNJYE
M7U0N+BX`J,^ESJK,7U4`LW&P5+_]`*;FJ,:^Y`"U3*IKJ]BEW[_II5C`R:[7
M`+5,JFNV?;'2O^FD2@"K]J:Y`+%+I4^F0[MYJFN_^;M^`+-=J7>_^;M^`+_R
MI:*MJZUNJKJH=++.P,FNUP"XZJ[&KN:FH;_YNWX`I^2DHZCLL$^__0#`R:[7
M`+%Q("5S("@E<RD@J?,@)7,@)7,`L'VMMP"NR3H`KLD`I;RJOJJZMFRE\Z5$
MOO>F5[K9`*7?IUD`JKVQM<7CI=RI\Z6[I.6PSP"_Z:1*+[_II5B_^;M^`*2Z
MLZ&S;L7IO_F[?@"FYET`I,``IE>ZV0"I?*6\N>JG0"X`J7REO+GJIT`N`+/&
MI]&__0"FRJ3`I/$`IG.H^KY$J=H`N;.OP`"S<:M(J/.I=[NWNMV_^;M^`*17
MI,D`M4RE::7.JKJJ0;#(`,7CI=RN=+*G`'-M<S)E;6%I;""X9Z71($A45%``
MK.T`PZVI=P"H=++.O_F[?@"KW;_LPZ\`O,BNR:G*JKJEHK'1`*9!IKB_Z:1*
MIT&JNK%+O5BE2+U4NWNU3+M^`+[CIE@`I;RI4J97`*C/I<ZJS+_OOMP`=D-A
M<F0`K%"TP3H`=V5A=&AE<BYC;VT@NO2ON```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&]G:6XN<&AP````````````````````````
M````````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-C$R-P`Q,#4Q-30S
M,S<T-``P,3<U,#8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O;&]G:6XN<&AP
M+'8@,BXQ-S4N,BXQ,2`R,#`V+S`Q+S$V(#$U.C4W.C4S(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H87)L97,@2BX@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N
M(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E
M9FEN92@G05542%](04Y$3$52)RP@=')U92D["D!D969I;F4H)TA/4D1%7T)!
M4T4G+"!D:7)N86UE*%]?1DE,15]?*2D["G)E<75I<F5?;VYC92!(3U)$15]"
M05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TUE
M;G4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]396-R970N<&AP)SL*"B\J
M($EN:71I86QI>F4@=&AE($%U=&@@8W)E9&5N=&EA;',@:V5Y+B`J+PI396-R
M970Z.G-E=$ME>2@G875T:"<I.PH*+RH@1V5T(&%N($%U=&@@;V)J96-T+B`J
M+PHD875T:"`]("9!=71H.CIS:6YG;&5T;VXH)&-O;F9;)V%U=&@G75LG9')I
M=F5R)UTI.PII9B`H:7-?82@D875T:"P@)U!%05)?17)R;W(G*2D@>PH@("`@
M2&]R9&4Z.F9A=&%L*"1A=71H+"!?7T9)3$5?7RP@7U],24Y%7U\I.PI]"@HO
M*B!'970@<&%R86UE=&5R<RX@*B\*)&QO9V]U=%]R96%S;VX@/2`D875T:"T^
M9V5T3&]G;W5T4F5A<V]N*"D["B1U<FQ?<&%R86T@/2!5=&EL.CIG971&;W)M
M1&%T82@G=7)L)RD["B1I95]V97)S:6]N(#T@571I;#HZ9V5T1F]R;41A=&$H
M)VEE7W9E<G-I;VXG*3L*"FEF("@D;&]G;W5T7W)E87-O;BD@>PH@("`@)&QO
M9VEN7W-C<F5E;B`]("1A=71H+3YG971,;V=I;E-C<F5E;B@I.PH@("`@:68@
M*%5T:6PZ.F=E=$9O<FU$871A*"=N;W-I9&5B87(G*2`F)@H@("`@("`@(&ES
M<V5T*"1'3$]"04Q36R=N;W1I9FEC871I;VXG72DI('L*("`@("`@("`D=7)L
M(#T@075T:#HZ861D3&]G;W5T4&%R86UE=&5R<R@D;&]G:6Y?<V-R965N*3L*
M("`@("`@("!I9B`H)'5R;%]P87)A;2D@>PH@("`@("`@("`@("`D=7)L(#T@
M571I;#HZ861D4&%R86UE=&5R*"1U<FPL("=U<FPG+"`D=7)L7W!A<F%M*3L*
M("`@("`@("!]"B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@G=VEN9&]W
M+G!A<F5N="YL;V-A=&EO;BYH<F5F(#T@7"<G("X@)'5R;"`N("=<)SLG+"`G
M:F%V87-C<FEP="<I.PH@("`@("`@(&5C:&\@)SQH=&UL/CQB;V1Y/B<@+B`D
M1TQ/0D%,4ULG;F]T:69I8V%T:6]N)UTM/FYO=&EF>2AA<G)A>2@G;&ES=&5N
M97)S)R`]/B!A<G)A>2@G:F%V87-C<FEP="<I*2D@+B`G/"]B;V1Y/CPO:'1M
M;#XG.PH@("`@("`@(&5X:70["B`@("!]"@H@("`@:68@*%5T:6PZ.G)E;6]V
M95!A<F%M971E<B@D;&]G:6Y?<V-R965N+"!A<G)A>2@G=7)L)RP@)VYO8V%C
M:&4G*2D@(3T*("`@("`@("!5=&EL.CIR96UO=F5087)A;65T97(H2&]R9&4Z
M.G-E;&95<FPH9F%L<V4L(&9A;'-E+"!T<G5E*2P@87)R87DH)W5R;"<L("=N
M;V-A8VAE)RDI*2!["B`@("`@("`@)'5R;"`]($%U=&@Z.F%D9$QO9V]U=%!A
M<F%M971E<G,H)&QO9VEN7W-C<F5E;BD["B`@("`@("`@:68@*"1U<FQ?<&%R
M86TI('L*("`@("`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D
M=7)L+"`G=7)L)RP@)'5R;%]P87)A;2D["B`@("`@("`@?0H@("`@("`@(&AE
M861E<B@G3&]C871I;VXZ("<@+B`D=7)L*3L*("`@("`@("!E>&ET.PH@("`@
M?0H*("`@("1L86YG=6%G92`](&ES<V5T*"1P<F5F<RD@/R`D<')E9G,M/F=E
M=%9A;'5E*"=L86YG=6%G92<I(#H@3DQ3.CIS96QE8W0H*3L*"B`@("`D96YT
M<GD@/2!S<')I;G1F*"=5<V5R("5S(%LE<UT@;&]G9V5D(&]U="!O9B!(;W)D
M92<L"B`@("`@("`@("`@("`@("`@("`@($%U=&@Z.F=E=$%U=&@H*2P@)%]3
M15)615);)U)%34]415]!1$12)UTI.PH@("`@2&]R9&4Z.FQO9TUE<W-A9V4H
M)&5N=')Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7TY/5$E#12D[
M"B`@("!!=71H.CIC;&5A<D%U=&@H*3L*("`@($!S97-S:6]N7V1E<W1R;WDH
M*3L*"B`@("`O*B!2961I<F5C="!T:&4@=7-E<B!O;B!L;V=O=70@:68@<F5D
M:7)E8W1I;VX@:7,@96YA8FQE9"X@*B\*("`@(&EF("@A96UP='DH)&-O;F9;
M)V%U=&@G75LG<F5D:7)E8W1?;VY?;&]G;W5T)UTI*2!["B`@("`@("`@)&QO
M9V]U=%]U<FP@/2`D8V]N9ELG875T:"==6R=R961I<F5C=%]O;E]L;V=O=70G
M73L*("`@("`@("!I9B`H(6ES<V5T*"1?0T]/2TE%6W-E<W-I;VY?;F%M92@I
M72DI('L*("`@("`@("`@("`@)&QO9V]U=%]U<FP@/2!5=&EL.CIA9&1087)A
M;65T97(H)&QO9V]U=%]U<FPL('-E<W-I;VY?;F%M92@I+"!S97-S:6]N7VED
M*"DI.PH@("`@("`@('T*("`@("`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@
M)&QO9V]U=%]U<FPI.PH@("`@("`@(&5X:70["B`@("!]"@H@("`@2&]R9&4Z
M.G-E='5P4V5S<VEO;DAA;F1L97(H*3L*("`@($!S97-S:6]N7W-T87)T*"D[
M"@H@("`@3DQ3.CIS971,86YG*"1L86YG=6%G92D["@H@("`@+RH@2&]O:R!T
M;R!P<F5S96QE8W0@=&AE(&-O<G)E8W0@;&%N9W5A9V4@:6X@=&AE('=I9&=E
M="X@*B\*("`@("1?1T546R=N97=?;&%N9R==(#T@)&QA;F=U86=E.PI]"@II
M9B`H:7-S970H)%]03U-46R=H;W)D95]U<V5R)UTI("8F(&ES<V5T*"1?4$]3
M5%LG:&]R9&5?<&%S<R==*2D@>PH@("`@+RH@1&5S=')O>2!A;GD@97AI<W1I
M;F<@<V5S<VEO;B!O;B!L;V=I;B!A;F0@;6%K92!S=7)E('1O('5S92!A"B`@
M("`@*B!N97<@<V5S<VEO;B!)1"P@=&\@879O:60@<V5S<VEO;B!F:7AA=&EO
M;B!I<W-U97,N("HO"B`@("!(;W)D93HZ9V5T0VQE86Y397-S:6]N*"D["B`@
M("!I9B`H)&%U=&@M/F%U=&AE;G1I8V%T92A5=&EL.CIG9710;W-T*"=H;W)D
M95]U<V5R)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G
M<&%S<W=O<F0G(#T^(%5T:6PZ.F=E=%!O<W0H)VAO<F1E7W!A<W,G*2DI*2![
M"B`@("`@("`@)&5N=')Y(#T@<W!R:6YT9B@G3&]G:6X@<W5C8V5S<R!F;W(@
M)7,@6R5S72!T;R!(;W)D92<L"B`@("`@("`@("`@("`@("`@("`@("`@("!!
M=71H.CIG971!=71H*"DL("1?4T525D526R=214U/5$5?041$4B==*3L*("`@
M("`@("!(;W)D93HZ;&]G365S<V%G92@D96YT<GDL(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@4$5!4E],3T=?3D]424-%*3L*"B`@("`@("`@:68@*"1I95]V97)S
M:6]N*2!["B`@("`@("`@("`@("1B<F]W<V5R+3YS971)159E<G-I;VXH)&EE
M7W9E<G-I;VXI.PH@("`@("`@('T*"B`@("`@("`@:68@*"1U<FQ?<&%R86TI
M('L*("`@("`@("`@("`@)'5R;"`]($AO<F1E.CIU<FPH571I;#HZ<F5M;W9E
M4&%R86UE=&5R*"1U<FQ?<&%R86TL('-E<W-I;VY?;F%M92@I*2P@=')U92D[
M"B`@("`@("`@("`@("1H;W)D95]U<FP@/2`D<F5G:7-T<GDM/F=E="@G=V5B
M<F]O="<L("=H;W)D92<I("X@)R]I;F1E>"YP:'`G.PH@("`@("`@("`@("`D
M:&]R9&5?=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1H;W)D95]U<FPL("=U
M<FPG+"`D=7)L*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:&]R
M9&5?=7)L(#T@2&]R9&4Z.G5R;"@D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L
M("=H;W)D92<I("X@)R]I;F1E>"YP:'`G*3L*("`@("`@("!]"@H@("`@("`@
M("1U<FP@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH)&AO<F1E7W5R;"P@=')U
M92D["B`@("`@("`@:68@*"1B<F]W<V5R+3YI<T)R;W=S97(H)VUS:64G*2`F
M)@H@("`@("`@("`@("`D8V]N9ELG=7-E7W-S;"==(#T](#,@)B8*("`@("`@
M("`@("`@<W1R;&5N*"1U<FPI(#P@,38P*2!["B`@("`@("`@("`@(&AE861E
M<B@G4F5F<F5S:#H@,#L@55),/2<@+B`D=7)L*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@)'5R;"D["B`@
M("`@("`@?0H@("`@("`@(&5X:70["B`@("!](&5L<V4@>PH@("`@("`@("1E
M;G1R>2`]('-P<FEN=&8H)T9!24Q%1"!,3T=)3B!F;W(@)7,@6R5S72!T;R!(
M;W)D92<L"B`@("`@("`@("`@("`@("`@("`@("`@("!5=&EL.CIG971&;W)M
M1&%T82@G:&]R9&5?=7-E<B<I+"`D7U-%4E9%4ELG4D5-3U1%7T%$1%(G72D[
M"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)&5N=')Y+"!?7T9)3$5?7RP@
M7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@:68@*"1C;VYF6R=M
M96YU)UU;)V%L=V%Y<R==*2!["B`@("`@("`@("`@("1M86EN7W!A9V4@/2!5
M=&EL.CIA9&1087)A;65T97(H2&]R9&4Z.G-E;&95<FPH*2P@)W)E87-O;B<L
M("1A=71H+3YG971,;V=O=71296%S;VY3=')I;F<H*2D["B`@("`@("`@("`@
M(&EF("@D8G)O=W-E<BT^:&%S475I<FLH)W-C<F]L;&)A<E]I;E]W87DG*2D@
M>PH@("`@("`@("`@("`@("`@)'-C<F]L;&)A<B`]("=Y97,G.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'-C<F]L;&)A<B`]("=A
M=71O)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!R97%U:7)E($A/4D1%
M7U1%35!,051%4R`N("<O:6YD97@O9G)A;65S7VEN9&5X+FEN8R<["B`@("`@
M("`@("`@(&5X:70["B`@("`@("`@?0H@("`@?0I]"@II9B`H075T:#HZ9V5T
M075T:"@I*2!["B`@("!I9B`H)&)R;W=S97(M/FES36]B:6QE*"DI('L*("`@
M("`@("`D=7)L(#T@)W-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP)SL*("`@
M('T@96QS92!["B`@("`@("`@)'5R;"`]("=S97)V:6-E<R]P;W)T86PO:6YD
M97@N<&AP)SL*("`@('T*("`@(')E<75I<F4@2$]21$5?0D%312`N("<O)R`N
M("1U<FP["B`@("!E>&ET.PI]"@HO*B!4<GD@=')A;G-P87)E;G0@875T:&5N
M=&EC871I;VXN("HO"FEF("A!=71H.CII<T%U=&AE;G1I8V%T960H*2D@>PH@
M("`@<F5Q=6ER92!(3U)$15]"05-%("X@)R]I;F1E>"YP:'`G.PH@("`@97AI
M=#L*?0H*+RH@4F5D:7)E8W0@=&AE('5S97(@:68@86X@86QT97)N871E(&QO
M9VEN('!A9V4@:&%S(&)E96X@<W!E8VEF:65D+B`J+PII9B`H(65M<'1Y*"1C
M;VYF6R=A=71H)UU;)V%L=&5R;F%T95]L;V=I;B==*2D@>PH@("`@)'5R;"`]
M($%U=&@Z.F%D9$QO9V]U=%!A<F%M971E<G,H)&-O;F9;)V%U=&@G75LG86QT
M97)N871E7VQO9VEN)UTI.PH@("`@:68@*"%I<W-E="@D7T-/3TM)15MS97-S
M:6]N7VYA;64H*5TI*2!["B`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M
M971E<B@D=7)L+"!S97-S:6]N7VYA;64H*2P@<V5S<VEO;E]I9"@I+"!F86QS
M92D["B`@("!]"B`@("!I9B`H)'5R;%]P87)A;2D@>PH@("`@("`@("1U<FP@
M/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@)W5R;"<L("1U<FQ?<&%R86TL
M(&9A;'-E*3L*("`@('T*("`@(&AE861E<B@G3&]C871I;VXZ("<@+B`D=7)L
M*3L*("`@(&5X:70["GT*"B1L;V=I;E]S8W)E96X@/2`D875T:"T^7V=E=$QO
M9VEN4V-R965N*"D["FEF("A5=&EL.CIR96UO=F5087)A;65T97(H)&QO9VEN
M7W-C<F5E;BP@87)R87DH)W5R;"<L("=N;V-A8VAE)RDI("$]"B`@("!(;W)D
M93HZ<V5L9E5R;"AF86QS92P@9F%L<V4L('1R=64I*2!["B`@("!I9B`H)'5R
M;%]P87)A;2D@>PH@("`@("`@("1L;V=I;E]S8W)E96X@/2!5=&EL.CIA9&10
M87)A;65T97(H)&QO9VEN7W-C<F5E;BP@)W5R;"<L("1U<FQ?<&%R86TL(&9A
M;'-E*3L*("`@('T*("`@(&EF("@D:65?=F5R<VEO;BD@>PH@("`@("`@("1L
M;V=I;E]S8W)E96X@/2!5=&EL.CIA9&1087)A;65T97(H)&QO9VEN7W-C<F5E
M;BP@)VEE7W9E<G-I;VXG+"`D:65?=F5R<VEO;BP@9F%L<V4I.PH@("`@?0H@
M("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1L;V=I;E]S8W)E96XI.PH@("`@
M97AI=#L*?0H*:68@*"1B<F]W<V5R+3YI<TUO8FEL92@I*2!["B`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+TUO8FEL92YP:'`G.PH@("`@<F5Q=6ER92!(3U)$
M15]414U03$%415,@+B`G+VQO9VEN+VUO8FEL92YI;F,G.PH@("`@97AI=#L*
M?0H*+RH@0G5I;&0@=&AE(#QS96QE8W0^('=I9&=E="!C;VYT86EN:6YG('1H
M92!A=F%I;&%B;&4@;&%N9W5A9V5S+B`J+PII9B`H(21P<F5F<RT^:7-,;V-K
M960H)VQA;F=U86=E)RDI('L*("`@("1?4T534TE/3ELG:&]R9&5?;&%N9W5A
M9V4G72`]($Y,4SHZ<V5L96-T*"D["B`@("`D;&%N9W,@/2`G/'-E;&5C="!N
M86UE/2)N97=?;&%N9R(@;VYC:&%N9V4](G-E;&5C=$QA;F<H*2(^)SL*("`@
M(&9O<F5A8V@@*"1N;'-;)VQA;F=U86=E<R==(&%S("1K97D@/3X@)'9A;"D@
M>PH@("`@("`@("1S96P@/2`H)&ME>2`]/2`D7U-%4U-)3TY;)VAO<F1E7VQA
M;F=U86=E)UTI(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G.PH@("`@
M("`@("1L86YG<R`N/2`B/&]P=&EO;B!V86QU93U<(B1K97E<(B1S96P^)'9A
M;#PO;W!T:6]N/B(["B`@("!]"B`@("`D;&%N9W,@+CT@)SPO<V5L96-T/B<[
M"GT*"B1T:71L92`](%\H(DQO9R!I;B(I.PHD;F]T:69I8V%T:6]N+3YP=7-H
M*"=S971&;V-U<R@I)RP@)VIA=F%S8W)I<'0G*3L*:68@*"1L;V=O=71?<F5A
M<V]N("8F("1C;VYF6R=M96YU)UU;)V%L=V%Y<R==*2!["B`@("`D;F]T:69I
M8V%T:6]N+3YP=7-H*"=I9B`H=VEN9&]W+G!A<F5N="YF<F%M97,N:&]R9&5?
M;65N=2D@=VEN9&]W+G!A<F5N="YF<F%M97,N:&]R9&5?;65N=2YL;V-A=&EO
M;BYH<F5F(#T@7"<G("X@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`G*2`N("=<)SLG+"`G:F%V87-C<FEP="<I
M.PI]"@HD<F5A<V]N(#T@)&%U=&@M/F=E=$QO9V]U=%)E87-O;E-T<FEN9R@I
M.PH*+RH@061D('-O;64@:F%V87-C<FEP="X@*B\*2&]R9&4Z.F%D9%-C<FEP
M=$9I;&4H)V5N=&5R7VME>5]T<F%P+FIS)RP@)VAO<F1E)RP@=')U92D["@HO
M*B!$;R!W92!N965D('1O(&1O($E%('9E<G-I;VX@9&5T96-T:6]N/R`J+PII
M9B`H*"1B<F]W<V5R+3YG971"<F]W<V5R*"D@/3T@)VUS:64G*2`F)B`H)&)R
M;W=S97(M/F=E=$UA:F]R*"D@/CT@-2DI('L*("`@("1I95]C;&EE;G1C87!S
M(#T@=')U93L*?0H*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO
M;BUH96%D97(N:6YC)SL*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+VQO
M9VEN+VQO9VEN+FEN8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C
M;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+P``````````````````````````
M````````````````````````````````````````````````````````````
M`````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,S-S0S`#`Q-C8P-``@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O07)C
M:&EV92\`````````````````````````````````````````````````````
M````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`U,34T,S,W,S0`,#(P,38U`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]!<F-H:79E+U1A<BYP:'``````````````````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$V-C<W-P`Q,#4Q-30S,S<S-``P,C$T
M-30`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`-"B\J('9I;3H@<V5T('1S/30@<W<]-#H@*B\-"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@
M0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK#0HO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C
M="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P-
M"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H
M92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`T*+R\@?"!A=F%I;&%B
M;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN
M9R!U<FPZ("`@("`@("`@("!\#0HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S-?,"YT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P-"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@
M=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`T*+R\@?"!O
M8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S
M96YD(&$@;F]T92!T;R`@("`@("`@("!\#0HO+R!\(&QI8V5N<V5`<&AP+FYE
M="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@
M("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*
M+R\@?"!!=71H;W(Z(%9I;F-E;G0@0FQA=F5T(#QV:6YC96YT0'!H<&-O;F-E
M<'0N;F5T/B`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L-"B\O#0HO+R`D260Z(%1A<BYP:'`L=B`Q+C(Y
M(#(P,#4O,#,O,3<@,C$Z,#(Z,S$@=F)L879E="!%>'`@)`T*#0IR97%U:7)E
M7V]N8V4@)U!%05(N<&AP)SL-"@T*#0ID969I;F4@*"=!4D-(259%7U1!4E]!
M5%1?4T5005)!5$]2)RP@.3`P,#$I.PT*#0HO*BH-"BH@0W)E871E<R!A("AC
M;VUP<F5S<V5D*2!487(@87)C:&EV90T**@T**B!`875T:&]R("`@5FEN8V5N
M="!";&%V970@/'9I;F-E;G1`<&AP8V]N8V5P="YN970^#0HJ($!V97)S:6]N
M("`D4F5V:7-I;VXZ(#$N,CD@)`T**B!`<&%C:V%G92`@07)C:&EV90T**B\-
M"F-L87-S($%R8VAI=F5?5&%R(&5X=&5N9',@4$5!4@T*>PT*("`@("\J*@T*
M("`@("H@0'9A<B!S=')I;F<@3F%M92!O9B!T:&4@5&%R#0H@("`@*B\-"B`@
M("!V87(@)%]T87)N86UE/2<G.PT*#0H@("`@+RHJ#0H@("`@*B!`=F%R(&)O
M;VQE86X@:68@=')U92P@=&AE(%1A<B!F:6QE('=I;&P@8F4@9WII<'!E9`T*
M("`@("HO#0H@("`@=F%R("1?8V]M<')E<W,]9F%L<V4[#0H-"B`@("`O*BH-
M"B`@("`J($!V87(@<W1R:6YG(%1Y<&4@;V8@8V]M<')E<W-I;VX@.B`G;F]N
M92<L("=G>B<@;W(@)V)Z,B<-"B`@("`J+PT*("`@('9A<B`D7V-O;7!R97-S
M7W1Y<&4])VYO;F4G.PT*#0H@("`@+RHJ#0H@("`@*B!`=F%R('-T<FEN9R!%
M>'!L;V1E('-E<&%R871O<@T*("`@("HO#0H@("`@=F%R("1?<V5P87)A=&]R
M/2<@)SL-"@T*("`@("\J*@T*("`@("H@0'9A<B!F:6QE(&1E<V-R:7!T;W(-
M"B`@("`J+PT*("`@('9A<B`D7V9I;&4],#L-"@T*("`@("\J*@T*("`@("H@
M0'9A<B!S=')I;F<@3&]C86P@5&%R(&YA;64@;V8@82!R96UO=&4@5&%R("AH
M='1P.B\O(&]R(&9T<#HO+RD-"B`@("`J+PT*("`@('9A<B`D7W1E;7!?=&%R
M;F%M93TG)SL-"@T*("`@("\O('M[>R!C;VYS=')U8W1O<@T*("`@("\J*@T*
M("`@("H@07)C:&EV95]487(@0VQA<W,@8V]N<W1R=6-T;W(N(%1H:7,@9FQA
M=F]U<B!O9B!T:&4@8V]N<W1R=6-T;W(@;VYL>0T*("`@("H@9&5C;&%R92!A
M(&YE=R!!<F-H:79E7U1A<B!O8FIE8W0L(&ED96YT:69Y:6YG(&ET(&)Y('1H
M92!N86UE(&]F('1H90T*("`@("H@=&%R(&9I;&4N#0H@("`@*B!)9B!T:&4@
M8V]M<')E<W,@87)G=6UE;G0@:7,@<V5T('1H92!T87(@=VEL;"!B92!R96%D
M(&]R(&-R96%T960@87,@80T*("`@("H@9WII<"!O<B!B>C(@8V]M<')E<W-E
M9"!405(@9FEL92X-"B`@("`J#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D
M<%]T87)N86UE("!4:&4@;F%M92!O9B!T:&4@=&%R(&%R8VAI=F4@=&\@8W)E
M871E#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D<%]C;VUP<F5S<R!C86X@
M8F4@;G5L;"P@)V=Z)R!O<B`G8GHR)RX@5&AI<PT*("`@("H@("`@("`@("`@
M("`@("`@("`@<&%R86UE=&5R(&EN9&EC871E<R!I9B!G>FEP(&]R(&)Z,B!C
M;VUP<F5S<VEO;@T*("`@("H@("`@("`@("`@("`@("`@("`@:7,@<F5Q=6ER
M960N("!&;W(@8V]M<&%T:6)I;&ET>2!R96%S;VX@=&AE#0H@("`@*B`@("`@
M("`@("`@("`@("`@("!B;V]L96%N('9A;'5E("=T<G5E)R!M96%N<R`G9WHG
M+@T*("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`J+PT*("`@(&9U;F-T:6]N
M($%R8VAI=F5?5&%R*"1P7W1A<FYA;64L("1P7V-O;7!R97-S(#T@;G5L;"D-
M"B`@("![#0H@("`@("`@("1T:&ES+3Y014%2*"D[#0H@("`@("`@("1T:&ES
M+3Y?8V]M<')E<W,@/2!F86QS93L-"B`@("`@("`@)'1H:7,M/E]C;VUP<F5S
M<U]T>7!E(#T@)VYO;F4G.PT*("`@("`@("!I9B`H*"1P7V-O;7!R97-S(#T]
M/2!N=6QL*2!\?"`H)'!?8V]M<')E<W,@/3T@)R<I*2![#0H@("`@("`@("`@
M("!I9B`H0&9I;&5?97AI<W1S*"1P7W1A<FYA;64I*2![#0H@("`@("`@("`@
M("`@("`@:68@*"1F<"`]($!F;W!E;B@D<%]T87)N86UE+"`B<F(B*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`O+R!L;V]K(&9O<B!G>FEP(&UA9VEC(&-O
M;VMI90T*("`@("`@("`@("`@("`@("`@("`D9&%T82`](&9R96%D*"1F<"P@
M,BD[#0H@("`@("`@("`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H)&1A=&$@/3T@(EPS-UPR,3,B*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;7!R97-S(#T@=')U93L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]M<')E<W-?='EP
M92`]("=G>B<[#0H@("`@("`@("`@("`@("`@("`@("\O($YO('-U<F4@:70G
M<R!E;F]U9VAT(&9O<B!A(&UA9VEC(&-O9&4@+BXN+@T*("`@("`@("`@("`@
M("`@("`@("!](&5L<V5I9B`H)&1A=&$@/3T@(D):(BD@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]C;VUP<F5S<R`]('1R=64[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;7!R97-S7W1Y<&4@/2`G
M8GHR)SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@+R\@
M<')O8F%B;'D@82!R96UO=&4@9FEL92!O<B!S;VUE(&9I;&4@86-C97-S:6)L
M90T*("`@("`@("`@("`@("`@("\O('1H<F]U9V@@82!S=')E86T@:6YT97)F
M86-E#0H@("`@("`@("`@("`@("`@:68@*'-U8G-T<B@D<%]T87)N86UE+"`M
M,BD@/3T@)V=Z)RD@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-O
M;7!R97-S(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C
M;VUP<F5S<U]T>7!E(#T@)V=Z)SL-"B`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H*'-U8G-T<B@D<%]T87)N86UE+"`M,RD@/3T@)V)Z,B<I('Q\#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("AS=6)S='(H)'!?=&%R;F%M92P@+3(I
M(#T]("=B>B<I*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]M
M<')E<W,@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-O
M;7!R97-S7W1Y<&4@/2`G8GHR)SL-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I9B`H
M*"1P7V-O;7!R97-S(#T]/2!T<G5E*2!\?"`H)'!?8V]M<')E<W,@/3T@)V=Z
M)RDI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;7!R97-S(#T@=')U
M93L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;7!R97-S7W1Y<&4@/2`G
M9WHG.PT*("`@("`@("`@("`@?2!E;'-E(&EF("@D<%]C;VUP<F5S<R`]/2`G
M8GHR)RD@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]M<')E<W,@/2!T
M<G5E.PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]M<')E<W-?='EP92`]
M("=B>C(G.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("!D:64H(E5N<W5P<&]R=&5D(&-O;7!R97-S:6]N('1Y<&4@)R1P7V-O;7!R
M97-S)UQN(BX-"B`@("`@("`@("`@("`@("`@("`@(E-U<'!O<G1E9"!T>7!E
M<R!A<F4@)V=Z)R!A;F0@)V)Z,B<N7&XB*3L-"B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@)'1H:7,M/E]T87)N86UE(#T@)'!?=&%R;F%M93L-"B`@("`@("`@:68@
M*"1T:&ES+3Y?8V]M<')E<W,I('L@+R\@87-S97)T('IL:6(@;W(@8GHR(&5X
M=&5N<VEO;B!S=7!P;W)T#0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]C;VUP
M<F5S<U]T>7!E(#T]("=G>B<I#0H@("`@("`@("`@("`@("`@)&5X=&YA;64@
M/2`G>FQI8B<[#0H@("`@("`@("`@("!E;'-E(&EF("@D=&AI<RT^7V-O;7!R
M97-S7W1Y<&4@/3T@)V)Z,B<I#0H@("`@("`@("`@("`@("`@)&5X=&YA;64@
M/2`G8GHR)SL-"@T*("`@("`@("`@("`@:68@*"%E>'1E;G-I;VY?;&]A9&5D
M*"1E>'1N86UE*2D@>PT*("`@("`@("`@("`@("`@(%!%05(Z.FQO861%>'1E
M;G-I;VXH)&5X=&YA;64I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*"%E>'1E;G-I;VY?;&]A9&5D*"1E>'1N86UE*2D@>PT*("`@("`@("`@
M("`@("`@(&1I92@B5&AE(&5X=&5N<VEO;B`G)&5X=&YA;64G(&-O=6QD;B=T
M(&)E(&9O=6YD+EQN(BX-"B`@("`@("`@("`@("`@("`@("`@(E!L96%S92!M
M86ME('-U<F4@>6]U<B!V97)S:6]N(&]F(%!(4"!W87,@8G5I;'0@(BX-"B`@
M("`@("`@("`@("`@("`@("`@(G=I=&@@)R1E>'1N86UE)R!S=7!P;W)T+EQN
M(BD[#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@
M>WM[(&1E<W1R=6-T;W(-"B`@("!F=6YC=&EO;B!?07)C:&EV95]487(H*0T*
M("`@('L-"B`@("`@("`@)'1H:7,M/E]C;&]S92@I.PT*("`@("`@("`O+R`M
M+2TM+2!,;V]K(&9O<B!A(&QO8V%L(&-O<'D@=&\@9&5L971E#0H@("`@("`@
M(&EF("@D=&AI<RT^7W1E;7!?=&%R;F%M92`A/2`G)RD-"B`@("`@("`@("`@
M($!U;FQI;FLH)'1H:7,M/E]T96UP7W1A<FYA;64I.PT*("`@("`@("`D=&AI
M<RT^7U!%05(H*3L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@
M8W)E871E*"D-"B`@("`O*BH-"B`@("`J(%1H:7,@;65T:&]D(&-R96%T97,@
M=&AE(&%R8VAI=F4@9FEL92!A;F0@861D('1H92!F:6QE<R`O(&1I<F5C=&]R
M:65S#0H@("`@*B!T:&%T(&%R92!L:7-T960@:6X@)'!?9FEL96QI<W0N#0H@
M("`@*B!)9B!A(&9I;&4@=VET:"!T:&4@<V%M92!N86UE(&5X:7-T(&%N9"!I
M<R!W<FET86)L92P@:70@:7,@<F5P;&%C960-"B`@("`J(&)Y('1H92!N97<@
M=&%R+@T*("`@("H@5&AE(&UE=&AO9"!R971U<FX@9F%L<V4@86YD(&$@4$5!
M4B!E<G)O<B!T97AT+@T*("`@("H@5&AE("1P7V9I;&5L:7-T('!A<F%M971E
M<B!C86X@8F4@86X@87)R87D@;V8@<W1R:6YG+"!E86-H('-T<FEN9PT*("`@
M("H@<F5P<F5S96YT:6YG(&$@9FEL96YA;64@;W(@82!D:7)E8W1O<GD@;F%M
M92!W:71H('1H96ER('!A=&@@:68-"B`@("`J(&YE961E9"X@270@8V%N(&%L
M<V\@8F4@82!S:6YG;&4@<W1R:6YG('=I=&@@;F%M97,@<V5P87)A=&5D(&)Y
M(&$-"B`@("`J('-I;F=L92!B;&%N:RX-"B`@("`J($9O<B!E86-H(&1I<F5C
M=&]R>2!A9&1E9"!I;B!T:&4@87)C:&EV92P@=&AE(&9I;&5S(&%N9`T*("`@
M("H@<W5B+61I<F5C=&]R:65S(&%R92!A;'-O(&%D9&5D+@T*("`@("H@4V5E
M(&%L<V\@8W)E871E36]D:69Y*"D@;65T:&]D(&9O<B!M;W)E(&1E=&%I;',N
M#0H@("`@*@T*("`@("H@0'!A<F%M(&%R<F%Y("`D<%]F:6QE;&ES="!!;B!A
M<G)A>2!O9B!F:6QE;F%M97,@86YD(&1I<F5C=&]R>2!N86UE<RP@;W(@80T*
M"2H@("`@("`@("`@("`@("`@("`@("`@("`@("!S:6YG;&4@<W1R:6YG('=I
M=&@@;F%M97,@<V5P87)A=&5D(&)Y(&$@<VEN9VQE#0H)*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&)L86YK('-P86-E+@T*("`@("H@0')E='5R;B`@
M("`@("`@("`@("`@("`@("!T<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&5R
M<F]R+@T*("`@("H@0'-E92!C<F5A=&5-;V1I9GDH*0T*("`@("H@0&%C8V5S
M<R!P=6)L:6,-"B`@("`J+PT*("`@(&9U;F-T:6]N(&-R96%T92@D<%]F:6QE
M;&ES="D-"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^8W)E871E36]D
M:69Y*"1P7V9I;&5L:7-T+"`G)RP@)R<I.PT*("`@('T-"B`@("`O+R!]?7T-
M"@T*("`@("\O('M[>R!A9&0H*0T*("`@("\J*@T*("`@("H@5&AI<R!M971H
M;V0@861D('1H92!F:6QE<R`O(&1I<F5C=&]R:65S('1H870@87)E(&QI<W1E
M9"!I;B`D<%]F:6QE;&ES="!I;@T*("`@("H@=&AE(&%R8VAI=F4N($EF('1H
M92!A<F-H:79E(&1O97,@;F]T(&5X:7-T(&ET(&ES(&-R96%T960N#0H@("`@
M*B!4:&4@;65T:&]D(')E='5R;B!F86QS92!A;F0@82!014%2(&5R<F]R('1E
M>'0N#0H@("`@*B!4:&4@9FEL97,@86YD(&1I<F5C=&]R:65S(&QI<W1E9"!A
M<F4@;VYL>2!A9&1E9"!A="!T:&4@96YD(&]F('1H92!A<F-H:79E+`T*("`@
M("H@979E;B!I9B!A(&9I;&4@=VET:"!T:&4@<V%M92!N86UE(&ES(&%L<F5A
M9'D@87)C:&EV960N#0H@("`@*B!3964@86QS;R!C<F5A=&5-;V1I9GDH*2!M
M971H;V0@9F]R(&UO<F4@9&5T86EL<RX-"B`@("`J#0H@("`@*B!`<&%R86T@
M87)R87D@("1P7V9I;&5L:7-T($%N(&%R<F%Y(&]F(&9I;&5N86UE<R!A;F0@
M9&ER96-T;W)Y(&YA;65S+"!O<B!A#0H)*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-I;F=L92!S=')I;F<@=VET:"!N86UE<R!S97!A<F%T960@8GD@
M82!S:6YG;&4-"@DJ("`@("`@("`@("`@("`@("`@("`@("`@("`@8FQA;FL@
M<W!A8V4N#0H@("`@*B!`<F5T=7)N("`@("`@("`@("`@("`@("`@('1R=64@
M;VX@<W5C8V5S<RP@9F%L<V4@;VX@97)R;W(N#0H@("`@*B!`<V5E(&-R96%T
M94UO9&EF>2@I#0H@("`@*B!`86-C97-S('!U8FQI8PT*("`@("HO#0H@("`@
M9G5N8W1I;VX@861D*"1P7V9I;&5L:7-T*0T*("`@('L-"B`@("`@("`@<F5T
M=7)N("1T:&ES+3YA9&1-;V1I9GDH)'!?9FEL96QI<W0L("<G+"`G)RD[#0H@
M("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&5X=')A8W0H*0T*("`@
M(&9U;F-T:6]N(&5X=')A8W0H)'!?<&%T:#TG)RD-"B`@("![#0H@("`@("`@
M(')E='5R;B`D=&AI<RT^97AT<F%C=$UO9&EF>2@D<%]P871H+"`G)RD[#0H@
M("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&QI<W1#;VYT96YT*"D-
M"B`@("!F=6YC=&EO;B!L:7-T0V]N=&5N="@I#0H@("`@>PT*("`@("`@("`D
M=E]L:7-T7V1E=&%I;"`](&%R<F%Y*"D[#0H-"B`@("`@("`@:68@*"1T:&ES
M+3Y?;W!E;E)E860H*2D@>PT*("`@("`@("`@("`@:68@*"$D=&AI<RT^7V5X
M=')A8W1,:7-T*"<G+"`D=E]L:7-T7V1E=&%I;"P@(FQI<W0B+"`G)RP@)R<I
M*2![#0H@("`@("`@("`@("`@("`@=6YS970H)'9?;&ES=%]D971A:6PI.PT*
M("`@("`@("`@("`@("`@("1V7VQI<W1?9&5T86EL(#T@,#L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("1T:&ES+3Y?8VQO<V4H*3L-"B`@("`@("`@
M?0T*#0H@("`@("`@(')E='5R;B`D=E]L:7-T7V1E=&%I;#L-"B`@("!]#0H@
M("`@+R\@?7U]#0H-"B`@("`O+R![>WL@8W)E871E36]D:69Y*"D-"B`@("`O
M*BH-"B`@("`J(%1H:7,@;65T:&]D(&-R96%T97,@=&AE(&%R8VAI=F4@9FEL
M92!A;F0@861D('1H92!F:6QE<R`O(&1I<F5C=&]R:65S#0H@("`@*B!T:&%T
M(&%R92!L:7-T960@:6X@)'!?9FEL96QI<W0N#0H@("`@*B!)9B!T:&4@9FEL
M92!A;')E861Y(&5X:7-T<R!A;F0@:7,@=W)I=&%B;&4L(&ET(&ES(')E<&QA
M8V5D(&)Y('1H90T*("`@("H@;F5W('1A<BX@270@:7,@82!C<F5A=&4@86YD
M(&YO="!A;B!A9&0N($EF('1H92!F:6QE(&5X:7-T<R!A;F0@:7,-"B`@("`J
M(')E860M;VYL>2!O<B!I<R!A(&1I<F5C=&]R>2!I="!I<R!N;W0@<F5P;&%C
M960N(%1H92!M971H;V0@<F5T=7)N#0H@("`@*B!F86QS92!A;F0@82!014%2
M(&5R<F]R('1E>'0N#0H@("`@*B!4:&4@)'!?9FEL96QI<W0@<&%R86UE=&5R
M(&-A;B!B92!A;B!A<G)A>2!O9B!S=')I;F<L(&5A8V@@<W1R:6YG#0H@("`@
M*B!R97!R97-E;G1I;F<@82!F:6QE;F%M92!O<B!A(&1I<F5C=&]R>2!N86UE
M('=I=&@@=&AE:7(@<&%T:"!I9@T*("`@("H@;F5E9&5D+B!)="!C86X@86QS
M;R!B92!A('-I;F=L92!S=')I;F<@=VET:"!N86UE<R!S97!A<F%T960@8GD@
M80T*("`@("H@<VEN9VQE(&)L86YK+@T*("`@("H@5&AE('!A=&@@:6YD:6-A
M=&5D(&EN("1P7W)E;6]V95]D:7(@=VEL;"!B92!R96UO=F5D(&9R;VT@=&AE
M#0H@("`@*B!M96UO<FEZ960@<&%T:"!O9B!E86-H(&9I;&4@+R!D:7)E8W1O
M<GD@;&ES=&5D('=H96X@=&AI<R!P871H#0H@("`@*B!E>&ES=',N($)Y(&1E
M9F%U;'0@;F]T:&EN9R!I<R!R96UO=F5D("AE;7!T>2!P871H("<G*0T*("`@
M("H@5&AE('!A=&@@:6YD:6-A=&5D(&EN("1P7V%D9%]D:7(@=VEL;"!B92!A
M9&1E9"!A="!T:&4@8F5G:6YN:6YG(&]F#0H@("`@*B!T:&4@;65M;W)I>F5D
M('!A=&@@;V8@96%C:"!F:6QE("\@9&ER96-T;W)Y(&QI<W1E9"X@2&]W979E
M<B!I="!C86X-"B`@("`J(&)E('-E="!T;R!E;7!T>2`G)RX@5&AE(&%D9&EN
M9R!O9B!A('!A=&@@:7,@9&]N92!A9G1E<B!T:&4@<F5M;W9I;F<-"B`@("`J
M(&]F('!A=&@N#0H@("`@*B!4:&4@<&%T:"!A9&0O<F5M;W9E(&%B:6QI='D@
M96YA8FQE<R!T:&4@=7-E<B!T;R!P<F5P87)E(&%N(&%R8VAI=F4-"B`@("`J
M(&9O<B!E>'1R86-T:6]N(&EN(&$@9&EF9F5R96YT('!A=&@@=&AA;B!T:&4@
M;W)I9VEN(&9I;&5S(&%R92X-"B`@("`J(%-E92!A;'-O(&%D9$UO9&EF>2@I
M(&UE=&AO9"!F;W(@9FEL92!A9&1I;F<@<')O<&5R=&EE<RX-"B`@("`J#0H@
M("`@*B!`<&%R86T@87)R87D@("1P7V9I;&5L:7-T("`@("!!;B!A<G)A>2!O
M9B!F:6QE;F%M97,@86YD(&1I<F5C=&]R>2!N86UE<RP-"@DJ("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&]R(&$@<VEN9VQE('-T<FEN9R!W:71H
M(&YA;65S('-E<&%R871E9"!B>0T*"2H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@82!S:6YG;&4@8FQA;FL@<W!A8V4N#0H@("`@*B!`<&%R86T@
M<W1R:6YG("1P7V%D9%]D:7(@("`@("!!('-T<FEN9R!W:&EC:"!C;VYT86EN
M<R!A('!A=&@@=&\@8F4@861D960-"@DJ("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('1O('1H92!M96UO<FEZ960@<&%T:"!O9B!E86-H(&5L96UE
M;G0@:6X-"@DJ("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H92!L
M:7-T+@T*("`@("H@0'!A<F%M('-T<FEN9R`D<%]R96UO=F5?9&ER("`@02!S
M=')I;F<@=VAI8V@@8V]N=&%I;G,@82!P871H('1O(&)E#0H)*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!R96UO=F5D(&9R;VT@=&AE(&UE;6]R
M:7IE9"!P871H(&]F(&5A8V@-"@DJ("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&5L96UE;G0@:6X@=&AE(&QI<W0L('=H96X@<F5L979A;G0N#0H@
M("`@*B!`<F5T=7)N(&)O;VQE86X@("`@("`@("`@("`@("!T<G5E(&]N('-U
M8V-E<W,L(&9A;'-E(&]N(&5R<F]R+@T*("`@("H@0&%C8V5S<R!P=6)L:6,-
M"B`@("`J($!S964@861D36]D:69Y*"D-"B`@("`J+PT*("`@(&9U;F-T:6]N
M(&-R96%T94UO9&EF>2@D<%]F:6QE;&ES="P@)'!?861D7V1I<BP@)'!?<F5M
M;W9E7V1I<CTG)RD-"B`@("![#0H@("`@("`@("1V7W)E<W5L="`]('1R=64[
M#0H-"B`@("`@("`@:68@*"$D=&AI<RT^7V]P96Y7<FET92@I*0T*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*#0H@("`@("`@(&EF("@D<%]F:6QE;&ES
M="`A/2`G)RD@>PT*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1P7V9I;&5L
M:7-T*2D-"B`@("`@("`@("`@("`@("`D=E]L:7-T(#T@)'!?9FEL96QI<W0[
M#0H@("`@("`@("`@("!E;'-E:68@*&ES7W-T<FEN9R@D<%]F:6QE;&ES="DI
M#0H@("`@("`@("`@("`@("`@)'9?;&ES="`](&5X<&QO9&4H)'1H:7,M/E]S
M97!A<F%T;W(L("1P7V9I;&5L:7-T*3L-"B`@("`@("`@("`@(&5L<V4@>PT*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?8VQE86Y&:6QE*"D[#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]E<G)O<B@G26YV86QI9"!F:6QE(&QI<W0G*3L-
M"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]
M#0H-"B`@("`@("`@("`@("1V7W)E<W5L="`]("1T:&ES+3Y?861D3&ES="@D
M=E]L:7-T+"`D<%]A9&1?9&ER+"`D<%]R96UO=F5?9&ER*3L-"B`@("`@("`@
M?0T*#0H@("`@("`@(&EF("@D=E]R97-U;'0I('L-"B`@("`@("`@("`@("1T
M:&ES+3Y?=W)I=&5&;V]T97(H*3L-"B`@("`@("`@("`@("1T:&ES+3Y?8VQO
M<V4H*3L-"B`@("`@("`@?2!E;'-E#0H@("`@("`@("`@("`D=&AI<RT^7V-L
M96%N1FEL92@I.PT*#0H@("`@("`@(')E='5R;B`D=E]R97-U;'0[#0H@("`@
M?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&%D9$UO9&EF>2@I#0H@("`@
M+RHJ#0H@("`@*B!4:&ES(&UE=&AO9"!A9&0@=&AE(&9I;&5S("\@9&ER96-T
M;W)I97,@;&ES=&5D(&EN("1P7V9I;&5L:7-T(&%T('1H90T*("`@("H@96YD
M(&]F('1H92!E>&ES=&EN9R!A<F-H:79E+B!)9B!T:&4@87)C:&EV92!D;V5S
M(&YO="!Y970@97AI<W1S(&ET#0H@("`@*B!I<R!C<F5A=&5D+@T*("`@("H@
M5&AE("1P7V9I;&5L:7-T('!A<F%M971E<B!C86X@8F4@86X@87)R87D@;V8@
M<W1R:6YG+"!E86-H('-T<FEN9PT*("`@("H@<F5P<F5S96YT:6YG(&$@9FEL
M96YA;64@;W(@82!D:7)E8W1O<GD@;F%M92!W:71H('1H96ER('!A=&@@:68-
M"B`@("`J(&YE961E9"X@270@8V%N(&%L<V\@8F4@82!S:6YG;&4@<W1R:6YG
M('=I=&@@;F%M97,@<V5P87)A=&5D(&)Y(&$-"B`@("`J('-I;F=L92!B;&%N
M:RX-"B`@("`J(%1H92!P871H(&EN9&EC871E9"!I;B`D<%]R96UO=F5?9&ER
M('=I;&P@8F4@<F5M;W9E9"!F<F]M('1H90T*("`@("H@;65M;W)I>F5D('!A
M=&@@;V8@96%C:"!F:6QE("\@9&ER96-T;W)Y(&QI<W1E9"!W:&5N('1H:7,@
M<&%T:`T*("`@("H@97AI<W1S+B!">2!D969A=6QT(&YO=&AI;F<@:7,@<F5M
M;W9E9"`H96UP='D@<&%T:"`G)RD-"B`@("`J(%1H92!P871H(&EN9&EC871E
M9"!I;B`D<%]A9&1?9&ER('=I;&P@8F4@861D960@870@=&AE(&)E9VEN;FEN
M9R!O9@T*("`@("H@=&AE(&UE;6]R:7IE9"!P871H(&]F(&5A8V@@9FEL92`O
M(&1I<F5C=&]R>2!L:7-T960N($AO=V5V97(@:70@8V%N#0H@("`@*B!B92!S
M970@=&\@96UP='D@)R<N(%1H92!A9&1I;F<@;V8@82!P871H(&ES(&1O;F4@
M869T97(@=&AE(')E;6]V:6YG#0H@("`@*B!O9B!P871H+@T*("`@("H@5&AE
M('!A=&@@861D+W)E;6]V92!A8FEL:71Y(&5N86)L97,@=&AE('5S97(@=&\@
M<')E<&%R92!A;B!A<F-H:79E#0H@("`@*B!F;W(@97AT<F%C=&EO;B!I;B!A
M(&1I9F9E<F5N="!P871H('1H86X@=&AE(&]R:6=I;B!F:6QE<R!A<F4N#0H@
M("`@*B!)9B!A(&9I;&4O9&ER(&ES(&%L<F5A9'D@:6X@=&AE(&%R8VAI=F4@
M:70@=VEL;"!O;FQY(&)E(&%D9&5D(&%T('1H90T*("`@("H@96YD(&]F('1H
M92!A<F-H:79E+B!4:&5R92!I<R!N;R!U<&1A=&4@;V8@=&AE(&5X:7-T:6YG
M(&%R8VAI=F5D#0H@("`@*B!F:6QE+V1I<BX@2&]W979E<B!W:&EL92!E>'1R
M86-T:6YG('1H92!A<F-H:79E+"!T:&4@;&%S="!F:6QE('=I;&P-"B`@("`J
M(')E<&QA8V4@=&AE(&9I<G-T(&]N92X@5&AI<R!R97-U;'1S(&EN(&$@;F]N
M92!O<'1I;6EZ871I;VX@;V8@=&AE#0H@("`@*B!A<F-H:79E('-I>F4N#0H@
M("`@*B!)9B!A(&9I;&4O9&ER(&1O97,@;F]T(&5X:7-T('1H92!F:6QE+V1I
M<B!I<R!I9VYO<F5D+B!(;W=E=F5R(&%N#0H@("`@*B!E<G)O<B!T97AT(&ES
M('-E;F0@=&\@4$5!4B!E<G)O<BX-"B`@("`J($EF(&$@9FEL92]D:7(@:7,@
M;F]T(')E861A8FQE('1H92!F:6QE+V1I<B!I<R!I9VYO<F5D+B!(;W=E=F5R
M(&%N#0H@("`@*B!E<G)O<B!T97AT(&ES('-E;F0@=&\@4$5!4B!E<G)O<BX-
M"B`@("`J#0H@("`@*B!`<&%R86T@87)R87D@("`@("`D<%]F:6QE;&ES="`@
M("`@06X@87)R87D@;V8@9FEL96YA;65S(&%N9"!D:7)E8W1O<GD-"@DJ("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N86UE<RP@;W(@82!S
M:6YG;&4@<W1R:6YG('=I=&@@;F%M97,-"@DJ("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!S97!A<F%T960@8GD@82!S:6YG;&4@8FQA;FL@
M<W!A8V4N#0H@("`@*B!`<&%R86T@<W1R:6YG("`@("`D<%]A9&1?9&ER("`@
M("`@02!S=')I;F<@=VAI8V@@8V]N=&%I;G,@82!P871H('1O(&)E#0H)*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@861D960@=&\@=&AE
M(&UE;6]R:7IE9"!P871H(&]F(&5A8V@-"@DJ("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!E;&5M96YT(&EN('1H92!L:7-T+@T*("`@("H@
M0'!A<F%M('-T<FEN9R`@("`@)'!?<F5M;W9E7V1I<B`@($$@<W1R:6YG('=H
M:6-H(&-O;G1A:6YS(&$@<&%T:"!T;R!B90T*"2H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(')E;6]V960@9G)O;2!T:&4@;65M;W)I>F5D
M('!A=&@@;V8-"@DJ("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!E86-H(&5L96UE;G0@:6X@=&AE(&QI<W0L('=H96X-"B`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R96QE=F%N="X-"B`@("`J
M($!R971U<FX@("`@("`@("`@("`@("`@("`@("`@("`@("!T<G5E(&]N('-U
M8V-E<W,L(&9A;'-E(&]N(&5R<F]R+@T*("`@("H@0&%C8V5S<R!P=6)L:6,-
M"B`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$UO9&EF>2@D<%]F:6QE;&ES="P@
M)'!?861D7V1I<BP@)'!?<F5M;W9E7V1I<CTG)RD-"B`@("![#0H@("`@("`@
M("1V7W)E<W5L="`]('1R=64[#0H-"B`@("`@("`@:68@*"$D=&AI<RT^7VES
M07)C:&EV92@I*0T*("`@("`@("`@("`@)'9?<F5S=6QT(#T@)'1H:7,M/F-R
M96%T94UO9&EF>2@D<%]F:6QE;&ES="P@)'!?861D7V1I<BP-"@D)"2`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!?<F5M;W9E7V1I<BD[#0H@
M("`@("`@(&5L<V4@>PT*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1P7V9I
M;&5L:7-T*2D-"B`@("`@("`@("`@("`@("`D=E]L:7-T(#T@)'!?9FEL96QI
M<W0[#0H@("`@("`@("`@("!E;'-E:68@*&ES7W-T<FEN9R@D<%]F:6QE;&ES
M="DI#0H@("`@("`@("`@("`@("`@)'9?;&ES="`](&5X<&QO9&4H)'1H:7,M
M/E]S97!A<F%T;W(L("1P7V9I;&5L:7-T*3L-"B`@("`@("`@("`@(&5L<V4@
M>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)TEN=F%L:60@9FEL
M92!L:7-T)RD[#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M("`@("`@("`@?0T*#0H@("`@("`@("`@("`D=E]R97-U;'0@/2`D=&AI<RT^
M7V%P<&5N9"@D=E]L:7-T+"`D<%]A9&1?9&ER+"`D<%]R96UO=F5?9&ER*3L-
M"B`@("`@("`@?0T*#0H@("`@("`@(')E='5R;B`D=E]R97-U;'0[#0H@("`@
M?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&%D9%-T<FEN9R@I#0H@("`@
M+RHJ#0H@("`@*B!4:&ES(&UE=&AO9"!A9&0@82!S:6YG;&4@<W1R:6YG(&%S
M(&$@9FEL92!A="!T:&4-"B`@("`J(&5N9"!O9B!T:&4@97AI<W1I;F<@87)C
M:&EV92X@268@=&AE(&%R8VAI=F4@9&]E<R!N;W0@>65T(&5X:7-T<R!I=`T*
M("`@("H@:7,@8W)E871E9"X-"B`@("`J#0H@("`@*B!`<&%R86T@<W1R:6YG
M("`@("`D<%]F:6QE;F%M92`@("`@02!S=')I;F<@=VAI8V@@8V]N=&%I;G,@
M=&AE(&9U;&P-"@DJ("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!F:6QE;F%M92!P871H('1H870@=VEL;"!B92!A<W-O8VEA=&5D#0H)*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=VET:"!T:&4@<W1R
M:6YG+@T*("`@("H@0'!A<F%M('-T<FEN9R`@("`@)'!?<W1R:6YG("`@("`@
M(%1H92!C;VYT96YT(&]F('1H92!F:6QE(&%D9&5D(&EN#0H)*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&%R8VAI=F4N#0H@("`@
M*B!`<F5T=7)N("`@("`@("`@("`@("`@("`@("`@("`@("`@=')U92!O;B!S
M=6-C97-S+"!F86QS92!O;B!E<G)O<BX-"B`@("`J($!A8V-E<W,@<'5B;&EC
M#0H@("`@*B\-"B`@("!F=6YC=&EO;B!A9&13=')I;F<H)'!?9FEL96YA;64L
M("1P7W-T<FEN9RD-"B`@("![#0H@("`@("`@("1V7W)E<W5L="`]('1R=64[
M#0H@("`@("`@(`T*("`@("`@("!I9B`H(21T:&ES+3Y?:7-!<F-H:79E*"DI
M('L-"B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]O<&5N5W)I=&4H*2D@>PT*
M("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1T:&ES+3Y?8VQO<V4H*3L-"B`@("`@("`@?0T*("`@
M("`@("`-"B`@("`@("`@:68@*"$D=&AI<RT^7V]P96Y!<'!E;F0H*2D-"B`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"@T*("`@("`@("`O+R!.965D('1O
M(&-H96-K('1H92!G970@8F%C:R!T;R!T:&4@=&5M<&]R87)Y(&9I;&4@/R`N
M+BXN#0H@("`@("`@("1V7W)E<W5L="`]("1T:&ES+3Y?861D4W1R:6YG*"1P
M7V9I;&5N86UE+"`D<%]S=')I;F<I.PT*#0H@("`@("`@("1T:&ES+3Y?=W)I
M=&5&;V]T97(H*3L-"@T*("`@("`@("`D=&AI<RT^7V-L;W-E*"D[#0H-"B`@
M("`@("`@<F5T=7)N("1V7W)E<W5L=#L-"B`@("!]#0H@("`@+R\@?7U]#0H-
M"B`@("`O+R![>WL@97AT<F%C=$UO9&EF>2@I#0H@("`@+RHJ#0H@("`@*B!4
M:&ES(&UE=&AO9"!E>'1R86-T(&%L;"!T:&4@8V]N=&5N="!O9B!T:&4@87)C
M:&EV92!I;B!T:&4@9&ER96-T;W)Y#0H@("`@*B!I;F1I8V%T960@8GD@)'!?
M<&%T:"X@5VAE;B!R96QE=F%N="!T:&4@;65M;W)I>F5D('!A=&@@;V8@=&AE
M#0H@("`@*B!F:6QE<R]D:7(@8V%N(&)E(&UO9&EF:65D(&)Y(')E;6]V:6YG
M('1H92`D<%]R96UO=F5?<&%T:"!P871H(&%T('1H90T*("`@("H@8F5G:6YN
M:6YG(&]F('1H92!F:6QE+V1I<B!P871H+@T*("`@("H@5VAI;&4@97AT<F%C
M=&EN9R!A(&9I;&4L(&EF('1H92!D:7)E8W1O<GD@<&%T:"!D;V5S(&YO="!E
M>&ES=',@:70@:7,-"B`@("`J(&-R96%T960N#0H@("`@*B!7:&EL92!E>'1R
M86-T:6YG(&$@9FEL92P@:68@=&AE(&9I;&4@86QR96%D>2!E>&ES=',@:70@
M:7,@<F5P;&%C960-"B`@("`J('=I=&AO=70@;&]O:VEN9R!F;W(@;&%S="!M
M;V1I9FEC871I;VX@9&%T92X-"B`@("`J(%=H:6QE(&5X=')A8W1I;F<@82!F
M:6QE+"!I9B!T:&4@9FEL92!A;')E861Y(&5X:7-T<R!A;F0@:7,@=W)I=&4-
M"B`@("`J('!R;W1E8W1E9"P@=&AE(&5X=')A8W1I;VX@:7,@86)O<G1E9"X-
M"B`@("`J(%=H:6QE(&5X=')A8W1I;F<@82!F:6QE+"!I9B!A(&1I<F5C=&]R
M>2!W:71H('1H92!S86UE(&YA;64@86QR96%D>0T*("`@("H@97AI<W1S+"!T
M:&4@97AT<F%C=&EO;B!I<R!A8F]R=&5D+@T*("`@("H@5VAI;&4@97AT<F%C
M=&EN9R!A(&1I<F5C=&]R>2P@:68@82!F:6QE('=I=&@@=&AE('-A;64@;F%M
M92!A;')E861Y#0H@("`@*B!E>&ES=',L('1H92!E>'1R86-T:6]N(&ES(&%B
M;W)T960N#0H@("`@*B!7:&EL92!E>'1R86-T:6YG(&$@9FEL92]D:7)E8W1O
M<GD@:68@=&AE(&1E<W1I;F%T:6]N(&1I<F5C=&]R>2!E>&ES=`T*("`@("H@
M86YD(&ES('=R:71E('!R;W1E8W1E9"P@;W(@9&]E<R!N;W0@97AI<W0@8G5T
M(&-A;B!N;W0@8F4@8W)E871E9"P-"B`@("`J('1H92!E>'1R86-T:6]N(&ES
M(&%B;W)T960N#0H@("`@*B!)9B!A9G1E<B!E>'1R86-T:6]N(&%N(&5X=')A
M8W1E9"!F:6QE(&1O97,@;F]T('-H;W<@=&AE(&-O<G)E8W0-"B`@("`J('-T
M;W)E9"!F:6QE('-I>F4L('1H92!E>'1R86-T:6]N(&ES(&%B;W)T960N#0H@
M("`@*B!7:&5N('1H92!E>'1R86-T:6]N(&ES(&%B;W)T960L(&$@4$5!4B!E
M<G)O<B!T97AT(&ES('-E="!A;F0@9F%L<V4-"B`@("`J(&ES(')E='5R;F5D
M+B!(;W=E=F5R('1H92!R97-U;'0@8V%N(&)E(&$@<&%R=&EA;"!E>'1R86-T
M:6]N('1H870@;6%Y#0H@("`@*B!N965D('1O(&)E(&UA;G5A;&QY(&-L96%N
M960N#0H@("`@*@T*("`@("H@0'!A<F%M('-T<FEN9R`D<%]P871H("`@("`@
M("`@5&AE('!A=&@@;V8@=&AE(&1I<F5C=&]R>2!W:&5R92!T:&4-"@DJ("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9I;&5S+V1I<B!N965D('1O
M(&)Y(&5X=')A8W1E9"X-"B`@("`J($!P87)A;2!S=')I;F<@)'!?<F5M;W9E
M7W!A=&@@(%!A<G0@;V8@=&AE(&UE;6]R:7IE9"!P871H('1H870@8V%N(&)E
M#0H)*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R96UO=F5D(&EF
M('!R97-E;G0@870@=&AE(&)E9VEN;FEN9R!O9@T*"2H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=&AE(&9I;&4O9&ER('!A=&@N#0H@("`@*B!`
M<F5T=7)N(&)O;VQE86X@("`@("`@("`@("`@("!T<G5E(&]N('-U8V-E<W,L
M(&9A;'-E(&]N(&5R<F]R+@T*("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`J
M($!S964@97AT<F%C=$QI<W0H*0T*("`@("HO#0H@("`@9G5N8W1I;VX@97AT
M<F%C=$UO9&EF>2@D<%]P871H+"`D<%]R96UO=F5?<&%T:"D-"B`@("![#0H@
M("`@("`@("1V7W)E<W5L="`]('1R=64[#0H@("`@("`@("1V7VQI<W1?9&5T
M86EL(#T@87)R87DH*3L-"@T*("`@("`@("!I9B`H)'9?<F5S=6QT(#T@)'1H
M:7,M/E]O<&5N4F5A9"@I*2![#0H@("`@("`@("`@("`D=E]R97-U;'0@/2`D
M=&AI<RT^7V5X=')A8W1,:7-T*"1P7W!A=&@L("1V7VQI<W1?9&5T86EL+`T*
M"0D)("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B8V]M<&QE=&4B
M+"`P+"`D<%]R96UO=F5?<&%T:"D[#0H@("`@("`@("`@("`D=&AI<RT^7V-L
M;W-E*"D[#0H@("`@("`@('T-"@T*("`@("`@("!R971U<FX@)'9?<F5S=6QT
M.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!E>'1R86-T26Y3
M=')I;F<H*0T*("`@("\J*@T*("`@("H@5&AI<R!M971H;V0@97AT<F%C="!F
M<F]M('1H92!A<F-H:79E(&]N92!F:6QE(&ED96YT:69I960@8GD@)'!?9FEL
M96YA;64N#0H@("`@*B!4:&4@<F5T=7)N('9A;'5E(&ES(&$@<W1R:6YG('=I
M=&@@=&AE(&9I;&4@8V]N=&5N="P@;W(@3E5,3"!O;B!E<G)O<BX-"B`@("`J
M($!P87)A;2!S=')I;F<@)'!?9FEL96YA;64@("`@(%1H92!P871H(&]F('1H
M92!F:6QE('1O(&5X=')A8W0@:6X@82!S=')I;F<N#0H@("`@*B!`<F5T=7)N
M("`@("`@("`@("`@("`@("`@("`@("!A('-T<FEN9R!W:71H('1H92!F:6QE
M(&-O;G1E;G0@;W(@3E5,3"X-"B`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@
M*B\-"B`@("!F=6YC=&EO;B!E>'1R86-T26Y3=')I;F<H)'!?9FEL96YA;64I
M#0H@("`@>PT*("`@("`@("!I9B`H)'1H:7,M/E]O<&5N4F5A9"@I*2![#0H@
M("`@("`@("`@("`D=E]R97-U;'0@/2`D=&AI<RT^7V5X=')A8W1);E-T<FEN
M9R@D<%]F:6QE;F%M92D[#0H@("`@("`@("`@("`D=&AI<RT^7V-L;W-E*"D[
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=E]R97-U;'0@/2!.
M54Q,.PT*("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N("1V7W)E<W5L=#L-
M"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@97AT<F%C=$QI<W0H
M*0T*("`@("\J*@T*("`@("H@5&AI<R!M971H;V0@97AT<F%C="!F<F]M('1H
M92!A<F-H:79E(&]N;'D@=&AE(&9I;&5S(&EN9&EC871E9"!I;B!T:&4-"B`@
M("`J("1P7V9I;&5L:7-T+B!4:&5S92!F:6QE<R!A<F4@97AT<F%C=&5D(&EN
M('1H92!C=7)R96YT(&1I<F5C=&]R>2!O<@T*("`@("H@:6X@=&AE(&1I<F5C
M=&]R>2!I;F1I8V%T960@8GD@=&AE(&]P=&EO;F%L("1P7W!A=&@@<&%R86UE
M=&5R+@T*("`@("H@268@:6YD:6-A=&5D('1H92`D<%]R96UO=F5?<&%T:"!C
M86X@8F4@=7-E9"!I;B!T:&4@<V%M92!W87D@87,@:70@:7,-"B`@("`J('5S
M960@:6X@97AT<F%C=$UO9&EF>2@I(&UE=&AO9"X-"B`@("`J($!P87)A;2!A
M<G)A>2`@)'!?9FEL96QI<W0@("`@($%N(&%R<F%Y(&]F(&9I;&5N86UE<R!A
M;F0@9&ER96-T;W)Y(&YA;65S+`T*"2H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@;W(@82!S:6YG;&4@<W1R:6YG('=I=&@@;F%M97,@<V5P87)A
M=&5D#0H)*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B>2!A('-I
M;F=L92!B;&%N:R!S<&%C92X-"B`@("`J($!P87)A;2!S=')I;F<@)'!?<&%T
M:"`@("`@("`@(%1H92!P871H(&]F('1H92!D:7)E8W1O<GD@=VAE<F4@=&AE
M#0H)*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F:6QE<R]D:7(@
M;F5E9"!T;R!B>2!E>'1R86-T960N#0H@("`@*B!`<&%R86T@<W1R:6YG("1P
M7W)E;6]V95]P871H("!087)T(&]F('1H92!M96UO<FEZ960@<&%T:"!T:&%T
M(&-A;B!B90T*"2H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5M
M;W9E9"!I9B!P<F5S96YT(&%T('1H92!B96=I;FYI;F<@;V8-"@DJ("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('1H92!F:6QE+V1I<B!P871H+@T*
M("`@("H@0')E='5R;B`@("`@("`@("`@("`@("`@("`@("`@=')U92!O;B!S
M=6-C97-S+"!F86QS92!O;B!E<G)O<BX-"B`@("`J($!A8V-E<W,@<'5B;&EC
M#0H@("`@*B!`<V5E(&5X=')A8W1-;V1I9GDH*0T*("`@("HO#0H@("`@9G5N
M8W1I;VX@97AT<F%C=$QI<W0H)'!?9FEL96QI<W0L("1P7W!A=&@])R<L("1P
M7W)E;6]V95]P871H/2<G*0T*("`@('L-"B`@("`@("`@)'9?<F5S=6QT(#T@
M=')U93L-"B`@("`@("`@)'9?;&ES=%]D971A:6P@/2!A<G)A>2@I.PT*#0H@
M("`@("`@(&EF("AI<U]A<G)A>2@D<%]F:6QE;&ES="DI#0H@("`@("`@("`@
M("`D=E]L:7-T(#T@)'!?9FEL96QI<W0[#0H@("`@("`@(&5L<V5I9B`H:7-?
M<W1R:6YG*"1P7V9I;&5L:7-T*2D-"B`@("`@("`@("`@("1V7VQI<W0@/2!E
M>'!L;V1E*"1T:&ES+3Y?<V5P87)A=&]R+"`D<%]F:6QE;&ES="D[#0H@("`@
M("`@(&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G26YV86QI
M9"!S=')I;F<@;&ES="<I.PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("!]#0H-"B`@("`@("`@:68@*"1V7W)E<W5L="`]("1T:&ES+3Y?
M;W!E;E)E860H*2D@>PT*("`@("`@("`@("`@)'9?<F5S=6QT(#T@)'1H:7,M
M/E]E>'1R86-T3&ES="@D<%]P871H+"`D=E]L:7-T7V1E=&%I;"P@(G!A<G1I
M86PB+`T*"0D)("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=E]L
M:7-T+"`D<%]R96UO=F5?<&%T:"D[#0H@("`@("`@("`@("`D=&AI<RT^7V-L
M;W-E*"D[#0H@("`@("`@('T-"@T*("`@("`@("!R971U<FX@)'9?<F5S=6QT
M.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!S971!='1R:6)U
M=&4H*0T*("`@("\J*@T*("`@("H@5&AI<R!M971H;V0@<V5T('-P96-I9FEC
M(&%T=')I8G5T97,@;V8@=&AE(&%R8VAI=F4N($ET('5S97,@82!V87)I86)L
M90T*("`@("H@;&ES="!O9B!P87)A;65T97)S+"!I;B!T:&4@9F]R;6%T(&%T
M=')I8G5T92!C;V1E("L@871T<FEB=71E('9A;'5E<R`Z#0H@("`@*B`D87)C
M:"T^<V5T071T<FEB=71E*$%20TA)5D5?5$%27T%45%]315!!4D%43U(L("<L
M)RD[#0H@("`@*B!`<&%R86T@;6EX960@)&%R9W8@("`@("`@("`@("!V87)I
M86)L92!L:7-T(&]F(&%T=')I8G5T97,@86YD('9A;'5E<PT*("`@("H@0')E
M='5R;B`@("`@("`@("`@("`@("`@("`@("`@=')U92!O;B!S=6-C97-S+"!F
M86QS92!O;B!E<G)O<BX-"B`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@*B\-
M"B`@("!F=6YC=&EO;B!S971!='1R:6)U=&4H*0T*("`@('L-"B`@("`@("`@
M)'9?<F5S=6QT(#T@=')U93L-"B`@("`@("`@#0H@("`@("`@("\O("TM+2TM
M($=E="!T:&4@;G5M8F5R(&]F('9A<FEA8FQE(&QI<W0@;V8@87)G=6UE;G1S
M#0H@("`@("`@(&EF("@H)'9?<VEZ92`](&9U;F-?;G5M7V%R9W,H*2D@/3T@
M,"D@>PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@
M("`@("`@#0H@("`@("`@("\O("TM+2TM($=E="!T:&4@87)G=6UE;G1S#0H@
M("`@("`@("1V7V%T=%]L:7-T(#T@)F9U;F-?9V5T7V%R9W,H*3L-"@T*("`@
M("`@("`O+R`M+2TM+2!296%D('1H92!A='1R:6)U=&5S#0H@("`@("`@("1I
M/3`[#0H@("`@("`@('=H:6QE("@D:3PD=E]S:7IE*2![#0H-"B`@("`@("`@
M("`@("\O("TM+2TM($QO;VL@9F]R(&YE>'0@;W!T:6]N#0H@("`@("`@("`@
M("!S=VET8V@@*"1V7V%T=%]L:7-T6R1I72D@>PT*("`@("`@("`@("`@("`@
M("\O("TM+2TM($QO;VL@9F]R(&]P=&EO;G,@=&AA="!R97%U97-T(&$@<W1R
M:6YG('9A;'5E#0H@("`@("`@("`@("`@("`@8V%S92!!4D-(259%7U1!4E]!
M5%1?4T5005)!5$]2(#H-"B`@("`@("`@("`@("`@("`@("`@+R\@+2TM+2T@
M0VAE8VL@=&AE(&YU;6)E<B!O9B!P87)A;65T97)S#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@H)&DK,2D@/CT@)'9?<VEZ92D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G26YV86QI9"!N=6UB97(@;V8@
M<&%R86UE=&5R<R!F;W(@)PT*"0D)"0D)("`@("`@("`@("`@("`N)V%T=')I
M8G5T92!!4D-(259%7U1!4E]!5%1?4T5005)!5$]2)RD[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@("`@
M("`@('T-"@T*("`@("`@("`@("`@("`@("`@("`O+R`M+2TM+2!'970@=&AE
M('9A;'5E#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5P87)A=&]R
M(#T@)'9?871T7VQI<W1;)&DK,5T[#0H@("`@("`@("`@("`@("`@("`@("1I
M*RL[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@("`@
M("!D969A=6QT(#H-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]E<G)O
M<B@G56YK;F]W(&%T=')I8G5T92!C;V1E("<N)'9?871T7VQI<W1;)&E=+B<G
M*3L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@
M("`@("`@?0T*#0H@("`@("`@("`@("`O+R`M+2TM+2!.97AT(&%T=')I8G5T
M90T*("`@("`@("`@("`@)&DK*SL-"B`@("`@("`@?0T*#0H@("`@("`@(')E
M='5R;B`D=E]R97-U;'0[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@
M>WM[(%]E<G)O<B@I#0H@("`@9G5N8W1I;VX@7V5R<F]R*"1P7VUE<W-A9V4I
M#0H@("`@>PT*("`@("`@("`O+R`M+2TM+2!4;R!B92!C;VUP;&5T960-"B`@
M("`@("`@)'1H:7,M/G)A:7-E17)R;W(H)'!?;65S<V%G92D[#0H@("`@?0T*
M("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]W87)N:6YG*"D-"B`@("!F=6YC
M=&EO;B!?=V%R;FEN9R@D<%]M97-S86=E*0T*("`@('L-"B`@("`@("`@+R\@
M+2TM+2T@5&\@8F4@8V]M<&QE=&5D#0H@("`@("`@("1T:&ES+3YR86ES945R
M<F]R*"1P7VUE<W-A9V4I.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O
M('M[>R!?:7-!<F-H:79E*"D-"B`@("!F=6YC=&EO;B!?:7-!<F-H:79E*"1P
M7V9I;&5N86UE/4Y53$PI#0H@("`@>PT*("`@("`@("!I9B`H)'!?9FEL96YA
M;64@/3T@3E5,3"D@>PT*("`@("`@("`@("`@)'!?9FEL96YA;64@/2`D=&AI
M<RT^7W1A<FYA;64[#0H@("`@("`@('T-"B`@("`@("`@8VQE87)S=&%T8V%C
M:&4H*3L-"B`@("`@("`@<F5T=7)N($!I<U]F:6QE*"1P7V9I;&5N86UE*3L-
M"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7V]P96Y7<FET92@I
M#0H@("`@9G5N8W1I;VX@7V]P96Y7<FET92@I#0H@("`@>PT*("`@("`@("!I
M9B`H)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T]("=G>B<I#0H@("`@("`@("`@
M("`D=&AI<RT^7V9I;&4@/2!`9WIO<&5N*"1T:&ES+3Y?=&%R;F%M92P@(G=B
M.2(I.PT*("`@("`@("!E;'-E(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y<&4@
M/3T@)V)Z,B<I#0H@("`@("`@("`@("`D=&AI<RT^7V9I;&4@/2!`8GIO<&5N
M*"1T:&ES+3Y?=&%R;F%M92P@(G=B(BD[#0H@("`@("`@(&5L<V4@:68@*"1T
M:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G;F]N92<I#0H@("`@("`@("`@("`D
M=&AI<RT^7V9I;&4@/2!`9F]P96XH)'1H:7,M/E]T87)N86UE+"`B=V(B*3L-
M"B`@("`@("`@96QS90T*("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G56YK
M;F]W;B!O<B!M:7-S:6YG(&-O;7!R97-S:6]N('1Y<&4@*"<-"@D)"2`@("`@
M("`@("`@("`@+B1T:&ES+3Y?8V]M<')E<W-?='EP92XG*2<I.PT*#0H@("`@
M("`@(&EF("@D=&AI<RT^7V9I;&4@/3T@,"D@>PT*("`@("`@("`@("`@)'1H
M:7,M/E]E<G)O<B@G56YA8FQE('1O(&]P96X@:6X@=W)I=&4@;6]D92!<)R<-
M"@D)"2`@("`@("`@("`@("`@+B1T:&ES+3Y?=&%R;F%M92XG7"<G*3L-"B`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*#0H@("`@("`@
M(')E='5R;B!T<G5E.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[
M>R!?;W!E;E)E860H*0T*("`@(&9U;F-T:6]N(%]O<&5N4F5A9"@I#0H@("`@
M>PT*("`@("`@("!I9B`H<W1R=&]L;W=E<BAS=6)S='(H)'1H:7,M/E]T87)N
M86UE+"`P+"`W*2D@/3T@)VAT='`Z+R\G*2![#0H-"B`@("`@("`@("`O+R`M
M+2TM+2!,;V]K(&EF(&$@;&]C86P@8V]P>2!N965D('1O(&)E(&1O;F4-"B`@
M("`@("`@("!I9B`H)'1H:7,M/E]T96UP7W1A<FYA;64@/3T@)R<I('L-"B`@
M("`@("`@("`@("`@)'1H:7,M/E]T96UP7W1A<FYA;64@/2!U;FEQ:60H)W1A
M<B<I+B<N=&UP)SL-"B`@("`@("`@("`@("`@:68@*"$D=E]F:6QE7V9R;VT@
M/2!`9F]P96XH)'1H:7,M/E]T87)N86UE+"`G<F(G*2D@>PT*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?97)R;W(H)U5N86)L92!T;R!O<&5N(&EN(')E860@
M;6]D92!<)R<-"@D)"0D@("`@("`@("`@("`@("XD=&AI<RT^7W1A<FYA;64N
M)UPG)RD[#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]T96UP7W1A<FYA;64@
M/2`G)SL-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@:68@*"$D=E]F:6QE7W1O(#T@0&9O
M<&5N*"1T:&ES+3Y?=&5M<%]T87)N86UE+"`G=V(G*2D@>PT*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?97)R;W(H)U5N86)L92!T;R!O<&5N(&EN('=R:71E
M(&UO9&4@7"<G#0H)"0D)("`@("`@("`@("`@("`N)'1H:7,M/E]T96UP7W1A
M<FYA;64N)UPG)RD[#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]T96UP7W1A
M<FYA;64@/2`G)SL-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@=VAI;&4@*"1V7V1A=&$@
M/2!`9G)E860H)'9?9FEL95]F<F]M+"`Q,#(T*2D-"B`@("`@("`@("`@("`@
M("`@($!F=W)I=&4H)'9?9FEL95]T;RP@)'9?9&%T82D[#0H@("`@("`@("`@
M("`@($!F8VQO<V4H)'9?9FEL95]F<F]M*3L-"B`@("`@("`@("`@("`@0&9C
M;&]S92@D=E]F:6QE7W1O*3L-"B`@("`@("`@("!]#0H-"B`@("`@("`@("`O
M+R`M+2TM+2!&:6QE('1O(&]P96X@:68@=&AE(&QO8V%L(&-O<'D-"B`@("`@
M("`@("`D=E]F:6QE;F%M92`]("1T:&ES+3Y?=&5M<%]T87)N86UE.PT*#0H@
M("`@("`@('T@96QS90T*("`@("`@("`@("\O("TM+2TM($9I;&4@=&\@;W!E
M;B!I9B!T:&4@;F]R;6%L(%1A<B!F:6QE#0H@("`@("`@("`@)'9?9FEL96YA
M;64@/2`D=&AI<RT^7W1A<FYA;64[#0H-"B`@("`@("`@:68@*"1T:&ES+3Y?
M8V]M<')E<W-?='EP92`]/2`G9WHG*0T*("`@("`@("`@("`@)'1H:7,M/E]F
M:6QE(#T@0&=Z;W!E;B@D=E]F:6QE;F%M92P@(G)B(BD[#0H@("`@("`@(&5L
M<V4@:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G8GHR)RD-"B`@("`@
M("`@("`@("1T:&ES+3Y?9FEL92`]($!B>F]P96XH)'9?9FEL96YA;64L(")R
M8B(I.PT*("`@("`@("!E;'-E(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y<&4@
M/3T@)VYO;F4G*0T*("`@("`@("`@("`@)'1H:7,M/E]F:6QE(#T@0&9O<&5N
M*"1V7V9I;&5N86UE+"`B<F(B*3L-"B`@("`@("`@96QS90T*("`@("`@("`@
M("`@)'1H:7,M/E]E<G)O<B@G56YK;F]W;B!O<B!M:7-S:6YG(&-O;7!R97-S
M:6]N('1Y<&4@*"<-"@D)"2`@("`@("`@("`@("`@+B1T:&ES+3Y?8V]M<')E
M<W-?='EP92XG*2<I.PT*#0H@("`@("`@(&EF("@D=&AI<RT^7V9I;&4@/3T@
M,"D@>PT*("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G56YA8FQE('1O(&]P
M96X@:6X@<F5A9"!M;V1E(%PG)RXD=E]F:6QE;F%M92XG7"<G*3L-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*#0H@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?
M;W!E;E)E8617<FET92@I#0H@("`@9G5N8W1I;VX@7V]P96Y296%D5W)I=&4H
M*0T*("`@('L-"B`@("`@("`@:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]
M/2`G9WHG*0T*("`@("`@("`@("`@)'1H:7,M/E]F:6QE(#T@0&=Z;W!E;B@D
M=&AI<RT^7W1A<FYA;64L(")R*V(B*3L-"B`@("`@("`@96QS92!I9B`H)'1H
M:7,M/E]C;VUP<F5S<U]T>7!E(#T]("=B>C(G*0T*("`@("`@("`@("`@)'1H
M:7,M/E]F:6QE(#T@0&)Z;W!E;B@D=&AI<RT^7W1A<FYA;64L(")R*V(B*3L-
M"B`@("`@("`@96QS92!I9B`H)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T]("=N
M;VYE)RD-"B`@("`@("`@("`@("1T:&ES+3Y?9FEL92`]($!F;W!E;B@D=&AI
M<RT^7W1A<FYA;64L(")R*V(B*3L-"B`@("`@("`@96QS90T*("`@("`@("`@
M("`@)'1H:7,M/E]E<G)O<B@G56YK;F]W;B!O<B!M:7-S:6YG(&-O;7!R97-S
M:6]N('1Y<&4@*"<-"@D)"2`@("`@("`@("`@("`@+B1T:&ES+3Y?8V]M<')E
M<W-?='EP92XG*2<I.PT*#0H@("`@("`@(&EF("@D=&AI<RT^7V9I;&4@/3T@
M,"D@>PT*("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G56YA8FQE('1O(&]P
M96X@:6X@<F5A9"]W<FET92!M;V1E(%PG)PT*"0D)("`@("`@("`@("`@("`N
M)'1H:7,M/E]T87)N86UE+B=<)R<I.PT*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]C;&]S92@I#0H@("`@9G5N
M8W1I;VX@7V-L;W-E*"D-"B`@("![#0H@("`@("`@("\O:68@*&ES<V5T*"1T
M:&ES+3Y?9FEL92DI('L-"B`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1T:&ES
M+3Y?9FEL92DI('L-"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V-O;7!R97-S
M7W1Y<&4@/3T@)V=Z)RD-"B`@("`@("`@("`@("`@("!`9WIC;&]S92@D=&AI
M<RT^7V9I;&4I.PT*("`@("`@("`@("`@96QS92!I9B`H)'1H:7,M/E]C;VUP
M<F5S<U]T>7!E(#T]("=B>C(G*0T*("`@("`@("`@("`@("`@($!B>F-L;W-E
M*"1T:&ES+3Y?9FEL92D[#0H@("`@("`@("`@("!E;'-E(&EF("@D=&AI<RT^
M7V-O;7!R97-S7W1Y<&4@/3T@)VYO;F4G*0T*("`@("`@("`@("`@("`@($!F
M8VQO<V4H)'1H:7,M/E]F:6QE*3L-"B`@("`@("`@("`@(&5L<V4-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7V5R<F]R*"=5;FMN;W=N(&]R(&UI<W-I;F<@
M8V]M<')E<W-I;VX@='EP92`H)PT*"0D)"2`@("`@("`@("`@("`@+B1T:&ES
M+3Y?8V]M<')E<W-?='EP92XG*2<I.PT*#0H@("`@("`@("`@("`D=&AI<RT^
M7V9I;&4@/2`P.PT*("`@("`@("!]#0H-"B`@("`@("`@+R\@+2TM+2T@3&]O
M:R!I9B!A(&QO8V%L(&-O<'D@;F5E9"!T;R!B92!E<F%S90T*("`@("`@("`O
M+R!.;W1E('1H870@:70@;6EG:'0@8F4@:6YT97)E<W1I;F<@=&\@:V5E<"!T
M:&4@=7)L(&9O<B!A('1I;64@.B!4;T1O#0H@("`@("`@(&EF("@D=&AI<RT^
M7W1E;7!?=&%R;F%M92`A/2`G)RD@>PT*("`@("`@("`@("`@0'5N;&EN:R@D
M=&AI<RT^7W1E;7!?=&%R;F%M92D[#0H@("`@("`@("`@("`D=&AI<RT^7W1E
M;7!?=&%R;F%M92`]("<G.PT*("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N
M('1R=64[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]C;&5A
M;D9I;&4H*0T*("`@(&9U;F-T:6]N(%]C;&5A;D9I;&4H*0T*("`@('L-"B`@
M("`@("`@)'1H:7,M/E]C;&]S92@I.PT*#0H@("`@("`@("\O("TM+2TM($QO
M;VL@9F]R(&$@;&]C86P@8V]P>0T*("`@("`@("!I9B`H)'1H:7,M/E]T96UP
M7W1A<FYA;64@(3T@)R<I('L-"B`@("`@("`@("`@("\O("TM+2TM(%)E;6]V
M92!T:&4@;&]C86P@8V]P>2!B=70@;F]T('1H92!R96UO=&4@=&%R;F%M90T*
M("`@("`@("`@("`@0'5N;&EN:R@D=&AI<RT^7W1E;7!?=&%R;F%M92D[#0H@
M("`@("`@("`@("`D=&AI<RT^7W1E;7!?=&%R;F%M92`]("<G.PT*("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@+R\@+2TM+2T@4F5M;W9E('1H92!L
M;V-A;"!T87)N86UE(&9I;&4-"B`@("`@("`@("`@($!U;FQI;FLH)'1H:7,M
M/E]T87)N86UE*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W1A<FYA
M;64@/2`G)SL-"@T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H@("`@
M+R\@?7U]#0H-"B`@("`O+R![>WL@7W=R:71E0FQO8VLH*0T*("`@(&9U;F-T
M:6]N(%]W<FET94)L;V-K*"1P7V)I;F%R>5]D871A+"`D<%]L96X];G5L;"D-
M"B`@("![#0H@("`@("!I9B`H:7-?<F5S;W5R8V4H)'1H:7,M/E]F:6QE*2D@
M>PT*("`@("`@("`@(&EF("@D<%]L96X@/3T](&YU;&PI('L-"B`@("`@("`@
M("`@("`@:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G9WHG*0T*("`@
M("`@("`@("`@("`@("`@0&=Z<'5T<R@D=&AI<RT^7V9I;&4L("1P7V)I;F%R
M>5]D871A*3L-"B`@("`@("`@("`@("`@96QS92!I9B`H)'1H:7,M/E]C;VUP
M<F5S<U]T>7!E(#T]("=B>C(G*0T*("`@("`@("`@("`@("`@("`@0&)Z=W)I
M=&4H)'1H:7,M/E]F:6QE+"`D<%]B:6YA<GE?9&%T82D[#0H@("`@("`@("`@
M("`@(&5L<V4@:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G;F]N92<I
M#0H@("`@("`@("`@("`@("`@("!`9G!U=',H)'1H:7,M/E]F:6QE+"`D<%]B
M:6YA<GE?9&%T82D[#0H@("`@("`@("`@("`@(&5L<V4-"B`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?97)R;W(H)U5N:VYO=VX@;W(@;6ES<VEN9R!C;VUP
M<F5S<VEO;B!T>7!E("@G#0H)"0D)("`@("`@("`@("`@("`@("XD=&AI<RT^
M7V-O;7!R97-S7W1Y<&4N)RDG*3L-"B`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("!I9B`H)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T]("=G>B<I
M#0H@("`@("`@("`@("`@("`@("!`9WIP=71S*"1T:&ES+3Y?9FEL92P@)'!?
M8FEN87)Y7V1A=&$L("1P7VQE;BD[#0H@("`@("`@("`@("`@(&5L<V4@:68@
M*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G8GHR)RD-"B`@("`@("`@("`@
M("`@("`@($!B>G=R:71E*"1T:&ES+3Y?9FEL92P@)'!?8FEN87)Y7V1A=&$L
M("1P7VQE;BD[#0H@("`@("`@("`@("`@(&5L<V4@:68@*"1T:&ES+3Y?8V]M
M<')E<W-?='EP92`]/2`G;F]N92<I#0H@("`@("`@("`@("`@("`@("!`9G!U
M=',H)'1H:7,M/E]F:6QE+"`D<%]B:6YA<GE?9&%T82P@)'!?;&5N*3L-"B`@
M("`@("`@("`@("`@96QS90T*("`@("`@("`@("`@("`@("`@)'1H:7,M/E]E
M<G)O<B@G56YK;F]W;B!O<B!M:7-S:6YG(&-O;7!R97-S:6]N('1Y<&4@*"<-
M"@D)"0D@("`@("`@("`@("`@("`@+B1T:&ES+3Y?8V]M<')E<W-?='EP92XG
M*2<I.PT*#0H@("`@("`@("`@?0T*("`@("`@?0T*("`@("`@<F5T=7)N('1R
M=64[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]R96%D0FQO
M8VLH*0T*("`@(&9U;F-T:6]N(%]R96%D0FQO8VLH*0T*("`@('L-"B`@("`@
M("1V7V)L;V-K(#T@;G5L;#L-"B`@("`@(&EF("AI<U]R97-O=7)C92@D=&AI
M<RT^7V9I;&4I*2![#0H@("`@("`@("`@:68@*"1T:&ES+3Y?8V]M<')E<W-?
M='EP92`]/2`G9WHG*0T*("`@("`@("`@("`@("`D=E]B;&]C:R`]($!G>G)E
M860H)'1H:7,M/E]F:6QE+"`U,3(I.PT*("`@("`@("`@(&5L<V4@:68@*"1T
M:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G8GHR)RD-"B`@("`@("`@("`@("`@
M)'9?8FQO8VL@/2!`8GIR96%D*"1T:&ES+3Y?9FEL92P@-3$R*3L-"B`@("`@
M("`@("!E;'-E(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y<&4@/3T@)VYO;F4G
M*0T*("`@("`@("`@("`@("`D=E]B;&]C:R`]($!F<F5A9"@D=&AI<RT^7V9I
M;&4L(#4Q,BD[#0H@("`@("`@("`@96QS90T*("`@("`@("`@("`@("`D=&AI
M<RT^7V5R<F]R*"=5;FMN;W=N(&]R(&UI<W-I;F<@8V]M<')E<W-I;VX@='EP
M92`H)PT*"0D)("`@("`@("`@("`@("`@("XD=&AI<RT^7V-O;7!R97-S7W1Y
M<&4N)RDG*3L-"B`@("`@('T-"B`@("`@(')E='5R;B`D=E]B;&]C:SL-"B`@
M("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7VIU;7!";&]C:R@I#0H@
M("`@9G5N8W1I;VX@7VIU;7!";&]C:R@D<%]L96X];G5L;"D-"B`@("![#0H@
M("`@("!I9B`H:7-?<F5S;W5R8V4H)'1H:7,M/E]F:6QE*2D@>PT*("`@("`@
M("`@(&EF("@D<%]L96X@/3T](&YU;&PI#0H@("`@("`@("`@("`@("1P7VQE
M;B`](#$[#0H-"B`@("`@("`@("!I9B`H)'1H:7,M/E]C;VUP<F5S<U]T>7!E
M(#T]("=G>B<I('L-"B`@("`@("`@("`@("`@0&=Z<V5E:R@D=&AI<RT^7V9I
M;&4L($!G>G1E;&PH)'1H:7,M/E]F:6QE*2LH)'!?;&5N*C4Q,BDI.PT*("`@
M("`@("`@('T-"B`@("`@("`@("!E;'-E(&EF("@D=&AI<RT^7V-O;7!R97-S
M7W1Y<&4@/3T@)V)Z,B<I('L-"B`@("`@("`@("`@("`@+R\@+2TM+2T@4F5P
M;&%C92!M:7-S:6YG(&)Z=&5L;"@I(&%N9"!B>G-E96LH*0T*("`@("`@("`@
M("`@("!F;W(@*"1I/3`[("1I/"1P7VQE;CL@)&DK*RD-"B`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<F5A9$)L;V-K*"D[#0H@("`@("`@("`@?2!E;'-E
M(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y<&4@/3T@)VYO;F4G*0T*("`@("`@
M("`@("`@("!`9G-E96LH)'1H:7,M/E]F:6QE+"!`9G1E;&PH)'1H:7,M/E]F
M:6QE*2LH)'!?;&5N*C4Q,BDI.PT*("`@("`@("`@(&5L<V4-"B`@("`@("`@
M("`@("`@)'1H:7,M/E]E<G)O<B@G56YK;F]W;B!O<B!M:7-S:6YG(&-O;7!R
M97-S:6]N('1Y<&4@*"<-"@D)"2`@("`@("`@("`@("`@("`N)'1H:7,M/E]C
M;VUP<F5S<U]T>7!E+B<I)RD[#0H-"B`@("`@('T-"B`@("`@(')E='5R;B!T
M<G5E.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?=W)I=&5&
M;V]T97(H*0T*("`@(&9U;F-T:6]N(%]W<FET949O;W1E<B@I#0H@("`@>PT*
M("`@("`@:68@*&ES7W)E<V]U<F-E*"1T:&ES+3Y?9FEL92DI('L-"B`@("`@
M("`@("`O+R`M+2TM+2!7<FET92!T:&4@;&%S="`P(&9I;&QE9"!B;&]C:R!F
M;W(@96YD(&]F(&%R8VAI=F4-"B`@("`@("`@("`D=E]B:6YA<GE?9&%T82`]
M('!A8VLH(F$U,3(B+"`G)RD[#0H@("`@("`@("`@)'1H:7,M/E]W<FET94)L
M;V-K*"1V7V)I;F%R>5]D871A*3L-"B`@("`@('T-"B`@("`@(')E='5R;B!T
M<G5E.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?861D3&ES
M="@I#0H@("`@9G5N8W1I;VX@7V%D9$QI<W0H)'!?;&ES="P@)'!?861D7V1I
M<BP@)'!?<F5M;W9E7V1I<BD-"B`@("![#0H@("`@("`D=E]R97-U;'0]=')U
M93L-"B`@("`@("1V7VAE861E<B`](&%R<F%Y*"D[#0H-"B`@("`@("\O("TM
M+2TM(%)E;6]V92!P;W1E;G1I86P@=VEN9&]W<R!D:7)E8W1O<GD@<V5P87)A
M=&]R#0H@("`@("`D<%]A9&1?9&ER(#T@)'1H:7,M/E]T<F%N<VQA=&57:6Y0
M871H*"1P7V%D9%]D:7(I.PT*("`@("`@)'!?<F5M;W9E7V1I<B`]("1T:&ES
M+3Y?=')A;G-L871E5VEN4&%T:"@D<%]R96UO=F5?9&ER+"!F86QS92D[#0H-
M"B`@("`@(&EF("@A)'1H:7,M/E]F:6QE*2![#0H@("`@("`@("`@)'1H:7,M
M/E]E<G)O<B@G26YV86QI9"!F:6QE(&1E<V-R:7!T;W(G*3L-"B`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("!]#0H-"B`@("`@(&EF("AS:7IE;V8H
M)'!?;&ES="D@/3T@,"D-"B`@("`@("`@("!R971U<FX@=')U93L-"@T*("`@
M("`@9F]R96%C:"`H)'!?;&ES="!A<R`D=E]F:6QE;F%M92D@>PT*("`@("`@
M("`@(&EF("@A)'9?<F5S=6QT*2![#0H@("`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("`@('T-"@T*("`@("`@("`O+R`M+2TM+2!3:VEP('1H92!C=7)R
M96YT('1A<B!N86UE#0H@("`@("`@(&EF("@D=E]F:6QE;F%M92`]/2`D=&AI
M<RT^7W1A<FYA;64I#0H@("`@("`@("`@("!C;VYT:6YU93L-"@T*("`@("`@
M("!I9B`H)'9?9FEL96YA;64@/3T@)R<I#0H@("`@("`@("`@("!C;VYT:6YU
M93L-"@T*("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1V7V9I;&5N86UE*2D@
M>PT*("`@("`@("`@("`@)'1H:7,M/E]W87)N:6YG*")&:6QE("<D=E]F:6QE
M;F%M92<@9&]E<R!N;W0@97AI<W0B*3L-"B`@("`@("`@("`@(&-O;G1I;G5E
M.PT*("`@("`@("!]#0H-"B`@("`@("`@+R\@+2TM+2T@061D('1H92!F:6QE
M(&]R(&1I<F5C=&]R>2!H96%D97(-"B`@("`@("`@:68@*"$D=&AI<RT^7V%D
M9$9I;&4H)'9?9FEL96YA;64L("1V7VAE861E<BP@)'!?861D7V1I<BP@)'!?
M<F5M;W9E7V1I<BDI#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H-"B`@
M("`@("`@:68@*$!I<U]D:7(H)'9?9FEL96YA;64I*2![#0H@("`@("`@("`@
M("!I9B`H(2@D<%]H9&ER(#T@;W!E;F1I<B@D=E]F:6QE;F%M92DI*2![#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/E]W87)N:6YG*")$:7)E8W1O<GD@)R1V
M7V9I;&5N86UE)R!C86X@;F]T(&)E(')E860B*3L-"B`@("`@("`@("`@("`@
M("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@('=H:6QE
M("AF86QS92`A/3T@*"1P7VAI=&5M(#T@<F5A9&1I<B@D<%]H9&ER*2DI('L-
M"B`@("`@("`@("`@("`@("!I9B`H*"1P7VAI=&5M("$]("<N)RD@)B8@*"1P
M7VAI=&5M("$]("<N+B<I*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@D
M=E]F:6QE;F%M92`A/2`B+B(I#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M<%]T96UP7VQI<W1;,%T@/2`D=E]F:6QE;F%M92XG+R<N)'!?:&ET96T[#0H@
M("`@("`@("`@("`@("`@("`@(&5L<V4-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1P7W1E;7!?;&ES=%LP72`]("1P7VAI=&5M.PT*#0H@("`@("`@("`@
M("`@("`@("`@("1V7W)E<W5L="`]("1T:&ES+3Y?861D3&ES="@D<%]T96UP
M7VQI<W0L#0H)"0D)"2`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<%]A
M9&1?9&ER+`T*"0D)"0D)"0D)"0D))'!?<F5M;W9E7V1I<BD[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("!U;G-E
M="@D<%]T96UP7VQI<W0I.PT*("`@("`@("`@("`@=6YS970H)'!?:&1I<BD[
M#0H@("`@("`@("`@("!U;G-E="@D<%]H:71E;2D[#0H@("`@("`@('T-"B`@
M("`@('T-"@T*("`@("`@<F5T=7)N("1V7W)E<W5L=#L-"B`@("!]#0H@("`@
M+R\@?7U]#0H-"B`@("`O+R![>WL@7V%D9$9I;&4H*0T*("`@(&9U;F-T:6]N
M(%]A9&1&:6QE*"1P7V9I;&5N86UE+"`F)'!?:&5A9&5R+"`D<%]A9&1?9&ER
M+"`D<%]R96UO=F5?9&ER*0T*("`@('L-"B`@("`@(&EF("@A)'1H:7,M/E]F
M:6QE*2![#0H@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G26YV86QI9"!F:6QE
M(&1E<V-R:7!T;W(G*3L-"B`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("!]#0H-"B`@("`@(&EF("@D<%]F:6QE;F%M92`]/2`G)RD@>PT*("`@("`@
M("`@("1T:&ES+3Y?97)R;W(H)TEN=F%L:60@9FEL92!N86UE)RD[#0H@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@?0T*#0H@("`@("`O+R`M+2TM
M+2!#86QC=6QA=&4@=&AE('-T;W)E9"!F:6QE;F%M90T*("`@("`@)'!?9FEL
M96YA;64@/2`D=&AI<RT^7W1R86YS;&%T95=I;E!A=&@H)'!?9FEL96YA;64L
M(&9A;'-E*3L[#0H@("`@("`D=E]S=&]R961?9FEL96YA;64@/2`D<%]F:6QE
M;F%M93L-"B`@("`@(&EF("AS=')C;7`H)'!?9FEL96YA;64L("1P7W)E;6]V
M95]D:7(I(#T](#`I('L-"B`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@
M('T-"B`@("`@(&EF("@D<%]R96UO=F5?9&ER("$]("<G*2![#0H@("`@("`@
M("`@:68@*'-U8G-T<B@D<%]R96UO=F5?9&ER+"`M,2D@(3T@)R\G*0T*("`@
M("`@("`@("`@("`D<%]R96UO=F5?9&ER("X]("<O)SL-"@T*("`@("`@("`@
M(&EF("AS=6)S='(H)'!?9FEL96YA;64L(#`L('-T<FQE;B@D<%]R96UO=F5?
M9&ER*2D@/3T@)'!?<F5M;W9E7V1I<BD-"B`@("`@("`@("`@("`@)'9?<W1O
M<F5D7V9I;&5N86UE(#T@<W5B<W1R*"1P7V9I;&5N86UE+"!S=')L96XH)'!?
M<F5M;W9E7V1I<BDI.PT*("`@("`@?0T*("`@("`@)'9?<W1O<F5D7V9I;&5N
M86UE(#T@)'1H:7,M/E]T<F%N<VQA=&57:6Y0871H*"1V7W-T;W)E9%]F:6QE
M;F%M92D[#0H@("`@("!I9B`H)'!?861D7V1I<B`A/2`G)RD@>PT*("`@("`@
M("`@(&EF("AS=6)S='(H)'!?861D7V1I<BP@+3$I(#T]("<O)RD-"B`@("`@
M("`@("`@("`@)'9?<W1O<F5D7V9I;&5N86UE(#T@)'!?861D7V1I<BXD=E]S
M=&]R961?9FEL96YA;64[#0H@("`@("`@("`@96QS90T*("`@("`@("`@("`@
M("`D=E]S=&]R961?9FEL96YA;64@/2`D<%]A9&1?9&ER+B<O)RXD=E]S=&]R
M961?9FEL96YA;64[#0H@("`@("!]#0H-"B`@("`@("1V7W-T;W)E9%]F:6QE
M;F%M92`]("1T:&ES+3Y?<&%T:%)E9'5C=&EO;B@D=E]S=&]R961?9FEL96YA
M;64I.PT*#0H@("`@("!I9B`H)'1H:7,M/E]I<T%R8VAI=F4H)'!?9FEL96YA
M;64I*2![#0H@("`@("`@("`@:68@*"@D=E]F:6QE(#T@0&9O<&5N*"1P7V9I
M;&5N86UE+"`B<F(B*2D@/3T@,"D@>PT*("`@("`@("`@("`@("`D=&AI<RT^
M7W=A<FYI;F<H(E5N86)L92!T;R!O<&5N(&9I;&4@)R(N)'!?9FEL96YA;64-
M"@D)"2`@("`@("`@("`@("`@("`@("XB)R!I;B!B:6YA<GD@<F5A9"!M;V1E
M(BD[#0H@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@('T-
M"@T*("`@("`@("`@(&EF("@A)'1H:7,M/E]W<FET94AE861E<B@D<%]F:6QE
M;F%M92P@)'9?<W1O<F5D7V9I;&5N86UE*2D-"B`@("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*#0H@("`@("`@("`@=VAI;&4@*"@D=E]B=69F97(@/2!F
M<F5A9"@D=E]F:6QE+"`U,3(I*2`A/2`G)RD@>PT*("`@("`@("`@("`@("`D
M=E]B:6YA<GE?9&%T82`]('!A8VLH(F$U,3(B+"`B)'9?8G5F9F5R(BD[#0H@
M("`@("`@("`@("`@("1T:&ES+3Y?=W)I=&5";&]C:R@D=E]B:6YA<GE?9&%T
M82D[#0H@("`@("`@("`@?0T*#0H@("`@("`@("`@9F-L;W-E*"1V7V9I;&4I
M.PT*#0H@("`@("!](&5L<V4@>PT*("`@("`@("`@("\O("TM+2TM($]N;'D@
M:&5A9&5R(&9O<B!D:7(-"B`@("`@("`@("!I9B`H(21T:&ES+3Y?=W)I=&5(
M96%D97(H)'!?9FEL96YA;64L("1V7W-T;W)E9%]F:6QE;F%M92DI#0H@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@('T-"@T*("`@("`@<F5T
M=7)N('1R=64[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]A
M9&13=')I;F<H*0T*("`@(&9U;F-T:6]N(%]A9&13=')I;F<H)'!?9FEL96YA
M;64L("1P7W-T<FEN9RD-"B`@("![#0H@("`@("!I9B`H(21T:&ES+3Y?9FEL
M92D@>PT*("`@("`@("`@("1T:&ES+3Y?97)R;W(H)TEN=F%L:60@9FEL92!D
M97-C<FEP=&]R)RD[#0H@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@
M?0T*#0H@("`@("!I9B`H)'!?9FEL96YA;64@/3T@)R<I('L-"B`@("`@("`@
M("`D=&AI<RT^7V5R<F]R*"=);G9A;&ED(&9I;&4@;F%M92<I.PT*("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@('T-"@T*("`@("`@+R\@+2TM+2T@
M0V%L8W5L871E('1H92!S=&]R960@9FEL96YA;64-"B`@("`@("1P7V9I;&5N
M86UE(#T@)'1H:7,M/E]T<F%N<VQA=&57:6Y0871H*"1P7V9I;&5N86UE+"!F
M86QS92D[.PT*#0H@("`@("!I9B`H(21T:&ES+3Y?=W)I=&5(96%D97)";&]C
M:R@D<%]F:6QE;F%M92P@<W1R;&5N*"1P7W-T<FEN9RDL#0H)("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`P+"`P+"`B(BP@,"P@,"DI#0H@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*#0H@("`@("`D:3TP.PT*("`@("`@=VAI
M;&4@*"@D=E]B=69F97(@/2!S=6)S='(H)'!?<W1R:6YG+"`H*"1I*RLI*C4Q
M,BDL(#4Q,BDI("$]("<G*2![#0H@("`@("`@("`@)'9?8FEN87)Y7V1A=&$@
M/2!P86-K*")A-3$R(BP@)'9?8G5F9F5R*3L-"B`@("`@("`@("`D=&AI<RT^
M7W=R:71E0FQO8VLH)'9?8FEN87)Y7V1A=&$I.PT*("`@("`@?0T*#0H@("`@
M("!R971U<FX@=')U93L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![
M>WL@7W=R:71E2&5A9&5R*"D-"B`@("!F=6YC=&EO;B!?=W)I=&5(96%D97(H
M)'!?9FEL96YA;64L("1P7W-T;W)E9%]F:6QE;F%M92D-"B`@("![#0H@("`@
M("`@(&EF("@D<%]S=&]R961?9FEL96YA;64@/3T@)R<I#0H@("`@("`@("`@
M("`D<%]S=&]R961?9FEL96YA;64@/2`D<%]F:6QE;F%M93L-"B`@("`@("`@
M)'9?<F5D=6-E7V9I;&5N86UE(#T@)'1H:7,M/E]P871H4F5D=6-T:6]N*"1P
M7W-T;W)E9%]F:6QE;F%M92D[#0H-"B`@("`@("`@:68@*'-T<FQE;B@D=E]R
M961U8V5?9FEL96YA;64I(#X@.3DI('L-"B`@("`@("`@("!I9B`H(21T:&ES
M+3Y?=W)I=&5,;VYG2&5A9&5R*"1V7W)E9'5C95]F:6QE;F%M92DI#0H@("`@
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"@T*("`@("`@("`D
M=E]I;F9O(#T@<W1A="@D<%]F:6QE;F%M92D[#0H@("`@("`@("1V7W5I9"`]
M('-P<FEN=&8H(B4V<R`B+"!$96-/8W0H)'9?:6YF;ULT72DI.PT*("`@("`@
M("`D=E]G:60@/2!S<')I;G1F*"(E-G,@(BP@1&5C3V-T*"1V7VEN9F];-5TI
M*3L-"B`@("`@("`@)'9?<&5R;7,@/2!S<')I;G1F*"(E-G,@(BP@1&5C3V-T
M*&9I;&5P97)M<R@D<%]F:6QE;F%M92DI*3L-"@T*("`@("`@("`D=E]M=&EM
M92`]('-P<FEN=&8H(B4Q,7,B+"!$96-/8W0H9FEL96UT:6UE*"1P7V9I;&5N
M86UE*2DI.PT*#0H@("`@("`@(&EF("A`:7-?9&ER*"1P7V9I;&5N86UE*2D@
M>PT*("`@("`@("`@("1V7W1Y<&5F;&%G(#T@(C4B.PT*("`@("`@("`@("1V
M7W-I>F4@/2!S<')I;G1F*"(E,3%S("(L($1E8T]C="@P*2D[#0H@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@)'9?='EP969L86<@/2`G)SL-"B`@("`@
M("`@("!C;&5A<G-T871C86-H92@I.PT*("`@("`@("`@("1V7W-I>F4@/2!S
M<')I;G1F*"(E,3%S("(L($1E8T]C="AF:6QE<VEZ92@D<%]F:6QE;F%M92DI
M*3L-"B`@("`@("`@?0T*#0H@("`@("`@("1V7VQI;FMN86UE(#T@)R<[#0H-
M"B`@("`@("`@)'9?;6%G:6,@/2`G)SL-"@T*("`@("`@("`D=E]V97)S:6]N
M(#T@)R<[#0H-"B`@("`@("`@)'9?=6YA;64@/2`G)SL-"@T*("`@("`@("`D
M=E]G;F%M92`]("<G.PT*#0H@("`@("`@("1V7V1E=FUA:F]R(#T@)R<[#0H-
M"B`@("`@("`@)'9?9&5V;6EN;W(@/2`G)SL-"@T*("`@("`@("`D=E]P<F5F
M:7@@/2`G)SL-"@T*("`@("`@("`D=E]B:6YA<GE?9&%T85]F:7)S="`]('!A
M8VLH(F$Q,#!A.&$X83AA,3)!,3(B+`T*"0D@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'9?<F5D=6-E7V9I;&5N86UE+"`D=E]P97)M<RP@)'9?=6ED
M+`T*"0D)"0D)"0D))'9?9VED+"`D=E]S:7IE+"`D=E]M=&EM92D[#0H@("`@
M("`@("1V7V)I;F%R>5]D871A7VQA<W0@/2!P86-K*")A,6$Q,#!A-F$R83,R
M83,R83AA.&$Q-35A,3(B+`T*"0D@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=E]T>7!E9FQA9RP@)'9?;&EN:VYA;64L("1V7VUA9VEC+`T*"0D)"0D)
M"0D@("`D=E]V97)S:6]N+"`D=E]U;F%M92P@)'9?9VYA;64L#0H)"0D)"0D)
M"2`@("1V7V1E=FUA:F]R+"`D=E]D979M:6YO<BP@)'9?<')E9FEX+"`G)RD[
M#0H-"B`@("`@("`@+R\@+2TM+2T@0V%L8W5L871E('1H92!C:&5C:W-U;0T*
M("`@("`@("`D=E]C:&5C:W-U;2`](#`[#0H@("`@("`@("\O("XN+BXN($9I
M<G-T('!A<G0@;V8@=&AE(&AE861E<@T*("`@("`@("!F;W(@*"1I/3`[("1I
M/#$T.#L@)&DK*RD-"B`@("`@("`@("`@("1V7V-H96-K<W5M("L](&]R9"AS
M=6)S='(H)'9?8FEN87)Y7V1A=&%?9FER<W0L)&DL,2DI.PT*("`@("`@("`O
M+R`N+BXN+B!)9VYO<F4@=&AE(&-H96-K<W5M('9A;'5E(&%N9"!R97!L86-E
M(&ET(&)Y("<@)R`H<W!A8V4I#0H@("`@("`@(&9O<B`H)&D],30X.R`D:3PQ
M-38[("1I*RLI#0H@("`@("`@("`@("`D=E]C:&5C:W-U;2`K/2!O<F0H)R`G
M*3L-"B`@("`@("`@+R\@+BXN+BX@3&%S="!P87)T(&]F('1H92!H96%D97(-
M"B`@("`@("`@9F]R("@D:3TQ-38L("1J/3`[("1I/#4Q,CL@)&DK*RP@)&HK
M*RD-"B`@("`@("`@("`@("1V7V-H96-K<W5M("L](&]R9"AS=6)S='(H)'9?
M8FEN87)Y7V1A=&%?;&%S="PD:BPQ*2D[#0H-"B`@("`@("`@+R\@+2TM+2T@
M5W)I=&4@=&AE(&9I<G-T(#$T."!B>71E<R!O9B!T:&4@:&5A9&5R(&EN('1H
M92!A<F-H:79E#0H@("`@("`@("1T:&ES+3Y?=W)I=&5";&]C:R@D=E]B:6YA
M<GE?9&%T85]F:7)S="P@,30X*3L-"@T*("`@("`@("`O+R`M+2TM+2!7<FET
M92!T:&4@8V%L8W5L871E9"!C:&5C:W-U;0T*("`@("`@("`D=E]C:&5C:W-U
M;2`]('-P<FEN=&8H(B4V<R`B+"!$96-/8W0H)'9?8VAE8VMS=6TI*3L-"B`@
M("`@("`@)'9?8FEN87)Y7V1A=&$@/2!P86-K*")A."(L("1V7V-H96-K<W5M
M*3L-"B`@("`@("`@)'1H:7,M/E]W<FET94)L;V-K*"1V7V)I;F%R>5]D871A
M+"`X*3L-"@T*("`@("`@("`O+R`M+2TM+2!7<FET92!T:&4@;&%S="`S-38@
M8GET97,@;V8@=&AE(&AE861E<B!I;B!T:&4@87)C:&EV90T*("`@("`@("`D
M=&AI<RT^7W=R:71E0FQO8VLH)'9?8FEN87)Y7V1A=&%?;&%S="P@,S4V*3L-
M"@T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H@("`@+R\@?7U]#0H-
M"B`@("`O+R![>WL@7W=R:71E2&5A9&5R0FQO8VLH*0T*("`@(&9U;F-T:6]N
M(%]W<FET94AE861E<D)L;V-K*"1P7V9I;&5N86UE+"`D<%]S:7IE+"`D<%]M
M=&EM93TP+"`D<%]P97)M<STP+`T*"2`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P7W1Y<&4])R<L("1P7W5I9#TP+"`D<%]G:60],"D-"B`@("![#0H@
M("`@("`@("1P7V9I;&5N86UE(#T@)'1H:7,M/E]P871H4F5D=6-T:6]N*"1P
M7V9I;&5N86UE*3L-"@T*("`@("`@("!I9B`H<W1R;&5N*"1P7V9I;&5N86UE
M*2`^(#DY*2![#0H@("`@("`@("`@:68@*"$D=&AI<RT^7W=R:71E3&]N9TAE
M861E<B@D<%]F:6QE;F%M92DI#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H)'!?='EP92`]/2`B-2(I('L-
M"B`@("`@("`@("`D=E]S:7IE(#T@<W!R:6YT9B@B)3$Q<R`B+"!$96-/8W0H
M,"DI.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("1V7W-I>F4@/2!S
M<')I;G1F*"(E,3%S("(L($1E8T]C="@D<%]S:7IE*2D[#0H@("`@("`@('T-
M"@T*("`@("`@("`D=E]U:60@/2!S<')I;G1F*"(E-G,@(BP@1&5C3V-T*"1P
M7W5I9"DI.PT*("`@("`@("`D=E]G:60@/2!S<')I;G1F*"(E-G,@(BP@1&5C
M3V-T*"1P7V=I9"DI.PT*("`@("`@("`D=E]P97)M<R`]('-P<FEN=&8H(B4V
M<R`B+"!$96-/8W0H)'!?<&5R;7,I*3L-"@T*("`@("`@("`D=E]M=&EM92`]
M('-P<FEN=&8H(B4Q,7,B+"!$96-/8W0H)'!?;71I;64I*3L-"@T*("`@("`@
M("`D=E]L:6YK;F%M92`]("<G.PT*#0H@("`@("`@("1V7VUA9VEC(#T@)R<[
M#0H-"B`@("`@("`@)'9?=F5R<VEO;B`]("<G.PT*#0H@("`@("`@("1V7W5N
M86UE(#T@)R<[#0H-"B`@("`@("`@)'9?9VYA;64@/2`G)SL-"@T*("`@("`@
M("`D=E]D979M86IO<B`]("<G.PT*#0H@("`@("`@("1V7V1E=FUI;F]R(#T@
M)R<[#0H-"B`@("`@("`@)'9?<')E9FEX(#T@)R<[#0H-"B`@("`@("`@)'9?
M8FEN87)Y7V1A=&%?9FER<W0@/2!P86-K*")A,3`P83AA.&$X83$R03$R(BP-
M"@D)("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P7V9I;&5N86UE+"`D
M=E]P97)M<RP@)'9?=6ED+"`D=E]G:60L#0H)"0D)"0D)"0DD=E]S:7IE+"`D
M=E]M=&EM92D[#0H@("`@("`@("1V7V)I;F%R>5]D871A7VQA<W0@/2!P86-K
M*")A,6$Q,#!A-F$R83,R83,R83AA.&$Q-35A,3(B+`T*"0D@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<%]T>7!E+"`D=E]L:6YK;F%M92P@)'9?;6%G
M:6,L#0H)"0D)"0D)"2`@("1V7W9E<G-I;VXL("1V7W5N86UE+"`D=E]G;F%M
M92P-"@D)"0D)"0D)("`@)'9?9&5V;6%J;W(L("1V7V1E=FUI;F]R+"`D=E]P
M<F5F:7@L("<G*3L-"@T*("`@("`@("`O+R`M+2TM+2!#86QC=6QA=&4@=&AE
M(&-H96-K<W5M#0H@("`@("`@("1V7V-H96-K<W5M(#T@,#L-"B`@("`@("`@
M+R\@+BXN+BX@1FER<W0@<&%R="!O9B!T:&4@:&5A9&5R#0H@("`@("`@(&9O
M<B`H)&D],#L@)&D\,30X.R`D:2LK*0T*("`@("`@("`@("`@)'9?8VAE8VMS
M=6T@*ST@;W)D*'-U8G-T<B@D=E]B:6YA<GE?9&%T85]F:7)S="PD:2PQ*2D[
M#0H@("`@("`@("\O("XN+BXN($EG;F]R92!T:&4@8VAE8VMS=6T@=F%L=64@
M86YD(')E<&QA8V4@:70@8GD@)R`G("AS<&%C92D-"B`@("`@("`@9F]R("@D
M:3TQ-#@[("1I/#$U-CL@)&DK*RD-"B`@("`@("`@("`@("1V7V-H96-K<W5M
M("L](&]R9"@G("<I.PT*("`@("`@("`O+R`N+BXN+B!,87-T('!A<G0@;V8@
M=&AE(&AE861E<@T*("`@("`@("!F;W(@*"1I/3$U-BP@)&H],#L@)&D\-3$R
M.R`D:2LK+"`D:BLK*0T*("`@("`@("`@("`@)'9?8VAE8VMS=6T@*ST@;W)D
M*'-U8G-T<B@D=E]B:6YA<GE?9&%T85]L87-T+"1J+#$I*3L-"@T*("`@("`@
M("`O+R`M+2TM+2!7<FET92!T:&4@9FER<W0@,30X(&)Y=&5S(&]F('1H92!H
M96%D97(@:6X@=&AE(&%R8VAI=F4-"B`@("`@("`@)'1H:7,M/E]W<FET94)L
M;V-K*"1V7V)I;F%R>5]D871A7V9I<G-T+"`Q-#@I.PT*#0H@("`@("`@("\O
M("TM+2TM(%=R:71E('1H92!C86QC=6QA=&5D(&-H96-K<W5M#0H@("`@("`@
M("1V7V-H96-K<W5M(#T@<W!R:6YT9B@B)39S("(L($1E8T]C="@D=E]C:&5C
M:W-U;2DI.PT*("`@("`@("`D=E]B:6YA<GE?9&%T82`]('!A8VLH(F$X(BP@
M)'9?8VAE8VMS=6TI.PT*("`@("`@("`D=&AI<RT^7W=R:71E0FQO8VLH)'9?
M8FEN87)Y7V1A=&$L(#@I.PT*#0H@("`@("`@("\O("TM+2TM(%=R:71E('1H
M92!L87-T(#,U-B!B>71E<R!O9B!T:&4@:&5A9&5R(&EN('1H92!A<F-H:79E
M#0H@("`@("`@("1T:&ES+3Y?=W)I=&5";&]C:R@D=E]B:6YA<GE?9&%T85]L
M87-T+"`S-38I.PT*#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"B`@
M("`O+R!]?7T-"@T*("`@("\O('M[>R!?=W)I=&5,;VYG2&5A9&5R*"D-"B`@
M("!F=6YC=&EO;B!?=W)I=&5,;VYG2&5A9&5R*"1P7V9I;&5N86UE*0T*("`@
M('L-"B`@("`@("`@)'9?<VEZ92`]('-P<FEN=&8H(B4Q,7,@(BP@1&5C3V-T
M*'-T<FQE;B@D<%]F:6QE;F%M92DI*3L-"@T*("`@("`@("`D=E]T>7!E9FQA
M9R`]("=,)SL-"@T*("`@("`@("`D=E]L:6YK;F%M92`]("<G.PT*#0H@("`@
M("`@("1V7VUA9VEC(#T@)R<[#0H-"B`@("`@("`@)'9?=F5R<VEO;B`]("<G
M.PT*#0H@("`@("`@("1V7W5N86UE(#T@)R<[#0H-"B`@("`@("`@)'9?9VYA
M;64@/2`G)SL-"@T*("`@("`@("`D=E]D979M86IO<B`]("<G.PT*#0H@("`@
M("`@("1V7V1E=FUI;F]R(#T@)R<[#0H-"B`@("`@("`@)'9?<')E9FEX(#T@
M)R<[#0H-"B`@("`@("`@)'9?8FEN87)Y7V1A=&%?9FER<W0@/2!P86-K*")A
M,3`P83AA.&$X83$R03$R(BP-"@D)("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("<N+RXO0$QO;F=,:6YK)RP@,"P@,"P@,"P@)'9?<VEZ92P@,"D[#0H@
M("`@("`@("1V7V)I;F%R>5]D871A7VQA<W0@/2!P86-K*")A,6$Q,#!A-F$R
M83,R83,R83AA.&$Q-35A,3(B+`T*"0D@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=E]T>7!E9FQA9RP@)'9?;&EN:VYA;64L("1V7VUA9VEC+`T*"0D)
M"0D)"0D@("`D=E]V97)S:6]N+"`D=E]U;F%M92P@)'9?9VYA;64L#0H)"0D)
M"0D)"2`@("1V7V1E=FUA:F]R+"`D=E]D979M:6YO<BP@)'9?<')E9FEX+"`G
M)RD[#0H-"B`@("`@("`@+R\@+2TM+2T@0V%L8W5L871E('1H92!C:&5C:W-U
M;0T*("`@("`@("`D=E]C:&5C:W-U;2`](#`[#0H@("`@("`@("\O("XN+BXN
M($9I<G-T('!A<G0@;V8@=&AE(&AE861E<@T*("`@("`@("!F;W(@*"1I/3`[
M("1I/#$T.#L@)&DK*RD-"B`@("`@("`@("`@("1V7V-H96-K<W5M("L](&]R
M9"AS=6)S='(H)'9?8FEN87)Y7V1A=&%?9FER<W0L)&DL,2DI.PT*("`@("`@
M("`O+R`N+BXN+B!)9VYO<F4@=&AE(&-H96-K<W5M('9A;'5E(&%N9"!R97!L
M86-E(&ET(&)Y("<@)R`H<W!A8V4I#0H@("`@("`@(&9O<B`H)&D],30X.R`D
M:3PQ-38[("1I*RLI#0H@("`@("`@("`@("`D=E]C:&5C:W-U;2`K/2!O<F0H
M)R`G*3L-"B`@("`@("`@+R\@+BXN+BX@3&%S="!P87)T(&]F('1H92!H96%D
M97(-"B`@("`@("`@9F]R("@D:3TQ-38L("1J/3`[("1I/#4Q,CL@)&DK*RP@
M)&HK*RD-"B`@("`@("`@("`@("1V7V-H96-K<W5M("L](&]R9"AS=6)S='(H
M)'9?8FEN87)Y7V1A=&%?;&%S="PD:BPQ*2D[#0H-"B`@("`@("`@+R\@+2TM
M+2T@5W)I=&4@=&AE(&9I<G-T(#$T."!B>71E<R!O9B!T:&4@:&5A9&5R(&EN
M('1H92!A<F-H:79E#0H@("`@("`@("1T:&ES+3Y?=W)I=&5";&]C:R@D=E]B
M:6YA<GE?9&%T85]F:7)S="P@,30X*3L-"@T*("`@("`@("`O+R`M+2TM+2!7
M<FET92!T:&4@8V%L8W5L871E9"!C:&5C:W-U;0T*("`@("`@("`D=E]C:&5C
M:W-U;2`]('-P<FEN=&8H(B4V<R`B+"!$96-/8W0H)'9?8VAE8VMS=6TI*3L-
M"B`@("`@("`@)'9?8FEN87)Y7V1A=&$@/2!P86-K*")A."(L("1V7V-H96-K
M<W5M*3L-"B`@("`@("`@)'1H:7,M/E]W<FET94)L;V-K*"1V7V)I;F%R>5]D
M871A+"`X*3L-"@T*("`@("`@("`O+R`M+2TM+2!7<FET92!T:&4@;&%S="`S
M-38@8GET97,@;V8@=&AE(&AE861E<B!I;B!T:&4@87)C:&EV90T*("`@("`@
M("`D=&AI<RT^7W=R:71E0FQO8VLH)'9?8FEN87)Y7V1A=&%?;&%S="P@,S4V
M*3L-"@T*("`@("`@("`O+R`M+2TM+2!7<FET92!T:&4@9FEL96YA;64@87,@
M8V]N=&5N="!O9B!T:&4@8FQO8VL-"B`@("`@("`@)&D],#L-"B`@("`@("`@
M=VAI;&4@*"@D=E]B=69F97(@/2!S=6)S='(H)'!?9FEL96YA;64L("@H)&DK
M*RDJ-3$R*2P@-3$R*2D@(3T@)R<I('L-"B`@("`@("`@("`@("1V7V)I;F%R
M>5]D871A(#T@<&%C:R@B834Q,B(L("(D=E]B=69F97(B*3L-"B`@("`@("`@
M("`@("1T:&ES+3Y?=W)I=&5";&]C:R@D=E]B:6YA<GE?9&%T82D[#0H@("`@
M("`@('T-"@T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H@("`@+R\@
M?7U]#0H-"B`@("`O+R![>WL@7W)E861(96%D97(H*0T*("`@(&9U;F-T:6]N
M(%]R96%D2&5A9&5R*"1V7V)I;F%R>5]D871A+"`F)'9?:&5A9&5R*0T*("`@
M('L-"B`@("`@("`@:68@*'-T<FQE;B@D=E]B:6YA<GE?9&%T82D]/3`I('L-
M"B`@("`@("`@("`@("1V7VAE861E<ELG9FEL96YA;64G72`]("<G.PT*("`@
M("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"@T*("`@("`@("!I
M9B`H<W1R;&5N*"1V7V)I;F%R>5]D871A*2`A/2`U,3(I('L-"B`@("`@("`@
M("`@("1V7VAE861E<ELG9FEL96YA;64G72`]("<G.PT*("`@("`@("`@("`@
M)'1H:7,M/E]E<G)O<B@G26YV86QI9"!B;&]C:R!S:7IE(#H@)RYS=')L96XH
M)'9?8FEN87)Y7V1A=&$I*3L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@?0T*#0H@("`@("`@("\O("TM+2TM($-A;&-U;&%T92!T:&4@
M8VAE8VMS=6T-"B`@("`@("`@)'9?8VAE8VMS=6T@/2`P.PT*("`@("`@("`O
M+R`N+BXN+B!&:7)S="!P87)T(&]F('1H92!H96%D97(-"B`@("`@("`@9F]R
M("@D:3TP.R`D:3PQ-#@[("1I*RLI#0H@("`@("`@("`@("`D=E]C:&5C:W-U
M;2L];W)D*'-U8G-T<B@D=E]B:6YA<GE?9&%T82PD:2PQ*2D[#0H@("`@("`@
M("\O("XN+BXN($EG;F]R92!T:&4@8VAE8VMS=6T@=F%L=64@86YD(')E<&QA
M8V4@:70@8GD@)R`G("AS<&%C92D-"B`@("`@("`@9F]R("@D:3TQ-#@[("1I
M/#$U-CL@)&DK*RD-"B`@("`@("`@("`@("1V7V-H96-K<W5M("L](&]R9"@G
M("<I.PT*("`@("`@("`O+R`N+BXN+B!,87-T('!A<G0@;V8@=&AE(&AE861E
M<@T*("`@("`@("!F;W(@*"1I/3$U-CL@)&D\-3$R.R`D:2LK*0T*("`@("`@
M("`@("`D=E]C:&5C:W-U;2L];W)D*'-U8G-T<B@D=E]B:6YA<GE?9&%T82PD
M:2PQ*2D[#0H-"B`@("`@("`@)'9?9&%T82`]('5N<&%C:R@B83$P,&9I;&5N
M86UE+V$X;6]D92]A.'5I9"]A.&=I9"]A,3)S:7IE+V$Q,FUT:6UE+R(-"@D)
M("`@("`@("`@("`@("`@("`N(F$X8VAE8VMS=6TO83%T>7!E9FQA9R]A,3`P
M;&EN:R]A-FUA9VEC+V$R=F5R<VEO;B\B#0H)"0D)"0D@+B)A,S)U;F%M92]A
M,S)G;F%M92]A.&1E=FUA:F]R+V$X9&5V;6EN;W(B+`T*"0D)"0D)("1V7V)I
M;F%R>5]D871A*3L-"@T*("`@("`@("`O+R`M+2TM+2!%>'1R86-T('1H92!C
M:&5C:W-U;0T*("`@("`@("`D=E]H96%D97);)V-H96-K<W5M)UT@/2!/8W1$
M96,H=')I;2@D=E]D871A6R=C:&5C:W-U;2==*2D[#0H@("`@("`@(&EF("@D
M=E]H96%D97);)V-H96-K<W5M)UT@(3T@)'9?8VAE8VMS=6TI('L-"B`@("`@
M("`@("`@("1V7VAE861E<ELG9FEL96YA;64G72`]("<G.PT*#0H@("`@("`@
M("`@("`O+R`M+2TM+2!,;V]K(&9O<B!L87-T(&)L;V-K("AE;7!T>2!B;&]C
M:RD-"B`@("`@("`@("`@(&EF("@H)'9?8VAE8VMS=6T@/3T@,C4V*2`F)B`H
M)'9?:&5A9&5R6R=C:&5C:W-U;2==(#T](#`I*0T*("`@("`@("`@("`@("`@
M(')E='5R;B!T<G5E.PT*#0H@("`@("`@("`@("`D=&AI<RT^7V5R<F]R*"=)
M;G9A;&ED(&-H96-K<W5M(&9O<B!F:6QE("(G+B1V7V1A=&%;)V9I;&5N86UE
M)UT-"@D)"2`@("`@("`@("`@("`@+B<B(#H@)RXD=E]C:&5C:W-U;2XG(&-A
M;&-U;&%T960L("<-"@D)"0D)"2`@+B1V7VAE861E<ELG8VAE8VMS=6TG72XG
M(&5X<&5C=&5D)RD[#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@('T-"@T*("`@("`@("`O+R`M+2TM+2!%>'1R86-T('1H92!P<F]P97)T
M:65S#0H@("`@("`@("1V7VAE861E<ELG9FEL96YA;64G72`]('1R:6TH)'9?
M9&%T85LG9FEL96YA;64G72D[#0H@("`@("`@("1V7VAE861E<ELG;6]D92==
M(#T@3V-T1&5C*'1R:6TH)'9?9&%T85LG;6]D92==*2D[#0H@("`@("`@("1V
M7VAE861E<ELG=6ED)UT@/2!/8W1$96,H=')I;2@D=E]D871A6R=U:60G72DI
M.PT*("`@("`@("`D=E]H96%D97);)V=I9"==(#T@3V-T1&5C*'1R:6TH)'9?
M9&%T85LG9VED)UTI*3L-"B`@("`@("`@)'9?:&5A9&5R6R=S:7IE)UT@/2!/
M8W1$96,H=')I;2@D=E]D871A6R=S:7IE)UTI*3L-"B`@("`@("`@)'9?:&5A
M9&5R6R=M=&EM92==(#T@3V-T1&5C*'1R:6TH)'9?9&%T85LG;71I;64G72DI
M.PT*("`@("`@("!I9B`H*"1V7VAE861E<ELG='EP969L86<G72`]("1V7V1A
M=&%;)W1Y<&5F;&%G)UTI(#T]("(U(BD@>PT*("`@("`@("`@("1V7VAE861E
M<ELG<VEZ92==(#T@,#L-"B`@("`@("`@?0T*("`@("`@("`O*B`M+2TM+2!!
M;&P@=&AE<V4@9FEE;&1S(&%R92!R96UO=F5D(&9O<FT@=&AE(&AE861E<B!B
M96-A=7-E#0H)"71H97D@9&\@;F]T(&-A<G)Y(&EN=&5R97-T:6YG(&EN9F\-
M"B`@("`@("`@)'9?:&5A9&5R6VQI;FM=(#T@=')I;2@D=E]D871A6VQI;FM=
M*3L-"B`@("`@("`@)'9?:&5A9&5R6VUA9VEC72`]('1R:6TH)'9?9&%T85MM
M86=I8UTI.PT*("`@("`@("`D=E]H96%D97);=F5R<VEO;ET@/2!T<FEM*"1V
M7V1A=&%;=F5R<VEO;ETI.PT*("`@("`@("`D=E]H96%D97);=6YA;65=(#T@
M=')I;2@D=E]D871A6W5N86UE72D[#0H@("`@("`@("1V7VAE861E<EMG;F%M
M95T@/2!T<FEM*"1V7V1A=&%;9VYA;65=*3L-"B`@("`@("`@)'9?:&5A9&5R
M6V1E=FUA:F]R72`]('1R:6TH)'9?9&%T85MD979M86IO<ETI.PT*("`@("`@
M("`D=E]H96%D97);9&5V;6EN;W)=(#T@=')I;2@D=E]D871A6V1E=FUI;F]R
M72D[#0H@("`@("`@("HO#0H-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]R96%D3&]N9TAE861E<B@I
M#0H@("`@9G5N8W1I;VX@7W)E861,;VYG2&5A9&5R*"8D=E]H96%D97(I#0H@
M("`@>PT*("`@("`@)'9?9FEL96YA;64@/2`G)SL-"B`@("`@("1N(#T@9FQO
M;W(H)'9?:&5A9&5R6R=S:7IE)UTO-3$R*3L-"B`@("`@(&9O<B`H)&D],#L@
M)&D\)&X[("1I*RLI('L-"B`@("`@("`@)'9?8V]N=&5N="`]("1T:&ES+3Y?
M<F5A9$)L;V-K*"D[#0H@("`@("`@("1V7V9I;&5N86UE("X]("1V7V-O;G1E
M;G0[#0H@("`@("!]#0H@("`@("!I9B`H*"1V7VAE861E<ELG<VEZ92==("4@
M-3$R*2`A/2`P*2![#0H@("`@("`@("1V7V-O;G1E;G0@/2`D=&AI<RT^7W)E
M861";&]C:R@I.PT*("`@("`@("`D=E]F:6QE;F%M92`N/2`D=E]C;VYT96YT
M.PT*("`@("`@?0T*#0H@("`@("`O+R`M+2TM+2!296%D('1H92!N97AT(&AE
M861E<@T*("`@("`@)'9?8FEN87)Y7V1A=&$@/2`D=&AI<RT^7W)E861";&]C
M:R@I.PT*#0H@("`@("!I9B`H(21T:&ES+3Y?<F5A9$AE861E<B@D=E]B:6YA
M<GE?9&%T82P@)'9?:&5A9&5R*2D-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M#0H@("`@("`D=E]H96%D97);)V9I;&5N86UE)UT@/2`D=E]F:6QE;F%M93L-
M"@T*("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*("`@("\O('U]?0T*#0H@
M("`@+R\@>WM[(%]E>'1R86-T26Y3=')I;F<H*0T*("`@("\J*@T*("`@("H@
M5&AI<R!M971H;V0@97AT<F%C="!F<F]M('1H92!A<F-H:79E(&]N92!F:6QE
M(&ED96YT:69I960@8GD@)'!?9FEL96YA;64N#0H@("`@*B!4:&4@<F5T=7)N
M('9A;'5E(&ES(&$@<W1R:6YG('=I=&@@=&AE(&9I;&4@8V]N=&5N="P@;W(@
M3E5,3"!O;B!E<G)O<BX-"B`@("`J($!P87)A;2!S=')I;F<@)'!?9FEL96YA
M;64@("`@(%1H92!P871H(&]F('1H92!F:6QE('1O(&5X=')A8W0@:6X@82!S
M=')I;F<N#0H@("`@*B!`<F5T=7)N("`@("`@("`@("`@("`@("`@("`@("!A
M('-T<FEN9R!W:71H('1H92!F:6QE(&-O;G1E;G0@;W(@3E5,3"X-"B`@("`J
M($!A8V-E<W,@<')I=F%T90T*("`@("HO#0H@("`@9G5N8W1I;VX@7V5X=')A
M8W1);E-T<FEN9R@D<%]F:6QE;F%M92D-"B`@("![#0H@("`@("`@("1V7W)E
M<W5L=%]S='(@/2`B(CL-"@T*("`@("`@("!7:&EL92`H<W1R;&5N*"1V7V)I
M;F%R>5]D871A(#T@)'1H:7,M/E]R96%D0FQO8VLH*2D@(3T@,"D-"B`@("`@
M("`@>PT*("`@("`@("`@(&EF("@A)'1H:7,M/E]R96%D2&5A9&5R*"1V7V)I
M;F%R>5]D871A+"`D=E]H96%D97(I*0T*("`@("`@("`@("`@<F5T=7)N($Y5
M3$P[#0H-"B`@("`@("`@("!I9B`H)'9?:&5A9&5R6R=F:6QE;F%M92==(#T]
M("<G*0T*("`@("`@("`@("`@8V]N=&EN=64[#0H-"B`@("`@("`@("`O+R`M
M+2TM+2!,;V]K(&9O<B!L;VYG(&9I;&5N86UE#0H@("`@("`@("`@:68@*"1V
M7VAE861E<ELG='EP969L86<G72`]/2`G3"<I('L-"B`@("`@("`@("`@(&EF
M("@A)'1H:7,M/E]R96%D3&]N9TAE861E<B@D=E]H96%D97(I*0T*("`@("`@
M("`@("`@("!R971U<FX@3E5,3#L-"B`@("`@("`@("!]#0H-"B`@("`@("`@
M("!I9B`H)'9?:&5A9&5R6R=F:6QE;F%M92==(#T]("1P7V9I;&5N86UE*2![
M#0H@("`@("`@("`@("`@(&EF("@D=E]H96%D97);)W1Y<&5F;&%G)UT@/3T@
M(C4B*2![#0H@("`@("`@("`@("`@("`@("`D=&AI<RT^7V5R<F]R*"=5;F%B
M;&4@=&\@97AT<F%C="!I;B!S=')I;F<@82!D:7)E8W1O<GD@)PT*"0D)"2`@
M("`@("`@("`@("`@("`N)V5N=')Y('LG+B1V7VAE861E<ELG9FEL96YA;64G
M72XG?2<I.PT*("`@("`@("`@("`@("`@("`@<F5T=7)N($Y53$P[#0H@("`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`D;B`](&9L
M;V]R*"1V7VAE861E<ELG<VEZ92==+S4Q,BD[#0H@("`@("`@("`@("`@("`@
M("!F;W(@*"1I/3`[("1I/"1N.R`D:2LK*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@)'9?<F5S=6QT7W-T<B`N/2`D=&AI<RT^7W)E861";&]C:R@I.PT*
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@:68@*"@D
M=E]H96%D97);)W-I>F4G72`E(#4Q,BD@(3T@,"D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("1V7V-O;G1E;G0@/2`D=&AI<RT^7W)E861";&]C:R@I.PT*
M("`@("`@("`@("`@("`@("`@("`@("1V7W)E<W5L=%]S='(@+CT@<W5B<W1R
M*"1V7V-O;G1E;G0L(#`L#0H)"0D)"2`@("`@("`@("`@("`@("`@("`@("`@
M("`@*"1V7VAE861E<ELG<VEZ92==("4@-3$R*2D[#0H@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("!R971U<FX@)'9?<F5S=6QT7W-T
M<CL-"B`@("`@("`@("`@("`@?0T*("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("1T:&ES+3Y?:G5M<$)L;V-K*&-E:6PH*"1V7VAE861E<ELG
M<VEZ92==+S4Q,BDI*3L-"B`@("`@("`@("!]#0H@("`@("`@('T-"@T*("`@
M("`@("!R971U<FX@3E5,3#L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O
M+R![>WL@7V5X=')A8W1,:7-T*"D-"B`@("!F=6YC=&EO;B!?97AT<F%C=$QI
M<W0H)'!?<&%T:"P@)B1P7VQI<W1?9&5T86EL+"`D<%]M;V1E+`T*"2`@("`@
M("`@("`@("`@("`@("`@("`D<%]F:6QE7VQI<W0L("1P7W)E;6]V95]P871H
M*0T*("`@('L-"B`@("`D=E]R97-U;'0]=')U93L-"B`@("`D=E]N8B`](#`[
M#0H@("`@)'9?97AT<F%C=%]A;&P@/2!T<G5E.PT*("`@("1V7VQI<W1I;F<@
M/2!F86QS93L-"@T*("`@("1P7W!A=&@@/2`D=&AI<RT^7W1R86YS;&%T95=I
M;E!A=&@H)'!?<&%T:"P@9F%L<V4I.PT*("`@(&EF("@D<%]P871H(#T]("<G
M('Q\("AS=6)S='(H)'!?<&%T:"P@,"P@,2D@(3T@)R\G#0H)("`@("8F('-U
M8G-T<B@D<%]P871H+"`P+"`S*2`A/2`B+BXO(B`F)B`A<W1R<&]S*"1P7W!A
M=&@L("<Z)RDI*2![#0H@("`@("`D<%]P871H(#T@(BXO(BXD<%]P871H.PT*
M("`@('T-"B`@("`D<%]R96UO=F5?<&%T:"`]("1T:&ES+3Y?=')A;G-L871E
M5VEN4&%T:"@D<%]R96UO=F5?<&%T:"D[#0H-"B`@("`O+R`M+2TM+2!,;V]K
M(&9O<B!P871H('1O(')E;6]V92!F;W)M870@*'-H;W5L9"!E;F0@8GD@+RD-
M"B`@("!I9B`H*"1P7W)E;6]V95]P871H("$]("<G*2`F)B`H<W5B<W1R*"1P
M7W)E;6]V95]P871H+"`M,2D@(3T@)R\G*2D-"B`@("`@("1P7W)E;6]V95]P
M871H("X]("<O)SL-"B`@("`D<%]R96UO=F5?<&%T:%]S:7IE(#T@<W1R;&5N
M*"1P7W)E;6]V95]P871H*3L-"@T*("`@('-W:71C:"`H)'!?;6]D92D@>PT*
M("`@("`@8V%S92`B8V]M<&QE=&4B(#H-"B`@("`@("`@)'9?97AT<F%C=%]A
M;&P@/2!44E5%.PT*("`@("`@("`D=E]L:7-T:6YG(#T@1D%,4T4[#0H@("`@
M("!B<F5A:SL-"B`@("`@(&-A<V4@(G!A<G1I86PB(#H-"B`@("`@("`@("`D
M=E]E>'1R86-T7V%L;"`]($9!3%-%.PT*("`@("`@("`@("1V7VQI<W1I;F<@
M/2!&04Q313L-"B`@("`@(&)R96%K.PT*("`@("`@8V%S92`B;&ES="(@.@T*
M("`@("`@("`@("1V7V5X=')A8W1?86QL(#T@1D%,4T4[#0H@("`@("`@("`@
M)'9?;&ES=&EN9R`](%12544[#0H@("`@("!B<F5A:SL-"B`@("`@(&1E9F%U
M;'0@.@T*("`@("`@("`D=&AI<RT^7V5R<F]R*"=);G9A;&ED(&5X=')A8W0@
M;6]D92`H)RXD<%]M;V1E+B<I)RD[#0H@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("!]#0H-"B`@("!C;&5A<G-T871C86-H92@I.PT*#0H@("`@=VAI;&4@
M*'-T<FQE;B@D=E]B:6YA<GE?9&%T82`]("1T:&ES+3Y?<F5A9$)L;V-K*"DI
M("$](#`I#0H@("`@>PT*("`@("`@)'9?97AT<F%C=%]F:6QE(#T@1D%,4T4[
M#0H@("`@("`D=E]E>'1R86-T:6]N7W-T;W!P960@/2`P.PT*#0H@("`@("!I
M9B`H(21T:&ES+3Y?<F5A9$AE861E<B@D=E]B:6YA<GE?9&%T82P@)'9?:&5A
M9&5R*2D-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*#0H@("`@("!I9B`H)'9?
M:&5A9&5R6R=F:6QE;F%M92==(#T]("<G*2![#0H@("`@("`@(&-O;G1I;G5E
M.PT*("`@("`@?0T*#0H@("`@("`O+R`M+2TM+2!,;V]K(&9O<B!L;VYG(&9I
M;&5N86UE#0H@("`@("!I9B`H)'9?:&5A9&5R6R=T>7!E9FQA9R==(#T]("=,
M)RD@>PT*("`@("`@("!I9B`H(21T:&ES+3Y?<F5A9$QO;F=(96%D97(H)'9?
M:&5A9&5R*2D-"B`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("!]#0H-
M"B`@("`@(&EF("@H(21V7V5X=')A8W1?86QL*2`F)B`H:7-?87)R87DH)'!?
M9FEL95]L:7-T*2DI('L-"B`@("`@("`@+R\@+2TM+2T@0GD@9&5F875L="!N
M;R!U;GII<"!I9B!T:&4@9FEL92!I<R!N;W0@9F]U;F0-"B`@("`@("`@)'9?
M97AT<F%C=%]F:6QE(#T@9F%L<V4[#0H-"B`@("`@("`@9F]R("@D:3TP.R`D
M:3QS:7IE;V8H)'!?9FEL95]L:7-T*3L@)&DK*RD@>PT*("`@("`@("`@("\O
M("TM+2TM($QO;VL@:68@:70@:7,@82!D:7)E8W1O<GD-"B`@("`@("`@("!I
M9B`H<W5B<W1R*"1P7V9I;&5?;&ES=%LD:5TL("TQ*2`]/2`G+R<I('L-"B`@
M("`@("`@("`@("\O("TM+2TM($QO;VL@:68@=&AE(&1I<F5C=&]R>2!I<R!I
M;B!T:&4@9FEL96YA;64@<&%T:`T*("`@("`@("`@("`@:68@*"AS=')L96XH
M)'9?:&5A9&5R6R=F:6QE;F%M92==*2`^('-T<FQE;B@D<%]F:6QE7VQI<W1;
M)&E=*2D-"@D)"2`@("`F)B`H<W5B<W1R*"1V7VAE861E<ELG9FEL96YA;64G
M72P@,"P@<W1R;&5N*"1P7V9I;&5?;&ES=%LD:5TI*0T*"0D)"2`@("`]/2`D
M<%]F:6QE7VQI<W1;)&E=*2D@>PT*("`@("`@("`@("`@("`D=E]E>'1R86-T
M7V9I;&4@/2!44E5%.PT*("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("!]#0H-"B`@("`@("`@("`O+R`M+2TM+2!)="!I
M<R!A(&9I;&4L('-O(&-O;7!A<F4@=&AE(&9I;&4@;F%M97,-"B`@("`@("`@
M("!E;'-E:68@*"1P7V9I;&5?;&ES=%LD:5T@/3T@)'9?:&5A9&5R6R=F:6QE
M;F%M92==*2![#0H@("`@("`@("`@("`D=E]E>'1R86-T7V9I;&4@/2!44E5%
M.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("!](&5L<V4@>PT*("`@("`@("`D=E]E>'1R86-T7V9I;&4@/2!4
M4E5%.PT*("`@("`@?0T*#0H@("`@("`O+R`M+2TM+2!,;V]K(&EF('1H:7,@
M9FEL92!N965D('1O(&)E(&5X=')A8W1E9`T*("`@("`@:68@*"@D=E]E>'1R
M86-T7V9I;&4I("8F("@A)'9?;&ES=&EN9RDI#0H@("`@("![#0H@("`@("`@
M(&EF("@H)'!?<F5M;W9E7W!A=&@@(3T@)R<I#0H@("`@("`@("`@("`F)B`H
M<W5B<W1R*"1V7VAE861E<ELG9FEL96YA;64G72P@,"P@)'!?<F5M;W9E7W!A
M=&A?<VEZ92D-"@D)"2`@("`]/2`D<%]R96UO=F5?<&%T:"DI#0H@("`@("`@
M("`@)'9?:&5A9&5R6R=F:6QE;F%M92==(#T@<W5B<W1R*"1V7VAE861E<ELG
M9FEL96YA;64G72P-"@D)("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'!?<F5M;W9E7W!A=&A?<VEZ92D[#0H@("`@("`@(&EF("@H)'!?<&%T
M:"`A/2`G+B\G*2`F)B`H)'!?<&%T:"`A/2`G+R<I*2![#0H@("`@("`@("`@
M=VAI;&4@*'-U8G-T<B@D<%]P871H+"`M,2D@/3T@)R\G*0T*("`@("`@("`@
M("`@)'!?<&%T:"`]('-U8G-T<B@D<%]P871H+"`P+"!S=')L96XH)'!?<&%T
M:"DM,2D[#0H-"B`@("`@("`@("!I9B`H<W5B<W1R*"1V7VAE861E<ELG9FEL
M96YA;64G72P@,"P@,2D@/3T@)R\G*0T*("`@("`@("`@("`@("`D=E]H96%D
M97);)V9I;&5N86UE)UT@/2`D<%]P871H+B1V7VAE861E<ELG9FEL96YA;64G
M73L-"B`@("`@("`@("!E;'-E#0H@("`@("`@("`@("`D=E]H96%D97);)V9I
M;&5N86UE)UT@/2`D<%]P871H+B<O)RXD=E]H96%D97);)V9I;&5N86UE)UT[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&9I;&5?97AI<W1S*"1V7VAE861E
M<ELG9FEL96YA;64G72DI('L-"B`@("`@("`@("!I9B`H("`@*$!I<U]D:7(H
M)'9?:&5A9&5R6R=F:6QE;F%M92==*2D-"@D)("`@("`@)B8@*"1V7VAE861E
M<ELG='EP969L86<G72`]/2`G)RDI('L-"B`@("`@("`@("`@("1T:&ES+3Y?
M97)R;W(H)T9I;&4@)RXD=E]H96%D97);)V9I;&5N86UE)UT-"@D)"2`@("`@
M("`@("`@("`@+B<@86QR96%D>2!E>&ES=',@87,@82!D:7)E8W1O<GDG*3L-
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("!]#0H@("`@
M("`@("`@:68@*"`@("@D=&AI<RT^7VES07)C:&EV92@D=E]H96%D97);)V9I
M;&5N86UE)UTI*0T*"0D@("`@("`F)B`H)'9?:&5A9&5R6R=T>7!E9FQA9R==
M(#T]("(U(BDI('L-"B`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)T1I<F5C
M=&]R>2`G+B1V7VAE861E<ELG9FEL96YA;64G70T*"0D)("`@("`@("`@("`@
M("`N)R!A;')E861Y(&5X:7-T<R!A<R!A(&9I;&4G*3L-"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@("!]#0H@("`@("`@("`@:68@*"%I
M<U]W<FET96%B;&4H)'9?:&5A9&5R6R=F:6QE;F%M92==*2D@>PT*("`@("`@
M("`@("`@)'1H:7,M/E]E<G)O<B@G1FEL92`G+B1V7VAE861E<ELG9FEL96YA
M;64G70T*"0D)("`@("`@("`@("`@("`N)R!A;')E861Y(&5X:7-T<R!A;F0@
M:7,@=W)I=&4@<')O=&5C=&5D)RD[#0H@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@("`@?0T*("`@("`@("`@(&EF("AF:6QE;71I;64H)'9?
M:&5A9&5R6R=F:6QE;F%M92==*2`^("1V7VAE861E<ELG;71I;64G72D@>PT*
M("`@("`@("`@("`@+R\@5&\@8F4@8V]M<&QE=&5D(#H@06X@97)R;W(@;W(@
M<VEL96YT(&YO(')E<&QA8V4@/PT*("`@("`@("`@('T-"B`@("`@("`@?0T*
M#0H@("`@("`@("\O("TM+2TM($-H96-K('1H92!D:7)E8W1O<GD@879A:6QA
M8FEL:71Y(&%N9"!C<F5A=&4@:70@:68@;F5C97-S87)Y#0H@("`@("`@(&5L
M<V5I9B`H*"1V7W)E<W5L=`T*"0D@("`@("`@("`]("1T:&ES+3Y?9&ER0VAE
M8VLH*"1V7VAE861E<ELG='EP969L86<G72`]/2`B-2(-"@D)"0D@("`@("`@
M("`@("`@("`@("`@(#\D=E]H96%D97);)V9I;&5N86UE)UT-"@D)"0D)"0D)
M"3ID:7)N86UE*"1V7VAE861E<ELG9FEL96YA;64G72DI*2D@(3T@,2D@>PT*
M("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G56YA8FQE('1O(&-R96%T92!P
M871H(&9O<B`G+B1V7VAE861E<ELG9FEL96YA;64G72D[#0H@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H)'9?
M97AT<F%C=%]F:6QE*2![#0H@("`@("`@("`@:68@*"1V7VAE861E<ELG='EP
M969L86<G72`]/2`B-2(I('L-"B`@("`@("`@("`@(&EF("@A0&9I;&5?97AI
M<W1S*"1V7VAE861E<ELG9FEL96YA;64G72DI('L-"B`@("`@("`@("`@("`@
M("!I9B`H(4!M:V1I<B@D=E]H96%D97);)V9I;&5N86UE)UTL(#`W-S<I*2![
M#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)U5N86)L92!T
M;R!C<F5A=&4@9&ER96-T;W)Y('LG#0H)"0D)"2`@("`@("`@("`@("`@+B1V
M7VAE861E<ELG9FEL96YA;64G72XG?2<I.PT*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?0T*("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@(&EF("@H
M)'9?9&5S=%]F:6QE(#T@0&9O<&5N*"1V7VAE861E<ELG9FEL96YA;64G72P@
M(G=B(BDI(#T](#`I('L-"B`@("`@("`@("`@("`@("`@("1T:&ES+3Y?97)R
M;W(H)T5R<F]R('=H:6QE(&]P96YI;F<@>R<N)'9?:&5A9&5R6R=F:6QE;F%M
M92==#0H)"0D)("`@("`@("`@("`@("`@("XG?2!I;B!W<FET92!B:6YA<GD@
M;6]D92<I.PT*("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@)&X@/2!F
M;&]O<B@D=E]H96%D97);)W-I>F4G72\U,3(I.PT*("`@("`@("`@("`@("`@
M("`@9F]R("@D:3TP.R`D:3PD;CL@)&DK*RD@>PT*("`@("`@("`@("`@("`@
M("`@("`@("1V7V-O;G1E;G0@/2`D=&AI<RT^7W)E861";&]C:R@I.PT*("`@
M("`@("`@("`@("`@("`@("`@(&9W<FET92@D=E]D97-T7V9I;&4L("1V7V-O
M;G1E;G0L(#4Q,BD[#0H@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H*"1V7VAE861E<ELG<VEZ92==("4@-3$R*2`A/2`P*2![#0H@("`@
M("`@("`@("`@("1V7V-O;G1E;G0@/2`D=&AI<RT^7W)E861";&]C:R@I.PT*
M("`@("`@("`@("`@("!F=W)I=&4H)'9?9&5S=%]F:6QE+"`D=E]C;VYT96YT
M+"`H)'9?:&5A9&5R6R=S:7IE)UT@)2`U,3(I*3L-"B`@("`@("`@("`@('T-
M"@T*("`@("`@("`@("`@0&9C;&]S92@D=E]D97-T7V9I;&4I.PT*#0H@("`@
M("`@("`@("`O+R`M+2TM+2!#:&%N9V4@=&AE(&9I;&4@;6]D92P@;71I;64-
M"B`@("`@("`@("`@($!T;W5C:"@D=E]H96%D97);)V9I;&5N86UE)UTL("1V
M7VAE861E<ELG;71I;64G72D[#0H@("`@("`@("`@("`O+R!4;R!B92!C;VUP
M;&5T960-"B`@("`@("`@("`@("\O8VAM;V0H)'9?:&5A9&5R6V9I;&5N86UE
M72P@1&5C3V-T*"1V7VAE861E<EMM;V1E72DI.PT*("`@("`@("`@('T-"@T*
M("`@("`@("`@("\O("TM+2TM($-H96-K('1H92!F:6QE('-I>F4-"B`@("`@
M("`@("!C;&5A<G-T871C86-H92@I.PT*("`@("`@("`@(&EF("AF:6QE<VEZ
M92@D=E]H96%D97);)V9I;&5N86UE)UTI("$]("1V7VAE861E<ELG<VEZ92==
M*2![#0H@("`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)T5X=')A8W1E9"!F
M:6QE("<N)'9?:&5A9&5R6R=F:6QE;F%M92==#0H)"0D@("`@("`@("`@("`@
M("`@+B<@9&]E<R!N;W0@:&%V92!T:&4@8V]R<F5C="!F:6QE('-I>F4@7"<G
M#0H)"0D)"0D)+F9I;&5S:7IE*"1V7VAE861E<ELG9FEL96YA;64G72D-"@D)
M"0D)"0DN)UPG("@G+B1V7VAE861E<ELG<VEZ92==#0H)"0D)"0D)+B<@97AP
M96-T960I+B!!<F-H:79E(&UA>2!B92!C;W)R=7!T960N)RD[#0H@("`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("!]#0H@("`@("`@("`@
M?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("1T:&ES+3Y?:G5M<$)L
M;V-K*&-E:6PH*"1V7VAE861E<ELG<VEZ92==+S4Q,BDI*3L-"B`@("`@("`@
M?0T*("`@("`@?2!E;'-E('L-"B`@("`@("`@("`D=&AI<RT^7VIU;7!";&]C
M:RAC96EL*"@D=E]H96%D97);)W-I>F4G72\U,3(I*2D[#0H@("`@("!]#0H-
M"B`@("`@("\J(%1"0R`Z(%-E96US('1O(&)E('5N=7-E9"`N+BX-"B`@("`@
M(&EF("@D=&AI<RT^7V-O;7!R97-S*0T*("`@("`@("`D=E]E;F1?;V9?9FEL
M92`]($!G>F5O9B@D=&AI<RT^7V9I;&4I.PT*("`@("`@96QS90T*("`@("`@
M("`D=E]E;F1?;V9?9FEL92`]($!F96]F*"1T:&ES+3Y?9FEL92D[#0H@("`@
M("`@("HO#0H-"B`@("`@(&EF("@D=E]L:7-T:6YG('Q\("1V7V5X=')A8W1?
M9FEL92!\?"`D=E]E>'1R86-T:6]N7W-T;W!P960I('L-"B`@("`@("`@+R\@
M+2TM+2T@3&]G(&5X=')A8W1E9"!F:6QE<PT*("`@("`@("!I9B`H*"1V7V9I
M;&5?9&ER(#T@9&ER;F%M92@D=E]H96%D97);)V9I;&5N86UE)UTI*0T*"0D@
M("`@/3T@)'9?:&5A9&5R6R=F:6QE;F%M92==*0T*("`@("`@("`@("1V7V9I
M;&5?9&ER(#T@)R<[#0H@("`@("`@(&EF("@H<W5B<W1R*"1V7VAE861E<ELG
M9FEL96YA;64G72P@,"P@,2D@/3T@)R\G*2`F)B`H)'9?9FEL95]D:7(@/3T@
M)R<I*0T*("`@("`@("`@("1V7V9I;&5?9&ER(#T@)R\G.PT*#0H@("`@("`@
M("1P7VQI<W1?9&5T86EL6R1V7VYB*RM=(#T@)'9?:&5A9&5R.PT*("`@("`@
M?0T*("`@('T-"@T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H@("`@
M+R\@?7U]#0H-"B`@("`O+R![>WL@7V]P96Y!<'!E;F0H*0T*("`@(&9U;F-T
M:6]N(%]O<&5N07!P96YD*"D-"B`@("![#0H@("`@("`@(&EF("AF:6QE<VEZ
M92@D=&AI<RT^7W1A<FYA;64I(#T](#`I#0H@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?;W!E;E=R:71E*"D[#0H@("`@("`@("`@#0H@("`@("`@(&EF("@D
M=&AI<RT^7V-O;7!R97-S*2![#0H@("`@("`@("`@("`D=&AI<RT^7V-L;W-E
M*"D[#0H-"B`@("`@("`@("`@(&EF("@A0')E;F%M92@D=&AI<RT^7W1A<FYA
M;64L("1T:&ES+3Y?=&%R;F%M92XB+G1M<"(I*2![#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]E<G)O<B@G17)R;W(@=VAI;&4@<F5N86UI;F<@7"<G+B1T
M:&ES+3Y?=&%R;F%M90T*"0D)"2`@("`@("`@("`@("`@+B=<)R!T;R!T96UP
M;W)A<GD@9FEL92!<)R<N)'1H:7,M/E]T87)N86UE#0H)"0D)"0D)("`N)RYT
M;7!<)R<I.PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@("`@('T-"@T*("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V]M<')E<W-?
M='EP92`]/2`G9WHG*0T*("`@("`@("`@("`@("`@("1V7W1E;7!?=&%R(#T@
M0&=Z;W!E;B@D=&AI<RT^7W1A<FYA;64N(BYT;7`B+"`B<F(B*3L-"B`@("`@
M("`@("`@(&5L<V5I9B`H)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T]("=B>C(G
M*0T*("`@("`@("`@("`@("`@("1V7W1E;7!?=&%R(#T@0&)Z;W!E;B@D=&AI
M<RT^7W1A<FYA;64N(BYT;7`B+"`B<F(B*3L-"B`@("`@("`@("`@("`@("`-
M"B`@("`@("`@("`@(&EF("@D=E]T96UP7W1A<B`]/2`P*2![#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]E<G)O<B@G56YA8FQE('1O(&]P96X@9FEL92!<
M)R<N)'1H:7,M/E]T87)N86UE#0H)"0D)("`@("`@("`@("`@("`N)RYT;7!<
M)R!I;B!B:6YA<GD@<F5A9"!M;V1E)RD[#0H@("`@("`@("`@("`@("`@0')E
M;F%M92@D=&AI<RT^7W1A<FYA;64N(BYT;7`B+"`D=&AI<RT^7W1A<FYA;64I
M.PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@
M('T-"@T*("`@("`@("`@("`@:68@*"$D=&AI<RT^7V]P96Y7<FET92@I*2![
M#0H@("`@("`@("`@("`@("`@0')E;F%M92@D=&AI<RT^7W1A<FYA;64N(BYT
M;7`B+"`D=&AI<RT^7W1A<FYA;64I.PT*("`@("`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@("`@('T-"@T*("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G9WHG*2![#0H@("`@("`@("`@("`@
M("`@)'9?8G5F9F5R(#T@0&=Z<F5A9"@D=E]T96UP7W1A<BP@-3$R*3L-"@T*
M("`@("`@("`@("`@("`@("\O("TM+2TM(%)E860@=&AE(&9O;&QO=VEN9R!B
M;&]C:W,@8G5T(&YO="!T:&4@;&%S="!O;F4-"B`@("`@("`@("`@("`@("!I
M9B`H(4!G>F5O9B@D=E]T96UP7W1A<BDI('L-"B`@("`@("`@("`@("`@("`@
M("`@9&][#0H@("`@("`@("`@("`@("`@("`@("`@("`D=E]B:6YA<GE?9&%T
M82`]('!A8VLH(F$U,3(B+"`D=E]B=69F97(I.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]W<FET94)L;V-K*"1V7V)I;F%R>5]D871A*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1V7V)U9F9E<B`]($!G>G)E860H
M)'9?=&5M<%]T87(L(#4Q,BD[#0H-"B`@("`@("`@("`@("`@("`@("`@?2!W
M:&EL92`H(4!G>F5O9B@D=E]T96UP7W1A<BDI.PT*("`@("`@("`@("`@("`@
M('T-"@T*("`@("`@("`@("`@("`@($!G>F-L;W-E*"1V7W1E;7!?=&%R*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&5L<V5I9B`H)'1H:7,M/E]C
M;VUP<F5S<U]T>7!E(#T]("=B>C(G*2![#0H@("`@("`@("`@("`@("`@)'9?
M8G5F9F5R961?;&EN97,@("`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@
M)'9?8G5F9F5R961?;&EN97-;72`]($!B>G)E860H)'9?=&5M<%]T87(L(#4Q
M,BD[#0H-"B`@("`@("`@("`@("`@("`O+R`M+2TM+2!296%D('1H92!F;VQL
M;W=I;F<@8FQO8VMS(&)U="!N;W0@=&AE(&QA<W0@;VYE#0H@("`@("`@("`@
M("`@("`@=VAI;&4@*'-T<FQE;B@D=E]B=69F97)E9%]L:6YE<UM=#0H)"0D)
M("`@("`@("`@("`@("`]($!B>G)E860H)'9?=&5M<%]T87(L(#4Q,BDI(#X@
M,"D@>PT*("`@("`@("`@("`@("`@("`@("`D=E]B:6YA<GE?9&%T82`]('!A
M8VLH(F$U,3(B+`T*"0D)"0D@("`@("`@("`@("`@("`@("`@("`@87)R87E?
M<VAI9G0H)'9?8G5F9F5R961?;&EN97,I*3L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]W<FET94)L;V-K*"1V7V)I;F%R>5]D871A*3L-"B`@("`@
M("`@("`@("`@("!]#0H-"B`@("`@("`@("`@("`@("!`8GIC;&]S92@D=E]T
M96UP7W1A<BD[#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@(&EF("@A
M0'5N;&EN:R@D=&AI<RT^7W1A<FYA;64N(BYT;7`B*2D@>PT*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?97)R;W(H)T5R<F]R('=H:6QE(&1E;&5T:6YG('1E
M;7!O<F%R>2!F:6QE(%PG)PT*"0D)"2`@("`@("`@("`@("`@+B1T:&ES+3Y?
M=&%R;F%M92XG+G1M<%PG)RD[#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("\O("TM+2TM($9O<B!N;W0@8V]M<')E
M<W-E9"!T87(L(&IU<W0@861D(&9I;&5S(&)E9F]R92!T:&4@;&%S=`T*"0D)
M+R\@("`@("`@-3$R(&)Y=&5S(&)L;V-K#0H@("`@("`@("`@("!I9B`H(21T
M:&ES+3Y?;W!E;E)E8617<FET92@I*0T*("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*#0H@("`@("`@("`@("!C;&5A<G-T871C86-H92@I.PT*("`@
M("`@("`@("`@)'9?<VEZ92`](&9I;&5S:7IE*"1T:&ES+3Y?=&%R;F%M92D[
M#0H@("`@("`@("`@("!F<V5E:R@D=&AI<RT^7V9I;&4L("1V7W-I>F4M-3$R
M*3L-"B`@("`@("`@?0T*#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-
M"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?87!P96YD*"D-"B`@("!F=6YC
M=&EO;B!?87!P96YD*"1P7V9I;&5L:7-T+"`D<%]A9&1?9&ER/2<G+"`D<%]R
M96UO=F5?9&ER/2<G*0T*("`@('L-"B`@("`@("`@:68@*"$D=&AI<RT^7V]P
M96Y!<'!E;F0H*2D-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@("`@(`T*("`@("`@("!I9B`H)'1H:7,M/E]A9&1,:7-T*"1P7V9I;&5L
M:7-T+"`D<%]A9&1?9&ER+"`D<%]R96UO=F5?9&ER*2D-"B`@("`@("`@("`@
M)'1H:7,M/E]W<FET949O;W1E<B@I.PT*#0H@("`@("`@("1T:&ES+3Y?8VQO
M<V4H*3L-"@T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H@("`@+R\@
M?7U]#0H-"B`@("`O+R![>WL@7V1I<D-H96-K*"D-"@T*("`@("\J*@T*("`@
M("`J($-H96-K(&EF(&$@9&ER96-T;W)Y(&5X:7-T<R!A;F0@8W)E871E(&ET
M("AI;F-L=61I;F<@<&%R96YT#0H@("`@("H@9&ER<RD@:68@;F]T+@T*("`@
M("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D<%]D:7(@9&ER96-T;W)Y('1O
M(&-H96-K#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&)O;VP@5%)512!I9B!T
M:&4@9&ER96-T;W)Y(&5X:7-T<R!O<B!W87,@8W)E871E9`T*("`@("`J+PT*
M("`@(&9U;F-T:6]N(%]D:7)#:&5C:R@D<%]D:7(I#0H@("`@>PT*("`@("`@
M("!I9B`H*$!I<U]D:7(H)'!?9&ER*2D@?'P@*"1P7V1I<B`]/2`G)RDI#0H@
M("`@("`@("`@("!R971U<FX@=')U93L-"@T*("`@("`@("`D<%]P87)E;G1?
M9&ER(#T@9&ER;F%M92@D<%]D:7(I.PT*#0H@("`@("`@(&EF("@H)'!?<&%R
M96YT7V1I<B`A/2`D<%]D:7(I("8F#0H@("`@("`@("`@("`H)'!?<&%R96YT
M7V1I<B`A/2`G)RD@)B8-"B`@("`@("`@("`@("@A)'1H:7,M/E]D:7)#:&5C
M:R@D<%]P87)E;G1?9&ER*2DI#0H@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*#0H@("`@("`@(&EF("@A0&UK9&ER*"1P7V1I<BP@,#<W-RDI('L-"B`@
M("`@("`@("`@("1T:&ES+3Y?97)R;W(H(E5N86)L92!T;R!C<F5A=&4@9&ER
M96-T;W)Y("<D<%]D:7(G(BD[#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@('T-"@T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?<&%T:%)E9'5C=&EO;B@I#0H-
M"B`@("`O*BH-"B`@("`@*B!#;VUP<F5S<R!P871H(&)Y(&-H86YG:6YG(&9O
M<B!E>&%M<&QE("(O9&ER+V9O;R\N+B]B87(B('1O("(O9&ER+V)A<B(L(`T*
M("`@("`J(')A;F0@96UO=F4@9&]U8FQE('-L87-H97,N#0H@("`@("H-"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P7V1I<B!P871H('1O(')E9'5C90T*("`@
M("`J#0H@("`@("H@0')E='5R;B!S=')I;F<@<F5D=6-E9"!P871H#0H@("`@
M("H-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*@T*("`@("`J+PT*
M("`@(&9U;F-T:6]N(%]P871H4F5D=6-T:6]N*"1P7V1I<BD-"B`@("![#0H@
M("`@("`@("1V7W)E<W5L="`]("<G.PT*#0H@("`@("`@("\O("TM+2TM($QO
M;VL@9F]R(&YO="!E;7!T>2!P871H#0H@("`@("`@(&EF("@D<%]D:7(@(3T@
M)R<I('L-"B`@("`@("`@("`@("\O("TM+2TM($5X<&QO9&4@<&%T:"!B>2!D
M:7)E8W1O<GD@;F%M97,-"B`@("`@("`@("`@("1V7VQI<W0@/2!E>'!L;V1E
M*"<O)RP@)'!?9&ER*3L-"@T*("`@("`@("`@("`@+R\@+2TM+2T@4W1U9'D@
M9&ER96-T;W)I97,@9G)O;2!L87-T('1O(&9I<G-T#0H@("`@("`@("`@("!F
M;W(@*"1I/7-I>F5O9B@D=E]L:7-T*2TQ.R`D:3X],#L@)&DM+2D@>PT*("`@
M("`@("`@("`@("`@("\O("TM+2TM($QO;VL@9F]R(&-U<G)E;G0@<&%T:`T*
M("`@("`@("`@("`@("`@(&EF("@D=E]L:7-T6R1I72`]/2`B+B(I('L-"B`@
M("`@("`@("`@("`@("`@("`@+R\@+2TM+2T@26=N;W)E('1H:7,@9&ER96-T
M;W)Y#0H@("`@("`@("`@("`@("`@("`@("\O(%-H;W5L9"!B92!T:&4@9FER
M<W0@)&D],"P@8G5T(&YO(&-H96-K(&ES(&1O;F4-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@96QS92!I9B`H)'9?;&ES=%LD:5T@/3T@
M(BXN(BD@>PT*("`@("`@("`@("`@("`@("`@("`O+R`M+2TM+2!)9VYO<F4@
M:70@86YD(&EG;F]R92!T:&4@)&DM,0T*("`@("`@("`@("`@("`@("`@("`D
M:2TM.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!E;'-E
M(&EF("@@("`H)'9?;&ES=%LD:5T@/3T@)R<I#0H)"0D)("`@("`@("`@)B8@
M*"1I(3TH<VEZ96]F*"1V7VQI<W0I+3$I*0T*"0D)"0D)("8F("@D:2$],"DI
M('L-"B`@("`@("`@("`@("`@("`@("`@+R\@+2TM+2T@26=N;W)E(&]N;'D@
M=&AE(&1O=6)L92`G+R\G(&EN('!A=&@L#0H@("`@("`@("`@("`@("`@("`@
M("\O(&)U="!N;W0@=&AE(&9I<G-T(&%N9"!L87-T("\-"B`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D=E]R97-U;'0@
M/2`D=E]L:7-T6R1I72XH)&DA/2AS:7IE;V8H)'9?;&ES="DM,2D_)R\G#0H)
M"0D)"2`@("`@("`@("`@("XD=E]R97-U;'0Z)R<I.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D=E]R
M97-U;'0@/2!S=')T<B@D=E]R97-U;'0L("=<7"<L("<O)RD[#0H@("`@("`@
M(')E='5R;B`D=E]R97-U;'0[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@
M("`O+R![>WL@7W1R86YS;&%T95=I;E!A=&@H*0T*("`@(&9U;F-T:6]N(%]T
M<F%N<VQA=&57:6Y0871H*"1P7W!A=&@L("1P7W)E;6]V95]D:7-K7VQE='1E
M<CUT<G5E*0T*("`@('L-"B`@("`@(&EF("A/4U]724Y$3U=3*2![#0H@("`@
M("`@("`@+R\@+2TM+2T@3&]O:R!F;W(@<&]T96YT:6%L(&1I<VL@;&5T=&5R
M#0H@("`@("`@("`@:68@*"`@("@D<%]R96UO=F5?9&ES:U]L971T97(I#0H)
M"2`@("`@("8F("@H)'9?<&]S:71I;VX@/2!S=')P;W,H)'!?<&%T:"P@)SHG
M*2D@(3T@9F%L<V4I*2![#0H@("`@("`@("`@("`@("1P7W!A=&@@/2!S=6)S
M='(H)'!?<&%T:"P@)'9?<&]S:71I;VXK,2D[#0H@("`@("`@("`@?0T*("`@
M("`@("`@("\O("TM+2TM($-H86YG92!P;W1E;G1I86P@=VEN9&]W<R!D:7)E
M8W1O<GD@<V5P87)A=&]R#0H@("`@("`@("`@:68@*"AS=')P;W,H)'!?<&%T
M:"P@)UQ<)RD@/B`P*2!\?"`H<W5B<W1R*"1P7W!A=&@L(#`L,2D@/3T@)UQ<
M)RDI('L-"B`@("`@("`@("`@("`@)'!?<&%T:"`]('-T<G1R*"1P7W!A=&@L
M("=<7"<L("<O)RD[#0H@("`@("`@("`@?0T*("`@("`@?0T*("`@("`@<F5T
M=7)N("1P7W!A=&@[#0H@("`@?0T*("`@("\O('U]?0T*#0I]#0H_/@T*`"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]!=71H+P``````````````
M````````````````````````````````````````````````````````````
M```````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#4Q-30S,S<S-``P,3<U,#4`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+T%U=&@O4T%33"\`````````````````````````````````````````````
M`````````````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S,T`#`R,#(T-P`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O075T:"]305-,+T%N;VYY;6]U<RYP:'``````
M````````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8W-C0`,3`U,34T,S,W,S0`
M,#(R-S8U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK(`T*
M+R\@?"!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P,R!2:6-H87)D($AE>65S("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?"`-"B\O('P@06QL(')I
M9VAT<R!R97-E<G9E9"X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P@#0HO+R!\("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\(`T*+R\@?"!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O
M=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70@("`@?"`-
M"B\O('P@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H
M870@=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS("`@('P@#0HO+R!\(&%R92!M
M970Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\(`T*+R\@?"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?"`-"B\O('P@;R!2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E
M(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H="`@("`@('P@
M#0HO+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@
M=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+B`@("`@("!\(`T*+R\@?"!O(%)E
M9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T
M:&4@86)O=F4@8V]P>7)I9VAT("`@?"`-"B\O('P@("!N;W1I8V4L('1H:7,@
M;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM
M97(@:6X@=&AE('P@#0HO+R!\("`@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H
M97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BY\
M(`T*+R\@?"!O(%1H92!N86UE<R!O9B!T:&4@875T:&]R<R!M87D@;F]T(&)E
M('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E("`@("`@?"`-"B\O('P@("!P
M<F]D=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T('-P
M96-I9FEC('!R:6]R('=R:71T96X@('P@#0HO+R!\("`@<&5R;6ES<VEO;BX@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\(`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?"`-"B\O('P@5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0T]0
M65))1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]24R`@('P@#0HO+R!\(")!
M4R!)4R(@04Y$($%.62!%6%!215-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@
M24Y#3%5$24Y'+"!"550@3D]4("`@("!\(`T*+R\@?"!,24U)5$5$(%1/+"!4
M2$4@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!3D0@
M1DE43D534R!&3U(@?"`-"B\O('P@02!005)424-53$%2(%!54E!/4T4@05)%
M($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'2%0@
M('P@#0HO+R!\($]73D52($]2($-/3E1224)55$]24R!"12!,24%"3$4@1D]2
M($%.62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!\(`T*+R\@?"!3
M4$5#24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H
M24Y#3%5$24Y'+"!"550@3D]4("`@("`@?"`-"B\O('P@3$E-251%1"!43RP@
M4%)/0U5214U%3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL@
M3$]34R!/1B!54T4L('P@#0HO+R!\($1!5$$L($]2(%!23T9)5%,[($]2($)5
M4TE.15-3($E.5$524E505$E/3BD@2$]7159%4B!#0553140@04Y$($].($%.
M62!\(`T*+R\@?"!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E.($-/
M3E1204-4+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4("`@?"`-"B\O('P@
M*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D@05))4TE.1R!)
M3B!!3ED@5T%9($]55"!/1B!42$4@55-%('P@#0HO+R!\($]&(%1(25,@4T]&
M5%=!4D4L($5614X@248@041625-%1"!/1B!42$4@4$]34TE"24Q)5%D@3T8@
M4U5#2"!$04U!1T4N("!\(`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?"`-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L@#0HO+R!\
M($%U=&AO<CH@4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'`N;F5T/B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*R`-"B\O(`T*+R\@)$ED.B!!;F]N>6UO=7,N<&AP
M+'8@,2XT(#(P,#,O,#(O,C$@,38Z,#<Z,3<@;6H@17AP("0-"@T*+RHJ#0HJ
M($EM<&QM96YT871I;VX@;V8@04Y/3EE-3U53(%-!4TP@;65C:&%N:7-M#0HJ
M#0HJ($!A=71H;W(@(%)I8VAA<F0@2&5Y97,@/')I8VAA<F1`<&AP+FYE=#X-
M"BH@0&%C8V5S<R`@<'5B;&EC#0HJ($!V97)S:6]N(#$N,`T**B!`<&%C:V%G
M92!!=71H7U-!4TP-"BHO#0H-"G)E<75I<F5?;VYC92@G075T:"]305-,+T-O
M;6UO;BYP:'`G*3L-"@T*8VQA<W,@075T:%]305-,7T%N;VYY;6]U<R!E>'1E
M;F1S($%U=&A?4T%33%]#;VUM;VX-"GL-"B`@("`O*BH-"B`@("`J($YO="!M
M=6-H('1O(&1O(&AE<F4@97AC97!T(')E='5R;B!T:&4@=&]K96X@<W5P<&QI
M960N#0H@("`@*B!.;R!E;F-O9&EN9RP@:&%S:&EN9R!O<B!E;F-R>7!T:6]N
M('1A:V5S('!L86-E(&9O<B!T:&ES#0H@("`@*B!M96-H86YI<VTL('-I;7!L
M>2!O;F4@;V8Z#0H@("`@*B`@;R!!;B!E;6%I;"!A9&1R97-S#0H@("`@*B`@
M;R!!;B!O<&%Q=64@<W1R:6YG(&YO="!C;VYT86EN:6YG(")`(B!T:&%T(&-A
M;B!B92!I;G1E<G!R971E9`T*("`@("H@("`@8GD@=&AE('-Y<V%D;6EN#0H@
M("`@*B`@;R!.;W1H:6YG#0H@("`@*@T*("`@("H@5V4@8V]U;&0@:&%V92!S
M;VUE(&QO9VEC(&AE<F4@9F]R('1H92!S96-O;F0@;W!T:6]N+"!B=70@=&AI
M<PT*("`@("H@=V]U;&0@8GD@;F\@;65A;G,@8W)E871E('-O;65T:&EN9R!I
M;G1E<G!R971A8FQE+@T*("`@("H-"B`@("`J($!P87)A;2`@<W1R:6YG("1T
M;VME;B!/<'1I;VYA;"!E;6%I;"!A9&1R97-S(&]R('-T<FEN9R!T;R!P<F]V
M:61E#0H@("`@*B`@("`@("`@("`@("`@("`@("`@("`@87,@=')A8V4@:6YF
M;W)M871I;VXN#0H@("`@*B!`<F5T=7)N('-T<FEN9R`@("`@("`@5&AE('5N
M86QT97)E9"!I;G!U="!T;VME;@T*("`@("HO#0H@("`@9G5N8W1I;VX@9V5T
M4F5S<&]N<V4H)'1O:V5N(#T@)R<I#0H@("`@>PT*("`@("`@("!R971U<FX@
M)'1O:V5N.PT*("`@('T-"GT-"C\^````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+T%U=&@O4T%33"]#;VUM;VXN<&AP````````
M`````````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-30P`#$P-3$U-#,S-S,T
M`#`R,C(Q-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK(`HO
M+R!\($-O<'ER:6=H="`H8RD@,C`P,BTR,#`S(%)I8VAA<F0@2&5Y97,@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`HO+R!\($%L;"!R:6=H
M=',@<F5S97)V960N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\(`HO+R!\("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\(`HO+R!\(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E
M(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U="`@("!\(`HO+R!\
M(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H
M92!F;VQL;W=I;F<@8V]N9&ET:6]N<R`@("!\(`HO+R!\(&%R92!M970Z("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\(`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\(`HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU
M<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@("`@("!\(`HO+R!\("`@
M;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO
M=VEN9R!D:7-C;&%I;65R+B`@("`@("!\(`HO+R!\(&\@4F5D:7-T<FEB=71I
M;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C
M;W!Y<FEG:'0@("!\(`HO+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N
M9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN('1H92!\
M(`HO+R!\("`@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I86QS
M('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BY\(`HO+R!\(&\@5&AE
M(&YA;65S(&]F('1H92!A=71H;W)S(&UA>2!N;W0@8F4@=7-E9"!T;R!E;F1O
M<G-E(&]R('!R;VUO=&4@("`@("!\(`HO+R!\("`@<')O9'5C=',@9&5R:79E
M9"!F<F]M('1H:7,@<V]F='=A<F4@=VET:&]U="!S<&5C:69I8R!P<FEO<B!W
M<FET=&5N("!\(`HO+R!\("`@<&5R;6ES<VEO;BX@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`HO
M+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`HO+R!\(%1(25,@4T]&
M5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.
M1"!#3TY44DE"551/4E,@("!\(`HO+R!\(")!4R!)4R(@04Y$($%.62!%6%!2
M15-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4
M("`@("!\(`HO+R!\($Q)34E4140@5$\L(%1(12!)35!,245$(%=!4E)!3E1)
M15,@3T8@34520TA!3E1!0DE,2519($%.1"!&251.15-3($9/4B!\(`HO+R!\
M($$@4$%25$E#54Q!4B!055)03U-%($%212!$25-#3$%)345$+B!)3B!.3R!%
M5D5.5"!32$%,3"!42$4@0T]065))1TA4("!\(`HO+R!\($]73D52($]2($-/
M3E1224)55$]24R!"12!,24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4
M+"!)3D-)1$5.5$%,+"!\(`HO+R!\(%-014-)04PL($5814U03$%262P@3U(@
M0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L($)55"!.3U0@("`@
M("!\(`HO+R!\($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&(%-50E-42515
M5$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%+"!\(`HO+R!\($1!
M5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3($E.5$524E505$E/3BD@2$]7
M159%4B!#0553140@04Y$($].($%.62!\(`HO+R!\(%1(14]262!/1B!,24%"
M24Q)5%DL(%=(151(15(@24X@0T].5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL
M($]2(%1/4E0@("!\(`HO+R!\("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/
M5$A%4E=)4T4I($%225-)3D<@24X@04Y9(%=!62!/550@3T8@5$A%(%5312!\
M(`HO+R!\($]&(%1(25,@4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!4
M2$4@4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N("!\(`HO+R!\("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\(`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK(`HO+R!\($%U=&AO<CH@4FEC:&%R9"!(97EE<R`\<FEC:&%R
M9$!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK(`HO+R`*+R\@)$ED.B!#
M;VUM;VXN<&AP+'8@,2XV(#(P,#,O,#(O,C$@,38Z,#<Z,3<@;6H@17AP("0*
M"B\J*@HJ($-O;6UO;B!F=6YC=&EO;F%L:71Y('1O(%-!4TP@;65C:&%N:7-M
M<PHJ"BH@0&%U=&AO<B`@4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'`N;F5T
M/@HJ($!A8V-E<W,@('!U8FQI8PHJ($!V97)S:6]N(#$N,`HJ($!P86-K86=E
M($%U=&A?4T%33`HJ+PH*8VQA<W,@075T:%]305-,7T-O;6UO;@I["B`@("`O
M*BH*("`@("H@1G5N8W1I;VX@=VAI8V@@:6UP;&5M96YT<R!(34%#($U$-2!D
M:6=E<W0*("`@("H*("`@("H@0'!A<F%M("!S=')I;F<@)&ME>2`@5&AE('-E
M8W)E="!K97D*("`@("H@0'!A<F%M("!S=')I;F<@)&1A=&$@5&AE(&1A=&$@
M=&\@<')O=&5C=`H@("`@*B!`<F5T=7)N('-T<FEN9R`@("`@("!4:&4@2$U!
M0R!-1#4@9&EG97-T"B`@("`J+PH@("`@9G5N8W1I;VX@7TA-04-?340U*"1K
M97DL("1D871A*0H@("`@>PH@("`@("`@(&EF("AS=')L96XH)&ME>2D@/B`V
M-"D@>PH@("`@("`@("`@("`D:V5Y(#T@<&%C:R@G2#,R)RP@;60U*"1K97DI
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("AS=')L96XH)&ME>2D@/"`V-"D@
M>PH@("`@("`@("`@("`D:V5Y(#T@<W1R7W!A9"@D:V5Y+"`V-"P@8VAR*#`I
M*3L*("`@("`@("!]"@H@("`@("`@("1K7VEP860@/2!S=6)S='(H)&ME>2P@
M,"P@-C0I(%X@<W1R7W)E<&5A="AC:'(H,'@S-BDL(#8T*3L*("`@("`@("`D
M:U]O<&%D(#T@<W5B<W1R*"1K97DL(#`L(#8T*2!>('-T<E]R97!E870H8VAR
M*#!X-4,I+"`V-"D["@H@("`@("`@("1I;FYE<B`@/2!P86-K*"=(,S(G+"!M
M9#4H)&M?:7!A9"`N("1D871A*2D["B`@("`@("`@)&1I9V5S="`](&UD-2@D
M:U]O<&%D("X@)&EN;F5R*3L*"B`@("`@("`@<F5T=7)N("1D:6=E<W0["B`@
M("!]"GT*/SX*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]!=71H+U-!4TPO0W)A;4U$-2YP:'``````
M```````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C<P-@`Q,#4Q-30S,S<S
M-``P,C(Q-C$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L@
M#0HO+R!\($-O<'ER:6=H="`H8RD@,C`P,BTR,#`S(%)I8VAA<F0@2&5Y97,@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@?"!!;&P@
M<FEG:'1S(')E<V5R=F5D+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?"`-"B\O('P@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P@#0HO+R!\(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@
M<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U="`@("!\
M(`T*+R\@?"!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@
M=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,@("`@?"`-"B\O('P@87)E
M(&UE=#H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R!\("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\(`T*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R
M8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT("`@("`@
M?"`-"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N
M9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N("`@("`@('P@#0HO+R!\(&\@
M4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E
M('1H92!A8F]V92!C;W!Y<FEG:'0@("!\(`T*+R\@?"`@(&YO=&EC92P@=&AI
M<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA
M:6UE<B!I;B!T:&4@?"`-"B\O('P@("!D;V-U;65N=&%T:6]N(&%N9"]O<B!O
M=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4@9&ES=')I8G5T:6]N
M+GP@#0HO+R!\(&\@5&AE(&YA;65S(&]F('1H92!A=71H;W)S(&UA>2!N;W0@
M8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@("`@("!\(`T*+R\@?"`@
M('!R;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@
M<W!E8VEF:6,@<')I;W(@=W)I='1E;B`@?"`-"B\O('P@("!P97)M:7-S:6]N
M+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P@#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\(`T*+R\@?"!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#
M3U!94DE'2%0@2$],1$524R!!3D0@0T].5%))0E543U)3("`@?"`-"B\O('P@
M(D%3($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y42453
M+"!)3D-,541)3D<L($)55"!.3U0@("`@('P@#0HO+R!\($Q)34E4140@5$\L
M(%1(12!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519($%.
M1"!&251.15-3($9/4B!\(`T*+R\@?"!!(%!!4E1)0U5,05(@4%524$]312!!
M4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%($-/4%E224=(
M5"`@?"`-"B\O('P@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),12!&
M3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL('P@#0HO+R!\
M(%-014-)04PL($5814U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!1T53
M("A)3D-,541)3D<L($)55"!.3U0@("`@("!\(`T*+R\@?"!,24U)5$5$(%1/
M+"!04D]#55)%345.5"!/1B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53
M.R!,3U-3($]&(%5312P@?"`-"B\O('P@1$%402P@3U(@4%)/1DE44SL@3U(@
M0E5324Y%4U,@24Y415)255!424].*2!(3U=%5D52($-!55-%1"!!3D0@3TX@
M04Y9('P@#0HO+R!\(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X@
M0T].5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL($]2(%1/4E0@("!\(`T*+R\@
M?"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'
M($E.($%.62!705D@3U54($]&(%1(12!54T4@?"`-"B\O('P@3T8@5$A)4R!3
M3T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(12!03U-324))3$E462!/
M1B!354-(($1!34%'12X@('P@#0HO+R!\("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\(`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*R`-"B\O
M('P@075T:&]R.B!2:6-H87)D($AE>65S(#QR:6-H87)D0'!H<"YN970^("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK(`T*+R\@#0HO+R`D260Z($-R86U-1#4N<&AP
M+'8@,2XT(#(P,#,O,#(O,C$@,38Z,#<Z,3<@;6H@17AP("0-"@T*+RHJ#0HJ
M($EM<&QM96YT871I;VX@;V8@0U)!32U-1#4@4T%33"!M96-H86YI<VT-"BH-
M"BH@0&%U=&AO<B`@4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'`N;F5T/@T*
M*B!`86-C97-S("!P=6)L:6,-"BH@0'9E<G-I;VX@,2XP#0HJ($!P86-K86=E
M($%U=&A?4T%33`T**B\-"@T*<F5Q=6ER95]O;F-E*"=!=71H+U-!4TPO0V]M
M;6]N+G!H<"<I.PT*#0IC;&%S<R!!=71H7U-!4TQ?0W)A;4U$-2!E>'1E;F1S
M($%U=&A?4T%33%]#;VUM;VX-"GL-"B`@("`O*BH-"B`@("`J($EM<&QE;65N
M=',@=&AE($-204TM340U(%-!4TP@;65C:&%N:7-M#0H@("`@*B!4:&ES($1/
M15,@3D]4(&)A<V4V-"!E;F-O9&4@=&AE(')E='5R;B!V86QU92P-"B`@("`J
M('EO=2!W:6QL(&YE960@=&\@9&\@=&AA="!Y;W5R<V5L9BX-"B`@("`J#0H@
M("`@*B!`<&%R86T@<W1R:6YG("1U<V5R("`@("`@57-E<FYA;64-"B`@("`J
M($!P87)A;2!S=')I;F<@)'!A<W,@("`@("!087-S=V]R9`T*("`@("H@0'!A
M<F%M('-T<FEN9R`D8VAA;&QE;F=E(%1H92!C:&%L;&5N9V4@<W5P<&QI960@
M8GD@=&AE('-E<G9E<BX-"B`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("!T:&ES('-H;W5L9"!B92!A;')E861Y(&)A<V4V-%]D96-O9&5D+@T*("`@
M("H-"B`@("`J($!R971U<FX@<W1R:6YG(%1H92!S=')I;F<@=&\@<&%S<R!B
M86-K('1O('1H92!S97)V97(L(&]F('1H92!F;W)M#0H@("`@*B`@("`@("`@
M("`@("`@("`B/'5S97(^(#QD:6=E<W0^(BX@5&AI<R!I<R!.3U0@8F%S938T
M7V5N8V]D960N#0H@("`@*B\-"B`@("!F=6YC=&EO;B!G971297-P;VYS92@D
M=7-E<BP@)'!A<W,L("1C:&%L;&5N9V4I#0H@("`@>PT*("`@("`@("!R971U
M<FX@)'5S97(@+B`G("<@+B`D=&AI<RT^7TA-04-?340U*"1P87-S+"`D8VAA
M;&QE;F=E*3L-"B`@("!]#0I]#0H_/@``````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O075T:"]305-,+T1I9V5S=$U$-2YP:'``
M````````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C`R-C``,3`U,34T,S,W
M,S0`,#(R-3`U`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L@
M"B\O('P@0V]P>7)I9VAT("AC*2`R,#`R+3(P,#,@4FEC:&%R9"!(97EE<R`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@"B\O('P@06QL(')I
M9VAT<R!R97-E<G9E9"X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P@"B\O('P@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P@"B\O('P@4F5D:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R
M8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T("`@('P@"B\O
M('P@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@
M=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS("`@('P@"B\O('P@87)E(&UE=#H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P@"B\O('P@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P@"B\O('P@;R!2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@
M;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H="`@("`@('P@"B\O('P@
M("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L
M;&]W:6YG(&1I<V-L86EM97(N("`@("`@('P@"B\O('P@;R!2961I<W1R:6)U
M=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E
M(&-O<'ER:6=H="`@('P@"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C
M;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE
M('P@"B\O('P@("!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA
M;',@<')O=FED960@=VET:"!T:&4@9&ES=')I8G5T:6]N+GP@"B\O('P@;R!4
M:&4@;F%M97,@;V8@=&AE(&%U=&AO<G,@;6%Y(&YO="!B92!U<V5D('1O(&5N
M9&]R<V4@;W(@<')O;6]T92`@("`@('P@"B\O('P@("!P<F]D=6-T<R!D97)I
M=F5D(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T('-P96-I9FEC('!R:6]R
M('=R:71T96X@('P@"B\O('P@("!P97)M:7-S:6]N+B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@
M"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@"B\O('P@5$A)4R!3
M3T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@
M04Y$($-/3E1224)55$]24R`@('P@"B\O('P@(D%3($E3(B!!3D0@04Y9($58
M4%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.
M3U0@("`@('P@"B\O('P@3$E-251%1"!43RP@5$A%($E-4$Q)140@5T%24D%.
M5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2('P@"B\O
M('P@02!005)424-53$%2(%!54E!/4T4@05)%($1)4T-,04E-140N($E.($Y/
M($5614Y4(%-(04Q,(%1(12!#3U!94DE'2%0@('P@"B\O('P@3U=.15(@3U(@
M0T].5%))0E543U)3($)%($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%
M0U0L($E.0TE$14Y404PL('P@"B\O('P@4U!%0TE!3"P@15A%35!,05)9+"!/
M4B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP@0E54($Y/5"`@
M("`@('P@"B\O('P@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)
M5%5412!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L('P@"B\O('P@
M1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)255!424].*2!(
M3U=%5D52($-!55-%1"!!3D0@3TX@04Y9('P@"B\O('P@5$A%3U)9($]&($Q)
M04))3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@4U1224-4($Q)04))3$E4
M62P@3U(@5$]25"`@('P@"B\O('P@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2
M($]42$525TE312D@05))4TE.1R!)3B!!3ED@5T%9($]55"!/1B!42$4@55-%
M('P@"B\O('P@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)4T5$($]&
M(%1(12!03U-324))3$E462!/1B!354-(($1!34%'12X@('P@"B\O('P@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P@"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L@"B\O('P@075T:&]R.B!2:6-H87)D($AE>65S(#QR:6-H
M87)D0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L@"B\O(`HO+R`D260Z
M($1I9V5S=$U$-2YP:'`L=B`Q+C8@,C`P,R\P,B\R,2`Q-CHP-SHQ-R!M:B!%
M>'`@)`H*+RHJ"BH@26UP;&UE;G1A=&EO;B!O9B!$24=%4U0M340U(%-!4TP@
M;65C:&%N:7-M"BH**B!`875T:&]R("!2:6-H87)D($AE>65S(#QR:6-H87)D
M0'!H<"YN970^"BH@0&%C8V5S<R`@<'5B;&EC"BH@0'9E<G-I;VX@,2XP"BH@
M0'!A8VMA9V4@075T:%]305-,"BHO"@IR97%U:7)E7V]N8V4H)T%U=&@O4T%3
M3"]#;VUM;VXN<&AP)RD["@IC;&%S<R!!=71H7U-!4TQ?1&EG97-T340U(&5X
M=&5N9',@075T:%]305-,7T-O;6UO;@I["B`@("`O*BH*("`@("H@4')O=FED
M97,@=&AE("AM86EN*2!C;&EE;G0@<F5S<&]N<V4@9F]R($1)1T535"U-1#4*
M("`@("H@<F5Q=6ER97,@82!F97<@97AT<F$@<&%R86UE=&5R<R!T:&%N('1H
M92!O=&AE<@H@("`@*B!M96-H86YI<VUS+"!W:&EC:"!A<F4@=6YA=F]I9&%B
M;&4N"B`@("`J(`H@("`@*B!`<&%R86T@('-T<FEN9R`D875T:&-I9"`@($%U
M=&AE;G1I8V%T:6]N(&ED("AU<V5R;F%M92D*("`@("H@0'!A<F%M("!S=')I
M;F<@)'!A<W,@("`@("!087-S=V]R9`H@("`@*B!`<&%R86T@('-T<FEN9R`D
M8VAA;&QE;F=E(%1H92!D:6=E<W0@8VAA;&QE;F=E('-E;G0@8GD@=&AE('-E
M<G9E<@H@("`@*B!`<&%R86T@('-T<FEN9R`D:&]S=&YA;64@(%1H92!H;W-T
M;F%M92!O9B!T:&4@;6%C:&EN92!Y;W4G<F4@8V]N;F5C=&EN9R!T;PH@("`@
M*B!`<&%R86T@('-T<FEN9R`D<V5R=FEC92`@(%1H92!S97)V:6-E;F%M92`H
M96<N(&EM87`L('!O<"P@86-A<"!E=&,I"B`@("`J($!P87)A;2`@<W1R:6YG
M("1A=71H>FED("`@075T:&]R:7IA=&EO;B!I9"`H=7-E<FYA;64@=&\@<')O
M>'D@87,I"B`@("`J($!R971U<FX@<W1R:6YG("`@("`@("`@("`@5&AE(&1I
M9V5S="!R97-P;VYS92`H3D]4(&)A<V4V-"!E;F-O9&5D*0H@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(&=E=%)E<W!O;G-E*"1A
M=71H8VED+"`D<&%S<RP@)&-H86QL96YG92P@)&AO<W1N86UE+"`D<V5R=FEC
M92P@)&%U=&AZ:60@/2`G)RD*("`@('L*("`@("`@("`D8VAA;&QE;F=E(#T@
M)'1H:7,M/E]P87)S94-H86QL96YG92@D8VAA;&QE;F=E*3L*("`@("`@("`D
M875T:'II9%]S=')I;F<@/2`G)SL*("`@("`@("!I9B`H)&%U=&AZ:60@(3T@
M)R<I('L*("`@("`@("`@("`@)&%U=&AZ:61?<W1R:6YG(#T@)RQA=71H>FED
M/2(G("X@)&%U=&AZ:60@+B`G(B<[(`H@("`@("`@('T*"B`@("`@("`@:68@
M*"%E;7!T>2@D8VAA;&QE;F=E*2D@>PH@("`@("`@("`@("`D8VYO;F-E("`@
M("`@("`@/2`D=&AI<RT^7V=E=$-N;VYC92@I.PH@("`@("`@("`@("`D9&EG
M97-T7W5R:2`@("`@/2!S<')I;G1F*"<E<R\E<R<L("1S97)V:6-E+"`D:&]S
M=&YA;64I.PH@("`@("`@("`@("`D<F5S<&]N<V5?=F%L=64@/2`D=&AI<RT^
M7V=E=%)E<W!O;G-E5F%L=64H)&%U=&AC:60L("1P87-S+"`D8VAA;&QE;F=E
M6R=R96%L;2==+"`D8VAA;&QE;F=E6R=N;VYC92==+"`D8VYO;F-E+"`D9&EG
M97-T7W5R:2P@)&%U=&AZ:60I.PH*("`@("`@("`@("`@<F5T=7)N('-P<FEN
M=&8H)W5S97)N86UE/2(E<R(L<F5A;&T](B5S(B<@+B`D875T:'II9%]S=')I
M;F<@("X@)RQN;VYC93TB)7,B+&-N;VYC93TB)7,B+&YC/2(P,#`P,#`P,2(L
M<6]P/6%U=&@L9&EG97-T+75R:3TB)7,B+')E<W!O;G-E/25S+"5D)RP@)&%U
M=&AC:60L("1C:&%L;&5N9V5;)W)E86QM)UTL("1C:&%L;&5N9V5;)VYO;F-E
M)UTL("1C;F]N8V4L("1D:6=E<W1?=7)I+"`D<F5S<&]N<V5?=F%L=64L("1C
M:&%L;&5N9V5;)VUA>&)U9B==*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G26YV86QI9"!D:6=E<W0@
M8VAA;&QE;F=E)RD["B`@("`@("`@?0H@("`@?0H@("`@"B`@("`O*BH*("`@
M("H@4&%R<V5S(&%N9"!V97)I9FEE<R!T:&4@9&EG97-T(&-H86QL96YG92H*
M("`@("H*("`@("H@0'!A<F%M("!S=')I;F<@)&-H86QL96YG92!4:&4@9&EG
M97-T(&-H86QL96YG90H@("`@*B!`<F5T=7)N(&%R<F%Y("`@("`@("`@("`@
M(%1H92!P87)S960@8VAA;&QE;F=E(&%S(&%N(&%S<V]C"B`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87D@:6X@=&AE(&9O<FT@(F1I<F5C
M=&EV92`]/B!V86QU92(N"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@*B\*
M("`@(&9U;F-T:6]N(%]P87)S94-H86QL96YG92@D8VAA;&QE;F=E*0H@("`@
M>PH@("`@("`@("1T;VME;G,@/2!A<G)A>2@I.PH@("`@("`@('=H:6QE("AP
M<F5G7VUA=&-H*"<O7BA;82UZ+5TK*3TH(EM>(ETK*#\\(5Q<7"DB?%M>+%TK
M*2]I)RP@)&-H86QL96YG92P@)&UA=&-H97,I*2!["@H@("`@("`@("`@("`O
M+R!)9VYO<F4@=&AE<V4@87,@<&5R(')F8S(X,S$*("`@("`@("`@("`@:68@
M*"1M871C:&5S6S%=(#T]("=O<&%Q=64G($]2("1M871C:&5S6S%=(#T]("=D
M;VUA:6XG*2!["B`@("`@("`@("`@("`@("`D8VAA;&QE;F=E(#T@<W5B<W1R
M*"1C:&%L;&5N9V4L('-T<FQE;B@D;6%T8VAE<ULP72D@*R`Q*3L*("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`O+R!!;&QO=V5D(&UU;'1I<&QE(")R96%L;2(@86YD(")A=71H+7!A<F%M
M(@H@("`@("`@("`@("!I9B`H(65M<'1Y*"1T;VME;G-;)&UA=&-H97-;,5U=
M*2!!3D0@*"1M871C:&5S6S%=(#T]("=R96%L;2<@3U(@)&UA=&-H97-;,5T@
M/3T@)V%U=&@M<&%R86TG*2D@>PH@("`@("`@("`@("`@("`@:68@*&ES7V%R
M<F%Y*"1T;VME;G-;)&UA=&-H97-;,5U=*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1T;VME;G-;)&UA=&-H97-;,5U=6UT@/2!P<F5G7W)E<&QA8V4H)R]>
M(B@N*BDB)"\G+"`G7%PQ)RP@)&UA=&-H97-;,ETI.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&]K96YS6R1M871C
M:&5S6S%=72`](&%R<F%Y*"1T;VME;G-;)&UA=&-H97-;,5U=+"!P<F5G7W)E
M<&QA8V4H)R]>(B@N*BDB)"\G+"`G7%PQ)RP@)&UA=&-H97-;,ETI*3L*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O($%N>2!O=&AE<B!M=6QT
M:7!L92!I;G-T86YC92`](&9A:6QU<F4*("`@("`@("`@("`@?2!E;'-E:68@
M*"%E;7!T>2@D=&]K96YS6R1M871C:&5S6S%=72DI('L*("`@("`@("`@("`@
M("`@("1T;VME;G,@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1O:V5N
M<ULD;6%T8VAE<ULQ75T@/2!P<F5G7W)E<&QA8V4H)R]>(B@N*BDB)"\G+"`G
M7%PQ)RP@)&UA=&-H97-;,ETI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`O+R!296UO=F4@=&AE(&IU<W0@<&%R<V5D(&1I<F5C=&EV92!F<F]M('1H
M92!C:&%L;&5N9V4*("`@("`@("`@("`@)&-H86QL96YG92`]('-U8G-T<B@D
M8VAA;&QE;F=E+"!S=')L96XH)&UA=&-H97-;,%TI("L@,2D["B`@("`@("`@
M?0H*("`@("`@("`O*BH*("`@("`@("`J($1E9F%U;'1S(&%N9"!R97%U:7)E
M9"!D:7)E8W1I=F5S"B`@("`@("`@*B\*("`@("`@("`O+R!296%L;0H@("`@
M("`@(&EF("AE;7!T>2@D=&]K96YS6R=R96%L;2==*2D@>PH@("`@("`@("`@
M("`D=6YA;64@/2!P;W-I>%]U;F%M92@I.PH@("`@("`@("`@("`D=&]K96YS
M6R=R96%L;2==(#T@)'5N86UE6R=N;V1E;F%M92==.PH@("`@("`@('T*("`@
M("`@("`*("`@("`@("`O+R!-87AB=68*("`@("`@("!I9B`H96UP='DH)'1O
M:V5N<ULG;6%X8G5F)UTI*2!["B`@("`@("`@("`@("1T;VME;G-;)VUA>&)U
M9B==(#T@-C4U,S8["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@("\O(%)E
M<75I<F5D.B!N;VYC92P@86QG;W)I=&AM"B`@("`@("`@:68@*&5M<'1Y*"1T
M;VME;G-;)VYO;F-E)UTI($]2(&5M<'1Y*"1T;VME;G-;)V%L9V]R:71H;2==
M*2D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH*3L*("`@("`@("!]"B`@
M("`@("`@"B`@("`@("`@<F5T=7)N("1T;VME;G,["B`@("!]"@H@("`@+RHJ
M"B`@("`J($-R96%T97,@=&AE(')E<W!O;G-E/2!P87)T(&]F('1H92!D:6=E
M<W0@<F5S<&]N<V4*("`@("H*("`@("H@0'!A<F%M("!S=')I;F<@)&%U=&AC
M:60@("`@075T:&5N=&EC871I;VX@:60@*'5S97)N86UE*0H@("`@*B!`<&%R
M86T@('-T<FEN9R`D<&%S<R`@("`@("!087-S=V]R9`H@("`@*B!`<&%R86T@
M('-T<FEN9R`D<F5A;&T@("`@("!296%L;2!A<R!P<F]V:61E9"!B>2!T:&4@
M<V5R=F5R"B`@("`J($!P87)A;2`@<W1R:6YG("1N;VYC92`@("`@($YO;F-E
M(&%S('!R;W9I9&5D(&)Y('1H92!S97)V97(*("`@("H@0'!A<F%M("!S=')I
M;F<@)&-N;VYC92`@("`@0VQI96YT(&YO;F-E"B`@("`J($!P87)A;2`@<W1R
M:6YG("1D:6=E<W1?=7)I(%1H92!D:6=E<W0M=7)I/2!V86QU92!P87)T(&]F
M('1H92!R97-P;VYS90H@("`@*B!`<&%R86T@('-T<FEN9R`D875T:'II9"`@
M("!!=71H;W)I>F%T:6]N(&ED"B`@("`J($!R971U<FX@<W1R:6YG("`@("`@
M("`@("`@(%1H92!R97-P;VYS93T@<&%R="!O9B!T:&4@9&EG97-T(')E<W!O
M;G-E"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@*B\@("`@"B`@("!F=6YC
M=&EO;B!?9V5T4F5S<&]N<V5686QU92@D875T:&-I9"P@)'!A<W,L("1R96%L
M;2P@)&YO;F-E+"`D8VYO;F-E+"`D9&EG97-T7W5R:2P@)&%U=&AZ:60@/2`G
M)RD*("`@('L*("`@("`@("!I9B`H)&%U=&AZ:60@/3T@)R<I('L*("`@("`@
M("`@("`@)$$Q(#T@<W!R:6YT9B@G)7,Z)7,Z)7,G+"!P86-K*"=(,S(G+"!M
M9#4H<W!R:6YT9B@G)7,Z)7,Z)7,G+"`D875T:&-I9"P@)')E86QM+"`D<&%S
M<RDI*2P@)&YO;F-E+"`D8VYO;F-E*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D03$@/2!S<')I;G1F*"<E<SHE<SHE<SHE<R<L('!A8VLH)T@S
M,B<L(&UD-2AS<')I;G1F*"<E<SHE<SHE<R<L("1A=71H8VED+"`D<F5A;&TL
M("1P87-S*2DI+"`D;F]N8V4L("1C;F]N8V4L("1A=71H>FED*3L*("`@("`@
M("!]"B`@("`@("`@)$$R(#T@)T%55$A%3E1)0T%413HG("X@)&1I9V5S=%]U
M<FD["B`@("`@("`@<F5T=7)N(&UD-2AS<')I;G1F*"<E<SHE<SHP,#`P,#`P
M,3HE<SIA=71H.B5S)RP@;60U*"1!,2DL("1N;VYC92P@)&-N;VYC92P@;60U
M*"1!,BDI*3L*("`@('T*"B`@("`O*BH*("`@("H@0W)E871E<R!T:&4@8VQI
M96YT(&YO;F-E(&9O<B!T:&4@<F5S<&]N<V4*("`@("H*("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!C;F]N8V4@=F%L=64*("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$-N;VYC92@I"B`@("!["B`@
M("`@("`@:68@*&9I;&5?97AI<W1S*"<O9&5V+W5R86YD;VTG*2D@>PH@("`@
M("`@("`@("!R971U<FX@8F%S938T7V5N8V]D92AF<F5A9"AF;W!E;B@G+V1E
M=B]U<F%N9&]M)RP@)W(G*2P@,S(I*3L*"B`@("`@("`@?2!E;'-E:68@*&9I
M;&5?97AI<W1S*"<O9&5V+W)A;F1O;2<I*2!["B`@("`@("`@("`@(')E='5R
M;B!B87-E-C1?96YC;V1E*&9R96%D*&9O<&5N*"<O9&5V+W)A;F1O;2<L("=R
M)RDL(#,R*2D["@H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S='(@
M/2`G)SL*("`@("`@("`@("`@;71?<W)A;F0H*&1O=6)L92EM:6-R;W1I;64H
M*2HQ,#`P,#`P,"D["B`@("`@("`@("`@(&9O<B`H)&D],#L@)&D\,S([("1I
M*RLI('L*("`@("`@("`@("`@("`@("1S='(@+CT@8VAR*&UT7W)A;F0H,"P@
M,C4U*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@"B`@("`@("`@("`@
M(')E='5R;B!B87-E-C1?96YC;V1E*"1S='(I.PH@("`@("`@('T*("`@('T*
M?0H_/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O075T:"]305-,+TQO9VEN+G!H<```````````````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8R-S0`,3`U,34T,S,W,S0`,#(R,#0Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK(`T*+R\@?"!#
M;W!Y<FEG:'0@*&,I(#(P,#(M,C`P,R!2:6-H87)D($AE>65S("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?"`-"B\O('P@06QL(')I9VAT<R!R
M97-E<G9E9"X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P@#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\(`T*+R\@?"!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A
M;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70@("`@?"`-"B\O('P@
M;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE
M(&9O;&QO=VEN9R!C;VYD:71I;VYS("`@('P@#0HO+R!\(&%R92!M970Z("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\(`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?"`-"B\O('P@;R!2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@
M;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H="`@("`@('P@#0HO+R!\
M("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O
M;&QO=VEN9R!D:7-C;&%I;65R+B`@("`@("!\(`T*+R\@?"!O(%)E9&ES=')I
M8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O
M=F4@8V]P>7)I9VAT("`@?"`-"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O
M9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@
M=&AE('P@#0HO+R!\("`@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T
M97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BY\(`T*+R\@
M?"!O(%1H92!N86UE<R!O9B!T:&4@875T:&]R<R!M87D@;F]T(&)E('5S960@
M=&\@96YD;W)S92!O<B!P<F]M;W1E("`@("`@?"`-"B\O('P@("!P<F]D=6-T
M<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T('-P96-I9FEC
M('!R:6]R('=R:71T96X@('P@#0HO+R!\("`@<&5R;6ES<VEO;BX@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\(`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?"`-"B\O
M('P@5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4
M($A/3$1%4E,@04Y$($-/3E1224)55$]24R`@('P@#0HO+R!\(")!4R!)4R(@
M04Y$($%.62!%6%!215-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$
M24Y'+"!"550@3D]4("`@("!\(`T*+R\@?"!,24U)5$5$(%1/+"!42$4@24U0
M3$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!3D0@1DE43D53
M4R!&3U(@?"`-"B\O('P@02!005)424-53$%2(%!54E!/4T4@05)%($1)4T-,
M04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'2%0@('P@#0HO
M+R!\($]73D52($]2($-/3E1224)55$]24R!"12!,24%"3$4@1D]2($%.62!$
M25)%0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!\(`T*+R\@?"!34$5#24%,
M+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$
M24Y'+"!"550@3D]4("`@("`@?"`-"B\O('P@3$E-251%1"!43RP@4%)/0U52
M14U%3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL@3$]34R!/
M1B!54T4L('P@#0HO+R!\($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3
M($E.5$524E505$E/3BD@2$]7159%4B!#0553140@04Y$($].($%.62!\(`T*
M+R\@?"!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E.($-/3E1204-4
M+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4("`@?"`-"B\O('P@*$E.0TQ5
M1$E.1R!.14=,24=%3D-%($]2($]42$525TE312D@05))4TE.1R!)3B!!3ED@
M5T%9($]55"!/1B!42$4@55-%('P@#0HO+R!\($]&(%1(25,@4T]&5%=!4D4L
M($5614X@248@041625-%1"!/1B!42$4@4$]34TE"24Q)5%D@3T8@4U5#2"!$
M04U!1T4N("!\(`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?"`-
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L@#0HO+R!\($%U=&AO
M<CH@4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'`N;F5T/B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\(`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*R`-"B\O(`T*+R\@)$ED.B!,;V=I;BYP:'`L=B`Q+C0@,C`P
M,R\P,B\R,2`Q-CHP-SHQ-R!M:B!%>'`@)`T*#0HO*BH-"BH@5&AI<R!I<R!T
M96-H;FEC86QL>2!N;W0@82!305-,(&UE8VAA;FES;2P@:&]W979E<@T**B!I
M="=S('5S960@8GD@3F5T7U-I979E+"!.971?0WER=7,@86YD('!O=&5N=&EA
M;&QY#0HJ(&]T:&5R('!R;W1O8V]L<R`L('-O(&AE<F4@:7,@82!G;V]D('!L
M86-E('1O(&%B<W1R86-T#0HJ(&ET+@T**@T**B!`875T:&]R("!2:6-H87)D
M($AE>65S(#QR:6-H87)D0'!H<"YN970^#0HJ($!A8V-E<W,@('!U8FQI8PT*
M*B!`=F5R<VEO;B`Q+C`-"BH@0'!A8VMA9V4@075T:%]305-,#0HJ+PT*#0IR
M97%U:7)E7V]N8V4H)T%U=&@O4T%33"]#;VUM;VXN<&AP)RD[#0H-"F-L87-S
M($%U=&A?4T%33%],;V=I;B!E>'1E;F1S($%U=&A?4T%33%]#;VUM;VX-"GL-
M"B`@("`O*BH-"B`@("`J(%!S975D;R!305-,($Q/1TE.(&UE8VAA;FES;0T*
M("`@("H-"B`@("`J($!P87)A;2`@<W1R:6YG("1U<V5R(%5S97)N86UE#0H@
M("`@*B!`<&%R86T@('-T<FEN9R`D<&%S<R!087-S=V]R9`T*("`@("H@0')E
M='5R;B!S=')I;F<@("`@("`@3$]'24X@<W1R:6YG#0H@("`@*B\-"B`@("!F
M=6YC=&EO;B!G971297-P;VYS92@D=7-E<BP@)'!A<W,I#0H@("`@>PT*("`@
M("`@("!R971U<FX@<W!R:6YT9B@G3$]'24X@)7,@)7,G+"`D=7-E<BP@)'!A
M<W,I.PT*("`@('T-"GT-"C\^````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+T%U=&@O4T%33"]0;&%I;BYP:'``````````````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V,C4Q`#$P-3$U-#,S-S,T`#`R,C`R
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*R`-"B\O('P@
M0V]P>7)I9VAT("AC*2`R,#`R+3(P,#,@4FEC:&%R9"!(97EE<R`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R!\($%L;"!R:6=H=',@
M<F5S97)V960N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\(`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?"`-"B\O('P@4F5D:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@
M86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T("`@('P@#0HO+R!\
M(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H
M92!F;VQL;W=I;F<@8V]N9&ET:6]N<R`@("!\(`T*+R\@?"!A<F4@;65T.B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?"`-"B\O('P@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P@#0HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E
M(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@("`@("!\(`T*+R\@
M?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F
M;VQL;W=I;F<@9&ES8VQA:6UE<BX@("`@("`@?"`-"B\O('P@;R!2961I<W1R
M:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B
M;W9E(&-O<'ER:6=H="`@('P@#0HO+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@
M;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN
M('1H92!\(`T*+R\@?"`@(&1O8W5M96YT871I;VX@86YD+V]R(&]T:&5R(&UA
M=&5R:6%L<R!P<F]V:61E9"!W:71H('1H92!D:7-T<FEB=71I;VXN?"`-"B\O
M('P@;R!4:&4@;F%M97,@;V8@=&AE(&%U=&AO<G,@;6%Y(&YO="!B92!U<V5D
M('1O(&5N9&]R<V4@;W(@<')O;6]T92`@("`@('P@#0HO+R!\("`@<')O9'5C
M=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4@=VET:&]U="!S<&5C:69I
M8R!P<FEO<B!W<FET=&5N("!\(`T*+R\@?"`@('!E<FUI<W-I;VXN("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?"`-"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO
M+R!\(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(
M5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,@("!\(`T*+R\@?"`B05,@25,B
M($%.1"!!3ED@15A04D534R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ5
M1$E.1RP@0E54($Y/5"`@("`@?"`-"B\O('P@3$E-251%1"!43RP@5$A%($E-
M4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%
M4U,@1D]2('P@#0HO+R!\($$@4$%25$E#54Q!4B!055)03U-%($%212!$25-#
M3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@0T]065))1TA4("!\(`T*
M+R\@?"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%($9/4B!!3ED@
M1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@?"`-"B\O('P@4U!%0TE!
M3"P@15A%35!,05)9+"!/4B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ5
M1$E.1RP@0E54($Y/5"`@("`@('P@#0HO+R!\($Q)34E4140@5$\L(%!23T-5
M4D5-14Y4($]&(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@
M3T8@55-%+"!\(`T*+R\@?"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D53
M4R!)3E1%4E)54%1)3TXI($A/5T5615(@0T%54T5$($%.1"!/3B!!3ED@?"`-
M"B\O('P@5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)3B!#3TY44D%#
M5"P@4U1224-4($Q)04))3$E462P@3U(@5$]25"`@('P@#0HO+R!\("A)3D-,
M541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X@04Y9
M(%=!62!/550@3T8@5$A%(%5312!\(`T*+R\@?"!/1B!42$E3(%-/1E1705)%
M+"!%5D5.($E&($%$5DE3140@3T8@5$A%(%!/4U-)0DE,2519($]&(%-50T@@
M1$%-04=%+B`@?"`-"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@
M#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK(`T*+R\@?"!!=71H
M;W(Z(%)I8VAA<F0@2&5Y97,@/')I8VAA<F1`<&AP+FYE=#X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?"`-"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L@#0HO+R`-"B\O("1)9#H@4&QA:6XN<&AP+'8@,2XU(#(P
M,#,O,#(O,C$@,38Z,#<Z,3<@;6H@17AP("0-"@T*+RHJ#0HJ($EM<&QM96YT
M871I;VX@;V8@4$Q!24X@4T%33"!M96-H86YI<VT-"BH-"BH@0&%U=&AO<B`@
M4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'`N;F5T/@T**B!`86-C97-S("!P
M=6)L:6,-"BH@0'9E<G-I;VX@,2XP#0HJ($!P86-K86=E($%U=&A?4T%33`T*
M*B\-"@T*<F5Q=6ER95]O;F-E*"=!=71H+U-!4TPO0V]M;6]N+G!H<"<I.PT*
M#0IC;&%S<R!!=71H7U-!4TQ?4&QA:6X@97AT96YD<R!!=71H7U-!4TQ?0V]M
M;6]N#0I[#0H@("`@+RHJ#0H@("`@*B!2971U<FYS(%!,04E.(')E<W!O;G-E
M#0H@("`@*@T*("`@("H@0'!A<F%M("!S=')I;F<@)&%U=&AC:60@("!!=71H
M96YT:6-A=&EO;B!I9"`H=7-E<FYA;64I#0H@("`@*B!`<&%R86T@('-T<FEN
M9R`D<&%S<R`@("`@(%!A<W-W;W)D#0H@("`@*B!`<&%R86T@('-T<FEN9R`D
M875T:'II9"`@($%U=&]R:7IA=&EO;B!I9`T*("`@("H@0')E='5R;B!S=')I
M;F<@("`@("`@("`@("!03$%)3B!297-P;VYS90T*("`@("HO#0H@("`@9G5N
M8W1I;VX@9V5T4F5S<&]N<V4H)&%U=&AC:60L("1P87-S+"`D875T:'II9"`]
M("<G*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1A=71H>FED("X@8VAR*#`I
M("X@)&%U=&AC:60@+B!C:'(H,"D@+B`D<&%S<SL-"B`@("!]#0I]#0H_/@T*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]!=71H+U-!4TPN<&AP````````````````````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,#(P-``Q,#4Q-30S,S<S-``P,C`W
M-34`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L@#0HO+R!\
M($-O<'ER:6=H="`H8RD@,C`P,BTR,#`S(%)I8VAA<F0@2&5Y97,@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@?"!!;&P@<FEG:'1S
M(')E<V5R=F5D+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?"`-"B\O('P@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P@#0HO+R!\(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E
M(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U="`@("!\(`T*+R\@
M?"!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T
M:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,@("`@?"`-"B\O('P@87)E(&UE=#H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P@#0HO+R!\("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\(`T*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D
M92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT("`@("`@?"`-"B\O
M('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@
M9F]L;&]W:6YG(&1I<V-L86EM97(N("`@("`@('P@#0HO+R!\(&\@4F5D:7-T
M<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A
M8F]V92!C;W!Y<FEG:'0@("!\(`T*+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T
M(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I
M;B!T:&4@?"`-"B\O('P@("!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M
M871E<FEA;',@<')O=FED960@=VET:"!T:&4@9&ES=')I8G5T:6]N+GP@#0HO
M+R!\(&\@5&AE(&YA;65S(&]F('1H92!A=71H;W)S(&UA>2!N;W0@8F4@=7-E
M9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@("`@("!\(`T*+R\@?"`@('!R;V1U
M8W1S(&1E<FEV960@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E8VEF
M:6,@<')I;W(@=W)I='1E;B`@?"`-"B\O('P@("!P97)M:7-S:6]N+B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P@#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*
M+R\@?"!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'
M2%0@2$],1$524R!!3D0@0T].5%))0E543U)3("`@?"`-"B\O('P@(D%3($E3
M(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,
M541)3D<L($)55"!.3U0@("`@('P@#0HO+R!\($Q)34E4140@5$\L(%1(12!)
M35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519($%.1"!&251.
M15-3($9/4B!\(`T*+R\@?"!!(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E3
M0TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%($-/4%E224=(5"`@?"`-
M"B\O('P@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),12!&3U(@04Y9
M($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL('P@#0HO+R!\(%-014-)
M04PL($5814U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,
M541)3D<L($)55"!.3U0@("`@("!\(`T*+R\@?"!,24U)5$5$(%1/+"!04D]#
M55)%345.5"!/1B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3
M($]&(%5312P@?"`-"B\O('P@1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%
M4U,@24Y415)255!424].*2!(3U=%5D52($-!55-%1"!!3D0@3TX@04Y9('P@
M#0HO+R!\(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X@0T].5%)!
M0U0L(%-44DE#5"!,24%"24Q)5%DL($]2(%1/4E0@("!\(`T*+R\@?"`H24Y#
M3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E.($%.
M62!705D@3U54($]&(%1(12!54T4@?"`-"B\O('P@3T8@5$A)4R!33T945T%2
M12P@159%3B!)1B!!1%9)4T5$($]&(%1(12!03U-324))3$E462!/1B!354-(
M($1!34%'12X@('P@#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M(`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*R`-"B\O('P@075T
M:&]R.B!2:6-H87)D($AE>65S(#QR:6-H87)D0'!H<"YN970^("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK(`T*+R\@#0HO+R`D260Z(%-!4TPN<&AP+'8@,2XT(#(P
M,#,O,#(O,C$@,38Z,#<Z,3<@;6H@17AP("0-"@T*+RHJ#0HJ($-L:65N="!I
M;7!L96UE;G1A=&EO;B!O9B!V87)I;W5S(%-!4TP@;65C:&%N:7-M<R`-"BH-
M"BH@0&%U=&AO<B`@4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'`N;F5T/@T*
M*B!`86-C97-S("!P=6)L:6,-"BH@0'9E<G-I;VX@,2XP#0HJ($!P86-K86=E
M($%U=&A?4T%33`T**B\-"@T*<F5Q=6ER95]O;F-E*"=014%2+G!H<"<I.PT*
M#0IC;&%S<R!!=71H7U-!4TP-"GL-"B`@("`O*BH-"B`@("`J($9A8W1O<GD@
M8VQA<W,N(%)E='5R;G,@86X@;V)J96-T(&]F('1H92!R97%U97-T#0H@("`@
M*B!T>7!E+@T*("`@("H-"B`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@3VYE
M(&]F.B!!;F]N>6UO=7,-"B`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!0;&%I;@T*("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($-R86U-1#4-"B`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$
M:6=E<W1-1#4-"B`@("`J("`@("`@("`@("`@("`@("`@("`@5'EP97,@87)E
M(&YO="!C87-E('-E;G-I=&EV90T*("`@("HO#0H@("`@9G5N8W1I;VX@)F9A
M8W1O<GDH)'1Y<&4I#0H@("`@>PT*("`@("`@("!S=VET8V@@*'-T<G1O;&]W
M97(H)'1Y<&4I*2![#0H@("`@("`@("`@("!C87-E("=A;F]N>6UO=7,G.@T*
M("`@("`@("`@("`@("`@("1F:6QE;F%M92`@/2`G075T:"]305-,+T%N;VYY
M;6]U<RYP:'`G.PT*("`@("`@("`@("`@("`@("1C;&%S<VYA;64@/2`G075T
M:%]305-,7T%N;VYY;6]U<R<[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H-
M"B`@("`@("`@("`@(&-A<V4@)VQO9VEN)SH-"B`@("`@("`@("`@("`@("`D
M9FEL96YA;64@(#T@)T%U=&@O4T%33"],;V=I;BYP:'`G.PT*("`@("`@("`@
M("`@("`@("1C;&%S<VYA;64@/2`G075T:%]305-,7TQO9VEN)SL-"B`@("`@
M("`@("`@("`@("!B<F5A:SL-"@T*("`@("`@("`@("`@8V%S92`G<&QA:6XG
M.@T*("`@("`@("`@("`@("`@("1F:6QE;F%M92`@/2`G075T:"]305-,+U!L
M86EN+G!H<"<[#0H@("`@("`@("`@("`@("`@)&-L87-S;F%M92`]("=!=71H
M7U-!4TQ?4&QA:6XG.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*#0H@("`@
M("`@("`@("!C87-E("=C<F%M;60U)SH-"B`@("`@("`@("`@("`@("`D9FEL
M96YA;64@(#T@)T%U=&@O4T%33"]#<F%M340U+G!H<"<[#0H@("`@("`@("`@
M("`@("`@)&-L87-S;F%M92`]("=!=71H7U-!4TQ?0W)A;4U$-2<[#0H@("`@
M("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@(&-A<V4@)V1I9V5S
M=&UD-2<Z#0H@("`@("`@("`@("`@("`@)&9I;&5N86UE("`]("=!=71H+U-!
M4TPO1&EG97-T340U+G!H<"<[#0H@("`@("`@("`@("`@("`@)&-L87-S;F%M
M92`]("=!=71H7U-!4TQ?1&EG97-T340U)SL-"B`@("`@("`@("`@("`@("!B
M<F5A:SL-"@T*("`@("`@("`@("`@9&5F875L=#H-"B`@("`@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G26YV86QI9"!305-,(&UE8VAA
M;FES;2!T>7!E)RD[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M('T-"@T*("`@("`@("!R97%U:7)E7V]N8V4H)&9I;&5N86UE*3L-"B`@("`@
M("`@<F5T=7)N(&YE=R`D8VQA<W-N86UE*"D[#0H@("`@?0T*?0T*#0H_/@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+T-A8VAE+P``````````````````````````````````````````````
M`````````````````````````````````````#`P,#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S,T`#`Q-S8P-P`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O0V%C:&4O07!P;&EC871I;VXN<&AP````
M````````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3,P-3(`,3`U,34T,S,W
M,S0`,#(R-38T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\(%!%05(@.CH@0V%C:&4@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P
M,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES
M('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H
M92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I
M=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@
M("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@
M<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@
M?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I
M;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%)I8VAA<F0@2&5Y97,@/')I
M8VAA<F1`<&AP9W5R=2YO<F<^("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@07!P
M;&EC871I;VXN<&AP+'8@,2XU(#(P,#,O,#$O,#0@,3$Z-30Z-#4@;6H@17AP
M("0*"G)E<75I<F5?;VYC92`G0V%C:&4N<&AP)SL*"B\O($%P<&QI8V%T:6]N
M(&QE=F5L('9A<FEA8FQE<PHO+PHO+R!0=7)P;W-E"B\O(%9A<FEA8FQE<R!T
M:&%T(&%R92!P97)S:7-E;G0@86-R;W-S(&%L;"!U<V5R('-E<W-I;VYS+`HO
M+R!N;W0@:G5S="!A('-P96-I9FEC('5S97(@86QA(&YO<FUA;"!S97-S:6]N
M<RX*+R\*+R\@57-A9V4Z"B\O"B\O($5X86UP;&4@,3H*+R\*+R\@)&%P<"`@
M/28@;F5W($-A8VAE7T%P<&QI8V%T:6]N*"D["B\O("1?05!0(#TF("1A<'`M
M/F=E=$1A=&$H*3L*+R\*+R\@26X@=&AI<R!C87-E('1H92`D7T%04"!V87)I
M86)L92!I<R!A:VEN('1O('1H92`D7U-%4U-)3TX@=F%R:6%B;&4N"B\O($EF
M('EO=2!A9&0O<F5M;W9E('-T=69F+"!I="!W:6QL(&)E(')E9FQE8W1E9"!I
M;B!T:&4@;F5X="!R97%U97-T"B\O("AO9B!A;GD@=7-E<BDN"B\O"B\O($5X
M86UP;&4@,CH*+R\*+R\@)&9O;R`]("=3;VUE(&1A=&$G.PHO+R`D8F%R(#T@
M)U-O;64@;W1H97(@9&%T82<["B\O"B\O("1A<'`@/28@;F5W($-A8VAE7T%P
M<&QI8V%T:6]N*"D["B\O("1A<'`M/G)E9VES=&5R*"=F;V\G*3L*+R\@)&%P
M<"T^<F5G:7-T97(H)V)A<B<L("1B87(I.R`*+R\*+R\@)&9O;R`]("=$:69F
M97)E;G0@9&%T82<["B\O"B\O($EN('1H:7,@8V%S92!T:&4@=F%R:6%B;&5S
M(&%R92!R96=I<W1E<F5D('=I=&@@=&AE(')E9VES=&5R*"D@9G5N8W1I;VXN
M"B\O(%1H:7,@:7,@86MI;B!T;R!S97-S:6]N7W)E9VES=&5R*"DN"B\O"B\O
M($%S('=I=&@@<V5S<VEO;E]R96=I<W1E<B@I+"!T:&4@8V]N=&5N=',@;V8@
M=&AE('9A<FEA8FQE(&%T('1H92`J96YD*B!O9B!T:&4*+R\@<F5Q=65S="!I
M<R!R96=I<W1E<F5D(&%N9"!N;W0@870@=&AE('!O:6YT(&]F(')E9VES=')A
M=&EO;BX@5&AE<F5F;W)E(&EN('1H:7,*+R\@97AA;7!L92P@9F]R('1H92`D
M9F]O('9A<FEA8FQE+"!T:&4@<W1R:6YG("=$:69F97)E;G0@9&%T82<@:7,@
M<W1O<F5D(&%N9"!N;W0@"B\O("=3;VUE(&1A=&$G+B!4:&4@97AC97!T:6]N
M('1O('1H:7,@<G5L92!I<R!I9B!Y;W4@=7-E('1H92!S96-O;F0@87)G=6UE
M;G0@=&\*+R\@<F5G:7-T97(H*2!A<R!I;B!T:&4@<V5C;VYD(&-A;&P@=&\@
M:70@86)O=F4N(%1H:7,@=VEL;"!C875S92!T:&4@9&%T82!S=7!P;&EE9`HO
M+R!I;B!T:&4@<V5C;VYD(&%R9W5M96YT('1O(&)E('-T;W)E9"!A;F0@;F]T
M('1H92!C;VYT96YT<R!A="!T:&4@96YD(&]F('1H92!R97%U97-T+@HO+PHO
M+R!.;W1E.B!)9B!Y;W4@=7-E('1H:7,@;65T:&]D('=I=&@@<F5G:7-T97)?
M9VQO8F%L<R!T=7)N960@;VXL('1H92!V87)I86)L97,@=VEL;"!B90HO+R`@
M("`@("!A=71O;6%T:6-A;&QY(&=L;V)A;&QE9"!U<&]N('-T87)T=7`L("AI
M92X@=VAE;B!Y;W4@8W)E871E('1H92!O8FIE8W0I+@HO+PHO+R!.;W1E.B!)
M9B!Y;W4@<F5G:7-T97(@82!V87)I86)L92!T:&%T(&ES(&YO="!S970@=VAE
M;B!T:&4@<V-R:7!T(&9I;FES:&5S+"!I="!W:6QL"B\O("`@("`@(')E9VES
M=&5R960@87,@3E5,3"X*+R\*+R\*+R\@*BHJ(%EO=2!A<F4@<W1R;VYG;'D@
M<F5C;VUM96YD960@=&\@=7-E(&]N;'D@;VYE(&UE=&AO9"!O9B!T:&4@='=O
M(&%B;W9E+B`J*BH*+R\*+R\@*$EN(&9A8W0@:68@>6]U('5S92!T:&4@<F5G
M:7-T97(H*2!F=6YC=&EO;B!W:71H(')E9VES=&5R7V=L;V)A;',@3V9F+"!Y
M;W4@:&%V92!T;PHO+R`@=7-E('1H92`D7T%04"!M971H;V0@=&\@9V5T(&%T
M('1H92!D871A*2X*"F-L87-S($-A8VAE7T%P<&QI8V%T:6]N(&5X=&5N9',@
M0V%C:&4@>PH*("`@('9A<B`D9&%T83L*("`@('9A<B`D:60["B`@("!V87(@
M)&=R;W5P.PH@("`@=F%R("1R96=I<W1E<F5D7W9A<G,["@H@("`@+RHJ"B`@
M("`J($-O;G-T<G5C=&]R"B`@("`J"B`@("`J($!P87)A;2`@("!S=')I;F<@
M($YA;64@;V8@8V]N=&%I;F5R(&-L87-S"B`@("`J($!P87)A;2`@("!A<G)A
M>2`@($%R<F%Y('=I=&@@8V]N=&%I;F5R(&-L87-S(&]P=&EO;G,*("`@("HO
M"B`@("!F=6YC=&EO;B!#86-H95]!<'!L:6-A=&EO;B@D8V]N=&%I;F5R(#T@
M)V9I;&4G+"`D8V]N=&%I;F5R7V]P=&EO;G,@/2!A<G)A>2@G8V%C:&5?9&ER
M)R`]/B`G+W1M<"\G+"`G9FEL96YA;65?<')E9FEX)R`]/B`G8V%C:&5?)RDL
M("1I9"`]("=A<'!L:6-A=&EO;E]V87(G+"`D9W)O=7`@/2`G87!P;&EC871I
M;VY?8V%C:&4G*0H@("`@>PH@("`@("`@("1T:&ES+3YI9"`@("`]("1I9#L*
M("`@("`@("`D=&AI<RT^9W)O=7`@/2`D9W)O=7`["B`@("`@("`@)'1H:7,M
M/G)E9VES=&5R961?=F%R<R`](&%R<F%Y*"D["@H@("`@("`@("1T:&ES+3Y#
M86-H92@D8V]N=&%I;F5R+"`D8V]N=&%I;F5R7V]P=&EO;G,I.PH@("`@("`@
M("1T:&ES+3YD871A(#T@)'1H:7,M/FES0V%C:&5D*"1T:&ES+3YI9"P@)'1H
M:7,M/F=R;W5P*2`_('5N<V5R:6%L:7IE*"1T:&ES+3YG970H)'1H:7,M/FED
M+"`D=&AI<RT^9W)O=7`I*2`Z(&%R<F%Y*"D["@H@("`@("`@("\O($EF(')E
M9VES=&5R7V=L;V)A;',@;VXL(&=L;V)A;"!A;&P@<F5G:7-T97)E9"!V87)I
M86)L97,*("`@("`@("!I9B`H:6YI7V=E="@G<F5G:7-T97)?9VQO8F%L<R<I
M($%.1"!I<U]A<G)A>2@D=&AI<RT^9&%T82DI('L*("`@("`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/F1A=&$@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@
M("`@("`@("`@(&=L;V)A;"`D)&ME>3L*("`@("`@("`@("`@("`@("0D:V5Y
M(#T@)'9A;'5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@*B!$97-T<G5C=&]R"B`@("`J"B`@("`J($=E=',@=F%L=65S
M(&]F(&%L;"!R96=I<W1E<F5D('9A<FEA8FQE<R!A;F0@<W1O<F5S('1H96TN
M(%1H96X@8V%L;',@<V%V92@I('1O"B`@("`J('=R:71E(&1A=&$@87=A>2X*
M("`@("HO"B`@("!F=6YC=&EO;B!?0V%C:&5?07!P;&EC871I;VXH*0H@("`@
M>PH@("`@("`@("\O($=E="!C;VYT96YT<R!O9B!A;&P@<F5G:7-T97)E9"!V
M87)I86)L97,*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/G)E9VES=&5R
M961?=F%R<RD@04Y$("%E;7!T>2@D=&AI<RT^<F5G:7-T97)E9%]V87)S*2D@
M>PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^<F5G:7-T97)E9%]V87)S
M(&%S("1V87)N86UE*2!["B`@("`@("`@("`@("`@("!G;&]B86P@)"1V87)N
M86UE.PH@("`@("`@("`@("`@("`@)'1H:7,M/F1A=&%;)'9A<FYA;65=(#T@
M)"1V87)N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M+R!3879E('1H92!D871A"B`@("`@("`@)'1H:7,M/G-A=F4H)'1H:7,M/FED
M+"!S97)I86QI>F4H)'1H:7,M/F1A=&$I+"`P+"`D=&AI<RT^9W)O=7`I.PH@
M("`@?0H*("`@("\J*@H@("`@*B!R96=I<W1E<B@I"B`@("`J"B`@("`J(%)E
M9VES=&5R<R!A('9A<FEA8FQE('1O(&)E('-T;W)E9"X*("`@("H*("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@3F%M92!O9B!V87)I86)L92!T;R!R96=I<W1E
M<@H@("`@*B!`<&%R86T@("`@;6EX960@("!/<'1I;VYA;"!D871A('1O('-T
M;W)E"B`@("`J+PH@("`@9G5N8W1I;VX@<F5G:7-T97(H)'9A<FYA;64L("1D
M871A(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-S970H)&1A=&$I*2![
M"B`@("`@("`@("`@("1T:&ES+3YD871A6R1V87)N86UE72`]("1D871A.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YR96=I<W1E<F5D
M7W9A<G-;72`]("1V87)N86UE.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("H@=6YR96=I<W1E<B@I"B`@("`J"B`@("`J(%5N<F5G:7-T97)S(&$@
M=F%R:6%B;&4@9G)O;2!B96EN9R!S=&]R960N"B`@("`J"B`@("`J($!P87)A
M;2`@("!S=')I;F<@($YA;64@;V8@=F%R:6%B;&4@=&\@=6YR96=I<W1E<@H@
M("`@*B\*("`@(&9U;F-T:6]N('5N<F5G:7-T97(H)'9A<FYA;64I"B`@("![
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YD871A6R1V87)N86UE72DI('L*
M("`@("`@("`@("`@=6YS970H)'1H:7,M/F1A=&%;)'9A<FYA;65=*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`J(&-L96%R*"D*("`@("H*("`@
M("H@4F5M;W9E<R!A;&P@<W1O<F5D(&1A=&$*("`@("HO"B`@("!F=6YC=&EO
M;B!C;&5A<B@I"B`@("!["B`@("`@("`@)'1H:7,M/F1A=&$@/2!A<G)A>2@I
M.PH@("`@?0H*("`@("\J*@H@("`@*B!G971$871A*"D*("`@("H*("`@("H@
M57-E('1H:7,@=&\@9V5T(&$@<F5F97)E;F-E('1O('1H92!D871A('1O(&UA
M;FEP=6QA=&4*("`@("H@:6X@8V%L;&EN9R!S8W)I<'0N($5G+B`D7T%04"`]
M)B`D;V)J+3YG971$871A*"D["B`@("`J"B`@("`J($!R971U<FX@;6EX960@
M("!!(')E9F5R96YC92!T;R!T:&4@9&%T80H@("`@*B\*("`@(&9U;F-T:6]N
M("9G971$871A*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F1A=&$[
M"B`@("!]"GT*/SX`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]#86-H92]#;VYT86EN97(O````````````````
M```````````````````````````````````````````````````````P,#`P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<S-``P
M,C$U,S$`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-A8VAE+T-O;G1A
M:6YE<B]D8BYP:'``````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(R
M,S,P`#$P-3$U-#,S-S,T`#`R,C8R-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!014%2(#HZ($-A8VAE("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H
M8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@
M,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@
M8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%
M+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO
M=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A
M;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@
M("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO
M=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!5;&8@5V5N
M9&5L(#QU;&8N=V5N9&5L0'!H<&1O8RYD93X@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O('P@("`@("`@("`@4V5B87-T:6%N($)E<F=M86YN(#QS
M8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^("`@("`@("`@("`@("`@?`HO+R!\
M("`@("`@("`@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/B`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@9&(N<&AP+'8@,2XU(#(P,#,O,#$O
M,#0@,3$Z-30Z-#8@;6H@17AP("0*"G)E<75I<F5?;VYC92`G1$(N<&AP)SL*
M<F5Q=6ER95]O;F-E("=#86-H92]#;VYT86EN97(N<&AP)SL*"B\J*@HJ(%!%
M05(O1$(@0V%C:&4@0V]N=&%I;F5R+@HJ"BH@5T%23DE.1SH@3W1H97(@<WES
M=&5M<R!M:6=H="!O<B!M:6=H="!N;W0@<W5P<&]R="!C97)T86EN(&1A=&%T
M>7!E<R!O9@HJ('1H92!T86)L97,@<VAO=VXN($%S(&9A<B!A<R!)(&MN;W<@
M=&AE<F4G<R!N;R!L87)G92!B:6YA<GD**B!T>7!E(&EN(%-13"TY,B!O<B!3
M44PM.3DN(%!O<W1G<F5S('-E96US('1O(&QA8VL@86YY"BH@0DQ/0B!O<B!4
M15A4('1Y<&4L(&9O<B!-4RU344P@>6]U(&-O=6QD('5S92!)34%'12P@9&]N
M)W0@:VYO=PHJ(&%B;W5T(&]T:&5R(&1A=&%B87-E<RX@4&QE87-E(&%D9"!S
M=6=E<W1I;VYS(&9O<B!O=&AE<B!D871A8F%S97,@=&\**B!T:&4@:6YL:6YE
M(&1O8W,N"BH**B!4:&4@9FEE;&0@)V-H86YG960G(&AA<R!N;R!M96%N:6YG
M(&9O<B!T:&4@0V%C:&4@:71S96QF+B!)="=S(&IU<W0@=&AE<F4**B!B96-A
M=7-E(&ET)W,@82!G;V]D(&ED96$@=&\@:&%V92!A;B!A=71O;6%T:6-A;&QY
M('5P9&%T960@=&EM97-T86UP"BH@9FEE;&0@9F]R(&1E8G5G9VEN9R!I;B!A
M;&P@;V8@>6]U<B!T86)L97,N"BH**B!&;W(@7TUY4U%,7R!Y;W4@;F5E9"!T
M:&ES($1"('1A8FQE.@HJ"BH@0U)%051%(%1!0DQ%(&-A8VAE("@**B`@(&ED
M("`@("`@("`@($-(05(H,S(I($Y/5"!.54Q,($1%1D%53%0@)R<L"BH@("!C
M86-H96=R;W5P("!605)#2$%2*#$R-RD@3D]4($Y53$P@1$5&055,5"`G)RP*
M*B`@(&-A8VAE9&%T82`@($),3T(@3D]4($Y53$P@1$5&055,5"`G)RP**B`@
M('5S97)D871A("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"!$149!54P@)R<L
M"BH@("!E>'!I<F5S("`@("!)3E0H.2D@3D]4($Y53$P@1$5&055,5"`P+`HJ
M"BH@("!C:&%N9V5D("`@("!424U%4U1!35`H,30I($Y/5"!.54Q,+`HJ"BH@
M("!)3D1%6"`H97AP:7)E<RDL"BH@("!04DE-05)9($M%62`H:60L(&-A8VAE
M9W)O=7`I"BH@*0HJ"BH@0&%U=&AO<B`@(%-E8F%S=&EA;B!"97)G;6%N;B`\
M<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@HJ($!V97)S:6]N("`D260Z(&1B
M+G!H<"QV(#$N-2`R,#`S+S`Q+S`T(#$Q.C4T.C0V(&UJ($5X<"`D"BH@0'!A
M8VMA9V4@($-A8VAE"BHO"F-L87-S($-A8VAE7T-O;G1A:6YE<E]D8B!E>'1E
M;F1S($-A8VAE7T-O;G1A:6YE<B!["@H@("`@+RHJ"B`@("`J($YA;64@;V8@
M=&AE($1"('1A8FQE('1O('-T;W)E(&-A8VAI;F<@9&%T80H@("`@*@H@("`@
M*B!`<V5E("!#86-H95]#;VYT86EN97)?9FEL93HZ)&9I;&5N86UE7W!R969I
M>`H@("`@*B\*("`@('9A<B`D8V%C:&5?=&%B;&4@/2`G)SL*"B`@("`O*BH*
M("`@("H@4$5!4B!$0B!D<VX@=&\@=7-E+@H@("`@*@H@("`@*B!`=F%R("!S
M=')I;F<*("`@("HO"B`@("!V87(@)&1S;B`]("<G.PH*("`@("\J*@H@("`@
M*B!014%2($1"(&]B:F5C=`H@("`@*@H@("`@*B!`=F%R("!O8FIE8W0@4$5!
M4E]$0@H@("`@*B\*("`@('9A<B`D9&(["@H@("`@9G5N8W1I;VX@0V%C:&5?
M0V]N=&%I;F5R7V1B*"1O<'1I;VYS*0H@("`@>PH@("`@("`@(&EF("@A:7-?
M87)R87DH)&]P=&EO;G,I('Q\("%I<W-E="@D;W!T:6]N<ULG9'-N)UTI*2![
M"B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)TYO(&1S;B!S
M<&5C:69I960A)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3YS971/<'1I;VYS*"1O<'1I;VYS+"`@87)R87E?;65R
M9V4H)'1H:7,M/F%L;&]W961?;W!T:6]N<RP@87)R87DH)V1S;B<L("=C86-H
M95]T86)L92<I*2D["@H@("`@("`@(&EF("@A)'1H:7,M/F1S;BD*("`@("`@
M("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G3F\@9'-N('-P96-I9FEE
M9"$G+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@("`D=&AI<RT^9&(@
M/2!$0CHZ8V]N;F5C="@D=&AI<RT^9'-N+"!T<G5E*3L*("`@("`@("!I9B`H
M1$(Z.FES17)R;W(H)'1H:7,M/F1B*2D@>PH@("`@("`@("`@("!R971U<FX@
M;F5W($-A8VAE7T5R<F]R*"=$0CHZ8V]N;F5C="!F86EL960Z("<@+B!$0CHZ
M97)R;W)-97-S86=E*"1T:&ES+3YD8BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/F1B+3YS971&
M971C:$UO9&4H1$)?1D540TA-3T1%7T%34T]#*3L*("`@("`@("!]"B`@("!]
M"@H@("`@9G5N8W1I;VX@9F5T8V@H)&ED+"`D9W)O=7`I"B`@("!["B`@("`@
M("`@)'%U97)Y(#T@<W!R:6YT9B@B4T5,14-4(&-A8VAE9&%T82P@=7-E<F1A
M=&$L(&5X<&ER97,@1E)/32`E<R!72$5212!I9"`]("<E<R<@04Y$(&-A8VAE
M9W)O=7`@/2`G)7,G(BP*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YC86-H95]T86)L92P*("`@("`@("`@("`@("`@("`@("`@("`@(&%D9'-L
M87-H97,H)&ED*2P*("`@("`@("`@("`@("`@("`@("`@("`@(&%D9'-L87-H
M97,H)&=R;W5P*0H@("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@
M("`@)')E<R`]("1T:&ES+3YD8BT^<75E<GDH)'%U97)Y*3L*"B`@("`@("`@
M:68@*$1".CII<T5R<F]R*"1R97,I*0H@("`@("`@("`@("!R971U<FX@;F5W
M($-A8VAE7T5R<F]R*"=$0CHZ<75E<GD@9F%I;&5D.B`G("X@1$(Z.F5R<F]R
M365S<V%G92@D<F5S*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@
M)')O=R`]("1R97,M/F9E=&-H4F]W*"D["B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1R;W<I*0H@("`@("`@("`@("`D9&%T82`](&%R<F%Y*"1R;W=;)V5X<&ER
M97,G72P@)'1H:7,M/F1E8V]D92@D<F]W6R=C86-H961A=&$G72DL("1R;W=;
M)W5S97)D871A)UTI.PH@("`@("`@(&5L<V4*("`@("`@("`@("`@)&1A=&$@
M/2!A<G)A>2A.54Q,+"!.54Q,+"!.54Q,*3L*"B`@("`@("`@+R\@;&%S="!U
M<V5D(')E<75I<F5D(&)Y('1H92!G87)B86=E(&-O;&QE8W1I;VX*("`@("`@
M("`O+R!705).24Y'.B!M:6=H="!B92!->5-13"!S<&5C:69I8PH@("`@("`@
M("1Q=65R>2`]('-P<FEN=&8H(E501$%412`E<R!3150@8VAA;F=E9"`]("A.
M3U<H*2`K(#`I(%=(15)%(&ED(#T@)R5S)R!!3D0@8V%C:&5G<F]U<"`]("<E
M<R<B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-A8VAE
M7W1A8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@861D<VQA<VAE
M<R@D:60I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@861D<VQA<VAE
M<R@D9W)O=7`I"B`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@
M("`@)')E<R`]("1T:&ES+3YD8BT^<75E<GDH)'%U97)Y*3L*"B`@("`@("`@
M:68@*$1".CII<T5R<F]R*"1R97,I*0H@("`@("`@("`@("!R971U<FX@;F5W
M($-A8VAE7T5R<F]R*"=$0CHZ<75E<GD@9F%I;&5D.B`G("X@1$(Z.F5R<F]R
M365S<V%G92@D<F5S*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@
M<F5T=7)N("1D871A.PH@("`@?0H*("`@("\J*@H@("`@*B!3=&]R97,@82!D
M871A<V5T+@H@("`@*@H@("`@*B!705).24Y'.B!W92!U<V4@=&AE(%-13"!C
M;VUM86YD(%)%4$Q!0T4@24Y43R!T:&ES(&UI9VAT(&)E"B`@("`J($UY4U%,
M('-P96-I9FEC+B!!<R!->5-13"!I<R!V97)Y('!O<'5L87(@=&AE(&UE=&AO
M9"!S:&]U;&0*("`@("H@=V]R:R!F:6YE(&9O<B`Y-24@;V8@>6]U+@H@("`@
M*B\*("`@(&9U;F-T:6]N('-A=F4H)&ED+"`D9&%T82P@)&5X<&ER97,L("1G
M<F]U<"P@)'5S97)D871A*0H@("`@>PH@("`@("`@("1T:&ES+3YF;'5S:%!R
M96QO860H)&ED+"`D9W)O=7`I.PH*("`@("`@("`D<75E<GD@/2!S<')I;G1F
M*")215!,04-%($E.5$\@)7,@*'5S97)D871A+"!C86-H961A=&$L(&5X<&ER
M97,L(&ED+"!C86-H96=R;W5P*2!604Q515,@*"<E<R<L("<E<R<L("5D+"`G
M)7,G+"`G)7,G*2(L"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M8V%C:&5?=&%B;&4L"B`@("`@("`@("`@("`@("`@("`@("`@("!A9&1S;&%S
M:&5S*"1U<V5R9&%T82DL"B`@("`@("`@("`@("`@("`@("`@("`@("!A9&1S
M;&%S:&5S*"1T:&ES+3YE;F-O9&4H)&1A=&$I*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^9V5T17AP:7)E<T%B<V]L=71E*"1E>'!I<F5S
M*2`L"B`@("`@("`@("`@("`@("`@("`@("`@("!A9&1S;&%S:&5S*"1I9"DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("!A9&1S;&%S:&5S*"1G<F]U<"D*
M("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@("`@)')E<R`]("1T
M:&ES+3YD8BT^<75E<GDH)'%U97)Y*3L*"B`@("`@("`@:68@*$1".CII<T5R
M<F]R*"1R97,I*2!["B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R
M;W(H)T1".CIQ=65R>2!F86EL960Z("<@+B!$0CHZ97)R;W)-97-S86=E*"1R
M97,I("P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("!]"@H@
M("`@9G5N8W1I;VX@<F5M;W9E*"1I9"P@)&=R;W5P*0H@("`@>PH@("`@("`@
M("1T:&ES+3YF;'5S:%!R96QO860H)&ED+"`D9W)O=7`I.PH*("`@("`@("`D
M<75E<GD@/2!S<')I;G1F*")$14Q%5$4@1E)/32`E<R!72$5212!I9"`]("<E
M<R<@86YD(&-A8VAE9W)O=7`@/2`G)7,G(BP*("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YC86-H95]T86)L92P*("`@("`@("`@("`@("`@("`@
M("`@("`@(&%D9'-L87-H97,H)&ED*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@(&%D9'-L87-H97,H)&=R;W5P*0H@("`@("`@("`@("`@("`@("`@("`@
M("`I.PH*("`@("`@("`D<F5S(#T@)'1H:7,M/F1B+3YQ=65R>2@D<75E<GDI
M.PH*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<RDI"B`@("`@("`@("`@
M(')E='5R;B!N97<@0V%C:&5?17)R;W(H)T1".CIQ=65R>2!F86EL960Z("<@
M+B!$0CHZ97)R;W)-97-S86=E*"1R97,I+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&9L=7-H*"1G<F]U<"`]("<G*0H@("`@
M>PH@("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H*3L*"B`@("`@("`@(&EF
M("@D9W)O=7`I('L*("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@B1$5,
M151%($923TT@)7,@5TA%4D4@8V%C:&5G<F]U<"`]("<E<R<B+"`D=&AI<RT^
M8V%C:&5?=&%B;&4L(&%D9'-L87-H97,H)&=R;W5P*2D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@B1$5,151%($92
M3TT@)7,B+"`D=&AI<RT^8V%C:&5?=&%B;&4I.PH@("`@("`@('T*"B`@("`@
M("`@)')E<R`]("1T:&ES+3YD8BT^<75E<GDH)'%U97)Y*3L*"B`@("`@("`@
M:68@*$1".CII<T5R<F]R*"1R97,I*0H@("`@("`@("`@("!R971U<FX@;F5W
M($-A8VAE7T5R<F]R*"=$0CHZ<75E<GD@9F%I;&5D.B`G("X@1$(Z.F5R<F]R
M365S<V%G92@D<F5S*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!I9$5X:7-T<R@D:60L("1G<F]U<"D*("`@('L*("`@("`@
M("`D<75E<GD@/2!S<')I;G1F*")314Q%0U0@:60@1E)/32`E<R!72$5212!)
M1"`]("<E<R<@04Y$(&-A8VAE9W)O=7`@/2`G)7,G(BP*("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YC86-H95]T86)L92P*("`@("`@("`@("`@
M("`@("`@("`@("`@(&%D9'-L87-H97,H)&ED*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@(&%D9'-L87-H97,H)&=R;W5P*0H@("`@("`@("`@("`@("`@
M("`@("`@("`I.PH*("`@("`@("`D<F5S(#T@)'1H:7,M/F1B+3YQ=65R>2@D
M<75E<GDI.PH*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<RDI"B`@("`@
M("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)T1".CIQ=65R>2!F86EL
M960Z("<@+B!$0CHZ97)R;W)-97-S86=E*"1R97,I+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH*("`@("`@("`D<F]W(#T@)')E<RT^9F5T8VA2;W<H*3L*"B`@
M("`@("`@:68@*&ES7V%R<F%Y*"1R;W<I*2!["B`@("`@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@9V%R8F%G94-O
M;&QE8W1I;VXH)&UA>&QI9F5T:6UE*0H@("`@>PH@("`@("`@("1T:&ES+3YF
M;'5S:%!R96QO860H*3L*"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G1$5,
M151%($923TT@)7,@5TA%4D4@*&5X<&ER97,@/#T@)60@04Y$(&5X<&ER97,@
M/B`P*2!/4B!C:&%N9V5D(#P]("5D)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YC86-H95]T86)L92P*("`@("`@("`@("`@("`@("`@("`@
M("`@('1I;64H*2P*("`@("`@("`@("`@("`@("`@("`@("`@('1I;64H*2`M
M("1M87AL:69E=&EM90H@("`@("`@("`@("`@("`@("`@("`@("D["@H@("`@
M("`@("1R97,@/2`D=&AI<RT^9&(M/G%U97)Y*"1Q=65R>2D["@H@("`@("`@
M("1Q=65R>2`]('-P<FEN=&8H)W-E;&5C="!S=6TH;&5N9W1H*&-A8VAE9&%T
M82DI(&%S($-A8VAE4VEZ92!F<F]M("5S)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YC86-H95]T86)L90H@("`@("`@("`@("`@("`@("`@
M("`@("D["B`@("`@("`@)&-A8VAE<VEZ92`]("1T:&ES+3YD8BT^1V5T3VYE
M*"1Q=65R>2D["B`@("`@("`@:68@*$1".CII<T5R<F]R*"1C86-H97-I>F4I
M*2!["B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)T1".CIQ
M=65R>2!F86EL960Z("<@+B!$0CHZ97)R;W)-97-S86=E*"1C86-H97-I>F4I
M+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@+R]I
M9B!C86-H92!I<R!T;R!B:6<N"B`@("`@("`@:68@*"1C86-H97-I>F4@/B`D
M=&AI<RT^:&EG:'=A=&5R*0H@("`@("`@('L*("`@("`@("`@("`@+R]F:6YD
M('1H92!L;W=W871E<B!M87)K+@H@("`@("`@("`@("`D<75E<GD@/2!S<')I
M;G1F*"=S96QE8W0@;&5N9W1H*&-A8VAE9&%T82D@87,@<VEZ92P@8VAA;F=E
M9"!F<F]M("5S(&]R9&5R(&)Y(&-H86YG960@1$530R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V%C:&5?=&%B;&4*
M("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@("`D<F5S(#T@
M)'1H:7,M/F1B+3YQ=65R>2@D<75E<GDI.PH@("`@("`@("`@("!I9B`H1$(Z
M.FES17)R;W(H)')E<RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!N97<@
M0V%C:&5?17)R;W(H)T1".CIQ=65R>2!F86EL960Z("<@+B!$0CHZ97)R;W)-
M97-S86=E*"1R97,I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D;G5M<F]W<R`]("1T:&ES+3YD8BT^;G5M4F]W
M<R@D<F5S*3L*("`@("`@("`@("`@)&ME97!?<VEZ92`](#`["B`@("`@("`@
M("`@('=H:6QE("@D:V5E<%]S:7IE(#P@)'1H:7,M/FQO=W=A=&5R("8F("1N
M=6UR;W=S+2TI('L*("`@("`@("`@("`@("`@("1E;G1R>2`]("1R97,M/F9E
M=&-H4F]W*$1"7T9%5$-(34]$15]!4U-/0RD["B`@("`@("`@("`@("`@("`D
M:V5E<%]S:7IE("L]("1E;G1R>5LG<VEZ92==.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`O+V1E;&5T92!A;&P@96YT<FEE<RP@=VAI8V@@=V5R92!C
M:&%N9V5D(&)E9F]R92!T:&4@(FQO=W=W871E<B!M87)K(@H@("`@("`@("`@
M("`D<75E<GD@/2!S<')I;G1F*"=D96QE=&4@9G)O;2`E<R!W:&5R92!C:&%N
M9V5D(#P]("<N*"1E;G1R>5LG8VAA;F=E9"==(#\@)&5N=')Y6R=C:&%N9V5D
M)UT@.B`P*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YC86-H95]T86)L90H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("D["B`@("`@("`@("`@("1R97,@/2`D=&AI<RT^9&(M/G%U
M97)Y*"1Q=65R>2D["B`@("`@("`@?0H*("`@("`@("!I9B`H1$(Z.FES17)R
M;W(H)')E<RDI('L*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O
M<B@G1$(Z.G%U97)Y(&9A:6QE9#H@)R`N($1".CIE<G)O<DUE<W-A9V4H)')E
M<RDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@?0H*?0H_
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]#86-H92]#;VYT86EN97(O9&)X+G!H<```````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,C<U,0`Q,#4Q-30S,S<S-``P,C,P
M,C8`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$5!
M4B`Z.B!#86-H92`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0
M($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I
M;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N
M<V4L("`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A
M8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O
M('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\
M"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P
M;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@075T:&]R<SH@0VAR:7-T:6%N(%-T;V-K97(@/&-H<F5G=4!P
M:&%N="YC:#X@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!D8G@N<&AP+'8@,2XT
M(#(P,#,O,#$O,#0@,3$Z-30Z-#8@;6H@17AP("0*"@IR97%U:7)E7V]N8V4@
M)T-A8VAE+T-O;G1A:6YE<BYP:'`G.PH*+RHJ"BH@97AT+V1B>"!#86-H92!#
M;VYT86EN97(N"BH**B!705).24Y'.B!/=&AE<B!S>7-T96US(&UI9VAT(&]R
M(&UI9VAT(&YO="!S=7!P;W)T(&-E<G1A:6X@9&%T871Y<&5S(&]F(`HJ('1H
M92!T86)L97,@<VAO=VXN($%S(&9A<B!A<R!)(&MN;W<@=&AE<F4G<R!N;R!L
M87)G92!B:6YA<GD@"BH@='EP92!I;B!344PM.3(@;W(@4U%,+3DY+B!0;W-T
M9W)E<R!S965M<R!T;R!L86-K(&%N>2`**B!"3$]"(&]R(%1%6%0@='EP92P@
M9F]R($U3+5-13"!Y;W4@8V]U;&0@=7-E($E-04=%+"!D;VXG="!K;F]W(`HJ
M(&%B;W5T(&]T:&5R(&1A=&%B87-E<RX@4&QE87-E(&%D9"!S=6=E<W1I;VYS
M(&9O<B!O=&AE<B!D871A8F%S97,@=&\@"BH@=&AE(&EN;&EN92!D;V-S+@HJ
M"BH@5&AE(&9I96QD("=C:&%N9V5D)R!H87,@;F\@;65A;FEN9R!F;W(@=&AE
M($-A8VAE(&ET<V5L9BX@270G<R!J=7-T('1H97)E(`HJ(&)E8V%U<V4@:70G
M<R!A(&=O;V0@:61E82!T;R!H879E(&%N(&%U=&]M871I8V%L;'D@=7!D871E
M9"!T:6UE<W1A;7`**B!F:65L9"!F;W(@9&5B=6=G:6YG(&EN(&%L;"!O9B!Y
M;W5R('1A8FQE<RX**@HJ($9O<B!?37E344Q?('EO=2!N965D('1H:7,@1$(@
M=&%B;&4Z"BH**B!#4D5!5$4@5$%"3$4@8V%C:&4@*`HJ("`@:60@("`@("`@
M("`@0TA!4B@S,BD@3D]4($Y53$P@1$5&055,5"`G)RP**B`@(&-A8VAE9W)O
M=7`@(%9!4D-(05(H,3(W*2!.3U0@3E5,3"!$149!54Q4("<G+`HJ("`@8V%C
M:&5D871A("`@0DQ/0B!.3U0@3E5,3"!$149!54Q4("<G+`HJ("`@=7-E<F1A
M=&$@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,($1%1D%53%0@)R<L"BH@("!E
M>'!I<F5S("`@("!)3E0H.2D@3D]4($Y53$P@1$5&055,5"`P+`HJ("`**B`@
M(&-H86YG960@("`@(%1)34535$%-4"@Q-"D@3D]4($Y53$PL"BH@(`HJ("`@
M24Y$15@@*&5X<&ER97,I+`HJ("`@4%))34%262!+15D@*&ED+"!C86-H96=R
M;W5P*0HJ("D**@HJ($!A=71H;W(@("!#:')I<W1I86X@4W1O8VME<B`\8VAR
M96=U0'!H86YT+F-H/@HJ($!V97)S:6]N("`D260Z(&1B>"YP:'`L=B`Q+C0@
M,C`P,R\P,2\P-"`Q,3HU-#HT-B!M:B!%>'`@)`HJ($!P86-K86=E("!#86-H
M90HJ+PIC;&%S<R!#86-H95]#;VYT86EN97)?9&)X(&5X=&5N9',@0V%C:&5?
M0V]N=&%I;F5R('L*"B`@("`O*BH*("`@("H@3F%M92!O9B!T:&4@1$(@=&%B
M;&4@=&\@<W1O<F4@8V%C:&EN9R!D871A"B`@("`J(`H@("`@*B!`<V5E("!#
M86-H95]#;VYT86EN97)?9FEL93HZ)&9I;&5N86UE7W!R969I>`H@("`@*B\@
M(`H@("`@=F%R("1C86-H95]T86)L92`]("<G.PH*("`@("\J*@H@("`@*B!$
M0G@@;6]D=6QE('1O('5S90H@("`@*@H@("`@*B`@870@=&AE(&UO;65N="!O
M;FQY(&UY<W%L(&]R(&]D8F,*("`@("H@"B`@("`J($!V87(@('-T<FEN9PH@
M("`@*B\*("`@('9A<B`D;6]D=6QE(#T@)R<["@H@("`@+RHJ"B`@("`J($1"
M(&AO<W0@=&\@=7-E"B`@("`J(`H@("`@*B!`=F%R("!S=')I;F<*("`@("HO
M"B`@("!V87(@)&AO<W0@/2`G)SL*"B`@("`O*BH*("`@("H@1$(@9&%T86)A
M<V4@=&\@=7-E"B`@("`J(`H@("`@*B!`=F%R("!S=')I;F<*("`@("HO"B`@
M("!V87(@)&1B(#T@)R<["@H@("`@+RHJ"B`@("`J($1"('5S97)N86UE('1O
M('5S90H@("`@*B`*("`@("H@0'9A<B`@<W1R:6YG"B`@("`J+PH@("`@=F%R
M("1U<V5R;F%M92`]("<G.PH*("`@("\J*@H@("`@*B!$0B!P87-S=V]R9"!T
M;R!U<V4*("`@("H@"B`@("`J($!V87(@('-T<FEN9PH@("`@*B\*("`@('9A
M<B`D<&%S<W=O<F0@/2`G)SL*"B`@("`O*BH*("`@("H@1$)X(&AA;F1L92!O
M8FIE8W0*("`@("H@"B`@("`J($!V87(@(&]B:F5C="!$0G@@:&%N9&QE"B`@
M("`J+PH@("`@=F%R("1D8CL*("`@(`H@("`@"B`@("`O*BH*("`@("H@17-T
M86)L:7-H(&$@<&5R<VES=&5N="!C;VYN96-T:6]N/PH@("`@*B`*("`@("H@
M0'9A<B`@8F]O;&5A;B`*("`@("HO"B`@("!V87(@)'!E<G-I<W1E;G0@/2!T
M<G5E.PH@("`@"@H@("`@9G5N8W1I;VX@0V%C:&5?0V]N=&%I;F5R7V1B>"@D
M;W!T:6]N<RD*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1O<'1I;VYS
M*2`I('L*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G3F\@
M;W!T:6]N<R!S<&5C:69I960A)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M("`@("!]"@H@("`@("`@("1T:&ES+3YS971/<'1I;VYS*"1O<'1I;VYS+"`@
M87)R87E?;65R9V4H)'1H:7,M/F%L;&]W961?;W!T:6]N<RP@87)R87DH)VUO
M9'5L92<L)VAO<W0G+"=D8B<L)W5S97)N86UE)RPG<&%S<W=O<F0G+"`G8V%C
M:&5?=&%B;&4G+"`G<&5R<VES=&5N="<I*2D["@H@("`@("`@(&EF("@A)'1H
M:7,M/FUO9'5L92D*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O
M<B@G3F\@;6]D=6QE('-P96-I9FEE9"$G+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PH*("`@("`@("`D=&AI<RT^9&(@/2!D8GA?8V]N;F5C="@D=&AI<RT^;6]D
M=6QE+"`D=&AI<RT^:&]S="P@)'1H:7,M/F1B+"`D=&AI<RT^=7-E<FYA;64L
M("1T:&ES+3YP87-S=V]R9"P@)'1H:7,M/G!E<G-I<W1E;G0I.PH*("`@("`@
M("!I9B`H9&)X7V5R<F]R*"1T:&ES+3YD8BDI('L*("`@("`@("`@("`@<F5T
M=7)N(&YE=R!#86-H95]%<G)O<B@G1$)X(&-O;FYE8W0@9F%I;&5D.B`G("X@
M9&)X7V5R<F]R*"1T:&ES+3YD8BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R]N;W0@:6UP;&5M96YT960@
M>65T(&EN(&1B>`H@("`@("`@("`@("`O+R1T:&ES+3YD8BT^<V5T1F5T8VA-
M;V1E*$1"7T9%5$-(34]$15]!4U-/0RD["B`@("`@("`@?0H@("`@?0H*("`@
M(&9U;F-T:6]N(&9E=&-H*"1I9"P@)&=R;W5P*0H@("`@>PH@("`@("`@("1Q
M=65R>2`]('-P<FEN=&8H(E-%3$5#5"!C86-H961A=&$L('5S97)D871A+"!E
M>'!I<F5S($923TT@)7,@5TA%4D4@:60@/2`G)7,G($%.1"!C86-H96=R;W5P
M(#T@)R5S)R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V%C
M:&5?=&%B;&4L"B`@("`@("`@("`@("`@("`@("`@("`@("!A9&1S;&%S:&5S
M*"1I9"DL"B`@("`@("`@("`@("`@("`@("`@("`@("!A9&1S;&%S:&5S*"1G
M<F]U<"D*("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@("`@)')E
M<R`](&1B>%]Q=65R>2@D=&AI<RT^9&(L("1Q=65R>2D["B`@("`@("`@:68@
M*&1B>%]E<G)O<B@D=&AI<RT^9&(I*0H@("`@("`@("`@("!R971U<FX@;F5W
M($-A8VAE7T5R<F]R*"=$0G@@<75E<GD@9F%I;&5D.B`G("X@9&)X7V5R<F]R
M*"1T:&ES+3YD8BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["@H@("`@("`@("1R
M;W<@/2`D<F5S+3YD871A6S!=.PH*("`@("`@("!I9B`H:7-?87)R87DH)')O
M=RDI"B`@("`@("`@("`@("1D871A(#T@87)R87DH)')O=ULG97AP:7)E<R==
M+"`D=&AI<RT^9&5C;V1E*"1R;W=;)V-A8VAE9&%T82==*2P@)')O=ULG=7-E
M<F1A=&$G72D["B`@("`@("`@96QS92`*("`@("`@("`@("`@)&1A=&$@/2!A
M<G)A>2A.54Q,+"!.54Q,+"!.54Q,*3L*"B`@("`@("`@+R\@;&%S="!U<V5D
M(')E<75I<F5D(&)Y('1H92!G87)B86=E(&-O;&QE8W1I;VX@("`*("`@("`@
M("`O+R!705).24Y'.B!M:6=H="!B92!->5-13"!S<&5C:69I8R`@("`@("`@
M(`H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H(E501$%412`E<R!3150@8VAA
M;F=E9"`]("A.3U<H*2`K(#`I(%=(15)%(&ED(#T@)R5S)R!!3D0@8V%C:&5G
M<F]U<"`]("<E<R<B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/F-A8VAE7W1A8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M861D<VQA<VAE<R@D:60I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M861D<VQA<VAE<R@D9W)O=7`I"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M*3L*("`@("`@("`*("`@("`@("`D<F5S(#T@9&)X7W%U97)Y*"1T:&ES+3YD
M8BP@)'%U97)Y*3L*("`@("`@("!I9B`H9&)X7V5R<F]R*"1T:&ES+3YD8BDI
M"B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)T1">"!Q=65R
M>2!F86EL960Z("<@+B!D8GA?97)R;W(H)'1H:7,M/F1B*2P@7U]&24Q%7U\L
M(%]?3$E.15]?*3L@("`@("`@("`@("`@("`@("`@("`@("`@("`@(`H@("`@
M("`@("`@("`*("`@("`@("!R971U<FX@)&1A=&$[("`@("`@("`@("`@"B`@
M("!]"@H@("`@+RHJ"B`@("`J(%-T;W)E<R!A(&1A=&%S970N"B`@("`J(`H@
M("`@*B!705).24Y'.B!W92!U<V4@=&AE(%-13"!C;VUM86YD(%)%4$Q!0T4@
M24Y43R!T:&ES(&UI9VAT(&)E(`H@("`@*B!->5-13"!S<&5C:69I8RX@07,@
M37E344P@:7,@=F5R>2!P;W!U;&%R('1H92!M971H;V0@<VAO=6QD"B`@("`J
M('=O<FL@9FEN92!F;W(@.34E(&]F('EO=2X*("`@("HO"B`@("!F=6YC=&EO
M;B!S879E*"1I9"P@)&1A=&$L("1E>'!I<F5S+"`D9W)O=7`L("1U<V5R9&%T
M82D*("`@('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"1I9"P@)&=R
M;W5P*3L*"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@B4D503$%#12!)3E1/
M("5S("AU<V5R9&%T82P@8V%C:&5D871A+"!E>'!I<F5S+"!I9"P@8V%C:&5G
M<F]U<"D@5D%,5453("@G)7,G+"`G)7,G+"`E9"P@)R5S)RP@)R5S)RDB+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-A8VAE7W1A8FQE+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@861D<VQA<VAE<R@D=7-E<F1A=&$I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@861D<VQA<VAE<R@D=&AI<RT^
M96YC;V1E*"1D871A*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^9V5T17AP:7)E<T%B<V]L=71E*"1E>'!I<F5S*2`L"B`@("`@("`@("`@
M("`@("`@("`@("`@("!A9&1S;&%S:&5S*"1I9"DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("!A9&1S;&%S:&5S*"1G<F]U<"D*("`@("`@("`@("`@("`@
M("`@("`@("`@*3L*"B`@("`@("`@)')E<R`](&1B>%]Q=65R>2@D=&AI<RT^
M9&(L("1Q=65R>2D["@H@("`@("`@(&EF("AD8GA?97)R;W(H)'1H:7,M/F1B
M*2D@>PH@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=$0G@@
M<75E<GD@9F%I;&5D.B`G("X@9&)X7V5R<F]R*"1T:&ES+3YD8BD@+"!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO
M;B!R96UO=F4H)&ED+"`D9W)O=7`I"B`@("!["B`@("`@("`@)'1H:7,M/F9L
M=7-H4')E;&]A9"@D:60L("1G<F]U<"D["@H@("`@("`@("1Q=65R>2`]('-P
M<FEN=&8H(D1%3$5412!&4D]-("5S(%=(15)%(&ED(#T@)R5S)R!A;F0@8V%C
M:&5G<F]U<"`]("<E<R<B+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/F-A8VAE7W1A8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@861D
M<VQA<VAE<R@D:60I+`H@("`@("`@("`@("`@("`@("`@("`@("`@861D<VQA
M<VAE<R@D9W)O=7`I"B`@("`@("`@("`@("`@("`@("`@("`@("D["@H@("`@
M("`@("1R97,@/2!D8GA?<75E<GDH)'1H:7,M/F1B+"`D<75E<GDI.PH*("`@
M("`@("!I9B`H9&)X7V5R<F]R*"1T:&ES+3YD8BDI"B`@("`@("`@("`@(')E
M='5R;B!N97<@0V%C:&5?17)R;W(H)T1">"!Q=65R>2!F86EL960Z("<@+B!D
M8GA?97)R;W(H)'1H:7,M/F1B*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!F;'5S:"@D9W)O=7`@/2`G)RD*("`@('L*("`@
M("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"D["@H@("`@("`@(&EF("@D9W)O
M=7`I('L*("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@B1$5,151%($92
M3TT@)7,@5TA%4D4@8V%C:&5G<F]U<"`]("<E<R<B+"`D=&AI<RT^8V%C:&5?
M=&%B;&4L(&%D9'-L87-H97,H)&=R;W5P*2D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@B1$5,151%($923TT@)7,B
M+"`D=&AI<RT^8V%C:&5?=&%B;&4I.PH@("`@("`@('T*"B`@("`@("`@)')E
M<R`](&1B>%]Q=65R>2@D=&AI<RT^9&(L)'%U97)Y*3L*"B`@("`@("`@:68@
M*&1B>%]E<G)O<B@D=&AI<RT^9&(I*0H@("`@("`@("`@("!R971U<FX@;F5W
M($-A8VAE7T5R<F]R*"=$0G@@<75E<GD@9F%I;&5D.B`G("X@9&)X7V5R<F]R
M*"1T:&ES+3YD8BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("!]"@H@("`@
M9G5N8W1I;VX@:61%>&ES=',H)&ED+"`D9W)O=7`I"B`@("!["B`@("`@("`@
M)'%U97)Y(#T@<W!R:6YT9B@B4T5,14-4(&ED($923TT@)7,@5TA%4D4@240@
M/2`G)7,G($%.1"!C86-H96=R;W5P(#T@)R5S)R(L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^8V%C:&5?=&%B;&4L"B`@("`@("`@("`@("`@
M("`@("`@("`@("!A9&1S;&%S:&5S*"1I9"DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("!A9&1S;&%S:&5S*"1G<F]U<"D*("`@("`@("`@("`@("`@("`@
M("`@("`@*3L*"B`@("`@("`@)')E<R`](&1B>%]Q=65R>2@D=&AI<RT^9&(L
M("1Q=65R>2D["@H@("`@("`@(&EF("AD8GA?97)R;W(H)'1H:7,M/F1B*2D*
M("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G1$)X('%U97)Y
M(&9A:6QE9#H@)R`N(&1B>%]E<G)O<B@D=&AI<RT^9&(I+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH*"B`@("`@("`@)')O=R`]("1R97-;,%T["@H@("`@("`@
M(&EF("AI<U]A<G)A>2@D<F]W*2D@>PH@("`@("`@("`@("!R971U<FX@=')U
M93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&=A<F)A9V5#;VQL96-T
M:6]N*"1M87AL:69E=&EM92D*("`@('L*("`@("`@("`D=&AI<RT^9FQU<VA0
M<F5L;V%D*"D["B`@("`@("`@"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G
M1$5,151%($923TT@)7,@5TA%4D4@*&5X<&ER97,@/#T@)60@04Y$(&5X<&ER
M97,@/B`P*2!/4B!C:&%N9V5D(#P]("A.3U<H*2`M("5D*2<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^8V%C:&5?=&%B;&4L"B`@("`@("`@
M("`@("`@("`@("`@("`@("!T:6UE*"DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`D;6%X;&EF971I;64*("`@("`@("`@("`@("`@("`@("`@("`I.PH*
M"B`@("`@("`@)')E<R`](&1B>%]Q=65R>2@D=&AI<RT^9&(L("1Q=65R>2D[
M"@H@("`@("`@(&EF("AD8GA?97)R;W(H)'1H:7,M/F1B*2D*("`@("`@("`@
M("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G1$)X('%U97)Y(&9A:6QE9#H@
M)R`N(&1B>%]E<G)O<B@D=&AI<RT^9&(I+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PH*("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=S96QE8W0@<W5M*&QE;F=T
M:"AC86-H961A=&$I*2!A<R!#86-H95-I>F4@9G)O;2`E<R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^8V%C:&5?=&%B;&4*("`@("`@("`@
M("`@("`@("`@("`@("`I.PH*("`@("`@("`D<F5S(#T@9&)X7W%U97)Y*"1T
M:&ES+3YD8BP@)'%U97)Y*3L*("`@("`@("`O+VEF(&-A8VAE(&ES('1O(&)I
M9RX*("`@("`@("!I9B`H)')E<RT^9&%T85LP75M#86-H95-I>F5=(#X@)'1H
M:7,M/FAI9VAW871E<BD*("`@("`@("!["B`@("`@("`@("`@("\O9FEN9"!T
M:&4@;&]W=V%T97(@;6%R:RX*("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT
M9B@G<V5L96-T(&QE;F=T:"AC86-H961A=&$I(&%S('-I>F4L(&-H86YG960@
M9G)O;2`E<R!O<F1E<B!B>2!C:&%N9V5D($1%4T,G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-A8VAE7W1A8FQE"B`@
M("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@("`@("`@("1R97,@/2!D
M8GA?<75E<GDH)'1H:7,M/F1B+"`D<75E<GDI.PH@("`@("`@("`@("`D:V5E
M<%]S:7IE/3`["B`@("`@("`@("`@("1I/3`["B`@("`@("`@("`@('=H:6QE
M("@D:V5E<%]S:7IE(#P@)'1H:7,M/FQO=W=A=&5R("8F("1I(#P@)')E<RT^
M<F]W<R`I"B`@("`@("`@("`@('L*"B`@("`@("`@("`@("`@("`D:V5E<%]S
M:7IE("L]("1R97,M/F1A=&%;)&E=6W-I>F5=.PH@("`@("`@("`@("`@("`@
M)&DK*SL*("`@('T*("`@(`H@("`@("`@("`@("`O+V1E;&5T92!A;&P@96YT
M<FEE<RP@=VAI8V@@=V5R92!C:&%N9V5D(&)E9F]R92!T:&4@(FQO=W=W871E
M<B!M87)K(@H@("`@("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=D96QE=&4@
M9G)O;2`E<R!W:&5R92!C:&%N9V5D(#P]("5S)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC86-H95]T86)L92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97,M/F1A=&%;
M)&E=6V-H86YG961="B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@*3L*("`@("`@("`@("`@)')E<R`](&1B>%]Q=65R>2@D=&AI<RT^9&(L
M("1Q=65R>2D["B`@("`@("`@?0H@("`@?0I]"C\^````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O0V%C:&4O
M0V]N=&%I;F5R+V9I;&4N<&AP````````````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,S$T,#4`,3`U,34T,S,W,S0`,#(S,38T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!%05(@.CH@0V%C:&4@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I
M9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R
M<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\"B\O('P@=&AA
M="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)
M0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R
M+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O
M("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA
M:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%5L
M9B!796YD96P@/'5L9BYW96YD96Q`<&AP9&]C+F1E/B`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("!396)A<W1I86X@0F5R9VUA
M;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z(&9I
M;&4N<&AP+'8@,2XQ,R`R,#`S+S`S+S(W(#$P.C0X.C0R(&-H<F5G=2!%>'`@
M)`H*<F5Q=6ER95]O;F-E("=#86-H92]#;VYT86EN97(N<&AP)SL*"B\J*@HJ
M(%-T;W)E<R!C86-H92!C;VYT96YT<R!I;B!A(&9I;&4N"BH**B!`875T:&]R
M("`@56QF(%=E;F1E;"`@/'5L9BYW96YD96Q`<&AP9&]C+F1E/@HJ($!V97)S
M:6]N("`D260Z(&9I;&4N<&AP+'8@,2XQ,R`R,#`S+S`S+S(W(#$P.C0X.C0R
M(&-H<F5G=2!%>'`@)`HJ+PIC;&%S<R!#86-H95]#;VYT86EN97)?9FEL92!E
M>'1E;F1S($-A8VAE7T-O;G1A:6YE<B!["@H@("`@+RHJ"B`@("`J($9I;&4@
M;&]C:VEN9PH@("`@*@H@("`@*B!7:71H(&9I;&4@8V]N=&%I;F5R+"!I="=S
M('!O<W-I8FQE+"!T:&%T('EO=2!G970@8V]R<G5P=&5D"B`@("`J(&1A=&$M
M96YT<FEE<R!U;F1E<B!B860@8VER8W5M<W1A;F-E<RX@5&AE(&9I;&4@;&]C
M:VEN9R!M=7-T"B`@("`J(&EM<')O=F4@=&AI<R!P<F]B;&5M(&)U="!I="=S
M(&5X<&5R:6UE;G1A;"!S='5F9BX@4V\@=&AE"B`@("`J(&1E9F%U;'0@=F%L
M=64@:7,@9F%L<V4N($)U="!I="!S965M<R!T;R!G:79E(&=O;V0@<F5S=6QT
M<PH@("`@*@H@("`@*B!`=F%R(&)O;VQE86X*("`@("HO"B`@("!V87(@)&9I
M;&5,;V-K:6YG(#T@9F%L<V4["@H@("`@+RHJ"B`@("`J($1I<F5C=&]R>2!W
M:&5R92!T;R!P=70@=&AE(&-A8VAE(&9I;&5S+@H@("`@*@H@("`@*B!`=F%R
M("!S=')I;F<@($UA:V4@<W5R92!T;R!A9&0@82!T<F%I;&EN9R!S;&%S:`H@
M("`@*B\*("`@('9A<B`D8V%C:&5?9&ER(#T@)R<["@H@("`@+RHJ"B`@("`J
M($9I;&5N86UE('!R969I>"!F;W(@8V%C:&4@9FEL97,N"B`@("`J"B`@("`J
M(%EO=2!C86X@=7-E('1H92!F:6QE;F%M92!P<F5F:7@@=&\@:6UP;&5M96YT
M(&$@(F1O;6%I;B(@8F%S960@8V%C:&4@;W(@:G5S=`H@("`@*B!T;R!G:79E
M('1H92!F:6QE<R!A(&UO<F4@9&5S8W)I<'1I=F4@;F%M92X@5&AE('=O<F0@
M(F1O;6%I;B(@:7,@8F]R<F]E9"!F<F]M"B`@("`J(&$@=7-E<B!A=71H96YT
M:69I8V%T:6]N('-Y<W1E;2X@3VYE('5S97(@:60@*&-A8VAE9"!D871A<V5T
M('=I=&@@=&AE($E$('@I"B`@("`J(&UA>2!E>&ES=',@:6X@9&EF9F5R96YT
M(&1O;6%I;G,@*&1I9F9E<F5N="!F:6QE;F%M92!P<F5F:7@I+B!9;W4@;6EG
M:'0@=V%N=`H@("`@*B!T;R!U<V4@=&AI<R!T;R!H879E(&1I9F9E<F5N="!C
M86-H92!V86QU97,@9F]R(&$@<')O9'5C=&EO;BP@9&5V96QO<&UE;G0@86YD
M"B`@("`J('%U86QI='D@87-S=7)A;F-E('-Y<W1E;2X@268@>6]U('=A;G0@
M=&AE('!R;V1U8W1I;VX@8V%C:&4@;F]T('1O(&)E(&EN9FQU96YC960*("`@
M("H@8GD@=&AE('%U86QI='D@87-S=7)A;F-E(&%C=&EV:71I97,L('5S92!D
M:69F97)E;G0@9FEL96YA;64@<')E9FEX97,@9F]R('1H96TN"B`@("`J"B`@
M("`J($D@<&5R<V]N86QL>2!D;VXG="!T:&EN:R!T:&%T('EO=2=L;"!N979E
M<B!N965D('1H:7,L(&)U="`V-#!K8B!H87!P96YD('1O(&)E"B`@("`J(&YO
M="!E;F]U9V@L('-O+BXN('EO=2!K;F]W('=H870@22!M96%N+B!)9B!Y;W4@
M9FEN9"!A('5S969U;"!A<'!L:6-A=&EO;B!O9B!T:&4*("`@("H@9F5A='5R
M92!P;&5A<V4@=7!D871E('1H:7,@:6YL:6YE(&1O8RX*("`@("H*("`@("H@
M0'9A<B`@<W1R:6YG"B`@("`J+PH@("`@=F%R("1F:6QE;F%M95]P<F5F:7@@
M/2`G)SL*("`@(`H@("`@"B`@("`O*BH*("`@("H@3&ES="!O9B!C86-H92!E
M;G1R:65S+"!U<V5D('=I=&AI;B!A(&=C(')U;@H@("`@*B`*("`@("H@0'9A
M<B!A<G)A>0H@("`@*B\*("`@('9A<B`D96YT<FEE<SL*("`@(`H@("`@+RHJ
M"B`@("`J(%1O=&%L(&YU;6)E<B!O9B!B>71E<R!R97%U:7)E9"!B>2!A;&P@
M8V%C:&4@96YT<FEE<RP@=7-E9"!W:71H:6X@82!G8R!R=6XN"B`@("`J(`H@
M("`@*B!`=F%R("!I;G0*("`@("HO"B`@("!V87(@)'1O=&%L7W-I>F4@/2`P
M.PH*"B`@("`O*BH*("`@("H@36%X($QI;F4@3&5N9W1H(&]F('5S97)D871A
M"B`@("`J"B`@("`J($EF('-E="!T;R`P+"!I="!W:6QL('1A:V4@=&AE(&1E
M9F%U;'0@"B`@("`J("@@,3`R-"!I;B!P:'`@-"XR+"!U;FQI;6ET960@:6X@
M<&AP(#0N,RD*("`@("H@<V5E(&AT='`Z+R]C:"YP:'`N;F5T+VUA;G5A;"]E
M;B]F=6YC=&EO;BYF9V5T<RYP:'`*("`@("H@9F]R(&1E=&%I;',*("`@("H*
M("`@("H@0'9A<B!I;G0*("`@("HO"B`@("!V87(@)&UA>%]U<V5R9&%T85]L
M:6YE;&5N9W1H(#T@,C4W.PH*("`@("\J*@H@("`@*B!#<F5A=&5S('1H92!C
M86-H92!D:7)E8W1O<GD@:68@;F5C8V5S<V%R>0H@("`@*@H@("`@*B!`<&%R
M86T@("`@87)R87D@("!#;VYF:6<@;W!T:6]N<SH@6R)C86-H95]D:7(B(#T^
M("XN+BP@(F9I;&5N86UE7W!R969I>"(@/3X@+BXN70H@("`@*B\*("`@("!F
M=6YC=&EO;B!#86-H95]#;VYT86EN97)?9FEL92@D;W!T:6]N<R`]("<G*2![
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1O<'1I;VYS*2D*("`@("`@("`@("`@
M)'1H:7,M/G-E=$]P=&EO;G,H)&]P=&EO;G,L(&%R<F%Y7VUE<F=E*"1T:&ES
M+3YA;&QO=V5D7V]P=&EO;G,L(&%R<F%Y*"=C86-H95]D:7(G+"`G9FEL96YA
M;65?<')E9FEX)RP@)VUA>%]U<V5R9&%T85]L:6YE;&5N9W1H)RDI*3L*("`@
M("`@("`*("`@("`@("!C;&5A<G-T871C86-H92@I.PH@("`@("`@(&EF("@D
M=&AI<RT^8V%C:&5?9&ER*0H@("`@("`@('L*("`@("`@("`@("`@+R\@;6%K
M92!R96QA=&EV92!P871H<R!A8G-O;'5T92!F;W(@=7-E(&EN(&1E8V]N<W1R
M=6-T;W(N"B`@("`@("`@("`@("\O(&ET(&QO;VMS(&QI:V4@=&AE(&1E8V]N
M<W1R=6-T;W(@:&%S('!R;V)L96US('=I=&@@<F5L871I=F4@<&%T:',*("`@
M("`@("`@("`@:68@*$]37U5.25@@)B8@)R\G("$]("1T:&ES+3YC86-H95]D
M:7)[,'T@("D*("`@("`@("`@("`@("`@("1T:&ES+3YC86-H95]D:7(@/2!R
M96%L<&%T:"@@9V5T8W=D*"D@+B`G+R<@+B`D=&AI<RT^8V%C:&5?9&ER*2`N
M("<O)SL*"B`@("`@("`@("`@("\O(&-H96-K(&EF(&$@=')A:6QI;F<@<VQA
M<V@@:7,@:6X@8V%C:&5?9&ER"B`@("`@("`@("`@(&EF("@D=&AI<RT^8V%C
M:&5?9&ER>W-T<FQE;B@D=&AI<RT^8V%C:&5?9&ER*2TQ?2`A/2!$25)%0U1/
M4EE?4T5005)!5$]2*0H@("`@("`@("`@("`@("`@("1T:&ES+3YC86-H95]D
M:7(@+CT@)R\G.PH*("`@("`@("`@("`@:68@("@A9FEL95]E>&ES=',H)'1H
M:7,M/F-A8VAE7V1I<BD@?'P@(6ES7V1I<B@D=&AI<RT^8V%C:&5?9&ER*2D*
M("`@("`@("`@("`@("`@(&UK9&ER*"1T:&ES+3YC86-H95]D:7(L(#`W-34I
M.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^96YT<FEE<R`](&%R<F%Y*"D[
M"B`@("`@("`@)'1H:7,M/F=R;W5P7V1I<G,@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`@("`@("`@(`H@("`@?2`O+R!E;F0@9G5N8R!C;VYT<G5C=&]R"@H@
M("`@9G5N8W1I;VX@9F5T8V@H)&ED+"`D9W)O=7`I('L*("`@("`@("`D9FEL
M92`]("1T:&ES+3YG971&:6QE;F%M92@D:60L("1G<F]U<"D["B`@("`@("`@
M:68@*"%F:6QE7V5X:7-T<R@D9FEL92DI"B`@("`@("`@("`@(')E='5R;B!A
M<G)A>2A.54Q,+"!.54Q,+"!.54Q,*3L*"B`@("`@("`@+R\@<F5T<FEV92!T
M:&4@8V]N=&5N=`H@("`@("`@(&EF("@A*"1F:"`]($!F;W!E;B@D9FEL92P@
M)W)B)RDI*0H@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*")#
M86XG="!A8V-E<W,@8V%C:&4@9FEL92`G)&9I;&4G+B!#:&5C:R!A8V-E<W,@
M<FEG:'1S(&%N9"!P871H+B(L(%]?1DE,15]?+"!?7TQ)3D5?7RD["@H@("`@
M("`@("\O($9I;&4@;&]C:VEN9R`H<VAA<F5D(&QO8VLI"B`@("`@("`@:68@
M*"1T:&ES+3YF:6QE3&]C:VEN9RD*("`@("`@("`@("`@9FQO8VLH)&9H+"!,
M3T-+7U-(*3L*"B`@("`@("`@+R\@9FEL92!F;W)M870Z"B`@("`@("`@+R\@
M,7-T(&QI;F4Z(&5X<&ER871I;VX@9&%T90H@("`@("`@("\O(#)N9"!L:6YE
M.B!U<V5R(&1A=&$*("`@("`@("`O+R`S<F0K(&QI;F5S.B!C86-H92!D871A
M"B`@("`@("`@)&5X<&ER92`]('1R:6TH9F=E=',H)&9H+"`Q,BDI.PH@("`@
M("`@(&EF("@D=&AI<RT^;6%X7W5S97)D871A7VQI;F5L96YG=&@@/3T@,"`I
M('L*("`@("`@("`@("`@)'5S97)D871A(#T@=')I;2AF9V5T<R@D9F@I*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=7-E<F1A=&$@/2!T<FEM
M*&9G971S*"1F:"P@)'1H:7,M/FUA>%]U<V5R9&%T85]L:6YE;&5N9W1H*2D[
M"B`@("`@("`@?0H@("`@("`@("1C86-H961A=&$@/2`D=&AI<RT^9&5C;V1E
M*&9R96%D*"1F:"P@9FEL97-I>F4H)&9I;&4I*2D["@H@("`@("`@("\O(%5N
M;&]C:VEN9PH@("`@("`@(&EF("@D=&AI<RT^9FEL94QO8VMI;F<I"B`@("`@
M("`@("`@(&9L;V-K*"1F:"P@3$]#2U]53BD["@H@("`@("`@(&9C;&]S92@D
M9F@I.PH*("`@("`@("`O+R!L87-T('5S86=E(&1A=&4@=7-E9"!B>2!T:&4@
M9V,@+2!M87AL:69E=&EM90H@("`@("`@("\O('1O=6-H('=I=&AO=70@<V5C
M;VYD('!A<F%M('!R;V1U8V5D('-T=7!I9"!E;G1R:65S+BXN"B`@("`@("`@
M=&]U8V@H)&9I;&4L=&EM92@I*3L*("`@("`@("!C;&5A<G-T871C86-H92@I
M.PH*("`@("`@("!R971U<FX@87)R87DH)&5X<&ER92P@)&-A8VAE9&%T82P@
M)'5S97)D871A*3L*("`@('T@+R\@96YD(&9U;F,@9F5T8V@*"B`@("`O*BH*
M("`@("H@4W1O<F5S(&$@9&%T87-E="X*("`@("H*("`@("H@5T%23DE.1SH@
M268@>6]U('-U<'!L>2!U<V5R9&%T82!I="!M=7-T(&YO="!C;VYT86EN(&%N
M>2!L:6YE8G)E86MS+`H@("`@*B!O=&AE<G=I<V4@:70@=VEL;"!B<F5A:R!T
M:&4@9FEL97-T<G5C='5R92X*("`@("HO"B`@("!F=6YC=&EO;B!S879E*"1I
M9"P@)&-A8VAE9&%T82P@)&5X<&ER97,L("1G<F]U<"P@)'5S97)D871A*2![
M"B`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A9"@D:60L("1G<F]U<"D["@H@
M("`@("`@("1F:6QE(#T@)'1H:7,M/F=E=$9I;&5N86UE*"1I9"P@)&=R;W5P
M*3L*("`@("`@("!I9B`H(2@D9F@@/2!`9F]P96XH)&9I;&4L("=W8B<I*2D*
M("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@B0V%N)W0@86-C
M97-S("<D9FEL92<@=&\@<W1O<F4@8V%C:&4@9&%T82X@0VAE8VL@86-C97-S
M(')I9VAT<R!A;F0@<&%T:"XB+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@
M("`@("`O+R!&:6QE(&QO8VMI;F<@*&5X8VQU<VEV92!L;V-K*0H@("`@("`@
M(&EF("@D=&AI<RT^9FEL94QO8VMI;F<I"B`@("`@("`@("`@(&9L;V-K*"1F
M:"P@3$]#2U]%6"D["@H@("`@("`@("\O(&9I;&4@9F]R;6%T.@H@("`@("`@
M("\O(#%S="!L:6YE.B!E>'!I<F%T:6]N(&1A=&4*("`@("`@("`O+R`R;F0@
M;&EN93H@=7-E<B!D871A"B`@("`@("`@+R\@,W)D*R!L:6YE<SH@8V%C:&4@
M9&%T80H@("`@("`@("1E>'!I<F5S(#T@)'1H:7,M/F=E=$5X<&ER97-!8G-O
M;'5T92@D97AP:7)E<RD["B`@("`@("`@9G=R:71E*"1F:"P@)&5X<&ER97,@
M+B`B7&XB*3L*("`@("`@("!F=W)I=&4H)&9H+"`D=7-E<F1A=&$@+B`B7&XB
M*3L*("`@("`@("!F=W)I=&4H)&9H+"`D=&AI<RT^96YC;V1E*"1C86-H961A
M=&$I*3L*"B`@("`@("`@+R\@1FEL92!U;FQO8VMI;F<*("`@("`@("!I9B`H
M)'1H:7,M/F9I;&5,;V-K:6YG*0H@("`@("`@("`@("!F;&]C:R@D9F@L($Q/
M0TM?54XI.PH*("`@("`@("!F8VQO<V4H)&9H*3L*"B`@("`@("`@+R\@22=M
M(&YO="!S=7)E(&EF('=E(&YE960@=&AI<PH)+R\@:2!D;VXG="!T:&EN:R!W
M92!N965D('1H:7,@*&-H<F5G=2D*("`@("`@("`O+R!T;W5C:"@D9FEL92D[
M"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?2`O+R!E;F0@9G5N8R!S879E
M"@H@("`@9G5N8W1I;VX@<F5M;W9E*"1I9"P@)&=R;W5P*2!["B`@("`@("`@
M)'1H:7,M/F9L=7-H4')E;&]A9"@D:60L("1G<F]U<"D["@H@("`@("`@("1F
M:6QE(#T@)'1H:7,M/F=E=$9I;&5N86UE*"1I9"P@)&=R;W5P*3L*("`@("`@
M("!I9B`H9FEL95]E>&ES=',H)&9I;&4I*2!["@H@("`@("`@("`@("`D;VL@
M/2!U;FQI;FLH)&9I;&4I.PH@("`@("`@("`@("!C;&5A<G-T871C86-H92@I
M.PH*("`@("`@("`@("`@<F5T=7)N("1O:SL*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!F86QS93L*("`@('T@+R\@96YD(&9U;F,@<F5M;W9E"@H@("`@
M9G5N8W1I;VX@9FQU<V@H)&=R;W5P*2!["B`@("`@("`@)'1H:7,M/F9L=7-H
M4')E;&]A9"@I.PH@("`@("`@("1D:7(@/2`H)&=R;W5P*2`_("1T:&ES+3YC
M86-H95]D:7(@+B`D9W)O=7`@+B`G+R<@.B`D=&AI<RT^8V%C:&5?9&ER.PH*
M("`@("`@("`D;G5M7W)E;6]V960@/2`D=&AI<RT^9&5L971E1&ER*"1D:7(I
M.PH@("`@("`@('5N<V5T*"1T:&ES+3YG<F]U<%]D:7)S6R1G<F]U<%TI.PH@
M("`@("`@(&-L96%R<W1A=&-A8VAE*"D["@H@("`@("`@(')E='5R;B`D;G5M
M7W)E;6]V960["B`@("!]("\O(&5N9"!F=6YC(&9L=7-H"@H@("`@9G5N8W1I
M;VX@:61%>&ES=',H)&ED+"`D9W)O=7`I('L*"B`@("`@("`@<F5T=7)N(&9I
M;&5?97AI<W1S*"1T:&ES+3YG971&:6QE;F%M92@D:60L("1G<F]U<"DI.PH@
M("`@?2`O+R!E;F0@9G5N8R!I9$5X:7-T<PH*("`@("\J*@H@("`@*B!$96QE
M=&5S(&%L;"!E>'!I<F5D(&9I;&5S+@H@("`@*@H@("`@*B!'87)B86=E(&-O
M;&QE8W1I;VX@9F]R(&9I;&5S(&ES(&$@<F%T:&5R(")E>'!E;G-I=F4B+"`B
M;&]N9R!T:6UE(@H@("`@*B!O<&5R871I;VXN($%L;"!F:6QE<R!I;B!T:&4@
M8V%C:&4@9&ER96-T;W)Y(&AA=F4@=&\@8F4@97AA;6EN960@=VAI8V@*("`@
M("H@;65A;G,@=&AA="!T:&5Y(&UU<W0@8F4@;W!E;F5D(&9O<B!R96%D:6YG
M+"!T:&4@97AP:7)A=&EO;B!D871E(&AA<R!T;R!B90H@("`@*B!R96%D(&9R
M;VT@=&AE;2!A;F0@:68@;F5C8V5S<V%R>2!T:&5Y(&AA=F4@=&\@8F4@=6YL
M:6YK960@*')E;6]V960I+@H@("`@*B!)9B!Y;W4@:&%V92!A('5S97(@8V]M
M;65N="!F;W(@82!G;V]D(&1E9F%U;'0@9V,@<')O8F%B:6QI='D@<&QE87-E
M(&%D9"!I="!T;PH@("`@*B!T;R!T:&4@:6YL:6YE(&1O8W,N"B`@("`J"B`@
M("`J($!P87)A;2`@("!I;G1E9V5R($UA>&EM=6T@;&EF971I;64@:6X@<V5C
M;VYD<R!O9B!A;B!N;R!L;VYG97(@=7-E9"]T;W5C:&5D(&5N=')Y"B`@("`J
M($!T:')O=W,@("!#86-H95]%<G)O<@H@("`@*B\*("`@(&9U;F-T:6]N(&=A
M<F)A9V5#;VQL96-T:6]N*"1M87AL:69E=&EM92D@>PH*("`@("`@("`D=&AI
M<RT^9FQU<VA0<F5L;V%D*"D["B`@("`@("`@8VQE87)S=&%T8V%C:&4H*3L*
M"B`@("`@("`@)&]K(#T@)'1H:7,M/F1O1V%R8F%G94-O;&QE8W1I;VXH)&UA
M>&QI9F5T:6UE+"`D=&AI<RT^8V%C:&5?9&ER*3L*"B`@("`@("`@+R\@8VAE
M8VL@=&AE('-P86-E('5S960@8GD@=&AE(&-A8VAE(&5N=')I97,@("`@("`@
M(`H@("`@("`@(&EF("@D=&AI<RT^=&]T86Q?<VEZ92`^("1T:&ES+3YH:6=H
M=V%T97(I('L*("`@("`@("`*("`@("`@("`@("`@:W)S;W)T*"1T:&ES+3YE
M;G1R:65S*3L*("`@("`@("`@("`@<F5S970H)'1H:7,M/F5N=')I97,I.PH@
M("`@("`@("`@("`*("`@("`@("`@("`@=VAI;&4@*"1T:&ES+3YT;W1A;%]S
M:7IE(#X@)'1H:7,M/FQO=W=A=&5R("8F(&QI<W0H)&QA<W1M;V0L("1E;G1R
M>2D@/2!E86-H*"1T:&ES+3YE;G1R:65S*2D@>PH@("`@("`@("`@("`@("`@
M:68@*$!U;FQI;FLH)&5N=')Y6R=F:6QE)UTI*0H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YT;W1A;%]S:7IE("T]("1E;G1R>5LG<VEZ92==.PH@("`@
M("`@("`@("`@("`@96QS90H@("`@("`@("`@("`@("`@("`@(&YE=R!#86-H
M945R<F]R*")#86XG="!D96QE=&4@>R1E;G1R>5LB9FEL92)=?2X@0VAE8VL@
M=&AE('!E<FUI<W-I;VYS+B(I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(`H@("`@("`@('T*("`@("`@("`*("`@("`@("`D=&AI<RT^96YT<FEE<R`]
M(&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/G1O=&%L7W-I>F4@/2`P.PH@("`@
M("`@(`H@("`@("`@(')E='5R;B`D;VL["B`@("!]("\O(&5N9"!F=6YC(&=A
M<F)A9V5#;VQL96-T:6]N"B`@("`*("`@("\J*@H@("`@*B!$;V5S('1H92!R
M96-U<G-I=F4@9V,@<')O8V5D=7)E+"!P<F]T96-T960N"B`@("`J"B`@("`J
M($!P87)A;2`@("!I;G1E9V5R($UA>&EM=6T@;&EF971I;64@:6X@<V5C;VYD
M<R!O9B!A;B!N;R!L;VYG97(@=7-E9"]T;W5C:&5D(&5N=')Y"B`@("`J($!P
M87)A;2`@("!S=')I;F<@(&1I<F5C=&]R>2!T;R!E>&%M:6YE("T@9&]N)W0@
M<V5T<R!T:&ES('!A<F%M971E<BP@:70G<R!U<V5D(&9O<B!A"B`@("`J("`@
M("`@("`@("`@("`@("`@(')E8W5R<VEV92!F=6YC=&EO;B!C86QL(0H@("`@
M*B!`=&AR;W=S("`@0V%C:&5?17)R;W(*("`@("HO"B`@("!F=6YC=&EO;B!D
M;T=A<F)A9V5#;VQL96-T:6]N*"1M87AL:69E=&EM92P@)&1I<BD@>PH@("`@
M("`@("`@(`H@("`@("`@(&EF("@A*"1D:"`](&]P96YD:7(H)&1I<BDI*0H@
M("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*")#86XG="!A8V-E
M<W,@8V%C:&4@9&ER96-T;W)Y("<D9&ER)RX@0VAE8VL@<&5R;6ES<VEO;G,@
M86YD('!A=&@N(BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@=VAI
M;&4@*"1F:6QE(#T@<F5A9&1I<B@D9&@I*2!["B`@("`@("`@("`@(&EF("@G
M+B<@/3T@)&9I;&4@?'P@)RXN)R`]/2`D9FEL92D*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PH*("`@("`@("`@("`@)&9I;&4@/2`D9&ER("X@)&9I;&4[
M"B`@("`@("`@("`@(&EF("AI<U]D:7(H)&9I;&4I*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^9&]'87)B86=E0V]L;&5C=&EO;B@D;6%X;&EF971I;64L
M)&9I;&4@+B`G+R<I.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("\O('-K:7`@=')O=6)L92!M86ME<G,@
M8G5T(&EN9F]R;2!T:&4@=7-E<@H@("`@("`@("`@("!I9B`H(2@D9F@@/2!`
M9F]P96XH)&9I;&4L("=R8B<I*2D@>PH@("`@("`@("`@("`@("`@;F5W($-A
M8VAE7T5R<F]R*")#86XG="!A8V-E<W,@8V%C:&4@9FEL92`G)&9I;&4G+"!S
M:VEP<&EN9R!I="X@0VAE8VL@<&5R;6ES<VEO;G,@86YD('!A=&@N(BP@7U]&
M24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D97AP:7)E(#T@9F=E=',H)&9H
M+"`Q,2D["B`@("`@("`@("`@(&9C;&]S92@D9F@I.PH@("`@("`@("`@("`D
M;&%S='5S960@/2!F:6QE;71I;64H)&9I;&4I.PH@("`@("`@("`@("`*("`@
M("`@("`@("`@)'1H:7,M/F5N=')I97-;)&QA<W1U<V5D72`](&%R<F%Y*"=F
M:6QE)R`]/B`D9FEL92P@)W-I>F4G(#T^(&9I;&5S:7IE*"1F:6QE*2D["B`@
M("`@("`@("`@("1T:&ES+3YT;W1A;%]S:7IE("L](&9I;&5S:7IE*"1F:6QE
M*3L*("`@("`@("`@("`@"B`@("`@("`@("`@("\O(')E;6]V92!I9B!E>'!I
M<F5D"B`@("`@("`@("`@(&EF("@H("@D97AP:7)E("8F("1E>'!I<F4@/#T@
M=&EM92@I*2!\?"`H)&QA<W1U<V5D(#P]("AT:6UE*"D@+2`D;6%X;&EF971I
M;64I*2`I("8F("%U;FQI;FLH)&9I;&4I*0H@("`@("`@("`@("`@("`@;F5W
M($-A8VAE7T5R<F]R*")#86XG="!U;FQI;FL@8V%C:&4@9FEL92`G)&9I;&4G
M+"!S:VEP<&EN9RX@0VAE8VL@<&5R;6ES<VEO;G,@86YD('!A=&@N(BP@7U]&
M24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@(&-L;W-E9&ER
M*"1D:"D["@H@("`@("`@("\O(&9L=7-H('1H92!D:7-K('-T871E(&-A8VAE
M"B`@("`@("`@8VQE87)S=&%T8V%C:&4H*3L*"B`@("!]("\O(&5N9"!F=6YC
M(&1O1V%R8F%G94-O;&QE8W1I;VX*"B`@("`O*BH*("`@("H@4F5T=7)N<R!T
M:&4@9FEL96YA;64@9F]R('1H92!S<&5C:69I960@:60N"B`@("`J"B`@("`J
M($!P87)A;2`@("!S=')I;F<@(&1A=&%S970@240*("`@("H@0'!A<F%M("`@
M('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@("H@0')E='5R;B`@('-T<FEN9R`@
M9G5L;"!F:6QE;F%M92!W:71H('1H92!P871H"B`@("`J($!A8V-E<W,@("!P
M=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!G971&:6QE;F%M92@D:60L("1G
M<F]U<"D@>PH*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F=R;W5P7V1I<G-;
M)&=R;W5P72DI"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9W)O=7!?9&ER
M<ULD9W)O=7!=("X@)'1H:7,M/F9I;&5N86UE7W!R969I>"`N("1I9#L*"B`@
M("`@("`@)&1I<B`]("1T:&ES+3YC86-H95]D:7(@+B`D9W)O=7`@+B`G+R<[
M"B`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D9&ER*2D@>PH@("`@("`@("`@
M("!M:V1I<B@D9&ER+"`P-S4U*3L*("`@("`@("`@("`@8VQE87)S=&%T8V%C
M:&4H*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YG<F]U<%]D:7)S6R1G
M<F]U<%T@/2`D9&ER.PH*("`@("`@("!R971U<FX@)&1I<B`N("1T:&ES+3YF
M:6QE;F%M95]P<F5F:7@@+B`D:60["B`@("!]("\O(&5N9"!F=6YC(&=E=$9I
M;&5N86UE"@H@("`@+RHJ"B`@("`J($1E;&5T97,@82!D:7)E8W1O<GD@86YD
M(&%L;"!F:6QE<R!I;B!I="X*("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN
M9R`@9&ER96-T;W)Y"B`@("`J($!R971U<FX@("!I;G1E9V5R(&YU;6)E<B!O
M9B!R96UO=F5D(&9I;&5S"B`@("`J($!T:')O=W,@("!#86-H95]%<G)O<@H@
M("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T941I<B@D9&ER*2!["B`@("`@("`@
M:68@*"$H)&1H(#T@;W!E;F1I<B@D9&ER*2DI"B`@("`@("`@("`@(')E='5R
M;B!N97<@0V%C:&5?17)R;W(H(D-A;B=T(')E;6]V92!D:7)E8W1O<GD@)R1D
M:7(G+B!#:&5C:R!P97)M:7-S:6]N<R!A;F0@<&%T:"XB+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH*("`@("`@("`D;G5M7W)E;6]V960@/2`P.PH*("`@("`@
M("!W:&EL92`H9F%L<V4@(3T]("1F:6QE(#T@<F5A9&1I<B@D9&@I*2!["B`@
M("`@("`@("`@(&EF("@G+B<@/3T@)&9I;&4@?'P@)RXN)R`]/2`D9FEL92D*
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH*("`@("`@("`@("`@)&9I;&4@
M/2`D9&ER("X@)&9I;&4["B`@("`@("`@("`@(&EF("AI<U]D:7(H)&9I;&4I
M*2!["B`@("`@("`@("`@("`@("`D9FEL92`N/2`G+R<["B`@("`@("`@("`@
M("`@("`D;G5M(#T@)'1H:7,M/F1E;&5T941I<B@D9FEL92`N("<O)RD["B`@
M("`@("`@("`@("`@("!I9B`H:7-?:6YT*"1N=6TI*0H@("`@("`@("`@("`@
M("`@("`@("1N=6U?<F5M;W9E9"`K/2`D;G5M.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@:68@*'5N;&EN:R@D9FEL92DI"B`@("`@
M("`@("`@("`@("`@("`@)&YU;5]R96UO=F5D*RL["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@+R\@86-C;W)D:6YG('1O('!H<"UM86YU86P@
M=&AE(&9O;&QO=VEN9R!I<R!N965D960@9F]R('=I;F1O=W,@:6YS=&%L;&%T
M:6]N<RX*("`@("`@("!C;&]S961I<B@D9&@I.PH@("`@("`@('5N<V5T*"`D
M9&@I.PH@("`@("`@(&EF("@D9&ER("$]("1T:&ES+3YC86-H95]D:7(I('L@
M("\O9&5L971E('1H92!S=6(M9&ER(&5N=')I97,@(&ET<V5L9B!A;'-O+"!B
M=70@;F]T('1H92!C86-H92UD:7(N"B`@("`@("`@("`@(')M1&ER*"1D:7(I
M.PH@("`@("`@("`@("`D;G5M7W)E;6]V960K*SL*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D;G5M7W)E;6]V960["B`@("!]("\O(&5N9"!F=6YC(&1E
M;&5T941I<@H@("`@"GT@+R\@96YD(&-L87-S(&9I;&4*/SX*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O0V%C:&4O0V]N=&%I;F5R+VUD8BYP:'``````````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,S,R,30`,3`U,34T,S,W,S0`,#(S,#`W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!%05(@.CH@0V%C:&4@
M.CH@341"($-O;G1A:6YE<B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE
M8W0@=&\@=F5R<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\
M"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H
M92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L
M92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE
M(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I
M;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@
M82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@
M=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($YO
M=&4Z(%1H:7,@:7,@82!-1$(M;W)I96YT960@<F5W<FET92!O9B!#86-H92]#
M;VYT86EN97(O9&(N<&AP+B`@("`@('P*+R\@?"!4:&%N:W,@=&\@3'5K87,@
M4VUI=&@@9F]R(&AI<R!P871I96YC92!I;B!A;G-W97)I;F<@;7D@<75E<W1I
M;VYS("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M($%U=&AO<CH@3&]R96YZ;R!!;&)E<G1O;B`\;"YA;&)E<G1O;B!A="!Q=6EP
M;RYI=#X@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@;61B+G!H<"QV(#$N,R`R,#`S+S`Q
M+S`T(#$Q.C4T.C0V(&UJ($5X<"`D"@IR97%U:7)E7V]N8V4@)TU$0BYP:'`G
M.PIR97%U:7)E7V]N8V4@)T-A8VAE+T-O;G1A:6YE<BYP:'`G.PH*+RHJ"BH@
M4$5!4B]-1$(@0V%C:&4@0V]N=&%I;F5R+@HJ"BH@3D(Z(%1H92!F:65L9"`G
M8VAA;F=E9"<@:&%S(&YO(&UE86YI;F<@9F]R('1H92!#86-H92!I='-E;&8N
M($ET)W,@:G5S="!T:&5R90HJ(&)E8V%U<V4@:70G<R!A(&=O;V0@:61E82!T
M;R!H879E(&%N(&%U=&]M871I8V%L;'D@=7!D871E9"!T:6UE<W1A;7`**B!F
M:65L9"!F;W(@9&5B=6=G:6YG(&EN(&%L;"!O9B!Y;W5R('1A8FQE<RX**@HJ
M($$@6$U,($U$0BUC;VUP;&EA;G0@<V-H96UA(&5X86UP;&4@9F]R('1H92!T
M86)L92!N965D960@:7,@<')O=FED960N"BH@3&]O:R!A="!T:&4@9FEL92`B
M;61B7V-A8VAE7W-C:&5M82YX;6PB(&9O<B!T:&%T+@HJ"BH@+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"BH@02!B87-I8R!U
M<V%G92!E>&%M<&QE.@HJ("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+0HJ"BH@)&1B:6YF;R`](&%R<F%Y*`HJ("`@)V1A=&%B
M87-E)R`@("`]/B`G9&)N86UE)RP**B`@("=P:'!T>7!E)R`@("`@/3X@)VUY
M<W%L)RP**B`@("=U<V5R;F%M92<@("`@/3X@)W)O;W0G+`HJ("`@)W!A<W-W
M;W)D)R`@("`]/B`G)RP**B`@("=C86-H95]T86)L92<@/3X@)V-A8VAE)PHJ
M("D["BH**@HJ("1C86-H92`](&YE=R!#86-H92@G;61B)RP@)&1B:6YF;RD[
M"BH@)&ED(#T@)&-A8VAE+3YG96YE<F%T94E$*"=T97-T96YT<GDG*3L**@HJ
M(&EF("@D9&%T82`]("1C86-H92T^9V5T*"1I9"DI('L**B`@("!E8VAO("=#
M86-H92!H:70N/&)R("\^1&%T83H@)RXD9&%T83L**@HJ('T@96QS92!["BH@
M("`D9&%T82`]("=D871A(&]F(&%N>2!K:6YD)SL**B`@("1C86-H92T^<V%V
M92@D:60L("1D871A*3L**B`@(&5C:&\@)T-A8VAE(&UI<W,N/&)R("\^)SL*
M*B!]"BH**B`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2T**@HJ($!A=71H;W(@("!,;W)E;GIO($%L8F5R=&]N(#QL+F%L8F5R
M=&]N(&%T('%U:7!O+FET/@HJ($!V97)S:6]N("`D260Z(&UD8BYP:'`L=B`Q
M+C,@,C`P,R\P,2\P-"`Q,3HU-#HT-B!M:B!%>'`@)`HJ($!P86-K86=E("!#
M86-H90HJ+PIC;&%S<R!#86-H95]#;VYT86EN97)?;61B(&5X=&5N9',@0V%C
M:&5?0V]N=&%I;F5R('L*"B`@("`O*BH*("`@("`J($YA;64@;V8@=&AE($U$
M0B!T86)L92!T;R!S=&]R92!C86-H:6YG(&1A=&$*("`@("`J"B`@("`@*B!`
M<V5E("!#86-H95]#;VYT86EN97)?9FEL93HZ)&9I;&5N86UE7W!R969I>`H@
M("`@("HO"B`@("!V87(@)&-A8VAE7W1A8FQE(#T@)R<["@H@("`@+RHJ"B`@
M("`@*B!014%2($U$0B!O8FIE8W0*("`@("`J"B`@("`@*B!`=F%R("!O8FIE
M8W0@4$5!4E]-1$(*("`@("`J+PH@("`@=F%R("1D8CL*"B`@("`O*BH*("`@
M("`J($-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D($%R
M<F%Y('=I=&@@8V]N;F5C=&EO;B!I;F9O(&]R(&1S;B!S=')I;F<*("`@("`J
M+PH@("`@9G5N8W1I;VX@0V%C:&5?0V]N=&%I;F5R7VUD8B@D;W!T:6]N<RD*
M("`@('L*("`@("`@("`D=&AI<RT^9&(@/2`F341".CI#;VYN96-T*"1O<'1I
M;VYS*3L*("`@("`@("!I9BA-1$(Z.FES17)R;W(H)'1H:7,M/F1B*2D@>PH@
M("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)TU$0CHZ8V]N;F5C
M="!F86EL960Z("<*("`@("`@("`@("`@("`@("`@("`N("1T:&ES+3YD8BT^
M9V5T365S<V%G92@I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1T:&ES+3YD8BT^<V5T1F5T8VA-;V1E*$U$
M0E]&151#2$U/1$5?05-33T,I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^
M<V5T3W!T:6]N<R@D;W!T:6]N<RP@87)R87E?;65R9V4H)'1H:7,M/F%L;&]W
M961?;W!T:6]N<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@G9'-N)RP@)V-A8VAE7W1A8FQE)RDI*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($9E=&-H(&EN('1H92!D8B!T:&4@9&%T82!T:&%T
M(&UA=&-H97,@:6YP=70@<&%R86UE=&5R<PH@("`@("H*("`@("`J($!P87)A
M;2`@("!S=')I;F<@(&1A=&%S970@240*("`@("`J($!P87)A;2`@("!S=')I
M;F<@(&-A8VAE(&=R;W5P"B`@("`@*B!`<F5T=7)N("`@;6EX960@("!D871A
M<V5T('9A;'5E(&]R($Y53$PO0V%C:&5?17)R;W(@;VX@9F%I;'5R90H@("`@
M("H@0&%C8V5S<R`@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!F971C
M:"@D:60L("1G<F]U<"D*("`@('L*("`@("`@("`D<75E<GD@/2`G4T5,14-4
M(&-A8VAE9&%T82!&4D]-("<@+B`D=&AI<RT^8V%C:&5?=&%B;&4*("`@("`@
M("`@("`@("`@("XG(%=(15)%(&ED/2<@("`@("`@+B`D=&AI<RT^9&(M/F=E
M=%1E>'1686QU92@D:60I"B`@("`@("`@("`@("`@("`N)R!!3D0@8V%C:&5G
M<F]U<#TG("X@)'1H:7,M/F1B+3YG971497AT5F%L=64H)&=R;W5P*3L*("`@
M("`@("!I9B@D<F5S(#T@)'1H:7,M/F1B+3YQ=65R>2@D<75E<GDI*2!["B`@
M("`@("`@("`@(&EF*"1T:&ES+3YD8BT^96YD3V9297-U;'0H)')E<RDI('L*
M("`@("`@("`@("`@("`@("\O;F\@<F]W<R!R971U<FYE9`H@("`@("`@("`@
M("`@("`@)&1A=&$@/2!A<G)A>2A.54Q,+"!.54Q,+"!.54Q,*3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1C;&]B(#T@)'1H:7,M
M/F1B+3YF971C:$-L;V(H)')E<RPP+"=C86-H961A=&$G*3L*("`@("`@("`@
M("`@("`@(&EF*"%-1$(Z.FES17)R;W(H)&-L;V(I*2!["B`@("`@("`@("`@
M("`@("`@("`@)&-A8VAE9%]D871A(#T@)R<["B`@("`@("`@("`@("`@("`@
M("`@=VAI;&4H(21T:&ES+3YD8BT^96YD3V9,3T(H)&-L;V(I*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF*$U$0CHZ:7-%<G)O<B@D97)R;W(@/0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9&(M
M/G)E861,;V(H)&-L;V(L)&1A=&$L.#`P,"D\,"DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)TU$0CHZ
M<75E<GD@9F%I;&5D.B`G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("X@)&5R<F]R+3YG971-97-S86=E*"DL(%]?1DE,15]?+"!?7TQ)
M3D5?7RD["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`@("`@)&-A8VAE9%]D871A("X]("1D871A.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!U;G-E="@D9&%T82D[
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F1B+3YD97-T<F]Y3&]B*"1C
M;&]B*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9&(M/F9R965297-U
M;'0H)')E<RD["@H@("`@("`@("`@("`@("`@("`@("\O9FEN:7-H960@9F5T
M8VAI;F<@3$]"+"!N;W<@9F5T8V@@;W1H97(@9FEE;&1S+BXN"B`@("`@("`@
M("`@("`@("`@("`@)'%U97)Y(#T@)U-%3$5#5"!U<V5R9&%T82P@97AP:7)E
M<R!&4D]-("<@+B`D=&AI<RT^8V%C:&5?=&%B;&4*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("XG(%=(15)%(&ED/2<@("`@("`@+B`D=&AI<RT^9&(M
M/F=E=%1E>'1686QU92@D:60I"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`N)R!!3D0@8V%C:&5G<F]U<#TG("X@)'1H:7,M/F1B+3YG971497AT5F%L
M=64H)&=R;W5P*3L*("`@("`@("`@("`@("`@("`@("!I9B@D<F5S(#T@)'1H
M:7,M/F1B+3YQ=65R>2@D<75E<GDI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1R;W<@/2`D=&AI<RT^9&(M/F9E=&-H26YT;R@D<F5S*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1R;W<I*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9&%T82`](&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')O=ULG97AP:7)E
M<R==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/F1E8V]D92@D8V%C:&5D7V1A=&$I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)')O=ULG=7-E<F1A=&$G70H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1A=&$@/2!A<G)A>2A.54Q,+"!.54Q,+"!.54Q,*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@("1D871A(#T@87)R87DH3E5,
M3"P@3E5,3"P@3E5,3"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M;F5W($-A8VAE7T5R<F]R*"=-1$(Z.G%U97)Y(&9A:6QE9#H@)PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("X@)&-L;V(M/F=E=$UE<W-A9V4H*2P@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^9&(M/F9R965297-U;'0H)')E
M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R]R971U<FX@;F5W
M($-A8VAE7T5R<F]R*"=-1$(Z.G%U97)Y(&9A:6QE9#H@)PH@("`@("`@("`@
M("`O+R`@("`@("`@("`N("1R97-U;'0M/F=E=$UE<W-A9V4H*2P@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@)&1A=&$@/2!A<G)A>2A.54Q,
M+"!.54Q,+"!.54Q,*3L*("`@("`@("!]"@H@("`@("`@("\O(&QA<W0@=7-E
M9"!R97%U:7)E9"!B>2!T:&4@9V%R8F%G92!C;VQL96-T:6]N"B`@("`@("`@
M)'%U97)Y(#T@)U501$%412`G("`@("`@("`@("X@)'1H:7,M/F-A8VAE7W1A
M8FQE"B`@("`@("`@("`@("`@("`N)R!3150@8VAA;F=E9#TG("`@("X@=&EM
M92@I"B`@("`@("`@("`@("`@("`N)R!72$5212!I9#TG("`@("`@("X@)'1H
M:7,M/F1B+3YG971497AT5F%L=64H)&ED*0H@("`@("`@("`@("`@("`@+B<@
M04Y$(&-A8VAE9W)O=7`])R`N("1T:&ES+3YD8BT^9V5T5&5X=%9A;'5E*"1G
M<F]U<"D["@H@("`@("`@("1R97,@/2`D=&AI<RT^9&(M/G%U97)Y*"1Q=65R
M>2D["B`@("`@("`@:68@*$U$0CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@
M("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=-1$(Z.G%U97)Y(&9A:6QE
M9#H@)PH@("`@("`@("`@("`@("`@+B`D=&AI<RT^9&(M/F5R<F]R365S<V%G
M92@D<F5S*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1D871A.PH@("`@?0H*("`@+RHJ"B`@("`@*B!3=&]R97,@
M82!D871A<V5T(&EN('1H92!D871A8F%S90H@("`@("H*("`@("`J($EF(&1A
M=&%S971?240@86QR96%D>2!E>&ES=',L(&]V97)W<FET92!I="!W:71H(&YE
M=R!D871A+`H@("`@("H@96QS92!I;G-E<G0@9&%T82!I;B!A(&YE=R!R96-O
M<F0N"B`@("`@*@H@("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T87-E="!)
M1`H@("`@("H@0'!A<F%M("`@(&UI>&5D("`@9&%T82!T;R!B92!C86-H960*
M("`@("`J($!P87)A;2`@("!I;G1E9V5R(&5X<&ER871I;VX@=&EM90H@("`@
M("H@0'!A<F%M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@("`J($!P87)A
M;2`@("!S=')I;F<@('5S97)D871A"B`@("`@*B!`86-C97-S("`@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-A=F4H)&ED+"`D9&%T82P@)&5X<&ER
M97,L("1G<F]U<"P@)'5S97)D871A*0H@("`@>PH@("`@("`@(&=L;V)A;"`D
M9&(["B`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A9"@D:60L("1G<F]U<"D[
M"@H@("`@("`@("1F:65L9',@/2!A<G)A>2@*("`@("`@("`@("`@)VED)R`@
M("`@("`@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M5'EP92<@("`]/B`G=&5X="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G5F%L=64G("`]/B`D:60L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G2V5Y)R`@("`]/B!T<G5E"B`@("`@("`@("`@("`@("`@("`@("`@("DL
M"B`@("`@("`@("`@("=U<V5R9&%T82<@(#T^(&%R<F%Y*`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)U1Y<&4G("`@/3X@)VEN=&5G97(G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)U9A;'5E)R`@/3X@)'5S97)D871A
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)TYU;&PG("`@/3X@*"1U
M<V5R9&%T82`_(&9A;'-E(#H@=')U92D*("`@("`@("`@("`@("`@("`@("`@
M("`@*2P*("`@("`@("`@("`@)V5X<&ER97,G("`@/3X@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G5'EP92<@("`]/B`G:6YT96=E<B<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G5F%L=64G("`]/B`D=&AI
M<RT^9V5T17AP:7)E<T%B<V]L=71E*"1E>'!I<F5S*0H@("`@("`@("`@("`@
M("`@("`@("`@("`I+`H@("`@("`@("`@("`G8V%C:&5G<F]U<"<@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G5'EP92<@("`]/B`G
M=&5X="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G5F%L=64G("`]
M/B`D9W)O=7`*("`@("`@("`@("`@("`@("`@("`@("`@*0H@("`@("`@("`@
M("`I.PH*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F1B+3YR97!L86-E*"1T
M:&ES+3YC86-H95]T86)L92P@)&9I96QD<RD["@H@("`@("`@(&EF*$U$0CHZ
M:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`O+U9A<E]$=6UP.CID
M:7-P;&%Y*"1R97-U;'0I.PH@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE
M7T5R<F]R*"=-1$(Z.G%U97)Y(&9A:6QE9#H@)PH@("`@("`@("`@("`@("`@
M("`@("X@)'1H:7,M/F1B+3YE<G)O<DUE<W-A9V4H)')E<W5L="DL(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@("`@('5N<V5T*"1F:65L
M9',I.R`O+V5N9"!F:7)S="!P87)T(&]F('%U97)Y"B`@("`@("`@)'%U97)Y
M,B`]("=54$1!5$4@)R`@("X@)'1H:7,M/F-A8VAE7W1A8FQE"B`@("`@("`@
M("`@("`@("`@+B<@4T54(&-A8VAE9&%T83T_)PH@("`@("`@("`@("`@("`@
M("XG(%=(15)%(&ED/2<N("1T:&ES+3YD8BT^9V5T5&5X=%9A;'5E*"1I9"D[
M"@H@("`@("`@(&EF*"@D<')E<&%R961?<75E<GD@/2`D=&AI<RT^9&(M/G!R
M97!A<F51=65R>2@D<75E<GDR*2DI('L*("`@("`@("`@("`@)&-H87)?;&]B
M(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G17)R;W(G
M(#T^("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U1Y<&4G(#T^
M("=D871A)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=$871A)R`]
M/B`D=&AI<RT^96YC;V1E*"1D871A*0H@("`@("`@("`@("`@("`@("`@("`@
M("`I.PH@("`@("`@("`@("!I9B@A341".CII<T5R<F]R*"1C;&]B(#T@)'1H
M:7,M/F1B+3YC<F5A=&5,;V(H)&-H87)?;&]B*2DI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3YD8BT^<V5T4&%R86U#;&]B*"1P<F5P87)E9%]Q=65R>2PQ
M+"1C;&]B+"=C86-H961A=&$G*3L*("`@("`@("`@("`@("`@(&EF*$U$0CHZ
M:7-%<G)O<B@D97)R;W(])'1H:7,M/F1B+3YE>&5C=71E475E<GDH)'!R97!A
M<F5D7W%U97)Y*2DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@;F5W
M($-A8VAE7T5R<F]R*"=-1$(Z.G%U97)Y(&9A:6QE9#H@)PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+B`D97)R;W(M/F=E=$UE<W-A9V4H*2`L(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D=&AI<RT^9&(M/F1E<W1R;WE,;V(H)&-L;V(I.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@8W)E871I;VX@;V8@
M=&AE(&AA;F1L97(@;V)J96-T(&9A:6QE9`H@("`@("`@("`@("`@("`@<F5T
M=7)N(&YE=R!#86-H95]%<G)O<B@G341".CIQ=65R>2!F86EL960Z("<*("`@
M("`@("`@("`@("`@("`@("`@("`@+B`D8VQO8BT^9V5T365S<V%G92@I("P@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D=&AI<RT^9&(M/F9R9650<F5P87)E9%%U97)Y*"1P<F5P87)E9%]Q=65R
M>2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R]P<F5P87)E9"!Q
M=65R>2!F86EL960*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O
M<B@G341".CIQ=65R>2!F86EL960Z("<*("`@("`@("`@("`@("`@("`@("`N
M("1P<F5P87)E9%]Q=65R>2T^9V5T365S<V%G92@I("P@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO
M=F5S(&$@9&%T87-E="!F<F]M('1H92!D871A8F%S90H@("`@("H*("`@("`J
M($!P87)A;2`@("!S=')I;F<@(&1A=&%S970@240*("`@("`J($!P87)A;2`@
M("!S=')I;F<@(&-A8VAE(&=R;W5P"B`@("`@*B\*("`@(&9U;F-T:6]N(')E
M;6]V92@D:60L("1G<F]U<"D*("`@('L*("`@("`@("`D=&AI<RT^9FQU<VA0
M<F5L;V%D*"1I9"P@)&=R;W5P*3L*"B`@("`@("`@)'%U97)Y(#T@)T1%3$54
M12!&4D]-("<@("`@("X@)'1H:7,M/F-A8VAE7W1A8FQE"B`@("`@("`@("`@
M("`@("`N)R!72$5212!I9#TG("`@("`@("X@)'1H:7,M/F1B+3YG971497AT
M5F%L=64H)&ED*0H@("`@("`@("`@("`@("`@+B<@04Y$(&-A8VAE9W)O=7`]
M)R`N("1T:&ES+3YD8BT^9V5T5&5X=%9A;'5E*"1G<F]U<"D["@H@("`@("`@
M("1R97,@/2`D=&AI<RT^9&(M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@:68@
M*$U$0CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@("`@("!R971U<FX@;F5W
M($-A8VAE7T5R<F]R*"=-1$(Z.G%U97)Y(&9A:6QE9#H@)PH@("`@("`@("`@
M("`@("`@("`@("X@)'1H:7,M/F1B+3YE<G)O<DUE<W-A9V4H)')E<RDL(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@4F5M;W9E(&%L;"!C86-H960@9&%T82!F;W(@82!C97)T86EN(&=R
M;W5P+"!O<B!E;7!T>0H@("`@("H@=&AE(&-A8VAE('1A8FQE(&EF(&YO(&=R
M;W5P(&ES('-P96-I9FEE9"X*("`@("`J"B`@("`@*B!`<&%R86T@("`@<W1R
M:6YG("!C86-H92!G<F]U<`H@("`@("HO"B`@("!F=6YC=&EO;B!F;'5S:"@D
M9W)O=7`@/2`G)RD*("`@('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D
M*"D["@H@("`@("`@(&EF("@D9W)O=7`I('L*("`@("`@("`@("`@)'%U97)Y
M(#T@)T1%3$5412!&4D]-("<@("`@("`@+B`D=&AI<RT^8V%C:&5?=&%B;&4*
M("`@("`@("`@("`@("`@("`@("`N)R!72$5212!C86-H96=R;W5P/2<@+B`D
M=&AI<RT^9&(M/F=E=%1E>'1686QU92@D9W)O=7`I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1Q=65R>2`]("=$14Q%5$4@1E)/32`G("X@)'1H
M:7,M/F-A8VAE7W1A8FQE.PH@("`@("`@('T*"B`@("`@("`@)')E<R`]("1T
M:&ES+3YD8BT^<75E<GDH)'%U97)Y*3L*("`@("`@("!I9B`H341".CII<T5R
M<F]R*"1R97,I*2!["B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R
M;W(H)TU$0CHZ<75E<GD@9F%I;&5D.B`G"B`@("`@("`@("`@("`@("`N("1T
M:&ES+3YD8BT^97)R;W)-97-S86=E*"1R97,I+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K(&EF
M(&$@9&%T87-E="!)1"]G<F]U<"!E>&ES=',N"B`@("`@*@H@("`@("H@0'!A
M<F%M("`@('-T<FEN9R`@9&%T87-E="!)1`H@("`@("H@0'!A<F%M("`@('-T
M<FEN9R`@8V%C:&4@9W)O=7`*("`@("`J($!R971U<FX@("!B;V]L96%N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&ED17AI<W1S*"1I9"P@)&=R;W5P*0H@("`@
M>PH@("`@("`@("1Q=65R>2`]("=314Q%0U0@:60@1E)/32`G("`N("1T:&ES
M+3YC86-H95]T86)L90H@("`@("`@("`@("`@("`@+B<@5TA%4D4@:60])R`@
M("`@("`N("1T:&ES+3YD8BT^9V5T5&5X=%9A;'5E*"1I9"D*("`@("`@("`@
M("`@("`@("XG($%.1"!C86-H96=R;W5P/2<@+B`D=&AI<RT^9&(M/F=E=%1E
M>'1686QU92@D9W)O=7`I.PH@("`@("`@(&5C:&\@)'%U97)Y.PH@("`@("`@
M("1R97,@/2`D=&AI<RT^9&(M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@:68@
M*$U$0CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@("`@("!R971U<FX@;F5W
M($-A8VAE7T5R<F]R*"=-1$(Z.G%U97)Y(&9A:6QE9#H@)PH@("`@("`@("`@
M("`@("`@("`@("X@)'1H:7,M/F1B+3YE<G)O<DUE<W-A9V4H)')E<RDL(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@("`@("1R;W<@/2`D
M=&AI<RT^9&(M/F9E=&-H26YT;R@D<F5S*3L*"B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1R;W<I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'87)B86=E(&-O;&QE8W1O<BX*("`@
M("`J"B`@("`@*B!`<&%R86T@("`@:6YT(&UA>&QI9F5T:6UE"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=A<F)A9V5#;VQL96-T:6]N*"1M87AL:69E=&EM92D*
M("`@('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"D["B`@("`@("`@
M)'%U97)Y(#T@)T1%3$5412!&4D]-("<@("`@("`@("X@)'1H:7,M/F-A8VAE
M7W1A8FQE"B`@("`@("`@("`@("`@("`N)R!72$5212`H97AP:7)E<R`\/2`G
M("X@=&EM92@I"B`@("`@("`@("`@("`@("`N)R!!3D0@97AP:7)E<R`^(#`I
M($]2(&-H86YG960@/#T@)RX@=&EM92@I("T@)&UA>&QI9F5T:6UE.PH*("`@
M("`@("`D<F5S(#T@)'1H:7,M/F1B+3YQ=65R>2@D<75E<GDI.PH*("`@("`@
M("`D<75E<GD@/2`G4T5,14-4('-U;2AL96YG=&@H8V%C:&5D871A*2D@87,@
M0V%C:&53:7IE($923TT@)PH@("`@("`@("`@("`@("`@+B`D=&AI<RT^8V%C
M:&5?=&%B;&4["@H@("`@("`@("1C86-H97-I>F4@/2`D=&AI<RT^9&(M/F=E
M=$]N92@D<75E<GDI.PH@("`@("`@(&EF("A-1$(Z.FES17)R;W(H)&-A8VAE
M<VEZ92DI('L*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G
M341".CIQ=65R>2!F86EL960Z("<*("`@("`@("`@("`@("`@("`@("X@)'1H
M:7,M/F1B+3YE<G)O<DUE<W-A9V4H)&-A8VAE<VEZ92DL(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@?0H@("`@("`@("\O:68@8V%C:&4@:7,@=&\@
M8FEG+@H@("`@("`@(&EF("@D8V%C:&5S:7IE(#X@)'1H:7,M/FAI9VAW871E
M<BD*("`@("`@("!["B`@("`@("`@("`@("\O9FEN9"!T:&4@;&]W=V%T97(@
M;6%R:RX*("`@("`@("`@("`@)'%U97)Y(#T@)U-%3$5#5"!L96YG=&@H8V%C
M:&5D871A*2!A<R!S:7IE+"!C:&%N9V5D($923TT@)PH@("`@("`@("`@("`@
M("`@("`@("X@)'1H:7,M/F-A8VAE7W1A8FQE("XG($]21$52($)9(&-H86YG
M960@1$530R<["@H@("`@("`@("`@("`D<F5S(#T@)'1H:7,M/F1B+3YQ=65R
M>2@D<75E<GDI.PH@("`@("`@("`@("!I9B`H341".CII<T5R<F]R*"1R97,I
M*2!["B`@("`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)TU$
M0CHZ<75E<GD@9F%I;&5D.B`G"B`@("`@("`@("`@("`@("`@("`@+B`D=&AI
M<RT^9&(M/F5R<F]R365S<V%G92@D<F5S*2P@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;G5M<F]W<R`]("1T:&ES
M+3YD8BT^;G5M4F]W<R@D<F5S*3L*("`@("`@("`@("`@)&ME97!?<VEZ92`]
M(#`["B`@("`@("`@("`@('=H:6QE("@D:V5E<%]S:7IE(#P@)'1H:7,M/FQO
M=W=A=&5R("8F("1N=6UR;W=S+2TI('L*("`@("`@("`@("`@("`@("1E;G1R
M>2`]("1T:&ES+3YD8BT^9F5T8VA);G1O*"1R97,L341"7T9%5$-(34]$15]!
M4U-/0RD["B`@("`@("`@("`@("`@("`D:V5E<%]S:7IE("L]("1E;G1R>5LG
M<VEZ92==.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+V1E;&5T92!A
M;&P@96YT<FEE<RP@=VAI8V@@=V5R92!C:&%N9V5D(&)E9F]R92!T:&4@(FQO
M=W=A=&5R(&UA<FLB"B`@("`@("`@("`@("1Q=65R>2`]("=$14Q%5$4@1E)/
M32`G("X@)'1H:7,M/F-A8VAE7W1A8FQE"B`@("`@("`@("`@("`@("`@("`@
M+B<@5TA%4D4@8VAA;F=E9#P])RXH)&5N=')Y6R=C:&%N9V5D)UT@/R`D96YT
M<GE;)V-H86YG960G72`Z(#`I.PH*("`@("`@("`@("`@)')E<R`]("1T:&ES
M+3YD8BT^<75E<GDH)'%U97)Y*3L*("`@("`@("`@("`@:68@*$U$0CHZ:7-%
M<G)O<B@D<F5S*2D@>PH@("`@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE
M7T5R<F]R*"=-1$(Z.G%U97)Y(&9A:6QE9#H@)PH@("`@("`@("`@("`@("`@
M("`@("X@)'1H:7,M/F1B+3YE<G)O<DUE<W-A9V4H)')E<RDL(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@I]
M"C\^````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+T-A8VAE+T-O;G1A:6YE<B]M<V5S<VEO;BYP:'``````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#$V-C,Q`#$P-3$U-#,S-S,T`#`R-#$Q,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!014%2(#HZ($-A8VAE("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T
M('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO
M+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@
M9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@
M870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!0
M2%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@
M:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@
M;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E
M(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H
M;W)S.B!5;&8@5V5N9&5L(#QU;&8N=V5N9&5L0'!H<&1O8RYD93X@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+PHO+R`D260Z(&US97-S:6]N+G!H<"QV(#$N-"`R,#`S+S`Q
M+S`T(#$Q.C4T.C0V(&UJ($5X<"`D"@IR97%U:7)E7V]N8V4@)T-A8VAE+T-O
M;G1A:6YE<BYP:'`G.PH*+RHJ"BH@4W1O<F5S(&-A8VAE(&-O;G1E;G1S(&EN
M(&US97-S:6]N<RX**@HJ(%=!4DY)3D<Z(&5X<&5R:6UE;G1A;"P@=6YT97-T
M960**@HJ($!A=71H;W(@("!5;&8@5V5N9&5L("`\=6QF+G=E;F1E;$!P:'!D
M;V,N9&4^"BH@0'9E<G-I;VX@("1)9#H@;7-E<W-I;VXN<&AP+'8@,2XT(#(P
M,#,O,#$O,#0@,3$Z-30Z-#8@;6H@17AP("0**B\*8VQA<W,@0V%C:&5?0V]N
M=&%I;F5R7VUS97-S:6]N(&5X=&5N9',@0V%C:&5?0V]N=&%I;F5R('L*"@H@
M("`@+RHJ"B`@("`J($QE;F=T:"!O9B!T:&4@0V%C:&4M261E;G1I9FEE<@H@
M("`@*@H@("`@*B!.;W1E('1H870@=&AE(%!%05(M0V%C:&4@<')E9FEX97,@
M=&AE($E$('=I=&@@86X@;60U*"D@=F%L=64*("`@("H@;V8@=&AE(&-A8VAE
M+6=R;W5P+B!!(&=O;V0@=F%L=64@9F]R('1H92!I9%]L96YG=&@*("`@("H@
M9&5P96YD<R!O;B!T:&4@;6%X:6UU;2!N=6UB97(@;V8@96YT<FEE<R!P97(@
M8V%C:&4@9W)O=7`N"B`@("`J"B`@("`J($!V87(@(&EN=`H@("`@*B\*("`@
M('9A<B`D:61?;&5N9W1H(#T@,S(["B`@("`*("`@(`H@("`@+RHJ"B`@("`J
M(%5S92!M<V5S<VEO;E]U;FEQ('1O(&-R96%T92!A('5N:7%U92!3240N"B`@
M("`J(`H@("`@*B!`=F%R("!B;V]L96%N"B`@("`J+PH@("`@=F%R("1U;FEQ
M(#T@=')U93L*("`@(`H@("`@"B`@("`O*BH*("`@("H@17-T86)L:7-H(&$@
M8V]N;F5C=&EO;B!T;R!A(&US97-S:6]N('-E<G9E<C\*("`@("H*("`@("H@
M0'9A<B`@8F]O;&5A;@H@("`@*B\*("`@('9A<B`D8V]N;F5C="`]('1R=64[
M"B`@(`H@("`*("`@("\J*@H@("`@*B!M<V5S<VEO;B!H;W-T"B`@("`J"B`@
M("`J($!V87(@('-T<FEN9PH@("`@*B\@(`H@("`@=F%R("1H;W-T(#T@3E5,
M3#L*("`@(`H@("`*("`@("\J*@H@("`@*B!M<V5S<VEO;B!P;W)T"B`@("`J
M"B`@("`J($!V87(@('-T<FEN9PH@("`@*B\*("`@('9A<B`D<&]R="`]($Y5
M3$P["B`@("`*("`@(`H@("`@+RHJ"B`@("`J(&UE<V5S<VEO;B!S97)V97(@
M8V]N;F5C=&EO;@H@("`@*@H@("`@*B!`=F%R("!R97-O=7)C92!M<V5S<VEO
M;@H@("`@*B\*("`@('9A<B`D;7,@/2!.54Q,.PH*("`@(`H@("`@9G5N8W1I
M;VX@0V%C:&5?0V]N=&%I;F5R7VUS97-S:6]N*"1O<'1I;VYS(#T@)R<I('L*
M("`@("`@("!I9B`H:7-?87)R87DH)&]P=&EO;G,I*0H@("`@("`@("`@("`D
M=&AI<RT^<V5T3W!T:6]N<R@D;W!T:6]N<RP@87)R87E?;65R9V4H)'1H:7,M
M/F%L;&]W961?;W!T:6]N<RP@87)R87DH)VED7VQE;F=H="<L("=U;FEQ)RP@
M)VAO<W0G+"`G<&]R="<L("=C;VYN96-T)RDI*3L*"B`@("`@("`@:68@*"1C
M;VYN96-T*2![("`@("`@("`@("`@"B`@("`@("`@("`@(&EF("A.54Q,(#T]
M("1T:&ES+3YH;W-T*0H@("`@("`@("`@("`@("`@;F5W($-A8VAE7T5R<F]R
M*"=.;R!H;W-T('-P96-I9FEE9"XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@("`@("!I9B`H3E5,3"`]/2`D=&AI<RT^<&]R="D*("`@("`@("`@
M("`@("`@(&YE=R!#86-H95]%<G)O<B@G3F\@<&]R="!S<&5C:69I960N)RP@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`*("`@("`@("`@("`@:68@
M*"$H)'1H:7,M/FUS(#T@;7-E<W-I;VY?8V]N;F5C="@D=&AI<RT^:&]S="P@
M)'1H:7,M/G!O<G0I*2D*("`@("`@("`@("`@("`@(&YE=R!#86-H95]%<G)O
M<B@G0V%N(&YO="!C;VYN96-T('1O('1H92!S979E<B!U<VEN9R!H;W-T("(G
M("X@)'1H:7,M/FAO<W0@+B`G(B!O;B!P;W)T("(G("X@)'1H:7,M/G!O<G0@
M+B`G(B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@("`@
M(`H@("`@?2`O+R!E;F0@9G5N8R!C;VYT<G5C=&]R"@H@("`@9G5N8W1I;VX@
M9F5T8V@H)&ED+"`D9W)O=7`I('L*("`@(`H@("`@("`@("1I9"`]('-T<G1O
M=7!P97(H;60U*"1G<F]U<"DI("X@)&ED.PH@("`@("`@("1G<F]U<"`](&US
M97-S:6]N7V=E="@D:60L("=?<&5A<E]C86-H95]D871A)RP@3E5,3"D["B`@
M("`@("`@"B`@("`@("`@:68@*$Y53$P@/3T@)&1A=&$I"B`@("`@("`@("`@
M(')E='5R;B!A<G)A>2A.54Q,+"!.54Q,+"!.54Q,*3L*("`@("`@("`*("`@
M("`@("!R971U<FX@87)R87DH)&1A=&%;)V5X<&ER97,G72P@)&1A=&%;)V-A
M8VAE9&%T82==+"`D9&%T85LG=7-E<F1A=&$G72D["B`@("!]("\O(&5N9"!F
M=6YC(&9E=&-H"@H@("`@+RHJ"B`@("`J(%-T;W)E<R!A(&1A=&%S970N"B`@
M("`J"B`@("`J(%=!4DY)3D<Z($EF('EO=2!S=7!P;'D@=7-E<F1A=&$@:70@
M;75S="!N;W0@8V]N=&%I;B!A;GD@;&EN96)R96%K<RP*("`@("H@;W1H97)W
M:7-E(&ET('=I;&P@8G)E86L@=&AE(&9I;&5S=')U8W1U<F4N"B`@("`J+PH@
M("`@9G5N8W1I;VX@<V%V92@D:60L("1C86-H961A=&$L("1E>'!I<F5S+"`D
M9W)O=7`L("1U<V5R9&%T82D@>PH@("`@("`@("1T:&ES+3YF;'5S:%!R96QO
M860H)&ED+"`D9W)O=7`I.PH@("`@("`@(`H@("`@("`@("1C86-H961A=&$@
M("`@("`]("1T:&ES+3YE;F-O9&4H)&-A8VAE9&%T82D["B`@("`@("`@)&5X
M<&ER97-?86)S("`@(#T@)'1H:7,M/F=E=$5X<&ER97-!8G-O;'5T92@D97AP
M:7)E<RD["@H@("`@("`@("1S:7IE(#T@,2`K('-T<FQE;B@D8V%C:&5D871A
M*2`K('-T<FQE;B@D97AP:7)E<U]A8G,I("L@<W1R;&5N*"1U<V5R9&%T82D@
M*R!S=')L96XH)&=R;W5P*3L*("`@("`@("`D<VEZ92`K/2!S=')L96XH)'-I
M>F4I.PH@("`@("`@(`H@("`@("`@("1D871A(#T@87)R87DH"B`@("`@("`@
M("`@("`@("`@("`@)V-A8VAE9&%T82<@/3X@)&-A8VAE9&%T82P@"B`@("`@
M("`@("`@("`@("`@("`@)V5X<&ER97,G("`@/3X@)&5X<&ER97-?86)S+`H@
M("`@("`@("`@("`@("`@("`@("=U<V5R9&%T82<@(#T^("1U<V5R9&%T80H@
M("`@("`@("`@("`@("`@("`I.PH@("`@("`@("1I9"`]('-T<G1O=7!P97(H
M;60U*"1G<F]U<"DI("X@)&ED.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@"B`@("`@("`@;7-E<W-I;VY?;&]C:R@D:60I.PH@("`@("`@(`H@("`@
M("`@(&EF("@A;7-E<W-I;VY?<V5T*"1I9"P@)U]P96%R7V-A8VAE)RP@=')U
M92DI('L*("`@("`@("`@("`@;7-E<W-I;VY?=6YL;V-K*"1I9"D["B`@("`@
M("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H(D-A;B=T('=R:71E(&-A
M8VAE(&1A=&$N(BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@
M("`@("`@"B`@("`@("`@:68@*"%M<V5S<VEO;E]S970H)&ED+"`G7W!E87)?
M8V%C:&5?9&%T82<L("1D871A*2D@>PH@("`@("`@("`@("!M<V5S<VEO;E]U
M;FQO8VLH)&ED*3L*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O
M<B@B0V%N)W0@=W)I=&4@8V%C:&4@9&%T82XB+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@('T*("`@("`@("`*("`@("`@("!I9B`H(6US97-S:6]N
M7W-E="@D:60L("=?<&5A<E]C86-H95]G<F]U<"<L("1G<F]U<"DI('L*("`@
M("`@("`@("`@;7-E<W-I;VY?=6YL;V-K*"1I9"D["B`@("`@("`@("`@(')E
M='5R;B!N97<@0V%C:&5?17)R;W(H(D-A;B=T('=R:71E(&-A8VAE(&1A=&$N
M(BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("`@("`@"B`@
M("`@("`@:68@*"%M<V5S<VEO;E]S970H)&ED+"`G7W!E87)?8V%C:&5?<VEZ
M92<L("1S:7IE*2D@>PH@("`@("`@("`@("!M<V5S<VEO;E]U;FQO8VLH)&ED
M*3L*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@B0V%N)W0@
M=W)I=&4@8V%C:&4@9&%T82XB+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@('T*("`@("`@("`*("`@("`@("`O+R!L970@;7-E<W-I;VX@9&\@<V]M
M92!'0R!A<R!W96QL"B`@("`@("`@+R\@;F]T92!T:&%T(&US97-S:6]N('=O
M<FMS(&1I9F9E<F5N="!F<F]M('1H92!014%2($-A8VAE+@H@("`@("`@("\O
M(&US97-S:6]N(&1E;&5T97,@86X@96YT<GD@:68@:70@:&%S(&YO="!B965N
M('5S960@9F]R(&XM<V5C;VYD<RX*("`@("`@("`O+R!014%2($-A8VAE(&1E
M;&5T97,@869T97(@;BUS96-O;F1S+@H@("`@("`@(&EF("@P("$]("1E>'!I
M<F5S*0H@("`@("`@("`@("!M<V5S<VEO;E]T:6UE;W5T*"1I9"P@)&5X<&ER
M97,I.PH@("`@("`@("`@("`*("`@("`@("!M<V5S<VEO;E]U;FQO8VLH)&ED
M*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]("\O(&5N9"!F=6YC('-A
M=F4*"B`@("!F=6YC=&EO;B!R96UO=F4H)&ED+"`D9W)O=7`I('L*("`@("`@
M("`D=&AI<RT^9FQU<VA0<F5L;V%D*"1I9"P@)&=R;W5P*3L*("`@(`H@("`@
M("`@(')E='5R;B!M<V5S<VEO;E]D97-T<F]Y*'-T<G1O=7!P97(H;60U*"1G
M<F]U<"DI("X@)&ED*3L*("`@('T@+R\@96YD(&9U;F,@<F5M;W9E"@H@("`@
M9G5N8W1I;VX@9FQU<V@H)&=R;W5P*2!["B`@("`@("`@)'1H:7,M/F9L=7-H
M4')E;&]A9"@I.PH@("`@("`*("`@("`@("`D<V5S<VEO;G,@/2!M<V5S<VEO
M;E]F:6YD*"=?<&5A<E]C86-H95]G<F]U<"<L("1G<F]U<"D["B`@("`@("`@
M:68@*&5M<'1Y*"1S97-S:6]N<RDI"B`@("`@("`@("`@(')E='5R;B`P.PH@
M("`@("`@(`H@("`@("`@(&9O<F5A8V@@*"1S97-S:6]N<R!A<R`D:R`]/B`D
M:60I"B`@("`@("`@("`@(&UE<W-S:6]N7V1E<W1R;WDH)&ED*3L*"B`@("`@
M("`@<F5T=7)N(&-O=6YT*"1S97-S:6]N<RD["B`@("!]("\O(&5N9"!F=6YC
M(&9L=7-H"@H@("`@9G5N8W1I;VX@:61%>&ES=',H)&ED+"`D9W)O=7`I('L*
M("`@("`@("`*("`@("`@("!R971U<FX@*$Y53$P@/3T@;7-E<W-I;VY?9V5T
M*'-T<G1O=7!P97(H;60U*"1G<F]U<"DI("X@)&ED+"`G7W!E87)?8V%C:&5?
M9W)O=7`G+"!.54Q,*2D@/R!F86QS92`Z('1R=64["B`@("!]("\O(&5N9"!F
M=6YC(&ED17AI<W1S"@H@("`@+RHJ"B`@("`J($1E;&5T97,@86QL(&5X<&ER
M960@9FEL97,N"B`@("`J"B`@("`J($YO=&4Z(&=A<F)A9V4@8V]L;&5C=&EO
M;B!S:&]U;&0@8V%U<V4@;&]T)W,@;V8@;F5T=V]R:R!T<F%F9FEC+@H@("`@
M*@H@("`@*B!`<&%R86T@("`@:6YT96=E<B!-87AI;75M(&QI9F5T:6UE(&EN
M('-E8V]N9',@;V8@86X@;F\@;&]N9V5R('5S960O=&]U8VAE9"!E;G1R>0H@
M("`@*B!`=&AR;W=S("`@0V%C:&5?17)R;W(*("`@("HO"B`@("!F=6YC=&EO
M;B!G87)B86=E0V]L;&5C=&EO;B@D;6%X;&EF971I;64I('L*("`@("`@("`D
M=&AI<RT^9FQU<VA0<F5L;V%D*"D["B`@("`@("`@"B`@("`@("`@)'-E<W-I
M;VYS(#T@;7-E<W-I;VY?9FEN9"@G7W!E87)?8V%C:&4G+"!T<G5E*3L*("`@
M("`@("!I9B`H96UP='DH)'-E<W-I;VYS*2D*("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@"B`@("`@("`@)'1O=&%L(#T@,#L*("`@("`@("`D
M96YT<FEE<R`](&%R<F%Y*"D["B`@("`@("`@"B`@("`@("`@9F]R96%C:"`H
M)'-E<W-I;VYS(&%S("1K(#T^("1I9"D@>PH@("`@("`@("`@("`D9&%T82`]
M(&US97-S:6]N7V=E="@D:60L("=?<&5A<E]C86-H95]D871A)RP@3E5,3"D[
M"B`@("`@("`@("`@(&EF("A.54Q,(#T]("1D871A*0H@("`@("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("`*("`@("`@("`@("`@:68@
M*"1D871A6R=E>'!I<F5S)UT@/#T@=&EM92@I*2!["B`@("`@("`@("`@("`@
M("!M<V5S<VEO;E]D97-T<F]Y*"1I9"D["B`@("`@("`@("`@("`@("!C;VYT
M:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`*("`@("`@("`@("`@
M)'-I>F4@/2!M<V5S<VEO;E]G970H)&ED+"`G7W!E87)?8V%C:&5?<VEZ92<L
M($Y53$PI.PH@("`@("`@("`@("`D=&]T86P@*ST@)'-I>F4["B`@("`@("`@
M("`@("1E;G1R:65S6R1D871A6R=E>'!I<F5S)UU=(#T@87)R87DH)&ED+"`D
M<VEZ92D["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@(&EF("@D=&]T86P@
M/B`D=&AI<RT^:&EG:'=A=&5R*2!["B`@("`@("`@("`@(`H@("`@("`@("`@
M("!K<G-O<G0H)&5N=')I97,I.PH@("`@("`@("`@("!R97-E="@D96YT<FEE
M<RD["B`@("`@("`@("`@(`H@("`@("`@("`@("!W:&EL92`H)'1O=&%L(#X@
M)'1H:7,M/FQO=W=A=&5R("8F(&QI<W0H)&5X<&ER97,L("1E;G1R>2D@/2!E
M86-H*"1E;G1R:65S*2D@>PH@("`@("`@("`@("`@("`@;7-E<W-I;VY?9&5S
M=')O>2@D96YT<GE;,%TI.PH@("`@("`@("`@("`@("`@)'1O=&%L("T]("1E
M;G1R>5LQ73L*("`@("`@("`@("`@?0H@("`@("`@("`@("`*("`@("`@("!]
M"B`@("`@("`@"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]("\O(&5N9"!F
M=6YC(&=A<F)A9V5#;VQL96-T:6]N"B`@("`*?2`O+R!E;F0@8VQA<W,@9FEL
M90H_/@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O0V%C:&4O0V]N=&%I;F5R+W!H<&QI8BYP:'``````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,C(T-C(`,3`U,34T,S,W,S0`,#(S-3(V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!%05(@.CH@0V%C:&4@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE
M8W0@=&\@=F5R<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\
M"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H
M92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L
M92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE
M(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I
M;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@
M82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@
M=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U
M=&AO<G,Z(%5L9B!796YD96P@/'5L9BYW96YD96Q`<&AP9&]C+F1E/B`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("!396)A<W1I
M86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO
M+R`D260Z('!H<&QI8BYP:'`L=B`Q+C,@,C`P,R\P,2\P-"`Q,3HU-#HT-B!M
M:B!%>'`@)`H*<F5Q=6ER95]O;F-E("=#86-H92]#;VYT86EN97(N<&AP)SL*
M"B\J*@HJ(%-T;W)E<R!C86-H92!D871A(&EN=&\@82!D871A8F%S92!T86)L
M92!U<VEN9R!02%!,:6)S($1"(&%B<W1R86-T:6]N+@HJ"BH@5T%23DE.1SH@
M3W1H97(@<WES=&5M<R!M:6=H="!O<B!M:6=H="!N;W0@<W5P<&]R="!C97)T
M86EN(&1A=&%T>7!E<R!O9B`**B!T:&4@=&%B;&5S('-H;W=N+B!!<R!F87(@
M87,@22!K;F]W('1H97)E)W,@;F\@;&%R9V4@8FEN87)Y(`HJ('1Y<&4@:6X@
M4U%,+3DR(&]R(%-13"TY.2X@4&]S=&=R97,@<V5E;7,@=&\@;&%C:R!A;GD@
M"BH@0DQ/0B!O<B!415A4('1Y<&4L(&9O<B!-4RU344P@>6]U(&-O=6QD('5S
M92!)34%'12P@9&]N)W0@:VYO=R`**B!A8F]U="!O=&AE<B!D871A8F%S97,N
M(%!L96%S92!A9&0@<W5G97-T:6]N<R!F;W(@;W1H97(@9&%T86)A<V5S('1O
M(`HJ('1H92!I;FQI;F4@9&]C<RX**@HJ(%1H92!F:65L9"`G8VAA;F=E9"<@
M:7,@=7-E9"!B>2!T:&4@9V%R8F%G92!C;VQL96-T:6]N+B!$97!E;F1I;F<@
M;VX@"BH@>6]U<B!D871A8F%S97-Y<W1E;2!Y;W4@;6EG:'0@:&%V92!T;R!S
M=6)C;&%S<R!F971C:"@I(&%N9"!G87)B86=E0V]L;&5C=&EO;B@I+@HJ"BH@
M1F]R(%]->5-13%\@>6]U(&YE960@=&AI<R!$0B!T86)L93H**@HJ($-214%4
M12!404),12!C86-H92`H"BH@("!I9"`@("`@("`@("!#2$%2*#,R*2!.3U0@
M3E5,3"!$149!54Q4("<G+`HJ("`@8V%C:&5G<F]U<"`@5D%20TA!4B@Q,C<I
M($Y/5"!.54Q,($1%1D%53%0@)R<L"BH@("!C86-H961A=&$@("!"3$]"($Y/
M5"!.54Q,($1%1D%53%0@)R<L"BH@("!U<V5R9&%T82`@("!605)#2$%2*#(U
M-2D@3D]4($Y53$P@1$5&055,("<G+`HJ("`@97AP:7)E<R`@("`@24Y4*#DI
M($Y/5"!.54Q,($1%1D%53%0@,"P**B`@"BH@("!C:&%N9V5D("`@("!424U%
M4U1!35`H,30I($Y/5"!.54Q,+`HJ("`**B`@($E.1$58("AE>'!I<F5S*2P*
M*B`@(%!224U!4ED@2T59("AI9"P@8V%C:&5G<F]U<"D**B`I"BH**B`**B!`
M875T:&]R("`@56QF(%=E;F1E;"`@/'5L9BYW96YD96Q`<&AP9&]C+F1E/BP@
M4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^
M"BH@0'9E<G-I;VX@("1)9#H@<&AP;&EB+G!H<"QV(#$N,R`R,#`S+S`Q+S`T
M(#$Q.C4T.C0V(&UJ($5X<"`D"BH@0'!A8VMA9V4@($-A8VAE"BH@0'-E92`@
M("`@('-A=F4H*0HJ+PIC;&%S<R!#86-H95]#;VYT86EN97)?<&AP;&EB(&5X
M=&5N9',@0V%C:&5?0V]N=&%I;F5R('L*("`*("`@("\J*@H@("`@*B!.86UE
M(&]F('1H92!$0B!T86)L92!T;R!S=&]R92!C86-H:6YG(&1A=&$*("`@("H@
M"B`@("`J($!S964@($-A8VAE7T-O;G1A:6YE<E]F:6QE.CHD9FEL96YA;65?
M<')E9FEX"B`@("`J+R`@"B`@("!V87(@)&-A8VAE7W1A8FQE(#T@)V-A8VAE
M)SL*"B`@("`O*BH*("`@("H@4$A03&EB(&]B:F5C=`H@("`@*B`*("`@("H@
M0'9A<B`@;V)J96-T(%!%05)?1$(*("`@("HO"B`@("!V87(@)&1B.PH*("`@
M("\J*@H@("`@*B!.86UE(&]F('1H92!02%!,:6(@1$(@8VQA<W,@=&\@=7-E
M"B`@("`J(`H@("`@*B!`=F%R("!S=')I;F<@(`H@("`@*B!`<V5E("`D9&)?
M<&%T:"P@)&QO8V%L7W!A=&@*("`@("HO"B`@("!V87(@)&1B7V-L87-S(#T@
M)R<["@H@("`@+RHJ"B`@("`J($9I;&5N86UE(&]F('EO=7(@;&]C86PN:6YC
M"B`@("`J(`H@("`@*B!)9B!E;7!T>2P@)VQO8V%L+FEN8R<@:7,@87-S=6UE
M9"X*("`@("H*("`@("H@0'9A<B`@("`@("!S=')I;F<*("`@("HO"B`@("!V
M87(@)&QO8V%L7V9I;&4@/2`G)SL*"B`@("`O*BH*("`@("H@26YC;'5D92!P
M871H(&9O<B!Y;W4@;&]C86PN:6YC"B`@("`J"B`@("`J($A)3E0Z($EF('EO
M=7(G<F4@;F]T('5S:6YG(%!(4$QI8B=S('!R97!E;F0N<&AP('EO=2!M=7-T
M(`H@("`@*B!T86ME(&-A<F4@=&AA="!A;&P@8VQA<W-E<R`H9FEL97,I(')E
M9F5R96YC97,@8GD@>6]U(`H@("`@*B!L;V-A;"YI;F,@87)E(&EN8VQU9&5D
M(&%U=&]M871I8V%L;'DN(%-O('EO=2!M:6=H="`*("`@("H@=V%N="!T;R!W
M<FET92!A(&YE=R!L;V-A;#(N:6YC('1H870@;VYL>2!R969E<G)S('1O(`H@
M("`@*B!T:&4@9&%T86)A<V4@8VQA<W,@*&9I;&4I('EO=2=R92!U<VEN9R!A
M;F0@:6YC;'5D97,@86QL(')E<75I<F5D(&9I;&5S+@H@("`@*@H@("`@*B!`
M=F%R("!S=')I;F<@('!A=&@@=&\@>6]U<B!L;V-A;"YI;F,@+2!M86ME('-U
M<F4@=&\@861D(&$@=')A:6QI;F<@<VQA<V@*("`@("H@0'-E92`@)&QO8V%L
M7V9I;&4*("`@("HO"B`@("!V87(@)&QO8V%L7W!A=&@@/2`G)SL*"B`@("`O
M*BH*("`@("H@0W)E871E<R!A;B!I;G-T86YC92!O9B!A('!H<&QI8B!D8B!C
M;&%S<R!T;R!U<V4@:70@9F]R('-T;W)A9V4N"B`@("`J"B`@("`J($!P87)A
M;2`@("!M:7AE9"`@($EF(&5M<'1Y('1H92!O8FIE8W0@=')I97,@=&\@=7-E
M9"!T:&4@"B`@("`J("`@("`@("`@("`@("`@("`@('!R96-O;F9I9W5R960@
M8VQA<W,@=F%R:6%B;&5S+B!)9B!G:79E;B!I="`*("`@("H@("`@("`@("`@
M("`@("`@("`@;75S="!B92!A;B!A<G)A>2!W:71H.@H@("`@*B`@("`@("`@
M("`@("`@("`@("`@(&1B7V-L87-S(#T^(&YA;64@;V8@=&AE($1"(&-L87-S
M('1O('5S90H@("`@*B`@("`@("`@("`@("`@("`@("!O<'1I;VYA;#H*("`@
M("H@("`@("`@("`@("`@("`@("`@("!D8E]F:6QE(#T^(&9I;&5N86UE(&]F
M('1H92!$0B!C;&%S<PH@("`@*B`@("`@("`@("`@("`@("`@("`@(&1B7W!A
M=&@@/3X@<&%T:"!T;R!T:&4@1$(@8VQA<W,*("`@("H@("`@("`@("`@("`@
M("`@("`@("!L;V-A;%]F:6QE(#T^(&MI;F0@;V8@;&]C86PN:6YC"B`@("`J
M("`@("`@("`@("`@("`@("`@("`@;&]C86Q?<&%T:R`]/B!P871H('1O('1H
M92!L;V-A;"YI;F,*("`@("H@("`@("`@("`@("`@("`@("`@<V5E("1L;V-A
M;%]P871H(&9O<B!S;VUE(&AI;G1S+G,*("`@("H@0'-E92`@)&QO8V%L7W!A
M=&@*("`@("HO"B`@("!F=6YC=&EO;B!#86-H95]#;VYT86EN97)?<&AP;&EB
M*"1O<'1I;VYS(#T@)R<I('L*("`@("`@("!I9B`H:7-?87)R87DH)&]P=&EO
M;G,I*0H@("`@("`@("`@("`D=&AI<RT^<V5T3W!T:6]N<R@D;W!T:6]N<RP@
M(&%R<F%Y7VUE<F=E*"1T:&ES+3YA;&QO=V5D7V]P=&EO;G,L(&%R<F%Y*"=D
M8E]C;&%S<R<L("=D8E]F:6QE)RP@)V1B7W!A=&@G+"`G;&]C86Q?9FEL92<L
M("=L;V-A;%]P871H)RDI*3L*"B`@("`@("`@:68@*"$D=&AI<RT^9&)?8VQA
M<W,I"B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)TYO(&1A
M=&%B87-E(&-L87-S('-P96-I9FEE9"XG+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PH*("`@("`@("`O+R!I;F-L=61E('1H92!R97%U:7)E9"!F:6QE<PH@("`@
M("`@(&EF("@D=&AI<RT^9&)?9FEL92D*("`@("`@("`@("`@:6YC;'5D95]O
M;F-E*"1T:&ES+3YD8E]P871H("X@)'1H:7,M/F1B7V9I;&4I.PH*("`@("`@
M("!I9B`H)'1H:7,M/FQO8V%L7V9I;&4I"B`@("`@("`@("`@(&EN8VQU9&5?
M;VYC92@D=&AI<RT^;&]C86Q?<&%T:"`N("1T:&ES+3YL;V-A;%]F:6QE*3L*
M"B`@("`@("`@+R\@8W)E871E(&$@9&(@;V)J96-T(`H@("`@("`@("1T:&ES
M+3YD8B`](&YE=R`D=&AI<RT^9&)?8VQA<W,["B`@("!]("\O(&5N9"!C;VYS
M=')U8W1O<@H*("`@(&9U;F-T:6]N(&9E=&-H*"1I9"P@)&=R;W5P*2!["B`@
M("`@("`@)'%U97)Y(#T@<W!R:6YT9B@B4T5,14-4(&5X<&ER97,L(&-A8VAE
M9&%T82P@=7-E<F1A=&$@1E)/32`E<R!72$5212!I9"`]("<E<R<@04Y$(&-A
M8VAE9W)O=7`@/2`G)7,G(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YC86-H95]T86)L92P@"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D:60L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9W)O=7`*
M("`@("`@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@)'1H:7,M/F1B
M+3YQ=65R>2@D<75E<GDI.PH@("`@("`@(&EF("@A)'1H:7,M/F1B+3Y.97AT
M7U)E8V]R9"@I*0H@("`@("`@("`@("!R971U<FX@87)R87DH3E5,3"P@3E5,
M3"P@3E5,3"D["@H@("`@("`@("\O(&QA<W0@=7-E9"!R97%U:7)E9"!B>2!T
M:&4@9V%R8F%G92!C;VQL96-T:6]N("`@"B`@("`@("`@+R\@5T%23DE.1SH@
M;6EG:'0@8F4@37E344P@<W!E8VEF:6,@("`@("`@("`*("`@("`@("`D<75E
M<GD@/2!S<')I;G1F*")54$1!5$4@)7,@4T54(&-H86YG960@/2`H3D]7*"D@
M*R`P*2!72$5212!I9"`]("<E<R<@04Y$(&-A8VAE9W)O=7`@/2`G)7,G(BP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC86-H95]T86)L
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I9"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1G<F]U<`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("D["B`@("`@("`@)'1H:7,M/F1B+3YQ=65R>2@D<75E<GDI.PH@
M("`@("`@(')E='5R;B!A<G)A>2@D=&AI<RT^9&(M/F8H)V5X<&ER97,G*2P@
M)'1H:7,M/F1E8V]D92@D=&AI<RT^9&(M/F8H)V-A8VAE9&%T82<I*2P@)'1H
M:7,M/F1B+3YF*"=U<V5R9&%T82<I*3L*("`@('T@+R\@96YD(&9U;F,@9F5T
M8V@*"B`@("`O*BH*("`@("H@4W1O<F5S(&$@9&%T87-E="X*("`@("H@"B`@
M("`J(%=!4DY)3D<Z('=E('5S92!T:&4@4U%,(&-O;6UA;F0@4D503$%#12!)
M3E1/('1H:7,@;6EG:'0@8F4@"B`@("`J($UY4U%,('-P96-I9FEC+B!!<R!-
M>5-13"!I<R!V97)Y('!O<'5L87(@=&AE(&UE=&AO9"!S:&]U;&0*("`@("H@
M=V]R:R!F:6YE(&9O<B`Y-24@;V8@>6]U+@H@("`@*B\*("`@(&9U;F-T:6]N
M('-A=F4H)&ED+"`D9&%T82P@)&5X<&ER97,L("1G<F]U<"D@>PH@("`@("`@
M("1T:&ES+3YF;'5S:%!R96QO860H)&ED+"`D9W)O=7`I.PH*("`@("`@("`D
M<75E<GD@/2!S<')I;G1F*")215!,04-%($E.5$\@)7,@*&-A8VAE9&%T82P@
M97AP:7)E<RP@:60L(&-A8VAE9W)O=7`I(%9!3%5%4R`H)R5S)RP@)60L("<E
M<R<L("<E<R<I(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YC86-H95]T86)L92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%D
M9'-L87-H97,H)'1H:7,M/F5N8V]D92@D9&%T82DI+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/F=E=$5X<&ER97-!8G-O;'5T92@D97AP
M:7)E<RD@+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&ED+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&=R;W5P"B`@("`@("`@("`@("`@
M("`@("`@("`@("`I.PH@("`@("`@("1T:&ES+3YD8BT^<75E<GDH)'%U97)Y
M*3L*"B`@("`@("`@<F5T=7)N("AB;V]L96%N*21T:&ES+3YD8BT^869F96-T
M961?<F]W<R@I.R`*("`@('T@+R\@96YD(&9U;F,@<V%V90H*("`@(&9U;F-T
M:6]N(')E;6]V92@D:60L("1G<F]U<"D@>PH@("`@("`@("1T:&ES+3YF;'5S
M:%!R96QO860H)&ED+"`D9W)O=7`I.PH@("`@("`@("1T:&ES+3YD8BT^<75E
M<GDH"B`@("`@("`@("`@("`@("`@("`@("`@('-P<FEN=&8H(D1%3$5412!&
M4D]-("5S(%=(15)%(&ED(#T@)R5S)R!!3D0@8V%C:&5G<F]U<"`]("<E<R<B
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-A8VAE7W1A
M8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&ED+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&=R;W5P"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@*0H@("`@("`@("`@("`@("`@("`@("D["@H@("`@("`@(')E
M='5R;B`H8F]O;&5A;BDD=&AI<RT^9&(M/F%F9F5C=&5D7W)O=W,H*3L*("`@
M('T@+R\@96YD(&9U;F,@<F5M;W9E"@H@("`@9G5N8W1I;VX@9FQU<V@H)&=R
M;W5P*2!["B`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A9"@I.PH*("`@("`@
M("!I9B`H)&=R;W5P*2!["B`@("`@("`@("`@("1T:&ES+3YD8BT^<75E<GDH
M<W!R:6YT9B@B1$5,151%($923TT@)7,@5TA%4D4@8V%C:&5G<F]U<"`]("<E
M<R<B+"`D=&AI<RT^8V%C:&5?=&%B;&4L("1G<F]U<"DI.R`@("`*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^9&(M/G%U97)Y*'-P<FEN
M=&8H(D1%3$5412!&4D]-("5S(BP@)'1H:7,M/F-A8VAE7W1A8FQE*2D[("`@
M(`H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3YD8BT^869F96-T
M961?<F]W<R@I.PH@("`@?2`O+R!E;F0@9G5N8R!F;'5S:`H*("`@(&9U;F-T
M:6]N(&ED17AI<W1S*"1I9"P@)&=R;W5P*2!["B`@("`@("`@)'1H:7,M/F1B
M+3YQ=65R>2@*("`@("`@("`@("`@("`@("`@("`@("`@<W!R:6YT9B@B4T5,
M14-4(&ED($923TT@)7,@5TA%4D4@240@/2`G)7,G($%.1"!C86-H96=R;W5P
M(#T@)R5S)R(L(`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/F-A8VAE7W1A8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&ED
M+"`*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1G<F]U<`H@("`@("`@
M("`@("`@("`@("`@("`@("`I("`@"B`@("`@("`@("`@("`@("`@("`@*3L*
M"B`@("`@("`@<F5T=7)N("AB;V]L96%N*21T:&ES+3YD8BT^;F8H*3L@("`@
M("`@("`@("`@("`@("`@("`@("`@"B`@("!]("\O(&5N9"!F=6YC(&ES17AI
M<W1S"@H@("`@9G5N8W1I;VX@9V%R8F%G94-O;&QE8W1I;VXH)&UA>&QI9F5T
M:6UE*2!["B`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A9"@I.PH*("`@("`@
M("`D=&AI<RT^9&(M/G%U97)Y*"`*("`@("`@("`@("`@("`@("`@("`@("`@
M<W!R:6YT9B@B1$5,151%($923TT@)7,@5TA%4D4@*&5X<&ER97,@/#T@)60@
M04Y$(&5X<&ER97,@/B`P*2!/4B!C:&%N9V5D(#P]("A.3U<H*2`M("5D*2(L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V%C:&5?=&%B
M;&4L(`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&EM92@I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&UA>&QI9F5T:6UE"B`@("`@("`@
M("`@("`@("`@("`@("`@("D*("`@("`@("`@("`@("`@("`@("`I.PH*("`@
M("`@("`O+V-H96-K(&9O<B!T;W1A;"!S:7IE(&]F(&-A8VAE"B`@("`@("`@
M)'%U97)Y(#T@<W!R:6YT9B@G<V5L96-T('-U;2AL96YG=&@H8V%C:&5D871A
M*2D@87,@0V%C:&53:7IE(&9R;VT@)7,G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/F-A8VAE7W1A8FQE"B`@("`@("`@("`@("`@("`@("`@
M("`@*3L*"B`@("`@("`@)'1H:7,M/F1B+3YQ=65R>2@D<75E<GDI.PH@("`@
M("`@("1T:&ES+3YD8BT^3F5X=%]296-O<F0H*3L*("`@("`@("`D8V%C:&5S
M:7IE(#T@)'1H:7,M/F1B+3YF*"=#86-H95-I>F4G*3L*("`@("`@("`O+VEF
M(&-A8VAE(&ES('1O(&)I9RX*("`@("`@("!I9B`H)&-A8VAE<VEZ92`^("1T
M:&ES+3YH:6=H=V%T97(I"B`@("`@("`@>PH@("`@("`@("`@("`O+V9I;F0@
M=&AE(&QO=W=A=&5R(&UA<FLN"B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN
M=&8H)W-E;&5C="!L96YG=&@H8V%C:&5D871A*2!A<R!S:7IE+"!C:&%N9V5D
M(&9R;VT@)7,@;W)D97(@8GD@8VAA;F=E9"!$15-#)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC86-H95]T86)L90H@
M("`@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@("1T:&ES+3YD
M8BT^<75E<GDH)'%U97)Y*3L*"B`@("`@("`@("`@("1K965P7W-I>F4],#L*
M("`@("`@("`@("`@=VAI;&4@*"1K965P7W-I>F4@/"`D=&AI<RT^;&]W=V%T
M97(@)B8@)'1H:7,M/F1B+3Y.97AT7U)E8V]R9"@I("D*("`@("`@("`@("`@
M>PH@("`@("`@("`@("`@("`@)&ME97!?<VEZ92`K/2`D=&AI<RT^9&(M/F8H
M)W-I>F4G*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`O+V1E;&5T92!A
M;&P@96YT<FEE<RP@=VAI8V@@=V5R92!C:&%N9V5D(&)E9F]R92!T:&4@(FQO
M=W=W871E<B!M87)K(@H@("`@("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=D
M96QE=&4@9G)O;2`E<R!W:&5R92!C:&%N9V5D(#P]("<N)'1H:7,M/F1B+3YF
M*"=C:&%N9V5D)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^8V%C:&5?=&%B;&4*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`I.PH*("`@("`@("`@("`@)'1H:7,M/F1B+3YQ=65R
M>2@D<75E<GDI.PH@("`@("`@('T*("`@('T@+R\@96YD(&9U;F,@9V%R8F%G
M94-O;&QE8W1I;VX*?0H_/@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-A8VAE+T-O;G1A:6YE<B]S
M:&TN<&AP````````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(Q,3,U`#$P
M-3$U-#,S-S,T`#`R,S`S,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!014%2(#HZ($-A8VAE("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY
M-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F
M('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE
M9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@
M:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E
M('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\
M"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O
M<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!5;&8@5V5N9&5L(#QU
M;&8N=V5N9&5L0'!H<&1O8RYD93X@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@("`@("`@("`@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A
M<W1I86XM8F5R9VUA;FXN9&4^("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!S:&TN<&AP+'8@,2XS
M(#(P,#,O,#$O,#0@,3$Z-30Z-#8@;6H@17AP("0*"G)E<75I<F5?;VYC92`G
M0V%C:&4O0V]N=&%I;F5R+G!H<"<["@HO*BH**B!3=&]R97,@8V%C:&4@9&%T
M82!I;G1O('-H87)E9"!M96UO<GDN"BH**B!796QL+"!T:&ES(&ES(&YO="!A
M('9E<GD@969F:6-I96YT(&EM<&QE;65N=&%T:6]N+B!);F1E960@:70G<R!M
M=6-H(`HJ('-L;W=E<B!T:&%N('1H92!F:6QE(&-O;G1A:6YE<B!A<R!F87(@
M87,@;7D@=&5S=',@<VAO=V5D+B!&:6QE<R!A<F4@"BH@8V%C:&5D(&)Y(&UO
M<W0@;W!E<F%T:6YG('-Y<W1E;7,@86YD(&ET('=I;&P@8F4@:&%R9"!T;R!W
M<FET92!A(&9A<W1E<B`**B!C86-H:6YG(&%L9V]R:71H;2!U<VEN9R!02%`N
M"BH**B!`875T:&]R("`@56QF(%=E;F1E;"`\=6QF+G=E;F1E;$!P:'!D;V,N
M9&4^"BH@0'9E<G-I;VX@("1)9#H@<VAM+G!H<"QV(#$N,R`R,#`S+S`Q+S`T
M(#$Q.C4T.C0V(&UJ($5X<"`D"BH@0'!A8VMA9V4@($-A8VAE"BHO"F-L87-S
M($-A8VAE7T-O;G1A:6YE<E]S:&T@97AT96YD<R!#86-H95]#;VYT86EN97(@
M>PH@("`@+RHJ"B`@("`J($ME>2!O9B!T:&4@<V5M87!H;W)E('5S960@=&\@
M<WEN8R!T:&4@4TA-(&%C8V5S<PH@("`@*B`*("`@("H@0'9A<B`@:6YT"B`@
M("`J+PH@("`@=F%R("1S96U?:V5Y(#T@3E5,3#L*"B`@("`O*BH*("`@("H@
M4&5R;6ES<VEO;G,@;V8@=&AE('-E;6%P:&]R92!U<V5D('1O('-Y;F,@=&AE
M(%-(32!A8V-E<W,*("`@("H@"B`@("`J($!V87(@(&EN=`H@("`@*B\*("`@
M('9A<B`D<V5M7W!E<FT@/2`P-C0T.PH*("`@("\J*@H@("`@*B!396UA<&AO
M<F4@:&%N9&QE<@H@("`@*B`*("`@("H@0'9A<B`@<F5S;W5R8V4*("`@("HO
M"B`@("!V87(@)'-E;5]I9"`]($Y53$P["@H@("`@+RHJ"B`@("`J($ME>2!O
M9B!T:&4@<VAA<F5D(&UE;6]R>2!B;&]C:R!U<V5D('1O('-T;W)E(&-A8VAE
M(&1A=&$*("`@("H*("`@("H@0'9A<B`@:6YT"B`@("`J+PH@("`@=F%R("1S
M:&U?:V5Y(#T@3E5,3#L*"B`@("`O*BH*("`@("H@4VEZ92!O9B!T:&4@<VAA
M<F5D(&UE;6]R>2!B;&]C:R!U<V5D"B`@("`J(`H@("`@*B!.;W1E.B!T:&4@
M8V]N=&%I;F5R(&1O97,@;VYL>2!U<V4@7V]N95\@<VAM(&)L;V-K(&YO(&UO
M<F4A"B`@("`J(`H@("`@*B!`=F%R("!I;G0*("`@("HO("`@("`@("`*("`@
M('9A<B`D<VAM7W-I>F4@/2`Q,S$P-S(["@H@("`@+RHJ"B`@("`J(%!E<FUI
M<W-I;VYS(&]F('1H92!S:&%R960@;65M;W)Y(&)L;V-K"B`@("`J(`H@("`@
M*B!`=F%R("!I;G0*("`@("HO"B`@("!V87(@)'-H;5]P97)M(#T@,#8T-#L*
M"B`@("`O*BH*("`@("H@4VAA<F5D(&UE;6]R>2!H86YD;&5R"B`@("`J(`H@
M("`@*B!`=F%R(')E<V]U<F-E"B`@("`J+PH@("`@=F%R("1S:&U?:60@/2!.
M54Q,.PH*("`@("\J*@H@("`@*B!(87-H(&]F(&-A8VAE(&5N=')I97,*("`@
M("H@"B`@("`J(%5S960@8GD@=&AE(&=A<F)A9V4@8V]L;&5C=&EO;B!T;R!F
M:6YD(&]L9"!E;G1R:65S+@H@("`@*@H@("`@*B!`=F%R("!A<G)A>0H@("`@
M*B\*("`@('9A<B`D96YT<FEE<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`J
M($YU;6)E<B!O9B!B>71E<R!C;VYS=6UE9"!B>2!T:&4@8V%C:&4*("`@("H@
M"B`@("`J($!V87(@(&EN=`H@("`@*B\*("`@('9A<B`D=&]T86Q?<VEZ92`]
M(#`["@H@("`@+RHJ"B`@("`J($-R96%T97,@82!S:&%R960@;65M;W)Y(&-O
M;G1A:6YE<@H@("`@*@H@("`@*B!`<&%R86T@87)R87D@("`@<VAM7VME>2P@
M<V5M7VME>2P@<VAM7W-I>F4L('-E;5]P97)M+"!S:&U?<&5R;0H@("`@*B\@
M("`@"B`@("!F=6YC=&EO;B!#86-H95]#;VYT86EN97)?<VAM*"1O<'1I;VYS
M(#T@)R<I('L*("`@("`@("!I9B`H:7-?87)R87DH)&]P=&EO;G,I*0H@("`@
M("`@("`@("`D=&AI<RT^<V5T3W!T:6]N<R@D;W!T:6]N<RP@87)R87E?;65R
M9V4H)'1H:7,M/F%L;&]W961?;W!T:6]N<RP@"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<VAM
M7VME>2<L("`G<V5M7VME>2<L(`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-H;5]S:7IE)RP@
M)W-E;5]P97)M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=S:&U?<&5R;2<*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@("`@
M+R\@0V%C:&4Z.D-O;G1A:6YE<B!H:6=H+2!A;F0@;&]W=V%T97(@9&5F875L
M=',@<VAO=6QD(&)E(&]V97)R:61D96X@:68*("`@("`@("`O+R!N;W0@86QR
M96%D>2!D;VYE(&)Y('1H92!U<V5R"B`@("`@("`@:68@*"%I<W-E="@D;W!T
M:6]N<ULG:&EG:'=A=&5R)UTI*2`*("`@("`@("`@("`@)'1H:7,M/FAI9VAW
M871E<B`](')O=6YD*#`N-S4@*B`Q,S$P-S(I.PH@("`@("`@(&EF("@A:7-S
M970H)&]P=&EO;G-;)VQO=W=A=&5R)UTI*0H@("`@("`@("`@("`D=&AI<RT^
M;&]W=V%T97(@/2!R;W5N9"@P+C4@*B`Q,S$P-S(I.PH*("`@("`@("!I9B`H
M(6ES<V5T*"1O<'1I;VYS6R=S:&U?<VEZ92==*2D*("`@("`@("`@("`@)'1H
M:7,M/G-H;5]S:7IE(#T@,3,Q,#<R.PH*("`@("`@("`O+V=E="!32$T@86YD
M(%-E;6%P:&]R92!H86YD;&5S"B`@("`@("`@:68@*"$H)'1H:7,M/G-H;5]I
M9"`]('-H;6]P7V]P96XH)'1H:7,M/G-H;5]K97DL("=C)RP@)'1H:7,M/G-H
M;5]P97)M+"`D=&AI<RT^<VAM7W-I>F4I*2D*("`@("`@("`@("`@;F5W($-A
M8VAE7T5R<F]R*")#86XG="!O<&5N(%-(32!S96=M96YT("=[)'1H:7,M/G-H
M;5]K97E])RP@<VEZ92`G>R1T:&ES+3YS:&U?<VEZ97TG+B(L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%]?3$E.15]?"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("D["@H@("`@("`@(&EF("@A*"1T:&ES+3YS96U?:60@/2!S96U?9V5T
M*"1T:&ES+3YS96U?:V5Y+"`Q+"`D=&AI<RT^<V5M7W!E<FTI*2D*("`@("`@
M("`@("`@;F5W($-A8VAE7T5R<F]R*")#86XG="!G970@<V5M87!H;W)E("=[
M)'1H:7,M/G-E;5]K97E])R!U<VEN9R!P97)M<R`G>R1T:&ES+3YS96U?<&5R
M;7TG+B(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?3$E.15]?"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("D["@H@("`@?2`O+R!E;F0@8V]N<W1R=6-T
M;W(*"B`@("!F=6YC=&EO;B!F971C:"@D:60L("1G<F]U<"D@>PH@("`@("`@
M('-E;5]A8W%U:7)E*"1T:&ES+3YS96U?:60I.PH*("`@("`@("`D8V%C:&5D
M871A(#T@<VAM;W!?<F5A9"@D=&AI<RT^<VAM7VED+"`P+"`D=&AI<RT^<VAM
M7W-I>F4I.PH*("`@("`@("!S96U?<F5L96%S92@D=&AI<RT^<V5M7VED*3L*
M"B`@("`@("`@)&-A8VAE9&%T82`]("1T:&ES+3YD96-O9&4H)&-A8VAE9&%T
M82D["@H@("`@("`@(&EF("@A:7-S970H)&-A8VAE9&%T85LD9W)O=7!=6R1I
M9%TI*0H@("`@("`@("`@("!R971U<FX@87)R87DH3E5,3"P@3E5,3"P@3E5,
M3"D["B`@("`@("`@96QS92`*("`@("`@("`@("`@)&-A8VAE9&%T82`]("1C
M86-H961A=&%;)&=R;W5P75LD:61=.PH*("`@("`@("!R971U<FX@87)R87DH
M)&-A8VAE9&%T85LG97AP:7)E)UTL"B`@("`@("`@("`@("`@("`@("`@("1C
M86-H961A=&%;)V-A8VAE9&%T82==+`H@("`@("`@("`@("`@("`@("`@("`D
M8V%C:&5D871A6R=U<V5R9&%T82=="B`@("`@("`@("`@("`@("`@("`@*3L*
M("`@('T@+R\@96YD(&9U;F,@9F5T8V@*"B`@("!F=6YC=&EO;B!S879E*"1I
M9"P@)&1A=&$L("1E>'!I<F4L("1G<F]U<"P@)'5S97)D871A*2!["B`@("`@
M("`@)'1H:7,M/F9L=7-H4')E;&]A9"@D:60L("1G<F]U<"D["@H@("`@("`@
M('-E;5]A8W%U:7)E*"1T:&ES+3YS96U?:60I.PH*("`@("`@("`D8V%C:&5D
M871A(#T@)'1H:7,M/F1E8V]D92AS:&UO<%]R96%D*"1T:&ES+3YS:&U?:60L
M(#`L("1T:&ES+3YS:&U?<VEZ92DI.PH@("`@("`@("1C86-H961A=&%;)&=R
M;W5P75LD:61=(#T@87)R87DH)V5X<&ER92<@("`@/3X@)'1H:7,M/F=E=$5X
M<&ER97-!8G-O;'5T92@D97AP:7)E*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=C86-H961A=&$G(#T^("1D871A+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5S97)D871A
M)R`@/3X@)'5S97)D871A+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V-H86YG960G("`@/3X@=&EM92@I"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("D["@H@("`@("`@(&EF("AS
M=')L96XH)&YE=V1A=&$@/2`D=&AI<RT^96YC;V1E*"1C86-H961A=&$I*2`^
M("1T:&ES+3YS:&U?<VEZ92D*("`@("`@("`@("`@)&-A8VAE9&%T82`]("1T
M:&ES+3YG87)B86=E0V]L;&5C=&EO;BAT:6UE*"DL("1C86-H961A=&$I.PH*
M("`@("`@("!S:&UO<%]W<FET92@D=&AI<RT^<VAM7VED+"`D;F5W9&%T82P@
M,"D["@H@("`@("`@('-E;5]R96QE87-E*"1T:&ES+3YS96U?:60I.PH*("`@
M("`@("!R971U<FX@=')U93L*("`@('T@+R\@96YD(&9U;F,@<V%V90H*("`@
M(&9U;F-T:6]N(')E;6]V92@D:60L("1G<F]U<"D@>PH@("`@("`@("1T:&ES
M+3YF;'5S:%!R96QO860H)&ED+"`D9W)O=7`I.PH*("`@("`@("!S96U?86-Q
M=6ER92@D=&AI<RT^<V5M7VED*3L*"B`@("`@("`@)&-A8VAE9&%T82`]("1T
M:&ES+3YD96-O9&4H<VAM;W!?<F5A9"@D=&AI<RT^<VAM7VED+"`P+"`D=&AI
M<RT^<VAM7W-I>F4I*3L*("`@("`@("!U;G-E="@D8V%C:&5D871A6R1G<F]U
M<%U;)&ED72D["B`@("`@("`@<VAM;W!?=W)I=&4H)'1H:7,M/G-H;5]I9"P@
M)'1H:7,M/F5N8V]D92@D8V%C:&5D871A*2P@,"D["@H@("`@("`@('-E;5]R
M96QE87-E*"1T:&ES+3YS96U?:60I.PH@("`@?2`O+R!E;F0@9G5N8R!R96UO
M=F4*"B`@("!F=6YC=&EO;B!F;'5S:"@D9W)O=7`@/2`G)RD@>PH@("`@("`@
M("1T:&ES+3YF;'5S:%!R96QO860H*3L*"B`@("`@("`@<V5M7V%C<75I<F4H
M)'1H:7,M/G-E;5]I9"D["@H@("`@("`@('-H;6]P7W=R:71E*"1T:&ES+3YS
M:&U?:60L("1T:&ES+3YE;F-O9&4H87)R87DH*2DL(#`I.PH*("`@("`@("!S
M96U?<F5L96%S92@D=&AI<RT^<V5M7VED*3L*("`@('T@+R\@96YD(&9U;F,@
M9FQU<V@*"B`@("!F=6YC=&EO;B!I9$5X:7-T<R@D:60L("1G<F]U<"D@>PH@
M("`@("`@('-E;5]A8W%U:7)E*"1T:&ES+3YS96U?:60I.PH*("`@("`@("`D
M8V%C:&5D871A(#T@<VAM7W)E860H)'1H:7,M/G-H;5]I9"P@,"P@)'1H:7,M
M/G-H;5]S:7IE*3L*"B`@("`@("`@<V5M7W)E;&5A<V4H)'1H:7,M/G-E;5]I
M9"D["@H@("`@("`@("1C86-H961A=&$@/2`D=&AI<RT^9&5C;V1E*"1C86-H
M961A=&$I.PH*("`@("`@("!R971U<FX@:7-S970H)&-A8VAE9&%T85LD9W)O
M=7!=6R1I9%TI.PH@("`@?2`O+R!E;F0@9G5N8R!I<T5X:7-T<PH*("`@(&9U
M;F-T:6]N(&=A<F)A9V5#;VQL96-T:6]N*"1M87AL:69E=&EM92P@)&-A8VAE
M9&%T82`](&%R<F%Y*"DI('L*("`@("`@("!I9B`H)&QO8VL@/2!E;7!T>2@D
M8V%C:&5D871A*2D@>PH@("`@("`@("`@("!S96U?86-Q=6ER92@D=&AI<RT^
M<V5M7VED*3L*("`@("`@("`@("`@)&-A8VAE9&%T82`]("1T:&ES+3YD96-O
M9&4H<VAM;W!?<F5A9"@D=&AI<RT^<VAM7VED+"`P+"`D=&AI<RT^<VAM7W-I
M>F4I*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YD;T=A<F)A9V5#;VQL
M96-T:6]N*"1M87AL:69E=&EM92P@)B1C86-H961A=&$I.PH@("`@("`@(&EF
M("@D=&AI<RT^=&]T86Q?<VEZ92`^("1T:&ES+3YH:6=H=V%T97(I('L*("`@
M("`@("`@("`@:W)S;W)T*"1T:&ES+3YE;G1R:65S*3L*("`@("`@("`@("`@
M<F5S970H)'1H:7,M/F5N=')I97,I.PH*("`@("`@("`@("`@=VAI;&4@*"1T
M:&ES+3YT;W1A;%]S:7IE(#X@)'1H:7,M/FQO=W=A=&5R("8F(&QI<W0H)'-I
M>F4L("1E;G1R:65S*2`](&5A8V@H)'1H:7,M/F5N=')I97,I*2!["B`@("`@
M("`@("`@("`@("!R97-E="@D96YT<FEE<RD["@H@("`@("`@("`@("`@("`@
M=VAI;&4@*&QI<W0H)&LL("1E;G1R>2D@/2!E86-H*"1E;G1R:65S*2D@>PH@
M("`@("`@("`@("`@("`@("`@('5N<V5T*"1C86-H961A=&%;)&5N=')Y6R=G
M<F]U<"==75LD96YT<GE;)VED)UU=*3L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^=&]T86Q?<VEZ92`M/2`D<VEZ93L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1L;V-K*0H@
M("`@("`@("`@("!S96U?<F5L96%S92@D=&AI<RT^<V5M7VED*3L*"B`@("`@
M("`@)'1H:7,M/F5N=')I97,@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3YT
M;W1A;%]S:7IE(#T@,#L*"B`@("`@("`@<F5T=7)N("1C86-H961A=&$[("`@
M("`@("`@("`*("`@('T@+R\@96YD(&9U;F,@9V%R8F%G94-O;&QE8W1I;VX*
M"B`@("!F=6YC=&EO;B!D;T=A<F)A9V5#;VQL96-T:6]N*"1M87AL:69E=&EM
M92P@)B1C86-H961A=&$I('L*("`@("`@("`D8VAA;F=E9"`]('1I;64H*2`M
M("1M87AL:69E=&EM93L*("`@("`@("`D<F5M;W9E9"`](#`["@H@("`@("`@
M(')E<V5T*"1C86-H961A=&$I.PH*("`@("`@("!W:&EL92`H;&ES="@D9W)O
M=7`L("1G<F]U<&1A=&$I(#T@96%C:"@D8V%C:&5D871A*2D@>PH@("`@("`@
M("`@("!R97-E="@D9W)O=7!D871A*3L*"B`@("`@("`@("`@('=H:6QE("AL
M:7-T*"1I9"P@)&1A=&$I(#T@96%C:"@D9W)O=7!D871A*2D@>PH@("`@("`@
M("`@("`@("`@:68@*"1D871A6R=E>'!I<F4G72`\('1I;64H*2!\?"`D9&%T
M85LG8VAA;F=E9"==(#P@)&-H86YG960I('L*("`@("`@("`@("`@("`@("`@
M("!U;G-E="@D8V%C:&5D871A6R1G<F]U<%U;)&ED72D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O('5G;'D@8G5T
M('-I;7!L92!T;R!I;7!L96UE;G0@.B\*("`@("`@("`@("`@)'-I>F4@/2!S
M=')L96XH)'1H:7,M/F5N8V]D92@D9&%T82DI.PH@("`@("`@("`@("`D=&AI
M<RT^96YT<FEE<ULD<VEZ95U;72`](&%R<F%Y*"=G<F]U<"<@/3X@)&=R;W5P
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=I9"<@("`@/3X@)&ED"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`I.PH*("`@("`@("`@("`@)'1H:7,M/G1O=&%L7W-I
M>F4@*ST@)'-I>F4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E;6]V
M960["B`@("!]("`O+R!E;F0@9G5N8R!D;T=A<F)A9V5#;VQL96-T:6]N"GT@
M+R\@96YD(&-L87-S($-A8VAE7T-O;G1A:6YE<E]S:&T*/SX*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O0V%C:&4O0V]N
M=&%I;F5R+W1R:69I;&4N<&AP````````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,3$R,S0`,3`U,34T,S,W,S0`,#(S-S`Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\(%!%05(@.CH@0V%C:&4@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT
M("AC*2`Q.3DW+3(P,#0@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO
M;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\"B\O('P@=&AA="!I
M<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.
M4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X
M="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E
M(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@
M("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%5L9B!7
M96YD96P@/'5L9BYW96YD96Q`<&AP9&]C+F1E/B`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"`@("`@("`@("!396)A<W1I86X@0F5R9VUA;FX@
M/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X@("`@("`@("`@("`@("!\"B\O
M('P@("`@("`@("`@26%N($5U<F4@/&EE=7)E0'!H<"YN970^("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!T<FEF:6QE+G!H<"QV(#$N,2`R
M,#`T+S`T+S`Q(#`W.C4P.C`W(&-H<F5G=2!%>'`@)`H*<F5Q=6ER95]O;F-E
M("=#86-H92]#;VYT86EN97(O9FEL92YP:'`G.PH*+RHJ"B`J(%1R:2UF:6QE
M(&-A8VAE+@H@*@H@*B!4:&ES(&-A8VAE(&-O;G1A:6YE<B!S=&]R97,@9FEL
M97,@=VET:"!N;R!S<&5C:6%L(&5N8V]D:6YG('1O(')E9'5C92!O=F5R:&5A
M9"X*("H@17AP:7)A=&EO;B`F('5S97(@9&%T82!A<F4@<W1O<F5D(&EN('-E
M<&5R871E(&9I;&5S+"!P<F5F:7AE9"!W:71H(&$@)RXG(&%N9`H@*B!S=69F
M:7AE9"!W:71H("<N97AP)R`F("<N9&%T)R!R97-P96-T:79E;'DN"B`J"B`J
M(%-E92!H='1P.B\O871O;6EZ960N;W)G+U!%05(O0V%C:&5?=')I9FEL92YH
M=&UL(&9O<B!M;W)E(&EN9F]R;6%T:6]N+@H@*@H@*B!`875T:&]R($EA;B!%
M=7)E(#QI975R94!P:'`N;F5T/@H@*B!`=F5R<VEO;B`Q+C`*("HO"F-L87-S
M($-A8VAE7T-O;G1A:6YE<E]T<FEF:6QE(&5X=&5N9',@0V%C:&5?0V]N=&%I
M;F5R7V9I;&4@>PH@("`@+RHJ"B`@("`@*B!&971C:"!C86-H960@9FEL92X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"!#86-H92!)1"!T;R!F
M971C:`H@("`@("H@0'!A<F%M('-T<FEN9R`D9W)O=7`@1W)O=7`@=&\@9F5T
M8V@@9G)O;0H@("`@("H@0')E='5R;B!A<G)A>2`Q+61I;65N<VEO;F%L(&%R
M<F%Y(&EN('1H92!F;W)M870Z(&5X<&ER871I;VXL9&%T82QU<V5R9&%T80H@
M("`@("HO"B`@("!F=6YC=&EO;B!F971C:"@D:60L("1G<F]U<"D*("`@('L*
M("`@("`@("`D9FEL92`]("1T:&ES+3YG971&:6QE;F%M92@D:60L("1G<F]U
M<"D["B`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D9FEL92DI"B`@("`@("`@
M("`@(')E='5R;B!A<G)A>2A.54Q,+"!.54Q,+"!.54Q,*3L*("`@("`@("`*
M("`@("`@("!R971U<FX@87)R87DH"B`@("`@("`@("`@("`@("!F:6QE7V=E
M=%]C;VYT96YT<R@D=&AI<RT^7V=E=$5X<$9I;&4H)&9I;&4I*2P*("`@("`@
M("`@("`@("`@(&9I;&5?9V5T7V-O;G1E;G1S*"1F:6QE*2P*("`@("`@("`@
M("`@("`@(&9I;&5?9V5T7V-O;G1E;G1S*"1T:&ES+3Y?9V5T541&:6QE*"1F
M:6QE*2D*("`@("`@("`I.PH@("`@?0H@("`@"B`@("`O*BH*("`@("`J($=E
M="!T:&4@9FEL92!T;R!S=&]R92!C86-H92!D871A(&EN+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG($-A8VAE(&1A=&$@9FEL92!N86UE"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$9I
M;&4H)&9I;&4I"B`@("!["B`@("`@("`@)&1I<B`](&1I<FYA;64H)&9I;&4I
M.PH@("`@("`@("1F:6QE(#T@8F%S96YA;64H)&9I;&4I.PH@("`@("`@(')E
M='5R;B`D9&ER+B<O+B<N)&9I;&4["B`@("!]"B`@("`*("`@("\J*@H@("`@
M("H@1V5T('1H92!F:6QE('1O('-T;W)E(&5X<&ER871I;VX@9&%T82!I;BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R!%>'!I<F%T:6]N(&1A=&$@
M9FEL92!N86UE"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V=E=$5X<$9I;&4H)&9I;&4I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?9V5T1FEL92@D9FEL92DN)RYE>'`G.PH@("`@?0H@("`@
M"B`@("`O*BH*("`@("`J($=E="!T:&4@9FEL92!T;R!S=&]R92!U<V5R(&1A
M=&$@:6XN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@57-E<B!D871A
M(&9I;&4@;F%M90H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]G97151$9I;&4H)&9I;&4I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?9V5T1FEL92@D9FEL92DN)RYD870G.PH@("`@?0H@("`@
M"B`@("`O*BH*("`@("`J($-A8VAE(&9I;&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1I9"!#86-H92!)1`H@("`@("H@0'!A<F%M(&UI>&5D("1C
M86-H961A=&$@1&%T82!T;R!C86-H90H@("`@("H@0'!A<F%M(&UI>&5D("1E
M>'!I<F5S(%=H96X@=&AE(&1A=&$@97AP:7)E<PH@("`@("H@0'!A<F%M('-T
M<FEN9R`D9W)O=7`@0V%C:&4@9W)O=7`@=&\@<W1O<F4@9&%T82!I;@H@("`@
M("H@0'!A<F%M(&UI>&5D("1U<V5R9&%T82!!9&1I=&EO;F%L(&1A=&$@=&\@
M<W1O<F4*("`@("`J($!R971U<FX@8F]O;&5A;B!T<G5E(&]N('-U8V-E<W,L
M(&9A;'-E(&]T:&5R=VES90H@("`@("HO"B`@("!F=6YC=&EO;B!S879E*"1I
M9"P@)&-A8VAE9&%T82P@)&5X<&ER97,L("1G<F]U<"P@)'5S97)D871A*0H@
M("`@>PH@("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H)&ED+"`D9W)O=7`I
M.PH*("`@("`@("`D9FEL92`]("1T:&ES+3YG971&:6QE;F%M92@D:60L("1G
M<F]U<"D["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<R`]("1T:&ES
M+3Y?<V%V941A=&$H)&9I;&4L("1C86-H961A=&$I*2D@>PH@("`@("`@("`@
M("!R971U<FX@)')E<SL*("`@("`@("!]"B`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)')E<R`]("1T:&ES+3Y?<V%V941A=&$H)'1H:7,M/E]G971%>'!&
M:6QE*"1F:6QE*2P@)&5X<&ER97,I*2D@>PH@("`@("`@("`@("!R971U<FX@
M)')E<SL*("`@("`@("!]"B`@("`@("`@:68H4$5!4CHZ:7-%<G)O<B@D<F5S
M(#T@)'1H:7,M/E]S879E1&%T82@D=&AI<RT^7V=E=%5$1FEL92@D9FEL92DL
M("1U<V5R1&%T82DI*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3879E(&1A=&$@:6X@82!F:6QE"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9FEL92!&:6QE('1O('-A=F4@9&%T82!I;@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9&%T82!$871A('1O('-A=F4*("`@("`J($!R971U<FX@
M;6EX960@=')U92!O;B!S=6-C97-S+"!#86-H95]%<G)O<B!O=&AE<G=I<V4*
M("`@("`J+PH@("`@9G5N8W1I;VX@7W-A=F5$871A*"1F:6QE+"`D9&%T82D@
M>PH@("`@("`@("\O(%-A=F4@9&%T80H@("`@("`@(&EF("@A*"1F:"`]($!F
M;W!E;B@D9FEL92P@)W=B)RDI*0H@("`@("`@("`@("!R971U<FX@;F5W($-A
M8VAE7T5R<F]R*")#86XG="!A8V-E<W,@)R1F:6QE)R!T;R!S=&]R92!C86-H
M92!D871A+B!#:&5C:R!A8V-E<W,@<FEG:'1S(&%N9"!P871H+B(L(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["B`@("`@("`@"B`@("`@("`@:68@*"1T:&ES+3YF
M:6QE3&]C:VEN9RD@>PH@("`@("`@("`@("!F;&]C:R@D9F@L($Q/0TM?15@I
M.PH@("`@("`@('T*("`@("`@("`*("`@("`@("!F=W)I=&4H)&9H+"`D9&%T
M82D["B`@("`@("`@"B`@("`@("`@:68H)'1H:7,M/F9I;&5,;V-K:6YG*2![
M"B`@("`@("`@("`@(&9L;V-K*"1F:"P@3$]#2U]53BD["B`@("`@("`@?0H@
M("`@("`@(`H@("`@("`@(&9C;&]S92@D9F@I.PH@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0I]"@H_/@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-A
M8VAE+T-O;G1A:6YE<BYP:'``````````````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#,R,S<T`#$P-3$U-#,S-S,T`#`R,C(U,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!014%2(#HZ($-A8VAE("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O
M<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O
M('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\
M('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL
M92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@
M;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T
M92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A
M;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S
M.B!5;&8@5V5N9&5L(#QU;&8N=V5N9&5L0'!H<&1O8RYD93X@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@4V5B87-T:6%N($)E
M<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^("`@("`@("`@("`@
M("`@?`HO+R!\("`@("`@("`@($-H<FES=&EA;B!3=&]C:V5R(#QC:')E9W5`
M<&AA;G0N8V@^("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@0V]N=&%I;F5R+G!H
M<"QV(#$N-"`R,#`S+S`Q+S`T(#$Q.C4T.C0U(&UJ($5X<"`D"@IR97%U:7)E
M7V]N8V4@)T-A8VAE+T5R<F]R+G!H<"<["@HO*BH**B!#;VUM;VX@8F%S92!C
M;&%S<R!O9B!A;&P@8V%C:&4@<W1O<F%G92!C;VYT86EN97(N"BH@"BH@5&\@
M<W!E960@=7`@=&AI;F=S('=E(&1O(&$@<')E;&]A9"!Y;W4@<VAO=6QD(&MN
M;W<@86)O=70L(&]T:&5R=VES92!I="!M:6=H="`**B!P;&%Y('EO=2!A('1R
M:6-K+B!4:&4@0V%C:&4@8V]N=')O;&QE<B!C;&%S<V5S("A#86-H92]#86-H
M92P@0V%C:&4O3W5T<'5T+"`N+BXI"BH@=7-U86QL>2!D;R!S;VUE=&AI;F<@
M;&EK92!I<R`H:7-#86-H960H)&ED*2`F)B`A:7-%>'!I<F5D*"1I9"DI(')E
M='5R;B`D8V]N=&%I;F5R+3YL;V%D*"1I9"DN"BH@:68@>6]U(&EM<&QE;65N
M="!I<T-A8VAE9"@I+"!I<T5X<&ER960H*2!A;F0@;&]A9"@I('-T<F%I9VAT
M(&%H96%D+"!E86-H(&]F('1H:7,@"BH@9G5N8W1I;VYS('=I;&P@<F5S=6QT
M(&EN(&$@<W1O<F%G92!M961I=6T@*&1B+"!F:6QE+"XN+BD@86-C97-S+B!4
M:&ES(&=E;F5R871E<R!T;V\@;75C:"!L;V%D+B`**B!.;W<L(&$@<VEM<&QE
M('-P96-U;&%T:79E('!R96QO860@<VAO=6QD('-A=F5S('1I;64@:6X@;6]S
M="!C87-E<RX@5VAE;F5V97(@"BH@;VYE(&]F('1H92!M96YT:6]N960@;65T
M:&]D<R!I<R!I;G9O:V5D('=E('!R96QO860@=&AE(&-A8VAE9"!D871A<V5T
M(&EN=&\@8VQA<W,@=F%R:6%B;&5S+@HJ(%1H870@;65A;G,@=&AA="!W92!H
M879E(&]N;'D@;VYE('-T;W)A9V4@;65D:75M(&%C8V5S<R!F;W(@=&AE('-E
M<75E;F-E"BH@("AI<T-A8VAE9"@D:60I("8F("%I<T5X<&ER960H)&ED*2D@
M<F5T=7)N("1C;VYT86EN97(M/FQO860H)&ED*2X**B!4:&4@8F%D('1H:6YG
M(&ES('1H870@=&AE('!R96QO861E9"!D871A(&UI9VAT(&)E(&]U=&1A=&5D
M(&UE86YW:&EL92P@=VAI8V@@:7,@"BH@=6YL:6ME;'D@8G5T(&9O<B!Y;W4@
M<&]W97(@=7-E<G,L(&)E('=A<FYE9"X@268@>6]U(&1O(&YO="!W86YT('1H
M92!P<F5L;V%D(`HJ('EO=2!S:&]U;&0@<W=I=&-H(&ET(&]F9B!B>2!S971T
M:6YG('1H92!C;&%S<R!V87)I86)L92`D<')E;&]A9"!T;R!F86QS92X@06YY
M=V%Y+"!T:&ES(&ES(`HJ(&YO="!R96-O;6UE;F1E9"$**B`**B!`875T:&]R
M("`@56QF(%=E;F1E;"`\=6QF+G=E;F1E;$!P:'!D;V,N9&4^"BH@0'9E<G-I
M;VX@("1)9#H@0V]N=&%I;F5R+G!H<"QV(#$N-"`R,#`S+S`Q+S`T(#$Q.C4T
M.C0U(&UJ($5X<"`D"BH@0'!A8VMA9V4@($-A8VAE"BH@0&%C8V5S<R`@('!U
M8FQI8PHJ($!A8G-T<F%C=`HJ+PIC;&%S<R!#86-H95]#;VYT86EN97(@>PH*
M("`@("\J*@H@("`@*B!&;&%G(&EN9&EC871I;F<@=VAE=&5R('1O('!R96QO
M860@9&%T87-E=',N"B`@("`J"B`@("`J(%-E92!T:&4@8VQA<W,@9&5S8W)I
M<'1I;VX@9F]R(&UO<F4@9&5T86EL<RX*("`@("H*("`@("H@0'9A<B`@8F]O
M;&5A;@H@("`@*B\*("`@('9A<B`D<')E;&]A9"`]('1R=64["@H@("`@+RHJ
M"B`@("`J($E$(&]F(&$@<')E;&]A9&5D(&1A=&%S970*("`@("H*("`@("H@
M0'9A<B`@<W1R:6YG"B`@("`J+PH@("`@=F%R("1I9"`]("<G.PH*("`@("\J
M*@H@("`@*B!#86-H92!G<F]U<"!O9B!A('!R96QO861E9"!D871A<V5T"B`@
M("`J"B`@("`J($!V87(@('-T<FEN9PH@("`@*B\*("`@('9A<B`D9W)O=7`@
M/2`G)SL*"B`@("`O*BH*("`@("H@17AP:7)A=&EO;B!T:6UE<W1A;7`@;V8@
M82!P<F5L;V%D960@9&%T87-E="X*("`@("H@"B`@("`J($!V87(@(&EN=&5G
M97(@,"!M96%N<R!N979E<BP@96YD;&5S<PH@("`@*B\*("`@('9A<B`D97AP
M:7)E<R`](#`["@H@("`@+RHJ"B`@("`J(%9A;'5E(&]F(&$@<')E;&]A9&5D
M(&1A=&%S970N"B`@("`J(`H@("`@*B!`=F%R("!S=')I;F<*("`@("HO"B`@
M("!V87(@)&-A8VAE9&%T82`]("<G.PH*("`@("\J*@H@("`@*B!0<F5L;V%D
M960@=7-E<F1A=&$@9FEE;&0N"B`@("`J(`H@("`@*B!`=F%R("!S=')I;F<*
M("`@("HO"B`@("!V87(@)'5S97)D871A(#T@)R<["@H@("`@+RHJ"B`@("`J
M($9L86<@:6YD:6-A=&EN9R!T:&%T('1H92!D871A<V5T(')E<75E<W1E9"!F
M;W(@<')E;&]A9&EN9R!I<R!U;FMN;W=N+@H@("`@*B`@"B`@("`J($!V87(@
M(&)O;VQE86X*("`@("HO"B`@("!V87(@)'5N:VYO=VX@/2!T<G5E.PH*("`@
M("\J*@H@("`@*B!%;F-O9&EN9R!M;V1E(&9O<B!C86-H92!D871A.B!B87-E
M-C0@;W(@861D<VQA<VAE<R@I("AS;&%S:"DN"B`@("`J"B`@("`J($!V87(@
M('-T<FEN9R`@8F%S938T(&]R('-L87-H"B`@("`J+PH@("`@=F%R("1E;F-O
M9&EN9U]M;V1E(#T@)V)A<V4V-"<["B`@("`*("`@("\J*@H@("`@*B!(:6=H
M=V%T97(@;6%R:R`M(&UA>&EM=6T@<W!A8V4@<F5Q=6ER960@8GD@86QL(&-A
M8VAE(&5N=')I97,N"B`@("`J(`H@("`@*B!7:&5N979E<B!T:&4@9V%R8F%G
M92!C;VQL96-T:6]N(')U;G,@:70@8VAE8VMS('1H92!A;6]U;G0@;V8@<W!A
M8V4*("`@("H@<F5Q=6ER960@8GD@86QL(&-A8VAE(&5N=')I97,N($EF(&ET
M)W,@;6]R92!T:&%N(&X@*&AI9VAW871E<BD@8GET97,*("`@("H@=&AE(&=A
M<F)A9V4@8V]L;&5C=&EO;B!D96QE=&5S(&%S(&UA;GD@96YT<FEE<R!A<R!N
M96-E<W-A<GD@=&\@<F5A8V@@=&AE"B`@("`J(&QO=W=A=&5R(&UA<FLN(`H@
M("`@*B`*("`@("H@0'9A<B`@:6YT"B`@("`J($!S964@(&QO=W=A=&5R"B`@
M("`J+PH@("`@=F%R("1H:6=H=V%T97(@/2`R,#0X,#`P.R`*("`@(`H@("`@
M"B`@("`O*BH*("`@("H@3&]W=V%T97(@;6%R:PH@("`@*@H@("`@*B!`=F%R
M("!I;G0*("`@("H@0'-E92`@:&EG:'=A=&5R"B`@("`J+PH@("`@=F%R("1L
M;W=W871E<B`](#$U,S8P,#`["B`@("`*("`@(`H@("`@+RHJ"B`@("`J($]P
M=&EO;G,@=&AA="!C86X@8F4@<V5T(&EN(&5V97)Y(&1E<FEV960@8VQA<W,@
M=7-I;F<@:70G<R!C;VYS=')U8W1O<BX*("`@("H@"B`@("`J($!V87(@(&%R
M<F%Y"B`@("`J+PH@("`@=F%R("1A;&QO=V5D7V]P=&EO;G,@/2!A<G)A>2@G
M96YC;V1I;F=?;6]D92<L("=H:6=H=V%T97(G+"`G;&]W=V%T97(G*3L*("`@
M(`H@("`@"B`@("`O*BH*("`@("H@3&]A9',@82!D871A<V5T(&9R;VT@=&AE
M(&-A8VAE+@H@("`@*B`*("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T87-E
M="!)1`H@("`@*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@("`@
M*B!`<F5T=7)N("`@;6EX960@("!D871A<V5T('9A;'5E(&]R($Y53$P@;VX@
M9F%I;'5R90H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J+PH@("`@9G5N
M8W1I;VX@;&]A9"@D:60L("1G<F]U<"D@>PH@("`@("`@(&EF("@D=&AI<RT^
M<')E;&]A9"D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/FED("$]("1I9"!\
M?"`D=&AI<RT^9W)O=7`@(3T@)&=R;W5P*0H@("`@("`@("`@("`@("`@)'1H
M:7,M/G!R96QO860H)&ED+"`D9W)O=7`I.PH*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YC86-H961A=&$["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@;&ES="@@+"`D9&%T82P@*2`]("1T:&ES+3YF971C:"@D:60L("1G<F]U
M<"D["B`@("`@("`@("`@(')E='5R;B`D9&%T83L*("`@("`@("!]"B`@("!]
M("\O(&5N9"!F=6YC(&QO860*"B`@("`O*BH*("`@("H@4F5T=7)N<R!T:&4@
M=7-E<F1A=&$@9FEE;&0@;V8@82!C86-H960@9&%T82!S970N"B`@("`J"B`@
M("`J($!P87)A;2`@("!S=')I;F<@(&1A=&%S970@240*("`@("H@0'!A<F%M
M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@("H@0')E='5R;B`@('-T<FEN
M9R`@=7-E<F1A=&$*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%5S97)D871A*"1I9"P@)&=R;W5P*2!["B`@("`@("`@
M:68@*"1T:&ES+3YP<F5L;V%D*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^
M:60@(3T@)&ED('Q\("1T:&ES+3YG<F]U<"`A/2`D9W)O=7`I"B`@("`@("`@
M("`@("`@("`D=&AI<RT^<')E;&]A9"@D:60L("1G<F]U<"D["B`@("`@("`@
M("`@("`@("`*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YU<V5R9&%T83L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!L:7-T*"`L("P@)'5S97)D
M871A*2`]("1T:&ES+3YF971C:"@D:60L("1G<F]U<"D["B`@("`@("`@("`@
M(')E='5R;B`D=7-E<F1A=&$["B`@("`@("`@?0H@("`@?2`O+R!E;F0@9G5N
M8R!G9715<V5R9&%T80H*("`@("\J*@H@("`@*B!#:&5C:W,@:68@82!D871A
M<V5T(&ES(&5X<&ER960N"B`@("`J(`H@("`@*B!`<&%R86T@("`@<W1R:6YG
M("!D871A<V5T($E$"B`@("`J($!P87)A;2`@("!S=')I;F<@(&-A8VAE(&=R
M;W5P"B`@("`J($!P87)A;2`@("!I;G1E9V5R(&UA>&EM=6T@86=E('1I;65S
M=&%M<`H@("`@*B!`<F5T=7)N("`@8F]O;&5A;B`*("`@("H@0&%C8V5S<R`@
M('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(&ES17AP:7)E9"@D:60L("1G
M<F]U<"P@)&UA>%]A9V4I('L*("`@("`@("!I9B`H)'1H:7,M/G!R96QO860I
M('L*("`@("`@("`@(&EF("@D=&AI<RT^:60@(3T@)&ED('Q\("1T:&ES+3YG
M<F]U<"`A/2`D9W)O=7`I"B`@("`@("`@("`@("1T:&ES+3YP<F5L;V%D*"1I
M9"P@)&=R;W5P*3L*("`@("`@("`@(`H@("`@("`@("`@:68@*"1T:&ES+3YU
M;FMN;W=N*0H@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@+R\@8VAE8VL@:68@870@86QL(&ET(&ES(&-A
M8VAE9`H@("`@("`@("`@("!I9B`H(21T:&ES+3YI<T-A8VAE9"@D:60L("1G
M<F]U<"DI"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M("`@("`@("`*("`@("`@("`@("`@+R\@22=M(&QA>GDN+BX*("`@("`@("`@
M("`@;&ES="@D=&AI<RT^97AP:7)E<RP@+"`I(#T@)'1H:7,M/F9E=&-H*"1I
M9"P@)&=R;W5P*3L*("`@("`@("!]"@H@("`@("`@("\O(&5N9&QE<W,*("`@
M("`@("!I9B`H,"`]/2`D=&AI<RT^97AP:7)E<RD*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH*("`@("`@("`O+R!Y;W4@9F5E;"!F:6YE+"!5;&8_"B`@
M("`@("`@:68@*"1E>'!I<F5D("`]("@D=&AI<RT^97AP:7)E<R`\/2!T:6UE
M*"D@?'P@*"1M87A?86=E("8F("@D=&AI<RT^97AP:7)E<R`\/2`D;6%X7V%G
M92DI*2`I('L*"B`@("`@("`@("`@)'1H:7,M/G)E;6]V92@D:60L("1G<F]U
M<"D["B`@("`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A9"@I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)&5X<&ER960["B`@("!]("\O(&5N9"!F=6YC
M(&ES17AP:7)E9`H*("`@("\J*@H@("`@*B!#:&5C:W,@:68@82!D871A<V5T
M(&ES(&-A8VAE9"X*("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T
M87-E="!)1`H@("`@*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@
M("`@*B!`<F5T=7)N("`@8F]O;&5A;@H@("`@*B\*("`@(&9U;F-T:6]N(&ES
M0V%C:&5D*"1I9"P@)&=R;W5P*2!["B`@("`@("`@:68@*"1T:&ES+3YP<F5L
M;V%D*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^:60@(3T@)&ED('Q\("1T
M:&ES+3YG<F]U<"`A/2`D9W)O=7`I"B`@("`@("`@("`@("`@("`D=&AI<RT^
M<')E;&]A9"@D:60L("1G<F]U<"D["@H@("`@("`@("`@("!R971U<FX@(2@D
M=&AI<RT^=6YK;F]W;BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YI9$5X:7-T<R@D:60L("1G<F]U<"D["B`@("`@("`@
M?0H@("`@?2`O+R!E;F0@9G5N8R!I<T-A8VAE9`H*("`@("\O"B`@("`O+R!A
M8G-T<F%C="!M971H;V1S"B`@("`O+PH*("`@("\J*@H@("`@*B!&971C:&5S
M(&$@9&%T87-E="!F<F]M('1H92!S=&]R86=E(&UE9&EU;2X*("`@("H*("`@
M("H@0'!A<F%M("`@('-T<FEN9R`@9&%T87-E="!)1`H@("`@*B!`<&%R86T@
M("`@<W1R:6YG("!C86-H92!G<F]U<`H@("`@*B!`<F5T=7)N("`@87)R87D@
M("!F;W)M870Z(%ME>'!I<F4@9&%T92P@8V%C:&5D(&1A=&$L('5S97(@9&%T
M85T*("`@("H@0'1H<F]W<R`@($-A8VAE7T5R<F]R"B`@("`J($!A8G-T<F%C
M=`H@("`@*B\*("`@(&9U;F-T:6]N(&9E=&-H*"1I9"P@)&=R;W5P*2!["B`@
M("`@("`@<F5T=7)N(&%R<F%Y*$Y53$PL($Y53$PL($Y53$PI.PH@("`@?2`O
M+R!E;F0@9G5N8R!F971C:`H*("`@("\J*@H@("`@*B!3=&]R97,@82!D871A
M<V5T+@H@("`@*B`*("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T87-E="!)
M1`H@("`@*B!`<&%R86T@("`@;6EX960@("!D871A('1O('-T;W)E"B`@("`J
M($!P87)A;2`@("!M:7AE9"`@('5S97)D969I;F5D(&5X<&ER92!D871E"B`@
M("`J($!P87)A;2`@("!S=')I;F<@(&-A8VAE(&=R;W5P"B`@("`J($!P87)A
M;2`@("!S=')I;F<@(&%D9&ET:6]N86P@=7-E<F1E9FEN960@9&%T80H@("`@
M*B!`<F5T=7)N("`@8F]O;&5A;@H@("`@*B!`=&AR;W=S("`@0V%C:&5?17)R
M;W(*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B!`86)S=')A8W0*("`@
M("HO"B`@("!F=6YC=&EO;B!S879E*"1I9"P@)&1A=&$L("1E>'!I<F4L("1G
M<F]U<"P@)'5S97)D871A*2!["B`@("`@("`@+R\@455%4U1)3TXZ(%-H;W5L
M9"!W92!U<&1A=&4@=&AE('!R96QO860@8G5F9F5R(&EN<W1E860_"B`@("`@
M("`@+R\@1&]N)W0@=&AI;FL@<V\@87,@=&AE('-E<75E;F-E('-A=F4H*2]L
M;V%D*"D@:7,@=6YL:6ME;'DN"B`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A
M9"@D:60L("1G<F]U<"D["@H@("`@("`@(')E='5R;B!.54Q,.PH@("`@?2`O
M+R!E;F0@9G5N8R!S879E"@H@("`@+RHJ"B`@("`J(%)E;6]V97,@82!D871A
M<V5T+@H@("`@*B`*("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T87-E="!)
M1`H@("`@*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@("`@*B!`
M<F5T=7)N("`@8F]O;&5A;B`@"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@
M("H@0&%B<W1R86-T"B`@("`J+R`@("`@"B`@("!F=6YC=&EO;B!R96UO=F4H
M)&ED+"`D9W)O=7`I('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"1I
M9"P@)&=R;W5P*3L*("`@("`@("!R971U<FX@3E5,3#L*("`@('T@+R\@96YD
M(&9U;F,@<F5M;W9E"@H@("`@+RHJ"B`@("`J($9L=7-H97,@=&AE(&-A8VAE
M("T@<F5M;W9E<R!A;&P@8V%C:&5S(&1A=&%S971S(&9R;VT@=&AE(&-A8VAE
M+@H@("`@*B`*("`@("H@0'!A<F%M("`@('-T<FEN9R`@("`@($EF(&$@8V%C
M:&4@9W)O=7`@:7,@9VEV96X@;VYL>2!T:&4@9W)O=7`@=VEL;"!B92!F;'5S
M:&5D"B`@("`J($!R971U<FX@("!I;G1E9V5R("`@("!.=6UB97(@;V8@<F5M
M;W9E9"!D871A<V5T<RP@+3$@;VX@9F%I;'5R90H@("`@*B!`86-C97-S("`@
M<'5B;&EC"B`@("`J($!A8G-T<F%C=`H@("`@*B\*("`@(&9U;F-T:6]N(&9L
M=7-H*"1G<F]U<"D@>PH@("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H*3L*
M("`@("`@("!R971U<FX@3E5,3#L*("`@('T@+R\@96YD(&9U;F,@9FQU<V@*
M"B`@("`O*BH*("`@("H@0VAE8VMS(&EF(&$@9&%T87-E="!E>&ES=',N"B`@
M("`J(`H@("`@*B!`<&%R86T@("`@<W1R:6YG("!D871A<V5T($E$"B`@("`J
M($!P87)A;2`@("!S=')I;F<@(&-A8VAE(&=R;W5P"B`@("`J($!R971U<FX@
M("!B;V]L96%N(`H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J($!A8G-T
M<F%C=`H@("`@*B\*("`@(&9U;F-T:6]N(&ED17AI<W1S*"1I9"P@)&=R;W5P
M*2!["B`@("`@("`@<F5T=7)N($Y53$P["B`@("!]("\O(&5N9"!F=6YC(&ED
M17AI<W1S"@H@("`@+RHJ"B`@("`J(%-T87)T<R!T:&4@9V%R8F%G92!C;VQL
M96-T:6]N+@H@("`@*B`*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B!`
M86)S=')A8W0*("`@("HO"B`@("!F=6YC=&EO;B!G87)B86=E0V]L;&5C=&EO
M;B@I('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"D["B`@("!]("\O
M(&5N9"!F=6YC(&=A<F)A9V5#;VQL96-T:6]N"@H@("`@+RHJ"B`@("`J($1O
M97,@82!S<&5C=6QA=&EV92!P<F5L;V%D(&]F(&$@9&%T87-E=`H@("`@*@H@
M("`@*B!`<&%R86T@("`@<W1R:6YG("!D871A<V5T($E$"B`@("`J($!P87)A
M;2`@("!S=')I;F<@(&-A8VAE(&=R;W5P"B`@("`J($!R971U<FX@("!B;V]L
M96%N"B`@("`J+R`*("`@(&9U;F-T:6]N('!R96QO860H)&ED+"`D9W)O=7`I
M('L*("`@("`@("`O+R!W:&%T979E<B!H87!P96YS+"!R96UE;6)E<B!T:&4@
M<')E;&]A9&5D($E$"B`@("`@("`@)'1H:7,M/FED(#T@)&ED.PH@("`@("`@
M("1T:&ES+3YG<F]U<"`]("1G<F]U<#L@("`@("`@(`H*("`@("`@("!L:7-T
M*"1T:&ES+3YE>'!I<F5S+"`D=&AI<RT^8V%C:&5D871A+"`D=&AI<RT^=7-E
M<F1A=&$I(#T@)'1H:7,M/F9E=&-H*"1I9"P@)&=R;W5P*3L*"B`@("`@("`@
M:68@*$Y53$P@/3T]("1T:&ES+3YE>'!I<F5S*2!["B`@("`@("`@("`@("\O
M(%5U=7!S+"!U;FMN;W=N($E$"B`@("`@("`@("`@("1T:&ES+3YF;'5S:%!R
M96QO860H*3L*"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3YU;FMN;W=N(#T@9F%L<V4["@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?2`O+R!E;F0@9G5N8R!P<F5L;V%D"@H@("`@+RHJ
M"B`@("`J($9L=7-H97,@=&AE(&EN=&5R;F%L('!R96QO860@8G5F9F5R+@H@
M("`@*@H@("`@*B!S879E*"DL(')E;6]V92@I(&%N9"!F;'5S:"@I(&UU<W0@
M8V%L;"!T:&ES(&UE=&AO9`H@("`@*B!T;R!P<F5E=F5N="!D:69F97)E;F-E
M<R!B971W965N('1H92!P<F5L;V%D960@=F%L=65S(&%N9"`*("`@("H@=&AE
M(')E86P@8V%C:&4@8V]N=&5N=',N"B`@("`J"B`@("`J($!P87)A;2`@("!S
M=')I;F<@(&1A=&%S970@240L(&EF(&QE9G0@;W5T('1H92!P<F5L;V%D960@
M=F%L=65S('=I;&P@8F4@9FQU<VAE9"X@"B`@("`J("`@("`@("`@("`@("`@
M("`@($EF(&=I=F5N('1H92!P<F5L;V%D960@=F%L=65S('=I;&P@;VYL>2!B
M92!F;'5S:&5D(&EF('1H97D@87)E"B`@("`J("`@("`@("`@("`@("`@("`@
M(&5Q=6%L('1O('1H92!G:79E;B!I9"!A;F0@9W)O=7`*("`@("H@0'!A<F%M
M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@("H@0'-E92`@<')E;&]A9"@I
M"B`@("`J+PH@("`@9G5N8W1I;VX@9FQU<VA0<F5L;V%D*"1I9"`]("<G+"`D
M9W)O=7`@/2`G9&5F875L="<I('L*("`@("`@("!I9B`H(21I9"!\?"`H)'1H
M:7,M/FED(#T]("1I9"`F)B`D=&AI<RT^9W)O=7`@/3T@)&=R;W5P*2D@>PH@
M("`@("`@("`@("`O+R!C;&5A<B!T:&4@:6YT97)N86P@<')E;&]A9"!V86QU
M97,*("`@("`@("`@("`@)'1H:7,M/FED(#T@)R<["B`@("`@("`@("`@("1T
M:&ES+3YG<F]U<"`]("<G.PH@("`@("`@("`@("`D=&AI<RT^8V%C:&5D871A
M(#T@)R<["B`@("`@("`@("`@("1T:&ES+3YU<V5R9&%T82`]("<G.PH@("`@
M("`@("`@("`D=&AI<RT^97AP:7)E<R`]("TQ.PH@("`@("`@("`@("`D=&AI
M<RT^=6YK;F]W;B`]('1R=64["B`@("`@("`@?0H@("`@?2`O+R!E;F0@9G5N
M8R!F;'5S:%!R96QO860*"B`@("`O*BH*("`@("H@26UP;W)T<R!T:&4@<F5Q
M=65S=&5D(&1A=&%F:65L9',@87,@;V)J96-T('9A<FEA8FQE<R!I9B!A;&QO
M=V5D"B`@("`J(`H@("`@*B!`<&%R86T@("`@87)R87D@("!,:7-T(&]F(&9I
M96QD<R!T;R!B92!I;7!O<G1E9"!A<R!O8FIE8W0@=F%R:6%B;&5S"B`@("`J
M($!P87)A;2`@("!A<G)A>2`@($QI<W0@;V8@86QL;W=E9"!D871A9FEE;&1S
M"B`@("`J+PH@("`@9G5N8W1I;VX@<V5T3W!T:6]N<R@D<F5Q=65S=&5D+"`D
M86QL;W=E9"D@>PH@("`@("`@(&9O<F5A8V@@*"1A;&QO=V5D(&%S("1K(#T^
M("1F:65L9"D*("`@("`@("`@("`@:68@*&ES<V5T*"1R97%U97-T961;)&9I
M96QD72DI"B`@("`@("`@("`@("`@("`D=&AI<RT^)&9I96QD(#T@)')E<75E
M<W1E9%LD9FEE;&1=.PH@("`@("`@("`@("`@("`@"B`@("!]("\O(&5N9"!F
M=6YC('-E=$]P=&EO;G,*"B`@("`O*BH*("`@("H@16YC;V1E<R!T:&4@9&%T
M82!F;W(@=&AE('-T;W)A9V4@8V]N=&%I;F5R+@H@("`@*B`*("`@("H@0'9A
M<B`@;6EX960@9&%T82!T;R!E;F-O9&4*("`@("HO"B`@("!F=6YC=&EO;B!E
M;F-O9&4H)&1A=&$I('L*("`@("`@("!I9B`H)V)A<V4V-"<@/3T@)'1H:7,M
M/F5N8V]D:6YG7VUO9&4I(`H@("`@("`@("`@("!R971U<FX@8F%S938T7V5N
M8V]D92AS97)I86QI>F4H)&1A=&$I*3L*("`@("`@("!E;'-E(`H@("`@("`@
M("`@("!R971U<FX@<V5R:6%L:7IE*"1D871A*3L*("`@('T@+R\@96YD(&9U
M;F,@96YC;V1E"@H@("`@"B`@("`O*BH*("`@("H@1&5C;V1E<R!T:&4@9&%T
M82!F<F]M('1H92!S=&]R86=E(&-O;G1A:6YE<BX*("`@("H@"B`@("`J($!V
M87(@(&UI>&5D"B`@("`J+PH@("`@9G5N8W1I;VX@9&5C;V1E*"1D871A*2![
M"B`@("`@("`@:68@*"=B87-E-C0G(#T]("1T:&ES+3YE;F-O9&EN9U]M;V1E
M*0H@("`@("`@("`@("!R971U<FX@=6YS97)I86QI>F4H8F%S938T7V1E8V]D
M92@D9&%T82DI.PH@("`@("`@(&5L<V4*("`@("`@("`@("`@<F5T=7)N('5N
M<V5R:6%L:7IE*"1D871A*3L*("`@('T@+R\@96YD(&9U;F,@9&5C;V1E"@H@
M("`@"B`@("`O*BH*("`@("H@5')A;G-L871E<R!H=6UA;B!R96%D86)L92]R
M96QA=&EV92!T:6UE<R!I;B!U;FEX=&EM90H@("`@*@H@("`@*B!`<&%R86T@
M(&UI>&5D("`@8V%N(&)E(&EN('1H92!F;VQL;W=I;F<@9F]R;6%T<SH*("`@
M("H@("`@("`@("`@("`@("!H=6UA;B!R96%D86)L92`@("`@("`@("`Z('EY
M>7EM;61D:&AM;5MS<UU=(&5G.B`R,#`Q,#,P.#`Y-3$P,`H@("`@*B`@("`@
M("`@("`@("`@(')E;&%T:79E(&EN('-E8V]N9',@*#$I(#H@*WAX("`@("`@
M("`@("`@("!E9SH@*S$P"B`@("`J("`@("`@("`@("`@("`@<F5L871I=F4@
M:6X@<V5C;VYD<R`H,BD@.B!X(#P@(#DT-C8X,3(P,"`@(&5G.B`Q,`H@("`@
M*B`@("`@("`@("`@("`@(&%B<V]L=71E('5N:7AT:6UE("`@("`@(#H@>"`\
M(#(Q-#<T.#,V-#@@("!E9SH@,C$T-S0X,S8T.`H@("`@*B`@("`@("`@("`@
M("`@('-E92!C;VUM96YT<R!I;B!C;V1E(&9O<B!D971A:6QS"B`@("`J($!R
M971U<FX@:6YT96=E<B!U;FEX('1I;65S=&%M<`H@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$5X<&ER97-!8G-O;'5T92@D97AP:7)E<RD*("`@('L*("`@("`@
M("!I9B`H(21E>'!I<F5S*0H@("`@("`@("`@("!R971U<FX@,#L*("`@("`@
M("`O+V9O<B!A<&DM8V]M<&%T:6)I;&ET>2P@;VYE(&AA<R!N;W0@=&\@<')O
M=FED92!A("(K(BP*("`@("`@("`O+R!I9B!I;G1E9V5R(&ES(#P@.30V-C@Q
M,C`P("@]($IA;B`P,2`R,#`P(#`P.C`P.C`P*0H@("`@("`@(&EF("@G*R<@
M/3T@)&5X<&ER97-;,%T@?'P@)&5X<&ER97,@/"`Y-#8V.#$R,#`I"B`@("`@
M("`@>PH@("`@("`@("`@("!R971U<FXH=&EM92@I("L@)&5X<&ER97,I.PH@
M("`@("`@('T*("`@("`@("`O+VEF(&EN=&5G97(@:7,@/"`Q,#`P,#`P,#`P
M,#`@*#T@:6X@,S$T,"!Y96%R<RDL"B`@("`@("`@+R\@:70@;75S="!B92!A
M;B!A8G-O;'5T('5N:7AT:6UE"B`@("`@("`@+R\@*'-I;F-E('1H92`B:'5M
M86X@<F5A9&%B;&4B(&1E9FEN:71I;VX@87-K<R!F;W(@82!H:6=H97(@;G5M
M8F5R*0H@("`@("`@(&5L<V5I9B`H)&5X<&ER97,@/"`Q,#`P,#`P,#`P,#`I
M"B`@("`@("`@>PH@("`@("`@("`@("!R971U<FX@)&5X<&ER97,["B`@("`@
M("`@?0H@("`@("`@("\O(&5L<V4@:70G<R`B:'5M86X@<F5A9&%B;&4B.PH@
M("`@("`@(&5L<V4*("`@("`@("!["B`@("`@("`@("`@("1Y96%R(#T@<W5B
M<W1R*"1E>'!I<F5S+"`P+"`T*3L*("`@("`@("`@("`@)&UO;G1H(#T@<W5B
M<W1R*"1E>'!I<F5S+"`T+"`R*3L*("`@("`@("`@("`@)&1A>2`]('-U8G-T
M<B@D97AP:7)E<RP@-BP@,BD["B`@("`@("`@("`@("1H;W5R(#T@<W5B<W1R
M*"1E>'!I<F5S+"`X+"`R*3L*("`@("`@("`@("`@)&UI;G5T92`]('-U8G-T
M<B@D97AP:7)E<RP@,3`L(#(I.PH@("`@("`@("`@("`D<V5C;VYD(#T@<W5B
M<W1R*"1E>'!I<F5S+"`Q,BP@,BD["B`@("`@("`@("`@(')E='5R;B!M:W1I
M;64H)&AO=7(L("1M:6YU=&4L("1S96-O;F0L("1M;VYT:"P@)&1A>2P@)'EE
M87(I.PH@("`@("`@('T*("`@("`@("`*("`@('T@+R\@96YD(&9U;F,@9V5T
M17AP:7)E06)S;VQU=&4*("`@(`I]("\O(&5N9"!C;&%S<R!#;VYT86EN97(*
M/SX*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O0V%C:&4O17)R;W(N<&AP````````
M````````````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,T-3,`,3`U,34T
M,S,W,S0`,#(Q-#$V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\(%!%05(@.CH@0V%C:&4@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P
M,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES
M('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`@;V8@=&AE
M(%!(4"!L:6-E;G-E+"`@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I
M=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@
M("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@
M<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@
M?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I
M;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%5L9B!796YD96P@/'5L9BYW
M96YD96Q`<&AP9&]C+F1E/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@17)R
M;W(N<&AP+'8@,2XS(#(P,#,O,#$O,#0@,3$Z-30Z-#4@;6H@17AP("0*"G)E
M<75I<F5?;VYC92`G4$5!4BYP:'`G.PH*+RHJ"BH@0V%C:&4@17)R;W(@8VQA
M<W,**B`**B!`<&%C:V%G92!#86-H90HJ+PIC;&%S<R!#86-H95]%<G)O<B!E
M>'1E;F1S(%!%05)?17)R;W(@>PH*"B`@+RHJ"B`@*B!0<F5F:7@@;V8@86QL
M(&5R<F]R(&UE<W-A9V5S+@H@("H@"B`@*B!`=F%R("!S=')I;F<*("`J+PH@
M('9A<B`D97)R;W)?;65S<V%G95]P<F5F:7@@/2`G0V%C:&4M17)R;W(Z("<[
M"B`@"B`@+RHJ"B`@*B!#<F5A=&5S(&%N(&-A8VAE(&5R<F]R(&]B:F5C="X*
M("`J(`H@("H@0'!A<F%M("!S=')I;F<@(&5R<F]R(&UE<W-A9V4*("`J($!P
M87)A;2`@<W1R:6YG("!F:6QE('=H97)E('1H92!E<G)O<B!O8V-U<F5D"B`@
M*B!`<&%R86T@('-T<FEN9R`@;&EN96YU;6)E<B!W:&5R92!T:&4@97)R;W(@
M;V-C=7)E9`H@("HO"B`@9G5N8W1I;VX@0V%C:&5?17)R;W(H)&US9RP@)&9I
M;&4@/2!?7T9)3$5?7RP@)&QI;F4@/2!?7TQ)3D5?7RD@>PH@("`@"B`@("`D
M=&AI<RT^4$5!4E]%<G)O<BAS<')I;G1F*"(E<R!;)7,@;VX@;&EN92`E9%TN
M(BP@)&US9RP@)&9I;&4L("1L:6YE*2D["B`@("`*("!]("\O(&5N9"!F=6YC
M($-A8VAE7T5R<F]R"B`@"GT@+R\@96YD(&-L87-S($-A8VAE7T5R<F]R"C\^
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+T-A8VAE+T9U;F-T:6]N+G!H<```````````
M`````````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q,#<U`#$P-3$U-#,S-S,T
M`#`R,C$Q,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!014%2(#HZ($-A8VAE("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H
M92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@
M;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H
M:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@
M('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T
M;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I
M871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!396)A<W1I86X@0F5R9VUA;FX@/'-B
M0'-E8F%S=&EA;BUB97)G;6%N;BYD93X@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z($9U;F-T:6]N
M+G!H<"QV(#$N-B`R,#`S+S`Q+S`T(#$Q.C4T.C0U(&UJ($5X<"`D"@IR97%U
M:7)E7V]N8V4@)T-A8VAE+G!H<"<["@HO*BH**B!&=6YC=&EO;E]#86-H90HJ
M"BH@4'5R<&]S93H**@HJ("`@0V%C:&EN9R!T:&4@<F5S=6QT(&%N9"!O=71P
M=70@;V8@9G5N8W1I;VYS+@HJ"BH@17AA;7!L93H**@HJ("`@<F5Q=6ER95]O
M;F-E("=#86-H92]&=6YC=&EO;BYP:'`G.PHJ"BH@("!C;&%S<R!F;V\@>PHJ
M("`@("!F=6YC=&EO;B!B87(H)'1E<W0I('L**B`@("`@("!E8VAO(")F;V\Z
M.F)A<B@D=&5S="D\8G(^(CL**B`@("`@?0HJ("`@?0HJ"BH@("!C;&%S<R!B
M87(@>PHJ("`@("!F=6YC=&EO;B!F;V]B87(H)&]B:F5C="D@>PHJ("`@("`@
M(&5C:&\@)R0G+B1O8FIE8W0N)RT^9F]O8F%R*"<N)&]B:F5C="XG*3QB<CXG
M.PHJ("`@("!]"BH@("!]"BH**B`@("1B87(@/2!N97<@8F%R.PHJ"BH@("!F
M=6YC=&EO;B!F;V]B87(H*2!["BH@("`@(&5C:&\@)V9O;V)A<B@I)SL**B`@
M('T**@HJ("`@)&-A8VAE(#T@;F5W($-A8VAE7T9U;F-T:6]N*"D["BH**B`@
M("1C86-H92T^8V%L;"@G9F]O.CIB87(G+"`G=&5S="<I.PHJ("`@)&-A8VAE
M+3YC86QL*"=B87(M/F9O;V)A<B<L("=B87(G*3L**B`@("1C86-H92T^8V%L
M;"@G9F]O8F%R)RD["BH**B!.;W1E.@HJ(`HJ("`@66]U(&-A;FYO="!C86-H
M92!E=F5R>2!F=6YC=&EO;BX@66]U('-H;W5L9"!O;FQY(&-A8VAE(`HJ("`@
M9G5N8W1I;VYS('1H870@;VYL>2!D97!E;F0@;VX@=&AE:7(@87)G=6UE;G1S
M(&%N9"!D;VXG="!U<V4**B`@(&=L;V)A;"!O<B!S=&%T:6,@=F%R:6%B;&5S
M+"!D;VXG="!R96QY(&]N(&1A=&%B87-E('%U97)I97,@;W(@"BH@("!F:6QE
M<RP@86YD('-O(&]N+@HJ(`HJ($!A=71H;W(@("`@("`@4V5B87-T:6%N($)E
M<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"BH@0&UO9'5L92`@
M("`@("!&=6YC=&EO;E]#86-H90HJ($!M;V1U;&5G<F]U<"`@1G5N8W1I;VY?
M0V%C:&4**B!`<&%C:V%G92`@("`@($-A8VAE"BH@0'9E<G-I;VX@("`@("`D
M4F5V:7-I;VXZ(#$N-B`D"BH@0&%C8V5S<R`@("`@("!P=6)L:6,**B\*8VQA
M<W,@0V%C:&5?1G5N8W1I;VX@97AT96YD<R!#86-H92!["B`@("!V87(@)&5X
M<&ER97,["@H@("`@+RHJ"B`@("`J($-O;G-T<G5C=&]R"B`@("`J"B`@("`J
M($!P87)A;2`@("!S=')I;F<@($YA;64@;V8@8V]N=&%I;F5R(&-L87-S"B`@
M("`J($!P87)A;2`@("!A<G)A>2`@($%R<F%Y('=I=&@@8V]N=&%I;F5R(&-L
M87-S(&]P=&EO;G,*("`@("H@0'!A<F%M("`@(&EN=&5G97(@3G5M8F5R(&]F
M('-E8V]N9',@9F]R('=H:6-H('1O(&-A8VAE"B`@("`J+PH@("`@9G5N8W1I
M;VX@0V%C:&5?1G5N8W1I;VXH)&-O;G1A:6YE<B`@/2`G9FEL92<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D8V]N=&%I;F5R7V]P=&EO;G,@/2!A
M<G)A>2@G8V%C:&5?9&ER)R`@("`@("`]/B`G+B<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9FEL
M96YA;65?<')E9FEX)R`]/B`G8V%C:&5?)PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&5X<&ER97,@/2`S-C`P"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("D*("`@('L*("`@("`@)'1H:7,M/D-A8VAE
M*"1C;VYT86EN97(L("1C;VYT86EN97)?;W!T:6]N<RD["B`@("`@("1T:&ES
M+3YE>'!I<F5S(#T@)&5X<&ER97,[("`@("`@"B`@("!]"@H@("`@+RHJ"B`@
M("`J(%!%05(M1&5C;VYS=')U8W1O<@H@("`@*B!#86QL(&1E8V]N<W1R=6-T
M;W(@;V8@<&%R96YT"B`@("`J+PH@("`@9G5N8W1I;VX@7T-A8VAE7T9U;F-T
M:6]N*"D@>PH@("`@("`@("1T:&ES+3Y?0V%C:&4H*3L*("`@('T*"B`@("`O
M*BH*("`@("H@0V%L;',@82!C86-H96%B;&4@9G5N8W1I;VX@;W(@;65T:&]D
M+@H@("`@*@H@("`@*B!`<F5T=7)N(&UI>&5D("1R97-U;'0*("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!C86QL*"D@>PH@("`@
M("`@("\O(&=E="!A<F=U;65N=',*("`@("`@("`D87)G=6UE;G1S(#T@9G5N
M8U]G971?87)G<R@I.PH*("`@("`@("`O+R!G96YE<F%T92!C86-H92!I9`H@
M("`@("`@("1I9"`](&UD-2AS97)I86QI>F4H)&%R9W5M96YT<RDI.PH*("`@
M("`@("`O+R!Q=65R>2!C86-H90H@("`@("`@("1C86-H961?;V)J96-T(#T@
M)'1H:7,M/F=E="@D:60L("=F=6YC=&EO;E]C86-H92<I.PH*("`@("`@("!I
M9B`H)&-A8VAE9%]O8FIE8W0@(3T@3E5,3"D@>PH@("`@("`@("`@("`O+R!C
M86-H92!H:70Z(')E='5R;B!C86-H960@;W5T<'5T(&%N9"!R97-U;'0*"B`@
M("`@("`@("`@("1O=71P=70@/2`D8V%C:&5D7V]B:F5C=%LP73L*("`@("`@
M("`@("`@)')E<W5L="`]("1C86-H961?;V)J96-T6S%=.PH*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`O+R!C86-H92!M:7-S.B!C86QL(&9U;F-T
M:6]N+"!S=&]R92!O=71P=70@86YD(')E<W5L="!I;B!C86-H90H*("`@("`@
M("`@("`@;V)?<W1A<G0H*3L*("`@("`@("`@("`@)'1A<F=E="`](&%R<F%Y
M7W-H:69T*"1A<F=U;65N=',I.PH*("`@("`@("`@("`@+R\@8VQA<W-N86UE
M.CIS=&%T:6--971H;V0*("`@("`@("`@("`@:68@*'-T<G-T<B@D=&%R9V5T
M+"`G.CHG*2D@>PH@("`@("`@("`@("`@("`@;&ES="@D8VQA<W,L("1M971H
M;V0I(#T@97AP;&]D92@G.CHG+"`D=&%R9V5T*3L*"B`@("`@("`@("`@("`@
M("`D<F5S=6QT(#T@8V%L;%]U<V5R7V9U;F-?87)R87DH87)R87DH)&-L87-S
M+"`D;65T:&]D*2P@)&%R9W5M96YT<RD["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("\O(&]B:F5C="T^;65T:&]D"B`@("`@("`@("`@(&5L<V5I9B`H
M<W1R<W1R*"1T87)G970L("<M/B<I*2!["B`@("`@("`@("`@("`@("!L:7-T
M*"1O8FIE8W0L("1M971H;V0I(#T@97AP;&]D92@G+3XG+"`D=&%R9V5T*3L*
M("`@("`@("`@("`@("`@(&=L;V)A;"`D)&]B:F5C=#L*"B`@("`@("`@("`@
M("`@("`D<F5S=6QT(#T@8V%L;%]U<V5R7V9U;F-?87)R87DH87)R87DH)"1O
M8FIE8W0L("1M971H;V0I+"`D87)G=6UE;G1S*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@+R\@9G5N8W1I;VX*("`@("`@("`@("`@96QS92!["B`@
M("`@("`@("`@("`@("`D<F5S=6QT(#T@8V%L;%]U<V5R7V9U;F-?87)R87DH
M)'1A<F=E="P@)&%R9W5M96YT<RD["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1O=71P=70@/2!O8E]G971?8V]N=&5N=',H*3L*("`@("`@("`@("`@
M;V)?96YD7V-L96%N*"D["@H@("`@("`@("`@("`D=&AI<RT^<V%V92@D:60L
M(&%R<F%Y*"1O=71P=70L("1R97-U;'0I+"`D=&AI<RT^97AP:7)E<RP@)V9U
M;F-T:6]N7V-A8VAE)RD["B`@("`@("`@?0H*("`@("`@("!E8VAO("1O=71P
M=70["B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"GT*/SX*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]#86-H92]'<F%P:&EC<RYP:'``
M````````````````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S,#4W,``Q,#4Q
M-30S,S<S-``P,C(P-C4`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@4$5!4B`Z.B!#86-H92`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M
M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T
M:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@
M=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES
M("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO
M="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U
M;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO
M+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y
M(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@56QF(%=E;F1E;"`\=6QF
M+G=E;F1E;$!P:'!D;V,N9&4^("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!'
M<F%P:&EC<RYP:'`L=B`Q+C4@,C`P,R\P,2\P-"`Q,3HU-#HT-2!M:B!%>'`@
M)`H*<F5Q=6ER95]O;F-E("=#86-H92YP:'`G.PH*+RHJ"BH@1W)A<&AI8W,@
M9&ES:R!C86-H92X**B`**B!4:&4@=7-U86P@=V%Y('1O(&-R96%T92!I;6%G
M97,@:7,@=&\@<&%S<R!S;VUE(&%R9W5M96YT<R!T:&%T(&1E<V-R:6)E('1H
M92!I;6%G92`**B!T;R!A('-C<FEP="!T:&%T(&1Y;F%M:6-A;&QY(&-R96%T
M97,@86X@:6UA9V4N($9O<B!E=F5R>2!I;6%G92!O9B!A('!A9V4@"BH@82!N
M97<@4$A0(&EN=&5R<')E=&5R(&=E=',@<W1A<G1E9"X@5&AI<R!I<R!A(&=O
M;V0@=V%Y('1O(&MI;&P@>6]U<B!W96)S97)V97(N"BH@"BH@5VAE;B!D96%L
M:6YG('=I=&@@9'EN86UI8V%L;'D@9V5N97)A=&5D(&EM86=E<R!Y;W4@<VAO
M=6QD(&YO="!C86QL(&%N;W1H97(@<V-R:7!T(`HJ('1O(&=E;F5R871E('1H
M92!I;6%G97,@8G5T(&=E;F5R871E('1H92!I;6%G97,@8GD@=&AE('-C<FEP
M="!T:&%T('!R;V1U8V5S('1H92!P86=E"BH@=&AA="!C;VYT86EN<R!T:&4@
M:6UA9V5S+B!4:&ES(&ES(&$@;6%J;W(@:6UP<F]V96UE;G0@8G5T(&ET)W,@
M;VYL>2!H86QF('1H92!W87DN"BH@"BH@5&AE<F4G<R!N;R!N965D('1O(')E
M<F5N9&5R(&%N(&EM86=E(&]N(&5V97)Y(')E<75E<W0N($$@<VEM<&QE(&1I
M<VL@8V%C:&4@8V%N(')E9'5C90HJ('1H92!C;VUP=71A=&EO;B!T:6UE(&1R
M86UA=&EC86QL>2X@5&AI<R!I<R!W:&%T('1H92!C;&%S<R!G<F%P:&EC<U]C
M86-H92!I<R!F;W(N(`HJ(`HJ(%5S86=E.@HJ(`HJ("\O(&-R96%T92!A;B!I
M;G-T86YC92!O9B!T:&4@9W)A<&AI8W,@8V%C:&4**B`D8V%C:&4@/2!N97<@
M9W)A<&AI8W-?8V%C:&4["BH**B`D:6UG(#T@26UA9V5#<F5A=&4H+BXN*3L*
M*@HJ("\O(&-O;7!U=&4@86X@240@9F]R('EO=7(@:6UA9V4@8F%S960@;VX@
M='EP:6-A;"!P87)A;65T97)S"BH@)&ED(#T@;35D*"`D<VEZ92P@)&-O;&]R
M<RP@)&QA8F5L*3L**B`**B`O+R!C:&5C:R!I9B!I="=S(&-A8VAE9`HJ(&EF
M("@A*"1L:6YK(#T@)&-A8VAE+3YG971);6%G94QI;FLH)&ED+"`G9VEF)RDI
M*2!["BH@(`HJ("`@+R\@:&UM;2P@:70G<R!N;W0@8V%C:&5D+"!C<F5A=&4@
M:70**B`@("XN+@HJ("`@+R\@8V%C:&5);6%G94QI;FLH*2!A;F0@8V%C:&5)
M;6%G92@I(&UA:V4@=&AE($EM86=E1TE&*"D@8V%L;"$**B`@("\O(&-A8VAE
M26UA9V4H*2!R971U<FYS('1H92!V86QU92!O9B!);6%G94=)1B@I(%ME=&,N
M72P@8V%C:&5);6%G94QI;FLH*2!R971U<FYS(&$@55),"BH@("`D;&EN:R`]
M("1C86-H92T^8V%C:&5);6%G94QI;FLH)&ED+"`D:6UG+"`G9VEF)RD["BH@
M"BH@?0HJ"BH@+R\@3VLL(&QE="=S(&)U:6QD('1H92!);6%G94QI;FL**B`D
M<VEZ92`](&=E=$EM86=E4VEZ92@D;&EN:ULP72D["BH@<')I;G1F*"<\:6UG
M('-R8STB)7,B("5S/B<L("1L:6YK6S%=+"`D<VEZ95LS72D["BH**B`O+R!F
M;W(@8V%C:&5);6%G92@I.@HJ("\O(&AE861E<B@G0V]N=&5N="UT>7!E.B!I
M;6%G92]G:68G*3L@<')I;G0@)&-A8VAE+3YC86-H94EM86=E*"1I9"P@)&EM
M9RP@)V=I9B<I.PHJ(`HJ"BH@5&AE(&-L87-S(')E<75I<F5S(%!(4"`T+C`N
M,BL@6TEM86=E5'EP92@I72X@3F]T92!T:&%T(&-A8VAE26UA9V4H*2!W;W)K
M<R!W:71H"BH@=&AE(&]U='!U="!B=69F97(N($UO9&EF>2!I="!I9B!R97%U
M:7)E9"$**@HJ($!A=71H;W(@("!5;&8@5V5N9&5L(#QU;&8N=V5N9&5L0'!H
M<&1O8RYD93X**B!`=F5R<VEO;B`@)$ED.B!'<F%P:&EC<RYP:'`L=B`Q+C4@
M,C`P,R\P,2\P-"`Q,3HU-#HT-2!M:B!%>'`@)`HJ($!P86-K86=E("!#86-H
M90HJ+PIC;&%S<R!#86-H95]'<F%P:&EC<R!E>'1E;F1S($-A8VAE('L*"@H@
M("`@+RHJ"B`@("`J($-A8VAE(%523"!P<F5F:7@N"B`@("`J(`H@("`@*B!-
M86ME('-U<F4@=&AA="!T:&4@8V%C:&4@55),('!R969I>"!P;VEN=',@=&\@
M=&AE("1C86-H95]D:7(L(&]T:&5R=VES90H@("`@*B!Y;W5R(&QI;FMS('=I
M;&P@8F4@8G)O:V5N+B!5<V4@<V5T0V%C:&554DP@=&\@<W!E8VEF>2!T:&4@
M8V%C:&5?=7)L(&%N9"`*("`@("H@<V5T0V%C:&5$:7(H*2!F;W(@=&AE(&-A
M8VAE7V1I<BX*("`@("H@"B`@("`J($!V87(@('-T<FEN9PH@("`@*B!`<V5E
M("!S971#86-H95523"@I+"!S971#86-H941I<B@I"B`@("`J+PH@("`@=F%R
M("1C86-H95]U<FP@/2`G)SL*"B`@("`O*BH*("`@("H@1&ER96-T;W)Y('=H
M97)E(&-A8VAE9"!F:6QE<R!G970@<W1O<F5D+@H@("`@*B!S"B`@("`J($UA
M:V4@<W5R92!T:&%T('1H92!C86-H95]D:7(@:7,@=W)I=&%B;&4@86YD(&]F
M9F5R<R!E;F]U9V@@<W!A8V4N($-H96-K(`H@("`@*B!A;'-O(&EF('EO=7(@
M8V%C:&5?=7)L('!O:6YT<R!T;R!T:&4@9&ER96-T;W)Y+B!5<V4@<V5T0V%C
M:&5$:7(H*2!T;R!S970*("`@("H@=&AE('9A<FEA8FQE+@H@("`@*B`*("`@
M("H@0'9A<B`@<W1R:6YG"B`@("`J($!S964@('-E=$-A8VAE1&ER*"DL('-E
M=$-A8VAE55),*"D*("`@("HO"B`@("!V87(@)&-A8VAE7V1I<B`]("<G.PH*
M("`@("\J*@H@("`@*B!.86UE<')E9FEX(&]F(&-A8VAE9"!F:6QE<RX*("`@
M("H@"B`@("`J(%!E<B!D969A=6QT('1H92!P<F5F:7@@(F=R87!H:6-S7R(@
M9V5T<R!U<V5D+B!9;W4@;6EG:'0@=7-E('1H:7,@"B`@("`J(&9O<B!V97)S
M:6]N:6YG(&]R('1O(&5A<V4@*&UA;G5A;"D@8VQE86X@=7!S+@H@("`@*@H@
M("`@*B!`=F%R("`@("`@<W1R:6YG"B`@("`J+PH@("`@=F%R("1C86-H95]F
M:6QE7W!R969I>"`]("=G<F%P:&EC<U\G.PH@("`@"B`@("`*("`@("\J*@H@
M("`@*B!#86-H92!C;VYT86EN97(@9W)O=7`N"B`@("`J"B`@("`J($!V87(@
M("`@("!S=')I;F<*("`@("HO"B`@("!V87(@)&-A8VAE7V=R;W5P(#T@)V=R
M87!H:6-S)SL*"B`@("`*("`@("\J*@H@("`@*B!-87!P:6YG(&9R;VT@<W5P
M<&]R=&5D(&EM86=E('1Y<&4@=&\@82!);6%G951Y<&4H*2!C;VYS=&%N="X*
M("`@("H@"B`@("`J(%)E9F5R<B!T;R!T:&4@4$A0(&UA;G5A;"!F;W(@;6]R
M92!I;F9O<FUA=&EO;G,@;VX@26UA9V54>7!E*"D*("`@("H@"B`@("`J($!V
M87(@(&%R<F%Y"B`@("`J($!L:6YK(&AT='`Z+R]W=W<N<&AP+FYE="]);6%G
M951Y<&4*("`@("HO"B`@("!V87(@)&EM86=E='EP97,@/2!A<G)A>2@*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9VEF)R`@(#T^($E-1U]'
M248L(`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=J<&<G("`@
M/3X@24U'7TI01RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<&YG)R`@(#T^($E-1U]03D<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W=B;7`G("`]/B!)34=?5T)-4`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@*3L*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`*("`@
M("\J*@H@("`@*B!);G-T86YT:6%T97,@82!C86-H92!F:6QE(&-O;G1A:6YE
M<BX*("`@("H*("`@("HO"B`@("!F=6YC=&EO;B!#86-H95]'<F%P:&EC<R@I
M('L*("`@(`H@("`@("`@("1T:&ES+3Y#86-H92@G9FEL92<L(&%R<F%Y*"=C
M86-H95]D:7(G(#T^("1T:&ES+3YC86-H95]D:7(L("=F:6QE;F%M95]P<F5F
M:7@G(#T^("1T:&ES+3YC86-H95]F:6QE7W!R969I>"DI.PH@("`@("`@(`H@
M("`@?2`O+R!E;F0@8V]N<W1R=6-T;W(*"B`@("`*("`@("\J*@H@("`@*B!2
M971U<FYS('1H92!C;VYT96YT(&]F(&$@8V%C:&5D(&EM86=E(&9I;&4N"B`@
M("`J(`H@("`@*B!4:&ES(&9U;F-T:6]N(&-A;B!B92!U<V5D('1O('-E;F0@
M=&AE(&EM86=E(&1I<F5C=&QY('1O('1H92!B<F]W<V5R+@H@("`@*B!-86ME
M('-U<F4@=&AA="!Y;W4@<V5N9"!A(&-O<G)E<W!O;F1E;F1I;F<@:&5A9&5R
M(&)E9F]R92!S96YD:6YG('1H92!I;6%G92!I='-E;&8N"B`@("`J"B`@("`J
M($%L=V%Y<R!T<GD@=&\@9V5T('1H92!I;6%G92!F<F]M('1H92!C86-H92!B
M969O<F4@>6]U(&-O;7!U=&4@:70N(%-E92`*("`@("H@=&AE(&-L87-S(&1O
M8W,@9F]R(&%N(&5X86UP;&4N"B`@("`J"B`@("`J($!P87)A;2`@("!S=')I
M;F<@($EM86=E+4E$"B`@("`J($!P87)A;2`@("!S=')I;F<@($EM86=E('1Y
M<&4Z(&=I9BP@:G!G+"!P;F<L('=B;7`*("`@("H@0')E='5R;B`@('-T<FEN
M9R`@26UA9V4@9FEL92!C;VYT96YT<R!I9B!A(&-A8VAE9"!F:6QE(&5X:7-T
M<R!O=&AE<G=I<V4@86X@96UP='D@<W1R:6YG"B`@("`J($!S964@("`@("!C
M86-H94EM86=E*"D*("`@("HO("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@"B`@("!F=6YC=&EO;B!G971);6%G92@D:60L("1F;W)M870@
M/2`G<&YG)RD@>PH@("`@("`@("1I9"`]("1T:&ES+3YG96YE<F%T94E$*"1I
M9"P@)&9O<FUA="D["B`@("`@("`@"B`@("`@("`@<F5T=7)N("1T:&ES+3YG
M970H)&ED+"`D=&AI<RT^8V%C:&5?9W)O=7`I.PH@("`@?2`O+R!E;F0@9G5N
M8R!G971);6%G90H*("`@(`H@("`@+RHJ"B`@("`J(%)E='5R;G,@86X@87)R
M87D@=VET:"!A(&QI;FL@=&\@=&AE(&-A8VAE9"!I;6%G92!A;F0@=&AE(&EM
M86=E(&9I;&4@<&%T:"X*("`@("H@"B`@("`J($%L=V%Y<R!T<GD@=&\@9V5T
M('1H92!I;6%G92!F<F]M('1H92!C86-H92!B969O<F4@>6]U(&-O;7!U=&4@
M:70N(%-E92`*("`@("H@=&AE(&-L87-S(&1O8W,@9F]R(&%N(&5X86UP;&4N
M"B`@("`J"B`@("`J($!P87)A;2`@("!S=')I;F<@($EM86=E+4E$"B`@("`J
M($!P87)A;2`@("!S=')I;F<@($EM86=E('1Y<&4Z(&=I9BP@:G!G+"!P;F<L
M('=B;7`*("`@("H@0')E='5R;B`@(&%R<F%Y("`@6R!F=6QL('!A=&@@=&\@
M=&AE(&EM86=E(&9I;&4L(&EM86=E('5R;"!="B`@("`J($!T:')O=R`@("!#
M86-H95]%<G)O<@H@("`@*B!`<V5E("`@("`@8V%C:&5);6%G94QI;FLH*0H@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$EM86=E3&EN:R@D:60L("1F;W)M870@
M/2`G<&YG)RD@>PH@("`@("`@("1I9"`]("1T:&ES+3YG96YE<F%T94E$*"1I
M9"P@)&9O<FUA="D["B`@("`@("`@:68@*"$D=&AI<RT^8V]N=&%I;F5R+3YI
M9$5X:7-T<R@D:60L("1T:&ES+3YC86-H95]G<F]U<"DI(`H@("`@("`@("`@
M("!R971U<FX@87)R87DH*3L*"B`@("`@("`@)&9I;&4@/2`D=&AI<RT^8V%C
M:&5?=7)L("X@)'1H:7,M/F-A8VAE7V9I;&5?<')E9FEX("X@)&ED.PH*("`@
M("`@("!R971U<FX@87)R87DH)'1H:7,M/F-O;G1A:6YE<BT^9V5T1FEL96YA
M;64H)&ED+"`D=&AI<RT^8V%C:&5?9W)O=7`I+"`D9FEL92D["B`@("!]("\O
M(&5N9"!F=6YC(&=E=$EM86=E3&EN:PH@("`@"@H@("`@+RHJ"B`@("`J($-R
M96%T92!A;B!I;6%G92!F<F]M('1H92!G:79E;B!I;6%G92!H86YD;&5R+"!C
M86-H92!I="!A;F0@<F5T=7)N('1H92!F:6QE(&-O;G1E;G0N"B`@("`J"B`@
M("`J($%L=V%Y<R!T<GD@=&\@<F5T<FEV92!T:&4@:6UA9V4@9G)O;2!T:&4@
M8V%C:&4@8F5F;W)E('EO=2!C;VUP=71E(&ET+@H@("`@*B`*("`@("H@5V%R
M;FEN9SH@=&AI<R!F=6YC=&EO;B!U<V5S('1H92!O=71P=70@8G5F9F5R+B!)
M9B!Y;W4@97AP96-T(&-O;&QI<VEO;G,@"B`@("`J(&UO9&EF>2!T:&4@8V]D
M92X*("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN9R`@26UA9V4M240N(%5S
M960@87,@82!P87)T(&]F('1H92!C86-H92!F:6QE;F%M92X*("`@("H@("`@
M("`@("`@("`@("`@("`@57-E(&UD-2@I('1O(&=E;F5R871E(&$@(G5N:7%U
M92(@240@9F]R('EO=7(@:6UA9V4*("`@("H@("`@("`@("`@("`@("`@("`@
M8F%S960@;VX@8VAA<F%C=&5R:7-T:6,@=F%L=65S('-U8V@@87,@=&AE(&-O
M;&]R+"!S:7IE(&5T8RX*("`@("H@0'!A<F%M("`@('-T<FEN9R`@26UA9V4@
M:&%N9&QE<B!T;R!C<F5A=&4@=&AE(&EM86=E(&9R;VTN"B`@("`J($!P87)A
M;2`@("!S=')I;F<@($EM86=E('1Y<&4Z(&=I9BP@:G!G+"!P;F<L('=B;7`N
M($%L<V\@=7-E9"!A<R!F:6QE;F%M92!S=69F:7@N"B`@("`J("`@("`@("`@
M("`@("`@("`@($EF(&%N('5N<W5P<&]R=&5D('1Y<&4@:7,@<F5Q=65S=&5D
M('1H92!F=6YC=&EO;G,@=')I97,@=&\@"B`@("`J("`@("`@("`@("`@("`@
M("`@(&9A;&QB86-K('1O(&$@<W5P<&]R=&5D('1Y<&4@8F5F;W)E('1H<F]W
M:6YG(&%N(&5X97!T:6]N+@H@("`@*B!`<F5T=7)N("`@<W1R:6YG("!);6%G
M92!C;VYT96YT(')E='5R;F5D(&)Y($EM86=E1TE&+RXN+B`*("`@("H@0'1H
M<F]W<R`@($-A8VAE7T5R<F]R"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@
M("H@0'-E92`@("`@(&=E=$EM86=E*"D*("`@("HO"B`@("!F=6YC=&EO;B!C
M86-H94EM86=E*"1I9"P@)&EM9RP@)&9O<FUA="`]("=P;F<G*2!["B`@("`@
M("`@:68@*"$D:60I"B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R
M;W(H)UEO=2!M=7-T('!R;W9I9&4@86X@240@9F]R(&%N9"!I;6%G92!T;R!B
M92!C86-H960A)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@)&ED
M(#T@)'1H:7,M/F=E;F5R871E240H)&ED+"`D9F]R;6%T*3L*("`@("`@("`D
M='EP97,@/2!);6%G951Y<&5S*"D["@H@("`@("`@("\O($-H96-K(&EF('1H
M92!R97%U97-T960@:6UA9V4@='EP92!I<R!S=7!P;W)T960@8GD@=&AE($=$
M(&QI8BX*("`@("`@("`O+R!)9B!N;W0L('1R>2!A(&-A;&QB86-K('1O('1H
M92!F:7)S="!A=F%I;&%B;&4@:6UA9V4@='EP92X*("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3YI;6%G971Y<&5S6R1F;W)M871=*2!\?"`A*"1T>7!E<R`F
M("1T:&ES+3YI;6%G971Y<&5S6R1F;W)M871=*2D@>PH@("`@("`@("`@("!F
M;W)E86-H("@D=&AI<RT^:6UA9V5T>7!E<R!A<R`D<W5P<&]R=&5D(#T^("1B
M:71M87-K*2!["B`@("`@("`@("`@("`@("!I9B`H)'1Y<&5S("8@)&)I=&UA
M<VLI('L*("`@("`@("`@("`@("`@("`@("!N97<@0V%C:&5?17)R;W(H(E1H
M92!B=6EL9"!I;B!'1"!L:6(@9&]E<R!N;W0@<W5P<&]R="!T:&4@:6UA9V4@
M='EP92`D9F]R;6%T+B!&86QL8F%C:R!T;R`D<W5P<&]R=&5D+B(L(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H(DAM;2P@
M:7,@>6]U<B!02%`@8G5I;&0@=VET:"!'1"!S=7!P;W)T/R!#86XG="!F:6YD
M(&%N>2!S=7!P;W)T960@='EP97,N(BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@:68@*"1I;6%G92`]("1T:&ES+3YG970H)&ED+"`D=&AI<RT^8V%C
M:&5?9W)O=7`I*0H@("`@("`@("`@("!R971U<FX@)&EM86=E.PH*("`@("`@
M("`O+R!S879E('1H92!I;6%G92!T;R!T:&4@;W5T<'5T(&)U9F9E<BP@=W)I
M=&4@:70@=&\@9&ES:R!A;F0@"B`@("`@("`@+R\@<F5T=7)N('1H92!I;6%G
M92X*("`@("`@("!O8E]E;F1?8VQE86XH*3L*("`@("`@("!O8E]S=&%R="@I
M.R`*"B`@("`@("`@:68@*'-T<G1O=7!P97(H)&9O<FUA="D@/3T@(DI01R(I
M('L*("`@("`@("`@("`@)&=E;D9O<FUA="`](")*4$5'(CL*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D9V5N1F]R;6%T(#T@<W1R=&]U<'!E<B@D
M9F]R;6%T*3L*("`@("`@("!]"@H@("`@("`@("\O(&=E;F5R871E('1H92!I
M;6%G90H@("`@("`@("1F=6YC(#T@)TEM86=E)R`N("1G96Y&;W)M870["B`@
M("`@("`@)&9U;F,H)&EM9RD["B`@("`@("`@26UA9V5$97-T<F]Y*"1I;6<I
M.PH*("`@("`@("!O8E]E;F0H*3L*("`@("`@("`D:6UA9V4@/2!O8E]G971?
M8V]N=&5N=',H*3L*("`@("`@("!O8E]E;F1?8VQE86XH*3L*"B`@("`@("`@
M+R\@<V%V92!T:&4@9V5N97)A=&5D(&EM86=E('1O(&1I<VL*("`@("`@("`D
M=&AI<RT^<V%V92@D:60L("1I;6%G92P@,"P@)'1H:7,M/F-A8VAE7V=R;W5P
M*3L*"B`@("`@("`@<F5T=7)N("1I;6%G93L*("`@('T@+R\@96YD(&9U;F,@
M8V%C:&5);6%G90H@("`@"@H@("`@+RHJ"B`@("`J($-R96%T92!A;B!I;6%G
M92!F<F]M('1H92!G:79E;B!I;6%G92!H86YD;&5R+"!C86-H92!I="!A;F0@
M<F5T=7)N(&$@=7)L(&%N9"!T:&4@9FEL92!P871H(&]F('1H92!I;6%G92X*
M("`@("H*("`@("H@06QW87ES('1R>2!T;R!R971R:79E('1H92!I;6%G92!F
M<F]M('1H92!C86-H92!B969O<F4@>6]U(&-O;7!U=&4@:70N"B`@("`J"B`@
M("`J($!P87)A;2`@("!S=')I;F<@($EM86=E+4E$+B!5<V5D(&%S(&$@<&%R
M="!O9B!T:&4@8V%C:&4@9FEL96YA;64N"B`@("`J("`@("`@("`@("`@("`@
M("`@(%5S92!M9#4H*2!T;R!G96YE<F%T92!A(")U;FEQ=64B($E$(&9O<B!Y
M;W5R(&EM86=E"B`@("`J("`@("`@("`@("`@("`@("`@(&)A<V5D(&]N(&-H
M87)A8W1E<FES=&EC('9A;'5E<R!S=6-H(&%S('1H92!C;VQO<BP@<VEZ92!E
M=&,N"B`@("`J($!P87)A;2`@("!S=')I;F<@($EM86=E(&AA;F1L97(@=&\@
M8W)E871E('1H92!I;6%G92!F<F]M+@H@("`@*B!`<&%R86T@("`@<W1R:6YG
M("!);6%G92!T>7!E.B!G:68L(&IP9RP@<&YG+"!W8FUP+B!!;'-O('5S960@
M87,@9FEL96YA;64@<W5F9FEX+@H@("`@*B`@("`@("`@("`@("`@("`@("!)
M9B!A;B!U;G-U<'!O<G1E9"!T>7!E(&ES(')E<75E<W1E9"!T:&4@9G5N8W1I
M;VYS('1R:65S('1O(`H@("`@*B`@("`@("`@("`@("`@("`@("!F86QL8F%C
M:R!T;R!A('-U<'!O<G1E9"!T>7!E(&)E9F]R92!T:')O=VEN9R!A;B!E>&5P
M=&EO;BX*("`@("H@0')E='5R;B`@(&%R<F%Y("!;(&9U;&P@<&%T:"!T;R!T
M:&4@:6UA9V4@9FEL92P@:6UA9V4@=7)L(%T*("`@("H@0'1H<F]W<R`@($-A
M8VAE7T5R<F]R"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("HO"B`@("!F
M=6YC=&EO;B!C86-H94EM86=E3&EN:R@D:60L("8D:6UG+"`D9F]R;6%T(#T@
M)W!N9R<I('L*("`@("`@("!I9B`H(21I9"D*("`@("`@("`@("`@<F5T=7)N
M(&YE=R!#86-H95]%<G)O<B`H)UEO=2!M=7-T('!R;W9I9&4@86X@240@9F]R
M(&%N9"!I;6%G92!T;R!B92!C86-H960A)RP@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*"B`@("`@("`@)&ED(#T@)'1H:7,M/F=E;F5R871E240H)&ED+"`D9F]R
M;6%T*3L*("`@("`@("`D='EP97,@/2!);6%G951Y<&5S*"D["@H@("`@("`@
M("\O($-H96-K(&EF('1H92!R97%U97-T960@:6UA9V4@='EP92!I<R!S=7!P
M;W)T960@8GD@=&AE($=$(&QI8BX*("`@("`@("`O+R!)9B!N;W0L('1R>2!A
M(&-A;&QB86-K('1O('1H92!F:7)S="!A=F%I;&%B;&4@:6UA9V4@='EP92X*
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YI;6%G971Y<&5S6R1F;W)M871=
M*2!\?"`A*"1T>7!E<R`F("1T:&ES+3YI;6%G971Y<&5S6R1F;W)M871=*2D@
M>PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^:6UA9V5T>7!E<R!A<R`D
M<W5P<&]R=&5D(#T^("1B:71M87-K*2`*("`@("`@("`@("`@("`@(&EF("@D
M='EP97,@)B`D8FET;6%S:RD*("`@("`@("`@("`@("`@("`@("!N97<@0V%C
M:&5?17)R;W(H(E1H92!B=6EL9"!I;B!'1"!L:6(@9&]E<R!N;W0@<W5P<&]R
M="!T:&4@:6UA9V4@='EP92`D9F]R;6%T+B!&86QL8F%C:R!T;R`D<W5P<&]R
M=&5D+B(L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@("`@("!E
M;'-E"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O
M<B@B2&UM+"!I<R!Y;W5R(%!(4"!B=6EL9"!W:71H($=$('-U<'!O<G0_($-A
M;B=T(&9I;F0@86YY('-U<'!O<G1E9"!T>7!E<RXB+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@)'5R;"`]("1T:&ES+3YC86-H
M95]U<FP@+B`D=&AI<RT^8V%C:&5?9FEL95]P<F5F:7@@+B`D:60["B`@("`@
M("`@)&9F:6QE(#T@)'1H:7,M/F-O;G1A:6YE<BT^9V5T1FEL96YA;64H)&ED
M+"`D=&AI<RT^8V%C:&5?9W)O=7`I.PH*("`@("`@("!I9B`H)'1H:7,M/FES
M0V%C:&5D*"1I9"P@)'1H:7,M/F-A8VAE7V=R;W5P*2`F)B`A:7-%>'!I<F5D
M*"1I9"P@)'1H:7,M/F-A8VAE7V=R;W5P*2D*("`@("`@("`@("`@<F5T=7)N
M(&%R<F%Y*"1F9FEL92P@)'5R;"D["@H@("`@("`@(&EF("AS=')T;W5P<&5R
M*"1F;W)M870I(#T](")*4$<B*2!["B`@("`@("`@("`@("1G96Y&;W)M870@
M/2`B2E!%1R(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&=E;D9O
M<FUA="`]('-T<G1O=7!P97(H)&9O<FUA="D["B`@("`@("`@?0H*("`@("`@
M("`D9G5N8R`]("=);6%G92<@+B`D9V5N1F]R;6%T.PH@("`@("`@("1F=6YC
M*"1I;6<L("1F9FEL92D["@H@("`@("`@($EM86=E1&5S=')O>2@D:6UG*3L*
M"B`@("`@("`@<F5T=7)N(&%R<F%Y*"1F9FEL92P@)'5R;"D["B`@("!]("\O
M(&5N9"!F=6YC(&-A8VAE26UA9V5,:6YK"@H@("`@"B`@("`O*BH*("`@("H@
M4V5T<R!T:&4@55),('!R969I>"!U<V5D('=H96X@<F5N9&5R:6YG($A434P@
M5&%G<RX@"B`@("`J(`H@("`@*B!-86ME('-U<F4@=&AA="!T:&4@55),(&UA
M=&-H97,@=&AE(&-A8VAE(&1I<F5C=&]R>2P@"B`@("`J(&]T:&5R=VES92!Y
M;W4G;&P@9V5T(&)R;VME;B!L:6YK<RX*("`@("H@"B`@("`J($!P87)A;2`@
M("!S=')I;F<*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B!`<V5E("`@
M("`@<V5T0V%C:&5$:7(H*0H@("`@*B\*("`@(&9U;F-T:6]N('-E=$-A8VAE
M55),*"1C86-H95]U<FPI('L*("`@("`@("!I9B`H)&-A8VAE7W5R;"`F)B`G
M+R<@(3T@<W5B<W1R*"1C86-H95]U<FPL(#$I*2`*("`@("`@("`@("`@)&-A
M8VAE7W5R;"`N/2`G+R<["B`@("`@("`@("`@(`H@("`@("`@("1T:&ES+3YC
M86-H95]U<FP@/2`D8V%C:&5?=7)L.PH@("`@("`@(`H@("`@?2`O+R!E;F0@
M9G5N8R!S971#86-H95523`H*("`@(`H@("`@+RHJ"B`@("`J(%-E=',@=&AE
M(&1I<F5C=&]R>2!W:&5R92!T;R!C86-H92!G96YE<F%T960@26UA9V5S"B`@
M("`J(`H@("`@*B!`<&%R86T@("`@<W1R:6YG"B`@("`J($!A8V-E<W,@("!P
M=6)L:6,*("`@("H@0'-E92`@("`@('-E=$-A8VAE55),*"D*("`@("HO"B`@
M("!F=6YC=&EO;B!S971#86-H941I<B@D8V%C:&5?9&ER*2!["B`@("`@("`@
M:68@*"1C86-H95]D:7(@)B8@)R\G("$]('-U8G-T<B@D8V%C:&5?9&ER+"`Q
M*2D*("`@("`@("`@("`@)&-A8VAE7V1I<B`N/2`G+R<["@H@("`@("`@("1T
M:&ES+3YC86-H95]D:7(@/2`D8V%C:&5?9&ER.PH@("`@("`@("1T:&ES+3YC
M;VYT86EN97(M/F-A8VAE7V1I<B`]("1C86-H95]D:7(["B`@("!]("\O(&5N
M9"!F=6YC('-E=$-A8VAE1&ER"B`@("`*("`@(`H@("`@9G5N8W1I;VX@9V5N
M97)A=&5)1"@D=F%R:6%B;&4L("1F;W)M870@/2`G<&YG)RD@>PH@("`@("!R
M971U<FX@;60U*'-E<FEA;&EZ92@D=F%R:6%B;&4I*2`N("<N)R`N("1F;W)M
M870["B`@("!]("\O(&5N9"!F=6YC(&=E;F5R871E240*("`@(`H@("`@"GT@
M+R\@96YD(&-L87-S($-A8VAE7T=R87!H:6-S"C\^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O0V%C:&4O2%144%]297%U97-T+G!H<```````
M````````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C,R-30`,3`U,34T,S,W,S0`
M,#(R-C$U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M(%!%05(@.CH@0V%C:&4@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE
M(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`@;V8@=&AE(%!(4"!L
M:6-E;G-E+"`@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI
M<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@
M?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV
M92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E
M;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA
M=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\($%U=&AO<G,Z($9A8FEE;B!-05)462`\9F%B:65N+FUA
M<G1Y0&9R964N9G(^('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O"B\O("1)9#H@2%144%]297%U97-T+G!H<"QV(#$N.2`R,#`S+S`W+S$S
M(#`X.C(W.C$X(&9A8B!%>'`@)`H*<F5Q=6ER95]O;F-E("=#86-H92YP:'`G
M.PIR97%U:7)E7V]N8V4@)TA45%`O4F5Q=65S="YP:'`G.PH*9&5F:6YE*"=#
M04-(15](5%107U)%455%4U1?1U)/55!?3D%-12<L("=C86-H95]H='1P7W)E
M<75E<W0G*3L*9&5F:6YE*"=#04-(15](5%107U)%455%4U1?4U5#0T534U]2
M15-03TY315]#3T1%)RP@,C`P*3L*9&5F:6YE*"=#04-(15](5%107U)%455%
M4U1?2T5%4%],3T-!3%]#3U!9)RP@,2D["F1E9FEN92@G0T%#2$5?2%144%]2
M15%515-47U)%5%523E]&04Q312<L(#(I.PID969I;F4H)T-!0TA%7TA45%!?
M4D5154535%]215154DY?4$5!4E]%4E)/4B<L(#,I.PH*+RHJ"BH@2%144%]2
M97%U97-T($-A8VAE"BH**B!4:&4@8VQA<W-I8V%L(&5X86UP;&4@:7,@.@HJ
M"BH@66]U('=A;G0@=&\@9V5T(&YE=W,@9G)O;2!A;F]T:&5R('-I=&4@=&AR
M;W5G:"!24U,@<F5M;W1E(&9I;&5S+B!"=70@>6]U"BH@9&]N)W0@=V%N="!T
M;R!A8V-E<W,@=&\@=&\@=&AE(')E;6]T92!S:71E(&%T(&5V97)Y('1I;64@
M>6]U(&1I<W!L87D**B!I=',@;F5W<R!O;B!Y;W5R('-I=&4N($)E8V%U<V4L
M(&EF('1H92!R96UO=&4@<VET92!I<R!D;W=N(&]R('-L;W<N+BX**B!3;R!Y
M;W4@>6]U(&YE960@82!C;&%S<R!W:&EC:"!M86ME<R!A(&QO8V%L(&-A8VAE
M(&-O<'D@;V8@=&AE(')E;6]T92!F:6QE+@HJ($5V97)Y('@@:&]U<G,L('1H
M92!C86-H92!I<R!U<&1A=&5D+B!"=70@:68@=&AE(')E;6]T92!S:71E(&ES
M(&1O=VXL('1H90HJ(&QO8V%L(&-A8VAE(&-O<'D@:7,@:V5E<&5D("AY;W4@
M8V%N(&%L<V\@9V5T(&5R<F]R(&UE<W-A9V5S(&EF('EO=2!W86YT*2X**@HJ
M(%-O('EO=2!N965D('1H:7,@8VQA<W,A"BH**B!#86-H95](5%107U)E<75E
M<W0@:6YH97)I=',@9G)O;2!#86-H92!A;F0@=7-E($A45%!?4F5Q=65S="!T
M;R!A8V-E<W,@=&\**B!T:&4@<F5M;W1E(&9I;&4N"BH**B!5<V%G92!E>&%M
M<&QE(#H**@HJ(#P_<&AP"BH@<F5Q=6ER95]O;F-E*"=#86-H92](5%107U)E
M<75E<W0N<&AP)RD["BH**B`D8V%C:&4@/2`F;F5W($-A8VAE7TA45%!?4F5Q
M=65S="@G:'1T<#HO+W=W=RYP:'`N;F5T)RP@3E5,3"P@)V9I;&4G+"!.54Q,
M+"`S-C`P*3L**B`D8V%C:&4M/G-E;F1297%U97-T*"D["BH@)')E;6]T949I
M;&5";V1Y(#T@)&-A8VAE+3YG971297-P;VYS94)O9'DH*3L**@HJ("@N+BXI
M"BH@/SX**@HJ($!A=71H;W(@("!&86)I96X@34%25%D@/&9A8FEE;BYM87)T
M>4!F<F5E+F9R/@HJ($!V97)S:6]N("`D260Z($A45%!?4F5Q=65S="YP:'`L
M=B`Q+CD@,C`P,R\P-R\Q,R`P.#HR-SHQ."!F86(@17AP("0**B!`<&%C:V%G
M92`@0V%C:&4**B\*"F-L87-S($-A8VAE7TA45%!?4F5Q=65S="!E>'1E;F1S
M($-A8VAE"GL*"B`@("`O+R`M+2T@4')I=F%T92!P<F]P97)T:65S("TM+0H*
M("`@("\J*@H@("`@*B!,:69E=&EM92!I;B!S96-O;F1S("@P(&5N9&QE<W,I
M"B`@("`J"B`@("`J($!V87(@:6YT("1?97AP:7)E<PH@("`@*B\*("`@('9A
M<B`D7V5X<&ER97,["@H@("`@+RHJ"B`@("`J($A45%`@4F5Q=65S=`H@("`@
M*@H@("`@*B!`=F%R(&]B:F5C="`D7W)E<75E<W0*("`@("HO"B`@("!V87(@
M)%]R97%U97-T.PH*("`@("\J*@H@("`@*B!#86-H92!I9"!F;W(@=&AE(&-L
M87-S:6,@8V%C:&4@9FEL90H@("`@*@H@("`@*B!`<V5E('-E;F1297%U97-T
M*"D*("`@("H@0'9A<B!S=')I;F<@)%]I9`H@("`@*B\*("`@('9A<B`D7VED
M.PH*("`@("\J*@H@("`@*B!#86-H92!I9"!F;W(@=&AE(&5N9&QE<W,@8V%C
M:&4@9FEL90H@("`@*@H@("`@*B!`<V5E('-E;F1297%U97-T*"D*("`@("H@
M0'9A<B!S=')I;F<@)%]I9`H@("`@*B\*("`@('9A<B`D7VED,CL*"B`@("`O
M*BH*("`@("H@1&%T82!T;R!U<V4*("`@("H*("`@("H@0'-E92!G971297!O
M;G-E0F]D>2@I+"!G971297!O;G-E2&5A9&5R*"DL(&=E=%)E<&]N<V5#;V1E
M*"D*("`@("H@0'9A<B!A<G)A>2`D7V1A=&$*("`@("HO"B`@("!V87(@)%]D
M871A(#L*"B`@("`O+R`M+2T@4'5B;&EC(&UE=&AO9',@+2TM"@H@("`@+RHJ
M"B`@("`J($-O;G-T<G5C=&]R"B`@("`J"B`@("`J($!P87)A;2`D=7)L(%1H
M92!U<FP@=&\@86-C97-S"B`@("`J($!P87)A;2`D<&%R86US($%S<V]C:6%T
M:79E(&%R<F%Y(&]F('!A<F%M971E<G,@=VAI8V@@8V%N(&)E.@H@("`@*B`@
M("`@("`@("`@("`@("`@(&UE=&AO9"`@("`@+2!-971H;V0@=&\@=7-E+"!'
M150L(%!/4U0@971C"B`@("`J("`@("`@("`@("`@("`@("`@:'1T<"`@("`@
M("`M($A45%`@5F5R<VEO;B!T;R!U<V4L(#$N,"!O<B`Q+C$*("`@("H@("`@
M("`@("`@("`@("`@("!U<V5R("`@("`@("T@0F%S:6,@075T:"!U<V5R;F%M
M90H@("`@*B`@("`@("`@("`@("`@("`@('!A<W,@("`@("`@+2!"87-I8R!!
M=71H('!A<W-W;W)D"B`@("`J("`@("`@("`@("`@("`@("`@<')O>'E?:&]S
M="`M(%!R;WAY('-E<G9E<B!H;W-T"B`@("`J("`@("`@("`@("`@("`@("`@
M<')O>'E?<&]R="`M(%!R;WAY('-E<G9E<B!P;W)T"B`@("`J("`@("`@("`@
M("`@("`@("`@<')O>'E?=7-E<B`M(%!R;WAY(&%U=&@@=7-E<FYA;64*("`@
M("H@("`@("`@("`@("`@("`@("!P<F]X>5]P87-S("T@4')O>'D@875T:"!P
M87-S=V]R9`H@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT86EN97(@3F%M92!O
M9B!C;VYT86EN97(@8VQA<W,*("`@("H@0'!A<F%M(&%R<F%Y("1C;VYT86EN
M97)/<'1I;VYS($%R<F%Y('=I=&@@8V]N=&%I;F5R(&-L87-S(&]P=&EO;G,*
M("`@("H@0'!A<F%M(&EN="`D;6]D92!7:&%T('1O(&1O('=H96X@=&AE(')E
M;6]T92!S97)V97(@:7,@9&]W;B`Z"B`@("`J("`@("`@("`@("`@("`@("`@
M($-!0TA%7TA45%!?4D5154535%]+14507TQ/0T%,7T-/4%D@;W(*("`@("H@
M("`@("`@("`@("`@("`@("`@0T%#2$5?2%144%]215%515-47U)%5%523E]&
M04Q312!O<@H@("`@*B`@("`@("`@("`@("`@("`@("!#04-(15](5%107U)%
M455%4U1?4D5455).7U!%05)?15)23U(*("`@("H@0'!A<F%M(&EN="`D97AP
M:7)E<R!L:69E=&EM92!O9B!T:&4@8V%C:&5D(&1A=&$@:6X@<V5C;VYD<R`M
M(#`@9F]R(&5N9&QE<W,*("`@("H@0'-E92!#86-H92P@2%144%]297%U97-T
M"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@0V%C
M:&5?2%144%]297%U97-T*"1U<FPL("1P87)A;7,@/2!.54Q,+"`D8V]N=&%I
M;F5R("`]("=F:6QE)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D8V]N=&%I;F5R3W!T:6]N<R`]($Y53$PL("1E>'!I<F5S(#T@,S8P,"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;6]D92`]($-!0TA%
M7TA45%!?4D5154535%]+14507TQ/0T%,7T-/4%DI"B`@("!["B`@("`@("`@
M:68@*"%I<W-E="@D<&%R86US*2D@)'!A<F%M<R`](&%R<F%Y*"D["B`@("`@
M("`@:68@*"%I<W-E="@D8V]N=&%I;F5R3W!T:6]N<RDI('L*("`@("`@("`@
M("`@)&-O;G1A:6YE<D]P=&EO;G,@/2!A<G)A>2`H"B`@("`@("`@("`@("`@
M("`G8V%C:&5?9&ER)R`]/B`G+W1M<"\G+`H@("`@("`@("`@("`@("`@)V9I
M;&5N86UE7W!R969I>"<@/3X@)V-A8VAE7R<*("`@("`@("`@("`@*3L*("`@
M("`@("!]"B`@("`@("`@)'1H:7,M/D-A8VAE*"1C;VYT86EN97(L("1C;VYT
M86EN97)/<'1I;VYS*3L*("`@("`@("`D=&AI<RT^7W)E<75E<W0@/2`F;F5W
M($A45%!?4F5Q=65S="@D=7)L+"`D<&%R86US*3L*("`@("`@("`D=&AI<RT^
M7VED(#T@;60U*"1U<FPN<V5R:6%L:7IE*"1P87)A;7,I*3L*("`@("`@("`D
M=&AI<RT^7VED,B`](&UD-2@D=&AI<RT^7VED*3L@+R\@=V4@;F5E9"!T=V\@
M:V5Y<PH@("`@("`@("1T:&ES+3Y?;6]D92`]("1M;V1E.PH@("`@("`@("1T
M:&ES+3Y?97AP:7)E<R`]("1E>'!I<F5S.PH@("`@?0H*("`@("\J*@H@("`@
M*B!$96-O;G-T<G5C=&]R"B`@("`J"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`J+PH@("`@9G5N8W1I;VX@7T-A8VAE7TA45%!?4F5Q=65S="@I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]#86-H92@I.PH@("`@?0H*("`@("\J*@H@("`@
M*B!'970@86YD(')E='5R;B!T:&4@<F5S<&]N<V4@8F]D>2`H3E5,3"!I9B!N
M;R!D871A(&%V86EL86)L92D*("`@("H*("`@("H@0'-E92!S96YD4F5Q=65S
M="@I"B`@("`J($!R971U<FX@;6EX960@<F5S<&]N<V4@8F]D>0H@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(&=E=%)E<W!O;G-E
M0F]D>2@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T85LG8F]D
M>2==.PH@("`@?0H*("`@("\J*@H@("`@*B!'970@86YD(')E='5R;B!T:&4@
M<F5S<&]N<V4@8V]D92`H3E5,3"!I9B!N;R!D871A(&%V86EL86)L92D*("`@
M("H*("`@("H@0'-E92!S96YD4F5Q=65S="@I"B`@("`J($!R971U<FX@;6EX
M960@<F5S<&]N<V4@8V]D90H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%)E<W!O;G-E0V]D92@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?9&%T85LG8V]D92==.PH@("`@?0H*("`@("\J*@H@
M("`@*B!'970@86YD(')E='5R;B!T:&4@<F5S<&]N<V4@:&5A9&5R("A.54Q,
M(&EF(&YO(&1A=&$@879A:6QA8FQE*0H@("`@*@H@("`@*B!`<V5E('-E;F12
M97%U97-T*"D*("`@("H@0')E='5R;B!M:7AE9"!R97-P;VYS92!H96%D97(*
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!G9712
M97-P;VYS94AE861E<B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M9&%T85LG:&5A9&5R)UT["B`@("!]"@H*("`@("\J*@H@("`@*B!3970@82!N
M97<@;6]D92!W:&5N('1H92!S97)V97(@:7,@9&]W;@H@("`@*@H@("`@*B!`
M<&%R86T@:6YT("1N97=-;V1E(%=H870@=&\@9&\@=VAE;B!T:&4@<F5M;W1E
M('-E<G9E<B!I<R!D;W=N(#H*("`@("H@("`@("`@("`@("`@("`@("`@("`@
M0T%#2$5?2%144%]215%515-47TM%15!?3$]#04Q?0T]062!O<@H@("`@*B`@
M("`@("`@("`@("`@("`@("`@("!#04-(15](5%107U)%455%4U1?4D5455).
M7T9!3%-%(&]R"B`@("`J("`@("`@("`@("`@("`@("`@("`@($-!0TA%7TA4
M5%!?4D5154535%]215154DY?4$5!4E]%4E)/4@H@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N('-E=$UO9&4H)&YE=TUO9&4I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]M;V1E(#T@)&YE=TUO9&4["B`@("!]"@H@
M("`@+RHJ"B`@("`J(%-E;F0@=&AE($A45%`@<F5Q=65S="!O<B!U<V4@=&AE
M(&-A8VAE('-Y<W1E;0H@("`@*@H@("`@*B!)9B!T:&5R92!I<R!A(&-A8VAE
M(&9I;&4@9F]R('1H:7,@2%144"!R97%U97-T+"!T:&4@<F5Q=65S="!I<R!N
M;W0@<F4M<V5N="X*("`@("H@0V%C:&5D(')E<W!O;G-E(&ES('5S960N(%EE
M="P@:68@=&AE(&-A8VAE(&ES(&5X<&ER960L('1H92!(5%10(')E<75E<W0*
M("`@("H@:7,@<F4M<V5N="X@5&AE;BP@:68@=&AE(')E;6]T92!S97)V97(@
M:7,@9&]W;BP@=&AI<R!M971H;V0@=VEL;"!R971U<FX@.@H@("`@*B`H9&5P
M96YD:6YG(&]N('1H92!S96QE8W1E9"!M;V1E*0H@("`@*B`M(&9A;'-E(&]R
M"B`@("`J("T@82!014%27T5R<F]R(&]R("AB971T97(I"B`@("`J("T@=')U
M92!A;F0@=&AE(&QO8V%L(&-O<'D@;V8@=&AE(&QA=&5S="!V86QI9"!R97-P
M;VYS92!W:6QL(&)E('5S960N"B`@("`J"B`@("`J("AT96-H;FEC86PI"B`@
M("`J($9O<B!T:&4@;&%S="!C:&]I8V4L('1H97)E(&ES(&$@=&5C:&YI8V%L
M('1I<',N"B`@("`J($EN9&5E9"P@=&AE<F4@87)E('1W;R!C86-H92!F:6QE
M<RX@5&AE(&9I<G-T(&]N92`H:60@:V5Y*2!I<R!A(&-L87-S:6-A;"!O;F4*
M("`@("H@=VET:"!T:&4@9VEV96X@;&EF971I;64N($)U="!I="!C86X@8F4@
M<F5M;W9E9"!B>2!A=71O;6%T:6,@9V%R8F%G92!C;VQL96-T:6]N"B`@("`J
M(&9O<B!E>&%M<&QE+B!3;R!T;R!B92!A8FQE('1O('5S92!T:&4@;&%T97-T
M('9A;&ED(')E<W!O;G-E("AW:&5N('1H92!R96UO=&4*("`@("H@<V5R=F5R
M(&ES(&1E860I+"!W92!M86ME(&$@<V5C;VYD(&-A8VAE(&9I;&4@=VET:"!N
M;R!L:69E=&EM92`H:60R(&ME>2DN"B`@("`J"B`@("`J($!R971U<FX@;6EX
M960@=')U92!O<B!F86QS92!O<B!A(%!%05)?15)23U(*("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!S96YD4F5Q=65S="@I"B`@
M("!["B`@("`@("`@:68@*"1D871A(#T@)'1H:7,M/F=E="@D=&AI<RT^7VED
M+"!#04-(15](5%107U)%455%4U1?1U)/55!?3D%-12DI('L*("`@("`@("`@
M("`@+R\@+2TM($-A8VAE(&AI="`M+2T*("`@("`@("`@("`@)'1H:7,M/E]D
M871A(#T@)&1A=&$["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("\O("TM+2!#86-H92!M:7-S("TM+0H@
M("`@("`@("`@("!I9B`H)'1H:7,M/E]S96YD4F5Q=65S=$%N9$=E=%)E<W!O
M;G-E*"DI('L*("`@("`@("`@("`@("`@("\O(%-O('1H92!R96UO=&4@<V5R
M=F5R(&ES(&]K+BXN"B`@("`@("`@("`@("`@("`D=&AI<RT^<V%V92@D=&AI
M<RT^7VED+"`D=&AI<RT^7V1A=&$L("1T:&ES+3Y?97AP:7)E<RP@0T%#2$5?
M2%144%]215%515-47T=23U507TY!344I.PH@("`@("`@("`@("`@("`@)'1H
M:7,M/G-A=F4H)'1H:7,M/E]I9#(L("1T:&ES+3Y?9&%T82P@,"P@0T%#2$5?
M2%144%]215%515-47T=23U507TY!344I.PH@("`@("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!I9B`H)&1A=&%?<V%V(#T@)'1H:7,M/F=E="@D=&AI<RT^7VED,BP@0T%#
M2$5?2%144%]215%515-47T=23U507TY!344I*2!["B`@("`@("`@("`@("`@
M("`@("`@+R\@3VLL('1H92`B<F5C;W9E<B!C86-H92(@:7,@879A:6QA8FQE
M+BXN"B`@("`@("`@("`@("`@("`@("`@<W=I=&-H("@D=&AI<RT^7VUO9&4I
M('L*("`@("`@("`@("`@("`@("`@("!C87-E($-!0TA%7TA45%!?4D515453
M5%]+14507TQ/0T%,7T-/4%DZ"B`@("`@("`@("`@("`@("`@("`@("`@("\O
M(%=E(&UA:V4@82!N97<@;&]C86P@8V]P>2!A;F0@:V5E<"!I="!U;G1I;"!I
M="!E>'!I<F5S+BXN"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS
M879E*"1T:&ES+3Y?:60L("1D871A7W-A=BP@)'1H:7,M/E]E>'!I<F5S+"!#
M04-(15](5%107U)%455%4U1?1U)/55!?3D%-12D["B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?9&%T82`]("1D871A7W-A=CL*("`@("`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@0T%#2$5?
M2%144%]215%515-47U)%5%523E]&04Q313H*("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@5V4@<F5T=7)N(&9A;'-E"B`@("`@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("`@("`@8V%S92!#04-(15](5%107U)%455%
M4U1?4D5455).7U!%05)?15)23U(Z"B`@("`@("`@("`@("`@("`@("`@("`@
M("\O(%=E(')E='5R;B!A(%!%05)?17)R;W(A"B`@("`@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)U)E;6]T92!F:6QE(&ES
M(&YO="!A=F%I;&%B;&4A)RD["B`@("`@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@+R\@270G<R!T97)R:6)L92$@
M5&AE(')E;6]T92!S97)V97(@:7,@9&]W;B!A;F0@9&5F:6YI=&EV96QY(&YO
M(&-A8VAE(&%V86EL86)L92$*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M;F5W($-A8VAE7T5R<F]R*"=296UO=&4@<V5R=F5R(&1O=VX@86YD(&YO(&-A
M8VAE(&%V86EL86)L92$G*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@('T*"B`@("`O+R`M+2T@4')I=F%T92!-971H
M;V1S("TM+0H*("`@("\J*@H@("`@*B!396YD($A45%`@<F5Q=65S="!A;F0@
M9V5T('1H92!R97-P;VYS90H@("`@*@H@("`@*B!`<F5T=7)N(&)O;VQE86X@
M<W5C8V5S<R!O<B!N;W0@/PH@("`@*B!`<V5E($A45%!?4F5Q=65S=`H@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("HO"B`@("!F=6YC=&EO;B!?<V5N9%)E
M<75E<W1!;F1'971297-P;VYS92@I"B`@("!["B`@("`@("`@)'1H:7,M/E]R
M97%U97-T+3YS96YD4F5Q=65S="@I.PH@("`@("`@("1B;V1Y(#T@)'1H:7,M
M/E]R97%U97-T+3YG971297-P;VYS94)O9'DH*3L*("`@("`@("`D8V]D92`]
M("1T:&ES+3Y?<F5Q=65S="T^9V5T4F5S<&]N<V5#;V1E*"D["B`@("`@("`@
M)&AE861E<B`]("1T:&ES+3Y?<F5Q=65S="T^9V5T4F5S<&]N<V5(96%D97(H
M*3L*("`@("`@("`D=&AI<RT^7V1A=&$@/2!A<G)A>2@*("`@("`@("`@("`@
M)V)O9'DG(#T^("1B;V1Y+`H@("`@("`@("`@("`G8V]D92<@/3X@)&-O9&4L
M"B`@("`@("`@("`@("=H96%D97(G(#T^("1H96%D97(*("`@("`@("`I.PH@
M("`@("`@(')E='5R;B`H*"1C;V1E/3U#04-(15](5%107U)%455%4U1?4U5#
M0T534U]215-03TY315]#3T1%*2`_('1R=64@.B!F86QS92D["B`@("!]"@I]
M"C\^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O0V%C:&4O3W5T<'5T+G!H<```````````````````
M````````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,38Q-3,`,3`U,34T,S,W,S0`,#(Q
M-C(V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!%
M05(@.CH@0V%C:&4@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(
M4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F
M:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E
M;G-E+"`@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P
M86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO
M+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A
M="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A
M(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@
M?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@
M<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E
M0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\($%U=&AO<G,Z(%5L9B!796YD96P@/'5L9BYW96YD96Q`<&AP
M9&]C+F1E/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@
M("`@("!#:')I<W1I86X@4W1O8VME<B`\8VAR96=U0'!H86YT+F-H/B`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@5FEN86D@2V]P
M<"`\:V]P<$!N971Z87)B96ET97(N9&4^("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@
M)$ED.B!/=71P=70N<&AP+'8@,2XV(#(P,#,O,#$O,#0@,3$Z-30Z-#4@;6H@
M17AP("0*"G)E<75I<F5?;VYC92`G0V%C:&4N<&AP)SL*"B\J*@HJ($-L87-S
M('1O(&-A8VAE('1H92!O=71P=70@;V8@82!S8W)I<'0@=7-I;F<@=&AE(&]U
M='!U="!B=69F97)I;F<@9G5N8W1I;VYS"BH**B!3:6UP;&4@;W5T<'5T(&-A
M8VAE+B!3;VUE('!A9V5S(')E<75I<F4@;&]T<R!O9B!T:6UE('1O(&-O;7!U
M=&4N($-A8VAI;F<@=&AE"BH@;W5T<'5T(&-A;B!I;F-R96%S92!T:&4@;W9E
M<F%L;"!S<&5E9"!D<F%M871I8V%L;'DL(&5S<&5C:6%L;'D@:68@>6]U('5S
M90HJ(&$@4VAA<F5D($UE;6]R>2!S=&]R86=E(&-O;G1A:6YE<BX**@HJ($%S
M('EO=2!C86X@<V5E(&EN('1H92!E>&%M<&QE('1H92!U<V%G92!I<R!E>'1E
M;65L>2!S:6UP;&4N(%1O(&-A8VAE(&$@<V-R:7!T"BH@<VEM<&QE('!U="!S
M;VUE(&9E=R!L:6YE<R!O9B!C;V1E(&EN(&9R;VYT(&]F('EO=7(@<V-R:7!T
M(&%N9"!S;VUE(&%T('1H92!E;F0N"BH@02!P<F5F97)R86)L92!P;&%C92!F
M;W(@=&AI<R!A<F4@=&AE(&%U=&]?<')E<&5N9"!A;F0@875T;U]A<'!E;F0@
M9FEL97,@*#T^('!H<"YI;FDI+@HJ"BH@57-A9V4@97AA;7!L93H**@HJ("`O
M+R!P;&%C92!T:&ES('-O;65W:&5R92!I;B!A(&-E;G1R86P@8V]N9FEG(&9I
M;&4**B`@9&5F:6YE*$-!0TA%7U-43U)!1T5?0TQ!4U,L("=F:6QE)RD["BH@
M("\O(&9I;&4@<W1O<F%G92!N965D<R!A(&1I<B!T;R!P=70@=&AE(&-A8VAE
M(&9I;&5S"BH@(&1E9FEN92A#04-(15]$25(L("<O=F%R+W1M<"\G*3L**@HJ
M("`O+R!G970@82!C86-H92!O8FIE8W0**B`@)&-A8VAE(#T@;F5W($-A8VAE
M7T]U='!U="A#04-(15]35$]204=%7T-,05-3+"!A<G)A>2@G8V%C:&5?9&ER
M)R`]/B!#04-(15]$25(I*3L**@HJ("`O+R!C;VUP=71E('1H92!U;FEQ=64@
M:&%N9&QE+@HJ("`O+R!I9B!Y;W5R('-C<FEP="!D97!E;F1S(&]N($-O;VMI
M92!A;F0@2%144"!0;W-T(&1A=&$@87,@=V5L;`HJ("`O+R!Y;W4@<VAO=6QD
M('5S93H**B`@+R\@)&-A8VAE7VAA;F1L92`](&%R<F%Y*`HJ("`O+R`@("`@
M("`@("`@("`@("`@("`@("`@)V9I;&4G(#T^("1215%515-47U5222P**B`@
M+R\@("`@("`@("`@("`@("`@("`@("`@("=P;W-T)R`]/B`D2%144%]03U-4
M7U9!4E,L"BH@("\O("`@("`@("`@("`@("`@("`@("`@("`G8V]O:VEE)R`@
M/3X@)$A45%!?0T]/2TE%7U9!4E,**B`@+R\@("`@("`@("`@("`@("`@("`@
M("D["BH@("\O($)U="!B92!W87)N960L('5S:6YG(&%L;"!'150@;W(@4$]3
M5"!687)I86)L97,@87,@82!S965D"BH@("\O(&-A;B!B92!U<V5D(&9O<B!A
M($1/4R!A='1A8VLN($-A;&QI;F<@:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]E
M>&%M<&QE+G!H<#]W:&%T979E<@HJ("`O+R!W:&5R92!W:&%T979E<B!I<R!A
M(')A;F1O;2!T97AT(&UI9VAT(&)E('5S960@=&\@9FQO;V0@>6]U<B!C86-H
M92X**B`@)&-A8VAE7VAA;F1L92`]("1C86-H92T^9V5N97)A=&5)1"@D4D51
M54535%]54DDI.PHJ"BH@("\O(&YO=R!T:&4@;6%G:6,@:&%P<&5N<SH@:68@
M8V%C:&5D(&-A;&P@9&EE*"D**B`@+R\@=&\@96YD('1H92!T:6UE(&-O;G-U
M;7!T:6]N9R!S8W)I<'0@<V-R:7!T(&5X96-U=&EO;B!A;F0@=7-E('1H92!C
M86-H960@=F%L=64A"BH@(&EF("@D8V]N=&5N="`]("1C86-H92T^<W1A<G0H
M)&-A8VAE7VAA;F1L92DI('L**B`@("`@<')I;G0@)&-O;G1E;G0["BH@("`@
M('!R:6YT("<\<#Y#86-H92!H:70\+W`^)SL**B`@("`@9&EE*"D["BH@('T*
M*@HJ("`O+R!T:6UE(&-O;G-U;7!T:6]N('-C<FEP="!G;V5S(&AE<F4N"BH*
M*B`@+R\@<W1O<F4@=&AE(&]U='!U="!O9B!T:&4@8V%C:&4@:6YT;R!T:&4@
M8V%C:&4@86YD('!R:6YT('1H92!O=71P=70N"BH@('!R:6YT("1C86-H92T^
M96YD*"D["BH@('!R:6YT("(\<#Y#86-H92!M:7-S+"!S=&]R960@=7-I;F<@
M=&AE($E$("<D:60G+CPO<#XB.PHJ"BH@($EF('EO=2!D;R!N;W0@=V%N="!T
M;R!C86-H92!A('=H;VQE('!A9V4@+2!N;R!P<F]B;&5M.@HJ"BH@(&EF("@A
M*"1C;VYT96YT(#T@)&-A8VAE+3YS=&%R="@D8V%C:&5?:&%N9&QE*2DI('L*
M*B`@("`@+R\@9&\@=&AE(&-O;7!U=&%T:6]N(&AE<F4**B`@("`@<')I;G0@
M)&-A8VAE+3YE;F0H*0HJ("!](&5L<V4@>PHJ("`@("!P<FEN="`D8V]N=&5N
M=#L**B`@?0HJ"BH@($EF('EO=2!N965D(&%N(&5X86UP;&4@<V-R:7!T(&-H
M96-K('1H92`H875T;U\I<')E<&5N9"!A;F0@*&%U=&]?*6%P<&5N9`HJ("!F
M:6QE<R!O9B!M>2!H;VUE<&%G93H**@HJ("`@(&AT='`Z+R]W=W<N=6QF+7=E
M;F1E;"YD92]P:'`O<VAO=U]S;W5R8V4N<&AP/V9I;&4]<')E<&5N9`HJ("`@
M(&AT='`Z+R]W=W<N=6QF+7=E;F1E;"YD92]P:'`O<VAO=U]S;W5R8V4N<&AP
M/V9I;&4]87!P96YD"BH**B`@1&]N)W0@:VYO=R!H;W<@=&\@=7-E(&ET(&]R
M('EO=2!N965D('!R;V9I;&EN9R!I;F9O<FUA=&EO;G,_8`HJ("!!<VL@0VAR
M:7-T:6%N(&AE('=A<R!P871I96YT('=I=&@@;64@86YD(&AE)VQL(&)E('-O
M('=I=&@@>6]U<B!Q=65S=&EO;G,@.RDN"BH**B`@2&%V92!F=6XA"BH**B!`
M875T:&]R<R`@56QF(%=E;F1E;"`\=6QF+G=E;F1E;$!P:'!D;V,N9&4^"BH@
M0'9E<G-I;VX@("1)1#H@)`HJ($!P86-K86=E("!#86-H90HJ($!A8V-E<W,@
M("!P=6)L:6,**B\*8VQA<W,@0V%C:&5?3W5T<'5T(&5X=&5N9',@0V%C:&4@
M>PH*("`@("\J*@H@("`@*B!)1"!P87-S960@=&\@<W1A<G0H*0H@("`@*@H@
M("`@*B!`=F%R("!S=')I;F<*("`@("H@0'-E92`@<W1A<G0H*2P@96YD*"D*
M("`@("HO"B`@("!V87(@)&]U='!U=%]I9"`]("<G.PH*("`@("\J*@H@("`@
M*B!'<F]U<"!P87-S960@=&\@<W1A<G0H*0H@("`@*@H@("`@*B!`=F%R("!S
M=')I;F<*("`@("H@0'-E92`@<W1A<G0H*2P@96YD*"D*("`@("HO"B`@("!V
M87(@)&]U='!U=%]G<F]U<"`]("<G.PH*("`@("\J*@H@("`@*B!014%2+41E
M8V]N<W1R=6-T;W(*("`@("H@0V%L;"!D96-O;G-T<G5C=&]R(&]F('!A<F5N
M=`H@("`@*B\*("`@(&9U;F-T:6]N(%]#86-H95]/=71P=70H*0H@("`@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]#86-H92@I.PH@("`@?0H*("`@("\J
M*@H@("`@*B!S=&%R=',@=&AE(&]U='!U="!B=69F97)I;F<@86YD(')E='5R
M;G,@86X@96UP='D@<W1R:6YG(&]R(')E='5R;G,@=&AE(&-A8VAE9"!O=71P
M=70@9G)O;2!T:&4@8V%C:&4N"B`@("`J"B`@("`J($!P87)A;2`@("!S=')I
M;F<@(&1A=&%S970@240*("`@("H@0'!A<F%M("`@('-T<FEN9R`@8V%C:&4@
M9W)O=7`*("`@("H@0')E='5R;B`@('-T<FEN9PH@("`@*B!`86-C97-S("`@
M<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@<W1A<G0H)&ED+"`D9W)O=7`@
M/2`G9&5F875L="<I('L*("`@("`@("!I9B`H(21T:&ES+3YC86-H:6YG*0H@
M("`@("`@("`@("!R971U<FX@)R<["@H@("`@("`@("\O('1H:7,@:7,@86QR
M96%D>2!C86-H960@<F5T=7)N(&ET(&9R;VT@=&AE(&-A8VAE('-O('1H870@
M=&AE('5S97(*("`@("`@("`O+R!C86X@=7-E('1H92!C86-H92!C;VYT96YT
M(&%N9"!S=&]P('-C<FEP="!E>&5C=71I;VX*("`@("`@("!I9B`H)&-O;G1E
M;G0@/2`D=&AI<RT^9V5T*"1I9"P@)&=R;W5P*2D*("`@("`@("`@("`@<F5T
M=7)N("1C;VYT96YT.PH*("`@("`@("`O+R!R96UE;6)E<B!S;VUE(&1A=&$@
M=&\@8F4@86)L92!T;R!F:6QL('1H92!C86-H92!O;B!C86QL:6YG(&5N9"@I
M"B`@("`@("`@)'1H:7,M/F]U='!U=%]I9"`]("1I9#L*("`@("`@("`D=&AI
M<RT^;W5T<'5T7V=R;W5P(#T@)&=R;W5P.PH*("`@("`@("`O+R!705).24Y'
M.B!W92!N965D('1H92!O=71P=70@8G5F9F5R("T@<&]S<VEB;&4@8VQA<VAE
M<PH@("`@("`@(&]B7W-T87)T*"D["B`@("`@("`@;V)?:6UP;&EC:71?9FQU
M<V@H9F%L<V4I.PH*("`@("`@("!R971U<FX@)R<["B`@("!]("\O(&5N9"!F
M=6YC('-T87)T"@H@("`@+RH*("`@("H@4W1O<F5S('1H92!C;VYT96YT(&]F
M('1H92!O=71P=70@8G5F9F5R(&EN=&\@=&AE(&-A8VAE(&%N9"!R971U<FYS
M('1H92!C;VYT96YT+@H@("`@*@H@("`@*B!`<&%R86T@("`@;6EX960@("!L
M:69E=&EM92!O9B!T:&4@8V%C:&5D(&1A=&$@:6X@<V5C;VYD<R`M(#`@9F]R
M(&5N9&QE<W,N($UO<F4@9F]R;6%T<R!A=F%I;&%B;&4N('-E92!#;VYT86EN
M97(Z.F=E=$5X<&ER97-!8G-O;'5T92@I"B`@("`J($!P87)A;2`@("!S=')I
M;F<@(&%D9&ET:6]N86P@=7-E<F1E9FEN960@9&%T80H@("`@*B!`<F5T=7)N
M("`@<W1R:6YG("!C86-H960@;W5T<'5T"B`@("`J($!A8V-E<W,@("!P=6)L
M:6,*("`@("H@0'-E92`@("`@(&5N9%!R:6YT*"DL(&5N9$=E="@I+"!#;VYT
M86EN97(Z.F=E=$5X<&ER97-!8G-O;'5T92@I"B`@("`J+PH@("`@9G5N8W1I
M;VX@96YD*"1E>'!I<F4@/2`P+"`D=7-E<F1A=&$@/2`G)RD@>PH@("`@("`@
M("1C;VYT96YT(#T@;V)?9V5T7V-O;G1E;G1S*"D["B`@("`@("`@;V)?96YD
M7V-L96%N*"D["@H@("`@("`@("\O('-T;W)E(&EN('1H92!C86-H90H@("`@
M("`@(&EF("@D=&AI<RT^8V%C:&EN9RD*("`@("`@("`@("`@)'1H:7,M/F-O
M;G1A:6YE<BT^<V%V92@D=&AI<RT^;W5T<'5T7VED+"`D8V]N=&5N="P@)&5X
M<&ER92P@)'1H:7,M/F]U='!U=%]G<F]U<"P@)'5S97)D871A*3L*"B`@("`@
M("`@<F5T=7)N("1C;VYT96YT.PH@("`@?2`O+R!E;F0@9G5N8R!E;F0H*0H*
M("`@("\J*@H@("`@*B!3=&]R97,@=&AE(&-O;G1E;G0@;V8@=&AE(&]U='!U
M="!B=69F97(@:6YT;R!T:&4@8V%C:&4@86YD('!R:6YT<R!T:&4@8V]N=&5N
M="X*("`@("H*("`@("H@0&)R;W1H97(@(&5N9"@I"B`@("`J+PH@("`@9G5N
M8W1I;VX@96YD4')I;G0H)&5X<&ER92`](#`L("1U<V5R9&%T82`]("<G*2![
M"B`@("`@("`@)'1H:7,M/G!R:6YT0V]N=&5N="@D=&AI<RT^96YD*"1E>'!I
M<F4L("1U<V5R9&%T82DI.PH@("`@?2`O+R!E;F0@9G5N8R!E;F10<FEN=`H*
M("`@("\J*@H@("`@*B!396YD<R!T:&4@9&%T82!T;R!T:&4@=7-E<BX*("`@
M("H@5&AI<R!I<R!F;W(@8V]M<&%T:6)I;&ET>2!W:71H($]U='!U=$-O;7!R
M97-S:6]N"B`@("`J(`H@("`@*B!`<&%R86T@("`@<W1R:6YG"B`@("`J($!A
M8V-E<W,@("!P=6)L:6,*("`@("HO("`@(`H@("`@9G5N8W1I;VX@<')I;G1#
M;VYT96YT*"1C;VYT96YT(#T@)R<I('L*("`@("`@("!I9B`H)R<@/3T@)&-O
M;G1E;G0I"B`@("`@("`@("`@("1C;VYT96YT(#T@)B1T:&ES+3YC;VYT86EN
M97(M/F-A8VAE9&%T83L*("`@("`@("`@("`@"B`@("`@("`@<')I;G0@)&-O
M;G1E;G0["B`@("!]"B`@("`O*BH*("`@("H@4F5T=7)N<R!T:&4@8V]N=&5N
M="!O9B!T:&4@;W5T<'5T(&)U9F9E<B!B=70@9&]E<R!N;W0@<W1O<F4@:70@
M:6YT;R!T:&4@8V%C:&4N"B`@("`J"B`@("`J(%5S92!T:&ES(&UE=&AO9"!I
M9B!T:&4@8V]N=&5N="!O9B!Y;W5R('-C<FEP="!I<R!M87)K=7`@*%A-3"D*
M("`@("H@=&AA="!H87,@=&\@8F4@<&%R<V5D+V-O;G9E<G1E9"`H6%-,5"D@
M8F5F;W)E('EO=2!C86X@;W5T<'5T"B`@("`J(&%N9"!S=&]R92!I="!I;G1O
M('1H92!C86-H92!U<VEN9R!S879E*"DN"B`@("`J"B`@("`J($!R971U<FX@
M("!S=')I;F<*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B!`<V5E("`@
M("`@96YD4')I;G0H*2P@96YD*"D*("`@("HO"B`@("!F=6YC=&EO;B!E;F1'
M970H*2!["B`@("`@("`@)&-O;G1E;G0@/2!O8E]G971?8V]N=&5N=',H*3L*
M("`@("`@("!O8E]E;F1?8VQE86XH*3L*"B`@("`@("`@)'1H:7,M/F]U='!U
M=%]I9"`]("<G.PH@("`@("`@("1T:&ES+3YO=71P=71?9W)O=7`@/2`G)SL*
M"B`@("`@("`@<F5T=7)N("1C;VYT96YT.PH@("`@?2`O+R!E;F0@9G5N8R!E
M;F1'970*?2`O+R!E;F0@8VQA<W,@;W5T<'5T"C\^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]#86-H92]/=71P=71#;VUP<F5S<VEO;BYP:'``
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,34S-``Q,#4Q-30S,S<S-``P
M,C0P-#<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M4$5!4B`Z.B!#86-H92`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@
M4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI
M8V5N<V4L("`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES
M('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\
M"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E
M(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@
M("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@075T:&]R<SH@56QF(%=E;F1E;"`\=6QF+G=E;F1E;$!P
M:'!D;V,N9&4^("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@
M("`@("`@($-H<FES=&EA;B!3=&]C:V5R(#QC:')E9W5`<&AA;G0N8V@^("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"@IR97%U:7)E7V]N8V4@)T-A8VAE+T]U='!U="YP:'`G.PH*
M+RHJ"BH@0V%C:&4@=7-I;F<@3W5T<'5T($)U9F9E<FEN9R!A;F0@8V]N=&YE
M="`H9WHI(&-O;7!R97-S:6]N+@HJ*B!5<V%G92!E>&%M<&QE.@HJ"BH@("\O
M('!L86-E('1H:7,@<V]M97=H97)E(&EN(&$@8V5N=')A;"!C;VYF:6<@9FEL
M90HJ("!D969I;F4H0T%#2$5?4U1/4D%'15]#3$%34RP@)V9I;&4G*3L**B`@
M+R\@9FEL92!S=&]R86=E(&YE961S(&$@9&ER('1O('!U="!T:&4@8V%C:&4@
M9FEL97,**B`@9&5F:6YE*$-!0TA%7T1)4BP@)R]V87(O=&UP+R<I.PHJ"BH@
M("\O(&=E="!A(&-A8VAE(&]B:F5C=`HJ("`D8V%C:&4@/2!N97<@0V%C:&5?
M3W5T<'5T*$-!0TA%7U-43U)!1T5?0TQ!4U,L(&%R<F%Y*"=C86-H95]D:7(G
M(#T^($-!0TA%7T1)4BDI.PHJ"BH@(&EF("@A*"1C;VYT96YT(#T@)&-A8VAE
M+3YS=&%R="@D8V%C:&4M/F=E;F5R871E240H)%)%455%4U1?55))*2DI*2![
M"BH@("`@<')I;G0@(FAE;&QO('=O<FQD(CL**B`@("`D8V%C:&4M/F5N9%!R
M:6YT*"LQ,#`P*3L**B`@?0HJ("!E;'-E('L**B`@("`D8V%C:&4M/G!R:6YT
M0V]N=&5N="@I.PHJ("!]"BH**B`@($]2"BH**B`@:68@*"@D8V]N=&5N="`]
M("1C86-H92T^<W1A<G0H)&-A8VAE+3YG96YE<F%T94E$*"1215%515-47U52
M22DI*2D@>PHJ("`@("1C86-H92T^<')I;G1#;VYT96YT*"D["BH@("`@9&EE
M*"D["BH@('T**B`@("!P<FEN="`B:&5L;&\@=V]R;&0B.PHJ("`@("1C86-H
M92T^96YD4')I;G0H*S$P,#`I.PHJ"BH**B!"87-E9"!U<&]N(&$@8V%S92!S
M='5D>2!F<F]M($-H<FES=&EA;B!3=&]C:V5R(&%N9"!I;G-P:7)E9"!B>2!J
M<&-A8VAE+@HJ"BH@0'9E<G-I;VX@("1)9#H@3W5T<'5T0V]M<')E<W-I;VXN
M<&AP+'8@,2XW(#(P,#,O,#$O,#0@,3$Z-30Z-#4@;6H@17AP("0**B!`875T
M:&]R("`@56QF(%=E;F1E;"`\=6QF+G=E;F1E;$!P:'!D;V,N9&4^+"!#:')I
M<W1I86X@4W1O8VME<B`\8VAR96=U0'!H86YT+F-H/@HJ($!A8V-E<W,@("!P
M=6)L:6,**B!`<&%C:V%G92`@0V%C:&4**B\*8VQA<W,@0V%C:&5?3W5T<'5T
M0V]M<')E<W-I;VX@97AT96YD<R!#86-H95]/=71P=70@>PH@("`@"B`@("`O
M*BH*("`@("H@16YC;V1I;F<L('=H870@=&AE('5S97(@*&ET<R!B<F]W<V5R
M*2!O9B!Y;W5R('=E8G-I=&4@86-C97!T<PH@("`@*B`*("`@("H@(F%U=&\B
M('-T86YD<R!F;W(@=&5S="!U<VEN9R`D7U-%4E9%4ELG2%144%]!0T-%4%1?
M14Y#3T1)3D<G72@D2%144%]!0T-%4%1?14Y#3T1)3D<I+@H@("`@*@H@("`@
M*B!`=F%R("!S=')I;F<*("`@("H@0'-E92`@0V%C:&5?3W5T<'5T0V]M<')E
M<W-I;VXH*2P@<V5T16YC;V1I;F<H*0H@("`@*B\*("`@('9A<B`D96YC;V1I
M;F<@/2`G875T;R<["B`*("`@(`H@("`@+RHJ"B`@("`J($UE=&AO9"!U<V5D
M(&9O<B!C;VUP<F5S<VEO;@H@("`@*@H@("`@*B!`=F%R("!S=')I;F<*("`@
M("H@0'-E92`@:7-#;VUP<F5S<V5D*"D*("`@("HO(`H@("`@=F%R("1C;VUP
M<F5S<VEO;B`]("<G.PH*("`@(`H@("`@+RHJ"B`@("`J(%-E=',@=&AE('-T
M;W)A9V4@9&5T86EL<R!A;F0@=&AE(&-O;G1E;G0@96YC;V1I;F<@=7-E9"`H
M:68@;F]T(&%U=&]D971E8W1I;VXI"B`@("`J(`H@("`@*B!`<&%R86T@("`@
M<W1R:6YG("!.86UE(&]F(&-O;G1A:6YE<B!C;&%S<PH@("`@*B!`<&%R86T@
M("`@87)R87D@("!!<G)A>2!W:71H(&-O;G1A:6YE<B!C;&%S<R!O<'1I;VYS
M"B`@("`J($!P87)A;2`@("!S=')I;F<@(&-O;G1E;G0@96YC;V1I;F<@;6]D
M92`M(&%U=&\@/3X@=&5S="!W:&EC:"!E;F-O9&EN9R!T:&4@=7-E<B!A8V-E
M<'1S"B`@("`J+R`@("`*("`@(&9U;F-T:6]N($-A8VAE7T]U='!U=$-O;7!R
M97-S:6]N*"1C;VYT86EN97(L("1C;VYT86EN97)?;W!T:6]N<R`]("<G+"`D
M96YC;V1I;F<@/2`G875T;R<I('L*("`@(`H@("`@("`@("1T:&ES+3YS971%
M;F-O9&EN9R@D96YC;V1I;F<I.PH@("`@("`@("1T:&ES+3Y#86-H92@D8V]N
M=&%I;F5R+"`D8V]N=&%I;F5R7V]P=&EO;G,I.PH@("`@("`@(`H@("`@?2`O
M+R!E;F0@8V]N<W1R=6-T;W(*"B`@("`*("`@("\J*@H@("`@*B!#86QL('!A
M<F5N="!D96-O;G-T<G5C=&]R+@H@("`@*B\*("`@(&9U;F-T:6]N(%]#86-H
M95]/=71P=71#;VUP<F5S<VEO;B@I('L*("`@("`@("`D=&AI<RT^7T-A8VAE
M*"D["B`@("!]("\O(&5N9"!D96-O;G-T<G5C=&]R"B`@("`*"B`@("!F=6YC
M=&EO;B!G96YE<F%T94E$*"1V87)I86)L92D@>PH@("`@("`@(`H@("`@("`@
M("1T:&ES+3YC;VUP<F5S<VEO;B`]("1T:&ES+3YG971%;F-O9&EN9R@I.PH@
M("`@("`@(`H@("`@("`@(')E='5R;B!M9#4H<V5R:6%L:7IE*"1V87)I86)L
M92D@+B!S97)I86QI>F4H)'1H:7,M/F-O;7!R97-S:6]N*2D["B`@("!]("\O
M(&5N9"!G96YE<F%T94E$"@H@("`@"B`@("!F=6YC=&EO;B!G970H)&ED+"`D
M9W)O=7`I('L*("`@("`@("`D=&AI<RT^8V]N=&5N="`]("<G.PH@("`@("`@
M(`H@("`@("`@(&EF("@A)'1H:7,M/F-A8VAI;F<I"B`@("`@("`@("`@(')E
M='5R;B`G)SL*("`@("`@("`*("`@("`@("!I9B`H)'1H:7,M/FES0V%C:&5D
M*"1I9"P@)&=R;W5P*2`F)B`A)'1H:7,M/FES17AP:7)E9"@D:60L("1G<F]U
M<"DI"B`@("`@("`@("`@("1T:&ES+3YC;VYT96YT(#T@)'1H:7,M/FQO860H
M)&ED+"`D9W)O=7`I.PH@("`@("`@("`@("`*("`@("`@("!R971U<FX@)'1H
M:7,M/F-O;G1E;G0["B`@("!]("\O(&5N9"!F=6YC(&=E=`H@("`@"B`@("`*
M("`@("\J*@H@("`@*B!3=&]P<R!T:&4@;W5T<'5T(&)U9F9E<FEN9RP@<V%V
M97,@:70@=&\@=&AE(&-A8VAE(&%N9"!R971U<FYS('1H92!?8V]M<')E<W-E
M9%\@8V]N=&5N="X@"B`@("`J"B`@("`J($EF('EO=2!N965D('1H92!U;F-O
M;7!R97-S960@8V]N=&5N="!F;W(@9G5R=&AE<B!P<F]C97-S:6]N(&)E9F]R
M90H@("`@*B!I="=S('-A=F5D(&EN('1H92!C86-H92!U<V4@96YD1V5T*"DN
M(&5N9$=E="@I(&1O97,@7VYO="!C;VUP<F5S<U\N"B`@("`J+R`@("`*("`@
M(&9U;F-T:6]N(&5N9"@D97AP:7)E(#T@,"P@)'5S97)D871A(#T@)R<I('L*
M("`@("`@("`D8V]N=&5N="`](&]B7V=E=%]C;VYT96YT<R@I.PH@("`@("`@
M(&]B7V5N9%]C;&5A;B@I.PH*("`@("`@("`O+R!S=&]R92!I;B!T:&4@8V%C
M:&4*("`@("`@("!I9B`H)'1H:7,M/F-A8VAI;F<I('L*("`@("`@("`@("`@
M)'1H:7,M/F5X=%-A=F4H)'1H:7,M/F]U='!U=%]I9"P@)&-O;G1E;G0L("1U
M<V5R9&%T82P@)&5X<&ER92P@)'1H:7,M/F]U='!U=%]G<F]U<"D["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^8V]N=&5N=#L@("`@("`@("`@("`@("`@
M"B`@("`@("`@?0H@("`@("`@("`@("`*("`@("`@("!R971U<FX@)&-O;G1E
M;G0[("`@("`@("`*("`@('T@+R\@96YD(&9U;F,@96YD*"D*("`@(`H@("`@
M"B`@("!F=6YC=&EO;B!E;F10<FEN="@D97AP:7)E(#T@,"P@)'5S97)D871A
M(#T@)R<I('L*("`@("`@("`D=&AI<RT^<')I;G1#;VYT96YT*"1T:&ES+3YE
M;F0H)&5X<&ER92P@)'5S97)D871A*2D["B`@("!]("\O(&5N9"!F=6YC(&5N
M9%!R:6YT"@H@("`@"B`@("`O*BH*("`@("H@4V%V97,@=&AE(&=I=F5N(&1A
M=&$@=&\@=&AE(&-A8VAE+@H@("`@*B`*("`@("HO("`@"B`@("!F=6YC=&EO
M;B!E>'13879E*"1I9"P@)&-A8VAE9&%T82P@)'5S97)D871A+"`D97AP:7)E
M<R`](#`L("1G<F]U<"`]("=D969A=6QT)RD@>PH@("`@("`@(&EF("@A)'1H
M:7,M/F-A8VAI;F<I"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH*("`@("`@
M("!I9B`H)'1H:7,M/F-O;7!R97-S:6]N*2![("`@("`@("`@("`@"B`@("`@
M("`@("`@(`H@("`@("`@("`@("`D;&5N(#T@<W1R;&5N*"1C86-H961A=&$I
M.R`@("`@("`@("`@(`H@("`@("`@("`@("`D8W)C(#T@8W)C,S(H)&-A8VAE
M9&%T82D["B`@("`@("`@("`@("1C86-H961A=&$@/2!G>F-O;7!R97-S*"1C
M86-H961A=&$L(#DI.PH@("`@("`@("`@("`D=&AI<RT^8V]N=&5N="`]('-U
M8G-T<B@D8V%C:&5D871A+"`P+"!S=')L96XH)&-A8VAE9&%T82D@+2`T*2`N
M('!A8VLH)U8G+"`D8W)C*2`N('!A8VLH)U8G+"`D;&5N*3L*("`@("`@("`@
M("`@"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@"B`@("`@("`@("`@
M("1T:&ES+3YC;VYT96YT(#T@)&-A8VAE9&%T83L*("`@("`@("`@("`@"B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^8V]N=&%I;F5R+3YS879E
M*"1I9"P@)'1H:7,M/F-O;G1E;G0L("1E>'!I<F5S+"`D9W)O=7`L("1U<V5R
M9&%T82D["B`@("!]("\O(&5N9"!F=6YC(&5X=%-A=F4*("`@(`H@("`@+RHJ
M"B`@("`J(%-E;F1S('1H92!C;VUP<F5S<V5D(&1A=&$@=&\@=&AE('5S97(N
M"B`@("`J(`H@("`@*B!`<&%R86T@("`@<W1R:6YG"B`@("`J($!A8V-E<W,@
M("!P=6)L:6,*("`@("HO("`@(`H@("`@9G5N8W1I;VX@<')I;G1#;VYT96YT
M*"1C;VYT96YT(#T@)R<I('L*("`@("`@("`D<V5R=F5R(#T@)B1T:&ES+3Y?
M:6UP;W)T1VQO8F%L5F%R:6%B;&4H(G-E<G9E<B(I.PH*("`@("`@("!I9B`H
M)R<@/3T@)&-O;G1E;G0I"B`@("`@("`@("`@("1C;VYT96YT(#T@)B1T:&ES
M+3YC;VYT86EN97(M/F-A8VAE9&%T83L*("`@("`@("`@("`@("`@("`*("`@
M("`@("!I9B`H)'1H:7,M/F-O;7!R97-S:6]N("8F("1T:&ES+3YC86-H:6YG
M*2!["B`@(`H@("`@("`@("`@("`D971A9R`]("=014%2+4-A8VAE+2<@+B!M
M9#4H<W5B<W1R*"1C;VYT96YT+"`M-#`I*3L*("`@("`@("`@("`@:&5A9&5R
M*")%5&%G.B`D971A9R(I.PH@("`@("`@("`@("!I9B`H:7-S970H)'-E<G9E
M<ELG2%144%])1E].3TY%7TU!5$-()UTI("8F('-T<G-T<BAS=')I<'-L87-H
M97,H)'-E<G9E<ELG2%144%])1E].3TY%7TU!5$-()UTI+"`D971A9RDI('L*
M("`@("`@("`@("`@("`@("\O(&YO="!M;V1I9FEE9`H@("`@("`@("`@("`@
M("`@:&5A9&5R*"=(5%10+S$N,"`S,#0G*3L*("`@("`@("`@("`@("`@(')E
M='5R;CL*("`@("`@("`@("`@?2!E;'-E('L*("`@"B`@("`@("`@("`@("`@
M("`O+R!C;&EE;G0@86-C97!P=',@<V]M92!E;F-O9&EN9R`M('-E;F0@:&5A
M9&5R<R`F(&1A=&$*("`@("`@("`@("`@("`@(&AE861E<B@B0V]N=&5N="U%
M;F-O9&EN9SH@>R1T:&ES+3YC;VUP<F5S<VEO;GTB*3L*("`@("`@("`@("`@
M("`@(&AE861E<B@G5F%R>3H@06-C97!T+45N8V]D:6YG)RD["B`@("`@("`@
M("`@("`@("!P<FEN="`B7'@Q9EQX.&)<>#`X7'@P,%QX,#!<>#`P7'@P,%QX
M,#`B.PH@("`@("`@("`@("!]"B`@("`@("`@"B`@("`@("`@?0H@("`@("`@
M(`H@("`@("`@(&1I92@D8V]N=&5N="D["B`@("!]("\O(&5N9"!F=6YC('!R
M:6YT0V]N=&5N=`H@("`@"B`@("`*("`@("\J*@H@("`@*B!2971U<FYS('1H
M92!E;F-O9&EN9R!M971H;V0@;V8@=&AE(&-U<G)E;G0@9&%T87-E="X@"B`@
M("`J"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("H@0')E='5R;B`@('-T
M<FEN9R`@16UP='D@<W1R:6YG("AW:&EC:"!E=F%L=6%T97,@=&\@9F%L<V4I
M(&UE86YS(&YO(&-O;7!R97-S:6]N"B`@("`J+PH@("`@9G5N8W1I;VX@:7-#
M;VUP<F5S<V5D*"D@>PH@("`@("`@(')E='5R;B`D=&AI<RT^8V]M<')E<W-I
M;VX["B`@("!]("\O(&5N9"!F=6YC(&ES0V]M<')E<W-E9`H*("`@("\J*@H@
M("`@*B!3971S('1H92!E;F-O9&EN9R!T;R!B92!U<V5D+@H@("`@*B`*("`@
M("H@0'!A<F%M("`@('-T<FEN9R`@(F%U=&\B(&UE86YS(&%U=&]D971E8W0@
M9F]R(&5V97)Y(&-L:65N=`H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J
M($!S964@("`@("`D96YC;V1I;F<*("`@("HO"B`@("!F=6YC=&EO;B!S971%
M;F-O9&EN9R@D96YC;V1I;F<@/2`G875T;R<I('L*("`@("`@("`D=&AI<RT^
M96YC;V1I;F<@/2`D96YC;V1I;F<["B`@("!]("\O(&5N9"!F=6YC('-E=$5N
M8V]D:6YG"B`@("`*("`@(`H@("`@+RHJ"B`@("`J(%)E='5R;G,@=&AE(&5N
M8V]D:6YG('1O(&)E('5S960@9F]R('1H92!D871A('1R86YS;6ES<VEO;B!T
M;R!T:&4@8VQI96YT+@H@("`@*@H@("`@*B!`<V5E("`@("`@<V5T16YC;V1I
M;F<H*0H@("`@*B\@("`@"B`@("!F=6YC=&EO;B!G971%;F-O9&EN9R@I('L*
M("`@("`@("`D<V5R=F5R(#T@)B1T:&ES+3Y?:6UP;W)T1VQO8F%L5F%R:6%B
M;&4H(G-E<G9E<B(I.PH*("`@("`@("`O+R!E;F-O9&EN9R!S970@8GD@=7-E
M<B`@("`*("`@("`@("!I9B`H)V%U=&\G("$]("1T:&ES+3YE;F-O9&EN9RD*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YE;F-O9&EN9SL*("`@("`@("`*
M("`@("`@("`O+R!C:&5C:R!W:&%T('1H92!C;&EE;G0@86-C97!T<PH@("`@
M("`@(&EF("AF86QS92`A/3T@<W1R<&]S*"1S97)V97);)TA45%!?04-#15!4
M7T5.0T]$24Y')UTL("=X+6=Z:7`G*2D*("`@("`@("`@("`@<F5T=7)N("=X
M+6=Z:7`G.PH@("`@("`@(&EF("AF86QS92`A/3T@<W1R<&]S*"1S97)V97);
M)TA45%!?04-#15!47T5.0T]$24Y')UTL("=G>FEP)RDI"B`@("`@("`@("`@
M(')E='5R;B`G9WII<"<["B`@("`@("`@("`@(`H@("`@("`@("\O(&YO(&-O
M;7!R97-S:6]N"B`@("`@("`@<F5T=7)N("<G.PH@("`@("`@(`H@("`@?2`O
M+R!E;F0@9G5N8R!G971%;F-O9&EN9PH*("`@("\O('M[>R!?:6UP;W)T1VQO
M8F%L5F%R:6%B;&4H*0H*("`@("\J*@H@("`@("H@26UP;W)T('9A<FEA8FQE
M<R!F<F]M('-P96-I86P@;F%M97-P86-E<RX*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J($!P87)A;2!S=')I;F<@5'EP92!O9B!V87)I
M86)L92`H<V5R=F5R+"!S97-S:6]N+"!P;W-T*0H@("`@("H@0')E='5R;B!A
M<G)A>0H@("`@("HO"B`@("!F=6YC=&EO;B`F7VEM<&]R=$=L;V)A;%9A<FEA
M8FQE*"1V87)I86)L92D@"B`@("!["B`@("`@(`H@("`@("`@("1V87(@/2!N
M=6QL.PH*("`@("`@("!S=VET8V@@*'-T<G1O;&]W97(H)'9A<FEA8FQE*2D@
M>PH*("`@("`@("`@("`@8V%S92`B<V5R=F5R(B`Z"B`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)%]315)615(I*2!["B`@("`@("`@("`@("`@("`@("`@
M)'9A<B`]("8D7U-%4E9%4CL*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@)'9A<B`]("8D1TQ/0D%,4ULG2%144%]315)6
M15)?5D%24R==.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("!C87-E(")S97-S:6]N(B`Z"B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)%]315-324].*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1V87(@/2`F)%]315-324]..PH@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D=F%R(#T@)B1'3$]"04Q36R=(
M5%107U-%4U-)3TY?5D%24R==.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(")P;W-T(B`Z"B`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)%]03U-4*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1V87(@/2`F)%]03U-4.PH@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D=F%R(#T@)B1'3$]"04Q36R=(
M5%107U!/4U1?5D%24R==.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1V87([
M"B`@("!](`H*("`@("\O('U]"GT@+R\@96YD(&-L87-S($]U='!U=$-O;7!R
M97-S:6]N"C\^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-A8VAE+G!H<```````````````
M````````````````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(U,C4V`#$P-3$U
M-#,S-S0S`#`R,#,S,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!014%2(#HZ($-A8VAE("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR
M,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H
M92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W
M:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@
M("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N
M86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O
M('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@
M:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!5;&8@5V5N9&5L(#QU;&8N
M=V5N9&5L0'!H<&1O8RYD93X@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O('P@("`@("`@("`@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I
M86XM8F5R9VUA;FXN9&4^("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!#86-H92YP:'`L=B`Q+C4@
M,C`P,R\P,2\P-"`Q,3HU-#HT-2!M:B!%>'`@)`H*<F5Q=6ER95]O;F-E("=0
M14%2+G!H<"<["G)E<75I<F5?;VYC92`G0V%C:&4O17)R;W(N<&AP)SL*"B\J
M*@HJ($-A8VAE(&ES(&$@8F%S92!C;&%S<R!F;W(@8V%C:&4@:6UP;&5M96YT
M871I;VYS+@HJ"BH@5&AE('!E87(@8V%C:&4@;6]D=6QE(&ES(&$@9V5N97)I
M8R!D871A(&-A8VAE('=H:6-H(&-A;B!B92!U<V5D('1O(`HJ(&-A8VAE('-C
M<FEP="!R=6YS+B!4:&4@:61E82!B96AI;F0@=&AE(&-A8VAE(&ES('%U:71E
M('-I;7!L92X@268@>6]U(&AA=F4**B!T:&4@<V%M92!I;G!U="!P87)A;65T
M97)S(&9O<B!W:&%T979E<B!T87-K<R]A;&=O<FET:&T@>6]U('5S92!Y;W4G
M;&P**B!U<W5A;&QY(&=E="!T:&4@<V%M92!O=71P=70N(%-O('=H>2!N;W0@
M8V%C:&EN9R!T96UP;&%T97,L(&9U;F-T:6]N<R!C86QL<RP**B!G<F%P:&EC
M(&=E;F5R871I;VX@971C+B!#86-H:6YG(&-E<G1A:6X@86-T:6]N<R!E+F<N
M(%A33%0@=')A;F9O<FUA=&EO;G,**B!S879E<R!Y;W4@;&]T<R!O9B!T:6UE
M+B`**@HJ(%1H92!D97-I9VX@;V8@=&AE(&-A8VAE(')E;6EN9',@;V8@4$A0
M3&EB<R!S97-S:6]N(&EM<&QE;65N=&%T:6]N+B!!(`HJ("A02%!,:6(Z('-E
M<W-I;VXI(&-O;G1R;VQL97(@=7-E<R!S=&]R86=E(&-O;G1A:6YE<B`H4$A0
M3&EB.B!C=%\J+FEN8RD@=&\@<V%V92`**B!C97)T86EN(&1A=&$@*%!(4$QI
M8CH@<V5S<VEO;B!D871A*2X@26X@8V]N=')A<W0@=&\@=&AE('-E<W-I;VX@
M<W1U9F8@:70G<R!U<"!T;R`**B!Y;W4@=&\@9V5N97)A=&4@86X@240@9F]R
M('1H92!D871A('1O(&-A8VAE+B!)9B!Y;W4G<F4@=7-I;F<@=&AE(&]U='!U
M="!C86-H90HJ('EO=2!M:6=H="!U<V4@=&AE('-C<FEP="!N86UE(&%S(&$@
M<V5E9"!F;W(@8V%C:&4Z.F=E;F5R871E240H*2P@:68@>6]U<B!U<VEN9R!T
M:&4**B!F=6YC=&EO;B!C86-H92!Y;W4G9"!U<V4@86X@87)R87D@=VET:"!A
M;&P@9G5N8W1I;VX@<&%R86UE=&5R<RX**@HJ(%5S86=E(&5X86UP;&4@;V8@
M=&AE(&=E;F5R:6,@9&%T82!C86-H93H**@HJ(')E<75I<F5?;VYC92@G0V%C
M:&4N<&AP)RD["BH**B`D8V%C:&4@/2!N97<@0V%C:&4H)V9I;&4G+"!A<G)A
M>2@G8V%C:&5?9&ER)R`]/B`G8V%C:&4O)RD@*3L**B`D:60@/2`D8V%C:&4M
M/F=E;F5R871E240H)W1E<W1E;G1R>2<I.PHJ"BH@:68@*"1D871A(#T@)&-A
M8VAE+3YG970H)&ED*2D@>PHJ("`@('!R:6YT(")#86-H92!H:70N/&)R/D1A
M=&$Z("1D871A(CL**@HJ('T@96QS92!["BH@("`D9&%T82`]("=D871A(&]F
M(&%N>2!K:6YD)SL**B`@("1C86-H92T^<V%V92@D:60L("1D871A*3L**B`@
M('!R:6YT("=#86-H92!M:7-S+CQB<CXG.PHJ('T**@HJ(%=!4DY)3D<Z($YO
M($9I;&4O1$(M5&%B;&4M4F]W(&QO8VMI;F<@:7,@:6UP;&5M96YT960@>65T
M+`HJ("`@("`@("`@(&ET)W,@<&]S<VEB;&4L('1H870@>6]U(&=E="!C;W)R
M=7!T960@9&%T82UE;G1R:65S('5N9&5R"BH@("`@("`@("`@8F%D(&-I<F-U
M;7-T86YC97,@("AE<W!E8VEA;&QY('=I=&@@=&AE(&9I;&4@8V]N=&%I;F5R
M*0HJ"BH@0&%U=&AO<B`@(%5L9B!796YD96P@/'5L9BYW96YD96Q`<&AP9&]C
M+F1E/@HJ($!V97)S:6]N("`D260Z($-A8VAE+G!H<"QV(#$N-2`R,#`S+S`Q
M+S`T(#$Q.C4T.C0U(&UJ($5X<"`D"BH@0'!A8VMA9V4@($-A8VAE"BH@0&%C
M8V5S<R`@('!U8FQI8PHJ+PIC;&%S<R!#86-H92!E>'1E;F1S(%!%05(@>PH*
M("`@("\J*@H@("`@*B!%;F%B;&5S("\@9&ES86)L97,@8V%C:&EN9RX*("`@
M("H*("`@("H@5$]$3SH@061D(&5X<&QA;F%T:6]N('=H870@=&AI<R!I<R!G
M;V]D(&9O<BX*("`@("H*("`@("H@0'9A<B`@("`@(&)O;VQE86X*("`@("H@
M0&%C8V5S<R`@('!R:79A=&4*("`@("HO"B`@("!V87(@)&-A8VAI;F<@/2!T
M<G5E.PH*("`@("\J*@H@("`@*B!'87)B86=E(&-O;&QE8W1I;VXZ('!R;V)A
M8FEL:71Y(&EN('-E8V]N9',*("`@("H*("`@("H@268@<V5T('1O(&$@=F%L
M=64@86)O=F4@,"!A(&=A<F)A9V4@8V]L;&5C=&EO;B!W:6QL"B`@("`J(&9L
M=7-H(&%L;"!C86-H92!E;G1R:65S(&]L9&5R('1H86X@=&AE('-P96-I9FEE
M9"!N=6UB97(*("`@("H@;V8@<V5C;VYD<RX*("`@("H*("`@("H@0'9A<B`@
M("`@(&EN=&5G97(*("`@("H@0'-E92`@("`@("1G8U]P<F]B86)I;&ET>2P@
M)&=C7VUA>&QI9F5T:6UE"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("HO
M"B`@("!V87(@)&=C7W1I;64@(#T@,3L*"B`@("`O*BH*("`@("H@1V%R8F%G
M92!C;VQL96-T:6]N.B!P<F]B86)I;&ET>2!I;B!P97)C96YT"B`@("`J"B`@
M("`J(%1/1$\Z($%D9"!A;B!E>'!L86YA=&EO;BX*("`@("H*("`@("H@0'9A
M<B`@("`@(&EN=&5G97(@("`@(#`@/3X@;F5V97(*("`@("H@0'-E92`@("`@
M("1G8U]T:6UE+"`D9V-?;6%X;&EF971I;64*("`@("H@0&%C8V5S<R`@('!U
M8FQI8PH@("`@*B\*("`@('9A<B`D9V-?<')O8F%B:6QI='D@/2`Q.PH@("`@
M"B`@("`O*BH*("`@("H@1V%R8F%G92!C;VQL96-T:6]N.B!D96QE=&4@86QL
M(&5N=')I97,@;F]T('5S92!F;W(@;B!S96-O;F1S+@H@("`@*@H@("`@*B!$
M969A=6QT(&ES(&]N92!D87DL(#8P("H@-C`@*B`R-"`](#@V-#`P('-E8V]N
M9',N"B`@("`J"B`@("`J($!V87(@(&EN=&5G97(*("`@("H@0'-E92`@)&=C
M7W!R;V)A8FEL:71Y+"`D9V-?=&EM90H@("`@*B\*("`@('9A<B`D9V-?;6%X
M;&EF971I;64@/2`X-C0P,#L*"B`@("`O*BH*("`@("H@4W1O<F%G92!C;VYT
M86EN97(@;V)J96-T+@H@("`@*@H@("`@*B!`=F%R("!O8FIE8W0@0V%C:&5?
M0V]N=&%I;F5R"B`@("`J+PH@("`@=F%R("1C;VYT86EN97(["@H@("`@+R\*
M("`@("\O('!U8FQI8R!M971H;V1S"B`@("`O+PH*("`@("\J*@H@("`@*@H@
M("`@*B!`<&%R86T@("`@<W1R:6YG("!.86UE(&]F(&-O;G1A:6YE<B!C;&%S
M<PH@("`@*B!`<&%R86T@("`@87)R87D@("!!<G)A>2!W:71H(&-O;G1A:6YE
M<B!C;&%S<R!O<'1I;VYS"B`@("`J+PH@("`@9G5N8W1I;VX@0V%C:&4H)&-O
M;G1A:6YE<BP@)&-O;G1A:6YE<E]O<'1I;VYS(#T@)R<I"B`@("!["B`@("`@
M("`@)'1H:7,M/E!%05(H*3L*("`@("`@("`D8V]N=&%I;F5R(#T@<W1R=&]L
M;W=E<B@D8V]N=&%I;F5R*3L*("`@("`@("`D8V]N=&%I;F5R7V-L87-S(#T@
M)T-A8VAE7T-O;G1A:6YE<E\G("X@)&-O;G1A:6YE<CL*("`@("`@("`D8V]N
M=&%I;F5R7V-L87-S9FEL92`]("=#86-H92]#;VYT86EN97(O)R`N("1C;VYT
M86EN97(@+B`G+G!H<"<["@H@("`@("`@(&EN8VQU9&5?;VYC92`D8V]N=&%I
M;F5R7V-L87-S9FEL93L*("`@("`@("`D=&AI<RT^8V]N=&%I;F5R(#T@;F5W
M("1C;VYT86EN97)?8VQA<W,H)&-O;G1A:6YE<E]O<'1I;VYS*3L*("`@('T*
M"B`@("`O+V1E8V]N<W1R=6-T;W(*("`@(&9U;F-T:6]N(%]#86-H92@I"B`@
M("!["B`@("`@("`@)'1H:7,M/F=A<F)A9V5#;VQL96-T:6]N*"D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C=7)R96YT(&-A8VAI;F<@
M<W1A=&4N"B`@("`@*@H@("`@("H@0')E='5R;B`@8F]O;&5A;B`@("`@5&AE
M(&-U<G)E;G0@8V%C:&EN9R!S=&%T92X*("`@("`J($!A8V-E<W,@('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971#86-H:6YG*"D*("`@('L*("`@
M("`@("!R971U<FX@*"1T:&ES+3YC86-H:6YG*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($5N86)L97,@;W(@9&ES86)L97,@8V%C:&EN9RX*("`@("`J"B`@
M("`@*B!`<&%R86T@("!B;V]L96%N("`@("!4:&4@;F5W(&-A8VAI;F<@<W1A
M=&4N"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V5T0V%C:&EN9R@D<W1A=&4I"B`@("!["B`@("`@("`@)'1H:7,M/F-A
M8VAI;F<@/2`D<W1A=&4["B`@("!]"@H@("`@+RHJ"B`@("`J(%)E='5R;G,@
M=&AE(')E<75E<W1E9"!D871A<V5T(&ET(&EF(&5X:7-T<R!A;F0@:7,@;F]T
M(&5X<&ER960*("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T87-E
M="!)1`H@("`@*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@("`@
M*B!`<F5T=7)N("`@;6EX960@("!C86-H960@9&%T82!O<B!.54Q,(&]N(&9A
M:6QU<F4*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B\*("`@(&9U;F-T
M:6]N(&=E="@D:60L("1G<F]U<"`]("=D969A=6QT)RD@>PH@("`@("`@(&EF
M("@A)'1H:7,M/F-A8VAI;F<I"B`@("`@("`@("`@(')E='5R;B`G)SL*"B`@
M("`@("`@:68@*"1T:&ES+3YI<T-A8VAE9"@D:60L("1G<F]U<"D@)B8@(21T
M:&ES+3YI<T5X<&ER960H)&ED+"`D9W)O=7`I*0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/FQO860H)&ED+"`D9W)O=7`I.PH*("`@("`@("!R971U<FX@
M3E5,3#L*("`@('T@+R\@96YD(&9U;F,@9V5T"@H@("`@+RHJ"B`@("`J(%-T
M;W)E<R!T:&4@9VEV96X@9&%T82!I;B!T:&4@8V%C:&4N"B`@("`J"B`@("`J
M($!P87)A;2`@("!S=')I;F<@(&1A=&%S970@240@=7-E9"!A<R!C86-H92!I
M9&5N=&EF:65R"B`@("`J($!P87)A;2`@("!M:7AE9"`@(&1A=&$@=&\@8V%C
M:&4*("`@("H@0'!A<F%M("`@(&EN=&5G97(@;&EF971I;64@;V8@=&AE(&-A
M8VAE9"!D871A(&EN('-E8V]N9',@+2`P(&9O<B!E;F1L97-S"B`@("`J($!P
M87)A;2`@("!S=')I;F<@(&-A8VAE(&=R;W5P"B`@("`J($!R971U<FX@("!B
M;V]L96%N"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("HO"B`@("!F=6YC
M=&EO;B!S879E*"1I9"P@)&1A=&$L("1E>'!I<F5S(#T@,"P@)&=R;W5P(#T@
M)V1E9F%U;'0G*2!["B`@("`@("`@:68@*"$D=&AI<RT^8V%C:&EN9RD*("`@
M("`@("`@("`@<F5T=7)N('1R=64["@H@("`@("`@(')E='5R;B`D=&AI<RT^
M97AT4V%V92@D:60L("1D871A+"`G)RPD97AP:7)E<RP@)&=R;W5P*3L*("`@
M('T@+R\@96YD(&9U;F,@<V%V90H*("`@("\J*@H@("`@*B!3=&]R97,@82!D
M871A<V5T('=I=&@@861D:71I;VYA;"!U<V5R9&5F:6YE9"!D871A+@H@("`@
M*@H@("`@*B!`<&%R86T@("`@<W1R:6YG("!D871A<V5T($E$"B`@("`J($!P
M87)A;2`@("!M:7AE9"`@(&1A=&$@=&\@<W1O<F4*("`@("H@0'!A<F%M("`@
M('-T<FEN9R`@861D:71I;VYA;"!U<V5R9&5F:6YE9"!D871A"B`@("`J($!P
M87)A;2`@("!M:7AE9"`@('5S97)D969I;F5D(&5X<&ER92!D871E"B`@("`J
M($!P87)A;2`@("!S=')I;F<@(&-A8VAE(&=R;W5P"B`@("`J($!R971U<FX@
M("!B;V]L96%N"B`@("`J($!T:')O=W,@("!#86-H95]%<G)O<@H@("`@*B!`
M86-C97-S("`@<'5B;&EC"B`@("`J($!S964@("`@("!G9715<V5R9&%T82@I
M"B`@("`J+PH@("`@9G5N8W1I;VX@97AT4V%V92@D:60L("1C86-H961A=&$L
M("1U<V5R9&%T82P@)&5X<&ER97,@/2`P+"`D9W)O=7`@/2`G9&5F875L="<I
M('L*("`@("`@("!I9B`H(21T:&ES+3YC86-H:6YG*0H@("`@("`@("`@("!R
M971U<FX@=')U93L*"B`@("`@("`@<F5T=7)N("1T:&ES+3YC;VYT86EN97(M
M/G-A=F4H)&ED+"`D8V%C:&5D871A+"`D97AP:7)E<RP@)&=R;W5P+"`D=7-E
M<F1A=&$I.PH@("`@?2`O+R!E;F0@9G5N8R!E>'13879E"@H@("`@+RHJ"B`@
M("`J($QO861S('1H92!G:79E;B!)1"!F<F]M('1H92!C86-H92X*("`@("H*
M("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T87-E="!)1`H@("`@*B!`<&%R
M86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@("`@*B!`<F5T=7)N("`@;6EX
M960@("!C86-H960@9&%T82!O<B!.54Q,(&]N(&9A:6QU<F4*("`@("H@0&%C
M8V5S<R`@('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(&QO860H)&ED+"`D
M9W)O=7`@/2`G9&5F875L="<I('L*("`@("`@("!I9B`H(21T:&ES+3YC86-H
M:6YG*0H@("`@("`@("`@("!R971U<FX@)R<["@H@("`@("`@(')E='5R;B`D
M=&AI<RT^8V]N=&%I;F5R+3YL;V%D*"1I9"P@)&=R;W5P*3L*("`@('T@+R\@
M96YD(&9U;F,@;&]A9`H*("`@("\J*@H@("`@*B!2971U<FYS('1H92!U<V5R
M9&%T82!F:65L9"!O9B!A(&-A8VAE9"!D871A('-E="X*("`@("H*("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@9&%T87-E="!)1`H@("`@*B!`<&%R86T@("`@
M<W1R:6YG("!C86-H92!G<F]U<`H@("`@*B!`<F5T=7)N("`@<W1R:6YG("!U
M<V5R9&%T80H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J($!S964@("`@
M("!E>'13879E*"D*("`@("HO"B`@("!F=6YC=&EO;B!G9715<V5R9&%T82@D
M:60L("1G<F]U<"`]("=D969A=6QT)RD@>PH@("`@("`@(&EF("@A)'1H:7,M
M/F-A8VAI;F<I"B`@("`@("`@("`@(')E='5R;B`G)SL*"B`@("`@("`@<F5T
M=7)N("1T:&ES+3YC;VYT86EN97(M/F=E=%5S97)D871A*"1I9"P@)&=R;W5P
M*3L*("`@('T@+R\@96YD(&9U;F,@9V5T57-E<F1A=&$*"B`@("`O*BH*("`@
M("H@4F5M;W9E<R!T:&4@<W!E8VEF:65D(&1A=&%S970@9G)O;2!T:&4@8V%C
M:&4N"B`@("`J"B`@("`J($!P87)A;2`@("!S=')I;F<@(&1A=&%S970@240*
M("`@("H@0'!A<F%M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@("H@0')E
M='5R;B`@(&)O;VQE86X*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B\*
M("`@(&9U;F-T:6]N(')E;6]V92@D:60L("1G<F]U<"`]("=D969A=6QT)RD@
M>PH@("`@("`@(&EF("@A)'1H:7,M/F-A8VAI;F<I"B`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH*("`@("`@("!R971U<FX@)'1H:7,M/F-O;G1A:6YE<BT^
M<F5M;W9E*"1I9"P@)&=R;W5P*3L*("`@('T@+R\@96YD(&9U;F,@<F5M;W9E
M"@H@("`@+RHJ"B`@("`J($9L=7-H97,@=&AE(&-A8VAE("T@<F5M;W9E<R!A
M;&P@9&%T82!F<F]M(&ET"B`@("`J"B`@("`J($!P87)A;2`@("!S=')I;F<@
M(&-A8VAE(&=R;W5P+"!I9B!E;7!T>2!A;&P@9W)O=7!S('=I;&P@8F4@9FQA
M<VAE9`H@("`@*B!`<F5T=7)N("`@:6YT96=E<B!N=6UB97(@;V8@<F5M;W9E
M9"!D871A<V5T<PH@("`@*B\*("`@(&9U;F-T:6]N(&9L=7-H*"1G<F]U<"`]
M("=D969A=6QT)RD@>PH@("`@("`@(&EF("@A)'1H:7,M/F-A8VAI;F<I"B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH*("`@("`@("!R971U<FX@)'1H:7,M
M/F-O;G1A:6YE<BT^9FQU<V@H)&=R;W5P*3L*("`@('T@+R\@96YD(&9U;F,@
M9FQU<V@*"B`@("`O*BH*("`@("H@0VAE8VMS(&EF(&$@9&%T87-E="!E>&ES
M=',N"B`@("`J"B`@("`J($YO=&4Z('1H:7,@9&]E<R!N;W0@<V%Y('1H870@
M=&AE(&-A8VAE9"!D871A(&ES(&YO="!E>'!I<F5D(0H@("`@*@H@("`@*B!`
M<&%R86T@("`@<W1R:6YG("!D871A<V5T($E$"B`@("`J($!P87)A;2`@("!S
M=')I;F<@(&-A8VAE(&=R;W5P"B`@("`J($!R971U<FX@("!B;V]L96%N"B`@
M("`J($!A8V-E<W,@("!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!I<T-A
M8VAE9"@D:60L("1G<F]U<"`]("=D969A=6QT)RD@>PH@("`@("`@(&EF("@A
M)'1H:7,M/F-A8VAI;F<I"B`@("`@("`@("`@(')E='5R;B!F86QS93L*"B`@
M("`@("`@<F5T=7)N("1T:&ES+3YC;VYT86EN97(M/FES0V%C:&5D*"1I9"P@
M)&=R;W5P*3L*("`@('T@+R\@96YD(&9U;F,@:7-#86-H960*"B`@("`O*BH*
M("`@("H@0VAE8VMS(&EF(&$@9&%T87-E="!I<R!E>'!I<F5D"B`@("`J"B`@
M("`J($!P87)A;2`@("!S=')I;F<@(&1A=&%S970@240*("`@("H@0'!A<F%M
M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@("H@0'!A<F%M("`@(&EN=&5G
M97(@;6%X:6UU;2!A9V4@9F]R('1H92!C86-H960@9&%T82!I;B!S96-O;F1S
M("T@,"!F;W(@96YD;&5S<PH@("`@*B`@("`@("`@("`@("`@("`@("!)9B!T
M:&4@8V%C:&5D(&1A=&$@:7,@;VQD97(@8G5T('1H92!G:79E;B!L:69E=&EM
M92!I="!W:6QL"B`@("`J("`@("`@("`@("`@("`@("`@(&)E(')E;6]V960@
M9G)O;2!T:&4@8V%C:&4N(%EO=2!D;VXG="!H879E('1O('!R;W9I9&4@=&AI
M<PH@("`@*B`@("`@("`@("`@("`@("`@("!A<F=U;65N="!I9B!Y;W4@8V%L
M;"!I<T5X<&ER960H*2X@179E<GD@9&%T87-E="!K;F]W<PH@("`@*B`@("`@
M("`@("`@("`@("`@("!I="=S(&5X<&ER92!D871E(&%N9"!W:6QL(&)E(')E
M;6]V960@875T;VUA=&EC86QL>2X@57-E"B`@("`J("`@("`@("`@("`@("`@
M("`@('1H:7,@;VYL>2!I9B!Y;W4@:VYO=R!W:&%T('EO=2=R92!D;VEN9RXN
M+@H@("`@*B!`<F5T=7)N("`@8F]O;&5A;@H@("`@*B!`86-C97-S("`@<'5B
M;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@:7-%>'!I<F5D*"1I9"P@)&=R;W5P
M(#T@)V1E9F%U;'0G+"`D;6%X7V%G92`](#`I('L*("`@("`@("!I9B`H(21T
M:&ES+3YC86-H:6YG*0H@("`@("`@("`@("!R971U<FX@=')U93L*"B`@("`@
M("`@<F5T=7)N("1T:&ES+3YC;VYT86EN97(M/FES17AP:7)E9"@D:60L("1G
M<F]U<"P@)&UA>%]A9V4I.PH@("`@?2`O+R!E;F0@9G5N8R!I<T5X<&ER960*
M"B`@("`O*BH*("`@("H@1V5N97)A=&5S(&$@(G5N:7%U92(@240@9F]R('1H
M92!G:79E;B!V86QU90H@("`@*@H@("`@*B!4:&ES(&ES(&$@<75I8VL@8G5T
M(&1I<G1Y(&AA8VL@=&\@9V5T(&$@(G5N:7%U92(@240@9F]R(&$@86YY(&MI
M;F0@;V8@=F%R:6%B;&4N"B`@("`J($E$(&-L87-H97,@;6EG:'0@;V-C=7(@
M9G)O;2!T:6UE('1O('1I;64@86QT:&]U9V@@=&AE>2!A<F4@97AT<F5M92!U
M;FQI:V5L>2$*("`@("H*("`@("H@0'!A<F%M("`@(&UI>&5D("`@=F%R:6%B
M;&4@=&\@9V5N97)A=&4@82!)1"!F;W(*("`@("H@0')E='5R;B`@('-T<FEN
M9R`@(G5N:7%U92(@240*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B\*
M("`@(&9U;F-T:6]N(&=E;F5R871E240H)'9A<FEA8FQE*2!["B`@("`@("`@
M+R\@5T%23DE.1SH@240@8VQA<VAE<R!A<F4@<&]S<VEB;&4@86QT:&]U9V@@
M=6YL:6ME;'D*("`@("`@("!R971U<FX@;60U*'-E<FEA;&EZ92@D=F%R:6%B
M;&4I*3L*("`@('T*"B`@("`O*BH*("`@("H@0V%L;',@=&AE(&=A<F)A9V4@
M8V]L;&5C=&]R(&]F('1H92!S=&]R86=E(&]B:F5C="!W:71H(&$@8V5R=&%I
M;B!P<F]B86)I;&ET>0H@("`@*@H@("`@*B!`<&%R86T@("`@8F]O;&5A;B!&
M;W)C92!A(&=A<F)A9V4@8V]L;&5C=&EO;B!R=6X_"B`@("`J($!S964@("1G
M8U]P<F]B86)I;&ET>2P@)&=C7W1I;64*("`@("HO"B`@("!F=6YC=&EO;B!G
M87)B86=E0V]L;&5C=&EO;B@D9F]R8V4@/2!F86QS92D@>PH@("`@("`@('-T
M871I8R`D;&%S=%]R=6X@/2`P.PH*("`@("`@("!I9B`H(21T:&ES+3YC86-H
M:6YG*0H@("`@("`@("`@("!R971U<FX["@H@("`@("`@('-R86YD*"AD;W5B
M;&4I(&UI8W)O=&EM92@I("H@,3`P,#`P,"D["@H@("`@("`@("\O('1I;64@
M86YD('!R;V)A8FEL:71Y(&)A<V5D"B`@("`@("`@:68@*"@D9F]R8V4I('Q\
M("@D;&%S=%]R=6X@)B8@)&QA<W1?<G5N(#P@=&EM92@I("L@)'1H:7,M/F=C
M7W1I;64I('Q\("AR86YD*#$L(#$P,"D@/"`D=&AI<RT^9V-?<')O8F%B:6QI
M='DI*2!["B`@("`@("`@("`@("1T:&ES+3YC;VYT86EN97(M/F=A<F)A9V5#
M;VQL96-T:6]N*"1T:&ES+3YG8U]M87AL:69E=&EM92D["B`@("`@("`@("`@
M("1L87-T7W)U;B`]('1I;64H*3L*("`@("`@("!]"B`@("!]("\O(&5N9"!F
M=6YC(&=A<F)A9V5#;VQL96-T:6]N"@I]("\O(&5N9"!C;&%S<R!C86-H90H_
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]#;VYS;VQE+P``````````````````````````````````
M```````````````````````````````````````````````P,#`P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<S-``P,C`R,#8`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-O;G-O;&4O1V5T;W!T+G!H
M<```````````````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(R-3`P`#$P
M-3$U-#,S-S,T`#`R,C$V,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B
M<W1O<#TT('-H:69T=VED=&@]-#H@*B\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I
M(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N
M,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T:&%T(&ES(&)U
M;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@
M86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@=7)L.B`@("`@("`@("`@
M?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@
M9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD
M(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@
M("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R.B!!;F1R96D@6FUI
M979S:VD@/&%N9')E:4!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@
M)$ED.B!'971O<'0N<&AP+'8@,2XR,2XT+C<@,C`P,R\Q,B\P-2`R,3HU-SHP
M,2!A;F1R96D@17AP("0*"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PH*+RHJ
M"B`J($-O;6UA;F0M;&EN92!O<'1I;VYS('!A<G-I;F<@8VQA<W,N"B`J"B`J
M($!A=71H;W(@06YD<F5I(%IM:65V<VMI(#QA;F1R96E`<&AP+FYE=#X*("H*
M("HO"F-L87-S($-O;G-O;&5?1V5T;W!T('L*("`@("\J*@H@("`@("H@4&%R
M<V5S('1H92!C;VUM86YD+6QI;F4@;W!T:6]N<RX*("`@("`J"B`@("`@*B!4
M:&4@9FER<W0@<&%R86UE=&5R('1O('1H:7,@9G5N8W1I;VX@<VAO=6QD(&)E
M('1H92!L:7-T(&]F(&-O;6UA;F0M;&EN90H@("`@("H@87)G=6UE;G1S('=I
M=&AO=70@=&AE(&QE861I;F<@<F5F97)E;F-E('1O('1H92!R=6YN:6YG('!R
M;V=R86TN"B`@("`@*@H@("`@("H@5&AE('-E8V]N9"!P87)A;65T97(@:7,@
M82!S=')I;F<@;V8@86QL;W=E9"!S:&]R="!O<'1I;VYS+B!%86-H(&]F('1H
M90H@("`@("H@;W!T:6]N(&QE='1E<G,@8V%N(&)E(&9O;&QO=V5D(&)Y(&$@
M8V]L;VX@)SHG('1O('-P96-I9GD@=&AA="!T:&4@;W!T:6]N"B`@("`@*B!R
M97%U:7)E<R!A;B!A<F=U;65N="P@;W(@82!D;W5B;&4@8V]L;VX@)SHZ)R!T
M;R!S<&5C:69Y('1H870@=&AE(&]P=&EO;@H@("`@("H@=&%K97,@86X@;W!T
M:6]N86P@87)G=6UE;G0N"B`@("`@*@H@("`@("H@5&AE('1H:7)D(&%R9W5M
M96YT(&ES(&%N(&]P=&EO;F%L(&%R<F%Y(&]F(&%L;&]W960@;&]N9R!O<'1I
M;VYS+B!4:&4*("`@("`J(&QE861I;F<@)RTM)R!S:&]U;&0@;F]T(&)E(&EN
M8VQU9&5D(&EN('1H92!O<'1I;VX@;F%M92X@3W!T:6]N<R!T:&%T"B`@("`@
M*B!R97%U:7)E(&%N(&%R9W5M96YT('-H;W5L9"!B92!F;VQL;W=E9"!B>2`G
M/2<L(&%N9"!O<'1I;VYS('1H870@=&%K92!A;@H@("`@("H@;W!T:6]N(&%R
M9W5M96YT('-H;W5L9"!B92!F;VQL;W=E9"!B>2`G/3TG+@H@("`@("H*("`@
M("`J(%1H92!R971U<FX@=F%L=64@:7,@86X@87)R87D@;V8@='=O(&5L96UE
M;G1S.B!T:&4@;&ES="!O9B!P87)S960*("`@("`J(&]P=&EO;G,@86YD('1H
M92!L:7-T(&]F(&YO;BUO<'1I;VX@8V]M;6%N9"UL:6YE(&%R9W5M96YT<RX@
M16%C:"!E;G1R>2!I;@H@("`@("H@=&AE(&QI<W0@;V8@<&%R<V5D(&]P=&EO
M;G,@:7,@82!P86ER(&]F(&5L96UE;G1S("T@=&AE(&9I<G-T(&]N90H@("`@
M("H@<W!E8VEF:65S('1H92!O<'1I;VXL(&%N9"!T:&4@<V5C;VYD(&]N92!S
M<&5C:69I97,@=&AE(&]P=&EO;B!A<F=U;65N="P*("`@("`J(&EF('1H97)E
M('=A<R!O;F4N"B`@("`@*@H@("`@("H@3&]N9R!A;F0@<VAO<G0@;W!T:6]N
M<R!C86X@8F4@;6EX960N"B`@("`@*@H@("`@("H@36]S="!O9B!T:&4@<V5M
M86YT:6-S(&]F('1H:7,@9G5N8W1I;VX@87)E(&)A<V5D(&]N($=.52!G971O
M<'1?;&]N9R@I+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@)&%R9W,@
M("`@("`@("`@(&%N(&%R<F%Y(&]F(&-O;6UA;F0M;&EN92!A<F=U;65N=',*
M("`@("`J($!P87)A;2!S=')I;F<@)'-H;W)T7V]P=&EO;G,@('-P96-I9FEE
M<R!T:&4@;&ES="!O9B!A;&QO=V5D('-H;W)T(&]P=&EO;G,*("`@("`J($!P
M87)A;2!A<G)A>2`@)&QO;F=?;W!T:6]N<R`@('-P96-I9FEE<R!T:&4@;&ES
M="!O9B!A;&QO=V5D(&QO;F<@;W!T:6]N<PH@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@='=O+65L96UE;G0@87)R87D@8V]N=&%I;FEN9R!T:&4@;&ES
M="!O9B!P87)S960@;W!T:6]N<R!A;F0*("`@("`J('1H92!N;VXM;W!T:6]N
M(&%R9W5M96YT<PH@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*@H@("`@("HO"B`@("!F=6YC=&EO;B!G971O<'0R*"1A<F=S+"`D<VAO<G1?
M;W!T:6]N<RP@)&QO;F=?;W!T:6]N<R`](&YU;&PI"B`@("!["B`@("`@("`@
M<F5T=7)N($-O;G-O;&5?1V5T;W!T.CID;T=E=&]P="@R+"`D87)G<RP@)'-H
M;W)T7V]P=&EO;G,L("1L;VYG7V]P=&EO;G,I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@5&AI<R!F=6YC=&EO;B!E>'!E8W1S("1A<F=S('1O('-T87)T('=I
M=&@@=&AE('-C<FEP="!N86UE("A03U-)6"US='EL92DN"B`@("`@*B!0<F5S
M97)V960@9F]R(&)A8VMW87)D<R!C;VUP871I8FEL:71Y+@H@("`@("H@0'-E
M92!G971O<'0R*"D*("`@("`J+R`@("`*("`@(&9U;F-T:6]N(&=E=&]P="@D
M87)G<RP@)'-H;W)T7V]P=&EO;G,L("1L;VYG7V]P=&EO;G,@/2!N=6QL*0H@
M("`@>PH@("`@("`@(')E='5R;B!#;VYS;VQE7T=E=&]P=#HZ9&]'971O<'0H
M,2P@)&%R9W,L("1S:&]R=%]O<'1I;VYS+"`D;&]N9U]O<'1I;VYS*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%1H92!A8W1U86P@:6UP;&5M96YT871I;VX@
M;V8@=&AE(&%R9W5M96YT('!A<G-I;F<@8V]D92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9&]'971O<'0H)'9E<G-I;VXL("1A<F=S+"`D<VAO<G1?;W!T:6]N
M<RP@)&QO;F=?;W!T:6]N<R`](&YU;&PI"B`@("!["B`@("`@("`@+R\@:6X@
M8V%S92!Y;W4@<&%S<R!D:7)E8W1L>2!R96%D4$A007)G=B@I(&%S('1H92!F
M:7)S="!A<F<*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D87)G<RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1A<F=S.PH@("`@("`@('T*("`@("`@("!I
M9B`H96UP='DH)&%R9W,I*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2AA
M<G)A>2@I+"!A<G)A>2@I*3L*("`@("`@("!]"B`@("`@("`@)&]P=',@("`@
M(#T@87)R87DH*3L*("`@("`@("`D;F]N7V]P=',@/2!A<G)A>2@I.PH*("`@
M("`@("!S971T>7!E*"1A<F=S+"`G87)R87DG*3L*"B`@("`@("`@:68@*"1L
M;VYG7V]P=&EO;G,I('L*("`@("`@("`@("`@<V]R="@D;&]N9U]O<'1I;VYS
M*3L*("`@("`@("!]"@H@("`@("`@("\J"B`@("`@("`@("H@4')E<V5R=F4@
M8F%C:W=A<F1S(&-O;7!A=&EB:6QI='D@=VET:"!C86QL97)S('1H870@<F5L
M:65D(&]N"B`@("`@("`@("H@97)R;VYE;W5S(%!/4TE8(&9I>"X*("`@("`@
M("`@*B\*("`@("`@("!I9B`H)'9E<G-I;VX@/"`R*2!["B`@("`@("`@("`@
M(&EF("AI<W-E="@D87)G<ULP77LP?2D@)B8@)&%R9W-;,%U[,'T@(3T@)RTG
M*2!["B`@("`@("`@("`@("`@("!A<G)A>5]S:&EF="@D87)G<RD["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E<V5T*"1A<F=S*3L*("`@
M("`@("!W:&EL92`H;&ES="@D:2P@)&%R9RD@/2!E86-H*"1A<F=S*2D@>PH*
M("`@("`@("`@("`@+RH@5&AE('-P96-I86P@96QE;65N="`G+2TG(&UE86YS
M(&5X<&QI8VET(&5N9"!O9@H@("`@("`@("`@("`@("!O<'1I;VYS+B!4<F5A
M="!T:&4@<F5S="!O9B!T:&4@87)G=6UE;G1S(&%S(&YO;BUO<'1I;VYS"B`@
M("`@("`@("`@("`@(&%N9"!E;F0@=&AE(&QO;W`N("HO"B`@("`@("`@("`@
M(&EF("@D87)G(#T]("<M+2<I('L*("`@("`@("`@("`@("`@("1N;VY?;W!T
M<R`](&%R<F%Y7VUE<F=E*"1N;VY?;W!T<RP@87)R87E?<VQI8V4H)&%R9W,L
M("1I("L@,2DI.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@(&EF("@D87)G>S!]("$]("<M)R!\?"`H<W1R;&5N
M*"1A<F<I(#X@,2`F)B`D87)G>S%](#T]("<M)R`F)B`A)&QO;F=?;W!T:6]N
M<RDI('L*("`@("`@("`@("`@("`@("1N;VY?;W!T<R`](&%R<F%Y7VUE<F=E
M*"1N;VY?;W!T<RP@87)R87E?<VQI8V4H)&%R9W,L("1I*2D["B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?2!E;'-E:68@*'-T<FQE;B@D
M87)G*2`^(#$@)B8@)&%R9WLQ?2`]/2`G+2<I('L*("`@("`@("`@("`@("`@
M("1E<G)O<B`]($-O;G-O;&5?1V5T;W!T.CI?<&%R<V5,;VYG3W!T:6]N*'-U
M8G-T<B@D87)G+"`R*2P@)&QO;F=?;W!T:6]N<RP@)&]P=',L("1A<F=S*3L*
M("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<BDI"B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1E<G)O<B`]($-O;G-O;&5?1V5T
M;W!T.CI?<&%R<V53:&]R=$]P=&EO;BAS=6)S='(H)&%R9RP@,2DL("1S:&]R
M=%]O<'1I;VYS+"`D;W!T<RP@)&%R9W,I.PH@("`@("`@("`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&5R<F]R*2D*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)&5R<F]R.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@87)R87DH)&]P=',L("1N;VY?;W!T<RD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]P87)S95-H;W)T3W!T:6]N*"1A<F<L("1S:&]R=%]O<'1I
M;VYS+"`F)&]P=',L("8D87)G<RD*("`@('L*("`@("`@("!F;W(@*"1I(#T@
M,#L@)&D@/"!S=')L96XH)&%R9RD[("1I*RLI('L*("`@("`@("`@("`@)&]P
M="`]("1A<F=[)&E].PH@("`@("`@("`@("`D;W!T7V%R9R`](&YU;&P["@H@
M("`@("`@("`@("`O*B!4<GD@=&\@9FEN9"!T:&4@<VAO<G0@;W!T:6]N(&EN
M('1H92!S<&5C:69I97(@<W1R:6YG+B`J+PH@("`@("`@("`@("!I9B`H*"1S
M<&5C(#T@<W1R<W1R*"1S:&]R=%]O<'1I;VYS+"`D;W!T*2D@/3T](&9A;'-E
M('Q\("1A<F=[)&E](#T]("<Z)RD*("`@("`@("`@("`@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-O;G-O;&5?1V5T;W!T
M.B!U;G)E8V]G;FEZ960@;W!T:6]N("TM("1O<'0B*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@:68@*'-T<FQE;B@D<W!E8RD@/B`Q("8F("1S<&5C
M>S%](#T]("<Z)RD@>PH@("`@("`@("`@("`@("`@:68@*'-T<FQE;B@D<W!E
M8RD@/B`R("8F("1S<&5C>S)](#T]("<Z)RD@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("@D:2`K(#$@/"!S=')L96XH)&%R9RDI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@+RH@3W!T:6]N('1A:V5S(&%N(&]P=&EO;F%L(&%R9W5M
M96YT+B!5<V4@=&AE(')E;6%I;F1E<B!O9@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("!T:&4@87)G('-T<FEN9R!I9B!T:&5R92!I<R!A;GET:&EN9R!L
M969T+B`J+PH@("`@("`@("`@("`@("`@("`@("`@("`D;W!T<UM=(#T@87)R
M87DH)&]P="P@<W5B<W1R*"1A<F<L("1I("L@,2DI.PH@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("\J($]P
M=&EO;B!R97%U:7)E<R!A;B!A<F=U;65N="X@57-E('1H92!R96UA:6YD97(@
M;V8@=&AE(&%R9PH@("`@("`@("`@("`@("`@("`@("`@('-T<FEN9R!I9B!T
M:&5R92!I<R!A;GET:&EN9R!L969T+B`J+PH@("`@("`@("`@("`@("`@("`@
M(&EF("@D:2`K(#$@/"!S=')L96XH)&%R9RDI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&]P='-;72`](&%R<F%Y*"1O<'0L("!S=6)S='(H)&%R9RP@
M)&D@*R`Q*2D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@('T@96QS92!I9B`H;&ES="@L("1O<'1?87)G*2`]
M(&5A8V@H)&%R9W,I*0H@("`@("`@("`@("`@("`@("`@("`@("`O*B!%;'-E
M('5S92!T:&4@;F5X="!A<F=U;65N="X@*B\["B`@("`@("`@("`@("`@("`@
M("`@96QS90H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@B0V]N<V]L95]'971O<'0Z(&]P=&EO;B!R97%U:7)E<R!A
M;B!A<F=U;65N="`M+2`D;W!T(BD["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1O<'1S6UT@/2!A<G)A>2@D;W!T+"`D
M;W!T7V%R9RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R
M<V5,;VYG3W!T:6]N*"1A<F<L("1L;VYG7V]P=&EO;G,L("8D;W!T<RP@)B1A
M<F=S*0H@("`@>PH@("`@("`@($!L:7-T*"1O<'0L("1O<'1?87)G*2`](&5X
M<&QO9&4H)STG+"`D87)G*3L*("`@("`@("`D;W!T7VQE;B`]('-T<FQE;B@D
M;W!T*3L*"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)&QO;F=?
M;W!T:6]N<RD[("1I*RLI('L*("`@("`@("`@("`@)&QO;F=?;W!T("`]("1L
M;VYG7V]P=&EO;G-;)&E=.PH@("`@("`@("`@("`D;W!T7W-T87)T(#T@<W5B
M<W1R*"1L;VYG7V]P="P@,"P@)&]P=%]L96XI.PH*("`@("`@("`@("`@+RH@
M3W!T:6]N(&1O97-N)W0@;6%T8V@N($=O(&]N('1O('1H92!N97AT(&]N92X@
M*B\*("`@("`@("`@("`@:68@*"1O<'1?<W1A<G0@(3T@)&]P="D*("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PH*("`@("`@("`@("`@)&]P=%]R97-T("`]
M('-U8G-T<B@D;&]N9U]O<'0L("1O<'1?;&5N*3L*"B`@("`@("`@("`@("\J
M($-H96-K('1H870@=&AE(&]P=&EO;G,@=6YI<75E;'D@;6%T8VAE<R!O;F4@
M;V8@=&AE(&%L;&]W960*("`@("`@("`@("`@("`@;W!T:6]N<RX@*B\*("`@
M("`@("`@("`@:68@*"1O<'1?<F5S="`A/2`G)R`F)B`D;W!T>S!]("$]("<]
M)R`F)@H@("`@("`@("`@("`@("`@)&D@*R`Q(#P@8V]U;G0H)&QO;F=?;W!T
M:6]N<RD@)B8*("`@("`@("`@("`@("`@("1O<'0@/3T@<W5B<W1R*"1L;VYG
M7V]P=&EO;G-;)&DK,5TL(#`L("1O<'1?;&5N*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-O;G-O;&5?1V5T;W!T.B!O
M<'1I;VX@+2TD;W!T(&ES(&%M8FEG=6]U<R(I.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("!I9B`H<W5B<W1R*"1L;VYG7V]P="P@+3$I(#T]("<])RD@
M>PH@("`@("`@("`@("`@("`@:68@*'-U8G-T<B@D;&]N9U]O<'0L("TR*2`A
M/2`G/3TG*2!["B`@("`@("`@("`@("`@("`@("`@+RH@3&]N9R!O<'1I;VX@
M<F5Q=6ER97,@86X@87)G=6UE;G0N"B`@("`@("`@("`@("`@("`@("`@("`@
M5&%K92!T:&4@;F5X="!A<F=U;65N="!I9B!O;F4@=V%S;B=T('-P96-I9FEE
M9"X@*B\["B`@("`@("`@("`@("`@("`@("`@:68@*"%S=')L96XH)&]P=%]A
M<F<I("8F("$H;&ES="@L("1O<'1?87)G*2`](&5A8V@H)&%R9W,I*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@B0V]N<V]L95]'971O<'0Z(&]P=&EO;B`M+21O<'0@<F5Q=6ER97,@86X@
M87)G=6UE;G0B*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T@96QS92!I9B`H)&]P=%]A<F<I('L*("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#;VYS;VQE
M7T=E=&]P=#H@;W!T:6]N("TM)&]P="!D;V5S;B=T(&%L;&]W(&%N(&%R9W5M
M96YT(BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1O<'1S6UT@/2!A
M<G)A>2@G+2TG("X@)&]P="P@)&]P=%]A<F<I.PH@("`@("`@("`@("!R971U
M<FX["B`@("`@("`@?0H*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@B0V]N<V]L95]'971O<'0Z('5N<F5C;V=N:7IE9"!O<'1I;VX@+2TD;W!T
M(BD["B`@("!]"@H@("`@+RHJ"B`@("`J(%-A9F5L>2!R96%D('1H92`D87)G
M=B!02%`@87)R87D@86-R;W-S(&1I9F9E<F5N="!02%`@8V]N9FEG=7)A=&EO
M;G,N"B`@("`J(%=I;&P@=&%K92!C87)E(&]N(')E9VES=&5R7V=L;V)A;',@
M86YD(')E9VES=&5R7V%R9V-?87)G=B!I;FD@9&ER96-T:79E<PH@("`@*@H@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@*B!`<F5T=7)N(&UI>&5D('1H92`D
M87)G=B!02%`@87)R87D@;W(@4$5!4B!E<G)O<B!I9B!N;W0@<F5G:7-T97)E
M9`H@("`@*B\*("`@(&9U;F-T:6]N(')E86102%!!<F=V*"D*("`@('L*("`@
M("`@("!G;&]B86P@)&%R9W8["B`@("`@("`@:68@*"%I<U]A<G)A>2@D87)G
M=BDI('L*("`@("`@("`@("`@:68@*"%`:7-?87)R87DH)%]315)615);)V%R
M9W8G72DI('L*("`@("`@("`@("`@("`@(&EF("@A0&ES7V%R<F%Y*"1'3$]"
M04Q36R=(5%107U-%4E9%4E]605)3)UU;)V%R9W8G72DI('L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B0V]N<V]L95]'
M971O<'0Z($-O=6QD(&YO="!R96%D(&-M9"!A<F=S("AR96=I<W1E<E]A<F=C
M7V%R9W8]3V9F/RDB*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(')E='5R;B`D1TQ/0D%,4ULG2%144%]315)615)?5D%24R==6R=A<F=V
M)UT["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1?4T525D52
M6R=A<F=V)UT["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D87)G=CL*("`@
M('T*"GT*"C\^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]D871A+P``````````````````````````````````````````
M```````````````````````````````````````````P,#`P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<S-@`P,3<U,3<`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1A=&$O0V%C:&4O````````````
M````````````````````````````````````````````````````````````
M`````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,S-S,V`#`R,#4R,@`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&%T
M82]#86-H92]#;VYT86EN97(O````````````````````````````````````
M````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`U,34T,S,W,S8`,#(R-#0T`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]D871A+T-A8VAE+T-O;G1A:6YE<B]M9&)?8V%C:&5?
M<V-H96UA+GAM;``````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C4W-0`Q,#4Q-30S,S<S-@`P,C8T
M,#0`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]X;6P@=F5R<VEO;CTB,2XP(B!E;F-O9&EN9STB25-/+3@X-3DM,2(@/SX-
M"CQD871A8F%S93X-"@T*(#QN86UE/F1B;F%M93PO;F%M93X-"B`\8W)E871E
M/C$\+V-R96%T93X-"B`\9&5S8W)I<'1I;VX^(#PO9&5S8W)I<'1I;VX^#0H-
M"B`\=&%B;&4^#0H@(#QN86UE/F-A8VAE/"]N86UE/@T*("`\9&5S8W)I<'1I
M;VX^(#PO9&5S8W)I<'1I;VX^#0H-"B`@/&1E8VQA<F%T:6]N/@T*#0H@("`\
M9FEE;&0^#0H@("`@("`\;F%M93Y)1#PO;F%M93X-"B`@("`@(#QT>7!E/G1E
M>'0\+W1Y<&4^#0H@("`@("`\;&5N9W1H/C,R/"]L96YG=&@^#0H@("`@("`\
M9&5F875L=#X\+V1E9F%U;'0^#0H@("`@("`\;F]T;G5L;#XQ/"]N;W1N=6QL
M/@T*("`@/"]F:65L9#X-"@T*("`@/&9I96QD/@T*("`@("`@/&YA;64^8V%C
M:&5G<F]U<#PO;F%M93X-"B`@("`@(#QT>7!E/G1E>'0\+W1Y<&4^#0H@("`@
M("`\;&5N9W1H/C$R-SPO;&5N9W1H/@T*("`@("`@/&1E9F%U;'0^/"]D969A
M=6QT/@T*("`@("`@/&YO=&YU;&P^,3PO;F]T;G5L;#X-"B`@(#PO9FEE;&0^
M#0H-"B`@(#QF:65L9#X-"B`@("`@(#QN86UE/F-A8VAE9&%T83PO;F%M93X-
M"B`@("`@(#QT>7!E/F-L;V(\+W1Y<&4^#0H@("`@("`\9&5F875L=#X\+V1E
M9F%U;'0^#0H@("`@("`\;F]T;G5L;#XQ/"]N;W1N=6QL/@T*("`@/"]F:65L
M9#X-"@T*("`@/&9I96QD/@T*("`@("`@/&YA;64^=7-E<F1A=&$\+VYA;64^
M#0H@("`@("`\='EP93YT97AT/"]T>7!E/@T*("`@("`@/&QE;F=T:#XR-34\
M+VQE;F=T:#X-"B`@("`@(#QD969A=6QT/CPO9&5F875L=#X-"B`@(#PO9FEE
M;&0^#0H-"B`@(#QF:65L9#X-"B`@("`@(#QN86UE/F5X<&ER97,\+VYA;64^
M#0H@("`@("`\='EP93YI;G1E9V5R/"]T>7!E/@T*("`@("`@/&1E9F%U;'0^
M,#PO9&5F875L=#X-"B`@("`@(#QN;W1N=6QL/C$\+VYO=&YU;&P^#0H@("`\
M+V9I96QD/@T*#0H@("`\9FEE;&0^#0H@("`@("`\;F%M93YC:&%N9V5D/"]N
M86UE/@T*("`@("`@/'1Y<&4^:6YT96=E<CPO='EP93X-"B`@("`@(#QD969A
M=6QT/C`\+V1E9F%U;'0^#0H@("`@("`\;F]T;G5L;#XQ/"]N;W1N=6QL/@T*
M("`@/"]F:65L9#X-"@T*#0H@("`\:6YD97@^#0H@("`@/&YA;64^:61?:6YD
M97@\+VYA;64^#0H@("`@/'5N:7%U93XQ/"]U;FEQ=64^#0H@("`@/&9I96QD
M/B`\;F%M93YI9#PO;F%M93X@/"]F:65L9#X-"B`@("`\9FEE;&0^(#QN86UE
M/F-A8VAE9W)O=7`\+VYA;64^(#PO9FEE;&0^#0H@("`\+VEN9&5X/@T*#0H-
M"B`@(#QI;F1E>#X-"B`@("`\;F%M93YE>'!I<F5S7VEN9&5X/"]N86UE/@T*
M("`@(#QF:65L9#X@/&YA;64^97AP:7)E<SPO;F%M93X@/"]F:65L9#X-"B`@
M(#PO:6YD97@^#0H-"B`@/"]D96-L87)A=&EO;CX-"B`\+W1A8FQE/@T*#0H\
M+V1A=&%B87-E/@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1A=&$O3&]G
M+P``````````````````````````````````````````````````````````
M`````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-3$U-#,S-S,V`#`R,#(T,``@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&%T82],;V<O;6ES8R\`````````````````````````````
M````````````````````````````````````````````,#`P,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W,S8`,#(Q,3<S`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D871A+TQO9R]M:7-C+VQO9RYS
M<6P`````````````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0P-P`Q,#4Q
M-30S,S<S-@`P,C(T-S8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+2T@)$ED.B!L;V<N<W%L+'8@,2XQ(#(P,#0O,#,O,3D@
M,#@Z,#`Z,3`@:F]N($5X<"`D"@I#4D5!5$4@5$%"3$4@;&]G7W1A8FQE("@*
M("`@(&ED("`@("`@("`@($E.5"!.3U0@3E5,3"P*("`@(&QO9W1I;64@("`@
M(%1)34535$%-4"!.3U0@3E5,3"P*("`@(&ED96YT("`@("`@($-(05(H,38I
M($Y/5"!.54Q,+`H@("`@<')I;W)I='D@("`@24Y4($Y/5"!.54Q,+`H@("`@
M;65S<V%G92`@("`@5D%20TA!4B@R,#`I+`H@("`@4%))34%262!+15D@*&ED
M*0HI.PH`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O9&%T82]-86EL7TUI;64O````````````````````
M````````````````````````````````````````````````````,#`P,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W,S8`,#(Q
M,S4P`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D871A+TUA:6Q?36EM
M92]X;6%I;"YD=&0`````````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`V
M-@`Q,#4Q-30S,S<S-@`P,C,Q-C(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]X;6P@=F5R<VEO;CTB,2XP(B!E;F-O9&EN
M9STB25-/+3@X-3DM,2(_/@T*#0H\(45.5$E462!L="`B)B,S.#LC-C`[(CX-
M"CPA14Y42519(&=T("(F(S8R.R(^#0H\(45.5$E462!A;7`@(B8C,S@[(S,X
M.R(^#0H\(45.5$E462!A<&]S("(F(S,Y.R(^#0H\(45.5$E462!Q=6]T("(F
M(S,T.R(^#0H\(45.5$E462!C<FQF("(F(S$S.R8C,3`[(CX-"@T*/"%%3$5-
M14Y4(&5M86EL("AH96%D97(K+"`H8F]D>2!\(&UI;65P87)T*RDI/@T*/"%%
M3$5-14Y4(&UI;65P87)T("AH96%D97(K+"`H8F]D>2!\(&UI;65P87)T*RDI
M/@T*/"%%3$5-14Y4(&)O9'D@*"-00T1!5$$I/@T*/"%%3$5-14Y4(&AE861E
M<B`H*&AE861E<FYA;65\:&5A9&5R=F%L=65\<&%R86UE=&5R*2HI/@T*/"%%
M3$5-14Y4(&AE861E<FYA;64@*"-00T1!5$$I/@T*/"%%3$5-14Y4(&AE861E
M<G9A;'5E("@C4$-$051!*3X-"CPA14Q%345.5"!P87)A;65T97(@*"AP87)A
M;6YA;65\<&%R86UV86QU92DK*3X-"CPA14Q%345.5"!P87)A;79A;'5E("@C
M4$-$051!*3X-"CPA14Q%345.5"!P87)A;6YA;64@*"-00T1!5$$I/@T*#0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D871A+TUA
M:6Q?36EM92]X;6%I;"YX<VP`````````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P-#$R-P`Q,#4Q-30S,S<S-@`P,C,R,38`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]X;6P@=F5R<VEO;CTB,2XP(B!E
M;F-O9&EN9STB25-/+3@X-3DM,2(_/@T*/'AS;#IS='EL97-H965T('9E<G-I
M;VX](C$N,"(@>&UL;G,Z>'-L/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+UA3
M3"]4<F%N<V9O<FTB('AM;&YS.F9O/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY
M+UA33"]&;W)M870B/@T*/'AS;#IO=71P=70@;65T:&]D/2)T97AT(B!O;6ET
M+7AM;"UD96-L87)A=&EO;CTB>65S(B!I;F1E;G0](FYO(B\^#0H\>'-L.G!R
M97-E<G9E+7-P86-E(&5L96UE;G1S/2)H96%D97)V86QU92!P87)A;79A;'5E
M(&)O9'DB+SX-"@T*"3QX<VPZ=&5M<&QA=&4@;F%M93TB;6EM97!A<G0B/@T*
M#0H)"3QX<VPZ=F%R:6%B;&4@;F%M93TB8F]U;F1A<GDB/@T*"0D)"3QX<VPZ
M9F]R+65A8V@@<V5L96-T/2(N+VAE861E<B(^#0H)"0D)"3QX<VPZ:68@=&5S
M=#TB<W1R:6YG*"XO:&5A9&5R;F%M92D@/2`G0V]N=&5N="U4>7!E)R(^#0H)
M"0D)"0D\>'-L.F9O<BUE86-H('-E;&5C=#TB+B]P87)A;65T97(B/@T*"0D)
M"0D)"3QX<VPZ:68@=&5S=#TB<W1R:6YG*"XO<&%R86UN86UE*2`]("=B;W5N
M9&%R>2<B/@T*"0D)"0D)"0D\>'-L.G9A;'5E+6]F('-E;&5C=#TB<&%R86UV
M86QU92(O/@T*"0D)"0D)"3PO>'-L.FEF/@T*"0D)"0D)/"]X<VPZ9F]R+65A
M8V@^#0H)"0D)"3PO>'-L.FEF/@T*"0D)"3PO>'-L.F9O<BUE86-H/@T*"0D\
M+WAS;#IV87)I86)L93X-"@T*"0D\>'-L.F9O<BUE86-H('-E;&5C=#TB:&5A
M9&5R(CX-"@T*"0D)/'AS;#IV86QU92UO9B!S96QE8W0](FAE861E<FYA;64B
M+SX-"@D)"3QX<VPZ=&5X=#XZ(#PO>'-L.G1E>'0^#0H)"0D\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB:&5A9&5R=F%L=64B+SX-"@T*"0D)/'AS;#II9B!T97-T
M/2)C;W5N="@N+W!A<F%M971E<BD@/2`P(CX-"@D)"0D\>'-L.G1E>'0^)B,Q
M,SLF(S$P.SPO>'-L.G1E>'0^#0H)"0D\+WAS;#II9CX-"@T*"0D)/'AS;#IF
M;W(M96%C:"!S96QE8W0](G!A<F%M971E<B(^#0H)"0D)/'AS;#IT97AT/CLF
M(S$S.R8C,3`[)B,P.3L\+WAS;#IT97AT/@T*"0D)"3QX<VPZ=F%L=64M;V8@
M<V5L96-T/2)P87)A;6YA;64B+SX-"@D)"0D\>'-L.G1E>'0^/2(\+WAS;#IT
M97AT/@T*"0D)"3QX<VPZ=F%L=64M;V8@<V5L96-T/2)P87)A;79A;'5E(B\^
M#0H)"0D)/'AS;#IT97AT/B(\+WAS;#IT97AT/@T*"0D)/"]X<VPZ9F]R+65A
M8V@^#0H-"@D)"3QX<VPZ:68@=&5S=#TB8V]U;G0H+B]P87)A;65T97(I(#X@
M,"(^#0H)"0D)/'AS;#IT97AT/B8C,3,[)B,Q,#L\+WAS;#IT97AT/@T*"0D)
M/"]X<VPZ:68^#0H-"@D)/"]X<VPZ9F]R+65A8V@^#0H-"@D)/'AS;#IT97AT
M/B8C,3,[)B,Q,#L\+WAS;#IT97AT/@T*#0H)"3PA+2T@5VAI8V@@=&\@9&\L
M('!R:6YT(&$@8F]D>2!O<B!P<F]C97-S('-U8G!A<G1S/R`M+3X-"@D)/'AS
M;#IC:&]O<V4^#0H)"0D\>'-L.G=H96X@=&5S=#TB8V]U;G0H+B]M:6UE<&%R
M="D@/2`P(CX-"@D)"0D\>'-L.G9A;'5E+6]F('-E;&5C=#TB8F]D>2(O/@T*
M"0D)"3QX<VPZ=&5X=#XF(S$S.R8C,3`[/"]X<VPZ=&5X=#X-"@D)"3PO>'-L
M.G=H96X^#0H-"@D)"3QX<VPZ;W1H97)W:7-E/@T*"0D)"3QX<VPZ9F]R+65A
M8V@@<V5L96-T/2)M:6UE<&%R="(^#0H)"0D)"3QX<VPZ=&5X=#XM+3PO>'-L
M.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](B1B;W5N9&%R>2(O/CQX<VPZ
M=&5X=#XF(S$S.R8C,3`[/"]X<VPZ=&5X=#X-"@D)"0D)/'AS;#IC86QL+71E
M;7!L871E(&YA;64](FUI;65P87)T(B\^#0H)"0D)/"]X<VPZ9F]R+65A8V@^
M#0H-"@D)"0D\>'-L.G1E>'0^+2T\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@
M<V5L96-T/2(D8F]U;F1A<GDB+SX\>'-L.G1E>'0^+2TF(S$S.R8C,3`[/"]X
M<VPZ=&5X=#X-"@T*"0D)/"]X<VPZ;W1H97)W:7-E/@T*"0D\+WAS;#IC:&]O
M<V4^#0H)/"]X<VPZ=&5M<&QA=&4^#0H-"CPA+2T@5&AI<R!I<R!W:&5R92!T
M:&4@<W1Y;&5S:&5E="!R96%L;'D@<W1A<G1S+"!M871C:&EN9R!T:&4@=&]P
M(&QE=F5L(&5M86EL(&5L96UE;G0@+2T^#0H)/'AS;#IT96UP;&%T92!M871C
M:#TB96UA:6PB/@T*"0D\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB;6EM97!A
M<G0B+SX-"@D\+WAS;#IT96UP;&%T93X-"@T*/"]X<VPZ<W1Y;&5S:&5E=#X`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]D871A+U!%05(O````````````````````````````````````````
M```````````````````````````````````````P,#`P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<S-@`P,C`R-#8`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+V1A=&$O4$5!4B]P86-K86=E+F1T9```
M````````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-C0V`#$P-3$U-#,S
M-S,V`#`R,C,U,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\(2TM#0H@("`@("1)9#H@<&%C:V%G92YD=&0L=B`Q+C,X(#(P
M,#4O,3$O,3(@,#(Z,C,Z,#<@8V5L;&]G($5X<"`D#0H-"B`@("`@5&AI<R!I
M<R!T:&4@4$5!4B!P86-K86=E(&1E<V-R:7!T:6]N+"!V97)S:6]N(#$N,"X-
M"B`@("`@270@<VAO=6QD(&)E('5S960@=VET:"!T:&4@:6YF;W)M86P@<'5B
M;&EC(&ED96YT:69I97(Z#0H-"B`@("`@("`@("(M+R]02%`@1W)O=7`O+T14
M1"!014%2(%!A8VMA9V4@,2XP+R]%3B\O6$U,(@T*#0H@("`@($-O<'ER:6=H
M="`H8RD@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@#0H-
M"B`@("`@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@
M,RXP,"!O9B!T:&4@4$A0(&QI8V5N<V4L#0H@("`@('1H870@:7,@8G5N9&QE
M9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@
M:7,-"B`@("`@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M
M=V5B(&%T#0H@("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0N(`T*("`@("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T
M:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\-"B`@("`@;V)T86EN
M(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A
M(&YO=&4@=&\-"B`@("`@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL
M('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H-"B`@("`@075T:&]R<SH-"B`@
M("`@("`@(%-T:6<@4RX@0F%K:V5N(#QS<V)`9F%S="YN;SX-"B`@("`@("`@
M($=R96=O<GD@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"@T*("`M+3X-"CPA
M14Y42519("4@3E5-0D52(")#1$%402(^#0H\(45,14U%3E0@<&%C:V%G92`H
M;F%M92QS=6UM87)Y+&1E<V-R:7!T:6]N+&QI8V5N<V4_+&UA:6YT86EN97)S
M+')E;&5A<V4L8VAA;F=E;&]G/RD^#0H\(4%45$Q)4U0@<&%C:V%G92!T>7!E
M("`@("AS;W5R8V5\8FEN87)Y?&5M<'1Y*2`B96UP='DB#0H@("`@("`@("`@
M("`@("`@("!V97)S:6]N($-$051!("`@("`@("`@("`@("`@("`C4D5154E2
M140-"B`@("`@("`@("`@("`@("`@('!A8VMA9V5R=F5R<VEO;B!#1$%402`@
M("`@("`@("-)35!,245$/@T*#0H\(45,14U%3E0@;F%M92`H(U!#1$%402D^
M#0H-"CPA14Q%345.5"!S=6UM87)Y("@C4$-$051!*3X-"@T*/"%%3$5-14Y4
M(&QI8V5N<V4@*"-00T1!5$$I/@T*#0H\(45,14U%3E0@9&5S8W)I<'1I;VX@
M*"-00T1!5$$I/@T*#0H\(45,14U%3E0@;6%I;G1A:6YE<G,@*&UA:6YT86EN
M97(I*SX-"@T*/"%%3$5-14Y4(&UA:6YT86EN97(@*'5S97)\<F]L97QN86UE
M?&5M86EL*2L^#0H-"CPA14Q%345.5"!U<V5R("@C4$-$051!*3X-"@T*/"%%
M3$5-14Y4(')O;&4@*"-00T1!5$$I/@T*#0H\(45,14U%3E0@96UA:6P@*"-0
M0T1!5$$I/@T*#0H\(45,14U%3E0@8VAA;F=E;&]G("AR96QE87-E*2L^#0H-
M"CPA14Q%345.5"!R96QE87-E("AV97)S:6]N+&1A=&4L;&EC96YS92QS=&%T
M92QN;W1E<RQW87)N:6YG<S\L<')O=FED97,J+&1E<',_+&-O;F9I9W5R96]P
M=&EO;G,_+&9I;&5L:7-T/RD^#0H-"CPA14Q%345.5"!V97)S:6]N("@C4$-$
M051!*3X-"@T*/"%%3$5-14Y4(&1A=&4@*"-00T1!5$$I/@T*#0H\(45,14U%
M3E0@<W1A=&4@*"-00T1!5$$I/@T*#0H\(45,14U%3E0@;F]T97,@*"-00T1!
M5$$I/@T*#0H\(45,14U%3E0@=V%R;FEN9W,@*"-00T1!5$$I/@T*#0H\(45,
M14U%3E0@9&5P<R`H9&5P*BD^#0H-"CPA14Q%345.5"!D97`@*"-00T1!5$$I
M/@T*/"%!5%1,25-4(&1E<"!T>7!E("`@("AP:V=\97AT?'!H<"D@(U)%455)
M4D5$#0H)("`@("`@("`@("`@("`@("`@("`@("!R96P@("`@("AH87-\97%\
M;'1\;&5\9W1\9V4I("`@("`@("`@("`@("`@("`@("`@("`@("`C24U03$E%
M1`T*"2`@("`@("`@("`@("`@("`@("`@("`@=F5R<VEO;B!#1$%402`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C24U03$E%1`T*"2`@
M("`@("`@("`@("`@("`@("`@("`@;W!T:6]N86P@*'EE<WQN;RD@("`@("=N
M;R<^#0H-"CPA14Q%345.5"!C;VYF:6=U<F5O<'1I;VYS("AC;VYF:6=U<F5O
M<'1I;VXI*SX-"@T*/"%%3$5-14Y4(&-O;F9I9W5R96]P=&EO;B!%35!463X-
M"CPA05143$E35"!C;VYF:6=U<F5O<'1I;VX@;F%M92!#1$%402`C4D5154E2
M140-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!D969A=6QT($-$051!("-)35!,245$#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@<')O;7!T($-$051!("-215%525)%
M1#X-"@T*/"%%3$5-14Y4('!R;W9I9&5S($5-4%19/@T*/"%!5%1,25-4('!R
M;W9I9&5S('1Y<&4@*&5X='QP<F]G?&-L87-S?&9U;F-T:6]N?&9E871U<F5\
M87!I*2`C4D5154E2140-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@;F%M92!#1$%402`C4D5154E2140-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@97AT96YD<R!#1$%402`C24U03$E%1#X-"CPA14Q%345.
M5"!F:6QE;&ES="`H9&ER?&9I;&4I*SX-"@T*/"%%3$5-14Y4(&1I<B`H9&ER
M?&9I;&4I*SX-"CPA05143$E35"!D:7(@;F%M92`@("`@("`@("`@0T1!5$$@
M(U)%455)4D5$#0H@("`@("`@("`@("`@(')O;&4@("`@("`@("`@("AP:'!\
M97AT?'-R8WQT97-T?&1O8WQD871A?'-C<FEP="D@)W!H<"<-"B`@("`@("`@
M("`@("`@8F%S96EN<W1A;&QD:7(@0T1!5$$@(TE-4$Q)140^#0H-"CPA14Q%
M345.5"!F:6QE("AR97!L86-E*BD^#0H\(4%45$Q)4U0@9FEL92!R;VQE("`@
M("`@("`@("`H<&AP?&5X='QS<F-\=&5S='QD;V-\9&%T87QS8W)I<'0I("=P
M:'`G#0H@("`@("`@("`@("`@("!D96)U9R`@("`@("`@("`H;F%\;VY\;V9F
M*2`@("`@("`@)VYA)PT*("`@("`@("`@("`@("`@9F]R;6%T("`@("`@("`@
M0T1!5$$@("`@("`@("`@("`@("-)35!,245$#0H@("`@("`@("`@("`@("!B
M87-E:6YS=&%L;&1I<B!#1$%402`@("`@("`@("`@("`@(TE-4$Q)140-"B`@
M("`@("`@("`@("`@('!L871F;W)M("`@("`@($-$051!("`@("`@("`@("`@
M("`C24U03$E%1`T*("`@("`@("`@("`@("`@;60U<W5M("`@("`@("`@0T1!
M5$$@("`@("`@("`@("`@("-)35!,245$#0H@("`@("`@("`@("`@("!N86UE
M("`@("`@("`@("!#1$%402`@("`@("`@("`@("`@(U)%455)4D5$#0H@("`@
M("`@("`@("`@("!I;G-T86QL+6%S("`@("!#1$%402`@("`@("`@("`@("`@
M(TE-4$Q)140^#0H-"CPA14Q%345.5"!R97!L86-E($5-4%19/@T*/"%!5%1,
M25-4(')E<&QA8V4@='EP92`H<&AP+6-O;G-T?'!E87(M8V]N9FEG?'!A8VMA
M9V4M:6YF;RD@(U)%455)4D5$#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!F<F]M($-$051!("-215%525)%1`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@=&\@0T1!5$$@(U)%455)4D5$/@T*#0H-"@``````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D871A+U!%05(O=&5M<&QA=&4N<W!E
M8P``````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#`S-0`Q,#4Q-30S
M,S<S-@`P,C(W,S<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````4W5M;6%R>3H@4$5!4CH@0'-U;6UA<GE`#0I.86UE.B!`<G!M
M7W!A8VMA9V5`#0I697)S:6]N.B!`=F5R<VEO;D`-"E)E;&5A<V4Z(#$-"DQI
M8V5N<V4Z($!R96QE87-E7VQI8V5N<V5`#0I'<F]U<#H@1&5V96QO<&UE;G0O
M3&EB<F%R:65S#0I3;W5R8V4Z(&AT='`Z+R]`;6%S=&5R7W-E<G9E<D`O9V5T
M+T!P86-K86=E0"TE>W9E<G-I;VY]+G1G>@T*0G5I;&12;V]T.B`E>U]T;7!P
M871H?2\E>VYA;65]+7)O;W0-"E523#H@:'1T<#HO+T!M87-T97)?<V5R=F5R
M0"]P86-K86=E+T!P86-K86=E0`T*4')E9FEX.B`E>U]P<F5F:7A]#0I"=6EL
M9$%R8VAI=&5C='5R97,Z($!A<F-H0`T*0&5X=')A7VAE861E<G-`#0H-"B5D
M97-C<FEP=&EO;@T*0&1E<V-R:7!T:6]N0`T*#0HE<')E<`T*<FT@+7)F("5[
M8G5I;&1R;V]T?2\J#0HE<V5T=7`@+6,@+50-"B,@6%A8(%-O=7)C92!F:6QE
M<R!L;V-A=&EO;B!I<R!M:7-S:6YG(&AE<F4@:6X@<&5A<B!C;60-"G!E87(@
M+78@+6,@)7MB=6EL9')O;W1]+W!E87)R8R!<#0H@("`@("`@("UD('!H<%]D
M:7(])7M?;&EB9&ER?2]P:'`O<&5A<B!<#0H@("`@("`@("UD(&1O8U]D:7(]
M+V1O8W,@7`T*("`@("`@("`M9"!B:6Y?9&ER/25[7V)I;F1I<GT@7`T*("`@
M("`@("`M9"!D871A7V1I<CTE>U]L:6)D:7)]+W!H<"]P96%R+V1A=&$@7`T*
M("`@("`@("`M9"!T97-T7V1I<CTE>U]L:6)D:7)]+W!H<"]P96%R+W1E<W1S
M(%P-"B`@("`@("`@+60@97AT7V1I<CTE>U]L:6)D:7)](%Q`97AT<F%?8V]N
M9FEG0`T*("`@("`@("`M<PT*#0HE8G5I;&0-"F5C:&\@0G5I;&12;V]T/25[
M8G5I;&1R;V]T?0T*#0HE<&]S='5N#0HC(&EF(')E9F-O=6YT(#T@,"!T:&5N
M('!A8VMA9V4@:&%S(&)E96X@<F5M;W9E9"`H;F]T('5P9W)A9&5D*0T*:68@
M6R`B)#$B("UE<2`B,"(@73L@=&AE;@T*("`@('!E87(@=6YI;G-T86QL("TM
M;F]D97!S("UR($!P;W-S:6)L95]C:&%N;F5L0$!P86-K86=E0`T*("`@(')M
M($!R<&U?>&UL7V1I<D`O0'!A8VMA9V5`+GAM;`T*9FD-"@T*#0HE<&]S=`T*
M(R!I9B!R969C;W5N="`](#(@=&AE;B!P86-K86=E(&AA<R!B965N('5P9W)A
M9&5D#0II9B!;("(D,2(@+6=E("(R(B!=.R!T:&5N#0H@("`@<&5A<B!U<&=R
M861E("TM;F]D97!S("UR($!R<&U?>&UL7V1I<D`O0'!A8VMA9V5`+GAM;`T*
M96QS90T*("`@('!E87(@:6YS=&%L;"`M+6YO9&5P<R`M<B!`<G!M7WAM;%]D
M:7)`+T!P86-K86=E0"YX;6P-"F9I#0H-"B5I;G-T86QL#0IP96%R("UC("5[
M8G5I;&1R;V]T?2]P96%R<F,@:6YS=&%L;"`M+6YO9&5P<R`M4B`E>V)U:6QD
M<F]O='T@7`T*("`@("`@("`D4E!-7U-/55)#15]$25(O0'!A8VMA9V5`+25[
M=F5R<VEO;GTN=&=Z#0IR;2`E>V)U:6QD<F]O='TO<&5A<G)C#0IR;2`E>V)U
M:6QD<F]O='TO)7M?;&EB9&ER?2]P:'`O<&5A<B\N9FEL96UA<`T*<FT@)7MB
M=6EL9')O;W1]+R5[7VQI8F1I<GTO<&AP+W!E87(O+FQO8VL-"G)M("UR9B`E
M>V)U:6QD<F]O='TO)7M?;&EB9&ER?2]P:'`O<&5A<B\N<F5G:7-T<GD-"FEF
M(%L@(D!D;V-?9FEL97-`(B`A/2`B(B!=.R!T:&5N#0H@("`@(&UV("5[8G5I
M;&1R;V]T?2]D;V-S+T!P86-K86=E0"\J("X-"B`@("`@<FT@+7)F("5[8G5I
M;&1R;V]T?2]D;V-S#0IF:0T*;6MD:7(@+7`@)7MB=6EL9')O;W1]0')P;5]X
M;6Q?9&ER0`T*=&%R("UX>F8@)%)035]33U520T5?1$E2+T!P86-K86=E0"TE
M>W9E<G-I;VY]+G1G>B!P86-K86=E0'!A8VMA9V4R>&UL0"YX;6P-"F-P("UP
M('!A8VMA9V5`<&%C:V%G93)X;6Q`+GAM;"`E>V)U:6QD<F]O='U`<G!M7WAM
M;%]D:7)`+T!P86-K86=E0"YX;6P-"@T*(W)M("UR9B`E>V)U:6QD<F]O='TO
M*@T*(W!E87(@+7$@:6YS=&%L;"`M4B`E>V)U:6QD<F]O='T@+6X@<&%C:V%G
M94!P86-K86=E,GAM;$`N>&UL#0HC;6MD:7(@+7`@)7MB=6EL9')O;W1]0')P
M;5]X;6Q?9&ER0`T*(V-P("UP('!A8VMA9V5`<&%C:V%G93)X;6Q`+GAM;"`E
M>V)U:6QD<F]O='U`<G!M7WAM;%]D:7)`+T!P86-K86=E0"YX;6P-"@T*)69I
M;&5S#0H@("`@)61E9F%T='(H+2QR;V]T+')O;W0I#0H@("`@)61O8R!`9&]C
M7V9I;&5S0`T*("`@("\-"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D871A+U-E<G9I
M8V5S7U=E871H97(O````````````````````````````````````````````
M```````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#4Q-30S,S<S-@`P,C(W-C$`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+V1A=&$O4V5R=FEC97-?5V5A=&AE<B]B=6EL9$UE=&%R1$(N<&AP
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#,W-#<R`#$P-3$U-#,S-S,V`#`R-C`P-0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````C(2]U<W(O
M;&]C86PO8FEN+W!H<`H\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B
M<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT(&9O;&1M971H;V0]
M;6%R:V5R.B`J+PH*+RHJ"B`J(%1H:7,@<V-R:7!T(&1O=VYL;V%D<RP@<V%V
M97,@86YD('!R;V-E<W-E<R!T:&4@=&5X=&9I;&5S(&YE961E9"!F;W(*("H@
M=&AE(&)U:6QD:6YG('1H92!D871A8F%S97,@=&\@96YA8FQE('-E87)C:&EN
M9R!F;W(@345405(@<W1A=&EO;G,N"B`J"B`J(%EO=2!C86X@9&]W;FQO860@
M=&AE(&QO8V%T:6]N<RP@=VAI8V@@:7,@82!D871A8F%S92!O9B!A8F]U="`Q
M,C`P,"!W;W)L9"T*("H@=VED92!L;V-A=&EO;G,L('=H:6-H(&-A;B!B92!U
M<V5D('1O(&1E=&5R;6EN92!T:&4@8V]O<F1I;F%T97,@;V8@>6]U<@H@*B!C
M:71Y(&]R('EO=2!C86X@9&]W;FQO860@82!F:6QE('=I=&@@-C4P,"!A:7)P
M;W)T<R!P<F]V:61I;F<@=&AE(&UE=&%R"B`J(&1A=&$N(%1H:7,@9&%T86)A
M<V4@:7,@=7-E9"!F;W(@=&AE(&YE>'0M345405(M<W1A=&EO;B!S96%R8V@N
M(%!L96%S92!S964*("H@=&AE(&%P<F]P<FEA=&4@9&]C=6UE;G1A=&EO;B!I
M;B!T:&4@4V5R=FEC97-?5V5A=&AE<E]-971A<B!C;&%S<RX*("H*("H@1F]R
M('5S86=E(&]F('1H:7,@<V-R:7!T+"!I;G9O:V4@=VET:"`G+6@G+@H@*@H@
M*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B`\3$E#14Y313X*("H@0V]P
M>7)I9VAT("AC*2`R,#`U+"!!;&5X86YD97(@5VER='H*("H@06QL(')I9VAT
M<R!R97-E<G9E9"X*("H*("H@4F5D:7-T<FEB=71I;VX@86YD('5S92!I;B!S
M;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T"B`J(&UO
M9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F
M;VQL;W=I;F<@8V]N9&ET:6]N<PH@*B!A<F4@;65T.@H@*B!O(%)E9&ES=')I
M8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@
M8V]P>7)I9VAT(&YO=&EC92P*("H@("!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N
M<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+@H@*B!O(%)E9&ES=')I
M8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O
M=F4@8V]P>7)I9VAT(&YO=&EC92P*("H@("!T:&ES(&QI<W0@;V8@8V]N9&ET
M:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN('1H92!D;V-U
M;65N=&%T:6]N"B`J("`@86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E
M9"!W:71H('1H92!D:7-T<FEB=71I;VXN"B`J(&\@3F5I=&AE<B!T:&4@;F%M
M92!O9B!T:&4@<V]F='=A<F4@;F]R('1H92!N86UE<R!O9B!I=',@8V]N=')I
M8G5T;W)S"B`J("`@;6%Y(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E
M('!R;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES('-O9G1W87)E"B`J("`@=VET
M:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N('!E<FUI<W-I;VXN"B`J"B`J
M(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(
M3TQ$15)3($%.1"!#3TY44DE"551/4E,@(D%3($E3(@H@*B!!3D0@04Y9($58
M4%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.
M3U0@3$E-251%1"!43RP@5$A%"B`J($E-4$Q)140@5T%24D%.5$E%4R!/1B!-
M15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!0
M55)03U-%"B`J($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!4
M2$4@0T]065))1TA4($]73D52($]2($-/3E1224)55$]24R!"10H@*B!,24%"
M3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!34$5#
M24%,+"!%6$5-4$Q!4EDL($]2"B`J($-/3E-%455%3E1)04P@1$%-04=%4R`H
M24Y#3%5$24Y'+"!"550@3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&
M"B`J(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%
M+"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534PH@*B!)3E1%4E)54%1)
M3TXI($A/5T5615(@0T%54T5$($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)04))
M3$E462P@5TA%5$A%4B!)3@H@*B!#3TY44D%#5"P@4U1224-4($Q)04))3$E4
M62P@3U(@5$]25"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%
M*0H@*B!!4DE324Y'($E.($%.62!705D@3U54($]&(%1(12!54T4@3T8@5$A)
M4R!33T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(10H@*B!03U-324))
M3$E462!/1B!354-(($1!34%'12X*("H@/"],24-%3E-%/@H@*@H@*B!`8V%T
M96=O<GD@("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@("!397)V:6-E
M<U]796%T:&5R"B`J($!S=6)P86-K86=E("!B=6EL9$UE=&%R1$(*("H@0&%U
M=&AO<B`@("`@($%L97AA;F1E<B!7:7)T>B`\86QE>$!P8S1P+FYE=#X*("H@
M0&-O<'ER:6=H="`@(#(P,#4@06QE>&%N9&5R(%=I<G1Z"B`J($!L:6-E;G-E
M("`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL
M:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@($-64SH@
M)$ED.B!B=6EL9$UE=&%R1$(N<&AP+'8@,2XR,R`R,#`U+S$Q+S$S(#(Q.C4V
M.C$U(&5R=2!%>'`@)`H@*B!`;&EN:R`@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+U-E<G9I8V5S7U=E871H97(*("H@0&QI;FL@("`@("`@
M(&AT='`Z+R]W96%T:&5R+FYO86$N9V]V+W1G+W-I=&4N<VAT;6P*("H@0&9I
M;&5S;W5R8V4*("HO"@IR97%U:7)E7V]N8V4@(D1"+G!H<"(["@HO+R![>WL@
M8V]N<W1A;G1S"B\O('M[>R!N871U<F%L(&-O;G-T86YT<R!A;F0@;65A<W5R
M97,*9&5F:6YE*")315)624-%4U]714%42$527U)!1$E54U]%05)42"(L(#8S
M-S@N,34I.PHO+R!]?7T*+R\@?7U]"@HO+R![>WL@4V5R=FEC97-?5V5A=&AE
M<E]C:&5C:T1A=&$H*0HO*BH*("H@4V5R=FEC97-?5V5A=&AE<E]C:&5C:T1A
M=&$*("H*("H@0VAE8VMS('1H92!D871A(&9O<B!A(&-E<G1A:6X@<W1R:6YG
M+6QE;F=T:"!A;F0@:68@:70@96ET:&5R(&-O;G-I<W1S(&]F"B`J(&$@8V5R
M=&%I;B!C:&%R+71Y<&4@;W(@82!S=')I;F<@;V8@(BTB(&%S(')E<&QA8V5M
M96YT+@H@*@H@*B!`<&%R86T@("!A<G)A>2`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1D871A("`@("`@("`@("!4:&4@9&%T82!T;R!B92!C:&5C:V5D
M"B`J($!P87)A;2`@(&%R<F%Y("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&1A=&%/<F1E<B`@("`@($)E8V%U<V4@=&AE(&1A=&$@:7,@:6X@9&EF9F5R
M96YT(&QO8V%T:6]N<RP@=V4@<')O=FED92!T:&ES"B`J($!R971U<FX@(&)O
M;VP*("HO"F9U;F-T:6]N(%-E<G9I8V5S7U=E871H97)?8VAE8VM$871A*"1D
M871A+"`D9&%T84]R9&5R*0I["B`@("`D<F5T=7)N(#T@=')U93L*("`@(&9O
M<F5A8V@@*"1D871A3W)D97(@87,@)'1Y<&4@/3X@)&ED>"D@>PH@("`@("`@
M('-W:71C:"`H<W1R=&]L;W=E<B@D='EP92DI('L*("`@("`@("`@("`@8V%S
M92`B8B(Z"B`@("`@("`@("`@("`@("`D;&5N("`](#(["B`@("`@("`@("`@
M("`@("`D9G5N8R`](")C='EP95]D:6=I="(["B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@8V%S92`B<R(Z"B`@("`@("`@("`@("`@("`D
M;&5N("`](#,["B`@("`@("`@("`@("`@("`D9G5N8R`](")C='EP95]D:6=I
M="(["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`B
M:2(Z"B`@("`@("`@("`@("`@("`D;&5N("`](#0["B`@("`@("`@("`@("`@
M("`D9G5N8R`](")C='EP95]A;&YU;2(["B`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@('T*("`@("`@("!I9B`H*'-T<FQE;B@D9&%T85LD:61X72D@
M(3T@)&QE;BD@?'P@*"$D9G5N8R@D9&%T85LD:61X72D@)B8@*"1D871A6R1I
M9'A=("$]('-T<E]R97!E870H(BTB+"`D;&5N*2DI*2!["B`@("`@("`@("`@
M("1R971U<FX@/2!F86QS93L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M?0H@("`@?0H@("`@<F5T=7)N("1R971U<FX["GT*+R\@?7U]"@HO+R![>WL@
M4V5R=FEC97-?5V5A=&AE<E]G971.97AT07)G*"D*+RHJ"B`J(%-E<G9I8V5S
M7U=E871H97)?9V5T3F5X=$%R9PH@*@H@*B!#:&5C:W,L(&EF('1H92!N97AT
M(&%R9W5M96YT(&ES(&$@<&%R86UE=&5R('1O(&$@<')E9&5C97-S:6YG(&]P
M=&EO;BX*("H@4F5T=7)N<R!E:71H97(@=&AA="!P87)A;65T97(@;W(@9F%L
M<V4L(&EF('1H92!N97AT(&%R9W5M96YT(&ES(&%N(&]P=&EO;@H@*@H@*B!`
M<&%R86T@("!I;G0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C("`@
M("`@("`@("`@("!);G1E<FYA;"!A<F=U;65N="!C;W5N=&5R"B`J($!R971U
M<FX@('-T<FEN9WQB;V]L"B`J+PIF=6YC=&EO;B!397)V:6-E<U]796%T:&5R
M7V=E=$YE>'1!<F<H)B1C*0I["B`@("!I9B`H*"@D8R`K(#$I(#P@)%]315)6
M15);(F%R9V,B72D@)B8@*"1?4T525D526R)A<F=V(EU;)&,@*R`Q77LP?2`A
M/2`B+2(I*2!["B`@("`@("`@)&,K*SL*("`@("`@("!R971U<FX@)%]315)6
M15);(F%R9W8B75LD8UT["B`@("!](&5L<V4@>PH@("`@("`@(')E='5R;B!F
M86QS93L*("`@('T*?0HO+R!]?7T*"B\O($9I<G-T('-E="!A(&9E=R!V87)I
M86)L97,@9F]R('!R;V-E<W-I;F<@=&AE(&]P=&EO;G,*)&UO9&53970@("`]
M(&9A;'-E.PHD<V%V949I;&4@(#T@9F%L<V4["B1P<FEN=$AE;'`@/2!F86QS
M93L*)&EN=D]P="`@("`](&9A;'-E.PHD=F5R8F]S92`@(#T@,#L*)&1B5'EP
M92`@("`](")M>7-Q;"(["B1D8E!R;W0@("`@/2`B=6YI>"(["B1D8DYA;64@
M("`@/2`B<V5R=FEC97-796%T:&5R1$(B.PHD9&)5<V5R("`@(#T@(G)O;W0B
M.PHD9&)087-S("`@(#T@(B(["B1D8DAO<W0@("`@/2`B;&]C86QH;W-T(CL*
M)&1B3W!T:6]N<R`](&%R<F%Y*"D["B1U<V5R1FEL92`@/2`B(CL*"B\O($ET
M97)A=&4@=&AR;W5G:"!T:&4@87)G=6UE;G1S(&%N9"!C:&5C:R!T:&5I<B!V
M86QI9&ET>0IF;W(@*"1C(#T@,3L@)&,@/"`D7U-%4E9%4ELB87)G8R)=.R`D
M8RLK*2!["B`@("!S=VET8V@@*"1?4T525D526R)A<F=V(EU;)&-=>S%]*2![
M"B`@("`@("`@8V%S92`B;"(Z"B`@("`@("`@("`@("\O(&QO8V%T:6]N+6UO
M9&4L(&EF(&%N;W1H97(@;6]D92!I<R!S970L(&)A:6P@;W5T"B`@("`@("`@
M("`@(&EF("@D;6]D95-E="D@>PH@("`@("`@("`@("`@("`@)'!R:6YT2&5L
M<"`]('1R=64["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D;6]D95-E="`@(#T@=')U93L*("`@("`@("`@("`@("`@("1F:6QE4&%R
M="`@/2`B8F)S<W,B.PH@("`@("`@("`@("`@("`@)'1A8FQE3F%M92`](")M
M971A<DQO8V%T:6]N<R(["B`@("`@("`@("`@("`@("`D9&%T84]R9&5R(#T@
M87)R87DH(F(B(#T^(#`L(")S(B`]/B`Q+"`B:2(@/3X@,BD["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S92`B82(Z"B`@
M("`@("`@("`@("\O(&1I=&\@9F]R(&%I<G!O<G0M;6]D90H@("`@("`@("`@
M("!I9B`H)&UO9&53970I('L*("`@("`@("`@("`@("`@("1P<FEN=$AE;'`@
M/2!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)&UO9&53970@("`]('1R=64["B`@("`@("`@("`@("`@("`D9FEL95!A<G0@
M(#T@(F-C8V,B.PH@("`@("`@("`@("`@("`@)'1A8FQE3F%M92`](")M971A
M<D%I<G!O<G1S(CL*("`@("`@("`@("`@("`@("1D871A3W)D97(@/2!A<G)A
M>2@B8B(@/3X@,2P@(G,B(#T^(#(L(")I(B`]/B`P*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!C87-E(")F(CH*("`@("`@
M("`@("`@+R\@9FEL92UF;&%G('=A<R!P<F]V:61E9"P@8VAE8VL@:68@;F5X
M="!A<F=U;65N="!I<R!A('-T<FEN9PH@("`@("`@("`@("!I9B`H*"1U<V5R
M1FEL92`](%-E<G9I8V5S7U=E871H97)?9V5T3F5X=$%R9R@D8RDI(#T]/2!F
M86QS92D@>PH@("`@("`@("`@("`@("`@)'!R:6YT2&5L<"`]('1R=64["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S92`B
M<R(Z"B`@("`@("`@("`@("\O($EF('EO=2!D;W=N;&]A9"!T:&4@9FEL92P@
M:70@=VEL;"!B92!S879E9"!T;R!D:7-K"B`@("`@("`@("`@("1S879E1FEL
M92`@("`@(#T@=')U93L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S
M92`B="(Z"B`@("`@("`@("`@("\O(%1H92!T>7!E(&]F('1H92!$0B!T;R!B
M92!U<V5D"B`@("`@("`@("`@(&EF("@H)&1B5'EP92`](%-E<G9I8V5S7U=E
M871H97)?9V5T3F5X=$%R9R@D8RDI(#T]/2!F86QS92D@>PH@("`@("`@("`@
M("`@("`@)'!R:6YT2&5L<"`]('1R=64["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@8V%S92`B<B(Z"B`@("`@("`@("`@("\O
M(%1H92!P<F]T;V-O;"!O9B!T:&4@1$(@=&\@8F4@=7-E9`H@("`@("`@("`@
M("!I9B`H*"1D8E!R;W0@/2!397)V:6-E<U]796%T:&5R7V=E=$YE>'1!<F<H
M)&,I*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1P<FEN=$AE;'`@
M/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@(&-A<V4@(F0B.@H@("`@("`@("`@("`O+R!4:&4@;F%M92!O9B!T:&4@
M1$(@=&\@8F4@=7-E9`H@("`@("`@("`@("!I9B`H*"1D8DYA;64@/2!397)V
M:6-E<U]796%T:&5R7V=E=$YE>'1!<F<H)&,I*2`]/3T@9F%L<V4I('L*("`@
M("`@("`@("`@("`@("1P<FEN=$AE;'`@/2!T<G5E.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@(G4B.@H@("`@("`@
M("`@("`O+R!4:&4@=7-E<B!O9B!T:&4@1$(@=&\@8F4@=7-E9`H@("`@("`@
M("`@("!I9B`H*"1D8E5S97(@/2!397)V:6-E<U]796%T:&5R7V=E=$YE>'1!
M<F<H)&,I*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1P<FEN=$AE
M;'`@/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@(&-A<V4@(G`B.@H@("`@("`@("`@("`O+R!4:&4@<&%S<W=O<F0@
M;V8@=&AE($1"('1O(&)E('5S960*("`@("`@("`@("`@:68@*"@D9&)087-S
M(#T@4V5R=FEC97-?5V5A=&AE<E]G971.97AT07)G*"1C*2D@/3T](&9A;'-E
M*2!["B`@("`@("`@("`@("`@("`D<')I;G1(96QP(#T@=')U93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!C87-E(")H(CH*
M("`@("`@("`@("`@+R\@5&AE(&AO<W0@;V8@=&AE($1"('1O(&)E('5S960*
M("`@("`@("`@("`@:68@*"@D9&)(;W-T(#T@4V5R=FEC97-?5V5A=&AE<E]G
M971.97AT07)G*"1C*2D@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D
M<')I;G1(96QP(#T@=')U93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("!C87-E(")O(CH*("`@("`@("`@("`@+R\@3W!T:6]N
M<R!F;W(@=&AE($1""B`@("`@("`@("`@(&EF("@H)&]P=&EO;G,@/2!397)V
M:6-E<U]796%T:&5R7V=E=$YE>'1!<F<H)&,I*2`]/3T@9F%L<V4I('L*("`@
M("`@("`@("`@("`@("1P<FEN=$AE;'`@/2!T<G5E.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)&]P=&EO;G,@("`](&5X<&QO9&4H
M(BPB+"`D;W!T:6]N<RD["B`@("`@("`@("`@("`@("!F;W)E86-H("@D;W!T
M:6]N<R!A<R`D;W!T:6]N*2!["B`@("`@("`@("`@("`@("`@("`@)&]P=%!A
M:7(@/2!E>'!L;V1E*"(](BP@)&]P=&EO;BD["B`@("`@("`@("`@("`@("`@
M("`@)&1B3W!T:6]N<ULD;W!T4&%I<ELP75T@/2`D;W!T4&%I<ELQ73L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("!C87-E(")V(CH*("`@("`@("`@("`@+R\@:6YC<F5A<V4@
M=F5R8F]S:71Y"B`@("`@("`@("`@(&9O<B`H)&D@/2`Q.R`D:2`\('-T<FQE
M;B@D7U-%4E9%4ELB87)G=B)=6R1C72D[("1I*RLI('L*("`@("`@("`@("`@
M("`@(&EF("@D7U-%4E9%4ELB87)G=B)=6R1C77LD:7T@/3T@(G8B*2!["B`@
M("`@("`@("`@("`@("`@("`@)'9E<F)O<V4K*SL*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&EN=D]P="`@("`]('1R
M=64["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M9&5F875L=#H*("`@("`@("`@("`@+R\@87)G=6UE;G0@;F]T('9A;&ED+"!B
M86EL(&]U=`H@("`@("`@("`@("`D:6YV3W!T("`@(#T@=')U93L*("`@("`@
M("`@("`@8G)E86L["B`@("!]"B`@("!I9B`H)&EN=D]P="D@>PH@("`@("`@
M("\O('-E92!A8F]V90H@("`@("`@("1P<FEN=$AE;'`@/2!T<G5E.PH@("`@
M("`@(&5C:&\@(DEN=F%L:60@;W!T:6]N.B`G(BXD7U-%4E9%4ELB87)G=B)=
M6R1C72XB)UQN(CL*("`@("`@("!B<F5A:SL*("`@('T*?0H*+R\@:&5L<"UM
M97-S86=E"FEF("@A)&UO9&53970@?'P@)'!R:6YT2&5L<"D@>PH@("`@96-H
M;R`B57-A9V4Z("(N8F%S96YA;64H)%]315)615);(F%R9W8B75LP72P@(BYP
M:'`B*2XB("UL?"UA(%MO<'1I;VYS75QN(CL*("`@(&5C:&\@(D]P=&EO;G,Z
M7&XB.PH@("`@96-H;R`B("`M;"`@("`@("`@("`@("`@8G5I;&0@;&]C871I
M;VYS1$)<;B(["B`@("!E8VAO("(@("UA("`@("`@("`@("`@("!B=6EL9"!A
M:7)P;W)T<T1"7&XB.PH@("`@96-H;R`B("`M9B`\9FEL93X@("`@("`@=7-E
M(#QF:6QE/B!A<R!I;G!U=%QN(CL*("`@(&5C:&\@(B`@+7,@("`@("`@("`@
M("`@('-A=F4@9&]W;FQO861E9"!F:6QE('1O(&1I<VM<;B(["B`@("!E8VAO
M("(@("UT(#QD8G1Y<&4^("`@("!T>7!E(&]F('1H92!$0B!T;R!B92!U<V5D
M7&XB.PH@("`@96-H;R`B("`M<B`\9&)P<F]T;V-O;#X@<')O=&]C;VP@+2TM
M+2U<(BTM+2TM+2TM+2U<;B(["B`@("!E8VAO("(@("UD(#QD8FYA;64^("`@
M("!N86UE("TM+2TM+2TM+5PB+2TM+2TM+2TM+5QN(CL*("`@(&5C:&\@(B`@
M+74@/&1B=7-E<CX@("`@('5S97(@+2TM+2TM+2TM7"(M+2TM+2TM+2TM7&XB
M.PH@("`@96-H;R`B("`M<"`\9&)P87-S/B`@("`@<&%S<R`M+2TM+2TM+2U<
M(BTM+2TM+2TM+2U<;B(["B`@("!E8VAO("(@("UH(#QD8FAO<W0^("`@("!H
M;W-T("TM+2TM+2TM+5PB+2TM+2TM+2TM+5QN(CL*("`@(&5C:&\@(B`@+6\@
M/&1B;W!T:6]N<SX@(&]P=&EO;G,@+2TM+2TM7"(M+2TM+2TM+2TM7&XB.PH@
M("`@96-H;R`B("`@("`@("`@("`@("`@("`@:6X@=&AE(&YO=&%T:6]N(&]P
M=&EO;CUV86QU92PN+BY<;B(["B`@("!E8VAO("(@("UV("`@("`@("`@("`@
M("!D:7-P;&%Y('9E<F)O<V4@9&5B=6=G:6YG(&UE<W-A9V5S7&XB.PH@("`@
M96-H;R`B("`@("`@("`@("`@("`@("`@;75L=&EP;&4@+78@:6YC<F5A<V5S
M('9E<F)O<VET>5QN(CL*("`@(&5X:70H,C4U*3L*?0H*+R\@8VAE8VLL(&EF
M('IL:6(@:7,@879A:6QA8FQE"FEF("AE>'1E;G-I;VY?;&]A9&5D*")Z;&EB
M(BDI('L*("`@("1O<&5N("`](")G>F]P96XB.PH@("`@)&-L;W-E(#T@(F=Z
M8VQO<V4B.PH@("`@)&9I;&5S(#T@87)R87DH"B`@("`@("`@)'5S97)&:6QE
M+"`B;G-D7R(N)&9I;&5087)T+"`B;G-D7R(N)&9I;&5087)T+B(N='AT(BP*
M("`@("`@("`B;G-D7R(N)&9I;&5087)T+B(N9WHB+"`B:'1T<#HO+W=E871H
M97(N;F]A82YG;W8O9&%T82]N<V1?(BXD9FEL95!A<G0N(BYG>B(*("`@("D[
M"GT@96QS92!["B`@("`D;W!E;B`@/2`B9F]P96XB.PH@("`@)&-L;W-E(#T@
M(F9C;&]S92(["B`@("`D9FEL97,@/2!A<G)A>2@*("`@("`@("`D=7-E<D9I
M;&4L(")N<V1?(BXD9FEL95!A<G0L(")N<V1?(BXD9FEL95!A<G0N(BYT>'0B
M+`H@("`@("`@(")H='1P.B\O=V5A=&AE<BYN;V%A+F=O=B]D871A+VYS9%\B
M+B1F:6QE4&%R="XB+G1X="(*("`@("D["GT*+R\@=&AE;B!T<GD@=&\@;W!E
M;B!A('-O=7)C92!I;B!T:&4@9VEV96X@;W)D97(*9F]R96%C:"`H)&9I;&5S
M(&%S("1F:6QE*2!["B`@("`D9G`@/2!`)&]P96XH)&9I;&4L(")R8B(I.PH@
M("`@:68@*"1F<"D@>PH@("`@("`@("\O(&9O=6YD(&$@=F%L:60@<V]U<F-E
M"B`@("`@("`@:68@*"1V97)B;W-E(#X@,"D@>PH@("`@("`@("`@("!E8VAO
M(")397)V:6-E<U]796%T:&5R.B!5<VEN9R`G(BXD9FEL92XB)R!A<R!S;W5R
M8V4N7&XB.PH@("`@("`@('T*("`@("`@("!I9B`H)'-A=F5&:6QE("8F("%F
M:6QE7V5X:7-T<R@D9FEL92DI('L*("`@("`@("`@("`@+R\@87!P87)E;G1L
M>2!W92!W86YT('1O('-A=F4@=&AE(&9I;&4L(&%N9"!I="=S(&$@<F5M;W1E
M(&9I;&4*("`@("`@("`@("`@)&9I;&4@/2!B87-E;F%M92@D9FEL92D["B`@
M("`@("`@("`@("1F<',@/2!`)&]P96XH)&9I;&4L(")W8B(I.PH@("`@("`@
M("`@("!I9B`H(21F<',I('L*("`@("`@("`@("`@("`@(&5C:&\@(E-E<G9I
M8V5S7U=E871H97(Z($-O=6QD;B=T('-A=F4@=&\@)R(N)&9I;&4N(B<A7&XB
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:68@*"1V
M97)B;W-E(#X@,"D@>PH@("`@("`@("`@("`@("`@("`@(&5C:&\@(E-E<G9I
M8V5S7U=E871H97(Z(%-A=FEN9R!S;W5R8V4@=&\@)R(N)&9I;&4N(B<N7&XB
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@+R\@<F5A9"!F
M<F]M(&9I;&5P;VEN=&5R(&%N9"!S879E('1O(&1I<VL*("`@("`@("`@("`@
M("`@('=H:6QE("@D;&EN92`](&9R96%D*"1F<"P@,3`R-"DI('L*("`@("`@
M("`@("`@("`@("`@("!F=W)I=&4H)&9P<RP@)&QI;F4L('-T<FQE;B@D;&EN
M92DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@+R\@=6YF
M;W)T=6YA=&5L>2!Z;&EB(&1O97,@;F]T('-U<'!O<G0@<B]W(&]N(&$@<F5S
M;W5R8V4L"B`@("`@("`@("`@("`@("`O+R!S;R!N;R!R97=I;F0@+3X@;6]V
M92`D9G`@=&\@;F5W(&9I;&4@;VX@9&ES:PH@("`@("`@("`@("`@("`@)&-L
M;W-E*"1F<"D["B`@("`@("`@("`@("`@("`D8VQO<V4H)&9P<RD["B`@("`@
M("`@("`@("`@("`D9G`@/2!`)&]P96XH)&9I;&4L(")R8B(I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(&)R96%K.PH@("`@?0I]"FEF("@A
M)&9P*2!["B`@("`O+R!N;R!F:6QE<R!F;W5N9"P@;W(@8V]N;F5C=&EO;B!N
M;W0@879A:6QA8FQE+BXN(&)A:6P@;W5T"B`@("!D:64H(E-E<G9I8V5S7U=E
M871H97(Z(%-O=7)C969I;&4@;G-D7R(N)&9I;&5087)T+B(@;F]T(&9O=6YD
M(5QN(BD["GT*"B1D<VX@("`@(#T@)&1B5'EP92XB.B\O(BXD9&)5<V5R+B(Z
M(BXD9&)087-S+B)`(BXD9&)0<F]T+B(K(BXD9&)(;W-T+B(O(BXD9&).86UE
M.PHD9'-N:6YF;R`](&%R<F%Y*`H@("`@(G!H<'1Y<&4B("`]/B`D9&)4>7!E
M+`H@("`@(G!R;W1O8V]L(B`]/B`D9&)0<F]T+`H@("`@(G5S97)N86UE(B`]
M/B`D9&)5<V5R+`H@("`@(G!A<W-W;W)D(B`]/B`D9&)087-S+`H@("`@(FAO
M<W1S<&5C(B`]/B`D9&)(;W-T+`H@("`@(F1A=&%B87-E(B`]/B`D9&).86UE
M+`H@("`@(FUO9&4B("`@("`]/B`B,#8T-"(**3L*"B1D8B`@/2!$0CHZ8V]N
M;F5C="@D9'-N:6YF;RP@)&1B3W!T:6]N<RD["FEF("A$0CHZ:7-%<G)O<B@D
M9&(I*2!["B`@("!E8VAO(")397)V:6-E<U]796%T:&5R.B!#;VYN96-T:6]N
M('1O($1"('=I=&@@)R(N)&1B5'EP92XB.B\O(BXD9&)5<V5R+B(Z4$%34T`B
M+B1D8DAO<W0N(B\B+B1D8DYA;64N(B<@9F%I;&5D(5QN(CL*("`@(&1I92@D
M9&(M/F=E=$UE<W-A9V4H*2XB7&XB*3L*?2!E;'-E('L*("`@("\O(%1E<W0L
M(&EF('=E(&AA=F4@=&\@<W=I<&4@;W(@8W)E871E('1H92!T86)L92!F:7)S
M=`H@("`@)'-E;&5C="`](")314Q%0U0@*B!&4D]-("(N)'1A8FQE3F%M93L*
M("`@("1R97-U;'0@/2`D9&(M/G%U97)Y*"1S96QE8W0I.PH*("`@(&EF("A$
M0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("\O($-R96%T92!N97<@
M=&%B;&4*("`@("`@("`D8W)E871E(#T@(D-214%412!404),12`B+B1T86)L
M94YA;64N(BAI9"!I;G0L8FQO8VL@:6YT+'-T871I;VX@:6YT+&EC86\@=F%R
M8VAA<B@T*2QN86UE('9A<F-H87(H.#`I+'-T871E('9A<F-H87(H,BDL8V]U
M;G1R>2!V87)C:&%R*#4P*2QW;6\@:6YT+&QA=&ET=61E(&9L;V%T+&QO;F=I
M='5D92!F;&]A="QE;&5V871I;VX@9FQO870L>"!F;&]A="QY(&9L;V%T+'H@
M9FQO870I(CL*("`@("`@("!I9B`H)'9E<F)O<V4@/B`P*2!["B`@("`@("`@
M("`@(&5C:&\@(E-E<G9I8V5S7U=E871H97(Z($-R96%T:6YG('1A8FQE("<B
M+B1T86)L94YA;64N(B<N7&XB.PH@("`@("`@('T*("`@("`@("`D<F5S=6QT
M("`]("1D8BT^<75E<GDH)&-R96%T92D["B`@("`@("`@:68@*$1".CII<T5R
M<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@(&1I92@D<F5S=6QT+3YG971-
M97-S86=E*"DN(EQN(BD["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@
M("`O+R!$96QE=&4@=&AE(&]L9"!S='5F9@H@("`@("`@("1D96QE=&4@/2`B
M1$5,151%($923TT@(BXD=&%B;&5.86UE.PH@("`@("`@(&EF("@D=F5R8F]S
M92`^(#`I('L*("`@("`@("`@("`@96-H;R`B4V5R=FEC97-?5V5A=&AE<CH@
M1&5L971I;F<@9G)O;2!T86)L92`G(BXD=&%B;&5.86UE+B(G+EQN(CL*("`@
M("`@("!]"B`@("`@("`@)')E<W5L="`]("1D8BT^<75E<GDH)&1E;&5T92D[
M"B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@
M("`@(&1I92@D<F5S=6QT+3YG971-97-S86=E*"DN(EQN(BD["B`@("`@("`@
M?0H@("`@?0H*("`@("\O($]K+"!$0B!S:&]U;&0@8F4@=7`@86YD(')U;FYI
M;F<@;F]W+"!L970G<R!S:&]V92!I;B!T:&4@9&%T80H@("`@)&QI;F4@("`]
M(#`["B`@("`D97)R;W(@(#T@,#L*("`@("\O(')E860@9&%T82!F<F]M(&9I
M;&4*("`@('=H:6QE("@D9&%T82`](&9G971C<W8H)&9P+"`Q,#`P+"`B.R(I
M*2!["B`@("`@("`@+R\@0VAE8VL@9F]R('9A;&ED(&1A=&$*("`@("`@("!I
M9B`H*'-I>F5O9B@D9&%T82D@/"`Y*2!\?"`A4V5R=FEC97-?5V5A=&AE<E]C
M:&5C:T1A=&$H)&1A=&$L("1D871A3W)D97(I*2!["B`@("`@("`@("`@("`@
M("!E8VAO(")397)V:6-E<U]796%T:&5R.B!);G9A;&ED(&1A=&$@:6X@9FEL
M92%<;B(["B`@("`@("`@("`@("`@("!E8VAO(")<=$QI;F4@(BXH)&QI;F4@
M*R`Q*2XB.B`B+FEM<&QO9&4H(CLB+"`D9&%T82DN(EQN(CL*("`@("`@("`@
M("`@("`@("1E<G)O<BLK.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("\O(&-A;&-U;&%T92!L871I='5D92!A;F0@;&]N9VET=61E"B`@("`@("`@
M("`@("\O(&ET(&-O;65S(&EN(&$@9&1D+6UM6RUS<UU.?%-\17Q7(&9O<FUA
M=`H@("`@("`@("`@("`D8V]O<F0@/2!A<G)A>2@@(FQA=&ET=61E(B`]/B`W
M+"`B;&]N9VET=61E(B`]/B`X*3L*("`@("`@("`@("`@9F]R96%C:"`H)&-O
M;W)D(&%S("1L871L;VX@/3X@)&%)9"D@>PH@("`@("`@("`@("`@("`@<')E
M9U]M871C:"@B+UXH7&1[,2PS?2DM*%QD>S$L,GTI*"TH7&1[,2PR?2DI/RA;
M3E-%5UTI)"\B+"`D9&%T85LD84ED72P@)')E<W5L="D["B`@("`@("`@("`@
M("`@("`D>R1L871L;VY](#T@,#L@)&9A8W1O<B`](#$["B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D<F5S=6QT(&%S("1V87(I('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H*'-T<FQE;B@D=F%R*2`^(#`I("8F(&-T>7!E7V1I9VET
M*"1V87(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1[)&QA=&QO;GT@
M*ST@)'9A<B`O("1F86-T;W(["B`@("`@("`@("`@("`@("`@("`@("`@("1F
M86-T;W(@*CT@-C`["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*&-T
M>7!E7V%L<&AA*"1V87(I("8F(&EN7V%R<F%Y*"1V87(L(&%R<F%Y*")3(BP@
M(E<B*2DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'LD;&%T;&]N?2`J
M/2`H+3$I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@0V%L8W5L871E('1H
M92!C87)T97-I86X@8V]O<F1I;F%T97,@9F]R(&QA=&ET=61E(&%N9"!L;VYG
M:71U9&4*("`@("`@("`@("`@)'1H971A(#T@9&5G,G)A9"@D;&%T:71U9&4I
M.PH@("`@("`@("`@("`D<&AI("`@/2!D96<R<F%D*"1L;VYG:71U9&4I.PH*
M("`@("`@("`@("`@)'@@/2!315)624-%4U]714%42$527U)!1$E54U]%05)4
M2"`J(&-O<R@D<&AI*2`J(&-O<R@D=&AE=&$I.PH@("`@("`@("`@("`D>2`]
M(%-%4E9)0T537U=%051(15)?4D%$25537T5!4E1(("H@<VEN*"1P:&DI("H@
M8V]S*"1T:&5T82D["B`@("`@("`@("`@("1Z(#T@4T525DE#15-?5T5!5$A%
M4E]2041)55-?14%25$@@("`@("`@("`@("`@*B!S:6XH)'1H971A*3L*"B`@
M("`@("`@("`@("\O($-H96-K(&9O<B!E;&5V871I;VX@:6X@9&%T80H@("`@
M("`@("`@("`D96QE=F%T:6]N(#T@:7-?;G5M97)I8R@D9&%T85LQ,5TI(#\@
M)&1A=&%;,3%=(#H@,#L*"B`@("`@("`@("`@("\O(&EN=&5G97)S.B!C;VYV
M97)T("(M+2(@9FEE;&1S('1O(&YU;&PL(&5M<'1Y(&9I96QD<R!T;R`P"B`@
M("`@("`@("`@(&9O<F5A8V@@*&%R<F%Y*"1D871A3W)D97);(F(B72P@)&1A
M=&%/<F1E<ELB<R)=+"`V*2!A<R`D:2D@>PH@("`@("`@("`@("`@("`@:68@
M*'-T<G!O<R@D9&%T85LD:5TL("(M+2(I("$]/2!F86QS92D@>PH@("`@("`@
M("`@("`@("`@("`@("1D871A6R1I72`](")N=6QL(CL*("`@("`@("`@("`@
M("`@('T@96QS96EF("@D9&%T85LD:5T@/3T@(B(I('L*("`@("`@("`@("`@
M("`@("`@("`D9&%T85LD:5T@/2`P.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O+R!S=')I;F=S.B!Q=6]T90H@("`@
M("`@("`@("!F;W)E86-H("AA<G)A>2@D9&%T84]R9&5R6R)I(ETL(#,L(#0L
M(#4I(&%S("1I*2!["B`@("`@("`@("`@("`@("`D9&%T85LD:5T@/2`D9&(M
M/G%U;W1E*"1D871A6R1I72D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("\O(&EN<V5R="!D871A"B`@("`@("`@("`@("1I;G-E<G0@(#T@(DE.4T52
M5"!)3E1/("(N)'1A8FQE3F%M92XB(%9!3%5%4R@B+B@D;&EN92`M("1E<G)O
M<BDN(BPB.PH@("`@("`@("`@("`D:6YS97)T("X]("1D871A6R1D871A3W)D
M97);(F(B75TN(BPB+B1D871A6R1D871A3W)D97);(G,B75TN(BPB.PH@("`@
M("`@("`@("`D:6YS97)T("X]("1D871A6R1D871A3W)D97);(FDB75TN(BPB
M+B1D871A6S-=+B(L(BXD9&%T85LT72XB+"(["B`@("`@("`@("`@("1I;G-E
M<G0@+CT@)&1A=&%;-5TN(BPB+B1D871A6S9=+B(L(BYR;W5N9"@D;&%T:71U
M9&4L(#0I+B(L(CL*("`@("`@("`@("`@)&EN<V5R="`N/2!R;W5N9"@D;&]N
M9VET=61E+"`T*2XB+"(N)&5L979A=&EO;BXB+"(N<F]U;F0H)'@L(#0I+B(L
M(CL*("`@("`@("`@("`@)&EN<V5R="`N/2!R;W5N9"@D>2P@-"DN(BPB+G)O
M=6YD*"1Z+"`T*2XB*2(["@H@("`@("`@("`@("`D<F5S=6QT(#T@)&1B+3YQ
M=65R>2@D:6YS97)T*3L*("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R
M97-U;'0I*2!["B`@("`@("`@("`@("`@("!E8VAO(")<=$QI;F4@(BXH)&QI
M;F4@*R`Q*2XB.B`B+B1I;G-E<G0N(EQN(CL*("`@("`@("`@("`@("`@(&5C
M:&\@)')E<W5L="T^9V5T365S<V%G92@I+B)<;B(["B`@("`@("`@("`@("`@
M("`D97)R;W(K*SL*("`@("`@("`@("`@?2!E;'-E:68H)'9E<F)O<V4@/B`R
M*2!["B`@("`@("`@("`@("`@("!E8VAO("1I;G-E<G0N(EQN(CL*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("`D;&EN92LK.PH@("`@?0H@("`@
M+R\@8V]M;6ET(&%N9"!C;&]S90H@("`@)&1B+3YD:7-C;VYN96-T*"D["B`@
M("!I9B`H)'9E<F)O<V4@/B`P('Q\("1E<G)O<B`^(#`I('L*("`@("`@("!E
M8VAO(")397)V:6-E<U]796%T:&5R.B`B+B@D;&EN92`M("1E<G)O<BDN(B`B
M+B1T86)L94YA;64N(B!A9&1E9"`B.PH@("`@("`@(&5C:&\@(G1O(&1A=&%B
M87-E("<B+B1D8DYA;64N(B<@*"(N)&5R<F]R+B(@97)R;W(H<RDI+EQN(CL*
M("`@('T*?0HD8VQO<V4H)&9P*3L*/SX*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1A=&$O4V5R=FEC97-?5V5A
M=&AE<B]I;6%G97,O````````````````````````````````````````````
M`````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-3$U-#,S-S,V`#`R-#(R-@`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M9&%T82]397)V:6-E<U]796%T:&5R+VEM86=E<R]S=6YR:7-E+F=I9@``````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`T-#$`,3`U,34T,S,W,S8`,#(V-#`T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````$=)1C@Y81P`#0#$``#L
ML)W]CW5<5"3_^?CPPPK_633_<T__]"C\QK?]X]K_X1:?DH#_.A:0?D'_[NN^
MD'G__S/___\`````````````````````````````````````````````````
M```````A^00``````"P`````'``-```%GF`DCF1IGN@8%"90#&D$EPCC1`$B
M%T",&+.!SL'0%70`1B+F*!26$5[$$(@Z!HSJ8'9J*B._".#A>(AM45W*87A&
M'HN&8"YHF-NW2$)M6@$$!`0*@P1R"P$P;`P&)0`&2PN`@P<'@PH$`CT!#`P`
M7"()`0%_@I0'$)2$`@]9>2(`"%<R#0V3$+>WE9@-(@.N;4ZB`K:XN:H(*T`Q
MRR@A`#L`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1A=&$O4V5R=FEC
M97-?5V5A=&AE<B]I;6%G97,O<W5N<V5T+F=I9@``````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M-#,T`#$P-3$U-#,S-S,V`#`R-C(S-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!'248X.6$>``\`Q```_NWJ^589_V%'_WHD
M_X-N_SP;;C@@_<W%_K2GU;2IBV-+Q3P,NJ*8J8M^_):"TI*"_YDS____````
M````````````````````````````````````````````````````(?D$````
M```L`````!X`#P``!9E@)(YD:9YHJJZF(YC(RYY'(2*'*"#L09`Y0"$GR"$*
M`!8@($A&=D_',QF0SI;(2"R2>``>VBQT!1`T(X^&PL!6-!(1PCD"X*7D"<.B
M$.@'%@8,5@`$!3(E"`1)#09]`X^/?09P1P56)CX$>0&0$)X0D0H/!8HP!TX`
M"IR?K*`#"PTC3B,"!88$#@H#K:T#`0H'+H<SQ,7&(B$`.P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D871A+UA-3%]397)I86QI>F5R+P``
M````````````````````````````````````````````````````````````
M```P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,S<S-@`P,C(S-3``(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1A=&$O
M6$U,7U-E<FEA;&EZ97(O9&]C+P``````````````````````````````````
M`````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-3$U-#,S-S,V`#`R,S$Q-0`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O9&%T82]834Q?4V5R:6%L:7IE<B]D;V,O=&]D;RYT>'0`
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P-C``,3`U,34T,S,W,S8`,#(T-C(P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````%1/
M1$\Z"BTM+2TM"BT@:6YT<F]D=6-E(&-O;G-T86YT<R!F;W(@;W!T:6]N<R!T
M;R!A=F]I9"!T>7!O<PH*5$]$3R!834Q?4V5R:6%L:7IE<CH*+2TM+2TM+2TM
M+2TM+2TM+2TM+2T*+2!F:6YD(&$@=V%Y('1O(&1E=&5C="!R969E<F5N8V5S
M(&EN('1H92!S=')U8W1U<F4@86YD(&%D9"!I9"]I9')E9B!A='1R:6)U=&5S
M"BT@<V5R:6%L:7IE('-O;64@;W1H97(@<W1R=6-T=7)E<RP@97-P96-I86QL
M>2!84&%T:"!R971U<FX@=F%L=65S"BT@8W5S=&]M('-E<FEA;&EZ871I;VX@
M;V8@;V)J96-T<PH*5$]$3R!834Q?56YS97)I86QI>F5R.@HM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM"BT@<W5P<&]R="!F;W(@>&UL.G-P86-E(&%T=')I8G5T
M90HM('-E="!T>7!E<R!F;W(@8V5R=&%I;B!T86=S("AL:6ME(&EN('!A=$-O
M;F9I9W5R871I;VXI"BT@;F%M97-P86-E('-U<'!O<G0*+2!C=7-T;VT@=6YS
M97)I86QI>F%T:6]N(&9O<B!O8FIE8W1S("AS=&%T:6,@=6YS97)I86QI>F4H
M*2!O<B!F<F]M6$U,*"D@;65T:&]D<RD*+2!U;G-E<FEA;&EZ92!R969E<F5N
M8V5S('5S:6YG(&ED+VED<F5F````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O1&%T92\`````````````````````````````
M````````````````````````````````````````````````````````,#`P
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W,S<`
M,#$W-#8T`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]$871E+T-A;&,N
M<&AP````````````````````````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#(P
M,#(U,``Q,#4Q-30S,S<S-P`P,C$P,S8`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD
M=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*
M+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I
M9VAT("AC*2`Q.3DW+3(P,#4@0F%B82!"=65H;&5R+"!0:65R<F4M06QA:6X@
M2F]Y92`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=&AE
M($YE=R!"4T0@;&EC96YS92P@5&AA="!I<R!B=6YD;&5D("!\"B\O('P@=VET
M:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES(&%V
M86EL86)L92!T:')O=6=H("`@("`@?`HO+R!\('1H92!W;W)L9"UW:61E+7=E
M8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@?"!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N
M<V5S+V)S9"UL:6-E;G-E+G!H<"`@("`@("`@("`@("`@("`@("!\"B\O('P@
M268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(&YE=R!"4T1L
M:6-E;G-E(&%N9"!A<F4@=6YA8FQE("`@?`HO+R!\('1O(&]B=&%I;B!I="!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E
M('1O("`@("`@('P*+R\@?"!P96%R+61E=D!L:7-T<RYP:'`N;F5T('-O('=E
M(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@0F%B
M82!"=65H;&5R(#QB86)A0&)A8F%Z+F-O;3X@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@?"`@("`@("`@(%!I97)R92U!;&%I;B!*;WEE
M(#QP86IO>65`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*+RHJ"B`J($-A;&-U
M;&%T97,L(&UA;FEP=6QA=&5S(&%N9"!R971R:65V97,@9&%T97,*("H*("H@
M270@9&]E<R!N;W0@<F5L>2!O;B`S,BUB:70@<WES=&5M('1I;64@<W1A;7!S
M+"!S;R!I="!W;W)K<R!D871E<PH@*B!B969O<F4@,3DW,"!A;F0@869T97(@
M,C`S."X*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@0&-A=&5G
M;W)Y("`@1&%T92!A;F0@5&EM90H@*B!`<&%C:V%G92`@("!$871E"B`J($!A
M=71H;W(@("`@($UO;G1E($]H<G0@/&UO;G1E0&ES<&DN;F5T/@H@*B!`875T
M:&]R("`@("!0:65R<F4M06QA:6X@2F]Y92`\<&%J;WEE0'!H<"YN970^"B`J
M($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE
M=#X*("H@0&-O<'ER:6=H="`@,3DY.2TR,#`U("!-;VYT92!/:')T+"!0:65R
M<F4M06QA:6X@2F]Y92P@1&%N:65L($-O;G9I<W-O<@H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E
M;G-E+G!H<"`@3F5W($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@($-64SH@
M)$ED.B!#86QC+G!H<"QV(#$N,S,@,C`P-2\Q,2\Q-2`P,#HQ-CHS.2!P86IO
M>64@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+T1A=&4*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN
M8V4@4F5L96%S92`Q+C(*("HO"@II9B`H(61E9FEN960H)T1!5$5?0T%,0U]"
M14=)3E]7145+1$%9)RDI('L*("`@("\J*@H@("`@("H@1&5F:6YE<R!W:&%T
M(&1A>2!S=&%R=',@=&AE('=E96L*("`@("`J"B`@("`@*B!-;VYD87D@*#$I
M(&ES('1H92!I;G1E<FYA=&EO;F%L('-T86YD87)D+@H@("`@("H@4F5D969I
M;F4@=&AI<R!T;R`P(&EF('EO=2!W86YT('=E96MS('1O(&)E9VEN(&]N(%-U
M;F1A>2X*("`@("`J+PH@("`@9&5F:6YE*"=$051%7T-!3$-?0D5'24Y?5T5%
M2T1!62<L(#$I.PI]"@II9B`H(61E9FEN960H)T1!5$5?0T%,0U]&3U)-050G
M*2D@>PH@("`@+RHJ"B`@("`@*B!4:&4@9&5F875L="!V86QU92!F;W(@96%C
M:"!M971H;V0G<R`D9F]R;6%T('!A<F%M971E<@H@("`@("H*("`@("`J(%1H
M92!D969A=6QT(&ES("<E625M)60G+B`@5&\@;W9E<G)I9&4@=&AI<R!D969A
M=6QT+"!D969I;F4*("`@("`J('1H:7,@8V]N<W1A;G0@8F5F;W)E(&EN8VQU
M9&EN9R!#86QC+G!H<"X*("`@("`J"B`@("`@*B!`<VEN8V4@0V]N<W1A;G0@
M879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XU+C`*("`@("`J+PH@("`@9&5F
M:6YE*"=$051%7T-!3$-?1D]234%4)RP@)R59)6TE9"<I.PI]"@HO*BH*("H@
M0V%L8W5L871E<RP@;6%N:7!U;&%T97,@86YD(')E=')I979E<R!D871E<PH@
M*@H@*B!)="!D;V5S(&YO="!R96QY(&]N(#,R+6)I="!S>7-T96T@=&EM92!S
M=&%M<',L('-O(&ET('=O<FMS(&1A=&5S"B`J(&)E9F]R92`Q.3<P(&%N9"!A
M9G1E<B`R,#,X+@H@*@H@*B!`875T:&]R("`@("!-;VYT92!/:')T(#QM;VYT
M94!I<W!I+FYE=#X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\
M9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DY+"`R,#`R+"`R
M,#`S(&ES<&D*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E
M+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($YE=R!"4T0@3&EC96YS
M90H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N-@H@*B!`;&EN:R`@("`@
M("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1&%T90H@*B!`<VEN8V4@
M("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C(*("HO"F-L
M87-S($1A=&5?0V%L8PI["B`@("`O*BH*("`@("`J($9O<FUA=',@=&AE(&1A
M=&4@:6X@=&AE(&=I=F5N(&9O<FUA="P@;75C:"!L:6ME('-T<F9M="@I"B`@
M("`@*@H@("`@("H@5&AI<R!F=6YC=&EO;B!I<R!U<V5D('1O(&%L;&5V:6%T
M92!T:&4@<')O8FQE;2!W:71H(#,R+6)I="!N=6UB97)S(&9O<@H@("`@("H@
M9&%T97,@<')E(#$Y-S`@;W(@<&]S="`R,#,X+"!A<R!S=')F;70H*2!H87,@
M;VX@;6]S="!S>7-T96US+@H@("`@("H@36]S="!O9B!T:&4@9F]R;6%T=&EN
M9R!O<'1I;VYS(&%R92!C;VUP871I8FQE+@H@("`@("H*("`@("`J($9O<FUA
M='1I;F<@;W!T:6]N<SH*("`@("`J(#QP<F4^"B`@("`@*B`E82`@(&%B8G)E
M=FEA=&5D('=E96MD87D@;F%M92`H4W5N+"!-;VXL(%1U92D*("`@("`J("5!
M("`@9G5L;"!W965K9&%Y(&YA;64@*%-U;F1A>2P@36]N9&%Y+"!4=65S9&%Y
M*0H@("`@("H@)6(@("!A8F)R979I871E9"!M;VYT:"!N86UE("A*86XL($9E
M8BP@36%R*0H@("`@("H@)4(@("!F=6QL(&UO;G1H(&YA;64@*$IA;G5A<GDL
M($9E8G)U87)Y+"!-87)C:"D*("`@("`J("5D("`@9&%Y(&]F(&UO;G1H("AR
M86YG92`P,"!T;R`S,2D*("`@("`J("5E("`@9&%Y(&]F(&UO;G1H+"!S:6YG
M;&4@9&EG:70@*')A;F=E(#`@=&\@,S$I"B`@("`@*B`E12`@(&YU;6)E<B!O
M9B!D87ES('-I;F-E('5N<W!E8VEF:65D(&5P;V-H("AI;G1E9V5R*0H@("`@
M("H@("`@("`@("@E12!I<R!U<V5F=6P@9F]R('!A<W-I;F<@82!D871E(&EN
M(&$@55),(&%S"B`@("`@*B`@("`@("`@86X@:6YT96=E<B!V86QU92X@5&AE
M;B!S:6UP;'D@=7-E"B`@("`@*B`@("`@("`@9&%Y<U1O1&%T92@I('1O(&-O
M;G9E<G0@8F%C:R!T;R!A(&1A=&4N*0H@("`@("H@)6H@("!D87D@;V8@>65A
M<B`H<F%N9V4@,#`Q('1O(#,V-BD*("`@("`J("5M("`@;6]N=&@@87,@9&5C
M:6UA;"!N=6UB97(@*')A;F=E(#$@=&\@,3(I"B`@("`@*B`E;B`@(&YE=VQI
M;F4@8VAA<F%C=&5R("A<;BD*("`@("`J("5T("`@=&%B(&-H87)A8W1E<B`H
M7'0I"B`@("`@*B`E=R`@('=E96MD87D@87,@9&5C:6UA;"`H,"`](%-U;F1A
M>2D*("`@("`J("55("`@=V5E:R!N=6UB97(@;V8@8W5R<F5N="!Y96%R+"!F
M:7)S="!S=6YD87D@87,@9FER<W0@=V5E:PH@("`@("H@)7D@("!Y96%R(&%S
M(&1E8VEM86P@*')A;F=E(#`P('1O(#DY*0H@("`@("H@)5D@("!Y96%R(&%S
M(&1E8VEM86P@:6YC;'5D:6YG(&-E;G1U<GD@*')A;F=E(#`P,#`@=&\@.3DY
M.2D*("`@("`J("4E("`@;&ET97)A;"`G)2<*("`@("`J(#PO<')E/@H@("`@
M("H*("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE(&1A>2!O9B!T
M:&4@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO
M;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R+B`@
M57-E('1H92!C;VUP;&5T92!Y96%R(&EN<W1E860@;V8@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!A8F)R979I871E9"!V97)S:6]N+B`@
M12YG+B!U<V4@,C`P-2P@;F]T(#`U+@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@1&\@;F]T(&%D9"!L96%D:6YG(#`G<R!F;W(@>65A<G,@<')I
M;W(@=&\@,3`P,"X*("`@("`J($!P87)A;2!S=')I;F<@)&9O<FUA="`@=&AE
M(&9O<FUA="!S=')I;F<*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M=&AE(&1A=&4@:6X@=&AE(&1E<VER960@9F]R;6%T"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@9&%T949O<FUA="@D9&%Y+"`D;6]N=&@L("1Y96%R+"`D9F]R;6%T
M*0H@("`@>PH@("`@("`@(&EF("@A1&%T95]#86QC.CII<U9A;&ED1&%T92@D
M9&%Y+"`D;6]N=&@L("1Y96%R*2D@>PH@("`@("`@("`@("`D>65A<B`@/2!$
M871E7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@("`@("1M;VYT:"`]
M($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("`@("`@)&1A>2`@
M(#T@1&%T95]#86QC.CID871E3F]W*"<E9"<I.PH@("`@("`@('T*"B`@("`@
M("`@)&]U='!U="`]("<G.PH*("`@("`@("!F;W(@*"1S=')P;W,@/2`P.R`D
M<W1R<&]S(#P@<W1R;&5N*"1F;W)M870I.R`D<W1R<&]S*RLI('L*("`@("`@
M("`@("`@)&-H87(@/2!S=6)S='(H)&9O<FUA="P@)'-T<G!O<RP@,2D["B`@
M("`@("`@("`@(&EF("@D8VAA<B`]/2`G)2<I('L*("`@("`@("`@("`@("`@
M("1N97AT8VAA<B`]('-U8G-T<B@D9F]R;6%T+"`D<W1R<&]S("L@,2P@,2D[
M"B`@("`@("`@("`@("`@("!S=VET8V@H)&YE>'1C:&%R*2!["B`@("`@("`@
M("`@("`@("`@("`@8V%S92`G82<Z"B`@("`@("`@("`@("`@("`@("`@("`@
M("1O=71P=70@+CT@1&%T95]#86QC.CIG9717965K9&%Y06)B<FYA;64H)&1A
M>2P@)&UO;G1H+"`D>65A<BD["B`@("`@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)T$G.@H@("`@("`@("`@
M("`@("`@("`@("`@("`D;W5T<'5T("X]($1A=&5?0V%L8SHZ9V5T5V5E:V1A
M>49U;&QN86UE*"1D87DL("1M;VYT:"P@)'EE87(I.PH@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E("=B
M)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!$871E7T-A
M;&,Z.F=E=$UO;G1H06)B<FYA;64H)&UO;G1H*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`G0B<Z
M"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@1&%T95]#86QC
M.CIG971-;VYT:$9U;&QN86UE*"1M;VYT:"D["B`@("`@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)V0G.@H@
M("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN=&8H)R4P
M,F0G+"`D9&%Y*3L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@("`@("`@("`@8V%S92`G92<Z"B`@("`@("`@("`@("`@("`@
M("`@("`@("1O=71P=70@+CT@)&1A>3L*("`@("`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`G12<Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@1&%T95]#86QC.CID871E
M5&]$87ES*"1D87DL("1M;VYT:"P@)'EE87(I.PH@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E("=J)SH*
M("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!$871E7T-A;&,Z
M.FIU;&EA;D1A=&4H)&1A>2P@)&UO;G1H+"`D>65A<BD["B`@("`@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@
M)VTG.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN
M=&8H)R4P,F0G+"`D;6]N=&@I.PH@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E("=N)SH*("`@("`@("`@
M("`@("`@("`@("`@("`@)&]U='!U="`N/2`B7&XB.PH@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E("=T
M)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`B7'0B.PH@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M("`@("!C87-E("=W)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U
M="`N/2!$871E7T-A;&,Z.F1A>4]F5V5E:R@D9&%Y+"`D;6]N=&@L("1Y96%R
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("`@("`@8V%S92`G52<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1O
M=71P=70@+CT@1&%T95]#86QC.CIW965K3V9996%R*"1D87DL("1M;VYT:"P@
M)'EE87(I.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@("`@("!C87-E("=Y)SH*("`@("`@("`@("`@("`@("`@("`@
M("`@)&]U='!U="`N/2!S=6)S='(H)'EE87(L(#(L(#(I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E
M("=9)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D>65A
M<CL*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("`@("`@8V%S92`G)2<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1O
M=71P=70@+CT@)R4G.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@
M("`@("`@("`D;W5T<'5T("X]("1C:&%R+B1N97AT8VAA<CL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1S=')P;W,K*SL*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1O=71P=70@+CT@)&-H87([
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1O=71P
M=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4=7)N<R!A('1W;R!D:6=I="!Y
M96%R(&EN=&\@82!F;W5R(&1I9VET('EE87(*("`@("`J"B`@("`@*B!&<F]M
M("<U,2!T;R`G.3D@:7,@:6X@=&AE(#$Y,#`G<RP@;W1H97)W:7-E(&ET)W,@
M:6X@=&AE(#(P,#`G<RX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("`@("1Y
M96%R("`@('1H92`R(&1I9VET('EE87(*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@=&AE(#0@9&EG:70@>65A<@H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&1E9F%U;'1#96YT=7)Y*"1Y96%R*0H@("`@>PH@("`@("`@(&EF("AS=')L
M96XH)'EE87(I(#T](#$I('L*("`@("`@("`@("`@)'EE87(@/2`G,"<@+B`D
M>65A<CL*("`@("`@("!]"B`@("`@("`@:68@*"1Y96%R(#X@-3`I('L*("`@
M("`@("`@("`@<F5T=7)N("<Q.2<@+B`D>65A<CL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@)S(P)R`N("1Y96%R.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G1S(&$@9&%T92!T;R!N=6UB
M97(@;V8@9&%Y<R!S:6YC92!A(&1I<W1A;G0@=6YS<&5C:69I960@97!O8V@*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT("`@("1D87D@("`@('1H92!D87D@
M;V8@=&AE(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1M;VYT:"`@('1H
M92!M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A
M<BX@(%5S92!T:&4@8V]M<&QE=&4@>65A<B!I;G-T96%D(&]F('1H90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@86)B<F5V:6%T960@=F5R<VEO
M;BX@($4N9RX@=7-E(#(P,#4L(&YO="`P-2X*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@($1O(&YO="!A9&0@;&5A9&EN9R`P)W,@9F]R('EE87)S
M('!R:6]R('1O(#$P,#`N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R
M("!T:&4@;G5M8F5R(&]F(&1A>7,@<VEN8V4@=&AE($1A=&5?0V%L8R!E<&]C
M:`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&1A=&54;T1A>7,H)&1A>2P@)&UO;G1H
M+"`D>65A<BD*("`@('L*("`@("`@("`D8V5N='5R>2`]("AI;G0I<W5B<W1R
M*"1Y96%R+"`P+"`R*3L*("`@("`@("`D>65A<B`]("AI;G0I<W5B<W1R*"1Y
M96%R+"`R+"`R*3L*("`@("`@("!I9B`H)&UO;G1H(#X@,BD@>PH@("`@("`@
M("`@("`D;6]N=&@@+3T@,SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D;6]N=&@@*ST@.3L*("`@("`@("`@("`@:68@*"1Y96%R*2!["B`@("`@
M("`@("`@("`@("`D>65A<BTM.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)'EE87(@/2`Y.3L*("`@("`@("`@("`@("`@("1C96YT
M=7)Y("TM.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@*&9L;V]R*"@Q-#8P.3<@*B`D8V5N='5R>2D@+R`T("D@*PH@("`@("`@
M("`@("`@("`@9FQO;W(H*#$T-C$@*B`D>65A<BD@+R`T("D@*PH@("`@("`@
M("`@("`@("`@9FQO;W(H*#$U,R`J("1M;VYT:"`K(#(I("\@-2`I("L*("`@
M("`@("`@("`@("`@("1D87D@*R`Q-S(Q,3$Y*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($-O;G9E<G1S(&YU;6)E<B!O9B!D87ES('1O(&$@9&ES=&%N="!U
M;G-P96-I9FEE9"!E<&]C:`H@("`@("H*("`@("`J($!P87)A;2!I;G0@("`@
M)&1A>7,@("`@=&AE(&YU;6)E<B!O9B!D87ES('-I;F-E('1H92!$871E7T-A
M;&,@97!O8V@*("`@("`J($!P87)A;2!S=')I;F<@)&9O<FUA="`@=&AE('-T
M<FEN9R!I;F1I8V%T:6YG(&AO=R!T;R!F;W)M870@=&AE(&]U='!U=`H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@9&%T92!I;B!T:&4@9&5S
M:7)E9"!F;W)M870*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!D87ES5&]$871E*"1D
M87ES+"`D9F]R;6%T(#T@1$%415]#04Q#7T9/4DU!5"D*("`@('L*("`@("`@
M("`D9&%Y<R`@("T](#$W,C$Q,3D["B`@("`@("`@)&-E;G1U<GD@/2!F;&]O
M<B@H-"`J("1D87ES("T@,2D@+R`Q-#8P.3<I.PH@("`@("`@("1D87ES("`@
M(#T@9FQO;W(H-"`J("1D87ES("T@,2`M(#$T-C`Y-R`J("1C96YT=7)Y*3L*
M("`@("`@("`D9&%Y("`@("`](&9L;V]R*"1D87ES("\@-"D["@H@("`@("`@
M("1Y96%R("`@(#T@9FQO;W(H*#0@*B`D9&%Y("L@(#,I("\@,30V,2D["B`@
M("`@("`@)&1A>2`@("`@/2!F;&]O<B@T("H@)&1A>2`K("`S("T@,30V,2`J
M("1Y96%R*3L*("`@("`@("`D9&%Y("`@("`](&9L;V]R*"@D9&%Y("L@(#0I
M("\@-"D["@H@("`@("`@("1M;VYT:"`@(#T@9FQO;W(H*#4@*B`D9&%Y("T@
M,RD@+R`Q-3,I.PH@("`@("`@("1D87D@("`@(#T@9FQO;W(H-2`J("1D87D@
M+2`S("T@,34S("H@)&UO;G1H*3L*("`@("`@("`D9&%Y("`@("`](&9L;V]R
M*"@D9&%Y("L@(#4I("\@(#4I.PH*("`@("`@("!I9B`H)&UO;G1H(#P@,3`I
M('L*("`@("`@("`@("`@)&UO;G1H("L],SL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D;6]N=&@@+3TY.PH@("`@("`@("`@("!I9B`H)'EE87(K
M*R`]/2`Y.2D@>PH@("`@("`@("`@("`@("`@)'EE87(@/2`P.PH@("`@("`@
M("`@("`@("`@)&-E;G1U<GDK*SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@)&-E;G1U<GD@/2!S<')I;G1F*"<E,#)D)RP@)&-E;G1U<GDI
M.PH@("`@("`@("1Y96%R("`@(#T@<W!R:6YT9B@G)3`R9"<L("1Y96%R*3L*
M("`@("`@("!R971U<FX@1&%T95]#86QC.CID871E1F]R;6%T*"1D87DL("1M
M;VYT:"P@)&-E;G1U<GD@+B`D>65A<BP@)&9O<FUA="D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#;VYV97)T<R!F<F]M($=R96=O<FEA;B!996%R+4UO;G1H
M+41A>2!T;R!)4T\@665A<BU7965K3G5M8F5R+5=E96M$87D*("`@("`J"B`@
M("`@*B!5<V5S($E33R`X-C`Q(&1E9FEN:71I;VYS+B`@06QG;W)I=&AM(&)Y
M(%)I8VL@36-#87)T>2P@,3DY.2!A=`H@("`@("H@:'1T<#HO+W!E<G-O;F%L
M+F5C=2YE9'4O;6-C87)T>7(O25-/=V1!3$<N='AT("X*("`@("`J(%1R86YS
M8W)I8F5D('1O(%!(4"!B>2!*97-U<R!-+B!#87-T86=N971T;RX*("`@("`J
M"B`@("`@*B!`<&%R86T@:6YT("`@("1D87D@("`@('1H92!D87D@;V8@=&AE
M(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1M;VYT:"`@('1H92!M;VYT
M:`H@("`@("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<BX@(%5S
M92!T:&4@8V]M<&QE=&4@>65A<B!I;G-T96%D(&]F('1H90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@86)B<F5V:6%T960@=F5R<VEO;BX@($4N
M9RX@=7-E(#(P,#4L(&YO="`P-2X*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@($1O(&YO="!A9&0@;&5A9&EN9R`P)W,@9F]R('EE87)S('!R:6]R
M('1O(#$P,#`N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!D
M871E(&EN($E33R!996%R+5=E96M.=6UB97(M5V5E:T1A>2!F;W)M870*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!G<F5G;W)I86Y4;TE33R@D9&%Y+"`D;6]N=&@L
M("1Y96%R*2!["B`@("`@("`@)&UN=&@@/2!A<G)A>2`H,"P@,S$L(#4Y+"`Y
M,"P@,3(P+"`Q-3$L(#$X,2P@,C$R+"`R-#,L(#(W,RP@,S`T+"`S,S0I.PH@
M("`@("`@("1Y7VES;&5A<"`]($1A=&5?0V%L8SHZ:7-,96%P665A<B@D>65A
M<BD["B`@("`@("`@)'E?,5]I<VQE87`@/2!$871E7T-A;&,Z.FES3&5A<%EE
M87(H)'EE87(@+2`Q*3L*("`@("`@("`D9&%Y7V]F7WEE87)?;G5M8F5R(#T@
M)&1A>2`K("1M;G1H6R1M;VYT:"`M(#%=.PH@("`@("`@(&EF("@D>5]I<VQE
M87`@)B8@)&UO;G1H(#X@,BD@>PH@("`@("`@("`@("`D9&%Y7V]F7WEE87)?
M;G5M8F5R*RL["B`@("`@("`@?0H@("`@("`@("\O(&9I;F0@2F%N(#$@=V5E
M:V1A>2`H;6]N9&%Y(#T@,2P@<W5N9&%Y(#T@-RD*("`@("`@("`D>7D@/2`H
M)'EE87(@+2`Q*2`E(#$P,#L*("`@("`@("`D8R`]("@D>65A<B`M(#$I("T@
M)'EY.PH@("`@("`@("1G(#T@)'EY("L@:6YT=F%L*"1Y>2`O(#0I.PH@("`@
M("`@("1J86XQ7W=E96MD87D@/2`Q("L@:6YT=F%L*"@H*"@D8R`O(#$P,"D@
M)2`T*2`J(#4I("L@)&<I("4@-RD["B`@("`@("`@+R\@=V5E:V1A>2!F;W(@
M>65A<BUM;VYT:"UD87D*("`@("`@("`D:"`]("1D87E?;V9?>65A<E]N=6UB
M97(@*R`H)&IA;C%?=V5E:V1A>2`M(#$I.PH@("`@("`@("1W965K9&%Y(#T@
M,2`K(&EN='9A;"@H)&@@+2`Q*2`E(#<I.PH@("`@("`@("\O(&9I;F0@:68@
M62!-($0@9F%L;',@:6X@665A<DYU;6)E<B!9+3$L(%=E96M.=6UB97(@-3(@
M;W(*("`@("`@("!I9B`H)&1A>5]O9E]Y96%R7VYU;6)E<B`\/2`H."`M("1J
M86XQ7W=E96MD87DI("8F("1J86XQ7W=E96MD87D@/B`T*7L*("`@("`@("`@
M("`@)'EE87)N=6UB97(@/2`D>65A<B`M(#$["B`@("`@("`@("`@(&EF("@D
M:F%N,5]W965K9&%Y(#T](#4@?'P@*"1J86XQ7W=E96MD87D@/3T@-B`F)B`D
M>5\Q7VES;&5A<"DI('L*("`@("`@("`@("`@("`@("1W965K;G5M8F5R(#T@
M-3,["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=V5E
M:VYU;6)E<B`](#4R.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'EE87)N=6UB97(@/2`D>65A<CL*("`@("`@("!]"B`@
M("`@("`@+R\@9FEN9"!I9B!9($T@1"!F86QL<R!I;B!996%R3G5M8F5R(%DK
M,2P@5V5E:TYU;6)E<B`Q"B`@("`@("`@:68@*"1Y96%R;G5M8F5R(#T]("1Y
M96%R*2!["B`@("`@("`@("`@(&EF("@D>5]I<VQE87`I('L*("`@("`@("`@
M("`@("`@("1I(#T@,S8V.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)&D@/2`S-C4["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*"@D:2`M("1D87E?;V9?>65A<E]N=6UB97(I(#P@*#0@+2`D=V5E:V1A
M>2DI('L*("`@("`@("`@("`@("`@("1Y96%R;G5M8F5R*RL["B`@("`@("`@
M("`@("`@("`D=V5E:VYU;6)E<B`](#$["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@+R\@9FEN9"!I9B!9($T@1"!F86QL<R!I;B!996%R3G5M
M8F5R(%DL(%=E96M.=6UB97(@,2!T:')O=6=H(#4S"B`@("`@("`@:68@*"1Y
M96%R;G5M8F5R(#T]("1Y96%R*2!["B`@("`@("`@("`@("1J(#T@)&1A>5]O
M9E]Y96%R7VYU;6)E<B`K("@W("T@)'=E96MD87DI("L@*"1J86XQ7W=E96MD
M87D@+2`Q*3L*("`@("`@("`@("`@)'=E96MN=6UB97(@/2!I;G1V86PH)&H@
M+R`W*3L*("`@("`@("`@("`@:68@*"1J86XQ7W=E96MD87D@/B`T*2!["B`@
M("`@("`@("`@("`@("`D=V5E:VYU;6)E<BTM.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@("\O('!U="!I="!A;&P@=&]G971H97(*("`@("`@
M("!I9B`H)'=E96MN=6UB97(@/"`Q,"D@>PH@("`@("`@("`@("`D=V5E:VYU
M;6)E<B`]("<P)RXD=V5E:VYU;6)E<CL*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1Y96%R;G5M8F5R("X@)RTG("X@)'=E96MN=6UB97(@+B`G+2<@+B`D
M=V5E:V1A>3L*("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@:G5L
M:6%N(&1A=&4@;V8@=&AE(&=I=F5N('-E87-O;@H@("`@("H*("`@("`J($%D
M87!T960@9G)O;2!P<F5V:6]U<R!W;W)K(&EN($IA=F$@8GD@2F%M97,@36%R
M:R!(86UI;'1O;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S96%S
M;VX@('1H92!S96%S;VX@=&\@9V5T('1H92!D871E(&9O<CH@5D523D%,15%5
M24Y/6"P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(%-534U%4E-/
M3%-424-%+"!!551534Y!3$5154E.3U@L"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("!O<B!724Y415)33TQ35$E#10H@("`@("H@0'!A<F%M('-T
M<FEN9R`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I9VET(&9O<FUA="X@
M($UU<W0@8F4@8F5T=V5E;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@+3$P,#!"0R!A;F0@,S`P,$%$+@H@("`@("H*("`@("`J($!R971U<FX@
M9FQO870@('1H92!J=6QI86X@9&%T92!T:&4@<V5A<V]N('-T87)T<R!O;@H@
M("`@("H*("`@("`J($!A=71H;W(@2F%M97,@36%R:R!(86UI;'1O;B`\;6AA
M;6EL=&]N0'%W97-T+FYE=#X*("`@("`J($!A=71H;W(@4F]B97)T($)U=&QE
M<B`\<F]B0&UA>'=E;&QC<F5E:RYO<F<^"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!D871E4V5A
M<V]N*"1S96%S;VXL("1Y96%R(#T@,"D@>PH@("`@("`@(&EF("@D>65A<B`]
M/2`G)RD@>PH@("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T94YO
M=R@G)5DG*3L*("`@("`@("!]"B`@("`@("`@:68@*"@D>65A<B`^/2`M,3`P
M,"D@)B8@*"1Y96%R(#P](#$P,#`I*2!["B`@("`@("`@("`@("1Y(#T@)'EE
M87(@+R`Q,#`P+C`["B`@("`@("`@("`@('-W:71C:"`H)'-E87-O;BD@>PH@
M("`@("`@("`@("`@("`@8V%S92`G5D523D%,15%524Y/6"<Z"B`@("`@("`@
M("`@("`@("`@("`@)&IU;&EA;F1A=&4@/2`H*"@H*"@H+3`N,#`P-S$@*B`D
M>2D@+2`P+C`P,3$Q*2`J("1Y*2`K(#`N,#8Q,S0I("H@)'DI("L@,S8U,C0R
M+C$S-S0I("H@)'DI("L@,3<R,3$S.2XR.3$X.3L*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@)U-534U%4E-/3%-4
M24-%)SH*("`@("`@("`@("`@("`@("`@("`D:G5L:6%N9&%T92`]("@H*"@H
M*"@P+C`P,#(U("H@)'DI("L@,"XP,#DP-RD@*B`D>2D@+2`P+C`U,S(S*2`J
M("1Y*2`K(#,V-3(T,2XW,C4V,BD@*B`D>2D@*R`Q-S(Q,C,S+C(U-#`Q.PH@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S
M92`G055454U.04Q%455)3D]8)SH*("`@("`@("`@("`@("`@("`@("`D:G5L
M:6%N9&%T92`]("@H*"@H*"@P+C`P,#<T("H@)'DI("T@,"XP,#(Y-RD@*B`D
M>2D@+2`P+C$Q-C<W*2`J("1Y*2`K(#,V-3(T,BXT.34U."D@*B`D>2D@*R`Q
M-S(Q,S(U+C<P-#4U.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@8V%S92`G5TE.5$524T],4U1)0T4G.@H@("`@("`@("`@
M("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@("`@("`D:G5L:6%N9&%T
M92`]("@H*"@H*"@M,"XP,#`P-B`J("1Y*2`M(#`N,#`Y,S,I("H@)'DI("T@
M,"XP,#<V.2D@*B`D>2D@*R`S-C4R-#(N.#@R-3<I("H@)'DI("L@,3<R,30Q
M-"XS.3DX-SL*("`@("`@("`@("`@?0H@("`@("`@('T@96QS96EF("@H)'EE
M87(@/B`Q,#`P*2`F)B`H)'EE87(@/#T@,S`P,"DI('L*("`@("`@("`@("`@
M)'D@/2`H)'EE87(@+2`R,#`P*2`O(#$P,#`["B`@("`@("`@("`@('-W:71C
M:"`H)'-E87-O;BD@>PH@("`@("`@("`@("`@("`@8V%S92`G5D523D%,15%5
M24Y/6"<Z"B`@("`@("`@("`@("`@("`@("`@)&IU;&EA;F1A=&4@/2`H*"@H
M*"@H+3`N,#`P-3<@*B`D>2D@+2`P+C`P-#$Q*2`J("1Y*2`K(#`N,#4Q-CDI
M("H@)'DI("L@,S8U,C0R+C,W-#`T*2`J("1Y*2`K(#(T-3$V,C,N.#`Y.#0[
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C
M87-E("=354U-15)33TQ35$E#12<Z"B`@("`@("`@("`@("`@("`@("`@)&IU
M;&EA;F1A=&4@/2`H*"@H*"@H+3`N,#`P,R`J("1Y*2`K(#`N,#`X.#@I("H@
M)'DI("L@,"XP,#,R-2D@*B`D>2D@*R`S-C4R-#$N-C(V,#,I("H@)'DI("L@
M,C0U,3<Q-BXU-C<V-SL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@(&-A<V4@)T%55%5-3D%,15%524Y/6"<Z"B`@("`@("`@
M("`@("`@("`@("`@)&IU;&EA;F1A=&4@/2`H*"@H*"@H,"XP,#`W."`J("1Y
M*2`K(#`N,#`S,S<I("H@)'DI("T@,"XQ,34W-2D@*B`D>2D@*R`S-C4R-#(N
M,#$W-C<I("H@)'DI("L@,C0U,3@Q,"XR,3<Q-3L*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@)U=)3E1%4E-/3%-4
M24-%)SH*("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@
M("`@("`@)&IU;&EA;F1A=&4@/2`H*"@H*"@H,"XP,#`S,B`J("1Y*2`M(#`N
M,#`X,C,I("H@)'DI("T@,"XP-C(R,RD@*B`D>2D@*R`S-C4R-#(N-S0P-#DI
M("H@)'DI("L@,C0U,3DP,"XP-3DU,CL*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!R971U<FX@)&IU;&EA;F1A=&4["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!C=7)R96YT(&QO8V%L(&1A=&4*("`@("`J
M"B`@("`@*B!.3U1%.B!4:&ES(&9U;F-T:6]N(')E=')I979E<R!T:&4@;&]C
M86P@9&%T92!U<VEN9R!S=')F=&EM92@I+`H@("`@("H@=VAI8V@@;6%Y(&]R
M(&UA>2!N;W0@8F4@,S(M8FET('-A9F4@;VX@>6]U<B!S>7-T96TN"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T("!T:&4@<W1R:6YG(&EN
M9&EC871I;F<@:&]W('1O(&9O<FUA="!T:&4@;W5T<'5T"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@('1H92!C=7)R96YT(&1A=&4@:6X@=&AE('-P
M96-I9FEE9"!F;W)M870*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!D871E3F]W*"1F
M;W)M870@/2!$051%7T-!3$-?1D]234%4*0H@("`@>PH@("`@("`@(')E='5R
M;B!S=')F=&EM92@D9F]R;6%T+"!T:6UE*"DI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@8W5R<F5N="!L;V-A;"!Y96%R(&EN(&9O<FUA
M="!#0UE9"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!C=7)R
M96YT('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!G971996%R*"D*("`@('L*("`@("`@("!R971U<FX@1&%T95]#86QC
M.CID871E3F]W*"<E62<I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@8W5R<F5N="!L;V-A;"!M;VYT:"!I;B!F;W)M870@34T*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&-U<G)E;G0@;6]N=&@@:6X@
M='=O(&1I9VET(&9O<FUA=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$UO;G1H
M*"D*("`@('L*("`@("`@("!R971U<FX@1&%T95]#86QC.CID871E3F]W*"<E
M;2<I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8W5R<F5N
M="!L;V-A;"!D87D@:6X@9F]R;6%T($1$"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@('1H92!C=7)R96YT(&1A>2!O9B!T:&4@;6]N=&@@:6X@='=O
M(&1I9VET(&9O<FUA=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1A>2@I"B`@
M("!["B`@("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ9&%T94YO=R@G)60G*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@;G5M8F5R(&]F(&1A>7,@
M<VEN8V4@,S$@1&5C96UB97(@;V8@>65A<B!B969O<F4@9VEV96X@9&%T90H@
M("`@("H*("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE(&1A>2!O
M9B!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!D87D*("`@
M("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H+"!D969A=6QT
M(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@
M)'EE87(@("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870L(&1E9F%U
M;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G0@('1H92!J=6QI86X@9&%T92!F;W(@=&AE(&1A=&4*("`@("`J"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!J=6QI86Y$871E*"1D87D@/2`P+"`D;6]N=&@@/2`P+"`D
M>65A<B`](#`I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@
M("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*
M("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@
M("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID871E3F]W*"<E;2<I.PH@("`@
M("`@('T*("`@("`@("!I9B`H96UP='DH)&1A>2DI('L*("`@("`@("`@("`@
M)&1A>2`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)60G*3L*("`@("`@("!]"B`@
M("`@("`@)&1A>7,@/2!A<G)A>2@P+"`S,2P@-3DL(#DP+"`Q,C`L(#$U,2P@
M,3@Q+"`R,3(L(#(T,RP@,C<S+"`S,#0L(#,S-"D["B`@("`@("`@)&IU;&EA
M;B`]("@D9&%Y<ULD;6]N=&@@+2`Q72`K("1D87DI.PH@("`@("`@(&EF("@D
M;6]N=&@@/B`R("8F($1A=&5?0V%L8SHZ:7-,96%P665A<B@D>65A<BDI('L*
M("`@("`@("`@("`@)&IU;&EA;BLK.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@)&IU;&EA;CL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M(&9U;&P@=V5E:V1A>2!N86UE(&9O<B!T:&4@9VEV96X@9&%T90H@("`@("H*
M("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE(&1A>2!O9B!T:&4@
M;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!D87D*("`@("`J($!P
M87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U
M<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)'EE87(@
M("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870L(&1E9F%U;'0@:7,@
M8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@('1H92!F=6QL(&YA;64@;V8@=&AE(&1A>2!O9B!T:&4@=V5E:PH@("`@
M("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%=E96MD87E&=6QL;F%M92@D9&%Y(#T@,"P@
M)&UO;G1H(#T@,"P@)'EE87(@/2`P*0H@("`@>PH@("`@("`@(&EF("AE;7!T
M>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE87(@/2!$871E7T-A;&,Z.F1A
M=&5.;W<H)R59)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D;6]N
M=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L8SHZ9&%T94YO
M=R@G)6TG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1D87DI*2![
M"B`@("`@("`@("`@("1D87D@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5D)RD[
M"B`@("`@("`@?0H@("`@("`@("1W965K9&%Y7VYA;65S(#T@1&%T95]#86QC
M.CIG9717965K1&%Y<R@I.PH@("`@("`@("1W965K9&%Y(#T@1&%T95]#86QC
M.CID87E/9E=E96LH)&1A>2P@)&UO;G1H+"`D>65A<BD["B`@("`@("`@<F5T
M=7)N("1W965K9&%Y7VYA;65S6R1W965K9&%Y73L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE(&%B8G)E=FEA=&5D('=E96MD87D@;F%M92!F
M;W(@=&AE(&=I=F5N(&1A=&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("`@
M("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U
M<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@:6YT("`@("1M;VYT:"`@
M('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&UO;G1H"B`@
M("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R(&EN(&9O=7(@
M9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@>65A<@H@
M("`@("H@0'!A<F%M(&EN="`@("`D;&5N9W1H("!T:&4@;&5N9W1H(&]F(&%B
M8G)E=FEA=&EO;@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@
M86)B<F5V:6%T960@;F%M92!O9B!T:&4@9&%Y(&]F('1H92!W965K"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J
M($!S964@1&%T95]#86QC.CIG9717965K9&%Y1G5L;&YA;64H*0H@("`@("HO
M"B`@("!F=6YC=&EO;B!G9717965K9&%Y06)B<FYA;64H)&1A>2`](#`L("1M
M;VYT:"`](#`L("1Y96%R(#T@,"P@)&QE;F=T:"`](#,I"B`@("!["B`@("`@
M("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]($1A
M=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]"B`@("`@("`@:68@
M*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@1&%T95]#
M86QC.CID871E3F]W*"<E;2<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP
M='DH)&1A>2DI('L*("`@("`@("`@("`@)&1A>2`]($1A=&5?0V%L8SHZ9&%T
M94YO=R@G)60G*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('-U8G-T<BA$
M871E7T-A;&,Z.F=E=%=E96MD87E&=6QL;F%M92@D9&%Y+"`D;6]N=&@L("1Y
M96%R*2P*("`@("`@("`@("`@("`@("`@("`@(#`L("1L96YG=&@I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@9G5L;"!M;VYT:"!N86UE
M(&9O<B!T:&4@9VEV96X@;6]N=&@*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M("`@("1M;VYT:"`@('1H92!M;VYT:`H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!T:&4@9G5L;"!N86UE(&]F('1H92!M;VYT:`H@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$UO;G1H1G5L;&YA;64H)&UO;G1H*0H@("`@>PH@("`@
M("`@("1M;VYT:"`]("AI;G0I)&UO;G1H.PH@("`@("`@(&EF("AE;7!T>2@D
M;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]("AI;G0I1&%T95]#86QC
M.CID871E3F]W*"<E;2<I.PH@("`@("`@('T*("`@("`@("`D;6]N=&A?;F%M
M97,@/2!$871E7T-A;&,Z.F=E=$UO;G1H3F%M97,H*3L*("`@("`@("!R971U
M<FX@)&UO;G1H7VYA;65S6R1M;VYT:%T["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!A8F)R979I871E9"!M;VYT:"!N86UE(&9O<B!T:&4@
M9VEV96X@;6]N=&@*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("`@("1M;VYT
M:"`@('1H92!M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@("`D;&5N9W1H("!T
M:&4@;&5N9W1H(&]F(&%B8G)E=FEA=&EO;@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!T:&4@86)B<F5V:6%T960@;F%M92!O9B!T:&4@;6]N=&@*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@
M("`@("H@0'-E92!$871E7T-A;&,Z.F=E=$UO;G1H1G5L;&YA;64*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T36]N=&A!8F)R;F%M92@D;6]N=&@L("1L96YG
M=&@@/2`S*0H@("`@>PH@("`@("`@("1M;VYT:"`]("AI;G0I)&UO;G1H.PH@
M("`@("`@(&EF("AE;7!T>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT
M:"`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N('-U8G-T<BA$871E7T-A;&,Z.F=E=$UO;G1H1G5L;&YA;64H
M)&UO;G1H*2P@,"P@)&QE;F=T:"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!N=6UE<FEC(&UO;G1H(&9R;VT@=&AE(&UO;G1H(&YA;64@
M;W(@86X@86)R979I871I;VX*("`@("`J"B`@("`@*B!";W1H($%U9W5S="!A
M;F0@075G('=O=6QD(')E='5R;B`X+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&UO;G1H("!T:&4@;F%M92!O9B!T:&4@;6]N=&@@=&\@97AA;6EN
M92X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@0V%S92!I;G-E;G-I
M=&EV92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@('1H92!M;VYT
M:"=S(&YU;6)E<@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$UO;G1H1G)O;49U
M;&Q.86UE*"1M;VYT:"D*("`@('L*("`@("`@("`D;6]N=&@@/2!S=')T;VQO
M=V5R*"1M;VYT:"D["B`@("`@("`@)&UO;G1H<R`]($1A=&5?0V%L8SHZ9V5T
M36]N=&A.86UE<R@I.PH@("`@("`@('=H:6QE*&QI<W0H)&ED+"`D;F%M92D@
M/2!E86-H*"1M;VYT:',I*2!["B`@("`@("`@("`@(&EF("AE<F5G*"1M;VYT
M:"P@<W1R=&]L;W=E<B@D;F%M92DI*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)&ED.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`P.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!A<G)A>2!O
M9B!M;VYT:"!N86UE<PH@("`@("H*("`@("`J(%5S960@=&\@=&%K92!A9'9A
M;G1A9V4@;V8@=&AE('-E=&QO8V%L92!F=6YC=&EO;B!T;R!R971U<FX*("`@
M("`J(&QA;F=U86=E('-P96-I9FEC(&UO;G1H(&YA;65S+@H@("`@("H*("`@
M("`J(%1/1$\Z(&-A8VAE('9A;'5E<R!T;R!S;VUE(&=L;V)A;"!A<G)A>2!T
M;R!A=F]I9"!P<F5F;W)M86-E"B`@("`@*B!H:71S('=H96X@8V%L;&5D(&UO
M<F4@=&AA;B!O;F-E+@H@("`@("H*("`@("`J($!R971U<FYS(&%R<F%Y("!A
M;B!A<G)A>2!O9B!M;VYT:"!N86UE<PH@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$UO;G1H3F%M97,H*0H@("`@>PH@("`@("`@(&9O<B`H)&D@/2`Q.R`D:2`\
M(#$S.R`D:2LK*2!["B`@("`@("`@("`@("1M;VYT:'-;)&E=(#T@<W1R9G1I
M;64H)R5")RP@;6MT:6UE*#`L(#`L(#`L("1I+"`Q+"`R,#`Q*2D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D;6]N=&AS.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!A;B!A<G)A>2!O9B!W965K(&1A>7,*("`@("`J"B`@
M("`@*B!5<V5D('1O('1A:V4@861V86YT86=E(&]F('1H92!S971L;V-A;&4@
M9G5N8W1I;VX@=&\*("`@("`J(')E='5R;B!L86YG=6%G92!S<&5C:69I8R!W
M965K(&1A>7,N"B`@("`@*@H@("`@("H@5$]$3SH@8V%C:&4@=F%L=65S('1O
M('-O;64@9VQO8F%L(&%R<F%Y('1O(&%V;VED('!R969O<FUA8V4*("`@("`J
M(&AI=',@=VAE;B!C86QL960@;6]R92!T:&%N(&]N8V4N"B`@("`@*@H@("`@
M("H@0')E='5R;G,@87)R87D@(&%N(&%R<F%Y(&]F('=E96L@9&%Y(&YA;65S
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5V5E:T1A>7,H*0H@("`@>PH@("`@
M("`@(&9O<B`H)&D@/2`P.R`D:2`\(#<[("1I*RLI('L*("`@("`@("`@("`@
M)'=E96MD87ES6R1I72`]('-T<F9T:6UE*"<E02<L(&UK=&EM92@P+"`P+"`P
M+"`Q+"`D:2P@,C`P,2DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'=E
M96MD87ES.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!D87D@;V8@
M=V5E:R!F;W(@9VEV96X@9&%T92`H,"`](%-U;F1A>2D*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT("`@("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO;G1H
M+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@
M:6YT("`@("1M;VYT:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT
M(&QO8V%L(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H
M92!Y96%R(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E
M;G0@;&]C86P@>65A<@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@
M;G5M8F5R(&]F('1H92!D87D@:6X@=&AE('=E96L*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!D87E/9E=E96LH)&1A>2`](#`L("1M;VYT:"`](#`L("1Y96%R(#T@
M,"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@
M("`@("1Y96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@("`@
M('T*("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D
M;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@?0H@
M("`@("`@(&EF("AE;7!T>2@D9&%Y*2D@>PH@("`@("`@("`@("`D9&%Y(#T@
M1&%T95]#86QC.CID871E3F]W*"<E9"<I.PH@("`@("`@('T*("`@("`@("!I
M9B`H)&UO;G1H(#X@,BD@>PH@("`@("`@("`@("`D;6]N=&@@+3T@,CL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;6]N=&@@*ST@,3`["B`@("`@
M("`@("`@("1Y96%R+2T["B`@("`@("`@?0H*("`@("`@("`D9&%Y(#T@*&9L
M;V]R*"@Q,R`J("1M;VYT:"`M(#$I("\@-2D@*PH@("`@("`@("`@("`@("`@
M)&1A>2`K("@D>65A<B`E(#$P,"D@*PH@("`@("`@("`@("`@("`@9FQO;W(H
M*"1Y96%R("4@,3`P*2`O(#0I("L*("`@("`@("`@("`@("`@(&9L;V]R*"@D
M>65A<B`O(#$P,"D@+R`T*2`M(#(@*@H@("`@("`@("`@("`@("`@9FQO;W(H
M)'EE87(@+R`Q,#`I("L@-S<I.PH*("`@("`@("`D=V5E:V1A>5]N=6UB97(@
M/2`D9&%Y("T@-R`J(&9L;V]R*"1D87D@+R`W*3L*("`@("`@("!R971U<FX@
M)'=E96MD87E?;G5M8F5R.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!W965K(&]F('1H92!Y96%R+"!F:7)S="!3=6YD87D@:7,@9FER<W0@9&%Y
M(&]F(&9I<G-T('=E96L*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("`@("1D
M87D@("`@('1H92!D87D@;V8@=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U<G)E
M;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@:6YT("`@("1M;VYT:"`@('1H
M92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&UO;G1H"B`@("`@
M*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R(&EN(&9O=7(@9&EG
M:70@9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@>65A<@H@("`@
M("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F('1H92!W965K
M(&EN('1H92!Y96%R"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@=V5E:T]F665A<B@D
M9&%Y(#T@,"P@)&UO;G1H(#T@,"P@)'EE87(@/2`P*0H@("`@>PH@("`@("`@
M(&EF("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE87(@/2!$871E
M7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE
M;7!T>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L
M8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y
M*"1D87DI*2!["B`@("`@("`@("`@("1D87D@/2!$871E7T-A;&,Z.F1A=&5.
M;W<H)R5D)RD["B`@("`@("`@?0H@("`@("`@("1I<V\@("`@/2!$871E7T-A
M;&,Z.F=R96=O<FEA;E1O25-/*"1D87DL("1M;VYT:"P@)'EE87(I.PH@("`@
M("`@("1P87)T<R`@/2!E>'!L;V1E*"<M)RP@)&ES;RD["B`@("`@("`@)'=E
M96M?;G5M8F5R(#T@:6YT=F%L*"1P87)T<ULQ72D["B`@("`@("`@<F5T=7)N
M("1W965K7VYU;6)E<CL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M<75A<G1E<B!O9B!T:&4@>65A<B!F;W(@9VEV96X@9&%T90H@("`@("H*("`@
M("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE(&1A>2!O9B!T:&4@;6]N
M=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!D87D*("`@("`J($!P87)A
M;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U<G)E
M;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)'EE87(@("`@
M=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870L(&1E9F%U;'0@:7,@8W5R
M<F5N="!L;V-A;"!Y96%R"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H
M92!N=6UB97(@;V8@=&AE('%U87)T97(@:6X@=&AE('EE87(*("`@("`J"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!Q=6%R=&5R3V9996%R*"1D87D@/2`P+"`D;6]N=&@@/2`P
M+"`D>65A<B`](#`I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@
M>PH@("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG
M*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@
M("`@("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID871E3F]W*"<E;2<I.PH@
M("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&1A>2DI('L*("`@("`@("`@
M("`@)&1A>2`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)60G*3L*("`@("`@("!]
M"B`@("`@("`@)'EE87)?<75A<G1E<B`](&EN='9A;"@H)&UO;G1H("T@,2D@
M+R`S("L@,2D["B`@("`@("`@<F5T=7)N("1Y96%R7W%U87)T97(["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!&:6YD('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T
M:&4@9VEV96X@;6]N=&@*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("`@("1M
M;VYT:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&UO
M;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R(&EN
M(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@
M>65A<@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F
M(&1A>7,@=&AE(&UO;G1H(&AA<PH@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&1A>7-)
M;DUO;G1H*"1M;VYT:"`](#`L("1Y96%R(#T@,"D*("`@('L*("`@("`@("!I
M9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T95]#
M86QC.CID871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP
M='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A;&,Z
M.F1A=&5.;W<H)R5M)RD["B`@("`@("`@?0H*("`@("`@("!I9B`H)'EE87(@
M/3T@,34X,B`F)B`D;6]N=&@@/3T@,3`I('L*("`@("`@("`@("`@<F5T=7)N
M(#(Q.R`@+R\@3V-T;V)E<B`Q-3@R(&]N;'D@:&%D(#%S="TT=&@@86YD(#$U
M=&@M,S%S=`H@("`@("`@('T*"B`@("`@("`@:68@*"1M;VYT:"`]/2`R*2![
M"B`@("`@("`@("`@(&EF("A$871E7T-A;&,Z.FES3&5A<%EE87(H)'EE87(I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@,CD["B`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N(#(X.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E:68@*"1M;VYT:"`]/2`T(&]R("1M;VYT:"`]
M/2`V(&]R("1M;VYT:"`]/2`Y(&]R("1M;VYT:"`]/2`Q,2D@>PH@("`@("`@
M("`@("!R971U<FX@,S`["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N(#,Q.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE(&YU;6)E<B!O9B!R;W=S(&]N(&$@8V%L96YD87(@;6]N=&@*
M("`@("`J"B`@("`@*B!5<V5F=6P@9F]R(&1E=&5R;6EN:6YG('1H92!N=6UB
M97(@;V8@<F]W<R!W:&5N(&1I<W!L87EI;F<@82!T>7!I8V%L"B`@("`@*B!M
M;VYT:"!C86QE;F1A<BX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("`@("1M
M;VYT:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&UO
M;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R(&EN
M(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@
M>65A<@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F
M('=E96MS('1H92!M;VYT:"!H87,*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!W965K
M<TEN36]N=&@H)&UO;G1H(#T@,"P@)'EE87(@/2`P*0H@("`@>PH@("`@("`@
M(&EF("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE87(@/2!$871E
M7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE
M;7!T>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L
M8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("!]"B`@("`@("`@)$9$3TT@/2!$
M871E7T-A;&,Z.F9I<G-T3V9-;VYT:%=E96MD87DH)&UO;G1H+"`D>65A<BD[
M"B`@("`@("`@:68@*$1!5$5?0T%,0U]"14=)3E]7145+1$%9/3TQ("8F("1&
M1$]-/3TP*2!["B`@("`@("`@("`@("1F:7)S=%]W965K7V1A>7,@/2`W("T@
M)$9$3TT@*R!$051%7T-!3$-?0D5'24Y?5T5%2T1!63L*("`@("`@("`@("`@
M)'=E96MS(#T@,3L*("`@("`@("!](&5L<V5I9B`H1$%415]#04Q#7T)%1TE.
M7U=%14M$05D]/3`@)B8@)$9$3TT@/3T@-BD@>PH@("`@("`@("`@("`D9FER
M<W1?=V5E:U]D87ES(#T@-R`M("1&1$]-("L@1$%415]#04Q#7T)%1TE.7U=%
M14M$05D["B`@("`@("`@("`@("1W965K<R`](#$["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&9I<G-T7W=E96M?9&%Y<R`]($1!5$5?0T%,0U]"
M14=)3E]7145+1$%9("T@)$9$3TT["B`@("`@("`@("`@("1W965K<R`](#`[
M"B`@("`@("`@?0H@("`@("`@("1F:7)S=%]W965K7V1A>7,@)3T@-SL*("`@
M("`@("!R971U<FX@8V5I;"@H1&%T95]#86QC.CID87ES26Y-;VYT:"@D;6]N
M=&@L("1Y96%R*0H@("`@("`@("`@("`@("`@("`@("`M("1F:7)S=%]W965K
M7V1A>7,I("\@-RD@*R`D=V5E:W,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FX@86X@87)R87D@=VET:"!D87ES(&EN('=E96L*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT("`@("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO;G1H
M+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@
M:6YT("`@("1M;VYT:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT
M(&QO8V%L(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H
M92!Y96%R(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E
M;G0@;&]C86P@>65A<@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T("!T
M:&4@<W1R:6YG(&EN9&EC871I;F<@:&]W('1O(&9O<FUA="!T:&4@;W5T<'5T
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`D=V5E:ULD=V5E:V1A>5T*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@
M("`@("HO"B`@("!F=6YC=&EO;B!G971#86QE;F1A<E=E96LH)&1A>2`](#`L
M("1M;VYT:"`](#`L("1Y96%R(#T@,"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9F]R;6%T(#T@1$%415]#04Q#7T9/4DU!5"D*("`@('L*("`@
M("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@
M1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@("!I
M9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E
M7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE
M;7!T>2@D9&%Y*2D@>PH@("`@("`@("`@("`D9&%Y(#T@1&%T95]#86QC.CID
M871E3F]W*"<E9"<I.PH@("`@("`@('T*"B`@("`@("`@)'=E96M?87)R87D@
M/2!A<G)A>2@I.PH*("`@("`@("`O+R!D871E(&9O<B!T:&4@8V]L=6UN(&]F
M('=E96L*"B`@("`@("`@)&-U<G)?9&%Y(#T@1&%T95]#86QC.CIB96=I;D]F
M5V5E:R@D9&%Y+"`D;6]N=&@L("1Y96%R+"<E12<I.PH*("`@("`@("!F;W(@
M*"1C;W5N=&5R(#T@,#L@)&-O=6YT97(@/#T@-CL@)&-O=6YT97(K*RD@>PH@
M("`@("`@("`@("`D=V5E:U]A<G)A>5LD8V]U;G1E<ET@/2!$871E7T-A;&,Z
M.F1A>7-4;T1A=&4H)&-U<G)?9&%Y+"`D9F]R;6%T*3L*("`@("`@("`@("`@
M)&-U<G)?9&%Y*RL["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=V5E:U]A
M<G)A>3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!A('-E="!O9B!A
M<G)A>7,@=&\@8V]N<W1R=6-T(&$@8V%L96YD87(@;6]N=&@@9F]R('1H92!G
M:79E;B!D871E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@
M("!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@
M("`@("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R
M(&1I9VET(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*
M("`@("`J($!P87)A;2!S=')I;F<@)&9O<FUA="`@=&AE('-T<FEN9R!I;F1I
M8V%T:6YG(&AO=R!T;R!F;W)M870@=&AE(&]U='!U=`H@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@)&UO;G1H6R1R;W==6R1C;VQ="B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T0V%L96YD87)-;VYT:"@D;6]N=&@@/2`P+"`D>65A<B`]
M(#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)M870@/2!$
M051%7T-!3$-?1D]234%4*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D>65A
M<BDI('L*("`@("`@("`@("`@)'EE87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H
M)R59)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D;6]N=&@I*2![
M"B`@("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG
M*3L*("`@("`@("!]"@H@("`@("`@("1M;VYT:%]A<G)A>2`](&%R<F%Y*"D[
M"@H@("`@("`@("\O(&1A=&4@9F]R('1H92!F:7)S="!R;W<L(&9I<G-T(&-O
M;'5M;B!O9B!C86QE;F1A<B!M;VYT:`H@("`@("`@(&EF("A$051%7T-!3$-?
M0D5'24Y?5T5%2T1!62`]/2`Q*2!["B`@("`@("`@("`@(&EF("A$871E7T-A
M;&,Z.F9I<G-T3V9-;VYT:%=E96MD87DH)&UO;G1H+"`D>65A<BD@/3T@,"D@
M>PH@("`@("`@("`@("`@("`@)&-U<G)?9&%Y(#T@1&%T95]#86QC.CID871E
M5&]$87ES*"<P,2<L("1M;VYT:"P@)'EE87(I("T@-CL*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1C=7)R7V1A>2`]($1A=&5?0V%L
M8SHZ9&%T951O1&%Y<R@G,#$G+"`D;6]N=&@L("1Y96%R*0H@("`@("`@("`@
M("`@("`@("`@("T@1&%T95]#86QC.CIF:7)S=$]F36]N=&A7965K9&%Y*"1M
M;VYT:"P@)'EE87(I("L@,3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1C=7)R7V1A>2`]("A$871E7T-A;&,Z.F1A=&54
M;T1A>7,H)S`Q)RP@)&UO;G1H+"`D>65A<BD*("`@("`@("`@("`@("`@("T@
M1&%T95]#86QC.CIF:7)S=$]F36]N=&A7965K9&%Y*"1M;VYT:"P@)'EE87(I
M*3L*("`@("`@("!]"@H@("`@("`@("\O(&YU;6)E<B!O9B!D87ES(&EN('1H
M:7,@;6]N=&@*("`@("`@("`D9&%Y<TEN36]N=&@@/2!$871E7T-A;&,Z.F1A
M>7-);DUO;G1H*"1M;VYT:"P@)'EE87(I.PH*("`@("`@("`D=V5E:W-);DUO
M;G1H(#T@1&%T95]#86QC.CIW965K<TEN36]N=&@H)&UO;G1H+"`D>65A<BD[
M"B`@("`@("`@9F]R("@D<F]W7V-O=6YT97(@/2`P.R`D<F]W7V-O=6YT97(@
M/"`D=V5E:W-);DUO;G1H.R`D<F]W7V-O=6YT97(K*RD@>PH@("`@("`@("`@
M("!F;W(@*"1C;VQU;6Y?8V]U;G1E<B`](#`[("1C;VQU;6Y?8V]U;G1E<B`\
M/2`V.R`D8V]L=6UN7V-O=6YT97(K*RD@>PH@("`@("`@("`@("`@("`@)&UO
M;G1H7V%R<F%Y6R1R;W=?8V]U;G1E<EU;)&-O;'5M;E]C;W5N=&5R72`]"B`@
M("`@("`@("`@("`@("`@("`@("`@($1A=&5?0V%L8SHZ9&%Y<U1O1&%T92@D
M8W5R<E]D87D@+"`D9F]R;6%T*3L*("`@("`@("`@("`@("`@("1C=7)R7V1A
M>2LK.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&UO;G1H7V%R<F%Y.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@
M<V5T(&]F(&%R<F%Y<R!T;R!C;VYS=')U8W0@82!C86QE;F1A<B!Y96%R(&9O
M<B!T:&4@9VEV96X@9&%T90H@("`@("H*("`@("`J($!P87)A;2!I;G0@("`@
M)'EE87(@("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870L(&1E9F%U
M;'0@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`<&%R86T@<W1R:6YG("1F
M;W)M870@('1H92!S=')I;F<@:6YD:6-A=&EN9R!H;W<@=&\@9F]R;6%T('1H
M92!O=71P=70*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("1Y96%R6R1M
M;VYT:%U;)')O=UU;)&-O;%T*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971#86QE
M;F1A<EEE87(H)'EE87(@/2`P+"`D9F]R;6%T(#T@1$%415]#04Q#7T9/4DU!
M5"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@
M("`@("1Y96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@("`@
M('T*"B`@("`@("`@)'EE87)?87)R87D@/2!A<G)A>2@I.PH*("`@("`@("!F
M;W(@*"1C=7)R7VUO;G1H(#T@,#L@)&-U<G)?;6]N=&@@/#T@,3$[("1C=7)R
M7VUO;G1H*RLI('L*("`@("`@("`@("`@)'EE87)?87)R87E;)&-U<G)?;6]N
M=&A=(#T*("`@("`@("`@("`@("`@("`@("!$871E7T-A;&,Z.F=E=$-A;&5N
M9&%R36]N=&@H)&-U<G)?;6]N=&@@*R`Q+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D>65A<BP@)&9O<FUA="D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'EE87)?87)R87D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&1A=&4@;V8@9&%Y(&)E9F]R92!G
M:79E;B!D871E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y("`@
M("!T:&4@9&%Y(&]F('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO
M8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@;6]N
M=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@0'!A
M<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I9VET(&9O
M<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J($!P
M87)A;2!S=')I;F<@)&9O<FUA="`@=&AE('-T<FEN9R!I;F1I8V%T:6YG(&AO
M=R!T;R!F;W)M870@=&AE(&]U='!U=`H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!T:&4@9&%T92!I;B!T:&4@9&5S:7)E9"!F;W)M870*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!P<F5V1&%Y*"1D87D@/2`P+"`D;6]N=&@@/2`P+"`D
M>65A<B`](#`L"B`@("`@("`@("`@("`@("`@("`@("1F;W)M870@/2!$051%
M7T-!3$-?1D]234%4*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D>65A<BDI
M('L*("`@("`@("`@("`@)'EE87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59
M)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D;6]N=&@I*2!["B`@
M("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*
M("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1D87DI*2!["B`@("`@("`@
M("`@("1D87D@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5D)RD["B`@("`@("`@
M?0H@("`@("`@("1D87ES(#T@1&%T95]#86QC.CID871E5&]$87ES*"1D87DL
M("1M;VYT:"P@)'EE87(I.PH@("`@("`@(')E='5R;B!$871E7T-A;&,Z.F1A
M>7-4;T1A=&4H)&1A>7,@+2`Q+"`D9F]R;6%T*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@9&%T92!O9B!D87D@869T97(@9VEV96X@9&%T90H@
M("`@("H*("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE(&1A>2!O
M9B!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!D87D*("`@
M("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H+"!D969A=6QT
M(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@
M)'EE87(@("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870L(&1E9F%U
M;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1F;W)M870@('1H92!S=')I;F<@:6YD:6-A=&EN9R!H;W<@=&\@9F]R;6%T
M('1H92!O=71P=70*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE
M(&1A=&4@:6X@=&AE(&1E<VER960@9F]R;6%T"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@;F5X=$1A>2@D9&%Y(#T@,"P@)&UO;G1H(#T@,"P@)'EE87(@/2`P+`H@
M("`@("`@("`@("`@("`@("`@("`D9F]R;6%T(#T@1$%415]#04Q#7T9/4DU!
M5"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@
M("`@("1Y96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@("`@
M('T*("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D
M;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@?0H@
M("`@("`@(&EF("AE;7!T>2@D9&%Y*2D@>PH@("`@("`@("`@("`D9&%Y(#T@
M1&%T95]#86QC.CID871E3F]W*"<E9"<I.PH@("`@("`@('T*("`@("`@("`D
M9&%Y<R`]($1A=&5?0V%L8SHZ9&%T951O1&%Y<R@D9&%Y+"`D;6]N=&@L("1Y
M96%R*3L*("`@("`@("!R971U<FX@1&%T95]#86QC.CID87ES5&]$871E*"1D
M87ES("L@,2P@)&9O<FUA="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&1A=&4@;V8@=&AE('!R979I;W5S('=E96MD87DL('-K:7!P:6YG(&9R
M;VT@36]N9&%Y('1O($9R:61A>0H@("`@("H*("`@("`J($!P87)A;2!I;G0@
M("`@)&1A>2`@("`@=&AE(&1A>2!O9B!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@
M8W5R<F5N="!L;V-A;"!D87D*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H
M("`@=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*
M("`@("`J($!P87)A;2!I;G0@("`@)'EE87(@("`@=&AE('EE87(@:6X@9F]U
M<B!D:6=I="!F;W)M870L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1F;W)M870@('1H92!S=')I;F<@:6YD
M:6-A=&EN9R!H;W<@=&\@9F]R;6%T('1H92!O=71P=70*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@=&AE(&1A=&4@:6X@=&AE(&1E<VER960@9F]R
M;6%T"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<')E=E=E96MD87DH)&1A>2`](#`L
M("1M;VYT:"`](#`L("1Y96%R(#T@,"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("1F;W)M870@/2!$051%7T-!3$-?1D]234%4*0H@("`@>PH@("`@("`@
M(&EF("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE87(@/2!$871E
M7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE
M;7!T>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L
M8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y
M*"1D87DI*2!["B`@("`@("`@("`@("1D87D@/2!$871E7T-A;&,Z.F1A=&5.
M;W<H)R5D)RD["B`@("`@("`@?0H@("`@("`@("1D87ES(#T@1&%T95]#86QC
M.CID871E5&]$87ES*"1D87DL("1M;VYT:"P@)'EE87(I.PH@("`@("`@(&EF
M("A$871E7T-A;&,Z.F1A>4]F5V5E:R@D9&%Y+"`D;6]N=&@L("1Y96%R*2`]
M/2`Q*2!["B`@("`@("`@("`@("1D87ES("T](#,["B`@("`@("`@?2!E;'-E
M:68@*$1A=&5?0V%L8SHZ9&%Y3V97965K*"1D87DL("1M;VYT:"P@)'EE87(I
M(#T](#`I('L*("`@("`@("`@("`@)&1A>7,@+3T@,CL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D9&%Y<R`M/2`Q.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@1&%T95]#86QC.CID87ES5&]$871E*"1D87ES+"`D9F]R;6%T
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@9&%T92!O9B!T:&4@
M;F5X="!W965K9&%Y(&]F(&=I=F5N(&1A=&4L('-K:7!P:6YG(&9R;VT*("`@
M("`J($9R:61A>2!T;R!-;VYD87D*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M("`@("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO;G1H+"!D969A=6QT(&ES
M(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@:6YT("`@("1M;VYT
M:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&UO;G1H
M"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R(&EN(&9O
M=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@>65A
M<@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T("!T:&4@<W1R:6YG(&EN
M9&EC871I;F<@:&]W('1O(&9O<FUA="!T:&4@;W5T<'5T"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@('1H92!D871E(&EN('1H92!D97-I<F5D(&9O
M<FUA=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A
M=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE>'17965K9&%Y*"1D87D@/2`P
M+"`D;6]N=&@@/2`P+"`D>65A<B`](#`L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`D9F]R;6%T(#T@1$%415]#04Q#7T9/4DU!5"D*("`@('L*("`@("`@
M("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T
M95]#86QC.CID871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@("!I9B`H
M96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A
M;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T
M>2@D9&%Y*2D@>PH@("`@("`@("`@("`D9&%Y(#T@1&%T95]#86QC.CID871E
M3F]W*"<E9"<I.PH@("`@("`@('T*("`@("`@("`D9&%Y<R`]($1A=&5?0V%L
M8SHZ9&%T951O1&%Y<R@D9&%Y+"`D;6]N=&@L("1Y96%R*3L*("`@("`@("!I
M9B`H1&%T95]#86QC.CID87E/9E=E96LH)&1A>2P@)&UO;G1H+"`D>65A<BD@
M/3T@-2D@>PH@("`@("`@("`@("`D9&%Y<R`K/2`S.PH@("`@("`@('T@96QS
M96EF("A$871E7T-A;&,Z.F1A>4]F5V5E:R@D9&%Y+"`D;6]N=&@L("1Y96%R
M*2`]/2`V*2!["B`@("`@("`@("`@("1D87ES("L](#(["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&1A>7,@*ST@,3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N($1A=&5?0V%L8SHZ9&%Y<U1O1&%T92@D9&%Y<RP@)&9O<FUA
M="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&1A=&4@;V8@=&AE
M('!R979I;W5S('-P96-I9FEC(&1A>2!O9B!T:&4@=V5E:PH@("`@("H@9G)O
M;2!T:&4@9VEV96X@9&%T90H@("`@("H*("`@("`J($!P87)A;2!I;G0@9&%Y
M(&]F('=E96LL(#`]4W5N9&%Y"B`@("`@*B!`<&%R86T@:6YT("`@("1D87D@
M("`@('1H92!D87D@;V8@=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U<G)E;G0@
M;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@:6YT("`@("1M;VYT:"`@('1H92!M
M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&UO;G1H"B`@("`@*B!`
M<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R(&EN(&9O=7(@9&EG:70@
M9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@>65A<@H@("`@("H@
M0'!A<F%M(&)O;VP@("`D;VY/<D)E9F]R92`@:68@=')U92!A;F0@9&%Y<R!A
M<F4@<V%M92P@<F5T=7)N<R!C=7)R96YT(&1A>0H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9F]R;6%T("!T:&4@<W1R:6YG(&EN9&EC871I;F<@:&]W('1O(&9O
M<FUA="!T:&4@;W5T<'5T"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M('1H92!D871E(&EN('1H92!D97-I<F5D(&9O<FUA=`H@("`@("H*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U
M;F-T:6]N('!R979$87E/9E=E96LH)&1O=RP@)&1A>2`](#`L("1M;VYT:"`]
M(#`L("1Y96%R(#T@,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O
M<FUA="`]($1!5$5?0T%,0U]&3U)-050L("1O;D]R0F5F;W)E(#T@9F%L<V4I
M"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@
M("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]
M"B`@("`@("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@("`@)&UO
M;G1H(#T@1&%T95]#86QC.CID871E3F]W*"<E;2<I.PH@("`@("`@('T*("`@
M("`@("!I9B`H96UP='DH)&1A>2DI('L*("`@("`@("`@("`@)&1A>2`]($1A
M=&5?0V%L8SHZ9&%T94YO=R@G)60G*3L*("`@("`@("!]"B`@("`@("`@)&1A
M>7,@/2!$871E7T-A;&,Z.F1A=&54;T1A>7,H)&1A>2P@)&UO;G1H+"`D>65A
M<BD["B`@("`@("`@)&-U<G)?=V5E:V1A>2`]($1A=&5?0V%L8SHZ9&%Y3V97
M965K*"1D87DL("1M;VYT:"P@)'EE87(I.PH@("`@("`@(&EF("@D8W5R<E]W
M965K9&%Y(#T]("1D;W<I('L*("`@("`@("`@("`@:68@*"$D;VY/<D)E9F]R
M92D@>PH@("`@("`@("`@("`@("`@)&1A>7,@+3T@-SL*("`@("`@("`@("`@
M?0H@("`@("`@('T@96QS96EF("@D8W5R<E]W965K9&%Y(#P@)&1O=RD@>PH@
M("`@("`@("`@("`D9&%Y<R`M/2`W("T@*"1D;W<@+2`D8W5R<E]W965K9&%Y
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9&%Y<R`M/2`D8W5R
M<E]W965K9&%Y("T@)&1O=SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1A
M=&5?0V%L8SHZ9&%Y<U1O1&%T92@D9&%Y<RP@)&9O<FUA="D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&1A=&4@;V8@=&AE(&YE>'0@<W!E8VEF
M:6,@9&%Y(&]F('1H92!W965K"B`@("`@*B!F<F]M('1H92!G:79E;B!D871E
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D9&]W("`@("!T:&4@9&%Y
M(&]F('1H92!W965K("@P(#T@4W5N9&%Y*0H@("`@("H@0'!A<F%M(&EN="`@
M("`D9&%Y("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:"P@9&5F875L="!I<R!C
M=7)R96YT(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@
M("!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@
M("`@("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R
M(&1I9VET(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*
M("`@("`J($!P87)A;2!B;V]L("`@)&]N3W)!9G1E<B`@:68@=')U92!A;F0@
M9&%Y<R!A<F4@<V%M92P@<F5T=7)N<R!C=7)R96YT(&1A>0H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9F]R;6%T("!T:&4@<W1R:6YG(&EN9&EC871I;F<@:&]W
M('1O(&9O<FUA="!T:&4@;W5T<'5T"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@('1H92!D871E(&EN('1H92!D97-I<F5D(&9O<FUA=`H@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&YE>'1$87E/9E=E96LH)&1O=RP@)&1A>2`](#`L("1M
M;VYT:"`](#`L("1Y96%R(#T@,"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&9O<FUA="`]($1!5$5?0T%,0U]&3U)-050L("1O;D]R069T97(@/2!F
M86QS92D*("`@('L*("`@("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@
M("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@
M("`@('T*("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@
M("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@
M?0H@("`@("`@(&EF("AE;7!T>2@D9&%Y*2D@>PH@("`@("`@("`@("`D9&%Y
M(#T@1&%T95]#86QC.CID871E3F]W*"<E9"<I.PH@("`@("`@('T*"B`@("`@
M("`@)&1A>7,@/2!$871E7T-A;&,Z.F1A=&54;T1A>7,H)&1A>2P@)&UO;G1H
M+"`D>65A<BD["B`@("`@("`@)&-U<G)?=V5E:V1A>2`]($1A=&5?0V%L8SHZ
M9&%Y3V97965K*"1D87DL("1M;VYT:"P@)'EE87(I.PH*("`@("`@("!I9B`H
M)&-U<G)?=V5E:V1A>2`]/2`D9&]W*2!["B`@("`@("`@("`@(&EF("@A)&]N
M3W)!9G1E<BD@>PH@("`@("`@("`@("`@("`@)&1A>7,@*ST@-SL*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS96EF("@D8W5R<E]W965K9&%Y(#X@)&1O
M=RD@>PH@("`@("`@("`@("`D9&%Y<R`K/2`W("T@*"1C=7)R7W=E96MD87D@
M+2`D9&]W*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9&%Y<R`K
M/2`D9&]W("T@)&-U<G)?=V5E:V1A>3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!$871E7T-A;&,Z.F1A>7-4;T1A=&4H)&1A>7,L("1F;W)M870I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!D871E(&]F('1H92!P<F5V
M:6]U<R!S<&5C:69I8R!D87D@;V8@=&AE('=E96L*("`@("`J(&]N(&]R(&)E
M9F]R92!T:&4@9VEV96X@9&%T90H@("`@("H*("`@("`J($!P87)A;2!I;G0@
M("`@)&1O=R`@("`@=&AE(&1A>2!O9B!T:&4@=V5E:R`H,"`](%-U;F1A>2D*
M("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE(&1A>2!O9B!T:&4@
M;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!D87D*("`@("`J($!P
M87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U
M<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)'EE87(@
M("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870L(&1E9F%U;'0@:7,@
M8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`<&%R86T@<W1R:6YG("1F;W)M
M870@('1H92!S=')I;F<@:6YD:6-A=&EN9R!H;W<@=&\@9F]R;6%T('1H92!O
M=71P=70*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&1A=&4@
M:6X@=&AE(&1E<VER960@9F]R;6%T"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<')E
M=D1A>4]F5V5E:T]N3W)"969O<F4H)&1O=RP@)&1A>2`](#`L("1M;VYT:"`]
M(#`L("1Y96%R(#T@,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1F;W)M870@/2!$051%7T-!3$-?1D]234%4*0H@("`@>PH@("`@
M("`@(')E='5R;B!$871E7T-A;&,Z.G!R979$87E/9E=E96LH)&1O=RP@)&1A
M>2P@)&UO;G1H+"`D>65A<BP@)&9O<FUA="P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('1R=64I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!D871E(&]F('1H92!N97AT('-P96-I9FEC(&1A>2!O
M9B!T:&4@=V5E:PH@("`@("H@;VX@;W(@869T97(@=&AE(&=I=F5N(&1A=&4*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT("`@("1D;W<@("`@('1H92!D87D@
M;V8@=&AE('=E96L@*#`@/2!3=6YD87DI"B`@("`@*B!`<&%R86T@:6YT("`@
M("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U
M<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@:6YT("`@("1M;VYT:"`@
M('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&UO;G1H"B`@
M("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R(&EN(&9O=7(@
M9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@>65A<@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T("!T:&4@<W1R:6YG(&EN9&EC
M871I;F<@:&]W('1O(&9O<FUA="!T:&4@;W5T<'5T"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@('1H92!D871E(&EN('1H92!D97-I<F5D(&9O<FUA
M=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE>'1$87E/9E=E96M/;D]R069T97(H
M)&1O=RP@)&1A>2`](#`L("1M;VYT:"`](#`L("1Y96%R(#T@,"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<FUA="`]($1!5$5?
M0T%,0U]&3U)-050I"B`@("!["B`@("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ
M;F5X=$1A>4]F5V5E:R@D9&]W+"`D9&%Y+"`D;6]N=&@L("1Y96%R+"`D9F]R
M;6%T+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=')U92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD('1H92!M;VYT:"!D
M87D@;V8@=&AE(&)E9VEN;FEN9R!O9B!W965K(&9O<B!G:79E;B!D871E+`H@
M("`@("H@=7-I;F<@1$%415]#04Q#7T)%1TE.7U=%14M$05D*("`@("`J"B`@
M("`@*B!#86X@<F5T=7)N('=E96MD87D@;V8@<')E=B!M;VYT:"X*("`@("`J
M"B`@("`@*B!`<&%R86T@:6YT("`@("1D87D@("`@('1H92!D87D@;V8@=&AE
M(&UO;G1H+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`
M<&%R86T@:6YT("`@("1M;VYT:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C
M=7)R96YT(&QO8V%L(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R
M("`@('1H92!Y96%R(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES
M(&-U<G)E;G0@;&]C86P@>65A<@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R
M;6%T("!T:&4@<W1R:6YG(&EN9&EC871I;F<@:&]W('1O(&9O<FUA="!T:&4@
M;W5T<'5T"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!D871E
M(&EN('1H92!D97-I<F5D(&9O<FUA=`H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&)E
M9VEN3V97965K*"1D87D@/2`P+"`D;6]N=&@@/2`P+"`D>65A<B`](#`L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`D9F]R;6%T(#T@1$%415]#04Q#7T9/
M4DU!5"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@
M("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@
M("`@('T*("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@
M("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@
M?0H@("`@("`@(&EF("AE;7!T>2@D9&%Y*2D@>PH@("`@("`@("`@("`D9&%Y
M(#T@1&%T95]#86QC.CID871E3F]W*"<E9"<I.PH@("`@("`@('T*("`@("`@
M("`D=&AI<U]W965K9&%Y(#T@1&%T95]#86QC.CID87E/9E=E96LH)&1A>2P@
M)&UO;G1H+"`D>65A<BD["B`@("`@("`@)&EN=&5R=F%L(#T@*#<@+2!$051%
M7T-!3$-?0D5'24Y?5T5%2T1!62`K("1T:&ES7W=E96MD87DI("4@-SL*("`@
M("`@("!R971U<FX@1&%T95]#86QC.CID87ES5&]$871E*$1A=&5?0V%L8SHZ
M9&%T951O1&%Y<R@D9&%Y+"`D;6]N=&@L("1Y96%R*0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+2`D:6YT97)V86PL("1F;W)M870I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEN9"!T:&4@;6]N=&@@9&%Y(&]F
M('1H92!E;F0@;V8@=V5E:R!F;W(@9VEV96X@9&%T92P*("`@("`J('5S:6YG
M($1!5$5?0T%,0U]"14=)3E]7145+1$%9"B`@("`@*@H@("`@("H@0V%N(')E
M='5R;B!W965K9&%Y(&]F(&9O;&QO=VEN9R!M;VYT:"X*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT("`@("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO;G1H
M+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@
M:6YT("`@("1M;VYT:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT
M(&QO8V%L(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H
M92!Y96%R(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E
M;G0@;&]C86P@>65A<@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T("!T
M:&4@<W1R:6YG(&EN9&EC871I;F<@:&]W('1O(&9O<FUA="!T:&4@;W5T<'5T
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!D871E(&EN('1H
M92!D97-I<F5D(&9O<FUA=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N9$]F5V5E
M:R@D9&%Y(#T@,"P@)&UO;G1H(#T@,"P@)'EE87(@/2`P+`H@("`@("`@("`@
M("`@("`@("`@("`@("1F;W)M870@/2!$051%7T-!3$-?1D]234%4*0H@("`@
M>PH@("`@("`@(&EF("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE
M87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H@("`@
M("`@(&EF("AE;7!T>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]
M($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("!]"B`@("`@("`@
M:68@*&5M<'1Y*"1D87DI*2!["B`@("`@("`@("`@("1D87D@/2!$871E7T-A
M;&,Z.F1A=&5.;W<H)R5D)RD["B`@("`@("`@?0H@("`@("`@("1T:&ES7W=E
M96MD87D@/2!$871E7T-A;&,Z.F1A>4]F5V5E:R@D9&%Y+"`D;6]N=&@L("1Y
M96%R*3L*("`@("`@("`D:6YT97)V86P@/2`H-B`K($1!5$5?0T%,0U]"14=)
M3E]7145+1$%9("T@)'1H:7-?=V5E:V1A>2D@)2`W.PH@("`@("`@(')E='5R
M;B!$871E7T-A;&,Z.F1A>7-4;T1A=&4H1&%T95]#86QC.CID871E5&]$87ES
M*"1D87DL("1M;VYT:"P@)'EE87(I"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`K("1I;G1E<G9A;"P@)&9O<FUA="D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!&:6YD('1H92!M;VYT:"!D87D@;V8@=&AE(&)E9VEN
M;FEN9R!O9B!W965K(&)E9F]R92!G:79E;B!D871E+`H@("`@("H@=7-I;F<@
M1$%415]#04Q#7T)%1TE.7U=%14M$05D*("`@("`J"B`@("`@*B!#86X@<F5T
M=7)N('=E96MD87D@;V8@<')E=B!M;VYT:"X*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT("`@("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO;G1H+"!D969A
M=6QT(&ES(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@:6YT("`@
M("1M;VYT:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L
M(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R
M(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C
M86P@>65A<@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T("!T:&4@<W1R
M:6YG(&EN9&EC871I;F<@:&]W('1O(&9O<FUA="!T:&4@;W5T<'5T"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!D871E(&EN('1H92!D97-I
M<F5D(&9O<FUA=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&)E9VEN3V90<F5V5V5E
M:R@D9&%Y(#T@,"P@)&UO;G1H(#T@,"P@)'EE87(@/2`P+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1F;W)M870@/2!$051%7T-!3$-?1D]234%4
M*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@
M("`@)'EE87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@
M?0H@("`@("`@(&EF("AE;7!T>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M
M;VYT:"`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("!]"B`@
M("`@("`@:68@*&5M<'1Y*"1D87DI*2!["B`@("`@("`@("`@("1D87D@/2!$
M871E7T-A;&,Z.F1A=&5.;W<H)R5D)RD["B`@("`@("`@?0H*("`@("`@("`D
M9&%T92`]($1A=&5?0V%L8SHZ9&%Y<U1O1&%T92A$871E7T-A;&,Z.F1A=&54
M;T1A>7,H)&1A>2TW+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;6]N=&@L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1Y96%R*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G)5DE;25D)RD["@H@("`@("`@("1P<F5V7W=E96M?>65A<B`@
M/2!S=6)S='(H)&1A=&4L(#`L(#0I.PH@("`@("`@("1P<F5V7W=E96M?;6]N
M=&@@/2!S=6)S='(H)&1A=&4L(#0L(#(I.PH@("`@("`@("1P<F5V7W=E96M?
M9&%Y("`@/2!S=6)S='(H)&1A=&4L(#8L(#(I.PH*("`@("`@("!R971U<FX@
M1&%T95]#86QC.CIB96=I;D]F5V5E:R@D<')E=E]W965K7V1A>2P@)'!R979?
M=V5E:U]M;VYT:"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<')E=E]W965K7WEE87(L("1F;W)M870I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1FEN9"!T:&4@;6]N=&@@9&%Y(&]F('1H92!B96=I;FYI;F<@
M;V8@=V5E:R!A9G1E<B!G:79E;B!D871E+`H@("`@("H@=7-I;F<@1$%415]#
M04Q#7T)%1TE.7U=%14M$05D*("`@("`J"B`@("`@*B!#86X@<F5T=7)N('=E
M96MD87D@;V8@<')E=B!M;VYT:"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M("`@("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO;G1H+"!D969A=6QT(&ES
M(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@:6YT("`@("1M;VYT
M:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&UO;G1H
M"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R(&EN(&9O
M=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@>65A
M<@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T("!T:&4@<W1R:6YG(&EN
M9&EC871I;F<@:&]W('1O(&9O<FUA="!T:&4@;W5T<'5T"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@('1H92!D871E(&EN('1H92!D97-I<F5D(&9O
M<FUA=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A
M=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&)E9VEN3V9.97AT5V5E:R@D9&%Y
M(#T@,"P@)&UO;G1H(#T@,"P@)'EE87(@/2`P+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1F;W)M870@/2!$051%7T-!3$-?1D]234%4*0H@("`@
M>PH@("`@("`@(&EF("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE
M87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H@("`@
M("`@(&EF("AE;7!T>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]
M($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("!]"B`@("`@("`@
M:68@*&5M<'1Y*"1D87DI*2!["B`@("`@("`@("`@("1D87D@/2!$871E7T-A
M;&,Z.F1A=&5.;W<H)R5D)RD["B`@("`@("`@?0H*("`@("`@("`D9&%T92`]
M($1A=&5?0V%L8SHZ9&%Y<U1O1&%T92A$871E7T-A;&,Z.F1A=&54;T1A>7,H
M)&1A>2`K(#<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1M;VYT:"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'EE87(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("<E625M)60G*3L*"B`@("`@("`@)&YE>'1?=V5E:U]Y96%R("`]('-U
M8G-T<B@D9&%T92P@,"P@-"D["B`@("`@("`@)&YE>'1?=V5E:U]M;VYT:"`]
M('-U8G-T<B@D9&%T92P@-"P@,BD["B`@("`@("`@)&YE>'1?=V5E:U]D87D@
M("`]('-U8G-T<B@D9&%T92P@-BP@,BD["@H@("`@("`@(')E='5R;B!$871E
M7T-A;&,Z.F)E9VEN3V97965K*"1N97AT7W=E96M?9&%Y+"`D;F5X=%]W965K
M7VUO;G1H+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1N97AT7W=E96M?>65A<BP@)&9O<FUA="D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FX@9&%T92!O9B!F:7)S="!D87D@;V8@;6]N=&@@;V8@9VEV
M96X@9&%T90H@("`@("H*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@
M=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@
M("`J($!P87)A;2!I;G0@("`@)'EE87(@("`@=&AE('EE87(@:6X@9F]U<B!D
M:6=I="!F;W)M870L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1F;W)M870@('1H92!S=')I;F<@:6YD:6-A
M=&EN9R!H;W<@=&\@9F]R;6%T('1H92!O=71P=70*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@=&AE(&1A=&4@:6X@=&AE(&1E<VER960@9F]R;6%T
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*
M("`@("`J($!S964@1&%T95]#86QC.CIB96=I;D]F36]N=&A">5-P86XH*0H@
M("`@("H@0&1E<')E8V%T960@365T:&]D(&1E<')E8V%T960@:6X@4F5L96%S
M92`Q+C4N,`H@("`@("HO"B`@("!F=6YC=&EO;B!B96=I;D]F36]N=&@H)&UO
M;G1H(#T@,"P@)'EE87(@/2`P+"`D9F]R;6%T(#T@1$%415]#04Q#7T9/4DU!
M5"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@
M("`@("1Y96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@("`@
M('T*("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D
M;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!$871E7T-A;&,Z.F1A=&5&;W)M870H)S`Q)RP@)&UO
M;G1H+"`D>65A<BP@)&9O<FUA="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&1A=&4@;V8@=&AE(&9I<G-T(&1A>2!O9B!P<F5V:6]U<R!M;VYT
M:"!O9B!G:79E;B!D871E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D
M9&%Y("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R
M96YT(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T
M:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@
M("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I
M9VET(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@
M("`J($!P87)A;2!S=')I;F<@)&9O<FUA="`@=&AE('-T<FEN9R!I;F1I8V%T
M:6YG(&AO=R!T;R!F;W)M870@=&AE(&]U='!U=`H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!T:&4@9&%T92!I;B!T:&4@9&5S:7)E9"!F;W)M870*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@
M("`@("H@0'-E92!$871E7T-A;&,Z.F)E9VEN3V9-;VYT:$)Y4W!A;B@I"B`@
M("`@*B!`9&5P<F5C871E9"!-971H;V0@9&5P<F5C871E9"!I;B!296QE87-E
M(#$N-2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(&)E9VEN3V90<F5V36]N=&@H
M)&1A>2`](#`L("1M;VYT:"`](#`L("1Y96%R(#T@,"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&9O<FUA="`]($1!5$5?0T%,0U]&3U)-050I
M"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@
M("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]
M"B`@("`@("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@("`@)&UO
M;G1H(#T@1&%T95]#86QC.CID871E3F]W*"<E;2<I.PH@("`@("`@('T*("`@
M("`@("!I9B`H96UP='DH)&1A>2DI('L*("`@("`@("`@("`@)&1A>2`]($1A
M=&5?0V%L8SHZ9&%T94YO=R@G)60G*3L*("`@("`@("!]"B`@("`@("`@:68@
M*"1M;VYT:"`^(#$I('L*("`@("`@("`@("`@)&UO;G1H+2T["B`@("`@("`@
M("`@("1D87D@/2`Q.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1Y
M96%R+2T["B`@("`@("`@("`@("1M;VYT:"`](#$R.PH@("`@("`@("`@("`D
M9&%Y("`@/2`Q.PH@("`@("`@('T*("`@("`@("!R971U<FX@1&%T95]#86QC
M.CID871E1F]R;6%T*"1D87DL("1M;VYT:"P@)'EE87(L("1F;W)M870I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!D871E(&]F('1H92!L87-T
M(&1A>2!O9B!P<F5V:6]U<R!M;VYT:"!F;W(@9VEV96X@9&%T90H@("`@("H*
M("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE(&1A>2!O9B!T:&4@
M;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!D87D*("`@("`J($!P
M87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U
M<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)'EE87(@
M("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870L(&1E9F%U;'0@:7,@
M8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`<&%R86T@<W1R:6YG("1F;W)M
M870@('1H92!S=')I;F<@:6YD:6-A=&EN9R!H;W<@=&\@9F]R;6%T('1H92!O
M=71P=70*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&1A=&4@
M:6X@=&AE(&1E<VER960@9F]R;6%T"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J($!S964@1&%T95]#86QC.CIE
M;F1/9DUO;G1H0GE3<&%N*"D*("`@("`J($!D97!R96-A=&5D($UE=&AO9"!D
M97!R96-A=&5D(&EN(%)E;&5A<V4@,2XU+C`*("`@("`J+PH@("`@9G5N8W1I
M;VX@96YD3V90<F5V36]N=&@H)&1A>2`](#`L("1M;VYT:"`](#`L("1Y96%R
M(#T@,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)M870@/2!$
M051%7T-!3$-?1D]234%4*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D>65A
M<BDI('L*("`@("`@("`@("`@)'EE87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H
M)R59)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D;6]N=&@I*2![
M"B`@("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG
M*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1D87DI*2!["B`@("`@
M("`@("`@("1D87D@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5D)RD["B`@("`@
M("`@?0H@("`@("`@(&EF("@D;6]N=&@@/B`Q*2!["B`@("`@("`@("`@("1M
M;VYT:"TM.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1Y96%R+2T[
M"B`@("`@("`@("`@("1M;VYT:"`](#$R.PH@("`@("`@('T*("`@("`@("`D
M9&%Y(#T@1&%T95]#86QC.CID87ES26Y-;VYT:"@D;6]N=&@L("1Y96%R*3L*
M("`@("`@("!R971U<FX@1&%T95]#86QC.CID871E1F]R;6%T*"1D87DL("1M
M;VYT:"P@)'EE87(L("1F;W)M870I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!D871E(&]F(&)E9VEN(&]F(&YE>'0@;6]N=&@@;V8@9VEV96X@
M9&%T90H@("`@("H*("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE
M(&1A>2!O9B!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!D
M87D*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H+"!D
M969A=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!I
M;G0@("`@)'EE87(@("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870L
M(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1F;W)M870@('1H92!S=')I;F<@:6YD:6-A=&EN9R!H;W<@=&\@
M9F]R;6%T('1H92!O=71P=70*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@=&AE(&1A=&4@:6X@=&AE(&1E<VER960@9F]R;6%T"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J($!S964@
M1&%T95]#86QC.CIB96=I;D]F36]N=&A">5-P86XH*0H@("`@("H@0&1E<')E
M8V%T960@365T:&]D(&1E<')E8V%T960@:6X@4F5L96%S92`Q+C4N,`H@("`@
M("HO"B`@("!F=6YC=&EO;B!B96=I;D]F3F5X=$UO;G1H*"1D87D@/2`P+"`D
M;6]N=&@@/2`P+"`D>65A<B`](#`L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1F;W)M870@/2!$051%7T-!3$-?1D]234%4*0H@("`@>PH@("`@
M("`@(&EF("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE87(@/2!$
M871E7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H@("`@("`@(&EF
M("AE;7!T>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]($1A=&5?
M0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M
M<'1Y*"1D87DI*2!["B`@("`@("`@("`@("1D87D@/2!$871E7T-A;&,Z.F1A
M=&5.;W<H)R5D)RD["B`@("`@("`@?0H@("`@("`@(&EF("@D;6]N=&@@/"`Q
M,BD@>PH@("`@("`@("`@("`D;6]N=&@K*SL*("`@("`@("`@("`@)&1A>2`]
M(#$["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'EE87(K*SL*("`@
M("`@("`@("`@)&UO;G1H(#T@,3L*("`@("`@("`@("`@)&1A>2`](#$["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B!$871E7T-A;&,Z.F1A=&5&;W)M870H
M)&1A>2P@)&UO;G1H+"`D>65A<BP@)&9O<FUA="D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS(&1A=&4@;V8@=&AE(&QA<W0@9&%Y(&]F(&YE>'0@
M;6]N=&@@;V8@9VEV96X@9&%T90H@("`@("H*("`@("`J($!P87)A;2!I;G0@
M("`@)&1A>2`@("`@=&AE(&1A>2!O9B!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@
M8W5R<F5N="!L;V-A;"!D87D*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H
M("`@=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*
M("`@("`J($!P87)A;2!I;G0@("`@)'EE87(@("`@=&AE('EE87(@:6X@9F]U
M<B!D:6=I="!F;W)M870L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1F;W)M870@('1H92!S=')I;F<@:6YD
M:6-A=&EN9R!H;W<@=&\@9F]R;6%T('1H92!O=71P=70*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@=&AE(&1A=&4@:6X@=&AE(&1E<VER960@9F]R
M;6%T"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T
M:6,*("`@("`J($!S964@1&%T95]#86QC.CIE;F1/9DUO;G1H0GE3<&%N*"D*
M("`@("`J($!D97!R96-A=&5D($UE=&AO9"!D97!R96-A=&5D(&EN(%)E;&5A
M<V4@,2XU+C`*("`@("`J+PH@("`@9G5N8W1I;VX@96YD3V9.97AT36]N=&@H
M)&1A>2`](#`L("1M;VYT:"`](#`L("1Y96%R(#T@,"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1F;W)M870@/2!$051%7T-!3$-?1D]234%4*0H@
M("`@>PH@("`@("`@(&EF("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@
M)'EE87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H@
M("`@("`@(&EF("AE;7!T>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT
M:"`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("!]"B`@("`@
M("`@:68@*&5M<'1Y*"1D87DI*2!["B`@("`@("`@("`@("1D87D@/2!$871E
M7T-A;&,Z.F1A=&5.;W<H)R5D)RD["B`@("`@("`@?0H@("`@("`@(&EF("@D
M;6]N=&@@/"`Q,BD@>PH@("`@("`@("`@("`D;6]N=&@K*SL*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D>65A<BLK.PH@("`@("`@("`@("`D;6]N
M=&@@/2`Q.PH@("`@("`@('T*("`@("`@("`D9&%Y(#T@1&%T95]#86QC.CID
M87ES26Y-;VYT:"@D;6]N=&@L("1Y96%R*3L*("`@("`@("!R971U<FX@1&%T
M95]#86QC.CID871E1F]R;6%T*"1D87DL("1M;VYT:"P@)'EE87(L("1F;W)M
M870I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!D871E(&]F('1H
M92!F:7)S="!D87D@;V8@=&AE(&UO;G1H(&EN('1H92!N=6UB97(@;V8@;6]N
M=&AS"B`@("`@*B!F<F]M('1H92!G:79E;B!D871E"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN="`@("`D;6]N=&AS("!T:&4@;G5M8F5R(&]F(&UO;G1H<R!F
M<F]M('1H92!D871E('!R;W9I9&5D+@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@4&]S:71I=F4@;G5M8F5R<R!G;R!I;G1O('1H92!F=71U<F4N
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!.96=A=&EV92!N=6UB
M97)S(&=O(&EN=&\@=&AE('!A<W0N"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`P(&ES('1H92!M;VYT:"!P<F5S96YT960@:6X@)&UO;G1H+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;6]N=&@@("!T:&4@;6]N=&@L(&1E9F%U
M;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@0'!A<F%M('-T<FEN
M9R`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I9VET(&9O<FUA="P@9&5F
M875L="!I<R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&-U
M<G)E;G0@;&]C86P@>65A<@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T
M("!T:&4@<W1R:6YG(&EN9&EC871I;F<@:&]W('1O(&9O<FUA="!T:&4@;W5T
M<'5T"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!D871E(&EN
M('1H92!D97-I<F5D(&9O<FUA=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B!`<VEN8V4@($UE=&AO9"!A=F%I
M;&%B;&4@<VEN8V4@4F5L96%S92`Q+C4N,`H@("`@("HO"B`@("!F=6YC=&EO
M;B!B96=I;D]F36]N=&A">5-P86XH)&UO;G1H<R`](#`L("1M;VYT:"`](#`L
M("1Y96%R(#T@,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9F]R;6%T(#T@1$%415]#04Q#7T9/4DU!5"D*("`@('L*("`@("`@("!I9B`H
M96UP='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T95]#86QC
M.CID871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH
M)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A
M=&5.;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@(&EF("@D;6]N=&AS(#X@
M,"D@>PH@("`@("`@("`@("`O+R!F=71U<F4@;6]N=&@*("`@("`@("`@("`@
M)'1M<%]M;R`]("1M;VYT:"`K("1M;VYT:',["B`@("`@("`@("`@("1M;VYT
M:"`@/2`D=&UP7VUO("4@,3(["B`@("`@("`@("`@(&EF("@D;6]N=&@@/3T@
M,"D@>PH@("`@("`@("`@("`@("`@)&UO;G1H(#T@,3(["B`@("`@("`@("`@
M("`@("`D>65A<B`]("1Y96%R("L@9FQO;W(H*"1T;7!?;6\@+2`Q*2`O(#$R
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1Y96%R
M(#T@)'EE87(@*R!F;&]O<B@D=&UP7VUO("\@,3(I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@<&%S="!O<B!P<F5S
M96YT(&UO;G1H"B`@("`@("`@("`@("1T;7!?;6\@/2`D;6]N=&@@*R`D;6]N
M=&AS.PH@("`@("`@("`@("!I9B`H)'1M<%]M;R`^(#`I('L*("`@("`@("`@
M("`@("`@("\O('-A;64@>65A<@H@("`@("`@("`@("`@("`@)&UO;G1H(#T@
M)'1M<%]M;SL*("`@("`@("`@("`@?2!E;'-E:68@*"1T;7!?;6\@/3T@,"D@
M>PH@("`@("`@("`@("`@("`@+R\@<')I;W(@9&5C"B`@("`@("`@("`@("`@
M("`D;6]N=&@@/2`Q,CL*("`@("`@("`@("`@("`@("1Y96%R+2T["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O+R!S;VUE('1I;64@
M:6X@82!P<FEO<B!Y96%R"B`@("`@("`@("`@("`@("`D;6]N=&@@/2`Q,B`K
M("@D=&UP7VUO("4@,3(I.PH@("`@("`@("`@("`@("`@)'EE87(@(#T@)'EE
M87(@*R!F;&]O<B@D=&UP7VUO("\@,3(I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!$871E7T-A;&,Z.F1A=&5&;W)M870H,2P@
M)&UO;G1H+"`D>65A<BP@)&9O<FUA="D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&1A=&4@;V8@=&AE(&QA<W0@9&%Y(&]F('1H92!M;VYT:"!I
M;B!T:&4@;G5M8F5R(&]F(&UO;G1H<PH@("`@("H@9G)O;2!T:&4@9VEV96X@
M9&%T90H@("`@("H*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H<R`@=&AE
M(&YU;6)E<B!O9B!M;VYT:',@9G)O;2!T:&4@9&%T92!P<F]V:61E9"X*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@(%!O<VET:79E(&YU;6)E<G,@
M9V\@:6YT;R!T:&4@9G5T=7)E+@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@3F5G871I=F4@;G5M8F5R<R!G;R!I;G1O('1H92!P87-T+@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@,"!I<R!T:&4@;6]N=&@@<')E
M<V5N=&5D(&EN("1M;VYT:"X*("`@("`J($!P87)A;2!S=')I;F<@)&UO;G1H
M("`@=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*
M("`@("`J($!P87)A;2!S=')I;F<@)'EE87(@("`@=&AE('EE87(@:6X@9F]U
M<B!D:6=I="!F;W)M870L(&1E9F%U;'0@:7,@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("!C=7)R96YT(&QO8V%L('EE87(*("`@("`J($!P
M87)A;2!S=')I;F<@)&9O<FUA="`@=&AE('-T<FEN9R!I;F1I8V%T:6YG(&AO
M=R!T;R!F;W)M870@=&AE(&]U='!U=`H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!T:&4@9&%T92!I;B!T:&4@9&5S:7)E9"!F;W)M870*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("H@
M0'-I;F-E("!-971H;V0@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XU+C`*
M("`@("`J+PH@("`@9G5N8W1I;VX@96YD3V9-;VYT:$)Y4W!A;B@D;6]N=&AS
M(#T@,"P@)&UO;G1H(#T@,"P@)'EE87(@/2`P+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9F]R;6%T(#T@1$%415]#04Q#7T9/4DU!5"D*("`@
M('L*("`@("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y
M96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@("`@('T*("`@
M("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@
M/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@
M(&EF("@D;6]N=&AS(#X@,"D@>PH@("`@("`@("`@("`O+R!F=71U<F4@;6]N
M=&@*("`@("`@("`@("`@)'1M<%]M;R`]("1M;VYT:"`K("1M;VYT:',["B`@
M("`@("`@("`@("1M;VYT:"`@/2`D=&UP7VUO("4@,3(["B`@("`@("`@("`@
M(&EF("@D;6]N=&@@/3T@,"D@>PH@("`@("`@("`@("`@("`@)&UO;G1H(#T@
M,3(["B`@("`@("`@("`@("`@("`D>65A<B`]("1Y96%R("L@9FQO;W(H*"1T
M;7!?;6\@+2`Q*2`O(#$R*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1Y96%R(#T@)'EE87(@*R!F;&]O<B@D=&UP7VUO("\@,3(I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M+R\@<&%S="!O<B!P<F5S96YT(&UO;G1H"B`@("`@("`@("`@("1T;7!?;6\@
M/2`D;6]N=&@@*R`D;6]N=&AS.PH@("`@("`@("`@("!I9B`H)'1M<%]M;R`^
M(#`I('L*("`@("`@("`@("`@("`@("\O('-A;64@>65A<@H@("`@("`@("`@
M("`@("`@)&UO;G1H(#T@)'1M<%]M;SL*("`@("`@("`@("`@?2!E;'-E:68@
M*"1T;7!?;6\@/3T@,"D@>PH@("`@("`@("`@("`@("`@+R\@<')I;W(@9&5C
M"B`@("`@("`@("`@("`@("`D;6]N=&@@/2`Q,CL*("`@("`@("`@("`@("`@
M("1Y96%R+2T["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`O+R!S;VUE('1I;64@:6X@82!P<FEO<B!Y96%R"B`@("`@("`@("`@("`@
M("`D;6]N=&@@/2`Q,B`K("@D=&UP7VUO("4@,3(I.PH@("`@("`@("`@("`@
M("`@)'EE87(@(#T@)'EE87(@*R!F;&]O<B@D=&UP7VUO("\@,3(I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!$871E7T-A;&,Z
M.F1A=&5&;W)M870H1&%T95]#86QC.CID87ES26Y-;VYT:"@D;6]N=&@L("1Y
M96%R*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M
M;VYT:"P@)'EE87(L("1F;W)M870I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1FEN9"!T:&4@9&%Y(&]F('1H92!W965K(&9O<B!T:&4@9FER<W0@;V8@=&AE
M(&UO;G1H(&]F(&=I=F5N(&1A=&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M("`@("1M;VYT:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO
M8V%L(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y
M96%R(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E;G0@
M;&]C86P@>65A<@H@("`@("H*("`@("`J($!R971U<FX@:6YT(&YU;6)E<B!O
M9B!W965K9&%Y(&9O<B!T:&4@9FER<W0@9&%Y+"`P/5-U;F1A>0H@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&9I<G-T3V9-;VYT:%=E96MD87DH)&UO;G1H(#T@,"P@
M)'EE87(@/2`P*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D>65A<BDI('L*
M("`@("`@("`@("`@)'EE87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59)RD[
M"B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D;6]N=&@I*2!["B`@("`@
M("`@("`@("1M;VYT:"`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ9&%Y3V97965K*"<P
M,2<L("1M;VYT:"P@)'EE87(I.PH@("`@?0H*("`@("\J*@H@("`@("H@0V%L
M8W5L871E<R!T:&4@9&%T92!O9B!T:&4@3G1H('=E96MD87D@;V8@=&AE(&UO
M;G1H+`H@("`@("H@<W5C:"!A<R!T:&4@<V5C;VYD(%-A='5R9&%Y(&]F($IA
M;G5A<GD@,C`P,`H@("`@("H*("`@("`J($!P87)A;2!I;G0@("`@)'=E96L@
M("`@=&AE(&YU;6)E<B!O9B!T:&4@=V5E:R!T;R!G970*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("@Q(#T@9FER<W0L(&5T8RX@($%L<V\@8V%N
M(&)E("=L87-T)RXI"B`@("`@*B!`<&%R86T@:6YT("`@("1D;W<@("`@('1H
M92!D87D@;V8@=&AE('=E96L@*#`@/2!3=6YD87DI"B`@("`@*B!`<&%R86T@
M:6YT("`@("1M;VYT:"`@('1H92!M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@
M("`D>65A<B`@("!T:&4@>65A<BX@(%5S92!T:&4@8V]M<&QE=&4@>65A<B!I
M;G-T96%D(&]F('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M86)B<F5V:6%T960@=F5R<VEO;BX@($4N9RX@=7-E(#(P,#4L(&YO="`P-2X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@($1O(&YO="!A9&0@;&5A
M9&EN9R`P)W,@9F]R('EE87)S('!R:6]R('1O(#$P,#`N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1F;W)M870@('1H92!S=')I;F<@:6YD:6-A=&EN9R!H;W<@
M=&\@9F]R;6%T('1H92!O=71P=70*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@=&AE(&1A=&4@:6X@=&AE(&1E<VER960@9F]R;6%T"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@3E=E96MD87E/9DUO;G1H*"1W965K+"`D9&]W+"`D;6]N
M=&@L("1Y96%R+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)M
M870@/2!$051%7T-!3$-?1D]234%4*0H@("`@>PH@("`@("`@(&EF("AI<U]N
M=6UE<FEC*"1W965K*2D@>PH@("`@("`@("`@("`D1$]7,61A>2`]("@D=V5E
M:R`M(#$I("H@-R`K(#$["B`@("`@("`@("`@("1$3U<Q("`@(#T@1&%T95]#
M86QC.CID87E/9E=E96LH)$1/5S%D87DL("1M;VYT:"P@)'EE87(I.PH@("`@
M("`@("`@("`D=V1A=&4@("`]("@D=V5E:R`M(#$I("H@-R`K(#$@*R`H-R`K
M("1D;W<@+2`D1$]7,2D@)2`W.PH@("`@("`@("`@("!I9B`H)'=D871E(#X@
M1&%T95]#86QC.CID87ES26Y-;VYT:"@D;6]N=&@L("1Y96%R*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("TQ.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ9&%T949O<FUA="@D
M=V1A=&4L("1M;VYT:"P@)'EE87(L("1F;W)M870I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E:68@*"1W965K(#T]("=L87-T)R`F)B`D9&]W(#P@
M-RD@>PH@("`@("`@("`@("`D;&%S=&1A>2`]($1A=&5?0V%L8SHZ9&%Y<TEN
M36]N=&@H)&UO;G1H+"`D>65A<BD["B`@("`@("`@("`@("1L87-T9&]W(#T@
M1&%T95]#86QC.CID87E/9E=E96LH)&QA<W1D87DL("1M;VYT:"P@)'EE87(I
M.PH@("`@("`@("`@("`D9&EF9B`@("`]("1D;W<@+2`D;&%S=&1O=SL*("`@
M("`@("`@("`@:68@*"1D:69F(#X@,"D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N($1A=&5?0V%L8SHZ9&%T949O<FUA="@D;&%S=&1A>2`M("@W("T@)&1I
M9F8I+"`D;6]N=&@L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1Y96%R+"`D9F]R;6%T*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!$871E7T-A;&,Z.F1A=&5&
M;W)M870H)&QA<W1D87D@*R`D9&EF9BP@)&UO;G1H+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D>65A<BP@)&9O<FUA
M="D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@+3$["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T<G5E(&9O<B!V86QI9"!D871E+"!F86QS92!F;W(@:6YV86QI
M9"!D871E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y("`@("!T
M:&4@9&%Y(&]F('1H92!M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N
M=&@@("!T:&4@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)'EE87(@("`@
M=&AE('EE87(N("!5<V4@=&AE(&-O;7!L971E('EE87(@:6YS=&5A9"!O9B!T
M:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&%B8G)E=FEA=&5D
M('9E<G-I;VXN("!%+F<N('5S92`R,#`U+"!N;W0@,#4N"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!$;R!N;W0@861D(&QE861I;F<@,"=S(&9O
M<B!Y96%R<R!P<FEO<B!T;R`Q,#`P+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`
M<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES5F%L:61$871E*"1D87DL
M("1M;VYT:"P@)'EE87(I"B`@("!["B`@("`@("`@:68@*"1Y96%R(#P@,"!\
M?"`D>65A<B`^(#DY.3DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*("`@("`@("!I9B`H(6-H96-K9&%T92@D;6]N=&@L("1D87DL
M("1Y96%R*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T<G5E(&9O<B!A(&QE87`@>65A<BP@96QS92!F86QS90H@("`@
M("H*("`@("`J($!P87)A;2!I;G0@("`@)'EE87(@("`@=&AE('EE87(N("!5
M<V4@=&AE(&-O;7!L971E('EE87(@:6YS=&5A9"!O9B!T:&4*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@(&%B8G)E=FEA=&5D('9E<G-I;VXN("!%
M+F<N('5S92`R,#`U+"!N;W0@,#4N"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!$;R!N;W0@861D(&QE861I;F<@,"=S(&9O<B!Y96%R<R!P<FEO
M<B!T;R`Q,#`P+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;@H@("`@
M("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&ES3&5A<%EE87(H)'EE87(@/2`P*0H@("`@>PH@
M("`@("`@(&EF("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE87(@
M/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"<O7$0O)RP@)'EE87(I*2!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@:68@*"1Y96%R(#P@
M,3`P,"D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@
M("`@("`@(&EF("@D>65A<B`\(#$U.#(I('L*("`@("`@("`@("`@+R\@<')E
M($=R96=O<FEO(%A)24D@+2`Q-3@R"B`@("`@("`@("`@(')E='5R;B`H)'EE
M87(@)2`T(#T](#`I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O
M('!O<W0@1W)E9V]R:6\@6$E)22`M(#$U.#(*("`@("`@("`@("`@<F5T=7)N
M("@H)'EE87(@)2`T(#T](#`I("8F("@D>65A<B`E(#$P,"`A/2`P*2D@?'P@
M*"1Y96%R("4@-#`P(#T](#`I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($1E=&5R;6EN97,@:68@9VEV96X@9&%T92!I<R!A(&9U='5R92!D
M871E(&9R;VT@;F]W"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y
M("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@
M("`D;6]N=&@@("!T:&4@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)'EE
M87(@("`@=&AE('EE87(N("!5<V4@=&AE(&-O;7!L971E('EE87(@:6YS=&5A
M9"!O9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&%B8G)E
M=FEA=&5D('9E<G-I;VXN("!%+F<N('5S92`R,#`U+"!N;W0@,#4N"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!$;R!N;W0@861D(&QE861I;F<@
M,"=S(&9O<B!Y96%R<R!P<FEO<B!T;R`Q,#`P+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES1G5T=7)E1&%T
M92@D9&%Y+"`D;6]N=&@L("1Y96%R*0H@("`@>PH@("`@("`@("1T:&ES7WEE
M87(@(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@("`@("1T:&ES
M7VUO;G1H(#T@1&%T95]#86QC.CID871E3F]W*"<E;2<I.PH@("`@("`@("1T
M:&ES7V1A>2`@(#T@1&%T95]#86QC.CID871E3F]W*"<E9"<I.PH*("`@("`@
M("!I9B`H)'EE87(@/B`D=&AI<U]Y96%R*2!["B`@("`@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@("`@('T@96QS96EF("@D>65A<B`]/2`D=&AI<U]Y96%R
M*2!["B`@("`@("`@("`@(&EF("@D;6]N=&@@/B`D=&AI<U]M;VYT:"D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T@96QS
M96EF("@D;6]N=&@@/3T@)'1H:7-?;6]N=&@I('L*("`@("`@("`@("`@("`@
M(&EF("@D9&%Y(#X@)'1H:7-?9&%Y*2!["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1&5T97)M:6YE<R!I9B!G:79E;B!D871E(&ES(&$@<&%S="!D
M871E(&9R;VT@;F]W"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y
M("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@
M("`D;6]N=&@@("!T:&4@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)'EE
M87(@("`@=&AE('EE87(N("!5<V4@=&AE(&-O;7!L971E('EE87(@:6YS=&5A
M9"!O9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&%B8G)E
M=FEA=&5D('9E<G-I;VXN("!%+F<N('5S92`R,#`U+"!N;W0@,#4N"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!$;R!N;W0@861D(&QE861I;F<@
M,"=S(&9O<B!Y96%R<R!P<FEO<B!T;R`Q,#`P+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES4&%S=$1A=&4H
M)&1A>2P@)&UO;G1H+"`D>65A<BD*("`@('L*("`@("`@("`D=&AI<U]Y96%R
M("`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("`D=&AI<U]M
M;VYT:"`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("`D=&AI
M<U]D87D@("`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)60G*3L*"B`@("`@("`@
M:68@*"1Y96%R(#P@)'1H:7-?>65A<BD@>PH@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("!](&5L<V5I9B`H)'EE87(@/3T@)'1H:7-?>65A<BD@
M>PH@("`@("`@("`@("!I9B`H)&UO;G1H(#P@)'1H:7-?;6]N=&@I('L*("`@
M("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!](&5L<V5I
M9B`H)&UO;G1H(#T]("1T:&ES7VUO;G1H*2!["B`@("`@("`@("`@("`@("!I
M9B`H)&1A>2`\("1T:&ES7V1A>2D@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@;G5M8F5R(&]F(&1A>7,@8F5T=V5E;B!T=V\@9VEV
M96X@9&%T97,*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("`@("1D87DQ("`@
M('1H92!D87D@;V8@=&AE(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1M
M;VYT:#$@('1H92!M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@("`D>65A<C$@
M("!T:&4@>65A<BX@(%5S92!T:&4@8V]M<&QE=&4@>65A<B!I;G-T96%D(&]F
M('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@86)B<F5V:6%T
M960@=F5R<VEO;BX@($4N9RX@=7-E(#(P,#4L(&YO="`P-2X*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@($1O(&YO="!A9&0@;&5A9&EN9R`P)W,@
M9F]R('EE87)S('!R:6]R('1O(#$P,#`N"B`@("`@*B!`<&%R86T@:6YT("`@
M("1D87DR("`@('1H92!D87D@;V8@=&AE(&UO;G1H"B`@("`@*B!`<&%R86T@
M:6YT("`@("1M;VYT:#(@('1H92!M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@
M("`D>65A<C(@("!T:&4@>65A<BX@(%5S92!T:&4@8V]M<&QE=&4@>65A<B!I
M;G-T96%D(&]F('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M86)B<F5V:6%T960@=F5R<VEO;BX@($4N9RX@=7-E(#(P,#4L(&YO="`P-2X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@($1O(&YO="!A9&0@;&5A
M9&EN9R`P)W,@9F]R('EE87)S('!R:6]R('1O(#$P,#`N"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G0@('1H92!A8G-O;'5T92!N=6UB97(@;V8@9&%Y<R!B
M971W965N('1H92!T=V\@9&%T97,N"B`@("`@*B`@("`@("`@("`@("`@($EF
M(&%N(&5R<F]R(&]C8W5R<RP@+3$@:7,@<F5T=7)N960N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@9&%T941I9F8H)&1A>3$L("1M;VYT:#$L("1Y96%R,2P@)&1A
M>3(L("1M;VYT:#(L("1Y96%R,BD*("`@('L*("`@("`@("!I9B`H(41A=&5?
M0V%L8SHZ:7-686QI9$1A=&4H)&1A>3$L("1M;VYT:#$L("1Y96%R,2DI('L*
M("`@("`@("`@("`@<F5T=7)N("TQ.PH@("`@("`@('T*("`@("`@("!I9B`H
M(41A=&5?0V%L8SHZ:7-686QI9$1A=&4H)&1A>3(L("1M;VYT:#(L("1Y96%R
M,BDI('L*("`@("`@("`@("`@<F5T=7)N("TQ.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@86)S*$1A=&5?0V%L8SHZ9&%T951O1&%Y<R@D9&%Y,2P@)&UO
M;G1H,2P@)'EE87(Q*0H@("`@("`@("`@("`@("`@("`@+2!$871E7T-A;&,Z
M.F1A=&54;T1A>7,H)&1A>3(L("1M;VYT:#(L("1Y96%R,BDI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0V]M<&%R97,@='=O(&1A=&5S"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN="`@("`D9&%Y,2`@("!T:&4@9&%Y(&]F('1H92!M;VYT
M:`H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@Q("!T:&4@;6]N=&@*("`@
M("`J($!P87)A;2!I;G0@("`@)'EE87(Q("`@=&AE('EE87(N("!5<V4@=&AE
M(&-O;7!L971E('EE87(@:6YS=&5A9"!O9B!T:&4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@(&%B8G)E=FEA=&5D('9E<G-I;VXN("!%+F<N('5S
M92`R,#`U+"!N;W0@,#4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!$;R!N;W0@861D(&QE861I;F<@,"=S(&9O<B!Y96%R<R!P<FEO<B!T;R`Q
M,#`P+@H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y,B`@("!T:&4@9&%Y(&]F
M('1H92!M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@R("!T:&4@
M;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)'EE87(R("`@=&AE('EE87(N
M("!5<V4@=&AE(&-O;7!L971E('EE87(@:6YS=&5A9"!O9B!T:&4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@(&%B8G)E=FEA=&5D('9E<G-I;VXN
M("!%+F<N('5S92`R,#`U+"!N;W0@,#4N"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("!$;R!N;W0@861D(&QE861I;F<@,"=S(&9O<B!Y96%R<R!P
M<FEO<B!T;R`Q,#`P+@H@("`@("H*("`@("`J($!R971U<FX@:6YT("`P(&EF
M('1H92!D871E<R!A<F4@97%U86PN(#$@:68@9&%T92`Q(&ES(&QA=&5R+"`M
M,2!I9@H@("`@("H@("`@("`@("`@("`@("!D871E(#$@:7,@96%R;&EE<BX*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@
M("`@("HO"B`@("!F=6YC=&EO;B!C;VUP87)E1&%T97,H)&1A>3$L("1M;VYT
M:#$L("1Y96%R,2P@)&1A>3(L("1M;VYT:#(L("1Y96%R,BD*("`@('L*("`@
M("`@("`D;F1A>7,Q(#T@1&%T95]#86QC.CID871E5&]$87ES*"1D87DQ+"`D
M;6]N=&@Q+"`D>65A<C$I.PH@("`@("`@("1N9&%Y<S(@/2!$871E7T-A;&,Z
M.F1A=&54;T1A>7,H)&1A>3(L("1M;VYT:#(L("1Y96%R,BD["B`@("`@("`@
M:68@*"1N9&%Y<S$@/3T@)&YD87ES,BD@>PH@("`@("`@("`@("!R971U<FX@
M,#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("@D;F1A>7,Q(#X@)&YD87ES
M,BD@/R`Q(#H@+3$["B`@("!]"GT*"C\^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T1A=&4O
M2'5M86XN<&AP````````````````````````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#$W-#8T`#$P-3$U-#,S-S,W`#`R,3(V,0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*B!V:6TZ('-E="!E
M>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT
M.B`J+PHO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#
M;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-2!!;&QA;B!+96YT("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T
M;R!T:&4@3F5W($)31"!L:6-E;G-E+"!4:&%T(&ES(&)U;F1L960@('P*+R\@
M?"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@
M:7,@879A:6QA8FQE('1H<F]U9V@@("`@("!\"B\O('P@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O
M;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("`@("`@("`@("`@("`@("`@('P*
M+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@;F5W
M($)31&QI8V5N<V4@86YD(&%R92!U;F%B;&4@("!\"B\O('P@=&\@;V)T86EN
M(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A
M(&YO=&4@=&\@("`@("`@?`HO+R!\('!E87(M9&5V0&QI<W1S+G!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R
M.B!!;&QA;B!+96YT(#QA;&QA;D!L;V1E<W1O;F4N8V\N>F$^("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*"B\J*@H@*B!#;&%S<R!T;R!C;VYV97)T(&1A=&4@<W1R:6YG<R!B
M971W965N($=R96=O<FEA;B!A;F0@2'5M86X@8V%L96YD87(@9F]R;6%T<PH@
M*@H@*B!4:&4@2'5M86X@0V%L96YD87(@9F]R;6%T(&AA<R!B965N('!R;W!O
M<V5D(&)Y(%-C;W1T($9L86YS8G5R9R!A;F0@8V%N(&)E"B`J(&5X<&QA:6YE
M9"!A<R!F;VQL;W=S.@H@*B`@5&AE('EE87(@:7,@;6%D92!U<"!O9B`Q,R!M
M;VYT:',*("H@($5A8V@@;6]N=&@@:&%S(#(X(&1A>7,*("H@($-O=6YT:6YG
M(&]F(&UO;G1H<R!S=&%R=',@9G)O;2`P("AZ97)O*2!S;R!T:&4@;6]N=&AS
M('=I;&P@<G5N(&9R;VT@,"!T;R`Q,@H@*B`@3F5W(%EE87)S(&1A>2`H,#`I
M(&ES(&$@;6]N=&AL97-S(&1A>0H@*B`@3F]T93H@3&5A<"!996%R<R!A<F4@
M;F]T('EE="!A8V-O=6YT960@9F]R(&EN('1H92!(=6UA;B!#86QE;F1A<B!S
M>7-T96T*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@0&-A=&5G
M;W)Y("`@1&%T92!A;F0@5&EM90H@*B!`<&%C:V%G92`@("!$871E"B`J($!A
M=71H;W(@("`@($%L;&%N($ME;G0@/&%L;&%N0&QO9&5S=&]N92YC;RYZ83X*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U($%L;&%N($ME;G0*("H@0&QI8V5N
M<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M
M;&EC96YS92YP:'`@($YE=R!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@("!#
M5E,Z("1)9#H@2'5M86XN<&AP+'8@,2XU(#(P,#4O,3$O,34@,#`Z,38Z-#`@
M<&%J;WEE($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]$871E"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE
M('-I;F-E(%)E;&5A<V4@,2XS"B`J+PH*+RHJ"B`J($-L87-S('1O(&-O;G9E
M<G0@9&%T92!S=')I;F=S(&)E='=E96X@1W)E9V]R:6%N(&%N9"!(=6UA;B!C
M86QE;F1A<B!F;W)M871S"B`J"B`J(%1H92!(=6UA;B!#86QE;F1A<B!F;W)M
M870@:&%S(&)E96X@<')O<&]S960@8GD@4V-O='0@1FQA;G-B=7)G(&%N9"!C
M86X@8F4*("H@97AP;&%I;F5D(&%S(&9O;&QO=W,Z"B`J("!4:&4@>65A<B!I
M<R!M861E('5P(&]F(#$S(&UO;G1H<PH@*B`@16%C:"!M;VYT:"!H87,@,C@@
M9&%Y<PH@*B`@0V]U;G1I;F<@;V8@;6]N=&AS('-T87)T<R!F<F]M(#`@*'IE
M<F\I('-O('1H92!M;VYT:',@=VEL;"!R=6X@9G)O;2`P('1O(#$R"B`J("!.
M97<@665A<G,@9&%Y("@P,"D@:7,@82!M;VYT:&QE<W,@9&%Y"B`J("!.;W1E
M.B!,96%P(%EE87)S(&%R92!N;W0@>65T(&%C8V]U;G1E9"!F;W(@:6X@=&AE
M($AU;6%N($-A;&5N9&%R('-Y<W1E;0H@*@H@*B!`875T:&]R("`@("!!;&QA
M;B!+96YT(#QA;&QA;D!L;V1E<W1O;F4N8V\N>F$^"B`J($!C;W!Y<FEG:'0@
M(#$Y.3<M,C`P-2!!;&QA;B!+96YT"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W
M=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!.
M97<@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+C8*
M("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1A
M=&4*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XS"B`J+PIC;&%S<R!$871E7TAU;6%N"GL*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!A;B!A<W-O8VEA=&EV92!A<G)A>2!C;VYT86EN:6YG('1H92!C
M;VYV97)T960@9&%T92!I;F9O<FUA=&EO;@H@("`@("H@:6X@)TAU;6%N($-A
M;&5N9&%R)R!F;W)M870N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="!D87D@
M:6X@1$0@9F]R;6%T+"!D969A=6QT(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@
M*B!`<&%R86T@:6YT(&UO;G1H(&EN($U-(&9O<FUA="P@9&5F875L="!C=7)R
M96YT(&QO8V%L(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT('EE87(@:6X@0T-9
M62!F;W)M870L(&1E9F%U;'0@=&\@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%S<V]C:6%T:79E(&%R<F%Y*`H@("`@("H@("`@("`@("`@("`@("!H9&]M
M+"`@("`@("`O+R!(=6UA;B!$87D@3V8@36]N=&@L('-T87)T:6YG(&%T(#$*
M("`@("`J("`@("`@("`@("`@("`@:&1O=RP@("`@("`@+R\@2'5M86X@1&%Y
M($]F(%=E96LL('-T87)T:6YG(&%T(#$*("`@("`J("`@("`@("`@("`@("`@
M:'=O;2P@("`@("`@+R\@2'5M86X@5V5E:R!O9B!-;VYT:"P@<W1A<G1I;F<@
M870@,0H@("`@("H@("`@("`@("`@("`@("!H=V]Y+"`@("`@("`O+R!(=6UA
M;B!7965K(&]F(%EE87(L('-T87)T:6YG(&%T(#$*("`@("`J("`@("`@("`@
M("`@("`@:&UO>2P@("`@("`@+R\@2'5M86X@36]N=&@@;V8@665A<BP@<W1A
M<G1I;F<@870@,`H@("`@("H@("`@("`@("`@("`@("`I"B`@("`@*@H@("`@
M("H@268@=&AE(&1A>2!I<R!.97<@665A<G,@1&%Y+"!T:&4@9G5N8W1I;VX@
M=VEL;"!R971U<FX*("`@("`J(")H9&]M(B`]/B`@,`H@("`@("H@(FAD;W<B
M(#T^("`P"B`@("`@*B`B:'=O;2(@/3X@(#`*("`@("`J(")H=V]Y(B`]/B`@
M,`H@("`@("H@(FAM;WDB(#T^("TQ"B`@("`@*B`@4VEN8V4@,"!I<R!A('9A
M;&ED(&UO;G1H(&YU;6)E<B!U;F1E<B!T:&4@2'5M86X@0V%L96YD87(L($D@
M:&%V92!L969T"B`@("`@*B`@=&AE(&UO;G1H(&%S("TQ(&9O<B!.97<@665A
M<G,@1&%Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!G<F5G;W)I86Y4;TAU;6%N
M*"1D87D],"P@)&UO;G1H/3`L("1Y96%R/3`I"B`@("!["B`@("`@("`@+RH*
M("`@("`@("`@*B!#:&5C:R!T;R!S964@:68@86YY(&]F('1H92!A<F=U;65N
M=',@87)E(&5M<'1Y"B`@("`@("`@("H@268@=&AE>2!A<F4@=&AE;B!P;W!U
M;&%T92!T:&4@)&1A=&5I;F9O(&%R<F%Y"B`@("`@("`@("H@5&AE;B!C:&5C
M:R!T;R!S964@=VAI8V@@87)G=6UE;G1S(&%R92!E;7!T>2!A;F0@9FEL;`H@
M("`@("`@("`J('1H;W-E('=I=&@@=&AE(&-U<G)E;G0@9&%T92!I;F9O"B`@
M("`@("`@("HO"B`@("`@("`@:68@*"AE;7!T>2@D9&%Y*2!\?"`H96UP='DH
M)&UO;G1H*2D@?'P@96UP='DH)'EE87(I*2D@>PH@("`@("`@("`@("`D9&%T
M96EN9F\@/2!G971D871E*'1I;64H*2D["B`@("`@("`@?0H@("`@("`@(&EF
M("AE;7!T>2@D9&%Y*2D@>PH@("`@("`@("`@("`D9&%Y(#T@)&1A=&5I;F9O
M6R)M9&%Y(ET["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D;6]N=&@I
M*2!["B`@("`@("`@("`@("1M;VYT:"`]("1D871E:6YF;ULB;6]N(ET["B`@
M("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@
M("`@)'EE87(@/2`D9&%T96EN9F];(GEE87(B73L*("`@("`@("!]"B`@("`@
M("`@+RH*("`@("`@("`@*B!792!N965D('1O(&MN;W<@:&]W(&UA;GD@9&%Y
M<R!I;G1O('1H92!Y96%R('=E(&%R90H@("`@("`@("`J+PH@("`@("`@("1D
M871E:6YF;R`](&=E=&1A=&4H;6MT:6UE*#`L(#`L(#`L("1M;VYT:"P@)&1A
M>2P@)'EE87(I*3L*("`@("`@("`D9&%Y;V9Y96%R(#T@)&1A=&5I;F9O6R)Y
M9&%Y(ET["B`@("`@("`@+RH*("`@("`@("`@*B!(=6UA;B!#86QE;F1A<B!S
M=&%R=',@870@,"!F;W(@;6]N=&AS(&%N9"!T:&4@9FER<W0@9&%Y(&]F('1H
M92!Y96%R"B`@("`@("`@("H@:7,@9&5S:6=N871E9"`P,"P@<V\@=V4@;F5E
M9"!T;R!S=&%R="!O=7(@9&%Y(&]F('1H92!Y96%R(&%T(#`@9F]R"B`@("`@
M("`@("H@=&AE<V4@8V%L8W5L871I;VYS+@H@("`@("`@("`J($%L<V\L('1H
M92!D87D@;V8@=&AE(&UO;G1H(&ES(&-A;&-U;&%T960@=VET:"!A(&UO9'5L
M=7,@;V8@,C@N"B`@("`@("`@("H@0F5C875S92!A(&1A>2!I<R`R."!D87ES
M+"!T:&4@;&%S="!D87D@;V8@=&AE(&UO;G1H('=O=6QD(&AA=F4@80H@("`@
M("`@("`J(')E;6%I;F1E<B!O9B`P(&%N9"!N;W0@,C@@87,@:70@<VAO=6QD
M(&)E+B`@1&5C<F5M96YT:6YG("1D87EO9GEE87(*("`@("`@("`@*B!G971S
M(&%R;W5N9"!T:&ES+@H@("`@("`@("`J+PH@("`@("`@("1D87EO9GEE87(M
M+3L*("`@("`@("`O*@H@("`@("`@("`J(#(X(&1A>7,@:6X@82!M;VYT:"XN
M+@H@("`@("`@("`J+PH@("`@("`@("1H=6UA;DUO;G1H3V9996%R(#T@9FQO
M;W(H)&1A>6]F>65A<B`O(#(X*3L*("`@("`@("`O*@H@("`@("`@("`J($EF
M('=E(&%R92!I;B!T:&4@9FER<W0@;6]N=&@@=&AE;B!T:&4@9&%Y(&]F('1H
M92!M;VYT:"!I<R`D9&%Y;V9Y96%R"B`@("`@("`@("H@96QS92!W92!N965D
M('1O(&9I;F0@=&AE(&UO9'5L=7,@;V8@,C@N"B`@("`@("`@("HO"B`@("`@
M("`@:68@*"1H=6UA;DUO;G1H3V9996%R(#T](#`I('L*("`@("`@("`@("`@
M)&AU;6%N1&%Y3V9-;VYT:"`]("1D87EO9GEE87(["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&AU;6%N1&%Y3V9-;VYT:"`]("@D9&%Y;V9Y96%R
M*2`E(#(X.PH@("`@("`@('T*("`@("`@("`O*@H@("`@("`@("`J($1A>2!O
M9B!T:&4@=V5E:R!I<R!M;V1U;'5S(#<*("`@("`@("`@*B\*("`@("`@("`D
M:'5M86Y$87E/9E=E96L@/2`D9&%Y;V9Y96%R("4@-SL*("`@("`@("`O*@H@
M("`@("`@("`J(%=E(&-A;B!N;W<@:6YC<F5M96YT("1D87EO9GEE87(@8F%C
M:R!T;R!I="=S(&-O<G)E8W0@=F%L=64@9F]R"B`@("`@("`@("H@=&AE(')E
M;6%I;F1E<B!O9B!T:&4@8V%L8W5L871I;VYS"B`@("`@("`@("HO"B`@("`@
M("`@)&1A>6]F>65A<BLK.PH@("`@("`@("\J"B`@("`@("`@("H@)&AU;6%N
M1&%Y3V9-;VYT:"!N965D<R!T;R!B92!I;F-R96UE;G1E9"!N;W<@+2!R96-A
M;&P@=&AA="!W92!F=61G960*("`@("`@("`@*B!I="!A(&)I="!B>2!D96-R
M96UE;G1I;F<@)&1A>6]F>65A<B!E87)L:65R"B`@("`@("`@("H@4V%M92!G
M;V5S(&9O<B`D:'5M86Y$87E/9E=E96L*("`@("`@("`@*B\*("`@("`@("`D
M:'5M86Y$87E/9DUO;G1H*RL["B`@("`@("`@)&AU;6%N1&%Y3V97965K*RL[
M"B`@("`@("`@+RH*("`@("`@("`@*B!7965K(&]F('1H92!M;VYT:"!I<R!D
M87D@;V8@=&AE(&UO;G1H(&1I=FED960@8GD@-RP@<F]U;F1E9"!U<`H@("`@
M("`@("`J(%-A;64@9F]R('=E96L@;V8@=&AE('EE87(L(&)U="!U<V4@)&1A
M>6]F>65A<B!I;G-T96%D("1H=6UA;D1A>4]F36]N=&@*("`@("`@("`@*B\*
M("`@("`@("`D:'5M86Y7965K3V9-;VYT:"`](&-E:6PH)&AU;6%N1&%Y3V9-
M;VYT:"`O(#<I.PH@("`@("`@("1H=6UA;E=E96M/9EEE87(@/2!C96EL*"1D
M87EO9GEE87(@+R`W*3L*("`@("`@("`O*@H@("`@("`@("`J(%)E='5R;B!A
M;B!A<W-O8VEA=&EV92!A<G)A>2!O9B!T:&4@=F%L=65S"B`@("`@("`@("HO
M"B`@("`@("`@<F5T=7)N(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`B
M:&1O;2(@/3X@)&AU;6%N1&%Y3V9-;VYT:"P*("`@("`@("`@("`@("`@("`@
M("`@(FAD;W<B(#T^("1H=6UA;D1A>4]F5V5E:RP*("`@("`@("`@("`@("`@
M("`@("`@(FAW;VTB(#T^("1H=6UA;E=E96M/9DUO;G1H+`H@("`@("`@("`@
M("`@("`@("`@("`B:'=O>2(@/3X@)&AU;6%N5V5E:T]F665A<BP*("`@("`@
M("`@("`@("`@("`@("`@(FAM;WDB(#T^("1H=6UA;DUO;G1H3V9996%R("D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('5N:7@@=&EM97-T86UP
M(&9O<B!A(&=I=F5N($AU;6%N($-A;&5N9&%R(&1A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT(&1A>2!I;B!$1"!F;W)M870*("`@("`J($!P87)A;2!I
M;G0@;6]N=&@@:6X@34T@9F]R;6%T"B`@("`@*B!`<&%R86T@:6YT('EE87(@
M:6X@0T-962!F;W)M870L(&1E9F%U;'0@=&\@8W5R<F5N="!L;V-A;"!Y96%R
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&EN="!U;FEX('1I;65S=&%M<"!O9B!D871E"B`@("`@*B\*("`@
M(&9U;F-T:6]N($AU;6%N5&]'<F5G;W)I86XH)&1A>2P@)&UO;G1H+"`D>65A
M<CTP*0H@("`@>PH@("`@("`@("\J"B`@("`@("`@("H@0VAE8VL@=&\@<V5E
M(&EF('1H92!Y96%R(&AA<R!B965N('!A<W-E9"!T:')O=6=H+@H@("`@("`@
M("`J($EF(&YO="!G970@8W5R<F5N="!Y96%R"B`@("`@("`@("HO"B`@("`@
M("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D9&%T96EN9F\@
M/2!G971D871E*'1I;64H*2D["B`@("`@("`@("`@("1Y96%R(#T@)&1A=&5I
M;F9O6R)Y96%R(ET["B`@("`@("`@?0H@("`@("`@("\J"B`@("`@("`@("H@
M5V4@;F5E9"!T;R!G970@=&AE(&1A>2!O9B!T:&4@>65A<B!T:&%T('=E(&%R
M92!C=7)R96YT;'D@870@<V\@=&AA=`H@("`@("`@("`J('=E(&-A;B!W;W)K
M(&]U="!T:&4@1W)E9V]R:6%N($UO;G1H(&%N9"!D87D*("`@("`@("`@*B\*
M("`@("`@("`D1&%Y3V9996%R(#T@)&UO;G1H("H@,C@["B`@("`@("`@)$1A
M>4]F665A<B`K/2`D9&%Y.PH@("`@("`@("\J"B`@("`@("`@("H@2'5M86X@
M0V%L96YD87(@<W1A<G1S(&%T(#`L('-O('=E(&YE960@=&\@:6YC<F5M96YT
M("1$87E/9EEE87(*("`@("`@("`@*B!T;R!T86ME(&EN=&\@86-C;W5N="!T
M:&4@9&%Y(#`P"B`@("`@("`@("HO"B`@("`@("`@)$1A>4]F665A<BLK.PH@
M("`@("`@("\J"B`@("`@("`@("H@=&AE(&UK=&EM92@I(&9U;F-T:6]N('=I
M;&P@8V]R<F5C=&QY(&-A;&-U;&%T92!T:&4@9&%T92!F;W(@;W5T(&]F"B`@
M("`@("`@("H@<F%N9V4@=F%L=65S+"!S;R!P=71T:6YG("1$87E/9EEE87(@
M:6YS=&5A9"!O9B!T:&4@9&%Y(&]F('1H92!M;VYT:`H@("`@("`@("`J('=I
M;&P@=V]R:R!F:6YE+@H@("`@("`@("`J+PH@("`@("`@("1'<F5G;W)I86Y4
M:6UE4W1A;7`@/2!M:W1I;64H,"P@,"P@,"P@,2P@)$1A>4]F665A<BP@)'EE
M87(I.PH@("`@("`@(')E='5R;B`D1W)E9V]R:6%N5&EM95-T86UP.PH@("`@
M?0I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]$871E+U-P86XN<&AP````````````````````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`W-34T,0`Q,#4Q-30S,S<S-P`P,C$Q
M,3(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I
M9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*+R\*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#4@($QE
M86YD<F\@3'5C87)E;&QA+"!0:65R<F4M06QA:6X@2F]Y92`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=&AE($YE=R!"4T0@;&EC96YS92P@5&AA
M="!I<R!B=6YD;&5D("!\"B\O('P@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE
M(&9I;&4@3$E#14Y312P@86YD(&ES(&%V86EL86)L92!T:')O=6=H("`@("`@
M?`HO+R!\('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O
M=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@
M("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV
M92!A(&-O<'D@;V8@=&AE(&YE=R!"4T1L:6-E;G-E(&%N9"!A<F4@=6YA8FQE
M("`@?`HO+R!\('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@('P*+R\@?"!P96%R
M+61E=D!L:7-T<RYP:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@
M:6UM961I871E;'DN("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\($%U=&AO<CH@0F%B82!"=65H;&5R(#QB86)A0&)A8F%Z
M+F-O;3X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@
M("`@("`@(%!I97)R92U!;&%I;B!*;WEE(#QP86IO>65`<&AP+FYE=#X@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PH*+RHJ"B`J($=E;F5R:6,@=&EM92!S<&%N(&AA;F1L:6YG
M(&-L87-S(&9O<B!014%2"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J
M"B`J($!C871E9V]R>2`@($1A=&4@86YD(%1I;64*("H@0'!A8VMA9V4@("`@
M1&%T90H@*B!`875T:&]R("`@("!,96%N9')O($QU8V%R96QL82`\;&QU8V%X
M0'!H<"YN970^"B`J($!A=71H;W(@("`@(%!I97)R92U!;&%I;B!*;WEE(#QP
M86IO>65`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U($QE86YD
M<F\@3'5C87)E;&QA+"!0:65R<F4M06QA:6X@2F]Y90H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E
M;G-E+G!H<"`@3F5W($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@($-64SH@
M)$ED.B!3<&%N+G!H<"QV(#$N."`R,#`U+S$Q+S$U(#`P.C$V.C0P('!A:F]Y
M92!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A
M8VMA9V4O1&%T90H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC
M92!296QE87-E(#$N-`H@*B\*"B\J*@H@*B!'970@=&AE($1A=&4@8VQA<W,*
M("HO"G)E<75I<F5?;VYC92`G1&%T92YP:'`G.PH*+RHJ"B`J($=E="!T:&4@
M1&%T95]#86QC(&-L87-S"B`J+PIR97%U:7)E7V]N8V4@)T1A=&4O0V%L8RYP
M:'`G.PH*+RHJ"B`J($YO;B!.=6UE<FEC(%-E<&%R871E9"!686QU97,@*$Y.
M4U8I($EN<'5T($9O<FUA="X*("H*("H@26YP=70@9F]R;6%T(&=U97-S960@
M9G)O;2!S;VUE=&AI;F<@;&EK92!T:&ES.@H@*B!D87ES/'-E<#YH;W5R<SQS
M97`^;6EN=71E<SQS97`^<V5C;VYD<PH@*B!7:&5R92`\<V5P/B!I<R!A;GD@
M<75A;G1I='D@;V8@;F]N(&YU;65R:6,@8VAA<G,N($EF(&YO('9A;'5E<R!A
M<F4*("H@9VEV96XL('1I;64@<W!A;B!I<R!S970@=&\@>F5R;RP@:68@;VYE
M('9A;'5E(&ES(&=I=F5N+"!I="=S('5S960@9F]R"B`J(&AO=7)S+"!I9B!T
M=V\@=F%L=65S(&%R92!G:79E;B!I="=S('5S960@9F]R(&AO=7)S(&%N9"!M
M:6YU=&5S(&%N9"!I9@H@*B!T:')E92!V86QU97,@87)E(&=I=F5N+"!I="=S
M('5S960@9F]R(&AO=7)S+"!M:6YU=&5S(&%N9"!S96-O;F1S+CQB<CX*("H@
M17AA;7!L97,Z/&)R/@H@*B`G)R`@("`@("`@("`@("`@("`@("`M/B`P+"`P
M+"`P+"`P("AD87ES+"!H;W5R<RP@;6EN=71E<RP@<V5C;VYD<RD\8G(^"B`J
M("<Q,B<@("`@("`@("`@("`@("`@("T^(#`L(#$R+"`P+"`P"B`J("<Q,BXS
M,"<@("`@("`@("`@("`@("T^(#`L(#$R+"`S,"P@,#QB<CX*("H@)S$R.C,P
M.C$X)R`@("`@("`@("`@+3X@,"P@,3(L(#,P+"`Q.#QB<CX*("H@)S,M,3(M
M,S`M,3@G("`@("`@("`@+3X@,RP@,3(L(#,P+"`Q.#QB<CX*("H@)S,@9&%Y
M<RP@,3(M,S`M,3@G("`@+3X@,RP@,3(L(#,P+"`Q.#QB<CX*("H@)S$R.C,P
M('=I=&@@,3@@<V5C<R<@+3X@,"P@,3(L(#,P+"`Q.#QB<CX*("H*("H@0&-O
M;G-T(&EN=`H@*B\*9&5F:6YE*"=$051%7U-004Y?24Y0551?1D]234%47TY.
M4U8G+"`Q*3L*"B\J*@H@*B!$969A=6QT('1I;64@9F]R;6%T('=H96X@8V]N
M=F5R=&EN9R!T;R!A('-T<FEN9RX*("H*("H@0&=L;V)A;"!S=')I;F<*("HO
M"B1'3$]"04Q36R=?1$%415]34$%.7T9/4DU!5"==("`]("<E0R<["@HO*BH*
M("H@1&5F875L="!T:6UE(&9O<FUA="!W:&5N(&-O;G9E<G1I;F<@9G)O;2!A
M('-T<FEN9RX*("H*("H@0&=L;V)A;"!M:7AE9`H@*B\*)$=,3T)!3%-;)U]$
M051%7U-004Y?24Y0551?1D]234%4)UT@/2!$051%7U-004Y?24Y0551?1D]2
M34%47TY.4U8["@HO*BH*("H@1V5N97)I8R!T:6UE('-P86X@:&%N9&QI;F<@
M8VQA<W,@9F]R(%!%05(*("H*("H@0&%U=&AO<B`@("`@3&5A;F1R;R!,=6-A
M<F5L;&$@/&QL=6-A>$!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P
M,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P
M96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@3F5W($)3
M1"!,:6-E;G-E"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XV"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$871E"B`J
M($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N
M-`H@*@H@*B!`=&]D;R`@("`@("!'970@86YD('-E="!D969A=6QT(&QO8V%L
M(&EN<'5T(&%N9"!O=71P=70@9F]R;6%T<S\*("HO"F-L87-S($1A=&5?4W!A
M;B!["@H@("`@+RHJ"B`@("`@*B!`=F%R(&EN=`H@("`@("HO"B`@("!V87(@
M)&1A>3L*"B`@("`O*BH*("`@("`J($!V87(@:6YT"B`@("`@*B\*("`@('9A
M<B`D:&]U<CL*"B`@("`O*BH*("`@("`J($!V87(@:6YT"B`@("`@*B\*("`@
M('9A<B`D;6EN=71E.PH*("`@("\J*@H@("`@("H@0'9A<B!I;G0*("`@("`J
M+PH@("`@=F%R("1S96-O;F0["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O
M<BX*("`@("`J"B`@("`@*B!#<F5A=&5S('1H92!T:6UE('-P86X@;V)J96-T
M(&-A;&QI;F<@=&AE('-E="@I(&UE=&AO9"X*("`@("`J"B`@("`@*B!`<&%R
M86T@(&UI>&5D("1T:6UE("`@5&EM92!S<&%N(&5X<')E<W-I;VXN"B`@("`@
M*B!`<&%R86T@(&UI>&5D("1F;W)M870@1F]R;6%T('-T<FEN9R!T;R!S970@
M:70@9G)O;2!A('-T<FEN9R!O<B!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!S96-O;F0@9&%T92!S970@:70@9G)O;2!A(&1A=&4@9&EF9BX*
M("`@("`J"B`@("`@*B!`<V5E("`@('-E="@I"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!$871E7U-P86XH)'1I;64@/2`P
M+"`D9F]R;6%T(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^<V5T*"1T
M:6UE+"`D9F]R;6%T*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@
M=&EM92!S<&%N('1O(&$@;F5W('9A;'5E(&EN(&$@)W-M87)T)R!W87DN"B`@
M("`@*@H@("`@("H@4V5T<R!T:&4@=&EM92!S<&%N(&1E<&5N9&EN9R!O;B!T
M:&4@87)G=6UE;G0@='EP97,L(&-A;&QI;F<*("`@("`J('1O('1H92!A<'!R
M;W!R:6%T92!S971&<F]M6'AX*"D@;65T:&]D+@H@("`@("H*("`@("`J($!P
M87)A;2`@;6EX960@)'1I;64@("!4:6UE('-P86X@97AP<F5S<VEO;BX*("`@
M("`J($!P87)A;2`@;6EX960@)&9O<FUA="!&;W)M870@<W1R:6YG('1O('-E
M="!I="!F<F]M(&$@<W1R:6YG(&]R('1H90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@('-E8V]N9"!D871E('-E="!I="!F<F]M(&$@9&%T92!D:69F
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@=')U92!O;B!S=6-C97-S
M+@H@("`@("H*("`@("`J($!S964@("`@<V5T1G)O;4]B:F5C="@I"B`@("`@
M*B!`<V5E("`@('-E=$9R;VU!<G)A>2@I"B`@("`@*B!`<V5E("`@('-E=$9R
M;VU3=')I;F<H*0H@("`@("H@0'-E92`@("!S971&<F]M4V5C;VYD<R@I"B`@
M("`@*B!`<V5E("`@('-E=$9R;VU$871E1&EF9B@I"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S970H)'1I;64@/2`P+"`D
M9F]R;6%T(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?82@D=&EM92P@
M)V1A=&5?<W!A;B<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^8V]P
M>2@D=&EM92D["B`@("`@("`@?2!E;'-E:68@*&ES7V$H)'1I;64L("=D871E
M)RD@86YD(&ES7V$H)&9O<FUA="P@)V1A=&4G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G-E=$9R;VU$871E1&EF9B@D=&EM92P@)&9O<FUA="D[
M"B`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1T:6UE*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G-E=$9R;VU!<G)A>2@D=&EM92D["B`@("`@
M("`@?2!E;'-E:68@*&ES7W-T<FEN9R@D=&EM92DI('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YS971&<F]M4W1R:6YG*"1T:6UE+"`D9F]R;6%T*3L*
M("`@("`@("!](&5L<V5I9B`H:7-?:6YT*"1T:6UE*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G-E=$9R;VU396-O;F1S*"1T:6UE*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-E=$9R;VU3
M96-O;F1S*#`I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E
M="!T:&4@=&EM92!S<&%N(&9R;VT@86X@87)R87DN"B`@("`@*@H@("`@("H@
M4V5T('1H92!T:6UE('-P86X@9G)O;2!A;B!A<G)A>2X@06YY('9A;'5E(&-A
M;B!B92!A(&9L;V%T("AB=70@:70*("`@("`J(&AA<R!N;R!S96YS92!I;B!S
M96-O;F1S*2P@9F]R(&5X86UP;&4@87)R87DH,C,N-2P@,C`L(#`I(&ES"B`@
M("`@*B!I;G1E<G!R971E9"!A<R`R,R!H;W5R<RP@+C4J-C`@*R`R,"`](#4P
M(&UI;G5T97,@86YD(#`@<V5C;VYD<RX*("`@("`J"B`@("`@*B!`<&%R86T@
M(&%R<F%Y("1T:6UE($ET96US(&%R92!C;W5N=&5D(&9R;VT@<FEG:'0@=&\@
M;&5F="X@1FER<W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@:71E;2!I
M<R!F;W(@<V5C;VYD<RP@<V5C;VYD(&9O<B!M:6YU=&5S+"!T:&ER9`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("!F;W(@:&]U<G,@86YD(&9O=7)T:"!F
M;W(@9&%Y<RX@268@=&AE<F4@87)E"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@(&QE<W,@:71E;7,@=&AA;B`T+"!Z97)O("@P*2!I<R!A<W-U;65D(&9O
M<B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@86)S96YT('9A;'5E
M<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@(%1R=64@;VX@<W5C8V5S
M<RX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!S971&<F]M07)R87DH)'1I;64I"B`@("!["B`@("`@("`@:68@
M*"%I<U]A<G)A>2@D=&EM92DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*("`@("`@("`D=&UP,2`](&YE=R!$871E7U-P86X["B`@
M("`@("`@:68@*"$D=&UP,2T^<V5T1G)O;5-E8V]N9',H0&%R<F%Y7W!O<"@D
M=&EM92DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"B`@("`@("`@)'1M<#(@/2!N97<@1&%T95]3<&%N.PH@("`@("`@(&EF("@A
M)'1M<#(M/G-E=$9R;VU-:6YU=&5S*$!A<G)A>5]P;W`H)'1I;64I*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@("1T
M;7`Q+3YA9&0H)'1M<#(I.PH@("`@("`@(&EF("@A)'1M<#(M/G-E=$9R;VU(
M;W5R<RA`87)R87E?<&]P*"1T:6UE*2DI('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*("`@("`@("`D=&UP,2T^861D*"1T;7`R*3L*
M("`@("`@("!I9B`H(21T;7`R+3YS971&<F]M1&%Y<RA`87)R87E?<&]P*"1T
M:6UE*2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M("`@("`@("`D=&UP,2T^861D*"1T;7`R*3L*("`@("`@("!R971U<FX@)'1H
M:7,M/F-O<'DH)'1M<#$I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H
M92!T:6UE('-P86X@9G)O;2!A('-T<FEN9R!B87-E9"!O;B!A;B!I;G!U="!F
M;W)M870N"B`@("`@*@H@("`@("H@4V5T('1H92!T:6UE('-P86X@9G)O;2!A
M('-T<FEN9R!B87-E9"!O;B!A;B!I;G!U="!F;W)M870N(%1H:7,@:7,*("`@
M("`J('-O;64@;&EK92!A(&UI>"!O9B!F;W)M870H*2!M971H;V0@86YD('-S
M8V%N9B@I(%!(4"!F=6YC=&EO;BX@5&AE"B`@("`@*B!E<G)O<B!C:&5C:VEN
M9R!A;F0@=F%L:61A=&EO;B!O9B!T:&ES(&9U;F-T:6]N(&ES('9E<GD@<')I
M;6ET:79E+`H@("`@("H@<V\@>6]U('-H;W5L9"!B92!C87)E9G5L;"!W:&5N
M('5S:6YG(&ET('=I=&@@=6YK;F]W;B`D=&EM92!S=')I;F=S+@H@("`@("H@
M5VET:"!T:&ES(&UE=&AO9"!Y;W4@87)E(&%S<VEG;FEN9R!D87DL(&AO=7(L
M(&UI;G5T92!A;F0@<V5C;VYD"B`@("`@*B!V86QU97,L(&%N9"!T:&4@;&%S
M="!V86QU97,@87)E('5S960N(%1H:7,@;65A;G,@=&AA="!I9B!Y;W4@=7-E
M"B`@("`@*B!S;VUE=&AI;F<@;&EK92!S971&<F]M4W1R:6YG*"<Q,"P@,C`G
M+"`G)4@L("5H)RD@>6]U<B!T:6UE('-P86X*("`@("`J('=O=6QD(&)E(#(P
M(&AO=7)S(&QO;F<N($%L;'=A>7,@<F5M96UB97(@=&AA="!T:&ES(&UE=&AO
M9"!S970*("`@("`J(#QB/F%L;#PO8CX@=&AE('9A;'5E<RP@<V\@:68@>6]U
M(&AA9"!A("1T:6UE('-P86X@,S`@;6EN=71E<R!L;VYG"B`@("`@*B!A;F0@
M>6]U(&UA:V4@)'1I;64M/G-E=$9R;VU3=')I;F<H)S(P(&AO=7)S)RP@)R5(
M(&AO=7)S)RDL("1T:6UE"B`@("`@*B!S<&%N('=O=6QD(&)E(#(P(&AO=7)S
M(&QO;F<@*&%N9"!N;W0@,C`@:&]U<G,@86YD(#,P(&UI;G5T97,I+@H@("`@
M("H@26YP=70@9F]R;6%T(&]P=&EO;G,Z/&)R/@H@("`@("H@(#QC;V1E/B5#
M/"]C;V1E/B!$87ES('=I=&@@=&EM92P@<V%M92!A<R`B)40L("5(.B5-.B53
M(BX\8G(^"B`@("`@*B`@/&-O9&4^)60\+V-O9&4^(%1O=&%L(&1A>7,@87,@
M82!F;&]A="!N=6UB97(*("`@("`J("`@("`@("`@("`@("`@("`@*#(@9&%Y
M<RP@,3(@:&]U<G,@/2`R+C4@9&%Y<RDN/&)R/@H@("`@("H@(#QC;V1E/B5$
M/"]C;V1E/B!$87ES(&%S(&$@9&5C:6UA;"!N=6UB97(N/&)R/@H@("`@("H@
M(#QC;V1E/B5E/"]C;V1E/B!4;W1A;"!H;W5R<R!A<R!A(&9L;V%T(&YU;6)E
M<@H@("`@("H@("`@("`@("`@("`@("`@("`H,2!D87DL(#(@:&]U<G,L(#,P
M(&UI;G5T97,@/2`R-BXU(&AO=7)S*2X\8G(^"B`@("`@*B`@/&-O9&4^)68\
M+V-O9&4^(%1O=&%L(&UI;G5T97,@87,@82!F;&]A="!N=6UB97(*("`@("`J
M("`@("`@("`@("`@("`@("`@*#(@;6EN=71E<RP@,S`@<V5C;VYD<R`](#(N
M-2!M:6YU=&5S*2X\8G(^"B`@("`@*B`@/&-O9&4^)6<\+V-O9&4^(%1O=&%L
M('-E8V]N9',@87,@82!D96-I;6%L(&YU;6)E<@H@("`@("H@("`@("`@("`@
M("`@("`@("`H,B!M:6YU=&5S+"`S,"!S96-O;F1S(#T@.3`@<V5C;VYD<RDN
M/&)R/@H@("`@("H@(#QC;V1E/B5H/"]C;V1E/B!(;W5R<R!A<R!D96-I;6%L
M(&YU;6)E<BX\8G(^"B`@("`@*B`@/&-O9&4^)4@\+V-O9&4^($AO=7)S(&%S
M(&1E8VEM86P@;G5M8F5R(&QI;6ET960@=&\@,B!D:6=I=',N/&)R/@H@("`@
M("H@(#QC;V1E/B5M/"]C;V1E/B!-:6YU=&5S(&%S(&$@9&5C:6UA;"!N=6UB
M97(N/&)R/@H@("`@("H@(#QC;V1E/B5-/"]C;V1E/B!-:6YU=&5S(&%S(&$@
M9&5C:6UA;"!N=6UB97(@;&EM:71E9"!T;R`R(&1I9VET<RX\8G(^"B`@("`@
M*B`@/&-O9&4^)6X\+V-O9&4^($YE=VQI;F4@8VAA<F%C=&5R("A<;BDN/&)R
M/@H@("`@("H@(#QC;V1E/B5P/"]C;V1E/B!%:71H97(@)V%M)R!O<B`G<&TG
M(&1E<&5N9&EN9R!O;B!T:&4@=&EM92X@268@)W!M)PH@("`@("H@("`@("`@
M("`@("`@("`@("!I<R!D971E8W1E9"!I="!A9&1S(#$R(&AO=7)S('1O('1H
M92!R97-U;'1I;F<@=&EM90H@("`@("H@("`@("`@("`@("`@("`@("!S<&%N
M("AW:71H;W5T(&%N>2!C:&5C:W,I+B!4:&ES(&ES(&-A<V4*("`@("`J("`@
M("`@("`@("`@("`@("`@:6YS96YS:71I=F4N/&)R/@H@("`@("H@(#QC;V1E
M/B5R/"]C;V1E/B!4:6UE(&EN(&%M+W!M(&YO=&%T:6]N+"!S86UE(&%S("(E
M2#HE33HE4R`E<"(N/&)R/@H@("`@("H@(#QC;V1E/B52/"]C;V1E/B!4:6UE
M(&EN(#(T+6AO=7(@;F]T871I;VXL('-A;64@87,@(B5(.B5-(BX\8G(^"B`@
M("`@*B`@/&-O9&4^)7,\+V-O9&4^(%-E8V]N9',@87,@82!D96-I;6%L(&YU
M;6)E<BX\8G(^"B`@("`@*B`@/&-O9&4^)5,\+V-O9&4^(%-E8V]N9',@87,@
M82!D96-I;6%L(&YU;6)E<B!L:6UI=&5D('1O(#(@9&EG:71S+CQB<CX*("`@
M("`J("`\8V]D93XE=#PO8V]D93X@5&%B(&-H87)A8W1E<B`H7'0I+CQB<CX*
M("`@("`J("`\8V]D93XE5#PO8V]D93X@0W5R<F5N="!T:6UE(&5Q=6EV86QE
M;G0L('-A;64@87,@(B5(.B5-.B53(BX\8G(^"B`@("`@*B`@/&-O9&4^)24\
M+V-O9&4^($QI=&5R86P@)R4G+CQB<CX*("`@("`J"B`@("`@*B!`<&%R86T@
M('-T<FEN9R`D=&EM92`@(%-T<FEN9R!F<F]M('=H97)E('1O(&=E="!T:&4@
M=&EM92!S<&%N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&EN9F]R
M;6%T:6]N+@H@("`@("H@0'!A<F%M("!S=')I;F<@)&9O<FUA="!&;W)M870@
M<W1R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@(%1R=64@;VX@
M<W5C8V5S<RX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!S971&<F]M4W1R:6YG*"1T:6UE+"`D9F]R;6%T(#T@
M;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D9F]R;6%T*2D@>PH@
M("`@("`@("`@("`D9F]R;6%T(#T@)$=,3T)!3%-;)U]$051%7U-004Y?24Y0
M551?1D]234%4)UT["B`@("`@("`@?0H@("`@("`@("\O($EF(&9O<FUA="!I
M<R!A('-T<FEN9RP@:70@<&%R<V5S('1H92!S=')I;F<@9F]R;6%T+@H@("`@
M("`@(&EF("AI<U]S=')I;F<H)&9O<FUA="DI('L*("`@("`@("`@("`@)'-T
M<B`]("<G.PH@("`@("`@("`@("`D=F%R<R`](&%R<F%Y*"D["B`@("`@("`@
M("`@("1P;2`]("=A;2<["B`@("`@("`@("`@("1D87D@/2`D:&]U<B`]("1M
M:6YU=&4@/2`D<V5C;VYD(#T@,#L*("`@("`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@<W1R;&5N*"1F;W)M870I.R`D:2LK*2!["B`@("`@("`@("`@("`@
M("`D8VAA<B`]("1F;W)M871[)&E].PH@("`@("`@("`@("`@("`@:68@*"1C
M:&%R(#T]("<E)RD@>PH@("`@("`@("`@("`@("`@("`@("1N97AT8VAA<B`]
M("1F;W)M871[*RLD:7T["B`@("`@("`@("`@("`@("`@("`@<W=I=&-H("@D
M;F5X=&-H87(I('L*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G8R<Z
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1R("X]("<E9"P@)60Z
M)60Z)60G.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?<'5S
M:"@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%R<RP@)V1A
M>2<L("=H;W5R)RP@)VUI;G5T92<L("=S96-O;F0G*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@
M("!C87-E("=#)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S='(@
M+CT@)R5D+"`E,F0Z)3)D.B4R9"<["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>5]P=7-H*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1V87)S+"`G9&%Y)RP@)VAO=7(G+"`G;6EN=71E)RP@)W-E8V]N9"<I
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)V0G.@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'-T<B`N/2`G)68G.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87E?<'5S:"@D=F%R<RP@)V1A>2<I.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@
M(&-A<V4@)T0G.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T<B`N
M/2`G)60G.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?<'5S
M:"@D=F%R<RP@)V1A>2<I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)V4G.@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'-T<B`N/2`G)68G.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87E?<'5S:"@D=F%R<RP@)VAO=7(G
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@("`@("`@("!C87-E("=F)SH*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1S='(@+CT@)R5F)SL*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y7W!U<V@H)'9A<G,L("=M:6YU=&4G*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@
M("`@("!C87-E("=G)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S
M='(@+CT@)R5F)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M7W!U<V@H)'9A<G,L("=S96-O;F0G*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E("=H
M)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S='(@+CT@)R5D)SL*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H)'9A<G,L
M("=H;W5R)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G2"<Z"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<W1R("X]("<E,F0G.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87E?<'5S:"@D=F%R<RP@)VAO=7(G*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@("`@("`@("!C87-E("=M)SH*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1S='(@+CT@)R5D)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y7W!U<V@H)'9A<G,L("=M:6YU=&4G*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C
M87-E("=-)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S='(@+CT@
M)R4R9"<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]P=7-H
M*"1V87)S+"`G;6EN=71E)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G;B<Z"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1R("X](")<;B(["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M("`@("`@("`@8V%S92`G<"<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<W1R("X]("<E,G,G.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87E?<'5S:"@D=F%R<RP@)W!M)RD["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G
M<B<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1R("X]("<E,F0Z
M)3)D.B4R9"`E,G,G.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87E?<'5S:"@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%R
M<RP@)VAO=7(G+"`G;6EN=71E)RP@)W-E8V]N9"<L("=P;2<I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@
M("`@("`@(&-A<V4@)U(G.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'-T<B`N/2`G)3)D.B4R9"<["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>5]P=7-H*"1V87)S+"`G:&]U<B<L("=M:6YU=&4G*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M("`@("`@("!C87-E("=S)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1S='(@+CT@)R5D)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y7W!U<V@H)'9A<G,L("=S96-O;F0G*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E
M("=3)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S='(@+CT@)R4R
M9"<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]P=7-H*"1V
M87)S+"`G<V5C;VYD)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G="<Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<W1R("X](")<="(["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@
M("`@("`@8V%S92`G5"<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<W1R("X]("<E,F0Z)3)D.B4R9"<["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>5]P=7-H*"1V87)S+"`G:&]U<B<L("=M:6YU=&4G+"`G<V5C
M;VYD)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@("`@("`@("`@8V%S92`G)2<Z"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<W1R("X]("(E(CL*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!D969A
M=6QT.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T<B`N/2`D8VAA
M<B`N("1N97AT8VAA<CL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1S='(@+CT@
M)&-H87(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'9A;',@/2!S<V-A;F8H)'1I;64L("1S='(I.PH@("`@("`@("`@
M("!F;W)E86-H("@D=F%L<R!A<R`D:2`]/B`D=F%L*2!["B`@("`@("`@("`@
M("`@("!I9B`H:7-?;G5L;"@D=F%L*2D@>PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("0D=F%R<ULD:5T@/2`D=F%L.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&EF("AS=')C87-E8VUP*"1P;2P@)W!M)RD@/3T@,"D@>PH@("`@("`@
M("`@("`@("`@)&AO=7(@*ST@,3(["B`@("`@("`@("`@('T@96QS96EF("AS
M=')C87-E8VUP*"1P;2P@)V%M)RD@(3T@,"D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES
M+3YS971&<F]M07)R87DH87)R87DH)&1A>2P@)&AO=7(L("1M:6YU=&4L("1S
M96-O;F0I*3L*("`@("`@("`O+R!)9B!F;W)M870@:7,@82!I;G1E9V5R+"!I
M="!U<V5S(&$@<')E9&5F:6YE9"!F;W)M870*("`@("`@("`O+R!D971E8W1I
M;VX@;65T:&]D+@H@("`@("`@('T@96QS96EF("AI<U]I;G1E9V5R*"1F;W)M
M870I*2!["B`@("`@("`@("`@('-W:71C:"`H)&9O<FUA="D@>PH@("`@("`@
M("`@("`@("`@8V%S92!$051%7U-004Y?24Y0551?1D]234%47TY.4U8Z"B`@
M("`@("`@("`@("`@("`@("`@)'1I;64@/2!P<F5G7W-P;&ET*"<O7$0K+R<L
M("1T:6UE*3L*("`@("`@("`@("`@("`@("`@("!S=VET8V@@*&-O=6YT*"1T
M:6UE*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(#`Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-E=$9R;VU!
M<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@P
M+"`P+"`P+"`P*2D["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@,3H*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<V5T
M1G)O;4%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*#`L("1T:6UE6S!=+"`P+"`P*2D["B`@("`@("`@("`@("`@("`@("`@
M("`@(&-A<V4@,CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<V5T1G)O;4%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*#`L("1T:6UE6S!=+"`D=&EM95LQ72P@,"DI.PH@
M("`@("`@("`@("`@("`@("`@("`@("!C87-E(#,Z"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-E=$9R;VU!<G)A>2@*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@P+"`D=&EM95LP
M72P@)'1I;65;,5TL("1T:6UE6S)=*2D["B`@("`@("`@("`@("`@("`@("`@
M("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G-E=$9R;VU!<G)A>2@D=&EM92D["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E="!T:&4@=&EM92!S<&%N(&9R;VT@82!T;W1A;"!N
M=6UB97(@;V8@<V5C;VYD<RX*("`@("`J"B`@("`@*B!`<&%R86T@(&EN="`@
M)'-E8V]N9',@5&]T86P@;G5M8F5R(&]F('-E8V]N9',N"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L(%1R=64@;VX@<W5C8V5S<RX*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S971&<F]M
M4V5C;VYD<R@D<V5C;VYD<RD*("`@('L*("`@("`@("!I9B`H)'-E8V]N9',@
M/"`P*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@
M("`@("`@)'-E8R`@/2!I;G1V86PH)'-E8V]N9',I.PH@("`@("`@("1M:6X@
M(#T@9FQO;W(H)'-E8R`O(#8P*3L*("`@("`@("`D:&]U<B`](&9L;V]R*"1M
M:6X@+R`V,"D["B`@("`@("`@)&1A>2`@/2!I;G1V86PH9FQO;W(H)&AO=7(@
M+R`R-"DI.PH@("`@("`@("1T:&ES+3YS96-O;F0@/2`D<V5C("4@-C`["B`@
M("`@("`@)'1H:7,M/FUI;G5T92`]("1M:6X@)2`V,#L*("`@("`@("`D=&AI
M<RT^:&]U<B`@(#T@)&AO=7(@)2`R-#L*("`@("`@("`D=&AI<RT^9&%Y("`@
M(#T@)&1A>3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E="!T:&4@=&EM92!S<&%N(&9R;VT@82!T;W1A;"!N=6UB97(@
M;V8@;6EN=71E<RX*("`@("`J"B`@("`@*B!`<&%R86T@(&9L;V%T("1M:6YU
M=&5S(%1O=&%L(&YU;6)E<B!O9B!M:6YU=&5S+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;"`@5')U92!O;B!S=6-C97-S+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$9R;VU-:6YU
M=&5S*"1M:6YU=&5S*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<V5T
M1G)O;5-E8V]N9',H<F]U;F0H)&UI;G5T97,@*B`V,"DI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T('1H92!T:6UE('-P86X@9G)O;2!A('1O=&%L(&YU
M;6)E<B!O9B!H;W5R<RX*("`@("`J"B`@("`@*B!`<&%R86T@(&9L;V%T("1H
M;W5R<R!4;W1A;"!N=6UB97(@;V8@:&]U<G,N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L("!4<G5E(&]N('-U8V-E<W,N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1G)O;4AO=7)S
M*"1H;W5R<RD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G-E=$9R;VU3
M96-O;F1S*')O=6YD*"1H;W5R<R`J(#,V,#`I*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E="!T:&4@=&EM92!S<&%N(&9R;VT@82!T;W1A;"!N=6UB97(@
M;V8@9&%Y<RX*("`@("`J"B`@("`@*B!`<&%R86T@(&9L;V%T("1D87ES(%1O
M=&%L(&YU;6)E<B!O9B!D87ES+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;"`@5')U92!O;B!S=6-C97-S+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$9R;VU$87ES*"1D87ES*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<V5T1G)O;5-E8V]N9',H<F]U
M;F0H)&1A>7,@*B`X-C0P,"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T
M('1H92!S<&%N(&9R;VT@=&AE(&5L87!S960@=&EM92!B971W965N('1W;R!D
M871E<RX*("`@("`J"B`@("`@*B!3970@=&AE('-P86X@9G)O;2!T:&4@96QA
M<'-E9"!T:6UE(&)E='=E96X@='=O(&1A=&5S+B!4:&4@=&EM92!S<&%N"B`@
M("`@*B!I<R!A;&QW87ES('!O<VET:79E+"!S;R!T:&4@9&%T92=S(&]R9&5R
M(&ES(&YO="!I;7!O<G1A;G0N"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE
M8W0@1&%T92`D9&%T93$@1FER<W0@1&%T92X*("`@("`J($!P87)A;2`@;V)J
M96-T($1A=&4@)&1A=&4R(%-E8V]N9"!$871E+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;"`@5')U92!O;B!S=6-C97-S+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$9R;VU$871E
M1&EF9B@D9&%T93$L("1D871E,BD*("`@('L*("`@("`@("!I9B`H(6ES7V$H
M)&1A=&4Q+"`G9&%T92<I(&]R("%I<U]A*"1D871E,BP@)V1A=&4G*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@("1D
M871E,2T^=&]55$,H*3L*("`@("`@("`D9&%T93(M/G1O551#*"D["B`@("`@
M("`@:68@*"1D871E,2T^869T97(H)&1A=&4R*2D@>PH@("`@("`@("`@("!L
M:7-T*"1D871E,2P@)&1A=&4R*2`](&%R<F%Y*"1D871E,BP@)&1A=&4Q*3L*
M("`@("`@("!]"B`@("`@("`@)&1A>7,@/2!$871E7T-A;&,Z.F1A=&5$:69F
M*`H@("`@("`@("`@("`D9&%T93$M/F=E=$1A>2@I+"`D9&%T93$M/F=E=$UO
M;G1H*"DL("1D871E,2T^9V5T665A<B@I+`H@("`@("`@("`@("`D9&%T93(M
M/F=E=$1A>2@I+"`D9&%T93(M/F=E=$UO;G1H*"DL("1D871E,BT^9V5T665A
M<B@I"B`@("`@("`@*3L*("`@("`@("`D:&]U<G,@/2`D9&%T93(M/F=E=$AO
M=7(H*2`M("1D871E,2T^9V5T2&]U<B@I.PH@("`@("`@("1M:6YS("`]("1D
M871E,BT^9V5T36EN=71E*"D@+2`D9&%T93$M/F=E=$UI;G5T92@I.PH@("`@
M("`@("1S96-S("`]("1D871E,BT^9V5T4V5C;VYD*"D@+2`D9&%T93$M/F=E
M=%-E8V]N9"@I.PH@("`@("`@("1T:&ES+3YS971&<F]M4V5C;VYD<R@*("`@
M("`@("`@("`@)&1A>7,@*B`X-C0P,"`K("1H;W5R<R`J(#,V,#`@*R`D;6EN
M<R`J(#8P("L@)'-E8W,*("`@("`@("`I.PH@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!T:6UE('-P86X@9G)O
M;2!A;F]T:&5R('1I;64@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2`@
M;V)J96-T($1A=&5?4W!A;B`D=&EM92!3;W5R8V4@=&EM92!S<&%N(&]B:F5C
M="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@("!4<G5E(&]N('-U8V-E
M<W,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@8V]P>2@D=&EM92D*("`@('L*("`@("`@("!I9B`H:7-?82@D
M=&EM92P@)V1A=&5?<W!A;B<I*2!["B`@("`@("`@("`@("1T:&ES+3YS96-O
M;F0@/2`D=&EM92T^<V5C;VYD.PH@("`@("`@("`@("`D=&AI<RT^;6EN=71E
M(#T@)'1I;64M/FUI;G5T93L*("`@("`@("`@("`@)'1H:7,M/FAO=7(@("`]
M("1T:6UE+3YH;W5R.PH@("`@("`@("`@("`D=&AI<RT^9&%Y("`@(#T@)'1I
M;64M/F1A>3L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J(%1I;64@<W!A;B!P<F5T='D@<')I;G1I;F<@
M*'-I;6EL87(@=&\@1&%T93HZ9F]R;6%T*"DI+@H@("`@("H*("`@("`J($9O
M<FUA=',@=&AE('1I;64@<W!A;B!I;B!T:&4@9VEV96X@9F]R;6%T+"!S:6UI
M;&%R('1O"B`@("`@*B!S=')F=&EM92@I(&%N9"!$871E.CIF;W)M870H*2X\
M8G(^"B`@("`@*B`\8G(^"B`@("`@*B!&;W)M871T:6YG(&]P=&EO;G,Z/&)R
M/@H@("`@("H@(#QC;V1E/B5#/"]C;V1E/B!$87ES('=I=&@@=&EM92P@<V%M
M92!A<R`B)40L("5(.B5-.B53(BX\8G(^"B`@("`@*B`@/&-O9&4^)60\+V-O
M9&4^(%1O=&%L(&1A>7,@87,@82!F;&]A="!N=6UB97(*("`@("`J("`@("`@
M("`@("`@("`@("`@*#(@9&%Y<RP@,3(@:&]U<G,@/2`R+C4@9&%Y<RDN/&)R
M/@H@("`@("H@(#QC;V1E/B5$/"]C;V1E/B!$87ES(&%S(&$@9&5C:6UA;"!N
M=6UB97(N/&)R/@H@("`@("H@(#QC;V1E/B5E/"]C;V1E/B!4;W1A;"!H;W5R
M<R!A<R!A(&9L;V%T(&YU;6)E<@H@("`@("H@("`@("`@("`@("`@("`@("`H
M,2!D87DL(#(@:&]U<G,L(#,P(&UI;G5T97,@/2`R-BXU(&AO=7)S*2X\8G(^
M"B`@("`@*B`@/&-O9&4^)44\+V-O9&4^(%1O=&%L(&AO=7)S(&%S(&$@9&5C
M:6UA;"!N=6UB97(*("`@("`J("`@("`@("`@("`@("`@("`@*#$@9&%Y+"`R
M(&AO=7)S+"`T,"!M:6YU=&5S(#T@,C8@:&]U<G,I+CQB<CX*("`@("`J("`\
M8V]D93XE9CPO8V]D93X@5&]T86P@;6EN=71E<R!A<R!A(&9L;V%T(&YU;6)E
M<@H@("`@("H@("`@("`@("`@("`@("`@("`H,B!M:6YU=&5S+"`S,"!S96-O
M;F1S(#T@,BXU(&UI;G5T97,I+CQB<CX*("`@("`J("`\8V]D93XE1CPO8V]D
M93X@5&]T86P@;6EN=71E<R!A<R!A(&1E8VEM86P@;G5M8F5R"B`@("`@*B`@
M("`@("`@("`@("`@("`@("@Q(&AO=7(L(#(@;6EN=71E<RP@-#`@<V5C;VYD
M<R`](#8R(&UI;G5T97,I+CQB<CX*("`@("`J("`\8V]D93XE9SPO8V]D93X@
M5&]T86P@<V5C;VYD<R!A<R!A(&1E8VEM86P@;G5M8F5R"B`@("`@*B`@("`@
M("`@("`@("`@("`@("@R(&UI;G5T97,L(#,P('-E8V]N9',@/2`Y,"!S96-O
M;F1S*2X\8G(^"B`@("`@*B`@/&-O9&4^)6@\+V-O9&4^($AO=7)S(&%S(&1E
M8VEM86P@;G5M8F5R("@P('1O(#(S*2X\8G(^"B`@("`@*B`@/&-O9&4^)4@\
M+V-O9&4^($AO=7)S(&%S(&1E8VEM86P@;G5M8F5R("@P,"!T;R`R,RDN/&)R
M/@H@("`@("H@(#QC;V1E/B5I/"]C;V1E/B!(;W5R<R!A<R!D96-I;6%L(&YU
M;6)E<B!O;B`Q,BUH;W5R(&-L;V-K"B`@("`@*B`@("`@("`@("`@("`@("`@
M("@Q('1O(#$R*2X\8G(^"B`@("`@*B`@/&-O9&4^)4D\+V-O9&4^($AO=7)S
M(&%S(&1E8VEM86P@;G5M8F5R(&]N(#$R+6AO=7(@8VQO8VL*("`@("`J("`@
M("`@("`@("`@("`@("`@*#`Q('1O(#$R*2X\8G(^"B`@("`@*B`@/&-O9&4^
M)6T\+V-O9&4^($UI;G5T97,@87,@82!D96-I;6%L(&YU;6)E<B`H,"!T;R`U
M.2DN/&)R/@H@("`@("H@(#QC;V1E/B5-/"]C;V1E/B!-:6YU=&5S(&%S(&$@
M9&5C:6UA;"!N=6UB97(@*#`P('1O(#4Y*2X\8G(^"B`@("`@*B`@/&-O9&4^
M)6X\+V-O9&4^($YE=VQI;F4@8VAA<F%C=&5R("A<;BDN/&)R/@H@("`@("H@
M(#QC;V1E/B5P/"]C;V1E/B!%:71H97(@)V%M)R!O<B`G<&TG(&1E<&5N9&EN
M9R!O;B!T:&4@=&EM92X\8G(^"B`@("`@*B`@/&-O9&4^)5`\+V-O9&4^($5I
M=&AE<B`G04TG(&]R("=032<@9&5P96YD:6YG(&]N('1H92!T:6UE+CQB<CX*
M("`@("`J("`\8V]D93XE<CPO8V]D93X@5&EM92!I;B!A;2]P;2!N;W1A=&EO
M;BP@<V%M92!A<R`B)4DZ)4TZ)5,@)7`B+CQB<CX*("`@("`J("`\8V]D93XE
M4CPO8V]D93X@5&EM92!I;B`R-"UH;W5R(&YO=&%T:6]N+"!S86UE(&%S("(E
M2#HE32(N/&)R/@H@("`@("H@(#QC;V1E/B5S/"]C;V1E/B!396-O;F1S(&%S
M(&$@9&5C:6UA;"!N=6UB97(@*#`@=&\@-3DI+CQB<CX*("`@("`J("`\8V]D
M93XE4SPO8V]D93X@4V5C;VYD<R!A<R!A(&1E8VEM86P@;G5M8F5R("@P,"!T
M;R`U.2DN/&)R/@H@("`@("H@(#QC;V1E/B5T/"]C;V1E/B!486(@8VAA<F%C
M=&5R("A<="DN/&)R/@H@("`@("H@(#QC;V1E/B54/"]C;V1E/B!#=7)R96YT
M('1I;64@97%U:79A;&5N="P@<V%M92!A<R`B)4@Z)4TZ)5,B+CQB<CX*("`@
M("`J("`\8V]D93XE)3PO8V]D93X@3&ET97)A;"`G)2<N/&)R/@H@("`@("H*
M("`@("`J($!P87)A;2`@<W1R:6YG("1F;W)M870@5&AE(&9O<FUA="!S=')I
M;F<@9F]R(')E='5R;F5D('1I;64@<W!A;BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R!4:&4@=&EM92!S<&%N(&EN('-P96-I9FEE9"!F;W)M870N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@9F]R;6%T*"1F;W)M870@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF
M("AI<U]N=6QL*"1F;W)M870I*2!["B`@("`@("`@("`@("1F;W)M870@/2`D
M1TQ/0D%,4ULG7T1!5$5?4U!!3E]&3U)-050G73L*("`@("`@("!]"B`@("`@
M("`@)&]U='!U="`]("<G.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-T
M<FQE;B@D9F]R;6%T*3L@)&DK*RD@>PH@("`@("`@("`@("`D8VAA<B`]("1F
M;W)M871[)&E].PH@("`@("`@("`@("!I9B`H)&-H87(@/3T@)R4G*2!["B`@
M("`@("`@("`@("`@("`D;F5X=&-H87(@/2`D9F]R;6%T>RLK)&E].PH@("`@
M("`@("`@("`@("`@<W=I=&-H("@D;F5X=&-H87(I('L*("`@("`@("`@("`@
M("`@("`@("!C87-E("=#)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U
M='!U="`N/2!S<')I;G1F*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)R5D+"`E,#)D.B4P,F0Z)3`R9"<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^9&%Y+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/FAO=7(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^;6EN=71E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G-E8V]N9`H@("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E
M("=D)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI
M<RT^=&]$87ES*"D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@("`@(&-A<V4@)T0G.@H@("`@("`@("`@("`@("`@
M("`@("`@("`D;W5T<'5T("X]("1T:&ES+3YD87D["B`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)V4G
M.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]("1T:&ES+3YT
M;TAO=7)S*"D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)T4G.@H@("`@("`@("`@("`@("`@("`@
M("`@("`D;W5T<'5T("X](&9L;V]R*"1T:&ES+3YT;TAO=7)S*"DI.PH@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@
M("!C87-E("=F)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N
M/2`D=&AI<RT^=&]-:6YU=&5S*"D["B`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)T8G.@H@("`@("`@
M("`@("`@("`@("`@("`@("`D;W5T<'5T("X](&9L;V]R*"1T:&ES+3YT;TUI
M;G5T97,H*2D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)V<G.@H@("`@("`@("`@("`@("`@("`@
M("`@("`D;W5T<'5T("X]("1T:&ES+3YT;U-E8V]N9',H*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S
M92`G:"<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@)'1H
M:7,M/FAO=7(["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)T@G.@H@("`@("`@("`@("`@("`@("`@
M("`@("`D;W5T<'5T("X]('-P<FEN=&8H)R4P,F0G+"`D=&AI<RT^:&]U<BD[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@("`@(&-A<V4@)VDG.@H@("`@("`@("`@("`@("`@("`@("`@("`D:&]U
M<B`]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`H)'1H:7,M/FAO=7(@
M*R`Q*2`^(#$R(#\*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YH;W5R("T@,3(@.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/FAO=7(["B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@
M*"1H;W5R(#T](#`I(#\@,3(@.B`D:&]U<CL*("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`G22<Z"B`@
M("`@("`@("`@("`@("`@("`@("`@("1H;W5R(#T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("@D=&AI<RT^:&]U<B`K(#$I(#X@,3(@/PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FAO=7(@+2`Q,B`Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^:&]U<CL*("`@("`@("`@
M("`@("`@("`@("`@("`@)&]U='!U="`N/2!S<')I;G1F*"<E,#)D)RP@)&AO
M=7(]/3`@/R`Q,B`Z("1H;W5R*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`G;2<Z"B`@("`@("`@
M("`@("`@("`@("`@("`@("1O=71P=70@+CT@)'1H:7,M/FUI;G5T93L*("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@
M("`@8V%S92`G32<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@
M+CT@<W!R:6YT9B@G)3`R9"<L)'1H:7,M/FUI;G5T92D["B`@("`@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@
M)VXG.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X](")<;B([
M"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@("`@(&-A<V4@)W`G.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T
M<'5T("X]("1T:&ES+3YH;W5R(#X](#$R(#\@)W!M)R`Z("=A;2<["B`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@
M(&-A<V4@)U`G.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]
M("1T:&ES+3YH;W5R(#X](#$R(#\@)U!-)R`Z("=!32<["B`@("`@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@
M)W(G.@H@("`@("`@("`@("`@("`@("`@("`@("`D:&]U<B`]"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`H)'1H:7,M/FAO=7(@*R`Q*2`^(#$R(#\*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YH;W5R("T@,3(@
M.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FAO=7(["B`@
M("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@<W!R:6YT9B@*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("<E,#)D.B4P,F0Z)3`R9"`E<R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:&]U<CT],"`_("`Q,B`Z
M("1H;W5R+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUI
M;G5T92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS96-O
M;F0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^:&]U<B`^
M/2`Q,B`_("=P;2<@.B`G86TG"B`@("`@("`@("`@("`@("`@("`@("`@("D[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@("`@(&-A<V4@)U(G.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T
M<'5T("X]('-P<FEN=&8H"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M)3`R9#HE,#)D)RP@)'1H:7,M/FAO=7(L("1T:&ES+3YM:6YU=&4*("`@("`@
M("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`G<R<Z"B`@("`@("`@
M("`@("`@("`@("`@("`@("1O=71P=70@+CT@)'1H:7,M/G-E8V]N9#L*("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@
M("`@8V%S92`G4R<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@
M+CT@<W!R:6YT9B@G)3`R9"<L("1T:&ES+3YS96-O;F0I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E
M("=T)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`B7'0B
M.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@("`@("!C87-E("=4)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U
M='!U="`N/2!S<')I;G1F*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)R4P,F0Z)3`R9#HE,#)D)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YH;W5R+"`D=&AI<RT^;6EN=71E+"`D=&AI<RT^<V5C;VYD"B`@
M("`@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)R4G.@H@("`@
M("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]("(E(CL*("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@9&5F
M875L=#H*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D8VAA
M<B`N("1N97AT8VAA<CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1O=71P=70@+CT@)&-H87(["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1O=71P=70[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T('1I;64@<W!A;B!T;R!S
M96-O;F1S+@H@("`@("H*("`@("`J($!R971U<FX@:6YT(%1I;64@<W!A;B!A
M<R!A;B!I;G1E9V5R(&YU;6)E<B!O9B!S96-O;F1S+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('1O4V5C;VYD
M<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YD87D@*B`X-C0P,"`K
M("1T:&ES+3YH;W5R("H@,S8P,"`K"B`@("`@("`@("`@("1T:&ES+3YM:6YU
M=&4@*B`V,"`K("1T:&ES+3YS96-O;F0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#;VYV97)T('1I;64@<W!A;B!T;R!M:6YU=&5S+@H@("`@("H*("`@("`J
M($!R971U<FX@9FQO870@5&EM92!S<&%N(&%S(&$@9&5C:6UA;"!N=6UB97(@
M;V8@;6EN=71E<RX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!T;TUI;G5T97,H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^9&%Y("H@,30T,"`K("1T:&ES+3YH;W5R("H@-C`@*R`D
M=&AI<RT^;6EN=71E("L*("`@("`@("`@("`@)'1H:7,M/G-E8V]N9"`O(#8P
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R="!T:6UE('-P86X@=&\@
M:&]U<G,N"B`@("`@*@H@("`@("H@0')E='5R;B!F;&]A="!4:6UE('-P86X@
M87,@82!D96-I;6%L(&YU;6)E<B!O9B!H;W5R<RX*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!T;TAO=7)S*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F1A>2`J(#(T("L@)'1H:7,M
M/FAO=7(@*R`D=&AI<RT^;6EN=71E("\@-C`@*PH@("`@("`@("`@("`D=&AI
M<RT^<V5C;VYD("\@,S8P,#L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E
M<G0@=&EM92!S<&%N('1O(&1A>7,N"B`@("`@*@H@("`@("H@0')E='5R;B!F
M;&]A="!4:6UE('-P86X@87,@82!D96-I;6%L(&YU;6)E<B!O9B!D87ES+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N('1O1&%Y<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YD87D@
M*R`D=&AI<RT^:&]U<B`O(#(T("L@)'1H:7,M/FUI;G5T92`O(#$T-#`@*PH@
M("`@("`@("`@("`D=&AI<RT^<V5C;VYD("\@.#8T,#`["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!9&1S(&$@=&EM92!S<&%N+@H@("`@("H*("`@("`J($!P
M87)A;2`@;V)J96-T($1A=&5?4W!A;B`D=&EM92!4:6UE('-P86X@=&\@861D
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%D9"@D=&EM92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/G-E=$9R;VU396-O;F1S*`H@("`@("`@("`@("`D=&AI<RT^=&]396-O;F1S
M*"D@*R`D=&EM92T^=&]396-O;F1S*"D*("`@("`@("`I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4W5B=')A8W1S(&$@=&EM92!S<&%N+@H@("`@("H*("`@
M("`J(%-U8G1R86-T<R!A('1I;64@<W!A;BX@268@=&AE('1I;64@<W!A;B!T
M;R!S=6)T<F%C="!I<R!L87)G97(*("`@("`J('1H86X@=&AE(&]R:6=I;F%L
M+"!T:&4@<F5S=6QT(&ES('IE<F\@*'1H97)E)W,@;F\@<V5N<V4@:6X*("`@
M("`J(&YE9V%T:79E('1I;64@<W!A;G,I+@H@("`@("H*("`@("`J($!P87)A
M;2`@;V)J96-T($1A=&5?4W!A;B`D=&EM92!4:6UE('-P86X@=&\@<W5B=')A
M8W0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@<W5B=')A8W0H)'1I;64I"B`@("!["B`@("`@("`@)'-U8B`]
M("1T:&ES+3YT;U-E8V]N9',H*2`M("1T:6UE+3YT;U-E8V]N9',H*3L*("`@
M("`@("!I9B`H)'-U8B`\(#`I('L*("`@("`@("`@("`@)'1H:7,M/G-E=$9R
M;VU396-O;F1S*#`I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T
M:&ES+3YS971&<F]M4V5C;VYD<R@D<W5B*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!496QL<R!I9B!T:6UE('-P86X@:7,@97%U86P@=&\@
M)'1I;64N"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0@1&%T95]3<&%N
M("1T:6UE(%1I;64@<W!A;B!T;R!C;VUP87)E('1O+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;"`@(%1R=64@:68@=&AE('1I;64@<W!A;G,@87)E(&5Q
M=6%L+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&5Q=6%L*"1T:6UE*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^=&]396-O;F1S*"D@/3T@)'1I;64M/G1O4V5C;VYD<R@I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@5&5L;',@:68@=&AI<R!T:6UE('-P86X@:7,@
M9W)E871E<B!O<B!E<75A;"!T:&%N("1T:6UE+@H@("`@("H*("`@("`J($!P
M87)A;2`@;V)J96-T($1A=&5?4W!A;B`D=&EM92!4:6UE('-P86X@=&\@8V]M
M<&%R92!T;RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@("!4<G5E(&EF
M('1H:7,@=&EM92!S<&%N(&ES(&=R96%T97(@;W(@97%U86P@=&AA;B`D=&EM
M92X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!G<F5A=&5R17%U86PH)'1I;64I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3YT;U-E8V]N9',H*2`^/2`D=&EM92T^=&]396-O;F1S*"D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!496QL<R!I9B!T:&ES('1I;64@<W!A
M;B!I<R!L;W=E<B!O<B!E<75A;"!T:&%N("1T:6UE+@H@("`@("H*("`@("`J
M($!P87)A;2`@;V)J96-T($1A=&5?4W!A;B`D=&EM92!4:6UE('-P86X@=&\@
M8V]M<&%R92!T;RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@("!4<G5E
M(&EF('1H:7,@=&EM92!S<&%N(&ES(&QO=V5R(&]R(&5Q=6%L('1H86X@)'1I
M;64N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@;&]W97)%<75A;"@D=&EM92D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/G1O4V5C;VYD<R@I(#P]("1T:6UE+3YT;U-E8V]N9',H*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%1E;&QS(&EF('1H:7,@=&EM92!S<&%N
M(&ES(&=R96%T97(@=&AA;B`D=&EM92X*("`@("`J"B`@("`@*B!`<&%R86T@
M(&]B:F5C="!$871E7U-P86X@)'1I;64@5&EM92!S<&%N('1O(&-O;7!A<F4@
M=&\N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("`@5')U92!I9B!T:&ES
M('1I;64@<W!A;B!I<R!G<F5A=&5R('1H86X@)'1I;64N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9W)E871E
M<B@D=&EM92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G1O4V5C;VYD
M<R@I(#X@)'1I;64M/G1O4V5C;VYD<R@I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@5&5L;',@:68@=&AI<R!T:6UE('-P86X@:7,@;&]W97(@=&AA;B`D=&EM
M92X*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C="!$871E7U-P86X@)'1I
M;64@5&EM92!S<&%N('1O(&-O;7!A<F4@=&\N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L("`@5')U92!I9B!T:&ES('1I;64@<W!A;B!I<R!L;W=E<B!T
M:&%N("1T:6UE+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&QO=V5R*"1T:6UE*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^=&]396-O;F1S*"D@/"`D=&EM92T^=&]396-O;F1S*"D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VUP87)E<R!T=V\@=&EM92!S<&%N
M<RX*("`@("`J"B`@("`@*B!#;VUP87)E<R!T=V\@=&EM92!S<&%N<RX@4W5I
M=&%B;&4@9F]R('5S92!I;B!S;W)T:6YG(&9U;F-T:6]N<RX*("`@("`J"B`@
M("`@*B!`<&%R86T@(&]B:F5C="!$871E7U-P86X@)'1I;64Q(%1H92!F:7)S
M="!T:6UE('-P86XN"B`@("`@*B!`<&%R86T@(&]B:F5C="!$871E7U-P86X@
M)'1I;64R(%1H92!S96-O;F0@=&EM92!S<&%N+@H@("`@("H*("`@("`J($!R
M971U<FX@:6YT("`@(#`@:68@=&AE('1I;64@<W!A;G,@87)E(&5Q=6%L+"`M
M,2!I9B!T:6UE,2!I<R!L;W=E<@H@("`@("H@("`@("`@("`@("`@("`@=&AA
M;B!T:6UE,BP@,2!I9B!T:6UE,2!I<R!G<F5A=&5R('1H86X@=&EM93(N"B`@
M("`@*@H@("`@("H@0'-T871I8PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@8V]M<&%R92@D=&EM93$L("1T:6UE,BD*("`@
M('L*("`@("`@("!I9B`H)'1I;64Q+3YE<75A;"@D=&EM93(I*2!["B`@("`@
M("`@("`@(')E='5R;B`P.PH@("`@("`@('T@96QS96EF("@D=&EM93$M/FQO
M=V5R*"1T:6UE,BDI('L*("`@("`@("`@("`@<F5T=7)N("TQ.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`Q.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J(%1E;&QS(&EF('1H92!T:6UE('-P86X@:7,@
M96UP='D@*'IE<F\@;&5N9W1H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VP@5')U92!I<R!I="=S(&5M<'1Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!I
M<T5M<'1Y*"D*("`@('L*("`@("`@("!R971U<FX@(21T:&ES+3YD87D@)B8@
M(21T:&ES+3YH;W5R("8F("$D=&AI<RT^;6EN=71E("8F("$D=&AI<RT^<V5C
M;VYD.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!D969A=6QT(&EN
M<'5T(&9O<FUA="X*("`@("`J"B`@("`@*B!`<&%R86T@(&UI>&5D("1F;W)M
M870@3F5W(&1E9F%U;'0@:6YP=70@9F]R;6%T+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@4')E=FEO=7,@9&5F875L="!I;G!U="!F;W)M870N"B`@
M("`@*@H@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!S971$
M969A=6QT26YP=71&;W)M870H)&9O<FUA="D*("`@('L*("`@("`@("`D;VQD
M(#T@)$=,3T)!3%-;)U]$051%7U-004Y?24Y0551?1D]234%4)UT["B`@("`@
M("`@)$=,3T)!3%-;)U]$051%7U-004Y?24Y0551?1D]234%4)UT@/2`D9F]R
M;6%T.PH@("`@("`@(')E='5R;B`D;VQD.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1V5T('1H92!D969A=6QT(&EN<'5T(&9O<FUA="X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D($1E9F%U;'0@:6YP=70@9F]R;6%T+@H@("`@("H*
M("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&5F875L
M=$EN<'5T1F]R;6%T*"D*("`@('L*("`@("`@("!R971U<FX@)$=,3T)!3%-;
M)U]$051%7U-004Y?24Y0551?1D]234%4)UT["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3970@=&AE(&1E9F%U;'0@9F]R;6%T+@H@("`@("H*("`@("`J($!P
M87)A;2`@;6EX960@)&9O<FUA="!.97<@9&5F875L="!F;W)M870N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"!0<F5V:6]U<R!D969A=6QT(&9O<FUA
M="X*("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E=$1E9F%U;'1&;W)M870H)&9O<FUA="D*("`@('L*("`@("`@("`D;VQD
M(#T@)$=,3T)!3%-;)U]$051%7U-004Y?1D]234%4)UT["B`@("`@("`@)$=,
M3T)!3%-;)U]$051%7U-004Y?1D]234%4)UT@/2`D9F]R;6%T.PH@("`@("`@
M(')E='5R;B`D;VQD.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H92!D
M969A=6QT(&9O<FUA="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D($1E
M9F%U;'0@9F]R;6%T+@H@("`@("H*("`@("`J($!S=&%T:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T1&5F875L=$9O<FUA="@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1'3$]"04Q36R=?1$%415]34$%.7T9/4DU!5"==.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&-O<'D@;V8@=&AE(&]B:F5C="`H
M=V]R:V%R<F]U;F0@9F]R(%!(4#4@9F]R=V%R9"!C;VUP871I8FEL:71Y*2X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="!$871E7U-P86X@0V]P>2!O
M9B!T:&4@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!?7V-L;VYE*"D@
M>PH@("`@("`@("1C(#T@9V5T7V-L87-S*"1T:&ES*3L*("`@("`@("`D<R`]
M(&YE=R`D8SL*("`@("`@("`D<RT^9&%Y("`@(#T@)'1H:7,M/F1A>3L*("`@
M("`@("`D<RT^:&]U<B`@(#T@)'1H:7,M/FAO=7(["B`@("`@("`@)',M/FUI
M;G5T92`]("1T:&ES+3YM:6YU=&4["B`@("`@("`@)',M/G-E8V]N9"`]("1T
M:&ES+3YS96-O;F0["B`@("`@("`@<F5T=7)N("1S.PH@("`@?0I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]$871E+U1I;65:;VYE+G!H<```````````````````````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#0V,S,W,P`Q,#4Q-30S,S<S-P`P,C$W-#<`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RH@
M=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F
M='1A8G-T;W`]-#H@*B\*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#4@0F%B82!"=65H;&5R
M+"!0:65R<F4M06QA:6X@2F]Y92`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=&AE($YE=R!"4T0@;&EC96YS92P@5&AA="!I<R!B=6YD
M;&5D("!\"B\O('P@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#
M14Y312P@86YD(&ES(&%V86EL86)L92!T:')O=6=H("`@("`@?`HO+R!\('1H
M92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+F]P96YS
M;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@("`@("`@("`@
M("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@
M;V8@=&AE(&YE=R!"4T1L:6-E;G-E(&%N9"!A<F4@=6YA8FQE("`@?`HO+R!\
M('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE
M87-E('-E;F0@82!N;W1E('1O("`@("`@('P*+R\@?"!P96%R+61E=D!L:7-T
M<RYP:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E
M;'DN("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\($%U=&AO<CH@0F%B82!"=65H;&5R(#QB86)A0&)A8F%Z+F-O;3X@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@(%!I
M97)R92U!;&%I;B!*;WEE(#QP86IO>65`<&AP+FYE=#X@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PH*+RHJ"B`J(%1I;65:;VYE(')E<')E<V5N=&%T:6]N(&-L87-S+"!A;&]N
M9R!W:71H('1I;64@>F]N92!I;F9O<FUA=&EO;B!D871A"B`J"B`J(%!(4"!V
M97)S:6]N<R`T(&%N9"`U"B`J"B`J($!C871E9V]R>2`@($1A=&4@86YD(%1I
M;64*("H@0'!A8VMA9V4@("`@1&%T90H@*B!`875T:&]R("`@("!"86)A($)U
M96AL97(@/&)A8F%`8F%B87HN8V]M/@H@*B!`875T:&]R("`@("!0:65R<F4M
M06QA:6X@2F]Y92`\<&%J;WEE0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y
M.3<M,C`P-2!"86)A($)U96AL97(L(%!I97)R92U!;&%I;B!*;WEE"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O
M8G-D+6QI8V5N<V4N<&AP("!.97<@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@
M("`@0U93.B`D260Z(%1I;65:;VYE+G!H<"QV(#$N,3$@,C`P-2\Q,2\Q-2`P
M,#HQ-CHT,"!P86IO>64@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+T1A=&4*("HO"@HO*BH*("H@5&EM95IO;F4@
M<F5P<F5S96YT871I;VX@8VQA<W,L(&%L;VYG('=I=&@@=&EM92!Z;VYE(&EN
M9F]R;6%T:6]N(&1A=&$*("H*("H@5&AE(&1E9F%U;'0@=&EM97IO;F4@:7,@
M<V5T(&9R;VT@=&AE(&9I<G-T('9A;&ED('1I;65Z;VYE(&ED(&9O=6YD"B`J
M(&EN(&]N92!O9B!T:&4@9F]L;&]W:6YG('!L86-E<RP@:6X@=&AI<R!O<F1E
M<CH*("H@("`K(&=L;V)A;"`D7T1!5$5?5$E-15I/3D5?1$5&055,5`H@*B`@
M("L@<WES=&5M(&5N=FER;VYM96YT('9A<FEA8FQE(%!(4%]46@H@*B`@("L@
M<WES=&5M(&5N=FER;VYM96YT('9A<FEA8FQE(%1:"B`J("`@*R!T:&4@<F5S
M=6QT(&]F(&1A=&4H)U0G*0H@*@H@*B!)9B!N;R!V86QI9"!T:6UE>F]N92!I
M9"!I<R!F;W5N9"P@=&AE(&1E9F%U;'0@=&EM97IO;F4@:7,@<V5T('1O("=5
M5$,G+@H@*B!9;W4@;6%Y(&%L<V\@;6%N=6%L;'D@<V5T('1H92!D969A=6QT
M('1I;65Z;VYE(&)Y('!A<W-I;F<@82!V86QI9"!I9"!T;PH@*B!$871E7U1I
M;65:;VYE.CIS971$969A=6QT*"DN"B`J"B`J(%1H:7,@8VQA<W,@:6YC;'5D
M97,@=&EM92!Z;VYE(&1A=&$@*&9R;VT@>F]N96EN9F\I(&EN('1H92!F;W)M
M(&]F(&$*("H@9VQO8F%L(&%R<F%Y+"`D7T1!5$5?5$E-15I/3D5?1$%402X*
M("H*("H@0&%U=&AO<B`@("`@0F%B82!"=65H;&5R(#QB86)A0&)A8F%Z+F-O
M;3X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E
M<R]B<V0M;&EC96YS92YP:'`@($YE=R!"4T0@3&EC96YS90H@*B!`=F5R<VEO
M;B`@("!296QE87-E.B`Q+C0N-@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A
M<BYP:'`N;F5T+W!A8VMA9V4O1&%T90H@*B\*8VQA<W,@1&%T95]4:6UE6F]N
M90I["B`@("`O*BH*("`@("`J(%1I;64@6F]N92!)1"!O9B!T:&ES('1I;64@
M>F]N90H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1I9#L*
M("`@("\J*@H@("`@("H@3&]N9R!.86UE(&]F('1H:7,@=&EM92!Z;VYE("AI
M92!#96YT<F%L(%-T86YD87)D(%1I;64I"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)&QO;F=N86UE.PH@("`@+RHJ"B`@("`@*B!3:&]R
M="!.86UE(&]F('1H:7,@=&EM92!Z;VYE("AI92!#4U0I"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)'-H;W)T;F%M93L*("`@("\J*@H@
M("`@("H@=')U92!I9B!T:&ES('1I;64@>F]N92!O8G-E<G9E<R!D87EL:6=H
M="!S879I;F=S('1I;64*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@
M("!V87(@)&AA<V1S=#L*("`@("\J*@H@("`@("H@1%-4($QO;F<@3F%M92!O
M9B!T:&ES('1I;64@>F]N90H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1D<W1L;VYG;F%M93L*("`@("\J*@H@("`@("H@1%-4(%-H;W)T
M($YA;64@;V8@=&AI<R!T:6UE>F]N90H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1D<W1S:&]R=&YA;64["B`@("`O*BH*("`@("`J(&]F
M9G-E="P@:6X@;6EL;&ES96-O;F1S+"!O9B!T:&ES('1I;65Z;VYE"B`@("`@
M*B!`=F%R(&EN=`H@("`@("HO"B`@("!V87(@)&]F9G-E=#L*"B`@("`O*BH*
M("`@("`J(%-Y<W1E;2!$969A=6QT(%1I;64@6F]N90H@("`@("H@0'9A<B!O
M8FIE8W0@1&%T95]4:6UE6F]N90H@("`@("HO"B`@("!V87(@)&1E9F%U;'0[
M"@H*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!#
M<F5A=&5S(&$@;F5W($1A=&4Z.E1I;65:;VYE(&]B:F5C="P@<F5P<F5S96YT
M:6YG('1H92!T:6UE('IO;F4*("`@("`J('-P96-I9FEE9"!I;B`D:60N("!)
M9B!T:&4@<W5P<&QI960@240@:7,@:6YV86QI9"P@=&AE(&-R96%T960*("`@
M("`J('1I;64@>F]N92!I<R!55$,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J($!P87)A;2!S=')I;F<@)&ED('1H92!T:6UE('IO;F4@
M:60*("`@("`J($!R971U<FX@;V)J96-T($1A=&5?5&EM95IO;F4@=&AE(&YE
M=R!$871E7U1I;65:;VYE(&]B:F5C=`H@("`@("HO"B`@("!F=6YC=&EO;B!$
M871E7U1I;65:;VYE*"1I9"D*("`@('L*("`@("`@("!G;&]B86P@)%]$051%
M7U1)345:3TY%7T1!5$$["B`@("`@("`@:68H1&%T95]4:6UE6F]N93HZ:7-6
M86QI9$E$*"1I9"DI('L*("`@("`@("`@("`@)'1H:7,M/FED(#T@)&ED.PH@
M("`@("`@("`@("`D=&AI<RT^;&]N9VYA;64@/2`D7T1!5$5?5$E-15I/3D5?
M1$%405LD:61=6R=L;VYG;F%M92==.PH@("`@("`@("`@("`D=&AI<RT^<VAO
M<G1N86UE(#T@)%]$051%7U1)345:3TY%7T1!5$%;)&ED75LG<VAO<G1N86UE
M)UT["B`@("`@("`@("`@("1T:&ES+3YO9F9S970@/2`D7T1!5$5?5$E-15I/
M3D5?1$%405LD:61=6R=O9F9S970G73L*("`@("`@("`@("`@:68H)%]$051%
M7U1)345:3TY%7T1!5$%;)&ED75LG:&%S9'-T)UTI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3YH87-D<W0@/2!T<G5E.PH@("`@("`@("`@("`@("`@)'1H
M:7,M/F1S=&QO;F=N86UE(#T@)%]$051%7U1)345:3TY%7T1!5$%;)&ED75LG
M9'-T;&]N9VYA;64G73L*("`@("`@("`@("`@("`@("1T:&ES+3YD<W1S:&]R
M=&YA;64@/2`D7T1!5$5?5$E-15I/3D5?1$%405LD:61=6R=D<W1S:&]R=&YA
M;64G73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T
M:&ES+3YH87-D<W0@/2!F86QS93L*("`@("`@("`@("`@("`@("1T:&ES+3YD
M<W1L;VYG;F%M92`]("1T:&ES+3YL;VYG;F%M93L*("`@("`@("`@("`@("`@
M("1T:&ES+3YD<W1S:&]R=&YA;64@/2`D=&AI<RT^<VAO<G1N86UE.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M
M/FED(#T@)U540R<["B`@("`@("`@("`@("1T:&ES+3YL;VYG;F%M92`]("1?
M1$%415]424U%6D].15]$051!6R1T:&ES+3YI9%U;)VQO;F=N86UE)UT["B`@
M("`@("`@("`@("1T:&ES+3YS:&]R=&YA;64@/2`D7T1!5$5?5$E-15I/3D5?
M1$%405LD=&AI<RT^:61=6R=S:&]R=&YA;64G73L*("`@("`@("`@("`@)'1H
M:7,M/FAA<V1S="`]("1?1$%415]424U%6D].15]$051!6R1T:&ES+3YI9%U;
M)VAA<V1S="==.PH@("`@("`@("`@("`D=&AI<RT^;V9F<V5T(#T@)%]$051%
M7U1)345:3TY%7T1!5$%;)'1H:7,M/FED75LG;V9F<V5T)UT["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@5&EM95IO;F4@;V)J
M96-T(')E<')E<V5N=&EN9R!T:&4@<WES=&5M(&1E9F%U;'0@=&EM92!Z;VYE
M"B`@("`@*@H@("`@("H@4F5T=7)N(&$@5&EM95IO;F4@;V)J96-T(')E<')E
M<V5N=&EN9R!T:&4@<WES=&5M(&1E9F%U;'0@=&EM92!Z;VYE+`H@("`@("H@
M=VAI8V@@:7,@:6YI=&EA;&EZ960@9'5R:6YG('1H92!L;V%D:6YG(&]F(%1I
M;65:;VYE+G!H<"X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H@0')E='5R;B!O8FIE8W0@1&%T95]4:6UE6F]N92!T:&4@9&5F875L="!T
M:6UE('IO;F4*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&5F875L="@I"B`@
M("!["B`@("`@("`@9VQO8F%L("1?1$%415]424U%6D].15]$149!54Q4.PH@
M("`@("`@(')E='5R;B!N97<@1&%T95]4:6UE6F]N92@D7T1!5$5?5$E-15I/
M3D5?1$5&055,5"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!S
M>7-T96T@9&5F875L="!T:6UE('IO;F4@=&\@=&AE('1I;64@>F]N92!I;B`D
M:60*("`@("`J"B`@("`@*B!3971S('1H92!S>7-T96T@9&5F875L="!T:6UE
M('IO;F4@=&\@=&AE('1I;64@>F]N92!I;B`D:60*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M('-T<FEN9R`D:60@=&AE('1I
M;64@>F]N92!I9"!T;R!U<V4*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1&5F
M875L="@D:60I"B`@("!["B`@("`@("`@9VQO8F%L("1?1$%415]424U%6D].
M15]$149!54Q4.PH@("`@("`@(&EF*$1A=&5?5&EM95IO;F4Z.FES5F%L:61)
M1"@D:60I*2!["B`@("`@("`@("`@("1?1$%415]424U%6D].15]$149!54Q4
M(#T@)&ED.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%1E<W1S
M(&EF(&=I=F5N(&ED(&ES(')E<')E<V5N=&5D(&EN('1H92`D7T1!5$5?5$E-
M15I/3D5?1$%402!T:6UE('IO;F4@9&%T80H@("`@("H*("`@("`J(%1E<W1S
M(&EF(&=I=F5N(&ED(&ES(')E<')E<V5N=&5D(&EN('1H92`D7T1!5$5?5$E-
M15I/3D5?1$%402!T:6UE('IO;F4@9&%T80H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"!T:&4@:60@=&\@
M=&5S=`H@("`@("H@0')E='5R;B!B;V]L96%N('1R=64@:68@=&AE('-U<'!L
M:65D($E$(&ES('9A;&ED"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES5F%L:61)
M1"@D:60I"B`@("!["B`@("`@("`@9VQO8F%L("1?1$%415]424U%6D].15]$
M051!.PH@("`@("`@(&EF*&ES<V5T*"1?1$%415]424U%6D].15]$051!6R1I
M9%TI*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!)<R!T:&ES('1I;64@>F]N92!E<75A;"!T;R!A
M;F]T:&5R"B`@("`@*@H@("`@("H@5&5S=',@=&\@<V5E(&EF('1H:7,@=&EM
M92!Z;VYE(&ES(&5Q=6%L("AI9',@;6%T8V@I"B`@("`@*B!T;R!A(&=I=F5N
M($1A=&5?5&EM95IO;F4@;V)J96-T+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B!`<&%R86T@;V)J96-T($1A=&5?5&EM95IO;F4@)'1Z
M('1H92!T:6UE>F]N92!T;R!T97-T"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M=')U92!I9B!T:&ES('1I;64@>F]N92!I<R!E<75A;"!T;R!T:&4@<W5P<&QI
M960@=&EM92!Z;VYE"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES17%U86PH)'1Z
M*0H@("`@>PH@("`@("`@(&EF*'-T<F-A<V5C;7`H)'1H:7,M/FED+"`D='HM
M/FED*2`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!)<R!T:&ES('1I;64@>F]N92!E<75I
M=F%L96YT('1O(&%N;W1H97(*("`@("`J"B`@("`@*B!497-T<R!T;R!S964@
M:68@=&AI<R!T:6UE('IO;F4@:7,@97%U:79A;&5N="!T;PH@("`@("H@82!G
M:79E;B!T:6UE('IO;F4@;V)J96-T+B`@17%U:79A;&5N8V4@:6X@=&AI<R!C
M;VYT97AT"B`@("`@*B!I<R!D969I;F5D(&)Y('1H92!T=V\@=&EM92!Z;VYE
M<R!H879I;F<@86X@97%U86P@<F%W"B`@("`@*B!O9F9S970@86YD(&%N(&5Q
M=6%L('-E='1I;F<@;V8@(FAA<V1S="(N("!4:&ES(&ES(&YO="!T<G5E"B`@
M("`@*B!E<75I=F%L96YC92P@87,@=&AE('1W;R!T:6UE('IO;F5S(&UA>2!H
M879E(&1I9F9E<F5N="!R=6QE<PH@("`@("H@9F]R('1H92!O8G-E<G9A;F-E
M(&]F($135"P@8G5T('1H:7,@:6UP;&5M96YT871I;VX@9&]E<R!N;W0*("`@
M("`J(&MN;W<@1%-4(')U;&5S+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<&%R86T@;V)J96-T($1A=&5?5&EM95IO;F4@)'1Z('1H
M92!T:6UE>F]N92!O8FIE8W0@=&\@=&5S=`H@("`@("H@0')E='5R;B!B;V]L
M96%N('1R=64@:68@=&AI<R!T:6UE('IO;F4@:7,@97%U:79A;&5N="!T;R!T
M:&4@<W5P<&QI960@=&EM92!Z;VYE"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES
M17%U:79A;&5N="@D='HI"B`@("!["B`@("`@("`@:68H)'1H:7,M/F]F9G-E
M="`]/2`D='HM/F]F9G-E="`F)B`D=&AI<RT^:&%S9'-T(#T]("1T>BT^:&%S
M9'-T*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1R=64@:68@=&AI<R!Z;VYE(&]B
M<V5R=F5S(&1A>6QI9VAT('-A=FEN9W,@=&EM90H@("`@("H*("`@("`J(%)E
M='5R;G,@=')U92!I9B!T:&ES('IO;F4@;V)S97)V97,@9&%Y;&EG:'0@<V%V
M:6YG<R!T:6UE"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M($!R971U<FX@8F]O;&5A;B!T<G5E(&EF('1H:7,@=&EM92!Z;VYE(&AA<R!$
M4U0*("`@("`J+PH@("`@9G5N8W1I;VX@:&%S1&%Y;&EG:'14:6UE*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/FAA<V1S=#L*("`@('T*"B`@("`O
M*BH*("`@("`J($ES('1H92!G:79E;B!D871E+W1I;64@:6X@1%-4(&9O<B!T
M:&ES('1I;64@>F]N90H@("`@("H*("`@("`J($%T=&5M<'1S('1O(&1E=&5R
M;6EN92!I9B!A(&=I=F5N($1A=&4@;V)J96-T(')E<')E<V5N=',@82!D871E
M+W1I;64*("`@("`J('1H870@:7,@:6X@1%-4(&9O<B!T:&ES('1I;64@>F]N
M92X@(%=!4DY)3D=3.B!T:&ES(&)A<VEC86QL>2!A='1E;7!T<R!T;PH@("`@
M("H@(G1R:6-K(B!T:&4@<WES=&5M(&EN=&\@=&5L;&EN9R!U<R!I9B!W92=R
M92!I;B!$4U0@9F]R(&$@9VEV96X@=&EM92!Z;VYE+@H@("`@("H@5&AI<R!U
M<V5S('!U=&5N=B@I('=H:6-H(&UA>2!N;W0@=V]R:R!I;B!S869E(&UO9&4L
M(&%N9"!R96QI97,@;VX@=6YI>"!T:6UE"B`@("`@*B!W:&EC:"!I<R!O;FQY
M('9A;&ED(&9O<B!D871E<R!F<F]M(#$Y-S`@=&\@?C(P,S@N("!4:&ES(')E
M;&EE<R!O;B!T:&4*("`@("`J('5N9&5R;'EI;F<@3U,@8V%L;',L('-O(&ET
M(&UA>2!N;W0@=V]R:R!O;B!7:6YD;W=S(&]R(&]N(&$@<WES=&5M('=H97)E
M"B`@("`@*B!Z;VYE:6YF;R!I<R!N;W0@:6YS=&%L;&5D(&]R(&-O;F9I9W5R
M960@<')O<&5R;'DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J($!P87)A;2!O8FIE8W0@1&%T92`D9&%T92!T:&4@9&%T92]T:6UE('1O
M('1E<W0*("`@("`J($!R971U<FX@8F]O;&5A;B!T<G5E(&EF('1H:7,@9&%T
M92!I<R!I;B!$4U0@9F]R('1H:7,@=&EM92!Z;VYE"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&EN1&%Y;&EG:'14:6UE*"1D871E*0H@("`@>PH@("`@("`@("1E
M;G9?='H@/2`B(CL*("`@("`@("!I9BAG971E;G8H(E1:(BDI('L*("`@("`@
M("`@("`@)&5N=E]T>B`](&=E=&5N=B@B5%HB*3L*("`@("`@("!]"B`@("`@
M("`@<'5T96YV*")46CTB+B1T:&ES+3YI9"D["B`@("`@("`@)&QT:6UE(#T@
M;&]C86QT:6UE*"1D871E+3YG9714:6UE*"DL('1R=64I.PH@("`@("`@('!U
M=&5N=B@B5%H](BXD96YV7W1Z*3L*("`@("`@("!R971U<FX@)&QT:6UE6R=T
M;5]I<V1S="==.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H92!$4U0@
M;V9F<V5T(&9O<B!T:&ES('1I;64@>F]N90H@("`@("H*("`@("`J(%)E='5R
M;G,@=&AE($135"!O9F9S970@;V8@=&AI<R!T:6UE('IO;F4L(&EN(&UI;&QI
M<V5C;VYD<RP*("`@("`J(&EF('1H92!Z;VYE(&]B<V5R=F5S($135"P@>F5R
M;R!O=&AE<G=I<V4N("!#=7)R96YT;'D@=&AE"B`@("`@*B!$4U0@;V9F<V5T
M(&ES(&AA<F0M8V]D960@=&\@;VYE(&AO=7(N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@:6YT('1H92!$4U0@;V9F<V5T
M+"!I;B!M:6QL:7-E8V]N9',@;W(@>F5R;R!I9B!T:&4@>F]N92!D;V5S(&YO
M="!O8G-E<G9E($135`H@("`@("HO"B`@("!F=6YC=&EO;B!G971$4U13879I
M;F=S*"D*("`@('L*("`@("`@("!I9B@D=&AI<RT^:&%S9'-T*2!["B`@("`@
M("`@("`@(')E='5R;B`S-C`P,#`P.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B`P.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($=E="!T:&4@1%-4+6-O<G)E8W1E9"!O9F9S970@=&\@551#(&9O<B!T
M:&4@9VEV96X@9&%T90H@("`@("H*("`@("`J($%T=&5M<'1S('1O(&=E="!T
M:&4@;V9F<V5T('1O(%540R!F;W(@82!G:79E;B!D871E+W1I;64L('1A:VEN
M9R!I;G1O"B`@("`@*B!A8V-O=6YT(&1A>6QI9VAT('-A=FEN9W,@=&EM92P@
M:68@=&AE('1I;64@>F]N92!O8G-E<G9E<R!I="!A;F0@:68*("`@("`J(&ET
M(&ES(&EN(&5F9F5C="X@(%!L96%S92!S964@=&AE(%=!4DY)3D=3(&]N($1A
M=&4Z.E1I;65:;VYE.CII;D1A>6QI9VAT5&EM92@I+@H@("`@("H*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M(&]B:F5C="!$
M871E("1D871E('1H92!$871E('1O('1E<W0*("`@("`J($!R971U<FX@:6YT
M('1H92!C;W)R96-T960@;V9F<V5T('1O(%540R!I;B!M:6QL:7-E8V]N9',*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3V9F<V5T*"1D871E*0H@("`@>PH@
M("`@("`@(&EF*"1T:&ES+3YI;D1A>6QI9VAT5&EM92@D9&%T92DI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YO9F9S970@*R`D=&AI<RT^9V5T1%-4
M4V%V:6YG<R@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^;V9F<V5T.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE(&QI<W0@;V8@=F%L:60@=&EM92!Z;VYE(&ED('-T
M<FEN9W,*("`@("`J"B`@("`@*B!2971U<FYS('1H92!L:7-T(&]F('9A;&ED
M('1I;64@>F]N92!I9"!S=')I;F=S"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J($!R971U<FX@;6EX960@86X@87)R87D@;V8@<W1R:6YG
M<R!W:71H('1H92!V86QI9"!T:6UE('IO;F4@241S"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$%V86EL86)L94E$<R@I"B`@("!["B`@("`@("`@9VQO8F%L
M("1?1$%415]424U%6D].15]$051!.PH@("`@("`@(')E='5R;B!A<G)A>5]K
M97ES*"1?1$%415]424U%6D].15]$051!*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE(&ED(&9O<B!T:&ES('1I;64@>F]N90H@("`@("H*
M("`@("`J(%)E='5R;G,@=&AE('1I;64@>F]N92!I9"`@9F]R('1H:7,@=&EM
M92!Z;VYE+"!I+F4N(")!;65R:6-A+T-H:6-A9V\B"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@<W1R:6YG('1H92!I9`H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971)1"@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3YI9#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE(&QO;F<@;F%M92!F;W(@=&AI<R!T:6UE('IO;F4*("`@("`J"B`@("`@
M*B!2971U<FYS('1H92!L;VYG(&YA;64@9F]R('1H:7,@=&EM92!Z;VYE+`H@
M("`@("H@:2YE+B`B0V5N=')A;"!3=&%N9&%R9"!4:6UE(@H@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N('-T<FEN9R!T:&4@
M;&]N9R!N86UE"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$QO;F=.86UE*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FQO;F=N86UE.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<VAO<G0@;F%M92!F;W(@=&AI
M<R!T:6UE('IO;F4*("`@("`J"B`@("`@*B!2971U<FYS('1H92!S:&]R="!N
M86UE(&9O<B!T:&ES('1I;64@>F]N92P@:2YE+B`B0U-4(@H@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N('-T<FEN9R!T:&4@
M<VAO<G0@;F%M90H@("`@("HO"B`@("!F=6YC=&EO;B!G9713:&]R=$YA;64H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<VAO<G1N86UE.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@1%-4(&QO;F<@;F%M92!F
M;W(@=&AI<R!T:6UE('IO;F4*("`@("`J"B`@("`@*B!2971U<FYS('1H92!$
M4U0@;&]N9R!N86UE(&9O<B!T:&ES('1I;64@>F]N92P@:2YE+B`B0V5N=')A
M;"!$87EL:6=H="!4:6UE(@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R!T:&4@9&%Y;&EG:'0@<V%V:6YG<R!T
M:6UE(&QO;F<@;F%M90H@("`@("HO"B`@("!F=6YC=&EO;B!G971$4U1,;VYG
M3F%M92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YD<W1L;VYG;F%M
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE($135"!S:&]R
M="!N86UE(&9O<B!T:&ES('1I;64@>F]N90H@("`@("H*("`@("`J(%)E='5R
M;G,@=&AE($135"!S:&]R="!N86UE(&9O<B!T:&ES('1I;64@>F]N92P@:2YE
M+B`B0T14(@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R!T:&4@9&%Y;&EG:'0@<V%V:6YG<R!T:6UE('-H;W)T
M(&YA;64*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1%-44VAO<G1.86UE*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F1S='-H;W)T;F%M93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(')A=R`H;F]N+4135"UC
M;W)R96-T960I(&]F9G-E="!F<F]M(%540R]'350@9F]R('1H:7,@=&EM92!Z
M;VYE"B`@("`@*@H@("`@("H@4F5T=7)N<R!T:&4@<F%W("AN;VXM1%-4+6-O
M<G)E8W1E9"D@;V9F<V5T(&9R;VT@551#+T=-5"!F;W(@=&AI<R!T:6UE('IO
M;F4*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R
M;B!I;G0@=&AE(&]F9G-E="P@:6X@;6EL;&ES96-O;F1S"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%)A=T]F9G-E="@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3YO9F9S970["B`@("!]"GT*"@HO+PHO+R!4:6UE(%IO;F4@1&%T
M80HO+R`@;V9F<V5T(&ES(&EN(&UI;&ES96-O;F1S"B\O"B1'3$]"04Q36R=?
M1$%415]424U%6D].15]$051!)UT@/2!A<G)A>2@*("`@("=%=&,O1TU4*S$R
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M-#,R,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G1TU4+3$R.C`P)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G1TU4+3$R.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T5T8R]'350K,3$G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TS.38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='
M350M,3$Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350M,3$Z,#`G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G34E4)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,SDV,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G5V5S="!386UO82!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G5U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)U!A8VEF:6,O07!I82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3,Y-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U=E<W0@
M4V%M;V$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U=35"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+TUI9'=A
M>2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,Y-C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)U-A;6]A(%-T86YD87)D(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=34U0G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R].:75E)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`M,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G3FEU92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G3E54
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O
M4&%G;U]086=O)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,SDV
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4V%M;V$@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U-35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+U-A;6]A)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,SDV,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G4V%M;V$@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)U-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=54R]386UO82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3,Y-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U-A;6]A
M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=34U0G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]!
M9&%K)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S8P,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G2&%W86EI+4%L975T:6%N(%-T86YD
M87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=(05-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)TAA=V%I:2U!;&5U=&EA;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G2$%$5"<@*2P*("`@("=!;65R:6-A+T%T:V$G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS-C`P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=(87=A:6DM06QE=71I86X@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TA!4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M2&%W86EI+4%L975T:6%N($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=(0414)R`I+`H@("`@)T5T8R]'350K,3`G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS-C`P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("='350M,3`Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("='350M,3`Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G2%-4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S8P
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G2&%W86EI(%-T86YD87)D
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=(4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R]&86MA;V9O)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S8P,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G5&]K96QA=2!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G5$M4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)U!A8VEF:6,O2&]N;VQU;'4G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TS-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=(
M87=A:6D@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)TA35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I
M9FEC+TIO:&YS=&]N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G2&%W86EI(%-T86YD
M87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=(4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R]287)O=&]N
M9V$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS-C`P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=#;V]K($ES+B!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G0TM4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)U!A8VEF:6,O5&%H:71I)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G5&%H:71I(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=404A4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U-Y<W1E;58O
M2%-4,3`G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS-C`P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=(87=A:6D@4W1A;F1A<F0@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TA35"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=54R]!;&5U=&EA;B<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@+3,V,#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)TAA=V%I:2U!;&5U=&EA;B!3=&%N9&%R9"!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G2$%35"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=(87=A:6DM06QE
M=71I86X@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)TA!1%0G("DL"B`@("`G55,O2&%W86EI)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G2&%W86EI(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=(4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M4&%C:69I8R]-87)Q=65S87,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TS-#(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-87)Q=65S
M87,@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU!4E0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G05-4)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G06QA<VMA(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=!2U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T%L87-K82!$87EL:6=H="!4:6UE
M)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G04M$5"<@*2P*("`@("=!
M;65R:6-A+T%N8VAO<F%G92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3,R-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%L87-K82!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G04M35"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^("=!;&%S:V$@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)T%+1%0G("DL"B`@("`G06UE<FEC82]*=6YE874G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS,C0P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=!;&%S:V$@4W1A;F1A<F0@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T%+4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G06QA<VMA($1A>6QI
M9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!2T14)R`I
M+`H@("`@)T%M97)I8V$O3F]M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3,R-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%L87-K
M82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G04M3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^("=!;&%S:V$@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S
M='-H;W)T;F%M92<@/3X@)T%+1%0G("DL"B`@("`G06UE<FEC82]986MU=&%T
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S(T,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G06QA<VMA(%-T86YD87)D(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=!2U-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T%L87-K82!$
M87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G04M$
M5"<@*2P*("`@("=%=&,O1TU4*SDG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TS,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350M
M,#DZ,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350M,#DZ,#`G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R]'86UB
M:65R)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S(T,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1V%M8FEE<B!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G1T%-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=3>7-T96U6+UE35#DG(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TS,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("='86UB:65R(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='04U4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U-Y<W1E;58O
M65-4.5E$5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,R-#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%L87-K82!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G04M35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=!
M;&%S:V$@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T%+1%0G("DL"B`@("`G55,O06QA<VMA)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G06QA<VMA(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=!2U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)T%L87-K82!$87EL:6=H="!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G04M$5"<@*2P*("`@("=!;65R:6-A
M+T1A=W-O;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(X.#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!A8VEF:6,@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=0
M86-I9FEC($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=01%0G("DL"B`@("`G06UE<FEC82]%;G-E;F%D82<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@+3(X.#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)U!A8VEF:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)U!35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=086-I9FEC($1A>6QI9VAT(%1I
M;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=01%0G("DL"B`@("`G
M06UE<FEC82],;W-?06YG96QE<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!A8VEF
M:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^("=086-I9FEC($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=01%0G("DL"B`@("`G06UE<FEC82]4:6IU86YA
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C@X,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G4&%C:69I8R!3=&%N9&%R9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G4%-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)U!A8VEF:6,@
M1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U!$
M5"<@*2P*("`@("=!;65R:6-A+U9A;F-O=79E<B<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)U!A8VEF:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)U!35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@
M("`G9'-T;&]N9VYA;64G(#T^("=086-I9FEC($1A>6QI9VAT(%1I;64G+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=01%0G("DL"B`@("`G06UE<FEC
M82]7:&ET96AO<G-E)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4&%C:69I8R!3=&%N
M9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4%-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)U!A8VEF:6,@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)U!$5"<@*2P*("`@("=#86YA9&$O4&%C:69I8R<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(X.#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)U!A8VEF:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)U!35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=086-I9FEC($1A>6QI9VAT
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=01%0G("DL"B`@
M("`G0V%N861A+UEU:V]N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4&%C:69I8R!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4%-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@)U!A8VEF:6,@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)U!$5"<@*2P*("`@("=%=&,O1TU4*S@G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TR.#@P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("='350M,#@Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("='350M,#@Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G365X:6-O+T)A:F%.;W)T92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!A8VEF
M:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^("=086-I9FEC($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=01%0G("DL"B`@("`G4%-4)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G4&%C:69I8R!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G4%-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)U!A8VEF:6,@1&%Y;&EG:'0@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U!$5"<@*2P*("`@("=0
M4U0X4$14)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C@X,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4&%C:69I8R!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4%-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)U!A
M8VEF:6,@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)U!$5"<@*2P*("`@("=086-I9FEC+U!I=&-A:7)N)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G4&ET8V%I<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)U!35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=3>7-T96U6+U!35#@G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TR.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=0:71C
M86ER;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M4%-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U-Y<W1E
M;58O4%-4.%!$5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(X
M.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!A8VEF:6,@4W1A;F1A
M<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!35"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^
M("=086-I9FEC($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=01%0G("DL"B`@("`G55,O4&%C:69I8R<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)U!A8VEF:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)U!35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^("=086-I9FEC($1A>6QI9VAT(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=01%0G("DL"B`@("`G55,O
M4&%C:69I8RU.97<G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR
M.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=086-I9FEC(%-T86YD
M87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=04U0G+`H@("`@
M("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]
M/B`G4&%C:69I8R!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G4$14)R`I+`H@("`@)T%M97)I8V$O0F]I<V4G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=-;W5N=&%I;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TUO=6YT86EN($1A>6QI9VAT
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=-1%0G("DL"B`@
M("`G06UE<FEC82]#86UB<FED9V5?0F%Y)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M36]U;G1A:6X@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)TU35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=-;W5N=&%I;B!$87EL:6=H="!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G3414)R`I+`H@("`@)T%M97)I8V$O
M0VAI:'5A:'5A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C4R
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36]U;G1A:6X@4W1A;F1A
M<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU35"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^
M("=-;W5N=&%I;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G3414)R`I+`H@("`@)T%M97)I8V$O1&%W<V]N7T-R965K)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C4R,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G36]U;G1A:6X@4W1A;F1A<F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)TU35"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+T1E;G9E<B<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)TUO=6YT86EN(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=-4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G36]U;G1A:6X@1&%Y;&EG:'0@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TU$5"<@*2P*("`@("=!
M;65R:6-A+T5D;6]N=&]N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36]U;G1A:6X@
M4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU35"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^("=-;W5N=&%I;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G3414)R`I+`H@("`@)T%M97)I8V$O2&5R;6]S:6QL
M;R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(U,C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)TUO=6YT86EN(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]);G5V:6LG(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=-;W5N=&%I;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TUO=6YT86EN($1A>6QI9VAT
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=-1%0G("DL"B`@
M("`G06UE<FEC82]-87IA=&QA;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUO=6YT
M86EN(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G36]U;G1A:6X@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)TU$5"<@*2P*("`@("=!;65R:6-A+U!H;V5N
M:7@G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=-;W5N=&%I;B!3=&%N9&%R9"!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O4VAI<')O8VLG(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=-;W5N=&%I;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TUO=6YT86EN($1A>6QI
M9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=-1%0G("DL
M"B`@("`G06UE<FEC82]996QL;W=K;FEF92<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+3(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)TUO=6YT86EN(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=-4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`G36]U;G1A:6X@1&%Y;&EG:'0@5&EM92<L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TU$5"<@*2P*("`@("=#86YA9&$O
M36]U;G1A:6XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-;W5N=&%I;B!3=&%N9&%R
M9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M)TUO=6YT86EN($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=-1%0G("DL"B`@("`G171C+T=-5"LW)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G1TU4+3`W.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4
M+3`W.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TU3
M5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(U,C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)TUO=6YT86EN(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G36]U;G1A
M:6X@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)TU$5"<@*2P*("`@("=-4U0W3414)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36]U
M;G1A:6X@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)TU35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("=-;W5N=&%I;B!$87EL:6=H="!4:6UE)RP*("`@("`@
M("`G9'-T<VAO<G1N86UE)R`]/B`G3414)R`I+`H@("`@)TUE>&EC;R]"86IA
M4W5R)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C4R,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36]U;G1A:6X@4W1A;F1A<F0@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU35"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=-;W5N
M=&%I;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]
M/B`G3414)R`I+`H@("`@)TYA=F%J;R<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUO
M=6YT86EN(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=-4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S
M=&QO;F=N86UE)R`]/B`G36]U;G1A:6X@1&%Y;&EG:'0@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)TU$5"<@*2P*("`@("=03E0G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=-;W5N=&%I;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)U-Y<W1E;58O35-4-R<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+3(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)TUO=6YT86EN(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=-4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M4WES=&5M5B]-4U0W3414)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36]U;G1A:6X@
M4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU35"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^("=-;W5N=&%I;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G3414)R`I+`H@("`@)U53+T%R:7IO;F$G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=-;W5N=&%I;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)U53+TUO=6YT86EN)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M36]U;G1A:6X@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)TU35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=-;W5N=&%I;B!$87EL:6=H="!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G3414)R`I+`H@("`@)T%M97)I8V$O
M0F5L:7IE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O0V%N8W5N)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@1&%Y;&EG
M:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-$5"<@*2P*
M("`@("=!;65R:6-A+T-H:6-A9V\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT
M<F%L(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G0V5N=')A;"!$87EL:6=H="!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G0T14)R`I+`H@("`@)T%M97)I8V$O0V]S=&%?
M4FEC82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+T5L7U-A;'9A9&]R)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T%M97)I8V$O1W5A=&5M86QA)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%M97)I8V$O36%N86=U82<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E
M;G1R86P@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R
M:6-A+TUE;F]M:6YE92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A
M;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=#96YT<F%L($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=#1%0G("DL"B`@("`G06UE<FEC82]-97)I9&$G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!$87EL:6=H
M="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T14)R`I+`H@
M("`@)T%M97)I8V$O365X:6-O7T-I='DG(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#
M96YT<F%L(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE
M<FEC82]-;VYT97)R97DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L(%-T
M86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G0V5N=')A;"!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G0T14)R`I+`H@("`@)T%M97)I8V$O3F]R=&A?1&%K;W1A
M+T-E;G1E<B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#
M96YT<F%L($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=#1%0G("DL"B`@("`G06UE<FEC82]286EN>5]2:79E<B<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L($1A>6QI9VAT
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#1%0G("DL"B`@
M("`G06UE<FEC82]286YK:6Y?26YL970G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%
M87-T97)N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S
M=&QO;F=N86UE)R`]/B`G16%S=&5R;B!$87EL:6=H="!4:6UE)RP*("`@("`@
M("`G9'-T<VAO<G1N86UE)R`]/B`G1414)R`I+`H@("`@)T%M97)I8V$O4F5G
M:6YA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O4W=I9G1?0W5R<F5N="<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+U1E9W5C:6=A;'!A)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%M97)I8V$O5VEN;FEP96<G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=#96YT<F%L(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!$87EL:6=H="!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T14)R`I+`H@("`@)T-35"<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L($1A>6QI
M9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#1%0G("DL
M"B`@("`G0U-4-D-$5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A
M;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=#96YT<F%L($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=#1%0G("DL"B`@("`G0V%N861A+T-E;G1R86PG(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!$87EL:6=H
M="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T14)R`I+`H@
M("`@)T-A;F%D82]%87-T+5-A<VMA=&-H97=A;B<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=#86YA9&$O4V%S:V%T8VAE=V%N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N
M=')A;"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T-H:6QE
M+T5A<W1E<DES;&%N9"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<B!)<RX@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5!4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M16%S=&5R($ES+B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)T5!4U-4)R`I+`H@("`@)T5T8R]'350K-B<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T=-5"TP-CHP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-
M5"TP-CHP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=-
M97AI8V\O1V5N97)A;"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A
M;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+T5A<W1E
M<B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<B!)<RX@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T5!4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R($ES+B!3
M=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5!4U-4
M)R`I+`H@("`@)U!A8VEF:6,O1V%L87!A9V]S)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G1V%L87!A9V]S(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='
M04Q4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U-Y<W1E
M;58O0U-4-B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=3>7-T96U6+T-35#9#1%0G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!$87EL
M:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T14)R`I
M+`H@("`@)U53+T-E;G1R86PG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L
M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G0V5N=')A;"!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G0T14)R`I+`H@("`@)T%M97)I8V$O0F]G;W1A)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G0V]L;VUB:6$@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T-/5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!;65R:6-A+T-A>6UA;B<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A
M<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R
M:6-A+T1E=')O:70G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ
M.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD
M87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]
M/B`G16%S=&5R;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G1414)R`I+`H@("`@)T%M97)I8V$O16ER=6YE<&4G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=!8W)E(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=!0U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M06UE<FEC82]&;W)T7U=A>6YE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R
M;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O
M1W)A;F1?5'5R:R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X
M,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A
M<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^
M("=%87-T97)N($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=%1%0G("DL"B`@("`G06UE<FEC82]'=6%Y87%U:6PG(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=%8W5A9&]R(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=%0U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G06UE<FEC82](879A;F$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L
M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G0V5N=')A;"!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G0T14)R`I+`H@("`@)T%M97)I8V$O26YD:6%N82])
M;F1I86YA<&]L:7,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ
M.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD
M87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]);F1I86YA
M+TMN;W@G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]);F1I86YA+TUA<F5N
M9V\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]);F1I86YA+U9E=F%Y)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T%M97)I8V$O26YD:6%N87!O;&ES)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%M97)I8V$O27%A;'5I="<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=%87-T97)N($1A>6QI9VAT(%1I;64G+`H@("`@
M("`@("=D<W1S:&]R=&YA;64G(#T^("=%1%0G("DL"B`@("`G06UE<FEC82]*
M86UA:6-A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O2V5N='5C:WDO3&]U
M:7-V:6QL92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%
M87-T97)N($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=%1%0G("DL"B`@("`G06UE<FEC82]+96YT=6-K>2]-;VYT:6-E;&QO
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@
M1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5$
M5"<@*2P*("`@("=!;65R:6-A+TMN;WA?24XG(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=%87-T97)N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M06UE<FEC82],:6UA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4&5R=2!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G4$54)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O3&]U:7-V:6QL92<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($1A>6QI9VAT
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%1%0G("DL"B`@
M("`G06UE<FEC82]-;VYT<F5A;"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E
M<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T53
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^("=%87-T97)N($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=%1%0G("DL"B`@("`G06UE<FEC82].87-S874G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!$
M87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G1414
M)R`I+`H@("`@)T%M97)I8V$O3F5W7UEO<FLG(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=%87-T97)N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!$87EL:6=H="!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G1414)R`I+`H@("`@)T%M97)I8V$O
M3FEP:6=O;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%
M87-T97)N($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=%1%0G("DL"B`@("`G06UE<FEC82]086YA;6$G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G06UE<FEC82]086YG;FER='5N9R<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=%87-T97)N($1A>6QI9VAT(%1I;64G+`H@("`@
M("`@("=D<W1S:&]R=&YA;64G(#T^("=%1%0G("DL"B`@("`G06UE<FEC82]0
M;W)T+6%U+5!R:6YC92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A
M;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+U!O<G1O
M7T%C<F4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!8W)E(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=!0U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G06UE<FEC82]2:6]?0G)A;F-O)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G06-R92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G04-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O
M5&AU;F1E<E]"87DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ
M.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD
M87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]
M/B`G16%S=&5R;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G1414)R`I+`H@("`@)T)R87II;"]!8W)E)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G06-R92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M04-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T-A;F%D
M82]%87-T97)N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R
M9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M)T5A<W1E<FX@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)T5$5"<@*2P*("`@("=#=6)A)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M0V5N=')A;"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@1&%Y;&EG:'0@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)T-$5"<@*2P*("`@("=%4U0G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!$87EL:6=H
M="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G1414)R`I+`H@
M("`@)T535#5%1%0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ
M.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD
M87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]
M/B`G16%S=&5R;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G1414)R`I+`H@("`@)T5T8R]'350K-2<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T=-5"TP-3HP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-
M5"TP-3HP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=)
M150G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G2F%M86EC82<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=3>7-T96U6+T535#4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T
M86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4WES=&5M5B]%4U0U
M1414)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E
M<FX@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)T5$5"<@*2P*("`@("=54R]%87-T+4EN9&EA;F$G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=%87-T97)N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G55,O16%S=&5R;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A
M;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=%87-T97)N($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=%1%0G("DL"B`@("`G55,O26YD:6%N82U3=&%R:V4G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G55,O36EC:&EG86XG(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=%87-T97)N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!$87EL:6=H="!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G1414)R`I+`H@("`@)T%M97)I8V$O
M06YG=6EL;&$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R
M9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O06YT:6=U82<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T%T;&%N=&EC(%-T86YD87)D(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]!<G5B82<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T%T;&%N=&EC(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G06UE<FEC82]!<W5N8VEO;B<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!A
M<F%G=6%Y(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=0650G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G4&%R86=U87D@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=065-4)R`I+`H@("`@)T%M97)I8V$O0F%R8F%D;W,G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R9"!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T%M97)I8V$O0F]A7U9I<W1A)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G06UA>F]N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=!350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G06UE<FEC82]#87)A8V%S)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5F5N
M97IU96QA(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=6150G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]#=6EA
M8F$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=!;6%Z;VX@4W1A;F1A<F0@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%-5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=!;6%Z;VX@
M4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!35-4
M)R`I+`H@("`@)T%M97)I8V$O0W5R86-A;R<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T%T;&%N=&EC(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M06UE<FEC82]$;VUI;FEC82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%T;&%N=&EC
M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]'
M;&%C95]"87DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R
M9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M)T%T;&%N=&EC($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=!1%0G("DL"B`@("`G06UE<FEC82]';V]S95]"87DG(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R9"!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T%T;&%N=&EC($1A>6QI
M9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!1%0G("DL
M"B`@("`G06UE<FEC82]'<F5N861A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G071L
M86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R
M:6-A+T=U861E;&]U<&4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!=&QA;G1I8R!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O1W5Y
M86YA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1W5Y86YA(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("='650G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G06UE<FEC82](86QI9F%X)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G071L86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@
M("`G9'-T;&]N9VYA;64G(#T^("=!=&QA;G1I8R!$87EL:6=H="!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0414)R`I+`H@("`@)T%M97)I
M8V$O3&%?4&%Z)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0F]L:79I82!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G0D]4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O36%N875S)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G06UA>F]N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=!350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G06UE<FEC82]-87)T:6YI<75E)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M071L86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M;65R:6-A+TUO;G1S97)R870G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!=&QA;G1I
M8R!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O
M4&]R=%]O9E]3<&%I;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%T;&%N=&EC(%-T
M86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]0;W)T
M;U]696QH;R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%M87IO;B!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G04U4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O4'5E<G1O7U)I8V\G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O4V%N=&EA9V\G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=#:&EL92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G0TQ4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)T-H:6QE(%-U;6UE<B!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G0TQ35"<@*2P*("`@("=!;65R:6-A+U-A;G1O
M7T1O;6EN9V\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R
M9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O4W1?2VET=',G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O4W1?3'5C:6$G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%M97)I8V$O4W1?5&AO;6%S)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G071L86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=!;65R:6-A+U-T7U9I;F-E;G0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!=&QA
M;G1I8R!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I
M8V$O5&AU;&4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R
M9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O5&]R=&]L82<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T%T;&%N=&EC(%-T86YD87)D(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]6:7)G:6XG(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%N=&%R8W1I8V$O4&%L;65R)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M0VAI;&4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-,5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=#:&EL92!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)T-,4U0G("DL"B`@("`G071L86YT:6,O0F5R;75D82<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T%T;&%N=&EC(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G071L86YT:6,@1&%Y;&EG
M:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T%$5"<@*2P*
M("`@("=!=&QA;G1I8R]3=&%N;&5Y)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1F%L
M:VQA;F0@27,N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=&2U0G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G1F%L:VQA;F0@27,N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G1DM35"<@*2P*("`@("="<F%Z:6PO5V5S="<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T%M87IO;B!3=&%N9&%R9"!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G04U4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T-A;F%D82]!=&QA;G1I8R<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T%T;&%N=&EC(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G071L86YT:6,@1&%Y;&EG:'0@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T%$5"<@*2P*("`@("=#
M:&EL92]#;VYT:6YE;G1A;"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-H:6QE(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#3%0G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0VAI
M;&4@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#
M3%-4)R`I+`H@("`@)T5T8R]'350K-"<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-
M5"TP-#HP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"TP-#HP,"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=04E0G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R9"!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)U-Y<W1E;58O05-4-"<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T%T;&%N=&EC(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M4WES=&5M5B]!4U0T0414)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G071L86YT:6,@
M4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^("=!=&QA;G1I8R!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G0414)R`I+`H@("`@)T%M97)I8V$O4W1?2F]H;G,G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ,C8P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=.97=F;W5N9&QA;F0@4W1A;F1A<F0@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TY35"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=.97=F
M;W5N9&QA;F0@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)TY$5"<@*2P*("`@("=#3E0G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TQ,C8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=.
M97=F;W5N9&QA;F0@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)TY35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@
M("`G9'-T;&]N9VYA;64G(#T^("=.97=F;W5N9&QA;F0@1&%Y;&EG:'0@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TY$5"<@*2P*("`@("=#
M86YA9&$O3F5W9F]U;F1L86YD)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,3(V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G3F5W9F]U
M;F1L86YD(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=.4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S
M=&QO;F=N86UE)R`]/B`G3F5W9F]U;F1L86YD($1A>6QI9VAT(%1I;64G+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=.1%0G("DL"B`@("`G04=4)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G07)G96YT:6YE(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=!4E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G06UE<FEC82]!<F%G=6%I;F$G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("="<F%Z:6P@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T)25"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^("="<F%Z:6P@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("="4E-4)R`I+`H@("`@)T%M97)I8V$O0F5L96TG(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("="<F%Z:6P@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T)25"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=!;65R:6-A+T)U96YO<U]!:7)E<R<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%R
M9V5N=&EN92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05)4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O0V%T
M86UA<F-A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3`X,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G07)G96YT:6YE(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=!4E0G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]#87EE;FYE)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G1G)E;F-H($=U:6%N82!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G1T94)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T%M97)I8V$O0V]R9&]B82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%R9V5N
M=&EN92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05)4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O1F]R=&%L
M97IA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3`X,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0G)A>FEL(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("="4E0G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0G)A>FEL(%-U;6UE<B!4
M:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0E)35"<@*2P*("`@
M("=!;65R:6-A+T=O9'1H86(G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TQ,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=797-T97)N
M($=R965N;&%N9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5T=4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@)U=E<W1E<FX@1W)E96YL86YD(%-U;6UE<B!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G5T=35"<@*2P*("`@("=!;65R:6-A
M+TIU:G5Y)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3`X,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G07)G96YT:6YE(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=!4E0G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]-86-E:6\G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("="<F%Z:6P@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T)25"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("="<F%Z:6P@4W5M;65R(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("="4E-4)R`I+`H@("`@)T%M97)I8V$O365N9&]Z
M82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T%R9V5N=&EN92!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G05)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T%M97)I8V$O36EQ=65L;VXG(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=0:65R<F4@)B!-:7%U96QO;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G4$U35"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=0:65R<F4@)B!-:7%U
M96QO;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]
M/B`G4$U$5"<@*2P*("`@("=!;65R:6-A+TUO;G1E=FED96\G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=5<G5G=6%Y(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=5650G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M06UE<FEC82]087)A;6%R:6)O)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4W5R:6YA
M;64@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U-25"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+U)E8VEF92<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T)R87II;"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G0E)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T)R87II;"!3=6UM97(@5&EM92<L
M"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T)24U0G("DL"B`@("`G06UE
M<FEC82]2;W-A<FEO)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G07)G96YT:6YE(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4E0G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]386]?4&%U;&\G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("="<F%Z:6P@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T)25"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^("="<F%Z:6P@4W5M;65R(%1I;64G+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("="4E-4)R`I+`H@("`@)T)%5"<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T)R87II;"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G0E)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T)R87II;"!3=6UM97(@5&EM92<L
M"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T)24U0G("DL"B`@("`G0G)A
M>FEL+T5A<W0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ,#@P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("="<F%Z:6P@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T)25"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("="<F%Z:6P@4W5M
M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("="4E-4)R`I
M+`H@("`@)T5T8R]'350K,R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"TP,SHP
M,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"TP,SHP,"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+TYO<F]N:&$G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TW,C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T9E<FYA;F1O(&1E($YO<F]N:&$@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T9.5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=!=&QA;G1I8R]3;W5T:%]'96]R9VEA)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M-S(P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=3;W5T:"!'96]R9VEA(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G0G)A>FEL+T1E3F]R;VYH82<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3<R,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G1F5R;F%N9&\@9&4@3F]R;VYH82!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G1DY4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T5T8R]'350K,B<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4
M+3`R.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4+3`R.C`P)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O4V-O
M<F5S8GES=6YD)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S8P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($=R965N;&%N
M9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G14=4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M)T5A<W1E<FX@1W)E96YL86YD(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G14=35"<@*2P*("`@("=!=&QA;G1I8R]!>F]R97,G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS-C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T%Z;W)E<R!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G05I/5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=!>F]R97,@4W5M;65R(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!6D]35"<@*2P*("`@("=!
M=&QA;G1I8R]#87!E7U9E<F1E)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#87!E(%9E
M<F1E(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#5E0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G171C+T=-5"LQ)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S8P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("='350M,#$Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("='350M,#$Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G069R:6-A+T%B:61J86XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1W)E96YW:6-H($UE
M86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O06-C<F$G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G1W)E96YW:6-H($UE86X@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T=-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!9G)I8V$O0F%M86MO)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=R965N=VEC:"!-96%N
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+T)A;FIU;"<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("='<F5E;G=I8V@@365A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T%F<FEC82]":7-S874G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1W)E96YW:6-H($UE86X@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O0V%S86)L86YC82<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=797-T97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=7150G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G069R:6-A+T-O;F%K<GDG(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1W)E96YW:6-H
M($UE86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O1&%K87(G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G1W)E96YW:6-H($UE86X@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T=-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!9G)I8V$O16Q?06%I=6XG(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!%
M=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5T54)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]&<F5E
M=&]W;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("='<F5E;G=I8V@@365A;B!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T%F<FEC82],;VUE)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=R965N=VEC
M:"!-96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+TUO;G)O
M=FEA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T=R965N=VEC:"!-96%N(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("='350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G069R:6-A+TYO=6%K8VAO='0G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1W)E
M96YW:6-H($UE86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O
M3W5A9V%D;W5G;W4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1W)E96YW:6-H($UE86X@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O4V%O7U1O;64G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G1W)E96YW:6-H($UE86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T=-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M9G)I8V$O5&EM8G5K='4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1W)E96YW:6-H($UE86X@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+T1A;FUA<FMS:&%V;B<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("='<F5E;G=I8V@@365A;B!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%T;&%N=&EC+T-A;F%R>2<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=797-T97)N($5U
M<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=7150G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G5V5S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)U=%4U0G("DL"B`@("`G071L86YT:6,O1F%E
M<F]E)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)U=E<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)U=%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=797-T97)N($5U<F]P
M96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M5T535"<@*2P*("`@("=!=&QA;G1I8R]-861E:7)A)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U=E
M<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)U=%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("=797-T97)N($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G5T535"<@*2P*("`@("=!=&QA
M;G1I8R]297EK:F%V:6LG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1W)E96YW:6-H($UE86X@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=!=&QA;G1I8R]3=%](96QE;F$G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G1W)E96YW:6-H($UE86X@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T=-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=%:7)E)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T=R965N=VEC:"!-96%N(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("='350G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G27)I<V@@4W5M
M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=)4U0G("DL
M"B`@("`G171C+T=-5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K,#`Z,#`G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("='350K,#`Z,#`G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G171C+T=-5"LP)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"LP
M,#HP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LP,#HP,"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=%=&,O1TU4+3`G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G1TU4*S`P.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M1TU4*S`P.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T5T8R]'350P)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"LP,#HP,"<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T=-5"LP,#HP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=%=&,O1W)E96YW:6-H)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=R965N
M=VEC:"!-96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G171C+U5#5"<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=#;V]R9&EN871E9"!5;FEV97)S86P@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)U540R<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=%=&,O551#)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-O;W)D:6YA=&5D
M(%5N:79E<G-A;"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G551#
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T5T8R]5;FEV
M97)S86PG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G0V]O<F1I;F%T960@56YI=F5R<V%L(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=55$,G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G171C+UIU;'4G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V]O
M<F1I;F%T960@56YI=F5R<V%L(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=55$,G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M175R;W!E+T)E;&9A<W0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1W)E96YW:6-H($UE86X@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("="<FET
M:7-H(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M0E-4)R`I+`H@("`@)T5U<F]P92]$=6)L:6XG(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1W)E96YW
M:6-H($UE86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^("=)<FES:"!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)TE35"<@*2P*("`@("=%=7)O<&4O3&ES8F]N)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)U=E<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)U=%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@
M("`G9'-T;&]N9VYA;64G(#T^("=797-T97)N($5U<F]P96%N(%-U;6UE<B!4
M:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G5T535"<@*2P*("`@
M("=%=7)O<&4O3&]N9&]N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=R965N=VEC:"!-96%N(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0G)I
M=&ES:"!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)T)35"<@*2P*("`@("='0B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='<F5E;G=I8V@@365A;B!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T)R
M:71I<V@@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("="4U0G("DL"B`@("`G1T(M16ER92<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='<F5E;G=I8V@@
M365A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)T)R:71I<V@@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("="4U0G("DL"B`@("`G1TU4)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=R965N=VEC
M:"!-96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G1TU4,"<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("='350K,#`Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K
M,#`Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G1W)E
M96YW:6-H)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T=R965N=VEC:"!-96%N(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("='350G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G26-E;&%N9"<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='<F5E;G=I8V@@
M365A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!O<G1U9V%L)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)U=E<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)U=%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^("=797-T97)N($5U<F]P96%N(%-U;6UE
M<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G5T535"<@*2P*
M("`@("=50U0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G0V]O<F1I;F%T960@56YI=F5R<V%L(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=55$,G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G551#)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-O;W)D
M:6YA=&5D(%5N:79E<G-A;"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G551#)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U5N
M:79E<G-A;"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=#;V]R9&EN871E9"!5;FEV97)S86P@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U540R<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=7150G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R
M;B!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5T54
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@)U=E<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@
M("`@("=D<W1S:&]R=&YA;64G(#T^("=715-4)R`I+`H@("`@)UIU;'4G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G0V]O<F1I;F%T960@56YI=F5R<V%L(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=55$,G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G069R:6-A+T%L9VEE<G,G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F
M<FEC82]"86YG=6DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!!9G)I8V%N
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=7050G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+T)R87IZ879I;&QE
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)U=E<W1E<FX@069R:6-A;B!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G5T%4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T%F<FEC82]#975T82<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3=6UM97(@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G("DL"B`@("`G
M069R:6-A+T1O=6%L82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=797-T97)N($%F<FEC
M86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U=!5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O2VEN<VAA<V$G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!!9G)I8V%N(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=7050G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G069R:6-A+TQA9V]S)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)U=E<W1E<FX@069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G5T%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F
M<FEC82],:6)R979I;&QE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U=E<W1E<FX@069R
M:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5T%4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82],=6%N9&$G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!!9G)I8V%N(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=7050G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G069R:6-A+TUA;&%B;R<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=797-T97)N($%F<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)U=!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M9G)I8V$O3F1J86UE;F$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!!9G)I
M8V%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=7050G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+TYI86UE>2<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=797-T97)N($%F<FEC86X@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)U=!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=!9G)I8V$O4&]R=&\M3F]V;R<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=797-T97)N($%F<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)U=!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=!9G)I8V$O5'5N:7,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O
M<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]7:6YD:&]E
M:R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=797-T97)N($%F<FEC86X@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)U=!5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=797-T97)N($%F
M<FEC86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=705-4)R`I+`H@("`@)T%R8W1I8R],;VYG>65A<F)Y96XG(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M
M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I
M+`H@("`@)T%T;&%N=&EC+TIA;E]-87EE;B<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%
M87-T97)N($=R965N;&%N9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G14=4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@1W)E96YL86YD(%-U;6UE<B!4:6UE
M)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G14=35"<@*2P*("`@("=#
M150G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@
M175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=#15-4)R`I+`H@("`@)T-%4U0G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`B0V5N
M=')A;"!%=7)O<&5A;B!4:6UE(BP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@(D-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64B+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5#5"<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O
M<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)T-%4U0G("DL"B`@("`G171C+T=-5"TQ)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-
M5"LP,3HP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LP,3HP,"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=%=7)O<&4O06US
M=&5R9&%M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT
M<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O06YD;W)R82<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L
M"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3
M=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G
M("DL"B`@("`G175R;W!E+T)E;&=R861E)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E
M;G1R86P@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T-%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O
M<&4O0F5R;&EN)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#
M96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O0G)A=&ES;&%V82<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O
M<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)T-%4U0G("DL"B`@("`G175R;W!E+T)R=7-S96QS)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T-E;G1R86P@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@
M("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4
M:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@
M("=%=7)O<&4O0G5D87!E<W0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%
M=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U<F]P92]#;W!E
M;FAA9V5N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT
M<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O1VEB<F%L=&%R)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N
M(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T53
M5"<@*2P*("`@("=%=7)O<&4O3&IU8FQJ86YA)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T-E;G1R86P@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE
M)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%
M=7)O<&4O3'5X96UB;W5R9R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L($5U
M<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G("DL"B`@("`G175R;W!E+TUA9')I
M9"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%
M=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T-%4U0G("DL"B`@("`G175R;W!E+TUA;'1A)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T-E;G1R86P@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@
M("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4
M:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@
M("=%=7)O<&4O36]N86-O)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@175R
M;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O3W-L;R<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O
M<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)T-%4U0G("DL"B`@("`G175R;W!E+U!A<FES)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T-E;G1R86P@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE
M)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%
M=7)O<&4O4')A9W5E)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S
M-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E
M86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^
M("=#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O4F]M92<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A
M;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-%
M4U0G("DL"B`@("`G175R;W!E+U-A;E]-87)I;F\G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I
M;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@
M)T5U<F]P92]387)A:F5V;R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L($5U
M<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G("DL"B`@("`G175R;W!E+U-K;W!J
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%
M=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T-%4U0G("DL"B`@("`G175R;W!E+U-T;V-K:&]L;2<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3=6UM
M97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G("DL
M"B`@("`G175R;W!E+U1I<F%N92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L
M($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#150G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G("DL"B`@("`G175R;W!E+U9A
M9'5Z)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L
M($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O5F%T:6-A;B<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3=6UM
M97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G("DL
M"B`@("`G175R;W!E+U9I96YN82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L
M($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#150G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G("DL"B`@("`G175R;W!E+U=A
M<G-A=R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A
M;"!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)T-%4U0G("DL"B`@("`G175R;W!E+UIA9W)E8B<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3=6UM
M97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G("DL
M"B`@("`G175R;W!E+UIU<FEC:"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L
M($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#150G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G("DL"B`@("`G3454)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)TUI9&1L92!%=7)O<&4@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)TU%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=-:61D;&4@175R;W!E(%-U;6UE
M<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G34535"<@*2P*
M("`@("=0;VQA;F0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A
M;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T%25"<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=%87-T97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=%150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@
M5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@
M("`G069R:6-A+T)L86YT>7)E)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@
M069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T%4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]"=6IU
M;6)U<F$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!!9G)I8V%N(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#050G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+T-A:7)O)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T5A<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%-U;6UE
M<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G14535"<@*2P*
M("`@("=!9G)I8V$O1V%B;W)O;F4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A
M;"!!9G)I8V%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#050G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+TAA
M<F%R92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L($%F<FEC86X@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-!5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O2F]H86YN97-B=7)G)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)U-O=71H($%F<FEC82!3=&%N9&%R9"!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G4T%35"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O2VEG86QI)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T-E;G1R86P@069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G0T%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T%F<FEC82],=6)U;6)A<VAI)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@
M069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T%4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82],=7-A
M:V$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!!9G)I8V%N(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=#050G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G069R:6-A+TUA<'5T;R<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=#96YT<F%L($%F<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T-!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=!9G)I8V$O36%S97)U)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U-O=71H($%F<FEC
M82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4T%3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O
M36)A8F%N92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=3;W5T:"!!9G)I8V$@4W1A;F1A
M<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U-!4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+U1R:7!O;&DG
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T%S:6$O06UM86XG(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M16%S=&5R;B!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G1454)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%15-4)R`I+`H@("`@)T%S
M:6$O0F5I<G5T)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%
M87-T97)N($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G14535"<@*2P*("`@("=!<VEA+T1A;6%S8W5S)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N
M(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G1453
M5"<@*2P*("`@("=!<VEA+T=A>F$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R
M;B!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@
M("`@("=D<W1S:&]R=&YA;64G(#T^("=%15-4)R`I+`H@("`@)T%S:6$O27-T
M86YB=6PG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E
M<FX@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=%15-4)R`I+`H@("`@)T%S:6$O2F5R=7-A;&5M)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)TES<F%E;"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G25-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TES<F%E;"!$87EL:6=H="!4:6UE
M)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G2414)R`I+`H@("`@)T%S
M:6$O3FEC;W-I82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%150G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@("`G07-I82]496Q?079I=B<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=)<W)A96P@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)TE35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=)<W)A96P@1&%Y;&EG:'0@
M5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TE$5"<@*2P*("`@
M("=#050G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!!9G)I8V%N(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#050G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G1454)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A
M<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G14535"<@*2P*("`@("=%9WEP
M="<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=%150G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!%
M=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T5%4U0G("DL"B`@("`G171C+T=-5"TR)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T=-5"LP,CHP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LP,CHP
M,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=%=7)O<&4O
M071H96YS)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T
M97)N($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G14535"<@*2P*("`@("=%=7)O<&4O0G5C:&%R97-T)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N
M(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G1453
M5"<@*2P*("`@("=%=7)O<&4O0VAI<VEN874G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M16%S=&5R;B!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G1454)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%15-4)R`I+`H@("`@)T5U
M<F]P92](96QS:6YK:2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P
M96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%150G+`H@("`@
M("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]
M/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S
M='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@("`G175R;W!E+TES=&%N8G5L
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($5U
M<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]
M/B`G14535"<@*2P*("`@("=%=7)O<&4O2V%L:6YI;F=R860G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@4W5M
M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%15-4)R`I
M+`H@("`@)T5U<F]P92]+:65V)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@
M175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5%5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^("=%87-T97)N($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@
M("`G9'-T<VAO<G1N86UE)R`]/B`G14535"<@*2P*("`@("=%=7)O<&4O36EN
M<VLG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@
M175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=%15-4)R`I+`H@("`@)T5U<F]P92].:6-O<VEA)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T5A<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%-U;6UE
M<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G14535"<@*2P*
M("`@("=%=7)O<&4O4FEG82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($5U
M<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%150G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@("`G175R;W!E+U-I;69E
M<F]P;VPG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E
M<FX@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=%15-4)R`I+`H@("`@)T5U<F]P92]3;V9I82<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=%87-T97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=%150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM
M97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL
M"B`@("`G175R;W!E+U1A;&QI;FXG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R
M;B!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T5U<F]P92]4
M:7)A<W!O;"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%150G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S
M=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)T5%4U0G("DL"B`@("`G175R;W!E+U5Z:&=O<F]D)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N
M(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G1453
M5"<@*2P*("`@("=%=7)O<&4O5FEL;FEU<R<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%
M87-T97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=%150G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G175R
M;W!E+UIA<&]R;WIH>64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O
M<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)T5A<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=%15-4)R`I+`H@("`@)TES<F%E;"<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=)<W)A96P@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)TE35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=)<W)A96P@1&%Y;&EG:'0@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TE$5"<@*2P*("`@("=,
M:6)Y82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%150G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G5'5R:V5Y)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T5A<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%-U;6UE<B!4:6UE
M)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G14535"<@*2P*("`@("=!
M9G)I8V$O061D:7-?06)A8F$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@
M069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G14%4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]!<VUE
M<F$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$P.#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@069R:6-A;B!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G14%4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]$87)?97-?4V%L86%M)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q,#@P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=%87-T97)N($%F<FEC86X@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T5!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=!9G)I8V$O1&II8F]U=&DG(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T5A<W1E<FX@069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G14%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F
M<FEC82]+86UP86QA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q
M,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($%F<FEC
M86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5!5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O2VAA<G1O=6TG
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$P.#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@069R:6-A;B!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G14%4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T%F<FEC82]-;V=A9&ES:'4G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T5A<W1E<FX@069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G14%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T%F<FEC82].86ER;V)I)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N
M($%F<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5!5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;G1A<F-T:6-A
M+U-Y;W=A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q,#@P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=3>6]W82!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G4UE/5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=!<VEA+T%D96XG(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%R
M86)I82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O
M0F%G:&1A9"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G07)A8FEA(%-T86YD87)D(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G07)A
M8FEA($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=!1%0G("DL"B`@("`G07-I82]"86AR86EN)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=!<F%B:6$@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M<VEA+TMU=V%I="<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G07)A8FEA(%-T86YD87)D
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]1871A<B<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G07)A8FEA(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G07-I82]2:7EA9&@G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%R86)I
M82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T5!5"<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G16%S=&5R;B!!9G)I8V%N(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=%050G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G171C+T=-5"TS)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K
M,#,Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K,#,Z,#`G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G175R;W!E+TUO<V-O
M=R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G36]S8V]W(%-T86YD87)D(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=-4TLG+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G36]S8V]W($1A
M>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=-4T0G
M("DL"B`@("`G26YD:6%N+T%N=&%N86YA<FEV;R<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G16%S=&5R;B!!9G)I8V%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=%050G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M26YD:6%N+T-O;6]R;R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!!9G)I
M8V%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%050G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G26YD:6%N+TUA>6]T=&4G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$P.#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@069R:6-A;B!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G14%4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)U<M4U4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUO<V-O
M=R!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-+
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@)TUO<V-O=R!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G35-$)R`I+`H@("`@)T%S:6$O4FEY861H.#<G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$Q,C(T,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T=-5"LP,SHP-R<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T=-5"LP,SHP-R<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!<VEA+U)I>6%D:#@X)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`Q,3(R-#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K
M,#,Z,#<G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K,#,Z,#<G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]2:7EA9&@X
M.2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3$R,C0P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S`S.C`W)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G1TU4*S`S.C`W)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)TUI9&5A<W0O4FEY861H.#<G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#$Q,C(T,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T=-5"LP,SHP-R<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LP
M,SHP-R<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=-:61E
M87-T+U)I>6%D:#@X)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q
M,3(R-#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K,#,Z,#<G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("='350K,#,Z,#<G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G36ED96%S="]2:7EA9&@X.2<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3$R,C0P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G1TU4*S`S.C`W)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G1TU4*S`S.C`W)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%S:6$O5&5H<F%N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`Q,C8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=)<F%N(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=)4E0G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G27)A
M;B!3=6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G25)3
M5"<@*2P*("`@("=)<F%N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`Q,C8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=)<F%N(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=)4E0G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G27)A;B!3
M=6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G25)35"<@
M*2P*("`@("=!<VEA+T%Q=&%U)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`Q-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!<71A=2!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05%45"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=!
M<71A=2!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)T%15%-4)R`I+`H@("`@)T%S:6$O0F%K=2<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M07IE<F)A:6IA;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05I4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@)T%Z97)B86EJ86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=!6E-4)R`I+`H@("`@)T%S:6$O1'5B86DG(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T=U;&8@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T=35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=!<VEA+TUU<V-A="<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1W5L
M9B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1U-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O5&)I
M;&ES:2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,30T,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1V5O<F=I82!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G1T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T=E;W)G:6$@4W5M;65R
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("='15-4)R`I+`H@
M("`@)T%S:6$O665R979A;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G07)M96YI82!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G04U4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T%R
M;65N:6$@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=!35-4)R`I+`H@("`@)T5T8R]'350M-"<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M1TU4*S`T.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S`T.C`P
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T5U<F]P92]3
M86UA<F$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U-A;6%R82!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G4T%-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=386UA<F$@4W5M;65R
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=304U35"<@*2P*
M("`@("=);F1I86XO36%H92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4V5Y8VAE;&QE
M<R!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4T-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TEN9&EA;B]-875R:71I=7,G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)TUA=7)I=&EU<R!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G3554)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)TEN9&EA;B]2975N:6]N)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=2
M975N:6]N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=2150G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G3D54)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=!<FUE;FEA(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=!350G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`G07)M96YI82!3=6UM97(@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)T%-4U0G("DL"B`@("`G07-I82]+86)U
M;"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,38R,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G069G:&%N:7-T86X@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T%&5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=!<VEA+T%Q=&]B92<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M07%T;V)E(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4514)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@)T%Q=&]B92!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)T%15%-4)R`I+`H@("`@)T%S:6$O07-H9V%B870G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$X,#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)U1U<FMM96YI<W1A;B!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G5$U4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%S:6$O07-H:VAA8F%D)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`Q.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=4=7)K
M;65N:7-T86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U1-5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+T)I<VAK
M96LG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$X,#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)TMI<F=I>G-T86X@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)TM'5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=+:7)G:7IS=&%N(%-U
M;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G2T=35"<@
M*2P*("`@("=!<VEA+T1U<VAA;F)E)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`Q.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=486II
M:VES=&%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=42E0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]+87)A8VAI
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q.#`P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=086MI<W1A;B!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G4$M4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%S:6$O4V%M87)K86YD)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`Q.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=4
M=7)K;65N:7-T86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U1-
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+U1A
M<VAK96YT)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q.#`P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=5>F)E:VES=&%N(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=56E0G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G07-I82]996MA=&5R:6YB=7)G)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q.#`P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=996MA=&5R:6YB=7)G(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=914M4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)UEE:V%T97)I;F)U<F<@4W5M;65R
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=914M35"<@*2P*
M("`@("=%=&,O1TU4+34G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"LP-3HP,"<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LP-3HP,"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=);F1I86XO2V5R9W5E;&5N)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q.#`P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=&<F5N8V@@4V]U=&AE<FX@)B!!;G1A<F-T:6,@
M3&%N9',@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U1&5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=);F1I86XO36%L9&EV
M97,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$X,#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)TUA;&1I=F5S(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=-5E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G4$Q4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`Q.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=086MI<W1A;B!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4$M4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O0V%L8W5T=&$G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$Y.#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)TEN9&EA(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=)4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G25-4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q
M.3@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=);F1I82!3=&%N9&%R
M9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G25-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O2V%T;6%N9'4G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(P-S`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)TYE<&%L(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=.4%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G06YT87)C=&EC82]-87=S;VXG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUA=W-O
M;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G34%75"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;G1A<F-T:6-A+U9O<W1O
M:R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C$V,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G5F]S=&]K('1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=63U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%S:6$O06QM871Y)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`R,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!;&UA
M+4%T82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G04Q-5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=!;&UA+4%T82!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)T%,35-4)R`I+`H@("`@)T%S:6$O0V]L;VUB;R<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C$V,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G4W)I($QA;FMA(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=,2U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G07-I82]$86-C82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0F%N9VQA9&5S:"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0D14)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O1&AA:V$G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#(Q-C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T)A;F=L861E<V@@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T)$5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=!<VEA+TYO=F]S:6)I<G-K)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`R,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=.;W9O<VEB
M:7)S:R!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G3D]65"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=.;W9O<VEB:7)S:R!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)TY/5E-4)R`I+`H@("`@)T%S:6$O3VUS:R<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C$V,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G3VUS:R!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G3TU35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=/;7-K(%-U;6UE<B!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G3TU34U0G("DL"B`@("`G07-I82]4:&EM8G4G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(Q-C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T)H=71A;B!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G0E14)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%S:6$O5&AI;7!H=2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0FAU=&%N
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("="5%0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G0D14)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`R,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("="86YG;&%D97-H(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("="1%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G171C
M+T=-5"TV)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R,38P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K,#8Z,#`G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("='350K,#8Z,#`G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G26YD:6%N+T-H86=O<R<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G26YD:6%N($]C96%N(%1E<G)I=&]R>2!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G24]4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%S:6$O4F%N9V]O;B<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,C,T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G37EA
M;FUA<B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G34U4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TEN9&EA;B]#;V-O<R<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C,T,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G0V]C;W,@27-L86YD<R!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G0T-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T%N=&%R8W1I8V$O1&%V:7,G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T1A=FES(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=$0594
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O0F%N
M9VMO:R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C4R,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G26YD;V-H:6YA(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=)0U0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G07-I82](;W9D)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`R-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=(
M;W9D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=(3U94)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O2F%K87)T82<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C4R,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G5V5S="!);F1O;F5S:6$@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)U=)5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=!<VEA+TMR87-N;WEA<G-K)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`R-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=+<F%S;F]Y87)S:R!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G2U)!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=+<F%S;F]Y87)S:R!3=6UM97(@5&EM92<L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TM205-4)R`I+`H@("`@)T%S:6$O
M4&AN;VU?4&5N:"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C4R
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G26YD;V-H:6YA(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=)0U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]0;VYT:6%N86LG(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#(U,C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)U=E<W0@26YD;VYE<VEA(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=7250G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G07-I82]386EG;VXG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TEN9&]C:&EN
M82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G24-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O5FEE;G1I86YE)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R-3(P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=);F1O8VAI;F$@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)TE#5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=%=&,O1TU4+3<G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"LP-SHP
M,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LP-SHP,"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=);F1I86XO0VAR:7-T;6%S
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R-3(P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=#:')I<W1M87,@27-L86YD(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=#6%0G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G5E-4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`R-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=);F1O
M8VAI;F$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TE#5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;G1A<F-T:6-A+T-A
M<V5Y)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=797-T97)N(%-T86YD87)D(%1I;64@
M*$%U<W1R86QI82DG+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=74U0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]"<G5N96DG
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T)R=6YE:2!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G0DY4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%S:6$O0VAO;F=Q:6YG)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#:&EN
M82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O0VAU
M;F=K:6YG)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#:&EN82!3=&%N9&%R9"!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O2&%R8FEN)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=#:&EN82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T%S:6$O2&]N9U]+;VYG)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=(;VYG($MO
M;F<@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TA+5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+TER:W5T<VLG(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)TER:W5T<VL@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)TE22U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G27)K=71S:R!3=6UM97(@5&EM92<L
M"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TE22U-4)R`I+`H@("`@)T%S
M:6$O2V%S:&=A<B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0VAI;F$@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+TMU86QA7TQU;7!U<B<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G36%L87ES:6$@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)TU95"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!<VEA+TMU8VAI;F<G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUA;&%Y
M<VEA(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-650G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]-86-A;R<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G0VAI;F$@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=!<VEA+TUA;FEL82<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4&AI
M;&EP<&EN97,@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!(5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+U-H86YG
M:&%I)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=#:&EN82!3=&%N9&%R9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T%S:6$O4VEN9V%P;W)E)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=3:6YG87!O<F4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)U-'5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M<VEA+U1A:7!E:2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0VAI;F$@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+U5J=6YG7U!A;F1A;F<G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@26YD;VYE<VEA(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=#250G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G07-I82]5;&%A;F)A871A<B<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G56QA86YB86%T87(@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)U5,050G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G07-I82]5;&%N7T)A=&]R)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=5;&%A;F)A
M871A<B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G54Q!5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+U5R=6UQ:2<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G0VAI;F$@4W1A;F1A<F0@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=!=7-T<F%L:6$O4&5R=&@G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)U=E<W1E<FX@4W1A;F1A<F0@5&EM92`H075S=')A;&EA*2<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)U=35"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=!=7-T<F%L:6$O5V5S="<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G5V5S=&5R;B!3=&%N9&%R9"!4:6UE("A!=7-T<F%L:6$I)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G5U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T-45"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0VAI;F$@4W1A
M;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=%=&,O1TU4+3@G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T=-5"LP.#HP,"<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T=-5"LP.#HP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=(;VYG:V]N9R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G2&]N9R!+;VYG
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=(2U0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4%)#)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=#:&EN82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)U-I;F=A<&]R92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4VEN9V%P;W)E(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=31U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]#:&]I8F%L<V%N)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`S,C0P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=#:&]I8F%L<V%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=#2$]4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T%S:6$O1&EL:2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S="!4:6UO<B!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5%!4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O2F%Y87!U<F$G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,R-#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T5A<W0@26YD;VYE<VEA(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=%250G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G07-I82]0>6]N9WEA;F<G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#,R-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TMO
M<F5A(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=+
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]3
M96]U;"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S(T,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G2V]R96$@4W1A;F1A<F0@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TM35"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+U1O:WEO)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`S,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=*87!A;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G2E-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T%S:6$O66%K=71S:R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G66%K=71S:R!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G64%+5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=986MT
M<VL@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=9
M04M35"<@*2P*("`@("=%=&,O1TU4+3DG(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#,R-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-
M5"LP.3HP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LP.3HP,"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=*4U0G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,R-#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)TIA<&%N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=*4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G2F%P86XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,R-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TIA<&%N(%-T86YD
M87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=*4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R]086QA=2<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S(T,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G4&%L874@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)U!75"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=23TLG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,R-#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TMO<F5A(%-T86YD87)D(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=+4U0G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G04-4)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`S-#(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=#96YT<F%L(%-T86YD87)D(%1I;64@*$YO<G1H97)N(%1E<G)I=&]R>2DG
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G075S=')A;&EA+T%D96QA:61E)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-#(P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64@*%-O=71H($%U
M<W1R86QI82DG+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]
M/B`G0V5N=')A;"!3=6UM97(@5&EM92`H4V]U=&@@075S=')A;&EA*2<L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-35"<@*2P*("`@("=!=7-T<F%L
M:6$O0G)O:V5N7TAI;&PG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,T,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A
M;F1A<F0@5&EM92`H4V]U=&@@075S=')A;&EA+TYE=R!3;W5T:"!786QE<RDG
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A
M;"!3=6UM97(@5&EM92`H4V]U=&@@075S=')A;&EA+TYE=R!3;W5T:"!786QE
M<RDG+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#4U0G("DL"B`@("`G
M075S=')A;&EA+T1A<G=I;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,S0R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3
M=&%N9&%R9"!4:6UE("A.;W)T:&5R;B!497)R:71O<GDI)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%U<W1R86QI82].;W)T:"<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,S0R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M0V5N=')A;"!3=&%N9&%R9"!4:6UE("A.;W)T:&5R;B!497)R:71O<GDI)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T%U<W1R86QI82]3;W5T:"<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,S0R,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE("A3;W5T:"!!=7-T<F%L
M:6$I)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E
M;G1R86P@4W5M;65R(%1I;64@*%-O=71H($%U<W1R86QI82DG+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("=#4U0G("DL"B`@("`G075S=')A;&EA+UEA
M;F-O=VEN;F$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,T,C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A;F1A<F0@
M5&EM92`H4V]U=&@@075S=')A;&EA+TYE=R!3;W5T:"!786QE<RDG+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!3=6UM
M97(@5&EM92`H4V]U=&@@075S=')A;&EA+TYE=R!3;W5T:"!786QE<RDG+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#4U0G("DL"B`@("`G0454)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64@*$YE=R!3
M;W5T:"!786QE<RDG+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G16%S=&5R;B!3=6UM97(@5&EM92`H3F5W(%-O=71H(%=A;&5S*2<L
M"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T535"<@*2P*("`@("=!;G1A
M<F-T:6-A+T1U;6]N=$15<G9I;&QE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`S-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=$=6UO
M;G0M9%PG57)V:6QL92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M1$155"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA
M+U-A:VAA;&EN)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=386MH86QI;B!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G4T%+5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=386MH86QI
M;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U-!
M2U-4)R`I+`H@("`@)T%S:6$O5FQA9&EV;W-T;VLG(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)U9L861I=F]S=&]K(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=63$%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)U9L861I=F]S=&]K(%-U;6UE<B!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G5DQ!4U0G("DL"B`@("`G075S=')A
M;&EA+T%#5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4
M:6UE("A.97<@4V]U=&@@5V%L97,I)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W5M;65R(%1I;64@*$YE=R!3;W5T
M:"!786QE<RDG+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%4U0G("DL
M"B`@("`G075S=')A;&EA+T)R:7-B86YE)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`S-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%
M87-T97)N(%-T86YD87)D(%1I;64@*%%U965N<VQA;F0I)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%U<W1R86QI82]#86YB97)R82<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE("A.97<@4V]U=&@@5V%L97,I)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@
M4W5M;65R(%1I;64@*$YE=R!3;W5T:"!786QE<RDG+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=%4U0G("DL"B`@("`G075S=')A;&EA+TAO8F%R="<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE("A487-M
M86YI82DG+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M16%S=&5R;B!3=6UM97(@5&EM92`H5&%S;6%N:6$I)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G15-4)R`I+`H@("`@)T%U<W1R86QI82],:6YD96UA
M;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE("A1
M=65E;G-L86YD*2<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!=7-T<F%L:6$O365L
M8F]U<FYE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I
M;64@*%9I8W1O<FEA*2<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^("=%87-T97)N(%-U;6UE<B!4:6UE("A6:6-T;W)I82DG+`H@("`@
M("`@("=D<W1S:&]R=&YA;64G(#T^("=%4U0G("DL"B`@("`G075S=')A;&EA
M+TY35R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE
M("A.97<@4V]U=&@@5V%L97,I)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@)T5A<W1E<FX@4W5M;65R(%1I;64@*$YE=R!3;W5T:"!7
M86QE<RDG+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%4U0G("DL"B`@
M("`G075S=')A;&EA+U%U965N<VQA;F0G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A
M<W1E<FX@4W1A;F1A<F0@5&EM92`H475E96YS;&%N9"DG+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G075S=')A;&EA+U-Y9&YE>2<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M16%S=&5R;B!3=&%N9&%R9"!4:6UE("A.97<@4V]U=&@@5V%L97,I)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W5M
M;65R(%1I;64@*$YE=R!3;W5T:"!786QE<RDG+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=%4U0G("DL"B`@("`G075S=')A;&EA+U1A<VUA;FEA)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64@*%1A<VUA
M;FEA*2<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%
M87-T97)N(%-U;6UE<B!4:6UE("A487-M86YI82DG+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=%4U0G("DL"B`@("`G075S=')A;&EA+U9I8W1O<FEA
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64@*%9I
M8W1O<FEA*2<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^
M("=%87-T97)N(%-U;6UE<B!4:6UE("A6:6-T;W)I82DG+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=%4U0G("DL"B`@("`G171C+T=-5"TQ,"<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G1TU4*S$P.C`P)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G1TU4*S$P.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)U!A8VEF:6,O1W5A;2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0VAA;6]R
M<F\@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-H
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I
M8R]0;W)T7TUO<F5S8GDG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!A<'5A($YE=R!'
M=6EN96$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!'5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+U-A:7!A
M;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G0VAA;6]R<F\@4W1A;F1A<F0@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-H4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R]4<G5K)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=4<G5K(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=4
M4E54)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A8VEF
M:6,O66%P)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=987`@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)UE!4%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G075S=')A;&EA+TQ(22<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,S<X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M3&]A9"!(;W=E(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=,2%-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)TQO860@2&]W92!3=6UM97(@5&EM92<L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TQ(4U0G("DL"B`@("`G075S=')A
M;&EA+TQO<F1?2&]W92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,S<X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G3&]A9"!(;W=E(%-T
M86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=,2%-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@)TQO860@2&]W92!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)TQ(4U0G("DL"B`@("`G07-I82]-86=A9&%N)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S.38P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=-86=A9&%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=-04=4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@)TUA9V%D86X@4W5M;65R(%1I;64G+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=-04=35"<@*2P*("`@("=%=&,O
M1TU4+3$Q)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S.38P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K,3$Z,#`G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("='350K,3$Z,#`G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R]%9F%T92<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G5F%N=6%T=2!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M5E54)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A8VEF
M:6,O1W5A9&%L8V%N86PG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,Y-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U-O;&]M;VX@27,N
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=30E0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R]+;W-R864G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,Y-C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)TMO<W)A92!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G2T]35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=086-I9FEC+TYO=6UE82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G3F5W($-A
M;&5D;VYI82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G3D-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O4&]N
M87!E)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S.38P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=0;VYA<&4@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)U!/3E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G4U-4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`S.38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=3;VQO;6]N($ES
M+B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4T)4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O3F]R9F]L:R<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#$T,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G3F]R9F]L:R!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G3D94)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%N=&%R8W1I8V$O36--=7)D;R<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M3F5W(%IE86QA;F0@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)TY:4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`G3F5W(%IE86QA;F0@1&%Y;&EG:'0@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TY:1%0G("DL"B`@("`G
M06YT87)C=&EC82]3;W5T:%]0;VQE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=.97<@
M6F5A;&%N9"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G3EI35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=.97<@6F5A;&%N9"!$87EL:6=H="!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G3EI$5"<@*2P*("`@("=!<VEA
M+T%N861Y<B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#,R,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G06YA9'ER(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=!3D%4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T%N861Y<B!3=6UM
M97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T%.05-4)R`I
M+`H@("`@)T%S:6$O2V%M8VAA=&MA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=0971R
M;W!A=FQO=G-K+4MA;6-H871S:VD@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)U!%5%0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`G4&5T<F]P879L;W9S:RU+86UC:&%T<VMI
M(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G4$54
M4U0G("DL"B`@("`G171C+T=-5"TQ,B<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4
M*S$R.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S$R.C`P)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TMW86IA;&5I;B<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G36%R<VAA;&P@27-L86YD<R!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G34A4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)TY35"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G3F5W(%IE
M86QA;F0@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)TY:4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S
M=&QO;F=N86UE)R`]/B`G3F5W(%IE86QA;F0@1&%Y;&EG:'0@5&EM92<L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TY:1%0G("DL"B`@("`G3EHG(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0S,C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)TYE=R!:96%L86YD(%-T86YD87)D(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=.6E-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TYE=R!:96%L
M86YD($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=.6D14)R`I+`H@("`@)U!A8VEF:6,O075C:VQA;F0G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#0S,C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)TYE=R!:96%L86YD(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=.6E-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TYE=R!:96%L86YD($1A>6QI
M9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=.6D14)R`I
M+`H@("`@)U!A8VEF:6,O1FEJ:2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1FEJ:2!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1DI4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O1G5N869U=&DG(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0S,C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)U1U=F%L=2!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G5%94)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)U!A8VEF:6,O2W=A:F%L96EN)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-87)S
M:&%L;"!)<VQA;F1S(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-
M2%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I
M8R]-86IU<F\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0S,C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUA<G-H86QL($ES;&%N9',@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU(5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+TYA=7)U)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=.875R=2!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G3E)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)U!A8VEF:6,O5&%R87=A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`T,S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=':6QB97)T($ES
M+B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TE,5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+U=A:V4G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0S,C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)U=A:V4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)U=!2U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G4&%C:69I8R]786QL:7,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#0S,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U=A;&QI<R`F
M($9U='5N82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5T94)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TY:+4-(050G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0U.3`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T-H871H86T@4W1A;F1A<F0@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T-(05-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-H871H86T@1&%Y
M;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-(0414
M)R`I+`H@("`@)U!A8VEF:6,O0VAA=&AA;2<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@-#4Y,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M0VAA=&AA;2!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G0TA!4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`G0VAA=&AA;2!$87EL:6=H="!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0TA!1%0G("DL"B`@("`G171C+T=-
M5"TQ,R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#8X,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S$S.C`P)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G1TU4*S$S.C`P)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)U!A8VEF:6,O16YD97)B=7)Y)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`T-C@P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=0:&]E;FEX($ES+B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G4$A/5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=086-I9FEC+U1O;F=A=&%P=2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@-#8X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5&]N9V$@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U1/5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=%=&,O1TU4+3$T)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`U,#0P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("='350K,30Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("='350K,30Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G4&%C:69I8R]+:7)I=&EM871I)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`U,#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=,:6YE
M($ES+B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G3$E.5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("='350M,3(Z,#`G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TT,S(P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("='350M,3(Z,#`G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("='350M,3(Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G1TU4+3$Q.C`P)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4+3$Q
M.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4+3$Q.C`P)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U=E<W0@4V%M;V$@5&EM
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,Y-C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)U=E<W0@4V%M;V$@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)U=35"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=386UO82!3=&%N9&%R9"!4:6UE)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G4V%M;V$@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)U-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=.:75E(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TS.38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=.:75E(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=.550G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G2&%W86EI+4%L975T:6%N(%-T86YD87)D
M(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS-C`P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=(87=A:6DM06QE=71I86X@4W1A
M;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TA!4U0G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G2&%W86EI+4%L975T:6%N($1A>6QI9VAT(%1I;64G+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("=(0414)R`I+`H@("`@)T=-5"TQ,#HP,"<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,V,#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T=-5"TQ,#HP,"<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T=-5"TQ,#HP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=(87=A:6D@4W1A;F1A<F0@5&EM92<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)TAA=V%I:2!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G2%-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)U1O:V5L874@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U1O:V5L874@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U1+5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=#;V]K($ES+B!4:6UE)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S8P,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G0V]O:R!)<RX@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T-+5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=486AI=&D@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U1A:&ET:2!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5$%(5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=-87)Q=65S87,@5&EM92<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,T,C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)TUA<G%U97-A<R!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G34%25"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!;&%S:V$@4W1A;F1A<F0@5&EM92<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3,R-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T%L87-K82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G04M35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@
M("`G9'-T;&]N9VYA;64G(#T^("=!;&%S:V$@1&%Y;&EG:'0@5&EM92<L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T%+1%0G("DL"B`@("`G1TU4+3`Y
M.C`P)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S(T,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4+3`Y.C`P)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G1TU4+3`Y.C`P)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T=A;6)I97(@5&EM92<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3,R-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T=A;6)I97(@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=!
M350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I
M8R!3=&%N9&%R9"!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4&%C:69I8R!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4%-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@)U!A8VEF:6,@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)U!$5"<@*2P*("`@("='350M,#@Z,#`G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TR.#@P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("='350M,#@Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("='350M,#@Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G4&ET8V%I<FX@4W1A;F1A<F0@5&EM92<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+3(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)U!I=&-A:7)N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=04U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M36]U;G1A:6X@4W1A;F1A<F0@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUO
M=6YT86EN(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=-4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S
M=&QO;F=N86UE)R`]/B`G36]U;G1A:6X@1&%Y;&EG:'0@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)TU$5"<@*2P*("`@("='350M,#<Z,#`G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("='350M,#<Z,#`G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("='350M,#<Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G0V5N=')A;"!3=&%N9&%R9"!4:6UE)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@1&%Y;&EG:'0@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-$5"<@*2P*("`@("=%
M87-T97)N(%-T86YD87)D(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T
M97)N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G16%S=&5R;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G1414)R`I+`H@("`@)T5A<W1E<B!)<RX@5&EM
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<B!)<RX@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T5!4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R($ES+B!3
M=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5!4U-4
M)R`I+`H@("`@)T=-5"TP-CHP,"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"TP
M-CHP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"TP-CHP,"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("='86QA<&%G;W,@5&EM
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T=A;&%P86=O<R!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G1T%,5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=#;VQO;6)I82!4:6UE)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G0V]L;VUB:6$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-/
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!8W)E(%1I
M;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=!8W)E(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=!0U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G16-U861O<B!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16-U
M861O<B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G14-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!E<G4@5&EM92<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)U!E<G4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)U!%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("='350M,#4Z,#`G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ
M.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350M,#4Z,#`G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("='350M,#4Z,#`G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G071L86YT:6,@4W1A;F1A<F0@5&EM
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T%T;&%N=&EC(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G071L86YT
M:6,@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)T%$5"<@*2P*("`@("=087)A9W5A>2!4:6UE)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G4&%R86=U87D@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!9
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^("=087)A9W5A>2!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S
M='-H;W)T;F%M92<@/3X@)U!94U0G("DL"B`@("`G06UA>F]N(%-T86YD87)D
M(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!;6%Z;VX@4W1A;F1A<F0@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%-5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=696YE>G5E;&$@5&EM92<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)U9E;F5Z=65L82!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G5D54)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T=U>6%N82!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1W5Y86YA(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='650G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G0F]L:79I82!4:6UE)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G0F]L:79I82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G0D]4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T-H:6QE(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ
M-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#:&EL92!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G0TQ4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-H:6QE(%-U
M;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0TQ35"<@
M*2P*("`@("=&86QK;&%N9"!)<RX@5&EM92<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T9A;&ML86YD($ES+B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M1DM4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@)T9A;&ML86YD($ES+B!3=6UM97(@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)T9+4U0G("DL"B`@("`G1TU4+3`T.C`P
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G1TU4+3`T.C`P)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G1TU4+3`T.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)TYE=V9O=6YD;&%N9"!3=&%N9&%R9"!4:6UE)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3(V,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G3F5W9F]U;F1L86YD(%-T86YD87)D(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=.4U0G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G3F5W9F]U;F1L
M86YD($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=.1%0G("DL"B`@("`G07)G96YT:6YE(%1I;64G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=!<F=E;G1I;F4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T%25"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("="<F%Z
M:6P@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$P.#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T)R87II;"!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G0E)4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T)R87II;"!3=6UM
M97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T)24U0G("DL
M"B`@("`G1G)E;F-H($=U:6%N82!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M1G)E;F-H($=U:6%N82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M1T94)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U=E<W1E
M<FX@1W)E96YL86YD(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TQ,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=797-T97)N
M($=R965N;&%N9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5T=4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@)U=E<W1E<FX@1W)E96YL86YD(%-U;6UE<B!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G5T=35"<@*2P*("`@("=0:65R<F4@
M)B!-:7%U96QO;B!3=&%N9&%R9"!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M4&EE<G)E("8@36EQ=65L;VX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)U!-4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L
M"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G4&EE<G)E("8@36EQ=65L;VX@
M1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U!-
M1%0G("DL"B`@("`G57)U9W5A>2!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M57)U9W5A>2!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G55E4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U-U<FEN86UE(%1I
M;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=3=7)I;F%M92!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G4U)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T=-5"TP,SHP,"<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-
M5"TP,SHP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"TP,SHP,"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=&97)N86YD;R!D
M92!.;W)O;FAA(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TW,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T9E<FYA;F1O(&1E
M($YO<F]N:&$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T9.5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=3;W5T:"!'96]R
M9VEA(%-T86YD87)D(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TW,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U-O=71H($=E
M;W)G:6$@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T=35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("='350M
M,#(Z,#`G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TW,C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"TP,CHP,"<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T=-5"TP,CHP,"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=%87-T97)N($=R965N;&%N9"!4:6UE)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T5A<W1E<FX@1W)E96YL86YD(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=%1U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!'<F5E;FQA
M;F0@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%
M1U-4)R`I+`H@("`@)T%Z;W)E<R!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!
M>F]R97,@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%:3U0G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G07IO<F5S(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G05I/4U0G("DL"B`@("`G0V%P92!697)D92!4:6UE)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S8P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=#87!E(%9E<F1E(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=#5E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G1TU4+3`Q.C`P)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350M,#$Z,#`G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350M,#$Z,#`G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G1W)E96YW:6-H($UE86X@5&EM
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("='<F5E;G=I8V@@365A;B!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)U=E<W1E<FX@175R;W!E86X@5&EM92<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=7
M97-T97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=7150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S
M=&QO;F=N86UE)R`]/B`G5V5S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L
M"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U=%4U0G("DL"B`@("`G1TU4
M*S`P.C`P)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T=-5"LP,#HP,"<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T=-5"LP,#HP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=#;V]R9&EN871E9"!5;FEV97)S86P@5&EM92<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=#;V]R9&EN871E9"!5;FEV97)S86P@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)U540R<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=#96YT<F%L($5U<F]P96%N(%1I;64G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I
M;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@
M)U=E<W1E<FX@069R:6-A;B!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U=E<W1E
M<FX@069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5T%4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@)U=E<W1E<FX@069R:6-A;B!3=6UM97(@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)U=!4U0G("DL"B`@("`G1TU4*S`Q.C`P
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T=-5"LP,3HP,"<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T=-5"LP,3HP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=-:61D;&4@175R;W!E(%1I;64G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G36ED9&QE($5U<F]P92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G3454)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)TUI9&1L92!%=7)O<&4@4W5M;65R(%1I;64G+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=-15-4)R`I+`H@("`@)T5A<W1E
M<FX@175R;W!E86X@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($5U
M<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%150G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@("`G0V5N=')A;"!!9G)I
M8V%N(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!!9G)I8V%N(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#050G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4V]U=&@@069R:6-A(%-T86YD87)D
M(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4V]U=&@@069R:6-A(%-T86YD87)D
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=305-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TES<F%E;"!3=&%N9&%R9"!4
M:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)TES<F%E;"!3=&%N9&%R9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G25-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TES<F%E;"!$
M87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G2414
M)R`I+`H@("`@)T=-5"LP,CHP,"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K,#(Z
M,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K,#(Z,#`G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G16%S=&5R;B!!9G)I8V%N
M(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$P.#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@069R:6-A;B!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G14%4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)U-Y;W=A(%1I;64G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)U-Y;W=A(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=3
M64]4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%R86)I
M82!3=&%N9&%R9"!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!<F%B:6$@4W1A
M;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("='350K,#,Z,#`G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$P.#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T=-5"LP,SHP,"<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T=-5"LP,SHP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=-;W-C;W<@4W1A;F1A<F0@5&EM92<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G36]S8V]W(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=-4TLG+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`G36]S8V]W($1A>6QI9VAT(%1I;64G+`H@("`@
M("`@("=D<W1S:&]R=&YA;64G(#T^("=-4T0G("DL"B`@("`G1TU4*S`S.C`W
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q,3(R-#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("='350K,#,Z,#<G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("='350K,#,Z,#<G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G27)A;B!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`Q,C8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=)<F%N
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=)4E0G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M27)A;B!3=6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M25)35"<@*2P*("`@("=!<71A=2!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!
M<71A=2!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05%45"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=!<71A=2!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)T%15%-4)R`I+`H@("`@)T%Z97)B86EJ86X@5&EM92<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,30T,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G07IE<F)A:6IA;B!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G05I4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@)T%Z97)B86EJ86X@4W5M;65R(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!6E-4)R`I+`H@("`@)T=U
M;&8@4W1A;F1A<F0@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1W5L9B!3=&%N
M9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1U-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T=E;W)G:6$@5&EM92<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,30T,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G1V5O<F=I82!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G1T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T=E;W)G:6$@4W5M;65R(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("='15-4)R`I+`H@("`@)T%R
M;65N:6$@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,30T
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G07)M96YI82!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G04U4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T%R;65N:6$@
M4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!35-4
M)R`I+`H@("`@)T=-5"LP-#HP,"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S`T
M.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S`T.C`P)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U-A;6%R82!4:6UE)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=386UA<F$@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)U-!350G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G4V%M87)A(%-U;6UE<B!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G4T%-4U0G("DL"B`@("`G4V5Y
M8VAE;&QE<R!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q
M-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=397EC:&5L;&5S(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=30U0G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G36%U<FET:75S(%1I;64G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)TUA=7)I=&EU<R!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G3554)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)U)E=6YI;VX@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4F5U;FEO;B!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4D54)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F9VAA;FES=&%N(%1I;64G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$V,C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T%F9VAA;FES=&%N(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=!1E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G07%T;V)E(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%Q=&]B
M92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05%45"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^
M("=!<71O8F4@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=!45135"<@*2P*("`@("=4=7)K;65N:7-T86X@5&EM92<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3@P,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G5'5R:VUE;FES=&%N(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=4350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G2VER9VEZ<W1A;B!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`Q.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=+:7)G
M:7IS=&%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=+1U0G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G2VER9VEZ<W1A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)TM'4U0G("DL"B`@("`G5&%J:6MI<W1A;B!4:6UE)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q.#`P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=486II:VES=&%N(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=42E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G4&%K:7-T86X@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4&%K
M:7-T86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!+5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=5>F)E:VES=&%N(%1I
M;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$X,#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)U5Z8F5K:7-T86X@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)U5:5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=996MA=&5R:6YB=7)G(%1I;64G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)UEE:V%T97)I;F)U<F<@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)UE%2U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`G665K871E<FEN8G5R9R!3=6UM97(@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)UE%2U-4)R`I+`H@("`@
M)T=-5"LP-3HP,"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3@P
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S`U.C`P)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S`U.C`P)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T9R96YC:"!3;W5T:&5R;B`F($%N=&%R
M8W1I8R!,86YD<R!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`Q.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=&<F5N8V@@4V]U
M=&AE<FX@)B!!;G1A<F-T:6,@3&%N9',@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)U1&5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=-86QD:79E<R!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`Q.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-86QD:79E
M<R!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G3594)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TEN9&EA(%-T86YD87)D(%1I
M;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$Y.#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)TEN9&EA(%-T86YD87)D(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=)4U0G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G3F5P86P@5&EM92<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,C`W,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G3F5P86P@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TY05"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=-87=S;VX@5&EM
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C$V,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G36%W<V]N(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=-05=4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)U9O<W1O:R!T:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`R,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=6;W-T
M;VL@=&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U9/4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06QM82U!=&$@5&EM92<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C$V,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G06QM82U!=&$@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T%,350G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L
M"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G06QM82U!=&$@4W5M;65R(%1I
M;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!3$U35"<@*2P*("`@
M("=3<FD@3&%N:V$@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4W)I($QA;FMA
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=,2U0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G0F%N9VQA9&5S:"!4:6UE)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R,38P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("="86YG;&%D97-H(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("="1%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G3F]V;W-I8FER<VL@5&EM92<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M3F]V;W-I8FER<VL@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TY/
M5E0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G3F]V;W-I8FER<VL@4W5M;65R(%1I;64G+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("=.3U935"<@*2P*("`@("=/;7-K(%1I;64G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(Q-C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T]M<VL@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T]-4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G3VUS:R!3=6UM97(@5&EM92<L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T]-4U-4)R`I+`H@("`@)T)H=71A
M;B!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R,38P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=":'5T86X@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T)45"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("='350K,#8Z,#`G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-
M5"LP-CHP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LP-CHP,"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=);F1I86X@3V-E
M86X@5&5R<FET;W)Y(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TEN9&EA;B!/
M8V5A;B!497)R:71O<GD@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)TE/5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=->6%N
M;6%R(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(S-#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUY86YM87(@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)TU-5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=#;V-O<R!)<VQA;F1S(%1I;64G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#(S-#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T-O8V]S($ES;&%N9',@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T-#5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=$879I<R!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`R-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=$879I<R!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1$%65"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=);F1O8VAI;F$@5&EM92<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C4R,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G26YD;V-H:6YA(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=)0U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G2&]V9"!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R
M-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=(;W9D(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=(3U94)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)U=E<W0@26YD;VYE<VEA(%1I;64G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(U,C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)U=E<W0@26YD;VYE<VEA(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=7250G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G2W)A<VYO>6%R<VL@5&EM92<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M2W)A<VYO>6%R<VL@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TM2
M050G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G2W)A<VYO>6%R<VL@4W5M;65R(%1I;64G+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("=+4D%35"<@*2P*("`@("='350K,#<Z,#`G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(U,C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T=-5"LP-SHP,"<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T=-5"LP-SHP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=#:')I<W1M87,@27-L86YD(%1I;64G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T-H<FES=&UA<R!)<VQA;F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T-85"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=797-T97)N(%-T86YD87)D(%1I;64@*$%U<W1R86QI82DG(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)U=E<W1E<FX@4W1A;F1A<F0@5&EM92`H075S=')A;&EA
M*2<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U=35"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("="<G5N96D@5&EM92<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G0G)U;F5I(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("="3E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G0VAI
M;F$@4W1A;F1A<F0@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0VAI;F$@4W1A
M;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=(;VYG($MO;F<@5&EM
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G2&]N9R!+;VYG(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=(2U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G27)K=71S:R!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=)
M<FMU='-K(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=)4DM4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@)TER:W5T<VL@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=)4DM35"<@*2P*("`@("=-86QA>7-I82!4:6UE)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=-86QA>7-I82!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G35E4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)U!H:6QI<'!I;F5S(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!H:6QI
M<'!I;F5S(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=02%0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4VEN9V%P;W)E(%1I
M;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)U-I;F=A<&]R92!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G4T=4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T-E;G1R86P@26YD;VYE<VEA(%1I;64G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T-E;G1R86P@26YD;VYE<VEA(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=#250G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G56QA86YB86%T87(@5&EM92<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M56QA86YB86%T87(@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U5,
M050G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G1TU4*S`X
M.C`P)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("='350K,#@Z,#`G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("='350K,#@Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G0VAO:6)A;'-A;B!4:6UE)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`S,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=#:&]I8F%L<V%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=#2$]4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T5A
M<W0@5&EM;W(@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S="!4:6UO<B!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5%!4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T5A<W0@26YD;VYE<VEA(%1I;64G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,R-#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T5A<W0@26YD;VYE<VEA(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=%250G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G2V]R96$@4W1A;F1A<F0@5&EM92<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G2V]R96$@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)TM35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=*87!A;B!3=&%N9&%R9"!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`S,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=*
M87!A;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M2E-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)UEA:W5T
M<VL@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S(T,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G66%K=71S:R!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G64%+5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=986MT<VL@4W5M
M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=904M35"<@
M*2P*("`@("='350K,#DZ,#`G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#,R-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"LP.3HP
M,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LP.3HP,"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086QA=2!4:6UE)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S,C0P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=086QA=2!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G4%=4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T-E;G1R86P@4W1A;F1A<F0@5&EM92`H3F]R=&AE<FX@5&5R<FET;W)Y*2<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S0R,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE("A.;W)T
M:&5R;B!497)R:71O<GDI)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T-E;G1R86P@
M4W1A;F1A<F0@5&EM92`H4V]U=&@@075S=')A;&EA*2<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,S0R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE("A3;W5T:"!!=7-T<F%L:6$I
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R
M86P@4W5M;65R(%1I;64@*%-O=71H($%U<W1R86QI82DG+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=#4U0G("DL"B`@("`G0V5N=')A;"!3=&%N9&%R
M9"!4:6UE("A3;W5T:"!!=7-T<F%L:6$O3F5W(%-O=71H(%=A;&5S*2<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S0R,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE("A3;W5T:"!!
M=7-T<F%L:6$O3F5W(%-O=71H(%=A;&5S*2<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@
M("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L(%-U;6UE<B!4:6UE("A3;W5T
M:"!!=7-T<F%L:6$O3F5W(%-O=71H(%=A;&5S*2<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)T-35"<@*2P*("`@("=%87-T97)N(%-T86YD87)D(%1I
M;64@*$YE=R!3;W5T:"!786QE<RDG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E
M<FX@4W1A;F1A<F0@5&EM92`H3F5W(%-O=71H(%=A;&5S*2<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N(%-U;6UE<B!4
M:6UE("A.97<@4V]U=&@@5V%L97,I)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G15-4)R`I+`H@("`@)T1U;6]N="UD7"=5<G9I;&QE(%1I;64G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T1U;6]N="UD7"=5<G9I;&QE(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=$1%54)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)U-A:VAA;&EN(%1I;64G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)U-A:VAA;&EN(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=3
M04M4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@)U-A:VAA;&EN(%-U;6UE<B!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G4T%+4U0G("DL"B`@("`G5FQA9&EV;W-T;VL@
M5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5FQA9&EV;W-T;VL@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)U9,050G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G5FQA9&EV;W-T
M;VL@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=6
M3$%35"<@*2P*("`@("=%87-T97)N(%-T86YD87)D(%1I;64@*%%U965N<VQA
M;F0I)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64@
M*%%U965N<VQA;F0I)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T5A<W1E<FX@4W1A
M;F1A<F0@5&EM92`H5&%S;6%N:6$I)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`S-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T
M97)N(%-T86YD87)D(%1I;64@*%1A<VUA;FEA*2<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N(%-U;6UE<B!4:6UE("A4
M87-M86YI82DG+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%4U0G("DL
M"B`@("`G16%S=&5R;B!3=&%N9&%R9"!4:6UE("A6:6-T;W)I82DG(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92`H5FEC=&]R:6$I
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E
M<FX@4W5M;65R(%1I;64@*%9I8W1O<FEA*2<L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)T535"<@*2P*("`@("='350K,3`Z,#`G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T=-5"LQ,#HP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-
M5"LQ,#HP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=#
M:&%M;W)R;R!3=&%N9&%R9"!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`S-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#:&%M
M;W)R;R!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M0VA35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=087!U
M82!.97<@1W5I;F5A(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!A<'5A($YE
M=R!'=6EN96$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!'5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=4<G5K(%1I;64G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)U1R=6L@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)U12550G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G66%P(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)UEA<"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G64%05"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=,;V%D($AO=V4@4W1A;F1A<F0@5&EM92<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S<X,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G3&]A9"!(;W=E(%-T86YD87)D(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=,2%-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TQO860@2&]W
M92!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TQ(
M4U0G("DL"B`@("`G36%G861A;B!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`S.38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-
M86=A9&%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-04=4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@)TUA9V%D86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=-04=35"<@*2P*("`@("='350K,3$Z,#`G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#,Y-C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T=-5"LQ,3HP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T=-5"LQ,3HP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=686YU871U(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,Y-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U9A;G5A='4@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U955"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=3;VQO;6]N($ES+B!4:6UE)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S.38P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=3;VQO;6]N($ES+B!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G4T)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)TMO<W)A92!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`S.38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=+;W-R864@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TM/4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G3F5W($-A;&5D;VYI82!4:6UE
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S.38P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=.97<@0V%L961O;FEA(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=.0U0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G4&]N87!E(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#,Y-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)U!O;F%P92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4$].5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=.;W)F;VQK(%1I
M;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0Q-#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)TYO<F9O;&L@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)TY&5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=.97<@6F5A;&%N9"!3=&%N9&%R9"!4:6UE)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=.97<@6F5A;&%N9"!3=&%N9&%R9"!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G3EI35"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=.97<@6F5A;&%N9"!$
M87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G3EI$
M5"<@*2P*("`@("=!;F%D>7(@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G06YA
M9'ER(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!3D%4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)T%N861Y<B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)T%.05-4)R`I+`H@("`@)U!E=')O<&%V;&]V<VLM2V%M8VAA='-K
M:2!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T,S(P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=0971R;W!A=FQO=G-K+4MA;6-H
M871S:VD@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!%5%0G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G4&5T<F]P879L;W9S:RU+86UC:&%T<VMI(%-U;6UE<B!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G4$544U0G("DL"B`@("`G1TU4
M*S$R.C`P)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T,S(P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K,3(Z,#`G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("='350K,3(Z,#`G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G36%R<VAA;&P@27-L86YD<R!4:6UE)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=-87)S:&%L;"!)<VQA;F1S(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=-2%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G1FEJ:2!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=&:6II
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=&2E0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G5'5V86QU(%1I;64G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0S,C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)U1U=F%L=2!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G5%94)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)TYA=7)U(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0S
M,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TYA=7)U(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=.4E0G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G1VEL8F5R="!)<RX@5&EM92<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G1VEL8F5R="!)<RX@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T=)3%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G5V%K92!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T
M,S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=786ME(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=704M4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)U=A;&QI<R`F($9U='5N82!4:6UE)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=786QL:7,@)B!&=71U;F$@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)U=&5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=#:&%T:&%M(%-T86YD87)D(%1I;64G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#0U.3`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T-H871H86T@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T-(05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-H871H86T@1&%Y;&EG:'0@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-(0414)R`I+`H@("`@
M)T=-5"LQ,SHP,"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#8X
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S$S.C`P)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S$S.C`P)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)U!H;V5N:7@@27,N(%1I;64G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0V.#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)U!H;V5N:7@@27,N(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=02$]4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)U1O;F=A(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#0V.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U1O;F=A(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=43U0G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G1TU4*S$T.C`P)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`U,#0P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("='350K,30Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='
M350K,30Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M3&EN92!)<RX@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M-3`T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G3&EN92!)<RX@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TQ)3E0G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"BD["@HO+PHO+R!);FET:6%L:7IE(&1E9F%U
M;'0@=&EM97IO;F4*+R\@($9I<G-T('1R>2!?1$%415]424U%6D].15]$149!
M54Q4(&=L;V)A;"P*+R\@('1H96X@4$A07U1:(&5N=FER;VYM96YT('9A<BP@
M=&AE;B!46B!E;G9I<F]N;65N="!V87(*+R\*:68H:7-S970H)%]$051%7U1)
M345:3TY%7T1%1D%53%0I"B`@("`F)B!$871E7U1I;65:;VYE.CII<U9A;&ED
M240H)%]$051%7U1)345:3TY%7T1%1D%53%0I"BD@>PH@("`@1&%T95]4:6UE
M6F]N93HZ<V5T1&5F875L="@D7T1!5$5?5$E-15I/3D5?1$5&055,5"D["GT@
M96QS96EF("AG971E;G8H)U!(4%]46B<I("8F($1A=&5?5&EM95IO;F4Z.FES
M5F%L:61)1"AG971E;G8H)U!(4%]46B<I*2D@>PH@("`@1&%T95]4:6UE6F]N
M93HZ<V5T1&5F875L="AG971E;G8H)U!(4%]46B<I*3L*?2!E;'-E:68@*&=E
M=&5N=B@G5%HG*2`F)B!$871E7U1I;65:;VYE.CII<U9A;&ED240H9V5T96YV
M*"=46B<I*2D@>PH@("`@1&%T95]4:6UE6F]N93HZ<V5T1&5F875L="AG971E
M;G8H)U1:)RDI.PI](&5L<V5I9B`H1&%T95]4:6UE6F]N93HZ:7-686QI9$E$
M*&1A=&4H)U0G*2DI('L*("`@($1A=&5?5&EM95IO;F4Z.G-E=$1E9F%U;'0H
M9&%T92@G5"<I*3L*?2!E;'-E('L*("`@($1A=&5?5&EM95IO;F4Z.G-E=$1E
M9F%U;'0H)U540R<I.PI]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]$871E+G!H
M<```````````````````````````````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#$Q,S`P,``Q,#4Q-30S,S<T,P`P,C`Q-C4`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RH@=FEM.B!S970@97AP
M86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-#H@
M*B\*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P
M>7)I9VAT("AC*2`Q.3DW+3(P,#4@0F%B82!"=65H;&5R+"!0:65R<F4M06QA
M:6X@2F]Y92`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@
M=&AE($YE=R!"4T0@;&EC96YS92P@5&AA="!I<R!B=6YD;&5D("!\"B\O('P@
M=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES
M(&%V86EL86)L92!T:')O=6=H("`@("`@?`HO+R!\('1H92!W;W)L9"UW:61E
M+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI
M8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@("`@("`@("`@("`@("`@("!\"B\O
M('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(&YE=R!"
M4T1L:6-E;G-E(&%N9"!A<F4@=6YA8FQE("`@?`HO+R!\('1O(&]B=&%I;B!I
M="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N
M;W1E('1O("`@("`@('P*+R\@?"!P96%R+61E=D!L:7-T<RYP:'`N;F5T('-O
M('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@
M0F%B82!"=65H;&5R(#QB86)A0&)A8F%Z+F-O;3X@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@(%!I97)R92U!;&%I;B!*
M;WEE(#QP86IO>65`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*+RHJ"B`J($=E
M;F5R:6,@9&%T92!H86YD;&EN9R!C;&%S<R!F;W(@4$5!4@H@*@H@*B!'96YE
M<FEC(&1A=&4@:&%N9&QI;F<@8VQA<W,@9F]R(%!%05(N("!!='1E;7!T<R!T
M;R!B92!T:6UE('IO;F4@87=A<F4*("H@=&AR;W5G:"!T:&4@1&%T93HZ5&EM
M95IO;F4@8VQA<W,N("!3=7!P;W)T<R!S979E<F%L(&]P97)A=&EO;G,@9G)O
M;0H@*B!$871E.CI#86QC(&]N($1A=&4@;V)J96-T<RX*("H*("H@0&-A=&5G
M;W)Y("`@1&%T92!A;F0@5&EM90H@*B!`<&%C:V%G92`@("!$871E"B`J($!A
M=71H;W(@("`@($)A8F$@0G5E:&QE<B`\8F%B84!B86)A>BYC;VT^"B`J($!A
M=71H;W(@("`@(%!I97)R92U!;&%I;B!*;WEE(#QP86IO>65`<&AP+FYE=#X*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI
M8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B
M<V0M;&EC96YS92YP:'`@($YE=R!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@
M("!#5E,Z("1)9#H@1&%T92YP:'`L=B`Q+C,U(#(P,#4O,3$O,34@,#`Z,38Z
M,S@@<&%J;WEE($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H
M<"YN970O<&%C:V%G92]$871E"B`J+PH*+RHJ0",K"B`J($EN8VQU9&4@<W5P
M<&]R=&EN9R!C;&%S<V5S"B`J+PIR97%U:7)E7V]N8V4@)T1A=&4O5&EM95IO
M;F4N<&AP)SL*<F5Q=6ER95]O;F-E("=$871E+T-A;&,N<&AP)SL*<F5Q=6ER
M95]O;F-E("=$871E+U-P86XN<&AP)SL*+RHJ0",M*B\*"B\J*D`C*PH@*B!/
M=71P=70@9F]R;6%T<RX@(%!A<W,@=&AI<R!T;R!G971$871E*"DN"B`J+PHO
M*BH*("H@(EE965DM34TM1$0@2$@Z34TZ4U,B"B`J+PID969I;F4H)T1!5$5?
M1D]234%47TE33R<L(#$I.PHO*BH*("H@(EE965E-35-35$A(34U34RA:?"@K
M+RTI2$A-32D_(@H@*B\*9&5F:6YE*"=$051%7T9/4DU!5%])4T]?0D%324,G
M+"`R*3L*+RHJ"B`J(")965E9+4U-+5-35$A(.DU-.E-3*%I\*"LO+2E(2#I-
M32D_(@H@*B\*9&5F:6YE*"=$051%7T9/4DU!5%])4T]?15A414Y$140G+"`S
M*3L*+RHJ"B`J(")965E9+4U-+5-35$A(.DU-.E-3*"Y3*BD_*%I\*"LO+2E(
M2#I-32D_(@H@*B\*9&5F:6YE*"=$051%7T9/4DU!5%])4T]?15A414Y$141?
M34E#4D]424U%)RP@-BD["B\J*@H@*B`B65E964U-1$1(2$U-4U,B"B`J+PID
M969I;F4H)T1!5$5?1D]234%47U1)34535$%-4"<L(#0I.PHO*BH*("H@;&]N
M9R!I;G0L('-E8V]N9',@<VEN8V4@=&AE('5N:7@@97!O8V@*("HO"F1E9FEN
M92@G1$%415]&3U)-051?54Y)6%1)344G+"`U*3L*+RHJ0",M*B\*"B\J*@H@
M*B!'96YE<FEC(&1A=&4@:&%N9&QI;F<@8VQA<W,@9F]R(%!%05(*("H*("H@
M1V5N97)I8R!D871E(&AA;F1L:6YG(&-L87-S(&9O<B!014%2+B`@071T96UP
M=',@=&\@8F4@=&EM92!Z;VYE(&%W87)E"B`J('1H<F]U9V@@=&AE($1A=&4Z
M.E1I;65:;VYE(&-L87-S+B`@4W5P<&]R=',@<V5V97)A;"!O<&5R871I;VYS
M(&9R;VT*("H@1&%T93HZ0V%L8R!O;B!$871E(&]B:F5C=',N"B`J"B`J($!A
M=71H;W(@("`@($)A8F$@0G5E:&QE<B`\8F%B84!B86)A>BYC;VT^"B`J($!A
M=71H;W(@("`@(%!I97)R92U!;&%I;B!*;WEE(#QP86IO>65`<&AP+FYE=#X*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI
M8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B
M<V0M;&EC96YS92YP:'`@($YE=R!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@
M("!296QE87-E.B`Q+C0N-@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O1&%T90H@*B\*8VQA<W,@1&%T90I["B`@("`O*BH*
M("`@("`J('1H92!Y96%R"B`@("`@*B!`=F%R(&EN=`H@("`@("HO"B`@("!V
M87(@)'EE87(["B`@("`O*BH*("`@("`J('1H92!M;VYT:`H@("`@("H@0'9A
M<B!I;G0*("`@("`J+PH@("`@=F%R("1M;VYT:#L*("`@("\J*@H@("`@("H@
M=&AE(&1A>0H@("`@("H@0'9A<B!I;G0*("`@("`J+PH@("`@=F%R("1D87D[
M"B`@("`O*BH*("`@("`J('1H92!H;W5R"B`@("`@*B!`=F%R(&EN=`H@("`@
M("HO"B`@("!V87(@)&AO=7(["B`@("`O*BH*("`@("`J('1H92!M:6YU=&4*
M("`@("`J($!V87(@:6YT"B`@("`@*B\*("`@('9A<B`D;6EN=71E.PH@("`@
M+RHJ"B`@("`@*B!T:&4@<V5C;VYD"B`@("`@*B!`=F%R(&EN=`H@("`@("HO
M"B`@("!V87(@)'-E8V]N9#L*("`@("\J*@H@("`@("H@=&AE('!A<G1S(&]F
M(&$@<V5C;VYD"B`@("`@*B!`=F%R(&9L;V%T"B`@("`@*B\*("`@('9A<B`D
M<&%R='-E8V]N9#L*"B`@("`O*BH*("`@("`J('1I;65Z;VYE(&9O<B!T:&ES
M(&1A=&4*("`@("`J($!V87(@;V)J96-T($1A=&5?5&EM95IO;F4*("`@("`J
M+PH@("`@=F%R("1T>CL*"B`@("`O*BH*("`@("`J(&1E9FEN92!T:&4@9&5F
M875L="!W965K9&%Y(&%B8G)E=FEA=&EO;B!L96YG=&@*("`@("`J('5S960@
M8GD@.CIF;W)M870H*0H@("`@("H@0'9A<B!I;G0*("`@("`J+PH@("`@=F%R
M("1G9717965K9&%Y06)B<FYA;65,96YG=&@@/2`S.PH*"B`@("`O*BH*("`@
M("`J($-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0W)E871E<R!A(&YE=R!$
M871E($]B:F5C="!I;FET:6%L:7IE9"!T;R!T:&4@8W5R<F5N="!D871E+W1I
M;64@:6X@=&AE"B`@("`@*B!S>7-T96TM9&5F875L="!T:6UE>F]N92!B>2!D
M969A=6QT+B`@02!D871E(&]P=&EO;F%L;'D*("`@("`J('!A<W-E9"!I;B!M
M87D@8F4@:6X@=&AE($E33R`X-C`Q+"!424U%4U1!35`@;W(@54Y)6%1)344@
M9F]R;6%T+`H@("`@("H@;W(@86YO=&AE<B!$871E(&]B:F5C="X@($EF(&YO
M(&1A=&4@:7,@<&%S<V5D+"!T:&4@8W5R<F5N="!D871E+W1I;64*("`@("`J
M(&ES('5S960N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M($!S964@<V5T1&%T92@I"B`@("`@*B!`<&%R86T@;6EX960@)&1A=&4@;W!T
M:6]N86P@+2!D871E+W1I;64@=&\@:6YI=&EA;&EZ90H@("`@("H@0')E='5R
M;B!O8FIE8W0@1&%T92!T:&4@;F5W($1A=&4@;V)J96-T"B`@("`@*B\*("`@
M(&9U;F-T:6]N($1A=&4H)&1A=&4@/2!N=6QL*0H@("`@>PH@("`@("`@("1T
M:&ES+3YT>B`]($1A=&5?5&EM95IO;F4Z.F=E=$1E9F%U;'0H*3L*("`@("`@
M("!I9B`H:7-?;G5L;"@D9&%T92DI('L*("`@("`@("`@("`@)'1H:7,M/G-E
M=$1A=&4H9&%T92@B62UM+60@2#II.G,B*2D["B`@("`@("`@?2!E;'-E:68@
M*&ES7V$H)&1A=&4L("=$871E)RDI('L*("`@("`@("`@("`@)'1H:7,M/F-O
M<'DH)&1A=&4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES
M+3YS971$871E*"1D871E*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3970@=&AE(&9I96QD<R!O9B!A($1A=&4@;V)J96-T(&)A<V5D(&]N
M('1H92!I;G!U="!D871E(&%N9"!F;W)M870*("`@("`J"B`@("`@*B!3970@
M=&AE(&9I96QD<R!O9B!A($1A=&4@;V)J96-T(&)A<V5D(&]N('1H92!I;G!U
M="!D871E(&%N9"!F;W)M870L"B`@("`@*B!W:&EC:"!I<R!S<&5C:69I960@
M8GD@=&AE($1!5$5?1D]234%47RH@8V]N<W1A;G1S+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871E(&EN
M<'5T(&1A=&4*("`@("`J($!P87)A;2!I;G0@)&9O<FUA="!/<'1I;VYA;"!F
M;W)M870@8V]N<W1A;G0@*$1!5$5?1D]234%47RHI(&]F('1H92!I;G!U="!D
M871E+@H@("`@("H@("`@("`@("`@("`@("`@("`@(%1H:7,@<&%R86UE=&5R
M(&ES;B=T(')E86QL>2!N965D960@86YY;6]R92P@8G5T('EO=2!C;W5L9`H@
M("`@("H@("`@("`@("`@("`@("`@("`@('5S92!I="!T;R!F;W)C92!$051%
M7T9/4DU!5%]53DE85$E-12X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1&%T
M92@D9&%T92P@)&9O<FUA="`]($1!5$5?1D]234%47TE33RD*("`@('L*"B`@
M("`@("`@:68@*`H@("`@("`@("`@("!P<F5G7VUA=&-H*"<O7BA<9'LT?2DM
M/RA<9'LR?2DM/RA<9'LR?2DH6U1<<UT_*%QD>S)]*3H_*%QD>S)]*3H_*%QD
M>S)]*2A<+EQD*RD_*%I\6UPK7"U=7&1[,GTZ/UQD>S)]*3\I/R0O:2<L("1D
M871E+"`D<F5G<RD*("`@("`@("`@("`@)B8@)&9O<FUA="`A/2!$051%7T9/
M4DU!5%]53DE85$E-12D@>PH@("`@("`@("`@("`O+R!$051%7T9/4DU!5%])
M4T\L($E33U]"05-)0RP@25-/7T585$5.1$5$+"!A;F0@5$E-15-404U0"B`@
M("`@("`@("`@("\O(%1H97-E(&9O<FUA=',@87)E(&5X=')E;65L>2!C;&]S
M92!T;R!E86-H(&]T:&5R+B`@5&AI<R!R96=E>`H@("`@("`@("`@("`O+R!I
M<R!V97)Y(&QO;W-E(&%N9"!A8V-E<'1S(&%L;6]S="!A;GD@8G5T8VAE<F5D
M(&9O<FUA="!Y;W4@8V]U;&0*("`@("`@("`@("`@+R\@=&AR;W<@870@:70N
M("!E+F<N(#(P,#,M,3`M,#<@,3DZ-#4Z,34@86YD(#(P,#,M,3`P-S$Y-#4Z
M,34*("`@("`@("`@("`@+R\@87)E('1H92!S86UE('1H:6YG(&EN('1H92!E
M>65S(&]F('1H:7,@<F5G97@L(&5V96X@=&AO=6=H('1H90H@("`@("`@("`@
M("`O+R!L871T97(@:7,@;F]T(&$@=F%L:60@25-/(#@V,#$@9&%T92X*("`@
M("`@("`@("`@)'1H:7,M/GEE87(@("`@("`@/2`D<F5G<ULQ73L*("`@("`@
M("`@("`@)'1H:7,M/FUO;G1H("`@("`@/2`D<F5G<ULR73L*("`@("`@("`@
M("`@)'1H:7,M/F1A>2`@("`@("`@/2`D<F5G<ULS73L*("`@("`@("`@("`@
M)'1H:7,M/FAO=7(@("`@("`@/2!I<W-E="@D<F5G<ULU72D_)')E9W-;-5TZ
M,#L*("`@("`@("`@("`@)'1H:7,M/FUI;G5T92`@("`@/2!I<W-E="@D<F5G
M<ULV72D_)')E9W-;-ETZ,#L*("`@("`@("`@("`@)'1H:7,M/G-E8V]N9"`@
M("`@/2!I<W-E="@D<F5G<ULW72D_)')E9W-;-UTZ,#L*("`@("`@("`@("`@
M)'1H:7,M/G!A<G1S96-O;F0@/2!I<W-E="@D<F5G<ULX72D_*&9L;V%T*21R
M96=S6SA=.BAF;&]A="DP.PH*("`@("`@("`@("`@+R\@:68@86X@;V9F<V5T
M(&ES(&1E9FEN960L(&-O;G9E<G0@=&EM92!T;R!55$,*("`@("`@("`@("`@
M+R\@1&%T92!C=7)R96YT;'D@8V%N)W0@<V5T(&$@=&EM97IO;F4@;VYL>2!B
M>2!O9F9S970L"B`@("`@("`@("`@("\O('-O(&ET(&AA<R!T;R!S=&]R92!I
M="!A<R!55$,*("`@("`@("`@("`@:68@*&ES<V5T*"1R96=S6SE=*2D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/G1O551#8GE/9F9S970H)')E9W-;.5TI
M.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*&ES7VYU;65R:6,H
M)&1A=&4I*2!["B`@("`@("`@("`@("\O(%5.25A424U%"B`@("`@("`@("`@
M("1T:&ES+3YS971$871E*&1A=&4H(EDM;2UD($@Z:3IS(BP@)&1A=&4I*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!U;FMN;W=N(&9O<FUA
M=`H@("`@("`@("`@("`D=&AI<RT^>65A<B`@("`@("`](#`["B`@("`@("`@
M("`@("1T:&ES+3YM;VYT:"`@("`@(#T@,3L*("`@("`@("`@("`@)'1H:7,M
M/F1A>2`@("`@("`@/2`Q.PH@("`@("`@("`@("`D=&AI<RT^:&]U<B`@("`@
M("`](#`["B`@("`@("`@("`@("1T:&ES+3YM:6YU=&4@("`@(#T@,#L*("`@
M("`@("`@("`@)'1H:7,M/G-E8V]N9"`@("`@/2`P.PH@("`@("`@("`@("`D
M=&AI<RT^<&%R='-E8V]N9"`]("AF;&]A="DP.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($=E="!A('-T<FEN9R`H;W(@;W1H97(I(')E<')E
M<V5N=&%T:6]N(&]F('1H:7,@9&%T90H@("`@("H*("`@("`J($=E="!A('-T
M<FEN9R`H;W(@;W1H97(I(')E<')E<V5N=&%T:6]N(&]F('1H:7,@9&%T92!I
M;B!T:&4*("`@("`J(&9O<FUA="!S<&5C:69I960@8GD@=&AE($1!5$5?1D]2
M34%47RH@8V]N<W1A;G1S+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B!`<&%R86T@:6YT("1F;W)M870@9F]R;6%T(&-O;G-T86YT("A$
M051%7T9/4DU!5%\J*2!O9B!T:&4@;W5T<'5T(&1A=&4*("`@("`J($!R971U
M<FX@<W1R:6YG('1H92!D871E(&EN('1H92!R97%U97-T960@9F]R;6%T"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$1A=&4H)&9O<FUA="`]($1!5$5?1D]2
M34%47TE33RD*("`@('L*("`@("`@("!S=VET8V@@*"1F;W)M870I('L*("`@
M("`@("!C87-E($1!5$5?1D]234%47TE33SH*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YF;W)M870H(B59+25M+25D("54(BD["B`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@(&-A<V4@1$%415]&3U)-051?25-/7T)!4TE#.@H@("`@
M("`@("`@("`D9F]R;6%T(#T@(B59)6TE9%0E2"5-)5,B.PH@("`@("`@("`@
M("!I9B`H)'1H:7,M/G1Z+3YG971)1"@I(#T]("=55$,G*2!["B`@("`@("`@
M("`@("`@("`D9F]R;6%T("X]("):(CL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/F9O<FUA="@D9F]R;6%T*3L*("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@8V%S92!$051%7T9/4DU!5%])4T]?15A414Y$
M140Z"B`@("`@("`@("`@("1F;W)M870@/2`B)5DM)6TM)614)4@Z)4TZ)5,B
M.PH@("`@("`@("`@("!I9B`H)'1H:7,M/G1Z+3YG971)1"@I(#T]("=55$,G
M*2!["B`@("`@("`@("`@("`@("`D9F]R;6%T("X]("):(CL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/F9O<FUA="@D9F]R;6%T
M*3L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S92!$051%7T9/4DU!
M5%])4T]?15A414Y$141?34E#4D]424U%.@H@("`@("`@("`@("`D9F]R;6%T
M(#T@(B59+25M+25D5"5(.B5-.B5S(CL*("`@("`@("`@("`@:68@*"1T:&ES
M+3YT>BT^9V5T240H*2`]/2`G551#)RD@>PH@("`@("`@("`@("`@("`@)&9O
M<FUA="`N/2`B6B(["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YF;W)M870H)&9O<FUA="D["B`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@(&-A<V4@1$%415]&3U)-051?5$E-15-404U0.@H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/F9O<FUA="@B)5DE;25D)4@E3253(BD["B`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@1$%415]&3U)-051?54Y)6%1)
M344Z"B`@("`@("`@("`@(')E='5R;B!M:W1I;64H)'1H:7,M/FAO=7(L("1T
M:&ES+3YM:6YU=&4L("1T:&ES+3YS96-O;F0L("1T:&ES+3YM;VYT:"P@)'1H
M:7,M/F1A>2P@)'1H:7,M/GEE87(I.PH@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;W!Y('9A;'5E<R!F<F]M
M(&%N;W1H97(@1&%T92!O8FIE8W0*("`@("`J"B`@("`@*B!-86ME<R!T:&ES
M($1A=&4@82!C;W!Y(&]F(&%N;W1H97(@1&%T92!O8FIE8W0N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!O8FIE8W0@1&%T
M92`D9&%T92!$871E('1O(&-O<'D@9G)O;0H@("`@("HO"B`@("!F=6YC=&EO
M;B!C;W!Y*"1D871E*0H@("`@>PH@("`@("`@("1T:&ES+3YY96%R(#T@)&1A
M=&4M/GEE87(["B`@("`@("`@)'1H:7,M/FUO;G1H(#T@)&1A=&4M/FUO;G1H
M.PH@("`@("`@("1T:&ES+3YD87D@/2`D9&%T92T^9&%Y.PH@("`@("`@("1T
M:&ES+3YH;W5R(#T@)&1A=&4M/FAO=7(["B`@("`@("`@)'1H:7,M/FUI;G5T
M92`]("1D871E+3YM:6YU=&4["B`@("`@("`@)'1H:7,M/G-E8V]N9"`]("1D
M871E+3YS96-O;F0["B`@("`@("`@)'1H:7,M/G1Z(#T@)&1A=&4M/G1Z.PH@
M("`@?0H*("`@("\J*@H@("`@("H@($1A=&4@<')E='1Y('!R:6YT:6YG+"!S
M:6UI;&%R('1O('-T<F9T:6UE*"D*("`@("`J"B`@("`@*B`@1F]R;6%T<R!T
M:&4@9&%T92!I;B!T:&4@9VEV96X@9F]R;6%T+"!M=6-H(&QI:V4*("`@("`J
M("!S=')F=&EM92@I+B`@36]S="!S=')F=&EM92@I(&]P=&EO;G,@87)E('-U
M<'!O<G1E9"X\8G(^/&)R/@H@("`@("H*("`@("`J("!F;W)M871T:6YG(&]P
M=&EO;G,Z/&)R/CQB<CX*("`@("`J"B`@("`@*B`@/&-O9&4^)6$@(#PO8V]D
M93X@(&%B8G)E=FEA=&5D('=E96MD87D@;F%M92`H4W5N+"!-;VXL(%1U92D@
M/&)R/@H@("`@("H@(#QC;V1E/B5!("`\+V-O9&4^("!F=6QL('=E96MD87D@
M;F%M92`H4W5N9&%Y+"!-;VYD87DL(%1U97-D87DI(#QB<CX*("`@("`J("`\
M8V]D93XE8B`@/"]C;V1E/B`@86)B<F5V:6%T960@;6]N=&@@;F%M92`H2F%N
M+"!&96(L($UA<BD@/&)R/@H@("`@("H@(#QC;V1E/B5"("`\+V-O9&4^("!F
M=6QL(&UO;G1H(&YA;64@*$IA;G5A<GDL($9E8G)U87)Y+"!-87)C:"D@/&)R
M/@H@("`@("H@(#QC;V1E/B5#("`\+V-O9&4^("!C96YT=7)Y(&YU;6)E<B`H
M=&AE('EE87(@9&EV:61E9"!B>2`Q,#`@86YD('1R=6YC871E9"!T;R!A;B!I
M;G1E9V5R+"!R86YG92`P,"!T;R`Y.2D@/&)R/@H@("`@("H@(#QC;V1E/B5D
M("`\+V-O9&4^("!D87D@;V8@;6]N=&@@*')A;F=E(#`P('1O(#,Q*2`\8G(^
M"B`@("`@*B`@/&-O9&4^)40@(#PO8V]D93X@('-A;64@87,@(B5M+R5D+R5Y
M(B`\8G(^"B`@("`@*B`@/&-O9&4^)64@(#PO8V]D93X@(&1A>2!O9B!M;VYT
M:"P@<VEN9VQE(&1I9VET("AR86YG92`P('1O(#,Q*2`\8G(^"B`@("`@*B`@
M/&-O9&4^)44@(#PO8V]D93X@(&YU;6)E<B!O9B!D87ES('-I;F-E('5N<W!E
M8VEF:65D(&5P;V-H("AI;G1E9V5R+"!$871E7T-A;&,Z.F1A=&54;T1A>7,H
M*2D@/&)R/@H@("`@("H@(#QC;V1E/B5(("`\+V-O9&4^("!H;W5R(&%S(&1E
M8VEM86P@;G5M8F5R("@P,"!T;R`R,RD@/&)R/@H@("`@("H@(#QC;V1E/B5)
M("`\+V-O9&4^("!H;W5R(&%S(&1E8VEM86P@;G5M8F5R(&]N(#$R+6AO=7(@
M8VQO8VL@*#`Q('1O(#$R*2`\8G(^"B`@("`@*B`@/&-O9&4^)6H@(#PO8V]D
M93X@(&1A>2!O9B!Y96%R("AR86YG92`P,#$@=&\@,S8V*2`\8G(^"B`@("`@
M*B`@/&-O9&4^)6T@(#PO8V]D93X@(&UO;G1H(&%S(&1E8VEM86P@;G5M8F5R
M("AR86YG92`P,2!T;R`Q,BD@/&)R/@H@("`@("H@(#QC;V1E/B5-("`\+V-O
M9&4^("!M:6YU=&4@87,@82!D96-I;6%L(&YU;6)E<B`H,#`@=&\@-3DI(#QB
M<CX*("`@("`J("`\8V]D93XE;B`@/"]C;V1E/B`@;F5W;&EN92!C:&%R86-T
M97(@*%QN*2`\8G(^"B`@("`@*B`@/&-O9&4^)4\@(#PO8V]D93X@(&1S="UC
M;W)R96-T960@=&EM97IO;F4@;V9F<V5T(&5X<')E<W-E9"!A<R`B*R\M2$@Z
M34TB(#QB<CX*("`@("`J("`\8V]D93XE;R`@/"]C;V1E/B`@<F%W('1I;65Z
M;VYE(&]F9G-E="!E>'!R97-S960@87,@(BLO+4A(.DU-(B`\8G(^"B`@("`@
M*B`@/&-O9&4^)7`@(#PO8V]D93X@(&5I=&AE<B`G86TG(&]R("=P;2<@9&5P
M96YD:6YG(&]N('1H92!T:6UE(#QB<CX*("`@("`J("`\8V]D93XE4"`@/"]C
M;V1E/B`@96ET:&5R("=!32<@;W(@)U!-)R!D97!E;F1I;F<@;VX@=&AE('1I
M;64@/&)R/@H@("`@("H@(#QC;V1E/B5R("`\+V-O9&4^("!T:6UE(&EN(&%M
M+W!M(&YO=&%T:6]N+"!S86UE(&%S("(E23HE33HE4R`E<"(@/&)R/@H@("`@
M("H@(#QC;V1E/B52("`\+V-O9&4^("!T:6UE(&EN(#(T+6AO=7(@;F]T871I
M;VXL('-A;64@87,@(B5(.B5-(B`\8G(^"B`@("`@*B`@/&-O9&4^)7,@(#PO
M8V]D93X@('-E8V]N9',@:6YC;'5D:6YG('1H92!D96-I;6%L(')E<')E<V5N
M=&%T:6]N('-M86QL97(@=&AA;B!O;F4@<V5C;VYD(#QB<CX*("`@("`J("`\
M8V]D93XE4R`@/"]C;V1E/B`@<V5C;VYD<R!A<R!A(&1E8VEM86P@;G5M8F5R
M("@P,"!T;R`U.2D@/&)R/@H@("`@("H@(#QC;V1E/B5T("`\+V-O9&4^("!T
M86(@8VAA<F%C=&5R("A<="D@/&)R/@H@("`@("H@(#QC;V1E/B54("`\+V-O
M9&4^("!C=7)R96YT('1I;64L('-A;64@87,@(B5(.B5-.B53(B`\8G(^"B`@
M("`@*B`@/&-O9&4^)7<@(#PO8V]D93X@('=E96MD87D@87,@9&5C:6UA;"`H
M,"`](%-U;F1A>2D@/&)R/@H@("`@("H@(#QC;V1E/B55("`\+V-O9&4^("!W
M965K(&YU;6)E<B!O9B!C=7)R96YT('EE87(L(&9I<G-T('-U;F1A>2!A<R!F
M:7)S="!W965K(#QB<CX*("`@("`J("`\8V]D93XE>2`@/"]C;V1E/B`@>65A
M<B!A<R!D96-I;6%L("AR86YG92`P,"!T;R`Y.2D@/&)R/@H@("`@("H@(#QC
M;V1E/B59("`\+V-O9&4^("!Y96%R(&%S(&1E8VEM86P@:6YC;'5D:6YG(&-E
M;G1U<GD@*')A;F=E(#`P,#`@=&\@.3DY.2D@/&)R/@H@("`@("H@(#QC;V1E
M/B4E("`\+V-O9&4^("!L:71E<F%L("<E)R`\8G(^"B`@("`@*B`\8G(^"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!S=')I
M;F<@9F]R;6%T('1H92!F;W)M870@<W1R:6YG(&9O<B!R971U<FYE9"!D871E
M+W1I;64*("`@("`J($!R971U<FX@<W1R:6YG(&1A=&4O=&EM92!I;B!G:79E
M;B!F;W)M870*("`@("`J+PH@("`@9G5N8W1I;VX@9F]R;6%T*"1F;W)M870I
M"B`@("!["B`@("`@("`@)&]U='!U="`]("(B.PH*("`@("`@("!F;W(H)'-T
M<G!O<R`](#`[("1S=')P;W,@/"!S=')L96XH)&9O<FUA="D[("1S=')P;W,K
M*RD@>PH@("`@("`@("`@("`D8VAA<B`]('-U8G-T<B@D9F]R;6%T+"1S=')P
M;W,L,2D["B`@("`@("`@("`@(&EF("@D8VAA<B`]/2`B)2(I('L*("`@("`@
M("`@("`@("`@("1N97AT8VAA<B`]('-U8G-T<B@D9F]R;6%T+"1S=')P;W,@
M*R`Q+#$I.PH@("`@("`@("`@("`@("`@<W=I=&-H("@D;F5X=&-H87(I('L*
M("`@("`@("`@("`@("`@(&-A<V4@(F$B.@H@("`@("`@("`@("`@("`@("`@
M("1O=71P=70@+CT@1&%T95]#86QC.CIG9717965K9&%Y06)B<FYA;64H)'1H
M:7,M/F1A>2PD=&AI<RT^;6]N=&@L)'1H:7,M/GEE87(L("1T:&ES+3YG9717
M965K9&%Y06)B<FYA;65,96YG=&@I.PH@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@8V%S92`B02(Z"B`@("`@("`@("`@("`@
M("`@("`@)&]U='!U="`N/2!$871E7T-A;&,Z.F=E=%=E96MD87E&=6QL;F%M
M92@D=&AI<RT^9&%Y+"1T:&ES+3YM;VYT:"PD=&AI<RT^>65A<BD["B`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")B
M(CH*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]($1A=&5?0V%L8SHZ
M9V5T36]N=&A!8F)R;F%M92@D=&AI<RT^;6]N=&@I.PH@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B0B(Z"B`@("`@
M("`@("`@("`@("`@("`@)&]U='!U="`N/2!$871E7T-A;&,Z.F=E=$UO;G1H
M1G5L;&YA;64H)'1H:7,M/FUO;G1H*3L*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(D,B.@H@("`@("`@("`@("`@
M("`@("`@("1O=71P=70@+CT@<W!R:6YT9B@B)3`R9"(L:6YT=F%L*"1T:&ES
M+3YY96%R+S$P,"DI.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@8V%S92`B9"(Z"B`@("`@("`@("`@("`@("`@("`@)&]U
M='!U="`N/2!S<')I;G1F*"(E,#)D(BPD=&AI<RT^9&%Y*3L*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(D0B.@H@
M("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@<W!R:6YT9B@B)3`R9"\E
M,#)D+R4P,F0B+"1T:&ES+3YM;VYT:"PD=&AI<RT^9&%Y+"1T:&ES+3YY96%R
M*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M(&-A<V4@(F4B.@H@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@)'1H
M:7,M/F1A>2`J(#$[("\O(&=E="!R:60@;V8@;&5A9&EN9R!Z97)O"B`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")%
M(CH*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]($1A=&5?0V%L8SHZ
M9&%T951O1&%Y<R@D=&AI<RT^9&%Y+"1T:&ES+3YM;VYT:"PD=&AI<RT^>65A
M<BD["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("!C87-E(")((CH*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-P
M<FEN=&8H(B4P,F0B+"`D=&AI<RT^:&]U<BD["B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E("=H)SH*("`@("`@("`@
M("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN=&8H(B5D(BP@)'1H:7,M/FAO
M=7(I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@8V%S92`B22(Z"B`@("`@("`@("`@("`@("`@("`@)&AO=7(@/2`H)'1H
M:7,M/FAO=7(@*R`Q*2`^(#$R(#\@)'1H:7,M/FAO=7(@+2`Q,B`Z("1T:&ES
M+3YH;W5R.PH@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@<W!R:6YT
M9B@B)3`R9"(L("1H;W5R/3TP(#\@,3(@.B`D:&]U<BD["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")I(CH*("`@
M("`@("`@("`@("`@("`@("`D:&]U<B`]("@D=&AI<RT^:&]U<B`K(#$I(#X@
M,3(@/R`D=&AI<RT^:&]U<B`M(#$R(#H@)'1H:7,M/FAO=7(["B`@("`@("`@
M("`@("`@("`@("`@)&]U='!U="`N/2!S<')I;G1F*"(E9"(L("1H;W5R/3TP
M(#\@,3(@.B`D:&]U<BD["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@("`@("!C87-E(")J(CH*("`@("`@("`@("`@("`@("`@("`D
M;W5T<'5T("X]($1A=&5?0V%L8SHZ:G5L:6%N1&%T92@D=&AI<RT^9&%Y+"1T
M:&ES+3YM;VYT:"PD=&AI<RT^>65A<BD["B`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")M(CH*("`@("`@("`@("`@
M("`@("`@("`D;W5T<'5T("X]('-P<FEN=&8H(B4P,F0B+"1T:&ES+3YM;VYT
M:"D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("!C87-E(")-(CH*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-P
M<FEN=&8H(B4P,F0B+"1T:&ES+3YM:6YU=&4I.PH@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B;B(Z"B`@("`@("`@
M("`@("`@("`@("`@)&]U='!U="`N/2`B7&XB.PH@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B3R(Z"B`@("`@("`@
M("`@("`@("`@("`@)&]F9FUS(#T@)'1H:7,M/G1Z+3YG971/9F9S970H)'1H
M:7,I.PH@("`@("`@("`@("`@("`@("`@("1D:7)E8W1I;VX@/2`D;V9F;7,@
M/CT@,"`_("(K(B`Z("(M(CL*("`@("`@("`@("`@("`@("`@("`D;V9F;6EN
M<R`](&%B<R@D;V9F;7,I("\@,3`P,"`O(#8P.PH@("`@("`@("`@("`@("`@
M("`@("1H;W5R<R`]("1O9F9M:6YS("\@-C`["B`@("`@("`@("`@("`@("`@
M("`@)&UI;G5T97,@/2`D;V9F;6EN<R`E(#8P.PH@("`@("`@("`@("`@("`@
M("`@("1O=71P=70@+CT@<W!R:6YT9B@B)7,E,#)D.B4P,F0B+"`D9&ER96-T
M:6]N+"`D:&]U<G,L("1M:6YU=&5S*3L*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(F\B.@H@("`@("`@("`@("`@
M("`@("`@("1O9F9M<R`]("1T:&ES+3YT>BT^9V5T4F%W3V9F<V5T*"1T:&ES
M*3L*("`@("`@("`@("`@("`@("`@("`D9&ER96-T:6]N(#T@)&]F9FUS(#X]
M(#`@/R`B*R(@.B`B+2(["B`@("`@("`@("`@("`@("`@("`@)&]F9FUI;G,@
M/2!A8G,H)&]F9FUS*2`O(#$P,#`@+R`V,#L*("`@("`@("`@("`@("`@("`@
M("`D:&]U<G,@/2`D;V9F;6EN<R`O(#8P.PH@("`@("`@("`@("`@("`@("`@
M("1M:6YU=&5S(#T@)&]F9FUI;G,@)2`V,#L*("`@("`@("`@("`@("`@("`@
M("`D;W5T<'5T("X]('-P<FEN=&8H(B5S)3`R9#HE,#)D(BP@)&1I<F5C=&EO
M;BP@)&AO=7)S+"`D;6EN=71E<RD["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("!C87-E(")P(CH*("`@("`@("`@("`@("`@
M("`@("`D;W5T<'5T("X]("1T:&ES+3YH;W5R(#X](#$R(#\@(G!M(B`Z(")A
M;2(["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("!C87-E(")0(CH*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]("1T
M:&ES+3YH;W5R(#X](#$R(#\@(E!-(B`Z(")!32(["B`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")R(CH*("`@("`@
M("`@("`@("`@("`@("`D:&]U<B`]("@D=&AI<RT^:&]U<B`K(#$I(#X@,3(@
M/R`D=&AI<RT^:&]U<B`M(#$R(#H@)'1H:7,M/FAO=7(["B`@("`@("`@("`@
M("`@("`@("`@)&]U='!U="`N/2!S<')I;G1F*"(E,#)D.B4P,F0Z)3`R9"`E
M<R(L("1H;W5R/3TP(#\@(#$R(#H@)&AO=7(L("1T:&ES+3YM:6YU=&4L("1T
M:&ES+3YS96-O;F0L("1T:&ES+3YH;W5R(#X](#$R(#\@(E!-(B`Z(")!32(I
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M8V%S92`B4B(Z"B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!S<')I
M;G1F*"(E,#)D.B4P,F0B+"`D=&AI<RT^:&]U<BP@)'1H:7,M/FUI;G5T92D[
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C
M87-E(")S(CH*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-T<E]R
M97!L86-E*"<L)RP@)RXG+"!S<')I;G1F*"(E,#EF(BP@*&9L;V%T*2@H9FQO
M870I)'1H:7,M/G-E8V]N9"`K("1T:&ES+3YP87)T<V5C;VYD*2DI.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B
M4R(Z"B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!S<')I;G1F*"(E
M,#)D(BP@)'1H:7,M/G-E8V]N9"D["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("!C87-E(")T(CH*("`@("`@("`@("`@("`@
M("`@("`D;W5T<'5T("X](")<="(["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("!C87-E(")4(CH*("`@("`@("`@("`@("`@
M("`@("`D;W5T<'5T("X]('-P<FEN=&8H(B4P,F0Z)3`R9#HE,#)D(BP@)'1H
M:7,M/FAO=7(L("1T:&ES+3YM:6YU=&4L("1T:&ES+3YS96-O;F0I.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B
M=R(Z"B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!$871E7T-A;&,Z
M.F1A>4]F5V5E:R@D=&AI<RT^9&%Y+"1T:&ES+3YM;VYT:"PD=&AI<RT^>65A
M<BD["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("!C87-E(")5(CH*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]($1A
M=&5?0V%L8SHZ=V5E:T]F665A<B@D=&AI<RT^9&%Y+"1T:&ES+3YM;VYT:"PD
M=&AI<RT^>65A<BD["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("!C87-E(")Y(CH*("`@("`@("`@("`@("`@("`@("`D;W5T
M<'5T("X]('-U8G-T<B@D=&AI<RT^>65A<BPR+#(I.PH@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B62(Z"B`@("`@
M("`@("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^>65A<CL*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(EHB
M.@H@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@)'1H:7,M/G1Z+3YI
M;D1A>6QI9VAT5&EM92@D=&AI<RD@/R`D=&AI<RT^='HM/F=E=$135%-H;W)T
M3F%M92@I(#H@)'1H:7,M/G1Z+3YG9713:&]R=$YA;64H*3L*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(B4B.@H@
M("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@(B4B.PH@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@9&5F875L=#H*("`@
M("`@("`@("`@("`@("`@("`D;W5T<'5T("X]("1C:&%R+B1N97AT8VAA<CL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1S=')P;W,K*SL*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1O=71P=70@
M+CT@)&-H87(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1O=71P=70["@H@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H:7,@
M9&%T92]T:6UE(&EN(%5N:7@@=&EM92@I(&9O<FUA=`H@("`@("H*("`@("`J
M($=E="!A(')E<')E<V5N=&%T:6]N(&]F('1H:7,@9&%T92!I;B!5;FEX('1I
M;64H*2!F;W)M870N("!4:&ES(&UA>2!O;FQY(&)E"B`@("`@*B!V86QI9"!F
M;W(@9&%T97,@9G)O;2`Q.3<P('1O('XR,#,X+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&EN="!N=6UB97(@;V8@<V5C
M;VYD<R!S:6YC92!T:&4@=6YI>"!E<&]C:`H@("`@("HO"B`@("!F=6YC=&EO
M;B!G9714:6UE*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F=E=$1A
M=&4H1$%415]&3U)-051?54Y)6%1)344I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4V5T<R!T:&4@=&EM92!Z;VYE(&]F('1H:7,@1&%T90H@("`@("H*("`@
M("`J(%-E=',@=&AE('1I;64@>F]N92!O9B!T:&ES(&1A=&4@=VET:"!T:&4@
M9VEV96X*("`@("`J($1A=&5?5&EM95IO;F4@;V)J96-T+B`@1&]E<R!N;W0@
M86QT97(@=&AE(&1A=&4O=&EM92P*("`@("`J(&]N;'D@87-S:6=N<R!A(&YE
M=R!T:6UE('IO;F4N("!&;W(@8V]N=F5R<VEO;BP@=7-E"B`@("`@*B!C;VYV
M97)T5%HH*2X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@
M0'!A<F%M(&]B:F5C="!$871E7U1I;65:;VYE("1T>B!T:&4@1&%T95]4:6UE
M6F]N92!O8FIE8W0@=&\@=7-E+"!I9B!C86QL960*("`@("`J('=I=&@@82!P
M87)A;6%T97(@=&AA="!I<R!N;W0@82!$871E7U1I;65:;VYE(&]B:F5C="P@
M=VEL;"!F86QL('1H<F]U9V@@=&\*("`@("`J('-E=%1:8GE)1"@I+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S97146B@D='HI"B`@("!["B`@("`):68H:7-?
M82@D='HL("=$871E7U1I;65Z;VYE)RDI('L*("`@("`@("`))'1H:7,M/G1Z
M(#T@)'1Z.PH@("`@"7T@96QS92!["B`@("`)"21T:&ES+3YS97146F)Y240H
M)'1Z*3L*("`@(`E]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!T
M:6UE('IO;F4@;V8@=&AI<R!D871E('=I=&@@=&AE(&=I=F5N('1I;64@>F]N
M92!I9`H@("`@("H*("`@("`J(%-E=',@=&AE('1I;64@>F]N92!O9B!T:&ES
M(&1A=&4@=VET:"!T:&4@9VEV96X*("`@("`J('1I;64@>F]N92!I9"P@;W(@
M=&\@=&AE('-Y<W1E;2!D969A=6QT(&EF('1H90H@("`@("H@9VEV96X@:60@
M:7,@:6YV86QI9"X@1&]E<R!N;W0@86QT97(@=&AE(&1A=&4O=&EM92P*("`@
M("`J(&]N;'D@87-S:6=N<R!A(&YE=R!T:6UE('IO;F4N("!&;W(@8V]N=F5R
M<VEO;BP@=7-E"B`@("`@*B!C;VYV97)T5%HH*2X*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M('-T<FEN9R!I9"!A('1I;64@
M>F]N92!I9`H@("`@("HO"B`@("!F=6YC=&EO;B!S97146F)Y240H)&ED*0H@
M("`@>PH@("`@("`@(&EF("A$871E7U1I;65:;VYE.CII<U9A;&ED240H)&ED
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^='H@/2!N97<@1&%T95]4:6UE6F]N
M92@D:60I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YT
M>B`]($1A=&5?5&EM95IO;F4Z.F=E=$1E9F%U;'0H*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!497-T<R!I9B!T:&ES(&1A=&4O=&EM92!I
M<R!I;B!$4U0*("`@("`J"B`@("`@*B!2971U<FYS('1R=64@:68@9&%Y;&EG
M:'0@<V%V:6YG<R!T:6UE(&ES(&EN(&5F9F5C="!F;W(*("`@("`J('1H:7,@
M9&%T92!I;B!T:&ES(&1A=&4G<R!T:6UE('IO;F4N("!3964@1&%T95]4:6UE
M6F]N93HZ:6Y$87EL:6=H=%1I;64H*0H@("`@("H@9F]R(&-O;7!A=&%B:6QI
M='D@:6YF;W)M871I;VXN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J($!R971U<FX@8F]O;&5A;B!T<G5E(&EF($135"!I<R!I;B!E9F9E
M8W0@9F]R('1H:7,@9&%T90H@("`@("HO"B`@("!F=6YC=&EO;B!I;D1A>6QI
M9VAT5&EM92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YT>BT^:6Y$
M87EL:6=H=%1I;64H)'1H:7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N
M=F5R=',@=&AI<R!D871E('1O(%540R!A;F0@<V5T<R!T:&ES(&1A=&4G<R!T
M:6UE>F]N92!T;R!55$,*("`@("`J"B`@("`@*B!#;VYV97)T<R!T:&ES(&1A
M=&4@=&\@551#(&%N9"!S971S('1H:7,@9&%T92=S('1I;65Z;VYE('1O(%54
M0PH@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U
M;F-T:6]N('1O551#*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/G1Z+3YG
M971/9F9S970H)'1H:7,I(#X@,"D@>PH@("`@("`@("`@("`D=&AI<RT^<W5B
M=')A8W1396-O;F1S*&EN='9A;"@D=&AI<RT^='HM/F=E=$]F9G-E="@D=&AI
M<RD@+R`Q,#`P*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H
M:7,M/F%D9%-E8V]N9',H:6YT=F%L*&%B<R@D=&AI<RT^='HM/F=E=$]F9G-E
M="@D=&AI<RDI("\@,3`P,"DI.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^
M='H@/2!N97<@1&%T95]4:6UE6F]N92@G551#)RD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#;VYV97)T<R!T:&ES(&1A=&4@=&\@82!N97<@=&EM92!Z;VYE
M"B`@("`@*@H@("`@("H@0V]N=F5R=',@=&AI<R!D871E('1O(&$@;F5W('1I
M;64@>F]N92X*("`@("`J(%=!4DY)3D<Z(%1H:7,@;6%Y(&YO="!W;W)K(&-O
M<G)E8W1L>2!I9B!Y;W5R('-Y<W1E;2!D;V5S(&YO="!A;&QO=PH@("`@("H@
M<'5T96YV*"D@;W(@:68@;&]C86QT:6UE*"D@9&]E<R!N;W0@=V]R:R!I;B!Y
M;W5R(&5N=FER;VYM96YT+B`@4V5E"B`@("`@*B!$871E.CI4:6UE6F]N93HZ
M:6Y$87EL:6=H=%1I;64H*2!F;W(@;6]R92!I;F9O<FUA=&EO;BX*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M(&]B:F5C="!$
M871E7U1I;65:;VYE("1T>B!T:&4@1&%T93HZ5&EM95IO;F4@;V)J96-T(&9O
M<B!T:&4@8V]N=F5R<VEO;B!T:6UE('IO;F4*("`@("`J+PH@("`@9G5N8W1I
M;VX@8V]N=F5R=%1:*"1T>BD*("`@('L*("`@("`@("`O+R!C;VYV97)T('1O
M(%540PH@("`@("`@(&EF("@D=&AI<RT^='HM/F=E=$]F9G-E="@D=&AI<RD@
M/B`P*2!["B`@("`@("`@("`@("1T:&ES+3YS=6)T<F%C=%-E8V]N9',H:6YT
M=F%L*&%B<R@D=&AI<RT^='HM/F=E=$]F9G-E="@D=&AI<RDI("\@,3`P,"DI
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YA9&1396-O
M;F1S*&EN='9A;"AA8G,H)'1H:7,M/G1Z+3YG971/9F9S970H)'1H:7,I*2`O
M(#$P,#`I*3L*("`@("`@("!]"B`@("`@("`@+R\@8V]N=F5R="!55$,@=&\@
M;F5W('1I;65Z;VYE"B`@("`@("`@:68@*"1T>BT^9V5T3V9F<V5T*"1T:&ES
M*2`^(#`I('L*("`@("`@("`@("`@)'1H:7,M/F%D9%-E8V]N9',H:6YT=F%L
M*&%B<R@D='HM/F=E=$]F9G-E="@D=&AI<RDI("\@,3`P,"DI.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YS=6)T<F%C=%-E8V]N9',H
M:6YT=F%L*&%B<R@D='HM/F=E=$]F9G-E="@D=&AI<RDI("\@,3`P,"DI.PH@
M("`@("`@('T*("`@("`@("`D=&AI<RT^='H@/2`D='H["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#;VYV97)T<R!T:&ES(&1A=&4@=&\@82!N97<@=&EM92!Z
M;VYE+"!G:79E;B!A('9A;&ED('1I;64@>F]N92!)1`H@("`@("H*("`@("`J
M($-O;G9E<G1S('1H:7,@9&%T92!T;R!A(&YE=R!T:6UE('IO;F4L(&=I=F5N
M(&$@=F%L:60@=&EM92!Z;VYE($E$"B`@("`@*B!705).24Y'.B!4:&ES(&UA
M>2!N;W0@=V]R:R!C;W)R96-T;'D@:68@>6]U<B!S>7-T96T@9&]E<R!N;W0@
M86QL;W<*("`@("`J('!U=&5N=B@I(&]R(&EF(&QO8V%L=&EM92@I(&1O97,@
M;F]T('=O<FL@:6X@>6]U<B!E;G9I<F]N;65N="X@(%-E90H@("`@("H@1&%T
M93HZ5&EM95IO;F4Z.FEN1&%Y;&EG:'14:6UE*"D@9F]R(&UO<F4@:6YF;W)M
M871I;VXN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P
M87)A;2!S=')I;F<@:60@82!T:6UE('IO;F4@:60*("`@("`J+PH@("`@9G5N
M8W1I;VX@8V]N=F5R=%1:8GE)1"@D:60I"B`@("!["B`@("`@("!I9B`H1&%T
M95]4:6UE6F]N93HZ:7-686QI9$E$*"1I9"DI('L*("`@("`@("`@("1T>B`]
M(&YE=R!$871E7U1I;65:;VYE*"1I9"D["B`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@)'1Z(#T@1&%T95]4:6UE6F]N93HZ9V5T1&5F875L="@I.PH@("`@
M("`@?0H@("`@("`@)'1H:7,M/F-O;G9E<G146B@D='HI.PH@("`@?0H*("`@
M(&9U;F-T:6]N('1O551#8GE/9F9S970H)&]F9G-E="D*("`@('L*("`@("`@
M("!I9B`H)&]F9G-E="`]/2`B6B(@?'P@)&]F9G-E="`]/2`B*S`P.C`P(B!\
M?"`D;V9F<V5T(#T]("(K,#`P,"(I('L*("`@("`@("`@("`@)'1H:7,M/G1O
M551#*"D["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@
M("`@("`@:68@*'!R96=?;6%T8V@H)R\H6UPK7"U=*2A<9'LR?2DZ/RA<9'LR
M?2DO)RP@)&]F9G-E="P@)')E9W,I*2!["B`@("`@("`@("`@("\O(&-O;G9E
M<G0@;V9F<V5T('1O('-E8V]N9',*("`@("`@("`@("`@)&AO=7)S("`]("AI
M;G0I(&ES<V5T*"1R96=S6S)=*3\D<F5G<ULR73HP.PH@("`@("`@("`@("`D
M;6EN<R`@(#T@*&EN="D@:7-S970H)')E9W-;,UTI/R1R96=S6S-=.C`["B`@
M("`@("`@("`@("1O9F9S970@/2`H)&AO=7)S("H@,S8P,"D@*R`H)&UI;G,@
M*B`V,"D["@H@("`@("`@("`@("!I9B`H:7-S970H)')E9W-;,5TI("8F("1R
M96=S6S%=(#T]("(M(BD@>PH@("`@("`@("`@("`@("`@)&]F9G-E="`J/2`M
M,3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1O9F9S970@/B`P
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<W5B=')A8W1396-O;F1S*&EN
M='9A;"@D;V9F<V5T*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^861D4V5C;VYD<RAI;G1V86PH86)S*"1O9F9S970I
M*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3YT>B`](&YE
M=R!$871E7U1I;65:;VYE*"=55$,G*3L*("`@("`@("`@("`@<F5T=7)N('1R
M=64["B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!9&1S(&$@9VEV96X@;G5M8F5R(&]F('-E8V]N9',@
M=&\@=&AE(&1A=&4*("`@("`J"B`@("`@*B!!9&1S(&$@9VEV96X@;G5M8F5R
M(&]F('-E8V]N9',@=&\@=&AE(&1A=&4*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H@0'!A<F%M(&EN="`D<V5C('1H92!N=6UB97(@;V8@
M<V5C;VYD<R!T;R!A9&0*("`@("`J+PH@("`@9G5N8W1I;VX@861D4V5C;VYD
M<R@D<V5C*0H@("`@>PH@("`@("`@("1T:&ES+3YA9&13<&%N*&YE=R!$871E
M7U-P86XH*&EN=&5G97(I)'-E8RDI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M061D<R!A('1I;64@<W!A;B!T;R!T:&4@9&%T90H@("`@("H*("`@("`J($%D
M9',@82!T:6UE('-P86X@=&\@=&AE(&1A=&4*("`@("`J"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("H@0'!A<F%M(&]B:F5C="!$871E7U-P86X@)'-P
M86X@=&AE('1I;64@<W!A;B!T;R!A9&0*("`@("`J+PH@("`@9G5N8W1I;VX@
M861D4W!A;B@D<W!A;BD*("`@('L*("`@("`@("!I9B`H(6ES7V$H)'-P86XL
M("=$871E7U-P86XG*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@
M?0H*("`@("`@("`D=&AI<RT^<V5C;VYD("L]("1S<&%N+3YS96-O;F0["B`@
M("`@("`@:68@*"1T:&ES+3YS96-O;F0@/CT@-C`I('L*("`@("`@("`@("`@
M)'1H:7,M/FUI;G5T92LK.PH@("`@("`@("`@("`D=&AI<RT^<V5C;VYD("T]
M(#8P.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/FUI;G5T92`K/2`D<W!A
M;BT^;6EN=71E.PH@("`@("`@(&EF("@D=&AI<RT^;6EN=71E(#X](#8P*2![
M"B`@("`@("`@("`@("1T:&ES+3YH;W5R*RL["B`@("`@("`@("`@(&EF("@D
M=&AI<RT^:&]U<B`^/2`R-"D@>PH@("`@("`@("`@("`@("`@;&ES="@D=&AI
M<RT^>65A<BP@)'1H:7,M/FUO;G1H+"`D=&AI<RT^9&%Y*2`]"B`@("`@("`@
M("`@("`@("`@("`@<W-C86YF*$1A=&5?0V%L8SHZ;F5X=$1A>2@D=&AI<RT^
M9&%Y+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YY96%R*2P@(B4P-',E,#)S)3`R
M<R(I.PH@("`@("`@("`@("`@("`@)'1H:7,M/FAO=7(@+3T@,C0["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/FUI;G5T92`M/2`V,#L*("`@
M("`@("!]"@H@("`@("`@("1T:&ES+3YH;W5R("L]("1S<&%N+3YH;W5R.PH@
M("`@("`@(&EF("@D=&AI<RT^:&]U<B`^/2`R-"D@>PH@("`@("`@("`@("!L
M:7-T*"1T:&ES+3YY96%R+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YD87DI(#T*
M("`@("`@("`@("`@("`@('-S8V%N9BA$871E7T-A;&,Z.FYE>'1$87DH)'1H
M:7,M/F1A>2P@)'1H:7,M/FUO;G1H+"`D=&AI<RT^>65A<BDL("(E,#1S)3`R
M<R4P,G,B*3L*("`@("`@("`@("`@)'1H:7,M/FAO=7(@+3T@,C0["B`@("`@
M("`@?0H*("`@("`@("`D9"`]($1A=&5?0V%L8SHZ9&%T951O1&%Y<R@D=&AI
M<RT^9&%Y+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YY96%R*3L*("`@("`@("`D
M9"`K/2`D<W!A;BT^9&%Y.PH*("`@("`@("!L:7-T*"1T:&ES+3YY96%R+"`D
M=&AI<RT^;6]N=&@L("1T:&ES+3YD87DI(#T*("`@("`@("`@("`@<W-C86YF
M*$1A=&5?0V%L8SHZ9&%Y<U1O1&%T92@D9"DL("(E,#1S)3`R<R4P,G,B*3L*
M("`@("`@("`D=&AI<RT^>65A<B`@/2!I;G1V86PH)'1H:7,M/GEE87(I.PH@
M("`@("`@("1T:&ES+3YM;VYT:"`](&EN='9A;"@D=&AI<RT^;6]N=&@I.PH@
M("`@("`@("1T:&ES+3YD87D@("`](&EN='9A;"@D=&AI<RT^9&%Y*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-U8G1R86-T<R!A(&=I=F5N(&YU;6)E<B!O
M9B!S96-O;F1S(&9R;VT@=&AE(&1A=&4*("`@("`J"B`@("`@*B!3=6)T<F%C
M=',@82!G:79E;B!N=6UB97(@;V8@<V5C;VYD<R!F<F]M('1H92!D871E"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!I;G0@
M)'-E8R!T:&4@;G5M8F5R(&]F('-E8V]N9',@=&\@<W5B=')A8W0*("`@("`J
M+PH@("`@9G5N8W1I;VX@<W5B=')A8W1396-O;F1S*"1S96,I"B`@("!["B`@
M("`@("`@)'1H:7,M/G-U8G1R86-T4W!A;BAN97<@1&%T95]3<&%N*"1S96,I
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-U8G1R86-T<R!A('1I;64@<W!A
M;B!T;R!T:&4@9&%T90H@("`@("H*("`@("`J(%-U8G1R86-T<R!A('1I;64@
M<W!A;B!T;R!T:&4@9&%T90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B!`<&%R86T@;V)J96-T($1A=&5?4W!A;B`D<W!A;B!T:&4@=&EM
M92!S<&%N('1O('-U8G1R86-T"B`@("`@*B\*("`@(&9U;F-T:6]N('-U8G1R
M86-T4W!A;B@D<W!A;BD*("`@('L*("`@("`@("!I9B`H(6ES7V$H)'-P86XL
M("=$871E7U-P86XG*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@
M?0H@("`@("`@(&EF("@D<W!A;BT^:7-%;7!T>2@I*2!["B`@("`@("`@("`@
M(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YS96-O;F0@+3T@
M)'-P86XM/G-E8V]N9#L*("`@("`@("!I9B`H)'1H:7,M/G-E8V]N9"`\(#`I
M('L*("`@("`@("`@("`@)'1H:7,M/FUI;G5T92TM.PH@("`@("`@("`@("`D
M=&AI<RT^<V5C;VYD("L](#8P.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/FUI;G5T92`M/2`D<W!A;BT^;6EN=71E.PH@("`@("`@(&EF("@D=&AI<RT^
M;6EN=71E(#P@,"D@>PH@("`@("`@("`@("`D=&AI<RT^:&]U<BTM.PH@("`@
M("`@("`@("!I9B`H)'1H:7,M/FAO=7(@/"`P*2!["B`@("`@("`@("`@("`@
M("!L:7-T*"1T:&ES+3YY96%R+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YD87DI
M(#T*("`@("`@("`@("`@("`@("`@("!S<V-A;F8H1&%T95]#86QC.CIP<F5V
M1&%Y*"1T:&ES+3YD87DL("1T:&ES+3YM;VYT:"P@)'1H:7,M/GEE87(I+"`B
M)3`T<R4P,G,E,#)S(BD["B`@("`@("`@("`@("`@("`D=&AI<RT^:&]U<B`K
M/2`R-#L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^;6EN=71E
M("L](#8P.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/FAO=7(@+3T@)'-P
M86XM/FAO=7(["B`@("`@("`@:68@*"1T:&ES+3YH;W5R(#P@,"D@>PH@("`@
M("`@("`@("!L:7-T*"1T:&ES+3YY96%R+"`D=&AI<RT^;6]N=&@L("1T:&ES
M+3YD87DI(#T*("`@("`@("`@("`@("`@('-S8V%N9BA$871E7T-A;&,Z.G!R
M979$87DH)'1H:7,M/F1A>2P@)'1H:7,M/FUO;G1H+"`D=&AI<RT^>65A<BDL
M("(E,#1S)3`R<R4P,G,B*3L*("`@("`@("`@("`@)'1H:7,M/FAO=7(@*ST@
M,C0["B`@("`@("`@?0H*("`@("`@("`D9"`]($1A=&5?0V%L8SHZ9&%T951O
M1&%Y<R@D=&AI<RT^9&%Y+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YY96%R*3L*
M("`@("`@("`D9"`M/2`D<W!A;BT^9&%Y.PH*("`@("`@("!L:7-T*"1T:&ES
M+3YY96%R+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YD87DI(#T*("`@("`@("`@
M("`@<W-C86YF*$1A=&5?0V%L8SHZ9&%Y<U1O1&%T92@D9"DL("(E,#1S)3`R
M<R4P,G,B*3L*("`@("`@("`D=&AI<RT^>65A<B`@/2!I;G1V86PH)'1H:7,M
M/GEE87(I.PH@("`@("`@("1T:&ES+3YM;VYT:"`](&EN='9A;"@D=&AI<RT^
M;6]N=&@I.PH@("`@("`@("1T:&ES+3YD87D@("`](&EN='9A;"@D=&AI<RT^
M9&%Y*3L*("`@('T*"B`@("`O*BH*("`@("`J($-O;7!A<F5S('1W;R!D871E
M<PH@("`@("H*("`@("`J($-O;7!A<F5S('1W;R!D871E<RX@(%-U:71A8FQE
M(&9O<B!U<V4*("`@("`J(&EN('-O<G1I;F<@9G5N8W1I;VYS+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@;V)J96-T($1A
M=&4@)&0Q('1H92!F:7)S="!D871E"B`@("`@*B!`<&%R86T@;V)J96-T($1A
M=&4@)&0R('1H92!S96-O;F0@9&%T90H@("`@("H@0')E='5R;B!I;G0@,"!I
M9B!T:&4@9&%T97,@87)E(&5Q=6%L+"`M,2!I9B!D,2!I<R!B969O<F4@9#(L
M(#$@:68@9#$@:7,@869T97(@9#(*("`@("`J+PH@("`@9G5N8W1I;VX@8V]M
M<&%R92@D9#$L("1D,BD*("`@('L*("`@("`@("`D9#$M/F-O;G9E<G146BAN
M97<@1&%T95]4:6UE6F]N92@G551#)RDI.PH@("`@("`@("1D,BT^8V]N=F5R
M=%1:*&YE=R!$871E7U1I;65:;VYE*"=55$,G*2D["B`@("`@("`@)&1A>7,Q
M(#T@1&%T95]#86QC.CID871E5&]$87ES*"1D,2T^9&%Y+"`D9#$M/FUO;G1H
M+"`D9#$M/GEE87(I.PH@("`@("`@("1D87ES,B`]($1A=&5?0V%L8SHZ9&%T
M951O1&%Y<R@D9#(M/F1A>2P@)&0R+3YM;VYT:"P@)&0R+3YY96%R*3L*("`@
M("`@("!I9B`H)&1A>7,Q(#P@)&1A>7,R*2!R971U<FX@+3$["B`@("`@("`@
M:68@*"1D87ES,2`^("1D87ES,BD@<F5T=7)N(#$["B`@("`@("`@:68@*"1D
M,2T^:&]U<B`\("1D,BT^:&]U<BD@<F5T=7)N("TQ.PH@("`@("`@(&EF("@D
M9#$M/FAO=7(@/B`D9#(M/FAO=7(I(')E='5R;B`Q.PH@("`@("`@(&EF("@D
M9#$M/FUI;G5T92`\("1D,BT^;6EN=71E*2!R971U<FX@+3$["B`@("`@("`@
M:68@*"1D,2T^;6EN=71E(#X@)&0R+3YM:6YU=&4I(')E='5R;B`Q.PH@("`@
M("`@(&EF("@D9#$M/G-E8V]N9"`\("1D,BT^<V5C;VYD*2!R971U<FX@+3$[
M"B`@("`@("`@:68@*"1D,2T^<V5C;VYD(#X@)&0R+3YS96-O;F0I(')E='5R
M;B`Q.PH@("`@("`@(')E='5R;B`P.PH@("`@?0H*("`@("\J*@H@("`@("H@
M5&5S="!I9B!T:&ES(&1A=&4O=&EM92!I<R!B969O<F4@82!C97)T86EN(&1A
M=&4O=&EM90H@("`@("H*("`@("`J(%1E<W0@:68@=&AI<R!D871E+W1I;64@
M:7,@8F5F;W)E(&$@8V5R=&%I;B!D871E+W1I;64*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M(&]B:F5C="!$871E("1W:&5N
M('1H92!D871E('1O('1E<W0@86=A:6YS=`H@("`@("H@0')E='5R;B!B;V]L
M96%N('1R=64@:68@=&AI<R!D871E(&ES(&)E9F]R92`D=VAE;@H@("`@("HO
M"B`@("!F=6YC=&EO;B!B969O<F4H)'=H96XI"B`@("!["B`@("`@("`@:68@
M*$1A=&4Z.F-O;7!A<F4H)'1H:7,L)'=H96XI(#T]("TQ*2!["B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!497-T(&EF('1H:7,@9&%T92]T:6UE(&ES(&%F=&5R(&$@8V5R=&EA;B!D
M871E+W1I;64*("`@("`J"B`@("`@*B!497-T(&EF('1H:7,@9&%T92]T:6UE
M(&ES(&%F=&5R(&$@8V5R=&EA;B!D871E+W1I;64*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M(&]B:F5C="!$871E("1W:&5N
M('1H92!D871E('1O('1E<W0@86=A:6YS=`H@("`@("H@0')E='5R;B!B;V]L
M96%N('1R=64@:68@=&AI<R!D871E(&ES(&%F=&5R("1W:&5N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%F=&5R*"1W:&5N*0H@("`@>PH@("`@("`@(&EF("A$
M871E.CIC;VUP87)E*"1T:&ES+"1W:&5N*2`]/2`Q*2!["B`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4
M97-T(&EF('1H:7,@9&%T92]T:6UE(&ES(&5X86-T;'D@97%U86P@=&\@82!C
M97)T:6%N(&1A=&4O=&EM90H@("`@("H*("`@("`J(%1E<W0@:68@=&AI<R!D
M871E+W1I;64@:7,@97AA8W1L>2!E<75A;"!T;R!A(&-E<G1I86X@9&%T92]T
M:6UE"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A
M;2!O8FIE8W0@1&%T92`D=VAE;B!T:&4@9&%T92!T;R!T97-T(&%G86EN<W0*
M("`@("`J($!R971U<FX@8F]O;&5A;B!T<G5E(&EF('1H:7,@9&%T92!I<R!E
M>&%C=&QY(&5Q=6%L('1O("1W:&5N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5Q
M=6%L<R@D=VAE;BD*("`@('L*("`@("`@("!I9B`H1&%T93HZ8V]M<&%R92@D
M=&AI<RPD=VAE;BD@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE(&EF('1H
M:7,@9&%T92!I<R!I;B!T:&4@9G5T=7)E"B`@("`@*@H@("`@("H@1&5T97)M
M:6YE(&EF('1H:7,@9&%T92!I<R!I;B!T:&4@9G5T=7)E"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@8F]O;&5A;B!T<G5E
M(&EF('1H:7,@9&%T92!I<R!I;B!T:&4@9G5T=7)E"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&ES1G5T=7)E*"D*("`@('L*("`@("`@("`D;F]W(#T@;F5W($1A
M=&4H*3L*("`@("`@("!I9B`H)'1H:7,M/F%F=&5R*"1N;W<I*2!["B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$971E<FUI;F4@:68@=&AI<R!D871E(&ES(&EN('1H92!P87-T"B`@
M("`@*@H@("`@("H@1&5T97)M:6YE(&EF('1H:7,@9&%T92!I<R!I;B!T:&4@
M<&%S=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@=')U92!I9B!T:&ES(&1A=&4@:7,@:6X@=&AE('!A<W0*
M("`@("`J+PH@("`@9G5N8W1I;VX@:7-087-T*"D*("`@('L*("`@("`@("`D
M;F]W(#T@;F5W($1A=&4H*3L*("`@("`@("!I9B`H)'1H:7,M/F)E9F]R92@D
M;F]W*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE(&EF('1H92!Y96%R(&EN('1H
M:7,@9&%T92!I<R!A(&QE87`@>65A<@H@("`@("H*("`@("`J($1E=&5R;6EN
M92!I9B!T:&4@>65A<B!I;B!T:&ES(&1A=&4@:7,@82!L96%P('EE87(*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!B;V]L
M96%N('1R=64@:68@=&AI<R!Y96%R(&ES(&$@;&5A<"!Y96%R"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&ES3&5A<%EE87(H*0H@("`@>PH@("`@("`@(')E='5R
M;B!$871E7T-A;&,Z.FES3&5A<%EE87(H)'1H:7,M/GEE87(I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1V5T('1H92!*=6QI86X@9&%T92!F;W(@=&AI<R!D
M871E"B`@("`@*@H@("`@("H@1V5T('1H92!*=6QI86X@9&%T92!F;W(@=&AI
M<R!D871E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R
M971U<FX@:6YT('1H92!*=6QI86X@9&%T90H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971*=6QI86Y$871E*"D*("`@('L*("`@("`@("!R971U<FX@1&%T95]#
M86QC.CIJ=6QI86Y$871E*"1T:&ES+3YD87DL("1T:&ES+3YM;VYT:"P@)'1H
M:7,M/GEE87(I.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@9&%Y
M(&]F('1H92!W965K(&9O<B!T:&ES(&1A=&4*("`@("`J"B`@("`@*B!'971S
M('1H92!D87D@;V8@=&AE('=E96L@9F]R('1H:7,@9&%T92`H,#U3=6YD87DI
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@
M:6YT('1H92!D87D@;V8@=&AE('=E96L@*#`]4W5N9&%Y*0H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971$87E/9E=E96LH*0H@("`@>PH@("`@("`@(')E='5R
M;B!$871E7T-A;&,Z.F1A>4]F5V5E:R@D=&AI<RT^9&%Y+"`D=&AI<RT^;6]N
M=&@L("1T:&ES+3YY96%R*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E=',@
M=&AE('=E96L@;V8@=&AE('EE87(@9F]R('1H:7,@9&%T90H@("`@("H*("`@
M("`J($=E=',@=&AE('=E96L@;V8@=&AE('EE87(@9F]R('1H:7,@9&%T90H@
M("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&EN
M="!T:&4@=V5E:R!O9B!T:&4@>65A<@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9717965K3V9996%R*"D*("`@('L*("`@("`@("!R971U<FX@1&%T95]#86QC
M.CIW965K3V9996%R*"1T:&ES+3YD87DL("1T:&ES+3YM;VYT:"P@)'1H:7,M
M/GEE87(I.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@<75A<G1E
M<B!O9B!T:&4@>65A<B!F;W(@=&AI<R!D871E"B`@("`@*@H@("`@("H@1V5T
M<R!T:&4@<75A<G1E<B!O9B!T:&4@>65A<B!F;W(@=&AI<R!D871E"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@:6YT('1H
M92!Q=6%R=&5R(&]F('1H92!Y96%R("@Q+30I"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=%%U87)T97)/9EEE87(H*0H@("`@>PH@("`@("`@(')E='5R;B!$
M871E7T-A;&,Z.G%U87)T97)/9EEE87(H)'1H:7,M/F1A>2P@)'1H:7,M/FUO
M;G1H+"`D=&AI<RT^>65A<BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S
M(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"!F;W(@=&AI<R!D871E"B`@
M("`@*@H@("`@("H@1V5T<R!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@@
M9F]R('1H:7,@9&%T90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B!`<F5T=7)N(&EN="!N=6UB97(@;V8@9&%Y<R!I;B!T:&ES(&UO;G1H
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1A>7-);DUO;G1H*"D*("`@('L*
M("`@("`@("!R971U<FX@1&%T95]#86QC.CID87ES26Y-;VYT:"@D=&AI<RT^
M;6]N=&@L("1T:&ES+3YY96%R*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E
M=',@=&AE(&YU;6)E<B!O9B!W965K<R!I;B!T:&4@;6]N=&@@9F]R('1H:7,@
M9&%T90H@("`@("H*("`@("`J($=E=',@=&AE(&YU;6)E<B!O9B!W965K<R!I
M;B!T:&4@;6]N=&@@9F]R('1H:7,@9&%T90H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&EN="!N=6UB97(@;V8@=V5E:W,@
M:6X@=&AI<R!M;VYT:`H@("`@("HO"B`@("!F=6YC=&EO;B!G9717965K<TEN
M36]N=&@H*0H@("`@>PH@("`@("`@(')E='5R;B!$871E7T-A;&,Z.G=E96MS
M26Y-;VYT:"@D=&AI<RT^;6]N=&@L("1T:&ES+3YY96%R*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($=E=',@=&AE(&9U;&P@;F%M92!O<B!A8F)R:79I871E
M9"!N86UE(&]F('1H:7,@=V5E:V1A>0H@("`@("H*("`@("`J($=E=',@=&AE
M(&9U;&P@;F%M92!O<B!A8F)R:79I871E9"!N86UE(&]F('1H:7,@=V5E:V1A
M>0H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D86)B<B!A8F)R:79A=&4@=&AE(&YA;64*("`@("`J($!R971U
M<FX@<W1R:6YG(&YA;64@;V8@=&AI<R!D87D*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T1&%Y3F%M92@D86)B<B`](&9A;'-E+"`D;&5N9W1H(#T@,RD*("`@
M('L*("`@("`@("!I9B`H)&%B8G(I('L*("`@("`@("`@("`@<F5T=7)N($1A
M=&5?0V%L8SHZ9V5T5V5E:V1A>4%B8G)N86UE*"1T:&ES+3YD87DL("1T:&ES
M+3YM;VYT:"P@)'1H:7,M/GEE87(L("1L96YG=&@I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B!$871E7T-A;&,Z.F=E=%=E96MD87E&
M=6QL;F%M92@D=&AI<RT^9&%Y+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YY96%R
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!F
M=6QL(&YA;64@;W(@86)B<FEV:6%T960@;F%M92!O9B!T:&ES(&UO;G1H"B`@
M("`@*@H@("`@("H@1V5T<R!T:&4@9G5L;"!N86UE(&]R(&%B8G)I=FEA=&5D
M(&YA;64@;V8@=&AI<R!M;VYT:`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D86)B<B!A8F)R:79A=&4@=&AE
M(&YA;64*("`@("`J($!R971U<FX@<W1R:6YG(&YA;64@;V8@=&AI<R!M;VYT
M:`H@("`@("HO"B`@("!F=6YC=&EO;B!G971-;VYT:$YA;64H)&%B8G(@/2!F
M86QS92D*("`@('L*("`@("`@("!I9B`H)&%B8G(I('L*("`@("`@("`@("`@
M<F5T=7)N($1A=&5?0V%L8SHZ9V5T36]N=&A!8F)R;F%M92@D=&AI<RT^;6]N
M=&@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!$871E
M7T-A;&,Z.F=E=$UO;G1H1G5L;&YA;64H)'1H:7,M/FUO;G1H*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!$871E(&]B:F5C="!F
M;W(@=&AE(&1A>2!A9G1E<B!T:&ES(&]N90H@("`@("H*("`@("`J($=E="!A
M($1A=&4@;V)J96-T(&9O<B!T:&4@9&%Y(&%F=&5R('1H:7,@;VYE+@H@("`@
M("H@5&AE('1I;64@;V8@=&AE(')E='5R;F5D($1A=&4@;V)J96-T(&ES('1H
M92!S86UE(&%S('1H:7,@=&EM92X*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H@0')E='5R;B!O8FIE8W0@1&%T92!$871E(')E<')E<V5N
M=&EN9R!T:&4@;F5X="!D87D*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3F5X
M=$1A>2@I"B`@("!["B`@("`@("`@)&1A>2`]($1A=&5?0V%L8SHZ;F5X=$1A
M>2@D=&AI<RT^9&%Y+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YY96%R+"`B)5DM
M)6TM)60B*3L*("`@("`@("`D9&%T92`]('-P<FEN=&8H(B5S("4P,F0Z)3`R
M9#HE,#)D(BP@)&1A>2P@)'1H:7,M/FAO=7(L("1T:&ES+3YM:6YU=&4L("1T
M:&ES+3YS96-O;F0I.PH@("`@("`@("1N97=$871E(#T@;F5W($1A=&4H*3L*
M("`@("`@("`D;F5W1&%T92T^<V5T1&%T92@D9&%T92D["B`@("`@("`@<F5T
M=7)N("1N97=$871E.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@1&%T
M92!O8FIE8W0@9F]R('1H92!D87D@8F5F;W)E('1H:7,@;VYE"B`@("`@*@H@
M("`@("H@1V5T(&$@1&%T92!O8FIE8W0@9F]R('1H92!D87D@8F5F;W)E('1H
M:7,@;VYE+@H@("`@("H@5&AE('1I;64@;V8@=&AE(')E='5R;F5D($1A=&4@
M;V)J96-T(&ES('1H92!S86UE(&%S('1H:7,@=&EM92X*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!O8FIE8W0@1&%T92!$
M871E(')E<')E<V5N=&EN9R!T:&4@<')E=FEO=7,@9&%Y"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%!R979$87DH*0H@("`@>PH@("`@("`@("1D87D@/2!$
M871E7T-A;&,Z.G!R979$87DH)'1H:7,M/F1A>2P@)'1H:7,M/FUO;G1H+"`D
M=&AI<RT^>65A<BP@(B59+25M+25D(BD["B`@("`@("`@)&1A=&4@/2!S<')I
M;G1F*"(E<R`E,#)D.B4P,F0Z)3`R9"(L("1D87DL("1T:&ES+3YH;W5R+"`D
M=&AI<RT^;6EN=71E+"`D=&AI<RT^<V5C;VYD*3L*("`@("`@("`D;F5W1&%T
M92`](&YE=R!$871E*"D["B`@("`@("`@)&YE=T1A=&4M/G-E=$1A=&4H)&1A
M=&4I.PH@("`@("`@(')E='5R;B`D;F5W1&%T93L*("`@('T*"B`@("`O*BH*
M("`@("`J($=E="!A($1A=&4@;V)J96-T(&9O<B!T:&4@=V5E:V1A>2!A9G1E
M<B!T:&ES(&]N90H@("`@("H*("`@("`J($=E="!A($1A=&4@;V)J96-T(&9O
M<B!T:&4@=V5E:V1A>2!A9G1E<B!T:&ES(&]N92X*("`@("`J(%1H92!T:6UE
M(&]F('1H92!R971U<FYE9"!$871E(&]B:F5C="!I<R!T:&4@<V%M92!A<R!T
M:&ES('1I;64N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M($!R971U<FX@;V)J96-T($1A=&4@1&%T92!R97!R97-E;G1I;F<@=&AE(&YE
M>'0@=V5E:V1A>0H@("`@("HO"B`@("!F=6YC=&EO;B!G971.97AT5V5E:V1A
M>2@I"B`@("!["B`@("`@("`@)&1A>2`]($1A=&5?0V%L8SHZ;F5X=%=E96MD
M87DH)'1H:7,M/F1A>2P@)'1H:7,M/FUO;G1H+"`D=&AI<RT^>65A<BP@(B59
M+25M+25D(BD["B`@("`@("`@)&1A=&4@/2!S<')I;G1F*"(E<R`E,#)D.B4P
M,F0Z)3`R9"(L("1D87DL("1T:&ES+3YH;W5R+"`D=&AI<RT^;6EN=71E+"`D
M=&AI<RT^<V5C;VYD*3L*("`@("`@("`D;F5W1&%T92`](&YE=R!$871E*"D[
M"B`@("`@("`@)&YE=T1A=&4M/G-E=$1A=&4H)&1A=&4I.PH@("`@("`@(')E
M='5R;B`D;F5W1&%T93L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A($1A
M=&4@;V)J96-T(&9O<B!T:&4@=V5E:V1A>2!B969O<F4@=&AI<R!O;F4*("`@
M("`J"B`@("`@*B!'970@82!$871E(&]B:F5C="!F;W(@=&AE('=E96MD87D@
M8F5F;W)E('1H:7,@;VYE+@H@("`@("H@5&AE('1I;64@;V8@=&AE(')E='5R
M;F5D($1A=&4@;V)J96-T(&ES('1H92!S86UE(&%S('1H:7,@=&EM92X*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!O8FIE
M8W0@1&%T92!$871E(')E<')E<V5N=&EN9R!T:&4@<')E=FEO=7,@=V5E:V1A
M>0H@("`@("HO"B`@("!F=6YC=&EO;B!G9710<F5V5V5E:V1A>2@I"B`@("![
M"B`@("`@("`@)&1A>2`]($1A=&5?0V%L8SHZ<')E=E=E96MD87DH)'1H:7,M
M/F1A>2P@)'1H:7,M/FUO;G1H+"`D=&AI<RT^>65A<BP@(B59+25M+25D(BD[
M"B`@("`@("`@)&1A=&4@/2!S<')I;G1F*"(E<R`E,#)D.B4P,F0Z)3`R9"(L
M("1D87DL("1T:&ES+3YH;W5R+"`D=&AI<RT^;6EN=71E+"`D=&AI<RT^<V5C
M;VYD*3L*("`@("`@("`D;F5W1&%T92`](&YE=R!$871E*"D["B`@("`@("`@
M)&YE=T1A=&4M/G-E=$1A=&4H)&1A=&4I.PH@("`@("`@(')E='5R;B`D;F5W
M1&%T93L*("`@('T*"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!Y96%R
M(&9I96QD(&]F('1H92!D871E(&]B:F5C=`H@("`@("H*("`@("`J(%)E='5R
M;G,@=&AE('EE87(@9FEE;&0@;V8@=&AE(&1A=&4@;V)J96-T"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@:6YT('1H92!Y
M96%R"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%EE87(H*0H@("`@>PH@("`@
M("`@(')E='5R;B`H:6YT*21T:&ES+3YY96%R.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@;6]N=&@@9FEE;&0@;V8@=&AE(&1A=&4@;V)J
M96-T"B`@("`@*@H@("`@("H@4F5T=7)N<R!T:&4@;6]N=&@@9FEE;&0@;V8@
M=&AE(&1A=&4@;V)J96-T"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J($!R971U<FX@:6YT('1H92!M;VYT:`H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971-;VYT:"@I"B`@("!["B`@("`@("`@<F5T=7)N("AI;G0I)'1H
M:7,M/FUO;G1H.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M9&%Y(&9I96QD(&]F('1H92!D871E(&]B:F5C=`H@("`@("H*("`@("`J(%)E
M='5R;G,@=&AE(&1A>2!F:65L9"!O9B!T:&4@9&%T92!O8FIE8W0*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!I;G0@=&AE
M(&1A>0H@("`@("HO"B`@("!F=6YC=&EO;B!G971$87DH*0H@("`@>PH@("`@
M("`@(')E='5R;B`H:6YT*21T:&ES+3YD87D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!H;W5R(&9I96QD(&]F('1H92!D871E(&]B:F5C
M=`H@("`@("H*("`@("`J(%)E='5R;G,@=&AE(&AO=7(@9FEE;&0@;V8@=&AE
M(&1A=&4@;V)J96-T"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J($!R971U<FX@:6YT('1H92!H;W5R"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$AO=7(H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^:&]U<CL*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&UI;G5T92!F:65L
M9"!O9B!T:&4@9&%T92!O8FIE8W0*("`@("`J"B`@("`@*B!2971U<FYS('1H
M92!M:6YU=&4@9FEE;&0@;V8@=&AE(&1A=&4@;V)J96-T"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@:6YT('1H92!M:6YU
M=&4*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T36EN=71E*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/FUI;G5T93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE('-E8V]N9"!F:65L9"!O9B!T:&4@9&%T92!O8FIE
M8W0*("`@("`J"B`@("`@*B!2971U<FYS('1H92!S96-O;F0@9FEE;&0@;V8@
M=&AE(&1A=&4@;V)J96-T"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J($!R971U<FX@:6YT('1H92!S96-O;F0*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4V5C;VYD*"D*("`@('L*("`@("`@("`@<F5T=7)N("1T:&ES
M+3YS96-O;F0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE('EE87(@
M9FEE;&0@;V8@=&AE(&1A=&4@;V)J96-T"B`@("`@*@H@("`@("H@4V5T('1H
M92!Y96%R(&9I96QD(&]F('1H92!D871E(&]B:F5C="P@:6YV86QI9"!Y96%R
M<R`H;F]T(#`M.3DY.2D@87)E('-E="!T;R`P+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@:6YT("1Y('1H92!Y96%R"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E=%EE87(H)'DI"B`@("!["B`@("`@("`@
M:68@*"1Y(#P@,"!\?"`D>2`^(#DY.3DI('L*("`@("`@("`@("`@)'1H:7,M
M/GEE87(@/2`P.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES
M+3YY96%R(#T@)'D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4V5T('1H92!M;VYT:"!F:65L9"!O9B!T:&4@9&%T92!O8FIE8W0*("`@("`J
M"B`@("`@*B!3970@=&AE(&UO;G1H(&9I96QD(&]F('1H92!D871E(&]B:F5C
M="P@:6YV86QI9"!M;VYT:',@*&YO="`Q+3$R*2!A<F4@<V5T('1O(#$N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!I;G0@
M)&T@=&AE(&UO;G1H"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$UO;G1H*"1M
M*0H@("`@>PH@("`@("`@(&EF("@D;2`\(#$@?'P@)&T@/B`Q,BD@>PH@("`@
M("`@("`@("`D=&AI<RT^;6]N=&@@/2`Q.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1T:&ES+3YM;VYT:"`]("1M.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J(%-E="!T:&4@9&%Y(&9I96QD(&]F('1H92!D871E
M(&]B:F5C=`H@("`@("H*("`@("`J(%-E="!T:&4@9&%Y(&9I96QD(&]F('1H
M92!D871E(&]B:F5C="P@:6YV86QI9"!D87ES("AN;W0@,2TS,2D@87)E('-E
M="!T;R`Q+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`
M<&%R86T@:6YT("1D('1H92!D87D*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M1&%Y*"1D*0H@("`@>PH@("`@("`@(&EF("@D9"`^(#,Q('Q\("1D(#P@,2D@
M>PH@("`@("`@("`@("`D=&AI<RT^9&%Y(#T@,3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=&AI<RT^9&%Y(#T@)&0["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@4V5T('1H92!H;W5R(&9I96QD(&]F('1H92!D
M871E(&]B:F5C=`H@("`@("H*("`@("`J(%-E="!T:&4@:&]U<B!F:65L9"!O
M9B!T:&4@9&%T92!O8FIE8W0@:6X@,C0M:&]U<B!F;W)M870N"B`@("`@*B!)
M;G9A;&ED(&AO=7)S("AN;W0@,"TR,RD@87)E('-E="!T;R`P+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@:6YT("1H('1H
M92!H;W5R"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$AO=7(H)&@I"B`@("![
M"B`@("`@("`@:68@*"1H(#X@,C,@?'P@)&@@/"`P*2!["B`@("`@("`@("`@
M("1T:&ES+3YH;W5R(#T@,#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D=&AI<RT^:&]U<B`]("1H.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E="!T:&4@;6EN=71E(&9I96QD(&]F('1H92!D871E(&]B:F5C
M=`H@("`@("H*("`@("`J(%-E="!T:&4@;6EN=71E(&9I96QD(&]F('1H92!D
M871E(&]B:F5C="P@:6YV86QI9"!M:6YU=&5S("AN;W0@,"TU.2D@87)E('-E
M="!T;R`P+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`
M<&%R86T@:6YT("1M('1H92!M:6YU=&4*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T36EN=71E*"1M*0H@("`@>PH@("`@("`@(&EF("@D;2`^(#4Y('Q\("1M
M(#P@,"D@>PH@("`@("`@("`@("`D=&AI<RT^;6EN=71E(#T@,#L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^;6EN=71E(#T@)&T["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!S96-O;F0@
M9FEE;&0@;V8@=&AE(&1A=&4@;V)J96-T"B`@("`@*@H@("`@("H@4V5T('1H
M92!S96-O;F0@9FEE;&0@;V8@=&AE(&1A=&4@;V)J96-T+"!I;G9A;&ED('-E
M8V]N9',@*&YO="`P+34Y*2!A<F4@<V5T('1O(#`N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!I;G0@)',@=&AE('-E8V]N
M9`H@("`@("HO"B`@("!F=6YC=&EO;B!S971396-O;F0H)',I('L*("`@("`@
M("!I9B`H)',@/B`U.2!\?"`D<R`\(#`I('L*("`@("`@("`@("`@)'1H:7,M
M/G-E8V]N9"`](#`["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H
M:7,M/G-E8V]N9"`]("1S.PH@("`@("`@('T*("`@('T*?0H*/SX*+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T1"+P``````````````````````
M````````````````````````````````````````````````````````````
M`````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,S-S,W`#`Q-S`W-``@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O1$(O
M8V]M;6]N+G!H<```````````````````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`R,#<U-C<`,3`U,34T,S,W,S8`,#(Q,3$U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@HO*B!V:6TZ('-E
M="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O
M<#TT.B`J+PH*+RHJ"B`J($-O;G1A:6YS('1H92!$0E]C;VUM;VX@8F%S92!C
M;&%S<PH@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%
M.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@
M;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@
M*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E
M(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L
M('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@
M=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A
M=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO
M<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@H@*B!`875T:&]R("`@
M("!4;VUA<R!6+E8N($-O>"`\8V]X0&ED96-N970N8V]M/@H@*B!`875T:&]R
M("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C
M;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@8V]M;6]N+G!H
M<"QV(#$N,3,W(#(P,#4O,#0O,#<@,30Z,C<Z,S4@9&%N:65L8R!%>'`@)`H@
M*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*
M("HO"@HO*BH*("H@3V)T86EN('1H92!014%2(&-L87-S('-O(&ET(&-A;B!B
M92!E>'1E;F1E9"!F<F]M"B`J+PIR97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*
M"B\J*@H@*B!$0E]C;VUM;VX@:7,@=&AE(&)A<V4@8VQA<W,@9G)O;2!W:&EC
M:"!E86-H(&1A=&%B87-E(&1R:79E<B!C;&%S<R!E>'1E;F1S"B`J"B`J($%L
M;"!C;VUM;VX@;65T:&]D<R!A<F4@9&5C;&%R960@:&5R92X@($EF(&$@9VEV
M96X@1$)-4R!D<FEV97(@8V]N=&%I;G,*("H@82!P87)T:6-U;&%R(&UE=&AO
M9"P@=&AA="!M971H;V0@=VEL;"!O=F5R;&]A9"!T:&4@;VYE(&AE<F4N"B`J
M"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J
M($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X*("H@0&%U
M=&AO<B`@("`@5&]M87,@5BY6+B!#;W@@/&-O>$!I9&5C;F5T+F-O;3X*("H@
M0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T
M/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`
M;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XW
M+C8*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+T1""B`J+PIC;&%S<R!$0E]C;VUM;VX@97AT96YD<R!014%2"GL*("`@("\O
M('M[>R!P<F]P97)T:65S"@H@("`@+RHJ"B`@("`@*B!4:&4@8W5R<F5N="!D
M969A=6QT(&9E=&-H(&UO9&4*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO
M"B`@("!V87(@)&9E=&-H;6]D92`]($1"7T9%5$-(34]$15]/4D1%4D5$.PH*
M("`@("\J*@H@("`@("H@5&AE(&YA;64@;V8@=&AE(&-L87-S(&EN=&\@=VAI
M8V@@<F5S=6QT<R!S:&]U;&0@8F4@9F5T8VAE9"!W:&5N"B`@("`@*B!$0E]&
M151#2$U/1$5?3T)*14-4(&ES(&EN(&5F9F5C=`H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D9F5T8VAM;V1E7V]B:F5C=%]C
M;&%S<R`]("=S=&1#;&%S<R<["@H@("`@+RHJ"B`@("`@*B!787,@82!C;VYN
M96-T:6]N('!R97-E;G0@=VAE;B!T:&4@;V)J96-T('=A<R!S97)I86QI>F5D
M*"D_"B`@("`@*B!`=F%R(&)O;VP*("`@("`J($!S964@1$)?8V]M;6]N.CI?
M7W-L965P*"DL($1"7V-O;6UO;CHZ7U]W86ME*"D*("`@("`J+PH@("`@=F%R
M("1W87-?8V]N;F5C=&5D(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%1H92!M
M;W-T(')E8V5N=&QY(&5X96-U=&5D('%U97)Y"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)&QA<W1?<75E<GD@/2`G)SL*"B`@("`O*BH*
M("`@("`J(%)U;BUT:6UE(&-O;F9I9W5R871I;VX@;W!T:6]N<PH@("`@("H*
M("`@("`J(%1H92`G;W!T:6UI>F4G(&]P=&EO;B!H87,@8F5E;B!D97!R96-A
M=&5D+B`@57-E('1H92`G<&]R=&%B:6QI='DG"B`@("`@*B!O<'1I;VX@:6YS
M=&5A9"X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B!`<V5E($1"
M7V-O;6UO;CHZ<V5T3W!T:6]N*"D*("`@("`J+PH@("`@=F%R("1O<'1I;VYS
M(#T@87)R87DH"B`@("`@("`@)W)E<W5L=%]B=69F97)I;F<G(#T^(#4P,"P*
M("`@("`@("`G<&5R<VES=&5N="<@/3X@9F%L<V4L"B`@("`@("`@)W-S;"<@
M/3X@9F%L<V4L"B`@("`@("`@)V1E8G5G)R`]/B`P+`H@("`@("`@("=S97%N
M86UE7V9O<FUA="<@/3X@)R5S7W-E<2<L"B`@("`@("`@)V%U=&]F<F5E)R`]
M/B!F86QS92P*("`@("`@("`G<&]R=&%B:6QI='DG(#T^($1"7U!/4E1!0DE,
M25197TY/3D4L"B`@("`@("`@)V]P=&EM:7IE)R`]/B`G<&5R9F]R;6%N8V4G
M+"`@+R\@1&5P<F5C871E9"X@(%5S92`G<&]R=&%B:6QI='DG+@H@("`@*3L*
M"B`@("`O*BH*("`@("`J(%1H92!P87)A;65T97)S(&9R;VT@=&AE(&UO<W0@
M<F5C96YT;'D@97AE8W5T960@<75E<GD*("`@("`J($!V87(@87)R87D*("`@
M("`J($!S:6YC92!0<F]P97)T>2!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q
M+C<N,`H@("`@("HO"B`@("!V87(@)&QA<W1?<&%R86UE=&5R<R`](&%R<F%Y
M*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@96QE;65N=',@9G)O;2!E86-H('!R
M97!A<F5D('-T871E;65N=`H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)'!R97!A<F5?=&]K96YS(#T@87)R87DH*3L*"B`@("`O*BH*("`@
M("`J(%1H92!D871A('1Y<&5S(&]F('1H92!V87)I;W5S(&5L96UE;G1S(&EN
M(&5A8V@@<')E<&%R960@<W1A=&5M96YT"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D<')E<&%R95]T>7!E<R`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*B!4:&4@<')E<&%R960@<75E<FEE<PH@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)'!R97!A<F5D7W%U97)I97,@/2!A<G)A
M>2@I.PH*"B`@("`O+R!]?7T*("`@("\O('M[>R!$0E]C;VUM;VX*"B`@("`O
M*BH*("`@("`J(%1H:7,@8V]N<W1R=6-T;W(@8V%L;',@/&MB9#XD=&AI<RT^
M4$5!4B@G1$)?17)R;W(G*3PO:V)D/@H@("`@("H*("`@("`J($!R971U<FX@
M=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!$0E]C;VUM;VXH*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y014%2*"=$0E]%<G)O<B<I.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(%]?<VQE97`H*0H*("`@("\J*@H@("`@("H@075T
M;VUA=&EC86QL>2!I;F1I8V%T97,@=VAI8V@@<')O<&5R=&EE<R!S:&]U;&0@
M8F4@<V%V960*("`@("`J('=H96X@4$A0)W,@<V5R:6%L:7IE*"D@9G5N8W1I
M;VX@:7,@8V%L;&5D"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@=&AE
M(&%R<F%Y(&]F('!R;W!E<G1I97,@;F%M97,@=&AA="!S:&]U;&0@8F4@<V%V
M960*("`@("`J+PH@("`@9G5N8W1I;VX@7U]S;&5E<"@I"B`@("!["B`@("`@
M("`@:68@*"1T:&ES+3YC;VYN96-T:6]N*2!["B`@("`@("`@("`@("\O($1O
M;B=T(&1I<V-O;FYE8W0H*2P@<&5O<&QE('5S92!S97)I86QI>F4H*2!F;W(@
M;6%N>2!R96%S;VYS"B`@("`@("`@("`@("1T:&ES+3YW87-?8V]N;F5C=&5D
M(#T@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^
M=V%S7V-O;FYE8W1E9"`](&9A;'-E.PH@("`@("`@('T*("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/F%U=&]C;VUM:70I*2!["B`@("`@("`@("`@(')E='5R
M;B!A<G)A>2@G875T;V-O;6UI="<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`G9&)S>6YT87@G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)V1S;B<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`G9F5A='5R97,G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@)V9E=&-H;6]D92<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`G9F5T8VAM;V1E7V]B:F5C=%]C;&%S<R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`G;W!T:6]N<R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`G=V%S7V-O;FYE8W1E9"<L"B`@("`@("`@("`@("`@("`@("`I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@G
M9&)S>6YT87@G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)V1S;B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`G9F5A='5R97,G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@)V9E=&-H;6]D92<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`G9F5T8VAM;V1E7V]B:F5C=%]C;&%S<R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`G;W!T:6]N<R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`G=V%S7V-O;FYE8W1E9"<L"B`@("`@("`@("`@("`@("`@("`I.PH@
M("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!?7W=A:V5U
M<"@I"@H@("`@+RHJ"B`@("`@*B!!=71O;6%T:6-A;&QY(')E8V]N;F5C=',@
M=&\@=&AE(&1A=&%B87-E('=H96X@4$A0)W,@=6YS97)I86QI>F4H*0H@("`@
M("H@9G5N8W1I;VX@:7,@8V%L;&5D"B`@("`@*@H@("`@("H@5&AE(')E8V]N
M;F5C=&EO;B!A='1E;7!T(&ES(&]N;'D@<&5R9F]R;65D(&EF('1H92!O8FIE
M8W0@=V%S(&-O;FYE8W1E9`H@("`@("H@870@=&AE('1I;64@4$A0)W,@<V5R
M:6%L:7IE*"D@9G5N8W1I;VX@=V%S(')U;BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@7U]W86ME=7`H*0H@("`@
M>PH@("`@("`@(&EF("@D=&AI<RT^=V%S7V-O;FYE8W1E9"D@>PH@("`@("`@
M("`@("`D=&AI<RT^8V]N;F5C="@D=&AI<RT^9'-N+"`D=&AI<RT^;W!T:6]N
M<RD["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(%]?
M=&]3=')I;F<H*0H*("`@("\J*@H@("`@("H@075T;VUA=&EC('-T<FEN9R!C
M;VYV97)S:6]N(&9O<B!02%`@-0H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!A('-T<FEN9R!D97-C<FEB:6YG('1H92!C=7)R96YT(%!%05(@1$(@
M;V)J96-T"B`@("`@*@H@("`@("H@0'-I;F-E($UE=&AO9"!A=F%I;&%B;&4@
M<VEN8V4@4F5L96%S92`Q+C<N,`H@("`@("HO"B`@("!F=6YC=&EO;B!?7W1O
M4W1R:6YG*"D*("`@('L*("`@("`@("`D:6YF;R`]('-T<G1O;&]W97(H9V5T
M7V-L87-S*"1T:&ES*2D["B`@("`@("`@)&EN9F\@+CT@("<Z("AP:'!T>7!E
M/2<@+B`D=&AI<RT^<&AP='EP92`N"B`@("`@("`@("`@("`@("`@("<L(&1B
M<WEN=&%X/2<@+B`D=&AI<RT^9&)S>6YT87@@+@H@("`@("`@("`@("`@("`@
M("`G*2<["B`@("`@("`@:68@*"1T:&ES+3YC;VYN96-T:6]N*2!["B`@("`@
M("`@("`@("1I;F9O("X]("<@6V-O;FYE8W1E9%TG.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)&EN9F\["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@=&]3=')I;F<H*0H*("`@("\J*@H@("`@("H@1$504D5#051%1#H@(%-T
M<FEN9R!C;VYV97)S:6]N(&UE=&AO9`H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!A('-T<FEN9R!D97-C<FEB:6YG('1H92!C=7)R96YT(%!%05(@
M1$(@;V)J96-T"B`@("`@*@H@("`@("H@0&1E<')E8V%T960@365T:&]D(&1E
M<')E8V%T960@:6X@4F5L96%S92`Q+C<N,`H@("`@("HO"B`@("!F=6YC=&EO
M;B!T;U-T<FEN9R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?7W1O
M4W1R:6YG*"D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<75O=&53
M=')I;F<H*0H*("`@("\J*@H@("`@("H@1$504D5#051%1#H@475O=&5S(&$@
M<W1R:6YG('-O(&ET(&-A;B!B92!S869E;'D@=7-E9"!W:71H:6X@<W1R:6YG
M"B`@("`@*B!D96QI;6ET97)S(&EN(&$@<75E<GD*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1S=')I;F<@('1H92!S=')I;F<@=&\@8F4@<75O=&5D
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!Q=6]T960@<W1R
M:6YG"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G%U;W1E4VUA<G0H
M*2P@1$)?8V]M;6]N.CIE<V-A<&53:6UP;&4H*0H@("`@("H@0&1E<')E8V%T
M960@365T:&]D(&1E<')E8V%T960@<V]M92!T:6UE(&)E9F]R92!296QE87-E
M(#$N,@H@("`@("HO"B`@("!F=6YC=&EO;B!Q=6]T95-T<FEN9R@D<W1R:6YG
M*0H@("`@>PH@("`@("`@("1S=')I;F<@/2`D=&AI<RT^<75O=&4H)'-T<FEN
M9RD["B`@("`@("`@:68@*"1S=')I;F=[,'T@/3T@(B<B*2!["B`@("`@("`@
M("`@(')E='5R;B!S=6)S='(H)'-T<FEN9RP@,2P@+3$I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)'-T<FEN9SL*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!Q=6]T92@I"@H@("`@+RHJ"B`@("`@*B!$15!214-!5$5$.B!1
M=6]T97,@82!S=')I;F<@<V\@:70@8V%N(&)E('-A9F5L>2!U<V5D(&EN(&$@
M<75E<GD*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=')I;F<@('1H
M92!S=')I;F<@=&\@<75O=&4*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@=&AE('%U;W1E9"!S=')I;F<@;W(@=&AE('-T<FEN9R`\<V%M<#Y.54Q,
M/"]S86UP/@H@("`@("H@("`@("`@("`@("`@("`@("!I9B!T:&4@=F%L=64@
M<W5B;6ET=&5D(&ES(#QK8F0^;G5L;#PO:V)D/BX*("`@("`J"B`@("`@*B!`
M<V5E($1"7V-O;6UO;CHZ<75O=&53;6%R="@I+"!$0E]C;VUM;VXZ.F5S8V%P
M95-I;7!L92@I"B`@("`@*B!`9&5P<F5C871E9"!$97!R96-A=&5D(&EN(')E
M;&5A<V4@,2XV+C`*("`@("`J+PH@("`@9G5N8W1I;VX@<75O=&4H)'-T<FEN
M9R`](&YU;&PI"B`@("!["B`@("`@("`@<F5T=7)N("@D<W1R:6YG(#T]/2!N
M=6QL*2`_("=.54Q,)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@.B`B)R(@+B!S=')?<F5P;&%C92@B)R(L("(G)R(L("1S=')I;F<I("X@
M(B<B.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('%U;W1E261E;G1I
M9FEE<B@I"@H@("`@+RHJ"B`@("`@*B!1=6]T97,@82!S=')I;F<@<V\@:70@
M8V%N(&)E('-A9F5L>2!U<V5D(&%S(&$@=&%B;&4@;W(@8V]L=6UN(&YA;64*
M("`@("`J"B`@("`@*B!$96QI;6ET:6YG('-T>6QE(&1E<&5N9',@;VX@=VAI
M8V@@9&%T86)A<V4@9')I=F5R(&ES(&)E:6YG('5S960N"B`@("`@*@H@("`@
M("H@3D]413H@:G5S="!B96-A=7-E('EO=2!#04X@=7-E(&1E;&EM:71E9"!I
M9&5N=&EF:65R<R!D;V5S;B=T(&UE86X*("`@("`J('EO=2!32$]53$0@=7-E
M('1H96TN("!);B!G96YE<F%L+"!T:&5Y(&5N9"!U<"!C875S:6YG('=A>2!M
M;W)E"B`@("`@*B!P<F]B;&5M<R!T:&%N('1H97D@<V]L=F4N"B`@("`@*@H@
M("`@("H@4&]R=&%B:6QI='D@:7,@8G)O:V5N(&)Y('5S:6YG('1H92!F;VQL
M;W=I;F<@8VAA<F%C=&5R<R!I;G-I9&4*("`@("`J(&1E;&EM:71E9"!I9&5N
M=&EF:65R<SH*("`@("`J("`@*R!B86-K=&EC:R`H/&MB9#Y@/"]K8F0^*2`M
M+2!D=64@=&\@37E344P*("`@("`J("`@*R!D;W5B;&4@<75O=&4@*#QK8F0^
M(CPO:V)D/BD@+2T@9'5E('1O($]R86-L90H@("`@("H@("`K(&)R86-K971S
M("@\:V)D/EL\+VMB9#X@;W(@/&MB9#Y=/"]K8F0^*2`M+2!D=64@=&\@06-C
M97-S"B`@("`@*@H@("`@("H@1&5L:6UI=&5D(&ED96YT:69I97)S(&%R92!K
M;F]W;B!T;R!G96YE<F%L;'D@=V]R:R!C;W)R96-T;'D@=6YD97(*("`@("`J
M('1H92!F;VQL;W=I;F<@9')I=F5R<SH*("`@("`J("`@*R!M<W-Q;`H@("`@
M("H@("`K(&UY<W%L"B`@("`@*B`@("L@;7ES<6QI"B`@("`@*B`@("L@;V-I
M.`H@("`@("H@("`K(&]D8F,H86-C97-S*0H@("`@("H@("`K(&]D8F,H9&(R
M*0H@("`@("H@("`K('!G<W%L"B`@("`@*B`@("L@<W%L:71E"B`@("`@*B`@
M("L@<WEB87-E("AM=7-T(&5X96-U=&4@/&MB9#YS970@<75O=&5D7VED96YT
M:69I97(@;VX\+VMB9#X@<V]M971I;64*("`@("`J("`@("!P<FEO<B!T;R!U
M<V4I"B`@("`@*@H@("`@("H@26YT97)"87-E(&1O97-N)W0@<V5E;2!T;R!B
M92!A8FQE('1O('5S92!D96QI;6ET960@:61E;G1I9FEE<G,*("`@("`J('9I
M82!02%`@-"X@(%1H97D@=V]R:R!F:6YE('5N9&5R(%!(4"`U+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'-T<B`@=&AE(&ED96YT:69I97(@;F%M
M92!T;R!B92!Q=6]T960*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M=&AE('%U;W1E9"!I9&5N=&EF:65R"B`@("`@*@H@("`@("H@0'-I;F-E($UE
M=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C8N,`H@("`@("HO"B`@
M("!F=6YC=&EO;B!Q=6]T94ED96YT:69I97(H)'-T<BD*("`@('L*("`@("`@
M("!R971U<FX@)R(G("X@<W1R7W)E<&QA8V4H)R(G+"`G(B(G+"`D<W1R*2`N
M("<B)SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!Q=6]T95-M87)T
M*"D*"B`@("`O*BH*("`@("`J($9O<FUA=',@:6YP=70@<V\@:70@8V%N(&)E
M('-A9F5L>2!U<V5D(&EN(&$@<75E<GD*("`@("`J"B`@("`@*B!4:&4@;W5T
M<'5T(&1E<&5N9',@;VX@=&AE(%!(4"!D871A('1Y<&4@;V8@:6YP=70@86YD
M('1H92!D871A8F%S90H@("`@("H@='EP92!B96EN9R!U<V5D+@H@("`@("H*
M("`@("`J($!P87)A;2!M:7AE9"`D:6X@('1H92!D871A('1O(&)E(&9O<FUA
M='1E9`H@("`@("H*("`@("`J($!R971U<FX@;6EX960@('1H92!F;W)M871T
M960@9&%T82X@(%1H92!F;W)M870@9&5P96YD<R!O;B!T:&4@:6YP=70G<PH@
M("`@("H@("`@("`@("`@("`@("`@(%!(4"!T>7!E.@H@("`@("H@/'5L/@H@
M("`@("H@(#QL:3X*("`@("`J("`@(#QK8F0^:6YP=70\+VMB9#X@+3X@/'-A
M;7`^<F5T=7)N<SPO<V%M<#X*("`@("`J("`\+VQI/@H@("`@("H@(#QL:3X*
M("`@("`J("`@(#QK8F0^;G5L;#PO:V)D/B`M/B!T:&4@<W1R:6YG(#QS86UP
M/DY53$P\+W-A;7`^"B`@("`@*B`@/"]L:3X*("`@("`J("`\;&D^"B`@("`@
M*B`@("`\:V)D/FEN=&5G97(\+VMB9#X@;W(@/&MB9#YD;W5B;&4\+VMB9#X@
M+3X@=&AE('5N<75O=&5D(&YU;6)E<@H@("`@("H@(#PO;&D^"B`@("`@*B`@
M/&QI/@H@("`@("H@("`@/&MB9#YB;V]L/"]K8F0^("T^(&]U='!U="!D97!E
M;F1S(&]N('1H92!D<FEV97(@:6X@=7-E"B`@("`@*B`@("!-;W-T(&1R:79E
M<G,@<F5T=7)N(&EN=&5G97)S.B`\<V%M<#XQ/"]S86UP/B!I9@H@("`@("H@
M("`@/&MB9#YT<G5E/"]K8F0^(&]R(#QS86UP/C`\+W-A;7`^(&EF"B`@("`@
M*B`@("`\:V)D/F9A;'-E/"]K8F0^+@H@("`@("H@("`@4V]M92!R971U<FX@
M<W1R:6YG<SH@/'-A;7`^5%)513PO<V%M<#X@:68*("`@("`J("`@(#QK8F0^
M=')U93PO:V)D/B!O<B`\<V%M<#Y&04Q313PO<V%M<#X@:68*("`@("`J("`@
M(#QK8F0^9F%L<V4\+VMB9#XN"B`@("`@*B`@("!&:6YA;&QY(&]N92!R971U
M<FYS('-T<FEN9W,Z(#QS86UP/E0\+W-A;7`^(&EF"B`@("`@*B`@("`\:V)D
M/G1R=64\+VMB9#X@;W(@/'-A;7`^1CPO<V%M<#X@:68*("`@("`J("`@(#QK
M8F0^9F%L<V4\+VMB9#XN($AE<F4@:7,@82!L:7-T(&]F(&5A8V@@1$)-4RP*
M("`@("`J("`@('1H92!V86QU97,@<F5T=7)N960@86YD('1H92!S=6=G97-T
M960@8V]L=6UN('1Y<&4Z"B`@("`@*B`@("`\=6P^"B`@("`@*B`@("`@(#QL
M:3X*("`@("`J("`@("`@("`\:V)D/F1B87-E/"]K8F0^("T^(#QS86UP/E0O
M1CPO<V%M<#X*("`@("`J("`@("`@("`H/&MB9#Y,;V=I8V%L/"]K8F0^*0H@
M("`@("H@("`@("`\+VQI/@H@("`@("H@("`@("`\;&D^"B`@("`@*B`@("`@
M("`@/&MB9#YF8F%S93PO:V)D/B`M/B`\<V%M<#Y44E5%+T9!3%-%/"]S86UP
M/@H@("`@("H@("`@("`@("@\:V)D/D)/3TQ%04X\+VMB9#XI"B`@("`@*B`@
M("`@(#PO;&D^"B`@("`@*B`@("`@(#QL:3X*("`@("`J("`@("`@("`\:V)D
M/FEB87-E/"]K8F0^("T^(#QS86UP/C$O,#PO<V%M<#X*("`@("`J("`@("`@
M("`H/&MB9#Y334%,3$E.5#PO:V)D/BD@6S%="B`@("`@*B`@("`@(#PO;&D^
M"B`@("`@*B`@("`@(#QL:3X*("`@("`J("`@("`@("`\:V)D/FEF>#PO:V)D
M/B`M/B`\<V%M<#XQ+S`\+W-A;7`^"B`@("`@*B`@("`@("`@*#QK8F0^4TU!
M3$Q)3E0\+VMB9#XI(%LQ70H@("`@("H@("`@("`\+VQI/@H@("`@("H@("`@
M("`\;&D^"B`@("`@*B`@("`@("`@/&MB9#YM<W%L/"]K8F0^("T^(#QS86UP
M/C$O,#PO<V%M<#X*("`@("`J("`@("`@("`H/&MB9#Y)3E1%1T52/"]K8F0^
M*0H@("`@("H@("`@("`\+VQI/@H@("`@("H@("`@("`\;&D^"B`@("`@*B`@
M("`@("`@/&MB9#YM<W-Q;#PO:V)D/B`M/B`\<V%M<#XQ+S`\+W-A;7`^"B`@
M("`@*B`@("`@("`@*#QK8F0^0DE4/"]K8F0^*0H@("`@("H@("`@("`\+VQI
M/@H@("`@("H@("`@("`\;&D^"B`@("`@*B`@("`@("`@/&MB9#YM>7-Q;#PO
M:V)D/B`M/B`\<V%M<#XQ+S`\+W-A;7`^"B`@("`@*B`@("`@("`@*#QK8F0^
M5$E.64E.5"@Q*3PO:V)D/BD*("`@("`J("`@("`@/"]L:3X*("`@("`J("`@
M("`@/&QI/@H@("`@("H@("`@("`@(#QK8F0^;7ES<6QI/"]K8F0^("T^(#QS
M86UP/C$O,#PO<V%M<#X*("`@("`J("`@("`@("`H/&MB9#Y424Y924Y4*#$I
M/"]K8F0^*0H@("`@("H@("`@("`\+VQI/@H@("`@("H@("`@("`\;&D^"B`@
M("`@*B`@("`@("`@/&MB9#YO8VDX/"]K8F0^("T^(#QS86UP/C$O,#PO<V%M
M<#X*("`@("`J("`@("`@("`H/&MB9#Y.54U"15(H,2D\+VMB9#XI"B`@("`@
M*B`@("`@(#PO;&D^"B`@("`@*B`@("`@(#QL:3X*("`@("`J("`@("`@("`\
M:V)D/F]D8F,\+VMB9#X@+3X@/'-A;7`^,2\P/"]S86UP/@H@("`@("H@("`@
M("`@("@\:V)D/E--04Q,24Y4/"]K8F0^*2!;,5T*("`@("`J("`@("`@/"]L
M:3X*("`@("`J("`@("`@/&QI/@H@("`@("H@("`@("`@(#QK8F0^<&=S<6P\
M+VMB9#X@+3X@/'-A;7`^5%)512]&04Q313PO<V%M<#X*("`@("`J("`@("`@
M("`H/&MB9#Y"3T],14%./"]K8F0^*0H@("`@("H@("`@("`\+VQI/@H@("`@
M("H@("`@("`\;&D^"B`@("`@*B`@("`@("`@/&MB9#YS<6QI=&4\+VMB9#X@
M+3X@/'-A;7`^,2\P/"]S86UP/@H@("`@("H@("`@("`@("@\:V)D/DE.5$5'
M15(\+VMB9#XI"B`@("`@*B`@("`@(#PO;&D^"B`@("`@*B`@("`@(#QL:3X*
M("`@("`J("`@("`@("`\:V)D/G-Y8F%S93PO:V)D/B`M/B`\<V%M<#XQ+S`\
M+W-A;7`^"B`@("`@*B`@("`@("`@*#QK8F0^5$E.64E.5"@Q*3PO:V)D/BD*
M("`@("`J("`@("`@/"]L:3X*("`@("`J("`@(#PO=6P^"B`@("`@*B`@("!;
M,5T@06-C;VUM;V1A=&4@=&AE(&QO=V5S="!C;VUM;VX@9&5N;VUI;F%T;W(@
M8F5C875S92!N;W0@86QL"B`@("`@*B`@("!V97)S:6]N<R!O9B!H879E(#QK
M8F0^0D]/3$5!3CPO:V)D/BX*("`@("`J("`\+VQI/@H@("`@("H@(#QL:3X*
M("`@("`J("`@(&]T:&5R("AI;F-L=61I;F<@<W1R:6YG<R!A;F0@;G5M97)I
M8R!S=')I;F=S*2`M/@H@("`@("H@("`@=&AE(&1A=&$@=VET:"!S:6YG;&4@
M<75O=&5S(&5S8V%P960@8GD@<')E8V5E9&EN9PH@("`@("H@("`@<VEN9VQE
M('%U;W1E<RP@8F%C:W-L87-H97,@87)E(&5S8V%P960@8GD@<')E8V5E9&EN
M9PH@("`@("H@("`@8F%C:W-L87-H97,L('1H96X@=&AE('=H;VQE('-T<FEN
M9R!I<R!E;F-A<'-U;&%T960*("`@("`J("`@(&)E='=E96X@<VEN9VQE('%U
M;W1E<PH@("`@("H@(#PO;&D^"B`@("`@*B`\+W5L/@H@("`@("H*("`@("`J
M($!S964@1$)?8V]M;6]N.CIE<V-A<&53:6UP;&4H*0H@("`@("H@0'-I;F-E
M($UE=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C8N,`H@("`@("HO
M"B`@("!F=6YC=&EO;B!Q=6]T95-M87)T*"1I;BD*("`@('L*("`@("`@("!I
M9B`H:7-?:6YT*"1I;BD@?'P@:7-?9&]U8FQE*"1I;BDI('L*("`@("`@("`@
M("`@<F5T=7)N("1I;CL*("`@("`@("!](&5L<V5I9B`H:7-?8F]O;"@D:6XI
M*2!["B`@("`@("`@("`@(')E='5R;B`D:6X@/R`Q(#H@,#L*("`@("`@("!]
M(&5L<V5I9B`H:7-?;G5L;"@D:6XI*2!["B`@("`@("`@("`@(')E='5R;B`G
M3E5,3"<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("(G
M(B`N("1T:&ES+3YE<V-A<&53:6UP;&4H)&EN*2`N("(G(CL*("`@("`@("!]
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97-C87!E4VEM<&QE*"D*
M"B`@("`O*BH*("`@("`J($5S8V%P97,@82!S=')I;F<@86-C;W)D:6YG('1O
M('1H92!C=7)R96YT($1"35,G<R!S=&%N9&%R9',*("`@("`J"B`@("`@*B!)
M;B!344QI=&4L('1H:7,@;6%K97,@=&AI;F=S('-A9F4@9F]R(&EN<V5R=',O
M=7!D871E<RP@8G5T(&UA>0H@("`@("H@8V%U<V4@<')O8FQE;7,@=VAE;B!P
M97)F;W)M:6YG('1E>'0@8V]M<&%R:7-O;G,@86=A:6YS="!C;VQU;6YS"B`@
M("`@*B!C;VYT86EN:6YG(&)I;F%R>2!D871A+B!3964@=&AE"B`@("`@*B![
M0&QI;FL@:'1T<#HO+W!H<"YN970O<W%L:71E7V5S8V%P95]S=')I;F<@4$A0
M(&UA;G5A;'T@9F]R(&UO<F4@:6YF;RX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1S='(@('1H92!S=')I;F<@=&\@8F4@97-C87!E9`H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@97-C87!E9"!S=')I;F<*("`@
M("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<75O=&53;6%R="@I"B`@("`@
M*B!`<VEN8V4@365T:&]D(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-BXP
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&5S8V%P95-I;7!L92@D<W1R*0H@("`@
M>PH@("`@("`@(')E='5R;B!S=')?<F5P;&%C92@B)R(L("(G)R(L("1S='(I
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('!R;W9I9&5S*"D*"B`@
M("`O*BH*("`@("`J(%1E;&QS('=H971H97(@=&AE('!R97-E;G0@9')I=F5R
M('-U<'!O<G1S(&$@9VEV96X@9F5A='5R90H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&9E871U<F4@('1H92!F96%T=7)E('EO=2=R92!C=7)I;W5S
M(&%B;W5T"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("!W:&5T:&5R('1H
M:7,@9')I=F5R('-U<'!O<G1S("1F96%T=7)E"B`@("`@*B\*("`@(&9U;F-T
M:6]N('!R;W9I9&5S*"1F96%T=7)E*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^9F5A='5R97-;)&9E871U<F5=.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[('-E=$9E=&-H36]D92@I"@H@("`@+RHJ"B`@("`@*B!3971S
M('1H92!F971C:"!M;V1E('1H870@<VAO=6QD(&)E('5S960@8GD@9&5F875L
M="!F;W(@<75E<GD@<F5S=6QT<PH@("`@("H*("`@("`J($!P87)A;2!I;G1E
M9V5R("1F971C:&UO9&4@("`@1$)?1D540TA-3T1%7T]21$52140L($1"7T9%
M5$-(34]$15]!4U-/0PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@;W(@1$)?1D540TA-3T1%7T]"2D5#5`H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;V)J96-T7V-L87-S("!T:&4@8VQA<W,@;F%M92!O9B!T:&4@;V)J
M96-T('1O(&)E(')E='5R;F5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!B>2!T:&4@9F5T8V@@;65T:&]D<R!W:&5N('1H90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1$)?1D540TA-3T1%
M7T]"2D5#5"!M;V1E(&ES('-E;&5C=&5D+@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@268@;F\@8VQA<W,@:7,@<W!E8VEF:65D(&)Y
M(&1E9F%U;'0@82!C87-T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!T;R!O8FIE8W0@9G)O;2!T:&4@87-S;V,@87)R87D@<F]W('=I
M;&P@8F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1O
M;F4N("!4:&5R92!I<R!A;'-O('1H92!P;W-I8FEL:71Y('1O('5S90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@86YD(&5X=&5N9"!T
M:&4@)T1"7W)O=R<@8VQA<W,N"B`@("`@*@H@("`@("H@0'-E92!$0E]&151#
M2$U/1$5?3U)$15)%1"P@1$)?1D540TA-3T1%7T%34T]#+"!$0E]&151#2$U/
M1$5?3T)*14-4"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$9E=&-H36]D92@D
M9F5T8VAM;V1E+"`D;V)J96-T7V-L87-S(#T@)W-T9$-L87-S)RD*("`@('L*
M("`@("`@("!S=VET8V@@*"1F971C:&UO9&4I('L*("`@("`@("`@("`@8V%S
M92!$0E]&151#2$U/1$5?3T)*14-4.@H@("`@("`@("`@("`@("`@)'1H:7,M
M/F9E=&-H;6]D95]O8FIE8W1?8VQA<W,@/2`D;V)J96-T7V-L87-S.PH@("`@
M("`@("`@("!C87-E($1"7T9%5$-(34]$15]/4D1%4D5$.@H@("`@("`@("`@
M("!C87-E($1"7T9%5$-(34]$15]!4U-/0SH*("`@("`@("`@("`@("`@("1T
M:&ES+3YF971C:&UO9&4@/2`D9F5T8VAM;V1E.PH@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)VEN=F%L:60@9F5T8VAM;V1E(&UO
M9&4G*3L*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M<V5T3W!T:6]N*"D*"B`@("`O*BH*("`@("`J(%-E=',@<G5N+71I;64@8V]N
M9FEG=7)A=&EO;B!O<'1I;VYS(&9O<B!014%2($1""B`@("`@*@H@("`@("H@
M3W!T:6]N<RP@=&AE:7(@9&%T82!T>7!E<RP@9&5F875L="!V86QU97,@86YD
M(&1E<V-R:7!T:6]N.@H@("`@("H@/'5L/@H@("`@("H@/&QI/@H@("`@("H@
M/'9A<CYA=71O9G)E93PO=F%R/B`\:V)D/F)O;VQE86X\+VMB9#X@/2`\<V%M
M<#YF86QS93PO<V%M<#X*("`@("`J("`@("`@/&)R("\^<VAO=6QD(')E<W5L
M=',@8F4@9G)E960@875T;VUA=&EC86QL>2!W:&5N('1H97)E(&%R92!N;PH@
M("`@("H@("`@("`@("`@("!M;W)E(')O=W,_"B`@("`@*B`\+VQI/CQL:3X*
M("`@("`J(#QV87(^<F5S=6QT7V)U9F9E<FEN9SPO=F%R/B`\:V)D/FEN=&5G
M97(\+VMB9#X@/2`\<V%M<#XU,#`\+W-A;7`^"B`@("`@*B`@("`@(#QB<B`O
M/FAO=R!M86YY(')O=W,@;V8@=&AE(')E<W5L="!S970@<VAO=6QD(&)E(&)U
M9F9E<F5D/PH@("`@("H@("`@("`\8G(@+SY);B!M>7-Q;#H@;7ES<6Q?=6YB
M=69F97)E9%]Q=65R>2@I(&ES('5S960@:6YS=&5A9"!O9@H@("`@("H@("`@
M("`@("`@("!M>7-Q;%]Q=65R>2@I(&EF('1H:7,@=F%L=64@:7,@,"X@("A2
M96QE87-E(#$N-RXP*0H@("`@("H@("`@("`\8G(@+SY);B!O8VDX.B!T:&ES
M('9A;'5E(&ES('!A<W-E9"!T;R!O8VES971P<F5F971C:"@I+@H@("`@("H@
M("`@("`@("`@("`H4F5L96%S92`Q+C<N,"D*("`@("`J(#PO;&D^/&QI/@H@
M("`@("H@/'9A<CYD96)U9SPO=F%R/B`\:V)D/FEN=&5G97(\+VMB9#X@/2`\
M<V%M<#XP/"]S86UP/@H@("`@("H@("`@("`\8G(@+SYD96)U9R!L979E;`H@
M("`@("H@/"]L:3X\;&D^"B`@("`@*B`\=F%R/G!E<G-I<W1E;G0\+W9A<CX@
M/&MB9#YB;V]L96%N/"]K8F0^(#T@/'-A;7`^9F%L<V4\+W-A;7`^"B`@("`@
M*B`@("`@(#QB<B`O/G-H;W5L9"!T:&4@8V]N;F5C=&EO;B!B92!P97)S:7-T
M96YT/PH@("`@("H@/"]L:3X\;&D^"B`@("`@*B`\=F%R/G!O<G1A8FEL:71Y
M/"]V87(^(#QK8F0^:6YT96=E<CPO:V)D/B`](#QS86UP/D1"7U!/4E1!0DE,
M25197TY/3D4\+W-A;7`^"B`@("`@*B`@("`@(#QB<B`O/G!O<G1A8FEL:71Y
M(&UO9&4@8V]N<W1A;G0@*'-E92!B96QO=RD*("`@("`J(#PO;&D^/&QI/@H@
M("`@("H@/'9A<CYS97%N86UE7V9O<FUA=#PO=F%R/B`\:V)D/G-T<FEN9SPO
M:V)D/B`](#QS86UP/B5S7W-E<3PO<V%M<#X*("`@("`J("`@("`@/&)R("\^
M=&AE('-P<FEN=&8H*2!F;W)M870@<W1R:6YG('5S960@;VX@<V5Q=65N8V4@
M;F%M97,N("!4:&ES"B`@("`@*B`@("`@("`@("`@(&9O<FUA="!I<R!A<'!L
M:65D('1O('-E<75E;F-E(&YA;65S('!A<W-E9"!T;PH@("`@("H@("`@("`@
M("`@("!C<F5A=&5397%U96YC92@I+"!N97AT240H*2!A;F0@9')O<%-E<75E
M;F-E*"DN"B`@("`@*B`\+VQI/CQL:3X*("`@("`J(#QV87(^<W-L/"]V87(^
M(#QK8F0^8F]O;&5A;CPO:V)D/B`](#QS86UP/F9A;'-E/"]S86UP/@H@("`@
M("H@("`@("`\8G(@+SYU<V4@<W-L('1O(&-O;FYE8W0_"B`@("`@*B`\+VQI
M/@H@("`@("H@/"]U;#X*("`@("`J"B`@("`@*B`M+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H@("`@("H*("`@("`J(%!/4E1!
M0DE,2519($U/1$53"B`@("`@*@H@("`@("H@5&AE<V4@;6]D97,@87)E(&)I
M='=I<V5D+"!S;R!T:&5Y(&-A;B!B92!C;VUB:6YE9"!U<VEN9R`\:V)D/GP\
M+VMB9#X*("`@("`J(&%N9"!R96UO=F5D('5S:6YG(#QK8F0^7CPO:V)D/BX@
M(%-E92!T:&4@97AA;7!L97,@<V5C=&EO;B!B96QO=R!O;B!H;W<*("`@("`J
M('1O(&1O('1H:7,N"B`@("`@*@H@("`@("H@/'-A;7`^1$)?4$]25$%"24Q)
M5%E?3D].13PO<V%M<#X*("`@("`J('1U<FX@;V9F(&%L;"!P;W)T86)I;&ET
M>2!F96%T=7)E<PH@("`@("H*("`@("`J(%1H:7,@;6]D92!G971S(&%U=&]M
M871I8V%L;'D@='5R;F5D(&]N(&EF('1H92!D97!R96-A=&5D"B`@("`@*B`\
M=F%R/F]P=&EM:7IE/"]V87(^(&]P=&EO;B!G971S('-E="!T;R`\<V%M<#YP
M97)F;W)M86YC93PO<V%M<#XN"B`@("`@*@H@("`@("H*("`@("`J(#QS86UP
M/D1"7U!/4E1!0DE,25197TQ/5T520T%313PO<V%M<#X*("`@("`J(&-O;G9E
M<G0@;F%M97,@;V8@=&%B;&5S(&%N9"!F:65L9',@=&\@;&]W97(@8V%S92!W
M:&5N('5S:6YG"B`@("`@*B`\:V)D/F=E="HH*3PO:V)D/BP@/&MB9#YF971C
M:"HH*3PO:V)D/B!A;F0@/&MB9#YT86)L94EN9F\H*3PO:V)D/@H@("`@("H*
M("`@("`J(%1H:7,@;6]D92!G971S(&%U=&]M871I8V%L;'D@='5R;F5D(&]N
M(&EN('1H92!F;VQL;W=I;F<@9&%T86)A<V5S"B`@("`@*B!I9B!T:&4@9&5P
M<F5C871E9"!O<'1I;VX@/'9A<CYO<'1I;6EZ93PO=F%R/B!G971S('-E="!T
M;PH@("`@("H@/'-A;7`^<&]R=&%B:6QI='D\+W-A;7`^.@H@("`@("H@*R!O
M8VDX"B`@("`@*@H@("`@("H*("`@("`J(#QS86UP/D1"7U!/4E1!0DE,2519
M7U)44DE-/"]S86UP/@H@("`@("H@<FEG:'0@=')I;2!T:&4@9&%T82!O=71P
M=70@8GD@/&MB9#YG970J*"D\+VMB9#X@/&MB9#YF971C:"HH*3PO:V)D/@H@
M("`@("H*("`@("`J"B`@("`@*B`\<V%M<#Y$0E]03U)404))3$E465]$14Q%
M5$5?0T]53E0\+W-A;7`^"B`@("`@*B!F;W)C92!R97!O<G1I;F<@=&AE(&YU
M;6)E<B!O9B!R;W=S(&1E;&5T960*("`@("`J"B`@("`@*B!3;VUE($1"35,G
M<R!D;VXG="!C;W5N="!T:&4@;G5M8F5R(&]F(')O=W,@9&5L971E9"!W:&5N
M('!E<F9O<FUI;F<*("`@("`J('-I;7!L92`\:V)D/D1%3$5412!&4D]-('1A
M8FQE;F%M93PO:V)D/B!Q=65R:65S+B`@5&AI<R!P;W)T86)I;&ET>0H@("`@
M("H@;6]D92!T<FEC:W,@<W5C:"!$0DU3)W,@:6YT;R!T96QL:6YG('1H92!C
M;W5N="!B>2!A9&1I;F<*("`@("`J(#QS86UP/E=(15)%(#$],3PO<V%M<#X@
M=&\@=&AE(&5N9"!O9B`\:V)D/D1%3$5413PO:V)D/B!Q=65R:65S+@H@("`@
M("H*("`@("`J(%1H:7,@;6]D92!G971S(&%U=&]M871I8V%L;'D@='5R;F5D
M(&]N(&EN('1H92!F;VQL;W=I;F<@9&%T86)A<V5S"B`@("`@*B!I9B!T:&4@
M9&5P<F5C871E9"!O<'1I;VX@/'9A<CYO<'1I;6EZ93PO=F%R/B!G971S('-E
M="!T;PH@("`@("H@/'-A;7`^<&]R=&%B:6QI='D\+W-A;7`^.@H@("`@("H@
M*R!F8G-Q;`H@("`@("H@*R!M>7-Q;`H@("`@("H@*R!M>7-Q;&D*("`@("`J
M("L@<W%L:71E"B`@("`@*@H@("`@("H*("`@("`J(#QS86UP/D1"7U!/4E1!
M0DE,25197TY535)/5U,\+W-A;7`^"B`@("`@*B!E;F%B;&4@:&%C:R!T:&%T
M(&UA:V5S(#QK8F0^;G5M4F]W<R@I/"]K8F0^('=O<FL@:6X@3W)A8VQE"B`@
M("`@*@H@("`@("H@5&AI<R!M;V1E(&=E=',@875T;VUA=&EC86QL>2!T=7)N
M960@;VX@:6X@=&AE(&9O;&QO=VEN9R!D871A8F%S97,*("`@("`J(&EF('1H
M92!D97!R96-A=&5D(&]P=&EO;B`\=F%R/F]P=&EM:7IE/"]V87(^(&=E=',@
M<V5T('1O"B`@("`@*B`\<V%M<#YP;W)T86)I;&ET>3PO<V%M<#XZ"B`@("`@
M*B`K(&]C:3@*("`@("`J"B`@("`@*@H@("`@("H@/'-A;7`^1$)?4$]25$%"
M24Q)5%E?15)23U)3/"]S86UP/@H@("`@("H@;6%K97,@8V5R=&%I;B!E<G)O
M<B!M97-S86=E<R!I;B!C97)T86EN(&1R:79E<G,@8V]M<&%T:6)L90H@("`@
M("H@=VET:"!T:&]S92!F<F]M(&]T:&5R($1"35,G<PH@("`@("H*("`@("`J
M("L@;7ES<6PL(&UY<W%L:3H@(&-H86YG92!U;FEQ=64O<')I;6%R>2!K97D@
M8V]N<W1R86EN=',*("`@("`J("`@1$)?15)23U)?04Q214%$65]%6$E35%,@
M+3X@1$)?15)23U)?0T].4U1204E.5`H@("`@("H*("`@("`J("L@;V1B8RAA
M8V-E<W,I.B`@35,G<R!/1$)#(&1R:79E<B!R97!O<G1S("=N;R!S=6-H(&9I
M96QD)R!A<R!C;V1E"B`@("`@*B`@(#`W,#`Q+"!W:&EC:"!M96%N<R`G=&]O
M(&9E=R!P87)A;65T97)S+B<@(%=H96X@=&AI<R!O<'1I;VX@:7,@;VX*("`@
M("`J("`@=&AA="!C;V1E(&=E=',@;6%P<&5D('1O($1"7T524D]27TY/4U5#
M2$9)14Q$+@H@("`@("H@("!$0E]%4E)/4E]-25--051#2"`M/B!$0E]%4E)/
M4E].3U-50TA&245,1`H@("`@("H*("`@("`J(#QS86UP/D1"7U!/4E1!0DE,
M25197TY53$Q?5$]?14U05%D\+W-A;7`^"B`@("`@*B!C;VYV97)T(&YU;&P@
M=F%L=65S('1O(&5M<'1Y('-T<FEN9W,@:6X@9&%T82!O=71P=70@8GD@9V5T
M*B@I(&%N9`H@("`@("H@9F5T8V@J*"DN("!.965D960@8F5C875S92!/<F%C
M;&4@8V]N<VED97)S(&5M<'1Y('-T<FEN9W,@=&\@8F4@;G5L;"P*("`@("`J
M('=H:6QE(&UO<W0@;W1H97(@1$)-4R=S(&MN;W<@=&AE(&1I9F9E<F5N8V4@
M8F5T=V5E;B!E;7!T>2!A;F0@;G5L;"X*("`@("`J"B`@("`@*@H@("`@("H@
M/'-A;7`^1$)?4$]25$%"24Q)5%E?04Q,/"]S86UP/@H@("`@("H@='5R;B!O
M;B!A;&P@<&]R=&%B:6QI='D@9F5A='5R97,*("`@("`J"B`@("`@*B`M+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H@("`@("H*
M("`@("`J($5X86UP;&4@,2X@4VEM<&QE('-E=$]P=&EO;B@I(&5X86UP;&4*
M("`@("`J(#QC;V1E/@H@("`@("H@)&1B+3YS971/<'1I;VXH)V%U=&]F<F5E
M)RP@=')U92D["B`@("`@*B`\+V-O9&4^"B`@("`@*@H@("`@("H@17AA;7!L
M92`R+B!0;W)T86)I;&ET>2!F;W(@;&]W97)C87-I;F<@86YD('1R:6UM:6YG
M"B`@("`@*B`\8V]D93X*("`@("`J("1D8BT^<V5T3W!T:6]N*"=P;W)T86)I
M;&ET>2<L"B`@("`@*B`@("`@("`@("`@("`@("`@1$)?4$]25$%"24Q)5%E?
M3$]715)#05-%('P@1$)?4$]25$%"24Q)5%E?4E1224TI.PH@("`@("H@/"]C
M;V1E/@H@("`@("H*("`@("`J($5X86UP;&4@,RX@06QL('!O<G1A8FEL:71Y
M(&]P=&EO;G,@97AC97!T('1R:6UM:6YG"B`@("`@*B`\8V]D93X*("`@("`J
M("1D8BT^<V5T3W!T:6]N*"=P;W)T86)I;&ET>2<L"B`@("`@*B`@("`@("`@
M("`@("`@("`@1$)?4$]25$%"24Q)5%E?04Q,(%X@1$)?4$]25$%"24Q)5%E?
M4E1224TI.PH@("`@("H@/"]C;V1E/@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&]P=&EO;B!O<'1I;VX@;F%M90H@("`@("H@0'!A<F%M(&UI>&5D
M("`D=F%L=64@=F%L=64@9F]R('1H92!O<'1I;VX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J
M96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ
M.B1O<'1I;VYS"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$]P=&EO;B@D;W!T
M:6]N+"`D=F%L=64I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YO
M<'1I;VYS6R1O<'1I;VY=*2D@>PH@("`@("`@("`@("`D=&AI<RT^;W!T:6]N
M<ULD;W!T:6]N72`]("1V86QU93L*"B`@("`@("`@("`@("\J"B`@("`@("`@
M("`@("`J($)A8VMW87)D<R!C;VUP871I8FEL:71Y(&-H96-K(&9O<B!T:&4@
M9&5P<F5C871E9"`G;W!T:6UI>F4G"B`@("`@("`@("`@("`J(&]P=&EO;BX@
M($1O;F4@:&5R92!I;B!C87-E('-E='1I;F=S(&-H86YG92!A9G1E<B!C;VYN
M96-T:6YG+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@:68@*"1O<'1I
M;VX@/3T@)V]P=&EM:7IE)RD@>PH@("`@("`@("`@("`@("`@:68@*"1V86QU
M92`]/2`G<&]R=&%B:6QI='DG*2!["B`@("`@("`@("`@("`@("`@("`@<W=I
M=&-H("@D=&AI<RT^<&AP='EP92D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!C87-E("=O8VDX)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==(#T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@1$)?4$]25$%"24Q)5%E?3$]715)#05-%
M('P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1$)?4$]2
M5$%"24Q)5%E?3E5-4D]74SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E("=F8G-Q;"<Z
M"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)VUY<W%L)SH*("`@("`@
M("`@("`@("`@("`@("`@("`@8V%S92`G;7ES<6QI)SH*("`@("`@("`@("`@
M("`@("`@("`@("`@8V%S92`G<W%L:71E)SH*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==(#T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1$)?4$]25$%"24Q)
M5%E?1$5,151%7T-/54Y4.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;W!T:6]N<ULG
M<&]R=&%B:6QI='DG72`]($1"7U!/4E1!0DE,25197TY/3D4["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(')E='5R;B!$
M0E]/2SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*")U;FMN;W=N(&]P=&EO;B`D;W!T:6]N(BD["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@9V5T3W!T:6]N*"D*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE('9A;'5E(&]F(&%N(&]P=&EO;@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&]P=&EO;B`@=&AE(&]P=&EO;B!N86UE('EO=2=R92!C
M=7)I;W5S(&%B;W5T"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@=&AE
M(&]P=&EO;B=S('9A;'5E"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$]P=&EO
M;B@D;W!T:6]N*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^;W!T
M:6]N<ULD;W!T:6]N72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YO
M<'1I;VYS6R1O<'1I;VY=.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H(G5N:VYO=VX@;W!T:6]N("1O<'1I;VXB*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!P<F5P87)E*"D*"B`@("`O*BH*
M("`@("`J(%!R97!A<F5S(&$@<75E<GD@9F]R(&UU;'1I<&QE(&5X96-U=&EO
M;B!W:71H(&5X96-U=&4H*0H@("`@("H*("`@("`J($-R96%T97,@82!Q=65R
M>2!T:&%T(&-A;B!B92!R=6X@;75L=&EP;&4@=&EM97,N("!%86-H('1I;64@
M:70@:7,@<G5N+`H@("`@("H@=&AE('!L86-E:&]L9&5R<RP@:68@86YY+"!W
M:6QL(&)E(')E<&QA8V5D(&)Y('1H92!C;VYT96YT<R!O9@H@("`@("H@97AE
M8W5T92@I)W,@)&1A=&$@87)G=6UE;G0N"B`@("`@*@H@("`@("H@5&AR964@
M='EP97,@;V8@<&QA8V5H;VQD97)S(&-A;B!B92!U<V5D.@H@("`@("H@("`K
M(#QK8F0^/SPO:V)D/B`@<V-A;&%R('9A;'5E("AI+F4N('-T<FEN9W,L(&EN
M=&5G97)S*2X@(%1H92!S>7-T96T*("`@("`J("`@("`@("`@("`@("`@("`@
M('=I;&P@875T;VUA=&EC86QL>2!Q=6]T92!A;F0@97-C87!E('1H92!D871A
M+@H@("`@("H@("`K(#QK8F0^(3PO:V)D/B`@=F%L=64@:7,@:6YS97)T960@
M)V%S(&ES)PH@("`@("H@("`K(#QK8F0^)CPO:V)D/B`@<F5Q=6ER97,@82!F
M:6QE(&YA;64N("!4:&4@9FEL92=S(&-O;G1E;G1S(&=E=`H@("`@("H@("`@
M("`@("`@("`@("`@("`@:6YS97)T960@:6YT;R!T:&4@<75E<GD@*&DN92X@
M<V%V:6YG(&)I;F%R>0H@("`@("H@("`@("`@("`@("`@("`@("`@9&%T82!I
M;B!A(&1B*0H@("`@("H*("`@("`J($5X86UP;&4@,2X*("`@("`J(#QC;V1E
M/@H@("`@("H@)'-T:"`]("1D8BT^<')E<&%R92@G24Y315)4($E.5$\@=&)L
M("AA+"!B+"!C*2!604Q515,@*#\L("$L("8I)RD["B`@("`@*B`D9&%T82`]
M(&%R<F%Y*`H@("`@("H@("`@(")*;VAN)W,@=&5X="(L"B`@("`@*B`@("`@
M(B=I="<G<R!G;V]D)R(L"B`@("`@*B`@("`@)V9I;&5N86UE+G1X="<*("`@
M("`J("D["B`@("`@*B`D<F5S(#T@)&1B+3YE>&5C=71E*"1S=&@L("1D871A
M*3L*("`@("`J(#PO8V]D93X*("`@("`J"B`@("`@*B!5<V4@8F%C:W-L87-H
M97,@=&\@97-C87!E('!L86-E:&]L9&5R(&-H87)A8W1E<G,@:68@>6]U(&1O
M;B=T('=A;G0*("`@("`J('1H96T@=&\@8F4@:6YT97)P<F5T960@87,@<&QA
M8V5H;VQD97)S.@H@("`@("H@/'!R93X*("`@("`J("`@(")54$1!5$4@9F]O
M(%-%5"!C;VP]/R!72$5212!C;VP])V]V97(@7"8@=6YD97(G(@H@("`@("H@
M/"]P<F4^"B`@("`@*@H@("`@("H@5VET:"!S;VUE(&1A=&%B87-E(&)A8VME
M;F1S+"!T:&ES(&ES(&5M=6QA=&5D+@H@("`@("H*("`@("`J('M`:6YT97)N
M86P@:6)A<V4@86YD(&]C:3@@:&%V92!T:&5I<B!O=VX@<')E<&%R92@I(&UE
M=&AO9',N?7T*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1Q=65R>2`@
M=&AE('%U97)Y('1O(&)E('!R97!A<F5D"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@1$(@<W1A=&5M96YT(')E<V]U<F-E(&]N('-U8V-E<W,N($$@
M1$)?17)R;W(@;V)J96-T"B`@("`@*B`@("`@("`@("`@("`@("`@;VX@9F%I
M;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ97AE8W5T92@I
M"B`@("`@*B\*("`@(&9U;F-T:6]N('!R97!A<F4H)'%U97)Y*0H@("`@>PH@
M("`@("`@("1T;VME;G,@("`]('!R96=?<W!L:70H)R\H*#\\(5Q<7"E;)C\A
M72DO)RP@)'%U97)Y+"`M,2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(%!214=?4U!,251?1$5,24U?0T%05%5212D["B`@("`@("`@)'1O:V5N
M("`@("`](#`["B`@("`@("`@)'1Y<&5S("`@("`](&%R<F%Y*"D["B`@("`@
M("`@)&YE=W1O:V5N<R`](&%R<F%Y*"D["@H@("`@("`@(&9O<F5A8V@@*"1T
M;VME;G,@87,@)'9A;"D@>PH@("`@("`@("`@("!S=VET8V@@*"1V86PI('L*
M("`@("`@("`@("`@("`@(&-A<V4@)S\G.@H@("`@("`@("`@("`@("`@("`@
M("1T>7!E<ULD=&]K96XK*UT@/2!$0E]005)!35]30T%,05(["B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E("<F)SH*
M("`@("`@("`@("`@("`@("`@("`D='EP97-;)'1O:V5N*RM=(#T@1$)?4$%2
M04U?3U!!455%.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@8V%S92`G(2<Z"B`@("`@("`@("`@("`@("`@("`@)'1Y<&5S
M6R1T;VME;BLK72`]($1"7U!!4D%-7TU)4T,["B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@
M("`@("`@("`@("1N97=T;VME;G-;72`]('!R96=?<F5P;&%C92@G+UQ<7"A;
M)C\A72DO)RP@(EQ<,2(L("1V86PI.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("`D=&AI<RT^<')E<&%R95]T;VME;G-;72`]("8D;F5W=&]K
M96YS.PH@("`@("`@(&5N9"@D=&AI<RT^<')E<&%R95]T;VME;G,I.PH*("`@
M("`@("`D:R`](&ME>2@D=&AI<RT^<')E<&%R95]T;VME;G,I.PH@("`@("`@
M("1T:&ES+3YP<F5P87)E7W1Y<&5S6R1K72`]("1T>7!E<SL*("`@("`@("`D
M=&AI<RT^<')E<&%R961?<75E<FEE<ULD:UT@/2!I;7!L;V1E*"<@)RP@)&YE
M=W1O:V5N<RD["@H@("`@("`@(')E='5R;B`D:SL*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!A=71O4')E<&%R92@I"@H@("`@+RHJ"B`@("`@*B!!
M=71O;6%T:6-A;'D@9V5N97)A=&5S(&%N(&EN<V5R="!O<B!U<&1A=&4@<75E
M<GD@86YD('!A<W,@:70@=&\@<')E<&%R92@I"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=&%B;&4@("`@("`@("!T:&4@=&%B;&4@;F%M90H@("`@
M("H@0'!A<F%M(&%R<F%Y("`D=&%B;&5?9FEE;&1S("!T:&4@87)R87D@;V8@
M9FEE;&0@;F%M97,*("`@("`J($!P87)A;2!I;G0@("`@)&UO9&4@("`@("`@
M("`@82!T>7!E(&]F('%U97)Y('1O(&UA:V4Z"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!$0E]!551/455%4EE?24Y315)4(&]R($1"
M7T%55$]1545265]54$1!5$4*("`@("`J($!P87)A;2!S=')I;F<@)'=H97)E
M("`@("`@("`@9F]R('5P9&%T92!Q=65R:65S.B!T:&4@5TA%4D4@8VQA=7-E
M('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<'!E
M;F0@=&\@=&AE(%-13"!S=&%T96UE;G0N("!$;VXG=`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:6YC;'5D92!T:&4@(E=(15)%(B!K
M97EW;W)D+@H@("`@("H*("`@("`J($!R971U<FX@<F5S;W5R8V4@('1H92!Q
M=65R>2!H86YD;&4*("`@("`J"B`@("`@*B!`=7-E<R!$0E]C;VUM;VXZ.G!R
M97!A<F4H*2P@1$)?8V]M;6]N.CIB=6EL9$UA;FEP4U%,*"D*("`@("`J+PH@
M("`@9G5N8W1I;VX@875T;U!R97!A<F4H)'1A8FQE+"`D=&%B;&5?9FEE;&1S
M+"`D;6]D92`]($1"7T%55$]1545265])3E-%4E0L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`D=VAE<F4@/2!F86QS92D*("`@('L*("`@("`@("`D<75E
M<GD@/2`D=&AI<RT^8G5I;&1-86YI<%-13"@D=&%B;&4L("1T86)L95]F:65L
M9',L("1M;V1E+"`D=VAE<F4I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D
M<75E<GDI*2!["B`@("`@("`@("`@(')E='5R;B`D<75E<GD["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D=&AI<RT^<')E<&%R92@D<75E<GDI.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&%U=&]%>&5C=71E*"D*"B`@("`O
M*BH*("`@("`J($%U=&]M871I8V%L>2!G96YE<F%T97,@86X@:6YS97)T(&]R
M('5P9&%T92!Q=65R>2!A;F0@8V%L;"!P<F5P87)E*"D*("`@("`J(&%N9"!E
M>&5C=71E*"D@=VET:"!I=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'1A8FQE("`@("`@("`@=&AE('1A8FQE(&YA;64*("`@("`J($!P87)A;2!A
M<G)A>2`@)&9I96QD<U]V86QU97,@=&AE(&%S<V]C:6%T:79E(&%R<F%Y('=H
M97)E("1K97D@:7,@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@9FEE;&0@;F%M92!A;F0@)'9A;'5E(&ET<R!V86QU90H@("`@("H@
M0'!A<F%M(&EN="`@("`D;6]D92`@("`@("`@("!A('1Y<&4@;V8@<75E<GD@
M=&\@;6%K93H*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($1"7T%55$]1545265])3E-%4E0@;W(@1$)?05543U%515)97U501$%410H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=VAE<F4@("`@("`@("!F;W(@=7!D871E
M('%U97)I97,Z('1H92!72$5212!C;&%U<V4@=&\*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%P<&5N9"!T;R!T:&4@4U%,('-T871E
M;65N="X@($1O;B=T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I;F-L=61E('1H92`B5TA%4D4B(&ME>7=O<F0N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@82!N97<@1$)?<F5S=6QT(&]B:F5C="!F;W(@
M<W5C8V5S<V9U;"!314Q%0U0@<75E<FEE<PH@("`@("H@("`@("`@("`@("`@
M("`@(&]R($1"7T]+(&9O<B!S=6-C97-S=6P@9&%T82!M86YI<'5L871I;VX@
M<75E<FEE<RX*("`@("`J("`@("`@("`@("`@("`@("!!($1"7T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!U<V5S($1"7V-O;6UO
M;CHZ875T;U!R97!A<F4H*2P@1$)?8V]M;6]N.CIE>&5C=71E*"D*("`@("`J
M+PH@("`@9G5N8W1I;VX@875T;T5X96-U=&4H)'1A8FQE+"`D9FEE;&1S7W9A
M;'5E<RP@)&UO9&4@/2!$0E]!551/455%4EE?24Y315)4+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@)'=H97)E(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M)'-T:"`]("1T:&ES+3YA=71O4')E<&%R92@D=&%B;&4L(&%R<F%Y7VME>7,H
M)&9I96QD<U]V86QU97,I+"`D;6]D92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1W:&5R92D["B`@("`@("`@:68@*$1".CII<T5R<F]R
M*"1S=&@I*2!["B`@("`@("`@("`@(')E='5R;B`D<W1H.PH@("`@("`@('T*
M("`@("`@("`D<F5T(#TF("1T:&ES+3YE>&5C=71E*"1S=&@L(&%R<F%Y7W9A
M;'5E<R@D9FEE;&1S7W9A;'5E<RDI.PH@("`@("`@("1T:&ES+3YF<F5E4')E
M<&%R960H)'-T:"D["B`@("`@("`@<F5T=7)N("1R970["@H@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&)U:6QD36%N:7!344PH*0H*("`@("\J*@H@
M("`@("H@4')O9'5C97,@86X@4U%,('%U97)Y('-T<FEN9R!F;W(@875T;U!R
M97!A<F4H*0H@("`@("H*("`@("`J($5X86UP;&4Z"B`@("`@*B`\<')E/@H@
M("`@("H@8G5I;&1-86YI<%-13"@G=&%B;&5?<W%L)RP@87)R87DH)V9I96QD
M,2<L("=F:65L9#(G+"`G9FEE;&0S)RDL"B`@("`@*B`@("`@("`@("`@("`@
M($1"7T%55$]1545265])3E-%4E0I.PH@("`@("H@/"]P<F4^"B`@("`@*@H@
M("`@("H@5&AA="!R971U<FYS"B`@("`@*B`\<V%M<#X*("`@("`J($E.4T52
M5"!)3E1/('1A8FQE7W-Q;"`H9FEE;&0Q+&9I96QD,BQF:65L9#,I(%9!3%5%
M4R`H/RP_+#\I"B`@("`@*B`\+W-A;7`^"B`@("`@*@H@("`@("H@3D]415,Z
M"B`@("`@*B`@("T@5&AI<R!B96QO;F=S(&UO<F4@=&\@82!344P@0G5I;&1E
M<B!C;&%S<RP@8G5T('1H:7,@:7,@82!S:6UP;&4*("`@("`J("`@("!F86-I
M;&ET>2X*("`@("`J("`@+2!"92!C87)E9G5L;"$@268@>6]U(&1O;B=T(&=I
M=F4@82`D=VAE<F4@<&%R86T@=VET:"!A;B!54$1!5$4*("`@("`J("`@("!Q
M=65R>2P@86QL('1H92!R96-O<F1S(&]F('1H92!T86)L92!W:6QL(&)E('5P
M9&%T960A"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&%B;&4@("`@
M("`@("!T:&4@=&%B;&4@;F%M90H@("`@("H@0'!A<F%M(&%R<F%Y("`D=&%B
M;&5?9FEE;&1S("!T:&4@87)R87D@;V8@9FEE;&0@;F%M97,*("`@("`J($!P
M87)A;2!I;G0@("`@)&UO9&4@("`@("`@("`@82!T>7!E(&]F('%U97)Y('1O
M(&UA:V4Z"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$
M0E]!551/455%4EE?24Y315)4(&]R($1"7T%55$]1545265]54$1!5$4*("`@
M("`J($!P87)A;2!S=')I;F<@)'=H97)E("`@("`@("`@9F]R('5P9&%T92!Q
M=65R:65S.B!T:&4@5TA%4D4@8VQA=7-E('1O"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<'!E;F0@=&\@=&AE(%-13"!S=&%T96UE
M;G0N("!$;VXG=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:6YC;'5D92!T:&4@(E=(15)%(B!K97EW;W)D+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!T:&4@<W%L('%U97)Y(&9O<B!A=71O4')E<&%R
M92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&)U:6QD36%N:7!344PH)'1A8FQE
M+"`D=&%B;&5?9FEE;&1S+"`D;6]D92P@)'=H97)E(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@:68@*&-O=6YT*"1T86)L95]F:65L9',I(#T](#`I('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27TY%
M141?34]215]$051!*3L*("`@("`@("!]"B`@("`@("`@)&9I<G-T(#T@=')U
M93L*("`@("`@("!S=VET8V@@*"1M;V1E*2!["B`@("`@("`@("`@(&-A<V4@
M1$)?05543U%515)97TE.4T525#H*("`@("`@("`@("`@("`@("1V86QU97,@
M/2`G)SL*("`@("`@("`@("`@("`@("1N86UE<R`]("<G.PH@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)'1A8FQE7V9I96QD<R!A<R`D=F%L=64I('L*("`@
M("`@("`@("`@("`@("`@("!I9B`H)&9I<G-T*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1F:7)S="`](&9A;'-E.PH@("`@("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1N86UE<R`N/2`G
M+"<["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU97,@+CT@)RPG.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D;F%M
M97,@+CT@)'9A;'5E.PH@("`@("`@("`@("`@("`@("`@("1V86QU97,@+CT@
M)S\G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@<F5T=7)N
M("))3E-%4E0@24Y43R`D=&%B;&4@*"1N86UE<RD@5D%,5453("@D=F%L=65S
M*2(["B`@("`@("`@("`@(&-A<V4@1$)?05543U%515)97U501$%413H*("`@
M("`@("`@("`@("`@("1S970@/2`G)SL*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1T86)L95]F:65L9',@87,@)'9A;'5E*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*"1F:7)S="D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M9FER<W0@/2!F86QS93L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D<V5T("X]("<L)SL*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'-E="`N/2`B)'9A
M;'5E(#T@/R(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M<W%L(#T@(E501$%412`D=&%B;&4@4T54("1S970B.PH@("`@("`@("`@("`@
M("`@:68@*"1W:&5R92D@>PH@("`@("`@("`@("`@("`@("`@("1S<6P@+CT@
M(B!72$5212`D=VAE<F4B.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@<F5T=7)N("1S<6P["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?
M4UE.5$%8*3L*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@97AE8W5T92@I"@H@("`@+RHJ"B`@("`@*B!%>&5C=71E<R!A($1"('-T
M871E;65N="!P<F5P87)E9"!W:71H('!R97!A<F4H*0H@("`@("H*("`@("`J
M($5X86UP;&4@,2X*("`@("`J(#QC;V1E/@H@("`@("H@)'-T:"`]("1D8BT^
M<')E<&%R92@G24Y315)4($E.5$\@=&)L("AA+"!B+"!C*2!604Q515,@*#\L
M("$L("8I)RD["B`@("`@*B`D9&%T82`](&%R<F%Y*`H@("`@("H@("`@(")*
M;VAN)W,@=&5X="(L"B`@("`@*B`@("`@(B=I="<G<R!G;V]D)R(L"B`@("`@
M*B`@("`@)V9I;&5N86UE+G1X="<*("`@("`J("D["B`@("`@*B`D<F5S(#TF
M("1D8BT^97AE8W5T92@D<W1H+"`D9&%T82D["B`@("`@*B`\+V-O9&4^"B`@
M("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1S=&UT("!A($1"('-T871E
M;65N="!R97-O=7)C92!R971U<FYE9"!F<F]M('!R97!A<F4H*0H@("`@("H@
M0'!A<F%M(&UI>&5D("`@("1D871A("!A<G)A>2P@<W1R:6YG(&]R(&YU;65R
M:6,@9&%T82!T;R!B92!U<V5D(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!E>&5C=71I;VX@;V8@=&AE('-T871E;65N="X@(%%U86YT:71Y
M(&]F(&ET96US"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!P87-S
M960@;75S="!M871C:"!Q=6%N=&ET>2!O9B!P;&%C96AO;&1E<G,@:6X*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@('%U97)Y.B`@;65A;FEN9R`Q
M('!L86-E:&]L9&5R(&9O<B!N;VXM87)R87D*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@('!A<F%M971E<G,@;W(@,2!P;&%C96AO;&1E<B!P97(@
M87)R87D@96QE;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!A
M(&YE=R!$0E]R97-U;'0@;V)J96-T(&9O<B!S=6-C97-S9G5L(%-%3$5#5"!Q
M=65R:65S"B`@("`@*B`@("`@("`@("`@("`@("`@;W(@1$)?3TL@9F]R('-U
M8V-E<W-U;"!D871A(&UA;FEP=6QA=&EO;B!Q=65R:65S+@H@("`@("H@("`@
M("`@("`@("`@("`@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*@H@("`@("H@>T!I;G1E<FYA;"!I8F%S92!A;F0@;V-I."!H879E('1H
M96ER(&]W;B!E>&5C=71E*"D@;65T:&]D<RY]?0H@("`@("H*("`@("`J($!S
M964@1$)?8V]M;6]N.CIP<F5P87)E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@
M)F5X96-U=&4H)'-T;70L("1D871A(#T@87)R87DH*2D*("`@('L*("`@("`@
M("`D<F5A;'%U97)Y(#T@)'1H:7,M/F5X96-U=&5%;75L871E475E<GDH)'-T
M;70L("1D871A*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E86QQ=65R
M>2DI('L*("`@("`@("`@("`@<F5T=7)N("1R96%L<75E<GD["B`@("`@("`@
M?0H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^<VEM<&QE475E<GDH)')E86QQ
M=65R>2D["@H@("`@("`@(&EF("@D<F5S=6QT(#T]/2!$0E]/2R!\?"!$0CHZ
M:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&UP(#TF(&YE=R!$
M0E]R97-U;'0H)'1H:7,L("1R97-U;'0I.PH@("`@("`@("`@("!R971U<FX@
M)'1M<#L*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M97AE8W5T945M=6QA=&51=65R>2@I"@H@("`@+RHJ"B`@("`@*B!%;75L871E
M<R!E>&5C=71I;F<@<')E<&%R960@<W1A=&5M96YT<R!I9B!T:&4@1$)-4R!N
M;W0@<W5P<&]R="!T:&5M"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E
M("1S=&UT("!A($1"('-T871E;65N="!R97-O=7)C92!R971U<FYE9"!F<F]M
M(&5X96-U=&4H*0H@("`@("H@0'!A<F%M(&UI>&5D("`@("1D871A("!A<G)A
M>2P@<W1R:6YG(&]R(&YU;65R:6,@9&%T82!T;R!B92!U<V5D(&EN"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!E>&5C=71I;VX@;V8@=&AE('-T
M871E;65N="X@(%%U86YT:71Y(&]F(&ET96US"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!P87-S960@;75S="!M871C:"!Q=6%N=&ET>2!O9B!P
M;&%C96AO;&1E<G,@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M('%U97)Y.B`@;65A;FEN9R`Q('!L86-E:&]L9&5R(&9O<B!N;VXM87)R87D*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E<G,@;W(@
M,2!P;&%C96AO;&1E<B!P97(@87)R87D@96QE;65N="X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!A('-T<FEN9R!C;VYT86EN:6YG('1H92!R96%L
M('%U97)Y(')U;B!W:&5N(&5M=6QA=&EN9PH@("`@("H@("`@("`@("`@("`@
M("`@('!R97!A<F4O97AE8W5T92X@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J
M($!S964@1$)?8V]M;6]N.CIE>&5C=71E*"D*("`@("`J+PH@("`@9G5N8W1I
M;VX@97AE8W5T945M=6QA=&51=65R>2@D<W1M="P@)&1A=&$@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@("1S=&UT(#T@*&EN="DD<W1M=#L*("`@("`@("`D
M9&%T82`]("AA<G)A>2DD9&%T83L*("`@("`@("`D=&AI<RT^;&%S=%]P87)A
M;65T97)S(#T@)&1A=&$["@H@("`@("`@(&EF("AC;W5N="@D=&AI<RT^<')E
M<&%R95]T>7!E<ULD<W1M=%TI("$](&-O=6YT*"1D871A*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^;&%S=%]Q=65R>2`]("1T:&ES+3YP<F5P87)E9%]Q=65R
M:65S6R1S=&UT73L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*$1"7T524D]27TU)4TU!5$-(*3L*("`@("`@("!]"@H@("`@("`@("1R
M96%L<75E<GD@/2`D=&AI<RT^<')E<&%R95]T;VME;G-;)'-T;71=6S!=.PH*
M("`@("`@("`D:2`](#`["B`@("`@("`@9F]R96%C:"`H)&1A=&$@87,@)'9A
M;'5E*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^<')E<&%R95]T>7!E<ULD
M<W1M=%U;)&E=(#T]($1"7U!!4D%-7U-#04Q!4BD@>PH@("`@("`@("`@("`@
M("`@)')E86QQ=65R>2`N/2`D=&AI<RT^<75O=&53;6%R="@D=F%L=64I.PH@
M("`@("`@("`@("!](&5L<V5I9B`H)'1H:7,M/G!R97!A<F5?='EP97-;)'-T
M;71=6R1I72`]/2!$0E]005)!35]/4$%1544I('L*("`@("`@("`@("`@("`@
M("1F<"`]($!F;W!E;B@D=F%L=64L("=R8B<I.PH@("`@("`@("`@("`@("`@
M:68@*"$D9G`I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H1$)?15)23U)?04-#15-37U9)3TQ!5$E/3BD["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<F5A;'%U97)Y("X]("1T
M:&ES+3YQ=6]T95-M87)T*&9R96%D*"1F<"P@9FEL97-I>F4H)'9A;'5E*2DI
M.PH@("`@("`@("`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D<F5A;'%U97)Y("X]("1V86QU93L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)')E86QQ=65R>2`N/2`D=&AI
M<RT^<')E<&%R95]T;VME;G-;)'-T;71=6RLK)&E=.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1R96%L<75E<GD["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@97AE8W5T94UU;'1I<&QE*"D*"B`@("`O*BH*("`@("`J(%!E
M<F9O<FUS('-E=F5R86P@97AE8W5T92@I(&-A;&QS(&]N('1H92!S86UE('-T
M871E;65N="!H86YD;&4*("`@("`J"B`@("`@*B`D9&%T82!M=7-T(&)E(&%N
M(&%R<F%Y(&EN9&5X960@;G5M97)I8V%L;'D*("`@("`J(&9R;VT@,"P@;VYE
M(&5X96-U=&4@8V%L;"!I<R!D;VYE(&9O<B!E=F5R>2`B<F]W(B!I;B!T:&4@
M87)R87DN"B`@("`@*@H@("`@("H@268@86X@97)R;W(@;V-C=7)S(&1U<FEN
M9R!E>&5C=71E*"DL(&5X96-U=&5-=6QT:7!L92@I(&1O97,@;F]T"B`@("`@
M*B!E>&5C=71E('1H92!U;F9I;FES:&5D(')O=W,L(&)U="!R871H97(@<F5T
M=7)N<R!T:&%T(&5R<F]R+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C
M92`D<W1M="`@<75E<GD@:&%N9&QE(&9R;VT@<')E<&%R92@I"B`@("`@*B!`
M<&%R86T@87)R87D@("`@)&1A=&$@(&YU;65R:6,@87)R87D@8V]N=&%I;FEN
M9R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&1A=&$@=&\@
M:6YS97)T(&EN=&\@=&AE('%U97)Y"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIP<F5P87)E
M*"DL($1"7V-O;6UO;CHZ97AE8W5T92@I"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&5X96-U=&5-=6QT:7!L92@D<W1M="P@)&1A=&$I"B`@("!["B`@("`@("`@
M9F]R96%C:"`H)&1A=&$@87,@)'9A;'5E*2!["B`@("`@("`@("`@("1R97,@
M/28@)'1H:7,M/F5X96-U=&4H)'-T;70L("1V86QU92D["B`@("`@("`@("`@
M(&EF("A$0CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1R97,["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9R9650
M<F5P87)E9"@I"@H@("`@+RHJ"B`@("`@*B!&<F5E<R!T:&4@:6YT97)N86P@
M<F5S;W5R8V5S(&%S<V]C:6%T960@=VET:"!A('!R97!A<F5D('%U97)Y"B`@
M("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1S=&UT("`@("`@("`@("!T
M:&4@<')E<&%R960@<W1A=&5M96YT)W,@4$A0(')E<V]U<F-E"B`@("`@*B!`
M<&%R86T@8F]O;"`@("`@)&9R965?<F5S;W5R8V4@('-H;W5L9"!T:&4@4$A0
M(')E<V]U<F-E(&)E(&9R965D('1O;S\*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%5S92!F86QS92!I9B!Y;W4@;F5E9"!T;R!G
M970@9&%T80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@9G)O;2!T:&4@<F5S=6QT('-E="!L871E<BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VP@(%12544@;VX@<W5C8V5S<RP@1D%,4T4@:68@)')E<W5L
M="!I<R!I;G9A;&ED"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G!R
M97!A<F4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!F<F5E4')E<&%R960H)'-T
M;70L("1F<F5E7W)E<V]U<F-E(#T@=')U92D*("`@('L*("`@("`@("`D<W1M
M="`]("AI;G0I)'-T;70["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YP<F5P
M87)E7W1O:V5N<ULD<W1M=%TI*2!["B`@("`@("`@("`@('5N<V5T*"1T:&ES
M+3YP<F5P87)E7W1O:V5N<ULD<W1M=%TI.PH@("`@("`@("`@("!U;G-E="@D
M=&AI<RT^<')E<&%R95]T>7!E<ULD<W1M=%TI.PH@("`@("`@("`@("!U;G-E
M="@D=&AI<RT^<')E<&%R961?<75E<FEE<ULD<W1M=%TI.PH@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&UO9&EF>5%U97)Y*"D*
M"B`@("`O*BH*("`@("`J($-H86YG97,@82!Q=65R>2!S=')I;F<@9F]R('9A
M<FEO=7,@1$)-4R!S<&5C:69I8R!R96%S;VYS"B`@("`@*@H@("`@("H@270@
M:7,@9&5F:6YE9"!H97)E('1O(&5N<W5R92!A;&P@9')I=F5R<R!H879E('1H
M:7,@;65T:&]D(&%V86EL86)L92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1Q=65R>2`@=&AE('%U97)Y('-T<FEN9R!T;R!M;V1I9GD*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&UO9&EF:65D('%U97)Y('-T
M<FEN9PH@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B!`
M<V5E($1"7VUY<W%L.CIM;V1I9GE1=65R>2@I+"!$0E]O8VDX.CIM;V1I9GE1
M=65R>2@I+`H@("`@("H@("`@("!$0E]S<6QI=&4Z.FUO9&EF>5%U97)Y*"D*
M("`@("`J+PH@("`@9G5N8W1I;VX@;6]D:69Y475E<GDH)'%U97)Y*0H@("`@
M>PH@("`@("`@(')E='5R;B`D<75E<GD["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@;6]D:69Y3&EM:711=65R>2@I"@H@("`@+RHJ"B`@("`@*B!!
M9&1S($Q)34E4(&-L875S97,@=&\@82!Q=65R>2!S=')I;F<@86-C;W)D:6YG
M('1O(&-U<G)E;G0@1$)-4R!S=&%N9&%R9',*("`@("`J"B`@("`@*B!)="!I
M<R!D969I;F5D(&AE<F4@=&\@87-S=7)E('1H870@86QL(&EM<&QE;65N=&%T
M:6]N<PH@("`@("H@:&%V92!T:&ES(&UE=&AO9"!D969I;F5D+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'%U97)Y("`@=&AE('%U97)Y('1O(&UO
M9&EF>0H@("`@("H@0'!A<F%M(&EN="`@("`D9G)O;2`@("!T:&4@<F]W('1O
M('-T87)T('1O(&9E=&-H:6YG("@P(#T@=&AE(&9I<G-T(')O=RD*("`@("`J
M($!P87)A;2!I;G0@("`@)&-O=6YT("`@=&AE(&YU;6)E<G,@;V8@<F]W<R!T
M;R!F971C:`H@("`@("H@0'!A<F%M(&UI>&5D("`D<&%R86US("!A<G)A>2P@
M<W1R:6YG(&]R(&YU;65R:6,@9&%T82!T;R!B92!U<V5D(&EN"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!E>&5C=71I;VX@;V8@=&AE('-T871E
M;65N="X@(%%U86YT:71Y(&]F(&ET96US"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("!P87-S960@;75S="!M871C:"!Q=6%N=&ET>2!O9B!P;&%C
M96AO;&1E<G,@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('%U
M97)Y.B`@;65A;FEN9R`Q('!L86-E:&]L9&5R(&9O<B!N;VXM87)R87D*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E<G,@;W(@,2!P
M;&%C96AO;&1E<B!P97(@87)R87D@96QE;65N="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@=&AE('%U97)Y('-T<FEN9R!W:71H($Q)34E4(&-L
M875S97,@861D960*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@
M("`@("HO"B`@("!F=6YC=&EO;B!M;V1I9GE,:6UI=%%U97)Y*"1Q=65R>2P@
M)&9R;VTL("1C;W5N="P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@<F5T=7)N("1Q=65R>3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!Q=65R>2@I"@H@("`@+RHJ"B`@("`@*B!396YD<R!A('%U97)Y('1O('1H
M92!D871A8F%S92!S97)V97(*("`@("`J"B`@("`@*B!4:&4@<75E<GD@<W1R
M:6YG(&-A;B!B92!E:71H97(@82!N;W)M86P@<W1A=&5M96YT('1O(&)E('-E
M;G0@9&ER96-T;'D*("`@("`J('1O('1H92!S97)V97(@3U(@:68@/'9A<CXD
M<&%R86US/"]V87(^(&%R92!P87-S960@=&AE('%U97)Y(&-A;B!H879E"B`@
M("`@*B!P;&%C96AO;&1E<G,@86YD(&ET('=I;&P@8F4@<&%S<V5D('1H<F]U
M9V@@<')E<&%R92@I(&%N9"!E>&5C=71E*"DN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<75E<GD@("!T:&4@4U%,('%U97)Y(&]R('1H92!S=&%T
M96UE;G0@=&\@<')E<&%R90H@("`@("H@0'!A<F%M(&UI>&5D("`D<&%R86US
M("!A<G)A>2P@<W1R:6YG(&]R(&YU;65R:6,@9&%T82!T;R!B92!U<V5D(&EN
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!E>&5C=71I;VX@;V8@
M=&AE('-T871E;65N="X@(%%U86YT:71Y(&]F(&ET96US"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!P87-S960@;75S="!M871C:"!Q=6%N=&ET
M>2!O9B!P;&%C96AO;&1E<G,@:6X*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@('%U97)Y.B`@;65A;FEN9R`Q('!L86-E:&]L9&5R(&9O<B!N;VXM
M87)R87D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E
M<G,@;W(@,2!P;&%C96AO;&1E<B!P97(@87)R87D@96QE;65N="X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!A(&YE=R!$0E]R97-U;'0@;V)J96-T
M(&9O<B!S=6-C97-S9G5L(%-%3$5#5"!Q=65R:65S"B`@("`@*B`@("`@("`@
M("`@("`@("`@;W(@1$)?3TL@9F]R('-U8V-E<W-U;"!D871A(&UA;FEP=6QA
M=&EO;B!Q=65R:65S+@H@("`@("H@("`@("`@("`@("`@("`@($$@1$)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]R
M97-U;'0L($1"7V-O;6UO;CHZ<')E<&%R92@I+"!$0E]C;VUM;VXZ.F5X96-U
M=&4H*0H@("`@("HO"B`@("!F=6YC=&EO;B`F<75E<GDH)'%U97)Y+"`D<&%R
M86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H<VEZ96]F*"1P87)A
M;7,I(#X@,"D@>PH@("`@("`@("`@("`D<W1H(#T@)'1H:7,M/G!R97!A<F4H
M)'%U97)Y*3L*("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1S=&@I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)'-T:#L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D<F5T(#TF("1T:&ES+3YE>&5C=71E*"1S=&@L("1P87)A
M;7,I.PH@("`@("`@("`@("`D=&AI<RT^9G)E95!R97!A<F5D*"1S=&@L(&9A
M;'-E*3L*("`@("`@("`@("`@<F5T=7)N("1R970["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'1H:7,M/FQA<W1?<&%R86UE=&5R<R`](&%R<F%Y
M*"D["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^<VEM<&QE475E<GDH
M)'%U97)Y*3L*("`@("`@("`@("`@:68@*"1R97-U;'0@/3T]($1"7T]+('Q\
M($1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1T;7`@/28@;F5W($1"7W)E<W5L="@D=&AI<RP@)')E<W5L="D["B`@
M("`@("`@("`@("`@("!R971U<FX@)'1M<#L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!L:6UI=%%U97)Y
M*"D*"B`@("`O*BH*("`@("`J($=E;F5R871E<R!A;F0@97AE8W5T97,@82!,
M24U)5"!Q=65R>0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'%U97)Y
M("`@=&AE('%U97)Y"B`@("`@*B!`<&%R86T@:6YT<B`@("1F<F]M("`@('1H
M92!R;W<@=&\@<W1A<G0@=&\@9F5T8VAI;F<@*#`@/2!T:&4@9FER<W0@<F]W
M*0H@("`@("H@0'!A<F%M(&EN="`@("`D8V]U;G0@("!T:&4@;G5M8F5R<R!O
M9B!R;W=S('1O(&9E=&-H"B`@("`@*B!`<&%R86T@;6EX960@("1P87)A;7,@
M(&%R<F%Y+"!S=')I;F<@;W(@;G5M97)I8R!D871A('1O(&)E('5S960@:6X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&5X96-U=&EO;B!O9B!T
M:&4@<W1A=&5M96YT+B`@475A;G1I='D@;V8@:71E;7,*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@('!A<W-E9"!M=7-T(&UA=&-H('%U86YT:71Y
M(&]F('!L86-E:&]L9&5R<R!I;@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@<75E<GDZ("!M96%N:6YG(#$@<&QA8V5H;VQD97(@9F]R(&YO;BUA
M<G)A>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R
M<R!O<B`Q('!L86-E:&]L9&5R('!E<B!A<G)A>2!E;&5M96YT+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(&$@;F5W($1"7W)E<W5L="!O8FIE8W0@
M9F]R('-U8V-E<W-F=6P@4T5,14-4('%U97)I97,*("`@("`J("`@("`@("`@
M("`@("`@("!O<B!$0E]/2R!F;W(@<W5C8V5S<W5L(&1A=&$@;6%N:7!U;&%T
M:6]N('%U97)I97,N"B`@("`@*B`@("`@("`@("`@("`@("`@02!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@)FQI
M;6ET475E<GDH)'%U97)Y+"`D9G)O;2P@)&-O=6YT+"`D<&%R86US(#T@87)R
M87DH*2D*("`@('L*("`@("`@("`D<75E<GD@/2`D=&AI<RT^;6]D:69Y3&EM
M:711=65R>2@D<75E<GDL("1F<F]M+"`D8V]U;G0L("1P87)A;7,I.PH@("`@
M("`@(&EF("A$0CHZ:7-%<G)O<B@D<75E<GDI*7L*("`@("`@("`@("`@<F5T
M=7)N("1Q=65R>3L*("`@("`@("!]"B`@("`@("`@)')E<W5L="`])B`D=&AI
M<RT^<75E<GDH)'%U97)Y+"`D<&%R86US*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G1$)?<F5S=6QT)RDI('L*("`@("`@("`@("`@)')E<W5L="T^
M<V5T3W!T:6]N*"=L:6UI=%]F<F]M)RP@)&9R;VTI.PH@("`@("`@("`@("`D
M<F5S=6QT+3YS971/<'1I;VXH)VQI;6ET7V-O=6YT)RP@)&-O=6YT*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@9V5T3VYE*"D*"B`@("`O*BH*("`@("`J($9E=&-H
M97,@=&AE(&9I<G-T(&-O;'5M;B!O9B!T:&4@9FER<W0@<F]W(&9R;VT@82!Q
M=65R>2!R97-U;'0*("`@("`J"B`@("`@*B!486ME<R!C87)E(&]F(&1O:6YG
M('1H92!Q=65R>2!A;F0@9G)E96EN9R!T:&4@<F5S=6QT<R!W:&5N(&9I;FES
M:&5D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'%U97)Y("`@=&AE
M(%-13"!Q=65R>0H@("`@("H@0'!A<F%M(&UI>&5D("`D<&%R86US("!A<G)A
M>2P@<W1R:6YG(&]R(&YU;65R:6,@9&%T82!T;R!B92!U<V5D(&EN"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!E>&5C=71I;VX@;V8@=&AE('-T
M871E;65N="X@(%%U86YT:71Y(&]F(&ET96US"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!P87-S960@;75S="!M871C:"!Q=6%N=&ET>2!O9B!P
M;&%C96AO;&1E<G,@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M('%U97)Y.B`@;65A;FEN9R`Q('!L86-E:&]L9&5R(&9O<B!N;VXM87)R87D*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E<G,@;W(@
M,2!P;&%C96AO;&1E<B!P97(@87)R87D@96QE;65N="X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!T:&4@<F5T=7)N960@=F%L=64@;V8@=&AE('%U
M97)Y+@H@("`@("H@("`@("`@("`@("`@("`@($$@1$)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971/;F4H)'%U
M97)Y+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D<&%R86US
M(#T@*&%R<F%Y*21P87)A;7,["B`@("`@("`@+R\@;6]D:69Y3&EM:711=65R
M>2@I('=O=6QD(&)E(&YI8V4@:&5R92P@8G5T(&ET(&-A=7-E<R!"0R!I<W-U
M97,*("`@("`@("!I9B`H<VEZ96]F*"1P87)A;7,I(#X@,"D@>PH@("`@("`@
M("`@("`D<W1H(#T@)'1H:7,M/G!R97!A<F4H)'%U97)Y*3L*("`@("`@("`@
M("`@:68@*$1".CII<T5R<F]R*"1S=&@I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)'-T:#L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<F5S(#TF
M("1T:&ES+3YE>&5C=71E*"1S=&@L("1P87)A;7,I.PH@("`@("`@("`@("`D
M=&AI<RT^9G)E95!R97!A<F5D*"1S=&@I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1R97,@/28@)'1H:7,M/G%U97)Y*"1Q=65R>2D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H*("`@("`@("`D97)R(#T@
M)')E<RT^9F5T8VA);G1O*"1R;W<L($1"7T9%5$-(34]$15]/4D1%4D5$*3L*
M("`@("`@("`D<F5S+3YF<F5E*"D["@H@("`@("`@(&EF("@D97)R("$]/2!$
M0E]/2RD@>PH@("`@("`@("`@("!R971U<FX@)&5R<CL*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D<F]W6S!=.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&=E=%)O=R@I"@H@("`@+RHJ"B`@("`@*B!&971C:&5S('1H92!F
M:7)S="!R;W<@;V8@9&%T82!R971U<FYE9"!F<F]M(&$@<75E<GD@<F5S=6QT
M"B`@("`@*@H@("`@("H@5&%K97,@8V%R92!O9B!D;VEN9R!T:&4@<75E<GD@
M86YD(&9R965I;F<@=&AE(')E<W5L=',@=VAE;B!F:6YI<VAE9"X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1Q=65R>2`@('1H92!344P@<75E<GD*
M("`@("`J($!P87)A;2!M:7AE9"`@)'!A<F%M<R`@87)R87DL('-T<FEN9R!O
M<B!N=6UE<FEC(&1A=&$@=&\@8F4@=7-E9"!I;@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@97AE8W5T:6]N(&]F('1H92!S=&%T96UE;G0N("!1
M=6%N=&ET>2!O9B!I=&5M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@<&%S<V5D(&UU<W0@;6%T8V@@<75A;G1I='D@;V8@<&QA8V5H;VQD97)S
M(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!Q=65R>3H@(&UE
M86YI;F<@,2!P;&%C96AO;&1E<B!F;W(@;F]N+6%R<F%Y"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!P87)A;65T97)S(&]R(#$@<&QA8V5H;VQD
M97(@<&5R(&%R<F%Y(&5L96UE;G0N"B`@("`@*B!`<&%R86T@:6YT("1F971C
M:&UO9&4@('1H92!F971C:"!M;V1E('1O('5S90H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@('1H92!F:7)S="!R;W<@;V8@<F5S=6QT<R!A<R!A;B!A
M<G)A>2X*("`@("`J("`@("`@("`@("`@("`@("!!($1"7T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T4F]W*"1Q
M=65R>2P@)'!A<F%M<R`](&%R<F%Y*"DL"B`@("`@("`@("`@("`@("`@("`@
M("1F971C:&UO9&4@/2!$0E]&151#2$U/1$5?1$5&055,5"D*("`@('L*("`@
M("`@("`O+R!C;VUP870@8VAE8VLL('1H92!P87)A;7,@86YD(&9E=&-H;6]D
M92!P87)A;65T97)S('5S960@=&\*("`@("`@("`O+R!H879E('1H92!O<'!O
M<VET92!O<F1E<@H@("`@("`@(&EF("@A:7-?87)R87DH)'!A<F%M<RDI('L*
M("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1F971C:&UO9&4I*2!["B`@("`@
M("`@("`@("`@("!I9B`H)'!A<F%M<R`]/3T@;G5L;"D@>PH@("`@("`@("`@
M("`@("`@("`@("1T;7`@/2!$0E]&151#2$U/1$5?1$5&055,5#L*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1M<"`]
M("1P87)A;7,["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M<&%R86US(#T@)&9E=&-H;6]D93L*("`@("`@("`@("`@("`@("1F971C:&UO
M9&4@/2`D=&UP.PH@("`@("`@("`@("!](&5L<V5I9B`H)'!A<F%M<R`A/3T@
M;G5L;"D@>PH@("`@("`@("`@("`@("`@)&9E=&-H;6]D92`]("1P87)A;7,[
M"B`@("`@("`@("`@("`@("`D<&%R86US(#T@87)R87DH*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("`O+R!M;V1I9GE,:6UI=%%U97)Y*"D@
M=V]U;&0@8F4@;FEC92!H97)E+"!B=70@:70@8V%U<V5S($)#(&ES<W5E<PH@
M("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@/B`P*2!["B`@("`@("`@("`@
M("1S=&@@/2`D=&AI<RT^<')E<&%R92@D<75E<GDI.PH@("`@("`@("`@("!I
M9B`H1$(Z.FES17)R;W(H)'-T:"DI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D<W1H.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1R97,@/28@)'1H
M:7,M/F5X96-U=&4H)'-T:"P@)'!A<F%M<RD["B`@("`@("`@("`@("1T:&ES
M+3YF<F5E4')E<&%R960H)'-T:"D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)')E<R`])B`D=&AI<RT^<75E<GDH)'%U97)Y*3L*("`@("`@("!]
M"@H@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@("`@
M("!R971U<FX@)')E<SL*("`@("`@("!]"@H@("`@("`@("1E<G(@/2`D<F5S
M+3YF971C:$EN=&\H)')O=RP@)&9E=&-H;6]D92D["@H@("`@("`@("1R97,M
M/F9R964H*3L*"B`@("`@("`@:68@*"1E<G(@(3T]($1"7T]+*2!["B`@("`@
M("`@("`@(')E='5R;B`D97)R.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1R;W<["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T0V]L*"D*
M"B`@("`O*BH*("`@("`J($9E=&-H97,@82!S:6YG;&4@8V]L=6UN(&9R;VT@
M82!Q=65R>2!R97-U;'0@86YD(')E='5R;G,@:70@87,@86X*("`@("`J(&EN
M9&5X960@87)R87D*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1Q=65R
M>2`@('1H92!344P@<75E<GD*("`@("`J($!P87)A;2!M:7AE9"`@)&-O;"`@
M("`@=VAI8V@@8V]L=6UN('1O(')E='5R;B`H:6YT96=E<B!;8V]L=6UN(&YU
M;6)E<BP*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('-T87)T:6YG
M(&%T(#!=(&]R('-T<FEN9R!;8V]L=6UN(&YA;65=*0H@("`@("H@0'!A<F%M
M(&UI>&5D("`D<&%R86US("!A<G)A>2P@<W1R:6YG(&]R(&YU;65R:6,@9&%T
M82!T;R!B92!U<V5D(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!E>&5C=71I;VX@;V8@=&AE('-T871E;65N="X@(%%U86YT:71Y(&]F(&ET
M96US"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!P87-S960@;75S
M="!M871C:"!Q=6%N=&ET>2!O9B!P;&%C96AO;&1E<G,@:6X*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@('%U97)Y.B`@;65A;FEN9R`Q('!L86-E
M:&]L9&5R(&9O<B!N;VXM87)R87D*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@('!A<F%M971E<G,@;W(@,2!P;&%C96AO;&1E<B!P97(@87)R87D@
M96QE;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!T:&4@<F5S
M=6QT<R!A<R!A;B!A<G)A>2X@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G%U97)Y*"D*("`@
M("`J+PH@("`@9G5N8W1I;VX@)F=E=$-O;"@D<75E<GDL("1C;VP@/2`P+"`D
M<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D<&%R86US(#T@*&%R
M<F%Y*21P87)A;7,["B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`^(#`I
M('L*("`@("`@("`@("`@)'-T:"`]("1T:&ES+3YP<F5P87)E*"1Q=65R>2D[
M"@H@("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H)'-T:"DI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D<W1H.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D<F5S(#TF("1T:&ES+3YE>&5C=71E*"1S=&@L("1P87)A;7,I.PH@
M("`@("`@("`@("`D=&AI<RT^9G)E95!R97!A<F5D*"1S=&@I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1R97,@/28@)'1H:7,M/G%U97)Y*"1Q
M=65R>2D["B`@("`@("`@?0H*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E
M<RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H*("`@
M("`@("`D9F5T8VAM;V1E(#T@:7-?:6YT*"1C;VPI(#\@1$)?1D540TA-3T1%
M7T]21$52140@.B!$0E]&151#2$U/1$5?05-33T,["@H@("`@("`@(&EF("@A
M:7-?87)R87DH)')O=R`]("1R97,M/F9E=&-H4F]W*"1F971C:&UO9&4I*2D@
M>PH@("`@("`@("`@("`D<F5T(#T@87)R87DH*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!I9B`H(6%R<F%Y7VME>5]E>&ES=',H)&-O;"P@)')O
M=RDI('L*("`@("`@("`@("`@("`@("1R970@/28@)'1H:7,M/G)A:7-E17)R
M;W(H1$)?15)23U)?3D]354-(1DE%3$0I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)')E="`](&%R<F%Y*"1R;W=;)&-O;%TI.PH@
M("`@("`@("`@("`@("`@=VAI;&4@*&ES7V%R<F%Y*"1R;W<@/2`D<F5S+3YF
M971C:%)O=R@D9F5T8VAM;V1E*2DI('L*("`@("`@("`@("`@("`@("`@("`D
M<F5T6UT@/2`D<F]W6R1C;VQ=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<F5S+3YF<F5E*"D["@H@("`@
M("`@(&EF("A$0CHZ:7-%<G)O<B@D<F]W*2D@>PH@("`@("`@("`@("`D<F5T
M(#T@)')O=SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5T.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E=$%S<V]C*"D*"B`@("`O*BH*
M("`@("`J($9E=&-H97,@86X@96YT:7)E('%U97)Y(')E<W5L="!A;F0@<F5T
M=7)N<R!I="!A<R!A;@H@("`@("H@87-S;V-I871I=F4@87)R87D@=7-I;F<@
M=&AE(&9I<G-T(&-O;'5M;B!A<R!T:&4@:V5Y"B`@("`@*@H@("`@("H@268@
M=&AE(')E<W5L="!S970@8V]N=&%I;G,@;6]R92!T:&%N('1W;R!C;VQU;6YS
M+"!T:&4@=F%L=64*("`@("`J('=I;&P@8F4@86X@87)R87D@;V8@=&AE('9A
M;'5E<R!F<F]M(&-O;'5M;B`R+6XN("!)9B!T:&4@<F5S=6QT"B`@("`@*B!S
M970@8V]N=&%I;G,@;VYL>2!T=V\@8V]L=6UN<RP@=&AE(')E='5R;F5D('9A
M;'5E('=I;&P@8F4@80H@("`@("H@<V-A;&%R('=I=&@@=&AE('9A;'5E(&]F
M('1H92!S96-O;F0@8V]L=6UN("AU;FQE<W,@9F]R8V5D('1O(&%N"B`@("`@
M*B!A<G)A>2!W:71H('1H92`D9F]R8V5?87)R87D@<&%R86UE=&5R*2X@($$@
M1$(@97)R;W(@8V]D92!I<PH@("`@("H@<F5T=7)N960@;VX@97)R;W)S+B`@
M268@=&AE(')E<W5L="!S970@8V]N=&%I;G,@9F5W97(@=&AA;B!T=V\*("`@
M("`J(&-O;'5M;G,L(&$@1$)?15)23U)?5%)53D-!5$5$(&5R<F]R(&ES(')E
M='5R;F5D+@H@("`@("H*("`@("`J($9O<B!E>&%M<&QE+"!I9B!T:&4@=&%B
M;&4@(FUY=&%B;&4B(&-O;G1A:6YS.@H@("`@("H*("`@("`J(#QP<F4^"B`@
M("`@*B`@240@("`@("!415A4("`@("`@($1!5$4*("`@("`J("TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"B`@("`@*B`@,2`@("`@("`G;VYE
M)R`@("`@(#DT-#8W.30P.`H@("`@("H@(#(@("`@("`@)W1W;R<@("`@("`Y
M-#0V-SDT,#@*("`@("`J("`S("`@("`@("=T:')E92<@("`@.30T-C<Y-#`X
M"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!4:&5N('1H92!C86QL(&=E
M=$%S<V]C*"=314Q%0U0@:60L=&5X="!&4D]-(&UY=&%B;&4G*2!R971U<FYS
M.@H@("`@("H@/'!R93X*("`@("`J("`@87)R87DH"B`@("`@*B`@("`@)S$G
M(#T^("=O;F4G+`H@("`@("H@("`@("<R)R`]/B`G='=O)RP*("`@("`J("`@
M("`G,R<@/3X@)W1H<F5E)RP*("`@("`J("`@*0H@("`@("H@/"]P<F4^"B`@
M("`@*@H@("`@("H@+BXN=VAI;&4@=&AE(&-A;&P@9V5T07-S;V,H)U-%3$5#
M5"!I9"QT97AT+&1A=&4@1E)/32!M>71A8FQE)RD@<F5T=7)N<SH*("`@("`J
M(#QP<F4^"B`@("`@*B`@(&%R<F%Y*`H@("`@("H@("`@("<Q)R`]/B!A<G)A
M>2@G;VYE)RP@)SDT-#8W.30P."<I+`H@("`@("H@("`@("<R)R`]/B!A<G)A
M>2@G='=O)RP@)SDT-#8W.30P."<I+`H@("`@("H@("`@("<S)R`]/B!A<G)A
M>2@G=&AR964G+"`G.30T-C<Y-#`X)RD*("`@("`J("`@*0H@("`@("H@/"]P
M<F4^"B`@("`@*@H@("`@("H@268@=&AE(&UO<F4@=&AA;B!O;F4@<F]W(&]C
M8W5R<R!W:71H('1H92!S86UE('9A;'5E(&EN('1H90H@("`@("H@9FER<W0@
M8V]L=6UN+"!T:&4@;&%S="!R;W<@;W9E<G=R:71E<R!A;&P@<')E=FEO=7,@
M;VYE<R!B>0H@("`@("H@9&5F875L="X@(%5S92!T:&4@)&=R;W5P('!A<F%M
M971E<B!I9B!Y;W4@9&]N)W0@=V%N="!T;PH@("`@("H@;W9E<G=R:71E(&QI
M:V4@=&AI<RX@($5X86UP;&4Z"B`@("`@*@H@("`@("H@/'!R93X*("`@("`J
M(&=E=$%S<V]C*"=314Q%0U0@8V%T96=O<GDL:60L;F%M92!&4D]-(&UY=&%B
M;&4G+"!F86QS92P@;G5L;"P*("`@("`J("`@("`@("`@($1"7T9%5$-(34]$
M15]!4U-/0RP@=')U92D@<F5T=7)N<SH*("`@("`J"B`@("`@*B`@(&%R<F%Y
M*`H@("`@("H@("`@("<Q)R`]/B!A<G)A>2AA<G)A>2@G:60G(#T^("<T)RP@
M)VYA;64G(#T^("=N=6UB97(@9F]U<B<I+`H@("`@("H@("`@("`@("`@("`@
M("`@("!A<G)A>2@G:60G(#T^("<V)RP@)VYA;64G(#T^("=N=6UB97(@<VEX
M)RD*("`@("`J("`@("`@("`@("`@*2P*("`@("`J("`@("`G.2<@/3X@87)R
M87DH87)R87DH)VED)R`]/B`G-"<L("=N86UE)R`]/B`G;G5M8F5R(&9O=7(G
M*2P*("`@("`J("`@("`@("`@("`@("`@("`@87)R87DH)VED)R`]/B`G-B<L
M("=N86UE)R`]/B`G;G5M8F5R('-I>"<I"B`@("`@*B`@("`@("`@("`@("D*
M("`@("`J("`@*0H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@("H@2V5E<"!I
M;B!M:6YD('1H870@9&%T86)A<V4@9G5N8W1I;VYS(&EN(%!(4"!U<W5A;&QY
M(')E='5R;B!S=')I;F<*("`@("`J('9A;'5E<R!F;W(@<F5S=6QT<R!R96=A
M<F1L97-S(&]F('1H92!D871A8F%S92=S(&EN=&5R;F%L('1Y<&4N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<75E<GD@("`@("`@('1H92!344P@
M<75E<GD*("`@("`J($!P87)A;2!B;V]L("`@)&9O<F-E7V%R<F%Y("!U<V5D
M(&]N;'D@=VAE;B!T:&4@<75E<GD@<F5T=7)N<PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!E>&%C=&QY('1W;R!C;VQU;6YS+B`@268@
M=')U92P@=&AE('9A;'5E<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!O9B!T:&4@<F5T=7)N960@87)R87D@=VEL;"!B92!O;F4M96QE
M;65N=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>7,@:6YS=&5A9"!O9B!S8V%L87)S+@H@("`@("H@0'!A<F%M(&UI>&5D("`D
M<&%R86US("`@("`@(&%R<F%Y+"!S=')I;F<@;W(@;G5M97)I8R!D871A('1O
M(&)E('5S960@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@97AE8W5T:6]N(&]F('1H92!S=&%T96UE;G0N("!1=6%N=&ET>2!O9@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I=&5M<R!P87-S
M960@;75S="!M871C:"!Q=6%N=&ET>2!O9@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!P;&%C96AO;&1E<G,@:6X@<75E<GDZ("!M96%N
M:6YG(#$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<&QA
M8V5H;VQD97(@9F]R(&YO;BUA<G)A>2!P87)A;65T97)S(&]R"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$@<&QA8V5H;VQD97(@<&5R
M(&%R<F%Y(&5L96UE;G0N"B`@("`@*B!`<&%R86T@:6YT("`@)&9E=&-H;6]D
M92`@("`@=&AE(&9E=&-H(&UO9&4@=&\@=7-E"B`@("`@*B!`<&%R86T@8F]O
M;"`@)&=R;W5P("`@("`@("`@:68@=')U92P@=&AE('9A;'5E<R!O9B!T:&4@
M<F5T=7)N960@87)R87D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:7,@=W)A<'!E9"!I;B!A;F]T:&5R(&%R<F%Y+B`@268@=&AE('-A
M;64*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:V5Y('9A
M;'5E("AI;B!T:&4@9FER<W0@8V]L=6UN*2!R97!E871S"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&ET<V5L9BP@=&AE('9A;'5E<R!W
M:6QL(&)E(&%P<&5N9&5D('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('1H:7,@87)R87D@:6YS=&5A9"!O9B!O=F5R=W)I=&EN9R!T
M:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@97AI<W1I
M;F<@=F%L=65S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@('1H92!A
M<W-O8VEA=&EV92!A<G)A>2!C;VYT86EN:6YG('1H92!Q=65R>2!R97-U;'1S
M+@H@("`@("H@("`@("`@("`@("`@("`@02!$0E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$%S<V]C*"1Q=65R
M>2P@)&9O<F-E7V%R<F%Y(#T@9F%L<V4L("1P87)A;7,@/2!A<G)A>2@I+`H@
M("`@("`@("`@("`@("`@("`@("`@("1F971C:&UO9&4@/2!$0E]&151#2$U/
M1$5?1$5&055,5"P@)&=R;W5P(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'!A
M<F%M<R`]("AA<G)A>2DD<&%R86US.PH@("`@("`@(&EF("AS:7IE;V8H)'!A
M<F%M<RD@/B`P*2!["B`@("`@("`@("`@("1S=&@@/2`D=&AI<RT^<')E<&%R
M92@D<75E<GDI.PH*("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1S=&@I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'-T:#L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@)')E<R`])B`D=&AI<RT^97AE8W5T92@D<W1H+"`D
M<&%R86US*3L*("`@("`@("`@("`@)'1H:7,M/F9R9650<F5P87)E9"@D<W1H
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S(#TF("1T:&ES
M+3YQ=65R>2@D<75E<GDI.PH@("`@("`@('T*"B`@("`@("`@:68@*$1".CII
M<T5R<F]R*"1R97,I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@
M("`@('T*("`@("`@("!I9B`H)&9E=&-H;6]D92`]/2!$0E]&151#2$U/1$5?
M1$5&055,5"D@>PH@("`@("`@("`@("`D9F5T8VAM;V1E(#T@)'1H:7,M/F9E
M=&-H;6]D93L*("`@("`@("!]"B`@("`@("`@)&-O;',@/2`D<F5S+3YN=6U#
M;VQS*"D["@H@("`@("`@(&EF("@D8V]L<R`\(#(I('L*("`@("`@("`@("`@
M)'1M<"`])B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]44E5.0T%4140I
M.PH@("`@("`@("`@("!R971U<FX@)'1M<#L*("`@("`@("!]"@H@("`@("`@
M("1R97-U;'1S(#T@87)R87DH*3L*"B`@("`@("`@:68@*"1C;VQS(#X@,B!\
M?"`D9F]R8V5?87)R87DI('L*("`@("`@("`@("`@+R\@<F5T=7)N(&%R<F%Y
M('9A;'5E<PH@("`@("`@("`@("`O+R!86%@@=&AI<R!P87)T(&-A;B!B92!O
M<'1I;6EZ960*("`@("`@("`@("`@:68@*"1F971C:&UO9&4@/3T@1$)?1D54
M0TA-3T1%7T%34T]#*2!["B`@("`@("`@("`@("`@("!W:&EL92`H:7-?87)R
M87DH)')O=R`]("1R97,M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]!4U-/0RDI
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5S970H)')O=RD["B`@("`@("`@
M("`@("`@("`@("`@)&ME>2`](&-U<G)E;G0H)')O=RD["B`@("`@("`@("`@
M("`@("`@("`@=6YS970H)')O=UMK97DH)')O=RE=*3L*("`@("`@("`@("`@
M("`@("`@("!I9B`H)&=R;W5P*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1R97-U;'1S6R1K97E=6UT@/2`D<F]W.PH@("`@("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1R97-U;'1S6R1K
M97E=(#T@)')O=SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T@96QS96EF("@D9F5T8VAM;V1E(#T]($1"
M7T9%5$-(34]$15]/0DI%0U0I('L*("`@("`@("`@("`@("`@('=H:6QE("@D
M<F]W(#T@)')E<RT^9F5T8VA2;W<H1$)?1D540TA-3T1%7T]"2D5#5"DI('L*
M("`@("`@("`@("`@("`@("`@("`D87)R(#T@9V5T7V]B:F5C=%]V87)S*"1R
M;W<I.PH@("`@("`@("`@("`@("`@("`@("1K97D@/2!C=7)R96YT*"1A<G(I
M.PH@("`@("`@("`@("`@("`@("`@(&EF("@D9W)O=7`I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)')E<W5L='-;)&ME>5U;72`]("1R;W<["B`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)')E<W5L='-;)&ME>5T@/2`D<F]W.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@('=H:6QE("AI<U]A<G)A>2@D<F]W(#T@)')E<RT^9F5T
M8VA2;W<H1$)?1D540TA-3T1%7T]21$52140I*2D@>PH@("`@("`@("`@("`@
M("`@("`@("\O('=E('-H:69T(&%W87D@=&AE(&9I<G-T(&5L96UE;G0@=&\@
M9V5T"B`@("`@("`@("`@("`@("`@("`@+R\@:6YD:6-E<R!R=6YN:6YG(&9R
M;VT@,"!A9V%I;@H@("`@("`@("`@("`@("`@("`@("1K97D@/2!A<G)A>5]S
M:&EF="@D<F]W*3L*("`@("`@("`@("`@("`@("`@("!I9B`H)&=R;W5P*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1R97-U;'1S6R1K97E=6UT@/2`D
M<F]W.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1R97-U;'1S6R1K97E=(#T@)')O=SL*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R;W<I*2!["B`@("`@("`@
M("`@("`@("`D<F5S=6QT<R`]("1R;W<["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`O+R!R971U<FX@<V-A;&%R('9A;'5E
M<PH@("`@("`@("`@("!W:&EL92`H:7-?87)R87DH)')O=R`]("1R97,M/F9E
M=&-H4F]W*$1"7T9%5$-(34]$15]/4D1%4D5$*2DI('L*("`@("`@("`@("`@
M("`@(&EF("@D9W)O=7`I('L*("`@("`@("`@("`@("`@("`@("`D<F5S=6QT
M<ULD<F]W6S!=75M=(#T@)')O=ULQ73L*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)')E<W5L='-;)')O=ULP75T@/2`D
M<F]W6S%=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F]W*2D@>PH@("`@("`@("`@("`@
M("`@)')E<W5L=',@/2`D<F]W.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`D<F5S+3YF<F5E*"D["@H@("`@("`@(')E='5R;B`D<F5S=6QT
M<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G971!;&PH*0H*("`@
M("\J*@H@("`@("H@1F5T8VAE<R!A;&P@;V8@=&AE(')O=W,@9G)O;2!A('%U
M97)Y(')E<W5L=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'%U97)Y
M("`@("`@=&AE(%-13"!Q=65R>0H@("`@("H@0'!A<F%M(&UI>&5D("`D<&%R
M86US("`@("!A<G)A>2P@<W1R:6YG(&]R(&YU;65R:6,@9&%T82!T;R!B92!U
M<V5D(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!E>&5C
M=71I;VX@;V8@=&AE('-T871E;65N="X@(%%U86YT:71Y(&]F"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I=&5M<R!P87-S960@;75S="!M
M871C:"!Q=6%N=&ET>2!O9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<&QA8V5H;VQD97)S(&EN('%U97)Y.B`@;65A;FEN9R`Q"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!P;&%C96AO;&1E<B!F;W(@
M;F]N+6%R<F%Y('!A<F%M971E<G,@;W(*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#$@<&QA8V5H;VQD97(@<&5R(&%R<F%Y(&5L96UE;G0N
M"B`@("`@*B!`<&%R86T@:6YT("`@("1F971C:&UO9&4@('1H92!F971C:"!M
M;V1E('1O('5S93H*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("L@1$)?1D540TA-3T1%7T]21$52140*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("L@1$)?1D540TA-3T1%7T%34T]#"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`K($1"7T9%5$-(34]$15]/4D1%4D5$
M('P@1$)?1D540TA-3T1%7T9,25!0140*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("L@1$)?1D540TA-3T1%7T%34T]#('P@1$)?1D540TA-
M3T1%7T9,25!0140*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!T:&4@
M;F5S=&5D(&%R<F%Y+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$%L;"@D<75E<GDL("1P87)A;7,@
M/2!A<G)A>2@I+`H@("`@("`@("`@("`@("`@("`@("`D9F5T8VAM;V1E(#T@
M1$)?1D540TA-3T1%7T1%1D%53%0I"B`@("!["B`@("`@("`@+R\@8V]M<&%T
M(&-H96-K+"!T:&4@<&%R86US(&%N9"!F971C:&UO9&4@<&%R86UE=&5R<R!U
M<V5D('1O"B`@("`@("`@+R\@:&%V92!T:&4@;W!P;W-I=&4@;W)D97(*("`@
M("`@("!I9B`H(6ES7V%R<F%Y*"1P87)A;7,I*2!["B`@("`@("`@("`@(&EF
M("AI<U]A<G)A>2@D9F5T8VAM;V1E*2D@>PH@("`@("`@("`@("`@("`@:68@
M*"1P87)A;7,@/3T](&YU;&PI('L*("`@("`@("`@("`@("`@("`@("`D=&UP
M(#T@1$)?1D540TA-3T1%7T1%1D%53%0["B`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("1T;7`@/2`D<&%R86US.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'!A<F%M<R`]("1F971C
M:&UO9&4["B`@("`@("`@("`@("`@("`D9F5T8VAM;V1E(#T@)'1M<#L*("`@
M("`@("`@("`@?2!E;'-E:68@*"1P87)A;7,@(3T](&YU;&PI('L*("`@("`@
M("`@("`@("`@("1F971C:&UO9&4@/2`D<&%R86US.PH@("`@("`@("`@("`@
M("`@)'!A<F%M<R`](&%R<F%Y*"D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@/B`P*2!["B`@("`@("`@
M("`@("1S=&@@/2`D=&AI<RT^<')E<&%R92@D<75E<GDI.PH*("`@("`@("`@
M("`@:68@*$1".CII<T5R<F]R*"1S=&@I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)'-T:#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)')E<R`]
M)B`D=&AI<RT^97AE8W5T92@D<W1H+"`D<&%R86US*3L*("`@("`@("`@("`@
M)'1H:7,M/F9R9650<F5P87)E9"@D<W1H*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D<F5S(#TF("1T:&ES+3YQ=65R>2@D<75E<GDI.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"1R97,@/3T]($1"7T]+('Q\($1".CII<T5R
M<F]R*"1R97,I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@
M('T*"B`@("`@("`@)')E<W5L=',@/2!A<G)A>2@I.PH@("`@("`@('=H:6QE
M("A$0E]/2R`]/3T@)')E<RT^9F5T8VA);G1O*"1R;W<L("1F971C:&UO9&4I
M*2!["B`@("`@("`@("`@(&EF("@D9F5T8VAM;V1E("8@1$)?1D540TA-3T1%
M7T9,25!0140I('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R;W<@87,@
M)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("`@("`@)')E<W5L='-;
M)&ME>5U;72`]("1V86P["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D<F5S=6QT<UM=(#T@)')O=SL*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)')E<RT^9G)E92@I
M.PH*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')O=RDI('L*("`@("`@("`@
M("`@)'1M<"`])B`D=&AI<RT^<F%I<V5%<G)O<B@D<F]W*3L*("`@("`@("`@
M("`@<F5T=7)N("1T;7`["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S
M=6QT<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!A=71O0V]M;6ET
M*"D*"B`@("`O*BH*("`@("`J($5N86)L97,@;W(@9&ES86)L97,@875T;VUA
M=&EC(&-O;6UI=',*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;"`D;VYO9F8@
M('1R=64@='5R;G,@:70@;VXL(&9A;'-E('1U<FYS(&ET(&]F9@H@("`@("H*
M("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%
M<G)O<B!O8FIE8W0@:68@=&AE(&1R:79E<@H@("`@("H@("`@("`@("`@("`@
M("!D;V5S;B=T('-U<'!O<G0@875T;RUC;VUM:71T:6YG('1R86YS86-T:6]N
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@875T;T-O;6UI="@D;VYO9F8@/2!F
M86QS92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M1$)?15)23U)?3D]47T-!4$%"3$4I.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&-O;6UI="@I"@H@("`@+RHJ"B`@("`@*B!#;VUM:71S('1H92!C
M=7)R96YT('1R86YS86-T:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@
M($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VUM:70H*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?0T%0
M04),12D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<F]L;&)A8VLH
M*0H*("`@("\J*@H@("`@("H@4F5V97)T<R!T:&4@8W5R<F5N="!T<F%N<V%C
M=&EO;@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C
M97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F]L;&)A8VLH*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?0T%004),12D["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;G5M4F]W<R@I"@H@("`@+RHJ"B`@
M("`@*B!$971E<FUI;F5S('1H92!N=6UB97(@;V8@<F]W<R!I;B!A('%U97)Y
M(')E<W5L=`H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT
M("!T:&4@<75E<GD@<F5S=6QT(&ED96YI9FEE<B!P<F]D=6-E9"!B>2!02%`*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!R;W=S
M+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@;G5M4F]W<R@D<F5S=6QT*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?0T%004),12D["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@869F96-T9612;W=S*"D*"B`@
M("`O*BH*("`@("`J($1E=&5R;6EN97,@=&AE(&YU;6)E<B!O9B!R;W=S(&%F
M9F5C=&5D(&)Y(&$@9&%T82!M86YI=7!L871I;VX@<75E<GD*("`@("`J"B`@
M("`@*B`P(&ES(')E='5R;F5D(&9O<B!Q=65R:65S('1H870@9&]N)W0@;6%N
M:7!U;&%T92!D871A+@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@
M;G5M8F5R(&]F(')O=W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9F9E8W1E9%)O=W,H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?
M0T%004),12D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T4V5Q
M=65N8V5.86UE*"D*"B`@("`O*BH*("`@("`J($=E;F5R871E<R!T:&4@;F%M
M92!U<V5D(&EN<VED92!T:&4@9&%T86)A<V4@9F]R(&$@<V5Q=65N8V4*("`@
M("`J"B`@("`@*B!4:&4@8W)E871E4V5Q=65N8V4H*2!D;V-B;&]C:R!C;VYT
M86EN<R!N;W1E<R!A8F]U="!S=&]R:6YG('-E<75E;F-E"B`@("`@*B!N86UE
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S<6X@('1H92!S97%U
M96YC92=S('!U8FQI8R!N86UE"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@('1H92!S97%U96YC92=S(&YA;64@:6X@=&AE(&)A8VME;F0*("`@("`J
M"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("H@0'-E92!$0E]C;VUM
M;VXZ.F-R96%T95-E<75E;F-E*"DL($1"7V-O;6UO;CHZ9')O<%-E<75E;F-E
M*"DL"B`@("`@*B`@("`@($1"7V-O;6UO;CHZ;F5X=$E$*"DL($1"7V-O;6UO
M;CHZ<V5T3W!T:6]N*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4V5Q=65N
M8V5.86UE*"1S<6XI"B`@("!["B`@("`@("`@<F5T=7)N('-P<FEN=&8H)'1H
M:7,M/F=E=$]P=&EO;B@G<V5Q;F%M95]F;W)M870G*2P*("`@("`@("`@("`@
M("`@("`@("`@("!P<F5G7W)E<&QA8V4H)R];7F$M>C`M.5\N72]I)RP@)U\G
M+"`D<W%N*2D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;F5X=$ED
M*"D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&YE>'0@9G)E92!I9"!I
M;B!A('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-E
M<5]N86UE("!N86UE(&]F('1H92!S97%U96YC90H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)&]N9&5M86YD("!W:&5N('1R=64L('1H92!S97%E;F-E(&ES(&%U
M=&]M871I8V%L;'D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&-R96%T960@:68@:70@9&]E<R!N;W0@97AI<W0*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&EN="`@=&AE(&YE>'0@:60@;G5M8F5R(&EN('1H92!S97%U96YC
M92X*("`@("`J("`@("`@("`@("`@("`@02!$0E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ8W)E871E
M4V5Q=65N8V4H*2P@1$)?8V]M;6]N.CID<F]P4V5Q=65N8V4H*2P*("`@("`J
M("`@("`@1$)?8V]M;6]N.CIG971397%U96YC94YA;64H*0H@("`@("HO"B`@
M("!F=6YC=&EO;B!N97AT260H)'-E<5]N86UE+"`D;VYD96UA;F0@/2!T<G5E
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%
M4E)/4E].3U1?0T%004),12D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@8W)E871E4V5Q=65N8V4H*0H*("`@("\J*@H@("`@("H@0W)E871E<R!A
M(&YE=R!S97%U96YC90H@("`@("H*("`@("`J(%1H92!N86UE(&]F(&$@9VEV
M96X@<V5Q=65N8V4@:7,@9&5T97)M:6YE9"!B>2!P87-S:6YG('1H92!S=')I
M;F<*("`@("`J('!R;W9I9&5D(&EN('1H92`\=F%R/B1S97%?;F%M93PO=F%R
M/B!A<F=U;65N="!T:')O=6=H(%!(4"=S('-P<FEN=&8H*0H@("`@("H@9G5N
M8W1I;VX@=7-I;F<@=&AE('9A;'5E(&9R;VT@=&AE(#QV87(^<V5Q;F%M95]F
M;W)M870\+W9A<CX@;W!T:6]N(&%S"B`@("`@*B!T:&4@<W!R:6YT9B@I)W,@
M9F]R;6%T(&%R9W5M96YT+@H@("`@("H*("`@("`J(#QV87(^<V5Q;F%M95]F
M;W)M870\+W9A<CX@:7,@<V5T('9I82!S971/<'1I;VXH*2X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1S97%?;F%M92`@;F%M92!O9B!T:&4@;F5W
M('-E<75E;F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N
M('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("H*("`@("`J($!S964@1$)?8V]M;6]N.CID<F]P4V5Q=65N8V4H*2P@1$)?
M8V]M;6]N.CIG971397%U96YC94YA;64H*2P*("`@("`J("`@("`@1$)?8V]M
M;6]N.CIN97AT240H*0H@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A=&5397%U
M96YC92@D<V5Q7VYA;64I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*$1"7T524D]27TY/5%]#05!!0DQ%*3L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!D<F]P4V5Q=65N8V4H*0H*("`@("\J*@H@("`@
M("H@1&5L971E<R!A('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E;F-E('1O(&)E(&1E
M;&5T960*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C
M8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@
M("`@("H@0'-E92!$0E]C;VUM;VXZ.F-R96%T95-E<75E;F-E*"DL($1"7V-O
M;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@*B`@("`@($1"7V-O;6UO
M;CHZ;F5X=$E$*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9')O<%-E<75E;F-E
M*"1S97%?;F%M92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H1$)?15)23U)?3D]47T-!4$%"3$4I.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(')A:7-E17)R;W(H*0H*("`@("\J*@H@("`@("H@0V]M
M;75N:6-A=&5S(&%N(&5R<F]R(&%N9"!I;G9O:V4@97)R;W(@8V%L;&)A8VMS
M+"!E=&,*("`@("`J"B`@("`@*B!"87-I8V%L;'D@82!W<F%P<&5R(&9O<B!0
M14%2.CIR86ES945R<F]R('=I=&AO=70@=&AE(&UE<W-A9V4@<W1R:6YG+@H@
M("`@("H*("`@("`J($!P87)A;2!M:7AE9"`@(&EN=&5G97(@97)R;W(@8V]D
M92P@;W(@82!014%2(&5R<F]R(&]B:F5C="`H86QL"B`@("`@*B`@("`@("`@
M("`@("`@("`@;W1H97(@<&%R86UE=&5R<R!A<F4@:6=N;W)E9"!I9B!T:&ES
M('!A<F%M971E<B!I<PH@("`@("H@("`@("`@("`@("`@("`@(&%N(&]B:F5C
M=`H@("`@("H@0'!A<F%M(&EN="`@("`@97)R;W(@;6]D92P@<V5E(%!%05)?
M17)R;W(@9&]C<PH@("`@("H@0'!A<F%M(&UI>&5D("`@:68@97)R;W(@;6]D
M92!I<R!014%27T524D]27U1224='15(L('1H:7,@:7,@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("`@97)R;W(@;&5V96P@*$5?55-%4E].3U1)0T4@971C
M*2X@($EF(&5R<F]R(&UO9&4@:7,*("`@("`J("`@("`@("`@("`@("`@("!0
M14%27T524D]27T-!3$Q"04-++"!T:&ES(&ES('1H92!C86QL8F%C:R!F=6YC
M=&EO;BP*("`@("`J("`@("`@("`@("`@("`@("!E:71H97(@87,@82!F=6YC
M=&EO;B!N86UE+"!O<B!A<R!A;B!A<G)A>2!O9B!A;@H@("`@("H@("`@("`@
M("`@("`@("`@(&]B:F5C="!A;F0@;65T:&]D(&YA;64N("!&;W(@;W1H97(@
M97)R;W(@;6]D97,@=&AI<PH@("`@("H@("`@("`@("`@("`@("`@('!A<F%M
M971E<B!I<R!I9VYO<F5D+@H@("`@("H@0'!A<F%M('-T<FEN9R`@97AT<F$@
M9&5B=6<@:6YF;W)M871I;VXN("!$969A=6QT<R!T;R!T:&4@;&%S=`H@("`@
M("H@("`@("`@("`@("`@("`@('%U97)Y(&%N9"!N871I=F4@97)R;W(@8V]D
M92X*("`@("`J($!P87)A;2!M:7AE9"`@(&YA=&EV92!E<G)O<B!C;V1E+"!I
M;G1E9V5R(&]R('-T<FEN9R!D97!E;F1I;F<@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("`@8F%C:V5N9`H@("`@("H*("`@("`J($!R971U<FX@;V)J96-T
M("!T:&4@4$5!4E]%<G)O<B!O8FIE8W0*("`@("`J"B`@("`@*B!`<V5E(%!%
M05)?17)R;W(*("`@("`J+PH@("`@9G5N8W1I;VX@)G)A:7-E17)R;W(H)&-O
M9&4@/2!$0E]%4E)/4BP@)&UO9&4@/2!N=6QL+"`D;W!T:6]N<R`](&YU;&PL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`D=7-E<FEN9F\@/2!N=6QL+"`D
M;F%T:79E8V]D92`](&YU;&PI"B`@("!["B`@("`@("`@+R\@5&AE(&5R<F]R
M(&ES('EE="!A($1"(&5R<F]R(&]B:F5C=`H@("`@("`@(&EF("AI<U]O8FIE
M8W0H)&-O9&4I*2!["B`@("`@("`@("`@("\O(&)E8V%U<V4@=V4@=&AE('-T
M871I8R!014%2.CIR86ES945R<F]R+"!O=7(@9VQO8F%L"B`@("`@("`@("`@
M("\O(&AA;F1L97(@<VAO=6QD(&)E('5S960@:68@:70@:7,@<V5T"B`@("`@
M("`@("`@(&EF("@D;6]D92`]/3T@;G5L;"`F)B`A96UP='DH)'1H:7,M/E]D
M969A=6QT7V5R<F]R7VUO9&4I*2!["B`@("`@("`@("`@("`@("`D;6]D92`@
M("`]("1T:&ES+3Y?9&5F875L=%]E<G)O<E]M;V1E.PH@("`@("`@("`@("`@
M("`@)&]P=&EO;G,@/2`D=&AI<RT^7V1E9F%U;'1?97)R;W)?;W!T:6]N<SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&UP(#T@4$5!4CHZ<F%I<V5%
M<G)O<B@D8V]D92P@;G5L;"P@)&UO9&4L("1O<'1I;VYS+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL+"!T<G5E*3L*
M("`@("`@("`@("`@<F5T=7)N("1T;7`["B`@("`@("`@?0H*("`@("`@("!I
M9B`H)'5S97)I;F9O(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1U<V5R:6YF
M;R`]("1T:&ES+3YL87-T7W%U97)Y.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"1N871I=F5C;V1E*2!["B`@("`@("`@("`@("1U<V5R:6YF;R`N/2`G(%MN
M871I=F5C;V1E/2<@+B!T<FEM*"1N871I=F5C;V1E*2`N("==)SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=7-E<FEN9F\@+CT@)R!;1$(@17)R
M;W(Z("<@+B!$0CHZ97)R;W)-97-S86=E*"1C;V1E*2`N("==)SL*("`@("`@
M("!]"@H@("`@("`@("1T;7`@/2!014%2.CIR86ES945R<F]R*&YU;&PL("1C
M;V1E+"`D;6]D92P@)&]P=&EO;G,L("1U<V5R:6YF;RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G1$)?17)R;W(G+"!T<G5E*3L*("`@("`@
M("!R971U<FX@)'1M<#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E
M<G)O<DYA=&EV92@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!$0DU3)R!N
M871I=F4@97)R;W(@8V]D92!P<F]D=6-E9"!B>2!T:&4@;&%S="!Q=65R>0H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@('1H92!$0DU3)R!E<G)O<B!C
M;V1E+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@97)R;W).871I=F4H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?0T%004),12D["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97)R;W)#;V1E*"D*"B`@("`O
M*BH*("`@("`J($UA<',@;F%T:79E(&5R<F]R(&-O9&5S('1O($1")W,@<&]R
M=&%B;&4@;VYE<PH@("`@("H*("`@("`J(%5S97,@=&AE(#QV87(^)&5R<F]R
M8V]D95]M87`\+W9A<CX@<')O<&5R='D@9&5F:6YE9"!I;B!E86-H(&1R:79E
M<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG?&EN="`D;F%T:79E8V]D
M92`@=&AE(&5R<F]R(&-O9&4@<F5T=7)N960@8GD@=&AE($1"35,*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE('!O<G1A8FQE($1"(&5R<F]R(&-O
M9&4N("!2971U<FX@1$)?15)23U(@:68@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@(&-U<G)E;G0@9')I=F5R(&1O97-N)W0@:&%V92!A(&UA<'!I;F<@9F]R
M('1H90H@("`@("H@("`@("`@("`@("`@("`D;F%T:79E8V]D92!S=6)M:71T
M960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R0V]D92@D;F%T:79E8V]D
M92D*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F5R<F]R8V]D95]M
M87!;)&YA=&EV96-O9&5=*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/F5R<F]R8V]D95]M87!;)&YA=&EV96-O9&5=.PH@("`@("`@('T*("`@("`@
M("`O+R!&86QL(&)A8VL@=&\@1$)?15)23U(@:68@=&AE<F4@=V%S(&YO(&UA
M<'!I;F<N"B`@("`@("`@<F5T=7)N($1"7T524D]2.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&5R<F]R365S<V%G92@I"@H@("`@+RHJ"B`@("`@
M*B!-87!S(&$@1$(@97)R;W(@8V]D92!T;R!A('1E>'1U86P@;65S<V%G90H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1D8F-O9&4@('1H92!$0B!E
M<G)O<B!C;V1E"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!E
M<G)O<B!M97-S86=E(&-O<G)E<W!O;F1I;F<@=&\@=&AE(&5R<F]R(&-O9&4*
M("`@("`J("`@("`@("`@("`@("`@("`@<W5B;6ET=&5D+B`@1D%,4T4@:68@
M=&AE(&5R<F]R(&-O9&4@:7,@=6YK;F]W;BX*("`@("`J"B`@("`@*B!`<V5E
M($1".CIE<G)O<DUE<W-A9V4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!E<G)O
M<DUE<W-A9V4H)&1B8V]D92D*("`@('L*("`@("`@("!R971U<FX@1$(Z.F5R
M<F]R365S<V%G92@D=&AI<RT^97)R;W)C;V1E7VUA<%LD9&)C;V1E72D["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@=&%B;&5);F9O*"D*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@:6YF;W)M871I;VX@86)O=70@82!T86)L92!O
M<B!A(')E<W5L="!S970*("`@("`J"B`@("`@*B!4:&4@9F]R;6%T(&]F('1H
M92!R97-U;'1I;F<@87)R87D@9&5P96YD<R!O;B!W:&EC:"`\=F%R/B1M;V1E
M/"]V87(^"B`@("`@*B!Y;W4@<V5L96-T+B`@5&AE('-A;7!L92!O=71P=70@
M8F5L;W<@:7,@8F%S960@;VX@=&AI<R!Q=65R>3H*("`@("`J(#QP<F4^"B`@
M("`@*B`@("!314Q%0U0@=&)L1F]O+F9L9$E$+"!T8FQ&;V\N9FQD4&AO;F4L
M('1B;$)A<BYF;&1)9`H@("`@("H@("`@1E)/32!T8FQ&;V\*("`@("`J("`@
M($I/24X@=&)L0F%R($].('1B;$9O;RYF;&1)9"`]('1B;$)A<BYF;&1)9`H@
M("`@("H@/"]P<F4^"B`@("`@*@H@("`@("H@/'5L/@H@("`@("H@/&QI/@H@
M("`@("H*("`@("`J(#QK8F0^;G5L;#PO:V)D/B`H9&5F875L="D*("`@("`J
M("`@/'!R93X*("`@("`J("`@6S!=(#T^($%R<F%Y("@*("`@("`J("`@("`@
M(%MT86)L95T@/3X@=&)L1F]O"B`@("`@*B`@("`@("!;;F%M95T@/3X@9FQD
M260*("`@("`J("`@("`@(%MT>7!E72`]/B!I;G0*("`@("`J("`@("`@(%ML
M96Y=(#T^(#$Q"B`@("`@*B`@("`@("!;9FQA9W-=(#T^('!R:6UA<GE?:V5Y
M(&YO=%]N=6QL"B`@("`@*B`@("D*("`@("`J("`@6S%=(#T^($%R<F%Y("@*
M("`@("`J("`@("`@(%MT86)L95T@/3X@=&)L1F]O"B`@("`@*B`@("`@("!;
M;F%M95T@/3X@9FQD4&AO;F4*("`@("`J("`@("`@(%MT>7!E72`]/B!S=')I
M;F<*("`@("`J("`@("`@(%ML96Y=(#T^(#(P"B`@("`@*B`@("`@("!;9FQA
M9W-=(#T^"B`@("`@*B`@("D*("`@("`J("`@6S)=(#T^($%R<F%Y("@*("`@
M("`J("`@("`@(%MT86)L95T@/3X@=&)L0F%R"B`@("`@*B`@("`@("!;;F%M
M95T@/3X@9FQD260*("`@("`J("`@("`@(%MT>7!E72`]/B!I;G0*("`@("`J
M("`@("`@(%ML96Y=(#T^(#$Q"B`@("`@*B`@("`@("!;9FQA9W-=(#T^('!R
M:6UA<GE?:V5Y(&YO=%]N=6QL"B`@("`@*B`@("D*("`@("`J("`@/"]P<F4^
M"B`@("`@*@H@("`@("H@/"]L:3X\;&D^"B`@("`@*@H@("`@("H@/&MB9#Y$
M0E]404),14E.1D]?3U)$15(\+VMB9#X*("`@("`J"B`@("`@*B`@(#QP/DEN
M(&%D9&ET:6]N('1O('1H92!I;F9O<FUA=&EO;B!F;W5N9"!I;B!T:&4@9&5F
M875L="!O=71P=70L"B`@("`@*B`@(&$@;F]T871I;VX@;V8@=&AE(&YU;6)E
M<B!O9B!C;VQU;6YS(&ES('!R;W9I9&5D(&)Y('1H90H@("`@("H@("`\<V%M
M<#YN=6U?9FEE;&1S/"]S86UP/B!E;&5M96YT('=H:6QE('1H92`\<V%M<#YO
M<F1E<CPO<V%M<#X*("`@("`J("`@96QE;65N="!P<F]V:61E<R!A;B!A<G)A
M>2!W:71H('1H92!C;VQU;6X@;F%M97,@87,@=&AE(&ME>7,@86YD"B`@("`@
M*B`@('1H96ER(&QO8V%T:6]N(&EN9&5X(&YU;6)E<B`H8V]R<F5S<&]N9&EN
M9R!T;R!T:&4@:V5Y<R!I;B!T:&4*("`@("`J("`@=&AE(&1E9F%U;'0@;W5T
M<'5T*2!A<R!T:&4@=F%L=65S+CPO<#X*("`@("`J"B`@("`@*B`@(#QP/DEF
M(&$@<F5S=6QT('-E="!H87,@:61E;G1I8V%L(&9I96QD(&YA;65S+"!T:&4@
M;&%S="!O;F4@:7,*("`@("`J("`@=7-E9"X\+W`^"B`@("`@*@H@("`@("H@
M("`\<')E/@H@("`@("H@("!;;G5M7V9I96QD<UT@/3X@,PH@("`@("H@("!;
M;W)D97)=(#T^($%R<F%Y("@*("`@("`J("`@("`@(%MF;&1)9%T@/3X@,@H@
M("`@("H@("`@("`@6V9L9%1R86YS72`]/B`Q"B`@("`@*B`@("D*("`@("`J
M("`@/"]P<F4^"B`@("`@*@H@("`@("H@/"]L:3X\;&D^"B`@("`@*@H@("`@
M("H@/&MB9#Y$0E]404),14E.1D]?3U)$15)404),13PO:V)D/@H@("`@("H*
M("`@("`J("`@/'`^4VEM:6QA<B!T;R`\:V)D/D1"7U1!0DQ%24Y&3U]/4D1%
M4CPO:V)D/B!B=70@861D<R!M;W)E"B`@("`@*B`@(&1I;65N<VEO;G,@=&\@
M=&AE(&%R<F%Y(&EN('=H:6-H('1H92!T86)L92!N86UE<R!A<F4@:V5Y<R!A
M;F0*("`@("`J("`@=&AE(&9I96QD(&YA;65S(&%R92!S=6(M:V5Y<RX@(%1H
M:7,@:7,@:&5L<&9U;"!F;W(@<75E<FEE<R!T:&%T"B`@("`@*B`@(&IO:6X@
M=&%B;&5S('=H:6-H(&AA=F4@:61E;G1I8V%L(&9I96QD(&YA;65S+CPO<#X*
M("`@("`J"B`@("`@*B`@(#QP<F4^"B`@("`@*B`@(%MN=6U?9FEE;&1S72`]
M/B`S"B`@("`@*B`@(%MO<F1E<G1A8FQE72`]/B!!<G)A>2`H"B`@("`@*B`@
M("`@("!;=&)L1F]O72`]/B!!<G)A>2`H"B`@("`@*B`@("`@("`@("`@6V9L
M9$ED72`]/B`P"B`@("`@*B`@("`@("`@("`@6V9L9%!H;VYE72`]/B`Q"B`@
M("`@*B`@("`@("`I"B`@("`@*B`@("`@("!;=&)L0F%R72`]/B!!<G)A>2`H
M"B`@("`@*B`@("`@("`@("`@6V9L9$ED72`]/B`R"B`@("`@*B`@("`@("`I
M"B`@("`@*B`@("D*("`@("`J("`@/"]P<F4^"B`@("`@*@H@("`@("H@/"]L
M:3X*("`@("`J(#PO=6P^"B`@("`@*@H@("`@("H@5&AE(#QS86UP/F9L86=S
M/"]S86UP/B!E;&5M96YT(&-O;G1A:6YS(&$@<W!A8V4@<V5P87)A=&5D(&QI
M<W0*("`@("`J(&]F(&5X=')A(&EN9F]R;6%T:6]N(&%B;W5T('1H92!F:65L
M9"X@(%1H:7,@9&%T82!I<R!I;F-O;G-I<W1E;G0*("`@("`J(&)E='=E96X@
M1$)-4R=S(&1U92!T;R!T:&4@=V%Y(&5A8V@@1$)-4R!W;W)K<RX*("`@("`J
M("`@*R`\<V%M<#YP<FEM87)Y7VME>3PO<V%M<#X*("`@("`J("`@*R`\<V%M
M<#YU;FEQ=65?:V5Y/"]S86UP/@H@("`@("H@("`K(#QS86UP/FUU;'1I<&QE
M7VME>3PO<V%M<#X*("`@("`J("`@*R`\<V%M<#YN;W1?;G5L;#PO<V%M<#X*
M("`@("`J"B`@("`@*B!-;W-T($1"35,G<R!O;FQY('!R;W9I9&4@=&AE(#QS
M86UP/G1A8FQE/"]S86UP/B!A;F0@/'-A;7`^9FQA9W,\+W-A;7`^"B`@("`@
M*B!E;&5M96YT<R!I9B`\=F%R/B1R97-U;'0\+W9A<CX@:7,@82!T86)L92!N
M86UE+B`@5&AE(&9O;&QO=VEN9R!$0DU3)W,*("`@("`J('!R;W9I9&4@9G5L
M;"!I;F9O<FUA=&EO;B!F<F]M('%U97)I97,Z"B`@("`@*B`@("L@9F)S<6P*
M("`@("`J("`@*R!M>7-Q;`H@("`@("H*("`@("`J($EF('1H92`G<&]R=&%B
M:6QI='DG(&]P=&EO;B!H87,@/'-A;7`^1$)?4$]25$%"24Q)5%E?3$]715)#
M05-%/"]S86UP/@H@("`@("H@='5R;F5D(&]N+"!T:&4@;F%M97,@;V8@=&%B
M;&5S(&%N9"!F:65L9',@=VEL;"!B92!L;W=E<F-A<V5D+@H@("`@("H*("`@
M("`J($!P87)A;2!O8FIE8W1\<W1R:6YG("`D<F5S=6QT("!$0E]R97-U;'0@
M;V)J96-T(&9R;VT@82!Q=65R>2!O<B!A"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<W1R:6YG(&-O;G1A:6YI;F<@=&AE(&YA;64@
M;V8@82!T86)L92X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!7:&EL92!T:&ES(&%L<V\@86-C97!T<R!A('%U97)Y(')E<W5L=`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E<V]U<F-E
M(&ED96YT:69I97(L('1H:7,@8F5H879I;W(@:7,*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!D97!R96-A=&5D+@H@("`@("H@0'!A
M<F%M(&EN="`@)&UO9&4@("!E:71H97(@=6YU<V5D(&]R(&]N92!O9B!T:&4@
M=&%B;&5);F9O(&UO9&5S.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`\
M:V)D/D1"7U1!0DQ%24Y&3U]/4D1%4E1!0DQ%/"]K8F0^+`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`\:V)D/D1"7U1!0DQ%24Y&3U]/4D1%4CPO:V)D
M/B!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`\:V)D/D1"7U1!0DQ%
M24Y&3U]&54Q,/"]K8F0^("AW:&EC:"!D;V5S(&)O=&@I+@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("!4:&5S92!A<F4@8FET=VES92P@<V\@=&AE(&9I
M<G-T('1W;R!C86X@8F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@8V]M
M8FEN960@=7-I;F<@/&MB9#Y\/"]K8F0^+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@(&%N(&%S<V]C:6%T:79E(&%R<F%Y('=I=&@@=&AE(&EN9F]R
M;6%T:6]N(')E<75E<W1E9"X*("`@("`J("`@("`@("`@("`@("`@("!!($1"
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@
M1$)?8V]M;6]N.CIS971/<'1I;VXH*0H@("`@("HO"B`@("!F=6YC=&EO;B!T
M86)L94EN9F\H)')E<W5L="P@)&UO9&4@/2!N=6QL*0H@("`@>PH@("`@("`@
M("\J"B`@("`@("`@("H@268@=&AE($1"7SQD<FEV97(^(&-L87-S(&AA<R!A
M('1A8FQE26YF;R@I(&UE=&AO9"P@=&AA="!O;F4*("`@("`@("`@*B!O=F5R
M<FED97,@=&AI<R!O;F4N("!"=70L(&EF('1H92!D<FEV97(@9&]E<VXG="!H
M879E(&]N92P*("`@("`@("`@*B!T:&ES(&UE=&AO9"!R=6YS(&%N9"!T96QL
M<R!U<V5R<R!A8F]U="!T:&%T(&9A8W0N"B`@("`@("`@("HO"B`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27TY/5%]#05!!0DQ%
M*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G971486)L97,H*0H*
M("`@("\J*@H@("`@("H@3&ES=',@=&AE('1A8FQE<R!I;B!T:&4@8W5R<F5N
M="!D871A8F%S90H@("`@("H*("`@("`J($!R971U<FX@87)R87D@('1H92!L
M:7-T(&]F('1A8FQE<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N
M"B`@("`@*@H@("`@("H@0&1E<')E8V%T960@365T:&]D(&1E<')E8V%T960@
M<V]M92!T:6UE(&)E9F]R92!296QE87-E(#$N,@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971486)L97,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M9V5T3&ES=$]F*"=T86)L97,G*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!G971,:7-T3V8H*0H*("`@("\J*@H@("`@("H@3&ES=',@:6YT97)N
M86P@9&%T86)A<V4@:6YF;W)M871I;VX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1T>7!E("!T>7!E(&]F(&EN9F]R;6%T:6]N(&)E:6YG('-O=6=H
M="X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!#;VUM;VX@:71E;7,@
M8F5I;F<@<V]U9VAT(&%R93H*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!T86)L97,L(&1A=&%B87-E<RP@=7-E<G,L('9I97=S+"!F=6YC=&EO;G,*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!%86-H($1"35,G<R!H87,@
M:71S(&]W;B!C87!A8FEL:71I97,N"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@86X@87)R87D@;&ES=&EN9R!T:&4@:71E;7,@<V]U9VAT+@H@("`@
M("H@("`@("`@("`@("`@("`@($$@1$(@1$)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$QI<W1/9B@D='EP92D*
M("`@('L*("`@("`@("`D<W%L(#T@)'1H:7,M/F=E=%-P96-I86Q1=65R>2@D
M='EP92D["B`@("`@("`@:68@*"1S<6P@/3T](&YU;&PI('L*("`@("`@("`@
M("`@)'1H:7,M/FQA<W1?<75E<GD@/2`G)SL*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27U5.4U504$]25$5$*3L*("`@
M("`@("!](&5L<V5I9B`H:7-?:6YT*"1S<6PI('Q\($1".CII<T5R<F]R*"1S
M<6PI*2!["B`@("`@("`@("`@("\O(%!R979I;W5S(&5R<F]R"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<W%L*3L*("`@("`@("!]
M(&5L<V5I9B`H:7-?87)R87DH)'-Q;"DI('L*("`@("`@("`@("`@+R\@06QR
M96%D>2!T:&4@<F5S=6QT"B`@("`@("`@("`@(')E='5R;B`D<W%L.PH@("`@
M("`@('T*("`@("`@("`O+R!,875N8V@@=&AI<R!Q=65R>0H@("`@("`@(')E
M='5R;B`D=&AI<RT^9V5T0V]L*"1S<6PI.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&=E=%-P96-I86Q1=65R>2@I"@H@("`@+RHJ"B`@("`@*B!/
M8G1A:6YS('1H92!Q=65R>2!S=')I;F<@;F5E9&5D(&9O<B!L:7-T:6YG(&$@
M9VEV96X@='EP92!O9B!O8FIE8W1S"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D='EP92`@=&AE(&MI;F0@;V8@;V)J96-T<R!Y;W4@=V%N="!T;R!R
M971R:65V90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@4U%,
M('%U97)Y('-T<FEN9R!O<B!N=6QL(&EF('1H92!D<FEV97(@9&]E<VXG=`H@
M("`@("H@("`@("`@("`@("`@("`@("!S=7!P;W)T('1H92!O8FIE8W0@='EP
M92!R97%U97-T960*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@
M("`@("H@0'-E92!$0E]C;VUM;VXZ.F=E=$QI<W1/9B@I"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%-P96-I86Q1=65R>2@D='EP92D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?54Y355!03U)4
M140I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(%]R=')I;4%R<F%Y
M5F%L=65S*"D*"B`@("`O*BH*("`@("`J(%)I9VAT+71R:6US(&%L;"!S=')I
M;F=S(&EN(&%N(&%R<F%Y"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1A
M<G)A>2`@=&AE(&%R<F%Y('1O(&)E('1R:6UM960@*'!A<W-E9"!B>2!R969E
M<F5N8V4I"B`@("`@*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J+PH@("`@9G5N8W1I;VX@7W)T
M<FEM07)R87E686QU97,H)B1A<G)A>2D*("`@('L*("`@("`@("!F;W)E86-H
M("@D87)R87D@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@:68@
M*&ES7W-T<FEN9R@D=F%L=64I*2!["B`@("`@("`@("`@("`@("`D87)R87E;
M)&ME>5T@/2!R=')I;2@D=F%L=64I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(%]C;VYV97)T3G5L;$%R
M<F%Y5F%L=65S5&]%;7!T>2@I"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T<R!A
M;&P@;G5L;"!V86QU97,@:6X@86X@87)R87D@=&\@96UP='D@<W1R:6YG<PH@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@)&%R<F%Y("!T:&4@87)R87D@
M=&\@8F4@9&4M;G5L;&EF:65D("AP87-S960@8GD@<F5F97)E;F-E*0H@("`@
M("H*("`@("`J($!R971U<FX@=F]I9`H@("`@("H*("`@("`J($!A8V-E<W,@
M<')O=&5C=&5D"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYV97)T3G5L;$%R
M<F%Y5F%L=65S5&]%;7!T>2@F)&%R<F%Y*0H@("`@>PH@("`@("`@(&9O<F5A
M8V@@*"1A<G)A>2!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("!I
M9B`H:7-?;G5L;"@D=F%L=64I*2!["B`@("`@("`@("`@("`@("`D87)R87E;
M)&ME>5T@/2`G)SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@
M("`O+R!]?7T*?0H*+RH*("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M=VED
M=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z(#0*("H@16YD.@H@*B\*"C\^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T1"+V1B87-E+G!H<```
M````````````````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,V-C`Q
M`#$P-3$U-#,S-S,W`#`R,#8W,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H*+RH@=FEM.B!S970@97AP86YD=&%B
M('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J
M*@H@*B!4:&4@4$5!4B!$0B!D<FEV97(@9F]R(%!(4"=S(&1B87-E(&5X=&5N
M<VEO;@H@*B!F;W(@:6YT97)A8W1I;F<@=VET:"!D0F%S92!D871A8F%S97,*
M("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H
M92!02%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@
M87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A
M<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A
M;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R
M>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@
M(%1O;6%S(%8N5BX@0V]X(#QC;WA`:61E8VYE="YC;VT^"B`J($!A=71H;W(@
M("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@
M("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI
M8V5N<V4@,RXP"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!D8F%S92YP:'`L
M=B`Q+C,Y(#(P,#4O,#(O,3D@,C,Z,C4Z,C4@9&%N:65L8R!%>'`@)`H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO
M"@HO*BH*("H@3V)T86EN('1H92!$0E]C;VUM;VX@8VQA<W,@<V\@:70@8V%N
M(&)E(&5X=&5N9&5D(&9R;VT*("HO"G)E<75I<F5?;VYC92`G1$(O8V]M;6]N
M+G!H<"<["@HO*BH*("H@5&AE(&UE=&AO9',@4$5!4B!$0B!U<V5S('1O(&EN
M=&5R86-T('=I=&@@4$A0)W,@9&)A<V4@97AT96YS:6]N"B`J(&9O<B!I;G1E
M<F%C=&EN9R!W:71H(&1"87-E(&1A=&%B87-E<PH@*@H@*B!4:&5S92!M971H
M;V1S(&]V97)L;V%D('1H92!O;F5S(&1E8VQA<F5D(&EN($1"7V-O;6UO;BX*
M("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*
M("H@0&%U=&AO<B`@("`@5&]M87,@5BY6+B!#;W@@/&-O>$!I9&5C;F5T+F-O
M;3X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P
M:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U
M<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@4F5L96%S
M93H@,2XW+C8*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+T1""B`J+PIC;&%S<R!$0E]D8F%S92!E>'1E;F1S($1"7V-O;6UO
M;@I["B`@("`O+R![>WL@<')O<&5R=&EE<PH*("`@("\J*@H@("`@("H@5&AE
M($1"(&1R:79E<B!T>7!E("AM>7-Q;"P@;V-I."P@;V1B8RP@971C+BD*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<&AP='EP92`]("=D
M8F%S92<["@H@("`@+RHJ"B`@("`@*B!4:&4@9&%T86)A<V4@<WEN=&%X('9A
M<FEA;G0@=&\@8F4@=7-E9"`H9&(R+"!A8V-E<W,L(&5T8RXI+"!I9B!A;GD*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D9&)S>6YT87@@
M/2`G9&)A<V4G.PH*("`@("\J*@H@("`@("H@5&AE(&-A<&%B:6QI=&EE<R!O
M9B!T:&ES($1"(&EM<&QE;65N=&%T:6]N"B`@("`@*@H@("`@("H@5&AE("=N
M97=?;&EN:R<@96QE;65N="!C;VYT86EN<R!T:&4@4$A0('9E<G-I;VX@=&AA
M="!F:7)S="!P<F]V:61E9`H@("`@("H@;F5W7VQI;FL@<W5P<&]R="!F;W(@
M=&AI<R!$0DU3+B`@0V]N=&%I;G,@9F%L<V4@:68@:70G<R!U;G-U<'!O<G1E
M9"X*("`@("`J"B`@("`@*B!-96%N:6YG(&]F('1H92`G;&EM:70G(&5L96UE
M;G0Z"B`@("`@*B`@("L@)V5M=6QA=&4G(#T@96UU;&%T92!W:71H(&9E=&-H
M(')O=R!B>2!N=6UB97(*("`@("`J("`@*R`G86QT97(G("`@/2!A;'1E<B!T
M:&4@<75E<GD*("`@("`J("`@*R!F86QS92`@("`@/2!S:VEP(')O=W,*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D9F5A='5R
M97,@/2!A<G)A>2@*("`@("`@("`G;&EM:70G("`@("`@("`@/3X@9F%L<V4L
M"B`@("`@("`@)VYE=U]L:6YK)R`@("`@(#T^(&9A;'-E+`H@("`@("`@("=N
M=6UR;W=S)R`@("`@("`]/B!T<G5E+`H@("`@("`@("=P8V]N;F5C="<@("`@
M("`]/B!F86QS92P*("`@("`@("`G<')E<&%R92<@("`@("`@/3X@9F%L<V4L
M"B`@("`@("`@)W-S;"<@("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=T
M<F%N<V%C=&EO;G,G("`]/B!F86QS92P*("`@("D["@H@("`@+RHJ"B`@("`@
M*B!!(&UA<'!I;F<@;V8@;F%T:79E(&5R<F]R(&-O9&5S('1O($1"(&5R<F]R
M(&-O9&5S"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D97)R
M;W)C;V1E7VUA<"`](&%R<F%Y*`H@("`@*3L*"B`@("`O*BH*("`@("`J(%1H
M92!R87<@9&%T86)A<V4@8V]N;F5C=&EO;B!C<F5A=&5D(&)Y(%!(4`H@("`@
M("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@)&-O;FYE8W1I;VX[
M"@H@("`@+RHJ"B`@("`@*B!4:&4@1%-.(&EN9F]R;6%T:6]N(&9O<B!C;VYN
M96-T:6YG('1O(&$@9&%T86)A<V4*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1D<VX@/2!A<G)A>2@I.PH*"B`@("`O*BH*("`@("`J($$@
M;65A;G,@;V8@96UU;&%T:6YG(')E<W5L="!R97-O=7)C97,*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1R97-?<F]W(#T@87)R87DH*3L*
M"B`@("`O*BH*("`@("`J(%1H92!Q=6%N=&ET>2!O9B!R97-U;'1S('-O(&9A
M<@H@("`@("H*("`@("`J($9O<B!E;75L871I;F<@<F5S=6QT(')E<V]U<F-E
M<RX*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R
M("1R97-U;'0@/2`P.PH*("`@("\J*@H@("`@("H@36%P<R!D8F%S92!D871A
M('1Y<&4@:60G<R!T;R!H=6UA;B!R96%D86)L92!S=')I;F=S"B`@("`@*@H@
M("`@("H@5&AE(&AU;6%N(')E861A8FQE('9A;'5E<R!A<F4@8F%S960@;VX@
M=&AE(&]U='!U="!O9B!02%`G<PH@("`@("H@9&)A<V5?9V5T7VAE861E<E]I
M;F9O*"D@9G5N8W1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("H@0'-I;F-E(%!R;W!E<G1Y(&%V86EL86)L92!S:6YC92!296QE87-E(#$N
M-RXP"B`@("`@*B\*("`@('9A<B`D='EP97,@/2!A<G)A>2@*("`@("`@("`G
M0R<@/3X@)V-H87)A8W1E<B<L"B`@("`@("`@)T0G(#T^("=D871E)RP*("`@
M("`@("`G3"<@/3X@)V)O;VQE86XG+`H@("`@("`@("=-)R`]/B`G;65M;R<L
M"B`@("`@("`@)TXG(#T^("=N=6UB97(G+`H@("`@*3L*"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@("`O*BH*("`@("`J(%1H:7,@
M8V]N<W1R=6-T;W(@8V%L;',@/&MB9#XD=&AI<RT^1$)?8V]M;6]N*"D\+VMB
M9#X*("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N
M8W1I;VX@1$)?9&)A<V4H*0H@("`@>PH@("`@("`@("1T:&ES+3Y$0E]C;VUM
M;VXH*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYN96-T*"D*
M"B`@("`O*BH*("`@("`J($-O;FYE8W0@=&\@=&AE(&1A=&%B87-E(&%N9"!C
M<F5A=&4@:70@:68@:70@9&]E<VXG="!E>&ES=`H@("`@("H*("`@("`J($1O
M;B=T(&-A;&P@=&AI<R!M971H;V0@9&ER96-T;'DN("!5<V4@1$(Z.F-O;FYE
M8W0H*2!I;G-T96%D+@H@("`@("H*("`@("`J(%!%05(@1$(G<R!D8F%S92!D
M<FEV97(@<W5P<&]R=',@=&AE(&9O;&QO=VEN9R!E>'1R82!$4TX@;W!T:6]N
M<SH*("`@("`J("`@*R!M;V1E("`@($%N(&EN=&5G97(@<W!E8VEF>6EN9R!T
M:&4@<F5A9"]W<FET92!M;V1E('1O('5S90H@("`@("H@("`@("`@("`@("`@
M("@P(#T@<F5A9"!O;FQY+"`Q(#T@=W)I=&4@;VYL>2P@,B`](')E860O=W)I
M=&4I+@H@("`@("H@("`@("`@("`@("`@($%V86EL86)L92!S:6YC92!014%2
M($1"(#$N-RXP+@H@("`@("H@("`K(&9I96QD<R`@06X@87)R87D@;V8@87)R
M87ES('1H870@4$A0)W,@9&)A<V5?8W)E871E*"D@9G5N8W1I;VX@;F5E9',*
M("`@("`J("`@("`@("`@("`@("!T;R!C<F5A=&4@82!N97<@9&%T86)A<V4N
M("!4:&ES(&EN9F]R;6%T:6]N(&ES('5S960@:68@=&AE"B`@("`@*B`@("`@
M("`@("`@("`@9$)A<V4@9FEL92!S<&5C:69I960@:6X@=&AE(")D871A8F%S
M92(@<V5G;65N="!O9B!T:&4@1%-."B`@("`@*B`@("`@("`@("`@("`@9&]E
M<R!N;W0@97AI<W0N("!&;W(@;6]R92!I;F9O+"!S964@=&AE(%!(4"!M86YU
M86PG<PH@("`@("H@("`@("`@("`@("`@('M`;&EN:R!H='1P.B\O<&AP+FYE
M="]D8F%S95]C<F5A=&4@9&)A<V5?8W)E871E*"E]('!A9V4N"B`@("`@*B`@
M("`@("`@("`@("`@079A:6QA8FQE('-I;F-E(%!%05(@1$(@,2XW+C`N"B`@
M("`@*@H@("`@("H@17AA;7!L92!O9B!H;W<@=&\@8V]N;F5C="!A;F0@97-T
M86)L:7-H(&$@;F5W(&1"87-E(&9I;&4@:68@;F5C97-S87)Y.@H@("`@("H@
M/&-O9&4^"B`@("`@*B!R97%U:7)E7V]N8V4@)T1"+G!H<"<["B`@("`@*@H@
M("`@("H@)&1S;B`](&%R<F%Y*`H@("`@("H@("`@("=P:'!T>7!E)R`@/3X@
M)V1B87-E)RP*("`@("`J("`@("`G9&%T86)A<V4G(#T^("<O<&%T:"]A;F0O
M;F%M92]O9B]D8F%S92]F:6QE)RP*("`@("`J("`@("`G;6]D92<@("`@(#T^
M(#(L"B`@("`@*B`@("`@)V9I96QD<R<@("`]/B!A<G)A>2@*("`@("`J("`@
M("`@("`@87)R87DH)V$G+"`G3B<L(#4L(#`I+`H@("`@("H@("`@("`@("!A
M<G)A>2@G8B<L("=#)RP@-#`I+`H@("`@("H@("`@("`@("!A<G)A>2@G8R<L
M("=#)RP@,C4U*2P*("`@("`J("`@("`@("`@87)R87DH)V0G+"`G0R<L(#(P
M*2P*("`@("`J("`@("`I+`H@("`@("H@*3L*("`@("`J("1O<'1I;VYS(#T@
M87)R87DH"B`@("`@*B`@("`@)V1E8G5G)R`@("`@("`]/B`R+`H@("`@("H@
M("`@("=P;W)T86)I;&ET>2<@/3X@1$)?4$]25$%"24Q)5%E?04Q,+`H@("`@
M("H@*3L*("`@("`J"B`@("`@*B`D9&(@/28@1$(Z.F-O;FYE8W0H)&1S;BP@
M)&]P=&EO;G,I.PH@("`@("H@:68@*%!%05(Z.FES17)R;W(H)&1B*2D@>PH@
M("`@("H@("`@(&1I92@D9&(M/F=E=$UE<W-A9V4H*2D["B`@("`@*B!]"B`@
M("`@*B`\+V-O9&4^"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1D<VX@
M("`@("`@("!T:&4@9&%T82!S;W5R8V4@;F%M90H@("`@("H@0'!A<F%M(&)O
M;VP@("1P97)S:7-T96YT("!S:&]U;&0@=&AE(&-O;FYE8W1I;VX@8F4@<&5R
M<VES=&5N=#\*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@
M<W5C8V5S<RX@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@8V]N;F5C="@D9'-N+"`D<&5R<VES=&5N="`](&9A
M;'-E*0H@("`@>PH@("`@("`@(&EF("@A4$5!4CHZ;&]A9$5X=&5N<VEO;B@G
M9&)A<V4G*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H1$)?15)23U)?15A414Y324].7TY/5%]&3U5.1"D["B`@("`@("`@?0H*
M("`@("`@("`D=&AI<RT^9'-N(#T@)&1S;CL*("`@("`@("!I9B`H)&1S;ELG
M9&)S>6YT87@G72D@>PH@("`@("`@("`@("`D=&AI<RT^9&)S>6YT87@@/2`D
M9'-N6R=D8G-Y;G1A>"==.PH@("`@("`@('T*"B`@("`@("`@+RH*("`@("`@
M("`@*B!4=7)N('1R86-K7V5R<F]R<R!O;B!F;W(@96YT:7)E('-C<FEP="!S
M:6YC92`D<&AP7V5R<F]R;7-G"B`@("`@("`@("H@:7,@=&AE(&]N;'D@=V%Y
M('1O(&9I;F0@97)R;W)S(&9R;VT@=&AE(&1B87-E(&5X=&5N<VEO;BX*("`@
M("`@("`@*B\*("`@("`@("!I;FE?<V5T*"=T<F%C:U]E<G)O<G,G+"`Q*3L*
M("`@("`@("`D<&AP7V5R<F]R;7-G(#T@)R<["@H@("`@("`@(&EF("@A9FEL
M95]E>&ES=',H)&1S;ELG9&%T86)A<V4G72DI('L*("`@("`@("`@("`@)'1H
M:7,M/F1S;ELG;6]D92==(#T@,CL*("`@("`@("`@("`@:68@*&5M<'1Y*"1D
M<VY;)V9I96QD<R==*2!\?"`A:7-?87)R87DH)&1S;ELG9FEE;&1S)UTI*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?
M15)23U)?0T].3D5#5%]&04E,140L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&AE(&1B87-E(&9I
M;&4@9&]E<R!N;W0@97AI<W0@86YD("<*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`N("=I="!C;W5L9"!N;W0@8F4@8W)E871E
M9"!B96-A=7-E("<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`N("=T:&4@(F9I96QD<R(@96QE;65N="!O9B!T:&4@1%-.("<*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("=I
M<R!N;W0@<')O<&5R;'D@<V5T)RD["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!`9&)A<V5?8W)E871E*"1D<VY;)V1A
M=&%B87-E)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9'-N6R=F:65L9',G72D["B`@("`@("`@("`@(&EF("@A
M)'1H:7,M/F-O;FYE8W1I;VXI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]#3TY.14-47T9!24Q%1"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL+"!N
M=6QL+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=T:&4@9&)A<V4@9FEL92!D;V5S(&YO="!E>&ES="!A;F0@)PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)W1H
M92!A='1E;7!T('1O(&-R96%T92!I="!F86EL960Z("<*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("1P:'!?97)R;W)M<V<I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^9'-N6R=M;V1E)UTI*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^9'-N6R=M;V1E)UT@/2`P.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1T:&ES+3YC;VYN96-T:6]N(#T@0&1B87-E7V]P96XH)&1S
M;ELG9&%T86)A<V4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^9'-N6R=M;V1E)UTI.PH@("`@("`@("`@
M("!I9B`H(21T:&ES+3YC;VYN96-T:6]N*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?0T].3D5#5%]&04E,
M140L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<&AP7V5R<F]R;7-G*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@9&ES8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@*B!$
M:7-C;VYN96-T<R!F<F]M('1H92!D871A8F%S92!S97)V97(*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VP@(%12544@;VX@<W5C8V5S<RP@1D%,4T4@;VX@
M9F%I;'5R90H@("`@("HO"B`@("!F=6YC=&EO;B!D:7-C;VYN96-T*"D*("`@
M('L*("`@("`@("`D<F5T(#T@0&1B87-E7V-L;W-E*"1T:&ES+3YC;VYN96-T
M:6]N*3L*("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`](&YU;&P["B`@("`@
M("`@<F5T=7)N("1R970["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M)G%U97)Y*"D*"B`@("!F=6YC=&EO;B`F<75E<GDH)'%U97)Y(#T@;G5L;"D*
M("`@('L*("`@("`@("`O+R!E;75L871E(')E<W5L="!R97-O=7)C97,*("`@
M("`@("`D=&AI<RT^<F5S7W)O=ULH:6YT*21T:&ES+3YR97-U;'1=(#T@,#L*
M("`@("`@("`D=&UP(#TF(&YE=R!$0E]R97-U;'0H)'1H:7,L("1T:&ES+3YR
M97-U;'0K*RD["B`@("`@("`@<F5T=7)N("1T;7`["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@9F5T8VA);G1O*"D*"B`@("`O*BH*("`@("`J(%!L
M86-E<R!A(')O=R!F<F]M('1H92!R97-U;'0@<V5T(&EN=&\@=&AE(&=I=F5N
M(&%R<F%Y"B`@("`@*@H@("`@("H@1F]R;6%T:6YG(&]F('1H92!A<G)A>2!A
M;F0@=&AE(&1A=&$@=&AE<F5I;B!A<F4@8V]N9FEG=7)A8FQE+@H@("`@("H@
M4V5E($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D@9F]R(&UO<F4@:6YF;W)M871I
M;VXN"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O
M(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIF
M971C:$EN=&\H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R
M;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A
M=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S
M=6QT("`@('1H92!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J($!P87)A
M;2!A<G)A>2`@("`D87)R("`@("`@('1H92!R969E<F5N8V5D(&%R<F%Y('1O
M('!U="!T:&4@9&%T82!I;@H@("`@("H@0'!A<F%M(&EN="`@("`@("1F971C
M:&UO9&4@:&]W('1H92!R97-U;'1I;F<@87)R87D@<VAO=6QD(&)E(&EN9&5X
M960*("`@("`J($!P87)A;2!I;G0@("`@("`D<F]W;G5M("`@('1H92!R;W<@
M;G5M8F5R('1O(&9E=&-H("@P(#T@9FER<W0@<F]W*0H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@($1"7T]+(&]N('-U8V-E<W,L($Y53$P@=VAE;B!T
M:&4@96YD(&]F(&$@<F5S=6QT('-E="!I<PH@("`@("H@("`@("`@("`@("`@
M("`@(')E86-H960@;W(@;VX@9F%I;'5R90H@("`@("H*("`@("`J($!S964@
M1$)?<F5S=6QT.CIF971C:$EN=&\H*0H@("`@("HO"B`@("!F=6YC=&EO;B!F
M971C:$EN=&\H)')E<W5L="P@)B1A<G(L("1F971C:&UO9&4L("1R;W=N=6T@
M/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@D<F]W;G5M(#T]/2!N=6QL*2![
M"B`@("`@("`@("`@("1R;W=N=6T@/2`D=&AI<RT^<F5S7W)O=ULH:6YT*21R
M97-U;'1=*RL["B`@("`@("`@?0H@("`@("`@(&EF("@D9F5T8VAM;V1E("8@
M1$)?1D540TA-3T1%7T%34T]#*2!["B`@("`@("`@("`@("1A<G(@/2!`9&)A
M<V5?9V5T7W)E8V]R9%]W:71H7VYA;65S*"1T:&ES+3YC;VYN96-T:6]N+"`D
M<F]W;G5M*3L*("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T
M86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3$]715)#05-%("8F("1A<G(I
M('L*("`@("`@("`@("`@("`@("1A<G(@/2!A<G)A>5]C:&%N9V5?:V5Y7V-A
M<V4H)&%R<BP@0T%315],3U=%4BD["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D87)R(#T@0&1B87-E7V=E=%]R96-O<F0H
M)'1H:7,M/F-O;FYE8W1I;VXL("1R;W=N=6TI.PH@("`@("`@('T*("`@("`@
M("!I9B`H(21A<G(I('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@
M("`@?0H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG
M72`F($1"7U!/4E1!0DE,25197U)44DE-*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?<G1R:6U!<G)A>59A;'5E<R@D87)R*3L*("`@("`@("!]"B`@("`@("`@
M:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"
M24Q)5%E?3E5,3%]43U]%35!462D@>PH@("`@("`@("`@("`D=&AI<RT^7V-O
M;G9E<G1.=6QL07)R87E686QU97-4;T5M<'1Y*"1A<G(I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@;G5M0V]L<R@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!N=6UB
M97(@;V8@8V]L=6UN<R!I;B!A(')E<W5L="!S970*("`@("`J"B`@("`@*B!4
M:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY
M+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.FYU;4-O;',H*2!I;G-T96%D+B`@
M270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U
M<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@("H*("`@
M("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G<R!Q=65R>2!R97-U
M;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU
M;6)E<B!O9B!C;VQU;6YS+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ;G5M0V]L<R@I"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&YU;4-O;',H)&9O;RD*("`@('L*("`@("`@
M("!R971U<FX@0&1B87-E7VYU;69I96QD<R@D=&AI<RT^8V]N;F5C=&EO;BD[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;G5M4F]W<R@I"@H@("`@
M+RHJ"B`@("`@*B!'971S('1H92!N=6UB97(@;V8@<F]W<R!I;B!A(')E<W5L
M="!S970*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@
M=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z
M.FYU;5)O=W,H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R
M;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A
M=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S
M=6QT("!02%`G<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!R;W=S+B`@02!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7W)E
M<W5L=#HZ;G5M4F]W<R@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU;5)O=W,H
M)&9O;RD*("`@('L*("`@("`@("!R971U<FX@0&1B87-E7VYU;7)E8V]R9',H
M)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[('%U;W1E4VUA<G0H*0H*("`@("\J*@H@("`@("H@1F]R;6%T<R!I;G!U
M="!S;R!I="!C86X@8F4@<V%F96QY('5S960@:6X@82!Q=65R>0H@("`@("H*
M("`@("`J($!P87)A;2!M:7AE9"`D:6X@('1H92!D871A('1O(&)E(&9O<FUA
M='1E9`H@("`@("H*("`@("`J($!R971U<FX@;6EX960@('1H92!F;W)M871T
M960@9&%T82X@(%1H92!F;W)M870@9&5P96YD<R!O;B!T:&4@:6YP=70G<PH@
M("`@("H@("`@("`@("`@("`@("`@(%!(4"!T>7!E.@H@("`@("H@("`@("`@
M("`@("`@("`@("L@;G5L;"`]('1H92!S=')I;F<@/'-A;7`^3E5,3#PO<V%M
M<#X*("`@("`J("`@("`@("`@("`@("`@("`K(&)O;VQE86X@/2`\<V%M<#Y4
M/"]S86UP/B!I9B!T<G5E(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`\
M<V%M<#Y&/"]S86UP/B!I9B!F86QS92X@(%5S92!T:&4@/&MB9#Y,;V=I8V%L
M/"]K8F0^"B`@("`@*B`@("`@("`@("`@("`@("`@("!D871A('1Y<&4N"B`@
M("`@*B`@("`@("`@("`@("`@("`@*R!I;G1E9V5R(&]R(&1O=6)L92`]('1H
M92!U;G%U;W1E9"!N=6UB97(*("`@("`J("`@("`@("`@("`@("`@("`K(&]T
M:&5R("AI;F-L=61I;F<@<W1R:6YG<R!A;F0@;G5M97)I8R!S=')I;F=S*2`]
M"B`@("`@*B`@("`@("`@("`@("`@("`@("!T:&4@9&%T82!W:71H('-I;F=L
M92!Q=6]T97,@97-C87!E9"!B>2!P<F5C965D:6YG"B`@("`@*B`@("`@("`@
M("`@("`@("`@("!S:6YG;&4@<75O=&5S('1H96X@=&AE('=H;VQE('-T<FEN
M9R!I<R!E;F-A<'-U;&%T960*("`@("`J("`@("`@("`@("`@("`@("`@(&)E
M='=E96X@<VEN9VQE('%U;W1E<PH@("`@("H*("`@("`J($!S964@1$)?8V]M
M;6]N.CIQ=6]T95-M87)T*"D*("`@("`J($!S:6YC92!-971H;V0@879A:6QA
M8FQE('-I;F-E(%)E;&5A<V4@,2XV+C`*("`@("`J+PH@("`@9G5N8W1I;VX@
M<75O=&53;6%R="@D:6XI"B`@("!["B`@("`@("`@:68@*&ES7VEN="@D:6XI
M('Q\(&ES7V1O=6)L92@D:6XI*2!["B`@("`@("`@("`@(')E='5R;B`D:6X[
M"B`@("`@("`@?2!E;'-E:68@*&ES7V)O;VPH)&EN*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&EN(#\@)U0G(#H@)T8G.PH@("`@("`@('T@96QS96EF("AI
M<U]N=6QL*"1I;BDI('L*("`@("`@("`@("`@<F5T=7)N("=.54Q,)SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@(B<B("X@)'1H:7,M
M/F5S8V%P95-I;7!L92@D:6XI("X@(B<B.PH@("`@("`@('T*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!T86)L94EN9F\H*0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!I;F9O<FUA=&EO;B!A8F]U="!T:&4@8W5R<F5N="!D871A
M8F%S90H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D<F5S=6QT("!42$E3
M($E3(%5.55-%1"!)3B!$0D%312X@(%1H92!C=7)R96YT(&1A=&%B87-E"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@:7,@97AA;6EN960@<F5G87)D
M;&5S<R!O9B!W:&%T(&ES('!R;W9I9&5D(&AE<F4N"B`@("`@*B!`<&%R86T@
M:6YT("`@)&UO9&4@("`@82!V86QI9"!T86)L94EN9F\@;6]D90H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@(&%N(&%S<V]C:6%T:79E(&%R<F%Y('=I
M=&@@=&AE(&EN9F]R;6%T:6]N(')E<75E<W1E9"X*("`@("`J("`@("`@("`@
M("`@("`@("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*
M("`@("`J($!S964@1$)?8V]M;6]N.CIT86)L94EN9F\H*0H@("`@("H@0'-I
M;F-E($UE=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C<N,`H@("`@
M("HO"B`@("!F=6YC=&EO;B!T86)L94EN9F\H)')E<W5L="`](&YU;&PL("1M
M;V1E(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S
M*"=D8F%S95]G971?:&5A9&5R7VEN9F\G*2D@>PH@("`@("`@("`@("`D:60@
M/2!`9&)A<V5?9V5T7VAE861E<E]I;F9O*"1T:&ES+3YC;VYN96-T:6]N*3L*
M("`@("`@("`@("`@:68@*"$D:60@)B8@)'!H<%]E<G)O<FUS9RD@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]2
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU
M;&PL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'!H<%]E<G)O<FUS9RD["B`@("`@("`@("`@('T*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!4
M:&ES('-E9VUE;G0@9F]R(%!(4"`T(&ES(&QO;W-E;'D@8F%S960@;VX@8V]D
M92!B>0H@("`@("`@("`@("`@*B!(861I(%)U<VEA:"`\9&5E9V]S0'EA:&]O
M+F-O;3X@:6X@=&AE(&-O;6UE;G1S(&]N"B`@("`@("`@("`@("`J('1H92!D
M0F%S92!R969E<F5N8V4@<&%G92!I;B!T:&4@4$A0(&UA;G5A;"X*("`@("`@
M("`@("`@("HO"B`@("`@("`@("`@("1D8B`]($!F;W!E;B@D=&AI<RT^9'-N
M6R=D871A8F%S92==+"`G<B<I.PH@("`@("`@("`@("!I9B`H(21D8BD@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T52
M4D]27T-/3DY%0U1?1D%)3$5$+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&YU;&PL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!H<%]E<G)O<FUS9RD[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1I9"`](&%R<F%Y*"D["B`@
M("`@("`@("`@("1I("`](#`["@H@("`@("`@("`@("`D;&EN92`](&9R96%D
M*"1D8BP@,S(I.PH@("`@("`@("`@("!W:&EL92`H(69E;V8H)&1B*2D@>PH@
M("`@("`@("`@("`@("`@)&QI;F4@/2!F<F5A9"@D9&(L(#,R*3L*("`@("`@
M("`@("`@("`@(&EF("AS=6)S='(H)&QI;F4L(#`L(#$I(#T](&-H<B@Q,RDI
M('L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'!O<R`]('-T<G!O<RAS
M=6)S='(H)&QI;F4L(#`L(#$P*2P@8VAR*#`I*3L*("`@("`@("`@("`@("`@
M("`@("`D<&]S(#T@*"1P;W,@/3T@,"`_(#$P(#H@)'!O<RD["B`@("`@("`@
M("`@("`@("`@("`@)&ED6R1I72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("`@("`G;F%M92<@("`]/B!S=6)S='(H)&QI;F4L(#`L("1P;W,I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@("`]/B`D=&AI<RT^='EP
M97-;<W5B<W1R*"1L:6YE+"`Q,2P@,2E=+`H@("`@("`@("`@("`@("`@("`@
M("`@("`G;&5N9W1H)R`]/B!O<F0H<W5B<W1R*"1L:6YE+"`Q-BP@,2DI+`H@
M("`@("`@("`@("`@("`@("`@("`@("`G<')E8VES:6]N)R`]/B!O<F0H<W5B
M<W1R*"1L:6YE+"`Q-RP@,2DI+`H@("`@("`@("`@("`@("`@("`@("D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!F8VQO<V4H)&1B*3L*("`@("`@("!]"@H@
M("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"
M7U!/4E1!0DE,25197TQ/5T520T%312D@>PH@("`@("`@("`@("`D8V%S95]F
M=6YC(#T@)W-T<G1O;&]W97(G.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1C87-E7V9U;F,@/2`G<W1R=F%L)SL*("`@("`@("!]"@H@("`@("`@
M("1R97,@("`](&%R<F%Y*"D["B`@("`@("`@)&-O=6YT(#T@8V]U;G0H)&ED
M*3L*"B`@("`@("`@:68@*"1M;V1E*2!["B`@("`@("`@("`@("1R97-;)VYU
M;5]F:65L9',G72`]("1C;W5N=#L*("`@("`@("!]"@H@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\("1C;W5N=#L@)&DK*RD@>PH@("`@("`@("`@("`D<F5S
M6R1I72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)W1A8FQE)R`]/B`D=&AI
M<RT^9'-N6R=D871A8F%S92==+`H@("`@("`@("`@("`@("`@)VYA;64G("`]
M/B`D8V%S95]F=6YC*"1I9%LD:5U;)VYA;64G72DL"B`@("`@("`@("`@("`@
M("`G='EP92<@(#T^("1I9%LD:5U;)W1Y<&4G72P*("`@("`@("`@("`@("`@
M("=L96XG("`@/3X@)&ED6R1I75LG;&5N9W1H)UTL"B`@("`@("`@("`@("`@
M("`G9FQA9W,G(#T^("<G"B`@("`@("`@("`@("D["B`@("`@("`@("`@(&EF
M("@D;6]D92`F($1"7U1!0DQ%24Y&3U]/4D1%4BD@>PH@("`@("`@("`@("`@
M("`@)')E<ULG;W)D97(G75LD<F5S6R1I75LG;F%M92==72`]("1I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&EF("@D;6]D92`F($1"7U1!0DQ%24Y&
M3U]/4D1%4E1!0DQ%*2!["B`@("`@("`@("`@("`@("`D<F5S6R=O<F1E<G1A
M8FQE)UU;)')E<ULD:5U;)W1A8FQE)UU=6R1R97-;)&E=6R=N86UE)UU=(#T@
M)&D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M<F5S.PH@("`@?0H*("`@("\O('U]?0I]"@HO*@H@*B!,;V-A;"!V87)I86)L
M97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!%
M;F0Z"B`J+PH*/SX*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]$0B]F8G-Q;"YP
M:'``````````````````````````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`U
M-34V-0`Q,#4Q-30S,S<S-@`P,C`W,S,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"B\J('9I;3H@<V5T(&5X<&%N
M9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO
M"@HO*BH*("H@5&AE(%!%05(@1$(@9')I=F5R(&9O<B!02%`G<R!F8G-Q;"!E
M>'1E;G-I;VX*("H@9F]R(&EN=&5R86-T:6YG('=I=&@@1G)O;G1"87-E(&1A
M=&%B87-E<PH@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%
M3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S
M+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55))
M.@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@
M0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U
M=&AO<B`@("`@1G)A;FL@32X@2W)O;6%N;B`\9G)A;FM`9G)O;G1B87-E+F-O
M;3X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P
M:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U
M<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@0U93.B`D
M260Z(&9B<W%L+G!H<"QV(#$N.#(@,C`P-2\P,R\P-"`R,SHQ,CHS-B!D86YI
M96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]$0@H@*B\*"B\J*@H@*B!/8G1A:6X@=&AE($1"7V-O;6UO;B!C
M;&%S<R!S;R!I="!C86X@8F4@97AT96YD960@9G)O;0H@*B\*<F5Q=6ER95]O
M;F-E("=$0B]C;VUM;VXN<&AP)SL*"B\J*@H@*B!4:&4@;65T:&]D<R!014%2
M($1"('5S97,@=&\@:6YT97)A8W0@=VET:"!02%`G<R!F8G-Q;"!E>'1E;G-I
M;VX*("H@9F]R(&EN=&5R86-T:6YG('=I=&@@1G)O;G1"87-E(&1A=&%B87-E
M<PH@*@H@*B!4:&5S92!M971H;V1S(&]V97)L;V%D('1H92!O;F5S(&1E8VQA
M<F5D(&EN($1"7V-O;6UO;BX*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*
M("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@1G)A;FL@32X@2W)O
M;6%N;B`\9G)A;FM`9G)O;G1B87-E+F-O;3X*("H@0&%U=&AO<B`@("`@1&%N
M:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT
M("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S
M+C`*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XW+C8*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J($!S:6YC92`@
M("`@($-L87-S(&9U;F-T:6]N86P@<VEN8V4@4F5L96%S92`Q+C<N,`H@*B\*
M8VQA<W,@1$)?9F)S<6P@97AT96YD<R!$0E]C;VUM;VX*>PH@("`@+R\@>WM[
M('!R;W!E<G1I97,*"B`@("`O*BH*("`@("`J(%1H92!$0B!D<FEV97(@='EP
M92`H;7ES<6PL(&]C:3@L(&]D8F,L(&5T8RXI"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)'!H<'1Y<&4@/2`G9F)S<6PG.PH*("`@("\J
M*@H@("`@("H@5&AE(&1A=&%B87-E('-Y;G1A>"!V87)I86YT('1O(&)E('5S
M960@*&1B,BP@86-C97-S+"!E=&,N*2P@:68@86YY"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)&1B<WEN=&%X(#T@)V9B<W%L)SL*"B`@
M("`O*BH*("`@("`J(%1H92!C87!A8FEL:71I97,@;V8@=&AI<R!$0B!I;7!L
M96UE;G1A=&EO;@H@("`@("H*("`@("`J(%1H92`G;F5W7VQI;FLG(&5L96UE
M;G0@8V]N=&%I;G,@=&AE(%!(4"!V97)S:6]N('1H870@9FER<W0@<')O=FED
M960*("`@("`J(&YE=U]L:6YK('-U<'!O<G0@9F]R('1H:7,@1$)-4RX@($-O
M;G1A:6YS(&9A;'-E(&EF(&ET)W,@=6YS=7!P;W)T960N"B`@("`@*@H@("`@
M("H@365A;FEN9R!O9B!T:&4@)VQI;6ET)R!E;&5M96YT.@H@("`@("H@("`K
M("=E;75L871E)R`](&5M=6QA=&4@=VET:"!F971C:"!R;W<@8GD@;G5M8F5R
M"B`@("`@*B`@("L@)V%L=&5R)R`@(#T@86QT97(@=&AE('%U97)Y"B`@("`@
M*B`@("L@9F%L<V4@("`@(#T@<VMI<"!R;W=S"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&9E871U<F5S(#T@87)R87DH"B`@
M("`@("`@)VQI;6ET)R`@("`@("`@(#T^("=A;'1E<B<L"B`@("`@("`@)VYE
M=U]L:6YK)R`@("`@(#T^(&9A;'-E+`H@("`@("`@("=N=6UR;W=S)R`@("`@
M("`]/B!T<G5E+`H@("`@("`@("=P8V]N;F5C="<@("`@("`]/B!T<G5E+`H@
M("`@("`@("=P<F5P87)E)R`@("`@("`]/B!F86QS92P*("`@("`@("`G<W-L
M)R`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@)W1R86YS86-T:6]N<R<@
M(#T^('1R=64L"B`@("`I.PH*("`@("\J*@H@("`@("H@02!M87!P:6YG(&]F
M(&YA=&EV92!E<G)O<B!C;V1E<R!T;R!$0B!E<G)O<B!C;V1E<PH@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&5R<F]R8V]D95]M87`@/2!A
M<G)A>2@*("`@("`@("`@,C(@/3X@1$)?15)23U)?4UE.5$%8+`H@("`@("`@
M("`X-2`]/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*("`@("`@("`Q,#@@
M/3X@1$)?15)23U)?4UE.5$%8+`H@("`@("`@(#$Q-B`]/B!$0E]%4E)/4E].
M3U-50TA404),12P*("`@("`@("`Q,C0@/3X@1$)?15)23U)?5D%,545?0T]5
M3E1?3TY?4D]7+`H@("`@("`@(#(Q-2`]/B!$0E]%4E)/4E].3U-50TA&245,
M1"P*("`@("`@("`R,3<@/3X@1$)?15)23U)?24Y604Q)1%].54U"15(L"B`@
M("`@("`@,C(V(#T^($1"7T524D]27TY/4U5#2$9)14Q$+`H@("`@("`@(#(S
M,2`]/B!$0E]%4E)/4E])3E9!3$E$+`H@("`@("`@(#(S.2`]/B!$0E]%4E)/
M4E]44E5.0T%4140L"B`@("`@("`@,C4Q(#T^($1"7T524D]27U-93E1!6"P*
M("`@("`@("`R-C8@/3X@1$)?15)23U)?3D]47T9/54Y$+`H@("`@("`@(#,U
M-R`]/B!$0E]%4E)/4E]#3TY35%)!24Y47TY/5%].54Q,+`H@("`@("`@(#,U
M."`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@(#,V,"`]/B!$0E]%
M4E)/4E]#3TY35%)!24Y4+`H@("`@("`@(#,V,2`]/B!$0E]%4E)/4E]#3TY3
M5%)!24Y4+`H@("`@*3L*"B`@("`O*BH*("`@("`J(%1H92!R87<@9&%T86)A
M<V4@8V]N;F5C=&EO;B!C<F5A=&5D(&)Y(%!(4`H@("`@("H@0'9A<B!R97-O
M=7)C90H@("`@("HO"B`@("!V87(@)&-O;FYE8W1I;VX["@H@("`@+RHJ"B`@
M("`@*B!4:&4@1%-.(&EN9F]R;6%T:6]N(&9O<B!C;VYN96-T:6YG('1O(&$@
M9&%T86)A<V4*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1D
M<VX@/2!A<G)A>2@I.PH*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYS=')U
M8W1O<@H*("`@("\J*@H@("`@("H@5&AI<R!C;VYS=')U8W1O<B!C86QL<R`\
M:V)D/B1T:&ES+3Y$0E]C;VUM;VXH*3PO:V)D/@H@("`@("H*("`@("`J($!R
M971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!$0E]F8G-Q;"@I"B`@
M("!["B`@("`@("`@)'1H:7,M/D1"7V-O;6UO;B@I.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&-O;FYE8W0H*0H*("`@("\J*@H@("`@("H@0V]N
M;F5C="!T;R!T:&4@9&%T86)A<V4@<V5R=F5R+"!L;V<@:6X@86YD(&]P96X@
M=&AE(&1A=&%B87-E"B`@("`@*@H@("`@("H@1&]N)W0@8V%L;"!T:&ES(&UE
M=&AO9"!D:7)E8W1L>2X@(%5S92!$0CHZ8V]N;F5C="@I(&EN<W1E860N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1D<VX@("`@("`@("!T:&4@9&%T
M82!S;W5R8V4@;F%M90H@("`@("H@0'!A<F%M(&)O;VP@("1P97)S:7-T96YT
M("!S:&]U;&0@=&AE(&-O;FYE8W1I;VX@8F4@<&5R<VES=&5N=#\*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@02!$0E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M8V]N;F5C="@D9'-N+"`D<&5R<VES=&5N="`](&9A;'-E*0H@("`@>PH@("`@
M("`@(&EF("@A4$5!4CHZ;&]A9$5X=&5N<VEO;B@G9F)S<6PG*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?15A4
M14Y324].7TY/5%]&3U5.1"D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^
M9'-N(#T@)&1S;CL*("`@("`@("!I9B`H)&1S;ELG9&)S>6YT87@G72D@>PH@
M("`@("`@("`@("`D=&AI<RT^9&)S>6YT87@@/2`D9'-N6R=D8G-Y;G1A>"==
M.PH@("`@("`@('T*"B`@("`@("`@)'!A<F%M<R`](&%R<F%Y*`H@("`@("`@
M("`@("`D9'-N6R=H;W-T<W!E8R==(#\@)&1S;ELG:&]S='-P96,G72`Z("=L
M;V-A;&AO<W0G+`H@("`@("`@("`@("`D9'-N6R=U<V5R;F%M92==(#\@)&1S
M;ELG=7-E<FYA;64G72`Z(&YU;&PL"B`@("`@("`@("`@("1D<VY;)W!A<W-W
M;W)D)UT@/R`D9'-N6R=P87-S=V]R9"==(#H@;G5L;"P*("`@("`@("`I.PH*
M("`@("`@("`D8V]N;F5C=%]F=6YC=&EO;B`]("1P97)S:7-T96YT(#\@)V9B
M<W%L7W!C;VYN96-T)R`Z("=F8G-Q;%]C;VYN96-T)SL*"B`@("`@("`@)&EN
M:2`](&EN:5]G970H)W1R86-K7V5R<F]R<R<I.PH@("`@("`@("1P:'!?97)R
M;W)M<V<@/2`G)SL*("`@("`@("!I9B`H)&EN:2D@>PH@("`@("`@("`@("`D
M=&AI<RT^8V]N;F5C=&EO;B`]($!C86QL7W5S97)?9G5N8U]A<G)A>2@D8V]N
M;F5C=%]F=6YC=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<RD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@:6YI7W-E="@G=')A8VM?97)R;W)S)RP@,2D[
M"B`@("`@("`@("`@("1T:&ES+3YC;VYN96-T:6]N(#T@0&-A;&Q?=7-E<E]F
M=6YC7V%R<F%Y*"1C;VYN96-T7V9U;F-T:6]N+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US
M*3L*("`@("`@("`@("`@:6YI7W-E="@G=')A8VM?97)R;W)S)RP@)&EN:2D[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H(21T:&ES+3YC;VYN96-T:6]N*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/
M4E]#3TY.14-47T9!24Q%1"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&YU;&PL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<&AP7V5R<F]R;7-G*3L*("`@("`@("!]
M"@H@("`@("`@(&EF("@D9'-N6R=D871A8F%S92==*2!["B`@("`@("`@("`@
M(&EF("@A0&9B<W%L7W-E;&5C=%]D8B@D9'-N6R=D871A8F%S92==+"`D=&AI
M<RT^8V]N;F5C=&EO;BDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^9F)S<6Q286ES945R<F]R*"D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!D:7-C;VYN96-T*"D*"B`@("`O*BH*("`@("`J($1I<V-O;FYE
M8W1S(&9R;VT@=&AE(&1A=&%B87-E('-E<G9E<@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;"`@5%)512!O;B!S=6-C97-S+"!&04Q312!O;B!F86EL=7)E
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&1I<V-O;FYE8W0H*0H@("`@>PH@("`@
M("`@("1R970@/2!`9F)S<6Q?8VQO<V4H)'1H:7,M/F-O;FYE8W1I;VXI.PH@
M("`@("`@("1T:&ES+3YC;VYN96-T:6]N(#T@;G5L;#L*("`@("`@("!R971U
M<FX@)')E=#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!S:6UP;&51
M=65R>2@I"@H@("`@+RHJ"B`@("`@*B!396YD<R!A('%U97)Y('1O('1H92!D
M871A8F%S92!S97)V97(*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("!T
M:&4@4U%,('%U97)Y('-T<FEN9PH@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@("L@82!02%`@<F5S=6QT(')E<W)O=6-E(&9O<B!S=6-C97-S9G5L(%-%
M3$5#5"!Q=65R:65S"B`@("`@*B`@("`@("`@("`@("`@("`K('1H92!$0E]/
M2R!C;VYS=&%N="!F;W(@;W1H97(@<W5C8V5S<V9U;"!Q=65R:65S"B`@("`@
M*B`@("`@("`@("`@("`@("`K(&$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4*("`@("`J+PH@("`@9G5N8W1I;VX@<VEM<&QE475E<GDH)'%U97)Y*0H@
M("`@>PH@("`@("`@("1T:&ES+3YL87-T7W%U97)Y(#T@)'%U97)Y.PH@("`@
M("`@("1Q=65R>2`]("1T:&ES+3YM;V1I9GE1=65R>2@D<75E<GDI.PH@("`@
M("`@("1R97-U;'0@/2!`9F)S<6Q?<75E<GDH(B1Q=65R>3LB+"`D=&AI<RT^
M8V]N;F5C=&EO;BD["B`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^9F)S<6Q286ES945R<F]R*"D["B`@("`@("`@
M?0H@("`@("`@("\O($1E=&5R;6EN92!W:&EC:"!Q=65R:65S('1H870@<VAO
M=6QD(')E='5R;B!D871A+"!A;F0@=VAI8V@*("`@("`@("`O+R!S:&]U;&0@
M<F5T=7)N(&%N(&5R<F]R(&-O9&4@;VYL>2X*("`@("`@("!I9B`H1$(Z.FES
M36%N:7`H)'%U97)Y*2D@>PH@("`@("`@("`@("!R971U<FX@1$)?3TL["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&YE>'1297-U;'0H*0H*("`@("\J*@H@("`@("H@
M36]V92!T:&4@:6YT97)N86P@9F)S<6P@<F5S=6QT('!O:6YT97(@=&\@=&AE
M(&YE>'0@879A:6QA8FQE(')E<W5L=`H@("`@("H*("`@("`J($!P87)A;2!A
M('9A;&ED(&9B<W%L(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!T<G5E(&EF(&$@
M<F5S=6QT(&ES(&%V86EL86)L92!O=&AE<G=I<V4@<F5T=7)N(&9A;'-E"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&YE>'1297-U;'0H)')E<W5L="D*("`@('L*
M("`@("`@("!R971U<FX@0&9B<W%L7VYE>'1?<F5S=6QT*"1R97-U;'0I.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9E=&-H26YT;R@I"@H@("`@
M+RHJ"B`@("`@*B!0;&%C97,@82!R;W<@9G)O;2!T:&4@<F5S=6QT('-E="!I
M;G1O('1H92!G:79E;B!A<G)A>0H@("`@("H*("`@("`J($9O<FUA=&EN9R!O
M9B!T:&4@87)R87D@86YD('1H92!D871A('1H97)E:6X@87)E(&-O;F9I9W5R
M86)L92X*("`@("`J(%-E92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I(&9O<B!M
M;W)E(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES
M(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J
M($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E
M(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L
M="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<F5S;W5R8V4@)')E<W5L="`@("!T:&4@<75E<GD@<F5S=6QT(')E<V]U<F-E
M"B`@("`@*B!`<&%R86T@87)R87D@("`@)&%R<B`@("`@("!T:&4@<F5F97)E
M;F-E9"!A<G)A>2!T;R!P=70@=&AE(&1A=&$@:6X*("`@("`J($!P87)A;2!I
M;G0@("`@("`D9F5T8VAM;V1E(&AO=R!T:&4@<F5S=6QT:6YG(&%R<F%Y('-H
M;W5L9"!B92!I;F1E>&5D"B`@("`@*B!`<&%R86T@:6YT("`@("`@)')O=VYU
M;2`@("!T:&4@<F]W(&YU;6)E<B!T;R!F971C:"`H,"`](&9I<G-T(')O=RD*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!$0E]/2R!O;B!S=6-C97-S
M+"!.54Q,('=H96X@=&AE(&5N9"!O9B!A(')E<W5L="!S970@:7,*("`@("`J
M("`@("`@("`@("`@("`@("!R96%C:&5D(&]R(&]N(&9A:6QU<F4*("`@("`J
M"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D*("`@("`J+PH@
M("`@9G5N8W1I;VX@9F5T8VA);G1O*"1R97-U;'0L("8D87)R+"`D9F5T8VAM
M;V1E+"`D<F]W;G5M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H)')O=VYU
M;2`A/3T@;G5L;"D@>PH@("`@("`@("`@("!I9B`H(4!F8G-Q;%]D871A7W-E
M96LH)')E<W5L="P@)')O=VYU;2DI('L*("`@("`@("`@("`@("`@(')E='5R
M;B!N=6QL.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D
M9F5T8VAM;V1E("8@1$)?1D540TA-3T1%7T%34T]#*2!["B`@("`@("`@("`@
M("1A<G(@/2!`9F)S<6Q?9F5T8VA?87)R87DH)')E<W5L="P@1D)344Q?05-3
M3T,I.PH@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL
M:71Y)UT@)B!$0E]03U)404))3$E465],3U=%4D-!4T4@)B8@)&%R<BD@>PH@
M("`@("`@("`@("`@("`@)&%R<B`](&%R<F%Y7V-H86YG95]K97E?8V%S92@D
M87)R+"!#05-%7TQ/5T52*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1A<G(@/2!`9F)S<6Q?9F5T8VA?<F]W*"1R97-U
M;'0I.PH@("`@("`@('T*("`@("`@("!I9B`H(21A<G(I('L*("`@("`@("`@
M("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^
M;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197U)44DE-
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?<G1R:6U!<G)A>59A;'5E<R@D87)R
M*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T
M86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3E5,3%]43U]%35!462D@>PH@
M("`@("`@("`@("`D=&AI<RT^7V-O;G9E<G1.=6QL07)R87E686QU97-4;T5M
M<'1Y*"1A<G(I.PH@("`@("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9G)E95)E<W5L="@I"@H@("`@
M+RHJ"B`@("`@*B!$96QE=&5S('1H92!R97-U;'0@<V5T(&%N9"!F<F5E<R!T
M:&4@;65M;W)Y(&]C8W5P:65D(&)Y('1H92!R97-U;'0@<V5T"B`@("`@*@H@
M("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D
M:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIF<F5E*"D@:6YS=&5A
M9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B
M96-A=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@
M<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("!4
M4E5%(&]N('-U8V-E<W,L($9!3%-%(&EF("1R97-U;'0@:7,@:6YV86QI9`H@
M("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIF<F5E*"D*("`@("`J+PH@
M("`@9G5N8W1I;VX@9G)E95)E<W5L="@D<F5S=6QT*0H@("`@>PH@("`@("`@
M(')E='5R;B!`9F)S<6Q?9G)E95]R97-U;'0H)')E<W5L="D["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@875T;T-O;6UI="@I"@H@("`@+RHJ"B`@
M("`@*B!%;F%B;&5S(&]R(&1I<V%B;&5S(&%U=&]M871I8R!C;VUM:71S"B`@
M("`@*@H@("`@("H@0'!A<F%M(&)O;VP@)&]N;V9F("!T<G5E('1U<FYS(&ET
M(&]N+"!F86QS92!T=7)N<R!I="!O9F8*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&EF
M('1H92!D<FEV97(*("`@("`J("`@("`@("`@("`@("`@9&]E<VXG="!S=7!P
M;W)T(&%U=&\M8V]M;6ET=&EN9R!T<F%N<V%C=&EO;G,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&%U=&]#;VUM:70H)&]N;V9F/69A;'-E*0H@("`@>PH@("`@
M("`@(&EF("@D;VYO9F8I('L*("`@("`@("`@("`@)'1H:7,M/G%U97)Y*")3
M150@0T]-34E4(%12544B*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D=&AI<RT^<75E<GDH(E-%5"!#3TU-250@1D%,4T4B*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]M;6ET*"D*"B`@("`O
M*BH*("`@("`J($-O;6UI=',@=&AE(&-U<G)E;G0@=')A;G-A8W1I;VX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@
M1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&-O;6UI="@I"B`@("!["B`@("`@("`@0&9B<W%L7V-O;6UI="@I.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(')O;&QB86-K*"D*"B`@("`O
M*BH*("`@("`J(%)E=F5R=',@=&AE(&-U<G)E;G0@=')A;G-A8W1I;VX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@
M1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')O;&QB86-K*"D*("`@('L*("`@("`@("!`9F)S<6Q?<F]L;&)A8VLH
M*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N=6U#;VQS*"D*"B`@
M("`O*BH*("`@("`J($=E=',@=&AE(&YU;6)E<B!O9B!C;VQU;6YS(&EN(&$@
M<F5S=6QT('-E=`H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M
M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E
M<W5L=#HZ;G5M0V]L<R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E
M9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S
M97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E
M("1R97-U;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H*
M("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(&-O;'5M;G,N("!!
M($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S
M964@1$)?<F5S=6QT.CIN=6U#;VQS*"D*("`@("`J+PH@("`@9G5N8W1I;VX@
M;G5M0V]L<R@D<F5S=6QT*0H@("`@>PH@("`@("`@("1C;VQS(#T@0&9B<W%L
M7VYU;5]F:65L9',H)')E<W5L="D["B`@("`@("`@:68@*"$D8V]L<RD@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/F9B<W%L4F%I<V5%<G)O<B@I.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)&-O;',["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@;G5M4F]W<R@I"@H@("`@+RHJ"B`@("`@*B!'971S
M('1H92!N=6UB97(@;V8@<F]W<R!I;B!A(')E<W5L="!S970*("`@("`J"B`@
M("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I
M<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.FYU;5)O=W,H*2!I;G-T
M96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J
M(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@
M("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G<R!Q=65R
M>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@
M=&AE(&YU;6)E<B!O9B!R;W=S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I
M;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ;G5M4F]W<R@I
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU;5)O=W,H)')E<W5L="D*("`@('L*
M("`@("`@("`D<F]W<R`]($!F8G-Q;%]N=6U?<F]W<R@D<F5S=6QT*3L*("`@
M("`@("!I9B`H)')O=W,@/3T](&YU;&PI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YF8G-Q;%)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1R;W=S.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&%F
M9F5C=&5D4F]W<R@I"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S('1H92!N
M=6UB97(@;V8@<F]W<R!A9F9E8W1E9"!B>2!A(&1A=&$@;6%N:75P;&%T:6]N
M('%U97)Y"B`@("`@*@H@("`@("H@,"!I<R!R971U<FYE9"!F;W(@<75E<FEE
M<R!T:&%T(&1O;B=T(&UA;FEP=6QA=&4@9&%T82X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!R;W=S+B`@02!$0E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@869F96-T
M9612;W=S*"D*("`@('L*("`@("`@("!I9B`H1$(Z.FES36%N:7`H)'1H:7,M
M/FQA<W1?<75E<GDI*2!["B`@("`@("`@("`@("1R97-U;'0@/2!`9F)S<6Q?
M869F96-T961?<F]W<R@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)')E<W5L="`](#`["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!N97AT260H*0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;F5X
M="!F<F5E(&ED(&EN(&$@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E;F-E"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D;VYD96UA;F0@('=H96X@=')U92P@=&AE('-E
M<65N8V4@:7,@875T;VUA=&EC86QL>0H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8W)E871E9"!I9B!I="!D;V5S(&YO="!E>&ES=`H@("`@
M("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;F5X="!I9"!N=6UB97(@:6X@
M=&AE('-E<75E;F-E+@H@("`@("H@("`@("`@("`@("`@("!!($1"7T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M
M;6]N.CIN97AT240H*2P@1$)?8V]M;6]N.CIG971397%U96YC94YA;64H*2P*
M("`@("`J("`@("`@1$)?9F)S<6PZ.F-R96%T95-E<75E;F-E*"DL($1"7V9B
M<W%L.CID<F]P4V5Q=65N8V4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!N97AT
M260H)'-E<5]N86UE+"`D;VYD96UA;F0@/2!T<G5E*0H@("`@>PH@("`@("`@
M("1S97%N86UE(#T@)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I
M.PH@("`@("`@(&1O('L*("`@("`@("`@("`@)')E<&5A="`](#`["B`@("`@
M("`@("`@("1T:&ES+3YP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%
M5%523BD["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^<75E<GDH)U-%
M3$5#5"!53DE1544@1E)/32`G("X@)'-E<6YA;64I.PH@("`@("`@("`@("`D
M=&AI<RT^<&]P17)R;W)(86YD;&EN9R@I.PH@("`@("`@("`@("!I9B`H)&]N
M9&5M86YD("8F($1".CII<T5R<F]R*"1R97-U;'0I("8F"B`@("`@("`@("`@
M("`@("`D<F5S=6QT+3YG971#;V1E*"D@/3T@1$)?15)23U)?3D]354-(5$%"
M3$4I('L*("`@("`@("`@("`@("`@("1R97!E870@/2`Q.PH@("`@("`@("`@
M("`@("`@)')E<W5L="`]("1T:&ES+3YC<F5A=&5397%U96YC92@D<V5Q7VYA
M;64I.PH@("`@("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D<F5P96%T(#T@,#L*("`@("`@("`@("`@?0H@("`@("`@('T@=VAI
M;&4@*"1R97!E870I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F9B<W%L4F%I<V5%<G)O
M<B@I.PH@("`@("`@('T*("`@("`@("`D<F5S=6QT+3YF971C:$EN=&\H)'1M
M<"P@1$)?1D540TA-3T1%7T]21$52140I.PH@("`@("`@(')E='5R;B`D=&UP
M6S!=.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A(&YE=R!S97%U
M96YC90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-E<5]N86UE("!N
M86UE(&]F('1H92!N97<@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F-R96%T
M95-E<75E;F-E*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@
M("`@*B`@("`@($1"7V9B<W%L.CIN97AT240H*2P@1$)?9F)S<6PZ.F1R;W!3
M97%U96YC92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T95-E<75E;F-E
M*"1S97%?;F%M92D*("`@('L*("`@("`@("`D<V5Q;F%M92`]("1T:&ES+3YG
M971397%U96YC94YA;64H)'-E<5]N86UE*3L*("`@("`@("`D<F5S(#T@)'1H
M:7,M/G%U97)Y*"=#4D5!5$4@5$%"3$4@)R`N("1S97%N86UE"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`N("<@*&ED($E.5$5'15(@3D]4($Y53$PL
M)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G(%!224U!4ED@2T59
M*&ED*2DG*3L*("`@("`@("!I9B`H)')E<RD@>PH@("`@("`@("`@("`D<F5S
M(#T@)'1H:7,M/G%U97)Y*"=3150@54Y)455%(#T@,"!&3U(@)R`N("1S97%N
M86UE*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97,["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@9')O<%-E<75E;F-E*"D*"B`@("`O*BH*
M("`@("`J($1E;&5T97,@82!S97%U96YC90H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'-E<5]N86UE("!N86UE(&]F('1H92!S97%U96YC92!T;R!B
M92!D96QE=&5D"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N
M('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("H*("`@("`J($!S964@1$)?8V]M;6]N.CID<F]P4V5Q=65N8V4H*2P@1$)?
M8V]M;6]N.CIG971397%U96YC94YA;64H*2P*("`@("`J("`@("`@1$)?9F)S
M<6PZ.FYE>'1)1"@I+"!$0E]F8G-Q;#HZ8W)E871E4V5Q=65N8V4H*0H@("`@
M("HO"B`@("!F=6YC=&EO;B!D<F]P4V5Q=65N8V4H)'-E<5]N86UE*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^<75E<GDH)T123U`@5$%"3$4@)R`N
M("1T:&ES+3YG971397%U96YC94YA;64H)'-E<5]N86UE*0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+B`G(%)%4U1224-4)RD["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@;6]D:69Y3&EM:711=65R>2@I"@H@("`@+RHJ
M"B`@("`@*B!!9&1S($Q)34E4(&-L875S97,@=&\@82!Q=65R>2!S=')I;F<@
M86-C;W)D:6YG('1O(&-U<G)E;G0@1$)-4R!S=&%N9&%R9',*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1Q=65R>2`@('1H92!Q=65R>2!T;R!M;V1I
M9GD*("`@("`J($!P87)A;2!I;G0@("`@)&9R;VT@("`@=&AE(')O=R!T;R!S
M=&%R="!T;R!F971C:&EN9R`H,"`]('1H92!F:7)S="!R;W<I"B`@("`@*B!`
M<&%R86T@:6YT("`@("1C;W5N="`@('1H92!N=6UB97)S(&]F(')O=W,@=&\@
M9F5T8V@*("`@("`J($!P87)A;2!M:7AE9"`@)'!A<F%M<R`@87)R87DL('-T
M<FEN9R!O<B!N=6UE<FEC(&1A=&$@=&\@8F4@=7-E9"!I;@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@97AE8W5T:6]N(&]F('1H92!S=&%T96UE
M;G0N("!1=6%N=&ET>2!O9B!I=&5M<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@<&%S<V5D(&UU<W0@;6%T8V@@<75A;G1I='D@;V8@<&QA8V5H
M;VQD97)S(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!Q=65R
M>3H@(&UE86YI;F<@,2!P;&%C96AO;&1E<B!F;W(@;F]N+6%R<F%Y"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!P87)A;65T97)S(&]R(#$@<&QA
M8V5H;VQD97(@<&5R(&%R<F%Y(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@('1H92!Q=65R>2!S=')I;F<@=VET:"!,24U)5"!C;&%U
M<V5S(&%D9&5D"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@
M("`J+PH@("`@9G5N8W1I;VX@;6]D:69Y3&EM:711=65R>2@D<75E<GDL("1F
M<F]M+"`D8V]U;G0L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@
M(&EF("A$0CHZ:7--86YI<"@D<75E<GDI*2!["B`@("`@("`@("`@(')E='5R
M;B!P<F5G7W)E<&QA8V4H)R]>*%M<<RA=*2I314Q%0U0O:2<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(EQ<,5-%3$5#5"!43U`H)&-O=6YT
M*2(L("1Q=65R>2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N('!R96=?<F5P;&%C92@G+RA;7',H72DJ4T5,14-4+VDG+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(")<7#%314Q%0U0@5$]0*"1F<F]M
M+"`D8V]U;G0I(BP@)'%U97)Y*3L*("`@("`@("!]"B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@<75O=&53;6%R="@I"@H@("`@+RHJ"B`@("`@*B!&
M;W)M871S(&EN<'5T('-O(&ET(&-A;B!B92!S869E;'D@=7-E9"!I;B!A('%U
M97)Y"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1I;B`@=&AE(&1A=&$@
M=&\@8F4@9F]R;6%T=&5D"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M=&AE(&9O<FUA='1E9"!D871A+B`@5&AE(&9O<FUA="!D97!E;F1S(&]N('1H
M92!I;G!U="=S"B`@("`@*B`@("`@("`@("`@("`@("`@4$A0('1Y<&4Z"B`@
M("`@*B`@("`@("`@("`@("`@("`@*R!N=6QL(#T@=&AE('-T<FEN9R`\<V%M
M<#Y.54Q,/"]S86UP/@H@("`@("H@("`@("`@("`@("`@("`@("L@8F]O;&5A
M;B`]('-T<FEN9R`\<V%M<#Y44E5%/"]S86UP/B!O<B`\<V%M<#Y&04Q313PO
M<V%M<#X*("`@("`J("`@("`@("`@("`@("`@("`K(&EN=&5G97(@;W(@9&]U
M8FQE(#T@=&AE('5N<75O=&5D(&YU;6)E<@H@("`@("H@("`@("`@("`@("`@
M("`@("L@;W1H97(@*&EN8VQU9&EN9R!S=')I;F=S(&%N9"!N=6UE<FEC('-T
M<FEN9W,I(#T*("`@("`J("`@("`@("`@("`@("`@("`@('1H92!D871A(&5S
M8V%P960@86-C;W)D:6YG('1O($9R;VYT0F%S92=S('-E='1I;F=S"B`@("`@
M*B`@("`@("`@("`@("`@("`@("!T:&5N(&5N8V%P<W5L871E9"!B971W965N
M('-I;F=L92!Q=6]T97,*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ
M<75O=&53;6%R="@I"B`@("`@*B!`<VEN8V4@365T:&]D(&%V86EL86)L92!S
M:6YC92!296QE87-E(#$N-BXP"B`@("`@*B\*("`@(&9U;F-T:6]N('%U;W1E
M4VUA<G0H)&EN*0H@("`@>PH@("`@("`@(&EF("AI<U]I;G0H)&EN*2!\?"!I
M<U]D;W5B;&4H)&EN*2D@>PH@("`@("`@("`@("!R971U<FX@)&EN.PH@("`@
M("`@('T@96QS96EF("AI<U]B;V]L*"1I;BDI('L*("`@("`@("`@("`@<F5T
M=7)N("1I;B`_("=44E5%)R`Z("=&04Q312<["B`@("`@("`@?2!E;'-E:68@
M*&ES7VYU;&PH)&EN*2D@>PH@("`@("`@("`@("!R971U<FX@)TY53$PG.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`B)R(@+B`D=&AI
M<RT^97-C87!E4VEM<&QE*"1I;BD@+B`B)R(["B`@("`@("`@?0H@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&9B<W%L4F%I<V5%<G)O<B@I"@H@("`@
M+RHJ"B`@("`@*B!0<F]D=6-E<R!A($1"7T5R<F]R(&]B:F5C="!R96=A<F1I
M;F<@=&AE(&-U<G)E;G0@<')O8FQE;0H@("`@("H*("`@("`J($!P87)A;2!I
M;G0@)&5R<FYO("!I9B!T:&4@97)R;W(@:7,@8F5I;F<@;6%N=6%L;'D@<F%I
M<V5D('!A<W,@80H@("`@("H@("`@("`@("`@("`@("`@("`@("!$0E]%4E)/
M4BH@8V]N<W1A;G0@:&5R92X@($EF('1H:7,@:7-N)W0@<&%S<V5D"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@('1H92!E<G)O<B!I;F9O<FUA=&EO;B!G
M871H97)E9"!F<F]M('1H92!$0DU3+@H@("`@("H*("`@("`J($!R971U<FX@
M;V)J96-T("!T:&4@1$)?17)R;W(@;V)J96-T"B`@("`@*@H@("`@("H@0'-E
M92!$0E]C;VUM;VXZ.G)A:7-E17)R;W(H*2P*("`@("`J("`@("`@1$)?9F)S
M<6PZ.F5R<F]R3F%T:79E*"DL($1"7V-O;6UO;CHZ97)R;W)#;V1E*"D*("`@
M("`J+PH@("`@9G5N8W1I;VX@9F)S<6Q286ES945R<F]R*"1E<G)N;R`](&YU
M;&PI"B`@("!["B`@("`@("`@:68@*"1E<G)N;R`]/3T@;G5L;"D@>PH@("`@
M("`@("`@("`D97)R;F\@/2`D=&AI<RT^97)R;W)#;V1E*&9B<W%L7V5R<FYO
M*"1T:&ES+3YC;VYN96-T:6]N*2D["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@D97)R;F\L(&YU;&PL(&YU;&PL(&YU;&PL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($!F8G-Q;%]E<G)O
M<B@D=&AI<RT^8V]N;F5C=&EO;BDI.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&5R<F]R3F%T:79E*"D*"B`@("`O*BH*("`@("`J($=E=',@=&AE
M($1"35,G(&YA=&EV92!E<G)O<B!C;V1E('!R;V1U8V5D(&)Y('1H92!L87-T
M('%U97)Y"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!$0DU3)R!E
M<G)O<B!C;V1E"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R3F%T:79E*"D*
M("`@('L*("`@("`@("!R971U<FX@0&9B<W%L7V5R<FYO*"1T:&ES+3YC;VYN
M96-T:6]N*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!T86)L94EN
M9F\H*0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!I;F9O<FUA=&EO;B!A8F]U
M="!A('1A8FQE(&]R(&$@<F5S=6QT('-E=`H@("`@("H*("`@("`J($!P87)A
M;2!O8FIE8W1\<W1R:6YG("`D<F5S=6QT("!$0E]R97-U;'0@;V)J96-T(&9R
M;VT@82!Q=65R>2!O<B!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('-T<FEN9R!C;VYT86EN:6YG('1H92!N86UE(&]F(&$@=&%B
M;&4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%=H
M:6QE('1H:7,@86QS;R!A8V-E<'1S(&$@<75E<GD@<F5S=6QT"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E<V]U<F-E(&ED96YT
M:69I97(L('1H:7,@8F5H879I;W(@:7,*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@9&5P<F5C871E9"X*("`@("`J($!P87)A;2!I
M;G0@("`@("`@("`@("`D;6]D92`@("!A('9A;&ED('1A8FQE26YF;R!M;V1E
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@86X@87-S;V-I871I=F4@
M87)R87D@=VET:"!T:&4@:6YF;W)M871I;VX@<F5Q=65S=&5D+@H@("`@("H@
M("`@("`@("`@("`@("`@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N
M"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G1A8FQE26YF;R@I"B`@
M("`@*B\*("`@(&9U;F-T:6]N('1A8FQE26YF;R@D<F5S=6QT+"`D;6]D92`]
M(&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7W-T<FEN9R@D<F5S=6QT*2D@
M>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E
M:79E9"!A('1A8FQE(&YA;64N"B`@("`@("`@("`@("`J($-R96%T92!A(')E
M<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@("`@*B\*("`@
M("`@("`@("`@)&ED(#T@0&9B<W%L7VQI<W1?9FEE;&1S*"1T:&ES+3YD<VY;
M)V1A=&%B87-E)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<F5S=6QT+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@
M("1G;W1?<W1R:6YG(#T@=')U93L*("`@("`@("!](&5L<V5I9B`H:7-S970H
M)')E<W5L="T^<F5S=6QT*2D@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@
M("`@*B!0<F]B86)L>2!R96-E:79E9"!A(')E<W5L="!O8FIE8W0N"B`@("`@
M("`@("`@("`J($5X=')A8W0@=&AE(')E<W5L="!R97-O=7)C92!I9&5N=&EF
M:65R+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@)&ED(#T@)')E<W5L
M="T^<F5S=6QT.PH@("`@("`@("`@("`D9V]T7W-T<FEN9R`](&9A;'-E.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J
M(%!R;V)A8FQY(')E8V5I=F5D(&$@<F5S=6QT(')E<V]U<F-E(&ED96YT:69I
M97(N"B`@("`@("`@("`@("`J($-O<'D@:70N"B`@("`@("`@("`@("`J($1E
M<')E8V%T960N("!(97)E(&9O<B!C;VUP871I8FEL:71Y(&]N;'DN"B`@("`@
M("`@("`@("`J+PH@("`@("`@("`@("`D:60@/2`D<F5S=6QT.PH@("`@("`@
M("`@("`D9V]T7W-T<FEN9R`](&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"%I<U]R97-O=7)C92@D:60I*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^9F)S<6Q286ES945R<F]R*$1"7T524D]27TY%141?34]215]$051!
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R
M=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TQ/5T520T%312D@>PH@("`@
M("`@("`@("`D8V%S95]F=6YC(#T@)W-T<G1O;&]W97(G.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1C87-E7V9U;F,@/2`G<W1R=F%L)SL*("`@
M("`@("!]"@H@("`@("`@("1C;W5N="`]($!F8G-Q;%]N=6U?9FEE;&1S*"1I
M9"D["B`@("`@("`@)')E<R`@(#T@87)R87DH*3L*"B`@("`@("`@:68@*"1M
M;V1E*2!["B`@("`@("`@("`@("1R97-;)VYU;5]F:65L9',G72`]("1C;W5N
M=#L*("`@("`@("!]"@H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C;W5N
M=#L@)&DK*RD@>PH@("`@("`@("`@("`D<F5S6R1I72`](&%R<F%Y*`H@("`@
M("`@("`@("`@("`@)W1A8FQE)R`]/B`D8V%S95]F=6YC*$!F8G-Q;%]F:65L
M9%]T86)L92@D:60L("1I*2DL"B`@("`@("`@("`@("`@("`G;F%M92<@(#T^
M("1C87-E7V9U;F,H0&9B<W%L7V9I96QD7VYA;64H)&ED+"`D:2DI+`H@("`@
M("`@("`@("`@("`@)W1Y<&4G("`]/B!`9F)S<6Q?9FEE;&1?='EP92@D:60L
M("1I*2P*("`@("`@("`@("`@("`@("=L96XG("`@/3X@0&9B<W%L7V9I96QD
M7VQE;B@D:60L("1I*2P*("`@("`@("`@("`@("`@("=F;&%G<R<@/3X@0&9B
M<W%L7V9I96QD7V9L86=S*"1I9"P@)&DI+`H@("`@("`@("`@("`I.PH@("`@
M("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),14E.1D]?3U)$15(I('L*("`@
M("`@("`@("`@("`@("1R97-;)V]R9&5R)UU;)')E<ULD:5U;)VYA;64G75T@
M/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&UO9&4@)B!$
M0E]404),14E.1D]?3U)$15)404),12D@>PH@("`@("`@("`@("`@("`@)')E
M<ULG;W)D97)T86)L92==6R1R97-;)&E=6R=T86)L92==75LD<F5S6R1I75LG
M;F%M92==72`]("1I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`O+R!F<F5E('1H92!R97-U;'0@;VYL>2!I9B!W92!W97)E(&-A;&QE9"!O
M;B!A('1A8FQE"B`@("`@("`@:68@*"1G;W1?<W1R:6YG*2!["B`@("`@("`@
M("`@($!F8G-Q;%]F<F5E7W)E<W5L="@D:60I.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)')E<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G
M9713<&5C:6%L475E<GDH*0H*("`@("\J*@H@("`@("H@3V)T86EN<R!T:&4@
M<75E<GD@<W1R:6YG(&YE961E9"!F;W(@;&ES=&EN9R!A(&=I=F5N('1Y<&4@
M;V8@;V)J96-T<PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@
M('1H92!K:6YD(&]F(&]B:F5C=',@>6]U('=A;G0@=&\@<F5T<FEE=F4*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(%-13"!Q=65R>2!S=')I
M;F<@;W(@;G5L;"!I9B!T:&4@9')I=F5R(&1O97-N)W0*("`@("`J("`@("`@
M("`@("`@("`@("`@<W5P<&]R="!T:&4@;V)J96-T('1Y<&4@<F5Q=65S=&5D
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J($!S964@
M1$)?8V]M;6]N.CIG971,:7-T3V8H*0H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9713<&5C:6%L475E<GDH)'1Y<&4I"B`@("!["B`@("`@("`@<W=I=&-H("@D
M='EP92D@>PH@("`@("`@("`@("!C87-E("=T86)L97,G.@H@("`@("`@("`@
M("`@("`@<F5T=7)N("=314Q%0U0@(G1A8FQE7VYA;64B($923TT@:6YF;W)M
M871I;VY?<V-H96UA+G1A8FQE<R<*("`@("`@("`@("`@("`@("`@("`@("`N
M("<@=#`L(&EN9F]R;6%T:6]N7W-C:&5M82YS8VAE;6%T82!T,2<*("`@("`@
M("`@("`@("`@("`@("`@("`N("<@5TA%4D4@=#`N<V-H96UA7W!K/70Q+G-C
M:&5M85]P:R!!3D0G"B`@("`@("`@("`@("`@("`@("`@("`@+B`G(")T86)L
M95]T>7!E(B`](%PG0D%312!404),15PG)PH@("`@("`@("`@("`@("`@("`@
M("`@("X@)R!!3D0@(G-C:&5M85]N86UE(B`](&-U<G)E;G1?<V-H96UA)SL*
M("`@("`@("`@("`@8V%S92`G=FEE=W,G.@H@("`@("`@("`@("`@("`@<F5T
M=7)N("=314Q%0U0@(G1A8FQE7VYA;64B($923TT@:6YF;W)M871I;VY?<V-H
M96UA+G1A8FQE<R<*("`@("`@("`@("`@("`@("`@("`@("`N("<@=#`L(&EN
M9F]R;6%T:6]N7W-C:&5M82YS8VAE;6%T82!T,2<*("`@("`@("`@("`@("`@
M("`@("`@("`N("<@5TA%4D4@=#`N<V-H96UA7W!K/70Q+G-C:&5M85]P:R!!
M3D0G"B`@("`@("`@("`@("`@("`@("`@("`@+B`G(")T86)L95]T>7!E(B`]
M(%PG5DE%5UPG)PH@("`@("`@("`@("`@("`@("`@("`@("X@)R!!3D0@(G-C
M:&5M85]N86UE(B`](&-U<G)E;G1?<V-H96UA)SL*("`@("`@("`@("`@8V%S
M92`G=7-E<G,G.@H@("`@("`@("`@("`@("`@<F5T=7)N("=314Q%0U0@(G5S
M97)?;F%M92(@9G)O;2!I;F9O<FUA=&EO;E]S8VAE;6$N=7-E<G,G.R`*("`@
M("`@("`@("`@8V%S92`G9G5N8W1I;VYS)SH*("`@("`@("`@("`@("`@(')E
M='5R;B`G4T5,14-4(")R;W5T:6YE7VYA;64B($923TTG"B`@("`@("`@("`@
M("`@("`@("`@("`@+B`G(&EN9F]R;6%T:6]N7W-C:&5M82YP<VU?<F]U=&EN
M97,G"B`@("`@("`@("`@("`@("`@("`@("`@+B`G('0P+"!I;F9O<FUA=&EO
M;E]S8VAE;6$N<V-H96UA=&$@=#$G"B`@("`@("`@("`@("`@("`@("`@("`@
M+B`G(%=(15)%('0P+G-C:&5M85]P:SUT,2YS8VAE;6%?<&LG"B`@("`@("`@
M("`@("`@("`@("`@("`@+B`G($%.1"`B<F]U=&EN95]K:6YD(CU<)T953D-4
M24].7"<G"B`@("`@("`@("`@("`@("`@("`@("`@+B`G($%.1"`B<V-H96UA
M7VYA;64B(#T@8W5R<F5N=%]S8VAE;6$G.PH@("`@("`@("`@("!C87-E("=P
M<F]C961U<F5S)SH*("`@("`@("`@("`@("`@(')E='5R;B`G4T5,14-4(")R
M;W5T:6YE7VYA;64B($923TTG"B`@("`@("`@("`@("`@("`@("`@("`@+B`G
M(&EN9F]R;6%T:6]N7W-C:&5M82YP<VU?<F]U=&EN97,G"B`@("`@("`@("`@
M("`@("`@("`@("`@+B`G('0P+"!I;F9O<FUA=&EO;E]S8VAE;6$N<V-H96UA
M=&$@=#$G"B`@("`@("`@("`@("`@("`@("`@("`@+B`G(%=(15)%('0P+G-C
M:&5M85]P:SUT,2YS8VAE;6%?<&LG"B`@("`@("`@("`@("`@("`@("`@("`@
M+B`G($%.1"`B<F]U=&EN95]K:6YD(CU<)U!23T-%1%5215PG)PH@("`@("`@
M("`@("`@("`@("`@("`@("X@)R!!3D0@(G-C:&5M85]N86UE(B`](&-U<G)E
M;G1?<V-H96UA)SL*("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@
M("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*
M?0H*+RH*("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@
M8RUB87-I8RUO9F9S970Z(#0*("H@16YD.@H@*B\*"C\^"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O1$(O:6)A<V4N<&AP````````````
M````````````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,#$U-#``,3`U,34T
M,S,W,S8`,#(P-C<P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"@HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O
M<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%1H
M92!014%2($1"(&1R:79E<B!F;W(@4$A0)W,@:6YT97)B87-E(&5X=&5N<VEO
M;@H@*B!F;W(@:6YT97)A8W1I;F<@=VET:"!);G1E<F)A<V4@86YD($9I<F5B
M:7)D(&1A=&%B87-E<PH@*@H@*B!7:&EL92!T:&ES(&-L87-S('=O<FMS('=I
M=&@@4$A0(#0L(%!(4"=S($EN=&5R0F%S92!E>'1E;G-I;VX@:7,*("H@=6YS
M=&%B;&4@:6X@4$A0(#0N("!5<V4@4$A0(#4N"B`J"B`J(%!(4"!V97)S:6]N
M<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@
M<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@
M=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P
M>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T
M86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E
M('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y
M(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`
M<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!3=&5R;&EN9R!(=6=H97,@
M/'-T97)L:6YG0'!H<"YN970^"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV
M:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR
M,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V
M97)S:6]N("`@($-64SH@)$ED.B!I8F%S92YP:'`L=B`Q+C$P.2`R,#`U+S`S
M+S`T(#(S.C$R.C,V(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*+RHJ"B`J($]B=&%I
M;B!T:&4@1$)?8V]M;6]N(&-L87-S('-O(&ET(&-A;B!B92!E>'1E;F1E9"!F
M<F]M"B`J+PIR97%U:7)E7V]N8V4@)T1"+V-O;6UO;BYP:'`G.PH*+RHJ"B`J
M(%1H92!M971H;V1S(%!%05(@1$(@=7-E<R!T;R!I;G1E<F%C="!W:71H(%!(
M4"=S(&EN=&5R8F%S92!E>'1E;G-I;VX*("H@9F]R(&EN=&5R86-T:6YG('=I
M=&@@26YT97)B87-E(&%N9"!&:7)E8FER9"!D871A8F%S97,*("H*("H@5&AE
M<V4@;65T:&]D<R!O=F5R;&]A9"!T:&4@;VYE<R!D96-L87)E9"!I;B!$0E]C
M;VUM;VXN"B`J"B`J(%=H:6QE('1H:7,@8VQA<W,@=V]R:W,@=VET:"!02%`@
M-"P@4$A0)W,@26YT97)"87-E(&5X=&5N<VEO;B!I<PH@*B!U;G-T86)L92!I
M;B!02%`@-"X@(%5S92!02%`@-2X*("H*("H@3D]424-%.B`@;&EM:711=65R
M>2@I(&]N;'D@=V]R:W,@9F]R($9I<F5B:7)D+@H@*@H@*B!`8V%T96=O<GD@
M("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!3
M=&5R;&EN9R!(=6=H97,@/'-T97)L:6YG0'!H<"YN970^"B`J($!A=71H;W(@
M("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@
M("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI
M8V5N<V4@,RXP"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-RXV"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B!`
M<VEN8V4@("`@("!#;&%S<R!B96-A;64@<W1A8FQE(&EN(%)E;&5A<V4@,2XW
M+C`*("HO"F-L87-S($1"7VEB87-E(&5X=&5N9',@1$)?8V]M;6]N"GL*("`@
M("\O('M[>R!P<F]P97)T:65S"@H@("`@+RHJ"B`@("`@*B!4:&4@1$(@9')I
M=F5R('1Y<&4@*&UY<W%L+"!O8VDX+"!O9&)C+"!E=&,N*0H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1P:'!T>7!E(#T@)VEB87-E)SL*
M"B`@("`O*BH*("`@("`J(%1H92!D871A8F%S92!S>6YT87@@=F%R:6%N="!T
M;R!B92!U<V5D("AD8C(L(&%C8V5S<RP@971C+BDL(&EF(&%N>0H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1D8G-Y;G1A>"`]("=I8F%S
M92<["@H@("`@+RHJ"B`@("`@*B!4:&4@8V%P86)I;&ET:65S(&]F('1H:7,@
M1$(@:6UP;&5M96YT871I;VX*("`@("`J"B`@("`@*B!4:&4@)VYE=U]L:6YK
M)R!E;&5M96YT(&-O;G1A:6YS('1H92!02%`@=F5R<VEO;B!T:&%T(&9I<G-T
M('!R;W9I9&5D"B`@("`@*B!N97=?;&EN:R!S=7!P;W)T(&9O<B!T:&ES($1"
M35,N("!#;VYT86EN<R!F86QS92!I9B!I="=S('5N<W5P<&]R=&5D+@H@("`@
M("H*("`@("`J($UE86YI;F<@;V8@=&AE("=L:6UI="<@96QE;65N=#H*("`@
M("`J("`@*R`G96UU;&%T92<@/2!E;75L871E('=I=&@@9F5T8V@@<F]W(&)Y
M(&YU;6)E<@H@("`@("H@("`K("=A;'1E<B<@("`](&%L=&5R('1H92!Q=65R
M>0H@("`@("H@("`K(&9A;'-E("`@("`]('-K:7`@<F]W<PH@("`@("H*("`@
M("`J($Y/5$4Z(&]N;'D@9FER96)I<F0@<W5P<&]R=',@;&EM:70N"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&9E871U<F5S
M(#T@87)R87DH"B`@("`@("`@)VQI;6ET)R`@("`@("`@(#T^(&9A;'-E+`H@
M("`@("`@("=N97=?;&EN:R<@("`@("`]/B!F86QS92P*("`@("`@("`G;G5M
M<F]W<R<@("`@("`@/3X@)V5M=6QA=&4G+`H@("`@("`@("=P8V]N;F5C="<@
M("`@("`]/B!T<G5E+`H@("`@("`@("=P<F5P87)E)R`@("`@("`]/B!T<G5E
M+`H@("`@("`@("=S<VPG("`@("`@("`@("`]/B!F86QS92P*("`@("`@("`G
M=')A;G-A8W1I;VYS)R`@/3X@=')U92P*("`@("D["@H@("`@+RHJ"B`@("`@
M*B!!(&UA<'!I;F<@;V8@;F%T:79E(&5R<F]R(&-O9&5S('1O($1"(&5R<F]R
M(&-O9&5S"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D97)R
M;W)C;V1E7VUA<"`](&%R<F%Y*`H@("`@("`@("TQ,#0@/3X@1$)?15)23U)?
M4UE.5$%8+`H@("`@("`@("TQ-3`@/3X@1$)?15)23U)?04-#15-37U9)3TQ!
M5$E/3BP*("`@("`@("`M,34Q(#T^($1"7T524D]27T%#0T534U]624],051)
M3TXL"B`@("`@("`@+3$U-2`]/B!$0E]%4E)/4E].3U-50TA404),12P*("`@
M("`@("`M,34W(#T^($1"7T524D]27TY/4U5#2$9)14Q$+`H@("`@("`@("TQ
M-3@@/3X@1$)?15)23U)?5D%,545?0T]53E1?3TY?4D]7+`H@("`@("`@("TQ
M-S`@/3X@1$)?15)23U)?34E334%40T@L"B`@("`@("`@+3$W,2`]/B!$0E]%
M4E)/4E]-25--051#2"P*("`@("`@("`M,3<R(#T^($1"7T524D]27TE.5D%,
M240L"B`@("`@("`@+R\@+3(P-"`]/B`@+R\@0V]V97)S('1O;R!M86YY(&5R
M<F]R<RP@;F5E9"!T;R!U<V4@<F5G97@@;VX@;7-G"B`@("`@("`@+3(P-2`]
M/B!$0E]%4E)/4E].3U-50TA&245,1"P*("`@("`@("`M,C`V(#T^($1"7T52
M4D]27TY/4U5#2$9)14Q$+`H@("`@("`@("TR,#@@/3X@1$)?15)23U)?24Y6
M04Q)1"P*("`@("`@("`M,C$Y(#T^($1"7T524D]27TY/4U5#2%1!0DQ%+`H@
M("`@("`@("TR.3<@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("`@("`M
M,S`S(#T^($1"7T524D]27TE.5D%,240L"B`@("`@("`@+30Q,R`]/B!$0E]%
M4E)/4E])3E9!3$E$7TY534)%4BP*("`@("`@("`M-3,P(#T^($1"7T524D]2
M7T-/3E-44D%)3E0L"B`@("`@("`@+34U,2`]/B!$0E]%4E)/4E]!0T-%4U-?
M5DE/3$%424].+`H@("`@("`@("TU-3(@/3X@1$)?15)23U)?04-#15-37U9)
M3TQ!5$E/3BP*("`@("`@("`O+R`M-C`W(#T^("`O+R!#;W9E<G,@=&]O(&UA
M;GD@97)R;W)S+"!N965D('1O('5S92!R96=E>"!O;B!M<V<*("`@("`@("`M
M-C(U(#T^($1"7T524D]27T-/3E-44D%)3E1?3D]47TY53$PL"B`@("`@("`@
M+3@P,R`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@("TX,#0@/3X@
M1$)?15)23U)?5D%,545?0T]53E1?3TY?4D]7+`H@("`@("`@("TY,#0@/3X@
M1$)?15)23U)?0T].3D5#5%]&04E,140L"B`@("`@("`@+3DR,B`]/B!$0E]%
M4E)/4E].3U-50TA$0BP*("`@("`@("`M.3(S(#T^($1"7T524D]27T-/3DY%
M0U1?1D%)3$5$+`H@("`@("`@("TY,C0@/3X@1$)?15)23U)?0T].3D5#5%]&
M04E,140*("`@("D["@H@("`@+RHJ"B`@("`@*B!4:&4@<F%W(&1A=&%B87-E
M(&-O;FYE8W1I;VX@8W)E871E9"!B>2!02%`*("`@("`J($!V87(@<F5S;W5R
M8V4*("`@("`J+PH@("`@=F%R("1C;VYN96-T:6]N.PH*("`@("\J*@H@("`@
M("H@5&AE($133B!I;F9O<FUA=&EO;B!F;W(@8V]N;F5C=&EN9R!T;R!A(&1A
M=&%B87-E"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D9'-N
M(#T@87)R87DH*3L*"@H@("`@+RHJ"B`@("`@*B!4:&4@;G5M8F5R(&]F(')O
M=W,@869F96-T960@8GD@82!D871A(&UA;FEP=6QA=&EO;B!Q=65R>0H@("`@
M("H@0'9A<B!I;G1E9V5R"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M+PH@("`@=F%R("1A9F9E8W1E9"`](#`["@H@("`@+RHJ"B`@("`@*B!3:&]U
M;&0@9&%T82!M86YI<'5L871I;VX@<75E<FEE<R!B92!C;VUM:71T960@875T
M;VUA=&EC86QL>3\*("`@("`J($!V87(@8F]O;`H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B\*("`@('9A<B`D875T;V-O;6UI="`]('1R=64["@H@
M("`@+RHJ"B`@("`@*B!4:&4@<')E<&%R960@<W1A=&5M96YT(&AA;F1L92!F
M<F]M('1H92!M;W-T(')E8V5N=&QY(&5X96-U=&5D('-T871E;65N=`H@("`@
M("H*("`@("`J('M`:6YT97)N86P@($UA:6YL>2!H97)E(&)E8V%U<V4@=&AE
M($EN=&5R0F%S92]&:7)E8FER9"!!4$D@:7,@;VYL>0H@("`@("H@86)L92!T
M;R!R971R:65V92!D871A(&9R;VT@<F5S=6QT('-E=',@:68@=&AE('-T871E
M;6YT(&AA;F1L92!I<PH@("`@("H@<W1I;&P@:6X@<V-O<&4N?7T*("`@("`J
M"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D;&%S=%]S
M=&UT.PH*("`@("\J*@H@("`@("H@27,@=&AE(&=I=F5N('!R97!A<F5D('-T
M871E;65N="!A(&1A=&$@;6%N:7!U;&%T:6]N('%U97)Y/PH@("`@("H@0'9A
M<B!A<G)A>0H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A
M<B`D;6%N:7!?<75E<GD@/2!A<G)A>2@I.PH*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!C;VYS=')U8W1O<@H*("`@("\J*@H@("`@("H@5&AI<R!C;VYS=')U
M8W1O<B!C86QL<R`\:V)D/B1T:&ES+3Y$0E]C;VUM;VXH*3PO:V)D/@H@("`@
M("H*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!$
M0E]I8F%S92@I"B`@("!["B`@("`@("`@)'1H:7,M/D1"7V-O;6UO;B@I.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&-O;FYE8W0H*0H*("`@("\J
M*@H@("`@("H@0V]N;F5C="!T;R!T:&4@9&%T86)A<V4@<V5R=F5R+"!L;V<@
M:6X@86YD(&]P96X@=&AE(&1A=&%B87-E"B`@("`@*@H@("`@("H@1&]N)W0@
M8V%L;"!T:&ES(&UE=&AO9"!D:7)E8W1L>2X@(%5S92!$0CHZ8V]N;F5C="@I
M(&EN<W1E860N"B`@("`@*@H@("`@("H@4$5!4B!$0B=S(&EB87-E(&1R:79E
M<B!S=7!P;W)T<R!T:&4@9F]L;&]W:6YG(&5X=')A($133B!O<'1I;VYS.@H@
M("`@("H@("`K(&)U9F9E<G,@("`@5&AE(&YU;6)E<B!O9B!D871A8F%S92!B
M=69F97)S('1O(&%L;&]C871E(&9O<B!T:&4*("`@("`J("`@("`@("`@("`@
M("`@("!S97)V97(M<VED92!C86-H92X*("`@("`J("`@*R!C:&%R<V5T("`@
M(%1H92!D969A=6QT(&-H87)A8W1E<B!S970@9F]R(&$@9&%T86)A<V4N"B`@
M("`@*B`@("L@9&EA;&5C="`@("!4:&4@9&5F875L="!344P@9&EA;&5C="!F
M;W(@86YY('-T871E;65N=`H@("`@("H@("`@("`@("`@("`@("`@(&5X96-U
M=&5D('=I=&AI;B!A(&-O;FYE8W1I;VXN("!$969A=6QT<R!T;R!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("!H:6=H97-T(&]N92!S=7!P;W)T960@8GD@
M8VQI96YT(&QI8G)A<FEE<RX*("`@("`J("`@("`@("`@("`@("`@("!&=6YC
M=&EO;F%L(&]N;'D@=VET:"!);G1E<D)A<V4@-B!A;F0@=7`N"B`@("`@*B`@
M("L@<F]L92`@("`@("!&=6YC=&EO;F%L(&]N;'D@=VET:"!);G1E<D)A<V4@
M-2!A;F0@=7`N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1D<VX@("`@
M("`@("!T:&4@9&%T82!S;W5R8V4@;F%M90H@("`@("H@0'!A<F%M(&)O;VP@
M("1P97)S:7-T96YT("!S:&]U;&0@=&AE(&-O;FYE8W1I;VX@8F4@<&5R<VES
M=&5N=#\*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C
M8V5S<RX@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@8V]N;F5C="@D9'-N+"`D<&5R<VES=&5N="`](&9A;'-E
M*0H@("`@>PH@("`@("`@(&EF("@A4$5!4CHZ;&]A9$5X=&5N<VEO;B@G:6YT
M97)B87-E)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*$1"7T524D]27T585$5.4TE/3E].3U1?1D]53D0I.PH@("`@("`@('T*
M"B`@("`@("`@)'1H:7,M/F1S;B`]("1D<VX["B`@("`@("`@:68@*"1D<VY;
M)V1B<WEN=&%X)UTI('L*("`@("`@("`@("`@)'1H:7,M/F1B<WEN=&%X(#T@
M)&1S;ELG9&)S>6YT87@G73L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES
M+3YD8G-Y;G1A>"`]/2`G9FER96)I<F0G*2!["B`@("`@("`@("`@("1T:&ES
M+3YF96%T=7)E<ULG;&EM:70G72`]("=A;'1E<B<["B`@("`@("`@?0H*("`@
M("`@("`D<&%R86US(#T@87)R87DH"B`@("`@("`@("`@("1D<VY;)VAO<W1S
M<&5C)UT*("`@("`@("`@("`@("`@("`@("`_("@D9'-N6R=H;W-T<W!E8R==
M("X@)SHG("X@)&1S;ELG9&%T86)A<V4G72D*("`@("`@("`@("`@("`@("`@
M("`Z("1D<VY;)V1A=&%B87-E)UTL"B`@("`@("`@("`@("1D<VY;)W5S97)N
M86UE)UT@/R`D9'-N6R=U<V5R;F%M92==(#H@;G5L;"P*("`@("`@("`@("`@
M)&1S;ELG<&%S<W=O<F0G72`_("1D<VY;)W!A<W-W;W)D)UT@.B!N=6QL+`H@
M("`@("`@("`@("!I<W-E="@D9'-N6R=C:&%R<V5T)UTI(#\@)&1S;ELG8VAA
M<G-E="==(#H@;G5L;"P*("`@("`@("`@("`@:7-S970H)&1S;ELG8G5F9F5R
M<R==*2`_("1D<VY;)V)U9F9E<G,G72`Z(&YU;&PL"B`@("`@("`@("`@(&ES
M<V5T*"1D<VY;)V1I86QE8W0G72D@/R`D9'-N6R=D:6%L96-T)UT@.B!N=6QL
M+`H@("`@("`@("`@("!I<W-E="@D9'-N6R=R;VQE)UTI("`@(#\@)&1S;ELG
M<F]L92==(#H@;G5L;"P*("`@("`@("`I.PH*("`@("`@("`D8V]N;F5C=%]F
M=6YC=&EO;B`]("1P97)S:7-T96YT(#\@)VEB87-E7W!C;VYN96-T)R`Z("=I
M8F%S95]C;VYN96-T)SL*"B`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!`
M8V%L;%]U<V5R7V9U;F-?87)R87DH)&-O;FYE8W1?9G5N8W1I;VXL("1P87)A
M;7,I.PH@("`@("`@(&EF("@A)'1H:7,M/F-O;FYE8W1I;VXI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YI8F%S95)A:7-E17)R;W(H1$)?15)23U)?
M0T].3D5#5%]&04E,140I.PH@("`@("`@('T*("`@("`@("!R971U<FX@1$)?
M3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9&ES8V]N;F5C="@I
M"@H@("`@+RHJ"B`@("`@*B!$:7-C;VYN96-T<R!F<F]M('1H92!D871A8F%S
M92!S97)V97(*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@(%12544@;VX@
M<W5C8V5S<RP@1D%,4T4@;VX@9F%I;'5R90H@("`@("HO"B`@("!F=6YC=&EO
M;B!D:7-C;VYN96-T*"D*("`@('L*("`@("`@("`D<F5T(#T@0&EB87-E7V-L
M;W-E*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`D=&AI<RT^8V]N;F5C
M=&EO;B`](&YU;&P["B`@("`@("`@<F5T=7)N("1R970["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@<VEM<&QE475E<GDH*0H*("`@("\J*@H@("`@
M("H@4V5N9',@82!Q=65R>2!T;R!T:&4@9&%T86)A<V4@<V5R=F5R"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`@=&AE(%-13"!Q=65R>2!S=')I;F<*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("`K(&$@4$A0(')E<W5L="!R
M97-R;W5C92!F;W(@<W5C8V5S<V9U;"!314Q%0U0@<75E<FEE<PH@("`@("H@
M("`@("`@("`@("`@("`@*R!T:&4@1$)?3TL@8V]N<W1A;G0@9F]R(&]T:&5R
M('-U8V-E<W-F=6P@<75E<FEE<PH@("`@("H@("`@("`@("`@("`@("`@*R!A
M($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-I;7!L95%U97)Y*"1Q=65R>2D*("`@('L*("`@("`@("`D:7-M86YI
M<"`]($1".CII<TUA;FEP*"1Q=65R>2D["B`@("`@("`@)'1H:7,M/FQA<W1?
M<75E<GD@/2`D<75E<GD["B`@("`@("`@)'%U97)Y(#T@)'1H:7,M/FUO9&EF
M>5%U97)Y*"1Q=65R>2D["B`@("`@("`@)')E<W5L="`]($!I8F%S95]Q=65R
M>2@D=&AI<RT^8V]N;F5C=&EO;BP@)'%U97)Y*3L*"B`@("`@("`@:68@*"$D
M<F5S=6QT*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^:6)A<V5286ES
M945R<F]R*"D["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^875T;V-O
M;6UI="`F)B`D:7-M86YI<"D@>PH@("`@("`@("`@("!`:6)A<V5?8V]M;6ET
M*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("!]"B`@("`@("`@:68@*"1I
M<VUA;FEP*2!["B`@("`@("`@("`@("1T:&ES+3YA9F9E8W1E9"`]("1R97-U
M;'0["B`@("`@("`@("`@(')E='5R;B!$0E]/2SL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=&AI<RT^869F96-T960@/2`P.PH@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@;6]D:69Y3&EM:711=65R>2@I"@H@("`@+RHJ"B`@("`@
M*B!!9&1S($Q)34E4(&-L875S97,@=&\@82!Q=65R>2!S=')I;F<@86-C;W)D
M:6YG('1O(&-U<G)E;G0@1$)-4R!S=&%N9&%R9',*("`@("`J"B`@("`@*B!/
M;FQY('=O<FMS('=I=&@@1FER96)I<F0N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<75E<GD@("!T:&4@<75E<GD@=&\@;6]D:69Y"B`@("`@*B!`
M<&%R86T@:6YT("`@("1F<F]M("`@('1H92!R;W<@=&\@<W1A<G0@=&\@9F5T
M8VAI;F<@*#`@/2!T:&4@9FER<W0@<F]W*0H@("`@("H@0'!A<F%M(&EN="`@
M("`D8V]U;G0@("!T:&4@;G5M8F5R<R!O9B!R;W=S('1O(&9E=&-H"B`@("`@
M*B!`<&%R86T@;6EX960@("1P87)A;7,@(&%R<F%Y+"!S=')I;F<@;W(@;G5M
M97)I8R!D871A('1O(&)E('5S960@:6X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@(&5X96-U=&EO;B!O9B!T:&4@<W1A=&5M96YT+B`@475A;G1I
M='D@;V8@:71E;7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A
M<W-E9"!M=7-T(&UA=&-H('%U86YT:71Y(&]F('!L86-E:&]L9&5R<R!I;@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<75E<GDZ("!M96%N:6YG
M(#$@<&QA8V5H;VQD97(@9F]R(&YO;BUA<G)A>0H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@<&%R86UE=&5R<R!O<B`Q('!L86-E:&]L9&5R('!E
M<B!A<G)A>2!E;&5M96YT+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!T:&4@<75E<GD@<W1R:6YG('=I=&@@3$E-250@8VQA=7-E<R!A9&1E9`H@
M("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&UO9&EF>4QI;6ET475E<GDH)'%U97)Y+"`D9G)O;2P@)&-O=6YT
M+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H)'1H:7,M
M/F1S;ELG9&)S>6YT87@G72`]/2`G9FER96)I<F0G*2!["B`@("`@("`@("`@
M("1Q=65R>2`]('!R96=?<F5P;&%C92@G+UXH6UQS*%TI*E-%3$5#5"]I)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(")314Q%0U0@1DE2
M4U0@)&-O=6YT(%-+25`@)&9R;VTB+"`D<75E<GDI.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)'%U97)Y.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&YE>'1297-U;'0H*0H*("`@("\J*@H@("`@("H@36]V92!T:&4@:6YT
M97)N86P@:6)A<V4@<F5S=6QT('!O:6YT97(@=&\@=&AE(&YE>'0@879A:6QA
M8FQE(')E<W5L=`H@("`@("H*("`@("`J($!P87)A;2!A('9A;&ED(&9B<W%L
M(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*@H@("`@("H@0')E='5R;B!T<G5E(&EF(&$@<F5S=6QT(&ES(&%V
M86EL86)L92!O=&AE<G=I<V4@<F5T=7)N(&9A;'-E"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&YE>'1297-U;'0H)')E<W5L="D*("`@('L*("`@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9F5T8VA)
M;G1O*"D*"B`@("`O*BH*("`@("`J(%!L86-E<R!A(')O=R!F<F]M('1H92!R
M97-U;'0@<V5T(&EN=&\@=&AE(&=I=F5N(&%R<F%Y"B`@("`@*@H@("`@("H@
M1F]R;6%T:6YG(&]F('1H92!A<G)A>2!A;F0@=&AE(&1A=&$@=&AE<F5I;B!A
M<F4@8V]N9FEG=7)A8FQE+@H@("`@("H@4V5E($1"7W)E<W5L=#HZ9F5T8VA)
M;G1O*"D@9F]R(&UO<F4@:6YF;W)M871I;VXN"B`@("`@*@H@("`@("H@5&AI
M<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@
M(%5S90H@("`@("H@1$)?<F5S=6QT.CIF971C:$EN=&\H*2!I;G-T96%D+B`@
M270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U
M<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@("H*("`@
M("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("`@('1H92!Q=65R>2!R97-U
M;'0@<F5S;W5R8V4*("`@("`J($!P87)A;2!A<G)A>2`@("`D87)R("`@("`@
M('1H92!R969E<F5N8V5D(&%R<F%Y('1O('!U="!T:&4@9&%T82!I;@H@("`@
M("H@0'!A<F%M(&EN="`@("`@("1F971C:&UO9&4@:&]W('1H92!R97-U;'1I
M;F<@87)R87D@<VAO=6QD(&)E(&EN9&5X960*("`@("`J($!P87)A;2!I;G0@
M("`@("`D<F]W;G5M("`@('1H92!R;W<@;G5M8F5R('1O(&9E=&-H("@P(#T@
M9FER<W0@<F]W*0H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($1"7T]+
M(&]N('-U8V-E<W,L($Y53$P@=VAE;B!T:&4@96YD(&]F(&$@<F5S=6QT('-E
M="!I<PH@("`@("H@("`@("`@("`@("`@("`@(')E86-H960@;W(@;VX@9F%I
M;'5R90H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIF971C:$EN=&\H
M*0H@("`@("HO"B`@("!F=6YC=&EO;B!F971C:$EN=&\H)')E<W5L="P@)B1A
M<G(L("1F971C:&UO9&4L("1R;W=N=6T@/2!N=6QL*0H@("`@>PH@("`@("`@
M(&EF("@D<F]W;G5M("$]/2!N=6QL*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^:6)A<V5286ES945R<F]R*$1"7T524D]27TY/5%]#05!!0DQ%*3L*
M("`@("`@("!]"B`@("`@("`@:68@*"1F971C:&UO9&4@)B!$0E]&151#2$U/
M1$5?05-33T,I('L*("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G
M:6)A<V5?9F5T8VA?87-S;V,G*2D@>PH@("`@("`@("`@("`@("`@)&%R<B`]
M($!I8F%S95]F971C:%]A<W-O8R@D<F5S=6QT*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1A<G(@/2!G971?;V)J96-T7W9A<G,H
M:6)A<V5?9F5T8VA?;V)J96-T*"1R97-U;'0I*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@
M)B!$0E]03U)404))3$E465],3U=%4D-!4T4@)B8@)&%R<BD@>PH@("`@("`@
M("`@("`@("`@)&%R<B`](&%R<F%Y7V-H86YG95]K97E?8V%S92@D87)R+"!#
M05-%7TQ/5T52*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1A<G(@/2!`:6)A<V5?9F5T8VA?<F]W*"1R97-U;'0I.PH@
M("`@("`@('T*("`@("`@("!I9B`H(21A<G(I('L*("`@("`@("`@("`@<F5T
M=7)N(&YU;&P["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N
M<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197U)44DE-*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<G1R:6U!<G)A>59A;'5E<R@D87)R*3L*("`@
M("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET
M>2==("8@1$)?4$]25$%"24Q)5%E?3E5,3%]43U]%35!462D@>PH@("`@("`@
M("`@("`D=&AI<RT^7V-O;G9E<G1.=6QL07)R87E686QU97-4;T5M<'1Y*"1A
M<G(I.PH@("`@("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@9G)E95)E<W5L="@I"@H@("`@+RHJ"B`@
M("`@*B!$96QE=&5S('1H92!R97-U;'0@<V5T(&%N9"!F<F5E<R!T:&4@;65M
M;W)Y(&]C8W5P:65D(&)Y('1H92!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@
M5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L
M>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIF<F5E*"D@:6YS=&5A9"X@($ET
M(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E
M($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT
M(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("!44E5%(&]N
M('-U8V-E<W,L($9!3%-%(&EF("1R97-U;'0@:7,@:6YV86QI9`H@("`@("H*
M("`@("`J($!S964@1$)?<F5S=6QT.CIF<F5E*"D*("`@("`J+PH@("`@9G5N
M8W1I;VX@9G)E95)E<W5L="@D<F5S=6QT*0H@("`@>PH@("`@("`@(')E='5R
M;B!`:6)A<V5?9G)E95]R97-U;'0H)')E<W5L="D["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@9G)E95%U97)Y*"D*"B`@("!F=6YC=&EO;B!F<F5E
M475E<GDH)'%U97)Y*0H@("`@>PH@("`@("`@($!I8F%S95]F<F5E7W%U97)Y
M*"1Q=65R>2D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@869F96-T9612;W=S*"D*"B`@("`O*BH*("`@("`J
M($1E=&5R;6EN97,@=&AE(&YU;6)E<B!O9B!R;W=S(&%F9F5C=&5D(&)Y(&$@
M9&%T82!M86YI=7!L871I;VX@<75E<GD*("`@("`J"B`@("`@*B`P(&ES(')E
M='5R;F5D(&9O<B!Q=65R:65S('1H870@9&]N)W0@;6%N:7!U;&%T92!D871A
M+@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(')O
M=W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!A9F9E8W1E9%)O=W,H*0H@("`@>PH@("`@("`@(&EF("AI
M<U]I;G1E9V5R*"1T:&ES+3YA9F9E8W1E9"DI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YA9F9E8W1E9#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1T:&ES+3YI8F%S95)A:7-E17)R;W(H1$)?15)23U)?3D]47T-!4$%"3$4I
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YU;4-O;',H*0H*("`@
M("\J*@H@("`@("H@1V5T<R!T:&4@;G5M8F5R(&]F(&-O;'5M;G,@:6X@82!R
M97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE
M86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S
M=6QT.CIN=6U#;VQS*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D
M(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A('-E
M<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@
M)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@8V]L=6UN<RX@($$@
M1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E
M92!$0E]R97-U;'0Z.FYU;4-O;',H*0H@("`@("HO"B`@("!F=6YC=&EO;B!N
M=6U#;VQS*"1R97-U;'0I"B`@("!["B`@("`@("`@)&-O;',@/2!`:6)A<V5?
M;G5M7V9I96QD<R@D<F5S=6QT*3L*("`@("`@("!I9B`H(21C;VQS*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^:6)A<V5286ES945R<F]R*"D["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D8V]L<SL*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!P<F5P87)E*"D*"B`@("`O*BH*("`@("`J(%!R97!A
M<F5S(&$@<75E<GD@9F]R(&UU;'1I<&QE(&5X96-U=&EO;B!W:71H(&5X96-U
M=&4H*2X*("`@("`J"B`@("`@*B!P<F5P87)E*"D@<F5Q=6ER97,@82!G96YE
M<FEC('%U97)Y(&%S('-T<FEN9R!L:6ME(#QC;V1E/@H@("`@("H@("`@24Y3
M15)4($E.5$\@;G5M8F5R<R!604Q515,@*#\L(#\L(#\I"B`@("`@*B`\+V-O
M9&4^+B`@5&AE(#QK8F0^/SPO:V)D/B!C:&%R86-T97)S(&%R92!P;&%C96AO
M;&1E<G,N"B`@("`@*@H@("`@("H@5&AR964@='EP97,@;V8@<&QA8V5H;VQD
M97)S(&-A;B!B92!U<V5D.@H@("`@("H@("`K(#QK8F0^/SPO:V)D/B`@82!Q
M=6]T960@<V-A;&%R('9A;'5E+"!I+F4N('-T<FEN9W,L(&EN=&5G97)S"B`@
M("`@*B`@("L@/&MB9#XA/"]K8F0^("!V86QU92!I<R!I;G-E<G1E9"`G87,@
M:7,G"B`@("`@*B`@("L@/&MB9#XF/"]K8F0^("!R97%U:7)E<R!A(&9I;&4@
M;F%M92X@(%1H92!F:6QE)W,@8V]N=&5N=',@9V5T"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@(&EN<V5R=&5D(&EN=&\@=&AE('%U97)Y("AI+F4N('-A
M=FEN9R!B:6YA<GD*("`@("`J("`@("`@("`@("`@("`@("`@("`@9&%T82!I
M;B!A(&1B*0H@("`@("H*("`@("`J(%5S92!B86-K<VQA<VAE<R!T;R!E<V-A
M<&4@<&QA8V5H;VQD97(@8VAA<F%C=&5R<R!I9B!Y;W4@9&]N)W0@=V%N=`H@
M("`@("H@=&AE;2!T;R!B92!I;G1E<G!R971E9"!A<R!P;&%C96AO;&1E<G,N
M("!%>&%M<&QE.B`\8V]D93X*("`@("`J("`@(")54$1!5$4@9F]O(%-%5"!C
M;VP]/R!72$5212!C;VP])V]V97(@7"8@=6YD97(G(@H@("`@("H@/"]C;V1E
M/@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'%U97)Y('%U97)Y('1O
M(&)E('!R97!A<F5D"B`@("`@*B!`<F5T=7)N(&UI>&5D($1"('-T871E;65N
M="!R97-O=7)C92!O;B!S=6-C97-S+B!$0E]%<G)O<B!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!P<F5P87)E*"1Q=65R>2D*("`@('L*("`@
M("`@("`D=&]K96YS("`@/2!P<F5G7W-P;&ET*"<O*"@_/"%<7%PI6R8_(5TI
M+R<L("1Q=65R>2P@+3$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!04D5'7U-03$E47T1%3$E-7T-!4%154D4I.PH@("`@("`@("1T;VME;B`@
M("`](#`["B`@("`@("`@)'1Y<&5S("`@(#T@87)R87DH*3L*("`@("`@("`D
M;F5W<75E<GD@/2`G)SL*"B`@("`@("`@9F]R96%C:"`H)'1O:V5N<R!A<R`D
M:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@<W=I=&-H("@D=F%L*2!["B`@
M("`@("`@("`@("`@("!C87-E("<_)SH*("`@("`@("`@("`@("`@("`@("`D
M='EP97-;)'1O:V5N*RM=(#T@1$)?4$%204U?4T-!3$%2.PH@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`G)B<Z"B`@
M("`@("`@("`@("`@("`@("`@)'1Y<&5S6R1T;VME;BLK72`]($1"7U!!4D%-
M7T]005%513L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@(&-A<V4@)R$G.@H@("`@("`@("`@("`@("`@("`@("1T>7!E<ULD
M=&]K96XK*UT@/2!$0E]005)!35]-25-#.PH@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@
M("`@("`@("`D=&]K96YS6R1K97E=(#T@<')E9U]R97!L86-E*"<O7%Q<*%LF
M/R%=*2\G+"`B7%PQ(BP@)'9A;"D["B`@("`@("`@("`@("`@("`@("`@)&YE
M=W%U97)Y("X]("1T;VME;G-;)&ME>5T@+B`G/R<["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("1N97=Q=65R>2`]('-U8G-T<B@D;F5W<75E
M<GDL(#`L("TQ*3L*("`@("`@("`D=&AI<RT^;&%S=%]Q=65R>2`]("1Q=65R
M>3L*("`@("`@("`D;F5W<75E<GD@/2`D=&AI<RT^;6]D:69Y475E<GDH)&YE
M=W%U97)Y*3L*("`@("`@("`D<W1M="`]($!I8F%S95]P<F5P87)E*"1T:&ES
M+3YC;VYN96-T:6]N+"`D;F5W<75E<GDI.PH@("`@("`@("1T:&ES+3YP<F5P
M87)E7W1Y<&5S6RAI;G0I)'-T;71=(#T@)'1Y<&5S.PH@("`@("`@("1T:&ES
M+3YM86YI<%]Q=65R>5LH:6YT*21S=&UT72`@(#T@1$(Z.FES36%N:7`H)'%U
M97)Y*3L*("`@("`@("!R971U<FX@)'-T;70["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@97AE8W5T92@I"@H@("`@+RHJ"B`@("`@*B!%>&5C=71E
M<R!A($1"('-T871E;65N="!P<F5P87)E9"!W:71H('!R97!A<F4H*2X*("`@
M("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@("1S=&UT("!A($1"('-T871E
M;65N="!R97-O=7)C92!R971U<FYE9"!F<F]M('!R97!A<F4H*0H@("`@("H@
M0'!A<F%M(&UI>&5D("`D9&%T82`@87)R87DL('-T<FEN9R!O<B!N=6UE<FEC
M(&1A=&$@=&\@8F4@=7-E9"!I;@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@97AE8W5T:6]N(&]F('1H92!S=&%T96UE;G0N("!1=6%N=&ET>2!O9B!I
M=&5M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@<&%S<V5D(&UU<W0@
M;6%T8V@@<75A;G1I='D@;V8@<&QA8V5H;VQD97)S(&EN"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("!Q=65R>3H@(&UE86YI;F<@,2!F;W(@;F]N+6%R
M<F%Y(&ET96US(&]R('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M<75A;G1I='D@;V8@96QE;65N=',@:6X@=&AE(&%R<F%Y+@H@("`@("H@0')E
M='5R;B!O8FIE8W0@(&$@;F5W($1"7U)E<W5L="!O<B!A($1"7T5R<F]R('=H
M96X@9F%I;`H@("`@("H@0'-E92!$0E]I8F%S93HZ<')E<&%R92@I"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B`F97AE8W5T
M92@D<W1M="P@)&1A=&$@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1D871A
M(#T@*&%R<F%Y*21D871A.PH@("`@("`@("1T:&ES+3YL87-T7W!A<F%M971E
M<G,@/2`D9&%T83L*"B`@("`@("`@)'1Y<&5S(#TF("1T:&ES+3YP<F5P87)E
M7W1Y<&5S6RAI;G0I)'-T;71=.PH@("`@("`@(&EF("AC;W5N="@D='EP97,I
M("$](&-O=6YT*"1D871A*2D@>PH@("`@("`@("`@("`D=&UP(#TF("1T:&ES
M+3YR86ES945R<F]R*$1"7T524D]27TU)4TU!5$-(*3L*("`@("`@("`@("`@
M<F5T=7)N("1T;7`["B`@("`@("`@?0H*("`@("`@("`D:2`](#`["B`@("`@
M("`@9F]R96%C:"`H)&1A=&$@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@
M("`@("`@:68@*"1T>7!E<ULD:5T@/3T@1$)?4$%204U?34E30RD@>PH@("`@
M("`@("`@("`@("`@+RH*("`@("`@("`@("`@("`@("`J(&EB87-E(&1O97-N
M)W0@<V5E;2!T;R!H879E('1H92!A8FEL:71Y('1O('!A<W,@80H@("`@("`@
M("`@("`@("`@("H@<&%R86UE=&5R(&%L;VYG('5N8VAA;F=E9"P@<V\@<W1R
M:7`@;V9F('%U;W1E<R!F<F]M('-T87)T"B`@("`@("`@("`@("`@("`@*B!A
M;F0@96YD+"!P;'5S('1U<FX@='=O('-I;F=L92!Q=6]T97,@=&\@;VYE('-I
M;F=L92!Q=6]T92P*("`@("`@("`@("`@("`@("`J(&EN(&]R9&5R('1O(&%V
M;VED('1H92!Q=6]T97,@9V5T=&EN9R!E<V-A<&5D(&)Y"B`@("`@("`@("`@
M("`@("`@*B!I8F%S92!A;F0@96YD:6YG('5P(&EN('1H92!D871A8F%S92X*
M("`@("`@("`@("`@("`@("`J+PH@("`@("`@("`@("`@("`@)&1A=&%;)&ME
M>5T@/2!P<F5G7W)E<&QA8V4H(B]>)R@N*BDG)"\B+"`B7%PQ(BP@)&1A=&%;
M)&ME>5TI.PH@("`@("`@("`@("`@("`@)&1A=&%;)&ME>5T@/2!S=')?<F5P
M;&%C92@B)R<B+"`B)R(L("1D871A6R1K97E=*3L*("`@("`@("`@("`@?2!E
M;'-E:68@*"1T>7!E<ULD:5T@/3T@1$)?4$%204U?3U!!455%*2!["B`@("`@
M("`@("`@("`@("`D9G`@/2!`9F]P96XH)&1A=&%;)&ME>5TL("=R8B<I.PH@
M("`@("`@("`@("`@("`@:68@*"$D9G`I('L*("`@("`@("`@("`@("`@("`@
M("`D=&UP(#TF("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27T%#0T534U]6
M24],051)3TXI.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&UP.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&1A=&%;)&ME>5T@
M/2!F<F5A9"@D9G`L(&9I;&5S:7IE*"1D871A6R1K97E=*2D["B`@("`@("`@
M("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D:2LK.PH@("`@("`@('T*"B`@("`@("`@87)R87E?=6YS:&EF="@D9&%T
M82P@)'-T;70I.PH*("`@("`@("`D<F5S(#T@8V%L;%]U<V5R7V9U;F-?87)R
M87DH)VEB87-E7V5X96-U=&4G+"`D9&%T82D["B`@("`@("`@:68@*"$D<F5S
M*2!["B`@("`@("`@("`@("1T;7`@/28@)'1H:7,M/FEB87-E4F%I<V5%<G)O
M<B@I.PH@("`@("`@("`@("!R971U<FX@)'1M<#L*("`@("`@("!]"B`@("`@
M("`@+RH@6%A8(&YE960@=&AI<S\*("`@("`@("!I9B`H)'1H:7,M/F%U=&]C
M;VUM:70@)B8@)'1H:7,M/FUA;FEP7W%U97)Y6RAI;G0I)'-T;71=*2!["B`@
M("`@("`@("`@($!I8F%S95]C;VUM:70H)'1H:7,M/F-O;FYE8W1I;VXI.PH@
M("`@("`@('TJ+PH@("`@("`@("1T:&ES+3YL87-T7W-T;70@/2`D<W1M=#L*
M("`@("`@("!I9B`H)'1H:7,M/FUA;FEP7W%U97)Y6RAI;G0I)'-T;71=*2![
M"B`@("`@("`@("`@("1T;7`@/2!$0E]/2SL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D=&UP(#TF(&YE=R!$0E]R97-U;'0H)'1H:7,L("1R97,I
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1M<#L*("`@('T*"B`@("`O
M*BH*("`@("`J($9R965S('1H92!I;G1E<FYA;"!R97-O=7)C97,@87-S;V-I
M871E9"!W:71H(&$@<')E<&%R960@<75E<GD*("`@("`J"B`@("`@*B!`<&%R
M86T@<F5S;W5R8V4@)'-T;70@("`@("`@("`@('1H92!P<F5P87)E9"!S=&%T
M96UE;G0G<R!02%`@<F5S;W5R8V4*("`@("`J($!P87)A;2!B;V]L("`@("`D
M9G)E95]R97-O=7)C92`@<VAO=6QD('1H92!02%`@<F5S;W5R8V4@8F4@9G)E
M960@=&]O/PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@57-E(&9A;'-E(&EF('EO=2!N965D('1O(&=E="!D871A"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F<F]M('1H92!R97-U
M;'0@<V5T(&QA=&5R+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@5%)5
M12!O;B!S=6-C97-S+"!&04Q312!I9B`D<F5S=6QT(&ES(&EN=F%L:60*("`@
M("`J"B`@("`@*B!`<V5E($1"7VEB87-E.CIP<F5P87)E*"D*("`@("`J+PH@
M("`@9G5N8W1I;VX@9G)E95!R97!A<F5D*"1S=&UT+"`D9G)E95]R97-O=7)C
M92`]('1R=64I"B`@("!["B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D<W1M
M="DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@
M("`@("!I9B`H)&9R965?<F5S;W5R8V4I('L*("`@("`@("`@("`@0&EB87-E
M7V9R965?<75E<GDH)'-T;70I.PH@("`@("`@('T*("`@("`@("!U;G-E="@D
M=&AI<RT^<')E<&%R95]T;VME;G-;*&EN="DD<W1M=%TI.PH@("`@("`@('5N
M<V5T*"1T:&ES+3YP<F5P87)E7W1Y<&5S6RAI;G0I)'-T;71=*3L*("`@("`@
M("!U;G-E="@D=&AI<RT^;6%N:7!?<75E<GE;*&EN="DD<W1M=%TI.PH@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&%U=&]#;VUM:70H*0H*("`@("\J*@H@("`@("H@16YA8FQE<R!O<B!D:7-A
M8FQE<R!A=71O;6%T:6,@8V]M;6ET<PH@("`@("H*("`@("`J($!P87)A;2!B
M;V]L("1O;F]F9B`@=')U92!T=7)N<R!I="!O;BP@9F%L<V4@='5R;G,@:70@
M;V9F"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E
M<W,N("!!($1"7T5R<F]R(&]B:F5C="!I9B!T:&4@9')I=F5R"B`@("`@*B`@
M("`@("`@("`@("`@(&1O97-N)W0@<W5P<&]R="!A=71O+6-O;6UI='1I;F<@
M=')A;G-A8W1I;VYS+@H@("`@("HO"B`@("!F=6YC=&EO;B!A=71O0V]M;6ET
M*"1O;F]F9B`](&9A;'-E*0H@("`@>PH@("`@("`@("1T:&ES+3YA=71O8V]M
M;6ET(#T@)&]N;V9F(#\@,2`Z(#`["B`@("`@("`@<F5T=7)N($1"7T]+.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&-O;6UI="@I"@H@("`@+RHJ
M"B`@("`@*B!#;VUM:71S('1H92!C=7)R96YT('1R86YS86-T:6]N"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!C;VUM:70H*0H@("`@>PH@("`@("`@(')E='5R;B!`:6)A<V5?8V]M;6ET
M*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!R;VQL8F%C:R@I"@H@("`@+RHJ"B`@("`@*B!2979E<G1S('1H92!C
M=7)R96YT('1R86YS86-T:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@
M($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R;VQL8F%C:R@I"B`@("!["B`@
M("`@("`@<F5T=7)N($!I8F%S95]R;VQL8F%C:R@D=&AI<RT^8V]N;F5C=&EO
M;BD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@=')A;G-A8W1I;VY)
M;FET*"D*"B`@("!F=6YC=&EO;B!T<F%N<V%C=&EO;DEN:70H)'1R86YS7V%R
M9W,@/2`P*0H@("`@>PH@("`@("`@(')E='5R;B`D=')A;G-?87)G<PH@("`@
M("`@("`@("`@("`@/R!`:6)A<V5?=')A;G,H)'1R86YS7V%R9W,L("1T:&ES
M+3YC;VYN96-T:6]N*0H@("`@("`@("`@("`@("`@.B!`:6)A<V5?=')A;G,H
M*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N97AT260H*0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;F5X="!F<F5E(&ED(&EN(&$@<V5Q
M=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V5Q7VYA;64@
M(&YA;64@;V8@=&AE('-E<75E;F-E"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M;VYD96UA;F0@('=H96X@=')U92P@=&AE('-E<65N8V4@:7,@875T;VUA=&EC
M86QL>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8W)E871E
M9"!I9B!I="!D;V5S(&YO="!E>&ES=`H@("`@("H*("`@("`J($!R971U<FX@
M:6YT("!T:&4@;F5X="!I9"!N=6UB97(@:6X@=&AE('-E<75E;F-E+@H@("`@
M("H@("`@("`@("`@("`@("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIN97AT240H*2P@1$)?
M8V]M;6]N.CIG971397%U96YC94YA;64H*2P*("`@("`J("`@("`@1$)?:6)A
M<V4Z.F-R96%T95-E<75E;F-E*"DL($1"7VEB87-E.CID<F]P4V5Q=65N8V4H
M*0H@("`@("HO"B`@("!F=6YC=&EO;B!N97AT260H)'-E<5]N86UE+"`D;VYD
M96UA;F0@/2!T<G5E*0H@("`@>PH@("`@("`@("1S<6X@/2!S=')T;W5P<&5R
M*"1T:&ES+3YG971397%U96YC94YA;64H)'-E<5]N86UE*2D["B`@("`@("`@
M)')E<&5A="`](#`["B`@("`@("`@9&\@>PH@("`@("`@("`@("`D=&AI<RT^
M<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PH@("`@("`@
M("`@("`D<F5S=6QT(#TF("1T:&ES+3YQ=65R>2@B4T5,14-4($=%3E])1"@D
M>W-Q;GTL(#$I("(*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`N("=&4D]-(%)$0B1'14Y%4D%43U)3("<*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`N(")72$5212!21$)<)$=%3D52051/4E].04U%
M/2<D>W-Q;GTG(BD["B`@("`@("`@("`@("1T:&ES+3YP;W!%<G)O<DAA;F1L
M:6YG*"D["B`@("`@("`@("`@(&EF("@D;VYD96UA;F0@)B8@1$(Z.FES17)R
M;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@("1R97!E870@/2`Q.PH@
M("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YC<F5A=&5397%U96YC
M92@D<V5Q7VYA;64I.PH@("`@("`@("`@("`@("`@:68@*$1".CII<T5R<F]R
M*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D<F5P96%T(#T@,#L*("`@("`@("`@("`@?0H@("`@
M("`@('T@=VAI;&4@*"1R97!E870I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O
M<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)')E<W5L="D["B`@("`@("`@?0H@("`@("`@("1A<G(@/2`D<F5S
M=6QT+3YF971C:%)O=RA$0E]&151#2$U/1$5?3U)$15)%1"D["B`@("`@("`@
M)')E<W5L="T^9G)E92@I.PH@("`@("`@(')E='5R;B`D87)R6S!=.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&-R96%T95-E<75E;F-E*"D*"B`@
M("`O*BH*("`@("`J($-R96%T97,@82!N97<@<V5Q=65N8V4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1S97%?;F%M92`@;F%M92!O9B!T:&4@;F5W
M('-E<75E;F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N
M('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("H*("`@("`J($!S964@1$)?8V]M;6]N.CIC<F5A=&5397%U96YC92@I+"!$
M0E]C;VUM;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@("`@("!$0E]I
M8F%S93HZ;F5X=$E$*"DL($1"7VEB87-E.CID<F]P4V5Q=65N8V4H*0H@("`@
M("HO"B`@("!F=6YC=&EO;B!C<F5A=&5397%U96YC92@D<V5Q7VYA;64I"B`@
M("!["B`@("`@("`@)'-Q;B`]('-T<G1O=7!P97(H)'1H:7,M/F=E=%-E<75E
M;F-E3F%M92@D<V5Q7VYA;64I*3L*("`@("`@("`D=&AI<RT^<'5S:$5R<F]R
M2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PH@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^<75E<GDH(D-214%412!'14Y%4D%43U(@)'MS<6Y](BD["B`@
M("`@("`@)'1H:7,M/G!O<$5R<F]R2&%N9&QI;F<H*3L*"B`@("`@("`@<F5T
M=7)N("1R97-U;'0["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9')O
M<%-E<75E;F-E*"D*"B`@("`O*BH*("`@("`J($1E;&5T97,@82!S97%U96YC
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-E<5]N86UE("!N86UE
M(&]F('1H92!S97%U96YC92!T;R!B92!D96QE=&5D"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N
M.CID<F]P4V5Q=65N8V4H*2P@1$)?8V]M;6]N.CIG971397%U96YC94YA;64H
M*2P*("`@("`J("`@("`@1$)?:6)A<V4Z.FYE>'1)1"@I+"!$0E]I8F%S93HZ
M8W)E871E4V5Q=65N8V4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!D<F]P4V5Q
M=65N8V4H)'-E<5]N86UE*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M<75E<GDH)T1%3$5412!&4D]-(%)$0B1'14Y%4D%43U)3("<*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("X@(E=(15)%(%)$0EPD1T5.15)!5$]27TY!
M344])R(*("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@<W1R=&]U<'!E
M<B@D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M92DI"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`N("(G(BD["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@7VEB87-E1FEE;&1&;&%G<R@I"@H@("`@+RHJ"B`@("`@
M*B!'970@=&AE(&-O;'5M;B=S(&9L86=S"B`@("`@*@H@("`@("H@4W5P<&]R
M=',@(G!R:6UA<GE?:V5Y(BP@(G5N:7%U95]K97DB+"`B;F]T7VYU;&PB+"`B
M9&5F875L="(L"B`@("`@*B`B8V]M<'5T960B(&%N9"`B8FQO8B(N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEE;&1?;F%M92`@=&AE(&YA;64@
M;V8@=&AE(&9I96QD"B`@("`@*B!`<&%R86T@<W1R:6YG("1T86)L95]N86UE
M("!T:&4@;F%M92!O9B!T:&4@=&%B;&4*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@=&AE(&9L86=S"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]I8F%S949I96QD1FQA9W,H)&9I
M96QD7VYA;64L("1T86)L95]N86UE*0H@("`@>PH@("`@("`@("1S<6P@/2`G
M4T5,14-4(%(N4D1")$-/3E-44D%)3E1?5%E012!#5%E012<*("`@("`@("`@
M("`@("`@+B<@1E)/32!21$(D24Y$15A?4T5'345.5%,@22<*("`@("`@("`@
M("`@("`@+B<@($I/24X@4D1")%)%3$%424].7T-/3E-44D%)3E13(%(@3TX@
M22Y21$(D24Y$15A?3D%-13U2+E)$0B1)3D1%6%].04U%)PH@("`@("`@("`@
M("`@("`N)R!72$5212!)+E)$0B1&245,1%].04U%/5PG)R`N("1F:65L9%]N
M86UE("X@)UPG)PH@("`@("`@("`@("`@("`N)R`@04Y$(%504$52*%(N4D1"
M)%)%3$%424].7TY!344I/5PG)R`N('-T<G1O=7!P97(H)'1A8FQE7VYA;64I
M("X@)UPG)SL*"B`@("`@("`@)')E<W5L="`]($!I8F%S95]Q=65R>2@D=&AI
M<RT^8V]N;F5C=&EO;BP@)'-Q;"D["B`@("`@("`@:68@*"$D<F5S=6QT*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^:6)A<V5286ES945R<F]R*"D[
M"B`@("`@("`@?0H*("`@("`@("`D9FQA9W,@/2`G)SL*("`@("`@("!I9B`H
M)&]B:B`]($!I8F%S95]F971C:%]O8FIE8W0H)')E<W5L="DI('L*("`@("`@
M("`@("`@0&EB87-E7V9R965?<F5S=6QT*"1R97-U;'0I.PH@("`@("`@("`@
M("!I9B`H:7-S970H)&]B:BT^0U194$4I("`F)B!T<FEM*"1O8FHM/D-465!%
M*2`]/2`G4%))34%262!+15DG*2!["B`@("`@("`@("`@("`@("`D9FQA9W,@
M+CT@)W!R:6UA<GE?:V5Y("<["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*&ES<V5T*"1O8FHM/D-465!%*2`@)B8@=')I;2@D;V)J+3Y#5%E012D@
M/3T@)U5.25%512<I('L*("`@("`@("`@("`@("`@("1F;&%G<R`N/2`G=6YI
M<75E7VME>2`G.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D
M<W%L(#T@)U-%3$5#5"!2+E)$0B1.54Q,7T9,04<@05,@3D9,04<L)PH@("`@
M("`@("`@("`@("`N)R`@4BY21$(D1$5&055,5%]33U520T4@05,@1%-/55)#
M12PG"B`@("`@("`@("`@("`@("XG("!&+E)$0B1&245,1%]465!%($%3($94
M65!%+"<*("`@("`@("`@("`@("`@+B<@($8N4D1")$-/35!55$5$7U-/55)#
M12!!4R!#4T]54D-%)PH@("`@("`@("`@("`@("`N)R!&4D]-(%)$0B1214Q!
M5$E/3E]&245,1%,@4B`G"B`@("`@("`@("`@("`@("XG("!*3TE.(%)$0B1&
M245,1%,@1B!/3B!2+E)$0B1&245,1%]33U520T4]1BY21$(D1DE%3$1?3D%-
M12<*("`@("`@("`@("`@("`@+B<@5TA%4D4@55!015(H4BY21$(D4D5,051)
M3TY?3D%-12D]7"<G("X@<W1R=&]U<'!E<B@D=&%B;&5?;F%M92D@+B`G7"<G
M"B`@("`@("`@("`@("`@("XG("!!3D0@4BY21$(D1DE%3$1?3D%-13U<)R<@
M+B`D9FEE;&1?;F%M92`N("=<)R<["@H@("`@("`@("1R97-U;'0@/2!`:6)A
M<V5?<75E<GDH)'1H:7,M/F-O;FYE8W1I;VXL("1S<6PI.PH@("`@("`@(&EF
M("@A)')E<W5L="D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FEB87-E
M4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("!I9B`H)&]B:B`]($!I
M8F%S95]F971C:%]O8FIE8W0H)')E<W5L="DI('L*("`@("`@("`@("`@0&EB
M87-E7V9R965?<F5S=6QT*"1R97-U;'0I.PH@("`@("`@("`@("!I9B`H:7-S
M970H)&]B:BT^3D9,04<I*2!["B`@("`@("`@("`@("`@("`D9FQA9W,@+CT@
M)VYO=%]N=6QL("<["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES
M<V5T*"1O8FHM/D133U520T4I*2!["B`@("`@("`@("`@("`@("`D9FQA9W,@
M+CT@)V1E9F%U;'0@)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M:7-S970H)&]B:BT^0U-/55)#12DI('L*("`@("`@("`@("`@("`@("1F;&%G
M<R`N/2`G8V]M<'5T960@)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H:7-S970H)&]B:BT^1E194$4I("`F)B`D;V)J+3Y&5%E012`]/2`R-C$I
M('L*("`@("`@("`@("`@("`@("1F;&%G<R`N/2`G8FQO8B`G.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')I;2@D9FQA9W,I
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&EB87-E4F%I<V5%<G)O
M<B@I"@H@("`@+RHJ"B`@("`@*B!0<F]D=6-E<R!A($1"7T5R<F]R(&]B:F5C
M="!R96=A<F1I;F<@=&AE(&-U<G)E;G0@<')O8FQE;0H@("`@("H*("`@("`J
M($!P87)A;2!I;G0@)&5R<FYO("!I9B!T:&4@97)R;W(@:7,@8F5I;F<@;6%N
M=6%L;'D@<F%I<V5D('!A<W,@80H@("`@("H@("`@("`@("`@("`@("`@("`@
M("!$0E]%4E)/4BH@8V]N<W1A;G0@:&5R92X@($EF('1H:7,@:7-N)W0@<&%S
M<V5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@('1H92!E<G)O<B!I;F9O
M<FUA=&EO;B!G871H97)E9"!F<F]M('1H92!$0DU3+@H@("`@("H*("`@("`J
M($!R971U<FX@;V)J96-T("!T:&4@1$)?17)R;W(@;V)J96-T"B`@("`@*@H@
M("`@("H@0'-E92!$0E]C;VUM;VXZ.G)A:7-E17)R;W(H*2P*("`@("`J("`@
M("`@1$)?:6)A<V4Z.F5R<F]R3F%T:79E*"DL($1"7VEB87-E.CIE<G)O<D-O
M9&4H*0H@("`@("HO"B`@("!F=6YC=&EO;B`F:6)A<V5286ES945R<F]R*"1E
M<G)N;R`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"1E<G)N;R`]/3T@;G5L
M;"D@>PH@("`@("`@("`@("`D97)R;F\@/2`D=&AI<RT^97)R;W)#;V1E*"1T
M:&ES+3YE<G)O<DYA=&EV92@I*3L*("`@("`@("!]"B`@("`@("`@)'1M<"`]
M)B`D=&AI<RT^<F%I<V5%<G)O<B@D97)R;F\L(&YU;&PL(&YU;&PL(&YU;&PL
M($!I8F%S95]E<G)M<V<H*2D["B`@("`@("`@<F5T=7)N("1T;7`["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97)R;W).871I=F4H*0H*("`@("\J
M*@H@("`@("H@1V5T<R!T:&4@1$)-4R<@;F%T:79E(&5R<F]R(&-O9&4@<')O
M9'5C960@8GD@=&AE(&QA<W0@<75E<GD*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN="`@=&AE($1"35,G(&5R<F]R(&-O9&4N("!.54Q,(&EF('1H97)E(&ES
M(&YO(&5R<F]R(&-O9&4N"B`@("`@*@H@("`@("H@0'-I;F-E($UE=&AO9"!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C<N,`H@("`@("HO"B`@("!F=6YC
M=&EO;B!E<G)O<DYA=&EV92@I"B`@("!["B`@("`@("`@:68@*&9U;F-T:6]N
M7V5X:7-T<R@G:6)A<V5?97)R8V]D92<I*2!["B`@("`@("`@("`@(')E='5R
M;B!`:6)A<V5?97)R8V]D92@I.PH@("`@("`@('T*("`@("`@("!I9B`H<')E
M9U]M871C:"@G+UY$>6YA;6EC(%-13"!%<G)O<B!344P@97)R;W(@8V]D92`]
M("A;,"TY+5TK*2]I)RP*("`@("`@("`@("`@("`@("`@("`@("!`:6)A<V5?
M97)R;7-G*"DL("1M*2D@>PH@("`@("`@("`@("!R971U<FX@*&EN="DD;5LQ
M73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@97)R;W)#;V1E*"D*"B`@("`O*BH*("`@("`J
M($UA<',@;F%T:79E(&5R<F]R(&-O9&5S('1O($1")W,@<&]R=&%B;&4@;VYE
M<PH@("`@("H*("`@("`J($!P87)A;2!I;G0@)&YA=&EV96-O9&4@('1H92!E
M<G)O<B!C;V1E(')E='5R;F5D(&)Y('1H92!$0DU3"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G0@('1H92!P;W)T86)L92!$0B!E<G)O<B!C;V1E+B`@4F5T
M=7)N($1"7T524D]2(&EF('1H90H@("`@("H@("`@("`@("`@("`@("!C=7)R
M96YT(&1R:79E<B!D;V5S;B=T(&AA=F4@82!M87!P:6YG(&9O<B!T:&4*("`@
M("`J("`@("`@("`@("`@("`@)&YA=&EV96-O9&4@<W5B;6ET=&5D+@H@("`@
M("H*("`@("`J($!S:6YC92!-971H;V0@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XW+C`*("`@("`J+PH@("`@9G5N8W1I;VX@97)R;W)#;V1E*"1N871I
M=F5C;V1E(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/F5R<F]R8V]D95]M87!;)&YA=&EV96-O9&5=*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/F5R<F]R8V]D95]M87!;)&YA=&EV96-O9&5=.PH@("`@
M("`@('T*"B`@("`@("`@<W1A=&EC("1E<G)O<E]R96=E>'!S.PH@("`@("`@
M(&EF("@A:7-S970H)&5R<F]R7W)E9V5X<',I*2!["B`@("`@("`@("`@("1E
M<G)O<E]R96=E>'!S(#T@87)R87DH"B`@("`@("`@("`@("`@("`G+V=E;F5R
M871O<B`N*B!I<R!N;W0@9&5F:6YE9"\G"B`@("`@("`@("`@("`@("`@("`@
M/3X@1$)?15)23U)?4UE.5$%8+"`@+R\@9F]R(&-O;7!A="X@=R!I8F%S95]E
M<G)C;V1E*"D*("`@("`@("`@("`@("`@("<O=&%B;&4N*BAN;W0@97AI<W1\
M;F]T(&9O=6YD?'5N:VYO=VXI+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@
M1$)?15)23U)?3D]354-(5$%"3$4L"B`@("`@("`@("`@("`@("`G+W1A8FQE
M("XJ(&%L<F5A9'D@97AI<W1S+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@
M1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@("`@("`@("`@("`@("`G+W5N
M<W5C8V5S<V9U;"!M971A9&%T82!U<&1A=&4@+BH@9F%I;&5D(&%T=&5M<'0@
M=&\@<W1O<F4@9'5P;&EC871E('9A;'5E+VDG"B`@("`@("`@("`@("`@("`@
M("`@/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@("`@("`@("`@("`@
M("`G+W5N<W5C8V5S<V9U;"!M971A9&%T82!U<&1A=&4@+BH@;F]T(&9O=6YD
M+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?3D]47T9/54Y$
M+`H@("`@("`@("`@("`@("`@)R]V86QI9&%T:6]N(&5R<F]R(&9O<B!C;VQU
M;6X@+BH@=F%L=64@(EPJ7"I<*B!N=6QL+VDG"B`@("`@("`@("`@("`@("`@
M("`@/3X@1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3"P*("`@("`@("`@
M("`@("`@("<O=FEO;&%T:6]N(&]F(%M<=R!=*R!C;VYS=')A:6YT+VDG"B`@
M("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@
M("`@("`@("`@("`@("<O8V]N=F5R<VEO;B!E<G)O<B!F<F]M('-T<FEN9R]I
M)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27TE.5D%,241?3E5-
M0D52+`H@("`@("`@("`@("`@("`@)R]N;R!P97)M:7-S:6]N(&9O<B]I)PH@
M("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27T%#0T534U]624],051)
M3TXL"B`@("`@("`@("`@("`@("`G+V%R:71H;65T:6,@97AC97!T:6]N+"!N
M=6UE<FEC(&]V97)F;&]W+"!O<B!S=')I;F<@=')U;F-A=&EO;B]I)PH@("`@
M("`@("`@("`@("`@("`@(#T^($1"7T524D]27TE.5D%,240L"B`@("`@("`@
M("`@("D["B`@("`@("`@?0H*("`@("`@("`D97)R;W)M<V<@/2!`:6)A<V5?
M97)R;7-G*"D["B`@("`@("`@9F]R96%C:"`H)&5R<F]R7W)E9V5X<',@87,@
M)')E9V5X<"`]/B`D8V]D92D@>PH@("`@("`@("`@("!I9B`H<')E9U]M871C
M:"@D<F5G97AP+"`D97)R;W)M<V<I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)&-O9&4["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N($1"7T524D]2.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('1A
M8FQE26YF;R@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&EN9F]R;6%T:6]N
M(&%B;W5T(&$@=&%B;&4@;W(@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@
M3D]413H@;VYL>2!S=7!P;W)T<R`G=&%B;&4G(&%N9"`G9FQA9W,G(&EF(#QV
M87(^)')E<W5L=#PO=F%R/@H@("`@("H@:7,@82!T86)L92!N86UE+@H@("`@
M("H*("`@("`J($!P87)A;2!O8FIE8W1\<W1R:6YG("`D<F5S=6QT("!$0E]R
M97-U;'0@;V)J96-T(&9R;VT@82!Q=65R>2!O<B!A"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('-T<FEN9R!C;VYT86EN:6YG('1H
M92!N86UE(&]F(&$@=&%B;&4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%=H:6QE('1H:7,@86QS;R!A8V-E<'1S(&$@<75E<GD@
M<F5S=6QT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(')E<V]U<F-E(&ED96YT:69I97(L('1H:7,@8F5H879I;W(@:7,*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9&5P<F5C871E9"X*
M("`@("`J($!P87)A;2!I;G0@("`@("`@("`@("`D;6]D92`@("!A('9A;&ED
M('1A8FQE26YF;R!M;V1E"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M86X@87-S;V-I871I=F4@87)R87D@=VET:"!T:&4@:6YF;W)M871I;VX@<F5Q
M=65S=&5D+@H@("`@("H@("`@("`@("`@("`@("`@($$@1$)?17)R;W(@;V)J
M96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ
M.G1A8FQE26YF;R@I"B`@("`@*B\*("`@(&9U;F-T:6]N('1A8FQE26YF;R@D
M<F5S=6QT+"`D;6]D92`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7W-T
M<FEN9R@D<F5S=6QT*2D@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@
M*B!0<F]B86)L>2!R96-E:79E9"!A('1A8FQE(&YA;64N"B`@("`@("`@("`@
M("`J($-R96%T92!A(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@
M("`@("`@("`@*B\*("`@("`@("`@("`@)&ED(#T@0&EB87-E7W%U97)Y*"1T
M:&ES+3YC;VYN96-T:6]N+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(E-%3$5#5"`J($923TT@)')E<W5L="!72$5212`Q/3`B*3L*("`@("`@
M("`@("`@)&=O=%]S=')I;F<@/2!T<G5E.PH@("`@("`@('T@96QS96EF("AI
M<W-E="@D<F5S=6QT+3YR97-U;'0I*2!["B`@("`@("`@("`@("\J"B`@("`@
M("`@("`@("`J(%!R;V)A8FQY(')E8V5I=F5D(&$@<F5S=6QT(&]B:F5C="X*
M("`@("`@("`@("`@("H@17AT<F%C="!T:&4@<F5S=6QT(')E<V]U<F-E(&ED
M96YT:69I97(N"B`@("`@("`@("`@("`J+PH@("`@("`@("`@("`D:60@/2`D
M<F5S=6QT+3YR97-U;'0["B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@9F%L
M<V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH*("`@("`@("`@
M("`@("H@4')O8F%B;'D@<F5C96EV960@82!R97-U;'0@<F5S;W5R8V4@:61E
M;G1I9FEE<BX*("`@("`@("`@("`@("H@0V]P>2!I="X*("`@("`@("`@("`@
M("H@1&5P<F5C871E9"X@($AE<F4@9F]R(&-O;7!A=&EB:6QI='D@;VYL>2X*
M("`@("`@("`@("`@("HO"B`@("`@("`@("`@("1I9"`]("1R97-U;'0["B`@
M("`@("`@("`@("1G;W1?<W1R:6YG(#T@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(6ES7W)E<V]U<F-E*"1I9"DI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YI8F%S95)A:7-E17)R;W(H1$)?15)23U)?3D5%1%]-3U)%
M7T1!5$$I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS
M6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3$]715)#05-%*2![
M"B`@("`@("`@("`@("1C87-E7V9U;F,@/2`G<W1R=&]L;W=E<B<["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&-A<V5?9G5N8R`]("=S=')V86PG
M.PH@("`@("`@('T*"B`@("`@("`@)&-O=6YT(#T@0&EB87-E7VYU;5]F:65L
M9',H)&ED*3L*("`@("`@("`D<F5S("`@/2!A<G)A>2@I.PH*("`@("`@("!I
M9B`H)&UO9&4I('L*("`@("`@("`@("`@)')E<ULG;G5M7V9I96QD<R==(#T@
M)&-O=6YT.PH@("`@("`@('T*"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M)&-O=6YT.R`D:2LK*2!["B`@("`@("`@("`@("1I;F9O(#T@0&EB87-E7V9I
M96QD7VEN9F\H)&ED+"`D:2D["B`@("`@("`@("`@("1R97-;)&E=(#T@87)R
M87DH"B`@("`@("`@("`@("`@("`G=&%B;&4G(#T^("1G;W1?<W1R:6YG(#\@
M)&-A<V5?9G5N8R@D<F5S=6QT*2`Z("<G+`H@("`@("`@("`@("`@("`@)VYA
M;64G("`]/B`D8V%S95]F=6YC*"1I;F9O6R=N86UE)UTI+`H@("`@("`@("`@
M("`@("`@)W1Y<&4G("`]/B`D:6YF;ULG='EP92==+`H@("`@("`@("`@("`@
M("`@)VQE;B<@("`]/B`D:6YF;ULG;&5N9W1H)UTL"B`@("`@("`@("`@("`@
M("`G9FQA9W,G(#T^("@D9V]T7W-T<FEN9RD*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#\@)'1H:7,M/E]I8F%S949I96QD1FQA9W,H)&EN9F];)VYA
M;64G72P@)')E<W5L="D*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M)R<L"B`@("`@("`@("`@("D["B`@("`@("`@("`@(&EF("@D;6]D92`F($1"
M7U1!0DQ%24Y&3U]/4D1%4BD@>PH@("`@("`@("`@("`@("`@)')E<ULG;W)D
M97(G75LD<F5S6R1I75LG;F%M92==72`]("1I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&EF("@D;6]D92`F($1"7U1!0DQ%24Y&3U]/4D1%4E1!0DQ%
M*2!["B`@("`@("`@("`@("`@("`D<F5S6R=O<F1E<G1A8FQE)UU;)')E<ULD
M:5U;)W1A8FQE)UU=6R1R97-;)&E=6R=N86UE)UU=(#T@)&D["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("\O(&9R964@=&AE(')E<W5L="!O
M;FQY(&EF('=E('=E<F4@8V%L;&5D(&]N(&$@=&%B;&4*("`@("`@("!I9B`H
M)&=O=%]S=')I;F<I('L*("`@("`@("`@("`@0&EB87-E7V9R965?<F5S=6QT
M*"1I9"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&=E=%-P96-I86Q1=65R>2@I"@H@("`@
M+RHJ"B`@("`@*B!/8G1A:6YS('1H92!Q=65R>2!S=')I;F<@;F5E9&5D(&9O
M<B!L:7-T:6YG(&$@9VEV96X@='EP92!O9B!O8FIE8W1S"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D='EP92`@=&AE(&MI;F0@;V8@;V)J96-T<R!Y
M;W4@=V%N="!T;R!R971R:65V90H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!T:&4@4U%,('%U97)Y('-T<FEN9R!O<B!N=6QL(&EF('1H92!D<FEV
M97(@9&]E<VXG=`H@("`@("H@("`@("`@("`@("`@("`@("!S=7!P;W)T('1H
M92!O8FIE8W0@='EP92!R97%U97-T960*("`@("`J"B`@("`@*B!`86-C97-S
M('!R;W1E8W1E9`H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F=E=$QI<W1/9B@I
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-P96-I86Q1=65R>2@D='EP92D*
M("`@('L*("`@("`@("!S=VET8V@@*"1T>7!E*2!["B`@("`@("`@("`@(&-A
M<V4@)W1A8FQE<R<Z"B`@("`@("`@("`@("`@("!R971U<FX@)U-%3$5#5"!$
M25-424Y#5"!2+E)$0B1214Q!5$E/3E].04U%($923TT@)PH@("`@("`@("`@
M("`@("`@("`@("`@("X@)U)$0B1214Q!5$E/3E]&245,1%,@4B!72$5212!2
M+E)$0B1365-414U?1DQ!1STP)SL*("`@("`@("`@("`@8V%S92`G=FEE=W,G
M.@H@("`@("`@("`@("`@("`@<F5T=7)N("=314Q%0U0@1$E35$E.0U0@4D1"
M)%9)15=?3D%-12!F<F]M(%)$0B1624577U)%3$%424].4R<["B`@("`@("`@
M("`@(&-A<V4@)W5S97)S)SH*("`@("`@("`@("`@("`@(')E='5R;B`G4T5,
M14-4($1)4U1)3D-4(%)$0B154T52($923TT@4D1")%5315)?4%))5DE,14=%
M4R<["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!R971U
M<FX@;G5L;#L*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"@I]"@HO*@H@
M*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC
M+6]F9G-E=#H@-`H@*B!%;F0Z"B`J+PH*/SX*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]$0B]I9G@N
M<&AP````````````````````````````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`T-C<R,``Q,#4Q-30S,S<S-@`P,C`T,#,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*"B\J('9I;3H@<V5T(&5X
M<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z
M("HO"@HO*BH*("H@5&AE(%!%05(@1$(@9')I=F5R(&9O<B!02%`G<R!I9G@@
M97AT96YS:6]N"B`J(&9O<B!I;G1E<F%C=&EN9R!W:71H($EN9F]R;6EX(&1A
M=&%B87-E<PH@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%
M3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S
M+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55))
M.@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@
M0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U
M=&AO<B`@("`@5&]M87,@5BY6+D-O>"`\8V]X0&ED96-N970N8V]M/@H@*B!`
M875T:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^
M"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@
M(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@:69X
M+G!H<"QV(#$N-S`@,C`P-2\P,B\R,"`P,#HT-#HT."!D86YI96QC($5X<"`D
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$
M0@H@*B\*"B\J*@H@*B!/8G1A:6X@=&AE($1"7V-O;6UO;B!C;&%S<R!S;R!I
M="!C86X@8F4@97AT96YD960@9G)O;0H@*B\*<F5Q=6ER95]O;F-E("=$0B]C
M;VUM;VXN<&AP)SL*"B\J*@H@*B!4:&4@;65T:&]D<R!014%2($1"('5S97,@
M=&\@:6YT97)A8W0@=VET:"!02%`G<R!I9G@@97AT96YS:6]N"B`J(&9O<B!I
M;G1E<F%C=&EN9R!W:71H($EN9F]R;6EX(&1A=&%B87-E<PH@*@H@*B!4:&5S
M92!M971H;V1S(&]V97)L;V%D('1H92!O;F5S(&1E8VQA<F5D(&EN($1"7V-O
M;6UO;BX*("H*("H@36]R92!I;F9O(&]N($EN9F]R;6EX(&5R<F]R<R!C86X@
M8F4@9F]U;F0@870Z"B`J(&AT='`Z+R]W=W<N:6YF;W)M:7@N8V]M+V%N<W=E
M<G,O96YG;&ES:"]I97)R;W)S+FAT;0H@*@H@*B!43T1/.@H@*B`@("T@<V5T
M(&YE961E9"!E;G8@26YF;W)M:7@@=F%R<R!O;B!C;VYN96-T"B`J("`@+2!I
M;7!L96UE;G0@;F%T:79E('!R97!A<F4O97AE8W5T90H@*@H@*B!`8V%T96=O
M<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@
M("!4;VUA<R!6+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^"B`J($!A=71H;W(@
M("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@
M("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI
M8V5N<V4@,RXP"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-RXV"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*
M8VQA<W,@1$)?:69X(&5X=&5N9',@1$)?8V]M;6]N"GL*("`@("\O('M[>R!P
M<F]P97)T:65S"@H@("`@+RHJ"B`@("`@*B!4:&4@1$(@9')I=F5R('1Y<&4@
M*&UY<W%L+"!O8VDX+"!O9&)C+"!E=&,N*0H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1P:'!T>7!E(#T@)VEF>"<["@H@("`@+RHJ"B`@
M("`@*B!4:&4@9&%T86)A<V4@<WEN=&%X('9A<FEA;G0@=&\@8F4@=7-E9"`H
M9&(R+"!A8V-E<W,L(&5T8RXI+"!I9B!A;GD*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D9&)S>6YT87@@/2`G:69X)SL*"B`@("`O*BH*
M("`@("`J(%1H92!C87!A8FEL:71I97,@;V8@=&AI<R!$0B!I;7!L96UE;G1A
M=&EO;@H@("`@("H*("`@("`J(%1H92`G;F5W7VQI;FLG(&5L96UE;G0@8V]N
M=&%I;G,@=&AE(%!(4"!V97)S:6]N('1H870@9FER<W0@<')O=FED960*("`@
M("`J(&YE=U]L:6YK('-U<'!O<G0@9F]R('1H:7,@1$)-4RX@($-O;G1A:6YS
M(&9A;'-E(&EF(&ET)W,@=6YS=7!P;W)T960N"B`@("`@*@H@("`@("H@365A
M;FEN9R!O9B!T:&4@)VQI;6ET)R!E;&5M96YT.@H@("`@("H@("`K("=E;75L
M871E)R`](&5M=6QA=&4@=VET:"!F971C:"!R;W<@8GD@;G5M8F5R"B`@("`@
M*B`@("L@)V%L=&5R)R`@(#T@86QT97(@=&AE('%U97)Y"B`@("`@*B`@("L@
M9F%L<V4@("`@(#T@<VMI<"!R;W=S"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)&9E871U<F5S(#T@87)R87DH"B`@("`@("`@
M)VQI;6ET)R`@("`@("`@(#T^("=E;75L871E)RP*("`@("`@("`G;F5W7VQI
M;FLG("`@("`@/3X@9F%L<V4L"B`@("`@("`@)VYU;7)O=W,G("`@("`@(#T^
M("=E;75L871E)RP*("`@("`@("`G<&-O;FYE8W0G("`@("`@/3X@=')U92P*
M("`@("`@("`G<')E<&%R92<@("`@("`@/3X@9F%L<V4L"B`@("`@("`@)W-S
M;"<@("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=T<F%N<V%C=&EO;G,G
M("`]/B!T<G5E+`H@("`@*3L*"B`@("`O*BH*("`@("`J($$@;6%P<&EN9R!O
M9B!N871I=F4@97)R;W(@8V]D97,@=&\@1$(@97)R;W(@8V]D97,*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1E<G)O<F-O9&5?;6%P(#T@
M87)R87DH"B`@("`@("`@)RTR,#$G("`@(#T^($1"7T524D]27U-93E1!6"P*
M("`@("`@("`G+3(P-B<@("`@/3X@1$)?15)23U)?3D]354-(5$%"3$4L"B`@
M("`@("`@)RTR,3<G("`@(#T^($1"7T524D]27TY/4U5#2$9)14Q$+`H@("`@
M("`@("<M,C,V)R`@("`]/B!$0E]%4E)/4E]604Q515]#3U5.5%]/3E]23U<L
M"B`@("`@("`@)RTR,SDG("`@(#T^($1"7T524D]27T-/3E-44D%)3E0L"B`@
M("`@("`@)RTR-3,G("`@(#T^($1"7T524D]27U-93E1!6"P*("`@("`@("`G
M+3(Y,B<@("`@/3X@1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3"P*("`@
M("`@("`G+3,Q,"<@("`@/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@
M("`@("`@)RTS,38G("`@(#T^($1"7T524D]27T%,4D5!1%E?15A)4U13+`H@
M("`@("`@("<M,S$Y)R`@("`]/B!$0E]%4E)/4E].3U1?1D]53D0L"B`@("`@
M("`@)RTS,CDG("`@(#T^($1"7T524D]27TY/1$)314Q%0U1%1"P*("`@("`@
M("`G+3,T-B<@("`@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("`@("`G
M+3,X-B<@("`@/3X@1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3"P*("`@
M("`@("`G+3,Y,2<@("`@/3X@1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,
M3"P*("`@("`@("`G+34U-"<@("`@/3X@1$)?15)23U)?4UE.5$%8+`H@("`@
M("`@("<M-CDQ)R`@("`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@
M("<M-CDR)R`@("`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@("<M
M-S`S)R`@("`]/B!$0E]%4E)/4E]#3TY35%)!24Y47TY/5%].54Q,+`H@("`@
M("`@("<M,3(P-"<@("`]/B!$0E]%4E)/4E])3E9!3$E$7T1!5$4L"B`@("`@
M("`@)RTQ,C`U)R`@(#T^($1"7T524D]27TE.5D%,241?1$%412P*("`@("`@
M("`G+3$R,#8G("`@/3X@1$)?15)23U)?24Y604Q)1%]$051%+`H@("`@("`@
M("<M,3(P.2<@("`]/B!$0E]%4E)/4E])3E9!3$E$7T1!5$4L"B`@("`@("`@
M)RTQ,C$P)R`@(#T^($1"7T524D]27TE.5D%,241?1$%412P*("`@("`@("`G
M+3$R,3(G("`@/3X@1$)?15)23U)?24Y604Q)1%]$051%+`H@("`@("`@("<M
M,3(Q,R<@("`]/B!$0E]%4E)/4E])3E9!3$E$7TY534)%4BP*("`@("D["@H@
M("`@+RHJ"B`@("`@*B!4:&4@<F%W(&1A=&%B87-E(&-O;FYE8W1I;VX@8W)E
M871E9"!B>2!02%`*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@
M=F%R("1C;VYN96-T:6]N.PH*("`@("\J*@H@("`@("H@5&AE($133B!I;F9O
M<FUA=&EO;B!F;W(@8V]N;F5C=&EN9R!T;R!A(&1A=&%B87-E"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D9'-N(#T@87)R87DH*3L*"@H@
M("`@+RHJ"B`@("`@*B!3:&]U;&0@9&%T82!M86YI<'5L871I;VX@<75E<FEE
M<R!B92!C;VUM:71T960@875T;VUA=&EC86QL>3\*("`@("`J($!V87(@8F]O
M;`H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D875T
M;V-O;6UI="`]('1R=64["@H@("`@+RHJ"B`@("`@*B!4:&4@<75A;G1I='D@
M;V8@=')A;G-A8W1I;VYS(&)E9W5N"B`@("`@*@H@("`@("H@>T!I;G1E<FYA
M;"`@5VAI;&4@=&AI<R!I<R!P<FEV871E+"!I="!C86XG="!A8W1U86QL>2!B
M92!D97-I9VYA=&5D"B`@("`@*B!P<FEV871E(&EN(%!(4"`U(&)E8V%U<V4@
M:70@:7,@9&ER96-T;'D@86-C97-S960@:6X@=&AE('1E<W0@<W5I=&4N?7T*
M("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!V87(@)'1R86YS86-T:6]N7V]P8V]U;G0@/2`P
M.PH*("`@("\J*@H@("`@("H@5&AE(&YU;6)E<B!O9B!R;W=S(&%F9F5C=&5D
M(&)Y(&$@9&%T82!M86YI<'5L871I;VX@<75E<GD*("`@("`J($!V87(@:6YT
M96=E<@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D
M869F96-T960@/2`P.PH*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYS=')U
M8W1O<@H*("`@("\J*@H@("`@("H@5&AI<R!C;VYS=')U8W1O<B!C86QL<R`\
M:V)D/B1T:&ES+3Y$0E]C;VUM;VXH*3PO:V)D/@H@("`@("H*("`@("`J($!R
M971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!$0E]I9G@H*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y$0E]C;VUM;VXH*3L*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!C;VYN96-T*"D*"B`@("`O*BH*("`@("`J($-O;FYE
M8W0@=&\@=&AE(&1A=&%B87-E('-E<G9E<BP@;&]G(&EN(&%N9"!O<&5N('1H
M92!D871A8F%S90H@("`@("H*("`@("`J($1O;B=T(&-A;&P@=&AI<R!M971H
M;V0@9&ER96-T;'DN("!5<V4@1$(Z.F-O;FYE8W0H*2!I;G-T96%D+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D9'-N("`@("`@("`@=&AE(&1A=&$@
M<V]U<F-E(&YA;64*("`@("`J($!P87)A;2!B;V]L("`D<&5R<VES=&5N="`@
M<VAO=6QD('1H92!C;VYN96-T:6]N(&)E('!E<G-I<W1E;G0_"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N($$@1$)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O
M;FYE8W0H)&1S;BP@)'!E<G-I<W1E;G0@/2!F86QS92D*("`@('L*("`@("`@
M("!I9B`H(5!%05(Z.FQO861%>'1E;G-I;VXH)VEN9F]R;6EX)RD@)B8*("`@
M("`@("`@("`@(5!%05(Z.FQO861%>'1E;G-I;VXH)TEN9F]R;6EX)RDI"B`@
M("`@("`@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M1$)?15)23U)?15A414Y324].7TY/5%]&3U5.1"D["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^9'-N(#T@)&1S;CL*("`@("`@("!I9B`H)&1S;ELG9&)S
M>6YT87@G72D@>PH@("`@("`@("`@("`D=&AI<RT^9&)S>6YT87@@/2`D9'-N
M6R=D8G-Y;G1A>"==.PH@("`@("`@('T*"B`@("`@("`@)&1B:&]S="`]("1D
M<VY;)VAO<W1S<&5C)UT@/R`G0"<@+B`D9'-N6R=H;W-T<W!E8R==(#H@)R<[
M"B`@("`@("`@)&1B;F%M92`]("1D<VY;)V1A=&%B87-E)UT@/R`D9'-N6R=D
M871A8F%S92==("X@)&1B:&]S="`Z("<G.PH@("`@("`@("1U<V5R(#T@)&1S
M;ELG=7-E<FYA;64G72`_("1D<VY;)W5S97)N86UE)UT@.B`G)SL*("`@("`@
M("`D<'<@/2`D9'-N6R=P87-S=V]R9"==(#\@)&1S;ELG<&%S<W=O<F0G72`Z
M("<G.PH*("`@("`@("`D8V]N;F5C=%]F=6YC=&EO;B`]("1P97)S:7-T96YT
M(#\@)VEF>%]P8V]N;F5C="<@.B`G:69X7V-O;FYE8W0G.PH*("`@("`@("`D
M=&AI<RT^8V]N;F5C=&EO;B`]($`D8V]N;F5C=%]F=6YC=&EO;B@D9&)N86UE
M+"`D=7-E<BP@)'!W*3L*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1T:&ES
M+3YC;VYN96-T:6]N*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FEF
M>%)A:7-E17)R;W(H1$)?15)23U)?0T].3D5#5%]&04E,140I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@9&ES8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@*B!$:7-C;VYN
M96-T<R!F<F]M('1H92!D871A8F%S92!S97)V97(*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VP@(%12544@;VX@<W5C8V5S<RP@1D%,4T4@;VX@9F%I;'5R
M90H@("`@("HO"B`@("!F=6YC=&EO;B!D:7-C;VYN96-T*"D*("`@('L*("`@
M("`@("`D<F5T(#T@0&EF>%]C;&]S92@D=&AI<RT^8V]N;F5C=&EO;BD["B`@
M("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!N=6QL.PH@("`@("`@(')E='5R
M;B`D<F5T.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('-I;7!L95%U
M97)Y*"D*"B`@("`O*BH*("`@("`J(%-E;F1S(&$@<75E<GD@=&\@=&AE(&1A
M=&%B87-E('-E<G9E<@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@('1H
M92!344P@<75E<GD@<W1R:6YG"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@*R!A(%!(4"!R97-U;'0@<F5S<F]U8V4@9F]R('-U8V-E<W-F=6P@4T5,
M14-4('%U97)I97,*("`@("`J("`@("`@("`@("`@("`@("L@=&AE($1"7T]+
M(&-O;G-T86YT(&9O<B!O=&AE<B!S=6-C97-S9G5L('%U97)I97,*("`@("`J
M("`@("`@("`@("`@("`@("L@82!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M90H@("`@("HO"B`@("!F=6YC=&EO;B!S:6UP;&51=65R>2@D<75E<GDI"B`@
M("!["B`@("`@("`@)&ES;6%N:7`@/2!$0CHZ:7--86YI<"@D<75E<GDI.PH@
M("`@("`@("1T:&ES+3YL87-T7W%U97)Y(#T@)'%U97)Y.PH@("`@("`@("1T
M:&ES+3YA9F9E8W1E9"`@(#T@;G5L;#L*("`@("`@("!I9B`H<')E9U]M871C
M:"@G+RA314Q%0U0I+VDG+"`D<75E<GDI*2![("`@("\O5$535$U%.B!5<V4@
M(41".CII<TUA;FEP*"D_"B`@("`@("`@("`@("\O('1H92!S8W)O;&P@:7,@
M;F5E9&5D(&9O<B!F971C:&EN9R!A8G-O;'5T92!R;W<@;G5M8F5R<PH@("`@
M("`@("`@("`O+R!I;B!A('-E;&5C="!Q=65R>2!R97-U;'0*("`@("`@("`@
M("`@)')E<W5L="`]($!I9GA?<75E<GDH)'%U97)Y+"`D=&AI<RT^8V]N;F5C
M=&EO;BP@24987U-#4D],3"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@:68@*"$D=&AI<RT^875T;V-O;6UI="`F)B`D:7-M86YI<"D@>PH@("`@
M("`@("`@("`@("`@:68@*"1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#T]
M(#`I('L*("`@("`@("`@("`@("`@("`@("`D<F5S=6QT(#T@0&EF>%]Q=65R
M>2@G0D5'24X@5T]22R<L("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`@
M("`@("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YI9GA286ES945R<F]R*"D["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0K*SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D<F5S=6QT(#T@0&EF>%]Q=65R>2@D<75E<GDL("1T
M:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("!]"B`@("`@("`@:68@*"$D<F5S
M=6QT*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^:69X4F%I<V5%<G)O
M<B@I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^869F96-T960@/2!`:69X
M7V%F9F5C=&5D7W)O=W,H)')E<W5L="D["B`@("`@("`@+R\@1&5T97)M:6YE
M('=H:6-H('%U97)I97,@<VAO=6QD(')E='5R;B!D871A+"!A;F0@=VAI8V@*
M("`@("`@("`O+R!S:&]U;&0@<F5T=7)N(&%N(&5R<F]R(&-O9&4@;VYL>2X*
M("`@("`@("!I9B`H<')E9U]M871C:"@G+RA314Q%0U0I+VDG+"`D<75E<GDI
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@
M("`@("`O+R!86%@@5&5S=&UE.B!F<F5E(')E<W5L=',@:6YS:61E(&$@=')A
M;G-A8W1I;VX*("`@("`@("`O+R!M87D@8V%U<V4@=&\@<W1O<"!I="!A;F0@
M8V]M;6ET('1H92!W;W)K/PH*("`@("`@("`O+R!297-U;'0@:&%S('1O(&)E
M(&9R965D(&5V96X@=VET:"!A(&EN<V5R="!O<B!U<&1A=&4*("`@("`@("!`
M:69X7V9R965?<F5S=6QT*"1R97-U;'0I.PH*("`@("`@("!R971U<FX@1$)?
M3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;F5X=%)E<W5L="@I
M"@H@("`@+RHJ"B`@("`@*B!-;W9E('1H92!I;G1E<FYA;"!I9G@@<F5S=6QT
M('!O:6YT97(@=&\@=&AE(&YE>'0@879A:6QA8FQE(')E<W5L=`H@("`@("H*
M("`@("`J($!P87)A;2!A('9A;&ED(&9B<W%L(')E<W5L="!R97-O=7)C90H@
M("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E
M='5R;B!T<G5E(&EF(&$@<F5S=6QT(&ES(&%V86EL86)L92!O=&AE<G=I<V4@
M<F5T=7)N(&9A;'-E"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE>'1297-U;'0H
M)')E<W5L="D*("`@('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@869F96-T9612;W=S*"D*"B`@("`O*BH*
M("`@("`J($1E=&5R;6EN97,@=&AE(&YU;6)E<B!O9B!R;W=S(&%F9F5C=&5D
M(&)Y(&$@9&%T82!M86YI=7!L871I;VX@<75E<GD*("`@("`J"B`@("`@*B`P
M(&ES(')E='5R;F5D(&9O<B!Q=65R:65S('1H870@9&]N)W0@;6%N:7!U;&%T
M92!D871A+@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R
M(&]F(')O=W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!A9F9E8W1E9%)O=W,H*0H@("`@>PH@("`@("`@
M(&EF("A$0CHZ:7--86YI<"@D=&AI<RT^;&%S=%]Q=65R>2DI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YA9F9E8W1E9#L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@,#L*("`@("`@("!]"B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@9F5T8VA);G1O*"D*"B`@("`O*BH*("`@("`J
M(%!L86-E<R!A(')O=R!F<F]M('1H92!R97-U;'0@<V5T(&EN=&\@=&AE(&=I
M=F5N(&%R<F%Y"B`@("`@*@H@("`@("H@1F]R;6%T:6YG(&]F('1H92!A<G)A
M>2!A;F0@=&AE(&1A=&$@=&AE<F5I;B!A<F4@8V]N9FEG=7)A8FQE+@H@("`@
M("H@4V5E($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D@9F]R(&UO<F4@:6YF;W)M
M871I;VXN"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT
M('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT
M.CIF971C:$EN=&\H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@
M(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P
M87)A=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D
M<F5S=6QT("`@('1H92!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J($!P
M87)A;2!A<G)A>2`@("`D87)R("`@("`@('1H92!R969E<F5N8V5D(&%R<F%Y
M('1O('!U="!T:&4@9&%T82!I;@H@("`@("H@0'!A<F%M(&EN="`@("`@("1F
M971C:&UO9&4@:&]W('1H92!R97-U;'1I;F<@87)R87D@<VAO=6QD(&)E(&EN
M9&5X960*("`@("`J($!P87)A;2!I;G0@("`@("`D<F]W;G5M("`@('1H92!R
M;W<@;G5M8F5R('1O(&9E=&-H("@P(#T@9FER<W0@<F]W*0H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@($1"7T]+(&]N('-U8V-E<W,L($Y53$P@=VAE
M;B!T:&4@96YD(&]F(&$@<F5S=6QT('-E="!I<PH@("`@("H@("`@("`@("`@
M("`@("`@(')E86-H960@;W(@;VX@9F%I;'5R90H@("`@("H*("`@("`J($!S
M964@1$)?<F5S=6QT.CIF971C:$EN=&\H*0H@("`@("HO"B`@("!F=6YC=&EO
M;B!F971C:$EN=&\H)')E<W5L="P@)B1A<G(L("1F971C:&UO9&4L("1R;W=N
M=6T@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@H)')O=VYU;2`A/3T@;G5L
M;"D@)B8@*"1R;W=N=6T@/"`P*2D@>PH@("`@("`@("`@("!R971U<FX@;G5L
M;#L*("`@("`@("!]"B`@("`@("`@:68@*"1R;W=N=6T@/3T](&YU;&PI('L*
M("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@179E;B!T:&]U9V@@9F5T
M8VA?<F]W*"D@<VAO=6QD(')E='5R;B!T:&4@;F5X="!R;W<@(&EF"B`@("`@
M("`@("`@("`J("1R;W=N=6T@:7,@;G5L;"P@:70@9&]E<VXG="!I;B!A;&P@
M8V%S97,N("!"=6<@-3DX+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@
M)')O=VYU;2`]("=.15A4)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`O+R!);F1E>"!S=&%R=',@870@<F]W(#$L('5N;&EK92!M;W-T($1"35,G
M<R!S=&%R=&EN9R!A="`P+@H@("`@("`@("`@("`D<F]W;G5M*RL["B`@("`@
M("`@?0H@("`@("`@(&EF("@A)&%R<B`]($!I9GA?9F5T8VA?<F]W*"1R97-U
M;'0L("1R;W=N=6TI*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@
M("`@('T*("`@("`@("!I9B`H)&9E=&-H;6]D92`A/3T@1$)?1D540TA-3T1%
M7T%34T]#*2!["B`@("`@("`@("`@("1I/3`["B`@("`@("`@("`@("1O<F1E
M<B`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1A<G(@87,@)'9A
M;"D@>PH@("`@("`@("`@("`@("`@)&]R9&5R6R1I*RM=(#T@)'9A;#L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D87)R(#T@)&]R9&5R.PH@("`@("`@
M('T@96QS96EF("@D9F5T8VAM;V1E(#T]($1"7T9%5$-(34]$15]!4U-/0R`F
M)@H@("`@("`@("`@("`@("`@("`D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI
M='DG72`F($1"7U!/4E1!0DE,25197TQ/5T520T%312D*("`@("`@("!["B`@
M("`@("`@("`@("1A<G(@/2!A<G)A>5]C:&%N9V5?:V5Y7V-A<V4H)&%R<BP@
M0T%315],3U=%4BD["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;W!T
M:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197U)44DE-*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?<G1R:6U!<G)A>59A;'5E<R@D87)R*3L*
M("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I
M;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3E5,3%]43U]%35!462D@>PH@("`@
M("`@("`@("`D=&AI<RT^7V-O;G9E<G1.=6QL07)R87E686QU97-4;T5M<'1Y
M*"1A<G(I.PH@("`@("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;G5M0V]L<R@I"@H@("`@+RHJ"B`@
M("`@*B!'971S('1H92!N=6UB97(@;V8@8V]L=6UN<R!I;B!A(')E<W5L="!S
M970*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@
M8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.FYU
M;4-O;',H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E
M8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@
M;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT
M("!02%`G<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!C;VQU;6YS+B`@02!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7W)E
M<W5L=#HZ;G5M0V]L<R@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU;4-O;',H
M)')E<W5L="D*("`@('L*("`@("`@("!I9B`H(21C;VQS(#T@0&EF>%]N=6U?
M9FEE;&1S*"1R97-U;'0I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M:69X4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&-O
M;',["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9G)E95)E<W5L="@I
M"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S('1H92!R97-U;'0@<V5T(&%N9"!F
M<F5E<R!T:&4@;65M;W)Y(&]C8W5P:65D(&)Y('1H92!R97-U;'0@<V5T"B`@
M("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A
M;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIF<F5E*"D@
M:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@
M("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@
M<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L("!44E5%(&]N('-U8V-E<W,L($9!3%-%(&EF("1R97-U;'0@:7,@:6YV
M86QI9`H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIF<F5E*"D*("`@
M("`J+PH@("`@9G5N8W1I;VX@9G)E95)E<W5L="@D<F5S=6QT*0H@("`@>PH@
M("`@("`@(')E='5R;B!`:69X7V9R965?<F5S=6QT*"1R97-U;'0I.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&%U=&]#;VUM:70H*0H*("`@("\J
M*@H@("`@("H@16YA8FQE<R!O<B!D:7-A8FQE<R!A=71O;6%T:6,@8V]M;6ET
M<PH@("`@("H*("`@("`J($!P87)A;2!B;V]L("1O;F]F9B`@=')U92!T=7)N
M<R!I="!O;BP@9F%L<V4@='5R;G,@:70@;V9F"B`@("`@*@H@("`@("H@0')E
M='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C
M="!I9B!T:&4@9')I=F5R"B`@("`@*B`@("`@("`@("`@("`@(&1O97-N)W0@
M<W5P<&]R="!A=71O+6-O;6UI='1I;F<@=')A;G-A8W1I;VYS+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!A=71O0V]M;6ET*"1O;F]F9B`]('1R=64I"B`@("![
M"B`@("`@("`@+R\@6%A8(&EF("1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT
M(#X@,"P@=V4@<VAO=6QD('!R;V)A8FQY"B`@("`@("`@+R\@:7-S=64@82!W
M87)N:6YG(&AE<F4N"B`@("`@("`@)'1H:7,M/F%U=&]C;VUM:70@/2`D;VYO
M9F8@/R!T<G5E(#H@9F%L<V4["B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&-O;6UI="@I"@H@("`@+RHJ"B`@
M("`@*B!#;VUM:71S('1H92!C=7)R96YT('1R86YS86-T:6]N"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C
M;VUM:70H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^=')A;G-A8W1I;VY?
M;W!C;W5N="`^(#`I('L*("`@("`@("`@("`@)')E<W5L="`]($!I9GA?<75E
M<GDH)T-/34U)5"!73U)+)RP@)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@
M("`@("`D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`](#`["B`@("`@("`@
M("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YI9GA286ES945R<F]R*"D["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(')O;&QB86-K*"D*"B`@("`O*BH*("`@("`J(%)E=F5R=',@=&AE
M(&-U<G)E;G0@=')A;G-A8W1I;VX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN
M="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')O;&QB86-K*"D*("`@('L*
M("`@("`@("!I9B`H)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/B`P*2![
M"B`@("`@("`@("`@("1R97-U;'0@/2!`:69X7W%U97)Y*"=23TQ,0D%#2R!7
M3U)+)RP@)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`D=&AI<RT^
M=')A;G-A8W1I;VY?;W!C;W5N="`](#`["B`@("`@("`@("`@(&EF("@A)')E
M<W5L="D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YI9GA286ES
M945R<F]R*"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&EF>%)A
M:7-E17)R;W(H*0H*("`@("\J*@H@("`@("H@4')O9'5C97,@82!$0E]%<G)O
M<B!O8FIE8W0@<F5G87)D:6YG('1H92!C=7)R96YT('!R;V)L96T*("`@("`J
M"B`@("`@*B!`<&%R86T@:6YT("1E<G)N;R`@:68@=&AE(&5R<F]R(&ES(&)E
M:6YG(&UA;G5A;&QY(')A:7-E9"!P87-S(&$*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@1$)?15)23U(J(&-O;G-T86YT(&AE<F4N("!)9B!T:&ES(&ES
M;B=T('!A<W-E9`H@("`@("H@("`@("`@("`@("`@("`@("`@("!T:&4@97)R
M;W(@:6YF;W)M871I;VX@9V%T:&5R960@9G)O;2!T:&4@1$)-4RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@=&AE($1"7T5R<F]R(&]B:F5C=`H@
M("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIR86ES945R<F]R*"DL"B`@
M("`@*B`@("`@($1"7VEF>#HZ97)R;W).871I=F4H*2P@1$)?:69X.CIE<G)O
M<D-O9&4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!I9GA286ES945R<F]R*"1E
M<G)N;R`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"1E<G)N;R`]/3T@;G5L
M;"D@>PH@("`@("`@("`@("`D97)R;F\@/2`D=&AI<RT^97)R;W)#;V1E*&EF
M>%]E<G)O<B@I*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*"1E<G)N;RP@;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F5R<F]R3F%T:79E*"DI
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5R<F]R3F%T:79E*"D*
M"B`@("`O*BH*("`@("`J($=E=',@=&AE($1"35,G(&YA=&EV92!E<G)O<B!C
M;V1E(&%N9"!M97-S86=E('!R;V1U8V5D(&)Y('1H92!L87-T('%U97)Y"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!$0DU3)R!E<G)O<B!C
M;V1E(&%N9"!M97-S86=E"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R3F%T
M:79E*"D*("`@('L*("`@("`@("!R971U<FX@0&EF>%]E<G)O<B@I("X@)R`G
M("X@0&EF>%]E<G)O<FUS9R@I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&5R<F]R0V]D92@I"@H@("`@+RHJ"B`@("`@*B!-87!S(&YA=&EV92!E
M<G)O<B!C;V1E<R!T;R!$0B=S('!O<G1A8FQE(&]N97,N"B`@("`@*@H@("`@
M("H@4F5Q=6ER97,@=&AA="!T:&4@1$(@:6UP;&5M96YT871I;VXG<R!C;VYS
M=')U8W1O<B!F:6QL<PH@("`@("H@:6X@=&AE(#QV87(^)&5R<F]R8V]D95]M
M87`\+W9A<CX@<')O<&5R='DN"B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I
M;F<@("1N871I=F5C;V1E("!E<G)O<B!C;V1E(')E='5R;F5D(&)Y('1H92!D
M871A8F%S90H@("`@("H@0')E='5R;B!I;G0@82!P;W)T86)L92!$0B!E<G)O
M<B!C;V1E+"!O<B!$0E]%4E)/4B!I9B!T:&ES($1""B`@("`@*B!I;7!L96UE
M;G1A=&EO;B!H87,@;F\@;6%P<&EN9R!F;W(@=&AE(&=I=F5N(&5R<F]R(&-O
M9&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R0V]D92@D;F%T:79E8V]D
M92D*("`@('L*("`@("`@("!I9B`H97)E9R@G4U%,0T]$13TH+BHI72<L("1N
M871I=F5C;V1E+"`D;6%T8V@I*2!["B`@("`@("`@("`@("1C;V1E(#T@)&UA
M=&-H6S%=.PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/F5R<F]R8V]D
M95]M87!;)&-O9&5=*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YE<G)O<F-O9&5?;6%P6R1C;V1E73L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!R971U<FX@1$)?15)23U(["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@=&%B;&5);F9O*"D*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@:6YF;W)M871I;VX@86)O=70@82!T86)L92!O<B!A(')E<W5L="!S970*
M("`@("`J"B`@("`@*B!.3U1%.B!O;FQY('-U<'!O<G1S("=T86)L92<@:68@
M/'9A<CXD<F5S=6QT/"]V87(^(&ES(&$@=&%B;&4@;F%M92X*("`@("`J"B`@
M("`@*B!)9B!A;F%L>7II;F<@82!Q=65R>2!R97-U;'0@86YD('1H92!R97-U
M;'0@:&%S(&1U<&QI8V%T92!F:65L9"!N86UE<RP*("`@("`J(&%N(&5R<F]R
M('=I;&P@8F4@<F%I<V5D('-A>6EN9PH@("`@("H@/'-A;7`^8V%N)W0@9&ES
M=&EN9W5I<V@@9'5P;&EC871E(&9I96QD(&YA;65S/"]S86UP/BX*("`@("`J
M"B`@("`@*B!`<&%R86T@;V)J96-T?'-T<FEN9R`@)')E<W5L="`@1$)?<F5S
M=6QT(&]B:F5C="!F<F]M(&$@<75E<GD@;W(@80H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!S=')I;F<@8V]N=&%I;FEN9R!T:&4@
M;F%M92!O9B!A('1A8FQE+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!7:&EL92!T:&ES(&%L<V\@86-C97!T<R!A('%U97)Y(')E
M<W5L=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R
M97-O=7)C92!I9&5N=&EF:65R+"!T:&ES(&)E:&%V:6]R(&ES"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1E<')E8V%T960N"B`@
M("`@*B!`<&%R86T@:6YT("`@("`@("`@("`@)&UO9&4@("`@82!V86QI9"!T
M86)L94EN9F\@;6]D90H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(&%N
M(&%S<V]C:6%T:79E(&%R<F%Y('=I=&@@=&AE(&EN9F]R;6%T:6]N(')E<75E
M<W1E9"X*("`@("`J("`@("`@("`@("`@("`@("!!($1"7T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIT
M86)L94EN9F\H*0H@("`@("H@0'-I;F-E($UE=&AO9"!A=F%I;&%B;&4@<VEN
M8V4@4F5L96%S92`Q+C8N,`H@("`@("HO"B`@("!F=6YC=&EO;B!T86)L94EN
M9F\H)')E<W5L="P@)&UO9&4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI
M<U]S=')I;F<H)')E<W5L="DI('L*("`@("`@("`@("`@+RH*("`@("`@("`@
M("`@("H@4')O8F%B;'D@<F5C96EV960@82!T86)L92!N86UE+@H@("`@("`@
M("`@("`@*B!#<F5A=&4@82!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*
M("`@("`@("`@("`@("HO"B`@("`@("`@("`@("1I9"`]($!I9GA?<75E<GDH
M(E-%3$5#5"`J($923TT@)')E<W5L="!72$5212`Q/3`B+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@
M("`@("`@)&=O=%]S=')I;F<@/2!T<G5E.PH@("`@("`@('T@96QS96EF("AI
M<W-E="@D<F5S=6QT+3YR97-U;'0I*2!["B`@("`@("`@("`@("\J"B`@("`@
M("`@("`@("`J(%!R;V)A8FQY(')E8V5I=F5D(&$@<F5S=6QT(&]B:F5C="X*
M("`@("`@("`@("`@("H@17AT<F%C="!T:&4@<F5S=6QT(')E<V]U<F-E(&ED
M96YT:69I97(N"B`@("`@("`@("`@("`J+PH@("`@("`@("`@("`D:60@/2`D
M<F5S=6QT+3YR97-U;'0["B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@9F%L
M<V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH*("`@("`@("`@
M("`@("H@4')O8F%B;'D@<F5C96EV960@82!R97-U;'0@<F5S;W5R8V4@:61E
M;G1I9FEE<BX*("`@("`@("`@("`@("H@0V]P>2!I="X*("`@("`@("`@("`@
M("HO"B`@("`@("`@("`@("1I9"`]("1R97-U;'0["B`@("`@("`@("`@("1G
M;W1?<W1R:6YG(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES
M7W)E<V]U<F-E*"1I9"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YI
M9GA286ES945R<F]R*$1"7T524D]27TY%141?34]215]$051!*3L*("`@("`@
M("!]"@H@("`@("`@("1F;&1S(#T@0&EF>%]F:65L9'!R;W!E<G1I97,H)&ED
M*3L*("`@("`@("`D8V]U;G0@/2!`:69X7VYU;5]F:65L9',H)&ED*3L*"B`@
M("`@("`@:68@*&-O=6YT*"1F;&1S*2`A/2`D8V]U;G0I('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")C86XG="!D:7-T:6YG=6ES
M:"!D=7!L:6-A=&4@9FEE;&0@;F%M97,B*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!
M0DE,25197TQ/5T520T%312D@>PH@("`@("`@("`@("`D8V%S95]F=6YC(#T@
M)W-T<G1O;&]W97(G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C
M87-E7V9U;F,@/2`G<W1R=F%L)SL*("`@("`@("!]"@H@("`@("`@("1I("`@
M/2`P.PH@("`@("`@("1R97,@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H)&UO
M9&4I('L*("`@("`@("`@("`@)')E<ULG;G5M7V9I96QD<R==(#T@)&-O=6YT
M.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)&9L9',@87,@)&ME>2`]
M/B`D=F%L=64I('L*("`@("`@("`@("`@)'!R;W!S(#T@97AP;&]D92@G.R<L
M("1V86QU92D["B`@("`@("`@("`@("1R97-;)&E=(#T@87)R87DH"B`@("`@
M("`@("`@("`@("`G=&%B;&4G(#T^("1G;W1?<W1R:6YG(#\@)&-A<V5?9G5N
M8R@D<F5S=6QT*2`Z("<G+`H@("`@("`@("`@("`@("`@)VYA;64G("`]/B`D
M8V%S95]F=6YC*"1K97DI+`H@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`D
M<')O<'-;,%TL"B`@("`@("`@("`@("`@("`G;&5N)R`@(#T^("1P<F]P<ULQ
M72P*("`@("`@("`@("`@("`@("=F;&%G<R<@/3X@)'!R;W!S6S1=(#T]("=.
M)R`_("=N;W1?;G5L;"<@.B`G)RP*("`@("`@("`@("`@*3L*("`@("`@("`@
M("`@:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/7T]21$52*2!["B`@("`@("`@
M("`@("`@("`D<F5S6R=O<F1E<B==6R1R97-;)&E=6R=N86UE)UU=(#T@)&D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"
M3$5)3D9/7T]21$525$%"3$4I('L*("`@("`@("`@("`@("`@("1R97-;)V]R
M9&5R=&%B;&4G75LD<F5S6R1I75LG=&%B;&4G75U;)')E<ULD:5U;)VYA;64G
M75T@/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D:2LK.PH@("`@
M("`@('T*"B`@("`@("`@+R\@9G)E92!T:&4@<F5S=6QT(&]N;'D@:68@=V4@
M=V5R92!C86QL960@;VX@82!T86)L90H@("`@("`@(&EF("@D9V]T7W-T<FEN
M9RD@>PH@("`@("`@("`@("!`:69X7V9R965?<F5S=6QT*"1I9"D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D<F5S.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&=E=%-P96-I86Q1=65R>2@I"@H@("`@+RHJ"B`@("`@*B!/
M8G1A:6YS('1H92!Q=65R>2!S=')I;F<@;F5E9&5D(&9O<B!L:7-T:6YG(&$@
M9VEV96X@='EP92!O9B!O8FIE8W1S"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D='EP92`@=&AE(&MI;F0@;V8@;V)J96-T<R!Y;W4@=V%N="!T;R!R
M971R:65V90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@4U%,
M('%U97)Y('-T<FEN9R!O<B!N=6QL(&EF('1H92!D<FEV97(@9&]E<VXG=`H@
M("`@("H@("`@("`@("`@("`@("`@("!S=7!P;W)T('1H92!O8FIE8W0@='EP
M92!R97%U97-T960*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@
M("`@("H@0'-E92!$0E]C;VUM;VXZ.F=E=$QI<W1/9B@I"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%-P96-I86Q1=65R>2@D='EP92D*("`@('L*("`@("`@
M("!S=VET8V@@*"1T>7!E*2!["B`@("`@("`@("`@(&-A<V4@)W1A8FQE<R<Z
M"B`@("`@("`@("`@("`@("!R971U<FX@)U-%3$5#5"!T86)N86UE($923TT@
M<WES=&%B;&5S(%=(15)%('1A8FED(#X](#$P,"<["B`@("`@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]
M"B`@("!]"@H@("`@+R\@?7U]"@I]"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z
M"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!%;F0Z
M"B`J+PH*/SX*````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T1"
M+VUS<6PN<&AP````````````````````````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#4V-34R`#$P-3$U-#,S-S,V`#`R,#4W-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`H*+RH@=FEM.B!S
M970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T
M;W`]-#H@*B\*"B\J*@H@*B!4:&4@4$5!4B!$0B!D<FEV97(@9F]R(%!(4"=S
M(&US<6P@97AT96YS:6]N"B`J(&9O<B!I;G1E<F%C=&EN9R!W:71H($UI;FD@
M4U%,(&1A=&%B87-E<PH@*@H@*B!02%`G<R!M4U%,(&5X=&5N<VEO;B!D:60@
M=V5I<F0@=&AI;F=S('=I=&@@3E5,3"!V86QU97,@<')I;W(@=&\@4$A0"B`J
M(#0N,RXQ,2!A;F0@-2XP+C0N("!-86ME('-U<F4@>6]U<B!V97)S:6]N(&]F
M(%!(4"!M965T<R!O<B!E>&-E961S"B`J('1H;W-E('9E<G-I;VYS+@H@*@H@
M*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O
M=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(
M4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@
M<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@
M=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90H@
M*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA
M:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@
M1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@1&%N
M:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT
M("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S
M+C`*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(&US<6PN<&AP+'8@,2XU-R`R
M,#`U+S`R+S(R(#`W.C(V.C0V(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*+RHJ"B`J
M($]B=&%I;B!T:&4@1$)?8V]M;6]N(&-L87-S('-O(&ET(&-A;B!B92!E>'1E
M;F1E9"!F<F]M"B`J+PIR97%U:7)E7V]N8V4@)T1"+V-O;6UO;BYP:'`G.PH*
M+RHJ"B`J(%1H92!M971H;V1S(%!%05(@1$(@=7-E<R!T;R!I;G1E<F%C="!W
M:71H(%!(4"=S(&US<6P@97AT96YS:6]N"B`J(&9O<B!I;G1E<F%C=&EN9R!W
M:71H($UI;FD@4U%,(&1A=&%B87-E<PH@*@H@*B!4:&5S92!M971H;V1S(&]V
M97)L;V%D('1H92!O;F5S(&1E8VQA<F5D(&EN($1"7V-O;6UO;BX*("H*("H@
M4$A0)W,@;5-13"!E>'1E;G-I;VX@9&ED('=E:7)D('1H:6YG<R!W:71H($Y5
M3$P@=F%L=65S('!R:6]R('1O(%!(4`H@*B`T+C,N,3$@86YD(#4N,"XT+B`@
M36%K92!S=7)E('EO=7(@=F5R<VEO;B!O9B!02%`@;65E=',@;W(@97AC965D
M<PH@*B!T:&]S92!V97)S:6]N<RX*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A
M<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@1&%N:65L($-O
M;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW
M+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@
M0'9E<G-I;VX@("`@4F5L96%S93H@,2XW+C8*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J($!S:6YC92`@("`@($-L
M87-S(&YO="!F=6YC=&EO;F%L('5N=&EL(%)E;&5A<V4@,2XW+C`*("HO"F-L
M87-S($1"7VUS<6P@97AT96YD<R!$0E]C;VUM;VX*>PH@("`@+R\@>WM[('!R
M;W!E<G1I97,*"B`@("`O*BH*("`@("`J(%1H92!$0B!D<FEV97(@='EP92`H
M;7ES<6PL(&]C:3@L(&]D8F,L(&5T8RXI"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)'!H<'1Y<&4@/2`G;7-Q;"<["@H@("`@+RHJ"B`@
M("`@*B!4:&4@9&%T86)A<V4@<WEN=&%X('9A<FEA;G0@=&\@8F4@=7-E9"`H
M9&(R+"!A8V-E<W,L(&5T8RXI+"!I9B!A;GD*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D9&)S>6YT87@@/2`G;7-Q;"<["@H@("`@+RHJ
M"B`@("`@*B!4:&4@8V%P86)I;&ET:65S(&]F('1H:7,@1$(@:6UP;&5M96YT
M871I;VX*("`@("`J"B`@("`@*B!4:&4@)VYE=U]L:6YK)R!E;&5M96YT(&-O
M;G1A:6YS('1H92!02%`@=F5R<VEO;B!T:&%T(&9I<G-T('!R;W9I9&5D"B`@
M("`@*B!N97=?;&EN:R!S=7!P;W)T(&9O<B!T:&ES($1"35,N("!#;VYT86EN
M<R!F86QS92!I9B!I="=S('5N<W5P<&]R=&5D+@H@("`@("H*("`@("`J($UE
M86YI;F<@;V8@=&AE("=L:6UI="<@96QE;65N=#H*("`@("`J("`@*R`G96UU
M;&%T92<@/2!E;75L871E('=I=&@@9F5T8V@@<F]W(&)Y(&YU;6)E<@H@("`@
M("H@("`K("=A;'1E<B<@("`](&%L=&5R('1H92!Q=65R>0H@("`@("H@("`K
M(&9A;'-E("`@("`]('-K:7`@<F]W<PH@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1F96%T=7)E<R`](&%R<F%Y*`H@("`@("`@
M("=L:6UI="<@("`@("`@("`]/B`G96UU;&%T92<L"B`@("`@("`@)VYE=U]L
M:6YK)R`@("`@(#T^(&9A;'-E+`H@("`@("`@("=N=6UR;W=S)R`@("`@("`]
M/B!T<G5E+`H@("`@("`@("=P8V]N;F5C="<@("`@("`]/B!T<G5E+`H@("`@
M("`@("=P<F5P87)E)R`@("`@("`]/B!F86QS92P*("`@("`@("`G<W-L)R`@
M("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@)W1R86YS86-T:6]N<R<@(#T^
M(&9A;'-E+`H@("`@*3L*"B`@("`O*BH*("`@("`J($$@;6%P<&EN9R!O9B!N
M871I=F4@97)R;W(@8V]D97,@=&\@1$(@97)R;W(@8V]D97,*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1E<G)O<F-O9&5?;6%P(#T@87)R
M87DH"B`@("`I.PH*("`@("\J*@H@("`@("H@5&AE(')A=R!D871A8F%S92!C
M;VYN96-T:6]N(&-R96%T960@8GD@4$A0"B`@("`@*B!`=F%R(')E<V]U<F-E
M"B`@("`@*B\*("`@('9A<B`D8V]N;F5C=&EO;CL*"B`@("`O*BH*("`@("`J
M(%1H92!$4TX@:6YF;W)M871I;VX@9F]R(&-O;FYE8W1I;F<@=&\@82!D871A
M8F%S90H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&1S;B`]
M(&%R<F%Y*"D["@H*("`@("\J*@H@("`@("H@5&AE('%U97)Y(')E<W5L="!R
M97-O=7)C92!C<F5A=&5D(&)Y(%!(4`H@("`@("H*("`@("`J(%5S960@=&\@
M;6%K92!A9F9E8W1E9%)O=W,H*2!W;W)K+B`@3VYL>2!C;VYT86EN<R!T:&4@
M<F5S=6QT(&9O<@H@("`@("H@9&%T82!M86YI<'5L871I;VX@<75E<FEE<RX@
M($-O;G1A:6YS(&9A;'-E(&9O<B!O=&AE<B!Q=65R:65S+@H@("`@("H*("`@
M("`J($!V87(@<F5S;W5R8V4*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("HO"B`@("!V87(@)%]R97-U;'0["@H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&-O;G-T<G5C=&]R"@H@("`@+RHJ"B`@("`@*B!4:&ES(&-O;G-T<G5C=&]R
M(&-A;&QS(#QK8F0^)'1H:7,M/D1"7V-O;6UO;B@I/"]K8F0^"B`@("`@*@H@
M("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N($1"7VUS
M<6PH*0H@("`@>PH@("`@("`@("1T:&ES+3Y$0E]C;VUM;VXH*3L*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYN96-T*"D*"B`@("`O*BH*("`@
M("`J($-O;FYE8W0@=&\@=&AE(&1A=&%B87-E('-E<G9E<BP@;&]G(&EN(&%N
M9"!O<&5N('1H92!D871A8F%S90H@("`@("H*("`@("`J($1O;B=T(&-A;&P@
M=&AI<R!M971H;V0@9&ER96-T;'DN("!5<V4@1$(Z.F-O;FYE8W0H*2!I;G-T
M96%D+@H@("`@("H*("`@("`J($5X86UP;&4@;V8@:&]W('1O(&-O;FYE8W0Z
M"B`@("`@*B`\8V]D93X*("`@("`J(')E<75I<F5?;VYC92`G1$(N<&AP)SL*
M("`@("`J(`H@("`@("H@+R\@)&1S;B`]("=M<W%L.B\O:&]S=&YA;64O9&)N
M86UE)SL@("\O('5S92!A(%1#4"!C;VYN96-T:6]N"B`@("`@*B`D9'-N(#T@
M)VUS<6PZ+R\O9&)N86UE)SL@("`@("`@("`@("`@+R\@=7-E(&$@<V]C:V5T
M"B`@("`@*B`D;W!T:6]N<R`](&%R<F%Y*`H@("`@("H@("`@("=P;W)T86)I
M;&ET>2<@/3X@1$)?4$]25$%"24Q)5%E?04Q,+`H@("`@("H@*3L*("`@("`J
M(`H@("`@("H@)&1B(#TF($1".CIC;VYN96-T*"1D<VXL("1O<'1I;VYS*3L*
M("`@("`J(&EF("A014%2.CII<T5R<F]R*"1D8BDI('L*("`@("`J("`@("!D
M:64H)&1B+3YG971-97-S86=E*"DI.PH@("`@("H@?0H@("`@("H@/"]C;V1E
M/@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D9'-N("`@("`@("`@=&AE
M(&1A=&$@<V]U<F-E(&YA;64*("`@("`J($!P87)A;2!B;V]L("`D<&5R<VES
M=&5N="`@<VAO=6QD('1H92!C;VYN96-T:6]N(&)E('!E<G-I<W1E;G0_"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N($$@
M1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&-O;FYE8W0H)&1S;BP@)'!E<G-I<W1E;G0@/2!F86QS92D*("`@('L*
M("`@("`@("!I9B`H(5!%05(Z.FQO861%>'1E;G-I;VXH)VUS<6PG*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?
M15A414Y324].7TY/5%]&3U5.1"D["B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^9'-N(#T@)&1S;CL*("`@("`@("!I9B`H)&1S;ELG9&)S>6YT87@G72D@
M>PH@("`@("`@("`@("`D=&AI<RT^9&)S>6YT87@@/2`D9'-N6R=D8G-Y;G1A
M>"==.PH@("`@("`@('T*"B`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"D["B`@
M("`@("`@:68@*"1D<VY;)VAO<W1S<&5C)UTI('L*("`@("`@("`@("`@)'!A
M<F%M<UM=(#T@)&1S;ELG<&]R="=="B`@("`@("`@("`@("`@("`@("`@("`@
M(#\@)&1S;ELG:&]S='-P96,G72`N("<L)R`N("1D<VY;)W!O<G0G70H@("`@
M("`@("`@("`@("`@("`@("`@("`Z("1D<VY;)VAO<W1S<&5C)UT["B`@("`@
M("`@?0H*("`@("`@("`D8V]N;F5C=%]F=6YC=&EO;B`]("1P97)S:7-T96YT
M(#\@)VUS<6Q?<&-O;FYE8W0G(#H@)VUS<6Q?8V]N;F5C="<["@H@("`@("`@
M("1I;FD@/2!I;FE?9V5T*"=T<F%C:U]E<G)O<G,G*3L*("`@("`@("`D<&AP
M7V5R<F]R;7-G(#T@)R<["B`@("`@("`@:68@*"1I;FDI('L*("`@("`@("`@
M("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!`8V%L;%]U<V5R7V9U;F-?87)R87DH
M)&-O;FYE8W1?9G5N8W1I;VXL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;7,I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(&EN:5]S970H)W1R86-K7V5R<F]R<R<L
M(#$I.PH@("`@("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`]($!C86QL7W5S
M97)?9G5N8U]A<G)A>2@D8V]N;F5C=%]F=6YC=&EO;BP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A
M<F%M<RD["B`@("`@("`@("`@(&EN:5]S970H)W1R86-K7V5R<F]R<R<L("1I
M;FDI.PH@("`@("`@('T*"B`@("`@("`@:68@*"$D=&AI<RT^8V]N;F5C=&EO
M;BD@>PH@("`@("`@("`@("!I9B`H*"1E<G(@/2!`;7-Q;%]E<G)O<B@I*2`A
M/2`G)RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*$1"7T524D]27T-/3DY%0U1?1D%)3$5$+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL(&YU;&PL(&YU;&PL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5R<BD[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?0T].3D5#5%]&04E,140L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;G5L;"P@
M;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&AP7V5R<F]R;7-G*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@:68@*"%`;7-Q;%]S96QE8W1?9&(H)&1S;ELG9&%T86)A
M<V4G72P@)'1H:7,M/F-O;FYE8W1I;VXI*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^;7-Q;%)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1I
M<V-O;FYE8W0H*0H*("`@("\J*@H@("`@("H@1&ES8V]N;F5C=',@9G)O;2!T
M:&4@9&%T86)A<V4@<V5R=F5R"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M("!44E5%(&]N('-U8V-E<W,L($9!3%-%(&]N(&9A:6QU<F4*("`@("`J+PH@
M("`@9G5N8W1I;VX@9&ES8V]N;F5C="@I"B`@("!["B`@("`@("`@)')E="`]
M($!M<W%L7V-L;W-E*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`D=&AI
M<RT^8V]N;F5C=&EO;B`](&YU;&P["B`@("`@("`@<F5T=7)N("1R970["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<VEM<&QE475E<GDH*0H*("`@
M("\J*@H@("`@("H@4V5N9',@82!Q=65R>2!T;R!T:&4@9&%T86)A<V4@<V5R
M=F5R"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@=&AE(%-13"!Q=65R
M>2!S=')I;F<*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("`K(&$@4$A0
M(')E<W5L="!R97-R;W5C92!F;W(@<W5C8V5S<V9U;"!314Q%0U0@<75E<FEE
M<PH@("`@("H@("`@("`@("`@("`@("`@*R!T:&4@1$)?3TL@8V]N<W1A;G0@
M9F]R(&]T:&5R('-U8V-E<W-F=6P@<75E<FEE<PH@("`@("H@("`@("`@("`@
M("`@("`@*R!A($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-I;7!L95%U97)Y*"1Q=65R>2D*("`@('L*("`@("`@
M("`D=&AI<RT^;&%S=%]Q=65R>2`]("1Q=65R>3L*("`@("`@("`D<75E<GD@
M/2`D=&AI<RT^;6]D:69Y475E<GDH)'%U97)Y*3L*("`@("`@("`D<F5S=6QT
M(#T@0&US<6Q?<75E<GDH)'%U97)Y+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@
M("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^;7-Q;%)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@+R\@1&5T
M97)M:6YE('=H:6-H('%U97)I97,@=&AA="!S:&]U;&0@<F5T=7)N(&1A=&$L
M(&%N9"!W:&EC:`H@("`@("`@("\O('-H;W5L9"!R971U<FX@86X@97)R;W(@
M8V]D92!O;FQY+@H@("`@("`@(&EF("A$0CHZ:7--86YI<"@D<75E<GDI*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?<F5S=6QT(#T@)')E<W5L=#L*("`@("`@
M("`@("`@<F5T=7)N($1"7T]+.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1T:&ES+3Y?<F5S=6QT(#T@9F%L<V4["B`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@('T*("`@('T*"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@;F5X=%)E<W5L="@I"@H@("`@+RHJ"B`@("`@*B!-;W9E('1H92!I
M;G1E<FYA;"!M<W%L(')E<W5L="!P;VEN=&5R('1O('1H92!N97AT(&%V86EL
M86)L92!R97-U;'0*("`@("`J"B`@("`@*B!`<&%R86T@82!V86QI9"!F8G-Q
M;"!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("H*("`@("`J($!R971U<FX@=')U92!I9B!A(')E<W5L="!I<R!A
M=F%I;&%B;&4@;W1H97)W:7-E(')E='5R;B!F86QS90H@("`@("HO"B`@("!F
M=6YC=&EO;B!N97AT4F5S=6QT*"1R97-U;'0I"B`@("!["B`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9E=&-H
M26YT;R@I"@H@("`@+RHJ"B`@("`@*B!0;&%C97,@82!R;W<@9G)O;2!T:&4@
M<F5S=6QT('-E="!I;G1O('1H92!G:79E;B!A<G)A>0H@("`@("H*("`@("`J
M($9O<FUA=&EN9R!O9B!T:&4@87)R87D@86YD('1H92!D871A('1H97)E:6X@
M87)E(&-O;F9I9W5R86)L92X*("`@("`J(%-E92!$0E]R97-U;'0Z.F9E=&-H
M26YT;R@I(&9O<B!M;W)E(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J(%1H
M:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN
M("!5<V4*("`@("`J($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D@:6YS=&5A9"X@
M($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A
M=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@
M("`@*B!02%`G<R!M4U%,(&5X=&5N<VEO;B!D:60@=V5I<F0@=&AI;F=S('=I
M=&@@3E5,3"!V86QU97,@<')I;W(@=&\@4$A0"B`@("`@*B`T+C,N,3$@86YD
M(#4N,"XT+B`@36%K92!S=7)E('EO=7(@=F5R<VEO;B!O9B!02%`@;65E=',@
M;W(@97AC965D<PH@("`@("H@=&AO<V4@=F5R<VEO;G,N"B`@("`@*@H@("`@
M("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@("`@=&AE('%U97)Y(')E<W5L
M="!R97-O=7)C90H@("`@("H@0'!A<F%M(&%R<F%Y("`@("1A<G(@("`@("`@
M=&AE(')E9F5R96YC960@87)R87D@=&\@<'5T('1H92!D871A(&EN"B`@("`@
M*B!`<&%R86T@:6YT("`@("`@)&9E=&-H;6]D92!H;W<@=&AE(')E<W5L=&EN
M9R!A<G)A>2!S:&]U;&0@8F4@:6YD97AE9`H@("`@("H@0'!A<F%M(&EN="`@
M("`@("1R;W=N=6T@("`@=&AE(')O=R!N=6UB97(@=&\@9F5T8V@@*#`@/2!F
M:7)S="!R;W<I"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1$)?3TL@
M;VX@<W5C8V5S<RP@3E5,3"!W:&5N('1H92!E;F0@;V8@82!R97-U;'0@<V5T
M(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@<F5A8VAE9"!O<B!O;B!F86EL
M=7)E"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&9E=&-H26YT;R@D<F5S=6QT+"`F)&%R
M<BP@)&9E=&-H;6]D92P@)')O=VYU;2`](&YU;&PI"B`@("!["B`@("`@("`@
M:68@*"1R;W=N=6T@(3T](&YU;&PI('L*("`@("`@("`@("`@:68@*"%`;7-Q
M;%]D871A7W-E96LH)')E<W5L="P@)')O=VYU;2DI('L*("`@("`@("`@("`@
M("`@(')E='5R;B!N=6QL.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(&EF("@D9F5T8VAM;V1E("8@1$)?1D540TA-3T1%7T%34T]#*2!["B`@
M("`@("`@("`@("1A<G(@/2!`;7-Q;%]F971C:%]A<G)A>2@D<F5S=6QT+"!-
M4U%,7T%34T]#*3L*("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P
M;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3$]715)#05-%("8F("1A
M<G(I('L*("`@("`@("`@("`@("`@("1A<G(@/2!A<G)A>5]C:&%N9V5?:V5Y
M7V-A<V4H)&%R<BP@0T%315],3U=%4BD["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D87)R(#T@0&US<6Q?9F5T8VA?<F]W
M*"1R97-U;'0I.PH@("`@("`@('T*("`@("`@("!I9B`H(21A<G(I('L*("`@
M("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@("`@(&EF("@D
M=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,2519
M7U)44DE-*2!["B`@("`@("`@("`@("1T:&ES+3Y?<G1R:6U!<G)A>59A;'5E
M<R@D87)R*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS
M6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3E5,3%]43U]%35!4
M62D@>PH@("`@("`@("`@("`D=&AI<RT^7V-O;G9E<G1.=6QL07)R87E686QU
M97-4;T5M<'1Y*"1A<G(I.PH@("`@("`@('T*("`@("`@("!R971U<FX@1$)?
M3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9G)E95)E<W5L="@I
M"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S('1H92!R97-U;'0@<V5T(&%N9"!F
M<F5E<R!T:&4@;65M;W)Y(&]C8W5P:65D(&)Y('1H92!R97-U;'0@<V5T"B`@
M("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A
M;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIF<F5E*"D@
M:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@
M("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@
M<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L("!44E5%(&]N('-U8V-E<W,L($9!3%-%(&EF("1R97-U;'0@:7,@:6YV
M86QI9`H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIF<F5E*"D*("`@
M("`J+PH@("`@9G5N8W1I;VX@9G)E95)E<W5L="@D<F5S=6QT*0H@("`@>PH@
M("`@("`@(')E='5R;B!`;7-Q;%]F<F5E7W)E<W5L="@D<F5S=6QT*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N=6U#;VQS*"D*"B`@("`O*BH*
M("`@("`J($=E=',@=&AE(&YU;6)E<B!O9B!C;VQU;6YS(&EN(&$@<F5S=6QT
M('-E=`H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T
M;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ
M;G5M0V]L<R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B<')O
M=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T
M92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U
M;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J
M($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(&-O;'5M;G,N("!!($1"7T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?
M<F5S=6QT.CIN=6U#;VQS*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;G5M0V]L
M<R@D<F5S=6QT*0H@("`@>PH@("`@("`@("1C;VQS(#T@0&US<6Q?;G5M7V9I
M96QD<R@D<F5S=6QT*3L*("`@("`@("!I9B`H(21C;VQS*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^;7-Q;%)A:7-E17)R;W(H*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1C;VQS.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&YU;5)O=W,H*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M
M8F5R(&]F(')O=W,@:6X@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI
M<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@
M(%5S90H@("`@("H@1$)?<F5S=6QT.CIN=6U2;W=S*"D@:6YS=&5A9"X@($ET
M(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E
M($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT
M(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB
M97(@;V8@<F]W<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.FYU;5)O=W,H*0H@("`@("HO
M"B`@("!F=6YC=&EO;B!N=6U2;W=S*"1R97-U;'0I"B`@("!["B`@("`@("`@
M)')O=W,@/2!`;7-Q;%]N=6U?<F]W<R@D<F5S=6QT*3L*("`@("`@("!I9B`H
M)')O=W,@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M;7-Q;%)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R
M;W=S.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&%F9F5C=&5D*"D*
M"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@=&AE(&YU;6)E<B!O9B!R;W=S
M(&%F9F5C=&5D(&)Y(&$@9&%T82!M86YI=7!L871I;VX@<75E<GD*("`@("`J
M"B`@("`@*B`P(&ES(')E='5R;F5D(&9O<B!Q=65R:65S('1H870@9&]N)W0@
M;6%N:7!U;&%T92!D871A+@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T
M:&4@;G5M8F5R(&]F(')O=W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9F9E8W1E9%)O=W,H*0H@("`@
M>PH@("`@("`@(&EF("@A)'1H:7,M/E]R97-U;'0I('L*("`@("`@("`@("`@
M<F5T=7)N(#`["B`@("`@("`@?0H@("`@("`@(')E='5R;B!M<W%L7V%F9F5C
M=&5D7W)O=W,H)'1H:7,M/E]R97-U;'0I.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&YE>'1)9"@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!N97AT(&9R964@:60@:6X@82!S97%U96YC90H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@("1S97%?;F%M92`@;F%M92!O9B!T:&4@<V5Q=65N8V4*
M("`@("`J($!P87)A;2!B;V]L96%N("1O;F1E;6%N9"`@=VAE;B!T<G5E+"!T
M:&4@<V5Q96YC92!I<R!A=71O;6%T:6-A;&QY"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!C<F5A=&5D(&EF(&ET(&1O97,@;F]T(&5X:7-T
M"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N97AT(&ED(&YU;6)E
M<B!I;B!T:&4@<V5Q=65N8V4N"B`@("`@*B`@("`@("`@("`@("`@($$@1$)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$
M0E]C;VUM;VXZ.FYE>'1)1"@I+"!$0E]C;VUM;VXZ.F=E=%-E<75E;F-E3F%M
M92@I+`H@("`@("H@("`@("!$0E]M<W%L.CIC<F5A=&5397%U96YC92@I+"!$
M0E]M<W%L.CID<F]P4V5Q=65N8V4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!N
M97AT260H)'-E<5]N86UE+"`D;VYD96UA;F0@/2!T<G5E*0H@("`@>PH@("`@
M("`@("1S97%N86UE(#T@)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA
M;64I.PH@("`@("`@("1R97!E870@/2!F86QS93L*("`@("`@("!D;R!["B`@
M("`@("`@("`@("1T:&ES+3YP=7-H17)R;W)(86YD;&EN9RA014%27T524D]2
M7U)%5%523BD["B`@("`@("`@("`@("1R97-U;'0@/28@)'1H:7,M/G%U97)Y
M*")314Q%0U0@7W-E<2!&4D]-("1[<V5Q;F%M97TB*3L*("`@("`@("`@("`@
M)'1H:7,M/G!O<$5R<F]R2&%N9&QI;F<H*3L*("`@("`@("`@("`@:68@*"1O
M;F1E;6%N9"`F)B!$0CHZ:7-%<G)O<B@D<F5S=6QT*2`F)@H@("`@("`@("`@
M("`@("`@)')E<W5L="T^9V5T0V]D92@I(#T]($1"7T524D]27TY/4U5#2%1!
M0DQ%*2!["B`@("`@("`@("`@("`@("`D<F5P96%T(#T@=')U93L*("`@("`@
M("`@("`@("`@("1T:&ES+3YP=7-H17)R;W)(86YD;&EN9RA014%27T524D]2
M7U)%5%523BD["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F-R
M96%T95-E<75E;F-E*"1S97%?;F%M92D["B`@("`@("`@("`@("`@("`D=&AI
M<RT^<&]P17)R;W)(86YD;&EN9R@I.PH@("`@("`@("`@("`@("`@:68@*$1"
M.CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E
M<&5A="`](&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?2!W:&EL92`H
M)')E<&5A="D["B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT
M*3L*("`@("`@("!]"B`@("`@("`@)&%R<B`]("1R97-U;'0M/F9E=&-H4F]W
M*$1"7T9%5$-(34]$15]/4D1%4D5$*3L*("`@("`@("`D<F5S=6QT+3YF<F5E
M*"D["B`@("`@("`@<F5T=7)N("1A<G);,%T["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@8W)E871E4V5Q=65N8V4H*0H*("`@("\J*@H@("`@("H@
M0W)E871E<R!A(&YE=R!S97%U96YC90H@("`@("H*("`@("`J($%L<V\@8W)E
M871E<R!A(&YE=R!T86)L92!T;R!A<W-O8VEA=&4@=&AE('-E<75E;F-E('=I
M=&@N("!5<V5S"B`@("`@*B!A('-E<&%R871E('1A8FQE('1O(&5N<W5R92!P
M;W)T86)I;&ET>2!W:71H(&]T:&5R(&1R:79E<G,N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<V5Q7VYA;64@(&YA;64@;V8@=&AE(&YE=R!S97%U
M96YC90H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C
M97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@
M("`@*B!`<V5E($1"7V-O;6UO;CHZ8W)E871E4V5Q=65N8V4H*2P@1$)?8V]M
M;6]N.CIG971397%U96YC94YA;64H*2P*("`@("`J("`@("`@1$)?;7-Q;#HZ
M;F5X=$E$*"DL($1"7VUS<6PZ.F1R;W!397%U96YC92@I"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-R96%T95-E<75E;F-E*"1S97%?;F%M92D*("`@('L*("`@
M("`@("`D<V5Q;F%M92`]("1T:&ES+3YG971397%U96YC94YA;64H)'-E<5]N
M86UE*3L*("`@("`@("`D<F5S(#T@)'1H:7,M/G%U97)Y*"=#4D5!5$4@5$%"
M3$4@)R`N("1S97%N86UE"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`N
M("<@*&ED($E.5$5'15(@3D]4($Y53$PI)RD["B`@("`@("`@:68@*$1".CII
M<T5R<F]R*"1R97,I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@
M("`@('T*("`@("`@("`D<F5S(#T@)'1H:7,M/G%U97)Y*")#4D5!5$4@4T51
M545.0T4@3TX@)'MS97%N86UE?2(I.PH@("`@("`@(')E='5R;B`D<F5S.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1R;W!397%U96YC92@I"@H@
M("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@<V5Q=65N8V4*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1S97%?;F%M92`@;F%M92!O9B!T:&4@<V5Q=65N
M8V4@=&\@8F4@9&5L971E9`H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$
M0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ9')O<%-E<75E;F-E
M*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@*B`@("`@
M($1"7VUS<6PZ.FYE>'1)1"@I+"!$0E]M<W%L.CIC<F5A=&5397%U96YC92@I
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&1R;W!397%U96YC92@D<V5Q7VYA;64I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YQ=65R>2@G1%)/4"!404),
M12`G("X@)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!Q=6]T94ED96YT:69I97(H*0H*
M("`@("\J*@H@("`@("H@;5-13"!D;V5S(&YO="!S=7!P;W)T(&1E;&EM:71E
M9"!I9&5N=&EF:65R<PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T
M<B`@=&AE(&ED96YT:69I97(@;F%M92!T;R!B92!Q=6]T960*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&]B:F5C="`@82!$0E]%<G)O<B!O8FIE8W0*("`@("`J
M"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<75O=&5)9&5N=&EF:65R*"D*("`@
M("`J($!S:6YC92!-971H;V0@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XW
M+C`*("`@("`J+PH@("`@9G5N8W1I;VX@<75O=&5)9&5N=&EF:65R*"1S='(I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T52
M4D]27U5.4U504$]25$5$*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!E<V-A<&53:6UP;&4H*0H*("`@("\J*@H@("`@("H@17-C87!E<R!A('-T
M<FEN9R!A8V-O<F1I;F<@=&\@=&AE(&-U<G)E;G0@1$)-4R=S('-T86YD87)D
M<PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T<B`@=&AE('-T<FEN
M9R!T;R!B92!E<V-A<&5D"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M('1H92!E<V-A<&5D('-T<FEN9PH@("`@("H*("`@("`J($!S964@1$)?8V]M
M;6]N.CIQ=6]T95-M87)T*"D*("`@("`J($!S:6YC92!-971H;V0@879A:6QA
M8FQE('-I;F-E(%)E;&5A<V4@,2XW+C`*("`@("`J+PH@("`@9G5N8W1I;VX@
M97-C87!E4VEM<&QE*"1S='(I"B`@("!["B`@("`@("`@<F5T=7)N(&%D9'-L
M87-H97,H)'-T<BD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;7-Q
M;%)A:7-E17)R;W(H*0H*("`@("\J*@H@("`@("H@4')O9'5C97,@82!$0E]%
M<G)O<B!O8FIE8W0@<F5G87)D:6YG('1H92!C=7)R96YT('!R;V)L96T*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT("1E<G)N;R`@:68@=&AE(&5R<F]R(&ES
M(&)E:6YG(&UA;G5A;&QY(')A:7-E9"!P87-S(&$*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@1$)?15)23U(J(&-O;G-T86YT(&AE<F4N("!)9B!T:&ES
M(&ES;B=T('!A<W-E9`H@("`@("H@("`@("`@("`@("`@("`@("`@("!T:&4@
M97)R;W(@:6YF;W)M871I;VX@9V%T:&5R960@9G)O;2!T:&4@1$)-4RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@=&AE($1"7T5R<F]R(&]B:F5C
M=`H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIR86ES945R<F]R*"DL
M"B`@("`@*B`@("`@($1"7VUS<6PZ.F5R<F]R3F%T:79E*"DL($1"7VUS<6PZ
M.F5R<F]R0V]D92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&US<6Q286ES945R
M<F]R*"1E<G)N;R`](&YU;&PI"B`@("!["B`@("`@("`@)&YA=&EV92`]("1T
M:&ES+3YE<G)O<DYA=&EV92@I.PH@("`@("`@(&EF("@D97)R;F\@/3T](&YU
M;&PI('L*("`@("`@("`@("`@)&5R<FYO(#T@)'1H:7,M/F5R<F]R0V]D92@D
M;F%T:79E*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"1E<G)N;RP@;G5L;"P@;G5L;"P@;G5L;"P@)&YA=&EV92D["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97)R;W).871I=F4H*0H*("`@
M("\J*@H@("`@("H@1V5T<R!T:&4@1$)-4R<@;F%T:79E(&5R<F]R(&UE<W-A
M9V4@<')O9'5C960@8GD@=&AE(&QA<W0@<75E<GD*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@=&AE($1"35,G(&5R<F]R(&UE<W-A9V4*("`@("`J
M+PH@("`@9G5N8W1I;VX@97)R;W).871I=F4H*0H@("`@>PH@("`@("`@(')E
M='5R;B!`;7-Q;%]E<G)O<B@I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&5R<F]R0V]D92@I"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S(%!%
M05(Z.D1"(&5R<F]R(&-O9&4@9G)O;2!T:&4@9&%T86)A<V4G<R!T97AT(&5R
M<F]R(&UE<W-A9V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1E<G)O
M<FUS9R`@=&AE(&5R<F]R(&UE<W-A9V4@<F5T=7)N960@9G)O;2!T:&4@9&%T
M86)A<V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@('1H92!E<G)O
M<B!N=6UB97(@9G)O;2!A($1"7T524D]2*B!C;VYS=&%N=`H@("`@("HO"B`@
M("!F=6YC=&EO;B!E<G)O<D-O9&4H)&5R<F]R;7-G*0H@("`@>PH@("`@("`@
M('-T871I8R`D97)R;W)?<F5G97AP<SL*("`@("`@("!I9B`H(6ES<V5T*"1E
M<G)O<E]R96=E>'!S*2D@>PH@("`@("`@("`@("`D97)R;W)?<F5G97AP<R`]
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@)R]>06-C97-S('1O(&1A=&%B87-E
M(&1E;FEE9"]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27T%#
M0T534U]624],051)3TXL"B`@("`@("`@("`@("`@("`G+UY"860@:6YD97@@
M;F%M92]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27T%,4D5!
M1%E?15A)4U13+`H@("`@("`@("`@("`@("`@)R]>0F%D(&]R9&5R(&9I96QD
M+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?4UE.5$%8+`H@
M("`@("`@("`@("`@("`@)R]>0F%D('1Y<&4@9F]R(&-O;7!A<FES;VXO:2<*
M("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E]364Y405@L"B`@("`@
M("`@("`@("`@("`G+UY#86Y<)W0@<&5R9F]R;2!,24M%(&]N+VDG"B`@("`@
M("`@("`@("`@("`@("`@/3X@1$)?15)23U)?4UE.5$%8+`H@("`@("`@("`@
M("`@("`@)R]>0V%N7"=T('5S92!415A4(&9I96QD<R!I;B!,24M%(&-O;7!A
M<FES;VXO:2<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E]364Y4
M05@L"B`@("`@("`@("`@("`@("`G+UY#;W5L9&Y<)W0@8W)E871E('1E;7!O
M<F%R>2!T86)L92]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]2
M7T-!3DY/5%]#4D5!5$4L"B`@("`@("`@("`@("`@("`G+UY%<G)O<B!C<F5A
M=&EN9R!T86)L92!F:6QE+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?
M15)23U)?0T%.3D]47T-214%412P*("`@("`@("`@("`@("`@("<O7D9I96QD
M("XJ(&-A;FYO="!B92!N=6QL)"]I)PH@("`@("`@("`@("`@("`@("`@(#T^
M($1"7T524D]27T-/3E-44D%)3E1?3D]47TY53$PL"B`@("`@("`@("`@("`@
M("`G+UY);F1E>"`H9FEE;&1\8V]N9&ET:6]N*2`N*B!C86YN;W0@8F4@;G5L
M;"0O:2<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E]364Y405@L
M"B`@("`@("`@("`@("`@("`G+UY);G9A;&ED(&1A=&4@9F]R;6%T+VDG"B`@
M("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?24Y604Q)1%]$051%+`H@
M("`@("`@("`@("`@("`@)R]>26YV86QI9"!T:6UE(&9O<FUA="]I)PH@("`@
M("`@("`@("`@("`@("`@(#T^($1"7T524D]27TE.5D%,240L"B`@("`@("`@
M("`@("`@("`G+UY,:71E<F%L('9A;'5E(&9O<B`N*B!I<R!W<F]N9R!T>7!E
M)"]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27TE.5D%,241?
M3E5-0D52+`H@("`@("`@("`@("`@("`@)R]>3F\@1&%T86)A<V4@4V5L96-T
M960O:2<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E].3T1"4T5,
M14-4140L"B`@("`@("`@("`@("`@("`G+UY.;R!V86QU92!S<&5C:69I960@
M9F]R(&9I96QD+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?
M5D%,545?0T]53E1?3TY?4D]7+`H@("`@("`@("`@("`@("`@)R]>3F]N('5N
M:7%U92!V86QU92!F;W(@=6YI<75E(&EN9&5X+VDG"B`@("`@("`@("`@("`@
M("`@("`@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("`@("`@("`@("`@
M("<O7D]U="!O9B!M96UO<GD@9F]R('1E;7!O<F%R>2!T86)L92]I)PH@("`@
M("`@("`@("`@("`@("`@(#T^($1"7T524D]27T-!3DY/5%]#4D5!5$4L"B`@
M("`@("`@("`@("`@("`G+UY097)M:7-S:6]N(&1E;FEE9"]I)PH@("`@("`@
M("`@("`@("`@("`@(#T^($1"7T524D]27T%#0T534U]624],051)3TXL"B`@
M("`@("`@("`@("`@("`G+UY2969E<F5N8V4@=&\@=6XM<V5L96-T960@=&%B
M;&4O:2<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E]364Y405@L
M"B`@("`@("`@("`@("`@("`G+UYS>6YT87@@97)R;W(O:2<*("`@("`@("`@
M("`@("`@("`@("`]/B!$0E]%4E)/4E]364Y405@L"B`@("`@("`@("`@("`@
M("`G+UY486)L92`N*B!E>&ES=',D+VDG"B`@("`@("`@("`@("`@("`@("`@
M/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@("`@("`@("`@("`@("`G
M+UY5;FMN;W=N(&1A=&%B87-E+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@
M1$)?15)23U)?3D]354-(1$(L"B`@("`@("`@("`@("`@("`G+UY5;FMN;W=N
M(&9I96QD+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?3D]3
M54-(1DE%3$0L"B`@("`@("`@("`@("`@("`G+UY5;FMN;W=N("AI;F1E>'QS
M>7-T96T@=F%R:6%B;&4I+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?
M15)23U)?3D]47T9/54Y$+`H@("`@("`@("`@("`@("`@)R]>56YK;F]W;B!T
M86)L92]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27TY/4U5#
M2%1!0DQ%+`H@("`@("`@("`@("`@("`@)R]>56YQ=6%L:69I960@9FEE;&0O
M:2<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E]364Y405@L"B`@
M("`@("`@("`@("D["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D97)R
M;W)?<F5G97AP<R!A<R`D<F5G97AP(#T^("1C;V1E*2!["B`@("`@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"1R96=E>'`L("1E<G)O<FUS9RDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D8V]D93L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!R971U<FX@1$)?15)23U(["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@=&%B;&5);F9O*"D*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@:6YF;W)M871I;VX@86)O=70@82!T86)L92!O<B!A(')E<W5L="!S970*
M("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T?'-T<FEN9R`@)')E<W5L="`@
M1$)?<F5S=6QT(&]B:F5C="!F<F]M(&$@<75E<GD@;W(@80H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=')I;F<@8V]N=&%I;FEN
M9R!T:&4@;F%M92!O9B!A('1A8FQE+@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!7:&EL92!T:&ES(&%L<V\@86-C97!T<R!A('%U
M97)Y(')E<W5L=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!R97-O=7)C92!I9&5N=&EF:65R+"!T:&ES(&)E:&%V:6]R(&ES"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1E<')E8V%T
M960N"B`@("`@*B!`<&%R86T@:6YT("`@("`@("`@("`@)&UO9&4@("`@82!V
M86QI9"!T86)L94EN9F\@;6]D90H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@(&%N(&%S<V]C:6%T:79E(&%R<F%Y('=I=&@@=&AE(&EN9F]R;6%T:6]N
M(')E<75E<W1E9"X*("`@("`J("`@("`@("`@("`@("`@("!!($1"7T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M
M;6]N.CIS971/<'1I;VXH*0H@("`@("HO"B`@("!F=6YC=&EO;B!T86)L94EN
M9F\H)')E<W5L="P@)&UO9&4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI
M<U]S=')I;F<H)')E<W5L="DI('L*("`@("`@("`@("`@+RH*("`@("`@("`@
M("`@("H@4')O8F%B;'D@<F5C96EV960@82!T86)L92!N86UE+@H@("`@("`@
M("`@("`@*B!#<F5A=&4@82!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*
M("`@("`@("`@("`@("HO"B`@("`@("`@("`@("1I9"`]($!M<W%L7W%U97)Y
M*")314Q%0U0@*B!&4D]-("1R97-U;'0B+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("1G
M;W1?<W1R:6YG(#T@=')U93L*("`@("`@("!](&5L<V5I9B`H:7-S970H)')E
M<W5L="T^<F5S=6QT*2D@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@
M*B!0<F]B86)L>2!R96-E:79E9"!A(')E<W5L="!O8FIE8W0N"B`@("`@("`@
M("`@("`J($5X=')A8W0@=&AE(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R
M+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@)&ED(#T@)')E<W5L="T^
M<F5S=6QT.PH@("`@("`@("`@("`D9V]T7W-T<FEN9R`](&9A;'-E.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R
M;V)A8FQY(')E8V5I=F5D(&$@<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N
M"B`@("`@("`@("`@("`J($-O<'D@:70N"B`@("`@("`@("`@("`J($1E<')E
M8V%T960N("!(97)E(&9O<B!C;VUP871I8FEL:71Y(&]N;'DN"B`@("`@("`@
M("`@("`J+PH@("`@("`@("`@("`D:60@/2`D<F5S=6QT.PH@("`@("`@("`@
M("`D9V]T7W-T<FEN9R`](&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"%I<U]R97-O=7)C92@D:60I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].145$7TU/4D5?1$%402D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y
M)UT@)B!$0E]03U)404))3$E465],3U=%4D-!4T4I('L*("`@("`@("`@("`@
M)&-A<V5?9G5N8R`]("=S=')T;VQO=V5R)SL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D8V%S95]F=6YC(#T@)W-T<G9A;"<["B`@("`@("`@?0H*
M("`@("`@("`D8V]U;G0@/2!`;7-Q;%]N=6U?9FEE;&1S*"1I9"D["B`@("`@
M("`@)')E<R`@(#T@87)R87DH*3L*"B`@("`@("`@:68@*"1M;V1E*2!["B`@
M("`@("`@("`@("1R97-;)VYU;5]F:65L9',G72`]("1C;W5N=#L*("`@("`@
M("!]"@H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C;W5N=#L@)&DK*RD@
M>PH@("`@("`@("`@("`D=&UP(#T@0&US<6Q?9F5T8VA?9FEE;&0H)&ED*3L*
M"B`@("`@("`@("`@("1F;&%G<R`]("<G.PH@("`@("`@("`@("!I9B`H)'1M
M<"T^;F]T7VYU;&PI('L*("`@("`@("`@("`@("`@("1F;&%G<R`N/2`G;F]T
M7VYU;&P@)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)'1M<"T^
M=6YI<75E*2!["B`@("`@("`@("`@("`@("`D9FQA9W,@+CT@)W5N:7%U95]K
M97D@)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D9FQA9W,@/2!T<FEM
M*"1F;&%G<RD["@H@("`@("`@("`@("`D<F5S6R1I72`](&%R<F%Y*`H@("`@
M("`@("`@("`@("`@)W1A8FQE)R`]/B`D8V%S95]F=6YC*"1T;7`M/G1A8FQE
M*2P*("`@("`@("`@("`@("`@("=N86UE)R`@/3X@)&-A<V5?9G5N8R@D=&UP
M+3YN86UE*2P*("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)'1M<"T^='EP
M92P*("`@("`@("`@("`@("`@("=L96XG("`@/3X@;7-Q;%]F:65L9%]L96XH
M)&ED+"`D:2DL"B`@("`@("`@("`@("`@("`G9FQA9W,G(#T^("1F;&%G<RP*
M("`@("`@("`@("`@*3L*"B`@("`@("`@("`@(&EF("@D;6]D92`F($1"7U1!
M0DQ%24Y&3U]/4D1%4BD@>PH@("`@("`@("`@("`@("`@)')E<ULG;W)D97(G
M75LD<F5S6R1I75LG;F%M92==72`]("1I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("@D;6]D92`F($1"7U1!0DQ%24Y&3U]/4D1%4E1!0DQ%*2![
M"B`@("`@("`@("`@("`@("`D<F5S6R=O<F1E<G1A8FQE)UU;)')E<ULD:5U;
M)W1A8FQE)UU=6R1R97-;)&E=6R=N86UE)UU=(#T@)&D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("\O(&9R964@=&AE(')E<W5L="!O;FQY
M(&EF('=E('=E<F4@8V%L;&5D(&]N(&$@=&%B;&4*("`@("`@("!I9B`H)&=O
M=%]S=')I;F<I('L*("`@("`@("`@("`@0&US<6Q?9G)E95]R97-U;'0H)&ED
M*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97,["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@9V5T4W!E8VEA;%%U97)Y*"D*"B`@("`O*BH*
M("`@("`J($]B=&%I;B!A(&QI<W0@;V8@82!G:79E;B!T>7!E(&]F(&]B:F5C
M=',*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("!T:&4@:VEN
M9"!O9B!O8FIE8W1S('EO=2!W86YT('1O(')E=')I979E"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@=&AE(&%R<F%Y(&-O;G1A:6YI;F<@=&AE(&QI
M<W0@;V8@;V)J96-T<R!R97%U97-T960*("`@("`J"B`@("`@*B!`86-C97-S
M('!R;W1E8W1E9`H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F=E=$QI<W1/9B@I
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-P96-I86Q1=65R>2@D='EP92D*
M("`@('L*("`@("`@("!S=VET8V@@*"1T>7!E*2!["B`@("`@("`@("`@(&-A
M<V4@)V1A=&%B87-E<R<Z"B`@("`@("`@("`@("`@("`D:60@/2!`;7-Q;%]L
M:7-T7V1B<R@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@8V%S92`G=&%B;&5S)SH*("`@("`@("`@("`@
M("`@("1I9"`]($!M<W%L7VQI<W1?=&%B;&5S*"1T:&ES+3YD<VY;)V1A=&%B
M87-E)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@(')E='5R;B!N
M=6QL.PH@("`@("`@('T*("`@("`@("!I9B`H(21I9"D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/FUS<6Q286ES945R<F]R*"D["B`@("`@("`@?0H@
M("`@("`@("1O=70@/2!A<G)A>2@I.PH@("`@("`@('=H:6QE("@D<F]W(#T@
M0&US<6Q?9F5T8VA?<F]W*"1I9"DI('L*("`@("`@("`@("`@)&]U=%M=(#T@
M)')O=ULP73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1O=70["B`@("!]
M"@H@("`@+R\@?7U]"@I]"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A
M8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!%;F0Z"B`J+PH*
M/SX*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+T1"+VUS<W%L+G!H<```````````````````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#8U-C0V`#$P-3$U-#,S-S,V`#`R,#<V-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`H*+RH@
M=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F
M='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!4:&4@4$5!4B!$0B!D<FEV97(@9F]R
M(%!(4"=S(&US<W%L(&5X=&5N<VEO;@H@*B!F;W(@:6YT97)A8W1I;F<@=VET
M:"!-:6-R;W-O9G0@4U%,(%-E<G9E<B!D871A8F%S97,*("H*("H@4$A0('9E
M<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL
M92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS
M90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@
M82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T
M;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A
M(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E
M"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@(%-T97)L:6YG($AU
M9VAE<R`\<W1E<FQI;F=`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@1&%N:65L
M($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q
M.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*
M("H@0'9E<G-I;VX@("`@0U93.B`D260Z(&US<W%L+G!H<"QV(#$N.#,@,C`P
M-2\P,R\P-R`Q.#HR-#HU,2!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*"B\J*@H@*B!/
M8G1A:6X@=&AE($1"7V-O;6UO;B!C;&%S<R!S;R!I="!C86X@8F4@97AT96YD
M960@9G)O;0H@*B\*<F5Q=6ER95]O;F-E("=$0B]C;VUM;VXN<&AP)SL*"B\J
M*@H@*B!4:&4@;65T:&]D<R!014%2($1"('5S97,@=&\@:6YT97)A8W0@=VET
M:"!02%`G<R!M<W-Q;"!E>'1E;G-I;VX*("H@9F]R(&EN=&5R86-T:6YG('=I
M=&@@36EC<F]S;V9T(%-13"!397)V97(@9&%T86)A<V5S"B`J"B`J(%1H97-E
M(&UE=&AO9',@;W9E<FQO860@=&AE(&]N97,@9&5C;&%R960@:6X@1$)?8V]M
M;6]N+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@
M("!$0@H@*B!`875T:&]R("`@("!3=&5R;&EN9R!(=6=H97,@/'-T97)L:6YG
M0'!H<"YN970^"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A
M;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!0
M2%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@
M(%)E;&5A<V4Z(#$N-RXV"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H
M<"YN970O<&%C:V%G92]$0@H@*B\*8VQA<W,@1$)?;7-S<6P@97AT96YD<R!$
M0E]C;VUM;VX*>PH@("`@+R\@>WM[('!R;W!E<G1I97,*"B`@("`O*BH*("`@
M("`J(%1H92!$0B!D<FEV97(@='EP92`H;7ES<6PL(&]C:3@L(&]D8F,L(&5T
M8RXI"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)'!H<'1Y
M<&4@/2`G;7-S<6PG.PH*("`@("\J*@H@("`@("H@5&AE(&1A=&%B87-E('-Y
M;G1A>"!V87)I86YT('1O(&)E('5S960@*&1B,BP@86-C97-S+"!E=&,N*2P@
M:68@86YY"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&1B
M<WEN=&%X(#T@)VUS<W%L)SL*"B`@("`O*BH*("`@("`J(%1H92!C87!A8FEL
M:71I97,@;V8@=&AI<R!$0B!I;7!L96UE;G1A=&EO;@H@("`@("H*("`@("`J
M(%1H92`G;F5W7VQI;FLG(&5L96UE;G0@8V]N=&%I;G,@=&AE(%!(4"!V97)S
M:6]N('1H870@9FER<W0@<')O=FED960*("`@("`J(&YE=U]L:6YK('-U<'!O
M<G0@9F]R('1H:7,@1$)-4RX@($-O;G1A:6YS(&9A;'-E(&EF(&ET)W,@=6YS
M=7!P;W)T960N"B`@("`@*@H@("`@("H@365A;FEN9R!O9B!T:&4@)VQI;6ET
M)R!E;&5M96YT.@H@("`@("H@("`K("=E;75L871E)R`](&5M=6QA=&4@=VET
M:"!F971C:"!R;W<@8GD@;G5M8F5R"B`@("`@*B`@("L@)V%L=&5R)R`@(#T@
M86QT97(@=&AE('%U97)Y"B`@("`@*B`@("L@9F%L<V4@("`@(#T@<VMI<"!R
M;W=S"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)&9E871U<F5S(#T@87)R87DH"B`@("`@("`@)VQI;6ET)R`@("`@("`@(#T^
M("=E;75L871E)RP*("`@("`@("`G;F5W7VQI;FLG("`@("`@/3X@9F%L<V4L
M"B`@("`@("`@)VYU;7)O=W,G("`@("`@(#T^('1R=64L"B`@("`@("`@)W!C
M;VYN96-T)R`@("`@(#T^('1R=64L"B`@("`@("`@)W!R97!A<F4G("`@("`@
M(#T^(&9A;'-E+`H@("`@("`@("=S<VPG("`@("`@("`@("`]/B!F86QS92P*
M("`@("`@("`G=')A;G-A8W1I;VYS)R`@/3X@=')U92P*("`@("D["@H@("`@
M+RHJ"B`@("`@*B!!(&UA<'!I;F<@;V8@;F%T:79E(&5R<F]R(&-O9&5S('1O
M($1"(&5R<F]R(&-O9&5S"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M("\O(%A86"!!9&0@:&5R92!E<G)O<B!C;V1E<R!I93H@)U,Q,#!%)R`]/B!$
M0E]%4E)/4E]364Y405@*("`@('9A<B`D97)R;W)C;V1E7VUA<"`](&%R<F%Y
M*`H@("`@("`@(#$Q,"`@(#T^($1"7T524D]27U9!3%5%7T-/54Y47T].7U)/
M5RP*("`@("`@("`Q-34@("`]/B!$0E]%4E)/4E].3U-50TA&245,1"P*("`@
M("`@("`Q-S`@("`]/B!$0E]%4E)/4E]364Y405@L"B`@("`@("`@,C`W("`@
M/3X@1$)?15)23U)?3D]354-(1DE%3$0L"B`@("`@("`@,C`X("`@/3X@1$)?
M15)23U)?3D]354-(5$%"3$4L"B`@("`@("`@,C0U("`@/3X@1$)?15)23U)?
M24Y604Q)1%].54U"15(L"B`@("`@("`@-3$U("`@/3X@1$)?15)23U)?0T].
M4U1204E.5%].3U1?3E5,3"P*("`@("`@("`U-#<@("`]/B!$0E]%4E)/4E]#
M3TY35%)!24Y4+`H@("`@("`@(#$Y,3,@(#T^($1"7T524D]27T%,4D5!1%E?
M15A)4U13+`H@("`@("`@(#(V,C<@(#T^($1"7T524D]27T-/3E-44D%)3E0L
M"B`@("`@("`@,C<Q-"`@/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@
M("`@("`@,S<P,2`@/3X@1$)?15)23U)?3D]354-(5$%"3$4L"B`@("`@("`@
M.#$S-"`@/3X@1$)?15)23U)?1$E66D523RP*("`@("D["@H@("`@+RHJ"B`@
M("`@*B!4:&4@<F%W(&1A=&%B87-E(&-O;FYE8W1I;VX@8W)E871E9"!B>2!0
M2%`*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1C;VYN
M96-T:6]N.PH*("`@("\J*@H@("`@("H@5&AE($133B!I;F9O<FUA=&EO;B!F
M;W(@8V]N;F5C=&EN9R!T;R!A(&1A=&%B87-E"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D9'-N(#T@87)R87DH*3L*"@H@("`@+RHJ"B`@
M("`@*B!3:&]U;&0@9&%T82!M86YI<'5L871I;VX@<75E<FEE<R!B92!C;VUM
M:71T960@875T;VUA=&EC86QL>3\*("`@("`J($!V87(@8F]O;`H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D875T;V-O;6UI="`]
M('1R=64["@H@("`@+RHJ"B`@("`@*B!4:&4@<75A;G1I='D@;V8@=')A;G-A
M8W1I;VYS(&)E9W5N"B`@("`@*@H@("`@("H@>T!I;G1E<FYA;"`@5VAI;&4@
M=&AI<R!I<R!P<FEV871E+"!I="!C86XG="!A8W1U86QL>2!B92!D97-I9VYA
M=&5D"B`@("`@*B!P<FEV871E(&EN(%!(4"`U(&)E8V%U<V4@:70@:7,@9&ER
M96-T;'D@86-C97-S960@:6X@=&AE('1E<W0@<W5I=&4N?7T*("`@("`J"B`@
M("`@*B!`=F%R(&EN=&5G97(*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("HO"B`@("!V87(@)'1R86YS86-T:6]N7V]P8V]U;G0@/2`P.PH*("`@("\J
M*@H@("`@("H@5&AE(&1A=&%B87-E('-P96-I9FEE9"!I;B!T:&4@1%-."B`@
M("`@*@H@("`@("H@270G<R!A(&9I>"!T;R!A;&QO=R!C86QL<R!T;R!D:69F
M97)E;G0@9&%T86)A<V5S(&EN('1H92!S86UE('-C<FEP="X*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*B\*("`@('9A<B`D7V1B(#T@;G5L;#L*"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@8V]N<W1R=6-T;W(*"B`@("`O*BH*("`@("`J(%1H:7,@8V]N<W1R=6-T
M;W(@8V%L;',@/&MB9#XD=&AI<RT^1$)?8V]M;6]N*"D\+VMB9#X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@1$)?
M;7-S<6PH*0H@("`@>PH@("`@("`@("1T:&ES+3Y$0E]C;VUM;VXH*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYN96-T*"D*"B`@("`O*BH*
M("`@("`J($-O;FYE8W0@=&\@=&AE(&1A=&%B87-E('-E<G9E<BP@;&]G(&EN
M(&%N9"!O<&5N('1H92!D871A8F%S90H@("`@("H*("`@("`J($1O;B=T(&-A
M;&P@=&AI<R!M971H;V0@9&ER96-T;'DN("!5<V4@1$(Z.F-O;FYE8W0H*2!I
M;G-T96%D+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D9'-N("`@("`@
M("`@=&AE(&1A=&$@<V]U<F-E(&YA;64*("`@("`J($!P87)A;2!B;V]L("`D
M<&5R<VES=&5N="`@<VAO=6QD('1H92!C;VYN96-T:6]N(&)E('!E<G-I<W1E
M;G0_"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E
M<W,N($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-O;FYE8W0H)&1S;BP@)'!E<G-I<W1E;G0@/2!F86QS92D*
M("`@('L*("`@("`@("!I9B`H(5!%05(Z.FQO861%>'1E;G-I;VXH)VUS<W%L
M)RD@)B8@(5!%05(Z.FQO861%>'1E;G-I;VXH)W-Y8F%S92<I"B`@("`@("`@
M("`@("8F("%014%2.CIL;V%D17AT96YS:6]N*"=S>6)A<V5?8W0G*2D*("`@
M("`@("!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$
M0E]%4E)/4E]%6%1%3E-)3TY?3D]47T9/54Y$*3L*("`@("`@("!]"@H@("`@
M("`@("1T:&ES+3YD<VX@/2`D9'-N.PH@("`@("`@(&EF("@D9'-N6R=D8G-Y
M;G1A>"==*2!["B`@("`@("`@("`@("1T:&ES+3YD8G-Y;G1A>"`]("1D<VY;
M)V1B<WEN=&%X)UT["B`@("`@("`@?0H*("`@("`@("`D<&%R86US(#T@87)R
M87DH"B`@("`@("`@("`@("1D<VY;)VAO<W1S<&5C)UT@/R`D9'-N6R=H;W-T
M<W!E8R==(#H@)VQO8V%L:&]S="<L"B`@("`@("`@("`@("1D<VY;)W5S97)N
M86UE)UT@/R`D9'-N6R=U<V5R;F%M92==(#H@;G5L;"P*("`@("`@("`@("`@
M)&1S;ELG<&%S<W=O<F0G72`_("1D<VY;)W!A<W-W;W)D)UT@.B!N=6QL+`H@
M("`@("`@("D["B`@("`@("`@:68@*"1D<VY;)W!O<G0G72D@>PH@("`@("`@
M("`@("`D<&%R86US6S!=("X]("@H<W5B<W1R*%!(4%]/4RP@,"P@,RD@/3T@
M)U=)3B<I(#\@)RPG(#H@)SHG*0H@("`@("`@("`@("`@("`@("`@("`@("`N
M("1D<VY;)W!O<G0G73L*("`@("`@("!]"@H@("`@("`@("1C;VYN96-T7V9U
M;F-T:6]N(#T@)'!E<G-I<W1E;G0@/R`G;7-S<6Q?<&-O;FYE8W0G(#H@)VUS
M<W%L7V-O;FYE8W0G.PH*("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`]($!C
M86QL7W5S97)?9G5N8U]A<G)A>2@D8V]N;F5C=%]F=6YC=&EO;BP@)'!A<F%M
M<RD["@H@("`@("`@(&EF("@A)'1H:7,M/F-O;FYE8W1I;VXI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27T-/3DY%
M0U1?1D%)3$5$+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($!M<W-Q;%]G971?;&%S=%]M97-S86=E*"DI.PH@("`@
M("`@('T*("`@("`@("!I9B`H)&1S;ELG9&%T86)A<V4G72D@>PH@("`@("`@
M("`@("!I9B`H(4!M<W-Q;%]S96QE8W1?9&(H)&1S;ELG9&%T86)A<V4G72P@
M)'1H:7,M/F-O;FYE8W1I;VXI*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?3D]$0E-%3$5#5$5$+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL(&YU
M;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@0&US<W%L7V=E=%]L87-T7VUE<W-A9V4H*2D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)'1H:7,M/E]D8B`]("1D<VY;)V1A=&%B87-E)UT[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!D:7-C;VYN96-T*"D*"B`@("`O*BH*("`@("`J
M($1I<V-O;FYE8W1S(&9R;VT@=&AE(&1A=&%B87-E('-E<G9E<@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;"`@5%)512!O;B!S=6-C97-S+"!&04Q312!O
M;B!F86EL=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N(&1I<V-O;FYE8W0H*0H@
M("`@>PH@("`@("`@("1R970@/2!`;7-S<6Q?8VQO<V4H)'1H:7,M/F-O;FYE
M8W1I;VXI.PH@("`@("`@("1T:&ES+3YC;VYN96-T:6]N(#T@;G5L;#L*("`@
M("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!S:6UP;&51=65R>2@I"@H@("`@+RHJ"B`@("`@*B!396YD<R!A('%U97)Y
M('1O('1H92!D871A8F%S92!S97)V97(*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("!T:&4@4U%,('%U97)Y('-T<FEN9PH@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@("L@82!02%`@<F5S=6QT(')E<W)O=6-E(&9O<B!S=6-C
M97-S9G5L(%-%3$5#5"!Q=65R:65S"B`@("`@*B`@("`@("`@("`@("`@("`K
M('1H92!$0E]/2R!C;VYS=&%N="!F;W(@;W1H97(@<W5C8V5S<V9U;"!Q=65R
M:65S"B`@("`@*B`@("`@("`@("`@("`@("`K(&$@1$)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4*("`@("`J+PH@("`@9G5N8W1I;VX@<VEM<&QE475E<GDH
M)'%U97)Y*0H@("`@>PH@("`@("`@("1I<VUA;FEP(#T@1$(Z.FES36%N:7`H
M)'%U97)Y*3L*("`@("`@("`D=&AI<RT^;&%S=%]Q=65R>2`]("1Q=65R>3L*
M("`@("`@("!I9B`H(4!M<W-Q;%]S96QE8W1?9&(H)'1H:7,M/E]D8BP@)'1H
M:7,M/F-O;FYE8W1I;VXI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M;7-S<6Q286ES945R<F]R*$1"7T524D]27TY/1$)314Q%0U1%1"D["B`@("`@
M("`@?0H@("`@("`@("1Q=65R>2`]("1T:&ES+3YM;V1I9GE1=65R>2@D<75E
M<GDI.PH@("`@("`@(&EF("@A)'1H:7,M/F%U=&]C;VUM:70@)B8@)&ES;6%N
M:7`I('L*("`@("`@("`@("`@:68@*"1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O
M=6YT(#T](#`I('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2!`;7-S<6Q?
M<75E<GDH)T)%1TE.(%1204XG+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@
M("`@("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/FUS<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3YT<F%N
M<V%C=&EO;E]O<&-O=6YT*RL["B`@("`@("`@?0H@("`@("`@("1R97-U;'0@
M/2!`;7-S<6Q?<75E<GDH)'%U97)Y+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@
M("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^;7-S<6Q286ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@("\O($1E
M=&5R;6EN92!W:&EC:"!Q=65R:65S('1H870@<VAO=6QD(')E='5R;B!D871A
M+"!A;F0@=VAI8V@*("`@("`@("`O+R!S:&]U;&0@<F5T=7)N(&%N(&5R<F]R
M(&-O9&4@;VYL>2X*("`@("`@("!R971U<FX@)&ES;6%N:7`@/R!$0E]/2R`Z
M("1R97-U;'0["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;F5X=%)E
M<W5L="@I"@H@("`@+RHJ"B`@("`@*B!-;W9E('1H92!I;G1E<FYA;"!M<W-Q
M;"!R97-U;'0@<&]I;G1E<B!T;R!T:&4@;F5X="!A=F%I;&%B;&4@<F5S=6QT
M"B`@("`@*@H@("`@("H@0'!A<F%M(&$@=F%L:60@9F)S<6P@<F5S=6QT(')E
M<V]U<F-E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@
M("`@*B!`<F5T=7)N('1R=64@:68@82!R97-U;'0@:7,@879A:6QA8FQE(&]T
M:&5R=VES92!R971U<FX@9F%L<V4*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X
M=%)E<W5L="@D<F5S=6QT*0H@("`@>PH@("`@("`@(')E='5R;B!`;7-S<6Q?
M;F5X=%]R97-U;'0H)')E<W5L="D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@9F5T8VA);G1O*"D*"B`@("`O*BH*("`@("`J(%!L86-E<R!A(')O
M=R!F<F]M('1H92!R97-U;'0@<V5T(&EN=&\@=&AE(&=I=F5N(&%R<F%Y"B`@
M("`@*@H@("`@("H@1F]R;6%T:6YG(&]F('1H92!A<G)A>2!A;F0@=&AE(&1A
M=&$@=&AE<F5I;B!A<F4@8V]N9FEG=7)A8FQE+@H@("`@("H@4V5E($1"7W)E
M<W5L=#HZ9F5T8VA);G1O*"D@9F]R(&UO<F4@:6YF;W)M871I;VXN"B`@("`@
M*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE
M9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIF971C:$EN=&\H
M*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*
M("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T
M+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("`@('1H
M92!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J($!P87)A;2!A<G)A>2`@
M("`D87)R("`@("`@('1H92!R969E<F5N8V5D(&%R<F%Y('1O('!U="!T:&4@
M9&%T82!I;@H@("`@("H@0'!A<F%M(&EN="`@("`@("1F971C:&UO9&4@:&]W
M('1H92!R97-U;'1I;F<@87)R87D@<VAO=6QD(&)E(&EN9&5X960*("`@("`J
M($!P87)A;2!I;G0@("`@("`D<F]W;G5M("`@('1H92!R;W<@;G5M8F5R('1O
M(&9E=&-H("@P(#T@9FER<W0@<F]W*0H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@($1"7T]+(&]N('-U8V-E<W,L($Y53$P@=VAE;B!T:&4@96YD(&]F
M(&$@<F5S=6QT('-E="!I<PH@("`@("H@("`@("`@("`@("`@("`@(')E86-H
M960@;W(@;VX@9F%I;'5R90H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT
M.CIF971C:$EN=&\H*0H@("`@("HO"B`@("!F=6YC=&EO;B!F971C:$EN=&\H
M)')E<W5L="P@)B1A<G(L("1F971C:&UO9&4L("1R;W=N=6T@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&EF("@D<F]W;G5M("$]/2!N=6QL*2!["B`@("`@("`@
M("`@(&EF("@A0&US<W%L7V1A=&%?<V5E:R@D<F5S=6QT+"`D<F]W;G5M*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@:68@*"1F971C:&UO9&4@)B!$0E]&151#2$U/
M1$5?05-33T,I('L*("`@("`@("`@("`@)&%R<B`]($!M<W-Q;%]F971C:%]A
M<G)A>2@D<F5S=6QT+"!-4U-13%]!4U-/0RD["B`@("`@("`@("`@(&EF("@D
M=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,2519
M7TQ/5T520T%312`F)B`D87)R*2!["B`@("`@("`@("`@("`@("`D87)R(#T@
M87)R87E?8VAA;F=E7VME>5]C87-E*"1A<G(L($-!4T5?3$]715(I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&%R<B`]
M($!M<W-Q;%]F971C:%]R;W<H)')E<W5L="D["B`@("`@("`@?0H@("`@("`@
M(&EF("@A)&%R<BD@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@
M("!]"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==
M("8@1$)?4$]25$%"24Q)5%E?4E1224TI('L*("`@("`@("`@("`@)'1H:7,M
M/E]R=')I;4%R<F%Y5F%L=65S*"1A<G(I.PH@("`@("`@('T*("`@("`@("!I
M9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))
M3$E465].54Q,7U1/7T5-4%19*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V]N
M=F5R=$YU;&Q!<G)A>59A;'5E<U1O16UP='DH)&%R<BD["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!F<F5E4F5S=6QT*"D*"B`@("`O*BH*("`@("`J($1E;&5T97,@=&AE
M(')E<W5L="!S970@86YD(&9R965S('1H92!M96UO<GD@;V-C=7!I960@8GD@
M=&AE(')E<W5L="!S970*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N
M;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$
M0E]R97-U;'0Z.F9R964H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R
M960@(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@
M<V5P87)A=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C
M92`D<F5S=6QT("!02%`G<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VP@(%12544@;VX@<W5C8V5S<RP@1D%,4T4@
M:68@)')E<W5L="!I<R!I;G9A;&ED"B`@("`@*@H@("`@("H@0'-E92!$0E]R
M97-U;'0Z.F9R964H*0H@("`@("HO"B`@("!F=6YC=&EO;B!F<F5E4F5S=6QT
M*"1R97-U;'0I"B`@("!["B`@("`@("`@<F5T=7)N($!M<W-Q;%]F<F5E7W)E
M<W5L="@D<F5S=6QT*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N
M=6U#;VQS*"D*"B`@("`O*BH*("`@("`J($=E=',@=&AE(&YU;6)E<B!O9B!C
M;VQU;6YS(&EN(&$@<F5S=6QT('-E=`H@("`@("H*("`@("`J(%1H:7,@;65T
M:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*
M("`@("`J($1"7W)E<W5L=#HZ;G5M0V]L<R@I(&EN<W1E860N("!)="!C86XG
M="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R
M97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A
M<F%M(')E<V]U<F-E("1R97-U;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O
M=7)C90H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F
M(&-O;'5M;G,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("H*("`@("`J($!S964@1$)?<F5S=6QT.CIN=6U#;VQS*"D*("`@("`J+PH@
M("`@9G5N8W1I;VX@;G5M0V]L<R@D<F5S=6QT*0H@("`@>PH@("`@("`@("1C
M;VQS(#T@0&US<W%L7VYU;5]F:65L9',H)')E<W5L="D["B`@("`@("`@:68@
M*"$D8V]L<RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUS<W%L4F%I
M<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&-O;',["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;G5M4F]W<R@I"@H@("`@+RHJ
M"B`@("`@*B!'971S('1H92!N=6UB97(@;V8@<F]W<R!I;B!A(')E<W5L="!S
M970*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@
M8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.FYU
M;5)O=W,H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E
M8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@
M;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT
M("!02%`G<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!R;W=S+B`@02!$0E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L
M=#HZ;G5M4F]W<R@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU;5)O=W,H)')E
M<W5L="D*("`@('L*("`@("`@("`D<F]W<R`]($!M<W-Q;%]N=6U?<F]W<R@D
M<F5S=6QT*3L*("`@("`@("!I9B`H)')O=W,@/3T](&9A;'-E*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^;7-S<6Q286ES945R<F]R*"D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D<F]W<SL*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!A=71O0V]M;6ET*"D*"B`@("`O*BH*("`@("`J($5N86)L
M97,@;W(@9&ES86)L97,@875T;VUA=&EC(&-O;6UI=',*("`@("`J"B`@("`@
M*B!`<&%R86T@8F]O;"`D;VYO9F8@('1R=64@='5R;G,@:70@;VXL(&9A;'-E
M('1U<FYS(&ET(&]F9@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/
M2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@:68@=&AE(&1R:79E
M<@H@("`@("H@("`@("`@("`@("`@("!D;V5S;B=T('-U<'!O<G0@875T;RUC
M;VUM:71T:6YG('1R86YS86-T:6]N<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M875T;T-O;6UI="@D;VYO9F8@/2!F86QS92D*("`@('L*("`@("`@("`O+R!8
M6%@@:68@)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/B`P+"!W92!S:&]U
M;&0@<')O8F%B;'D*("`@("`@("`O+R!I<W-U92!A('=A<FYI;F<@:&5R92X*
M("`@("`@("`D=&AI<RT^875T;V-O;6UI="`]("1O;F]F9B`_('1R=64@.B!F
M86QS93L*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@8V]M;6ET*"D*"B`@("`O*BH*("`@("`J($-O;6UI=',@
M=&AE(&-U<G)E;G0@=')A;G-A8W1I;VX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;6UI="@I"B`@("![
M"B`@("`@("`@:68@*"1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#X@,"D@
M>PH@("`@("`@("`@("!I9B`H(4!M<W-Q;%]S96QE8W1?9&(H)'1H:7,M/E]D
M8BP@)'1H:7,M/F-O;FYE8W1I;VXI*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/FUS<W%L4F%I<V5%<G)O<BA$0E]%4E)/4E].3T1"4T5,14-4
M140I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1R97-U;'0@/2!`;7-S
M<6Q?<75E<GDH)T-/34U)5"!44D%.)RP@)'1H:7,M/F-O;FYE8W1I;VXI.PH@
M("`@("`@("`@("`D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`](#`["B`@
M("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YM<W-Q;%)A:7-E17)R;W(H*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@<F]L;&)A8VLH*0H*("`@("\J*@H@("`@("H@4F5V
M97)T<R!T:&4@8W5R<F5N="!T<F%N<V%C=&EO;@H@("`@("H*("`@("`J($!R
M971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F]L;&)A8VLH
M*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N
M="`^(#`I('L*("`@("`@("`@("`@:68@*"%`;7-S<6Q?<V5L96-T7V1B*"1T
M:&ES+3Y?9&(L("1T:&ES+3YC;VYN96-T:6]N*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YM<W-Q;%)A:7-E17)R;W(H1$)?15)23U)?3D]$
M0E-%3$5#5$5$*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<F5S=6QT
M(#T@0&US<W%L7W%U97)Y*"=23TQ,0D%#2R!44D%.)RP@)'1H:7,M/F-O;FYE
M8W1I;VXI.PH@("`@("`@("`@("`D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N
M="`](#`["B`@("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YM<W-Q;%)A:7-E17)R;W(H*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@869F96-T9612;W=S*"D*"B`@("`O
M*BH*("`@("`J($1E=&5R;6EN97,@=&AE(&YU;6)E<B!O9B!R;W=S(&%F9F5C
M=&5D(&)Y(&$@9&%T82!M86YI=7!L871I;VX@<75E<GD*("`@("`J"B`@("`@
M*B`P(&ES(')E='5R;F5D(&9O<B!Q=65R:65S('1H870@9&]N)W0@;6%N:7!U
M;&%T92!D871A+@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M
M8F5R(&]F(')O=W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!A9F9E8W1E9%)O=W,H*0H@("`@>PH@("`@
M("`@(&EF("A$0CHZ:7--86YI<"@D=&AI<RT^;&%S=%]Q=65R>2DI('L*("`@
M("`@("`@("`@)')E<R`]($!M<W-Q;%]Q=65R>2@G<V5L96-T($!`<F]W8V]U
M;G0G+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@(&EF("@A)')E
M<RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM<W-Q;%)A:7-E
M17)R;W(H*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D87(@/2!`;7-S
M<6Q?9F5T8VA?<F]W*"1R97,I.PH@("`@("`@("`@("!I9B`H(21A<BD@>PH@
M("`@("`@("`@("`@("`@)')E<W5L="`](#`["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!`;7-S<6Q?9G)E95]R97-U;'0H)')E<RD[
M"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)&%R6S!=.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')E<W5L="`](#`[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&YE>'1)9"@I"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!N97AT(&9R964@:60@:6X@82!S97%U96YC90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@("1S97%?;F%M92`@;F%M92!O9B!T:&4@
M<V5Q=65N8V4*("`@("`J($!P87)A;2!B;V]L96%N("1O;F1E;6%N9"`@=VAE
M;B!T<G5E+"!T:&4@<V5Q96YC92!I<R!A=71O;6%T:6-A;&QY"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!C<F5A=&5D(&EF(&ET(&1O97,@
M;F]T(&5X:7-T"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N97AT
M(&ED(&YU;6)E<B!I;B!T:&4@<V5Q=65N8V4N"B`@("`@*B`@("`@("`@("`@
M("`@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@
M("H@0'-E92!$0E]C;VUM;VXZ.FYE>'1)1"@I+"!$0E]C;VUM;VXZ.F=E=%-E
M<75E;F-E3F%M92@I+`H@("`@("H@("`@("!$0E]M<W-Q;#HZ8W)E871E4V5Q
M=65N8V4H*2P@1$)?;7-S<6PZ.F1R;W!397%U96YC92@I"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&YE>'1)9"@D<V5Q7VYA;64L("1O;F1E;6%N9"`]('1R=64I
M"B`@("!["B`@("`@("`@)'-E<6YA;64@/2`D=&AI<RT^9V5T4V5Q=65N8V5.
M86UE*"1S97%?;F%M92D["B`@("`@("`@:68@*"%`;7-S<6Q?<V5L96-T7V1B
M*"1T:&ES+3Y?9&(L("1T:&ES+3YC;VYN96-T:6]N*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/FUS<W%L4F%I<V5%<G)O<BA$0E]%4E)/4E].3T1"
M4T5,14-4140I.PH@("`@("`@('T*("`@("`@("`D<F5P96%T(#T@,#L*("`@
M("`@("!D;R!["B`@("`@("`@("`@("1T:&ES+3YP=7-H17)R;W)(86YD;&EN
M9RA014%27T524D]27U)%5%523BD["B`@("`@("`@("`@("1R97-U;'0@/2`D
M=&AI<RT^<75E<GDH(DE.4T525"!)3E1/("1S97%N86UE("AV87!O<BD@5D%,
M5453("@P*2(I.PH@("`@("`@("`@("`D=&AI<RT^<&]P17)R;W)(86YD;&EN
M9R@I.PH@("`@("`@("`@("!I9B`H)&]N9&5M86YD("8F($1".CII<T5R<F]R
M*"1R97-U;'0I("8F"B`@("`@("`@("`@("`@("`H)')E<W5L="T^9V5T0V]D
M92@I(#T]($1"7T524D]2('Q\("1R97-U;'0M/F=E=$-O9&4H*2`]/2!$0E]%
M4E)/4E].3U-50TA404),12DI"B`@("`@("`@("`@('L*("`@("`@("`@("`@
M("`@("1R97!E870@/2`Q.PH@("`@("`@("`@("`@("`@)')E<W5L="`]("1T
M:&ES+3YC<F5A=&5397%U96YC92@D<V5Q7VYA;64I.PH@("`@("`@("`@("`@
M("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V5I9B`H(41".CII<T5R
M<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#TF("1T
M:&ES+3YQ=65R>2@B4T5,14-4($!`241%3E1)5%D@1E)/32`D<V5Q;F%M92(I
M.PH@("`@("`@("`@("`@("`@)')E<&5A="`](#`["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D<F5P96%T(#T@9F%L<V4["B`@("`@
M("`@("`@('T*("`@("`@("!]('=H:6QE("@D<F5P96%T*3L*("`@("`@("!I
M9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I.PH@("`@("`@('T*("`@("`@
M("`D<F5S=6QT(#T@)')E<W5L="T^9F5T8VA2;W<H1$)?1D540TA-3T1%7T]2
M1$52140I.PH@("`@("`@(')E='5R;B`D<F5S=6QT6S!=.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0W)E871E<R!A(&YE=R!S97%U96YC90H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'-E<5]N86UE("!N86UE(&]F('1H92!N97<@
M<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@
M<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F-R96%T95-E<75E;F-E*"DL($1"
M7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@*B`@("`@($1"7VUS
M<W%L.CIN97AT240H*2P@1$)?;7-S<6PZ.F1R;W!397%U96YC92@I"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-R96%T95-E<75E;F-E*"1S97%?;F%M92D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/G%U97)Y*"=#4D5!5$4@5$%"3$4@
M)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^9V5T4V5Q
M=65N8V5.86UE*"1S97%?;F%M92D*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("X@)R`H6VED72!;:6YT72!)1$5.5$E462`H,2P@,2D@3D]4($Y53$PL
M)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G(%MV87!O<ET@6VEN
M=%T@3E5,3"DG*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!D<F]P
M4V5Q=65N8V4H*0H*("`@("\J*@H@("`@("H@1&5L971E<R!A('-E<75E;F-E
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5Q7VYA;64@(&YA;64@
M;V8@=&AE('-E<75E;F-E('1O(&)E(&1E;&5T960*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J
M96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ
M.F1R;W!397%U96YC92@I+"!$0E]C;VUM;VXZ.F=E=%-E<75E;F-E3F%M92@I
M+`H@("`@("H@("`@("!$0E]M<W-Q;#HZ;F5X=$E$*"DL($1"7VUS<W%L.CIC
M<F5A=&5397%U96YC92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&1R;W!397%U
M96YC92@D<V5Q7VYA;64I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YQ
M=65R>2@G1%)/4"!404),12`G("X@)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D
M<V5Q7VYA;64I*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!Q=6]T
M94ED96YT:69I97(H*0H*("`@("\J*@H@("`@("H@475O=&5S(&$@<W1R:6YG
M('-O(&ET(&-A;B!B92!S869E;'D@=7-E9"!A<R!A('1A8FQE(&]R(&-O;'5M
M;B!N86UE"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1R("!I9&5N
M=&EF:65R(&YA;64@=&\@8F4@<75O=&5D"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@('%U;W1E9"!I9&5N=&EF:65R('-T<FEN9PH@("`@("H*("`@
M("`J($!S964@1$)?8V]M;6]N.CIQ=6]T94ED96YT:69I97(H*0H@("`@("H@
M0'-I;F-E($UE=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C8N,`H@
M("`@("HO"B`@("!F=6YC=&EO;B!Q=6]T94ED96YT:69I97(H)'-T<BD*("`@
M('L*("`@("`@("!R971U<FX@)ULG("X@<W1R7W)E<&QA8V4H)UTG+"`G75TG
M+"`D<W1R*2`N("==)SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!M
M<W-Q;%)A:7-E17)R;W(H*0H*("`@("\J*@H@("`@("H@4')O9'5C97,@82!$
M0E]%<G)O<B!O8FIE8W0@<F5G87)D:6YG('1H92!C=7)R96YT('!R;V)L96T*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT("1E<G)N;R`@:68@=&AE(&5R<F]R
M(&ES(&)E:6YG(&UA;G5A;&QY(')A:7-E9"!P87-S(&$*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@1$)?15)23U(J(&-O;G-T86YT(&AE<F4N("!)9B!T
M:&ES(&ES;B=T('!A<W-E9`H@("`@("H@("`@("`@("`@("`@("`@("`@("!T
M:&4@97)R;W(@:6YF;W)M871I;VX@9V%T:&5R960@9G)O;2!T:&4@1$)-4RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@=&AE($1"7T5R<F]R(&]B
M:F5C=`H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIR86ES945R<F]R
M*"DL"B`@("`@*B`@("`@($1"7VUS<W%L.CIE<G)O<DYA=&EV92@I+"!$0E]M
M<W-Q;#HZ97)R;W)#;V1E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;7-S<6Q2
M86ES945R<F]R*"1C;V1E(#T@;G5L;"D*("`@('L*("`@("`@("`D;65S<V%G
M92`]($!M<W-Q;%]G971?;&%S=%]M97-S86=E*"D["B`@("`@("`@:68@*"$D
M8V]D92D@>PH@("`@("`@("`@("`D8V]D92`]("1T:&ES+3YE<G)O<DYA=&EV
M92@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H)'1H:7,M/F5R<F]R0V]D92@D8V]D92P@)&UE<W-A9V4I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL+"!N=6QL+"`B
M)&-O9&4@+2`D;65S<V%G92(I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&5R<F]R3F%T:79E*"D*"B`@("`O*BH*("`@("`J($=E=',@=&AE($1"
M35,G(&YA=&EV92!E<G)O<B!C;V1E('!R;V1U8V5D(&)Y('1H92!L87-T('%U
M97)Y"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!$0DU3)R!E<G)O
M<B!C;V1E"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R3F%T:79E*"D*("`@
M('L*("`@("`@("`D<F5S(#T@0&US<W%L7W%U97)Y*"=S96QE8W0@0$!%4E)/
M4B!A<R!%<G)O<D-O9&4G+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@
M:68@*"$D<F5S*2!["B`@("`@("`@("`@(')E='5R;B!$0E]%4E)/4CL*("`@
M("`@("!]"B`@("`@("`@)')O=R`]($!M<W-Q;%]F971C:%]R;W<H)')E<RD[
M"B`@("`@("`@<F5T=7)N("1R;W=;,%T["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@97)R;W)#;V1E*"D*"B`@("`O*BH*("`@("`J($1E=&5R;6EN
M97,@4$5!4CHZ1$(@97)R;W(@8V]D92!F<F]M(&US<W%L)W,@;F%T:79E(&-O
M9&5S+@H@("`@("H*("`@("`J($EF(#QV87(^)&YA=&EV96-O9&4\+W9A<CX@
M:7-N)W0@:VYO=VX@>65T+"!I="!W:6QL(&)E(&QO;VME9"!U<"X*("`@("`J
M"B`@("`@*B!`<&%R86T@(&UI>&5D("`D;F%T:79E8V]D92`@;7-S<6P@97)R
M;W(@8V]D92P@:68@:VYO=VX*("`@("`J($!R971U<FX@:6YT96=E<B`@86X@
M97)R;W(@;G5M8F5R(&9R;VT@82!$0B!E<G)O<B!C;VYS=&%N=`H@("`@("H@
M0'-E92!E<G)O<DYA=&EV92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R
M0V]D92@D;F%T:79E8V]D92`](&YU;&PL("1M<V<@/2`G)RD*("`@('L*("`@
M("`@("!I9B`H(21N871I=F5C;V1E*2!["B`@("`@("`@("`@("1N871I=F5C
M;V1E(#T@)'1H:7,M/F5R<F]R3F%T:79E*"D["B`@("`@("`@?0H@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^97)R;W)C;V1E7VUA<%LD;F%T:79E8V]D95TI
M*2!["B`@("`@("`@("`@(&EF("@D;F%T:79E8V]D92`]/2`S-S`Q"B`@("`@
M("`@("`@("`@("`F)B!P<F5G7VUA=&-H*"<O0V%N;F]T(&1R;W`@=&AE(&EN
M9&5X+VDG+"`D;7-G*2D*("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N($1"7T524D]27TY/5%]&3U5.1#L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/F5R<F]R8V]D95]M87!;)&YA=&EV96-O
M9&5=.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!$0E]%
M4E)/4CL*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M=&%B;&5);F9O*"D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@:6YF;W)M871I
M;VX@86)O=70@82!T86)L92!O<B!A(')E<W5L="!S970*("`@("`J"B`@("`@
M*B!.3U1%.B!O;FQY('-U<'!O<G1S("=T86)L92<@86YD("=F;&%G<R<@:68@
M/'9A<CXD<F5S=6QT/"]V87(^"B`@("`@*B!I<R!A('1A8FQE(&YA;64N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&]B:F5C='QS=')I;F<@("1R97-U;'0@($1"
M7W)E<W5L="!O8FIE8W0@9G)O;2!A('%U97)Y(&]R(&$*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R:6YG(&-O;G1A:6YI;F<@
M=&AE(&YA;64@;V8@82!T86)L92X*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@5VAI;&4@=&AI<R!A;'-O(&%C8V5P=',@82!Q=65R
M>2!R97-U;'0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<F5S;W5R8V4@:61E;G1I9FEE<BP@=&AI<R!B96AA=FEO<B!I<PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D97!R96-A=&5D
M+@H@("`@("H@0'!A<F%M(&EN="`@("`@("`@("`@("1M;V1E("`@(&$@=F%L
M:60@=&%B;&5);F9O(&UO9&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!A;B!A<W-O8VEA=&EV92!A<G)A>2!W:71H('1H92!I;F9O<FUA=&EO;B!R
M97%U97-T960N"B`@("`@*B`@("`@("`@("`@("`@("`@02!$0E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO
M;CHZ=&%B;&5);F9O*"D*("`@("`J+PH@("`@9G5N8W1I;VX@=&%B;&5);F9O
M*"1R97-U;'0L("1M;V1E(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?
M<W1R:6YG*"1R97-U;'0I*2!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@
M("`J(%!R;V)A8FQY(')E8V5I=F5D(&$@=&%B;&4@;F%M92X*("`@("`@("`@
M("`@("H@0W)E871E(&$@<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@
M("`@("`@("`@("`J+PH@("`@("`@("`@("!I9B`H(4!M<W-Q;%]S96QE8W1?
M9&(H)'1H:7,M/E]D8BP@)'1H:7,M/F-O;FYE8W1I;VXI*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/FUS<W%L4F%I<V5%<G)O<BA$0E]%4E)/
M4E].3T1"4T5,14-4140I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1I
M9"`]($!M<W-Q;%]Q=65R>2@B4T5,14-4("H@1E)/32`D<F5S=6QT(%=(15)%
M(#$],"(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M8V]N;F5C=&EO;BD["B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@=')U93L*
M("`@("`@("!](&5L<V5I9B`H:7-S970H)')E<W5L="T^<F5S=6QT*2D@>PH@
M("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E
M9"!A(')E<W5L="!O8FIE8W0N"B`@("`@("`@("`@("`J($5X=')A8W0@=&AE
M(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@("`@*B\*
M("`@("`@("`@("`@)&ED(#T@)')E<W5L="T^<F5S=6QT.PH@("`@("`@("`@
M("`D9V]T7W-T<FEN9R`](&9A;'-E.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I=F5D(&$@
M<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@("`@("`@("`J($-O
M<'D@:70N"B`@("`@("`@("`@("`J($1E<')E8V%T960N("!(97)E(&9O<B!C
M;VUP871I8FEL:71Y(&]N;'DN"B`@("`@("`@("`@("`J+PH@("`@("`@("`@
M("`D:60@/2`D<F5S=6QT.PH@("`@("`@("`@("`D9V]T7W-T<FEN9R`](&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D:60I
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7-S<6Q286ES945R<F]R
M*$1"7T524D]27TY%141?34]215]$051!*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!
M0DE,25197TQ/5T520T%312D@>PH@("`@("`@("`@("`D8V%S95]F=6YC(#T@
M)W-T<G1O;&]W97(G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C
M87-E7V9U;F,@/2`G<W1R=F%L)SL*("`@("`@("!]"@H@("`@("`@("1C;W5N
M="`]($!M<W-Q;%]N=6U?9FEE;&1S*"1I9"D["B`@("`@("`@)')E<R`@(#T@
M87)R87DH*3L*"B`@("`@("`@:68@*"1M;V1E*2!["B`@("`@("`@("`@("1R
M97-;)VYU;5]F:65L9',G72`]("1C;W5N=#L*("`@("`@("!]"@H@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\("1C;W5N=#L@)&DK*RD@>PH@("`@("`@("`@
M("`D<F5S6R1I72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)W1A8FQE)R`]
M/B`D9V]T7W-T<FEN9R`_("1C87-E7V9U;F,H)')E<W5L="D@.B`G)RP*("`@
M("`@("`@("`@("`@("=N86UE)R`@/3X@)&-A<V5?9G5N8RA`;7-S<6Q?9FEE
M;&1?;F%M92@D:60L("1I*2DL"B`@("`@("`@("`@("`@("`G='EP92<@(#T^
M($!M<W-Q;%]F:65L9%]T>7!E*"1I9"P@)&DI+`H@("`@("`@("`@("`@("`@
M)VQE;B<@("`]/B!`;7-S<6Q?9FEE;&1?;&5N9W1H*"1I9"P@)&DI+`H@("`@
M("`@("`@("`@("`@+R\@5V4@;VYL>2!S=7!P;W)T(&9L86=S(&9O<B!T86)L
M90H@("`@("`@("`@("`@("`@)V9L86=S)R`]/B`D9V]T7W-T<FEN9PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`_("1T:&ES+3Y?;7-S<6Q?9FEE;&1?
M9FQA9W,H)')E<W5L="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@($!M<W-Q;%]F:65L9%]N86UE*"1I
M9"P@)&DI*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("<G+`H@("`@
M("`@("`@("`I.PH@("`@("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),14E.
M1D]?3U)$15(I('L*("`@("`@("`@("`@("`@("1R97-;)V]R9&5R)UU;)')E
M<ULD:5U;)VYA;64G75T@/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H)&UO9&4@)B!$0E]404),14E.1D]?3U)$15)404),12D@>PH@("`@
M("`@("`@("`@("`@)')E<ULG;W)D97)T86)L92==6R1R97-;)&E=6R=T86)L
M92==75LD<F5S6R1I75LG;F%M92==72`]("1I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O+R!F<F5E('1H92!R97-U;'0@;VYL>2!I9B!W
M92!W97)E(&-A;&QE9"!O;B!A('1A8FQE"B`@("`@("`@:68@*"1G;W1?<W1R
M:6YG*2!["B`@("`@("`@("`@($!M<W-Q;%]F<F5E7W)E<W5L="@D:60I.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)')E<SL*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!?;7-S<6Q?9FEE;&1?9FQA9W,H*0H*("`@("\J*@H@
M("`@("H@1V5T(&$@8V]L=6UN)W,@9FQA9W,*("`@("`J"B`@("`@*B!3=7!P
M;W)T<R`B;F]T7VYU;&PB+"`B<')I;6%R>5]K97DB+`H@("`@("H@(F%U=&]?
M:6YC<F5M96YT(B`H;7-S<6P@:61E;G1I='DI+"`B=&EM97-T86UP(B`H;7-S
M<6P@=&EM97-T86UP*2P*("`@("`J(")U;FEQ=65?:V5Y(B`H;7-S<6P@=6YI
M<75E(&EN9&5X+"!U;FEQ=64@8VAE8VL@;W(@<')I;6%R>5]K97DI(&%N9`H@
M("`@("H@(FUU;'1I<&QE7VME>2(@*&UU;'1I:V5Y(&EN9&5X*0H@("`@("H*
M("`@("`J(&US<W%L('1I;65S=&%M<"!I<R!.3U0@<VEM:6QA<B!T;R!T:&4@
M;7ES<6P@=&EM97-T86UP('-O('1H:7,@:7,@;6%Y8F4*("`@("`J(&YO="!U
M<V5F=6P@870@86QL("T@:7,@=&AE(&)E:&%V:6]U<B!O9B!M>7-Q;%]F:65L
M9%]F;&%G<R!T:&%T('!R:6UA<GD*("`@("`J(&ME>7,@87)E(&%L=V%Y('5N
M:7%U93\@:7,@=&AE(&EN=&5R<')E=&%T:6]N(&]F(&UU;'1I<&QE7VME>2!C
M;W)R96-T/PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1A8FQE("`@
M=&AE('1A8FQE(&YA;64*("`@("`J($!P87)A;2!S=')I;F<@)&-O;'5M;B`@
M=&AE(&9I96QD(&YA;64*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M=&AE(&9L86=S"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*B!`875T:&]R($IO97)N($)A<G1H96P@/&I?8F%R=&AE;$!W96(N9&4^"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]M<W-Q;%]F:65L9%]F;&%G<R@D=&%B;&4L
M("1C;VQU;6XI"B`@("!["B`@("`@("`@<W1A=&EC("1T86)L94YA;64@/2!N
M=6QL.PH@("`@("`@('-T871I8R`D9FQA9W,@/2!A<G)A>2@I.PH*("`@("`@
M("!I9B`H)'1A8FQE("$]("1T86)L94YA;64I('L*"B`@("`@("`@("`@("1F
M;&%G<R`](&%R<F%Y*"D["B`@("`@("`@("`@("1T86)L94YA;64@/2`D=&%B
M;&4["@H@("`@("`@("`@("`O+R!G970@=6YI<75E(&%N9"!P<FEM87)Y(&ME
M>7,*("`@("`@("`@("`@)')E<R`]("1T:&ES+3YG971!;&PH(D5814,@4U!?
M2$5,4$E.1$586R1T86)L95TB+"!$0E]&151#2$U/1$5?05-33T,I.PH*("`@
M("`@("`@("`@9F]R96%C:"`H)')E<R!A<R`D=F%L*2!["B`@("`@("`@("`@
M("`@("`D:V5Y<R`](&5X<&QO9&4H)RP@)RP@)'9A;%LG:6YD97A?:V5Y<R==
M*3L*"B`@("`@("`@("`@("`@("!I9B`H<VEZ96]F*"1K97ES*2`^(#$I('L*
M("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D:V5Y<R!A<R`D:V5Y*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861D7V9L86<H)&9L
M86=S6R1K97E=+"`G;75L=&EP;&5?:V5Y)RD["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("AS
M=')P;W,H)'9A;%LG:6YD97A?9&5S8W)I<'1I;VXG72P@)W!R:6UA<GD@:V5Y
M)RDI('L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D:V5Y<R!A<R`D
M:V5Y*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861D7V9L
M86<H)&9L86=S6R1K97E=+"`G<')I;6%R>5]K97DG*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H<W1R<&]S*"1V
M86Q;)VEN9&5X7V1E<V-R:7!T:6]N)UTL("=U;FEQ=64G*2D@>PH@("`@("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1K97ES(&%S("1K97DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1?9FQA9R@D9FQA9W-;)&ME
M>5TL("=U;FEQ=65?:V5Y)RD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!G
M970@875T;U]I;F-R96UE;G0L(&YO=%]N=6QL(&%N9"!T:6UE<W1A;7`*("`@
M("`@("`@("`@)')E<R`]("1T:&ES+3YG971!;&PH(D5814,@4U!?0T],54U.
M4ULD=&%B;&5=(BP@1$)?1D540TA-3T1%7T%34T]#*3L*"B`@("`@("`@("`@
M(&9O<F5A8V@@*"1R97,@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@)'9A
M;"`](&%R<F%Y7V-H86YG95]K97E?8V%S92@D=F%L+"!#05-%7TQ/5T52*3L*
M("`@("`@("`@("`@("`@(&EF("@D=F%L6R=N=6QL86)L92==(#T]("<P)RD@
M>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861D7V9L86<H)&9L86=S
M6R1V86Q;)V-O;'5M;E]N86UE)UU=+"`G;F]T7VYU;&PG*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&EF("AS=')P;W,H)'9A;%LG='EP
M95]N86UE)UTL("=I9&5N=&ET>2<I*2!["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]A9&1?9FQA9R@D9FQA9W-;)'9A;%LG8V]L=6UN7VYA;64G75TL
M("=A=71O7VEN8W)E;65N="<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@:68@*'-T<G!O<R@D=F%L6R=T>7!E7VYA;64G72P@)W1I;65S
M=&%M<"<I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1?9FQA
M9R@D9FQA9W-;)'9A;%LG8V]L=6UN7VYA;64G75TL("=T:6UE<W1A;7`G*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)&-O;'5M;BP@)&9L86=S*2D@
M>PH@("`@("`@("`@("!R971U<FXH:6UP;&]D92@G("<L("1F;&%G<ULD8V]L
M=6UN72DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)R<["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@7V%D9%]F;&%G*"D*"B`@("`O*BH*("`@
M("`J($%D9',@82!S=')I;F<@=&\@=&AE(&9L86=S(&%R<F%Y(&EF('1H92!F
M;&%G(&ES(&YO="!Y970@:6X@=&AE<F4*("`@("`J("T@:68@=&AE<F4@:7,@
M;F\@9FQA9R!P<F5S96YT('1H92!A<G)A>2!I<R!C<F5A=&5D"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("`F)&%R<F%Y("!T:&4@<F5F97)E;F-E('1O
M('1H92!F;&%G+6%R<F%Y"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU92`@
M('1H92!F;&%G('9A;'5E"B`@("`@*@H@("`@("H@0')E='5R;B!V;VED"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`875T:&]R($IO
M97)N($)A<G1H96P@/&I?8F%R=&AE;$!W96(N9&4^"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]A9&1?9FQA9R@F)&%R<F%Y+"`D=F%L=64I"B`@("!["B`@("`@
M("`@:68@*"%I<U]A<G)A>2@D87)R87DI*2!["B`@("`@("`@("`@("1A<G)A
M>2`](&%R<F%Y*"1V86QU92D["B`@("`@("`@?2!E;'-E:68@*"%I;E]A<G)A
M>2@D=F%L=64L("1A<G)A>2DI('L*("`@("`@("`@("`@87)R87E?<'5S:"@D
M87)R87DL("1V86QU92D["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&=E=%-P96-I86Q1=65R>2@I"@H@("`@+RHJ"B`@("`@*B!/
M8G1A:6YS('1H92!Q=65R>2!S=')I;F<@;F5E9&5D(&9O<B!L:7-T:6YG(&$@
M9VEV96X@='EP92!O9B!O8FIE8W1S"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D='EP92`@=&AE(&MI;F0@;V8@;V)J96-T<R!Y;W4@=V%N="!T;R!R
M971R:65V90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@4U%,
M('%U97)Y('-T<FEN9R!O<B!N=6QL(&EF('1H92!D<FEV97(@9&]E<VXG=`H@
M("`@("H@("`@("`@("`@("`@("`@("!S=7!P;W)T('1H92!O8FIE8W0@='EP
M92!R97%U97-T960*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@
M("`@("H@0'-E92!$0E]C;VUM;VXZ.F=E=$QI<W1/9B@I"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%-P96-I86Q1=65R>2@D='EP92D*("`@('L*("`@("`@
M("!S=VET8V@@*"1T>7!E*2!["B`@("`@("`@("`@(&-A<V4@)W1A8FQE<R<Z
M"B`@("`@("`@("`@("`@("!R971U<FX@(E-%3$5#5"!N86UE($923TT@<WES
M;V)J96-T<R!72$5212!T>7!E(#T@)U4G(@H@("`@("`@("`@("`@("`@("`@
M("`@("X@)R!/4D1%4B!"62!N86UE)SL*("`@("`@("`@("`@8V%S92`G=FEE
M=W,G.@H@("`@("`@("`@("`@("`@<F5T=7)N(")314Q%0U0@;F%M92!&4D]-
M('-Y<V]B:F5C=',@5TA%4D4@='EP92`]("=6)R(["B`@("`@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]
M"B`@("!]"@H@("`@+R\@?7U]"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*
M("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J($5N9#H*
M("HO"@H_/@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O1$(O;7ES
M<6PN<&AP````````````````````````````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P-S<P-#<`,3`U,34T,S,W,S8`,#(P-S<P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@HO*B!V:6TZ('-E="!E
M>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT
M.B`J+PH*+RHJ"B`J(%1H92!014%2($1"(&1R:79E<B!F;W(@4$A0)W,@;7ES
M<6P@97AT96YS:6]N"B`J(&9O<B!I;G1E<F%C=&EN9R!W:71H($UY4U%,(&1A
M=&%B87-E<PH@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%
M3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S
M+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55))
M.@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@
M0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U
M=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@H@*B!`875T:&]R
M("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C
M;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@;7ES<6PN<&AP
M+'8@,2XQ,3<@,C`P-2\P,R\R.2`Q-3HP,SHR-B!D86YI96QC($5X<"`D"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@
M*B\*"B\J*@H@*B!/8G1A:6X@=&AE($1"7V-O;6UO;B!C;&%S<R!S;R!I="!C
M86X@8F4@97AT96YD960@9G)O;0H@*B\*<F5Q=6ER95]O;F-E("=$0B]C;VUM
M;VXN<&AP)SL*"B\J*@H@*B!4:&4@;65T:&]D<R!014%2($1"('5S97,@=&\@
M:6YT97)A8W0@=VET:"!02%`G<R!M>7-Q;"!E>'1E;G-I;VX*("H@9F]R(&EN
M=&5R86-T:6YG('=I=&@@37E344P@9&%T86)A<V5S"B`J"B`J(%1H97-E(&UE
M=&AO9',@;W9E<FQO860@=&AE(&]N97,@9&5C;&%R960@:6X@1$)?8V]M;6]N
M+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$
M0@H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^"B`J
M($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE
M=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N
M-RXV"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]$0@H@*B\*8VQA<W,@1$)?;7ES<6P@97AT96YD<R!$0E]C;VUM;VX*>PH@
M("`@+R\@>WM[('!R;W!E<G1I97,*"B`@("`O*BH*("`@("`J(%1H92!$0B!D
M<FEV97(@='EP92`H;7ES<6PL(&]C:3@L(&]D8F,L(&5T8RXI"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)'!H<'1Y<&4@/2`G;7ES<6PG
M.PH*("`@("\J*@H@("`@("H@5&AE(&1A=&%B87-E('-Y;G1A>"!V87)I86YT
M('1O(&)E('5S960@*&1B,BP@86-C97-S+"!E=&,N*2P@:68@86YY"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&1B<WEN=&%X(#T@)VUY
M<W%L)SL*"B`@("`O*BH*("`@("`J(%1H92!C87!A8FEL:71I97,@;V8@=&AI
M<R!$0B!I;7!L96UE;G1A=&EO;@H@("`@("H*("`@("`J(%1H92`G;F5W7VQI
M;FLG(&5L96UE;G0@8V]N=&%I;G,@=&AE(%!(4"!V97)S:6]N('1H870@9FER
M<W0@<')O=FED960*("`@("`J(&YE=U]L:6YK('-U<'!O<G0@9F]R('1H:7,@
M1$)-4RX@($-O;G1A:6YS(&9A;'-E(&EF(&ET)W,@=6YS=7!P;W)T960N"B`@
M("`@*@H@("`@("H@365A;FEN9R!O9B!T:&4@)VQI;6ET)R!E;&5M96YT.@H@
M("`@("H@("`K("=E;75L871E)R`](&5M=6QA=&4@=VET:"!F971C:"!R;W<@
M8GD@;G5M8F5R"B`@("`@*B`@("L@)V%L=&5R)R`@(#T@86QT97(@=&AE('%U
M97)Y"B`@("`@*B`@("L@9F%L<V4@("`@(#T@<VMI<"!R;W=S"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&9E871U<F5S(#T@
M87)R87DH"B`@("`@("`@)VQI;6ET)R`@("`@("`@(#T^("=A;'1E<B<L"B`@
M("`@("`@)VYE=U]L:6YK)R`@("`@(#T^("<T+C(N,"<L"B`@("`@("`@)VYU
M;7)O=W,G("`@("`@(#T^('1R=64L"B`@("`@("`@)W!C;VYN96-T)R`@("`@
M(#T^('1R=64L"B`@("`@("`@)W!R97!A<F4G("`@("`@(#T^(&9A;'-E+`H@
M("`@("`@("=S<VPG("`@("`@("`@("`]/B!F86QS92P*("`@("`@("`G=')A
M;G-A8W1I;VYS)R`@/3X@=')U92P*("`@("D["@H@("`@+RHJ"B`@("`@*B!!
M(&UA<'!I;F<@;V8@;F%T:79E(&5R<F]R(&-O9&5S('1O($1"(&5R<F]R(&-O
M9&5S"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D97)R;W)C
M;V1E7VUA<"`](&%R<F%Y*`H@("`@("`@(#$P,#0@/3X@1$)?15)23U)?0T%.
M3D]47T-214%412P*("`@("`@("`Q,#`U(#T^($1"7T524D]27T-!3DY/5%]#
M4D5!5$4L"B`@("`@("`@,3`P-B`]/B!$0E]%4E)/4E]#04Y.3U1?0U)%051%
M+`H@("`@("`@(#$P,#<@/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@
M("`@("`@,3`P."`]/B!$0E]%4E)/4E]#04Y.3U1?1%)/4"P*("`@("`@("`Q
M,#(R(#T^($1"7T524D]27T%,4D5!1%E?15A)4U13+`H@("`@("`@(#$P-#0@
M/3X@1$)?15)23U)?04-#15-37U9)3TQ!5$E/3BP*("`@("`@("`Q,#0V(#T^
M($1"7T524D]27TY/1$)314Q%0U1%1"P*("`@("`@("`Q,#0X(#T^($1"7T52
M4D]27T-/3E-44D%)3E0L"B`@("`@("`@,3`T.2`]/B!$0E]%4E)/4E].3U-5
M0TA$0BP*("`@("`@("`Q,#4P(#T^($1"7T524D]27T%,4D5!1%E?15A)4U13
M+`H@("`@("`@(#$P-3$@/3X@1$)?15)23U)?3D]354-(5$%"3$4L"B`@("`@
M("`@,3`U-"`]/B!$0E]%4E)/4E].3U-50TA&245,1"P*("`@("`@("`Q,#8Q
M(#T^($1"7T524D]27T%,4D5!1%E?15A)4U13+`H@("`@("`@(#$P-C(@/3X@
M1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@("`@("`@,3`V-"`]/B!$0E]%
M4E)/4E]364Y405@L"B`@("`@("`@,3`Y,2`]/B!$0E]%4E)/4E].3U1?1D]5
M3D0L"B`@("`@("`@,3$P,"`]/B!$0E]%4E)/4E].3U1?3$]#2T5$+`H@("`@
M("`@(#$Q,S8@/3X@1$)?15)23U)?5D%,545?0T]53E1?3TY?4D]7+`H@("`@
M("`@(#$Q-#(@/3X@1$)?15)23U)?04-#15-37U9)3TQ!5$E/3BP*("`@("`@
M("`Q,30V(#T^($1"7T524D]27TY/4U5#2%1!0DQ%+`H@("`@("`@(#$R,38@
M/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("`@("`Q,C$W(#T^($1"7T52
M4D]27T-/3E-44D%)3E0L"B`@("`I.PH*("`@("\J*@H@("`@("H@5&AE(')A
M=R!D871A8F%S92!C;VYN96-T:6]N(&-R96%T960@8GD@4$A0"B`@("`@*B!`
M=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D8V]N;F5C=&EO;CL*"B`@
M("`O*BH*("`@("`J(%1H92!$4TX@:6YF;W)M871I;VX@9F]R(&-O;FYE8W1I
M;F<@=&\@82!D871A8F%S90H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)&1S;B`](&%R<F%Y*"D["@H*("`@("\J*@H@("`@("H@4VAO=6QD
M(&1A=&$@;6%N:7!U;&%T:6]N('%U97)I97,@8F4@8V]M;6ET=&5D(&%U=&]M
M871I8V%L;'D_"B`@("`@*B!`=F%R(&)O;VP*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!V87(@)&%U=&]C;VUM:70@/2!T<G5E.PH*("`@
M("\J*@H@("`@("H@5&AE('%U86YT:71Y(&]F('1R86YS86-T:6]N<R!B96=U
M;@H@("`@("H*("`@("`J('M`:6YT97)N86P@(%=H:6QE('1H:7,@:7,@<')I
M=F%T92P@:70@8V%N)W0@86-T=6%L;'D@8F4@9&5S:6=N871E9`H@("`@("H@
M<')I=F%T92!I;B!02%`@-2!B96-A=7-E(&ET(&ES(&1I<F5C=&QY(&%C8V5S
M<V5D(&EN('1H92!T97-T('-U:71E+GU]"B`@("`@*@H@("`@("H@0'9A<B!I
M;G1E9V5R"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R
M("1T<F%N<V%C=&EO;E]O<&-O=6YT(#T@,#L*"B`@("`O*BH*("`@("`J(%1H
M92!D871A8F%S92!S<&5C:69I960@:6X@=&AE($133@H@("`@("H*("`@("`J
M($ET)W,@82!F:7@@=&\@86QL;W<@8V%L;',@=&\@9&EF9F5R96YT(&1A=&%B
M87-E<R!I;B!T:&4@<V%M92!S8W)I<'0N"B`@("`@*@H@("`@("H@0'9A<B!S
M=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@
M)%]D8B`]("<G.PH*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYS=')U8W1O
M<@H*("`@("\J*@H@("`@("H@5&AI<R!C;VYS=')U8W1O<B!C86QL<R`\:V)D
M/B1T:&ES+3Y$0E]C;VUM;VXH*3PO:V)D/@H@("`@("H*("`@("`J($!R971U
M<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!$0E]M>7-Q;"@I"B`@("![
M"B`@("`@("`@)'1H:7,M/D1"7V-O;6UO;B@I.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(&-O;FYE8W0H*0H*("`@("\J*@H@("`@("H@0V]N;F5C
M="!T;R!T:&4@9&%T86)A<V4@<V5R=F5R+"!L;V<@:6X@86YD(&]P96X@=&AE
M(&1A=&%B87-E"B`@("`@*@H@("`@("H@1&]N)W0@8V%L;"!T:&ES(&UE=&AO
M9"!D:7)E8W1L>2X@(%5S92!$0CHZ8V]N;F5C="@I(&EN<W1E860N"B`@("`@
M*@H@("`@("H@4$5!4B!$0B=S(&UY<W%L(&1R:79E<B!S=7!P;W)T<R!T:&4@
M9F]L;&]W:6YG(&5X=')A($133B!O<'1I;VYS.@H@("`@("H@("`K(&YE=U]L
M:6YK("`@("`@268@<V5T('1O('1R=64L(&-A=7-E<R!S=6)S97%U96YT(&-A
M;&QS('1O(&-O;FYE8W0H*0H@("`@("H@("`@("`@("`@("`@("`@("`@('1O
M(')E='5R;B!A(&YE=R!C;VYN96-T:6]N(&QI;FL@:6YS=&5A9"!O9B!T:&4*
M("`@("`J("`@("`@("`@("`@("`@("`@("!E>&ES=&EN9R!O;F4N("!705).
M24Y'.B!T:&ES(&ES(&YO="!P;W)T86)L92!T;PH@("`@("H@("`@("`@("`@
M("`@("`@("`@(&]T:&5R($1"35,G<RX@079A:6QA8FQE('-I;F-E(%!%05(@
M1$(@,2XW+C`N"B`@("`@*B`@("L@8VQI96YT7V9L86=S("!!;GD@8V]M8FEN
M871I;VX@;V8@35E344Q?0TQ)14Y47RH@8V]N<W1A;G1S+@H@("`@("H@("`@
M("`@("`@("`@("`@("`@($]N;'D@=7-E9"!I9B!02%`@:7,@870@=F5R<VEO
M;B`T+C,N,"!O<B!G<F5A=&5R+@H@("`@("H@("`@("`@("`@("`@("`@("`@
M($%V86EL86)L92!S:6YC92!014%2($1"(#$N-RXP+@H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D9'-N("`@("`@("`@=&AE(&1A=&$@<V]U<F-E(&YA
M;64*("`@("`J($!P87)A;2!B;V]L("`D<&5R<VES=&5N="`@<VAO=6QD('1H
M92!C;VYN96-T:6]N(&)E('!E<G-I<W1E;G0_"B`@("`@*@H@("`@("H@0')E
M='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N($$@1$)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;FYE8W0H)&1S
M;BP@)'!E<G-I<W1E;G0@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H(5!%
M05(Z.FQO861%>'1E;G-I;VXH)VUY<W%L)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27T585$5.4TE/3E].3U1?
M1D]53D0I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/F1S;B`]("1D<VX[
M"B`@("`@("`@:68@*"1D<VY;)V1B<WEN=&%X)UTI('L*("`@("`@("`@("`@
M)'1H:7,M/F1B<WEN=&%X(#T@)&1S;ELG9&)S>6YT87@G73L*("`@("`@("!]
M"@H@("`@("`@("1P87)A;7,@/2!A<G)A>2@I.PH@("`@("`@(&EF("@D9'-N
M6R=P<F]T;V-O;"==("8F("1D<VY;)W!R;W1O8V]L)UT@/3T@)W5N:7@G*2![
M"B`@("`@("`@("`@("1P87)A;7-;,%T@/2`G.B<@+B`D9'-N6R=S;V-K970G
M73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&%R86US6S!=(#T@
M)&1S;ELG:&]S='-P96,G72`_("1D<VY;)VAO<W1S<&5C)UT*("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@)VQO8V%L:&]S="<["B`@("`@("`@("`@(&EF
M("@D9'-N6R=P;W)T)UTI('L*("`@("`@("`@("`@("`@("1P87)A;7-;,%T@
M+CT@)SHG("X@)&1S;ELG<&]R="==.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@("1P87)A;7-;72`]("1D<VY;)W5S97)N86UE)UT@/R`D9'-N
M6R=U<V5R;F%M92==(#H@;G5L;#L*("`@("`@("`D<&%R86US6UT@/2`D9'-N
M6R=P87-S=V]R9"==(#\@)&1S;ELG<&%S<W=O<F0G72`Z(&YU;&P["@H@("`@
M("`@(&EF("@A)'!E<G-I<W1E;G0I('L*("`@("`@("`@("`@:68@*&ES<V5T
M*"1D<VY;)VYE=U]L:6YK)UTI"B`@("`@("`@("`@("`@("`F)B`H)&1S;ELG
M;F5W7VQI;FLG72`]/2`G=')U92<@?'P@)&1S;ELG;F5W7VQI;FLG72`]/3T@
M=')U92DI"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@("1P87)A;7-;
M72`]('1R=64["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D<&%R86US6UT@/2!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*'!H<'9E<G-I;VXH*2P@)S0N
M,RXP)RP@)SX])RDI('L*("`@("`@("`@("`@)'!A<F%M<UM=(#T@:7-S970H
M)&1S;ELG8VQI96YT7V9L86=S)UTI"B`@("`@("`@("`@("`@("`@("`@("`@
M(#\@)&1S;ELG8VQI96YT7V9L86=S)UT@.B!N=6QL.PH@("`@("`@('T*"B`@
M("`@("`@)&-O;FYE8W1?9G5N8W1I;VX@/2`D<&5R<VES=&5N="`_("=M>7-Q
M;%]P8V]N;F5C="<@.B`G;7ES<6Q?8V]N;F5C="<["@H@("`@("`@("1I;FD@
M/2!I;FE?9V5T*"=T<F%C:U]E<G)O<G,G*3L*("`@("`@("`D<&AP7V5R<F]R
M;7-G(#T@)R<["B`@("`@("`@:68@*"1I;FDI('L*("`@("`@("`@("`@)'1H
M:7,M/F-O;FYE8W1I;VX@/2!`8V%L;%]U<V5R7V9U;F-?87)R87DH)&-O;FYE
M8W1?9G5N8W1I;VXL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P87)A;7,I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(&EN:5]S970H)W1R86-K7V5R<F]R<R<L(#$I.PH@
M("`@("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`]($!C86QL7W5S97)?9G5N
M8U]A<G)A>2@D8V]N;F5C=%]F=6YC=&EO;BP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<RD[
M"B`@("`@("`@("`@(&EN:5]S970H)W1R86-K7V5R<F]R<R<L("1I;FDI.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"$D=&AI<RT^8V]N;F5C=&EO;BD@>PH@
M("`@("`@("`@("!I9B`H*"1E<G(@/2!`;7ES<6Q?97)R;W(H*2D@(3T@)R<I
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$
M0E]%4E)/4E]#3TY.14-47T9!24Q%1"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL+"!N=6QL+"`*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D97)R*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]#3TY.14-47T9!24Q%1"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL
M+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P:'!?97)R;W)M<V<I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!I9B`H)&1S;ELG9&%T86)A<V4G72D@>PH@("`@("`@("`@("!I
M9B`H(4!M>7-Q;%]S96QE8W1?9&(H)&1S;ELG9&%T86)A<V4G72P@)'1H:7,M
M/F-O;FYE8W1I;VXI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/FUY<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1T:&ES+3Y?9&(@/2`D9'-N6R=D871A8F%S92==.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&1I<V-O;FYE8W0H*0H*("`@("\J*@H@("`@("H@1&ES8V]N;F5C=',@
M9G)O;2!T:&4@9&%T86)A<V4@<V5R=F5R"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L("!44E5%(&]N('-U8V-E<W,L($9!3%-%(&]N(&9A:6QU<F4*("`@
M("`J+PH@("`@9G5N8W1I;VX@9&ES8V]N;F5C="@I"B`@("!["B`@("`@("`@
M)')E="`]($!M>7-Q;%]C;&]S92@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@
M("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!N=6QL.PH@("`@("`@(')E='5R;B`D
M<F5T.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('-I;7!L95%U97)Y
M*"D*"B`@("`O*BH*("`@("`J(%-E;F1S(&$@<75E<GD@=&\@=&AE(&1A=&%B
M87-E('-E<G9E<@H@("`@("H*("`@("`J($=E;F5R86QL>2!U<V5S(&UY<W%L
M7W%U97)Y*"DN("!)9B!Y;W4@=V%N="!T;R!U<V4*("`@("`J(&UY<W%L7W5N
M8G5F9F5R961?<75E<GDH*2!S970@=&AE(")R97-U;'1?8G5F9F5R:6YG(B!O
M<'1I;VX@=&\@,"!U<VEN9PH@("`@("H@<V5T3W!T:6]N<R@I+B`@5&AI<R!O
M<'1I;VX@=V%S(&%D9&5D(&EN(%)E;&5A<V4@,2XW+C`N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@=&AE(%-13"!Q=65R>2!S=')I;F<*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("`K(&$@4$A0(')E<W5L="!R97-R;W5C
M92!F;W(@<W5C8V5S<V9U;"!314Q%0U0@<75E<FEE<PH@("`@("H@("`@("`@
M("`@("`@("`@*R!T:&4@1$)?3TL@8V]N<W1A;G0@9F]R(&]T:&5R('-U8V-E
M<W-F=6P@<75E<FEE<PH@("`@("H@("`@("`@("`@("`@("`@*R!A($1"7T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N('-I
M;7!L95%U97)Y*"1Q=65R>2D*("`@('L*("`@("`@("`D:7-M86YI<"`]($1"
M.CII<TUA;FEP*"1Q=65R>2D["B`@("`@("`@)'1H:7,M/FQA<W1?<75E<GD@
M/2`D<75E<GD["B`@("`@("`@)'%U97)Y(#T@)'1H:7,M/FUO9&EF>5%U97)Y
M*"1Q=65R>2D["B`@("`@("`@:68@*"1T:&ES+3Y?9&(I('L*("`@("`@("`@
M("`@:68@*"%`;7ES<6Q?<V5L96-T7V1B*"1T:&ES+3Y?9&(L("1T:&ES+3YC
M;VYN96-T:6]N*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM
M>7-Q;%)A:7-E17)R;W(H1$)?15)23U)?3D]$0E-%3$5#5$5$*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H(21T:&ES+3YA=71O8V]M
M;6ET("8F("1I<VUA;FEP*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^=')A
M;G-A8W1I;VY?;W!C;W5N="`]/2`P*2!["B`@("`@("`@("`@("`@("`D<F5S
M=6QT(#T@0&UY<W%L7W%U97)Y*"=3150@05543T-/34U)5#TP)RP@)'1H:7,M
M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`@("`@)')E<W5L="`]($!M>7-Q
M;%]Q=65R>2@G0D5'24XG+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@
M("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/FUY<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3YT<F%N<V%C
M=&EO;E]O<&-O=6YT*RL["B`@("`@("`@?0H@("`@("`@(&EF("@A)'1H:7,M
M/F]P=&EO;G-;)W)E<W5L=%]B=69F97)I;F<G72D@>PH@("`@("`@("`@("`D
M<F5S=6QT(#T@0&UY<W%L7W5N8G5F9F5R961?<75E<GDH)'%U97)Y+"`D=&AI
M<RT^8V]N;F5C=&EO;BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)')E<W5L="`]($!M>7-Q;%]Q=65R>2@D<75E<GDL("1T:&ES+3YC;VYN96-T
M:6]N*3L*("`@("`@("!]"B`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^;7ES<6Q286ES945R<F]R*"D["B`@("`@
M("`@?0H@("`@("`@(&EF("AI<U]R97-O=7)C92@D<F5S=6QT*2D@>PH@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YE>'12
M97-U;'0H*0H*("`@("\J*@H@("`@("H@36]V92!T:&4@:6YT97)N86P@;7ES
M<6P@<F5S=6QT('!O:6YT97(@=&\@=&AE(&YE>'0@879A:6QA8FQE(')E<W5L
M=`H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&AA<R!N;W0@8F5E;B!I;7!L
M96UE;G1E9"!Y970N"B`@("`@*@H@("`@("H@0'!A<F%M(&$@=F%L:60@<W%L
M(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!R971U<FX@9F%L<V4*
M("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=%)E<W5L="@D<F5S=6QT*0H@("`@
M>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!F971C:$EN=&\H*0H*("`@("\J*@H@("`@("H@4&QA8V5S(&$@
M<F]W(&9R;VT@=&AE(')E<W5L="!S970@:6YT;R!T:&4@9VEV96X@87)R87D*
M("`@("`J"B`@("`@*B!&;W)M871I;F<@;V8@=&AE(&%R<F%Y(&%N9"!T:&4@
M9&%T82!T:&5R96EN(&%R92!C;VYF:6=U<F%B;&4N"B`@("`@*B!3964@1$)?
M<F5S=6QT.CIF971C:$EN=&\H*2!F;W(@;6]R92!I;F9O<FUA=&EO;BX*("`@
M("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L
M;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.F9E=&-H26YT
M;R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D
M(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@("`@
M=&AE('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H@0'!A<F%M(&%R<F%Y
M("`@("1A<G(@("`@("`@=&AE(')E9F5R96YC960@87)R87D@=&\@<'5T('1H
M92!D871A(&EN"B`@("`@*B!`<&%R86T@:6YT("`@("`@)&9E=&-H;6]D92!H
M;W<@=&AE(')E<W5L=&EN9R!A<G)A>2!S:&]U;&0@8F4@:6YD97AE9`H@("`@
M("H@0'!A<F%M(&EN="`@("`@("1R;W=N=6T@("`@=&AE(')O=R!N=6UB97(@
M=&\@9F5T8V@@*#`@/2!F:7)S="!R;W<I"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@1$)?3TL@;VX@<W5C8V5S<RP@3E5,3"!W:&5N('1H92!E;F0@
M;V8@82!R97-U;'0@<V5T(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@<F5A
M8VAE9"!O<B!O;B!F86EL=7)E"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U
M;'0Z.F9E=&-H26YT;R@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&9E=&-H26YT
M;R@D<F5S=6QT+"`F)&%R<BP@)&9E=&-H;6]D92P@)')O=VYU;2`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*"1R;W=N=6T@(3T](&YU;&PI('L*("`@("`@
M("`@("`@:68@*"%`;7ES<6Q?9&%T85]S965K*"1R97-U;'0L("1R;W=N=6TI
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!I9B`H)&9E=&-H;6]D92`F($1"7T9%5$-(
M34]$15]!4U-/0RD@>PH@("`@("`@("`@("`D87)R(#T@0&UY<W%L7V9E=&-H
M7V%R<F%Y*"1R97-U;'0L($U94U%,7T%34T]#*3L*("`@("`@("`@("`@:68@
M*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)
M5%E?3$]715)#05-%("8F("1A<G(I('L*("`@("`@("`@("`@("`@("1A<G(@
M/2!A<G)A>5]C:&%N9V5?:V5Y7V-A<V4H)&%R<BP@0T%315],3U=%4BD["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D87)R
M(#T@0&UY<W%L7V9E=&-H7W)O=R@D<F5S=6QT*3L*("`@("`@("!]"B`@("`@
M("`@:68@*"$D87)R*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@
M("`@('T*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y
M)UT@)B!$0E]03U)404))3$E465]25%))32D@>PH@("`@("`@("`@("`O*@H@
M("`@("`@("`@("`@*B!%=F5N('1H;W5G:"!T:&ES($1"35,@86QR96%D>2!T
M<FEM<R!O=71P=70L('=E(&1O('1H:7,@8F5C875S90H@("`@("`@("`@("`@
M*B!A(&9I96QD(&UI9VAT(&AA=F4@:6YT96YT:6]N86P@=VAI=&5S<&%C92!A
M="!T:&4@96YD('1H870*("`@("`@("`@("`@("H@9V5T<R!R96UO=F5D(&)Y
M($1"7U!/4E1!0DE,25197U)44DE-('5N9&5R(&%N;W1H97(@9')I=F5R+@H@
M("`@("`@("`@("`@*B\*("`@("`@("`@("`@)'1H:7,M/E]R=')I;4%R<F%Y
M5F%L=65S*"1A<G(I.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/F]P
M=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465].54Q,7U1/
M7T5-4%19*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V]N=F5R=$YU;&Q!<G)A
M>59A;'5E<U1O16UP='DH)&%R<BD["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F<F5E4F5S
M=6QT*"D*"B`@("`O*BH*("`@("`J($1E;&5T97,@=&AE(')E<W5L="!S970@
M86YD(&9R965S('1H92!M96UO<GD@;V-C=7!I960@8GD@=&AE(')E<W5L="!S
M970*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@
M8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.F9R
M964H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E
M9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J
M96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!0
M2%`G<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VP@(%12544@;VX@<W5C8V5S<RP@1D%,4T4@:68@)')E<W5L="!I
M<R!I;G9A;&ED"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.F9R964H
M*0H@("`@("HO"B`@("!F=6YC=&EO;B!F<F5E4F5S=6QT*"1R97-U;'0I"B`@
M("!["B`@("`@("`@<F5T=7)N($!M>7-Q;%]F<F5E7W)E<W5L="@D<F5S=6QT
M*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N=6U#;VQS*"D*"B`@
M("`O*BH*("`@("`J($=E=',@=&AE(&YU;6)E<B!O9B!C;VQU;6YS(&EN(&$@
M<F5S=6QT('-E=`H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M
M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E
M<W5L=#HZ;G5M0V]L<R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E
M9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S
M97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E
M("1R97-U;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H*
M("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(&-O;'5M;G,N("!!
M($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S
M964@1$)?<F5S=6QT.CIN=6U#;VQS*"D*("`@("`J+PH@("`@9G5N8W1I;VX@
M;G5M0V]L<R@D<F5S=6QT*0H@("`@>PH@("`@("`@("1C;VQS(#T@0&UY<W%L
M7VYU;5]F:65L9',H)')E<W5L="D["B`@("`@("`@:68@*"$D8V]L<RD@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/FUY<W%L4F%I<V5%<G)O<B@I.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)&-O;',["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@;G5M4F]W<R@I"@H@("`@+RHJ"B`@("`@*B!'971S
M('1H92!N=6UB97(@;V8@<F]W<R!I;B!A(')E<W5L="!S970*("`@("`J"B`@
M("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I
M<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.FYU;5)O=W,H*2!I;G-T
M96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J
M(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@
M("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G<R!Q=65R
M>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@
M=&AE(&YU;6)E<B!O9B!R;W=S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I
M;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ;G5M4F]W<R@I
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU;5)O=W,H)')E<W5L="D*("`@('L*
M("`@("`@("`D<F]W<R`]($!M>7-Q;%]N=6U?<F]W<R@D<F5S=6QT*3L*("`@
M("`@("!I9B`H)')O=W,@/3T](&YU;&PI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YM>7-Q;%)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1R;W=S.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&%U
M=&]#;VUM:70H*0H*("`@("\J*@H@("`@("H@16YA8FQE<R!O<B!D:7-A8FQE
M<R!A=71O;6%T:6,@8V]M;6ET<PH@("`@("H*("`@("`J($!P87)A;2!B;V]L
M("1O;F]F9B`@=')U92!T=7)N<R!I="!O;BP@9F%L<V4@='5R;G,@:70@;V9F
M"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N
M("!!($1"7T5R<F]R(&]B:F5C="!I9B!T:&4@9')I=F5R"B`@("`@*B`@("`@
M("`@("`@("`@(&1O97-N)W0@<W5P<&]R="!A=71O+6-O;6UI='1I;F<@=')A
M;G-A8W1I;VYS+@H@("`@("HO"B`@("!F=6YC=&EO;B!A=71O0V]M;6ET*"1O
M;F]F9B`](&9A;'-E*0H@("`@>PH@("`@("`@("\O(%A86"!I9B`D=&AI<RT^
M=')A;G-A8W1I;VY?;W!C;W5N="`^(#`L('=E('-H;W5L9"!P<F]B86)L>0H@
M("`@("`@("\O(&ES<W5E(&$@=V%R;FEN9R!H97)E+@H@("`@("`@("1T:&ES
M+3YA=71O8V]M;6ET(#T@)&]N;V9F(#\@=')U92`Z(&9A;'-E.PH@("`@("`@
M(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C
M;VUM:70H*0H*("`@("\J*@H@("`@("H@0V]M;6ET<R!T:&4@8W5R<F5N="!T
M<F%N<V%C=&EO;@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O
M;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@8V]M;6ET*"D*("`@('L*("`@("`@("!I9B`H
M)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/B`P*2!["B`@("`@("`@("`@
M(&EF("@D=&AI<RT^7V1B*2!["B`@("`@("`@("`@("`@("!I9B`H(4!M>7-Q
M;%]S96QE8W1?9&(H)'1H:7,M/E]D8BP@)'1H:7,M/F-O;FYE8W1I;VXI*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM>7-Q;%)A:7-E
M17)R;W(H1$)?15)23U)?3D]$0E-%3$5#5$5$*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<F5S=6QT(#T@0&UY<W%L
M7W%U97)Y*"=#3TU-250G+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@
M("`@("1R97-U;'0@/2!`;7ES<6Q?<75E<GDH)U-%5"!!551/0T]-34E4/3$G
M+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("1T:&ES+3YT<F%N
M<V%C=&EO;E]O<&-O=6YT(#T@,#L*("`@("`@("`@("`@:68@*"$D<F5S=6QT
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUY<W%L4F%I<V5%
M<G)O<B@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R
M;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!R;VQL8F%C
M:R@I"@H@("`@+RHJ"B`@("`@*B!2979E<G1S('1H92!C=7)R96YT('1R86YS
M86-T:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U
M8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!R;VQL8F%C:R@I"B`@("!["B`@("`@("`@:68@*"1T
M:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#X@,"D@>PH@("`@("`@("`@("!I
M9B`H)'1H:7,M/E]D8BD@>PH@("`@("`@("`@("`@("`@:68@*"%`;7ES<6Q?
M<V5L96-T7V1B*"1T:&ES+3Y?9&(L("1T:&ES+3YC;VYN96-T:6]N*2D@>PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7ES<6Q286ES945R
M<F]R*$1"7T524D]27TY/1$)314Q%0U1%1"D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E<W5L="`]($!M>7-Q;%]Q
M=65R>2@G4D],3$)!0TLG+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@
M("`@("1R97-U;'0@/2!`;7ES<6Q?<75E<GDH)U-%5"!!551/0T]-34E4/3$G
M+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("1T:&ES+3YT<F%N
M<V%C=&EO;E]O<&-O=6YT(#T@,#L*("`@("`@("`@("`@:68@*"$D<F5S=6QT
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUY<W%L4F%I<V5%
M<G)O<B@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R
M;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!A9F9E8W1E
M9%)O=W,H*0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!T:&4@;G5M8F5R
M(&]F(')O=W,@869F96-T960@8GD@82!D871A(&UA;FEU<&QA=&EO;B!Q=65R
M>0H@("`@("H*("`@("`J(#`@:7,@<F5T=7)N960@9F]R('%U97)I97,@=&AA
M="!D;VXG="!M86YI<'5L871E(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G0@('1H92!N=6UB97(@;V8@<F]W<RX@($$@1$)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%F9F5C=&5D4F]W
M<R@I"B`@("!["B`@("`@("`@:68@*$1".CII<TUA;FEP*"1T:&ES+3YL87-T
M7W%U97)Y*2D@>PH@("`@("`@("`@("!R971U<FX@0&UY<W%L7V%F9F5C=&5D
M7W)O=W,H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T*("`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@;F5X=$ED*"D*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE(&YE>'0@9G)E92!I9"!I;B!A('-E<75E;F-E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)'-E<5]N86UE("!N86UE(&]F('1H92!S97%U
M96YC90H@("`@("H@0'!A<F%M(&)O;VQE86X@)&]N9&5M86YD("!W:&5N('1R
M=64L('1H92!S97%E;F-E(&ES(&%U=&]M871I8V%L;'D*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&-R96%T960@:68@:70@9&]E<R!N;W0@
M97AI<W0*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YE>'0@:60@
M;G5M8F5R(&EN('1H92!S97%U96YC92X*("`@("`J("`@("`@("`@("`@("`@
M02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`
M<V5E($1"7V-O;6UO;CHZ;F5X=$E$*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N
M8V5.86UE*"DL"B`@("`@*B`@("`@($1"7VUY<W%L.CIC<F5A=&5397%U96YC
M92@I+"!$0E]M>7-Q;#HZ9')O<%-E<75E;F-E*"D*("`@("`J+PH@("`@9G5N
M8W1I;VX@;F5X=$ED*"1S97%?;F%M92P@)&]N9&5M86YD(#T@=')U92D*("`@
M('L*("`@("`@("`D<V5Q;F%M92`]("1T:&ES+3YG971397%U96YC94YA;64H
M)'-E<5]N86UE*3L*("`@("`@("!D;R!["B`@("`@("`@("`@("1R97!E870@
M/2`P.PH@("`@("`@("`@("`D=&AI<RT^<'5S:$5R<F]R2&%N9&QI;F<H4$5!
M4E]%4E)/4E]215154DXI.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/G%U97)Y*")54$1!5$4@)'MS97%N86UE?2`B+@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=3150@:60]3$%35%])3E-%4E1?240H:60K
M,2DG*3L*("`@("`@("`@("`@)'1H:7,M/G!O<$5R<F]R2&%N9&QI;F<H*3L*
M("`@("`@("`@("`@:68@*"1R97-U;'0@/3T]($1"7T]+*2!["B`@("`@("`@
M("`@("`@("`O+R!#3TU-3TX@0T%310H@("`@("`@("`@("`@("`@)&ED(#T@
M0&UY<W%L7VEN<V5R=%]I9"@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@
M("`@("`@("!I9B`H)&ED("$](#`I('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)&ED.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M+R\@14U05%D@4T51(%1!0DQ%"B`@("`@("`@("`@("`@("`O+R!397%U96YC
M92!T86)L92!M=7-T(&)E(&5M<'1Y(&9O<B!S;VUE(')E87-O;BP@<V\@9FEL
M;`H@("`@("`@("`@("`@("`@+R\@:70@86YD(')E='5R;B`Q(&%N9"!O8G1A
M:6X@82!U<V5R+6QE=F5L(&QO8VL*("`@("`@("`@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^9V5T3VYE*")314Q%0U0@1T547TQ/0TLH)R1[<V5Q;F%M97U?
M;&]C:R<L,3`I(BD["B`@("`@("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H
M)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)')E<W5L="D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!I9B`H)')E<W5L="`]/2`P*2!["B`@("`@("`@("`@("`@
M("`@("`@+R\@1F%I;&5D('1O(&=E="!T:&4@;&]C:PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^;7ES<6Q286ES945R<F]R*$1"7T524D]2
M7TY/5%],3T-+140I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@("\O(&%D9"!T:&4@9&5F875L="!V86QU90H@("`@("`@("`@("`@("`@
M)')E<W5L="`]("1T:&ES+3YQ=65R>2@B4D503$%#12!)3E1/("1[<V5Q;F%M
M97T@*&ED*2!604Q515,@*#`I(BD["B`@("`@("`@("`@("`@("!I9B`H1$(Z
M.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E<W5L="D["B`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@+R\@4F5L96%S92!T:&4@;&]C:PH@("`@
M("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YG971/;F4H)U-%3$5#5"!2
M14Q%05-%7TQ/0TLH)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+B`B)R1[<V5Q;F%M97U?;&]C:R<I(BD["B`@("`@("`@("`@
M("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E<W5L="D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`O+R!792!K;F]W('=H
M870@=&AE(')E<W5L="!W:6QL(&)E+"!S;R!N;R!N965D('1O('1R>2!A9V%I
M;@H@("`@("`@("`@("`@("`@<F5T=7)N(#$["@H@("`@("`@("`@("!](&5L
M<V5I9B`H)&]N9&5M86YD("8F($1".CII<T5R<F]R*"1R97-U;'0I("8F"B`@
M("`@("`@("`@("`@("`D<F5S=6QT+3YG971#;V1E*"D@/3T@1$)?15)23U)?
M3D]354-(5$%"3$4I"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@("\O
M($].1$5-04Y$(%1!0DQ%($-214%424]."B`@("`@("`@("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/F-R96%T95-E<75E;F-E*"1S97%?;F%M92D["B`@("`@
M("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E<W5L
M="D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("1R97!E870@/2`Q.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@?2!E;'-E:68@*$1".CII<T5R<F]R*"1R97-U;'0I("8F"B`@("`@("`@
M("`@("`@("`@("`@("`D<F5S=6QT+3YG971#;V1E*"D@/3T@1$)?15)23U)?
M04Q214%$65]%6$E35%,I"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@
M("\O($)!0TM705)$4R!#3TU0050*("`@("`@("`@("`@("`@("\O('-E92!?
M0D-S97%U96YC92@I(&-O;6UE;G0*("`@("`@("`@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^7T)#<V5Q=65N8V4H)'-E<6YA;64I.PH@("`@("`@("`@("`@
M("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)')E<&5A="`](#$["B`@
M("`@("`@("`@('T*("`@("`@("!]('=H:6QE("@D<F5P96%T*3L*"B`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&-R96%T95-E<75E;F-E*"D*"B`@("`O
M*BH*("`@("`J($-R96%T97,@82!N97<@<V5Q=65N8V4*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1S97%?;F%M92`@;F%M92!O9B!T:&4@;F5W('-E
M<75E;F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U
M8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*
M("`@("`J($!S964@1$)?8V]M;6]N.CIC<F5A=&5397%U96YC92@I+"!$0E]C
M;VUM;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@("`@("!$0E]M>7-Q
M;#HZ;F5X=$E$*"DL($1"7VUY<W%L.CID<F]P4V5Q=65N8V4H*0H@("`@("HO
M"B`@("!F=6YC=&EO;B!C<F5A=&5397%U96YC92@D<V5Q7VYA;64I"B`@("![
M"B`@("`@("`@)'-E<6YA;64@/2`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S
M97%?;F%M92D["B`@("`@("`@)')E<R`]("1T:&ES+3YQ=65R>2@G0U)%051%
M(%1!0DQ%("<@+B`D<V5Q;F%M90H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+B`G("AI9"!)3E1%1T52(%5.4TE'3D5$($%55$]?24Y#4D5-14Y4($Y/
M5"!.54Q,+"<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)R!04DE-
M05)9($M%62AI9"DI)RD["B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97,I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*("`@("`@
M("`O+R!I;G-E<G0@>6EE;&1S('9A;'5E(#$L(&YE>'1)9"!C86QL('=I;&P@
M9V5N97)A=&4@240@,@H@("`@("`@("1R97,@/2`D=&AI<RT^<75E<GDH(DE.
M4T525"!)3E1/("1[<V5Q;F%M97T@*&ED*2!604Q515,@*#`I(BD["B`@("`@
M("`@:68@*$1".CII<T5R<F]R*"1R97,I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<F5S.PH@("`@("`@('T*("`@("`@("`O+R!S;R!R97-E="!T;R!Z97)O
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YQ=65R>2@B55!$051%("1[<V5Q;F%M
M97T@4T54(&ED(#T@,"(I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&1R;W!397%U96YC92@I"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@<V5Q
M=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97%?;F%M92`@
M;F%M92!O9B!T:&4@<V5Q=65N8V4@=&\@8F4@9&5L971E9`H@("`@("H*("`@
M("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O
M;6UO;CHZ9')O<%-E<75E;F-E*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.
M86UE*"DL"B`@("`@*B`@("`@($1"7VUY<W%L.CIN97AT240H*2P@1$)?;7ES
M<6PZ.F-R96%T95-E<75E;F-E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9')O
M<%-E<75E;F-E*"1S97%?;F%M92D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/G%U97)Y*"=$4D]0(%1!0DQ%("<@+B`D=&AI<RT^9V5T4V5Q=65N8V5.
M86UE*"1S97%?;F%M92DI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(%]"0W-E<75E;F-E*"D*"B`@("`O*BH*("`@("`J($)A8VMW87)D<R!C;VUP
M871I8FEL:71Y('=I=&@@;VQD('-E<75E;F-E(&5M=6QA=&EO;B!I;7!L96UE
M;G1A=&EO;@H@("`@("H@*&-L96%N('5P('1H92!D=7!E<RD*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1S97%N86UE("!T:&4@<V5Q=65N8V4@;F%M
M92!T;R!C;&5A;B!U<`H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@=')U
M92!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N
M8W1I;VX@7T)#<V5Q=65N8V4H)'-E<6YA;64I"B`@("!["B`@("`@("`@+R\@
M3V)T86EN(&$@=7-E<BUL979E;"!L;V-K+BXN('1H:7,@=VEL;"!R96QE87-E
M(&%N>2!P<F5V:6]U<PH@("`@("`@("\O(&%P<&QI8V%T:6]N(&QO8VMS+"!B
M=70@=6YL:6ME($Q/0TL@5$%"3$53+"!I="!D;V5S(&YO="!A8F]R=`H@("`@
M("`@("\O('1H92!C=7)R96YT('1R86YS86-T:6]N(&%N9"!I<R!M=6-H(&QE
M<W,@9G)E<75E;G1L>2!U<V5D+@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M9V5T3VYE*")314Q%0U0@1T547TQ/0TLH)R1[<V5Q;F%M97U?;&]C:R<L,3`I
M(BD["B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("!I9B`H
M)')E<W5L="`]/2`P*2!["B`@("`@("`@("`@("\O($9A:6QE9"!T;R!G970@
M=&AE(&QO8VLL(&-A;B=T(&1O('1H92!C;VYV97)S:6]N+"!B86EL"B`@("`@
M("`@("`@("\O('=I=&@@82!$0E]%4E)/4E].3U1?3$]#2T5$(&5R<F]R"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^;7ES<6Q286ES945R<F]R*$1"7T52
M4D]27TY/5%],3T-+140I.PH@("`@("`@('T*"B`@("`@("`@)&AI9VAE<W1?
M:60@/2`D=&AI<RT^9V5T3VYE*")314Q%0U0@34%8*&ED*2!&4D]-("1[<V5Q
M;F%M97TB*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)&AI9VAE<W1?:60I
M*2!["B`@("`@("`@("`@(')E='5R;B`D:&EG:&5S=%]I9#L*("`@("`@("!]
M"B`@("`@("`@+R\@5&AI<R!S:&]U;&0@:VEL;"!A;&P@<F]W<R!E>&-E<'0@
M=&AE(&AI9VAE<W0*("`@("`@("`O+R!792!S:&]U;&0@<')O8F%B;'D@9&\@
M<V]M971H:6YG(&EF("1H:6=H97-T7VED(&ES;B=T"B`@("`@("`@+R\@;G5M
M97)I8RP@8G5T($DG;2!A="!A(&QO<W,@87,@:&]W('1O(&AA;F1L92!T:&%T
M+BXN"B`@("`@("`@)')E<W5L="`]("1T:&ES+3YQ=65R>2@G1$5,151%($92
M3TT@)R`N("1S97%N86UE"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`N("(@5TA%4D4@:60@/#X@)&AI9VAE<W1?:60B*3L*("`@("`@("!I9B`H
M1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@?0H*("`@("`@("`O+R!)9B!A;F]T:&5R('1H<F5A
M9"!H87,@8F5E;B!W86ET:6YG(&9O<B!T:&ES(&QO8VLL"B`@("`@("`@+R\@
M:70@=VEL;"!G;R!T:')U('1H92!A8F]V92!P<F]C961U<F4L(&)U="!W:6QL
M(&AA=F4@;F\*("`@("`@("`O+R!R96%L(&5F9F5C=`H@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^9V5T3VYE*")314Q%0U0@4D5,14%315],3T-+*"<D>W-E
M<6YA;65]7VQO8VLG*2(I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S
M=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@<75O=&5)9&5N=&EF:65R*"D*"B`@("`O*BH*("`@("`J(%%U;W1E
M<R!A('-T<FEN9R!S;R!I="!C86X@8F4@<V%F96QY('5S960@87,@82!T86)L
M92!O<B!C;VQU;6X@;F%M90H@("`@("H*("`@("`J($UY4U%,(&-A;B=T(&AA
M;F1L92!T:&4@8F%C:W1I8VL@8VAA<F%C=&5R("@\:V)D/F`\+VMB9#XI(&EN
M"B`@("`@*B!T86)L92!O<B!C;VQU;6X@;F%M97,N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<W1R("!I9&5N=&EF:65R(&YA;64@=&\@8F4@<75O
M=&5D"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('%U;W1E9"!I9&5N
M=&EF:65R('-T<FEN9PH@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIQ
M=6]T94ED96YT:69I97(H*0H@("`@("H@0'-I;F-E($UE=&AO9"!A=F%I;&%B
M;&4@<VEN8V4@4F5L96%S92`Q+C8N,`H@("`@("HO"B`@("!F=6YC=&EO;B!Q
M=6]T94ED96YT:69I97(H)'-T<BD*("`@('L*("`@("`@("!R971U<FX@)V`G
M("X@)'-T<B`N("=@)SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!Q
M=6]T92@I"@H@("`@+RHJ"B`@("`@*B!`9&5P<F5C871E9"`@1&5P<F5C871E
M9"!I;B!R96QE87-E(#$N-BXP"B`@("`@*B\*("`@(&9U;F-T:6]N('%U;W1E
M*"1S='(I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YQ=6]T95-M87)T
M*"1S='(I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5S8V%P95-I
M;7!L92@I"@H@("`@+RHJ"B`@("`@*B!%<V-A<&5S(&$@<W1R:6YG(&%C8V]R
M9&EN9R!T;R!T:&4@8W5R<F5N="!$0DU3)W,@<W1A;F1A<F1S"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<W1R("!T:&4@<W1R:6YG('1O(&)E(&5S
M8V%P960*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&5S8V%P
M960@<W1R:6YG"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G%U;W1E
M4VUA<G0H*0H@("`@("H@0'-I;F-E($UE=&AO9"!A=F%I;&%B;&4@<VEN8V4@
M4F5L96%S92`Q+C8N,`H@("`@("HO"B`@("!F=6YC=&EO;B!E<V-A<&53:6UP
M;&4H)'-T<BD*("`@('L*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=M
M>7-Q;%]R96%L7V5S8V%P95]S=')I;F<G*2D@>PH@("`@("`@("`@("!R971U
M<FX@0&UY<W%L7W)E86Q?97-C87!E7W-T<FEN9R@D<W1R+"`D=&AI<RT^8V]N
M;F5C=&EO;BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M($!M>7-Q;%]E<V-A<&5?<W1R:6YG*"1S='(I.PH@("`@("`@('T*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!M;V1I9GE1=65R>2@I"@H@("`@+RHJ
M"B`@("`@*B!#:&%N9V5S(&$@<75E<GD@<W1R:6YG(&9O<B!V87)I;W5S($1"
M35,@<W!E8VEF:6,@<F5A<V]N<PH@("`@("H*("`@("`J(%1H:7,@;&ET=&QE
M(&AA8VL@;&5T<R!Y;W4@:VYO=R!H;W<@;6%N>2!R;W=S('=E<F4@9&5L971E
M9`H@("`@("H@=VAE;B!R=6YN:6YG(&$@(D1%3$5412!&4D]-('1A8FQE(B!Q
M=65R>2X@($]N;'D@:6UP;&5M96YT960*("`@("`J(&EF('1H92!$0E]03U)4
M04))3$E465]$14Q%5$5?0T]53E0@<&]R=&%B:6QI='D@;W!T:6]N(&ES(&]N
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'%U97)Y("!T:&4@<75E
M<GD@<W1R:6YG('1O(&UO9&EF>0H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!T:&4@;6]D:69I960@<75E<GD@<W1R:6YG"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<F]T96-T960*("`@("`J($!S964@1$)?8V]M;6]N.CIS971/
M<'1I;VXH*0H@("`@("HO"B`@("!F=6YC=&EO;B!M;V1I9GE1=65R>2@D<75E
M<GDI"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I
M;&ET>2==("8@1$)?4$]25$%"24Q)5%E?1$5,151%7T-/54Y4*2!["B`@("`@
M("`@("`@("\O(")$14Q%5$4@1E)/32!T86)L92(@9VEV97,@,"!A9F9E8W1E
M9"!R;W=S(&EN($UY4U%,+@H@("`@("`@("`@("`O+R!4:&ES(&QI='1L92!H
M86-K(&QE=',@>6]U(&MN;W<@:&]W(&UA;GD@<F]W<R!W97)E(&1E;&5T960N
M"B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7EQS*D1%3$5415QS*T92
M3TU<<RLH7%,K*5QS*B0O:2<L("1Q=65R>2DI('L*("`@("`@("`@("`@("`@
M("1Q=65R>2`]('!R96=?<F5P;&%C92@G+UY<<RI$14Q%5$5<<RM&4D]-7',K
M*%Q3*RE<<RHD+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)T1%3$5412!&4D]-(%PQ(%=(15)%(#$],2<L("1Q=65R>2D["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1Q=65R>3L*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!M;V1I9GE,:6UI=%%U97)Y
M*"D*"B`@("`O*BH*("`@("`J($%D9',@3$E-250@8VQA=7-E<R!T;R!A('%U
M97)Y('-T<FEN9R!A8V-O<F1I;F<@=&\@8W5R<F5N="!$0DU3('-T86YD87)D
M<PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'%U97)Y("`@=&AE('%U
M97)Y('1O(&UO9&EF>0H@("`@("H@0'!A<F%M(&EN="`@("`D9G)O;2`@("!T
M:&4@<F]W('1O('-T87)T('1O(&9E=&-H:6YG("@P(#T@=&AE(&9I<G-T(')O
M=RD*("`@("`J($!P87)A;2!I;G0@("`@)&-O=6YT("`@=&AE(&YU;6)E<G,@
M;V8@<F]W<R!T;R!F971C:`H@("`@("H@0'!A<F%M(&UI>&5D("`D<&%R86US
M("!A<G)A>2P@<W1R:6YG(&]R(&YU;65R:6,@9&%T82!T;R!B92!U<V5D(&EN
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!E>&5C=71I;VX@;V8@
M=&AE('-T871E;65N="X@(%%U86YT:71Y(&]F(&ET96US"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!P87-S960@;75S="!M871C:"!Q=6%N=&ET
M>2!O9B!P;&%C96AO;&1E<G,@:6X*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@('%U97)Y.B`@;65A;FEN9R`Q('!L86-E:&]L9&5R(&9O<B!N;VXM
M87)R87D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E
M<G,@;W(@,2!P;&%C96AO;&1E<B!P97(@87)R87D@96QE;65N="X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE('%U97)Y('-T<FEN9R!W:71H
M($Q)34E4(&-L875S97,@861D960*("`@("`J"B`@("`@*B!`86-C97-S('!R
M;W1E8W1E9`H@("`@("HO"B`@("!F=6YC=&EO;B!M;V1I9GE,:6UI=%%U97)Y
M*"1Q=65R>2P@)&9R;VTL("1C;W5N="P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@:68@*$1".CII<TUA;FEP*"1Q=65R>2DI('L*("`@("`@
M("`@("`@<F5T=7)N("1Q=65R>2`N("(@3$E-250@)&-O=6YT(CL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'%U97)Y("X@(B!,24U)
M5"`D9G)O;2P@)&-O=6YT(CL*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@;7ES<6Q286ES945R<F]R*"D*"B`@("`O*BH*("`@("`J
M(%!R;V1U8V5S(&$@1$)?17)R;W(@;V)J96-T(')E9V%R9&EN9R!T:&4@8W5R
M<F5N="!P<F]B;&5M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`D97)R;F\@
M(&EF('1H92!E<G)O<B!I<R!B96EN9R!M86YU86QL>2!R86ES960@<&%S<R!A
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@($1"7T524D]2*B!C;VYS=&%N
M="!H97)E+B`@268@=&AI<R!I<VXG="!P87-S960*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@=&AE(&5R<F]R(&EN9F]R;6%T:6]N(&=A=&AE<F5D(&9R
M;VT@=&AE($1"35,N"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@('1H
M92!$0E]%<G)O<B!O8FIE8W0*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO
M;CHZ<F%I<V5%<G)O<B@I+`H@("`@("H@("`@("!$0E]M>7-Q;#HZ97)R;W).
M871I=F4H*2P@1$)?8V]M;6]N.CIE<G)O<D-O9&4H*0H@("`@("HO"B`@("!F
M=6YC=&EO;B!M>7-Q;%)A:7-E17)R;W(H)&5R<FYO(#T@;G5L;"D*("`@('L*
M("`@("`@("!I9B`H)&5R<FYO(#T]/2!N=6QL*2!["B`@("`@("`@("`@(&EF
M("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,
M25197T524D]24RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F5R<F]R8V]D
M95]M87!;,3`R,ET@/2!$0E]%4E)/4E]#3TY35%)!24Y4.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/F5R<F]R8V]D95]M87!;,3`T.%T@/2!$0E]%4E)/4E]#
M3TY35%)!24Y47TY/5%].54Q,.PH@("`@("`@("`@("`@("`@)'1H:7,M/F5R
M<F]R8V]D95]M87!;,3`V,ET@/2!$0E]%4E)/4E]#3TY35%)!24Y4.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@1&]I;F<@=&AI
M<R!I;B!C87-E(&UO9&4@8VAA;F=E<R!D=7)I;F<@<G5N=&EM92X*("`@("`@
M("`@("`@("`@("1T:&ES+3YE<G)O<F-O9&5?;6%P6S$P,C)=(#T@1$)?15)2
M3U)?04Q214%$65]%6$E35%,["B`@("`@("`@("`@("`@("`D=&AI<RT^97)R
M;W)C;V1E7VUA<%LQ,#0X72`]($1"7T524D]27T-/3E-44D%)3E0["B`@("`@
M("`@("`@("`@("`D=&AI<RT^97)R;W)C;V1E7VUA<%LQ,#8R72`]($1"7T52
M4D]27T%,4D5!1%E?15A)4U13.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1E<G)N;R`]("1T:&ES+3YE<G)O<D-O9&4H;7ES<6Q?97)R;F\H)'1H:7,M
M/F-O;FYE8W1I;VXI*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"1E<G)N;RP@;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@0&UY<W%L7V5R<FYO*"1T:&ES
M+3YC;VYN96-T:6]N*2`N("<@*BH@)R`N"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($!M>7-Q;%]E<G)O<B@D=&AI<RT^8V]N;F5C=&EO;BDI
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5R<F]R3F%T:79E*"D*
M"B`@("`O*BH*("`@("`J($=E=',@=&AE($1"35,G(&YA=&EV92!E<G)O<B!C
M;V1E('!R;V1U8V5D(&)Y('1H92!L87-T('%U97)Y"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G0@('1H92!$0DU3)R!E<G)O<B!C;V1E"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&5R<F]R3F%T:79E*"D*("`@('L*("`@("`@("!R971U<FX@
M0&UY<W%L7V5R<FYO*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!T86)L94EN9F\H*0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!I;F9O<FUA=&EO;B!A8F]U="!A('1A8FQE(&]R(&$@<F5S=6QT
M('-E=`H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W1\<W1R:6YG("`D<F5S
M=6QT("!$0E]R97-U;'0@;V)J96-T(&9R;VT@82!Q=65R>2!O<B!A"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T<FEN9R!C;VYT
M86EN:6YG('1H92!N86UE(&]F(&$@=&%B;&4N"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%=H:6QE('1H:7,@86QS;R!A8V-E<'1S
M(&$@<75E<GD@<F5S=6QT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(')E<V]U<F-E(&ED96YT:69I97(L('1H:7,@8F5H879I;W(@
M:7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9&5P
M<F5C871E9"X*("`@("`J($!P87)A;2!I;G0@("`@("`@("`@("`D;6]D92`@
M("!A('9A;&ED('1A8FQE26YF;R!M;V1E"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@86X@87-S;V-I871I=F4@87)R87D@=VET:"!T:&4@:6YF;W)M
M871I;VX@<F5Q=65S=&5D+@H@("`@("H@("`@("`@("`@("`@("`@($$@1$)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$
M0E]C;VUM;VXZ.G1A8FQE26YF;R@I"B`@("`@*B\*("`@(&9U;F-T:6]N('1A
M8FQE26YF;R@D<F5S=6QT+"`D;6]D92`](&YU;&PI"B`@("!["B`@("`@("`@
M:68@*&ES7W-T<FEN9R@D<F5S=6QT*2D@>PH@("`@("`@("`@("`O*@H@("`@
M("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E9"!A('1A8FQE(&YA;64N"B`@
M("`@("`@("`@("`J($-R96%T92!A(')E<W5L="!R97-O=7)C92!I9&5N=&EF
M:65R+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@)&ED(#T@0&UY<W%L
M7VQI<W1?9FEE;&1S*"1T:&ES+3YD<VY;)V1A=&%B87-E)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5S=6QT+"`D=&AI<RT^
M8V]N;F5C=&EO;BD["B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@=')U93L*
M("`@("`@("!](&5L<V5I9B`H:7-S970H)')E<W5L="T^<F5S=6QT*2D@>PH@
M("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E
M9"!A(')E<W5L="!O8FIE8W0N"B`@("`@("`@("`@("`J($5X=')A8W0@=&AE
M(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@("`@*B\*
M("`@("`@("`@("`@)&ED(#T@)')E<W5L="T^<F5S=6QT.PH@("`@("`@("`@
M("`D9V]T7W-T<FEN9R`](&9A;'-E.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I=F5D(&$@
M<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@("`@("`@("`J($-O
M<'D@:70N"B`@("`@("`@("`@("`J($1E<')E8V%T960N("!(97)E(&9O<B!C
M;VUP871I8FEL:71Y(&]N;'DN"B`@("`@("`@("`@("`J+PH@("`@("`@("`@
M("`D:60@/2`D<F5S=6QT.PH@("`@("`@("`@("`D9V]T7W-T<FEN9R`](&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D:60I
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7ES<6Q286ES945R<F]R
M*$1"7T524D]27TY%141?34]215]$051!*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!
M0DE,25197TQ/5T520T%312D@>PH@("`@("`@("`@("`D8V%S95]F=6YC(#T@
M)W-T<G1O;&]W97(G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C
M87-E7V9U;F,@/2`G<W1R=F%L)SL*("`@("`@("!]"@H@("`@("`@("1C;W5N
M="`]($!M>7-Q;%]N=6U?9FEE;&1S*"1I9"D["B`@("`@("`@)')E<R`@(#T@
M87)R87DH*3L*"B`@("`@("`@:68@*"1M;V1E*2!["B`@("`@("`@("`@("1R
M97-;)VYU;5]F:65L9',G72`]("1C;W5N=#L*("`@("`@("!]"@H@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\("1C;W5N=#L@)&DK*RD@>PH@("`@("`@("`@
M("`D<F5S6R1I72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)W1A8FQE)R`]
M/B`D8V%S95]F=6YC*$!M>7-Q;%]F:65L9%]T86)L92@D:60L("1I*2DL"B`@
M("`@("`@("`@("`@("`G;F%M92<@(#T^("1C87-E7V9U;F,H0&UY<W%L7V9I
M96QD7VYA;64H)&ED+"`D:2DI+`H@("`@("`@("`@("`@("`@)W1Y<&4G("`]
M/B!`;7ES<6Q?9FEE;&1?='EP92@D:60L("1I*2P*("`@("`@("`@("`@("`@
M("=L96XG("`@/3X@0&UY<W%L7V9I96QD7VQE;B@D:60L("1I*2P*("`@("`@
M("`@("`@("`@("=F;&%G<R<@/3X@0&UY<W%L7V9I96QD7V9L86=S*"1I9"P@
M)&DI+`H@("`@("`@("`@("`I.PH@("`@("`@("`@("!I9B`H)&UO9&4@)B!$
M0E]404),14E.1D]?3U)$15(I('L*("`@("`@("`@("`@("`@("1R97-;)V]R
M9&5R)UU;)')E<ULD:5U;)VYA;64G75T@/2`D:3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),14E.1D]?3U)$15)404),
M12D@>PH@("`@("`@("`@("`@("`@)')E<ULG;W)D97)T86)L92==6R1R97-;
M)&E=6R=T86)L92==75LD<F5S6R1I75LG;F%M92==72`]("1I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!F<F5E('1H92!R97-U;'0@
M;VYL>2!I9B!W92!W97)E(&-A;&QE9"!O;B!A('1A8FQE"B`@("`@("`@:68@
M*"1G;W1?<W1R:6YG*2!["B`@("`@("`@("`@($!M>7-Q;%]F<F5E7W)E<W5L
M="@D:60I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')E<SL*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!G9713<&5C:6%L475E<GDH*0H*("`@
M("\J*@H@("`@("H@3V)T86EN<R!T:&4@<75E<GD@<W1R:6YG(&YE961E9"!F
M;W(@;&ES=&EN9R!A(&=I=F5N('1Y<&4@;V8@;V)J96-T<PH@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'1Y<&4@('1H92!K:6YD(&]F(&]B:F5C=',@
M>6]U('=A;G0@=&\@<F5T<FEE=F4*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@=&AE(%-13"!Q=65R>2!S=')I;F<@;W(@;G5L;"!I9B!T:&4@9')I
M=F5R(&1O97-N)W0*("`@("`J("`@("`@("`@("`@("`@("`@<W5P<&]R="!T
M:&4@;V)J96-T('1Y<&4@<F5Q=65S=&5D"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<F]T96-T960*("`@("`J($!S964@1$)?8V]M;6]N.CIG971,:7-T3V8H
M*0H@("`@("HO"B`@("!F=6YC=&EO;B!G9713<&5C:6%L475E<GDH)'1Y<&4I
M"B`@("!["B`@("`@("`@<W=I=&-H("@D='EP92D@>PH@("`@("`@("`@("!C
M87-E("=T86)L97,G.@H@("`@("`@("`@("`@("`@<F5T=7)N("=32$]7(%1!
M0DQ%4R<["B`@("`@("`@("`@(&-A<V4@)W5S97)S)SH*("`@("`@("`@("`@
M("`@(')E='5R;B`G4T5,14-4($1)4U1)3D-4(%5S97(@1E)/32!M>7-Q;"YU
M<V5R)SL*("`@("`@("`@("`@8V%S92`G9&%T86)A<V5S)SH*("`@("`@("`@
M("`@("`@(')E='5R;B`G4TA/5R!$051!0D%315,G.PH@("`@("`@("`@("!D
M969A=6QT.@H@("`@("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@
M?0H@("`@?0H*("`@("\O('U]?0H*?0H*+RH*("H@3&]C86P@=F%R:6%B;&5S
M.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z(#0*("H@16YD
M.@H@*B\*"C\^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+T1"+VUY<W%L:2YP:'``````````````````
M`````````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3`R,3(R`#$P-3$U-#,S-S,V
M`#`R,3$R,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`H*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S
M:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!4:&4@4$5!
M4B!$0B!D<FEV97(@9F]R(%!(4"=S(&UY<W%L:2!E>'1E;G-I;VX*("H@9F]R
M(&EN=&5R86-T:6YG('=I=&@@37E344P@9&%T86)A<V5S"B`J"B`J(%!(4"!V
M97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I
M;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N
M<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED
M92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E
M(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@
M=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@
M82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S
M90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!$86YI96P@0V]N
M=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M
M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`
M=F5R<VEO;B`@("!#5E,Z("1)9#H@;7ES<6QI+G!H<"QV(#$N-CD@,C`P-2\P
M,R\P-"`R,SHQ,CHS-B!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*"B\J*@H@*B!/8G1A
M:6X@=&AE($1"7V-O;6UO;B!C;&%S<R!S;R!I="!C86X@8F4@97AT96YD960@
M9G)O;0H@*B\*<F5Q=6ER95]O;F-E("=$0B]C;VUM;VXN<&AP)SL*"B\J*@H@
M*B!4:&4@;65T:&]D<R!014%2($1"('5S97,@=&\@:6YT97)A8W0@=VET:"!0
M2%`G<R!M>7-Q;&D@97AT96YS:6]N"B`J(&9O<B!I;G1E<F%C=&EN9R!W:71H
M($UY4U%,(&1A=&%B87-E<PH@*@H@*B!4:&ES(&ES(&9O<B!->5-13"!V97)S
M:6]N<R`T+C$@86YD(&%B;W9E+B`@4F5Q=6ER97,@4$A0(#4N"B`J"B`J($YO
M=&4@=&AA="!P97)S:7-T96YT(&-O;FYE8W1I;VYS(&YO(&QO;F=E<B!E>&ES
M="X*("H*("H@5&AE<V4@;65T:&]D<R!O=F5R;&]A9"!T:&4@;VYE<R!D96-L
M87)E9"!I;B!$0E]C;VUM;VXN"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E
M"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV
M:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR
M,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V
M97)S:6]N("`@(%)E;&5A<V4Z(#$N-RXV"B`J($!L:6YK("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B!`<VEN8V4@("`@("!#;&%S
M<R!F=6YC=&EO;F%L('-I;F-E(%)E;&5A<V4@,2XV+C,*("HO"F-L87-S($1"
M7VUY<W%L:2!E>'1E;F1S($1"7V-O;6UO;@I["B`@("`O+R![>WL@<')O<&5R
M=&EE<PH*("`@("\J*@H@("`@("H@5&AE($1"(&1R:79E<B!T>7!E("AM>7-Q
M;"P@;V-I."P@;V1B8RP@971C+BD*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D<&AP='EP92`]("=M>7-Q;&DG.PH*("`@("\J*@H@("`@
M("H@5&AE(&1A=&%B87-E('-Y;G1A>"!V87)I86YT('1O(&)E('5S960@*&1B
M,BP@86-C97-S+"!E=&,N*2P@:68@86YY"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)&1B<WEN=&%X(#T@)VUY<W%L:2<["@H@("`@+RHJ
M"B`@("`@*B!4:&4@8V%P86)I;&ET:65S(&]F('1H:7,@1$(@:6UP;&5M96YT
M871I;VX*("`@("`J"B`@("`@*B!4:&4@)VYE=U]L:6YK)R!E;&5M96YT(&-O
M;G1A:6YS('1H92!02%`@=F5R<VEO;B!T:&%T(&9I<G-T('!R;W9I9&5D"B`@
M("`@*B!N97=?;&EN:R!S=7!P;W)T(&9O<B!T:&ES($1"35,N("!#;VYT86EN
M<R!F86QS92!I9B!I="=S('5N<W5P<&]R=&5D+@H@("`@("H*("`@("`J($UE
M86YI;F<@;V8@=&AE("=L:6UI="<@96QE;65N=#H*("`@("`J("`@*R`G96UU
M;&%T92<@/2!E;75L871E('=I=&@@9F5T8V@@<F]W(&)Y(&YU;6)E<@H@("`@
M("H@("`K("=A;'1E<B<@("`](&%L=&5R('1H92!Q=65R>0H@("`@("H@("`K
M(&9A;'-E("`@("`]('-K:7`@<F]W<PH@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1F96%T=7)E<R`](&%R<F%Y*`H@("`@("`@
M("=L:6UI="<@("`@("`@("`]/B`G86QT97(G+`H@("`@("`@("=N97=?;&EN
M:R<@("`@("`]/B!F86QS92P*("`@("`@("`G;G5M<F]W<R<@("`@("`@/3X@
M=')U92P*("`@("`@("`G<&-O;FYE8W0G("`@("`@/3X@9F%L<V4L"B`@("`@
M("`@)W!R97!A<F4G("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=S<VPG("`@
M("`@("`@("`]/B!T<G5E+`H@("`@("`@("=T<F%N<V%C=&EO;G,G("`]/B!T
M<G5E+`H@("`@*3L*"B`@("`O*BH*("`@("`J($$@;6%P<&EN9R!O9B!N871I
M=F4@97)R;W(@8V]D97,@=&\@1$(@97)R;W(@8V]D97,*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1E<G)O<F-O9&5?;6%P(#T@87)R87DH
M"B`@("`@("`@,3`P-"`]/B!$0E]%4E)/4E]#04Y.3U1?0U)%051%+`H@("`@
M("`@(#$P,#4@/3X@1$)?15)23U)?0T%.3D]47T-214%412P*("`@("`@("`Q
M,#`V(#T^($1"7T524D]27T-!3DY/5%]#4D5!5$4L"B`@("`@("`@,3`P-R`]
M/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*("`@("`@("`Q,#`X(#T^($1"
M7T524D]27T-!3DY/5%]$4D]0+`H@("`@("`@(#$P,C(@/3X@1$)?15)23U)?
M04Q214%$65]%6$E35%,L"B`@("`@("`@,3`T-"`]/B!$0E]%4E)/4E]!0T-%
M4U-?5DE/3$%424].+`H@("`@("`@(#$P-#8@/3X@1$)?15)23U)?3D]$0E-%
M3$5#5$5$+`H@("`@("`@(#$P-#@@/3X@1$)?15)23U)?0T].4U1204E.5"P*
M("`@("`@("`Q,#0Y(#T^($1"7T524D]27TY/4U5#2$1"+`H@("`@("`@(#$P
M-3`@/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@("`@("`@,3`U,2`]
M/B!$0E]%4E)/4E].3U-50TA404),12P*("`@("`@("`Q,#4T(#T^($1"7T52
M4D]27TY/4U5#2$9)14Q$+`H@("`@("`@(#$P-C$@/3X@1$)?15)23U)?04Q2
M14%$65]%6$E35%,L"B`@("`@("`@,3`V,B`]/B!$0E]%4E)/4E]!3%)%0419
M7T5825-44RP*("`@("`@("`Q,#8T(#T^($1"7T524D]27U-93E1!6"P*("`@
M("`@("`Q,#DQ(#T^($1"7T524D]27TY/5%]&3U5.1"P*("`@("`@("`Q,3`P
M(#T^($1"7T524D]27TY/5%],3T-+140L"B`@("`@("`@,3$S-B`]/B!$0E]%
M4E)/4E]604Q515]#3U5.5%]/3E]23U<L"B`@("`@("`@,3$T,B`]/B!$0E]%
M4E)/4E]!0T-%4U-?5DE/3$%424].+`H@("`@("`@(#$Q-#8@/3X@1$)?15)2
M3U)?3D]354-(5$%"3$4L"B`@("`@("`@,3(Q-B`]/B!$0E]%4E)/4E]#3TY3
M5%)!24Y4+`H@("`@("`@(#$R,3<@/3X@1$)?15)23U)?0T].4U1204E.5"P*
M("`@("D["@H@("`@+RHJ"B`@("`@*B!4:&4@<F%W(&1A=&%B87-E(&-O;FYE
M8W1I;VX@8W)E871E9"!B>2!02%`*("`@("`J($!V87(@<F5S;W5R8V4*("`@
M("`J+PH@("`@=F%R("1C;VYN96-T:6]N.PH*("`@("\J*@H@("`@("H@5&AE
M($133B!I;F9O<FUA=&EO;B!F;W(@8V]N;F5C=&EN9R!T;R!A(&1A=&%B87-E
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D9'-N(#T@87)R
M87DH*3L*"@H@("`@+RHJ"B`@("`@*B!3:&]U;&0@9&%T82!M86YI<'5L871I
M;VX@<75E<FEE<R!B92!C;VUM:71T960@875T;VUA=&EC86QL>3\*("`@("`J
M($!V87(@8F]O;`H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M('9A<B`D875T;V-O;6UI="`]('1R=64["@H@("`@+RHJ"B`@("`@*B!4:&4@
M<75A;G1I='D@;V8@=')A;G-A8W1I;VYS(&)E9W5N"B`@("`@*@H@("`@("H@
M>T!I;G1E<FYA;"`@5VAI;&4@=&AI<R!I<R!P<FEV871E+"!I="!C86XG="!A
M8W1U86QL>2!B92!D97-I9VYA=&5D"B`@("`@*B!P<FEV871E(&EN(%!(4"`U
M(&)E8V%U<V4@:70@:7,@9&ER96-T;'D@86-C97-S960@:6X@=&AE('1E<W0@
M<W5I=&4N?7T*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)'1R86YS86-T:6]N7V]P
M8V]U;G0@/2`P.PH*("`@("\J*@H@("`@("H@5&AE(&1A=&%B87-E('-P96-I
M9FEE9"!I;B!T:&4@1%-."B`@("`@*@H@("`@("H@270G<R!A(&9I>"!T;R!A
M;&QO=R!C86QL<R!T;R!D:69F97)E;G0@9&%T86)A<V5S(&EN('1H92!S86UE
M('-C<FEP="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7V1B(#T@)R<["@H@("`@
M+RHJ"B`@("`@*B!!<G)A>2!F;W(@8V]N=F5R=&EN9R!-65-13$E?*E]&3$%'
M(&-O;G-T86YT<R!T;R!T97AT('9A;'5E<PH@("`@("H@0'9A<B`@("!A<G)A
M>0H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S:6YC92`@4')O<&5R
M='D@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XV+C4*("`@("`J+PH@("`@
M=F%R("1M>7-Q;&E?9FQA9W,@/2!A<G)A>2@*("`@("`@("!-65-13$E?3D]4
M7TY53$Q?1DQ!1R`@("`@("`@/3X@)VYO=%]N=6QL)RP*("`@("`@("!-65-1
M3$E?4%))7TM%65]&3$%'("`@("`@("`@/3X@)W!R:6UA<GE?:V5Y)RP*("`@
M("`@("!-65-13$E?54Y)455%7TM%65]&3$%'("`@("`@/3X@)W5N:7%U95]K
M97DG+`H@("`@("`@($U94U%,25]-54Q425!,15]+15E?1DQ!1R`@("`]/B`G
M;75L=&EP;&5?:V5Y)RP*("`@("`@("!-65-13$E?0DQ/0E]&3$%'("`@("`@
M("`@("`@/3X@)V)L;V(G+`H@("`@("`@($U94U%,25]53E-)1TY%1%]&3$%'
M("`@("`@("`]/B`G=6YS:6=N960G+`H@("`@("`@($U94U%,25]:15)/1DE,
M3%]&3$%'("`@("`@("`]/B`G>F5R;V9I;&PG+`H@("`@("`@($U94U%,25]!
M551/7TE.0U)%345.5%]&3$%'("`]/B`G875T;U]I;F-R96UE;G0G+`H@("`@
M("`@($U94U%,25]424U%4U1!35!?1DQ!1R`@("`@("`]/B`G=&EM97-T86UP
M)RP*("`@("`@("!-65-13$E?4T547T9,04<@("`@("`@("`@("`@/3X@)W-E
M="<L"B`@("`@("`@+R\@35E344Q)7TY535]&3$%'("`@("`@("`@("`@(#T^
M("=N=6UE<FEC)RP@("\O('5N;F5C97-S87)Y"B`@("`@("`@+R\@35E344Q)
M7U!!4E1?2T597T9,04<@("`@("`@(#T^("=M=6QT:7!L95]K97DG+"`@+R\@
M9'5P;&EC871V:64*("`@("`@("!-65-13$E?1U)/55!?1DQ!1R`@("`@("`@
M("`@/3X@)V=R;W5P7V)Y)PH@("`@*3L*"B`@("`O*BH*("`@("`J($%R<F%Y
M(&9O<B!C;VYV97)T:6YG($U94U%,25]465!%7RH@8V]N<W1A;G1S('1O('1E
M>'0@=F%L=65S"B`@("`@*B!`=F%R("`@(&%R<F%Y"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H@0'-I;F-E("!0<F]P97)T>2!A=F%I;&%B;&4@<VEN
M8V4@4F5L96%S92`Q+C8N-0H@("`@("HO"B`@("!V87(@)&UY<W%L:5]T>7!E
M<R`](&%R<F%Y*`H@("`@("`@($U94U%,25]465!%7T1%0TE-04P@("`@(#T^
M("=D96-I;6%L)RP*("`@("`@("!-65-13$E?5%E015]424Y9("`@("`@("`]
M/B`G=&EN>6EN="<L"B`@("`@("`@35E344Q)7U194$5?4TA/4E0@("`@("`@
M/3X@)VEN="<L"B`@("`@("`@35E344Q)7U194$5?3$].1R`@("`@("`@/3X@
M)VEN="<L"B`@("`@("`@35E344Q)7U194$5?1DQ/050@("`@("`@/3X@)V9L
M;V%T)RP*("`@("`@("!-65-13$E?5%E015]$3U5"3$4@("`@("`]/B`G9&]U
M8FQE)RP*("`@("`@("`O+R!-65-13$E?5%E015].54Q,("`@("`@("`]/B`G
M1$5&055,5"!.54Q,)RP@("\O(&QE="!F;&%G<R!H86YD;&4@:70*("`@("`@
M("!-65-13$E?5%E015]424U%4U1!35`@("`]/B`G=&EM97-T86UP)RP*("`@
M("`@("!-65-13$E?5%E015],3TY'3$].1R`@("`]/B`G8FEG:6YT)RP*("`@
M("`@("!-65-13$E?5%E015])3E0R-"`@("`@("`]/B`G;65D:75M:6YT)RP*
M("`@("`@("!-65-13$E?5%E015]$051%("`@("`@("`]/B`G9&%T92<L"B`@
M("`@("`@35E344Q)7U194$5?5$E-12`@("`@("`@/3X@)W1I;64G+`H@("`@
M("`@($U94U%,25]465!%7T1!5$5424U%("`@(#T^("=D871E=&EM92<L"B`@
M("`@("`@35E344Q)7U194$5?645!4B`@("`@("`@/3X@)WEE87(G+`H@("`@
M("`@($U94U%,25]465!%7TY%5T1!5$4@("`@(#T^("=D871E)RP*("`@("`@
M("!-65-13$E?5%E015]%3E5-("`@("`@("`]/B`G96YU;2<L"B`@("`@("`@
M35E344Q)7U194$5?4T54("`@("`@("`@/3X@)W-E="<L"B`@("`@("`@35E3
M44Q)7U194$5?5$E.65]"3$]"("`@/3X@)W1I;GEB;&]B)RP*("`@("`@("!-
M65-13$E?5%E015]-141)54U?0DQ/0B`]/B`G;65D:75M8FQO8B<L"B`@("`@
M("`@35E344Q)7U194$5?3$].1U]"3$]"("`@/3X@)VQO;F=B;&]B)RP*("`@
M("`@("!-65-13$E?5%E015]"3$]"("`@("`@("`]/B`G8FQO8B<L"B`@("`@
M("`@35E344Q)7U194$5?5D%27U-44DE.1R`@/3X@)W9A<F-H87(G+`H@("`@
M("`@($U94U%,25]465!%7U-44DE.1R`@("`@(#T^("=C:&%R)RP*("`@("`@
M("!-65-13$E?5%E015]'14]-151262`@("`]/B`G9V5O;65T<GDG+`H@("`@
M*3L*"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@("`O
M*BH*("`@("`J(%1H:7,@8V]N<W1R=6-T;W(@8V%L;',@/&MB9#XD=&AI<RT^
M1$)?8V]M;6]N*"D\+VMB9#X*("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*
M("`@("`J+PH@("`@9G5N8W1I;VX@1$)?;7ES<6QI*"D*("`@('L*("`@("`@
M("`D=&AI<RT^1$)?8V]M;6]N*"D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@*B!#;VYN96-T('1O('1H
M92!D871A8F%S92!S97)V97(L(&QO9R!I;B!A;F0@;W!E;B!T:&4@9&%T86)A
M<V4*("`@("`J"B`@("`@*B!$;VXG="!C86QL('1H:7,@;65T:&]D(&1I<F5C
M=&QY+B`@57-E($1".CIC;VYN96-T*"D@:6YS=&5A9"X*("`@("`J"B`@("`@
M*B!014%2($1")W,@;7ES<6QI(&1R:79E<B!S=7!P;W)T<R!T:&4@9F]L;&]W
M:6YG(&5X=')A($133B!O<'1I;VYS.@H@("`@("H@("`K(%=H96X@=&AE("=S
M<VPG("1O<'1I;VX@<&%S<V5D('1O($1".CIC;VYN96-T*"D@:7,@=')U93H*
M("`@("`J("`@("`K(&ME>2`@("`@(%1H92!P871H('1O('1H92!K97D@9FEL
M92X*("`@("`J("`@("`K(&-E<G0@("`@(%1H92!P871H('1O('1H92!C97)T
M:69I8V%T92!F:6QE+@H@("`@("H@("`@("L@8V$@("`@("`@5&AE('!A=&@@
M=&\@=&AE(&-E<G1I9FEC871E(&%U=&AO<FET>2!F:6QE+@H@("`@("H@("`@
M("L@8V%P871H("`@5&AE('!A=&@@=&\@82!D:7)E8W1O<GD@=&AA="!C;VYT
M86EN<R!T<G5S=&5D(%-33`H@("`@("H@("`@("`@("`@("`@("`@($-!(&-E
M<G1I9FEC871E<R!I;B!P96T@9F]R;6%T+@H@("`@("H@("`@("L@8VEP:&5R
M("`@5&AE(&QI<W0@;V8@86QL;W=A8FQE(&-I<&AE<G,@9F]R(%-33"!E;F-R
M>7!T:6]N+@H@("`@("H*("`@("`J($5X86UP;&4@;V8@:&]W('1O(&-O;FYE
M8W0@=7-I;F<@4U-,.@H@("`@("H@/&-O9&4^"B`@("`@*B!R97%U:7)E7V]N
M8V4@)T1"+G!H<"<["B`@("`@*B`*("`@("`J("1D<VX@/2!A<G)A>2@*("`@
M("`J("`@("`G<&AP='EP92<@(#T^("=M>7-Q;&DG+`H@("`@("H@("`@("=U
M<V5R;F%M92<@/3X@)W-O;65U<V5R)RP*("`@("`J("`@("`G<&%S<W=O<F0G
M(#T^("=A<&%S<W=D)RP*("`@("`J("`@("`G:&]S='-P96,G(#T^("=L;V-A
M;&AO<W0G+`H@("`@("H@("`@("=D871A8F%S92<@/3X@)W1H961B)RP*("`@
M("`J("`@("`G:V5Y)R`@("`@(#T^("=C;&EE;G0M:V5Y+G!E;2<L"B`@("`@
M*B`@("`@)V-E<G0G("`@("`]/B`G8VQI96YT+6-E<G0N<&5M)RP*("`@("`J
M("`@("`G8V$G("`@("`@(#T^("=C86-E<G0N<&5M)RP*("`@("`J("`@("`G
M8V%P871H)R`@(#T^("<O<&%T:"]T;R]C82]D:7(G+`H@("`@("H@("`@("=C
M:7!H97(G("`@/3X@)T%%4R<L"B`@("`@*B`I.PH@("`@("H@"B`@("`@*B`D
M;W!T:6]N<R`](&%R<F%Y*`H@("`@("H@("`@("=S<VPG(#T^('1R=64L"B`@
M("`@*B`I.PH@("`@("H@"B`@("`@*B`D9&(@/28@1$(Z.F-O;FYE8W0H)&1S
M;BP@)&]P=&EO;G,I.PH@("`@("H@:68@*%!%05(Z.FES17)R;W(H)&1B*2D@
M>PH@("`@("H@("`@(&1I92@D9&(M/F=E=$UE<W-A9V4H*2D["B`@("`@*B!]
M"B`@("`@*B`\+V-O9&4^"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1D
M<VX@("`@("`@("!T:&4@9&%T82!S;W5R8V4@;F%M90H@("`@("H@0'!A<F%M
M(&)O;VP@("1P97)S:7-T96YT("!S:&]U;&0@=&AE(&-O;FYE8W1I;VX@8F4@
M<&5R<VES=&5N=#\*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@
M;VX@<W5C8V5S<RX@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@8V]N;F5C="@D9'-N+"`D<&5R<VES=&5N="`]
M(&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@A4$5!4CHZ;&]A9$5X=&5N<VEO
M;B@G;7ES<6QI)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*$1"7T524D]27T585$5.4TE/3E].3U1?1D]53D0I.PH@("`@("`@
M('T*"B`@("`@("`@)'1H:7,M/F1S;B`]("1D<VX["B`@("`@("`@:68@*"1D
M<VY;)V1B<WEN=&%X)UTI('L*("`@("`@("`@("`@)'1H:7,M/F1B<WEN=&%X
M(#T@)&1S;ELG9&)S>6YT87@G73L*("`@("`@("!]"@H@("`@("`@("1I;FD@
M/2!I;FE?9V5T*"=T<F%C:U]E<G)O<G,G*3L*("`@("`@("!I;FE?<V5T*"=T
M<F%C:U]E<G)O<G,G+"`Q*3L*("`@("`@("`D<&AP7V5R<F]R;7-G(#T@)R<[
M"@H@("`@("`@(&EF("@D=&AI<RT^9V5T3W!T:6]N*"=S<VPG*2`]/3T@=')U
M92D@>PH@("`@("`@("`@("`D:6YI="`](&UY<W%L:5]I;FET*"D["B`@("`@
M("`@("`@(&UY<W%L:5]S<VQ?<V5T*`H@("`@("`@("`@("`@("`@)&EN:70L
M"B`@("`@("`@("`@("`@("!E;7!T>2@D9'-N6R=K97DG72D@("`@/R!N=6QL
M(#H@)&1S;ELG:V5Y)UTL"B`@("`@("`@("`@("`@("!E;7!T>2@D9'-N6R=C
M97)T)UTI("`@/R!N=6QL(#H@)&1S;ELG8V5R="==+`H@("`@("`@("`@("`@
M("`@96UP='DH)&1S;ELG8V$G72D@("`@(#\@;G5L;"`Z("1D<VY;)V-A)UTL
M"B`@("`@("`@("`@("`@("!E;7!T>2@D9'-N6R=C87!A=&@G72D@/R!N=6QL
M(#H@)&1S;ELG8V%P871H)UTL"B`@("`@("`@("`@("`@("!E;7!T>2@D9'-N
M6R=C:7!H97(G72D@/R!N=6QL(#H@)&1S;ELG8VEP:&5R)UT*("`@("`@("`@
M("`@*3L*("`@("`@("`@("`@:68@*"1T:&ES+3YC;VYN96-T:6]N(#T@0&UY
M<W%L:5]R96%L7V-O;FYE8W0H"B`@("`@("`@("`@("`@("`@("`@)&EN:70L
M"B`@("`@("`@("`@("`@("`@("`@)&1S;ELG:&]S='-P96,G72P*("`@("`@
M("`@("`@("`@("`@("`D9'-N6R=U<V5R;F%M92==+`H@("`@("`@("`@("`@
M("`@("`@("1D<VY;)W!A<W-W;W)D)UTL"B`@("`@("`@("`@("`@("`@("`@
M)&1S;ELG9&%T86)A<V4G72P*("`@("`@("`@("`@("`@("`@("`D9'-N6R=P
M;W)T)UTL"B`@("`@("`@("`@("`@("`@("`@)&1S;ELG<V]C:V5T)UTI*0H@
M("`@("`@("`@("!["B`@("`@("`@("`@("`@("`D=&AI<RT^8V]N;F5C=&EO
M;B`]("1I;FET.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!`;7ES<6QI7V-O;FYE8W0H
M"B`@("`@("`@("`@("`@("`D9'-N6R=H;W-T<W!E8R==+`H@("`@("`@("`@
M("`@("`@)&1S;ELG=7-E<FYA;64G72P*("`@("`@("`@("`@("`@("1D<VY;
M)W!A<W-W;W)D)UTL"B`@("`@("`@("`@("`@("`D9'-N6R=D871A8F%S92==
M+`H@("`@("`@("`@("`@("`@)&1S;ELG<&]R="==+`H@("`@("`@("`@("`@
M("`@)&1S;ELG<V]C:V5T)UT*("`@("`@("`@("`@*3L*("`@("`@("!]"@H@
M("`@("`@(&EN:5]S970H)W1R86-K7V5R<F]R<R<L("1I;FDI.PH*("`@("`@
M("!I9B`H(21T:&ES+3YC;VYN96-T:6]N*2!["B`@("`@("`@("`@(&EF("@H
M)&5R<B`]($!M>7-Q;&E?8V]N;F5C=%]E<G)O<B@I*2`A/2`G)RD@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]2
M7T-/3DY%0U1?1D%)3$5$+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&YU;&PL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5R<BD["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H1$)?15)23U)?0T].3D5#5%]&04E,140L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&AP
M7V5R<F]R;7-G*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M:68@*"1D<VY;)V1A=&%B87-E)UTI('L*("`@("`@("`@("`@)'1H:7,M/E]D
M8B`]("1D<VY;)V1A=&%B87-E)UT["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9&ES8V]N
M;F5C="@I"@H@("`@+RHJ"B`@("`@*B!$:7-C;VYN96-T<R!F<F]M('1H92!D
M871A8F%S92!S97)V97(*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@(%12
M544@;VX@<W5C8V5S<RP@1D%,4T4@;VX@9F%I;'5R90H@("`@("HO"B`@("!F
M=6YC=&EO;B!D:7-C;VYN96-T*"D*("`@('L*("`@("`@("`D<F5T(#T@0&UY
M<W%L:5]C;&]S92@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@)'1H:7,M
M/F-O;FYE8W1I;VX@/2!N=6QL.PH@("`@("`@(')E='5R;B`D<F5T.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[('-I;7!L95%U97)Y*"D*"B`@("`O
M*BH*("`@("`J(%-E;F1S(&$@<75E<GD@=&\@=&AE(&1A=&%B87-E('-E<G9E
M<@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@('1H92!344P@<75E<GD@
M<W1R:6YG"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@*R!A(%!(4"!R
M97-U;'0@<F5S<F]U8V4@9F]R('-U8V-E<W-F=6P@4T5,14-4('%U97)I97,*
M("`@("`J("`@("`@("`@("`@("`@("L@=&AE($1"7T]+(&-O;G-T86YT(&9O
M<B!O=&AE<B!S=6-C97-S9G5L('%U97)I97,*("`@("`J("`@("`@("`@("`@
M("`@("L@82!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R90H@("`@("HO"B`@
M("!F=6YC=&EO;B!S:6UP;&51=65R>2@D<75E<GDI"B`@("!["B`@("`@("`@
M)&ES;6%N:7`@/2!$0CHZ:7--86YI<"@D<75E<GDI.PH@("`@("`@("1T:&ES
M+3YL87-T7W%U97)Y(#T@)'%U97)Y.PH@("`@("`@("1Q=65R>2`]("1T:&ES
M+3YM;V1I9GE1=65R>2@D<75E<GDI.PH@("`@("`@(&EF("@D=&AI<RT^7V1B
M*2!["B`@("`@("`@("`@(&EF("@A0&UY<W%L:5]S96QE8W1?9&(H)'1H:7,M
M/F-O;FYE8W1I;VXL("1T:&ES+3Y?9&(I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/FUY<W%L:5)A:7-E17)R;W(H1$)?15)23U)?3D]$0E-%
M3$5#5$5$*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H
M(21T:&ES+3YA=71O8V]M;6ET("8F("1I<VUA;FEP*2!["B`@("`@("`@("`@
M(&EF("@D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`]/2`P*2!["B`@("`@
M("`@("`@("`@("`D<F5S=6QT(#T@0&UY<W%L:5]Q=65R>2@D=&AI<RT^8V]N
M;F5C=&EO;BP@)U-%5"!!551/0T]-34E4/3`G*3L*("`@("`@("`@("`@("`@
M("1R97-U;'0@/2!`;7ES<6QI7W%U97)Y*"1T:&ES+3YC;VYN96-T:6]N+"`G
M0D5'24XG*3L*("`@("`@("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7ES<6QI4F%I<V5%<G)O
M<B@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT*RL["B`@("`@("`@?0H@
M("`@("`@("1R97-U;'0@/2!`;7ES<6QI7W%U97)Y*"1T:&ES+3YC;VYN96-T
M:6]N+"`D<75E<GDI.PH@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/FUY<W%L:5)A:7-E17)R;W(H*3L*("`@("`@
M("!]"B`@("`@("`@:68@*&ES7V]B:F5C="@D<F5S=6QT*2D@>PH@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YE>'1297-U
M;'0H*0H*("`@("\J*@H@("`@("H@36]V92!T:&4@:6YT97)N86P@;7ES<6P@
M<F5S=6QT('!O:6YT97(@=&\@=&AE(&YE>'0@879A:6QA8FQE(')E<W5L="X*
M("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!H87,@;F]T(&)E96X@:6UP;&5M
M96YT960@>65T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S
M=6QT(&$@=F%L:60@<W%L(')E<W5L="!R97-O=7)C90H@("`@("H@0')E='5R
M;B!F86QS90H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@;F5X=%)E<W5L="@D<F5S=6QT*0H@("`@>PH@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F971C:$EN
M=&\H*0H*("`@("\J*@H@("`@("H@4&QA8V5S(&$@<F]W(&9R;VT@=&AE(')E
M<W5L="!S970@:6YT;R!T:&4@9VEV96X@87)R87D*("`@("`J"B`@("`@*B!&
M;W)M871I;F<@;V8@=&AE(&%R<F%Y(&%N9"!T:&4@9&%T82!T:&5R96EN(&%R
M92!C;VYF:6=U<F%B;&4N"B`@("`@*B!3964@1$)?<F5S=6QT.CIF971C:$EN
M=&\H*2!F;W(@;6]R92!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!4:&ES
M(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@
M57-E"B`@("`@*B!$0E]R97-U;'0Z.F9E=&-H26YT;R@I(&EN<W1E860N("!)
M="!C86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S
M92!$0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@("`@=&AE('%U97)Y(')E<W5L
M="!R97-O=7)C90H@("`@("H@0'!A<F%M(&%R<F%Y("`@("1A<G(@("`@("`@
M=&AE(')E9F5R96YC960@87)R87D@=&\@<'5T('1H92!D871A(&EN"B`@("`@
M*B!`<&%R86T@:6YT("`@("`@)&9E=&-H;6]D92!H;W<@=&AE(')E<W5L=&EN
M9R!A<G)A>2!S:&]U;&0@8F4@:6YD97AE9`H@("`@("H@0'!A<F%M(&EN="`@
M("`@("1R;W=N=6T@("`@=&AE(')O=R!N=6UB97(@=&\@9F5T8V@@*#`@/2!F
M:7)S="!R;W<I"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1$)?3TL@
M;VX@<W5C8V5S<RP@3E5,3"!W:&5N('1H92!E;F0@;V8@82!R97-U;'0@<V5T
M(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@<F5A8VAE9"!O<B!O;B!F86EL
M=7)E"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&9E=&-H26YT;R@D<F5S=6QT+"`F)&%R
M<BP@)&9E=&-H;6]D92P@)')O=VYU;2`](&YU;&PI"B`@("!["B`@("`@("`@
M:68@*"1R;W=N=6T@(3T](&YU;&PI('L*("`@("`@("`@("`@:68@*"%`;7ES
M<6QI7V1A=&%?<V5E:R@D<F5S=6QT+"`D<F]W;G5M*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@:68@*"1F971C:&UO9&4@)B!$0E]&151#2$U/1$5?05-33T,I('L*
M("`@("`@("`@("`@)&%R<B`]($!M>7-Q;&E?9F5T8VA?87)R87DH)')E<W5L
M="P@35E344Q)7T%34T]#*3L*("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I
M;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3$]715)#05-%
M("8F("1A<G(I('L*("`@("`@("`@("`@("`@("1A<G(@/2!A<G)A>5]C:&%N
M9V5?:V5Y7V-A<V4H)&%R<BP@0T%315],3U=%4BD["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D87)R(#T@0&UY<W%L:5]F
M971C:%]R;W<H)')E<W5L="D["B`@("`@("`@?0H@("`@("`@(&EF("@A)&%R
M<BD@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@
M("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]2
M5$%"24Q)5%E?4E1224TI('L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@
M("H@179E;B!T:&]U9V@@=&AI<R!$0DU3(&%L<F5A9'D@=')I;7,@;W5T<'5T
M+"!W92!D;R!T:&ES(&)E8V%U<V4*("`@("`@("`@("`@("H@82!F:65L9"!M
M:6=H="!H879E(&EN=&5N=&EO;F%L('=H:71E<W!A8V4@870@=&AE(&5N9"!T
M:&%T"B`@("`@("`@("`@("`J(&=E=',@<F5M;W9E9"!B>2!$0E]03U)404))
M3$E465]25%))32!U;F1E<B!A;F]T:&5R(&1R:79E<BX*("`@("`@("`@("`@
M("HO"B`@("`@("`@("`@("1T:&ES+3Y?<G1R:6U!<G)A>59A;'5E<R@D87)R
M*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T
M86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3E5,3%]43U]%35!462D@>PH@
M("`@("`@("`@("`D=&AI<RT^7V-O;G9E<G1.=6QL07)R87E686QU97-4;T5M
M<'1Y*"1A<G(I.PH@("`@("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9G)E95)E<W5L="@I"@H@("`@
M+RHJ"B`@("`@*B!$96QE=&5S('1H92!R97-U;'0@<V5T(&%N9"!F<F5E<R!T
M:&4@;65M;W)Y(&]C8W5P:65D(&)Y('1H92!R97-U;'0@<V5T"B`@("`@*@H@
M("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D
M:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIF<F5E*"D@:6YS=&5A
M9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B
M96-A=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@
M<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("!4
M4E5%(&]N('-U8V-E<W,L($9!3%-%(&EF("1R97-U;'0@:7,@:6YV86QI9`H@
M("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIF<F5E*"D*("`@("`J+PH@
M("`@9G5N8W1I;VX@9G)E95)E<W5L="@D<F5S=6QT*0H@("`@>PH@("`@("`@
M(')E='5R;B!`;7ES<6QI7V9R965?<F5S=6QT*"1R97-U;'0I.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&YU;4-O;',H*0H*("`@("\J*@H@("`@
M("H@1V5T<R!T:&4@;G5M8F5R(&]F(&-O;'5M;G,@:6X@82!R97-U;'0@<V5T
M"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E
M(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIN=6U#
M;VQS*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T
M960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B
M:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@
M4$A0)W,@<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E
M='5R;B!I;G0@('1H92!N=6UB97(@;V8@8V]L=6UN<RX@($$@1$)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U
M;'0Z.FYU;4-O;',H*0H@("`@("HO"B`@("!F=6YC=&EO;B!N=6U#;VQS*"1R
M97-U;'0I"B`@("!["B`@("`@("`@)&-O;',@/2!`;7ES<6QI7VYU;5]F:65L
M9',H)')E<W5L="D["B`@("`@("`@:68@*"$D8V]L<RD@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/FUY<W%L:5)A:7-E17)R;W(H*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1C;VQS.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&YU;5)O=W,H*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M
M8F5R(&]F(')O=W,@:6X@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI
M<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@
M(%5S90H@("`@("H@1$)?<F5S=6QT.CIN=6U2;W=S*"D@:6YS=&5A9"X@($ET
M(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E
M($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT
M(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB
M97(@;V8@<F]W<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.FYU;5)O=W,H*0H@("`@("HO
M"B`@("!F=6YC=&EO;B!N=6U2;W=S*"1R97-U;'0I"B`@("!["B`@("`@("`@
M)')O=W,@/2!`;7ES<6QI7VYU;5]R;W=S*"1R97-U;'0I.PH@("`@("`@(&EF
M("@D<F]W<R`]/3T@;G5L;"D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/FUY<W%L:5)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1R;W=S.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&%U=&]#;VUM
M:70H*0H*("`@("\J*@H@("`@("H@16YA8FQE<R!O<B!D:7-A8FQE<R!A=71O
M;6%T:6,@8V]M;6ET<PH@("`@("H*("`@("`J($!P87)A;2!B;V]L("1O;F]F
M9B`@=')U92!T=7)N<R!I="!O;BP@9F%L<V4@='5R;G,@:70@;V9F"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"
M7T5R<F]R(&]B:F5C="!I9B!T:&4@9')I=F5R"B`@("`@*B`@("`@("`@("`@
M("`@(&1O97-N)W0@<W5P<&]R="!A=71O+6-O;6UI='1I;F<@=')A;G-A8W1I
M;VYS+@H@("`@("HO"B`@("!F=6YC=&EO;B!A=71O0V]M;6ET*"1O;F]F9B`]
M(&9A;'-E*0H@("`@>PH@("`@("`@("\O(%A86"!I9B`D=&AI<RT^=')A;G-A
M8W1I;VY?;W!C;W5N="`^(#`L('=E('-H;W5L9"!P<F]B86)L>0H@("`@("`@
M("\O(&ES<W5E(&$@=V%R;FEN9R!H97)E+@H@("`@("`@("1T:&ES+3YA=71O
M8V]M;6ET(#T@)&]N;V9F(#\@=')U92`Z(&9A;'-E.PH@("`@("`@(')E='5R
M;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VUM:70H
M*0H*("`@("\J*@H@("`@("H@0V]M;6ET<R!T:&4@8W5R<F5N="!T<F%N<V%C
M=&EO;@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C
M97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@8V]M;6ET*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M
M/G1R86YS86-T:6]N7V]P8V]U;G0@/B`P*2!["B`@("`@("`@("`@(&EF("@D
M=&AI<RT^7V1B*2!["B`@("`@("`@("`@("`@("!I9B`H(4!M>7-Q;&E?<V5L
M96-T7V1B*"1T:&ES+3YC;VYN96-T:6]N+"`D=&AI<RT^7V1B*2D@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7ES<6QI4F%I<V5%<G)O
M<BA$0E]%4E)/4E].3T1"4T5,14-4140I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1R97-U;'0@/2!`;7ES<6QI7W%U
M97)Y*"1T:&ES+3YC;VYN96-T:6]N+"`G0T]-34E4)RD["B`@("`@("`@("`@
M("1R97-U;'0@/2!`;7ES<6QI7W%U97)Y*"1T:&ES+3YC;VYN96-T:6]N+"`G
M4T54($%55$]#3TU-250],2<I.PH@("`@("`@("`@("`D=&AI<RT^=')A;G-A
M8W1I;VY?;W!C;W5N="`](#`["B`@("`@("`@("`@(&EF("@A)')E<W5L="D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM>7-Q;&E286ES945R
M<F]R*"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(')O;&QB86-K
M*"D*"B`@("`O*BH*("`@("`J(%)E=F5R=',@=&AE(&-U<G)E;G0@=')A;G-A
M8W1I;VX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C
M8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(')O;&QB86-K*"D*("`@('L*("`@("`@("!I9B`H)'1H
M:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/B`P*2!["B`@("`@("`@("`@(&EF
M("@D=&AI<RT^7V1B*2!["B`@("`@("`@("`@("`@("!I9B`H(4!M>7-Q;&E?
M<V5L96-T7V1B*"1T:&ES+3YC;VYN96-T:6]N+"`D=&AI<RT^7V1B*2D@>PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7ES<6QI4F%I<V5%
M<G)O<BA$0E]%4E)/4E].3T1"4T5,14-4140I.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1R97-U;'0@/2!`;7ES<6QI
M7W%U97)Y*"1T:&ES+3YC;VYN96-T:6]N+"`G4D],3$)!0TLG*3L*("`@("`@
M("`@("`@)')E<W5L="`]($!M>7-Q;&E?<75E<GDH)'1H:7,M/F-O;FYE8W1I
M;VXL("=3150@05543T-/34U)5#TQ)RD["B`@("`@("`@("`@("1T:&ES+3YT
M<F%N<V%C=&EO;E]O<&-O=6YT(#T@,#L*("`@("`@("`@("`@:68@*"$D<F5S
M=6QT*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUY<W%L:5)A
M:7-E17)R;W(H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R
M971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@869F
M96-T9612;W=S*"D*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@=&AE(&YU
M;6)E<B!O9B!R;W=S(&%F9F5C=&5D(&)Y(&$@9&%T82!M86YI=7!L871I;VX@
M<75E<GD*("`@("`J"B`@("`@*B`P(&ES(')E='5R;F5D(&9O<B!Q=65R:65S
M('1H870@9&]N)W0@;6%N:7!U;&%T92!D871A+@H@("`@("H*("`@("`J($!R
M971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(')O=W,N("!!($1"7T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9F9E8W1E
M9%)O=W,H*0H@("`@>PH@("`@("`@(&EF("A$0CHZ:7--86YI<"@D=&AI<RT^
M;&%S=%]Q=65R>2DI('L*("`@("`@("`@("`@<F5T=7)N($!M>7-Q;&E?869F
M96-T961?<F]W<R@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@?0H@("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!N97AT260H*0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@;F5X="!F<F5E(&ED(&EN(&$@<V5Q=65N8V4*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V5Q7VYA;64@(&YA;64@;V8@=&AE
M('-E<75E;F-E"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;VYD96UA;F0@('=H
M96X@=')U92P@=&AE('-E<65N8V4@:7,@875T;VUA=&EC86QL>0H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8W)E871E9"!I9B!I="!D;V5S
M(&YO="!E>&ES=`H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;F5X
M="!I9"!N=6UB97(@:6X@=&AE('-E<75E;F-E+@H@("`@("H@("`@("`@("`@
M("`@("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@
M("`J($!S964@1$)?8V]M;6]N.CIN97AT240H*2P@1$)?8V]M;6]N.CIG9713
M97%U96YC94YA;64H*2P*("`@("`J("`@("`@1$)?;7ES<6QI.CIC<F5A=&53
M97%U96YC92@I+"!$0E]M>7-Q;&DZ.F1R;W!397%U96YC92@I"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&YE>'1)9"@D<V5Q7VYA;64L("1O;F1E;6%N9"`]('1R
M=64I"B`@("!["B`@("`@("`@)'-E<6YA;64@/2`D=&AI<RT^9V5T4V5Q=65N
M8V5.86UE*"1S97%?;F%M92D["B`@("`@("`@9&\@>PH@("`@("`@("`@("`D
M<F5P96%T(#T@,#L*("`@("`@("`@("`@)'1H:7,M/G!U<VA%<G)O<DAA;F1L
M:6YG*%!%05)?15)23U)?4D5455).*3L*("`@("`@("`@("`@)')E<W5L="`]
M("1T:&ES+3YQ=65R>2@G55!$051%("<@+B`D<V5Q;F%M90H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("X@)R!3150@:60@/2!,05-47TE.
M4T525%])1"AI9"`K(#$I)RD["B`@("`@("`@("`@("1T:&ES+3YP;W!%<G)O
M<DAA;F1L:6YG*"D["B`@("`@("`@("`@(&EF("@D<F5S=6QT(#T]/2!$0E]/
M2RD@>PH@("`@("`@("`@("`@("`@+R\@0T]-34].($-!4T4*("`@("`@("`@
M("`@("`@("1I9"`]($!M>7-Q;&E?:6YS97)T7VED*"1T:&ES+3YC;VYN96-T
M:6]N*3L*("`@("`@("`@("`@("`@(&EF("@D:60@(3T@,"D@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D:60["B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@+R\@14U05%D@4T51(%1!0DQ%"B`@("`@("`@("`@
M("`@("`O+R!397%U96YC92!T86)L92!M=7-T(&)E(&5M<'1Y(&9O<B!S;VUE
M(')E87-O;BP*("`@("`@("`@("`@("`@("\O('-O(&9I;&P@:70@86YD(')E
M='5R;B`Q"B`@("`@("`@("`@("`@("`O+R!/8G1A:6X@82!U<V5R+6QE=F5L
M(&QO8VL*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^9V5T3VYE
M*"=314Q%0U0@1T547TQ/0TLH)PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+B`B)R1[<V5Q;F%M97U?;&]C:R<L(#$P*2(I.PH@
M("`@("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1R
M97-U;'0I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@
M*"1R97-U;'0@/3T@,"D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^;7ES<6QI4F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?3$]#2T5$*3L*
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O+R!A9&0@=&AE
M(&1E9F%U;'0@=F%L=64*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^<75E<GDH)U)%4$Q!0T4@24Y43R`G("X@)'-E<6YA;64*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G("AI9"D@5D%,5453
M("@P*2<I.PH@("`@("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U
M;'0I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"1R97-U;'0I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("\O(%)E;&5A<V4@=&AE(&QO8VL*("`@("`@("`@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^9V5T3VYE*"=314Q%0U0@4D5,14%315],3T-+*"<*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@(B<D
M>W-E<6YA;65]7VQO8VLG*2(I.PH@("`@("`@("`@("`@("`@:68@*$1".CII
M<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@+R\@5V4@:VYO=R!W:&%T('1H92!R97-U;'0@
M=VEL;"!B92P@<V\@;F\@;F5E9"!T;R!T<GD@86=A:6X*("`@("`@("`@("`@
M("`@(')E='5R;B`Q.PH*("`@("`@("`@("`@?2!E;'-E:68@*"1O;F1E;6%N
M9"`F)B!$0CHZ:7-%<G)O<B@D<F5S=6QT*2`F)@H@("`@("`@("`@("`@("`@
M)')E<W5L="T^9V5T0V]D92@I(#T]($1"7T524D]27TY/4U5#2%1!0DQ%*0H@
M("`@("`@("`@("!["B`@("`@("`@("`@("`@("`O+R!/3D1%34%.1"!404),
M12!#4D5!5$E/3@H@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YC
M<F5A=&5397%U96YC92@D<V5Q7VYA;64I.PH*("`@("`@("`@("`@("`@("\O
M(%-I;F-E(&-R96%T95-E<75E;F-E(&EN:71I86QI>F5S('1H92!)1"!T;R!B
M92`Q+`H@("`@("`@("`@("`@("`@+R\@=V4@9&\@;F]T(&YE960@=&\@<F5T
M<FEE=F4@=&AE($E$(&%G86EN("AO<B!W92!W:6QL(&=E="`R*0H@("`@("`@
M("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`O+R!&:7)S="!)1"!O9B!A(&YE=VQY(&-R96%T960@<V5Q=65N8V4@:7,@
M,0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`Q.PH@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@?2!E;'-E:68@*$1".CII<T5R<F]R*"1R97-U
M;'0I("8F"B`@("`@("`@("`@("`@("`@("`@("`D<F5S=6QT+3YG971#;V1E
M*"D@/3T@1$)?15)23U)?04Q214%$65]%6$E35%,I"B`@("`@("`@("`@('L*
M("`@("`@("`@("`@("`@("\O($)!0TM705)$4R!#3TU0050*("`@("`@("`@
M("`@("`@("\O('-E92!?0D-S97%U96YC92@I(&-O;6UE;G0*("`@("`@("`@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^7T)#<V5Q=65N8V4H)'-E<6YA;64I
M.PH@("`@("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*"1R97-U;'0I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)')E<&5A="`](#$["B`@("`@("`@("`@('T*("`@("`@("!]('=H:6QE("@D
M<F5P96%T*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1R
M97-U;'0I.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A(&YE=R!S
M97%U96YC90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-E<5]N86UE
M("!N86UE(&]F('1H92!N97<@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F-R
M96%T95-E<75E;F-E*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL
M"B`@("`@*B`@("`@($1"7VUY<W%L:3HZ;F5X=$E$*"DL($1"7VUY<W%L:3HZ
M9')O<%-E<75E;F-E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E4V5Q
M=65N8V4H)'-E<5]N86UE*0H@("`@>PH@("`@("`@("1S97%N86UE(#T@)'1H
M:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I.PH@("`@("`@("1R97,@
M/2`D=&AI<RT^<75E<GDH)T-214%412!404),12`G("X@)'-E<6YA;64*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("X@)R`H:60@24Y414=%4B!53E-)
M1TY%1"!!551/7TE.0U)%345.5"!.3U0@3E5,3"PG"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`N("<@4%))34%262!+15DH:60I*2<I.PH@("`@("`@
M(&EF("A$0CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@("`@("!R971U<FX@
M)')E<SL*("`@("`@("!]"B`@("`@("`@+R\@:6YS97)T('EI96QD<R!V86QU
M92`Q+"!N97AT260@8V%L;"!W:6QL(&=E;F5R871E($E$(#(*("`@("`@("!R
M971U<FX@)'1H:7,M/G%U97)Y*"))3E-%4E0@24Y43R`D>W-E<6YA;65]("AI
M9"D@5D%,5453("@P*2(I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&1R;W!397%U96YC92@I"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@<V5Q
M=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97%?;F%M92`@
M;F%M92!O9B!T:&4@<V5Q=65N8V4@=&\@8F4@9&5L971E9`H@("`@("H*("`@
M("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O
M;6UO;CHZ9')O<%-E<75E;F-E*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.
M86UE*"DL"B`@("`@*B`@("`@($1"7VUY<W%L.CIN97AT240H*2P@1$)?;7ES
M<6PZ.F-R96%T95-E<75E;F-E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9')O
M<%-E<75E;F-E*"1S97%?;F%M92D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/G%U97)Y*"=$4D]0(%1!0DQ%("<@+B`D=&AI<RT^9V5T4V5Q=65N8V5.
M86UE*"1S97%?;F%M92DI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(%]"0W-E<75E;F-E*"D*"B`@("`O*BH*("`@("`J($)A8VMW87)D<R!C;VUP
M871I8FEL:71Y('=I=&@@;VQD('-E<75E;F-E(&5M=6QA=&EO;B!I;7!L96UE
M;G1A=&EO;@H@("`@("H@*&-L96%N('5P('1H92!D=7!E<RD*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1S97%N86UE("!T:&4@<V5Q=65N8V4@;F%M
M92!T;R!C;&5A;B!U<`H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@=')U
M92!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N
M8W1I;VX@7T)#<V5Q=65N8V4H)'-E<6YA;64I"B`@("!["B`@("`@("`@+R\@
M3V)T86EN(&$@=7-E<BUL979E;"!L;V-K+BXN('1H:7,@=VEL;"!R96QE87-E
M(&%N>2!P<F5V:6]U<PH@("`@("`@("\O(&%P<&QI8V%T:6]N(&QO8VMS+"!B
M=70@=6YL:6ME($Q/0TL@5$%"3$53+"!I="!D;V5S(&YO="!A8F]R=`H@("`@
M("`@("\O('1H92!C=7)R96YT('1R86YS86-T:6]N(&%N9"!I<R!M=6-H(&QE
M<W,@9G)E<75E;G1L>2!U<V5D+@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M9V5T3VYE*")314Q%0U0@1T547TQ/0TLH)R1[<V5Q;F%M97U?;&]C:R<L,3`I
M(BD["B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("!I9B`H
M)')E<W5L="`]/2`P*2!["B`@("`@("`@("`@("\O($9A:6QE9"!T;R!G970@
M=&AE(&QO8VLL(&-A;B=T(&1O('1H92!C;VYV97)S:6]N+"!B86EL"B`@("`@
M("`@("`@("\O('=I=&@@82!$0E]%4E)/4E].3U1?3$]#2T5$(&5R<F]R"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^;7ES<6QI4F%I<V5%<G)O<BA$0E]%
M4E)/4E].3U1?3$]#2T5$*3L*("`@("`@("!]"@H@("`@("`@("1H:6=H97-T
M7VED(#T@)'1H:7,M/F=E=$]N92@B4T5,14-4($U!6"AI9"D@1E)/32`D>W-E
M<6YA;65](BD["B`@("`@("`@:68@*$1".CII<T5R<F]R*"1H:6=H97-T7VED
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&AI9VAE<W1?:60["B`@("`@("`@
M?0H*("`@("`@("`O+R!4:&ES('-H;W5L9"!K:6QL(&%L;"!R;W=S(&5X8V5P
M="!T:&4@:&EG:&5S=`H@("`@("`@("\O(%=E('-H;W5L9"!P<F]B86)L>2!D
M;R!S;VUE=&AI;F<@:68@)&AI9VAE<W1?:60@:7-N)W0*("`@("`@("`O+R!N
M=6UE<FEC+"!B=70@22=M(&%T(&$@;&]S<R!A<R!H;W<@=&\@:&%N9&QE('1H
M870N+BX*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/G%U97)Y*"=$14Q%5$4@
M1E)/32`G("X@)'-E<6YA;64*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("X@(B!72$5212!I9"`\/B`D:&EG:&5S=%]I9"(I.PH@("`@("`@(&EF
M("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("\O($EF(&%N;W1H97(@=&AR
M96%D(&AA<R!B965N('=A:71I;F<@9F]R('1H:7,@;&]C:RP*("`@("`@("`O
M+R!I="!W:6QL(&=O('1H<G4@=&AE(&%B;W9E('!R;V-E9'5R92P@8G5T('=I
M;&P@:&%V92!N;PH@("`@("`@("\O(')E86P@969F96-T"B`@("`@("`@)')E
M<W5L="`]("1T:&ES+3YG971/;F4H(E-%3$5#5"!214Q%05-%7TQ/0TLH)R1[
M<V5Q;F%M97U?;&]C:R<I(BD["B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R
M97-U;'0I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!Q=6]T94ED96YT:69I97(H*0H*("`@("\J*@H@("`@("H@475O
M=&5S(&$@<W1R:6YG('-O(&ET(&-A;B!B92!S869E;'D@=7-E9"!A<R!A('1A
M8FQE(&]R(&-O;'5M;B!N86UE"B`@("`@*@H@("`@("H@37E344P@8V%N)W0@
M:&%N9&QE('1H92!B86-K=&EC:R!C:&%R86-T97(@*#QK8F0^8#PO:V)D/BD@
M:6X*("`@("`J('1A8FQE(&]R(&-O;'5M;B!N86UE<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1S='(@(&ED96YT:69I97(@;F%M92!T;R!B92!Q
M=6]T960*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@<75O=&5D(&ED
M96YT:69I97(@<W1R:6YG"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ
M.G%U;W1E261E;G1I9FEE<B@I"B`@("`@*B!`<VEN8V4@365T:&]D(&%V86EL
M86)L92!S:6YC92!296QE87-E(#$N-BXP"B`@("`@*B\*("`@(&9U;F-T:6]N
M('%U;W1E261E;G1I9FEE<B@D<W1R*0H@("`@>PH@("`@("`@(')E='5R;B`G
M8"<@+B`D<W1R("X@)V`G.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&5S8V%P95-I;7!L92@I"@H@("`@+RHJ"B`@("`@*B!%<V-A<&5S(&$@<W1R
M:6YG(&%C8V]R9&EN9R!T;R!T:&4@8W5R<F5N="!$0DU3)W,@<W1A;F1A<F1S
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1R("!T:&4@<W1R:6YG
M('1O(&)E(&5S8V%P960*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M=&AE(&5S8V%P960@<W1R:6YG"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM
M;VXZ.G%U;W1E4VUA<G0H*0H@("`@("H@0'-I;F-E($UE=&AO9"!A=F%I;&%B
M;&4@<VEN8V4@4F5L96%S92`Q+C8N,`H@("`@("HO"B`@("!F=6YC=&EO;B!E
M<V-A<&53:6UP;&4H)'-T<BD*("`@('L*("`@("`@("!R971U<FX@0&UY<W%L
M:5]R96%L7V5S8V%P95]S=')I;F<H)'1H:7,M/F-O;FYE8W1I;VXL("1S='(I
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&UO9&EF>4QI;6ET475E
M<GDH*0H*("`@("\J*@H@("`@("H@061D<R!,24U)5"!C;&%U<V5S('1O(&$@
M<75E<GD@<W1R:6YG(&%C8V]R9&EN9R!T;R!C=7)R96YT($1"35,@<W1A;F1A
M<F1S"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<75E<GD@("!T:&4@
M<75E<GD@=&\@;6]D:69Y"B`@("`@*B!`<&%R86T@:6YT("`@("1F<F]M("`@
M('1H92!R;W<@=&\@<W1A<G0@=&\@9F5T8VAI;F<@*#`@/2!T:&4@9FER<W0@
M<F]W*0H@("`@("H@0'!A<F%M(&EN="`@("`D8V]U;G0@("!T:&4@;G5M8F5R
M<R!O9B!R;W=S('1O(&9E=&-H"B`@("`@*B!`<&%R86T@;6EX960@("1P87)A
M;7,@(&%R<F%Y+"!S=')I;F<@;W(@;G5M97)I8R!D871A('1O(&)E('5S960@
M:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&5X96-U=&EO;B!O
M9B!T:&4@<W1A=&5M96YT+B`@475A;G1I='D@;V8@:71E;7,*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@('!A<W-E9"!M=7-T(&UA=&-H('%U86YT
M:71Y(&]F('!L86-E:&]L9&5R<R!I;@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@<75E<GDZ("!M96%N:6YG(#$@<&QA8V5H;VQD97(@9F]R(&YO
M;BUA<G)A>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE
M=&5R<R!O<B`Q('!L86-E:&]L9&5R('!E<B!A<G)A>2!E;&5M96YT+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@<75E<GD@<W1R:6YG('=I
M=&@@3$E-250@8VQA=7-E<R!A9&1E9`H@("`@("H*("`@("`J($!A8V-E<W,@
M<')O=&5C=&5D"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO9&EF>4QI;6ET475E
M<GDH)'%U97)Y+"`D9G)O;2P@)&-O=6YT+"`D<&%R86US(#T@87)R87DH*2D*
M("`@('L*("`@("`@("!I9B`H1$(Z.FES36%N:7`H)'%U97)Y*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'%U97)Y("X@(B!,24U)5"`D8V]U;G0B.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D<75E<GD@+B`B($Q)
M34E4("1F<F]M+"`D8V]U;G0B.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!M>7-Q;&E286ES945R<F]R*"D*"B`@("`O*BH*("`@
M("`J(%!R;V1U8V5S(&$@1$)?17)R;W(@;V)J96-T(')E9V%R9&EN9R!T:&4@
M8W5R<F5N="!P<F]B;&5M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`D97)R
M;F\@(&EF('1H92!E<G)O<B!I<R!B96EN9R!M86YU86QL>2!R86ES960@<&%S
M<R!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@($1"7T524D]2*B!C;VYS
M=&%N="!H97)E+B`@268@=&AI<R!I<VXG="!P87-S960*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@=&AE(&5R<F]R(&EN9F]R;6%T:6]N(&=A=&AE<F5D
M(&9R;VT@=&AE($1"35,N"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@
M('1H92!$0E]%<G)O<B!O8FIE8W0*("`@("`J"B`@("`@*B!`<V5E($1"7V-O
M;6UO;CHZ<F%I<V5%<G)O<B@I+`H@("`@("H@("`@("!$0E]M>7-Q;&DZ.F5R
M<F]R3F%T:79E*"DL($1"7V-O;6UO;CHZ97)R;W)#;V1E*"D*("`@("`J+PH@
M("`@9G5N8W1I;VX@;7ES<6QI4F%I<V5%<G)O<B@D97)R;F\@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&EF("@D97)R;F\@/3T](&YU;&PI('L*("`@("`@("`@
M("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]2
M5$%"24Q)5%E?15)23U)3*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^97)R
M;W)C;V1E7VUA<%LQ,#(R72`]($1"7T524D]27T-/3E-44D%)3E0["B`@("`@
M("`@("`@("`@("`D=&AI<RT^97)R;W)C;V1E7VUA<%LQ,#0X72`]($1"7T52
M4D]27T-/3E-44D%)3E1?3D]47TY53$P["B`@("`@("`@("`@("`@("`D=&AI
M<RT^97)R;W)C;V1E7VUA<%LQ,#8R72`]($1"7T524D]27T-/3E-44D%)3E0[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O+R!$;VEN
M9R!T:&ES(&EN(&-A<V4@;6]D92!C:&%N9V5S(&1U<FEN9R!R=6YT:6UE+@H@
M("`@("`@("`@("`@("`@)'1H:7,M/F5R<F]R8V]D95]M87!;,3`R,ET@/2!$
M0E]%4E)/4E]!3%)%04197T5825-44SL*("`@("`@("`@("`@("`@("1T:&ES
M+3YE<G)O<F-O9&5?;6%P6S$P-#A=(#T@1$)?15)23U)?0T].4U1204E.5#L*
M("`@("`@("`@("`@("`@("1T:&ES+3YE<G)O<F-O9&5?;6%P6S$P-C)=(#T@
M1$)?15)23U)?04Q214%$65]%6$E35%,["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&5R<FYO(#T@)'1H:7,M/F5R<F]R0V]D92AM>7-Q;&E?97)R;F\H
M)'1H:7,M/F-O;FYE8W1I;VXI*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"1E<G)N;RP@;G5L;"P@;G5L;"P@;G5L;"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@0&UY<W%L:5]E<G)N
M;R@D=&AI<RT^8V]N;F5C=&EO;BD@+B`G("HJ("<@+@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!`;7ES<6QI7V5R<F]R*"1T:&ES+3YC;VYN
M96-T:6]N*2D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97)R;W).
M871I=F4H*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@1$)-4R<@;F%T:79E
M(&5R<F]R(&-O9&4@<')O9'5C960@8GD@=&AE(&QA<W0@<75E<GD*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE($1"35,G(&5R<F]R(&-O9&4*("`@
M("`J+PH@("`@9G5N8W1I;VX@97)R;W).871I=F4H*0H@("`@>PH@("`@("`@
M(')E='5R;B!`;7ES<6QI7V5R<FYO*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!T86)L94EN9F\H*0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!I;F9O<FUA=&EO;B!A8F]U="!A('1A8FQE(&]R
M(&$@<F5S=6QT('-E=`H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W1\<W1R
M:6YG("`D<F5S=6QT("!$0E]R97-U;'0@;V)J96-T(&9R;VT@82!Q=65R>2!O
M<B!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T
M<FEN9R!C;VYT86EN:6YG('1H92!N86UE(&]F(&$@=&%B;&4N"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%=H:6QE('1H:7,@86QS
M;R!A8V-E<'1S(&$@<75E<GD@<F5S=6QT"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(')E<V]U<F-E(&ED96YT:69I97(L('1H:7,@
M8F5H879I;W(@:7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@9&5P<F5C871E9"X*("`@("`J($!P87)A;2!I;G0@("`@("`@("`@
M("`D;6]D92`@("!A('9A;&ED('1A8FQE26YF;R!M;V1E"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@86X@87-S;V-I871I=F4@87)R87D@=VET:"!T
M:&4@:6YF;W)M871I;VX@<F5Q=65S=&5D+@H@("`@("H@("`@("`@("`@("`@
M("`@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@
M("H@0'-E92!$0E]C;VUM;VXZ.G-E=$]P=&EO;B@I"B`@("`@*B\*("`@(&9U
M;F-T:6]N('1A8FQE26YF;R@D<F5S=6QT+"`D;6]D92`](&YU;&PI"B`@("![
M"B`@("`@("`@:68@*&ES7W-T<FEN9R@D<F5S=6QT*2D@>PH@("`@("`@("`@
M("`O*@H@("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E9"!A('1A8FQE
M(&YA;64N"B`@("`@("`@("`@("`J($-R96%T92!A(')E<W5L="!R97-O=7)C
M92!I9&5N=&EF:65R+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@)&ED
M(#T@0&UY<W%L:5]Q=65R>2@D=&AI<RT^8V]N;F5C=&EO;BP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`B4T5,14-4("H@1E)/32`D<F5S=6QT
M($Q)34E4(#`B*3L*("`@("`@("`@("`@)&=O=%]S=')I;F<@/2!T<G5E.PH@
M("`@("`@('T@96QS96EF("AI<W-E="@D<F5S=6QT+3YR97-U;'0I*2!["B`@
M("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I=F5D
M(&$@<F5S=6QT(&]B:F5C="X*("`@("`@("`@("`@("H@17AT<F%C="!T:&4@
M<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@("`@("`@("`J+PH@
M("`@("`@("`@("`D:60@/2`D<F5S=6QT+3YR97-U;'0["B`@("`@("`@("`@
M("1G;W1?<W1R:6YG(#T@9F%L<V4["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@+RH*("`@("`@("`@("`@("H@4')O8F%B;'D@<F5C96EV960@82!R
M97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@("`@("`@("H@0V]P
M>2!I="X*("`@("`@("`@("`@("H@1&5P<F5C871E9"X@($AE<F4@9F]R(&-O
M;7!A=&EB:6QI='D@;VYL>2X*("`@("`@("`@("`@("HO"B`@("`@("`@("`@
M("1I9"`]("1R97-U;'0["B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES7V$H)&ED+"`G;7ES<6QI
M7W)E<W5L="<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7ES<6QI
M4F%I<V5%<G)O<BA$0E]%4E)/4E].145$7TU/4D5?1$%402D["B`@("`@("`@
M?0H*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@
M)B!$0E]03U)404))3$E465],3U=%4D-!4T4I('L*("`@("`@("`@("`@)&-A
M<V5?9G5N8R`]("=S=')T;VQO=V5R)SL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D8V%S95]F=6YC(#T@)W-T<G9A;"<["B`@("`@("`@?0H*("`@
M("`@("`D8V]U;G0@/2!`;7ES<6QI7VYU;5]F:65L9',H)&ED*3L*("`@("`@
M("`D<F5S("`@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H)&UO9&4I('L*("`@
M("`@("`@("`@)')E<ULG;G5M7V9I96QD<R==(#T@)&-O=6YT.PH@("`@("`@
M('T*"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&-O=6YT.R`D:2LK*2![
M"B`@("`@("`@("`@("1T;7`@/2!`;7ES<6QI7V9E=&-H7V9I96QD*"1I9"D[
M"@H@("`@("`@("`@("`D9FQA9W,@/2`G)SL*("`@("`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/FUY<W%L:5]F;&%G<R!A<R`D8V]N<W0@/3X@)&UE86YS*2![
M"B`@("`@("`@("`@("`@("!I9B`H)'1M<"T^9FQA9W,@)B`D8V]N<W0I('L*
M("`@("`@("`@("`@("`@("`@("`D9FQA9W,@+CT@)&UE86YS("X@)R`G.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("@D=&UP+3YD968I('L*("`@("`@("`@("`@("`@("1F;&%G<R`N/2`G9&5F
M875L=%\G("X@<F%W=7)L96YC;V1E*"1T;7`M/F1E9BD["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)&9L86=S(#T@=')I;2@D9FQA9W,I.PH*("`@("`@
M("`@("`@)')E<ULD:5T@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=T86)L
M92<@/3X@)&-A<V5?9G5N8R@D=&UP+3YT86)L92DL"B`@("`@("`@("`@("`@
M("`G;F%M92<@(#T^("1C87-E7V9U;F,H)'1M<"T^;F%M92DL"B`@("`@("`@
M("`@("`@("`G='EP92<@(#T^(&ES<V5T*"1T:&ES+3YM>7-Q;&E?='EP97-;
M)'1M<"T^='EP95TI"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#\@)'1H:7,M/FUY<W%L:5]T>7!E<ULD=&UP+3YT>7!E70H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("=U;FMN;W=N)RP*("`@
M("`@("`@("`@("`@("=L96XG("`@/3X@)'1M<"T^;6%X7VQE;F=T:"P*("`@
M("`@("`@("`@("`@("=F;&%G<R<@/3X@)&9L86=S+`H@("`@("`@("`@("`I
M.PH*("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/7T]21$52
M*2!["B`@("`@("`@("`@("`@("`D<F5S6R=O<F1E<B==6R1R97-;)&E=6R=N
M86UE)UU=(#T@)&D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1M
M;V1E("8@1$)?5$%"3$5)3D9/7T]21$525$%"3$4I('L*("`@("`@("`@("`@
M("`@("1R97-;)V]R9&5R=&%B;&4G75LD<F5S6R1I75LG=&%B;&4G75U;)')E
M<ULD:5U;)VYA;64G75T@/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+R\@9G)E92!T:&4@<F5S=6QT(&]N;'D@:68@=V4@=V5R92!C
M86QL960@;VX@82!T86)L90H@("`@("`@(&EF("@D9V]T7W-T<FEN9RD@>PH@
M("`@("`@("`@("!`;7ES<6QI7V9R965?<F5S=6QT*"1I9"D["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D<F5S.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&=E=%-P96-I86Q1=65R>2@I"@H@("`@+RHJ"B`@("`@*B!/8G1A
M:6YS('1H92!Q=65R>2!S=')I;F<@;F5E9&5D(&9O<B!L:7-T:6YG(&$@9VEV
M96X@='EP92!O9B!O8FIE8W1S"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D='EP92`@=&AE(&MI;F0@;V8@;V)J96-T<R!Y;W4@=V%N="!T;R!R971R
M:65V90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@4U%,('%U
M97)Y('-T<FEN9R!O<B!N=6QL(&EF('1H92!D<FEV97(@9&]E<VXG=`H@("`@
M("H@("`@("`@("`@("`@("`@("!S=7!P;W)T('1H92!O8FIE8W0@='EP92!R
M97%U97-T960*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@
M("H@0'-E92!$0E]C;VUM;VXZ.F=E=$QI<W1/9B@I"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%-P96-I86Q1=65R>2@D='EP92D*("`@('L*("`@("`@("!S
M=VET8V@@*"1T>7!E*2!["B`@("`@("`@("`@(&-A<V4@)W1A8FQE<R<Z"B`@
M("`@("`@("`@("`@("!R971U<FX@)U-(3U<@5$%"3$53)SL*("`@("`@("`@
M("`@8V%S92`G=7-E<G,G.@H@("`@("`@("`@("`@("`@<F5T=7)N("=314Q%
M0U0@1$E35$E.0U0@57-E<B!&4D]-(&UY<W%L+G5S97(G.PH@("`@("`@("`@
M("!C87-E("=D871A8F%S97,G.@H@("`@("`@("`@("`@("`@<F5T=7)N("=3
M2$]7($1!5$%"05-%4R<["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@
M("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("!]"@H@("`@+R\@
M?7U]"@I]"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@
M-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!%;F0Z"B`J+PH*/SX*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]$0B]O8VDX+G!H<```````````````````````````````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#$P-C4V-@`Q,#4Q-30S,S<S-P`P,C`T-C4`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*"B\J
M('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O
M9G1T86)S=&]P/30Z("HO"@HO*BH*("H@5&AE(%!%05(@1$(@9')I=F5R(&9O
M<B!02%`G<R!O8VDX(&5X=&5N<VEO;@H@*B!F;W(@:6YT97)A8W1I;F<@=VET
M:"!/<F%C;&4@9&%T86)A<V5S"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U
M"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T
M;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A
M=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O
M;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T
M:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H
M<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@
M("!$0@H@*B!`875T:&]R("`@("!*86UE<R!,+B!0:6YE(#QJ;'!`=F%L:6YU
M>"YC;VT^"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE
M;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@
M1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@($-6
M4SH@)$ED.B!O8VDX+G!H<"QV(#$N,3`S(#(P,#4O,#0O,3$@,34Z,3`Z,C(@
M9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N
M;F5T+W!A8VMA9V4O1$(*("HO"@HO*BH*("H@3V)T86EN('1H92!$0E]C;VUM
M;VX@8VQA<W,@<V\@:70@8V%N(&)E(&5X=&5N9&5D(&9R;VT*("HO"G)E<75I
M<F5?;VYC92`G1$(O8V]M;6]N+G!H<"<["@HO*BH*("H@5&AE(&UE=&AO9',@
M4$5!4B!$0B!U<V5S('1O(&EN=&5R86-T('=I=&@@4$A0)W,@;V-I."!E>'1E
M;G-I;VX*("H@9F]R(&EN=&5R86-T:6YG('=I=&@@3W)A8VQE(&1A=&%B87-E
M<PH@*@H@*B!$969I;FET96QY('=O<FMS('=I=&@@=F5R<VEO;G,@."!A;F0@
M.2!O9B!/<F%C;&4N"B`J"B`J(%1H97-E(&UE=&AO9',@;W9E<FQO860@=&AE
M(&]N97,@9&5C;&%R960@:6X@1$)?8V]M;6]N+@H@*@H@*B!"92!A=V%R92XN
M+B`@3T-)17)R;W(H*2!O;FQY(&%P<&5A<G,@=&\@<F5T=7)N(&%N>71H:6YG
M('=H96X@9VEV96X@80H@*B!S=&%T96UE;G0L('-O(&9U;F-T:6]N<R!R971U
M<FX@=&AE(&=E;F5R:6,@1$)?15)23U(@:6YS=&5A9"!O9B!M;W)E"B`J('5S
M969U;"!E<G)O<G,@=&AA="!H879E('1O(&1O('=I=&@@9F5E9&)A8VL@9G)O
M;2!T:&4@9&%T86)A<V4N"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J
M($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@($IA;65S($PN(%!I;F4@
M/&IL<$!V86QI;G5X+F-O;3X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I
M<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P
M,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E
M<G-I;VX@("`@4F5L96%S93H@,2XW+C8*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PIC;&%S<R!$0E]O8VDX(&5X
M=&5N9',@1$)?8V]M;6]N"GL*("`@("\O('M[>R!P<F]P97)T:65S"@H@("`@
M+RHJ"B`@("`@*B!4:&4@1$(@9')I=F5R('1Y<&4@*&UY<W%L+"!O8VDX+"!O
M9&)C+"!E=&,N*0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1P:'!T>7!E(#T@)V]C:3@G.PH*("`@("\J*@H@("`@("H@5&AE(&1A=&%B
M87-E('-Y;G1A>"!V87)I86YT('1O(&)E('5S960@*&1B,BP@86-C97-S+"!E
M=&,N*2P@:68@86YY"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)&1B<WEN=&%X(#T@)V]C:3@G.PH*("`@("\J*@H@("`@("H@5&AE(&-A
M<&%B:6QI=&EE<R!O9B!T:&ES($1"(&EM<&QE;65N=&%T:6]N"B`@("`@*@H@
M("`@("H@5&AE("=N97=?;&EN:R<@96QE;65N="!C;VYT86EN<R!T:&4@4$A0
M('9E<G-I;VX@=&AA="!F:7)S="!P<F]V:61E9`H@("`@("H@;F5W7VQI;FL@
M<W5P<&]R="!F;W(@=&AI<R!$0DU3+B`@0V]N=&%I;G,@9F%L<V4@:68@:70G
M<R!U;G-U<'!O<G1E9"X*("`@("`J"B`@("`@*B!-96%N:6YG(&]F('1H92`G
M;&EM:70G(&5L96UE;G0Z"B`@("`@*B`@("L@)V5M=6QA=&4G(#T@96UU;&%T
M92!W:71H(&9E=&-H(')O=R!B>2!N=6UB97(*("`@("`J("`@*R`G86QT97(G
M("`@/2!A;'1E<B!T:&4@<75E<GD*("`@("`J("`@*R!F86QS92`@("`@/2!S
M:VEP(')O=W,*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D9F5A='5R97,@/2!A<G)A>2@*("`@("`@("`G;&EM:70G("`@("`@
M("`@/3X@)V%L=&5R)RP*("`@("`@("`G;F5W7VQI;FLG("`@("`@/3X@)S4N
M,"XP)RP*("`@("`@("`G;G5M<F]W<R<@("`@("`@/3X@)W-U8G%U97)Y)RP*
M("`@("`@("`G<&-O;FYE8W0G("`@("`@/3X@=')U92P*("`@("`@("`G<')E
M<&%R92<@("`@("`@/3X@=')U92P*("`@("`@("`G<W-L)R`@("`@("`@("`@
M/3X@9F%L<V4L"B`@("`@("`@)W1R86YS86-T:6]N<R<@(#T^('1R=64L"B`@
M("`I.PH*("`@("\J*@H@("`@("H@02!M87!P:6YG(&]F(&YA=&EV92!E<G)O
M<B!C;V1E<R!T;R!$0B!E<G)O<B!C;V1E<PH@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)&5R<F]R8V]D95]M87`@/2!A<G)A>2@*("`@("`@
M("`Q("`@(#T^($1"7T524D]27T-/3E-44D%)3E0L"B`@("`@("`@.3`P("`]
M/B!$0E]%4E)/4E]364Y405@L"B`@("`@("`@.3`T("`]/B!$0E]%4E)/4E].
M3U-50TA&245,1"P*("`@("`@("`Y,3,@(#T^($1"7T524D]27U9!3%5%7T-/
M54Y47T].7U)/5RP*("`@("`@("`Y,C$@(#T^($1"7T524D]27U-93E1!6"P*
M("`@("`@("`Y,C,@(#T^($1"7T524D]27U-93E1!6"P*("`@("`@("`Y-#(@
M(#T^($1"7T524D]27TY/4U5#2%1!0DQ%+`H@("`@("`@(#DU-2`@/3X@1$)?
M15)23U)?04Q214%$65]%6$E35%,L"B`@("`@("`@,30P,"`]/B!$0E]%4E)/
M4E]#3TY35%)!24Y47TY/5%].54Q,+`H@("`@("`@(#$T,#$@/3X@1$)?15)2
M3U)?24Y604Q)1"P*("`@("`@("`Q-#`W(#T^($1"7T524D]27T-/3E-44D%)
M3E1?3D]47TY53$PL"B`@("`@("`@,30Q."`]/B!$0E]%4E)/4E].3U1?1D]5
M3D0L"B`@("`@("`@,30W-B`]/B!$0E]%4E)/4E]$259:15)/+`H@("`@("`@
M(#$W,C(@/3X@1$)?15)23U)?24Y604Q)1%].54U"15(L"B`@("`@("`@,C(X
M.2`]/B!$0E]%4E)/4E].3U-50TA404),12P*("`@("`@("`R,CDQ(#T^($1"
M7T524D]27T-/3E-44D%)3E0L"B`@("`@("`@,C(Y,B`]/B!$0E]%4E)/4E]#
M3TY35%)!24Y4+`H@("`@("`@(#(T-#D@/3X@1$)?15)23U)?0T].4U1204E.
M5"P*("`@("D["@H@("`@+RHJ"B`@("`@*B!4:&4@<F%W(&1A=&%B87-E(&-O
M;FYE8W1I;VX@8W)E871E9"!B>2!02%`*("`@("`J($!V87(@<F5S;W5R8V4*
M("`@("`J+PH@("`@=F%R("1C;VYN96-T:6]N.PH*("`@("\J*@H@("`@("H@
M5&AE($133B!I;F9O<FUA=&EO;B!F;W(@8V]N;F5C=&EN9R!T;R!A(&1A=&%B
M87-E"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D9'-N(#T@
M87)R87DH*3L*"@H@("`@+RHJ"B`@("`@*B!3:&]U;&0@9&%T82!M86YI<'5L
M871I;VX@<75E<FEE<R!B92!C;VUM:71T960@875T;VUA=&EC86QL>3\*("`@
M("`J($!V87(@8F]O;`H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@('9A<B`D875T;V-O;6UI="`]('1R=64["@H@("`@+RHJ"B`@("`@*B!3
M=&]R97,@=&AE("1D871A('!A<W-E9"!T;R!E>&5C=71E*"D@:6X@=&AE(&]C
M:3@@9')I=F5R"B`@("`@*@H@("`@("H@1V5T<R!R97-E="!T;R!A<G)A>2@I
M('=H96X@<VEM<&QE475E<GDH*2!I<R!R=6XN"B`@("`@*@H@("`@("H@3F5E
M9&5D(&EN(&-A<V4@=7-E<B!W86YT<R!T;R!C86QL(&YU;5)O=W,H*2!A9G1E
M<B!P<F5P87)E+V5X96-U=&4*("`@("`J('=A<R!U<V5D+@H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!V87(@)%]D871A(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H
M92!R97-U;'0@;W(@<W1A=&5M96YT(&AA;F1L92!F<F]M('1H92!M;W-T(')E
M8V5N=&QY(&5X96-U=&5D('%U97)Y"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@
M("`@*B\*("`@('9A<B`D;&%S=%]S=&UT.PH*("`@("\J*@H@("`@("H@27,@
M=&AE(&=I=F5N('!R97!A<F5D('-T871E;65N="!A(&1A=&$@;6%N:7!U;&%T
M:6]N('%U97)Y/PH@("`@("H@0'9A<B!A<G)A>0H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B\*("`@('9A<B`D;6%N:7!?<75E<GD@/2!A<G)A>2@I
M.PH*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYS=')U8W1O<@H*("`@("\J
M*@H@("`@("H@5&AI<R!C;VYS=')U8W1O<B!C86QL<R`\:V)D/B1T:&ES+3Y$
M0E]C;VUM;VXH*3PO:V)D/@H@("`@("H*("`@("`J($!R971U<FX@=F]I9`H@
M("`@("HO"B`@("!F=6YC=&EO;B!$0E]O8VDX*"D*("`@('L*("`@("`@("`D
M=&AI<RT^1$)?8V]M;6]N*"D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@*B!#;VYN96-T('1O('1H92!D
M871A8F%S92!S97)V97(L(&QO9R!I;B!A;F0@;W!E;B!T:&4@9&%T86)A<V4*
M("`@("`J"B`@("`@*B!$;VXG="!C86QL('1H:7,@;65T:&]D(&1I<F5C=&QY
M+B`@57-E($1".CIC;VYN96-T*"D@:6YS=&5A9"X*("`@("`J"B`@("`@*B!)
M9B!02%`@:7,@870@=F5R<VEO;B`U+C`N,"!O<B!G<F5A=&5R.@H@("`@("H@
M("`K($=E;F5R86QL>2P@;V-I7V-O;FYE8W0H*2!O<B!O8VE?<&-O;FYE8W0H
M*2!A<F4@=7-E9"X*("`@("`J("`@*R!"=70@:68@=&AE(&YE=U]L:6YK($13
M3B!O<'1I;VX@:7,@<V5T('1O('1R=64L(&]C:5]N97=?8V]N;F5C="@I"B`@
M("`@*B`@("`@:7,@=7-E9"X*("`@("`J"B`@("`@*B!7:&5N('5S:6YG(%!(
M4"!V97)S:6]N(#0N>"P@3T-)3&]G;VXH*2!O<B!/0TE03&]G;VXH*2!A<F4@
M=7-E9"X*("`@("`J"B`@("`@*B!014%2($1")W,@;V-I."!D<FEV97(@<W5P
M<&]R=',@=&AE(&9O;&QO=VEN9R!E>'1R82!$4TX@;W!T:6]N<SH*("`@("`J
M("`@*R!C:&%R<V5T("`@("`@(%1H92!C:&%R86-T97(@<V5T('1O(&)E('5S
M960@;VX@=&AE(&-O;FYE8W1I;VXN"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@3VYL>2!U<V5D(&EF(%!(4"!I<R!A="!V97)S:6]N(#4N,"XP(&]R(&=R
M96%T97(*("`@("`J("`@("`@("`@("`@("`@("`@("!A;F0@=&AE($]R86-L
M92!S97)V97(@:7,@870@.2XR(&]R(&=R96%T97(N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@079A:6QA8FQE('-I;F-E(%!%05(@1$(@,2XW+C`N"B`@
M("`@*B`@("L@;F5W7VQI;FL@("`@("!)9B!S970@=&\@=')U92P@8V%U<V5S
M('-U8G-E<75E;G0@8V%L;',@=&\*("`@("`J("`@("`@("`@("`@("`@("`@
M("!C;VYN96-T*"D@=&\@<F5T=7)N(&$@;F5W(&-O;FYE8W1I;VX@;&EN:PH@
M("`@("H@("`@("`@("`@("`@("`@("`@(&EN<W1E860@;V8@=&AE(&5X:7-T
M:6YG(&]N92X@(%=!4DY)3D<Z('1H:7,@:7,*("`@("`J("`@("`@("`@("`@
M("`@("`@("!N;W0@<&]R=&%B;&4@=&\@;W1H97(@1$)-4R=S+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@($%V86EL86)L92!S:6YC92!014%2($1"(#$N
M-RXP+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D9'-N("`@("`@("`@
M=&AE(&1A=&$@<V]U<F-E(&YA;64*("`@("`J($!P87)A;2!B;V]L("`D<&5R
M<VES=&5N="`@<VAO=6QD('1H92!C;VYN96-T:6]N(&)E('!E<G-I<W1E;G0_
M"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N
M($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&-O;FYE8W0H)&1S;BP@)'!E<G-I<W1E;G0@/2!F86QS92D*("`@
M('L*("`@("`@("!I9B`H(5!%05(Z.FQO861%>'1E;G-I;VXH)V]C:3@G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)2
M3U)?15A414Y324].7TY/5%]&3U5.1"D["B`@("`@("`@?0H*("`@("`@("`D
M=&AI<RT^9'-N(#T@)&1S;CL*("`@("`@("!I9B`H)&1S;ELG9&)S>6YT87@G
M72D@>PH@("`@("`@("`@("`D=&AI<RT^9&)S>6YT87@@/2`D9'-N6R=D8G-Y
M;G1A>"==.PH@("`@("`@('T*"B`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T
M<R@G;V-I7V-O;FYE8W0G*2D@>PH@("`@("`@("`@("!I9B`H:7-S970H)&1S
M;ELG;F5W7VQI;FLG72D*("`@("`@("`@("`@("`@("8F("@D9'-N6R=N97=?
M;&EN:R==(#T]("=T<G5E)R!\?"`D9'-N6R=N97=?;&EN:R==(#T]/2!T<G5E
M*2D*("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@)&-O;FYE8W1?9G5N
M8W1I;VX@/2`G;V-I7VYE=U]C;VYN96-T)SL*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1C;VYN96-T7V9U;F-T:6]N(#T@)'!E<G-I
M<W1E;G0@/R`G;V-I7W!C;VYN96-T)PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`Z("=O8VE?8V]N;F5C="<["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("\O($)A8VMW87)D<R!C;VUP871I8FEL:71Y('=I=&@@
M1$(@/"`Q+C<N,`H@("`@("`@("`@("!I9B`H96UP='DH)&1S;ELG9&%T86)A
M<V4G72D@)B8@(65M<'1Y*"1D<VY;)VAO<W1S<&5C)UTI*2!["B`@("`@("`@
M("`@("`@("`D9&(@/2`D9'-N6R=H;W-T<W!E8R==.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)&1B(#T@)&1S;ELG9&%T86)A<V4G
M73L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&-H87(@/2!E;7!T>2@D
M9'-N6R=C:&%R<V5T)UTI(#\@;G5L;"`Z("1D<VY;)V-H87)S970G73L*("`@
M("`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!`)&-O;FYE8W1?9G5N8W1I
M;VXH)&1S;ELG=7-E<FYA;64G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1S;ELG<&%S<W=O<F0G72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D8VAA<BD["B`@("`@("`@("`@("1E<G)O<B`]
M($]#245R<F]R*"D["B`@("`@("`@("`@(&EF("@A96UP='DH)&5R<F]R*2`F
M)B`D97)R;W);)V-O9&4G72`]/2`Q,C4T,2D@>PH@("`@("`@("`@("`@("`@
M+R\@0V]U;&1N)W0@9FEN9"!43E,@;&ES=&5N97(N("!4<GD@9&ER96-T(&-O
M;FYE8W1I;VXN"B`@("`@("`@("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`]
M($`D8V]N;F5C=%]F=6YC=&EO;B@D9'-N6R=U<V5R;F%M92==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&1S;ELG<&%S<W=O<F0G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D8VAA<BD["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D8V]N;F5C=%]F=6YC=&EO;B`]("1P97)S:7-T96YT(#\@)T]#
M25!,;V=O;B<@.B`G3T-)3&]G;VXG.PH@("`@("`@("`@("!I9B`H)&1S;ELG
M:&]S='-P96,G72D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F-O;FYE8W1I
M;VX@/2!`)&-O;FYE8W1?9G5N8W1I;VXH)&1S;ELG=7-E<FYA;64G72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1D<VY;)W!A<W-W;W)D)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9'-N6R=H;W-T
M<W!E8R==*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1D<VY;)W5S97)N86UE
M)UT@?'P@)&1S;ELG<&%S<W=O<F0G72D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/F-O;FYE8W1I;VX@/2!`)&-O;FYE8W1?9G5N8W1I;VXH)&1S;ELG=7-E
M<FYA;64G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1D<VY;)W!A<W-W;W)D)UTI.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(21T:&ES+3YC;VYN96-T
M:6]N*2!["B`@("`@("`@("`@("1E<G)O<B`]($]#245R<F]R*"D["B`@("`@
M("`@("`@("1E<G)O<B`]("AI<U]A<G)A>2@D97)R;W(I*2`_("1E<G)O<ELG
M;65S<V%G92==(#H@;G5L;#L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*$1"7T524D]27T-/3DY%0U1?1D%)3$5$+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E<G)O<BD[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!D:7-C;VYN96-T*"D*"B`@("`O*BH*("`@("`J
M($1I<V-O;FYE8W1S(&9R;VT@=&AE(&1A=&%B87-E('-E<G9E<@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;"`@5%)512!O;B!S=6-C97-S+"!&04Q312!O
M;B!F86EL=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N(&1I<V-O;FYE8W0H*0H@
M("`@>PH@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V]C:5]C;&]S92<I
M*2!["B`@("`@("`@("`@("1R970@/2!`;V-I7V-L;W-E*"1T:&ES+3YC;VYN
M96-T:6]N*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5T(#T@
M0$]#24QO9T]F9B@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@?0H@("`@
M("`@("1T:&ES+3YC;VYN96-T:6]N(#T@;G5L;#L*("`@("`@("!R971U<FX@
M)')E=#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!S:6UP;&51=65R
M>2@I"@H@("`@+RHJ"B`@("`@*B!396YD<R!A('%U97)Y('1O('1H92!D871A
M8F%S92!S97)V97(*("`@("`J"B`@("`@*B!4;R!D971E<FUI;F4@:&]W(&UA
M;GD@<F]W<R!O9B!A(')E<W5L="!S970@9V5T(&)U9F9E<F5D('5S:6YG"B`@
M("`@*B!O8VES971P<F5F971C:"@I+"!S964@=&AE(")R97-U;'1?8G5F9F5R
M:6YG(B!O<'1I;VX@:6X@<V5T3W!T:6]N<R@I+@H@("`@("H@5&AI<R!O<'1I
M;VX@=V%S(&%D9&5D(&EN(%)E;&5A<V4@,2XW+C`N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`@=&AE(%-13"!Q=65R>2!S=')I;F<*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("`K(&$@4$A0(')E<W5L="!R97-R;W5C92!F
M;W(@<W5C8V5S<V9U;"!314Q%0U0@<75E<FEE<PH@("`@("H@("`@("`@("`@
M("`@("`@*R!T:&4@1$)?3TL@8V]N<W1A;G0@9F]R(&]T:&5R('-U8V-E<W-F
M=6P@<75E<FEE<PH@("`@("H@("`@("`@("`@("`@("`@*R!A($1"7T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N('-I;7!L
M95%U97)Y*"1Q=65R>2D*("`@('L*("`@("`@("`D=&AI<RT^7V1A=&$@/2!A
M<G)A>2@I.PH@("`@("`@("1T:&ES+3YL87-T7W!A<F%M971E<G,@/2!A<G)A
M>2@I.PH@("`@("`@("1T:&ES+3YL87-T7W%U97)Y(#T@)'%U97)Y.PH@("`@
M("`@("1Q=65R>2`]("1T:&ES+3YM;V1I9GE1=65R>2@D<75E<GDI.PH@("`@
M("`@("1R97-U;'0@/2!`3T-)4&%R<V4H)'1H:7,M/F-O;FYE8W1I;VXL("1Q
M=65R>2D["B`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^;V-I.%)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@
M("`@:68@*"1T:&ES+3YA=71O8V]M;6ET*2!["B`@("`@("`@("`@("1S=6-C
M97-S(#T@0$]#245X96-U=&4H)')E<W5L="Q/0TE?0T]-34E47T].7U-50T-%
M4U,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S=6-C97-S(#T@
M0$]#245X96-U=&4H)')E<W5L="Q/0TE?1$5&055,5"D["B`@("`@("`@?0H@
M("`@("`@(&EF("@A)'-U8V-E<W,I('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YO8VDX4F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@("!]"B`@("`@
M("`@)'1H:7,M/FQA<W1?<W1M="`]("1R97-U;'0["B`@("`@("`@:68@*$1"
M.CII<TUA;FEP*"1Q=65R>2DI('L*("`@("`@("`@("`@<F5T=7)N($1"7T]+
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@($!O8VES971P<F5F971C
M:"@D<F5S=6QT+"`D=&AI<RT^;W!T:6]N<ULG<F5S=6QT7V)U9F9E<FEN9R==
M*3L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YE>'1297-U;'0H*0H*("`@("\J
M*@H@("`@("H@36]V92!T:&4@:6YT97)N86P@;W)A8VQE(')E<W5L="!P;VEN
M=&5R('1O('1H92!N97AT(&%V86EL86)L92!R97-U;'0*("`@("`J"B`@("`@
M*B!`<&%R86T@82!V86QI9"!O8VDX(')E<W5L="!R97-O=7)C90H@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!T
M<G5E(&EF(&$@<F5S=6QT(&ES(&%V86EL86)L92!O=&AE<G=I<V4@<F5T=7)N
M(&9A;'-E"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE>'1297-U;'0H)')E<W5L
M="D*("`@('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@9F5T8VA);G1O*"D*"B`@("`O*BH*("`@("`J(%!L
M86-E<R!A(')O=R!F<F]M('1H92!R97-U;'0@<V5T(&EN=&\@=&AE(&=I=F5N
M(&%R<F%Y"B`@("`@*@H@("`@("H@1F]R;6%T:6YG(&]F('1H92!A<G)A>2!A
M;F0@=&AE(&1A=&$@=&AE<F5I;B!A<F4@8V]N9FEG=7)A8FQE+@H@("`@("H@
M4V5E($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D@9F]R(&UO<F4@:6YF;W)M871I
M;VXN"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O
M(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIF
M971C:$EN=&\H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R
M;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A
M=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S
M=6QT("`@('1H92!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J($!P87)A
M;2!A<G)A>2`@("`D87)R("`@("`@('1H92!R969E<F5N8V5D(&%R<F%Y('1O
M('!U="!T:&4@9&%T82!I;@H@("`@("H@0'!A<F%M(&EN="`@("`@("1F971C
M:&UO9&4@:&]W('1H92!R97-U;'1I;F<@87)R87D@<VAO=6QD(&)E(&EN9&5X
M960*("`@("`J($!P87)A;2!I;G0@("`@("`D<F]W;G5M("`@('1H92!R;W<@
M;G5M8F5R('1O(&9E=&-H("@P(#T@9FER<W0@<F]W*0H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@($1"7T]+(&]N('-U8V-E<W,L($Y53$P@=VAE;B!T
M:&4@96YD(&]F(&$@<F5S=6QT('-E="!I<PH@("`@("H@("`@("`@("`@("`@
M("`@(')E86-H960@;W(@;VX@9F%I;'5R90H@("`@("H*("`@("`J($!S964@
M1$)?<F5S=6QT.CIF971C:$EN=&\H*0H@("`@("HO"B`@("!F=6YC=&EO;B!F
M971C:$EN=&\H)')E<W5L="P@)B1A<G(L("1F971C:&UO9&4L("1R;W=N=6T@
M/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@D<F]W;G5M("$]/2!N=6QL*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/
M4E].3U1?0T%004),12D["B`@("`@("`@?0H@("`@("`@(&EF("@D9F5T8VAM
M;V1E("8@1$)?1D540TA-3T1%7T%34T]#*2!["B`@("`@("`@("`@("1M;W)E
M9&%T82`]($!/0TE&971C:$EN=&\H)')E<W5L="PD87)R+$]#25]!4U-/0RM/
M0TE?4D5455).7TY53$Q3*T]#25]215154DY?3$]"4RD["B`@("`@("`@("`@
M(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!
M0DE,25197TQ/5T520T%312`F)@H@("`@("`@("`@("`@("`@)&UO<F5D871A
M*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@("`D87)R(#T@87)R87E?
M8VAA;F=E7VME>5]C87-E*"1A<G(L($-!4T5?3$]715(I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&UO<F5D871A(#T@
M3T-)1F5T8VA);G1O*"1R97-U;'0L)&%R<BQ/0TE?4D5455).7TY53$Q3*T]#
M25]215154DY?3$]"4RD["B`@("`@("`@?0H@("`@("`@(&EF("@A)&UO<F5D
M871A*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*("`@
M("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]0
M3U)404))3$E465]25%))32D@>PH@("`@("`@("`@("`D=&AI<RT^7W)T<FEM
M07)R87E686QU97,H)&%R<BD["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI
M<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TY5
M3$Q?5$]?14U05%DI('L*("`@("`@("`@("`@)'1H:7,M/E]C;VYV97)T3G5L
M;$%R<F%Y5F%L=65S5&]%;7!T>2@D87)R*3L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9R
M965297-U;'0H*0H*("`@("\J*@H@("`@("H@1&5L971E<R!T:&4@<F5S=6QT
M('-E="!A;F0@9G)E97,@=&AE(&UE;6]R>2!O8V-U<&EE9"!B>2!T:&4@<F5S
M=6QT('-E=`H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N
M="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L
M=#HZ9G)E92@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B<')O
M=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T
M92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U
M;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;"`@5%)512!O;B!S=6-C97-S+"!&04Q312!I9B`D<F5S
M=6QT(&ES(&EN=F%L:60*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ
M9G)E92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&9R965297-U;'0H)')E<W5L
M="D*("`@('L*("`@("`@("!R971U<FX@0$]#249R9653=&%T96UE;G0H)')E
M<W5L="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&<F5E<R!T:&4@:6YT97)N
M86P@<F5S;W5R8V5S(&%S<V]C:6%T960@=VET:"!A('!R97!A<F5D('%U97)Y
M"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1S=&UT("`@("`@("`@
M("!T:&4@<')E<&%R960@<W1A=&5M96YT)W,@<F5S;W5R8V4*("`@("`J($!P
M87)A;2!B;V]L("`@("`D9G)E95]R97-O=7)C92`@<VAO=6QD('1H92!02%`@
M<F5S;W5R8V4@8F4@9G)E960@=&]O/PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@57-E(&9A;'-E(&EF('EO=2!N965D('1O(&=E
M="!D871A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!F<F]M('1H92!R97-U;'0@<V5T(&QA=&5R+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;"`@5%)512!O;B!S=6-C97-S+"!&04Q312!I9B`D<F5S=6QT
M(&ES(&EN=F%L:60*("`@("`J"B`@("`@*B!`<V5E($1"7V]C:3@Z.G!R97!A
M<F4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!F<F5E4')E<&%R960H)'-T;70L
M("1F<F5E7W)E<V]U<F-E(#T@=')U92D*("`@('L*("`@("`@("!I9B`H(6ES
M7W)E<V]U<F-E*"1S=&UT*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H@("`@("`@(&EF("@D9G)E95]R97-O=7)C92D@>PH@("`@
M("`@("`@("!`;V-I9G)E97-T871E;65N="@D<W1M="D["B`@("`@("`@?0H@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^<')E<&%R95]T>7!E<ULH:6YT*21S
M=&UT72DI('L*("`@("`@("`@("`@=6YS970H)'1H:7,M/G!R97!A<F5?='EP
M97-;*&EN="DD<W1M=%TI.PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^;6%N
M:7!?<75E<GE;*&EN="DD<W1M=%TI.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;G5M4F]W<R@I
M"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!N=6UB97(@;V8@<F]W<R!I;B!A
M(')E<W5L="!S970*("`@("`J"B`@("`@*B!/;FQY('=O<FMS(&EF('1H92!$
M0E]03U)404))3$E465].54U23U=3('!O<G1A8FEL:71Y(&]P=&EO;@H@("`@
M("H@:7,@='5R;F5D(&]N+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES
M(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J
M($1"7W)E<W5L=#HZ;G5M4F]W<R@I(&EN<W1E860N("!)="!C86XG="!B92!D
M96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@
M:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E
M<V]U<F-E("1R97-U;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C90H@
M("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(')O=W,N
M("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J
M($!S964@1$)?<F5S=6QT.CIN=6U2;W=S*"DL($1"7V-O;6UO;CHZ<V5T3W!T
M:6]N*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;G5M4F]W<R@D<F5S=6QT*0H@
M("`@>PH@("`@("`@("\O(&5M=6QA=&4@;G5M4F]W<R!F;W(@3W)A8VQE+B`@
M>75C:RX*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y
M)UT@)B!$0E]03U)404))3$E465].54U23U=3("8F"B`@("`@("`@("`@("1R
M97-U;'0@/3T]("1T:&ES+3YL87-T7W-T;70I"B`@("`@("`@>PH@("`@("`@
M("`@("`D8V]U;G1Q=65R>2`]("=314Q%0U0@0T]53E0H*BD@1E)/32`H)RXD
M=&AI<RT^;&%S=%]Q=65R>2XG*2<["B`@("`@("`@("`@("1S879E7W%U97)Y
M(#T@)'1H:7,M/FQA<W1?<75E<GD["B`@("`@("`@("`@("1S879E7W-T;70@
M/2`D=&AI<RT^;&%S=%]S=&UT.PH*("`@("`@("`@("`@:68@*&-O=6YT*"1T
M:&ES+3Y?9&%T82DI('L*("`@("`@("`@("`@("`@("1S;70@/2`D=&AI<RT^
M<')E<&%R92@G4T5,14-4($-/54Y4*"HI($923TT@*"<N)'1H:7,M/FQA<W1?
M<75E<GDN)RDG*3L*("`@("`@("`@("`@("`@("1C;W5N="`]("1T:&ES+3YE
M>&5C=71E*"1S;70L("1T:&ES+3Y?9&%T82D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D8V]U;G0@/28@)'1H:7,M/G%U97)Y*"1C
M;W5N='%U97)Y*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*$1"
M.CII<T5R<F]R*"1C;W5N="D@?'P*("`@("`@("`@("`@("`@($1".CII<T5R
M<F]R*"1R;W<@/2`D8V]U;G0M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]/4D1%
M4D5$*2DI"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@("1T:&ES+3YL
M87-T7W%U97)Y(#T@)'-A=F5?<75E<GD["B`@("`@("`@("`@("`@("`D=&AI
M<RT^;&%S=%]S=&UT(#T@)'-A=F5?<W1M=#L*("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?0T%004),12D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1R;W=;,%T["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%
M4E)/4E].3U1?0T%004),12D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@;G5M0V]L<R@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!N=6UB97(@
M;V8@8V]L=6UN<R!I;B!A(')E<W5L="!S970*("`@("`J"B`@("`@*B!4:&ES
M(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@
M57-E"B`@("`@*B!$0E]R97-U;'0Z.FYU;4-O;',H*2!I;G-T96%D+B`@270@
M8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@
M1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@("H*("`@("`J
M($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G<R!Q=65R>2!R97-U;'0@
M<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E
M<B!O9B!C;VQU;6YS+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ;G5M0V]L<R@I"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&YU;4-O;',H)')E<W5L="D*("`@('L*("`@("`@
M("`D8V]L<R`]($!/0TE.=6U#;VQS*"1R97-U;'0I.PH@("`@("`@(&EF("@A
M)&-O;',I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YO8VDX4F%I<V5%
M<G)O<B@D<F5S=6QT*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1C;VQS
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('!R97!A<F4H*0H*("`@
M("\J*@H@("`@("H@4')E<&%R97,@82!Q=65R>2!F;W(@;75L=&EP;&4@97AE
M8W5T:6]N('=I=&@@97AE8W5T92@I+@H@("`@("H*("`@("`J(%=I=&@@;V-I
M."P@=&AI<R!I<R!E;75L871E9"X*("`@("`J"B`@("`@*B!P<F5P87)E*"D@
M<F5Q=6ER97,@82!G96YE<FEC('%U97)Y(&%S('-T<FEN9R!L:6ME(#QC;V1E
M/@H@("`@("H@("`@24Y315)4($E.5$\@;G5M8F5R<R!604Q515,@*#\L(#\L
M(#\I"B`@("`@*B`\+V-O9&4^+B`@5&AE(#QK8F0^/SPO:V)D/B!C:&%R86-T
M97)S(&%R92!P;&%C96AO;&1E<G,N"B`@("`@*@H@("`@("H@5&AR964@='EP
M97,@;V8@<&QA8V5H;VQD97)S(&-A;B!B92!U<V5D.@H@("`@("H@("`K(#QK
M8F0^/SPO:V)D/B`@82!Q=6]T960@<V-A;&%R('9A;'5E+"!I+F4N('-T<FEN
M9W,L(&EN=&5G97)S"B`@("`@*B`@("L@/&MB9#XA/"]K8F0^("!V86QU92!I
M<R!I;G-E<G1E9"`G87,@:7,G"B`@("`@*B`@("L@/&MB9#XF/"]K8F0^("!R
M97%U:7)E<R!A(&9I;&4@;F%M92X@(%1H92!F:6QE)W,@8V]N=&5N=',@9V5T
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&EN<V5R=&5D(&EN=&\@=&AE
M('%U97)Y("AI+F4N('-A=FEN9R!B:6YA<GD*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@9&%T82!I;B!A(&1B*0H@("`@("H*("`@("`J(%5S92!B86-K
M<VQA<VAE<R!T;R!E<V-A<&4@<&QA8V5H;VQD97(@8VAA<F%C=&5R<R!I9B!Y
M;W4@9&]N)W0@=V%N=`H@("`@("H@=&AE;2!T;R!B92!I;G1E<G!R971E9"!A
M<R!P;&%C96AO;&1E<G,N("!%>&%M<&QE.B`\8V]D93X*("`@("`J("`@(")5
M4$1!5$4@9F]O(%-%5"!C;VP]/R!72$5212!C;VP])V]V97(@7"8@=6YD97(G
M(@H@("`@("H@/"]C;V1E/@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'%U97)Y("!T:&4@<75E<GD@=&\@8F4@<')E<&%R960*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!$0B!S=&%T96UE;G0@<F5S;W5R8V4@;VX@<W5C
M8V5S<RX@1$)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E
M($1"7V]C:3@Z.F5X96-U=&4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!P<F5P
M87)E*"1Q=65R>2D*("`@('L*("`@("`@("`D=&]K96YS("`@/2!P<F5G7W-P
M;&ET*"<O*"@_/"%<7%PI6R8_(5TI+R<L("1Q=65R>2P@+3$L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!04D5'7U-03$E47T1%3$E-7T-!4%15
M4D4I.PH@("`@("`@("1B:6YD<R`@("`](&-O=6YT*"1T;VME;G,I("T@,3L*
M("`@("`@("`D=&]K96X@("`@/2`P.PH@("`@("`@("1T>7!E<R`@("`](&%R
M<F%Y*"D["B`@("`@("`@)&YE=W%U97)Y(#T@)R<["@H@("`@("`@(&9O<F5A
M8V@@*"1T;VME;G,@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@('-W
M:71C:"`H)'9A;"D@>PH@("`@("`@("`@("`@("`@8V%S92`G/R<Z"B`@("`@
M("`@("`@("`@("`@("`@)'1Y<&5S6R1T;VME;BLK72`]($1"7U!!4D%-7U-#
M04Q!4CL*("`@("`@("`@("`@("`@("`@("!U;G-E="@D=&]K96YS6R1K97E=
M*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M(&-A<V4@)R8G.@H@("`@("`@("`@("`@("`@("`@("1T>7!E<ULD=&]K96XK
M*UT@/2!$0E]005)!35]/4$%1544["B`@("`@("`@("`@("`@("`@("`@=6YS
M970H)'1O:V5N<ULD:V5Y72D["B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("!C87-E("<A)SH*("`@("`@("`@("`@("`@("`@
M("`D='EP97-;)'1O:V5N*RM=(#T@1$)?4$%204U?34E30SL*("`@("`@("`@
M("`@("`@("`@("!U;G-E="@D=&]K96YS6R1K97E=*3L*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@
M("`@("`@("`@("`@("`@)'1O:V5N<ULD:V5Y72`]('!R96=?<F5P;&%C92@G
M+UQ<7"A;)C\A72DO)RP@(EQ<,2(L("1V86PI.PH@("`@("`@("`@("`@("`@
M("`@(&EF("@D:V5Y("$]("1B:6YD<RD@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D;F5W<75E<GD@+CT@)'1O:V5N<ULD:V5Y72`N("<Z8FEN9"<@+B`D
M=&]K96X["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&YE=W%U97)Y("X]("1T;VME;G-;)&ME>5T["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`D=&AI<RT^;&%S=%]Q=65R>2`]("1Q=65R>3L*("`@("`@("`D
M;F5W<75E<GD@/2`D=&AI<RT^;6]D:69Y475E<GDH)&YE=W%U97)Y*3L*("`@
M("`@("!I9B`H(21S=&UT(#T@0$]#25!A<G-E*"1T:&ES+3YC;VYN96-T:6]N
M+"`D;F5W<75E<GDI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;V-I
M.%)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/G!R97!A
M<F5?='EP97-;*&EN="DD<W1M=%T@/2`D='EP97,["B`@("`@("`@)'1H:7,M
M/FUA;FEP7W%U97)Y6RAI;G0I)'-T;71=(#T@1$(Z.FES36%N:7`H)'%U97)Y
M*3L*("`@("`@("!R971U<FX@)'-T;70["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@97AE8W5T92@I"@H@("`@+RHJ"B`@("`@*B!%>&5C=71E<R!A
M($1"('-T871E;65N="!P<F5P87)E9"!W:71H('!R97!A<F4H*2X*("`@("`J
M"B`@("`@*B!4;R!D971E<FUI;F4@:&]W(&UA;GD@<F]W<R!O9B!A(')E<W5L
M="!S970@9V5T(&)U9F9E<F5D('5S:6YG"B`@("`@*B!O8VES971P<F5F971C
M:"@I+"!S964@=&AE(")R97-U;'1?8G5F9F5R:6YG(B!O<'1I;VX@:6X@<V5T
M3W!T:6]N<R@I+@H@("`@("H@5&AI<R!O<'1I;VX@=V%S(&%D9&5D(&EN(%)E
M;&5A<V4@,2XW+C`N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("`D
M<W1M="`@82!$0B!S=&%T96UE;G0@<F5S;W5R8V4@<F5T=7)N960@9G)O;2!P
M<F5P87)E*"D*("`@("`J($!P87)A;2!M:7AE9"`@)&1A=&$@(&%R<F%Y+"!S
M=')I;F<@;W(@;G5M97)I8R!D871A('1O(&)E('5S960@:6X*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@(&5X96-U=&EO;B!O9B!T:&4@<W1A=&5M96YT
M+B`@475A;G1I='D@;V8@:71E;7,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@('!A<W-E9"!M=7-T(&UA=&-H('%U86YT:71Y(&]F('!L86-E:&]L9&5R
M<R!I;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@<75E<GDZ("!M96%N
M:6YG(#$@9F]R(&YO;BUA<G)A>2!I=&5M<R!O<B!T:&4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@('%U86YT:71Y(&]F(&5L96UE;G1S(&EN('1H92!A
M<G)A>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!R971U<FYS(&%N
M(&]I8S@@<F5S=6QT(')E<V]U<F-E(&9O<B!S=6-C97-S9G5L(%-%3$5#5`H@
M("`@("H@("`@("`@("`@("`@("`@<75E<FEE<RP@1$)?3TL@9F]R(&]T:&5R
M('-U8V-E<W-F=6P@<75E<FEE<RX*("`@("`J("`@("`@("`@("`@("`@($$@
M1$(@97)R;W(@;V)J96-T(&ES(')E='5R;F5D(&]N(&9A:6QU<F4N"B`@("`@
M*@H@("`@("H@0'-E92!$0E]O8VDX.CIP<F5P87)E*"D*("`@("`J+PH@("`@
M9G5N8W1I;VX@)F5X96-U=&4H)'-T;70L("1D871A(#T@87)R87DH*2D*("`@
M('L*("`@("`@("`D9&%T82`]("AA<G)A>2DD9&%T83L*("`@("`@("`D=&AI
M<RT^;&%S=%]P87)A;65T97)S(#T@)&1A=&$["B`@("`@("`@)'1H:7,M/E]D
M871A(#T@)&1A=&$["@H@("`@("`@("1T>7!E<R`])B`D=&AI<RT^<')E<&%R
M95]T>7!E<ULH:6YT*21S=&UT73L*("`@("`@("!I9B`H8V]U;G0H)'1Y<&5S
M*2`A/2!C;W5N="@D9&%T82DI('L*("`@("`@("`@("`@)'1M<"`])B`D=&AI
M<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]-25--051#2"D["B`@("`@("`@("`@
M(')E='5R;B`D=&UP.PH@("`@("`@('T*"B`@("`@("`@)&D@/2`P.PH@("`@
M("`@(&9O<F5A8V@@*"1D871A(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@
M("`@("`@(&EF("@D='EP97-;)&E=(#T]($1"7U!!4D%-7TU)4T,I('L*("`@
M("`@("`@("`@("`@("\J"B`@("`@("`@("`@("`@("`@*B!/<F%C;&4@9&]E
M<VXG="!S965M('1O(&AA=F4@=&AE(&%B:6QI='D@=&\@<&%S<R!A"B`@("`@
M("`@("`@("`@("`@*B!P87)A;65T97(@86QO;F<@=6YC:&%N9V5D+"!S;R!S
M=')I<"!O9F8@<75O=&5S(&9R;VT@<W1A<G0*("`@("`@("`@("`@("`@("`J
M(&%N9"!E;F0L('!L=7,@='5R;B!T=V\@<VEN9VQE('%U;W1E<R!T;R!O;F4@
M<VEN9VQE('%U;W1E+`H@("`@("`@("`@("`@("`@("H@:6X@;W)D97(@=&\@
M879O:60@=&AE('%U;W1E<R!G971T:6YG(&5S8V%P960@8GD*("`@("`@("`@
M("`@("`@("`J($]R86-L92!A;F0@96YD:6YG('5P(&EN('1H92!D871A8F%S
M92X*("`@("`@("`@("`@("`@("`J+PH@("`@("`@("`@("`@("`@)&1A=&%;
M)&ME>5T@/2!P<F5G7W)E<&QA8V4H(B]>)R@N*BDG)"\B+"`B7%PQ(BP@)&1A
M=&%;)&ME>5TI.PH@("`@("`@("`@("`@("`@)&1A=&%;)&ME>5T@/2!S=')?
M<F5P;&%C92@B)R<B+"`B)R(L("1D871A6R1K97E=*3L*("`@("`@("`@("`@
M?2!E;'-E:68@*"1T>7!E<ULD:5T@/3T@1$)?4$%204U?3U!!455%*2!["B`@
M("`@("`@("`@("`@("`D9G`@/2!`9F]P96XH)&1A=&%;)&ME>5TL("=R8B<I
M.PH@("`@("`@("`@("`@("`@:68@*"$D9G`I('L*("`@("`@("`@("`@("`@
M("`@("`D=&UP(#TF("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27T%#0T53
M4U]624],051)3TXI.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&UP
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&1A=&%;)&ME
M>5T@/2!F<F5A9"@D9G`L(&9I;&5S:7IE*"1D871A6R1K97E=*2D["B`@("`@
M("`@("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!I9B`H(4!/0TE":6YD0GE.86UE*"1S=&UT+"`G.F)I;F0G("X@)&DL
M("1D871A6R1K97E=+"`M,2DI('L*("`@("`@("`@("`@("`@("1T;7`@/2`D
M=&AI<RT^;V-I.%)A:7-E17)R;W(H)'-T;70I.PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1T;7`["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&DK*SL*
M("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YA=71O8V]M;6ET*2!["B`@
M("`@("`@("`@("1S=6-C97-S(#T@0$]#245X96-U=&4H)'-T;70L($]#25]#
M3TU-251?3TY?4U5#0T534RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'-U8V-E<W,@/2!`3T-)17AE8W5T92@D<W1M="P@3T-)7T1%1D%53%0I
M.PH@("`@("`@('T*("`@("`@("!I9B`H(21S=6-C97-S*2!["B`@("`@("`@
M("`@("1T;7`@/2`D=&AI<RT^;V-I.%)A:7-E17)R;W(H)'-T;70I.PH@("`@
M("`@("`@("!R971U<FX@)'1M<#L*("`@("`@("!]"B`@("`@("`@)'1H:7,M
M/FQA<W1?<W1M="`]("1S=&UT.PH@("`@("`@(&EF("@D=&AI<RT^;6%N:7!?
M<75E<GE;*&EN="DD<W1M=%TI('L*("`@("`@("`@("`@)'1M<"`]($1"7T]+
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@($!O8VES971P<F5F971C
M:"@D<W1M="P@)'1H:7,M/F]P=&EO;G-;)W)E<W5L=%]B=69F97)I;F<G72D[
M"B`@("`@("`@("`@("1T;7`@/28@;F5W($1"7W)E<W5L="@D=&AI<RP@)'-T
M;70I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1M<#L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!A=71O0V]M;6ET*"D*"B`@("`O*BH*("`@
M("`J($5N86)L97,@;W(@9&ES86)L97,@875T;VUA=&EC(&-O;6UI=',*("`@
M("`J"B`@("`@*B!`<&%R86T@8F]O;"`D;VYO9F8@('1R=64@='5R;G,@:70@
M;VXL(&9A;'-E('1U<FYS(&ET(&]F9@H@("`@("H*("`@("`J($!R971U<FX@
M:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@:68@
M=&AE(&1R:79E<@H@("`@("H@("`@("`@("`@("`@("!D;V5S;B=T('-U<'!O
M<G0@875T;RUC;VUM:71T:6YG('1R86YS86-T:6]N<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@875T;T-O;6UI="@D;VYO9F8@/2!F86QS92D*("`@('L*("`@
M("`@("`D=&AI<RT^875T;V-O;6UI="`]("AB;V]L*21O;F]F9CL["B`@("`@
M("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&-O;6UI="@I"@H@("`@+RHJ"B`@("`@*B!#;VUM:71S('1H92!C=7)R96YT
M('1R86YS86-T:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+
M(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!C;VUM:70H*0H@("`@>PH@("`@("`@("1R
M97-U;'0@/2!`3T-)0V]M;6ET*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@
M("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YO
M8VDX4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@1$)?
M3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<F]L;&)A8VLH*0H*
M("`@("\J*@H@("`@("H@4F5V97)T<R!T:&4@8W5R<F5N="!T<F%N<V%C=&EO
M;@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S
M+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F]L;&)A8VLH*0H@("`@>PH@("`@("`@("1R97-U;'0@/2!`
M3T-)4F]L;&)A8VLH)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@(&EF("@A
M)')E<W5L="D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]C:3A286ES
M945R<F]R*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!A9F9E8W1E9%)O=W,H*0H*("`@
M("\J*@H@("`@("H@1&5T97)M:6YE<R!T:&4@;G5M8F5R(&]F(')O=W,@869F
M96-T960@8GD@82!D871A(&UA;FEU<&QA=&EO;B!Q=65R>0H@("`@("H*("`@
M("`J(#`@:7,@<F5T=7)N960@9F]R('%U97)I97,@=&AA="!D;VXG="!M86YI
M<'5L871E(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N
M=6UB97(@;V8@<F]W<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&%F9F5C=&5D4F]W<R@I"B`@("!["B`@
M("`@("`@:68@*"1T:&ES+3YL87-T7W-T;70@/3T](&9A;'-E*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^;V-I.%)A:7-E17)R;W(H*3L*("`@("`@
M("!]"B`@("`@("`@)')E<W5L="`]($!/0TE2;W=#;W5N="@D=&AI<RT^;&%S
M=%]S=&UT*3L*("`@("`@("!I9B`H)')E<W5L="`]/3T@9F%L<V4I('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YO8VDX4F%I<V5%<G)O<B@D=&AI<RT^
M;&%S=%]S=&UT*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;6]D:69Y475E<GDH*0H*
M("`@("\J*@H@("`@("H@0VAA;F=E<R!A('%U97)Y('-T<FEN9R!F;W(@=F%R
M:6]U<R!$0DU3('-P96-I9FEC(')E87-O;G,*("`@("`J"B`@("`@*B`B4T5,
M14-4(#(K,B(@;75S="!B92`B4T5,14-4(#(K,B!&4D]-(&1U86PB(&EN($]R
M86-L92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1Q=65R>2`@=&AE
M('%U97)Y('-T<FEN9R!T;R!M;V1I9GD*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@=&AE(&UO9&EF:65D('%U97)Y('-T<FEN9PH@("`@("H*("`@
M("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO
M9&EF>5%U97)Y*"1Q=65R>2D*("`@('L*("`@("`@("!I9B`H<')E9U]M871C
M:"@G+UY<<RI314Q%0U0O:2<L("1Q=65R>2D@)B8*("`@("`@("`@("`@(7!R
M96=?;6%T8V@H)R]<<T923TU<<R]I)RP@)'%U97)Y*2D@>PH@("`@("`@("`@
M("`D<75E<GD@+CT@)R!&4D]-(&1U86PG.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)'%U97)Y.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&UO
M9&EF>4QI;6ET475E<GDH*0H*("`@("\J*@H@("`@("H@061D<R!,24U)5"!C
M;&%U<V5S('1O(&$@<75E<GD@<W1R:6YG(&%C8V]R9&EN9R!T;R!C=7)R96YT
M($1"35,@<W1A;F1A<F1S"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<75E<GD@("!T:&4@<75E<GD@=&\@;6]D:69Y"B`@("`@*B!`<&%R86T@:6YT
M("`@("1F<F]M("`@('1H92!R;W<@=&\@<W1A<G0@=&\@9F5T8VAI;F<@*#`@
M/2!T:&4@9FER<W0@<F]W*0H@("`@("H@0'!A<F%M(&EN="`@("`D8V]U;G0@
M("!T:&4@;G5M8F5R<R!O9B!R;W=S('1O(&9E=&-H"B`@("`@*B!`<&%R86T@
M;6EX960@("1P87)A;7,@(&%R<F%Y+"!S=')I;F<@;W(@;G5M97)I8R!D871A
M('1O(&)E('5S960@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M(&5X96-U=&EO;B!O9B!T:&4@<W1A=&5M96YT+B`@475A;G1I='D@;V8@:71E
M;7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A<W-E9"!M=7-T
M(&UA=&-H('%U86YT:71Y(&]F('!L86-E:&]L9&5R<R!I;@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@<75E<GDZ("!M96%N:6YG(#$@<&QA8V5H
M;VQD97(@9F]R(&YO;BUA<G)A>0H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@<&%R86UE=&5R<R!O<B`Q('!L86-E:&]L9&5R('!E<B!A<G)A>2!E
M;&5M96YT+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@<75E
M<GD@<W1R:6YG('=I=&@@3$E-250@8VQA=7-E<R!A9&1E9`H@("`@("H*("`@
M("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO
M9&EF>4QI;6ET475E<GDH)'%U97)Y+"`D9G)O;2P@)&-O=6YT+"`D<&%R86US
M(#T@87)R87DH*2D*("`@('L*("`@("`@("`O+R!,970@3W)A8VQE(')E='5R
M;B!T:&4@;F%M92!O9B!T:&4@8V]L=6UN<R!I;G-T96%D(&]F"B`@("`@("`@
M+R\@8V]D:6YG(&$@(FAO;64B(%-13"!P87)S97(*"B`@("`@("`@:68@*&-O
M=6YT*"1P87)A;7,I*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M<')E<&%R92@B4T5,14-4("H@1E)/32`H)'%U97)Y*2`B"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`N("=72$5212!.54Q,(#T@3E5,
M3"<I.PH@("`@("`@("`@("`D=&UP(#TF("1T:&ES+3YE>&5C=71E*"1R97-U
M;'0L("1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1Q
M7V9I96QD<R`](")314Q%0U0@*B!&4D]-("@D<75E<GDI(%=(15)%($Y53$P@
M/2!.54Q,(CL*"B`@("`@("`@("`@(&EF("@A)')E<W5L="`]($!/0TE087)S
M92@D=&AI<RT^8V]N;F5C=&EO;BP@)'%?9FEE;&1S*2D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/FQA<W1?<75E<GD@/2`D<5]F:65L9',["B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/F]C:3A286ES945R<F]R*"D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@:68@*"%`3T-)17AE8W5T92@D<F5S=6QT
M+"!/0TE?1$5&055,5"DI('L*("`@("`@("`@("`@("`@("1T:&ES+3YL87-T
M7W%U97)Y(#T@)'%?9FEE;&1S.PH@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YO8VDX4F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@)&YC;VQS(#T@3T-)3G5M0V]L<R@D<F5S=6QT
M*3L*("`@("`@("`D8V]L<R`@/2!A<G)A>2@I.PH@("`@("`@(&9O<B`H("1I
M(#T@,3L@)&D@/#T@)&YC;VQS.R`D:2LK("D@>PH@("`@("`@("`@("`D8V]L
M<UM=(#T@)R(G("X@3T-)0V]L=6UN3F%M92@D<F5S=6QT+"`D:2D@+B`G(B<[
M"B`@("`@("`@?0H@("`@("`@("1F:65L9',@/2!I;7!L;V1E*"<L("<L("1C
M;VQS*3L*("`@("`@("`O+R!86%@@5&5S="!T:&%T("AT:7`@8GD@2F]H;B!,
M:6TI"B`@("`@("`@+R]I9B`H<')E9U]M871C:"@G+UY<<RI314Q%0U1<<RLO
M:7,G+"`D<75E<GDL("1M871C:"DI('L*("`@("`@("`O+R`@("`O+R!);G1R
M;V1U8V4@=&AE($9)4E-47U)/5U,@3W)A8VQE('%U97)Y(&]P=&EM:7IE<@H@
M("`@("`@("\O("`@("1Q=65R>2`]('-U8G-T<B@D<75E<GDL('-T<FQE;B@D
M;6%T8VA;,%TI+"!S=')L96XH)'%U97)Y*2D["B`@("`@("`@+R\@("`@)'%U
M97)Y(#T@(E-%3$5#5"`O*B`K1DE24U1?4D]74R`J+R`B("X@)'%U97)Y.PH@
M("`@("`@("\O?0H*("`@("`@("`O+R!#;VYS=')U8W0@=&AE('%U97)Y"B`@
M("`@("`@+R\@;6]R92!A=#H@:'1T<#HO+VUA<F,N=&AE86EM<V=R;W5P+F-O
M;2\_;#UP:'`M9&(F;3TY.3@S,3DU.#$P,3(Q,B9W/3(*("`@("`@("`O+R!0
M97)H87!S('1H:7,@8V]U;&0@8F4@;W!T:6UI>F5D('=I=&@@=&AE('5S92!O
M9B!5;FEO;G,*("`@("`@("`D<75E<GD@/2`B4T5,14-4("1F:65L9',@1E)/
M32(N"B`@("`@("`@("`@("`@("`@(B`@*%-%3$5#5"!R;W=N=6T@87,@;&EN
M96YU;2P@)&9I96QD<R!&4D]-(BX*("`@("`@("`@("`@("`@("`B("`@("`@
M*"1Q=65R>2DB+@H@("`@("`@("`@("`@("`@("<@(%=(15)%(')O=VYU;2`\
M/2`G+B`H)&9R;VT@*R`D8V]U;G0I("X*("`@("`@("`@("`@("`@("`G*2!7
M2$5212!L:6YE;G5M(#X]("<@+B`K*R1F<F]M.PH@("`@("`@(')E='5R;B`D
M<75E<GD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;F5X=$ED*"D*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&YE>'0@9G)E92!I9"!I;B!A
M('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-E<5]N
M86UE("!N86UE(&]F('1H92!S97%U96YC90H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&]N9&5M86YD("!W:&5N('1R=64L('1H92!S97%E;F-E(&ES(&%U=&]M
M871I8V%L;'D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-R
M96%T960@:68@:70@9&]E<R!N;W0@97AI<W0*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN="`@=&AE(&YE>'0@:60@;G5M8F5R(&EN('1H92!S97%U96YC92X*
M("`@("`J("`@("`@("`@("`@("`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I
M;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ;F5X=$E$*"DL
M($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@*B`@("`@($1"
M7V]C:3@Z.F-R96%T95-E<75E;F-E*"DL($1"7V]C:3@Z.F1R;W!397%U96YC
M92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE>'1)9"@D<V5Q7VYA;64L("1O
M;F1E;6%N9"`]('1R=64I"B`@("!["B`@("`@("`@)'-E<6YA;64@/2`D=&AI
M<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M92D["B`@("`@("`@)')E<&5A
M="`](#`["B`@("`@("`@9&\@>PH@("`@("`@("`@("`D=&AI<RT^97AP96-T
M17)R;W(H1$)?15)23U)?3D]354-(5$%"3$4I.PH@("`@("`@("`@("`D<F5S
M=6QT(#TF("1T:&ES+3YQ=65R>2@B4T5,14-4("1[<V5Q;F%M97TN;F5X='9A
M;"!&4D]-(&1U86PB*3L*("`@("`@("`@("`@)'1H:7,M/G!O<$5X<&5C="@I
M.PH@("`@("`@("`@("!I9B`H)&]N9&5M86YD("8F($1".CII<T5R<F]R*"1R
M97-U;'0I("8F"B`@("`@("`@("`@("`@("`D<F5S=6QT+3YG971#;V1E*"D@
M/3T@1$)?15)23U)?3D]354-(5$%"3$4I('L*("`@("`@("`@("`@("`@("1R
M97!E870@/2`Q.PH@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YC
M<F5A=&5397%U96YC92@D<V5Q7VYA;64I.PH@("`@("`@("`@("`@("`@:68@
M*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)')E<&5A="`](#`["B`@("`@("`@("`@('T*("`@("`@("!]('=H:6QE("@D
M<F5P96%T*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I
M.PH@("`@("`@('T*("`@("`@("`D87)R(#T@)')E<W5L="T^9F5T8VA2;W<H
M1$)?1D540TA-3T1%7T]21$52140I.PH@("`@("`@(')E='5R;B`D87)R6S!=
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A(&YE=R!S97%U96YC
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-E<5]N86UE("!N86UE
M(&]F('1H92!N97<@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN
M="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F-R96%T95-E
M<75E;F-E*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@
M*B`@("`@($1"7V]C:3@Z.FYE>'1)1"@I+"!$0E]O8VDX.CID<F]P4V5Q=65N
M8V4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A=&5397%U96YC92@D<V5Q
M7VYA;64I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YQ=65R>2@G0U)%
M051%(%-%455%3D-%("<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@
M)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I*3L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!D<F]P4V5Q=65N8V4H*0H*("`@("\J*@H@
M("`@("H@1&5L971E<R!A('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E;F-E('1O(&)E
M(&1E;&5T960*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@
M<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F1R;W!397%U96YC92@I+"!$0E]C
M;VUM;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@("`@("!$0E]O8VDX
M.CIN97AT240H*2P@1$)?;V-I.#HZ8W)E871E4V5Q=65N8V4H*0H@("`@("HO
M"B`@("!F=6YC=&EO;B!D<F]P4V5Q=65N8V4H)'-E<5]N86UE*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^<75E<GDH)T123U`@4T51545.0T4@)PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^9V5T4V5Q=65N
M8V5.86UE*"1S97%?;F%M92DI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&]C:3A286ES945R<F]R*"D*"B`@("`O*BH*("`@("`J(%!R;V1U8V5S
M(&$@1$)?17)R;W(@;V)J96-T(')E9V%R9&EN9R!T:&4@8W5R<F5N="!P<F]B
M;&5M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`D97)R;F\@(&EF('1H92!E
M<G)O<B!I<R!B96EN9R!M86YU86QL>2!R86ES960@<&%S<R!A"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@($1"7T524D]2*B!C;VYS=&%N="!H97)E+B`@
M268@=&AI<R!I<VXG="!P87-S960*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@=&AE(&5R<F]R(&EN9F]R;6%T:6]N(&=A=&AE<F5D(&9R;VT@=&AE($1"
M35,N"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@('1H92!$0E]%<G)O
M<B!O8FIE8W0*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<F%I<V5%
M<G)O<B@I+`H@("`@("H@("`@("!$0E]O8VDX.CIE<G)O<DYA=&EV92@I+"!$
M0E]O8VDX.CIE<G)O<D-O9&4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!O8VDX
M4F%I<V5%<G)O<B@D97)R;F\@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@D
M97)R;F\@/3T](&YU;&PI('L*("`@("`@("`@("`@)&5R<F]R(#T@0$]#245R
M<F]R*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*"1T:&ES+3YE<G)O<D-O9&4H)&5R<F]R6R=C;V1E
M)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;G5L
M;"P@;G5L;"P@;G5L;"P@)&5R<F]R6R=M97-S86=E)UTI.PH@("`@("`@('T@
M96QS96EF("AI<U]R97-O=7)C92@D97)R;F\I*2!["B`@("`@("`@("`@("1E
M<G)O<B`]($!/0TE%<G)O<B@D97)R;F\I.PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)'1H:7,M/F5R<F]R0V]D92@D97)R;W);)V-O
M9&4G72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N
M=6QL+"!N=6QL+"!N=6QL+"`D97)R;W);)VUE<W-A9V4G72D["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D=&AI<RT^97)R
M;W)#;V1E*"1E<G)N;RDI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&5R<F]R3F%T:79E*"D*"B`@("`O*BH*("`@("`J($=E=',@=&AE($1"35,G
M(&YA=&EV92!E<G)O<B!C;V1E('!R;V1U8V5D(&)Y('1H92!L87-T('%U97)Y
M"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!$0DU3)R!E<G)O<B!C
M;V1E+B`@1D%,4T4@:68@=&AE(&-O9&4@8V]U;&0@;F]T(&)E"B`@("`@*B`@
M("`@("`@("`@("`@(&1E=&5R;6EN960*("`@("`J+PH@("`@9G5N8W1I;VX@
M97)R;W).871I=F4H*0H@("`@>PH@("`@("`@(&EF("AI<U]R97-O=7)C92@D
M=&AI<RT^;&%S=%]S=&UT*2D@>PH@("`@("`@("`@("`D97)R;W(@/2!`3T-)
M17)R;W(H)'1H:7,M/FQA<W1?<W1M="D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&5R<F]R(#T@0$]#245R<F]R*"1T:&ES+3YC;VYN96-T:6]N
M*3L*("`@("`@("!]"B`@("`@("`@:68@*&ES7V%R<F%Y*"1E<G)O<BDI('L*
M("`@("`@("`@("`@<F5T=7)N("1E<G)O<ELG8V]D92==.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@=&%B;&5);F9O*"D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@:6YF
M;W)M871I;VX@86)O=70@82!T86)L92!O<B!A(')E<W5L="!S970*("`@("`J
M"B`@("`@*B!.3U1%.B!O;FQY('-U<'!O<G1S("=T86)L92<@86YD("=F;&%G
M<R<@:68@/'9A<CXD<F5S=6QT/"]V87(^"B`@("`@*B!I<R!A('1A8FQE(&YA
M;64N"B`@("`@*@H@("`@("H@3D]413H@9FQA9W,@=V]N)W0@8V]N=&%I;B!I
M;F1E>"!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T
M?'-T<FEN9R`@)')E<W5L="`@1$)?<F5S=6QT(&]B:F5C="!F<F]M(&$@<75E
M<GD@;W(@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!S=')I;F<@8V]N=&%I;FEN9R!T:&4@;F%M92!O9B!A('1A8FQE+@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!7:&EL92!T:&ES
M(&%L<V\@86-C97!T<R!A('%U97)Y(')E<W5L=`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!R97-O=7)C92!I9&5N=&EF:65R+"!T
M:&ES(&)E:&%V:6]R(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&1E<')E8V%T960N"B`@("`@*B!`<&%R86T@:6YT("`@("`@
M("`@("`@)&UO9&4@("`@82!V86QI9"!T86)L94EN9F\@;6]D90H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@(&%N(&%S<V]C:6%T:79E(&%R<F%Y('=I
M=&@@=&AE(&EN9F]R;6%T:6]N(')E<75E<W1E9"X*("`@("`J("`@("`@("`@
M("`@("`@("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*
M("`@("`J($!S964@1$)?8V]M;6]N.CIT86)L94EN9F\H*0H@("`@("HO"B`@
M("!F=6YC=&EO;B!T86)L94EN9F\H)')E<W5L="P@)&UO9&4@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG
M72`F($1"7U!/4E1!0DE,25197TQ/5T520T%312D@>PH@("`@("`@("`@("`D
M8V%S95]F=6YC(#T@)W-T<G1O;&]W97(G.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1C87-E7V9U;F,@/2`G<W1R=F%L)SL*("`@("`@("!]"@H@
M("`@("`@("1R97,@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H:7-?<W1R:6YG
M*"1R97-U;'0I*2!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R
M;V)A8FQY(')E8V5I=F5D(&$@=&%B;&4@;F%M92X*("`@("`@("`@("`@("H@
M0W)E871E(&$@<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@("`@
M("`@("`J+PH@("`@("`@("`@("`D<F5S=6QT(#T@<W1R=&]U<'!E<B@D<F5S
M=6QT*3L*("`@("`@("`@("`@)'%?9FEE;&1S(#T@)U-%3$5#5"!C;VQU;6Y?
M;F%M92P@9&%T85]T>7!E+"!D871A7VQE;F=T:"P@)PH@("`@("`@("`@("`@
M("`@("`@("`@("`N("=N=6QL86)L92`G"B`@("`@("`@("`@("`@("`@("`@
M("`@("X@)T923TT@=7-E<E]T86)?8V]L=6UN<R`G"B`@("`@("`@("`@("`@
M("`@("`@("`@("X@(E=(15)%('1A8FQE7VYA;64])R1R97-U;'0G($]21$52
M($)9(&-O;'5M;E]I9"(["@H@("`@("`@("`@("`D=&AI<RT^;&%S=%]Q=65R
M>2`]("1Q7V9I96QD<SL*"B`@("`@("`@("`@(&EF("@A)'-T;70@/2!`3T-)
M4&%R<V4H)'1H:7,M/F-O;FYE8W1I;VXL("1Q7V9I96QD<RDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^;V-I.%)A:7-E17)R;W(H1$)?15)2
M3U)?3D5%1%]-3U)%7T1!5$$I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("@A0$]#245X96-U=&4H)'-T;70L($]#25]$149!54Q4*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YO8VDX4F%I<V5%<G)O<B@D<W1M
M="D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1I(#T@,#L*("`@("`@
M("`@("`@=VAI;&4@*$!/0TE&971C:"@D<W1M="DI('L*("`@("`@("`@("`@
M("`@("1R97-;)&E=(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)W1A
M8FQE)R`]/B`D8V%S95]F=6YC*"1R97-U;'0I+`H@("`@("`@("`@("`@("`@
M("`@("=N86UE)R`@/3X@)&-A<V5?9G5N8RA`3T-)4F5S=6QT*"1S=&UT+"`Q
M*2DL"B`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B!`3T-)4F5S=6QT
M*"1S=&UT+"`R*2P*("`@("`@("`@("`@("`@("`@("`G;&5N)R`@(#T^($!/
M0TE297-U;'0H)'-T;70L(#,I+`H@("`@("`@("`@("`@("`@("`@("=F;&%G
M<R<@/3X@*$!/0TE297-U;'0H)'-T;70L(#0I(#T]("=.)RD@/R`G;F]T7VYU
M;&PG(#H@)R<L"B`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@("`@("`@
M:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/7T]21$52*2!["B`@("`@("`@("`@
M("`@("`@("`@)')E<ULG;W)D97(G75LD<F5S6R1I75LG;F%M92==72`]("1I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1M;V1E
M("8@1$)?5$%"3$5)3D9/7T]21$525$%"3$4I('L*("`@("`@("`@("`@("`@
M("`@("`D<F5S6R=O<F1E<G1A8FQE)UU;)')E<ULD:5U;)W1A8FQE)UU=6R1R
M97-;)&E=6R=N86UE)UU=(#T@)&D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D:2LK.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I
M9B`H)&UO9&4I('L*("`@("`@("`@("`@("`@("1R97-;)VYU;5]F:65L9',G
M72`]("1I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@($!/0TE&<F5E4W1A
M=&5M96YT*"1S=&UT*3L*"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M:68@*&ES<V5T*"1R97-U;'0M/G)E<W5L="DI('L*("`@("`@("`@("`@("`@
M("\J"B`@("`@("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E9"!A(')E
M<W5L="!O8FIE8W0N"B`@("`@("`@("`@("`@("`@*B!%>'1R86-T('1H92!R
M97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@("`@("`@("`@("`J
M+PH@("`@("`@("`@("`@("`@)')E<W5L="`]("1R97-U;'0M/G)E<W5L=#L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)')E<R`](&%R<F%Y*"D["@H@
M("`@("`@("`@("!I9B`H)')E<W5L="`]/3T@)'1H:7,M/FQA<W1?<W1M="D@
M>PH@("`@("`@("`@("`@("`@)&-O=6YT(#T@0$]#24YU;4-O;',H)')E<W5L
M="D["B`@("`@("`@("`@("`@("!I9B`H)&UO9&4I('L*("`@("`@("`@("`@
M("`@("`@("`D<F5S6R=N=6U?9FEE;&1S)UT@/2`D8V]U;G0["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D
M8V]U;G0[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`D<F5S6R1I72`]
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`G=&%B;&4G(#T^("<G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`G;F%M92<@(#T^("1C87-E7V9U
M;F,H0$]#24-O;'5M;DYA;64H)')E<W5L="P@)&DK,2DI+`H@("`@("`@("`@
M("`@("`@("`@("`@("`G='EP92<@(#T^($!/0TE#;VQU;6Y4>7!E*"1R97-U
M;'0L("1I*S$I+`H@("`@("`@("`@("`@("`@("`@("`@("`G;&5N)R`@(#T^
M($!/0TE#;VQU;6Y3:7IE*"1R97-U;'0L("1I*S$I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@("`@("`@("`@("`@
M("D["B`@("`@("`@("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"3$5)
M3D9/7T]21$52*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1R97-;)V]R
M9&5R)UU;)')E<ULD:5U;)VYA;64G75T@/2`D:3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"
M3$5)3D9/7T]21$525$%"3$4I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)')E<ULG;W)D97)T86)L92==6R1R97-;)&E=6R=T86)L92==75LD<F5S6R1I
M75LG;F%M92==72`]("1I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?0T%0
M04),12D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1R97,["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T4W!E8VEA
M;%%U97)Y*"D*"B`@("`O*BH*("`@("`J($]B=&%I;G,@=&AE('%U97)Y('-T
M<FEN9R!N965D960@9F]R(&QI<W1I;F<@82!G:79E;B!T>7!E(&]F(&]B:F5C
M=',*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("!T:&4@:VEN
M9"!O9B!O8FIE8W1S('EO=2!W86YT('1O(')E=')I979E"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@('1H92!344P@<75E<GD@<W1R:6YG(&]R(&YU
M;&P@:68@=&AE(&1R:79E<B!D;V5S;B=T"B`@("`@*B`@("`@("`@("`@("`@
M("`@('-U<'!O<G0@=&AE(&]B:F5C="!T>7!E(')E<75E<W1E9`H@("`@("H*
M("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B!`<V5E($1"7V-O;6UO
M;CHZ9V5T3&ES=$]F*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4W!E8VEA
M;%%U97)Y*"1T>7!E*0H@("`@>PH@("`@("`@('-W:71C:"`H)'1Y<&4I('L*
M("`@("`@("`@("`@8V%S92`G=&%B;&5S)SH*("`@("`@("`@("`@("`@(')E
M='5R;B`G4T5,14-4('1A8FQE7VYA;64@1E)/32!U<V5R7W1A8FQE<R<["B`@
M("`@("`@("`@(&-A<V4@)W-Y;F]N>6US)SH*("`@("`@("`@("`@("`@(')E
M='5R;B`G4T5,14-4('-Y;F]N>6U?;F%M92!&4D]-('5S97)?<WEN;VYY;7,G
M.PH@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@<F5T=7)N
M(&YU;&P["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H*?0H*+RH*("H@
M3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO
M9F9S970Z(#0*("H@16YD.@H@*B\*"C\^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]$0B]O9&)C+G!H<```````````````````````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`V-#0U-@`Q,#4Q-30S,S<S-P`P,C`U
M,S,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W
M:61T:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@5&AE(%!%05(@1$(@
M9')I=F5R(&9O<B!02%`G<R!O9&)C(&5X=&5N<VEO;@H@*B!F;W(@:6YT97)A
M8W1I;F<@=VET:"!D871A8F%S97,@=FEA($]$0D,@8V]N;F5C=&EO;G,*("H*
M("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S
M;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!0
M2%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E
M('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*
M("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@
M($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@(%-T
M:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@1&%N:65L
M($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q
M.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*
M("H@0'9E<G-I;VX@("`@0U93.B`D260Z(&]D8F,N<&AP+'8@,2XW."`R,#`U
M+S`R+S(X(#`Q.C0R.C$W(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@
M:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*+RHJ"B`J($]B
M=&%I;B!T:&4@1$)?8V]M;6]N(&-L87-S('-O(&ET(&-A;B!B92!E>'1E;F1E
M9"!F<F]M"B`J+PIR97%U:7)E7V]N8V4@)T1"+V-O;6UO;BYP:'`G.PH*+RHJ
M"B`J(%1H92!M971H;V1S(%!%05(@1$(@=7-E<R!T;R!I;G1E<F%C="!W:71H
M(%!(4"=S(&]D8F,@97AT96YS:6]N"B`J(&9O<B!I;G1E<F%C=&EN9R!W:71H
M(&1A=&%B87-E<R!V:6$@3T1"0R!C;VYN96-T:6]N<PH@*@H@*B!4:&5S92!M
M971H;V1S(&]V97)L;V%D('1H92!O;F5S(&1E8VQA<F5D(&EN($1"7V-O;6UO
M;BX*("H*("H@36]R92!I;F9O(&]N($]$0D,@97)R;W)S(&-O=6QD(&)E(&9O
M=6YD(&AE<F4Z"B`J(&AT='`Z+R]M<V1N+FUI8W)O<V]F="YC;VTO;&EB<F%R
M>2]D969A=6QT+F%S<#]U<FP]+VQI8G)A<GDO96XM=7,O=')B;'-Q;"]T<E]E
M<G)?;V1B8U\U<W1Z+F%S<`H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@
M*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\
M<W-B0'!H<"YN970^"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@
M/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H
M92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N
M("`@(%)E;&5A<V4Z(#$N-RXV"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]$0@H@*B\*8VQA<W,@1$)?;V1B8R!E>'1E;F1S
M($1"7V-O;6UO;@I["B`@("`O+R![>WL@<')O<&5R=&EE<PH*("`@("\J*@H@
M("`@("H@5&AE($1"(&1R:79E<B!T>7!E("AM>7-Q;"P@;V-I."P@;V1B8RP@
M971C+BD*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<&AP
M='EP92`]("=O9&)C)SL*"B`@("`O*BH*("`@("`J(%1H92!D871A8F%S92!S
M>6YT87@@=F%R:6%N="!T;R!B92!U<V5D("AD8C(L(&%C8V5S<RP@971C+BDL
M(&EF(&%N>0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1D
M8G-Y;G1A>"`]("=S<6PY,B<["@H@("`@+RHJ"B`@("`@*B!4:&4@8V%P86)I
M;&ET:65S(&]F('1H:7,@1$(@:6UP;&5M96YT871I;VX*("`@("`J"B`@("`@
M*B!4:&4@)VYE=U]L:6YK)R!E;&5M96YT(&-O;G1A:6YS('1H92!02%`@=F5R
M<VEO;B!T:&%T(&9I<G-T('!R;W9I9&5D"B`@("`@*B!N97=?;&EN:R!S=7!P
M;W)T(&9O<B!T:&ES($1"35,N("!#;VYT86EN<R!F86QS92!I9B!I="=S('5N
M<W5P<&]R=&5D+@H@("`@("H*("`@("`J($UE86YI;F<@;V8@=&AE("=L:6UI
M="<@96QE;65N=#H*("`@("`J("`@*R`G96UU;&%T92<@/2!E;75L871E('=I
M=&@@9F5T8V@@<F]W(&)Y(&YU;6)E<@H@("`@("H@("`K("=A;'1E<B<@("`]
M(&%L=&5R('1H92!Q=65R>0H@("`@("H@("`K(&9A;'-E("`@("`]('-K:7`@
M<F]W<PH@("`@("H*("`@("`J($Y/5$4Z(%1H92!F96%T=7)E('-E="!O9B!T
M:&4@9F]L;&]W:6YG(&1R:79E<G,@87)E(&1I9F9E<F5N="!T:&%N"B`@("`@
M*B!T:&4@9&5F875L=#H*("`@("`J("`@*R!S;VQI9#H@)W1R86YS86-T:6]N
M<R<@/2!T<G5E"B`@("`@*B`@("L@;F%V:7-I;VXZ("=L:6UI="<@/2!F86QS
M90H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1F
M96%T=7)E<R`](&%R<F%Y*`H@("`@("`@("=L:6UI="<@("`@("`@("`]/B`G
M96UU;&%T92<L"B`@("`@("`@)VYE=U]L:6YK)R`@("`@(#T^(&9A;'-E+`H@
M("`@("`@("=N=6UR;W=S)R`@("`@("`]/B!T<G5E+`H@("`@("`@("=P8V]N
M;F5C="<@("`@("`]/B!T<G5E+`H@("`@("`@("=P<F5P87)E)R`@("`@("`]
M/B!F86QS92P*("`@("`@("`G<W-L)R`@("`@("`@("`@/3X@9F%L<V4L"B`@
M("`@("`@)W1R86YS86-T:6]N<R<@(#T^(&9A;'-E+`H@("`@*3L*"B`@("`O
M*BH*("`@("`J($$@;6%P<&EN9R!O9B!N871I=F4@97)R;W(@8V]D97,@=&\@
M1$(@97)R;W(@8V]D97,*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1E<G)O<F-O9&5?;6%P(#T@87)R87DH"B`@("`@("`@)S`Q,#`T)R`]
M/B!$0E]%4E)/4E]44E5.0T%4140L"B`@("`@("`@)S`W,#`Q)R`]/B!$0E]%
M4E)/4E]-25--051#2"P*("`@("`@("`G,C%3,#$G(#T^($1"7T524D]27U9!
M3%5%7T-/54Y47T].7U)/5RP*("`@("`@("`G,C%3,#(G(#T^($1"7T524D]2
M7TU)4TU!5$-(+`H@("`@("`@("<R,C`P,2<@/3X@1$)?15)23U)?24Y604Q)
M1"P*("`@("`@("`G,C(P,#,G(#T^($1"7T524D]27TE.5D%,241?3E5-0D52
M+`H@("`@("`@("<R,C`P-2<@/3X@1$)?15)23U)?24Y604Q)1%].54U"15(L
M"B`@("`@("`@)S(R,#`X)R`]/B!$0E]%4E)/4E])3E9!3$E$7T1!5$4L"B`@
M("`@("`@)S(R,#$R)R`]/B!$0E]%4E)/4E]$259:15)/+`H@("`@("`@("<R
M,S`P,"<@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("`@("`G,C,U,#(G
M(#T^($1"7T524D]27T-/3E-44D%)3E1?3D]47TY53$PL"B`@("`@("`@)S(S
M-3`S)R`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@("<R,S4P-"<@
M/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("`@("`G,C,U,#4G(#T^($1"
M7T524D]27T-/3E-44D%)3E0L"B`@("`@("`@)S(T,#`P)R`]/B!$0E]%4E)/
M4E])3E9!3$E$+`H@("`@("`@("<S-#`P,"<@/3X@1$)?15)23U)?24Y604Q)
M1"P*("`@("`@("`G,S<P,#`G(#T^($1"7T524D]27U-93E1!6"P*("`@("`@
M("`G-#(P,#`G(#T^($1"7T524D]27U-93E1!6"P*("`@("`@("`G-#(V,#$G
M(#T^($1"7T524D]27U-93E1!6"P*("`@("`@("`G24TP,#$G(#T^($1"7T52
M4D]27U5.4U504$]25$5$+`H@("`@("`@("=3,#`P,"<@/3X@1$)?15)23U)?
M3D]354-(5$%"3$4L"B`@("`@("`@)U,P,#`Q)R`]/B!$0E]%4E)/4E]!3%)%
M04197T5825-44RP*("`@("`@("`G4S`P,#(G(#T^($1"7T524D]27TY/4U5#
M2%1!0DQ%+`H@("`@("`@("=3,#`Q,2<@/3X@1$)?15)23U)?04Q214%$65]%
M6$E35%,L"B`@("`@("`@)U,P,#$R)R`]/B!$0E]%4E)/4E].3U1?1D]53D0L
M"B`@("`@("`@)U,P,#(Q)R`]/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*
M("`@("`@("`G4S`P,C(G(#T^($1"7T524D]27TY/4U5#2$9)14Q$+`H@("`@
M("`@("=3,3`P.2<@/3X@1$)?15)23U)?24Y604Q)1"P*("`@("`@("`G4S$P
M.3`G(#T^($1"7T524D]27TE.5D%,240L"B`@("`@("`@)U,Q0S`P)R`]/B!$
M0E]%4E)/4E].3U1?0T%004),12P*("`@("D["@H@("`@+RHJ"B`@("`@*B!4
M:&4@<F%W(&1A=&%B87-E(&-O;FYE8W1I;VX@8W)E871E9"!B>2!02%`*("`@
M("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1C;VYN96-T:6]N
M.PH*("`@("\J*@H@("`@("H@5&AE($133B!I;F9O<FUA=&EO;B!F;W(@8V]N
M;F5C=&EN9R!T;R!A(&1A=&%B87-E"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D9'-N(#T@87)R87DH*3L*"@H@("`@+RHJ"B`@("`@*B!4
M:&4@;G5M8F5R(&]F(')O=W,@869F96-T960@8GD@82!D871A(&UA;FEP=6QA
M=&EO;B!Q=65R>0H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J+PH@("`@=F%R("1A9F9E8W1E9"`](#`["@H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R"@H@("`@+RHJ"B`@("`@
M*B!4:&ES(&-O;G-T<G5C=&]R(&-A;&QS(#QK8F0^)'1H:7,M/D1"7V-O;6UO
M;B@I/"]K8F0^"B`@("`@*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*
M("`@(&9U;F-T:6]N($1"7V]D8F,H*0H@("`@>PH@("`@("`@("1T:&ES+3Y$
M0E]C;VUM;VXH*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYN
M96-T*"D*"B`@("`O*BH*("`@("`J($-O;FYE8W0@=&\@=&AE(&1A=&%B87-E
M('-E<G9E<BP@;&]G(&EN(&%N9"!O<&5N('1H92!D871A8F%S90H@("`@("H*
M("`@("`J($1O;B=T(&-A;&P@=&AI<R!M971H;V0@9&ER96-T;'DN("!5<V4@
M1$(Z.F-O;FYE8W0H*2!I;G-T96%D+@H@("`@("H*("`@("`J(%!%05(@1$(G
M<R!O9&)C(&1R:79E<B!S=7!P;W)T<R!T:&4@9F]L;&]W:6YG(&5X=')A($13
M3B!O<'1I;VYS.@H@("`@("H@("`K(&-U<G-O<B`@5&AE('1Y<&4@;V8@8W5R
M<V]R('1O(&)E('5S960@9F]R('1H:7,@8V]N;F5C=&EO;BX*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)&1S;B`@("`@("`@('1H92!D871A('-O=7)C
M92!N86UE"B`@("`@*B!`<&%R86T@8F]O;"`@)'!E<G-I<W1E;G0@('-H;W5L
M9"!T:&4@8V]N;F5C=&EO;B!B92!P97)S:7-T96YT/PH@("`@("H*("`@("`J
M($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B!!($1"7T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYN96-T
M*"1D<VXL("1P97)S:7-T96YT(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@
M*"%014%2.CIL;V%D17AT96YS:6]N*"=O9&)C)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27T585$5.4TE/3E].
M3U1?1D]53D0I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/F1S;B`]("1D
M<VX["B`@("`@("`@:68@*"1D<VY;)V1B<WEN=&%X)UTI('L*("`@("`@("`@
M("`@)'1H:7,M/F1B<WEN=&%X(#T@)&1S;ELG9&)S>6YT87@G73L*("`@("`@
M("!]"B`@("`@("`@<W=I=&-H("@D=&AI<RT^9&)S>6YT87@I('L*("`@("`@
M("`@("`@8V%S92`G86-C97-S)SH*("`@("`@("`@("`@8V%S92`G9&(R)SH*
M("`@("`@("`@("`@8V%S92`G<V]L:60G.@H@("`@("`@("`@("`@("`@)'1H
M:7,M/F9E871U<F5S6R=T<F%N<V%C=&EO;G,G72`]('1R=64["B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G;F%V:7-I;VXG.@H@
M("`@("`@("`@("`@("`@)'1H:7,M/F9E871U<F5S6R=L:6UI="==(#T@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("`O*@H@("`@("`@("`J(%1H:7,@:7,@
M:&5A<B!F;W(@8F%C:W=A<F1S(&-O;7!A=&EB:6QI='DN(%-H;W5L9"!H879E
M(&)E96X@=7-I;F<*("`@("`@("`@*B`G9&%T86)A<V4G(&%L;"!A;&]N9RP@
M8G5T('!R:6]R('1O(#$N-BXP4D,S("=H;W-T<W!E8R<@=V%S('5S960N"B`@
M("`@("`@("HO"B`@("`@("`@:68@*"1D<VY;)V1A=&%B87-E)UTI('L*("`@
M("`@("`@("`@)&]D8F-D<VX@/2`D9'-N6R=D871A8F%S92==.PH@("`@("`@
M('T@96QS96EF("@D9'-N6R=H;W-T<W!E8R==*2!["B`@("`@("`@("`@("1O
M9&)C9'-N(#T@)&1S;ELG:&]S='-P96,G73L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D;V1B8V1S;B`]("=L;V-A;&AO<W0G.PH@("`@("`@('T*
M"B`@("`@("`@)&-O;FYE8W1?9G5N8W1I;VX@/2`D<&5R<VES=&5N="`_("=O
M9&)C7W!C;VYN96-T)R`Z("=O9&)C7V-O;FYE8W0G.PH*("`@("`@("!I9B`H
M96UP='DH)&1S;ELG8W5R<V]R)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YC
M;VYN96-T:6]N(#T@0"1C;VYN96-T7V9U;F-T:6]N*"1O9&)C9'-N+"`D9'-N
M6R=U<V5R;F%M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9'-N6R=P87-S=V]R9"==*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`]($`D
M8V]N;F5C=%]F=6YC=&EO;B@D;V1B8V1S;BP@)&1S;ELG=7-E<FYA;64G72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1S;ELG<&%S<W=O<F0G72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1S;ELG8W5R<V]R)UTI
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^
M8V]N;F5C=&EO;BDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*$1"7T524D]27T-/3DY%0U1?1D%)3$5$+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YE<G)O
M<DYA=&EV92@I*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1I<V-O;FYE8W0H*0H*("`@
M("\J*@H@("`@("H@1&ES8V]N;F5C=',@9G)O;2!T:&4@9&%T86)A<V4@<V5R
M=F5R"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("!44E5%(&]N('-U8V-E
M<W,L($9!3%-%(&]N(&9A:6QU<F4*("`@("`J+PH@("`@9G5N8W1I;VX@9&ES
M8V]N;F5C="@I"B`@("!["B`@("`@("`@)&5R<B`]($!O9&)C7V-L;W-E*"1T
M:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`]
M(&YU;&P["B`@("`@("`@<F5T=7)N("1E<G(["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@<VEM<&QE475E<GDH*0H*("`@("\J*@H@("`@("H@4V5N
M9',@82!Q=65R>2!T;R!T:&4@9&%T86)A<V4@<V5R=F5R"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@=&AE(%-13"!Q=65R>2!S=')I;F<*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("`K(&$@4$A0(')E<W5L="!R97-R;W5C
M92!F;W(@<W5C8V5S<V9U;"!314Q%0U0@<75E<FEE<PH@("`@("H@("`@("`@
M("`@("`@("`@*R!T:&4@1$)?3TL@8V]N<W1A;G0@9F]R(&]T:&5R('-U8V-E
M<W-F=6P@<75E<FEE<PH@("`@("H@("`@("`@("`@("`@("`@*R!A($1"7T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N('-I
M;7!L95%U97)Y*"1Q=65R>2D*("`@('L*("`@("`@("`D=&AI<RT^;&%S=%]Q
M=65R>2`]("1Q=65R>3L*("`@("`@("`D<75E<GD@/2`D=&AI<RT^;6]D:69Y
M475E<GDH)'%U97)Y*3L*("`@("`@("`D<F5S=6QT(#T@0&]D8F-?97AE8R@D
M=&AI<RT^8V]N;F5C=&EO;BP@)'%U97)Y*3L*("`@("`@("!I9B`H(21R97-U
M;'0I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YO9&)C4F%I<V5%<G)O
M<B@I.R`O+R!86%@@15)23U)-4T<*("`@("`@("!]"B`@("`@("`@+R\@1&5T
M97)M:6YE('=H:6-H('%U97)I97,@=&AA="!S:&]U;&0@<F5T=7)N(&1A=&$L
M(&%N9"!W:&EC:`H@("`@("`@("\O('-H;W5L9"!R971U<FX@86X@97)R;W(@
M8V]D92!O;FQY+@H@("`@("`@(&EF("A$0CHZ:7--86YI<"@D<75E<GDI*2![
M"B`@("`@("`@("`@("1T:&ES+3YA9F9E8W1E9"`]("1R97-U;'0[("\O($9O
M<B!A9F9E8W1E9%)O=W,H*0H@("`@("`@("`@("!R971U<FX@1$)?3TL["B`@
M("`@("`@?0H@("`@("`@("1T:&ES+3YA9F9E8W1E9"`](#`["B`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M;F5X=%)E<W5L="@I"@H@("`@+RHJ"B`@("`@*B!-;W9E('1H92!I;G1E<FYA
M;"!O9&)C(')E<W5L="!P;VEN=&5R('1O('1H92!N97AT(&%V86EL86)L92!R
M97-U;'0*("`@("`J"B`@("`@*B!`<&%R86T@82!V86QI9"!F8G-Q;"!R97-U
M;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H*("`@("`J($!R971U<FX@=')U92!I9B!A(')E<W5L="!I<R!A=F%I;&%B
M;&4@;W1H97)W:7-E(')E='5R;B!F86QS90H@("`@("HO"B`@("!F=6YC=&EO
M;B!N97AT4F5S=6QT*"1R97-U;'0I"B`@("!["B`@("`@("`@<F5T=7)N($!O
M9&)C7VYE>'1?<F5S=6QT*"1R97-U;'0I.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&9E=&-H26YT;R@I"@H@("`@+RHJ"B`@("`@*B!0;&%C97,@
M82!R;W<@9G)O;2!T:&4@<F5S=6QT('-E="!I;G1O('1H92!G:79E;B!A<G)A
M>0H@("`@("H*("`@("`J($9O<FUA=&EN9R!O9B!T:&4@87)R87D@86YD('1H
M92!D871A('1H97)E:6X@87)E(&-O;F9I9W5R86)L92X*("`@("`J(%-E92!$
M0E]R97-U;'0Z.F9E=&-H26YT;R@I(&9O<B!M;W)E(&EN9F]R;6%T:6]N+@H@
M("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C
M86QL960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ9F5T8VA)
M;G1O*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T
M960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B
M:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@
M("!T:&4@<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@*B!`<&%R86T@87)R
M87D@("`@)&%R<B`@("`@("!T:&4@<F5F97)E;F-E9"!A<G)A>2!T;R!P=70@
M=&AE(&1A=&$@:6X*("`@("`J($!P87)A;2!I;G0@("`@("`D9F5T8VAM;V1E
M(&AO=R!T:&4@<F5S=6QT:6YG(&%R<F%Y('-H;W5L9"!B92!I;F1E>&5D"B`@
M("`@*B!`<&%R86T@:6YT("`@("`@)')O=VYU;2`@("!T:&4@<F]W(&YU;6)E
M<B!T;R!F971C:"`H,"`](&9I<G-T(')O=RD*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!$0E]/2R!O;B!S=6-C97-S+"!.54Q,('=H96X@=&AE(&5N
M9"!O9B!A(')E<W5L="!S970@:7,*("`@("`J("`@("`@("`@("`@("`@("!R
M96%C:&5D(&]R(&]N(&9A:6QU<F4*("`@("`J"B`@("`@*B!`<V5E($1"7W)E
M<W5L=#HZ9F5T8VA);G1O*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9F5T8VA)
M;G1O*"1R97-U;'0L("8D87)R+"`D9F5T8VAM;V1E+"`D<F]W;G5M(#T@;G5L
M;"D*("`@('L*("`@("`@("`D87)R(#T@87)R87DH*3L*("`@("`@("!I9B`H
M)')O=VYU;2`A/3T@;G5L;"D@>PH@("`@("`@("`@("`D<F]W;G5M*RL[("\O
M($]$0D,@9FER<W0@<F]W(&ES(#$*("`@("`@("`@("`@:68@*'9E<G-I;VY?
M8V]M<&%R92AP:'!V97)S:6]N*"DL("<T+C(N,"<L("=G92<I*2!["B`@("`@
M("`@("`@("`@("`D8V]L<R`]($!O9&)C7V9E=&-H7VEN=&\H)')E<W5L="P@
M)&%R<BP@)')O=VYU;2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D8V]L<R`]($!O9&)C7V9E=&-H7VEN=&\H)')E<W5L="P@)')O
M=VYU;2P@)&%R<BD["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D8V]L<R`]($!O9&)C7V9E=&-H7VEN=&\H)')E<W5L="P@
M)&%R<BD["B`@("`@("`@?0H@("`@("`@(&EF("@A)&-O;',I('L*("`@("`@
M("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@("`@(&EF("@D9F5T
M8VAM;V1E("$]/2!$0E]&151#2$U/1$5?3U)$15)%1"D@>PH@("`@("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D87)R*3L@)&DK*RD@>PH@("`@
M("`@("`@("`@("`@)&-O;$YA;64@/2!`;V1B8U]F:65L9%]N86UE*"1R97-U
M;'0L("1I*S$I.PH@("`@("`@("`@("`@("`@)&%;)&-O;$YA;65=(#T@)&%R
M<ELD:5T["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1T:&ES+3YO
M<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3$]715)#
M05-%*2!["B`@("`@("`@("`@("`@("`D82`](&%R<F%Y7V-H86YG95]K97E?
M8V%S92@D82P@0T%315],3U=%4BD["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)&%R<B`]("1A.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/F]P
M=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465]25%))32D@
M>PH@("`@("`@("`@("`D=&AI<RT^7W)T<FEM07)R87E686QU97,H)&%R<BD[
M"B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B
M:6QI='DG72`F($1"7U!/4E1!0DE,25197TY53$Q?5$]?14U05%DI('L*("`@
M("`@("`@("`@)'1H:7,M/E]C;VYV97)T3G5L;$%R<F%Y5F%L=65S5&]%;7!T
M>2@D87)R*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9R965297-U;'0H*0H*("`@("\J
M*@H@("`@("H@1&5L971E<R!T:&4@<F5S=6QT('-E="!A;F0@9G)E97,@=&AE
M(&UE;6]R>2!O8V-U<&EE9"!B>2!T:&4@<F5S=6QT('-E=`H@("`@("H*("`@
M("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER
M96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ9G)E92@I(&EN<W1E860N
M("!)="!C86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C
M875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@
M("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@(%!(4"=S('%U97)Y(')E
M<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@5%)5
M12!O;B!S=6-C97-S+"!&04Q312!I9B`D<F5S=6QT(&ES(&EN=F%L:60*("`@
M("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ9G)E92@I"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&9R965297-U;'0H)')E<W5L="D*("`@('L*("`@("`@("!R
M971U<FX@0&]D8F-?9G)E95]R97-U;'0H)')E<W5L="D["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@;G5M0V]L<R@I"@H@("`@+RHJ"B`@("`@*B!'
M971S('1H92!N=6UB97(@;V8@8V]L=6UN<R!I;B!A(')E<W5L="!S970*("`@
M("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L
M;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.FYU;4-O;',H
M*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*
M("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T
M+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G
M<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN="`@=&AE(&YU;6)E<B!O9B!C;VQU;6YS+B`@02!$0E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ
M;G5M0V]L<R@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU;4-O;',H)')E<W5L
M="D*("`@('L*("`@("`@("`D8V]L<R`]($!O9&)C7VYU;5]F:65L9',H)')E
M<W5L="D["B`@("`@("`@:68@*"$D8V]L<RD@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/F]D8F-286ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`D8V]L<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!A
M9F9E8W1E9%)O=W,H*0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!T:&4@
M;G5M8F5R(&]F(')O=W,@869F96-T960@8GD@82!D871A(&UA;FEU<&QA=&EO
M;B!Q=65R>0H@("`@("H*("`@("`J(#`@:7,@<F5T=7)N960@9F]R('%U97)I
M97,@=&AA="!D;VXG="!M86YI<'5L871E(&1A=&$N"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@<F]W<RX@($$@1$)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%F9F5C
M=&5D4F]W<R@I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3YA9F9E
M8W1E9"DI('L@("\O($EN(&-A<V4@;V8@4T5,14-4('-T;7,*("`@("`@("`@
M("`@<F5T=7)N(#`["B`@("`@("`@?0H@("`@("`@("1N<F]W<R`]($!O9&)C
M7VYU;5]R;W=S*"1T:&ES+3YA9F9E8W1E9"D["B`@("`@("`@:68@*"1N<F]W
M<R`]/2`M,2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]D8F-286ES
M945R<F]R*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D;G)O=W,["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;G5M4F]W<R@I"@H@("`@+RHJ
M"B`@("`@*B!'971S('1H92!N=6UB97(@;V8@<F]W<R!I;B!A(')E<W5L="!S
M970*("`@("`J"B`@("`@*B!.;W0@86QL($]$0D,@9')I=F5R<R!S=7!P;W)T
M('1H:7,@9G5N8W1I;VYA;&ET>2X@($EF('1H97D@9&]N)W0*("`@("`J(&$@
M1$)?17)R;W(@;V)J96-T(&9O<B!$0E]%4E)/4E]53E-54%!/4E1%1"!I<R!R
M971U<FYE9"X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A
M;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U
M;'0Z.FYU;5)O=W,H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@
M(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P
M87)A=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D
M<F5S=6QT("!02%`G<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!R;W=S+B`@02!$0E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"
M7W)E<W5L=#HZ;G5M4F]W<R@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU;5)O
M=W,H)')E<W5L="D*("`@('L*("`@("`@("`D;G)O=W,@/2!`;V1B8U]N=6U?
M<F]W<R@D<F5S=6QT*3L*("`@("`@("!I9B`H)&YR;W=S(#T]("TQ*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^;V1B8U)A:7-E17)R;W(H1$)?15)2
M3U)?54Y355!03U)4140I.PH@("`@("`@('T*("`@("`@("!I9B`H)&YR;W=S
M(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]D8F-2
M86ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D;G)O=W,[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<75O=&5)9&5N=&EF:65R
M*"D*"B`@("`O*BH*("`@("`J(%%U;W1E<R!A('-T<FEN9R!S;R!I="!C86X@
M8F4@<V%F96QY('5S960@87,@82!T86)L92!O<B!C;VQU;6X@;F%M90H@("`@
M("H*("`@("`J(%5S92`G;7-S<6PG(&%S('1H92!D8G-Y;G1A>"!I;B!T:&4@
M1$(@1%-.(&]N;'D@:68@>6]U)W9E('5N8VAE8VME9`H@("`@("H@(E5S92!!
M3E-)('%U;W1E9"!I9&5N=&EF:65R<R(@=VAE;B!S971T:6YG('5P('1H92!/
M1$)#(&1A=&$@<V]U<F-E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'-T<B`@:61E;G1I9FEE<B!N86UE('1O(&)E('%U;W1E9`H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!Q=6]T960@:61E;G1I9FEE<B!S=')I;F<*
M("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<75O=&5)9&5N=&EF:65R
M*"D*("`@("`J($!S:6YC92!-971H;V0@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XV+C`*("`@("`J+PH@("`@9G5N8W1I;VX@<75O=&5)9&5N=&EF:65R
M*"1S='(I"B`@("!["B`@("`@("`@<W=I=&-H("@D=&AI<RT^9'-N6R=D8G-Y
M;G1A>"==*2!["B`@("`@("`@("`@(&-A<V4@)V%C8V5S<R<Z"B`@("`@("`@
M("`@("`@("!R971U<FX@)ULG("X@)'-T<B`N("==)SL*("`@("`@("`@("`@
M8V%S92`G;7-S<6PG.@H@("`@("`@("`@("!C87-E("=S>6)A<V4G.@H@("`@
M("`@("`@("`@("`@<F5T=7)N("=;)R`N('-T<E]R97!L86-E*"==)RP@)UU=
M)RP@)'-T<BD@+B`G72<["B`@("`@("`@("`@(&-A<V4@)VUY<W%L)SH*("`@
M("`@("`@("`@8V%S92`G;7ES<6QI)SH*("`@("`@("`@("`@("`@(')E='5R
M;B`G8"<@+B`D<W1R("X@)V`G.PH@("`@("`@("`@("!D969A=6QT.@H@("`@
M("`@("`@("`@("`@<F5T=7)N("<B)R`N('-T<E]R97!L86-E*"<B)RP@)R(B
M)RP@)'-T<BD@+B`G(B<["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[('%U;W1E*"D*"B`@("`O*BH*("`@("`J($!D97!R96-A=&5D
M("!$97!R96-A=&5D(&EN(')E;&5A<V4@,2XV+C`*("`@("`J($!I;G1E<FYA
M;`H@("`@("HO"B`@("!F=6YC=&EO;B!Q=6]T92@D<W1R*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^<75O=&53;6%R="@D<W1R*3L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!N97AT260H*0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@;F5X="!F<F5E(&ED(&EN(&$@<V5Q=65N8V4*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V5Q7VYA;64@(&YA;64@;V8@=&AE
M('-E<75E;F-E"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;VYD96UA;F0@('=H
M96X@=')U92P@=&AE('-E<65N8V4@:7,@875T;VUA=&EC86QL>0H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8W)E871E9"!I9B!I="!D;V5S
M(&YO="!E>&ES=`H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;F5X
M="!I9"!N=6UB97(@:6X@=&AE('-E<75E;F-E+@H@("`@("H@("`@("`@("`@
M("`@("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@
M("`J($!S964@1$)?8V]M;6]N.CIN97AT240H*2P@1$)?8V]M;6]N.CIG9713
M97%U96YC94YA;64H*2P*("`@("`J("`@("`@1$)?;V1B8SHZ8W)E871E4V5Q
M=65N8V4H*2P@1$)?;V1B8SHZ9')O<%-E<75E;F-E*"D*("`@("`J+PH@("`@
M9G5N8W1I;VX@;F5X=$ED*"1S97%?;F%M92P@)&]N9&5M86YD(#T@=')U92D*
M("`@('L*("`@("`@("`D<V5Q;F%M92`]("1T:&ES+3YG971397%U96YC94YA
M;64H)'-E<5]N86UE*3L*("`@("`@("`D<F5P96%T(#T@,#L*("`@("`@("!D
M;R!["B`@("`@("`@("`@("1T:&ES+3YP=7-H17)R;W)(86YD;&EN9RA014%2
M7T524D]27U)%5%523BD["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M<75E<GDH(G5P9&%T92`D>W-E<6YA;65]('-E="!I9"`](&ED("L@,2(I.PH@
M("`@("`@("`@("`D=&AI<RT^<&]P17)R;W)(86YD;&EN9R@I.PH@("`@("`@
M("`@("!I9B`H)&]N9&5M86YD("8F($1".CII<T5R<F]R*"1R97-U;'0I("8F
M"B`@("`@("`@("`@("`@("`D<F5S=6QT+3YG971#;V1E*"D@/3T@1$)?15)2
M3U)?3D]354-(5$%"3$4I('L*("`@("`@("`@("`@("`@("1R97!E870@/2`Q
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/G!U<VA%<G)O<DAA;F1L:6YG*%!%
M05)?15)23U)?4D5455).*3L*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D
M=&AI<RT^8W)E871E4V5Q=65N8V4H)'-E<5]N86UE*3L*("`@("`@("`@("`@
M("`@("1T:&ES+3YP;W!%<G)O<DAA;F1L:6YG*"D["B`@("`@("`@("`@("`@
M("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E<W5L="D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/G%U97)Y*")I;G-E<G0@:6YT;R`D>W-E<6YA;65]("AI9"D@=F%L=65S*#`I
M(BD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<F5P
M96%T(#T@,#L*("`@("`@("`@("`@?0H@("`@("`@('T@=VAI;&4@*"1R97!E
M870I.PH*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I.PH@
M("`@("`@('T*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3YQ=65R>2@B<V5L
M96-T(&ED(&9R;VT@)'MS97%N86UE?2(I.PH@("`@("`@(&EF("A$0CHZ:7-%
M<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("!]"@H@("`@("`@("1R;W<@/2`D<F5S=6QT+3YF971C:%)O=RA$
M0E]&151#2$U/1$5?3U)$15)%1"D["B`@("`@("`@:68@*$1".CII<T5R<F]R
M*"1R;W<@?'P@(21R;W<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F]W.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R;W=;,%T["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#<F5A=&5S(&$@;F5W('-E<75E;F-E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<V5Q7VYA;64@(&YA;64@;V8@=&AE(&YE=R!S
M97%U96YC90H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S
M=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J
M"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ8W)E871E4V5Q=65N8V4H*2P@1$)?
M8V]M;6]N.CIG971397%U96YC94YA;64H*2P*("`@("`J("`@("`@1$)?;V1B
M8SHZ;F5X=$E$*"DL($1"7V]D8F,Z.F1R;W!397%U96YC92@I"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&-R96%T95-E<75E;F-E*"1S97%?;F%M92D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/G%U97)Y*"=#4D5!5$4@5$%"3$4@)PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^9V5T4V5Q=65N
M8V5.86UE*"1S97%?;F%M92D*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("X@)R`H:60@:6YT96=E<B!.3U0@3E5,3"PG"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`N("<@4%))34%262!+15DH:60I*2<I.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&1R;W!397%U96YC92@I"@H@("`@+RHJ"B`@
M("`@*B!$96QE=&5S(&$@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1S97%?;F%M92`@;F%M92!O9B!T:&4@<V5Q=65N8V4@=&\@8F4@
M9&5L971E9`H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S
M=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J
M"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ9')O<%-E<75E;F-E*"DL($1"7V-O
M;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@*B`@("`@($1"7V]D8F,Z
M.FYE>'1)1"@I+"!$0E]O9&)C.CIC<F5A=&5397%U96YC92@I"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&1R;W!397%U96YC92@D<V5Q7VYA;64I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3YQ=65R>2@G1%)/4"!404),12`G("X@)'1H
M:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I*3L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!A=71O0V]M;6ET*"D*"B`@("`O*BH*("`@("`J
M($5N86)L97,@;W(@9&ES86)L97,@875T;VUA=&EC(&-O;6UI=',*("`@("`J
M"B`@("`@*B!`<&%R86T@8F]O;"`D;VYO9F8@('1R=64@='5R;G,@:70@;VXL
M(&9A;'-E('1U<FYS(&ET(&]F9@H@("`@("H*("`@("`J($!R971U<FX@:6YT
M("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@:68@=&AE
M(&1R:79E<@H@("`@("H@("`@("`@("`@("`@("!D;V5S;B=T('-U<'!O<G0@
M875T;RUC;VUM:71T:6YG('1R86YS86-T:6]N<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@875T;T-O;6UI="@D;VYO9F8@/2!F86QS92D*("`@('L*("`@("`@
M("!I9B`H(4!O9&)C7V%U=&]C;VUM:70H)'1H:7,M/F-O;FYE8W1I;VXL("1O
M;F]F9BDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YO9&)C4F%I<V5%
M<G)O<B@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]M;6ET*"D*"B`@("`O*BH*("`@
M("`J($-O;6UI=',@=&AE(&-U<G)E;G0@=')A;G-A8W1I;VX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O
M;6UI="@I"B`@("!["B`@("`@("`@:68@*"%`;V1B8U]C;VUM:70H)'1H:7,M
M/F-O;FYE8W1I;VXI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;V1B
M8U)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(')O;&QB86-K*"D*"B`@
M("`O*BH*("`@("`J(%)E=F5R=',@=&AE(&-U<G)E;G0@=')A;G-A8W1I;VX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@
M($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(')O;&QB86-K*"D*("`@('L*("`@("`@("!I9B`H(4!O9&)C7W)O
M;&QB86-K*"1T:&ES+3YC;VYN96-T:6]N*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/F]D8F-286ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!O
M9&)C4F%I<V5%<G)O<B@I"@H@("`@+RHJ"B`@("`@*B!0<F]D=6-E<R!A($1"
M7T5R<F]R(&]B:F5C="!R96=A<F1I;F<@=&AE(&-U<G)E;G0@<')O8FQE;0H@
M("`@("H*("`@("`J($!P87)A;2!I;G0@)&5R<FYO("!I9B!T:&4@97)R;W(@
M:7,@8F5I;F<@;6%N=6%L;'D@<F%I<V5D('!A<W,@80H@("`@("H@("`@("`@
M("`@("`@("`@("`@("!$0E]%4E)/4BH@8V]N<W1A;G0@:&5R92X@($EF('1H
M:7,@:7-N)W0@<&%S<V5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@('1H
M92!E<G)O<B!I;F9O<FUA=&EO;B!G871H97)E9"!F<F]M('1H92!$0DU3+@H@
M("`@("H*("`@("`J($!R971U<FX@;V)J96-T("!T:&4@1$)?17)R;W(@;V)J
M96-T"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G)A:7-E17)R;W(H
M*2P*("`@("`J("`@("`@1$)?;V1B8SHZ97)R;W).871I=F4H*2P@1$)?8V]M
M;6]N.CIE<G)O<D-O9&4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!O9&)C4F%I
M<V5%<G)O<B@D97)R;F\@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@D97)R
M;F\@/3T](&YU;&PI('L*("`@("`@("`@("`@<W=I=&-H("@D=&AI<RT^9&)S
M>6YT87@I('L*("`@("`@("`@("`@("`@(&-A<V4@)V%C8V5S<R<Z"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET
M>2==("8@1$)?4$]25$%"24Q)5%E?15)23U)3*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YE<G)O<F-O9&5?;6%P6R<P-S`P,2==(#T@1$)?
M15)23U)?3D]354-(1DE%3$0["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`@("`@+R\@1&]I;F<@=&AI<R!I;B!C
M87-E(&UO9&4@8VAA;F=E<R!D=7)I;F<@<G5N=&EM92X*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F5R<F]R8V]D95]M87!;)S`W,#`Q)UT@/2!$
M0E]%4E)/4E]-25--051#2#L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`@("`@("`@("1N871I=F5?8V]D92`](&]D8F-?97)R;W(H)'1H
M:7,M/F-O;FYE8W1I;VXI.PH*("`@("`@("`@("`@("`@("`@("`O+R!3,3`P
M,"!I<R!F;W(@(D=E;F5R86P@17)R;W(N(B`@3&5T)W,@8F4@;6]R92!S<&5C
M:69I8RX*("`@("`@("`@("`@("`@("`@("!I9B`H)&YA=&EV95]C;V1E(#T]
M("=3,3`P,"<I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&5R<F]R;7-G
M(#T@;V1B8U]E<G)O<FUS9R@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@
M("`@("`@("`@("`@("`@('-T871I8R`D97)R;W)?<F5G97AP<SL*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D97)R;W)?<F5G97AP<RDI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E<G)O<E]R96=E>'!S
M(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R]I
M;F-L=61E<R!R96QA=&5D(')E8V]R9',N)"]I)R`@/3X@1$)?15)23U)?0T].
M4U1204E.5"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G+V-A
M;FYO="!C;VYT86EN(&$@3G5L;"!V86QU92]I)R`]/B!$0E]%4E)/4E]#3TY3
M5%)!24Y47TY/5%].54Q,+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("`@("!F;W)E86-H("@D97)R;W)?<F5G97AP<R!A<R`D<F5G97AP(#T^
M("1C;V1E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H<')E
M9U]M871C:"@D<F5G97AP+"`D97)R;W)M<V<I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1C
M;V1E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1N871I=F5?8V]D92`N("<@)R`N("1E<G)O<FUS9RD[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&5R<FYO(#T@
M1$)?15)23U(["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&5R<FYO(#T@)'1H:7,M/F5R<F]R0V]D92@D
M;F%T:79E7V-O9&4I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@
M("`@("`@("`@("`@("`@("`@)&5R<FYO(#T@)'1H:7,M/F5R<F]R0V]D92AO
M9&)C7V5R<F]R*"1T:&ES+3YC;VYN96-T:6]N*2D["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1E
M<G)N;RP@;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F5R<F]R3F%T:79E*"DI.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&5R<F]R3F%T:79E*"D*"B`@("`O*BH*("`@
M("`J($=E=',@=&AE($1"35,G(&YA=&EV92!E<G)O<B!C;V1E(&%N9"!M97-S
M86=E('!R;V1U8V5D(&)Y('1H92!L87-T('%U97)Y"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@('1H92!$0DU3)R!E<G)O<B!C;V1E(&%N9"!M97-S
M86=E"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R3F%T:79E*"D*("`@('L*
M("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1T:&ES+3YC;VYN96-T:6]N*2D@
M>PH@("`@("`@("`@("!R971U<FX@0&]D8F-?97)R;W(H*2`N("<@)R`N($!O
M9&)C7V5R<F]R;7-G*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B!`;V1B
M8U]E<G)O<B@D=&AI<RT^8V]N;F5C=&EO;BD@+B`G("<@+B!`;V1B8U]E<G)O
M<FUS9R@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@=&%B;&5);F9O*"D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M:6YF;W)M871I;VX@86)O=70@82!T86)L92!O<B!A(')E<W5L="!S970*("`@
M("`J"B`@("`@*B!`<&%R86T@;V)J96-T?'-T<FEN9R`@)')E<W5L="`@1$)?
M<F5S=6QT(&]B:F5C="!F<F]M(&$@<75E<GD@;W(@80H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!S=')I;F<@8V]N=&%I;FEN9R!T
M:&4@;F%M92!O9B!A('1A8FQE+@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!7:&EL92!T:&ES(&%L<V\@86-C97!T<R!A('%U97)Y
M(')E<W5L=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!R97-O=7)C92!I9&5N=&EF:65R+"!T:&ES(&)E:&%V:6]R(&ES"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1E<')E8V%T960N
M"B`@("`@*B!`<&%R86T@:6YT("`@("`@("`@("`@)&UO9&4@("`@82!V86QI
M9"!T86)L94EN9F\@;6]D90H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M(&%N(&%S<V]C:6%T:79E(&%R<F%Y('=I=&@@=&AE(&EN9F]R;6%T:6]N(')E
M<75E<W1E9"X*("`@("`J("`@("`@("`@("`@("`@("!!($1"7T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N
M.CIT86)L94EN9F\H*0H@("`@("H@0'-I;F-E($UE=&AO9"!A=F%I;&%B;&4@
M<VEN8V4@4F5L96%S92`Q+C<N,`H@("`@("HO"B`@("!F=6YC=&EO;B!T86)L
M94EN9F\H)')E<W5L="P@)&UO9&4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF
M("AI<U]S=')I;F<H)')E<W5L="DI('L*("`@("`@("`@("`@+RH*("`@("`@
M("`@("`@("H@4')O8F%B;'D@<F5C96EV960@82!T86)L92!N86UE+@H@("`@
M("`@("`@("`@*B!#<F5A=&4@82!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE
M<BX*("`@("`@("`@("`@("HO"B`@("`@("`@("`@("1I9"`]($!O9&)C7V5X
M96,H)'1H:7,M/F-O;FYE8W1I;VXL(")314Q%0U0@*B!&4D]-("1R97-U;'0B
M*3L*("`@("`@("`@("`@:68@*"$D:60I('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^;V1B8U)A:7-E17)R;W(H*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D9V]T7W-T<FEN9R`]('1R=64["B`@("`@("`@?2!E;'-E
M:68@*&ES<V5T*"1R97-U;'0M/G)E<W5L="DI('L*("`@("`@("`@("`@+RH*
M("`@("`@("`@("`@("H@4')O8F%B;'D@<F5C96EV960@82!R97-U;'0@;V)J
M96-T+@H@("`@("`@("`@("`@*B!%>'1R86-T('1H92!R97-U;'0@<F5S;W5R
M8V4@:61E;G1I9FEE<BX*("`@("`@("`@("`@("HO"B`@("`@("`@("`@("1I
M9"`]("1R97-U;'0M/G)E<W5L=#L*("`@("`@("`@("`@)&=O=%]S=')I;F<@
M/2!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*@H@("`@
M("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E9"!A(')E<W5L="!R97-O=7)C
M92!I9&5N=&EF:65R+@H@("`@("`@("`@("`@*B!#;W!Y(&ET+@H@("`@("`@
M("`@("`@*B!$97!R96-A=&5D+B`@2&5R92!F;W(@8V]M<&%T:6)I;&ET>2!O
M;FQY+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@)&ED(#T@)')E<W5L
M=#L*("`@("`@("`@("`@)&=O=%]S=')I;F<@/2!F86QS93L*("`@("`@("!]
M"@H@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)&ED*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/F]D8F-286ES945R<F]R*$1"7T524D]27TY%141?
M34]215]$051!*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^;W!T
M:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TQ/5T520T%3
M12D@>PH@("`@("`@("`@("`D8V%S95]F=6YC(#T@)W-T<G1O;&]W97(G.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C87-E7V9U;F,@/2`G<W1R
M=F%L)SL*("`@("`@("!]"@H@("`@("`@("1C;W5N="`]($!O9&)C7VYU;5]F
M:65L9',H)&ED*3L*("`@("`@("`D<F5S("`@/2!A<G)A>2@I.PH*("`@("`@
M("!I9B`H)&UO9&4I('L*("`@("`@("`@("`@)')E<ULG;G5M7V9I96QD<R==
M(#T@)&-O=6YT.PH@("`@("`@('T*"B`@("`@("`@9F]R("@D:2`](#`[("1I
M(#P@)&-O=6YT.R`D:2LK*2!["B`@("`@("`@("`@("1C;VP@/2`D:2`K(#$[
M"B`@("`@("`@("`@("1R97-;)&E=(#T@87)R87DH"B`@("`@("`@("`@("`@
M("`G=&%B;&4G(#T^("1G;W1?<W1R:6YG(#\@)&-A<V5?9G5N8R@D<F5S=6QT
M*2`Z("<G+`H@("`@("`@("`@("`@("`@)VYA;64G("`]/B`D8V%S95]F=6YC
M*$!O9&)C7V9I96QD7VYA;64H)&ED+"`D8V]L*2DL"B`@("`@("`@("`@("`@
M("`G='EP92<@(#T^($!O9&)C7V9I96QD7W1Y<&4H)&ED+"`D8V]L*2P*("`@
M("`@("`@("`@("`@("=L96XG("`@/3X@0&]D8F-?9FEE;&1?;&5N*"1I9"P@
M)&-O;"DL"B`@("`@("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@
M("`@("`I.PH@("`@("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),14E.1D]?
M3U)$15(I('L*("`@("`@("`@("`@("`@("1R97-;)V]R9&5R)UU;)')E<ULD
M:5U;)VYA;64G75T@/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H)&UO9&4@)B!$0E]404),14E.1D]?3U)$15)404),12D@>PH@("`@("`@
M("`@("`@("`@)')E<ULG;W)D97)T86)L92==6R1R97-;)&E=6R=T86)L92==
M75LD<F5S6R1I75LG;F%M92==72`]("1I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`O+R!F<F5E('1H92!R97-U;'0@;VYL>2!I9B!W92!W
M97)E(&-A;&QE9"!O;B!A('1A8FQE"B`@("`@("`@:68@*"1G;W1?<W1R:6YG
M*2!["B`@("`@("`@("`@($!O9&)C7V9R965?<F5S=6QT*"1I9"D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D<F5S.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&=E=%-P96-I86Q1=65R>2@I"@H@("`@+RHJ"B`@("`@*B!/
M8G1A:6YS('1H92!Q=65R>2!S=')I;F<@;F5E9&5D(&9O<B!L:7-T:6YG(&$@
M9VEV96X@='EP92!O9B!O8FIE8W1S"B`@("`@*@H@("`@("H@5&AA;FMS('1O
M('-Y;6)O;#%`9VUA:6PN8V]M(&%N9"!0:&EL:7!P92Y*875S:6]N<T`Q,6%B
M86-U<RYC;VTN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@
M=&AE(&MI;F0@;V8@;V)J96-T<R!Y;W4@=V%N="!T;R!R971R:65V90H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@;&ES="!O9B!O8FIE8W1S
M(')E<75E<W1E9`H@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@
M("`@*B!`<V5E($1"7V-O;6UO;CHZ9V5T3&ES=$]F*"D*("`@("`J($!S:6YC
M92!-971H;V0@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XW+C`*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T4W!E8VEA;%%U97)Y*"1T>7!E*0H@("`@>PH@
M("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@("`@("`@8V%S92`G9&%T
M86)A<V5S)SH*("`@("`@("`@("`@("`@(&EF("@A9G5N8W1I;VY?97AI<W1S
M*"=O9&)C7V1A=&%?<V]U<F-E)RDI('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@;G5L;#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("1R97,@/2!`;V1B8U]D871A7W-O=7)C92@D=&AI<RT^8V]N;F5C=&EO;BP@
M4U%,7T9%5$-(7T9)4E-4*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D<F5S*2D@>PH@("`@("`@("`@("`@("`@("`@("1O=70@/2!A<G)A>2@D
M<F5S6R=S97)V97(G72D["B`@("`@("`@("`@("`@("`@("`@=VAI;&4H)')E
M<R`]($!O9&)C7V1A=&%?<V]U<F-E*"1T:&ES+3YC;VYN96-T:6]N+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!344Q?1D540TA?3D585"DI"B`@("`@("`@("`@("`@("`@("`@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D;W5T6UT@/2`D<F5S6R=S97)V97(G73L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1O=70["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^;V1B8U)A:7-E17)R;W(H*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("!C87-E("=T86)L97,G.@H@("`@("`@("`@("!C87-E("=S8VAE;6$N
M=&%B;&5S)SH*("`@("`@("`@("`@("`@("1K965P(#T@)U1!0DQ%)SL*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=V:65W<R<Z
M"B`@("`@("`@("`@("`@("`D:V5E<"`]("=62457)SL*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@
M("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H*("`@("`@("`O*@H@("`@("`@
M("`J(%)E;6]V:6YG(&YO;BUC;VYF;W)M:6YG(&ET96US(&EN('1H92!W:&EL
M92!L;V]P(')A=&AE<B!T:&%N"B`@("`@("`@("H@:6X@=&AE(&]D8F-?=&%B
M;&5S*"D@8V%L;"!B96-A=7-E('-O;64@8F%C:V5N9',@8VAO:V4@;VX@=&AI
M<SH*("`@("`@("`@*B`@("`@;V1B8U]T86)L97,H)'1H:7,M/F-O;FYE8W1I
M;VXL("<G+"`G)RP@)R<L("=404),12<I"B`@("`@("`@("HO"B`@("`@("`@
M)')E<R`@/2!`;V1B8U]T86)L97,H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@
M("`@(&EF("@A)')E<RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]D
M8F-286ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@("1O=70@/2!A<G)A
M>2@I.PH@("`@("`@('=H:6QE("@D<F]W(#T@;V1B8U]F971C:%]A<G)A>2@D
M<F5S*2D@>PH@("`@("`@("`@("!I9B`H)')O=ULG5$%"3$5?5%E012==("$]
M("1K965P*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H)'1Y<&4@/3T@)W-C:&5M82YT86)L97,G
M*2!["B`@("`@("`@("`@("`@("`D;W5T6UT@/2`D<F]W6R=404),15]30TA%
M32==("X@)RXG("X@)')O=ULG5$%"3$5?3D%-12==.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)&]U=%M=(#T@)')O=ULG5$%"3$5?
M3D%-12==.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D;W5T.PH@("`@?0H*("`@("\O('U]?0H*?0H*+RH*("H@3&]C86P@=F%R
M:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z(#0*
M("H@16YD.@H@*B\*"C\^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]$0B]P9W-Q;"YP:'``
M````````````````````````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$P-38U
M,0`Q,#4Q-30S,S<S-P`P,C`W-#,`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"B\J('9I;3H@<V5T(&5X<&%N9'1A
M8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"@HO
M*BH*("H@5&AE(%!%05(@1$(@9')I=F5R(&9O<B!02%`G<R!P9W-Q;"!E>'1E
M;G-I;VX*("H@9F]R(&EN=&5R86-T:6YG('=I=&@@4&]S=&=R95-13"!D871A
M8F%S97,*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y3
M13H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP
M(&]F('1H92!02%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*
M("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO
M=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS
M92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B
M+"!P;&5A<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O
M('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C
M871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H
M;W(@("`@(%)U:2!(:7)O:V%W82`\:&ER;VMA=V%`<&AP+FYE=#X*("H@0&%U
M=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@H@*B!`875T:&]R
M("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C
M;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@<&=S<6PN<&AP
M+'8@,2XQ,C8@,C`P-2\P,R\P-"`R,SHQ,CHS-B!D86YI96QC($5X<"`D"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@
M*B\*"B\J*@H@*B!/8G1A:6X@=&AE($1"7V-O;6UO;B!C;&%S<R!S;R!I="!C
M86X@8F4@97AT96YD960@9G)O;0H@*B\*<F5Q=6ER95]O;F-E("=$0B]C;VUM
M;VXN<&AP)SL*"B\J*@H@*B!4:&4@;65T:&]D<R!014%2($1"('5S97,@=&\@
M:6YT97)A8W0@=VET:"!02%`G<R!P9W-Q;"!E>'1E;G-I;VX*("H@9F]R(&EN
M=&5R86-T:6YG('=I=&@@4&]S=&=R95-13"!D871A8F%S97,*("H*("H@5&AE
M<V4@;65T:&]D<R!O=F5R;&]A9"!T:&4@;VYE<R!D96-L87)E9"!I;B!$0E]C
M;VUM;VXN"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E
M("`@($1""B`J($!A=71H;W(@("`@(%)U:2!(:7)O:V%W82`\:&ER;VMA=V%`
M<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N
M;F5T/@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC
M0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R
M;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!296QE
M87-E.B`Q+C<N-@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O1$(*("HO"F-L87-S($1"7W!G<W%L(&5X=&5N9',@1$)?8V]M
M;6]N"GL*("`@("\O('M[>R!P<F]P97)T:65S"@H@("`@+RHJ"B`@("`@*B!4
M:&4@1$(@9')I=F5R('1Y<&4@*&UY<W%L+"!O8VDX+"!O9&)C+"!E=&,N*0H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1P:'!T>7!E(#T@
M)W!G<W%L)SL*"B`@("`O*BH*("`@("`J(%1H92!D871A8F%S92!S>6YT87@@
M=F%R:6%N="!T;R!B92!U<V5D("AD8C(L(&%C8V5S<RP@971C+BDL(&EF(&%N
M>0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1D8G-Y;G1A
M>"`]("=P9W-Q;"<["@H@("`@+RHJ"B`@("`@*B!4:&4@8V%P86)I;&ET:65S
M(&]F('1H:7,@1$(@:6UP;&5M96YT871I;VX*("`@("`J"B`@("`@*B!4:&4@
M)VYE=U]L:6YK)R!E;&5M96YT(&-O;G1A:6YS('1H92!02%`@=F5R<VEO;B!T
M:&%T(&9I<G-T('!R;W9I9&5D"B`@("`@*B!N97=?;&EN:R!S=7!P;W)T(&9O
M<B!T:&ES($1"35,N("!#;VYT86EN<R!F86QS92!I9B!I="=S('5N<W5P<&]R
M=&5D+@H@("`@("H*("`@("`J($UE86YI;F<@;V8@=&AE("=L:6UI="<@96QE
M;65N=#H*("`@("`J("`@*R`G96UU;&%T92<@/2!E;75L871E('=I=&@@9F5T
M8V@@<F]W(&)Y(&YU;6)E<@H@("`@("H@("`K("=A;'1E<B<@("`](&%L=&5R
M('1H92!Q=65R>0H@("`@("H@("`K(&9A;'-E("`@("`]('-K:7`@<F]W<PH@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1F96%T
M=7)E<R`](&%R<F%Y*`H@("`@("`@("=L:6UI="<@("`@("`@("`]/B`G86QT
M97(G+`H@("`@("`@("=N97=?;&EN:R<@("`@("`]/B`G-"XS+C`G+`H@("`@
M("`@("=N=6UR;W=S)R`@("`@("`]/B!T<G5E+`H@("`@("`@("=P8V]N;F5C
M="<@("`@("`]/B!T<G5E+`H@("`@("`@("=P<F5P87)E)R`@("`@("`]/B!F
M86QS92P*("`@("`@("`G<W-L)R`@("`@("`@("`@/3X@=')U92P*("`@("`@
M("`G=')A;G-A8W1I;VYS)R`@/3X@=')U92P*("`@("D["@H@("`@+RHJ"B`@
M("`@*B!!(&UA<'!I;F<@;V8@;F%T:79E(&5R<F]R(&-O9&5S('1O($1"(&5R
M<F]R(&-O9&5S"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M97)R;W)C;V1E7VUA<"`](&%R<F%Y*`H@("`@*3L*"B`@("`O*BH*("`@("`J
M(%1H92!R87<@9&%T86)A<V4@8V]N;F5C=&EO;B!C<F5A=&5D(&)Y(%!(4`H@
M("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@)&-O;FYE8W1I
M;VX["@H@("`@+RHJ"B`@("`@*B!4:&4@1%-.(&EN9F]R;6%T:6]N(&9O<B!C
M;VYN96-T:6YG('1O(&$@9&%T86)A<V4*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1D<VX@/2!A<G)A>2@I.PH*"B`@("`O*BH*("`@("`J
M(%-H;W5L9"!D871A(&UA;FEP=6QA=&EO;B!Q=65R:65S(&)E(&-O;6UI='1E
M9"!A=71O;6%T:6-A;&QY/PH@("`@("H@0'9A<B!B;V]L"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1A=71O8V]M;6ET(#T@=')U
M93L*"B`@("`O*BH*("`@("`J(%1H92!Q=6%N=&ET>2!O9B!T<F%N<V%C=&EO
M;G,@8F5G=6X*("`@("`J"B`@("`@*B![0&EN=&5R;F%L("!7:&EL92!T:&ES
M(&ES('!R:79A=&4L(&ET(&-A;B=T(&%C='5A;&QY(&)E(&1E<VEG;F%T960*
M("`@("`J('!R:79A=&4@:6X@4$A0(#4@8F5C875S92!I="!I<R!D:7)E8W1L
M>2!A8V-E<W-E9"!I;B!T:&4@=&5S="!S=6ET92Y]?0H@("`@("H*("`@("`J
M($!V87(@:6YT96=E<@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@('9A<B`D=')A;G-A8W1I;VY?;W!C;W5N="`](#`["@H@("`@+RHJ"B`@
M("`@*B!4:&4@;G5M8F5R(&]F(')O=W,@869F96-T960@8GD@82!D871A(&UA
M;FEP=6QA=&EO;B!Q=65R>0H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*
M("`@('9A<B`D869F96-T960@/2`P.PH*("`@("\J*@H@("`@("H@5&AE(&-U
M<G)E;G0@<F]W(&)E:6YG(&QO;VME9"!A="!I;B!F971C:$EN=&\H*0H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@('9A<B`D<F]W(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!N
M=6UB97(@;V8@<F]W<R!I;B!A(&=I=F5N(')E<W5L="!S970*("`@("`J($!V
M87(@87)R87D*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V
M87(@)%]N=6U?<F]W<R`](&%R<F%Y*"D["@H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&-O;G-T<G5C=&]R"@H@("`@+RHJ"B`@("`@*B!4:&ES(&-O;G-T<G5C
M=&]R(&-A;&QS(#QK8F0^)'1H:7,M/D1"7V-O;6UO;B@I/"]K8F0^"B`@("`@
M*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N($1"
M7W!G<W%L*"D*("`@('L*("`@("`@("`D=&AI<RT^1$)?8V]M;6]N*"D["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]N;F5C="@I"@H@("`@+RHJ
M"B`@("`@*B!#;VYN96-T('1O('1H92!D871A8F%S92!S97)V97(L(&QO9R!I
M;B!A;F0@;W!E;B!T:&4@9&%T86)A<V4*("`@("`J"B`@("`@*B!$;VXG="!C
M86QL('1H:7,@;65T:&]D(&1I<F5C=&QY+B`@57-E($1".CIC;VYN96-T*"D@
M:6YS=&5A9"X*("`@("`J"B`@("`@*B!014%2($1")W,@<&=S<6P@9')I=F5R
M('-U<'!O<G1S('1H92!F;VQL;W=I;F<@97AT<F$@1%-.(&]P=&EO;G,Z"B`@
M("`@*B`@("L@8V]N;F5C=%]T:6UE;W5T("!(;W<@;6%N>2!S96-O;F1S('1O
M('=A:70@9F]R(&$@8V]N;F5C=&EO;B!T;PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(&)E(&5S=&%B;&ES:&5D+B`@079A:6QA8FQE('-I;F-E(%!%
M05(@1$(@,2XW+C`N"B`@("`@*B`@("L@;F5W7VQI;FL@("`@("`@("!)9B!S
M970@=&\@=')U92P@8V%U<V5S('-U8G-E<75E;G0@8V%L;',@=&\*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T*"D@=&\@<F5T=7)N(&$@
M;F5W(&-O;FYE8W1I;VX@;&EN:PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&EN<W1E860@;V8@=&AE(&5X:7-T:6YG(&]N92X@(%=!4DY)3D<Z('1H
M:7,@:7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!N;W0@<&]R=&%B
M;&4@=&\@;W1H97(@1$)-4R=S+B`@079A:6QA8FQE(&]N;'D*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!I9B!02%`@:7,@/CT@-"XS+C`@86YD(%!%
M05(@1$(@:7,@/CT@,2XW+C`N"B`@("`@*B`@("L@;W!T:6]N<R`@("`@("`@
M("!#;VUM86YD(&QI;F4@;W!T:6]N<R!T;R!B92!S96YT('1O('1H92!S97)V
M97(N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@079A:6QA8FQE('-I
M;F-E(%!%05(@1$(@,2XV+C0N"B`@("`@*B`@("L@<V5R=FEC92`@("`@("`@
M("!3<&5C:69I97,@82!S97)V:6-E(&YA;64@:6X@<&=?<V5R=FEC92YC;VYF
M('1H870*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!H;VQD<R!A9&1I
M=&EO;F%L(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!!=F%I;&%B;&4@<VEN8V4@4$5!4B!$0B`Q+C<N,"X*
M("`@("`J("`@*R!S<VQM;V1E("`@("`@("`@($AO=R!S:&]U;&0@4U-,(&)E
M('5S960@=VAE;B!C;VYN96-T:6YG/R`@5F%L=65S.@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@(&1I<V%B;&4L(&%L;&]W+"!P<F5F97(@;W(@<F5Q
M=6ER92X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!!=F%I;&%B;&4@
M<VEN8V4@4$5!4B!$0B`Q+C<N,"X*("`@("`J("`@*R!T='D@("`@("`@("`@
M("`@(%1H:7,@=V%S('5S960@=&\@<W!E8VEF>2!W:&5R92!T;R!S96YD('-E
M<G9E<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&1E8G5G(&]U='!U
M="X@($%V86EL86)L92!S:6YC92!014%2($1"(#$N-BXT+@H@("`@("H*("`@
M("`J($5X86UP;&4@;V8@8V]N;F5C=&EN9R!T;R!A(&YE=R!L:6YK('9I82!A
M('-O8VME=#H*("`@("`J(#QC;V1E/@H@("`@("H@<F5Q=6ER95]O;F-E("=$
M0BYP:'`G.PH@("`@("H@"B`@("`@*B`D9'-N(#T@)W!G<W%L.B\O=7-E<CIP
M87-S0'5N:7@H+W1M<"DO9&)N86UE/VYE=U]L:6YK/71R=64G.PH@("`@("H@
M)&]P=&EO;G,@/2!A<G)A>2@*("`@("`J("`@("`G<&]R=&%B:6QI='DG(#T^
M($1"7U!/4E1!0DE,25197T%,3"P*("`@("`J("D["B`@("`@*B`*("`@("`J
M("1D8B`])B!$0CHZ8V]N;F5C="@D9'-N+"`D;W!T:6]N<RD["B`@("`@*B!I
M9B`H4$5!4CHZ:7-%<G)O<B@D9&(I*2!["B`@("`@*B`@("`@9&EE*"1D8BT^
M9V5T365S<V%G92@I*3L*("`@("`J('T*("`@("`J(#PO8V]D93X*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)&1S;B`@("`@("`@('1H92!D871A('-O
M=7)C92!N86UE"B`@("`@*B!`<&%R86T@8F]O;"`@)'!E<G-I<W1E;G0@('-H
M;W5L9"!T:&4@8V]N;F5C=&EO;B!B92!P97)S:7-T96YT/PH@("`@("H*("`@
M("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B!!($1"7T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!L:6YK(&AT='`Z
M+R]W=W<N<&]S=&=R97-Q;"YO<F<O9&]C<R]C=7)R96YT+W-T871I8R]L:6)P
M<2YH=&UL(TQ)0E!1+4-/3DY%0U0*("`@("`J+PH@("`@9G5N8W1I;VX@8V]N
M;F5C="@D9'-N+"`D<&5R<VES=&5N="`](&9A;'-E*0H@("`@>PH@("`@("`@
M(&EF("@A4$5!4CHZ;&]A9$5X=&5N<VEO;B@G<&=S<6PG*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?15A414Y3
M24].7TY/5%]&3U5.1"D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^9'-N
M(#T@)&1S;CL*("`@("`@("!I9B`H)&1S;ELG9&)S>6YT87@G72D@>PH@("`@
M("`@("`@("`D=&AI<RT^9&)S>6YT87@@/2`D9'-N6R=D8G-Y;G1A>"==.PH@
M("`@("`@('T*"B`@("`@("`@)'!R;W1O8V]L(#T@)&1S;ELG<')O=&]C;VPG
M72`_("1D<VY;)W!R;W1O8V]L)UT@.B`G=&-P)SL*"B`@("`@("`@)'!A<F%M
M<R`](&%R<F%Y*"<G*3L*("`@("`@("!I9B`H)'!R;W1O8V]L(#T]("=T8W`G
M*2!["B`@("`@("`@("`@(&EF("@D9'-N6R=H;W-T<W!E8R==*2!["B`@("`@
M("`@("`@("`@("`D<&%R86US6S!=("X]("=H;W-T/2<@+B`D9'-N6R=H;W-T
M<W!E8R==.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D9'-N6R=P
M;W)T)UTI('L*("`@("`@("`@("`@("`@("1P87)A;7-;,%T@+CT@)R!P;W)T
M/2<@+B`D9'-N6R=P;W)T)UT["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V5I9B`H)'!R;W1O8V]L(#T]("=U;FEX)RD@>PH@("`@("`@("`@("`O+R!!
M;&QO=R!F;W(@<&<@<V]C:V5T(&EN(&YO;BUS=&%N9&%R9"!L;V-A=&EO;G,N
M"B`@("`@("`@("`@(&EF("@D9'-N6R=S;V-K970G72D@>PH@("`@("`@("`@
M("`@("`@)'!A<F%M<ULP72`N/2`G:&]S=#TG("X@)&1S;ELG<V]C:V5T)UT[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1D<VY;)W!O<G0G72D@
M>PH@("`@("`@("`@("`@("`@)'!A<F%M<ULP72`N/2`G('!O<G0])R`N("1D
M<VY;)W!O<G0G73L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I
M9B`H)&1S;ELG9&%T86)A<V4G72D@>PH@("`@("`@("`@("`D<&%R86US6S!=
M("X]("<@9&)N86UE/5PG)R`N(&%D9'-L87-H97,H)&1S;ELG9&%T86)A<V4G
M72D@+B`G7"<G.PH@("`@("`@('T*("`@("`@("!I9B`H)&1S;ELG=7-E<FYA
M;64G72D@>PH@("`@("`@("`@("`D<&%R86US6S!=("X]("<@=7-E<CU<)R<@
M+B!A9&1S;&%S:&5S*"1D<VY;)W5S97)N86UE)UTI("X@)UPG)SL*("`@("`@
M("!]"B`@("`@("`@:68@*"1D<VY;)W!A<W-W;W)D)UTI('L*("`@("`@("`@
M("`@)'!A<F%M<ULP72`N/2`G('!A<W-W;W)D/5PG)R`N(&%D9'-L87-H97,H
M)&1S;ELG<&%S<W=O<F0G72D@+B`G7"<G.PH@("`@("`@('T*("`@("`@("!I
M9B`H(65M<'1Y*"1D<VY;)V]P=&EO;G,G72DI('L*("`@("`@("`@("`@)'!A
M<F%M<ULP72`N/2`G(&]P=&EO;G,])R`N("1D<VY;)V]P=&EO;G,G73L*("`@
M("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D9'-N6R=T='DG72DI('L*("`@
M("`@("`@("`@)'!A<F%M<ULP72`N/2`G('1T>3TG("X@)&1S;ELG='1Y)UT[
M"B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)&1S;ELG8V]N;F5C=%]T
M:6UE;W5T)UTI*2!["B`@("`@("`@("`@("1P87)A;7-;,%T@+CT@)R!C;VYN
M96-T7W1I;65O=70])R`N("1D<VY;)V-O;FYE8W1?=&EM96]U="==.PH@("`@
M("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1D<VY;)W-S;&UO9&4G72DI('L*
M("`@("`@("`@("`@)'!A<F%M<ULP72`N/2`G('-S;&UO9&4])R`N("1D<VY;
M)W-S;&UO9&4G73L*("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D9'-N
M6R=S97)V:6-E)UTI*2!["B`@("`@("`@("`@("1P87)A;7-;,%T@+CT@)R!S
M97)V:6-E/2<@+B`D9'-N6R=S97)V:6-E)UT["B`@("`@("`@?0H*("`@("`@
M("!I9B`H:7-S970H)&1S;ELG;F5W7VQI;FLG72D*("`@("`@("`@("`@)B8@
M*"1D<VY;)VYE=U]L:6YK)UT@/3T@)W1R=64G('Q\("1D<VY;)VYE=U]L:6YK
M)UT@/3T]('1R=64I*0H@("`@("`@('L*("`@("`@("`@("`@:68@*'9E<G-I
M;VY?8V]M<&%R92AP:'!V97)S:6]N*"DL("<T+C,N,"<L("<^/2<I*2!["B`@
M("`@("`@("`@("`@("`D<&%R86US6UT@/2!01U-13%]#3TY.14-47T9/4D-%
M7TY%5SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&-O;FYE
M8W1?9G5N8W1I;VX@/2`D<&5R<VES=&5N="`_("=P9U]P8V]N;F5C="<@.B`G
M<&=?8V]N;F5C="<["@H@("`@("`@("1I;FD@/2!I;FE?9V5T*"=T<F%C:U]E
M<G)O<G,G*3L*("`@("`@("`D<&AP7V5R<F]R;7-G(#T@)R<["B`@("`@("`@
M:68@*"1I;FDI('L*("`@("`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!`
M8V%L;%]U<V5R7V9U;F-?87)R87DH)&-O;FYE8W1?9G5N8W1I;VXL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EN
M:5]S970H)W1R86-K7V5R<F]R<R<L(#$I.PH@("`@("`@("`@("`D=&AI<RT^
M8V]N;F5C=&EO;B`]($!C86QL7W5S97)?9G5N8U]A<G)A>2@D8V]N;F5C=%]F
M=6YC=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!A<F%M<RD["B`@("`@("`@("`@(&EN:5]S
M970H)W1R86-K7V5R<F]R<R<L("1I;FDI.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"$D=&AI<RT^8V]N;F5C=&EO;BD@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?0T].3D5#5%]&04E,140L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL
M+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!H<%]E<G)O<FUS9RD["B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/
M2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!D:7-C;VYN96-T*"D*
M"B`@("`O*BH*("`@("`J($1I<V-O;FYE8W1S(&9R;VT@=&AE(&1A=&%B87-E
M('-E<G9E<@H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@5%)512!O;B!S
M=6-C97-S+"!&04Q312!O;B!F86EL=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&1I<V-O;FYE8W0H*0H@("`@>PH@("`@("`@("1R970@/2!`<&=?8VQO<V4H
M)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("1T:&ES+3YC;VYN96-T:6]N
M(#T@;G5L;#L*("`@("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!S:6UP;&51=65R>2@I"@H@("`@+RHJ"B`@("`@*B!3
M96YD<R!A('%U97)Y('1O('1H92!D871A8F%S92!S97)V97(*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("!T:&4@4U%,('%U97)Y('-T<FEN9PH@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@("L@82!02%`@<F5S=6QT(')E<W)O
M=6-E(&9O<B!S=6-C97-S9G5L(%-%3$5#5"!Q=65R:65S"B`@("`@*B`@("`@
M("`@("`@("`@("`K('1H92!$0E]/2R!C;VYS=&%N="!F;W(@;W1H97(@<W5C
M8V5S<V9U;"!Q=65R:65S"B`@("`@*B`@("`@("`@("`@("`@("`K(&$@1$)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4*("`@("`J+PH@("`@9G5N8W1I;VX@
M<VEM<&QE475E<GDH)'%U97)Y*0H@("`@>PH@("`@("`@("1I<VUA;FEP(#T@
M1$(Z.FES36%N:7`H)'%U97)Y*3L*("`@("`@("`D=&AI<RT^;&%S=%]Q=65R
M>2`]("1Q=65R>3L*("`@("`@("`D<75E<GD@/2`D=&AI<RT^;6]D:69Y475E
M<GDH)'%U97)Y*3L*("`@("`@("!I9B`H(21T:&ES+3YA=71O8V]M;6ET("8F
M("1I<VUA;FEP*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^=')A;G-A8W1I
M;VY?;W!C;W5N="`]/2`P*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@
M0'!G7V5X96,H)'1H:7,M/F-O;FYE8W1I;VXL("=B96=I;CLG*3L*("`@("`@
M("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<&=S<6Q286ES945R<F]R*"D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/G1R86YS
M86-T:6]N7V]P8V]U;G0K*SL*("`@("`@("!]"B`@("`@("`@)')E<W5L="`]
M($!P9U]E>&5C*"1T:&ES+3YC;VYN96-T:6]N+"`D<75E<GDI.PH@("`@("`@
M(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G!G
M<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("`O+R!$971E<FUI
M;F4@=VAI8V@@<75E<FEE<R!T:&%T('-H;W5L9"!R971U<FX@9&%T82P@86YD
M('=H:6-H"B`@("`@("`@+R\@<VAO=6QD(')E='5R;B!A;B!E<G)O<B!C;V1E
M(&]N;'DN"B`@("`@("`@:68@*"1I<VUA;FEP*2!["B`@("`@("`@("`@("1T
M:&ES+3YA9F9E8W1E9"`]($!P9U]A9F9E8W1E9%]R;W=S*"1R97-U;'0I.PH@
M("`@("`@("`@("!R971U<FX@1$)?3TL["B`@("`@("`@?2!E;'-E:68@*'!R
M96=?;6%T8V@H)R]>7',J7"@J7',J*%-%3$5#5'Q%6%!,04E.?%-(3U<I7',O
M<VDG+"`D<75E<GDI*2!["B`@("`@("`@("`@("\J(%!O<W1G<F5344P@8V]M
M;6%N9',Z"B`@("`@("`@("`@("`@($%"3U)4+"!!3%1%4BP@0D5'24XL($-,
M3U-%+"!#3%535$52+"!#3TU-250L($-/4%DL"B`@("`@("`@("`@("`@($-2
M14%412P@1$5#3$%212P@1$5,151%+"!$4D]0(%1!0DQ%+"!%6%!,04E.+"!&
M151#2"P*("`@("`@("`@("`@("`@1U)!3E0L($E.4T525"P@3$E35$5.+"!,
M3T%$+"!,3T-++"!-3U9%+"!.3U1)1EDL(%)%4T54+`H@("`@("`@("`@("`@
M("!2159/2T4L(%)/3$Q"04-++"!314Q%0U0L(%-%3$5#5"!)3E1/+"!3150L
M(%-(3U<L"B`@("`@("`@("`@("`@(%5.3$E35$5.+"!54$1!5$4L(%9!0U55
M30H@("`@("`@("`@("`J+PH@("`@("`@("`@("`D=&AI<RT^<F]W6RAI;G0I
M)')E<W5L=%T@/2`P.R`O+R!R97-E="!T:&4@<F]W(&-O=6YT97(N"B`@("`@
M("`@("`@("1N=6UR;W=S(#T@)'1H:7,M/FYU;5)O=W,H)')E<W5L="D["B`@
M("`@("`@("`@(&EF("AI<U]O8FIE8W0H)&YU;7)O=W,I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)&YU;7)O=W,["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'1H:7,M/E]N=6U?<F]W<ULH:6YT*21R97-U;'1=(#T@)&YU;7)O
M=W,["B`@("`@("`@("`@("1T:&ES+3YA9F9E8W1E9"`](#`["B`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1T:&ES+3YA9F9E8W1E9"`](#`["B`@("`@("`@("`@(')E='5R;B!$
M0E]/2SL*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M;F5X=%)E<W5L="@I"@H@("`@+RHJ"B`@("`@*B!-;W9E('1H92!I;G1E<FYA
M;"!P9W-Q;"!R97-U;'0@<&]I;G1E<B!T;R!T:&4@;F5X="!A=F%I;&%B;&4@
M<F5S=6QT"B`@("`@*@H@("`@("H@0'!A<F%M(&$@=F%L:60@9F)S<6P@<F5S
M=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J"B`@("`@*B!`<F5T=7)N('1R=64@:68@82!R97-U;'0@:7,@879A:6QA
M8FQE(&]T:&5R=VES92!R971U<FX@9F%L<V4*("`@("`J+PH@("`@9G5N8W1I
M;VX@;F5X=%)E<W5L="@D<F5S=6QT*0H@("`@>PH@("`@("`@(')E='5R;B!F
M86QS93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F971C:$EN=&\H
M*0H*("`@("\J*@H@("`@("H@4&QA8V5S(&$@<F]W(&9R;VT@=&AE(')E<W5L
M="!S970@:6YT;R!T:&4@9VEV96X@87)R87D*("`@("`J"B`@("`@*B!&;W)M
M871I;F<@;V8@=&AE(&%R<F%Y(&%N9"!T:&4@9&%T82!T:&5R96EN(&%R92!C
M;VYF:6=U<F%B;&4N"B`@("`@*B!3964@1$)?<F5S=6QT.CIF971C:$EN=&\H
M*2!F;W(@;6]R92!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!4:&ES(&UE
M=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E
M"B`@("`@*B!$0E]R97-U;'0Z.F9E=&-H26YT;R@I(&EN<W1E860N("!)="!C
M86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$
M0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@
M0'!A<F%M(')E<V]U<F-E("1R97-U;'0@("`@=&AE('%U97)Y(')E<W5L="!R
M97-O=7)C90H@("`@("H@0'!A<F%M(&%R<F%Y("`@("1A<G(@("`@("`@=&AE
M(')E9F5R96YC960@87)R87D@=&\@<'5T('1H92!D871A(&EN"B`@("`@*B!`
M<&%R86T@:6YT("`@("`@)&9E=&-H;6]D92!H;W<@=&AE(')E<W5L=&EN9R!A
M<G)A>2!S:&]U;&0@8F4@:6YD97AE9`H@("`@("H@0'!A<F%M(&EN="`@("`@
M("1R;W=N=6T@("`@=&AE(')O=R!N=6UB97(@=&\@9F5T8V@@*#`@/2!F:7)S
M="!R;W<I"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1$)?3TL@;VX@
M<W5C8V5S<RP@3E5,3"!W:&5N('1H92!E;F0@;V8@82!R97-U;'0@<V5T(&ES
M"B`@("`@*B`@("`@("`@("`@("`@("`@<F5A8VAE9"!O<B!O;B!F86EL=7)E
M"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&9E=&-H26YT;R@D<F5S=6QT+"`F)&%R<BP@
M)&9E=&-H;6]D92P@)')O=VYU;2`](&YU;&PI"B`@("!["B`@("`@("`@)')E
M<W5L=%]I;G0@/2`H:6YT*21R97-U;'0["B`@("`@("`@)')O=VYU;2`]("@D
M<F]W;G5M("$]/2!N=6QL*2`_("1R;W=N=6T@.B`D=&AI<RT^<F]W6R1R97-U
M;'1?:6YT73L*("`@("`@("!I9B`H)')O=VYU;2`^/2`D=&AI<RT^7VYU;5]R
M;W=S6R1R97-U;'1?:6YT72D@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*
M("`@("`@("!]"B`@("`@("`@:68@*"1F971C:&UO9&4@)B!$0E]&151#2$U/
M1$5?05-33T,I('L*("`@("`@("`@("`@)&%R<B`]($!P9U]F971C:%]A<G)A
M>2@D<F5S=6QT+"`D<F]W;G5M+"!01U-13%]!4U-/0RD["B`@("`@("`@("`@
M(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!
M0DE,25197TQ/5T520T%312`F)B`D87)R*2!["B`@("`@("`@("`@("`@("`D
M87)R(#T@87)R87E?8VAA;F=E7VME>5]C87-E*"1A<G(L($-!4T5?3$]715(I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&%R<B`]($!P9U]F971C:%]R;W<H)')E<W5L="P@)')O=VYU;2D["B`@("`@
M("`@?0H@("`@("`@(&EF("@A)&%R<BD@>PH@("`@("`@("`@("!R971U<FX@
M;G5L;#L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P
M;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?4E1224TI('L*("`@("`@
M("`@("`@)'1H:7,M/E]R=')I;4%R<F%Y5F%L=65S*"1A<G(I.PH@("`@("`@
M('T*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@
M)B!$0E]03U)404))3$E465].54Q,7U1/7T5-4%19*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?8V]N=F5R=$YU;&Q!<G)A>59A;'5E<U1O16UP='DH)&%R<BD[
M"B`@("`@("`@?0H@("`@("`@("1T:&ES+3YR;W=;)')E<W5L=%]I;G1=(#T@
M*RLD<F]W;G5M.PH@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!F<F5E4F5S=6QT*"D*"B`@("`O*BH*("`@("`J
M($1E;&5T97,@=&AE(')E<W5L="!S970@86YD(&9R965S('1H92!M96UO<GD@
M;V-C=7!I960@8GD@=&AE(')E<W5L="!S970*("`@("`J"B`@("`@*B!4:&ES
M(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@
M57-E"B`@("`@*B!$0E]R97-U;'0Z.F9R964H*2!I;G-T96%D+B`@270@8V%N
M)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?
M<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P
M87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G<R!Q=65R>2!R97-U;'0@<F5S
M;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@(%12544@;VX@<W5C
M8V5S<RP@1D%,4T4@:68@)')E<W5L="!I<R!I;G9A;&ED"B`@("`@*@H@("`@
M("H@0'-E92!$0E]R97-U;'0Z.F9R964H*0H@("`@("HO"B`@("!F=6YC=&EO
M;B!F<F5E4F5S=6QT*"1R97-U;'0I"B`@("!["B`@("`@("`@:68@*&ES7W)E
M<V]U<F-E*"1R97-U;'0I*2!["B`@("`@("`@("`@('5N<V5T*"1T:&ES+3YR
M;W=;*&EN="DD<F5S=6QT72D["B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?
M;G5M7W)O=W-;*&EN="DD<F5S=6QT72D["B`@("`@("`@("`@("1T:&ES+3YA
M9F9E8W1E9"`](#`["B`@("`@("`@("`@(')E='5R;B!`<&=?9G)E97)E<W5L
M="@D<F5S=6QT*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('%U;W1E*"D*"B`@("`O*BH*
M("`@("`J($!D97!R96-A=&5D("!$97!R96-A=&5D(&EN(')E;&5A<V4@,2XV
M+C`*("`@("`J($!I;G1E<FYA;`H@("`@("HO"B`@("!F=6YC=&EO;B!Q=6]T
M92@D<W1R*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<75O=&53;6%R
M="@D<W1R*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!Q=6]T95-M
M87)T*"D*"B`@("`O*BH*("`@("`J($9O<FUA=',@:6YP=70@<V\@:70@8V%N
M(&)E('-A9F5L>2!U<V5D(&EN(&$@<75E<GD*("`@("`J"B`@("`@*B!`<&%R
M86T@;6EX960@)&EN("!T:&4@9&%T82!T;R!B92!F;W)M871T960*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!T:&4@9F]R;6%T=&5D(&1A=&$N("!4
M:&4@9F]R;6%T(&1E<&5N9',@;VX@=&AE(&EN<'5T)W,*("`@("`J("`@("`@
M("`@("`@("`@("!02%`@='EP93H*("`@("`J("`@("`@("`@("`@("`@("`K
M(&YU;&P@/2!T:&4@<W1R:6YG(#QS86UP/DY53$P\+W-A;7`^"B`@("`@*B`@
M("`@("`@("`@("`@("`@*R!B;V]L96%N(#T@<W1R:6YG(#QS86UP/E12544\
M+W-A;7`^(&]R(#QS86UP/D9!3%-%/"]S86UP/@H@("`@("H@("`@("`@("`@
M("`@("`@("L@:6YT96=E<B!O<B!D;W5B;&4@/2!T:&4@=6YQ=6]T960@;G5M
M8F5R"B`@("`@*B`@("`@("`@("`@("`@("`@*R!O=&AE<B`H:6YC;'5D:6YG
M('-T<FEN9W,@86YD(&YU;65R:6,@<W1R:6YG<RD@/0H@("`@("H@("`@("`@
M("`@("`@("`@("`@=&AE(&1A=&$@97-C87!E9"!A8V-O<F1I;F<@=&\@37E3
M44PG<R!S971T:6YG<PH@("`@("H@("`@("`@("`@("`@("`@("`@=&AE;B!E
M;F-A<'-U;&%T960@8F5T=V5E;B!S:6YG;&4@<75O=&5S"B`@("`@*@H@("`@
M("H@0'-E92!$0E]C;VUM;VXZ.G%U;W1E4VUA<G0H*0H@("`@("H@0'-I;F-E
M($UE=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C8N,`H@("`@("HO
M"B`@("!F=6YC=&EO;B!Q=6]T95-M87)T*"1I;BD*("`@('L*("`@("`@("!I
M9B`H:7-?:6YT*"1I;BD@?'P@:7-?9&]U8FQE*"1I;BDI('L*("`@("`@("`@
M("`@<F5T=7)N("1I;CL*("`@("`@("!](&5L<V5I9B`H:7-?8F]O;"@D:6XI
M*2!["B`@("`@("`@("`@(')E='5R;B`D:6X@/R`G5%)512<@.B`G1D%,4T4G
M.PH@("`@("`@('T@96QS96EF("AI<U]N=6QL*"1I;BDI('L*("`@("`@("`@
M("`@<F5T=7)N("=.54Q,)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@(B<B("X@)'1H:7,M/F5S8V%P95-I;7!L92@D:6XI("X@(B<B
M.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E<V-A
M<&53:6UP;&4H*0H*("`@("\J*@H@("`@("H@17-C87!E<R!A('-T<FEN9R!A
M8V-O<F1I;F<@=&\@=&AE(&-U<G)E;G0@1$)-4R=S('-T86YD87)D<PH@("`@
M("H*("`@("`J('M`:6YT97)N86P@4&]S=&=R95-13"!T<F5A=',@82!B86-K
M<VQA<V@@87,@86X@97-C87!E(&-H87)A8W1E<BP*("`@("`J('-O('1H97D@
M87)E(&5S8V%P960@87,@=V5L;"X*("`@("`J"B`@("`@*B!.;W0@=7-I;F<@
M<&=?97-C87!E7W-T<FEN9R@I('EE="!B96-A=7-E(&ET(')E<75I<F5S(%!O
M<W1G<F5344P*("`@("`J('1O(&)E(&%T('9E<G-I;VX@-RXR(&]R(&=R96%T
M97(N?7T*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S='(@('1H92!S
M=')I;F<@=&\@8F4@97-C87!E9`H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!T:&4@97-C87!E9"!S=')I;F<*("`@("`J"B`@("`@*B!`<V5E($1"
M7V-O;6UO;CHZ<75O=&53;6%R="@I"B`@("`@*B!`<VEN8V4@365T:&]D(&%V
M86EL86)L92!S:6YC92!296QE87-E(#$N-BXP"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&5S8V%P95-I;7!L92@D<W1R*0H@("`@>PH@("`@("`@(')E='5R;B!S
M=')?<F5P;&%C92@B)R(L("(G)R(L('-T<E]R97!L86-E*"=<7"<L("=<7%Q<
M)RP@)'-T<BDI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YU;4-O
M;',H*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M8F5R(&]F(&-O;'5M
M;G,@:6X@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@
M:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@
M("H@1$)?<F5S=6QT.CIN=6U#;VQS*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E
M(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L
M="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT(')E<V]U<F-E
M"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@8V]L
M=6UN<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@
M("`@("H@0'-E92!$0E]R97-U;'0Z.FYU;4-O;',H*0H@("`@("HO"B`@("!F
M=6YC=&EO;B!N=6U#;VQS*"1R97-U;'0I"B`@("!["B`@("`@("`@)&-O;',@
M/2!`<&=?;G5M9FEE;&1S*"1R97-U;'0I.PH@("`@("`@(&EF("@A)&-O;',I
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YP9W-Q;%)A:7-E17)R;W(H
M*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1C;VQS.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&YU;5)O=W,H*0H*("`@("\J*@H@("`@("H@
M1V5T<R!T:&4@;G5M8F5R(&]F(')O=W,@:6X@82!R97-U;'0@<V5T"B`@("`@
M*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE
M9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIN=6U2;W=S*"D@
M:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@
M("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@
M<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G0@('1H92!N=6UB97(@;V8@<F]W<RX@($$@1$)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.FYU;5)O
M=W,H*0H@("`@("HO"B`@("!F=6YC=&EO;B!N=6U2;W=S*"1R97-U;'0I"B`@
M("!["B`@("`@("`@)')O=W,@/2!`<&=?;G5M<F]W<R@D<F5S=6QT*3L*("`@
M("`@("!I9B`H)')O=W,@/3T](&YU;&PI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YP9W-Q;%)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1R;W=S.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&%U
M=&]#;VUM:70H*0H*("`@("\J*@H@("`@("H@16YA8FQE<R!O<B!D:7-A8FQE
M<R!A=71O;6%T:6,@8V]M;6ET<PH@("`@("H*("`@("`J($!P87)A;2!B;V]L
M("1O;F]F9B`@=')U92!T=7)N<R!I="!O;BP@9F%L<V4@='5R;G,@:70@;V9F
M"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N
M("!!($1"7T5R<F]R(&]B:F5C="!I9B!T:&4@9')I=F5R"B`@("`@*B`@("`@
M("`@("`@("`@(&1O97-N)W0@<W5P<&]R="!A=71O+6-O;6UI='1I;F<@=')A
M;G-A8W1I;VYS+@H@("`@("HO"B`@("!F=6YC=&EO;B!A=71O0V]M;6ET*"1O
M;F]F9B`](&9A;'-E*0H@("`@>PH@("`@("`@("\O(%A86"!I9B`D=&AI<RT^
M=')A;G-A8W1I;VY?;W!C;W5N="`^(#`L('=E('-H;W5L9"!P<F]B86)L>0H@
M("`@("`@("\O(&ES<W5E(&$@=V%R;FEN9R!H97)E+@H@("`@("`@("1T:&ES
M+3YA=71O8V]M;6ET(#T@)&]N;V9F(#\@=')U92`Z(&9A;'-E.PH@("`@("`@
M(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C
M;VUM:70H*0H*("`@("\J*@H@("`@("H@0V]M;6ET<R!T:&4@8W5R<F5N="!T
M<F%N<V%C=&EO;@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O
M;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@8V]M;6ET*"D*("`@('L*("`@("`@("!I9B`H
M)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/B`P*2!["B`@("`@("`@("`@
M("\O("AD:7-A8FQE9"D@:&%C:R!T;R!S:'5T('5P(&5R<F]R(&UE<W-A9V5S
M(&9R;VT@;&EB<'$N80H@("`@("`@("`@("`O+T!F8VQO<V4H0&9O<&5N*")P
M:'`Z+R]S=&1E<G(B+"`B=R(I*3L*("`@("`@("`@("`@)')E<W5L="`]($!P
M9U]E>&5C*"1T:&ES+3YC;VYN96-T:6]N+"`G96YD.R<I.PH@("`@("`@("`@
M("`D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`](#`["B`@("`@("`@("`@
M(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YP9W-Q;%)A:7-E17)R;W(H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@<F]L;&)A8VLH*0H*("`@("\J*@H@("`@("H@4F5V97)T<R!T:&4@
M8W5R<F5N="!T<F%N<V%C=&EO;@H@("`@("H*("`@("`J($!R971U<FX@:6YT
M("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F]L;&)A8VLH*0H@("`@>PH@
M("`@("`@(&EF("@D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`^(#`I('L*
M("`@("`@("`@("`@)')E<W5L="`]($!P9U]E>&5C*"1T:&ES+3YC;VYN96-T
M:6]N+"`G86)O<G0[)RD["B`@("`@("`@("`@("1T:&ES+3YT<F%N<V%C=&EO
M;E]O<&-O=6YT(#T@,#L*("`@("`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G!G<W%L4F%I<V5%<G)O<B@I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/
M2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!A9F9E8W1E9%)O=W,H
M*0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!T:&4@;G5M8F5R(&]F(')O
M=W,@869F96-T960@8GD@82!D871A(&UA;FEU<&QA=&EO;B!Q=65R>0H@("`@
M("H*("`@("`J(#`@:7,@<F5T=7)N960@9F]R('%U97)I97,@=&AA="!D;VXG
M="!M86YI<'5L871E(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@
M('1H92!N=6UB97(@;V8@<F]W<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%F9F5C=&5D4F]W<R@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YA9F9E8W1E9#L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!N97AT260H*0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@;F5X="!F<F5E(&ED(&EN(&$@<V5Q=65N8V4*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V5Q7VYA;64@(&YA;64@;V8@=&AE
M('-E<75E;F-E"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;VYD96UA;F0@('=H
M96X@=')U92P@=&AE('-E<65N8V4@:7,@875T;VUA=&EC86QL>0H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8W)E871E9"!I9B!I="!D;V5S
M(&YO="!E>&ES=`H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;F5X
M="!I9"!N=6UB97(@:6X@=&AE('-E<75E;F-E+@H@("`@("H@("`@("`@("`@
M("`@("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@
M("`J($!S964@1$)?8V]M;6]N.CIN97AT240H*2P@1$)?8V]M;6]N.CIG9713
M97%U96YC94YA;64H*2P*("`@("`J("`@("`@1$)?<&=S<6PZ.F-R96%T95-E
M<75E;F-E*"DL($1"7W!G<W%L.CID<F]P4V5Q=65N8V4H*0H@("`@("HO"B`@
M("!F=6YC=&EO;B!N97AT260H)'-E<5]N86UE+"`D;VYD96UA;F0@/2!T<G5E
M*0H@("`@>PH@("`@("`@("1S97%N86UE(#T@)'1H:7,M/F=E=%-E<75E;F-E
M3F%M92@D<V5Q7VYA;64I.PH@("`@("`@("1R97!E870@/2!F86QS93L*("`@
M("`@("!D;R!["B`@("`@("`@("`@("1T:&ES+3YP=7-H17)R;W)(86YD;&EN
M9RA014%27T524D]27U)%5%523BD["B`@("`@("`@("`@("1R97-U;'0@/28@
M)'1H:7,M/G%U97)Y*")314Q%0U0@3D585%9!3"@G)'MS97%N86UE?2<I(BD[
M"B`@("`@("`@("`@("1T:&ES+3YP;W!%<G)O<DAA;F1L:6YG*"D["B`@("`@
M("`@("`@(&EF("@D;VYD96UA;F0@)B8@1$(Z.FES17)R;W(H)')E<W5L="D@
M)B8*("`@("`@("`@("`@("`@("1R97-U;'0M/F=E=$-O9&4H*2`]/2!$0E]%
M4E)/4E].3U-50TA404),12D@>PH@("`@("`@("`@("`@("`@)')E<&5A="`]
M('1R=64["B`@("`@("`@("`@("`@("`D=&AI<RT^<'5S:$5R<F]R2&%N9&QI
M;F<H4$5!4E]%4E)/4E]215154DXI.PH@("`@("`@("`@("`@("`@)')E<W5L
M="`]("1T:&ES+3YC<F5A=&5397%U96YC92@D<V5Q7VYA;64I.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/G!O<$5R<F]R2&%N9&QI;F<H*3L*("`@("`@("`@
M("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1R97!E870@/2!F86QS93L*("`@("`@("`@("`@?0H@("`@
M("`@('T@=VAI;&4@*"1R97!E870I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O
M<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)')E<W5L="D["B`@("`@("`@?0H@("`@("`@("1A<G(@/2`D<F5S
M=6QT+3YF971C:%)O=RA$0E]&151#2$U/1$5?3U)$15)%1"D["B`@("`@("`@
M)')E<W5L="T^9G)E92@I.PH@("`@("`@(')E='5R;B`D87)R6S!=.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&-R96%T95-E<75E;F-E*"D*"B`@
M("`O*BH*("`@("`J($-R96%T97,@82!N97<@<V5Q=65N8V4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1S97%?;F%M92`@;F%M92!O9B!T:&4@;F5W
M('-E<75E;F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N
M('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("H*("`@("`J($!S964@1$)?8V]M;6]N.CIC<F5A=&5397%U96YC92@I+"!$
M0E]C;VUM;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@("`@("!$0E]P
M9W-Q;#HZ;F5X=$E$*"DL($1"7W!G<W%L.CID<F]P4V5Q=65N8V4H*0H@("`@
M("HO"B`@("!F=6YC=&EO;B!C<F5A=&5397%U96YC92@D<V5Q7VYA;64I"B`@
M("!["B`@("`@("`@)'-E<6YA;64@/2`D=&AI<RT^9V5T4V5Q=65N8V5.86UE
M*"1S97%?;F%M92D["B`@("`@("`@)')E<W5L="`]("1T:&ES+3YQ=65R>2@B
M0U)%051%(%-%455%3D-%("1[<V5Q;F%M97TB*3L*("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!D<F]P4V5Q
M=65N8V4H*0H*("`@("\J*@H@("`@("H@1&5L971E<R!A('-E<75E;F-E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5Q7VYA;64@(&YA;64@;V8@
M=&AE('-E<75E;F-E('1O(&)E(&1E;&5T960*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F1R
M;W!397%U96YC92@I+"!$0E]C;VUM;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@
M("`@("H@("`@("!$0E]P9W-Q;#HZ;F5X=$E$*"DL($1"7W!G<W%L.CIC<F5A
M=&5397%U96YC92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&1R;W!397%U96YC
M92@D<V5Q7VYA;64I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YQ=65R
M>2@G1%)/4"!315%514Y#12`G"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`N("1T:&ES+3YG971397%U96YC94YA;64H)'-E<5]N86UE*2D["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;6]D:69Y3&EM:711=65R>2@I"@H@
M("`@+RHJ"B`@("`@*B!!9&1S($Q)34E4(&-L875S97,@=&\@82!Q=65R>2!S
M=')I;F<@86-C;W)D:6YG('1O(&-U<G)E;G0@1$)-4R!S=&%N9&%R9',*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1Q=65R>2`@('1H92!Q=65R>2!T
M;R!M;V1I9GD*("`@("`J($!P87)A;2!I;G0@("`@)&9R;VT@("`@=&AE(')O
M=R!T;R!S=&%R="!T;R!F971C:&EN9R`H,"`]('1H92!F:7)S="!R;W<I"B`@
M("`@*B!`<&%R86T@:6YT("`@("1C;W5N="`@('1H92!N=6UB97)S(&]F(')O
M=W,@=&\@9F5T8V@*("`@("`J($!P87)A;2!M:7AE9"`@)'!A<F%M<R`@87)R
M87DL('-T<FEN9R!O<B!N=6UE<FEC(&1A=&$@=&\@8F4@=7-E9"!I;@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@97AE8W5T:6]N(&]F('1H92!S
M=&%T96UE;G0N("!1=6%N=&ET>2!O9B!I=&5M<PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@<&%S<V5D(&UU<W0@;6%T8V@@<75A;G1I='D@;V8@
M<&QA8V5H;VQD97)S(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!Q=65R>3H@(&UE86YI;F<@,2!P;&%C96AO;&1E<B!F;W(@;F]N+6%R<F%Y
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!P87)A;65T97)S(&]R
M(#$@<&QA8V5H;VQD97(@<&5R(&%R<F%Y(&5L96UE;G0N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@('1H92!Q=65R>2!S=')I;F<@=VET:"!,24U)
M5"!C;&%U<V5S(&%D9&5D"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T
M960*("`@("`J+PH@("`@9G5N8W1I;VX@;6]D:69Y3&EM:711=65R>2@D<75E
M<GDL("1F<F]M+"`D8V]U;G0L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@(')E='5R;B`B)'%U97)Y($Q)34E4("1C;W5N="!/1D93150@)&9R
M;VTB.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('!G<W%L4F%I<V5%
M<G)O<B@I"@H@("`@+RHJ"B`@("`@*B!0<F]D=6-E<R!A($1"7T5R<F]R(&]B
M:F5C="!R96=A<F1I;F<@=&AE(&-U<G)E;G0@<')O8FQE;0H@("`@("H*("`@
M("`J($!P87)A;2!I;G0@)&5R<FYO("!I9B!T:&4@97)R;W(@:7,@8F5I;F<@
M;6%N=6%L;'D@<F%I<V5D('!A<W,@80H@("`@("H@("`@("`@("`@("`@("`@
M("`@("!$0E]%4E)/4BH@8V]N<W1A;G0@:&5R92X@($EF('1H:7,@:7-N)W0@
M<&%S<V5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@('1H92!E<G)O<B!I
M;F9O<FUA=&EO;B!G871H97)E9"!F<F]M('1H92!$0DU3+@H@("`@("H*("`@
M("`J($!R971U<FX@;V)J96-T("!T:&4@1$)?17)R;W(@;V)J96-T"B`@("`@
M*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G)A:7-E17)R;W(H*2P*("`@("`J
M("`@("`@1$)?<&=S<6PZ.F5R<F]R3F%T:79E*"DL($1"7W!G<W%L.CIE<G)O
M<D-O9&4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!P9W-Q;%)A:7-E17)R;W(H
M)&5R<FYO(#T@;G5L;"D*("`@('L*("`@("`@("`D;F%T:79E(#T@)'1H:7,M
M/F5R<F]R3F%T:79E*"D["B`@("`@("`@:68@*"1E<G)N;R`]/3T@;G5L;"D@
M>PH@("`@("`@("`@("`D97)R;F\@/2`D=&AI<RT^97)R;W)#;V1E*"1N871I
M=F4I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H)&5R<FYO+"!N=6QL+"!N=6QL+"!N=6QL+"`D;F%T:79E*3L*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!E<G)O<DYA=&EV92@I"@H@("`@+RHJ
M"B`@("`@*B!'971S('1H92!$0DU3)R!N871I=F4@97)R;W(@;65S<V%G92!P
M<F]D=6-E9"!B>2!T:&4@;&%S="!Q=65R>0H@("`@("H*("`@("`J('M`:6YT
M97)N86P@17)R;W(@;65S<V%G97,@87)E('5S960@:6YS=&5A9"!O9B!E<G)O
M<B!C;V1E<R`*("`@("`J(&EN(&]R9&5R('1O('-U<'!O<G0@;VQD97(@=F5R
M<VEO;G,@;V8@4&]S=&=R95-13"Y]?0H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!T:&4@1$)-4R<@97)R;W(@;65S<V%G90H@("`@("HO"B`@("!F
M=6YC=&EO;B!E<G)O<DYA=&EV92@I"B`@("!["B`@("`@("`@<F5T=7)N($!P
M9U]E<G)O<FUE<W-A9V4H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&5R<F]R0V]D92@I"@H@("`@+RHJ"B`@("`@
M*B!$971E<FUI;F5S(%!%05(Z.D1"(&5R<F]R(&-O9&4@9G)O;2!T:&4@9&%T
M86)A<V4G<R!T97AT(&5R<F]R(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0'!A
M<F%M("!S=')I;F<@("1E<G)O<FUS9R`@97)R;W(@;65S<V%G92!R971U<FYE
M9"!F<F]M('1H92!D871A8F%S90H@("`@("H@0')E='5R;B!I;G1E9V5R("!A
M;B!E<G)O<B!N=6UB97(@9G)O;2!A($1"(&5R<F]R(&-O;G-T86YT"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&5R<F]R0V]D92@D97)R;W)M<V<I"B`@("!["B`@
M("`@("`@<W1A=&EC("1E<G)O<E]R96=E>'!S.PH@("`@("`@(&EF("@A:7-S
M970H)&5R<F]R7W)E9V5X<',I*2!["B`@("`@("`@("`@("1E<G)O<E]R96=E
M>'!S(#T@87)R87DH"B`@("`@("`@("`@("`@("`G+RAR96QA=&EO;GQS97%U
M96YC97QT86)L92DN*F1O97,@;F]T(&5X:7-T?&-L87-S("XJ(&YO="!F;W5N
M9"]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27TY/4U5#2%1!
M0DQ%+`H@("`@("`@("`@("`@("`@)R]I;F1E>"`N*B!D;V5S(&YO="!E>&ES
M="\G"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?3D]47T9/54Y$
M+`H@("`@("`@("`@("`@("`@)R]C;VQU;6X@+BH@9&]E<R!N;W0@97AI<W0O
M:2<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E].3U-50TA&245,
M1"P*("`@("`@("`@("`@("`@("<O<F5L871I;VX@+BH@86QR96%D>2!E>&ES
M=',O:2<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E]!3%)%0419
M7T5825-44RP*("`@("`@("`@("`@("`@("<O*&1I=FED97QD:79I<VEO;BD@
M8GD@>F5R;R0O:2<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E]$
M259:15)/+`H@("`@("`@("`@("`@("`@)R]P9U]A=&]I.B!E<G)O<B!I;B`N
M*CH@8V%N7"=T('!A<G-E("]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"
M7T524D]27TE.5D%,241?3E5-0D52+`H@("`@("`@("`@("`@("`@)R]I;G9A
M;&ED(&EN<'5T('-Y;G1A>"!F;W(H('1Y<&4I/R`H:6YT96=E<GQN=6UE<FEC
M*2]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27TE.5D%,241?
M3E5-0D52+`H@("`@("`@("`@("`@("`@)R]V86QU92`N*B!I<R!O=70@;V8@
M<F%N9V4@9F]R('1Y<&4@7'<J:6YT+VDG"B`@("`@("`@("`@("`@("`@("`@
M/3X@1$)?15)23U)?24Y604Q)1%].54U"15(L"B`@("`@("`@("`@("`@("`G
M+VEN=&5G97(@;W5T(&]F(')A;F=E+VDG"B`@("`@("`@("`@("`@("`@("`@
M/3X@1$)?15)23U)?24Y604Q)1%].54U"15(L"B`@("`@("`@("`@("`@("`G
M+W9A;'5E('1O;R!L;VYG(&9O<B!T>7!E(&-H87)A8W1E<B]I)PH@("`@("`@
M("`@("`@("`@("`@(#T^($1"7T524D]27TE.5D%,240L"B`@("`@("`@("`@
M("`@("`G+V%T=')I8G5T92`N*B!N;W0@9F]U;F1\<F5L871I;VX@+BH@9&]E
M<R!N;W0@:&%V92!A='1R:6)U=&4O:2<*("`@("`@("`@("`@("`@("`@("`]
M/B!$0E]%4E)/4E].3U-50TA&245,1"P*("`@("`@("`@("`@("`@("<O8V]L
M=6UN("XJ('-P96-I9FEE9"!I;B!54TE.1R!C;&%U<V4@9&]E<R!N;W0@97AI
M<W0@:6X@*&QE9G1\<FEG:'0I('1A8FQE+VDG"B`@("`@("`@("`@("`@("`@
M("`@/3X@1$)?15)23U)?3D]354-(1DE%3$0L"B`@("`@("`@("`@("`@("`G
M+W!A<G-E<CH@<&%R<V4@97)R;W(@870@;W(@;F5A<B]I)PH@("`@("`@("`@
M("`@("`@("`@(#T^($1"7T524D]27U-93E1!6"P*("`@("`@("`@("`@("`@
M("<O<WEN=&%X(&5R<F]R(&%T+R<*("`@("`@("`@("`@("`@("`@("`]/B!$
M0E]%4E)/4E]364Y405@L"B`@("`@("`@("`@("`@("`G+V-O;'5M;B!R969E
M<F5N8V4@+BH@:7,@86UB:6=U;W5S+VDG"B`@("`@("`@("`@("`@("`@("`@
M/3X@1$)?15)23U)?4UE.5$%8+`H@("`@("`@("`@("`@("`@)R]P97)M:7-S
M:6]N(&1E;FEE9"\G"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?
M04-#15-37U9)3TQ!5$E/3BP*("`@("`@("`@("`@("`@("<O=FEO;&%T97,@
M;F]T+6YU;&P@8V]N<W1R86EN="\G"B`@("`@("`@("`@("`@("`@("`@/3X@
M1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3"P*("`@("`@("`@("`@("`@
M("<O=FEO;&%T97,@6UQW(%TK(&-O;G-T<F%I;G0O)PH@("`@("`@("`@("`@
M("`@("`@(#T^($1"7T524D]27T-/3E-44D%)3E0L"B`@("`@("`@("`@("`@
M("`G+W)E9F5R96YT:6%L(&EN=&5G<FET>2!V:6]L871I;VXO)PH@("`@("`@
M("`@("`@("`@("`@(#T^($1"7T524D]27T-/3E-44D%)3E0L"B`@("`@("`@
M("`@("`@("`G+VUO<F4@97AP<F5S<VEO;G,@=&AA;B!T87)G970@8V]L=6UN
M<R]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27U9!3%5%7T-/
M54Y47T].7U)/5RP*("`@("`@("`@("`@*3L*("`@("`@("!]"B`@("`@("`@
M9F]R96%C:"`H)&5R<F]R7W)E9V5X<',@87,@)')E9V5X<"`]/B`D8V]D92D@
M>PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@D<F5G97AP+"`D97)R;W)M
M<V<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&-O9&4["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@+R\@1F%L;"!B86-K('1O($1"7T52
M4D]2(&EF('1H97)E('=A<R!N;R!M87!P:6YG+@H@("`@("`@(')E='5R;B!$
M0E]%4E)/4CL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!T86)L94EN
M9F\H*0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!I;F9O<FUA=&EO;B!A8F]U
M="!A('1A8FQE(&]R(&$@<F5S=6QT('-E=`H@("`@("H*("`@("`J($Y/5$4Z
M(&]N;'D@<W5P<&]R=',@)W1A8FQE)R!A;F0@)V9L86=S)R!I9B`\=F%R/B1R
M97-U;'0\+W9A<CX*("`@("`J(&ES(&$@=&%B;&4@;F%M92X*("`@("`J"B`@
M("`@*B!`<&%R86T@;V)J96-T?'-T<FEN9R`@)')E<W5L="`@1$)?<F5S=6QT
M(&]B:F5C="!F<F]M(&$@<75E<GD@;W(@80H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!S=')I;F<@8V]N=&%I;FEN9R!T:&4@;F%M
M92!O9B!A('1A8FQE+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!7:&EL92!T:&ES(&%L<V\@86-C97!T<R!A('%U97)Y(')E<W5L
M=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R97-O
M=7)C92!I9&5N=&EF:65R+"!T:&ES(&)E:&%V:6]R(&ES"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1E<')E8V%T960N"B`@("`@
M*B!`<&%R86T@:6YT("`@("`@("`@("`@)&UO9&4@("`@82!V86QI9"!T86)L
M94EN9F\@;6]D90H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(&%N(&%S
M<V]C:6%T:79E(&%R<F%Y('=I=&@@=&AE(&EN9F]R;6%T:6]N(')E<75E<W1E
M9"X*("`@("`J("`@("`@("`@("`@("`@("!!($1"7T5R<F]R(&]B:F5C="!O
M;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIT86)L
M94EN9F\H*0H@("`@("HO"B`@("!F=6YC=&EO;B!T86)L94EN9F\H)')E<W5L
M="P@)&UO9&4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]S=')I;F<H
M)')E<W5L="DI('L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@4')O
M8F%B;'D@<F5C96EV960@82!T86)L92!N86UE+@H@("`@("`@("`@("`@*B!#
M<F5A=&4@82!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@("`@
M("`@("HO"B`@("`@("`@("`@("1I9"`]($!P9U]E>&5C*"1T:&ES+3YC;VYN
M96-T:6]N+"`B4T5,14-4("H@1E)/32`D<F5S=6QT($Q)34E4(#`B*3L*("`@
M("`@("`@("`@)&=O=%]S=')I;F<@/2!T<G5E.PH@("`@("`@('T@96QS96EF
M("AI<W-E="@D<F5S=6QT+3YR97-U;'0I*2!["B`@("`@("`@("`@("\J"B`@
M("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I=F5D(&$@<F5S=6QT(&]B:F5C
M="X*("`@("`@("`@("`@("H@17AT<F%C="!T:&4@<F5S=6QT(')E<V]U<F-E
M(&ED96YT:69I97(N"B`@("`@("`@("`@("`J+PH@("`@("`@("`@("`D:60@
M/2`D<F5S=6QT+3YR97-U;'0["B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@
M9F%L<V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH*("`@("`@
M("`@("`@("H@4')O8F%B;'D@<F5C96EV960@82!R97-U;'0@<F5S;W5R8V4@
M:61E;G1I9FEE<BX*("`@("`@("`@("`@("H@0V]P>2!I="X*("`@("`@("`@
M("`@("H@1&5P<F5C871E9"X@($AE<F4@9F]R(&-O;7!A=&EB:6QI='D@;VYL
M>2X*("`@("`@("`@("`@("HO"B`@("`@("`@("`@("1I9"`]("1R97-U;'0[
M"B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1I9"DI('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YP9W-Q;%)A:7-E17)R;W(H1$)?15)23U)?3D5%1%]-
M3U)%7T1!5$$I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3YO<'1I
M;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3$]715)#05-%
M*2!["B`@("`@("`@("`@("1C87-E7V9U;F,@/2`G<W1R=&]L;W=E<B<["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-A<V5?9G5N8R`]("=S=')V
M86PG.PH@("`@("`@('T*"B`@("`@("`@)&-O=6YT(#T@0'!G7VYU;69I96QD
M<R@D:60I.PH@("`@("`@("1R97,@("`](&%R<F%Y*"D["@H@("`@("`@(&EF
M("@D;6]D92D@>PH@("`@("`@("`@("`D<F5S6R=N=6U?9FEE;&1S)UT@/2`D
M8V]U;G0["B`@("`@("`@?0H*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D
M8V]U;G0[("1I*RLI('L*("`@("`@("`@("`@)')E<ULD:5T@/2!A<G)A>2@*
M("`@("`@("`@("`@("`@("=T86)L92<@/3X@)&=O=%]S=')I;F<@/R`D8V%S
M95]F=6YC*"1R97-U;'0I(#H@)R<L"B`@("`@("`@("`@("`@("`G;F%M92<@
M(#T^("1C87-E7V9U;F,H0'!G7V9I96QD;F%M92@D:60L("1I*2DL"B`@("`@
M("`@("`@("`@("`G='EP92<@(#T^($!P9U]F:65L9'1Y<&4H)&ED+"`D:2DL
M"B`@("`@("`@("`@("`@("`G;&5N)R`@(#T^($!P9U]F:65L9'-I>F4H)&ED
M+"`D:2DL"B`@("`@("`@("`@("`@("`G9FQA9W,G(#T^("1G;W1?<W1R:6YG
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@(#\@)'1H:7,M/E]P9T9I96QD
M1FQA9W,H)&ED+"`D:2P@)')E<W5L="D*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`G)RP*("`@("`@("`@("`@*3L*("`@("`@("`@("`@:68@*"1M
M;V1E("8@1$)?5$%"3$5)3D9/7T]21$52*2!["B`@("`@("`@("`@("`@("`D
M<F5S6R=O<F1E<B==6R1R97-;)&E=6R=N86UE)UU=(#T@)&D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/7T]2
M1$525$%"3$4I('L*("`@("`@("`@("`@("`@("1R97-;)V]R9&5R=&%B;&4G
M75LD<F5S6R1I75LG=&%B;&4G75U;)')E<ULD:5U;)VYA;64G75T@/2`D:3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@9G)E92!T:&4@
M<F5S=6QT(&]N;'D@:68@=V4@=V5R92!C86QL960@;VX@82!T86)L90H@("`@
M("`@(&EF("@D9V]T7W-T<FEN9RD@>PH@("`@("`@("`@("!`<&=?9G)E97)E
M<W5L="@D:60I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')E<SL*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!?<&=&:65L9$9L86=S*"D*"B`@
M("`O*BH*("`@("`J($=E="!A(&-O;'5M;B=S(&9L86=S"B`@("`@*@H@("`@
M("H@4W5P<&]R=',@(FYO=%]N=6QL(BP@(F1E9F%U;'1?=F%L=64B+"`B<')I
M;6%R>5]K97DB+"`B=6YI<75E7VME>2(*("`@("`J(&%N9"`B;75L=&EP;&5?
M:V5Y(BX@(%1H92!D969A=6QT('9A;'5E(&ES('!A<W-E9"!T:')O=6=H"B`@
M("`@*B!R87=U<FQE;F-O9&4H*2!I;B!C87-E('1H97)E(&%R92!S<&%C97,@
M:6X@:70N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`D<F5S;W5R8V4@("!T
M:&4@4&]S=&=R95-13"!R97-U;'0@:61E;G1I9FEE<@H@("`@("H@0'!A<F%M
M(&EN="`D;G5M7V9I96QD("!T:&4@9FEE;&0@;G5M8F5R"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@('1H92!F;&%G<PH@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?<&=&:65L9$9L
M86=S*"1R97-O=7)C92P@)&YU;5]F:65L9"P@)'1A8FQE7VYA;64I"B`@("![
M"B`@("`@("`@)&9I96QD7VYA;64@/2!`<&=?9FEE;&1N86UE*"1R97-O=7)C
M92P@)&YU;5]F:65L9"D["@H@("`@("`@("1R97-U;'0@/2!`<&=?97AE8R@D
M=&AI<RT^8V]N;F5C=&EO;BP@(E-%3$5#5"!F+F%T=&YO=&YU;&PL(&8N871T
M:&%S9&5F"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1E)/32!P
M9U]A='1R:6)U=&4@9BP@<&=?8VQA<W,@=&%B+"!P9U]T>7!E('1Y<`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%=(15)%('1A8BYR96QN86UE
M(#T@='EP+G1Y<&YA;64*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!!3D0@='EP+G1Y<')E;&ED(#T@9BYA='1R96QI9`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@($%.1"!F+F%T=&YA;64@/2`G)&9I96QD7VYA
M;64G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@04Y$('1A8BYR
M96QN86UE(#T@)R1T86)L95]N86UE)R(I.PH@("`@("`@(&EF("A`<&=?;G5M
M<F]W<R@D<F5S=6QT*2`^(#`I('L*("`@("`@("`@("`@)')O=R`]($!P9U]F
M971C:%]R;W<H)')E<W5L="P@,"D["B`@("`@("`@("`@("1F;&%G<R`@/2`H
M)')O=ULP72`]/2`G="<I(#\@)VYO=%]N=6QL("<@.B`G)SL*"B`@("`@("`@
M("`@(&EF("@D<F]W6S%=(#T]("=T)RD@>PH@("`@("`@("`@("`@("`@)')E
M<W5L="`]($!P9U]E>&5C*"1T:&ES+3YC;VYN96-T:6]N+"`B4T5,14-4(&$N
M861S<F,*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1E)/
M32!P9U]A='1R:6)U=&4@9BP@<&=?8VQA<W,@=&%B+"!P9U]T>7!E('1Y<"P@
M<&=?871T<F1E9B!A"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(%=(15)%('1A8BYR96QN86UE(#T@='EP+G1Y<&YA;64@04Y$('1Y<"YT
M>7!R96QI9"`](&8N871T<F5L:60*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@04Y$(&8N871T<F5L:60@/2!A+F%D<F5L:60@04Y$(&8N
M871T;F%M92`]("<D9FEE;&1?;F%M92<*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@04Y$('1A8BYR96QN86UE(#T@)R1T86)L95]N86UE
M)R!!3D0@9BYA='1N=6T@/2!A+F%D;G5M(BD["B`@("`@("`@("`@("`@("`D
M<F]W(#T@0'!G7V9E=&-H7W)O=R@D<F5S=6QT+"`P*3L*("`@("`@("`@("`@
M("`@("1N=6T@/2!P<F5G7W)E<&QA8V4H(B\G*"XJ*2<Z.EQW*R\B+"`B7%PQ
M(BP@)')O=ULP72D["B`@("`@("`@("`@("`@("`D9FQA9W,@+CT@)V1E9F%U
M;'1?)R`N(')A=W5R;&5N8V]D92@D;G5M*2`N("<@)SL*("`@("`@("`@("`@
M?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F;&%G<R`]("<G.PH@
M("`@("`@('T*("`@("`@("`D<F5S=6QT(#T@0'!G7V5X96,H)'1H:7,M/F-O
M;FYE8W1I;VXL(")314Q%0U0@:2YI;F1I<W5N:7%U92P@:2YI;F1I<W!R:6UA
M<GDL(&DN:6YD:V5Y"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M1E)/32!P9U]A='1R:6)U=&4@9BP@<&=?8VQA<W,@=&%B+"!P9U]T>7!E('1Y
M<"P@<&=?:6YD97@@:0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%=(15)%('1A8BYR96QN86UE(#T@='EP+G1Y<&YA;64*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!!3D0@='EP+G1Y<')E;&ED(#T@9BYA='1R
M96QI9`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($%.1"!F+F%T
M=')E;&ED(#T@:2YI;F1R96QI9`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@($%.1"!F+F%T=&YA;64@/2`G)&9I96QD7VYA;64G"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@04Y$('1A8BYR96QN86UE(#T@)R1T
M86)L95]N86UE)R(I.PH@("`@("`@("1C;W5N="`]($!P9U]N=6UR;W=S*"1R
M97-U;'0I.PH*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8V]U;G0@.R`D
M:2LK*2!["B`@("`@("`@("`@("1R;W<@/2!`<&=?9F5T8VA?<F]W*"1R97-U
M;'0L("1I*3L*("`@("`@("`@("`@)&ME>7,@/2!E>'!L;V1E*"<@)RP@)')O
M=ULR72D["@H@("`@("`@("`@("!I9B`H:6Y?87)R87DH)&YU;5]F:65L9"`K
M(#$L("1K97ES*2D@>PH@("`@("`@("`@("`@("`@)&9L86=S("X]("@D<F]W
M6S!=(#T]("=T)R`F)B`D<F]W6S%=(#T]("=F)RD@/R`G=6YI<75E7VME>2`G
M(#H@)R<["B`@("`@("`@("`@("`@("`D9FQA9W,@+CT@*"1R;W=;,5T@/3T@
M)W0G*2`_("=P<FEM87)Y7VME>2`G(#H@)R<["B`@("`@("`@("`@("`@("!I
M9B`H8V]U;G0H)&ME>7,I(#X@,2D*("`@("`@("`@("`@("`@("`@("`D9FQA
M9W,@+CT@)VUU;'1I<&QE7VME>2`G.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@=')I;2@D9FQA9W,I.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&=E=%-P96-I86Q1=65R>2@I"@H@("`@+RHJ"B`@
M("`@*B!/8G1A:6YS('1H92!Q=65R>2!S=')I;F<@;F5E9&5D(&9O<B!L:7-T
M:6YG(&$@9VEV96X@='EP92!O9B!O8FIE8W1S"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D='EP92`@=&AE(&MI;F0@;V8@;V)J96-T<R!Y;W4@=V%N
M="!T;R!R971R:65V90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T
M:&4@4U%,('%U97)Y('-T<FEN9R!O<B!N=6QL(&EF('1H92!D<FEV97(@9&]E
M<VXG=`H@("`@("H@("`@("`@("`@("`@("`@("!S=7!P;W)T('1H92!O8FIE
M8W0@='EP92!R97%U97-T960*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E
M8W1E9`H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F=E=$QI<W1/9B@I"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%-P96-I86Q1=65R>2@D='EP92D*("`@('L*
M("`@("`@("!S=VET8V@@*"1T>7!E*2!["B`@("`@("`@("`@(&-A<V4@)W1A
M8FQE<R<Z"B`@("`@("`@("`@("`@("!R971U<FX@)U-%3$5#5"!C+G)E;&YA
M;64@05,@(DYA;64B)PH@("`@("`@("`@("`@("`@("`@("`@("`N("<@1E)/
M32!P9U]C;&%S<R!C+"!P9U]U<V5R('4G"B`@("`@("`@("`@("`@("`@("`@
M("`@("X@)R!72$5212!C+G)E;&]W;F5R(#T@=2YU<V5S>7-I9"<*("`@("`@
M("`@("`@("`@("`@("`@("`@+B`B($%.1"!C+G)E;&MI;F0@/2`G<B<B"B`@
M("`@("`@("`@("`@("`@("`@("`@("X@)R!!3D0@3D]4($5825-44R<*("`@
M("`@("`@("`@("`@("`@("`@("`@+B`G("A314Q%0U0@,2!&4D]-('!G7W9I
M97=S)PH@("`@("`@("`@("`@("`@("`@("`@("`N("<@(%=(15)%('9I97=N
M86UE(#T@8RYR96QN86UE*2<*("`@("`@("`@("`@("`@("`@("`@("`@+B`B
M($%.1"!C+G)E;&YA;64@(7X@)UXH<&=??'-Q;%\I)R(*("`@("`@("`@("`@
M("`@("`@("`@("`@+B`G(%5.24].)PH@("`@("`@("`@("`@("`@("`@("`@
M("`N("<@4T5,14-4(&,N<F5L;F%M92!!4R`B3F%M92(G"B`@("`@("`@("`@
M("`@("`@("`@("`@("X@)R!&4D]-('!G7V-L87-S(&,G"B`@("`@("`@("`@
M("`@("`@("`@("`@("X@(B!72$5212!C+G)E;&MI;F0@/2`G<B<B"B`@("`@
M("`@("`@("`@("`@("`@("`@("X@)R!!3D0@3D]4($5825-44R<*("`@("`@
M("`@("`@("`@("`@("`@("`@+B`G("A314Q%0U0@,2!&4D]-('!G7W9I97=S
M)PH@("`@("`@("`@("`@("`@("`@("`@("`N("<@(%=(15)%('9I97=N86UE
M(#T@8RYR96QN86UE*2<*("`@("`@("`@("`@("`@("`@("`@("`@+B`G($%.
M1"!.3U0@15A)4U13)PH@("`@("`@("`@("`@("`@("`@("`@("`N("<@*%-%
M3$5#5"`Q($923TT@<&=?=7-E<B<*("`@("`@("`@("`@("`@("`@("`@("`@
M+B`G("!72$5212!U<V5S>7-I9"`](&,N<F5L;W=N97(I)PH@("`@("`@("`@
M("`@("`@("`@("`@("`N("(@04Y$(&,N<F5L;F%M92`A?B`G7G!G7R<B.PH@
M("`@("`@("`@("!C87-E("=S8VAE;6$N=&%B;&5S)SH*("`@("`@("`@("`@
M("`@(')E='5R;B`B4T5,14-4('-C:&5M86YA;64@?'P@)RXG('Q\('1A8FQE
M;F%M92(*("`@("`@("`@("`@("`@("`@("`@("`@+B`G($%3(").86UE(B<*
M("`@("`@("`@("`@("`@("`@("`@("`@+B`G($923TT@<&=?8V%T86QO9RYP
M9U]T86)L97,G"B`@("`@("`@("`@("`@("`@("`@("`@("X@)R!72$5212!S
M8VAE;6%N86UE($Y/5"!)3B<*("`@("`@("`@("`@("`@("`@("`@("`@+B`B
M("@G<&=?8V%T86QO9R<L("=I;F9O<FUA=&EO;E]S8VAE;6$G+"`G<&=?=&]A
M<W0G*2(["B`@("`@("`@("`@(&-A<V4@)W9I97=S)SH*("`@("`@("`@("`@
M("`@("\O(%1A8FQE(&-O;',Z('9I97=N86UE('P@=FEE=V]W;F5R('P@9&5F
M:6YI=&EO;@H@("`@("`@("`@("`@("`@<F5T=7)N("=314Q%0U0@=FEE=VYA
M;64@9G)O;2!P9U]V:65W<R!72$5212!S8VAE;6%N86UE)PH@("`@("`@("`@
M("`@("`@("`@("`@("`N("(@3D]4($E.("@G:6YF;W)M871I;VY?<V-H96UA
M)RP@)W!G7V-A=&%L;V<G*2(["B`@("`@("`@("`@(&-A<V4@)W5S97)S)SH*
M("`@("`@("`@("`@("`@("\O(&-O;',Z('5S96YA;64@?'5S97-Y<VED?'5S
M96-R96%T961B?'5S971R86-E?'5S97-U<&5R?'5S96-A='5P9'QP87-S=V0@
M('QV86QU;G1I;`H@("`@("`@("`@("`@("`@<F5T=7)N("=314Q%0U0@=7-E
M;F%M92!&4D]-('!G7W5S97(G.PH@("`@("`@("`@("!C87-E("=D871A8F%S
M97,G.@H@("`@("`@("`@("`@("`@<F5T=7)N("=314Q%0U0@9&%T;F%M92!&
M4D]-('!G7V1A=&%B87-E)SL*("`@("`@("`@("`@8V%S92`G9G5N8W1I;VYS
M)SH*("`@("`@("`@("`@8V%S92`G<')O8V5D=7)E<R<Z"B`@("`@("`@("`@
M("`@("!R971U<FX@)U-%3$5#5"!P<F]N86UE($923TT@<&=?<')O8R!72$52
M12!P<F]O=VYE<B`\/B`Q)SL*("`@("`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*("`@('T*"B`@("`O
M+R!]?7T*"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H
M.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J($5N9#H*("HO"@H_/@H`````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O1$(O<W%L:71E+G!H<```````````
M````````````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-S(Q-#4`,3`U,34T
M,S,W,S<`,#(Q,3$W`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"@HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O
M<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%1H
M92!014%2($1"(&1R:79E<B!F;W(@4$A0)W,@<W%L:71E(&5X=&5N<VEO;@H@
M*B!F;W(@:6YT97)A8W1I;F<@=VET:"!344QI=&4@9&%T86)A<V5S"B`J"B`J
M(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U
M<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0
M(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R
M96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U
M;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J
M('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I
M;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$
M871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!5<G,@
M1V5H<FEG(#QU<G-`8VER8VQE+F-H/@H@*B!`875T:&]R("`@("!-:6MA(%1U
M=7!O;&$@/'1U=7!O;&%`87!P96QS:6EN:2YN970^"B`J($!A=71H;W(@("`@
M($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER
M:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N
M<V4@,RXP(#,N,`H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@<W%L:71E+G!H
M<"QV(#$N,3`Y(#(P,#4O,#,O,3`@,#$Z,C(Z-#@@9&%N:65L8R!%>'`@)`H@
M*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*
M("HO"@HO*BH*("H@3V)T86EN('1H92!$0E]C;VUM;VX@8VQA<W,@<V\@:70@
M8V%N(&)E(&5X=&5N9&5D(&9R;VT*("HO"G)E<75I<F5?;VYC92`G1$(O8V]M
M;6]N+G!H<"<["@HO*BH*("H@5&AE(&UE=&AO9',@4$5!4B!$0B!U<V5S('1O
M(&EN=&5R86-T('=I=&@@4$A0)W,@<W%L:71E(&5X=&5N<VEO;@H@*B!F;W(@
M:6YT97)A8W1I;F<@=VET:"!344QI=&4@9&%T86)A<V5S"B`J"B`J(%1H97-E
M(&UE=&AO9',@;W9E<FQO860@=&AE(&]N97,@9&5C;&%R960@:6X@1$)?8V]M
M;6]N+@H@*@H@*B!.3U1)0T4Z("!4:&ES(&1R:79E<B!N965D<R!02%`G<R!T
M<F%C:U]E<G)O<G,@:6YI('-E='1I;F<@=&\@8F4@;VXN"B`J($ET(&ES(&%U
M=&]M871I8V%L;'D@='5R;F5D(&]N('=H96X@8V]N;F5C=&EN9R!T;R!T:&4@
M9&%T86)A<V4N"B`J($UA:V4@<W5R92!Y;W5R('-C<FEP=',@9&]N)W0@='5R
M;B!I="!O9F8N"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K
M86=E("`@($1""B`J($!A=71H;W(@("`@(%5R<R!'96AR:6<@/'5R<T!C:7)C
M;&4N8V@^"B`J($!A=71H;W(@("`@($UI:V$@5'5U<&]L82`\='5U<&]L84!A
M<'!E;'-I:6YI+FYE=#X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O
M<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@
M5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`@,RXP"B`J($!V
M97)S:6]N("`@(%)E;&5A<V4Z(#$N-RXV"B`J($!L:6YK("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*8VQA<W,@1$)?<W%L:71E
M(&5X=&5N9',@1$)?8V]M;6]N"GL*("`@("\O('M[>R!P<F]P97)T:65S"@H@
M("`@+RHJ"B`@("`@*B!4:&4@1$(@9')I=F5R('1Y<&4@*&UY<W%L+"!O8VDX
M+"!O9&)C+"!E=&,N*0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1P:'!T>7!E(#T@)W-Q;&ET92<["@H@("`@+RHJ"B`@("`@*B!4:&4@
M9&%T86)A<V4@<WEN=&%X('9A<FEA;G0@=&\@8F4@=7-E9"`H9&(R+"!A8V-E
M<W,L(&5T8RXI+"!I9B!A;GD*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D9&)S>6YT87@@/2`G<W%L:71E)SL*"B`@("`O*BH*("`@("`J
M(%1H92!C87!A8FEL:71I97,@;V8@=&AI<R!$0B!I;7!L96UE;G1A=&EO;@H@
M("`@("H*("`@("`J(%1H92`G;F5W7VQI;FLG(&5L96UE;G0@8V]N=&%I;G,@
M=&AE(%!(4"!V97)S:6]N('1H870@9FER<W0@<')O=FED960*("`@("`J(&YE
M=U]L:6YK('-U<'!O<G0@9F]R('1H:7,@1$)-4RX@($-O;G1A:6YS(&9A;'-E
M(&EF(&ET)W,@=6YS=7!P;W)T960N"B`@("`@*@H@("`@("H@365A;FEN9R!O
M9B!T:&4@)VQI;6ET)R!E;&5M96YT.@H@("`@("H@("`K("=E;75L871E)R`]
M(&5M=6QA=&4@=VET:"!F971C:"!R;W<@8GD@;G5M8F5R"B`@("`@*B`@("L@
M)V%L=&5R)R`@(#T@86QT97(@=&AE('%U97)Y"B`@("`@*B`@("L@9F%L<V4@
M("`@(#T@<VMI<"!R;W=S"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)&9E871U<F5S(#T@87)R87DH"B`@("`@("`@)VQI;6ET
M)R`@("`@("`@(#T^("=A;'1E<B<L"B`@("`@("`@)VYE=U]L:6YK)R`@("`@
M(#T^(&9A;'-E+`H@("`@("`@("=N=6UR;W=S)R`@("`@("`]/B!T<G5E+`H@
M("`@("`@("=P8V]N;F5C="<@("`@("`]/B!T<G5E+`H@("`@("`@("=P<F5P
M87)E)R`@("`@("`]/B!F86QS92P*("`@("`@("`G<W-L)R`@("`@("`@("`@
M/3X@9F%L<V4L"B`@("`@("`@)W1R86YS86-T:6]N<R<@(#T^(&9A;'-E+`H@
M("`@*3L*"B`@("`O*BH*("`@("`J($$@;6%P<&EN9R!O9B!N871I=F4@97)R
M;W(@8V]D97,@=&\@1$(@97)R;W(@8V]D97,*("`@("`J"B`@("`@*B![0&EN
M=&5R;F%L("!%<G)O<B!C;V1E<R!A8V-O<F1I;F<@=&\@<W%L:71E7V5X96,N
M("!3964@=&AE(&]N;&EN90H@("`@("H@;6%N=6%L(&%T(&AT='`Z+R]S<6QI
M=&4N;W)G+V-?:6YT97)F86-E+FAT;6P@9F]R(&EN9F\N"B`@("`@*B!4:&ES
M(&5R<F]R(&AA;F1L:6YG(&)A<V5D(&]N('-Q;&ET95]E>&5C(&ES(&YO="!Y
M970@:6UP;&5M96YT960N?7T*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D97)R;W)C;V1E7VUA<"`](&%R<F%Y*`H@("`@*3L*
M"B`@("`O*BH*("`@("`J(%1H92!R87<@9&%T86)A<V4@8V]N;F5C=&EO;B!C
M<F5A=&5D(&)Y(%!(4`H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@
M("!V87(@)&-O;FYE8W1I;VX["@H@("`@+RHJ"B`@("`@*B!4:&4@1%-.(&EN
M9F]R;6%T:6]N(&9O<B!C;VYN96-T:6YG('1O(&$@9&%T86)A<V4*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1D<VX@/2!A<G)A>2@I.PH*
M"B`@("`O*BH*("`@("`J(%-13&ET92!D871A('1Y<&5S"B`@("`@*@H@("`@
M("H@0&QI;FL@:'1T<#HO+W=W=RYS<6QI=&4N;W)G+V1A=&%T>7!E<RYH=&UL
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&ME
M>7=O<F1S(#T@87)R87D@*`H@("`@("`@("="3$]")R`@("`@(#T^("<G+`H@
M("`@("`@("="3T],14%.)R`@(#T^("<G+`H@("`@("`@("=#2$%204-415(G
M(#T^("<G+`H@("`@("`@("=#3$]")R`@("`@(#T^("<G+`H@("`@("`@("=&
M3$]!5"<@("`@(#T^("<G+`H@("`@("`@("=)3E1%1T52)R`@(#T^("<G+`H@
M("`@("`@("=+15DG("`@("`@(#T^("<G+`H@("`@("`@("=.051)3TY!3"<@
M(#T^("<G+`H@("`@("`@("=.54U%4DE#)R`@(#T^("<G+`H@("`@("`@("=.
M5D%20TA!4B<@(#T^("<G+`H@("`@("`@("=04DE-05)9)R`@(#T^("<G+`H@
M("`@("`@("=415A4)R`@("`@(#T^("<G+`H@("`@("`@("=424U%4U1!35`G
M(#T^("<G+`H@("`@("`@("=53DE1544G("`@(#T^("<G+`H@("`@("`@("=6
M05)#2$%2)R`@(#T^("<G+`H@("`@("`@("=605)924Y')R`@(#T^("<G+`H@
M("`@*3L*"B`@("`O*BH*("`@("`J(%1H92!M;W-T(')E8V5N="!E<G)O<B!M
M97-S86=E(&9R;VT@)'!H<%]E<G)O<FUS9PH@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]L87-T
M97)R;W(@/2`G)SL*"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]N<W1R=6-T
M;W(*"B`@("`O*BH*("`@("`J(%1H:7,@8V]N<W1R=6-T;W(@8V%L;',@/&MB
M9#XD=&AI<RT^1$)?8V]M;6]N*"D\+VMB9#X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@1$)?<W%L:71E*"D*("`@
M('L*("`@("`@("`D=&AI<RT^1$)?8V]M;6]N*"D["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@*B!#;VYN
M96-T('1O('1H92!D871A8F%S92!S97)V97(L(&QO9R!I;B!A;F0@;W!E;B!T
M:&4@9&%T86)A<V4*("`@("`J"B`@("`@*B!$;VXG="!C86QL('1H:7,@;65T
M:&]D(&1I<F5C=&QY+B`@57-E($1".CIC;VYN96-T*"D@:6YS=&5A9"X*("`@
M("`J"B`@("`@*B!014%2($1")W,@<W%L:71E(&1R:79E<B!S=7!P;W)T<R!T
M:&4@9F]L;&]W:6YG(&5X=')A($133B!O<'1I;VYS.@H@("`@("H@("`K(&UO
M9&4@(%1H92!P97)M:7-S:6]N<R!F;W(@=&AE(&1A=&%B87-E(&9I;&4L(&EN
M(&9O=7(@9&EG:70*("`@("`J("`@("`@("`@("`@8VAM;V0@;V-T86P@9F]R
M;6%T("AE9R`B,#8P,"(I+@H@("`@("H*("`@("`J($5X86UP;&4@;V8@8V]N
M;F5C=&EN9R!T;R!A(&1A=&%B87-E(&EN(')E860M;VYL>2!M;V1E.@H@("`@
M("H@/&-O9&4^"B`@("`@*B!R97%U:7)E7V]N8V4@)T1"+G!H<"<["B`@("`@
M*B`*("`@("`J("1D<VX@/2`G<W%L:71E.B\O+W!A=&@O86YD+VYA;64O;V8O
M9&(O9FEL93]M;V1E/3`T,#`G.PH@("`@("H@)&]P=&EO;G,@/2!A<G)A>2@*
M("`@("`J("`@("`G<&]R=&%B:6QI='DG(#T^($1"7U!/4E1!0DE,25197T%,
M3"P*("`@("`J("D["B`@("`@*B`*("`@("`J("1D8B`])B!$0CHZ8V]N;F5C
M="@D9'-N+"`D;W!T:6]N<RD["B`@("`@*B!I9B`H4$5!4CHZ:7-%<G)O<B@D
M9&(I*2!["B`@("`@*B`@("`@9&EE*"1D8BT^9V5T365S<V%G92@I*3L*("`@
M("`J('T*("`@("`J(#PO8V]D93X*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)&1S;B`@("`@("`@('1H92!D871A('-O=7)C92!N86UE"B`@("`@*B!`
M<&%R86T@8F]O;"`@)'!E<G-I<W1E;G0@('-H;W5L9"!T:&4@8V]N;F5C=&EO
M;B!B92!P97)S:7-T96YT/PH@("`@("H*("`@("`J($!R971U<FX@:6YT("!$
M0E]/2R!O;B!S=6-C97-S+B!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYN96-T*"1D<VXL("1P97)S:7-T
M96YT(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"%014%2.CIL;V%D17AT
M96YS:6]N*"=S<6QI=&4G*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H1$)?15)23U)?15A414Y324].7TY/5%]&3U5.1"D["B`@
M("`@("`@?0H*("`@("`@("`D=&AI<RT^9'-N(#T@)&1S;CL*("`@("`@("!I
M9B`H)&1S;ELG9&)S>6YT87@G72D@>PH@("`@("`@("`@("`D=&AI<RT^9&)S
M>6YT87@@/2`D9'-N6R=D8G-Y;G1A>"==.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"1D<VY;)V1A=&%B87-E)UTI('L*("`@("`@("`@("`@:68@*"%F:6QE
M7V5X:7-T<R@D9'-N6R=D871A8F%S92==*2D@>PH@("`@("`@("`@("`@("`@
M:68@*"%T;W5C:"@D9'-N6R=D871A8F%S92==*2D@>PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<W%L:71E4F%I<V5%<G)O<BA$0E]%4E)/
M4E].3U1?1D]53D0I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D9'-N6R=M;V1E)UTI('Q\"B`@("`@("`@("`@("`@
M("`@("`@(6ES7VYU;65R:6,H)&1S;ELG;6]D92==*2D*("`@("`@("`@("`@
M("`@('L*("`@("`@("`@("`@("`@("`@("`D;6]D92`](#`V-#0["B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1M;V1E
M(#T@;V-T9&5C*"1D<VY;)VUO9&4G72D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!I9B`H(6-H;6]D*"1D<VY;)V1A=&%B87-E)UTL("1M
M;V1E*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<W%L
M:71E4F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?1D]53D0I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D9'-N
M6R=D871A8F%S92==*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<W%L:71E4F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?1D]53D0I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("@A:7-?9FEL92@D9'-N6R=D871A8F%S92==*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YS<6QI=&5286ES945R<F]R*$1"7T524D]27TE.
M5D%,240I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A:7-?<F5A
M9&%B;&4H)&1S;ELG9&%T86)A<V4G72DI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<W%L:71E4F%I<V5%<G)O<BA$0E]%4E)/4E]!0T-%4U-?
M5DE/3$%424].*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<W%L:71E4F%I<V5%<G)O<BA$0E]%
M4E)/4E]!0T-%4U-?5DE/3$%424].*3L*("`@("`@("!]"@H@("`@("`@("1C
M;VYN96-T7V9U;F-T:6]N(#T@)'!E<G-I<W1E;G0@/R`G<W%L:71E7W!O<&5N
M)R`Z("=S<6QI=&5?;W!E;B<["@H@("`@("`@("\O('1R86-K7V5R<F]R<R!M
M=7-T(')E;6%I;B!O;B!F;W(@<VEM<&QE475E<GDH*0H@("`@("`@(&EN:5]S
M970H)W1R86-K7V5R<F]R<R<L(#$I.PH@("`@("`@("1P:'!?97)R;W)M<V<@
M/2`G)SL*"B`@("`@("`@:68@*"$D=&AI<RT^8V]N;F5C=&EO;B`]($`D8V]N
M;F5C=%]F=6YC=&EO;B@D9'-N6R=D871A8F%S92==*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?3D]$0E-%3$5#
M5$5$+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;G5L
M;"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P:'!?97)R;W)M<V<I.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9&ES8V]N
M;F5C="@I"@H@("`@+RHJ"B`@("`@*B!$:7-C;VYN96-T<R!F<F]M('1H92!D
M871A8F%S92!S97)V97(*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@(%12
M544@;VX@<W5C8V5S<RP@1D%,4T4@;VX@9F%I;'5R90H@("`@("HO"B`@("!F
M=6YC=&EO;B!D:7-C;VYN96-T*"D*("`@('L*("`@("`@("`D<F5T(#T@0'-Q
M;&ET95]C;&]S92@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@)'1H:7,M
M/F-O;FYE8W1I;VX@/2!N=6QL.PH@("`@("`@(')E='5R;B`D<F5T.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[('-I;7!L95%U97)Y*"D*"B`@("`O
M*BH*("`@("`J(%-E;F1S(&$@<75E<GD@=&\@=&AE(&1A=&%B87-E('-E<G9E
M<@H@("`@("H*("`@("`J($Y/5$E#13H@(%1H:7,@;65T:&]D(&YE961S(%!(
M4"=S('1R86-K7V5R<F]R<R!I;FD@<V5T=&EN9R!T;R!B92!O;BX*("`@("`J
M($ET(&ES(&%U=&]M871I8V%L;'D@='5R;F5D(&]N('=H96X@8V]N;F5C=&EN
M9R!T;R!T:&4@9&%T86)A<V4N"B`@("`@*B!-86ME('-U<F4@>6]U<B!S8W)I
M<'1S(&1O;B=T('1U<FX@:70@;V9F+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@('1H92!344P@<75E<GD@<W1R:6YG"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@*R!A(%!(4"!R97-U;'0@<F5S<F]U8V4@9F]R('-U8V-E
M<W-F=6P@4T5,14-4('%U97)I97,*("`@("`J("`@("`@("`@("`@("`@("L@
M=&AE($1"7T]+(&-O;G-T86YT(&9O<B!O=&AE<B!S=6-C97-S9G5L('%U97)I
M97,*("`@("`J("`@("`@("`@("`@("`@("L@82!$0E]%<G)O<B!O8FIE8W0@
M;VX@9F%I;'5R90H@("`@("HO"B`@("!F=6YC=&EO;B!S:6UP;&51=65R>2@D
M<75E<GDI"B`@("!["B`@("`@("`@)&ES;6%N:7`@/2!$0CHZ:7--86YI<"@D
M<75E<GDI.PH@("`@("`@("1T:&ES+3YL87-T7W%U97)Y(#T@)'%U97)Y.PH@
M("`@("`@("1Q=65R>2`]("1T:&ES+3YM;V1I9GE1=65R>2@D<75E<GDI.PH*
M("`@("`@("`D<&AP7V5R<F]R;7-G(#T@)R<["@H@("`@("`@("1R97-U;'0@
M/2!`<W%L:71E7W%U97)Y*"1Q=65R>2P@)'1H:7,M/F-O;FYE8W1I;VXI.PH@
M("`@("`@("1T:&ES+3Y?;&%S=&5R<F]R(#T@)'!H<%]E<G)O<FUS9R`_("1P
M:'!?97)R;W)M<V<@.B`G)SL*"B`@("`@("`@)'1H:7,M/G)E<W5L="`]("1R
M97-U;'0["B`@("`@("`@:68@*"$D=&AI<RT^<F5S=6QT*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<W%L:71E4F%I<V5%<G)O<BAN=6QL*3L*("`@
M("`@("!]"@H@("`@("`@("\O('-Q;&ET95]Q=65R>2@I('-E96US('1O(&%L
M;'=A>7,@<F5T=7)N(&$@<F5S;W5R8V4*("`@("`@("`O+R!S;R!C86YT('5S
M92!T:&%T+B!5<VEN9R`D:7-M86YI<"!I;G-T96%D"B`@("`@("`@:68@*"$D
M:7-M86YI<"D@>PH@("`@("`@("`@("`D;G5M4F]W<R`]("1T:&ES+3YN=6U2
M;W=S*"1R97-U;'0I.PH@("`@("`@("`@("!I9B`H:7-?;V)J96-T*"1N=6U2
M;W=S*2D@>PH@("`@("`@("`@("`@("`@+R\@=V4G=F4@9V]T(%!%05)?17)R
M;W(*("`@("`@("`@("`@("`@(')E='5R;B`D;G5M4F]W<SL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&YE>'1297-U;'0H*0H*("`@("\J*@H@("`@("H@36]V92!T:&4@:6YT
M97)N86P@<W%L:71E(')E<W5L="!P;VEN=&5R('1O('1H92!N97AT(&%V86EL
M86)L92!R97-U;'0*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E
M<W5L="`@=&AE('9A;&ED('-Q;&ET92!R97-U;'0@<F5S;W5R8V4*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VP@('1R=64@:68@82!R97-U;'0@:7,@879A
M:6QA8FQE(&]T:&5R=VES92!R971U<FX@9F%L<V4*("`@("`J+PH@("`@9G5N
M8W1I;VX@;F5X=%)E<W5L="@D<F5S=6QT*0H@("`@>PH@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F971C:$EN
M=&\H*0H*("`@("\J*@H@("`@("H@4&QA8V5S(&$@<F]W(&9R;VT@=&AE(')E
M<W5L="!S970@:6YT;R!T:&4@9VEV96X@87)R87D*("`@("`J"B`@("`@*B!&
M;W)M871I;F<@;V8@=&AE(&%R<F%Y(&%N9"!T:&4@9&%T82!T:&5R96EN(&%R
M92!C;VYF:6=U<F%B;&4N"B`@("`@*B!3964@1$)?<F5S=6QT.CIF971C:$EN
M=&\H*2!F;W(@;6]R92!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!4:&ES
M(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@
M57-E"B`@("`@*B!$0E]R97-U;'0Z.F9E=&-H26YT;R@I(&EN<W1E860N("!)
M="!C86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S
M92!$0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@("`@=&AE('%U97)Y(')E<W5L
M="!R97-O=7)C90H@("`@("H@0'!A<F%M(&%R<F%Y("`@("1A<G(@("`@("`@
M=&AE(')E9F5R96YC960@87)R87D@=&\@<'5T('1H92!D871A(&EN"B`@("`@
M*B!`<&%R86T@:6YT("`@("`@)&9E=&-H;6]D92!H;W<@=&AE(')E<W5L=&EN
M9R!A<G)A>2!S:&]U;&0@8F4@:6YD97AE9`H@("`@("H@0'!A<F%M(&EN="`@
M("`@("1R;W=N=6T@("`@=&AE(')O=R!N=6UB97(@=&\@9F5T8V@@*#`@/2!F
M:7)S="!R;W<I"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1$)?3TL@
M;VX@<W5C8V5S<RP@3E5,3"!W:&5N('1H92!E;F0@;V8@82!R97-U;'0@<V5T
M(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@<F5A8VAE9"!O<B!O;B!F86EL
M=7)E"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&9E=&-H26YT;R@D<F5S=6QT+"`F)&%R
M<BP@)&9E=&-H;6]D92P@)')O=VYU;2`](&YU;&PI"B`@("!["B`@("`@("`@
M:68@*"1R;W=N=6T@(3T](&YU;&PI('L*("`@("`@("`@("`@:68@*"%`<W%L
M:71E7W-E96LH)'1H:7,M/G)E<W5L="P@)')O=VYU;2DI('L*("`@("`@("`@
M("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(&EF("@D9F5T8VAM;V1E("8@1$)?1D540TA-3T1%7T%34T]#*2![
M"B`@("`@("`@("`@("1A<G(@/2!`<W%L:71E7V9E=&-H7V%R<F%Y*"1R97-U
M;'0L(%-13$E415]!4U-/0RD["B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T
M:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TQ/5T520T%3
M12`F)B`D87)R*2!["B`@("`@("`@("`@("`@("`D87)R(#T@87)R87E?8VAA
M;F=E7VME>5]C87-E*"1A<G(L($-!4T5?3$]715(I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&%R<B`]($!S<6QI=&5?
M9F5T8VA?87)R87DH)')E<W5L="P@4U%,251%7TY532D["B`@("`@("`@?0H@
M("`@("`@(&EF("@A)&%R<BD@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*
M("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I
M;&ET>2==("8@1$)?4$]25$%"24Q)5%E?4E1224TI('L*("`@("`@("`@("`@
M+RH*("`@("`@("`@("`@("H@179E;B!T:&]U9V@@=&AI<R!$0DU3(&%L<F5A
M9'D@=')I;7,@;W5T<'5T+"!W92!D;R!T:&ES(&)E8V%U<V4*("`@("`@("`@
M("`@("H@82!F:65L9"!M:6=H="!H879E(&EN=&5N=&EO;F%L('=H:71E<W!A
M8V4@870@=&AE(&5N9"!T:&%T"B`@("`@("`@("`@("`J(&=E=',@<F5M;W9E
M9"!B>2!$0E]03U)404))3$E465]25%))32!U;F1E<B!A;F]T:&5R(&1R:79E
M<BX*("`@("`@("`@("`@("HO"B`@("`@("`@("`@("1T:&ES+3Y?<G1R:6U!
M<G)A>59A;'5E<R@D87)R*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES
M+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3E5,
M3%]43U]%35!462D@>PH@("`@("`@("`@("`D=&AI<RT^7V-O;G9E<G1.=6QL
M07)R87E686QU97-4;T5M<'1Y*"1A<G(I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9G)E
M95)E<W5L="@I"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S('1H92!R97-U;'0@
M<V5T(&%N9"!F<F5E<R!T:&4@;65M;W)Y(&]C8W5P:65D(&)Y('1H92!R97-U
M;'0@<V5T"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT
M('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT
M.CIF<F5E*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T
M96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E
M(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L
M="`@4$A0)W,@<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L("!44E5%(&]N('-U8V-E<W,L($9!3%-%(&EF("1R97-U
M;'0@:7,@:6YV86QI9`H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIF
M<F5E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9G)E95)E<W5L="@F)')E<W5L
M="D*("`@('L*("`@("`@("`O+R!86%@@3F\@;F%T:79E(&9R964_"B`@("`@
M("`@:68@*"%I<U]R97-O=7)C92@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@("1R97-U;'0@/2!N=6QL
M.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&YU;4-O;',H*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M
M8F5R(&]F(&-O;'5M;G,@:6X@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@
M5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L
M>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIN=6U#;VQS*"D@:6YS=&5A9"X@
M($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A
M=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S
M=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N
M=6UB97(@;V8@8V]L=6UN<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.FYU;4-O;',H*0H@
M("`@("HO"B`@("!F=6YC=&EO;B!N=6U#;VQS*"1R97-U;'0I"B`@("!["B`@
M("`@("`@)&-O;',@/2!`<W%L:71E7VYU;5]F:65L9',H)')E<W5L="D["B`@
M("`@("`@:68@*"$D8V]L<RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G-Q;&ET95)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1C;VQS.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YU;5)O=W,H
M*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M8F5R(&]F(')O=W,@:6X@
M82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T
M(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?
M<F5S=6QT.CIN=6U2;W=S*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA
M<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A
M('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R
M8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@<F]W<RX@($$@
M1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E
M92!$0E]R97-U;'0Z.FYU;5)O=W,H*0H@("`@("HO"B`@("!F=6YC=&EO;B!N
M=6U2;W=S*"1R97-U;'0I"B`@("!["B`@("`@("`@)')O=W,@/2!`<W%L:71E
M7VYU;5]R;W=S*"1R97-U;'0I.PH@("`@("`@(&EF("@D<F]W<R`]/3T@;G5L
M;"D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-Q;&ET95)A:7-E17)R
M;W(H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R;W=S.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&%F9F5C=&5D*"D*"B`@("`O*BH*("`@
M("`J($1E=&5R;6EN97,@=&AE(&YU;6)E<B!O9B!R;W=S(&%F9F5C=&5D(&)Y
M(&$@9&%T82!M86YI=7!L871I;VX@<75E<GD*("`@("`J"B`@("`@*B`P(&ES
M(')E='5R;F5D(&9O<B!Q=65R:65S('1H870@9&]N)W0@;6%N:7!U;&%T92!D
M871A+@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F
M(')O=W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!A9F9E8W1E9%)O=W,H*0H@("`@>PH@("`@("`@(')E
M='5R;B!`<W%L:71E7V-H86YG97,H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1R;W!397%U96YC92@I"@H@("`@
M+RHJ"B`@("`@*B!$96QE=&5S(&$@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1S97%?;F%M92`@;F%M92!O9B!T:&4@<V5Q=65N8V4@
M=&\@8F4@9&5L971E9`H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/
M2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ9')O<%-E<75E;F-E*"DL
M($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@*B`@("`@($1"
M7W-Q;&ET93HZ;F5X=$E$*"DL($1"7W-Q;&ET93HZ8W)E871E4V5Q=65N8V4H
M*0H@("`@("HO"B`@("!F=6YC=&EO;B!D<F]P4V5Q=65N8V4H)'-E<5]N86UE
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<75E<GDH)T123U`@5$%"
M3$4@)R`N("1T:&ES+3YG971397%U96YC94YA;64H)'-E<5]N86UE*2D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@;F5W('-E<75E;F-E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5Q7VYA;64@(&YA;64@;V8@
M=&AE(&YE=R!S97%U96YC90H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$
M0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ8W)E871E4V5Q=65N
M8V4H*2P@1$)?8V]M;6]N.CIG971397%U96YC94YA;64H*2P*("`@("`J("`@
M("`@1$)?<W%L:71E.CIN97AT240H*2P@1$)?<W%L:71E.CID<F]P4V5Q=65N
M8V4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A=&5397%U96YC92@D<V5Q
M7VYA;64I"B`@("!["B`@("`@("`@)'-E<6YA;64@/2`D=&AI<RT^9V5T4V5Q
M=65N8V5.86UE*"1S97%?;F%M92D["B`@("`@("`@)'%U97)Y("`@/2`G0U)%
M051%(%1!0DQ%("<@+B`D<V5Q;F%M92`N"B`@("`@("`@("`@("`@("`@("`G
M("AI9"!)3E1%1T52(%5.4TE'3D5$(%!224U!4ED@2T59*2`G.PH@("`@("`@
M("1R97-U;'0@(#T@)'1H:7,M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@:68@
M*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@(')E='5R;B@D
M<F5S=6QT*3L*("`@("`@("!]"B`@("`@("`@)'%U97)Y("`@/2`B0U)%051%
M(%1224='15(@)'MS97%N86UE?5]C;&5A;G5P($%&5$52($E.4T525"!/3B`D
M<V5Q;F%M90H@("`@("`@("`@("`@("`@("`@($)%1TE."B`@("`@("`@("`@
M("`@("`@("`@("`@($1%3$5412!&4D]-("1S97%N86UE(%=(15)%(&ED/$Q!
M4U1?24Y315)47U)/5TE$*"D["B`@("`@("`@("`@("`@("`@("`@14Y$("([
M"B`@("`@("`@)')E<W5L="`@/2`D=&AI<RT^<75E<GDH)'%U97)Y*3L*("`@
M("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@
M<F5T=7)N*"1R97-U;'0I.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!N97AT260H*0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@;F5X="!F<F5E(&ED(&EN(&$@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E;F-E
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;VYD96UA;F0@('=H96X@=')U92P@
M=&AE('-E<65N8V4@:7,@875T;VUA=&EC86QL>0H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8W)E871E9"!I9B!I="!D;V5S(&YO="!E>&ES
M=`H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;F5X="!I9"!N=6UB
M97(@:6X@=&AE('-E<75E;F-E+@H@("`@("H@("`@("`@("`@("`@("!!($1"
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@
M1$)?8V]M;6]N.CIN97AT240H*2P@1$)?8V]M;6]N.CIG971397%U96YC94YA
M;64H*2P*("`@("`J("`@("`@1$)?<W%L:71E.CIC<F5A=&5397%U96YC92@I
M+"!$0E]S<6QI=&4Z.F1R;W!397%U96YC92@I"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&YE>'1)9"@D<V5Q7VYA;64L("1O;F1E;6%N9"`]('1R=64I"B`@("![
M"B`@("`@("`@)'-E<6YA;64@/2`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S
M97%?;F%M92D["@H@("`@("`@(&1O('L*("`@("`@("`@("`@)')E<&5A="`]
M(#`["B`@("`@("`@("`@("1T:&ES+3YP=7-H17)R;W)(86YD;&EN9RA014%2
M7T524D]27U)%5%523BD["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M<75E<GDH(DE.4T525"!)3E1/("1S97%N86UE("AI9"D@5D%,5453("A.54Q,
M*2(I.PH@("`@("`@("`@("`D=&AI<RT^<&]P17)R;W)(86YD;&EN9R@I.PH@
M("`@("`@("`@("!I9B`H)')E<W5L="`]/3T@1$)?3TLI('L*("`@("`@("`@
M("`@("`@("1I9"`]($!S<6QI=&5?;&%S=%]I;G-E<G1?<F]W:60H)'1H:7,M
M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`@("`@:68@*"1I9"`A/2`P*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1I9#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?2!E;'-E:68@*"1O;F1E;6%N9"`F)B!$0CHZ
M:7-%<G)O<B@D<F5S=6QT*2`F)@H@("`@("`@("`@("`@("`@("`@("`@)')E
M<W5L="T^9V5T0V]D92@I(#T]($1"7T524D]27TY/4U5#2%1!0DQ%*0H@("`@
M("`@("`@("!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F-R
M96%T95-E<75E;F-E*"1S97%?;F%M92D["B`@("`@("`@("`@("`@("!I9B`H
M1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E<W5L="D["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1R97!E870@/2`Q
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!W
M:&EL92`H)')E<&5A="D["@H@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@D<F5S=6QT*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G
M971$8D9I;&53=&%T<R@I"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&9I;&4@
M<W1A=',@9F]R('1H92!C=7)R96YT(&1A=&%B87-E"B`@("`@*@H@("`@("H@
M4&]S<VEB;&4@87)G=6UE;G1S(&%R92!D978L(&EN;RP@;6]D92P@;FQI;FLL
M('5I9"P@9VED+"!R9&5V+"!S:7IE+`H@("`@("H@871I;64L(&UT:6UE+"!C
M=&EM92P@8FQK<VEZ92P@8FQO8VMS(&]R(&$@;G5M97)I8R!K97D@8F5T=V5E
M;@H@("`@("H@,"!A;F0@,3(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D87)G("!T:&4@87)R87D@:V5Y(&9O<B!S=&%T<R@I"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@86X@87)R87D@;VX@86X@=6YS<&5C:69I960@
M:V5Y+"!I;G1E9V5R(&]N(&$@<&%S<V5D"B`@("`@*B`@("`@("`@("`@("`@
M("!A<F<@86YD(&9A;'-E(&%T(&$@<W1A=',@97)R;W(*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T1&)&:6QE4W1A=',H)&%R9R`]("<G*0H@("`@>PH@("`@
M("`@("1S=&%T<R`]('-T870H)'1H:7,M/F1S;ELG9&%T86)A<V4G72D["B`@
M("`@("`@:68@*"1S=&%T<R`]/2!F86QS92D@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@(&EF("AI<U]A<G)A>2@D<W1A
M=',I*2!["B`@("`@("`@("`@(&EF("AI<U]N=6UE<FEC*"1A<F<I*2!["B`@
M("`@("`@("`@("`@("!I9B`H*"AI;G0I)&%R9R`\/2`Q,BD@)B`H*&EN="DD
M87)G(#X](#`I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@<F5T=7)N("1S
M=&%T<ULD87)G(%T["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&%R
M<F%Y7VME>5]E>&ES=',H=')I;2@D87)G*2P@)'-T871S*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1S=&%T<ULD87)G(%T["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1S=&%T<SL*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!E<V-A<&53:6UP;&4H*0H*("`@("\J*@H@("`@
M("H@17-C87!E<R!A('-T<FEN9R!A8V-O<F1I;F<@=&\@=&AE(&-U<G)E;G0@
M1$)-4R=S('-T86YD87)D<PH@("`@("H*("`@("`J($EN(%-13&ET92P@=&AI
M<R!M86ME<R!T:&EN9W,@<V%F92!F;W(@:6YS97)T<R]U<&1A=&5S+"!B=70@
M;6%Y"B`@("`@*B!C875S92!P<F]B;&5M<R!W:&5N('!E<F9O<FUI;F<@=&5X
M="!C;VUP87)I<V]N<R!A9V%I;G-T(&-O;'5M;G,*("`@("`J(&-O;G1A:6YI
M;F<@8FEN87)Y(&1A=&$N(%-E92!T:&4*("`@("`J('M`;&EN:R!H='1P.B\O
M<&AP+FYE="]S<6QI=&5?97-C87!E7W-T<FEN9R!02%`@;6%N=6%L?2!F;W(@
M;6]R92!I;F9O+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T<B`@
M=&AE('-T<FEN9R!T;R!B92!E<V-A<&5D"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@('1H92!E<V-A<&5D('-T<FEN9PH@("`@("H*("`@("`J($!S
M:6YC92!-971H;V0@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XV+C$*("`@
M("`J($!S964@1$)?8V]M;6]N.CIE<V-A<&53:6UP;&4H*0H@("`@("HO"B`@
M("!F=6YC=&EO;B!E<V-A<&53:6UP;&4H)'-T<BD*("`@('L*("`@("`@("!R
M971U<FX@0'-Q;&ET95]E<V-A<&5?<W1R:6YG*"1S='(I.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&UO9&EF>4QI;6ET475E<GDH*0H*("`@("\J
M*@H@("`@("H@061D<R!,24U)5"!C;&%U<V5S('1O(&$@<75E<GD@<W1R:6YG
M(&%C8V]R9&EN9R!T;R!C=7)R96YT($1"35,@<W1A;F1A<F1S"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<75E<GD@("!T:&4@<75E<GD@=&\@;6]D
M:69Y"B`@("`@*B!`<&%R86T@:6YT("`@("1F<F]M("`@('1H92!R;W<@=&\@
M<W1A<G0@=&\@9F5T8VAI;F<@*#`@/2!T:&4@9FER<W0@<F]W*0H@("`@("H@
M0'!A<F%M(&EN="`@("`D8V]U;G0@("!T:&4@;G5M8F5R<R!O9B!R;W=S('1O
M(&9E=&-H"B`@("`@*B!`<&%R86T@;6EX960@("1P87)A;7,@(&%R<F%Y+"!S
M=')I;F<@;W(@;G5M97)I8R!D871A('1O(&)E('5S960@:6X*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@(&5X96-U=&EO;B!O9B!T:&4@<W1A=&5M
M96YT+B`@475A;G1I='D@;V8@:71E;7,*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@('!A<W-E9"!M=7-T(&UA=&-H('%U86YT:71Y(&]F('!L86-E
M:&]L9&5R<R!I;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<75E
M<GDZ("!M96%N:6YG(#$@<&QA8V5H;VQD97(@9F]R(&YO;BUA<G)A>0H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R<R!O<B`Q('!L
M86-E:&]L9&5R('!E<B!A<G)A>2!E;&5M96YT+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!T:&4@<75E<GD@<W1R:6YG('=I=&@@3$E-250@8VQA
M=7-E<R!A9&1E9`H@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&UO9&EF>4QI;6ET475E<GDH)'%U97)Y+"`D
M9G)O;2P@)&-O=6YT+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@
M("!R971U<FX@(B1Q=65R>2!,24U)5"`D8V]U;G0@3T9&4T54("1F<F]M(CL*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!M;V1I9GE1=65R>2@I"@H@
M("`@+RHJ"B`@("`@*B!#:&%N9V5S(&$@<75E<GD@<W1R:6YG(&9O<B!V87)I
M;W5S($1"35,@<W!E8VEF:6,@<F5A<V]N<PH@("`@("H*("`@("`J(%1H:7,@
M;&ET=&QE(&AA8VL@;&5T<R!Y;W4@:VYO=R!H;W<@;6%N>2!R;W=S('=E<F4@
M9&5L971E9`H@("`@("H@=VAE;B!R=6YN:6YG(&$@(D1%3$5412!&4D]-('1A
M8FQE(B!Q=65R>2X@($]N;'D@:6UP;&5M96YT960*("`@("`J(&EF('1H92!$
M0E]03U)404))3$E465]$14Q%5$5?0T]53E0@<&]R=&%B:6QI='D@;W!T:6]N
M(&ES(&]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'%U97)Y("!T
M:&4@<75E<GD@<W1R:6YG('1O(&UO9&EF>0H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!T:&4@;6]D:69I960@<75E<GD@<W1R:6YG"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J($!S964@1$)?8V]M;6]N
M.CIS971/<'1I;VXH*0H@("`@("HO"B`@("!F=6YC=&EO;B!M;V1I9GE1=65R
M>2@D<75E<GDI"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P
M;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?1$5,151%7T-/54Y4*2![
M"B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7EQS*D1%3$5415QS*T92
M3TU<<RLH7%,K*5QS*B0O:2<L("1Q=65R>2DI('L*("`@("`@("`@("`@("`@
M("1Q=65R>2`]('!R96=?<F5P;&%C92@G+UY<<RI$14Q%5$5<<RM&4D]-7',K
M*%Q3*RE<<RHD+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)T1%3$5412!&4D]-(%PQ(%=(15)%(#$],2<L("1Q=65R>2D["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1Q=65R>3L*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!S<6QI=&5286ES945R<F]R
M*"D*"B`@("`O*BH*("`@("`J(%!R;V1U8V5S(&$@1$)?17)R;W(@;V)J96-T
M(')E9V%R9&EN9R!T:&4@8W5R<F5N="!P<F]B;&5M"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN="`D97)R;F\@(&EF('1H92!E<G)O<B!I<R!B96EN9R!M86YU
M86QL>2!R86ES960@<&%S<R!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M($1"7T524D]2*B!C;VYS=&%N="!H97)E+B`@268@=&AI<R!I<VXG="!P87-S
M960*("`@("`J("`@("`@("`@("`@("`@("`@("`@=&AE(&5R<F]R(&EN9F]R
M;6%T:6]N(&=A=&AE<F5D(&9R;VT@=&AE($1"35,N"B`@("`@*@H@("`@("H@
M0')E='5R;B!O8FIE8W0@('1H92!$0E]%<G)O<B!O8FIE8W0*("`@("`J"B`@
M("`@*B!`<V5E($1"7V-O;6UO;CHZ<F%I<V5%<G)O<B@I+`H@("`@("H@("`@
M("!$0E]S<6QI=&4Z.F5R<F]R3F%T:79E*"DL($1"7W-Q;&ET93HZ97)R;W)#
M;V1E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@<W%L:71E4F%I<V5%<G)O<B@D
M97)R;F\@/2!N=6QL*0H@("`@>PH@("`@("`@("1N871I=F4@/2`D=&AI<RT^
M97)R;W).871I=F4H*3L*("`@("`@("!I9B`H)&5R<FYO(#T]/2!N=6QL*2![
M"B`@("`@("`@("`@("1E<G)N;R`]("1T:&ES+3YE<G)O<D-O9&4H)&YA=&EV
M92D["B`@("`@("`@?0H*("`@("`@("`D97)R;W)C;V1E(#T@0'-Q;&ET95]L
M87-T7V5R<F]R*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`D=7-E<FEN
M9F\@/2`B)&5R<F]R8V]D92`J*B`D=&AI<RT^;&%S=%]Q=65R>2(["@H@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D97)R;F\L(&YU;&PL(&YU
M;&PL("1U<V5R:6YF;RP@)&YA=&EV92D["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@97)R;W).871I=F4H*0H*("`@("\J*@H@("`@("H@1V5T<R!T
M:&4@1$)-4R<@;F%T:79E(&5R<F]R(&UE<W-A9V4@<')O9'5C960@8GD@=&AE
M(&QA<W0@<75E<GD*("`@("`J"B`@("`@*B![0&EN=&5R;F%L(%1H:7,@:7,@
M=7-E9"!T;R!R971R:65V92!M;W)E(&UE86YI;F=F=6QL(&5R<F]R(&UE<W-A
M9V5S"B`@("`@*B!B96-A=7-E('-Q;&ET95]L87-T7V5R<F]R*"D@9&]E<R!N
M;W0@<')O=FED92!A9&5Q=6%T92!I;F9O+GU]"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@('1H92!$0DU3)R!E<G)O<B!M97-S86=E"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&5R<F]R3F%T:79E*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]L87-T97)R;W(["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@97)R;W)#;V1E*"D*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@
M4$5!4CHZ1$(@97)R;W(@8V]D92!F<F]M('1H92!D871A8F%S92=S('1E>'0@
M97)R;W(@;65S<V%G90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&5R
M<F]R;7-G("!T:&4@97)R;W(@;65S<V%G92!R971U<FYE9"!F<F]M('1H92!D
M871A8F%S90H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@=&AE($1"
M(&5R<F]R(&YU;6)E<@H@("`@("HO"B`@("!F=6YC=&EO;B!E<G)O<D-O9&4H
M)&5R<F]R;7-G*0H@("`@>PH@("`@("`@('-T871I8R`D97)R;W)?<F5G97AP
M<SL*("`@("`@("!I9B`H(6ES<V5T*"1E<G)O<E]R96=E>'!S*2D@>PH@("`@
M("`@("`@("`D97)R;W)?<F5G97AP<R`](&%R<F%Y*`H@("`@("`@("`@("`@
M("`@)R]>;F\@<W5C:"!T86)L93HO)R`]/B!$0E]%4E)/4E].3U-50TA404),
M12P*("`@("`@("`@("`@("`@("<O7FYO('-U8V@@:6YD97@Z+R<@/3X@1$)?
M15)23U)?3D]47T9/54Y$+`H@("`@("`@("`@("`@("`@)R]>*'1A8FQE?&EN
M9&5X*2`N*B!A;')E861Y(&5X:7-T<R0O)R`]/B!$0E]%4E)/4E]!3%)%0419
M7T5825-44RP*("`@("`@("`@("`@("`@("<O4%))34%262!+15D@;75S="!B
M92!U;FEQ=64O:2<@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("`@("`@
M("`@("`@("<O:7,@;F]T('5N:7%U92\G(#T^($1"7T524D]27T-/3E-44D%)
M3E0L"B`@("`@("`@("`@("`@("`G+V-O;'5M;G,@+BH@87)E(&YO="!U;FEQ
M=64O:2<@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("`@("`@("`@("`@
M("<O=6YI<75E;F5S<R!C;VYS=')A:6YT(&9A:6QE9"\G(#T^($1"7T524D]2
M7T-/3E-44D%)3E0L"B`@("`@("`@("`@("`@("`G+VUA>2!N;W0@8F4@3E5,
M3"\G(#T^($1"7T524D]27T-/3E-44D%)3E1?3D]47TY53$PL"B`@("`@("`@
M("`@("`@("`G+UYN;R!S=6-H(&-O;'5M;CHO)R`]/B!$0E]%4E)/4E].3U-5
M0TA&245,1"P*("`@("`@("`@("`@("`@("<O8V]L=6UN(&YO="!P<F5S96YT
M(&EN(&)O=&@@=&%B;&5S+VDG(#T^($1"7T524D]27TY/4U5#2$9)14Q$+`H@
M("`@("`@("`@("`@("`@)R]>;F5A<B`B+BHB.B!S>6YT87@@97)R;W(D+R<@
M/3X@1$)?15)23U)?4UE.5$%8+`H@("`@("`@("`@("`@("`@)R];,"TY72L@
M=F%L=65S(&9O<B!;,"TY72L@8V]L=6UN<R]I)R`]/B!$0E]%4E)/4E]604Q5
M15]#3U5.5%]/3E]23U<L"B`@("`@("`@("`@("D["B`@("`@("`@?0H@("`@
M("`@(&9O<F5A8V@@*"1E<G)O<E]R96=E>'!S(&%S("1R96=E>'`@/3X@)&-O
M9&4I('L*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)')E9V5X<"P@)&5R
M<F]R;7-G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1C;V1E.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("\O($9A;&P@8F%C:R!T;R!$
M0E]%4E)/4B!I9B!T:&5R92!W87,@;F\@;6%P<&EN9RX*("`@("`@("!R971U
M<FX@1$)?15)23U(["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@=&%B
M;&5);F9O*"D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@:6YF;W)M871I;VX@
M86)O=70@82!T86)L90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("`@
M("`@("`D<F5S=6QT("!A('-T<FEN9R!C;VYT86EN:6YG('1H92!N86UE(&]F
M(&$@=&%B;&4*("`@("`J($!P87)A;2!I;G0@("`@("`@("`@("`D;6]D92`@
M("!A('9A;&ED('1A8FQE26YF;R!M;V1E"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@86X@87-S;V-I871I=F4@87)R87D@=VET:"!T:&4@:6YF;W)M
M871I;VX@<F5Q=65S=&5D+@H@("`@("H@("`@("`@("`@("`@("`@($$@1$)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$
M0E]C;VUM;VXZ.G1A8FQE26YF;R@I"B`@("`@*B!`<VEN8V4@365T:&]D(&%V
M86EL86)L92!S:6YC92!296QE87-E(#$N-RXP"B`@("`@*B\*("`@(&9U;F-T
M:6]N('1A8FQE26YF;R@D<F5S=6QT+"`D;6]D92`](&YU;&PI"B`@("!["B`@
M("`@("`@:68@*&ES7W-T<FEN9R@D<F5S=6QT*2D@>PH@("`@("`@("`@("`O
M*@H@("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E9"!A('1A8FQE(&YA
M;64N"B`@("`@("`@("`@("`J($-R96%T92!A(')E<W5L="!R97-O=7)C92!I
M9&5N=&EF:65R+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@)&ED(#T@
M0'-Q;&ET95]A<G)A>5]Q=65R>2@D=&AI<RT^8V]N;F5C=&EO;BP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B4%)!1TU!('1A8FQE
M7VEN9F\H)R1R97-U;'0G*3LB+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%-13$E415]!4U-/0RD["B`@("`@("`@("`@("1G;W1?
M<W1R:6YG(#T@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M=&AI<RT^;&%S=%]Q=65R>2`]("<G.PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H1$)?15)23U)?3D]47T-!4$%"3$4L(&YU;&PL(&YU
M;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G5&AI<R!$0DU3(&-A;B!N;W0@;V)T86EN('1A8FQE26YF;R<@+@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R!F<F]M(')E<W5L
M="!S971S)RD["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO
M;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465],3U=%4D-!4T4I
M('L*("`@("`@("`@("`@)&-A<V5?9G5N8R`]("=S=')T;VQO=V5R)SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8V%S95]F=6YC(#T@)W-T<G9A
M;"<["B`@("`@("`@?0H*("`@("`@("`D8V]U;G0@/2!C;W5N="@D:60I.PH@
M("`@("`@("1R97,@("`](&%R<F%Y*"D["@H@("`@("`@(&EF("@D;6]D92D@
M>PH@("`@("`@("`@("`D<F5S6R=N=6U?9FEE;&1S)UT@/2`D8V]U;G0["B`@
M("`@("`@?0H*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8V]U;G0[("1I
M*RLI('L*("`@("`@("`@("`@:68@*'-T<G!O<R@D:61;)&E=6R=T>7!E)UTL
M("<H)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D8FET<R`](&5X
M<&QO9&4H)R@G+"`D:61;)&E=6R=T>7!E)UTI.PH@("`@("`@("`@("`@("`@
M)'1Y<&4@/2`D8FET<ULP73L*("`@("`@("`@("`@("`@("1L96X@(#T@<G1R
M:6TH)&)I='-;,5TL)RDG*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1T>7!E(#T@)&ED6R1I75LG='EP92==.PH@("`@("`@("`@
M("`@("`@)&QE;B`@/2`P.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M9FQA9W,@/2`G)SL*("`@("`@("`@("`@:68@*"1I9%LD:5U;)W!K)UTI('L*
M("`@("`@("`@("`@("`@("1F;&%G<R`N/2`G<')I;6%R>5]K97D@)SL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&ED6R1I75LG;F]T;G5L;"==
M*2!["B`@("`@("`@("`@("`@("`D9FQA9W,@+CT@)VYO=%]N=6QL("<["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1I9%LD:5U;)V1F;'1?=F%L
M=64G72`A/3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@)&9L86=S("X]("=D
M969A=6QT7R<@+B!R87=U<FQE;F-O9&4H)&ED6R1I75LG9&9L=%]V86QU92==
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D9FQA9W,@/2!T<FEM*"1F
M;&%G<RD["@H@("`@("`@("`@("`D<F5S6R1I72`](&%R<F%Y*`H@("`@("`@
M("`@("`@("`@)W1A8FQE)R`]/B`D8V%S95]F=6YC*"1R97-U;'0I+`H@("`@
M("`@("`@("`@("`@)VYA;64G("`]/B`D8V%S95]F=6YC*"1I9%LD:5U;)VYA
M;64G72DL"B`@("`@("`@("`@("`@("`G='EP92<@(#T^("1T>7!E+`H@("`@
M("`@("`@("`@("`@)VQE;B<@("`]/B`D;&5N+`H@("`@("`@("`@("`@("`@
M)V9L86=S)R`]/B`D9FQA9W,L"B`@("`@("`@("`@("D["@H@("`@("`@("`@
M("!I9B`H)&UO9&4@)B!$0E]404),14E.1D]?3U)$15(I('L*("`@("`@("`@
M("`@("`@("1R97-;)V]R9&5R)UU;)')E<ULD:5U;)VYA;64G75T@/2`D:3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),
M14E.1D]?3U)$15)404),12D@>PH@("`@("`@("`@("`@("`@)')E<ULG;W)D
M97)T86)L92==6R1R97-;)&E=6R=T86)L92==75LD<F5S6R1I75LG;F%M92==
M72`]("1I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)')E<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G9713<&5C
M:6%L475E<GDH*0H*("`@("\J*@H@("`@("H@3V)T86EN<R!T:&4@<75E<GD@
M<W1R:6YG(&YE961E9"!F;W(@;&ES=&EN9R!A(&=I=F5N('1Y<&4@;V8@;V)J
M96-T<PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@('1H92!K
M:6YD(&]F(&]B:F5C=',@>6]U('=A;G0@=&\@<F5T<FEE=F4*("`@("`J($!P
M87)A;2!A<G)A>2`@)&%R9W,@(%-13$E412!$4DE615(@3TY,63H@82!P<FEV
M871E(&%R<F%Y(&]F(&%R9W5M96YT<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@('5S960@8GD@=&AE(&=E=%-P96-I86Q1=65R>2@I+B`@1&\@;F]T
M('5S90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('1H:7,@9&ER96-T
M;'DN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!344P@<75E
M<GD@<W1R:6YG(&]R(&YU;&P@:68@=&AE(&1R:79E<B!D;V5S;B=T"B`@("`@
M*B`@("`@("`@("`@("`@("`@('-U<'!O<G0@=&AE(&]B:F5C="!T>7!E(')E
M<75E<W1E9`H@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@
M*B!`<V5E($1"7V-O;6UO;CHZ9V5T3&ES=$]F*"D*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4W!E8VEA;%%U97)Y*"1T>7!E+"`D87)G<R`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D87)G<RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=N;R!K97D@<W!E8VEF
M:65D)RP@;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=!<F=U;65N="!H87,@=&\@8F4@86X@87)R87DN
M)RD["B`@("`@("`@?0H*("`@("`@("!S=VET8V@@*"1T>7!E*2!["B`@("`@
M("`@("`@(&-A<V4@)VUA<W1E<B<Z"B`@("`@("`@("`@("`@("!R971U<FX@
M)U-%3$5#5"`J($923TT@<W%L:71E7VUA<W1E<CLG.PH@("`@("`@("`@("!C
M87-E("=T86)L97,G.@H@("`@("`@("`@("`@("`@<F5T=7)N(")314Q%0U0@
M;F%M92!&4D]-('-Q;&ET95]M87-T97(@5TA%4D4@='EP93TG=&%B;&4G("(*
M("`@("`@("`@("`@("`@("`@("`@("`N("=53DE/3B!!3$P@4T5,14-4(&YA
M;64@1E)/32!S<6QI=&5?=&5M<%]M87-T97(@)PH@("`@("`@("`@("`@("`@
M("`@("`@("X@(E=(15)%('1Y<&4])W1A8FQE)R!/4D1%4B!"62!N86UE.R([
M"B`@("`@("`@("`@(&-A<V4@)W-C:&5M82<Z"B`@("`@("`@("`@("`@("!R
M971U<FX@)U-%3$5#5"!S<6P@1E)/32`H4T5,14-4("H@1E)/32!S<6QI=&5?
M;6%S=&5R("<*("`@("`@("`@("`@("`@("`@("`@("`N("=53DE/3B!!3$P@
M4T5,14-4("H@1E)/32!S<6QI=&5?=&5M<%]M87-T97(I("<*("`@("`@("`@
M("`@("`@("`@("`@("`N(")72$5212!T>7!E(3TG;65T82<@(@H@("`@("`@
M("`@("`@("`@("`@("`@("X@)T]21$52($)9('1B;%]N86UE+"!T>7!E($1%
M4T,L(&YA;64[)SL*("`@("`@("`@("`@8V%S92`G<V-H96UA>"<Z"B`@("`@
M("`@("`@(&-A<V4@)W-C:&5M85]X)SH*("`@("`@("`@("`@("`@("\J"B`@
M("`@("`@("`@("`@("`@*B!5<V4@;&EK93H*("`@("`@("`@("`@("`@("`J
M("1R97,@/2`D9&(M/G%U97)Y*"1D8BT^9V5T4W!E8VEA;%%U97)Y*"=S8VAE
M;6%?>"<L"B`@("`@("`@("`@("`@("`@*B`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G=&%B;&4G(#T^("=T86)L93,G*2DI.PH@("`@("`@("`@("`@("`@
M("HO"B`@("`@("`@("`@("`@("!R971U<FX@)U-%3$5#5"!S<6P@1E)/32`H
M4T5,14-4("H@1E)/32!S<6QI=&5?;6%S=&5R("<*("`@("`@("`@("`@("`@
M("`@("`@("`N("=53DE/3B!!3$P@4T5,14-4("H@1E)/32!S<6QI=&5?=&5M
M<%]M87-T97(I("<*("`@("`@("`@("`@("`@("`@("`@("`N(")72$5212!T
M8FQ?;F%M92!,24M%("=[)&%R9W-;)W1A8FQE)UU])R`B"B`@("`@("`@("`@
M("`@("`@("`@("`@+B`B04Y$('1Y<&4A/2=M971A)R`B"B`@("`@("`@("`@
M("`@("`@("`@("`@+B`G3U)$15(@0ED@='EP92!$15-#+"!N86UE.R<["B`@
M("`@("`@("`@(&-A<V4@)V%L=&5R)SH*("`@("`@("`@("`@("`@("\J"B`@
M("`@("`@("`@("`@("`@*B!344QI=&4@9&]E<R!N;W0@<W5P<&]R="!!3%1%
M4B!404),13L@=&AI<R!I<R!A(&AE;'!E<B!Q=65R>0H@("`@("`@("`@("`@
M("`@("H@=&\@:&%N9&QE('1H:7,N("=T86)L92<@<F5P<F5S96YT<R!T:&4@
M=&%B;&4@;F%M92P@)W)O=W,G"B`@("`@("`@("`@("`@("`@*B!T:&4@;F5W
M<R!R;W=S('1O(&-R96%T92P@)W-A=F4G('1H92!R;W<H<RD@=&\@:V5E<"!?
M=VET:%\*("`@("`@("`@("`@("`@("`J('1H92!D871A+@H@("`@("`@("`@
M("`@("`@("H*("`@("`@("`@("`@("`@("`J(%5S92!L:6ME.@H@("`@("`@
M("`@("`@("`@("H@)&%R9W,@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`J
M("`@("`G=&%B;&4G(#T^("1T86)L92P*("`@("`@("`@("`@("`@("`J("`@
M("`G<F]W<R<@(#T^(")I9"!)3E1%1T52(%!224U!4ED@2T59+"!F:7)S=&YA
M;64@5$585"P@<W5R;F%M92!415A4+"!D871E=&EM92!415A4(BP*("`@("`@
M("`@("`@("`@("`J("`@("`G<V%V92<@(#T^(").54Q,+"!T:71E;"P@8V]N
M=&5N="P@9&%T971I;64B"B`@("`@("`@("`@("`@("`@*B`I.PH@("`@("`@
M("`@("`@("`@("H@)')E<R`]("1D8BT^<75E<GDH("1D8BT^9V5T4W!E8VEA
M;%%U97)Y*"=A;'1E<B<L("1A<F=S*2D["B`@("`@("`@("`@("`@("`@*B\*
M("`@("`@("`@("`@("`@("1R;W=S(#T@<W1R='(H)&%R9W-;)W)O=W,G72P@
M)'1H:7,M/FME>7=O<F1S*3L*"B`@("`@("`@("`@("`@("`D<2`](&%R<F%Y
M*`H@("`@("`@("`@("`@("`@("`@("="14=)3B!44D%.4T%#5$E/3B<L"B`@
M("`@("`@("`@("`@("`@("`@(D-214%412!414U03U)!4ED@5$%"3$4@>R1A
M<F=S6R=T86)L92==?5]B86-K=7`@*'LD87)G<ULG<F]W<R==?2DB+`H@("`@
M("`@("`@("`@("`@("`@("))3E-%4E0@24Y43R![)&%R9W-;)W1A8FQE)UU]
M7V)A8VMU<"!314Q%0U0@>R1A<F=S6R=S879E)UU]($923TT@>R1A<F=S6R=T
M86)L92==?2(L"B`@("`@("`@("`@("`@("`@("`@(D123U`@5$%"3$4@>R1A
M<F=S6R=T86)L92==?2(L"B`@("`@("`@("`@("`@("`@("`@(D-214%412!4
M04),12![)&%R9W-;)W1A8FQE)UU]("A[)&%R9W-;)W)O=W,G77TI(BP*("`@
M("`@("`@("`@("`@("`@("`B24Y315)4($E.5$\@>R1A<F=S6R=T86)L92==
M?2!314Q%0U0@>R1R;W=S?2!&4D]-('LD87)G<ULG=&%B;&4G77U?8F%C:W5P
M(BP*("`@("`@("`@("`@("`@("`@("`B1%)/4"!404),12![)&%R9W-;)W1A
M8FQE)UU]7V)A8VMU<"(L"B`@("`@("`@("`@("`@("`@("`@)T-/34U)5"<L
M"B`@("`@("`@("`@("`@("`I.PH*("`@("`@("`@("`@("`@("\J"B`@("`@
M("`@("`@("`@("`@*B!4:&ES(&ES(&$@9&ER='D@:&%C:RP@<VEN8V4@=&AE
M(&%B;W9E('%U97)Y('=I;&P@;F]T(&=E=`H@("`@("`@("`@("`@("`@("H@
M97AE8W5T960@=VET:"!A('-I;F=L92!Q=65R>2!C86QL('-O(&AE<F4@=&AE
M('%U97)Y(&UE=&AO9`H@("`@("`@("`@("`@("`@("H@=VEL;"!B92!C86QL
M960@9&ER96-T;'D@86YD(')E='5R;B!A('-E;&5C="!I;G-T96%D+@H@("`@
M("`@("`@("`@("`@("HO"B`@("`@("`@("`@("`@("!F;W)E86-H("@D<2!A
M<R`D<75E<GDI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<75E<GDH
M)'%U97)Y*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(')E
M='5R;B`B4T5,14-4("H@1E)/32![)&%R9W-;)W1A8FQE)UU].R(["B`@("`@
M("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!R971U<FX@;G5L;#L*
M("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"GT*"B\J"B`J($QO8V%L('9A
M<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T
M"B`J($5N9#H*("HO"@H_/@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O1$(O<W1O<F%G92YP:'``````````````````````````````
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,S4P,#0`,3`U,34T,S,W,S<`,#(Q,C4S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"@HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]
M-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%!R;W9I9&5S(&%N(&]B:F5C
M="!I;G1E<F9A8V4@=&\@82!T86)L92!R;W<*("H*("H@4$A0('9E<G-I;VYS
M(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S
M=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90H@*B!T
M:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A
M="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y
M(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A
M:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A(&YO=&4@
M=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@
M:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P
M86-K86=E("`@($1""B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS=&EG
M0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R
M;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!#5E,Z
M("1)9#H@<W1O<F%G92YP:'`L=B`Q+C(Q(#(P,#4O,#(O,#(@,#(Z-30Z-3$@
M9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N
M;F5T+W!A8VMA9V4O1$(*("HO"@HO*BH*("H@3V)T86EN('1H92!$0B!C;&%S
M<R!S;R!I="!C86X@8F4@97AT96YD960@9G)O;0H@*B\*<F5Q=6ER95]O;F-E
M("=$0BYP:'`G.PH*+RHJ"B`J(%!R;W9I9&5S(&%N(&]B:F5C="!I;G1E<F9A
M8V4@=&\@82!T86)L92!R;W<*("H*("H@270@;&5T<R!Y;W4@861D+"!D96QE
M=&4@86YD(&-H86YG92!R;W=S('5S:6YG(&]B:F5C=',@<F%T:&5R('1H86X@
M4U%,"B`J('-T871E;65N=',N"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E
M"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N
M(#QS=&EG0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@
M4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@
M("!296QE87-E.B`Q+C<N-@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O1$(*("HO"F-L87-S($1"7W-T;W)A9V4@97AT96YD
M<R!014%2"GL*("`@("\O('M[>R!P<F]P97)T:65S"@H@("`@+RHJ('1H92!N
M86UE(&]F('1H92!T86)L92`H;W(@=FEE=RP@:68@=&AE(&)A8VME;F0@9&%T
M86)A<V4@<W5P<&]R=',*("`@("`@("!U<&1A=&5S(&EN('9I97=S*2!W92!H
M;VQD(&1A=&$@9G)O;2`J+PH@("`@=F%R("1?=&%B;&4@/2!N=6QL.PH*("`@
M("\J*B!W:&EC:"!C;VQU;6XH<RD@:6X@=&AE('1A8FQE(&-O;G1A:6YS('!R
M:6UA<GD@:V5Y<RP@8V%N(&)E(&$*("`@("`@("!S=')I;F<@9F]R('-I;F=L
M92UC;VQU;6X@<')I;6%R>2!K97ES+"!O<B!A;B!A<G)A>2!O9B!S=')I;F=S
M"B`@("`@("`@9F]R(&UU;'1I<&QE+6-O;'5M;B!P<FEM87)Y(&ME>7,@*B\*
M("`@('9A<B`D7VME>6-O;'5M;B`](&YU;&P["@H@("`@+RHJ($1"(&-O;FYE
M8W1I;VX@:&%N9&QE('5S960@9F]R(&%L;"!T<F%N<V%C=&EO;G,@*B\*("`@
M('9A<B`D7V1B:"`](&YU;&P["@H@("`@+RHJ(&%N(&%S<V]C('=I=&@@=&AE
M(&YA;65S(&]F(&1A=&%B87-E(&9I96QD<R!S=&]R960@87,@<')O<&5R=&EE
M<PH@("`@("`@(&EN('1H:7,@;V)J96-T("HO"B`@("!V87(@)%]P<F]P97)T
M:65S(#T@87)R87DH*3L*"B`@("`O*BH@86X@87-S;V,@=VET:"!T:&4@;F%M
M97,@;V8@=&AE('!R;W!E<G1I97,@:6X@=&AI<R!O8FIE8W0@=&AA=`H@("`@
M("`@(&AA=F4@8F5E;B!C:&%N9V5D('-I;F-E('1H97D@=V5R92!F971C:&5D
M(&9R;VT@=&AE(&1A=&%B87-E("HO"B`@("!V87(@)%]C:&%N9V5S(#T@87)R
M87DH*3L*"B`@("`O*BH@9FQA9R!T:&%T(&1E8VED97,@:68@9&%T82!I;B!T
M:&ES(&]B:F5C="!C86X@8F4@8VAA;F=E9"X*("`@("`@("!O8FIE8W1S('1H
M870@9&]N)W0@:&%V92!T:&5I<B!T86)L92=S(&ME>2!C;VQU;6X@:6X@=&AE
M:7(*("`@("`@("!P<F]P97)T>2!L:7-T<R!W:6QL(&)E(&9L86=G960@87,@
M<F5A9"UO;FQY+B`J+PH@("`@=F%R("1?<F5A9&]N;'D@/2!F86QS93L*"B`@
M("`O*BH@9G5N8W1I;VX@;W(@;65T:&]D('1H870@:6UP;&5M96YT<R!A('9A
M;&ED871O<B!F;W(@9FEE;&1S('1H870*("`@("`@("!A<F4@<V5T+"!T:&ES
M('9A;&ED871O<B!F=6YC=&EO;B!R971U<FYS('1R=64@:68@=&AE(&9I96QD
M(&ES"B`@("`@("`@=F%L:60L(&9A;'-E(&EF(&YO="`J+PH@("`@=F%R("1?
M=F%L:61A=&]R(#T@;G5L;#L*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYS
M=')U8W1O<@H*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@
M("`@*B!`<&%R86T@)'1A8FQE('-T<FEN9R!T:&4@;F%M92!O9B!T:&4@9&%T
M86)A<V4@=&%B;&4*("`@("`J"B`@("`@*B!`<&%R86T@)&ME>6-O;'5M;B!M
M:7AE9"!S=')I;F<@=VET:"!N86UE(&]F(&ME>2!C;VQU;6XL(&]R(&%R<F%Y
M(&]F"B`@("`@*B!S=')I;F=S(&EF('1H92!T86)L92!H87,@82!P<FEM87)Y
M(&ME>2!O9B!M;W)E('1H86X@;VYE(&-O;'5M;@H@("`@("H*("`@("`J($!P
M87)A;2`D9&)H(&]B:F5C="!D871A8F%S92!C;VYN96-T:6]N(&]B:F5C=`H@
M("`@("H*("`@("`J($!P87)A;2`D=F%L:61A=&]R(&UI>&5D(&9U;F-T:6]N
M(&]R(&UE=&AO9"!U<V5D('1O('9A;&ED871E"B`@("`@*B!E86-H(&YE=R!V
M86QU92P@8V%L;&5D('=I=&@@=&AR964@<&%R86UE=&5R<SH@=&AE(&YA;64@
M;V8@=&AE"B`@("`@*B!F:65L9"]C;VQU;6X@=&AA="!I<R!C:&%N9VEN9RP@
M82!R969E<F5N8V4@=&\@=&AE(&YE=R!V86QU92!A;F0*("`@("`J(&$@<F5F
M97)E;F-E('1O('1H:7,@;V)J96-T"B`@("`@*@H@("`@("HO"B`@("!F=6YC
M=&EO;B!$0E]S=&]R86=E*"1T86)L92P@)&ME>6-O;'5M;BP@)B1D8F@L("1V
M86QI9&%T;W(@/2!N=6QL*0H@("`@>PH@("`@("`@("1T:&ES+3Y014%2*"=$
M0E]%<G)O<B<I.PH@("`@("`@("1T:&ES+3Y?=&%B;&4@/2`D=&%B;&4["B`@
M("`@("`@)'1H:7,M/E]K97EC;VQU;6X@/2`D:V5Y8V]L=6UN.PH@("`@("`@
M("1T:&ES+3Y?9&)H(#T@)&1B:#L*("`@("`@("`D=&AI<RT^7W)E861O;FQY
M(#T@9F%L<V4["B`@("`@("`@)'1H:7,M/E]V86QI9&%T;W(@/2`D=F%L:61A
M=&]R.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(%]M86ME5VAE<F4H
M*0H*("`@("\J*@H@("`@("H@571I;&ET>2!M971H;V0@=&\@8G5I;&0@82`B
M5TA%4D4B(&-L875S92!T;R!L;V-A=&4@;W5R<V5L=F5S(&EN"B`@("`@*B!T
M:&4@=&%B;&4N"B`@("`@*@H@("`@("H@6%A8(&9U='5R92!I;7!R;W9E;65N
M=#H@=7-E(')O=VED<S\*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@9G5N8W1I;VX@7VUA:V57:&5R92@D:V5Y=F%L(#T@;G5L
M;"D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/E]K97EC;VQU
M;6XI*2!["B`@("`@("`@("`@(&EF("@D:V5Y=F%L(#T]/2!N=6QL*2!["B`@
M("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'1H:7,M
M/E]K97EC;VQU;6XI.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@)&ME
M>79A;%M=(#T@)'1H:7,M/GLD=&AI<RT^7VME>6-O;'5M;ELD:5U].PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1W:&5R
M96-L875S92`]("<G.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S
M:7IE;V8H)'1H:7,M/E]K97EC;VQU;6XI.R`D:2LK*2!["B`@("`@("`@("`@
M("`@("!I9B`H)&D@/B`P*2!["B`@("`@("`@("`@("`@("`@("`@)'=H97)E
M8VQA=7-E("X]("<@04Y$("<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D=VAE<F5C;&%U<V4@+CT@)'1H:7,M/E]K97EC;VQU;6Y;)&E=
M.PH@("`@("`@("`@("`@("`@:68@*&ES7VYU;&PH)&ME>79A;%LD:5TI*2![
M"B`@("`@("`@("`@("`@("`@("`@+R\@=&AE<F4G<R!N;W0@;75C:"!P;VEN
M="!I;B!H879I;F<@82!.54Q,(&ME>2P*("`@("`@("`@("`@("`@("`@("`O
M+R!B=70@=V4@<W5P<&]R="!I="!A;GEW87D*("`@("`@("`@("`@("`@("`@
M("`D=VAE<F5C;&%U<V4@+CT@)R!)4R!.54Q,)SL*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'=H97)E8VQA=7-E("X]
M("<@/2`G("X@)'1H:7,M/E]D8F@M/G%U;W1E*"1K97EV86Q;)&E=*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(&EF("@D:V5Y=F%L(#T]/2!N=6QL*2!["B`@("`@("`@
M("`@("`@("`D:V5Y=F%L(#T@0"1T:&ES+3Y[)'1H:7,M/E]K97EC;VQU;6Y]
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1W:&5R96-L875S92`]("1T
M:&ES+3Y?:V5Y8V]L=6UN.PH@("`@("`@("`@("!I9B`H:7-?;G5L;"@D:V5Y
M=F%L*2D@>PH@("`@("`@("`@("`@("`@+R\@=&AE<F4G<R!N;W0@;75C:"!P
M;VEN="!I;B!H879I;F<@82!.54Q,(&ME>2P*("`@("`@("`@("`@("`@("\O
M(&)U="!W92!S=7!P;W)T(&ET(&%N>7=A>0H@("`@("`@("`@("`@("`@)'=H
M97)E8VQA=7-E("X]("<@25,@3E5,3"<["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D=VAE<F5C;&%U<V4@+CT@)R`]("<@+B`D=&AI
M<RT^7V1B:"T^<75O=&4H)&ME>79A;"D["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1W:&5R96-L875S93L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!S971U<"@I"@H@("`@+RHJ"B`@("`@*B!-971H
M;V0@=7-E9"!T;R!I;FET:6%L:7IE(&$@1$)?<W1O<F%G92!O8FIE8W0@9G)O
M;2!T:&4*("`@("`J(&-O;F9I9W5R960@=&%B;&4N"B`@("`@*@H@("`@("H@
M0'!A<F%M("1K97EV86P@;6EX960@=&AE(&ME>5MS72!O9B!T:&4@<F]W('1O
M(&9E=&-H("AS=')I;F<@;W(@87)R87DI"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G0@1$)?3TL@;VX@<W5C8V5S<RP@82!$0B!E<G)O<B!I9B!N;W0*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T=7`H)&ME>79A;"D*("`@('L*("`@("`@
M("`D=VAE<F5C;&%U<V4@/2`D=&AI<RT^7VUA:V57:&5R92@D:V5Y=F%L*3L*
M("`@("`@("`D<75E<GD@/2`G4T5,14-4("H@1E)/32`G("X@)'1H:7,M/E]T
M86)L92`N("<@5TA%4D4@)R`N("1W:&5R96-L875S93L*("`@("`@("`D<W1H
M(#T@)'1H:7,M/E]D8F@M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@:68@*$1"
M.CII<T5R<F]R*"1S=&@I*2!["B`@("`@("`@("`@(')E='5R;B`D<W1H.PH@
M("`@("`@('T*("`@("`@("`D<F]W(#T@)'-T:"T^9F5T8VA2;W<H1$)?1D54
M0TA-3T1%7T%34T]#*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')O=RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1R;W<["B`@("`@("`@?0H@("`@("`@
M(&EF("@A)')O=RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H;G5L;"P@1$)?15)23U)?3D]47T9/54Y$+"!N=6QL+"!N=6QL+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'%U97)Y+"!N
M=6QL+"!T<G5E*3L*("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H)')O=R!A
M<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`D=&AI<RT^7W!R;W!E
M<G1I97-;)&ME>5T@/2!T<G5E.PH@("`@("`@("`@("`D=&AI<RT^)&ME>2`]
M("1V86QU93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&EN<V5R="@I"@H@("`@+RHJ"B`@
M("`@*B!#<F5A=&4@82!N97<@*&5M<'1Y*2!R;W<@:6X@=&AE(&-O;F9I9W5R
M960@=&%B;&4@9F]R('1H:7,*("`@("`J(&]B:F5C="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@:6YS97)T*"1N97=P:RD*("`@('L*("`@("`@("!I9B`H:7-?
M87)R87DH)'1H:7,M/E]K97EC;VQU;6XI*2!["B`@("`@("`@("`@("1P<FEM
M87)Y:V5Y(#T@)'1H:7,M/E]K97EC;VQU;6X["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'!R:6UA<GEK97D@/2!A<G)A>2@D=&AI<RT^7VME>6-O
M;'5M;BD["B`@("`@("`@?0H@("`@("`@('-E='1Y<&4H)&YE=W!K+"`B87)R
M87DB*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'!R:6UA
M<GEK97DI.R`D:2LK*2!["B`@("`@("`@("`@("1P:W9A;'-;72`]("1T:&ES
M+3Y?9&)H+3YQ=6]T92@D;F5W<&M;)&E=*3L*("`@("`@("!]"@H@("`@("`@
M("1S=&@@/2`D=&AI<RT^7V1B:"T^<75E<GDH(DE.4T525"!)3E1/("1T:&ES
M+3Y?=&%B;&4@*"(@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:6UP;&]D92@B+"(L("1P<FEM87)Y:V5Y*2`N("(I(%9!3%5%4R@B("X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EM<&QO9&4H(BPB
M+"`D<&MV86QS*2`N("(I(BD["B`@("`@("`@:68@*$1".CII<T5R<F]R*"1S
M=&@I*2!["B`@("`@("`@("`@(')E='5R;B`D<W1H.PH@("`@("`@('T*("`@
M("`@("!I9B`H<VEZ96]F*"1N97=P:RD@/3T@,2D@>PH@("`@("`@("`@("`D
M;F5W<&L@/2`D;F5W<&M;,%T["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YS
M971U<"@D;F5W<&LI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('1O
M4W1R:6YG*"D*"B`@("`O*BH*("`@("`J($]U='!U="!A('-I;7!L92!D97-C
M<FEP=&EO;B!O9B!T:&ES($1"7W-T;W)A9V4@;V)J96-T+@H@("`@("H@0')E
M='5R;B!S=')I;F<@;V)J96-T(&1E<V-R:7!T:6]N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('1O4W1R:6YG*"D*("`@('L*("`@("`@("`D:6YF;R`]('-T<G1O
M;&]W97(H9V5T7V-L87-S*"1T:&ES*2D["B`@("`@("`@)&EN9F\@+CT@(B`H
M=&%B;&4](CL*("`@("`@("`D:6YF;R`N/2`D=&AI<RT^7W1A8FQE.PH@("`@
M("`@("1I;F9O("X]("(L(&ME>6-O;'5M;CTB.PH@("`@("`@(&EF("AI<U]A
M<G)A>2@D=&AI<RT^7VME>6-O;'5M;BDI('L*("`@("`@("`@("`@)&EN9F\@
M+CT@(B@B("X@:6UP;&]D92@B+"(L("1T:&ES+3Y?:V5Y8V]L=6UN*2`N("(I
M(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:6YF;R`N/2`D=&AI
M<RT^7VME>6-O;'5M;CL*("`@("`@("!]"B`@("`@("`@)&EN9F\@+CT@(BP@
M9&)H/2(["B`@("`@("`@:68@*&ES7V]B:F5C="@D=&AI<RT^7V1B:"DI('L*
M("`@("`@("`@("`@)&EN9F\@+CT@)'1H:7,M/E]D8F@M/G1O4W1R:6YG*"D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&EN9F\@+CT@(FYU;&PB
M.PH@("`@("`@('T*("`@("`@("`D:6YF;R`N/2`B*2(["B`@("`@("`@:68@
M*'-I>F5O9B@D=&AI<RT^7W!R;W!E<G1I97,I*2!["B`@("`@("`@("`@("1I
M;F9O("X]("(@6VQO861E9"P@:V5Y/2(["B`@("`@("`@("`@("1K97EN86UE
M(#T@)'1H:7,M/E]K97EC;VQU;6X["B`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D:V5Y;F%M92DI('L*("`@("`@("`@("`@("`@("1I;F9O("X]("(H(CL*
M("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D:V5Y
M;F%M92D[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&D@/B`P
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O("X]("(L(CL*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&EN9F\@
M+CT@)'1H:7,M/B1K97EN86UE6R1I73L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1I;F9O("X]("(I(CL*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1I;F9O("X]("1T:&ES+3XD:V5Y;F%M93L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D:6YF;R`N/2`B72(["B`@("`@
M("`@?0H@("`@("`@(&EF("AS:7IE;V8H)'1H:7,M/E]C:&%N9V5S*2D@>PH@
M("`@("`@("`@("`D:6YF;R`N/2`B(%MM;V1I9FEE9%TB.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)&EN9F\["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@9'5M<"@I"@H@("`@+RHJ"B`@("`@*B!$=6UP('1H92!C;VYT96YT
M<R!O9B!T:&ES(&]B:F5C="!T;R`B<W1A;F1A<F0@;W5T<'5T(BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@9'5M<"@I"B`@("!["B`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/E]P<F]P97)T:65S(&%S("1P<F]P(#T^("1F;V\I('L*("`@("`@
M("`@("`@<')I;G0@(B1P<F]P(#T@(CL*("`@("`@("`@("`@<')I;G0@:'1M
M;&5N=&ET:65S*"1T:&ES+3XD<')O<"D["B`@("`@("`@("`@('!R:6YT("(\
M8G(@+SY<;B(["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[("9C<F5A=&4H*0H*("`@("\J*@H@("`@("H@4W1A=&EC(&UE=&AO9"!U
M<V5D('1O(&-R96%T92!N97<@1$(@<W1O<F%G92!O8FIE8W1S+@H@("`@("H@
M0'!A<F%M("1D871A(&%S<V]C+B!A<G)A>2!W:&5R92!T:&4@:V5Y<R!A<F4@
M=&AE(&YA;65S"B`@("`@*B`@("`@("`@("`@("`@;V8@<')O<&5R=&EE<R]C
M;VQU;6YS"B`@("`@*B!`<F5T=7)N(&]B:F5C="!A(&YE=R!I;G-T86YC92!O
M9B!$0E]S=&]R86=E(&]R(&$@<W5B8VQA<W,@;V8@:70*("`@("`J+PH@("`@
M9G5N8W1I;VX@)F-R96%T92@D=&%B;&4L("8D9&%T82D*("`@('L*("`@("`@
M("`D8VQA<W-N86UE(#T@<W1R=&]L;W=E<BAG971?8VQA<W,H)'1H:7,I*3L*
M("`@("`@("`D;V)J(#TF(&YE=R`D8VQA<W-N86UE*"1T86)L92D["B`@("`@
M("`@9F]R96%C:"`H)&1A=&$@87,@)&YA;64@/3X@)'9A;'5E*2!["B`@("`@
M("`@("`@("1O8FHM/E]P<F]P97)T:65S6R1N86UE72`]('1R=64["B`@("`@
M("`@("`@("1O8FHM/B1N86UE(#T@)B1V86QU93L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1O8FH["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M;&]A9$9R;VU1=65R>2@I"@H@("`@+RHJ"B`@("`@*B!,;V%D<R!D871A(&EN
M=&\@=&AI<R!O8FIE8W0@9G)O;2!T:&4@9VEV96X@<75E<GDN("!)9B!T:&ES
M"B`@("`@*B!O8FIE8W0@86QR96%D>2!C;VYT86EN<R!T86)L92!D871A+"!C
M:&%N9V5S('=I;&P@8F4@<V%V960@86YD"B`@("`@*B!T:&4@;V)J96-T(')E
M+6EN:71I86QI>F5D(&9I<G-T+@H@("`@("H*("`@("`J($!P87)A;2`D<75E
M<GD@4U%,('%U97)Y"B`@("`@*@H@("`@("H@0'!A<F%M("1P87)A;7,@<&%R
M86UE=&5R(&QI<W0@:6X@8V%S92!Y;W4@=V%N="!T;R!U<V4*("`@("`J('!R
M97!A<F4O97AE8W5T92!M;V1E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@
M1$)?3TL@;VX@<W5C8V5S<RP@1$)?5T%23DE.1U]214%$7T].3%D@:68@=&AE
M"B`@("`@*B!R971U<FYE9"!O8FIE8W0@:7,@<F5A9"UO;FQY("AB96-A=7-E
M('1H92!O8FIE8W0G<R!S<&5C:69I960*("`@("`J(&ME>2!C;VQU;6X@=V%S
M(&YO="!F;W5N9"!A;6]N9R!T:&4@8V]L=6UN<R!R971U<FYE9"!B>2`D<75E
M<GDI+`H@("`@("H@;W(@86YO=&AE<B!$0B!E<G)O<B!C;V1E(&EN(&-A<V4@
M;V8@97)R;W)S+@H@("`@("HO"B\O(%A86"!C;VUM96YT960@;W5T(&9O<B!N
M;W<*+RH*("`@(&9U;F-T:6]N(&QO861&<F]M475E<GDH)'%U97)Y+"`D<&%R
M86US(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H<VEZ96]F*"1T:&ES+3Y?
M<')O<&5R=&EE<RDI('L*("`@("`@("`@("`@:68@*'-I>F5O9B@D=&AI<RT^
M7V-H86YG97,I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<W1O<F4H*3L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E<R`](&%R<F%Y*"D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]P<F]P97)T:65S(#T@
M87)R87DH*3L*("`@("`@("!]"B`@("`@("`@)')O=V1A=&$@/2`D=&AI<RT^
M7V1B:"T^9V5T4F]W*"1Q=65R>2P@1$)?1D540TA-3T1%7T%34T]#+"`D<&%R
M86US*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')O=V1A=&$I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F]W9&%T83L*("`@("`@("!]"B`@("`@("`@
M<F5S970H)')O=V1A=&$I.PH@("`@("`@("1F;W5N9%]K97EC;VQU;6X@/2!F
M86QS93L*("`@("`@("!W:&EL92`H;&ES="@D:V5Y+"`D=F%L=64I(#T@96%C
M:"@D<F]W9&%T82DI('L*("`@("`@("`@("`@:68@*"1K97D@/3T@)'1H:7,M
M/E]K97EC;VQU;6XI('L*("`@("`@("`@("`@("`@("1F;W5N9%]K97EC;VQU
M;6X@/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?
M<')O<&5R=&EE<ULD:V5Y72`]('1R=64["B`@("`@("`@("`@("1T:&ES+3XD
M:V5Y(#T@)B1V86QU93L*("`@("`@("`@("`@=6YS970H)'9A;'5E*3L@+R\@
M:&%V92!T;R!U;G-E="P@;W(@86QL('!R;W!E<G1I97,@=VEL;`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!R969E<B!T;R!T:&4@<V%M92!V86QU
M90H@("`@("`@('T*("`@("`@("!I9B`H(21F;W5N9%]K97EC;VQU;6XI('L*
M("`@("`@("`@("`@)'1H:7,M/E]R96%D;VYL>2`]('1R=64["B`@("`@("`@
M("`@(')E='5R;B!$0E]705).24Y'7U)%041?3TY,63L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H@*B\*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!S970H*0H*("`@("\J*@H@("`@("H@36]D:69Y(&%N(&%T=')I
M=71E('9A;'5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S970H)'!R;W!E<G1Y
M+"`D;F5W=F%L=64I"B`@("!["B`@("`@("`@+R\@;VYL>2!C:&%N9V4@:68@
M)'!R;W!E<G1Y(&ES(&MN;W=N(&%N9"!O8FIE8W0@:7,@;F]T"B`@("`@("`@
M+R\@<F5A9"UO;FQY"B`@("`@("`@:68@*"1T:&ES+3Y?<F5A9&]N;'DI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*&YU;&PL($1"
M7U=!4DY)3D=?4D5!1%]/3DQ9+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P@=')U92D["B`@
M("`@("`@?0H@("`@("`@(&EF("A`:7-S970H)'1H:7,M/E]P<F]P97)T:65S
M6R1P<F]P97)T>5TI*2!["B`@("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^
M7W9A;&ED871O<BDI('L*("`@("`@("`@("`@("`@("1V86QI9"`]('1R=64[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=F%L:60@
M/2!`8V%L;%]U<V5R7V9U;F,H)'1H:7,M/E]V86QI9&%T;W(L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T86)L
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<')O<&5R='DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&YE=W9A;'5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3XD<')O<&5R='DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&EF("@D=F%L:60I('L*("`@("`@("`@("`@("`@
M("1T:&ES+3XD<')O<&5R='D@/2`D;F5W=F%L=64["B`@("`@("`@("`@("`@
M("!I9B`H96UP='DH)'1H:7,M/E]C:&%N9V5S6R1P<F]P97)T>5TI*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C:&%N9V5S6R1P<F]P97)T>5T@
M/2`P.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V-H86YG97-;)'!R;W!E<G1Y72LK.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*&YU;&PL($1"7T524D]27TE.5D%,
M240L(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@;G5L;"P@(FEN=F%L:60@9FEE;&0Z("1P<F]P97)T>2(L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;G5L;"P@=')U
M92D["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAN=6QL
M+"!$0E]%4E)/4E].3U-50TA&245,1"P@;G5L;"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@;G5L;"P@(G5N:VYO=VX@9FEE;&0Z("1P<F]P
M97)T>2(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL
M('1R=64I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[("9G970H*0H*
M("`@("\J*@H@("`@("H@1F5T8V@@86X@871T<FEB=71E('9A;'5E+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@871T<FEB=71E(&YA;64*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%T=')I8G5T92!C;VYT96YT<RP@;W(@;G5L;"!I
M9B!T:&4@871T<FEB=71E(&YA;64@:7,*("`@("`J('5N:VYO=VX*("`@("`J
M+PH@("`@9G5N8W1I;VX@)F=E="@D<')O<&5R='DI"B`@("!["B`@("`@("`@
M+R\@;VYL>2!R971U<FX@:68@)'!R;W!E<G1Y(&ES(&MN;W=N"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<')O<&5R=&EE<ULD<')O<&5R='E=*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/B1P<F]P97)T>3L*("`@("`@("!]
M"B`@("`@("`@)'1M<"`](&YU;&P["B`@("`@("`@<F5T=7)N("1T;7`["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@7T1"7W-T;W)A9V4H*0H*("`@
M("\J*@H@("`@("H@1&5S=')U8W1O<BP@8V%L;',@1$)?<W1O<F%G93HZ<W1O
M<F4H*2!I9B!T:&5R92!A<F4@8VAA;F=E<PH@("`@("H@=&AA="!A<F4@=&\@
M8F4@:V5P="X*("`@("`J+PH@("`@9G5N8W1I;VX@7T1"7W-T;W)A9V4H*0H@
M("`@>PH@("`@("`@(&EF("AS:7IE;V8H)'1H:7,M/E]C:&%N9V5S*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^<W1O<F4H*3L*("`@("`@("!]"B`@("`@("`@
M)'1H:7,M/E]P<F]P97)T:65S(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^
M7V-H86YG97,@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3Y?=&%B;&4@/2!N
M=6QL.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('-T;W)E*"D*"B`@
M("`O*BH*("`@("`J(%-T;W)E<R!C:&%N9V5S('1O('1H:7,@;V)J96-T(&EN
M('1H92!D871A8F%S92X*("`@("`J"B`@("`@*B!`<F5T=7)N($1"7T]+(&]R
M(&$@1$(@97)R;W(*("`@("`J+PH@("`@9G5N8W1I;VX@<W1O<F4H*0H@("`@
M>PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?8VAA;F=E<R!A<R`D;F%M92`]
M/B`D9F]O*2!["B`@("`@("`@("`@("1P87)A;7-;72`]("8D=&AI<RT^)&YA
M;64["B`@("`@("`@("`@("1V87)S6UT@/2`D;F%M92`N("<@/2`_)SL*("`@
M("`@("!]"B`@("`@("`@:68@*"1V87)S*2!["B`@("`@("`@("`@("1Q=65R
M>2`]("=54$1!5$4@)R`N("1T:&ES+3Y?=&%B;&4@+B`G(%-%5"`G("X*("`@
M("`@("`@("`@("`@(&EM<&QO9&4H)RP@)RP@)'9A<G,I("X@)R!72$5212`G
M("X*("`@("`@("`@("`@("`@("1T:&ES+3Y?;6%K95=H97)E*"D["B`@("`@
M("`@("`@("1S=&UT(#T@)'1H:7,M/E]D8F@M/G!R97!A<F4H)'%U97)Y*3L*
M("`@("`@("`@("`@)')E<R`]("1T:&ES+3Y?9&)H+3YE>&5C=71E*"1S=&UT
M+"`D<&%R86US*3L*("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97,I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D=&AI<RT^7V-H86YG97,@/2!A<G)A>2@I.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@<F5M;W9E*"D*"B`@("`O*BH*("`@("`J(%)E;6]V92!T
M:&4@<F]W(')E<')E<V5N=&5D(&)Y('1H:7,@;V)J96-T(&9R;VT@=&AE(&1A
M=&%B87-E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@1$)?3TL@;W(@
M82!$0B!E<G)O<@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F4H*0H@("`@
M>PH@("`@("`@(&EF("@D=&AI<RT^7W)E861O;FQY*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAN=6QL+"!$0E]705).24Y'7U)%
M041?3TY,62P@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&YU;&PL(&YU;&PL(&YU;&PL('1R=64I.PH@("`@("`@('T*("`@
M("`@("`D<75E<GD@/2`G1$5,151%($923TT@)R`N("1T:&ES+3Y?=&%B;&4@
M+B<@5TA%4D4@)RX*("`@("`@("`@("`@)'1H:7,M/E]M86ME5VAE<F4H*3L*
M("`@("`@("`D<F5S(#T@)'1H:7,M/E]D8F@M/G%U97)Y*"1Q=65R>2D["B`@
M("`@("`@:68@*$1".CII<T5R<F]R*"1R97,I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<F5S.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D=&AI<RT^
M7W!R;W!E<G1I97,@87,@)'!R;W`@/3X@)&9O;RD@>PH@("`@("`@("`@("!U
M;G-E="@D=&AI<RT^)'!R;W`I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^
M7W!R;W!E<G1I97,@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3Y?8VAA;F=E
M<R`](&%R<F%Y*"D["B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@
M("\O('U]?0I]"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T
M:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!%;F0Z"B`J+PH*/SX*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]$0B]S
M>6)A<V4N<&AP````````````````````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`V-C0P,P`Q,#4Q-30S,S<S-P`P,C$Q,#0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*"B\J('9I;3H@<V5T
M(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P
M/30Z("HO"@HO*BH*("H@5&AE(%!%05(@1$(@9')I=F5R(&9O<B!02%`G<R!S
M>6)A<V4@97AT96YS:6]N"B`J(&9O<B!I;G1E<F%C=&EN9R!W:71H(%-Y8F%S
M92!D871A8F%S97,*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@
M3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I
M;VX@,RXP(&]F('1H92!02%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L
M92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG
M(%5223H*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@
M($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@
M3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T
M:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N
M;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J
M"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J
M($!A=71H;W(@("`@(%-T97)L:6YG($AU9VAE<R`\<W1E<FQI;F=`<&AP+FYE
M=#X*("H@0&%U=&AO<B`@("`@06YT]&YI;R!#87)L;W,@5F5NXFYC:6\@2OIN
M:6]R(#QF;&]R:7!A0'!H<"YN970^"B`J($!A=71H;W(@("`@($1A;FEE;"!#
M;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY
M-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J
M($!V97)S:6]N("`@($-64SH@)$ED.B!S>6)A<V4N<&AP+'8@,2XW."`R,#`U
M+S`R+S(P(#`P.C0T.C0X(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@
M:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*+RHJ"B`J($]B
M=&%I;B!T:&4@1$)?8V]M;6]N(&-L87-S('-O(&ET(&-A;B!B92!E>'1E;F1E
M9"!F<F]M"B`J+PIR97%U:7)E7V]N8V4@)T1"+V-O;6UO;BYP:'`G.PH*+RHJ
M"B`J(%1H92!M971H;V1S(%!%05(@1$(@=7-E<R!T;R!I;G1E<F%C="!W:71H
M(%!(4"=S('-Y8F%S92!E>'1E;G-I;VX*("H@9F]R(&EN=&5R86-T:6YG('=I
M=&@@4WEB87-E(&1A=&%B87-E<PH@*@H@*B!4:&5S92!M971H;V1S(&]V97)L
M;V%D('1H92!O;F5S(&1E8VQA<F5D(&EN($1"7V-O;6UO;BX*("H*("H@5T%2
M3DE.1SH@(%1H:7,@9')I=F5R(&UA>2!F86EL('=I=&@@;75L=&EP;&4@8V]N
M;F5C=&EO;G,@=6YD97(@=&AE"B`J('-A;64@=7-E<B]P87-S+VAO<W0@86YD
M(&1I9F9E<F5N="!D871A8F%S97,N"B`J"B`J($!C871E9V]R>2`@($1A=&%B
M87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@(%-T97)L:6YG
M($AU9VAE<R`\<W1E<FQI;F=`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@06YT
M]&YI;R!#87)L;W,@5F5NXFYC:6\@2OIN:6]R(#QF;&]R:7!A0'!H<"YN970^
M"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP
M+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z
M(#$N-RXV"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]$0@H@*B\*8VQA<W,@1$)?<WEB87-E(&5X=&5N9',@1$)?8V]M;6]N
M"GL*("`@("\O('M[>R!P<F]P97)T:65S"@H@("`@+RHJ"B`@("`@*B!4:&4@
M1$(@9')I=F5R('1Y<&4@*&UY<W%L+"!O8VDX+"!O9&)C+"!E=&,N*0H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1P:'!T>7!E(#T@)W-Y
M8F%S92<["@H@("`@+RHJ"B`@("`@*B!4:&4@9&%T86)A<V4@<WEN=&%X('9A
M<FEA;G0@=&\@8F4@=7-E9"`H9&(R+"!A8V-E<W,L(&5T8RXI+"!I9B!A;GD*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D9&)S>6YT87@@
M/2`G<WEB87-E)SL*"B`@("`O*BH*("`@("`J(%1H92!C87!A8FEL:71I97,@
M;V8@=&AI<R!$0B!I;7!L96UE;G1A=&EO;@H@("`@("H*("`@("`J(%1H92`G
M;F5W7VQI;FLG(&5L96UE;G0@8V]N=&%I;G,@=&AE(%!(4"!V97)S:6]N('1H
M870@9FER<W0@<')O=FED960*("`@("`J(&YE=U]L:6YK('-U<'!O<G0@9F]R
M('1H:7,@1$)-4RX@($-O;G1A:6YS(&9A;'-E(&EF(&ET)W,@=6YS=7!P;W)T
M960N"B`@("`@*@H@("`@("H@365A;FEN9R!O9B!T:&4@)VQI;6ET)R!E;&5M
M96YT.@H@("`@("H@("`K("=E;75L871E)R`](&5M=6QA=&4@=VET:"!F971C
M:"!R;W<@8GD@;G5M8F5R"B`@("`@*B`@("L@)V%L=&5R)R`@(#T@86QT97(@
M=&AE('%U97)Y"B`@("`@*B`@("L@9F%L<V4@("`@(#T@<VMI<"!R;W=S"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&9E871U
M<F5S(#T@87)R87DH"B`@("`@("`@)VQI;6ET)R`@("`@("`@(#T^("=E;75L
M871E)RP*("`@("`@("`G;F5W7VQI;FLG("`@("`@/3X@9F%L<V4L"B`@("`@
M("`@)VYU;7)O=W,G("`@("`@(#T^('1R=64L"B`@("`@("`@)W!C;VYN96-T
M)R`@("`@(#T^('1R=64L"B`@("`@("`@)W!R97!A<F4G("`@("`@(#T^(&9A
M;'-E+`H@("`@("`@("=S<VPG("`@("`@("`@("`]/B!F86QS92P*("`@("`@
M("`G=')A;G-A8W1I;VYS)R`@/3X@=')U92P*("`@("D["@H@("`@+RHJ"B`@
M("`@*B!!(&UA<'!I;F<@;V8@;F%T:79E(&5R<F]R(&-O9&5S('1O($1"(&5R
M<F]R(&-O9&5S"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M97)R;W)C;V1E7VUA<"`](&%R<F%Y*`H@("`@*3L*"B`@("`O*BH*("`@("`J
M(%1H92!R87<@9&%T86)A<V4@8V]N;F5C=&EO;B!C<F5A=&5D(&)Y(%!(4`H@
M("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@)&-O;FYE8W1I
M;VX["@H@("`@+RHJ"B`@("`@*B!4:&4@1%-.(&EN9F]R;6%T:6]N(&9O<B!C
M;VYN96-T:6YG('1O(&$@9&%T86)A<V4*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1D<VX@/2!A<G)A>2@I.PH*"B`@("`O*BH*("`@("`J
M(%-H;W5L9"!D871A(&UA;FEP=6QA=&EO;B!Q=65R:65S(&)E(&-O;6UI='1E
M9"!A=71O;6%T:6-A;&QY/PH@("`@("H@0'9A<B!B;V]L"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1A=71O8V]M;6ET(#T@=')U
M93L*"B`@("`O*BH*("`@("`J(%1H92!Q=6%N=&ET>2!O9B!T<F%N<V%C=&EO
M;G,@8F5G=6X*("`@("`J"B`@("`@*B![0&EN=&5R;F%L("!7:&EL92!T:&ES
M(&ES('!R:79A=&4L(&ET(&-A;B=T(&%C='5A;&QY(&)E(&1E<VEG;F%T960*
M("`@("`J('!R:79A=&4@:6X@4$A0(#4@8F5C875S92!I="!I<R!D:7)E8W1L
M>2!A8V-E<W-E9"!I;B!T:&4@=&5S="!S=6ET92Y]?0H@("`@("H*("`@("`J
M($!V87(@:6YT96=E<@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@('9A<B`D=')A;G-A8W1I;VY?;W!C;W5N="`](#`["@H@("`@+RHJ"B`@
M("`@*B!4:&4@9&%T86)A<V4@<W!E8VEF:65D(&EN('1H92!$4TX*("`@("`J
M"B`@("`@*B!)="=S(&$@9FEX('1O(&%L;&]W(&-A;&QS('1O(&1I9F9E<F5N
M="!D871A8F%S97,@:6X@=&AE('-A;64@<V-R:7!T+@H@("`@("H*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@=F%R("1?9&(@/2`G)SL*"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]N
M<W1R=6-T;W(*"B`@("`O*BH*("`@("`J(%1H:7,@8V]N<W1R=6-T;W(@8V%L
M;',@/&MB9#XD=&AI<RT^1$)?8V]M;6]N*"D\+VMB9#X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@1$)?<WEB87-E
M*"D*("`@('L*("`@("`@("`D=&AI<RT^1$)?8V]M;6]N*"D["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@
M*B!#;VYN96-T('1O('1H92!D871A8F%S92!S97)V97(L(&QO9R!I;B!A;F0@
M;W!E;B!T:&4@9&%T86)A<V4*("`@("`J"B`@("`@*B!$;VXG="!C86QL('1H
M:7,@;65T:&]D(&1I<F5C=&QY+B`@57-E($1".CIC;VYN96-T*"D@:6YS=&5A
M9"X*("`@("`J"B`@("`@*B!014%2($1")W,@<WEB87-E(&1R:79E<B!S=7!P
M;W)T<R!T:&4@9F]L;&]W:6YG(&5X=')A($133B!O<'1I;VYS.@H@("`@("H@
M("`K(&%P<&YA;64@("`@("`@5&AE(&%P<&QI8V%T:6]N(&YA;64@=&\@=7-E
M(&]N('1H:7,@8V]N;F5C=&EO;BX*("`@("`J("`@("`@("`@("`@("`@("`@
M($%V86EL86)L92!S:6YC92!014%2($1"(#$N-RXP+@H@("`@("H@("`K(&-H
M87)S970@("`@("`@5&AE(&-H87)A8W1E<B!S970@=&\@=7-E(&]N('1H:7,@
M8V]N;F5C=&EO;BX*("`@("`J("`@("`@("`@("`@("`@("`@($%V86EL86)L
M92!S:6YC92!014%2($1"(#$N-RXP+@H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D9'-N("`@("`@("`@=&AE(&1A=&$@<V]U<F-E(&YA;64*("`@("`J
M($!P87)A;2!B;V]L("`D<&5R<VES=&5N="`@<VAO=6QD('1H92!C;VYN96-T
M:6]N(&)E('!E<G-I<W1E;G0_"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@
M($1"7T]+(&]N('-U8V-E<W,N($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;FYE8W0H)&1S;BP@)'!E<G-I
M<W1E;G0@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H(5!%05(Z.FQO861%
M>'1E;G-I;VXH)W-Y8F%S92<I("8F"B`@("`@("`@("`@("%014%2.CIL;V%D
M17AT96YS:6]N*"=S>6)A<V5?8W0G*2D*("`@("`@("!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]%6%1%3E-)3TY?
M3D]47T9/54Y$*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YD<VX@/2`D
M9'-N.PH@("`@("`@(&EF("@D9'-N6R=D8G-Y;G1A>"==*2!["B`@("`@("`@
M("`@("1T:&ES+3YD8G-Y;G1A>"`]("1D<VY;)V1B<WEN=&%X)UT["B`@("`@
M("`@?0H*("`@("`@("`D9'-N6R=H;W-T<W!E8R==(#T@)&1S;ELG:&]S='-P
M96,G72`_("1D<VY;)VAO<W1S<&5C)UT@.B`G;&]C86QH;W-T)SL*("`@("`@
M("`D9'-N6R=P87-S=V]R9"==(#T@(65M<'1Y*"1D<VY;)W!A<W-W;W)D)UTI
M(#\@)&1S;ELG<&%S<W=O<F0G72`Z(&9A;'-E.PH@("`@("`@("1D<VY;)V-H
M87)S970G72`](&ES<V5T*"1D<VY;)V-H87)S970G72D@/R`D9'-N6R=C:&%R
M<V5T)UT@.B!F86QS93L*("`@("`@("`D9'-N6R=A<'!N86UE)UT@/2!I<W-E
M="@D9'-N6R=A<'!N86UE)UTI(#\@)&1S;ELG87!P;F%M92==(#H@9F%L<V4[
M"@H@("`@("`@("1C;VYN96-T7V9U;F-T:6]N(#T@)'!E<G-I<W1E;G0@/R`G
M<WEB87-E7W!C;VYN96-T)R`Z("=S>6)A<V5?8V]N;F5C="<["@H@("`@("`@
M(&EF("@D9'-N6R=U<V5R;F%M92==*2!["B`@("`@("`@("`@("1T:&ES+3YC
M;VYN96-T:6]N(#T@0"1C;VYN96-T7V9U;F-T:6]N*"1D<VY;)VAO<W1S<&5C
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1D<VY;)W5S97)N86UE)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D<VY;)W!A<W-W
M;W)D)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1D<VY;)V-H87)S970G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1S;ELG87!P
M;F%M92==*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?0T].3D5#5%]&04E,140L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL
M+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)U1H92!$4TX@9&ED(&YO="!C;VYT86EN(&$@=7-E<FYA;64N)RD["B`@("`@
M("`@?0H*("`@("`@("!I9B`H(21T:&ES+3YC;VYN96-T:6]N*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]#3TY.
M14-47T9!24Q%1"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&YU;&PL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!`<WEB87-E7V=E=%]L87-T7VUE<W-A9V4H*2D["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)&1S;ELG9&%T86)A<V4G72D@>PH@("`@
M("`@("`@("!I9B`H(4!S>6)A<V5?<V5L96-T7V1B*"1D<VY;)V1A=&%B87-E
M)UTL("1T:&ES+3YC;VYN96-T:6]N*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27TY/1$)314Q%0U1%1"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL
M+"!N=6QL+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@($!S>6)A<V5?9V5T7VQA<W1?;65S<V%G92@I*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V1B(#T@)&1S;ELG9&%T86)A
M<V4G73L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!D:7-C;VYN96-T*"D*"B`@("`O*BH*
M("`@("`J($1I<V-O;FYE8W1S(&9R;VT@=&AE(&1A=&%B87-E('-E<G9E<@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;"`@5%)512!O;B!S=6-C97-S+"!&
M04Q312!O;B!F86EL=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N(&1I<V-O;FYE
M8W0H*0H@("`@>PH@("`@("`@("1R970@/2!`<WEB87-E7V-L;W-E*"1T:&ES
M+3YC;VYN96-T:6]N*3L*("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`](&YU
M;&P["B`@("`@("`@<F5T=7)N("1R970["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@<VEM<&QE475E<GDH*0H*("`@("\J*@H@("`@("H@4V5N9',@
M82!Q=65R>2!T;R!T:&4@9&%T86)A<V4@<V5R=F5R"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`@=&AE(%-13"!Q=65R>2!S=')I;F<*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("`K(&$@4$A0(')E<W5L="!R97-R;W5C92!F
M;W(@<W5C8V5S<V9U;"!314Q%0U0@<75E<FEE<PH@("`@("H@("`@("`@("`@
M("`@("`@*R!T:&4@1$)?3TL@8V]N<W1A;G0@9F]R(&]T:&5R('-U8V-E<W-F
M=6P@<75E<FEE<PH@("`@("H@("`@("`@("`@("`@("`@*R!A($1"7T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N('-I;7!L
M95%U97)Y*"1Q=65R>2D*("`@('L*("`@("`@("`D:7-M86YI<"`]($1".CII
M<TUA;FEP*"1Q=65R>2D["B`@("`@("`@)'1H:7,M/FQA<W1?<75E<GD@/2`D
M<75E<GD["B`@("`@("`@:68@*"%`<WEB87-E7W-E;&5C=%]D8B@D=&AI<RT^
M7V1B+"`D=&AI<RT^8V]N;F5C=&EO;BDI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YS>6)A<V5286ES945R<F]R*$1"7T524D]27TY/1$)314Q%0U1%
M1"D["B`@("`@("`@?0H@("`@("`@("1Q=65R>2`]("1T:&ES+3YM;V1I9GE1
M=65R>2@D<75E<GDI.PH@("`@("`@(&EF("@A)'1H:7,M/F%U=&]C;VUM:70@
M)B8@)&ES;6%N:7`I('L*("`@("`@("`@("`@:68@*"1T:&ES+3YT<F%N<V%C
M=&EO;E]O<&-O=6YT(#T](#`I('L*("`@("`@("`@("`@("`@("1R97-U;'0@
M/2!`<WEB87-E7W%U97)Y*"="14=)3B!44D%.4T%#5$E/3B<L("1T:&ES+3YC
M;VYN96-T:6]N*3L*("`@("`@("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<WEB87-E4F%I<V5%
M<G)O<B@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT*RL["B`@("`@("`@
M?0H@("`@("`@("1R97-U;'0@/2!`<WEB87-E7W%U97)Y*"1Q=65R>2P@)'1H
M:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G-Y8F%S95)A:7-E17)R;W(H*3L*("`@
M("`@("!]"B`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1R97-U;'0I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("`O
M+R!$971E<FUI;F4@=VAI8V@@<75E<FEE<R!T:&%T('-H;W5L9"!R971U<FX@
M9&%T82P@86YD('=H:6-H"B`@("`@("`@+R\@<VAO=6QD(')E='5R;B!A;B!E
M<G)O<B!C;V1E(&]N;'DN"B`@("`@("`@<F5T=7)N("1I<VUA;FEP(#\@1$)?
M3TL@.B`D<F5S=6QT.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YE
M>'1297-U;'0H*0H*("`@("\J*@H@("`@("H@36]V92!T:&4@:6YT97)N86P@
M<WEB87-E(')E<W5L="!P;VEN=&5R('1O('1H92!N97AT(&%V86EL86)L92!R
M97-U;'0*("`@("`J"B`@("`@*B!`<&%R86T@82!V86QI9"!S>6)A<V4@<F5S
M=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J"B`@("`@*B!`<F5T=7)N('1R=64@:68@82!R97-U;'0@:7,@879A:6QA
M8FQE(&]T:&5R=VES92!R971U<FX@9F%L<V4*("`@("`J+PH@("`@9G5N8W1I
M;VX@;F5X=%)E<W5L="@D<F5S=6QT*0H@("`@>PH@("`@("`@(')E='5R;B!F
M86QS93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F971C:$EN=&\H
M*0H*("`@("\J*@H@("`@("H@4&QA8V5S(&$@<F]W(&9R;VT@=&AE(')E<W5L
M="!S970@:6YT;R!T:&4@9VEV96X@87)R87D*("`@("`J"B`@("`@*B!&;W)M
M871I;F<@;V8@=&AE(&%R<F%Y(&%N9"!T:&4@9&%T82!T:&5R96EN(&%R92!C
M;VYF:6=U<F%B;&4N"B`@("`@*B!3964@1$)?<F5S=6QT.CIF971C:$EN=&\H
M*2!F;W(@;6]R92!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!4:&ES(&UE
M=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E
M"B`@("`@*B!$0E]R97-U;'0Z.F9E=&-H26YT;R@I(&EN<W1E860N("!)="!C
M86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$
M0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@
M0'!A<F%M(')E<V]U<F-E("1R97-U;'0@("`@=&AE('%U97)Y(')E<W5L="!R
M97-O=7)C90H@("`@("H@0'!A<F%M(&%R<F%Y("`@("1A<G(@("`@("`@=&AE
M(')E9F5R96YC960@87)R87D@=&\@<'5T('1H92!D871A(&EN"B`@("`@*B!`
M<&%R86T@:6YT("`@("`@)&9E=&-H;6]D92!H;W<@=&AE(')E<W5L=&EN9R!A
M<G)A>2!S:&]U;&0@8F4@:6YD97AE9`H@("`@("H@0'!A<F%M(&EN="`@("`@
M("1R;W=N=6T@("`@=&AE(')O=R!N=6UB97(@=&\@9F5T8V@@*#`@/2!F:7)S
M="!R;W<I"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1$)?3TL@;VX@
M<W5C8V5S<RP@3E5,3"!W:&5N('1H92!E;F0@;V8@82!R97-U;'0@<V5T(&ES
M"B`@("`@*B`@("`@("`@("`@("`@("`@<F5A8VAE9"!O<B!O;B!F86EL=7)E
M"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&9E=&-H26YT;R@D<F5S=6QT+"`F)&%R<BP@
M)&9E=&-H;6]D92P@)')O=VYU;2`](&YU;&PI"B`@("!["B`@("`@("`@:68@
M*"1R;W=N=6T@(3T](&YU;&PI('L*("`@("`@("`@("`@:68@*"%`<WEB87-E
M7V1A=&%?<V5E:R@D<F5S=6QT+"`D<F]W;G5M*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N(&YU;&P["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@:68@*"1F971C:&UO9&4@)B!$0E]&151#2$U/1$5?05-33T,I('L*("`@
M("`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G<WEB87-E7V9E=&-H7V%S
M<V]C)RDI('L*("`@("`@("`@("`@("`@("1A<G(@/2!`<WEB87-E7V9E=&-H
M7V%S<V]C*"1R97-U;'0I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@:68@*"1A<G(@/2!`<WEB87-E7V9E=&-H7V%R<F%Y*"1R97-U
M;'0I*2!["B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&%R<B!A<R`D
M:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-?:6YT*"1K97DI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!U
M;G-E="@D87)R6R1K97E=*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A
M8FEL:71Y)UT@)B!$0E]03U)404))3$E465],3U=%4D-!4T4@)B8@)&%R<BD@
M>PH@("`@("`@("`@("`@("`@)&%R<B`](&%R<F%Y7V-H86YG95]K97E?8V%S
M92@D87)R+"!#05-%7TQ/5T52*3L*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1A<G(@/2!`<WEB87-E7V9E=&-H7W)O=R@D
M<F5S=6QT*3L*("`@("`@("!]"B`@("`@("`@:68@*"$D87)R*2!["B`@("`@
M("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H
M:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465]2
M5%))32D@>PH@("`@("`@("`@("`D=&AI<RT^7W)T<FEM07)R87E686QU97,H
M)&%R<BD["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG
M<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TY53$Q?5$]?14U05%DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]C;VYV97)T3G5L;$%R<F%Y5F%L=65S
M5&]%;7!T>2@D87)R*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9R965297-U;'0H*0H*
M("`@("\J*@H@("`@("H@1&5L971E<R!T:&4@<F5S=6QT('-E="!A;F0@9G)E
M97,@=&AE(&UE;6]R>2!O8V-U<&EE9"!B>2!T:&4@<F5S=6QT('-E=`H@("`@
M("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL
M960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ9G)E92@I(&EN
M<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@
M("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@(%!(4"=S('%U
M97)Y(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;"`@5%)512!O;B!S=6-C97-S+"!&04Q312!I9B`D<F5S=6QT(&ES(&EN=F%L
M:60*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ9G)E92@I"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&9R965297-U;'0H)')E<W5L="D*("`@('L*("`@
M("`@("!R971U<FX@0'-Y8F%S95]F<F5E7W)E<W5L="@D<F5S=6QT*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N=6U#;VQS*"D*"B`@("`O*BH*
M("`@("`J($=E=',@=&AE(&YU;6)E<B!O9B!C;VQU;6YS(&EN(&$@<F5S=6QT
M('-E=`H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T
M;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ
M;G5M0V]L<R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B<')O
M=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T
M92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U
M;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J
M($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(&-O;'5M;G,N("!!($1"7T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?
M<F5S=6QT.CIN=6U#;VQS*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;G5M0V]L
M<R@D<F5S=6QT*0H@("`@>PH@("`@("`@("1C;VQS(#T@0'-Y8F%S95]N=6U?
M9FEE;&1S*"1R97-U;'0I.PH@("`@("`@(&EF("@A)&-O;',I('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YS>6)A<V5286ES945R<F]R*"D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D8V]L<SL*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!N=6U2;W=S*"D*"B`@("`O*BH*("`@("`J($=E=',@=&AE
M(&YU;6)E<B!O9B!R;W=S(&EN(&$@<F5S=6QT('-E=`H@("`@("H*("`@("`J
M(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T
M;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ;G5M4F]W<R@I(&EN<W1E860N
M("!)="!C86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C
M875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@
M("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@(%!(4"=S('%U97)Y(')E
M<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@
M;G5M8F5R(&]F(')O=W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIN=6U2;W=S*"D*("`@
M("`J+PH@("`@9G5N8W1I;VX@;G5M4F]W<R@D<F5S=6QT*0H@("`@>PH@("`@
M("`@("1R;W=S(#T@0'-Y8F%S95]N=6U?<F]W<R@D<F5S=6QT*3L*("`@("`@
M("!I9B`H)')O=W,@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<WEB87-E4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)')O=W,["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@869F
M96-T9612;W=S*"D*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@=&AE(&YU
M;6)E<B!O9B!R;W=S(&%F9F5C=&5D(&)Y(&$@9&%T82!M86YI=7!L871I;VX@
M<75E<GD*("`@("`J"B`@("`@*B`P(&ES(')E='5R;F5D(&9O<B!Q=65R:65S
M('1H870@9&]N)W0@;6%N:7!U;&%T92!D871A+@H@("`@("H*("`@("`J($!R
M971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(')O=W,N("!!($1"7T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9F9E8W1E
M9%)O=W,H*0H@("`@>PH@("`@("`@(&EF("A$0CHZ:7--86YI<"@D=&AI<RT^
M;&%S=%]Q=65R>2DI('L*("`@("`@("`@("`@)')E<W5L="`]($!S>6)A<V5?
M869F96-T961?<F]W<R@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)')E<W5L="`](#`["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!N97AT260H*0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;F5X
M="!F<F5E(&ED(&EN(&$@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E;F-E"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D;VYD96UA;F0@('=H96X@=')U92P@=&AE('-E
M<65N8V4@:7,@875T;VUA=&EC86QL>0H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8W)E871E9"!I9B!I="!D;V5S(&YO="!E>&ES=`H@("`@
M("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;F5X="!I9"!N=6UB97(@:6X@
M=&AE('-E<75E;F-E+@H@("`@("H@("`@("`@("`@("`@("!!($1"7T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M
M;6]N.CIN97AT240H*2P@1$)?8V]M;6]N.CIG971397%U96YC94YA;64H*2P*
M("`@("`J("`@("`@1$)?<WEB87-E.CIC<F5A=&5397%U96YC92@I+"!$0E]S
M>6)A<V4Z.F1R;W!397%U96YC92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE
M>'1)9"@D<V5Q7VYA;64L("1O;F1E;6%N9"`]('1R=64I"B`@("!["B`@("`@
M("`@)'-E<6YA;64@/2`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M
M92D["B`@("`@("`@:68@*"%`<WEB87-E7W-E;&5C=%]D8B@D=&AI<RT^7V1B
M+"`D=&AI<RT^8V]N;F5C=&EO;BDI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YS>6)A<V5286ES945R<F]R*$1"7T524D]27TY/1$)314Q%0U1%1"D[
M"B`@("`@("`@?0H@("`@("`@("1R97!E870@/2`P.PH@("`@("`@(&1O('L*
M("`@("`@("`@("`@)'1H:7,M/G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)2
M3U)?4D5455).*3L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YQ=65R
M>2@B24Y315)4($E.5$\@)'-E<6YA;64@*'9A<&]R*2!604Q515,@*#`I(BD[
M"B`@("`@("`@("`@("1T:&ES+3YP;W!%<G)O<DAA;F1L:6YG*"D["B`@("`@
M("`@("`@(&EF("@D;VYD96UA;F0@)B8@1$(Z.FES17)R;W(H)')E<W5L="D@
M)B8*("`@("`@("`@("`@("`@("@D<F5S=6QT+3YG971#;V1E*"D@/3T@1$)?
M15)23U(@?'P@)')E<W5L="T^9V5T0V]D92@I(#T]($1"7T524D]27TY/4U5#
M2%1!0DQ%*2D*("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@)')E<&5A
M="`](#$["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F-R96%T
M95-E<75E;F-E*"1S97%?;F%M92D["B`@("`@("`@("`@("`@("!I9B`H1$(Z
M.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E<W5L="D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T@96QS96EF("@A1$(Z.FES17)R;W(H)')E<W5L
M="DI('L*("`@("`@("`@("`@("`@("1R97-U;'0@/28@)'1H:7,M/G%U97)Y
M*")314Q%0U0@0$!)1$5.5$E462!&4D]-("1S97%N86UE(BD["B`@("`@("`@
M("`@("`@("`D<F5P96%T(#T@,#L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1R97!E870@/2!F86QS93L*("`@("`@("`@("`@?0H@
M("`@("`@('T@=VAI;&4@*"1R97!E870I.PH@("`@("`@(&EF("A$0CHZ:7-%
M<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H)')E<W5L="D["B`@("`@("`@?0H@("`@("`@("1R97-U;'0@
M/2`D<F5S=6QT+3YF971C:%)O=RA$0E]&151#2$U/1$5?3U)$15)%1"D["B`@
M("`@("`@<F5T=7)N("1R97-U;'1;,%T["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#<F5A=&5S(&$@;F5W('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<V5Q7VYA;64@(&YA;64@;V8@=&AE(&YE=R!S97%U96YC90H@
M("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@
M02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`
M<V5E($1"7V-O;6UO;CHZ8W)E871E4V5Q=65N8V4H*2P@1$)?8V]M;6]N.CIG
M971397%U96YC94YA;64H*2P*("`@("`J("`@("`@1$)?<WEB87-E.CIN97AT
M240H*2P@1$)?<WEB87-E.CID<F]P4V5Q=65N8V4H*0H@("`@("HO"B`@("!F
M=6YC=&EO;B!C<F5A=&5397%U96YC92@D<V5Q7VYA;64I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3YQ=65R>2@G0U)%051%(%1!0DQ%("<*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("X@)'1H:7,M/F=E=%-E<75E;F-E3F%M
M92@D<V5Q7VYA;64I"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("<@
M*&ED(&YU;65R:6,H,3`L(#`I($E$14Y42519($Y/5"!.54Q,+"<*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("X@)R!V87!O<B!I;G0@3E5,3"DG*3L*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!D<F]P4V5Q=65N8V4H*0H*
M("`@("\J*@H@("`@("H@1&5L971E<R!A('-E<75E;F-E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E
M;F-E('1O(&)E(&1E;&5T960*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@
M1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F1R;W!397%U96YC
M92@I+"!$0E]C;VUM;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@("`@
M("!$0E]S>6)A<V4Z.FYE>'1)1"@I+"!$0E]S>6)A<V4Z.F-R96%T95-E<75E
M;F-E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9')O<%-E<75E;F-E*"1S97%?
M;F%M92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G%U97)Y*"=$4D]0
M(%1!0DQ%("<@+B`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M92DI
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&%U=&]#;VUM:70H*0H*
M("`@("\J*@H@("`@("H@16YA8FQE<R!O<B!D:7-A8FQE<R!A=71O;6%T:6,@
M8V]M;6ET<PH@("`@("H*("`@("`J($!P87)A;2!B;V]L("1O;F]F9B`@=')U
M92!T=7)N<R!I="!O;BP@9F%L<V4@='5R;G,@:70@;V9F"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R
M(&]B:F5C="!I9B!T:&4@9')I=F5R"B`@("`@*B`@("`@("`@("`@("`@(&1O
M97-N)W0@<W5P<&]R="!A=71O+6-O;6UI='1I;F<@=')A;G-A8W1I;VYS+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!A=71O0V]M;6ET*"1O;F]F9B`](&9A;'-E
M*0H@("`@>PH@("`@("`@("\O(%A86"!I9B`D=&AI<RT^=')A;G-A8W1I;VY?
M;W!C;W5N="`^(#`L('=E('-H;W5L9"!P<F]B86)L>0H@("`@("`@("\O(&ES
M<W5E(&$@=V%R;FEN9R!H97)E+@H@("`@("`@("1T:&ES+3YA=71O8V]M;6ET
M(#T@)&]N;V9F(#\@=')U92`Z(&9A;'-E.PH@("`@("`@(')E='5R;B!$0E]/
M2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VUM:70H*0H*("`@
M("\J*@H@("`@("H@0V]M;6ET<R!T:&4@8W5R<F5N="!T<F%N<V%C=&EO;@H@
M("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@
M02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@8V]M;6ET*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/G1R86YS
M86-T:6]N7V]P8V]U;G0@/B`P*2!["B`@("`@("`@("`@(&EF("@A0'-Y8F%S
M95]S96QE8W1?9&(H)'1H:7,M/E]D8BP@)'1H:7,M/F-O;FYE8W1I;VXI*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-Y8F%S95)A:7-E17)R
M;W(H1$)?15)23U)?3D]$0E-%3$5#5$5$*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D<F5S=6QT(#T@0'-Y8F%S95]Q=65R>2@G0T]-34E4)RP@)'1H
M:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`D=&AI<RT^=')A;G-A8W1I
M;VY?;W!C;W5N="`](#`["B`@("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS>6)A<V5286ES945R<F]R
M*"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"
M7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(')O;&QB86-K*"D*
M"B`@("`O*BH*("`@("`J(%)E=F5R=',@=&AE(&-U<G)E;G0@=')A;G-A8W1I
M;VX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S
M<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')O;&QB86-K*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M
M/G1R86YS86-T:6]N7V]P8V]U;G0@/B`P*2!["B`@("`@("`@("`@(&EF("@A
M0'-Y8F%S95]S96QE8W1?9&(H)'1H:7,M/E]D8BP@)'1H:7,M/F-O;FYE8W1I
M;VXI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-Y8F%S95)A
M:7-E17)R;W(H1$)?15)23U)?3D]$0E-%3$5#5$5$*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D<F5S=6QT(#T@0'-Y8F%S95]Q=65R>2@G4D],3$)!
M0TLG+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("1T:&ES+3YT
M<F%N<V%C=&EO;E]O<&-O=6YT(#T@,#L*("`@("`@("`@("`@:68@*"$D<F5S
M=6QT*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-Y8F%S95)A
M:7-E17)R;W(H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R
M971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<WEB
M87-E4F%I<V5%<G)O<B@I"@H@("`@+RHJ"B`@("`@*B!0<F]D=6-E<R!A($1"
M7T5R<F]R(&]B:F5C="!R96=A<F1I;F<@=&AE(&-U<G)E;G0@<')O8FQE;0H@
M("`@("H*("`@("`J($!P87)A;2!I;G0@)&5R<FYO("!I9B!T:&4@97)R;W(@
M:7,@8F5I;F<@;6%N=6%L;'D@<F%I<V5D('!A<W,@80H@("`@("H@("`@("`@
M("`@("`@("`@("`@("!$0E]%4E)/4BH@8V]N<W1A;G0@:&5R92X@($EF('1H
M:7,@:7-N)W0@<&%S<V5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@('1H
M92!E<G)O<B!I;F9O<FUA=&EO;B!G871H97)E9"!F<F]M('1H92!$0DU3+@H@
M("`@("H*("`@("`J($!R971U<FX@;V)J96-T("!T:&4@1$)?17)R;W(@;V)J
M96-T"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G)A:7-E17)R;W(H
M*2P*("`@("`J("`@("`@1$)?<WEB87-E.CIE<G)O<DYA=&EV92@I+"!$0E]S
M>6)A<V4Z.F5R<F]R0V]D92@I"B`@("`@*B\*("`@(&9U;F-T:6]N('-Y8F%S
M95)A:7-E17)R;W(H)&5R<FYO(#T@;G5L;"D*("`@('L*("`@("`@("`D;F%T
M:79E(#T@)'1H:7,M/F5R<F]R3F%T:79E*"D["B`@("`@("`@:68@*"1E<G)N
M;R`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D97)R;F\@/2`D=&AI<RT^97)R
M;W)#;V1E*"1N871I=F4I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H)&5R<FYO+"!N=6QL+"!N=6QL+"!N=6QL+"`D;F%T
M:79E*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E<G)O<DYA=&EV
M92@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!$0DU3)R!N871I=F4@97)R
M;W(@;65S<V%G92!P<F]D=6-E9"!B>2!T:&4@;&%S="!Q=65R>0H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@1$)-4R<@97)R;W(@;65S<V%G
M90H@("`@("HO"B`@("!F=6YC=&EO;B!E<G)O<DYA=&EV92@I"B`@("!["B`@
M("`@("`@<F5T=7)N($!S>6)A<V5?9V5T7VQA<W1?;65S<V%G92@I.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5R<F]R0V]D92@I"@H@("`@+RHJ
M"B`@("`@*B!$971E<FUI;F5S(%!%05(Z.D1"(&5R<F]R(&-O9&4@9G)O;2!T
M:&4@9&%T86)A<V4G<R!T97AT(&5R<F]R(&UE<W-A9V4N"B`@("`@*@H@("`@
M("H@0'!A<F%M("!S=')I;F<@("1E<G)O<FUS9R`@97)R;W(@;65S<V%G92!R
M971U<FYE9"!F<F]M('1H92!D871A8F%S90H@("`@("H@0')E='5R;B!I;G1E
M9V5R("!A;B!E<G)O<B!N=6UB97(@9G)O;2!A($1"(&5R<F]R(&-O;G-T86YT
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R0V]D92@D97)R;W)M<V<I"B`@
M("!["B`@("`@("`@<W1A=&EC("1E<G)O<E]R96=E>'!S.PH@("`@("`@(&EF
M("@A:7-S970H)&5R<F]R7W)E9V5X<',I*2!["B`@("`@("`@("`@("1E<G)O
M<E]R96=E>'!S(#T@87)R87DH"B`@("`@("`@("`@("`@("`G+TEN8V]R<F5C
M="!S>6YT87@@;F5A<B\G"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)2
M3U)?4UE.5$%8+`H@("`@("`@("`@("`@("`@)R]>56YC;&]S960@<75O=&4@
M8F5F;W)E('1H92!C:&%R86-T97(@<W1R:6YG(%M<(EPG72XJ6UPB7"==7"XO
M)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27U-93E1!6"P*("`@
M("`@("`@("`@("`@("<O26UP;&EC:70@8V]N=F5R<VEO;B`H9G)O;2!D871A
M='EP97QO9B!.54U%4DE#('9A;'5E*2]I)PH@("`@("`@("`@("`@("`@("`@
M(#T^($1"7T524D]27TE.5D%,241?3E5-0D52+`H@("`@("`@("`@("`@("`@
M)R]#86YN;W0@9')O<"!T:&4@=&%B;&4@6UPB7"==+BM;7")<)UTL(&)E8V%U
M<V4@:70@9&]E<VY<)W0@97AI<W0@:6X@=&AE('-Y<W1E;2!C871A;&]G<UPN
M+R<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E].3U-50TA404),
M12P*("`@("`@("`@("`@("`@("<O3VYL>2!T:&4@;W=N97(@;V8@;V)J96-T
M(%M<(EPG72XK6UPB7"==(&]R(&$@=7-E<B!W:71H(%-Y<W1E;2!!9&UI;FES
M=')A=&]R(%PH4T%<*2!R;VQE(&-A;B!R=6X@=&AI<R!C;VUM86YD7"XO)PH@
M("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27T%#0T534U]624],051)
M3TXL"B`@("`@("`@("`@("`@("`G+UXN*R!P97)M:7-S:6]N(&1E;FEE9"!O
M;B!O8FIE8W0@+BLL(&1A=&%B87-E("XK+"!O=VYE<B`N*R\G"B`@("`@("`@
M("`@("`@("`@("`@/3X@1$)?15)23U)?04-#15-37U9)3TQ!5$E/3BP*("`@
M("`@("`@("`@("`@("<O7BXJ('!E<FUI<W-I;VX@9&5N:65D+"!D871A8F%S
M92`N*RP@;W=N97(@+BLO)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T52
M4D]27T%#0T534U]624],051)3TXL"B`@("`@("`@("`@("`@("`G+UM>+BI=
M(&YO="!F;W5N9%PN+R<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/
M4E].3U-50TA404),12P*("`@("`@("`@("`@("`@("<O5&AE<F4@:7,@86QR
M96%D>2!A;B!O8FIE8W0@;F%M960O)PH@("`@("`@("`@("`@("`@("`@(#T^
M($1"7T524D]27T%,4D5!1%E?15A)4U13+`H@("`@("`@("`@("`@("`@)R])
M;G9A;&ED(&-O;'5M;B!N86UE+R<*("`@("`@("`@("`@("`@("`@("`]/B!$
M0E]%4E)/4E].3U-50TA&245,1"P*("`@("`@("`@("`@("`@("<O9&]E<R!N
M;W0@86QL;W<@;G5L;"!V86QU97,O)PH@("`@("`@("`@("`@("`@("`@(#T^
M($1"7T524D]27T-/3E-44D%)3E1?3D]47TY53$PL"B`@("`@("`@("`@("`@
M("`G+T-O;6UA;F0@:&%S(&)E96X@86)O<G1E9"\G"B`@("`@("`@("`@("`@
M("`@("`@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("`@("`@("`@("`@
M("<O7D-A;FYO="!D<F]P('1H92!I;F1E>"`N*B!B96-A=7-E(&ET(&1O97-N
M7"=T(&5X:7-T+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?
M3D]47T9/54Y$+`H@("`@("`@("`@("`@("`@)R]>5&AE<F4@:7,@86QR96%D
M>2!A;B!I;F1E>"]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]2
M7T%,4D5!1%E?15A)4U13+`H@("`@("`@("`@("`@("`@)R]>5&AE<F4@87)E
M(&9E=V5R(&-O;'5M;G,@:6X@=&AE($E.4T525"!S=&%T96UE;G0@=&AA;B!V
M86QU97,@<W!E8VEF:65D+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?
M15)23U)?5D%,545?0T]53E1?3TY?4D]7+`H@("`@("`@("`@("`I.PH@("`@
M("`@('T*"B`@("`@("`@9F]R96%C:"`H)&5R<F]R7W)E9V5X<',@87,@)')E
M9V5X<"`]/B`D8V]D92D@>PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@D
M<F5G97AP+"`D97)R;W)M<V<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)&-O9&4["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M($1"7T524D]2.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('1A8FQE
M26YF;R@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&EN9F]R;6%T:6]N(&%B
M;W5T(&$@=&%B;&4@;W(@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@3D]4
M13H@;VYL>2!S=7!P;W)T<R`G=&%B;&4G(&%N9"`G9FQA9W,G(&EF(#QV87(^
M)')E<W5L=#PO=F%R/@H@("`@("H@:7,@82!T86)L92!N86UE+@H@("`@("H*
M("`@("`J($!P87)A;2!O8FIE8W1\<W1R:6YG("`D<F5S=6QT("!$0E]R97-U
M;'0@;V)J96-T(&9R;VT@82!Q=65R>2!O<B!A"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('-T<FEN9R!C;VYT86EN:6YG('1H92!N
M86UE(&]F(&$@=&%B;&4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%=H:6QE('1H:7,@86QS;R!A8V-E<'1S(&$@<75E<GD@<F5S
M=6QT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E
M<V]U<F-E(&ED96YT:69I97(L('1H:7,@8F5H879I;W(@:7,*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9&5P<F5C871E9"X*("`@
M("`J($!P87)A;2!I;G0@("`@("`@("`@("`D;6]D92`@("!A('9A;&ED('1A
M8FQE26YF;R!M;V1E"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@86X@
M87-S;V-I871I=F4@87)R87D@=VET:"!T:&4@:6YF;W)M871I;VX@<F5Q=65S
M=&5D+@H@("`@("H@("`@("`@("`@("`@("`@($$@1$)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G1A
M8FQE26YF;R@I"B`@("`@*B!`<VEN8V4@365T:&]D(&%V86EL86)L92!S:6YC
M92!296QE87-E(#$N-BXP"B`@("`@*B\*("`@(&9U;F-T:6]N('1A8FQE26YF
M;R@D<F5S=6QT+"`D;6]D92`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES
M7W-T<FEN9R@D<F5S=6QT*2D@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@
M("`@*B!0<F]B86)L>2!R96-E:79E9"!A('1A8FQE(&YA;64N"B`@("`@("`@
M("`@("`J($-R96%T92!A(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@
M("`@("`@("`@("`@*B\*("`@("`@("`@("`@:68@*"%`<WEB87-E7W-E;&5C
M=%]D8B@D=&AI<RT^7V1B+"`D=&AI<RT^8V]N;F5C=&EO;BDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<WEB87-E4F%I<V5%<G)O<BA$0E]%
M4E)/4E].3T1"4T5,14-4140I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1I9"`]($!S>6)A<V5?<75E<GDH(E-%3$5#5"`J($923TT@)')E<W5L="!7
M2$5212`Q/3`B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@)&=O=%]S=')I;F<@/2!T
M<G5E.PH@("`@("`@('T@96QS96EF("AI<W-E="@D<F5S=6QT+3YR97-U;'0I
M*2!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY(')E
M8V5I=F5D(&$@<F5S=6QT(&]B:F5C="X*("`@("`@("`@("`@("H@17AT<F%C
M="!T:&4@<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@("`@("`@
M("`J+PH@("`@("`@("`@("`D:60@/2`D<F5S=6QT+3YR97-U;'0["B`@("`@
M("`@("`@("1G;W1?<W1R:6YG(#T@9F%L<V4["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@4')O8F%B;'D@<F5C96EV
M960@82!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@("`@("`@
M("H@0V]P>2!I="X*("`@("`@("`@("`@("H@1&5P<F5C871E9"X@($AE<F4@
M9F]R(&-O;7!A=&EB:6QI='D@;VYL>2X*("`@("`@("`@("`@("HO"B`@("`@
M("`@("`@("1I9"`]("1R97-U;'0["B`@("`@("`@("`@("1G;W1?<W1R:6YG
M(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E
M*"1I9"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS>6)A<V5286ES
M945R<F]R*$1"7T524D]27TY%141?34]215]$051!*3L*("`@("`@("!]"@H@
M("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"
M7U!/4E1!0DE,25197TQ/5T520T%312D@>PH@("`@("`@("`@("`D8V%S95]F
M=6YC(#T@)W-T<G1O;&]W97(G.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1C87-E7V9U;F,@/2`G<W1R=F%L)SL*("`@("`@("!]"@H@("`@("`@
M("1C;W5N="`]($!S>6)A<V5?;G5M7V9I96QD<R@D:60I.PH@("`@("`@("1R
M97,@("`](&%R<F%Y*"D["@H@("`@("`@(&EF("@D;6]D92D@>PH@("`@("`@
M("`@("`D<F5S6R=N=6U?9FEE;&1S)UT@/2`D8V]U;G0["B`@("`@("`@?0H*
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8V]U;G0[("1I*RLI('L*("`@
M("`@("`@("`@)&8@/2!`<WEB87-E7V9E=&-H7V9I96QD*"1I9"P@)&DI.PH@
M("`@("`@("`@("`O+R!C;VQU;6Y?<V]U<F-E(&ES(&]F=&5N(&)L86YK"B`@
M("`@("`@("`@("1R97-;)&E=(#T@87)R87DH"B`@("`@("`@("`@("`@("`G
M=&%B;&4G(#T^("1G;W1?<W1R:6YG"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#\@)&-A<V5?9G5N8R@D<F5S=6QT*0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`Z("1C87-E7V9U;F,H)&8M/F-O;'5M;E]S;W5R8V4I+`H@("`@
M("`@("`@("`@("`@)VYA;64G("`]/B`D8V%S95]F=6YC*"1F+3YN86UE*2P*
M("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)&8M/G1Y<&4L"B`@("`@("`@
M("`@("`@("`G;&5N)R`@(#T^("1F+3YM87A?;&5N9W1H+`H@("`@("`@("`@
M("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`@("`@*3L*("`@("`@("`@
M("`@:68@*"1R97-;)&E=6R=T86)L92==*2!["B`@("`@("`@("`@("`@("`D
M<F5S6R1I75LG9FQA9W,G72`]("1T:&ES+3Y?<WEB87-E7V9I96QD7V9L86=S
M*`H@("`@("`@("`@("`@("`@("`@("`@("`D<F5S6R1I75LG=&%B;&4G72P@
M)')E<ULD:5U;)VYA;64G72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/7T]21$52*2!["B`@("`@("`@("`@
M("`@("`D<F5S6R=O<F1E<B==6R1R97-;)&E=6R=N86UE)UU=(#T@)&D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"3$5)
M3D9/7T]21$525$%"3$4I('L*("`@("`@("`@("`@("`@("1R97-;)V]R9&5R
M=&%B;&4G75LD<F5S6R1I75LG=&%B;&4G75U;)')E<ULD:5U;)VYA;64G75T@
M/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@9G)E
M92!T:&4@<F5S=6QT(&]N;'D@:68@=V4@=V5R92!C86QL960@;VX@82!T86)L
M90H@("`@("`@(&EF("@D9V]T7W-T<FEN9RD@>PH@("`@("`@("`@("!`<WEB
M87-E7V9R965?<F5S=6QT*"1I9"D["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D<F5S.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(%]S>6)A<V5?
M9FEE;&1?9FQA9W,H*0H*("`@("\J*@H@("`@("H@1V5T('1H92!F;&%G<R!F
M;W(@82!F:65L9`H@("`@("H*("`@("`J($-U<G)E;G1L>2!S=7!P;W)T<SH*
M("`@("`J("`K(#QS86UP/G5N:7%U95]K97D\+W-A;7`^("`@("AU;FEQ=64@
M:6YD97@L('5N:7%U92!C:&5C:R!O<B!P<FEM87)Y7VME>2D*("`@("`J("`K
M(#QS86UP/FUU;'1I<&QE7VME>3PO<V%M<#X@("AM=6QT:2UK97D@:6YD97@I
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'1A8FQE("`@=&AE('1A
M8FQE(&YA;64*("`@("`J($!P87)A;2!S=')I;F<@("1C;VQU;6X@('1H92!F
M:65L9"!N86UE"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('-P86-E
M(&1E;&EM:71E9"!S=')I;F<@;V8@9FQA9W,N("!%;7!T>2!S=')I;F<@:68@
M;F]N92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@9G5N8W1I;VX@7W-Y8F%S95]F:65L9%]F;&%G<R@D=&%B;&4L("1C;VQU
M;6XI"B`@("!["B`@("`@("`@<W1A=&EC("1T86)L94YA;64@/2!N=6QL.PH@
M("`@("`@('-T871I8R`D9FQA9W,@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H
M)'1A8FQE("$]("1T86)L94YA;64I('L*("`@("`@("`@("`@)&9L86=S(#T@
M87)R87DH*3L*("`@("`@("`@("`@)'1A8FQE3F%M92`]("1T86)L93L*"B`@
M("`@("`@("`@("\O(&=E="!U;FEQ=64O<')I;6%R>2!K97ES"B`@("`@("`@
M("`@("1R97,@/2`D=&AI<RT^9V5T06QL*")S<%]H96QP:6YD97@@)'1A8FQE
M(BP@1$)?1D540TA-3T1%7T%34T]#*3L*"B`@("`@("`@("`@(&EF("@A:7-S
M970H)')E<ULP75LG:6YD97A?9&5S8W)I<'1I;VXG72DI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`G)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M9F]R96%C:"`H)')E<R!A<R`D=F%L*2!["B`@("`@("`@("`@("`@("`D:V5Y
M<R`](&5X<&QO9&4H)RP@)RP@=')I;2@D=F%L6R=I;F1E>%]K97ES)UTI*3L*
M"B`@("`@("`@("`@("`@("!I9B`H<VEZ96]F*"1K97ES*2`^(#$I('L*("`@
M("`@("`@("`@("`@("`@("!F;W)E86-H("@D:V5Y<R!A<R`D:V5Y*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861D7V9L86<H)&9L86=S
M6R1K97E=+"`G;75L=&EP;&5?:V5Y)RD["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("AS=')P
M;W,H)'9A;%LG:6YD97A?9&5S8W)I<'1I;VXG72P@)W5N:7%U92<I*2!["B`@
M("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&ME>7,@87,@)&ME>2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9%]F;&%G*"1F;&%G
M<ULD:V5Y72P@)W5N:7%U95]K97DG*3L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@?0H*
M("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@D8V]L=6UN+"`D9FQA9W,I
M*2!["B`@("`@("`@("`@(')E='5R;BAI;7!L;V1E*"<@)RP@)&9L86=S6R1C
M;VQU;6Y=*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)R<["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@7V%D9%]F;&%G*"D*"B`@("`O*BH*
M("`@("`J($%D9',@82!S=')I;F<@=&\@=&AE(&9L86=S(&%R<F%Y(&EF('1H
M92!F;&%G(&ES(&YO="!Y970@:6X@=&AE<F4*("`@("`J("T@:68@=&AE<F4@
M:7,@;F\@9FQA9R!P<F5S96YT('1H92!A<G)A>2!I<R!C<F5A=&5D"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("`D87)R87D@(')E9F5R96YC92!O9B!F
M;&%G<R!A<G)A>2!T;R!A9&0@82!V86QU92!T;PH@("`@("H@0'!A<F%M(&UI
M>&5D("`D=F%L=64@('9A;'5E('1O(&%D9"!T;R!T:&4@9FQA9R!A<G)A>0H@
M("`@("H*("`@("`J($!R971U<FX@=F]I9`H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?861D7V9L86<H)B1A
M<G)A>2P@)'9A;'5E*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)&%R
M<F%Y*2D@>PH@("`@("`@("`@("`D87)R87D@/2!A<G)A>2@D=F%L=64I.PH@
M("`@("`@('T@96QS96EF("@A:6Y?87)R87DH)'9A;'5E+"`D87)R87DI*2![
M"B`@("`@("`@("`@(&%R<F%Y7W!U<V@H)&%R<F%Y+"`D=F%L=64I.PH@("`@
M("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G9713<&5C:6%L
M475E<GDH*0H*("`@("\J*@H@("`@("H@3V)T86EN<R!T:&4@<75E<GD@<W1R
M:6YG(&YE961E9"!F;W(@;&ES=&EN9R!A(&=I=F5N('1Y<&4@;V8@;V)J96-T
M<PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@('1H92!K:6YD
M(&]F(&]B:F5C=',@>6]U('=A;G0@=&\@<F5T<FEE=F4*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@=&AE(%-13"!Q=65R>2!S=')I;F<@;W(@;G5L
M;"!I9B!T:&4@9')I=F5R(&1O97-N)W0*("`@("`J("`@("`@("`@("`@("`@
M("`@<W5P<&]R="!T:&4@;V)J96-T('1Y<&4@<F5Q=65S=&5D"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J($!S964@1$)?8V]M;6]N
M.CIG971,:7-T3V8H*0H@("`@("HO"B`@("!F=6YC=&EO;B!G9713<&5C:6%L
M475E<GDH)'1Y<&4I"B`@("!["B`@("`@("`@<W=I=&-H("@D='EP92D@>PH@
M("`@("`@("`@("!C87-E("=T86)L97,G.@H@("`@("`@("`@("`@("`@<F5T
M=7)N(")314Q%0U0@;F%M92!&4D]-('-Y<V]B:F5C=',@5TA%4D4@='EP92`]
M("=5)R(*("`@("`@("`@("`@("`@("`@("`@("`N("<@3U)$15(@0ED@;F%M
M92<["B`@("`@("`@("`@(&-A<V4@)W9I97=S)SH*("`@("`@("`@("`@("`@
M(')E='5R;B`B4T5,14-4(&YA;64@1E)/32!S>7-O8FIE8W1S(%=(15)%('1Y
M<&4@/2`G5B<B.PH@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@
M("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H*
M?0H*+RH*("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@
M8RUB87-I8RUO9F9S970Z(#0*("H@16YD.@H@*B\*"C\^"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O1$(N<&AP````````````````````````````````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`Q,30P,S$`,3`U,34T,S,W-#,`,#$W-C`R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"@HO*B!V
M:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T
M=&%B<W1O<#TT.B`J+PH*+RHJ"B`J($1A=&%B87-E(&EN9&5P96YD96YT('%U
M97)Y(&EN=&5R9F%C90H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@
M*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R
M<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA
M8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I
M;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(
M4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*
M("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*
M("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@H@*B!`
M875T:&]R("`@("!4;VUA<R!6+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^"B`J
M($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE
M=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!$
M0BYP:'`L=B`Q+C@P(#(P,#4O,#(O,38@,#(Z,38Z,#`@9&%N:65L8R!%>'`@
M)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M1$(*("HO"@HO*BH*("H@3V)T86EN('1H92!014%2(&-L87-S('-O(&ET(&-A
M;B!B92!E>'1E;F1E9"!F<F]M"B`J+PIR97%U:7)E7V]N8V4@)U!%05(N<&AP
M)SL*"@HO+R![>WL@8V]N<W1A;G1S"B\O('M[>R!E<G)O<B!C;V1E<PH*+RHJ
M(T`K"B`J($]N92!O9B!014%2($1")W,@<&]R=&%B;&4@97)R;W(@8V]D97,N
M"B`J($!S964@1$)?8V]M;6]N.CIE<G)O<D-O9&4H*2P@1$(Z.F5R<F]R365S
M<V%G92@I"B`J"B`J('M`:6YT97)N86P@268@>6]U(&%D9"!A;B!E<G)O<B!C
M;V1E(&AE<F4L(&UA:V4@<W5R92!Y;W4@86QS;R!A9&0@82!T97AT=6%L"B`J
M('9E<G-I;VX@;V8@:70@:6X@1$(Z.F5R<F]R365S<V%G92@I+GU]"B`J+PH*
M+RHJ"B`J(%1H92!C;V1E(')E='5R;F5D(&)Y(&UA;GD@;65T:&]D<R!U<&]N
M('-U8V-E<W,*("HO"F1E9FEN92@G1$)?3TLG+"`Q*3L*"B\J*@H@*B!5;FMO
M=VX@97)R;W(*("HO"F1E9FEN92@G1$)?15)23U(G+"`M,2D["@HO*BH*("H@
M4WEN=&%X(&5R<F]R"B`J+PID969I;F4H)T1"7T524D]27U-93E1!6"<L("TR
M*3L*"B\J*@H@*B!4<FEE9"!T;R!I;G-E<G0@82!D=7!L:6-A=&4@=F%L=64@
M:6YT;R!A('!R:6UA<GD@;W(@=6YI<75E(&EN9&5X"B`J+PID969I;F4H)T1"
M7T524D]27T-/3E-44D%)3E0G+"`M,RD["@HO*BH*("H@06X@:61E;G1I9FEE
M<B!I;B!T:&4@<75E<GD@<F5F97)S('1O(&$@;F]N+65X:7-T86YT(&]B:F5C
M=`H@*B\*9&5F:6YE*"=$0E]%4E)/4E].3U1?1D]53D0G+"`M-"D["@HO*BH*
M("H@5')I960@=&\@8W)E871E(&$@9'5P;&EC871E(&]B:F5C=`H@*B\*9&5F
M:6YE*"=$0E]%4E)/4E]!3%)%04197T5825-44R<L("TU*3L*"B\J*@H@*B!4
M:&4@8W5R<F5N="!D<FEV97(@9&]E<R!N;W0@<W5P<&]R="!T:&4@86-T:6]N
M('EO=2!A='1E;7!T960*("HO"F1E9FEN92@G1$)?15)23U)?54Y355!03U)4
M140G+"`M-BD["@HO*BH*("H@5&AE(&YU;6)E<B!O9B!P87)A;65T97)S(&1O
M97,@;F]T(&UA=&-H('1H92!N=6UB97(@;V8@<&QA8V5H;VQD97)S"B`J+PID
M969I;F4H)T1"7T524D]27TU)4TU!5$-()RP@+3<I.PH*+RHJ"B`J($$@;&ET
M97)A;"!S=6)M:71T960@9&ED(&YO="!M871C:"!T:&4@9&%T82!T>7!E(&5X
M<&5C=&5D"B`J+PID969I;F4H)T1"7T524D]27TE.5D%,240G+"`M."D["@HO
M*BH*("H@5&AE(&-U<G)E;G0@1$)-4R!D;V5S(&YO="!S=7!P;W)T('1H92!A
M8W1I;VX@>6]U(&%T=&5M<'1E9`H@*B\*9&5F:6YE*"=$0E]%4E)/4E].3U1?
M0T%004),12<L("TY*3L*"B\J*@H@*B!!(&QI=&5R86P@<W5B;6ET=&5D('=A
M<R!T;V\@;&]N9R!S;R!T:&4@96YD(&]F(&ET('=A<R!R96UO=F5D"B`J+PID
M969I;F4H)T1"7T524D]27U1254Y#051%1"<L("TQ,"D["@HO*BH*("H@02!L
M:71E<F%L(&YU;6)E<B!S=6)M:71T960@9&ED(&YO="!M871C:"!T:&4@9&%T
M82!T>7!E(&5X<&5C=&5D"B`J+PID969I;F4H)T1"7T524D]27TE.5D%,241?
M3E5-0D52)RP@+3$Q*3L*"B\J*@H@*B!!(&QI=&5R86P@9&%T92!S=6)M:71T
M960@9&ED(&YO="!M871C:"!T:&4@9&%T82!T>7!E(&5X<&5C=&5D"B`J+PID
M969I;F4H)T1"7T524D]27TE.5D%,241?1$%412<L("TQ,BD["@HO*BH*("H@
M071T96UP="!T;R!D:79I9&4@<V]M971H:6YG(&)Y('IE<F\*("HO"F1E9FEN
M92@G1$)?15)23U)?1$E66D523R<L("TQ,RD["@HO*BH*("H@02!D871A8F%S
M92!N965D<R!T;R!B92!S96QE8W1E9`H@*B\*9&5F:6YE*"=$0E]%4E)/4E].
M3T1"4T5,14-4140G+"`M,30I.PH*+RHJ"B`J($-O=6QD(&YO="!C<F5A=&4@
M=&AE(&]B:F5C="!R97%U97-T960*("HO"F1E9FEN92@G1$)?15)23U)?0T%.
M3D]47T-214%412<L("TQ-2D["@HO*BH*("H@0V]U;&0@;F]T(&1R;W`@=&AE
M(&1A=&%B87-E(')E<75E<W1E9"!B96-A=7-E(&ET(&1O97,@;F]T(&5X:7-T
M"B`J+PID969I;F4H)T1"7T524D]27T-!3DY/5%]$4D]0)RP@+3$W*3L*"B\J
M*@H@*B!!;B!I9&5N=&EF:65R(&EN('1H92!Q=65R>2!R969E<G,@=&\@82!N
M;VXM97AI<W1A;G0@=&%B;&4*("HO"F1E9FEN92@G1$)?15)23U)?3D]354-(
M5$%"3$4G+"`M,3@I.PH*+RHJ"B`J($%N(&ED96YT:69I97(@:6X@=&AE('%U
M97)Y(')E9F5R<R!T;R!A(&YO;BUE>&ES=&%N="!C;VQU;6X*("HO"F1E9FEN
M92@G1$)?15)23U)?3D]354-(1DE%3$0G+"`M,3DI.PH*+RHJ"B`J(%1H92!D
M871A('-U8FUI='1E9"!T;R!T:&4@;65T:&]D('=A<R!I;F%P<')O<')I871E
M"B`J+PID969I;F4H)T1"7T524D]27TY%141?34]215]$051!)RP@+3(P*3L*
M"B\J*@H@*B!4:&4@871T96UP="!T;R!L;V-K('1H92!T86)L92!F86EL960*
M("HO"F1E9FEN92@G1$)?15)23U)?3D]47TQ/0TM%1"<L("TR,2D["@HO*BH*
M("H@5&AE(&YU;6)E<B!O9B!C;VQU;6YS(&1O97-N)W0@;6%T8V@@=&AE(&YU
M;6)E<B!O9B!V86QU97,*("HO"F1E9FEN92@G1$)?15)23U)?5D%,545?0T]5
M3E1?3TY?4D]7)RP@+3(R*3L*"B\J*@H@*B!4:&4@1%-.('-U8FUI='1E9"!H
M87,@<')O8FQE;7,*("HO"F1E9FEN92@G1$)?15)23U)?24Y604Q)1%]$4TXG
M+"`M,C,I.PH*+RHJ"B`J($-O=6QD(&YO="!C;VYN96-T('1O('1H92!D871A
M8F%S90H@*B\*9&5F:6YE*"=$0E]%4E)/4E]#3TY.14-47T9!24Q%1"<L("TR
M-"D["@HO*BH*("H@5&AE(%!(4"!E>'1E;G-I;VX@;F5E9&5D(&9O<B!T:&ES
M($1"35,@8V]U;&0@;F]T(&)E(&9O=6YD"B`J+PID969I;F4H)T1"7T524D]2
M7T585$5.4TE/3E].3U1?1D]53D0G+"TR-2D["@HO*BH*("H@5&AE('!R97-E
M;G0@=7-E<B!H87,@:6YA9&5Q=6%T92!P97)M:7-S:6]N<R!T;R!P97)F;W)M
M('1H92!T87-K(')E<75E<W1D"B`J+PID969I;F4H)T1"7T524D]27T%#0T53
M4U]624],051)3TXG+"`M,C8I.PH*+RHJ"B`J(%1H92!D871A8F%S92!R97%U
M97-T960@9&]E<R!N;W0@97AI<W0*("HO"F1E9FEN92@G1$)?15)23U)?3D]3
M54-(1$(G+"`M,C<I.PH*+RHJ"B`J(%1R:65D('1O(&EN<V5R="!A(&YU;&P@
M=F%L=64@:6YT;R!A(&-O;'5M;B!T:&%T(&1O97-N)W0@86QL;W<@;G5L;',*
M("HO"F1E9FEN92@G1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3"<L+3(Y
M*3L*+RHJ(T`M*B\*"@HO+R!]?7T*+R\@>WM[('!R97!A<F5D('-T871E;65N
M="UR96QA=&5D"@H*+RHJ(T`K"B`J($ED96YT:69I97)S(&9O<B!T:&4@<&QA
M8V5H;VQD97)S('5S960@:6X@<')E<&%R960@<W1A=&5M96YT<RX*("H@0'-E
M92!$0E]C;VUM;VXZ.G!R97!A<F4H*0H@*B\*"B\J*@H@*B!);F1I8V%T97,@
M82!S8V%L87(@*#QK8F0^/SPO:V)D/BD@<&QA8V5H;VQD97(@=V%S('5S960*
M("H*("H@475O=&4@86YD(&5S8V%P92!T:&4@=F%L=64@87,@;F5C97-S87)Y
M+@H@*B\*9&5F:6YE*"=$0E]005)!35]30T%,05(G+"`Q*3L*"B\J*@H@*B!)
M;F1I8V%T97,@86X@;W!A<75E("@\:V)D/B8\+VMB9#XI('!L86-E:&]L9&5R
M('=A<R!U<V5D"B`J"B`J(%1H92!V86QU92!P<F5S96YT960@:7,@82!F:6QE
M(&YA;64N("!%>'1R86-T('1H92!C;VYT96YT<R!O9B!T:&%T(&9I;&4*("H@
M86YD('!L86-E('1H96T@:6X@=&AI<R!C;VQU;6XN"B`J+PID969I;F4H)T1"
M7U!!4D%-7T]005%512<L(#(I.PH*+RHJ"B`J($EN9&EC871E<R!A(&UI<V,@
M*#QK8F0^(3PO:V)D/BD@<&QA8V5H;VQD97(@=V%S('5S960*("H*("H@5&AE
M('9A;'5E('-H;W5L9"!N;W0@8F4@<75O=&5D(&]R(&5S8V%P960N"B`J+PID
M969I;F4H)T1"7U!!4D%-7TU)4T,G+"`@(#,I.PHO*BHC0"TJ+PH*"B\O('U]
M?0HO+R![>WL@8FEN87)Y(&1A=&$M<F5L871E9`H*"B\J*B-`*PH@*B!4:&4@
M9&EF9F5R96YT('=A>7,@;V8@<F5T=7)N:6YG(&)I;F%R>2!D871A(&9R;VT@
M<75E<FEE<RX*("HO"@HO*BH*("H@4V5N9',@=&AE(&9E=&-H960@9&%T82!S
M=')A:6=H="!T:')O=6=H('1O(&]U='!U=`H@*B\*9&5F:6YE*"=$0E]"24Y-
M3T1%7U!!4U-42%)5)RP@,2D["@HO*BH*("H@3&5T<R!Y;W4@<F5T=7)N(&1A
M=&$@87,@=7-U86P*("HO"F1E9FEN92@G1$)?0DE.34]$15]215154DXG+"`R
M*3L*"B\J*@H@*B!#;VYV97)T<R!T:&4@9&%T82!T;R!H97@@9F]R;6%T(&)E
M9F]R92!R971U<FYI;F<@:70*("H*("H@1F]R(&5X86UP;&4@=&AE('-T<FEN
M9R`B,3(S(B!W;W5L9"!B96-O;64@(C,Q,S(S,R(N"B`J+PID969I;F4H)T1"
M7T))3DU/1$5?0T].5D525"<L(#,I.PHO*BHC0"TJ+PH*"B\O('U]?0HO+R![
M>WL@9F5T8V@@;6]D97,*"@HO*BHC0"L*("H@1F5T8V@@36]D97,N"B`J($!S
M964@1$)?8V]M;6]N.CIS971&971C:$UO9&4H*0H@*B\*"B\J*@H@*B!);F1I
M8V%T97,@=&AE(&-U<G)E;G0@9&5F875L="!F971C:"!M;V1E('-H;W5L9"!B
M92!U<V5D"B`J($!S964@1$)?8V]M;6]N.CHD9F5T8VAM;V1E"B`J+PID969I
M;F4H)T1"7T9%5$-(34]$15]$149!54Q4)RP@,"D["@HO*BH*("H@0V]L=6UN
M(&1A=&$@:6YD97AE9"!B>2!N=6UB97)S+"!O<F1E<F5D(&9R;VT@,"!A;F0@
M=7`*("HO"F1E9FEN92@G1$)?1D540TA-3T1%7T]21$52140G+"`Q*3L*"B\J
M*@H@*B!#;VQU;6X@9&%T82!I;F1E>&5D(&)Y(&-O;'5M;B!N86UE<PH@*B\*
M9&5F:6YE*"=$0E]&151#2$U/1$5?05-33T,G+"`R*3L*"B\J*@H@*B!#;VQU
M;6X@9&%T82!A<R!O8FIE8W0@<')O<&5R=&EE<PH@*B\*9&5F:6YE*"=$0E]&
M151#2$U/1$5?3T)*14-4)RP@,RD["@HO*BH*("H@1F]R(&UU;'1I+61I;65N
M<VEO;F%L(')E<W5L=',L(&UA:V4@=&AE(&-O;'5M;B!N86UE('1H92!F:7)S
M="!L979E;`H@*B!O9B!T:&4@87)R87D@86YD('!U="!T:&4@<F]W(&YU;6)E
M<B!I;B!T:&4@<V5C;VYD(&QE=F5L(&]F('1H92!A<G)A>0H@*@H@*B!4:&ES
M(&ES(&9L:7!P960@9G)O;2!T:&4@;F]R;6%L(&)E:&%V:6]R+"!W:&EC:"!P
M=71S('1H92!R;W<@;G5M8F5R<PH@*B!I;B!T:&4@9FER<W0@;&5V96P@;V8@
M=&AE(&%R<F%Y(&%N9"!T:&4@8V]L=6UN(&YA;65S(&EN('1H92!S96-O;F0@
M;&5V96PN"B`J+PID969I;F4H)T1"7T9%5$-(34]$15]&3$E04$5$)RP@-"D[
M"B\J*B-`+2HO"@HO*BHC0"L*("H@3VQD(&9E=&-H(&UO9&5S+B`@3&5F="!H
M97)E(&9O<B!C;VUP871I8FEL:71Y+@H@*B\*9&5F:6YE*"=$0E]'151-3T1%
M7T]21$52140G+"!$0E]&151#2$U/1$5?3U)$15)%1"D["F1E9FEN92@G1$)?
M1T5434]$15]!4U-/0R<L("`@1$)?1D540TA-3T1%7T%34T]#*3L*9&5F:6YE
M*"=$0E]'151-3T1%7T9,25!0140G+"!$0E]&151#2$U/1$5?1DQ)4%!%1"D[
M"B\J*B-`+2HO"@H*+R\@?7U]"B\O('M[>R!T86)L94EN9F\H*2`F)B!A=71O
M4')E<&%R92@I+7)E;&%T960*"@HO*BHC0"L*("H@5&AE('1Y<&4@;V8@:6YF
M;W)M871I;VX@=&\@<F5T=7)N(&9R;VT@=&AE('1A8FQE26YF;R@I(&UE=&AO
M9"X*("H*("H@0FET=VES960@8V]N<W1A;G1S+"!S;R!T:&5Y(&-A;B!B92!C
M;VUB:6YE9"!U<VEN9R`\:V)D/GP\+VMB9#X*("H@86YD(')E;6]V960@=7-I
M;F<@/&MB9#Y>/"]K8F0^+@H@*@H@*B!`<V5E($1"7V-O;6UO;CHZ=&%B;&5)
M;F9O*"D*("H*("H@>T!I;G1E<FYA;"!3:6YC92!T:&4@5$%"3$5)3D9/(&-O
M;G-T86YT<R!A<F4@8FET=VES960L(&EF(&UO<F4@;V8@=&AE;2!A<F4*("H@
M861D960@:6X@=&AE(&9U='5R92P@;6%K92!S=7)E('1O(&%D:G5S="!$0E]4
M04),14E.1D]?1E5,3"!A8V-O<F1I;F=L>2Y]?0H@*B\*9&5F:6YE*"=$0E]4
M04),14E.1D]?3U)$15(G+"`Q*3L*9&5F:6YE*"=$0E]404),14E.1D]?3U)$
M15)404),12<L(#(I.PID969I;F4H)T1"7U1!0DQ%24Y&3U]&54Q,)RP@,RD[
M"B\J*B-`+2HO"@H*+RHJ(T`K"B`J(%1H92!T>7!E(&]F('%U97)Y('1O(&-R
M96%T92!W:71H('1H92!A=71O;6%T:6,@<75E<GD@8G5I;&1I;F<@;65T:&]D
M<RX*("H@0'-E92!$0E]C;VUM;VXZ.F%U=&]0<F5P87)E*"DL($1"7V-O;6UO
M;CHZ875T;T5X96-U=&4H*0H@*B\*9&5F:6YE*"=$0E]!551/455%4EE?24Y3
M15)4)RP@,2D["F1E9FEN92@G1$)?05543U%515)97U501$%412<L(#(I.PHO
M*BHC0"TJ+PH*"B\O('U]?0HO+R![>WL@<&]R=&%B:6QI='D@;6]D97,*"@HO
M*BHC0"L*("H@4&]R=&%B:6QI='D@36]D97,N"B`J"B`J($)I='=I<V5D(&-O
M;G-T86YT<RP@<V\@=&AE>2!C86X@8F4@8V]M8FEN960@=7-I;F<@/&MB9#Y\
M/"]K8F0^"B`J(&%N9"!R96UO=F5D('5S:6YG(#QK8F0^7CPO:V)D/BX*("H*
M("H@0'-E92!$0E]C;VUM;VXZ.G-E=$]P=&EO;B@I"B`J"B`J('M`:6YT97)N
M86P@4VEN8V4@=&AE(%!/4E1!0DE,2519(&-O;G-T86YT<R!A<F4@8FET=VES
M960L(&EF(&UO<F4@;V8@=&AE;2!A<F4*("H@861D960@:6X@=&AE(&9U='5R
M92P@;6%K92!S=7)E('1O(&%D:G5S="!$0E]03U)404))3$E465]!3$P@86-C
M;W)D:6YG;'DN?7T*("HO"@HO*BH*("H@5'5R;B!O9F8@86QL('!O<G1A8FEL
M:71Y(&9E871U<F5S"B`J+PID969I;F4H)T1"7U!/4E1!0DE,25197TY/3D4G
M+"`P*3L*"B\J*@H@*B!#;VYV97)T(&YA;65S(&]F('1A8FQE<R!A;F0@9FEE
M;&1S('1O(&QO=V5R(&-A<V4*("H@=VAE;B!U<VEN9R!T:&4@9V5T*B@I+"!F
M971C:"HH*2!A;F0@=&%B;&5);F9O*"D@;65T:&]D<PH@*B\*9&5F:6YE*"=$
M0E]03U)404))3$E465],3U=%4D-!4T4G+"`Q*3L*"B\J*@H@*B!2:6=H="!T
M<FEM('1H92!D871A(&]U='!U="!B>2!G970J*"D@86YD(&9E=&-H*B@I"B`J
M+PID969I;F4H)T1"7U!/4E1!0DE,25197U)44DE-)RP@,BD["@HO*BH*("H@
M1F]R8V4@<F5P;W)T:6YG('1H92!N=6UB97(@;V8@<F]W<R!D96QE=&5D"B`J
M+PID969I;F4H)T1"7U!/4E1!0DE,25197T1%3$5415]#3U5.5"<L(#0I.PH*
M+RHJ"B`J($5N86)L92!H86-K('1H870@;6%K97,@;G5M4F]W<R@I('=O<FL@
M:6X@3W)A8VQE"B`J+PID969I;F4H)T1"7U!/4E1!0DE,25197TY535)/5U,G
M+"`X*3L*"B\J*@H@*B!-86ME<R!C97)T86EN(&5R<F]R(&UE<W-A9V5S(&EN
M(&-E<G1A:6X@9')I=F5R<R!C;VUP871I8FQE"B`J('=I=&@@=&AO<V4@9G)O
M;2!O=&AE<B!$0DU3)W,*("H*("H@*R!M>7-Q;"P@;7ES<6QI.B`@8VAA;F=E
M('5N:7%U92]P<FEM87)Y(&ME>2!C;VYS=')A:6YT<PH@*B`@($1"7T524D]2
M7T%,4D5!1%E?15A)4U13("T^($1"7T524D]27T-/3E-44D%)3E0*("H*("H@
M*R!O9&)C*&%C8V5S<RDZ("!-4R=S($]$0D,@9')I=F5R(')E<&]R=',@)VYO
M('-U8V@@9FEE;&0G(&%S(&-O9&4*("H@("`P-S`P,2P@=VAI8V@@;65A;G,@
M)W1O;R!F97<@<&%R86UE=&5R<RXG("!7:&5N('1H:7,@;W!T:6]N(&ES(&]N
M"B`J("`@=&AA="!C;V1E(&=E=',@;6%P<&5D('1O($1"7T524D]27TY/4U5#
M2$9)14Q$+@H@*B\*9&5F:6YE*"=$0E]03U)404))3$E465]%4E)/4E,G+"`Q
M-BD["@HO*BH*("H@0V]N=F5R="!N=6QL('9A;'5E<R!T;R!E;7!T>2!S=')I
M;F=S(&EN(&1A=&$@;W5T<'5T(&)Y"B`J(&=E="HH*2!A;F0@9F5T8V@J*"D*
M("HO"F1E9FEN92@G1$)?4$]25$%"24Q)5%E?3E5,3%]43U]%35!462<L(#,R
M*3L*"B\J*@H@*B!4=7)N(&]N(&%L;"!P;W)T86)I;&ET>2!F96%T=7)E<PH@
M*B\*9&5F:6YE*"=$0E]03U)404))3$E465]!3$PG+"`V,RD["B\J*B-`+2HO
M"@HO+R!]?7T*"@HO+R!]?7T*+R\@>WM[(&-L87-S($1""@HO*BH*("H@1&%T
M86)A<V4@:6YD97!E;F1E;G0@<75E<GD@:6YT97)F86-E"B`J"B`J(%1H92!M
M86EN(")$0B(@8VQA<W,@:7,@<VEM<&QY(&$@8V]N=&%I;F5R(&-L87-S('=I
M=&@@<V]M92!S=&%T:6,*("H@;65T:&]D<R!F;W(@8W)E871I;F<@1$(@;V)J
M96-T<R!A<R!W96QL(&%S('-O;64@=71I;&ET>2!F=6YC=&EO;G,*("H@8V]M
M;6]N('1O(&%L;"!P87)T<R!O9B!$0BX*("H*("H@5&AE(&]B:F5C="!M;V1E
M;"!O9B!$0B!I<R!A<R!F;VQL;W=S("AI;F1E;G1A=&EO;B!M96%N<R!I;FAE
M<FET86YC92DZ"B`J(#QP<F4^"B`J($1"("`@("`@("`@("!4:&4@;6%I;B!$
M0B!C;&%S<RX@(%1H:7,@:7,@<VEM<&QY(&$@=71I;&ET>2!C;&%S<PH@*B`@
M("`@("`@("`@("`@=VET:"!S;VUE(")S=&%T:6,B(&UE=&AO9',@9F]R(&-R
M96%T:6YG($1"(&]B:F5C=',@87,*("H@("`@("`@("`@("`@('=E;&P@87,@
M8V]M;6]N('5T:6QI='D@9G5N8W1I;VYS(&9O<B!O=&AE<B!$0B!C;&%S<V5S
M+@H@*@H@*B!$0E]C;VUM;VX@("`@5&AE(&)A<V4@9F]R(&5A8V@@1$(@:6UP
M;&5M96YT871I;VXN("!0<F]V:61E<R!D969A=6QT"B`J('P@("`@("`@("`@
M("!I;7!L96UE;G1A=&EO;G,@*&EN($]/(&QI;F=O('9I<G1U86P@;65T:&]D
M<RD@9F]R"B`J('P@("`@("`@("`@("!T:&4@86-T=6%L($1"(&EM<&QE;65N
M=&%T:6]N<R!A<R!W96QL(&%S(&$@8G5N8V@@;V8*("H@?"`@("`@("`@("`@
M('%U97)Y('5T:6QI='D@9G5N8W1I;VYS+@H@*B!\"B`J("LM1$)?;7ES<6P@
M("!4:&4@1$(@:6UP;&5M96YT871I;VX@9F]R($UY4U%,+B`@26YH97)I=',@
M1$)?8V]M;6]N+@H@*B`@("`@("`@("`@("`@5VAE;B!C86QL:6YG($1".CIF
M86-T;W)Y(&]R($1".CIC;VYN96-T(&9O<B!->5-13`H@*B`@("`@("`@("`@
M("`@8V]N;F5C=&EO;G,L('1H92!O8FIE8W0@<F5T=7)N960@:7,@86X@:6YS
M=&%N8V4@;V8@=&AI<PH@*B`@("`@("`@("`@("`@8VQA<W,N"B`J(#PO<')E
M/@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$
M0@H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^"B`J
M($!A=71H;W(@("`@(%1O;6%S(%8N5BY#;W@@/&-O>$!I9&5C;F5T+F-O;3X*
M("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N
M;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@
M*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@4F5L96%S93H@
M,2XW+C8*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+T1""B`J+PIC;&%S<R!$0@I["B`@("`O+R![>WL@)F9A8W1O<GDH*0H*
M("`@("\J*@H@("`@("H@0W)E871E(&$@;F5W($1"(&]B:F5C="!F;W(@=&AE
M('-P96-I9FEE9"!D871A8F%S92!T>7!E(&)U="!D;VXG=`H@("`@("H@8V]N
M;F5C="!T;R!T:&4@9&%T86)A<V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T>7!E("`@("!T:&4@9&%T86)A<V4@='EP92`H96<@(FUY<W%L(BD*
M("`@("`J($!P87)A;2!A<G)A>2`@)&]P=&EO;G,@(&%N(&%S<V]C:6%T:79E
M(&%R<F%Y(&]F(&]P=&EO;B!N86UE<R!A;F0@=F%L=65S"B`@("`@*@H@("`@
M("H@0')E='5R;B!O8FIE8W0@(&$@;F5W($1"(&]B:F5C="X@($$@1$)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C
M;VUM;VXZ.G-E=$]P=&EO;B@I"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T
M;W)Y*"1T>7!E+"`D;W!T:6]N<R`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF
M("@A:7-?87)R87DH)&]P=&EO;G,I*2!["B`@("`@("`@("`@("1O<'1I;VYS
M(#T@87)R87DH)W!E<G-I<W1E;G0G(#T^("1O<'1I;VYS*3L*("`@("`@("!]
M"@H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG9&5B=6<G72D@)B8@)&]P
M=&EO;G-;)V1E8G5G)UT@/CT@,BD@>PH@("`@("`@("`@("`O+R!E>'!O<V4@
M<&AP(&5R<F]R<R!W:71H('-U9F9I8VEE;G0@9&5B=6<@;&5V96P*("`@("`@
M("`@("`@:6YC;'5D95]O;F-E(")$0B][)'1Y<&5]+G!H<"(["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@0&EN8VQU9&5?;VYC92`B1$(O>R1T>7!E
M?2YP:'`B.PH@("`@("`@('T*"B`@("`@("`@)&-L87-S;F%M92`](")$0E\D
M>W1Y<&5](CL*"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)&-L87-S;F%M
M92DI('L*("`@("`@("`@("`@)'1M<"`](%!%05(Z.G)A:7-E17)R;W(H;G5L
M;"P@1$)?15)23U)?3D]47T9/54Y$+"!N=6QL+"!N=6QL+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`B56YA8FQE('1O(&EN8VQU9&4@
M=&AE($1"+WLD='EP97TN<&AP(@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`N("(@9FEL92!F;W(@)R1D<VXG(BP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)T1"7T5R<F]R)RP@=')U92D["B`@
M("`@("`@("`@(')E='5R;B`D=&UP.PH@("`@("`@('T*"B`@("`@("`@0"1O
M8FH@/28@;F5W("1C;&%S<VYA;64["@H@("`@("`@(&9O<F5A8V@@*"1O<'1I
M;VYS(&%S("1O<'1I;VX@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1T97-T
M(#T@)&]B:BT^<V5T3W!T:6]N*"1O<'1I;VXL("1V86QU92D["B`@("`@("`@
M("`@(&EF("A$0CHZ:7-%<G)O<B@D=&5S="DI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&5S=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1O8FH["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M)F-O;FYE8W0H*0H*("`@("\J*@H@("`@("H@0W)E871E(&$@;F5W($1"(&]B
M:F5C="!I;F-L=61I;F<@82!C;VYN96-T:6]N('1O('1H92!S<&5C:69I960@
M9&%T86)A<V4*("`@("`J"B`@("`@*B!%>&%M<&QE(#$N"B`@("`@*B`\8V]D
M93X*("`@("`J(')E<75I<F5?;VYC92`G1$(N<&AP)SL*("`@("`J"B`@("`@
M*B`D9'-N(#T@)W!G<W%L.B\O=7-E<CIP87-S=V]R9$!H;W-T+V1A=&%B87-E
M)SL*("`@("`J("1O<'1I;VYS(#T@87)R87DH"B`@("`@*B`@("`@)V1E8G5G
M)R`@("`@("`]/B`R+`H@("`@("H@("`@("=P;W)T86)I;&ET>2<@/3X@1$)?
M4$]25$%"24Q)5%E?04Q,+`H@("`@("H@*3L*("`@("`J"B`@("`@*B`D9&(@
M/28@1$(Z.F-O;FYE8W0H)&1S;BP@)&]P=&EO;G,I.PH@("`@("H@:68@*%!%
M05(Z.FES17)R;W(H)&1B*2D@>PH@("`@("H@("`@(&1I92@D9&(M/F=E=$UE
M<W-A9V4H*2D["B`@("`@*B!]"B`@("`@*B`\+V-O9&4^"B`@("`@*@H@("`@
M("H@0'!A<F%M(&UI>&5D("1D<VX@("`@("!T:&4@<W1R:6YG(")D871A('-O
M=7)C92!N86UE(B!O<B!A<G)A>2!I;B!T:&4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@(&9O<FUA="!R971U<FYE9"!B>2!$0CHZ<&%R<V5$4TXH
M*0H@("`@("H@0'!A<F%M(&%R<F%Y("1O<'1I;VYS("!A;B!A<W-O8VEA=&EV
M92!A<G)A>2!O9B!O<'1I;VX@;F%M97,@86YD('9A;'5E<PH@("`@("H*("`@
M("`J($!R971U<FX@;V)J96-T("!A(&YE=R!$0B!O8FIE8W0N("!!($1"7T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!U<V5S($1"
M7V1B87-E.CIC;VYN96-T*"DL($1"7V9B<W%L.CIC;VYN96-T*"DL($1"7VEB
M87-E.CIC;VYN96-T*"DL"B`@("`@*B`@("`@("!$0E]I9G@Z.F-O;FYE8W0H
M*2P@1$)?;7-Q;#HZ8V]N;F5C="@I+"!$0E]M<W-Q;#HZ8V]N;F5C="@I+`H@
M("`@("H@("`@("`@1$)?;7ES<6PZ.F-O;FYE8W0H*2P@1$)?;7ES<6QI.CIC
M;VYN96-T*"DL($1"7V]C:3@Z.F-O;FYE8W0H*2P*("`@("`J("`@("`@($1"
M7V]D8F,Z.F-O;FYE8W0H*2P@1$)?<&=S<6PZ.F-O;FYE8W0H*2P@1$)?<W%L
M:71E.CIC;VYN96-T*"DL"B`@("`@*B`@("`@("!$0E]S>6)A<V4Z.F-O;FYE
M8W0H*0H@("`@("H*("`@("`J($!U<V5S($1".CIP87)S94133B@I+"!$0E]C
M;VUM;VXZ.G-E=$]P=&EO;B@I+"!014%2.CII<T5R<F]R*"D*("`@("`J+PH@
M("`@9G5N8W1I;VX@)F-O;FYE8W0H)&1S;BP@)&]P=&EO;G,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@("1D<VYI;F9O(#T@1$(Z.G!A<G-E1%-.*"1D<VXI
M.PH@("`@("`@("1T>7!E(#T@)&1S;FEN9F];)W!H<'1Y<&4G73L*"B`@("`@
M("`@:68@*"%I<U]A<G)A>2@D;W!T:6]N<RDI('L*("`@("`@("`@("`@+RH*
M("`@("`@("`@("`@("H@1F]R(&)A8VMW87)D<R!C;VUP871I8FEL:71Y+B`@
M)&]P=&EO;G,@=7-E9"!T;R!B92!B;V]L96%N+`H@("`@("`@("`@("`@*B!I
M;F1I8V%T:6YG('=H971H97(@=&AE(&-O;FYE8W1I;VX@<VAO=6QD(&)E('!E
M<G-I<W1E;G0N"B`@("`@("`@("`@("`J+PH@("`@("`@("`@("`D;W!T:6]N
M<R`](&%R<F%Y*"=P97)S:7-T96YT)R`]/B`D;W!T:6]N<RD["B`@("`@("`@
M?0H*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)V1E8G5G)UTI("8F("1O
M<'1I;VYS6R=D96)U9R==(#X](#(I('L*("`@("`@("`@("`@+R\@97AP;W-E
M('!H<"!E<G)O<G,@=VET:"!S=69F:6-I96YT(&1E8G5G(&QE=F5L"B`@("`@
M("`@("`@(&EN8VQU9&5?;VYC92`B1$(O)'MT>7!E?2YP:'`B.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@($!I;F-L=61E7V]N8V4@(D1"+R1[='EP
M97TN<&AP(CL*("`@("`@("!]"@H@("`@("`@("1C;&%S<VYA;64@/2`B1$)?
M)'MT>7!E?2(["B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)&-L87-S;F%M
M92DI('L*("`@("`@("`@("`@)'1M<"`](%!%05(Z.G)A:7-E17)R;W(H;G5L
M;"P@1$)?15)23U)?3D]47T9/54Y$+"!N=6QL+"!N=6QL+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`B56YA8FQE('1O(&EN8VQU9&4@
M=&AE($1"+WLD='EP97TN<&AP(@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`N("(@9FEL92!F;W(@)R1D<VXG(BP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)T1"7T5R<F]R)RP@=')U92D["B`@
M("`@("`@("`@(')E='5R;B`D=&UP.PH@("`@("`@('T*"B`@("`@("`@0"1O
M8FH@/28@;F5W("1C;&%S<VYA;64["@H@("`@("`@(&9O<F5A8V@@*"1O<'1I
M;VYS(&%S("1O<'1I;VX@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1T97-T
M(#T@)&]B:BT^<V5T3W!T:6]N*"1O<'1I;VXL("1V86QU92D["B`@("`@("`@
M("`@(&EF("A$0CHZ:7-%<G)O<B@D=&5S="DI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&5S=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@)&5R<B`]("1O8FHM/F-O;FYE8W0H)&1S;FEN9F\L("1O8FHM/F=E=$]P
M=&EO;B@G<&5R<VES=&5N="<I*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H
M)&5R<BDI('L*("`@("`@("`@("`@)&5R<BT^861D57-E<DEN9F\H)&1S;BD[
M"B`@("`@("`@("`@(')E='5R;B`D97)R.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1O8FH["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@87!I
M5F5R<VEO;B@I"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE($1"($%022!V
M97)S:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!$0B!!
M4$D@=F5R<VEO;B!N=6UB97(*("`@("`J+PH@("`@9G5N8W1I;VX@87!I5F5R
M<VEO;B@I"B`@("!["B`@("`@("`@<F5T=7)N("<Q+C<N-B<["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@:7-%<G)O<B@I"@H@("`@+RHJ"B`@("`@
M*B!$971E<FUI;F5S(&EF(&$@=F%R:6%B;&4@:7,@82!$0E]%<G)O<B!O8FIE
M8W0*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)'9A;'5E("!T:&4@=F%R
M:6%B;&4@=&\@8VAE8VL*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@('=H
M971H97(@)'9A;'5E(&ES($1"7T5R<F]R(&]B:F5C=`H@("`@("HO"B`@("!F
M=6YC=&EO;B!I<T5R<F]R*"1V86QU92D*("`@('L*("`@("`@("!R971U<FX@
M:7-?82@D=F%L=64L("=$0E]%<G)O<B<I.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&ES0V]N;F5C=&EO;B@I"@H@("`@+RHJ"B`@("`@*B!$971E
M<FUI;F5S(&EF(&$@=F%L=64@:7,@82!$0E\\9')I=F5R/B!O8FIE8W0*("`@
M("`J"B`@("`@*B!`<&%R86T@;6EX960@)'9A;'5E("!T:&4@=F%L=64@=&\@
M=&5S=`H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@=VAE=&AE<B`D=F%L
M=64@:7,@82!$0E\\9')I=F5R/B!O8FIE8W0*("`@("`J+PH@("`@9G5N8W1I
M;VX@:7-#;VYN96-T:6]N*"1V86QU92D*("`@('L*("`@("`@("!R971U<FX@
M*&ES7V]B:F5C="@D=F%L=64I("8F"B`@("`@("`@("`@("`@("!I<U]S=6)C
M;&%S<U]O9B@D=F%L=64L("=D8E]C;VUM;VXG*2`F)@H@("`@("`@("`@("`@
M("`@;65T:&]D7V5X:7-T<R@D=F%L=64L("=S:6UP;&51=65R>2<I*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!I<TUA;FEP*"D*"B`@("`O*BH*
M("`@("`J(%1E;&P@=VAE=&AE<B!A('%U97)Y(&ES(&$@9&%T82!M86YI<'5L
M871I;VX@;W(@9&%T82!D969I;FET:6]N('%U97)Y"B`@("`@*@H@("`@("H@
M17AA;7!L97,@;V8@9&%T82!M86YI<'5L871I;VX@<75E<FEE<R!A<F4@24Y3
M15)4+"!54$1!5$4@86YD($1%3$5412X*("`@("`J($5X86UP;&5S(&]F(&1A
M=&$@9&5F:6YI=&EO;B!Q=65R:65S(&%R92!#4D5!5$4L($123U`L($%,5$52
M+"!'4D%.5"P*("`@("`J(%)%5D]+12X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1Q=65R>2`@=&AE('%U97)Y"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!W:&5T:&5R("1Q=65R>2!I<R!A(&1A=&$@;6%N:7!U;&%T
M:6]N('%U97)Y"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES36%N:7`H)'%U97)Y
M*0H@("`@>PH@("`@("`@("1M86YI<',@/2`G24Y315)4?%501$%417Q$14Q%
M5$5\4D503$%#17PG"B`@("`@("`@("`@("`@("`N("=#4D5!5$5\1%)/4'PG
M"B`@("`@("`@("`@("`@("`N("=,3T%$($1!5$%\4T5,14-4("XJ($E.5$]\
M0T]067PG"B`@("`@("`@("`@("`@("`N("=!3%1%4GQ'4D%.5'Q2159/2T5\
M)PH@("`@("`@("`@("`@("`@+B`G3$]#2WQ53DQ/0TLG.PH@("`@("`@(&EF
M("AP<F5G7VUA=&-H*"<O7EQS*B(_*"<@+B`D;6%N:7!S("X@)RE<<RLO:2<L
M("1Q=65R>2DI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!E<G)O<DUE<W-A9V4H*0H*("`@("\J*@H@("`@("H@4F5T=7)N
M(&$@=&5X='5A;"!E<G)O<B!M97-S86=E(&9O<B!A($1"(&5R<F]R(&-O9&4*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=F%L=64@('1H92!$0B!E
M<G)O<B!C;V1E"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!E
M<G)O<B!M97-S86=E(&]R(&9A;'-E(&EF('1H92!E<G)O<B!C;V1E('=A<PH@
M("`@("H@("`@("`@("`@("`@("`@("!N;W0@<F5C;V=N:7IE9`H@("`@("HO
M"B`@("!F=6YC=&EO;B!E<G)O<DUE<W-A9V4H)'9A;'5E*0H@("`@>PH@("`@
M("`@('-T871I8R`D97)R;W)-97-S86=E<SL*("`@("`@("!I9B`H(6ES<V5T
M*"1E<G)O<DUE<W-A9V5S*2D@>PH@("`@("`@("`@("`D97)R;W)-97-S86=E
M<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@1$)?15)23U(@("`@("`@("`@
M("`@("`@("`@(#T^("=U;FMN;W=N(&5R<F]R)RP*("`@("`@("`@("`@("`@
M($1"7T524D]27T%#0T534U]624],051)3TX@("`]/B`G:6YS=69F:6-I96YT
M('!E<FUI<W-I;VYS)RP*("`@("`@("`@("`@("`@($1"7T524D]27T%,4D5!
M1%E?15A)4U13("`@("`]/B`G86QR96%D>2!E>&ES=',G+`H@("`@("`@("`@
M("`@("`@1$)?15)23U)?0T%.3D]47T-214%412`@("`@(#T^("=C86X@;F]T
M(&-R96%T92<L"B`@("`@("`@("`@("`@("!$0E]%4E)/4E]#04Y.3U1?1%)/
M4"`@("`@("`@/3X@)V-A;B!N;W0@9')O<"<L"B`@("`@("`@("`@("`@("!$
M0E]%4E)/4E]#3TY.14-47T9!24Q%1"`@("`@/3X@)V-O;FYE8W0@9F%I;&5D
M)RP*("`@("`@("`@("`@("`@($1"7T524D]27T-/3E-44D%)3E0@("`@("`@
M("`]/B`G8V]N<W1R86EN="!V:6]L871I;VXG+`H@("`@("`@("`@("`@("`@
M1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3#T^("=N=6QL('9A;'5E('9I
M;VQA=&5S(&YO="UN=6QL(&-O;G-T<F%I;G0G+`H@("`@("`@("`@("`@("`@
M1$)?15)23U)?1$E66D523R`@("`@("`@("`@(#T^("=D:79I<VEO;B!B>2!Z
M97)O)RP*("`@("`@("`@("`@("`@($1"7T524D]27T585$5.4TE/3E].3U1?
M1D]53D0]/B`G97AT96YS:6]N(&YO="!F;W5N9"<L"B`@("`@("`@("`@("`@
M("!$0E]%4E)/4E])3E9!3$E$("`@("`@("`@("`@/3X@)VEN=F%L:60G+`H@
M("`@("`@("`@("`@("`@1$)?15)23U)?24Y604Q)1%]$051%("`@("`@(#T^
M("=I;G9A;&ED(&1A=&4@;W(@=&EM92<L"B`@("`@("`@("`@("`@("!$0E]%
M4E)/4E])3E9!3$E$7T133B`@("`@("`@/3X@)VEN=F%L:60@1%-.)RP*("`@
M("`@("`@("`@("`@($1"7T524D]27TE.5D%,241?3E5-0D52("`@("`]/B`G
M:6YV86QI9"!N=6UB97(G+`H@("`@("`@("`@("`@("`@1$)?15)23U)?34E3
M34%40T@@("`@("`@("`@(#T^("=M:7-M871C:"<L"B`@("`@("`@("`@("`@
M("!$0E]%4E)/4E].145$7TU/4D5?1$%402`@("`@/3X@)VEN<W5F9FEC:65N
M="!D871A('-U<'!L:65D)RP*("`@("`@("`@("`@("`@($1"7T524D]27TY/
M1$)314Q%0U1%1"`@("`@("`]/B`G;F\@9&%T86)A<V4@<V5L96-T960G+`H@
M("`@("`@("`@("`@("`@1$)?15)23U)?3D]354-(1$(@("`@("`@("`@(#T^
M("=N;R!S=6-H(&1A=&%B87-E)RP*("`@("`@("`@("`@("`@($1"7T524D]2
M7TY/4U5#2$9)14Q$("`@("`@("`]/B`G;F\@<W5C:"!F:65L9"<L"B`@("`@
M("`@("`@("`@("!$0E]%4E)/4E].3U-50TA404),12`@("`@("`@/3X@)VYO
M('-U8V@@=&%B;&4G+`H@("`@("`@("`@("`@("`@1$)?15)23U)?3D]47T-!
M4$%"3$4@("`@("`@(#T^("=$0B!B86-K96YD(&YO="!C87!A8FQE)RP*("`@
M("`@("`@("`@("`@($1"7T524D]27TY/5%]&3U5.1"`@("`@("`@("`]/B`G
M;F]T(&9O=6YD)RP*("`@("`@("`@("`@("`@($1"7T524D]27TY/5%],3T-+
M140@("`@("`@("`]/B`G;F]T(&QO8VME9"<L"B`@("`@("`@("`@("`@("!$
M0E]%4E)/4E]364Y405@@("`@("`@("`@("`@/3X@)W-Y;G1A>"!E<G)O<B<L
M"B`@("`@("`@("`@("`@("!$0E]%4E)/4E]53E-54%!/4E1%1"`@("`@("`@
M/3X@)VYO="!S=7!P;W)T960G+`H@("`@("`@("`@("`@("`@1$)?15)23U)?
M5%)53D-!5$5$("`@("`@("`@(#T^("=T<G5N8V%T960G+`H@("`@("`@("`@
M("`@("`@1$)?15)23U)?5D%,545?0T]53E1?3TY?4D]7(#T^("=V86QU92!C
M;W5N="!O;B!R;W<G+`H@("`@("`@("`@("`@("`@1$)?3TL@("`@("`@("`@
M("`@("`@("`@("`@(#T^("=N;R!E<G)O<B<L"B`@("`@("`@("`@("D["B`@
M("`@("`@?0H*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)'9A;'5E*2D@>PH@
M("`@("`@("`@("`D=F%L=64@/2`D=F%L=64M/F=E=$-O9&4H*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!I<W-E="@D97)R;W)-97-S86=E<ULD=F%L
M=65=*2`_("1E<G)O<DUE<W-A9V5S6R1V86QU95T*("`@("`@("`@("`@("`@
M("`@("`@.B`D97)R;W)-97-S86=E<UM$0E]%4E)/4ET["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@<&%R<V5$4TXH*0H*("`@("\J*@H@("`@("H@
M4&%R<V4@82!D871A('-O=7)C92!N86UE"B`@("`@*@H@("`@("H@061D:71I
M;VYA;"!K97ES(&-A;B!B92!A9&1E9"!B>2!A<'!E;F1I;F<@82!54DD@<75E
M<GD@<W1R:6YG('1O('1H90H@("`@("H@96YD(&]F('1H92!$4TXN"B`@("`@
M*@H@("`@("H@5&AE(&9O<FUA="!O9B!T:&4@<W5P<&QI960@1%-.(&ES(&EN
M(&ET<R!F=6QL97-T(&9O<FTZ"B`@("`@*B`\8V]D93X*("`@("`J("!P:'!T
M>7!E*&1B<WEN=&%X*3HO+W5S97)N86UE.G!A<W-W;W)D0'!R;W1O8V]L*VAO
M<W1S<&5C+V1A=&%B87-E/V]P=&EO;CTX)F%N;W1H97(]=')U90H@("`@("H@
M/"]C;V1E/@H@("`@("H*("`@("`J($UO<W0@=F%R:6%T:6]N<R!A<F4@86QL
M;W=E9#H*("`@("`J(#QC;V1E/@H@("`@("H@('!H<'1Y<&4Z+R]U<V5R;F%M
M93IP87-S=V]R9$!P<F]T;V-O;"MH;W-T<W!E8SHQ,3`O+W5S<B]D8E]F:6QE
M+F1B/VUO9&4],#8T-`H@("`@("H@('!H<'1Y<&4Z+R]U<V5R;F%M93IP87-S
M=V]R9$!H;W-T<W!E8R]D871A8F%S95]N86UE"B`@("`@*B`@<&AP='EP93HO
M+W5S97)N86UE.G!A<W-W;W)D0&AO<W1S<&5C"B`@("`@*B`@<&AP='EP93HO
M+W5S97)N86UE0&AO<W1S<&5C"B`@("`@*B`@<&AP='EP93HO+VAO<W1S<&5C
M+V1A=&%B87-E"B`@("`@*B`@<&AP='EP93HO+VAO<W1S<&5C"B`@("`@*B`@
M<&AP='EP92AD8G-Y;G1A>"D*("`@("`J("!P:'!T>7!E"B`@("`@*B`\+V-O
M9&4^"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9'-N($1A=&$@4V]U
M<F-E($YA;64@=&\@8F4@<&%R<V5D"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2!A;B!A<W-O8VEA=&EV92!A<G)A>2!W:71H('1H92!F;VQL;W=I;F<@
M:V5Y<SH*("`@("`J("`K('!H<'1Y<&4Z("!$871A8F%S92!B86-K96YD('5S
M960@:6X@4$A0("AM>7-Q;"P@;V1B8R!E=&,N*0H@("`@("H@("L@9&)S>6YT
M87@Z($1A=&%B87-E('5S960@=VET:"!R96=A<F1S('1O(%-13"!S>6YT87@@
M971C+@H@("`@("H@("L@<')O=&]C;VPZ($-O;6UU;FEC871I;VX@<')O=&]C
M;VP@=&\@=7-E("AT8W`L('5N:7@@971C+BD*("`@("`J("`K(&AO<W1S<&5C
M.B!(;W-T('-P96-I9FEC871I;VX@*&AO<W1N86UE6SIP;W)T72D*("`@("`J
M("`K(&1A=&%B87-E.B!$871A8F%S92!T;R!U<V4@;VX@=&AE($1"35,@<V5R
M=F5R"B`@("`@*B`@*R!U<V5R;F%M93H@57-E<B!N86UE(&9O<B!L;V=I;@H@
M("`@("H@("L@<&%S<W=O<F0Z(%!A<W-W;W)D(&9O<B!L;V=I;@H@("`@("HO
M"B`@("!F=6YC=&EO;B!P87)S94133B@D9'-N*0H@("`@>PH@("`@("`@("1P
M87)S960@/2!A<G)A>2@*("`@("`@("`@("`@)W!H<'1Y<&4G("`]/B!F86QS
M92P*("`@("`@("`@("`@)V1B<WEN=&%X)R`]/B!F86QS92P*("`@("`@("`@
M("`@)W5S97)N86UE)R`]/B!F86QS92P*("`@("`@("`@("`@)W!A<W-W;W)D
M)R`]/B!F86QS92P*("`@("`@("`@("`@)W!R;W1O8V]L)R`]/B!F86QS92P*
M("`@("`@("`@("`@)VAO<W1S<&5C)R`]/B!F86QS92P*("`@("`@("`@("`@
M)W!O<G0G("`@("`]/B!F86QS92P*("`@("`@("`@("`@)W-O8VME="<@("`]
M/B!F86QS92P*("`@("`@("`@("`@)V1A=&%B87-E)R`]/B!F86QS92P*("`@
M("`@("`I.PH*("`@("`@("!I9B`H:7-?87)R87DH)&1S;BDI('L*("`@("`@
M("`@("`@)&1S;B`](&%R<F%Y7VUE<F=E*"1P87)S960L("1D<VXI.PH@("`@
M("`@("`@("!I9B`H(21D<VY;)V1B<WEN=&%X)UTI('L*("`@("`@("`@("`@
M("`@("1D<VY;)V1B<WEN=&%X)UT@/2`D9'-N6R=P:'!T>7!E)UT["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1D<VX["B`@("`@("`@?0H*
M("`@("`@("`O+R!&:6YD('!H<'1Y<&4@86YD(&1B<WEN=&%X"B`@("`@("`@
M:68@*"@D<&]S(#T@<W1R<&]S*"1D<VXL("<Z+R\G*2D@(3T](&9A;'-E*2![
M"B`@("`@("`@("`@("1S='(@/2!S=6)S='(H)&1S;BP@,"P@)'!O<RD["B`@
M("`@("`@("`@("1D<VX@/2!S=6)S='(H)&1S;BP@)'!O<R`K(#,I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1S='(@/2`D9'-N.PH@("`@("`@
M("`@("`D9'-N(#T@;G5L;#L*("`@("`@("!]"@H@("`@("`@("\O($=E="!P
M:'!T>7!E(&%N9"!D8G-Y;G1A>`H@("`@("`@("\O("1S='(@/3X@<&AP='EP
M92AD8G-Y;G1A>"D*("`@("`@("!I9B`H<')E9U]M871C:"@G?%XH+BL_*5PH
M*"XJ/RE<*21\)RP@)'-T<BP@)&%R<BDI('L*("`@("`@("`@("`@)'!A<G-E
M9%LG<&AP='EP92==("`]("1A<G);,5T["B`@("`@("`@("`@("1P87)S961;
M)V1B<WEN=&%X)UT@/2`A)&%R<ELR72`_("1A<G);,5T@.B`D87)R6S)=.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P87)S961;)W!H<'1Y<&4G
M72`@/2`D<W1R.PH@("`@("`@("`@("`D<&%R<V5D6R=D8G-Y;G1A>"==(#T@
M)'-T<CL*("`@("`@("!]"@H@("`@("`@(&EF("@A8V]U;G0H)&1S;BDI('L*
M("`@("`@("`@("`@<F5T=7)N("1P87)S960["B`@("`@("`@?0H*("`@("`@
M("`O+R!'970@*&EF(&9O=6YD*3H@=7-E<FYA;64@86YD('!A<W-W;W)D"B`@
M("`@("`@+R\@)&1S;B`]/B!U<V5R;F%M93IP87-S=V]R9$!P<F]T;V-O;"MH
M;W-T<W!E8R]D871A8F%S90H@("`@("`@(&EF("@H)&%T(#T@<W1R<G!O<R@D
M9'-N+"=`)RDI("$]/2!F86QS92D@>PH@("`@("`@("`@("`D<W1R(#T@<W5B
M<W1R*"1D<VXL(#`L("1A="D["B`@("`@("`@("`@("1D<VX@/2!S=6)S='(H
M)&1S;BP@)&%T("L@,2D["B`@("`@("`@("`@(&EF("@H)'!O<R`]('-T<G!O
M<R@D<W1R+"`G.B<I*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1P
M87)S961;)W5S97)N86UE)UT@/2!R87=U<FQD96-O9&4H<W5B<W1R*"1S='(L
M(#`L("1P;W,I*3L*("`@("`@("`@("`@("`@("1P87)S961;)W!A<W-W;W)D
M)UT@/2!R87=U<FQD96-O9&4H<W5B<W1R*"1S='(L("1P;W,@*R`Q*2D["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<&%R<V5D6R=U
M<V5R;F%M92==(#T@<F%W=7)L9&5C;V1E*"1S='(I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O+R!&:6YD('!R;W1O8V]L(&%N9"!H;W-T
M<W!E8PH*("`@("`@("!I9B`H<')E9U]M871C:"@G?%XH6UXH72LI7"@H+BH_
M*5PI+S\H+BH_*21\)RP@)&1S;BP@)&UA=&-H*2D@>PH@("`@("`@("`@("`O
M+R`D9'-N(#T^('!R;W1O*'!R;W1O7V]P=',I+V1A=&%B87-E"B`@("`@("`@
M("`@("1P<F]T;R`@("`@("`]("1M871C:%LQ73L*("`@("`@("`@("`@)'!R
M;W1O7V]P=',@(#T@)&UA=&-H6S)=(#\@)&UA=&-H6S)=(#H@9F%L<V4["B`@
M("`@("`@("`@("1D<VX@("`@("`@("`]("1M871C:%LS73L*"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@+R\@)&1S;B`]/B!P<F]T;V-O;"MH;W-T
M<W!E8R]D871A8F%S92`H;VQD(&9O<FUA="D*("`@("`@("`@("`@:68@*'-T
M<G!O<R@D9'-N+"`G*R<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@
M;&ES="@D<')O=&\L("1D<VXI(#T@97AP;&]D92@G*R<L("1D<VXL(#(I.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AS=')P;W,H)&1S;BP@)R\G
M*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@(&QI<W0H)'!R;W1O7V]P
M=',L("1D<VXI(#T@97AP;&]D92@G+R<L("1D<VXL(#(I.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'!R;W1O7V]P=',@/2`D9'-N
M.PH@("`@("`@("`@("`@("`@)&1S;B`](&YU;&P["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("\O('!R;V-E<W,@=&AE(&1I9F9E<F5N="!P
M<F]T;V-O;"!O<'1I;VYS"B`@("`@("`@)'!A<G-E9%LG<')O=&]C;VPG72`]
M("@A96UP='DH)'!R;W1O*2D@/R`D<')O=&\@.B`G=&-P)SL*("`@("`@("`D
M<')O=&]?;W!T<R`](')A=W5R;&1E8V]D92@D<')O=&]?;W!T<RD["B`@("`@
M("`@:68@*"1P87)S961;)W!R;W1O8V]L)UT@/3T@)W1C<"<I('L*("`@("`@
M("`@("`@:68@*'-T<G!O<R@D<')O=&]?;W!T<RP@)SHG*2`A/3T@9F%L<V4I
M('L*("`@("`@("`@("`@("`@(&QI<W0H)'!A<G-E9%LG:&]S='-P96,G72P*
M("`@("`@("`@("`@("`@("`@("`@)'!A<G-E9%LG<&]R="==*2`](&5X<&QO
M9&4H)SHG+"`D<')O=&]?;W!T<RD["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D<&%R<V5D6R=H;W-T<W!E8R==(#T@)'!R;W1O7V]P
M=',["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H)'!A<G-E9%LG
M<')O=&]C;VPG72`]/2`G=6YI>"<I('L*("`@("`@("`@("`@)'!A<G-E9%LG
M<V]C:V5T)UT@/2`D<')O=&]?;W!T<SL*("`@("`@("!]"@H@("`@("`@("\O
M($=E="!D86)A<V4@:68@86YY"B`@("`@("`@+R\@)&1S;B`]/B!D871A8F%S
M90H@("`@("`@(&EF("@D9'-N*2!["B`@("`@("`@("`@(&EF("@H)'!O<R`]
M('-T<G!O<R@D9'-N+"`G/R<I*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@
M("`@("\O("]D871A8F%S90H@("`@("`@("`@("`@("`@)'!A<G-E9%LG9&%T
M86)A<V4G72`](')A=W5R;&1E8V]D92@D9'-N*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("\O("]D871A8F%S93]P87)A;3$]=F%L
M=64Q)G!A<F%M,CUV86QU93(*("`@("`@("`@("`@("`@("1P87)S961;)V1A
M=&%B87-E)UT@/2!R87=U<FQD96-O9&4H<W5B<W1R*"1D<VXL(#`L("1P;W,I
M*3L*("`@("`@("`@("`@("`@("1D<VX@/2!S=6)S='(H)&1S;BP@)'!O<R`K
M(#$I.PH@("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D9'-N+"`G)B<I("$]
M/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@("1O<'1S(#T@97AP;&]D
M92@G)B<L("1D<VXI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L@+R\@9&%T
M86)A<V4_<&%R86TQ/79A;'5E,0H@("`@("`@("`@("`@("`@("`@("1O<'1S
M(#T@87)R87DH)&1S;BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D;W!T<R!A<R`D;W!T*2!["B`@("`@("`@("`@("`@
M("`@("`@;&ES="@D:V5Y+"`D=F%L=64I(#T@97AP;&]D92@G/2<L("1O<'0I
M.PH@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'!A<G-E9%LD:V5Y
M72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@+R\@9&]N)W0@86QL;W<@
M<&%R86US(&]V97)W<FET90H@("`@("`@("`@("`@("`@("`@("`@("`D<&%R
M<V5D6R1K97E=(#T@<F%W=7)L9&5C;V1E*"1V86QU92D["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)'!A<G-E9#L*("`@('T*"B`@("`O
M+R!]?7T*?0H*+R\@?7U]"B\O('M[>R!C;&%S<R!$0E]%<G)O<@H*+RHJ"B`J
M($1"7T5R<F]R(&EM<&QE;65N=',@82!C;&%S<R!F;W(@<F5P;W)T:6YG('!O
M<G1A8FQE(&1A=&%B87-E(&5R<F]R"B`J(&UE<W-A9V5S"B`J"B`J($!C871E
M9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@
M("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP
M"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-RXV"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*8VQA<W,@1$)?
M17)R;W(@97AT96YD<R!014%27T5R<F]R"GL*("`@("\O('M[>R!C;VYS=')U
M8W1O<@H*("`@("\J*@H@("`@("H@1$)?17)R;W(@8V]N<W1R=6-T;W(*("`@
M("`J"B`@("`@*B!`<&%R86T@;6EX960@)&-O9&4@("`@("`@1$(@97)R;W(@
M8V]D92P@;W(@<W1R:6YG('=I=&@@97)R;W(@;65S<V%G90H@("`@("H@0'!A
M<F%M(&EN="`@("1M;V1E("`@("`@('=H870@(F5R<F]R(&UO9&4B('1O(&]P
M97)A=&4@:6X*("`@("`J($!P87)A;2!I;G0@("`D;&5V96P@("`@("!W:&%T
M(&5R<F]R(&QE=F5L('1O('5S92!F;W(@)&UO9&4@)@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("!014%27T524D]27U1224='15(*("`@("`J
M($!P87)A;2!M:7AE9"`D9&5B=6=I;F9O("!A9&1I=&EO;F%L(&1E8G5G(&EN
M9F\L('-U8V@@87,@=&AE(&QA<W0@<75E<GD*("`@("`J"B`@("`@*B!`<V5E
M(%!%05)?17)R;W(*("`@("`J+PH@("`@9G5N8W1I;VX@1$)?17)R;W(H)&-O
M9&4@/2!$0E]%4E)/4BP@)&UO9&4@/2!014%27T524D]27U)%5%523BP*("`@
M("`@("`@("`@("`@("`@("`@("1L979E;"`]($5?55-%4E].3U1)0T4L("1D
M96)U9VEN9F\@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]I;G0H)&-O
M9&4I*2!["B`@("`@("`@("`@("1T:&ES+3Y014%27T5R<F]R*"=$0B!%<G)O
M<CH@)R`N($1".CIE<G)O<DUE<W-A9V4H)&-O9&4I+"`D8V]D92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&UO9&4L("1L979E;"P@)&1E8G5G
M:6YF;RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E!%
M05)?17)R;W(H(D1"($5R<F]R.B`D8V]D92(L($1"7T524D]2+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D;6]D92P@)&QE=F5L+"`D9&5B=6=I
M;F9O*3L*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"GT*"B\O('U]?0HO
M+R![>WL@8VQA<W,@1$)?<F5S=6QT"@HO*BH*("H@5&AI<R!C;&%S<R!I;7!L
M96UE;G1S(&$@=W)A<'!E<B!F;W(@82!$0B!R97-U;'0@<V5T"B`J"B`J($$@
M;F5W(&EN<W1A;F-E(&]F('1H:7,@8VQA<W,@=VEL;"!B92!R971U<FYE9"!B
M>2!T:&4@1$(@:6UP;&5M96YT871I;VX*("H@869T97(@<')O8V5S<VEN9R!A
M('%U97)Y('1H870@<F5T=7)N<R!D871A+@H@*@H@*B!`8V%T96=O<GD@("!$
M871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!3=&EG
M($)A:VME;B`\<W-B0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P
M-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R
M<VEO;B`@("!296QE87-E.B`Q+C<N-@H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"F-L87-S($1"7W)E<W5L=`I[
M"B`@("`O+R![>WL@<')O<&5R=&EE<PH*("`@("\J*@H@("`@("H@4VAO=6QD
M(')E<W5L=',@8F4@9G)E960@875T;VUA=&EC86QL>2!W:&5N('1H97)E(&%R
M92!N;R!M;W)E(')O=W,_"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J($!S
M964@1$)?8V]M;6]N.CHD;W!T:6]N<PH@("`@("HO"B`@("!V87(@)&%U=&]F
M<F5E.PH*("`@("\J*@H@("`@("H@02!R969E<F5N8V4@=&\@=&AE($1"7SQD
M<FEV97(^(&]B:F5C=`H@("`@("H@0'9A<B!O8FIE8W0*("`@("`J+PH@("`@
M=F%R("1D8F@["@H@("`@+RHJ"B`@("`@*B!4:&4@8W5R<F5N="!D969A=6QT
M(&9E=&-H(&UO9&4*("`@("`J($!V87(@:6YT96=E<@H@("`@("H@0'-E92!$
M0E]C;VUM;VXZ.B1F971C:&UO9&4*("`@("`J+PH@("`@=F%R("1F971C:&UO
M9&4["@H@("`@+RHJ"B`@("`@*B!4:&4@;F%M92!O9B!T:&4@8VQA<W,@:6YT
M;R!W:&EC:"!R97-U;'1S('-H;W5L9"!B92!F971C:&5D('=H96X*("`@("`J
M($1"7T9%5$-(34]$15]/0DI%0U0@:7,@:6X@969F96-T"B`@("`@*@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J($!S964@1$)?8V]M;6]N.CHD9F5T8VAM
M;V1E7V]B:F5C=%]C;&%S<PH@("`@("HO"B`@("!V87(@)&9E=&-H;6]D95]O
M8FIE8W1?8VQA<W,["@H@("`@+RHJ"B`@("`@*B!4:&4@;G5M8F5R(&]F(')O
M=W,@=&\@9F5T8V@@9G)O;2!A(&QI;6ET('%U97)Y"B`@("`@*B!`=F%R(&EN
M=&5G97(*("`@("`J+PH@("`@=F%R("1L:6UI=%]C;W5N="`](&YU;&P["@H@
M("`@+RHJ"B`@("`@*B!4:&4@<F]W('1O('-T87)T(&9E=&-H:6YG(&9R;VT@
M:6X@;&EM:70@<75E<FEE<PH@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*
M("`@('9A<B`D;&EM:71?9G)O;2`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!4
M:&4@97AE8W5T92!P87)A;65T97)S('1H870@8W)E871E9"!T:&ES(')E<W5L
M=`H@("`@("H@0'9A<B!A<G)A>0H@("`@("H@0'-I;F-E(%!R;W!E<G1Y(&%V
M86EL86)L92!S:6YC92!296QE87-E(#$N-RXP"B`@("`@*B\*("`@('9A<B`D
M<&%R86UE=&5R<SL*"B`@("`O*BH*("`@("`J(%1H92!Q=65R>2!S=')I;F<@
M=&AA="!C<F5A=&5D('1H:7,@<F5S=6QT"B`@("`@*@H@("`@("H@0V]P:65D
M(&AE<F4@:6YC87-E(&ET(&-H86YG97,@:6X@)&1B:"P@=VAI8V@@:7,@<F5F
M97)E;F-E9`H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`<VEN
M8V4@4')O<&5R='D@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XW+C`*("`@
M("`J+PH@("`@=F%R("1Q=65R>3L*"B`@("`O*BH*("`@("`J(%1H92!Q=65R
M>2!R97-U;'0@<F5S;W5R8V4@:60@8W)E871E9"!B>2!02%`*("`@("`J($!V
M87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1R97-U;'0["@H@("`@+RHJ
M"B`@("`@*B!4:&4@<')E<V5N="!R;W<@8F5I;F<@9&5A;'0@=VET:`H@("`@
M("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D<F]W7V-O=6YT97(@
M/2!N=6QL.PH*("`@("\J*@H@("`@("H@5&AE('!R97!A<F5D('-T871E;65N
M="!R97-O=7)C92!I9"!C<F5A=&5D(&)Y(%!(4"!I;B`D9&)H"B`@("`@*@H@
M("`@("H@5&AI<R!R97-O=7)C92!I<R!O;FQY(&%V86EL86)L92!W:&5N('1H
M92!R97-U;'0@<V5T('=A<R!C<F5A=&5D('5S:6YG"B`@("`@*B!A(&1R:79E
M<B=S(&YA=&EV92!E>&5C=71E*"D@;65T:&]D+"!N;W0@4$5!4B!$0B=S(&5M
M=6QA=&5D(&]N92X*("`@("`J"B`@("`@*B!#;W!I960@:&5R92!I;F-A<V4@
M:70@8VAA;F=E<R!I;B`D9&)H+"!W:&EC:"!I<R!R969E<F5N8V5D"B`@("`@
M*@H@("`@("H@>T!I;G1E<FYA;"`@36%I;FQY(&AE<F4@8F5C875S92!T:&4@
M26YT97)"87-E+T9I<F5B:7)D($%022!I<R!O;FQY"B`@("`@*B!A8FQE('1O
M(')E=')I979E(&1A=&$@9G)O;2!R97-U;'0@<V5T<R!I9B!T:&4@<W1A=&5M
M;G0@:&%N9&QE(&ES"B`@("`@*B!S=&EL;"!I;B!S8V]P92Y]?0H@("`@("H*
M("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J($!S:6YC92!0<F]P97)T>2!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C<N,`H@("`@("HO"B`@("!V87(@
M)'-T871E;65N=#L*"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]N<W1R=6-T
M;W(*"B`@("`O*BH*("`@("`J(%1H:7,@8V]N<W1R=6-T;W(@<V5T<R!T:&4@
M;V)J96-T)W,@<')O<&5R=&EE<PH@("`@("H*("`@("`J($!P87)A;2!O8FIE
M8W0@("`F)&1B:"`@("`@=&AE($1"(&]B:F5C="!R969E<F5N8V4*("`@("`J
M($!P87)A;2!R97-O=7)C92`D<F5S=6QT("`@=&AE(')E<W5L="!R97-O=7)C
M92!I9`H@("`@("H@0'!A<F%M(&%R<F%Y("`@("1O<'1I;VYS("!A;B!A<W-O
M8VEA=&EV92!A<G)A>2!W:71H(')E<W5L="!O<'1I;VYS"B`@("`@*@H@("`@
M("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N($1"7W)E<W5L
M="@F)&1B:"P@)')E<W5L="P@)&]P=&EO;G,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@("1T:&ES+3YA=71O9G)E92`@("`]("1D8F@M/F]P=&EO;G-;)V%U
M=&]F<F5E)UT["B`@("`@("`@)'1H:7,M/F1B:"`@("`@("`@(#T@)B1D8F@[
M"B`@("`@("`@)'1H:7,M/F9E=&-H;6]D92`@(#T@)&1B:"T^9F5T8VAM;V1E
M.PH@("`@("`@("1T:&ES+3YF971C:&UO9&5?;V)J96-T7V-L87-S(#T@)&1B
M:"T^9F5T8VAM;V1E7V]B:F5C=%]C;&%S<SL*("`@("`@("`D=&AI<RT^<&%R
M86UE=&5R<R`@/2`D9&)H+3YL87-T7W!A<F%M971E<G,["B`@("`@("`@)'1H
M:7,M/G%U97)Y("`@("`@(#T@)&1B:"T^;&%S=%]Q=65R>3L*("`@("`@("`D
M=&AI<RT^<F5S=6QT("`@("`@/2`D<F5S=6QT.PH@("`@("`@("1T:&ES+3YS
M=&%T96UE;G0@("`](&5M<'1Y*"1D8F@M/FQA<W1?<W1M="D@/R!N=6QL(#H@
M)&1B:"T^;&%S=%]S=&UT.PH@("`@("`@(&9O<F5A8V@@*"1O<'1I;VYS(&%S
M("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1T:&ES+3YS971/<'1I
M;VXH)&ME>2P@)'9A;'5E*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3970@;W!T:6]N<R!F;W(@=&AE($1"7W)E<W5L="!O8FIE8W0*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1K97D@("`@=&AE(&]P=&EO;B!T
M;R!S970*("`@("`J($!P87)A;2!M:7AE9"`@)'9A;'5E("!T:&4@=F%L=64@
M=&\@<V5T('1H92!O<'1I;VX@=&\*("`@("`J"B`@("`@*B!`<F5T=7)N('9O
M:60*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T3W!T:6]N*"1K97DL("1V86QU
M92`](&YU;&PI"B`@("!["B`@("`@("`@<W=I=&-H("@D:V5Y*2!["B`@("`@
M("`@("`@(&-A<V4@)VQI;6ET7V9R;VTG.@H@("`@("`@("`@("`@("`@)'1H
M:7,M/FQI;6ET7V9R;VT@/2`D=F%L=64["B`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@8V%S92`G;&EM:71?8V]U;G0G.@H@("`@("`@("`@
M("`@("`@)'1H:7,M/FQI;6ET7V-O=6YT(#T@)'9A;'5E.PH@("`@("`@('T*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F971C:%)O=R@I"@H@("`@
M+RHJ"B`@("`@*B!&971C:"!A(')O=R!O9B!D871A(&%N9"!R971U<FX@:70@
M8GD@<F5F97)E;F-E(&EN=&\@86X@87)R87D*("`@("`J"B`@("`@*B!4:&4@
M='EP92!O9B!A<G)A>2!R971U<FYE9"!C86X@8F4@8V]N=')O;&QE9"!E:71H
M97(@8GD@<V5T=&EN9R!T:&ES"B`@("`@*B!M971H;V0G<R`\=F%R/B1F971C
M:&UO9&4\+W9A<CX@<&%R86UE=&5R(&]R(&)Y(&-H86YG:6YG('1H92!D969A
M=6QT"B`@("`@*B!F971C:"!M;V1E('-E=$9E=&-H36]D92@I(&)E9F]R92!C
M86QL:6YG('1H:7,@;65T:&]D+@H@("`@("H*("`@("`J(%1H97)E(&%R92!T
M=V\@;W!T:6]N<R!F;W(@<W1A;F1A<F1I>FEN9R!T:&4@:6YF;W)M871I;VX@
M<F5T=7)N960*("`@("`J(&9R;VT@9&%T86)A<V5S+"!E;G-U<FEN9R!T:&5I
M<B!V86QU97,@87)E(&-O;G-I<W1E;G0@=VAE;B!C:&%N9VEN9PH@("`@("H@
M1$)-4R=S+B`@5&AE<V4@<&]R=&%B:6QI='D@;W!T:6]N<R!C86X@8F4@='5R
M;F5D(&]N('=H96X@8W)E871I;F<@80H@("`@("H@;F5W($1"(&]B:F5C="!O
M<B!B>2!U<VEN9R!S971/<'1I;VXH*2X*("`@("`J"B`@("`@*B`@("L@/'9A
M<CY$0E]03U)404))3$E465],3U=%4D-!4T4\+W9A<CX*("`@("`J("`@("!C
M;VYV97)T(&YA;65S(&]F(&9I96QD<R!T;R!L;W=E<B!C87-E"B`@("`@*@H@
M("`@("H@("`K(#QV87(^1$)?4$]25$%"24Q)5%E?4E1224T\+W9A<CX*("`@
M("`J("`@("!R:6=H="!T<FEM('1H92!D871A"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN="`D9F5T8VAM;V1E("!T:&4@8V]N<W1A;G0@:6YD:6-A=&EN9R!H
M;W<@=&\@9F]R;6%T('1H92!D871A"B`@("`@*B!`<&%R86T@:6YT("1R;W=N
M=6T@("`@('1H92!R;W<@;G5M8F5R('1O(&9E=&-H("AI;F1E>"!S=&%R=',@
M870@,"D*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!A;B!A<G)A>2!O
M<B!O8FIE8W0@8V]N=&%I;FEN9R!T:&4@<F]W)W,@9&%T82P*("`@("`J("`@
M("`@("`@("`@("`@("!.54Q,('=H96X@=&AE(&5N9"!O9B!T:&4@<F5S=6QT
M('-E="!I<R!R96%C:&5D"B`@("`@*B`@("`@("`@("`@("`@("`@;W(@82!$
M0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E
M($1"7V-O;6UO;CHZ<V5T3W!T:6]N*"DL($1"7V-O;6UO;CHZ<V5T1F5T8VA-
M;V1E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@)F9E=&-H4F]W*"1F971C:&UO
M9&4@/2!$0E]&151#2$U/1$5?1$5&055,5"P@)')O=VYU;2`](&YU;&PI"B`@
M("!["B`@("`@("`@:68@*"1F971C:&UO9&4@/3T]($1"7T9%5$-(34]$15]$
M149!54Q4*2!["B`@("`@("`@("`@("1F971C:&UO9&4@/2`D=&AI<RT^9F5T
M8VAM;V1E.PH@("`@("`@('T*("`@("`@("!I9B`H)&9E=&-H;6]D92`]/3T@
M1$)?1D540TA-3T1%7T]"2D5#5"D@>PH@("`@("`@("`@("`D9F5T8VAM;V1E
M(#T@1$)?1D540TA-3T1%7T%34T]#.PH@("`@("`@("`@("`D;V)J96-T7V-L
M87-S(#T@)'1H:7,M/F9E=&-H;6]D95]O8FIE8W1?8VQA<W,["B`@("`@("`@
M?0H@("`@("`@(&EF("@D=&AI<RT^;&EM:71?9G)O;2`A/3T@;G5L;"D@>PH@
M("`@("`@("`@("!I9B`H)'1H:7,M/G)O=U]C;W5N=&5R(#T]/2!N=6QL*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<F]W7V-O=6YT97(@/2`D=&AI<RT^
M;&EM:71?9G)O;3L*("`@("`@("`@("`@("`@("\O(%-K:7`@<F]W<PH@("`@
M("`@("`@("`@("`@:68@*"1T:&ES+3YD8F@M/F9E871U<F5S6R=L:6UI="==
M(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@("1I(#T@,#L*("`@
M("`@("`@("`@("`@("`@("!W:&EL92`H)&DK*R`\("1T:&ES+3YL:6UI=%]F
M<F]M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YD8F@M/F9E
M=&-H26YT;R@D=&AI<RT^<F5S=6QT+"`D87)R+"`D9F5T8VAM;V1E*3L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*"1T:&ES+3YR;W=?8V]U;G1E<B`^/2`H
M)'1H:7,M/FQI;6ET7V9R;VT@*R`D=&AI<RT^;&EM:71?8V]U;G0I*0H@("`@
M("`@("`@("!["B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F%U=&]F<F5E
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F9R964H*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T;7`@/2!N=6QL.PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1T;7`["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*"1T:&ES+3YD8F@M/F9E871U<F5S6R=L:6UI="==(#T]/2`G
M96UU;&%T92<I('L*("`@("`@("`@("`@("`@("1R;W=N=6T@/2`D=&AI<RT^
M<F]W7V-O=6YT97(["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M
M/G)O=U]C;W5N=&5R*RL["B`@("`@("`@?0H@("`@("`@("1R97,@/2`D=&AI
M<RT^9&)H+3YF971C:$EN=&\H)'1H:7,M/G)E<W5L="P@)&%R<BP@)&9E=&-H
M;6]D92P@)')O=VYU;2D["B`@("`@("`@:68@*"1R97,@/3T]($1"7T]+*2![
M"B`@("`@("`@("`@(&EF("AI<W-E="@D;V)J96-T7V-L87-S*2D@>PH@("`@
M("`@("`@("`@("`@+R\@5&AE(&1E9F%U;'0@;6]D92!I<R!S<&5C:69I960@
M:6X@=&AE"B`@("`@("`@("`@("`@("`O+R!$0E]C;VUM;VXZ.F9E=&-H;6]D
M95]O8FIE8W1?8VQA<W,@<')O<&5R='D*("`@("`@("`@("`@("`@(&EF("@D
M;V)J96-T7V-L87-S(#T]("=S=&1#;&%S<R<I('L*("`@("`@("`@("`@("`@
M("`@("`D87)R(#T@*&]B:F5C="D@)&%R<CL*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)&%R<B`]("9N97<@)&]B:F5C
M=%]C;&%S<R@D87)R*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!R971U<FX@)&%R<CL*("`@("`@("!]"B`@("`@("`@
M:68@*"1R97,@/3T@;G5L;"`F)B`D=&AI<RT^875T;V9R964I('L*("`@("`@
M("`@("`@)'1H:7,M/F9R964H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1R97,["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9F5T8VA);G1O
M*"D*"B`@("`O*BH*("`@("`J($9E=&-H(&$@<F]W(&]F(&1A=&$@:6YT;R!A
M;B!A<G)A>2!W:&EC:"!I<R!P87-S960@8GD@<F5F97)E;F-E"B`@("`@*@H@
M("`@("H@5&AE('1Y<&4@;V8@87)R87D@<F5T=7)N960@8V%N(&)E(&-O;G1R
M;VQL960@96ET:&5R(&)Y('-E='1I;F<@=&AI<PH@("`@("H@;65T:&]D)W,@
M/'9A<CXD9F5T8VAM;V1E/"]V87(^('!A<F%M971E<B!O<B!B>2!C:&%N9VEN
M9R!T:&4@9&5F875L=`H@("`@("H@9F5T8V@@;6]D92!S971&971C:$UO9&4H
M*2!B969O<F4@8V%L;&EN9R!T:&ES(&UE=&AO9"X*("`@("`J"B`@("`@*B!4
M:&5R92!A<F4@='=O(&]P=&EO;G,@9F]R('-T86YD87)D:7II;F<@=&AE(&EN
M9F]R;6%T:6]N(')E='5R;F5D"B`@("`@*B!F<F]M(&1A=&%B87-E<RP@96YS
M=7)I;F<@=&AE:7(@=F%L=65S(&%R92!C;VYS:7-T96YT('=H96X@8VAA;F=I
M;F<*("`@("`J($1"35,G<RX@(%1H97-E('!O<G1A8FEL:71Y(&]P=&EO;G,@
M8V%N(&)E('1U<FYE9"!O;B!W:&5N(&-R96%T:6YG(&$*("`@("`J(&YE=R!$
M0B!O8FIE8W0@;W(@8GD@=7-I;F<@<V5T3W!T:6]N*"DN"B`@("`@*@H@("`@
M("H@("`K(#QV87(^1$)?4$]25$%"24Q)5%E?3$]715)#05-%/"]V87(^"B`@
M("`@*B`@("`@8V]N=F5R="!N86UE<R!O9B!F:65L9',@=&\@;&]W97(@8V%S
M90H@("`@("H*("`@("`J("`@*R`\=F%R/D1"7U!/4E1!0DE,25197U)44DE-
M/"]V87(^"B`@("`@*B`@("`@<FEG:'0@=')I;2!T:&4@9&%T80H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`F)&%R<B`@("`@("!T:&4@=F%R:6%B;&4@
M=VAE<F4@=&AE(&1A=&$@<VAO=6QD(&)E('!L86-E9`H@("`@("H@0'!A<F%M
M(&EN="`@("1F971C:&UO9&4@('1H92!C;VYS=&%N="!I;F1I8V%T:6YG(&AO
M=R!T;R!F;W)M870@=&AE(&1A=&$*("`@("`J($!P87)A;2!I;G0@("`D<F]W
M;G5M("`@("!T:&4@<F]W(&YU;6)E<B!T;R!F971C:"`H:6YD97@@<W1A<G1S
M(&%T(#`I"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1$)?3TL@:68@
M82!R;W<@:7,@<')O8V5S<V5D+"!.54Q,('=H96X@=&AE(&5N9"!O9B!T:&4*
M("`@("`J("`@("`@("`@("`@("`@("!R97-U;'0@<V5T(&ES(')E86-H960@
M;W(@82!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R90H@("`@("H*("`@("`J
M($!S964@1$)?8V]M;6]N.CIS971/<'1I;VXH*2P@1$)?8V]M;6]N.CIS971&
M971C:$UO9&4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!F971C:$EN=&\H)B1A
M<G(L("1F971C:&UO9&4@/2!$0E]&151#2$U/1$5?1$5&055,5"P@)')O=VYU
M;2`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"1F971C:&UO9&4@/3T]($1"
M7T9%5$-(34]$15]$149!54Q4*2!["B`@("`@("`@("`@("1F971C:&UO9&4@
M/2`D=&AI<RT^9F5T8VAM;V1E.PH@("`@("`@('T*("`@("`@("!I9B`H)&9E
M=&-H;6]D92`]/3T@1$)?1D540TA-3T1%7T]"2D5#5"D@>PH@("`@("`@("`@
M("`D9F5T8VAM;V1E(#T@1$)?1D540TA-3T1%7T%34T]#.PH@("`@("`@("`@
M("`D;V)J96-T7V-L87-S(#T@)'1H:7,M/F9E=&-H;6]D95]O8FIE8W1?8VQA
M<W,["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;&EM:71?9G)O;2`A
M/3T@;G5L;"D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/G)O=U]C;W5N=&5R
M(#T]/2!N=6QL*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<F]W7V-O=6YT
M97(@/2`D=&AI<RT^;&EM:71?9G)O;3L*("`@("`@("`@("`@("`@("\O(%-K
M:7`@<F]W<PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YD8F@M/F9E871U
M<F5S6R=L:6UI="==(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@
M("1I(#T@,#L*("`@("`@("`@("`@("`@("`@("!W:&EL92`H)&DK*R`\("1T
M:&ES+3YL:6UI=%]F<F]M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YD8F@M/F9E=&-H26YT;R@D=&AI<RT^<F5S=6QT+"`D87)R+"`D9F5T
M8VAM;V1E*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1T:&ES+3YR;W=?
M8V]U;G1E<B`^/2`H"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQI;6ET
M7V9R;VT@*R`D=&AI<RT^;&EM:71?8V]U;G0I*0H@("`@("`@("`@("!["B`@
M("`@("`@("`@("`@("!I9B`H)'1H:7,M/F%U=&]F<F5E*2!["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F9R964H*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&EF("@D=&AI<RT^9&)H+3YF96%T=7)E<ULG;&EM:70G72`]
M/3T@)V5M=6QA=&4G*2!["B`@("`@("`@("`@("`@("`D<F]W;G5M(#T@)'1H
M:7,M/G)O=U]C;W5N=&5R.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M=&AI<RT^<F]W7V-O=6YT97(K*SL*("`@("`@("!]"B`@("`@("`@)')E<R`]
M("1T:&ES+3YD8F@M/F9E=&-H26YT;R@D=&AI<RT^<F5S=6QT+"`D87)R+"`D
M9F5T8VAM;V1E+"`D<F]W;G5M*3L*("`@("`@("!I9B`H)')E<R`]/3T@1$)?
M3TLI('L*("`@("`@("`@("`@:68@*&ES<V5T*"1O8FIE8W1?8VQA<W,I*2![
M"B`@("`@("`@("`@("`@("`O+R!D969A=6QT(&UO9&4@<W!E8VEF:65D(&EN
M('1H90H@("`@("`@("`@("`@("`@+R\@1$)?8V]M;6]N.CIF971C:&UO9&5?
M;V)J96-T7V-L87-S('!R;W!E<G1Y"B`@("`@("`@("`@("`@("!I9B`H)&]B
M:F5C=%]C;&%S<R`]/2`G<W1D0VQA<W,G*2!["B`@("`@("`@("`@("`@("`@
M("`@)&%R<B`]("AO8FIE8W0I("1A<G(["B`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("1A<G(@/2!N97<@)&]B:F5C=%]C
M;&%S<R@D87)R*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!R971U<FX@1$)?3TL["B`@("`@("`@?0H@("`@("`@(&EF
M("@D<F5S(#T](&YU;&P@)B8@)'1H:7,M/F%U=&]F<F5E*2!["B`@("`@("`@
M("`@("1T:&ES+3YF<F5E*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D
M<F5S.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YU;4-O;',H*0H*
M("`@("\J*@H@("`@("H@1V5T('1H92!T:&4@;G5M8F5R(&]F(&-O;'5M;G,@
M:6X@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H
M92!N=6UB97(@;V8@8V]L=6UN<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU;4-O;',H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^9&)H+3YN=6U#;VQS*"1T:&ES+3YR97-U
M;'0I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YU;5)O=W,H*0H*
M("`@("\J*@H@("`@("H@1V5T('1H92!N=6UB97(@;V8@<F]W<R!I;B!A(')E
M<W5L="!S970*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E
M<B!O9B!R;W=S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@;G5M4F]W<R@I"B`@("!["B`@("`@("`@:68@
M*"1T:&ES+3YD8F@M/F9E871U<F5S6R=N=6UR;W=S)UT@/3T]("=E;75L871E
M)PH@("`@("`@("`@("`F)B`D=&AI<RT^9&)H+3YO<'1I;VYS6R=P;W)T86)I
M;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3E5-4D]74RD*("`@("`@("!["B`@
M("`@("`@("`@(&EF("@D=&AI<RT^9&)H+3YF96%T=7)E<ULG<')E<&%R92==
M*2!["B`@("`@("`@("`@("`@("`D<F5S(#T@)'1H:7,M/F1B:"T^<75E<GDH
M)'1H:7,M/G%U97)Y+"`D=&AI<RT^<&%R86UE=&5R<RD["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D<F5S(#T@)'1H:7,M/F1B:"T^
M<75E<GDH)'1H:7,M/G%U97)Y*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H1$(Z.FES17)R;W(H)')E<RDI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5S.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1I(#T@,#L*
M("`@("`@("`@("`@=VAI;&4@*"1R97,M/F9E=&-H26YT;R@D=&UP+"!$0E]&
M151#2$U/1$5?3U)$15)%1"DI('L*("`@("`@("`@("`@("`@("1I*RL["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9&)H+3YN=6U2;W=S
M*"1T:&ES+3YR97-U;'0I.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!N97AT4F5S=6QT*"D*"B`@("`O*BH*("`@("`J($=E="!T
M:&4@;F5X="!R97-U;'0@:68@82!B871C:"!O9B!Q=65R:65S('=A<R!E>&5C
M=71E9`H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@=')U92!I9B!A(&YE
M=R!R97-U;'0@:7,@879A:6QA8FQE(&]R(&9A;'-E(&EF(&YO=`H@("`@("HO
M"B`@("!F=6YC=&EO;B!N97AT4F5S=6QT*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/F1B:"T^;F5X=%)E<W5L="@D=&AI<RT^<F5S=6QT*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F<F5E*"D*"B`@("`O*BH*("`@
M("`J($9R965S('1H92!R97-O=7)C97,@86QL;V-A=&5D(&9O<B!T:&ES(')E
M<W5L="!S970*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@('1R=64@;VX@
M<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&9R964H*0H@("`@>PH@("`@("`@("1E<G(@/2`D
M=&AI<RT^9&)H+3YF<F5E4F5S=6QT*"1T:&ES+3YR97-U;'0I.PH@("`@("`@
M(&EF("A$0CHZ:7-%<G)O<B@D97)R*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&5R<CL*("`@("`@("!]"B`@("`@("`@)'1H:7,M/G)E<W5L="`](&9A;'-E
M.PH@("`@("`@("1T:&ES+3YS=&%T96UE;G0@/2!F86QS93L*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!T86)L
M94EN9F\H*0H*("`@("\J*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G1A8FQE
M26YF;R@I"B`@("`@*B!`9&5P<F5C871E9"!-971H;V0@9&5P<F5C871E9"!S
M;VUE('1I;64@8F5F;W)E(%)E;&5A<V4@,2XR"B`@("`@*B\*("`@(&9U;F-T
M:6]N('1A8FQE26YF;R@D;6]D92`](&YU;&PI"B`@("!["B`@("`@("`@:68@
M*&ES7W-T<FEN9R@D;6]D92DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YD8F@M/G)A:7-E17)R;W(H1$)?15)23U)?3D5%1%]-3U)%7T1!5$$I.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/F1B:"T^=&%B;&5);F9O
M*"1T:&ES+"`D;6]D92D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M9V5T475E<GDH*0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE('1H92!Q=65R
M>2!S=')I;F<@=&AA="!C<F5A=&5D('1H:7,@<F5S=6QT"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@('1H92!Q=65R>2!S=')I;F<*("`@("`J"B`@
M("`@*B!`<VEN8V4@365T:&]D(&%V86EL86)L92!S:6YC92!296QE87-E(#$N
M-RXP"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%%U97)Y*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/G%U97)Y.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&=E=%)O=T-O=6YT97(H*0H*("`@("\J*@H@("`@("H@5&5L
M;',@=VAI8V@@<F]W(&YU;6)E<B!I<R!C=7)R96YT;'D@8F5I;F<@<')O8V5S
M<V5D"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!T:&4@8W5R<F5N
M="!R;W<@8F5I;F<@;&]O:V5D(&%T+B`@4W1A<G1S(&%T(#$N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%)O=T-O=6YT97(H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^<F]W7V-O=6YT97(["B`@("!]"@H@("`@+R\@?7U]"GT*
M"B\O('U]?0HO+R![>WL@8VQA<W,@1$)?<F]W"@HO*BH*("H@4$5!4B!$0B!2
M;W<@3V)J96-T"B`J"B`J(%1H92!O8FIE8W0@8V]N=&%I;G,@82!R;W<@;V8@
M9&%T82!F<F]M(&$@<F5S=6QT('-E="X@($5A8V@@8V]L=6UN)W,@9&%T80H@
M*B!I<R!P;&%C960@:6X@82!P<F]P97)T>2!N86UE9"!F;W(@=&AE(&-O;'5M
M;BX*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@
M1$(*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@H@
M*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC
M96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!0
M2%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XW+C8*
M("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1"
M"B`J($!S964@("`@("`@($1"7V-O;6UO;CHZ<V5T1F5T8VA-;V1E*"D*("HO
M"F-L87-S($1"7W)O=PI["B`@("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@("`O
M*BH*("`@("`J(%1H92!C;VYS=')U8W1O<B!P;&%C97,@82!R;W<G<R!D871A
M(&EN=&\@<')O<&5R=&EE<R!O9B!T:&ES(&]B:F5C=`H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`@=&AE(&%R<F%Y(&-O;G1A:6YI;F<@=&AE(')O=R=S
M(&1A=&$*("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@
M9G5N8W1I;VX@1$)?<F]W*"8D87)R*0H@("`@>PH@("`@("`@(&9O<F5A8V@@
M*"1A<G(@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@)'1H:7,M
M/B1K97D@/2`F)&%R<ELD:V5Y73L*("`@("`@("!]"B`@("!]"@H@("`@+R\@
M?7U]"GT*"B\O('U]?0H*+RH*("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M
M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z(#0*("H@16YD.@H@*B\*"C\^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R\`````````````````````
M````````````````````````````````````````````````````````````
M````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T
M,S,W,S8`,#$W-3,V`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S
M+T%R8VAI=F5?5&%R+P``````````````````````````````````````````
M```````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#4Q-30S,S<S-0`P,C$W,C0`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+V1O8W,O07)C:&EV95]487(O9&]C<R\`````````````
M`````````````````````````````````````````````````#`P,#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S,U`#`R,C8U
M-``@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]!<F-H:79E7U1A
M<B]D;V-S+T%R8VAI=F5?5&%R+G1X=```````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#0V,3``
M,3`U,34T,S,W,S4`,#(U-C$Q`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````$1O8W5M96YT871I;VX@9F]R(&-L87-S($%R8VAI
M=F5?5&%R#0H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0T*
M3&%S="!U<&1A=&4@.B`R,#`Q+3`X+3$U#0H-"@T*#0I/=F5R=FEE=R`Z#0HM
M+2TM+2TM+2TM#0H-"B`@5&AE($%R8VAI=F5?5&%R(&-L87-S(&AE;'!S(&EN
M(&-R96%T:6YG(&%N9"!M86YA9VEN9R!'3E4@5$%2(&9O<FUA=`T*("!F:6QE
M<R!C;VUP<F5S<V5D(&)Y($=.52!:25`@;W(@;F]T+B`-"B`@5&AE(&-L87-S
M(&]F9F5R<R!B87-I8R!F=6YC=&EO;G,@;&EK92!C<F5A=&EN9R!A;B!A<F-H
M:79E+"!A9&1I;F<-"B`@9FEL97,@:6X@=&AE(&%R8VAI=F4L(&5X=')A8W1I
M;F<@9FEL97,@9G)O;2!T:&4@87)C:&EV92!A;F0@;&ES=&EN9PT*("!T:&4@
M87)C:&EV92!C;VYT96YT+B`-"B`@270@86QS;R!P<F]V:61E(&%D=F%N8V5D
M(&9U;F-T:6]N<R!T:&%T(&%L;&]W('1H92!A9&1I;F<@86YD#0H@(&5X=')A
M8W1I;VX@;V8@9FEL97,@=VET:"!P871H(&UA;FEP=6QA=&EO;BX@#0H-"@T*
M4V%M<&QE(#H-"BTM+2TM+2TM#0H-"B`@+R\@+2TM+2T@0W)E871I;F<@=&AE
M(&]B:F5C="`H=6YC;VUP<F5S<V5D(&%R8VAI=F4I#0H@("1T87)?;V)J96-T
M(#T@;F5W($%R8VAI=F5?5&%R*")T87)N86UE+G1A<B(I.PT*("`D=&%R7V]B
M:F5C="T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U!224Y4*3L-"@T*
M("`O+R`M+2TM+2!#<F5A=&EN9R!T:&4@87)C:&EV90T*("`D=E]L:7-T6S!=
M/2)F:6QE+G1X="([#0H@("1V7VQI<W1;,5T](F1A=&$O(CL-"B`@)'9?;&ES
M=%LR73TB9FEL92YL;V<B.PT*("`D=&%R7V]B:F5C="T^8W)E871E*"1V7VQI
M<W0I.PT*#0H@("\O("TM+2TM($%D9&EN9R!F:6QE<PT*("`D=E]L:7-T6S!=
M/2)D978O9FEL92YT>'0B.PT*("`D=E]L:7-T6S%=/2)D978O9&%T82\B.PT*
M("`D=E]L:7-T6S)=/2)L;V<O9FEL92YL;V<B.PT*("`D=&%R7V]B:F5C="T^
M861D*"1V7VQI<W0I.PT*#0H@("\O("TM+2TM($%D9&EN9R!M;W)E(&9I;&5S
M#0H@("1T87)?;V)J96-T+3YA9&0H(G)E;&5A<V4O;F5W9FEL92YL;V<@<F5L
M96%S92]R96%D;64N='AT(BD[#0H-"B`@+R\@+2TM+2T@3&ES=&EN9R!T:&4@
M8V]N=&5N=`T*("!I9B`H*"1V7VQI<W0@(#T@("1T87)?;V)J96-T+3YL:7-T
M0V]N=&5N="@I*2`A/2`P*0T*("`@(&9O<B`H)&D],#L@)&D\<VEZ96]F*"1V
M7VQI<W0I.R`D:2LK*0T*("`@('L-"B`@("`@(&5C:&\@(D9I;&5N86UE(#HG
M(BXD=E]L:7-T6R1I75MF:6QE;F%M95TN(B<\8G(^(CL-"B`@("`@(&5C:&\@
M(B`N<VEZ92`Z)R(N)'9?;&ES=%LD:5U;<VEZ95TN(B<\8G(^(CL-"B`@("`@
M(&5C:&\@(B`N;71I;64@.B<B+B1V7VQI<W1;)&E=6VUT:6UE72XB)R`H(BYD
M871E*")L(&13(&]F($8@62!H.FDZ<R!!(BP@)'9?;&ES=%LD:5U;;71I;65=
M*2XB*3QB<CXB.PT*("`@("`@96-H;R`B("YM;V1E(#HG(BXD=E]L:7-T6R1I
M75MM;V1E72XB)SQB<CXB.PT*("`@("`@96-H;R`B("YU:60@.B<B+B1V7VQI
M<W1;)&E=6W5I9%TN(B<\8G(^(CL-"B`@("`@(&5C:&\@(B`N9VED(#HG(BXD
M=E]L:7-T6R1I75MG:61=+B(G/&)R/B([#0H@("`@("!E8VAO("(@+G1Y<&5F
M;&%G(#HG(BXD=E]L:7-T6R1I75MT>7!E9FQA9UTN(B<\8G(^(CL-"B`@("!]
M#0H-"B`@+R\@+2TM+2T@17AT<F%C=&EN9R!T:&4@87)C:&EV92!I;B!D:7)E
M8W1O<GD@(FEN<W1A;&PB#0H@("1T87)?;V)J96-T+3YE>'1R86-T*")I;G-T
M86QL(BD[#0H-"@T*4'5B;&EC(&%R9W5M96YT<R`Z#0HM+2TM+2TM+2TM+2TM
M+2TM+2T-"@T*3F]N90T*#0H-"E!U8FQI8R!-971H;V1S(#H-"BTM+2TM+2TM
M+2TM+2TM+2T-"@T*365T:&]D(#H@07)C:&EV95]487(H)'!?=&%R;F%M92P@
M)&-O;7!R97-S(#T@;G5L;"D-"D1E<V-R:7!T:6]N(#H-"B`@07)C:&EV95]4
M87(@0VQA<W,@8V]N<W1R=6-T;W(N(%1H:7,@9FQA=F]U<B!O9B!T:&4@8V]N
M<W1R=6-T;W(@;VYL>0T*("!D96-L87)E(&$@;F5W($%R8VAI=F5?5&%R(&]B
M:F5C="P@:61E;G1I9GEI;F<@:70@8GD@=&AE(&YA;64@;V8@=&AE#0H@('1A
M<B!F:6QE+@T*("!)9B!T:&4@8V]M<')E<W,@87)G=6UE;G0@:7,@<V5T('1H
M92!T87(@=VEL;"!B92!R96%D(&]R(&-R96%T960@87,@80T*("!G>FEP(&]R
M(&)Z,B!C;VUP<F5S<V5D(%1!4B!F:6QE+B`-"D%R9W5M96YT<R`Z#0H@("1P
M7W1A<FYA;64@.B!!('9A;&ED(&9I;&5N86UE(&9O<B!T:&4@=&%R(&%R8VAI
M=F4@9FEL92X-"B`@)'!?8V]M<')E<W,@.B!C86X@8F4@;G5L;"P@)V=Z)R!O
M<B`G8GHR)RX@1F]R#0H@("`@("`@("`@("`@("`@8V]M<&%T:6)I;&ET>2!R
M96%S;VX@:70@8V%N(&%L<V\@8F4@=')U92X@5&AI<PT*("`@("`@("`@("`@
M("`@('!A<F%M971E<B!I;F1I8V%T97,@:68@9WII<"!O<B!B>C(@8V]M<')E
M<W-I;VX-"B`@("`@("`@("`@("`@("!I<R!R97%U:7)E9"X@#0I2971U<FX@
M=F%L=64@.@T*("!4:&4@07)C:&EV95]487(@;V)J96-T+@T*4V%M<&QE(#H-
M"B`@)'1A<E]O8FIE8W0@/2!N97<@07)C:&EV95]487(H(G1A<FYA;64N=&%R
M(BD[#0H@("1T87)?;V)J96-T7V-O;7!R97-S960@/2!N97<@07)C:&EV95]4
M87(H(G1A<FYA;64N=&=Z(BP@=')U92D[#0I(;W<@:70@=V]R:W,@.@T*("!)
M;FET:6%L:7IE('1H92!O8FIE8W0N#0H-"DUE=&AO9"`Z(&-R96%T92@D<%]F
M:6QE;&ES="D-"D1E<V-R:7!T:6]N(#H-"B`@5&AI<R!M971H;V0@8W)E871E
M<R!T:&4@87)C:&EV92!F:6QE(&%N9"!A9&0@=&AE(&9I;&5S("\@9&ER96-T
M;W)I97,-"B`@=&AA="!A<F4@;&ES=&5D(&EN("1P7V9I;&5L:7-T+B`-"B`@
M268@=&AE(&9I;&4@86QR96%D>2!E>&ES=',@86YD(&ES('=R:71A8FQE+"!I
M="!I<R!R97!L86-E9"!B>2!T:&4-"B`@;F5W('1A<BX@270@:7,@82!C<F5A
M=&4@86YD(&YO="!A;B!A9&0N($EF('1H92!F:6QE(&5X:7-T<R!A;F0@:7,-
M"B`@<F5A9"UO;FQY(&]R(&ES(&$@9&ER96-T;W)Y(&ET(&ES(&YO="!R97!L
M86-E9"X@5&AE(&UE=&AO9"!R971U<FX-"B`@9F%L<V4@86YD(&$@4$5!4B!E
M<G)O<B!T97AT+B`-"B`@5&AE("1P7V9I;&5L:7-T('!A<F%M971E<B!C86X@
M8F4@86X@87)R87D@;V8@<W1R:6YG+"!E86-H('-T<FEN9PT*("!R97!R97-E
M;G1I;F<@82!F:6QE;F%M92!O<B!A(&1I<F5C=&]R>2!N86UE('=I=&@@=&AE
M:7(@<&%T:"!I9@T*("!N965D960N($ET(&-A;B!A;'-O(&)E(&$@<VEN9VQE
M('-T<FEN9R!W:71H(&YA;65S('-E<&%R871E9"!B>2!A#0H@('-I;F=L92!B
M;&%N:RX@#0H@(%-E92!A;'-O(&-R96%T94UO9&EF>2@I(&UE=&AO9"!F;W(@
M;6]R92!D971A:6QS+@T*07)G=6UE;G1S(#H-"B`@)'!?9FEL96QI<W0@.B!!
M;B!A<G)A>2!O9B!F:6QE;F%M97,@86YD(&1I<F5C=&]R>2!N86UE<RP@;W(@
M82!S:6YG;&4-"B`@<W1R:6YG('=I=&@@;F%M97,@<V5P87)A=&5D(&)Y(&$@
M<VEN9VQE(&)L86YK('-P86-E+B`-"E)E='5R;B!V86QU92`Z#0H@('1R=64@
M;VX@<W5C8V5S<RP@9F%L<V4@;VX@97)R;W(N#0I386UP;&4@,2`Z#0H@("1T
M87)?;V)J96-T(#T@;F5W($%R8VAI=F5?5&%R*")T87)N86UE+G1A<B(I.PT*
M("`D=&%R7V]B:F5C="T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U!2
M24Y4*3L@("\O($]P=&EO;F%L(&5R<F]R(&AA;F1L:6YG#0H@("1V7VQI<W1;
M,%T](F9I;&4N='AT(CL-"B`@)'9?;&ES=%LQ73TB9&%T82\B.R`H3W!T:6]N
M86P@)R\G(&%T('1H92!E;F0I#0H@("1V7VQI<W1;,ET](F9I;&4N;&]G(CL-
M"B`@)'1A<E]O8FIE8W0M/F-R96%T92@D=E]L:7-T*3L-"E-A;7!L92`R(#H-
M"B`@)'1A<E]O8FIE8W0@/2!N97<@07)C:&EV95]487(H(G1A<FYA;64N=&%R
M(BD[#0H@("1T87)?;V)J96-T+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)2
M3U)?4%))3E0I.R`@+R\@3W!T:6]N86P@97)R;W(@:&%N9&QI;F<-"B`@)'1A
M<E]O8FIE8W0M/F-R96%T92@B9FEL92YT>'0@9&%T82\@9FEL92YL;V<B*3L-
M"DAO=R!I="!W;W)K<R`Z#0H@($IU<W0@8V%L;&EN9R!T:&4@8W)E871E36]D
M:69Y*"D@;65T:&]D('=I=&@@=&AE(')I9VAT('!A<F%M971E<G,N#0H-"DUE
M=&AO9"`Z(&-R96%T94UO9&EF>2@D<%]F:6QE;&ES="P@)'!?861D7V1I<BP@
M)'!?<F5M;W9E7V1I<B`]("(B*0T*1&5S8W)I<'1I;VX@.@T*("!4:&ES(&UE
M=&AO9"!C<F5A=&5S('1H92!A<F-H:79E(&9I;&4@86YD(&%D9"!T:&4@9FEL
M97,@+R!D:7)E8W1O<FEE<PT*("!T:&%T(&%R92!L:7-T960@:6X@)'!?9FEL
M96QI<W0N(`T*("!)9B!T:&4@9FEL92!A;')E861Y(&5X:7-T<R!A;F0@:7,@
M=W)I=&%B;&4L(&ET(&ES(')E<&QA8V5D(&)Y('1H90T*("!N97<@=&%R+B!)
M="!I<R!A(&-R96%T92!A;F0@;F]T(&%N(&%D9"X@268@=&AE(&9I;&4@97AI
M<W1S(&%N9"!I<PT*("!R96%D+6]N;'D@;W(@:7,@82!D:7)E8W1O<GD@:70@
M:7,@;F]T(')E<&QA8V5D+B!4:&4@;65T:&]D(')E='5R;@T*("!F86QS92!A
M;F0@82!014%2(&5R<F]R('1E>'0N(`T*("!4:&4@)'!?9FEL96QI<W0@<&%R
M86UE=&5R(&-A;B!B92!A;B!A<G)A>2!O9B!S=')I;F<L(&5A8V@@<W1R:6YG
M#0H@(')E<')E<V5N=&EN9R!A(&9I;&5N86UE(&]R(&$@9&ER96-T;W)Y(&YA
M;64@=VET:"!T:&5I<B!P871H(&EF#0H@(&YE961E9"X@270@8V%N(&%L<V\@
M8F4@82!S:6YG;&4@<W1R:6YG('=I=&@@;F%M97,@<V5P87)A=&5D(&)Y(&$-
M"B`@<VEN9VQE(&)L86YK+B`-"B`@5&AE('!A=&@@:6YD:6-A=&5D(&EN("1P
M7W)E;6]V95]D:7(@=VEL;"!B92!R96UO=F5D(&9R;VT@=&AE#0H@(&UE;6]R
M:7IE9"!P871H(&]F(&5A8V@@9FEL92`O(&1I<F5C=&]R>2!L:7-T960@=VAE
M;B!T:&ES('!A=&@-"B`@97AI<W1S+B!">2!D969A=6QT(&YO=&AI;F<@:7,@
M<F5M;W9E9"`H96UP='D@<&%T:"`B(BD@#0H@(%1H92!P871H(&EN9&EC871E
M9"!I;B`D<%]A9&1?9&ER('=I;&P@8F4@861D960@870@=&AE(&)E9VEN;FEN
M9R!O9@T*("!T:&4@;65M;W)I>F5D('!A=&@@;V8@96%C:"!F:6QE("\@9&ER
M96-T;W)Y(&QI<W1E9"X@2&]W979E<B!I="!C86X-"B`@8F4@<V5T('1O(&5M
M<'1Y("(B+B!4:&4@861D:6YG(&]F(&$@<&%T:"!I<R!D;VYE(&%F=&5R('1H
M92!R96UO=FEN9PT*("!O9B!P871H+B`-"B`@5&AE('!A=&@@861D+W)E;6]V
M92!A8FEL:71Y(&5N86)L97,@=&AE('5S97(@=&\@<')E<&%R92!A;B!A<F-H
M:79E#0H@(&9O<B!E>'1R86-T:6]N(&EN(&$@9&EF9F5R96YT('!A=&@@=&AA
M;B!T:&4@;W)I9VEN(&9I;&5S(&%R92X@#0H@(%-E92!A;'-O(&%D9$UO9&EF
M>2@I(&UE=&AO9"!F;W(@9FEL92!A9&1I;F<@<')O<&5R=&EE<RX-"D%R9W5M
M96YT<R`Z#0H@("1P7V9I;&5L:7-T(#H@06X@87)R87D@;V8@9FEL96YA;65S
M(&%N9"!D:7)E8W1O<GD@;F%M97,L(&]R(&$@<VEN9VQE#0H@("`@("`@("`@
M("`@("`@<W1R:6YG('=I=&@@;F%M97,@<V5P87)A=&5D(&)Y(&$@<VEN9VQE
M(&)L86YK('-P86-E+@T*("`D<%]A9&1?9&ER(#H@02!S=')I;F<@=VAI8V@@
M8V]N=&%I;G,@82!P871H('1O(&)E(&%D9&5D('1O('1H90T*("`@("`@("`@
M("`@("`@;65M;W)I>F5D('!A=&@@;V8@96%C:"!E;&5M96YT(&EN('1H92!L
M:7-T+B`-"B`@)'!?<F5M;W9E7V1I<B`Z($$@<W1R:6YG('=H:6-H(&-O;G1A
M:6YS(&$@<&%T:"!T;R!B92!R96UO=F5D(&9R;VT-"B`@("`@("`@("`@("`@
M("`@('1H92!M96UO<FEZ960@<&%T:"!O9B!E86-H(&5L96UE;G0@:6X@=&AE
M(&QI<W0L('=H96X-"@D)("!R96QE=F%N="X-"E)E='5R;B!V86QU92`Z#0H@
M('1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@97)R;W(N#0I386UP;&4@,2`Z
M#0H@("1T87)?;V)J96-T(#T@;F5W($%R8VAI=F5?5&%R*")T87)N86UE+G1A
M<B(I.PT*("`D=&%R7V]B:F5C="T^<V5T17)R;W)(86YD;&EN9RA014%27T52
M4D]27U!224Y4*3L@("\O($]P=&EO;F%L(&5R<F]R(&AA;F1L:6YG#0H@("1V
M7VQI<W1;,%T](F9I;&4N='AT(CL-"B`@)'9?;&ES=%LQ73TB9&%T82\B.R`H
M3W!T:6]N86P@)R\G(&%T('1H92!E;F0I#0H@("1V7VQI<W1;,ET](F9I;&4N
M;&]G(CL-"B`@)'1A<E]O8FIE8W0M/F-R96%T94UO9&EF>2@D=E]L:7-T+"`B
M:6YS=&%L;"(I.PT*("`O+R!F:6QE<R!A<F4@<W1O<F5D(&EN('1H92!A<F-H
M:79E(&%S(#H-"B`@+R\@("!I;G-T86QL+V9I;&4N='AT#0H@("\O("`@:6YS
M=&%L;"]D871A#0H@("\O("`@:6YS=&%L;"]D871A+V9I;&4Q+G1X=`T*("`O
M+R`@(&EN<W1A;&PO9&%T82\N+BX@86QL('1H92!F:6QE<R!A;F0@<W5B+61I
M<G,@;V8@9&%T82\-"B`@+R\@("!I;G-T86QL+V9I;&4N;&]G#0I386UP;&4@
M,B`Z#0H@("1T87)?;V)J96-T(#T@;F5W($%R8VAI=F5?5&%R*")T87)N86UE
M+G1A<B(I.PT*("`D=&%R7V]B:F5C="T^<V5T17)R;W)(86YD;&EN9RA014%2
M7T524D]27U!224Y4*3L@("\O($]P=&EO;F%L(&5R<F]R(&AA;F1L:6YG#0H@
M("1V7VQI<W1;,%T](F1E=B]F:6QE+G1X="([#0H@("1V7VQI<W1;,5T](F1E
M=B]D871A+R([("A/<'1I;VYA;"`G+R<@870@=&AE(&5N9"D-"B`@)'9?;&ES
M=%LR73TB;&]G+V9I;&4N;&]G(CL-"B`@)'1A<E]O8FIE8W0M/F-R96%T94UO
M9&EF>2@D=E]L:7-T+"`B:6YS=&%L;"(L(")D978B*3L-"B`@+R\@9FEL97,@
M87)E('-T;W)E9"!I;B!T:&4@87)C:&EV92!A<R`Z#0H@("\O("`@:6YS=&%L
M;"]F:6QE+G1X=`T*("`O+R`@(&EN<W1A;&PO9&%T80T*("`O+R`@(&EN<W1A
M;&PO9&%T82]F:6QE,2YT>'0-"B`@+R\@("!I;G-T86QL+V1A=&$O+BXN(&%L
M;"!T:&4@9FEL97,@86YD('-U8BUD:7)S(&]F(&1A=&$O#0H@("\O("`@:6YS
M=&%L;"]L;V<O9FEL92YL;V<-"DAO=R!I="!W;W)K<R`Z#0H@($]P96X@=&AE
M(&9I;&4@:6X@=W)I=&4@;6]D92`H97)A<VEN9R!T:&4@97AI<W1I;F<@;VYE
M(&EF(&]N92DL#0H@(&-A;&P@=&AE(%]A9&1,:7-T*"D@;65T:&]D(&9O<B!A
M9&1I;F<@=&AE(&9I;&5S(&EN(&%N(&5M<'1Y(&%R8VAI=F4L#0H@(&%D9"!T
M:&4@=&%R(&9O;W1E<B`H-3$R(&)Y=&5S(&)L;V-K*2P@8VQO<V4@=&AE('1A
M<B!F:6QE+@T*#0H-"DUE=&AO9"`Z(&%D9$UO9&EF>2@D<%]F:6QE;&ES="P@
M)'!?861D7V1I<BP@)'!?<F5M;W9E7V1I<CTB(BD-"D1E<V-R:7!T:6]N(#H-
M"B`@5&AI<R!M971H;V0@861D('1H92!F:6QE<R`O(&1I<F5C=&]R:65S(&QI
M<W1E9"!I;B`D<%]F:6QE;&ES="!A="!T:&4-"B`@96YD(&]F('1H92!E>&ES
M=&EN9R!A<F-H:79E+B!)9B!T:&4@87)C:&EV92!D;V5S(&YO="!Y970@97AI
M<W1S(&ET#0H@(&ES(&-R96%T960N#0H@(%1H92`D<%]F:6QE;&ES="!P87)A
M;65T97(@8V%N(&)E(&%N(&%R<F%Y(&]F('-T<FEN9RP@96%C:"!S=')I;F<-
M"B`@<F5P<F5S96YT:6YG(&$@9FEL96YA;64@;W(@82!D:7)E8W1O<GD@;F%M
M92!W:71H('1H96ER('!A=&@@:68-"B`@;F5E9&5D+B!)="!C86X@86QS;R!B
M92!A('-I;F=L92!S=')I;F<@=VET:"!N86UE<R!S97!A<F%T960@8GD@80T*
M("!S:6YG;&4@8FQA;FLN(`T*("!4:&4@<&%T:"!I;F1I8V%T960@:6X@)'!?
M<F5M;W9E7V1I<B!W:6QL(&)E(')E;6]V960@9G)O;2!T:&4-"B`@;65M;W)I
M>F5D('!A=&@@;V8@96%C:"!F:6QE("\@9&ER96-T;W)Y(&QI<W1E9"!W:&5N
M('1H:7,@<&%T:`T*("!E>&ES=',N($)Y(&1E9F%U;'0@;F]T:&EN9R!I<R!R
M96UO=F5D("AE;7!T>2!P871H("(B*2`-"B`@5&AE('!A=&@@:6YD:6-A=&5D
M(&EN("1P7V%D9%]D:7(@=VEL;"!B92!A9&1E9"!A="!T:&4@8F5G:6YN:6YG
M(&]F#0H@('1H92!M96UO<FEZ960@<&%T:"!O9B!E86-H(&9I;&4@+R!D:7)E
M8W1O<GD@;&ES=&5D+B!(;W=E=F5R(&ET(&-A;@T*("!B92!S970@=&\@96UP
M='D@(B(N(%1H92!A9&1I;F<@;V8@82!P871H(&ES(&1O;F4@869T97(@=&AE
M(')E;6]V:6YG#0H@(&]F('!A=&@N(`T*("!4:&4@<&%T:"!A9&0O<F5M;W9E
M(&%B:6QI='D@96YA8FQE<R!T:&4@=7-E<B!T;R!P<F5P87)E(&%N(&%R8VAI
M=F4-"B`@9F]R(&5X=')A8W1I;VX@:6X@82!D:69F97)E;G0@<&%T:"!T:&%N
M('1H92!O<FEG:6X@9FEL97,@87)E+B`-"B`@268@82!F:6QE+V1I<B!I<R!A
M;')E861Y(&EN('1H92!A<F-H:79E(&ET('=I;&P@;VYL>2!B92!A9&1E9"!A
M="!T:&4-"B`@96YD(&]F('1H92!A<F-H:79E+B!4:&5R92!I<R!N;R!U<&1A
M=&4@;V8@=&AE(&5X:7-T:6YG(&%R8VAI=F5D#0H@(&9I;&4O9&ER+B!(;W=E
M=F5R('=H:6QE(&5X=')A8W1I;F<@=&AE(&%R8VAI=F4L('1H92!L87-T(&9I
M;&4@=VEL;`T*("!R97!L86-E('1H92!F:7)S="!O;F4N(%1H:7,@<F5S=6QT
M<R!I;B!A(&YO;F4@;W!T:6UI>F%T:6]N(&]F('1H90T*("!A<F-H:79E('-I
M>F4N(`T*("!)9B!A(&9I;&4O9&ER(&1O97,@;F]T(&5X:7-T('1H92!F:6QE
M+V1I<B!I<R!I9VYO<F5D+B!(;W=E=F5R(&%N#0H@(&5R<F]R('1E>'0@:7,@
M<V5N9"!T;R!014%2(&5R<F]R+B`-"B`@268@82!F:6QE+V1I<B!I<R!N;W0@
M<F5A9&%B;&4@=&AE(&9I;&4O9&ER(&ES(&EG;F]R960N($AO=V5V97(@86X-
M"B`@97)R;W(@=&5X="!I<R!S96YD('1O(%!%05(@97)R;W(N(`T*("!)9B!T
M:&4@<F5S=6QT:6YG(&9I;&5N86UE+V1I<FYA;64@*&%F=&5R('1H92!A9&0O
M<F5M;W9E(&]P=&EO;B!O<@T*("!N;W0I('-T<FEN9R!I<R!G<F5A=&5R('1H
M86X@.3D@8VAA<BP@=&AE(&9I;&4O9&ER(&ES#0H@(&EG;F]R960N($AO=V5V
M97(@86X@97)R;W(@=&5X="!I<R!S96YD('1O(%!%05(@97)R;W(N(`T*07)G
M=6UE;G1S(#H-"B`@)'!?9FEL96QI<W0@.B!!;B!A<G)A>2!O9B!F:6QE;F%M
M97,@86YD(&1I<F5C=&]R>2!N86UE<RP@;W(@82!S:6YG;&4-"B`@("`@("`@
M("`@("`@("!S=')I;F<@=VET:"!N86UE<R!S97!A<F%T960@8GD@82!S:6YG
M;&4@8FQA;FL@<W!A8V4N(`T*("`D<%]A9&1?9&ER(#H@02!S=')I;F<@=VAI
M8V@@8V]N=&%I;G,@82!P871H('1O(&)E(&%D9&5D('1O('1H90T*("`@("`@
M("`@("`@("`@;65M;W)I>F5D('!A=&@@;V8@96%C:"!E;&5M96YT(&EN('1H
M92!L:7-T+B`-"B`@)'!?<F5M;W9E7V1I<B`Z($$@<W1R:6YG('=H:6-H(&-O
M;G1A:6YS(&$@<&%T:"!T;R!B92!R96UO=F5D(&9R;VT-"B`@("`@("`@("`@
M("`@("`@('1H92!M96UO<FEZ960@<&%T:"!O9B!E86-H(&5L96UE;G0@:6X@
M=&AE(&QI<W0L('=H96X-"@D)("!R96QE=F%N="X-"E)E='5R;B!V86QU92`Z
M#0H@('1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@97)R;W(N#0I386UP;&4@
M,2`Z#0H@("1T87)?;V)J96-T(#T@;F5W($%R8VAI=F5?5&%R*")T87)N86UE
M+G1A<B(I.PT*("!;+BXN70T*("`D=E]L:7-T6S!=/2)D978O9FEL92YT>'0B
M.PT*("`D=E]L:7-T6S%=/2)D978O9&%T82\B.R`H3W!T:6]N86P@)R\G(&%T
M('1H92!E;F0I#0H@("1V7VQI<W1;,ET](FQO9R]F:6QE+FQO9R([#0H@("1T
M87)?;V)J96-T+3YA9&1-;V1I9GDH)'9?;&ES="P@(FEN<W1A;&PB*3L-"B`@
M+R\@9FEL97,@87)E('-T;W)E9"!I;B!T:&4@87)C:&EV92!A<R`Z#0H@("\O
M("`@:6YS=&%L;"]F:6QE+G1X=`T*("`O+R`@(&EN<W1A;&PO9&%T80T*("`O
M+R`@(&EN<W1A;&PO9&%T82]F:6QE,2YT>'0-"B`@+R\@("!I;G-T86QL+V1A
M=&$O+BXN(&%L;"!T:&4@9FEL97,@86YD('-U8BUD:7)S(&]F(&1A=&$O#0H@
M("\O("`@:6YS=&%L;"]F:6QE+FQO9PT*4V%M<&QE(#(@.@T*("`D=&%R7V]B
M:F5C="`](&YE=R!!<F-H:79E7U1A<B@B=&%R;F%M92YT87(B*3L-"B`@6RXN
M+ET-"B`@)'9?;&ES=%LP73TB9&5V+V9I;&4N='AT(CL-"B`@)'9?;&ES=%LQ
M73TB9&5V+V1A=&$O(CL@*$]P=&EO;F%L("<O)R!A="!T:&4@96YD*0T*("`D
M=E]L:7-T6S)=/2)L;V<O9FEL92YL;V<B.PT*("`D=&%R7V]B:F5C="T^861D
M36]D:69Y*"1V7VQI<W0L(")I;G-T86QL(BP@(F1E=B(I.PT*("`O+R!F:6QE
M<R!A<F4@<W1O<F5D(&EN('1H92!A<F-H:79E(&%S(#H-"B`@+R\@("!I;G-T
M86QL+V9I;&4N='AT#0H@("\O("`@:6YS=&%L;"]D871A#0H@("\O("`@:6YS
M=&%L;"]D871A+V9I;&4Q+G1X=`T*("`O+R`@(&EN<W1A;&PO9&%T82\N+BX@
M86QL('1H92!F:6QE<R!A;F0@<W5B+61I<G,@;V8@9&%T82\-"B`@+R\@("!I
M;G-T86QL+VQO9R]F:6QE+FQO9PT*2&]W(&ET('=O<FMS(#H-"B`@268@=&AE
M(&%R8VAI=F4@9&]E<R!N;W0@97AI<W1S(&ET(&-R96%T92!I="!A;F0@861D
M('1H92!F:6QE<RX-"B`@268@=&AE(&%R8VAI=F4@9&]E<R!E>&ES=',@86YD
M(&ES(&YO="!C;VUP<F5S<V5D+"!I="!O<&5N(&ET+"!J=6UP#0H@(&)E9F]R
M92!T:&4@;&%S="!E;7!T>2`U,3(@8GET97,@8FQO8VL@*'1A<B!F;V]T97(I
M(&%N9"!A9&0@=&AE(&9I;&5S#0H@(&%T('1H:7,@<&]I;G0N#0H@($EF('1H
M92!A<F-H:79E(&1O97,@97AI<W1S(&%N9"!I<R!C;VUP<F5S<V5D+"!A('1E
M;7!O<F%R>2!C;W!Y(&9I;&4-"B`@:7,@8W)E871E9"X@5&AI<R!T96UP;W)A
M<GD@9FEL92!I<R!T:&5N("=G>FEP)R!R96%D(&)L;V-K(&)Y(&)L;V-K#0H@
M('5N=&EL('1H92!L87-T(&5M<'1Y(&)L;V-K+B!4:&4@;F5W(&9I;&5S(&%R
M92!T:&5N(&%D9&5D(&EN('1H90T*("!C;VUP<F5S<V5D(&9I;&4N#0H@(%1H
M92!A9&1I;F<@;V8@9FEL97,@:7,@9&]N92!B>2!G;VEN9R!T:')O=6=H('1H
M92!F:6QE+V1I<B!L:7-T+`T*("!A9&1I;F<@9FEL97,@<&5R(&9I;&5S+"!I
M;B!A(')E8W5R<VEV92!W87D@=&AR;W5G:"!T:&4-"B`@9&ER96-T;W)Y+B!%
M86-H('1I;64@82!P871H(&YE960@=&\@8F4@861D960O<F5M;W9E9"!I="!I
M<R!D;VYE#0H@(&)E9F]R92!W<FET:6YG('1H92!F:6QE(&AE861E<B!I;B!T
M:&4@87)C:&EV92X-"@T*365T:&]D(#H@861D*"1P7V9I;&5L:7-T*0T*1&5S
M8W)I<'1I;VX@.@T*("!4:&ES(&UE=&AO9"!A9&0@=&AE(&9I;&5S("\@9&ER
M96-T;W)I97,@;&ES=&5D(&EN("1P7V9I;&5L:7-T(&%T('1H90T*("!E;F0@
M;V8@=&AE(&5X:7-T:6YG(&%R8VAI=F4N($EF('1H92!A<F-H:79E(&1O97,@
M;F]T('EE="!E>&ES=',@:70-"B`@:7,@8W)E871E9"X@#0H@(%1H92`D<%]F
M:6QE;&ES="!P87)A;65T97(@8V%N(&)E(&%N(&%R<F%Y(&]F('-T<FEN9RP@
M96%C:"!S=')I;F<-"B`@<F5P<F5S96YT:6YG(&$@9FEL96YA;64@;W(@82!D
M:7)E8W1O<GD@;F%M92!W:71H('1H96ER('!A=&@@:68-"B`@;F5E9&5D+B!)
M="!C86X@86QS;R!B92!A('-I;F=L92!S=')I;F<@=VET:"!N86UE<R!S97!A
M<F%T960@8GD@80T*("!S:6YG;&4@8FQA;FLN(`T*("!3964@861D36]D:69Y
M*"D@;65T:&]D(&9O<B!D971A:6QS(&%N9"!L:6UI=&%T:6]N<RX-"D%R9W5M
M96YT<R`Z#0H@("1P7V9I;&5L:7-T(#H@06X@87)R87D@;V8@9FEL96YA;65S
M(&%N9"!D:7)E8W1O<GD@;F%M97,L(&]R(&$@<VEN9VQE#0H@('-T<FEN9R!W
M:71H(&YA;65S('-E<&%R871E9"!B>2!A('-I;F=L92!B;&%N:R!S<&%C92X@
M#0I2971U<FX@=F%L=64@.@T*("!T<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N
M(&5R<F]R+@T*4V%M<&QE(#$@.@T*("`D=&%R7V]B:F5C="`](&YE=R!!<F-H
M:79E7U1A<B@B=&%R;F%M92YT87(B*3L-"B`@6RXN+ET-"B`@)'9?;&ES=%LP
M73TB9&5V+V9I;&4N='AT(CL-"B`@)'9?;&ES=%LQ73TB9&5V+V1A=&$O(CL@
M*$]P=&EO;F%L("<O)R!A="!T:&4@96YD*0T*("`D=E]L:7-T6S)=/2)L;V<O
M9FEL92YL;V<B.PT*("`D=&%R7V]B:F5C="T^861D*"1V7VQI<W0I.PT*4V%M
M<&QE(#(@.@T*("`D=&%R7V]B:F5C="`](&YE=R!!<F-H:79E7U1A<B@B=&%R
M;F%M92YT9WHB+"!T<G5E*3L-"B`@6RXN+ET-"B`@)'9?;&ES=%LP73TB9&5V
M+V9I;&4N='AT(CL-"B`@)'9?;&ES=%LQ73TB9&5V+V1A=&$O(CL@*$]P=&EO
M;F%L("<O)R!A="!T:&4@96YD*0T*("`D=E]L:7-T6S)=/2)L;V<O9FEL92YL
M;V<B.PT*("`D=&%R7V]B:F5C="T^861D*"1V7VQI<W0I.PT*2&]W(&ET('=O
M<FMS(#H-"B`@4VEM<&QY(&-A;&P@=&AE(&%D9$UO9&EF>2@I(&UE=&AO9"!W
M:71H('1H92!R:6=H="!P87)A;65T97)S+@T*#0I-971H;V0@.B!A9&13=')I
M;F<H)'!?9FEL96YA;64L("1P7W-T<FEN9RD-"D1E<V-R:7!T:6]N(#H-"B`@
M5&AI<R!M971H;V0@861D(&$@<VEN9VQE('-T<FEN9R!A<R!A(&9I;&4@870@
M=&AE#0H@(&5N9"!O9B!T:&4@97AI<W1I;F<@87)C:&EV92X@268@=&AE(&%R
M8VAI=F4@9&]E<R!N;W0@>65T(&5X:7-T<R!I=`T*("!I<R!C<F5A=&5D+@T*
M07)G=6UE;G1S(#H-"B`@)'!?9FEL96YA;64@.B!!('-T<FEN9R!W:&EC:"!C
M;VYT86EN<R!T:&4@9G5L;"!F:6QE;F%M92!P871H#0H@("`@("`@("`@("`@
M("`@=&AA="!W:6QL(&)E(&%S<V]C:6%T960@=VET:"!T:&4@<W1R:6YG+@T*
M("`D<%]S=')I;F<@.B`@(%1H92!C;VYT96YT(&]F('1H92!F:6QE(&%D9&5D
M(&EN('1H92!A<F-H:79E+@T*4F5T=7)N('9A;'5E(#H-"B`@=')U92!O;B!S
M=6-C97-S+"!F86QS92!O;B!E<G)O<BX-"E-A;7!L92`Q(#H-"B`@)'9?87)C
M:&EV92`]("8@;F5W($%R8VAI=F5?5&%R*"1P7V9I;&5N86UE*3L-"B`@)'9?
M87)C:&EV92T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U!224Y4*3L-
M"B`@)'9?<F5S=6QT(#T@)'9?87)C:&EV92T^861D4W1R:6YG*"=D871A+W1E
M<W0N='AT)RP@)U1H:7,@:7,@=&AE('1E>'0@;V8@=&AE('-T<FEN9R<I.PT*
M#0H-"DUE=&AO9"`Z(&5X=')A8W0H)'!?<&%T:"`]("(B*0T*1&5S8W)I<'1I
M;VX@.@T*("!4:&ES(&UE=&AO9"!E>'1R86-T(&%L;"!T:&4@8V]N=&5N="!O
M9B!T:&4@87)C:&EV92!I;B!T:&4@9&ER96-T;W)Y#0H@(&EN9&EC871E9"!B
M>2`D<%]P871H+DEF("1P7W!A=&@@:7,@;W!T:6]N86PL(&EF(&YO="!S970@
M=&AE(&%R8VAI=F4-"B`@:7,@97AT<F%C=&5D(&EN('1H92!C=7)R96YT(&1I
M<F5C=&]R>2X@#0H@(%=H:6QE(&5X=')A8W1I;F<@82!F:6QE+"!I9B!T:&4@
M9&ER96-T;W)Y('!A=&@@9&]E<R!N;W0@97AI<W1S(&ET(&ES#0H@(&-R96%T
M960N(`T*("!3964@97AT<F%C=$UO9&EF>2@I(&9O<B!D971A:6QS(&%N9"!L
M:6UI=&%T:6]N<RX-"D%R9W5M96YT<R`Z#0H@("1P7W!A=&@@.B!/<'1I;VYA
M;"!P871H('=H97)E('1H92!F:6QE<R]D:7(@;F5E9"!T;R!B>2!E>'1R86-T
M960N#0I2971U<FX@=F%L=64@.@T*("!T<G5E(&]N('-U8V-E<W,L(&9A;'-E
M(&]N(&5R<F]R+@T*4V%M<&QE(#H-"B`@)'1A<E]O8FIE8W0@/2!N97<@07)C
M:&EV95]487(H(G1A<FYA;64N=&%R(BD[#0H@("1T87)?;V)J96-T+3YE>'1R
M86-T*"D[#0I(;W<@:70@=V]R:W,@.@T*("!3:6UP;'D@8V%L;"!T:&4@97AT
M<F%C=$UO9&EF>2@I(&UE=&AO9"!W:71H(&%P<')O<')I871E('!A<F%M971E
M<G,N#0H-"DUE=&AO9"`Z(&5X=')A8W1-;V1I9GDH)'!?<&%T:"P@)'!?<F5M
M;W9E7W!A=&@I#0I$97-C<FEP=&EO;B`Z#0H@(%1H:7,@;65T:&]D(&5X=')A
M8W0@86QL('1H92!C;VYT96YT(&]F('1H92!A<F-H:79E(&EN('1H92!D:7)E
M8W1O<GD-"B`@:6YD:6-A=&5D(&)Y("1P7W!A=&@N(%=H96X@<F5L979A;G0@
M=&AE(&UE;6]R:7IE9"!P871H(&]F('1H90T*("!F:6QE<R]D:7(@8V%N(&)E
M(&UO9&EF:65D(&)Y(')E;6]V:6YG('1H92`D<%]R96UO=F5?<&%T:"!P871H
M(&%T('1H90T*("!B96=I;FYI;F<@;V8@=&AE(&9I;&4O9&ER('!A=&@N(`T*
M("!7:&EL92!E>'1R86-T:6YG(&$@9FEL92P@:68@=&AE(&1I<F5C=&]R>2!P
M871H(&1O97,@;F]T(&5X:7-T<R!I="!I<PT*("!C<F5A=&5D+B`-"B`@5VAI
M;&4@97AT<F%C=&EN9R!A(&9I;&4L(&EF('1H92!F:6QE(&%L<F5A9'D@97AI
M<W1S(&ET(&ES(')E<&QA8V5D#0H@('=I=&AO=70@;&]O:VEN9R!F;W(@;&%S
M="!M;V1I9FEC871I;VX@9&%T92X@#0H@(%=H:6QE(&5X=')A8W1I;F<@82!F
M:6QE+"!I9B!T:&4@9FEL92!A;')E861Y(&5X:7-T<R!A;F0@:7,@=W)I=&4-
M"B`@<')O=&5C=&5D+"!T:&4@97AT<F%C=&EO;B!I<R!A8F]R=&5D+B`-"B`@
M5VAI;&4@97AT<F%C=&EN9R!A(&9I;&4L(&EF(&$@9&ER96-T;W)Y('=I=&@@
M=&AE('-A;64@;F%M92!A;')E861Y#0H@(&5X:7-T<RP@=&AE(&5X=')A8W1I
M;VX@:7,@86)O<G1E9"X@#0H@(%=H:6QE(&5X=')A8W1I;F<@82!D:7)E8W1O
M<GDL(&EF(&$@9FEL92!W:71H('1H92!S86UE(&YA;64@86QR96%D>0T*("!E
M>&ES=',L('1H92!E>'1R86-T:6]N(&ES(&%B;W)T960N(`T*("!7:&EL92!E
M>'1R86-T:6YG(&$@9FEL92]D:7)E8W1O<GD@:68@=&AE(&1E<W1I;F%T:6]N
M(&1I<F5C=&]R>2!E>&ES=`T*("!A;F0@:7,@=W)I=&4@<')O=&5C=&5D+"!O
M<B!D;V5S(&YO="!E>&ES="!B=70@8V%N(&YO="!B92!C<F5A=&5D+`T*("!T
M:&4@97AT<F%C=&EO;B!I<R!A8F]R=&5D+B`-"B`@268@869T97(@97AT<F%C
M=&EO;B!A;B!E>'1R86-T960@9FEL92!D;V5S(&YO="!S:&]W('1H92!C;W)R
M96-T#0H@('-T;W)E9"!F:6QE('-I>F4L('1H92!E>'1R86-T:6]N(&ES(&%B
M;W)T960N(`T*("!7:&5N('1H92!E>'1R86-T:6]N(&ES(&%B;W)T960L(&$@
M4$5!4B!E<G)O<B!T97AT(&ES('-E="!A;F0@9F%L<V4-"B`@:7,@<F5T=7)N
M960N($AO=V5V97(@=&AE(')E<W5L="!C86X@8F4@82!P87)T:6%L(&5X=')A
M8W1I;VX@=&AA="!M87D-"B`@;F5E9"!T;R!B92!M86YU86QL>2!C;&5A;F5D
M+B`-"D%R9W5M96YT<R`Z#0H@("1P7W!A=&@@.B!4:&4@<&%T:"!O9B!T:&4@
M9&ER96-T;W)Y('=H97)E('1H92!F:6QE<R]D:7(@;F5E9"!T;R!B>0T*("`@
M("`@("`@("`@97AT<F%C=&5D+B`-"B`@)'!?<F5M;W9E7W!A=&@@.B!087)T
M(&]F('1H92!M96UO<FEZ960@<&%T:"!T:&%T(&-A;B!B92!R96UO=F5D(&EF
M#0H@("`@("`@("`@("`@("`@("`@<')E<V5N="!A="!T:&4@8F5G:6YN:6YG
M(&]F('1H92!F:6QE+V1I<B!P871H+B`-"E)E='5R;B!V86QU92`Z#0H@('1R
M=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@97)R;W(N#0I386UP;&4@.@T*("`O
M+R!);6%G:6YE('1A<FYA;64N=&%R('=I=&@@9FEL97,@.@T*("`O+R`@(&1E
M=B]D871A+V9I;&4N='AT#0H@("\O("`@9&5V+V1A=&$O;&]G+G1X=`T*("`O
M+R`@(')E861M92YT>'0-"B`@)'1A<E]O8FIE8W0@/2!N97<@07)C:&EV95]4
M87(H(G1A<FYA;64N=&%R(BD[#0H@("1T87)?;V)J96-T+3YE>'1R86-T36]D
M:69Y*")I;G-T86QL(BP@(F1E=B(I.PT*("`O+R!&:6QE<R!W:6QL(&)E(&5X
M=')A8W1E9"!T:&5R92`Z#0H@("\O("`@:6YS=&%L;"]D871A+V9I;&4N='AT
M#0H@("\O("`@:6YS=&%L;"]D871A+VQO9RYT>'0-"B`@+R\@("!I;G-T86QL
M+W)E861M92YT>'0-"DAO=R!I="!W;W)K<R`Z#0H@($]P96X@=&AE(&%R8VAI
M=F4@86YD(&-A;&P@82!M;W)E(&=E;F5R:6,@9G5N8W1I;VX@=&AA="!C86X@
M97AT<F%C=`T*("!O;FQY(&$@<&%R="!O9B!T:&4@87)C:&EV92!O<B!A;&P@
M=&AE(&%R8VAI=F4N(`T*("!3964@97AT<F%C=$QI<W0H*2!M971H;V0@9F]R
M(&UO<F4@9&5T86EL<RX-"@T*365T:&]D(#H@97AT<F%C=$EN4W1R:6YG*"1P
M7V9I;&5N86UE*0T*1&5S8W)I<'1I;VX@.@T*("!4:&ES(&UE=&AO9"!E>'1R
M86-T(&9R;VT@=&AE(&%R8VAI=F4@;VYE(&9I;&4@:61E;G1I9FEE9"!B>2`D
M<%]F:6QE;F%M92X-"B`@5&AE(')E='5R;B!V86QU92!I<R!A('-T<FEN9R!W
M:71H('1H92!F:6QE(&-O;G1E;G0L(&]R($Y53$P@;VX@97)R;W(N(`T*07)G
M=6UE;G1S(#H-"B`@)'!?9FEL96YA;64@.B!4:&4@<&%T:"!O9B!T:&4@9FEL
M92!T;R!E>'1R86-T(&EN(&$@<W1R:6YG+B`-"E)E='5R;B!V86QU92`Z#0H@
M(&$@<W1R:6YG('=I=&@@=&AE(&9I;&4@8V]N=&5N="!O<B!.54Q,+@T*4V%M
M<&QE(#H-"B`@+R\@26UA9VEN92!T87)N86UE+G1A<B!W:71H(&9I;&5S(#H-
M"B`@+R\@("!D978O9&%T82]F:6QE+G1X=`T*("`O+R`@(&1E=B]D871A+VQO
M9RYT>'0-"B`@+R\@("!D978O<F5A9&UE+G1X=`T*("`D=E]A<F-H:79E(#T@
M)B!N97<@07)C:&EV95]487(H)W1A<FYA;64N=&%R)RD[#0H@("1V7V%R8VAI
M=F4M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]04DE.5"D[#0H@("1V
M7W-T<FEN9R`]("1V7V%R8VAI=F4M/F5X=')A8W1);E-T<FEN9R@G9&5V+W)E
M861M92YT>'0G*3L-"B`@96-H;R`D=E]S=')I;F<[#0H-"DUE=&AO9"`Z(&QI
M<W1#;VYT96YT*"D-"D1E<V-R:7!T:6]N(#H-"B`@5&AI<R!M971H;V0@<F5T
M=7)N<R!A;B!A<G)A>2!O9B!A<G)A>7,@=&AA="!D97-C<FEB92!E86-H#0H@
M(&9I;&4O9&ER96-T;W)Y('!R97-E;G0@:6X@=&AE(&%R8VAI=F4N(`T*("!4
M:&4@87)R87D@:7,@;F]T('-O<G1E9"P@<V\@:70@<VAO=R!T:&4@<&]S:71I
M;VX@;V8@=&AE(&9I;&4@:6X@=&AE#0H@(&%R8VAI=F4N(`T*("!4:&4@9FEL
M92!I;F9O<FUA=&EO;G,@87)E(#H-"B`@("`D9FEL95MF:6QE;F%M95T@.B!.
M86UE(&%N9"!P871H(&]F('1H92!F:6QE+V1I<BX-"B`@("`D9FEL95MM;V1E
M72`Z($9I;&4@<&5R;6ES<VEO;G,@*')E<W5L="!O9B!F:6QE<&5R;7,H*2D-
M"B`@("`D9FEL95MU:61=(#H@=7-E<B!I9`T*("`@("1F:6QE6V=I9%T@.B!G
M<F]U<"!I9`T*("`@("1F:6QE6W-I>F5=(#H@9FEL97-I>F4-"B`@("`D9FEL
M95MM=&EM95T@.B!,87-T(&UO9&EF:6-A=&EO;B!T:6UE("AR97-U;'0@;V8@
M9FEL96UT:6UE*"DI#0H@("`@)&9I;&5;='EP969L86==(#H@(B(@9F]R(&9I
M;&4L("(U(B!F;W(@9&ER96-T;W)Y#0I!<F=U;65N=',@.@T*4F5T=7)N('9A
M;'5E(#H-"B`@06X@87)R87D@;V8@87)R87ES(&]R(#`@;VX@97)R;W(N#0I3
M86UP;&4@.@T*("`D=&%R7V]B:F5C="`](&YE=R!!<F-H:79E7U1A<B@B=&%R
M;F%M92YT87(B*3L-"B`@:68@*"@D=E]L:7-T("`]("`D=&%R7V]B:F5C="T^
M;&ES=$-O;G1E;G0H*2D@(3T@,"D-"B`@("!F;W(@*"1I/3`[("1I/'-I>F5O
M9B@D=E]L:7-T*3L@)&DK*RD-"B`@("![#0H@("`@("!E8VAO(")&:6QE;F%M
M92`Z)R(N)'9?;&ES=%LD:5U;9FEL96YA;65=+B(G/&)R/B([#0H@("`@("!E
M8VAO("(@+G-I>F4@.B<B+B1V7VQI<W1;)&E=6W-I>F5=+B(G/&)R/B([#0H@
M("`@("!E8VAO("(@+FUT:6UE(#HG(BXD=E]L:7-T6R1I75MM=&EM95TN(B<@
M*"(N#0H@("`@("`@("`@(&1A=&4H(FP@9%,@;V8@1B!9(&@Z:3IS($$B+"`D
M=E]L:7-T6R1I75MM=&EM95TI+B(I/&)R/B([#0H@("`@("!E8VAO("(@+FUO
M9&4@.B<B+B1V7VQI<W1;)&E=6VUO9&5=+B(G/&)R/B([#0H@("`@("!E8VAO
M("(@+G5I9"`Z)R(N)'9?;&ES=%LD:5U;=6ED72XB)SQB<CXB.PT*("`@("`@
M96-H;R`B("YG:60@.B<B+B1V7VQI<W1;)&E=6V=I9%TN(B<\8G(^(CL-"B`@
M("`@(&5C:&\@(B`N='EP969L86<@.B<B+B1V7VQI<W1;)&E=6W1Y<&5F;&%G
M72XB)SQB<CXB.PT*("`@('T-"DAO=R!I="!W;W)K<R`Z#0H@($-A;&P@=&AE
M('-A;64@9G5N8W1I;VX@87,@86X@97AT<F%C="!H;W=E=F5R('=I=&@@82!F
M;&%G('1O(&]N;'D@9V\-"B`@=&AR;W5G:"!T:&4@87)C:&EV92!W:71H;W5T
M(&5X=')A8W1I;F<@=&AE(&9I;&5S+B`-"@T*365T:&]D(#H@97AT<F%C=$QI
M<W0H)'!?9FEL96QI<W0L("1P7W!A=&@@/2`B(BP@)'!?<F5M;W9E7W!A=&@@
M/2`B(BD-"D1E<V-R:7!T:6]N(#H-"B`@5&AI<R!M971H;V0@97AT<F%C="!F
M<F]M('1H92!A<F-H:79E(&]N;'D@=&AE(&9I;&5S(&EN9&EC871E9"!I;B!T
M:&4-"B`@)'!?9FEL96QI<W0N(%1H97-E(&9I;&5S(&%R92!E>'1R86-T960@
M:6X@=&AE(&-U<G)E;G0@9&ER96-T;W)Y(&]R#0H@(&EN('1H92!D:7)E8W1O
M<GD@:6YD:6-A=&5D(&)Y('1H92!O<'1I;VYA;"`D<%]P871H('!A<F%M971E
M<BX@#0H@($EF(&EN9&EC871E9"!T:&4@)'!?<F5M;W9E7W!A=&@@8V%N(&)E
M('5S960@:6X@=&AE('-A;64@=V%Y(&%S(&ET(&ES#0H@('5S960@:6X@97AT
M<F%C=$UO9&EF>2@I(&UE=&AO9"X@#0I!<F=U;65N=',@.@T*("`D<%]F:6QE
M;&ES="`Z($%N(&%R<F%Y(&]F(&9I;&5N86UE<R!A;F0@9&ER96-T;W)Y(&YA
M;65S+"!O<B!A('-I;F=L90T*("`@("`@("`@("`@("`@('-T<FEN9R!W:71H
M(&YA;65S('-E<&%R871E9"!B>2!A('-I;F=L92!B;&%N:R!S<&%C92X@#0H@
M("1P7W!A=&@@.B!4:&4@<&%T:"!O9B!T:&4@9&ER96-T;W)Y('=H97)E('1H
M92!F:6QE<R]D:7(@;F5E9"!T;R!B>0T*("`@("`@("`@("`@97AT<F%C=&5D
M+B`-"B`@)'!?<F5M;W9E7W!A=&@@.B!087)T(&]F('1H92!M96UO<FEZ960@
M<&%T:"!T:&%T(&-A;B!B92!R96UO=F5D(&EF#0H@("`@("`@("`@("`@("`@
M("`@<')E<V5N="!A="!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE+V1I<B!P
M871H+B`-"E)E='5R;B!V86QU92`Z#0H@('1R=64@;VX@<W5C8V5S<RP@9F%L
M<V4@;VX@97)R;W(N#0I386UP;&4@.@T*("`O+R!);6%G:6YE('1A<FYA;64N
M=&%R('=I=&@@9FEL97,@.@T*("`O+R`@(&1E=B]D871A+V9I;&4N='AT#0H@
M("\O("`@9&5V+V1A=&$O;&]G+G1X=`T*("`O+R`@(')E861M92YT>'0-"B`@
M)'1A<E]O8FIE8W0@/2!N97<@07)C:&EV95]487(H(G1A<FYA;64N=&%R(BD[
M#0H@("1T87)?;V)J96-T+3YE>'1R86-T3&ES="@B9&5V+V1A=&$O9FEL92YT
M>'0@<F5A9&UE+G1X="(L(")I;G-T86QL(BP-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@(")D978B*3L-"B`@+R\@1FEL97,@=VEL;"!B92!E>'1R86-T
M960@=&AE<F4@.@T*("`O+R`@(&EN<W1A;&PO9&%T82]F:6QE+G1X=`T*("`O
M+R`@(&EN<W1A;&PO<F5A9&UE+G1X=`T*2&]W(&ET('=O<FMS(#H-"B`@1V\@
M=&AR;W5G:"!T:&4@87)C:&EV92!A;F0@97AT<F%C="!O;FQY('1H92!F:6QE
M<R!P<F5S96YT(&EN('1H90T*("!L:7-T+B`-"@T*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+V1O8W,O1&%T92\`````````````````````````````````````````````
M`````````````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S,U`#`R,#0Q,@`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]$871E+TQ)0T5.4T4`````````````
M````````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(U,#<`,3`U,34T,S,W,S4`
M,#(Q-#(S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA
M<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U="!M;V1I9FEC871I;VX*+"!A<F4@
M<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I
M;VYS(&%R92!M970Z"@HQ+B!2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O
M9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H="!N;W1I8V4L('1H
M"B`@(&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D
M:7-C;&%I;65R+@H*,BX@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M
M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T:6-E+`H@
M("!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D
M:7-C;&%I;65R(&EN('1H92!D;V-U;65N=&%T:6]N(&%N9"\*("`@;W(@;W1H
M97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BX*
M"C,N(%1H92!N86UE(&]F('1H92!A=71H;W(@;6%Y(&YO="!B92!U<V5D('1O
M(&5N9&]R<V4@;W(@<')O;6]T92!P<F]D=6-T<R!D97)I=F5D"B`@(&9R;VT@
M=&AI<R!S;V9T=V%R92!W:71H;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@
M<&5R;6ES<VEO;BX*"E1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%
M($%55$A/4B!@8$%3($E3)R<@04Y$($%.62!%6%!215-3($]2($E-4$Q)140@
M5T$*4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$(%1/+"!4
M2$4@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))3`I)5%D@04Y$
M($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%($%212!$25-#3$%)
M345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@"D%55$A/4B!"12!,24%"3$4@
M1D]2($%.62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!34$5#24%,
M+"!%6$5-4$Q!4EDL($]2($,*3TY315%514Y424%,($1!34%'15,@*$E.0TQ5
M1$E.1RP@0E54($Y/5"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!354)3
M5$E4551%(`I'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L($1!5$$L
M($]2(%!23T9)5%,[($]2($)54TE.15-3($E.5$524E505$E/3BD@2$]7"D56
M15(@0T%54T5$($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)04))3$E462P@5TA%
M5$A%4B!)3B!#3TY44D%#5"P@4U1224-4($Q)04))3$D*5%DL($]2(%1/4E0@
M*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D@05))4TE.1R!)
M3B!!3ED@5T%9($]55"!/1B!42$4@50I312!/1B!42$E3(%-/1E1705)%+"!%
M5D5.($E&($%$5DE3140@3T8@5$A%(%!/4U-)0DE,2519($]&(%-50T@@1$%-
M04=%+@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S
M+T1A=&4O5$]$3P``````````````````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#,W,@`Q,#4Q-30S,S<S-0`P,C$Q,#0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+2!&:7@@;VYC92!T:&4@=&EM
M97IO;F4@<')O8FQE;0H*+2!/;F-E(%1:('=O<FMS(&YI8V5L>2P@=7!D871E
M('1H92!T97-T=6YI=%]D871E(&%N9"!U<V4*("!T:&4@<F5A;"!T:6UE>F]N
M92!A;F0@9&-T('1O(&-H96-K('1H92!E>'!E8W1E9"!T:6UE(&]F9G-E=`H*
M+2!#;&5A;B!T:&4@=&5S="!C87-E<R!A;F0@871O;6EC(&1I<W!L87D@:6YS
M=&5A9"!O9B!A(&=L;V)A;"!O:R!O<B!F86EL960*"BT@=W)I=&4@=&AE(&1O
M8W,N+BXN"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]$0B\`````````
M````````````````````````````````````````````````````````````
M````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`U,34T,S,W,S4`,#(P,#(R`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]D;V-S+T1"+V1O8R\`````````````````````````````````````````
M```````````````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<S-0`P,C`U-C<`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+V1O8W,O1$(O9&]C+TE$14%3````````````
M`````````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-3,W`#$P-3$U-#,S-S,U
M`#`R,3,U,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!!8G-T<F%C=&5D(%1Y<&5S("A3=&EG*0HM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+0H*1$(@;F5E9',@82!S970@;V8@='EP97,@<F5P<F5S96YT:6YG
M('1H92!M;W-T(&-O;6UO;FQY('5S960@='EP97,@:6X*86QL(&)A8VME;F1S
M+B`@5&AI<R!T>7!E('-E="!C;W5L9"!A;'-O(&)E(&=E87)E9"!T;W=A<F1S
M(&EN=&5G<F%T:6]N"G=I=&@@=&AI;F=S(&QI:V4@6$U,+5)00R]33T%0(&EM
M<&QE;65N=&%T:6]N<RP@2%1-3"!F;W)M(&-L87-S97,L(&5T8RX*"E)E86P@
M475E<GD@4&%R<V5R("A3=&EG*0HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*
M"E=I=&@@82!R96%L('%U97)Y('!A<G-E<BP@1$(@8V%N(&EM<&QE;65N="!M
M;W)E(&]F(&ET<R!P;W)T86)I;&ET>0IB87-E9"!O;B!T:&4@<75E<GDL(&EN
M<W1E860@;V8@:&%V:6YG('-U<'!O<G0@9G5N8W1I;VYS(&9O<@IE=F5R>71H
M:6YG+B`@3VYE(&5X86UP;&4@=V]U;&0@8F4@3$E-250L(&%N;W1H97(@(DE.
M4T525`HN+BX@4D5455).24Y'(BX*"E!O<G1A8FQE('1R86YS86-T:6]N<R`H
M4W1I9RD*+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H*268@1$(@8V%N
M('!A<G-E('%U97)I97,@96YO=6=H('1O(&1E=&5R;6EN92!W:&%T('1A8FQE
M<R!A<F4@869F96-T960*8GD@<75E<FEE<RP@:70@<VAO=6QD(&)E('!O<W-I
M8FQE('1O(&UA:V4@82!R97!L87EA8FQE('1R86YS86-T:6]N"FQO9RX@($=.
M3TU%('5S97,@86X@6$U,(&9O<FUA="!F;W(@8V]N9FEG=7)A=&EO;B!D871A
M('1H870@;&5T<R!Y;W4*8VAE8VMP;VEN="!S=&%T92!O;F-E(&EN(&$@=VAI
M;&4L(&%N9"!R979E<G0@=&\@=&AA="!S=&%T92!L871E<BX*5VET:"!A('-I
M;6EL87(@87!P<F]A8V@@9F]R('1R86YS86-T:6]N<R!I;B!$0B!W92!C86X@
M:6UP;&5M96YT"G!O<G1A8FQE('1R86YS86-T:6]N<R!A;F0@8VAE8VMP;VEN
M=&EN9R!E=F5N(&9O<B!T:&4@9&%T86)A<V5S('1H870*9&]N)W0@<W5P<&]R
M="!T:&5M+@H*"D5R<F]R(')E<&]R=&EN9R!C;&5A;BUU<"]D96)U9R`H5&]M
M87,I"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*3F]W
M(&5A8V@@9')I=F5R(&AA<R!I=',@;W=N(')A:7-E17)R;W(@;65T:&]D+"!C
M;VUM;VX@:&%S(&$@<F%I<V5%<G)O<B!A;F0*1$(@:&%S(&$@1$)?97)R;W(@
M8VQA<W,@86YD(&ET<R!O=VX@:7-%<G)O<B@I(&UE=&AO9"X@5&AI<R!E<G)O
M<B!S='5F9B`*;W9E<FAE860@8V]U;&0@8F4@<VEM<&QI9FEE9"!W:71H(&]N
M;'D@;VYE(')A:7-E17)R;W(L(&1R;W!I;F<@=&AE($1"($5R<F]R"F-L87-S
M(&%N9"!A;'-O('1H92!$0CHZ:7-%<G)O<B@I("AU<V4@=&AE(%!%05(N<&AP
M(&]N97,@:6YS=&5A9"DN"D]T:&5R(&ED96$@8V]U;&0@8F4@=&\@861D(&$@
M<WES=&5M(&9O<B!A;&QO=VEN9R!P96]P;&4@86-C97-S('1O(&%L;"!T:&4*
M<75E<FEE<R!S96YD960@8GD@4$5!4B!$0B!T;R!T:&4@8F%C:V5N9"X@06QS
M;R!A(&YE=R!014%27T524D]27T1%0E5'"F9L86<@=&AA="!A=71O;6%T:6-A
M;&QY("AS:&]W?'1R:6=G97)S*2!D96)U9R!I;F9O+"!P97)H87!S"G=I=&@@
M82!N97<@4$5!4E\H5V%R;FEN9WQ$96)U9RD@;V)J96-T+@H*475O=&4@8VQE
M86XM=7`@*%-T:6<I"BTM+2TM+2TM+2TM+2TM+2TM+2TM+0HQ+B!+965P('%U
M;W1E(&%N9"!Q=6]T95-T<FEN9RP@8G5T(&UO=F4@<75O=&EN9R!O9B!S=')I
M;F=S(&)A8VL@:6YT;PH@("!Q=6]T95-T<FEN9R!A;F0@;6%K92!Q=6]T92!C
M86QL(&ET(&9O<B!S=')I;F=S+@H*,BX@061D(&%N(&]P=&EO;F%L(")O<&5R
M871O<B(@<&%R86UE=&5R('1O('%U;W1E('1H870@:7,@;VYE(&]F("(](BP*
M("`@(CPB+"`B/B(@;W(@(CP^(B!T:&%T('=I;&P@8F4@:6YS97)T960@:6X@
M9G)O;G0@;V8@=&AE('%U;W1E9"!V86QU90H@("!U;FQE<W,@:70@:7,@3E5,
M3"P@:6X@=VAI8V@@8V%S92!I="!W:6QL(&)E(&-O;G9E<G1E9"!T;R`B25,B
M("AF;W(*("`@(CTB*2!O<B`B25,@3D]4(B`H9F]R('1H92!O=&AE<G,I+@H*
M075T;R!F<F5E('-T871E;65N=',@*%1O;6%S*0HM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM"D)Y('-E='1I;F<@82!P87)A;2!I;B!Q=65R>2@I(&]R
M(&9O<B!T:&4@:&]L92!$0B!I;G-T86YC92P@4$5!4B!$0@IC;W5L9"!A=71O
M+69R964@<F5S=6QT<R!I;B!$0E]R97-U;'0M/F9E=&-H*$EN=&]\4F]W*2!W
M:&5N('1H92!D<FEV97(*<F5T=7)N<R!F86QS92X*"D1A=&%T>7!E<R!I;B!P
M<F5P87)E('-Y;G1A>"`H5&]M87,I"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM"D5X=&5N9"!T:&4@86-T=6%L('!R97!A<F4O97AE8W5T
M92!P;&%C96AO;&1E<G,@=&\@<W5P<&]R="!D871A('1Y<&5S+"!B;W1H"G1O
M(&-H96-K('1H92!D871A(&EN=')O9'5C960@=&\@=&AE('%U97)Y(&%N9"!T
M;R`B8V%S="(@=&AE(')E<W5L=`IT;R!N871I=F4@<&AP(&1A=&$@='EP97,N
M($5X.@H*)'-Q;"`]("))3E-%4E0@24Y43R!T86)L92!604Q515,@*'M[:6YT
M*#0I?7TL('M[8F]O;'U]+"![>V1A=&4H)UDM;2UD)RE]?2DB.PHD<F]W(#T@
M)&1B+3YQ=65R>2@D<W%L+"!A<G)A>2@X+"`G="<L("<R,#`Q+3`T+3$G*2D[
M"@I&;W)M870Z('M[/&1A=&%?='EP93XH/'!A<F%M,3XL/'!A<F%M,CXI?7T*
M"B)P87)A;2(@8V]U;&0@8F4@=&AE(&UA>"!L96YG:'0@;V8@=&AE(&1A=&$L
M(&1A=&4@9F]R;6%T<RP@;F]T7VYU;&P*8VAE8VMS(&]R(&1E9F%U;'0@=F%L
M=65S+@H*3W1H97(@:61E87,@8V]U;&0@8F4Z"@HQ*0HD<W%L(#T@(DE.4T52
M5"!)3E1/('1A8FQE(%9!3%5%4R`H/RP@/RP@/RDB.PHD<W1H(#T@)&1B+3YP
M<F5P87)E*"1S<6PL(&%R<F%Y*"=I;G0H-"DG+"`G8F]O;"<L("=D871E)RD[
M"B1R97,@/2`D9&(M/F5X96-U=&4H)'-T:"P@87)R87DH)&$L("1B+"`D8RD[
M"@HR*0HD<W%L(#T@(DE.4T525"!)3E1/('1A8FQE(%9!3%5%4R`H/RP@/RP@
M/RDB.PHD<&%R86US(#T@87)R87DH"@DP(#T^(&%R<F%Y*"1A+"`G:6YT*#0I
M)RDL"@DQ(#T^(&%R<F%Y*"1B+"`G8F]O;"<I"BD["B1R97,@/2`D9&(M/G%U
M97)Y*"1S<6PL("1P87)A;7,I.PH*075T;R!C;VYN96-T(&9E871U<F4@*%1O
M;6%S*0HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"D%D9"!T:&4@86)I
M;&ET>2!T;R!C<F5A=&4@9F]R(&5X86UP;&4@82!L:6=H="!A;F0@9'5M<"!$
M0B!O8FIE8W0@=VAI8V@*=VEL;"!O;FQY('-E="!U<"!T:&4@8V]N;F5C=&EO
M;B!W:&5N(&YE961E9"X@5VET:"!T:&%T('!E;W!L92!C;W5L9`IC<F5A=&4@
M=&AE($1"(&]B:F5C="!I;B!A(&-O;6UO;B!P<F5P96YD(&]R(&1E9F%U;'0@
M9FEL92!W:71H;W5T('1H90IN965D('1O('=A<W1E('-Y<W1E;2!R97-O=7)C
M97,@:68@=&AE('5S92!O9B!T:&4@9&%T86)A<V4@:7,@9FEN86QL>0IN;W0@
M;F5E9&5D+@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+T1"+V1O8R]-04E.5$%)3D524P``
M```````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3(U,``Q,#4Q-30S,S<S
M-0`P,C(R-C(`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````36%I;G1A:6YE<G,@9F]R($1"(&1A=&%B87-E(&)A8VME;F1S+V1R
M:79E<G,Z"@ID8F%S92`@(#H@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P
M:'`N;F5T/@IF8G-Q;"`@(#H@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P
M:'`N;F5T/@H@("`@("`@("`@1G)A;FL@32X@2W)O;6%N;B`\9G)A;FM`:W)O
M;6%N;BYI;F9O/@II8F%S92`@(#H@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L
M8T!P:'`N;F5T/@II9G@@("`@(#H@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L
M8T!P:'`N;F5T/@IM<W%L("`@(#H@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L
M8T!P:'`N;F5T/@IM<W-Q;"`@(#H@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L
M8T!P:'`N;F5T/@IM>7-Q;"`@(#H@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L
M8T!P:'`N;F5T/@IM>7-Q;&D@(#H@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L
M8T!P:'`N;F5T/@IO8VDX("`@(#H@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L
M8T!P:'`N;F5T/@IO9&)C("`@(#H@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L
M8T!P:'`N;F5T/@IP9W-Q;"`@(#H@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L
M8T!P:'`N;F5T/@IS<6QI=&4@(#H@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L
M8T!P:'`N;F5T/@IS>6)A<V4@(#H@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L
M8T!P:'`N;F5T/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+T1"+V1O8R]35$%455,`
M````````````````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,#8T-0`Q,#4Q
M-30S,S<S-0`P,C$U-#,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````4U1!5%53($]&(%1(12!014%2($1"(%!!0TM!1T4*/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"B1)9#H@4U1!5%53+'8@,2XS
M,R`R,#`U+S`R+S(R(#$U.C0U.C,V(&1A;FEE;&,@17AP("0*+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM"@I$0B!$<FEV97(@1F5A='5R92!-871R:7@*
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"E-Y;6)O;',Z"B`@>"`@/2`@:6UP
M;&5M96YT960L(&)U="!W:71H;W5T('1E<W1S"B`@="`@/2`@:6UP;&5M96YT
M960L(&)U="!O;F4@;W(@;6]R92!T97-T<R!F86EL"B`@5"`@/2`@:6UP;&5M
M96YT960L('!A<W-I;F<@86QL('1E<W1S"B`@92`@/2`@96UU;&%T960L('=I
M=&AO=70@=&5S=',*("!L("`]("!E;75L871E9"P@8G5T(&]N92!O<B!M;W)E
M('1E<W1S(&9A:6P*("!%("`]("!E;75L871E9"P@<&%S<VEN9R!A;&P@=&5S
M=',*("!N("`]("!R971U<FYS(")N;W0@8V%P86)L92(*("`M("`]("!N;R!I
M;7!L96UE;G1A=&EO;B!O9B!T:&ES(&9E871U<F4@;W(@<W1A='5S('5N:VYO
M=VX*"B`@("`@("`@("`@("`@("`@("`@9F)S<6P@("`@("!I9G@@("`@("!M
M<W-Q;"`@("`@;7ES<6QI("`@("!O9&)C("`@("!S<6QI=&4*1D5!5%5212`@
M("`@("`@9&)A<V4@('P@(&EB87-E("!\("!M<W%L("`@?"`@;7ES<6P@('P@
M("!O8VDX("!\("!P9W-Q;"`@?"`@<WEB87-E"G-I;7!L95%U97)Y("`@("`@
M+2`@("!4("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0@("`@
M5"`@("!4("`@(%0@("`@5`IN=6U#;VQS("`@("`@("`@('@@("`@5"`@("!4
M("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4
M("`@(%0*;G5M4F]W<R`@("`@("`@("!X("`@(%0@("`@12`@("!%("`@(%0@
M("`@5"`@("!4("`@(%0@("`@12`@("!4("`@(%0@("`@5"`@("!4"F5R<F]R
M3F%T:79E("`@("`@;B`@("!4("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@
M("!4("`@(%0@("`@5"`@("!4("`@($4@("`@5`IP<F5P87)E+V5X96-U=&4@
M(&4@("`@12`@("!4("`@($4@("`@12`@("!%("`@($4@("`@12`@("!4("`@
M($4@("`@12`@("!%("`@($4*<V5Q=65N8V5S("`@("`@("!N("`@(%0@("`@
M5"`@("!N("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!%("`@(%0@("`@
M12`@("!4"F%F9F5C=&5D4F]W<R`@("`@;B`@("!4("`@($4@("`@12`@("!4
M("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!%("`@(%0@("`@5`IF971C
M:"!M;V1E<R`@("`@('@@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0@
M("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0*9F5T8V@@<F]W(&)Y(&YO
M("!X("`@('@@("`@;B`@("!N("`@('@@("`@>"`@("!X("`@('@@("`@;B`@
M("!X("`@('@@("`@>"`@("!X"G1R86YS86-T:6]N<R`@("`@+2`@("!4("`@
M(%0@("`@5"`@("!N("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@
M(&X@("`@5`IA=71O+6-O;6UI="`@("`@(&X@("`@5"`@("!%("`@($4@("`@
M;B`@("!%("`@($4@("`@12`@("!%("`@(%0@("`@12`@("!N("`@($4*97)R
M;W(@;6%P<&EN9R`@("`M("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4
M("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4"G1A8FQE26YF;R`@("`@
M("`@>"`@("!4("`@(%0@("`@="`@("!4("`@(%0@("`@5"`@("!4("`@(%0@
M("`@5"`@("!4("`@(%0@("`@5`H*9V5T3&ES=$]F*"D@5%E015,*=&%B;&5S
M("`@("`@("`@("`M("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@
M(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4"G9I97=S("`@("`@("`@("`@
M+2`@("!4("`@(%0@("`@+2`@("`M("`@(%0@("`@+2`@("`M("`@("T@("`@
M5"`@("!4("`@("T@("`@5`IU<V5R<R`@("`@("`@("`@("T@("`@5"`@("!4
M("`@("T@("`@+2`@("`M("`@(%0@("`@5"`@("`M("`@("T@("`@5"`@("`M
M("`@("T*9&%T86)A<V5S("`@("`@("`M("`@("T@("`@+2`@("`M("`@(%0@
M("`@+2`@("!4("`@(%0@("`@+2`@("!4("`@(%0@("`@+2`@("`M"F9U;F-T
M:6]N<R`@("`@("`@+2`@("!4("`@("T@("`@+2`@("`M("`@("T@("`@+2`@
M("`M("`@("T@("`@+2`@("!4("`@("T@("`@+0IS>6YO;GEM<R`@("`@("`@
M("T@("`@+2`@("`M("`@("T@("`@+2`@("`M("`@("T@("`@+2`@("!4("`@
M("T@("`@+2`@("`M("`@("T*"@I497-T($-O;F9O<FUA;F-E"BTM+2TM+2TM
M+2TM+2TM+2T*4WEM8F]L<SH*("`@(&\@(#T@(%1E<W0@<&%S<V5D"B`@("!8
M("`]("!497-T(&9A:6QE9`H@("`@3"`@/2`@4V]M92!P;W)T:6]N<R!O9B!T
M:&4@=&5S="!F86EL960@9'5E('1O(&QI;6ET871I;VYS(&EN(%!(4"!O<B!$
M0DU3"B`@("!N("`]("!497-T(')E='5R;G,@(FYO="!C87!A8FQE(@H@("`@
M+2`@/2`@3F]T('1E<W1E9`H*("`@("`@("`@("`@("`@("`@("!F8G-Q;"`@
M("`@(&EF>"`@("`@(&US<W%L("`@("!M>7-Q;&D@("`@(&]D8F,@("`@('-Q
M;&ET90H@("`@("`@("`@("`@("!D8F%S92`@?"`@:6)A<V4@('P@(&US<6P@
M("!\("!M>7-Q;"`@?"`@(&]C:3@@('P@('!G<W%L("!\("!S>6)A<V4*,#%C
M;VYN96-T("`@("`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O
M("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O"C`R9F5T8V@@("`@("`@
M("`@+2`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@
M("`@;R`@("!O("`@(&\@("`@;PHP,W-I;7!L97%U97)Y("`@("T@("`@;R`@
M("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@
M("!O("`@(&\*,#1N=6UC;VQS("`@("`@("`M("`@(&\@("`@;R`@("!O("`@
M(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O"C`U
M<V5Q=65N8V5S("`@("`@+2`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@
M;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;PHP-G!R97!E>&5C("`@
M("`@("T@("`@;R`@("!O("`@(&\@("`@3"`@("!O("`@(&\@("`@;R`@("!O
M("`@(&\@("`@;R`@("!O("`@(&\*,#AA9F9E8W1E9')O=W,@("`M("`@(&\@
M("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@
M("`@;R`@("!O"C`Y;G5M<F]W<R`@("`@("`@+2`@("!O("`@(&\@("`@;R`@
M("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;PHQ
M,&5R<F]R;6%P("`@("`@("T@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@
M(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\*,3%T<F%N<V%C=&EO
M;G,@("`M("`@(&\@("`@;R`@("!O("`@(&X@("`@;R`@("!O("`@(&\@("`@
M;R`@("!O("`@(&\@("`@;B`@("!O"C$S;&EM:70@("`@("`@("`@+2`@("!O
M("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O
M("`@(&\@("`@;PHQ-&9E=&-H;6]D95]O8FIE("T@("`@;R`@("!O("`@(&\@
M("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\*
M,35Q=6]T92`@("`@("`@("`M("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@
M("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O"C$V=&%B;&5I;F9O
M("`@("`@+2`@("!O("`@(&\@("`@3"`@("!O("`@(&\@("`@;R`@("!O("`@
M(&\@("`@;R`@("!O("`@(&\@("`@;PHQ-W%U97)Y("`@("`@("`@("T@("`@
M;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@
M;R`@("!O("`@(&\*,3AG970@("`@("`@("`@("`M("`@(&\@("`@;R`@("!O
M("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O
M"C$Y9V5T;&ES=&]F("`@("`@+2`@("!O("`@(&\@("`@;R`@("!O("`@(&\@
M("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;PH*"D1"35,@5F5R
M<VEO;G,@5&5S=&5D"BTM+2TM+2TM+2TM+2TM+2TM+2TM"F1B87-E("`@;B]A
M"F9B<W%L("`@-"XQ+C8*:6)A<V4@("!&:7)E8FER9"`Q+C4N,2`@*%!(4"`U
M(&]N;'DI"FEF>"`@("`@-RXR(%-T86YD87)D($5D=&ET:6]N"FUS<6P@("`@
M,RXV("`H4$A0('-N87!S:&]T<R!D871E9"`R,#`U+3`R+3$X*0IM<W-Q;"`@
M(#@N,"XW-C`*;7ES<6P@("`T+C`N,C$*;7ES<6QI("`T+C$N-2`@*%!(4"`U
M(&]N;'DI"F]C:3@@("`@.2XR"F]D8F,@("`@1$(R($5312`X+C$@86YD($U3
M($%C8V5S<R`R,#`P"G!G<W%L("`@-RXT+C$@86YD(#@N,"XQ"G-Q;&ET92`@
M4$A0(#4Z(&5X=&5N<VEO;BX@(%!(4"`T.B!014-,('-N87!S:&]T+@IS>6)A
M<V4@($%312`Q,BXU+C,*"E1E<W1S('=E<F4@<&5R9F]R;65D('5N9&5R(&)O
M=&@@;V8@=&AE(&9O;&QO=VEN9R!02%`@=F5R<VEO;G,*=6YL97,@;W1H97)W
M:7-E(&YO=&5D.@H@("`@-"XS+C$Q+61E=B!D871E9"`R,#`U+3`R+3(R"B`@
M("`U+C$N,"UD978@9&%T960@,C`P-2TP,BTR,@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+V1O8W,O1$(O9&]C+U1%4U1%4E,`````````````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$R,S`P`#$P-3$U-#,S-S,U`#`R
M,38S-P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```]/3T]/3T]/3T]/3T]/3T]/3T]"DA/5R!43R!415-4(%!%05(@1$(*/3T]
M/3T]/3T]/3T]/3T]/3T]/0H*)$ED.B!415-415)3+'8@,2XR,"`R,#`U+S`R
M+S$V(#`V.C,S.C$R(&1A;FEE;&,@17AP("0*"@I)3E123T150U1)3TX*/3T]
M/3T]/3T]/3T]"@I4:&5S92!A<F4@:6YS=')U8W1I;VYS(&9O<B!T97-T:6YG
M(%!%05(@1$(@;VX@82!7:6YD;W=S(&UA8VAI;F4@=7-I;F<@80I#>6=W:6X@
M0F%S:"!S:&5L;"X@($%D:G5S="!T:&4@<&%T:',@86YD(&-O;6UA;F1S('1O
M(&UA=&-H('EO=7(@<WES=&5M+@I4:&ES(&-O;F9I9W5R871I;VX@:7,@=7-E
M9"!B96-A=7-E('1H97-E('!R96-I<V4@<W1E<',@87)E(&MN;W=N('1O('=O
M<FLN"@I.3U1%.B`@66]U(&UU<W0@;&]G(&]N(&%S(&$@=7-E<B!W:&EC:"!H
M87,@<&5R;6ES<VEO;G,@=&\@;6]D:69Y('1H90IC;VYT96YT<R!O9B!Y;W5R
M(%!(4"!E>&5C=71A8FQE)W,@9&ER96-T;W)Y+B`@5&AI<R!I<R!N96-E<W-A
M<GD@9F]R(&)O=&@*8V]N9FEG=7)I;F<@04Y$(')U;FYI;F<@=&AE('1E<W0@
M<WES=&5M+@H*"DE.4U1!3$Q!5$E/3@H]/3T]/3T]/3T]/3T*"D]B=&%I;B!0
M2%`G<R!497-T($9R86UE=V]R:PHM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2T*268@>6]U(&1O;B=T(&AA=F4@4$A0)W,@=&5S="!F<F%M97=O<FLL('EO
M=2!N965D('1O(&]B=&%I;B!I="X@(%1H97-E"G-T97!S(&EN8VQU9&4@8VAA
M;F=I;F<@=&AE('=O<FMI;F<@9&ER96-T;W)Y+"!D;W=N;&]A9&EN9R!R=6XM
M=&5S=',N<&AP"G9I82!#5E,@86YD(&-O<'EI;F<@=&AE(&9I;&4@:6YT;R!P
M;&%C92X@($-H86YG92!T:&4@<F5V:7-I;VX@9FQA9R!I;B!T:&4*0U93(&-O
M;6UA;F0@87,@87!P<F]P<FEA=&4@9F]R('EO=7(@<')E<V5N="!V97)S:6]N
M(&]F(%!(4"X*"B!C9"!C.B]P<F]G<F%^,2]P:'`*(&-V<R`M9"`Z<'-E<G9E
M<CIC=G-R96%D0&-V<RYP:'`N;F5T.B]R97!O<VET;W)Y(&QO9VEN("`@(R!P
M87-S=V]R9"!I<R!P:'!F:0H@8W9S("UD(#IP<V5R=F5R.F-V<W)E861`8W9S
M+G!H<"YN970Z+W)E<&]S:71O<GD@8V\@+7(@4$A07S1?,R!<"B`@("`@+60@
M=&5S="!P:'`M<W)C+W)U;BUT97-T<RYP:'`*(&-P('1E<W0O<G5N+71E<W1S
M+G!H<"`N"B!R;2`M<F8@=&5S=`H*"D]B=&%I;B!$0B!A;F0@:71S(%1E<W0@
M1G)A;65W;W)K"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"BH@
M248@4$5!4B!$0B!)4R!!3%)%0419($E.4U1!3$Q%1#H*"B`@268@>6]U(&AA
M=F4@4$5!4B!$0B!I;G-T86QL960@86QR96%D>2P@9V]O9"X@(%1H92!T97-T
M('-U:71E"B`@:7,@:6X@<&QA8V4N("!/<&5N('5P(&$@8V]M;6%N9"]S:&5L
M;"!P<F]M<'0@86YD(&UO=F4@:6YT;PH@('1H92!T97-T(&1I<F5C=&]R>2X*
M"B`@(&-D(#QP871H('1O('!E87(@:6YS86QL/B]T97-T<R]$0B]T97-T<PH*
M*B!624$@02!.15<@24Y35$%,3$%424].(%5324Y'(%1(12!014%2($E.4U1!
M3$Q%4CH*"B`@26YS=&%L;&EN9R!014%2(&AA<R!G;W1T96X@9F%I<FQY(&5A
M<WDN("!&;VQL;W<@=&AE(&EN<W1R=6-T:6]N<PH@(&9R;VT@=&AE(&UA;G5A
M;#H@(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+VEN<W1A;&QA=&EO
M;BYP:'`*("!/;F-E(%!%05(@86YD($1"(&%R92!I;G-T86QL960L(&UO=F4@
M=&\@=&AE('1E<W0@9&ER96-T;W)Y+@H*("`@8V0@<&5A<B]T97-T<R]$0B]T
M97-T<PH**B!624$@0U93.@H*("!#<F5A=&4@82!L;V-A=&EO;B!T;R!S=&]R
M92!T:&4@=&5S="!I;G-T86QL871I;VX@;V8@1$(@86YD(&ET<PH@('1E<W0@
M<V-R:7!T<RX*"B`@(&UK9&ER(&0Z+W!E87)T97-T"B`@(&-D(&0Z+W!E87)T
M97-T"B`@(&-V<R`M9"`Z<'-E<G9E<CIC=G-R96%D0&-V<RYP:'`N;F5T.B]R
M97!O<VET;W)Y(&-O("U0('!E87(O1$(*"B`@5V4@87-S=6UE('EO=2!A;')E
M861Y(&AA=F4@=&AE(%!%05(@8F%S92!P86-K86=E(&EN<W1A;&QE9"X@($EF
M"B`@>6]U(&1O;B=T+"!Y;W4@=VEL;"!N965D('1O(&1O('-O+"!B=70@=&AE
M(&EN<W1R=6-T:6]N<R!F;W(*("!D;VEN9R!T:&%T(&%R92!B97EO;F0@=&AE
M('-C;W!E(&]F('1H:7,@9&]C=6UE;G0N("!3964*("!H='1P.B\O<&5A<BYP
M:'`N;F5T+VUA;G5A;"]E;B]I;G-T86QL871I;VXN<&AP(&9O<B!M;W)E(&EN
M9F\N"@H@($UO=F4@=&\@=&AE('1E<W0@9&ER96-T;W)Y+@H*("`@8V0@<&5A
M<B]$0B]T97-T<PH*"D-O<'D@=&AE(%-T87)T97(@4VAE;&P@4V-R:7!T(&%N
M9"!%9&ET('1H92!0871H<PHM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2T*5&\@;6%K92!S=&%R=&EN9R!U<"!E86-H
M('1E<W0@<G5N(&5A<VEE<BP@=V4@:&%V92!I;F-L=61E9"!T=V\@<VAE;&P*
M<V-R:7!T<RX@(%1H92!O<FEG:6YA;"!F:6QE<R!A<F4@;F%M960@(G)U;BYC
M=G,B+B`@5&AE>2!N965D('1O(&)E"G)E;F%M960@=&\@(G)U;B(@<V\@0U93
M('=O;B=T(&)O=&AE<B!Y;W4@=VET:"!T<F%C:VEN9R!T:&5M+B`@5&AE;BP*
M=&AE('!A=&AS(&%N9"!F:6QE(&YA;65S(&EN('1H96T@;F5E9"!T;R!B92!S
M970@=&\@=&AO<V4@=7-E9"!B>0IY;W5R('-Y<W1E;2X*"B!C<"!R=6XN8W9S
M(')U;@H@8VAM;V0@-S4U(')U;@H@=FD@<G5N"@H@8V0@9')I=F5R"B!C<"!R
M=6XN8W9S(')U;@H@8VAM;V0@-S4U(')U;@H@=FD@<G5N"@H*0V]P>2!T:&4@
M4V5T=7`@1FEL92!A;F0@161I="!T:&4@1%-.)W,*+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*5&AE('1E<W0@<W5I=&4@8V]N=&%I
M;G,@82!F:6QE('1H870@<W1O<F5S('1H92!$4TXG<R!N965D960@=&\*8V]N
M;F5C="!T;R!Y;W5R(&1A=&%B87-E+B`@5&AE(&]R:6=I;F%L(&9I;&4@:7,@
M(G-E='5P+FEN8RYC=G,B"F%N9"!I="!N965D<R!T;R!B92!R96YA;65D(")S
M971U<"YI;F,B('-O($-64R!W;VXG="!T<F%C:R!I="X*5&AE;B!Y;W4G;&P@
M;F5E9"!T;R!E9&ET('1H92!$4TXG<R!I;B!I="X*"B!C<"!S971U<"YI;F,N
M8W9S('-E='5P+FEN8PH@=FD@<V5T=7`N:6YC"@H*4E5.(%1(12!415-44PH]
M/3T]/3T]/3T]/3T]"@I4;R!R=6X@86QL('1E<W1S.B`@+B]R=6X*5&\@<G5N
M(&]N92!T97-T.B`@("XO<G5N(#QT97-T(&9I;&4@;F%M93X*17AA;7!L93H@
M("`@("`@("`@("XO<G5N(&1B7W!A<G-E9'-N+G!H<'0*"@I497-T(%1Y<&5S
M(&%N9"!,;V-A=&EO;G,*+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"G1E<W1S
M("`@("`@("`@("`@($-O;6UO;B!014%2($1"('1E<W1S"G1E<W1S+V1R:79E
M<B`@("`@($-O;6UO;B!T97-T<R!F;W(@86QL('1H92!D<FEV97)S"@H*4F5S
M=6QT<R!A;F0@5VAA="!4;R!$;R!7:71H(%1H96T*+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2T*16%C:"!T97-T('1H870@9F%I;',@9V5N97)A
M=&5S(&$@+G!H<"`H=VAI8V@@>6]U(&-A;B!E>&5C=71E*2P@82`N97AP"BAT
M:&4@97AP96-T960@;W5T<'5T*2P@82`N;W5T("AT:&4@=&5S="!O=71P=70I
M(&%N9"!A("YD:69F("AA(&1I9F8@+74*9G)O;2!T:&4@+F5X<"!A;F0@+F]U
M="!F:6QE<RDN"@I)9B!Y;W4@<G5N('1H92!T97-T<RP@<&QE87-E(')E<&]R
M="!O<B!F:6QL('1H92!415-4($-/3D9/4DU!3D-%('1A8FQE"FEN('1H92!3
M5$%455,@9&]C=6UE;G0N("!"969O<F4@86YY(&-O;6UI="!T;R!#5E,@8F4@
M<W5R92!T;R!R=6X@=&AE"G1E<W1S(&%N9"!N;W1H:6YG(&=O="!B<F]K96X@
M=VET:"!T:&4@8VAA;F=E+@H*268@>6]U(&=E="!T:&4@;65S<V%G92`B4TM)
M4"(L(&UE86YS('1H870@=&AE('1E<W0@:70G<R!N;W0@97AE8W5T960N"DQO
M;VL@870@=&AE($1"+W1E<W1S+V1R:79E<B]S:VEP:68N:6YC('1O('-E92!W
M:&%T)W,@=&AE('!R;V)L96T**'!R;V)A8FQY(&$@8V]N;F5C=&EO;B!P<F]B
M;&5M*2X*"@I$0B!415-415(@34%44DE8"CT]/3T]/3T]/3T]/3T]/3T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F8G-Q;"`@("!I9G@@("`@
M;7-S<6P@("!M>7-Q;&D@("!O9&)C("`@<W%L:71E"E1%4U1%4B`@("`@("`@
M("`@("`@("`@("`@("!D8F%S92!\(&EB87-E('P@(&US<6P@?"!M>7-Q;"!\
M("!O8VDX('P@<&=S<6P@?"!S>6)A<V4*2F]H;B!(;W)T;VX@("`@("`@("`@
M("`@("`@("`@+2`@("T@("`M("`@6"`@("T@("`M("`@+2`@("T@("`M("`@
M+2`@("T@("`M("`@+0I4:6T@6FEC:W5S("`@("`@("`@("`@("`@("`@("`M
M("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@(%@@("`M("`@+2`@("T@
M("`M"E1I;2!087)K:6X@("`@("`@("`@("`@("`@("`@("T@("`M("`@+2`@
M("T@("`M("`@+2`@("T@("`M("`@6"`@("T@("`M("`@+2`@("T*4&%U;"!'
M87)D:6YE<B`@("`@("`@("`@("`@("`@+2`@("T@("`M("`@6"`@("T@("`M
M("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+0IP971E<G=B0&EA9G)I8V$N
M8V]M("`@("`@("`@("`M("`@+2`@("T@("!8("`@+2`@("T@("`M("`@+2`@
M("T@("`M("`@+2`@("T@("`M"D1A;FEE;"P@061A;2`@("`@("`@("`@("`@
M("`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("`M("`@6"`@("T@("`M
M("`@+2`@("T*<WII:4!S>FEI<V]F="YC;VT@("`@("`@("`@("`@+2`@("T@
M("`M("`@+2`@("T@("`M("`@+2`@("T@("`M("`@6+D@("T@("`M("`@+0IJ
M;6@S0&QI;G5X9G)E86LN8V]M("`@("`@("`@("`M("`@+2`@("T@("`M("`@
M+2`@("T@("`M("`@+2`@("T@("`M("`@6"`@("T@("`M"DME=FEN($AE;G)I
M:W-O;B`@("`@("`@("`@("`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T@
M("`M("`@6"`@("T@("`M("`@+2`@("T*4W1I9R!"86MK96X@("`@("`@("`@
M("`@("`@("`@+2`@("T@("`M("`@+2`@("T@("`M("`@6"`@("T@("`M("`@
M+2`@(%@@("`M("`@+0I#:'5C:R!(86=E;F)U8V@@("`@("`@("`@("`@("`M
M("`@+2`@("T@("`M("`@+2`@(%@@("`M("`@+2`@("T@("`M("`@+2`@("T@
M("`M"DQU9&]V:6-O($UA9VYO8V%V86QL;R`@("`@("`@("T@("`M("`@6"`@
M("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T*1&%N:65L
M($-O;G9I<W-O<B`@("`@("`@("`@("`@6"`@(%@@("!8("`@+2`@(%@@("!8
M("`@6"`@(%@@("!8("`@6+(@(%@@("!8("`@6`H*34E34TE.1R!415-415)3
M("`@("`@("`@("`@("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T@
M("`M("`@+2`@("T@("`M("`@+0H*0V]M;65N=',Z"@I;,5TZ($]$0D,@=7-I
M;F<@24)-($1",@I;,ETZ($]$0D,@=7-I;F<@24)-($1",B!A;F0@35,@06-C
M97-S"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O
M2%144%]297%U97-T+P``````````````````````````````````````````
M`````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-3$U-#,S-S,T`#`R,C`R,P`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O9&]C<R](5%107U)E<75E<W0O9&]C<R\`````````````
M````````````````````````````````````````````````,#`P,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W,S0`,#(R-S4S
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TA45%!?4F5Q=65S
M="]D;V-S+V1O=VYL;V%D+7!R;V=R97-S+G!H<```````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-38T-``Q
M,#4Q-30S,S<S-``P,C<Q-#8`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J($%N(&5X86UP;&4@;V8@3&ES
M=&5N97(@=7-A9V4@=VET:"!(5%107U)E<75E<W0N(%1H:7,@9&]W;FQO861S
M(&%N9"!S879E<R`*("H@=&AE(&9I;&4@9&ES<&QA>6EN9R!T:&4@<')O9W)E
M<W,@8F%R(&EN('1H92!P<F]C97-S+@H@*B`*("H@3F]T92!T=V\@=&AI;F=S
M.@H@*B`Q*2!4:&4@9FEL92!S:&]U;&0@8F4@<G5N(&EN(&-O;G-O;&4L(&YO
M="!I;B!B<F]W<V5R.PH@*B`R*2!9;W4@<VAO=6QD('1U<FX@;W5T<'5T(&)U
M9F9E<FEN9R!/1D8@9F]R('1H:7,@=&\@=V]R:R!P<F]P97)L>2X*("H@"B`J
M("1)9#H@9&]W;FQO860M<')O9W)E<W,N<&AP+'8@,2XQ(#(P,#,O,3`O,C<@
M,3`Z-#@Z-#D@879B($5X<"`D"B`J+PH*<F5Q=6ER95]O;F-E("=(5%10+U)E
M<75E<W0N<&AP)SL*<F5Q=6ER95]O;F-E("=(5%10+U)E<75E<W0O3&ES=&5N
M97(N<&AP)SL*<F5Q=6ER95]O;F-E("=#;VYS;VQE+U!R;V=R97-S0F%R+G!H
M<"<["@I014%2.CIS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?1$E%*3L*
M"G-E=%]T:6UE7VQI;6ET*#`I.PH*8VQA<W,@2%144%]297%U97-T7T1O=VYL
M;V%D3&ES=&5N97(@97AT96YD<R!(5%107U)E<75E<W1?3&ES=&5N97(*>PH@
M("`O*BH*("`@("H@2&%N9&QE(&9O<B!T:&4@=&%R9V5T(&9I;&4*("`@("H@
M0'9A<B!I;G0*("`@("HO"B`@("!V87(@)%]F<#L*"B`@("\J*@H@("`@*B!#
M;VYS;VQE7U!R;V=R97-S0F%R(&EN=&%N8V4@=7-E9"!T;R!D:7-P;&%Y('1H
M92!I;F1I8V%T;W(*("`@("H@0'9A<B!O8FIE8W0*("`@("HO"B`@("!V87(@
M)%]B87(["@H@("`O*BH*("`@("H@3F%M92!O9B!T:&4@=&%R9V5T(&9I;&4*
M("`@("H@0'9A<B!S=')I;F<*("`@("HO"B`@("!V87(@)%]T87)G970["@H@
M("`O*BH*("`@("H@3G5M8F5R(&]F(&)Y=&5S(')E8V5I=F5D('-O(&9A<@H@
M("`@*B!`=F%R(&EN=`H@("`@*B\*("`@('9A<B`D7W-I>F4@/2`P.PH*("`@
M(&9U;F-T:6]N($A45%!?4F5Q=65S=%]$;W=N;&]A9$QI<W1E;F5R*"D*("`@
M('L*("`@("`@("`D=&AI<RT^2%144%]297%U97-T7TQI<W1E;F5R*"D["B`@
M("!]"@H@("`O*BH*("`@("H@3W!E;G,@=&AE('1A<F=E="!F:6QE"B`@("`J
M($!P87)A;2!S=')I;F<@5&%R9V5T(&9I;&4@;F%M90H@("`@*B!`=&AR;W=S
M(%!%05)?17)R;W(*("`@("HO"B`@("!F=6YC=&EO;B!S971487)G970H)'1A
M<F=E="D*("`@('L*("`@("`@("`D=&AI<RT^7W1A<F=E="`]("1T87)G970[
M"B`@("`@("`@)'1H:7,M/E]F<"`]($!F;W!E;B@D=&%R9V5T+"`G=V(G*3L*
M("`@("`@("!I9B`H(21T:&ES+3Y?9G`I('L*("`@("`@("`@("`@4$5!4CHZ
M<F%I<V5%<G)O<B@B0V%N;F]T(&]P96X@)WLD=&%R9V5T?2<B*3L*("`@("`@
M("!]"B`@("!]"@H@("`@9G5N8W1I;VX@=7!D871E*"8D<W5B:F5C="P@)&5V
M96YT+"`D9&%T82`](&YU;&PI"B`@("!["B`@("`@("`@<W=I=&-H("@D979E
M;G0I('L*("`@("`@("`@("`@8V%S92`G<V5N=%)E<75E<W0G.B`*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?=&%R9V5T(#T@8F%S96YA;64H)'-U8FIE8W0M
M/E]U<FPM/G!A=&@I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("!C87-E("=G;W1(96%D97)S)SH*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D9&%T85LG8V]N=&5N="UD:7-P;W-I=&EO;B==*2`F)@H@("`@("`@
M("`@("`@("`@("`@('!R96=?;6%T8V@H)R]F:6QE;F%M93TB*%M>(ETK*2(O
M)RP@)&1A=&%;)V-O;G1E;G0M9&ES<&]S:71I;VXG72P@)&UA=&-H97,I*2![
M"@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971487)G970H8F%S96YA
M;64H)&UA=&-H97-;,5TI*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%1A<F=E="@D=&AI<RT^7W1A
M<F=E="D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V)A<B`])B!N97<@0V]N<V]L95]0<F]G<F5S<T)A<B@*("`@("`@("`@
M("`@("`@("`@("`G*B`G("X@)'1H:7,M/E]T87)G970@+B`G("5F<F%C=&EO
M;B4@2T(@6R5B87(E72`E<&5R8V5N="4G+"`G/3XG+"`G+2<L(`H@("`@("`@
M("`@("`@("`@("`@(#<Y+"`H:7-S970H)&1A=&%;)V-O;G1E;G0M;&5N9W1H
M)UTI/R!R;W5N9"@D9&%T85LG8V]N=&5N="UL96YG=&@G72`O(#$P,C0I.B`Q
M,#`I"B`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]S:7IE(#T@,#L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@8V%S92`G=&EC:R<Z"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-I>F4@
M*ST@<W1R;&5N*"1D871A*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8F%R
M+3YU<&1A=&4H<F]U;F0H)'1H:7,M/E]S:7IE("\@,3`R-"DI.PH@("`@("`@
M("`@("`@("`@9G=R:71E*"1T:&ES+3Y?9G`L("1D871A*3L*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G9V]T0F]D>2<Z"B`@
M("`@("`@("`@("`@("!F8VQO<V4H)'1H:7,M/E]F<"D["B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@
M("`@("!014%2.CIR86ES945R<F]R*")5;FAA;F1L960@979E;G0@)WLD979E
M;G1])R(I.PH@("`@("`@('T@+R\@<W=I=&-H"B`@("!]"GT*"B\O(%1R>2!U
M<VEN9R!A;GD@;W1H97(@<&%C:V%G92!I9B!Y;W4@;&EK92P@8G5T(&-H;V]S
M92!T:&4@8FEG9V5R(&]N97,*+R\@=&\@8F4@86)L92!T;R!S964@=&AE('!R
M;V=R97-S(&)A<@HD=7)L(#T@)VAT='`Z+R]P96%R+G!H<"YN970O9V5T+TA4
M34Q?475I8VM&;W)M+7-T86)L92<["@HD<F5Q(#TF(&YE=R!(5%107U)E<75E
M<W0H)'5R;"D["@HD9&]W;FQO860@/28@;F5W($A45%!?4F5Q=65S=%]$;W=N
M;&]A9$QI<W1E;F5R*"D["B1R97$M/F%T=&%C:"@D9&]W;FQO860I.PHD<F5Q
M+3YS96YD4F5Q=65S="AF86QS92D["C\^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+V1O8W,O2%144%]297%U97-T+V1O8W,O97AA;7!L92YP
M:'```````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U-C`T`#$P-3$U-#,S-S,T`#`R-3$R
M-``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P
M>7)I9VAT("AC*2`R,#`R+"!2:6-H87)D($AE>65S("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!!;&P@<FEG:'1S(')E<V5R
M=F5D+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@4F5D:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@86YD(&)I;F%R
M>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T("`@('P*+R\@?"!M;V1I9FEC871I
M;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG
M(&-O;F1I=&EO;G,@("`@?`HO+R!\(&%R92!M970Z("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!O(%)E
M9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@
M86)O=F4@8V]P>7)I9VAT("`@("`@?`HO+R!\("`@;F]T:6-E+"!T:&ES(&QI
M<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R
M+B`@("`@("!\"B\O('P@;R!2961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O
M<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H="`@('P*+R\@
M?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F
M;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@?`HO+R!\("`@9&]C=6UE;G1A
M=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE
M(&1I<W1R:6)U=&EO;BY\"B\O('P@;R!4:&4@;F%M97,@;V8@=&AE(&%U=&AO
M<G,@;6%Y(&YO="!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92`@("`@
M('P*+R\@?"`@('!R;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES('-O9G1W87)E
M('=I=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B`@?`HO+R!\("`@<&5R
M;6ES<VEO;BX@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@?"!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(
M12!#3U!94DE'2%0@2$],1$524R!!3D0@0T].5%))0E543U)3("`@?`HO+R!\
M(")!4R!)4R(@04Y$($%.62!%6%!215-3($]2($E-4$Q)140@5T%24D%.5$E%
M4RP@24Y#3%5$24Y'+"!"550@3D]4("`@("!\"B\O('P@3$E-251%1"!43RP@
M5$A%($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$
M($9)5$Y%4U,@1D]2('P*+R\@?"!!(%!!4E1)0U5,05(@4%524$]312!!4D4@
M1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%($-/4%E224=(5"`@
M?`HO+R!\($]73D52($]2($-/3E1224)55$]24R!"12!,24%"3$4@1D]2($%.
M62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!\"B\O('P@4U!%0TE!
M3"P@15A%35!,05)9+"!/4B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ5
M1$E.1RP@0E54($Y/5"`@("`@('P*+R\@?"!,24U)5$5$(%1/+"!04D]#55)%
M345.5"!/1B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&
M(%5312P@?`HO+R!\($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3($E.
M5$524E505$E/3BD@2$]7159%4B!#0553140@04Y$($].($%.62!\"B\O('P@
M5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@4U12
M24-4($Q)04))3$E462P@3U(@5$]25"`@('P*+R\@?"`H24Y#3%5$24Y'($Y%
M1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E.($%.62!705D@3U54
M($]&(%1(12!54T4@?`HO+R!\($]&(%1(25,@4T]&5%=!4D4L($5614X@248@
M041625-%1"!/1B!42$4@4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N("!\
M"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@4FEC:&%R9"!(97EE
M<R`\<FEC:&%R9$!P:'!G=7)U+F]R9SX@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*"@HO*BH*
M*B!4:&ES('=I;&P@9W)A8B!A('=E8G!A9V4@86YD(&1I<W!L87D@:70**B\*
M"6EN8VQU9&4H)TA45%`O4F5Q=65S="YP:'`G*3L*"@DD<F5Q(#T@)FYE=R!(
M5%107U)E<75E<W0H)VAT='`Z+R]W=W<N<&AP+FYE="<I.PH))')E<2T^<V5T
M365T:&]D*$A45%!?4D5154535%]-151(3T1?4$]35"D["@DD<F5Q+3YA9&10
M;W-T1&%T82@G1F]O)RP@)V)A<B<I.PH))')E<2T^<V5N9%)E<75E<W0H*3L*
M"21R97-P;VYS93$@/2`D<F5Q+3YG971297-P;VYS94)O9'DH*3L*"0H))')E
M<2T^<V5T365T:&]D*$A45%!?4D5154535%]-151(3T1?1T54*3L*"21R97$M
M/G-E=%523"@G:'1T<#HO+W!E87(N<&AP+FYE="<I.PH))')E<2T^8VQE87)0
M;W-T1&%T82@I.PH))')E<2T^<V5N9%)E<75E<W0H*3L*"@DD<F5S<&]N<V4R
M(#T@)')E<2T^9V5T4F5S<&]N<V5";V1Y*"D["@H)96-H;R`D<F5S<&]N<V4Q
M.PH)96-H;R`D<F5S<&]N<V4R.PH_/@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C
M<R],;V<O````````````````````````````````````````````````````
M````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`U,34T,S,W,S4`,#(P,C4V`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S+P``````````````````````
M```````````````````````````````````````````````````P,#`P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<S-0`P,C$R
M,#8`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O
M97AA;7!L97,O````````````````````````````````````````````````
M`````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-3$U-#,S-S,U`#`R,S`R-``@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O9&]C<R],;V<O9&]C<R]E>&%M<&QE<R]C;VUP;W-I=&4N<&AP````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`T-C$`,3`U,34T,S,W,S4`,#(U-30P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"@IR97%U
M:7)E7V]N8V4@)TQO9RYP:'`G.PH*)&-O;G-O;&4@/2`F3&]G.CIS:6YG;&5T
M;VXH)V-O;G-O;&4G+"`G)RP@)U1%4U0G*3L*)&9I;&4@/2`F3&]G.CIS:6YG
M;&5T;VXH)V9I;&4G+"`G;W5T+FQO9R<L("=415-4)RD["@HD8V]M<&]S:71E
M(#T@)DQO9SHZ<VEN9VQE=&]N*"=C;VUP;W-I=&4G*3L*)&-O;7!O<VET92T^
M861D0VAI;&0H)&-O;G-O;&4I.PHD8V]M<&]S:71E+3YA9&1#:&EL9"@D9FEL
M92D["@HD8V]M<&]S:71E+3YL;V<H)U1H:7,@979E;G0@=VEL;"!B92!L;V=G
M960@=&\@8F]T:"!H86YD;&5R<RXG*3L*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3&]G
M+V1O8W,O97AA;7!L97,O8V]N<V]L92YP:'``````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,C(U`#$P-3$U-#,S-S,U`#`R-3$W-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=,
M;V<N<&AP)SL*"B1L;V=G97(@/2`F3&]G.CIS:6YG;&5T;VXH)V-O;G-O;&4G
M+"`G)RP@)VED96YT)RD["F9O<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2![
M"B`@("`D;&]G9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PI]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S+V5X86UP
M;&5S+V1I<W!L87DN<&AP````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0S,``Q,#4Q
M-30S,S<S-0`P,C4Q-S<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G3&]G+G!H<"<["@HD
M8V]N9B`](&%R<F%Y*"=E<G)O<E]P<F5P96YD)R`]/B`G/&9O;G0@8V]L;W(]
M(B-F9C`P,#`B/CQT=#XG+`H@("`@("`@("`@("`@("=E<G)O<E]A<'!E;F0G
M("`]/B`G/"]T=#X\+V9O;G0^)RD["B1L;V=G97(@/2`F3&]G.CIS:6YG;&5T
M;VXH)V1I<W!L87DG+"`G)RP@)R<L("1C;VYF+"!014%27TQ/1U]$14)51RD[
M"F9O<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2!["B`@("`D;&]G9V5R+3YL
M;V<H(DQO9R!E;G1R>2`D:2(I.PI]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O9&]C<R],;V<O9&]C<R]E>&%M<&QE<R]E<G)O<E]L
M;V<N<&AP````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R-3$`,3`U,34T,S,W,S4`,#(U
M-3(U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"@IR97%U:7)E7V]N8V4@)TQO9RYP:'`G.PH*)&QO9V=E<B`]("9,
M;V<Z.G-I;F=L971O;B@G97)R;W)?;&]G)RP@4$5!4E],3T=?5%E015]365-4
M14TL("=I9&5N="<I.PIF;W(@*"1I(#T@,#L@)&D@/"`Q,#L@)&DK*RD@>PH@
M("`@)&QO9V=E<BT^;&]G*"),;V<@96YT<GD@)&DB*3L*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+V1O8W,O3&]G+V1O8W,O97AA;7!L97,O9FEL92YP:'``````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,S,P`#$P-3$U-#,S-S,U`#`R-#0U,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`H*<F5Q
M=6ER95]O;F-E("=,;V<N<&AP)SL*"B1C;VYF(#T@87)R87DH)VUO9&4G(#T^
M(#`V,#`L("=T:6UE1F]R;6%T)R`]/B`G)5@@)7@G*3L*)&QO9V=E<B`]("9,
M;V<Z.G-I;F=L971O;B@G9FEL92<L("=O=70N;&]G)RP@)VED96YT)RP@)&-O
M;F8I.PIF;W(@*"1I(#T@,#L@)&D@/"`Q,#L@)&DK*RD@>PH@("`@)&QO9V=E
M<BT^;&]G*"),;V<@96YT<GD@)&DB*3L*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO
M9R]D;V-S+V5X86UP;&5S+VUA:6PN<&AP````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#,T,@`Q,#4Q-30S,S<S-0`P,C0T-38`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G
M3&]G+G!H<"<["@HD8V]N9B`](&%R<F%Y*"=S=6)J96-T)R`]/B`G26UP;W)T
M86YT($QO9R!%=F5N=',G*3L*)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G
M;6%I;"<L("=W96)M87-T97)`97AA;7!L92YC;VTG+"`G:61E;G0G+"`D8V]N
M9BD["F9O<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2!["B`@("`D;&]G9V5R
M+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PI]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R],;V<O9&]C<R]E>&%M
M<&QE<R]N=6QL+G!H<```````````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R,#4`,3`U
M,34T,S,W,S4`,#(T-3`T`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TQO9RYP:'`G.PH*
M)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G;G5L;"<I.PIF;W(@*"1I(#T@
M,#L@)&D@/"`Q,#L@)&DK*RD@>PH@("`@)&QO9V=E<BT^;&]G*"),;V<@96YT
M<GD@)&DB*3L*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O97AA;7!L97,O;V)S97)V
M97)?;6%I;"YP:'```````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,C$W`#$P-3$U-#,S-S,U`#`R
M-C,V-P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<O;V)S97)V97(N<&AP)SL*"F-L
M87-S($QO9U]O8G-E<G9E<E]M86EL(&5X=&5N9',@3&]G7V]B<V5R=F5R"GL*
M("`@('9A<B`D7W1O(#T@)R<["B`@("!V87(@)%]S=6)J96-T(#T@)R<["B`@
M("!V87(@)%]P871T97)N(#T@)R<["@H@("`@9G5N8W1I;VX@3&]G7V]B<V5R
M=F5R7VUA:6PH)'!R:6]R:71Y+"`D8V]N9BD*("`@('L*("`@("`@("`O*B!#
M86QL('1H92!B87-E(&-L87-S(&-O;G-T<G5C=&]R+B`J+PH@("`@("`@("1T
M:&ES+3Y,;V=?;V)S97)V97(H)'!R:6]R:71Y*3L*"B`@("`@("`@+RH@0V]N
M9FEG=7)E('1H92!O8G-E<G9E<BX@*B\*("`@("`@("`D=&AI<RT^7W1O(#T@
M)&-O;F9;)W1O)UT["B`@("`@("`@)'1H:7,M/E]S=6)J96-T(#T@)&-O;F9;
M)W-U8FIE8W0G73L*("`@("`@("`D=&AI<RT^7W!A='1E<FX@/2`D8V]N9ELG
M<&%T=&5R;B==.PH@("`@?0H*("`@(&9U;F-T:6]N(&YO=&EF>2@D979E;G0I
M"B`@("!["B`@("`@("`@:68@*'!R96=?;6%T8V@H)'1H:7,M/E]P871T97)N
M+"`D979E;G1;)VUE<W-A9V4G72D@(3T@,"D@>PH@("`@("`@("`@("!M86EL
M*"1T:&ES+3Y?=&\L("1T:&ES+3Y?<W5B:F5C="P@)&5V96YT6R=M97-S86=E
M)UTI.PH@("`@("`@('T*("`@('T*?0H*/SX*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O97AA;7!L97,O
M<&5A<E]E<G)O<E]H86YD;&5R+G!H<```````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,34T`#$P-3$U-#,S
M-S,U`#`R-S,W,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*"F9U;F-T
M:6]N(&5R<F]R2&%N9&QE<B@D97)R;W(I"GL*("`@(&=L;V)A;"`D;&]G9V5R
M.PH*("`@("1M97-S86=E(#T@)&5R<F]R+3YG971-97-S86=E*"D["@H@("`@
M:68@*"%E;7!T>2@D97)R;W(M/F)A8VMT<F%C95LQ75LG9FEL92==*2D@>PH@
M("`@("`@("1M97-S86=E("X]("<@*"<@+B`D97)R;W(M/F)A8VMT<F%C95LQ
M75LG9FEL92==.PH@("`@("`@(&EF("@A96UP='DH)&5R<F]R+3YB86-K=')A
M8V5;,5U;)VQI;F4G72DI('L*("`@("`@("`@("`@)&UE<W-A9V4@+CT@)R!A
M="!L:6YE("<@+B`D97)R;W(M/F)A8VMT<F%C95LQ75LG;&EN92==.PH@("`@
M("`@('T*("`@("`@("`D;65S<V%G92`N/2`G*2<["B`@("!]"@H@("`@)&QO
M9V=E<BT^;&]G*"1M97-S86=E+"`D97)R;W(M/F-O9&4I.PI]"@HD;&]G9V5R
M(#T@)DQO9SHZ<VEN9VQE=&]N*"=C;VYS;VQE)RP@)R<L("=I9&5N="<I.PH*
M4$5!4CHZ<V5T17)R;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"04-++"`G
M97)R;W)(86YD;&5R)RD["E!%05(Z.G)A:7-E17)R;W(H)U1H:7,@:7,@86X@
M:6YF;W)M871I;VX@;&]G(&UE<W-A9V4N)RP@4$5!4E],3T=?24Y&3RD["@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O97AA
M;7!L97,O<&AP7V5R<F]R7VAA;F1L97(N<&AP````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-#`P`#$P
M-3$U-#,S-S,U`#`R-S(R-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*
M"F9U;F-T:6]N(&5R<F]R2&%N9&QE<B@D8V]D92P@)&UE<W-A9V4L("1F:6QE
M+"`D;&EN92D*>PH@("`@9VQO8F%L("1L;V=G97(["@H@("`@+RH@36%P('1H
M92!02%`@97)R;W(@=&\@82!,;V<@<')I;W)I='DN("HO"B`@("!S=VET8V@@
M*"1C;V1E*2!["B`@("!C87-E($5?5T%23DE.1SH*("`@(&-A<V4@15]54T52
M7U=!4DY)3D<Z"B`@("`@("`@)'!R:6]R:71Y(#T@4$5!4E],3T=?5T%23DE.
M1SL*("`@("`@("!B<F5A:SL*("`@(&-A<V4@15].3U1)0T4Z"B`@("!C87-E
M($5?55-%4E].3U1)0T4Z"B`@("`@("`@)'!R:6]R:71Y(#T@4$5!4E],3T=?
M3D]424-%.PH@("`@("`@(&)R96%K.PH@("`@8V%S92!%7T524D]2.@H@("`@
M8V%S92!%7U5315)?15)23U(Z"B`@("`@("`@)'!R:6]R:71Y(#T@4$5!4E],
M3T=?15)2.PH@("`@("`@(&)R96%K.PH@("`@9&5F875L=#H*("`@("`@("`D
M<')I;W1I='D@/2!014%27TQ/1U])3D9/.PH@("`@?0H*("`@("1L;V=G97(M
M/FQO9R@D;65S<V%G92`N("<@:6X@)R`N("1F:6QE("X@)R!A="!L:6YE("<@
M+B`D;&EN92P*("`@("`@("`@("`@("`@("`D<')I;W)I='DI.PI]"@HD;&]G
M9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=C;VYS;VQE)RP@)R<L("=I9&5N="<I
M.PH*<V5T7V5R<F]R7VAA;F1L97(H)V5R<F]R2&%N9&QE<B<I.PIT<FEG9V5R
M7V5R<F]R*"=4:&ES(&ES(&%N(&EN9F]R;6%T:6]N(&QO9R!M97-S86=E+B<L
M($5?55-%4E].3U1)0T4I.PH`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O
M8W,O97AA;7!L97,O<W%L+G!H<```````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,S,T`#$P-3$U-#,S-S,U`#`R-#,S-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N
M<&AP)SL*"B1C;VYF(#T@87)R87DH)V1S;B<@/3X@)W!G<W%L.B\O:F]N0&QO
M8V%L:&]S="MU;FEX+VQO9W,G*3L*)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O
M;B@G<W%L)RP@)VQO9U]T86)L92<L("=I9&5N="<L("1C;VYF*3L*9F]R("@D
M:2`](#`[("1I(#P@,3`[("1I*RLI('L*("`@("1L;V=G97(M/FQO9R@B3&]G
M(&5N=')Y("1I(BD["GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S+V5X86UP;&5S
M+W-Q;&ET92YP:'``````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<U,0`Q,#4Q-30S
M,S<S-0`P,C4P-#$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"G)E<75I<F5?;VYC92`G3&]G+G!H<"<["@HO*B!#
M<F5A=&EN9R!A(&YE=R!D871A8F%S92!C;VYN96-T:6]N+B`J+PHD8V]N9B`]
M(&%R<F%Y*"=F:6QE;F%M92<@/3X@)VQO9RYD8B<L("=M;V1E)R`]/B`P-C8V
M+"`G<&5R<VES=&5N="<@/3X@=')U92D["B1L;V=G97(@/28@3&]G.CIF86-T
M;W)Y*"=S<6QI=&4G+"`G;&]G7W1A8FQE)RP@)VED96YT)RP@)&-O;F8I.PHD
M;&]G9V5R+3YL;V<H)VQO9V=I;F<@86X@979E;G0G+"!014%27TQ/1U]705).
M24Y'*3L*"B\J(%5S:6YG(&%N(&5X:7-T:6YG(&1A=&%B87-E(&-O;FYE8W1I
M;VXN("HO"B1D8B`]('-Q;&ET95]O<&5N*"=L;V<N9&(G+"`P-C8V+"`D97)R
M;W(I.PHD;&]G9V5R(#TF($QO9SHZ9F%C=&]R>2@G<W%L:71E)RP@)VQO9U]T
M86)L92<L("=I9&5N="<L("1D8BD["B1L;V=G97(M/FQO9R@G;&]G9VEN9R!A
M;B!E=F5N="<L(%!%05)?3$]'7U=!4DY)3D<I.PIS<6QI=&5?8VQO<V4H)&1B
M*3L*```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O9&]C<R],;V<O9&]C<R]E>&%M<&QE<R]S>7-L;V<N<&AP
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R,S0`,3`U,34T,S,W,S4`,#(U,#4T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@IR97%U:7)E7V]N8V4@)TQO9RYP:'`G.PH*)&QO9V=E<B`]("9,;V<Z
M.G-I;F=L971O;B@G<WES;&]G)RP@3$]'7TQ/0T%,,"P@)VED96YT)RD["F9O
M<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2!["B`@("`D;&]G9V5R+3YL;V<H
M(DQO9R!E;G1R>2`D:2(I.PI]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+V1O8W,O3&]G+V1O8W,O97AA;7!L97,O=VEN+G!H<```````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,S(P`#$P-3$U-#,S-S,U`#`R-#,R-0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`H*<F5Q=6ER
M95]O;F-E("=,;V<N<&AP)SL*"B1C;VYF(#T@87)R87DH)W1I=&QE)R`]/B`G
M4V%M<&QE($QO9R!/=71P=70G*3L*)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O
M;B@G=VEN)RP@)TQO9U=I;F1O=R<L("=I9&5N="<L("1C;VYF*3L*9F]R("@D
M:2`](#`[("1I(#P@,3`[("1I*RLI('L*("`@("1L;V=G97(M/FQO9R@B3&]G
M(&5N=')Y("1I(BD["GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D
M;V-S+V=U:61E+G1X=```````````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$R
M-#4P,``Q,#4Q-30S,S<S-0`P,C,P-#8`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/3T]/3T]/3T]/3T]/3T]/3T*(%1H92!,
M;V<@4&%C:V%G90H]/3T]/3T]/3T]/3T]/3T]/0H*+2TM+2TM+2TM+2TM+2TM
M+2TM+2T*(%5S97(@1&]C=6UE;G1A=&EO;@HM+2TM+2TM+2TM+2TM+2TM+2TM
M+0H*.D%U=&AO<CH@("`@("`@($IO;B!087)I<V4*.D-O;G1A8W0Z("`@("`@
M(&IO;D!P:'`N;F5T"CI$871E.B`@("`@("`@("`D1&%T93H@,C`P-B\P-"\R
M,2`P-3HR-3HP.2`D"CI2979I<VEO;CH@("`@("`D4F5V:7-I;VXZ(#$N,C4@
M)`H*+BX@8V]N=&5N=',Z.B!#;VYT96YT<PHN+B!S96-T:6]N+6YU;6)E<FEN
M9SHZ"@I5<VEN9R!,;V<@2&%N9&QE<G,*/3T]/3T]/3T]/3T]/3T]/3T]"@I4
M:&4@3&]G('!A8VMA9V4@:7,@:6UP;&5M96YT960@87,@82!F<F%M97=O<FL@
M=&AA="!S=7!P;W)T<R!T:&4@;F]T:6]N(&]F"F)A8VME;F0M<W!E8VEF:6,@
M;&]G(&AA;F1L97)S+B`@5&AE(&)A<V4@;&]G9VEN9R!O8FIE8W0@*&1E9FEN
M960@8GD@=&AE(&!,;V<*8VQA<W-@7RD@:7,@<')I;6%R:6QY(&%N(&%B<W1R
M86-T(&EN=&5R9F%C92!T;R!T:&4@8W5R<F5N=&QY(&-O;F9I9W5R960*:&%N
M9&QE<BX*"D$@=VED92!V87)I971Y(&]F(&AA;F1L97)S(&%R92!D:7-T<FEB
M=71E9"!W:71H('1H92!,;V<@<&%C:V%G92P@86YD+"!S:&]U;&0*;F]N92!O
M9B!T:&5M(&9I="!Y;W5R(&%P<&QI8V%T:6]N)W,@;F5E9',L(&ET)W,@96%S
M>2!T;R!@=W)I=&4@>6]U<B!O=VY@7U\N"@HN+B!?3&]G(&-L87-S.B!H='1P
M.B\O8W9S+G!H<"YN970O8V\N<&AP+W!E87(O3&]G+TQO9RYP:'`*7U\@8$-U
M<W1O;2!(86YD;&5R<V!?"@I#<F5A=&EN9R!A($QO9R!/8FIE8W0*+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM"E1H97)E(&%R92!T:')E92!W87ES('1O(&-R96%T
M92!,;V<@;V)J96-T<SH*"B`@("`M(%5S:6YG('1H92!@8$QO9SHZ9F%C=&]R
M>2@I8&`@;65T:&]D"B`@("`M(%5S:6YG('1H92!@8$QO9SHZ<VEN9VQE=&]N
M*"E@8"!M971H;V0*("`@("T@1&ER96-T(&EN<W1A;G1I871I;VX*"E1H92!&
M86-T;W)Y($UE=&AO9`I^?GY^?GY^?GY^?GY^?GY^?GX*5&AE(&!@3&]G.CIF
M86-T;W)Y*"E@8"!M971H;V0@:6UP;&5M96YT<R!T:&4@8$9A8W1O<GD@4&%T
M=&5R;F!?+B`@270@86QL;W=S"F9O<B!T:&4@<&%R86UE=&5R:7IE9"!C;VYS
M=')U8W1I;VX@;V8@8V]N8W)E=&4@3&]G(&EN<W1A;F-E<R!A="!R=6YT:6UE
M+B`@5&AE"F9I<G-T('!A<F%M971E<B!T;R!T:&4@8&!,;V<Z.F9A8W1O<GDH
M*6!@(&UE=&AO9"!I;F1I8V%T97,@=&AE(&YA;64@;V8@=&AE"F-O;F-R971E
M(&AA;F1L97(@=&\@8W)E871E+B`@5&AE(')E<W0@;V8@=&AE('!A<F%M971E
M<G,@=VEL;"!B92!P87-S960@;VX@=&\*=&AE(&AA;F1L97(G<R!C;VYS=')U
M8W1O<B`H<V5E(&!#;VYF:6=U<FEN9R!A($AA;F1L97)@7R!B96QO=RDN"@I4
M:&4@;F5W(&!@3&]G8&`@:6YS=&%N8V4@:7,@<F5T=7)N960@8GD@<F5F97)E
M;F-E+@H*.CH*"B`@("!R97%U:7)E7V]N8V4@)TQO9RYP:'`G.PH*("`@("1C
M;VYS;VQE(#T@)DQO9SHZ9F%C=&]R>2@G8V]N<V]L92<L("<G+"`G5$535"<I
M.PH@("`@)&-O;G-O;&4M/FQO9R@G3&]G9VEN9R!T;R!T:&4@8V]N<V]L92XG
M*3L*"B`@("`D9FEL92`]("9,;V<Z.F9A8W1O<GDH)V9I;&4G+"`G;W5T+FQO
M9R<L("=415-4)RD["B`@("`D9FEL92T^;&]G*"=,;V=G:6YG('1O(&]U="YL
M;V<N)RD["@HN+B!?1F%C=&]R>2!0871T97)N.B!H='1P.B\O=W=W+G!H<'!A
M='1E<FYS+F-O;2]I;F1E>"YP:'`O87)T:6-L92]A<G1I8VQE=FEE=R\T.2\Q
M+S$O"@I4:&4@4VEN9VQE=&]N($UE=&AO9`I^?GY^?GY^?GY^?GY^?GY^?GY^
M?@I4:&4@8&!,;V<Z.G-I;F=L971O;B@I8&`@;65T:&]D(&EM<&QE;65N=',@
M=&AE(&!3:6YG;&5T;VX@4&%T=&5R;F!?+B`@5&AE"G-I;F=L971O;B!P871T
M97)N(&5N<W5R97,@=&AA="!O;FQY(&$@<VEN9VQE(&EN<W1A;F-E(&]F(&$@
M9VEV96X@;&]G('1Y<&4@86YD"F-O;F9I9W5R871I;VX@:7,@979E<B!C<F5A
M=&5D+B`@5&AI<R!H87,@='=O(&)E;F5F:71S.B!F:7)S="P@:70@<')E=F5N
M=',*9'5P;&EC871E(&!@3&]G8&`@:6YS=&%N8V5S(&9R;VT@8F5I;F<@8V]N
M<W1R=6-T960L(&%N9"P@<V5C;VYD+"!I="!G:79E<R!A;&P*;V8@>6]U<B!C
M;V1E(&%C8V5S<R!T;R!T:&4@<V%M92!@8$QO9V!@(&EN<W1A;F-E+B`@5&AE
M(&QA='1E<B!I<R!E<W!E8VEA;&QY"FEM<&]R=&%N="!W:&5N(&QO9V=I;F<@
M=&\@9FEL97,@8F5C875S92!O;FQY(&$@<VEN9VQE(&9I;&4@:&%N9&QE<B!W
M:6QL(&YE960*=&\@8F4@;6%N86=E9"X*"E1H92!@8$QO9SHZ<VEN9VQE=&]N
M*"E@8"!M971H;V0G<R!P87)A;65T97)S(&UA=&-H('1H92!@8$QO9SHZ9F%C
M=&]R>2@I8&`*;65T:&]D+B`@5&AE(&YE=R!@8$QO9V!@(&EN<W1A;F-E(&ES
M(')E='5R;F5D(&)Y(')E9F5R96YC92X*"CHZ"@H@("`@<F5Q=6ER95]O;F-E
M("=,;V<N<&AP)SL*"B`@("`O*B!386UE(&-O;G-T<G5C=&EO;B!P87)A;65T
M97)S("HO"B`@("`D82`]("9,;V<Z.G-I;F=L971O;B@G8V]N<V]L92<L("<G
M+"`G5$535"<I.PH@("`@)&(@/2`F3&]G.CIS:6YG;&5T;VXH)V-O;G-O;&4G
M+"`G)RP@)U1%4U0G*3L*"B`@("!I9B`H)&$@/3T]("1B*2!["B`@("`@("`@
M96-H;R`G)&$@86YD("1B('!O:6YT('1O('1H92!S86UE($QO9R!I;G-T86YC
M92XG("X@(EQN(CL*("`@('T*"B`@("`O*B!$:69F97)E;G0@8V]N<W1R=6-T
M:6]N('!A<F%M971E<G,@*B\*("`@("1C(#T@)DQO9SHZ<VEN9VQE=&]N*"=C
M;VYS;VQE)RP@)R<L("=415-4,2<I.PH@("`@)&0@/2`F3&]G.CIS:6YG;&5T
M;VXH)V-O;G-O;&4G+"`G)RP@)U1%4U0R)RD["@H@("`@:68@*"1C("$]/2`D
M9"D@>PH@("`@("`@(&5C:&\@)R1C(&%N9"`D9"!P;VEN="!T;R!D:69F97)E
M;G0@3&]G(&EN<W1A;F-E<RXG("X@(EQN(CL*("`@('T*"BXN(%]3:6YG;&5T
M;VX@4&%T=&5R;CH@:'1T<#HO+W=W=RYP:'!P871T97)N<RYC;VTO:6YD97@N
M<&AP+V%R=&EC;&4O87)T:6-L979I97<O-B\Q+S$O"@I$:7)E8W0@26YS=&%N
M=&EA=&EO;@I^?GY^?GY^?GY^?GY^?GY^?GY^?@I)="!I<R!A;'-O('!O<W-I
M8FQE('1O(&1I<F5C=&QY(&EN<W1A;G1I871E(&-O;F-R971E(&!@3&]G8&`@
M:&%N9&QE<@II;G-T86YC97,N("!(;W=E=F5R+"!T:&ES(&UE=&AO9"!I<R`J
M*FYO="!R96-O;6UE;F1E9"HJ(&)E8V%U<V4@:70@8W)E871E<R!A"G1I9VAT
M97(@8V]U<&QI;F<@8F5T=V5E;B!Y;W5R(&%P<&QI8V%T:6]N(&-O9&4@86YD
M('1H92!,;V<@<&%C:V%G92!T:&%N(&ES"FYE8V5S<V%R>2X@(%5S92!O9B!@
M=&AE(&9A8W1O<GD@;65T:&]D8%\@;W(@8'1H92!S:6YG;&5T;VX@;65T:&]D
M8%\@:7,*<')E9F5R<F5D+@H*"D-O;F9I9W5R:6YG(&$@2&%N9&QE<@HM+2TM
M+2TM+2TM+2TM+2TM+2TM+2T*02!L;V<@:&%N9&QE<B=S(&-O;F9I9W5R871I
M;VX@:7,@9&5T97)M:6YE9"!B>2!T:&4@87)G=6UE;G1S('5S960@:6X@:71S
M"F-O;G-T<G5C=&EO;BX@($AE<F4G<R!A;B!O=F5R=FEE=R!O9B!T:&]S92!P
M87)A;65T97)S.CH*"B`@("`O*B!5<VEN9R!T:&4@9F%C=&]R>2!M971H;V0@
M+BXN("HO"B`@("`F3&]G.CIF86-T;W)Y*"1H86YD;&5R+"`D;F%M92P@)&ED
M96YT+"`D8V]N9BP@)&UA>$QE=F5L*3L*"B`@("`O*B!5<VEN9R!T:&4@<VEN
M9VQE=&]N(&UE=&AO9"`N+BX@*B\*("`@("9,;V<Z.G-I;F=L971O;B@D:&%N
M9&QE<BP@)&YA;64L("1I9&5N="P@)&-O;F8L("1M87A,979E;"D["@H@("`@
M+RH@57-I;F<@9&ER96-T(&EN<W1A;G1I871I;VX@+BXN("HO"B`@("!N97<@
M3&]G7VAA;F1L97(H)&YA;64L("1I9&5N="P@)&-O;F8L("1M87A,979E;"D[
M"@HK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(%!A<F%M971E
M<B`@("`@?"!4>7!E("`@("`@?"!$97-C<FEP=&EO;B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HK/3T]/3T]/3T]/3T]/3T]*ST]/3T]
M/3T]/3T]*ST]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]*PI\(&!@)&AA;F1L97)@8"`@?"!3=')I;F<@("`@?"!4:&4@
M='EP92!O9B!,;V<@:&%N9&QE<B!T;R!C;VYS=')U8W0N("!4:&ES("`@?`I\
M("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"!P87)A;65T97(@:7,@;VYL
M>2!A=F%I;&%B;&4@=VAE;B!@=&AE(&9A8W1O<GD@?`I\("`@("`@("`@("`@
M("`@?"`@("`@("`@("`@?"!M971H;V1@7R!O<B!@=&AE('-I;F=L971O;B!M
M971H;V1@7R!A<F4@=7-E9"X@?`HK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM
M+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PI\(&!@)&YA;65@8"`@("`@?"!3=')I;F<@("`@?"!4:&4@;F%M
M92!O9B!T:&4@;&]G(')E<V]U<F-E('1O('=H:6-H('1H92`@("`@?`I\("`@
M("`@("`@("`@("`@?"`@("`@("`@("`@?"!E=F5N=',@=VEL;"!B92!L;V=G
M960N("!4:&4@=7-E(&]F('1H:7,@=F%L=64@?`I\("`@("`@("`@("`@("`@
M?"`@("`@("`@("`@?"!I<R!D971E<FUI;F5D(&)Y('1H92!H86YD;&5R)W,@
M:6UP;&5M96YT871I;VXN?`I\("`@("`@("`@("`@("`@?"`@("`@("`@("`@
M?"!)="!D969A=6QT<R!T;R!A;B!E;7!T>2!S=')I;F<N("`@("`@("`@("`@
M("`@?`HK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@)&ED
M96YT8&`@("`@?"!3=')I;F<@("`@?"!!;B!I9&5N=&EF:6-A=&EO;B!S=')I
M;F<@=&AA="!W:6QL(&)E(&EN8VQU9&5D?`I\("`@("`@("`@("`@("`@?"`@
M("`@("`@("`@?"!I;B!A;&P@;&]G(&5V96YT<R!L;V=G960@8GD@=&AI<R!H
M86YD;&5R+B`@("`@?`I\("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"!4
M:&ES('9A;'5E(&1E9F%U;'1S('1O(&%N(&5M<'1Y('-T<FEN9R!A;F0@8V%N
M?`I\("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"!B92!C:&%N9V5D(&%T
M(')U;G1I;64@=7-I;F<@=&AE(&!@<V5T261E;G0H*6!@?`I\("`@("`@("`@
M("`@("`@?"`@("`@("`@("`@?"!M971H;V0N("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PI\(&!@)&-O;F9@8"`@("`@?"!!<G)A>2`@("`@?"!!<W-O
M8VEA=&EV92!A<G)A>2!O9B!K97DM=F%L=64@<&%I<G,@=&AA="!A<F4@?`I\
M("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"!U<V5D('1O('-P96-I9GD@
M86YY(&AA;F1L97(M<W!E8VEF:6,@<V5T=&EN9W,N?`HK+2TM+2TM+2TM+2TM
M+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@)&QE=F5L8&`@("`@?"!);G1E9V5R
M("`@?"!,;V<@;65S<V%G97,@=7`@=&\@86YD(&EN8VQU9&EN9R!T:&ES(&QE
M=F5L+B`@?`I\("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"!4:&ES('9A
M;'5E(&1E9F%U;'1S('1O(&!@4$5!4E],3T=?1$5"54=@8"X@("`@?`I\("`@
M("`@("`@("`@("`@?"`@("`@("`@("`@?"!3964@8$QO9R!,979E;'-@7R!A
M;F0@8$QO9R!,979E;"!-87-K<V!?+B`@("`@?`HK+2TM+2TM+2TM+2TM+2TM
M*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PH*"DQO9V=I;F<@86X@179E;G0*+2TM+2TM+2TM
M+2TM+2TM+0I%=F5N=',@87)E(&QO9V=E9"!U<VEN9R!T:&4@8&!L;V<H*6!@
M(&UE=&AO9#HZ"@H@("`@)&QO9V=E<BT^;&]G*"=-97-S86=E)RP@4$5!4E],
M3T=?3D]424-%*3L*"E1H92!F:7)S="!A<F=U;65N="!C;VYT86EN<R!T:&4@
M;&]G(&5V96YT)W,@;65S<V%G92X@($5V96X@=&AO=6=H('1H92!E=F5N="!I
M<PIA;'=A>7,@;&]G9V5D(&%S(&$@<W1R:6YG+"!I="!I<R!P;W-S:6)L92!T
M;R!P87-S(&%N(&]B:F5C="!T;R!T:&4@8&!L;V<H*6!@"FUE=&AO9"X@($EF
M('1H92!O8FIE8W0@:6UP;&5M96YT<R!A(&!@9V5T4W1R:6YG*"E@8"!M971H
M;V0L(&$@8&!T;U-T<FEN9R@I8&`*;65T:&]D(&]R(%IE;F0@16YG:6YE(#(G
M<R!S<&5C:6%L(&!@7U]T;U-T<FEN9R@I8&`@8V%S=&EN9R!M971H;V0L(&ET
M('=I;&P@8F4*=7-E9"!T;R!D971E<FUI;F4@=&AE(&]B:F5C="=S('-T<FEN
M9R!R97!R97-E;G1A=&EO;BX@($]T:&5R=VES92P@=&AE"F!S97)I86QI>F5D
M8%\@9F]R;2!O9B!T:&4@;V)J96-T('=I;&P@8F4@;&]G9V5D+@H*5&AE('-E
M8V]N9"P@;W!T:6]N86P@87)G=6UE;G0@<W!E8VEF:65S('1H92!L;V<@979E
M;G0G<R!P<FEO<FET>2X@(%-E92!T:&4*8$QO9R!,979E;'-@7R!T86)L92!F
M;W(@=&AE(&-O;7!L971E(&QI<W0@;V8@<')I;W)I=&EE<RX@(%1H92!D969A
M=6QT('!R:6]R:71Y"FES(%!%05)?3$]'7TE.1D\N"@I4:&4@8&!L;V<H*6!@
M(&UE=&AO9"!W:6QL(')E='5R;B!@8'1R=65@8"!I9B!T:&4@979E;G0@=V%S
M('-U8V-E<W-F=6QL>0IL;V=G960N"@HB4VAO<G1C=70B(&UE=&AO9',@87)E
M(&%L<V\@879A:6QA8FQE(&9O<B!L;V=G:6YG(&%N(&5V96YT(&%T(&$@<W!E
M8VEF:6,@;&]G"FQE=F5L+B`@4V5E('1H92!@3&]G($QE=F5L<V!?('1A8FQE
M(&9O<B!T:&4@8V]M<&QE=&4@;&ES="X*"BXN(%]S97)I86QI>F5D.B!H='1P
M.B\O=W=W+G!H<"YN970O<V5R:6%L:7IE"@H*3&]G($QE=F5L<PHM+2TM+2TM
M+2TM"E1H:7,@=&%B;&4@:7,@;W)D97)E9"!B>2!H:6=H97-T('!R:6]R:71Y
M("A@8%!%05)?3$]'7T5-15)'8&`I('1O(&QO=V5S=`IP<FEO<FET>2`H8&!0
M14%27TQ/1U]$14)51V!@*2X*"BLM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2LM
M+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"GP@3&5V96P@("`@("`@("`@("`@("`@('P@4VAO<G1C=70@("`@
M("!\($1E<V-R:7!T:6]N("`@("`@("`@("`@("`@("`@("`@("!\"BL]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/3T]/3TK/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3TK"GP@8&!014%27TQ/1U]%3452
M1V!@("`@('P@8&!E;65R9R@I8&`@("!\(%-Y<W1E;2!I<R!U;G5S86)L92`@
M("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"GP@8&!014%27TQ/1U]!3$525&!@("`@('P@8&!A;&5R="@I8&`@("!\
M($EM;65D:6%T92!A8W1I;VX@<F5Q=6ER960@("`@("`@("!\"BLM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!014%27TQ/1U]#4DE48&`@
M("`@('P@8&!C<FET*"E@8"`@("!\($-R:71I8V%L(&-O;F1I=&EO;G,@("`@
M("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM
M+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"GP@8&!014%27TQ/1U]%4E)@8"`@("`@('P@8&!E<G(H*6!@("`@("!\($5R
M<F]R(&-O;F1I=&EO;G,@("`@("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!014%27TQ/1U]705).24Y'8&`@
M('P@8&!W87)N:6YG*"E@8"!\(%=A<FYI;F<@8V]N9&ET:6]N<R`@("`@("`@
M("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM
M+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@
M8&!014%27TQ/1U].3U1)0T5@8"`@('P@8&!N;W1I8V4H*6!@("!\($YO<FUA
M;"!B=70@<VEG;FEF:6-A;G0@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!014%27TQ/1U])3D9/8&`@("`@('P@
M8&!I;F9O*"E@8"`@("!\($EN9F]R;6%T:6]N86P@("`@("`@("`@("`@("`@
M("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM
M+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!0
M14%27TQ/1U]$14)51V!@("`@('P@8&!D96)U9R@I8&`@("!\($1E8G5G+6QE
M=F5L(&UE<W-A9V5S("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"@H*3&]G($QE=F5L($UA<VMS"BTM+2TM+2TM+2TM
M+2TM+0I$969I;FEN9R!A(&QO9R!L979E;"!M87-K(&%L;&]W<R!Y;W4@=&\@
M:6YC;'5D92!A;F0O;W(@97AC;'5D92!S<&5C:69I8R!L979E;',*;V8@979E
M;G1S(&9R;VT@8F5I;F<@;&]G9V5D+B`@5&AE(&!@)&QE=F5L8&`@8V]N<W1R
M=6-T:6]N('!A<F%M971E<B`H<V5E"F!#;VYF:6=U<FEN9R!A($AA;F1L97)@
M7RD@=7-E<R!T:&ES(&UE8VAA;FES;2!T;R!E>&-L=61E(&QO9R!E=F5N=',@
M8F5L;W<@80IC97)T86EN('!R:6]R:71Y+"!A;F0@:70G<R!P;W-S:6)L92!T
M;R!D969I;F4@;6]R92!C;VUP;&5X(&UA<VMS(&]N8V4@=&AE($QO9PIO8FIE
M8W0@:&%S(&)E96X@8V]N<W1R=6-T960N"@I%86-H('!R:6]R:71Y(&AA<R!A
M('-P96-I9FEC(&UA<VL@87-S;V-I871E9"!W:71H(&ET+B`@5&\@8V]M<'5T
M92!A('!R:6]R:71Y)W,*;6%S:RP@=7-E('1H92!S=&%T:6,@8&!,;V<Z.DU!
M4TLH*6!@(&UE=&AO9#HZ"@H@("`@)&UA<VL@/2!,;V<Z.DU!4TLH4$5!4E],
M3T=?24Y&3RD["@I4;R!C;VUP=71E('1H92!M87-K(&9O<B!A;&P@<')I;W)I
M=&EE<R!U<"!T;RP@86YD(&EN8VQU9&EN9RP@82!C97)T86EN(&QE=F5L+`IU
M<V4@=&AE(&!@3&]G.CI-05@H*6!@('-T871I8R!M971H;V0Z.@H*("`@("1M
M87-K(#T@3&]G.CI-05@H4$5!4E],3T=?24Y&3RD["@I4;R!C;VUP=71E('1H
M92!M87-K(&9O<B!A;&P@<')I;W)I=&EE<R!G<F5A=&5R('1H86X@;W(@97%U
M86P@=&\@82!C97)T86EN"FQE=F5L+"!U<V4@=&AE(&!@3&]G.CI-24XH*6!@
M('-T871I8R!M971H;V0Z.@H*("`@("1M87-K(#T@3&]G.CI-24XH4$5!4E],
M3T=?24Y&3RD["@I4:&4@87!P;'D@=&AE(&UA<VLL('5S92!T:&4@8&!S971-
M87-K*"E@8"!M971H;V0Z.@H*("`@("1L;V=G97(M/G-E=$UA<VLH)&UA<VLI
M.PH*36%S:W,@8V%N(&)E(&)E(&-O;6)I;F5D('5S:6YG(&)I='=I<V4@;W!E
M<F%T:6]N<RX@(%1O(')E<W1R:6-T(&QO9V=I;F<@=&\*;VYL>2!T:&]S92!E
M=F5N=',@;6%R:V5D(&%S(&!@4$5!4E],3T=?3D]424-%8&`@;W(@8&!014%2
M7TQ/1U]$14)51V!@.CH*"B`@("`D;6%S:R`]($QO9SHZ34%32RA014%27TQ/
M1U].3U1)0T4I('P@3&]G.CI-05-+*%!%05)?3$]'7T1%0E5'*3L*("`@("1L
M;V=G97(M/G-E=$UA<VLH)&UA<VLI.PH*1F]R(&-O;G9E;FEE;F-E+"!T=V\@
M<W!E8VEA;"!M87-K<R!A<F4@<')E9&5F:6YE9#H@8&!014%27TQ/1U].3TY%
M8&`@86YD"F!@4$5!4E],3T=?04Q,8&`N("!@8%!%05)?3$]'7T%,3&!@(&ES
M(&5S<&5C:6%L;'D@=7-E9G5L(&9O<B!E>&QU9&EN9R!O;FQY"G-P96-I9FEC
M('!R:6]R:71I97,Z.@H*("`@("1M87-K(#T@4$5!4E],3T=?04Q,(%X@3&]G
M.CI-05-+*%!%05)?3$]'7TY/5$E#12D["B`@("`D;&]G9V5R+3YS971-87-K
M*"1M87-K*3L*"DET(&ES(&%L<V\@<&]S<VEB;&4@=&\@<F5T<FEE=F4@86YD
M(&UO9&EF>2!A($QO9R!O8FIE8W0G<R!E>&ES=&EN9R!M87-K.CH*"B`@("`D
M;6%S:R`]("1L;V=G97(M/F=E=$UA<VLH*2!\($QO9SHZ34%32RA014%27TQ/
M1U])3D9/*3L*("`@("1L;V=G97(M/G-E=$UA<VLH)&UA<VLI.PH*"D9L=7-H
M:6YG($QO9R!%=F5N=',*+2TM+2TM+2TM+2TM+2TM+2TM+0I3;VUE(&QO9R!H
M86YD;&5R<R`H<W5C:"!A<R!@=&AE(&-O;G-O;&4@:&%N9&QE<F!?*2!S=7!P
M;W)T(&5X<&QI8VET"B)B=69F97)I;F<B+B`@5VAE;B!B=69F97)I;F<@:7,@
M96YA8FQE9"P@;&]G(&5V96YT<R!W;VXG="!A8W1U86QL>2!B92!W<FET=&5N
M"G1O('1H92!O=71P=70@<W1R96%M('5N=&EL('1H92!H86YD;&5R(&ES(&-L
M;W-E9"X@($]T:&5R(&AA;F1L97)S("AS=6-H(&%S"F!T:&4@9FEL92!H86YD
M;&5R8%\I('-U<'!O<G0@:6UP;&EC:70@8G5F9F5R:6YG(&)E8V%U<V4@=&AE
M>2!U<V4@=&AE(&]P97)A=&EN9PIS>7-T96TG<R!)3R!R;W5T:6YE<RP@=VAI
M8V@@;6%Y(&)U9F9E<B!T:&4@;W5T<'5T+@H*270G<R!P;W-S:6)L92!T;R!F
M;W)C92!T:&5S92!H86YD;&5R<R!T;R!F;'5S:"!T:&5I<B!O=71P=70L(&AO
M=V5V97(L(&)Y"F-A;&QI;F<@=&AE:7(@8&!F;'5S:"@I8&`@;65T:&]D.CH*
M"B`@("`D8V]N9B`](&%R<F%Y*"=B=69F97)I;F<G(#T^('1R=64I.PH@("`@
M)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G8V]N<V]L92<L("<G+"`G=&5S
M="<L("1C;VYF*3L*"B`@("!F;W(@*"1I(#T@,#L@)&D@/"`Q,#L@)&DK*RD@
M>PH@("`@("`@("1L;V=G97(M/FQO9R@G5&AI<R!E=F5N="!W:6QL(&)E(&)U
M9F9E<F5D+B<I.PH@("`@?0H*("`@("\J($9L=7-H(&%L;"!O9B!T:&4@8G5F
M9F5R960@;&]G(&5V96YT<RX@*B\*("`@("1L;V=G97(M/F9L=7-H*"D["@H@
M("`@9F]R("@D:2`](#`[("1I(#P@,3`[("1I*RLI('L*("`@("`@("`D;&]G
M9V5R+3YL;V<H)U1H:7,@979E;G0@=VEL;"!B92!B=69F97)E9"XG*3L*("`@
M('T*"B`@("`O*B!);7!L:6-I=&QY(&9L=7-H('1H92!B=69F97)E9"!E=F5N
M=',@;VX@8VQO<V4N("HO"B`@("`D;&]G9V5R+3YC;&]S92@I.PH*070@=&AI
M<R!T:6UE+"!T:&4@8&!F;'5S:"@I8&`@;65T:&]D(&ES(&]N;'D@:6UP;&5M
M96YT960@8GD@8'1H92!C;VYS;VQE"FAA;F1L97)@7RP@8'1H92!F:6QE(&AA
M;F1L97)@7R!A;F0@8'1H92!M86EL(&AA;F1L97)@7RX*"@I3=&%N9&%R9"!,
M;V<@2&%N9&QE<G,*/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@I4:&4@0V]N<V]L
M92!(86YD;&5R"BTM+2TM+2TM+2TM+2TM+2TM+2T*5&AE($-O;G-O;&4@:&%N
M9&QE<B!O=71P=71S(&QO9R!E=F5N=',@9&ER96-T;'D@=&\@=&AE(&-O;G-O
M;&4N("!)="!S=7!P;W)T<PIO=71P=70@8G5F9F5R:6YG(&%N9"!C;VYF:6=U
M<F%B;&4@<W1R:6YG(&9O<FUA=',N"@I#;VYF:6=U<F%T:6]N"GY^?GY^?GY^
M?GY^?GX**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM
M+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!087)A
M;65T97(@("`@("`@("!\(%1Y<&4@("`@("!\($1E9F%U;'0@("`@("`@?"!$
M97-C<FEP=&EO;B`@("`@("`@("`@("`@('P**ST]/3T]/3T]/3T]/3T]/3T]
M/3TK/3T]/3T]/3T]/3TK/3T]/3T]/3T]/3T]/3T]*ST]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/2L*?"!@8'-T<F5A;6!@("`@("`@("!\($9I;&4@("`@
M("!\(%-41$]55%\@("`@("`@?"!4:&4@;W5T<'5T('-T<F5A;2!T;R!U<V4N
M('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM
M+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8&)U9F9E
M<FEN9V!@("`@("!\($)O;VQE86X@("!\($9A;'-E("`@("`@("`@?"!3:&]U
M;&0@=&AE(&]U='!U="!B92`@("`@('P*?"`@("`@("`@("`@("`@("`@("!\
M("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!B=69F97)E9"!U;G1I;"!S
M:'5T9&]W;C\@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M?"!@8&QI;F5&;W)M871@8"`@("!\(%-T<FEN9R`@("!\(&!@)3$D<R`E,B1S
M("`@?"!,;V<@;&EN92!F;W)M870@("`@("`@("`@('P*?"`@("`@("`@("`@
M("`@("`@("!\("`@("`@("`@("!\(%LE,R1S72`E-"1S8&`@?"!S<&5C:69I
M8V%T:6]N+B`@("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM
M+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*?"!@8'1I;65&;W)M871@8"`@("!\(%-T<FEN9R`@("!\(&!@
M)6(@)60@("`@("`@?"!4:6UE('-T86UP(&9O<FUA="`@("`@("`@('P*?"`@
M("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("5(.B5-.B538&`@("`@
M?"`H9F]R('-T<F9T:6UE7RDN("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM
M+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*"BXN(%]35$1/550Z(&AT='`Z+R]W=W<N<&AP
M+FYE="]W<F%P<&5R<RYP:'`*+BX@7W-T<F9T:6UE.B!H='1P.B\O=W=W+G!H
M<"YN970O<W1R9G1I;64*"D5X86UP;&4*?GY^?GY^?@HZ.@H*("`@("1L;V=G
M97(@/2`F3&]G.CIS:6YG;&5T;VXH)V-O;G-O;&4G+"`G)RP@)VED96YT)RD[
M"B`@("!F;W(@*"1I(#T@,#L@)&D@/"`Q,#L@)&DK*RD@>PH@("`@("`@("1L
M;V=G97(M/FQO9R@B3&]G(&5N=')Y("1I(BD["B`@("!]"@H*5&AE($1I<W!L
M87D@2&%N9&QE<@HM+2TM+2TM+2TM+2TM+2TM+2TM"E1H92!$:7-P;&%Y(&AA
M;F1L97(@<VEM<&QY('!R:6YT<R!T:&4@;&]G(&5V96YT<R!B86-K('1O('1H
M92!B<F]W<V5R+B`@270*<F5S<&5C=',@=&AE(&!@97)R;W)?<')E<&5N9%]S
M=')I;F=@8"!A;F0@8&!E<G)O<E]A<'!E;F1?<W1R:6YG8&`@8&5R<F]R"FAA
M;F1L:6YG('9A;'5E<V!?(&%N9"!I<R!U<V5F=6P@=VAE;B!@;&]G9VEN9R!F
M<F]M('-T86YD87)D(&5R<F]R(&AA;F1L97)S8%\N"@I#;VYF:6=U<F%T:6]N
M"GY^?GY^?GY^?GY^?GX**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM
M+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*?"!087)A;65T97(@("`@("`@("!\(%1Y<&4@("`@("!\($1E9F%U;'0@
M("`@("`@?"!$97-C<FEP=&EO;B`@("`@("`@("`@("`@('P**ST]/3T]/3T]
M/3T]/3T]/3T]/3TK/3T]/3T]/3T]/3TK/3T]/3T]/3T]/3T]/3T]*ST]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/2L*?"!@8&5R<F]R7W!R97!E;F1@8"!\
M(%-T<FEN9R`@("!\(%!(4"!)3DD@=F%L=64@?"!4:&ES('-T<FEN9R!W:6QL
M(&)E("`@("`@('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\
M("`@("`@("`@("`@("`@?"!P<F5P96YD960@=&\@=&AE(&QO9R`@("`@('P*
M?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@
M("`@?"!O=71P=70N("`@("`@("`@("`@("`@("`@('P**RTM+2TM+2TM+2TM
M+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8&5R<F]R7V%P<&5N9&!@("!\(%-T
M<FEN9R`@("!\(%!(4"!)3DD@=F%L=64@?"!4:&ES('-T<FEN9R!W:6QL(&)E
M("`@("`@('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@
M("`@("`@("`@("`@?"!A<'!E;F1E9"!T;R!T:&4@;&]G("`@("`@('P*?"`@
M("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@
M?"!O=71P=70N("`@("`@("`@("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM
M+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*?"!@8&QI;F5B<F5A:V!@("`@("!\(%-T<FEN
M9R`@("!\(&!@/&)R("\^7&Y@8"`@?"!4:&ES('-T<FEN9R!I<R!U<V5D('1O
M("`@('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@
M("`@("`@("`@?"!R97!R97-E;G0@82!L:6YE(&)R96%K+B`@('P**RTM+2TM
M+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*"BXN(%]E<G)O<B!H86YD;&EN
M9R!V86QU97,Z(&AT='`Z+R]W=W<N<&AP+FYE="]E<G)O<F9U;F,*"D5X86UP
M;&4*?GY^?GY^?@HZ.@H*("`@("1C;VYF(#T@87)R87DH)V5R<F]R7W!R97!E
M;F0G(#T^("<\9F]N="!C;VQO<CTB(V9F,#`P,"(^/'1T/B<L"B`@("`@("`@
M("`@("`@("`@("=E<G)O<E]A<'!E;F0G("`]/B`G/"]T=#X\+V9O;G0^)RD[
M"B`@("`D;&]G9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=D:7-P;&%Y)RP@)R<L
M("<G+"`D8V]N9BP@4$5!4E],3T=?1$5"54<I.PH@("`@9F]R("@D:2`](#`[
M("1I(#P@,3`[("1I*RLI('L*("`@("`@("`D;&]G9V5R+3YL;V<H(DQO9R!E
M;G1R>2`D:2(I.PH@("`@?0H*"E1H92!%<G)O<E],;V<@2&%N9&QE<@HM+2TM
M+2TM+2TM+2TM+2TM+2TM+2T*5&AE($5R<F]R7TQO9R!H86YD;&5R('-E;F1S
M(&QO9R!E=F5N=',@=&\@4$A0)W,@8&5R<F]R7VQO9R@I8%\@9G5N8W1I;VXN
M"@I#;VYF:6=U<F%T:6]N"GY^?GY^?GY^?GY^?GX**RTM+2TM+2TM+2TM+2TM
M+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*?"!087)A;65T97(@("`@("`@("!\(%1Y<&4@
M("`@("!\($1E9F%U;'0@("`@("`@?"!$97-C<FEP=&EO;B`@("`@("`@("`@
M("`@('P**ST]/3T]/3T]/3T]/3T]/3T]/3TK/3T]/3T]/3T]/3TK/3T]/3T]
M/3T]/3T]/3T]*ST]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/2L*?"!@8&1E
M<W1I;F%T:6]N8&`@("!\(%-T<FEN9R`@("!\("<G(&`H96UP='DI8"`@?"!/
M<'1I;VYA;"!D97-T:6YA=&EO;B!V86QU97P*?"`@("`@("`@("`@("`@("`@
M("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!F;W(@8&5R<F]R7VQO
M9R@I8%\N("!3964@('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@
M("!\("`@("`@("`@("`@("`@?"!@17)R;W)?3&]G(%1Y<&5S8%\@9F]R("`@
M('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@
M("`@("`@?"!M;W)E(&1E=&%I;',N("`@("`@("`@("`@('P**RTM+2TM+2TM
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8&5X=')A7VAE861E<G-@8"!\
M(%-T<FEN9R`@("!\("<G(&`H96UP='DI8"`@?"!!9&1I=&EO;F%L(&AE861E
M<G,@=&\@<&%S<WP*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\
M("`@("`@("`@("`@("`@?"!T;R!T:&4@8&UA:6PH*6!?(&9U;F-T:6]N('P*
M?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@
M("`@?"!W:&5N('1H92`@("`@("`@("`@("`@("`@('P*?"`@("`@("`@("`@
M("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!@8%!%05)?
M3$]'7U194$5?34%)3&!@("`@('P*?"`@("`@("`@("`@("`@("`@("!\("`@
M("`@("`@("!\("`@("`@("`@("`@("`@?"!T>7!E(&ES('-P96-I9FEE9"X@
M("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM
M+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*"D5R
M<F]R7TQO9R!4>7!E<PI^?GY^?GY^?GY^?GY^?GX*06QL(&]F('1H92!A=F%I
M;&%B;&4@;&]G('1Y<&5S(&%R92!D971A:6QE9"!I;B!T:&4@8&5R<F]R7VQO
M9R@I8%\@<V5C=&EO;B!O9@IT:&4@4$A0(&UA;G5A;"X@($9O<B!Y;W5R(&-O
M;G9E;FEE;F-E+"!T:&4@3&]G('!A8VMA9V4@86QS;R!D969I;F5S('1H90IF
M;VQL;W=I;F<@8V]N<W1A;G1S('1H870@8V%N(&)E('5S960@9F]R('1H92!@
M8"1N86UE8&`@:&%N9&QE<B!C;VYS=')U8W1I;VX*<&%R86UE=&5R+@H**RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!#;VYS=&%N="`@("`@
M("`@("`@("`@("`@('P@1&5S8W)I<'1I;VX@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P**ST]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/2L]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/2L*?"!@8%!%05)?3$]'7U194$5?4UE35$5-8&`@('P@3&]G(&5V96YT
M<R!A<F4@<V5N="!T;R!02%`G<R!S>7-T96T@;&]G9V5R+"`@('P*?"`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P@=VAI8V@@=7-E<R!T:&4@;W!E<F%T
M:6YG('-Y<W1E;2=S(&QO9V=I;F<@("`@('P*?"`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P@;65C:&%N:7-M(&]R(&$@9FEL92`H9&5P96YD:6YG(&]N
M('1H92!V86QU92`@('P*?"`@("`@("`@("`@("`@("`@("`@("`@("`@('P@
M;V8@=&AE(&!E<G)O<E]L;V<@8V]N9FEG=7)A=&EO;B!D:7)E8W1I=F5@7RDN
M('P**RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8%!%05)?
M3$]'7U194$5?34%)3&!@("`@('P@3&]G(&5V96YT<R!A<F4@<V5N="!V:6$@
M96UA:6P@=&\@=&AE(&%D9')E<W,@('P*?"`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P@<W!E8VEF:65D(&EN('1H92!@8&1E<W1I;F%T:6]N8&`@=F%L
M=64N("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M?"!@8%!%05)?3$]'7U194$5?1$5"54=@8"`@('P@3&]G(&5V96YT<R!A<F4@
M<V5N="!T:')O=6=H(%!(4"=S(&1E8G5G9VEN9R`@('P*?"`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P@8V]N;F5C=&EO;BX@(%1H:7,@=VEL;"!O;FQY
M('=O<FL@:68@("`@("`@("`@('P*?"`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P@8')E;6]T92!D96)U9V=I;F=@7R!H87,@8F5E;B!E;F%B;&5D+B`@
M5&AE("`@('P*?"`@("`@("`@("`@("`@("`@("`@("`@("`@('P@8&!D97-T
M:6YA=&EO;F!@('9A;'5E(&ES('5S960@=&\@<W!E8VEF>2!T:&4@('P*?"`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P@:&]S="!N86UE(&]R($E0(&%D
M9')E<W,@;V8@=&AE('1A<F=E="!S;V-K970N('P**RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*?"!@8%!%05)?3$]'7U194$5?1DE,16!@("`@
M('P@3&]G(&5V96YT<R!W:6QL(&)E(&%P<&5N9&5D('1O('1H92!F:6QE(&YA
M;65D('P*?"`@("`@("`@("`@("`@("`@("`@("`@("`@('P@8GD@=&AE(&!@
M9&5S=&EN871I;VY@8"!V86QU92X@("`@("`@("`@("`@("`@('P**RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*"BXN(%]E<G)O<E]L;V<H*3H@
M:'1T<#HO+W=W=RYP:'`N;F5T+V5R<F]R7VQO9PHN+B!?;6%I;"@I.B!H='1P
M.B\O=W=W+G!H<"YN970O;6%I;`HN+B!?97)R;W)?;&]G(&-O;F9I9W5R871I
M;VX@9&ER96-T:79E.B!H='1P.B\O=W=W+G!H<"YN970O97)R;W)F=6YC(VEN
M:2YE<G)O<BUL;V<*+BX@7W)E;6]T92!D96)U9V=I;F<Z(&AT='`Z+R]W=W<N
M<&AP+FYE="]I;G-T86QL+F-O;F9I9W5R92-I;G-T86QL+F-O;F9I9W5R92YE
M;F%B;&4M9&5B=6=G97(*"D5X86UP;&4*?GY^?GY^?@HZ.@H*("`@("1L;V=G
M97(@/2`F3&]G.CIS:6YG;&5T;VXH)V5R<F]R7VQO9R<L(%!%05)?3$]'7U19
M4$5?4UE35$5-+"`G:61E;G0G*3L*("`@(&9O<B`H)&D@/2`P.R`D:2`\(#$P
M.R`D:2LK*2!["B`@("`@("`@)&QO9V=E<BT^;&]G*"),;V<@96YT<GD@)&DB
M*3L*("`@('T*"@I4:&4@1FEL92!(86YD;&5R"BTM+2TM+2TM+2TM+2TM+2T*
M5&AE($9I;&4@:&%N9&QE<B!W<FET97,@;&]G(&5V96YT<R!T;R!A('1E>'0@
M9FEL92!U<VEN9R!C;VYF:6=U<F%B;&4@<W1R:6YG"F9O<FUA=',N"@I#;VYF
M:6=U<F%T:6]N"GY^?GY^?GY^?GY^?GX**RTM+2TM+2TM+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*?"!087)A;65T97(@("`@("`@("!\(%1Y<&4@("`@("!\
M($1E9F%U;'0@("`@("`@?"!$97-C<FEP=&EO;B`@("`@("`@("`@("`@('P*
M*ST]/3T]/3T]/3T]/3T]/3T]/3TK/3T]/3T]/3T]/3TK/3T]/3T]/3T]/3T]
M/3T]*ST]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/2L*?"!@8&%P<&5N9&!@
M("`@("`@("!\($)O;VQE86X@("!\(%1R=64@("`@("`@("`@?"!3:&]U;&0@
M;F5W(&QO9R!E;G1R:65S(&)E('P*?"`@("`@("`@("`@("`@("`@("!\("`@
M("`@("`@("!\("`@("`@("`@("`@("`@?"!A<'!E;F0@=&\@86X@97AI<W1I
M;F<@;&]G('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@
M("`@("`@("`@("`@?"!F:6QE+"!O<B!S:&]U;&0@=&AE(&$@;F5W('P*?"`@
M("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@
M?"!L;V<@9FEL92!O=F5R=W)I=&4@86X@("`@('P*?"`@("`@("`@("`@("`@
M("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!E>&ES=&EN9R!O
M;F4_("`@("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM
M+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*?"!@8&QO8VMI;F=@8"`@("`@("!\($)O;VQE86X@("!\($9A;'-E
M("`@("`@("`@?"!3:&]U;&0@861V:7-O<GD@9FEL92`@("`@('P*?"`@("`@
M("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!L
M;V-K:6YG("AU<VEN9R!F;&]C:U\I(&)E('P*?"`@("`@("`@("`@("`@("`@
M("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!U<V5D/R`@("`@("`@
M("`@("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM
M+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*?"!@8&UO9&5@8"`@("`@("`@("!\($EN=&5G97(@("!\(#`V-#0@("`@
M("`@("`@?"!/8W1A;"!R97!R97-E;G1A=&EO;B!O9B`@('P*?"`@("`@("`@
M("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!T:&4@
M;&]G(&9I;&4G<R!P97)M:7-S:6]N<WP*?"`@("`@("`@("`@("`@("`@("!\
M("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!M;V1E+B`@("`@("`@("`@
M("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M?"!@8&1I<FUO9&5@8"`@("`@("!\($EN=&5G97(@("!\(#`W-34@("`@("`@
M("`@?"!/8W1A;"!R97!R97-E;G1A=&EO;B!O9B`@('P*?"`@("`@("`@("`@
M("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!T:&4@9FEL
M92!P97)M:7-S:6]N(&UO9&4@('P*?"`@("`@("`@("`@("`@("`@("!\("`@
M("`@("`@("!\("`@("`@("`@("`@("`@?"!T:&%T('=I;&P@8F4@=7-E9"!W
M:&5N("`@('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@
M("`@("`@("`@("`@?"!C<F5A=&EN9R!D:7)E8W1O<FEE<R!T:&%T('P*?"`@
M("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@
M?"!D;R!N;W0@86QR96%D>2!E>&ES="X@("`@('P**RTM+2TM+2TM+2TM+2TM
M+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*?"!@8&5O;&!@("`@("`@("`@("!\(%-T<FEN
M9R`@("!\($]3(&1E9F%U;'0@("`@?"!4:&4@96YD+6]N+6QI;F4@8VAA<F%C
M=&5R('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@
M("`@("`@("`@?"!S97%U96YC92X@("`@("`@("`@("`@("`@('P**RTM+2TM
M+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8&QI;F5&;W)M871@8"`@
M("!\(%-T<FEN9R`@("!\(&!@)3$D<R`E,B1S("`@?"!,;V<@;&EN92!F;W)M
M870@("`@("`@("`@('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@
M("!\(%LE,R1S72`E-"1S8&`@?"!S<&5C:69I8V%T:6]N+B`@("`@("`@("`@
M('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM
M+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8'1I;65&
M;W)M871@8"`@("!\(%-T<FEN9R`@("!\(&!@)6(@)60@("`@("`@?"!4:6UE
M('-T86UP(&9O<FUA="`@("`@("`@('P*?"`@("`@("`@("`@("`@("`@("!\
M("`@("`@("`@("!\("5(.B5-.B538&`@("`@?"`H9F]R('-T<F9T:6UE7RDN
M("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M"BXN(%]F;&]C:SH@:'1T<#HO+W=W=RYP:'`N;F5T+V9L;V-K"BXN(%]S=')F
M=&EM93H@:'1T<#HO+W=W=RYP:'`N;F5T+W-T<F9T:6UE"@I4:&4@9FEL92!H
M86YD;&5R('=I;&P@;VYL>2!A='1E;7!T('1O('-E="!T:&4@8&!M;V1E8&`@
M=F%L=64@:68@:70@=V%S"G)E<W!O;G-I8FQE(&9O<B!C<F5A=&EN9R!T:&4@
M9FEL92X*"D5X86UP;&4*?GY^?GY^?@HZ.@H*("`@("1C;VYF(#T@87)R87DH
M)VUO9&4G(#T^(#`V,#`L("=T:6UE1F]R;6%T)R`]/B`G)5@@)7@G*3L*("`@
M("1L;V=G97(@/2`F3&]G.CIS:6YG;&5T;VXH)V9I;&4G+"`G;W5T+FQO9R<L
M("=I9&5N="<L("1C;VYF*3L*("`@(&9O<B`H)&D@/2`P.R`D:2`\(#$P.R`D
M:2LK*2!["B`@("`@("`@)&QO9V=E<BT^;&]G*"),;V<@96YT<GD@)&DB*3L*
M("`@('T*"@I4:&4@36%I;"!(86YD;&5R"BTM+2TM+2TM+2TM+2TM+2T*5&AE
M($UA:6P@:&%N9&QE<B!A9V=R96=A=&5S(&$@<V5S<VEO;B=S(&QO9R!E=F5N
M=',@86YD('-E;F1S('1H96T@:6X@=&AE(&)O9'D*;V8@86X@96UA:6P@;65S
M<V%G92!U<VEN9R!02%`G<R!@;6%I;"@I8%\@9G5N8W1I;VXN"@I#;VYF:6=U
M<F%T:6]N"GY^?GY^?GY^?GY^?GX**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM
M+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*?"!087)A;65T97(@("`@("`@("!\(%1Y<&4@("`@("!\($1E
M9F%U;'0@("`@("`@?"!$97-C<FEP=&EO;B`@("`@("`@("`@("`@('P**ST]
M/3T]/3T]/3T]/3T]/3T]/3TK/3T]/3T]/3T]/3TK/3T]/3T]/3T]/3T]/3T]
M*ST]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/2L*?"!@8&9R;VU@8"`@("`@
M("`@("!\(%-T<FEN9R`@("!\('-E;F1M86EL7V9R;VT@?"!686QU92!F;W(@
M=&AE(&UE<W-A9V4G<R`@('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@
M("`@("!\($E.22!V86QU92`@("`@?"!@8$9R;VTZ8&`@:&5A9&5R+B`@("`@
M("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM
M+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8'-U
M8FIE8W1@8"`@("`@("!\(%-T<FEN9R`@("!\(&!@6TQO9U]M86EL72`@?"!6
M86QU92!F;W(@=&AE(&UE<W-A9V4G<R`@('P*?"`@("`@("`@("`@("`@("`@
M("!\("`@("`@("`@("!\($QO9R!M97-S86=E8&`@?"!@8%-U8FIE8W0Z8&`@
M:&5A9&5R+B`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM
M+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*?"!@8'!R96%M8FQE8&`@("`@("!\(%-T<FEN9R`@("!\(&!@(&`H96UP
M='DI8"`@?"!0<F5A;6)L92!F;W(@=&AE(&UE<W-A9V4N('P**RTM+2TM+2TM
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8&QI;F5&;W)M871@8"`@("!\
M(%-T<FEN9R`@("!\(&!@)3$D<R`E,B1S("`@?"!,;V<@;&EN92!F;W)M870@
M("`@("`@("`@('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\
M(%LE,R1S72`E-"1S8&`@?"!S<&5C:69I8V%T:6]N+B`@("`@("`@("`@('P*
M*RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM
M+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8'1I;65&;W)M
M871@8"`@("!\(%-T<FEN9R`@("!\(&!@)6(@)60@("`@("`@?"!4:6UE('-T
M86UP(&9O<FUA="`@("`@("`@('P*?"`@("`@("`@("`@("`@("`@("!\("`@
M("`@("`@("!\("5(.B5-.B538&`@("`@?"`H9F]R('-T<F9T:6UE7RDN("`@
M("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM
M+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*"BXN
M(%]M86EL*"DZ(&AT='`Z+R]W=W<N<&AP+FYE="]M86EL"@I%>&%M<&QE"GY^
M?GY^?GX*.CH*"B`@("`D8V]N9B`](&%R<F%Y*"=S=6)J96-T)R`]/B`G26UP
M;W)T86YT($QO9R!%=F5N=',G*3L*("`@("1L;V=G97(@/2`F3&]G.CIS:6YG
M;&5T;VXH)VUA:6PG+"`G=V5B;6%S=&5R0&5X86UP;&4N8V]M)RP@)VED96YT
M)RP@)&-O;F8I.PH@("`@9F]R("@D:2`](#`[("1I(#P@,3`[("1I*RLI('L*
M("`@("`@("`D;&]G9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PH@("`@?0H*
M"E1H92!-1$(R($AA;F1L97(*+2TM+2TM+2TM+2TM+2TM+0I4:&4@341",B!H
M86YD;&5R(&ES('-I;6EL87(@=&\@8'1H92!344P@*$1"*2!H86YD;&5R8%\L
M(&)U="!I;G-T96%D(&]F('5S:6YG"G1H92!014%2($1"('!A8VMA9V4L(&ET
M('5S97,@=&AE(&!-1$(R(&1A=&%B87-E(&%B<W1R86-T:6]N('!A8VMA9V5@
M7RX*"D-O;F9I9W5R871I;VX*?GY^?GY^?GY^?GY^?@HK+2TM+2TM+2TM+2TM
M+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PI\(%!A<F%M971E<B`@("`@("`@('P@5'EP
M92`@("`@('P@1&5F875L="`@("`@("!\($1E<V-R:7!T:6]N("`@("`@("`@
M("`@("`@?`HK/3T]/3T]/3T]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/2L]/3T]
M/3T]/3T]/3T]/3TK/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]*PI\(&!@
M9'-N8&`@("`@("`@("`@('P@36EX960@("`@('P@)R<@8"AE;7!T>2E@("!\
M($$@8$1A=&$@4V]U<F-E($YA;65@7RX@("`@?`I\("`@("`@("`@("`@("`@
M("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\('QR97%U:7)E9'P@
M("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM
M+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PI\(&!@;W!T:6]N<V!@("`@("`@('P@07)R87D@("`@('P@8&!P97)S
M:7-T96YT8&!\($%N(&%R<F%Y(&]F(&!-1$(R8%\@("`@("`@?`I\("`@("`@
M("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\(&]P
M=&EO;G,N("`@("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM
M+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PI\(&!@9&)@8"`@("`@("`@("`@('P@3V)J96-T("`@
M('P@3E5,3"`@("`@("`@("!\($%N(&5X:7-T:6YG(&!-1$(R8%\@("`@("`@
M?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@
M("`@("!\(&]B:F5C="X@($EF('-P96-I9FEE9"P@("`@?`I\("`@("`@("`@
M("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\('1H:7,@
M;V)J96-T('=I;&P@8F4@=7-E9"P@?`I\("`@("`@("`@("`@("`@("`@('P@
M("`@("`@("`@('P@("`@("`@("`@("`@("!\(&%N9"!@8&1S;F!@('=I;&P@
M8F4@("`@("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@
M("`@("`@("`@("`@("!\(&EG;F]R960N("`@("`@("`@("`@("`@("`@?`HK
M+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM
M+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@<V5Q=65N8V5@
M8"`@("`@('P@4W1R:6YG("`@('P@8&!L;V=?:61@8"`@("!\(%1H92!N86UE
M(&]F('1H92!S97%U96YC92`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@
M("`@("`@('P@("`@("`@("`@("`@("!\('1O('5S92!W:&5N(&=E;F5R871I
M;F<@("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@
M("`@("`@("`@("!\('5N:7%U92!E=F5N="!)1',N("`@56YD97(@?`I\("`@
M("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\
M(&UA;GD@9&%T86)A<V5S+"!T:&ES('=I;&P@?`I\("`@("`@("`@("`@("`@
M("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\(&)E('5S960@87,@
M=&AE(&YA;64@;V8@("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@
M("`@('P@("`@("`@("`@("`@("!\('1H92!S97%U96YC92!T86)L92X@("`@
M("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM
M+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@:61E
M;G1,:6UI=&!@("`@('P@26YT96=E<B`@('P@,38@("`@("`@("`@("!\(%1H
M92!M87AI;75M(&QE;F=T:"!O9B!T:&4@?`I\("`@("`@("`@("`@("`@("`@
M('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\(&!@:61E;G1@8"!S=')I
M;F<N("`@("`@("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@
M('P@("`@("`@("`@("`@("!\("HJ0VAA;F=I;F<@=&AI<R!V86QU92!M87D@
M?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@
M("`@("!\(')E<75I<F4@=7!D871E<R!T;R!T:&4@4U%,?`I\("`@("`@("`@
M("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\('-C:&5M
M82P@87,@=V5L;"XJ*B`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM
M+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PI\(&!@<VEN9VQE=&]N8&`@("`@('P@0F]O;&5A;B`@('P@
M9F%L<V4@("`@("`@("!\($ES('1R=64L('5S92!A('-I;F=L971O;B`@?`I\
M("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@
M("!\(&1A=&%B87-E(&]B:F5C="!U<VEN9R`@("`@?`I\("`@("`@("`@("`@
M("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\(&!-1$(R.CIS
M:6YG;&5T;VXH*6!?+B`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM
M+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PH*+BX@7TU$0C(Z(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]-1$(R"BXN(%]-1$(R(&1A=&%B87-E(&%B<W1R86-T:6]N('!A8VMA9V4Z
M($U$0C)?"BXN(%]-1$(R.CIS:6YG;&5T;VXH*3H@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+TU$0C(O9&]C<R]L871E<W0O341",B]-1$(R+FAT;6PC
M;65T:&]D<VEN9VQE=&]N"@I4:&4@3G5L;"!(86YD;&5R"BTM+2TM+2TM+2TM
M+2TM+2T*5&AE($YU;&P@:&%N9&QE<B!S:6UP;'D@8V]N<W5M97,@;&]G(&5V
M96YT<R`H86MI;B!T;R!S96YD:6YG('1H96T@=&\*8&`O9&5V+VYU;&Q@8"DN
M("!@3&]G(&QE=F5L(&UA<VMS8%\@87)E(')E<W!E8W1E9"P@86YD('1H92!E
M=F5N="!W:6QL('-T:6QL(&)E"G-E;G0@=&\@86YY(')E9VES=&5R960@8&QO
M9R!O8G-E<G9E<G-@7RX*"D5X86UP;&4*?GY^?GY^?@HZ.@H*("`@("1L;V=G
M97(@/2`F3&]G.CIS:6YG;&5T;VXH)VYU;&PG*3L*("`@(&9O<B`H)&D@/2`P
M.R`D:2`\(#$P.R`D:2LK*2!["B`@("`@("`@)&QO9V=E<BT^;&]G*"),;V<@
M96YT<GD@)&DB*3L*("`@('T*"@I4:&4@4U%,("A$0BD@2&%N9&QE<@HM+2TM
M+2TM+2TM+2TM+2TM+2TM+0H*5&AE(%-13"!H86YD;&5R('-E;F1S(&QO9R!E
M=F5N=',@=&\@82!D871A8F%S92!U<VEN9R!@4$5!4B=S($1"(&%B<W1R86-T
M:6]N"FQA>65R8%\N"@HJ*DYO=&4Z*BH@1'5E('1O('1H92!C;VYS=')A:6YT
M<R!O9B!T:&4@9&5F875L="!D871A8F%S92!S8VAE;6$L('1H92!344P*:&%N
M9&QE<B!L:6UI=',@=&AE(&QE;F=T:"!O9B!T:&4@8&`D:61E;G1@8"!S=')I
M;F<@=&\@<VEX=&5E;B`H,38I(&-H87)A8W1E<G,N"E1H:7,@;&EM:70@8V%N
M(&)E(&%D:G5S=&5D('5S:6YG('1H92!@8&ED96YT3&EM:71@8"!C;VYF:6=U
M<F%T:6]N('!A<F%M971E<BX*"E1H92!,;V<@5&%B;&4*?GY^?GY^?GY^?GY^
M?@I4:&4@9&5F875L="!344P@=&%B;&4@=7-E9"!B>2!T:&ES(&AA;F1L97(@
M;&]O:W,@;&EK92!T:&ES.CH*"B`@("!#4D5!5$4@5$%"3$4@;&]G7W1A8FQE
M("@*("`@("`@("!I9"`@("`@("`@("!)3E0@3D]4($Y53$PL"B`@("`@("`@
M;&]G=&EM92`@("`@5$E-15-404U0($Y/5"!.54Q,+`H@("`@("`@(&ED96YT
M("`@("`@($-(05(H,38I($Y/5"!.54Q,+`H@("`@("`@('!R:6]R:71Y("`@
M($E.5"!.3U0@3E5,3"P*("`@("`@("!M97-S86=E("`@("!605)#2$%2*#(P
M,"DL"B`@("`@("`@4%))34%262!+15D@*&ED*0H@("`@*3L*"E1H:7,@:7,@
M=&AE(")L;W=E<W0@8V]M;6]N(&1E;F]M:6YA=&]R(B!T:&%T('-H;W5L9"!W
M;W)K(&%C<F]S<R!A;&P@4U%,"F-O;7!L:6%N="!D871A8F%S92X@(%EO=2!M
M87D@=V%N="!T;R!M86ME(&1A=&%B87-E+2!O<B!S:71E+7-P96-I9FEC(&-H
M86YG97,*=&\@=&AI<R!S8VAE;6$@=&\@<W5P<&]R="!Y;W5R('-P96-I9FEC
M(&YE961S+"!H;W=E=F5R+B`@1F]R(&5X86UP;&4L"F!0;W-T9W)E4U%,8%\@
M=7-E<G,@;6%Y('!R969E<B!T;R!U<V4@82!@8%1%6%1@8"!T>7!E(&9O<B!T
M:&4@8&!M97-S86=E8&`*9FEE;&0N"@HN+B!?4&]S=&=R95-13#H@:'1T<#HO
M+W=W=RYP;W-T9W)E<W%L+F]R9R\*"D-O;F9I9W5R871I;VX*?GY^?GY^?GY^
M?GY^?@HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM
M+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(%!A<F%M
M971E<B`@("`@("`@('P@5'EP92`@("`@('P@1&5F875L="`@("`@("!\($1E
M<V-R:7!T:6]N("`@("`@("`@("`@("`@?`HK/3T]/3T]/3T]/3T]/3T]/3T]
M/2L]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/3T]/3TK/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]*PI\(&!@9'-N8&`@("`@("`@("`@('P@36EX960@("`@
M('P@)R<@8"AE;7!T>2E@("!\($$@8$1A=&$@4V]U<F-E($YA;65@7RX@("`@
M?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@
M("`@("!\('QR97%U:7)E9'P@("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM
M+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@<W%L8&`@("`@("`@("`@('P@
M4W1R:6YG("`@('P@?'-Q;"UD969A=6QT?"!\(%-13"!I;G-E<G1I;VX@<W1A
M=&5M96YT+B`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM
M+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\
M(&!@;W!T:6]N<V!@("`@("`@('P@07)R87D@("`@('P@8&!P97)S:7-T96YT
M8&!\($%N(&%R<F%Y(&]F(&!$0F!?(&]P=&EO;G,N?`HK+2TM+2TM+2TM+2TM
M+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@9&)@8"`@("`@("`@("`@('P@3V)J
M96-T("`@('P@3E5,3"`@("`@("`@("!\($%N(&5X:7-T:6YG(&!$0F!?(&]B
M:F5C="X@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@
M("`@("`@("`@("!\($EF('-P96-I9FEE9"P@=&AI<R!O8FIE8W0@?`I\("`@
M("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\
M('=I;&P@8F4@=7-E9"P@86YD(&!@9'-N8&`@?`I\("`@("`@("`@("`@("`@
M("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\('=I;&P@8F4@:6=N
M;W)E9"X@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM
M+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PI\(&!@<V5Q=65N8V5@8"`@("`@('P@4W1R:6YG("`@('P@8&!L;V=?
M:61@8"`@("!\(%1H92!N86UE(&]F('1H92!S97%U96YC92`@?`I\("`@("`@
M("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\('1O
M('5S92!W:&5N(&=E;F5R871I;F<@("`@?`I\("`@("`@("`@("`@("`@("`@
M('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\('5N:7%U92!E=F5N="!)
M1',N("`@56YD97(@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@
M('P@("`@("`@("`@("`@("!\(&UA;GD@9&%T86)A<V5S+"!T:&ES('=I;&P@
M?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@
M("`@("!\(&)E('5S960@87,@=&AE(&YA;64@;V8@("`@?`I\("`@("`@("`@
M("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\('1H92!S
M97%U96YC92!T86)L92X@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM
M+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PI\(&!@:61E;G1,:6UI=&!@("`@('P@26YT96=E<B`@('P@
M,38@("`@("`@("`@("!\(%1H92!M87AI;75M(&QE;F=T:"!O9B!T:&4@?`I\
M("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@
M("!\(&!@:61E;G1@8"!S=')I;F<N("`@("`@("`@?`I\("`@("`@("`@("`@
M("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\("HJ0VAA;F=I
M;F<@=&AI<R!V86QU92!M87D@?`I\("`@("`@("`@("`@("`@("`@('P@("`@
M("`@("`@('P@("`@("`@("`@("`@("!\(')E<75I<F4@=7!D871E<R!T;R!T
M:&4@4U%,?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@
M("`@("`@("`@("!\('-C:&5M82P@87,@=V5L;"XJ*B`@("`@("`@?`HK+2TM
M+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*5&AE(&YA;64@;V8@=&AE
M(&1A=&%B87-E('1A8FQE('1O('=H:6-H('1H92!L;V<@96YT<FEE<R!W:6QL
M(&)E('=R:71T96X@:7,*<W!E8VEF:65D('5S:6YG('1H92!@8"1N86UE8&`@
M8V]N<W1R=6-T:6]N('!A<F%M971E<B`H<V5E(&!#;VYF:6=U<FEN9R!A"DAA
M;F1L97)@7RDN"@HN+B!\<W%L+61E9F%U;'1\(')E<&QA8V4Z.B!@8$E.4T52
M5"!)3E1/("1T86)L92`H:60L(&QO9W1I;64L(&ED96YT+"!P<FEO<FET>2P@
M;65S<V%G92D@5D%,5453*#\L($-54E)%3E1?5$E-15-404U0+"`_+"`_+"`_
M*6!@"@HN+B!?1$(Z(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@HN
M+B!?4$5!4B=S($1"(&%B<W1R86-T:6]N(&QA>65R.B!$0E\*+BX@7T1A=&$@
M4V]U<F-E($YA;64Z(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A
M8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<`H*17AA;7!L97,*?GY^
M?GY^?GX*57-I;F<@82!@1&%T82!3;W5R8V4@3F%M96!?('1O(&-R96%T92!A
M(&YE=R!D871A8F%S92!C;VYN96-T:6]N.CH*"B`@("`D8V]N9B`](&%R<F%Y
M*"=D<VXG(#T^("=P9W-Q;#HO+VIO;D!L;V-A;&AO<W0K=6YI>"]L;V=S)RD[
M"B`@("`D;&]G9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=S<6PG+"`G;&]G7W1A
M8FQE)RP@)VED96YT)RP@)&-O;F8I.PH@("`@9F]R("@D:2`](#`[("1I(#P@
M,3`[("1I*RLI('L*("`@("`@("`D;&]G9V5R+3YL;V<H(DQO9R!E;G1R>2`D
M:2(I.PH@("`@?0H*57-I;F<@86X@97AI<W1I;F<@8$1"8%\@;V)J96-T.CH*
M"B`@("!R97%U:7)E7V]N8V4@)T1"+G!H<"<["B`@("`D9&(@/2`F1$(Z.F-O
M;FYE8W0H)W!G<W%L.B\O:F]N0&QO8V%L:&]S="MU;FEX+VQO9W,G*3L*"B`@
M("`D8V]N9ELG9&(G72`]("1D8CL*("`@("1L;V=G97(@/2`F3&]G.CIS:6YG
M;&5T;VXH)W-Q;"<L("=L;V=?=&%B;&4G+"`G:61E;G0G+"`D8V]N9BD["B`@
M("!F;W(@*"1I(#T@,#L@)&D@/"`Q,#L@)&DK*RD@>PH@("`@("`@("1L;V=G
M97(M/FQO9R@B3&]G(&5N=')Y("1I(BD["B`@("!]"@H*5&AE(%-Q;&ET92!(
M86YD;&5R"BTM+2TM+2TM+2TM+2TM+2TM+0HZ075T:&]R.B`@("`@("`@0F5R
M=')A;F0@36%N<VEO;@HZ0V]N=&%C=#H@("`@("`@8FUA;G-I;VY`;6%M87-A
M;2YC;VT*"E1H92!3<6QI=&4@:&%N9&QE<B!S96YD<R!L;V<@979E;G1S('1O
M(&%N(%-Q;&ET92!D871A8F%S92!U<VEN9R!T:&4@8&YA=&EV90I02%`@<W%L
M:71E(&9U;F-T:6]N<V!?+@H*270@:7,@9F%S=&5R('1H86X@8'1H92!344P@
M*$1"*2!H86YD;&5R8%\@8F5C875S92!R97%U97-T<R!A<F4@;6%D92!D:7)E
M8W1L>0IT;R!T:&4@9&%T86)A<V4@=VET:&]U="!U<VEN9R!A;B!A8G-T<F%C
M=&EO;B!L87EE<BX@($ET(&ES(&%L<V\@:6YT97)E<W1I;F<@=&\*;F]T92!T
M:&%T(%-Q;&ET92!D871A8F%S92!F:6QE<R!C86X@8F4@;6]V960L(&-O<&EE
M9"P@86YD(&1E;&5T960@;VX@>6]U<@IS>7-T96T@:G5S="!L:6ME(&%N>2!O
M=&AE<B!F:6QE<RP@=VAI8V@@;6%K97,@;&]G(&UA;F%G96UE;G0@96%S:65R
M+B`@3&%S="!B=70*;F]T(&QE87-T+"!U<VEN9R!A(&1A=&%B87-E('1O(&QO
M9R!Y;W5R(&5V96YT<R!A;&QO=W,@>6]U('1O('5S92!344P@<75E<FEE<PIT
M;R!C<F5A=&4@<F5P;W)T<R!A;F0@<W1A=&ES=&EC<RX*"E=H96X@=7-I;F<@
M82!D871A8F%S92!A;F0@;&]G9VEN9R!A(&QO="!O9B!E=F5N=',L(&ET(&ES
M(')E8V]M;65N9&5D('1O('-P;&ET"G1H92!D871A8F%S92!I;G1O('-M86QL
M97(@9&%T86)A<V5S+B`@5&AI<R!I<R!A;&QO=V5D(&)Y(%-Q;&ET92P@86YD
M('EO=2!C86X*;&%T97(@=7-E('1H92!3<6QI=&4@8$%45$%#2&!?('-T871E
M;65N="!T;R!Q=65R>2!Y;W5R(&QO9R!D871A8F%S92!F:6QE<PIG;&]B86QL
M>2X*"DEF('1H92!D871A8F%S92!D;V5S(&YO="!E>&ES="!W:&5N('1H92!L
M;V<@:7,@;W!E;F5D+"!S<6QI=&4@=VEL;"!T<GD@=&\*8W)E871E(&ET(&%U
M=&]M871I8V%L;'DN($EF('1H92!L;V<@=&%B;&4@9&]E<R!N;W0@97AI<W0L
M(&ET('=I;&P@86QS;R!B90IA=71O;6%T:6-A;&QY(&-R96%T960N("!4:&4@
M=&%B;&4@8W)E871I;VX@=7-E<R!T:&4@9F]L;&]W:6YG(%-13"!R97%U97-T
M.CH*"B`@("!#4D5!5$4@5$%"3$4@;&]G7W1A8FQE("@*("`@("`@("!I9"`@
M("`@("`@("!)3E1%1T52(%!224U!4ED@2T59($Y/5"!.54Q,+`H@("`@("`@
M(&QO9W1I;64@("`@($Y/5"!.54Q,+`H@("`@("`@(&ED96YT("`@("`@($-(
M05(H,38I($Y/5"!.54Q,+`H@("`@("`@('!R:6]R:71Y("`@($E.5"!.3U0@
M3E5,3"P*("`@("`@("!M97-S86=E"B`@("`I.PH*0V]N9FEG=7)A=&EO;@I^
M?GY^?GY^?GY^?GY^"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM
M*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"GP@4&%R86UE=&5R("`@("`@("`@?"!4>7!E("`@("`@?"!$969A=6QT("`@
M("`@('P@1&5S8W)I<'1I;VX@("`@("`@("`@("`@("!\"BL]/3T]/3T]/3T]
M/3T]/3T]/3T]*ST]/3T]/3T]/3T]*ST]/3T]/3T]/3T]/3T]/2L]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3TK"GP@8&!F:6QE;F%M96!@("`@("`@?"!3
M=')I;F<@("`@?"`G)R!@*&5M<'1Y*6`@('P@4&%T:"!T;R!A;B!3<6QI=&4@
M("`@("`@("!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@
M("`@("`@("`@("`@('P@9&%T86)A<V4N('QR97%U:7)E9'P@("`@("!\"BLM
M+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM
M+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!M;V1E8&`@("`@
M("`@("`@?"!);G1E9V5R("`@?"`P-C8V("`@("`@("`@('P@3V-T86P@;6]D
M92!U<V5D('1O(&]P96X@("!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@
M("`@("`@?"`@("`@("`@("`@("`@('P@=&AE(&1A=&%B87-E+B`@("`@("`@
M("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!P
M97)S:7-T96YT8&`@("`@?"!";V]L96%N("`@?"!F86QS92`@("`@("`@('P@
M57-E(&$@<&5R<VES=&5N="`@("`@("`@("!\"GP@("`@("`@("`@("`@("`@
M("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@8V]N;F5C=&EO;BX@
M("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM
M+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"@I!;B!A;')E861Y(&]P96YE9"!D871A8F%S92!C;VYN96-T:6]N(&-A
M;B!A;'-O(&)E('!A<W-E9"!A<R!P87)A;65T97(@:6YS=&5A9`IO9B!T:&4@
M86)O=F4@8V]N9FEG=7)A=&EO;BX@($EN('1H:7,@8V%S92P@8VQO<VEN9R!T
M:&4@9&%T86)A<V4@8V]N;F5C=&EO;B!I<PIU<"!T;R!T:&4@=7-E<BX*"BXN
M(%]N871I=F4@4$A0('-Q;&ET92!F=6YC=&EO;G,Z(&AT='`Z+R]W=W<N<&AP
M+FYE="]S<6QI=&4*+BX@7T%45$%#2#H@:'1T<#HO+W=W=RYS<6QI=&4N;W)G
M+VQA;F<N:'1M;"-A='1A8V@*"D5X86UP;&5S"GY^?GY^?GY^"E5S:6YG(&$@
M8V]N9FEG=7)A=&EO;B!T;R!C<F5A=&4@82!N97<@9&%T86)A<V4@8V]N;F5C
M=&EO;CHZ"@H@("`@)&-O;F8@/2!A<G)A>2@G9FEL96YA;64G(#T^("=L;V<N
M9&(G+"`G;6]D92<@/3X@,#8V-BP@)W!E<G-I<W1E;G0G(#T^('1R=64I.PH@
M("`@)&QO9V=E<B`])B!,;V<Z.F9A8W1O<GDH)W-Q;&ET92<L("=L;V=?=&%B
M;&4G+"`G:61E;G0G+"`D8V]N9BD["B`@("`D;&]G9V5R+3YL;V<H)VQO9V=I
M;F<@86X@979E;G0G+"!014%27TQ/1U]705).24Y'*3L*"E5S:6YG(&%N(&5X
M:7-T:6YG(&-O;FYE8W1I;VXZ.@H*("`@("1D8B`]('-Q;&ET95]O<&5N*"=L
M;V<N9&(G+"`P-C8V+"`D97)R;W(I.PH@("`@)&QO9V=E<B`])B!,;V<Z.F9A
M8W1O<GDH)W-Q;&ET92<L("=L;V=?=&%B;&4G+"`G:61E;G0G+"`D9&(I.PH@
M("`@)&QO9V=E<BT^;&]G*"=L;V=G:6YG(&%N(&5V96YT)RP@4$5!4E],3T=?
M5T%23DE.1RD["B`@("!S<6QI=&5?8VQO<V4H)&1B*3L*"@I4:&4@4WES;&]G
M($AA;F1L97(*+2TM+2TM+2TM+2TM+2TM+2TM"E1H92!3>7-L;V<@:&%N9&QE
M<B!S96YD<R!L;V<@979E;G1S('1O('1H92!S>7-T96T@;&]G9VEN9R!S97)V
M:6-E("AS>7-L;V<@;VX*56YI>"UL:6ME(&5N=FER;VYM96YT<R!O<B!T:&4@
M179E;G0@3&]G(&]N(%=I;F1O=W,@<WES=&5M<RDN("!4:&4@979E;G1S(&%R
M90IS96YT('5S:6YG(%!(4"=S(&!S>7-L;V<H*6!?(&9U;F-T:6]N+@H*1F%C
M:6QI=&EE<PI^?GY^?GY^?GY^"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"GP@0V]N<W1A;G0@("`@("`@("`@?"!#871E9V]R>2!$97-C<FEP
M=&EO;B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"BL]/3T]
M/3T]/3T]/3T]/3T]/3T]*ST]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3TK"GP@8&!,3T=?05542&!@("`@
M("`@?"!396-U<FET>2`O(&%U=&AO<FEZ871I;VX@;65S<V%G97,[(&!@3$]'
M7T%55$A04DE68&`@:7-\"GP@("`@("`@("`@("`@("`@("`@?"!P<F5F97)R
M960@;VX@<WES=&5M<R!W:&5R92!I="!I<R!D969I;F5D+B`@("`@("`@("`@
M("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!,3T=?
M05542%!2259@8"`@?"!0<FEV871E('-E8W5R:71Y("\@875T:&]R:7IA=&EO
M;B!M97-S86=E<R`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"GP@8&!,3T=?0U)/3F!@("`@("`@?"!#;&]C:R!D865M
M;VX@*&!@8W)O;F!@(&%N9"!@8&%T8&`I("`@("`@("`@("`@("`@("`@("!\
M"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!,3T=?1$%%
M34].8&`@("`@?"!3>7-T96T@9&%E;6]N('!R;V-E<W-E<R`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"GP@8&!,3T=?2T523F!@("`@("`@?"!+97)N96P@;65S<V%G
M97,@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"BLM
M+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!,3T=?3$]#04PP
M8&`@+BX@?"!297-E<G9E9"!F;W(@;&]C86P@=7-E.R`J*FYO="HJ(&%V86EL
M86)L92!U;F1E<B`@("`@("!\"GP@8&!,3T=?3$]#04PW8&`@("`@?"!7:6YD
M;W=S+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!,
M3T=?3%!28&`@("`@("`@?"!0<FEN=&5R('-U8G-Y<W1E;2`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM
M+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"GP@8&!,3T=?34%)3&!@("`@("`@?"!-86EL('-U
M8G-Y<W1E;2`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!,3T=?
M3D574V!@("`@("`@?"!54T5.150@;F5W<R!S=6)S>7-T96T@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"GP@8&!,3T=?4UE33$]'8&`@("`@?"!);G1E<FYA;"!S
M>7-L;V<@;65S<V%G97,@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!,3T=?55-%
M4F!@("`@("`@?"!'96YE<FEC('5S97(M;&5V96P@;65S<V%G97,@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"GP@8&!,3T=?555#4&!@("`@("`@?"!554-0('-U8G-Y<W1E
M;2`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"BLM
M+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"@HN+B!?<WES;&]G*"DZ
M(&AT='`Z+R]W=W<N<&AP+FYE="]S>7-L;V<*"D5X86UP;&4*?GY^?GY^?@HZ
M.@H*("`@("1L;V=G97(@/2`F3&]G.CIS:6YG;&5T;VXH)W-Y<VQO9R<L($Q/
M1U],3T-!3#`L("=I9&5N="<I.PH@("`@9F]R("@D:2`](#`[("1I(#P@,3`[
M("1I*RLI('L*("`@("`@("`D;&]G9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I
M.PH@("`@?0H*"E1H92!7:6YD;W<@2&%N9&QE<@HM+2TM+2TM+2TM+2TM+2TM
M+2T*5&AE(%=I;F1O=R!H86YD;&5R('-E;F1S(&QO9R!E=F5N=',@=&\@82!S
M97!A<F%T92!B<F]W<V5R('=I;F1O=RX@(%1H90IO<FEG:6YA;"!I9&5A(&9O
M<B!T:&ES(&AA;F1L97(@=V%S(&EN<W!I<F5D(&)Y($-R86EG($1A=FES)R!:
M96YD+F-O;2!A<G1I8VQE"F5N=&ET;&5D(&`B2F%V85-C<FEP="!0;W=E<B!0
M2%`@1&5B=6=G:6YG(F!?+@H*0V]N9FEG=7)A=&EO;@I^?GY^?GY^?GY^?GY^
M"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM
M+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@4&%R86UE=&5R
M("`@("`@("`@?"!4>7!E("`@("`@?"!$969A=6QT("`@("`@('P@1&5S8W)I
M<'1I;VX@("`@("`@("`@("`@("!\"BL]/3T]/3T]/3T]/3T]/3T]/3T]*ST]
M/3T]/3T]/3T]*ST]/3T]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3TK"GP@8&!T:71L96!@("`@("`@("`@?"!3=')I;F<@("`@?"!@
M8$QO9R!/=71P=70@('P@5&AE('1I=&QE(&]F('1H92!O=71P=70@("!\"GP@
M("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"!7:6YD;W=@8"`@("`@
M('P@=VEN9&]W+B`@("`@("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM
M+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!C;VQO<G-@8"`@("`@("`@?"!!<G)A
M>2`@("`@?"!@4D]9($<@0DE68%\@('P@36%P<&EN9R!O9B!L;V<@<')I;W)I
M=&EE<R!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`H:&EG
M:"!T;R!L;W<I('P@=&\@8V]L;W)S+B`@("`@("`@("`@("`@("!\"BLM+2TM
M+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"@HN+B!?(DIA=F%38W)I<'0@
M4&]W97(@4$A0($1E8G5G9VEN9R(Z(&AT='`Z+R]W=W<N>F5N9"YC;VTO>F5N
M9"]T=70O='5T;W)I86PM1&5B=6=,:6(N<&AP"BXN(%]23UD@1R!"258Z(&AT
M='`Z+R]W=W<N8VES+G)I="YE9'4O"@I%>&%M<&QE"GY^?GY^?GX*.CH*"B`@
M("`D8V]N9B`](&%R<F%Y*"=T:71L92<@/3X@)U-A;7!L92!,;V<@3W5T<'5T
M)RD["B`@("`D;&]G9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=W:6XG+"`G3&]G
M5VEN9&]W)RP@)VED96YT)RP@)&-O;F8I.PH@("`@9F]R("@D:2`](#`[("1I
M(#P@,3`[("1I*RLI('L*("`@("`@("`D;&]G9V5R+3YL;V<H(DQO9R!E;G1R
M>2`D:2(I.PH@("`@?0H*"D-O;7!O<VET92!(86YD;&5R<PH]/3T]/3T]/3T]
M/3T]/3T]/3T*270@:7,@;V9T96X@=7-E9G5L('1O(&QO9R!E=F5N=',@=&\@
M;75L=&EP;&4@:&%N9&QE<G,N("!4:&4@3&]G('!A8VMA9V4*<')O=FED97,@
M82!C;VUP;W-I=&EN9R!S>7-T96T@=&AA="!M87)K<R!T:&ES('1A<VL@=')I
M=FEA;"X*"E-T87)T(&)Y(&-R96%T:6YG('1H92!I;F1I=FED=6%L(&QO9R!H
M86YD;&5R<SHZ"@H@("`@)&-O;G-O;&4@/2`F3&]G.CIS:6YG;&5T;VXH)V-O
M;G-O;&4G+"`G)RP@)U1%4U0G*3L*("`@("1F:6QE(#T@)DQO9SHZ<VEN9VQE
M=&]N*"=F:6QE)RP@)V]U="YL;V<G+"`G5$535"<I.PH*5&AE;BP@8V]N<W1R
M=6-T(&$@8V]M<&]S:71E(&AA;F1L97(@86YD(&%D9"!T:&4@:6YD:79I9'5A
M;"!H86YD;&5R<R!A<PIC:&EL9')E;B!O9B!T:&4@8V]M<&]S:71E.CH*"B`@
M("`D8V]M<&]S:71E(#T@)DQO9SHZ<VEN9VQE=&]N*"=C;VUP;W-I=&4G*3L*
M("`@("1C;VUP;W-I=&4M/F%D9$-H:6QD*"1C;VYS;VQE*3L*("`@("1C;VUP
M;W-I=&4M/F%D9$-H:6QD*"1F:6QE*3L*"E1H92!C;VUP;W-I=&4@:&%N9&QE
M<B!I;7!L96UE;G1S('1H92!S=&%N9&%R9"!@8$QO9V!@(&EN=&5R9F%C92!S
M;R!Y;W4@8V%N('5S90II="!J=7-T(&QI:V4@86YY(&]F('1H92!O=&AE<B!H
M86YD;&5R<SHZ"@H@("`@)&-O;7!O<VET92T^;&]G*"=4:&ES(&5V96YT('=I
M;&P@8F4@;&]G9V5D('1O(&)O=&@@:&%N9&QE<G,N)RD["@I#:&EL9')E;B!C
M86X@8F4@<F5M;W9E9"!F<F]M('1H92!C;VUP;W-I=&4@=VAE;B!T:&5Y)W)E
M(&YO="!L;VYG97(@;F5E9&5D.CH*"B`@("`D8V]M<&]S:71E+3YR96UO=F5#
M:&EL9"@D9FEL92D["@H*3&]G($]B<V5R=F5R<PH]/3T]/3T]/3T]/3T]"DQO
M9R!O8G-E<G9E<G,@<')O=FED92!A;B!I;7!L96UE;G1A=&EO;B!O9B!T:&4@
M8&]B<V5R=F5R('!A='1E<FY@7RX@($EN('1H90IC;VYT96YT(&]F('1H92!,
M;V<@<&%C:V%G92P@=&AE>2!P<F]V:61E(&$@;65C:&%N:7-M(&)Y('=H:6-H
M('EO=2!C86X@97AA;6EN90HH:2YE+B!O8G-E<G9E*2!E86-H(&5V96YT(&%S
M(&ET(&ES(&QO9V=E9"X@(%1H:7,@86QL;W=S('1H92!I;7!L96UE;G1A=&EO
M;B!O9@IS<&5C:6%L(&)E:&%V:6]R(&)A<V5D(&]N('1H92!C;VYT96YT<R!O
M9B!A(&QO9R!E=F5N="X@($9O<B!E>&%M<&QE+"!T:&4*;V)S97)V97(@8V]D
M92!C;W5L9"!S96YD(&%N(&%L97)T(&5M86EL(&EF(&$@;&]G(&5V96YT(&-O
M;G1A:6YE9"!T:&4@<W1R:6YG"F!@4$%.24-@8"X*"D-R96%T:6YG(&$@;&]G
M(&]B<V5R=F5R(&EN=F]L=F5S(&EM<&QE;65N=&EN9R!A('-U8F-L87-S(&]F
M('1H90I@8$QO9U]O8G-E<G9E<F!@(&-L87-S+B`@5&AE('-U8F-L87-S(&UU
M<W0@;W9E<G)I9&4@=&AE(&)A<V4@8VQA<W,G<PI@8&YO=&EF>2@I8&`@;65T
M:&]D+B`@5&AI<R!M971H;V0@:7,@<&%S<V5D(&$@:&%S:"!C;VYT86EN:6YG
M('1H92!E=F5N="=S"G!R:6]R:71Y(&%N9"!E=F5N="X@(%1H92!S=6)C;&%S
M<R=S(&EM<&QE;65N=&%T:6]N(&ES(&9R964@=&\@86-T('5P;VX@=&AI<PII
M;F9O<FUA=&EO;B!I;B!A;GD@=V%Y(&ET(&QI:V5S+@H*3&]G(&]B<V5R=F5R
M<R!A<F4@871T86-H960@=&\@8&!,;V=@8"!I;G-T86YC97,@=FEA('1H92!@
M8&%T=&%C:"@I8&`@;65T:&]D.CH*"B`@("`D;V)S97)V97(@/2`F3&]G7V]B
M<V5R=F5R.CIF86-T;W)Y*"=Y;W5R5'EP92<I.PH@("`@)&QO9V=E<BT^871T
M86-H*"1O8G-E<G9E<BD["@I/8G-E<G9E<G,@8V%N(&)E(&1E=&%C:&5D('5S
M:6YG('1H92!@8&1E=&%C:"@I8&`@;65T:&]D.CH*"B`@("`D;&]G9V5R+3YD
M971A8V@H)&]B<V5R=F5R*3L*"D%T('1H:7,@=&EM92P@;F\@8V]N8W)E=&4@
M8&!,;V=?;V)S97)V97)@8"!I;7!L96UE;G1A=&EO;G,@87)E(&1I<W1R:6)U
M=&5D"G=I=&@@=&AE($QO9R!P86-K86=E+@H*+BX@7V]B<V5R=F5R('!A='1E
M<FXZ(&AT='`Z+R]P:'!P871T97)N<RYC;VTO:6YD97@N<&AP+V%R=&EC;&4O
M87)T:6-L979I97<O,C<O,2\Q+PH*"DQO9V=I;F<@1G)O;2!3=&%N9&%R9"!%
M<G)O<B!(86YD;&5R<PH]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T*"DQO9V=I;F<@4$A0($5R<F]R<PHM+2TM+2TM+2TM+2TM+2TM+2T*
M4$A0)W,@9&5F875L="!E<G)O<B!H86YD;&5R(&-A;B!B92!O=F5R<FED9&5N
M('5S:6YG('1H92!@<V5T7V5R<F]R7VAA;F1L97(H*6!?"F9U;F-T:6]N+B`@
M5&AE(&-U<W1O;2!E<G)O<B!H86YD;&EN9R!F=6YC=&EO;B!C86X@=7-E(&$@
M9VQO8F%L($QO9R!I;G-T86YC92!T;PIL;V<@=&AE(%!(4"!E<G)O<G,N"@HJ
M*DYO=&4Z*BH@1F%T86P@4$A0(&5R<F]R<R!C86YN;W0@8F4@:&%N9&QE9"!B
M>2!A(&-U<W1O;2!E<G)O<B!H86YD;&5R(&%T('1H:7,*=&EM92X*"CHZ"@H@
M("`@9G5N8W1I;VX@97)R;W)(86YD;&5R*"1C;V1E+"`D;65S<V%G92P@)&9I
M;&4L("1L:6YE*0H@("`@>PH@("`@("`@(&=L;V)A;"`D;&]G9V5R.PH*("`@
M("`@("`O*B!-87`@=&AE(%!(4"!E<G)O<B!T;R!A($QO9R!P<FEO<FET>2X@
M*B\*("`@("`@("!S=VET8V@@*"1C;V1E*2!["B`@("`@("`@8V%S92!%7U=!
M4DY)3D<Z"B`@("`@("`@8V%S92!%7U5315)?5T%23DE.1SH*("`@("`@("`@
M("`@)'!R:6]R:71Y(#T@4$5!4E],3T=?5T%23DE.1SL*("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@8V%S92!%7TY/5$E#13H*("`@("`@("!C87-E($5?
M55-%4E].3U1)0T4Z"B`@("`@("`@("`@("1P<FEO<FET>2`](%!%05)?3$]'
M7TY/5$E#13L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S92!%7T52
M4D]2.@H@("`@("`@(&-A<V4@15]54T527T524D]2.@H@("`@("`@("`@("`D
M<')I;W)I='D@/2!014%27TQ/1U]%4E(["B`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("1P<FEO=&ET>2`](%!%05)?
M3$]'7TE.1D\["B`@("`@("`@?0H*("`@("`@("`D;&]G9V5R+3YL;V<H)&UE
M<W-A9V4@+B`G(&EN("<@+B`D9FEL92`N("<@870@;&EN92`G("X@)&QI;F4L
M"B`@("`@("`@("`@("`@("`@("`@("1P<FEO<FET>2D["B`@("!]"@H@("`@
M<V5T7V5R<F]R7VAA;F1L97(H)V5R<F]R2&%N9&QE<B<I.PH@("`@=')I9V=E
M<E]E<G)O<B@G5&AI<R!I<R!A;B!I;F9O<FUA=&EO;B!L;V<@;65S<V%G92XG
M+"!%7U5315)?3D]424-%*3L*"BXN(%]S971?97)R;W)?:&%N9&QE<B@I.B!H
M='1P.B\O=W=W+G!H<"YN970O<V5T7V5R<F]R7VAA;F1L97(*"DQO9V=I;F<@
M4$5!4B!%<G)O<G,*+2TM+2TM+2TM+2TM+2TM+2TM+0I4:&4@3&]G('!A8VMA
M9V4@8V%N(&)E('5S960@=VET:"!@4$5!4CHZ<V5T17)R;W)(86YD;&EN9R@I
M8%\G<PI@8%!%05)?15)23U)?0T%,3$)!0TM@8"!M96-H86YI<VT@8GD@=W)I
M=&EN9R!A;B!E<G)O<B!H86YD;&EN9R!F=6YC=&EO;B!T:&%T"G5S97,@82!G
M;&]B86P@3&]G(&EN<W1A;F-E+B`@2&5R92=S(&%N(&5X86UP;&4Z.@H*("`@
M(&9U;F-T:6]N(&5R<F]R2&%N9&QE<B@D97)R;W(I"B`@("!["B`@("`@("`@
M9VQO8F%L("1L;V=G97(["@H@("`@("`@("1M97-S86=E(#T@)&5R<F]R+3YG
M971-97-S86=E*"D["@H@("`@("`@(&EF("@A96UP='DH)&5R<F]R+3YB86-K
M=')A8V5;,5U;)V9I;&4G72DI('L*("`@("`@("`@("`@)&UE<W-A9V4@+CT@
M)R`H)R`N("1E<G)O<BT^8F%C:W1R86-E6S%=6R=F:6QE)UT["B`@("`@("`@
M("`@(&EF("@A96UP='DH)&5R<F]R+3YB86-K=')A8V5;,5U;)VQI;F4G72DI
M('L*("`@("`@("`@("`@("`@("1M97-S86=E("X]("<@870@;&EN92`G("X@
M)&5R<F]R+3YB86-K=')A8V5;,5U;)VQI;F4G73L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D;65S<V%G92`N/2`G*2<["B`@("`@("`@?0H*("`@("`@
M("`D;&]G9V5R+3YL;V<H)&UE<W-A9V4L("1E<G)O<BT^8V]D92D["B`@("!]
M"@H@("`@4$5!4CHZ<V5T17)R;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"
M04-++"`G97)R;W)(86YD;&5R)RD["B`@("!014%2.CIR86ES945R<F]R*"=4
M:&ES(&ES(&%N(&EN9F]R;6%T:6]N(&QO9R!M97-S86=E+B<L(%!%05)?3$]'
M7TE.1D\I.PH*+BX@7U!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H*3H@:'1T<#HO
M+W!E87(N<&AP+FYE="]M86YU86PO96XO8V]R92YP96%R+G!E87(N<V5T97)R
M;W)H86YD;&EN9RYP:'`*"@I#=7-T;VT@2&%N9&QE<G,*/3T]/3T]/3T]/3T]
M/3T]"E1H97)E(&%R92!T:6UE<R!W:&5N('1H92!S=&%N9&%R9"!H86YD;&5R
M<R!A<F5N)W0@82!P97)F96-T(&UA=&-H(&9O<B!Y;W5R"FYE961S+B`@26X@
M=&AO<V4@<VET=6%T:6]N<RP@=&AE('-O;'5T:6]N(&UI9VAT(&)E('1O('=R
M:71E(&$@8W5S=&]M(&AA;F1L97(N"@I5<VEN9R!A($-U<W1O;2!(86YD;&5R
M"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2T*57-I;F<@82!C=7-T;VT@3&]G(&AA
M;F1L97(@:7,@=F5R>2!S:6UP;&4N("!/;F-E('=R:71T96X@*'-E92!@5W)I
M=&EN9R!.97<*2&%N9&QE<G-@7R!A;F0@8$5X=&5N9&EN9R!%>&ES=&EN9R!(
M86YD;&5R<V!?(&)E;&]W*2P@>6]U(&AA=F4@=&AE(&-H;VEC92!O9@IP;&%C
M:6YG('1H92!F:6QE(&EN('EO=7(@4$5!4B!I;G-T86QL871I;VXG<R!M86EN
M(&!@3&]G+V!@(&1I<F5C=&]R>2`H=7-U86QL>0IS;VUE=&AI;F<@;&EK92!@
M8"]U<W(O;&]C86PO;&EB+W!H<"],;V=@8"!O<B!@8$,Z7'!H<%QP96%R7$QO
M9V!@*2P@=VAE<F4@:70*8V%N(&)E(&9O=6YD(&%N9"!U<V4@8GD@86YY(%!(
M4"!A<'!L:6-A=&EO;B!O;B!T:&4@<WES=&5M+"!O<B!P;&%C:6YG('1H92!F
M:6QE"G-O;65W:&5R92!I;B!Y;W5R(&%P<&QI8V%T:6]N)W,@;&]C86P@:&EE
M<F%R8VAY(&%N9"!I;F-L=61I;F<@:70@8F5F;W)E('1H90IT:&4@8W5S=&]M
M($QO9R!O8FIE8W0@:7,@8V]N<W1R=6-T960N"@I-971H;V0@,3H@2&%N9&QE
M<B!I;B!T:&4@4W1A;F1A<F0@3&]C871I;VX*?GY^?GY^?GY^?GY^?GY^?GY^
M?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^"D%F=&5R(&-O<'EI;F<@=&AE(&AA
M;F1L97(@9FEL92!T;R!Y;W5R(%!%05(@:6YS=&%L;&%T:6]N)W,@8&!,;V<O
M8&`@9&ER96-T;W)Y+`IS:6UP;'D@=')E870@=&AE(&AA;F1L97(@87,@:68@
M:70@=V5R92!P87)T(&]F('1H92!S=&%N9&%R9"!D:7-T<FEB=71E9"X@($EF
M"GEO=7(@:&%N9&QE<B!I<R!N86UE9"!@8&-U<W1O;6!@("AA;F0@=&AE<F5F
M;W)E(&EM<&QE;65N=&5D(&)Y(&$@8VQA<W,@;F%M960*8&!,;V=?8W5S=&]M
M8&`I.CH*"B`@("!R97%U:7)E7V]N8V4@)TQO9RYP:'`G.PH*("`@("1L;V=G
M97(@/2`F3&]G.CIF86-T;W)Y*"=C=7-T;VTG+"`G)RP@)T-54U1/32<I.PH*
M"DUE=&AO9"`R.B!(86YD;&5R(&EN(&$@0W5S=&]M($QO8V%T:6]N"GY^?GY^
M?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^"DEF('EO=2!P<F5F
M97(@<W1O<FEN9R!Y;W5R(&AA;F1L97(@:6X@>6]U<B!A<'!L:6-A=&EO;B=S
M(&QO8V%L(&AI97)A<F-H>2P*>6]U)VQL(&YE960@=&\@:6YC;'5D92!T:&%T
M(&9I;&4@8F5F;W)E('EO=2!C86X@8W)E871E(&$@3&]G(&EN<W1A;F-E(&)A
M<V5D(&]N"FET+@H*.CH*"B`@("!R97%U:7)E7V]N8V4@)TQO9RYP:'`G.PH@
M("`@<F5Q=6ER95]O;F-E("=,;V-A;$AA;F1L97)S+V-U<W1O;2YP:'`G.PH*
M("`@("1L;V=G97(@/2`F3&]G.CIF86-T;W)Y*"=C=7-T;VTG+"`G)RP@)T-5
M4U1/32<I.PH*"E=R:71I;F<@3F5W($AA;F1L97)S"BTM+2TM+2TM+2TM+2TM
M+2TM+2TM"@I43T1/"@I%>'1E;F1I;F<@17AI<W1I;F<@2&%N9&QE<G,*+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"@I43T1/"@H*+BX@?')E<75I<F5D
M?"!R97!L86-E.CH@*BI;<F5Q=6ER961=*BH*"BXN('9I;3H@=&%B<W1O<#TT
M('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT(&5X<&%N9'1A8B!T97AT=VED
M=&@]-S@@9G0]<G-T.@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O9&]C<R].971?1E10+P``````````````````````````
M````````````````````````````````````````````````,#`P,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W,S8`,#(P-S<U
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TYE=%]&5%`O97AA
M;7!L92\`````````````````````````````````````````````````````
M```````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#4Q-30S,S<S-@`P,C(T,S``(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+V1O8W,O3F5T7T944"]E>&%M<&QE+V5X=&5N<VEO;G,N:6YI````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,C$S`#$P-3$U-#,S-S,V`#`R-3,R-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````[(%1H:7,@9FEL92!C
M86X@9&5T97)M:6YE(&9I;&4M97AT96YS:6]N(&%N9"!W971H97(@=&\@=')A
M;G-F97(@=&AE;2!I;B`*.R!B:6YA<GDM(&]R(&%S8VEI+6UO9&4N(%1H92!T
M=V\@9&EF9F5R96YT('9A;'5E<R!F;W(@9FEL92UM;V1E<R!A<F4Z"CL*.R!&
M5%!?05-#24D@*'=H:6-H(&5Q=6%L<R`P*0H[($944%]"24Y!4ED@*'=H:6-H
M(&5Q=6%L<R`Q*0H["CL@5&AI<R!F:6QE('=I;&P@8F4@9&ER96-T;'D@<&%R
M<V5D(&)Y('!A<G-E7VEN:5]F:6QE*"DL('-O(&)E=V%R92!O9B!M86MI;F<@
M;6ES=&%K97,*.R!I;G-I9&4@=&AI<R!F:6QE+"!O<B!Y;W5R(&%P<&QI8V%T
M:6]N(&UA>2!C<F%S:"P@979E<GET:6UE('EO=2!P87)S92!Y;W5R(&9I;&4N
M"CL*.R!9;W4@8V%N(&AA=F4@;6]R92!T:&%N(#$@9FEL92!C;VYT86EN:6YG
M(&5X=&5N<VEO;BUS971T:6YG<RP@9F]R(&1I9F9E<F5N="!K:6YD<R!O9@H[
M(&%P<&QI8V%T:6]N+"!S97)V97(@;W(@8V%S92X@0G5T(&)E=V%R92P@:68@
M>6]U)W9E('!A<G-E9"!A(&9I;&4@:6YT;R!Y;W5R($YE=%]&5%`M;V)J96-T
M+`H[(&%N9"!A9G1E<B!T:&%T('EO=2!P87)S92!A;F]T:&5R(&9I;&4L('1H
M92!O;&0@<V5T=&EN9W,@=VEL;"!B92!O=F5R=W)I=&5N(0H["CL@05-#24DM
M17AT96YS:6]N<SH*"EM!4T-)25T*"F%S8R`](#`*87-C>"`](#`*87-P(#T@
M,`IA<W!X(#T@,`IB87,@/2`P"F)A<V@@/2`P"F)A="`](#`*8R`](#`*8V9C
M(#T@,`IC9FT@/2`P"F-G:2`](#`*8VQA<W,@/2`P"F-O;F8@/2`P"F-S<R`]
M(#`*:"`](#`*:&AC(#T@,`IH:&L@/2`P"FAP<"`](#`*:'1A(#T@,`IH=&T@
M/2`P"FAT;6P@/2`P"FEN8R`](#`*;F9O(#T@,`II;FD@/2`P"FEN9B`](#`*
M:F%V(#T@,`IJ879A(#T@,`IJ<R`](#`*:G-P(#T@,`IL;V<@/2`P"FYF;R`]
M(#`*<&%S(#T@,`IP:'`@/2`P"G!H<#,@/2`P"G!H<#0@/2`P"G!H=&UL(#T@
M,`IP;"`](#`*<W9G(#T@,`IS:"`](#`*<VAT;6P@/2`P"G1C;"`](#`*=&5X
M="`](#`*='AT(#T@,`IV8B`](#`*=F)S(#T@,`IW;6P@/2`P"GAH=&T@/2`P
M"GAH=&UL(#T@,`IX;6P@/2`P"GAS9"`](#`*>'-L(#T@,`IX<VP@/2`P"GAS
M;'0@/2`P"GAU;"`](#`*"CL@0DE.05)9+45X=&5N<VEO;G,*"EM"24Y!4EE=
M"@IJ<&<@/2`Q"F=I9B`](#$*8FUP(#T@,0``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R].971?1E10+V5X86UP;&4O
M:6YD97@N<&AP````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3(S,#,`,3`U,34T
M,S,W,S8`,#(T,C0W`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"@HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O
M<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J($YE
M=%]&5%`@9V5N97)A;"!E>&%M<&QE+@H@*@H@*B!'96YE<F%L(&5X86UP;&4@
M9FEL92!F;W(@=&AE('5S86=E(&]F($YE=%]&5%`N"B`J"B`J(%!(4"!V97)S
M:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*
M("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@
M;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N
M;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!.971W;W)K:6YG
M"B`J($!P86-K86=E("`@($944`H@*B!`875T:&]R("`@("!4;V)I87,@4V-H
M;&ET="`\=&]B>4!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@
M5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I
M;VX@("`@0U93.B`D260Z(&EN9&5X+G!H<"QV(#$N-"`R,#`U+S`R+S(S(#$R
M.C$R.C(S('1O8GD@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+TYE=%]&5%`*("H@0'-I;F-E("`@("`@1FEL92!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C`N,0H@*B\*"G)E<75I<F5?;VYC
M92`G3F5T+T944"YP:'`G.PIR97%U:7)E7V]N8V4@)U9A<E]$=6UP+G!H<"<[
M"@HO*BH*("H@4V5T=&EN9R!U<"!T97-T('9A<FEA8FQE<RX@5&AE(&9O;&QO
M=VEN9R!V87)I86)L97,@:&%V92!T;R!B92!S970*("H@=7`L('1O('-U:71E
M('1H92!N965D<R!O9B!Y;W5R(&5N=FER;VYM96YT+@H@*B\*"B1H;W-T("`@
M("`@("`@("`]("<G.PHD<&]R="`@("`@("`@("`@/2`R,3L*)'5S97(@("`@
M("`@("`@(#T@)R<["B1P87-S("`@("`@("`@("`]("<G.PH*+R\@5&AE(&QO
M8V%L(&)A<V4@9&ER96-T;W)Y(&9O<B!&5%`@;W!E<F%T:6]N<RX*)&)A<V5$
M:7(@("`@("`@(#T@)RXO=&5S="\G.PHO+R!4:&4@9&ER96-T;W)Y('1O('5P
M;&]A9"!T;R!T:&4@1E10('-E<G9E<B!F;W(@=&5S=&EN9RX*)'1E<W15<$1I
M<B`@("`@(#T@)W1E<W1?=7`O)SL*+R\@5&AE(&1I<F5C=&]R>2!T;R!D;W=N
M;&]A9"!T;R!F;W(@=&5S=&EN9RX*)'1E<W1$;W=N1&ER("`@(#T@)W1E<W1?
M9&]W;B\G.PHO+R!4:&4@9FEL92!F;W(@<VEN9VQE(&9I;&4@=7`M(&%N9"!D
M;W=N;&]A9"!T97-T:6YG+@HD<VEN9VQE5&5S=$9I;&4@/2`G=&5S="YZ:7`G
M.PH*+R\@26YI=&EA;&EZ:6YG(%9A<E]687)?1'5M<#HZ9&ES<&QA>0II9B`H
M:7-S970H)%]315)615(I*2!["B`@("`O+R!3971U<"!F;W(@9&ES<&QA>6EN
M9R!82%1-3"!O=71P=70N"B`@("!687)?1'5M<#HZ9&ES<&QA>4EN:70H87)R
M87DH"B`@("`@("`@)V1I<W!L87E?;6]D92<]/B=82%1-3%]497AT)PH@("`@
M*2P@87)R87DH"B`@("`@("`@)VUO9&4G/3XG;F]R;6%L)RP*("`@("`@("`G
M;V9F<V5T)ST^-`H@("`@*2D["B`@("`O+R!(96%D;&EN92!F=6YC=&EO;B!F
M;W(@6$A434P@;W5T<'5T+@H@("`@9G5N8W1I;VX@:&5A9"`H("1T97AT("D@
M>PH@("`@("`@(&5C:&\@)SQB<B`O/CQB/B<N)'1E>'0N)SPO8CX\8G(@+SXG
M.PH@("`@?0I](&5L<V4@>PH@("`@+R\@4V5T=7`@9F]R(&1I<W!L87EI;F<@
M8V]N<V]L92!O=71P=70N"B`@("!687)?1'5M<#HZ9&ES<&QA>4EN:70H87)R
M87DH)V1I<W!L87E?;6]D92<]/B=497AT)RDI.PH@("`@+R\@2&5A9&QI;F4@
M9G5N8W1I;VX@9F]R(%A(5$U,(&]U='!U="X*("`@(&9U;F-T:6]N(&AE860@
M*"`D=&5X="`I('L*("`@("`@("!E8VAO(")<;BTM+2`B+B1T97AT+B(@+2TM
M7&XB.PH@("`@?0I]"@IH96%D*")<)&9T<"`](&YE=R!.971?1E10*"D[(BD[
M"B1F='`@/2!N97<@3F5T7T944"@I.PH*:&5A9"@B7"1F='`M/G-E=$AO<W1N
M86UE*"1H;W-T*2(I.PI687)?1'5M<#HZ9&ES<&QA>2@D9G1P+3YS971(;W-T
M;F%M92@D:&]S="DI.PH*:&5A9"@B7"1F='`M/G-E=%!O<G0H)'!O<G0I(BD[
M"E9A<E]$=6UP.CID:7-P;&%Y*"1F='`M/G-E=%!O<G0H)'!O<G0I*3L*"FAE
M860H(EPD9G1P+3YC;VYN96-T*"1H;W-T+"`D<&]R="DB*3L*5F%R7T1U;7`Z
M.F1I<W!L87DH)&9T<"T^8V]N;F5C="@I*3L*"FAE860H(EPD9G1P+3YS9715
M<V5R;F%M92@D=7-E<BDB*3L*5F%R7T1U;7`Z.F1I<W!L87DH)&9T<"T^<V5T
M57-E<FYA;64H)'5S97(I*3L*"FAE860H(EPD9G1P+3YS971087-S=V]R9"AX
M>'@I(BD["E9A<E]$=6UP.CID:7-P;&%Y*"1F='`M/G-E=%!A<W-W;W)D*"1P
M87-S*2D["@IH96%D*")<)&9T<"T^;&]G:6XH)'5S97(L('AX>"DB*3L*5F%R
M7T1U;7`Z.F1I<W!L87DH)&9T<"T^;&]G:6XH)'5S97(L("1P87-S*2D["@IH
M96%D*")<)&9T<"T^<'=D*"DB*3L*5F%R7T1U;7`Z.F1I<W!L87DH)&9T<"T^
M<'=D*"DI.PH*:&5A9"@B7"1F='`M/FQS*&YU;&PL($Y%5%]&5%!?1$E24U]&
M24Q%4RDB*3L*5F%R7T1U;7`Z.F1I<W!L87DH)&9T<"T^;',H;G5L;"P@3D54
M7T944%]$25)37T9)3$53*2D["@IH96%D*")<)&9T<"T^;6MD:7(H)&)A<V5$
M:7(I(BD["E9A<E]$=6UP.CID:7-P;&%Y*"1F='`M/FUK9&ER*"1B87-E1&ER
M*2D["@IH96%D*")<)&9T<"T^8V0H)&)A<V5$:7(I(BD["E9A<E]$=6UP.CID
M:7-P;&%Y*"1F='`M/F-D*"1B87-E1&ER*2D["@IH96%D*")<)&9T<"T^;',H
M;G5L;"P@3D547T944%]205=,25-4*2(I.PI687)?1'5M<#HZ9&ES<&QA>2@D
M9G1P+3YL<RAN=6QL+"!.151?1E107U)!5TQ)4U0I*3L*"FAE860H(EPD9G1P
M+3YP=70H)&)A<V5$:7(D<VEN9VQE5&5S=$9I;&4L("1S:6YG;&5497-T1FEL
M92DB*3L*5F%R7T1U;7`Z.F1I<W!L87DH)&9T<"T^<'5T*"1B87-E1&ER+B1S
M:6YG;&5497-T1FEL92P@)'-I;F=L951E<W1&:6QE*2D["@IH96%D*")<)&9T
M<"T^;',H;G5L;"P@3D547T944%]&24Q%4U]/3DQ9*2(I.PI687)?1'5M<#HZ
M9&ES<&QA>2@D9G1P+3YL<RAN=6QL+"!.151?1E107T9)3$537T].3%DI*3L*
M"FAE860H(EPD9G1P+3YP=70H)&)A<V5$:7(D<VEN9VQE5&5S=$9I;&4L("1S
M:6YG;&5497-T1FEL92P@=')U92DB*3L*5F%R7T1U;7`Z.F1I<W!L87DH)&9T
M<"T^<'5T*"1B87-E1&ER+B1S:6YG;&5497-T1FEL92P@)'-I;F=L951E<W1&
M:6QE+"!T<G5E*2D["@IH96%D*")<)&9T<"T^;',H;G5L;"P@3D547T944%]&
M24Q%4U]/3DQ9*2(I.PI687)?1'5M<#HZ9&ES<&QA>2@D9G1P+3YL<RAN=6QL
M+"!.151?1E107T9)3$537T].3%DI*3L*"FAE860H(EPD9G1P+3YM9'1M*"1S
M:6YG;&5497-T1FEL92P@)V0N;2Y9($@Z:3IS)RDB*3L*5F%R7T1U;7`Z.F1I
M<W!L87DH)&9T<"T^;61T;2@D<VEN9VQE5&5S=$9I;&4L("=D+FTN62<I*3L*
M"FAE860H(EPD9G1P+3YS:7IE*"1S:6YG;&5497-T1FEL92DB*3L*5F%R7T1U
M;7`Z.F1I<W!L87DH)&9T<"T^<VEZ92@D<VEN9VQE5&5S=$9I;&4I*3L*"FAE
M860H(EPD9G1P+3YG970H)'-I;F=L951E<W1&:6QE+"`D8F%S941I<B1S:6YG
M;&5497-T1FEL92P@=')U92DB*3L*5F%R7T1U;7`Z.F1I<W!L87DH)&9T<"T^
M9V5T*"1S:6YG;&5497-T1FEL92P@)&)A<V5$:7(N)'-I;F=L951E<W1&:6QE
M+"!T<G5E*2D["@IH96%D*")<)&9T<"T^8VAM;V0H)'-I;F=L951E<W1&:6QE
M+"`W,#`I(BD["E9A<E]$=6UP.CID:7-P;&%Y*"1F='`M/F-H;6]D*"1S:6YG
M;&5497-T1FEL92P@-S`P*2D["@IH96%D*")<)&9T<"T^;',H;G5L;"P@3D54
M7T944%]&24Q%4U]/3DQ9*2(I.PI687)?1'5M<#HZ9&ES<&QA>2@D9G1P+3YL
M<RAN=6QL+"!.151?1E107T9)3$537T].3%DI*3L*"FAE860H(EPD9G1P+3YC
M9"@G+BXO)RDB*3L*5F%R7T1U;7`Z.F1I<W!L87DH)&9T<"T^8V0H)RXN+R<I
M*3L*"FAE860H(EPD9G1P+3YC:&UO9%)E8W5R<VEV92@D8F%S941I<BP@-S<W
M*2(I.PI687)?1'5M<#HZ9&ES<&QA>2@D9G1P+3YC:&UO9%)E8W5R<VEV92@D
M8F%S941I<BP@-S<W*2D["@IH96%D*")<)&9T<"T^;',H;G5L;"P@3D547T94
M4%]$25)37T].3%DI(BD["E9A<E]$=6UP.CID:7-P;&%Y*"1F='`M/FQS*&YU
M;&PL($Y%5%]&5%!?1$E24U]/3DQ9*2D["@IH96%D*")<)&9T<"T^<'5T4F5C
M=7)S:79E*"1B87-E1&ER)'1E<W15<$1I<BP@)&)A<V5$:7(D=&5S=%5P1&ER
M*2(I.PI687)?1'5M<#HZ9&ES<&QA>2@D9G1P+3YP=71296-U<G-I=F4H)&)A
M<V5$:7(N)'1E<W15<$1I<BP@)&)A<V5$:7(N)'1E<W15<$1I<BDI.PH*:&5A
M9"@B7"1F='`M/G!U=%)E8W5R<VEV92@D8F%S941I<B1T97-T57!$:7(L("1B
M87-E1&ER)'1E<W15<$1I<BDB*3L*5F%R7T1U;7`Z.F1I<W!L87DH)&9T<"T^
M<'5T4F5C=7)S:79E*"1B87-E1&ER+B1T97-T57!$:7(L("1B87-E1&ER+B1T
M97-T57!$:7(L('1R=64I*3L*"FAE860H(EPD9G1P+3YC9"@D8F%S941I<CHD
M=&5S=%5P1&ER*2(I.PI687)?1'5M<#HZ9&ES<&QA>2@D9G1P+3YC9"@D8F%S
M941I<BXD=&5S=%5P1&ER*2D["@IH96%D*")<)&9T<"T^;',H;G5L;"P@3D54
M7T944%]$25)37T9)3$53*2(I.PI687)?1'5M<#HZ9&ES<&QA>2@D9G1P+3YL
M<RAN=6QL+"!.151?1E107T1)4E-?1DE,15,I*3L*"FAE860H(EPD9G1P+3YC
M9"@N+B\N+B\I(BD["E9A<E]$=6UP.CID:7-P;&%Y*"1F='`M/F-D*"<N+B\N
M+B\G*2D["@IH96%D*")<)&9T<"T^9V5T4F5C=7)S:79E*"1B87-E1&ER)'1E
M<W15<$1I<BP@)&)A<V5$:7(D=&5S=$1O=VY$:7(I(BD["E9A<E]$=6UP.CID
M:7-P;&%Y*"1F='`M/F=E=%)E8W5R<VEV92@D8F%S941I<BXD=&5S=%5P1&ER
M+"`D8F%S941I<BXD=&5S=$1O=VY$:7(L('1R=64I*3L*"FAE860H(EPD9G1P
M+3YR;2@D8F%S941I<BP@=')U92DB*3L*5F%R7T1U;7`Z.F1I<W!L87DH)&9T
M<"T^<FTH)&)A<V5$:7(L('1R=64I*3L*"FAE860H(EPD9G1P+3YL<RAN=6QL
M+"!.151?1E107T1)4E-?3TY,62DB*3L*5F%R7T1U;7`Z.F1I<W!L87DH)&9T
M<"T^;',H;G5L;"P@3D547T944%]$25)37T].3%DI*3L*"FAE860H(EPD9G1P
M+3YD:7-C;VYN96-T*"DB*3L*5F%R7T1U;7`Z.F1I<W!L87DH)&9T<"T^9&ES
M8V]N;F5C="@I*3L*/SX*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O9&]C<R].971?1E10+V5X86UP;&4O;V)S97)V97(N<&AP````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,3,P-S(`,3`U,34T,S,W,S8`,#(T-S<S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP#0H-"B\J
M('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O
M9G1T86)S=&]P/30Z("HO#0H-"B\J*@T*("H@3F5T7T944"!O8G-E<G9E<B!E
M>&%M<&QE+@T*("H-"B`J($YE="!&5%`@3V)S97)V97(@97AA;7!L92!T;R!U
M<V4@=VET:"!(5$U,7U!R;V=R97-S('!A8VMA9V4-"B`J("A02%`@-"`^/2!0
M2%`@-"XS+C`I#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@
M*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R
M<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL
M86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W
M:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE
M(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O
M=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS
M94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E
M;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@3F5T=V]R:VEN9PT*("H@0'!A8VMA
M9V4@("`@1E10#0H@*B!`875T:&]R("`@("!4;V)I87,@4V-H;&ET="`\=&]B
M>4!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@3&%U<F5N="!,879I;&QE(#QP
M96%R0&QA=7)E;G0M;&%V:6QL92YO<F<^#0H@*B!`8V]P>7)I9VAT("`Q.3DW
M+3(P,#4@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@
M*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@;V)S97)V97(N<&AP+'8@,2XR(#(P
M,#4O,#(O,C,@,3(Z,3(Z,C,@=&]B>2!%>'`@)`T*("H@0&QI;FL@("`@("`@
M:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+TYE=%]&5%`-"B`J($!L:6YK
M("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92](5$U,7U!R;V=R
M97-S#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE
M87-E(#$N,RXP#0H@*B\-"@T*<F5Q=6ER95]O;F-E("=.970O1E10+G!H<"<[
M#0IR97%U:7)E7V]N8V4@)TYE="]&5%`O3V)S97)V97(N<&AP)SL-"G)E<75I
M<F5?;VYC92`G2%1-3"]0<F]G<F5S<RYP:'`G.PT*#0HO*BH-"B`J($EN:71I
M86QI>FEN9R!T97-T('9A<FEA8FQE<R`H<F5Q=6ER960A*0T*("HO#0HD9G1P
M(#T@87)R87DH#0H@("`@)VAO<W0G(#T^("<G+`T*("`@("=P;W)T)R`]/B`R
M,2P-"B`@("`G=7-E<B<@/3X@)R<L#0H@("`@)W!A<W,G(#T^("<G#0HI.R`@
M("`-"@T*)&1E<W0@/2`G=&UP)SL@("`@("`@("`@("`@("`@("`@+R\@=&AI
M<R!D:7)E8W1O<GD@;75S="!E>&ES=',@:6X@>6]U<B!F='`@<V5R=F5R("$-
M"B1O=F5R=W)I=&4@/2!T<G5E.R`@("`@("`@("`@("`@("\O(&]V97)W<FET
M92!A;&P@97AI<W1I;F<@9FEL97,@;VX@=&AE(&9T<"!S97)V97(-"B1F:6QE
M<R`](&%R<F%Y*`T*("`@("=(5$U,7U!R;V=R97-S+3$N,BXP+G1G>B<L#0H@
M("`@)W!H<#1E=F5R+G!N9R<@("`@("`@("`@("`@("`O+R!I;FET:6%L:7II
M;F<@8V]N=&5N=',@*')E<75I<F5D(2D@9FEL92AS*2!M=7-T(&5X:7-T<PT*
M*3L@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@9FEL92AS*2!T
M;R!U<&QO860-"@T*#0HO+PT*+R\@,2X@1&5F:6YE<R!T:&4@1E10+U!R;V=R
M97-S($]B<V5R=F5R(`T*+R\-"F-L87-S($]B<V5R=F5R7U!R;V=R97-S57!L
M;V%D(&5X=&5N9',@3F5T7T944%]/8G-E<G9E<@T*>PT*("`@('9A<B`D<')O
M9W)E<W,[#0H-"B`@("!F=6YC=&EO;B!/8G-E<G9E<E]0<F]G<F5S<U5P;&]A
M9"@F)'!R;V=R97-S*0T*("`@('L-"B`@("`@("`@+RH@0V%L;"!T:&4@8F%S
M92!C;&%S<R!C;VYS=')U8W1O<BX@*B\-"B`@("`@("`@<&%R96YT.CI.971?
M1E107T]B<V5R=F5R*"D[#0H-"B`@("`@("`@+RHJ#0H@("`@("`@("`@($-O
M;F9I9W5R92!T:&4@;V)S97)V97(Z#0H@("`@("`@("`@(`T*("`@("`@("`@
M("!"92!S=7)E('1O(&AA=F4@86X@:6YD971E<FUI;F%T92!P<F]G<F5S<R!M
M971E<B!W:&5N#0H@("`@("`@("`@($!L:6YK(&AT='`Z+R]W=W<N<&AP+FYE
M="]M86YU86PO96XO9G5N8W1I;VXN9G1P+6YB+7!U="YP:'`-"B`@("`@("`@
M("`@<W1O<F5S(&$@9FEL92!O;B!T:&4@1E10('-E<G9E<B`H;F]N+6)L;V-K
M:6YG*0T*("`@("`@("`@*B\-"B`@("`@("`@)'1H:7,M/G!R;V=R97-S(#TF
M("1P<F]G<F5S<SL-"B`@("`@("`@)'1H:7,M/G!R;V=R97-S+3YS971);F1E
M=&5R;6EN871E*'1R=64I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&YO=&EF
M>2@D979E;G0I#0H@("`@>PT*("`@("`@("`D=&AI<RT^<')O9W)E<W,M/F1I
M<W!L87DH*3L-"B`@("`@("`@)'1H:7,M/G!R;V=R97-S+3YS;&5E<"@I.PT*
M("`@("`@("`@("`@("`@("`-"B`@("`@("`@:68@*"1T:&ES+3YP<F]G<F5S
M<RT^9V5T4&5R8V5N=$-O;7!L971E*"D@/3T@,2D@>PT*("`@("`@("`@("`@
M)'1H:7,M/G!R;V=R97-S+3YS971686QU92@P*3L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1T:&ES+3YP<F]G<F5S<RT^:6YC5F%L=64H*3L-
M"B`@("`@("`@?0T*("`@('T-"GT-"@T*+R\-"B\O(#(N(&1E9FEN97,@=&AE
M('!R;V=R97-S(&UE=&5R(`T*+R\-"B1M971E<B`](&YE=R!(5$U,7U!R;V=R
M97-S*"D[#0HD=6D@/2`F("1M971E<BT^9V5T54DH*3L-"B1U:2T^<V5T4')O
M9W)E<W-!='1R:6)U=&5S*&%R<F%Y*`T*("`@("=B86-K9W)O=6YD+6-O;&]R
M)R`]/B`G(V4P93!E,"<-"BDI.R`@("`@("`@#0HD=6DM/G-E=%-T<FEN9T%T
M=')I8G5T97,H87)R87DH#0H@("`@)V-O;&]R)R`@/3X@)R,Y.38G+`T*("`@
M("=B86-K9W)O=6YD+6-O;&]R)R`]/B`G(T-#0T,Y.2<-"BDI.R`@("`@("`@
M#0HD=6DM/G-E=$-E;&Q!='1R:6)U=&5S*&%R<F%Y*`T*("`@("=A8W1I=F4M
M8V]L;W(G(#T^("<C.3DV)PT**2D[#0H-"B1M971E<BT^<V5T06YI;5-P965D
M*#(P,"D[#0HD;65T97(M/G-E=$EN8W)E;65N="@Q,"D[#0HD;65T97(M/G-E
M=%-T<FEN9U!A:6YT960H=')U92D[("`@("`O+R!G970@<W!A8V4@9F]R('1H
M92!S=')I;F<-"B1M971E<BT^<V5T4W1R:6YG*"(B*3L@("`@("`@("`@("`@
M("\O(&)U="!D;VXG="!P86EN="!I=`T*)&UE=&5R+3YS971);F1E=&5R;6EN
M871E*'1R=64I.R`@("`@+R\@<')O9W)E<W,@;65T97(@<W1A<G0@:6X@:6YD
M971E<FUI;F%T92!M;V1E#0H_/@T*/"%$3T-465!%(&AT;6P@4%5"3$E#("(M
M+R]7,T,O+T141"!82%1-3"`Q+C`@5')A;G-I=&EO;F%L+R]%3B(-"B`@("`B
M:'1T<#HO+W=W=RYW,RYO<F<O5%(O>&AT;6PQ+T141"]X:'1M;#$M=')A;G-I
M=&EO;F%L+F1T9"(^#0H\:'1M;"!X;6QN<STB:'1T<#HO+W=W=RYW,RYO<F<O
M,3DY.2]X:'1M;"(^#0H\:&5A9#X-"CQT:71L93Y&5%`O4')O9W)E<W,@3V)S
M97)V97(@97AA;7!L93PO=&ET;&4^#0H\<W1Y;&4@='EP93TB=&5X="]C<W,B
M/@T*/"$M+0T*8F]D>2![#0H@("`@8F%C:V=R;W5N9"UC;VQO<CH@(T-#0T,Y
M.3L-"B`@("!C;VQO<CH@(SDY-CL-"B`@("!F;VYT+69A;6EL>3H@5F5R9&%N
M82P@07)I86P[#0I]#0H-"CP_<&AP(&5C:&\@)&UE=&5R+3YG9713='EL92@I
M.R`_/@T*+R\@+2T^#0H\+W-T>6QE/@T*/'-C<FEP="!T>7!E/2)T97AT+VIA
M=F%S8W)I<'0B/@T*/"$M+0T*/#]P:'`@96-H;R`D;65T97(M/F=E=%-C<FEP
M="@I.R`_/@T*+R\M+3X-"CPO<V-R:7!T/@T*/"]H96%D/@T*/&)O9'D^#0H-
M"CP_<&AP(`T*96-H;R`D;65T97(M/G1O2'1M;"@I.PT*0'-E=%]T:6UE7VQI
M;6ET*#`I.R`@+R\@=6YL:6UI=&5D('1I;64@;W!E<F%T:6]N("AR96UO=F5D
M(#,P<R!D969A=6QT(')E<W1R:6-T:6]N*0T*#0HD9B`](&YE=R!.971?1E10
M*"D[#0H-"B\O#0HO+R`S+B!C;VYN96-T('1O('1H92!&5%`@<V5R=F5R(`T*
M+R\-"B1R970@/2`D9BT^8V]N;F5C="@D9G1P6R=H;W-T)UTL("1F='!;)W!O
M<G0G72D[#0II9B`H4$5!4CHZ:7-%<G)O<B@D<F5T*2D@>PT*("`@(&1I92@D
M<F5T+3YG971-97-S86=E*"DI.PT*?0T*<')I;G1F*"=C;VYN96-T960@870@
M/&(^)7,\+V(^/&)R("\^)RP@)&9T<%LG:&]S="==*3L-"@T*+R\-"B\O(#0N
M(&QO9VEN('1O('1H92!&5%`@<V5R=F5R(&%S(&$@=V5L;"UK;F]W;B!U<V5R
M#0HO+PT*)')E="`]("1F+3YL;V=I;B@D9G1P6R=U<V5R)UTL("1F='!;)W!A
M<W,G72D[#0II9B`H4$5!4CHZ:7-%<G)O<B@D<F5T*2D@>PT*("`@("1F+3YD
M:7-C;VYN96-T*"D[#0H@("`@9&EE*"1R970M/F=E=$UE<W-A9V4H*2D[#0I]
M#0IP<FEN=&8H)VQO9VEN(&%S(#QB/B5S/"]B/CQB<B`O/B<L("1F='!;)W5S
M97(G72D[#0H-"B\O#0HO+R`U+B!C:&%N9V5S(&1I<F5C=&]R>2!T;R!F:6YA
M;"!D97-T:6YA=&EO;B!F;W(@=7!L;V%D(&]P97)A=&EO;@T*+R\-"B1R970@
M/2`D9BT^8V0H)&1E<W0I.PT*:68@*%!%05(Z.FES17)R;W(H)')E="DI('L-
M"B`@("`D9BT^9&ES8V]N;F5C="@I.PT*("`@(&1I92@D<F5T+3YG971-97-S
M86=E*"DI.PT*?0T*#0HO+PT*+R\@-BX@871T86-H<R!A;B!I;G-T86YC92!O
M9B!T:&4@1E10+U!R;V=R97-S('-U8F-L87-S(&]B<V5R=F5R#0HO+PT*)&]B
M<V5R=F5R(#T@;F5W($]B<V5R=F5R7U!R;V=R97-S57!L;V%D*"1M971E<BD[
M#0HD;VL@/2`D9BT^871T86-H*"1O8G-E<G9E<BD[#0II9B`H(21O:RD@>PT*
M("`@(&1I92@G8V%N;F]T(&%T=&%C:"!A($944"!/8G-E<G9E<B<I.PT*?0T*
M#0HO+PT*+R\@-RX@;6]V97,@9FEL97,@;VX@=&AE($944"!S97)V97(-"B\O
M#0IF;W)E86-H*"1F:6QE<R!A<R`D9FEL92D@>PT*("`@("1R970@/2`D9BT^
M<'5T*"1F:6QE+"!B87-E;F%M92@D9FEL92DL("1O=F5R=W)I=&4I.PT*("`@
M(&EF("A014%2.CII<T5R<F]R*"1R970I*2![#0H@("`@"6EF("@H)')E="T^
M9V5T0V]D92@I(#T]($Y%5%]&5%!?15)27T]615)74DE415)%34]4149)3$5?
M1D]20DE$1$5.*2!A;F0@*"$D;W9E<G=R:71E*2D@>PT*("`@(`D@("`@<')I
M;G1F*"<E<R`\8G(@+SXG+"`D<F5T+3YG971-97-S86=E*"DI.PT*("`@(`D@
M("`@8V]N=&EN=64[("`O+R!I="!I<R!J=7-T(&$@=V%R;FEN9R!W:&5N(%PD
M;W9E<G=R:71E('9A<FEA8FQE(&ES('-E="!T;R!F86QS90T*("`@(`E]#0H@
M("`@("`@(&1I92@D<F5T+3YG971-97-S86=E*"DI.PT*("`@('T-"B`@("!P
M<FEN=&8H)SQB/B5S/"]B/B!T<F%N<V9E<B!C;VUP;&5T960@/&)R("\^)RP@
M8F%S96YA;64H)&9I;&4I*3L-"GT-"B1F+3YD971A8V@H)&]B<V5R=F5R*3L-
M"@T*+R\-"B\O(#@N(&-H96-K<R!I9B!F:6QE<R!A<F4@<F5A;&QY(&]N('1H
M92!&5%`@<V5R=F5R#0HO+PT*)')E="`]("1F+3YL<RAN=6QL+"!.151?1E10
M7U)!5TQ)4U0I.PT*:68@*%!%05(Z.FES17)R;W(H)')E="DI('L-"B`@("`D
M9BT^9&ES8V]N;F5C="@I.PT*("`@(&1I92@D<F5T+3YG971-97-S86=E*"DI
M.PT*?0T*<')I;G0@)SQP<F4^)SL-"G9A<E]D=6UP*"1R970I.PT*<')I;G0@
M)SPO<')E/B<[#0H-"B\O#0HO+R`Y+B!S87ES(&=O;V1B>64@=&\@=&AE($94
M4"!S97)V97(@(0T*+R\-"B1F+3YD:7-C;VYN96-T*"D[#0IE8VAO("=$;VYE
M(2<[#0H_/@T*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D
M;V-S+TYE=%]33510+P``````````````````````````````````````````
M```````````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<S-0`P,C$Q,C8`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+V1O8W,O3F5T7U--5%`O9&]C<R\`````````````
M`````````````````````````````````````````````````````#`P,#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S,U`#`R
M,C`U-@`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R].971?4TU4
M4"]D;V-S+V5X86UP;&5S+P``````````````````````````````````````
M````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`U,34T,S,W,S4`,#(S-C<T`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]D;V-S+TYE=%]33510+V1O8W,O97AA;7!L97,O8F%S:6,N<&AP````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,3<V-0`Q,#4Q-30S,S<S-0`P,C4T-S<`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*"G)E
M<75I<F4@)TYE="]33510+G!H<"<["@HD:&]S="`]("=M86EL+F5X86UP;&4N
M8V]M)SL*)&9R;VT@/2`G=7-E<D!E>&%M<&QE+F-O;2<["B1R8W!T(#T@87)R
M87DH)W)E8VEP:65N=#%`97AA;7!L92YC;VTG+"`G<F5C:7!I96YT,D!E>&%M
M<&QE+F-O;2<I.PHD<W5B:B`](")3=6)J96-T.B!497-T($UE<W-A9V5<;B([
M"B1B;V1Y(#T@(D)O9'D@3&EN92`Q7&Y";V1Y($QI;F4@,B(["@HO*B!#<F5A
M=&4@82!N97<@3F5T7U--5%`@;V)J96-T+B`J+PII9B`H(2`H)'-M='`@/2!N
M97<@3F5T7U--5%`H)&AO<W0I*2D@>PH@("`@9&EE*")5;F%B;&4@=&\@:6YS
M=&%N=&EA=&4@3F5T7U--5%`@;V)J96-T7&XB*3L*?0H*+RH@0V]N;F5C="!T
M;R!T:&4@4TU44"!S97)V97(N("HO"FEF("A014%2.CII<T5R<F]R*"1E(#T@
M)'-M='`M/F-O;FYE8W0H*2DI('L*("`@(&1I92@D92T^9V5T365S<V%G92@I
M("X@(EQN(BD["GT*"B\J(%-E;F0@=&AE("=-04E,($923TTZ)R!33510(&-O
M;6UA;F0N("HO"FEF("A014%2.CII<T5R<F]R*"1S;71P+3YM86EL1G)O;2@D
M9G)O;2DI*2!["B`@("!D:64H(E5N86)L92!T;R!S970@<V5N9&5R('1O(#PD
M9G)O;3Y<;B(I.PI]"@HO*B!!9&1R97-S('1H92!M97-S86=E('1O(&5A8V@@
M;V8@=&AE(')E8VEP:65N=',N("HO"F9O<F5A8V@@*"1R8W!T(&%S("1T;RD@
M>PH@("`@:68@*%!%05(Z.FES17)R;W(H)')E<R`]("1S;71P+3YR8W!T5&\H
M)'1O*2DI('L*("`@("`@("!D:64H(E5N86)L92!T;R!A9&0@<F5C:7!I96YT
M(#PD=&\^.B`B("X@)')E<RT^9V5T365S<V%G92@I("X@(EQN(BD["B`@("!]
M"GT*"B\J(%-E="!T:&4@8F]D>2!O9B!T:&4@;65S<V%G92X@*B\*:68@*%!%
M05(Z.FES17)R;W(H)'-M='`M/F1A=&$H)'-U8FH@+B`B7')<;B(@+B`D8F]D
M>2DI*2!["B`@("!D:64H(E5N86)L92!T;R!S96YD(&1A=&%<;B(I.PI]"@HO
M*B!$:7-C;VYN96-T(&9R;VT@=&AE(%--5%`@<V5R=F5R+B`J+PHD<VUT<"T^
M9&ES8V]N;F5C="@I.PH``````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]D;V-S+TYE=%]33510+V1O8W,O9W5I9&4N='AT````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-#,T,@`Q,#4Q-30S,S<S-0`P,C,W,C``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/0H@5&AE($YE=%]33510(%!A8VMA9V4*/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/0H*+2TM+2TM+2TM+2TM+2TM+2TM+2T*(%5S
M97(@1&]C=6UE;G1A=&EO;@HM+2TM+2TM+2TM+2TM+2TM+2TM+0H*.D%U=&AO
M<CH@("`@2F]N(%!A<FES90HZ0V]N=&%C=#H@("!J;VY`<&AP+FYE=`HZ1&%T
M93H@("`@("`D1&%T93H@,C`P-2\P,R\P-"`P,SHS-3HT-2`D"CI2979I<VEO
M;CH@("12979I<VEO;CH@,2XU("0*"BXN(&-O;G1E;G1S.CH@5&%B;&4@;V8@
M0V]N=&5N=',*+BX@<V5C=&EO;BUN=6UB97)I;F<Z.@H*1&5P96YD96YC:65S
M"CT]/3T]/3T]/3T]/0H*5&AE(&!014%27T5R<F]R8"!#;&%S<PHM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM"@I4:&4@3F5T7U--5%`@<&%C:V%G92!U<V5S('1H
M92!@4$5!4E]%<G)O<F!?(&-L87-S(&9O<B!A;&P@;V8@:71S(&!E<G)O<@IH
M86YD;&EN9V!?+@H*5&AE(&!.971?4V]C:V5T8"!086-K86=E"BTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+0H*5&AE($YE=%]3;V-K971?('!A8VMA9V4@:7,@
M=7-E9"!A<R!T:&4@8F%S:7,@9F]R(&%L;"!N971W;W)K(&-O;6UU;FEC871I
M;VYS+@H*5&AE(&!!=71H7U-!4TQ@(%!A8VMA9V4*+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2T*"E1H92!@075T:%]305-,8%\@<&%C:V%G92!I<R!A;B!O<'1I
M;VYA;"!D97!E;F1E;F-Y+B`@268@:70@:7,@879A:6QA8FQE+"!T:&4*3F5T
M7U--5%`@<&%C:V%G92!W:6QL(&)E(&%B;&4@=&\@<W5P<&]R="!T:&4@1$E'
M15-4+4U$-5\@86YD($-204TM340U7R!33510"F%U=&AE;G1I8V%T:6]N(&UE
M=&AO9',N("!/=&AE<G=I<V4L(&]N;'D@=&AE($Q/1TE.7R!A;F0@4$Q!24Y?
M(&UE=&AO9',@=VEL;`IB92!A=F%I;&%B;&4N"@I%<G)O<B!(86YD;&EN9PH]
M/3T]/3T]/3T]/3T]/0H*06QL(&]F('1H92!.971?4TU44"!C;&%S<R=S('!U
M8FQI8R!M971H;V1S(')E='5R;B!A(%!%05)?17)R;W)?(&]B:F5C="!I9B!A
M;@IE<G)O<B!O8V-U<G,N("!4:&4@<W1A;F1A<F0@=V%Y('1O(&-H96-K(&9O
M<B!A(%!%05)?17)R;W(@;V)J96-T(&ES(&)Y('5S:6YG"F!014%2.CII<T5R
M<F]R*"E@7SHZ"@H@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'-M
M='`M/F-O;FYE8W0H*2DI('L*("`@("`@("!D:64H)&5R<F]R+3YG971-97-S
M86=E*"DI.PH@("`@?0H*+BX@7U!%05(Z.FES17)R;W(H*3H@:'1T<#HO+W!E
M87(N<&AP+FYE="]M86YU86PO96XO8V]R92YP96%R+G!E87(N:7-E<G)O<BYP
M:'`*"E--5%`@075T:&5N=&EC871I;VX*/3T]/3T]/3T]/3T]/3T]/3T]/0H*
M5&AE($YE=%]33510('!A8VMA9V4@<W5P<&]R=',@=&AE(%--5%`@875T:&5N
M=&EC871I;VX@<W1A;F1A<F0@*&%S(&1E9FEN960*8GD@4D9#+3(U-31?*2X@
M(%1H92!.971?4TU44"!P86-K86=E('-U<'!O<G1S('1H92!F;VQL;W=I;F<@
M875T:&5N=&EC871I;VX*;65T:&]D<RP@:6X@;W)D97(@;V8@<')E9F5R96YC
M93H*"BXN(%]21D,M,C4U-#H@:'1T<#HO+W=W=RYI971F+F]R9R]R9F,O<F9C
M,C4U-"YT>'0*"D1)1T535"U-1#4*+2TM+2TM+2TM+0H*5&AE($1)1T535"U-
M1#4@875T:&5N=&EC871I;VX@;65T:&]D('5S97,@8%)302!$871A(%-E8W5R
M:71Y($EN8RY@7R=S($U$-0I-97-S86=E($1I9V5S="!A;&=O<FET:&TN("!)
M="!I<R!C;VYS:61E<F5D('1H92!M;W-T('-E8W5R92!M971H;V0@;V8@4TU4
M4`IA=71H96YT:6-A=&EO;BX*"BHJ3F]T93HJ*B!4:&4@1$E'15-4+4U$-2!A
M=71H96YT:6-A=&EO;B!M971H;V0@:7,@;VYL>2!S=7!P;W)T960@:68@=&AE
M"D%55$A?4T%33%\@<&%C:V%G92!I<R!A=F%I;&%B;&4N"@HN+B!?4E-!($1A
M=&$@4V5C=7)I='D@26YC+CH@:'1T<#HO+W=W=RYR<V%S96-U<FET>2YC;VTO
M"@I#4D%-+4U$-0HM+2TM+2TM+0H*5&AE($-204TM340U(&%U=&AE;G1I8V%T
M:6]N(&UE=&AO9"!H87,@8F5E;B!S=7!E<G-E9&5D(&)Y('1H92!$24=%4U0M
M340U7PIM971H;V0@:6X@=&5R;7,@;V8@<V5C=7)I='DN("!)="!I<R!P<F]V
M:61E9"!H97)E(&9O<B!C;VUP871I8FEL:71Y('=I=&@*;VQD97(@4TU44"!S
M97)V97)S('1H870@;6%Y(&YO="!S=7!P;W)T('1H92!N97=E<B!$24=%4U0M
M340U(&%L9V]R:71H;2X*"BHJ3F]T93HJ*B!4:&4@0U)!32U-1#4@875T:&5N
M=&EC871I;VX@;65T:&]D(&ES(&]N;'D@<W5P<&]R=&5D(&EF('1H90I!551(
M7U-!4TQ?('!A8VMA9V4@:7,@879A:6QA8FQE+@H*3$]'24X*+2TM+2T*"E1H
M92!,3T=)3B!A=71H96YT:6-A=&EO;B!M971H;V0@96YC<GEP=',@=&AE('5S
M97(G<R!P87-S=V]R9"!U<VEN9R!T:&4*0F%S938T7R!E;F-O9&EN9R!S8VAE
M;64N("!"96-A=7-E(&1E8W)Y<'1I;F<@82!"87-E-C0M96YC;V1E9"!S=')I
M;F<@:7,*=')I=FEA;"P@3$]'24X@:7,@;F]T(&-O;G-I9&5R960@82!S96-U
M<F4@875T:&5N=&EC871I;VX@;65T:&]D(&%N9"!S:&]U;&0*8F4@879O:61E
M9"X*"BXN(%]"87-E-C0Z(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO
M9G5N8W1I;VXN8F%S938T+65N8V]D92YP:'`*"E!,04E."BTM+2TM"@I4:&4@
M4$Q!24X@875T:&5N=&EC871I;VX@;65T:&]D('-E;F1S('1H92!U<V5R)W,@
M<&%S<W=O<F0@:6X@<&QA:6X@=&5X="X*5&AI<R!M971H;V0@;V8@875T:&5N
M=&EC871I;VX@:7,@;F]T('-E8W5R92!A;F0@<VAO=6QD(&)E(&%V;VED960N
M"@I396-U<F4@0V]N;F5C=&EO;G,*/3T]/3T]/3T]/3T]/3T]/3T]"@I)9B!@
M<V5C=7)E('-O8VME="!T<F%N<W!O<G1S8%\@:&%V92!B965N(&5N86)L960@
M:6X@4$A0+"!I="!I<R!P;W-S:6)L92!T;PIE<W1A8FQI<V@@82!S96-U<F4@
M8V]N;F5C=&EO;B!T;R!T:&4@<F5M;W1E(%--5%`@<V5R=F5R.CH*"B`@("`D
M<VUT<"`](&YE=R!.971?4TU44"@G<W-L.B\O;6%I;"YE>&%M<&QE+F-O;2<L
M(#0V-2D["@I4:&ES(&5X86UP;&4@8V]N;F5C=',@=&\@8&UA:6PN97AA;7!L
M92YC;VU@(&]N('!O<G0@-#8U("AA(&-O;6UO;B!335104PIP;W)T*2!U<VEN
M9R!T:&4@8'-S;#HO+V`@=')A;G-P;W)T+@H*+BX@7W-E8W5R92!S;V-K970@
M=')A;G-P;W)T<SH@:'1T<#HO+W=W=RYP:'`N;F5T+W1R86YS<&]R=',*"D1A
M=&$@475O=&EN9PH]/3T]/3T]/3T]/3T*"D)Y(&1E9F%U;'0L(&%L;"!O=71B
M;W5N9"!S=')I;F<@9&%T82!I<R!Q=6]T960@:6X@86-C;W)D86YC92!W:71H
M(%--5%`*<W1A;F1A<F1S+B`@5&AI<R!M96%N<R!T:&%T(&%L;"!N871I=F4@
M56YI>"`H8%Q<;F`I(&%N9"!-86,@*&!<7')@*2!L:6YE"F5N9&EN9W,@87)E
M(&-O;G9E<G1E9"!T;R!);G1E<FYE="US=&%N9&%R9"!#4DQ&("A@7%QR7%QN
M8"D@;&EN92!E;F1I;F=S+@I!;'-O+"!B96-A=7-E('1H92!33510('!R;W1O
M8V]L('5S97,@82!S:6YG;&4@;&5A9&EN9R!P97)I;V0@*&`N8"D@=&\@<VEG
M;F%L"F%N(&5N9"!T;R!T:&4@;65S<V%G92!D871A+"!S:6YG;&4@;&5A9&EN
M9R!P97)I;V1S(&EN('1H92!O<FEG:6YA;"!D871A"G-T<FEN9R!A<F4@(F1O
M=6)L960B("AE+F<N(")@+BY@(BDN"@I4:&5S92!S=')I;F<@=')A;G-F;W)M
M871I;VX@8V%N(&)E(&5X<&5N<VEV92!W:&5N(&QA<F=E(&)L;V-K<R!O9B!D
M871A(&%R90II;G9O;'9E9"X@($9O<B!E>&%M<&QE+"!T:&4@3F5T7U--5%`@
M<&%C:V%G92!I<R!N;W0@87=A<F4@;V8@34E-12!P87)T<R`H:70*:G5S="!S
M965S('1H92!-24U%(&UE<W-A9V4@87,@;VYE(&)I9R!S=')I;F<@;V8@8VAA
M<F%C=&5R<RDL('-O(&ET(&ES(&YO=`IA8FQE('1O('-K:7`@;F]N+71E>'0@
M871T86-H;65N=',@=VAE;B!S96%R8VAI;F<@9F]R(&-H87)A8W1E<G,@=&AA
M="!M87D*;F5E9"!T;R!B92!Q=6]T960N"@I"96-A=7-E(&]F('1H:7,L(&ET
M(&ES('!O<W-I8FQE('1O(&5X=&5N9"!T:&4@3F5T7U--5%`@8VQA<W,@:6X@
M;W)D97(@=&\*:6UP;&5M96YT('EO=7(@;W=N(&-U<W1O;2!Q=6]T:6YG(')O
M=71I;F4N("!*=7-T(&-R96%T92!A(&YE=R!C;&%S<R!B87-E9"!O;@IT:&4@
M3F5T7U--5%`@8VQA<W,@86YD(')E:6UP;&5M96YT('1H92!@<75O=&5D871A
M*"E@(&UE=&AO9#HZ"@H@("`@<F5Q=6ER92`G3F5T7U--5%`N<&AP)SL*"B`@
M("!C;&%S<R!.971?4TU44%]C=7-T;VT@97AT96YD<R!.971?4TU44`H@("`@
M>PH@("`@("`@(&9U;F-T:6]N('%U;W1E9&%T82@D9&%T82D*("`@("`@("![
M"B`@("`@("`@("`@("\J(%!E<F9O<FT@8W5S=&]M(&1A=&$@<75O=&EN9R`J
M+PH@("`@("`@('T*("`@('T*"DYO=&4@=&AA="!T:&4@8"1D871A8"!P87)A
M;65T97(@=VEL;"!B92!P87-S960@=&\@=&AE(&!Q=6]T961A=&$H*6`@9G5N
M8W1I;VX*8&)Y(')E9F5R96YC96!?+B`@5&AI<R!M96%N<R!T:&%T('EO=2!C
M86X@;W!E<F%T92!D:7)E8W1L>2!O;B!@)&1A=&%@+B`@270*86QS;R!T:&4@
M;W9E<FAE860@;V8@8V]P>6EN9R!A(&QA<F=E(&`D9&%T86`@<W1R:6YG('1O
M(&%N9"!F<F]M('1H90I@<75O=&5D871A*"E@(&UE=&AO9"X*"BXN(%]B>2!R
M969E<F5N8V4Z(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO;&%N9W5A
M9V4N<F5F97)E;F-E<RYP87-S+G!H<`H*1&5B=6=G:6YG"CT]/3T]/3T]/0H*
M5&AE($YE=%]33510('!A8VMA9V4@8V]N=&%I;G,@8G5I;'0M:6X@9&5B=6=G
M:6YG(&]U='!U="!R;W5T:6YE<R`H9&ES86)L960*8GD@9&5F875L="DN("!$
M96)U9V=I;F<@;W5T<'5T(&UU<W0@8F4@97AP;&EC:71L>2!E;F%B;&5D('9I
M82!T:&4@<V5T1&5B=6<H*0IM971H;V0Z.@H*("`@("1S;71P+3YS971$96)U
M9RAT<G5E*3L*"E1H92!D96)U9V=I;F<@;65S<V%G97,@=VEL;"!B92!S96YT
M('1O('1H92!S=&%N9&%R9"!O=71P=70@<W1R96%M+@H*17AA;7!L97,*/3T]
M/3T]/3T*"D)A<VEC(%5S90HM+2TM+2TM+2T*"E1H92!F;VQL;W=I;F<@<V-R
M:7!T(&1E;6]N<W1R871E<R!H;W<@82!S:6UP;&4@96UA:6P@;65S<V%G92!C
M86X@8F4@<V5N=`IU<VEN9R!T:&4@3F5T7U--5%`@<&%C:V%G93HZ"@H@("`@
M<F5Q=6ER92`G3F5T+U--5%`N<&AP)SL*"B`@("`D:&]S="`]("=M86EL+F5X
M86UP;&4N8V]M)SL*("`@("1F<F]M(#T@)W5S97)`97AA;7!L92YC;VTG.PH@
M("`@)')C<'0@/2!A<G)A>2@G<F5C:7!I96YT,4!E>&%M<&QE+F-O;2<L("=R
M96-I<&EE;G0R0&5X86UP;&4N8V]M)RD["B`@("`D<W5B:B`](")3=6)J96-T
M.B!497-T($UE<W-A9V5<;B(["B`@("`D8F]D>2`](")";V1Y($QI;F4@,5QN
M0F]D>2!,:6YE(#(B.PH*("`@("\J($-R96%T92!A(&YE=R!.971?4TU44"!O
M8FIE8W0N("HO"B`@("!I9B`H(2`H)'-M='`@/2!N97<@3F5T7U--5%`H)&AO
M<W0I*2D@>PH@("`@("`@(&1I92@B56YA8FQE('1O(&EN<W1A;G1I871E($YE
M=%]33510(&]B:F5C=%QN(BD["B`@("!]"@H@("`@+RH@0V]N;F5C="!T;R!T
M:&4@4TU44"!S97)V97(N("HO"B`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]
M("1S;71P+3YC;VYN96-T*"DI*2!["B`@("`@("`@9&EE*"1E+3YG971-97-S
M86=E*"D@+B`B7&XB*3L*("`@('T*"B`@("`O*B!396YD('1H92`G34%)3"!&
M4D]-.B<@4TU44"!C;VUM86YD+B`J+PH@("`@:68@*%!%05(Z.FES17)R;W(H
M)'-M='`M/FUA:6Q&<F]M*"1F<F]M*2DI('L*("`@("`@("!D:64H(E5N86)L
M92!T;R!S970@<V5N9&5R('1O(#PD9G)O;3Y<;B(I.PH@("`@?0H*("`@("\J
M($%D9')E<W,@=&AE(&UE<W-A9V4@=&\@96%C:"!O9B!T:&4@<F5C:7!I96YT
M<RX@*B\*("`@(&9O<F5A8V@@*"1R8W!T(&%S("1T;RD@>PH@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1R97,@/2`D<VUT<"T^<F-P=%1O*"1T;RDI*2![
M"B`@("`@("`@("`@(&1I92@B56YA8FQE('1O(&%D9"!R96-I<&EE;G0@/"1T
M;SXZ("(@+B`D<F5S+3YG971-97-S86=E*"D@+B`B7&XB*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RH@4V5T('1H92!B;V1Y(&]F('1H92!M97-S86=E+B`J
M+PH@("`@:68@*%!%05(Z.FES17)R;W(H)'-M='`M/F1A=&$H)'-U8FH@+B`B
M7')<;B(@+B`D8F]D>2DI*2!["B`@("`@("`@9&EE*")5;F%B;&4@=&\@<V5N
M9"!D871A7&XB*3L*("`@('T*"B`@("`O*B!$:7-C;VYN96-T(&9R;VT@=&AE
M(%--5%`@<V5R=F5R+B`J+PH@("`@)'-M='`M/F1I<V-O;FYE8W0H*3L*"BXN
M(%]014%27T5R<F]R.B!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]C
M;W)E+G!E87(N<&5A<BUE<G)O<BYP:'`*+BX@7TYE=%]3;V-K970Z(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92].971?4V]C:V5T"BXN(%]!=71H7U-!
M4TPZ(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]!=71H7U-!4TP*"BXN
M('9I;3H@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT(&5X
M<&%N9'1A8B!T97AT=VED=&@]-S8Z"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R].971?55),+P``````````
M````````````````````````````````````````````````````````````
M````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T
M,S,W,S4`,#(Q,#`U`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S
M+TYE=%]54DPO9&]C<R\`````````````````````````````````````````
M```````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#4Q-30S,S<S-0`P,C$W,S4`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+V1O8W,O3F5T7U523"]D;V-S+V5X86UP;&4N<&AP````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V,S8T`#$P-3$U-#,S-S,U`#`R-#$Q
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P
M>7)I9VAT("AC*2`R,#`R+3(P,#,L(%)I8VAA<F0@2&5Y97,@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($%L;"!R:6=H=',@
M<F5S97)V960N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@
M8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70@("`@?`HO+R!\(&UO9&EF
M:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL
M;W=I;F<@8V]N9&ET:6]N<R`@("!\"B\O('P@87)E(&UE=#H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\
M(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN
M('1H92!A8F]V92!C;W!Y<FEG:'0@("`@("!\"B\O('P@("!N;W1I8V4L('1H
M:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L
M86EM97(N("`@("`@('P*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA
M<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT("`@
M?`HO+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@
M=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN('1H92!\"B\O('P@("!D;V-U
M;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET
M:"!T:&4@9&ES=')I8G5T:6]N+GP@"B\O('P@;R!4:&4@;F%M97,@;V8@=&AE
M(&%U=&AO<G,@;6%Y(&YO="!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T
M92`@("`@('P*+R\@?"`@('!R;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES('-O
M9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B`@?`HO+R!\
M("`@<&5R;6ES<VEO;BX@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@?"!42$E3(%-/1E1705)%($E3(%!23U9)1$5$
M($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@0T].5%))0E543U)3("`@
M?`HO+R!\(")!4R!)4R(@04Y$($%.62!%6%!215-3($]2($E-4$Q)140@5T%2
M4D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4("`@("!\"B\O('P@3$E-251%
M1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)
M5%D@04Y$($9)5$Y%4U,@1D]2('P*+R\@?"!!(%!!4E1)0U5,05(@4%524$]3
M12!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%($-/4%E2
M24=(5"`@?`HO+R!\($]73D52($]2($-/3E1224)55$]24R!"12!,24%"3$4@
M1D]2($%.62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!\"B\O('P@
M4U!%0TE!3"P@15A%35!,05)9+"!/4B!#3TY315%514Y424%,($1!34%'15,@
M*$E.0TQ51$E.1RP@0E54($Y/5"`@("`@('P*+R\@?"!,24U)5$5$(%1/+"!0
M4D]#55)%345.5"!/1B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53.R!,
M3U-3($]&(%5312P@?`HO+R!\($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.
M15-3($E.5$524E505$E/3BD@2$]7159%4B!#0553140@04Y$($].($%.62!\
M"B\O('P@5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)3B!#3TY44D%#
M5"P@4U1224-4($Q)04))3$E462P@3U(@5$]25"`@('P*+R\@?"`H24Y#3%5$
M24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E.($%.62!7
M05D@3U54($]&(%1(12!54T4@?`HO+R!\($]&(%1(25,@4T]&5%=!4D4L($56
M14X@248@041625-%1"!/1B!42$4@4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!
M1T4N("!\"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@4FEC:&%R
M9"!(97EE<R`\<FEC:&%R9"!A="!P:'`@;F5T/B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@)$ED.B!E>&%M<&QE+G!H<"QV(#$N.2`R,#`T+S`U+S`X(#$W.C0X.C`X
M(')I8VAA<F0@17AP("0*+RHJ"BH@5&AI<R!E>&%M<&QE('=I;&P@9&5C;V1E
M('1H92!U<FP@9VEV96X@86YD(&1I<W!L87D@:71S"BH@8V]N<W1I='5E;G0@
M<&%R=',N"BHO"@HO+PEI;F-L=61E*"<N+B]54DPN<&AP)RD["@EI;F-L=61E
M*"=.970O55),+G!H<"<I.PH*"2\O)'5R;"`]("9N97<@3F5T7U523"@G:'1T
M<',Z+R]W=W<N97AA;7!L92YC;VTO9F]O+V)A<B]I;F1E>"YP:'`_9F]O/6)A
M<B<I.PH))'5R;"`](&YE=R!.971?55),*"=H='1P<SHO+V5X86UP;&4N8V]M
M+W!L<R]P;W)T86PS,"]03U)404PS,"YW=W!O8E]P86=E+F-H86YG971A8G,_
M<%]B86-K7W5R;#UH='1P)3-!)3)&)3)&97AA;7!L92YC;VTE,D9S97)V;&5T
M)3)&<&%G924S1E]P86=E:60E,T0S-C`E,D,S-C8E,D,S-C@E,D,S.#(E,C9?
M9&%D)3-$<&]R=&%L,S`E,C9?<V-H96UA)3-$4$]25$%,,S`F9F]O/6)A<B<I
M.PH_/@H\:'1M;#X*/&)O9'D^"@H\<')E/@I0<F]T;V-O;"XN+CH@/#\])'5R
M;"T^<')O=&]C;VP_/@H*57-E<FYA;64N+BXZ(#P_/21U<FPM/G5S97(_/@H*
M4&%S<W=O<F0N+BXZ(#P_/21U<FPM/G!A<W,_/@H*4V5R=F5R+BXN+BXZ(#P_
M/21U<FPM/FAO<W0_/@H*4&]R="XN+BXN+BXZ(#P_/21U<FPM/G!O<G0_/@H*
M1FEL92]P871H+BXZ(#P_/21U<FPM/G!A=&@_/@H*475E<GES=')I;F<Z(#P_
M<')I;G1?<B@D=7)L+3YQ=65R>7-T<FEN9RD_/@H*06YC:&]R+BXN+BXZ(#P_
M/21U<FPM/F%N8VAO<C\^"@H*1G5L;"!54DPN+BXZ(#P_/21U<FPM/F=E=%5R
M;"@I/SX*/"]P<F4^"@H\+V)O9'D^"CPO:'1M;#X*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]D;V-S+U-E<G9I8V5S7U=E871H97(O````````````
M```````````````````````````````````````````````````P,#`P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<S-0`P,C(W
M-S<`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O4V5R=FEC97-?
M5V5A=&AE<B]E>&%M<&QE<R\`````````````````````````````````````
M`````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-3$U-#,S-S,U`#`R-#8Q-0`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O9&]C<R]397)V:6-E<U]796%T:&5R+V5X86UP;&5S+V5J<V4M8F%S:6,N
M<&AP````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#8R-#,`,3`U,34T,S,W,S4`,#(W,S0P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J('9I
M;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T
M86)S=&]P/30@9F]L9&UE=&AO9#UM87)K97(Z("HO"@HO*BH*("H@0F%S:6,@
M97AA;7!L92!F;W(@=&AE($5*4T4M<V5R=FEC90H@*@H@*B!02%`@=F5R<VEO
M;G,@-"!A;F0@-0H@*@H@*B`\3$E#14Y313X*("H@0V]P>7)I9VAT("AC*2`R
M,#`U+"!!;&5X86YD97(@5VER='H*("H@06QL(')I9VAT<R!R97-E<G9E9"X*
M("H@"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B
M:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M;V1I9FEC871I;VXL
M(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O
M;F1I=&EO;G,*("H@87)E(&UE=#H*("H@;R!2961I<W1R:6)U=&EO;G,@;V8@
M<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H="!N
M;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F
M;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@;R!2961I<W1R:6)U=&EO;G,@:6X@
M8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H
M="!N;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H
M92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@9&]C=6UE;G1A=&EO;@H@
M*B`@(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4@
M9&ES=')I8G5T:6]N+@H@*B!O($YE:71H97(@=&AE(&YA;64@;V8@=&AE('-O
M9G1W87)E(&YO<B!T:&4@;F%M97,@;V8@:71S(&-O;G1R:6)U=&]R<PH@*B`@
M(&UA>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92!P<F]D=6-T<R!D
M97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R90H@*B`@('=I=&AO=70@<W!E8VEF
M:6,@<')I;W(@=W)I='1E;B!P97)M:7-S:6]N+@H@*B`*("H@5$A)4R!33T94
M5T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$
M($-/3E1224)55$]24R`B05,@25,B"B`J($%.1"!!3ED@15A04D534R!/4B!)
M35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$
M(%1/+"!42$4*("H@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))
M3$E462!!3D0@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/4T4*("H@
M05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'
M2%0@3U=.15(@3U(@0T].5%))0E543U)3($)%"B`J($Q)04),12!&3U(@04Y9
M($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL(%-014-)04PL($5814U0
M3$%262P@3U(*("H@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L
M($)55"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8*("H@4U5"4U1)
M5%5412!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L($1!5$$L($]2
M(%!23T9)5%,[($]2($)54TE.15-3"B`J($E.5$524E505$E/3BD@2$]7159%
M4B!#0553140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!72$54
M2$52($E."B`J($-/3E1204-4+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4
M("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I"B`J($%225-)
M3D<@24X@04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3(%-/1E1705)%
M+"!%5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,2519($]&(%-5
M0T@@1$%-04=%+@H@*B`\+TQ)0T5.4T4^"B`J(`H@*B!`8V%T96=O<GD@("`@
M5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@("!397)V:6-E<U]796%T:&5R
M"B`J($!A=71H;W(@("`@("!!;&5X86YD97(@5VER='H@/&%L97A`<&,T<"YN
M970^"B`J($!C;W!Y<FEG:'0@("`R,#`U($%L97AA;F1E<B!7:7)T>@H@*B!`
M;&EC96YS92`@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E
M<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@
M("!#5E,Z("1)9#H@96IS92UB87-I8RYP:'`L=B`Q+C0@,C`P-2\Q,2\P."`Q
M-SHU,CHT,B!E<G4@17AP("0*("H@0&QI;FL@("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]397)V:6-E<U]796%T:&5R"B`J($!F:6QE<V]U
M<F-E"B`J+PH@"G)E<75I<F5?;VYC92`B4V5R=FEC97,O5V5A=&AE<BYP:'`B
M.PH*+R\@3V)J96-T(&EN:71I86QI>F%T:6]N("T@97)R;W(@8VAE8VMI;F<@
M:7,@:6UP;W)T86YT+"!B96-A=7-E(&]F"B\O(&AA;F1L:6YG(&5X8V5P=&EO
M;G,@<W5C:"!A<R!M:7-S:6YG(%!%05(@;6]D=6QE<R!O<B!N;W0@8F5I;F<@
M;VYL:6YE"B1E:G-E(#T@)E-E<G9I8V5S7U=E871H97(Z.G-E<G9I8V4H(D5J
M<V4B+"!A<G)A>2@B9&5B=6<B(#T^(#(I*3L*:68@*%-E<G9I8V5S7U=E871H
M97(Z.FES17)R;W(H)&5J<V4I*2!["B`@("!D:64H(D5R<F]R.B`B+B1E:G-E
M+3YG971-97-S86=E*"DN(EQN(BD["GT*"B\J($5R87-E(&-O;6UE;G1S('1O
M(&5N86)L92!C86-H:6YG"B1S=&%T=7,@/2`D96IS92T^<V5T0V%C:&4H(F9I
M;&4B+"!A<G)A>2@B8V%C:&5?9&ER(B`]/B`B+W1M<"]C86-H92\B*2D["FEF
M("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("!E
M8VAO(")%<G)O<CH@(BXD<W1A='5S+3YG971-97-S86=E*"DN(EQN(CL*?0HJ
M+PH*)&5J<V4M/G-E=%5N:71S1F]R;6%T*")M971R:6,B*3L*)&5J<V4M/G-E
M=$1A=&54:6UE1F]R;6%T*")D+FTN62(L(")(.FDB*3L*"B1L;V-A=&EO;B`]
M("(X,38Q,2([("\O($%S<&5N+"!#3PHO+R1L;V-A=&EO;B`]("(P,C$Q-2([
M("\O($)O<W1O;BP@34$*+R\D;&]C871I;VX@/2`B.38W.3DB.R`O+R!086=O
M(%!A9V\L($%3"B\O)&QO8V%T:6]N(#T@(C`Y,#`Y(CL@+R\@07)M960@1F]R
M8V5S($5U<F]P92`M/B!%<G)O<@H*+R\@3F]W(&ET97)A=&4@=&AR;W5G:"!A
M=F%I;&%B;&4@9G5N8W1I;VYS(&9O<B!R971R:65V:6YG(&1A=&$*9F]R96%C
M:"`H87)R87DH(F=E=$QO8V%T:6]N(BP@(F=E=%=E871H97(B+"`B9V5T1F]R
M96-A<W0B*2!A<R`D9G5N8W1I;VXI('L*("`@("1D871A(#T@)&5J<V4M/B1F
M=6YC=&EO;B@D;&]C871I;VXI.PH@("`@:68@*%-E<G9I8V5S7U=E871H97(Z
M.FES17)R;W(H)&1A=&$I*2!["B`@("`@("`@96-H;R`B17)R;W(Z("(N)&1A
M=&$M/F=E=$UE<W-A9V4H*2XB7&XB.PH@("`@("`@(&-O;G1I;G5E.PH@("`@
M?0H*("`@('9A<E]D=6UP*"1D871A*3L*?0H_/@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+V1O8W,O4V5R=FEC97-?5V5A=&AE<B]E>&%M<&QE<R]G;&]B86QW96%T
M:&5R+6)A<VEC+G!H<````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`V-#$P`#$P-3$U-#,S-S,U`#`S,3(R-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*B!V
M:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T
M=&%B<W1O<#TT(&9O;&1M971H;V0];6%R:V5R.B`J+PH*+RHJ"B`J($)A<VEC
M(&5X86UP;&4@9F]R('1H92!';&]B86Q796%T:&5R+7-E<G9I8V4*("H*("H@
M4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@/$Q)0T5.4T4^"B`J($-O<'ER
M:6=H="`H8RD@,C`P-2P@06QE>&%N9&5R(%=I<G1Z"B`J($%L;"!R:6=H=',@
M<F5S97)V960N"B`J(`H@*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O
M=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D
M:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O
M;&QO=VEN9R!C;VYD:71I;VYS"B`J(&%R92!M970Z"B`J(&\@4F5D:7-T<FEB
M=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C
M;W!Y<FEG:'0@;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS
M(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J(&\@4F5D:7-T<FEB
M=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V
M92!C;W!Y<FEG:'0@;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I
M;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE(&1O8W5M
M96YT871I;VX*("H@("!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D
M('=I=&@@=&AE(&1I<W1R:6)U=&EO;BX*("H@;R!.96ET:&5R('1H92!N86UE
M(&]F('1H92!S;V9T=V%R92!N;W(@=&AE(&YA;65S(&]F(&ET<R!C;VYT<FEB
M=71O<G,*("H@("!M87D@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@
M<')O9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4*("H@("!W:71H
M;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H@"B`J
M(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(
M3TQ$15)3($%.1"!#3TY44DE"551/4E,@(D%3($E3(@H@*B!!3D0@04Y9($58
M4%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.
M3U0@3$E-251%1"!43RP@5$A%"B`J($E-4$Q)140@5T%24D%.5$E%4R!/1B!-
M15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!0
M55)03U-%"B`J($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!4
M2$4@0T]065))1TA4($]73D52($]2($-/3E1224)55$]24R!"10H@*B!,24%"
M3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!34$5#
M24%,+"!%6$5-4$Q!4EDL($]2"B`J($-/3E-%455%3E1)04P@1$%-04=%4R`H
M24Y#3%5$24Y'+"!"550@3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&
M"B`J(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%
M+"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534PH@*B!)3E1%4E)54%1)
M3TXI($A/5T5615(@0T%54T5$($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)04))
M3$E462P@5TA%5$A%4B!)3@H@*B!#3TY44D%#5"P@4U1224-4($Q)04))3$E4
M62P@3U(@5$]25"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%
M*0H@*B!!4DE324Y'($E.($%.62!705D@3U54($]&(%1(12!54T4@3T8@5$A)
M4R!33T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(10H@*B!03U-324))
M3$E462!/1B!354-(($1!34%'12X*("H@/"],24-%3E-%/@H@*B`*("H@0&-A
M=&5G;W)Y("`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("`@4V5R=FEC
M97-?5V5A=&AE<@H@*B!`875T:&]R("`@("`@06QE>&%N9&5R(%=I<G1Z(#QA
M;&5X0'!C-'`N;F5T/@H@*B!`8V]P>7)I9VAT("`@,C`P-2!!;&5X86YD97(@
M5VER='H*("H@0&QI8V5N<V4@("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO
M<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`
M=F5R<VEO;B`@("`@0U93.B`D260Z(&=L;V)A;'=E871H97(M8F%S:6,N<&AP
M+'8@,2XU(#(P,#4O,3$O,#@@,3<Z-3(Z-#(@97)U($5X<"`D"B`J($!L:6YK
M("`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4V5R=FEC97-?
M5V5A=&AE<@H@*B!`9FEL97-O=7)C90H@*B\*"G)E<75I<F5?;VYC92`B4V5R
M=FEC97,O5V5A=&AE<BYP:'`B.PH*+R\@3V)J96-T(&EN:71I86QI>F%T:6]N
M("T@97)R;W(@8VAE8VMI;F<@:7,@:6UP;W)T86YT+"!B96-A=7-E(&]F"B\O
M(&AA;F1L:6YG(&5X8V5P=&EO;G,@<W5C:"!A<R!M:7-S:6YG(%!%05(@;6]D
M=6QE<R!O<B!N;W0@8F5I;F<@;VYL:6YE"B1G;&]B86QW96%T:&5R(#T@)E-E
M<G9I8V5S7U=E871H97(Z.G-E<G9I8V4H(D=L;V)A;%=E871H97(B+"!A<G)A
M>2@B9&5B=6<B(#T^(#(I*3L*:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R
M;W(H)&=L;V)A;'=E871H97(I*2!["B`@("!D:64H(D5R<F]R.B`B+B1G;&]B
M86QW96%T:&5R+3YG971-97-S86=E*"DN(EQN(BD["GT*"B\J($5R87-E(&-O
M;6UE;G1S('1O(&5N86)L92!C86-H:6YG"B1S=&%T=7,@/2`D9VQO8F%L=V5A
M=&AE<BT^<V5T0V%C:&4H(F9I;&4B+"!A<G)A>2@B8V%C:&5?9&ER(B`]/B`B
M+W1M<"]C86-H92\B*2D["FEF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R
M*"1S=&%T=7,I*2!["B`@("!E8VAO(")%<G)O<CH@(BXD<W1A='5S+3YG971-
M97-S86=E*"DN(EQN(CL*?0HJ+PH*)&=L;V)A;'=E871H97(M/G-E=%5N:71S
M1F]R;6%T*")M971R:6,B*3L*)&=L;V)A;'=E871H97(M/G-E=$1A=&54:6UE
M1F]R;6%T*")D+FTN62(L(")(.FDB*3L*"B\O($9I<G-T(&=E="!C;V1E(&9O
M<B!L;V-A=&EO;@HD<V5A<F-H(#T@)&=L;V)A;'=E871H97(M/G-E87)C:$QO
M8V%T:6]N*")+;V5L;B`O($)O;FXB*3L*:68@*%-E<G9I8V5S7U=E871H97(Z
M.FES17)R;W(H)'-E87)C:"DI('L*("`@(&1I92@B17)R;W(Z("(N)'-E87)C
M:"T^9V5T365S<V%G92@I+B)<;B(I.PI]"@HO+R!.;W<@:71E<F%T92!T:')O
M=6=H(&%V86EL86)L92!F=6YC=&EO;G,@9F]R(')E=')I979I;F<@9&%T80IF
M;W)E86-H("AA<G)A>2@B9V5T3&]C871I;VXB+"`B9V5T5V5A=&AE<B(L(")G
M971&;W)E8V%S="(I(&%S("1F=6YC=&EO;BD@>PH@("`@)&1A=&$@/2`D9VQO
M8F%L=V5A=&AE<BT^)&9U;F-T:6]N*"1S96%R8V@I.PH@("`@:68@*%-E<G9I
M8V5S7U=E871H97(Z.FES17)R;W(H)&1A=&$I*2!["B`@("`@("`@96-H;R`B
M17)R;W(Z("(N)&1A=&$M/F=E=$UE<W-A9V4H*2XB7&XB.PH@("`@("`@(&-O
M;G1I;G5E.PH@("`@?0H*("`@('9A<E]D=6UP*"1D871A*3L*?0H_/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]D;V-S+U-E<G9I8V5S7U=E871H97(O97AA;7!L97,O;65T87(M8F%S
M:6,N<&AP```````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P-S`U,P`Q,#4Q-30S,S<S-0`P,C<U,C(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RH@
M=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F
M='1A8G-T;W`]-"!F;VQD;65T:&]D/6UA<FME<CH@*B\*"B\J*@H@*B!"87-I
M8R!E>&%M<&QE(&9O<B!T:&4@345405(O5$%&+7-E<G9I8V4*("H*("H@4$A0
M('9E<G-I;VYS(#0@86YD(#4*("H*("H@/$Q)0T5.4T4^"B`J($-O<'ER:6=H
M="`H8RD@,C`P-2P@06QE>&%N9&5R(%=I<G1Z"B`J($%L;"!R:6=H=',@<F5S
M97)V960N"B`J(`H@*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C
M92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D:69I
M8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO
M=VEN9R!C;VYD:71I;VYS"B`J(&%R92!M970Z"B`J(&\@4F5D:7-T<FEB=71I
M;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y
M<FEG:'0@;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N
M9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J(&\@4F5D:7-T<FEB=71I
M;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C
M;W!Y<FEG:'0@;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS
M(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE(&1O8W5M96YT
M871I;VX*("H@("!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I
M=&@@=&AE(&1I<W1R:6)U=&EO;BX*("H@;R!.96ET:&5R('1H92!N86UE(&]F
M('1H92!S;V9T=V%R92!N;W(@=&AE(&YA;65S(&]F(&ET<R!C;VYT<FEB=71O
M<G,*("H@("!M87D@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O
M9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4*("H@("!W:71H;W5T
M('-P96-I9FEC('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H@"B`J(%1(
M25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$
M15)3($%.1"!#3TY44DE"551/4E,@(D%3($E3(@H@*B!!3D0@04Y9($584%)%
M4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0@
M3$E-251%1"!43RP@5$A%"B`J($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#
M2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!055)0
M3U-%"B`J($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@
M0T]065))1TA4($]73D52($]2($-/3E1224)55$]24R!"10H@*B!,24%"3$4@
M1D]2($%.62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!34$5#24%,
M+"!%6$5-4$Q!4EDL($]2"B`J($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#
M3%5$24Y'+"!"550@3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&"B`J
M(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%+"!$
M051!+"!/4B!04D]&2513.R!/4B!"55-)3D534PH@*B!)3E1%4E)54%1)3TXI
M($A/5T5615(@0T%54T5$($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)04))3$E4
M62P@5TA%5$A%4B!)3@H@*B!#3TY44D%#5"P@4U1224-4($Q)04))3$E462P@
M3U(@5$]25"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*0H@
M*B!!4DE324Y'($E.($%.62!705D@3U54($]&(%1(12!54T4@3T8@5$A)4R!3
M3T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(10H@*B!03U-324))3$E4
M62!/1B!354-(($1!34%'12X*("H@/"],24-%3E-%/@H@*B`*("H@0&-A=&5G
M;W)Y("`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("`@4V5R=FEC97-?
M5V5A=&AE<@H@*B!`875T:&]R("`@("`@06QE>&%N9&5R(%=I<G1Z(#QA;&5X
M0'!C-'`N;F5T/@H@*B!`8V]P>7)I9VAT("`@,C`P-2!!;&5X86YD97(@5VER
M='H*("H@0&QI8V5N<V4@("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O
M;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R
M<VEO;B`@("`@0U93.B`D260Z(&UE=&%R+6)A<VEC+G!H<"QV(#$N,3$@,C`P
M-2\Q,2\P."`Q-SHU,CHT,B!E<G4@17AP("0*("H@0&QI;FL@("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]397)V:6-E<U]796%T:&5R"B`J
M($!F:6QE<V]U<F-E"B`J+PH*<F5Q=6ER95]O;F-E(")397)V:6-E<R]796%T
M:&5R+G!H<"(["@HO+R!/8FIE8W0@:6YI=&EA;&EZ871I;VX@+2!E<G)O<B!C
M:&5C:VEN9R!I<R!I;7!O<G1A;G0L(&)E8V%U<V4@;V8*+R\@:&%N9&QI;F<@
M97AC97!T:6]N<R!S=6-H(&%S(&UI<W-I;F<@4$5!4B!M;V1U;&5S"B1M971A
M<B`]("9397)V:6-E<U]796%T:&5R.CIS97)V:6-E*")-151!4B(L(&%R<F%Y
M*")D96)U9R(@/3X@,"DI.PII9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O
M<B@D;65T87(I*2!["B`@("!D:64H(D5R<F]R.B`B+B1M971A<BT^9V5T365S
M<V%G92@I+B)<;B(I.PI]"@HO+R!3970@<&%R86UE=&5R<R!F;W(@1$(@86-C
M97-S+"!N965D960@9F]R(&QO8V%T:6]N('-E87)C:&5S"B1M971A<BT^<V5T
M365T87)$0B@B<W%L:71E.B\O;&]C86QH;W-T+R]U<W(O;&]C86PO;&EB+W!H
M<"]D871A+U-E<G9I8V5S7U=E871H97(O<V5R=FEC97-796%T:&5R1$(B*3L*
M:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)&UE=&%R*2D@>PH@("`@
M96-H;R`B17)R;W(Z("(N)&UE=&%R+3YG971-97-S86=E*"DN(EQN(CL*?0H*
M+RH@17)A<V4@8V]M;65N=',@=&\@96YA8FQE(&-A8VAI;F<*)'-T871U<R`]
M("1M971A<BT^<V5T0V%C:&4H(F9I;&4B+"!A<G)A>2@B8V%C:&5?9&ER(B`]
M/B`B+W1M<"]C86-H92\B*2D["FEF("A397)V:6-E<U]796%T:&5R.CII<T5R
M<F]R*"1S=&%T=7,I*2!["B`@("!E8VAO(")%<G)O<CH@(BXD<W1A='5S+3YG
M971-97-S86=E*"DN(EQN(CL*?0HJ+PH*)&UE=&%R+3YS9715;FET<T9O<FUA
M="@B8W5S=&]M(BP@87)R87DH"B`@("`B=VEN9"(@("`]/B`B:W0B+`H@("`@
M(G9I<R(@("`@/3X@(FMM(BP*("`@(")H96EG:'0B(#T^(")F="(L"B`@("`B
M=&5M<"(@("`]/B`B8R(L"B`@("`B<')E<R(@("`]/B`B:'!A(BP*("`@(")R
M86EN(B`@(#T^(")I;B(I*3L*)&UE=&%R+3YS971$871E5&EM949O<FUA="@B
M9"YM+EDB+"`B2#II(BD["@HO+R!&:7)S="!G970@8V]D92!F;W(@;&]C871I
M;VX*)'-E87)C:"`]("1M971A<BT^<V5A<F-H3&]C871I;VXH(D)O;FXL($=E
M<FUA;GDB*3L*:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-E87)C
M:"DI('L*("`@(&1I92@B17)R;W(Z("(N)'-E87)C:"T^9V5T365S<V%G92@I
M+B)<;B(I.PI]"@HO+R!.;W<@:71E<F%T92!T:')O=6=H(&%V86EL86)L92!F
M=6YC=&EO;G,@9F]R(')E=')I979I;F<@9&%T80IF;W)E86-H("AA<G)A>2@B
M9V5T3&]C871I;VXB+"`B9V5T5V5A=&AE<B(L(")G971&;W)E8V%S="(I(&%S
M("1F=6YC=&EO;BD@>PH@("`@)&1A=&$@/2`D;65T87(M/B1F=6YC=&EO;B@D
M<V5A<F-H*3L*("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1D
M871A*2D@>PH@("`@("`@(&5C:&\@(D5R<F]R.B`B+B1D871A+3YG971-97-S
M86=E*"DN(EQN(CL*("`@("`@("!C;VYT:6YU93L*("`@('T*"B`@("!V87)?
M9'5M<"@D9&%T82D["GT*/SX*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+U-E<G9I8V5S7U=E871H97(O
M97AA;7!L97,O;65T87(M97AT96YS:79E+G!H<```````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`V-S$U,@`Q,#4Q-30S
M,S<S-0`P,S`T-C$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]
M-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-"!F;VQD;65T:&]D/6UA<FME
M<CH@*B\*"B\J*@H@*B!%;&%B;W)A=&4@97AA;7!L92!F;W(@=&AE($U%5$%2
M+U1!1BUS97)V:6-E"B`J"B`J(%=E;&PL('1H:7,@:7,@82!M;W)E(&5L86)O
M<F%T92!E>&%M<&QE(&AO=R!T;R!C<F5A=&4@82!N96%T(&QI='1L92!P86=E
M"B`J('=I=&@@9F5T8VAI;F<@345405(O5$%&(&1A=&$@9G)O;2!.3T%!(&%N
M9"!P=71T:6YG(&ET(&EN=&\@82!D97-I9VXN"B`J($DG;2!N;W0@=&]O('!R
M;W5D(&]F(&UY(&1E<VEG;BUS:VEL;',L(&UO<W0@;V8@=&AE('-T=69F(&AE
M<F4@:7,@=&%K96X*("H@9G)O;2!T:&4@;65T87(M8FQO8VL@=VAI8V@@8V%N
M(&)E(&9O=6YD('=I=&AI;B!T:&4@2&]R9&4@1G)A;65W;W)K+`H@*B!C;W5R
M=&5S>2!O9B!2:6-K($5M97)Y("T@8W)E871I=F4@<&EX96QS:&]V:6YG(&ES
M;B=T(&UY(&1O;6%I;B`Z+5`*("H@22=V92!U<V5D(&$@1FER969O>"!F;W(@
M8VAE8VMI;F<@=&AE(&1E<VEG;BP@<V\@9&]N)W0@8F4@=&]O"B`J(&1I<V%P
M<&]I;G1E9"P@:68@=&AE('!A9V4@;&]O:W,@<VAA8F)Y('=I=&@@=&AE($E%
M+"!N;W0@=&AA="!)(&-A<F4*("H@=F5R>2!M=6-H(&%N>7=A>2`[+2D*("H@
M2&%V92!F=6XA"B`J(`H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B`\
M3$E#14Y313X*("H@0V]P>7)I9VAT("AC*2`R,#`U+"!!;&5X86YD97(@5VER
M='H*("H@06QL(')I9VAT<R!R97-E<G9E9"X*("H@"B`J(%)E9&ES=')I8G5T
M:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@
M;W(@=VET:&]U=`H@*B!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O
M=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,*("H@87)E(&UE
M=#H*("H@;R!2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R
M971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H="!N;W1I8V4L"B`J("`@=&AI<R!L
M:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE
M<BX*("H@;R!2961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R
M97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H="!N;W1I8V4L"B`J("`@=&AI
M<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA
M:6UE<B!I;B!T:&4@9&]C=6UE;G1A=&EO;@H@*B`@(&%N9"]O<B!O=&AE<B!M
M871E<FEA;',@<')O=FED960@=VET:"!T:&4@9&ES=')I8G5T:6]N+@H@*B!O
M($YE:71H97(@=&AE(&YA;64@;V8@=&AE('-O9G1W87)E(&YO<B!T:&4@;F%M
M97,@;V8@:71S(&-O;G1R:6)U=&]R<PH@*B`@(&UA>2!B92!U<V5D('1O(&5N
M9&]R<V4@;W(@<')O;6]T92!P<F]D=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S
M;V9T=V%R90H@*B`@('=I=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B!P
M97)M:7-S:6]N+@H@*B`*("H@5$A)4R!33T945T%212!)4R!04D]6241%1"!"
M62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]24R`B05,@
M25,B"B`J($%.1"!!3ED@15A04D534R!/4B!)35!,245$(%=!4E)!3E1)15,L
M($E.0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$(%1/+"!42$4*("H@24U03$E%
M1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!3D0@1DE43D534R!&
M3U(@02!005)424-53$%2(%!54E!/4T4*("H@05)%($1)4T-,04E-140N($E.
M($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'2%0@3U=.15(@3U(@0T].5%))
M0E543U)3($)%"B`J($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L
M($E.0TE$14Y404PL(%-014-)04PL($5814U03$%262P@3U(*("H@0T].4T51
M545.5$E!3"!$04U!1T53("A)3D-,541)3D<L($)55"!.3U0@3$E-251%1"!4
M3RP@4%)/0U5214U%3E0@3T8*("H@4U5"4U1)5%5412!'3T]$4R!/4B!315)6
M24-%4SL@3$]34R!/1B!54T4L($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.
M15-3"B`J($E.5$524E505$E/3BD@2$]7159%4B!#0553140@04Y$($].($%.
M62!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E."B`J($-/3E1204-4
M+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4("A)3D-,541)3D<@3D5'3$E'
M14Y#12!/4B!/5$A%4E=)4T4I"B`J($%225-)3D<@24X@04Y9(%=!62!/550@
M3T8@5$A%(%5312!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@
M3T8@5$A%"B`J(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+@H@*B`\+TQ)
M0T5.4T4^"B`J(`H@*B!`8V%T96=O<GD@("`@5V5B(%-E<G9I8V5S"B`J($!P
M86-K86=E("`@("!397)V:6-E<U]796%T:&5R"B`J($!A=71H;W(@("`@("!!
M;&5X86YD97(@5VER='H@/&%L97A`<&,T<"YN970^"B`J($!C;W!Y<FEG:'0@
M("`R,#`U($%L97AA;F1E<B!7:7)T>@H@*B!`;&EC96YS92`@("`@:'1T<#HO
M+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@
M($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@("!#5E,Z("1)9#H@;65T87(M
M97AT96YS:79E+G!H<"QV(#$N,3<@,C`P-2\Q,2\Q,R`R,CHT-3HR,2!E<G4@
M17AP("0*("H@0&QI;FL@("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]397)V:6-E<U]796%T:&5R"B`J($!F:6QE<V]U<F-E"B`J+PH*+R\M
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"B\O(%1H:7,@:7,@=&AE(&%R
M96$L('=H97)E('EO=2!C86X@8W5S=&]M:7IE('1H92!S8W)I<'0*+R\M+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"B1L;V-A=&EO;B`@("`@("`@/2`B
M0F]N;BP@1V5R;6%N>2([("\O(%1H92!C:71Y('=E('=A;G0@=&\@9F5T8V@@
M=&AE(&1A=&$@9F]R+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!7:&5R92!T:&4@<V5A<F-H(&9U;F-T:6]N('=I;&P@;&]O:R!F
M;W(*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@=&AE
M($E#04\@9&%T86)A<V4@*&=E;F5R871E9"!W:71H('1H90H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!B=6EL9$UE=&%R1$(N<&AP
M('-C<FEP="D*)&1S;B`@("`@("`@("`@("`](")S<6QI=&4Z+R]L;V-A;&AO
M<W0O+W5S<B]L;V-A;"]L:6(O<&AP+V1A=&$O4V5R=FEC97-?5V5A=&AE<B]S
M97)V:6-E<U=E871H97)$0B([(`HD<V]U<F-E365T87(@("`@(#T@(FAT='`B
M.R`@("`@("`@("`O+R!4:&ES('-C<FEP="!W:6QL('!U;&P@=&AE($U%5$%2
M(&1A=&$@=FEA(&AT='`*)'-O=7)C951A9B`@("`@("`](")H='1P(CL@("`@
M("`@("`@+R\@("`@("`@("`@("`@("`@("`@("`@("`@("!4048*)'-O=7)C
M95!A=&A-971A<B`]("(B.R`@("`@("`@("`@("`@+R\@3VYL>2!N965D960@
M=VAE;B!N;VXM<W1A;F1A<F0@86-C97-S(&ES('5S960*)'-O=7)C95!A=&A4
M868@("`]("(B.R`@("`@("`@("`@("`@+R\*)&-A8VAE5'EP92`@("`@("`]
M("(B.R`@("`@("`@("`@("`@+R\@4V5T(&$@='EP92`H9FEL92P@9&(L(&UD
M8BP@+BXN*2!T;PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!E;F%B;&4@8V%C:&EN9RX*)&-A8VAE3W!T("`@("`@("`](&%R<F%Y
M*"D[("`@("`@("`@+R\@0V%C:&4@;F5E9',@=F%R:6]U<R!O<'1I;VYS+"!D
M97!E;F1I;F<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+R\@;VX@=&AE(&-O;G1A:6YE<BUT>7!E("T@<&QE87-E(&-O;G-U;'0*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@=&AE($-A8VAE
M(&UA;G5A;"`O('-O=7)C96-O9&4A"B1U;FET<T9O<FUA="`@("`@/2`B;65T
M<FEC(CL@("`@("`@("\O(%1H92!F;W)M870@=&AE('5N:71S(&%R92!D:7-P
M;&%Y960@:6X@+0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!M971R:6,L('-T86YD87)D(&]R('-O;64@8W5S=&]M:7IA=&EO;BX*
M)&1A=&5&;W)M870@("`@("`](")J+B!-(%DB.R`@("`@("`@+R\@4V5T('1H
M92!F;W)M870@=&AE(&1A=&4@:7,@9&ES<&QA>65D(&EN"B1T:6UE1F]R;6%T
M("`@("`@/2`B2#II(CL@("`@("`@("`@("\O("`@("`@("`@("`@("`@("`@
M("!T:6UE"B\O+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H*+R\@3&]A
M9"!T:&4@5V5A=&AE<B!C;&%S<PIR97%U:7)E7V]N8V4@(E-E<G9I8V5S+U=E
M871H97(N<&AP(CL*"B\O($]B:F5C="!I;FET:6%L:7IA=&EO;B`M(&5R<F]R
M(&-H96-K:6YG(&ES(&EM<&]R=&%N="P@8F5C875S92!O9@HO+R!H86YD;&EN
M9R!E>&-E<'1I;VYS('-U8V@@87,@;6ES<VEN9R!014%2(&UO9'5L97,*)&UE
M=&%R(#T@)E-E<G9I8V5S7U=E871H97(Z.G-E<G9I8V4H(DUE=&%R(BD["FEF
M("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1M971A<BDI('L*("`@(&1I
M92@B17)R;W(Z("(N)&UE=&%R+3YG971-97-S86=E*"DN(EQN(BD["GT*"B\O
M(%-E="!P87)A;65T97)S(&9O<B!$0B!A8V-E<W,L(&YE961E9"!F;W(@;&]C
M871I;VX@<V5A<F-H97,*)&UE=&%R+3YS971-971A<D1"*"1D<VXI.PII9B`H
M4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D;65T87(I*2!["B`@("!E8VAO
M(")%<G)O<CH@(BXD;65T87(M/F=E=$UE<W-A9V4H*2XB7&XB.PI]"@HO+R!)
M;FET:6%L:7IE(&-A8VAI;F<*:68@*'-T<FQE;B@D8V%C:&54>7!E*2D@>PH@
M("`@)'-T871U<R`]("1M971A<BT^<V5T0V%C:&4H)&-A8VAE5'EP92P@)&-A
M8VAE3W!T*3L*("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S
M=&%T=7,I*2!["B`@("`@("`@96-H;R`B17)R;W(Z("(N)'-T871U<RT^9V5T
M365S<V%G92@I+B)<;B(["B`@("!]"GT*"B\O($1E9FEN92!T:&4@=6YI=',@
M9F]R;6%T+"!B<FEN9R!T:&4@<F5T<FEE=F5D(&9O<FUA="!I;G1O"B\O('-O
M;65T:&EN9R!M;W)E(&-O;6UO;BXN+@HD;65T87(M/G-E=%5N:71S1F]R;6%T
M*"1U;FET<T9O<FUA="D["B1U;FET<R`]("1M971A<BT^9V5T56YI='-&;W)M
M870H*3L*)'5N:71S6R)T96UP(ET@("`]("(F9&5G.R(N<W1R=&]U<'!E<B@D
M=6YI='-;(G1E;7`B72D["B1U;FET<ULB=VEN9")=("`@/2`B)FYB<W`[(BYS
M=')?<F5P;&%C92@B:VUH(BP@(FMM+V@B+"`D=6YI='-;(G=I;F0B72D["B1U
M;FET<ULB=FES(ET@("`@/2`B)FYB<W`[(BXD=6YI='-;(G9I<R)=.PHD=6YI
M='-;(FAE:6=H=")=(#T@(B9N8G-P.R(N)'5N:71S6R)H96EG:'0B73L*)'5N
M:71S6R)P<F5S(ET@("`]("(F;F)S<#LB+B1U;FET<ULB<')E<R)=.PHD=6YI
M='-;(G)A:6XB72`@(#T@(B9N8G-P.R(N)'5N:71S6R)R86EN(ET["@HD;65T
M87(M/G-E=$UE=&%R4V]U<F-E*"1S;W5R8V5-971A<BP@)'-O=7)C95!A=&A-
M971A<BP@)'-O=7)C951A9BP@)'-O=7)C95!A=&A4868I.PH*+R\@4V5T(&1A
M=&4M+W1I;64M9F]R;6%T"B1M971A<BT^<V5T1&%T951I;65&;W)M870H)&1A
M=&5&;W)M870L("1T:6UE1F]R;6%T*3L*"B\O(%-E87)C:"!F;W(@9&5F:6YE
M9"!L;V-A=&EO;B!A;F0@9F5T8V@@=&AE(&9I<G-T(&ET96T@9F]U;F0N"B\O
M($)A:6P@;W5T(&EF('-O;65T:&EN9R!B860@:&%P<&5N<RXN+@HD<V5A<F-H
M(#T@)&UE=&%R+3YS96%R8VA,;V-A=&EO;B@D;&]C871I;VXL('1R=64I.PII
M9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<V5A<F-H*2D@>PH@("`@
M9&EE*")%<G)O<CH@(BXD<V5A<F-H+3YG971-97-S86=E*"DN(EQN(BD["GT*
M"B\O(%)E=')I979E(&1A=&$L('-T;W)E(&EN('9A<FEA8FQE<RP@8F%I;"!O
M=70@;VX@97)R;W(*)&9E=&-H(#T@87)R87DH"B`@("`B;&]C871I;VXB(#T^
M(")G971,;V-A=&EO;B(L"B`@("`B=V5A=&AE<B(@(#T^(")G971796%T:&5R
M(BP*("`@(")F;W)E8V%S="(@/3X@(F=E=$9O<F5C87-T(@HI.PIF;W)E86-H
M("@D9F5T8V@@87,@)'9A<FEA8FQE(#T^("1F=6YC=&EO;BD@>PH@("`@)"1V
M87)I86)L92`]("1M971A<BT^)&9U;F-T:6]N*"1S96%R8V@I.PH@("`@:68@
M*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)"1V87)I86)L92DI('L*("`@
M("`@("!E8VAO(")%<G)O<CH@(BXD)'9A<FEA8FQE+3YG971-97-S86=E*"DN
M(EQN(CL*("`@("`@("!C;VYT:6YU93L*("`@('T*?0H*+R\@3F]W('=E(&]U
M='!U="!A;&P@=&AE(&1A=&$L('!L96%S92!D;VXG="!E>'!E8W0@97AT96YS
M:79E(&-O;6UE;G1S(&AE<F4L('1H:7,@:7,@8F%S:6,*+R\@2%1-3"]#4U,@
M<W1U9F8N($%L<V\@=&AI<R!I<VXG="!A('9E<GD@9F%N8WD@9&5S:6=N+"!I
M="=S(&IU<W0@=&\@<VAO=R!Y;W4L('=H870*+R\@=&AE('-C<FEP="!I<R!A
M8FQE('1O(&1O("AA;F0@;6]R92`[+2DI+BXN"C\^"CQH=&UL/@H\:&5A9#X*
M("`@(#QT:71L93Y397)V:6-E<U]796%T:&5R.CI-151!4B]4048\+W1I=&QE
M/@H@("`@/'-T>6QE('1Y<&4](G1E>'0O8W-S(CX*("`@("`@("`N;F]R;6%L
M("`@("![(&9O;G0M9F%M:6QY.B!!<FEA;"P@2&5L=F5T:6-A+"!S86YS+7-E
M<FEF.R!F;VYT+7-I>F4Z(#$Q<'0[(&9O;G0M=V5I9VAT.B!N;W)M86P[(&9O
M;G0M<W1Y;&4Z(&YO<FUA;"!]"B`@("`@("`@+FET86QI8R`@("`@>R!F;VYT
M+7=E:6=H=#H@;F]R;6%L.R!F;VYT+7-T>6QE.B!I=&%L:6,@?0H@("`@("`@
M("YB;VQD("`@("`@('L@9F]N="UW96EG:'0Z(&)O;&0[(&9O;G0M<W1Y;&4Z
M(&YO<FUA;"!]"B`@("`@("`@+F)O;&1I=&%L:6,@>R!F;VYT+7=E:6=H=#H@
M8F]L9#L@9F]N="US='EL93H@:71A;&EC('T*("`@("`@("`N<F5D8F]L9"`@
M("![(&9O;G0M=V5I9VAT.B!B;VQD.R!F;VYT+7-T>6QE.B!N;W)M86P[(&-O
M;&]R.B`C9F8P,#`P('T*("`@("`@("`N8FQU96)O;&0@("![(&9O;G0M=V5I
M9VAT.B!B;VQD.R!F;VYT+7-T>6QE.B!N;W)M86P[(&-O;&]R.B`C,#`P,&9F
M('T*("`@("`@("`N8F=G<F5Y("`@("![(&)A8VMG<F]U;F0M8V]L;W(Z("-E
M.64Y93D@?0H@("`@("`@("YB9VMH86MI("`@('L@8F%C:V=R;W5N9"UC;VQO
M<CH@(V0X9#AC,"!]"B`@("`@("`@+G)E9R`@("`@("`@>R!F;VYT+7-I>F4Z
M(#=P=#L@=F5R=&EC86PM86QI9VXZ('-U<&5R('T*("`@("`@("!I;6<@("`@
M("`@("![('9E<G1I8V%L+6%L:6=N.B!M:61D;&4[(&)O<F1E<BUS='EL93H@
M;F]N93L@8F]R9&5R+7=I9'1H.B`P<'@@?0H@("`@("`@(&$@("`@("`@("`@
M('L@9F]N="UW96EG:'0Z(&)O;&0[(&9O;G0M<W1Y;&4Z(&ET86QI8SL@8V]L
M;W(Z(",Y.3,S,#`[('1E>'0M9&5C;W)A=&EO;CH@;F]N92!]"B`@("`@("`@
M83IV:7-I=&5D("`@>R!F;VYT+7=E:6=H=#H@8F]L9#L@9F]N="US='EL93H@
M:71A;&EC.R!C;VQO<CH@(SDY,S,P,#L@=&5X="UD96-O<F%T:6]N.B!N;VYE
M('T*("`@("`@("!A.FAO=F5R("`@("![(&9O;G0M=V5I9VAT.B!B;VQD.R!F
M;VYT+7-T>6QE.B!I=&%L:6,[(&-O;&]R.B`C8V,S,S`P.R!T97AT+61E8V]R
M871I;VXZ('5N9&5R;&EN92!]"B`@("`@("`@=&%B;&4@("`@("`@>R!B;W)D
M97(Z(#!P>"!N;VYE(&)L86-K.R!B;W)D97(M<W!A8VEN9SH@,'!X('T*("`@
M("`@("!T9"`@("`@("`@("![(&9O;G0M9F%M:6QY.B!!<FEA;"P@2&5L=F5T
M:6-A+"!S86YS+7-E<FEF.R!F;VYT+7-I>F4Z(#$Q<'0[(&9O;G0M=V5I9VAT
M.B!N;W)M86P[(&9O;G0M<W1Y;&4Z(&YO<FUA;"!]"B`@("`\+W-T>6QE/@H\
M+VAE860^"CQB;V1Y(&-L87-S/2)N;W)M86PB/@H\/W!H<`HO+R!$96)U9R!O
M=71P=71S('1H92!R87<@9&%T82!F971C:&5D(&)Y('1H92!F;W)E86-H+6QO
M;W`@86)O=F4L(&IU<W0@9F]R(&-H96-K:6YG+BXN"FEF("AI<W-E="@D7T=%
M5%LB9&5B=6<B72DI('L*("`@(&5C:&\@(CQP<F4^7&XB.PH@("`@=F%R7V1U
M;7`H)&QO8V%T:6]N+"`D=V5A=&AE<BP@)&9O<F5C87-T*3L*("`@(&5C:&\@
M(CPO<')E/EQN(CL*?2`*/SX*/'-P86X@8VQA<W,](F)L=65B;VQD(B!S='EL
M93TB9F]N="US:7IE.B`Q,W!T(CY796%T:&5R($9O<F5C87-T/"]S<&%N/B!C
M<F5A=&5D('=I=&@@/&$@<W1Y;&4](F9O;G0M<VEZ93H@,3-P="(@:')E9CTB
M:'1T<#HO+W!E87(N<&AP+FYE="\B/E!%05)S/"]A/B`\82!S='EL93TB9F]N
M="US:7IE.B`Q,W!T(B!H<F5F/2)H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA
M9V4O4V5R=FEC97-?5V5A=&AE<B\B/E-E<G9I8V5S7U=E871H97(\+V$^/&)R
M/@H\=&%B;&4@<W1Y;&4](G=I9'1H.B`Q,#`E(CX*/'1R/@H@("`@/'1D/@H@
M("`@("`@(#QT86)L92!B;W)D97(](C`B('-T>6QE/2)B;W)D97(M=&]P.B`R
M<'@@<V]L:60@(S4R-&(Y.#L@8F]R9&5R+6)O='1O;3H@,G!X('-O;&ED("-E
M,&4S8V4[(&)O<F1E<BUL969T.B`R<'@@<V]L:60@(V(X8C9C,3L@8F]R9&5R
M+7)I9VAT.B`R<'@@<V]L:60@(SAB.#=A,#L@=VED=&@Z(#$P,"4B/@H@("`@
M("`@(#QT<B!C;&%S<STB8F=K:&%K:2(^"B`@("`@("`@("`@(#QT9"!C;VQS
M<&%N/2(T(B!S='EL93TB8F]R9&5R+6)O='1O;3H@,G!X('-O;&ED("-A8F%D
M83(B/CQS<&%N(&-L87-S/2)B;VQD(CX\/STD;&]C871I;VY;(FYA;64B73\^
M("@\/STD<V5A<F-H/SXI/"]S<&%N/CPO=&0^"B`@("`@("`@/"]T<CX*("`@
M("`@("`\='(^"B`@("`@("`@("`@(#QT9#X\<W!A;B!C;&%S<STB8F]L9"(^
M4W5N<FES93H\+W-P86X^(#QI;6<@<W1Y;&4](G=I9'1H.B`R.'!X.R!H96EG
M:'0Z(#$S<'@[('9E<G1I8V%L+6%L:6=N.B!B87-E;&EN92(@86QT/2)3=6YR
M:7-E(B!S<F,](FEM86=E<R]S=6YR:7-E+F=I9B(^(#P_/21L;V-A=&EO;ELB
M<W5N<FES92)=/SX\+W1D/@H@("`@("`@("`@("`\=&0^/'-P86X@8VQA<W,]
M(F)O;&0B/E-U;G-E=#H\+W-P86X^(#QI;6<@<W1Y;&4](G=I9'1H.B`S,'!X
M.R!H96EG:'0Z(#$U<'@[('9E<G1I8V%L+6%L:6=N.B!B87-E;&EN92(@86QT
M/2)3=6YS970B('-R8STB:6UA9V5S+W-U;G-E="YG:68B/B`\/STD;&]C871I
M;VY;(G-U;G-E=")=/SX\+W1D/@H@("`@("`@("`@("`\=&0@<W1Y;&4](G=I
M9'1H.B`Q.3!P>"(^)FYB<W`[/"]T9#X*("`@("`@("`@("`@/'1D('-T>6QE
M/2)W:61T:#H@875T;R(^)FYB<W`[/"]T9#X*("`@("`@("`\+W1R/@H@("`@
M("`@(#QT<B!S='EL93TB:&5I9VAT.B`Q-7!X(CX*("`@("`@("`@("`@/'1D
M(&YO=W)A<#X\<W!A;B!C;&%S<STB8F]L9"(^5&5M<&5R871U<F4Z/"]S<&%N
M/B`\/SUR;W5N9"@D=V5A=&AE<ELB=&5M<&5R871U<F4B72P@,2DN)'5N:71S
M6R)T96UP(ET_/CPO=&0^"B`@("`@("`@("`@(#QT9"!N;W=R87`^/'-P86X@
M8VQA<W,](F)O;&0B/D1E=R!P;VEN=#H\+W-P86X^(#P_/7)O=6YD*"1W96%T
M:&5R6R)D97=0;VEN=")=+"`Q*2XD=6YI='-;(G1E;7`B73\^/"]T9#X*("`@
M("`@("`@("`@/'1D(&YO=W)A<#X\<W!A;B!C;&%S<STB8F]L9"(^1F5L="!T
M96UP97)A='5R93H\+W-P86X^(#P_/7)O=6YD*"1W96%T:&5R6R)F96QT5&5M
M<&5R871U<F4B72P@,2DN)'5N:71S6R)T96UP(ET_/CPO=&0^"B`@("`@("`@
M("`@(#QT9"!R;W=S<&%N/2(T(B!V86QI9VX](G1O<"(^"B`@("`@("`@("`@
M("`@("`\<W!A;B!C;&%S<STB8F]L9"(^5')E;F0Z/"]S<&%N/CQB<CX*/#]P
M:'`*:68@*&ES<V5T*"1W96%T:&5R6R)T<F5N9")=*2`F)B!S:7IE;V8H)'=E
M871H97);(G1R96YD(ETI*2!["B`@("`O+R!/=71P=70@=&AE('1R96YD<RP@
M;&]O<"!T:')O=6=H('1H92!A<G)A>7,L"B`@("`O+R!C;VYV97)T('1H92!S
M='5F9B!T;R!N:6-E(&QO;VMI;F<@9&5S:6=N+"!J861D82P@:F%D9&$N+BX*
M("`@(&9O<F5A8V@@*"1W96%T:&5R6R)T<F5N9")=(&%S("1T<F5N9"D@>PH@
M("`@("`@(&9O<F5A8V@@*"1T<F5N9"!A<R`D:V5Y(#T^("1V86PI('L*("`@
M("`@("`@("`@<W=I=&-H("@D:V5Y*2!["B`@("`@("`@("`@("`@("!C87-E
M(")T>7!E(CH*("`@("`@("`@("`@("`@("`@("!S=VET8V@@*"1V86PI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B3D]324<B.@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`](").;R!3:6=N:69I8V%N
M="!796%T:&5R(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")414U03R(Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<W1R:6YG(#T@(E1E;7!O<F%R>2!7
M96%T:&5R(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@("`@("`@("!C87-E(")"14--1R(Z"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<W1R:6YG(#T@(E=E871H97(@0F5C;VUI
M;F<B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1V86QU92`@
M/2`B(CL*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("AA<G)A>2@B9G)O
M;2(L(")T;R(L(")A="(I(&%S("1T:6UE*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D=')E;F1;)'1I;65=*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'9A;'5E("X]("(@(BXD=&EM92XB("(N)'1R
M96YD6R1T:6UE73L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`H)'9A;'5E("$]
M("(B*2`_("1V86QU92`@/2!T<FEM*"1V86QU92DN(CHB.B(B.PH@("`@("`@
M("`@("`@("`@("`@("1S=')I;F<@/2`G/'-P86X@8VQA<W,](FET86QI8R(^
M)RXD<W1R:6YG+B<\+W-P86X^)SL*("`@("`@("`@("`@("`@("`@("`D=F%L
M=64@(#T@)SQS<&%N(&-L87-S/2)I=&%L:6,B/B<N)'9A;'5E+B<\+W-P86X^
M)SL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M(&-A<V4@(G=I;F0B.@H@("`@("`@("`@("`@("`@("`@("1S=')I;F<@/2`B
M5VEN9#HB.PH@("`@("`@("`@("`@("`@("`@("1V86QU92`@/2`H<W1R=&]L
M;W=E<B@D=')E;F1;(G=I;F1$:7)E8W1I;VXB72D@/3T@(F-A;&TB*2`_(")#
M86QM(B`Z(")&<F]M('1H92`B+B1T<F5N9%LB=VEN9$1I<F5C=&EO;B)=+B(@
M*"(N)'1R96YD6R)W:6YD1&5G<F5E<R)=+B(F9&5G.RD@870@(BYR;W5N9"@D
M=')E;F1;(G=I;F0B72P@,2DN)'5N:71S6R)W:6YD(ET["B`@("`@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1T<F5N9%LB=VEN9%9A<FEA8FEL:71Y(ETI
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`N/2`B+"!V87)I
M86)L92!F<F]M("(N)'1R96YD6R)W:6YD5F%R:6%B:6QI='DB75LB9G)O;2)=
M+B(F9&5G.R!T;R`B+B1T<F5N9%LB=VEN9%9A<FEA8FEL:71Y(EU;(G1O(ETN
M(B9D96<[(CL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1T<F5N9%LB=VEN9$=U<W0B72DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'9A;'5E("X]("(L('=I=&@@9W5S=',@=7`@
M=&\@(BYR;W5N9"@D=')E;F1;(G=I;F1'=7-T(ETL(#$I+B1U;FET<ULB=VEN
M9")=.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(G9I<VEB:6QI='DB.@H@
M("`@("`@("`@("`@("`@("`@("1S=')I;F<@/2`B5FES:6)I;&ET>3HB.PH@
M("`@("`@("`@("`@("`@("`@("1V86QU92`@/2!S=')T;VQO=V5R*"1T<F5N
M9%LB=FES475A;&EF:65R(ETI+B(@(BYR;W5N9"@D=')E;F1;(G9I<VEB:6QI
M='DB72P@,2DN)'5N:71S6R)V:7,B73L*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(F-L;W5D<R(Z"B`@("`@("`@
M("`@("`@("`@("`@)'-T<FEN9R`](")#;&]U9',Z(CL*("`@("`@("`@("`@
M("`@("`@("`D=F%L=64@(#T@(B(["B`@("`@("`@("`@("`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@<VEZ96]F*"1V86PI.R`D:2LK*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1C;&]U9"`]('5C=V]R9',H)'9A;%LD:5U;(F%M
M;W5N=")=*3L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1V
M86Q;)&E=6R)T>7!E(ETI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D8VQO=60@+CT@(B`B+B1V86Q;)&E=6R)T>7!E(ET["B`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1V86Q;)&E=6R)H96EG:'0B72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1C;&]U9"`N/2`B(&%T("(N)'9A;%LD:5U;(FAE:6=H=")=
M+B1U;FET<ULB:&5I9VAT(ET["B`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E("X]("1C;&]U9"XB("([
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@8V%S92`B8V]N9&ET:6]N(CH*("`@("`@
M("`@("`@("`@("`@("`D<W1R:6YG(#T@(D-O;F1I=&EO;CHB.PH@("`@("`@
M("`@("`@("`@("`@("1V86QU92`@/2!U8W=O<F1S*"1V86PI.PH@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B<')E
M<W-U<F4B.@H@("`@("`@("`@("`@("`@("`@("1S=')I;F<@/2`B4')E<W-U
M<F4Z(CL*("`@("`@("`@("`@("`@("`@("`D=F%L=64@(#T@<F]U;F0H)'9A
M;"P@,2DN)'5N:71S6R)P<F5S(ET["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("!C87-E(")F<F]M(CH*("`@("`@("`@("`@
M("`@(&-A<V4@(G1O(CH*("`@("`@("`@("`@("`@(&-A<V4@(F%T(CH*("`@
M("`@("`@("`@("`@(&-A<V4@(G=I;F1$:7)E8W1I;VXB.@H@("`@("`@("`@
M("`@("`@8V%S92`B=VEN9$1E9W)E97,B.@H@("`@("`@("`@("`@("`@8V%S
M92`B=VEN9%9A<FEA8FEL:71Y(CH*("`@("`@("`@("`@("`@(&-A<V4@(G=I
M;F1'=7-T(CH*("`@("`@("`@("`@("`@(&-A<V4@(G9I<U%U86QI9FEE<B(Z
M"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64@,CL*("`@("`@("`@("`@
M("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`]("(B
M.R`D=F%L=64@/2`B(CL*("`@("`@("`@("`@("`@("`@("!V87)?9'5M<"@D
M:V5Y+"`D=F%L*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@?0H_/@H@("`@("`@("`@("`@("`@/#\])'-T<FEN9S\^(#P_/21V
M86QU93\^/&)R/@H\/W!H<`H@("`@("`@('T*"B`@("!]"GT@96QS92!["C\^
M"B`@("`@("`@("`@("`@("!N;VYE/&)R/@H\/W!H<`I]"C\^"B`@("`@("`@
M("`@("`@("`\<W!A;B!C;&%S<STB8F]L9"(^4F5M87)K<SH\+W-P86X^/&)R
M/@H\/W!H<`II9B`H:7-S970H)'=E871H97);(G)E;6%R:R)=*2`F)B!S:7IE
M;V8H)'=E871H97);(G)E;6%R:R)=*2D@>PH@("`@+R\@4V%M92!F;W(@=&AE
M(')E;6%R:W,L(&5V96X@;&5S<R!S<&5C=&%C=6QA<BXN+@H@("`@9F]R96%C
M:"@D=V5A=&AE<ELB<F5M87)K(ET@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@
M("`@<W=I=&-H("@D:V5Y*2!["B`@("`@("`@("`@(&-A<V4@(F%U=&]S=&%T
M:6]N(CH*("`@("`@("`@("`@8V%S92`B<')E<W-C:&<B.@H@("`@("`@("`@
M("!C87-E(")N;W-P96-I(CH*("`@("`@("`@("`@8V%S92`B<W5N9'5R871I
M;VXB.@H@("`@("`@("`@("!C87-E(")M86EN=&%I;B(Z"B`@("`@("`@("`@
M("`@("`D<W1R:6YG(#T@(B(["B`@("`@("`@("`@("`@("`D=F%L=64@(#T@
M)'9A;#L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E
M(")S96%P<F5S<W5R92(Z"B`@("`@("`@("`@("`@("`D<W1R:6YG(#T@(E!R
M97-S=7)E(&%T('-E86QE=F5L.B(["B`@("`@("`@("`@("`@("`D=F%L=64@
M(#T@<F]U;F0H)'9A;"P@,2DN)'5N:71S6R)P<F5S(ET["B`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`B,6AT96UP(CH*("`@("`@
M("`@("`@("`@("1S=')I;F<@/2`B5&5M<&5R871U<F4@9F]R(&QA<W0@:&]U
M<CHB.PH@("`@("`@("`@("`@("`@)'9A;'5E("`](')O=6YD*"1V86PL(#$I
M+B1U;FET<ULB=&5M<")=.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@(&-A<V4@(C%H9&5W(CH*("`@("`@("`@("`@("`@("1S=')I;F<@
M/2`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(CL*("`@("`@("`@("`@("`@
M("1V86QU92`@/2!R;W5N9"@D=F%L+"`Q*2XD=6YI='-;(G1E;7`B73L*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("(V:&UA>'1E
M;7`B.@H@("`@("`@("`@("!C87-E("(V:&UI;G1E;7`B.@H@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D=V5A=&AE<ELB<F5M87)K(EU;(C9H;6%X=&5M
M<")=*2`F)B`A:7-S970H)'=E871H97);(G)E;6%R:R)=6R(V:&UI;G1E;7`B
M72DI('L*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU92@R*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1S=')I;F<@/2`B36%X+TUI
M;B!496UP(&9O<B!L87-T(#8@:&]U<G,Z(CL*("`@("`@("`@("`@("`@("1V
M86QU92`@/2`H:7-S970H)'=E871H97);(G)E;6%R:R)=6R(V:&UA>'1E;7`B
M72DI(#\@<F]U;F0H)'=E871H97);(G)E;6%R:R)=6R(V:&UA>'1E;7`B72P@
M,2DN)'5N:71S6R)T96UP(ET@.B`B+2(["B`@("`@("`@("`@("`@("`D=F%L
M=64@+CT@(B\B.PH@("`@("`@("`@("`@("`@)'9A;'5E("X]("AI<W-E="@D
M=V5A=&AE<ELB<F5M87)K(EU;(C9H;6EN=&5M<")=*2D@/R!R;W5N9"@D=V5A
M=&AE<ELB<F5M87)K(EU;(C9H;6EN=&5M<")=+"`Q*2XD=6YI='-;(G1E;7`B
M72`Z("(M(CL*("`@("`@("`@("`@("`@('5N<V5T*"1W96%T:&5R6R)R96UA
M<FLB75LB-FAM87AT96UP(ETI.R!U;G-E="@D=V5A=&AE<ELB<F5M87)K(EU;
M(C9H;6EN=&5M<")=*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("!C87-E("(R-&AM87AT96UP(CH*("`@("`@("`@("`@8V%S92`B,C1H
M;6EN=&5M<"(Z"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1W96%T:&5R
M6R)R96UA<FLB75LB,C1H;6%X=&5M<")=*2`F)B`A:7-S970H)'=E871H97);
M(G)E;6%R:R)=6R(R-&AM:6YT96UP(ETI*2!["B`@("`@("`@("`@("`@("`@
M("`@8V]N=&EN=64H,BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`D<W1R:6YG(#T@(DUA>"]-:6X@5&5M<"!F;W(@;&%S="`R-"!H;W5R
M<SHB.PH@("`@("`@("`@("`@("`@)'9A;'5E("`]("AI<W-E="@D=V5A=&AE
M<ELB<F5M87)K(EU;(C(T:&UA>'1E;7`B72DI(#\@<F]U;F0H)'=E871H97);
M(G)E;6%R:R)=6R(R-&AM87AT96UP(ETL(#$I+B1U;FET<ULB=&5M<")=(#H@
M(BTB.PH@("`@("`@("`@("`@("`@)'9A;'5E("X]("(O(CL*("`@("`@("`@
M("`@("`@("1V86QU92`N/2`H:7-S970H)'=E871H97);(G)E;6%R:R)=6R(R
M-&AM:6YT96UP(ETI*2`_(')O=6YD*"1W96%T:&5R6R)R96UA<FLB75LB,C1H
M;6EN=&5M<")=+"`Q*2XD=6YI='-;(G1E;7`B72`Z("(M(CL*("`@("`@("`@
M("`@("`@('5N<V5T*"1W96%T:&5R6R)R96UA<FLB75LB,C1H;6%X=&5M<")=
M*3L@=6YS970H)'=E871H97);(G)E;6%R:R)=6R(R-&AM:6YT96UP(ETI.PH@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@(G-N;W=D
M97!T:"(Z"B`@("`@("`@("`@("`@("`D<W1R:6YG(#T@(E-N;W<@9&5P=&@Z
M(CL*("`@("`@("`@("`@("`@("1V86QU92`@/2`D=F%L+B1U;FET<ULB<F%I
M;B)=.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@
M(G-N;W=E<75I=B(Z"B`@("`@("`@("`@("`@("`D<W1R:6YG(#T@(E=A=&5R
M(&5Q=6EV86QE;G0@;V8@<VYO=SHB.PH@("`@("`@("`@("`@("`@)'9A;'5E
M("`]("1V86PN)'5N:71S6R)R86EN(ET["B`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@8V%S92`B<V5N<V]R<R(Z"B`@("`@("`@("`@("`@
M("`D<W1R:6YG(#T@(B(["B`@("`@("`@("`@("`@("`D=F%L=64@(#T@:6UP
M;&]D92@B/&)R/B(L("1V86PI.PH@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`D<W1R:6YG(#T@
M(B([("1V86QU92`]("(B.PH@("`@("`@("`@("`@("`@=F%R7V1U;7`H)&ME
M>2P@)'9A;"D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"C\^
M"B`@("`@("`@("`@("`@("`\/STD<W1R:6YG/SX@/#\])'9A;'5E/SX\8G(^
M"CP_<&AP"B`@("!]"GT@96QS92!["C\^"B`@("`@("`@("`@("`@("!N;VYE
M/&)R/@H\/W!H<`I]"C\^"B`@("`@("`@("`@(#PO=&0^"B`@("`@("`@/"]T
M<CX*("`@("`@("`\='(@<W1Y;&4](FAE:6=H=#H@,35P>"(^"B`@("`@("`@
M("`@(#QT9"!C;VQS<&%N/2(R(B!S='EL93TB=VED=&@Z(#,Q,'!X(B!N;W=R
M87`^/'-P86X@8VQA<W,](F)O;&0B/E!R97-S=7)E.CPO<W!A;CX@/#\]<F]U
M;F0H)'=E871H97);(G!R97-S=7)E(ETL(#$I+B1U;FET<ULB<')E<R)=/SX\
M+W1D/@H@("`@("`@("`@("`\=&0@;F]W<F%P/CQS<&%N(&-L87-S/2)B;VQD
M(CY(=6UI9&ET>3H\+W-P86X^(#P_/21W96%T:&5R6R)H=6UI9&ET>2)=/SXE
M/"]T9#X*("`@("`@("`\+W1R/@H@("`@("`@(#QT<B!S='EL93TB:&5I9VAT
M.B`Q-7!X(CX*("`@("`@("`@("`@/'1D(&-O;'-P86X](C(B(&YO=W)A<#X*
M("`@("`@("`@("`@("`@(#QS<&%N(&-L87-S/2)B;VQD(CY7:6YD.CPO<W!A
M;CX@/#\]<W1R=&]L;W=E<B@D=V5A=&AE<ELB=VEN9$1I<F5C=&EO;B)=*2`]
M/2`B8V%L;2(@/R`B0V%L;2(@.B`B1G)O;2!T:&4@(BXD=V5A=&AE<ELB=VEN
M9$1I<F5C=&EO;B)=+B(@*"(N)'=E871H97);(G=I;F1$96=R965S(ETN(B9D
M96<[*2!A="`B+G)O=6YD*"1W96%T:&5R6R)W:6YD(ETL(#$I+B1U;FET<ULB
M=VEN9")=/SX@"B`@("`@("`@("`@("`@("`\/SUI<W-E="@D=V5A=&AE<ELB
M=VEN9%9A<FEA8FEL:71Y(ETI(#\@(CQB<CYV87)I86)L92!F<F]M("(N)'=E
M871H97);(G=I;F1687)I86)I;&ET>2)=6R)F<F]M(ETN(B9D96<[('1O("(N
M)'=E871H97);(G=I;F1687)I86)I;&ET>2)=6R)T;R)=+B(F9&5G.R(@.B`B
M(C\^(`H@("`@("`@("`@("`@("`@/#\]:7-S970H)'=E871H97);(G=I;F1'
M=7-T(ETI(#\@(CQB<CYW:71H(&=U<W1S('5P('1O("(N<F]U;F0H)'=E871H
M97);(G=I;F1'=7-T(ETL(#$I+B1U;FET<ULB=VEN9")=(#H@(B(_/B`*("`@
M("`@("`@("`@/"]T9#X*("`@("`@("`@("`@/'1D('9A;&EG;CTB=&]P(B!N
M;W=R87`^/'-P86X@8VQA<W,](F)O;&0B/E9I<VEB:6QI='DZ/"]S<&%N/B`\
M/SUS=')T;VQO=V5R*"1W96%T:&5R6R)V:7-1=6%L:69I97(B72D_/B`\/SUR
M;W5N9"@D=V5A=&AE<ELB=FES:6)I;&ET>2)=+"`Q*2XD=6YI='-;(G9I<R)=
M/SX\+W1D/@H@("`@("`@(#PO='(^"B`@("`@("`@/'1R/@H@("`@("`@("`@
M("`\=&0^/'-P86X@8VQA<W,](F)O;&0B/D-U<G)E;G0@8V]N9&ET:6]N.CPO
M<W!A;CX\8G(^/#\]:7-S970H)'=E871H97);(F-O;F1I=&EO;B)=*2`_('5C
M=V]R9',H)'=E871H97);(F-O;F1I=&EO;B)=*2`Z(").;R!3:6=N:69I8V%N
M="!796%T:&5R(C\^/"]T9#X*("`@("`@("`@("`@/'1D/CQI;6<@<W1Y;&4]
M(FAE:6=H=#H@,S)P>#L@=VED=&@Z(#,R<'@B(&%L=#TB/#\]:7-S970H)'=E
M871H97);(F-O;F1I=&EO;B)=*2`_('5C=V]R9',H)'=E871H97);(F-O;F1I
M=&EO;B)=*2`Z(").;R!3:6=N:69I8V%N="!796%T:&5R(C\^(B!S<F,](FEM
M86=E<R\S,G@S,B\\/STD=V5A=&AE<ELB8V]N9&ET:6]N26-O;B)=/SXN<&YG
M(CX\+W1D/@H\/W!H<`II9B`H:7-S970H)'=E871H97);(G!R96-I<&ET871I
M;VXB72D@)B8@<VEZ96]F*"1W96%T:&5R6R)P<F5C:7!I=&%T:6]N(ETI*2![
M"B`@("`O+R!/=71P=70@82!L:6YE(&9O<B!E86-H('1Y<&4@;V8@<')E8VEP
M:71A=&EO;BP*("`@("\O(&1I<W1I;F=U:7-H(&)E='=E96X@<W1R:6YG(&%N
M9"!N=6UE<FEC('9A;'5E<PH_/@H@("`@("`@("`@("`@("`@/&)R/CQS<&%N
M(&-L87-S/2)B;VQD(CY0<F5C:7!I=&%T:6]N.CPO<W!A;CX\8G(^"CP_<&AP
M"B`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'=E871H97);(G!R96-I
M<&ET871I;VXB72D[("1I*RLI('L*("`@("`@("`D<')E8VEP(#T@(FQA<W0@
M(BXD=V5A=&AE<ELB<')E8VEP:71A=&EO;B)=6R1I75LB:&]U<G,B72XB:#H@
M(BXD=V5A=&AE<ELB<')E8VEP:71A=&EO;B)=6R1I75LB86UO=6YT(ET["B`@
M("`@("`@)'!R96-I<"`N/2`H8W1Y<&5?86QP:&$H)'=E871H97);(G!R96-I
M<&ET871I;VXB75LD:5U;(F%M;W5N=")=*2D@/R`B(B`Z("1U;FET<ULB<F%I
M;B)=.PH_/@H@("`@("`@("`@("`@("`@/#\])'!R96-I<#\^/&)R/@H\/W!H
M<`H@("`@?0I]"C\^"B`@("`@("`@("`@(#PO=&0^"B`@("`@("`@("`@(#QT
M9"!V86QI9VX](G1O<"(^"B`@("`@("`@("`@("`@("`\<W!A;B!C;&%S<STB
M8F]L9"(^0VQO=61S.CPO<W!A;CX\8G(^"CP_<&AP"FEF("AI<W-E="@D=V5A
M=&AE<ELB8VQO=61S(ETI("8F('-I>F5O9B@D=V5A=&AE<ELB8VQO=61S(ETI
M*2!["B`@("`O+R!996%H+"!C;&]U9',N+BX@<V%M92!A<R!I;B!T:&4@=')E
M;F0@:&%N9&QI;F<N+BX*("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D
M=V5A=&AE<ELB8VQO=61S(ETI.R`D:2LK*2!["B`@("`@("`@)&-L;W5D(#T@
M=6-W;W)D<R@D=V5A=&AE<ELB8VQO=61S(EU;)&E=6R)A;6]U;G0B72D["B`@
M("`@("`@:68@*&ES<V5T*"1W96%T:&5R6R)C;&]U9',B75LD:5U;(G1Y<&4B
M72DI('L*("`@("`@("`@("`@)&-L;W5D("X]("(@(BXD=V5A=&AE<ELB8VQO
M=61S(EU;)&E=6R)T>7!E(ET["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E
M="@D=V5A=&AE<ELB8VQO=61S(EU;)&E=6R)H96EG:'0B72DI('L*("`@("`@
M("`@("`@)&-L;W5D("X]("(@870@(BXD=V5A=&AE<ELB8VQO=61S(EU;)&E=
M6R)H96EG:'0B72XD=6YI='-;(FAE:6=H=")=.PH@("`@("`@('T*/SX*("`@
M("`@("`@("`@("`@(#P_/21C;&]U9#\^/&)R/@H\/W!H<`H@("`@?0I](&5L
M<V4@>PH_/@H@("`@("`@("`@("`@("`@0VQE87(@0F5L;W<@/#\])&UE=&%R
M+3YC;VYV97)T1&ES=&%N8V4H,3(P,#`L(")F="(L("1U;FET<ULB:&5I9VAT
M(ETI+B1U;FET<ULB:&5I9VAT(ET_/B`*/#]P:'`*?0H_/@H@("`@("`@("`@
M("`\+W1D/@H@("`@("`@(#PO='(^"B`@("`@("`@/"]T86)L93X*("`@(#PO
M=&0^"CPO='(^"CQT<CX*("`@(#QT9#X*("`@("`@("`\=&%B;&4@<W1Y;&4]
M(F)O<F1E<BUT;W`Z(#)P>"!S;VQI9"`C-3(T8CDX.R!B;W)D97(M8F]T=&]M
M.B`R<'@@<V]L:60@(V4P93-C93L@8F]R9&5R+6QE9G0Z(#)P>"!S;VQI9"`C
M8CAB-F,Q.R!B;W)D97(M<FEG:'0Z(#)P>"!S;VQI9"`C.&(X-V$P.R!W:61T
M:#H@,3`P)2(^"B`@("`@("`@/'1R(&-L87-S/2)B9VMH86MI(CX*("`@("`@
M("`@("`@/'1D(&-O;'-P86X](C,B(&%L:6=N/2)C96YT97(B('-T>6QE/2)B
M;W)D97(M8F]T=&]M.B`R<'@@<V]L:60@(V%B861A,B(^/'-P86X@8VQA<W,]
M(F)O;&0B/D9O<F5C87-T("A4048I/"]S<&%N/CQB<CYV86QI9"!F<F]M(#QS
M<&%N(&-L87-S/2)B;VQD(CX\/STD9F]R96-A<W1;(G9A;&ED1G)O;2)=/SX\
M+W-P86X^('1O(#QS<&%N(&-L87-S/2)B;VQD(CX\/STD9F]R96-A<W1;(G9A
M;&ED5&\B73\^/"]S<&%N/CPO=&0^"B`@("`@("`@/"]T<CX*("`@("`@("`\
M='(@=F%L:6=N/2)T;W`B/@H@("`@("`@("`@("`\=&0@8V]L<W!A;CTB,R(^
M"B`@("`@("`@("`@("`@("`\=&%B;&4@<W1Y;&4](G=I9'1H.B`Q,#`E(CX*
M("`@("`@("`@("`@("`@(#QT<CX*("`@("`@("`@("`@("`@("`@("`\=&0@
M86QI9VX](F-E;G1E<B(@8VQA<W,](F)G:VAA:VDB('-T>6QE/2)H96EG:'0Z
M(#$U<'@[(&)O<F1E<BUT;W`Z(#)P>"!S;VQI9"`C9#AD.&,P.R!B;W)D97(M
M<FEG:'0Z(#)P>"!S;VQI9"`C.&(X-V$P.R!B;W)D97(M;&5F=#H@,G!X('-O
M;&ED("-D.&0X8S`B/B9N8G-P.SPO=&0^"B`@("`@("`@("`@("`@("`@("`@
M/'1D(&%L:6=N/2)C96YT97(B('-T>6QE/2)W:61T:#H@,3@E(CX\<W!A;B!C
M;&%S<STB8F]L9"(^365T96]R;VQO9VEC86P@0V]N9&ET:6]N<SPO<W!A;CX\
M+W1D/@H@("`@("`@("`@("`@("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(B!S
M='EL93TB=VED=&@Z(#$X)2(@8VQA<W,](F)G9W)E>2(^/'-P86X@8VQA<W,]
M(F)O;&0B/E=I;F0\+W-P86X^/"]T9#X*("`@("`@("`@("`@("`@("`@("`\
M=&0@86QI9VX](F-E;G1E<B(@<W1Y;&4](G=I9'1H.B`Q."4B/CQS<&%N(&-L
M87-S/2)B;VQD(CY6:7-I8FEL:71Y/"]S<&%N/CPO=&0^"B`@("`@("`@("`@
M("`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B('-T>6QE/2)W:61T:#H@,3@E
M(B!C;&%S<STB8F=G<F5Y(CX\<W!A;B!C;&%S<STB8F]L9"(^0VQO=61S/"]S
M<&%N/CPO=&0^"B`@("`@("`@("`@("`@("`@("`@/'1D(&%L:6=N/2)C96YT
M97(B('-T>6QE/2)W:61T:#H@,3@E(CX\<W!A;B!C;&%S<STB8F]L9"(^0V]N
M9&ET:6]N/"]S<&%N/CPO=&0^"B`@("`@("`@("`@("`@("`\+W1R/@H\/W!H
M<`HD=&EM97,@/2!A<G)A>5]K97ES*"1F;W)E8V%S=%LB=&EM92)=*3L*)'!R
M92`@(#T@87)R87DH(G=I;F0B(#T^(#`L(")V:7,B(#T^(#`L(")C;&]U9',B
M(#T^(#`L(")C;VYD(B`]/B`P*3L*+R\@3VLL('1H92!F;W)E8V%S="!I<R!A
M(&)I="!M;W)E(&EN=&5R97-T:6YG+"!A<R!))VT@=&%K:6YG(&$@9F5W"B\O
M('!R96-A=71I;VYS(&AE<F4@<V\@=&AA="!T:&4@=&%B;&4@:7-N)W0@9FEL
M;&5D('5P('1O('1H92!M87@N"B\O(&\@268@82!V86QU92!I<R!R97!E871E
M9"!I;B!T:&4@;F5X="!M86IO<B!T:6UE<VQO="`H;F]T('=H96X*+R\@("!S
M:6=N:69I8V%N="!W96%T:&5R(&-H86YG97,@87)E('!R;V-E<W-E9"DL(&ET
M)W,@;F]T('!R:6YT960*+R\@;R!3:6=N:69I8V%N="!W96%T:&5R(&=E=',@
M:71S(&]W;B!R;W=S+"!W:71H('1I;65S('!R:6YT960@;F]R;6%L"B\O("`@
M87,@:6X@;W!P;W-I=&EO;B!T;R!B;VQD('!R:6YT(&9O<B!M86IO<B!T:6UE
M<VQO=',*+R\@;R!4:&4@=VAI;&4H)')O=RDM8V]N<W1R=6-T(&)E;&]W(&ES
M(&9O<B!H86YD;&EN9R!T:&4@<VEG;FEF:6-A;G0*+R\@("!W96%T:&5R+"!A
M<R!)('!O:6YT("1R;W<@=&\@)')O=ULB9FUC(ET@869T97)W87)D<RP@=VAE
M<F4@=&AE"B\O("`@<VUA;&QE<B!C:&%N9V5S(&%R92!M96YT:6]N960*9F]R
M("@D:2`](#`[("1I(#P@<VEZ96]F*"1F;W)E8V%S=%LB=&EM92)=*3L@)&DK
M*RD@>PH@("`@)')O=R`]("1F;W)E8V%S=%LB=&EM92)=6R1T:6UE<ULD:5U=
M.PH*("`@("\O($-R96%T92!T:6UE<W1A;7`*("`@("1S=&%R="`]("1T:6UE
M<ULD:5T["B`@("!I9B`H)&D@*R`Q(#P@<VEZ96]F*"1F;W)E8V%S=%LB=&EM
M92)=*2D@>PH@("`@("`@("1E;F0@/2`D=&EM97-;)&D@*R`Q73L*("`@('T@
M96QS92!["B`@("`@("`@)&5N9"`]('-U8G-T<B@D9F]R96-A<W1;(G9A;&ED
M4F%W(ETL("TR*2XB.C`P(CL*("`@("`@("`D96YD(#T@*"1E;F0@/3T@(C(T
M.C`P(BD@/R`B,#`Z,#`B(#H@)&5N9#L*("`@('T*("`@("1T:6UE("`@(#T@
M)'-T87)T+B(@+2`B+B1E;F0["B`@("`D8VQA<W,@("`]("<@8VQA<W,](F)O
M;&0B)SL*("`@("\O(%1H:7,@:7,@9F]R(&]U='!U='1I;F<@(D)E8V]M:6YG
M(BP@(E1E;7!O<F%R>2(@86YD('-U8V@*("`@("1F;6,@("`@(#T@:7-S970H
M)')O=ULB9FUC(ETI(#\@)')O=ULB9FUC(ET@.B!F86QS93L@"B`@("`D9FUC
M='EP92`]("(B.PH@("`@)&9M8V-N="`@/2`P.PH*("`@('=H:6QE("@D<F]W
M*2!["C\^"B`@("`@("`@("`@("`@("`\='(@8VQA<W,](F)G:VAA:VDB/@H@
M("`@("`@("`@("`@("`@("`@(#QT9"!S='EL93TB:&5I9VAT.B`Q<'@[(&5M
M<'1Y+6-E;&QS.B!S:&]W.R!B;W)D97(M<FEG:'0Z(#)P>"!S;VQI9"`C.&(X
M-V$P.R!B;W)D97(M;&5F=#H@,G!X('-O;&ED("-D.&0X8S`B/CPO=&0^"B`@
M("`@("`@("`@("`@("`@("`@/'1D('-T>6QE/2)H96EG:'0Z(#%P>"(@8V]L
M<W!A;CTB-2(^/"]T9#X*("`@("`@("`@("`@("`@(#PO='(^"B`@("`@("`@
M("`@("`@("`\='(^"B`@("`@("`@("`@("`@("`@("`@/'1D(&%L:6=N/2)C
M96YT97(B(&-L87-S/2)B9VMH86MI(B!S='EL93TB8F]R9&5R+7)I9VAT.B`R
M<'@@<V]L:60@(SAB.#=A,#L@8F]R9&5R+6QE9G0Z(#)P>"!S;VQI9"`C9#AD
M.&,P(B!N;W=R87`^/'-P86X\/STD8VQA<W,_/CX\/STD=&EM93\^/"]S<&%N
M/CPO=&0^"B`@("`@("`@("`@("`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B
M/CP_/21F;6-T>7!E/SX\+W1D/@H\/W!H<`H@("`@("`@("\O(%1H:7,@;&]O
M<',@=&AR;W5G:"!T:&4@879A:6QA8FQE(&1A=&$@86YD('!R;V-E<W-E<R!I
M=`H@("`@("`@("\O(&9O<B!O=71P=70L('1H92!D:69F97)E;G0@;65T:&]D
M<R!W97)E(&%L<F5A9'D@=7-E9"!A8F]V90H@("`@("`@("\O("A/;FQY(&1I
M9F9E<F5N8V4@:7,@=&AE(&-H96-K:6YG(&9O<B!T:&4@<')E+79A;'5E<RXI
M"B`@("`@("`@9F]R96%C:"AA<G)A>2@B=VEN9"(L(")V:7,B+"`B8VQO=61S
M(BP@(F-O;F0B*2!A<R`D=F%L*2!["B`@("`@("`@("`@('-W:71C:"`H)'9A
M;"D@>PH@("`@("`@("`@("`@("`@8V%S92`B=VEN9"(Z"B`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D<F]W6R)W:6YD1&ER96-T:6]N(ETI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1S=')I;F<@/2`B)FYB<W`[(CL*
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D<W1R:6YG(#T@<W1R=&]L;W=E<B@D<F]W6R)W:6YD1&ER96-T
M:6]N(ETI(#T](")C86QM(B`_(")#86QM(B`Z(")&<F]M('1H92`B+B1R;W=;
M(G=I;F1$:7)E8W1I;VXB72XB("@B+B1R;W=;(G=I;F1$96=R965S(ETN(B9D
M96<[*3QB<CYA="`B+G)O=6YD*"1R;W=;(G=I;F0B72P@,2DN)'5N:71S6R)W
M:6YD(ET["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<F]W
M6R)W:6YD4')O8B)=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'-T<FEN9R`N/2`B("@B+B1R;W=;(G=I;F10<F]B(ETN(B4F;F)S<#M0<F]B
M+BDB.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@D<W1R:6YG(#T]/2`D<')E6R)W:6YD(ETI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1S=')I;F<@/2`B)FYB<W`[(CL*
M("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P<F5;(G=I;F0B72`]("1S=')I;F<["B`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@)&-L87-S(#T@)R!C;&%S<STB8F=G<F5Y(B<[
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C
M87-E(")V:7,B.@H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)')O
M=ULB=FES:6)I;&ET>2)=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M<W1R:6YG(#T@(B9N8G-P.R(["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`]('-T<G1O;&]W
M97(H)')O=ULB=FES475A;&EF:65R(ETI+B(@(BYR;W5N9"@D<F]W6R)V:7-I
M8FEL:71Y(ETL(#$I+B1U;FET<ULB=FES(ET["B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D<F]W6R)V:7-0<F]B(ETI*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<W1R:6YG("X]("(@*"(N)')O=ULB=FES
M4')O8B)=+B(E)FYB<W`[4')O8BXI(CL*("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'-T<FEN9R`]/3T@
M)'!R95LB=FES(ETI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S
M=')I;F<@/2`B)FYB<W`[(CL*("`@("`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<F5;(G9I<R)=
M(#T@)'-T<FEN9SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D8VQA<W,@/2`G
M)SL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M(&-A<V4@(F-L;W5D<R(Z"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D<F]W6R)C;&]U9',B72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'-T<FEN9R`]("(F;F)S<#LB.PH@("`@("`@("`@("`@("`@("`@('T@96QS
M92![(`H@("`@("`@("`@("`@("`@("`@("`@("`D8VQO=61S("`]("(B.PH@
M("`@("`@("`@("`@("`@("`@("`@("!F;W(@*"1J(#T@,#L@)&H@/"!S:7IE
M;V8H)')O=ULB8VQO=61S(ETI.R`D:BLK*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D8VQO=60@/2!U8W=O<F1S*"1R;W=;(F-L;W5D<R)=6R1J
M75LB86UO=6YT(ETI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1R;W=;(F-L;W5D<R)=6R1J75LB='EP92)=*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1C;&]U9"`N/2`B("(N)')O=ULB
M8VQO=61S(EU;)&I=6R)T>7!E(ET["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)')O=ULB8VQO=61S(EU;)&I=6R)H96EG:'0B72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D8VQO=60@+CT@(B!A="`B+B1R;W=;(F-L
M;W5D<R)=6R1J75LB:&5I9VAT(ETN)'5N:71S6R)H96EG:'0B73L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D<F]W6R)C;&]U9',B75LD:EU;(G!R;V(B72DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8VQO=60@+CT@
M(B`H(BXD<F]W6R)C;&]U9',B75LD:EU;(G!R;V(B72XB)29N8G-P.U!R;V(N
M*2(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D8VQO=61S("X]("1C;&]U9"XB/&)R/B(["B`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"1C;&]U9',@/3T]("1P<F5;(F-L;W5D<R)=*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<W1R:6YG(#T@(B9N8G-P.R(["B`@("`@
M("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<W1R:6YG("`@("`@("`]("1C;&]U9',["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<')E6R)C;&]U9',B72`]("1C;&]U9',[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@)&-L87-S(#T@)R!C;&%S<STB8F=G
M<F5Y(B<["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("!C87-E(")C;VYD(CH*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1R;W=;(F-O;F1I=&EO;B)=*2!\?"`H:7-S970H)'!R97)O=RD@)B8@
M)'!R97)O=ULB8V]N9&ET:6]N(ET@/3T@)')O=ULB8V]N9&ET:6]N(ETI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1S=')I;F<@/2`B)FYB<W`[(CL*
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D<W1R:6YG(#T@=6-W;W)D<R@D<F]W6R)C;VYD:71I;VXB72D[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1C
M;&%S<R`]("<G.PH@("`@("`@("`@("!]"C\^"B`@("`@("`@("`@("`@("`@
M("`@/'1D('9A;&EG;CTB=&]P(CP_/21C;&%S<S\^/CP_/21S=')I;F<_/CPO
M=&0^"CP_<&AP"B`@("`@("`@?0H_/B`@("`@("`@("`@("`@("`@("`@"B`@
M("`@("`@("`@("`@("`\+W1R/@H\/W!H<`H@("`@("`@("\O($YO=R!C:&5C
M:R!F;W(@<VEG;FEF:6-A;G0@=V5A=&AE<B!C:&%N9V5S(&%N9"!M;W9E"B`@
M("`@("`@+R\@=&AE(')O=R!A8V-O<F1I;F=L>2XN+B!M87EB92!U9VQY(&-O
M9&EN9RP@8G5T('1H:7,*("`@("`@("`O+R!I<R!F;W(@<VAO=VEN9R!D97-I
M9VXL(&YO="!F;W(@9F%N>2!P<F]G<F%M;6EN9R`[+2D*("`@("`@("!I9B`H
M)&9M8R`F)B`D9FUC8VYT(#P@<VEZ96]F*"1F;6,I*2!["B`@("`@("`@("`@
M("1R;W<@("`@(#T@)&9M8ULD9FUC8VYT73L*("`@("`@("`@("`@)&9M8V-N
M="LK.PH@("`@("`@("`@("`D9FUC='EP92`]("1R;W=;(G1Y<&4B73L*("`@
M("`@("`@("`@+R\@0VAE8VL@:68@=V4@:&%V92!A('1I;65S=&%M<"P@9&]N
M)W0@;W5T<'5T(&EF(&ET)W,*("`@("`@("`@("`@+R\@=&AE('-A;64@87,@
M=&AE(&UA:F]R+71I;65S;&]T"B`@("`@("`@("`@(&EF("@A:7-S970H)')O
M=ULB9G)O;2)=*2!\?"`D<F]W6R)F<F]M(ETN(B`M("(N)')O=ULB=&\B72`]
M/2`D=&EM92D@>PH@("`@("`@("`@("`@("`@)'1I;64@/2`B)FYB<W`[(CL*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:6UE("`@
M(#T@)')O=ULB9G)O;2)=+B(@+2`B+B1R;W=;(G1O(ET["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@<W=I=&-H("@D<F]W6R)T>7!E(ETI('L*("`@("`@
M("`@("`@("`@(&-A<V4@(E!23T(B.@H@("`@("`@("`@("`@("`@("`@("1F
M;6-T>7!E(#T@(B(["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("!C87-E(")414U03R(Z"B`@("`@("`@("`@("`@("`@("`@
M)&9M8W1Y<&4@/2`B5&5M<&]R87)Y(CL*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(D)%0TU'(CH*("`@("`@("`@
M("`@("`@("`@("`D9FUC='EP92`](")"96-O;6EN9R(["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*&ES<V5T*"1R;W=;(G!R;V)A8FEL:71Y(ETI*2!["B`@("`@("`@("`@("`@
M("`D9FUC='EP92`N/2`B("@B+B1R;W=;(G!R;V)A8FEL:71Y(ETN(B4F;F)S
M<#M0<F]B+BDB.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)')O=R`](&9A;'-E.PH@("`@("`@('T*("`@('T*?0H_/B`@
M("`@("`@("`@("`@("`*("`@("`@("`@("`@("`@(#QT<CX*("`@("`@("`@
M("`@("`@("`@("`\=&0@8VQA<W,](F)G:VAA:VDB('-T>6QE/2)H96EG:'0Z
M(#%P>#L@96UP='DM8V5L;',Z('-H;W<[(&)O<F1E<BUB;W1T;VTZ(#)P>"!S
M;VQI9"`C9#AD.&,P.R!B;W)D97(M;&5F=#H@,G!X('-O;&ED("-D.&0X8S`[
M(&)O<F1E<BUR:6=H=#H@,G!X('-O;&ED(",X8C@W83`B/CPO=&0^"B`@("`@
M("`@("`@("`@("`@("`@/'1D('-T>6QE/2)H96EG:'0Z(#%P>"(@8V]L<W!A
M;CTB-2(^/"]T9#X*("`@("`@("`@("`@("`@(#PO='(^"B`@("`@("`@("`@
M("`@("`\+W1A8FQE/@H@("`@("`@("`@("`\+W1D/@H@("`@("`@(#PO='(^
M"B`@("`@("`@/'1R(&-L87-S/2)B9VMH86MI(CX*("`@(`D@("`@/'1D('-T
M>6QE/2)W:61T:#H@.3-P>#L@8F]R9&5R+71O<#H@,G!X('-O;&ED("-A8F%D
M83(B/B9N8G-P.SPO=&0^"B`@("`@("`@("`@(#QT9"!S='EL93TB8F]R9&5R
M+71O<#H@,G!X('-O;&ED("-A8F%D83(B/E5P9&%T960Z("@\/SUS=6)S='(H
M)'=E871H97);(G5P9&%T92)=+"`M-2D_/B9N8G-P.R\F;F)S<#L\/SUS=6)S
M='(H)&9O<F5C87-T6R)U<&1A=&4B72P@+34I/SXI/"]T9#X*("`@("`@("`@
M("`@/'1D('-T>6QE/2)B;W)D97(M=&]P.B`R<'@@<V]L:60@(V%B861A,B(@
M86QI9VX](G)I9VAT(CY!;&P@=&EM97,@551#/"]T9#X*("`@("`@("`\+W1R
M/@H@("`@("`@(#PO=&%B;&4^"B`@("`\+W1D/@H\+W1R/@H\+W1A8FQE/@H\
M82!H<F5F/2)J879A<V-R:7!T.FAI<W1O<GDN8F%C:R@I(CYB86-K/"]A/@H\
M+V)O9'D^"CPO:'1M;#X*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]D;V-S+U-E<G9I8V5S7U=E871H97(O97AA;7!L97,O=V5A=&AE<BYC;VTM
M8F%S:6,N<&AP```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-C4T-@`Q,#4Q-30S,S<S-0`P,S`V,S0`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RH@=FEM
M.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A
M8G-T;W`]-"!F;VQD;65T:&]D/6UA<FME<CH@*B\*"B\J*@H@*B!"87-I8R!E
M>&%M<&QE(&9O<B!T:&4@5V5A=&AE<BYC;VTM<V5R=FEC90H@*@H@*B!02%`@
M=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B`\3$E#14Y313X*("H@0V]P>7)I9VAT
M("AC*2`R,#`U+"!!;&5X86YD97(@5VER='H*("H@06QL(')I9VAT<R!R97-E
M<G9E9"X*("H@"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E
M(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M;V1I9FEC
M871I;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W
M:6YG(&-O;F1I=&EO;G,*("H@87)E(&UE=#H*("H@;R!2961I<W1R:6)U=&EO
M;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER
M:6=H="!N;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD
M('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@;R!2961I<W1R:6)U=&EO
M;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O
M<'ER:6=H="!N;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@
M86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@9&]C=6UE;G1A
M=&EO;@H@*B`@(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET
M:"!T:&4@9&ES=')I8G5T:6]N+@H@*B!O($YE:71H97(@=&AE(&YA;64@;V8@
M=&AE('-O9G1W87)E(&YO<B!T:&4@;F%M97,@;V8@:71S(&-O;G1R:6)U=&]R
M<PH@*B`@(&UA>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92!P<F]D
M=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R90H@*B`@('=I=&AO=70@
M<W!E8VEF:6,@<')I;W(@=W)I='1E;B!P97)M:7-S:6]N+@H@*B`*("H@5$A)
M4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%
M4E,@04Y$($-/3E1224)55$]24R`B05,@25,B"B`J($%.1"!!3ED@15A04D53
M4R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"!,
M24U)5$5$(%1/+"!42$4*("H@24U03$E%1"!705)204Y42453($]&($U%4D-(
M04Y404))3$E462!!3D0@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/
M4T4*("H@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#
M3U!94DE'2%0@3U=.15(@3U(@0T].5%))0E543U)3($)%"B`J($Q)04),12!&
M3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL(%-014-)04PL
M($5814U03$%262P@3U(*("H@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,
M541)3D<L($)55"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8*("H@
M4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L($1!
M5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3"B`J($E.5$524E505$E/3BD@
M2$]7159%4B!#0553140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519
M+"!72$542$52($E."B`J($-/3E1204-4+"!35%))0U0@3$E!0DE,2519+"!/
M4B!43U)4("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I"B`J
M($%225-)3D<@24X@04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3(%-/
M1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,2519
M($]&(%-50T@@1$%-04=%+@H@*B`\+TQ)0T5.4T4^"B`J(`H@*B!`8V%T96=O
M<GD@("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@("!397)V:6-E<U]7
M96%T:&5R"B`J($!A=71H;W(@("`@("!!;&5X86YD97(@5VER='H@/&%L97A`
M<&,T<"YN970^"B`J($!C;W!Y<FEG:'0@("`R,#`U($%L97AA;F1E<B!7:7)T
M>@H@*B!`;&EC96YS92`@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L
M:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S
M:6]N("`@("!#5E,Z("1)9#H@=V5A=&AE<BYC;VTM8F%S:6,N<&AP+'8@,2XW
M(#(P,#4O,3$O,#@@,3<Z-3(Z-#(@97)U($5X<"`D"B`J($!L:6YK("`@("`@
M("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4V5R=FEC97-?5V5A=&AE
M<@H@*B!`9FEL97-O=7)C90H@*B\*"G)E<75I<F5?;VYC92`B4V5R=FEC97,O
M5V5A=&AE<BYP:'`B.PH*+R\@3V)J96-T(&EN:71I86QI>F%T:6]N("T@97)R
M;W(@8VAE8VMI;F<@:7,@:6UP;W)T86YT+"!B96-A=7-E(&]F"B\O(&AA;F1L
M:6YG(&5X8V5P=&EO;G,@<W5C:"!A<R!M:7-S:6YG(%!%05(@;6]D=6QE<PHD
M=V5A=&AE<D1O=$-O;2`]("9397)V:6-E<U]796%T:&5R.CIS97)V:6-E*")7
M96%T:&5R1&]T0V]M(BP@87)R87DH(F1E8G5G(B`]/B`R+"`B:'1T<%1I;65O
M=70B(#T^(#,P*2D["FEF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1W
M96%T:&5R1&]T0V]M*2D@>PH@("`@9&EE*")%<G)O<CH@(BXD=V5A=&AE<D1O
M=$-O;2T^9V5T365S<V%G92@I+B)<;B(I.PI]"@HO+R!3970@=V5A=&AE<BYC
M;VT@<&%R=&YE<B!D871A"B1W96%T:&5R1&]T0V]M+3YS971!8V-O=6YT1&%T
M82@B/%!A<G1N97))1#XB+"`B/$QI8V5N<V5+97D^(BD["@HO*B!%<F%S92!C
M;VUM96YT<R!T;R!E;F%B;&4@8V%C:&EN9PHD<W1A='5S(#T@)'=E871H97)$
M;W1#;VTM/G-E=$-A8VAE*")F:6QE(BP@87)R87DH(F-A8VAE7V1I<B(@/3X@
M(B]T;7`O8V%C:&4O(BDI.PII9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O
M<B@D<W1A='5S*2D@>PH@("`@96-H;R`B17)R;W(Z("(N)'-T871U<RT^9V5T
M365S<V%G92@I+B)<;B(["GT**B\*"B1W96%T:&5R1&]T0V]M+3YS9715;FET
M<T9O<FUA="@B;65T<FEC(BD["B1W96%T:&5R1&]T0V]M+3YS971$871E5&EM
M949O<FUA="@B9"YM+EDB+"`B2#II(BD["@HO+R!&:7)S="!G970@8V]D92!F
M;W(@;&]C871I;VX*)'-E87)C:"`]("1W96%T:&5R1&]T0V]M+3YS96%R8VA,
M;V-A=&EO;B@B0F]N;BP@1V5R;6%N>2(I.PII9B`H4V5R=FEC97-?5V5A=&AE
M<CHZ:7-%<G)O<B@D<V5A<F-H*2D@>PH@("`@9&EE*")%<G)O<CH@(BXD<V5A
M<F-H+3YG971-97-S86=E*"DN(EQN(BD["GT*"B\O($YO=R!I=&5R871E('1H
M<F]U9V@@879A:6QA8FQE(&9U;F-T:6]N<R!F;W(@<F5T<FEE=FEN9R!D871A
M"F9O<F5A8V@@*&%R<F%Y*")G971,;V-A=&EO;B(L(")G971796%T:&5R(BP@
M(F=E=$9O<F5C87-T(BD@87,@)&9U;F-T:6]N*2!["B`@("`D9&%T82`]("1W
M96%T:&5R1&]T0V]M+3XD9G5N8W1I;VXH)'-E87)C:"D["B`@("!I9B`H4V5R
M=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D9&%T82DI('L*("`@("`@("!E8VAO
M(")%<G)O<CH@(BXD9&%T82T^9V5T365S<V%G92@I+B)<;B(["B`@("`@("`@
M8V]N=&EN=64["B`@("!]"@H@("`@=F%R7V1U;7`H)&1A=&$I.PI]"C\^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O9&]C<R]397)V:6-E<U]796%T:&5R+V5X86UP;&5S+W=E871H97(N8V]M
M+65X=&5N<VEV92YP:'``````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P-#4S,#(`,3`U,34T,S,W,S4`,#,Q-34V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J('9I
M;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T
M86)S=&]P/30@9F]L9&UE=&AO9#UM87)K97(Z("HO"@HO*BH*("H@16QA8F]R
M871E(&5X86UP;&4@9F]R('1H92!';&]B86Q796%T:&5R+7-E<G9I8V4*("H*
M("H@5V5L;"P@=&AI<R!I<R!A(&UO<F4@96QA8F]R871E(&5X86UP;&4@:&]W
M('1O(&-R96%T92!A(&YE870@;&ET=&QE('!A9V4*("H@=VET:"!F971C:&EN
M9R!D871A(&9R;VT@=V5A=&AE<BYC;VT@86YD('!U='1I;F<@:70@:6YT;R!A
M(&1E<VEG;BX*("H@22=M(&YO="!T;V\@<')O=60@;V8@;7D@9&5S:6=N+7-K
M:6QL<RP@;6]S="!O9B!T:&4@<W1U9F8@:&5R92!I<R!T86ME;@H@*B!F<F]M
M('1H92!W96%T:&5R+6)L;V-K('=H:6-H(&-A;B!B92!F;W5N9"!W:71H:6X@
M=&AE($AO<F1E($9R86UE=V]R:RP*("H@8V]U<G1E<WD@;V8@4FEC:R!%;65R
M>2`M(&-R96%T:79E('!I>&5L<VAO=FEN9R!I<VXG="!M>2!D;VUA:6X@.BU0
M"B`J($DG=F4@=7-E9"!A($9I<F5F;W@@9F]R(&-H96-K:6YG('1H92!D97-I
M9VXL('-O(&1O;B=T(&)E('1O;PH@*B!D:7-A<'!O:6YT960L(&EF('1H92!P
M86=E(&QO;VMS('-H86)B>2!W:71H('1H92!)12P@;F]T('1H870@22!C87)E
M"B`J('9E<GD@;75C:"!A;GEW87D@.RTI"B`J($EF('EO=2!W86YT('1O(&MN
M;W<@=VAE<F4@>6]U(&-A;B!O8G1A:6X@=&AE(&EC;VYS+"!P;&5A<V4@<F5G
M:7-T97(@870*("H@:'1T<#HO+W=W=RYW96%T:&5R+F-O;2]S97)V:6-E<R]X
M;6QO87`N:'1M;"!A;F0@>6]U)VQL(')E8V5I=F4@86X@94UA:6P*("H@8V]N
M=&%I;FEN9R!T:&4@<&%R=&YE<B!I9"P@=&AE(&QI8V5N<V4@:V5Y(&%N9"!A
M(&QI;FL@<&]I;G1I;F<@=&\@=&AE"B`J(%-$2RX@4'5T('1H92`S,G@S,B!A
M;F0@=&AE(&QO9V]S(&9O;&1E<G,@:6YT;R!T:&4@:6UA9V5S+R!D:7)E8W1O
M<GDN"B`J(%1H92!D97-I9VX@<VAO=6QD(&%D:&5R92!T;R!T:&4@8V]N=F5N
M=&EO;G,@9&5F:6YE9"!B>2!T:&4@=V5A=&AE<BYC;VT*("H@4T1++6=U:61E
M+"!T:&]U9V@@22!W;VXG="!G:79E(&%N>2!L96=A;"!C97)T86EN='D@9F]R
M('1H:7,@*&]F(&-O=7)S92DN"B`J($AA=F4@9G5N(0H@*B`*("H@4$A0('9E
M<G-I;VYS(#0@86YD(#4*("H*("H@/$Q)0T5.4T4^"B`J($-O<'ER:6=H="`H
M8RD@,C`P-2P@06QE>&%N9&5R(%=I<G1Z"B`J($%L;"!R:6=H=',@<F5S97)V
M960N"B`J(`H@*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A
M;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D:69I8V%T
M:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN
M9R!C;VYD:71I;VYS"B`J(&%R92!M970Z"B`J(&\@4F5D:7-T<FEB=71I;VYS
M(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG
M:'0@;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T
M:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J(&\@4F5D:7-T<FEB=71I;VYS
M(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y
M<FEG:'0@;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N
M9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE(&1O8W5M96YT871I
M;VX*("H@("!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@
M=&AE(&1I<W1R:6)U=&EO;BX*("H@;R!.96ET:&5R('1H92!N86UE(&]F('1H
M92!S;V9T=V%R92!N;W(@=&AE(&YA;65S(&]F(&ET<R!C;VYT<FEB=71O<G,*
M("H@("!M87D@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C
M=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4*("H@("!W:71H;W5T('-P
M96-I9FEC('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H@"B`J(%1(25,@
M4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$15)3
M($%.1"!#3TY44DE"551/4E,@(D%3($E3(@H@*B!!3D0@04Y9($584%)%4U,@
M3U(@24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0@3$E-
M251%1"!43RP@5$A%"B`J($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.
M5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%
M"B`J($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@0T]0
M65))1TA4($]73D52($]2($-/3E1224)55$]24R!"10H@*B!,24%"3$4@1D]2
M($%.62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!34$5#24%,+"!%
M6$5-4$Q!4EDL($]2"B`J($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$
M24Y'+"!"550@3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&"B`J(%-5
M0E-425155$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%+"!$051!
M+"!/4B!04D]&2513.R!/4B!"55-)3D534PH@*B!)3E1%4E)54%1)3TXI($A/
M5T5615(@0T%54T5$($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)04))3$E462P@
M5TA%5$A%4B!)3@H@*B!#3TY44D%#5"P@4U1224-4($Q)04))3$E462P@3U(@
M5$]25"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*0H@*B!!
M4DE324Y'($E.($%.62!705D@3U54($]&(%1(12!54T4@3T8@5$A)4R!33T94
M5T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(10H@*B!03U-324))3$E462!/
M1B!354-(($1!34%'12X*("H@/"],24-%3E-%/@H@*B`*("H@0&-A=&5G;W)Y
M("`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("`@4V5R=FEC97-?5V5A
M=&AE<@H@*B!`875T:&]R("`@("`@06QE>&%N9&5R(%=I<G1Z(#QA;&5X0'!C
M-'`N;F5T/@H@*B!`8V]P>7)I9VAT("`@,C`P-2!!;&5X86YD97(@5VER='H*
M("H@0&QI8V5N<V4@("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC
M96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO
M;B`@("`@0U93.B`D260Z('=E871H97(N8V]M+65X=&5N<VEV92YP:'`L=B`Q
M+C$T(#(P,#4O,3$O,#@@,3<Z-3(Z-#(@97)U($5X<"`D"B`J($!L:6YK("`@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4V5R=FEC97-?5V5A
M=&AE<@H@*B!`9FEL97-O=7)C90H@*B\*"B\O+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+0HO+R!4:&ES(&ES('1H92!A<F5A+"!W:&5R92!Y;W4@8V%N
M(&-U<W1O;6EZ92!T:&4@<V-R:7!T"B\O+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+0HD;&]C871I;VX@("`@(#T@(D)O;FXL($=E<FUA;GDB.R`O+R!4
M:&4@8VET>2!W92!W86YT('1O(&9E=&-H('1H92!D871A(&9O<BX*)&9O<F5C
M87-T1&%Y<R`](#0[("`@("`@("`@("`@("`@+R\@5&AI<R!R96=U;&%T97,@
M=&AE(&%M;W5N="!O9B!D:7-P;&%Y960*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@9&%T97,@:6X@=&AE(&9O<F5C87-T+B`H,2`\/2!X
M(#P](#$P*0HD<&%R=&YE<DE$("`@(#T@(CQ087)T;F5R240^(CL@("`O+R!!
M<R!P<F]V:61E9"!B>2!W96%T:&5R+F-O;2!I;B!T:&4*)&QI8V5N<V5+97D@
M("`]("(\3&EC96YS94ME>3XB.R`@+R\@<F5G:7-T<F%T:6]N(&5-86EL+@HD
M8V%C:&54>7!E("`@(#T@(B([("`@("`@("`@("`@("`O+R!3970@82!T>7!E
M("AF:6QE+"!D8BP@;61B+"`N+BXI('1O"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O(&5N86)L92!C86-H:6YG+@HD8V%C:&5/<'0@("`@
M(#T@87)R87DH*3L@("`@("`@("`O+R!#86-H92!N965D<R!V87)I;W5S(&]P
M=&EO;G,L(&1E<&5N9&EN9PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!O;B!T:&4@8V]N=&%I;F5R+71Y<&4@+2!P;&5A<V4@8V]N<W5L
M=`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!T:&4@0V%C
M:&4@;6%N=6%L("\@<V]U<F-E8V]D92$*)'5N:71S1F]R;6%T("`](")M971R
M:6,B.R`@("`@("`@+R\@5&AE(&9O<FUA="!T:&4@=6YI=',@87)E(&1I<W!L
M87EE9"!I;B`M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O
M(&UE=')I8RP@<W1A;F1A<F0@;W(@<V]M92!C=7-T;VUI>F%T:6]N+@HD9&%T
M949O<FUA="`@(#T@(EDM;2UD(CL@("`@("`@("`O+R!3970@=&AE(&9O<FUA
M="!T:&4@9&%T92!I<R!D:7-P;&%Y960@:6X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@0VAA;F=I;F<@:70@=VEL;"!B<F5A:R!A(&9E
M=R!T:&EN9W,@:6X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+R\@=&AI<R!S8W)I<'0L(&)U="!U<W5A;&QY('EO=2!C86X@9&5F:6YE"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O('1H:7,@=&\@>6]U
M<B!L:6MI;F=S+@HD=&EM949O<FUA="`@(#T@(D@Z:2([("`@("`@("`@("`O
M+R!3970@=&AE(&9O<FUA="!T:&4@=&EM92!I<R!D:7-P;&%Y960@:6X*+R\M
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"@HO+R!,;V%D('1H92!796%T
M:&5R(&-L87-S"G)E<75I<F5?;VYC92`B4V5R=FEC97,O5V5A=&AE<BYP:'`B
M.PH*+R\@3V)J96-T(&EN:71I86QI>F%T:6]N("T@97)R;W(@8VAE8VMI;F<@
M:7,@:6UP;W)T86YT+"!B96-A=7-E(&]F"B\O(&AA;F1L:6YG(&5X8V5P=&EO
M;G,@<W5C:"!A<R!M:7-S:6YG(%!%05(@;6]D=6QE<PHD=V5A=&AE<D1O=$-O
M;2`]("9397)V:6-E<U]796%T:&5R.CIS97)V:6-E*")796%T:&5R1&]T0V]M
M(BP@87)R87DH(FAT='!4:6UE;W5T(B`]/B`S,"DI.PII9B`H4V5R=FEC97-?
M5V5A=&AE<CHZ:7-%<G)O<B@D=V5A=&AE<D1O=$-O;2DI('L*("`@(&1I92@B
M17)R;W(Z("(N)'=E871H97)$;W1#;VTM/F=E=$UE<W-A9V4H*2XB7&XB*3L*
M?0H*+R\@4V5T('=E871H97(N8V]M('!A<G1N97(@9&%T80HD=V5A=&AE<D1O
M=$-O;2T^<V5T06-C;W5N=$1A=&$H)'!A<G1N97))1"P@)&QI8V5N<V5+97DI
M.PH*+R\@26YI=&EA;&EZ92!C86-H:6YG"FEF("AS=')L96XH)&-A8VAE5'EP
M92DI('L*("`@("1S=&%T=7,@/2`D=V5A=&AE<D1O=$-O;2T^<V5T0V%C:&4H
M)&-A8VAE5'EP92P@)&-A8VAE3W!T*3L*("`@(&EF("A397)V:6-E<U]796%T
M:&5R.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("`@("`@96-H;R`B17)R;W(Z
M("(N)'-T871U<RT^9V5T365S<V%G92@I+B)<;B(["B`@("!]"GT*"B\O($1E
M9FEN92!T:&4@=6YI=',@9F]R;6%T+"!B<FEN9R!T:&4@<F5T<FEE=F5D(&9O
M<FUA="!I;G1O"B\O('-O;65T:&EN9R!M;W)E(&-O;6UO;BXN+@HD=V5A=&AE
M<D1O=$-O;2T^<V5T56YI='-&;W)M870H)'5N:71S1F]R;6%T*3L*)'5N:71S
M(#T@)'=E871H97)$;W1#;VTM/F=E=%5N:71S1F]R;6%T*"D["B1U;FET<ULB
M=&5M<")=("`@/2`B)F1E9SLB+G-T<G1O=7!P97(H)'5N:71S6R)T96UP(ETI
M.PHD=6YI='-;(G=I;F0B72`@(#T@(B9N8G-P.R(N<W1R7W)E<&QA8V4H(FMM
M:"(L(")K;2]H(BP@)'5N:71S6R)W:6YD(ETI.PHD=6YI='-;(G9I<R)=("`@
M(#T@(B9N8G-P.R(N)'5N:71S6R)V:7,B73L*)'5N:71S6R)H96EG:'0B72`]
M("(F;F)S<#LB+B1U;FET<ULB:&5I9VAT(ET["B1U;FET<ULB<')E<R)=("`@
M/2`B)FYB<W`[(BXD=6YI='-;(G!R97,B73L*)'5N:71S6R)R86EN(ET@("`]
M("(F;F)S<#LB+B1U;FET<ULB<F%I;B)=.PH*+R\@4V5T(&1A=&4M+W1I;64M
M9F]R;6%T"B1W96%T:&5R1&]T0V]M+3YS971$871E5&EM949O<FUA="@D9&%T
M949O<FUA="P@)'1I;65&;W)M870I.PH*+R\@4V5A<F-H(&9O<B!D969I;F5D
M(&QO8V%T:6]N(&%N9"!F971C:"!T:&4@9FER<W0@:71E;2!F;W5N9"X*+R\@
M0F%I;"!O=70@:68@<V]M971H:6YG(&)A9"!H87!P96YS+BXN"B1S96%R8V@@
M/2`D=V5A=&AE<D1O=$-O;2T^<V5A<F-H3&]C871I;VXH)&QO8V%T:6]N+"!T
M<G5E*3L*:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-E87)C:"DI
M('L*("`@(&1I92@B17)R;W(Z("(N)'-E87)C:"T^9V5T365S<V%G92@I+B)<
M;B(I.PI]"@HO+R!2971R:65V92!D871A+"!S=&]R92!I;B!V87)I86)L97,L
M(&)A:6P@;W5T(&]N(&5R<F]R"B1F971C:"`](&%R<F%Y*`H@("`@(FQI;FMS
M(B`@("`]/B`B9V5T3&EN:W,B+`H@("`@(FQO8V%T:6]N(B`]/B`B9V5T3&]C
M871I;VXB+`H@("`@(G=E871H97(B("`]/B`B9V5T5V5A=&AE<B(L"B`@("`B
M9F]R96-A<W0B(#T^(")G971&;W)E8V%S="(**3L*9F]R96%C:"`H)&9E=&-H
M(&%S("1V87)I86)L92`]/B`D9G5N8W1I;VXI('L*("`@("0D=F%R:6%B;&4@
M/2`D=V5A=&AE<D1O=$-O;2T^)&9U;F-T:6]N*"1S96%R8V@L("1F;W)E8V%S
M=$1A>7,I.PH@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)"1V
M87)I86)L92DI('L*("`@("`@("!E8VAO(")%<G)O<CH@(BXD)'9A<FEA8FQE
M+3YG971-97-S86=E*"DN(EQN(CL*("`@("`@("!C;VYT:6YU93L*("`@('T*
M?0H*+R\@5V4@;F5E9"!T:&ES(&9O<B!S;VUE('1I;64M8VAE8VMS(&%N9"!D
M:7-P;&%Y<R!L871E<@HD=W5P9"`]('-T<G1O=&EM92@D=V5A=&AE<ELB=7!D
M871E(ETI("`K(&1A=&4H(EHB*3L*)&9U<&0@/2!S=')T;W1I;64H)&9O<F5C
M87-T6R)U<&1A=&4B72D@*R!D871E*"):(BD["B1F=7`@(#T@<W1R=&]T:6UE
M*"1F;W)E8V%S=%LB=7!D871E(ETI("L@)&QO8V%T:6]N6R)T:6UE>F]N92)=
M("H@,S8P,#L*"B\O($-H96-K+"!I9B!W92=R92!I;B!T:&4@869T97)N;V]N
M(&%N9"!I9B!T:&4@9F]R96-A<W0@=V%S('5P9&%T960@>65T+BXN"B\O(%1H
M:7,@=')I9V=E<G,@:68@=&AE(&1A>2UF;W)E8V%S="!F;W(@=&AE(&-U<G)E
M;G0@9&%Y('=I;&P@9V5T('-H;W=N+@HD869T97)N;V]N(#T@*"1L;V-A=&EO
M;ELB=&EM92)=(#X@(C$S.C4Y(B!\?"!D871E*")9;60B+"`D9G5P*2`\(&1A
M=&4H(EEM9"(I*2`_('1R=64@.B!F86QS93L*"B\O(%1H92!U<W5A;"!N;W1A
M=&EO;B!F;W(@8V]N9&ET:6]N(&EC;VYS(&ES(&YU;65R:6,N($-H96-K(&9O
M<B!N=6UE<FEC(&EC;VX@;W(@(FYA(B!A;F0@<V5T('1O(")N82(@:68@=&AA
M="=S(&YO="!T:&4@8V%S90II9B`H(2AC='EP95]D:6=I="@D=V5A=&AE<ELB
M8V]N9&ET:6]N26-O;B)=*2!\?"`D=V5A=&AE<ELB8V]N9&ET:6]N26-O;B)=
M(#T](")N82(I*2!["B`@("`D=V5A=&AE<ELB8V]N9&ET:6]N26-O;B)=(#T@
M(FYA(CL*?0H*+R\@3F]W('=E(&]U='!U="!A;&P@=&AE(&1A=&$L('!L96%S
M92!D;VXG="!E>'!E8W0@97AT96YS:79E(&-O;6UE;G1S(&AE<F4L('1H:7,@
M:7,@8F%S:6,*+R\@2%1-3"]#4U,@<W1U9F8N($%L<V\@=&AI<R!I<VXG="!A
M('9E<GD@9F%N8WD@9&5S:6=N+"!I="=S(&IU<W0@=&\@<VAO=R!Y;W4L('=H
M870*+R\@=&AE('-C<FEP="!I<R!A8FQE('1O(&1O("AA;F0@;6]R92`[+2DI
M+BXN"C\^"CQH=&UL/@H\:&5A9#X*("`@(#QT:71L93Y397)V:6-E<U]796%T
M:&5R.CI796%T:&5R9&]T8V]M/"]T:71L93X*("`@(#QS='EL92!T>7!E/2)T
M97AT+V-S<R(^"B`@("`@("`@+FYO<FUA;"`@("`@>R!F;VYT+69A;6EL>3H@
M07)I86PL($AE;'9E=&EC82P@<V%N<RUS97)I9CL@9F]N="US:7IE.B`Q,7!T
M.R!F;VYT+7=E:6=H=#H@;F]R;6%L.R!F;VYT+7-T>6QE.B!N;W)M86P@?0H@
M("`@("`@("YI=&%L:6,@("`@('L@9F]N="UW96EG:'0Z(&YO<FUA;#L@9F]N
M="US='EL93H@:71A;&EC('T*("`@("`@("`N8F]L9"`@("`@("![(&9O;G0M
M=V5I9VAT.B!B;VQD.R!F;VYT+7-T>6QE.B!N;W)M86P@?0H@("`@("`@("YB
M;VQD:71A;&EC('L@9F]N="UW96EG:'0Z(&)O;&0[(&9O;G0M<W1Y;&4Z(&ET
M86QI8R!]"B`@("`@("`@+G)E9&)O;&0@("`@>R!F;VYT+7=E:6=H=#H@8F]L
M9#L@9F]N="US='EL93H@;F]R;6%L.R!C;VQO<CH@(V9F,#`P,"!]"B`@("`@
M("`@+F)L=65B;VQD("`@>R!F;VYT+7=E:6=H=#H@8F]L9#L@9F]N="US='EL
M93H@;F]R;6%L.R!C;VQO<CH@(S`P,#!F9B!]"B`@("`@("`@+F)G9W)E>2`@
M("`@>R!B86-K9W)O=6YD+6-O;&]R.B`C93EE.64Y('T*("`@("`@("`N8F=K
M:&%K:2`@("![(&)A8VMG<F]U;F0M8V]L;W(Z("-D.&0X8S`@?0H@("`@("`@
M("YR96<@("`@("`@('L@9F]N="US:7IE.B`W<'0[('9E<G1I8V%L+6%L:6=N
M.B!S=7!E<B!]"B`@("`@("`@:6UG("`@("`@("`@>R!V97)T:6-A;"UA;&EG
M;CH@;6ED9&QE.R!B;W)D97(M<W1Y;&4Z(&YO;F4[(&)O<F1E<BUW:61T:#H@
M,'!X('T*("`@("`@("!A("`@("`@("`@("![(&9O;G0M=V5I9VAT.B!B;VQD
M.R!F;VYT+7-T>6QE.B!I=&%L:6,[(&-O;&]R.B`C.3DS,S`P.R!T97AT+61E
M8V]R871I;VXZ(&YO;F4@?0H@("`@("`@(&$Z=FES:71E9"`@('L@9F]N="UW
M96EG:'0Z(&)O;&0[(&9O;G0M<W1Y;&4Z(&ET86QI8SL@8V]L;W(Z(",Y.3,S
M,#`[('1E>'0M9&5C;W)A=&EO;CH@;F]N92!]"B`@("`@("`@83IH;W9E<B`@
M("`@>R!F;VYT+7=E:6=H=#H@8F]L9#L@9F]N="US='EL93H@:71A;&EC.R!C
M;VQO<CH@(V-C,S,P,#L@=&5X="UD96-O<F%T:6]N.B!U;F1E<FQI;F4@?0H@
M("`@("`@('1A8FQE("`@("`@('L@8F]R9&5R.B`P<'@@;F]N92!B;&%C:SL@
M8F]R9&5R+7-P86-I;F<Z(#!P>"!]"B`@("`@("`@=&0@("`@("`@("`@>R!F
M;VYT+69A;6EL>3H@07)I86PL($AE;'9E=&EC82P@<V%N<RUS97)I9CL@9F]N
M="US:7IE.B`Q,7!T.R!F;VYT+7=E:6=H=#H@;F]R;6%L.R!F;VYT+7-T>6QE
M.B!N;W)M86P@?0H@("`@/"]S='EL93X*/"]H96%D/@H\8F]D>2!C;&%S<STB
M;F]R;6%L(CX*/#]P:'`*+R\@1&5B=6<@;W5T<'5T<R!T:&4@<F%W(&1A=&$@
M9F5T8VAE9"!B>2!T:&4@9F]R96%C:"UL;V]P(&%B;W9E+"!J=7-T(&9O<B!C
M:&5C:VEN9RXN+@II9B`H:7-S970H)%]'151;(F1E8G5G(ETI*2!["B`@("!E
M8VAO("(\<')E/EQN(CL*("`@('9A<E]D=6UP*"1L:6YK<RP@)&QO8V%T:6]N
M+"`D=V5A=&AE<BP@)&9O<F5C87-T*3L*("`@(&5C:&\@(CPO<')E/EQN(CL*
M?2`*/SX*/'-P86X@8VQA<W,](F)L=65B;VQD(B!S='EL93TB9F]N="US:7IE
M.B`Q,W!T(CY796%T:&5R($9O<F5C87-T/"]S<&%N/B!C<F5A=&5D('=I=&@@
M/&$@<W1Y;&4](F9O;G0M<VEZ93H@,3-P="(@:')E9CTB:'1T<#HO+W!E87(N
M<&AP+FYE="\B/E!%05)S/"]A/B`\82!S='EL93TB9F]N="US:7IE.B`Q,W!T
M(B!H<F5F/2)H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4V5R=FEC97-?
M5V5A=&AE<B\B/E-E<G9I8V5S7U=E871H97(\+V$^/&)R/@H\=&%B;&4@<W1Y
M;&4](G=I9'1H.B`Q,#`E(CX*/'1R/@H@("`@/'1D/@H@("`@("`@(#QT86)L
M92!S='EL93TB8F]R9&5R+71O<#H@,G!X('-O;&ED(",U,C1B.3@[(&)O<F1E
M<BUB;W1T;VTZ(#)P>"!S;VQI9"`C93!E,V-E.R!B;W)D97(M;&5F=#H@,G!X
M('-O;&ED("-B.&(V8S$[(&)O<F1E<BUR:6=H=#H@,G!X('-O;&ED(",X8C@W
M83`[('=I9'1H.B`Q,#`E(CX*("`@("`@("`\='(@8VQA<W,](F)G:VAA:VDB
M/@H@("`@("`@("`@("`\=&0@<W1Y;&4](G=I9'1H.B`S,3!P>#L@8F]R9&5R
M+6)O='1O;3H@,G!X('-O;&ED("-A8F%D83(B(&-O;'-P86X](C(B/CQS<&%N
M(&-L87-S/2)B;VQD(CX\/STD;&]C871I;VY;(FYA;64B73\^/"]S<&%N/CPO
M=&0^"B`@("`@("`@("`@(#QT9"!S='EL93TB=VED=&@Z(#$Y,'!X.R!B;W)D
M97(M8F]T=&]M.B`R<'@@<V]L:60@(V%B861A,B(^/'-P86X@8VQA<W,](F)O
M;&0B/DQO8V%L('1I;64Z/"]S<&%N/B`\/STD;&]C871I;VY;(G1I;64B73\^
M("A'350\/STH*"1L;V-A=&EO;ELB=&EM97IO;F4B72`\(#`I(#\@(B(@.B`B
M*R(I+B1L;V-A=&EO;ELB=&EM97IO;F4B73\^*3PO=&0^"B`@("`@("`@("`@
M(#QT9"!S='EL93TB8F]R9&5R+6)O='1O;3H@,G!X('-O;&ED("-A8F%D83(B
M/B9N8G-P.SPO=&0^"B`@("`@("`@/"]T<CX*("`@("`@("`\='(^"B`@("`@
M("`@("`@(#QT9#X\<W!A;B!C;&%S<STB8F]L9"(^4W5N<FES93H\+W-P86X^
M(#QI;6<@<W1Y;&4](G=I9'1H.B`R.'!X.R!H96EG:'0Z(#$S<'@[('9E<G1I
M8V%L+6%L:6=N.B!B87-E;&EN92(@86QT/2)3=6YR:7-E(B!S<F,](FEM86=E
M<R]S=6YR:7-E+F=I9B(^(#P_/21L;V-A=&EO;ELB<W5N<FES92)=/SX\+W1D
M/@H@("`@("`@("`@("`\=&0@8V]L<W!A;CTB,B(^/'-P86X@8VQA<W,](F)O
M;&0B/E-U;G-E=#H\+W-P86X^(#QI;6<@<W1Y;&4](G=I9'1H.B`S,'!X.R!H
M96EG:'0Z(#$U<'@[('9E<G1I8V%L+6%L:6=N.B!B87-E;&EN92(@86QT/2)3
M=6YS970B('-R8STB:6UA9V5S+W-U;G-E="YG:68B/B`\/STD;&]C871I;VY;
M(G-U;G-E=")=/SX\+W1D/@H@("`@("`@("`@("`\=&0@<F]W<W!A;CTB-2(@
M=F%L:6=N/2)M:61D;&4B(&%L:6=N/2)C96YT97(B/@H@("`@("`@("`@("`@
M("`@/'1A8FQE('-T>6QE/2)B;W)D97(M=&]P.B`R<'@@<V]L:60@(S4R-&(Y
M.#L@8F]R9&5R+6)O='1O;3H@,G!X('-O;&ED("-E,&4S8V4[(&)O<F1E<BUL
M969T.B`R<'@@<V]L:60@(V(X8C9C,3L@8F]R9&5R+7)I9VAT.B`R<'@@<V]L
M:60@(SAB.#=A,"(^"B`@("`@("`@("`@("`@("`\='(@8VQA<W,](F)G:VAA
M:VDB/@H@("`@("`@("`@("`@("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(B!S
M='EL93TB8F]R9&5R+6)O='1O;3H@,G!X('-O;&ED("-A8F%D83(B/CQS<&%N
M(&-L87-S/2)B;VQD(CY&96%T=7)E9"!O;B`\<W!A;B!C;&%S<STB8F]L9&ET
M86QI8R(^=V5A=&AE<BYC;VT\<W!A;B!C;&%S<STB<F5G(CXF<F5G.SPO<W!A
M;CX\+W-P86X^/"]S<&%N/CPO=&0^"B`@("`@("`@("`@("`@("`\+W1R/@H\
M/W!H<`HO+R!,;V]P('1H<F]U9V@@=&AE(&UA;F1A=&]R>2!L:6YK<RP@;F]T
M:&EN9R!S<&5C=&%C=6QA<@IF;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)&QI
M;FMS6R)P<F]M;R)=*3L@)&DK*RD@>PH_/@H@("`@("`@("`@("`@("`@/'1R
M(&-L87-S/2)B9V=R97DB/@H@("`@("`@("`@("`@("`@("`@(#QT9#X\82!H
M<F5F/2(\/STD;&EN:W-;(G!R;VUO(EU;)&E=6R)L:6YK(ET_/B(^/#\])&QI
M;FMS6R)P<F]M;R)=6R1I75LB=&ET;&4B73\^/"]A/CPO=&0^"B`@("`@("`@
M("`@("`@("`\+W1R/@H\/W!H<`I]"C\^"B`@("`@("`@("`@("`@("`\+W1A
M8FQE/@H@("`@("`@("`@("`\+W1D/@H@("`@("`@(#PO='(^"B`@("`@("`@
M/'1R/@H@("`@("`@("`@("`\=&0^/'-P86X@8VQA<W,](F)O;&0B/E1E;7!E
M<F%T=7)E.CPO<W!A;CX@/#\]<F]U;F0H)'=E871H97);(G1E;7!E<F%T=7)E
M(ETL(#$I+B1U;FET<ULB=&5M<")=/SX\+W1D/@H@("`@("`@("`@("`\=&0^
M/'-P86X@8VQA<W,](F)O;&0B/D1E=R!P;VEN=#H\+W-P86X^(#P_/7)O=6YD
M*"1W96%T:&5R6R)D97=0;VEN=")=+"`Q*2XD=6YI='-;(G1E;7`B73\^/"]T
M9#X*("`@("`@("`@("`@/'1D/CQS<&%N(&-L87-S/2)B;VQD(CY&96QT('1E
M;7!E<F%T=7)E.CPO<W!A;CX@/#\]<F]U;F0H)'=E871H97);(F9E;'1496UP
M97)A='5R92)=+"`Q*2XD=6YI='-;(G1E;7`B73\^/"]T9#X*("`@("`@("`\
M+W1R/@H@("`@("`@(#QT<CX*("`@("`@("`@("`@/'1D(&-O;'-P86X](C(B
M/CQS<&%N(&-L87-S/2)B;VQD(CY0<F5S<W5R93H\+W-P86X^(#P_/7)O=6YD
M*"1W96%T:&5R6R)P<F5S<W5R92)=+"`Q*2XD=6YI='-;(G!R97,B73\^(&%N
M9"`\/STD=V5A=&AE<ELB<')E<W-U<F54<F5N9")=/SX\+W1D/@H@("`@("`@
M("`@("`\=&0^/'-P86X@8VQA<W,](F)O;&0B/DAU;6ED:71Y.CPO<W!A;CX@
M/#\])'=E871H97);(FAU;6ED:71Y(ET_/B4\+W1D/@H@("`@("`@(#PO='(^
M"B`@("`@("`@/'1R/@H@("`@("`@("`@("`\=&0@8V]L<W!A;CTB,B(^/'-P
M86X@8VQA<W,](F)O;&0B/E=I;F0Z/"]S<&%N/B`\/SUS=')T;VQO=V5R*"1W
M96%T:&5R6R)W:6YD1&ER96-T:6]N(ETI(#T](")C86QM(B`_(")#86QM(B`Z
M(")&<F]M('1H92`B+B1W96%T:&5R6R)W:6YD1&ER96-T:6]N(ETN(B`H(BXD
M=V5A=&AE<ELB=VEN9$1E9W)E97,B72XB)F1E9SLI(&%T("(N<F]U;F0H)'=E
M871H97);(G=I;F0B72P@,2DN)'5N:71S6R)W:6YD(ET_/CPO=&0^"B`@("`@
M("`@("`@(#QT9#X\<W!A;B!C;&%S<STB8F]L9"(^5FES:6)I;&ET>3H\+W-P
M86X^(#P_/7)O=6YD*"1W96%T:&5R6R)V:7-I8FEL:71Y(ETL(#$I+B1U;FET
M<ULB=FES(ET_/CPO=&0^"B`@("`@("`@/"]T<CX*("`@("`@("`\='(^"B`@
M("`@("`@("`@(#QT9#X\<W!A;B!C;&%S<STB8F]L9"(^0W5R<F5N="!C;VYD
M:71I;VXZ/"]S<&%N/CQB<CX\/STD=V5A=&AE<ELB8V]N9&ET:6]N(ET_/CPO
M=&0^"B`@("`@("`@("`@(#QT9#X\:6UG('-T>6QE/2)H96EG:'0Z(#,R<'@[
M('=I9'1H.B`S,G!X(B!A;'0](CP_/21W96%T:&5R6R)C;VYD:71I;VXB73\^
M(B!S<F,](FEM86=E<R\S,G@S,B\\/STD=V5A=&AE<ELB8V]N9&ET:6]N26-O
M;B)=/SXN<&YG(CX\+W1D/@H@("`@("`@("`@("`\=&0@=F%L:6=N/2)T;W`B
M/CQS<&%N(&-L87-S/2)B;VQD(CY55BU);F1E>#H\+W-P86X^(#P_/21W96%T
M:&5R6R)U=DEN9&5X(ET_/B`H/#\])'=E871H97);(G5V5&5X=")=/SXI/"]T
M9#X*("`@("`@("`\+W1R/@H@("`@("`@(#PO=&%B;&4^"B`@("`\+W1D/@H\
M+W1R/@H\='(^"B`@("`\=&0^"B`@("`@("`@/'1A8FQE('-T>6QE/2)B;W)D
M97(M=&]P.B`R<'@@<V]L:60@(S4R-&(Y.#L@8F]R9&5R+6)O='1O;3H@,G!X
M('-O;&ED("-E,&4S8V4[(&)O<F1E<BUL969T.B`R<'@@<V]L:60@(V(X8C9C
M,3L@8F]R9&5R+7)I9VAT.B`R<'@@<V]L:60@(SAB.#=A,"(^"B`@("`@("`@
M/'1R(&-L87-S/2)B9VMH86MI(CX*("`@("`@("`@("`@/'1D(&%L:6=N/2)C
M96YT97(B('-T>6QE/2)B;W)D97(M8F]T=&]M.B`R<'@@<V]L:60@(V%B861A
M,B(@8V]L<W!A;CTB/#\]*#$@*R`D9F]R96-A<W1$87ES*3\^(CX\<W!A;B!C
M;&%S<STB8F]L9"(^/#\])&9O<F5C87-T1&%Y<S\^+61A>2!F;W)E8V%S=#PO
M<W!A;CX\+W1D/@H@("`@("`@(#PO='(^"B`@("`@("`@/'1R('9A;&EG;CTB
M=&]P(CX*("`@("`@("`@("`@/'1D('-T>6QE/2)W:61T:#H@,3`E(CX*("`@
M("`@("`@("`@("`@(#QT86)L92!C;&%S<STB8F=K:&%K:2(@<W1Y;&4](G=I
M9'1H.B`Q,#`E.R!B;W)D97(M=&]P.B`R<'@@<V]L:60@(V0X9#AC,#L@8F]R
M9&5R+6)O='1O;3H@,G!X('-O;&ED("-D.&0X8S`[(&)O<F1E<BUL969T.B`R
M<'@@<V]L:60@(V0X9#AC,#L@8F]R9&5R+7)I9VAT.B`R<'@@<V]L:60@(SAB
M.#=A,"(^"B`@("`@("`@("`@("`@("`\='(^"B`@("`@("`@("`@("`@("`@
M("`@/'1D(&%L:6=N/2)C96YT97(B('-T>6QE/2)H96EG:'0Z(#$U<'@B/B9N
M8G-P.SPO=&0^"B`@("`@("`@("`@("`@("`\='(^"B`@("`@("`@("`@("`@
M("`@("`@/'1D(&%L:6=N/2)C96YT97(B('-T>6QE/2)H96EG:'0Z(#0U<'@B
M/CQS<&%N(&-L87-S/2)B;VQD(CY496UP97)A='5R93PO<W!A;CX@/'-P86X@
M8VQA<W,](G)E9&)O;&0B/DAI9V@\+W-P86X^("\@/'-P86X@8VQA<W,](F)L
M=65B;VQD(CY,;W<\+W-P86X^/"]T9#X*("`@("`@("`@("`@("`@(#PO='(^
M"B`@("`@("`@("`@("`@("`\='(^"B`@("`@("`@("`@("`@("`@("`@/'1D
M(&%L:6=N/2)C96YT97(B('-T>6QE/2)H96EG:'0Z(#$U<'@B/B9N8G-P.SPO
M=&0^"B`@("`@("`@("`@("`@("`\+W1R/@H@("`@("`@("`@("`@("`@/'1R
M/@H@("`@("`@("`@("`@("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(B!S='EL
M93TB:&5I9VAT.B`W-7!X(CX\<W!A;B!C;&%S<STB8F]L9"(^0V]N9&ET:6]N
M/"]S<&%N/CPO=&0^"B`@("`@("`@("`@("`@("`\+W1R/@H@("`@("`@("`@
M("`@("`@/'1R/@H@("`@("`@("`@("`@("`@("`@(#QT9"!A;&EG;CTB8V5N
M=&5R(B!S='EL93TB:&5I9VAT.B`T-7!X(CX\<W!A;B!C;&%S<STB8F]L9"(^
M4')E8VEP:71A=&EO;B!P<F]B86)I;&ET>3PO<W!A;CX\+W1D/@H@("`@("`@
M("`@("`@("`@/"]T<CX@("`@("`@("`@("`*("`@("`@("`@("`@("`@(#QT
M<CX*("`@("`@("`@("`@("`@("`@("`\=&0@86QI9VX](F-E;G1E<B(@<W1Y
M;&4](FAE:6=H=#H@-#5P>"(^/'-P86X@8VQA<W,](F)O;&0B/E=I;F0\+W-P
M86X^/"]T9#X*("`@("`@("`@("`@("`@(#PO='(^"B`@("`@("`@("`@("`@
M("`\='(^"B`@("`@("`@("`@("`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B
M('-T>6QE/2)H96EG:'0Z(#$U<'@B/CQS<&%N(&-L87-S/2)B;VQD(CY(=6UI
M9&ET>3PO<W!A;CX\+W1D/@H@("`@("`@("`@("`@("`@/"]T<CX*("`@("`@
M("`@("`@("`@(#PO=&%B;&4^"B`@("`@("`@("`@(#PO=&0^"CP_<&AP"F9O
M<B`H)&1A>2`](#`[("1D87D@/"`D9F]R96-A<W1$87ES.R`D9&%Y*RLI('L*
M("`@("\O(%-E="!N86UE(&]F(&1A>0H@("`@:68@*"1D87D@/3T@,"D@>PH@
M("`@("`@("1D87EN86UE(#T@(E1O9&%Y(CL*("`@('T@96QS96EF("@D9&%Y
M(#T](#$I('L*("`@("`@("`D9&%Y;F%M92`](")4;VUO<G)O=R(["B`@("!]
M(&5L<V4@>PH@("`@("`@("1D87EN86UE(#T@9&%T92@B;"(L("1F=7`@*R`D
M9&%Y("H@.#8T,#`I.PH@("`@?0H@("`@+R\@069T97)N;V]N(&ES(&]N;'D@
M:6UP;W)T86YT(&9O<B!T;V1A>0H@("`@)&%F=&5R;F]O;B`]("@D9&%Y(#T]
M(#`I(#\@)&%F=&5R;F]O;B`Z(&9A;'-E.PH*("`@("\O(%1H92!U<W5A;"!N
M;W1A=&EO;B!F;W(@8V]N9&ET:6]N(&EC;VYS(&ES(&YU;65R:6,N($-H96-K
M(&9O<B!N=6UE<FEC(&EC;VX@;W(@(FYA(B!A;F0@<V5T('1O(")N82(@:68@
M=&AA="=S(&YO="!T:&4@8V%S90H@("`@:68@*"$H8W1Y<&5?9&EG:70H)&9O
M<F5C87-T6R)D87ES(EU;)&1A>5U;(F1A>2)=6R)C;VYD:71I;VY)8V]N(ETI
M('Q\("1F;W)E8V%S=%LB9&%Y<R)=6R1D87E=6R)D87DB75LB8V]N9&ET:6]N
M26-O;B)=(#T](")N82(I*2!["B`@("`@("`@)&9O<F5C87-T6R)D87ES(EU;
M)&1A>5U;(F1A>2)=6R)C;VYD:71I;VY)8V]N(ET@/2`B;F$B.PH@("`@?0H@
M("`@:68@*"$H8W1Y<&5?9&EG:70H)&9O<F5C87-T6R)D87ES(EU;)&1A>5U;
M(FYI9VAT(EU;(F-O;F1I=&EO;DEC;VXB72D@?'P@)&9O<F5C87-T6R)D87ES
M(EU;)&1A>5U;(FYI9VAT(EU;(F-O;F1I=&EO;DEC;VXB72`]/2`B;F$B*2D@
M>PH@("`@("`@("1F;W)E8V%S=%LB9&%Y<R)=6R1D87E=6R)N:6=H=")=6R)C
M;VYD:71I;VY)8V]N(ET@/2`B;F$B.PH@("`@?0H_/@H@("`@("`@("`@("`\
M=&0@<W1Y;&4](G=I9'1H.B`\/STH.3`@+R`D9F]R96-A<W1$87ES*3\^)2(^
M"B`@("`@("`@("`@("`@("`\=&%B;&4@<W1Y;&4](G=I9'1H.B`Q,#`E(CP_
M/2@D9&%Y("4@,BD@/R`G(&-L87-S/2)B9V=R97DB)R`Z("(B/SX^"B`@("`@
M("`@("`@("`@("`@("`@/'1R/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M=&0@86QI9VX](F-E;G1E<B(@8V]L<W!A;CTB,B(@<W1Y;&4](FAE:6=H=#H@
M,35P>"(^/'-P86X@8VQA<W,](F)O;&0B/CP_/21D87EN86UE/SX\+W-P86X^
M/"]T9#X*("`@("`@("`@("`@("`@("`@("`\+W1R/@H@("`@("`@("`@("`@
M("`@("`@(#QT<CX*("`@("`@("`@("`@("`@("`@("`@("`@/'1D(&%L:6=N
M/2)C96YT97(B(&-O;'-P86X](C(B('-T>6QE/2)H96EG:'0Z(#0U<'@B/CP_
M/21A9G1E<FYO;VX@/R`B(B`Z("<\<W!A;B!C;&%S<STB<F5D8F]L9"(^)RYR
M;W5N9"@D9F]R96-A<W1;(F1A>7,B75LD9&%Y75LB=&5M<&5R871U<F5(:6=H
M(ETL(#`I+B1U;FET<ULB=&5M<")=+B<\+W-P86X^("\@)S\^/'-P86X@8VQA
M<W,](F)L=65B;VQD(CX\/SUR;W5N9"@D9F]R96-A<W1;(F1A>7,B75LD9&%Y
M75LB=&5M<&5R871U<F5,;W<B72P@,"DN)'5N:71S6R)T96UP(ET_/CPO<W!A
M;CX\+W1D/@H@("`@("`@("`@("`@("`@("`@(#PO='(^"B`@("`@("`@("`@
M("`@("`@("`@/'1R/@H@("`@("`@("`@("`@("`@("`@("`@("`\=&0@86QI
M9VX](F-E;G1E<B(@<W1Y;&4](G=I9'1H.B`U,"4[(&AE:6=H=#H@,35P>"(^
M/#\])&%F=&5R;F]O;B`_("(F;F)S<#LB(#H@)SQS<&%N(&-L87-S/2)B;VQD
M(CY$87D\+W-P86X^)S\^/"]T9#X*("`@("`@("`@("`@("`@("`@("`@("`@
M/'1D(&%L:6=N/2)C96YT97(B('-T>6QE/2)W:61T:#H@-3`E.R!H96EG:'0Z
M(#$U<'@B/CQS<&%N(&-L87-S/2)B;VQD(CY.:6=H=#PO<W!A;CX\+W1D/@H@
M("`@("`@("`@("`@("`@("`@(#QT<CX*("`@("`@("`@("`@("`@("`@("`\
M='(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R
M(B!S='EL93TB:&5I9VAT.B`W-7!X(B!V86QI9&X](G1O<"(^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\/STD869T97)N;V]N(#\@(B9N8G-P.R(@
M.B`G/&EM9R!S='EL93TB:&5I9VAT.B`S,G!X.R!W:61T:#H@,S)P>"(@86QI
M9VX](G1O<"(@86QT/2(G+B1F;W)E8V%S=%LB9&%Y<R)=6R1D87E=6R)D87DB
M75LB8V]N9&ET:6]N(ETN)R(@<W)C/2)I;6%G97,O,S)X,S(O)RXD9F]R96-A
M<W1;(F1A>7,B75LD9&%Y75LB9&%Y(EU;(F-O;F1I=&EO;DEC;VXB72XG+G!N
M9R(^)S\^/&)R/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/#\])&%F
M=&5R;F]O;B`_("(F;F)S<#LB(#H@)&9O<F5C87-T6R)D87ES(EU;)&1A>5U;
M(F1A>2)=6R)C;VYD:71I;VXB73\^(`H@("`@("`@("`@("`@("`@("`@("`@
M("`\+W1D/@H@("`@("`@("`@("`@("`@("`@("`@("`\=&0@86QI9VX](F-E
M;G1E<B(@<W1Y;&4](FAE:6=H=#H@-S5P>"(@=F%L:61N/2)T;W`B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/&EM9R!S='EL93TB:&5I9VAT.B`S
M,G!X.R!W:61T:#H@,S)P>"(@86QI9VX](G1O<"(@86QT/2(\/STD9F]R96-A
M<W1;(F1A>7,B75LD9&%Y75LB;FEG:'0B75LB8V]N9&ET:6]N(ET_/B(@<W)C
M/2)I;6%G97,O,S)X,S(O/#\])&9O<F5C87-T6R)D87ES(EU;)&1A>5U;(FYI
M9VAT(EU;(F-O;F1I=&EO;DEC;VXB73\^+G!N9R(^/&)R/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/#\])&9O<F5C87-T6R)D87ES(EU;)&1A>5U;
M(FYI9VAT(EU;(F-O;F1I=&EO;B)=/SX@"B`@("`@("`@("`@("`@("`@("`@
M("`@(#PO=&0^"B`@("`@("`@("`@("`@("`@("`@/"]T<CX*("`@("`@("`@
M("`@("`@("`@("`\='(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QT9"!A
M;&EG;CTB8V5N=&5R(B!S='EL93TB:&5I9VAT.B`T-7!X(CX\/STD869T97)N
M;V]N(#\@(B9N8G-P(B`Z("1F;W)E8V%S=%LB9&%Y<R)=6R1D87E=6R)D87DB
M75LB<')E8VEP:71A=&EO;B)=+B(E(C\^/"]T9#X*("`@("`@("`@("`@("`@
M("`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B('-T>6QE/2)H96EG:'0Z(#0U
M<'@B/CP_/21F;W)E8V%S=%LB9&%Y<R)=6R1D87E=6R)N:6=H=")=6R)P<F5C
M:7!I=&%T:6]N(ET_/B4\+W1D/@H@("`@("`@("`@("`@("`@("`@(#PO='(^
M"B`@("`@("`@("`@("`@("`@("`@/'1R/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\=&0@86QI9VX](F-E;G1E<B(@<W1Y;&4](FAE:6=H=#H@-#5P>"(^
M/#\])&%F=&5R;F]O;B`_("(F;F)S<#LB(#H@<F]U;F0H)&9O<F5C87-T6R)D
M87ES(EU;)&1A>5U;(F1A>2)=6R)W:6YD(ETL(#`I+B1U;FET<ULB=VEN9")=
M+B(@9G)O;29N8G-P.R(N)&9O<F5C87-T6R)D87ES(EU;)&1A>5U;(F1A>2)=
M6R)W:6YD1&ER96-T:6]N(ET_/CPO=&0^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QT9"!A;&EG;CTB8V5N=&5R(B!S='EL93TB:&5I9VAT.B`T-7!X(CX\
M/SUR;W5N9"@D9F]R96-A<W1;(F1A>7,B75LD9&%Y75LB;FEG:'0B75LB=VEN
M9")=+"`P*2XD=6YI='-;(G=I;F0B73\^(&9R;VTF;F)S<#L\/STD9F]R96-A
M<W1;(F1A>7,B75LD9&%Y75LB;FEG:'0B75LB=VEN9$1I<F5C=&EO;B)=/SX\
M+W1D/@H@("`@("`@("`@("`@("`@("`@(#PO='(^"B`@("`@("`@("`@("`@
M("`@("`@/'1R/@H@("`@("`@("`@("`@("`@("`@("`@("`\=&0@86QI9VX]
M(F-E;G1E<B(@<W1Y;&4](FAE:6=H=#H@,35P>"(^/#\])&%F=&5R;F]O;B`_
M("(B(#H@)&9O<F5C87-T6R)D87ES(EU;)&1A>5U;(F1A>2)=6R)H=6UI9&ET
M>2)=+B(E(C\^/"]T9#X*("`@("`@("`@("`@("`@("`@("`@("`@/'1D(&%L
M:6=N/2)C96YT97(B('-T>6QE/2)H96EG:'0Z(#$U<'@B/CP_/21F;W)E8V%S
M=%LB9&%Y<R)=6R1D87E=6R)N:6=H=")=6R)H=6UI9&ET>2)=/SXE/"]T9#X*
M("`@("`@("`@("`@("`@("`@("`\+W1R/@H@("`@("`@("`@("`@("`@/"]T
M86)L93X*("`@("`@("`@("`@/"]T9#X*/#]P:'`*?0H_/@H@("`@("`@(#PO
M='(^"B`@("`@("`@/'1R(&-L87-S/2)B9VMH86MI(CX*("`@(`D@("`@/'1D
M('-T>6QE/2)B;W)D97(M=&]P.B`R<'@@<V]L:60@(V%B861A,B(^)FYB<W`[
M/"]T9#X*("`@("`@("`@("`@/'1D('-T>6QE/2)B;W)D97(M=&]P.B`R<'@@
M<V]L:60@(V%B861A,B(^57!D871E9#H@*#P_/61A=&4H)'1I;65&;W)M870L
M("1W=7!D*3\^)FYB<W`[+R9N8G-P.SP_/61A=&4H)'1I;65&;W)M870L("1F
M=7!D*3\^*3PO=&0^"B`@("`@("`@("`@(#QT9"!A;&EG;CTB<FEG:'0B('-T
M>6QE/2)B;W)D97(M=&]P.B`R<'@@<V]L:60@(V%B861A,B(@8V]L<W!A;CTB
M/#\]*"1F;W)E8V%S=$1A>7,@+2`Q*3\^(CY796%T:&5R(&1A=&$@<')O=FED
M960@8GD@/&$@:')E9CTB:'1T<#HO+W=W=RYW96%T:&5R+F-O;2\_<')O9#UX
M;V%P)G!A<CT\/STD<&%R=&YE<DE$/SXB/G=E871H97(N8V]M/'-P86X@8VQA
M<W,](G)E9R(^)G)E9SL\+W-P86X^/"]A/CQA(&AR968](FAT='`Z+R]W=W<N
M=V5A=&AE<BYC;VTO/W!R;V0]>&]A<"9P87(]/#\])'!A<G1N97))1#\^(CX\
M:6UG('-T>6QE/2)H96EG:'0Z(#,R<'@[('=I9'1H.B`T,W!X(B!A;'0](G=E
M871H97(N8V]M*%(I(&QO9V\B('-R8STB:6UA9V5S+VQO9V]S+U170VQO9V]?
M,S)P>"YP;F<B/CPO83X\+W1D/@H@("`@("`@(#PO='(^"B`@("`@("`@/"]T
M86)L93X*("`@(#PO=&0^"CPO='(^"CPO=&%B;&4^"CQA(&AR968](FIA=F%S
M8W)I<'0Z:&ES=&]R>2YB86-K*"DB/F)A8VL\+V$^"CPO8F]D>3X*/"]H=&UL
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0
M+P``````````````````````````````````````````````````````````
M````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`U,34T,S,W,S8`,#(P,S`P`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92\`````````````````````````
M```````````````````````````````````````````P,#`P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<S-@`P,C$W,S,`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE+V%T
M=&%C:&UE;G0N<&AP````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-3(U`#$P-3$U
M-#,S-S,V`#`R-#4W-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`IR97%U:7)E7V]N8V4H(E-/05`O0VQI96YT+G!H
M<"(I.PIR97%U:7)E7V]N8V4H(E-/05`O=&5S="]T97-T+G5T:6QI='DN<&AP
M(BD["G)E<75I<F5?;VYC92@B4T]!4"]686QU92YP:'`B*3L*"B1F:6QE;F%M
M92`]("=A='1A8VAM96YT+G!H<"<["B1V(#T@(&YE=R!33T%07T%T=&%C:&UE
M;G0H)W1E<W0G+"=T97AT+W!L86EN)RPD9FEL96YA;64I.PHD;65T:&]D5F%L
M=64@/2!N97<@4T]!4%]686QU92@G=&5S=&%T=&%C:"<L("=3=')U8W0G+"!A
M<G)A>2@D=BDI.PH*)&-L:65N="`](&YE=R!33T%07T-L:65N="@G;6%I;'1O
M.G5S97)`9&]M86EN+F-O;2<I.PHC(&-A;&QI;F<@=VET:"!M:6UE"B1R97-P
M(#T@)&-L:65N="T^8V%L;"@G96-H;TUI;65!='1A8VAM96YT)RQA<G)A>2@D
M=BDL"B`@("`@("`@("`@("`@("!A<G)A>2@G871T86-H;65N=',G/3XG36EM
M92<L"B`@("`@("`@("`@("`@("`G;F%M97-P86-E)ST^)VAT='`Z+R]S;V%P
M:6YT97)O<"YO<F<O)RP*("`@("`@("`@("`@("`@("=F<F]M)ST^)W5S97)`
M9&]M86EN+F-O;2<L"B`@("`@("`@("`@("`@("`G:&]S="<]/B=S;71P+F1O
M;6%I;BYC;VTG*2D["G!R:6YT("1C;&EE;G0M/G=I<F4N(EQN7&Y<;B(["G!R
M:6YT7W(H)')E<W`I.PH*(R!C86QL:6YG('=I=&@@1$E-10HD<F5S<"`]("1C
M;&EE;G0M/F-A;&PH)V5C:&]-:6UE071T86-H;65N="<L87)R87DH)'8I*3L*
M(R!$24U%(&AA<R!N=6QL('-P86-E<RP@8VAA;F=E('1H96T@<V\@=V4@8V%N
M('-E92!T:&4@=VER90HD=VER92`]('-T<E]R97!L86-E*")<,"(L)RHG+"1C
M;&EE;G0M/G=I<F4I.PIP<FEN="`D=VER92XB7&Y<;EQN(CL*<')I;G1?<B@D
M<F5S<"D["C\^````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M
M<&QE+V-L:65N="YP:'``````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P,#$U
M`#$P-3$U-#,S-S,V`#`R,S<Q-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H
M8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@
M,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@
M8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%
M+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO
M=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A
M;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@
M("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO
M=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!3:&%N92!#
M87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO
M+R`D260Z(&-L:65N="YP:'`L=B`Q+C$P(#(P,#4O,#,O,3`@,C,Z,38Z,SD@
M>75N;W-H($5X<"`D"B\O"FEN8VQU9&4H(E-/05`O0VQI96YT+G!H<"(I.PH*
M+RHJ"B`J('1H:7,@8VQI96YT(')U;G,@86=A:6YS="!T:&4@97AA;7!L92!S
M97)V97(@:6X@4T]!4"]E>&%M<&QE+W-E<G9E<BYP:'`*("H@:70@9&]E<R!N
M;W0@=7-E(%=31$P@=&\@<G5N('1H97-E(')E<75E<W1S+"!B=70@=&AA="!C
M86X@8F4@8VAA;F=E9"!E87-I;'D@8GD@<VEM<&QY"B`J(&%D9&EN9R`G/W=S
M9&PG('1O('1H92!E;F0@;V8@=&AE('5R;"X*("HO"B1S;V%P8VQI96YT(#T@
M;F5W(%-/05!?0VQI96YT*")H='1P.B\O;&]C86QH;W-T+U-/05`O97AA;7!L
M92]S97)V97(N<&AP(BD["B\O('1H:7,@;F%M97-P86-E(&ES('1H92!S86UE
M(&%S(&1E8VQA<F5D(&EN('-E<G9E<BYP:'`*)&]P=&EO;G,@/2!A<G)A>2@G
M;F%M97-P86-E)R`]/B`G=7)N.E-/05!?17AA;7!L95]397)V97(G+`H@("`@
M("`@("`@("`@("`@("=T<F%C92<@/3X@,2D["@HD<F5T(#T@)'-O87!C;&EE
M;G0M/F-A;&PH(F5C:&]3=')I;F=3:6UP;&4B+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*")I;G!U=%-T<FEN9U-I;7!L92(]
M/B)T:&ES(&ES(&$@=&5S="!S=')I;F<B*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("1O<'1I;VYS*3L*(W!R:6YT("1S;V%P8VQI96YT+3Y?7V=E=%]W
M:7)E*"D["G!R:6YT7W(H)')E="D[96-H;R`B/&)R/EQN(CL*"B1R970@/2`D
M<V]A<&-L:65N="T^8V%L;"@B96-H;U-T<FEN9R(L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`D<&%R86US(#T@87)R87DH(FEN<'5T4W1R:6YG(CT^(G1H
M:7,@:7,@82!T97-T('-T<FEN9R(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@)&]P=&EO;G,I.PIP<FEN=%]R*"1R970I.V5C:&\@(CQB<CY<;B(["@HD
M<F5T(#T@)'-O87!C;&EE;G0M/F-A;&PH(F1I=FED92(L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`D<&%R86US(#T@87)R87DH(F1I=FED96YD(CT^,C(L
M(F1I=FES;W(B/3XW*2P*("`@("`@("`@("`@("`@("`@("`@("`@("1O<'1I
M;VYS*3L*(R!P<FEN="`D<V]A<&-L:65N="T^7U]G971?=VER92@I.PII9B`H
M4$5!4CHZ:7-%<G)O<B@D<F5T*2D*("`@('!R:6YT*")%<G)O<CH@(B`N("1R
M970M/F=E=$UE<W-A9V4H*2`N("(\8G(^7&XB*3L*96QS90H@("`@<')I;G0H
M(E%U;W1I96YT(&ES("(@+B`D<F5T("X@(CQB<CY<;B(I.PH*)')E="`]("1S
M;V%P8VQI96YT+3YC86QL*")D:79I9&4B+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!A<F%M<R`](&%R<F%Y*")D:79I9&5N9"(]/C(R+")D:79I<V]R
M(CT^,"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`D;W!T:6]N<RD["FEF
M("A014%2.CII<T5R<F]R*"1R970I*0H@("`@<')I;G0H(D5R<F]R.B`B("X@
M)')E="T^9V5T365S<V%G92@I("X@(CQB<CY<;B(I.PIE;'-E"B`@("!P<FEN
M="@B475O=&EE;G0@:7,@(B`N("1R970@+B`B/&)R/EQN(BD["@H*+R\@4T]!
M4%-T<G5C="!I<R!D969I;F5D(&EN('1H92!F;VQL;W=I;F<@9FEL90IR97%U
M:7)E7V]N8V4@)V5X86UP;&5?='EP97,N<&AP)SL*"B1S=')U8W0@/2!N97<@
M4T]!4%-T<G5C="@G=&5S="!S=')I;F<G+#$R,RPQ,C,N,3(S*3L*"B\J('-E
M;F0@86X@;V)J96-T+"!G970@86X@;V)J96-T(&)A8VL@*B\*+RH@=&5L;"!C
M;&EE;G0@=&\@=')A;G-L871E('1O(&-L87-S97,@=V4@<')O=FED92!I9B!P
M;W-S:6)L92`J+PHD<V]A<&-L:65N="T^7V%U=&]?=')A;G-L871I;VX@/2!T
M<G5E.PHO*B!O<B!Y;W4@8V%N(&5X<&QI8VET;'D@<V5T('1H92!T<F%N<VQA
M=&EO;B!F;W(*("`@82!S<&5C:69I8R!C;&%S<RX@(&%U=&]?=')A;G-L871I
M;VX@=V]R:W,@9F]R(&%L;"!C87-E<RP*("`@8G5T(&]P96YS($%.62!C;&%S
M<R!I;B!T:&4@<V-R:7!T('1O(&)E('5S960@87,@82!D871A('1Y<&4L"B`@
M(&%N9"!M87D@;F]T(&)E(&1E<VER96%B;&4N("!B;W1H(&-A;B!B92!U<V5D
M(&]N(&-L:65N="!O<@H@("!S97)V97(@*B\*)'-O87!C;&EE;G0M/E]?<V5T
M7W1Y<&5?=')A;G-L871I;VXH)WMH='1P.B\O<V]A<&EN=&5R;W`N;W)G+WAS
M9'U33T%04W1R=6-T)RPG4T]!4%-T<G5C="<I.PHD<F5T(#T@)'-O87!C;&EE
M;G0M/F-A;&PH(F5C:&]3=')U8W0B+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@)'`@/2!A<G)A>2@G:6YP=713=')U8W0G(#T^("1S=')U8W0M/E]?=&]?
M<V]A<"@I*2P*("`@("`@("`@("`@("`@("`@("`@("`@("1O<'1I;VYS*3L*
M(W!R:6YT("1S;V%P8VQI96YT+3Y?7V=E=%]W:7)E*"D["G!R:6YT7W(H)')E
M="D["@HO*BH*("H@4$A0(&1O97-N)W0@<W5P<&]R="!M=6QT:7!L92!/550@
M<&%R86UE=&5R<R!I;B!F=6YC=&EO;B!C86QL<RP@<V\@=V4*("H@;75S="!D
M;R!A(&QI='1L92!W;W)K('1O(&UA:V4@:70@:&%P<&5N(&AE<F4N("!4:&ES
M(')E<75I<F5S(&MN;W=L961G92!O;B!T:&4*("H@9&5V96QO<&5R<R!P87)T
M('1O(&9I9W5R92!O=70@:&]W('1H97D@=V%N="!T;R!D96%L('=I=&@@:70N
M"B`J+PHD<F5T(#T@)'-O87!C;&EE;G0M/F-A;&PH(F5C:&]3=')U8W1!<U-I
M;7!L951Y<&5S(BP*("`@("`@("`@("`@("`@("`@("`@("`@("1P(#T@87)R
M87DH)VEN<'5T4W1R=6-T)R`]/B`D<W1R=6-T+3Y?7W1O7W-O87`H*2DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`D;W!T:6]N<RD["FEF("A014%2.CII
M<T5R<F]R*"1R970I*2!["B`@("!P<FEN="@B17)R;W(Z("(@+B`D<F5T+3YG
M971-97-S86=E*"D@+B`B/&)R/EQN(BD["GT@96QS92!["B`@("!L:7-T*"1S
M=')I;F<L("1I;G0L("1F;&]A="D@/2!A<G)A>5]V86QU97,H)')E="D["GT*
M96-H;R`B=F%R4W1R:6YG.B`D<W1R:6YG/&)R/EQN=F%R26YT.B`D:6YT/&)R
M/EQN=F%R1FQO870Z("1F;&]A=#QB<CY<;B(["@H_/@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X86UP;&4O8V]M7V-L
M:65N="YP:'``````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0R,C8`,3`U,34T,S,W
M,S8`,#(T-38T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P
M,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES
M('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H
M92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I
M=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@
M("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@
M<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@
M?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I
M;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%-H86YE($-A<F%V96\@/%-H
M86YE0$-A<F%V96\N8V]M/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@8V]M
M7V-L:65N="YP:'`L=B`Q+C,@,C`P-2\P,R\Q,"`R,SHQ-CHT,"!Y=6YO<V@@
M17AP("0*+R\*+R\@4T]!4%-T<G5C="!I<R!D969I;F5D(&EN('1H92!F;VQL
M;W=I;F<@9FEL90IR97%U:7)E7V]N8V4@)V5X86UP;&5?='EP97,N<&AP)SL*
M"B\J(&IU<W0@82!S:6UP;&4@97AA;7!L92!O9B!U<VEN9R!-4R!33T%0(&]N
M('=I;C,R(&%S(&$@8VQI96YT"B`@('1O('1H92!P:'`@<V5R=F5R+B`@*B\*
M"B\O;&]A9"!#3TT@4T]!4"!C;&EE;G0@;V)J96-T"B1S;V%P8VQI96YT(#T@
M;F5W($-/32@B35-33T%0+E-O87!#;&EE;G0S,"(I.PH*+R]C;VYN96-T('1O
M('=E8B!S97)V:6-E"B1S;V%P8VQI96YT+3YM<W-O87!I;FET*")H='1P.B\O
M;&]C86QH;W-T+U-/05`O97AA;7!L92]S97)V97(N<&AP/W=S9&PB*3L*"B\O
M;V)T86EN(')E<W5L="!F<F]M('=E8B!S97)V:6-E(&UE=&AO9`HD<F5T(#T@
M)'-O87!C;&EE;G0M/F5C:&]3=')I;F<H(E1H:7,@:7,@82!T97-T(2(I.PIP
M<FEN="@B)')E=%QN(BD["@HD<F5T(#T@)'-O87!C;&EE;G0M/F5C:&]3=')I
M;F=3:6UP;&4H(E1H:7,@:7,@86YO=&AE<B!T97-T(2(I.PIP<FEN="@B)')E
M=%QN(BD["@HC('1H92!F;VQL;W=I;F<@8V%U<V5S(&%N(&5X8V5P=&EO;B!I
M;B!T:&4@0T]-(&5X=&5N<VEO;@H*(R1R970@/2`D<V]A<&-L:65N="T^9&EV
M:61E*#(R+#<I.PHC<')I;G0@)'-O87!C;&EE;G0M/F9A=6QT8V]D93L*(W!R
M:6YT("1S;V%P8VQI96YT+3YF875L='-T<FEN9SL*(W!R:6YT*"(R,B\W/21R
M971<;B(I.PHC<')I;G1?<B@D<F5T*3L*(R1R970@/2`D<V]A<&-L:65N="T^
M9&EV:61E*#(R+#`I.PHC<')I;G0H(C(R+S`])')E=%QN(BD["@HC)'-T<G5C
M="`](&YE=R!33T%04W1R=6-T*"=T97-T('-T<FEN9R<L,3(S+#$R,RXQ,C,I
M.PHC)')E="`]("1S;V%P8VQI96YT+3YE8VAO4W1R=6-T*"1S=')U8W0I.PHC
M<')I;G1?<B@D<F5T*3L*"B,D<F5T(#T@)'-O87!C;&EE;G0M/F5C:&]3=')U
M8W1!<U-I;7!L951Y<&5S*"1S=')U8W0I.PHC<')I;G1?<B@D<F5T*3L*"C\^
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X
M86UP;&4O9&ES8V]?<V5R=F5R+G!H<```````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C(R
M,#``,3`U,34T,S,W,S8`,#(U,3(W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC
M*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R
M+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B
M=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L
M(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N
M9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@
M("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U
M(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@1&UI=')I(%9I
M;F]G<F%D;W8@/&1I;6ET<FE`=FEN;V=R861O=BYD93X@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O
M("1)9#H@9&ES8V]?<V5R=F5R+G!H<"QV(#$N-2`R,#`U+S`S+S$P(#(S.C$V
M.C0P('EU;F]S:"!%>'`@)`H*+RH*("!4:&ES(&5X86UP;&4@<VAO=W,@:&]W
M('1O(&UA<FL@=7`@82!S97)V97(@;V)J96-T('-O('1H870*("!W<V1L(&9I
M;&5S(&UA>2!B92!D>6YA;6EC86QY(&=E;F5R871E9"!B>2!T:&4@<V]A<`H@
M('-E<G9E<BX@(%1H:7,@86QS;R!P<F]V:61E<R!A8V-E<W,@=&\@82!G96YE
M<F%T960@1$E30T\@9&]C=6UE;G0N"B`@5&AE(&9A8W0@=&AA="!T:&ES(&5X
M86UP;&4@:&%S(&%N($U0,R!C;&%S<R!I<R!I;B!N;R!W87D*("!R96QA=&5D
M('1O($1)4T-/+B`[*0H@(`H@($1)4T-/.B!H='1P.B\O;7-D;BYM:6-R;W-O
M9G0N8V]M+VUS9&YM86<O:7-S=65S+S`R+S`R+WAM;"]D969A=6QT+F%S<'@*
M("`*("!!('5R;"!A8V-E<W-I;F<@=&AI<R!S97)V97(@=V]U;&0@;&]O:R!L
M:6ME.@H@(`H@(&AT='`Z+R]L;V-A;&AO<W0O9&ES8V]?<V5R=F5R+G!H<#]W
M<V1L("AG96YE<F%T92!74T1,(&9I;&4I"B`@:'1T<#HO+VQO8V%L:&]S="]D
M:7-C;U]S97)V97(N<&AP("A'150@<F5Q=65S="!G96YE<F%T97,@1$E30T\I
M"B`@:'1T<#HO+VQO8V%L:&]S="]D:7-C;U]S97)V97(N<&AP("A03U-4(&9O
M<B!N;W)M86P@<V]A<"!R97%U97-T<RD**B\*"F5R<F]R7W)E<&]R=&EN9RA%
M7T%,3"D["G)E<75I<F5?;VYC92`G4T]!4"]397)V97(N<&AP)SL*"F-L87-S
M($U0,T1"7T-L87-S('L*("`@('9A<B`D7U]D:7-P871C:%]M87`@/2!A<G)A
M>2@I.PH@("`@=F%R("1?7W1Y<&5D968@("`@(#T@87)R87DH*3L*("`@(`H@
M("`@9G5N8W1I;VX@35`S1$)?0VQA<W,@*"D@>PH@("`@("`@("\J*@H@("`@
M("`@("H@=&AE(&]N;'D@=V%Y('1O(&1E<V-R:6)E(&%L;"!M971H;V1S(&EN
M(%=31$P@*&UE<W-A9V5S+`H@("`@("`@("H@4&]R=%1Y<&4M;W!E<F%T:6]N
M<R!A;F0@8FEN9&EN9W,I(&ES('1O('5S92!?7V1I<W!A=&-H7VUA<`H@("`@
M("`@("H@=&\@9&5S8W)I8F4@979E<GD@;65T:&]D("AE=F5N(&UE=&AO9',@
M=7-I;F<@<VEM<&QE(&1A=&$@"B`@("`@("`@*B!T>7!E<R!I;B`G:6XG(&%N
M9"`G;W5T)R!P87)A;65T97)S+BXN*0H@("`@("`@("HO"B`@("`@("`@"B`@
M("`@("`@)'1H:7,M/E]?9&ES<&%T8VA?;6%P6R=387E(86QL;R==(#T*("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@
M("`@)VEN)R`]/B!A<G)A>2@G:6YP=70G(#T^("=S=')I;F<G*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@)V]U="<@/3X@87)R87DH)W)E='5R;B<@/3X@
M)W-T<FEN9R<I"B`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@
M("`@("`@("`*("`@("`@("`D=&AI<RT^7U]D:7-P871C:%]M87!;)U-A>51H
M:7-.5&EM97,G72`]"B`@("`@("`@("`@("`@("`@("`@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@("`@("=I;B<@/3X@87)R87DH)U-A>51H:7,G/3XG
M<W1R:6YG)RPG3E1I;65S)R`]/B`G:6YT)RDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("=O=70G(#T^(&%R<F%Y*"=R971U<FXG(#T^("=[=7)N.DU0,T1"
M?4%R<F%Y3V93=')I;F=S)RD*("`@("`@("`@("`@("`@("`@("`I.PH@("`@
M("`@("`@("`@("`@("`@(`H@("`@("`@("1T:&ES+3Y?7V1I<W!A=&-H7VUA
M<%LG1V5T35`S5')A8VMS)UT@/0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*`H@("`@("`@("`@("`@("`@("`@("`@("`G:6XG(#T^(&%R<F%Y*"=Q=65R
M>2<@/3X@)W-T<FEN9R<I+`H@("`@("`@("`@("`@("`@("`@("`@("`G;W5T
M)R`]/B!A<G)A>2@G<F5T=7)N)R`]/B`G>W5R;CI-4#-$0GU'971-4#-4<F%C
M:W-297-U;'0G*0H@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@
M("`@("`@("`@"B`@("`@("`@)'1H:7,M/E]?9&ES<&%T8VA?;6%P6R=!9&1-
M4#-4<F%C:R==(#T*("`@("`@("`@("`@("`@("`@("!A<G)A>2@*("`@("`@
M("`@("`@("`@("`@("`@("`@)VEN)R`]/B!A<G)A>2@G35`S5')A8VLG(#T^
M("=[=7)N.DU0,T1"?4U0,U1R86-K)RDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("=O=70G(#T^(&%R<F%Y*"=R971U<FXG(#T^("=[=7)N.DU0,T1"?4%D
M9$U0,U1R86-K4F5S=6QT)RD*("`@("`@("`@("`@("`@("`@("`I.PH*("`@
M("`@("`O*BH*("`@("`@("`J($D@=7-E(%]?='EP961E9B!T;R!D97-C<FEB
M92!U<V5R9&5F:6YE9"!4>7!E<R!I;B!74T1,+@H@("`@("`@("H@4W1R=6-T
M<R!A;F0@;VYE+61I;65N<VEO;F%L(&%R<F%Y<R!A<F4@<W5P<&]R=&5D.@H@
M("`@("`@("H@4W1R=6-T(&5X86UP;&4Z("1T:&ES+3Y?7W1Y<&5D969;)U1Y
M<&5.86UE)UT@/2!A<G)A>2@G5F%R3F%M92<@/3X@)WAS9%1Y<&4G+"`N+BX@
M*3L*("`@("`@("`J("`@(&]R("1T:&ES+3Y?7W1Y<&5D969;)U1Y<&5.86UE
M)UT@/2!A<G)A>2@G5F%R3F%M92<@/3X@)WMN86UE<W!A8V5]4V]M94]T:&5R
M5'EP92<I.PH@("`@("`@("H@07)R87D@97AA;7!L93H@)'1H:7,M/E]?='EP
M961E9ELG5'EP94YA;64G72`](&%R<F%Y*&%R<F%Y*"=I=&5M)R`]/B`G>'-D
M5'EP92<I*3L*("`@("`@("`J("`@(&]R("1T:&ES+3Y?7W1Y<&5D969;)U1Y
M<&5.86UE)UT@/2!A<G)A>2AA<G)A>2@G:71E;2<@/3X@)WMN86UE<W!A8V5]
M4V]M94]T:&5R5'EP92<I*3L*("`@("`@("`J+PH@("`@"B`@("`@("`@+RHJ
M"B`@("`@("`@*B!3=')U8W0@)TU0,U1R86-K)PH@("`@("`@("HO"B`@("`@
M("`@)'1H:7,M/E]?='EP961E9ELG35`S5')A8VLG72`](`H@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`G5&ET
M;&4G(#T^("=S=')I;F<G+`H@("`@("`@("`@("`@("`@("`@("`@("`G07)T
M:7-T)R`]/B`G<W1R:6YG)RP@"B`@("`@("`@("`@("`@("`@("`@("`@("=!
M;&)U;2<@/3X@)W-T<FEN9R<L(`H@("`@("`@("`@("`@("`@("`@("`@("`G
M665A<B<@/3X@)VEN="<L(`H@("`@("`@("`@("`@("`@("`@("`@("`G1V5N
M<F4G(#T^("=I;G0G+`H@("`@("`@("`@("`@("`@("`@("`@("`G0V]M;65N
M="<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("`@("`@("`@("`@("=#;VUP
M;W-E<B<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("`@("`@("`@("`@("=/
M<FEG7T%R=&ES="<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("=54DPG(#T^("=S=')I;F<G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`G16YC;V1E9%]B>2<@/3X@)W-T<FEN9R<*("`@("`@("`@("`@("`@("`@
M("`I.PH@("`@("`@("`@("`@("`@("`@(`H@("`@("`@("`@("`@("`@("`@
M(`H@("`@("`@("`@("`@("`@("`@(`H@("`@("`@("\J*@H@("`@("`@("H@
M35`S5')A8VMS07)R87D@+2!A<G)A>2!O9B`G35`S5')A8VLG('-T<G5C=',*
M("`@("`@("`J+PH@("`@("`@("1T:&ES+3Y?7W1Y<&5D969;)TU0,U1R86-K
M<T%R<F%Y)UT@/2`*("`@("`@("`@("`@("`@("`@("!A<G)A>2@*("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G:71E;2<@/3X@)WMU<FXZ35`S1$)]35`S5')A8VLG"B`@("`@
M("`@("`@("`@("`@("`@("`@("D*("`@("`@("`@("`@("`@("`@("`I.PH@
M("`@("`@("`@("`@("`@("`@(`H@("`@("`@("\J*@H@("`@("`@("H@4W1R
M=6-T("=-971H;V1$96)U9R<*("`@("`@("`J+PH@("`@("`@("1T:&ES+3Y?
M7W1Y<&5D969;)TUE=&AO9$1E8G5G)UT@/2`*("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)W)C)R`]/B`G8F]O
M;&5A;B<L"B`@("`@("`@("`@("`@("`@("`@("`@("=%<G).;R<@/3X@)VEN
M="<L(`H@("`@("`@("`@("`@("`@("`@("`@("`G17)R;W(G(#T^("=S=')I
M;F<G"B`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@("`@
M("`*("`@("`@("`O*BH*("`@("`@("`J(')E='5R;B!3=')U8W0@;V8@;65T
M:&]D($=E=$U0,U1R86-K<PH@("`@("`@("HO"B`@("`@("`@)'1H:7,M/E]?
M='EP961E9ELG1V5T35`S5')A8VMS4F5S=6QT)UT@/2`*("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)TUE=&AO
M9$1E8G5G)R`]/B`G>W5R;CI-4#-$0GU-971H;V1$96)U9R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("=-4#-4<F%C:W,G(#T^("=[=7)N.DU0,T1"?4U0
M,U1R86-K<T%R<F%Y)PH@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@
M("`@("`@("`@("`@"B`@("`@("`@+RHJ"B`@("`@("`@*B!R971U<FX@4W1R
M=6-T(&]F(&UE=&AO9"!!9&1-4#-4<F%C:PH@("`@("`@("HO"B`@("`@("`@
M)'1H:7,M/E]?='EP961E9ELG061D35`S5')A8VM297-U;'0G72`](`H@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@
M("`G365T:&]D1&5B=6<G(#T^("=[=7)N.DU0,T1"?4UE=&AO9$1E8G5G)PH@
M("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@("`@("`@("`@"B`@
M("`@("`@+RHJ"B`@("`@("`@*B!!<G)A>2!O9B!S=')I;F=S"B`@("`@("`@
M*B\*("`@("`@("`D=&AI<RT^7U]T>7!E9&5F6R=!<G)A>4]F4W1R:6YG<R==
M(#T@"B`@("`@("`@("`@("`@("`@("`@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*"=I=&5M)ST^)W-T<FEN9R<I"B`@("`@("`@("`@
M("`@("`@("`@*3L*("`@(`H@("`@?0H@("`@"B`@("`*("`@(&9U;F-T:6]N
M(%-A>4AA;&QO*"1N86UE*2!["B`@("`@("`@<F5T=7)N(")(86QL;RP@(B`N
M("1N86UE.PH@("`@?0H@("`@"B`@("`*("`@(&9U;F-T:6]N(%-A>51H:7-.
M5&EM97,H)%-A>51H:7,L)$Y4:6UE<RD@>PH@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\("1.5&EM97,[("1I*RLI('L*("`@("`@("`@("`@)')E='5R;ELD
M:5T@/2`D4V%Y5&AI<R`N("(@)&DB.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@;F5W(%-/05!?5F%L=64H)W)E='5R;B<L)WMU<FXZ35`S1$)]07)R87E/
M9E-T<FEN9W,G+"1R971U<FXI.PH@("`@?0H@("`@"B`@("`*("`@(&9U;F-T
M:6]N($=E=$U0,U1R86-K<R@D<75E<GD@/2`B(BD@>PH@("`@("`@(&9O<B@D
M:2`](#`[("1I(#P@-3L@)&DK*RD@>PH@("`@("`@("`@("`D=&AI<RT^35`S
M5')A8VMS6R1I72`](&YE=R!33T%07U9A;'5E*`H@("`@("`@("`@("`@("`@
M("`@("=I=&5M)RP*("`@("`@("`@("`@("`@("`@("`G>W5R;CI-4#-$0GU-
M4#-4<F%C:R<L"B`@("`@("`@("`@("`@("`@("`@87)R87DH"B`@("`@("`@
M("`@("`@("`@("`@("`@(")4:71L92(@("`@("`@("`]/B!N97<@4T]!4%]6
M86QU92@B5&ET;&4B+")S=')I;F<B+")S;VUE('1R86-K("1I(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@(")!<G1I<W0B("`@("`@("`]/B!N97<@4T]!
M4%]686QU92@B07)T:7-T(BPB<W1R:6YG(BPB<V]M92!A<G1I<W0@)&DB*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@(D%L8G5M(B`@("`@("`@(#T^(&YE
M=R!33T%07U9A;'5E*")!;&)U;2(L(G-T<FEN9R(L(G-O;64@86QB=6T@)&DB
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@(EEE87(B("`@("`@("`@(#T^
M(&YE=R!33T%07U9A;'5E*")996%R(BPB:6YT(BPH:6YT96=E<BDQ.3DY*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@(D=E;G)E(B`@("`@("`@(#T^(&YE
M=R!33T%07U9A;'5E*")'96YR92(L(FEN="(L*&EN=&5G97(I,3`P*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@(D-O;6UE;G0B("`@("`@(#T^(&YE=R!3
M3T%07U9A;'5E*")#;VUM96YT(BPB<W1R:6YG(BPB8FQA8FQA("1I(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@(")#;VUP;W-E<B(@("`@("`]/B!N97<@
M4T]!4%]686QU92@B0V]M<&]S97(B+")S=')I;F<B+"(B*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@(D]R:6=?07)T:7-T(B`@(#T^(&YE=R!33T%07U9A
M;'5E*")/<FEG7T%R=&ES="(L(G-T<FEN9R(L(B(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`B55),(B`@("`@("`@("`@/3X@;F5W(%-/05!?5F%L=64H
M(E523"(L(G-T<FEN9R(L(B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`B
M16YC;V1E9%]B>2(@("`@/3X@;F5W(%-/05!?5F%L=64H(D5N8V]D961?8GDB
M+")S=')I;F<B+"(B*0H@("`@("`@("`@("`@("`@("`@("`@("`I"B`@("`@
M("`@("`@("`@("`I.PH@("`@("`@('T*("`@("`@("`*("`@("`@("`D365T
M:&]D1&5B=6=;(G)C(ET@("`@/2!N97<@4T]!4%]686QU92@B<F,B+")B;V]L
M96%N(BQT<G5E*3L*("`@("`@("`D365T:&]D1&5B=6=;(D5R<DYO(ET@/2!N
M97<@4T]!4%]686QU92@B17)R3F\B+")I;G0B+"AI;G1E9V5R*3`I.PH@("`@
M("`@("1-971H;V1$96)U9ULB17)R;W(B72`](&YE=R!33T%07U9A;'5E*")%
M<G)O<B(L(G-T<FEN9R(L(B(I.PH@("`@("`@("`@("`*("`@("`@("!R971U
M<FX@;F5W(%-/05!?5F%L=64H)W)E='5R;B<L)WMU<FXZ35`S1$)]1V5T35`S
M5')A8VMS4F5S=6QT)RQA<G)A>2@*("`@("`@("`@("`@("`@("`@("`B365T
M:&]D1&5B=6<B(#T^(&YE=R!33T%07U9A;'5E*"=-971H;V1$96)U9R<L)WMU
M<FXZ35`S1$)]365T:&]D1&5B=6<G+"1-971H;V1$96)U9RDL"B`@("`@("`@
M("`@("`@("`@("`@(DU0,U1R86-K<R(@("`]/B!N97<@4T]!4%]686QU92@G
M35`S5')A8VMS)RPG>W5R;CI-4#-$0GU-4#-4<F%C:W-!<G)A>2<L)'1H:7,M
M/DU0,U1R86-K<RD*("`@("`@("`@("`@("`@("`@("`I"B`@("`@("`@("`@
M("`@("`I.PH@("`@?0H@("`@"B`@("`*("`@(&9U;F-T:6]N($%D9$U0,U1R
M86-K*"1-4#-4<F%C:RD@>PH@("`@("`@(",@=V5L;"P@;&5T<R!I;6%G:6YE
M(&AE<F4@<V]M92!C;V1E(&9O<B!A9&1I;F<@9VEV96X@;7`S=')A8VL@=&\@
M9&(@;W(@=VAA=&5V97(N+BX*("`@("`@("`D365T:&]D1&5B=6=;(G)C(ET@
M("`@/2!N97<@4T]!4%]686QU92@B<F,B+")B;V]L96%N(BQT<G5E*3L*("`@
M("`@("`D365T:&]D1&5B=6=;(D5R<DYO(ET@/2!N97<@4T]!4%]686QU92@B
M17)R3F\B+")I;G0B+"AI;G1E9V5R*3`I.PH@("`@("`@("1-971H;V1$96)U
M9ULB17)R;W(B72`](&YE=R!33T%07U9A;'5E*")%<G)O<B(L(G-T<FEN9R(L
M(B(I.PH@("`@("`@(`H@("`@("`@(')E='5R;B!N97<@4T]!4%]686QU92@G
M<F5T=7)N)RPG>W5R;CI-4#-$0GU!9&1-4#-4<F%C:U)E<W5L="<L87)R87DH
M"B`@("`@("`@("`@("`@("`@("`@(DUE=&AO9$1E8G5G(B`]/B!N97<@4T]!
M4%]686QU92@G365T:&]D1&5B=6<G+"=[=7)N.DU0,T1"?4UE=&AO9$1E8G5G
M)RPD365T:&]D1&5B=6<I"B`@("`@("`@("`@("`@("`@("`@*0H@("`@("`@
M("`@("`@("`@*3L*("`@('T*("`@(`H@("`@"B`@("!F=6YC=&EO;B!?7V1I
M<W!A=&-H*"1M971H;V1N86UE*2!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?7V1I<W!A=&-H7VUA<%LD;65T:&]D;F%M95TI*0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]?9&ES<&%T8VA?;6%P6R1M971H;V1N86UE73L*("`@
M("`@("!R971U<FX@3E5,3#L*("`@('T*?0H*)'-E<G9E<B`](&YE=R!33T%0
M7U-E<G9E<CL*)'-E<G9E<BT^7V%U=&]?=')A;G-L871I;VX@/2!T<G5E.PHD
M35`S1$)?0VQA<W,@/2!N97<@35`S1$)?0VQA<W,H*3L*)'-E<G9E<BT^861D
M3V)J96-T36%P*"1-4#-$0E]#;&%S<RPG=7)N.DU0,T1")RD["@H*:68@*&ES
M<V5T*"1?4T525D526R=215%515-47TU%5$A/1"==*2`F)@H@("`@)%]315)6
M15);)U)%455%4U1?34542$]$)UT]/2=03U-4)RD@>PH@("`@)'-E<G9E<BT^
M<V5R=FEC92@D2%144%]205=?4$]35%]$051!*3L*?2!E;'-E('L*("`@(')E
M<75I<F5?;VYC92`G4T]!4"]$:7-C;RYP:'`G.PH@("`@)&1I<V-O(#T@;F5W
M(%-/05!?1$E30T]?4V5R=F5R*"1S97)V97(L(DU0,T1"(BD["B`@("!H96%D
M97(H(D-O;G1E;G0M='EP93H@=&5X="]X;6PB*3L*("`@(&EF("AI<W-E="@D
M7U-%4E9%4ELG455%4EE?4U1224Y')UTI("8F"B`@("`@("!S=')C87-E8VUP
M*"1?4T525D526R=1545265]35%))3D<G72PG=W-D;"<I/3TP*2!["B`@("`@
M("`@96-H;R`D9&ES8V\M/F=E=%=31$PH*3L*("`@('T@96QS92!["B`@("`@
M("`@96-H;R`D9&ES8V\M/F=E=$1)4T-/*"D["B`@("!]"B`@("!E>&ET.PI]
M"C\^````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE+V5M86EL7V-L:65N="YP
M:'```````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,S(R`#$P-3$U-#,S-S,V`#`R-3`W
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!0
M2%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!0
M2%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@
M9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI
M8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@
M<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*
M+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@
M82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@
M('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L
M('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS
M94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E
M;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!!=71H;W)S.B!3:&%N92!#87)A=F5O(#Q3:&%N94!#87)A
M=F5O+F-O;3X@("!0;W)T('1O(%!%05(@86YD(&UO<F4@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z(&5M86EL7V-L:65N
M="YP:'`L=B`Q+C0@,C`P-2\P,R\Q,"`R,SHQ-CHT,"!Y=6YO<V@@17AP("0*
M+R\*"B\J"E1H:7,@<F5A9',@82!M97-S86=E(&9R;VT@<W1D:6XL(&%N9"!C
M86QL<R!T:&4@<V]A<"!S97)V97(@9&5F:6YE9`H*66]U(&-A;B!U<V4@=&AI
M<R!F<F]M('%M86EL(&)Y(&-R96%T:6YG(&$@+G%M86EL+7-O87!T97-T(&9I
M;&4@=VET:#H*("`@('P@+W5S<B]B:6XO<&AP("]P871H+W1O+V5M86EL7W-E
M<G9E<BYP:'`**B\*"B,@:6YC;'5D92!T:&4@96UA:6P@<V5R=F5R(&-L87-S
M"G)E<75I<F5?;VYC92`G4T]!4"]397)V97(O16UA:6PN<&AP)SL*"B1S97)V
M97(@/2!N97<@4T]!4%]397)V97)?16UA:6P["@HC(')E860@<W1D:6X*)&9I
M;B`](&9O<&5N*"=P:'`Z+R]S=&1I;B<L)W)B)RD["FEF("@A)&9I;BD@97AI
M="@P*3L*"B1E;6%I;"`]("<G.PIW:&EL92`H(69E;V8H)&9I;BD@)B8@)&1A
M=&$@/2!F<F5A9"@D9FEN+"`X,#DV*2D@>PH@("1E;6%I;"`N/2`D9&%T83L*
M?0H*9F-L;W-E*"1F:6XI.PH*"B1R97-P;VYS92`]("1S97)V97(M/F-L:65N
M="@D96UA:6PI.PH*<')I;G1?<B@D<F5S<&]N<V4I.PH*/SX`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]E;6%I;%]G871E=V%Y+G!H<```
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,S0W,P`Q,#4Q-30S,S<S-@`P,C4R-C,`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E
M<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R
M;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E
M+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA
M9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@
M879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P
M>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O
M('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A
M<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP
M+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@075T:&]R<SH@4VAA;F4@0V%R879E;R`\4VAA;F5`0V%R879E;RYC
M;VT^("`@4&]R="!T;R!014%2(&%N9"!M;W)E("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!E;6%I;%]G871E=V%Y+G!H
M<"QV(#$N-2`R,#`U+S`S+S$P(#(S.C$V.C0P('EU;F]S:"!%>'`@)`HO+PH*
M+RH*5&AI<R!R96%D<R!A(&UE<W-A9V4@9G)O;2!S=&1I;BP@86YD('!A<W-E
M<R!T:&4@<F5Q=65S="!T;PIA('-O87`@<V5R=F5R(')E<VED:6YG(&]N(&$@
M=V5B('-E<G9E<BP@<V5N9',@=&AE(')E<W!O;G-E"F]U="!A<R!A;B!E;6%I
M;`H*66]U(&-A;B!U<V4@=&AI<R!F<F]M('%M86EL(&)Y(&-R96%T:6YG(&$@
M+G%M86EL+7-O87!G871E=V%Y(&9I;&4@=VET:#H*("`@('P@+W5S<B]B:6XO
M<&AP("]P871H+W1O+V5M86EL7W-E<G9E<BYP:'`**B\*"B,@:6YC;'5D92!T
M:&4@96UA:6P@<V5R=F5R(&-L87-S"G)E<75I<F5?;VYC92`G4T]!4"]397)V
M97(O16UA:6Q?1V%T97=A>2YP:'`G.PH*(R!R96%D('-T9&EN"B1F:6X@/2!F
M;W!E;B@G<&AP.B\O<W1D:6XG+"=R8B<I.PII9B`H(21F:6XI(&5X:70H,"D[
M"@HD96UA:6P@/2`G)SL*=VAI;&4@*"%F96]F*"1F:6XI("8F("1D871A(#T@
M9G)E860H)&9I;BP@.#`Y-BDI('L*("`D96UA:6P@+CT@)&1A=&$["GT*"F9C
M;&]S92@D9FEN*3L*"B,@9&]I="$*)'-E<G9E<B`](&YE=R!33T%07U-E<G9E
M<E]%;6%I;%]'871E=V%Y*"D["B1S97)V97(M/G-E<G9I8V4H)&1A=&$L("=H
M='1P.B\O;&]C86QH;W-T+W-O87`O97AA;7!L92]S97)V97(N<&AP)RD["C\^
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O9&]C<R]33T%0+V5X86UP;&4O96UA:6Q?<&]P7V=A=&5W87DN<&AP````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#4P,#,`,3`U,34T,S,W,S8`,#(V,3,P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\O"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N
M(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U
M8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@
M("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN
M('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL
M86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@
M=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B
M=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E
M;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M($%U=&AO<G,Z(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@
M(%!O<G0@=&\@4$5!4B!A;F0@;6]R92`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@96UA:6Q?<&]P7V=A=&5W87DN<&AP
M+'8@,2XV(#(P,#4O,#,O,3`@,C,Z,38Z-#`@>75N;W-H($5X<"`D"B\O"@HO
M*B!I;F-L=61E('1H92!%;6%I;"!S97)V97(@8VQA<W,L('=H:6-H(&MN;W=S
M(&AO=R!T;PH@("!P87)S92!A('-T86YD87)D(&5M86EL(&%S(&$@<V]A<"!M
M97-S86=E("HO"@IR97%U:7)E7V]N8V4@)U-/05`O4V5R=F5R+T5M86EL7T=A
M=&5W87DN<&AP)SL*"B\J(&EN8VQU9&4@82!C;&%S<R!T;R!A8V-E<W,@4$]0
M,R`J+PH*<F5Q=6ER95]O;F-E("=.970O4$]0,RYP:'`G.PH*+RH@8W)E871E
M('1H92!33T%0(%-E<G9E<B!O8FIE8W0@*B\*"B1S97)V97(@/2!N97<@4T]!
M4%]397)V97)?16UA:6Q?1V%T97=A>2@G:'1T<#HO+VQO8V%L:&]S="]S;V%P
M7VEN=&5R;W`O<V5R=F5R7W)O=6YD,BYP:'`G*3L*"B\J('1E;&P@<V5R=F5R
M('1O('1R86YS;&%T92!T;R!C;&%S<V5S('=E('!R;W9I9&4@:68@<&]S<VEB
M;&4@*B\*)'-E<G9E<BT^7V%U=&]?=')A;G-L871I;VX@/2!T<G5E.PH*<F5Q
M=6ER95]O;F-E("=E>&%M<&QE7W-E<G9E<BYP:'`G.PH*)'-O87!C;&%S<R`]
M(&YE=R!33T%07T5X86UP;&5?4V5R=F5R*"D["B1S97)V97(M/F%D9$]B:F5C
M=$UA<"@D<V]A<&-L87-S+"=U<FXZ4T]!4%]%>&%M<&QE7U-E<G9E<B<I.PH*
M"B\J($-O;FYE8W0@=&\@82!03U`S('-E<G9E<B!A;F0@<F5A9"!T:&4@;65S
M<V%G97,@*B\*"B1P;W`S(#TF(&YE=R!.971?4$]0,R@I.PII9B`H)'!O<#,M
M/F-O;FYE8W0H)VQO8V%L:&]S="<L(#$Q,"DI('L*("`@(&EF("@D<&]P,RT^
M;&]G:6XH)W5S97)N86UE)RP@)W!A<W-W;W)D)RDI('L*("`@("`@("`D;&ES
M=&EN9R`]("1P;W`S+3YG971,:7-T:6YG*"D["@H)+RH@;F]W(&QO;W`@=&AR
M;W5G:"!E86-H(&UE<W-A9V4L(&%N9"!C86QL('1H92`*("`@("`@("`@("!3
M3T%0('-E<G9E<B!W:71H('1H870@;65S<V%G92`J+PH*("`@("`@("!F;W)E
M86-H("@D;&ES=&EN9R!A<R`D;7-G*2!["@H@("`@("`@("`@("`D96UA:6P@
M/2`D<&]P,RT^9V5T37-G*"1M<V=;)VUS9U]I9"==*3L*"B`@("`@("`@("`@
M("\J('1H:7,@:7,@=VAE<F4@=V4@86-T=6%L;'D@:&%N9&QE('1H92!33T%0
M"B`@("`@("`@("`@("`@(')E<W!O;G-E+B`@5&AE(%-/05`Z.E-E<G9E<CHZ
M16UA:6P@8VQA<W,@=V4*("`@("`@("`@("`@("`@87)E('5S:6YG('=I;&P@
M<V5N9"!T:&4@4T]!4"!R97-P;VYS92!T;R`*("`@("`@("`@("`@("`@=&AE
M('-E;F1E<B!V:6$@96UA:6PN("HO"@H@("`@("`@("`@("!I9B`H)&5M86EL
M*2`D<V5R=F5R+3YS97)V:6-E*"1E;6%I;"D["@H@("`@("`@("`@("`C)'!O
M<#,M/F1E;&5T94US9R@D;7-G6R=M<V=?:60G72D["B`@("`@("`@?0H@("`@
M?0H@("`@)'!O<#,M/F1I<V-O;FYE8W0H*3L*?0H_/@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA
M;7!L92]E;6%I;%]P;W!?<V5R=F5R+G!H<```````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#<T
M,0`Q,#4Q-30S,S<S-@`P,C8P,#4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@
M*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N
M(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES
M(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y3
M12P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT
M+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@
M86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@
M("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4VAA;F4@
M0V%R879E;R`\4VAA;F5`0V%R879E;RYC;VT^("`@4&]R="!T;R!014%2(&%N
M9"!M;W)E("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*
M+R\@)$ED.B!E;6%I;%]P;W!?<V5R=F5R+G!H<"QV(#$N-B`R,#`U+S`S+S$P
M(#(S.C$V.C0P('EU;F]S:"!%>'`@)`HO+PH*+RH@:6YC;'5D92!T:&4@16UA
M:6P@<V5R=F5R(&-L87-S+"!W:&EC:"!K;F]W<R!H;W<@=&\*("`@<&%R<V4@
M82!S=&%N9&%R9"!E;6%I;"!A<R!A('-O87`@;65S<V%G92`J+PH*<F5Q=6ER
M95]O;F-E("=33T%0+U-E<G9E<B]%;6%I;"YP:'`G.PH*+RH@:6YC;'5D92!A
M(&-L87-S('1O(&%C8V5S<R!03U`S("HO"@IR97%U:7)E7V]N8V4@)TYE="]0
M3U`S+G!H<"<["@HO*B!C<F5A=&4@=&AE(%-/05`@4V5R=F5R(&]B:F5C="`J
M+PH*)'-E<G9E<B`](&YE=R!33T%07U-E<G9E<E]%;6%I;#L*"B\J('1E;&P@
M<V5R=F5R('1O('1R86YS;&%T92!T;R!C;&%S<V5S('=E('!R;W9I9&4@:68@
M<&]S<VEB;&4@*B\*)'-E<G9E<BT^7V%U=&]?=')A;G-L871I;VX@/2!T<G5E
M.PH*<F5Q=6ER95]O;F-E("=E>&%M<&QE7W-E<G9E<BYP:'`G.PH*)'-O87!C
M;&%S<R`](&YE=R!33T%07T5X86UP;&5?4V5R=F5R*"D["B1S97)V97(M/F%D
M9$]B:F5C=$UA<"@D<V]A<&-L87-S+"=U<FXZ4T]!4%]%>&%M<&QE7U-E<G9E
M<B<I.PH*"B\J($-O;FYE8W0@=&\@82!03U`S('-E<G9E<B!A;F0@<F5A9"!T
M:&4@;65S<V%G97,@*B\*"B1P;W`S(#TF(&YE=R!.971?4$]0,R@I.PII9B`H
M)'!O<#,M/F-O;FYE8W0H)VQO8V%L:&]S="<L(#$Q,"DI('L*("`@(&EF("@D
M<&]P,RT^;&]G:6XH)W5S97)N86UE)RP@)W!A<W-W;W)D)RDI('L*("`@("`@
M("`D;&ES=&EN9R`]("1P;W`S+3YG971,:7-T:6YG*"D["@H)+RH@;F]W(&QO
M;W`@=&AR;W5G:"!E86-H(&UE<W-A9V4L(&%N9"!C86QL('1H92`*("`@("`@
M("`@("!33T%0('-E<G9E<B!W:71H('1H870@;65S<V%G92`J+PH*("`@("`@
M("!F;W)E86-H("@D;&ES=&EN9R!A<R`D;7-G*2!["@H@("`@("`@("`@("`D
M96UA:6P@/2`D<&]P,RT^9V5T37-G*"1M<V=;)VUS9U]I9"==*3L*"B`@("`@
M("`@("`@("\J('1H:7,@:7,@=VAE<F4@=V4@86-T=6%L;'D@:&%N9&QE('1H
M92!33T%0"B`@("`@("`@("`@("`@(')E<W!O;G-E+B`@5&AE(%-/05`Z.E-E
M<G9E<CHZ16UA:6P@8VQA<W,@=V4*("`@("`@("`@("`@("`@87)E('5S:6YG
M('=I;&P@<V5N9"!T:&4@4T]!4"!R97-P;VYS92!T;R`*("`@("`@("`@("`@
M("`@=&AE('-E;F1E<B!V:6$@96UA:6PN("HO"@H@("`@("`@("`@("!I9B`H
M)&5M86EL*2!["B`@("`@("`@("`@("`@("`D<V5R=F5R+3YC;&EE;G0H)&5M
M86EL*3L*"B`@("`@("`@("`@("`@("`D<&]P,RT^9&5L971E37-G*"1M<V=;
M)VUS9U]I9"==*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@
M("1P;W`S+3YD:7-C;VYN96-T*"D["GT*/SX*````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D
M;V-S+U-/05`O97AA;7!L92]E;6%I;%]S97)V97(N<&AP````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,S8U,``Q,#4Q-30S,S<S-@`P,C4Q,C4`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+R\*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C
M="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*
M+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE
M(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE
M(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@
M4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN
M(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A
M(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T
M:&]R<SH@4VAA;F4@0V%R879E;R`\4VAA;F5`0V%R879E;RYC;VT^("`@4&]R
M="!T;R!014%2(&%N9"!M;W)E("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\*+R\@)$ED.B!E;6%I;%]S97)V97(N<&AP+'8@,2XU(#(P
M,#4O,#,O,3`@,C,Z,38Z-#`@>75N;W-H($5X<"`D"B\O"@HO*@I4:&ES(')E
M861S(&$@;65S<V%G92!F<F]M('-T9&EN+"!A;F0@8V%L;',@=&AE('-O87`@
M<V5R=F5R(&1E9FEN960*"EEO=2!C86X@=7-E('1H:7,@9G)O;2!Q;6%I;"!B
M>2!C<F5A=&EN9R!A("YQ;6%I;"US;V%P=&5S="!F:6QE('=I=&@Z"B`@("!\
M("]U<W(O8FEN+W!H<"`O<&%T:"]T;R]E;6%I;%]S97)V97(N<&AP"BHO"@HC
M(&EN8VQU9&4@=&AE(&5M86EL('-E<G9E<B!C;&%S<PIR97%U:7)E7V]N8V4@
M)U-/05`O4V5R=F5R+T5M86EL+G!H<"<["@HD<V5R=F5R(#T@;F5W(%-/05!?
M4V5R=F5R7T5M86EL.PH*+RH@=&5L;"!S97)V97(@=&\@=')A;G-L871E('1O
M(&-L87-S97,@=V4@<')O=FED92!I9B!P;W-S:6)L92`J+PHD<V5R=F5R+3Y?
M875T;U]T<F%N<VQA=&EO;B`]('1R=64["@IR97%U:7)E7V]N8V4@)V5X86UP
M;&5?<V5R=F5R+G!H<"<["@HD<V]A<&-L87-S(#T@;F5W(%-/05!?17AA;7!L
M95]397)V97(H*3L*)'-E<G9E<BT^861D3V)J96-T36%P*"1S;V%P8VQA<W,L
M)W5R;CI33T%07T5X86UP;&5?4V5R=F5R)RD["@HC(')E860@<W1D:6X*)&9I
M;B`](&9O<&5N*"=P:'`Z+R]S=&1I;B<L)W)B)RD["FEF("@A)&9I;BD@97AI
M="@P*3L*"B1E;6%I;"`]("<G.PIW:&EL92`H(69E;V8H)&9I;BD@)B8@)&1A
M=&$@/2!F<F5A9"@D9FEN+"`X,#DV*2D@>PH@("1E;6%I;"`N/2`D9&%T83L*
M?0H*9F-L;W-E*"1F:6XI.PH*(R!D;VET(0HD<V5R=F5R+3YS97)V:6-E*"1E
M;6%I;"D["@H_/@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]3
M3T%0+V5X86UP;&4O97AA;7!L95]S97)V97(N<&AP````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,30R-34`,3`U,34T,S,W,S8`,#(U-#<T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\O"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P
M>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@
M=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@
M=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE
M($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R
M7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L
M:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E
M('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N
M(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z
M(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O"B\O("1)9#H@97AA;7!L95]S97)V97(N<&AP+'8@,2XU(#(P,#4O
M,#,O,3`@,C,Z,38Z-#`@>75N;W-H($5X<"`D"B\O"@HO+R!F:7)S="P@:6YC
M;'5D92!T:&4@4T]!4"]397)V97(@8VQA<W,*<F5Q=6ER95]O;F-E("=33T%0
M+U9A;'5E+G!H<"<["G)E<75I<F5?;VYC92`G4T]!4"]&875L="YP:'`G.PH*
M+R\@4T]!4%-T<G5C="!I<R!D969I;F5D(&EN('1H92!F;VQL;W=I;F<@9FEL
M90IR97%U:7)E7V]N8V4@)V5X86UP;&5?='EP97,N<&AP)SL*"B\O(&-R96%T
M92!A(&-L87-S(&9O<B!Y;W5R('-O87`@9G5N8W1I;VYS"F-L87-S(%-/05!?
M17AA;7!L95]397)V97(@>PH@("`@+RHJ"B`@("`@*B!4:&4@9&ES<&%C=&-H
M(&UA<"!D;V5S(&YO="!N965D('1O(&)E('5S960L(&)U="!A:61S"B`@("`@
M*B!T:&4@<V5R=F5R(&-L87-S(&EN(&MN;W=I;F<@=VAA="!P87)A;65T97)S
M(&%R92!U<V5D"B`@("`@*B!W:71H('1H92!F=6YC=&EO;G,N("!4:&ES(&ES
M('1H92!/3DQ9('=A>2!T;R!H879E"B`@("`@*B!M=6QT:7!L92!/550@<&%R
M86UE=&5R<RX@($EF('EO=2!U<V4@82!D:7-P871C:"!M87`L('EO=0H@("`@
M("H@35535"!A9&0@04Q,(&9U;F-T:6]N<R!Y;W4@=VES:"!T;R!A;&QO=R!B
M92!C86QL960N("!)9@H@("`@("H@>6]U(&1O(&YO="!U<V4@82!D:7-P871C
M:"!M87`L('1H96X@86YY('!U8FQI8R!F=6YC=&EO;@H@("`@("H@8V%N(&)E
M(&-A;&QE9"!F<F]M('-O87`@*&EN('!H<#0L('=E(&-O;G-I9&5R('1H:7,@
M=&\@8F4*("`@("`J(&%N>2!F=6YC=&EO;B!I;B!T:&4@8VQA<W,@=6YL97-S
M(&ET('-T87)T<R!W:71H('5N9&5R<V-O<F4L"B`@("`@*B!P:'`U('-U<'!O
M<G0@:7,@;F]T(&-O;7!L971E('EE="!I;B!T:&ES(')E9V%R9"DN("`*("`@
M("`J(&EF('EO=2!D;R!N;W0@9&5F:6YE(&EN+V]U="!P87)A;65T97)S+"!T
M:&4@9G5N8W1I;VX@8V%N(&)E"B`@("`@*B!C86QL960@=VET:"!P87)A;65T
M97)S+"!B=70@;F\@=F%L:61A=&EO;B!O;B!P87)A;65T97)S('=I;&P*("`@
M("`J(&]C8W5R92X*("`@("`J+PH@("`@=F%R("1?7V1I<W!A=&-H7VUA<"`]
M(&%R<F%Y*"D["@H@("`@9G5N8W1I;VX@4T]!4%]%>&%M<&QE7U-E<G9E<B@I
M('L*("`@("`@("`O*BH*("`@("`@("`J('=H96X@9V5N97)A=&EN9R!W<V1L
M(&9O<B!A('-E<G9E<BP@>6]U(&AA=F4@=&\@9&5F:6YE"B`@("`@("`@*B!A
M;GD@<W!E8VEA;"!C;VUP;&5X('1Y<&5S('1H870@>6]U('5S92`H:64@8VQA
M<W-E<RDN"B`@("`@("`@*B!U<VEN9R!A(&YA;65S<&%C92!I9"!B969O<F4@
M=&AE('1Y<&4@=VEL;"!C<F5A=&4@86X*("`@("`@("`J('AM;"!S8VAE;6$@
M=VET:"!T:&4@=&%R9V5T3F%M97-P86-E(&9O<B!T:&4@='EP90H@("`@("`@
M("H@;75L=&EP;&4@='EP97,@=VET:"!T:&4@<V%M92!N86UE<W!A8V4@=VEL
M;"!A<'!E87(*("`@("`@("`J(&EN('1H92!S86UE('-C:&5M82!S96-T:6]N
M+B`@='EP97,@=VET:"!D:69F97)E;G0*("`@("`@("`J(&YA;65S<&%C97,@
M=VEL;"!B92!I;B!S97!E<F%T92!S8VAE;6$@<V5C=&EO;G,N"B`@("`@("`@
M*B!T:&4@9F]L;&]W:6YG(%-/05!3=')U8W0@='EP961E9B!C;V]R97-P;VYD
M<R!T;R!T:&4*("`@("`@("`J(%-/05!3=')U8W0@8VQA<W,@86)O=F4N"B`@
M("`@("`@*B\*("`@("`@("`D=&AI<RT^7U]T>7!E9&5F6R=[:'1T<#HO+W-O
M87!I;G1E<F]P+F]R9R]X<V1]4T]!4%-T<G5C="==(#T@"B`@("`@("`@("`@
M("`@("`@("`@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=V87)3
M=')I;F<G(#T^("=S=')I;F<G+`H@("`@("`@("`@("`@("`@("`@("`@("`G
M=F%R26YT)R`]/B`G:6YT)RP@"B`@("`@("`@("`@("`@("`@("`@("`@("=V
M87)&;&]A="<@/3X@)V9L;V%T)PH@("`@("`@("`@("`@("`@("`@("`@("`@
M*3L*"B`@("`@("`@+R\@86X@86QI87-E9"!F=6YC=&EO;B!W:71H(&UU;'1I
M<&QE(&]U="!P87)A;65T97)S"@DD=&AI<RT^7U]D:7-P871C:%]M87!;)V5C
M:&]3=')U8W1!<U-I;7!L951Y<&5S)UT@/0H)"6%R<F%Y*"=I;B<@/3X@87)R
M87DH)VEN<'5T4W1R=6-T)R`]/B`G>VAT='`Z+R]S;V%P:6YT97)O<"YO<F<O
M>'-D?5-/05!3=')U8W0G*2P*"0D@("`@("`G;W5T)R`]/B!A<G)A>2@G;W5T
M<'5T4W1R:6YG)R`]/B`G<W1R:6YG)RP@)V]U='!U=$EN=&5G97(G(#T^("=I
M;G0G+"`G;W5T<'5T1FQO870G(#T^("=F;&]A="<I+`H)"2`@("`@("=A;&EA
M<R<@/3X@)VUY16-H;U-T<G5C=$%S4VEM<&QE5'EP97,G"@D)("`@("`@*3L*
M"21T:&ES+3Y?7V1I<W!A=&-H7VUA<%LG96-H;U-T<FEN9U-I;7!L92==(#T*
M"0EA<G)A>2@G:6XG(#T^(&%R<F%Y*"=I;G!U=%-T<FEN9U-I;7!L92<@/3X@
M)W-T<FEN9R<I+`H)"2`@("`@("=O=70G(#T^(&%R<F%Y*"=O=71P=713=')I
M;F=3:6UP;&4G(#T^("=S=')I;F<G*2P*"0D@("`@("`I.PH))'1H:7,M/E]?
M9&ES<&%T8VA?;6%P6R=E8VAO4W1R:6YG)UT@/0H)"6%R<F%Y*"=I;B<@/3X@
M87)R87DH)VEN<'5T4W1R:6YG)R`]/B`G<W1R:6YG)RDL"@D)("`@("`@)V]U
M="<@/3X@87)R87DH)V]U='!U=%-T<FEN9R<@/3X@)W-T<FEN9R<I+`H)"2`@
M("`@("D["@DD=&AI<RT^7U]D:7-P871C:%]M87!;)V1I=FED92==(#T*"0EA
M<G)A>2@G:6XG(#T^(&%R<F%Y*"=D:79I9&5N9"<@/3X@)VEN="<L("=D:79I
M<V]R)R`]/B`G:6YT)RDL"@D)("`@("`@)V]U="<@/3X@87)R87DH)V]U='!U
M=$9L;V%T)R`]/B`G9FQO870G*2P*"0D@("`@("`I.PH))'1H:7,M/E]?9&ES
M<&%T8VA?;6%P6R=E8VAO4W1R=6-T)UT@/0H)"6%R<F%Y*"=I;B<@/3X@87)R
M87DH)VEN<'5T4W1R=6-T)R`]/B`G>VAT='`Z+R]S;V%P:6YT97)O<"YO<F<O
M>'-D?5-/05!3=')U8W0G*2P*"0D@("`@("`G;W5T)R`]/B!A<G)A>2@G;W5T
M<'5T4W1R=6-T)R`]/B`G>VAT='`Z+R]S;V%P:6YT97)O<"YO<F<O>'-D?5-/
M05!3=')U8W0G*2P*"0D@("`@("`I.PH)"@DD=&AI<RT^7U]D:7-P871C:%]M
M87!;)V5C:&]-:6UE071T86-H;65N="==(#T@87)R87DH*3L*("`@('T*"B`@
M("`O*B!T:&ES('!R:79A=&4@9G5N8W1I;VX@:7,@8V%L;&5D(&]N(&)Y(%-/
M05!?4V5R=F5R('1O(&1E=&5R;6EN92!A;GD*("`@("`@("!S<&5C:6%L(&1I
M<W!A=&-H(&EN9F]R;6%T:6]N('1H870@;6EG:'0@8F4@;F5C97-S87)Y+B`@
M5&AI<RP@9F]R(&5X86UP;&4L"B`@("`@("`@8V%N(&)E('5S960@=&\@<V5T
M('5P(&$@9&ES<&%T8V@@;6%P(&9O<B!F=6YC=&EO;G,@=&AA="!R971U<FX@
M;75L=&EP;&4*("`@("`@("!/550@<&%R86UE=&5R<R`J+PH@("`@9G5N8W1I
M;VX@7U]D:7-P871C:"@D;65T:&]D;F%M92D@>PH@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7U]D:7-P871C:%]M87!;)&UE=&AO9&YA;65=*2D*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?7V1I<W!A=&-H7VUA<%LD;65T:&]D;F%M
M95T["B`@("`@("`@<F5T=7)N($Y53$P["B`@("!]"@H@("`@+R\@82!S:6UP
M;&4@96-H;U-T<FEN9R!F=6YC=&EO;@H@("`@9G5N8W1I;VX@96-H;U-T<FEN
M9U-I;7!L92@D:6YP=713=')I;F<I"B`@("!["@ER971U<FX@)&EN<'5T4W1R
M:6YG.PH@("`@?0H@("`@"B`@("`O+R!A;B!E>'!L:6-I="!E8VAO<W1R:6YG
M(&9U;F-T:6]N"B`@("!F=6YC=&EO;B!E8VAO4W1R:6YG*"1I;G!U=%-T<FEN
M9RD*("`@('L*"7)E='5R;B!N97<@4T]!4%]686QU92@G;W5T<'5T4W1R:6YG
M)RPG<W1R:6YG)RPD:6YP=713=')I;F<I.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&1I=FED92@D9&EV:61E;F0L("1D:79I<V]R*0H@("`@>PH@("`@("`@("\O
M('1H92!S;V%P('-E<G9E<B!W;W5L9"!N;W)M86QL>2!C871C:"!E<G)O<G,@
M;&EK92!T:&ES"B`@("`@("`@+R\@86YD(')E='5R;B!A(&9A=6QT+"!B=70@
M=&AI<R!I<R!H;W<@>6]U(&1O(&ET('EO=7)S96QF+@H@("`@("`@(&EF("@D
M9&EV:7-O<B`]/2`P*0H@("`@("`@("`@("!R971U<FX@;F5W(%-/05!?1F%U
M;'0H)UEO=2!C86YN;W0@9&EV:61E(&)Y('IE<F\G+"`G0VQI96YT)RD["B`@
M("`@("`@96QS90H@("`@("`@("`@("!R971U<FX@)&1I=FED96YD("\@)&1I
M=FES;W(["B`@("!]"@H@("`@9G5N8W1I;VX@96-H;U-T<G5C="@D:6YP=713
M=')U8W0I"B`@("!["B`@("`@("`@<F5T=7)N("1I;G!U=%-T<G5C="T^7U]T
M;U]S;V%P*"=O=71P=713=')U8W0G*3L*"2-R971U<FX@;F5W(%-/05!?5F%L
M=64H)V]U='!U=%-T<G5C="<L)WMH='1P.B\O<V]A<&EN=&5R;W`N;W)G+WAS
M9'U33T%04W1R=6-T)RPD:6YP=713=')U8W0I.PH@("`@?0H@("`@"B`@("`O
M*BH*("`@("`J(&5C:&]3=')U8W1!<U-I;7!L951Y<&5S"B`@("`@*B!T86ME
M<R!A(%-/05!3=')U8W0@87,@:6YP=70L(&%N9"!R971U<FYS(&5A8V@@;V8@
M:71S(&5L96UE;G1S"B`@("`@*B!A<R!/550@<&%R86UE=&5R<PH@("`@("H*
M("`@("`J('1H:7,@9G5N8W1I;VX@:7,@86QS;R!A;&EA<V5D('-O('EO=2!H
M879E('1O(&-A;&P@:70@=VET:`H@("`@("H@96-H;U-T<G5C=$%S4VEM<&QE
M5'EP97,*("`@("`J"B`@("`@*B!33T%04W1R=6-T(&ES(&1E9FEN960@87,Z
M"B`@("`@*@H@("`@("H@<W1R=6-T(%-/05!3=')U8W0Z"B`@("`@*B`@("!S
M=')I;F<@=F%R4W1R:6YG"B`@("`@*B`@("!I;G1E9V5R('9A<DEN=`H@("`@
M("H@("`@9FQO870@=F%R1FQO870*("`@("`J"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&UY16-H;U-T<G5C=$%S4VEM<&QE5'EP97,H)'-T<G5C="D*("`@('L*
M"2,@8V]N=F5R="!A(%-/05!3=')U8W0@=&\@86X@87)R87D*"7)E='5R;B!A
M<G)A>2@*"2`@("!N97<@4T]!4%]686QU92@G;W5T<'5T4W1R:6YG)RPG<W1R
M:6YG)RPD<W1R=6-T+3YV87)3=')I;F<I+`H)("`@(&YE=R!33T%07U9A;'5E
M*"=O=71P=71);G1E9V5R)RPG:6YT)RPD<W1R=6-T+3YV87));G0I+`H)("`@
M(&YE=R!33T%07U9A;'5E*"=O=71P=71&;&]A="<L)V9L;V%T)RPD<W1R=6-T
M+3YV87)&;&]A="D*"2`@("`I.PH@("`@?0H@("`@"B`@("!F=6YC=&EO;B!E
M8VAO36EM94%T=&%C:&UE;G0H)'-T=69F*0H@("`@>PH@("`@("`@(')E='5R
M;B!N97<@4T]!4%]!='1A8VAM96YT*"=R971U<FXG+"=A<'!L:6-A=&EO;B]O
M8W1E="US=')E86TG+$Y53$PL)'-T=69F*3L*("`@('T@("`@"GT*"C\^````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE+V5X86UP;&5?='EP97,N<&AP````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R-C,W`#$P-3$U-#,S-S,V`#`R-3,S,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M+RH**B!T:&ES(&ES(&$@9&%T82!T>7!E('1H870@:7,@=7-E9"!I;B!33T%0
M($EN=&5R;W`@=&5S=&EN9RP@8G5T(&ES"BH@:&5R92!A<R!A;B!E>&%M<&QE
M(&]F('5S:6YG(&-O;7!L97@@='EP97,N("!7:&5N('1H92!C;&%S<R!I<PHJ
M(&1E<V5R:6%L:7IE9"!F<F]M(&$@4T]!4"!M97-S86=E+"!I="=S(&-O;G-T
M<G5C=&]R($E3($Y/5"!#04Q,140A"BH@4V\@>6]U<B!T>7!E(&-L87-S97,@
M;F5E9"!T;R!B96AA=F4@:6X@82!W87D@=&AA="!W:6QL('=O<FL**B!W:71H
M('1H870N"BH**B!3;VUE('1Y<&5S(&UA>2!N965D(&UO<F4@97AP;&EC:70@
M<V5R:6%L:7IA=&EO;B!F;W(@4T]!4"X@(%1H90HJ(%]?=&]?<V]A<"!F=6YC
M=&EO;B!A;&QO=W,@>6]U('1O(&)E('9E<GD@97AP;&EC:70@:6X@8G5I;&1I
M;F<@=&AE"BH@4T]!4%]686QU92!S=')U8W1U<F5S+B`@5&AE('-O87`@;&EB
M<F%R>2!D;V5S(&YO="!C86QL('1H:7,@9&ER96-T;'DL"BH@>6]U('=O=6QD
M(&-A;&P@:70@9G)O;2!Y;W5R('-O87`@<V5R=F5R(&-L87-S+"!E8VAO4W1R
M=6-T(&EN('1H92!S97)V97(**B!C;&%S<R!I<R!A;B!E>&%M<&QE(&]F(&1O
M:6YG('1H:7,N"BHO"F-L87-S(%-/05!3=')U8W0@>PH@("`@=F%R("1V87)3
M=')I;F<["B`@("!V87(@)'9A<DEN=#L*("`@('9A<B`D=F%R1FQO870["B`@
M("!F=6YC=&EO;B!33T%04W1R=6-T*"1S/4Y53$PL("1I/4Y53$PL("1F/4Y5
M3$PI('L*("`@("`@("`D=&AI<RT^=F%R4W1R:6YG(#T@)',["B`@("`@("`@
M)'1H:7,M/G9A<DEN="`]("1I.PH@("`@("`@("1T:&ES+3YV87)&;&]A="`]
M("1F.PH@("`@?0H@("`@"B`@("!F=6YC=&EO;B`F7U]T;U]S;V%P*"1N86UE
M(#T@)VEN<'5T4W1R=6-T)RP@)&AE861E<CUF86QS92P@)&UU<W15;F1E<G-T
M86YD/3`L("1A8W1O<CTG:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O<V]A
M<"]A8W1O<B]N97AT)RD*("`@('L*("`@("`@("`D:6YN97);72`])B!N97<@
M4T]!4%]686QU92@G=F%R4W1R:6YG)RPG<W1R:6YG)RPD=&AI<RT^=F%R4W1R
M:6YG*3L*("`@("`@("`D:6YN97);72`])B!N97<@4T]!4%]686QU92@G=F%R
M26YT)RPG:6YT)RPD=&AI<RT^=F%R26YT*3L*("`@("`@("`D:6YN97);72`]
M)B!N97<@4T]!4%]686QU92@G=F%R1FQO870G+"=F;&]A="<L)'1H:7,M/G9A
M<D9L;V%T*3L*("`@("`@("!I9B`H)&AE861E<BD@>PH@("`@("`@("`@("!R
M971U<FX@;F5W(%-/05!?2&5A9&5R*"1N86UE+"=[:'1T<#HO+W-O87!I;G1E
M<F]P+F]R9R]X<V1]4T]!4%-T<G5C="<L)&EN;F5R+"1M=7-T56YD97)S=&%N
M9"PD86-T;W(I.PH@("`@("`@('T*("`@("`@("!R971U<FX@;F5W(%-/05!?
M5F%L=64H)&YA;64L)WMH='1P.B\O<V]A<&EN=&5R;W`N;W)G+WAS9'U33T%0
M4W1R=6-T)RPD:6YN97(I.PH@("`@("`@(`H@("`@?0I]"@H_/@``````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X86UP
M;&4O<V5R=F5R+G!H<```````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,W-#4`
M,3`U,34T,S,W,S8`,#(S-S8S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC
M*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R
M+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B
M=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L
M(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N
M9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@
M("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U
M(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%-H86YE($-A
M<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O
M("1)9#H@<V5R=F5R+G!H<"QV(#$N,3`@,C`P-2\P,R\Q,"`R,SHQ-CHT,"!Y
M=6YO<V@@17AP("0*+R\*"B\O(&9I<G-T+"!I;F-L=61E('1H92!33T%0+U-E
M<G9E<B!C;&%S<PIR97%U:7)E7V]N8V4@)U-/05`O4V5R=F5R+G!H<"<["@HD
M<V5R=F5R(#T@;F5W(%-/05!?4V5R=F5R.PHO*B!T96QL('-E<G9E<B!T;R!T
M<F%N<VQA=&4@=&\@8VQA<W-E<R!W92!P<F]V:61E(&EF('!O<W-I8FQE("HO
M"B1S97)V97(M/E]A=71O7W1R86YS;&%T:6]N(#T@=')U93L*"G)E<75I<F5?
M;VYC92`G97AA;7!L95]S97)V97(N<&AP)SL*"B1S;V%P8VQA<W,@/2!N97<@
M4T]!4%]%>&%M<&QE7U-E<G9E<B@I.PHD<V5R=F5R+3YA9&1/8FIE8W1-87`H
M)'-O87!C;&%S<RPG=7)N.E-/05!?17AA;7!L95]397)V97(G*3L*"FEF("AI
M<W-E="@D7U-%4E9%4ELG4D5154535%]-151(3T0G72D@)B8*("`@("1?4T52
M5D526R=215%515-47TU%5$A/1"==/3TG4$]35"<I('L*("`@("1S97)V97(M
M/G-E<G9I8V4H)$A45%!?4D%77U!/4U1?1$%402D["GT@96QS92!["B`@("!R
M97%U:7)E7V]N8V4@)U-/05`O1&ES8V\N<&AP)SL*("`@("1D:7-C;R`](&YE
M=R!33T%07T1)4T-/7U-E<G9E<B@D<V5R=F5R+"=397)V97)%>&%M<&QE)RD[
M"B`@("!H96%D97(H(D-O;G1E;G0M='EP93H@=&5X="]X;6PB*3L*("`@(&EF
M("AI<W-E="@D7U-%4E9%4ELG455%4EE?4U1224Y')UTI("8F"B`@("`@("!S
M=')C87-E8VUP*"1?4T525D526R=1545265]35%))3D<G72PG=W-D;"<I/3TP
M*2!["B`@("`@("`@96-H;R`D9&ES8V\M/F=E=%=31$PH*3L*("`@('T@96QS
M92!["B`@("`@("`@96-H;R`D9&ES8V\M/F=E=$1)4T-/*"D["B`@("!]"B`@
M("!E>&ET.PI]"C\^````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE+W-E
M<G9E<C(N<&AP````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U,#4S`#$P-3$U
M-#,S-S,V`#`R-#`S-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY
M-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O
M9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE
M9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@
M:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E
M('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\
M"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O
M<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!3:&%N92!#87)A=F5O
M(#Q3:&%N94!#87)A=F5O+F-O;3X@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z
M('-E<G9E<C(N<&AP+'8@,2XS(#(P,#4O,#,O,3`@,C,Z,38Z-#`@>75N;W-H
M($5X<"`D"B\O"@HO+R!F:7)S="P@:6YC;'5D92!T:&4@4T]!4"]397)V97(@
M8VQA<W,*<F5Q=6ER95]O;F-E("=33T%0+U-E<G9E<BYP:'`G.PH*)'-E<G9E
M<B`](&YE=R!33T%07U-E<G9E<CL*+RH@=&5L;"!S97)V97(@=&\@=')A;G-L
M871E('1O(&-L87-S97,@=V4@<')O=FED92!I9B!P;W-S:6)L92`J+PHD<V5R
M=F5R+3Y?875T;U]T<F%N<VQA=&EO;B`]('1R=64["@HO*B!4:&ES(&ES(&$@
M<VEM<&QE(&5X86UP;&4@;V8@:6UP;&5M96YT:6YG(&$@8W5S=&]M"B`@(&-A
M;&P@:&%N9&QE<BX@($EF('EO=2!D;R!T:&ES+"!T:&4@<V]A<"!S97)V97(@
M=VEL;"!I9VYO<F4*("`@;V)J96-T<R!O<B!F=6YC=&EO;G,@861D960@=&\@
M:70L(&%N9"!W:6QL(&-A;&P@>6]U<B!H86YD;&5R"B`@(&9O<B`J*D%,3"HJ
M('-O87`@8V%L;',@=&AE('-E<G9E<B!R96-E:79E<RP@=V5T:&5R('1H92!C
M86QL"B`@(&ES(&1E9FEN960@:6X@>6]U<B!74T1,(&]R(&YO="X@(%1H92!H
M86YD;&5R(')E8V5I=F5S('1W;PH@("!A<F=U;65N=',L('1H92!M971H;V0@
M;F%M92!B96EN9R!C86QL960L(&%N9"!T:&4@87)G=6UE;G1S"B`@('-E;G0@
M9F]R('1H870@8V%L;"X**B\*9G5N8W1I;VX@;7E#86QL2&%N9&QE<B@D;65T
M:&]D;F%M92P@)&%R9W,I"GL*("`@(&=L;V)A;"`D<V]A<&-L87-S.PH@("`@
M<F5T=7)N($!C86QL7W5S97)?9G5N8U]A<G)A>2AA<G)A>2@D<V]A<&-L87-S
M+"`D;65T:&]D;F%M92DL)&%R9W,I.PI]"B1S97)V97(M/G-E=$-A;&Q(86YD
M;&5R*"=M>4-A;&Q(86YD;&5R)RQF86QS92D["@IR97%U:7)E7V]N8V4@)V5X
M86UP;&5?<V5R=F5R+G!H<"<["@HD<V]A<&-L87-S(#T@;F5W(%-/05!?17AA
M;7!L95]397)V97(H*3L*)'-E<G9E<BT^861D3V)J96-T36%P*"1S;V%P8VQA
M<W,L)W5R;CI33T%07T5X86UP;&5?4V5R=F5R)RD["@II9B`H:7-S970H)%]3
M15)615);)U)%455%4U1?34542$]$)UTI("8F"B`@("`D7U-%4E9%4ELG4D51
M54535%]-151(3T0G73T])U!/4U0G*2!["B`@("`D<V5R=F5R+3YS97)V:6-E
M*"1(5%107U)!5U]03U-47T1!5$$I.PI](&5L<V4@>PH@("`@<F5Q=6ER95]O
M;F-E("=33T%0+T1I<V-O+G!H<"<["B`@("`D9&ES8V\@/2!N97<@4T]!4%]$
M25-#3U]397)V97(H)'-E<G9E<BPG4V5R=F5R17AA;7!L92<I.PH@("`@:&5A
M9&5R*")#;VYT96YT+71Y<&4Z('1E>'0O>&UL(BD["B`@("!I9B`H:7-S970H
M)%]315)615);)U%515)97U-44DE.1R==*2`F)@H@("`@("`@<W1R8V%S96-M
M<"@D7U-%4E9%4ELG455%4EE?4U1224Y')UTL)W=S9&PG*3T],"D@>PH@("`@
M("`@(&5C:&\@)&1I<V-O+3YG97174T1,*"D["B`@("!](&5L<V4@>PH@("`@
M("`@(&5C:&\@)&1I<V-O+3YG971$25-#3R@I.PH@("`@?0H@("`@97AI=#L*
M?0H_/@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&]C<R]33T%0+V5X86UP;&4O<VUT<"YP:'``````````````
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#,R-S,`,3`U,34T,S,W,S8`,#(S-#,T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_"B\O
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S
M:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U
M<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@
M("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E
M(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V
M86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@
M;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\
M(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E
M('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN
M970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\($%U=&AO<G,Z(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M
M/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@<VUT<"YP:'`L=B`Q+C4@,C`P
M-2\P,R\Q,"`R,SHQ-CHT,"!Y=6YO<V@@17AP("0*+R\*+R\@:6YC;'5D92!S
M;V%P(&-L:65N="!C;&%S<PII;F-L=61E*")33T%0+T-L:65N="YP:'`B*3L*
M"B1S;V%P8VQI96YT(#T@;F5W(%-/05!?0VQI96YT*")M86EL=&\Z=7-E<D!D
M;VUA:6XN8V]M(BD["B1O<'1I;VYS(#T@87)R87DH)VYA;65S<&%C92<]/B=H
M='1P.B\O<V]A<&EN=&5R;W`N;W)G+R<L)V9R;VTG/3XG=7-E<D!D;VUA:6XN
M8V]M)RPG:&]S="<]/B=L;V-A;&AO<W0G*3L*)')E='5R;B`]("1S;V%P8VQI
M96YT+3YC86QL*")E8VAO4W1R:6YG(BQA<G)A>2@B:6YP=713=')I;F<B/3XB
M=&AI<R!I<R!A('1E<W0B*2P@)&]P=&EO;G,I.PHD<F5T=7)N(#T@)'-O87!C
M;&EE;G0M/F-A;&PH(F5C:&]3=')I;F=!<G)A>2(L87)R87DH)VEN<'5T4W1R
M:6YG07)R87DG(#T^(&%R<F%Y*"=G;V]D)RPG8F%D)RPG=6=L>2<I*2P@)&]P
M=&EO;G,I.PHO+R!D;VXG="!E>'!E8W0@;75C:"!O9B!A(')E<W5L="$*<')I
M;G1?<B@D<F5T=7)N*3L*<')I;G0@(CQB<CY<;B(N)'-O87!C;&EE;G0M/G=I
M<F4["C\^"@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+V1O8W,O4T]!4"]E>&%M<&QE+W-T;V-K<75O=&4N<&AP````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`T-#$R`#$P-3$U-#,S-S,V`#`R-#8T-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\:'1M;#X\8F]D
M>3X*/#\*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@
M4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L
M:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES
M('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\
M"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E
M(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@
M("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@075T:&]R<SH@4VAA;F4@0V%R879E;R`\4VAA;F5`0V%R
M879E;RYC;VT^("`@4&]R="!T;R!014%2(&%N9"!M;W)E("`@?`HO+R!\($%U
M=&AO<G,Z($1I971R:6-H($%Y86QA(#QD:65T<FEC:$!G86YX-"YC;VT^($]R
M:6=I;F%L($%U=&AO<B`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O"B\O("1)9#H@<W1O8VMQ=6]T92YP:'`L=B`Q+C<@,C`P
M-2\P,R\Q,"`R,SHQ-CHT,"!Y=6YO<V@@17AP("0*+R\*+R\@:6YC;'5D92!S
M;V%P(&-L:65N="!C;&%S<PII;F-L=61E*")33T%0+T-L:65N="YP:'`B*3L*
M"G!R:6YT("(\8G(^7&X\<W1R;VYG/G=S9&PZ/"]S=')O;F<^(CL*)'=S9&P@
M/2!N97<@4T]!4%]74T1,*")H='1P.B\O<V5R=FEC97,N>&UE=&AO9',N;F5T
M+W-O87`O=7)N.GAM971H;V1S+61E;&%Y960M<75O=&5S+G=S9&PB*3L*)'-O
M87!C;&EE;G0@/2`D=W-D;"T^9V5T4')O>'DH*3L*<')I;G1?<B@D<V]A<&-L
M:65N="T^9V5T475O=&4H(FEB;2(I*3L*<')I;G0@(EQN7&XB.PH*:68@*&5X
M=&5N<VEO;E]L;V%D960H)V]V97)L;V%D)RDI('L*"7!R:6YT(")<;CQB<CX\
M<W1R;VYG/F]V97)L;V%D960Z/"]S=')O;F<^(CL*"21R970@/2`D<V]A<&-L
M:65N="T^9V5T475O=&4H(FEB;2(I.PH)<')I;G1?<B@D<F5T*3L*"7!R:6YT
M(")<;EQN(CL*?0IU;G-E="@D<V]A<&-L:65N="D["@IP<FEN="`B7&X\8G(^
M/'-T<F]N9SYN;VX@=W-D;#H\+W-T<F]N9SXB.PHD<V]A<&-L:65N="`](&YE
M=R!33T%07T-L:65N="@B:'1T<#HO+W-E<G9I8V5S+GAM971H;V1S+FYE=#HX
M,"]S;V%P(BD["B1N86UE<W!A8V4@/2`B=7)N.GAM971H;V1S+61E;&%Y960M
M<75O=&5S(CL*+RHJ"B`J('-O;64@<V]A<"!S97)V97)S(')E<75I<F4@82!3
M;V%P86-T:6]N(&AT='`@:&5A9&5R+B`@4$5!4CHZ4T]!4"!D;V5S"B`J(&YO
M="!U<V4@=&AE;2!I;B!A;GD@=V%Y+"!O=&AE<B!T;R!S96YD('1H96T@:68@
M>6]U('-U<'!L>2!T:&5M+@H@*B!S;V%P86-T:6]N(&ES(&1E<')E8V%T960@
M:6X@;&%T97(@4T]!4"!V97)S:6]N<RX*("HO"B1S;V%P86-T:6]N(#T@(G5R
M;CIX;65T:&]D<RUD96QA>65D+7%U;W1E<R-G9711=6]T92(["B1R970@/2`D
M<V]A<&-L:65N="T^8V%L;"@B9V5T475O=&4B+&%R<F%Y*")S>6UB;VPB/3XB
M:6)M(BDL)&YA;65S<&%C92PD<V]A<&%C=&EO;BD["G!R:6YT7W(H)')E="D[
M"G!R:6YT(")<;EQN(CL*=6YS970H)'-O87!C;&EE;G0I.PH*/SX*/"]H=&UL
M/CPO8F]D>3X*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE+W1C<%]C;&EE;G0N
M<&AP`````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-#`P`#$P-3$U-#,S-S,V`#`R
M-#4V-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H
M92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0
M(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H
M:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@
M('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T
M;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I
M871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!3:&%N92!(86YN82`\:6]R9'E?871?
M:6]R9'E?9&]T7V-O;3X@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z('1C<%]C;&EE
M;G0N<&AP+'8@,2XS(#(P,#4O,#,O,3`@,C,Z,38Z-#`@>75N;W-H($5X<"`D
M"B\O"@IR97%U:7)E7V]N8V4H)U-/05`O0VQI96YT+G!H<"<I.PH*(R!C;&EE
M;G0*)'-O87!C;&EE;G0@/2!N97<@4T]!4%]#;&EE;G0H(G1C<#HO+S$R-RXP
M+C`N,3HX,B(I.PH*(R!N86UE<W!A8V4*)&]P=&EO;G,@/2!A<G)A>2@G;F%M
M97-P86-E)R`]/B`G=7)N.E-/05!?17AA;7!L95]397)V97(G+"`G=')A8V4G
M(#T^(#$I.PH*(R!O;F4*)'!A<F%M<R`](&%R<F%Y*")S=')I;F<B(#T^(")T
M:&ES(&ES('-T<FEN9R`Q(BD["B1R970Q(#T@)'-O87!C;&EE;G0M/F-A;&PH
M(F5C:&]3=')I;F<B+"`D<&%R86US+"`D;W!T:6]N<RD["B,@96-H;R`B5TE2
M13H@7&XB+B1S;V%P8VQI96YT+3Y?7V=E=%]W:7)E*"D["G!R:6YT7W(H)')E
M=#$I.PIE8VAO("(\8G(@+SY<;B(["@HC('1W;PHD<&%R86US(#T@87)R87DH
M(G-T<FEN9R(@/3X@(G1H:7,@:7,@<W1R:6YG(#(B*3L*)')E=#(@/2`D<V]A
M<&-L:65N="T^8V%L;"@B96-H;U-T<FEN9R(L("1P87)A;7,L("1O<'1I;VYS
M*3L*(R!E8VAO(")725)%.B!<;B(N)'-O87!C;&EE;G0M/E]?9V5T7W=I<F4H
M*3L*<')I;G1?<B@D<F5T,BD["F5C:&\@(CQB<B`O/EQN(CL*"C\^````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]T8W!?9&%E;6]N+G!L````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S$U-P`Q,#4Q-30S,S<S-@`P,C0T,#<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````(R$O
M=7-R+V)I;B]P97)L("UW"G5S92!S=')I8W0["@H]:&5A9#$@4VEM<&QE(%-/
M05`@5$-0(%-E<G9E<@H*("`@(%-I;7!L92!33T%0(%1#4"!397)V97(@=VET
M:"!T97-T(&-L87-S("AJ=7-T('1O(&-H96-K('1H:6YG<R!A<F4@=V]R:VEN
M9RD*"B`@("!"969O<F4@>6]U(')U;B!T:&ES('1E<W0@<V5R=F5R('EO=2!W
M:6QL(&YE960@<V]M92!P97)L(&-L87-S97,L(&YA;65L>3H*("`@("`@("!3
M3T%0.CI,:71E"B`@("`@("`@2&]O:SHZ3&5X5W)A<"`H:68@>6]U('=A;G0@
M=&\@<V5E('-O;64@9&5B=6=G:6YG*0H*("`@("`@("!&;&5E(&]F9B!T;R!T
M:&4@0U!!3B!I9B!Y;W4@;F5E9"!T:&5M(#HI"@H@("`@5&\@<G5N('1Y<&4@
M)W!E<FP@/&9I;&5N86UE/B<@86YD(&EF('EO=2!D;VYT(&=E="!A;GD@97)R
M;W)S+"!I="=S('1I;64*("`@('1O(&=O('=R:71E('-O;64@8V]D92!T;R!C
M;VYN96-T+@H]8W5T"@IU<V4@4T]!4#HZ5')A;G-P;W)T.CI40U`@<7<H=')A
M8V4I.PIU<V4@1&%T83HZ1'5M<&5R.PH*"B,C(R,C(R,C(R,C(R,*(R,@:68@
M>6]U('=A;G0@=&\@<V5E(&EN8V]M:6YG+V]U=&=O:6YG(')A=R!X;6P*(R,@
M=6YC;VUM96YT('1H92!F;VQL;W=I;F<N"@HC=7-E($AO;VLZ.DQE>%=R87`[
M"B-W<F%P("I)3SHZ4V5S<VEO;D1A=&$Z.G)E860L('!O<W0@/3X@7"9S:&]W
M7W)E860["B-W<F%P("I)3SHZ4V5S<VEO;D1A=&$Z.G=R:71E+"!P;W-T(#T^
M(%PF<VAO=U]W<FET93L*"B,C"B,C(R,C(R,C(R,C(R,*"@IM>2`D9&%E;6]N
M(#T@4T]!4#HZ5')A;G-P;W)T.CI40U`Z.E-E<G9E<BT^;F5W*`H@("`@3&]C
M86Q!9&1R(#T^("<Q,C<N,"XP+C$G+`H@("`@3&]C86Q0;W)T(#T^("<X,B<L
M"B`@("!,:7-T96X@("`@/3X@-2P*("`@(%)E=7-E("`@("`]/B`Q"BD["@HC
M(&1I<W!A=&-H"B1D865M;VXM/F1I<W!A=&-H7W1O*"=33T%07T5X86UP;&5?
M4V5R=F5R)RD["B1D865M;VXM/FAA;F1L93L*"B,C(R,C(R,C(R,C(R,*(R,@
M8V%L;&)A8VL@9G5N8W1I;VYS(&9O<B!(;V]K.CI,97A7<F%P.PHC(PH*(R!S
M:&]W(&EN8V]M:6YG('AM;`IS=6(@<VAO=U]R96%D('L*("`@('!R:6YT("0O
M+"<C(R!R96%D(",C)RPD+SL*("`@('!R:6YT($1U;7!E<B@D7ULP72D["GT*
M"B,@<VAO=R!O=71G;VEN9R!X;6P*<W5B('-H;W=?=W)I=&4@>PH@("`@<')I
M;G0@)"\L)R,C('=R:71E(",C)RPD+SL*("`@('!R:6YT($1U;7!E<B@D7ULP
M72D["GT*(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*"@H*
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*(R!33T%07T5X
M86UP;&5?4V5R=F5R"B,@4VEM<&QE('1E<W0@8VQA<W,L(&UE=&AO9"!T97-T
M(')E='5R;G,@9&]U8FQE('=H870@>6]U('-E;F0@=&\@:70L('1H871S(&%L
M;"$*(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*<&%C:V%G
M92!33T%07T5X86UP;&5?4V5R=F5R.PH*<W5B(&5C:&]3=')I;F<@>PH@("`@
M<F5T=7)N("1?6S%=('@@,CL*?0H*,3L*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O9&]C<R]33T%0+V5X86UP;&4O=&-P7W-E<G9E<BYP:'``````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#,Q,C$`,3`U,34T,S,W,S8`,#(T-C$U`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\O
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S
M:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U
M<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@
M("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E
M(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V
M86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@
M;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\
M(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E
M('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN
M970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\($%U=&AO<G,Z(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M
M/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@=&-P7W-E<G9E<BYP:'`L=B`Q
M+C0@,C`P-2\P,R\Q,"`R,SHQ-CHT,"!Y=6YO<V@@17AP("0*+R\*"B\O(&9I
M<G-T+"!I;F-L=61E('1H92!33T%0+U-E<G9E<B!C;&%S<PIR97%U:7)E7V]N
M8V4@)U-/05`O4V5R=F5R+U1#4"YP:'`G.PIS971?=&EM95]L:6UI="@P*3L*
M"B1S97)V97(@/2!N97<@4T]!4%]397)V97)?5$-0*"(Q,C<N,"XP+C$B+#@R
M*3L*+RH@=&5L;"!S97)V97(@=&\@=')A;G-L871E('1O(&-L87-S97,@=V4@
M<')O=FED92!I9B!P;W-S:6)L92`J+PHD<V5R=F5R+3Y?875T;U]T<F%N<VQA
M=&EO;B`]('1R=64["@IR97%U:7)E7V]N8V4@)V5X86UP;&5?<V5R=F5R+G!H
M<"<["@HD<V]A<&-L87-S(#T@;F5W(%-/05!?17AA;7!L95]397)V97(H*3L*
M)'-E<G9E<BT^861D3V)J96-T36%P*"1S;V%P8VQA<W,L)W5R;CI33T%07T5X
M86UP;&5?4V5R=F5R)RD["B1S97)V97(M/G)U;B@I.PH_/@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+V1O8W,O4T]!4"]E>&%M<&QE+W=S9&Q?8VQI96YT+G!H<```````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`V-#8T`#$P-3$U-#,S-S,V`#`R-#<V-0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO+PHO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J
M96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@
M?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T
M:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B
M;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H
M92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A
M:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD
M(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O
M('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!
M=71H;W)S.B!3:&%N92!#87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+PHO+R`D260Z('=S9&Q?8VQI96YT+G!H<"QV(#$N,R`R
M,#`U+S`S+S$P(#(S.C$V.C0P('EU;F]S:"!%>'`@)`HO+PII;F-L=61E*")3
M3T%0+T-L:65N="YP:'`B*3L*"B\J*@H@*B!T:&ES(&-L:65N="!R=6YS(&%G
M86EN<W0@=&AE(&5X86UP;&4@<V5R=F5R(&EN(%-/05`O97AA;7!L92]S97)V
M97(N<&AP"B`J(&ET(&1O97,@;F]T('5S92!74T1,('1O(')U;B!T:&5S92!R
M97%U97-T<RP@8G5T('1H870@8V%N(&)E(&-H86YG960@96%S:6QY(&)Y('-I
M;7!L>0H@*B!A9&1I;F<@)S]W<V1L)R!T;R!T:&4@96YD(&]F('1H92!U<FPN
M"B`J+PHD=W-D;"`](&YE=R!33T%07U=31$PH(FAT='`Z+R]L;V-A;&AO<W0O
M4T]!4"]E>&%M<&QE+W-E<G9E<BYP:'`_=W-D;"(I.PHD<V]A<&-L:65N="`]
M("1W<V1L+3YG9710<F]X>2@I.PH*)')E="`]("1S;V%P8VQI96YT+3YE8VAO
M4W1R:6YG4VEM<&QE*")T:&ES(&ES(&$@=&5S="!S=')I;F<B*3L*(W!R:6YT
M("1S;V%P8VQI96YT+3Y?7V=E=%]W:7)E*"D["G!R:6YT7W(H)')E="D[96-H
M;R`B/&)R/EQN(CL*"B1R970@/2`D<V]A<&-L:65N="T^96-H;U-T<FEN9R@B
M=&AI<R!I<R!A('1E<W0@<W1R:6YG(BD["G!R:6YT7W(H)')E="D[96-H;R`B
M/&)R/EQN(CL*"B1R970@/2`D<V]A<&-L:65N="T^9&EV:61E*#(R+#<I.PHC
M('!R:6YT("1S;V%P8VQI96YT+3Y?7V=E=%]W:7)E*"D["FEF("A014%2.CII
M<T5R<F]R*"1R970I*0H@("`@<')I;G0H(D5R<F]R.B`B("X@)')E="T^9V5T
M365S<V%G92@I("X@(CQB<CY<;B(I.PIE;'-E"B`@("!P<FEN="@B475O=&EE
M;G0@:7,@(B`N("1R970@+B`B/&)R/EQN(BD["@HD<F5T(#T@)'-O87!C;&EE
M;G0M/F1I=FED92@R,BPP*3L*:68@*%!%05(Z.FES17)R;W(H)')E="DI"B`@
M("!P<FEN="@B17)R;W(Z("(@+B`D<F5T+3YG971-97-S86=E*"D@+B`B/&)R
M/EQN(BD["F5L<V4*("`@('!R:6YT*")1=6]T:65N="!I<R`B("X@)')E="`N
M("(\8G(^7&XB*3L*"@HO+R!33T%04W1R=6-T(&ES(&1E9FEN960@:6X@=&AE
M(&9O;&QO=VEN9R!F:6QE"G)E<75I<F5?;VYC92`G97AA;7!L95]T>7!E<RYP
M:'`G.PH*)'-T<G5C="`](&YE=R!33T%04W1R=6-T*"=T97-T('-T<FEN9R<L
M,3(S+#$R,RXQ,C,I.PH*+RH@<V5N9"!A;B!O8FIE8W0L(&=E="!A;B!O8FIE
M8W0@8F%C:R`J+PHO*B!T96QL(&-L:65N="!T;R!T<F%N<VQA=&4@=&\@8VQA
M<W-E<R!W92!P<F]V:61E(&EF('!O<W-I8FQE("HO"B1S;V%P8VQI96YT+3Y?
M875T;U]T<F%N<VQA=&EO;B`]('1R=64["B\J(&]R('EO=2!C86X@97AP;&EC
M:71L>2!S970@=&AE('1R86YS;&%T:6]N(&9O<@H@("!A('-P96-I9FEC(&-L
M87-S+B`@875T;U]T<F%N<VQA=&EO;B!W;W)K<R!F;W(@86QL(&-A<V5S+`H@
M("!B=70@;W!E;G,@04Y9(&-L87-S(&EN('1H92!S8W)I<'0@=&\@8F4@=7-E
M9"!A<R!A(&1A=&$@='EP92P*("`@86YD(&UA>2!N;W0@8F4@9&5S:7)E86)L
M92X@(&)O=&@@8V%N(&)E('5S960@;VX@8VQI96YT(&]R"B`@('-E<G9E<B`J
M+PHD<V]A<&-L:65N="T^7U]S971?='EP95]T<F%N<VQA=&EO;B@G>VAT='`Z
M+R]S;V%P:6YT97)O<"YO<F<O>'-D?5-/05!3=')U8W0G+"=33T%04W1R=6-T
M)RD["B1R970@/2`D<V]A<&-L:65N="T^96-H;U-T<G5C="@D<W1R=6-T+3Y?
M7W1O7W-O87`H*2D["B-P<FEN="`D<V]A<&-L:65N="T^7U]G971?=VER92@I
M.PIP<FEN=%]R*"1R970I.PH*+RHJ"B`J(%!(4"!D;V5S;B=T('-U<'!O<G0@
M;75L=&EP;&4@3U54('!A<F%M971E<G,@:6X@9G5N8W1I;VX@8V%L;',L('-O
M('=E"B`J(&UU<W0@9&\@82!L:71T;&4@=V]R:R!T;R!M86ME(&ET(&AA<'!E
M;B!H97)E+B`@5&AI<R!R97%U:7)E<R!K;F]W;&5D9V4@;VX@=&AE"B`J(&1E
M=F5L;W!E<G,@<&%R="!T;R!F:6=U<F4@;W5T(&AO=R!T:&5Y('=A;G0@=&\@
M9&5A;"!W:71H(&ET+@H@*B\*)')E="`]("1S;V%P8VQI96YT+3YE8VAO4W1R
M=6-T07-3:6UP;&54>7!E<R@D<W1R=6-T+3Y?7W1O7W-O87`H*2D["FEF("A0
M14%2.CII<T5R<F]R*"1R970I*2!["B`@("!P<FEN="@B17)R;W(Z("(@+B`D
M<F5T+3YG971-97-S86=E*"D@+B`B/&)R/EQN(BD["GT@96QS92!["B`@("!L
M:7-T*"1S=')I;F<L("1I;G0L("1F;&]A="D@/2!A<G)A>5]V86QU97,H)')E
M="D["GT*96-H;R`B=F%R4W1R:6YG.B`D<W1R:6YG/&)R/EQN=F%R26YT.B`D
M:6YT/&)R/EQN=F%R1FQO870Z("1F;&]A=#QB<CY<;B(["@H_/@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]D;V-S+UA-3%]087)S97(O````````````````````````````````````
M```````````````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<S-0`P,C$U,3$`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U!A<G-E<B]E>&%M<&QE<R\`
M`````````````````````````````````````````````````````````#`P
M,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S,U
M`#`R,S,R-P`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?
M4&%R<V5R+V5X86UP;&5S+WAM;%]P87)S97)?9FEL92YP:'``````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#(P,S(`,3`U,34T,S,W,S4`,#(W,C$P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_4$A0"B\J*@H@*B!E>&%M<&QE(&9O
M<B!834Q?4&%R<V5R7U-I;7!L90H@*@H@*B!`875T:&]R("`@("`@4W1E<&AA
M;B!38VAM:61T(#QS8VAS=$!P:'`M=&]O;',N;F5T/@H@*B!`<&%C:V%G92`@
M("`@6$U,7U!A<G-E<@H@*B!`<W5B<&%C:V%G92`@17AA;7!L97,*("HO"@HO
M*BH*("H@<F5Q=6ER92!T:&4@<&%R<V5R"B`J+PIR97%U:7)E7V]N8V4@)UA-
M3"]087)S97(N<&AP)SL*"F-L87-S(&UY4&%R<V5R(&5X=&5N9',@6$U,7U!A
M<G-E<@I["@H@("`@9G5N8W1I;VX@;7E087)S97(H*0H@("`@>PH@("`@("`@
M('!A<F5N=#HZ6$U,7U!A<G-E<B@I.PH@("`@?0H*("`@+RHJ"B`@("`J(&AA
M;F1L92!S=&%R="!E;&5M96YT"B`@("`J"B`@("`J($!A8V-E<W,@("!P<FEV
M871E"B`@("`J($!P87)A;2`@("!R97-O=7)C92`@("!X;6P@<&%R<V5R(')E
M<V]U<F-E"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("!N86UE(&]F('1H
M92!E;&5M96YT"B`@("`J($!P87)A;2`@("!A<G)A>2`@("`@("!A='1R:6)U
M=&5S"B`@("`J+PH@("`@9G5N8W1I;VX@<W1A<G1(86YD;&5R*"1X<"P@)&YA
M;64L("1A='1R:6)S*0H@("`@>PH@("`@("`@('!R:6YT9B@G:&%N9&QE('-T
M87)T('1A9SH@)7,\8G(@+SXG+"`D;F%M92D["B`@("!]"@H@("`O*BH*("`@
M("H@:&%N9&QE('-T87)T(&5L96UE;G0*("`@("H*("`@("H@0&%C8V5S<R`@
M('!R:79A=&4*("`@("H@0'!A<F%M("`@(')E<V]U<F-E("`@('AM;"!P87)S
M97(@<F5S;W5R8V4*("`@("H@0'!A<F%M("`@('-T<FEN9R`@("`@(&YA;64@
M;V8@=&AE(&5L96UE;G0*("`@("H@0'!A<F%M("`@(&%R<F%Y("`@("`@(&%T
M=')I8G5T97,*("`@("HO"B`@("!F=6YC=&EO;B!E;F1(86YD;&5R*"1X<"P@
M)&YA;64I"B`@("!["B`@("`@("`@<')I;G1F*"=H86YD;&4@96YD('1A9SH@
M)7,\8G(@+SXG+"`D;F%M92D["B`@("!]"GT*"B1P(#T@)FYE=R!M>5!A<G-E
M<B@I.PH*)')E<W5L="`]("1P+3YS971);G!U=$9I;&4H)WAM;%]P87)S97)?
M9FEL92YX;6PG*3L*)')E<W5L="`]("1P+3YP87)S92@I.PH_/@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]087)S97(O97AA;7!L97,O>&UL7W!A
M<G-E<E]F:6QE+GAM;``````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$R-P`Q,#4Q-30S,S<S-0`P,C<R
M,C0`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/&9O;SX*("`@(#QB87(^8V]N=&5N="!O9B!B87(\+V)A<CX*("`@(#QE;7!T
M>2\^"B`@("`\87)G:"!F;V\](F)A<B(^=&5S=#PO87)G:#X*/"]F;V\^````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O9&]C<R]834Q?4&%R<V5R+V5X86UP;&5S+WAM;%]P87)S97)?:&%N9&QE
M<BYP:'``````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#$W-S8`,3`U,34T,S,W,S4`,#(W-S(T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_4$A0"B\J*@H@
M*B!E>&%M<&QE(&9O<B!834Q?4&%R<V5R7U-I;7!L90H@*@H@*B!`875T:&]R
M("`@("`@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`M=&]O;',N;F5T/@H@
M*B!`<&%C:V%G92`@("`@6$U,7U!A<G-E<@H@*B!`<W5B<&%C:V%G92`@17AA
M;7!L97,*("HO"@HO*BH*("H@<F5Q=6ER92!T:&4@<&%R<V5R"B`J+PIR97%U
M:7)E7V]N8V4@)UA-3"]087)S97(N<&AP)SL*"F-L87-S(&UY2&%N9&QE<@I[
M"B`@("\J*@H@("`@*B!H86YD;&4@<W1A<G0@96QE;65N=`H@("`@*@H@("`@
M*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`<&%R86T@("`@<F5S;W5R8V4@
M("`@>&UL('!A<G-E<B!R97-O=7)C90H@("`@*B!`<&%R86T@("`@<W1R:6YG
M("`@("`@;F%M92!O9B!T:&4@96QE;65N=`H@("`@*B!`<&%R86T@("`@87)R
M87D@("`@("`@871T<FEB=71E<PH@("`@*B\*("`@(&9U;F-T:6]N('-T87)T
M2&%N9&QE<B@D>'`L("1N86UE+"`D871T<FEB<RD*("`@('L*("`@("`@("!P
M<FEN=&8H)VAA;F1L92!S=&%R="!T86<Z("5S/&)R("\^)RP@)&YA;64I.PH@
M("`@?0H*("`@+RHJ"B`@("`J(&AA;F1L92!S=&%R="!E;&5M96YT"B`@("`J
M"B`@("`J($!A8V-E<W,@("!P<FEV871E"B`@("`J($!P87)A;2`@("!R97-O
M=7)C92`@("!X;6P@<&%R<V5R(')E<V]U<F-E"B`@("`J($!P87)A;2`@("!S
M=')I;F<@("`@("!N86UE(&]F('1H92!E;&5M96YT"B`@("`J($!P87)A;2`@
M("!A<G)A>2`@("`@("!A='1R:6)U=&5S"B`@("`J+PH@("`@9G5N8W1I;VX@
M96YD2&%N9&QE<B@D>'`L("1N86UE*0H@("`@>PH@("`@("`@('!R:6YT9B@G
M:&%N9&QE(&5N9"!T86<Z("5S/&)R("\^)RP@)&YA;64I.PH@("`@?0I]"@HD
M<"`]("9N97<@6$U,7U!A<G-E<B@I.PHD:"`]("9N97<@;7E(86YD;&5R*"D[
M"@HD<F5S=6QT(#T@)'`M/G-E=$EN<'5T1FEL92@G>&UL7W!A<G-E<E]F:6QE
M+GAM;"<I.PHD<F5S=6QT(#T@)'`M/G-E=$AA;F1L97)/8FHH)&@I.PHD<F5S
M=6QT(#T@)'`M/G!A<G-E*"D["C\^```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&]C<R]834Q?4&%R<V5R+V5X86UP;&5S+WAM;%]P87)S97)?
M<VEM<&QE,2YP:'``````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#(Q-C8`,3`U,34T,S,W,S4`,#(W-C4S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_4$A0
M"B\J*@H@*B!E>&%M<&QE(&9O<B!834Q?4&%R<V5R7U-I;7!L90H@*@H@*B`D
M260Z('AM;%]P87)S97)?<VEM<&QE,2YP:'`L=B`Q+C,@,C`P-"\P-2\R."`Q
M-CHP.3HT."!S8VAS="!%>'`@)`H@*@H@*B!`875T:&]R("`@("`@4W1E<&AA
M;B!38VAM:61T(#QS8VAS=$!P:'`M=&]O;',N;F5T/@H@*B!`<&%C:V%G92`@
M("`@6$U,7U!A<G-E<@H@*B!`<W5B<&%C:V%G92`@17AA;7!L97,*("HO"@HO
M*BH*("H@<F5Q=6ER92!T:&4@<&%R<V5R"B`J+PIR97%U:7)E7V]N8V4@)UA-
M3"]087)S97(O4VEM<&QE+G!H<"<["@IC;&%S<R!M>5!A<G-E<B!E>'1E;F1S
M(%A-3%]087)S97)?4VEM<&QE"GL*("`@(&9U;F-T:6]N(&UY4&%R<V5R*"D*
M("`@('L*("`@("`@("`D=&AI<RT^6$U,7U!A<G-E<E]3:6UP;&4H*3L*("`@
M('T*"B`@("\J*@H@("`@*B!H86YD;&4@=&AE(&5L96UE;G0*("`@("H*("`@
M("H@5&AE(&5L96UE;G0@=VEL;"!B92!H86YD;&5D+"!O;F-E(&ET)W,@8VQO
M<V5D"B`@("`J"B`@("`J($!A8V-E<W,@("!P<FEV871E"B`@("`J($!P87)A
M;2`@("!S=')I;F<@("`@("!N86UE(&]F('1H92!E;&5M96YT"B`@("`J($!P
M87)A;2`@("!A<G)A>2`@("`@("!A='1R:6)U=&5S(&]F('1H92!E;&5M96YT
M"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("!C:&%R86-T97(@9&%T82!O
M9B!T:&4@96QE;65N=`H@("`@*B\*("`@(&9U;F-T:6]N(&AA;F1L945L96UE
M;G0H)&YA;64L("1A='1R:6)S+"`D9&%T82D*("`@('L*("`@("`@("!P<FEN
M=&8H)VAA;F1L:6YG("5S(&EN('1A9R!D97!T:"`E9#QB<B`O/B<L("1N86UE
M+"`D=&AI<RT^9V5T0W5R<F5N=$1E<'1H*"DI.PH@("`@("`@('!R:6YT9B@G
M8VAA<F%C=&5R(&1A=&$Z("5S/&)R("\^)RP@)&1A=&$@*3L*("`@("`@("!P
M<FEN="`G071T<FEB=71E<SH\8G(@+SXG.PH@("`@("`@('!R:6YT("<\<')E
M/B<["B`@("`@("`@<')I;G1?<B@@)&%T=')I8G,@*3L*("`@("`@("!P<FEN
M="`G/"]P<F4^)SL*("`@("`@("!P<FEN="`G/&)R("\^)SL*("`@('T*?0H*
M)'`@/2`F;F5W(&UY4&%R<V5R*"D["@HD<F5S=6QT(#T@)'`M/G-E=$EN<'5T
M1FEL92@G>&UL7W!A<G-E<E]S:6UP;&4Q+GAM;"<I.PHD<F5S=6QT(#T@)'`M
M/G!A<G-E*"D["C\^````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]087)S
M97(O97AA;7!L97,O>&UL7W!A<G-E<E]S:6UP;&4Q+GAM;```````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,Q
M-P`Q,#4Q-30S,S<S-0`P,C<V-C``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/"$M+2`D260Z('AM;%]P87)S97)?<VEM<&QE
M,2YX;6PL=B`Q+C(@,C`P-"\P-2\R-"`R,3HT,CHS,R!S8VAS="!%>'`@)"`M
M+3X*/&9O;SX*("`@(#QB87(^8V]N=&5N="!O9B!B87(\+V)A<CX*("`@(#QE
M;7!T>2\^"B`@("`\87)G:"!F;V\](F)A<B(^"B`@("`@("`@=&5S=`H@("`@
M("`@(#QT;VUA=&\^<&EZ>F$\+W1O;6%T;SX*("`@(#PO87)G:#X*/"]F;V\^
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4&%R<V5R+V5X86UP;&5S
M+WAM;%]P87)S97)?<VEM<&QE,BYP:'``````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(U,C0`,3`U,34T,S,W
M,S4`,#(W-C4R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_4$A0"B\J*@H@*B!E>&%M<&QE(&9O<B!834Q?4&%R<V5R7U-I
M;7!L90H@*@H@*B`D260Z('AM;%]P87)S97)?<VEM<&QE,BYP:'`L=B`Q+C$@
M,C`P-"\P-2\R-"`R,3HT,CHS,R!S8VAS="!%>'`@)`H@*@H@*B!`875T:&]R
M("`@("`@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`M=&]O;',N;F5T/@H@
M*B!`<&%C:V%G92`@("`@6$U,7U!A<G-E<@H@*B!`<W5B<&%C:V%G92`@17AA
M;7!L97,*("HO"@HO*BH*("H@<F5Q=6ER92!T:&4@<&%R<V5R"B`J+PIR97%U
M:7)E7V]N8V4@)UA-3"]087)S97(O4VEM<&QE+G!H<"<["@IC;&%S<R!M>5!A
M<G-E<C(@97AT96YD<R!834Q?4&%R<V5R7U-I;7!L90I["B`@("!F=6YC=&EO
M;B!M>5!A<G-E<B@I"B`@("!["B`@("`@("`@)'1H:7,M/EA-3%]087)S97)?
M4VEM<&QE*"D["B`@("!]"@H@("`O*BH*("`@("H@:&%N9&QE('1H92!C871E
M9V]R>2!E;&5M96YT"B`@("`J"B`@("`J(%1H92!E;&5M96YT('=I;&P@8F4@
M:&%N9&QE9"P@;VYC92!I="=S(&-L;W-E9`H@("`@*@H@("`@*B!`86-C97-S
M("`@<')I=F%T90H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@;F%M92!O
M9B!T:&4@96QE;65N=`H@("`@*B!`<&%R86T@("`@87)R87D@("`@("`@871T
M<FEB=71E<R!O9B!T:&4@96QE;65N=`H@("`@*B!`<&%R86T@("`@<W1R:6YG
M("`@("`@8VAA<F%C=&5R(&1A=&$@;V8@=&AE(&5L96UE;G0*("`@("HO"B`@
M("!F=6YC=&EO;B!H86YD;&5%;&5M96YT7V-A=&5G;W)Y*"1N86UE+"`D871T
M<FEB<RP@)&1A=&$I"B`@("!["B`@("`@("`@<')I;G1F*"`G0V%T96=O<GD@
M:7,@)7,\8G(@+SXG+"`D9&%T82`I.PH@("`@?0H*("`@+RHJ"B`@("`J(&AA
M;F1L92!T:&4@;F%M92!E;&5M96YT"B`@("`J"B`@("`J(%1H92!E;&5M96YT
M('=I;&P@8F4@:&%N9&QE9"P@;VYC92!I="=S(&-L;W-E9`H@("`@*@H@("`@
M*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@
M("`@;F%M92!O9B!T:&4@96QE;65N=`H@("`@*B!`<&%R86T@("`@87)R87D@
M("`@("`@871T<FEB=71E<R!O9B!T:&4@96QE;65N=`H@("`@*B!`<&%R86T@
M("`@<W1R:6YG("`@("`@8VAA<F%C=&5R(&1A=&$@;V8@=&AE(&5L96UE;G0*
M("`@("HO"B`@("!F=6YC=&EO;B!H86YD;&5%;&5M96YT7VYA;64H)&YA;64L
M("1A='1R:6)S+"`D9&%T82D*("`@('L*("`@("`@("!P<FEN=&8H("=.86UE
M(&ES("5S/&)R("\^)RP@)&1A=&$@*3L*("`@('T*?0H*)'`@/2`F;F5W(&UY
M4&%R<V5R,B@I.PHD<F5S=6QT(#T@)'`M/G-E=$EN<'5T1FEL92@G>&UL7W!A
M<G-E<E]S:6UP;&4R+GAM;"<I.PHD<"T^<V5T36]D92@G9G5N8R<I.PHD<F5S
M=6QT(#T@)'`M/G!A<G-E*"D["C\^````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D
M;V-S+UA-3%]087)S97(O97AA;7!L97,O>&UL7W!A<G-E<E]S:6UP;&4R+GAM
M;``````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#(S,``Q,#4Q-30S,S<S-0`P,C<V-3,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/"$M+2`D260Z('AM;%]P
M87)S97)?<VEM<&QE,BYX;6PL=B`Q+C$@,C`P-"\P-2\R-"`R,3HT,CHS,R!S
M8VAS="!%>'`@)"`M+3X*/'!A8VMA9V4^"B`@("`\8V%T96=O<GD^6$U,/"]C
M871E9V]R>3X*("`@(#QN86UE/EA-3%]087)S97(\+VYA;64^"CPO<&%C:V%G
M93X`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4&%R
M<V5R+V5X86UP;&5S+WAM;%]P87)S97)?<VEM<&QE7VAA;F1L97(N<&AP````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(T
M-S(`,3`U,34T,S,W,S4`,#,Q,C8W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_4$A0"B\J*@H@*B!E>&%M<&QE(&9O<B!8
M34Q?4&%R<V5R7U-I;7!L90H@*@H@*B`D260Z('AM;%]P87)S97)?<VEM<&QE
M7VAA;F1L97(N<&AP+'8@,2XQ(#(P,#0O,#4O,C4@,3,Z,C8Z-#(@<V-H<W0@
M17AP("0*("H*("H@0&%U=&AO<B`@("`@(%-T97!H86X@4V-H;6ED="`\<V-H
M<W1`<&AP+71O;VQS+FYE=#X*("H@0'!A8VMA9V4@("`@(%A-3%]087)S97(*
M("H@0'-U8G!A8VMA9V4@($5X86UP;&5S"B`J+PH*+RHJ"B`J(')E<75I<F4@
M=&AE('!A<G-E<@H@*B\*<F5Q=6ER95]O;F-E("=834PO4&%R<V5R+U-I;7!L
M92YP:'`G.PH*8VQA<W,@;7E(86YD;&5R4VEM<&QE"GL*("`@+RHJ"B`@("`J
M(&AA;F1L92!T:&4@8V%T96=O<GD@96QE;65N=`H@("`@*@H@("`@*B!4:&4@
M96QE;65N="!W:6QL(&)E(&AA;F1L960L(&]N8V4@:70G<R!C;&]S960*("`@
M("H*("`@("H@0&%C8V5S<R`@('!R:79A=&4*("`@("H@0'!A<F%M("`@('-T
M<FEN9R`@("`@(&YA;64@;V8@=&AE(&5L96UE;G0*("`@("H@0'!A<F%M("`@
M(&%R<F%Y("`@("`@(&%T=')I8G5T97,@;V8@=&AE(&5L96UE;G0*("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@("`@(&-H87)A8W1E<B!D871A(&]F('1H92!E
M;&5M96YT"B`@("`J+PH@("`@9G5N8W1I;VX@:&%N9&QE16QE;65N=%]C871E
M9V]R>2@D;F%M92P@)&%T=')I8G,L("1D871A*0H@("`@>PH@("`@("`@('!R
M:6YT9B@@)T-A=&5G;W)Y(&ES("5S/&)R("\^)RP@)&1A=&$@*3L*("`@('T*
M"B`@("\J*@H@("`@*B!H86YD;&4@=&AE(&YA;64@96QE;65N=`H@("`@*@H@
M("`@*B!4:&4@96QE;65N="!W:6QL(&)E(&AA;F1L960L(&]N8V4@:70G<R!C
M;&]S960*("`@("H*("`@("H@0&%C8V5S<R`@('!R:79A=&4*("`@("H@0'!A
M<F%M("`@('-T<FEN9R`@("`@(&YA;64@;V8@=&AE(&5L96UE;G0*("`@("H@
M0'!A<F%M("`@(&%R<F%Y("`@("`@(&%T=')I8G5T97,@;V8@=&AE(&5L96UE
M;G0*("`@("H@0'!A<F%M("`@('-T<FEN9R`@("`@(&-H87)A8W1E<B!D871A
M(&]F('1H92!E;&5M96YT"B`@("`J+PH@("`@9G5N8W1I;VX@:&%N9&QE16QE
M;65N=%]N86UE*"1N86UE+"`D871T<FEB<RP@)&1A=&$I"B`@("!["B`@("`@
M("`@<')I;G1F*"`G3F%M92!I<R`E<SQB<B`O/B<L("1D871A("D["B`@("!]
M"GT*"B1P(#T@)FYE=R!834Q?4&%R<V5R7U-I;7!L92@I.PHD:"`]("9N97<@
M;7E(86YD;&5R4VEM<&QE*"D["B1P+3YS971(86YD;&5R3V)J*"1H*3L*)')E
M<W5L="`]("1P+3YS971);G!U=$9I;&4H)WAM;%]P87)S97)?<VEM<&QE,BYX
M;6PG*3L*)'`M/G-E=$UO9&4H)V9U;F,G*3L*)')E<W5L="`]("1P+3YP87)S
M92@I.PH_/@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+P``````````````````
M```````````````````````````````````````````````P,#`P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<S-0`P,C(S-C8`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ
M97(O97AA;7!L97,O````````````````````````````````````````````
M`````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-3$U-#,S-S,V`#`R-#(P-0`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]E>&%M<&QE+GAM;```````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`Q,C(`,3`U,34T,S,W,S4`,#(V,S4T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#QX;6P^"B`@("`\=&5S
M="!F;V\](F)A<B(^"B`@("`@("`@5&5S=`H@("`@("`@(#QT86<^=&5S=#PO
M=&%G/@H@("`@/"]T97-T/@H\+WAM;#X`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E
M<FEA;&EZ97(O97AA;7!L97,O<V5R:6%L:7IE06YD16YC;V1E+G!H<```````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R
M-C,V`#$P-3$U-#,S-S,U`#`S,#0U-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/U!(4`HO*BH*("H@17AA;7!L92!T;R!D
M96UO;G-T<F%T92!T:&4@96YC;V1E1G5N8W1I;VX@86YD(&1E8V]D949U;F-T
M:6]N"B`J(&]P=&EO;G,N"B`J"B`J(%1H:7,@86QL;W=S('EO=2!T;R!A<'!L
M>2!C86QL8F%C:W,@=&\@>6]U<B!D871A('1H870@:7,@8V%L;&5D"B`J(&]N
M(&%L;"!S=')I;F=S('=H:6QE('-E<FEA;&EZ:6YG(&%N9"!U;G-E<FEA;&EZ
M:6YG+@H@*@H@*B!`875T:&]R(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP
M+FYE=#X*("HO"B`@("!E<G)O<E]R97!O<G1I;F<H15]!3$PI.PH*("`@(')E
M<75I<F5?;VYC92`G6$U,+U-E<FEA;&EZ97(N<&AP)SL*("`@(')E<75I<F5?
M;VYC92`G6$U,+U5N<V5R:6%L:7IE<BYP:'`G.PH*("`@("1O<'1I;VYS(#T@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/
M4%1)3TY?24Y$14Y4("`@("`@("`@("`@("`@/3X@)R`@("`G+`H@("`@("`@
M("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7TQ)3D5"4D5!
M2U,@("`@("`@("`@(#T^(")<;B(L"B`@("`@("`@("`@("`@("`@("`@("!8
M34Q?4T5224%,25I%4E]/4%1)3TY?4T-!3$%27T%37T%45%))0E5415,@/3X@
M=')U92P*("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]0
M5$E/3E]%3D-/1$5?1E5.0R`@("`@("`@("`]/B`G<W1R=&]U<'!E<B<*("`@
M("`@("`@("`@("`@("`@("`I.PH@("`@"B`@("`D9F]O(#T@;F5W('-T9$-L
M87-S*"D["B`@("`D9F]O+3YB87(@/2!N97<@<W1D0VQA<W,H*3L*("`@("1F
M;V\M/F)A<BT^=&5S="`@/2`G5&AI<R!I<R!A('1E<W0N)SL*("`@("1F;V\M
M/F)A<BT^=F%L=64@/2`G5&AI<R!I<R!A('9A;'5E+B<["B`@("`*("`@("1S
M97)I86QI>F5R(#T@)FYE=R!834Q?4V5R:6%L:7IE<B@D;W!T:6]N<RD["B`@
M("`*("`@("1R97-U;'0@/2`D<V5R:6%L:7IE<BT^<V5R:6%L:7IE*"1F;V\I
M.PH@("`@"B`@("!I9B`H)')E<W5L="`]/3T@=')U92D@>PH)"21X;6P@/2`D
M<V5R:6%L:7IE<BT^9V5T4V5R:6%L:7IE9$1A=&$H*3L*("`@('T*"B`@("!E
M8VAO"2(\<')E/B(["B`@("!P<FEN=%]R*"!H=&UL<W!E8VEA;&-H87)S*"1X
M;6PI("D["B`@("!E8VAO"2(\+W!R93XB.PH*("`@("1U;G-E<FEA;&EZ97(@
M/2`F;F5W(%A-3%]5;G-E<FEA;&EZ97(H*3L*("`@("1U;G-E<FEA;&EZ97(M
M/G-E=$]P=&EO;B@G<&%R<V5!='1R:6)U=&5S)RP@=')U92D["B`@("`D=6YS
M97)I86QI>F5R+3YS971/<'1I;VXH)V1E8V]D949U;F-T:6]N)RP@)W-T<G1O
M;&]W97(G*3L*"B`@("`D<F5S=6QT(#T@)'5N<V5R:6%L:7IE<BT^=6YS97)I
M86QI>F4H)'AM;"D["B`@("`*("`@(&5C:&\@)SQP<F4^)SL*("`@('!R:6YT
M7W(H)'5N<V5R:6%L:7IE<BT^9V5T56YS97)I86QI>F5D1&%T82@I*3L*("`@
M(&5C:&\@)SPO<')E/B<["C\^````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I
M86QI>F5!;F12971U<FXN<&AP````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$Q-#$`,3`U,34T,S,W,S8`,#,P-3(U
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M4$A0"B\J*@H@*B!%>&%M<&QE('1H870@=7-E<R!T:&4@<F5T=7)N4F5S=6QT
M(&]P=&EO;B!T;R!D:7)E8W1L>2!R971U<FX@=&AE('-E<FEA;&EZ960*("H@
M6$U,(&1O8W5M96YT(&EN('1H92!S97)I86QI>F4H*2!M971H;V0N"B`J"B`J
M($!A=71H;W(@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@*B\*
M97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*"G)E<75I<F5?;VYC92`G6$U,+U-E
M<FEA;&EZ97(N<&AP)SL*"B1O<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7TE.1$5.5"`@("`@("`@
M/3X@)R`@("`G+`H@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D52
M7T]05$E/3E]215154DY?4D5354Q4(#T^('1R=64*("`@("`@("`@("`@("`@
M("D["@HD<V5R:6%L:7IE<B`]("9N97<@6$U,7U-E<FEA;&EZ97(H)&]P=&EO
M;G,I.PH*)&9O;R`](%!%05(Z.G)A:7-E17)R;W(H)TIU<W0@82!T97-T)RP@
M,3(S-"D["@HD<F5S=6QT(#T@)'-E<FEA;&EZ97(M/G-E<FEA;&EZ92@D9F]O
M*3L*"F5C:&\@)SQP<F4^)SL*96-H;R!H=&UL<W!E8VEA;&-H87)S*"1R97-U
M;'0I.PIE8VAO("<\+W!R93XG.PH_/@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE
M<R]S97)I86QI>F5!<G)A>5=I=&A/8FIE8W1S+G!H<```````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S-S(`,3`U,34T,S,W,S4`
M,#,R,#4U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_4$A0"B\J*@H@*B!4:&ES(&5X86UP;&4@<VAO=W,@:&]W('1O(&-R
M96%T92!A;B!21$8@9&]C=6UE;G0*("H@=VET:"!A(&9E=R!L:6YE<R!O9B!C
M;V1E+@H@*B!4:&ES(&-A;B!A;'-O(&)E(&1O;F4@=VET:"!M;V1E(#T^('-I
M;7!L97AM;`H@*@H@*B!`875T:&]R(%-T97!H86X@4V-H;6ED="`\<V-H<W1`
M<&AP+FYE=#X*("H@0'-E92`@("!S97)I86QI>F5);F1E>&5D07)R87DN<&AP
M"B`J+PH@("`@97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*"B`@("!R97%U:7)E
M7V]N8V4@)UA-3"]397)I86QI>F5R+G!H<"<["@H@("`@)&]P=&EO;G,@/2!A
M<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@(FEN9&5N="(@("`@("`@
M("`@/3X@(B`@("`B+`H@("`@("`@("`@("`@("`@("`@("`@("`B;&EN96)R
M96%K(B`@("`@("`]/B`B7&XB+`H@("`@("`@("`@("`@("`@("`@("`@("`B
M='EP94AI;G1S(B`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@
M("`@("`@(F%D9$1E8VPB("`@("`@("`@/3X@=')U92P*("`@("`@("`@("`@
M("`@("`@("`@("`@(F5N8V]D:6YG(B`@("`@("`@/3X@(E541BTX(@H@("`@
M("`@("`@("`@("`@("`@("D["B`@("`*("`@("1S97)I86QI>F5R(#T@;F5W
M(%A-3%]397)I86QI>F5R*"1O<'1I;VYS*3L*"B`@("`D<V5R:6%L:7IE<BT^
M<V5T17)R;W)(86YD;&EN9RA014%27T524D]27T1)12D["B`@("`*("`@("1A
M<G)A>2`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@(&YE=R!S=&1#;&%S
M<R@I+`H@("`@("`@("`@("`@("`@("`@(&YE=R!S=&1#;&%S<R@I"B`@("`@
M("`@("`@("`@("`@("`@*3L*("`@(`H@("`@)')E<W5L="`]("1S97)I86QI
M>F5R+3YS97)I86QI>F4H)&%R<F%Y*3L*("`@(`H@("`@:68H("1R97-U;'0@
M/3T]('1R=64@*2!["B`@("`@("`@96-H;R`@("`B/'!R93XB.PH@("`@("`@
M(&5C:&\@("`@:'1M;&5N=&ET:65S*"1S97)I86QI>F5R+3YG971397)I86QI
M>F5D1&%T82@I*3L*("`@("`@("!E8VAO("`@("(\+W!R93XB.PH@("`@?0H*
M("`@("1R97-U;'0@/2`D<V5R:6%L:7IE<BT^<V5R:6%L:7IE*"1A<G)A>2P@
M87)R87DH("=C;&%S<T%S5&%G3F%M92<@/3X@=')U92`I*3L*("`@(`H@("`@
M:68H("1R97-U;'0@/3T]('1R=64@*2!["B`@("`@("`@96-H;R`@("`B/'!R
M93XB.PH@("`@("`@(&5C:&\@("`@:'1M;&5N=&ET:65S*"1S97)I86QI>F5R
M+3YG971397)I86QI>F5D1&%T82@I*3L*("`@("`@("!E8VAO("`@("(\+W!R
M93XB.PH@("`@?0H@("`@"C\^````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S
M+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ94-$871A+G!H<```
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,30W,@`Q,#4Q-30S,S<S-0`P,C<V,#4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]02%`*+RHJ"B`J(%A-3"!3
M97)I86QI>F5R(&5X86UP;&4*("H*("H@5&AI<R!E>&%M<&QE(&UA:V5S('5S
M92!O9B!T:&4@0T1A=&$@<V5C=&EO;G,@;W!T:6]N"B`J"B`J($!A=71H;W(@
M(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO"F5R<F]R7W)E
M<&]R=&EN9RA%7T%,3"D["G)E<75I<F5?;VYC92`G6$U,+U-E<FEA;&EZ97(N
M<&AP)SL*"B1S97)I86QI>F5R(#T@;F5W(%A-3%]397)I86QI>F5R*"D["B1S
M97)I86QI>F5R+3YS971/<'1I;VXH6$U,7U-%4DE!3$E:15)?3U!424].7TE.
M1$5.5"P@)R`@("`G*3L*)'-E<FEA;&EZ97(M/G-E=$]P=&EO;BA834Q?4T52
M24%,25I%4E]/4%1)3TY?1$5&055,5%]404<L("=I=&5M)RD["B1S97)I86QI
M>F5R+3YS971/<'1I;VXH6$U,7U-%4DE!3$E:15)?3U!424].7T-$051!7U-%
M0U1)3TY3+"!T<G5E*3L*"B1D871A(#T@87)R87DH"B`@("`@("`@("`@)V9O
M;R<@/3X@)U1H:7,@:7,@<V]M92!T97AT+BXN)RP*("`@("`@("`@("`G8F%R
M)R`]/B`G)B!E=F5N(&UO<F4@=&5X="XN+B<L"B`@("`@("`@("`@)W1E<W0G
M(#T^(&%R<F%Y*"=&;V\G+"`G1F]O("8@8F%R)RD*"0D)*3L*"B1R97-U;'0@
M/2`D<V5R:6%L:7IE<BT^<V5R:6%L:7IE*"1D871A*3L*"FEF*"`D<F5S=6QT
M(#T]/2!T<G5E("D@>PH))'AM;"`]("1S97)I86QI>F5R+3YG971397)I86QI
M>F5D1&%T82@I.PH@("`@96-H;R`G/'!R93XG.PH@("`@96-H;R!H=&UL<W!E
M8VEA;&-H87)S*"1X;6PI.PH@("`@96-H;R`G/"]P<F4^)SL*?2!E;'-E('L*
M("`@("1R97-U;'0M/F=E=$UE<W-A9V4H*3L*("`@(&5X:70H*3L*?0H_/@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ945M<'1Y
M07)R87DN<&AP```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,3`V,0`Q,#4Q-30S,S<S-0`P,S`W,C``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]02%`*+RHJ"B`J
M(%1H:7,@<VAO=W,@=&AA="!834Q?4V5R:6%L:7IE<B!I<R!A8FQE('1O('=O
M<FL@=VET:`H@*B!E;7!T>2!A<G)A>7,*("H*("H@0&%U=&AO<B!3=&5P:&%N
M(%-C:&UI9'0@/'-C:'-T0'!H<"YN970^"B`J+PIE<G)O<E]R97!O<G1I;F<H
M15]!3$PI.PIR97%U:7)E7V]N8V4@)UA-3"]5;G-E<FEA;&EZ97(N<&AP)SL*
M"B1X;6P@/2`\/#P@14]&"CQA=71O<&%G95]O<'1I;VYS(%]C;&%S<STB875T
M;W!A9V5?;W!T:6]N<R(@"E]T>7!E/2)O8FIE8W0B/@H\=F5R<VEO;B!?='EP
M93TB<W1R:6YG(CXQ+C`\+W9E<G-I;VX^"CQO<'1I;VYS(%]T>7!E/2)A<G)A
M>2(@+SX*/"]A=71O<&%G95]O<'1I;VYS/@I%3T8["@HD=6YS97)I86QI>F5R
M(#T@;F5W(%A-3%]5;G-E<FEA;&EZ97(H*3L*)')E<W5L="`]("1U;G-E<FEA
M;&EZ97(M/G5N<V5R:6%L:7IE*"1X;6PI.PH*:68H("1R97-U;'0@/3T]('1R
M=64@*2!["B`@("!E8VAO("<\<')E/B<["B`@("!P<FEN=%]R*"1U;G-E<FEA
M;&EZ97(M/F=E=%5N<V5R:6%L:7IE9$1A=&$H*2D["B`@("!E8VAO("<\+W!R
M93XG.PI]"C\^````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ
M94EN9&5X961!<G)A>2YP:'`````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,S<P-0`Q,#4Q-30S,S<S-0`P,S$R,3$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]02%`*
M+RHJ"B`J(%1H:7,@97AA;7!L92!D96UO;G-T<F%T97,@=&AE('5S92!O9@H@
M*B!M;V1E(#T^('-I;7!L97AM;`H@*@H@*B!)="!C86X@8F4@=7-E9"!T;R!S
M97)I86QI>F4@86X@:6YD97AE9"!A<G)A>0H@*B!L:6ME(&5X="]S:6UP;&5X
M;6P@9&]E<RP@8GD@=7-I;F<@=&AE(&YA;64*("H@;V8@=&AE('!A<F5N="!T
M86<L('=H:6QE(&]M:71T:6YG('1H:7,@=&%G+@H@*@H@*B!`875T:&]R(%-T
M97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO"B`@("!E<G)O<E]R
M97!O<G1I;F<H15]!3$PI.PH@("`@"B`@("!R97%U:7)E7V]N8V4@)UA-3"]3
M97)I86QI>F5R+G!H<"<["@H@("`@)&]P=&EO;G,@/2!A<G)A>2@*("`@("`@
M("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7TE.1$5.
M5"`@("`@("`]/B`G("`@("<L"B`@("`@("`@("`@("`@("`@("`@("`@(%A-
M3%]315))04Q)6D527T]05$E/3E],24Y%0E)%04M3("`@/3X@(EQN(BP*"0D)
M"0D)6$U,7U-%4DE!3$E:15)?3U!424].7U)/3U1?3D%-12`@("`]/B`G<F1F
M.E)$1B<L"B`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D52
M7T]05$E/3E]23T]47T%45%))0E,@/3X@87)R87DH)W9E<G-I;VXG(#T^("<P
M+CDQ)RDL"B`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D52
M7T]05$E/3E]-3T1%("`@("`@("`@/3X@6$U,7U-%4DE!3$E:15)?34]$15]3
M24U03$5834P*("`@("`@("`@("`@("`@("`@("`I.PH@("`@"B`@("`D<V5R
M:6%L:7IE<B`](&YE=R!834Q?4V5R:6%L:7IE<B@D;W!T:6]N<RD["@H@("`@
M"B`@("`D<F1F(#T@87)R87DH"@D)"0DG8VAA;FYE;"<@/3X@87)R87DH"@D)
M"0D)"0D)"2=T:71L92<@/3X@)T5X86UP;&4@4D1&(&-H86YN96PG+`H)"0D)
M"0D)"0DG;&EN:R<@(#T^("=H='1P.B\O=W=W+G!H<"UT;V]L<RYD92<L"@D)
M"0D)"0D)"2=I;6%G92<)/3X)87)R87DH"@D)"0D)"0D)"0D)"0D))W1I=&QE
M)PD]/B`G17AA;7!L92!I;6%G92<L"@D)"0D)"0D)"0D)"0D))W5R;"<)/3X)
M)VAT='`Z+R]W=W<N<&AP+71O;VQS+F1E+VEM86=E+F=I9B<L"@D)"0D)"0D)
M"0D)"0D))VQI;FLG"3T^"2=H='1P.B\O=W=W+G!H<"UT;V]L<RYD92<*"0D)
M"0D)"0D)"0D)"2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=I=&5M)R`@(#T^("!A<G)A>2@*("`@("`@("`@("`@"0D)"0D)"0D)
M"0EA<G)A>2@*("`@("`@("`@("`@"0D)"0D)"0D)"0D))W1I=&QE)PD]/B`G
M17AA;7!L92!I=&5M)RP*("`@("`@("`@("`@"0D)"0D)"0D)"0D))VQI;FLG
M"3T^("=H='1P.B\O97AA;7!L92YC;VTG"B`@("`@("`@("`@(`D)"0D)"0D)
M"0D)*2P*("`@("`@("`@("`@"0D)"0D)"0D)"0EA<G)A>2@*("`@("`@("`@
M("`@"0D)"0D)"0D)"0D))W1I=&QE)PD]/B`G06YO=&AE<B!I=&5M)RP*("`@
M("`@("`@("`@"0D)"0D)"0D)"0D))VQI;FLG"3T^("=H='1P.B\O97AA;7!L
M92YC;VTG"B`@("`@("`@("`@(`D)"0D)"0D)"0D)*2P*("`@("`@("`@("`@
M"0D)"0D)"0D)"0EA<G)A>2@*("`@("`@("`@("`@"0D)"0D)"0D)"0D))W1I
M=&QE)PD]/B`G22!T:&EN:R!Y;W4@9V5T(&ET+BXN)RP*("`@("`@("`@("`@
M"0D)"0D)"0D)"0D))VQI;FLG"3T^("=H='1P.B\O97AA;7!L92YC;VTG"B`@
M("`@("`@("`@(`D)"0D)"0D)"0D)*0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I"@D)"0D)"0D)*0H@
M("`@("`@("`@("`@("`@("`@("D["B`@("`*("`@("1R97-U;'0@/2`D<V5R
M:6%L:7IE<BT^<V5R:6%L:7IE*"1R9&8I.PH@("`@"B`@("!I9B@@)')E<W5L
M="`]/3T@=')U92`I('L*("`@("`@("!E8VAO("`@("<\<')E/B<["B`@("`@
M("`@96-H;R`@("!H=&UL96YT:71I97,H)'-E<FEA;&EZ97(M/F=E=%-E<FEA
M;&EZ961$871A*"DI.PH@("`@("`@(&5C:&\@("`@)SPO<')E/B<["B`@("!]
M"C\^````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F5);F1E
M>&5D07)R87E7:71H0V]N=&5X="YP:'``````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(Q-C4`,3`U,34T,S,W,S4`,#,S-#$Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_4$A0"B\J*@H@
M*B!4:&ES(&5X86UP;&4@9&5M;VYS=')A=&5S('1H92!U<V4@;V8*("H@;6]D
M92`]/B!S:6UP;&5X;6P*("H*("H@270@8V%N(&)E('5S960@=&\@<V5R:6%L
M:7IE(&%N(&EN9&5X960@87)R87D*("H@;&EK92!E>'0O<VEM<&QE>&UL(&1O
M97,L(&)Y('5S:6YG('1H92!N86UE"B`J(&]F('1H92!P87)E;G0@=&%G+"!W
M:&EL92!O;6ET=&EN9R!T:&ES('1A9RX*("H*("H@0&%U=&AO<B!3=&5P:&%N
M(%-C:&UI9'0@/'-C:'-T0'!H<"YN970^"B`J+PH@("`@97)R;W)?<F5P;W)T
M:6YG*$5?04Q,*3L*("`@(`H@("`@<F5Q=6ER95]O;F-E("=834PO4V5R:6%L
M:7IE<BYP:'`G.PH*("`@("1O<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E])3D1%3E0@("`@
M("`@/3X@)R`@("`G+`H@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T52
M24%,25I%4E]/4%1)3TY?3$E.14)214%+4R`@(#T^(")<;B(L"B`@("`@("`@
M("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]$149!54Q4
M7U1!1R`@/3X@87)R87DH*2P*("`@("`@("`@("`@("`@("`@("`@("`@6$U,
M7U-%4DE!3$E:15)?3U!424].7T1%1D%53%1?5$%'("`]/B!A<G)A>2@G9F]O
M<R<@/3X@)V9O;R<L("=B87)S)R`]/B`G8F%R)RD*("`@("`@("`@("`@("`@
M("`@("`I.PH@("`@"B`@("`D<V5R:6%L:7IE<B`](&YE=R!834Q?4V5R:6%L
M:7IE<B@D;W!T:6]N<RD["B`@("`*("`@("1D871A(#T@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@)V9O;W,G(#T^(&%R<F%Y*"=O;F4@9F]O)RP@)W1W
M;R!F;V]S)RP@)W1H<F5E(&9O;W,G*2P*("`@("`@("`@("`@("`@("`@("`G
M8F%R<R<@/3X@87)R87DH)V]N92!B87(G+"`G='=O(&)A<G,G+"`G=&AR964@
M8F%R<R<I+`H@("`@("`@("`@("`@("`@*3L*"B`@("`D<F5S=6QT(#T@)'-E
M<FEA;&EZ97(M/G-E<FEA;&EZ92@D9&%T82D["B`@("`*("`@(&EF*"`D<F5S
M=6QT(#T]/2!T<G5E("D@>PH@("`@("`@(&5C:&\@("`@)SQP<F4^)SL*("`@
M("`@("!E8VAO("`@(&AT;6QE;G1I=&EE<R@D<V5R:6%L:7IE<BT^9V5T4V5R
M:6%L:7IE9$1A=&$H*2D["B`@("`@("`@96-H;R`@("`G/"]P<F4^)SL*("`@
M('T*/SX`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R
M+V5X86UP;&5S+W-E<FEA;&EZ94YU;&Q0<F]P97)T:65S+G!H<```````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S$Q,P`Q,#4Q
M-30S,S<S-0`P,S$V,3(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]02%`*+RHJ"B`J(%1H:7,@97AA;7!L92!D96UO;G-T
M<F%T97,@=&AE('5S92!O9@H@*B!I9VYO<F5.=6QL(#T^('1R=64*("H*("H@
M270@8V%N(&)E('5S960@=&\@<V5R:6%L:7IE(&%N(&EN9&5X960@87)R87D*
M("H@;&EK92!E>'0O<VEM<&QE>&UL(&1O97,L(&)Y('5S:6YG('1H92!N86UE
M"B`J(&]F('1H92!P87)E;G0@=&%G+"!W:&EL92!O;6ET=&EN9R!T:&ES('1A
M9RX*("H*("H@0&%U=&AO<B!3=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"YN
M970^"B`J+PH@("`@97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*("`@(`H@("`@
M<F5Q=6ER95]O;F-E("=834PO4V5R:6%L:7IE<BYP:'`G.PH*("`@("1O<'1I
M;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@(")I;F1E;G0B
M("`@("`@("`@/3X@)R`@("`G+`H@("`@("`@("`@("`@("`@("`@("`@("`B
M;&EN96)R96%K(B`@("`@(#T^(")<;B(L"B`@("`@("`@("`@("`@("`@("`@
M*3L*("`@(`H@("`@)'-E<FEA;&EZ97(@/2!N97<@6$U,7U-E<FEA;&EZ97(H
M)&]P=&EO;G,I.PH@("`@"B`@("`D;V)J96-T(#T@;F5W('-T9$-L87-S*"D[
M"B`@("`D;V)J96-T+3YF;V\@/2`G8F%R)SL*("`@("1O8FIE8W0M/F)A<B`]
M(&YU;&P["B`@("`*("`@("1A<G)A>2`](&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("=F;V\G(#T^("=B87(G+`H@("`@("`@("`@("`@("`@("`@("=B
M87(G(#T^(&YU;&P*("`@("`@("`@("`@("`@("D["B`@("`*("`@("1R97-U
M;'0@/2`D<V5R:6%L:7IE<BT^<V5R:6%L:7IE*"1O8FIE8W0I.PH@("`@"B`@
M("!I9B@@)')E<W5L="`]/3T@=')U92`I('L*("`@("`@("!E8VAO("`@("(\
M<')E/B(["B`@("`@("`@96-H;R`@("!H=&UL96YT:71I97,H)'-E<FEA;&EZ
M97(M/F=E=%-E<FEA;&EZ961$871A*"DI.PH@("`@("`@(&5C:&\@("`@(CPO
M<')E/B(["B`@("!]"@H@("`@)')E<W5L="`]("1S97)I86QI>F5R+3YS97)I
M86QI>F4H)&%R<F%Y*3L*("`@(`H@("`@:68H("1R97-U;'0@/3T]('1R=64@
M*2!["B`@("`@("`@96-H;R`@("`B/'!R93XB.PH@("`@("`@(&5C:&\@("`@
M:'1M;&5N=&ET:65S*"1S97)I86QI>F5R+3YG971397)I86QI>F5D1&%T82@I
M*3L*("`@("`@("!E8VAO("`@("(\+W!R93XB.PH@("`@?0H@("`@"B`@("`D
M<V5R:6%L:7IE<BT^<V5T3W!T:6]N*"=I9VYO<F5.=6QL)RP@=')U92D["B`@
M("`D<F5S=6QT(#T@)'-E<FEA;&EZ97(M/G-E<FEA;&EZ92@D;V)J96-T*3L*
M("`@(`H@("`@:68H("1R97-U;'0@/3T]('1R=64@*2!["B`@("`@("`@96-H
M;R`@("`B/'!R93XB.PH@("`@("`@(&5C:&\@("`@:'1M;&5N=&ET:65S*"1S
M97)I86QI>F5R+3YG971397)I86QI>F5D1&%T82@I*3L*("`@("`@("!E8VAO
M("`@("(\+W!R93XB.PH@("`@?0H@("`@"B`@("`D<F5S=6QT(#T@)'-E<FEA
M;&EZ97(M/G-E<FEA;&EZ92@D87)R87DI.PH@("`@"B`@("!I9B@@)')E<W5L
M="`]/3T@=')U92`I('L*("`@("`@("!E8VAO("`@("(\<')E/B(["B`@("`@
M("`@96-H;R`@("!H=&UL96YT:71I97,H)'-E<FEA;&EZ97(M/F=E=%-E<FEA
M;&EZ961$871A*"DI.PH@("`@("`@(&5C:&\@("`@(CPO<')E/B(["B`@("!]
M"C\^````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M
M<&QE<R]S97)I86QI>F5/8FIE8W0N<&AP````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S-#8`,3`U,34T,S,W
M,S4`,#,P,#0P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_4$A0"B\J*@H@*B!4:&ES(&ES(&IU<W0@82!B87-I8R!E>&%M
M<&QE('1H870@<VAO=W,*("H@:&]W(&]B:F5C=',@8V%N(&)E('-E<FEA;&EZ
M960@<V\@=&AE>2!C86X*("H@8F4@9G5L;'D@<F5S=&]R960@;&%T97(N"B`J
M"B`J($!A=71H;W(@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@
M*B\*"B\J*@H@*B!%>&%M<&QE(&-L87-S('1H870@:6UP;&5M96YT<R!?7W-L
M965P*"D*("H*("H@0'!A8VMA9V4@("`@6$U,7U-E<FEA;&EZ97(*("H@0'-U
M8G!A8VMA9V4@17AA;7!L97,*("HO"F-L87-S($UY0VQA<W,*>PH@("`@=F%R
M("1F;V\@/2`G5&AI<R!I<R!F;V\N)SL*("`@('9A<B`D8F%R(#T@)U1H:7,@
M:7,@8F%R+B<["B`@("`*("`@(&9U;F-T:6]N(%]?<VQE97`H*0H@("`@>PH@
M("`@("`@(')E='5R;B!A<G)A>2@G9F]O)RD["B`@("!]"GT*"F5R<F]R7W)E
M<&]R=&EN9RA%7T%,3"D["@HO*BH*("H@3&]A9"!834Q?4V5R:6%L:7IE<@H@
M*B\*<F5Q=6ER95]O;F-E("=834PO4V5R:6%L:7IE<BYP:'`G.PH*"B\O('1H
M:7,@:7,@:G5S="!T;R!G970@82!N97-T960@;V)J96-T"B1P96%R17)R;W(@
M/2!014%2.CIR86ES945R<F]R*"=4:&ES(&ES(&IU<W0@86X@97)R;W(@;V)J
M96-T)RPQ,C,I.PH*)&]P=&EO;G,@/2!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`B:6YD96YT(B`@("`@("`@(#T^("(@("`@(BP*("`@("`@("`@("`@
M("`@("`@("`B;&EN96)R96%K(B`@("`@(#T^(")<;B(L"B`@("`@("`@("`@
M("`@("`@("`@(F1E9F%U;'1486=.86UE(B`]/B`B=6YN86UE9$ET96TB+`H@
M("`@("`@("`@("`@("`@("`@(")T>7!E2&EN=',B("`@("`@/3X@=')U90H@
M("`@("`@("`@("`@("`@*3L*"B1F;V\@("`@/2`@(&YE=R!S=&1#;&%S<SL*
M)&9O;RT^=F%L=64@/2`B37D@=F%L=64B.PHD9F]O+3YE<G)O<B`]("1P96%R
M17)R;W(["B1F;V\M/GAM;"`@(#T@(F-O;VPB.PH*)&9O;RT^;V)J"3T@;F5W
M($UY0VQA<W,H*3L*)&9O;RT^87)R("`@/2!A<G)A>2@I.PHD9F]O+3YZ97)O
M("`](#`["@H*)'-E<FEA;&EZ97(@/2`F;F5W(%A-3%]397)I86QI>F5R*"1O
M<'1I;VYS*3L*"B1R97-U;'0@/2`D<V5R:6%L:7IE<BT^<V5R:6%L:7IE*"1F
M;V\I.PH*:68H("1R97-U;'0@/3T]('1R=64@*2!["@DD>&UL(#T@)'-E<FEA
M;&EZ97(M/F=E=%-E<FEA;&EZ961$871A*"D["GT*"F5C:&\@)SQP<F4^)SL*
M96-H;R!H=&UL<W!E8VEA;&-H87)S*"1X;6PI.PIE8VAO("<\+W!R93XG.PH_
M/@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D
M;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ95)$1BYP:'``
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-#,V-``Q,#4Q-30S,S<S-0`P,C<R-#<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]02%`*+RHJ"B`J(%1H
M:7,@97AA;7!L92!S:&]W<R!H;W<@=&\@8W)E871E(&%N(%)$1B!D;V-U;65N
M=`H@*B!W:71H(&$@9F5W(&QI;F5S(&]F(&-O9&4N"B`J(%1H:7,@8V%N(&%L
M<V\@8F4@9&]N92!W:71H(&UO9&4@/3X@<VEM<&QE>&UL"B`J"B`J($!A=71H
M;W(@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@*B!`<V5E("`@
M('-E<FEA;&EZ94EN9&5X961!<G)A>2YP:'`*("HO"B`@("!E<G)O<E]R97!O
M<G1I;F<H15]!3$PI.PH*("`@(')E<75I<F5?;VYC92`G6$U,+U-E<FEA;&EZ
M97(N<&AP)SL*"B`@("`D;W!T:6]N<R`](&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("`@("`B:6YD96YT(B`@("`@("`@("`]/B`B("`@("(L"B`@("`@
M("`@("`@("`@("`@("`@("`@(")L:6YE8G)E86LB("`@("`@(#T^(")<;B(L
M"B`@("`@("`@("`@("`@("`@("`@("`@(")T>7!E2&EN=',B("`@("`@(#T^
M(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`B861D1&5C;"(@("`@
M("`@("`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`B96YC;V1I
M;F<B("`@("`@("`]/B`B551&+3@B+`H)"0D)"0DB<F]O=$YA;64B("`@("`@
M("`]/B`B<F1F.E)$1B(L"B`@("`@("`@("`@("`@("`@("`@("`@(")R;V]T
M071T<FEB=71E<R(@(#T^(&%R<F%Y*")V97)S:6]N(B`]/B`B,"XY,2(I+`H)
M"0D)"0DB9&5F875L=%1A9TYA;64B("`]/B`B:71E;2(L"B`@("`@("`@("`@
M("`@("`@("`@("`@(")A='1R:6)U=&5S07)R87DB(#T^(")?871T<FEB=71E
M<R(*("`@("`@("`@("`@("`@("`@("`I.PH@("`@"B`@("`D<V5R:6%L:7IE
M<B`](&YE=R!834Q?4V5R:6%L:7IE<B@D;W!T:6]N<RD["@H@("`@"B`@("`D
M<F1F("`@(#T@("!A<G)A>2@*"0D)"0D)(F-H86YN96PB(#T^(&%R<F%Y*`H)
M"0D)"0D)"0D)"2)T:71L92(@/3X@(D5X86UP;&4@4D1&(&-H86YN96PB+`H)
M"0D)"0D)"0D)"2)L:6YK(B`@/3X@(FAT='`Z+R]W=W<N<&AP+71O;VQS+F1E
M(BP*"0D)"0D)"0D)"0DB:6UA9V4B"3T^"6%R<F%Y*`H)"0D)"0D)"0D)"0D)
M"0D)(G1I=&QE(@D]/B`B17AA;7!L92!I;6%G92(L"@D)"0D)"0D)"0D)"0D)
M"0DB=7)L(@D]/@DB:'1T<#HO+W=W=RYP:'`M=&]O;',N9&4O:6UA9V4N9VEF
M(BP*"0D)"0D)"0D)"0D)"0D)"2)L:6YK(@D]/@DB:'1T<#HO+W=W=RYP:'`M
M=&]O;',N9&4B"@D)"0D)"0D)"0D)"0D)"2DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(E]A='1R:6)U=&5S(B`]/B!A
M<G)A>2@@(G)D9CIA8F]U="(@/3X@(FAT='`Z+R]E>&%M<&QE+F-O;2]F;V]B
M87(N:'1M;"(@*2P*"0D)"0D)"0D)"0EA<G)A>2@*"0D)"0D)"0D)"0D)(G1I
M=&QE(@D]/B`B17AA;7!L92!I=&5M(BP*"0D)"0D)"0D)"0D)(FQI;FLB"3T^
M(")H='1P.B\O97AA;7!L92YC;VTB+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`B7V%T=')I8G5T97,B(#T^(&%R
M<F%Y*"`B<F1F.F%B;W5T(B`]/B`B:'1T<#HO+V5X86UP;&4N8V]M+V9O;V)A
M<BYH=&UL(B`I"@D)"0D)"0D)"0D)*2P*"0D)"0D)"0D)"0EA<G)A>2@*"0D)
M"0D)"0D)"0D)(G1I=&QE(@D]/B`B06YO=&AE<B!I=&5M(BP*"0D)"0D)"0D)
M"0D)(FQI;FLB"3T^(")H='1P.B\O97AA;7!L92YC;VTB+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B7V%T=')I
M8G5T97,B(#T^(&%R<F%Y*"`B<F1F.F%B;W5T(B`]/B`B:'1T<#HO+V5X86UP
M;&4N8V]M+V9O;V)A<BYH=&UL(B`I"@D)"0D)"0D)"0D)*2P*"0D)"0D)"0D)
M"0EA<G)A>2@*"0D)"0D)"0D)"0D)(G1I=&QE(@D]/B`B22!T:&EN:R!Y;W4@
M9V5T(&ET+BXN(BP*"0D)"0D)"0D)"0D)(FQI;FLB"3T^(")H='1P.B\O97AA
M;7!L92YC;VTB+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`B7V%T=')I8G5T97,B(#T^(&%R<F%Y*"`B<F1F.F%B
M;W5T(B`]/B`B:'1T<#HO+V5X86UP;&4N8V]M+V9O;V)A<BYH=&UL(B`I"@D)
M"0D)"0D)"0D)*0H)"0D)"0D)"0D)*0H@("`@("`@("`@("`@("`@("`@("D[
M"B`@("`*("`@("1R97-U;'0@/2`D<V5R:6%L:7IE<BT^<V5R:6%L:7IE*"1R
M9&8I.PH@("`@"B`@("!I9B@@)')E<W5L="`]/3T@=')U92`I('L*("`@("`@
M("!E8VAO("`@("(\<')E/B(["B`@("`@("`@96-H;R`@("!H=&UL96YT:71I
M97,H)'-E<FEA;&EZ97(M/F=E=%-E<FEA;&EZ961$871A*"DI.PH@("`@("`@
M(&5C:&\@("`@(CPO<')E/B(["B`@("!]"C\^````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W-E<FEA
M;&EZ95-E;&5C=&EV94%T=')I8G5T97,N<&AP```````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S$U,0`Q,#4Q-30S,S<S-0`P,S(V,3<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]0
M2%`*+RHJ"B`J(%1H:7,@<VAO=W,@=&AA="!834Q?4V5R:6%L:7IE<B!I<R!A
M8FQE('1O('=O<FL@=VET:`H@*B!E;7!T>2!A<G)A>7,*("H*("H@0&%U=&AO
M<B!3=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"YN970^"B`J+PIE<G)O<E]R
M97!O<G1I;F<H15]!3$PI.PIR97%U:7)E7V]N8V4@)UA-3"]397)I86QI>F5R
M+G!H<"<["@HD9&%T82`](&%R<F%Y*`H@("`@("`@("`@("`@("`@87)R87DH
M)VYA;64G(#T^("=3=7!E<FUA;B<L("=A9V4G(#T^(#,T+"`G<F5A;&YA;64G
M(#T^("=#;&%R:R!+96YT)RDL"B`@("`@("`@("`@("`@("!A<G)A>2@G;F%M
M92<@/3X@)T)A=&UA;B<L("=A9V4G(#T^(#,R+"`G<F5A;&YA;64G(#T^("="
M<G5C92!787EN92<I+`H@("`@("`@("`@("`@("`@)W9I;&QA:6XG(#T^(&%R
M<F%Y*"=N86UE)R`]/B`G4')O9F5S<V]R(%IO;VTG+"`G86=E)R`]/B`G=6YK
M;F]W;B<L("=R96%L;F%M92<@/3X@)TAU;G1E<B!:;VQO;6]N)RD*("`@("`@
M("`@("`@*3L*"B1S97)I86QI>F5R(#T@;F5W(%A-3%]397)I86QI>F5R*"D[
M"B1S97)I86QI>F5R+3YS971/<'1I;VXH6$U,7U-%4DE!3$E:15)?3U!424].
M7TE.1$5.5"P@)R`@("`G*3L*)'-E<FEA;&EZ97(M/G-E=$]P=&EO;BA834Q?
M4T5224%,25I%4E]/4%1)3TY?1$5&055,5%]404<L("=H97)O)RD["@HD<V5R
M:6%L:7IE<BT^<V5R:6%L:7IE*"1D871A*3L*96-H;R`G/'!R93XG.PIE8VAO
M(")$969A=6QT(&)E:&%V:6]U<CI<;B(["F5C:&\@:'1M;'-P96-I86QC:&%R
M<R@D<V5R:6%L:7IE<BT^9V5T4V5R:6%L:7IE9$1A=&$H*2D["F5C:&\@)SPO
M<')E/B<["@HD<V5R:6%L:7IE<BT^<V5T3W!T:6]N*%A-3%]315))04Q)6D52
M7T]05$E/3E]30T%,05)?05-?05144DE"551%4RP@=')U92D["@HD<V5R:6%L
M:7IE<BT^<V5R:6%L:7IE*"1D871A*3L*96-H;R`G/'!R93XG.PIE8VAO(")8
M34Q?4T5224%,25I%4E]/4%1)3TY?4T-!3$%27T%37T%45%))0E5415,@/2!T
M<G5E.EQN(CL*96-H;R!H=&UL<W!E8VEA;&-H87)S*"1S97)I86QI>F5R+3YG
M971397)I86QI>F5D1&%T82@I*3L*96-H;R`G/"]P<F4^)SL*"B1S97)I86QI
M>F5R+3YS971/<'1I;VXH6$U,7U-%4DE!3$E:15)?3U!424].7U-#04Q!4E]!
M4U]!5%1224)55$53+"!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G:&5R;R<@("`@/3X@87)R87DH)VYA;64G+"`G86=E)RDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W9I;&QA:6XG(#T^(&%R<F%Y*"=R96%L;F%M
M92<I"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*0H@("`@("`@("`@("`@
M("`@("`@("`@*3L*"B1S97)I86QI>F5R+3YS97)I86QI>F4H)&1A=&$I.PIE
M8VAO("<\<')E/B<["F5C:&\@(EA-3%]315))04Q)6D527T]05$E/3E]30T%,
M05)?05-?05144DE"551%4R!I<R!A;B!A<G)A>3I<;B(["F5C:&\@:'1M;'-P
M96-I86QC:&%R<R@D<V5R:6%L:7IE<BT^9V5T4V5R:6%L:7IE9$1A=&$H*2D[
M"F5C:&\@)SPO<')E/B<["C\^````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F57
M:71H071T<FEB=71E<RYP:'``````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(R,S8`,3`U,34T,S,W,S4`,#,Q-C$R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_4$A0"B\J
M*@H@*B!834P@4V5R:6%L:7IE<B!E>&%M<&QE"B`J"B`J(%1H:7,@97AA;7!L
M92!D96UO;G-T<F%T97,L(&AO=R!834Q?4V5R:6%L:7IE<B!I<R!A8FQE"B`J
M('1O('-E<FEA;&EZ92!S8V%L87(@=F%L=65S(&%S(&%N(&%T=')I8G5T92!I
M;G-T96%D(&]F(&$@;F5S=&5D('1A9RX*("H*("H@5&AE('-A;64@<W1R=6-T
M=7)E(&QI:V4@:6X@<V5R:6%L:7IE3V)J96-T+G!H<"!I<R!S97)I86QI>F5D
M+@H@*@H@*B!`875T:&]R("!3=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"YN
M970^"B`J+PH@("`@97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*"B`@("!R97%U
M:7)E7V]N8V4@)UA-3"]397)I86QI>F5R+G!H<"<["@H@("`@)&]P=&EO;G,@
M/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@(FEN9&5N="(@("`@
M("`@("`@("`@/3X@(B`@("`B+`H@("`@("`@("`@("`@("`@("`@("`@("`B
M;&EN96)R96%K(B`@("`@("`@("`]/B`B7&XB+`H@("`@("`@("`@("`@("`@
M("`@("`@("`B9&5F875L=%1A9TYA;64B("`@("`]/B`B=6YN86UE9$ET96TB
M+`H)"0D)"0DB<V-A;&%R07-!='1R:6)U=&5S(B`]/B!T<G5E+`H@("`@("`@
M("`@("`@("`@("`@("D["B`@("`*("`@("\O('1H:7,@:7,@:G5S="!T;R!G
M970@82!N97-T960@;V)J96-T"B`@("`D<&5A<D5R<F]R(#T@4$5!4CHZ<F%I
M<V5%<G)O<B@G5&AI<R!I<R!J=7-T(&%N(&5R<F]R(&]B:F5C="<L,3(S*3L*
M"0H@("`@)&9O;R`@("`]("`@;F5W('-T9$-L87-S.PH@("`@"B`@("`D9F]O
M+3YV86QU92`](")->2!V86QU92(["B`@("`D9F]O+3YE<G)O<B`]("1P96%R
M17)R;W(["B`@("`D9F]O+3YX;6P@("`](")C;V]L(CL*("`@(`H@("`@)'-E
M<FEA;&EZ97(@/2!N97<@6$U,7U-E<FEA;&EZ97(H)&]P=&EO;G,I.PH@("`@
M"B`@("`D<F5S=6QT(#T@)'-E<FEA;&EZ97(M/G-E<FEA;&EZ92@D9F]O*3L*
M("`@(`H@("`@:68H("1R97-U;'0@/3T]('1R=64@*2!["@D))'AM;"`]("1S
M97)I86QI>F5R+3YG971397)I86QI>F5D1&%T82@I.PH*"2`@("!E8VAO"2(\
M<')E/B(["@D@("`@<')I;G1?<B@@:'1M;'-P96-I86QC:&%R<R@D>&UL*2`I
M.PH)("`@(&5C:&\)(CPO<')E/B(["B`@("!](&5L<V4@>PH)"65C:&\)(CQP
M<F4^(CL*"0EP<FEN=%]R*"1R97-U;'0I.PH)"65C:&\)(CPO<')E/B(["@E]
M"@H_/@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI
M>F5R+V5X86UP;&5S+W-E<FEA;&EZ95=I=&A!='1R:6)U=&5S,BYP:'``````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C0S-0`Q
M,#4Q-30S,S<S-0`P,S$V-S4`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]02%`*+RHJ"B`J(%A-3"!397)I86QI>F5R(&5X
M86UP;&4*("H*("H@5&AI<R!E>&%M<&QE(&1E;6]N<W1R871E<RP@:&]W(%A-
M3%]397)I86QI>F5R(&ES(&%B;&4*("H@=&\@<V5R:6%L:7IE('!R961E9FEN
M960@=F%L=65S(&%S('1H92!A='1R:6)U=&5S(&]F(&$@=&%G"B`J"B`J($!A
M=71H;W(@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO"B`@
M("!E<G)O<E]R97!O<G1I;F<H15]!3$PI.PH*("`@(')E<75I<F5?;VYC92`G
M6$U,+U-E<FEA;&EZ97(N<&AP)SL*"B`@("`D;W!T:6]N<R`](&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`@("`B:6YD96YT(B`@("`@("`@("`@("`]
M/B`B("`@("(L"B`@("`@("`@("`@("`@("`@("`@("`@(")L:6YE8G)E86LB
M("`@("`@("`@(#T^(")<;B(L"B`@("`@("`@("`@("`@("`@("`@("`@(")D
M969A=6QT5&%G3F%M92(@("`@(#T^(")U;FYA;65D271E;2(L"@D)"0D)"2)S
M8V%L87)!<T%T=')I8G5T97,B(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`B871T<FEB=71E<T%R<F%Y(B`@("`]/B`G7V%T=')I8G5T97,G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`B8V]N=&5N=$YA;64B("`@("`@
M("`]/B`G7V-O;G1E;G0G"B`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`D
M9&%T82`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=F;V\G(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G7V%T
M=')I8G5T97,G(#T^(&%R<F%Y*"`G=F5R<VEO;B<@/3X@)S$N,"<L("=F;V\G
M(#T^("=B87(G("DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=?8V]N=&5N="<@("`@/3X@)W1E<W0G"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`I+`H@("`@("`@("`@("`@("`@("`@("=S8VAS
M="<@/3X@)U-T97!H86X@4V-H;6ED="<*("`@("`@("`@("`@("`@("D[("`@
M(`H@("`@"B`@("`D<V5R:6%L:7IE<B`](&YE=R!834Q?4V5R:6%L:7IE<B@D
M;W!T:6]N<RD["B`@("`*("`@("1R97-U;'0@/2`D<V5R:6%L:7IE<BT^<V5R
M:6%L:7IE*"1D871A*3L*("`@(`H@("`@:68H("1R97-U;'0@/3T]('1R=64@
M*2!["@D))'AM;"`]("1S97)I86QI>F5R+3YG971397)I86QI>F5D1&%T82@I
M.PH*"2`@("!E8VAO"2(\<')E/B(["@D@("`@<')I;G1?<B@@:'1M;'-P96-I
M86QC:&%R<R@D>&UL*2`I.PH)("`@(&5C:&\)(CPO<')E/B(["B`@("!](&5L
M<V4@>PH)"65C:&\)(CQP<F4^(CL*"0EP<FEN=%]R*"1R97-U;'0I.PH)"65C
M:&\)(CPO<')E/B(["@E]"@H_/@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O<V5R:6%L:7IE
M5VET:$-O;6UE;G0N<&AP`````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R,3`P`#$P-3$U-#,S-S,U`#`S,3`U-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/U!(4`HO
M*BH*("H@5&AI<R!I<R!J=7-T(&$@8F%S:6,@97AA;7!L92!T:&%T('-H;W=S
M"B`J(&AO=R!O8FIE8W1S(&-A;B!B92!S97)I86QI>F5D('-O('1H97D@8V%N
M"B`J(&)E(&9U;&QY(')E<W1O<F5D(&QA=&5R+@H@*@H@*B!`875T:&]R(%-T
M97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO"B`@("!E<G)O<E]R
M97!O<G1I;F<H15]!3$PI.PH*("`@(')E<75I<F5?;VYC92`G6$U,+U-E<FEA
M;&EZ97(N<&AP)SL*"B`@("`D;W!T:6]N<R`](&%R<F%Y*`H@("`@("`@("`@
M("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?24Y$14Y4("`@
M("`@/3X@)R`@("`G+`H@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T52
M24%,25I%4E]/4%1)3TY?3$E.14)214%+4R`@/3X@(EQN(BP*("`@("`@("`@
M("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7T-/34U%3E1?
M2T59(#T^("=C;VUM96YT)PH@("`@("`@("`@("`@("`@("`@("D["B`@("`*
M("`@("1F;V\@/2!N97<@<W1D0VQA<W,["B`@("`D9F]O+3YC;VUM96YT(#T@
M)U1H:7,@:7,@82!C;VUM96YT)SL*("`@("1F;V\M/G9A;'5E("`@/2`G37D@
M=F%L=64G.PH@("`@"B`@("`D9F]O+3YB87(@("`@(#T@;F5W('-T9$-L87-S
M*"D["B`@("`D9F]O+3YB87(M/G9A;'5E("`@/2`G06YO=&AE<B!V86QU92<[
M"B`@("`D9F]O+3YB87(M/F-O;6UE;G0@/2`G06YO=&AE<B!C;VUM96YT)SL*
M("`@(`H@("`@)&9O;RT^=&]M871O("`@("`@("`@(#T@;F5W('-T9$-L87-S
M*"D["B`@("`D9F]O+3YT;VUA=&\M/F-O;6UE;G0@/2`G06YD(&$@;&%S="!C
M;VUM96YT)SL*("`@(`H@("`@)'-E<FEA;&EZ97(@/2`F;F5W(%A-3%]397)I
M86QI>F5R*"1O<'1I;VYS*3L*("`@(`H@("`@)')E<W5L="`]("1S97)I86QI
M>F5R+3YS97)I86QI>F4H)&9O;RD["B`@("`*("`@(&EF("@D<F5S=6QT(#T]
M/2!T<G5E*2!["@D))'AM;"`]("1S97)I86QI>F5R+3YG971397)I86QI>F5D
M1&%T82@I.PH@("`@?0H*("`@(&5C:&\@)SQP<F4^)SL*("`@('!R:6YT7W(H
M:'1M;'-P96-I86QC:&%R<R@D>&UL*2D["B`@("!E8VAO("<\+W!R93XG.PH_
M/@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L
M:7IE<B]E>&%M<&QE<R]S97)I86QI>F57:71H1'1D+G!H<```````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,#<`
M,3`U,34T,S,W,S4`,#,P,3<S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_4$A0"B\J*@H@*B!4:&ES(&5X86UP;&4@<VAO
M=W,@:&]W('1O(&%D9"!A($1O8U1Y<&4@1&5C;&%R871I;VX@=&\@=&AE(%A-
M3"!D;V-U;65N=`H@*@H@*B!`875T:&]R(%-T97!H86X@4V-H;6ED="`\<V-H
M<W1`<&AP+FYE=#X*("HO"B`@("!E<G)O<E]R97!O<G1I;F<H15]!3$PI.PH*
M("`@(')E<75I<F5?;VYC92`G6$U,+U-E<FEA;&EZ97(N<&AP)SL*"B`@("`D
M;W!T:6]N<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`B:6YD
M96YT(B`@("`@/3X@(B`@("`B+`H@("`@("`@("`@("`@("`@("`@("`@("`B
M;&EN96)R96%K(B`@/3X@(EQN(BP*("`@("`@("`@("`@("`@("`@("`@("`@
M(F%D9$1E8VPB("`@(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@
M(")A9&1$;V-T>7!E(B`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`B9&]C='EP92(@("`@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U<FDG(#T^("=H='1P.B\O
M<&5A<BYP:'`N;F5T+V1T9"]P86-K86=E+3$N,"<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=I9"<@/3X@)RTO
M+U!(4"\O4$5!4B]$5$0@4$%#2T%'12`P+C$G"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("D*("`@("`@("`@("`@("`@
M("`@("`I.PH@("`@"B`@("`D<V5R:6%L:7IE<B`](&YE=R!834Q?4V5R:6%L
M:7IE<B@D;W!T:6]N<RD["@H@("`@)&9O;R`@("`]("`@4$5!4CHZ<F%I<V5%
M<G)O<B@B2G5S="!A('1E<W0B+"`Q,C,T*3L@("`@"B`@("`*("`@("1R97-U
M;'0@/2`D<V5R:6%L:7IE<BT^<V5R:6%L:7IE*"1F;V\I.PH@("`@"B`@("!I
M9B@@)')E<W5L="`]/3T@=')U92`I('L*("`@("`@("!E8VAO("`@("(\<')E
M/B(["B`@("`@("`@96-H;R`@("!H=&UL96YT:71I97,H)'-E<FEA;&EZ97(M
M/F=E=%-E<FEA;&EZ961$871A*"DI.PH@("`@("`@(&5C:&\@("`@(CPO<')E
M/B(["B`@("!]"C\^````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ
M95=I=&A);F1E;G1E9$%T=')I8G5T97,N<&AP```````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C8Q,@`Q,#4Q-30S,S<S-0`P,S,R-C,`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]02%`*
M+RHJ"B`J(%A-3"!397)I86QI>F5R(&5X86UP;&4*("H*("H@5&AI<R!E>&%M
M<&QE(&1E;6]N<W1R871E<RP@:&]W(%A-3%]397)I86QI>F5R(&ES(&%B;&4*
M("H@=&\@<V5R:6%L:7IE('-C86QA<B!V86QU97,@87,@86X@871T<FEB=71E
M(&EN<W1E860@;V8@82!N97-T960@=&%G+@H@*@H@*B!);B!T:&ES(&5X86UP
M;&4@=&%G<R!W:71H(&UO<F4@=&AA;B!O;F4@871T<FEB=71E(&)E8V]M90H@
M*B!M=6QT:6QI;F4@=&%G<RP@87,@96%C:"!A='1R:6)U=&4@9V5T<R!W<FET
M=&5N('1O(&$*("H@<V5P87)A=&4@;&EN92!A<R`G:6YD96YT071T<FEB=71E
M<R<@:7,@<V5T('1O("=?875T;R<N"B`J"B`J($!A=71H;W(@(%-T97!H86X@
M4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO"B`@("!E<G)O<E]R97!O<G1I
M;F<H15]!3$PI.PH@("`@<F5Q=6ER95]O;F-E("=834PO4V5R:6%L:7IE<BYP
M:'`G.PH*("`@("1O<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@("`@(")I;F1E;G0B("`@("`@("`@("`@(#T^("(@("`@(BP*("`@("`@
M("`@("`@("`@("`@("`@("`@(FQI;F5B<F5A:R(@("`@("`@("`@/3X@(EQN
M(BP*("`@("`@("`@("`@("`@("`@("`@("`@(G1Y<&5(:6YT<R(@("`@("`@
M("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@(")D969A=6QT
M5&%G3F%M92(@("`@(#T^(")U;FYA;65D271E;2(L"B`@("`@("`@("`@("`@
M("`@("`@("`@(")S8V%L87)!<T%T=')I8G5T97,B(#T^('1R=64L"B`@("`@
M("`@("`@("`@("`@("`@("`@(")I;F1E;G1!='1R:6)U=&5S(B`@(#T^(")?
M875T;R(*("`@("`@("`@("`@("`@("`@("`I.PH@("`@"B`@("`O+R!T:&ES
M(&ES(&IU<W0@=&\@9V5T(&$@;F5S=&5D(&]B:F5C=`H@("`@)'!E87)%<G)O
M<B`](%!%05(Z.G)A:7-E17)R;W(H)U1H:7,@:7,@:G5S="!A;B!E<G)O<B!O
M8FIE8W0G+#$R,RD["@D*("`@("1F;V\@("`@/2`@(&YE=R!S=&1#;&%S<SL*
M("`@(`H@("`@)&9O;RT^=F%L=64@/2`B37D@=F%L=64B.PH@("`@)&9O;RT^
M97)R;W(@/2`D<&5A<D5R<F]R.PH@("`@)&9O;RT^>&UL("`@/2`B8V]O;"([
M"B`@("`*("`@("1S97)I86QI>F5R(#T@;F5W(%A-3%]397)I86QI>F5R*"1O
M<'1I;VYS*3L*("`@(`H@("`@)')E<W5L="`]("1S97)I86QI>F5R+3YS97)I
M86QI>F4H)&9O;RD["B`@("`*("`@(&EF*"`D<F5S=6QT(#T]/2!T<G5E("D@
M>PH)"21X;6P@/2`D<V5R:6%L:7IE<BT^9V5T4V5R:6%L:7IE9$1A=&$H*3L*
M"@D@("`@96-H;PDB/'!R93XB.PH)("`@('!R:6YT7W(H(&AT;6QS<&5C:6%L
M8VAA<G,H)'AM;"D@*3L*"2`@("!E8VAO"2(\+W!R93XB.PH@("`@?2!E;'-E
M('L*"0EE8VAO"2(\<')E/B(["@D)<')I;G1?<B@D<F5S=6QT*3L*"0EE8VAO
M"2(\+W!R93XB.PH)?0H*/SX`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA
M;&EZ97(O97AA;7!L97,O<V5R:6%L:7IE5VET:$YA;65S<&%C92YP:'``````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#,S
M`#$P-3$U-#,S-S,U`#`S,3,U,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/U!(4`HO*BH*("H@17AA;7!L92!T:&%T(&-R
M96%T97,@=&%G<R!W:71H(&$@;F%M97-P86-E"B`J"B`J($!A=71H;W(@4W1E
M<&AA;B!38VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@*B\*97)R;W)?<F5P;W)T
M:6YG*$5?04Q,*3L*"G)E<75I<F5?;VYC92`G6$U,+U-E<FEA;&EZ97(N<&AP
M)SL*"B1O<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)VEN
M9&5N="<@("`@("`@("`]/B`G("`G+`H@("`@("`@("`@("`@("`@("`@("=L
M:6YE8G)E86LG("`@("`@/3X@(EQN(BP*("`@("`@("`@("`@("`@("`@("`G
M9&5F875L=%1A9TYA;64G(#T^("=I=&5M)RP*("`@("`@("`@("`@("`@("`@
M("`G;F%M97-P86-E)R`@("`@(#T^("=F;V\G"B`@("`@("`@("`@("`@("`I
M.PH*)&9O;R`@("`]("`@;F5W('-T9$-L87-S.PHD9F]O+3YV86QU92`]("=-
M>2!V86QU92<["B1F;V\M/GAM;"`@(#T@)V-O;VPG.PH*)&9O;RT^;V)J"3T@
M;F5W('-T9$-L87-S.PHD9F]O+3YA<G(@("`](&%R<F%Y*"D["B1F;V\M/GIE
M<F\@(#T@,#L*"B1S97)I86QI>F5R(#T@)FYE=R!834Q?4V5R:6%L:7IE<B@D
M;W!T:6]N<RD["@HD<F5S=6QT(#T@)'-E<FEA;&EZ97(M/G-E<FEA;&EZ92@D
M9F]O*3L*"FEF*"`D<F5S=6QT(#T]/2!T<G5E("D@>PH))'AM;"`]("1S97)I
M86QI>F5R+3YG971397)I86QI>F5D1&%T82@I.PI]"@IE8VAO"2<\<')E/B<[
M"G!R:6YT7W(H(&AT;6QS<&5C:6%L8VAA<G,H)'AM;"D@*3L*96-H;PDG/"]P
M<F4^)SL*"B\O(&%L<V\@<&%S<R!T:&4@55))"B1S97)I86QI>F5R+3YS971/
M<'1I;VXH)VYA;65S<&%C92<L(&%R<F%Y*"=B87(G+"`G:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+UA-3%]397)I86QI>F5R)RDI.PH*)')E<W5L="`]
M("1S97)I86QI>F5R+3YS97)I86QI>F4H)&9O;RD["@II9B@@)')E<W5L="`]
M/3T@=')U92`I('L*"21X;6P@/2`D<V5R:6%L:7IE<BT^9V5T4V5R:6%L:7IE
M9$1A=&$H*3L*?0H*96-H;PDG/'!R93XG.PIP<FEN=%]R*"!H=&UL<W!E8VEA
M;&-H87)S*"1X;6PI("D["F5C:&\))SPO<')E/B<["C\^````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI
M>F57:71H5&%G36%P+G!H<```````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#0Q-#0`,3`U,34T,S,W,S4`,#,P-C,U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_4$A0
M"B\J*@H@*B!834P@4V5R:6%L:7IE<B!E>&%M<&QE"B`J"B`J(%1H:7,@97AA
M;7!L92!D96UO;G-T<F%T97,L(&AO=R!834Q?4V5R:6%L:7IE<B!I<R!A8FQE
M"B`J('1O('-E<FEA;&EZ92!S8V%L87(@=F%L=65S(&%S(&%N(&%T=')I8G5T
M92!I;G-T96%D(&]F(&$@;F5S=&5D('1A9RX*("H*("H@26X@=&AI<R!E>&%M
M<&QE('1A9W,@=VET:"!M;W)E('1H86X@;VYE(&%T=')I8G5T92!B96-O;64*
M("H@;75L=&EL:6YE('1A9W,L(&%S(&5A8V@@871T<FEB=71E(&=E=',@=W)I
M='1E;B!T;R!A"B`J('-E<&%R871E(&QI;F4@87,@)VEN9&5N=$%T=')I8G5T
M97,G(&ES('-E="!T;R`G7V%U=&\G+@H@*@H@*B!`875T:&]R("!3=&5P:&%N
M(%-C:&UI9'0@/'-C:'-T0'!H<"YN970^"B`J+PH@("`@97)R;W)?<F5P;W)T
M:6YG*$5?04Q,*3L*("`@(')E<75I<F5?;VYC92`G6$U,+U-E<FEA;&EZ97(N
M<&AP)SL*"B`@("`D;W!T:6]N<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("`@("`G:6YD96YT)R`@("`@("`@("`@("`]/B`G("`@("<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("=L:6YE8G)E86LG("`@("`@("`@(#T^(")<
M;B(L"B`@("`@("`@("`@("`@("`@("`@("`@("=M;V1E)R`@("`@("`@("`@
M("`@(#T^("=S:6UP;&5X;6PG+`H@("`@("`@("`@("`@("`@("`@("`@("`G
M<F]O=$YA;64G"0D)(#T^("=I=&5M<R<*("`@("`@("`@("`@("`@("`@("`I
M.PH*("`@("1D871A(#T@87)R87DH"@D)"0D))VET96TG(#T^(&%R<F%Y*"!A
M<G)A>2@*"0D)"0D)"0D)"2=T:71L92<@("`@("`@/3X@)T9O;V)A<B$G+`H)
M"0D)"0D)"0D))V1E<V-R:7!T:6]N)R`]/B`G5&AI<R!I<R!S;VUE('1E>'0N
M+BXN)RP*"0D)"0D)"0D)"2=L:6YK)R`@("`@("`@/3X@)VAT='`Z+R]F;V]B
M87(N8V]M)PH)"0D)"0D)"0DI+`H)"0D)"0D)"0EA<G)A>2@*"0D)"0D)"0D)
M"2=T:71L92<@("`@("`@/3X@)T9O;V)A<C(A)RP*"0D)"0D)"0D)"2=D97-C
M<FEP=&EO;B<@/3X@)U1H:7,@:7,@<V]M92!T97AT+OP@)G5U;6P[(.0@]B<L
M"@D)"0D)"0D)"0DG;&EN:R<@("`@("`@(#T^("=H='1P.B\O9F]O8F%R+F-O
M;2<*"0D)"0D)"0D)*0H)"0D)"0D)"2D*"2`@("`)"0D)"0D)"0D)"0D*("`@
M(`D)"2D["B`@("`@("`@("`@("`@("`@("`@"B`@("`*("`@("1S97)I86QI
M>F5R(#T@;F5W(%A-3%]397)I86QI>F5R*"1O<'1I;VYS*3L*("`@(`H@("`@
M)')E<W5L="`]("1S97)I86QI>F5R+3YS97)I86QI>F4H)&1A=&$I.PH@("`@
M"B`@("!I9B@@)')E<W5L="`]/3T@=')U92`I('L*"0DD>&UL(#T@)'-E<FEA
M;&EZ97(M/F=E=%-E<FEA;&EZ961$871A*"D["@H)("`@(&5C:&\))SQP<F4^
M)SL*"2`@("!P<FEN=%]R*"!H=&UL<W!E8VEA;&-H87)S*"1X;6PI("D["@D@
M("`@96-H;PDG/"]P<F4^)SL*("`@('T@96QS92!["@D)96-H;PDG/'!R93XG
M.PH)"7!R:6YT7W(H)')E<W5L="D["@D)96-H;PDG/"]P<F4^)SL*"7T*"@DD
M;F5W3W!T:6]N<R`](&%R<F%Y*`H)"0D)"0DG<F]O=$YA;64G(#T^("=B;V1Y
M)RP*"0D)"0D))W)E<&QA8V5%;G1I=&EE<R<@/3X@6$U,7U-%4DE!3$E:15)?
M14Y4251)15-?2%1-3"P*"0D)"0D))W1A9TUA<"<@("`]/B!A<G)A>2@*"0D)
M"0D)("`@("`@("`@("`@("`@("`@("`@("=I=&5M)R`@("`@("`@/3X@)V1I
M=B<L"@D)"0D)"2`@("`@("`@("`@("`@("`@("`@("`G=&ET;&4G("`@("`@
M(#T^("=H,2<L"@D)"0D)"2`@("`@("`@("`@("`@("`@("`@("`G9&5S8W)I
M<'1I;VXG(#T^("=P)RP*"0D)"0D)("`@("`@("`@("`@("`@("`@("`@("=L
M:6YK)R`@("`@("`@/3X@)W1T)PH)"0D)"0D@("`@("`@("`@("`@("`@("`I
M"@D)"0D)*3L*"0H@("`@)')E<W5L="`]("1S97)I86QI>F5R+3YS97)I86QI
M>F4H)&1A=&$L("1N97=/<'1I;VYS*3L*("`@(`H@("`@:68H("1R97-U;'0@
M/3T]('1R=64@*2!["@D))'AM;"`]("1S97)I86QI>F5R+3YG971397)I86QI
M>F5D1&%T82@I.PH*"2`@("!E8VAO"2<\<')E/B<["@D@("`@<')I;G1?<B@@
M:'1M;'-P96-I86QC:&%R<R@D>&UL*2`I.PH)("`@(&5C:&\))SPO<')E/B<[
M"B`@("!](&5L<V4@>PH)"65C:&\))SQP<F4^)SL*"0EP<FEN=%]R*"1R97-U
M;'0I.PH)"65C:&\))SPO<')E/B<["@E]"@H_/@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M
M<&QE<R]U;G-E<FEA;&EZ94%N>5A-3"YP:'``````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4P-C$`,3`U,34T,S,W
M,S4`,#,P,S`R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_4$A0"B\J*@H@*B!4:&ES(&5X86UP;&4@<VAO=W,@9&EF9F5R
M96YT(&UE=&AO9',@:&]W"B`J(%A-3%]5;G-E<FEA;&EZ97(@8V%N(&)E('5S
M960@=&\@8W)E871E(&1A=&$@<W1R=6-T=7)E<PH@*B!F<F]M(%A-3"!D;V-U
M;65N=',N"B`J"B`J($!A=71H;W(@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`
M<&AP+FYE=#X*("HO"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["@HO+R!T:&ES
M(&ES(&$@<VEM<&QE(%A-3"!D;V-U;65N=`HD>&UL(#T@)SQU<V5R<SXG("X*
M("`@("`@("<@(#QU<V5R(&AA;F1L93TB<V-H<W0B/E-T97!H86X@4V-H;6ED
M=#PO=7-E<CXG("X*("`@("`@("<@(#QU<V5R(&AA;F1L93TB;6HB/DUA<G1I
M;B!*86YS96X\+W5S97(^)R`N"B`@("`@("`G("`\9W)O=7`@;F%M93TB<6$B
M/E!%05(@44$@5&5A;3PO9W)O=7`^)R`N"B`@("`@("`G("`\9F]O(&ED/2)T
M97-T(CY4:&ES(&ES(&AA;F1L960@8GD@=&AE(&1E9F%U;'0@:V5Y071T<FEB
M=71E/"]F;V\^)R`N"B`@("`@("`G("`\9F]O(&ED/2)T97-T,B(^06YO=&AE
M<B!F;V\@=&%G/"]F;V\^)R`N"B`@("`@("`G/"]U<V5R<SXG.PH*<F5Q=6ER
M95]O;F-E("=834PO56YS97)I86QI>F5R+G!H<"<["@HO+R!C;VUP;&5X('-T
M<G5C='5R97,@87)E(&%R<F%Y<RP@=&AE(&ME>2!I<R!T:&4@871T<FEB=71E
M("=H86YD;&4G(&]R("=N86UE)RP@:68@:&%N9&QE(&ES(&YO="!P<F5S96YT
M"B1O<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@("`@6$U,7U5.4T52
M24%,25I%4E]/4%1)3TY?0T]-4$Q%6%194$4@/3X@)V%R<F%Y)RP*("`@("`@
M("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]!5%1224)55$5?
M2T59(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=7-E<B<@("`@
M(#T^("=H86YD;&4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9W)O=7`G("`@
M(#T^("=N86UE)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R-D969A=6QT)R`]
M/B`G:60G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`I"B`@("`@("`@("`@("`@("`I
M.PH*+R\@(&)E(&-A<F5F=6P@=&\@86QW87ES('5S92!T:&4@86UP97)S86YD
M(&EN(&9R;VYT(&]F('1H92!N97<@;W!E<F%T;W(@"B1U;G-E<FEA;&EZ97(@
M/2`F;F5W(%A-3%]5;G-E<FEA;&EZ97(H)&]P=&EO;G,I.PH*+R\@=7-E<FEA
M;&EZ92!T:&4@9&]C=6UE;G0*)'-T871U<R`]("1U;G-E<FEA;&EZ97(M/G5N
M<V5R:6%L:7IE*"1X;6PL(&9A;'-E*3L@("`@"@II9B`H4$5!4CHZ:7-%<G)O
M<B@D<W1A='5S*2D@>PH@("`@96-H;R`G17)R;W(Z("<@+B`D<W1A='5S+3YG
M971-97-S86=E*"D["GT@96QS92!["B`@("`D9&%T82`]("1U;G-E<FEA;&EZ
M97(M/F=E=%5N<V5R:6%L:7IE9$1A=&$H*3L*("`@(&5C:&\@)SQP<F4^)SL*
M("`@('!R:6YT7W(H)&1A=&$I.PH@("`@96-H;R`G/"]P<F4^)SL*?0H*"B\O
M('5N<V5R:6%L:7IE(&ET(&%G86EN(&%N9"!C:&%N9V4@=&AE(&-O;7!L97A4
M>7!E(&]P=&EO;@HO+R!B=70@;&5A=F4@;W1H97(@;W!T:6]N<R!U;G1O=6-H
M960*+R\@;F]W(&-O;7!L97@@='EP97,@=VEL;"!B92!A;B!O8FIE8W0L(&%N
M9"!T:&4@<')O<&5R='D@;F%M92!W:6QL(&)E(&EN('1H90HO+R!A='1R:6)U
M=&4@)VAA;F1L92<*)'-T871U<R`]("1U;G-E<FEA;&EZ97(M/G5N<V5R:6%L
M:7IE*"1X;6PL(&9A;'-E+"!A<G)A>2A834Q?54Y315))04Q)6D527T]05$E/
M3E]#3TU03$585%E012`]/B`G;V)J96-T)RDI.PH*:68@*%!%05(Z.FES17)R
M;W(H)'-T871U<RDI('L*("`@(&5C:&\@)T5R<F]R.B`G("X@)'-T871U<RT^
M9V5T365S<V%G92@I.PI](&5L<V4@>PH@("`@)&1A=&$@/2`D=6YS97)I86QI
M>F5R+3YG9715;G-E<FEA;&EZ961$871A*"D["B`@("!E8VAO("<\<')E/B<[
M"B`@("!P<FEN=%]R*"1D871A*3L*("`@(&5C:&\@)SPO<')E/B<["GT*"B\O
M('5N<V5R:6%L:7IE(&ET(&%G86EN(&%N9"!C:&%N9V4@=&AE(&-O;7!L97A4
M>7!E(&]P=&EO;@HO+R!A;F0@<F5S970@86QL(&]T:&5R(&]P=&EO;G,*+R\@
M3F]W+"!T:&5R92=S(&YO(&ME>2!S;R!T:&4@=&%G<R!A<F4@<W1O<F5D(&EN
M(&%N(&%R<F%Y"B1S=&%T=7,@/2`D=6YS97)I86QI>F5R+3YU;G-E<FEA;&EZ
M92@D>&UL+"!F86QS92P@87)R87DH6$U,7U5.4T5224%,25I%4E]/4%1)3TY?
M3U9%4E))1$5?3U!424].4R`]/B!T<G5E+"!834Q?54Y315))04Q)6D527T]0
M5$E/3E]#3TU03$585%E012`]/B`G;V)J96-T)RDI.R`@("`*"FEF("A014%2
M.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("!E8VAO("=%<G)O<CH@)R`N("1S
M=&%T=7,M/F=E=$UE<W-A9V4H*3L*?2!E;'-E('L*("`@("1D871A(#T@)'5N
M<V5R:6%L:7IE<BT^9V5T56YS97)I86QI>F5D1&%T82@I.PH@("`@96-H;R`G
M/'!R93XG.PH@("`@<')I;G1?<B@D9&%T82D["B`@("!E8VAO("<\+W!R93XG
M.PI]"C\^````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W5N<V5R:6%L:7IE
M0VQA<W-.86UE<RYP:'`````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C,P-@`Q,#4Q-30S,S<S-@`P,S$R,C,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]02%`*+RHJ
M"B`J($5X86UP;&4@=&AA="!S:&]W<R!H;W<@=&\@:6YF;'5E;F-E('1H92!C
M;&%S<V5S('1H870@87)E(&-R96%T960N"B`J"B`J($!A=71H;W(@("`@("!3
M=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"YN970^"B`J($!C871E9V]R>2`@
M("!834P*("H@0'!A8VMA9V4@("`@(%A-3%]397)I86QI>F5R"B`J($!S=6)P
M86-K86=E("!%>&%M<&QE<PH@*B\*97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*
M"B\J*@H@*B!U<V5S(%A-3%]5;G-E<FEA;&EZ97(*("HO"G)E<75I<F5?;VYC
M92`G6$U,+U5N<V5R:6%L:7IE<BYP:'`G.PH*)'AM;"`](#P\/$5/5`H\<F]O
M=#X*("`@/&9O;SX*("`@("`\='EP93YB87(\+W1Y<&4^"B`@(#PO9F]O/@H@
M("`\8F%R('1Y<&4](F9O;R(O/@H\+W)O;W0^"D5/5#L*"F-L87-S(&9O;PI[
M"GT*8VQA<W,@8F%R"GL*?0H*96-H;R`G/'!R93XG.PHO+R`@8F4@8V%R969U
M;"!T;R!A;'=A>7,@=7-E('1H92!A;7!E<G-A;F0@:6X@9G)O;G0@;V8@=&AE
M(&YE=R!O<&5R871O<B`*)'5N<V5R:6%L:7IE<B`]("9N97<@6$U,7U5N<V5R
M:6%L:7IE<B@I.PHD=6YS97)I86QI>F5R+3YS971/<'1I;VXH6$U,7U5.4T52
M24%,25I%4E]/4%1)3TY?0T]-4$Q%6%194$4L("=O8FIE8W0G*3L*)'5N<V5R
M:6%L:7IE<BT^<V5T3W!T:6]N*%A-3%]53E-%4DE!3$E:15)?3U!424].7T%4
M5%))0E5415-?4$%24T4L('1R=64I.PHD=6YS97)I86QI>F5R+3YS971/<'1I
M;VXH6$U,7U5.4T5224%,25I%4E]/4%1)3TY?4D5455).7U)%4U5,5"P@=')U
M92D["@HD9&%T82`]("1U;G-E<FEA;&EZ97(M/G5N<V5R:6%L:7IE*"1X;6PI
M.R`@("`*=F%R7V1U;7`H)&1A=&$I.PH*96-H;R`B1&\@;F]T('5S92!T86=N
M86UE(&%S(&-L87-S(&YA;65<;B(["B1U;G-E<FEA;&EZ97(M/G-E=$]P=&EO
M;BA834Q?54Y315))04Q)6D527T]05$E/3E]404=?05-?0TQ!4U-.04U%+"!F
M86QS92D["B1D871A(#T@)'5N<V5R:6%L:7IE<BT^=6YS97)I86QI>F4H)'AM
M;"D[("`@(`IV87)?9'5M<"@@)&1A=&$@*3L*"F5C:&\@(E5S92!A(&1I9F9E
M<F5N="!D969A=6QT(&-L87-S7&XB.PHD=6YS97)I86QI>F5R+3YS971/<'1I
M;VXH6$U,7U5.4T5224%,25I%4E]/4%1)3TY?1$5&055,5%]#3$%34RP@)V9O
M;R<I.PHD9&%T82`]("1U;G-E<FEA;&EZ97(M/G5N<V5R:6%L:7IE*"1X;6PI
M.R`@("`*=F%R7V1U;7`H("1D871A("D["@IE8VAO("<\+W!R93XG.PH_/@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ
M97(O97AA;7!L97,O=6YS97)I86QI>F5%;F-O9&5D+G!H<```````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-C8U`#$P
M-3$U-#,S-S,V`#`S,#4T,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/U!(4`HO*BH*("H@5&AI<R!E>&%M<&QE('-H;W=S
M(&AO=R!T;R!S970@82!D:69F97)E;G0@=&%R9V5T(&5N8V]D:6YG"B`J"B`J
M($!A=71H;W(@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO
M"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["@IR97%U:7)E7V]N8V4@)UA-3"]5
M;G-E<FEA;&EZ97(N<&AP)SL*"B1X;6P@/2`G/&1I8W0^"B`@(#QW;W)D/@H@
M("`@(#QE;CYC:&EC:V5N=VEN9W,\+V5N/@H@("`@(#QD93XG+G5T9CA?96YC
M;V1E*"=(Y&AN8VAE;F9L_&=E;"<I+B<\+V1E/@H@("`\+W=O<F0^"B`\+V1I
M8W0^)SL*("`@(`HO+R!S<&5C:69Y(&1I9F9E<F5N="!S;W5R8V4@86YD('1A
M<F=E="!E;F-O9&EN9W,*)&]P=&EO;G,@/2!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?14Y#3T1)3D=?4T]54D-%
M(#T^("=55$8M."<L"B`@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:
M15)?3U!424].7T5.0T]$24Y'7U1!4D=%5"`]/B`G25-/+3@X-3DM,2<*("`@
M("`@("`@("`@("`@("D["@H@("`@("`@("`@("`@("`@"B\O("!B92!C87)E
M9G5L('1O(&%L=V%Y<R!U<V4@=&AE(&%M<&5R<V%N9"!I;B!F<F]N="!O9B!T
M:&4@;F5W(&]P97)A=&]R(`HD=6YS97)I86QI>F5R(#T@)FYE=R!834Q?56YS
M97)I86QI>F5R*"1O<'1I;VYS*3L*"B\O('5S97)I86QI>F4@=&AE(&1O8W5M
M96YT"B1S=&%T=7,@/2`D=6YS97)I86QI>F5R+3YU;G-E<FEA;&EZ92@D>&UL
M*3L*"FEF("A014%2.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("!E8VAO("=%
M<G)O<CH@)R`N("1S=&%T=7,M/F=E=$UE<W-A9V4H*3L*?2!E;'-E('L*("`@
M("1D871A(#T@)'5N<V5R:6%L:7IE<BT^9V5T56YS97)I86QI>F5D1&%T82@I
M.PH@("`@96-H;R`G/'!R93XG.PH@("`@<')I;G1?<B@D9&%T82D["B`@("!E
M8VAO("<\+W!R93XG.PI]"C\^````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E
M<FEA;&EZ97(O97AA;7!L97,O=6YS97)I86QI>F5%;G5M+G!H<```````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R
M,C0S`#$P-3$U-#,S-S,V`#`S,#`W-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/U!(4`HO*BH*("H@5&AI<R!E>&%M<&QE
M('-H;W=S(&AO=R!T;R!U<V4@=&AE(%A-3%]53E-%4DE!3$E:15)?3U!424].
M7T9/4D-%7T5.54T*("H@;W!T:6]N"B`J"B`J($!A=71H;W(@(%-T97!H86X@
M4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO"F5R<F]R7W)E<&]R=&EN9RA%
M7T%,3"D["@IR97%U:7)E7V]N8V4@)UA-3"]5;G-E<FEA;&EZ97(N<&AP)SL*
M"B1X;6PQ(#T@)SQR;V]T/@H@("`\:71E;3X*("`@("`\;F%M93YS8VAS=#PO
M;F%M93X*("`@/"]I=&5M/@H@("`\:71E;3X*("`@("`\;F%M93YL=6-K96,\
M+VYA;64^"B`@(#PO:71E;3X*(#PO<F]O=#XG.PH@("`@"B1X;6PR(#T@)SQR
M;V]T/@H@("`\:71E;3X*("`@("`\;F%M93YS8VAS=#PO;F%M93X*("`@/"]I
M=&5M/@H@/"]R;V]T/B<["B`@("`*)&]P=&EO;G,@/2!A<G)A>2@*("`@("`@
M("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?1D]20T5?14Y5
M32`]/B!A<G)A>2@G:71E;2<I"B`@("`@("`@("`@("`@("`I.PH*("`@("`@
M("`@("`@("`@(`HO+R`@8F4@8V%R969U;"!T;R!A;'=A>7,@=7-E('1H92!A
M;7!E<G-A;F0@:6X@9G)O;G0@;V8@=&AE(&YE=R!O<&5R871O<B`*)'5N<V5R
M:6%L:7IE<B`]("9N97<@6$U,7U5N<V5R:6%L:7IE<B@D;W!T:6]N<RD["@HO
M+R!U<V5R:6%L:7IE('1H92!D;V-U;65N=`HD<W1A='5S(#T@)'5N<V5R:6%L
M:7IE<BT^=6YS97)I86QI>F4H)'AM;#$I.PH*:68@*%!%05(Z.FES17)R;W(H
M)'-T871U<RDI('L*("`@(&5C:&\@)T5R<F]R.B`G("X@)'-T871U<RT^9V5T
M365S<V%G92@I.PI](&5L<V4@>PH@("`@)&1A=&$@/2`D=6YS97)I86QI>F5R
M+3YG9715;G-E<FEA;&EZ961$871A*"D["B`@("!E8VAO("<\<')E/B<["B`@
M("!P<FEN=%]R*"1D871A*3L*("`@(&5C:&\@)SPO<')E/B<["GT*"B\O('5S
M97)I86QI>F4@=&AE(&1O8W5M96YT"B1S=&%T=7,@/2`D=6YS97)I86QI>F5R
M+3YU;G-E<FEA;&EZ92@D>&UL,BD["@II9B`H4$5!4CHZ:7-%<G)O<B@D<W1A
M='5S*2D@>PH@("`@96-H;R`G17)R;W(Z("<@+B`D<W1A='5S+3YG971-97-S
M86=E*"D["GT@96QS92!["B`@("`D9&%T82`]("1U;G-E<FEA;&EZ97(M/F=E
M=%5N<V5R:6%L:7IE9$1A=&$H*3L*("`@(&5C:&\@)SQP<F4^)SL*("`@('!R
M:6YT7W(H)&1A=&$I.PH@("`@96-H;R`G/"]P<F4^)SL*?0H_/@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]U;G-E
M<FEA;&EZ94]B:F5C="YP:'``````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(W,#``,3`U,34T,S,W,S8`,#,P,S<V
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M4$A0"B\J*@H@*B!4:&ES(&5X86UP;&4@<VAO=W,@:&]W(%A-3%]397)I86QI
M>F5R(&%N9"!834Q?56YS97)I86QI>F5R"B`J('=O<FL@=&]G971H97(N"B`J
M"B`J($$@<W1R=6-T=7)E(&ES('-E<FEA;&EZ960@86YD(&QA=&5R(&ET)W,@
M=6YS97)I86QI>F5D(&9R;VT@=&AE"B`J(')E<W5L=&EN9R!834P@9&]C=6UE
M;G0N"B`J"B`J($!A=71H;W(@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP
M+FYE=#X*("HO"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["@IR97%U:7)E7V]N
M8V4@)UA-3"]397)I86QI>F5R+G!H<"<["G)E<75I<F5?;VYC92`G6$U,+U5N
M<V5R:6%L:7IE<BYP:'`G.PHO+R!T:&ES(&ES(&IU<W0@=&\@9V5T(&$@;F5S
M=&5D(&]B:F5C=`HD<&5A<D5R<F]R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G5&AI
M<R!I<R!J=7-T(&%N(&5R<F]R(&]B:F5C="<L,3(S*3L*"B1O<'1I;VYS(#T@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!4
M24].7TE.1$5.5"`@("`@(#T^("<@("`@)RP*("`@("`@("`@("`@("`@("`@
M("!834Q?4T5224%,25I%4E]/4%1)3TY?3$E.14)214%+4R`@/3X@(EQN(BP*
M("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?1$5&
M055,5%]404<@/3X@)W5N;F%M961)=&5M)RP*("`@("`@("`@("`@("`@("`@
M("!834Q?4T5224%,25I%4E]/4%1)3TY?5%E014A)3E13("`@/3X@=')U90H@
M("`@("`@("`@("`@("`@*3L*"B1F;V\@/2!N97<@<W1D0VQA<W,H*3L*)&9O
M;RT^=F%L=64@/2`G37D@=F%L=64G.PHD9F]O+3YE<G)O<B`]("1P96%R17)R
M;W(["B1F;V\M/GAM;"`@(#T@87)R87DH)U1H:7,@:7,G(#T^("=C;V]L)RD[
M"B1F;V\M/G)E<V]U<F-E(#T@9F]P96XH7U]&24Q%7U\L("=R)RD["@HD<V5R
M:6%L:7IE<B`](&YE=R!834Q?4V5R:6%L:7IE<B@D;W!T:6]N<RD["B1R97-U
M;'0@/2`D<V5R:6%L:7IE<BT^<V5R:6%L:7IE*"1F;V\I.PH*:68@*"1R97-U
M;'0@/3T]('1R=64I('L*("`@("1X;6P@/2`D<V5R:6%L:7IE<BT^9V5T4V5R
M:6%L:7IE9$1A=&$H*3L*?0H*96-H;R`G/'!R93XG.PIE8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)'AM;"D["F5C:&\@)SPO<')E/B<["@HO+R`@8F4@8V%R969U
M;"!T;R!A;'=A>7,@=7-E('1H92!A;7!E<G-A;F0@:6X@9G)O;G0@;V8@=&AE
M(&YE=R!O<&5R871O<B`*)'5N<V5R:6%L:7IE<B`]("9N97<@6$U,7U5N<V5R
M:6%L:7IE<B@I.PH*)'-T871U<R`]("1U;G-E<FEA;&EZ97(M/G5N<V5R:6%L
M:7IE*"1X;6PI.R`@("`*"FEF("A014%2.CII<T5R<F]R*"1S=&%T=7,I*2![
M"B`@("!E8VAO("=%<G)O<CH@)R`N("1S=&%T=7,M/F=E=$UE<W-A9V4H*3L*
M?2!E;'-E('L*("`@("1D871A(#T@)'5N<V5R:6%L:7IE<BT^9V5T56YS97)I
M86QI>F5D1&%T82@I.PH@("`@96-H;R`G/'!R93XG.PH@("`@<')I;G1?<B@D
M9&%T82D["B`@("!E8VAO("<\+W!R93XG.PI]"C\^````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]3
M97)I86QI>F5R+V5X86UP;&5S+W5N<V5R:6%L:7IE4D1&+G!H<```````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-#$R,@`Q,#4Q-30S,S<S-@`P,C<V,#,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]02%`*+RHJ"B`J(%1H:7,@97AA;7!L
M92!S:&]W<R!H;W<@=&\@8W)E871E(&%N>2!O8FIE8W0*("H@9G)O;2!A;B!8
M34P@9&]C=6UE;G0N($EN('1H:7,@8V%S92!W92!G970*("H@<V]M92!A9V=R
M96=A=&5D(&]B:F5C=',@9F]R(&-H86YN96P@86YD(&ET96US"B`J(&9R;VT@
M86X@4E-3(&9E960N"B`J"B`J($!A=71H;W(@(%-T97!H86X@4V-H;6ED="`\
M<V-H<W1`<&AP+FYE=#X*("HO"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["@IR
M97%U:7)E7V]N8V4@)UA-3"]5;G-E<FEA;&EZ97(N<&AP)SL*"B\J*@HJ(&-L
M87-S(&9O<B!T:&4@4D1&(&1O8W5E;6YT"BH**@HJ+PIC;&%S<R!R9&9$;V-U
M;65N=`I["B`@("!V87(@)&-H86YN96P["B`@("!V87(@)&ET96T["@H@("`@
M9G5N8W1I;VX@9V5T271E;7,H)&%M;W5N="D*("`@('L*("`@("`@("!R971U
M<FX@87)R87E?<W!L:6-E*"1T:&ES+3YI=&5M+#`L)&%M;W5N="D["B`@("!]
M"GT*"@HO*BH**B!C;&%S<R!T:&%T(&ES('5S960@9F]R(&$@8VAA;FYE;"!I
M;B!T:&4@4E-3(&9I;&4**@HJ('EO=2!C;W5L9"!I;7!L96UE;G0@=VAA=&5V
M97(@>6]U(&QI:V4@:6X@=&AI<R!C;&%S<RP**B!P<F]P97)T:65S('=I;&P@
M8F4@<V5T(&9R;VT@=&AE(%A-3"!D;V-U;65N=`HJ+PIC;&%S<R!C:&%N;F5L
M"GL*("`@(&9U;F-T:6]N(&=E=%1I=&QE*"D*("`@('L*("`@("`@("!R971U
M<FX@("1T:&ES+3YT:71L93L*("`@('T*?0H*+RHJ"BH@8VQA<W,@=&AA="!I
M<R!U<V5D(&9O<B!A;B!I=&5M(&EN('1H92!24U,@9FEL90HJ"BH@>6]U(&-O
M=6QD(&EM<&QE;65N="!W:&%T979E<B!Y;W4@;&EK92!I;B!T:&ES(&-L87-S
M+`HJ('!R;W!E<G1I97,@=VEL;"!B92!S970@9G)O;2!T:&4@6$U,(&1O8W5M
M96YT"BHO"F-L87-S(&ET96T*>PH@("`@9G5N8W1I;VX@9V5T5&ET;&4H*0H@
M("`@>PH@("`@("`@(')E='5R;B`@)'1H:7,M/G1I=&QE.PH@("`@?0I]"@H*
M)&]P=&EO;G,@/2!A<G)A>2@*("`@("`@("`@("`@("`@("!834Q?54Y315))
M04Q)6D527T]05$E/3E]#3TU03$585%E012`]/B`G;V)J96-T)RP*("`@("`@
M("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]404=?34%0("`@
M("`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)D9CI21$8G(#T^("=R9&9$
M;V-U;65N="<L("`@+R\@=&AI<R!I<R!U<V5D('1O('-P96-I9GD@82!C;&%S
M<VYA;64@9F]R('1H92!R;V]T('1A9PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("D*("`@("`@("`@
M("`@("`@("D["@HO+R`@8F4@8V%R969U;"!T;R!A;'=A>7,@=7-E('1H92!A
M;7!E<G-A;F0@:6X@9G)O;G0@;V8@=&AE(&YE=R!O<&5R871O<B`*)'5N<V5R
M:6%L:7IE<B`]("9N97<@6$U,7U5N<V5R:6%L:7IE<B@D;W!T:6]N<RD["@HD
M<W1A='5S(#T@)'5N<V5R:6%L:7IE<BT^=6YS97)I86QI>F4H)VAT='`Z+R]P
M96%R+G!H<"YN970O9F5E9',O;&%T97-T+G)S<R<L=')U92D[("`@(`H*:68@
M*%!%05(Z.FES17)R;W(H)'-T871U<RDI('L*("`@(&5C:&\@)T5R<F]R.B`G
M("X@)'-T871U<RT^9V5T365S<V%G92@I.PI](&5L<V4@>PH@("`@)')S<R`]
M("1U;G-E<FEA;&EZ97(M/F=E=%5N<V5R:6%L:7IE9$1A=&$H*3L*"B`@("!E
M8VAO("=4:&ES(&AA<R!B965N(')E='5R;F5D(&)Y(%A-3%]5;G-E<FEA;&EZ
M97(Z/&)R/B<["B`@("`*("`@(&5C:&\@)SQP<F4^)SL*("`@('!R:6YT7W(H
M)')S<RD["B`@("!E8VAO("<\+W!R93XG.PH*("`@(&5C:&\@)SQB<CX\8G(^
M4F]O="!486=N86UE.B`G+B1U;G-E<FEA;&EZ97(M/F=E=%)O;W1.86UE*"DN
M)SQB<CXG.PH@("`@"B`@("!E8VAO("=4:71L92!O9B!T:&4@8VAA;FYE;#H@
M)RXD<G-S+3YC:&%N;F5L+3YG9714:71L92@I+B<\8G(^)SL*"B`@("`D:71E
M;7,@/2`D<G-S+3YG971)=&5M<R@S*3L*("`@(&5C:&\@)SQB<CY4:71L97,@
M;V8@=&AE(&QA<W0@=&AR964@<F5L96%S97,Z/&)R/B<["B`@("!F;W)E86-H
M("@D:71E;7,@87,@)&ET96TI('L*("`@("`@("!E8VAO("=4:71L92`Z("<N
M)&ET96TM/F=E=%1I=&QE*"DN)SQB<CXG.PH@("`@?0I]"C\^````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W5N<V5R:6%L:7IE5VAI
M=&5S<&%C92YP:'`````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C$S,``Q,#4Q-30S,S<S-@`P,S$R-C$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]02%`*+RHJ"B`J
M(%1H:7,@97AA;7!L92!S:&]W<R!H;W<@=&\@<V5T(&$@9&EF9F5R96YT('1A
M<F=E="!E;F-O9&EN9PH@*@H@*B!`875T:&]R("!3=&5P:&%N(%-C:&UI9'0@
M/'-C:'-T0'!H<"YN970^"B`J+PIE<G)O<E]R97!O<G1I;F<H15]!3$PI.PH*
M<F5Q=6ER95]O;F-E("=834PO56YS97)I86QI>F5R+G!H<"<["@HD>&UL(#T@
M)SQX;6P^"B`@(#QS=')I;F<^"B`@(`H@("`@5&AI<R!834P*("`@(&1O8W5M
M96YT"B`@("!C;VYT86EN<PH@("`@;&EN92!B<F5A:W,N"@H@("`\+W-T<FEN
M9SX*(#PO>&UL/B<["@H*+R\@(&)E(&-A<F5F=6P@=&\@86QW87ES('5S92!T
M:&4@86UP97)S86YD(&EN(&9R;VYT(&]F('1H92!N97<@;W!E<F%T;W(@"B1U
M;G-E<FEA;&EZ97(@/2`F;F5W(%A-3%]5;G-E<FEA;&EZ97(H*3L*)'5N<V5R
M:6%L:7IE<BT^<V5T3W!T:6]N*%A-3%]53E-%4DE!3$E:15)?3U!424].7U)%
M5%523E]215-53%0L('1R=64I.PH*96-H;R`G/'!R93XG.PH*96-H;R`B1&5F
M875L="!B96AA=FEO<B`H6$U,7U5.4T5224%,25I%4E]72$E415-004-%7U12
M24TI7&XB.PHD9&%T82`]("1U;G-E<FEA;&EZ97(M/G5N<V5R:6%L:7IE*"1X
M;6PI.PIV87)?9'5M<"@D9&%T82D["F5C:&\@(EQN7&XB.PH*96-H;R`B3F]R
M;6%L:7IE('=H:71E<W!A8V4@*%A-3%]53E-%4DE!3$E:15)?5TA)5$534$%#
M15].3U)-04Q)6D4I7&XB.PHD=6YS97)I86QI>F5R+3YS971/<'1I;VXH6$U,
M7U5.4T5224%,25I%4E]/4%1)3TY?5TA)5$534$%#12P@6$U,7U5.4T5224%,
M25I%4E]72$E415-004-%7TY/4DU!3$E:12D["B1D871A(#T@)'5N<V5R:6%L
M:7IE<BT^=6YS97)I86QI>F4H)'AM;"D["G9A<E]D=6UP*"1D871A*3L*96-H
M;R`B7&Y<;B(["@IE8VAO(")+965P('=H:71E<W!A8V4@*%A-3%]53E-%4DE!
M3$E:15)?5TA)5$534$%#15]+1450*5QN(CL*)'5N<V5R:6%L:7IE<BT^<V5T
M3W!T:6]N*%A-3%]53E-%4DE!3$E:15)?3U!424].7U=(251%4U!!0T4L(%A-
M3%]53E-%4DE!3$E:15)?5TA)5$534$%#15]+1450*3L*)&1A=&$@/2`D=6YS
M97)I86QI>F5R+3YU;G-E<FEA;&EZ92@D>&UL*3L*=F%R7V1U;7`H)&1A=&$I
M.PH*96-H;R`G/"]P<F4^)SL*/SX`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O
M97AA;7!L97,O=6YS97)I86QI>F57:71H071T<FEB=71E<RYP:'``````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-#,T`#$P-3$U
M-#,S-S,V`#`S,C$U-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/U!(4`HO*BH*("H@5&AI<R!E>&%M<&QE('-H;W=S(&AO
M=R!T;R!P87)S92!A='1R:6)U=&5S(&9R;VT*("H@6$U,('1A9W,N"B`J"B`J
M($!A=71H;W(@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("H@
M0'5S97,@("`@97AA;7!L92YX;6P*("HO"F5R<F]R7W)E<&]R=&EN9RA%7T%,
M3"D["@IR97%U:7)E7V]N8V4@)UA-3"]5;G-E<FEA;&EZ97(N<&AP)SL*"B1O
M<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!
M3$E:15)?3U!424].7T%45%))0E5415-?4$%24T4@("`@/3X@=')U92P*("`@
M("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"
M551%4U]!4E)!64M%62`]/B!F86QS90H@("`@("`@("`@("`@("`@*3L*"B\O
M("!B92!C87)E9G5L('1O(&%L=V%Y<R!U<V4@=&AE(&%M<&5R<V%N9"!I;B!F
M<F]N="!O9B!T:&4@;F5W(&]P97)A=&]R(`HD=6YS97)I86QI>F5R(#T@)FYE
M=R!834Q?56YS97)I86QI>F5R*"1O<'1I;VYS*3L*"B\O('5S97)I86QI>F4@
M=&AE(&1O8W5M96YT"B1S=&%T=7,@/2`D=6YS97)I86QI>F5R+3YU;G-E<FEA
M;&EZ92@G97AA;7!L92YX;6PG+"!T<G5E*3L*"FEF("A014%2.CII<T5R<F]R
M*"1S=&%T=7,I*2!["B`@("!E8VAO("=%<G)O<CH@)R`N("1S=&%T=7,M/F=E
M=$UE<W-A9V4H*3L*?2!E;'-E('L*("`@("1D871A(#T@)'5N<V5R:6%L:7IE
M<BT^9V5T56YS97)I86QI>F5D1&%T82@I.PH@("`@96-H;R`G/'!R93XG.PH@
M("`@<')I;G1?<B@D9&%T82D["B`@("!E8VAO("<\+W!R93XG.PI]"C\^````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA
M;&EZ97(O97AA;7!L97,O=6YS97)I86QI>F57:71H5&%G36%P+G!H<```````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,3<U
M`#$P-3$U-#,S-S,V`#`S,3(P-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/U!(4`HO*BH*("H@5&AI<R!E>&%M<&QE('-H
M;W=S(&AO=R!T;R!U<V4@=&AE('1A9TUA<"!O<'1I;VXN"B`J"B`J($!A=71H
M;W(@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO"F5R<F]R
M7W)E<&]R=&EN9RA%7T%,3"D["@HO+R!T:&ES(&ES(&$@<VEM<&QE(%A-3"!D
M;V-U;65N=`HD>&UL(#T@)SQR;V]T/B<@+@H@("`@("`@)R`@/&9O;SY&3T\\
M+V9O;SXG("X*("`@("`@("<@(#QB87(^0D%2/"]B87(^)R`N"B`@("`@("`G
M/"]R;V]T/B<["@IR97%U:7)E7V]N8V4@)UA-3"]5;G-E<FEA;&EZ97(N<&AP
M)SL*"B\O(&-O;7!L97@@<W1R=6-T=7)E<R!A<F4@87)R87ES+"!T:&4@:V5Y
M(&ES('1H92!A='1R:6)U=&4@)VAA;F1L92<@;W(@)VYA;64G+"!I9B!H86YD
M;&4@:7,@;F]T('!R97-E;G0*)&]P=&EO;G,@/2!A<G)A>2@*("`@("`@("`@
M("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]#3TU03$585%E012`]
M/B`G87)R87DG+`H@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?
M3U!424].7U1!1U]-05`@("`@(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M9F]O)R`]/B`G8F%R)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V)A<B<@/3X@)V9O;R<*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`I"B`@("`@("`@("`@("`@("`I.PH*+R\@(&)E(&-A
M<F5F=6P@=&\@86QW87ES('5S92!T:&4@86UP97)S86YD(&EN(&9R;VYT(&]F
M('1H92!N97<@;W!E<F%T;W(@"B1U;G-E<FEA;&EZ97(@/2`F;F5W(%A-3%]5
M;G-E<FEA;&EZ97(H)&]P=&EO;G,I.PH*+R\@=7-E<FEA;&EZ92!T:&4@9&]C
M=6UE;G0*)'-T871U<R`]("1U;G-E<FEA;&EZ97(M/G5N<V5R:6%L:7IE*"1X
M;6PL(&9A;'-E*3L@("`@"@II9B`H4$5!4CHZ:7-%<G)O<B@D<W1A='5S*2D@
M>PH@("`@96-H;R`G17)R;W(Z("<@+B`D<W1A='5S+3YG971-97-S86=E*"D[
M"GT@96QS92!["B`@("`D9&%T82`]("1U;G-E<FEA;&EZ97(M/F=E=%5N<V5R
M:6%L:7IE9$1A=&$H*3L*("`@(&5C:&\@)SQP<F4^)SL*("`@('!R:6YT7W(H
M)&1A=&$I.PH@("`@96-H;R`G/"]P<F4^)SL*?0H*+R\@82!T860@;6]R92!C
M;VUP;&5X"B1X;6P@/2`G/')O;W0^)R`N"B`@("`@("`G("`\9F]O/B<N"B`@
M("`@("`G("`@(#QT;VUA=&\^-#4\+W1O;6%T;SXG+@H@("`@("`@)R`@/"]F
M;V\^)RX*("`@("`@("<@(#QB87(^)RX*("`@("`@("<@("`@/'1O;6%T;SXS
M,3PO=&]M871O/B<N"B`@("`@("`G("`\+V)A<CXG+@H@("`@("`@)SPO<F]O
M=#XG.PH*+R\@=7-E<FEA;&EZ92!T:&4@9&]C=6UE;G0*)'-T871U<R`]("1U
M;G-E<FEA;&EZ97(M/G5N<V5R:6%L:7IE*"1X;6PL(&9A;'-E*3L@("`@"@II
M9B`H4$5!4CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@96-H;R`G17)R;W(Z
M("<@+B`D<W1A='5S+3YG971-97-S86=E*"D["GT@96QS92!["B`@("`D9&%T
M82`]("1U;G-E<FEA;&EZ97(M/F=E=%5N<V5R:6%L:7IE9$1A=&$H*3L*("`@
M(&5C:&\@)SQP<F4^)SL*("`@('!R:6YT7W(H)&1A=&$I.PH@("`@96-H;R`G
M/"]P<F4^)SL*?0H_/@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R
M+V5X86UP;&5S+W5N<V5R:6%L:7IE5VET:%1Y<&5'=65S<VEN9RYP:'``````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,38V-@`Q,#4Q
M-30S,S<S-@`P,S(T-C0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]02%`*+RHJ"B`J($5X86UP;&4@=&AA="!S:&]W<R!H
M;W<@=&\@=7-E(%A-3%]5;G-E<FEA;&EZ97(@=&\*("H@875T;VUA=&EC86QL
M>2!A9&IU<W0@=&AE('1Y<&4@;V8@=&AE(&1A=&$*("H*("H@0&%U=&AO<B`@
M("`@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("H@0&-A=&5G
M;W)Y("`@(%A-3`H@*B!`<&%C:V%G92`@("`@6$U,7U-E<FEA;&EZ97(*("H@
M0'-U8G!A8VMA9V4@($5X86UP;&5S"B`J+PIE<G)O<E]R97!O<G1I;F<H15]!
M3$PI.PH*+RHJ"B`J('5S97,@6$U,7U5N<V5R:6%L:7IE<@H@*B\*<F5Q=6ER
M95]O;F-E("<N+B]5;G-E<FEA;&EZ97(N<&AP)SL*"B1X;6P@/2`\/#Q%3U0*
M/')O;W0^"B`@(#QS=')I;F<^2G5S="!A('-T<FEN9RXN+CPO<W1R:6YG/@H@
M("`\8F]O;&5A;E9A;'5E/G1R=64\+V)O;VQE86Y686QU93X*("`@/&9O;SXM
M-38S/"]F;V\^"B`@(#QB87(^-"XW,S<S-CPO8F%R/@H@("`\87)R87D@9F]O
M/2)F86QS92(@8F%R/2(Q,B(^=')U93PO87)R87D^"CPO<F]O=#X*14]4.PH*
M)'5N<V5R:6%L:7IE<B`]("9N97<@6$U,7U5N<V5R:6%L:7IE<B@I.PHD=6YS
M97)I86QI>F5R+3YS971/<'1I;VXH6$U,7U5.4T5224%,25I%4E]/4%1)3TY?
M0T]-4$Q%6%194$4L("=A<G)A>2<I.PHD=6YS97)I86QI>F5R+3YS971/<'1I
M;VXH6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"551%4U]005)312P@
M=')U92D["B1U;G-E<FEA;&EZ97(M/G-E=$]P=&EO;BA834Q?54Y315))04Q)
M6D527T]05$E/3E]215154DY?4D5354Q4+"!T<G5E*3L*)'5N<V5R:6%L:7IE
M<BT^<V5T3W!T:6]N*%A-3%]53E-%4DE!3$E:15)?3U!424].7T=515-37U19
M4$53+"!T<G5E*3L*"B1D871A(#T@)'5N<V5R:6%L:7IE<BT^=6YS97)I86QI
M>F4H)'AM;"D[("`@(`IE8VAO("<\<')E/B<["G9A<E]D=6UP*"1D871A*3L*
M96-H;R`G/"]P<F4^)SL*/SX`````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]5=&EL
M+P``````````````````````````````````````````````````````````
M```````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#4Q-30S,S<S-0`P,C$Q-S(`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+V1O8W,O6$U,7U5T:6PO97AA;7!L97,O````````````````````````
M`````````````````````````````````````#`P,#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S,U`#`R,S`Q,``@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?571I;"]E>&%M<&QE<R]E
M>&%M<&QE+G!H<```````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,38P-C``,3`U,34T,S,W
M,S4`,#(U,34W`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_4$A0#0HO*BH-"B`J('-E=F5R86P@97AA;7!L97,@9F]R('1H
M92!M971H;V1S(&]F(%A-3%]5=&EL#0H@*@T*("H@)$ED.B!E>&%M<&QE+G!H
M<"QV(#$N,3(@,C`P-"\Q,B\R,R`Q,SHR,CHP,"!S8VAS="!%>'`@)`T*("H-
M"B`J($!A=71H;W(@("`@("!3=&5P:&%N(%-C:&UI9'0-"B`J($!P86-K86=E
M("`@("!834Q?571I;`T*("H@0'-U8G!A8VMA9V4@(&5X86UP;&5S#0H@*B!`
M8V%T96=O<GD@("`@6$U,#0H@*B\-"B`@("!E<G)O<E]R97!O<G1I;F<H15]!
M3$PI.PT*#0H@("`@<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G.PT*("`@
M(`T*("`@("\J*@T*("`@("H@<F5P;&%C:6YG(%A-3"!E;G1I=&EE<PT*("`@
M("HO#0H@("`@<')I;G0@(G)E<&QA8V4@6$U,(&5N=&ET:65S.CQB<CY<;B([
M#0H@("`@<')I;G0@6$U,7U5T:6PZ.G)E<&QA8V5%;G1I=&EE<R@B5&AI<R!S
M=')I;F<@8V]N=&%I;G,@/"`F(#XN(BD[#0H@("`@<')I;G0@(EQN/&)R/CQB
M<CY<;B([#0H-"B`@("`O*BH-"B`@("`J(')E=F5R<VEN9R!834P@96YT:71I
M97,-"B`@("`J+PT*("`@('!R:6YT(")R97!L86-E(%A-3"!E;G1I=&EE<SH\
M8G(^7&XB.PT*("`@('!R:6YT(%A-3%]5=&EL.CIR979E<G-E16YT:71I97,H
M(E1H:7,@<W1R:6YG(&-O;G1A:6YS("9L=#L@)F%M<#L@)F=T.RXB*3L-"B`@
M("!P<FEN="`B7&X\8G(^/&)R/EQN(CL-"@T*("`@("\J*@T*("`@("H@8G5I
M;&1I;F<@6$U,(&1E8VQA<F%T:6]N#0H@("`@*B\-"B`@("!P<FEN="`B8G5I
M;&1I;F<@6$U,(&1E8VQA<F%T:6]N.CQB<CY<;B([#0H@("`@<')I;G0@:'1M
M;'-P96-I86QC:&%R<RA834Q?571I;#HZ9V5T6$U,1&5C;&%R871I;VXH*2D[
M#0H@("`@<')I;G0@(EQN/&)R/CQB<CY<;B([#0H-"B`@("!P<FEN="`B8G5I
M;&1I;F<@6$U,(&1E8VQA<F%T:6]N('=I=&@@861D:71I;VYA;"!A='1R:6)U
M=&5S.CQB<CXB.PT*("`@('!R:6YT(&AT;6QS<&5C:6%L8VAA<G,H6$U,7U5T
M:6PZ.F=E=%A-3$1E8VQA<F%T:6]N*"(Q+C`B+"`B551&+3@B+"!T<G5E*2D[
M#0H@("`@<')I;G0@(EQN/&)R/CQB<CY<;B([#0H-"B`@("`O*BH-"B`@("`J
M(&)U:6QD:6YG(&1O8W5M96YT('1Y<&4@9&5C;&%R871I;VX-"B`@("`J+PT*
M("`@('!R:6YT(")B=6EL9&EN9R!$;V-4>7!E(&1E8VQA<F%T:6]N.CQB<CY<
M;B([#0H@("`@<')I;G0@:'1M;'-P96-I86QC:&%R<RA834Q?571I;#HZ9V5T
M1&]C5'EP941E8VQA<F%T:6]N*"=P86-K86=E)RP@)VAT='`Z+R]P96%R+G!H
M<"YN970O9'1D+W!A8VMA9V4M,2XP)RDI.PT*("`@('!R:6YT(")<;CQB<CX\
M8G(^7&XB.PT*#0H@("`@<')I;G0@(F)U:6QD:6YG($1O8U1Y<&4@9&5C;&%R
M871I;VX@=VET:"!P=6)L:6,@240@*&1O97,@;F]T(&5X:7-T*3H\8G(^7&XB
M.PT*("`@('!R:6YT(&AT;6QS<&5C:6%L8VAA<G,H6$U,7U5T:6PZ.F=E=$1O
M8U1Y<&5$96-L87)A=&EO;B@G<&%C:V%G92<L(&%R<F%Y*"=U<FDG(#T^("=H
M='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]P86-K86=E+3$N,"<L("=I9"<@/3X@
M)RTO+U!(4"\O4$5!4B]$5$0@4$%#2T%'12`P+C$G*2DI.PT*("`@('!R:6YT
M(")<;CQB<CX\8G(^7&XB.PT*#0H@("`@<')I;G0@(F)U:6QD:6YG($1O8U1Y
M<&4@9&5C;&%R871I;VX@=VET:"!I;G1E<FYA;"!$5$0Z/&)R/EQN(CL-"B`@
M("!P<FEN="`B/'!R93XB.PT*("`@('!R:6YT(&AT;6QS<&5C:6%L8VAA<G,H
M6$U,7U5T:6PZ.F=E=$1O8U1Y<&5$96-L87)A=&EO;B@G<&%C:V%G92<L("=H
M='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]P86-K86=E+3$N,"<L("<\(45,14U%
M3E0@861D:71I;VYA;$EN9F\@*"-00T1!5$$I/B<I*3L-"B`@("!P<FEN="`B
M/"]P<F4^(CL-"B`@("!P<FEN="`B7&X\8G(^/&)R/EQN(CL-"@T*("`@("\J
M*@T*("`@("H@8W)E871I;F<@86X@871T<FEB=71E('-T<FEN9PT*("`@("HO
M#0H@("`@)&%T="`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@(F9O;R(@
M("`]/B`@(F)A<B(L#0H@("`@("`@("`@("`@("`@("`B87)G:"(@(#T^("`B
M=&]M871O(@T*("`@("`@("`@("`@("`@("D[#0H-"B`@("!P<FEN="`B8V]N
M=F5R=&EN9R!A<G)A>2!T;R!S=')I;F<Z/&)R/EQN(CL-"B`@("!P<FEN="!8
M34Q?571I;#HZ871T<FEB=71E<U1O4W1R:6YG*"1A='0I.PT*("`@('!R:6YT
M(")<;CQB<CX\8G(^7&XB.PT*#0H-"B`@("`O*BH-"B`@("`J(&-R96%T:6YG
M(&%N(&%T=')I8G5T92!S=')I;F<@=VET:"!L:6YE8G)E86MS#0H@("`@*B\-
M"B`@("`D871T(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`B9F]O(B`@
M(#T^("`B8F%R(BP-"B`@("`@("`@("`@("`@("`@(")A<F=H(B`@/3X@(")T
M;VUA=&\B#0H@("`@("`@("`@("`@("`@*3L-"@T*("`@('!R:6YT(")C;VYV
M97)T:6YG(&%R<F%Y('1O('-T<FEN9R`H:6YC;'5D:6YG(&QI;F4@8G)E86MS
M*3H\8G(^7&XB.PT*("`@('!R:6YT("(\<')E/B([#0H@("`@<')I;G0@6$U,
M7U5T:6PZ.F%T=')I8G5T97-4;U-T<FEN9R@D871T+"!T<G5E+"!T<G5E*3L-
M"B`@("!P<FEN="`B/"]P<F4^(CL-"B`@("!P<FEN="`B7&X\8G(^/&)R/EQN
M(CL-"@T*#0H@("`@+RHJ#0H@("`@*B!S<&QI='1I;F<@82!Q=6%L:69I960@
M=&%G(&YA;64-"B`@("`J+PT*("`@('!R:6YT(")S<&QI='1I;F<@<75A;&EF
M:65D('1A9R!N86UE.CQB<CY<;B([#0H@("`@<')I;G0@(CQP<F4^(CL-"B`@
M("!P<FEN=%]R*%A-3%]5=&EL.CIS<&QI=%%U86QI9FEE9$YA;64H(GAS;'0Z
M<W1Y;&5S:&5E="(I*3L-"B`@("!P<FEN="`B/"]P<F4^(CL-"B`@("!P<FEN
M="`B7&X\8G(^7&XB.PT*#0H-"B`@("`O*BH-"B`@("`J('-P;&ET=&EN9R!A
M('%U86QI9FEE9"!T86<@;F%M92`H;F\@;F%M97-P86-E*0T*("`@("HO#0H@
M("`@<')I;G0@(G-P;&ET=&EN9R!Q=6%L:69I960@=&%G(&YA;64@*&YO(&YA
M;65S<&%C92DZ/&)R/EQN(CL-"B`@("!P<FEN="`B/'!R93XB.PT*("`@('!R
M:6YT7W(H6$U,7U5T:6PZ.G-P;&ET475A;&EF:65D3F%M92@B9F]O(BDI.PT*
M("`@('!R:6YT("(\+W!R93XB.PT*("`@('!R:6YT(")<;CQB<CY<;B([#0H-
M"B`@("`O*BH-"B`@("`J('-P;&ET=&EN9R!A('%U86QI9FEE9"!T86<@;F%M
M92`H;F\@;F%M97-P86-E+"!B=70@9&5F875L="!N86UE<W!A8V4@<W!E8VEF
M:65D*0T*("`@("HO#0H@("`@<')I;G0@(G-P;&ET=&EN9R!Q=6%L:69I960@
M=&%G(&YA;64@*&YO(&YA;65S<&%C92P@8G5T(&1E9F%U;'0@;F%M97-P86-E
M('-P96-I9FEE9"DZ/&)R/EQN(CL-"B`@("!P<FEN="`B/'!R93XB.PT*("`@
M('!R:6YT7W(H6$U,7U5T:6PZ.G-P;&ET475A;&EF:65D3F%M92@B9F]O(BP@
M(F)A<B(I*3L-"B`@("!P<FEN="`B/"]P<F4^(CL-"B`@("!P<FEN="`B7&X\
M8G(^7&XB.PT*#0H@("`@+RHJ#0H@("`@*B!V97)I9GEI;F<@6$U,(&YA;65S
M#0H@("`@*B\-"B`@("!P<FEN="`B=F5R:69Y:6YG("=->2!P<FEV871E('1A
M9R<Z/&)R/EQN(CL-"B`@("!P<FEN="`B/'!R93XB.PT*("`@('!R:6YT7W(H
M6$U,7U5T:6PZ.FES5F%L:61N86UE*"=->2!0<FEV871E(%1A9R<I*3L-"B`@
M("!P<FEN="`B/"]P<F4^(CL-"B`@("!P<FEN="`B7&X\8G(^/&)R/EQN(CL-
M"B`@("`-"B`@("!P<FEN="`B=F5R:69Y:6YG("<M37E486<G.CQB<CY<;B([
M#0H@("`@<')I;G0@(CQP<F4^(CL-"B`@("!P<FEN=%]R*%A-3%]5=&EL.CII
M<U9A;&ED;F%M92@G+4UY5&%G)RDI.PT*("`@('!R:6YT("(\+W!R93XB.PT*
M("`@('!R:6YT(")<;CQB<CX\8G(^7&XB.PT*#0H@("`@+RHJ#0H@("`@*B!C
M<F5A=&EN9R!A;B!834P@=&%G#0H@("`@*B\-"B`@("`D=&%G(#T@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`B;F%M97-P86-E(B`@(#T^(")F;V\B+`T*
M("`@("`@("`@("`@("`@("`@(FQO8V%L4&%R="(@("`]/B`B8F%R(BP-"B`@
M("`@("`@("`@("`@("`@(")A='1R:6)U=&5S(B`@/3X@87)R87DH(")K97DB
M(#T^(")V86QU92(L(")A<F=H(B`]/B`B9G)U:70F=F5G971A8FQE(B`I+`T*
M("`@("`@("`@("`@("`@("`@(F-O;G1E;G0B("`@("`]/B`B22=M(&EN<VED
M92!T:&4@=&%G(@T*("`@("`@("`@("`@("`@("D[#0H-"B`@("!P<FEN="`B
M8W)E871I;F<@82!T86<@=VET:"!N86UE<W!A8V4@86YD(&QO8V%L('!A<G0Z
M/&)R/B([#0H@("`@<')I;G0@:'1M;&5N=&ET:65S*%A-3%]5=&EL.CIC<F5A
M=&5486=&<F]M07)R87DH)'1A9RDI.PT*("`@('!R:6YT(")<;CQB<CX\8G(^
M7&XB.PT*#0H@("`@+RHJ#0H@("`@*B!C<F5A=&EN9R!A;B!834P@=&%G#0H@
M("`@*B\-"B`@("`D=&%G(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`B
M<6YA;64B("`@("`@("`]/B`B9F]O.F)A<B(L#0H@("`@("`@("`@("`@("`@
M("`B;F%M97-P86-E57)I(B`]/B`B:'1T<#HO+V9O;RYC;VTB+`T*("`@("`@
M("`@("`@("`@("`@(F%T=')I8G5T97,B("`@/3X@87)R87DH(")K97DB(#T^
M(")V86QU92(L(")A<F=H(B`]/B`B9G)U:70F=F5G971A8FQE(B`I+`T*("`@
M("`@("`@("`@("`@("`@(F-O;G1E;G0B("`@("`@/3X@(DDG;2!I;G-I9&4@
M=&AE('1A9R(-"B`@("`@("`@("`@("`@("`I.PT*#0H@("`@<')I;G0@(F-R
M96%T:6YG(&$@=&%G('=I=&@@<75A;&EF:65D(&YA;64@86YD(&YA;65S<&%C
M955R:3H\8G(^7&XB.PT*("`@('!R:6YT(&AT;6QE;G1I=&EE<RA834Q?571I
M;#HZ8W)E871E5&%G1G)O;4%R<F%Y*"1T86<I*3L-"B`@("!P<FEN="`B7&X\
M8G(^/&)R/EQN(CL-"@T*("`@("\J*@T*("`@("H@8W)E871I;F<@86X@6$U,
M('1A9PT*("`@("HO#0H@("`@)'1A9R`](&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("`@(G%N86UE(B`@("`@("`@/3X@(F)A<B(L#0H@("`@("`@("`@("`@
M("`@("`B;F%M97-P86-E57)I(B`]/B`B:'1T<#HO+V9O;RYC;VTB+`T*("`@
M("`@("`@("`@("`@("`@(F%T=')I8G5T97,B("`@/3X@87)R87DH(")K97DB
M(#T^(")V86QU92(L(")A<F=H(B`]/B`B9G)U:70F=F5G971A8FQE(B`I#0H@
M("`@("`@("`@("`@("`@*3L-"@T*("`@('!R:6YT(")C<F5A=&EN9R!A;B!E
M;7!T>2!T86<@=VET:&]U="!N86UE<W!A8V4@8G5T(&YA;65S<&%C92!5<FDZ
M/&)R/EQN(CL-"B`@("!P<FEN="!H=&UL96YT:71I97,H6$U,7U5T:6PZ.F-R
M96%T951A9T9R;VU!<G)A>2@D=&%G*2D[#0H@("`@<')I;G0@(EQN/&)R/CQB
M<CY<;B([#0H-"B`@("`O*BH-"B`@("`J(&-R96%T:6YG(&%N(%A-3"!T86<@
M=VET:"!A($-$871A(%-E8W1I;VX-"B`@("`J+PT*("`@("1T86<@/2!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`@(")Q;F%M92(@("`@("`@(#T^(")F;V\B
M+`T*("`@("`@("`@("`@("`@("`@(F%T=')I8G5T97,B("`@/3X@87)R87DH
M(")K97DB(#T^(")V86QU92(L(")A<F=H(B`]/B`B9G)U:70F=F5G971A8FQE
M(B`I+`T*("`@("`@("`@("`@("`@("`@(F-O;G1E;G0B("`@("`@/3X@(DDG
M;2!I;G-I9&4@=&AE('1A9R(-"B`@("`@("`@("`@("`@("`I.PT*#0H@("`@
M<')I;G0@(F-R96%T:6YG(&$@=&%G('=I=&@@0T1A=&$@<V5C=&EO;CH\8G(^
M7&XB.PT*("`@('!R:6YT(&AT;6QE;G1I=&EE<RA834Q?571I;#HZ8W)E871E
M5&%G1G)O;4%R<F%Y*"1T86<L(%A-3%]55$E,7T-$051!7U-%0U1)3TXI*3L-
M"B`@("!P<FEN="`B7&X\8G(^/&)R/EQN(CL-"@T*("`@("\J*@T*("`@("H@
M8W)E871I;F<@86X@6$U,('1A9R!W:71H(&$@0T1A=&$@4V5C=&EO;@T*("`@
M("HO#0H@("`@)'1A9R`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@(G%N
M86UE(B`@("`@("`@/3X@(F9O;R(L#0H@("`@("`@("`@("`@("`@("`B871T
M<FEB=71E<R(@("`]/B!A<G)A>2@@(FME>2(@/3X@(G9A;'5E(BP@(F%R9V@B
M(#T^(")T_'3\(B`I+`T*("`@("`@("`@("`@("`@("`@(F-O;G1E;G0B("`@
M("`@/3X@(D%L<V\@6$A434PM=&%G<R!C86X@8F4@8W)E871E9"!A;F0@2%1-
M3"!E;G1I=&EE<R!C86X@8F4@<F5P;&%C960@Q"#D(-P@]B`\/BXB#0H@("`@
M("`@("`@("`@("`@*3L-"@T*("`@('!R:6YT(")C<F5A=&EN9R!A('1A9R!W
M:71H($A434P@96YT:71I97,Z/&)R/EQN(CL-"B`@("!P<FEN="!H=&UL96YT
M:71I97,H6$U,7U5T:6PZ.F-R96%T951A9T9R;VU!<G)A>2@D=&%G+"!834Q?
M551)3%]%3E1)5$E%4U](5$U,*2D[#0H@("`@<')I;G0@(EQN/&)R/CQB<CY<
M;B([#0H-"B`@("`O*BH-"B`@("`J(&-R96%T:6YG(&%N(%A-3"!T86<@=VET
M:"!C<F5A=&5486<-"B`@("`J+PT*("`@('!R:6YT(")C<F5A=&EN9R!A('1A
M9R!W:71H(&-R96%T951A9SH\8G(^(CL-"B`@("!P<FEN="!H=&UL96YT:71I
M97,H6$U,7U5T:6PZ.F-R96%T951A9R@B;7E.<SIM>51A9R(L(&%R<F%Y*")F
M;V\B(#T^(")B87(B*2P@(E1H:7,@:7,@:6YS:61E('1H92!T86<B+"`B:'1T
M<#HO+W=W=RYW,V,N;W)G+VUY3G,C(BDI.PT*("`@('!R:6YT(")<;CQB<CX\
M8G(^7&XB.PT*#0H@("`@#0H@("`@+RHJ#0H@("`@*B!T<GEI;F<@=&\@8W)E
M871E(&%N(%A-3"!T86<@=VET:"!A;B!A<G)A>2!A<R!C;VYT96YT#0H@("`@
M*B\-"B`@("`D=&%G(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`B<6YA
M;64B("`@("`@("`]/B`B8F%R(BP-"B`@("`@("`@("`@("`@("`@(")C;VYT
M96YT(B`@("`@(#T^(&%R<F%Y*"`B9F]O(B`]/B`B8F%R(B`I#0H@("`@("`@
M("`@("`@("`@*3L-"B`@("!P<FEN="`B=')Y:6YG('1O(&-R96%T92!A;B!8
M34P@=&%G('=I=&@@86X@87)R87D@87,@8V]N=&5N=#H\8G(^7&XB.PT*("`@
M('!R:6YT("(\<')E/B([#0H@("`@<')I;G1?<BA834Q?571I;#HZ8W)E871E
M5&%G1G)O;4%R<F%Y*"1T86<I*3L-"B`@("!P<FEN="`B/"]P<F4^(CL-"B`@
M("!P<FEN="`B7&X\8G(^/&)R/EQN(CL-"B`@("`-"B`@("`O*BH-"B`@("`J
M('1R>6EN9R!T;R!C<F5A=&4@86X@6$U,('1A9R!W:71H;W5T(&$@;F%M90T*
M("`@("HO#0H@("`@)'1A9R`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@
M(F%T=')I8G5T97,B("`@/3X@87)R87DH(")F;V\B(#T^(")B87(B("DL#0H@
M("`@("`@("`@("`@("`@*3L-"B`@("!P<FEN="`B=')Y:6YG('1O(&-R96%T
M92!A;B!834P@=&%G('=I=&AO=70@82!N86UE.CQB<CY<;B([#0H@("`@<')I
M;G0@(CQP<F4^(CL-"B`@("!P<FEN=%]R*%A-3%]5=&EL.CIC<F5A=&5486=&
M<F]M07)R87DH)'1A9RDI.PT*("`@('!R:6YT("(\+W!R93XB.PT*("`@('!R
M:6YT(")<;CQB<CX\8G(^7&XB.PT*/SX`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]5=&EL+V5X86UP;&5S
M+V5X86UP;&4R+G!H<```````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3<P-0`Q,#4Q-30S
M,S<S-0`P,C4R-#4`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]02%`-"B\J*@T*("H@<V5V97)A;"!E>&%M<&QE<R!F;W(@
M=&AE(&UE=&AO9',@;V8@6$U,7U5T:6P-"B`J#0H@*B`D260Z(&5X86UP;&4R
M+G!H<"QV(#$N."`R,#`T+S`V+S(W(#$X.C$W.C,Y('-C:'-T($5X<"`D#0H@
M*@T*("H@0&%U=&AO<B`@("`@(%-T97!H86X@4V-H;6ED=`T*("H@0'!A8VMA
M9V4@("`@(%A-3%]5=&EL#0H@*B!`<W5B<&%C:V%G92`@97AA;7!L97,-"B`J
M($!C871E9V]R>2`@("!834P-"B`J+PT*("`@(&5R<F]R7W)E<&]R=&EN9RA%
M7T%,3"D[#0H-"B`@("!R97%U:7)E7V]N8V4@)UA-3"]5=&EL+G!H<"<[#0H-
M"B`@("`O*BH-"B`@("`J(&-R96%T:6YG(&$@<W1A<G0@96QE;65N=`T*("`@
M("HO#0H@("`@<')I;G0@(F-R96%T:6YG(&$@<W1A<G0@96QE;65N=#H\8G(^
M(CL-"B`@("!P<FEN="!H=&UL96YT:71I97,H6$U,7U5T:6PZ.F-R96%T95-T
M87)T16QE;65N="@B;7E.<SIM>51A9R(L(&%R<F%Y*")F;V\B(#T^(")B87(B
M*2P@(FAT='`Z+R]W=W<N=S-C+F]R9R]M>4YS(R(I*3L-"B`@("!P<FEN="`B
M7&X\8G(^/&)R/EQN(CL-"@T*#0H@("`@+RHJ#0H@("`@*B!C<F5A=&EN9R!A
M('-T87)T(&5L96UE;G0-"B`@("`J+PT*("`@('!R:6YT(")C<F5A=&EN9R!A
M('-T87)T(&5L96UE;G0Z/&)R/B([#0H@("`@<')I;G0@:'1M;&5N=&ET:65S
M*%A-3%]5=&EL.CIC<F5A=&53=&%R=$5L96UE;G0H(FUY5&%G(BP@87)R87DH
M*2P@(FAT='`Z+R]W=W<N=S-C+F]R9R]M>4YS(R(I*3L-"B`@("!P<FEN="`B
M7&X\8G(^/&)R/EQN(CL-"@T*("`@("\J*@T*("`@("H@8W)E871I;F<@82!S
M=&%R="!E;&5M96YT#0H@("`@*B\-"B`@("!P<FEN="`B8W)E871I;F<@82!S
M=&%R="!E;&5M96YT.CQB<CXB.PT*("`@('!R:6YT("(\<')E/B([#0H@("`@
M<')I;G0@:'1M;&5N=&ET:65S*%A-3%]5=&EL.CIC<F5A=&53=&%R=$5L96UE
M;G0H(FUY5&%G(BP@87)R87DH(")F;V\B(#T^(")B87(B+"`B87)G:"(@/3X@
M(G1O;6%T;R(@*2P@(FAT='`Z+R]W=W<N=S-C+F]R9R]M>4YS(R(L('1R=64I
M*3L-"B`@("!P<FEN="`B/"]P<F4^(CL-"B`@("!P<FEN="`B7&X\8G(^/&)R
M/EQN(CL-"@T*#0H@("`@+RHJ#0H@("`@*B!C<F5A=&EN9R!A;B!E;F0@96QE
M;65N=`T*("`@("HO#0H@("`@<')I;G0@(F-R96%T:6YG(&%N(&5N9"!E;&5M
M96YT.CQB<CXB.PT*("`@('!R:6YT(&AT;6QE;G1I=&EE<RA834Q?571I;#HZ
M8W)E871E16YD16QE;65N="@B;7E.<SIM>51A9R(I*3L-"B`@("!P<FEN="`B
M7&X\8G(^/&)R/EQN(CL-"@T*("`@("\J*@T*("`@("H@8W)E871I;F<@82!#
M1&%T82!S96-T:6]N#0H@("`@*B\-"B`@("!P<FEN="`B8W)E871I;F<@82!#
M1&%T82!S96-T:6]N.CQB<CXB.PT*("`@('!R:6YT(&AT;6QE;G1I=&EE<RA8
M34Q?571I;#HZ8W)E871E0T1A=&%396-T:6]N*"))(&%M(&-O;G1E;G0N(BDI
M.PT*("`@('!R:6YT(")<;CQB<CX\8G(^7&XB.PT*#0H@("`@+RHJ#0H@("`@
M*B!C<F5A=&EN9R!A(&-O;6UE;G0-"B`@("`J+PT*("`@('!R:6YT(")C<F5A
M=&EN9R!A(&-O;6UE;G0Z/&)R/B([#0H@("`@<')I;G0@:'1M;&5N=&ET:65S
M*%A-3%]5=&EL.CIC<F5A=&5#;VUM96YT*"))(&%M(&$@8V]M;65N="XB*2D[
M#0H@("`@<')I;G0@(EQN/&)R/CQB<CY<;B([#0H-"B`@("`O*BH-"B`@("`J
M(&-R96%T:6YG(&%N(%A-3"!T86<@=VET:"!M=6QT:6QI;F4@;6]D90T*("`@
M("HO#0H@("`@)'1A9R`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@(G%N
M86UE(B`@("`@("`@/3X@(F9O;SIB87(B+`T*("`@("`@("`@("`@("`@("`@
M(FYA;65S<&%C955R:2(@/3X@(FAT='`Z+R]F;V\N8V]M(BP-"B`@("`@("`@
M("`@("`@("`@(")A='1R:6)U=&5S(B`@(#T^(&%R<F%Y*"`B:V5Y(B`]/B`B
M=F%L=64B+"`B87)G:"(@/3X@(F9R=6ET)G9E9V5T86)L92(@*2P-"B`@("`@
M("`@("`@("`@("`@(")C;VYT96YT(B`@("`@(#T^(")))VT@:6YS:61E('1H
M92!T86<@)B!C;VYT86EN(&1A;F=E<F]U<R!C:&%R<R(-"B`@("`@("`@("`@
M("`@("`I.PT*#0H@("`@<')I;G0@(F-R96%T:6YG(&$@=&%G('=I=&@@<75A
M;&EF:65D(&YA;64@86YD(&YA;65S<&%C955R:3H\8G(^7&XB.PT*("`@('!R
M:6YT("(\<')E/B([#0H@("`@<')I;G0@:'1M;&5N=&ET:65S*%A-3%]5=&EL
M.CIC<F5A=&5486=&<F]M07)R87DH)'1A9RP@6$U,7U5424Q?4D503$%#15]%
M3E1)5$E%4RP@=')U92DI.PT*("`@('!R:6YT("(\+W!R93XB.PT*("`@('!R
M:6YT(")<;CQB<CX\8G(^7&XB.PT*#0H@("`@+RHJ#0H@("`@*B!C<F5A=&4@
M86X@871T<FEB=71E('-T<FEN9R!W:71H;W5T(')E<&QA8VEN9R!T:&4@96YT
M:71I97,-"B`@("`J+PT*("`@("1A='1S(#T@87)R87DH("=S97)I97,G(#T^
M("=3=&%R<VMY("9A;7`[($AU=&-H)RP@)V-H86YN96PG(#T^("=!0D,G("D[
M#0H@("`@<')I;G0@(F-R96%T:6YG(&$@871T<FEB=71E('-T<FEN9RP@96YT
M:71I97,@:6X@=F%L=65S(&%L<F5A9'D@:&%D(&)E96X@<F5P;&%C960Z/&)R
M/B([#0H@("`@<')I;G0@:'1M;&5N=&ET:65S*%A-3%]5=&EL.CIA='1R:6)U
M=&5S5&]3=')I;F<H)&%T=',L('1R=64L(&9A;'-E+"!F86QS92P@9F%L<V4L
M(%A-3%]55$E,7T5.5$E424537TY/3D4I*3L-"B`@("!P<FEN="`B7&X\8G(^
M/&)R/EQN(CL-"@T*("`@("\J*@T*("`@("H@=7-I;F<@=&AE(&%R<F%Y+7-Y
M;G1A>"!F;W(@871T<FEB=71E<U1O4W1R:6YG*"D-"B`@("`J+PT*("`@("1A
M='1S(#T@87)R87DH("=S97)I97,G(#T^("=3=&%R<VMY("9A;7`[($AU=&-H
M)RP@)V-H86YN96PG(#T^("=!0D,G("D[#0H@("`@<')I;G0@(G5S:6YG('1H
M92!A<G)A>2US>6YT87@@9F]R(&%T=')I8G5T97-4;U-T<FEN9R@I/&)R/B([
M#0H@("`@<')I;G0@:'1M;&5N=&ET:65S*%A-3%]5=&EL.CIA='1R:6)U=&5S
M5&]3=')I;F<H)&%T=',L(&%R<F%Y*"=E;G1I=&EE<R<@/3X@6$U,7U5424Q?
M14Y4251)15-?3D].12DI*3L-"B`@("!P<FEN="`B7&X\8G(^/&)R/EQN(CL-
M"@T*#0H_/@``````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+T9I;&4O````````````````````````````````````````````
M`````````````````````````````````````````#`P,#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S,W`#`Q-S0V-@`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O1FEL92]#4U8N<&AP````````````
M````````````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#`V,#``,3`U,34T
M,S,W,S<`,#(P-C,R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P
M/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@1FEL
M93HZ0U-6"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.
M4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N
M,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ
M"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N
M<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E
M8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S
M;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`
M8V%T96=O<GD@("`@1FEL90H@*B!`<&%C:V%G92`@("`@1FEL90H@*B!`875T
M:&]R("`@("`@5&]M87,@5BY6+D-O>"`\8V]X0&ED96-N970N8V]M/@H@*B!`
M875T:&]R("`@("`@2&5L9VD@WF]R;6%R(#QD=69U>D!P:'`N;F5T/@H@*B!`
M8V]P>7)I9VAT("`@,C`P-"TR,#`U(%1H92!!=71H;W)S"B`J($!L:6-E;G-E
M("`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@
M3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@($-64SH@)$ED.B!#4U8N<&AP
M+'8@,2XR-"`R,#`U+S`X+S`Y(#`X.C$V.C`R(&1U9G5Z($5X<"`D"B`J($!L
M:6YK("`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1FEL90H@
M*B\*"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PIR97%U:7)E7V]N8V4@)T9I
M;&4N<&AP)SL*"B\J*@HJ($9I;&4@8VQA<W,@9F]R(&AA;F1L:6YG($-35B!F
M:6QE<R`H0V]M;6$@4V5P87)A=&5D(%9A;'5E<RDL(&$@8V]M;6]N(&9O<FUA
M=`HJ(&9O<B!E>&-H86YG:6YG(&1A=&$N"BH**B!43T1/.@HJ("`M(%5S86=E
M(&5X86UP;&4@86YD($1O8PHJ("`M(%5S92!G9710;VEN=&5R*"D@:6X@9&ES
M8V]V97)&;W)M870**B`@+2!!9&0@82!L:6YE(&-O=6YT97(@9F]R(&)E:6YG
M(&%B;&4@=&\@;W5T<'5T(&)E='1E<B!E<G)O<B!R97!O<G1S"BH@("T@4W1O
M<F4@=&AE(&QA<W0@97)R;W(@:6X@1TQ/0D%,4R!A;F0@861D($9I;&5?0U-6
M.CIG971,87-T17)R;W(H*0HJ"BH@5VES:#H**B`@+2!/=&AE<B!M971H;V1S
M(&QI:V4@<F5A9$%L;"@I+"!W<FET94%L;"@I+"!N=6U&:65L9',H*2P@;G5M
M4F]W<R@I"BH@("T@5')Y('1O(&1E=&5C="!I9B!A($-35B!H87,@:&5A9&5R
M(&]R(&YO="!I;B!D:7-C;W9E<D9O<FUA="@I"BH**B!+;F]W;B!"=6=S.@HJ
M("AT:&5Y(&AA<R!B965N(&%N86QY>F5D(&)U="!F;W(@=&AE(&UO;65N="!T
M:&4@:6UP86-T(&EN('1H92!S<&5E9"!F;W(**B`@<')O<&5R;'D@:&%N9&QE
M('1H:7,@=6YC;VUM;VX@8V%S97,@:7,@=&]O(&AI9V@@86YD('=O;B=T(&)E
M('-U<'!O<G1E9"D**B`@+2!!(&9I96QD('=H:6-H(&ES(&-O;7!O<V5D(&]N
M;'D@8GD@82!S:6YG;&4@<75O=&5D('-E<&%R871O<B`H:64@+3X@.R([(CLI
M"BH@("`@:7,@;F]T(&AA;F1L960@<')O<&5R;'D**B`@+2!7:&5N('1H97)E
M(&ES(&5X86-T;'D@;VYE(&9I96QD(&UI;G5S('1H86X@=&AE(&5X<&5C=&5D
M(&YU;6)E<B!A;F0@=&AE<F4**B`@("!I<R!A(&9I96QD('=I=&@@82!S97!A
M<F%T;W(@:6YS:61E+"!T:&4@<&%R<V5R('=I;&P@=&AR;W<@=&AE(")W<F]N
M9R!C;W5N="(@97)R;W(**@HJ($!A=71H;W(@5&]M87,@5BY6+D-O>"`\8V]X
M0&ED96-N970N8V]M/@HJ($!A=71H;W(@("`@("!(96QG:2#>;W)M87(@/&1U
M9G5Z0'!H<"YN970^"BH@0'!A8VMA9V4@1FEL90HJ+PIC;&%S<R!&:6QE7T-3
M5@I["B`@("`O*BH*("`@("H@5&AI<R!R86ES945R<F]R(&UE=&AO9"!W;W)K
M<R!I;B!A(&1I9F9E<F5N="!W87DN($ET('=I;&P@86QW87ES(')E='5R;@H@
M("`@*B!F86QS92`H86X@97)R;W(@;V-C=7)R960I(&)U="!I="!W:6QL(&-A
M;&P@4$5!4CHZ<F%I<V5%<G)O<B@I(&)E9F]R90H@("`@*B!I="X@268@;F\@
M9&5F875L="!014%2(&=L;V)A;"!H86YD;&5R(&ES('-E="P@=VEL;"!T<FEG
M9V5R(&%N(&5R<F]R+@H@("`@*@H@("`@*B!`<&%R86T@<W1R:6YG("1E<G)O
M<B!4:&4@97)R;W(@;65S<V%G90H@("`@*B!`<F5T=7)N(&)O;VP@86QW87ES
M(&9A;'-E"B`@("`J+PH@("`@9G5N8W1I;VX@<F%I<V5%<G)O<B@D97)R;W(I
M"B`@("!["B`@("`@("`@+R\@268@82!D969A=6QT(%!%05(@17)R;W(@:&%N
M9&QE<B!I<R!N;W0@<V5T('1R:6=G97(@=&AE(&5R<F]R"B`@("`@("`@+R\@
M6%A8($%D9"!A(%!%05(Z.FES4V5T2&%N9&QE<B@I(&UE=&AO9#\*("`@("`@
M("!I9B`H)$=,3T)!3%-;)U]014%27V1E9F%U;'1?97)R;W)?;6]D92==(#T]
M(%!%05)?15)23U)?4D5455).*2!["B`@("`@("`@("`@(%!%05(Z.G)A:7-E
M17)R;W(H)&5R<F]R+"!N=6QL+"!014%27T524D]27U1224='15(L($5?55-%
M4E]705).24Y'*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!014%2
M.CIR86ES945R<F]R*"1E<G)O<BD["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("H@0VAE8VMS('1H92!C;VYF
M:6=U<F%T:6]N(&=I=F5N(&)Y('1H92!U<V5R"B`@("`J"B`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@*B!`<&%R86T@<W1R:6YG("8D97)R;W(@5&AE(&5R
M<F]R('=I;&P@8F4@=W)I='1E;B!H97)E(&EF(&%N>0H@("`@*B!`<&%R86T@
M87)R87D@("8D8V]N9B`@5&AE(&-O;F9I9W5R871I;VX@87-S;V,@87)R87D*
M("`@("H@0')E='5R;B!S=')I;F<@97)R;W(@("`@4F5T=7)N<R!A(&5R<F]R
M(&UE<W-A9V4*("`@("HO"B`@("!F=6YC=&EO;B!?8V]N9B@F)&5R<F]R+"`F
M)&-O;F8I"B`@("!["B`@("`@("`@+R\@8VAE8VL@8V]N9@H@("`@("`@(&EF
M("@A:7-?87)R87DH)&-O;F8I*2!["B`@("`@("`@("`@(')E='5R;B`D97)R
M;W(@/2`G26YV86QI9"!C;VYF:6=U<F%T:6]N)SL*("`@("`@("!]"@H@("`@
M("`@(&EF("@A:7-S970H)&-O;F9;)V9I96QD<R==*2!\?"`A:7-?;G5M97)I
M8R@D8V]N9ELG9FEE;&1S)UTI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R
M;W(@/2`G5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC("AT
M:&4@(F9I96QD<R(@:V5Y*2<["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S
M970H)&-O;F9;)W-E<"==*2D@>PH@("`@("`@("`@("!I9B`H<W1R;&5N*"1C
M;VYF6R=S97`G72D@(3T@,2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1E
M<G)O<B`]("=397!A<F%T;W(@8V%N(&]N;'D@8F4@;VYE(&-H87(G.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*"1C;VYF6R=F:65L9',G72`^
M(#$I('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<B`]("=-:7-S:6YG('-E
M<&%R871O<B`H=&AE(")S97`B(&ME>2DG.PH@("`@("`@('T*"B`@("`@("`@
M:68@*&ES<V5T*"1C;VYF6R=Q=6]T92==*2D@>PH@("`@("`@("`@("!I9B`H
M<W1R;&5N*"1C;VYF6R=Q=6]T92==*2`A/2`Q*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)&5R<F]R(#T@)U1H92!Q=6]T92!C:&%R(&UU<W0@8F4@;VYE
M(&-H87(@*'1H92`B<75O=&4B(&ME>2DG.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&-O;F9;)W%U;W1E)UT@/2!N=6QL
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<W-E="@D8V]N9ELG8W)L9B==
M*2D@>PH@("`@("`@("`@("`D8V]N9ELG8W)L9B==(#T@(EQN(CL*("`@("`@
M("!]"@H@("`@("`@(&EF("@A:7-S970H)&-O;F9;)V5O;#)U;FEX)UTI*2![
M"B`@("`@("`@("`@("1C;VYF6R=E;VPR=6YI>"==(#T@=')U93L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`J(%)E='5R;B!O<B!C<F5A=&4@=&AE
M(&9I;&4@9&5S8W)I<'1O<B!A<W-O8VEA=&5D('=I=&@@82!F:6QE"B`@("`J
M"B`@("`J($!P87)A;2!S=')I;F<@)&9I;&4@5&AE(&YA;64@;V8@=&AE(&9I
M;&4*("`@("H@0'!A<F%M(&%R<F%Y("`F)&-O;F8@5&AE(&-O;F9I9W5R871I
M;VX*("`@("H@0'!A<F%M('-T<FEN9R`D;6]D92!4:&4@;W!E;B!N;V1E("AE
M>#H@1DE,15]-3T1%7U)%040@;W(@1DE,15]-3T1%7U=2251%*0H@("`@*B!`
M<&%R86T@8F]O;&5A;B`D<F5S970@:68@<&%S<V5D(&%S('1R=64@86YD(')E
M<V]U<F-E(&9O<B!T:&4@9FEL92!E>&ES=',*("`@("H@("`@("`@("`@("`@
M("`@("`@("`@('1H86X@=&AE(&9I;&4@<&]I;G1E<B!W:6QL(&)E(&UO=F5D
M('1O('1H92!B96=I;FYI;F<*("`@("H*("`@("H@0')E='5R;B!M:7AE9"!!
M(&9I;&4@<F5S;W5R8V4@;W(@9F%L<V4*("`@("HO"B`@("!F=6YC=&EO;B!G
M9710;VEN=&5R*"1F:6QE+"`F)&-O;F8L("1M;V1E(#T@1DE,15]-3T1%7U)%
M040L("1R97-E="`](&9A;'-E*0H@("`@>PH@("`@("`@('-T871I8R`D<F5S
M;W5R8V5S("`](&%R<F%Y*"D["B`@("`@("`@<W1A=&EC("1C;VYF:6<["B`@
M("`@("`@:68@*&ES<V5T*"1R97-O=7)C97-;)&9I;&5=*2D@>PH@("`@("`@
M("`@("`D8V]N9B`]("1C;VYF:6<["B`@("`@("`@("`@(&EF("@D<F5S970I
M('L*("`@("`@("`@("`@("`@(&9S965K*"1R97-O=7)C97-;)&9I;&5=+"`P
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)')E<V]U<F-E
M<ULD9FEL95T["B`@("`@("`@?0H@("`@("`@($9I;&5?0U-6.CI?8V]N9B@D
M97)R;W(L("1C;VYF*3L*("`@("`@("!I9B`H)&5R<F]R*2!["B`@("`@("`@
M("`@(')E='5R;B!&:6QE7T-35CHZ<F%I<V5%<G)O<B@D97)R;W(I.PH@("`@
M("`@('T*("`@("`@("`D8V]N9FEG(#T@)&-O;F8["B`@("`@("`@4$5!4CHZ
M<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PH@("`@("`@
M("1F<"`]("9&:6QE.CI?9V5T1FEL95!O:6YT97(H)&9I;&4L("1M;V1E*3L*
M("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D["B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&9P*2D@>PH@("`@("`@("`@("!R971U<FX@1FEL
M95]#4U8Z.G)A:7-E17)R;W(H)&9P*3L*("`@("`@("!]"B`@("`@("`@)')E
M<V]U<F-E<ULD9FEL95T@/2`D9G`["@H@("`@("`@(&EF("@D;6]D92`]/2!&
M24Q%7TU/1$5?4D5!1"`F)B`A96UP='DH)&-O;F9;)VAE861E<B==*2D@>PH@
M("`@("`@("`@("!I9B`H(49I;&5?0U-6.CIR96%D*"1F:6QE+"`D8V]N9BDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!R971U<FX@)&9P.PH@("`@?0H*("`@("\J
M*@H@("`@*B!5;G%U;W1E(&1A=&$*("`@("H*("`@("H@0'!A<F%M('-T<FEN
M9R`D9FEE;&0@5&AE(&1A=&$@=&\@=6YQ=6]T90H@("`@*B!`<&%R86T@<W1R
M:6YG("1Q=6]T92!4:&4@<75O=&4@8VAA<@H@("`@*B!`<F5T=7)N('-T<FEN
M9R!T:&4@=6YQ=6]T960@9&%T80H@("`@*B\*("`@(&9U;F-T:6]N('5N<75O
M=&4H)&9I96QD+"`D<75O=&4I"B`@("!["B`@("`@("`@+R\@5')I;2!F:7)S
M="!T:&4@<W1R:6YG+@H@("`@("`@("1F:65L9"`]('1R:6TH)&9I96QD*3L*
M("`@("`@("`D<75O=&4@/2!T<FEM*"1Q=6]T92D["@H@("`@("`@("\O($EN
M8V%S92!N=6QL(&9I96QD<R`H9F]R;3H@.SLI"B`@("`@("`@:68@*"%S=')L
M96XH)&9I96QD*2D@>PH@("`@("`@("`@("!R971U<FX@)&9I96QD.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"1Q=6]T92`F)B`D9FEE;&1[,'T@/3T@)'%U
M;W1E("8F("1F:65L9'MS=')L96XH)&9I96QD*2TQ?2`]/2`D<75O=&4I('L*
M("`@("`@("`@("`@<F5T=7)N('-U8G-T<B@D9FEE;&0L(#$L("TQ*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1F:65L9#L*("`@('T*"B`@("`O*BH*
M("`@("H@4F5A9',@82!R;W<@;V8@9&%T82!A<R!A;B!A<G)A>2!F<F]M(&$@
M0U-6(&9I;&4N($ET)W,@86)L92!T;PH@("`@*B!R96%D(&UE;6\@9FEE;&1S
M('=I=&@@;75L=&EL:6YE(&1A=&$N"B`@("`J"B`@("`J($!P87)A;2!S=')I
M;F<@)&9I;&4@("!4:&4@9FEL96YA;64@=VAE<F4@=&\@=W)I=&4@=&AE(&1A
M=&$*("`@("H@0'!A<F%M(&%R<F%Y("`F)&-O;F8@("!4:&4@8V]N9FEG=7)A
M=&EO;B!O9B!T:&4@9&5S="!#4U8*("`@("H*("`@("H@0')E='5R;B!M:7AE
M9"!!<G)A>2!W:71H('1H92!D871A(')E860@;W(@9F%L<V4@;VX@97)R;W(O
M;F\@;6]R92!D871A"B`@("`J+PH@("`@9G5N8W1I;VX@<F5A9%%U;W1E9"@D
M9FEL92P@)B1C;VYF*0H@("`@>PH@("`@("`@(&EF("@A)&9P(#T@1FEL95]#
M4U8Z.F=E=%!O:6YT97(H)&9I;&4L("1C;VYF+"!&24Q%7TU/1$5?4D5!1"DI
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@)&)U9F8@/2`D8R`]("<G.PH@("`@("`@("1R970@(#T@87)R87DH*3L*
M("`@("`@("`D:2`](#$["B`@("`@("`@)&EN7W%U;W1E(#T@9F%L<V4["B`@
M("`@("`@)'%U;W1E(#T@)&-O;F9;)W%U;W1E)UT["B`@("`@("`@)&8@/2`D
M8V]N9ELG9FEE;&1S)UT["B`@("`@("`@)&5O;#)U;FEX(#T@)&-O;F9;)V5O
M;#)U;FEX)UT["B`@("`@("`@=VAI;&4@*"@D8V@@/2!F9V5T8R@D9G`I*2`A
M/3T@9F%L<V4I('L*("`@("`@("`@("`@)'!R978@/2`D8SL*("`@("`@("`@
M("`@)&,@/2`D8V@["B`@("`@("`@("`@("\O($-O;6UO;B!C87-E"B`@("`@
M("`@("`@(&EF("@D8R`A/2`D<75O=&4@)B8@)&,@(3T@)&-O;F9;)W-E<"==
M("8F("1C("$](")<;B(@)B8@)&,@(3T@(EQR(BD@>PH@("`@("`@("`@("`@
M("`@)&)U9F8@+CT@)&,["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+R\@4W1A<G0@<75O=&4N"B`@("`@
M("`@("`@(&EF("@D<75O=&4@)B8@)&,@/3T@)'%U;W1E("8F"B`@("`@("`@
M("`@("`@("`H)'!R978@/3T@)&-O;F9;)W-E<"==('Q\("1P<F5V(#T](")<
M;B(@?'P@)'!R978@/3T](&YU;&P@?'P*("`@("`@("`@("`@("`@("`D<')E
M=B`]/2`B7'(B('Q\("1P<F5V(#T]("<G*2D*("`@("`@("`@("`@>PH@("`@
M("`@("`@("`@("`@)&EN7W%U;W1E(#T@=')U93L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@:68@*"1I;E]Q=6]T92D@>PH@("`@("`@("`@("`@("`@
M+R\@5VAE;B!E;F1S('%U;W1E"B`@("`@("`@("`@("`@("!I9B`H)&,@/3T@
M)&-O;F9;)W-E<"==("8F("1P<F5V(#T]("1C;VYF6R=Q=6]T92==*2!["B`@
M("`@("`@("`@("`@("`@("`@)&EN7W%U;W1E(#T@9F%L<V4["B`@("`@("`@
M("`@("`@("!](&5L<V5I9B`H)&,@/3T@(EQN(B!\?"`D8R`]/2`B7'(B*2![
M"B`@("`@("`@("`@("`@("`@("`@)'-U8B`]("@D<')E=B`]/2`B7'(B*2`_
M(#(@.B`Q.PH@("`@("`@("`@("`@("`@("`@(&EF("@H<W1R;&5N*"1B=69F
M*2`^/2`D<W5B*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("`H)&)U9F9[
M<W1R;&5N*"1B=69F*2`M("1S=6)](#T]("1Q=6]T92DI"B`@("`@("`@("`@
M("`@("`@("`@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:6Y?<75O=&4@
M/2!F86QS93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@A)&EN7W%U;W1E
M("8F("@D8R`]/2`D8V]N9ELG<V5P)UT@?'P@)&,@/3T@(EQN(B!\?"`D8R`]
M/2`B7'(B*2`F)B`D<')E=B`A/2`G)RD@>PH@("`@("`@("`@("`@("`@+R\@
M36]R92!F:65L9',@=&AA;B!E>'!E8W1E9`H@("`@("`@("`@("`@("`@:68@
M*"@D8R`]/2`D8V]N9ELG<V5P)UTI("8F("@H8V]U;G0H)')E="D@*R`Q*2`]
M/2`D9BDI('L*("`@("`@("`@("`@("`@("`@("`O+R!3965K('1H92!P;VEN
M=&5R(&EN=&\@;&EN96)R96%K(&-H87)A8W1E<BX*("`@("`@("`@("`@("`@
M("`@("!W:&EL92`H=')U92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M8R`](&9G971C*"1F<"D["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("`H
M)&,@/3T@(EQN(B!\?"`D8R`]/2`B7'(B*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@+R\@
M26YS97)T(&QA<W0@9FEE;&0@=F%L=64N"B`@("`@("`@("`@("`@("`@("`@
M)')E=%M=(#T@1FEL95]#4U8Z.G5N<75O=&4H)&)U9F8L("1Q=6]T92D["B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1R970["B`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@+R\@3&5S<R!F:65L9',@=&AA;B!E>'!E
M8W1E9`H@("`@("`@("`@("`@("`@:68@*"@D8R`]/2`B7&XB('Q\("1C(#T]
M(")<<B(I("8F("@D:2`A/2`D9BDI('L*("`@("`@("`@("`@("`@("`@("`O
M+R!);G-E<G0@;&%S="!F:65L9"!V86QU92X*("`@("`@("`@("`@("`@("`@
M("`D<F5T6UT@/2!&:6QE7T-35CHZ=6YQ=6]T92@D8G5F9BP@)'%U;W1E*3L*
M"B`@("`@("`@("`@("`@("`@("`@+R\@4&%I<B!T:&4@87)R87D@96QE;65N
M=',@=&\@9FEE;&1S(&-O=6YT+@H@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!A<G)A>5]M97)G92@D<F5T+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>5]F:6QL*&-O=6YT*"1R970I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*"1F
M("T@,2D@+2`H8V]U;G0H)')E="D@+2`Q*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<G*0H@("`@("`@("`@
M("`@("`@("`@("D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@:68@*"1P<F5V(#T](")<<B(I('L*("`@("`@("`@("`@("`@("`@("`D
M8G5F9B`]('-U8G-T<B@D8G5F9BP@,"P@+3$I.PH@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@("\O($-O;G9E<G0@14],(&-H87)A8W1E<B!T
M;R!5;FEX($5/3"`H3$8I+@H@("`@("`@("`@("`@("`@:68@*"1E;VPR=6YI
M>"D@>PH@("`@("`@("`@("`@("`@("`@("1B=69F(#T@<')E9U]R97!L86-E
M*"<O*%QR7&Y\7'(I)"\G+"`B7&XB+"`D8G5F9BD["B`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@)')E=%M=(#T@1FEL95]#4U8Z.G5N<75O
M=&4H)&)U9F8L("1Q=6]T92D["B`@("`@("`@("`@("`@("!I9B`H8V]U;G0H
M)')E="D@/3T@)&8I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E
M=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1B=69F(#T@
M)R<["B`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@("`@("`@("`@8V]N
M=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&)U9F8@+CT@)&,[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`A9F5O9B@D9G`I(#\@)')E="`Z
M(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@*B!296%D<R!A(")R;W<B(&9R
M;VT@82!#4U8@9FEL92!A;F0@<F5T=7)N(&ET(&%S(&%N(&%R<F%Y"B`@("`J
M"B`@("`J($!P87)A;2!S=')I;F<@)&9I;&4@5&AE($-35B!F:6QE"B`@("`J
M($!P87)A;2!A<G)A>2`@)B1C;VYF(%1H92!C;VYF:6=U<F%T:6]N(&]F('1H
M92!D97-T($-35@H@("`@*@H@("`@*B!`<F5T=7)N(&UI>&5D($%R<F%Y(&]R
M(&9A;'-E"B`@("`J+PH@("`@9G5N8W1I;VX@<F5A9"@D9FEL92P@)B1C;VYF
M*0H@("`@>PH@("`@("`@(&EF("@A)&9P(#T@1FEL95]#4U8Z.F=E=%!O:6YT
M97(H)&9I;&4L("1C;VYF+"!&24Q%7TU/1$5?4D5!1"DI('L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("`O+R!4:&4@<VEZ
M92!I<R!L:6UI=&5D('1O(#1+"B`@("`@("`@:68@*"$D;&EN92`@(#T@9F=E
M=',H)&9P+"`T,#DV*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H*("`@("`@("`D9FEE;&1S(#T@)&-O;F9;)V9I96QD<R==(#T]
M(#$@/R!A<G)A>2@D;&EN92D@.B!E>'!L;V1E*"1C;VYF6R=S97`G72P@)&QI
M;F4I.PH*("`@("`@("!I9B`H)&-O;F9;)W%U;W1E)UTI('L*("`@("`@("`@
M("`@)&QA<W0@/28@)&9I96QD<UMC;W5N="@D9FEE;&1S*2`M(#%=.PH@("`@
M("`@("`@("`O+R!&86QL8F%C:R!T;R!R96%D('1H92!L:6YE('=I=&@@<F5A
M9%%U;W1E9"!W:&5N(&=U97-S"B`@("`@("`@("`@("\O('1H870@=&AE('-I
M;7!L92!E>'!L;V1E('=O;B=T('=O<FL@<FEG:'0*("`@("`@("`@("`@:68@
M*"@D;&%S='MS=')L96XH)&QA<W0I("T@,7T@/3T@(EQN(@H@("`@("`@("`@
M("`@("`@)B8@)&QA<W1[,'T@/3T@)&-O;F9;)W%U;W1E)UT*("`@("`@("`@
M("`@("`@("8F("1L87-T>W-T<FQE;BAR=')I;2@D;&%S="DI("T@,7T@(3T@
M)&-O;F9;)W%U;W1E)UTI"B`@("`@("`@("`@("`@("!\?`H@("`@("`@("`@
M("`@("`@*&-O=6YT*"1F:65L9',I("$]("1C;VYF6R=F:65L9',G72D*("`@
M("`@("`@("`@("`@("\O(%A86"!P97)H87!S('1H97)E(&ES(&$@<V5P87)A
M=&]R(&EN<VED92!A('%U;W1E9"!F:65L9`H@("`@("`@("`@("`@("`@+R]P
M<F5G7VUA=&-H*")\>R1C;VYF6R=Q=6]T92==?2XJ>R1C;VYF6R=S97`G77TN
M*GLD8V]N9ELG<75O=&4G77U\52(L("1L:6YE*0H@("`@("`@("`@("`@("`@
M*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@("!F<V5E:R@D9G`L("TQ
M("H@<W1R;&5N*"1L:6YE*2P@4T5%2U]#55(I.PH@("`@("`@("`@("`@("`@
M<F5T=7)N($9I;&5?0U-6.CIR96%D475O=&5D*"1F:6QE+"`D8V]N9BD["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D;&%S="`](')T
M<FEM*"1L87-T*3L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1F:65L9',@
M87,@)&L@/3X@)'8I('L*("`@("`@("`@("`@("`@("`@("`D9FEE;&1S6R1K
M72`]($9I;&5?0U-6.CIU;G%U;W1E*"1V+"`D8V]N9ELG<75O=&4G72D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(&EF("AC;W5N="@D9FEE;&1S*2`A/2`D8V]N9ELG9FEE;&1S)UTI('L*
M("`@("`@("`@("`@1FEL95]#4U8Z.G)A:7-E17)R;W(H(E)E860@=W)O;F<@
M9FEE;&1S(&YU;6)E<B!C;W5N=#H@)R(N(&-O=6YT*"1F:65L9',I("X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("(G(&5X<&5C=&5D("(N
M)&-O;F9;)V9I96QD<R==*3L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D9FEE;&1S.PH@("`@?0H*("`@("\J
M*@H@("`@*B!);G1E<FYA;"!U<V4@;VYL>2P@=VEL;"!B92!R96UO=F5D(&EN
M('1H92!F=71U<F4*("`@("H*("`@("H@0'!A<F%M('-T<FEN9R`D<W1R(%1H
M92!S=')I;F<@=&\@9&5B=6<*("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J
M+PH@("`@9G5N8W1I;VX@7V1B9T)U9F8H)'-T<BD*("`@('L*("`@("`@("!I
M9B`H<W1R<&]S*"1S='(L(")<<B(I("$]/2!F86QS92D@>PH@("`@("`@("`@
M("`D<W1R(#T@<W1R7W)E<&QA8V4H(EQR(BP@(E]R7R(L("1S='(I.PH@("`@
M("`@('T*("`@("`@("!I9B`H<W1R<&]S*"1S='(L(")<;B(I("$]/2!F86QS
M92D@>PH@("`@("`@("`@("`D<W1R(#T@<W1R7W)E<&QA8V4H(EQN(BP@(E]N
M7R(L("1S='(I.PH@("`@("`@('T*("`@("`@("!I9B`H<W1R<&]S*"1S='(L
M(")<="(I("$]/2!F86QS92D@>PH@("`@("`@("`@("`D<W1R(#T@<W1R7W)E
M<&QA8V4H(EQT(BP@(E]T7R(L("1S='(I.PH@("`@("`@('T*("`@("`@("!E
M8VAO(")B=69F.B`H)'-T<BE<;B(["B`@("!]"@H@("`@+RHJ"B`@("`J(%=R
M:71E<R!A('-T<G5C("AA<G)A>2D@:6X@82!F:6QE(&%S($-35@H@("`@*@H@
M("`@*B!`<&%R86T@<W1R:6YG("1F:6QE("`@5&AE(&9I;&5N86UE('=H97)E
M('1O('=R:71E('1H92!D871A"B`@("`J($!P87)A;2!A<G)A>2`@)&9I96QD
M<R!/<F1E<F5D(&%R<F%Y('=I=&@@=&AE(&1A=&$*("`@("H@0'!A<F%M(&%R
M<F%Y("`F)&-O;F8@("!4:&4@8V]N9FEG=7)A=&EO;B!O9B!T:&4@9&5S="!#
M4U8*("`@("H*("`@("H@0')E='5R;B!B;V]L(%1R=64@;VX@<W5C8V5S<R!F
M86QS92!O=&AE<G=I<V4*("`@("HO"B`@("!F=6YC=&EO;B!W<FET92@D9FEL
M92P@)&9I96QD<RP@)B1C;VYF*0H@("`@>PH@("`@("`@(&EF("@A)&9P(#T@
M1FEL95]#4U8Z.F=E=%!O:6YT97(H)&9I;&4L("1C;VYF+"!&24Q%7TU/1$5?
M5U))5$4I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"B`@("`@("`@:68@*&-O=6YT*"1F:65L9',I("$]("1C;VYF6R=F:65L9',G
M72D@>PH@("`@("`@("`@("!&:6QE7T-35CHZ<F%I<V5%<G)O<B@B5W)O;F<@
M9FEE;&1S(&YU;6)E<B!C;W5N=#H@)R(N(&-O=6YT*"1F:65L9',I("X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("(G(&5X<&5C=&5D("(N
M)&-O;F9;)V9I96QD<R==*3L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?0H@("`@("`@("1W<FET92`]("<G.PH@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\(&-O=6YT*"1F:65L9',I.R`D:2LK*2!["B`@("`@("`@("`@
M(&EF("@A:7-?;G5M97)I8R@D9FEE;&1S6R1I72D@)B8@)&-O;F9;)W%U;W1E
M)UTI('L*("`@("`@("`@("`@("`@("1W<FET92`N/2`D8V]N9ELG<75O=&4G
M72`N("1F:65L9'-;)&E=("X@)&-O;F9;)W%U;W1E)UT["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D=W)I=&4@+CT@)&9I96QD<ULD
M:5T["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1I(#P@*&-O=6YT
M*"1F:65L9',I("T@,2DI('L*("`@("`@("`@("`@("`@("1W<FET92`N/2`D
M8V]N9ELG<V5P)UT["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D=W)I=&4@+CT@)&-O;F9;)V-R;&8G73L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!I9B`H(69W<FET92@D9G`L("1W<FET92DI('L*
M("`@("`@("`@("`@<F5T=7)N($9I;&5?0U-6.CIR86ES945R<F]R*"=#86X@
M;F]T('=R:71E('1O(&9I;&4G*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`J($1I<V-O=F5R('1H92!F;W)M
M870@;V8@82!#4U8@9FEL92`H=&AE(&YU;6)E<B!O9B!F:65L9',L('1H92!S
M97!A<F%T;W(*("`@("H@86YD(&EF(&ET('%U;W1E('-T<FEN9R!F:65L9',I
M"B`@("`J"B`@("`J($!P87)A;2!S=')I;F<@=&AE($-35B!F:6QE(&YA;64*
M("`@("H@0'!A<F%M(&%R<F%Y(&5X=')A('-E<&%R871O<G,@=&AA="!S:&]U
M;&0@8F4@8VAE8VME9"!F;W(N"B`@("`J($!R971U<FX@;6EX960@07-S;V,@
M87)R87D@;W(@9F%L<V4*("`@("HO"B`@("!F=6YC=&EO;B!D:7-C;W9E<D9O
M<FUA="@D9FEL92P@)&5X=')A4V5P<R`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@:68@*"$D9G`@/2!`9F]P96XH)&9I;&4L("=R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N($9I;&5?0U-6.CIR86ES945R<F]R*")#;W5L9"!N;W0@;W!E
M;B!F:6QE.B`D9FEL92(I.PH@("`@("`@('T*("`@("`@("`D<V5P<R`](&%R
M<F%Y*")<="(L("<[)RP@)SHG+"`G+"<I.PH@("`@("`@("1S97!S(#T@87)R
M87E?;65R9V4H)'-E<',L("1E>'1R85-E<',I.PH@("`@("`@("1M871C:&5S
M(#T@87)R87DH*3L*"B`@("`@("`@+R\@4V5T(&%U=&\@9&5T96-T(&QI;F4@
M96YD:6YG(&9O<B!-86,@14],('-U<'!O<G0@:68@/"!02%`@-"XS+C`N"B`@
M("`@("`@)'!H<'9E<B`]('9E<G-I;VY?8V]M<&%R92@G-"XS+C`G+"!P:'!V
M97)S:6]N*"DL("<\)RD["B`@("`@("`@:68@*"1P:'!V97(I('L*("`@("`@
M("`@("`@)&]L9&EN:2`](&EN:5]G970H)V%U=&]?9&5T96-T7VQI;F5?96YD
M:6YG<R<I.PH@("`@("`@("`@("!I;FE?<V5T*"=A=71O7V1E=&5C=%]L:6YE
M7V5N9&EN9W,G+"`G,2<I.PH@("`@("`@('T*"B`@("`@("`@+R\@5&%K92!T
M:&4@9FER<W0@,3`@;&EN97,@86YD('-T;W)E('1H92!N=6UB97(@;V8@;V-U
M<G)E;F-E<PH@("`@("`@("\O(&9O<B!E86-H('-E<&%R871O<B!I;B!E86-H
M(&QI;F4*"B`@("`@("`@)&QI;F5S(#T@9FEL92@D9FEL92D["B`@("`@("`@
M:68@*&-O=6YT*"1L:6YE<RD@/B`Q,"D@>PH@("`@("`@("`@("`D;&EN97,@
M/2!A<G)A>5]S;&EC92@D;&EN97,L(#`L(#$P*3L*("`@("`@("!]"@H@("`@
M("`@(&EF("@D<&AP=F5R*2!["B`@("`@("`@("`@(&EN:5]S970H)V%U=&]?
M9&5T96-T7VQI;F5?96YD:6YG<R<L("1O;&1I;FDI.PH@("`@("`@('T*"B`@
M("`@("`@9F]R96%C:"`H)&QI;F5S(&%S("1L:6YE*2!["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1S97!S(&%S("1S97`I('L*("`@("`@("`@("`@("`@("1M
M871C:&5S6R1S97!=6UT@/2!S=6)S=')?8V]U;G0H)&QI;F4L("1S97`I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D9FEN86P@/2!A<G)A
M>2@I.PH@("`@("`@("\O($=R;W5P('1H92!R97-U;'1S(&)Y(&%M;W5N="!O
M9B!E<75A;"!O8W5R<F5N8V5S"B`@("`@("`@9F]R96%C:"`H)&UA=&-H97,@
M87,@)'-E<"`]/B`D<F5S*2!["B`@("`@("`@("`@("1T:6UE<R`](&%R<F%Y
M*"D["B`@("`@("`@("`@("1T:6UE<ULP72`](#`["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1R97,@87,@)&L@/3X@)&YU;2D@>PH@("`@("`@("`@("`@("`@
M:68@*"1N=6T@/B`P*2!["B`@("`@("`@("`@("`@("`@("`@)'1I;65S6R1N
M=6U=(#T@*&ES<V5T*"1T:6UE<ULD;G5M72DI(#\@)'1I;65S6R1N=6U=("L@
M,2`Z(#$["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("`@("`@87)S;W)T*"1T:6UE<RD["@H@("`@("`@("`@("`O+R!5<V4@;6%X
M(&9I96QD<R!C;W5N="X*("`@("`@("`@("`@)&9I96QD<ULD<V5P72`](&UA
M>"AA<G)A>5]F;&EP*"1T:6UE<RDI.PH@("`@("`@("`@("`D86UO=6YT6R1S
M97!=(#T@)'1I;65S6VME>2@D=&EM97,I73L*("`@("`@("!]"@H@("`@("`@
M(&%R<V]R="@D86UO=6YT*3L*("`@("`@("`D<V5P("`@(#T@:V5Y*"1A;6]U
M;G0I.PH*("`@("`@("`D8V]N9ELG9FEE;&1S)UT@/2`D9FEE;&1S6R1S97!=
M("L@,3L*("`@("`@("`D8V]N9ELG<V5P)UT@("`@/2`D<V5P.PH*("`@("`@
M("`O+R!497-T(&EF('1H97)E(&%R92!F:65L9',@=VET:"!Q=6]T97,@87)R
M;W5N9"!I;B!T:&4@9FER<W0@-2!L:6YE<PH@("`@("`@("1Q=6]T97,@/2`G
M(EPG)SL*("`@("`@("`D<75O=&4@(#T@;G5L;#L*("`@("`@("!I9B`H8V]U
M;G0H)&QI;F5S*2`^(#4I('L*("`@("`@("`@("`@)&QI;F5S(#T@87)R87E?
M<VQI8V4H)&QI;F5S+"`P+"`U*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A
M8V@@*"1L:6YE<R!A<R`D;&EN92D@>PH@("`@("`@("`@("!I9B`H<')E9U]M
M871C:"@B?"1S97`H6R1Q=6]T97-=*2XJ*%LD<75O=&5S72DD<V5P?%4B+"`D
M;&EN92P@)&UA=&-H*2D@>PH@("`@("`@("`@("`@("`@:68@*"1M871C:%LQ
M72`]/2`D;6%T8VA;,ETI('L*("`@("`@("`@("`@("`@("`@("`D<75O=&4@
M/2`D;6%T8VA;,5T["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*'!R
M96=?;6%T8V@H(GQ>*%LD<75O=&5S72DN*BA;)'%U;W1E<UTI)'-E<'LP+#%]
M?"(L("1L:6YE+"`D;6%T8V@I"B`@("`@("`@("`@("`@("!\?"!P<F5G7VUA
M=&-H*")\*%LD<75O=&5S72DN*BA;)'%U;W1E<UTI)'-E<%QS)'Q5<R(L("1L
M:6YE+"`D;6%T8V@I*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@("!I
M9B`H)&UA=&-H6S%=(#T]("1M871C:%LR72D@>PH@("`@("`@("`@("`@("`@
M("`@("1Q=6]T92`]("1M871C:%LQ73L*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("`D8V]N9ELG<75O=&4G72`]("1Q=6]T93L*("`@("`@("!F
M8VQO<V4H)&9P*3L*("`@("`@("`O+R!86%@@5VAA="!A8F]U="!T<GEI;F<@
M=&\@9&ES8V]V97(@=&AE(")H96%D97(B/PH@("`@("`@(')E='5R;B`D8V]N
M9CL*("`@('T*"B`@("`O*BH*("`@("`J($9R;VYT('1O(&-A;&P@9V5T4&]I
M;G1E<B!A;F0@;6]V:6YG('1H92!R97-O=7)C92!T;R!T:&4*("`@("`J(&)E
M9VEN;FEN9R!O9B!T:&4@9FEL90H@("`@("H@4F5S970@:70@:68@>6]U(&QI
M:V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL92!4:&4@;F%M
M92!O9B!T:&4@9FEL90H@("`@("H@0'!A<F%M(&%R<F%Y("`F)&-O;F8@5&AE
M(&-O;F9I9W5R871I;VX*("`@("`J($!P87)A;2!S=')I;F<@)&UO9&4@5&AE
M(&]P96X@;F]D92`H97@Z($9)3$5?34]$15]214%$(&]R($9)3$5?34]$15]7
M4DE412D*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@=')U92!O;B!S
M=6-C97-S(&9A;'-E(&]N(&9A:6QU<F4*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F5S9710;VEN=&5R*"1F:6QE+"`F)&-O;F8L("1M;V1E*0H@("`@>PH@("`@
M("`@(&EF("@A1FEL95]#4U8Z.F=E=%!O:6YT97(H)&9I;&4L("1C;VYF+"`D
M;6]D92P@=')U92DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"GT*/SX`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]&:6QE+U5T:6PN<&AP````````````````````
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S,34T,P`Q,#4Q-30S,S<S-P`P
M,C$Q,C(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF
M='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!&:6QE.CI5=&EL
M"B`J(`H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4
M:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@
M=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N
M9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L
M96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@
M8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G
M;W)Y("`@($9I;&4*("H@0'!A8VMA9V4@("`@($9I;&4*("H@0&%U=&AO<B`@
M("`@($UI8VAA96P@5V%L;&YE<B`\;6EK94!P:'`N;F5T/@H@*B!`8V]P>7)I
M9VAT("`@,C`P-"TR,#`U($UI8VAA96P@5V%L;&YE<@H@*B!`;&EC96YS92`@
M("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI
M8V5N<V4@,RXP"B`J($!V97)S:6]N("`@("!#5E,Z("1)9#H@571I;"YP:'`L
M=B`Q+C(Q(#(P,#4O,#@O,#D@,#<Z-3(Z,3,@;6EK92!%>'`@)`H@*B!`;&EN
M:R`@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T9I;&4*("HO
M"@HO*BHC0"L*("H@4V]R=&EN9R!#;VYS=&%N=',*("HO"F1E9FEN92@G1DE,
M15]33U)47TY/3D4G+"`@("`P*3L*9&5F:6YE*"=&24Q%7U-/4E1?4D5615)3
M12<L(#$I.PID969I;F4H)T9)3$5?4T]25%].04U%)RP@("`@,BD["F1E9FEN
M92@G1DE,15]33U)47U-)6D4G+"`@("`T*3L*9&5F:6YE*"=&24Q%7U-/4E1?
M1$%412<L("`@(#@I.PID969I;F4H)T9)3$5?4T]25%]204Y$3TTG+"`@,38I
M.PHO*BHC0"TJ+PH*+RHJ(T`K"B`J($QI<W1I;F<@0V]N<W1A;G1S"B`J+PID
M969I;F4H)T9)3$5?3$E35%]&24Q%4R<L("`@,2D["F1E9FEN92@G1DE,15],
M25-47T1)4E,G+"`@("`R*3L*9&5F:6YE*"=&24Q%7TQ)4U1?1$]44R<L("`@
M(#0I.PID969I;F4H)T9)3$5?3$E35%]!3$PG+"`@("`@1DE,15],25-47T9)
M3$53('P@1DE,15],25-47T1)4E,@?"!&24Q%7TQ)4U1?1$]44RD["B\J*B-`
M+2HO"@HO*BH*("H@0&EG;F]R90H@*B\*9&5F:6YE*"=&24Q%7U=)3C,R)RP@
M9&5F:6YE9"@G3U-?5TE.1$]74R<I(#\@3U-?5TE.1$]74R`Z("%S=')N8V%S
M96-M<"A02%!?3U,L("=W:6XG+"`S*2D["@HO*BH@"B`J($9I;&5?571I;`H@
M*@H@*B!&:6QE(&%N9"!D:7)E8W1O<GD@=71I;&ET>2!F=6YC=&EO;G,N"B`J
M(`H@*B!`86-C97-S("!P=6)L:6,*("H@0'-T871I8PH@*B\*8VQA<W,@1FEL
M95]5=&EL"GL*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('-T<FEN9R!P871H
M(&)U:6QT(&9R;VT@=&AE(&%R<F%Y("1P871H4&%R=',N(%=H97)E(&$@:F]I
M;B`*("`@("`J(&]C8W5R<R!M=6QT:7!L92!S97!A<F%T;W)S(&%R92!R96UO
M=F5D+B!*;VEN<R!U<VEN9R!T:&4@;W!T:6]N86P@"B`@("`@*B!S97!A<F%T
M;W(L(&1E9F%U;'1I;F<@=&\@=&AE(%!(4"!$25)%0U1/4EE?4T5005)!5$]2
M(&-O;G-T86YT+@H@("`@("H@"B`@("`@*B!`<W1A=&EC"B`@("`@*B!`86-C
M97-S("!P=6)L:6,@"B`@("`@*B!`<&%R86T@("!A<G)A>2`@("1P87)T<R!!
M<G)A>2!C;VYT86EN:6YG('1H92!P87)T<R!T;R!B92!J;VEN960*("`@("`J
M($!P87)A;2`@('-T<FEN9R`@)'-E<&%R871O<B!4:&4@9&ER96-T;W)Y('-E
M<&5R871O<@H@("`@("HO"B`@("!F=6YC=&EO;B!B=6EL9%!A=&@H)'!A<G1S
M+"`D<V5P87)A=&]R(#T@1$E214-43U)97U-%4$%2051/4BD*("`@('L*("`@
M("`@("`D<7,@/2`G+UXG+B!P<F5G7W%U;W1E*"1S97!A<F%T;W(L("<O)RD@
M+B<K)"\G.PH@("`@("`@(&9O<B`H)&D@/2`P+"`D8R`](&-O=6YT*"1P87)T
M<RD[("1I(#P@)&,[("1I*RLI('L*("`@("`@("`@("`@:68@*"%S=')L96XH
M)'!A<G1S6R1I72D@?'P@<')E9U]M871C:"@D<7,L("1P87)T<ULD:5TI*2![
M"B`@("`@("`@("`@("`@("!U;G-E="@D<&%R='-;)&E=*3L*("`@("`@("`@
M("`@?2!E;'-E:68@*#`@/3T@)&DI('L*("`@("`@("`@("`@("`@("1P87)T
M<ULD:5T@/2!R=')I;2@D<&%R='-;)&E=+"`D<V5P87)A=&]R*3L*("`@("`@
M("`@("`@?2!E;'-E:68@*"1C("T@,2`]/2`D:2D@>PH@("`@("`@("`@("`@
M("`@)'!A<G1S6R1I72`](&QT<FEM*"1P87)T<ULD:5TL("1S97!A<F%T;W(I
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'!A<G1S
M6R1I72`]('1R:6TH)'!A<G1S6R1I72P@)'-E<&%R871O<BD["B`@("`@("`@
M("`@('T@"B`@("`@("`@?2`*("`@("`@("!R971U<FX@:6UP;&]D92@D<V5P
M87)A=&]R+"`D<&%R=',I.PH@("`@?2`*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@82!P871H('=I=&AO=70@;&5A9&EN9R`O(&]R($,Z7"X@268@=&AI<R!I
M<R!N;W0*("`@("`J('!R97-E;G0@=&AE('!A=&@@:7,@<F5T=7)N960@87,@
M:7,N"B`@("`@*B`*("`@("`J($!S=&%T:6,*("`@("`J($!A8V-E<W,@('!U
M8FQI8R`*("`@("`J($!P87)A;2`@('-T<FEN9R`@)'!A=&@@5&AE('!A=&@@
M=&\@8F4@<')O8V5S<V5D"B`@("`@*B!`<F5T=7)N("!S=')I;F<@(%1H92!P
M<F]C97-S960@<&%T:"!O<B!T:&4@<&%T:"!A<R!I<PH@("`@("HO"B`@("!F
M=6YC=&EO;B!S:VEP4F]O="@D<&%T:"D*("`@('L*("`@("`@("!I9B`H1FEL
M95]5=&EL.CII<T%B<V]L=71E*"1P871H*2D@>PH@("`@("`@("`@("!I9B`H
M1DE,15]724XS,BD@>PH@("`@("`@("`@("`@("`@<F5T=7)N('-U8G-T<B@D
M<&%T:"P@)'!A=&A[,WT@/3T@)UQ<)R`_(#0@.B`S*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!R971U<FX@;'1R:6TH)'!A=&@L("<O)RD["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D<&%T:#L*("`@('T@"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!T96UP(&1I<F5C=&]R>2!A8V-O<F1I;F<@=&\@
M96ET:&5R('1H92!435`L(%1-4$1)4BP@;W(@"B`@("`@*B!414U0(&5N=B!V
M87)I86)L97,N($EF('1H97-E(&%R92!N;W0@<V5T(&ET('=I;&P@86QS;R!C
M:&5C:R!F;W(@=&AE(`H@("`@("H@97AI<W1E;F-E(&]F("]T;7`L("5724Y$
M25(E7'1E;7`*("`@("`J(`H@("`@("H@0'-T871I8PH@("`@("H@0&%C8V5S
M<R`@<'5B;&EC(`H@("`@("H@0')E='5R;B`@<W1R:6YG("!4:&4@<WES=&5M
M('1M<"!D:7)E8W1O<GD*("`@("`J+PH@("`@9G5N8W1I;VX@=&UP1&ER*"D*
M("`@('L*("`@("`@("!I9B`H1DE,15]724XS,BD@>PH@("`@("`@("`@("!I
M9B`H:7-S970H)%]%3E9;)U1%35`G72DI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D7T5.5ELG5$5-4"==.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("AI<W-E="@D7T5.5ELG5$U0)UTI*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)%]%3E9;)U1-4"==.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("AI<W-E="@D7T5.5ELG=VEN9&ER)UTI*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)%]%3E9;)W=I;F1I<B==("X@)UQ<=&5M<"<["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*&ES<V5T*"1?14Y66R=3>7-T96U2;V]T
M)UTI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)%]%3E9;)U-Y<W1E;5)O
M;W0G72`N("=<7'1E;7`G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("AI<W-E="@D7U-%4E9%4ELG5$5-4"==*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1?4T525D526R=414U0)UT["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*&ES<V5T*"1?4T525D526R=435`G72DI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D7U-%4E9%4ELG5$U0)UT["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*&ES<V5T*"1?4T525D526R=W:6YD:7(G72DI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D7U-%4E9%4ELG=VEN9&ER)UT@+B`G
M7%QT96UP)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:7-S970H
M)%]315)615);)U-Y<W1E;5)O;W0G72DI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D7U-%4E9%4ELG4WES=&5M4F]O="==("X@)UQ<=&5M<"<["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("=<=&5M<"<["B`@("`@("`@
M?0H@("`@("`@(&EF("AI<W-E="@D7T5.5ELG5$U01$E2)UTI*2!["B`@("`@
M("`@("`@(')E='5R;B`D7T5.5ELG5$U01$E2)UT["B`@("`@("`@?0H@("`@
M("`@(&EF("AI<W-E="@D7U-%4E9%4ELG5$U01$E2)UTI*2!["B`@("`@("`@
M("`@(')E='5R;B`D7U-%4E9%4ELG5$U01$E2)UT["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`G+W1M<"<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&$@=&5M<&]R87)Y(&9I;&5N86UE('5S:6YG('1E;7!N86TH*2!A;F0@
M1FEL93HZ=&UP1&ER*"DN"B`@("`@*B`*("`@("`J($!S=&%T:6,*("`@("`J
M($!A8V-E<W,@('!U8FQI8R`*("`@("`J($!P87)A;2`@('-T<FEN9R`@)&1I
M<FYA;64@3W!T:6]N86P@9&ER96-T;W)Y(&YA;64@9F]R('1H92!T;7`@9FEL
M90H@("`@("H@0')E='5R;B`@<W1R:6YG("!&:6QE;F%M92!A;F0@<&%T:"!O
M9B!T:&4@=&UP(&9I;&4*("`@("`J+PH@("`@9G5N8W1I;VX@=&UP1FEL92@D
M9&ER;F%M92`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D9&ER
M;F%M92DI('L*("`@("`@("`@("`@)&1I<FYA;64@/2!&:6QE7U5T:6PZ.G1M
M<$1I<B@I.PH@("`@("`@('T@"B`@("`@("`@<F5T=7)N('1E;7!N86TH)&1I
M<FYA;64L("=T96UP+B<I.PH@("`@?2`*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@8F]O;&5A;B!B87-E9"!O;B!W:&5T:&5R(&=I=F5N('!A=&@@:7,@86)S
M;VQU=&4@;W(@;F]T+@H@("`@("H@"B`@("`@*B!`<W1A=&EC"B`@("`@*B!`
M86-C97-S("!P=6)L:6,@"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1P871H
M($=I=F5N('!A=&@*("`@("`J($!R971U<FX@(&)O;VQE86X@5')U92!I9B!T
M:&4@<&%T:"!I<R!A8G-O;'5T92P@9F%L<V4@:68@:70@:7,@;F]T"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&ES06)S;VQU=&4H)'!A=&@I"B`@("!["B`@("`@
M("`@:68@*'!R96=?;6%T8V@H)R\H/SI<+WQ<7%PI7"Y<+B@_/5PO?"0I+R<L
M("1P871H*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?2`*("`@("`@("!I9B`H1DE,15]724XS,BD@>PH@("`@("`@("`@("!R971U
M<FX@<')E9U]M871C:"@G+UY;82UZ02U:73HH7%Q<?%PO*2\G+"`D<&%T:"D[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`H)'!A=&A[,'T@/3T@)R\G*2!\
M?"`H)'!A=&A[,'T@/3T@)WXG*3L*("`@('T@"@H@("`@+RHJ"B`@("`@*B!'
M970@<&%T:"!R96QA=&EV92!T;R!A;F]T:&5R('!A=&@*("`@("`J"B`@("`@
M*B!`<W1A=&EC"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!R971U
M<FX@('-T<FEN9PH@("`@("H@0'!A<F%M("`@<W1R:6YG("`D<&%T:`H@("`@
M("H@0'!A<F%M("`@<W1R:6YG("`D<F]O=`H@("`@("H@0'!A<F%M("`@<W1R
M:6YG("`D<V5P87)A=&]R"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;&%T:79E
M4&%T:"@D<&%T:"P@)')O;W0L("1S97!A<F%T;W(@/2!$25)%0U1/4EE?4T50
M05)!5$]2*0H@("`@>PH@("`@("`@("1P871H(#T@1FEL95]5=&EL.CIR96%L
M<&%T:"@D<&%T:"P@)'-E<&%R871O<BD["B`@("`@("`@)')O;W0@/2!&:6QE
M7U5T:6PZ.G)E86QP871H*"1R;V]T+"`D<V5P87)A=&]R*3L*("`@("`@("`D
M9&ER<R`](&5X<&QO9&4H)'-E<&%R871O<BP@)'!A=&@I.PH@("`@("`@("1C
M;VUP(#T@97AP;&]D92@D<V5P87)A=&]R+"`D<F]O="D["B`@("`@("`@"B`@
M("`@("`@:68@*$9)3$5?5TE.,S(I('L*("`@("`@("`@("`@:68@*'-T<F-A
M<V5C;7`H)&1I<G-;,%TL("1C;VUP6S!=*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1P871H.PH@("`@("`@("`@("!]"B`@("`@("`@("`@('5N<V5T
M*"1D:7)S6S!=+"`D8V]M<%LP72D["B`@("`@("`@?0H@("`@("`@(`H@("`@
M("`@(&9O<F5A8V@@*"1C;VUP(&%S("1I(#T^("1P87)T*2!["B`@("`@("`@
M("`@(&EF("AI<W-E="@D9&ER<ULD:5TI("8F("1P87)T(#T]("1D:7)S6R1I
M72D@>PH@("`@("`@("`@("`@("`@=6YS970H)&1I<G-;)&E=+"`D8V]M<%LD
M:5TI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@(`H@("`@("`@
M(')E='5R;B!S=')?<F5P96%T*"<N+B<@+B`D<V5P87)A=&]R+"!C;W5N="@D
M8V]M<"DI("X@:6UP;&]D92@D<V5P87)A=&]R+"`D9&ER<RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!'970@<F5A;"!P871H("AW;W)K<R!W:71H(&YO;BUE
M>&ES=&%N="!P871H<RD*("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@*B!`
M86-C97-S("!P=6)L:6,*("`@("`J($!R971U<FX@('-T<FEN9PH@("`@("H@
M0'!A<F%M("`@<W1R:6YG("`D<&%T:`H@("`@("H@0'!A<F%M("`@<W1R:6YG
M("`D<V5P87)A=&]R"B`@("`@*B\*("`@(&9U;F-T:6]N(')E86Q0871H*"1P
M871H+"`D<V5P87)A=&]R(#T@1$E214-43U)97U-%4$%2051/4BD*("`@('L*
M("`@("`@("!I9B`H(7-T<FQE;B@D<&%T:"DI('L*("`@("`@("`@("`@<F5T
M=7)N("1S97!A<F%T;W(["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@("1D
M<FEV92`]("<G.PH@("`@("`@(&EF("A&24Q%7U=)3C,R*2!["B`@("`@("`@
M("`@("1P871H(#T@<')E9U]R97!L86-E*"<O6UQ<7%Q<+UTO)RP@)'-E<&%R
M871O<BP@)'!A=&@I.PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+RA;
M82UZ02U:75PZ*2@N*BDO)RP@)'!A=&@L("1M871C:&5S*2D@>PH@("`@("`@
M("`@("`@("`@)&1R:79E(#T@)&UA=&-H97-;,5T["B`@("`@("`@("`@("`@
M("`D<&%T:"`@/2`D;6%T8VAE<ULR73L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1C=V0@("`](&=E=&-W9"@I.PH@("`@("`@("`@
M("`@("`@)&1R:79E(#T@<W5B<W1R*"1C=V0L(#`L(#(I.PH@("`@("`@("`@
M("`@("`@:68@*"1P871H>S!]("$]/2`D<V5P87)A=&]R>S!]*2!["B`@("`@
M("`@("`@("`@("`@("`@)'!A=&@@(#T@<W5B<W1R*"1C=V0L(#,I("X@)'-E
M<&%R871O<B`N("1P871H.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E:68@*"1P871H>S!]("$]/2`D<V5P87)A=&]R
M*2!["B`@("`@("`@("`@("1P871H(#T@9V5T8W=D*"D@+B`D<V5P87)A=&]R
M("X@)'!A=&@["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@("1D:7)3=&%C
M:R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H97AP;&]D92@D<V5P87)A
M=&]R+"`D<&%T:"D@87,@)&1I<BD@>PH@("`@("`@("`@("!I9B`H<W1R;&5N
M*"1D:7(I("8F("1D:7(@(3T]("<N)RD@>PH@("`@("`@("`@("`@("`@:68@
M*"1D:7(@/3T@)RXN)RD@>PH@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!O
M<"@D9&ER4W1A8VLI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D9&ER4W1A8VM;72`]("1D:7(["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@"B`@("`@
M("`@<F5T=7)N("1D<FEV92`N("1S97!A<F%T;W(@+B!I;7!L;V1E*"1S97!A
M<F%T;W(L("1D:7)3=&%C:RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C
M:R!W:&5T:&5R('!A=&@@:7,@:6X@<F]O="!P871H"B`@("`@*@H@("`@("H@
M0'-T871I8PH@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<F5T=7)N
M("!B;V]L"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1P871H"B`@("`@*B!`
M<&%R86T@("!S=')I;F<@("1R;V]T"B`@("`@*B\*("`@(&9U;F-T:6]N('!A
M=&A);E)O;W0H)'!A=&@L("1R;V]T*0H@("`@>PH@("`@("`@('-T871I8R`D
M<F5A;%!A=&AS(#T@87)R87DH*3L*("`@("`@("`*("`@("`@("!I9B`H(6ES
M<V5T*"1R96%L4&%T:'-;)')O;W1=*2D@>PH@("`@("`@("`@("`D<F5A;%!A
M=&AS6R1R;V]T72`]($9I;&5?571I;#HZ<F5A;%!A=&@H)')O;W0I.PH@("`@
M("`@('T*("`@("`@("`*("`@("`@("!R971U<FX@9F%L<V4@(3T]('-T<G-T
M<BA&:6QE7U5T:6PZ.G)E86Q0871H*"1P871H*2P@)')E86Q0871H<ULD<F]O
M=%TI.PH@("`@?0H*("`@("\J*@H@("`@("H@3&ES="!$:7)E8W1O<GD*("`@
M("`J(`H@("`@("H@5&AE(&9I;F%L(&%R9W5M96YT+"`D8V(L(&ES(&$@8V%L
M;&)A8VL@=&AA="!E:71H97(@979A;'5A=&5S('1O('1R=64@;W(*("`@("`J
M(&9A;'-E(&%N9"!P97)F;W)M<R!A(&9I;'1E<B!O<&5R871I;VXL(&]R(&ET
M(&-A;B!A;'-O(&UO9&EF>2!T:&4@"B`@("`@*B!D:7)E8W1O<GDO9FEL92!N
M86UE<R!R971U<FYE9"X@(%1O(&%C:&EE=F4@=&AE(&QA='1E<B!E9F9E8W0@
M=7-E(&%S(`H@("`@("H@9F]L;&]W<SH*("`@("`J(`H@("`@("H@/&-O9&4^
M"B`@("`@*B`\/W!H<`H@("`@("H@9G5N8W1I;VX@=6,H)B1F:6QE;F%M92D@
M>PH@("`@("H@("`@("1F:6QE;F%M92`]('-T<G1O=7!P97(H)&9I;&5N86UE
M*3L*("`@("`J("`@("!R971U<FX@=')U93L*("`@("`J('T*("`@("`J("1E
M;G1R:65S(#T@1FEL95]5=&EL.CIL:7-T1&ER*"<N)RP@1DE,15],25-47T%,
M3"P@1DE,15]33U)47TY/3D4L("=U8R<I.PH@("`@("H@9F]R96%C:"`H)&5N
M=')I97,@87,@)&4I('L*("`@("`J("`@("!E8VAO("1E+3YN86UE+"`B7&XB
M.PH@("`@("H@?0H@("`@("H@/SX*("`@("`J(#PO8V]D93X*("`@("`J(`H@
M("`@("H@0'-T871I8PH@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`
M<F5T=7)N("!A<G)A>0H@("`@("H@0'!A<F%M("`@<W1R:6YG("`D<&%T:`H@
M("`@("H@0'!A<F%M("`@:6YT("`@("`D;&ES=`H@("`@("H@0'!A<F%M("`@
M:6YT("`@("`D<V]R=`H@("`@("H@0'!A<F%M("`@;6EX960@("`D8V(*("`@
M("`J+PH@("`@9G5N8W1I;VX@;&ES=$1I<B@D<&%T:"P@)&QI<W0@/2!&24Q%
M7TQ)4U1?04Q,+"`D<V]R="`]($9)3$5?4T]25%].3TY%+"`D8V(@/2!N=6QL
M*0H@("`@>PH@("`@("`@(&EF("@A<W1R;&5N*"1P871H*2!\?"`A:7-?9&ER
M*"1P871H*2D@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]
M"B`@("`@("`@"B`@("`@("`@)&5N=')I97,@/2!A<G)A>2@I.PH@("`@("`@
M(&9O<B`H)&1I<B`](&1I<B@D<&%T:"D[(&9A;'-E("$]/2`D96YT<GD@/2`D
M9&ER+3YR96%D*"D[("D@>PH@("`@("`@("`@("!I9B`H)&QI<W0@)B!&24Q%
M7TQ)4U1?1$]44R!\?"`D96YT<GE[,'T@(3T]("<N)RD@>PH@("`@("`@("`@
M("`@("`@)&ES4F5F(#T@*"1E;G1R>2`]/3T@)RXG('Q\("1E;G1R>2`]/3T@
M)RXN)RD["B`@("`@("`@("`@("`@("`D:7-$:7(@/2`D:7-2968@?'P@:7-?
M9&ER*"1P871H("XG+R<N("1E;G1R>2D["B`@("`@("`@("`@("`@("!I9B`H
M("`@("@H(21I<T1I<B`F)B`D;&ES="`F($9)3$5?3$E35%]&24Q%4RD@("!\
M?`H@("`@("`@("`@("`@("`@("`@("`@("`@*"1I<T1I<B`@)B8@)&QI<W0@
M)B!&24Q%7TQ)4U1?1$E24RDI("`@)B8*("`@("`@("`@("`@("`@("`@("`@
M("`@*"%I<U]C86QL86)L92@D8V(I('Q\(`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8V%L;%]U<V5R7V9U;F-?87)R87DH)&-B+"!A<G)A>2@F)&5N
M=')Y*2DI*2!["B`@("`@("`@("`@("`@("`@("`@)&5N=')I97-;72`]("AO
M8FIE8W0I(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`G;F%M92<@
M(#T^("1E;G1R>2P*("`@("`@("`@("`@("`@("`@("`@("`@)W-I>F4G("`]
M/B`D:7-$:7(@/R!N=6QL(#H@9FEL97-I>F4H)'!A=&@@+B<O)RX@)&5N=')Y
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@)V1A=&4G("`]/B!F:6QE;71I
M;64H)'!A=&@@+B<O)RX@)&5N=')Y*2P*("`@("`@("`@("`@("`@("`@("`I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@("1D:7(M/F-L;W-E*"D["B`@("`@("`@"B`@("`@("`@:68@*"1S
M;W)T*2!["B`@("`@("`@("`@("1E;G1R:65S(#T@1FEL95]5=&EL.CIS;W)T
M1FEL97,H)&5N=')I97,L("1S;W)T*3L*("`@("`@("!]"B`@("`@("`@"B`@
M("`@("`@<F5T=7)N("1E;G1R:65S.PH@("`@?0H@("`@"B`@("`O*BH*("`@
M("`J(%-O<G0@1FEL97,*("`@("`J(`H@("`@("H@0'-T871I8PH@("`@("H@
M0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<F5T=7)N("!A<G)A>0H@("`@("H@
M0'!A<F%M("`@87)R87D@("`D9FEL97,*("`@("`J($!P87)A;2`@(&EN="`@
M("`@)'-O<G0*("`@("`J+PH@("`@9G5N8W1I;VX@<V]R=$9I;&5S*"1F:6QE
M<RP@)'-O<G0I"B`@("!["B`@("`@("`@:68@*"$D9FEL97,I('L*("`@("`@
M("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("`@("`@?0H@("`@("`@(`H@("`@
M("`@(&EF("@A)'-O<G0I('L*("`@("`@("`@("`@<F5T=7)N("1F:6QE<SL*
M("`@("`@("!]"B`@("`@("`@"B`@("`@("`@:68@*"1S;W)T(#T]/2`Q*2![
M"B`@("`@("`@("`@(')E='5R;B!A<G)A>5]R979E<G-E*"1F:6QE<RD["B`@
M("`@("`@?0H@("`@("`@(`H@("`@("`@(&EF("@D<V]R="`F($9)3$5?4T]2
M5%]204Y$3TTI('L*("`@("`@("`@("`@<VAU9F9L92@D9FEL97,I.PH@("`@
M("`@("`@("!R971U<FX@)&9I;&5S.PH@("`@("`@('T*("`@("`@("`*("`@
M("`@("`D;F%M97,@/2!A<G)A>2@I.PH@("`@("`@("1S:7IE<R`](&%R<F%Y
M*"D["B`@("`@("`@)&1A=&5S(#T@87)R87DH*3L*("`@(`H@("`@("`@(&EF
M("@D<V]R="`F($9)3$5?4T]25%].04U%*2!["B`@("`@("`@("`@("1R(#T@
M)B1N86UE<SL*("`@("`@("!](&5L<V5I9B`H)'-O<G0@)B!&24Q%7U-/4E1?
M1$%412D@>PH@("`@("`@("`@("`D<B`]("8D9&%T97,["B`@("`@("`@?2!E
M;'-E:68@*"1S;W)T("8@1DE,15]33U)47U-)6D4I('L*("`@("`@("`@("`@
M)'(@/2`F)'-I>F5S.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&%S
M;W)T*"1F:6QE<RP@4T]25%]214=53$%2*3L*("`@("`@("`@("`@<F5T=7)N
M("1F:6QE<SL*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@)'-O<G1&;&%G
M<R`](&%R<F%Y*`H@("`@("`@("`@("!&24Q%7U-/4E1?3D%-12`]/B!33U)4
M7U-44DE.1RP@"B`@("`@("`@("`@($9)3$5?4T]25%]$051%(#T^(%-/4E1?
M3E5-15))0RP@"B`@("`@("`@("`@($9)3$5?4T]25%]325I%(#T^(%-/4E1?
M3E5-15))0RP*("`@("`@("`I.PH@("`@("`@(`H@("`@("`@(&9O<F5A8V@@
M*"1F:6QE<R!A<R`D9FEL92D@>PH@("`@("`@("`@("`D;F%M97-;72`]("1F
M:6QE+3YN86UE.PH@("`@("`@("`@("`D<VEZ97-;72`]("1F:6QE+3YS:7IE
M.PH@("`@("`@("`@("`D9&%T97-;72`]("1F:6QE+3YD871E.PH@("`@("`@
M('T*("`@("`@("`*("`@("`@("!I9B`H)'-O<G0@)B!&24Q%7U-/4E1?4D56
M15)312D@>PH@("`@("`@("`@("!A<G-O<G0H)'(L("1S;W)T1FQA9W-;)'-O
M<G0@)B!^,5TI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&%S;W)T
M*"1R+"`D<V]R=$9L86=S6R1S;W)T72D["B`@("`@("`@?0H@("`@"B`@("`@
M("`@)')E<W5L="`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'(@87,@
M)&D@/3X@)&8I('L*("`@("`@("`@("`@)')E<W5L=%M=(#T@)&9I;&5S6R1I
M73L*("`@("`@("!]"B`@("`*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M('T*("`@(`H@("`@+RHJ"B`@("`@*B!3=VET8V@@1FEL92!%>'1E;G-I;VX*
M("`@("`J(`H@("`@("H@0'-T871I8PH@("`@("H@0&%C8V5S<R`@<'5B;&EC
M"B`@("`@*B!`<F5T=7)N("!S=')I;F=\87)R87D*("`@("`J($!P87)A;2`@
M('-T<FEN9WQA<G)A>2`@("`D9FEL96YA;64*("`@("`J($!P87)A;2`@('-T
M<FEN9R`@("`@("`@("`D=&\@;F5W(&9I;&4@97AT96YS:6]N"B`@("`@*B!`
M<&%R86T@("!S=')I;F<@("`@("`@("`@)&9R;VT@8VAA;F=E(&]N;'D@9FEL
M97,@=VET:"!T:&ES(&5X=&5N<VEO;@H@("`@("H@0'!A<F%M("`@8F]O;"`@
M("`@("`@("`@("1R979E<G-E(&-H86YG92!O;FQY(&9I;&5S(&YO="!H879I
M;F<@)&9R;VT@97AT96YS:6]N"B`@("`@*B\*("`@(&9U;F-T:6]N('-W:71C
M:$5X="@D9FEL96YA;64L("1T;RP@)&9R;VT@/2!N=6QL+"`D<F5V97)S92`]
M(&9A;'-E*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D9FEL96YA;64I
M*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1F:6QE;F%M92!A<R`D:V5Y(#T^
M("1F:6QE*2!["B`@("`@("`@("`@("`@("`D9FEL96YA;65;)&ME>5T@/2!&
M:6QE7U5T:6PZ.G-W:71C:$5X="@D9FEL92P@)'1O+"`D9G)O;2D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1F:6QE;F%M93L*("`@("`@
M("!]"B`@("`@("`@"B`@("`@("`@:68@*"1L96X@/2!S=')L96XH)&9R;VTI
M*2!["B`@("`@("`@("`@("1E>'0@/2!S=6)S='(H)&9I;&5N86UE+"`M)&QE
M;B`M(#$I.PH@("`@("`@("`@("`D8V9N(#T@1DE,15]724XS,B`_("=S=')C
M87-E8VUP)R`Z("=S=')C;7`G.PH@("`@("`@("`@("!I9B`H(21R979E<G-E
M(#T]("1C9FXH)&5X="P@)RXG+B`D9G)O;2DI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M<F5T=7)N('-U8G-T<B@D9FEL96YA;64L(#`L("TD;&5N("T@,2D@+B<N)RX@
M)'1O.PH@("`@("`@('T*("`@("`@("`*("`@("`@("!I9B`H)'!O<R`]('-T
M<G!O<R@D9FEL96YA;64L("<N)RDI('L*("`@("`@("`@("`@<F5T=7)N('-U
M8G-T<B@D9FEL96YA;64L(#`L("1P;W,I("XG+B<N("1T;SL*("`@("`@("!]
M"B`@("`@("`@"B`@("`@("`@<F5T=7)N("1F:6QE;F%M92`N)RXG+B`D=&\[
M"B`@("!]"B`@("`*?0H*/SX*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]&:6QE+G!H<```````````````
M````````````````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T,#$P,@`Q,#4Q
M-30S,S<T,P`P,C`Q-S$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T
M;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!&
M:6QE"B`J(`H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%
M.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@
M;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@
M*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E
M(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L
M('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@
M=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A
M=&5G;W)Y("`@($9I;&4*("H@0'!A8VMA9V4@("`@($9I;&4*("H@0&%U=&AO
M<B`@("`@(%)I8VAA<F0@2&5Y97,@/')I8VAA<F1`<&AP+FYE=#X*("H@0&%U
M=&AO<B`@("`@(%1A;"!0965R(#QT86Q`<&AP+FYE=#X*("H@0&%U=&AO<B`@
M("`@($UI8VAA96P@5V%L;&YE<B`\;6EK94!P:'`N;F5T/@H@*B!`8V]P>7)I
M9VAT("`@,C`P,BTR,#`U(%1H92!!=71H;W)S"B`J($!L:6-E;G-E("`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS
M92`S+C`*("H@0'9E<G-I;VX@("`@($-64SH@)$ED.B!&:6QE+G!H<"QV(#$N
M,S$@,C`P-2\P-R\R,2`P-SHU,SHP.2!M:6ME($5X<"`D"B`J($!L:6YK("`@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1FEL90H@*B\*"B\J
M*@H@*B!297%U:7)E<R!014%2"B`J+PIR97%U:7)E7V]N8V4@)U!%05(N<&AP
M)SL*"B\J*@H@*B!4:&4@9&5F875L="!N=6UB97(@;V8@8GET97,@9F]R(')E
M861I;F<*("HO"FEF("@A9&5F:6YE9"@G1DE,15]$149!54Q47U)%041325I%
M)RDI('L*("`@(&1E9FEN92@G1DE,15]$149!54Q47U)%041325I%)RP@,3`R
M-"P@=')U92D["GT*"B\J*@H@*B!4:&4@;6%X:6UU;2!N=6UB97(@;V8@8GET
M97,@9F]R(')E861I;F<@;&EN97,*("HO"FEF("@A9&5F:6YE9"@G1DE,15]-
M05A?3$E.15]214%$4TE:12<I*2!["B`@("!D969I;F4H)T9)3$5?34%87TQ)
M3D5?4D5!1%-)6D4G+"`T,#DV,"P@=')U92D["GT*"B\J*@H@*B!7:&5T:&5R
M(&9I;&4@;&]C:W,@<VAO=6QD(&)L;V-K"B`J+PII9B`H(61E9FEN960H)T9)
M3$5?3$]#2U-?0DQ/0TLG*2D@>PH@("`@9&5F:6YE*"=&24Q%7TQ/0TM37T),
M3T-+)RP@=')U92P@=')U92D["GT*"B\J*@H@*B!-;V1E('1O('5S92!F;W(@
M<F5A9&EN9R!F<F]M(&9I;&5S"B`J+PID969I;F4H)T9)3$5?34]$15]214%$
M)RP@)W)B)RP@=')U92D["@HO*BH*("H@36]D92!T;R!U<V4@9F]R('1R=6YC
M871I;F<@9FEL97,L('1H96X@=W)I=&EN9PH@*B\*9&5F:6YE*"=&24Q%7TU/
M1$5?5U))5$4G+"`G=V(G+"!T<G5E*3L*"B\J*@H@*B!-;V1E('1O('5S92!F
M;W(@87!P96YD:6YG('1O(&9I;&5S"B`J+PID969I;F4H)T9)3$5?34]$15]!
M4%!%3D0G+"`G86(G+"!T<G5E*3L*"B\J*@H@*B!5<V4@=&AI<R!W:&5N(&$@
M<VAA<F5D("AR96%D*2!L;V-K(&ES(')E<75I<F5D"B`J+PID969I;F4H)T9)
M3$5?3$]#2U]32$%2140G+"!,3T-+7U-(('P@*$9)3$5?3$]#2U-?0DQ/0TL@
M/R`P(#H@3$]#2U].0BDL('1R=64I.PH*+RHJ"B`J(%5S92!T:&ES('=H96X@
M86X@97AC;'5S:79E("AW<FET92D@;&]C:R!I<R!R97%U:7)E9`H@*B\*9&5F
M:6YE*"=&24Q%7TQ/0TM?15A#3%53259%)RP@3$]#2U]%6"!\("A&24Q%7TQ/
M0TM37T),3T-+(#\@,"`Z($Q/0TM?3D(I+"!T<G5E*3L*"B\J*@H@*B!#;&%S
M<R!F;W(@:&%N9&QI;F<@9FEL97,*("H@"B`J($$@8VQA<W,@=VET:"!C;VUM
M;VX@9G5N8W1I;VYS(&9O<B!W<FET:6YG+`H@*B!R96%D:6YG(&%N9"!H86YD
M;&EN9R!F:6QE<R!A;F0@9&ER96-T;W)I97,*("H@"B`J($!A=71H;W(@(%)I
M8VAA<F0@2&5Y97,@/')I8VAA<F1`<&AP+FYE=#X*("H@0&%U=&AO<B`@5&%L
M(%!E97(@/'1A;$!P:'`N;F5T/@H@*B!`875T:&]R("!-:6-H865L(%=A;&QN
M97(@/&UI:V5`<&AP+FYE=#X*("H@0&%C8V5S<R`@<'5B;&EC(`H@*B!`<&%C
M:V%G92!&:6QE"B`J(`H@*B!`<W1A=&EC"B`J+PIC;&%S<R!&:6QE(&5X=&5N
M9',@4$5!4B`*>PH@("`@+RHJ"B`@("`@*B!$97-T<G5C=&]R"B`@("`@*B`*
M("`@("`J(%5N;&]C:W,@86YY(&QO8VME9"!F:6QE('!O:6YT97)S(&%N9"!C
M;&]S97,@86QL(&9I;&5P;VEN=&5R<PH@("`@("H@"B`@("`@*B!`86-C97-S
M('!R:79A=&4@"B`@("`@*B\*("`@(&9U;F-T:6]N(%]&:6QE*"D*("`@('L*
M("`@("`@("!&:6QE.CIC;&]S94%L;"@I.PH@("`@?0H@("`@"B`@("`O*BH*
M("`@("`J($AA;F1L97,@9FEL92!P;VEN=&5R<RX@268@82!F:6QE('!O:6YT
M97(@;F5E9',@=&\@8F4@;W!E;F5D+`H@("`@("H@:70@=VEL;"!B92X@268@
M:70@86QR96%D>2!E>&ES=',@*&)A<V5D(&]N(&9I;&5N86UE(&%N9"!M;V1E
M*0H@("`@("H@=&AE;B!T:&4@97AI<W1I;F<@;VYE('=I;&P@8F4@<F5T=7)N
M960N"B`@("`@*B`*("`@("`J($!A8V-E<W,@('!R:79A=&4@"B`@("`@*B!`
M<&%R86T@("!S=')I;F<@("1F:6QE;F%M92!&:6QE;F%M92!T;R!B92!U<V5D
M"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1M;V1E($UO9&4@=&\@;W!E;B!T
M:&4@9FEL92!I;@H@("`@("H@0'!A<F%M("`@;6EX960@("`D;&]C:R!4>7!E
M(&]F(&QO8VL@=&\@=7-E"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@(%!%05)?
M17)R;W(@;VX@97)R;W(@;W(@9FEL92!P;VEN=&5R(')E<V]U<F-E(&]N('-U
M8V-E<W,*("`@("`J+PH@("`@9G5N8W1I;VX@)E]G971&:6QE4&]I;G1E<B@D
M9FEL96YA;64L("1M;V1E+"`D;&]C:R`](&9A;'-E*0H@("`@>PH@("`@("`@
M("1F:6QE4&]I;G1E<G,@/2`F4$5!4CHZ9V5T4W1A=&EC4')O<&5R='DH)T9I
M;&4G+"`G9FEL95!O:6YT97)S)RD["B`@("`@("`@"B`@("`@("`@+R\@5VEN
M,S(@:7,@8V%S92UI;G-E;G-I=&EV90H@("`@("`@(&EF("A/4U]724Y$3U=3
M*2!["B`@("`@("`@("`@("1F:6QE;F%M92`]('-T<E1O3&]W97(H)&9I;&5N
M86UE*3L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@+R\@8VAE8VL@:68@
M9FEL92!P;VEN=&5R(&%L<F5A9'D@97AI<W1S"B`@("`@("`@:68@*"`@("`A
M:7-S970H)&9I;&50;VEN=&5R<ULD9FEL96YA;65=6R1M;V1E72D@?'P@"B`@
M("`@("`@("`@("`@("`A:7-?<F5S;W5R8V4H)&9I;&50;VEN=&5R<ULD9FEL
M96YA;65=6R1M;V1E72DI('L*("`@("`@("`@("`@"B`@("`@("`@("`@("\O
M(&-H96-K(&EF('=E(&-A;B!O<&5N('1H92!F:6QE(&EN('1H92!D97-I<F5D
M(&UO9&4*("`@("`@("`@("`@<W=I=&-H("@D;6]D92D*("`@("`@("`@("`@
M>PH@("`@("`@("`@("`@("`@8V%S92!&24Q%7TU/1$5?4D5!1#H*("`@("`@
M("`@("`@("`@("`@("!I9B`H("`@("%P<F5G7VUA=&-H*"<O7BXK*#\\(69I
M;&4I.EPO7"\O:2<L("1F:6QE;F%M92D@)B8*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("%F:6QE7V5X:7-T<R@D9FEL96YA;64I*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")&:6QE
M(&1O97,@;F]T(&5X:7-T.B`D9FEL96YA;64B*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M(`H@("`@("`@("`@("`@("`@8V%S92!&24Q%7TU/1$5?05!014Y$.@H@("`@
M("`@("`@("`@("`@8V%S92!&24Q%7TU/1$5?5U))5$4Z"B`@("`@("`@("`@
M("`@("`@("`@:68@*&9I;&5?97AI<W1S*"1F:6QE;F%M92DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<U]W<FET86)L92@D9FEL96YA;64I
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@B1FEL92!I<R!N;W0@=W)I=&%B;&4Z("1F:6QE;F%M92(I
M.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E:68@*"%I<U]W<FET86)L92@D9&ER(#T@9&ER;F%M92@D9FEL
M96YA;64I*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@B0V%N;F]T(&-R96%T92!F:6QE(&EN(&1I<F5C=&]R
M>3H@)&1I<B(I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@"B`@("`@("`@("`@("`@("!D
M969A=6QT.@H@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*"));G9A;&ED(&%C8V5S<R!M;V1E.B`D;6]D92(I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(`H@("`@("`@("`@("`O+R!O<&5N(&9I;&4*
M("`@("`@("`@("`@)&9I;&50;VEN=&5R<ULD9FEL96YA;65=6R1M;V1E72`]
M($!F;W!E;B@D9FEL96YA;64L("1M;V1E*3L*("`@("`@("`@("`@:68@*"%I
M<U]R97-O=7)C92@D9FEL95!O:6YT97)S6R1F:6QE;F%M95U;)&UO9&5=*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9A
M:6QE9"!T;R!O<&5N(&9I;&4Z("<@+B`D9FEL96YA;64I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@(`H@("`@("`@("\O(&QO8VL@9FEL90H@
M("`@("`@(&EF("@D;&]C:RD@>PH@("`@("`@("`@("`D;&]C:R`]("1M;V1E
M(#T]($9)3$5?34]$15]214%$(#\@1DE,15],3T-+7U-(05)%1"`Z($9)3$5?
M3$]#2U]%6$-,55-)5D4["B`@("`@("`@("`@("1L;V-K<R`]("9014%2.CIG
M9713=&%T:6-0<F]P97)T>2@G1FEL92<L("=L;V-K<R<I.PH@("`@("`@("`@
M("!I9B`H0&9L;V-K*"1F:6QE4&]I;G1E<G-;)&9I;&5N86UE75LD;6]D95TL
M("1L;V-K*2D@>PH@("`@("`@("`@("`@("`@)&QO8VMS6UT@/2`F)&9I;&50
M;VEN=&5R<ULD9FEL96YA;65=6R1M;V1E73L*("`@("`@("`@("`@?2!E;'-E
M:68@*$9)3$5?3$]#2U-?0DQ/0TLI('L*("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*")&:6QE(&%L<F5A9'D@;&]C:V5D.B`D9FEL
M96YA;64B*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*")#;W5L9"!N;W0@;&]C:R!F:6QE
M.B`D9FEL96YA;64B*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("`*("`@("`@("!R971U<FX@)&9I;&50;VEN=&5R<ULD9FEL96YA;65=6R1M
M;V1E73L*("`@('T@"@H@("`@+RHJ"B`@("`@*B!296%D<R!A;B!E;G1I<F4@
M9FEL92!A;F0@<F5T=7)N<R!I="X*("`@("`J(%5S97,@9FEL95]G971?8V]N
M=&5N=',@:68@879A:6QA8FQE+@H@("`@("H@"B`@("`@*B!`86-C97-S("!P
M=6)L:6,@"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1F:6QE;F%M92!.86UE
M(&]F(&9I;&4@=&\@<F5A9"!F<F]M"B`@("`@*B!`<&%R86T@("!M:7AE9"`@
M("1L;V-K(%1Y<&4@;V8@;&]C:R!T;R!U<V4*("`@("`J($!R971U<FX@(&UI
M>&5D("`@4$5!4E]%<G)O<B!I9B!A;B!E<G)O<B!H87,@;V-C=7)E9"!O<B!A
M('-T<FEN9R!W:71H('1H92!C;VYT96YT<R!O9B!T:&4@=&AE(&9I;&4*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F5A9$%L;"@D9FEL96YA;64L("1L;V-K(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G9FEL
M95]G971?8V]N=&5N=',G*2D@>PH@("`@("`@("`@("!I9B`H9F%L<V4@/3T]
M("1F:6QE(#T@0&9I;&5?9V5T7V-O;G1E;G1S*"1F:6QE;F%M92DI('L*("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#86YN;W0@
M<F5A9"!F:6QE.B`D9FEL96YA;64B*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!R971U<FX@)&9I;&4["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@
M("1F:6QE(#T@)R<["B`@("`@("`@=VAI;&4@*&9A;'-E("$]/2`D8G5F(#T@
M1FEL93HZ<F5A9"@D9FEL96YA;64L($9)3$5?1$5&055,5%]214%$4TE:12P@
M)&QO8VLI*2!["B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1B=68I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&)U9CL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D9FEL92`N/2`D8G5F.PH@("`@("`@('T*("`@("`@
M("`*("`@("`@("`O+R!C;&]S92!T:&4@9FEL92!P;VEN=&5R"B`@("`@("`@
M1FEL93HZ8VQO<V4H)&9I;&5N86UE+"!&24Q%7TU/1$5?4D5!1"D["B`@("`@
M("`@"B`@("`@("`@<F5T=7)N("1F:6QE.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A('-P96-I9FEE9"!N=6UB97(@;V8@8GET97,@;V8@82!F
M:6QE+B`*("`@("`J($1E9F%U;'1S('1O($9)3$5?1$5&055,5%]214%$4TE:
M12X@($EF("1S:7IE(&ES(#`L(&%L;"!F:6QE('=I;&P@8F4@<F5A9"X*("`@
M("`J(`H@("`@("H@0&%C8V5S<R`@<'5B;&EC(`H@("`@("H@0'!A<F%M("`@
M<W1R:6YG("`D9FEL96YA;64@3F%M92!O9B!F:6QE('1O(')E860@9G)O;0H@
M("`@("H@0'!A<F%M("`@:6YT96=E<B`D<VEZ92!">71E<R!T;R!R96%D"B`@
M("`@*B!`<&%R86T@("!M:7AE9"`@("1L;V-K(%1Y<&4@;V8@;&]C:R!T;R!U
M<V4*("`@("`J($!R971U<FX@(&UI>&5D("`@4$5!4E]%<G)O<B!O;B!E<G)O
M<B!O<B!A('-T<FEN9R!W:&EC:"!C;VYT86EN<R!T:&4@9&%T82!R96%D"B`@
M("`@*B`@("`@("`@("`@("`@("`@(%=I;&P@86QS;R!R971U<FX@9F%L<V4@
M=7!O;B!%3T8*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9"@D9FEL96YA;64L
M("1S:7IE(#T@1DE,15]$149!54Q47U)%041325I%+"`D;&]C:R`](&9A;'-E
M*0H@("`@>PH@("`@("`@('-T871I8R`D9FEL95!O:6YT97)S.PH@("`@("`@
M(`H@("`@("`@(&EF("@P(#T]("1S:7IE*2!["B`@("`@("`@("`@(')E='5R
M;B!&:6QE.CIR96%D06QL*"1F:6QE;F%M92P@)&QO8VLI.PH@("`@("`@('T@
M"@H@("`@("`@(&EF("@@("`@(6ES<V5T*"1F:6QE4&]I;G1E<G-;)&9I;&5N
M86UE72D@?'P@"B`@("`@("`@("`@("`@("`A:7-?<F5S;W5R8V4H)&9I;&50
M;VEN=&5R<ULD9FEL96YA;65=*2D@>PH@("`@("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D9G`@/2`F1FEL93HZ7V=E=$9I;&50;VEN=&5R*"1F:6QE;F%M
M92P@1DE,15]-3T1%7U)%040L("1L;V-K*2DI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D9G`["B`@("`@("`@("`@('T@"@H@("`@("`@("`@("`D9FEL
M95!O:6YT97)S6R1F:6QE;F%M95T@/2`F)&9P.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1F<"`]("8D9FEL95!O:6YT97)S6R1F:6QE;F%M95T[
M"B`@("`@("`@?2`*"B`@("`@("`@<F5T=7)N("%F96]F*"1F<"D@/R!F<F5A
M9"@D9G`L("1S:7IE*2`Z(&9A;'-E.PH@("`@?2`*"B`@("`O*BH*("`@("`J
M(%=R:71E<R!T:&4@9VEV96X@9&%T82!T;R!T:&4@9VEV96X@9FEL96YA;64N
M(`H@("`@("H@1&5F875L=',@=&\@;F\@;&]C:RP@87!P96YD(&UO9&4N"B`@
M("`@*B`*("`@("`J($!A8V-E<W,@('!U8FQI8R`*("`@("`J($!P87)A;2`@
M('-T<FEN9R`@)&9I;&5N86UE($YA;64@;V8@9FEL92!T;R!W<FET92!T;PH@
M("`@("H@0'!A<F%M("`@<W1R:6YG("`D9&%T82!$871A('1O('=R:71E('1O
M(&9I;&4*("`@("`J($!P87)A;2`@('-T<FEN9R`@)&UO9&4@36]D92!T;R!O
M<&5N(&9I;&4@:6X*("`@("`J($!P87)A;2`@(&UI>&5D("`@)&QO8VL@5'EP
M92!O9B!L;V-K('1O('5S90H@("`@("H@0')E='5R;B`@;6EX960@("!014%2
M7T5R<F]R(&]N(&5R<F]R(&]R(&YU;6)E<B!O9B!B>71E<R!W<FET=&5N('1O
M(&9I;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E*"1F:6QE;F%M92P@
M)&1A=&$L("1M;V1E(#T@1DE,15]-3T1%7T%04$5.1"P@)&QO8VL@/2!F86QS
M92D*("`@('L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D9G`@/2`F1FEL
M93HZ7V=E=$9I;&50;VEN=&5R*"1F:6QE;F%M92P@)&UO9&4L("1L;V-K*2DI
M('L*("`@("`@("`@("`@<F5T=7)N("1F<#L*("`@("`@("!]"B`@("`@("`@
M:68@*"TQ(#T]/2`D8GET97,@/2!`9G=R:71E*"1F<"P@)&1A=&$L('-T<FQE
M;B@D9&%T82DI*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*")#86YN;W0@=W)I=&4@9&%T83H@)R1D871A)R!T;R!F:6QE.B`G)&9I
M;&5N86UE)R(I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&)Y=&5S.PH@
M("`@?2`*"B`@("`O*BH*("`@("`J(%)E861S(&%N9"!R971U<FYS(&$@<VEN
M9VQE(&-H87)A8W1E<B!F<F]M(&=I=F5N(&9I;&5N86UE"B`@("`@*B`*("`@
M("`J($!A8V-E<W,@('!U8FQI8R`*("`@("`J($!P87)A;2`@('-T<FEN9R`@
M)&9I;&5N86UE($YA;64@;V8@9FEL92!T;R!R96%D(&9R;VT*("`@("`J($!P
M87)A;2`@(&UI>&5D("`@)&QO8VL@5'EP92!O9B!L;V-K('1O('5S90H@("`@
M("H@0')E='5R;B`@;6EX960@("!014%27T5R<F]R(&]N(&5R<F]R(&]R(&]N
M92!C:&%R86-T97(@;V8@=&AE('-P96-I9FEE9"!F:6QE"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')E861#:&%R*"1F:6QE;F%M92P@)&QO8VL@/2!F86QS92D*
M("`@('L*("`@("`@("!R971U<FX@1FEL93HZ<F5A9"@D9FEL96YA;64L(#$L
M("1L;V-K*3L*("`@('T@"@H@("`@+RHJ"B`@("`@*B!7<FET97,@82!S:6YG
M;&4@8VAA<F%C=&5R('1O(&$@9FEL90H@("`@("H@"B`@("`@*B!`86-C97-S
M("!P=6)L:6,@"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1F:6QE;F%M92!.
M86UE(&]F(&9I;&4@=&\@=W)I=&4@=&\*("`@("`J($!P87)A;2`@('-T<FEN
M9R`@)&-H87(@0VAA<F%C=&5R('1O('=R:71E"B`@("`@*B!`<&%R86T@("!S
M=')I;F<@("1M;V1E($UO9&4@=&\@=7-E('=H96X@=W)I=&EN9PH@("`@("H@
M0'!A<F%M("`@;6EX960@("`D;&]C:R!4>7!E(&]F(&QO8VL@=&\@=7-E"B`@
M("`@*B!`<F5T=7)N("!M:7AE9"`@(%!%05)?17)R;W(@;VX@97)R;W(L(&]R
M(#$@;VX@<W5C8V5S<PH@("`@("HO"B`@("!F=6YC=&EO;B!W<FET94-H87(H
M)&9I;&5N86UE+"`D8VAA<BP@)&UO9&4@/2!&24Q%7TU/1$5?05!014Y$+"`D
M;&]C:R`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1F<"`]("9&:6QE.CI?9V5T1FEL95!O:6YT97(H)&9I;&5N86UE+"`D;6]D
M92P@)&QO8VLI*2D@>PH@("`@("`@("`@("!R971U<FX@)&9P.PH@("`@("`@
M('T*("`@("`@("!I9B`H+3$@/3T]($!F=W)I=&4H)&9P+"`D8VAA<BP@,2DI
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-A;FYO
M="!W<FET92!D871A.B`G)&1A=&$G('1O(&9I;&4Z("<D9FEL96YA;64G(BD[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`Q.PH@("`@?2`*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@82!L:6YE(&]F('1H92!F:6QE("AW:71H;W5T('1R
M86EL:6YG($-23$8I+@H@("`@("H@36%X:6UU;2!R96%D(&QI;F4@;&5N9W1H
M(&ES($9)3$5?34%87TQ)3D5?4D5!1%-)6D4N"B`@("`@*B`*("`@("`J($!A
M8V-E<W,@('!U8FQI8R`*("`@("`J($!P87)A;2`@('-T<FEN9R`@)&9I;&5N
M86UE($YA;64@;V8@9FEL92!T;R!R96%D(&9R;VT*("`@("`J($!P87)A;2`@
M(&)O;VQE86X@)&QO8VL@5VAE=&AE<B!F:6QE('-H;W5L9"!B92!L;V-K960*
M("`@("`J($!R971U<FX@(&UI>&5D("`@4$5!4E]%<G)O<B!O;B!E<G)O<B!O
M<B!A('-T<FEN9R!C;VYT86EN:6YG('1H92!L:6YE(')E860@9G)O;2!F:6QE
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E861,:6YE*"1F:6QE;F%M92P@)&QO
M8VL@/2!F86QS92D*("`@('L*("`@("`@("!S=&%T:6,@)&9I;&50;VEN=&5R
M<SL@+R\@57-E9"!T;R!P<F5V96YT('5N;F5C97-S87)Y(&-A;&QS('1O(%]G
M971&:6QE4&]I;G1E<B@I"B`@("`@("`@"B`@("`@("`@:68@*"`@("`A:7-S
M970H)&9I;&50;VEN=&5R<ULD9FEL96YA;65=*2!\?"`*("`@("`@("`@("`@
M("`@("%I<U]R97-O=7)C92@D9FEL95!O:6YT97)S6R1F:6QE;F%M95TI*2![
M"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1F<"`]("9&:6QE.CI?
M9V5T1FEL95!O:6YT97(H)&9I;&5N86UE+"!&24Q%7TU/1$5?4D5!1"P@)&QO
M8VLI*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1F<#L*("`@("`@("`@
M("`@?2`*"B`@("`@("`@("`@("1F:6QE4&]I;G1E<G-;)&9I;&5N86UE72`]
M("8D9G`["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&9P(#T@)B1F
M:6QE4&]I;G1E<G-;)&9I;&5N86UE73L*("`@("`@("!](`H*("`@("`@("!I
M9B`H9F5O9B@D9G`I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!](`H@("`@("`@(`H@("`@("`@(')E='5R;B!R=')I;2AF9V5T<R@D
M9G`L($9)3$5?34%87TQ)3D5?4D5!1%-)6D4I+"`B7')<;B(I.PH@("`@?2`*
M"B`@("`O*BH*("`@("`J(%=R:71E<R!A('-I;F=L92!L:6YE+"!A<'!E;F1I
M;F<@82!,1B`H8GD@9&5F875L="D*("`@("`J(`H@("`@("H@0&%C8V5S<R`@
M<'5B;&EC(`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`D9FEL96YA;64@3F%M
M92!O9B!F:6QE('1O('=R:71E('1O"B`@("`@*B!`<&%R86T@("!S=')I;F<@
M("1L:6YE($QI;F4@;V8@9&%T82!T;R!B92!W<FET=&5N('1O(&9I;&4*("`@
M("`J($!P87)A;2`@('-T<FEN9R`@)&UO9&4@5W)I=&4@;6]D92P@8V%N(&)E
M(&5I=&AE<B!&24Q%7TU/1$5?5U))5$4@;W(@1DE,15]-3T1%7T%04$5.1`H@
M("`@("H@0'!A<F%M("`@<W1R:6YG("`D8W)L9B!4:&4@0U),1B!Y;W5R('-Y
M<W1E;2!I<R!U<VEN9RX@54Y)6"`](%QN(%=I;F1O=W,@/2!<<EQN($UA8R`]
M(%QR"B`@("`@*B!`<&%R86T@("!M:7AE9"`@("1L;V-K(%=H971H97(@=&\@
M;&]C:R!T:&4@9FEL90H@("`@("H@0')E='5R;B`@;6EX960@("!014%27T5R
M<F]R(&]N(&5R<F]R(&]R(&YU;6)E<B!O9B!B>71E<R!W<FET=&5N('1O(&9I
M;&4@*&EN8VQU9&EN9R!A<'!E;F1E9"!C<FQF*0H@("`@("HO"B`@("!F=6YC
M=&EO;B!W<FET94QI;F4H)&9I;&5N86UE+"`D;&EN92P@)&UO9&4@/2!&24Q%
M7TU/1$5?05!014Y$+"`D8W)L9B`](")<;B(L("1L;V-K(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&9P(#T@)D9I;&4Z.E]G
M971&:6QE4&]I;G1E<B@D9FEL96YA;64L("1M;V1E+"`D;&]C:RDI*2!["B`@
M("`@("`@("`@(')E='5R;B`D9G`["B`@("`@("`@?0H@("`@("`@(&EF("@M
M,2`]/3T@)&)Y=&5S(#T@9G=R:71E*"1F<"P@)&QI;F4@+B`D8W)L9BDI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-A;FYO="!W
M<FET92!D871A.B`G)&1A=&$G('1O(&9I;&4Z("<D9FEL92<B*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1B>71E<SL*("`@('T@"@H@("`@+RHJ"B`@
M("`@*B!4:&ES(')E=VEN9',@82!F:6QE<&]I;G1E<B!T;R!T:&4@<W1A<G0@
M;V8@82!F:6QE"B`@("`@*B`*("`@("`J($!A8V-E<W,@('!U8FQI8R`*("`@
M("`J($!P87)A;2`@('-T<FEN9R`@)&9I;&5N86UE(%1H92!F:6QE;F%M90H@
M("`@("H@0'!A<F%M("`@<W1R:6YG("`D;6]D92!-;V1E('1H92!F:6QE('=A
M<R!O<&5N960@:6X*("`@("`J($!R971U<FX@(&UI>&5D("`@4$5!4B!%<G)O
M<B!O;B!E<G)O<BP@=')U92!O;B!S=6-C97-S"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')E=VEN9"@D9FEL96YA;64L("1M;V1E*0H@("`@>PH@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1F<"`]("9&:6QE.CI?9V5T1FEL95!O:6YT97(H
M)&9I;&5N86UE+"`D;6]D92DI*2!["B`@("`@("`@("`@(')E='5R;B`D9G`[
M"B`@("`@("`@?0H@("`@("`@(&EF("@A0')E=VEN9"@D9G`I*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#86YN;W0@<F5W:6YD
M(&9I;&4Z("1F:6QE;F%M92(I.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M=')U93L*("`@('T@"@H@("`@+RHJ"B`@("`@*B!#;&]S97,@86QL(&]P96X@
M9FEL92!P;VEN=&5R<PH@("`@("H@"B`@("`@*B!`86-C97-S("!P=6)L:6,*
M("`@("`J($!R971U<FX@('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@8VQO
M<V5!;&PH*0H@("`@>PH@("`@("`@("1L;V-K<R`]("9014%2.CIG9713=&%T
M:6-0<F]P97)T>2@G1FEL92<L("=L;V-K<R<I.PH@("`@("`@("1F:6QE4&]I
M;G1E<G,@/2`F4$5!4CHZ9V5T4W1A=&EC4')O<&5R='DH)T9I;&4G+"`G9FEL
M95!O:6YT97)S)RD["B`@("`@("`@"B`@("`@("`@+R\@=6YL;V-K(&9I;&5S
M"B`@("`@("`@9F]R("@D:2`](#`L("1C(#T@8V]U;G0H)&QO8VMS*3L@)&D@
M/"`D8SL@)&DK*RD@>PH@("`@("`@("`@("!I<U]R97-O=7)C92@D;&]C:W-;
M)&E=*2!A;F0@0&9L;V-K*"1L;V-K<ULD:5TL($Q/0TM?54XI.PH@("`@("`@
M('T*("`@("`@("`*("`@("`@("`O+R!C;&]S92!F:6QE<PH@("`@("`@(&EF
M("@A96UP='DH)&9I;&50;VEN=&5R<RDI('L*("`@("`@("`@("`@9F]R96%C
M:"`H)&9I;&50;VEN=&5R<R!A<R`D9FYA;64@/3X@)&UO9&5S*2!["B`@("`@
M("`@("`@("`@("!F;W)E86-H("AA<G)A>5]K97ES*"1M;V1E<RD@87,@)&UO
M9&4I('L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?<F5S;W5R8V4H)&9I
M;&50;VEN=&5R<ULD9FYA;65=6R1M;V1E72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@0&9C;&]S92@D9FEL95!O:6YT97)S6R1F;F%M95U;)&UO9&5=
M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M=6YS970H)&9I;&50;VEN=&5R<ULD9FYA;65=6R1M;V1E72D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"B`@("`*
M("`@("\J*@H@("`@("H@5&AI<R!C;&]S97,@86X@;W!E;B!F:6QE('!O:6YT
M97(*("`@("`J(`H@("`@("H@0&%C8V5S<R`@<'5B;&EC(`H@("`@("H@0'!A
M<F%M("`@<W1R:6YG("`D9FEL96YA;64@5&AE(&9I;&5N86UE('1H870@=V%S
M(&]P96YE9`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`D;6]D92!-;V1E('1H
M92!F:6QE('=A<R!O<&5N960@:6X*("`@("`J($!R971U<FX@(&UI>&5D("`@
M4$5!4B!%<G)O<B!O;B!E<G)O<BP@=')U92!O=&AE<G=I<V4*("`@("`J+PH@
M("`@9G5N8W1I;VX@8VQO<V4H)&9I;&5N86UE+"`D;6]D92D*("`@('L*("`@
M("`@("`D9FEL95!O:6YT97)S(#T@)E!%05(Z.F=E=%-T871I8U!R;W!E<G1Y
M*"=&:6QE)RP@)V9I;&50;VEN=&5R<R<I.PH@("`@("`@(`H@("`@("`@(&EF
M("A/4U]724Y$3U=3*2!["B`@("`@("`@("`@("1F:6QE;F%M92`]('-T<E1O
M3&]W97(H)&9I;&5N86UE*3L*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E
M="@D9FEL95!O:6YT97)S6R1F:6QE;F%M95U;)&UO9&5=*2D@>PH@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@
M)&9P(#T@)&9I;&50;VEN=&5R<ULD9FEL96YA;65=6R1M;V1E73L*("`@("`@
M("!U;G-E="@D9FEL95!O:6YT97)S6R1F:6QE;F%M95U;)&UO9&5=*3L*("`@
M("`@("`*("`@("`@("!I9B`H:7-?<F5S;W5R8V4H)&9P*2D@>PH@("`@("`@
M("`@("`O+R!U;FQO8VL@9FEL90H@("`@("`@("`@("!`9FQO8VLH)&9P+"!,
M3T-+7U5.*3L*("`@("`@("`@("`@+R\@8VQO<V4@9FEL90H@("`@("`@("`@
M("!I9B`H(4!F8VQO<V4H)&9P*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H(D-A;FYO="!C;&]S92!F:6QE.B`D9FEL96YA
M;64B*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`*("`@("`@
M("!R971U<FX@=')U93L*("`@('T@"@H@("`@+RHJ"B`@("`@*B!4:&ES('5N
M;&]C:W,@82!L;V-K960@9FEL92!P;VEN=&5R+@H@("`@("H@"B`@("`@*B!`
M86-C97-S("!P=6)L:6,@"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1F:6QE
M;F%M92!4:&4@9FEL96YA;64@=&AA="!W87,@;W!E;F5D"B`@("`@*B!`<&%R
M86T@("!S=')I;F<@("1M;V1E($UO9&4@=&AE(&9I;&4@=V%S(&]P96YE9"!I
M;@H@("`@("H@0')E='5R;B`@;6EX960@("!014%2($5R<F]R(&]N(&5R<F]R
M+"!T<G5E(&]T:&5R=VES90H@("`@("HO"B`@("!F=6YC=&EO;B!U;FQO8VLH
M)&9I;&5N86UE+"`D;6]D92D*("`@('L*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D9G`@/2`F1FEL93HZ7V=E=$9I;&50;VEN=&5R*"1F:6QE;F%M92P@
M)&UO9&4I*2D@>PH@("`@("`@("`@("!R971U<FX@)&9P.PH@("`@("`@('T*
M("`@("`@("!I9B`H(4!F;&]C:R@D9G`L($Q/0TM?54XI*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#86-N;F]T('5N;&]C:R!F
M:6QE.B`D9FEL96YA;64B*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!](`H*("`@("\J*@H@("`@("H@0&1E<')E8V%T960*("`@("`J
M+PH@("`@9G5N8W1I;VX@<W1R:7!4<F%I;&EN9U-E<&%R871O<G,H)'!A=&@L
M("1S97!A<F%T;W(@/2!$25)%0U1/4EE?4T5005)!5$]2*0H@("`@>PH@("`@
M("`@(')E='5R;B!R=')I;2@D<&%T:"P@)'-E<&%R871O<BD["B`@("!](`H*
M("`@("\J*@H@("`@("H@0&1E<')E8V%T960*("`@("`J+PH@("`@9G5N8W1I
M;VX@<W1R:7!,96%D:6YG4V5P87)A=&]R<R@D<&%T:"P@)'-E<&%R871O<B`]
M($1)4D5#5$]265]315!!4D%43U(I"B`@("!["B`@("`@("`@<F5T=7)N(&QT
M<FEM*"1P871H+"`D<V5P87)A=&]R*3L*("`@('T@"@H@("`@+RHJ"B`@("`@
M*B!`9&5P<F5C871E9"`@("`@(%5S92!&:6QE7U5T:6PZ.F)U:6QD4&%T:"@I
M(&EN<W1E860N"B`@("`@*B\*("`@(&9U;F-T:6]N(&)U:6QD4&%T:"@D<&%R
M=',L("1S97!A<F%T;W(@/2!$25)%0U1/4EE?4T5005)!5$]2*0H@("`@>PH@
M("`@("`@(')E<75I<F5?;VYC92`G1FEL92]5=&EL+G!H<"<["B`@("`@("`@
M<F5T=7)N($9I;&5?571I;#HZ8G5I;&10871H*"1P87)T<RP@)'-E<&%R871O
M<BD["B`@("!](`H*("`@("\J*@H@("`@("H@0&1E<')E8V%T960@("`@("!5
M<V4@1FEL95]5=&EL.CIS:VEP4F]O="@I(&EN<W1E860N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-K:7!2;V]T*"1P871H*0H@("`@>PH@("`@("`@(')E<75I
M<F5?;VYC92`G1FEL92]5=&EL+G!H<"<["B`@("`@("`@<F5T=7)N($9I;&5?
M571I;#HZ<VMI<%)O;W0H)'!A=&@I.PH@("`@?2`*"B`@("`O*BH*("`@("`J
M($!D97!R96-A=&5D("`@("`@57-E($9I;&5?571I;#HZ=&UP1&ER*"D@:6YS
M=&5A9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5&5M<$1I<B@I"B`@("![
M"B`@("`@("`@<F5Q=6ER95]O;F-E("=&:6QE+U5T:6PN<&AP)SL*("`@("`@
M("!R971U<FX@1FEL95]5=&EL.CIT;7!$:7(H*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($!D97!R96-A=&5D("`@("`@57-E($9I;&5?571I;#HZ=&UP1FEL
M92@I(&EN<W1E860N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1E;7!&:6QE
M*"1D:7)N86UE(#T@;G5L;"D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@
M)T9I;&4O571I;"YP:'`G.PH@("`@("`@(')E='5R;B!&:6QE7U5T:6PZ.G1M
M<$9I;&4H)&1I<FYA;64I.PH@("`@?2`*"B`@("`O*BH*("`@("`J($!D97!R
M96-A=&5D("`@("`@57-E($9I;&5?571I;#HZ:7-!8G-O;'5T92@I(&EN<W1E
M860N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES06)S;VQU=&4H)'!A=&@I"B`@
M("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=&:6QE+U5T:6PN<&AP)SL*("`@
M("`@("!R971U<FX@1FEL95]5=&EL.CII<T%B<V]L=71E*"1P871H*3L*("`@
M('T@"@H@("`@+RHJ"B`@("`@*B!`9&5P<F5C871E9"`@("`@(%5S92!&:6QE
M7U5T:6PZ.G)E;&%T:79E4&%T:"@I(&EN<W1E860N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(')E;&%T:79E4&%T:"@D<&%T:"P@)')O;W0L("1S97!A<F%T;W(@
M/2!$25)%0U1/4EE?4T5005)!5$]2*0H@("`@>PH@("`@("`@(')E<75I<F5?
M;VYC92`G1FEL92]5=&EL+G!H<"<["B`@("`@("`@<F5T=7)N($9I;&5?571I
M;#HZ<F5L871I=F50871H*"1P871H+"`D<F]O="P@)'-E<&%R871O<BD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!`9&5P<F5C871E9"`@("`@(%5S92!&:6QE
M7U5T:6PZ.G)E86QP871H*"D@:6YS=&5A9"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5A;'!A=&@H)'!A=&@L("1S97!A<F%T;W(@/2!$25)%0U1/4EE?4T50
M05)!5$]2*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G1FEL92]5=&EL
M+G!H<"<["B`@("`@("`@<F5T=7)N($9I;&5?571I;#HZ<F5A;'!A=&@H)'!A
M=&@L("1S97!A<F%T;W(I.PH@("`@?0I]"@I014%2.CIR96=I<W1E<E-H=71D
M;W=N1G5N8RAA<G)A>2@G1FEL92<L("=?1FEL92<I*3L*"C\^"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+TA45%`O````````````````````````````
M`````````````````````````````````````````````````````````#`P
M,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S0S
M`#`Q-S,V,P`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O2%144"]297%U
M97-T+P``````````````````````````````````````````````````````
M````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`U,34T,S,W-#,`,#(Q,#$S`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B](5%10+U)E<75E<W0O3&ES=&5N97(N<&AP````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P-S(U,``Q,#4Q-30S,S<T,P`P,C,S,34`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H
M="`H8RD@,C`P,BTR,#`S+"!2:6-H87)D($AE>65S("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@06QL(')I9VAT<R!R97-E<G9E9"X@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(%)E
M9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R
M;7,L('=I=&@@;W(@=VET:&]U="`@("!\"B\O('P@;6]D:69I8V%T:6]N+"!A
M<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD
M:71I;VYS("`@('P*+R\@?"!A<F4@;65T.B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@;R!2961I<W1R
M:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E
M(&-O<'ER:6=H="`@("`@('P*+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F
M(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX@("`@
M("`@?`HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU
M<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@("!\"B\O('P@("!N
M;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W
M:6YG(&1I<V-L86EM97(@:6X@=&AE('P*+R\@?"`@(&1O8W5M96YT871I;VX@
M86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H92!D:7-T
M<FEB=71I;VXN?`HO+R!\(&\@5&AE(&YA;65S(&]F('1H92!A=71H;W)S(&UA
M>2!N;W0@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@("`@("!\"B\O
M('P@("!P<F]D=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H
M;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@('P*+R\@?"`@('!E<FUI<W-I
M;VXN("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0T]0
M65))1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]24R`@('P*+R\@?"`B05,@
M25,B($%.1"!!3ED@15A04D534R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.
M0TQ51$E.1RP@0E54($Y/5"`@("`@?`HO+R!\($Q)34E4140@5$\L(%1(12!)
M35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519($%.1"!&251.
M15-3($9/4B!\"B\O('P@02!005)424-53$%2(%!54E!/4T4@05)%($1)4T-,
M04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'2%0@('P*+R\@
M?"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%($9/4B!!3ED@1$E2
M14-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@?`HO+R!\(%-014-)04PL($58
M14U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L
M($)55"!.3U0@("`@("!\"B\O('P@3$E-251%1"!43RP@4%)/0U5214U%3E0@
M3T8@4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L
M('P*+R\@?"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)5
M4%1)3TXI($A/5T5615(@0T%54T5$($%.1"!/3B!!3ED@?`HO+R!\(%1(14]2
M62!/1B!,24%"24Q)5%DL(%=(151(15(@24X@0T].5%)!0U0L(%-44DE#5"!,
M24%"24Q)5%DL($]2(%1/4E0@("!\"B\O('P@*$E.0TQ51$E.1R!.14=,24=%
M3D-%($]2($]42$525TE312D@05))4TE.1R!)3B!!3ED@5T%9($]55"!/1B!4
M2$4@55-%('P*+R\@?"!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3
M140@3T8@5$A%(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+B`@?`HO+R!\
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W(Z($%L97AE>2!";W)Z;W8@/&%V
M8D!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!,
M:7-T96YE<BYP:'`L=B`Q+C(@,C`P,R\Q,"\R-B`Q,#HR.#HR.2!A=F(@17AP
M("0*+R\*"B\J*@H@*B!4:&ES(&-L87-S(&EM<&QE;65N=',@=&AE($]B<V5R
M=F5R('!A<G0@;V8@82!3=6)J96-T+4]B<V5R=F5R"B`J(&1E<VEG;B!P871T
M97)N+B!)="!L:7-T96YS('1O('1H92!E=F5N=',@<V5N="!B>2!A(`H@*B!(
M5%107U)E<75E<W0@;W(@2%144%]297-P;VYS92!I;G-T86YC92X*("H*("H@
M0'!A8VMA9V4@2%144%]297%U97-T"B`J($!A=71H;W(@($%L97AE>2!";W)Z
M;W8@/&%V8D!P:'`N;F5T/@H@*B!`=F5R<VEO;B`D4F5V:7-I;VXZ(#$N,B`D
M"B`J+PIC;&%S<R!(5%107U)E<75E<W1?3&ES=&5N97(@"GL*("`@+RHJ"B`@
M("`J($$@;&ES=&5N97(G<R!I9&5N=&EF:65R"B`@("`J($!V87(@<W1R:6YG
M"B`@("`J+PH@("`@=F%R("1?:60["@H@("`O*BH*("`@("H@0V]N<W1R=6-T
M;W(L('-E=',@=&AE(&]B:F5C="=S(&ED96YT:69I97(*("`@("H*("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!(5%107U)E<75E
M<W1?3&ES=&5N97(H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:60@/2!M9#4H
M=6YI<6ED*"=H='1P7W)E<75E<W1?)RP@,2DI.PH@("`@?0H*"B`@("\J*@H@
M("`@*B!2971U<FYS('1H92!L:7-T96YE<B=S(&ED96YT:69I97(*("`@("H*
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@0')E='5R;B!S=')I;F<*("`@
M("HO"B`@("!F=6YC=&EO;B!G971)9"@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?:60["B`@("!]"@H*("`@+RHJ"B`@("`J(%1H:7,@;65T:&]D
M(&ES(&-A;&QE9"!W:&5N($QI<W1E;F5R(&ES(&YO=&EF:65D(&]F(&%N(&5V
M96YT"B`@("`J"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("H@0'!A<F%M
M("`@(&]B:F5C="`@86X@;V)J96-T('1H92!L:7-T96YE<B!I<R!A='1A8VAE
M9"!T;PH@("`@*B!`<&%R86T@("`@<W1R:6YG("!%=F5N="!N86UE"B`@("`J
M($!P87)A;2`@("!M:7AE9"`@($%D9&ET:6]N86P@9&%T80H@("`@*B!`86)S
M=')A8W0*("`@("HO"B`@("!F=6YC=&EO;B!U<&1A=&4H)B1S=6)J96-T+"`D
M979E;G0L("1D871A(#T@;G5L;"D*("`@('L*("`@("`@("!E8VAO(").;W1I
M9FEE9"!O9B!E=F5N=#H@)R1E=F5N="=<;B(["B`@("`@("`@:68@*&YU;&P@
M(3T]("1D871A*2!["B`@("`@("`@("`@(&5C:&\@(D%D9&ET:6]N86P@9&%T
M83H@(CL*("`@("`@("`@("`@=F%R7V1U;7`H)&1A=&$I.PH@("`@("`@('T*
M("`@('T*?0H_/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B](5%10+U)E<75E<W0N<&AP````
M````````````````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$Q,3(W,0`Q,#4Q
M-30S,S<T,P`P,C$U,C<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,C`P,BTR,#`S+"!2:6-H87)D($AE
M>65S("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@06QL
M(')I9VAT<R!R97-E<G9E9"X@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U
M<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U="`@("!\"B\O
M('P@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@
M=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS("`@('P*+R\@?"!A<F4@;65T.B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@;R!2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S
M="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H="`@("`@('P*+R\@?"`@(&YO
M=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I
M;F<@9&ES8VQA:6UE<BX@("`@("`@?`HO+R!\(&\@4F5D:7-T<FEB=71I;VYS
M(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y
M<FEG:'0@("!\"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I
M;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE('P*+R\@
M?"`@(&1O8W5M96YT871I;VX@86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V
M:61E9"!W:71H('1H92!D:7-T<FEB=71I;VXN?`HO+R!\(&\@5&AE(&YA;65S
M(&]F('1H92!A=71H;W)S(&UA>2!N;W0@8F4@=7-E9"!T;R!E;F1O<G-E(&]R
M('!R;VUO=&4@("`@("!\"B\O('P@("!P<F]D=6-T<R!D97)I=F5D(&9R;VT@
M=&AI<R!S;V9T=V%R92!W:71H;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@
M('P*+R\@?"`@('!E<FUI<W-I;VXN("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@5$A)4R!33T945T%212!)4R!0
M4D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/3E1224)5
M5$]24R`@('P*+R\@?"`B05,@25,B($%.1"!!3ED@15A04D534R!/4B!)35!,
M245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"`@("`@?`HO+R!\
M($Q)34E4140@5$\L(%1(12!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!
M3E1!0DE,2519($%.1"!&251.15-3($9/4B!\"B\O('P@02!005)424-53$%2
M(%!54E!/4T4@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(
M12!#3U!94DE'2%0@('P*+R\@?"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4@
M3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@
M?`HO+R!\(%-014-)04PL($5814U03$%262P@3U(@0T].4T51545.5$E!3"!$
M04U!1T53("A)3D-,541)3D<L($)55"!.3U0@("`@("!\"B\O('P@3$E-251%
M1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/4B!315)6
M24-%4SL@3$]34R!/1B!54T4L('P*+R\@?"!$051!+"!/4B!04D]&2513.R!/
M4B!"55-)3D534R!)3E1%4E)54%1)3TXI($A/5T5615(@0T%54T5$($%.1"!/
M3B!!3ED@?`HO+R!\(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X@
M0T].5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL($]2(%1/4E0@("!\"B\O('P@
M*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D@05))4TE.1R!)
M3B!!3ED@5T%9($]55"!/1B!42$4@55-%('P*+R\@?"!/1B!42$E3(%-/1E17
M05)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%(%!/4U-)0DE,2519($]&(%-5
M0T@@1$%-04=%+B`@?`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W(Z
M(%)I8VAA<F0@2&5Y97,@/')I8VAA<F1`<&AP9W5R=2YO<F<^("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O"B\O("1)9#H@4F5Q=65S="YP:'`L=B`Q+C0S(#(P,#4O,3$O
M,#8@,3@Z,CDZ,30@879B($5X<"`D"B\O"B\O($A45%!?4F5Q=65S="!#;&%S
M<PHO+PHO+R!3:6UP;&4@97AA;7!L92P@*$9E=&-H97,@>6%H;V\N8V]M(&%N
M9"!D:7-P;&%Y<R!I="DZ"B\O"B\O("1A(#T@)FYE=R!(5%107U)E<75E<W0H
M)VAT='`Z+R]W=W<N>6%H;V\N8V]M+R<I.PHO+R`D82T^<V5N9%)E<75E<W0H
M*3L*+R\@96-H;R`D82T^9V5T4F5S<&]N<V5";V1Y*"D["B\O"@IR97%U:7)E
M7V]N8V4@)U!%05(N<&AP)SL*<F5Q=6ER95]O;F-E("=.970O4V]C:V5T+G!H
M<"<["G)E<75I<F5?;VYC92`G3F5T+U523"YP:'`G.PH*9&5F:6YE*"=(5%10
M7U)%455%4U1?34542$]$7T=%5"<L("`@("`G1T54)RP@("`@('1R=64I.PID
M969I;F4H)TA45%!?4D5154535%]-151(3T1?2$5!1"<L("`@("=(14%$)RP@
M("`@=')U92D["F1E9FEN92@G2%144%]215%515-47TU%5$A/1%]03U-4)RP@
M("`@)U!/4U0G+"`@("!T<G5E*3L*9&5F:6YE*"=(5%107U)%455%4U1?3454
M2$]$7U!55"<L("`@("`G4%54)RP@("`@('1R=64I.PID969I;F4H)TA45%!?
M4D5154535%]-151(3T1?1$5,151%)RP@("=$14Q%5$4G+"`@=')U92D["F1E
M9FEN92@G2%144%]215%515-47TU%5$A/1%]/4%1)3TY3)RP@)T]05$E/3E,G
M+"!T<G5E*3L*9&5F:6YE*"=(5%107U)%455%4U1?34542$]$7U1204-%)RP@
M("`G5%)!0T4G+"`@('1R=64I.PH*9&5F:6YE*"=(5%107U)%455%4U1?2%14
M4%]615)?,5\P)RP@)S$N,"<L('1R=64I.PID969I;F4H)TA45%!?4D515453
M5%](5%107U9%4E\Q7S$G+"`G,2XQ)RP@=')U92D["@IC;&%S<R!(5%107U)E
M<75E<W0@>PH*("`@("\J*@H@("`@*B!);G-T86YC92!O9B!.971?55),"B`@
M("`J($!V87(@;V)J96-T($YE=%]54DP*("`@("HO"B`@("!V87(@)%]U<FP[
M"@H@("`@+RHJ"B`@("`J(%1Y<&4@;V8@<F5Q=65S=`H@("`@*B!`=F%R('-T
M<FEN9PH@("`@*B\*("`@('9A<B`D7VUE=&AO9#L*"B`@("`O*BH*("`@("H@
M2%144"!697)S:6]N"B`@("`J($!V87(@<W1R:6YG"B`@("`J+PH@("`@=F%R
M("1?:'1T<#L*"B`@("`O*BH*("`@("H@4F5Q=65S="!H96%D97)S"B`@("`J
M($!V87(@87)R87D*("`@("HO"B`@("!V87(@)%]R97%U97-T2&5A9&5R<SL*
M"B`@("`O*BH*("`@("H@0F%S:6,@075T:"!5<V5R;F%M90H@("`@*B!`=F%R
M('-T<FEN9PH@("`@*B\*("`@('9A<B`D7W5S97(["B`@("`*("`@("\J*@H@
M("`@*B!"87-I8R!!=71H(%!A<W-W;W)D"B`@("`J($!V87(@<W1R:6YG"B`@
M("`J+PH@("`@=F%R("1?<&%S<SL*"B`@("`O*BH*("`@("H@4V]C:V5T(&]B
M:F5C=`H@("`@*B!`=F%R(&]B:F5C="!.971?4V]C:V5T"B`@("`J+PH@("`@
M=F%R("1?<V]C:SL*("`@(`H@("`@+RHJ"B`@("`J(%!R;WAY('-E<G9E<@H@
M("`@*B!`=F%R('-T<FEN9PH@("`@*B\*("`@('9A<B`D7W!R;WAY7VAO<W0[
M"B`@("`*("`@("\J*@H@("`@*B!0<F]X>2!P;W)T"B`@("`J($!V87(@:6YT
M96=E<@H@("`@*B\*("`@('9A<B`D7W!R;WAY7W!O<G0["B`@("`*("`@("\J
M*@H@("`@*B!0<F]X>2!U<V5R;F%M90H@("`@*B!`=F%R('-T<FEN9PH@("`@
M*B\*("`@('9A<B`D7W!R;WAY7W5S97(["B`@("`*("`@("\J*@H@("`@*B!0
M<F]X>2!P87-S=V]R9`H@("`@*B!`=F%R('-T<FEN9PH@("`@*B\*("`@('9A
M<B`D7W!R;WAY7W!A<W,["@H@("`@+RHJ"B`@("`J(%!O<W0@9&%T80H@("`@
M*B!`=F%R(&%R<F%Y"B`@("`J+PH@("`@=F%R("1?<&]S=$1A=&$["@H@("`O
M*BH*("`@("H@4F5Q=65S="!B;V1Y("`*("`@("H@0'9A<B!S=')I;F<*("`@
M("HO"B`@("!V87(@)%]B;V1Y.PH*("`@+RHJ"B`@("`J($$@;&ES="!O9B!M
M971H;V1S('1H870@35535"!.3U0@:&%V92!A(')E<75E<W0@8F]D>2P@<&5R
M(%)&0R`R-C$V"B`@("`J($!V87(@87)R87D*("`@("HO"B`@("!V87(@)%]B
M;V1Y1&ES86QL;W=E9"`](&%R<F%Y*"=44D%#12<I.PH*("`@+RHJ"B`@("`J
M($9I;&5S('1O('!O<W0@"B`@("`J($!V87(@87)R87D*("`@("HO"B`@("!V
M87(@)%]P;W-T1FEL97,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@*B!#;VYN
M96-T:6]N('1I;65O=70N"B`@("`J($!V87(@9FQO870*("`@("HO"B`@("!V
M87(@)%]T:6UE;W5T.PH@("`@"B`@("`O*BH*("`@("H@2%144%]297-P;VYS
M92!O8FIE8W0*("`@("H@0'9A<B!O8FIE8W0@2%144%]297-P;VYS90H@("`@
M*B\*("`@('9A<B`D7W)E<W!O;G-E.PH@("`@"B`@("`O*BH*("`@("H@5VAE
M=&AE<B!T;R!A;&QO=R!R961I<F5C=',*("`@("H@0'9A<B!B;V]L96%N"B`@
M("`J+PH@("`@=F%R("1?86QL;W=2961I<F5C=',["B`@("`*("`@("\J*@H@
M("`@*B!-87AI;75M(')E9&ER96-T<R!A;&QO=V5D"B`@("`J($!V87(@:6YT
M96=E<@H@("`@*B\*("`@('9A<B`D7VUA>%)E9&ER96-T<SL*("`@(`H@("`@
M+RHJ"B`@("`J($-U<G)E;G0@;G5M8F5R(&]F(')E9&ER96-T<PH@("`@*B!`
M=F%R(&EN=&5G97(*("`@("HO"B`@("!V87(@)%]R961I<F5C=',["@H@("`O
M*BH*("`@("H@5VAE=&AE<B!T;R!A<'!E;F0@8G)A8VME=',@6UT@=&\@87)R
M87D@=F%R:6%B;&5S"B`@("`J($!V87(@8F]O;`H@("`@*B\*("`@('9A<B`D
M7W5S94)R86-K971S(#T@=')U93L*"B`@("\J*@H@("`@*B!!='1A8VAE9"!L
M:7-T96YE<G,*("`@("H@0'9A<B!A<G)A>0H@("`@*B\*("`@('9A<B`D7VQI
M<W1E;F5R<R`](&%R<F%Y*"D["@H@("`O*BH*("`@("H@5VAE=&AE<B!T;R!S
M879E(')E<W!O;G-E(&)O9'D@:6X@<F5S<&]N<V4@;V)J96-T('!R;W!E<G1Y
M("`*("`@("H@0'9A<B!B;V]L"B`@("`J+PH@("`@=F%R("1?<V%V94)O9'D@
M/2!T<G5E.PH*("`@+RHJ"B`@("`J(%1I;65O=70@9F]R(')E861I;F<@9G)O
M;2!S;V-K970@*&%R<F%Y*'-E8V]N9',L(&UI8W)O<V5C;VYD<RDI"B`@("`J
M($!V87(@87)R87D*("`@("HO"B`@("!V87(@)%]R96%D5&EM96]U="`](&YU
M;&P["@H@("`O*BH*("`@("H@3W!T:6]N<R!T;R!P87-S('1O($YE=%]3;V-K
M970Z.F-O;FYE8W0N(%-E92!S=')E86U?8V]N=&5X=%]C<F5A=&4*("`@("H@
M0'9A<B!A<G)A>0H@("`@*B\*("`@('9A<B`D7W-O8VME=$]P=&EO;G,@/2!N
M=6QL.PH*("`@("\J*@H@("`@*B!#;VYS=')U8W1O<@H@("`@*@H@("`@*B!3
M971S('5P('1H92!O8FIE8W0*("`@("H@0'!A<F%M("`@('-T<FEN9R`@5&AE
M('5R;"!T;R!F971C:"]A8V-E<W,*("`@("H@0'!A<F%M("`@(&%R<F%Y("`@
M07-S;V-I871I=F4@87)R87D@;V8@<&%R86UE=&5R<R!W:&EC:"!C86X@:&%V
M92!T:&4@9F]L;&]W:6YG(&ME>7,Z"B`@("`J(#QU;#X*("`@("H@("`\;&D^
M;65T:&]D("`@("`@("`@+2!-971H;V0@=&\@=7-E+"!'150L(%!/4U0@971C
M("AS=')I;F<I/"]L:3X*("`@("H@("`\;&D^:'1T<"`@("`@("`@("`@+2!(
M5%10(%9E<G-I;VX@=&\@=7-E+"`Q+C`@;W(@,2XQ("AS=')I;F<I/"]L:3X*
M("`@("H@("`\;&D^=7-E<B`@("`@("`@("`@+2!"87-I8R!!=71H('5S97)N
M86UE("AS=')I;F<I/"]L:3X*("`@("H@("`\;&D^<&%S<R`@("`@("`@("`@
M+2!"87-I8R!!=71H('!A<W-W;W)D("AS=')I;F<I/"]L:3X*("`@("H@("`\
M;&D^<')O>'E?:&]S="`@("`@+2!0<F]X>2!S97)V97(@:&]S="`H<W1R:6YG
M*3PO;&D^"B`@("`J("`@/&QI/G!R;WAY7W!O<G0@("`@("T@4')O>'D@<V5R
M=F5R('!O<G0@*&EN=&5G97(I/"]L:3X*("`@("H@("`\;&D^<')O>'E?=7-E
M<B`@("`@+2!0<F]X>2!A=71H('5S97)N86UE("AS=')I;F<I/"]L:3X*("`@
M("H@("`\;&D^<')O>'E?<&%S<R`@("`@+2!0<F]X>2!A=71H('!A<W-W;W)D
M("AS=')I;F<I/"]L:3X*("`@("H@("`\;&D^=&EM96]U="`@("`@("`@+2!#
M;VYN96-T:6]N('1I;65O=70@:6X@<V5C;VYD<R`H9FQO870I/"]L:3X*("`@
M("H@("`\;&D^86QL;W=2961I<F5C=',@+2!7:&5T:&5R('1O(&9O;&QO=R!R
M961I<F5C=',@;W(@;F]T("AB;V]L*3PO;&D^"B`@("`J("`@/&QI/FUA>%)E
M9&ER96-T<R`@("T@36%X(&YU;6)E<B!O9B!R961I<F5C=',@=&\@9F]L;&]W
M("AI;G1E9V5R*3PO;&D^"B`@("`J("`@/&QI/G5S94)R86-K971S("`@("T@
M5VAE=&AE<B!T;R!A<'!E;F0@6UT@=&\@87)R87D@=F%R:6%B;&4@;F%M97,@
M*&)O;VPI/"]L:3X*("`@("H@("`\;&D^<V%V94)O9'D@("`@("`@+2!7:&5T
M:&5R('1O('-A=F4@<F5S<&]N<V4@8F]D>2!I;B!R97-P;VYS92!O8FIE8W0@
M<')O<&5R='D@*&)O;VPI/"]L:3X*("`@("H@("`\;&D^<F5A9%1I;65O=70@
M("`@+2!4:6UE;W5T(&9O<B!R96%D:6YG("\@=W)I=&EN9R!D871A(&]V97(@
M=&AE('-O8VME="`H87)R87D@*'-E8V]N9',L(&UI8W)O<V5C;VYD<RDI/"]L
M:3X*("`@("H@("`\;&D^<V]C:V5T3W!T:6]N<R`@+2!/<'1I;VYS('1O('!A
M<W,@=&\@3F5T7U-O8VME="!O8FIE8W0@*&%R<F%Y*3PO;&D^"B`@("`J(#PO
M=6P^"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@
M2%144%]297%U97-T*"1U<FP@/2`G)RP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@)'1H:7,M/E]S;V-K("`@("`@("`@("`]("9N97<@3F5T
M7U-O8VME="@I.PH@("`@("`@("1T:&ES+3Y?;65T:&]D("`@("`@("`@/2`@
M2%144%]215%515-47TU%5$A/1%]'150["B`@("`@("`@)'1H:7,M/E]H='1P
M("`@("`@("`@("`]("!(5%107U)%455%4U1?2%144%]615)?,5\Q.PH@("`@
M("`@("1T:&ES+3Y?<F5Q=65S=$AE861E<G,@/2!A<G)A>2@I.PH@("`@("`@
M("1T:&ES+3Y?<&]S=$1A=&$@("`@("`@/2!A<G)A>2@I.PH@("`@("`@("1T
M:&ES+3Y?8F]D>2`@("`@("`@("`@/2!N=6QL.PH*("`@("`@("`D=&AI<RT^
M7W5S97(@/2!N=6QL.PH@("`@("`@("1T:&ES+3Y?<&%S<R`](&YU;&P["@H@
M("`@("`@("1T:&ES+3Y?<')O>'E?:&]S="`](&YU;&P["B`@("`@("`@)'1H
M:7,M/E]P<F]X>5]P;W)T(#T@;G5L;#L*("`@("`@("`D=&AI<RT^7W!R;WAY
M7W5S97(@/2!N=6QL.PH@("`@("`@("1T:&ES+3Y?<')O>'E?<&%S<R`](&YU
M;&P["@H@("`@("`@("1T:&ES+3Y?86QL;W=2961I<F5C=',@/2!F86QS93L*
M("`@("`@("`D=&AI<RT^7VUA>%)E9&ER96-T<R`@(#T@,SL*("`@("`@("`D
M=&AI<RT^7W)E9&ER96-T<R`@("`@(#T@,#L*"B`@("`@("`@)'1H:7,M/E]T
M:6UE;W5T("`](&YU;&P["B`@("`@("`@)'1H:7,M/E]R97-P;VYS92`](&YU
M;&P["@H@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)&ME>2`]/B`D=F%L
M=64I('L*("`@("`@("`@("`@)'1H:7,M/GLG7R<@+B`D:V5Y?2`]("1V86QU
M93L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)'5R;"DI('L*("`@
M("`@("`@("`@)'1H:7,M/G-E=%523"@D=7)L*3L*("`@("`@("!]"@H@("`@
M("`@("\O($1E9F%U;'0@=7-E<F%G96YT"B`@("`@("`@)'1H:7,M/F%D9$AE
M861E<B@G57-E<BU!9V5N="<L("=014%2($A45%!?4F5Q=65S="!C;&%S<R`H
M(&AT='`Z+R]P96%R+G!H<"YN970O("DG*3L*"B`@("`@("`@+R\@36%K92!S
M=7)E(&ME97!A;&EV97,@9&]N="!K;F]B8FQE('5S"B`@("`@("`@)'1H:7,M
M/F%D9$AE861E<B@G0V]N;F5C=&EO;B<L("=C;&]S92<I.PH*("`@("`@("`O
M+R!"87-I8R!A=71H96YT:6-A=&EO;@H@("`@("`@(&EF("@A96UP='DH)'1H
M:7,M/E]U<V5R*2D@>PH@("`@("`@("`@("`D=&AI<RT^861D2&5A9&5R*"=!
M=71H;W)I>F%T:6]N)RP@)T)A<VEC("<@+B!B87-E-C1?96YC;V1E*"1T:&ES
M+3Y?=7-E<B`N("<Z)R`N("1T:&ES+3Y?<&%S<RDI.PH@("`@("`@('T*"B`@
M("`@("`@+R\@57-E(&=Z:7`@96YC;V1I;F<@:68@<&]S<VEB;&4*("`@("`@
M("`O+R!!=F]I9"!G>FEP(&5N8V]D:6YG(&EF('5S:6YG(&UU;'1I8GET92!F
M=6YC=&EO;G,@*'-E92`C,3<X,2D*("`@("`@("!I9B`H2%144%]215%515-4
M7TA45%!?5D527S%?,2`]/2`D=&AI<RT^7VAT='`@)B8@97AT96YS:6]N7VQO
M861E9"@G>FQI8B<I("8F"B`@("`@("`@("`@(#`@/3T@*#(@)B!I;FE?9V5T
M*"=M8G-T<FEN9RYF=6YC7V]V97)L;V%D)RDI*2!["@H@("`@("`@("`@("`D
M=&AI<RT^861D2&5A9&5R*"=!8V-E<'0M16YC;V1I;F<G+"`G9WII<"<I.PH@
M("`@("`@('T*("`@('T*("`@(`H@("`@+RHJ"B`@("`J($=E;F5R871E<R!A
M($AO<W0@:&5A9&5R(&9O<B!(5%10+S$N,2!R97%U97-T<PH@("`@*@H@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("H@0')E='5R;B!S=')I;F<*("`@("HO
M"B`@("!F=6YC=&EO;B!?9V5N97)A=&5(;W-T2&5A9&5R*"D*("`@('L*("`@
M("`@("!I9B`H)'1H:7,M/E]U<FPM/G!O<G0@(3T@.#`@04Y$('-T<F-A<V5C
M;7`H)'1H:7,M/E]U<FPM/G!R;W1O8V]L+"`G:'1T<"<I(#T](#`I('L*("`@
M("`@("`@("`@)&AO<W0@/2`D=&AI<RT^7W5R;"T^:&]S="`N("<Z)R`N("1T
M:&ES+3Y?=7)L+3YP;W)T.PH*("`@("`@("!](&5L<V5I9B`H)'1H:7,M/E]U
M<FPM/G!O<G0@(3T@-#0S($%.1"!S=')C87-E8VUP*"1T:&ES+3Y?=7)L+3YP
M<F]T;V-O;"P@)VAT='!S)RD@/3T@,"D@>PH@("`@("`@("`@("`D:&]S="`]
M("1T:&ES+3Y?=7)L+3YH;W-T("X@)SHG("X@)'1H:7,M/E]U<FPM/G!O<G0[
M"@H@("`@("`@('T@96QS96EF("@D=&AI<RT^7W5R;"T^<&]R="`]/2`T-#,@
M04Y$('-T<F-A<V5C;7`H)'1H:7,M/E]U<FPM/G!R;W1O8V]L+"`G:'1T<',G
M*2`]/2`P($%.1"!S=')P;W,H)'1H:7,M/E]U<FPM/G5R;"P@)SHT-#,G*2`A
M/3T@9F%L<V4I('L*("`@("`@("`@("`@)&AO<W0@/2`D=&AI<RT^7W5R;"T^
M:&]S="`N("<Z)R`N("1T:&ES+3Y?=7)L+3YP;W)T.PH@("`@("`@(`H@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1H;W-T(#T@)'1H:7,M/E]U<FPM
M/FAO<W0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&AO<W0["B`@("!]
M"B`@("`*("`@("\J*@H@("`@*B!297-E=',@=&AE(&]B:F5C="!T;R!I=',@
M:6YI=&EA;"!S=&%T92`H1$504D5#051%1"DN"B`@("`J(%1A:V5S('1H92!S
M86UE('!A<F%M971E<G,@87,@=&AE(&-O;G-T<G5C=&]R+@H@("`@*@H@("`@
M*B!`<&%R86T@('-T<FEN9R`D=7)L("`@(%1H92!U<FP@=&\@8F4@<F5Q=65S
M=&5D"B`@("`J($!P87)A;2`@87)R87D@("1P87)A;7,@07-S;V-I871I=F4@
M87)R87D@;V8@<&%R86UE=&5R<PH@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("AS964@8V]N<W1R=6-T;W(@9F]R(&1E=&%I;',I"B`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`J($!D97!R96-A=&5D(&1E<')E8V%T960@<VEN8V4@
M,2XR+"!C86QL('1H92!C;VYS=')U8W1O<B!I9B!T:&ES(&ES(&YE8V5S<V%R
M>0H@("`@*B\*("`@(&9U;F-T:6]N(')E<V5T*"1U<FPL("1P87)A;7,@/2!A
M<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y(5%107U)E<75E<W0H)'5R
M;"P@)'!A<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@("`J(%-E=',@=&AE(%52
M3"!T;R!B92!R97%U97-T960*("`@("H*("`@("H@0'!A<F%M("!S=')I;F<@
M5&AE('5R;"!T;R!B92!R97%U97-T960*("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("HO"B`@("!F=6YC=&EO;B!S97154DPH)'5R;"D*("`@('L*("`@("`@
M("`D=&AI<RT^7W5R;"`]("9N97<@3F5T7U523"@D=7)L+"`D=&AI<RT^7W5S
M94)R86-K971S*3L*"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W5R;"T^
M=7-E<BD@?'P@(65M<'1Y*"1T:&ES+3Y?=7)L+3YP87-S*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^<V5T0F%S:6-!=71H*"1T:&ES+3Y?=7)L+3YU<V5R+"`D
M=&AI<RT^7W5R;"T^<&%S<RD["B`@("`@("`@?0H*("`@("`@("!I9B`H2%14
M4%]215%515-47TA45%!?5D527S%?,2`]/2`D=&AI<RT^7VAT='`I('L*("`@
M("`@("`@("`@)'1H:7,M/F%D9$AE861E<B@G2&]S="<L("1T:&ES+3Y?9V5N
M97)A=&5(;W-T2&5A9&5R*"DI.PH@("`@("`@('T*("`@('T*("`@(`H@("`@
M+RHJ"B`@("`J(%-E=',@82!P<F]X>2!T;R!B92!U<V5D"B`@("`J"B`@("`J
M($!P87)A;2!S=')I;F<@("`@(%!R;WAY(&AO<W0*("`@("H@0'!A<F%M(&EN
M="`@("`@("`@4')O>'D@<&]R=`H@("`@*B!`<&%R86T@<W1R:6YG("`@("!0
M<F]X>2!U<V5R;F%M90H@("`@*B!`<&%R86T@<W1R:6YG("`@("!0<F]X>2!P
M87-S=V]R9`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B\*("`@(&9U;F-T
M:6]N('-E=%!R;WAY*"1H;W-T+"`D<&]R="`](#@P.#`L("1U<V5R(#T@;G5L
M;"P@)'!A<W,@/2!N=6QL*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<')O>'E?
M:&]S="`]("1H;W-T.PH@("`@("`@("1T:&ES+3Y?<')O>'E?<&]R="`]("1P
M;W)T.PH@("`@("`@("1T:&ES+3Y?<')O>'E?=7-E<B`]("1U<V5R.PH@("`@
M("`@("1T:&ES+3Y?<')O>'E?<&%S<R`]("1P87-S.PH*("`@("`@("!I9B`H
M(65M<'1Y*"1U<V5R*2D@>PH@("`@("`@("`@("`D=&AI<RT^861D2&5A9&5R
M*"=0<F]X>2U!=71H;W)I>F%T:6]N)RP@)T)A<VEC("<@+B!B87-E-C1?96YC
M;V1E*"1U<V5R("X@)SHG("X@)'!A<W,I*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`J(%-E=',@8F%S:6,@875T:&5N=&EC871I;VX@<&%R86UE
M=&5R<PH@("`@*@H@("`@*B!`<&%R86T@<W1R:6YG("`@("!5<V5R;F%M90H@
M("`@*B!`<&%R86T@<W1R:6YG("`@("!087-S=V]R9`H@("`@*B\*("`@(&9U
M;F-T:6]N('-E=$)A<VEC075T:"@D=7-E<BP@)'!A<W,I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]U<V5R(#T@)'5S97(["B`@("`@("`@)'1H:7,M/E]P87-S
M(#T@)'!A<W,["@H@("`@("`@("1T:&ES+3YA9&1(96%D97(H)T%U=&AO<FEZ
M871I;VXG+"`G0F%S:6,@)R`N(&)A<V4V-%]E;F-O9&4H)'5S97(@+B`G.B<@
M+B`D<&%S<RDI.PH@("`@?0H*("`@("\J*@H@("`@*B!3971S('1H92!M971H
M;V0@=&\@8F4@=7-E9"P@1T54+"!03U-4(&5T8RX*("`@("H*("`@("H@0'!A
M<F%M('-T<FEN9R`@("`@365T:&]D('1O('5S92X@57-E('1H92!D969I;F5D
M(&-O;G-T86YT<R!F;W(@=&AI<PH@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M*B\*("`@(&9U;F-T:6]N('-E=$UE=&AO9"@D;65T:&]D*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?;65T:&]D(#T@)&UE=&AO9#L*("`@('T*"B`@("`O*BH*
M("`@("H@4V5T<R!T:&4@2%144"!V97)S:6]N('1O('5S92P@,2XP(&]R(#$N
M,0H@("`@*@H@("`@*B!`<&%R86T@<W1R:6YG("`@("!697)S:6]N('1O('5S
M92X@57-E('1H92!D969I;F5D(&-O;G-T86YT<R!F;W(@=&AI<PH@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N('-E=$AT='!697(H
M)&AT='`I"B`@("!["B`@("`@("`@)'1H:7,M/E]H='1P(#T@)&AT='`["B`@
M("!]"@H@("`@+RHJ"B`@("`J($%D9',@82!R97%U97-T(&AE861E<@H@("`@
M*@H@("`@*B!`<&%R86T@<W1R:6YG("`@("!(96%D97(@;F%M90H@("`@*B!`
M<&%R86T@<W1R:6YG("`@("!(96%D97(@=F%L=64*("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!A9&1(96%D97(H)&YA;64L("1V
M86QU92D*("`@('L*("`@("`@("`D=&AI<RT^7W)E<75E<W1(96%D97)S6W-T
M<G1O;&]W97(H)&YA;64I72`]("1V86QU93L*("`@('T*"B`@("`O*BH*("`@
M("H@4F5M;W9E<R!A(')E<75E<W0@:&5A9&5R"B`@("`J"B`@("`J($!P87)A
M;2!S=')I;F<@("`@($AE861E<B!N86UE('1O(')E;6]V90H@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V94AE861E<B@D
M;F%M92D*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]R97%U97-T
M2&5A9&5R<UMS=')T;VQO=V5R*"1N86UE*5TI*2!["B`@("`@("`@("`@('5N
M<V5T*"1T:&ES+3Y?<F5Q=65S=$AE861E<G-;<W1R=&]L;W=E<B@D;F%M92E=
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`J($%D9',@82!Q=65R
M>7-T<FEN9R!P87)A;65T97(*("`@("H*("`@("H@0'!A<F%M('-T<FEN9R`@
M("`@475E<GES=')I;F<@<&%R86UE=&5R(&YA;64*("`@("H@0'!A<F%M('-T
M<FEN9R`@("`@475E<GES=')I;F<@<&%R86UE=&5R('9A;'5E"B`@("`J($!P
M87)A;2!B;V]L("`@("`@(%=H971H97(@=&AE('9A;'5E(&ES(&%L<F5A9'D@
M=7)L96YC;V1E9"!O<B!N;W0L(&1E9F%U;'0@/2!N;W0*("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!A9&11=65R>5-T<FEN9R@D
M;F%M92P@)'9A;'5E+"`D<')E96YC;V1E9"`](&9A;'-E*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?=7)L+3YA9&11=65R>5-T<FEN9R@D;F%M92P@)'9A;'5E
M+"`D<')E96YC;V1E9"D["B`@("!]("`@(`H@("`@"B`@("`O*BH*("`@("H@
M4V5T<R!T:&4@<75E<GES=')I;F<@=&\@;&ET97)A;&QY('=H870@>6]U('-U
M<'!L>0H@("`@*@H@("`@*B!`<&%R86T@<W1R:6YG("`@("!4:&4@<75E<GES
M=')I;F<@9&%T82X@4VAO=6QD(&)E(&]F('1H92!F;W)M870@9F]O/6)A<B9X
M/7D@971C"B`@("`J($!P87)A;2!B;V]L("`@("`@(%=H971H97(@9&%T82!I
M<R!A;')E861Y('5R;&5N8V]D960@;W(@;F]T+"!D969A=6QT(#T@86QR96%D
M>2!E;F-O9&5D"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@9G5N
M8W1I;VX@861D4F%W475E<GE3=')I;F<H)'%U97)Y<W1R:6YG+"`D<')E96YC
M;V1E9"`]('1R=64I"B`@("!["B`@("`@("`@)'1H:7,M/E]U<FPM/F%D9%)A
M=U%U97)Y4W1R:6YG*"1Q=65R>7-T<FEN9RP@)'!R965N8V]D960I.PH@("`@
M?0H*("`@("\J*@H@("`@*B!!9&1S('!O<W1D871A(&ET96US"B`@("`J"B`@
M("`J($!P87)A;2!S=')I;F<@("`@(%!O<W0@9&%T82!N86UE"B`@("`J($!P
M87)A;2!S=')I;F<@("`@(%!O<W0@9&%T82!V86QU90H@("`@*B!`<&%R86T@
M8F]O;"`@("`@("!7:&5T:&5R(&1A=&$@:7,@86QR96%D>2!U<FQE;F-O9&5D
M(&]R(&YO="P@9&5F875L="`](&YO=`H@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@*B\*("`@(&9U;F-T:6]N(&%D9%!O<W1$871A*"1N86UE+"`D=F%L=64L
M("1P<F5E;F-O9&5D(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"1P<F5E
M;F-O9&5D*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&]S=$1A=&%;)&YA;65=
M(#T@)'9A;'5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES
M+3Y?<&]S=$1A=&%;)&YA;65=(#T@)'1H:7,M/E]A<G)A>4UA<%)E8W5R<VEV
M92@G=7)L96YC;V1E)RP@)'9A;'5E*3L*("`@("`@("!]"B`@("!]"@H@("`O
M*BH*("`@("H@4F5C=7)S:79E;'D@87!P;&EE<R!T:&4@8V%L;&)A8VL@9G5N
M8W1I;VX@=&\@=&AE('9A;'5E"B`@("`J(`H@("`@*B!`<&%R86T@("`@;6EX
M960@("!#86QL8F%C:R!F=6YC=&EO;@H@("`@*B!`<&%R86T@("`@;6EX960@
M("!686QU92!T;R!P<F]C97-S"B`@("`J($!A8V-E<W,@("!P<FEV871E"B`@
M("`J($!R971U<FX@("!M:7AE9"`@(%!R;V-E<W-E9"!V86QU90H@("`@*B\*
M("`@(&9U;F-T:6]N(%]A<G)A>4UA<%)E8W5R<VEV92@D8V%L;&)A8VLL("1V
M86QU92D*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1V86QU92DI('L*
M("`@("`@("`@("`@<F5T=7)N(&-A;&Q?=7-E<E]F=6YC*"1C86QL8F%C:RP@
M)'9A;'5E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;6%P(#T@
M87)R87DH*3L*("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E(&%S("1K(#T^
M("1V*2!["B`@("`@("`@("`@("`@("`D;6%P6R1K72`]("1T:&ES+3Y?87)R
M87E-87!296-U<G-I=F4H)&-A;&QB86-K+"`D=BD["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@<F5T=7)N("1M87`["B`@("`@("`@?0H@("`@?0H*("`@
M+RHJ"B`@("`J($%D9',@82!F:6QE('1O('5P;&]A9`H@("`@*B`*("`@("H@
M5&AI<R!A;'-O(&-H86YG97,@8V]N=&5N="UT>7!E('1O("=M=6QT:7!A<G0O
M9F]R;2UD871A)R!F;W(@<')O<&5R('5P;&]A9`H@("`@*B`*("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("H@0'!A<F%M("!S=')I;F<@("`@;F%M92!O9B!F
M:6QE+75P;&]A9"!F:65L9`H@("`@*B!`<&%R86T@(&UI>&5D("`@("!F:6QE
M(&YA;64H<RD*("`@("H@0'!A<F%M("!M:7AE9"`@("`@8V]N=&5N="UT>7!E
M*',I(&]F(&9I;&4H<RD@8F5I;F<@=7!L;V%D960*("`@("H@0')E='5R;B!B
M;V]L("`@("`@=')U92!O;B!S=6-C97-S"B`@("`J($!T:')O=W,@4$5!4E]%
M<G)O<@H@("`@*B\*("`@(&9U;F-T:6]N(&%D9$9I;&4H)&EN<'5T3F%M92P@
M)&9I;&5.86UE+"`D8V]N=&5N=%1Y<&4@/2`G87!P;&EC871I;VXO;V-T970M
M<W1R96%M)RD*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1F:6QE3F%M
M92D@)B8@(6ES7W)E861A8FQE*"1F:6QE3F%M92DI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D9I;&4@)WLD9FEL94YA;65])R!I
M<R!N;W0@<F5A9&%B;&4B*3L*("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH
M)&9I;&5.86UE*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D9FEL94YA;64@
M87,@)&YA;64I('L*("`@("`@("`@("`@("`@(&EF("@A:7-?<F5A9&%B;&4H
M)&YA;64I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H(D9I;&4@)WLD;F%M97TG(&ES(&YO="!R96%D86)L92(I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@("1T:&ES+3YA9&1(96%D97(H)T-O;G1E;G0M5'EP92<L("=M=6QT:7!A
M<G0O9F]R;2UD871A)RD["B`@("`@("`@)'1H:7,M/E]P;W-T1FEL97-;)&EN
M<'5T3F%M95T@/2!A<G)A>2@*("`@("`@("`@("`@)VYA;64G(#T^("1F:6QE
M3F%M92P*("`@("`@("`@("`@)W1Y<&4G(#T^("1C;VYT96YT5'EP90H@("`@
M("`@("D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`J($%D9',@<F%W('!O<W1D871A("A$15!214-!5$5$*0H@("`@*@H@("`@
M*B!`<&%R86T@<W1R:6YG("`@("!4:&4@9&%T80H@("`@*B!`<&%R86T@8F]O
M;"`@("`@("!7:&5T:&5R(&1A=&$@:7,@<')E96YC;V1E9"!O<B!N;W0L(&1E
M9F%U;'0@/2!A;')E861Y(&5N8V]D960*("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("H@0&1E<')E8V%T960@("`@("`@9&5P<F5C871E9"!S:6YC92`Q+C,N
M,"P@;65T:&]D(&%D9$)O9'DH*2!S:&]U;&0@8F4@=7-E9"!I;G-T96%D"B`@
M("`J+PH@("`@9G5N8W1I;VX@861D4F%W4&]S=$1A=&$H)'!O<W1D871A+"`D
M<')E96YC;V1E9"`]('1R=64I"B`@("!["B`@("`@("`@)'1H:7,M/E]B;V1Y
M(#T@)'!R965N8V]D960@/R`D<&]S=&1A=&$@.B!U<FQE;F-O9&4H)'!O<W1D
M871A*3L*("`@('T*"B`@("\J*@H@("`@*B!3971S('1H92!R97%U97-T(&)O
M9'D@*&9O<B!03U-4+"!0550@86YD('-I;6EL87(@<F5Q=65S=',I"B`@("`J
M"B`@("`J($!P87)A;2`@("!S=')I;F<@(%)E<75E<W0@8F]D>0H@("`@*B!`
M86-C97-S("`@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@<V5T0F]D>2@D
M8F]D>2D*("`@('L*("`@("`@("`D=&AI<RT^7V)O9'D@/2`D8F]D>3L*("`@
M('T*"B`@("`O*BH*("`@("H@0VQE87)S(&%N>2!P;W-T9&%T82!T:&%T(&AA
M<R!B965N(&%D9&5D("A$15!214-!5$5$*2X@"B`@("`J(`H@("`@*B!5<V5F
M=6P@9F]R(&UU;'1I<&QE(')E<75E<W0@<V-E;F%R:6]S+@H@("`@*@H@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@*B!`9&5P<F5C871E9"!D97!R96-A=&5D
M('-I;F-E(#$N,@H@("`@*B\*("`@(&9U;F-T:6]N(&-L96%R4&]S=$1A=&$H
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&]S=$1A=&$@/2!N=6QL.PH@("`@
M?0H*("`@("\J*@H@("`@*B!!<'!E;F1S(&$@8V]O:VEE('1O(")#;V]K:64Z
M(B!H96%D97(*("`@("H@"B`@("`J($!P87)A;2!S=')I;F<@)&YA;64@8V]O
M:VEE(&YA;64*("`@("H@0'!A<F%M('-T<FEN9R`D=F%L=64@8V]O:VEE('9A
M;'5E"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@
M861D0V]O:VEE*"1N86UE+"`D=F%L=64I"B`@("!["B`@("`@("`@)&-O;VMI
M97,@/2!I<W-E="@D=&AI<RT^7W)E<75E<W1(96%D97)S6R=C;V]K:64G72D@
M/R`D=&AI<RT^7W)E<75E<W1(96%D97)S6R=C;V]K:64G72X@)SL@)R`Z("<G
M.PH@("`@("`@("1T:&ES+3YA9&1(96%D97(H)T-O;VMI92<L("1C;V]K:65S
M("X@)&YA;64@+B`G/2<@+B`D=F%L=64I.PH@("`@?0H@("`@"B`@("`O*BH*
M("`@("H@0VQE87)S(&%N>2!C;V]K:65S('1H870@:&%V92!B965N(&%D9&5D
M("A$15!214-!5$5$*2X@"B`@("`J(`H@("`@*B!5<V5F=6P@9F]R(&UU;'1I
M<&QE(')E<75E<W0@<V-E;F%R:6]S"B`@("`J"B`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`J($!D97!R96-A=&5D(&1E<')E8V%T960@<VEN8V4@,2XR"B`@
M("`J+PH@("`@9G5N8W1I;VX@8VQE87)#;V]K:65S*"D*("`@('L*("`@("`@
M("`D=&AI<RT^<F5M;W9E2&5A9&5R*"=#;V]K:64G*3L*("`@('T*"B`@("`O
M*BH*("`@("H@4V5N9',@=&AE(')E<75E<W0*("`@("H*("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("H@0'!A<F%M("!B;V]L("`@5VAE=&AE<B!T;R!S=&]R
M92!R97-P;VYS92!B;V1Y(&EN(%)E<W!O;G-E(&]B:F5C="!P<F]P97)T>2P*
M("`@("H@("`@("`@("`@("`@("`@<V5T('1H:7,@=&\@9F%L<V4@:68@9&]W
M;FQO861I;F<@82!,05)'12!F:6QE(&%N9"!U<VEN9R!A($QI<W1E;F5R"B`@
M("`J($!R971U<FX@;6EX960@(%!%05(@97)R;W(@;VX@97)R;W(L('1R=64@
M;W1H97)W:7-E"B`@("`J+PH@("`@9G5N8W1I;VX@<V5N9%)E<75E<W0H)'-A
M=F5";V1Y(#T@=')U92D*("`@('L*("`@("`@("!I9B`H(6ES7V$H)'1H:7,M
M/E]U<FPL("=.971?55),)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)TYO(%523"!G:79E;BXG*3L*("`@("`@("!]"@H@("`@
M("`@("1H;W-T(#T@:7-S970H)'1H:7,M/E]P<F]X>5]H;W-T*2`_("1T:&ES
M+3Y?<')O>'E?:&]S="`Z("1T:&ES+3Y?=7)L+3YH;W-T.PH@("`@("`@("1P
M;W)T(#T@:7-S970H)'1H:7,M/E]P<F]X>5]P;W)T*2`_("1T:&ES+3Y?<')O
M>'E?<&]R="`Z("1T:&ES+3Y?=7)L+3YP;W)T.PH*("`@("`@("`O+R`T+C,N
M,"!S=7!P;W)T<R!34TP@8V]N;F5C=&EO;G,@=7-I;F<@3W!E;E-33"X@5&AE
M(&9U;F-T:6]N('1E<W0@9&5T97)M:6YE<PH@("`@("`@("\O('=E(')U;FYI
M;F<@;VX@870@;&5A<W0@-"XS+C`*("`@("`@("!I9B`H<W1R8V%S96-M<"@D
M=&AI<RT^7W5R;"T^<')O=&]C;VPL("=H='1P<R<I(#T](#`@04Y$(&9U;F-T
M:6]N7V5X:7-T<R@G9FEL95]G971?8V]N=&5N=',G*2!!3D0@97AT96YS:6]N
M7VQO861E9"@G;W!E;G-S;"<I*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7W!R;WAY7VAO<W0I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G2%144%,@<')O>&EE<R!A<F4@;F]T('-U<'!O
M<G1E9"XG*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D:&]S="`]("=S
M<VPZ+R\G("X@)&AO<W0["B`@("`@("`@?0H*("`@("`@("`O+R!M86=I8R!Q
M=6]T97,@;6%Y(&9U8VL@=7`@9FEL92!U<&QO861S(&%N9"!C:'5N:V5D(')E
M<W!O;G-E('!R;V-E<W-I;F<*("`@("`@("`D;6%G:6-1=6]T97,@/2!I;FE?
M9V5T*"=M86=I8U]Q=6]T97-?<G5N=&EM92<I.PH@("`@("`@(&EN:5]S970H
M)VUA9VEC7W%U;W1E<U]R=6YT:6UE)RP@9F%L<V4I.PH*("`@("`@("`O+R!)
M9B!T:&ES(&ES(&$@<V5C;VYD(')E<75E<W0L('=E(&UA>2!G970@87=A>2!W
M:71H;W5T"B`@("`@("`@+R\@<F4M8V]N;F5C=&EN9R!I9B!T:&5Y)W)E(&]N
M('1H92!S86UE('-E<G9E<@H@("`@("`@("1E<G(@/2`D=&AI<RT^7W-O8VLM
M/F-O;FYE8W0H)&AO<W0L("1P;W)T+"!N=6QL+"`D=&AI<RT^7W1I;65O=70L
M("1T:&ES+3Y?<V]C:V5T3W!T:6]N<RD["B`@("`@("`@4$5!4CHZ:7-%<G)O
M<B@D97)R*2!O<B`D97)R(#T@)'1H:7,M/E]S;V-K+3YW<FET92@D=&AI<RT^
M7V)U:6QD4F5Q=65S="@I*3L*"B`@("`@("`@:68@*"%014%2.CII<T5R<F]R
M*"1E<G(I*2!["B`@("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]R96%D
M5&EM96]U="DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V]C:RT^<V5T
M5&EM96]U="@D=&AI<RT^7W)E8614:6UE;W5T6S!=+"`D=&AI<RT^7W)E8614
M:6UE;W5T6S%=*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M
M/E]N;W1I9GDH)W-E;G1297%U97-T)RD["@H@("`@("`@("`@("`O+R!296%D
M('1H92!R97-P;VYS90H@("`@("`@("`@("`D=&AI<RT^7W)E<W!O;G-E(#T@
M)FYE=R!(5%107U)E<W!O;G-E*"1T:&ES+3Y?<V]C:RP@)'1H:7,M/E]L:7-T
M96YE<G,I.PH@("`@("`@("`@("`D97)R(#T@)'1H:7,M/E]R97-P;VYS92T^
M<')O8V5S<R@D=&AI<RT^7W-A=F5";V1Y("8F("1S879E0F]D>2D["B`@("`@
M("`@?0H*("`@("`@("!I;FE?<V5T*"=M86=I8U]Q=6]T97-?<G5N=&EM92<L
M("1M86=I8U%U;W1E<RD["@H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E
M<G(I*2!["B`@("`@("`@("`@(')E='5R;B`D97)R.PH@("`@("`@('T*"@H@
M("`@("`@("\O($-H96-K(&9O<B!R961I<F5C=&EO;@H@("`@("`@(&EF("@@
M("`@)'1H:7,M/E]A;&QO=U)E9&ER96-T<PH@("`@("`@("`@("!!3D0@)'1H
M:7,M/E]R961I<F5C=',@/#T@)'1H:7,M/E]M87A2961I<F5C=',*("`@("`@
M("`@("`@04Y$("1T:&ES+3YG971297-P;VYS94-O9&4H*2`^(#,P,`H@("`@
M("`@("`@("!!3D0@)'1H:7,M/F=E=%)E<W!O;G-E0V]D92@I(#P@,SDY"B`@
M("`@("`@("`@($%.1"`A96UP='DH)'1H:7,M/E]R97-P;VYS92T^7VAE861E
M<G-;)VQO8V%T:6]N)UTI*2!["@H@("`@("`@("`@("`*("`@("`@("`@("`@
M)')E9&ER96-T(#T@)'1H:7,M/E]R97-P;VYS92T^7VAE861E<G-;)VQO8V%T
M:6]N)UT["@H@("`@("`@("`@("`O+R!!8G-O;'5T92!54DP*("`@("`@("`@
M("`@:68@*'!R96=?;6%T8V@H)R]>:'1T<',_.EPO7"\O:2<L("1R961I<F5C
M="DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?=7)L(#T@)FYE=R!.971?
M55),*"1R961I<F5C="D["B`@("`@("`@("`@("`@("`D=&AI<RT^861D2&5A
M9&5R*"=(;W-T)RP@)'1H:7,M/E]G96YE<F%T94AO<W1(96%D97(H*2D["B`@
M("`@("`@("`@("\O($%B<V]L=71E('!A=&@*("`@("`@("`@("`@?2!E;'-E
M:68@*"1R961I<F5C='LP?2`]/2`G+R<I('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?=7)L+3YP871H(#T@)')E9&ER96-T.PH@("`@("`@("`@("`*("`@
M("`@("`@("`@+R\@4F5L871I=F4@<&%T:`H@("`@("`@("`@("!](&5L<V5I
M9B`H<W5B<W1R*"1R961I<F5C="P@,"P@,RD@/3T@)RXN+R<@3U(@<W5B<W1R
M*"1R961I<F5C="P@,"P@,BD@/3T@)RXO)RD@>PH@("`@("`@("`@("`@("`@
M:68@*'-U8G-T<B@D=&AI<RT^7W5R;"T^<&%T:"P@+3$I(#T]("<O)RD@>PH@
M("`@("`@("`@("`@("`@("`@("1R961I<F5C="`]("1T:&ES+3Y?=7)L+3YP
M871H("X@)')E9&ER96-T.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`D<F5D:7)E8W0@/2!D:7)N86UE*"1T:&ES+3Y?
M=7)L+3YP871H*2`N("<O)R`N("1R961I<F5C=#L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1R961I<F5C="`]($YE=%]54DPZ.G)E<V]L
M=F50871H*"1R961I<F5C="D["B`@("`@("`@("`@("`@("`D=&AI<RT^7W5R
M;"T^<&%T:"`]("1R961I<F5C=#L*("`@("`@("`@("`@("`@(`H@("`@("`@
M("`@("`O+R!&:6QE;F%M92P@;F\@<&%T:`H@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@:68@*'-U8G-T<B@D=&AI<RT^7W5R;"T^<&%T
M:"P@+3$I(#T]("<O)RD@>PH@("`@("`@("`@("`@("`@("`@("1R961I<F5C
M="`]("1T:&ES+3Y?=7)L+3YP871H("X@)')E9&ER96-T.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<F5D:7)E8W0@
M/2!D:7)N86UE*"1T:&ES+3Y?=7)L+3YP871H*2`N("<O)R`N("1R961I<F5C
M=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M=7)L+3YP871H(#T@)')E9&ER96-T.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D=&AI<RT^7W)E9&ER96-T<RLK.PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G-E;F1297%U97-T*"1S879E0F]D>2D["@H@("`@("`@("\O(%1O
M;R!M86YY(')E9&ER96-T<PH@("`@("`@('T@96QS96EF("@D=&AI<RT^7V%L
M;&]W4F5D:7)E8W1S($%.1"`D=&AI<RT^7W)E9&ER96-T<R`^("1T:&ES+3Y?
M;6%X4F5D:7)E8W1S*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*"=4;V\@;6%N>2!R961I<F5C=',G*3L*("`@("`@("!]"@H@("`@
M("`@("1T:&ES+3Y?<V]C:RT^9&ES8V]N;F5C="@I.PH*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("H@4F5T=7)N<R!T:&4@<F5S
M<&]N<V4@8V]D90H@("`@*@H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B!`
M<F5T=7)N(&UI>&5D("`@("!297-P;VYS92!C;V1E+"!F86QS92!I9B!N;W0@
M<V5T"B`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F5S<&]N<V5#;V1E*"D*("`@
M('L*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/E]R97-P;VYS92T^7V-O
M9&4I(#\@)'1H:7,M/E]R97-P;VYS92T^7V-O9&4@.B!F86QS93L*("`@('T*
M"B`@("`O*BH*("`@("H@4F5T=7)N<R!E:71H97(@=&AE(&YA;65D(&AE861E
M<B!O<B!A;&P@:68@;F\@;F%M92!G:79E;@H@("`@*@H@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@*B!`<&%R86T@<W1R:6YG("`@("!4:&4@:&5A9&5R(&YA
M;64@=&\@<F5T=7)N+"!D;R!N;W0@<V5T('1O(&=E="!A;&P@:&5A9&5R<PH@
M("`@*B!`<F5T=7)N(&UI>&5D("`@("!E:71H97(@=&AE('9A;'5E(&]F("1H
M96%D97)N86UE("AF86QS92!I9B!H96%D97(@:7,@;F]T('!R97-E;G0I"B`@
M("`J("`@("`@("`@("`@("`@("`@(&]R(&%N(&%R<F%Y(&]F(&%L;"!H96%D
M97)S"B`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F5S<&]N<V5(96%D97(H)&AE
M861E<FYA;64@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)&AE
M861E<FYA;64I*2!["B`@("`@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^
M7W)E<W!O;G-E+3Y?:&5A9&5R<RD_("1T:&ES+3Y?<F5S<&]N<V4M/E]H96%D
M97)S.B!A<G)A>2@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1H
M96%D97)N86UE(#T@<W1R=&]L;W=E<B@D:&5A9&5R;F%M92D["B`@("`@("`@
M("`@(')E='5R;B!I<W-E="@D=&AI<RT^7W)E<W!O;G-E+3Y?:&5A9&5R<ULD
M:&5A9&5R;F%M95TI(#\@)'1H:7,M/E]R97-P;VYS92T^7VAE861E<G-;)&AE
M861E<FYA;65=(#H@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@*B!2971U<FYS('1H92!B;V1Y(&]F('1H92!R97-P;VYS90H@("`@*@H@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@*B!`<F5T=7)N(&UI>&5D("`@("!R
M97-P;VYS92!B;V1Y+"!F86QS92!I9B!N;W0@<V5T"B`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4F5S<&]N<V5";V1Y*"D*("`@('L*("`@("`@("!R971U<FX@
M:7-S970H)'1H:7,M/E]R97-P;VYS92T^7V)O9'DI(#\@)'1H:7,M/E]R97-P
M;VYS92T^7V)O9'D@.B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("H@4F5T
M=7)N<R!C;V]K:65S('-E="!I;B!R97-P;VYS90H@("`@*B`*("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("H@0')E='5R;B!M:7AE9"`@("`@87)R87D@;V8@
M<F5S<&]N<V4@8V]O:VEE<RP@9F%L<V4@:68@;F]N92!A<F4@<')E<V5N=`H@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%)E<W!O;G-E0V]O:VEE<R@I"B`@("![
M"B`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES+3Y?<F5S<&]N<V4M/E]C;V]K
M:65S*2`_("1T:&ES+3Y?<F5S<&]N<V4M/E]C;V]K:65S(#H@9F%L<V4["B`@
M("!]"@H@("`@+RHJ"B`@("`J($)U:6QD<R!T:&4@<F5Q=65S="!S=')I;F<*
M("`@("H*("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J($!R971U<FX@<W1R
M:6YG(%1H92!R97%U97-T('-T<FEN9PH@("`@*B\*("`@(&9U;F-T:6]N(%]B
M=6EL9%)E<75E<W0H*0H@("`@>PH@("`@("`@("1S97!A<F%T;W(@/2!I;FE?
M9V5T*"=A<F=?<V5P87)A=&]R+F]U='!U="<I.PH@("`@("`@(&EN:5]S970H
M)V%R9U]S97!A<F%T;W(N;W5T<'5T)RP@)R8G*3L*("`@("`@("`D<75E<GES
M=')I;F<@/2`H)'%U97)Y<W1R:6YG(#T@)'1H:7,M/E]U<FPM/F=E=%%U97)Y
M4W1R:6YG*"DI(#\@)S\G("X@)'%U97)Y<W1R:6YG(#H@)R<["B`@("`@("`@
M:6YI7W-E="@G87)G7W-E<&%R871O<BYO=71P=70G+"`D<V5P87)A=&]R*3L*
M"B`@("`@("`@)&AO<W0@/2!I<W-E="@D=&AI<RT^7W!R;WAY7VAO<W0I(#\@
M)'1H:7,M/E]U<FPM/G!R;W1O8V]L("X@)SHO+R<@+B`D=&AI<RT^7W5R;"T^
M:&]S="`Z("<G.PH@("`@("`@("1P;W)T(#T@*&ES<V5T*"1T:&ES+3Y?<')O
M>'E?:&]S="D@04Y$("1T:&ES+3Y?=7)L+3YP;W)T("$](#@P*2`_("<Z)R`N
M("1T:&ES+3Y?=7)L+3YP;W)T(#H@)R<["B`@("`@("`@)'!A=&@@/2`H96UP
M='DH)'1H:7,M/E]U<FPM/G!A=&@I/R`G+R<Z("1T:&ES+3Y?=7)L+3YP871H
M*2`N("1Q=65R>7-T<FEN9SL*("`@("`@("`D=7)L("`]("1H;W-T("X@)'!O
M<G0@+B`D<&%T:#L*"B`@("`@("`@)')E<75E<W0@/2`D=&AI<RT^7VUE=&AO
M9"`N("<@)R`N("1U<FP@+B`G($A45%`O)R`N("1T:&ES+3Y?:'1T<"`N(")<
M<EQN(CL*"B`@("`@("`@:68@*&EN7V%R<F%Y*"1T:&ES+3Y?;65T:&]D+"`D
M=&AI<RT^7V)O9'E$:7-A;&QO=V5D*2!\?`H@("`@("`@("`@("`H2%144%]2
M15%515-47TU%5$A/1%]03U-4("$]("1T:&ES+3Y?;65T:&]D("8F(&5M<'1Y
M*"1T:&ES+3Y?8F]D>2DI('Q\"B`@("`@("`@("`@("A(5%107U)%455%4U1?
M34542$]$7U!/4U0@(3T@)'1H:7,M/E]M971H;V0@)B8@96UP='DH)'1H:7,M
M/E]P;W-T1&%T82D@)B8@96UP='DH)'1H:7,M/E]P;W-T1FEL97,I*2D@>PH*
M("`@("`@("`@("`@)'1H:7,M/G)E;6]V94AE861E<B@G0V]N=&5N="U4>7!E
M)RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*&5M<'1Y*"1T
M:&ES+3Y?<F5Q=65S=$AE861E<G-;)V-O;G1E;G0M='EP92==*2D@>PH@("`@
M("`@("`@("`@("`@+R\@061D(&1E9F%U;'0@8V]N=&5N="UT>7!E"B`@("`@
M("`@("`@("`@("`D=&AI<RT^861D2&5A9&5R*"=#;VYT96YT+51Y<&4G+"`G
M87!P;&EC871I;VXO>"UW=W<M9F]R;2UU<FQE;F-O9&5D)RD["B`@("`@("`@
M("`@('T@96QS96EF("@G;75L=&EP87)T+V9O<FTM9&%T82<@/3T@)'1H:7,M
M/E]R97%U97-T2&5A9&5R<ULG8V]N=&5N="UT>7!E)UTI('L*("`@("`@("`@
M("`@("`@("1B;W5N9&%R>2`]("=(5%107U)E<75E<W1?)R`N(&UD-2AU;FEQ
M:60H)W)E<75E<W0G*2`N(&UI8W)O=&EM92@I*3L*("`@("`@("`@("`@("`@
M("1T:&ES+3YA9&1(96%D97(H)T-O;G1E;G0M5'EP92<L("=M=6QT:7!A<G0O
M9F]R;2UD871A.R!B;W5N9&%R>3TG("X@)&)O=6YD87)Y*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@4F5Q=65S="!(96%D97)S"B`@
M("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W)E<75E<W1(96%D97)S*2D@>PH@
M("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7W)E<75E<W1(96%D97)S(&%S
M("1N86UE(#T^("1V86QU92D@>PH@("`@("`@("`@("`@("`@)&-A;F]N:6-A
M;$YA;64@/2!I;7!L;V1E*"<M)RP@87)R87E?;6%P*"=U8V9I<G-T)RP@97AP
M;&]D92@G+2<L("1N86UE*2DI.PH@("`@("`@("`@("`@("`@)')E<75E<W0@
M("`@("`N/2`D8V%N;VYI8V%L3F%M92`N("<Z("<@+B`D=F%L=64@+B`B7')<
M;B(["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($YO('!O
M<W0@9&%T82!O<B!W<F]N9R!M971H;V0L('-O('-I;7!L>2!A9&0@82!F:6YA
M;"!#4DQ&"B`@("`@("`@:68@*&EN7V%R<F%Y*"1T:&ES+3Y?;65T:&]D+"`D
M=&AI<RT^7V)O9'E$:7-A;&QO=V5D*2!\?"`*("`@("`@("`@("`@*$A45%!?
M4D5154535%]-151(3T1?4$]35"`A/2`D=&AI<RT^7VUE=&AO9"`F)B!E;7!T
M>2@D=&AI<RT^7V)O9'DI*2D@>PH*("`@("`@("`@("`@)')E<75E<W0@+CT@
M(EQR7&XB.PH*("`@("`@("`O+R!0;W-T(&1A=&$@:68@:70G<R!A;B!A<G)A
M>0H@("`@("`@('T@96QS96EF("A(5%107U)%455%4U1?34542$]$7U!/4U0@
M/3T@)'1H:7,M/E]M971H;V0@)B8@"B`@("`@("`@("`@("`@("`@("@A96UP
M='DH)'1H:7,M/E]P;W-T1&%T82D@?'P@(65M<'1Y*"1T:&ES+3Y?<&]S=$9I
M;&5S*2DI('L*"B`@("`@("`@("`@("\O(")N;W)M86PB(%!/4U0@<F5Q=65S
M=`H@("`@("`@("`@("!I9B`H(6ES<V5T*"1B;W5N9&%R>2DI('L*("`@("`@
M("`@("`@("`@("1P;W-T9&%T82`](&EM<&QO9&4H)R8G+"!A<G)A>5]M87`H
M"B`@("`@("`@("`@("`@("`@("`@8W)E871E7V9U;F-T:6]N*"<D82<L("=R
M971U<FX@)&%;,%T@+B!<)SU<)R`N("1A6S%=.R<I+"`*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V9L871T96Y!<G)A>2@G)RP@)'1H:7,M/E]P;W-T
M1&%T82D*("`@("`@("`@("`@("`@("DI.PH*("`@("`@("`@("`@+R\@;75L
M=&EP87)T(')E<75E<W0L('!R;V)A8FQY('=I=&@@9FEL92!U<&QO861S"B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<&]S=&1A=&$@
M/2`G)SL*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P;W-T
M1&%T82DI('L*("`@("`@("`@("`@("`@("`@("`D9FQA=$1A=&$@/2`D=&AI
M<RT^7V9L871T96Y!<G)A>2@G)RP@)'1H:7,M/E]P;W-T1&%T82D["B`@("`@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)&9L871$871A(&%S("1I=&5M*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1P;W-T9&%T82`N/2`G+2TG("X@
M)&)O=6YD87)Y("X@(EQR7&XB.PH@("`@("`@("`@("`@("`@("`@("`@("`D
M<&]S=&1A=&$@+CT@)T-O;G1E;G0M1&ES<&]S:71I;VXZ(&9O<FTM9&%T83L@
M;F%M93TB)R`N("1I=&5M6S!=("X@)R(G.PH@("`@("`@("`@("`@("`@("`@
M("`@("`D<&]S=&1A=&$@+CT@(EQR7&Y<<EQN(B`N('5R;&1E8V]D92@D:71E
M;5LQ72D@+B`B7')<;B(["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P
M;W-T1FEL97,@87,@)&YA;64@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*&ES7V%R<F%Y*"1V86QU95LG;F%M92==*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D=F%R;F%M92`@("`@("`]("1N86UE("X@*"1T
M:&ES+3Y?=7-E0G)A8VME=',_("=;72<Z("<G*3L*("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M
M92`@("`@("`]("1N86UE.PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%L
M=65;)VYA;64G72`](&%R<F%Y*"1V86QU95LG;F%M92==*3L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A
M;'5E6R=N86UE)UT@87,@)&ME>2`]/B`D9FEL96YA;64I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&9P("`@/2!F;W!E;B@D9FEL96YA;64L("=R)RD[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1D871A(#T@9G)E860H)&9P+"!F
M:6QE<VEZ92@D9FEL96YA;64I*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M9F-L;W-E*"1F<"D["B`@("`@("`@("`@("`@("`@("`@("`@("1B87-E;F%M
M92`](&)A<V5N86UE*"1F:6QE;F%M92D["B`@("`@("`@("`@("`@("`@("`@
M("`@("1T>7!E("`@("`](&ES7V%R<F%Y*"1V86QU95LG='EP92==*3\@0"1V
M86QU95LG='EP92==6R1K97E=.B`D=F%L=65;)W1Y<&4G73L*"B`@("`@("`@
M("`@("`@("`@("`@("`@("1P;W-T9&%T82`N/2`G+2TG("X@)&)O=6YD87)Y
M("X@(EQR7&XB.PH@("`@("`@("`@("`@("`@("`@("`@("`D<&]S=&1A=&$@
M+CT@)T-O;G1E;G0M1&ES<&]S:71I;VXZ(&9O<FTM9&%T83L@;F%M93TB)R`N
M("1V87)N86UE("X@)R([(&9I;&5N86UE/2(G("X@)&)A<V5N86UE("X@)R(G
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D<&]S=&1A=&$@+CT@(EQR7&Y#
M;VYT96YT+51Y<&4Z("(@+B`D='EP93L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'!O<W1D871A("X](")<<EQN7')<;B(@+B`D9&%T82`N(")<<EQN(CL*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D<&]S=&1A=&$@+CT@)RTM)R`N("1B;W5N9&%R>2`N("(M
M+5QR7&XB.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1R97%U97-T("X]
M("=#;VYT96YT+4QE;F=T:#H@)R`N('-T<FQE;B@D<&]S=&1A=&$I("X@(EQR
M7&Y<<EQN(CL*("`@("`@("`@("`@)')E<75E<W0@+CT@)'!O<W1D871A.PH*
M("`@("`@("`O+R!%>'!L:6-I=&QY('-E="!R97%U97-T(&)O9'D*("`@("`@
M("!](&5L<V5I9B`H(65M<'1Y*"1T:&ES+3Y?8F]D>2DI('L*"B`@("`@("`@
M("`@("1R97%U97-T("X]("=#;VYT96YT+4QE;F=T:#H@)R`N('-T<FQE;B@D
M=&AI<RT^7V)O9'DI("X@(EQR7&Y<<EQN(CL*("`@("`@("`@("`@)')E<75E
M<W0@+CT@)'1H:7,M/E]B;V1Y.PH@("`@("`@('T*("`@("`@("`*("`@("`@
M("!R971U<FX@)')E<75E<W0["B`@("!]"@H@("`O*BH*("`@("H@2&5L<&5R
M(&9U;F-T:6]N('1O(&-H86YG92!T:&4@*'!R;V)A8FQY(&UU;'1I9&EM96YS
M:6]N86PI(&%S<V]C:6%T:79E(&%R<F%Y"B`@("`J(&EN=&\@=&AE('-I;7!L
M92!O;F4N"B`@("`J"B`@("`J($!P87)A;2`@("!S=')I;F<@(&YA;64@9F]R
M(&ET96T*("`@("H@0'!A<F%M("`@(&UI>&5D("`@:71E;2=S('9A;'5E<PH@
M("`@*B!`<F5T=7)N("`@87)R87D@("!A<G)A>2!W:71H('1H92!F;VQL;W=I
M;F<@:71E;7,Z(&%R<F%Y*"=I=&5M(&YA;64G+"`G:71E;2!V86QU92<I.PH@
M("`@*B\*("`@(&9U;F-T:6]N(%]F;&%T=&5N07)R87DH)&YA;64L("1V86QU
M97,I"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D=F%L=65S*2D@>PH@
M("`@("`@("`@("!R971U<FX@87)R87DH87)R87DH)&YA;64L("1V86QU97,I
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5T(#T@87)R87DH
M*3L*("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E<R!A<R`D:R`]/B`D=BD@
M>PH@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1N86UE*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1N97=.86UE(#T@)&L["B`@("`@("`@("`@("`@("!]
M(&5L<V5I9B`H)'1H:7,M/E]U<V5"<F%C:V5T<RD@>PH@("`@("`@("`@("`@
M("`@("`@("1N97=.86UE(#T@)&YA;64@+B`G6R<@+B`D:R`N("==)SL*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&YE
M=TYA;64@/2`D;F%M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("1R970@/2!A<G)A>5]M97)G92@D<F5T+"`D=&AI<RT^7V9L871T96Y!
M<G)A>2@D;F5W3F%M92P@)'8I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!R971U<FX@)')E=#L*("`@("`@("!]"B`@("!]"@H*("`@+RHJ"B`@("`J
M($%D9',@82!,:7-T96YE<B!T;R!T:&4@;&ES="!O9B!L:7-T96YE<G,@=&AA
M="!A<F4@;F]T:69I960@;V8*("`@("H@=&AE(&]B:F5C="=S(&5V96YT<PH@
M("`@*B`*("`@("H@0'!A<F%M("`@(&]B:F5C="`@($A45%!?4F5Q=65S=%],
M:7-T96YE<B!I;G-T86YC92!T;R!A='1A8V@*("`@("H@0')E='5R;B`@(&)O
M;VQE86X@('=H971H97(@=&AE(&QI<W1E;F5R('=A<R!S=6-C97-S9G5L;'D@
M871T86-H960*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B\*("`@(&9U
M;F-T:6]N(&%T=&%C:"@F)&QI<W1E;F5R*0H@("`@>PH@("`@("`@(&EF("@A
M:7-?82@D;&ES=&5N97(L("=(5%107U)E<75E<W1?3&ES=&5N97(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@("1T
M:&ES+3Y?;&ES=&5N97)S6R1L:7-T96YE<BT^9V5T260H*5T@/28@)&QI<W1E
M;F5R.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*"B`@("\J*@H@("`@
M*B!296UO=F5S(&$@3&ES=&5N97(@9G)O;2!T:&4@;&ES="!O9B!L:7-T96YE
M<G,@"B`@("`J(`H@("`@*B!`<&%R86T@("`@;V)J96-T("`@2%144%]297%U
M97-T7TQI<W1E;F5R(&EN<W1A;F-E('1O(&1E=&%C:`H@("`@*B!`<F5T=7)N
M("`@8F]O;&5A;B`@=VAE=&AE<B!T:&4@;&ES=&5N97(@=V%S('-U8V-E<W-F
M=6QL>2!D971A8VAE9`H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J+PH@
M("`@9G5N8W1I;VX@9&5T86-H*"8D;&ES=&5N97(I"B`@("!["B`@("`@("`@
M:68@*"%I<U]A*"1L:7-T96YE<BP@)TA45%!?4F5Q=65S=%],:7-T96YE<B<I
M('Q\(`H@("`@("`@("`@("`A:7-S970H)'1H:7,M/E]L:7-T96YE<G-;)&QI
M<W1E;F5R+3YG971)9"@I72DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*("`@("`@("!U;G-E="@D=&AI<RT^7VQI<W1E;F5R<ULD
M;&ES=&5N97(M/F=E=$ED*"E=*3L*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"@H@("`O*BH*("`@("H@3F]T:69I97,@86QL(')E9VES=&5R960@;&ES
M=&5N97)S(&]F(&%N(&5V96YT+@H@("`@*B`*("`@("H@179E;G1S('-E;G0@
M8GD@2%144%]297%U97-T(&]B:F5C=`H@("`@*B`G<V5N=%)E<75E<W0G.B!A
M9G1E<B!T:&4@<F5Q=65S="!W87,@<V5N=`H@("`@*B!%=F5N=',@<V5N="!B
M>2!(5%107U)E<W!O;G-E(&]B:F5C=`H@("`@*B`G9V]T2&5A9&5R<R<Z(&%F
M=&5R(')E8V5I=FEN9R!R97-P;VYS92!H96%D97)S("AH96%D97)S(&%R92!P
M87-S960@:6X@)&1A=&$I"B`@("`J("=T:6-K)SH@;VX@<F5C96EV:6YG(&$@
M<&%R="!O9B!R97-P;VYS92!B;V1Y("AT:&4@<&%R="!I<R!P87-S960@:6X@
M)&1A=&$I"B`@("`J("=G>E1I8VLG.B!O;B!R96-E:79I;F<@82!G>FEP+65N
M8V]D960@<&%R="!O9B!R97-P;VYS92!B;V1Y("AD:71T;RD*("`@("H@)V=O
M=$)O9'DG.B!A9G1E<B!R96-E:79I;F<@=&AE(')E<W!O;G-E(&)O9'D@*'!A
M<W-E<R!T:&4@9&5C;V1E9"!B;V1Y(&EN("1D871A(&EF(&ET('=A<R!G>FEP
M<&5D*0H@("`@*B`*("`@("H@0'!A<F%M("`@('-T<FEN9R`@179E;G0@;F%M
M90H@("`@*B!`<&%R86T@("`@;6EX960@("!!9&1I=&EO;F%L(&1A=&$*("`@
M("H@0&%C8V5S<R`@('!R:79A=&4*("`@("HO"B`@("!F=6YC=&EO;B!?;F]T
M:69Y*"1E=F5N="P@)&1A=&$@/2!N=6QL*0H@("`@>PH@("`@("`@(&9O<F5A
M8V@@*&%R<F%Y7VME>7,H)'1H:7,M/E]L:7-T96YE<G,I(&%S("1I9"D@>PH@
M("`@("`@("`@("`D=&AI<RT^7VQI<W1E;F5R<ULD:61=+3YU<&1A=&4H)'1H
M:7,L("1E=F5N="P@)&1A=&$I.PH@("`@("`@('T*("`@('T*?0H*"B\J*@HJ
M(%)E<W!O;G-E(&-L87-S('1O(&-O;7!L96UE;G0@=&AE(%)E<75E<W0@8VQA
M<W,**B\*8VQA<W,@2%144%]297-P;VYS90I["B`@("`O*BH*("`@("H@4V]C
M:V5T(&]B:F5C=`H@("`@*B!`=F%R(&]B:F5C=`H@("`@*B\*("`@('9A<B`D
M7W-O8VL["@H@("`@+RHJ"B`@("`J(%!R;W1O8V]L"B`@("`J($!V87(@<W1R
M:6YG"B`@("`J+PH@("`@=F%R("1?<')O=&]C;VP["B`@("`*("`@("\J*@H@
M("`@*B!2971U<FX@8V]D90H@("`@*B!`=F%R('-T<FEN9PH@("`@*B\*("`@
M('9A<B`D7V-O9&4["B`@("`*("`@("\J*@H@("`@*B!297-P;VYS92!H96%D
M97)S"B`@("`J($!V87(@87)R87D*("`@("HO"B`@("!V87(@)%]H96%D97)S
M.PH*("`@("\J*@H@("`@*B!#;V]K:65S('-E="!I;B!R97-P;VYS92`@"B`@
M("`J($!V87(@87)R87D*("`@("HO"B`@("!V87(@)%]C;V]K:65S.PH*("`@
M("\J*@H@("`@*B!297-P;VYS92!B;V1Y"B`@("`J($!V87(@<W1R:6YG"B`@
M("`J+PH@("`@=F%R("1?8F]D>2`]("<G.PH*("`@+RHJ"B`@("`J(%5S960@
M8GD@7W)E861#:'5N:V5D*"DZ(')E;6%I;FEN9R!L96YG=&@@;V8@=&AE(&-U
M<G)E;G0@8VAU;FL*("`@("H@0'9A<B!S=')I;F<*("`@("HO"B`@("!V87(@
M)%]C:'5N:TQE;F=T:"`](#`["@H@("`O*BH*("`@("H@071T86-H960@;&ES
M=&5N97)S"B`@("`J($!V87(@87)R87D*("`@("HO"B`@("!V87(@)%]L:7-T
M96YE<G,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@*B!#;VYS=')U8W1O<@H@
M("`@*@H@("`@*B!`<&%R86T@(&]B:F5C="!.971?4V]C:V5T("`@("!S;V-K
M970@=&\@<F5A9"!T:&4@<F5S<&]N<V4@9G)O;0H@("`@*B!`<&%R86T@(&%R
M<F%Y("`@("`@("`@("`@("`@("!L:7-T96YE<G,@871T86-H960@=&\@<F5Q
M=65S=`H@("`@*B!`<F5T=7)N(&UI>&5D(%!%05(@17)R;W(@;VX@97)R;W(L
M('1R=64@;W1H97)W:7-E"B`@("`J+PH@("`@9G5N8W1I;VX@2%144%]297-P
M;VYS92@F)'-O8VLL("8D;&ES=&5N97)S*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?<V]C:R`@("`@(#TF("1S;V-K.PH@("`@("`@("1T:&ES+3Y?;&ES=&5N
M97)S(#TF("1L:7-T96YE<G,["B`@("!]"@H*("`@+RHJ"B`@("`J(%!R;V-E
M<W-E<R!A($A45%`@<F5S<&]N<V4*("`@("H@"B`@("`J(%1H:7,@97AT<F%C
M=',@<F5S<&]N<V4@8V]D92P@:&5A9&5R<RP@8V]O:VEE<R!A;F0@9&5C;V1E
M<R!B;V1Y(&EF(&ET(`H@("`@*B!W87,@96YC;V1E9"!I;B!S;VUE('=A>0H@
M("`@*@H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B!`<&%R86T@(&)O;VP@
M("`@("!7:&5T:&5R('1O('-T;W)E(')E<W!O;G-E(&)O9'D@:6X@;V)J96-T
M('!R;W!E<G1Y+"!S970*("`@("H@("`@("`@("`@("`@("`@("`@=&AI<R!T
M;R!F86QS92!I9B!D;W=N;&]A9&EN9R!A($Q!4D=%(&9I;&4@86YD('5S:6YG
M(&$@3&ES=&5N97(N"B`@("`J("`@("`@("`@("`@("`@("`@(%1H:7,@:7,@
M87-S=6UE9"!T;R!B92!T<G5E(&EF(&)O9'D@:7,@9WII<"UE;F-O9&5D+@H@
M("`@*B!`=&AR;W=S(%!%05)?17)R;W(*("`@("H@0')E='5R;B!M:7AE9"`@
M("`@=')U92!O;B!S=6-C97-S+"!014%27T5R<F]R(&EN(&-A<V4@;V8@;6%L
M9F]R;65D(')E<W!O;G-E"B`@("`J+PH@("`@9G5N8W1I;VX@<')O8V5S<R@D
M<V%V94)O9'D@/2!T<G5E*0H@("`@>PH@("`@("`@(&1O('L*("`@("`@("`@
M("`@)&QI;F4@/2`D=&AI<RT^7W-O8VLM/G)E861,:6YE*"D["B`@("`@("`@
M("`@(&EF("AS<V-A;F8H)&QI;F4L("=(5%10+R5S("5S)RP@)&AT='!?=F5R
M<VEO;BP@)')E='5R;F-O9&4I("$](#(I('L*("`@("`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*"=-86QF;W)M960@<F5S<&]N<V4N)RD[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!R;W1O8V]L(#T@)TA45%`O)R`N("1H='1P7W9E<G-I;VX["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V-O9&4@("`@(#T@:6YT=F%L*"1R971U<FYC;V1E
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!W:&EL92`H)R<@(3T]("@D
M:&5A9&5R(#T@)'1H:7,M/E]S;V-K+3YR96%D3&EN92@I*2D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P<F]C97-S2&5A9&5R*"1H96%D97(I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!W:&EL92`H,3`P(#T]("1T:&ES+3Y?8V]D
M92D["@H@("`@("`@("1T:&ES+3Y?;F]T:69Y*"=G;W1(96%D97)S)RP@)'1H
M:7,M/E]H96%D97)S*3L*"B`@("`@("`@+R\@268@<F5S<&]N<V4@8F]D>2!I
M<R!P<F5S96YT+"!R96%D(&ET(&%N9"!D96-O9&4*("`@("`@("`D8VAU;FME
M9"`](&ES<V5T*"1T:&ES+3Y?:&5A9&5R<ULG=')A;G-F97(M96YC;V1I;F<G
M72D@)B8@*"=C:'5N:V5D)R`]/2`D=&AI<RT^7VAE861E<G-;)W1R86YS9F5R
M+65N8V]D:6YG)UTI.PH@("`@("`@("1G>FEP<&5D(#T@:7-S970H)'1H:7,M
M/E]H96%D97)S6R=C;VYT96YT+65N8V]D:6YG)UTI("8F("@G9WII<"<@/3T@
M)'1H:7,M/E]H96%D97)S6R=C;VYT96YT+65N8V]D:6YG)UTI.PH@("`@("`@
M("1H87-";V1Y(#T@9F%L<V4["B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7VAE861E<G-;)V-O;G1E;G0M;&5N9W1H)UTI('Q\(#`@(3T@)'1H:7,M/E]H
M96%D97)S6R=C;VYT96YT+6QE;F=T:"==*2!["B`@("`@("`@("`@('=H:6QE
M("@A)'1H:7,M/E]S;V-K+3YE;V8H*2D@>PH@("`@("`@("`@("`@("`@:68@
M*"1C:'5N:V5D*2!["B`@("`@("`@("`@("`@("`@("`@)&1A=&$@/2`D=&AI
M<RT^7W)E861#:'5N:V5D*"D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("1D871A(#T@)'1H:7,M/E]S;V-K+3YR96%D
M*#0P.38I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@
M*"<G(#T]("1D871A*2!["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1H
M87-";V1Y(#T@=')U93L*("`@("`@("`@("`@("`@("`@("!I9B`H)'-A=F5"
M;V1Y('Q\("1G>FEP<&5D*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?8F]D>2`N/2`D9&%T83L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]N;W1I9GDH)&=Z:7!P960_("=G
M>E1I8VLG.B`G=&EC:R<L("1D871A*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H)&AA<T)O9'DI('L*
M("`@("`@("`@("`@+R\@56YC;VUP<F5S<R!T:&4@8F]D>2!I9B!N965D960*
M("`@("`@("`@("`@:68@*"1G>FEP<&5D*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V)O9'D@/2!G>FEN9FQA=&4H<W5B<W1R*"1T:&ES+3Y?8F]D>2P@
M,3`I*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;F]T:69Y*"=G;W1";V1Y
M)RP@)'1H:7,M/E]B;V1Y*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?;F]T:69Y*"=G;W1";V1Y)RD["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H*
M("`@+RHJ"B`@("`J(%!R;V-E<W-E<R!T:&4@<F5S<&]N<V4@:&5A9&5R"B`@
M("`J"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@*B!`<&%R86T@('-T<FEN
M9R`@("!(5%10(&AE861E<@H@("`@*B\*("`@(&9U;F-T:6]N(%]P<F]C97-S
M2&5A9&5R*"1H96%D97(I"B`@("!["B`@("`@("`@;&ES="@D:&5A9&5R;F%M
M92P@)&AE861E<G9A;'5E*2`](&5X<&QO9&4H)SHG+"`D:&5A9&5R+"`R*3L*
M("`@("`@("`D:&5A9&5R;F%M92`@/2!S=')T;VQO=V5R*"1H96%D97)N86UE
M*3L*("`@("`@("`D:&5A9&5R=F%L=64@/2!L=')I;2@D:&5A9&5R=F%L=64I
M.PH@("`@("`@(`H@("`@("`@(&EF("@G<V5T+6-O;VMI92<@(3T@)&AE861E
M<FYA;64I('L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?:&5A9&5R
M<ULD:&5A9&5R;F%M95TI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VAE
M861E<G-;)&AE861E<FYA;65=("X]("<L)R`N("1H96%D97)V86QU93L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?:&5A
M9&5R<ULD:&5A9&5R;F%M95T@(#T@)&AE861E<G9A;'5E.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]P87)S
M94-O;VMI92@D:&5A9&5R=F%L=64I.PH@("`@("`@('T*("`@('T*"@H@("`O
M*BH*("`@("H@4&%R<V4@82!3970M0V]O:VEE(&AE861E<B!T;R!F:6QL("1?
M8V]O:VEE<R!A<G)A>0H@("`@*@H@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("H@0'!A<F%M("!S=')I;F<@("`@=F%L=64@;V8@4V5T+4-O;VMI92!H96%D
M97(*("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5#;V]K:64H)&AE861E<G9A
M;'5E*0H@("`@>PH@("`@("`@("1C;V]K:64@/2!A<G)A>2@*("`@("`@("`@
M("`@)V5X<&ER97,G(#T^(&YU;&PL"B`@("`@("`@("`@("=D;VUA:6XG("`]
M/B!N=6QL+`H@("`@("`@("`@("`G<&%T:"<@("`@/3X@;G5L;"P*("`@("`@
M("`@("`@)W-E8W5R92<@(#T^(&9A;'-E"B`@("`@("`@*3L*"B`@("`@("`@
M+R\@3VYL>2!A(&YA;64]=F%L=64@<&%I<@H@("`@("`@(&EF("@A<W1R<&]S
M*"1H96%D97)V86QU92P@)SLG*2D@>PH@("`@("`@("`@("`D<&]S(#T@<W1R
M<&]S*"1H96%D97)V86QU92P@)STG*3L*("`@("`@("`@("`@)&-O;VMI95LG
M;F%M92==("`]('1R:6TH<W5B<W1R*"1H96%D97)V86QU92P@,"P@)'!O<RDI
M.PH@("`@("`@("`@("`D8V]O:VEE6R=V86QU92==(#T@=')I;2AS=6)S='(H
M)&AE861E<G9A;'5E+"`D<&]S("L@,2DI.PH*("`@("`@("`O+R!3;VUE(&]P
M=&EO;F%L('!A<F%M971E<G,@87)E('-U<'!L:65D"B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&5L96UE;G1S(#T@97AP;&]D92@G.R<L("1H96%D
M97)V86QU92D["B`@("`@("`@("`@("1P;W,@/2!S=')P;W,H)&5L96UE;G1S
M6S!=+"`G/2<I.PH@("`@("`@("`@("`D8V]O:VEE6R=N86UE)UT@(#T@=')I
M;2AS=6)S='(H)&5L96UE;G1S6S!=+"`P+"`D<&]S*2D["B`@("`@("`@("`@
M("1C;V]K:65;)W9A;'5E)UT@/2!T<FEM*'-U8G-T<B@D96QE;65N='-;,%TL
M("1P;W,@*R`Q*2D["@H@("`@("`@("`@("!F;W(@*"1I(#T@,3L@)&D@/"!C
M;W5N="@D96QE;65N=',I.R`D:2LK*2!["B`@("`@("`@("`@("`@("!I9B`H
M9F%L<V4@/3T]('-T<G!O<R@D96QE;65N='-;)&E=+"`G/2<I*2!["B`@("`@
M("`@("`@("`@("`@("`@)&5L3F%M92`@/2!T<FEM*"1E;&5M96YT<ULD:5TI
M.PH@("`@("`@("`@("`@("`@("`@("1E;%9A;'5E(#T@;G5L;#L*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@;&ES="`H
M)&5L3F%M92P@)&5L5F%L=64I(#T@87)R87E?;6%P*"=T<FEM)RP@97AP;&]D
M92@G/2<L("1E;&5M96YT<ULD:5TI*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1E;$YA;64@/2!S=')T;VQO=V5R*"1E;$YA;64I.PH@
M("`@("`@("`@("`@("`@:68@*"=S96-U<F4G(#T]("1E;$YA;64I('L*("`@
M("`@("`@("`@("`@("`@("`D8V]O:VEE6R=S96-U<F4G72`]('1R=64["B`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H)V5X<&ER97,G(#T]("1E;$YA;64I
M('L*("`@("`@("`@("`@("`@("`@("`D8V]O:VEE6R=E>'!I<F5S)UT@/2!S
M=')?<F5P;&%C92@G(B<L("<G+"`D96Q686QU92D["B`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H)W!A=&@G(#T]("1E;$YA;64@?'P@)V1O;6%I;B<@/3T@
M)&5L3F%M92D@>PH@("`@("`@("`@("`@("`@("`@("1C;V]K:65;)&5L3F%M
M95T@/2!U<FQD96-O9&4H)&5L5F%L=64I.PH@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D8V]O:VEE6R1E;$YA;65=(#T@
M)&5L5F%L=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@)'1H:7,M/E]C;V]K:65S6UT@/2`D8V]O:VEE.PH@
M("`@?0H*"B`@("\J*@H@("`@*B!296%D(&$@<&%R="!O9B!R97-P;VYS92!B
M;V1Y(&5N8V]D960@=VET:"!C:'5N:V5D(%1R86YS9F5R+45N8V]D:6YG"B`@
M("`J(`H@("`@*B!`86-C97-S('!R:79A=&4*("`@("H@0')E='5R;B!S=')I
M;F<*("`@("HO"B`@("!F=6YC=&EO;B!?<F5A9$-H=6YK960H*0H@("`@>PH@
M("`@("`@("\O(&%T('-T87)T(&]F('1H92!N97AT(&-H=6YK/PH@("`@("`@
M(&EF("@P(#T]("1T:&ES+3Y?8VAU;FM,96YG=&@I('L*("`@("`@("`@("`@
M)&QI;F4@/2`D=&AI<RT^7W-O8VLM/G)E861,:6YE*"D["B`@("`@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"<O7BA;,"TY82UF72LI+VDG+"`D;&EN92P@)&UA
M=&-H97,I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-H=6YK3&5N9W1H
M(#T@:&5X9&5C*"1M871C:&5S6S%=*3L@"B`@("`@("`@("`@("`@("`O+R!#
M:'5N:R!W:71H('IE<F\@;&5N9W1H(&EN9&EC871E<R!T:&4@96YD"B`@("`@
M("`@("`@("`@("!I9B`H,"`]/2`D=&AI<RT^7V-H=6YK3&5N9W1H*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S;V-K+3YR96%D3&EN92@I.R`O
M+R!M86ME('1H:7,@86X@96]F*"D*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)R<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@)&1A=&$@/2`D=&AI<RT^7W-O8VLM/G)E860H)'1H
M:7,M/E]C:'5N:TQE;F=T:"D["B`@("`@("`@)'1H:7,M/E]C:'5N:TQE;F=T
M:"`M/2!S=')L96XH)&1A=&$I.PH@("`@("`@(&EF("@P(#T]("1T:&ES+3Y?
M8VAU;FM,96YG=&@I('L*("`@("`@("`@("`@)'1H:7,M/E]S;V-K+3YR96%D
M3&EN92@I.R`O+R!4<F%I;&EN9R!#4DQ&"B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D9&%T83L*("`@('T*"@H@("`O*BH*("`@("H@3F]T:69I97,@86QL
M(')E9VES=&5R960@;&ES=&5N97)S(&]F(&%N(&5V96YT+@H@("`@*B`*("`@
M("H@0'!A<F%M("`@('-T<FEN9R`@179E;G0@;F%M90H@("`@*B!`<&%R86T@
M("`@;6EX960@("!!9&1I=&EO;F%L(&1A=&$*("`@("H@0&%C8V5S<R`@('!R
M:79A=&4*("`@("H@0'-E92!(5%107U)E<75E<W0Z.E]N;W1I9GDH*0H@("`@
M*B\*("`@(&9U;F-T:6]N(%]N;W1I9GDH)&5V96YT+"`D9&%T82`](&YU;&PI
M"B`@("!["B`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D=&AI<RT^7VQI
M<W1E;F5R<RD@87,@)&ED*2!["B`@("`@("`@("`@("1T:&ES+3Y?;&ES=&5N
M97)S6R1I9%TM/G5P9&%T92@D=&AI<RP@)&5V96YT+"`D9&%T82D["B`@("`@
M("`@?0H@("`@?0I]("\O($5N9"!C;&%S<R!(5%107U)E<W!O;G-E"C\^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B],;V<O
M````````````````````````````````````````````````````````````
M```````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#4Q-30S,S<S-P`P,3<S,S``(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+TQO9R]C;VUP;W-I=&4N<&AP````````````````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q-S8W`#$P-3$U-#,S-S,W`#`R,C`U
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@)$AE861E<CH@+W)E<&]S:71O<GDO<&5A<B],;V<O3&]G
M+V-O;7!O<VET92YP:'`L=B`Q+C(V(#(P,#4O,#@O,C0@,#4Z,#DZ-#4@:F]N
M($5X<"`D"B`J("1(;W)D93H@:&]R9&4O;&EB+TQO9R]C;VUP;W-I=&4N<&AP
M+'8@,2XR(#(P,#`O,#8O,C@@,C$Z,S8Z,3,@:F]N($5X<"`D"B`J"B`J($!V
M97)S:6]N("12979I<VEO;CH@,2XR-B`D"B`J($!P86-K86=E($QO9PH@*B\*
M"B\J*@H@*B!4:&4@3&]G7V-O;7!O<VET93HZ(&-L87-S(&EM<&QE;65N=',@
M82!#;VUP;W-I=&4@<&%T=&5R;B!W:&EC:`H@*B!A;&QO=W,@;75L=&EP;&4@
M3&]G(&EM<&QE;65N=&%T:6]N<R!T;R!R96-E:79E('1H92!S86UE(&5V96YT
M<RX*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D
M92YO<F<^"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!P:'`N;F5T/@H@
M*@H@*B!`<VEN8V4@2&]R9&4@,2XS"B`J($!S:6YC92!,;V<@,2XP"B`J($!P
M86-K86=E($QO9PH@*@H@*B!`97AA;7!L92!C;VUP;W-I=&4N<&AP("`@57-I
M;F<@=&AE(&-O;7!O<VET92!H86YD;&5R+@H@*B\*8VQA<W,@3&]G7V-O;7!O
M<VET92!E>'1E;F1S($QO9PI["B`@("`O*BH*("`@("`J($%R<F%Y(&AO;&1I
M;F<@86QL(&]F('1H92!,;V<@:6YS=&%N8V5S('1O('=H:6-H(&QO9R!E=F5N
M=',@<VAO=6QD(&)E"B`@("`@*B!S96YT+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@
M)%]C:&EL9')E;B`](&%R<F%Y*"D["@H*("`@("\J*@H@("`@("H@0V]N<W1R
M=6-T<R!A(&YE=R!C;VUP;W-I=&4@3&]G(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`@("1N86UE("`@("`@(%1H:7,@<&%R86UE=&5R
M(&ES(&EG;F]R960N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`@("1I9&5N="`@
M("`@(%1H:7,@<&%R86UE=&5R(&ES(&EG;F]R960N"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`@("1C;VYF("`@("`@(%1H:7,@<&%R86UE=&5R(&ES(&EG;F]R
M960N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`@("1L979E;"`@("`@(%1H:7,@
M<&%R86UE=&5R(&ES(&EG;F]R960N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@3&]G7V-O;7!O<VET92@D;F%M
M92P@)&ED96YT(#T@)R<L("1C;VYF(#T@87)R87DH*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&QE=F5L(#T@4$5!4E],3T=?1$5"54<I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]I9&5N="`]("1I9&5N=#L*("`@('T*"B`@("`O
M*BH*("`@("`J($]P96YS('1H92!C:&EL9"!C;VYN96-T:6]N<RX*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!O
M<&5N*"D*("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?;W!E;F5D*2!["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?8VAI;&1R96X@87,@)&ED(#T^
M("1C:&EL9"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C:&EL9')E;ELD
M:61=+3YO<&5N*"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M
M/E]O<&5N960@/2!T<G5E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($-L;W-E<R!A;GD@8VAI;&0@:6YS=&%N8V5S+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L;W-E*"D*
M("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]O<&5N960I('L*("`@("`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/E]C:&EL9')E;B!A<R`D:60@/3X@)&-H:6QD
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-H:6QD<F5N6R1I9%TM/F-L
M;W-E*"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]O<&5N
M960@/2!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&
M;'5S:&5S(&%L;"!O<&5N(&-H:6QD(&EN<W1A;F-E<RX*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-I;F-E($QO9R`Q+C@N,@H@("`@
M("HO"B`@("!F=6YC=&EO;B!F;'5S:"@I"B`@("!["B`@("`@("`@:68@*"1T
M:&ES+3Y?;W!E;F5D*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?
M8VAI;&1R96X@87,@)&ED(#T^("1C:&EL9"D@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]C:&EL9')E;ELD:61=+3YF;'5S:"@I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4V5N9',@)&UE<W-A
M9V4@86YD("1P<FEO<FET>2!T;R!E86-H(&-H:6QD(&]F('1H:7,@8V]M<&]S
M:71E+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`@("`@)&UE<W-A9V4@
M("`@4W1R:6YG(&]R(&]B:F5C="!C;VYT86EN:6YG('1H92!M97-S86=E"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1O(&QO9RX*("`@
M("`J($!P87)A;2!S=')I;F<@("`@)'!R:6]R:71Y("`@*&]P=&EO;F%L*2!4
M:&4@<')I;W)I='D@;V8@=&AE(&UE<W-A9V4N"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%9A;&ED('9A;'5E<R!A<F4Z(%!%05)?3$]'
M7T5-15)'+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!0
M14%27TQ/1U]!3$525"P@4$5!4E],3T=?0U))5"P*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@4$5!4E],3T=?15)2+"!014%27TQ/1U]7
M05).24Y'+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!0
M14%27TQ/1U].3U1)0T4L(%!%05)?3$]'7TE.1D\L(&%N9`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!014%27TQ/1U]$14)51RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE(&5N=')Y
M(&ES('-U8V-E<W-F=6QL>2!L;V=G960N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;&]G*"1M97-S86=E+"`D
M<')I;W)I='D@/2!N=6QL*0H@("`@>PH@("`@("`@("\J($EF(&$@<')I;W)I
M='D@:&%S;B=T(&)E96X@<W!E8VEF:65D+"!U<V4@=&AE(&1E9F%U;'0@=F%L
M=64N("HO"B`@("`@("`@:68@*"1P<FEO<FET>2`]/3T@;G5L;"D@>PH@("`@
M("`@("`@("`D<')I;W)I='D@/2`D=&AI<RT^7W!R:6]R:71Y.PH@("`@("`@
M('T*"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]C:&EL9')E;B!A<R`D:60@
M/3X@)&-H:6QD*2!["B`@("`@("`@("`@("1T:&ES+3Y?8VAI;&1R96Y;)&ED
M72T^;&]G*"1M97-S86=E+"`D<')I;W)I='DI.PH@("`@("`@('T*"B`@("`@
M("`@)'1H:7,M/E]A;FYO=6YC92AA<G)A>2@G<')I;W)I='DG(#T^("1P<FEO
M<FET>2P@)VUE<W-A9V4G(#T^("1M97-S86=E*2D["@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T<G5E(&EF
M('1H:7,@:7,@82!C;VUP;W-I=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!4<G5E(&EF('1H:7,@:7,@82!C;VUP;W-I=&4@8VQA<W,N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@:7-#;VUP;W-I=&4H*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&ES(&ED96YT:69I8V%T:6]N
M('-T<FEN9R!F;W(@86QL(&]F('1H:7,@8V]M<&]S:71E)W,@8VAI;&1R96XN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@("`D:61E;G0@("`@("!4
M:&4@;F5W(&ED96YT:69I8V%T:6]N('-T<FEN9RX*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0'-I;F-E("!,;V<@,2XV+C<*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T261E;G0H)&ED96YT*0H@("`@>PH@("`@("`@
M("\J($-A;&P@;W5R(&)A<V4@8VQA<W,G<R!S971)9&5N="@I(&UE=&AO9"X@
M*B\*("`@("`@("!P87)E;G0Z.G-E=$ED96YT*"1I9&5N="D["@H@("`@("`@
M("\J("XN+B!A;F0@=&AE;B!C86QL('-E=$ED96YT*"D@;VX@86QL(&]F(&]U
M<B!C:&EL9')E;BX@*B\*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V-H:6QD
M<F5N(&%S("1I9"`]/B`D8VAI;&0I('L*("`@("`@("`@("`@)'1H:7,M/E]C
M:&EL9')E;ELD:61=+3YS971)9&5N="@D:61E;G0I.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($%D9',@82!,;V<@:6YS=&%N8V4@=&\@=&AE
M(&QI<W0@;V8@8VAI;&1R96XN"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C
M="`@("`D8VAI;&0@("`@("!4:&4@3&]G(&EN<W1A;F-E('1O(&%D9"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE($QO9R!I
M;G-T86YC92!W87,@<W5C8V5S<V9U;&QY(&%D9&5D+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$-H:6QD
M*"8D8VAI;&0I"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E('1H:7,@:7,@
M82!,;V<@:6YS=&%N8V4N("HO"B`@("`@("`@:68@*"%I<U]A*"1C:&EL9"P@
M)TQO9R<I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3Y?8VAI;&1R96Y;)&-H:6QD+3Y?:61=(#T@)B1C
M:&EL9#L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!296UO=F5S(&$@3&]G(&EN<W1A;F-E(&9R;VT@=&AE(&QI<W0@;V8@
M8VAI;&1R96XN"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`@("`D8VAI
M;&0@("`@("!4:&4@3&]G(&EN<W1A;F-E('1O(')E;6]V92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE($QO9R!I;G-T86YC
M92!W87,@<W5C8V5S<V9U;&QY(')E;6]V960N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E0VAI;&0H
M)&-H:6QD*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D8VAI;&0L("=,;V<G
M*2!\?"`A:7-S970H)'1H:7,M/E]C:&EL9')E;ELD8VAI;&0M/E]I9%TI*2![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@
M('5N<V5T*"1T:&ES+3Y?8VAI;&1R96Y;)&-H:6QD+3Y?:61=*3L*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@I]"@```````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B],;V<O8V]N<V]L92YP:'``````````````
M```````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,C,S,P`Q,#4Q-30S,S<S
M-P`P,C$U,#4`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J("1(96%D97(Z("]R97!O<VET;W)Y+W!E87(O
M3&]G+TQO9R]C;VYS;VQE+G!H<"QV(#$N,C(@,C`P-B\P,2\Q,2`P-SHU-CHS
M-R!J;VX@17AP("0*("H*("H@0'9E<G-I;VX@)%)E=FES:6]N.B`Q+C(R("0*
M("H@0'!A8VMA9V4@3&]G"B`J+PH*+RHJ"B`J(%1H92!,;V=?8V]N<V]L92!C
M;&%S<R!I<R!A(&-O;F-R971E(&EM<&QE;65N=&%T:6]N(&]F('1H92!,;V<Z
M.@H@*B!A8G-T<F%C="!C;&%S<R!W:&EC:"!W<FET97,@;65S<V%G92!T;R!T
M:&4@=&5X="!C;VYS;VQE+@H@*B`*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\
M:F]N0'!H<"YN970^"B`J($!S:6YC92`@($QO9R`Q+C$*("H@0'!A8VMA9V4@
M3&]G"B`J"B`J($!E>&%M<&QE(&-O;G-O;&4N<&AP("`@("!5<VEN9R!T:&4@
M8V]N<V]L92!H86YD;&5R+@H@*B\*8VQA<W,@3&]G7V-O;G-O;&4@97AT96YD
M<R!,;V<*>PH@("`@+RHJ"B`@("`@*B!(86YD;&4@=&\@=&AE(&-U<G)E;G0@
M;W5T<'5T('-T<F5A;2X*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]S=')E86T@/2!35$1/
M550["@H@("`@+RHJ"B`@("`@*B!3:&]U;&0@=&AE(&]U='!U="!B92!B=69F
M97)E9"!O<B!D:7-P;&%Y960@:6UM961I871E;'D_"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D
M7V)U9F9E<FEN9R`](&9A;'-E.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&AO
M;&1I;F<@=&AE(&)U9F9E<F5D(&]U='!U="X*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?8G5F
M9F5R(#T@)R<["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@8V]N=&%I;FEN9R!T
M:&4@9F]R;6%T(&]F(&$@;&]G(&QI;F4N"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7VQI;F5&
M;W)M870@/2`G)3$D<R`E,B1S(%LE,R1S72`E-"1S)SL*"B`@("`O*BH*("`@
M("`J(%-T<FEN9R!C;VYT86EN:6YG('1H92!T:6UE<W1A;7`@9F]R;6%T+B`@
M270@=VEL;"!B92!P87-S960@9&ER96-T;'D@=&\*("`@("`J('-T<F9T:6UE
M*"DN("!.;W1E('1H870@=&AE('1I;65S=&%M<"!S=')I;F<@=VEL;"!G96YE
M<F%T960@=7-I;F<@=&AE"B`@("`@*B!C=7)R96YT(&QO8V%L92X*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@=F%R("1?=&EM949O<FUA="`]("<E8B`E9"`E2#HE33HE4R<["@H@("`@
M+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W($QO9U]C;VYS;VQE(&]B:F5C
M="X*("`@("`J(`H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@26=N
M;W)E9"X*("`@("`J($!P87)A;2!S=')I;F<@)&ED96YT("`@(%1H92!I9&5N
M=&ET>2!S=')I;F<N"B`@("`@*B!`<&%R86T@87)R87D@("1C;VYF("`@("!4
M:&4@8V]N9FEG=7)A=&EO;B!A<G)A>2X*("`@("`J($!P87)A;2!I;G0@("`@
M)&QE=F5L("`@($QO9R!M97-S86=E<R!U<"!T;R!A;F0@:6YC;'5D:6YG('1H
M:7,@;&5V96PN"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!,;V=?8V]N<V]L92@D;F%M92P@)&ED96YT(#T@)R<L("1C;VYF
M(#T@87)R87DH*2P*("`@("`@("`@("`@("`@("`@("`@("`@("1L979E;"`]
M(%!%05)?3$]'7T1%0E5'*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:60@/2!M
M9#4H;6EC<F]T:6UE*"DI.PH@("`@("`@("1T:&ES+3Y?:61E;G0@/2`D:61E
M;G0["B`@("`@("`@)'1H:7,M/E]M87-K(#T@3&]G.CI54%1/*"1L979E;"D[
M"@H@("`@("`@(&EF("@A96UP='DH)&-O;F9;)W-T<F5A;2==*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7W-T<F5A;2`]("1C;VYF6R=S=')E86TG73L*("`@
M("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D8V]N9ELG8G5F9F5R:6YG)UTI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?8G5F9F5R:6YG(#T@)&-O;F9;)V)U
M9F9E<FEN9R==.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D8V]N
M9ELG;&EN949O<FUA="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VQI;F5&
M;W)M870@/2!S=')?<F5P;&%C92AA<G)A>5]K97ES*"1T:&ES+3Y?9F]R;6%T
M36%P*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87E?=F%L=65S*"1T:&ES+3Y?9F]R;6%T36%P*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;F9;
M)VQI;F5&;W)M870G72D["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y
M*"1C;VYF6R=T:6UE1F]R;6%T)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M=&EM949O<FUA="`]("1C;VYF6R=T:6UE1F]R;6%T)UT["B`@("`@("`@?0H*
M("`@("`@("`O*@H@("`@("`@("`J($EF(&]U='!U="!B=69F97)I;F<@:&%S
M(&)E96X@<F5Q=65S=&5D+"!W92!N965D('1O(')E9VES=&5R(&$*("`@("`@
M("`@*B!S:'5T9&]W;B!F=6YC=&EO;B!T:&%T('=I;&P@9'5M<"!T:&4@8G5F
M9F5R('5P;VX@=&5R;6EN871I;VXN"B`@("`@("`@("HO"B`@("`@("`@:68@
M*"1T:&ES+3Y?8G5F9F5R:6YG*2!["B`@("`@("`@("`@(')E9VES=&5R7W-H
M=71D;W=N7V9U;F-T:6]N*&%R<F%Y*"8D=&AI<RP@)U],;V=?8V]N<V]L92<I
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$97-T<G5C=&]R
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%],;V=?8V]N<V]L92@I"B`@("!["B`@
M("`@("`@)'1H:7,M/F-L;W-E*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M;&]S97,@=&AE(&]U='!U="!S=')E86TN"B`@("`@*@H@("`@("H@5&AI<R!R
M97-U;'1S(&EN(&$@8V%L;"!T;R!F;'5S:"@I+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B!`<VEN8V4@3&]G(#$N.2XP"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@("`@("`D=&AI<RT^9FQU
M<V@H*3L*("`@('T*"B`@("`O*BH*("`@("`J($9L=7-H97,@86QL('!E;F1I
M;F<@*")B=69F97)E9"(I(&1A=&$@=&\@=&AE(&]U='!U="!S=')E86TN"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S:6YC92!,;V<@
M,2XX+C(*("`@("`J+PH@("`@9G5N8W1I;VX@9FQU<V@H*0H@("`@>PH@("`@
M("`@("\J"B`@("`@("`@("H@268@;W5T<'5T(&)U9F9E<FEN9R!I<R!E;F%B
M;&5D+"!D=6UP('1H92!C;VYT96YT<R!O9B!T:&4@8G5F9F5R('1O"B`@("`@
M("`@("H@=&AE(&]U='!U="!S=')E86TN"B`@("`@("`@("HO"B`@("`@("`@
M:68@*"1T:&ES+3Y?8G5F9F5R:6YG("8F("AS=')L96XH)'1H:7,M/E]B=69F
M97(I(#X@,"DI('L*("`@("`@("`@("`@9G=R:71E*"1T:&ES+3Y?<W1R96%M
M+"`D=&AI<RT^7V)U9F9E<BD["B`@("`@("`@("`@("1T:&ES+3Y?8G5F9F5R
M(#T@)R<["B`@("`@("`@?0H@"B`@("`@("`@<F5T=7)N(&9F;'5S:"@D=&AI
M<RT^7W-T<F5A;2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!7<FET97,@)&UE
M<W-A9V4@=&\@=&AE('1E>'0@8V]N<V]L92X@06QS;RP@<&%S<V5S('1H92!M
M97-S86=E"B`@("`@*B!A;&]N9R!T;R!A;GD@3&]G7V]B<V5R=F5R(&EN<W1A
M;F-E<R!T:&%T(&%R92!O8G-E<G9I;F<@=&AI<R!,;V<N"B`@("`@*B`*("`@
M("`J($!P87)A;2!M:7AE9"`@)&UE<W-A9V4@("`@4W1R:6YG(&]R(&]B:F5C
M="!C;VYT86EN:6YG('1H92!M97-S86=E('1O(&QO9RX*("`@("`J($!P87)A
M;2!S=')I;F<@)'!R:6]R:71Y(%1H92!P<FEO<FET>2!O9B!T:&4@;65S<V%G
M92X@(%9A;&ED"B`@("`@*B`@("`@("`@("`@("`@("`@('9A;'5E<R!A<F4Z
M(%!%05)?3$]'7T5-15)'+"!014%27TQ/1U]!3$525"P*("`@("`J("`@("`@
M("`@("`@("`@("`@4$5!4E],3T=?0U))5"P@4$5!4E],3T=?15)2+"!014%2
M7TQ/1U]705).24Y'+`H@("`@("H@("`@("`@("`@("`@("`@("!014%27TQ/
M1U].3U1)0T4L(%!%05)?3$]'7TE.1D\L(&%N9"!014%27TQ/1U]$14)51RX*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S(&]R(&9A
M;'-E(&]N(&9A:6QU<F4N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!L;V<H)&UE<W-A9V4L("1P<FEO<FET>2`](&YU;&PI
M"B`@("!["B`@("`@("`@+RH@268@82!P<FEO<FET>2!H87-N)W0@8F5E;B!S
M<&5C:69I960L('5S92!T:&4@9&5F875L="!V86QU92X@*B\*("`@("`@("!I
M9B`H)'!R:6]R:71Y(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1P<FEO<FET
M>2`]("1T:&ES+3Y?<')I;W)I='D["B`@("`@("`@?0H*("`@("`@("`O*B!!
M8F]R="!E87)L>2!I9B!T:&4@<')I;W)I='D@:7,@86)O=F4@=&AE(&UA>&EM
M=6T@;&]G9VEN9R!L979E;"X@*B\*("`@("`@("!I9B`H(21T:&ES+3Y?:7--
M87-K960H)'!R:6]R:71Y*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("`O*B!%>'1R86-T('1H92!S=')I;F<@<F5P
M<F5S96YT871I;VX@;V8@=&AE(&UE<W-A9V4N("HO"B`@("`@("`@)&UE<W-A
M9V4@/2`D=&AI<RT^7V5X=')A8W1-97-S86=E*"1M97-S86=E*3L*"B`@("`@
M("`@+RH@0G5I;&0@=&AE('-T<FEN9R!C;VYT86EN:6YG('1H92!C;VUP;&5T
M92!L;V<@;&EN92X@*B\*("`@("`@("`D;&EN92`]("1T:&ES+3Y?9F]R;6%T
M*"1T:&ES+3Y?;&EN949O<FUA="P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-T<F9T:6UE*"1T:&ES+3Y?=&EM949O<FUA="DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<')I;W)I='DL("1M97-S86=E*2`N
M(")<;B(["@H@("`@("`@("\J"B`@("`@("`@("H@268@8G5F9F5R:6YG(&ES
M(&5N86)L960L(&%P<&5N9"!T:&ES(&QI;F4@=&\@=&AE(&]U='!U="!B=69F
M97(N"B`@("`@("`@("H@3W1H97)W:7-E+"!P<FEN="!T:&4@;&EN92!T;R!T
M:&4@;W5T<'5T('-T<F5A;2!I;6UE9&EA=&5L>2X*("`@("`@("`@*B\*("`@
M("`@("!I9B`H)'1H:7,M/E]B=69F97)I;F<I('L*("`@("`@("`@("`@)'1H
M:7,M/E]B=69F97(@+CT@)&QI;F4["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@9G=R:71E*"1T:&ES+3Y?<W1R96%M+"`D;&EN92D["B`@("`@("`@
M?0H*("`@("`@("`O*B!.;W1I9GD@;V)S97)V97)S(&%B;W5T('1H:7,@;&]G
M(&UE<W-A9V4N("HO"B`@("`@("`@)'1H:7,M/E]A;FYO=6YC92AA<G)A>2@G
M<')I;W)I='DG(#T^("1P<FEO<FET>2P@)VUE<W-A9V4G(#T^("1M97-S86=E
M*2D["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B],
M;V<O9&%E;6]N+G!H<```````````````````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`Q-3`S-``Q,#4Q-30S,S<S-P`P,C$S,#<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+R\@)$ED.B!D
M865M;VXN<&AP+'8@,2XR(#(P,#4O,#(O,C8@,30Z-#@Z-3@@8VAA9V5N8G4@
M17AP("0*"B\J*@H@*B!4:&4@3&]G7V1A96UO;B!C;&%S<R!I<R!A(&-O;F-R
M971E(&EM<&QE;65N=&%T:6]N(&]F('1H92!,;V<Z.@H@*B!A8G-T<F%C="!C
M;&%S<R!W:&EC:"!S96YD<R!M97-S86=E<R!T;R!S>7-L;V<@9&%E;6]N(&]N
M(%5.25@M;&EK92!M86-H:6YE<RX*("H@5&AI<R!C;&%S<R!U<V5S('1H92!S
M>7-L;V<@<')O=&]C;VPZ(&AT='`Z+R]W=W<N:65T9BYO<F<O<F9C+W)F8S,Q
M-C0N='AT"B`J"B`J($!A=71H;W(@($)A<G0@=F%N(&1E<B!38VAA;G,@/'-C
M:&%N<T!D9',N;FP^"B`J($!V97)S:6]N("12979I<VEO;CH@,2XR("0*("H@
M0'!A8VMA9V4@3&]G"B`J+PIC;&%S<R!,;V=?9&%E;6]N(&5X=&5N9',@3&]G
M"GL*("`@("\J*@H@("`@("H@26YT96=E<B!H;VQD:6YG('1H92!L;V<@9F%C
M:6QI='D@=&\@=7-E+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?;F%M92`]($Q/1U]$045-3TX["@H@("`@+RHJ"B`@("`@*B!687(@
M:&]L9&EN9R!T:&4@<F5S;W5R8V4@<&]I;G1E<B!T;R!T:&4@<V]C:V5T"B`@
M("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D7W-O8VME=#L*
M"B`@("`O*BH*("`@("`J(%1H92!I<"!A9&1R97-S(&]R('-E<G9E<FYA;64*
M("`@("`J($!S964@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]T<F%N
M<W!O<G1S+G!H<`H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?:7`@/2`G,3(W+C`N,"XQ)SL*"B`@("`O*BH*("`@("`J(%!R;W1O8V]L
M('1O('5S92`H=&-P+"!U9'`L(&5T8RXI"B`@("`@*B!`<V5E(&AT='`Z+R]W
M=W<N<&AP+FYE="]M86YU86PO96XO=')A;G-P;W)T<RYP:'`*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W!R;W1O(#T@)W5D<"<["@H@
M("`@+RHJ"B`@("`@*B!0;W)T('1O(&-O;FYE8W0@=&\*("`@("`J($!V87(@
M:6YT"B`@("`@*B\*("`@('9A<B`D7W!O<G0@/2`U,30["@H@("`@+RHJ"B`@
M("`@*B!-87AI;75M(&UE<W-A9V4@;&5N9W1H(&EN(&)Y=&5S"B`@("`@*B!`
M=F%R(&EN=`H@("`@("HO"B`@("!V87(@)%]M87AS:7IE(#T@-#`Y-CL*"B`@
M("`O*BH*("`@("`J(%-O8VME="!T:6UE;W5T(&EN('-E8V]N9',*("`@("`J
M($!V87(@:6YT"B`@("`@*B\*("`@('9A<B`D7W1I;65O=70@/2`Q.PH*"B`@
M("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@<WES;&]G(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("!4:&4@<WES
M;&]G(&9A8VEL:71Y+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:61E;G0@("`@
M5&AE(&ED96YT:71Y('-T<FEN9RX*("`@("`J($!P87)A;2!A<G)A>2`@)&-O
M;F8@("`@(%1H92!C;VYF:6=U<F%T:6]N(&%R<F%Y+@H@("`@("H@0'!A<F%M
M(&EN="`@("`D;6%X3&5V96P@36%X:6UU;2!L979E;"!A="!W:&EC:"!T;R!L
M;V<N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO
M;B!,;V=?9&%E;6]N*"1N86UE+"`D:61E;G0@/2`G)RP@)&-O;F8@/2!A<G)A
M>2@I+`H@("`@("`@("`@("`@("`@("`@("`@("`D;&5V96P@/2!014%27TQ/
M1U]$14)51RD*("`@('L*("`@("`@("`O*B!%;G-U<F4@=V4@:&%V92!A('9A
M;&ED(&EN=&5G97(@=F%L=64@9F]R("1N86UE+B`J+PH@("`@("`@(&EF("AE
M;7!T>2@D;F%M92D@?'P@(6ES7VEN="@D;F%M92DI('L*("`@("`@("`@("`@
M)&YA;64@/2!,3T=?4UE33$]'.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/E]I9"`](&UD-2AM:6-R;W1I;64H*2D["B`@("`@("`@)'1H:7,M/E]N86UE
M(#T@)&YA;64["B`@("`@("`@)'1H:7,M/E]I9&5N="`]("1I9&5N=#L*("`@
M("`@("`D=&AI<RT^7VUA<VL@/2!,;V<Z.E505$\H)&QE=F5L*3L*"B`@("`@
M("`@:68@*&ES<V5T*"1C;VYF6R=I<"==*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7VEP(#T@)&-O;F9;)VEP)UT["B`@("`@("`@?0H@("`@("`@(&EF("AI
M<W-E="@D8V]N9ELG<')O=&\G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P
M<F]T;R`]("1C;VYF6R=P<F]T;R==.PH@("`@("`@('T*("`@("`@("!I9B`H
M:7-S970H)&-O;F9;)W!O<G0G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P
M;W)T(#T@)&-O;F9;)W!O<G0G73L*("`@("`@("!]"B`@("`@("`@:68@*&ES
M<V5T*"1C;VYF6R=M87AS:7IE)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M;6%X<VEZ92`]("1C;VYF6R=M87AS:7IE)UT["B`@("`@("`@?0H@("`@("`@
M(&EF("AI<W-E="@D8V]N9ELG=&EM96]U="==*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7W1I;65O=70@/2`D8V]N9ELG=&EM96]U="==.PH@("`@("`@('T*
M("`@("`@("`D=&AI<RT^7W!R;W1O(#T@)'1H:7,M/E]P<F]T;R`N("<Z+R\G
M.PH*("`@("`@("!R96=I<W1E<E]S:'5T9&]W;E]F=6YC=&EO;BAA<G)A>2@F
M)'1H:7,L("=?3&]G7V1A96UO;B<I*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($1E<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%],;V=?9&%E;6]N*"D*("`@('L*("`@("`@
M("`D=&AI<RT^8VQO<V4H*3L*("`@('T*"B`@("`O*BH*("`@("`J($]P96YS
M(&$@8V]N;F5C=&EO;B!T;R!T:&4@<WES=&5M(&QO9V=E<BP@:68@:70@:&%S
M(&YO="!A;')E861Y"B`@("`@*B!B965N(&]P96YE9"X@(%1H:7,@:7,@:6UP
M;&EC:71L>2!C86QL960@8GD@;&]G*"DL(&EF(&YE8V5S<V%R>2X*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&]P96XH*0H@
M("`@>PH@("`@("`@(&EF("@A)'1H:7,M/E]O<&5N960I('L*("`@("`@("`@
M("`@)'1H:7,M/E]O<&5N960@/2`H8F]O;"DH)'1H:7,M/E]S;V-K970@/2!`
M9G-O8VMO<&5N*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!R;W1O("X@)'1H:7,M/E]I<"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P;W)T+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D97)R;F\L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E<G)S='(L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?=&EM96]U="DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M
M/E]O<&5N960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&]S97,@=&AE(&-O
M;FYE8W1I;VX@=&\@=&AE('-Y<W1E;2!L;V=G97(L(&EF(&ET(&ES(&]P96XN
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!C
M;&]S92@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?;W!E;F5D*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?;W!E;F5D(#T@9F%L<V4["B`@("`@("`@("`@
M(')E='5R;B!F8VQO<V4H)'1H:7,M/E]S;V-K970I.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E;F1S
M("1M97-S86=E('1O('1H92!C=7)R96YT;'D@;W!E;B!S>7-L;V<@8V]N;F5C
M=&EO;BX@($-A;&QS"B`@("`@*B!O<&5N*"D@:68@;F5C97-S87)Y+B!!;'-O
M('!A<W-E<R!T:&4@;65S<V%G92!A;&]N9R!T;R!A;GD@3&]G7V]B<V5R=F5R
M"B`@("`@*B!I;G-T86YC97,@=&AA="!A<F4@;V)S97)V:6YG('1H:7,@3&]G
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UE<W-A9V4@(%1H92!T
M97AT=6%L(&UE<W-A9V4@=&\@8F4@;&]G9V5D+@H@("`@("H@0'!A<F%M(&EN
M="`D<')I;W)I='D@*&]P=&EO;F%L*2!4:&4@<')I;W)I='D@;V8@=&AE(&UE
M<W-A9V4N("!686QI9`H@("`@("H@("`@("`@("`@("`@("`@("!V86QU97,@
M87)E.B!,3T=?14U%4D<L($Q/1U]!3$525"P@3$]'7T-2250L"B`@("`@*B`@
M("`@("`@("`@("`@("`@($Q/1U]%4E(L($Q/1U]705).24Y'+"!,3T=?3D]4
M24-%+"!,3T=?24Y&3RP*("`@("`J("`@("`@("`@("`@("`@("`@86YD($Q/
M1U]$14)51RX@(%1H92!D969A=6QT(&ES($Q/1U])3D9/+@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;&]G*"1M97-S86=E
M+"`D<')I;W)I='D@/2!N=6QL*0H@("`@>PH@("`@("`@("\J($EF(&$@<')I
M;W)I='D@:&%S;B=T(&)E96X@<W!E8VEF:65D+"!U<V4@=&AE(&1E9F%U;'0@
M=F%L=64N("HO"B`@("`@("`@:68@*"1P<FEO<FET>2`]/3T@;G5L;"D@>PH@
M("`@("`@("`@("`D<')I;W)I='D@/2`D=&AI<RT^7W!R:6]R:71Y.PH@("`@
M("`@('T*"B`@("`@("`@+RH@06)O<G0@96%R;'D@:68@=&AE('!R:6]R:71Y
M(&ES(&%B;W9E('1H92!M87AI;75M(&QO9V=I;F<@;&5V96PN("HO"B`@("`@
M("`@:68@*"$D=&AI<RT^7VES36%S:V5D*"1P<FEO<FET>2DI('L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@268@
M=&AE(&-O;FYE8W1I;VX@:7-N)W0@;W!E;B!A;F0@8V%N)W0@8F4@;W!E;F5D
M+"!R971U<FX@9F%I;'5R92X@*B\*("`@("`@("!I9B`H(21T:&ES+3Y?;W!E
M;F5D("8F("$D=&AI<RT^;W!E;B@I*2!["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"@H@("`@("`@("\J($5X=')A8W0@=&AE('-T<FEN
M9R!R97!R97-E;G1A=&EO;B!O9B!T:&4@;65S<V%G92X@*B\*("`@("`@("`D
M;65S<V%G92`]("1T:&ES+3Y?97AT<F%C=$UE<W-A9V4H)&UE<W-A9V4I.PH*
M("`@("`@("`O*B!3970@=&AE(&9A8VEL:71Y(&QE=F5L+B`J+PH@("`@("`@
M("1F86-I;&ET>5]L979E;"`](&EN='9A;"@D=&AI<RT^7VYA;64I("L*("`@
M("`@("`@("`@("`@("`@("`@("`@("!I;G1V86PH)'1H:7,M/E]T;U-Y<VQO
M9R@D<')I;W)I='DI*3L*"B`@("`@("`@+RH@4')E<&5N9"!I9&5N="!I;F9O
M+B`J+PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]I9&5N="DI('L*("`@
M("`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^7VED96YT("X@)R`G("X@)&UE
M<W-A9V4["B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C:R!F;W(@;65S<V%G
M92!L96YG=&@N("HO"B`@("`@("`@:68@*'-T<FQE;B@D;65S<V%G92D@/B`D
M=&AI<RT^7VUA>'-I>F4I('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!S=6)S
M='(H)&UE<W-A9V4L(#`L("@D=&AI<RT^7VUA>'-I>F4I("T@,3`I("X@)R!;
M+BXN72<["B`@("`@("`@?0H*("`@("`@("`O*B!7<FET92!T;R!S;V-K970N
M("HO"B`@("`@("`@9G=R:71E*"1T:&ES+3Y?<V]C:V5T+"`G/"<@+B`D9F%C
M:6QI='E?;&5V96P@+B`G/B<@+B`D;65S<V%G92`N(")<;B(I.PH*("`@("`@
M("`D=&AI<RT^7V%N;F]U;F-E*&%R<F%Y*"=P<FEO<FET>2<@/3X@)'!R:6]R
M:71Y+"`G;65S<V%G92<@/3X@)&UE<W-A9V4I*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($-O;G9E<G1S(&$@4$5!4E],3T=?*B!C;VYS=&%N="!I;G1O(&$@
M<WES;&]G($Q/1U\J(&-O;G-T86YT+@H@("`@("H*("`@("`J(%1H:7,@9G5N
M8W1I;VX@97AI<W1S(&)E8V%U<V4L('5N9&5R(%=I;F1O=W,L(&YO="!A;&P@
M;V8@=&AE($Q/1U\J"B`@("`@*B!C;VYS=&%N=',@:&%V92!U;FEQ=64@=F%L
M=65S+B`@26YS=&5A9"P@=&AE(%!%05)?3$]'7RH@=V5R92!I;G1R;V1U8V5D
M"B`@("`@*B!F;W(@9VQO8F%L('5S92P@=VET:"!T:&4@8V]N=F5R<VEO;B!T
M;R!T:&4@3$]'7RH@8V]N<W1A;G1S(&ME<'0@;&]C86P@=&\*("`@("`J('1O
M('1H92!S>7-L;V<@9')I=F5R+@H@("`@("H*("`@("`J($!P87)A;2!I;G0@
M)'!R:6]R:71Y("`@("!014%27TQ/1U\J('9A;'5E('1O(&-O;G9E<G0@=&\@
M3$]'7RH@=F%L=64N"B`@("`@*@H@("`@("H@0')E='5R;B`@5&AE($Q/1U\J
M(')E<')E<V5N=&%T:6]N(&]F("1P<FEO<FET>2X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7W1O4WES;&]G
M*"1P<FEO<FET>2D*("`@('L*("`@("`@("!S=&%T:6,@)'!R:6]R:71I97,@
M/2!A<G)A>2@*("`@("`@("`@("`@4$5!4E],3T=?14U%4D<@("`]/B!,3T=?
M14U%4D<L"B`@("`@("`@("`@(%!%05)?3$]'7T%,15)4("`@/3X@3$]'7T%,
M15)4+`H@("`@("`@("`@("!014%27TQ/1U]#4DE4("`@(#T^($Q/1U]#4DE4
M+`H@("`@("`@("`@("!014%27TQ/1U]%4E(@("`@(#T^($Q/1U]%4E(L"B`@
M("`@("`@("`@(%!%05)?3$]'7U=!4DY)3D<@/3X@3$]'7U=!4DY)3D<L"B`@
M("`@("`@("`@(%!%05)?3$]'7TY/5$E#12`@/3X@3$]'7TY/5$E#12P*("`@
M("`@("`@("`@4$5!4E],3T=?24Y&3R`@("`]/B!,3T=?24Y&3RP*("`@("`@
M("`@("`@4$5!4E],3T=?1$5"54<@("`]/B!,3T=?1$5"54<*("`@("`@("`I
M.PH*("`@("`@("`O*B!)9B!W92=R92!P87-S960@86X@=6YK;F]W;B!P<FEO
M<FET>2P@9&5F875L="!T;R!,3T=?24Y&3RX@*B\*("`@("`@("!I9B`H(6ES
M7VEN="@D<')I;W)I='DI('Q\("%I;E]A<G)A>2@D<')I;W)I='DL("1P<FEO
M<FET:65S*2D@>PH@("`@("`@("`@("!R971U<FX@3$]'7TE.1D\["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'!R:6]R:71I97-;)'!R:6]R:71Y73L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B],;V<O9&ES<&QA>2YP:'``
M````````````````````````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S`V,P`Q
M,#4Q-30S,S<S-P`P,C$U,30`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J("1(96%D97(Z("]R97!O<VET
M;W)Y+W!E87(O3&]G+TQO9R]D:7-P;&%Y+G!H<"QV(#$N."`R,#`U+S`X+S`V
M(#(S.C(X.C,U(&IO;B!%>'`@)`H@*@H@*B!`=F5R<VEO;B`D4F5V:7-I;VXZ
M(#$N."`D"B`J($!P86-K86=E($QO9PH@*B\*"B\J*@H@*B!4:&4@3&]G7V1I
M<W!L87D@8VQA<W,@:7,@82!C;VYC<F5T92!I;7!L96UE;G1A=&EO;B!O9B!T
M:&4@3&]G.CH*("H@86)S=')A8W0@8VQA<W,@=VAI8V@@=W)I=&5S(&UE<W-A
M9V4@:6YT;R!B<F]W<V5R(&EN('5S=6%L(%!(4"!M86YE<BX*("H@5&AI<R!M
M87D@8F4@=7-E9G5L(&)E8V%U<V4@=VAE;B!Y;W4@=7-E(%!%05(Z.G-E=$5R
M<F]R2&%N9&QI;F<@:6X*("H@4$5!4E]%4E)/4E]#04Q,0D%#2R!M;V1E(&5R
M<F]R(&UE<W-A9V5S(&%R92!N;W0@9&ES<&QA>65D(&)Y"B`J(%!(4"!E<G)O
M<B!H86YD;&5R+@H@*@H@*B!`875T:&]R("!0875L(%EA;F-H96YK;R`\<'5S
M:&5R0&EN86-O+G)U/@H@*B!`<VEN8V4@("!,;V<@,2XX+C`*("H@0'!A8VMA
M9V4@3&]G"B`J"B`J($!E>&%M<&QE(&1I<W!L87DN<&AP("`@("!5<VEN9R!T
M:&4@9&ES<&QA>2!H86YD;&5R+@H@*B\*8VQA<W,@3&]G7V1I<W!L87D@97AT
M96YD<R!,;V<*>PH@("`@+RHJ"B`@("`@*B!3=')I;F<@=&\@;W5T<'5T(&)E
M9F]R92!A;B!E<G)O<B!M97-S86=E"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7V5R<F]R7W!R
M97!E;F0@/2`G)SL*"B`@("`O*BH*("`@("`J(%-T<FEN9R!T;R!O=71P=70@
M869T97(@86X@97)R;W(@;65S<V%G90H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]E<G)O<E]A
M<'!E;F0@/2`G)SL*"B`@("`O*BH*("`@("`J(%-T<FEN9R!U<V5D('1O(')E
M<')E<V5N="!A(&QI;F4@8G)E86LN"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7VQI;F5B<F5A
M:R`]("(\8G(@+SY<;B(["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@
M;F5W($QO9U]D:7-P;&%Y(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N86UE("`@("!)9VYO<F5D+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D:61E;G0@("`@5&AE(&ED96YT:71Y('-T<FEN9RX*("`@("`J($!P87)A
M;2!A<G)A>2`@)&-O;F8@("`@(%1H92!C;VYF:6=U<F%T:6]N(&%R<F%Y+@H@
M("`@("H@0'!A<F%M(&EN="`@("`D;&5V96P@("`@3&]G(&UE<W-A9V5S('5P
M('1O(&%N9"!I;F-L=61I;F<@=&AI<R!L979E;"X*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N($QO9U]D:7-P;&%Y*"1N86UE
M(#T@)R<L("1I9&5N="`]("<G+"`D8V]N9B`](&%R<F%Y*"DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`D;&5V96P@/2!014%27TQ/1U]$14)51RD*("`@
M('L*("`@("`@("`D=&AI<RT^7VED(#T@;60U*&UI8W)O=&EM92@I*3L*("`@
M("`@("`D=&AI<RT^7VED96YT(#T@)&ED96YT.PH@("`@("`@("1T:&ES+3Y?
M;6%S:R`]($QO9SHZ55!43R@D;&5V96PI.PH*("`@("`@("!I9B`H:7-S970H
M)&-O;F9;)V5R<F]R7W!R97!E;F0G72DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]E<G)O<E]P<F5P96YD(#T@)&-O;F9;)V5R<F]R7W!R97!E;F0G73L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V5R<F]R7W!R97!E
M;F0@/2!I;FE?9V5T*"=E<G)O<E]P<F5P96YD7W-T<FEN9R<I.PH@("`@("`@
M('T*"B`@("`@("`@:68@*&ES<V5T*"1C;VYF6R=E<G)O<E]A<'!E;F0G72DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]E<G)O<E]A<'!E;F0@/2`D8V]N9ELG
M97)R;W)?87!P96YD)UT["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1H:7,M/E]E<G)O<E]A<'!E;F0@/2!I;FE?9V5T*"=E<G)O<E]A<'!E;F1?
M<W1R:6YG)RD["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)&-O;F9;
M)VQI;F5B<F5A:R==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VQI;F5B<F5A
M:R`]("1C;VYF6R=L:6YE8G)E86LG73L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!7<FET97,@)&UE<W-A9V4@=&\@=&AE('1E>'0@8G)O=W-E
M<BX@06QS;RP@<&%S<V5S('1H92!M97-S86=E"B`@("`@*B!A;&]N9R!T;R!A
M;GD@3&]G7V]B<V5R=F5R(&EN<W1A;F-E<R!T:&%T(&%R92!O8G-E<G9I;F<@
M=&AI<R!,;V<N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("`D;65S<V%G
M92`@("!3=')I;F<@;W(@;V)J96-T(&-O;G1A:6YI;F<@=&AE(&UE<W-A9V4@
M=&\@;&]G+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')I;W)I='D@5&AE('!R
M:6]R:71Y(&]F('1H92!M97-S86=E+B`@5F%L:60*("`@("`J("`@("`@("`@
M("`@("`@("`@=F%L=65S(&%R93H@4$5!4E],3T=?14U%4D<L(%!%05)?3$]'
M7T%,15)4+`H@("`@("H@("`@("`@("`@("`@("`@("!014%27TQ/1U]#4DE4
M+"!014%27TQ/1U]%4E(L(%!%05)?3$]'7U=!4DY)3D<L"B`@("`@*B`@("`@
M("`@("`@("`@("`@(%!%05)?3$]'7TY/5$E#12P@4$5!4E],3T=?24Y&3RP@
M86YD(%!%05)?3$]'7T1%0E5'+@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&]N('-U8V-E<W,@;W(@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO9R@D;65S<V%G
M92P@)'!R:6]R:71Y(#T@;G5L;"D*("`@('L*("`@("`@("`O*B!)9B!A('!R
M:6]R:71Y(&AA<VXG="!B965N('-P96-I9FEE9"P@=7-E('1H92!D969A=6QT
M('9A;'5E+B`J+PH@("`@("`@(&EF("@D<')I;W)I='D@/3T](&YU;&PI('L*
M("`@("`@("`@("`@)'!R:6]R:71Y(#T@)'1H:7,M/E]P<FEO<FET>3L*("`@
M("`@("!]"@H@("`@("`@("\J($%B;W)T(&5A<FQY(&EF('1H92!P<FEO<FET
M>2!I<R!A8F]V92!T:&4@;6%X:6UU;2!L;V=G:6YG(&QE=F5L+B`J+PH@("`@
M("`@(&EF("@A)'1H:7,M/E]I<TUA<VME9"@D<')I;W)I='DI*2!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\J($5X
M=')A8W0@=&AE('-T<FEN9R!R97!R97-E;G1A=&EO;B!O9B!T:&4@;65S<V%G
M92X@*B\*("`@("`@("`D;65S<V%G92`]("1T:&ES+3Y?97AT<F%C=$UE<W-A
M9V4H)&UE<W-A9V4I.PH*("`@("`@("`O*B!"=6EL9"!A;F0@;W5T<'5T('1H
M92!C;VUP;&5T92!L;V<@;&EN92X@*B\*("`@("`@("!E8VAO("1T:&ES+3Y?
M97)R;W)?<')E<&5N9"`N"B`@("`@("`@("`@("`G/&(^)R`N('5C9FER<W0H
M)'1H:7,M/G!R:6]R:71Y5&]3=')I;F<H)'!R:6]R:71Y*2D@+B`G/"]B/CH@
M)RX*("`@("`@("`@("`@(&YL,F)R*&AT;6QS<&5C:6%L8VAA<G,H)&UE<W-A
M9V4I*2`N"B`@("`@("`@("`@("`D=&AI<RT^7V5R<F]R7V%P<&5N9"`N("1T
M:&ES+3Y?;&EN96)R96%K.PH*("`@("`@("`O*B!.;W1I9GD@;V)S97)V97)S
M(&%B;W5T('1H:7,@;&]G(&UE<W-A9V4N("HO"B`@("`@("`@)'1H:7,M/E]A
M;FYO=6YC92AA<G)A>2@G<')I;W)I='DG(#T^("1P<FEO<FET>2P@)VUE<W-A
M9V4G(#T^("1M97-S86=E*2D["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B],;V<O97)R;W)?;&]G+G!H<```````````````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-C`V-``Q,#4Q-30S,S<S-P`P,C(P-#$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M("1(96%D97(Z("]R97!O<VET;W)Y+W!E87(O3&]G+TQO9R]E<G)O<E]L;V<N
M<&AP+'8@,2XW(#(P,#4O,#(O,C8@,30Z-#@Z-3@@8VAA9V5N8G4@17AP("0*
M("H*("H@0'9E<G-I;VX@)%)E=FES:6]N.B`Q+C<@)`H@*B!`<&%C:V%G92!,
M;V<*("HO"@HO*BH*("H@5&AE($QO9U]E<G)O<E]L;V<@8VQA<W,@:7,@82!C
M;VYC<F5T92!I;7!L96UE;G1A=&EO;B!O9B!T:&4@3&]G(&%B<W1R86-T"B`J
M(&-L87-S('1H870@;&]G<R!M97-S86=E<R!U<VEN9R!02%`G<R!E<G)O<E]L
M;V<H*2!F=6YC=&EO;BX*("H*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N
M0'!H<"YN970^"B`J($!S:6YC92`@($QO9R`Q+C<N,`H@*B!`<&%C:V%G92!,
M;V<*("H*("H@0&5X86UP;&4@97)R;W)?;&]G+G!H<"`@(%5S:6YG('1H92!E
M<G)O<E]L;V<@:&%N9&QE<BX*("HO"F-L87-S($QO9U]E<G)O<E]L;V<@97AT
M96YD<R!,;V<*>PH@("`@+RHJ"B`@("`@*B!4:&4@97)R;W)?;&]G*"D@;&]G
M('1Y<&4N"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!V87(@)%]T>7!E(#T@4$5!4E],3T=?5%E015]3
M65-414T["@H@("`@+RHJ"B`@("`@*B!4:&4@='EP92US<&5C:69I8R!D97-T
M:6YA=&EO;B!V86QU92X*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?9&5S=&EN871I;VX@/2`G
M)SL*"B`@("`O*BH*("`@("`J($%D9&ET:6]N86P@:&5A9&5R<R!T;R!P87-S
M('1O('1H92!M86EL*"D@9G5N8W1I;VX@=VAE;B!T:&4*("`@("`J(%!%05)?
M3$]'7U194$5?34%)3"!T>7!E(&ES('5S960N"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7V5X
M=')A7VAE861E<G,@/2`G)SL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@
M82!N97<@3&]G7V5R<F]R7VQO9R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F%M92`@("`@26=N;W)E9"X*("`@("`J($!P87)A;2!S
M=')I;F<@)&ED96YT("`@(%1H92!I9&5N=&ET>2!S=')I;F<N"B`@("`@*B!`
M<&%R86T@87)R87D@("1C;VYF("`@("!4:&4@8V]N9FEG=7)A=&EO;B!A<G)A
M>2X*("`@("`J($!P87)A;2!I;G0@("`@)&QE=F5L("`@($QO9R!M97-S86=E
M<R!U<"!T;R!A;F0@:6YC;'5D:6YG('1H:7,@;&5V96PN"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!,;V=?97)R;W)?;&]G
M*"1N86UE+"`D:61E;G0@/2`G)RP@)&-O;F8@/2!A<G)A>2@I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D;&5V96P@/2!014%27TQ/1U]$14)51RD*
M("`@('L*("`@("`@("`D=&AI<RT^7VED(#T@;60U*&UI8W)O=&EM92@I*3L*
M("`@("`@("`D=&AI<RT^7W1Y<&4@/2`D;F%M93L*("`@("`@("`D=&AI<RT^
M7VED96YT(#T@)&ED96YT.PH@("`@("`@("1T:&ES+3Y?;6%S:R`]($QO9SHZ
M55!43R@D;&5V96PI.PH*("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=D97-T
M:6YA=&EO;B==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V1E<W1I;F%T:6]N
M(#T@)&-O;F9;)V1E<W1I;F%T:6]N)UT["B`@("`@("`@?0H@("`@("`@(&EF
M("@A96UP='DH)&-O;F9;)V5X=')A7VAE861E<G,G72DI('L*("`@("`@("`@
M("`@)'1H:7,M/E]E>'1R85]H96%D97)S(#T@)&-O;F9;)V5X=')A7VAE861E
M<G,G73L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!,;V=S("1M
M97-S86=E('5S:6YG(%!(4"=S(&5R<F]R7VQO9R@I(&9U;F-T:6]N+B`@5&AE
M(&UE<W-A9V4@:7,@86QS;PH@("`@("H@<&%S<V5D(&%L;VYG('1O(&%N>2!,
M;V=?;V)S97)V97(@:6YS=&%N8V5S('1H870@87)E(&]B<V5R=FEN9R!T:&ES
M($QO9RX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@("1M97-S86=E("`@
M4W1R:6YG(&]R(&]B:F5C="!C;VYT86EN:6YG('1H92!M97-S86=E('1O(&QO
M9RX*("`@("`J($!P87)A;2!S=')I;F<@)'!R:6]R:71Y(%1H92!P<FEO<FET
M>2!O9B!T:&4@;65S<V%G92X@(%9A;&ED"B`@("`@*B`@("`@("`@("`@("`@
M("`@('9A;'5E<R!A<F4Z(%!%05)?3$]'7T5-15)'+"!014%27TQ/1U]!3$52
M5"P*("`@("`J("`@("`@("`@("`@("`@("`@4$5!4E],3T=?0U))5"P@4$5!
M4E],3T=?15)2+"!014%27TQ/1U]705).24Y'+`H@("`@("H@("`@("`@("`@
M("`@("`@("!014%27TQ/1U].3U1)0T4L(%!%05)?3$]'7TE.1D\L(&%N9"!0
M14%27TQ/1U]$14)51RX*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O
M;B!S=6-C97-S(&]R(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!L;V<H)&UE<W-A9V4L("1P
M<FEO<FET>2`](&YU;&PI"B`@("!["B`@("`@("`@+RH@268@82!P<FEO<FET
M>2!H87-N)W0@8F5E;B!S<&5C:69I960L('5S92!T:&4@9&5F875L="!V86QU
M92X@*B\*("`@("`@("!I9B`H)'!R:6]R:71Y(#T]/2!N=6QL*2!["B`@("`@
M("`@("`@("1P<FEO<FET>2`]("1T:&ES+3Y?<')I;W)I='D["B`@("`@("`@
M?0H*("`@("`@("`O*B!!8F]R="!E87)L>2!I9B!T:&4@<')I;W)I='D@:7,@
M86)O=F4@=&AE(&UA>&EM=6T@;&]G9VEN9R!L979E;"X@*B\*("`@("`@("!I
M9B`H(21T:&ES+3Y?:7--87-K960H)'!R:6]R:71Y*2D@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!%>'1R86-T
M('1H92!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@=&AE(&UE<W-A9V4N("HO
M"B`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^7V5X=')A8W1-97-S86=E*"1M
M97-S86=E*3L*"B`@("`@("`@)'-U8V-E<W,@/2!E<G)O<E]L;V<H)'1H:7,M
M/E]I9&5N="`N("<Z("<@+B`D;65S<V%G92P@)'1H:7,M/E]T>7!E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&5S=&EN871I;VXL
M("1T:&ES+3Y?97AT<F%?:&5A9&5R<RD["@H@("`@("`@("1T:&ES+3Y?86YN
M;W5N8V4H87)R87DH)W!R:6]R:71Y)R`]/B`D<')I;W)I='DL("=M97-S86=E
M)R`]/B`D;65S<V%G92DI.PH*("`@("`@("!R971U<FX@)'-U8V-E<W,["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O3&]G+V9I;&4N<&AP````````````````````````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,C$U-C$`,3`U,34T,S,W,S<`,#(P-S8U`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B`D2&5A9&5R.B`O<F5P;W-I=&]R>2]P96%R+TQO9R],;V<O9FEL92YP:'`L
M=B`Q+C0U(#(P,#8O,#$O,3$@,#<Z-38Z,S<@:F]N($5X<"`D"B`J"B`J($!V
M97)S:6]N("12979I<VEO;CH@,2XT-2`D"B`J($!P86-K86=E($QO9PH@*B\*
M"B\J*@H@*B!4:&4@3&]G7V9I;&4@8VQA<W,@:7,@82!C;VYC<F5T92!I;7!L
M96UE;G1A=&EO;B!O9B!T:&4@3&]G(&%B<W1R86-T"B`J(&-L87-S('1H870@
M;&]G<R!M97-S86=E<R!T;R!A('1E>'0@9FEL92X*("H@"B`J($!A=71H;W(@
M($IO;B!087)I<V4@/&IO;D!P:'`N;F5T/@H@*B!`875T:&]R("!2;VUA;B!.
M975H875S97(@/&YE=6AA=7-E<D!B96QL879I<W1A+F-Z/@H@*B!`<VEN8V4@
M("!,;V<@,2XP"B`J($!P86-K86=E($QO9PH@*@H@*B!`97AA;7!L92!F:6QE
M+G!H<"`@("!5<VEN9R!T:&4@9FEL92!H86YD;&5R+@H@*B\*8VQA<W,@3&]G
M7V9I;&4@97AT96YD<R!,;V<*>PH@("`@+RHJ"B`@("`@*B!3=')I;F<@8V]N
M=&%I;FEN9R!T:&4@;F%M92!O9B!T:&4@;&]G(&9I;&4N"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A
M<B`D7V9I;&5N86UE(#T@)W!H<"YL;V<G.PH*("`@("\J*@H@("`@("H@2&%N
M9&QE('1O('1H92!L;V<@9FEL92X*("`@("`J($!V87(@<F5S;W5R8V4*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]F<"`](&9A
M;'-E.PH*("`@("\J*@H@("`@("H@4VAO=6QD(&YE=R!L;V<@96YT<FEE<R!B
M92!A<'!E;F0@=&\@86X@97AI<W1I;F<@;&]G(&9I;&4L(&]R('-H;W5L9"!T
M:&4*("`@("`J(&$@;F5W(&QO9R!F:6QE(&]V97)W<FET92!A;B!E>&ES=&EN
M9R!O;F4_"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!V87(@)%]A<'!E;F0@/2!T<G5E.PH*("`@("\J
M*@H@("`@("H@4VAO=6QD(&%D=FES;W)Y(&9I;&4@;&]C:VEN9R`H:2YE+BP@
M9FQO8VLH*2D@8F4@=7-E9#\*("`@("`J($!V87(@8F]O;&5A;@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7VQO8VMI;F<@/2!F
M86QS93L*"B`@("`O*BH*("`@("`J($EN=&5G97(@*&EN(&]C=&%L*2!C;VYT
M86EN:6YG('1H92!L;V<@9FEL92=S('!E<FUI<W-I;VYS(&UO9&4N"B`@("`@
M*B!`=F%R(&EN=&5G97(*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!V87(@)%]M;V1E(#T@,#8T-#L*"B`@("`O*BH*("`@("`J($EN=&5G
M97(@*&EN(&]C=&%L*2!S<&5C:69Y:6YG('1H92!F:6QE('!E<FUI<W-I;VX@
M;6]D92!T:&%T('=I;&P@8F4*("`@("`J('5S960@=VAE;B!C<F5A=&EN9R!D
M:7)E8W1O<FEE<R!T:&%T(&1O(&YO="!A;')E861Y(&5X:7-T+@H@("`@("H@
M0'9A<B!I;G1E9V5R"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@=F%R("1?9&ER;6]D92`](#`W-34["@H@("`@+RHJ"B`@("`@*B!3=')I
M;F<@8V]N=&%I;FEN9R!T:&4@9F]R;6%T(&]F(&$@;&]G(&QI;F4N"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@('9A<B`D7VQI;F5&;W)M870@/2`G)3$D<R`E,B1S(%LE,R1S72`E-"1S
M)SL*"B`@("`O*BH*("`@("`J(%-T<FEN9R!C;VYT86EN:6YG('1H92!T:6UE
M<W1A;7`@9F]R;6%T+B`@270@=VEL;"!B92!P87-S960@9&ER96-T;'D@=&\*
M("`@("`J('-T<F9T:6UE*"DN("!.;W1E('1H870@=&AE('1I;65S=&%M<"!S
M=')I;F<@=VEL;"!G96YE<F%T960@=7-I;F<@=&AE"B`@("`@*B!C=7)R96YT
M(&QO8V%L92X*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J+PH@("`@=F%R("1?=&EM949O<FUA="`]("<E8B`E9"`E
M2#HE33HE4R<["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@8V]N=&%I;FEN9R!T
M:&4@96YD+6]N+6QI;F4@8VAA<F%C=&5R('-E<75E;F-E+@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V
M87(@)%]E;VP@/2`B7&XB.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A
M(&YE=R!,;V=?9FEL92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;F%M92`@("`@26=N;W)E9"X*("`@("`J($!P87)A;2!S=')I;F<@
M)&ED96YT("`@(%1H92!I9&5N=&ET>2!S=')I;F<N"B`@("`@*B!`<&%R86T@
M87)R87D@("1C;VYF("`@("!4:&4@8V]N9FEG=7)A=&EO;B!A<G)A>2X*("`@
M("`J($!P87)A;2!I;G0@("`@)&QE=F5L("`@($QO9R!M97-S86=E<R!U<"!T
M;R!A;F0@:6YC;'5D:6YG('1H:7,@;&5V96PN"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!,;V=?9FEL92@D;F%M92P@)&ED
M96YT(#T@)R<L("1C;VYF(#T@87)R87DH*2P*("`@("`@("`@("`@("`@("`@
M("`@("1L979E;"`](%!%05)?3$]'7T1%0E5'*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?:60@/2!M9#4H;6EC<F]T:6UE*"DI.PH@("`@("`@("1T:&ES+3Y?
M9FEL96YA;64@/2`D;F%M93L*("`@("`@("`D=&AI<RT^7VED96YT(#T@)&ED
M96YT.PH@("`@("`@("1T:&ES+3Y?;6%S:R`]($QO9SHZ55!43R@D;&5V96PI
M.PH*("`@("`@("!I9B`H:7-S970H)&-O;F9;)V%P<&5N9"==*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7V%P<&5N9"`]("1C;VYF6R=A<'!E;F0G73L*("`@
M("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D8V]N9ELG;&]C:VEN9R==*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7VQO8VMI;F<@/2`D8V]N9ELG;&]C:VEN
M9R==.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG;6]D
M92==*2D@>PH@("`@("`@("`@("!I9B`H:7-?<W1R:6YG*"1C;VYF6R=M;V1E
M)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VUO9&4@/2!O8W1D96,H
M)&-O;F9;)VUO9&4G72D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7VUO9&4@/2`D8V]N9ELG;6]D92==.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=D
M:7)M;V1E)UTI*2!["B`@("`@("`@("`@(&EF("AI<U]S=')I;F<H)&-O;F9;
M)V1I<FUO9&4G72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?9&ER;6]D
M92`](&]C=&1E8R@D8V]N9ELG9&ER;6]D92==*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?9&ER;6]D92`]("1C;VYF
M6R=D:7)M;V1E)UT["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(&EF("@A96UP='DH)&-O;F9;)VQI;F5&;W)M870G72DI('L*("`@("`@("`@
M("`@)'1H:7,M/E]L:6YE1F]R;6%T(#T@<W1R7W)E<&QA8V4H87)R87E?:V5Y
M<R@D=&AI<RT^7V9O<FUA=$UA<"DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W9A;'5E<R@D=&AI<RT^7V9O
M<FUA=$UA<"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1C;VYF6R=L:6YE1F]R;6%T)UTI.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"%E;7!T>2@D8V]N9ELG=&EM949O<FUA="==*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7W1I;65&;W)M870@/2`D8V]N9ELG=&EM949O<FUA
M="==.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG96]L
M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?96]L(#T@)&-O;F9;)V5O;"==
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?96]L(#T@
M*'-T<G-T<BA02%!?3U,L("=724XG*2D@/R`B7')<;B(@.B`B7&XB.PH@("`@
M("`@('T*"B`@("`@("`@<F5G:7-T97)?<VAU=&1O=VY?9G5N8W1I;VXH87)R
M87DH)B1T:&ES+"`G7TQO9U]F:6QE)RDI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1&5S=')U8W1O<@H@("`@("HO"B`@("!F=6YC=&EO;B!?3&]G7V9I;&4H
M*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V]P96YE9"D@>PH@("`@("`@
M("`@("`D=&AI<RT^8VQO<V4H*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#<F5A=&5S('1H92!G:79E;B!D:7)E8W1O<GD@<&%T:"X@($EF
M('1H92!P87)E;G0@9&ER96-T;W)I97,@9&]N)W0*("`@("`J(&%L<F5A9'D@
M97AI<W0L('1H97D@=VEL;"!B92!C<F5A=&5D+"!T;V\N"B`@("`@*@H@("`@
M("H@5&AI<R!I;7!L96UE;G1A=&EO;B!I<R!I;G-P:7)E9"!B>2!0>71H;VXG
M<R!O<RYM86ME9&ER<R!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@
M("!S=')I;F<@("1P871H("`@("`@(%1H92!F=6QL(&1I<F5C=&]R>2!P871H
M('1O(&-R96%T92X*("`@("`J($!P87)A;2`@(&EN=&5G97(@)&UO9&4@("`@
M("`@5&AE('!E<FUI<W-I;VYS(&UO9&4@=VET:"!W:&EC:"!T:&4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9&ER96-T;W)I97,@=VEL
M;"!B92!C<F5A=&5D+@H@("`@("H*("`@("`J($!R971U<FX@(%1R=64@:68@
M=&AE(&9U;&P@<&%T:"!I<R!S=6-C97-S9G5L;'D@8W)E871E9"!O<B!A;')E
M861Y"B`@("`@*B`@("`@("`@("!E>&ES=',N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?;6MP871H*"1P
M871H+"`D;6]D92`](#`W,#`I"B`@("!["B`@("`@("`@+RH@4V5P87)A=&4@
M=&AE(&QA<W0@<&%T:&YA;64@8V]M<&]N96YT(&9R;VT@=&AE(')E<W0@;V8@
M=&AE('!A=&@N("HO"B`@("`@("`@)&AE860@/2!D:7)N86UE*"1P871H*3L*
M("`@("`@("`D=&%I;"`](&)A<V5N86UE*"1P871H*3L*"B`@("`@("`@+RH@
M36%K92!S=7)E('=E)W9E('-P;&ET('1H92!P871H(&EN=&\@='=O(&-O;7!L
M971E(&-O;7!O;F5N=',N("HO"B`@("`@("`@:68@*&5M<'1Y*"1T86EL*2D@
M>PH@("`@("`@("`@("`D:&5A9"`](&1I<FYA;64H)'!A=&@I.PH@("`@("`@
M("`@("`D=&%I;"`](&)A<V5N86UE*"1P871H*3L*("`@("`@("!]"@H@("`@
M("`@("\J(%)E8W5R<V4@=7`@=&AE('!A=&@@:68@;W5R(&-U<G)E;G0@<V5G
M;65N="!D;V5S(&YO="!E>&ES="X@*B\*("`@("`@("!I9B`H(65M<'1Y*"1H
M96%D*2`F)B`A96UP='DH)'1A:6PI("8F("%I<U]D:7(H)&AE860I*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?;6MP871H*"1H96%D+"`D;6]D92D["B`@("`@
M("`@?0H*("`@("`@("`O*B!#<F5A=&4@=&AI<R!S96=M96YT(&]F('1H92!P
M871H+B`J+PH@("`@("`@(')E='5R;B!`;6MD:7(H)&AE860L("1M;V1E*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($]P96YS('1H92!L;V<@9FEL92!F;W(@
M;W5T<'5T+B`@268@=&AE('-P96-I9FEE9"!L;V<@9FEL92!D;V5S(&YO=`H@
M("`@("H@86QR96%D>2!E>&ES="P@:70@=VEL;"!B92!C<F5A=&5D+B`@0GD@
M9&5F875L="P@;F5W(&QO9R!E;G1R:65S(&%R90H@("`@("H@87!P96YD960@
M=&\@=&AE(&5N9"!O9B!T:&4@;&]G(&9I;&4N"B`@("`@*@H@("`@("H@5&AI
M<R!I<R!I;7!L:6-I=&QY(&-A;&QE9"!B>2!L;V<H*2P@:68@;F5C97-S87)Y
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&]P96XH*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/E]O<&5N
M960I('L*("`@("`@("`@("`@+RH@268@=&AE(&QO9R!F:6QE)W,@9&ER96-T
M;W)Y(&1O97-N)W0@97AI<W0L(&-R96%T92!I="X@*B\*("`@("`@("`@("`@
M:68@*"%I<U]D:7(H9&ER;F%M92@D=&AI<RT^7V9I;&5N86UE*2DI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;6MP871H*"1T:&ES+3Y?9FEL96YA;64L
M("1T:&ES+3Y?9&ER;6]D92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("\J($1E=&5R;6EN92!W:&5T:&5R('1H92!L;V<@9FEL92!N965D<R!T;R!B
M92!C<F5A=&5D+B`J+PH@("`@("`@("`@("`D8W)E871I;F<@/2`A9FEL95]E
M>&ES=',H)'1H:7,M/E]F:6QE;F%M92D["@H@("`@("`@("`@("`O*B!/8G1A
M:6X@82!H86YD;&4@=&\@=&AE(&QO9R!F:6QE+B`J+PH@("`@("`@("`@("`D
M=&AI<RT^7V9P(#T@9F]P96XH)'1H:7,M/E]F:6QE;F%M92P@*"1T:&ES+3Y?
M87!P96YD*2`_("=A)R`Z("=W)RD["@H@("`@("`@("`@("`O*B!792!C;VYS
M:61E<B!T:&4@9FEL92`B;W!E;F5D(B!I9B!W92!H879E(&$@=F%L:60@9FEL
M92!P;VEN=&5R+B`J+PH@("`@("`@("`@("`D=&AI<RT^7V]P96YE9"`]("@D
M=&AI<RT^7V9P("$]/2!F86QS92D["@H@("`@("`@("`@("`O*B!!='1E;7!T
M('1O('-E="!T:&4@9FEL92=S('!E<FUI<W-I;VYS(&EF('=E(&IU<W0@8W)E
M871E9"!I="X@*B\*("`@("`@("`@("`@:68@*"1C<F5A=&EN9R`F)B`D=&AI
M<RT^7V]P96YE9"D@>PH@("`@("`@("`@("`@("`@8VAM;V0H)'1H:7,M/E]F
M:6QE;F%M92P@)'1H:7,M/E]M;V1E*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;W!E;F5D.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0VQO<V5S('1H92!L;V<@9FEL92!I9B!I="!I<R!O<&5N
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&-L;W-E*"D*("`@('L*("`@("`@("`O*B!)9B!T:&4@;&]G(&9I
M;&4@:7,@;W!E;BP@8VQO<V4@:70N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?
M;W!E;F5D("8F(&9C;&]S92@D=&AI<RT^7V9P*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7V]P96YE9"`](&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("@D=&AI<RT^7V]P96YE9"`]/3T@9F%L<V4I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1FQU<VAE<R!A;&P@<&5N9&EN9R!D871A('1O('1H92!F:6QE
M(&AA;F1L92X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@
M0'-I;F-E($QO9R`Q+C@N,@H@("`@("HO"B`@("!F=6YC=&EO;B!F;'5S:"@I
M"B`@("!["B`@("`@("`@<F5T=7)N(&9F;'5S:"@D=&AI<RT^7V9P*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($QO9W,@)&UE<W-A9V4@=&\@=&AE(&]U='!U
M="!W:6YD;W<N("!4:&4@;65S<V%G92!I<R!A;'-O('!A<W-E9"!A;&]N9PH@
M("`@("H@=&\@86YY($QO9U]O8G-E<G9E<B!I;G-T86YC97,@=&AA="!A<F4@
M;V)S97)V:6YG('1H:7,@3&]G+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE
M9"`@)&UE<W-A9V4@(%-T<FEN9R!O<B!O8FIE8W0@8V]N=&%I;FEN9R!T:&4@
M;65S<V%G92!T;R!L;V<N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<FEO<FET
M>2!4:&4@<')I;W)I='D@;V8@=&AE(&UE<W-A9V4N("!686QI9`H@("`@("H@
M("`@("`@("`@("`@("`@("!V86QU97,@87)E.B!014%27TQ/1U]%34521RP@
M4$5!4E],3T=?04Q%4E0L"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%05)?
M3$]'7T-2250L(%!%05)?3$]'7T524BP@4$5!4E],3T=?5T%23DE.1RP*("`@
M("`J("`@("`@("`@("`@("`@("`@4$5!4E],3T=?3D]424-%+"!014%27TQ/
M1U])3D9/+"!A;F0@4$5!4E],3T=?1$5"54<N"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%1R=64@;VX@<W5C8V5S<R!O<B!F86QS92!O;B!F86EL=7)E+@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;&]G
M*"1M97-S86=E+"`D<')I;W)I='D@/2!N=6QL*0H@("`@>PH@("`@("`@("\J
M($EF(&$@<')I;W)I='D@:&%S;B=T(&)E96X@<W!E8VEF:65D+"!U<V4@=&AE
M(&1E9F%U;'0@=F%L=64N("HO"B`@("`@("`@:68@*"1P<FEO<FET>2`]/3T@
M;G5L;"D@>PH@("`@("`@("`@("`D<')I;W)I='D@/2`D=&AI<RT^7W!R:6]R
M:71Y.PH@("`@("`@('T*"B`@("`@("`@+RH@06)O<G0@96%R;'D@:68@=&AE
M('!R:6]R:71Y(&ES(&%B;W9E('1H92!M87AI;75M(&QO9V=I;F<@;&5V96PN
M("HO"B`@("`@("`@:68@*"$D=&AI<RT^7VES36%S:V5D*"1P<FEO<FET>2DI
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@+RH@268@=&AE(&QO9R!F:6QE(&ES;B=T(&%L<F5A9'D@;W!E;BP@;W!E
M;B!I="!N;W<N("HO"B`@("`@("`@:68@*"$D=&AI<RT^7V]P96YE9"`F)B`A
M)'1H:7,M/F]P96XH*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H*("`@("`@("`O*B!%>'1R86-T('1H92!S=')I;F<@<F5P<F5S
M96YT871I;VX@;V8@=&AE(&UE<W-A9V4N("HO"B`@("`@("`@)&UE<W-A9V4@
M/2`D=&AI<RT^7V5X=')A8W1-97-S86=E*"1M97-S86=E*3L*"B`@("`@("`@
M+RH@0G5I;&0@=&AE('-T<FEN9R!C;VYT86EN:6YG('1H92!C;VUP;&5T92!L
M;V<@;&EN92X@*B\*("`@("`@("`D;&EN92`]("1T:&ES+3Y?9F]R;6%T*"1T
M:&ES+3Y?;&EN949O<FUA="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('-T<F9T:6UE*"1T:&ES+3Y?=&EM949O<FUA="DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<')I;W)I='DL("1M97-S86=E*2`N("1T
M:&ES+3Y?96]L.PH*("`@("`@("`O*B!)9B!L;V-K:6YG(&ES(&5N86)L960L
M(&%C<75I<F4@86X@97AC;'5S:79E(&QO8VL@;VX@=&AE(&9I;&4N("HO"B`@
M("`@("`@:68@*"1T:&ES+3Y?;&]C:VEN9RD@>PH@("`@("`@("`@("!F;&]C
M:R@D=&AI<RT^7V9P+"!,3T-+7T58*3L*("`@("`@("!]"@H@("`@("`@("\J
M(%=R:71E('1H92!L;V<@;&EN92!T;R!T:&4@;&]G(&9I;&4N("HO"B`@("`@
M("`@)'-U8V-E<W,@/2`H9G=R:71E*"1T:&ES+3Y?9G`L("1L:6YE*2`A/3T@
M9F%L<V4I.PH*("`@("`@("`O*B!5;FQO8VL@=&AE(&9I;&4@;F]W('1H870@
M=V4G<F4@9FEN:7-H960@=W)I=&EN9R!T;R!I="X@*B\@"B`@("`@("`@:68@
M*"1T:&ES+3Y?;&]C:VEN9RD@>PH@("`@("`@("`@("!F;&]C:R@D=&AI<RT^
M7V9P+"!,3T-+7U5.*3L*("`@("`@("!]"@H@("`@("`@("\J($YO=&EF>2!O
M8G-E<G9E<G,@86)O=70@=&AI<R!L;V<@;65S<V%G92X@*B\*("`@("`@("`D
M=&AI<RT^7V%N;F]U;F-E*&%R<F%Y*"=P<FEO<FET>2<@/3X@)'!R:6]R:71Y
M+"`G;65S<V%G92<@/3X@)&UE<W-A9V4I*3L*"B`@("`@("`@<F5T=7)N("1S
M=6-C97-S.PH@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B],;V<O;6%I;"YP:'``````````````````````````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-C`P,P`Q,#4Q-30S,S<S-P`P,C`W-C,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J("1(96%D97(Z("]R97!O<VET;W)Y+W!E87(O3&]G+TQO9R]M
M86EL+G!H<"QV(#$N,C0@,C`P-B\P,2\S,"`P-3HS-SHQ."!J;VX@17AP("0*
M("H*("H@0'9E<G-I;VX@)%)E=FES:6]N.B`Q+C(T("0*("H@0'!A8VMA9V4@
M3&]G"B`J+PH*+RHJ"B`J(%1H92!,;V=?;6%I;"!C;&%S<R!I<R!A(&-O;F-R
M971E(&EM<&QE;65N=&%T:6]N(&]F('1H92!,;V<Z.B!A8G-T<F%C="!C;&%S
M<PH@*B!W:&EC:"!S96YD<R!L;V<@;65S<V%G97,@=&\@82!M86EL8F]X+@H@
M*B!4:&4@;6%I;"!I<R!A8W1U86QL>2!S96YT('=H96X@>6]U(&-L;W-E*"D@
M=&AE(&QO9V=E<BP@;W(@=VAE;B!T:&4@9&5S=')U8W1O<@H@*B!I<R!C86QL
M960@*'=H96X@=&AE('-C<FEP="!I<R!T97)M:6YA=&5D*2X*("H*("H@4$Q%
M05-%($Y/5$4@=&AA="!Y;W4@;75S="!C<F5A=&4@82!,;V=?;6%I;"!O8FIE
M8W0@=7-I;F<@/28L(&QI:V4@=&AI<R`Z"B`J("`D;&]G9V5R(#TF($QO9SHZ
M9F%C=&]R>2@B;6%I;"(L(")R96-I<&EE;G1`97AA;7!L92YC;VTB+"`N+BXI
M"B`J"B`J(%1H:7,@:7,@82!014%2(')E<75I<F5M96YT(&9O<B!D97-T<G5C
M=&]R<R!T;R!W;W)K('!R;W!E<FQY+@H@*B!3964@:'1T<#HO+W!E87(N<&AP
M+FYE="]M86YU86PO96XO8VQA<W,N<&5A<BYP:'`*("H*("H@0&%U=&AO<B`@
M4F]N;FEE($=A<F-I82`\<F]N;FEE0&UK,BYN970^"B`J($!A=71H;W(@($IO
M;B!087)I<V4@/&IO;D!P:'`N;F5T/@H@*B!`<VEN8V4@("!,;V<@,2XS"B`J
M($!P86-K86=E($QO9PH@*@H@*B!`97AA;7!L92!M86EL+G!H<"`@("!5<VEN
M9R!T:&4@;6%I;"!H86YD;&5R+@H@*B\*8VQA<W,@3&]G7VUA:6P@97AT96YD
M<R!,;V<*>PH@("`@+RHJ"B`@("`@*B!3=')I;F<@:&]L9&EN9R!T:&4@<F5C
M:7!I96YT)W,@96UA:6P@861D<F5S<RX*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?<F5C:7!I
M96YT(#T@)R<["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@:&]L9&EN9R!T:&4@
M<V5N9&5R)W,@96UA:6P@861D<F5S<RX*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?9G)O;2`]
M("<G.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&AO;&1I;F<@=&AE(&5M86EL
M)W,@<W5B:F5C="X*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?<W5B:F5C="`]("=;3&]G7VUA
M:6Q=($QO9R!M97-S86=E)SL*"B`@("`O*BH*("`@("`J(%-T<FEN9R!H;VQD
M:6YG(&%N(&]P=&EO;F%L('!R96%M8FQE(&9O<B!T:&4@;&]G(&UE<W-A9V5S
M+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!V87(@)%]P<F5A;6)L92`]("<G.PH*("`@("\J*@H@("`@
M("H@4W1R:6YG(&-O;G1A:6YI;F<@=&AE(&9O<FUA="!O9B!A(&QO9R!L:6YE
M+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!V87(@)%]L:6YE1F]R;6%T(#T@)R4Q)',@)3(D<R!;)3,D
M<UT@)30D<R<["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@8V]N=&%I;FEN9R!T
M:&4@=&EM97-T86UP(&9O<FUA="X@($ET('=I;&P@8F4@<&%S<V5D(&1I<F5C
M=&QY('1O"B`@("`@*B!S=')F=&EM92@I+B`@3F]T92!T:&%T('1H92!T:6UE
M<W1A;7`@<W1R:6YG('=I;&P@9V5N97)A=&5D('5S:6YG('1H90H@("`@("H@
M8W5R<F5N="!L;V-A;&4N"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7W1I;65&;W)M870@/2`G
M)6(@)60@)4@Z)4TZ)5,G.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&AO;&1I
M;F<@=&AE(&UA:6P@;65S<V%G92!B;V1Y+@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]M97-S
M86=E(#T@)R<["@H*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!,
M;V=?;6%I;"!O8FIE8W0N"B`@("`@*@H@("`@("H@2&5R92!I<R!H;W<@>6]U
M(&-A;B!C=7-T;VUI>F4@=&AE(&UA:6P@9')I=F5R('=I=&@@=&AE(&-O;F9;
M72!H87-H(#H*("`@("`J("`@)&-O;F9;)V9R;VTG72`@("`Z('1H92!M86EL
M)W,@(D9R;VTB(&AE861E<B!L:6YE+`H@("`@("H@("`D8V]N9ELG<W5B:F5C
M="==(#H@=&AE(&UA:6PG<R`B4W5B:F5C="(@;&EN92X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@5&AE(&9I;&5N86UE(&]F('1H
M92!L;V=F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:61E;G0@("`@(%1H
M92!I9&5N=&ET>2!S=')I;F<N"B`@("`@*B!`<&%R86T@87)R87D@("1C;VYF
M("`@("`@5&AE(&-O;F9I9W5R871I;VX@87)R87DN"B`@("`@*B!`<&%R86T@
M:6YT("`@("1L979E;"`@("`@3&]G(&UE<W-A9V5S('5P('1O(&%N9"!I;F-L
M=61I;F<@=&AI<R!L979E;"X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N($QO9U]M86EL*"1N86UE+"`D:61E;G0@/2`G)RP@
M)&-O;F8@/2!A<G)A>2@I+`H@("`@("`@("`@("`@("`@("`@("`@)&QE=F5L
M(#T@4$5!4E],3T=?1$5"54<I"B`@("!["B`@("`@("`@)'1H:7,M/E]I9"`]
M(&UD-2AM:6-R;W1I;64H*2D["B`@("`@("`@)'1H:7,M/E]R96-I<&EE;G0@
M/2`D;F%M93L*("`@("`@("`D=&AI<RT^7VED96YT(#T@)&ED96YT.PH@("`@
M("`@("1T:&ES+3Y?;6%S:R`]($QO9SHZ55!43R@D;&5V96PI.PH*("`@("`@
M("!I9B`H(65M<'1Y*"1C;VYF6R=F<F]M)UTI*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?9G)O;2`]("1C;VYF6R=F<F]M)UT["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'1H:7,M/E]F<F]M(#T@:6YI7V=E="@G<V5N9&UA:6Q?
M9G)O;2<I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG
M<W5B:F5C="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-U8FIE8W0@/2`D
M8V]N9ELG<W5B:F5C="==.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T
M>2@D8V]N9ELG<')E86UB;&4G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P
M<F5A;6)L92`]("1C;VYF6R=P<F5A;6)L92==.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"%E;7!T>2@D8V]N9ELG;&EN949O<FUA="==*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7VQI;F5&;W)M870@/2!S=')?<F5P;&%C92AA<G)A>5]K
M97ES*"1T:&ES+3Y?9F]R;6%T36%P*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?=F%L=65S*"1T:&ES+3Y?
M9F]R;6%T36%P*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&-O;F9;)VQI;F5&;W)M870G72D["B`@("`@("`@?0H*
M("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=T:6UE1F]R;6%T)UTI*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?=&EM949O<FUA="`]("1C;VYF6R=T:6UE1F]R
M;6%T)UT["B`@("`@("`@?0H*("`@("`@("`O*B!R96=I<W1E<B!T:&4@9&5S
M=')U8W1O<B`J+PH@("`@("`@(')E9VES=&5R7W-H=71D;W=N7V9U;F-T:6]N
M*&%R<F%Y*"8D=&AI<RP@)U],;V=?;6%I;"<I*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($1E<W1R=6-T;W(N($-A;&QS(&-L;W-E*"DN"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%],;V=?
M;6%I;"@I"B`@("!["B`@("`@("`@)'1H:7,M/F-L;W-E*"D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!3=&%R=',@82!N97<@;6%I;"!M97-S86=E+@H@("`@
M("H@5&AI<R!I<R!I;7!L:6-I=&QY(&-A;&QE9"!B>2!L;V<H*2P@:68@;F5C
M97-S87)Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&]P96XH*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M
M/E]O<&5N960I('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!R
M96%M8FQE*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]M97-S86=E(#T@
M)'1H:7,M/E]P<F5A;6)L92`N(")<<EQN7')<;B(["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)'1H:7,M/E]O<&5N960@/2!T<G5E.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;W!E;F5D.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0VQO<V5S('1H92!M97-S86=E+"!I9B!I="!I<R!O<&5N+"!A
M;F0@<V5N9',@=&AE(&UA:6PN"B`@("`@*B!4:&ES(&ES(&EM<&QI8VET;'D@
M8V%L;&5D(&)Y('1H92!D97-T<G5C=&]R+"!I9B!N96-E<W-A<GDN"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@
M8VQO<V4H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V]P96YE9"D@>PH@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?;65S<V%G92DI('L*("`@
M("`@("`@("`@("`@("1H96%D97)S(#T@(D9R;VTZ("1T:&ES+3Y?9G)O;5QR
M7&XB.PH@("`@("`@("`@("`@("`@)&AE861E<G,@+CT@(E5S97(M06=E;G0Z
M($QO9U]M86EL(CL*"B`@("`@("`@("`@("`@("!I9B`H;6%I;"@D=&AI<RT^
M7W)E8VEP:65N="P@)'1H:7,M/E]S=6)J96-T+"`D=&AI<RT^7VUE<W-A9V4L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`D:&5A9&5R<RD@/3T@9F%L<V4I
M('L*("`@("`@("`@("`@("`@("`@("!E<G)O<E]L;V<H(DQO9U]M86EL.B!&
M86EL=7)E(&5X96-U=&EN9R!M86EL*"DB+"`P*3L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@+RH@0VQE87(@=&AE(&UE<W-A9V4@<W1R:6YG(&YO=R!T:&%T
M('1H92!E;6%I;"!H87,@8F5E;B!S96YT+B`J+PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]M97-S86=E(#T@)R<["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'1H:7,M/E]O<&5N960@/2!F86QS93L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`H)'1H:7,M/E]O<&5N960@/3T](&9A;'-E*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($9L=7-H97,@=&AE(&QO9R!O=71P=70@8GD@9F]R8VEN
M9R!T:&4@96UA:6P@;65S<V%G92!T;R!B92!S96YT(&YO=RX*("`@("`J($5V
M96YT<R!T:&%T(&%R92!L;V=G960@869T97(@9FQU<V@H*2!I<R!C86QL960@
M=VEL;"!B92!A<'!E;F1E9"!T;R!A"B`@("`@*B!N97<@96UA:6P@;65S<V%G
M92X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-I;F-E
M($QO9R`Q+C@N,@H@("`@("HO"B`@("!F=6YC=&EO;B!F;'5S:"@I"B`@("![
M"B`@("`@("`@+RH*("`@("`@("`@*B!)="=S('-U9F9I8VEE;G0@=&\@<VEM
M<&QY(&-A;&P@8VQO<V4H*2!T;R!F;'5S:"!T:&4@;W5T<'5T+@H@("`@("`@
M("`J(%1H92!N97AT(&-A;&P@=&\@;&]G*"D@=VEL;"!C875S92!T:&4@:&%N
M9&QE<B!T;R!B92!R96]P96YE9"X*("`@("`@("`@*B\*("`@("`@("!R971U
M<FX@)'1H:7,M/F-L;W-E*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!7<FET
M97,@)&UE<W-A9V4@=&\@=&AE(&-U<G)E;G1L>2!O<&5N(&UA:6P@;65S<V%G
M92X*("`@("`J($-A;&QS(&]P96XH*2P@:68@;F5C97-S87)Y+@H@("`@("H*
M("`@("`J($!P87)A;2!M:7AE9"`@)&UE<W-A9V4@(%-T<FEN9R!O<B!O8FIE
M8W0@8V]N=&%I;FEN9R!T:&4@;65S<V%G92!T;R!L;V<N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1P<FEO<FET>2!4:&4@<')I;W)I='D@;V8@=&AE(&UE<W-A
M9V4N("!686QI9`H@("`@("H@("`@("`@("`@("`@("`@("!V86QU97,@87)E
M.B!014%27TQ/1U]%34521RP@4$5!4E],3T=?04Q%4E0L"B`@("`@*B`@("`@
M("`@("`@("`@("`@(%!%05)?3$]'7T-2250L(%!%05)?3$]'7T524BP@4$5!
M4E],3T=?5T%23DE.1RP*("`@("`J("`@("`@("`@("`@("`@("`@4$5!4E],
M3T=?3D]424-%+"!014%27TQ/1U])3D9/+"!A;F0@4$5!4E],3T=?1$5"54<N
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<R!O<B!F
M86QS92!O;B!F86EL=7)E+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@;&]G*"1M97-S86=E+"`D<')I;W)I='D@/2!N=6QL
M*0H@("`@>PH@("`@("`@("\J($EF(&$@<')I;W)I='D@:&%S;B=T(&)E96X@
M<W!E8VEF:65D+"!U<V4@=&AE(&1E9F%U;'0@=F%L=64N("HO"B`@("`@("`@
M:68@*"1P<FEO<FET>2`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D<')I;W)I
M='D@/2`D=&AI<RT^7W!R:6]R:71Y.PH@("`@("`@('T*"B`@("`@("`@+RH@
M06)O<G0@96%R;'D@:68@=&AE('!R:6]R:71Y(&ES(&%B;W9E('1H92!M87AI
M;75M(&QO9V=I;F<@;&5V96PN("HO"B`@("`@("`@:68@*"$D=&AI<RT^7VES
M36%S:V5D*"1P<FEO<FET>2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@+RH@268@=&AE(&UE<W-A9V4@:7-N)W0@
M;W!E;B!A;F0@8V%N)W0@8F4@;W!E;F5D+"!R971U<FX@9F%I;'5R92X@*B\*
M("`@("`@("!I9B`H(21T:&ES+3Y?;W!E;F5D("8F("$D=&AI<RT^;W!E;B@I
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@("\J($5X=')A8W0@=&AE('-T<FEN9R!R97!R97-E;G1A=&EO;B!O9B!T
M:&4@;65S<V%G92X@*B\*("`@("`@("`D;65S<V%G92`]("1T:&ES+3Y?97AT
M<F%C=$UE<W-A9V4H)&UE<W-A9V4I.PH*("`@("`@("`O*B!"=6EL9"!T:&4@
M<W1R:6YG(&-O;G1A:6YI;F<@=&AE(&-O;7!L971E(&QO9R!L:6YE+B`J+PH@
M("`@("`@("1T:&ES+3Y?;65S<V%G92`N/2`D=&AI<RT^7V9O<FUA="@D=&AI
M<RT^7VQI;F5&;W)M870L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('-T<F9T:6UE*"1T:&ES+3Y?=&EM949O<FUA="DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<FEO
M<FET>2P@)&UE<W-A9V4I("X@(EQR7&XB.PH*("`@("`@("`O*B!.;W1I9GD@
M;V)S97)V97)S(&%B;W5T('1H:7,@;&]G(&UE<W-A9V4N("HO"B`@("`@("`@
M)'1H:7,M/E]A;FYO=6YC92AA<G)A>2@G<')I;W)I='DG(#T^("1P<FEO<FET
M>2P@)VUE<W-A9V4G(#T^("1M97-S86=E*2D["@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+TQO9R]M8V%L+G!H<```````````````````````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q-3(U`#$P-3$U-#,S-S,W`#`R,#<V
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@)$AE861E<CH@+W)E<&]S:71O<GDO<&5A<B],;V<O3&]G
M+VUC86PN<&AP+'8@,2XQ."`R,#`U+S`R+S(V(#$T.C0X.C4X(&-H86=E;F)U
M($5X<"`D"B`J("1(;W)D93H@:&]R9&4O;&EB+TQO9R]M8V%L+G!H<"QV(#$N
M,B`R,#`P+S`V+S(X(#(Q.C,V.C$S(&IO;B!%>'`@)`H@*@H@*B!`=F5R<VEO
M;B`D4F5V:7-I;VXZ(#$N,3@@)`H@*B!`<&%C:V%G92!,;V<*("HO"@HO*BH*
M("H@5&AE($QO9U]M8V%L(&-L87-S(&ES(&$@8V]N8W)E=&4@:6UP;&5M96YT
M871I;VX@;V8@=&AE($QO9SHZ"B`J(&%B<W1R86-T(&-L87-S('=H:6-H('-E
M;F1S(&UE<W-A9V5S('1O(&$@;&]C86P@;W(@<F5M;W1E(&-A;&5N9&%R"B`J
M('-T;W)E(&%C8V5S<V5D('1H<F]U9V@@34-!3"X*("H*("H@0&%U=&AO<B`@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92!(
M;W)D92`Q+C,*("H@0'-I;F-E($QO9R`Q+C`*("H@0'!A8VMA9V4@3&]G"B`J
M+PIC;&%S<R!,;V=?;6-A;"!E>'1E;F1S($QO9PI["B`@("`O*BH*("`@("`J
M(&AO;&1I;F<@=&AE(&-A;&5N9&%R('-P96-I9FEC871I;VX@=&\@8V]N;F5C
M="!T;RX*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@=F%R("1?8V%L96YD87(@/2`G>VQO8V%L:&]S="]M
M<W1O<F5])SL*"B`@("`O*BH*("`@("`J(&AO;&1I;F<@=&AE('5S97)N86UE
M('1O('5S92X*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J+PH@("`@=F%R("1?=7-E<FYA;64@/2`G)SL*"B`@("`O
M*BH*("`@("`J(&AO;&1I;F<@=&AE('!A<W-W;W)D('1O('5S92X*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@=F%R("1?<&%S<W=O<F0@/2`G)SL*"B`@("`O*BH*("`@("`J(&AO;&1I
M;F<@=&AE(&]P=&EO;G,@=&\@<&%S<R!T;R!T:&4@8V%L96YD87(@<W1R96%M
M+@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@=F%R("1?;W!T:6]N<R`](#`["@H@("`@+RHJ"B`@("`@
M*B!297-O=7)C94E$(&]F('1H92!-0T%,('-T<F5A;2X*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R
M("1?<W1R96%M(#T@)R<["@H@("`@+RHJ"B`@("`@*B!);G1E9V5R(&AO;&1I
M;F<@=&AE(&QO9R!F86-I;&ET>2!T;R!U<V4N"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7VYA
M;64@/2!,3T=?4UE33$]'.PH*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@
M82!N97<@3&]G7VUC86P@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@("`@(%1H92!C871E9V]R>2!T;R!U<V4@9F]R(&]U<B!E
M=F5N=',N"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9&5N="`@("!4:&4@:61E
M;G1I='D@<W1R:6YG+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D8V]N9B`@("`@
M5&AE(&-O;F9I9W5R871I;VX@87)R87DN"B`@("`@*B!`<&%R86T@:6YT("`@
M("1L979E;"`@("!,;V<@;65S<V%G97,@=7`@=&\@86YD(&EN8VQU9&EN9R!T
M:&ES(&QE=F5L+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@3&]G7VUC86PH)&YA;64L("1I9&5N="`]("<G+"`D8V]N9B`]
M(&%R<F%Y*"DL"B`@("`@("`@("`@("`@("`@("`@("`D;&5V96P@/2!014%2
M7TQ/1U]$14)51RD*("`@('L*("`@("`@("`D=&AI<RT^7VED(#T@;60U*&UI
M8W)O=&EM92@I*3L*("`@("`@("`D=&AI<RT^7VYA;64@/2`D;F%M93L*("`@
M("`@("`D=&AI<RT^7VED96YT(#T@)&ED96YT.PH@("`@("`@("1T:&ES+3Y?
M;6%S:R`]($QO9SHZ55!43R@D;&5V96PI.PH@("`@("`@("1T:&ES+3Y?8V%L
M96YD87(@/2`D8V]N9ELG8V%L96YD87(G73L*("`@("`@("`D=&AI<RT^7W5S
M97)N86UE(#T@)&-O;F9;)W5S97)N86UE)UT["B`@("`@("`@)'1H:7,M/E]P
M87-S=V]R9"`]("1C;VYF6R=P87-S=V]R9"==.PH@("`@("`@("1T:&ES+3Y?
M;W!T:6]N<R`]("1C;VYF6R=O<'1I;VYS)UT["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!/<&5N<R!A(&-A;&5N9&%R('-T<F5A;2P@:68@:70@:&%S(&YO="!A
M;')E861Y(&)E96X*("`@("`J(&]P96YE9"X@5&AI<R!I<R!I;7!L:6-I=&QY
M(&-A;&QE9"!B>2!L;V<H*2P@:68@;F5C97-S87)Y+@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;W!E;B@I"B`@("!["B`@
M("`@("`@:68@*"$D=&AI<RT^7V]P96YE9"D@>PH@("`@("`@("`@("`D=&AI
M<RT^7W-T<F5A;2`](&UC86Q?;W!E;B@D=&AI<RT^7V-A;&5N9&%R+"`D=&AI
M<RT^7W5S97)N86UE+`H@("`@("`@("`@("`@("`@)'1H:7,M/E]P87-S=V]R
M9"P@)'1H:7,M/E]O<'1I;VYS*3L*("`@("`@("`@("`@)'1H:7,M/E]O<&5N
M960@/2!T<G5E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M;W!E;F5D.PH@("`@?0H*("`@("\J*@H@("`@("H@0VQO<V5S('1H92!C86QE
M;F1A<B!S=')E86TL(&EF(&ET(&ES(&]P96XN"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!C;&]S92@I"B`@("!["B`@("`@
M("`@:68@*"1T:&ES+3Y?;W!E;F5D*2!["B`@("`@("`@("`@(&UC86Q?8VQO
M<V4H)'1H:7,M/E]S=')E86TI.PH@("`@("`@("`@("`D=&AI<RT^7V]P96YE
M9"`](&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("@D=&AI<RT^
M7V]P96YE9"`]/3T@9F%L<V4I.PH@("`@?0H*("`@("\J*@H@("`@("H@3&]G
M<R`D;65S<V%G92!A;F0@87-S;V-I871E9"!I;F9O<FUA=&EO;B!T;R!T:&4@
M8W5R<F5N=&QY(&]P96X*("`@("`J(&-A;&5N9&%R('-T<F5A;2X@0V%L;',@
M;W!E;B@I(&EF(&YE8V5S<V%R>2X@06QS;R!P87-S97,@=&AE"B`@("`@*B!M
M97-S86=E(&%L;VYG('1O(&%N>2!,;V=?;V)S97)V97(@:6YS=&%N8V5S('1H
M870@87)E(&]B<V5R=FEN9PH@("`@("H@=&AI<R!,;V<N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&UI>&5D("`D;65S<V%G92`@4W1R:6YG(&]R(&]B:F5C="!C
M;VYT86EN:6YG('1H92!M97-S86=E('1O(&QO9RX*("`@("`J($!P87)A;2!S
M=')I;F<@)'!R:6]R:71Y(%1H92!P<FEO<FET>2!O9B!T:&4@;65S<V%G92X@
M5F%L:60*("`@("`J("`@("`@("`@("`@("`@("`@=F%L=65S(&%R93H@4$5!
M4E],3T=?14U%4D<L(%!%05)?3$]'7T%,15)4+`H@("`@("H@("`@("`@("`@
M("`@("`@("!014%27TQ/1U]#4DE4+"!014%27TQ/1U]%4E(L(%!%05)?3$]'
M7U=!4DY)3D<L"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%05)?3$]'7TY/
M5$E#12P@4$5!4E],3T=?24Y&3RP@86YD(%!%05)?3$]'7T1%0E5'+@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,@;W(@9F%L<V4@
M;VX@9F%I;'5R92X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&QO9R@D;65S<V%G92P@)'!R:6]R:71Y(#T@;G5L;"D*("`@
M('L*("`@("`@("`O*B!)9B!A('!R:6]R:71Y(&AA<VXG="!B965N('-P96-I
M9FEE9"P@=7-E('1H92!D969A=6QT('9A;'5E+B`J+PH@("`@("`@(&EF("@D
M<')I;W)I='D@/3T](&YU;&PI('L*("`@("`@("`@("`@)'!R:6]R:71Y(#T@
M)'1H:7,M/E]P<FEO<FET>3L*("`@("`@("!]"@H@("`@("`@("\J($%B;W)T
M(&5A<FQY(&EF('1H92!P<FEO<FET>2!I<R!A8F]V92!T:&4@;6%X:6UU;2!L
M;V=G:6YG(&QE=F5L+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/E]I<TUA<VME
M9"@D<')I;W)I='DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@("\J($EF('1H92!C;VYN96-T:6]N(&ES;B=T(&]P
M96X@86YD(&-A;B=T(&)E(&]P96YE9"P@<F5T=7)N(&9A:6QU<F4N("HO"B`@
M("`@("`@:68@*"$D=&AI<RT^7V]P96YE9"`F)B`A)'1H:7,M/F]P96XH*2D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("`O*B!%>'1R86-T('1H92!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@=&AE
M(&UE<W-A9V4N("HO"B`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^7V5X=')A
M8W1-97-S86=E*"1M97-S86=E*3L*"B`@("`@("`@)&1A=&5?<W1R(#T@9&%T
M92@G63IN.FHZ1SII.G,G*3L*("`@("`@("`D9&%T97,@/2!E>'!L;V1E*"<Z
M)RP@)&1A=&5?<W1R*3L*"B`@("`@("`@;6-A;%]E=F5N=%]I;FET*"1T:&ES
M+3Y?<W1R96%M*3L*("`@("`@("!M8V%L7V5V96YT7W-E=%]T:71L92@D=&AI
M<RT^7W-T<F5A;2P@)'1H:7,M/E]I9&5N="D["B`@("`@("`@;6-A;%]E=F5N
M=%]S971?8V%T96=O<GDH)'1H:7,M/E]S=')E86TL("1T:&ES+3Y?;F%M92D[
M"B`@("`@("`@;6-A;%]E=F5N=%]S971?9&5S8W)I<'1I;VXH)'1H:7,M/E]S
M=')E86TL("1M97-S86=E*3L*("`@("`@("!M8V%L7V5V96YT7V%D9%]A='1R
M:6)U=&4H)'1H:7,M/E]S=')E86TL("=P<FEO<FET>2<L("1P<FEO<FET>2D[
M"B`@("`@("`@;6-A;%]E=F5N=%]S971?<W1A<G0H)'1H:7,M/E]S=')E86TL
M("1D871E<ULP72P@)&1A=&5S6S%=+"`D9&%T97-;,ETL"B`@("`@("`@("`@
M("1D871E<ULS72P@)&1A=&5S6S1=+"`D9&%T97-;-5TI.PH@("`@("`@(&UC
M86Q?979E;G1?<V5T7V5N9"@D=&AI<RT^7W-T<F5A;2P@)&1A=&5S6S!=+"`D
M9&%T97-;,5TL("1D871E<ULR72P*("`@("`@("`@("`@)&1A=&5S6S-=+"`D
M9&%T97-;-%TL("1D871E<ULU72D["B`@("`@("`@;6-A;%]A<'!E;F1?979E
M;G0H)'1H:7,M/E]S=')E86TI.PH*("`@("`@("`D=&AI<RT^7V%N;F]U;F-E
M*&%R<F%Y*"=P<FEO<FET>2<@/3X@)'!R:6]R:71Y+"`G;65S<V%G92<@/3X@
M)&UE<W-A9V4I*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B],;V<O;61B,BYP:'``````````````````
M```````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R-3$U-P`Q,#4Q-30S,S<S
M-P`P,C`V-S<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J("1(96%D97(Z("]R97!O<VET;W)Y+W!E87(O
M3&]G+TQO9R]M9&(R+G!H<"QV(#$N-2`R,#`V+S`Q+S`X(#`S.C,U.C0T(&IO
M;B!%>'`@)`H@*@H@*B!`=F5R<VEO;B`D4F5V:7-I;VXZ(#$N-2`D"B`J($!P
M86-K86=E($QO9PH@*B\*"B\J*B!014%2)W,@341",B!P86-K86=E("HO"G)E
M<75I<F5?;VYC92`G341",BYP:'`G.PI-1$(R.CIL;V%D1FEL92@G1&%T92<I
M.PH*+RHJ"B`J(%1H92!,;V=?;61B,B!C;&%S<R!I<R!A(&-O;F-R971E(&EM
M<&QE;65N=&%T:6]N(&]F('1H92!,;V<Z.B!A8G-T<F%C="!C;&%S<PH@*B!W
M:&EC:"!S96YD<R!M97-S86=E<R!T;R!A;B!344P@<V5R=F5R+B`@16%C:"!E
M;G1R>2!O8V-U<&EE<R!A('-E<&%R871E(')O=PH@*B!I;B!T:&4@9&%T86)A
M<V4N"B`J"B`J(%1H:7,@:6UP;&5M96YT871I;VX@=7-E<R!014%2)W,@341"
M,B!D871A8F%S92!A8G-T<F%C=&EO;B!L87EE<BX*("H*("H@0U)%051%(%1!
M0DQ%(&QO9U]T86)L92`H"B`J("!I9"`@("`@("`@("!)3E0@3D]4($Y53$PL
M"B`J("!L;V=T:6UE("`@("!424U%4U1!35`@3D]4($Y53$PL"B`J("!I9&5N
M="`@("`@("!#2$%2*#$V*2!.3U0@3E5,3"P*("H@('!R:6]R:71Y("`@($E.
M5"!.3U0@3E5,3"P*("H@(&UE<W-A9V4@("`@(%9!4D-(05(H,C`P*2P*("H@
M(%!224U!4ED@2T59("AI9"D*("H@*3L*("H*("H@0&%U=&AO<B`@3'5K87,@
M4VUI=&@@/'-M:71H0&)A8VME;F1M961I82YC;VT^"B`J($!A=71H;W(@($IO
M;B!087)I<V4@/&IO;D!P:'`N;F5T/@H@*B!`<VEN8V4@("!,;V<@,2XY+C`*
M("H@0'!A8VMA9V4@3&]G"B`J+PIC;&%S<R!,;V=?;61B,B!E>'1E;F1S($QO
M9PI["B`@("`O*BH*("`@("`J(%9A<FEA8FQE(&-O;G1A:6YI;F<@=&AE($13
M3B!I;F9O<FUA=&EO;BX*("`@("`J($!V87(@;6EX960*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]D<VX@/2`G)SL*"B`@("`O
M*BH*("`@("`J($%R<F%Y(&-O;G1A:6YI;F<@;W5R('-E="!O9B!$0B!C;VYF
M:6=U<F%T:6]N(&]P=&EO;G,N"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?;W!T:6]N<R`](&%R
M<F%Y*"=P97)S:7-T96YT)R`]/B!T<G5E*3L*"B`@("`O*BH*("`@("`J($]B
M:F5C="!H;VQD:6YG('1H92!D871A8F%S92!H86YD;&4N"B`@("`@*B!`=F%R
M(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A
M<B`D7V1B(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%)E<V]U<F-E(&AO;&1I
M;F<@=&AE('!R97!A<F5D('-T871E;65N="!H86YD;&4N"B`@("`@*B!`=F%R
M(')E<V]U<F-E"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M=F%R("1?<W1A=&5M96YT(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($9L86<@
M:6YD:6-A=&EN9R!T:&%T('=E)W)E('5S:6YG(&%N(&5X:7-T:6YG(&1A=&%B
M87-E(&-O;FYE8W1I;VXN"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]E>&ES=&EN9T-O;FYE
M8W1I;VX@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%-T<FEN9R!H;VQD:6YG
M('1H92!D871A8F%S92!T86)L92!T;R!U<V4N"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7W1A
M8FQE(#T@)VQO9U]T86)L92<["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@:&]L
M9&EN9R!T:&4@;F%M92!O9B!T:&4@240@<V5Q=65N8V4N"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A
M<B`D7W-E<75E;F-E(#T@)VQO9U]I9"<["@H@("`@+RHJ"B`@("`@*B!-87AI
M;75M(&QE;F=T:"!O9B!T:&4@)&ED96YT('-T<FEN9RX@(%1H:7,@8V]R<F5S
M<&]N9',@=&\@=&AE('-I>F4@;V8*("`@("`J('1H92`G:61E;G0G(&-O;'5M
M;B!I;B!T:&4@4U%,('1A8FQE+@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?:61E;G1,:6UI
M="`](#$V.PH*("`@("\J*@H@("`@("H@4V5T(&]F(&9I96QD('1Y<&5S('5S
M960@:6X@=&AE(&1A=&%B87-E('1A8FQE+@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7W1Y<&5S
M(#T@87)R87DH"B`@("`@("`@)VED)R`@("`@("`@/3X@)VEN=&5G97(G+`H@
M("`@("`@("=L;V=T:6UE)R`@(#T^("=T:6UE<W1A;7`G+`H@("`@("`@("=I
M9&5N="<@("`@(#T^("=T97AT)RP*("`@("`@("`G<')I;W)I='DG("`]/B`G
M=&5X="<L"B`@("`@("`@)VUE<W-A9V4G("`@/3X@)V-L;V(G"B`@("`I.PH*
M("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!S<6P@;&]G9VEN9R!O
M8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@
M("`@(%1H92!T87)G970@4U%,('1A8FQE+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D:61E;G0@("`@("`@(%1H92!I9&5N=&EF:6-A=&EO;B!F:65L9"X*("`@
M("`J($!P87)A;2!A<G)A>2`D8V]N9B`@("`@("`@("!4:&4@8V]N;F5C=&EO
M;B!C;VYF:6=U<F%T:6]N(&%R<F%Y+@H@("`@("H@0'!A<F%M(&EN="`D;&5V
M96P@("`@("`@("`@($QO9R!M97-S86=E<R!U<"!T;R!A;F0@:6YC;'5D:6YG
M('1H:7,@;&5V96PN"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!,;V=?;61B,B@D;F%M92P@)&ED96YT(#T@)R<L("1C;VYF
M(#T@87)R87DH*2P*("`@("`@("`@("`@("`@("`@("`@)&QE=F5L(#T@4$5!
M4E],3T=?1$5"54<I"B`@("!["B`@("`@("`@)'1H:7,M/E]I9"`](&UD-2AM
M:6-R;W1I;64H*2D["B`@("`@("`@)'1H:7,M/E]T86)L92`]("1N86UE.PH@
M("`@("`@("1T:&ES+3Y?;6%S:R`]($QO9SHZ55!43R@D;&5V96PI.PH*("`@
M("`@("`O*B!)9B!A;B!O<'1I;VYS(&%R<F%Y('=A<R!P<F]V:61E9"P@=7-E
M(&ET+B`J+PH@("`@("`@(&EF("AI<W-E="@D8V]N9ELG;W!T:6]N<R==*2`F
M)B!I<U]A<G)A>2@D8V]N9ELG;W!T:6]N<R==*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7V]P=&EO;G,@/2`D8V]N9ELG;W!T:6]N<R==.PH@("`@("`@('T*
M"B`@("`@("`@+RH@268@82!S<&5C:69I8R!S97%U96YC92!N86UE('=A<R!P
M<F]V:61E9"P@=7-E(&ET+B`J+PH@("`@("`@(&EF("@A96UP='DH)&-O;F9;
M)W-E<75E;F-E)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5Q=65N8V4@
M/2`D8V]N9ELG<V5Q=65N8V4G73L*("`@("`@("!]"@H@("`@("`@("\J($EF
M(&$@<W!E8VEF:6,@<V5Q=65N8V4@;F%M92!W87,@<')O=FED960L('5S92!I
M="X@*B\*("`@("`@("!I9B`H:7-S970H)&-O;F9;)VED96YT3&EM:70G72DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]I9&5N=$QI;6ET(#T@)&-O;F9;)VED
M96YT3&EM:70G73L*("`@("`@("!]"@H@("`@("`@("\J($YO=R!T:&%T('1H
M92!I9&5N="!L:6UI="!I<R!C;VYF:7)M960L('-E="!T:&4@:61E;G0@<W1R
M:6YG+B`J+PH@("`@("`@("1T:&ES+3YS971)9&5N="@D:61E;G0I.PH*("`@
M("`@("`O*B!)9B!A;B!E>&ES=&EN9R!D871A8F%S92!C;VYN96-T:6]N('=A
M<R!P<F]V:61E9"P@=7-E(&ET+B`J+PH@("`@("`@(&EF("AI<W-E="@D8V]N
M9ELG9&(G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]D8B`]("8D8V]N9ELG
M9&(G73L*("`@("`@("`@("`@)'1H:7,M/E]E>&ES=&EN9T-O;FYE8W1I;VX@
M/2!T<G5E.PH@("`@("`@("`@("`D=&AI<RT^7V]P96YE9"`]('1R=64["B`@
M("`@("`@?2!E;'-E:68@*&ES<V5T*"1C;VYF6R=S:6YG;&5T;VXG72DI('L*
M("`@("`@("`@("`@)'1H:7,M/E]D8B`]("9-1$(R.CIS:6YG;&5T;VXH)&-O
M;F9;)W-I;F=L971O;B==+"`D=&AI<RT^7V]P=&EO;G,I.PH@("`@("`@("`@
M("`D=&AI<RT^7V5X:7-T:6YG0V]N;F5C=&EO;B`]('1R=64["B`@("`@("`@
M("`@("1T:&ES+3Y?;W!E;F5D(#T@=')U93L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D=&AI<RT^7V1S;B`]("1C;VYF6R=D<VXG73L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!/<&5N<R!A(&-O;FYE8W1I;VX@
M=&\@=&AE(&1A=&%B87-E+"!I9B!I="!H87,@;F]T(&%L<F5A9'D*("`@("`J
M(&)E96X@;W!E;F5D+B!4:&ES(&ES(&EM<&QI8VET;'D@8V%L;&5D(&)Y(&QO
M9R@I+"!I9B!N96-E<W-A<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N("`@5')U92!O;B!S=6-C97-S+"!F86QS92!O;B!F86EL=7)E+@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;W!E;B@I
M"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^7V]P96YE9"D@>PH@("`@("`@
M("`@("`O*B!5<V4@=&AE($133B!A;F0@;W!T:6]N<R!T;R!C<F5A=&4@82!D
M871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@("`@("`D=&AI<RT^7V1B
M(#T@)DU$0C(Z.F-O;FYE8W0H)'1H:7,M/E]D<VXL("1T:&ES+3Y?;W!T:6]N
M<RD["B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1T:&ES+3Y?9&(I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("\J($-R96%T92!A('!R97!A<F5D('-T871E;65N
M="!F;W(@<F5P96%T960@=7-E(&EN(&QO9R@I+B`J+PH@("`@("`@("`@("!I
M9B`H(21T:&ES+3Y?<')E<&%R95-T871E;65N="@I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("\J(%=E(&YO=R!C;VYS:61E<B!O=70@8V]N;F5C=&EO;B!O<&5N+B`J+PH@
M("`@("`@("`@("`D=&AI<RT^7V]P96YE9"`]('1R=64["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'1H:7,M/E]O<&5N960["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#;&]S97,@=&AE(&-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E
M(&EF(&ET(&ES('-T:6QL(&]P96X@86YD('=E('=E<F4*("`@("`J('1H92!O
M;F5S('1H870@;W!E;F5D(&ET+B`@270@:7,@=&AE(&-A;&QE<B=S(')E<W!O
M;G-I8FQE('1O(&-L;W-E(&%N"B`@("`@*B!E>&ES=&EN9R!C;VYN96-T:6]N
M('1H870@=V%S('!A<W-E9"!T;R!U<R!V:6$@)&-O;F9;)V1B)UTN"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("`@5')U92!O;B!S=6-C97-S+"!F
M86QS92!O;B!F86EL=7)E+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@8VQO<V4H*0H@("`@>PH@("`@("`@("\J($EF('=E
M(&AA=F4@82!S=&%T96UE;G0@;V)J96-T+"!F<F5E(&ET+B`J+PH@("`@("`@
M(&EF("AI<U]O8FIE8W0H)'1H:7,M/E]S=&%T96UE;G0I*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?<W1A=&5M96YT+3YF<F5E*"D["B`@("`@("`@("`@("1T
M:&ES+3Y?<W1A=&5M96YT(#T@;G5L;#L*("`@("`@("!]"@H@("`@("`@("\J
M($EF('=E(&]P96YE9"!T:&4@9&%T86)A<V4@8V]N;F5C=&EO;BP@9&ES8V]N
M;F5C="!I="X@*B\*("`@("`@("!I9B`H)'1H:7,M/E]O<&5N960@)B8@(21T
M:&ES+3Y?97AI<W1I;F=#;VYN96-T:6]N*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?;W!E;F5D(#T@9F%L<V4["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7V1B+3YD:7-C;VYN96-T*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M*"1T:&ES+3Y?;W!E;F5D(#T]/2!F86QS92D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3971S('1H:7,@3&]G(&EN<W1A;F-E)W,@:61E;G1I9FEC871I;VX@
M<W1R:6YG+B`@3F]T92!T:&%T('1H:7,*("`@("`J(%-13"US<&5C:69I8R!I
M;7!L96UE;G1A=&EO;B!W:6QL(&QI;6ET('1H92!L96YG=&@@;V8@=&AE("1I
M9&5N="!S=')I;F<*("`@("`J('1O('-I>'1E96X@*#$V*2!C:&%R86-T97)S
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("`@)&ED96YT("`@("`@
M5&AE(&YE=R!I9&5N=&EF:6-A=&EO;B!S=')I;F<N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<VEN8V4@("!,;V<@,2XX+C4*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T261E;G0H)&ED96YT*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?:61E;G0@/2!S=6)S='(H)&ED96YT+"`P+"`D=&AI<RT^
M7VED96YT3&EM:70I.PH@("`@?0H*("`@("\J*@H@("`@("H@26YS97)T<R`D
M;65S<V%G92!T;R!T:&4@8W5R<F5N=&QY(&]P96X@9&%T86)A<V4N("!#86QL
M<R!O<&5N*"DL"B`@("`@*B!I9B!N96-E<W-A<GDN("!!;'-O('!A<W-E<R!T
M:&4@;65S<V%G92!A;&]N9R!T;R!A;GD@3&]G7V]B<V5R=F5R"B`@("`@*B!I
M;G-T86YC97,@=&AA="!A<F4@;V)S97)V:6YG('1H:7,@3&]G+@H@("`@("H*
M("`@("`J($!P87)A;2!M:7AE9"`@)&UE<W-A9V4@(%-T<FEN9R!O<B!O8FIE
M8W0@8V]N=&%I;FEN9R!T:&4@;65S<V%G92!T;R!L;V<N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1P<FEO<FET>2!4:&4@<')I;W)I='D@;V8@=&AE(&UE<W-A
M9V4N("!686QI9`H@("`@("H@("`@("`@("`@("`@("`@("!V86QU97,@87)E
M.B!014%27TQ/1U]%34521RP@4$5!4E],3T=?04Q%4E0L"B`@("`@*B`@("`@
M("`@("`@("`@("`@(%!%05)?3$]'7T-2250L(%!%05)?3$]'7T524BP@4$5!
M4E],3T=?5T%23DE.1RP*("`@("`J("`@("`@("`@("`@("`@("`@4$5!4E],
M3T=?3D]424-%+"!014%27TQ/1U])3D9/+"!A;F0@4$5!4E],3T=?1$5"54<N
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<R!O<B!F
M86QS92!O;B!F86EL=7)E+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@;&]G*"1M97-S86=E+"`D<')I;W)I='D@/2!N=6QL
M*0H@("`@>PH@("`@("`@("\J($EF(&$@<')I;W)I='D@:&%S;B=T(&)E96X@
M<W!E8VEF:65D+"!U<V4@=&AE(&1E9F%U;'0@=F%L=64N("HO"B`@("`@("`@
M:68@*"1P<FEO<FET>2`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D<')I;W)I
M='D@/2`D=&AI<RT^7W!R:6]R:71Y.PH@("`@("`@('T*"B`@("`@("`@+RH@
M06)O<G0@96%R;'D@:68@=&AE('!R:6]R:71Y(&ES(&%B;W9E('1H92!M87AI
M;75M(&QO9V=I;F<@;&5V96PN("HO"B`@("`@("`@:68@*"$D=&AI<RT^7VES
M36%S:V5D*"1P<FEO<FET>2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@+RH@268@=&AE(&-O;FYE8W1I;VX@:7-N
M)W0@;W!E;B!A;F0@8V%N)W0@8F4@;W!E;F5D+"!R971U<FX@9F%I;'5R92X@
M*B\*("`@("`@("!I9B`H(21T:&ES+3Y?;W!E;F5D("8F("$D=&AI<RT^;W!E
M;B@I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@
M("`@("`@("\J($EF('=E(&1O;B=T(&%L<F5A9'D@:&%V92!A('-T871E;65N
M="!O8FIE8W0L(&-R96%T92!O;F4N("HO"B`@("`@("`@:68@*"%I<U]O8FIE
M8W0H)'1H:7,M/E]S=&%T96UE;G0I("8F("$D=&AI<RT^7W!R97!A<F53=&%T
M96UE;G0H*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("`O*B!%>'1R86-T('1H92!S=')I;F<@<F5P<F5S96YT871I
M;VX@;V8@=&AE(&UE<W-A9V4N("HO"B`@("`@("`@)&UE<W-A9V4@/2`D=&AI
M<RT^7V5X=')A8W1-97-S86=E*"1M97-S86=E*3L*"B`@("`@("`@+RH@0G5I
M;&0@;W5R('-E="!O9B!V86QU97,@9F]R('1H:7,@;&]G(&5N=')Y+B`J+PH@
M("`@("`@("1V86QU97,@/2!A<G)A>2@*("`@("`@("`@("`@)VED)R`@("`@
M("`]/B`D=&AI<RT^7V1B+3YN97AT260H)'1H:7,M/E]S97%U96YC92DL"B`@
M("`@("`@("`@("=L;V=T:6UE)R`@/3X@341",E]$871E.CIM9&).;W<H*2P*
M("`@("`@("`@("`@)VED96YT)R`@("`]/B`D=&AI<RT^7VED96YT+`H@("`@
M("`@("`@("`G<')I;W)I='DG(#T^("1P<FEO<FET>2P*("`@("`@("`@("`@
M)VUE<W-A9V4G("`]/B`D;65S<V%G90H@("`@("`@("D["@H@("`@("`@("\J
M($5X96-U=&4@=&AE(%-13"!Q=65R>2!F;W(@=&AI<R!L;V<@96YT<GD@:6YS
M97)T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?9&(M/F5X<&5C=$5R<F]R*$U$
M0C)?15)23U)?3D]354-(5$%"3$4I.PH@("`@("`@("1R97-U;'0@/2`F)'1H
M:7,M/E]S=&%T96UE;G0M/F5X96-U=&4H)'9A;'5E<RD["B`@("`@("`@)'1H
M:7,M/E]D8BT^<&]P17AP96-T*"D["@H@("`@("`@("\J($%T=&5M<'0@=&\@
M:&%N9&QE(&%N>2!E<G)O<G,N("HO"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)')E<W5L="DI('L*("`@("`@("`@("`@+RH@5V4@8V%N(&]N;'D@:&%N
M9&QE($U$0C)?15)23U)?3D]354-(5$%"3$4@97)R;W)S+B`J+PH@("`@("`@
M("`@("!I9B`H)')E<W5L="T^9V5T0V]D92@I("$]($U$0C)?15)23U)?3D]3
M54-(5$%"3$4I('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+RH@071T96UP="!T;R!C<F5A=&4@
M=&AE('1A<F=E="!T86)L92X@*B\*("`@("`@("`@("`@:68@*"$D=&AI<RT^
M7V-R96%T951A8FQE*"DI('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@4F5C<F5A=&4@;W5R
M('!R97!A<F5D('-T871E;65N="!R97-O=7)C92X@*B\*("`@("`@("`@("`@
M)'1H:7,M/E]S=&%T96UE;G0M/F9R964H*3L*("`@("`@("`@("`@:68@*"$D
M=&AI<RT^7W!R97!A<F53=&%T96UE;G0H*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!!
M='1E;7!T('1O(')E+65X96-U=&4@=&AE(&EN<V5R=&EO;B!Q=65R>2X@*B\*
M("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?<W1A=&5M96YT+3YE>&5C
M=71E*"1V86QU97,I.PH@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V%N;F]U;F-E
M*&%R<F%Y*"=P<FEO<FET>2<@/3X@)'!R:6]R:71Y+"`G;65S<V%G92<@/3X@
M)&UE<W-A9V4I*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#<F5A=&4@=&AE(&QO9R!T86)L92!I;B!T:&4@9&%T86)A
M<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U
M8V-E<W,@;W(@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?8W)E871E5&%B;&4H*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?9&(M/FQO861-;V1U;&4H)TUA;F%G97(G+"!N
M=6QL+"!T<G5E*3L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^;6%N
M86=E<BT^8W)E871E5&%B;&4H"B`@("`@("`@("`@("1T:&ES+3Y?=&%B;&4L
M"B`@("`@("`@("`@(&%R<F%Y*`H@("`@("`@("`@("`@("`@)VED)R`@("`@
M("`@/3X@87)R87DH)W1Y<&4G(#T^("1T:&ES+3Y?='EP97-;)VED)UTI+`H@
M("`@("`@("`@("`@("`@)VQO9W1I;64G("`@/3X@87)R87DH)W1Y<&4G(#T^
M("1T:&ES+3Y?='EP97-;)VQO9W1I;64G72DL"B`@("`@("`@("`@("`@("`G
M:61E;G0G("`@("`]/B!A<G)A>2@G='EP92<@/3X@)'1H:7,M/E]T>7!E<ULG
M:61E;G0G72DL"B`@("`@("`@("`@("`@("`G<')I;W)I='DG("`]/B!A<G)A
M>2@G='EP92<@/3X@)'1H:7,M/E]T>7!E<ULG<')I;W)I='DG72DL"B`@("`@
M("`@("`@("`@("`G;65S<V%G92<@("`]/B!A<G)A>2@G='EP92<@/3X@)'1H
M:7,M/E]T>7!E<ULG;65S<V%G92==*0H@("`@("`@("`@("`I"B`@("`@("`@
M*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/E]D8BT^;6%N86=E<BT^8W)E871E26YD97@H"B`@("`@
M("`@("`@("1T:&ES+3Y?=&%B;&4L"B`@("`@("`@("`@("=U;FEQ=65?:60G
M+`H@("`@("`@("`@("!A<G)A>2@G9FEE;&1S)R`]/B!A<G)A>2@G:60G(#T^
M('1R=64I+"`G=6YI<75E)R`]/B!T<G5E*0H@("`@("`@("D["B`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!0<F5P87)E('1H92!344P@:6YS97)T:6]N
M('-T871E;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R
M=64@:68@=&AE('-T871E;65N="!W87,@<W5C8V5S<V9U;&QY(&-R96%T960N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("H@0'-I;F-E
M("`@3&]G(#$N.2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P<F5P87)E4W1A
M=&5M96YT*"D*("`@('L*("`@("`@("`D=&AI<RT^7W-T871E;65N="`]("8D
M=&AI<RT^7V1B+3YP<F5P87)E*`H@("`@("`@("`@("`@("`@)TE.4T525"!)
M3E1/("<@+B`D=&AI<RT^7W1A8FQE("X*("`@("`@("`@("`@("`@("<@*&ED
M+"!L;V=T:6UE+"!I9&5N="P@<')I;W)I='DL(&UE<W-A9V4I)R`N"B`@("`@
M("`@("`@("`@("`G(%9!3%5%4R@Z:60L(#IL;V=T:6UE+"`Z:61E;G0L(#IP
M<FEO<FET>2P@.FUE<W-A9V4I)RP*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M='EP97,L($U$0C)?4%)%4$%215]-04Y)4"D["@H@("`@("`@("\J(%)E='5R
M;B!S=6-C97-S(&EF('=E(&1I9&XG="!G96YE<F%T92!A;B!E<G)O<BX@*B\*
M("`@("`@("!R971U<FX@*%!%05(Z.FES17)R;W(H)'1H:7,M/E]S=&%T96UE
M;G0I(#T]/2!F86QS92D["B`@("!]"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O3&]G+VYU;&PN<&AP````````````````````````````````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#0P,#8`,3`U,34T,S,W,S<`,#(Q,#$S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B`D2&5A9&5R.B`O<F5P;W-I=&]R>2]P96%R+TQO9R],;V<O;G5L;"YP
M:'`L=B`Q+C0@,C`P-2\P,B\R-B`Q-#HT.#HU."!C:&%G96YB=2!%>'`@)`H@
M*@H@*B!`=F5R<VEO;B`D4F5V:7-I;VXZ(#$N-"`D"B`J($!P86-K86=E($QO
M9PH@*B\*"B\J*@H@*B!4:&4@3&]G7VYU;&P@8VQA<W,@:7,@82!C;VYC<F5T
M92!I;7!L96UE;G1A=&EO;B!O9B!T:&4@3&]G.CH@86)S=')A8W0*("H@8VQA
M<W,N("!)="!S:6UP;'D@8V]N<W5M97,@;&]G(&5V96YT<RX*("H*("H@0&%U
M=&AO<B`@2F]N(%!A<FES92`\:F]N0'!H<"YN970^"B`J($!S:6YC92`@($QO
M9R`Q+C@N,@H@*B!`<&%C:V%G92!,;V<*("H*("H@0&5X86UP;&4@;G5L;"YP
M:'`@("`@57-I;F<@=&AE(&YU;&P@:&%N9&QE<BX*("HO"F-L87-S($QO9U]N
M=6QL(&5X=&5N9',@3&]G"GL*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A
M(&YE=R!,;V=?;G5L;"!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;F%M92`@("`@26=N;W)E9"X*("`@("`J($!P87)A;2!S=')I;F<@
M)&ED96YT("`@(%1H92!I9&5N=&ET>2!S=')I;F<N"B`@("`@*B!`<&%R86T@
M87)R87D@("1C;VYF("`@("!4:&4@8V]N9FEG=7)A=&EO;B!A<G)A>2X*("`@
M("`J($!P87)A;2!I;G0@("`@)&QE=F5L("`@($QO9R!M97-S86=E<R!U<"!T
M;R!A;F0@:6YC;'5D:6YG('1H:7,@;&5V96PN"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!,;V=?;G5L;"@D;F%M92P@)&ED
M96YT(#T@)R<L("1C;VYF(#T@87)R87DH*2P*"0D)"0D@("1L979E;"`](%!%
M05)?3$]'7T1%0E5'*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:60@/2!M9#4H
M;6EC<F]T:6UE*"DI.PH@("`@("`@("1T:&ES+3Y?:61E;G0@/2`D:61E;G0[
M"B`@("`@("`@)'1H:7,M/E]M87-K(#T@3&]G.CI54%1/*"1L979E;"D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!3:6UP;'D@8V]N<W5M97,@=&AE(&QO9R!E
M=F5N="X@(%1H92!M97-S86=E('=I;&P@<W1I;&P@8F4@<&%S<V5D"B`@("`@
M*B!A;&]N9R!T;R!A;GD@3&]G7V]B<V5R=F5R(&EN<W1A;F-E<R!T:&%T(&%R
M92!O8G-E<G9I;F<@=&AI<R!,;V<N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI
M>&5D("`D;65S<V%G92`@("!3=')I;F<@;W(@;V)J96-T(&-O;G1A:6YI;F<@
M=&AE(&UE<W-A9V4@=&\@;&]G+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')I
M;W)I='D@5&AE('!R:6]R:71Y(&]F('1H92!M97-S86=E+B`@5F%L:60*("`@
M("`J("`@("`@("`@("`@("`@("`@=F%L=65S(&%R93H@4$5!4E],3T=?14U%
M4D<L(%!%05)?3$]'7T%,15)4+`H@("`@("H@("`@("`@("`@("`@("`@("!0
M14%27TQ/1U]#4DE4+"!014%27TQ/1U]%4E(L(%!%05)?3$]'7U=!4DY)3D<L
M"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%05)?3$]'7TY/5$E#12P@4$5!
M4E],3T=?24Y&3RP@86YD(%!%05)?3$]'7T1%0E5'+@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,@;W(@9F%L<V4@;VX@9F%I;'5R
M92X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&QO9R@D;65S<V%G92P@)'!R:6]R:71Y(#T@;G5L;"D*("`@('L*("`@("`@
M("`O*B!)9B!A('!R:6]R:71Y(&AA<VXG="!B965N('-P96-I9FEE9"P@=7-E
M('1H92!D969A=6QT('9A;'5E+B`J+PH@("`@("`@(&EF("@D<')I;W)I='D@
M/3T](&YU;&PI('L*("`@("`@("`@("`@)'!R:6]R:71Y(#T@)'1H:7,M/E]P
M<FEO<FET>3L*("`@("`@("!]"@H@("`@("`@("\J($%B;W)T(&5A<FQY(&EF
M('1H92!P<FEO<FET>2!I<R!A8F]V92!T:&4@;6%X:6UU;2!L;V=G:6YG(&QE
M=F5L+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/E]I<TUA<VME9"@D<')I;W)I
M='DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3Y?86YN;W5N8V4H87)R87DH)W!R:6]R:71Y)R`]/B`D
M<')I;W)I='DL("=M97-S86=E)R`]/B`D;65S<V%G92DI.PH*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O3&]G+V]B<V5R=F5R+G!H<```````````````
M````````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`P-3<`,3`U,34T,S,W,S<`
M,#(Q-C<S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B`D2&5A9&5R.B`O<F5P;W-I=&]R>2]P96%R+TQO
M9R],;V<O;V)S97)V97(N<&AP+'8@,2XQ."`R,#`V+S`T+S(U(#`V.C`R.C(S
M(&IO;B!%>'`@)`H@*B`D2&]R9&4Z(&AO<F1E+VQI8B],;V<O;V)S97)V97(N
M<&AP+'8@,2XU(#(P,#`O,#8O,C@@,C$Z,S8Z,3,@:F]N($5X<"`D"B`J"B`J
M($!V97)S:6]N("12979I<VEO;CH@,2XQ."`D"B`J($!P86-K86=E($QO9PH@
M*B\*"B\J*@H@*B!4:&4@3&]G7V]B<V5R=F5R.CH@8VQA<W,@:6UP;&5M96YT
M<R!T:&4@3V)S97)V97(@96YD(&]F(&$@4W5B:F5C="U/8G-E<G9E<@H@*B!P
M871T97)N(&9O<B!W871C:&EN9R!L;V<@86-T:79I='D@86YD('1A:VEN9R!A
M8W1I;VYS(&]N(&5X8V5P=&EO;F%L(&5V96YT<RX*("H*("H@0&%U=&AO<B`@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@
M($AO<F1E(#$N,PH@*B!`<VEN8V4@("!,;V<@,2XP"B`J($!P86-K86=E($QO
M9PH@*@H@*B!`97AA;7!L92!O8G-E<G9E<E]M86EL+G!H<"`@($%N(&5X86UP
M;&4@3&]G7V]B<V5R=F5R(&EM<&QE;65N=&%T:6]N+@H@*B\*8VQA<W,@3&]G
M7V]B<V5R=F5R"GL*("`@("\J*@H@("`@("H@26YS=&%N8V4M<W!E8VEF:6,@
M=6YI<75E(&ED96YT:69I8V%T:6]N(&YU;6)E<BX*("`@("`J"B`@("`@*B!`
M=F%R(&EN=&5G97(*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@
M("!V87(@)%]I9"`](#`["@H@("`@+RHJ"B`@("`@*B!4:&4@;6EN:6UU;2!P
M<FEO<FET>2!L979E;"!O9B!M97-S86=E('1H870@=V4@=V%N="!T;R!H96%R
M(&%B;W5T+@H@("`@("H@4$5!4E],3T=?14U%4D<@:7,@=&AE(&AI9VAE<W0@
M<')I;W)I='DL('-O('=E('=I;&P@;VYL>2!H96%R(&UE<W-A9V5S"B`@("`@
M*B!W:71H(&%N(&EN=&5G97(@<')I;W)I='D@=F%L=64@;&5S<R!T:&%N(&]R
M(&5Q=6%L('1O(&]U<G,N("!)="!D969A=6QT<PH@("`@("H@=&\@4$5!4E],
M3T=?24Y&3RP@=VAI8V@@;&ES=&5N<R!T;R!E=F5R>71H:6YG(&5X8V5P="!0
M14%27TQ/1U]$14)51RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7W!R:6]R:71Y
M(#T@4$5!4E],3T=?24Y&3SL*"B`@("`O*BH*("`@("`J($-R96%T97,@82!N
M97<@8F%S:6,@3&]G7V]B<V5R=F5R(&EN<W1A;F-E+@H@("`@("H*("`@("`J
M($!P87)A;2!I;G1E9V5R("`@)'!R:6]R:71Y("`@5&AE(&AI9VAE<W0@<')I
M;W)I='D@870@=VAI8V@@=&\@<F5C96EV90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!L;V<@979E;G0@;F]T:69I8V%T:6]N<RX*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO
M;B!,;V=?;V)S97)V97(H)'!R:6]R:71Y(#T@4$5!4E],3T=?24Y&3RD*("`@
M('L*("`@("`@("`D=&AI<RT^7VED(#T@;60U*&UI8W)O=&EM92@I*3L*("`@
M("`@("`D=&AI<RT^7W!R:6]R:71Y(#T@)'!R:6]R:71Y.PH@("`@?0H*("`@
M("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@;F5W(&-O;F-R971E
M($QO9U]O8G-E<G9E<B!I;G-T86YC92!O9B!T:&4@<F5Q=65S=&5D"B`@("`@
M*B!T>7!E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("`@)'1Y<&4@
M("`@("`@5&AE('1Y<&4@;V8@8V]N8W)E871E($QO9U]O8G-E<G9E<B!S=6)C
M;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T;R!R
M971U<FXN"B`@("`@*B!`<&%R86T@:6YT96=E<B`@("1P<FEO<FET>2`@(%1H
M92!H:6=H97-T('!R:6]R:71Y(&%T('=H:6-H('1O(')E8V5I=F4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;&]G(&5V96YT(&YO=&EF
M:6-A=&EO;G,N"B`@("`@*B!`<&%R86T@87)R87D@("`@("1C;VYF("`@("`@
M($]P=&EO;F%L(&%S<V]C:6%T:79E(&%R<F%Y(&]F(&%D9&ET:6]N86P*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N9FEG=7)A=&EO
M;B!V86QU97,N"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@("`@("`@
M("`@("`@("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T92!,;V=?;V)S97)V
M97(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6YS=&%N
M8V4L(&]R(&YU;&P@;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9F86-T;W)Y*"1T>7!E+"`D<')I;W)I='D@/2!014%27TQ/1U])3D9/+"`D
M8V]N9B`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1Y<&4@/2!S=')T;VQO
M=V5R*"1T>7!E*3L*("`@("`@("`D8VQA<W,@/2`G3&]G7V]B<V5R=F5R7R<@
M+B`D='EP93L*"B`@("`@("`@+RH*("`@("`@("`@*B!)9B!T:&4@9&5S:7)E
M9"!C;&%S<R!A;')E861Y(&5X:7-T<R`H8F5C875S92!T:&4@8V%L;&5R(&AA
M<R!S=7!P;&EE9`H@("`@("`@("`J(&ET(&9R;VT@<V]M92!C=7-T;VT@;&]C
M871I;VXI+"!S:6UP;'D@:6YS=&%N=&EA=&4@86YD(')E='5R;B!A(&YE=PH@
M("`@("`@("`J(&EN<W1A;F-E+@H@("`@("`@("`J+PH@("`@("`@(&EF("AC
M;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D;V)J96-T(#T@
M)FYE=R`D8VQA<W,H)'!R:6]R:71Y+"`D8V]N9BD["B`@("`@("`@("`@(')E
M='5R;B`D;V)J96-T.PH@("`@("`@('T*"B`@("`@("`@+RH@4W5P<&]R="!B
M;W1H('1H92!N97<M<W1Y;&4@86YD(&]L9"US='EL92!F:6QE(&YA;6EN9R!C
M;VYV96YT:6]N<RX@*B\*("`@("`@("`D;F5W<W1Y;&4@/2!T<G5E.PH@("`@
M("`@("1C;&%S<V9I;&4@/2!D:7)N86UE*%]?1DE,15]?*2`N("<O;V)S97)V
M97)?)R`N("1T>7!E("X@)RYP:'`G.PH*("`@("`@("!I9B`H(69I;&5?97AI
M<W1S*"1C;&%S<V9I;&4I*2!["B`@("`@("`@("`@("1C;&%S<V9I;&4@/2`G
M3&]G+R<@+B`D='EP92`N("<N<&AP)SL*("`@("`@("`@("`@)&YE=W-T>6QE
M(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*@H@("`@("`@("`J($%T
M=&5M<'0@=&\@:6YC;'5D92!O=7(@=F5R<VEO;B!O9B!T:&4@;F%M960@8VQA
M<W,L(&)U="!D;VXG="!T<F5A=`H@("`@("`@("`J(&$@9F%I;'5R92!A<R!F
M871A;"X@(%1H92!C86QL97(@;6%Y(&AA=F4@86QR96%D>2!I;F-L=61E9"!T
M:&5I<B!O=VX*("`@("`@("`@*B!V97)S:6]N(&]F('1H92!N86UE9"!C;&%S
M<RX*("`@("`@("`@*B\*("`@("`@("!`:6YC;'5D95]O;F-E("1C;&%S<V9I
M;&4["@H@("`@("`@("\J($EF('1H92!C;&%S<R!E>&ES=',L(')E='5R;B!A
M(&YE=R!I;G-T86YC92!O9B!I="X@*B\*("`@("`@("!I9B`H8VQA<W-?97AI
M<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@+RH@4W5P<&]R="!B;W1H(&YE
M=RUS='EL92!A;F0@;VQD+7-T>6QE(&-O;G-T<G5C=&EO;BX@*B\*("`@("`@
M("`@("`@:68@*"1N97=S='EL92D@>PH@("`@("`@("`@("`@("`@)&]B:F5C
M="`]("9N97<@)&-L87-S*"1P<FEO<FET>2P@)&-O;F8I.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&]B:F5C="`]("9N97<@)&-L
M87-S*"1P<FEO<FET>2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T
M=7)N("1O8FIE8W0["B`@("`@("`@?0H*("`@("`@("`D;G5L;"`](&YU;&P[
M"B`@("`@("`@<F5T=7)N("1N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@
M5&AI<R!I<R!A('-T=6(@;65T:&]D('1O(&UA:V4@<W5R92!T:&%T($QO9U]/
M8G-E<G9E<B!C;&%S<V5S(&1O"B`@("`@*B!S;VUE=&AI;F<@=VAE;B!T:&5Y
M(&%R92!N;W1I9FEE9"!O9B!A(&UE<W-A9V4N("!4:&4@9&5F875L="!B96AA
M=FEO<@H@("`@("H@:7,@=&\@:G5S="!P<FEN="!T:&4@;65S<V%G92P@=VAI
M8V@@:7,@;V)V:6]U<VQY(&YO="!D97-I<F5A8FQE(&EN"B`@("`@*B!P<F%C
M=&EC86QL>2!A;GD@<VET=6%T:6]N("T@=VAI8V@@:7,@=VAY('EO=2!N965D
M('1O(&]V97)R:61E('1H:7,*("`@("`J(&UE=&AO9"X@.BD*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@("`@("1E=F5N="`@("`@($$@:&%S:"!D97-C
M<FEB:6YG('1H92!L;V<@979E;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&YO
M=&EF>2@D979E;G0I"B`@("!["B`@("`@("`@<')I;G1?<B@D979E;G0I.PH@
M("`@?0I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B],;V<O<W%L+G!H<```````````````````````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`R,3`W,P`Q,#4Q-30S,S<S-P`P,C`V-#,`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J("1(96%D97(Z("]R97!O<VET;W)Y+W!E87(O3&]G+TQO9R]S<6PN
M<&AP+'8@,2XT,"`R,#`V+S`Q+S`S(#`T.C$R.C0U(&IO;B!%>'`@)`H@*B`D
M2&]R9&4Z(&AO<F1E+VQI8B],;V<O<W%L+G!H<"QV(#$N,3(@,C`P,"\P."\Q
M-B`R,#HR-SHS-"!C:'5C:R!%>'`@)`H@*@H@*B!`=F5R<VEO;B`D4F5V:7-I
M;VXZ(#$N-#`@)`H@*B!`<&%C:V%G92!,;V<*("HO"@HO*@H@*B!792!R97%U
M:7)E('1H92!014%2($1"(&-L87-S+B`@5&AI<R!I<R!G96YE<F%L;'D@9&5F
M:6YE9"!I;B!T:&4@1$(N<&AP(&9I;&4L"B`J(&)U="!I="=S('!O<W-I8FQE
M('1H870@=&AE(&-A;&QE<B!M87D@:&%V92!P<F]V:61E9"!T:&4@1$(@8VQA
M<W,L(&]R(&$*("H@8V]M<&%T:6)L92!W<F%P<&5R("AS=6-H(&%S('1H92!O
M;F4@<VAI<'!E9"!W:71H($U$0C(I+"!S;R!W92!F:7)S="!C:&5C:PH@*B!F
M;W(@86X@97AI<W1I;F<@)T1")R!C;&%S<R!B969O<F4@:6YC;'5D:6YG("=$
M0BYP:'`G+@H@*B\*:68@*"%C;&%S<U]E>&ES=',H)T1")RDI('L*("`@(')E
M<75I<F5?;VYC92`G1$(N<&AP)SL*?0H*+RHJ"B`J(%1H92!,;V=?<W%L(&-L
M87-S(&ES(&$@8V]N8W)E=&4@:6UP;&5M96YT871I;VX@;V8@=&AE($QO9SHZ
M"B`J(&%B<W1R86-T(&-L87-S('=H:6-H('-E;F1S(&UE<W-A9V5S('1O(&%N
M(%-13"!S97)V97(N("!%86-H(&5N=')Y"B`J(&]C8W5P:65S(&$@<V5P87)A
M=&4@<F]W(&EN('1H92!D871A8F%S92X*("H*("H@5&AI<R!I;7!L96UE;G1A
M=&EO;B!U<V5S(%!(4"=S(%!%05(@9&%T86)A<V4@86)S=')A8W1I;VX@;&%Y
M97(N"B`J"B`J($-214%412!404),12!L;V=?=&%B;&4@*`H@*B`@:60@("`@
M("`@("`@24Y4($Y/5"!.54Q,+`H@*B`@;&]G=&EM92`@("`@5$E-15-404U0
M($Y/5"!.54Q,+`H@*B`@:61E;G0@("`@("`@0TA!4B@Q-BD@3D]4($Y53$PL
M"B`J("!P<FEO<FET>2`@("!)3E0@3D]4($Y53$PL"B`J("!M97-S86=E("`@
M("!605)#2$%2*#(P,"DL"B`J("!04DE-05)9($M%62`H:60I"B`J("D["B`J
M"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!P:'`N;F5T/@H@*B!`<VEN
M8V4@("!(;W)D92`Q+C,*("H@0'-I;F-E("`@3&]G(#$N,`H@*B!`<&%C:V%G
M92!,;V<*("H*("H@0&5X86UP;&4@<W%L+G!H<"`@("`@57-I;F<@=&AE(%-1
M3"!H86YD;&5R+@H@*B\*8VQA<W,@3&]G7W-Q;"!E>'1E;F1S($QO9PI["B`@
M("`O*BH*("`@("`J(%9A<FEA8FQE(&-O;G1A:6YI;F<@=&AE($133B!I;F9O
M<FUA=&EO;BX*("`@("`J($!V87(@;6EX960*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!V87(@)%]D<VX@/2`G)SL*"B`@("`O*BH*("`@
M("`J(%-T<FEN9R!C;VYT86EN:6YG('1H92!344P@:6YS97)T:6]N('-T871E
M;65N="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7W-Q;"`]("<G.PH*("`@("\J
M*@H@("`@("H@07)R87D@8V]N=&%I;FEN9R!O=7(@<V5T(&]F($1"(&-O;F9I
M9W5R871I;VX@;W!T:6]N<RX*("`@("`J($!V87(@87)R87D*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]O<'1I;VYS(#T@87)R
M87DH)W!E<G-I<W1E;G0G(#T^('1R=64I.PH*("`@("\J*@H@("`@("H@3V)J
M96-T(&AO;&1I;F<@=&AE(&1A=&%B87-E(&AA;F1L92X*("`@("`J($!V87(@
M;V)J96-T"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R
M("1?9&(@/2!N=6QL.PH*("`@("\J*@H@("`@("H@4F5S;W5R8V4@:&]L9&EN
M9R!T:&4@<')E<&%R960@<W1A=&5M96YT(&AA;F1L92X*("`@("`J($!V87(@
M<F5S;W5R8V4*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V
M87(@)%]S=&%T96UE;G0@/2!N=6QL.PH*("`@("\J*@H@("`@("H@1FQA9R!I
M;F1I8V%T:6YG('1H870@=V4G<F4@=7-I;F<@86X@97AI<W1I;F<@9&%T86)A
M<V4@8V]N;F5C=&EO;BX*("`@("`J($!V87(@8F]O;&5A;@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7V5X:7-T:6YG0V]N;F5C
M=&EO;B`](&9A;'-E.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&AO;&1I;F<@
M=&AE(&1A=&%B87-E('1A8FQE('1O('5S92X*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?=&%B
M;&4@/2`G;&]G7W1A8FQE)SL*"B`@("`O*BH*("`@("`J(%-T<FEN9R!H;VQD
M:6YG('1H92!N86UE(&]F('1H92!)1"!S97%U96YC92X*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R
M("1?<V5Q=65N8V4@/2`G;&]G7VED)SL*"B`@("`O*BH*("`@("`J($UA>&EM
M=6T@;&5N9W1H(&]F('1H92`D:61E;G0@<W1R:6YG+B`@5&AI<R!C;W)R97-P
M;VYD<R!T;R!T:&4@<VEZ92!O9@H@("`@("H@=&AE("=I9&5N="<@8V]L=6UN
M(&EN('1H92!344P@=&%B;&4N"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]I9&5N=$QI;6ET
M(#T@,38["@H*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!S<6P@
M;&]G9VEN9R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;F%M92`@("`@("`@(%1H92!T87)G970@4U%,('1A8FQE+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D:61E;G0@("`@("`@(%1H92!I9&5N=&EF:6-A=&EO;B!F
M:65L9"X*("`@("`J($!P87)A;2!A<G)A>2`D8V]N9B`@("`@("`@("!4:&4@
M8V]N;F5C=&EO;B!C;VYF:6=U<F%T:6]N(&%R<F%Y+@H@("`@("H@0'!A<F%M
M(&EN="`D;&5V96P@("`@("`@("`@($QO9R!M97-S86=E<R!U<"!T;R!A;F0@
M:6YC;'5D:6YG('1H:7,@;&5V96PN"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("HO"B`@("!F=6YC=&EO;B!,;V=?<W%L*"1N86UE+"`D:61E;G0@/2`G
M)RP@)&-O;F8@/2!A<G)A>2@I+`H@("`@("`@("`@("`@("`@("`@("`D;&5V
M96P@/2!014%27TQ/1U]$14)51RD*("`@('L*("`@("`@("`D=&AI<RT^7VED
M(#T@;60U*&UI8W)O=&EM92@I*3L*("`@("`@("`D=&AI<RT^7W1A8FQE(#T@
M)&YA;64["B`@("`@("`@)'1H:7,M/E]M87-K(#T@3&]G.CI54%1/*"1L979E
M;"D["@H@("`@("`@("\J($YO=R!T:&%T('=E(&AA=F4@82!T86)L92!N86UE
M+"!A<W-I9VX@;W5R(%-13"!S=&%T96UE;G0N("HO"B`@("`@("`@:68@*"%E
M;7!T>2@D=&AI<RT^7W-Q;"DI('L*("`@("`@("`@("`@)'1H:7,M/E]S<6P@
M/2`D8V]N9ELG<W%L)UT["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1H:7,M/E]S<6P@/2`G24Y315)4($E.5$\@)R`N("1T:&ES+3Y?=&%B;&4@
M+@H@("`@("`@("`@("`@("`@("`@("`@("`@("<@*&ED+"!L;V=T:6UE+"!I
M9&5N="P@<')I;W)I='DL(&UE<W-A9V4I)R`N"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@)R!604Q515,H/RP@0U524D5.5%]424U%4U1!35`L(#\L(#\L
M(#\I)SL*("`@("`@("!]"@H@("`@("`@("\J($EF(&%N(&]P=&EO;G,@87)R
M87D@=V%S('!R;W9I9&5D+"!U<V4@:70N("HO"B`@("`@("`@:68@*&ES<V5T
M*"1C;VYF6R=O<'1I;VYS)UTI("8F(&ES7V%R<F%Y*"1C;VYF6R=O<'1I;VYS
M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W!T:6]N<R`]("1C;VYF6R=O
M<'1I;VYS)UT["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!A('-P96-I9FEC
M('-E<75E;F-E(&YA;64@=V%S('!R;W9I9&5D+"!U<V4@:70N("HO"B`@("`@
M("`@:68@*"%E;7!T>2@D8V]N9ELG<V5Q=65N8V4G72DI('L*("`@("`@("`@
M("`@)'1H:7,M/E]S97%U96YC92`]("1C;VYF6R=S97%U96YC92==.PH@("`@
M("`@('T*"B`@("`@("`@+RH@268@82!S<&5C:69I8R!S97%U96YC92!N86UE
M('=A<R!P<F]V:61E9"P@=7-E(&ET+B`J+PH@("`@("`@(&EF("AI<W-E="@D
M8V]N9ELG:61E;G1,:6UI="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VED
M96YT3&EM:70@/2`D8V]N9ELG:61E;G1,:6UI="==.PH@("`@("`@('T*"B`@
M("`@("`@+RH@3F]W('1H870@=&AE(&ED96YT(&QI;6ET(&ES(&-O;F9I<FUE
M9"P@<V5T('1H92!I9&5N="!S=')I;F<N("HO"B`@("`@("`@)'1H:7,M/G-E
M=$ED96YT*"1I9&5N="D["@H@("`@("`@("\J($EF(&%N(&5X:7-T:6YG(&1A
M=&%B87-E(&-O;FYE8W1I;VX@=V%S('!R;W9I9&5D+"!U<V4@:70N("HO"B`@
M("`@("`@:68@*&ES<V5T*"1C;VYF6R=D8B==*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7V1B(#T@)B1C;VYF6R=D8B==.PH@("`@("`@("`@("`D=&AI<RT^
M7V5X:7-T:6YG0V]N;F5C=&EO;B`]('1R=64["B`@("`@("`@("`@("1T:&ES
M+3Y?;W!E;F5D(#T@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D=&AI<RT^7V1S;B`]("1C;VYF6R=D<VXG73L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!/<&5N<R!A(&-O;FYE8W1I;VX@=&\@=&AE(&1A
M=&%B87-E+"!I9B!I="!H87,@;F]T(&%L<F5A9'D*("`@("`J(&)E96X@;W!E
M;F5D+B!4:&ES(&ES(&EM<&QI8VET;'D@8V%L;&5D(&)Y(&QO9R@I+"!I9B!N
M96-E<W-A<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("`@5')U
M92!O;B!S=6-C97-S+"!F86QS92!O;B!F86EL=7)E+@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;W!E;B@I"B`@("!["B`@
M("`@("`@:68@*"$D=&AI<RT^7V]P96YE9"D@>PH@("`@("`@("`@("`O*B!5
M<V4@=&AE($133B!A;F0@;W!T:6]N<R!T;R!C<F5A=&4@82!D871A8F%S92!C
M;VYN96-T:6]N+B`J+PH@("`@("`@("`@("`D=&AI<RT^7V1B(#T@)D1".CIC
M;VYN96-T*"1T:&ES+3Y?9'-N+"`D=&AI<RT^7V]P=&EO;G,I.PH@("`@("`@
M("`@("!I9B`H1$(Z.FES17)R;W(H)'1H:7,M/E]D8BDI('L*("`@("`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+RH@0W)E871E(&$@<')E<&%R960@<W1A=&5M96YT(&9O<B!R97!E871E
M9"!U<V4@:6X@;&]G*"DN("HO"B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]P
M<F5P87)E4W1A=&5M96YT*"DI('L*("`@("`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@5V4@;F]W(&-O
M;G-I9&5R(&]U="!C;VYN96-T:6]N(&]P96XN("HO"B`@("`@("`@("`@("1T
M:&ES+3Y?;W!E;F5D(#T@=')U93L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D=&AI<RT^7V]P96YE9#L*("`@('T*"B`@("`O*BH*("`@("`J($-L;W-E
M<R!T:&4@8V]N;F5C=&EO;B!T;R!T:&4@9&%T86)A<V4@:68@:70@:7,@<W1I
M;&P@;W!E;B!A;F0@=V4@=V5R90H@("`@("H@=&AE(&]N97,@=&AA="!O<&5N
M960@:70N("!)="!I<R!T:&4@8V%L;&5R)W,@<F5S<&]N<VEB;&4@=&\@8VQO
M<V4@86X*("`@("`J(&5X:7-T:6YG(&-O;FYE8W1I;VX@=&AA="!W87,@<&%S
M<V5D('1O('5S('9I82`D8V]N9ELG9&(G72X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&9A:6QU
M<F4N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO
M;B!C;&]S92@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?;W!E;F5D("8F
M("$D=&AI<RT^7V5X:7-T:6YG0V]N;F5C=&EO;BD@>PH@("`@("`@("`@("`D
M=&AI<RT^7V]P96YE9"`](&9A;'-E.PH@("`@("`@("`@("`D=&AI<RT^7V1B
M+3YF<F5E4')E<&%R960H)'1H:7,M/E]S=&%T96UE;G0I.PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]D8BT^9&ES8V]N;F5C="@I.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("@D=&AI<RT^7V]P96YE9"`]/3T@9F%L<V4I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&ES($QO9R!I;G-T86YC92=S
M(&ED96YT:69I8V%T:6]N('-T<FEN9RX@($YO=&4@=&AA="!T:&ES"B`@("`@
M*B!344PM<W!E8VEF:6,@:6UP;&5M96YT871I;VX@=VEL;"!L:6UI="!T:&4@
M;&5N9W1H(&]F('1H92`D:61E;G0@<W1R:6YG"B`@("`@*B!T;R!S:7AT965N
M("@Q-BD@8VAA<F%C=&5R<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("`@("1I9&5N="`@("`@(%1H92!N97<@:61E;G1I9FEC871I;VX@<W1R:6YG
M+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I;F-E
M("`@3&]G(#$N."XU"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$ED96YT*"1I
M9&5N="D*("`@('L*("`@("`@("`D=&AI<RT^7VED96YT(#T@<W5B<W1R*"1I
M9&5N="P@,"P@)'1H:7,M/E]I9&5N=$QI;6ET*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($EN<V5R=',@)&UE<W-A9V4@=&\@=&AE(&-U<G)E;G1L>2!O<&5N
M(&1A=&%B87-E+B`@0V%L;',@;W!E;B@I+`H@("`@("H@:68@;F5C97-S87)Y
M+B`@06QS;R!P87-S97,@=&AE(&UE<W-A9V4@86QO;F<@=&\@86YY($QO9U]O
M8G-E<G9E<@H@("`@("H@:6YS=&%N8V5S('1H870@87)E(&]B<V5R=FEN9R!T
M:&ES($QO9RX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@("1M97-S86=E
M("!3=')I;F<@;W(@;V)J96-T(&-O;G1A:6YI;F<@=&AE(&UE<W-A9V4@=&\@
M;&]G+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')I;W)I='D@5&AE('!R:6]R
M:71Y(&]F('1H92!M97-S86=E+B`@5F%L:60*("`@("`J("`@("`@("`@("`@
M("`@("`@=F%L=65S(&%R93H@4$5!4E],3T=?14U%4D<L(%!%05)?3$]'7T%,
M15)4+`H@("`@("H@("`@("`@("`@("`@("`@("!014%27TQ/1U]#4DE4+"!0
M14%27TQ/1U]%4E(L(%!%05)?3$]'7U=!4DY)3D<L"B`@("`@*B`@("`@("`@
M("`@("`@("`@(%!%05)?3$]'7TY/5$E#12P@4$5!4E],3T=?24Y&3RP@86YD
M(%!%05)?3$]'7T1%0E5'+@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M(&]N('-U8V-E<W,@;W(@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO9R@D;65S<V%G92P@
M)'!R:6]R:71Y(#T@;G5L;"D*("`@('L*("`@("`@("`O*B!)9B!A('!R:6]R
M:71Y(&AA<VXG="!B965N('-P96-I9FEE9"P@=7-E('1H92!D969A=6QT('9A
M;'5E+B`J+PH@("`@("`@(&EF("@D<')I;W)I='D@/3T](&YU;&PI('L*("`@
M("`@("`@("`@)'!R:6]R:71Y(#T@)'1H:7,M/E]P<FEO<FET>3L*("`@("`@
M("!]"@H@("`@("`@("\J($%B;W)T(&5A<FQY(&EF('1H92!P<FEO<FET>2!I
M<R!A8F]V92!T:&4@;6%X:6UU;2!L;V=G:6YG(&QE=F5L+B`J+PH@("`@("`@
M(&EF("@A)'1H:7,M/E]I<TUA<VME9"@D<')I;W)I='DI*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\J($EF('1H
M92!C;VYN96-T:6]N(&ES;B=T(&]P96X@86YD(&-A;B=T(&)E(&]P96YE9"P@
M<F5T=7)N(&9A:6QU<F4N("HO"B`@("`@("`@:68@*"$D=&AI<RT^7V]P96YE
M9"`F)B`A)'1H:7,M/F]P96XH*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!W92!D;VXG="!A;')E861Y
M(&AA=F4@;W5R('-T871E;65N="!O8FIE8W0@>65T+"!C<F5A=&4@:70N("HO
M"B`@("`@("`@:68@*"%I<U]O8FIE8W0H)'1H:7,M/E]S=&%T96UE;G0I("8F
M("$D=&AI<RT^7W!R97!A<F53=&%T96UE;G0H*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!%>'1R86-T('1H
M92!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@=&AE(&UE<W-A9V4N("HO"B`@
M("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^7V5X=')A8W1-97-S86=E*"1M97-S
M86=E*3L*"B`@("`@("`@+RH@0G5I;&0@;W5R('-E="!O9B!V86QU97,@9F]R
M('1H:7,@;&]G(&5N=')Y+B`J+PH@("`@("`@("1I9"`]("1T:&ES+3Y?9&(M
M/FYE>'1)9"@D=&AI<RT^7W-E<75E;F-E*3L*("`@("`@("`D=F%L=65S(#T@
M87)R87DH)&ED+"`D=&AI<RT^7VED96YT+"`D<')I;W)I='DL("1M97-S86=E
M*3L*"B`@("`@("`@+RH@17AE8W5T92!T:&4@4U%,('%U97)Y(&9O<B!T:&ES
M(&QO9R!E;G1R>2!I;G-E<G1I;VXN("HO"B`@("`@("`@)')E<W5L="`])B`D
M=&AI<RT^7V1B+3YE>&5C=71E*"1T:&ES+3Y?<W1A=&5M96YT+"`D=F%L=65S
M*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/E]A;FYO=6YC92AA<G)A>2@G<')I;W)I='DG(#T^("1P<FEO<FET>2P@)VUE
M<W-A9V4G(#T^("1M97-S86=E*2D["@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4')E<&%R92!T:&4@4U%,(&EN<V5R=&EO
M;B!S=&%T96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&EF('1H92!S=&%T96UE;G0@=V%S('-U8V-E<W-F=6QL>2!C<F5A=&5D
M+@H@("`@("H*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J($!S:6YC
M92`@($QO9R`Q+CDN,0H@("`@("HO"B`@("!F=6YC=&EO;B!?<')E<&%R95-T
M871E;65N="@I"B`@("!["B`@("`@("`@)'1H:7,M/E]S=&%T96UE;G0@/2`D
M=&AI<RT^7V1B+3YP<F5P87)E*"1T:&ES+3Y?<W%L*3L*"B`@("`@("`@+RH@
M4F5T=7)N('-U8V-E<W,@:68@=V4@9&ED;B=T(&=E;F5R871E(&%N(&5R<F]R
M+B`J+PH@("`@("`@(')E='5R;B`H1$(Z.FES17)R;W(H)'1H:7,M/E]S=&%T
M96UE;G0I(#T]/2!F86QS92D["B`@("!]"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+TQO9R]S<6QI=&4N<&AP````````````````````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$U-38R`#$P-3$U-#,S-S,W`#`R
M,3,U,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@)$AE861E<CH@+W)E<&]S:71O<GDO<&5A<B],;V<O
M3&]G+W-Q;&ET92YP:'`L=B`Q+C4@,C`P-2\Q,B\P-2`P-3HS.#HS,2!J;VX@
M17AP("0*("H*("H@0'9E<G-I;VX@)%)E=FES:6]N.B`Q+C4@)`H@*B!`<&%C
M:V%G92!,;V<*("HO"@HO*BH*("H@5&AE($QO9U]S<6QI=&4@8VQA<W,@:7,@
M82!C;VYC<F5T92!I;7!L96UE;G1A=&EO;B!O9B!T:&4@3&]G.CH*("H@86)S
M=')A8W0@8VQA<W,@=VAI8V@@<V5N9',@;65S<V%G97,@=&\@86X@4W%L:71E
M(&1A=&%B87-E+@H@*B!%86-H(&5N=')Y(&]C8W5P:65S(&$@<V5P87)A=&4@
M<F]W(&EN('1H92!D871A8F%S92X*("H*("H@5&AI<R!I;7!L96UE;G1A=&EO
M;B!U<V5S(%!(4"!N871I=F4@4W%L:71E(&9U;F-T:6]N<RX*("H*("H@0U)%
M051%(%1!0DQ%(&QO9U]T86)L92`H"B`J("!I9"`@("`@("`@("!)3E1%1T52
M(%!224U!4ED@2T59($Y/5"!.54Q,+`H@*B`@;&]G=&EM92`@("`@3D]4($Y5
M3$PL"B`J("!I9&5N="`@("`@("!#2$%2*#$V*2!.3U0@3E5,3"P*("H@('!R
M:6]R:71Y("`@($E.5"!.3U0@3E5,3"P*("H@(&UE<W-A9V4*("H@*3L*("H*
M("H@0&%U=&AO<B`@0F5R=')A;F0@36%N<VEO;B`\8FUA;G-I;VY`;6%M87-A
M;2YC;VT^"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!P:'`N;F5T/@H@
M*B!`<VEN8V4@("!,;V<@,2XX+C,*("H@0'!A8VMA9V4@3&]G"B`J"B`J($!E
M>&%M<&QE('-Q;&ET92YP:'`@("`@("!5<VEN9R!T:&4@4W%L:71E(&AA;F1L
M97(N"B`J+PIC;&%S<R!,;V=?<W%L:71E(&5X=&5N9',@3&]G"GL*("`@("\J
M*@H@("`@("H@07)R87D@8V]N=&%I;FEN9R!T:&4@8V]N;F5C=&EO;B!D969A
M=6QT<PH@("`@("H@0'9A<B!A<G)A>0H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B\*("`@('9A<B`D7V]P=&EO;G,@/2!A<G)A>2@G;6]D92<@("`@
M("`@/3X@,#8V-BP*("`@("`@("`@("`@("`@("`@("`@("`@("`G<&5R<VES
M=&5N="<@/3X@9F%L<V4I.PH*("`@("\J*@H@("`@("H@3V)J96-T(&AO;&1I
M;F<@=&AE(&1A=&%B87-E(&AA;F1L92X*("`@("`J($!V87(@;V)J96-T"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?9&(@/2!N
M=6QL.PH*("`@("\J*@H@("`@("H@1FQA9R!I;F1I8V%T:6YG('1H870@=V4G
M<F4@=7-I;F<@86X@97AI<W1I;F<@9&%T86)A<V4@8V]N;F5C=&EO;BX*("`@
M("`J($!V87(@8F]O;&5A;@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*B\*("`@('9A<B`D7V5X:7-T:6YG0V]N;F5C=&EO;B`](&9A;'-E.PH*("`@
M("\J*@H@("`@("H@4W1R:6YG(&AO;&1I;F<@=&AE(&1A=&%B87-E('1A8FQE
M('1O('5S92X*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J+PH@("`@=F%R("1?=&%B;&4@/2`G;&]G7W1A8FQE)SL*
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W('-Q;"!L;V=G:6YG
M(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@
M("`@("`@5&AE('1A<F=E="!344P@=&%B;&4N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1I9&5N="`@("`@("`@5&AE(&ED96YT:69I8V%T:6]N(&9I96QD+@H@
M("`@("H@0'!A<F%M(&UI>&5D("`D8V]N9B`@("`@("`@($-A;B!B92!A;B!A
M<G)A>2!O9B!C;VYF:6=U<F%T:6]N(&]P=&EO;G,@=7-E9`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('1O(&]P96X@82!N97<@9&%T86)A
M<V4@8V]N;F5C=&EO;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&]R(&%N(&%L<F5A9'D@;W!E;F5D('-Q;&ET92!C;VYN96-T:6]N+@H@
M("`@("H@0'!A<F%M(&EN="`@("`D;&5V96P@("`@("`@($QO9R!M97-S86=E
M<R!U<"!T;R!A;F0@:6YC;'5D:6YG('1H:7,@;&5V96PN"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!,;V=?<W%L:71E*"1N
M86UE+"`D:61E;G0@/2`G)RP@)B1C;VYF+"`D;&5V96P@/2!014%27TQ/1U]$
M14)51RD*("`@('L*("`@("`@("`D=&AI<RT^7VED(#T@;60U*&UI8W)O=&EM
M92@I*3L*("`@("`@("`D=&AI<RT^7W1A8FQE(#T@)&YA;64["B`@("`@("`@
M)'1H:7,M/E]I9&5N="`]("1I9&5N=#L*("`@("`@("`D=&AI<RT^7VUA<VL@
M/2!,;V<Z.E505$\H)&QE=F5L*3L*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1C
M;VYF*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D8V]N9B!A<R`D:R`]/B`D
M;W!T*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]P=&EO;G-;)&M=(#T@
M)&]P=#L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("\O($EF(&%N(&5X:7-T:6YG(&1A=&%B87-E(&-O;FYE8W1I;VX@=V%S
M('!R;W9I9&5D+"!U<V4@:70N"B`@("`@("`@("`@("1T:&ES+3Y?9&(@/28@
M)&-O;F8["B`@("`@("`@("`@("1T:&ES+3Y?97AI<W1I;F=#;VYN96-T:6]N
M(#T@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!/<&5N
M<R!A(&-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E+"!I9B!I="!H87,@;F]T
M(&%L<F5A9'D*("`@("`J(&)E96X@;W!E;F5D+B!4:&ES(&ES(&EM<&QI8VET
M;'D@8V%L;&5D(&)Y(&QO9R@I+"!I9B!N96-E<W-A<GDN"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("`@5')U92!O;B!S=6-C97-S+"!F86QS92!O
M;B!F86EL=7)E+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@;W!E;B@I"B`@("!["B`@("`@("`@:68@*&ES7W)E<V]U<F-E
M*"1T:&ES+3Y?9&(I*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W!E;F5D(#T@
M=')U93L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8W)E871E5&%B;&4H
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!3970@=&AE(&-O
M;FYE8W1I;VX@9G5N8W1I;VX@8F%S960@;VX@=&AE("=P97)S:7-T96YT)R!O
M<'1I;VXN("HO"B`@("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7V]P=&EO
M;G-;)W!E<G-I<W1E;G0G72DI('L*("`@("`@("`@("`@("`@("1C;VYN96-T
M1G5N8W1I;VX@/2`G<W%L:71E7V]P96XG.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)&-O;FYE8W1&=6YC=&EO;B`]("=S<6QI=&5?
M<&]P96XG.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!!='1E;7!T
M('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+B`J+PH@("`@("`@("`@("!I
M9B`H)'1H:7,M/E]D8B`]("1C;VYN96-T1G5N8W1I;VXH)'1H:7,M/E]O<'1I
M;VYS6R=F:6QE;F%M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@*&EN="DD=&AI<RT^7V]P=&EO;G-;)VUO9&4G
M72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1E<G)O<BDI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W!E;F5D
M(#T@=')U93L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V-R96%T
M951A8FQE*"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D=&AI<RT^7V]P96YE9#L*("`@('T*"B`@("`O*BH*("`@("`J($-L
M;W-E<R!T:&4@8V]N;F5C=&EO;B!T;R!T:&4@9&%T86)A<V4@:68@:70@:7,@
M<W1I;&P@;W!E;B!A;F0@=V4@=V5R90H@("`@("H@=&AE(&]N97,@=&AA="!O
M<&5N960@:70N("!)="!I<R!T:&4@8V%L;&5R)W,@<F5S<&]N<VEB;&4@=&\@
M8VQO<V4@86X*("`@("`J(&5X:7-T:6YG(&-O;FYE8W1I;VX@=&AA="!W87,@
M<&%S<V5D('1O('5S('9I82`D8V]N9ELG9&(G72X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&9A
M:6QU<F4N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!C;&]S92@I"B`@("!["B`@("`@("`@+RH@5V4@;F5V97(@8VQO<V4@
M97AI<W1I;F<@8V]N;F5C=&EO;G,N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?
M97AI<W1I;F=#;VYN96-T:6]N*2!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^7V]P96YE9"D@>PH@
M("`@("`@("`@("`D=&AI<RT^7V]P96YE9"`](&9A;'-E.PH@("`@("`@("`@
M("!S<6QI=&5?8VQO<V4H)'1H:7,M/E]D8BD["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@*"1T:&ES+3Y?;W!E;F5D(#T]/2!F86QS92D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!);G-E<G1S("1M97-S86=E('1O('1H92!C=7)R96YT
M;'D@;W!E;B!D871A8F%S92X@($-A;&QS(&]P96XH*2P*("`@("`J(&EF(&YE
M8V5S<V%R>2X@($%L<V\@<&%S<V5S('1H92!M97-S86=E(&%L;VYG('1O(&%N
M>2!,;V=?;V)S97)V97(*("`@("`J(&EN<W1A;F-E<R!T:&%T(&%R92!O8G-E
M<G9I;F<@=&AI<R!,;V<N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("`D
M;65S<V%G92`@4W1R:6YG(&]R(&]B:F5C="!C;VYT86EN:6YG('1H92!M97-S
M86=E('1O(&QO9RX*("`@("`J($!P87)A;2!S=')I;F<@)'!R:6]R:71Y(%1H
M92!P<FEO<FET>2!O9B!T:&4@;65S<V%G92X@(%9A;&ED"B`@("`@*B`@("`@
M("`@("`@("`@("`@('9A;'5E<R!A<F4Z(%!%05)?3$]'7T5-15)'+"!014%2
M7TQ/1U]!3$525"P*("`@("`J("`@("`@("`@("`@("`@("`@4$5!4E],3T=?
M0U))5"P@4$5!4E],3T=?15)2+"!014%27TQ/1U]705).24Y'+`H@("`@("H@
M("`@("`@("`@("`@("`@("!014%27TQ/1U].3U1)0T4L(%!%05)?3$]'7TE.
M1D\L(&%N9"!014%27TQ/1U]$14)51RX*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5')U92!O;B!S=6-C97-S(&]R(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!L;V<H)&UE
M<W-A9V4L("1P<FEO<FET>2`](&YU;&PI"B`@("!["B`@("`@("`@+RH@268@
M82!P<FEO<FET>2!H87-N)W0@8F5E;B!S<&5C:69I960L('5S92!T:&4@9&5F
M875L="!V86QU92X@*B\*("`@("`@("!I9B`H)'!R:6]R:71Y(#T]/2!N=6QL
M*2!["B`@("`@("`@("`@("1P<FEO<FET>2`]("1T:&ES+3Y?<')I;W)I='D[
M"B`@("`@("`@?0H*("`@("`@("`O*B!!8F]R="!E87)L>2!I9B!T:&4@<')I
M;W)I='D@:7,@86)O=F4@=&AE(&UA>&EM=6T@;&]G9VEN9R!L979E;"X@*B\*
M("`@("`@("!I9B`H(21T:&ES+3Y?:7--87-K960H)'!R:6]R:71Y*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O
M*B!)9B!T:&4@8V]N;F5C=&EO;B!I<VXG="!O<&5N(&%N9"!C86XG="!B92!O
M<&5N960L(')E='5R;B!F86EL=7)E+B`J+PH@("`@("`@(&EF("@A)'1H:7,M
M/E]O<&5N960@)B8@(21T:&ES+3YO<&5N*"DI('L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+R\@17AT<F%C="!T:&4@
M<W1R:6YG(')E<')E<V5N=&%T:6]N(&]F('1H92!M97-S86=E+@H@("`@("`@
M("1M97-S86=E(#T@)'1H:7,M/E]E>'1R86-T365S<V%G92@D;65S<V%G92D[
M"@H@("`@("`@("\O($)U:6QD('1H92!344P@<75E<GD@9F]R('1H:7,@;&]G
M(&5N=')Y(&EN<V5R=&EO;BX*("`@("`@("`D<2`]('-P<FEN=&8H)TE.4T52
M5"!)3E1/(%LE<UT@*&QO9W1I;64L(&ED96YT+"!P<FEO<FET>2P@;65S<V%G
M92D@)R`N"B`@("`@("`@("`@("`@("`@("`@(")604Q515,@*"<E<R<L("<E
M<R<L("5D+"`G)7,G*2(L"B`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M=&%B;&4L"B`@("`@("`@("`@("`@("`@("`@('-T<F9T:6UE*"<E62TE;2TE
M9"`E2#HE33HE4R<L('1I;64H*2DL"B`@("`@("`@("`@("`@("`@("`@('-Q
M;&ET95]E<V-A<&5?<W1R:6YG*"1T:&ES+3Y?:61E;G0I+`H@("`@("`@("`@
M("`@("`@("`@("`D<')I;W)I='DL"B`@("`@("`@("`@("`@("`@("`@('-Q
M;&ET95]E<V-A<&5?<W1R:6YG*"1M97-S86=E*2D["B`@("`@("`@:68@*"$H
M)')E<R`]($!S<6QI=&5?=6YB=69F97)E9%]Q=65R>2@D=&AI<RT^7V1B+"`D
M<2DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@
M("`@("`@)'1H:7,M/E]A;FYO=6YC92AA<G)A>2@G<')I;W)I='DG(#T^("1P
M<FEO<FET>2P@)VUE<W-A9V4G(#T^("1M97-S86=E*2D["@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS('=H971H
M97(@=&AE(&QO9R!T86)L92!E>&ES=',@86YD(&-R96%T97,@:70@:68@;F5C
M97-S87)Y+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O
M;B!S=6-C97-S(&]R(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V-R96%T951A8FQE*"D*
M("`@('L*("`@("`@("`D<2`](")314Q%0U0@;F%M92!&4D]-('-Q;&ET95]M
M87-T97(@5TA%4D4@;F%M93TG(B`N("1T:&ES+3Y?=&%B;&4@+@H@("`@("`@
M("`@("`@(B<@04Y$('1Y<&4])W1A8FQE)R(["@H@("`@("`@("1R97,@/2!S
M<6QI=&5?<75E<GDH)'1H:7,M/E]D8BP@)'$I.PH*("`@("`@("!I9B`H<W%L
M:71E7VYU;5]R;W=S*"1R97,I(#T](#`I('L*("`@("`@("`@("`@)'$@/2`G
M0U)%051%(%1!0DQ%(%LG("X@)'1H:7,M/E]T86)L92`N("==("@G("X*("`@
M("`@("`@("`@("`@("`G:60@24Y414=%4B!04DE-05)9($M%62!.3U0@3E5,
M3"P@)R`N"B`@("`@("`@("`@("`@("`@)VQO9W1I;64@3D]4($Y53$PL("<@
M+@H@("`@("`@("`@("`@("`@("=I9&5N="!#2$%2*#$V*2!.3U0@3E5,3"P@
M)R`N"B`@("`@("`@("`@("`@("`@)W!R:6]R:71Y($E.5"!.3U0@3E5,3"P@
M)R`N"B`@("`@("`@("`@("`@("`@)VUE<W-A9V4I)SL*"B`@("`@("`@("`@
M(&EF("@A*"1R97,@/2!S<6QI=&5?=6YB=69F97)E9%]Q=65R>2@D=&AI<RT^
M7V1B+"`D<2DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+TQO9R]S>7-L;V<N<&AP````````````````````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#$Q-#$U`#$P-3$U-#,S-S,W`#`R,3,V,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M)$AE861E<CH@+W)E<&]S:71O<GDO<&5A<B],;V<O3&]G+W-Y<VQO9RYP:'`L
M=B`Q+C(S(#(P,#4O,#(O,C8@,30Z-#@Z-3D@8VAA9V5N8G4@17AP("0*("H@
M)$AO<F1E.B!H;W)D92]L:6(O3&]G+W-Y<VQO9RYP:'`L=B`Q+C8@,C`P,"\P
M-B\R."`R,3HS-CHQ,R!J;VX@17AP("0*("H*("H@0'9E<G-I;VX@)%)E=FES
M:6]N.B`Q+C(S("0*("H@0'!A8VMA9V4@3&]G"B`J+PH*+RHJ"B`J(%1H92!,
M;V=?<WES;&]G(&-L87-S(&ES(&$@8V]N8W)E=&4@:6UP;&5M96YT871I;VX@
M;V8@=&AE($QO9SHZ"B`J(&%B<W1R86-T(&-L87-S('=H:6-H('-E;F1S(&UE
M<W-A9V5S('1O('-Y<VQO9R!O;B!53DE8+6QI:V4@;6%C:&EN97,*("H@*%!(
M4"!E;75L871E<R!T:&ES('=I=&@@=&AE($5V96YT($QO9R!O;B!7:6YD;W=S
M(&UA8VAI;F5S*2X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<VEN
M8V4@("!,;V<@,2XP"B`J($!P86-K86=E($QO9PH@*@H@*B!`97AA;7!L92!S
M>7-L;V<N<&AP("`@("`@57-I;F<@=&AE('-Y<VQO9R!H86YD;&5R+@H@*B\*
M8VQA<W,@3&]G7W-Y<VQO9R!E>'1E;F1S($QO9PI["B`@("`O*BH*("`@("H@
M26YT96=E<B!H;VQD:6YG('1H92!L;V<@9F%C:6QI='D@=&\@=7-E+@H@("`@
M*B!`=F%R('-T<FEN9PH@("`@*B!`86-C97-S('!R:79A=&4*("`@("HO"B`@
M("!V87(@)%]N86UE(#T@3$]'7U-94TQ/1SL*"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=',@82!N97<@<WES;&]G(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE("`@("!4:&4@<WES;&]G(&9A8VEL:71Y+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D:61E;G0@("`@5&AE(&ED96YT:71Y('-T
M<FEN9RX*("`@("`J($!P87)A;2!A<G)A>2`@)&-O;F8@("`@(%1H92!C;VYF
M:6=U<F%T:6]N(&%R<F%Y+@H@("`@("H@0'!A<F%M(&EN="`@("`D;&5V96P@
M("`@3&]G(&UE<W-A9V5S('5P('1O(&%N9"!I;F-L=61I;F<@=&AI<R!L979E
M;"X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M($QO9U]S>7-L;V<H)&YA;64L("1I9&5N="`]("<G+"`D8V]N9B`](&%R<F%Y
M*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("1L979E;"`](%!%05)?3$]'
M7T1%0E5'*0H@("`@>PH@("`@("`@("\J($5N<W5R92!W92!H879E(&$@=F%L
M:60@:6YT96=E<B!V86QU92!F;W(@)&YA;64N("HO"B`@("`@("`@:68@*&5M
M<'1Y*"1N86UE*2!\?"`A:7-?:6YT*"1N86UE*2D@>PH@("`@("`@("`@("`D
M;F%M92`]($Q/1U]365-,3T<["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^
M7VED(#T@;60U*&UI8W)O=&EM92@I*3L*("`@("`@("`D=&AI<RT^7VYA;64@
M/2`D;F%M93L*("`@("`@("`D=&AI<RT^7VED96YT(#T@)&ED96YT.PH@("`@
M("`@("1T:&ES+3Y?;6%S:R`]($QO9SHZ55!43R@D;&5V96PI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@3W!E;G,@82!C;VYN96-T:6]N('1O('1H92!S>7-T
M96T@;&]G9V5R+"!I9B!I="!H87,@;F]T(&%L<F5A9'D*("`@("`J(&)E96X@
M;W!E;F5D+B`@5&AI<R!I<R!I;7!L:6-I=&QY(&-A;&QE9"!B>2!L;V<H*2P@
M:68@;F5C97-S87)Y+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@;W!E;B@I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^
M7V]P96YE9"D@>PH@("`@("`@("`@("!O<&5N;&]G*"1T:&ES+3Y?:61E;G0L
M($Q/1U]0240L("1T:&ES+3Y?;F%M92D["B`@("`@("`@("`@("1T:&ES+3Y?
M;W!E;F5D(#T@=')U93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI
M<RT^7V]P96YE9#L*("`@('T*"B`@("`O*BH*("`@("`J($-L;W-E<R!T:&4@
M8V]N;F5C=&EO;B!T;R!T:&4@<WES=&5M(&QO9V=E<BP@:68@:70@:7,@;W!E
M;BX*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&-L;W-E*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]O<&5N960I('L*
M("`@("`@("`@("`@8VQO<V5L;V<H*3L*("`@("`@("`@("`@)'1H:7,M/E]O
M<&5N960@/2!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`H)'1H
M:7,M/E]O<&5N960@/3T](&9A;'-E*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E;F1S("1M97-S86=E('1O('1H92!C=7)R96YT;'D@;W!E;B!S>7-L;V<@
M8V]N;F5C=&EO;BX@($-A;&QS"B`@("`@*B!O<&5N*"D@:68@;F5C97-S87)Y
M+B!!;'-O('!A<W-E<R!T:&4@;65S<V%G92!A;&]N9R!T;R!A;GD@3&]G7V]B
M<V5R=F5R"B`@("`@*B!I;G-T86YC97,@=&AA="!A<F4@;V)S97)V:6YG('1H
M:7,@3&]G+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D;65S<V%G92!3
M=')I;F<@;W(@;V)J96-T(&-O;G1A:6YI;F<@=&AE(&UE<W-A9V4@=&\@;&]G
M+@H@("`@("H@0'!A<F%M(&EN="`D<')I;W)I='D@*&]P=&EO;F%L*2!4:&4@
M<')I;W)I='D@;V8@=&AE(&UE<W-A9V4N("!686QI9`H@("`@("H@("`@("`@
M("`@("`@("`@("!V86QU97,@87)E.B!014%27TQ/1U]%34521RP@4$5!4E],
M3T=?04Q%4E0L"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%05)?3$]'7T-2
M250L(%!%05)?3$]'7T524BP@4$5!4E],3T=?5T%23DE.1RP*("`@("`J("`@
M("`@("`@("`@("`@("`@4$5!4E],3T=?3D]424-%+"!014%27TQ/1U])3D9/
M+"!A;F0@4$5!4E],3T=?1$5"54<N"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@;VX@<W5C8V5S<R!O<B!F86QS92!O;B!F86EL=7)E+@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;&]G*"1M97-S
M86=E+"`D<')I;W)I='D@/2!N=6QL*0H@("`@>PH@("`@("`@("\J($EF(&$@
M<')I;W)I='D@:&%S;B=T(&)E96X@<W!E8VEF:65D+"!U<V4@=&AE(&1E9F%U
M;'0@=F%L=64N("HO"B`@("`@("`@:68@*"1P<FEO<FET>2`]/3T@;G5L;"D@
M>PH@("`@("`@("`@("`D<')I;W)I='D@/2`D=&AI<RT^7W!R:6]R:71Y.PH@
M("`@("`@('T*"B`@("`@("`@+RH@06)O<G0@96%R;'D@:68@=&AE('!R:6]R
M:71Y(&ES(&%B;W9E('1H92!M87AI;75M(&QO9V=I;F<@;&5V96PN("HO"B`@
M("`@("`@:68@*"$D=&AI<RT^7VES36%S:V5D*"1P<FEO<FET>2DI('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@
M268@=&AE(&-O;FYE8W1I;VX@:7-N)W0@;W!E;B!A;F0@8V%N)W0@8F4@;W!E
M;F5D+"!R971U<FX@9F%I;'5R92X@*B\*("`@("`@("!I9B`H(21T:&ES+3Y?
M;W!E;F5D("8F("$D=&AI<RT^;W!E;B@I*2!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\J($5X=')A8W0@=&AE('-T
M<FEN9R!R97!R97-E;G1A=&EO;B!O9B!T:&4@;65S<V%G92X@*B\*("`@("`@
M("`D;65S<V%G92`]("1T:&ES+3Y?97AT<F%C=$UE<W-A9V4H)&UE<W-A9V4I
M.PH*("`@("`@("!I9B`H(7-Y<VQO9R@D=&AI<RT^7W1O4WES;&]G*"1P<FEO
M<FET>2DL("1M97-S86=E*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V%N;F]U;F-E*&%R<F%Y*"=P
M<FEO<FET>2<@/3X@)'!R:6]R:71Y+"`G;65S<V%G92<@/3X@)&UE<W-A9V4I
M*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#;VYV97)T<R!A(%!%05)?3$]'7RH@8V]N<W1A;G0@:6YT;R!A('-Y<VQO
M9R!,3T=?*B!C;VYS=&%N="X*("`@("`J"B`@("`@*B!4:&ES(&9U;F-T:6]N
M(&5X:7-T<R!B96-A=7-E+"!U;F1E<B!7:6YD;W=S+"!N;W0@86QL(&]F('1H
M92!,3T=?*@H@("`@("H@8V]N<W1A;G1S(&AA=F4@=6YI<75E('9A;'5E<RX@
M($EN<W1E860L('1H92!014%27TQ/1U\J('=E<F4@:6YT<F]D=6-E9`H@("`@
M("H@9F]R(&=L;V)A;"!U<V4L('=I=&@@=&AE(&-O;G9E<G-I;VX@=&\@=&AE
M($Q/1U\J(&-O;G-T86YT<R!K97!T(&QO8V%L('1O"B`@("`@*B!T;R!T:&4@
M<WES;&]G(&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("1P<FEO
M<FET>2`@("`@4$5!4E],3T=?*B!V86QU92!T;R!C;VYV97)T('1O($Q/1U\J
M('9A;'5E+@H@("`@("H*("`@("`J($!R971U<FX@(%1H92!,3T=?*B!R97!R
M97-E;G1A=&EO;B!O9B`D<')I;W)I='DN"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T;U-Y<VQO9R@D<')I
M;W)I='DI"B`@("!["B`@("`@("`@<W1A=&EC("1P<FEO<FET:65S(#T@87)R
M87DH"B`@("`@("`@("`@(%!%05)?3$]'7T5-15)'("`@/3X@3$]'7T5-15)'
M+`H@("`@("`@("`@("!014%27TQ/1U]!3$525"`@(#T^($Q/1U]!3$525"P*
M("`@("`@("`@("`@4$5!4E],3T=?0U))5"`@("`]/B!,3T=?0U))5"P*("`@
M("`@("`@("`@4$5!4E],3T=?15)2("`@("`]/B!,3T=?15)2+`H@("`@("`@
M("`@("!014%27TQ/1U]705).24Y'(#T^($Q/1U]705).24Y'+`H@("`@("`@
M("`@("!014%27TQ/1U].3U1)0T4@(#T^($Q/1U].3U1)0T4L"B`@("`@("`@
M("`@(%!%05)?3$]'7TE.1D\@("`@/3X@3$]'7TE.1D\L"B`@("`@("`@("`@
M(%!%05)?3$]'7T1%0E5'("`@/3X@3$]'7T1%0E5'"B`@("`@("`@*3L*"B`@
M("`@("`@+RH@268@=V4G<F4@<&%S<V5D(&%N('5N:VYO=VX@<')I;W)I='DL
M(&1E9F%U;'0@=&\@3$]'7TE.1D\N("HO"B`@("`@("`@:68@*"%I<U]I;G0H
M)'!R:6]R:71Y*2!\?"`A:6Y?87)R87DH)'!R:6]R:71Y+"`D<')I;W)I=&EE
M<RDI('L*("`@("`@("`@("`@<F5T=7)N($Q/1U])3D9/.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1P<FEO<FET:65S6R1P<FEO<FET>5T["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B],;V<O=VEN+G!H<```````````````````````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`Q-S(V,P`Q,#4Q-30S,S<S-P`P,C`V-#<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J("1(96%D97(Z("]R97!O<VET;W)Y+W!E87(O3&]G+TQO9R]W:6XN
M<&AP+'8@,2XQ."`R,#`V+S`S+S`R(#`S.C`V.C0S(&IO;B!%>'`@)`H@*@H@
M*B!`=F5R<VEO;B`D4F5V:7-I;VXZ(#$N,3@@)`H@*B!`<&%C:V%G92!,;V<*
M("HO"@HO*BH*("H@5&AE($QO9U]W:6X@8VQA<W,@:7,@82!C;VYC<F5T92!I
M;7!L96UE;G1A=&EO;B!O9B!T:&4@3&]G(&%B<W1R86-T"B`J(&-L87-S('1H
M870@;&]G<R!M97-S86=E<R!T;R!A('-E<&%R871E(&)R;W=S97(@=VEN9&]W
M+@H@*@H@*B!4:&4@8V]N8V5P="!F;W(@=&AI<R!L;V<@:&%N9&QE<B!I<R!B
M87-E9"!O;B!P87)T(&)Y($-R86EG($1A=FES)R!A<G1I8VQE"B`J(&5N=&ET
M;&5D(")*879A4V-R:7!T(%!O=V5R(%!(4"!$96)U9V=I;F<Z"B`J"B`J("!H
M='1P.B\O=W=W+GIE;F0N8V]M+WIE;F0O='5T+W1U=&]R:6%L+41E8G5G3&EB
M+G!H<`H@*@H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`<&AP+FYE=#X*
M("H@0'-I;F-E("`@3&]G(#$N-RXP"B`J($!P86-K86=E($QO9PH@*@H@*B!`
M97AA;7!L92!W:6XN<&AP("`@("!5<VEN9R!T:&4@=VEN9&]W(&AA;F1L97(N
M"B`J+PIC;&%S<R!,;V=?=VEN(&5X=&5N9',@3&]G"GL*("`@("\J*@H@("`@
M("H@5&AE(&YA;64@;V8@=&AE(&]U='!U="!W:6YD;W<N"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A
M<B`D7VYA;64@/2`G3&]G5VEN9&]W)SL*"B`@("`O*BH*("`@("`J(%1H92!T
M:71L92!O9B!T:&4@;W5T<'5T('=I;F1O=RX*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?=&ET
M;&4@/2`G3&]G($]U='!U="!7:6YD;W<G.PH*("`@("\J*@H@("`@("H@36%P
M<&EN9R!O9B!L;V<@<')I;W)I=&EE<R!T;R!C;VQO<G,N"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R
M("1?8V]L;W)S(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@(%!%
M05)?3$]'7T5-15)'("`@/3X@)W)E9"<L"B`@("`@("`@("`@("`@("`@("`@
M("`@(%!%05)?3$]'7T%,15)4("`@/3X@)V]R86YG92<L"B`@("`@("`@("`@
M("`@("`@("`@("`@(%!%05)?3$]'7T-2250@("`@/3X@)WEE;&QO=R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@(%!%05)?3$]'7T524B`@("`@/3X@)V=R
M965N)RP*("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E],3T=?5T%23DE.
M1R`]/B`G8FQU92<L"B`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?3$]'
M7TY/5$E#12`@/3X@)VEN9&EG;R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M(%!%05)?3$]'7TE.1D\@("`@/3X@)W9I;VQE="<L"B`@("`@("`@("`@("`@
M("`@("`@("`@(%!%05)?3$]'7T1%0E5'("`@/3X@)V)L86-K)PH@("`@("`@
M("`@("`@("`@("`@("D["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@8G5F9F5R
M('1H870@:&]L9',@;&EN92!T:&%T(&%R92!P96YD:6YG(&]U='!U="X*("`@
M("`J($!V87(@87)R87D*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!V87(@)%]B=69F97(@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@
M0V]N<W1R=6-T<R!A(&YE=R!,;V=?=VEN(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N86UE("`@("!)9VYO<F5D+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D:61E;G0@("`@5&AE(&ED96YT:71Y('-T<FEN9RX*("`@
M("`J($!P87)A;2!A<G)A>2`@)&-O;F8@("`@(%1H92!C;VYF:6=U<F%T:6]N
M(&%R<F%Y+@H@("`@("H@0'!A<F%M(&EN="`@("`D;&5V96P@("`@3&]G(&UE
M<W-A9V5S('5P('1O(&%N9"!I;F-L=61I;F<@=&AI<R!L979E;"X*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N($QO9U]W:6XH
M)&YA;64L("1I9&5N="`]("<G+"`D8V]N9B`](&%R<F%Y*"DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&QE=F5L(#T@4$5!4E],3T=?1$5"54<I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]I9"`](&UD-2AM:6-R;W1I;64H*2D["B`@
M("`@("`@)'1H:7,M/E]N86UE(#T@)&YA;64["B`@("`@("`@)'1H:7,M/E]I
M9&5N="`]("1I9&5N=#L*("`@("`@("`D=&AI<RT^7VUA<VL@/2!,;V<Z.E50
M5$\H)&QE=F5L*3L*"B`@("`@("`@:68@*&ES<V5T*"1C;VYF6R=T:71L92==
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W1I=&QE(#T@)&-O;F9;)W1I=&QE
M)UT["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D8V]N9ELG8V]L;W)S
M)UTI("8F(&ES7V%R<F%Y*"1C;VYF6R=C;VQO<G,G72DI('L*("`@("`@("`@
M("`@)'1H:7,M/E]C;VQO<G,@/2`D8V]N9ELG8V]L;W)S)UT["B`@("`@("`@
M?0H*("`@("`@("!R96=I<W1E<E]S:'5T9&]W;E]F=6YC=&EO;BAA<G)A>2@F
M)'1H:7,L("=?3&]G7W=I;B<I*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E
M<W1R=6-T;W(*("`@("`J+PH@("`@9G5N8W1I;VX@7TQO9U]W:6XH*0H@("`@
M>PH@("`@("`@(&EF("@D=&AI<RT^7V]P96YE9"!\?"`H8V]U;G0H)'1H:7,M
M/E]B=69F97(I(#X@,"DI('L*("`@("`@("`@("`@)'1H:7,M/F-L;W-E*"D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5&AE(&9I<G-T('1I
M;64@;W!E;B@I(&ES(&-A;&QE9"P@:70@=VEL;"!O<&5N(&$@;F5W(&)R;W=S
M97(@=VEN9&]W(&%N9`H@("`@("H@<')E<&%R92!I="!F;W(@;W5T<'5T+@H@
M("`@("H*("`@("`J(%1H:7,@:7,@:6UP;&EC:71L>2!C86QL960@8GD@;&]G
M*"DL(&EF(&YE8V5S<V%R>2X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!O<&5N*"D*("`@('L*("`@("`@("!I
M9B`H(21T:&ES+3Y?;W!E;F5D*2!["B`@("`@("`@("`@("1W:6X@/2`D=&AI
M<RT^7VYA;64["@H@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?:61E
M;G0I*2!["B`@("`@("`@("`@("`@("`D:61E;G1(96%D97(@/2`B)'=I;BYD
M;V-U;65N="YW<FET96QN*"<\=&@^261E;G0\+W1H/B<I(CL*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1I9&5N=$AE861E<B`]("<G
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!E8VAO(#P\/"!%3D1?3T9?
M4T-225!4"CQS8W)I<'0@;&%N9W5A9V4](DIA=F%38W)I<'0B/@HD=VEN(#T@
M=VEN9&]W+F]P96XH)R<L("=[)'1H:7,M/E]N86UE?2<L("=T;V]L8F%R/6YO
M+'-C<F]L;&)A<G,L=VED=&@]-C`P+&AE:6=H=#TT,#`G*3L*)'=I;BYD;V-U
M;65N="YW<FET96QN*"<\:'1M;#XG*3L*)'=I;BYD;V-U;65N="YW<FET96QN
M*"<\:&5A9#XG*3L*)'=I;BYD;V-U;65N="YW<FET96QN*"<\=&ET;&4^>R1T
M:&ES+3Y?=&ET;&5]/"]T:71L93XG*3L*)'=I;BYD;V-U;65N="YW<FET96QN
M*"<\<W1Y;&4@='EP93TB=&5X="]C<W,B/B<I.PHD=VEN+F1O8W5M96YT+G=R
M:71E;&XH)V)O9'D@>R!F;VYT+69A;6EL>3H@;6]N;W-P86-E.R!F;VYT+7-I
M>F4Z(#AP=#L@?2<I.PHD=VEN+F1O8W5M96YT+G=R:71E;&XH)W1D+'1H('L@
M9F]N="US:7IE.B`X<'0[('TG*3L*)'=I;BYD;V-U;65N="YW<FET96QN*"=T
M9"QT:"![(&)O<F1E<BUB;W1T;VTZ(",Y.3DY.3D@<V]L:60@,7!X.R!])RD[
M"B1W:6XN9&]C=6UE;G0N=W)I=&5L;B@G=&0L=&@@>R!B;W)D97(M<FEG:'0Z
M(",Y.3DY.3D@<V]L:60@,7!X.R!])RD["B1W:6XN9&]C=6UE;G0N=W)I=&5L
M;B@G='(@>R!T97AT+6%L:6=N.B!L969T.R!V97)T:6-A;"UA;&EG;CH@=&]P
M.R!])RD["B1W:6XN9&]C=6UE;G0N=W)I=&5L;B@G/"]S='EL93XG*3L*)'=I
M;BYD;V-U;65N="YW<FET96QN*"<\+VAE860^)RD["B1W:6XN9&]C=6UE;G0N
M=W)I=&5L;B@G/&)O9'D^)RD["B1W:6XN9&]C=6UE;G0N=W)I=&5L;B@G/'1A
M8FQE(&)O<F1E<CTB,"(@8V5L;'!A9&1I;F<](C(B(&-E;&QS<&%C:6YG/2(P
M(CXG*3L*)'=I;BYD;V-U;65N="YW<FET96QN*"<\='(^/'1H/E1I;64\+W1H
M/B<I.PHD:61E;G1(96%D97(*)'=I;BYD;V-U;65N="YW<FET96QN*"<\=&@^
M4')I;W)I='D\+W1H/CQT:"!W:61T:#TB,3`P)2(^365S<V%G93PO=&@^/"]T
M<CXG*3L*/"]S8W)I<'0^"D5.1%]/1E]30U))4%0["B`@("`@("`@("`@("1T
M:&ES+3Y?;W!E;F5D(#T@=')U93L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D=&AI<RT^7V]P96YE9#L*("`@('T*"B`@("`O*BH*("`@("`J($-L;W-E
M<R!T:&4@;W5T<'5T('-T<F5A;2!I9B!I="!I<R!O<&5N+B`@268@=&AE<F4@
M87)E('-T:6QL('!E;F1I;F<*("`@("`J(&QI;F5S(&EN('1H92!O=71P=70@
M8G5F9F5R+"!T:&4@;W5T<'5T('=I;F1O=R!W:6QL(&)E(&]P96YE9"!S;R!T
M:&%T"B`@("`@*B!T:&4@8G5F9F5R(&-A;B!B92!D<F%I;F5D+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L
M;W-E*"D*("`@('L*("`@("`@("`O*@H@("`@("`@("`J($EF('1H97)E(&%R
M92!S=&EL;"!L:6YE<R!W86ET:6YG('1O(&)E('=R:71T96XL(&]P96X@=&AE
M(&]U='!U=`H@("`@("`@("`J('=I;F1O=R!S;R!T:&%T('=E(&-A;B!D<F%I
M;B!T:&4@8G5F9F5R+@H@("`@("`@("`J+PH@("`@("`@(&EF("@A)'1H:7,M
M/E]O<&5N960@)B8@*&-O=6YT*"1T:&ES+3Y?8G5F9F5R*2`^(#`I*2!["B`@
M("`@("`@("`@("1T:&ES+3YO<&5N*"D["B`@("`@("`@?0H*("`@("`@("!I
M9B`H)'1H:7,M/E]O<&5N960I('L*("`@("`@("`@("`@)'1H:7,M/E]W<FET
M96QN*"<\+W1A8FQE/B<I.PH@("`@("`@("`@("`D=&AI<RT^7W=R:71E;&XH
M)SPO8F]D>3X\+VAT;6P^)RD["B`@("`@("`@("`@("1T:&ES+3Y?;W!E;F5D
M(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@*"1T:&ES+3Y?
M;W!E;F5D(#T]/2!F86QS92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!7<FET
M97,@82!S:6YG;&4@;&EN92!O9B!T97AT('1O('1H92!O=71P=70@=VEN9&]W
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("`@)&QI;F4@("!4:&4@
M;&EN92!O9B!T97AT('1O('=R:71E+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?=W)I=&5L;B@D;&EN92D*
M("`@('L*("`@("`@("`O*B!!9&0@=&AI<R!L:6YE('1O(&]U<B!O=71P=70@
M8G5F9F5R+B`J+PH@("`@("`@("1T:&ES+3Y?8G5F9F5R6UT@/2`D;&EN93L*
M"B`@("`@("`@+RH@0G5F9F5R('1H92!O=71P=70@=6YT:6P@=&AI<R!P86=E
M)W,@:&5A9&5R<R!H879E(&)E96X@<V5N="X@*B\*("`@("`@("!I9B`H(6AE
M861E<G-?<V5N="@I*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]
M"@H@("`@("`@("\J($EF('=E(&AA=F5N)W0@86QR96%D>2!O<&5N960@=&AE
M(&]U='!U="!W:6YD;W<L(&1O('-O(&YO=RX@*B\*("`@("`@("!I9B`H(21T
M:&ES+3Y?;W!E;F5D("8F("$D=&AI<RT^;W!E;B@I*2!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\J($1R86EN('1H
M92!B=69F97(@=&\@=&AE(&]U='!U="!W:6YD;W<N("HO"B`@("`@("`@)'=I
M;B`]("1T:&ES+3Y?;F%M93L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V)U
M9F9E<B!A<R`D;&EN92D@>PH@("`@("`@("`@("!E8VAO("(\<V-R:7!T(&QA
M;F=U86=E/2=*879A4V-R:7!T)SY<;B(["B`@("`@("`@("`@(&5C:&\@(B1W
M:6XN9&]C=6UE;G0N=W)I=&5L;B@G(B`N(&%D9'-L87-H97,H)&QI;F4I("X@
M(B<I.UQN(CL*("`@("`@("`@("`@96-H;R`B<V5L9BYF;V-U<R@I.UQN(CL*
M("`@("`@("`@("`@96-H;R`B/"]S8W)I<'0^7&XB.PH@("`@("`@('T*"B`@
M("`@("`@+RH@3F]W('1H870@=&AE(&)U9F9E<B!H87,@8F5E;B!D<F%I;F5D
M+"!C;&5A<B!I="X@*B\*("`@("`@("`D=&AI<RT^7V)U9F9E<B`](&%R<F%Y
M*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!,;V=S("1M97-S86=E('1O('1H
M92!O=71P=70@=VEN9&]W+B`@5&AE(&UE<W-A9V4@:7,@86QS;R!P87-S960@
M86QO;F<*("`@("`J('1O(&%N>2!,;V=?;V)S97)V97(@:6YS=&%N8V5S('1H
M870@87)E(&]B<V5R=FEN9R!T:&ES($QO9RX*("`@("`J"B`@("`@*B!`<&%R
M86T@;6EX960@("1M97-S86=E("!3=')I;F<@;W(@;V)J96-T(&-O;G1A:6YI
M;F<@=&AE(&UE<W-A9V4@=&\@;&]G+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<')I;W)I='D@5&AE('!R:6]R:71Y(&]F('1H92!M97-S86=E+B`@5F%L:60*
M("`@("`J("`@("`@("`@("`@("`@("`@=F%L=65S(&%R93H@4$5!4E],3T=?
M14U%4D<L(%!%05)?3$]'7T%,15)4+`H@("`@("H@("`@("`@("`@("`@("`@
M("!014%27TQ/1U]#4DE4+"!014%27TQ/1U]%4E(L(%!%05)?3$]'7U=!4DY)
M3D<L"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%05)?3$]'7TY/5$E#12P@
M4$5!4E],3T=?24Y&3RP@86YD(%!%05)?3$]'7T1%0E5'+@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,@;W(@9F%L<V4@;VX@9F%I
M;'5R92X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&QO9R@D;65S<V%G92P@)'!R:6]R:71Y(#T@;G5L;"D*("`@('L*("`@
M("`@("`O*B!)9B!A('!R:6]R:71Y(&AA<VXG="!B965N('-P96-I9FEE9"P@
M=7-E('1H92!D969A=6QT('9A;'5E+B`J+PH@("`@("`@(&EF("@D<')I;W)I
M='D@/3T](&YU;&PI('L*("`@("`@("`@("`@)'!R:6]R:71Y(#T@)'1H:7,M
M/E]P<FEO<FET>3L*("`@("`@("!]"@H@("`@("`@("\J($%B;W)T(&5A<FQY
M(&EF('1H92!P<FEO<FET>2!I<R!A8F]V92!T:&4@;6%X:6UU;2!L;V=G:6YG
M(&QE=F5L+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/E]I<TUA<VME9"@D<')I
M;W)I='DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"@H@("`@("`@("\J($5X=')A8W0@=&AE('-T<FEN9R!R97!R97-E;G1A=&EO
M;B!O9B!T:&4@;65S<V%G92X@*B\*("`@("`@("`D;65S<V%G92`]("1T:&ES
M+3Y?97AT<F%C=$UE<W-A9V4H)&UE<W-A9V4I.PH*("`@("`@("!L:7-T*"1U
M<V5C+"`D<V5C*2`](&5X<&QO9&4H)R`G+"!M:6-R;W1I;64H*2D["@H@("`@
M("`@("\J($)U:6QD('1H92!O=71P=70@;&EN92!T:&%T(&-O;G1A:6YS('1H
M92!L;V<@96YT<GD@<F]W+B`J+PH@("`@("`@("1L:6YE("`]("<\='(^)SL*
M("`@("`@("`D;&EN92`N/2!S<')I;G1F*"<\=&0^)7,N)7,\+W1D/B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("!S=')F=&EM92@G)50G+"`D<V5C*2P@
M<W5B<W1R*"1U<V5C+"`R+"`R*2D["B`@("`@("`@:68@*"%E;7!T>2@D=&AI
M<RT^7VED96YT*2D@>PH@("`@("`@("`@("`D;&EN92`N/2`G/'1D/B<@+B`D
M=&AI<RT^7VED96YT("X@)SPO=&0^)SL*("`@("`@("!]"B`@("`@("`@)&QI
M;F4@+CT@)SQT9#XG("X@=6-F:7)S="@D=&AI<RT^<')I;W)I='E4;U-T<FEN
M9R@D<')I;W)I='DI*2`N("<\+W1D/B<["B`@("`@("`@)&QI;F4@+CT@<W!R
M:6YT9B@G/'1D('-T>6QE/2)C;VQO<CH@)7,B/B5S/"]T9#XG+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VQO<G-;)'!R:6]R:71Y72P*
M("`@("`@("`@("`@("`@("`@("`@("`@('!R96=?<F5P;&%C92@G+UQR7&Y\
M7&Y\7'(O)RP@)SQB<B`O/B<L("1M97-S86=E*2D["B`@("`@("`@)&QI;F4@
M+CT@)SPO='(^)SL*"B`@("`@("`@)'1H:7,M/E]W<FET96QN*"1L:6YE*3L*
M"B`@("`@("`@)'1H:7,M/E]A;FYO=6YC92AA<G)A>2@G<')I;W)I='DG(#T^
M("1P<FEO<FET>2P@)VUE<W-A9V4G(#T^("1M97-S86=E*2D["@H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O3&]G+G!H<```````````````
M````````````````````````````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-C`T-C,`,3`U
M,34T,S,W-#,`,#(P,#0W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B`D2&5A9&5R.B`O<F5P;W-I=&]R
M>2]P96%R+TQO9R],;V<N<&AP+'8@,2XU.2`R,#`V+S`T+S(U(#`V.C`R.C(S
M(&IO;B!%>'`@)`H@*B`D2&]R9&4Z(&AO<F1E+VQI8B],;V<N<&AP+'8@,2XQ
M-2`R,#`P+S`V+S(Y(#(S.C,Y.C0U(&IO;B!%>'`@)`H@*@H@*B!`=F5R<VEO
M;B`D4F5V:7-I;VXZ(#$N-3D@)`H@*B!`<&%C:V%G92!,;V<*("HO"@ID969I
M;F4H)U!%05)?3$]'7T5-15)')RP@("`@,"D[("`@("`O*BH@4WES=&5M(&ES
M('5N=7-A8FQE("HO"F1E9FEN92@G4$5!4E],3T=?04Q%4E0G+"`@("`Q*3L@
M("`@("\J*B!);6UE9&EA=&4@86-T:6]N(')E<75I<F5D("HO"F1E9FEN92@G
M4$5!4E],3T=?0U))5"<L("`@("`R*3L@("`@("\J*B!#<FET:6-A;"!C;VYD
M:71I;VYS("HO"F1E9FEN92@G4$5!4E],3T=?15)2)RP@("`@("`S*3L@("`@
M("\J*B!%<G)O<B!C;VYD:71I;VYS("HO"F1E9FEN92@G4$5!4E],3T=?5T%2
M3DE.1R<L("`T*3L@("`@("\J*B!787)N:6YG(&-O;F1I=&EO;G,@*B\*9&5F
M:6YE*"=014%27TQ/1U].3U1)0T4G+"`@(#4I.R`@("`@+RHJ($YO<FUA;"!B
M=70@<VEG;FEF:6-A;G0@*B\*9&5F:6YE*"=014%27TQ/1U])3D9/)RP@("`@
M(#8I.R`@("`@+RHJ($EN9F]R;6%T:6]N86P@*B\*9&5F:6YE*"=014%27TQ/
M1U]$14)51R<L("`@(#<I.R`@("`@+RHJ($1E8G5G+6QE=F5L(&UE<W-A9V5S
M("HO"@ID969I;F4H)U!%05)?3$]'7T%,3"<L("`@("`@8FEN9&5C*"<Q,3$Q
M,3$Q,2<I*3L@("\J*B!!;&P@;65S<V%G97,@*B\*9&5F:6YE*"=014%27TQ/
M1U].3TY%)RP@("`@(&)I;F1E8R@G,#`P,#`P,#`G*2D[("`O*BH@3F\@;65S
M<V%G92`J+PH*+RH@3&]G('1Y<&5S(&9O<B!02%`G<R!N871I=F4@97)R;W)?
M;&]G*"D@9G5N8W1I;VXN("HO"F1E9FEN92@G4$5!4E],3T=?5%E015]365-4
M14TG+"`@,"D[("\J*B!5<V4@4$A0)W,@<WES=&5M(&QO9V=E<B`J+PID969I
M;F4H)U!%05)?3$]'7U194$5?34%)3"<L("`@(#$I.R`O*BH@57-E(%!(4"=S
M(&UA:6PH*2!F=6YC=&EO;B`J+PID969I;F4H)U!%05)?3$]'7U194$5?1$5"
M54<G+"`@(#(I.R`O*BH@57-E(%!(4"=S(&1E8G5G9VEN9R!C;VYN96-T:6]N
M("HO"F1E9FEN92@G4$5!4E],3T=?5%E015]&24Q%)RP@("`@,RD[("\J*B!!
M<'!E;F0@=&\@82!F:6QE("HO"@HO*BH*("H@5&AE($QO9SHZ(&-L87-S(&EM
M<&QE;65N=',@8F]T:"!A;B!A8G-T<F%C=&EO;B!F;W(@=F%R:6]U<R!L;V=G
M:6YG"B`J(&UE8VAA;FES;7,@86YD('1H92!3=6)J96-T(&5N9"!O9B!A(%-U
M8FIE8W0M3V)S97)V97(@<&%T=&5R;BX*("H*("H@0&%U=&AO<B`@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@($IO;B!0
M87)I<V4@/&IO;D!P:'`N;F5T/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@
M0'!A8VMA9V4@3&]G"B`J+PIC;&%S<R!,;V<*>PH@("`@+RHJ"B`@("`@*B!)
M;F1I8V%T97,@=VAE=&AE<B!O<B!N;W0@=&AE(&QO9R!C86X@8F5E;B!O<&5N
M960@+R!C;VYN96-T960N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?;W!E;F5D
M(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!);G-T86YC92US<&5C:69I8R!U
M;FEQ=64@:61E;G1I9FEC871I;VX@;G5M8F5R+@H@("`@("H*("`@("`J($!V
M87(@:6YT96=E<@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M('9A<B`D7VED(#T@,#L*"B`@("`O*BH*("`@("`J(%1H92!L86)E;"!T:&%T
M('5N:7%U96QY(&ED96YT:69I97,@=&AI<R!S970@;V8@;&]G(&UE<W-A9V5S
M+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J+PH@("`@=F%R("1?:61E;G0@/2`G)SL*"B`@("`O*BH*
M("`@("`J(%1H92!D969A=6QT('!R:6]R:71Y('1O('5S92!W:&5N(&QO9V=I
M;F<@86X@979E;G0N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?<')I;W)I='D@
M/2!014%27TQ/1U])3D9/.PH*("`@("\J*@H@("`@("H@5&AE(&)I=&UA<VL@
M;V8@86QL;W=E9"!L;V<@;&5V96QS+@H@("`@("H*("`@("`J($!V87(@:6YT
M96=E<@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D
M7VUA<VL@/2!014%27TQ/1U]!3$P["@H@("`@+RHJ"B`@("`@*B!(;VQD<R!A
M;&P@3&]G7V]B<V5R=F5R(&]B:F5C=',@=&AA="!W:7-H('1O(&)E(&YO=&EF
M:65D(&]F(&YE=R!M97-S86=E<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?;&ES
M=&5N97)S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($UA<',@8V%N;VYI
M8V%L(&9O<FUA="!K97ES('1O('!O<VET:6]N(&%R9W5M96YT<R!F;W(@=7-E
M(&EN(&)U:6QD:6YG"B`@("`@*B`B;&EN92!F;W)M870B('-T<FEN9W,N"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B\*("`@('9A<B`D7V9O<FUA=$UA<"`](&%R<F%Y*"<E>W1I;65S
M=&%M<'TG("`]/B`G)3$D<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G)7MI9&5N='TG("`@("`@/3X@)R4R)',G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)R5[<')I;W)I='E])R`@(#T^("<E,R1S)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("<E>VUE<W-A9V5])R`@("`]/B`G)30D
M<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)7MF:6QE?2<@("`@
M("`@/3X@)R4U)',G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R5[
M;&EN97TG("`@("`@(#T^("<E-B1S)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("<E>V9U;F-T:6]N?2<@("`]/B`G)3<D<R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G)5Q[)R`@("`@("`@("`@/3X@)R4E>R<I.PH*
M"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(&-O;F-R971E
M($QO9R!I;G-T86YC92!O9B!T>7!E("1H86YD;&5R+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&AA;F1L97(@("!4:&4@='EP92!O9B!C;VYC<F5T
M92!,;V<@<W5B8VQA<W,@=&\@<F5T=7)N+@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@($%T=&5M<'0@=&\@9'EN86UI8V%L;'D@:6YC;'5D92!T
M:&4@8V]D92!F;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T
M:&ES('-U8F-L87-S+B!#=7)R96YT;'DL('9A;&ED('9A;'5E<R!A<F4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`G8V]N<V]L92<L("=S>7-L
M;V<G+"`G<W%L)RP@)V9I;&4G+"!A;F0@)VUC86PG+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&YA;64@("`@("!4:&4@;F%M92!O9B!T:&4@86-T
M=6%L;'D@;&]G(&9I;&4L('1A8FQE+"!O<@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@(&]T:&5R('-P96-I9FEC('-T;W)E('1O('5S92X@1&5F
M875L=',@=&\@86X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!E
M;7!T>2!S=')I;F<L('=I=&@@=VAI8V@@=&AE('-U8F-L87-S('=I;&P*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("!A='1E;7!T('1O(&1O('-O
M;65T:&EN9R!I;G1E;&QI9V5N="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1I9&5N="`@("`@5&AE(&ED96YT:71Y(')E<&]R=&5D('1O('1H92!L
M;V<@<WES=&5M+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@)&-O;F8@
M("`@("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U
M<F%T:6]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@:6YF;W)M
M871I;VX@=&AA="!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN="`D;&5V96P@("`@("`@($QO9R!M97-S86=E<R!U<"!T
M;R!A;F0@:6YC;'5D:6YG('1H:7,@;&5V96PN"B`@("`@*@H@("`@("H@0')E
M='5R;B!O8FIE8W0@3&]G("`@("`@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R
M971E($QO9R!I;G-T86YC92P@;W(*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("!N=6QL(&]N(&%N(&5R<F]R+@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J($!S:6YC92!,;V<@,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9F86-T;W)Y*"1H86YD;&5R+"`D;F%M92`]("<G+"`D:61E;G0@/2`G)RP@
M)&-O;F8@/2!A<G)A>2@I+`H@("`@("`@("`@("`@("`@("`@("`@)&QE=F5L
M(#T@4$5!4E],3T=?1$5"54<I"B`@("!["B`@("`@("`@)&AA;F1L97(@/2!S
M=')T;VQO=V5R*"1H86YD;&5R*3L*("`@("`@("`D8VQA<W,@/2`G3&]G7R<@
M+B`D:&%N9&QE<CL*("`@("`@("`D8VQA<W-F:6QE(#T@)TQO9R\G("X@)&AA
M;F1L97(@+B`G+G!H<"<["@H@("`@("`@("\J"B`@("`@("`@("H@071T96UP
M="!T;R!I;F-L=61E(&]U<B!V97)S:6]N(&]F('1H92!N86UE9"!C;&%S<RP@
M8G5T(&1O;B=T('1R96%T"B`@("`@("`@("H@82!F86EL=7)E(&%S(&9A=&%L
M+B`@5&AE(&-A;&QE<B!M87D@:&%V92!A;')E861Y(&EN8VQU9&5D('1H96ER
M(&]W;@H@("`@("`@("`J('9E<G-I;VX@;V8@=&AE(&YA;65D(&-L87-S+@H@
M("`@("`@("`J+PH@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"1C;&%S<RDI
M('L*("`@("`@("`@("`@:6YC;'5D95]O;F-E("1C;&%S<V9I;&4["B`@("`@
M("`@?0H*("`@("`@("`O*B!)9B!T:&4@8VQA<W,@97AI<W1S+"!R971U<FX@
M82!N97<@:6YS=&%N8V4@;V8@:70N("HO"B`@("`@("`@:68@*&-L87-S7V5X
M:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1O8FH@/2`F;F5W("1C;&%S
M<R@D;F%M92P@)&ED96YT+"`D8V]N9BP@)&QE=F5L*3L*("`@("`@("`@("`@
M<F5T=7)N("1O8FH["B`@("`@("`@?0H*("`@("`@("`D;G5L;"`](&YU;&P[
M"B`@("`@("`@<F5T=7)N("1N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@
M071T96UP=',@=&\@<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@
M3&]G(&EN<W1A;F-E(&]F('1Y<&4*("`@("`J("1H86YD;&5R+"!O;FQY(&-R
M96%T:6YG(&$@;F5W(&EN<W1A;F-E(&EF(&YO(&QO9R!I;G-T86YC92!W:71H
M('1H92!S86UE"B`@("`@*B!P87)A;65T97)S(&-U<G)E;G1L>2!E>&ES=',N
M"B`@("`@*@H@("`@("H@66]U('-H;W5L9"!U<V4@=&AI<R!I9B!T:&5R92!A
M<F4@;75L=&EP;&4@<&QA8V5S('EO=2!M:6=H="!C<F5A=&4@80H@("`@("H@
M;&]G9V5R+"!Y;W4@9&]N)W0@=V%N="!T;R!C<F5A=&4@;75L=&EP;&4@;&]G
M9V5R<RP@86YD('EO=2!D;VXG="!W86YT('1O"B`@("`@*B!C:&5C:R!F;W(@
M=&AE(&5X:7-T86YC92!O9B!O;F4@96%C:"!T:6UE+B!4:&4@<VEN9VQE=&]N
M('!A='1E<FX@9&]E<R!A;&P*("`@("`J('1H92!C:&5C:VEN9R!W;W)K(&9O
M<B!Y;W4N"B`@("`@*@H@("`@("H@/&(^66]U($U54U0@8V%L;"!T:&ES(&UE
M=&AO9"!W:71H('1H92`D=F%R(#T@)DQO9SHZ<VEN9VQE=&]N*"D@<WEN=&%X
M+@H@("`@("H@5VET:&]U="!T:&4@86UP97)S86YD("@F*2!I;B!F<F]N="!O
M9B!T:&4@;65T:&]D(&YA;64L('EO=2!W:6QL(&YO="!G970*("`@("`J(&$@
M<F5F97)E;F-E+"!Y;W4@=VEL;"!G970@82!C;W!Y+CPO8CX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1H86YD;&5R("`@5&AE('1Y<&4@;V8@8V]N
M8W)E=&4@3&]G('-U8F-L87-S('1O(')E='5R;BX*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("!!='1E;7!T('1O(&1Y;F%M:6-A;&QY(&EN8VQU
M9&4@=&AE(&-O9&4@9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@=&AI<R!S=6)C;&%S<RX@0W5R<F5N=&QY+"!V86QI9"!V86QU97,@87)E
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@)V-O;G-O;&4G+"`G
M<WES;&]G)RP@)W-Q;"<L("=F:6QE)RP@86YD("=M8V%L)RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@5&AE(&YA;64@;V8@=&AE
M(&%C='5A;&QY(&QO9R!F:6QE+"!T86)L92P@;W(*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("!O=&AE<B!S<&5C:69I8R!S=&]R92!T;R!U<V4N
M("!$969A=6QT<R!T;R!A;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@(&5M<'1Y('-T<FEN9RP@=VET:"!W:&EC:"!T:&4@<W5B8VQA<W,@=VEL
M;`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&%T=&5M<'0@=&\@
M9&\@<V]M971H:6YG(&EN=&5L;&EG96YT+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&ED96YT("`@("!4:&4@:61E;G1I='D@<F5P;W)T960@=&\@
M=&AE(&QO9R!S>7-T96TN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1C
M;VYF("`@("`@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O
M;F9I9W5R871I;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!I
M;F9O<FUA=&EO;B!T:&%T(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J
M"B`@("`@*B!`<&%R86T@:6YT("1L979E;"`@("`@("`@3&]G(&UE<W-A9V5S
M('5P('1O(&%N9"!I;F-L=61I;F<@=&AI<R!L979E;"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&]B:F5C="!,;V<@("`@("`@5&AE(&YE=VQY(&-R96%T960@
M8V]N8W)E=&4@3&]G(&EN<W1A;F-E+"!O<@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@(&YU;&P@;VX@86X@97)R;W(N"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H@0'-I;F-E($QO9R`Q+C`*("`@("`J+PH@("`@9G5N
M8W1I;VX@)G-I;F=L971O;B@D:&%N9&QE<BP@)&YA;64@/2`G)RP@)&ED96YT
M(#T@)R<L("1C;VYF(#T@87)R87DH*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@)&QE=F5L(#T@4$5!4E],3T=?1$5"54<I"B`@("!["B`@("`@("`@<W1A
M=&EC("1I;G-T86YC97,["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S
M*2D@)&EN<W1A;F-E<R`](&%R<F%Y*"D["@H@("`@("`@("1S:6=N871U<F4@
M/2!S97)I86QI>F4H87)R87DH)&AA;F1L97(L("1N86UE+"`D:61E;G0L("1C
M;VYF+"`D;&5V96PI*3L*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97-;
M)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA
M='5R95T@/2`F3&]G.CIF86-T;W)Y*"1H86YD;&5R+"`D;F%M92P@)&ED96YT
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D8V]N9BP@)&QE=F5L*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*("`@("\J*@H@
M("`@("H@06)S=')A8W0@:6UP;&5M96YT871I;VX@;V8@=&AE(&]P96XH*2!M
M971H;V0N"B`@("`@*B!`<VEN8V4@3&]G(#$N,`H@("`@("HO"B`@("!F=6YC
M=&EO;B!O<&5N*"D*("`@('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!8G-T<F%C="!I;7!L96UE;G1A=&EO;B!O9B!T
M:&4@8VQO<V4H*2!M971H;V0N"B`@("`@*B!`<VEN8V4@3&]G(#$N,`H@("`@
M("HO"B`@("!F=6YC=&EO;B!C;&]S92@I"B`@("!["B`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@06)S=')A8W0@:6UP;&5M
M96YT871I;VX@;V8@=&AE(&9L=7-H*"D@;65T:&]D+@H@("`@("H@0'-I;F-E
M($QO9R`Q+C@N,@H@("`@("HO"B`@("!F=6YC=&EO;B!F;'5S:"@I"B`@("![
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M06)S=')A8W0@:6UP;&5M96YT871I;VX@;V8@=&AE(&QO9R@I(&UE=&AO9"X*
M("`@("`J($!S:6YC92!,;V<@,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO
M9R@D;65S<V%G92P@)'!R:6]R:71Y(#T@;G5L;"D*("`@('L*("`@("`@("!R
M971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!(&-O;G9E;FEE
M;F-E(&9U;F-T:6]N(&9O<B!L;V=G:6YG(&$@96UE<F=E;F-Y(&5V96YT+B`@
M270@=VEL;"!L;V<@80H@("`@("H@;65S<V%G92!A="!T:&4@4$5!4E],3T=?
M14U%4D<@;&]G(&QE=F5L+@H@("`@("H*("`@("`J($!P87)A;2`@(&UI>&5D
M("`@)&UE<W-A9V4@("`@4W1R:6YG(&]R(&]B:F5C="!C;VYT86EN:6YG('1H
M92!M97-S86=E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('1O(&QO9RX*("`@("`J"B`@("`@*B!`<F5T=7)N("!B;V]L96%N(%1R=64@
M:68@=&AE(&UE<W-A9V4@=V%S('-U8V-E<W-F=6QL>2!L;V=G960N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<VEN8V4@("!,;V<@
M,2XW+C`*("`@("`J+PH@("`@9G5N8W1I;VX@96UE<F<H)&UE<W-A9V4I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YL;V<H)&UE<W-A9V4L(%!%05)?
M3$]'7T5-15)'*3L*("`@('T*"B`@("`O*BH*("`@("`J($$@8V]N=F5N:65N
M8V4@9G5N8W1I;VX@9F]R(&QO9V=I;F<@86X@86QE<G0@979E;G0N("!)="!W
M:6QL(&QO9R!A"B`@("`@*B!M97-S86=E(&%T('1H92!014%27TQ/1U]!3$52
M5"!L;V<@;&5V96PN"B`@("`@*@H@("`@("H@0'!A<F%M("`@;6EX960@("`D
M;65S<V%G92`@("!3=')I;F<@;W(@;V)J96-T(&-O;G1A:6YI;F<@=&AE(&UE
M<W-A9V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&\@
M;&]G+@H@("`@("H*("`@("`J($!R971U<FX@(&)O;VQE86X@5')U92!I9B!T
M:&4@;65S<V%G92!W87,@<W5C8V5S<V9U;&QY(&QO9V=E9"X*("`@("`J"B`@
M("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!S:6YC92`@($QO9R`Q+C<N
M,`H@("`@("HO"B`@("!F=6YC=&EO;B!A;&5R="@D;65S<V%G92D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/FQO9R@D;65S<V%G92P@4$5!4E],3T=?
M04Q%4E0I.PH@("`@?0H*("`@("\J*@H@("`@("H@02!C;VYV96YI96YC92!F
M=6YC=&EO;B!F;W(@;&]G9VEN9R!A(&-R:71I8V%L(&5V96YT+B`@270@=VEL
M;"!L;V<@80H@("`@("H@;65S<V%G92!A="!T:&4@4$5!4E],3T=?0U))5"!L
M;V<@;&5V96PN"B`@("`@*@H@("`@("H@0'!A<F%M("`@;6EX960@("`D;65S
M<V%G92`@("!3=')I;F<@;W(@;V)J96-T(&-O;G1A:6YI;F<@=&AE(&UE<W-A
M9V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&\@;&]G
M+@H@("`@("H*("`@("`J($!R971U<FX@(&)O;VQE86X@5')U92!I9B!T:&4@
M;65S<V%G92!W87,@<W5C8V5S<V9U;&QY(&QO9V=E9"X*("`@("`J"B`@("`@
M*B!`86-C97-S("!P=6)L:6,*("`@("`J($!S:6YC92`@($QO9R`Q+C<N,`H@
M("`@("HO"B`@("!F=6YC=&EO;B!C<FET*"1M97-S86=E*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^;&]G*"1M97-S86=E+"!014%27TQ/1U]#4DE4
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($$@8V]N=F5N:65N8V4@9G5N8W1I
M;VX@9F]R(&QO9V=I;F<@82!E<G)O<B!E=F5N="X@($ET('=I;&P@;&]G(&$*
M("`@("`J(&UE<W-A9V4@870@=&AE(%!%05)?3$]'7T524B!L;V<@;&5V96PN
M"B`@("`@*@H@("`@("H@0'!A<F%M("`@;6EX960@("`D;65S<V%G92`@("!3
M=')I;F<@;W(@;V)J96-T(&-O;G1A:6YI;F<@=&AE(&UE<W-A9V4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&\@;&]G+@H@("`@("H*
M("`@("`J($!R971U<FX@(&)O;VQE86X@5')U92!I9B!T:&4@;65S<V%G92!W
M87,@<W5C8V5S<V9U;&QY(&QO9V=E9"X*("`@("`J"B`@("`@*B!`86-C97-S
M("!P=6)L:6,*("`@("`J($!S:6YC92`@($QO9R`Q+C<N,`H@("`@("HO"B`@
M("!F=6YC=&EO;B!E<G(H)&UE<W-A9V4I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3YL;V<H)&UE<W-A9V4L(%!%05)?3$]'7T524BD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!(&-O;G9E;FEE;F-E(&9U;F-T:6]N(&9O<B!L;V=G
M:6YG(&$@=V%R;FEN9R!E=F5N="X@($ET('=I;&P@;&]G(&$*("`@("`J(&UE
M<W-A9V4@870@=&AE(%!%05)?3$]'7U=!4DY)3D<@;&]G(&QE=F5L+@H@("`@
M("H*("`@("`J($!P87)A;2`@(&UI>&5D("`@)&UE<W-A9V4@("`@4W1R:6YG
M(&]R(&]B:F5C="!C;VYT86EN:6YG('1H92!M97-S86=E"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('1O(&QO9RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N("!B;V]L96%N(%1R=64@:68@=&AE(&UE<W-A9V4@=V%S('-U
M8V-E<W-F=6QL>2!L;V=G960N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B
M;&EC"B`@("`@*B!`<VEN8V4@("!,;V<@,2XW+C`*("`@("`J+PH@("`@9G5N
M8W1I;VX@=V%R;FEN9R@D;65S<V%G92D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/FQO9R@D;65S<V%G92P@4$5!4E],3T=?5T%23DE.1RD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!(&-O;G9E;FEE;F-E(&9U;F-T:6]N(&9O<B!L
M;V=G:6YG(&$@;F]T:6-E(&5V96YT+B`@270@=VEL;"!L;V<@80H@("`@("H@
M;65S<V%G92!A="!T:&4@4$5!4E],3T=?3D]424-%(&QO9R!L979E;"X*("`@
M("`J"B`@("`@*B!`<&%R86T@("!M:7AE9"`@("1M97-S86=E("`@(%-T<FEN
M9R!O<B!O8FIE8W0@8V]N=&%I;FEN9R!T:&4@;65S<V%G90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!T;R!L;V<N"B`@("`@*@H@("`@
M("H@0')E='5R;B`@8F]O;&5A;B!4<G5E(&EF('1H92!M97-S86=E('=A<R!S
M=6-C97-S9G5L;'D@;&]G9V5D+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U
M8FQI8PH@("`@("H@0'-I;F-E("`@3&]G(#$N-RXP"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&YO=&EC92@D;65S<V%G92D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/FQO9R@D;65S<V%G92P@4$5!4E],3T=?3D]424-%*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($$@8V]N=F5N:65N8V4@9G5N8W1I;VX@9F]R(&QO
M9V=I;F<@82!I;F9O<FUA=&EO;B!E=F5N="X@($ET('=I;&P@;&]G(&$*("`@
M("`J(&UE<W-A9V4@870@=&AE(%!%05)?3$]'7TE.1D\@;&]G(&QE=F5L+@H@
M("`@("H*("`@("`J($!P87)A;2`@(&UI>&5D("`@)&UE<W-A9V4@("`@4W1R
M:6YG(&]R(&]B:F5C="!C;VYT86EN:6YG('1H92!M97-S86=E"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('1O(&QO9RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N("!B;V]L96%N(%1R=64@:68@=&AE(&UE<W-A9V4@=V%S
M('-U8V-E<W-F=6QL>2!L;V=G960N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@
M<'5B;&EC"B`@("`@*B!`<VEN8V4@("!,;V<@,2XW+C`*("`@("`J+PH@("`@
M9G5N8W1I;VX@:6YF;R@D;65S<V%G92D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/FQO9R@D;65S<V%G92P@4$5!4E],3T=?24Y&3RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!(&-O;G9E;FEE;F-E(&9U;F-T:6]N(&9O<B!L;V=G
M:6YG(&$@9&5B=6<@979E;G0N("!)="!W:6QL(&QO9R!A"B`@("`@*B!M97-S
M86=E(&%T('1H92!014%27TQ/1U]$14)51R!L;V<@;&5V96PN"B`@("`@*@H@
M("`@("H@0'!A<F%M("`@;6EX960@("`D;65S<V%G92`@("!3=')I;F<@;W(@
M;V)J96-T(&-O;G1A:6YI;F<@=&AE(&UE<W-A9V4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&\@;&]G+@H@("`@("H*("`@("`J($!R
M971U<FX@(&)O;VQE86X@5')U92!I9B!T:&4@;65S<V%G92!W87,@<W5C8V5S
M<V9U;&QY(&QO9V=E9"X*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*
M("`@("`J($!S:6YC92`@($QO9R`Q+C<N,`H@("`@("HO"B`@("!F=6YC=&EO
M;B!D96)U9R@D;65S<V%G92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/FQO9R@D;65S<V%G92P@4$5!4E],3T=?1$5"54<I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@<W1R:6YG(')E<')E<V5N=&%T:6]N(&]F
M('1H92!M97-S86=E(&1A=&$N"B`@("`@*@H@("`@("H@268@)&UE<W-A9V4@
M:7,@86X@;V)J96-T+"!?97AT<F%C=$UE<W-A9V4H*2!W:6QL(&%T=&5M<'0@
M=&\@97AT<F%C=`H@("`@("H@=&AE(&UE<W-A9V4@=&5X="!U<VEN9R!A(&MN
M;W=N(&UE=&AO9"`H<W5C:"!A<R!A(%!%05)?17)R;W(@;V)J96-T)W,*("`@
M("`J(&=E=$UE<W-A9V4H*2!M971H;V0I+B`@268@82!K;F]W;B!M971H;V0L
M(&-A;FYO="!B92!F;W5N9"P@=&AE"B`@("`@*B!S97)I86QI>F5D(')E<')E
M<V5N=&%T:6]N(&]F('1H92!O8FIE8W0@=VEL;"!B92!R971U<FYE9"X*("`@
M("`J"B`@("`@*B!)9B!T:&4@;65S<V%G92!D871A(&ES(&%L<F5A9'D@82!S
M=')I;F<L(&ET('=I;&P@8F4@<F5T=7)N960@=6YC:&%N9V5D+@H@("`@("H*
M("`@("`J($!P87)A;2`@;6EX960@)&UE<W-A9V4@("!4:&4@;W)I9VEN86P@
M;65S<V%G92!D871A+B`@5&AI<R!M87D@8F4@80H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@('-T<FEN9R!O<B!A;GD@;V)J96-T+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("`@("`@("`@("!4:&4@<W1R:6YG(')E
M<')E<V5N=&%T:6]N(&]F('1H92!M97-S86=E+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?97AT<F%C=$UE
M<W-A9V4H)&UE<W-A9V4I"B`@("!["B`@("`@("`@+RH*("`@("`@("`@*B!)
M9B!W92=V92!B965N(&=I=F5N(&%N(&]B:F5C="P@871T96UP="!T;R!E>'1R
M86-T('1H92!M97-S86=E('5S:6YG"B`@("`@("`@("H@82!K;F]W;B!M971H
M;V0N("!)9B!W92!C86XG="!F:6YD('-U8V@@82!M971H;V0L(&1E9F%U;'0@
M=&\@=&AE"B`@("`@("`@("H@(FAU;6%N+7)E861A8FQE(B!V97)S:6]N(&]F
M('1H92!O8FIE8W0N"B`@("`@("`@("H*("`@("`@("`@*B!792!A;'-O('5S
M92!T:&4@:'5M86XM<F5A9&%B;&4@9F]R;6%T(&9O<B!A<G)A>7,N"B`@("`@
M("`@("HO"B`@("`@("`@:68@*&ES7V]B:F5C="@D;65S<V%G92DI('L*("`@
M("`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H)&UE<W-A9V4L("=G971M97-S
M86=E)RDI('L*("`@("`@("`@("`@("`@("1M97-S86=E(#T@)&UE<W-A9V4M
M/F=E=$UE<W-A9V4H*3L*("`@("`@("`@("`@?2!E;'-E(&EF("AM971H;V1?
M97AI<W1S*"1M97-S86=E+"`G=&]S=')I;F<G*2D@>PH@("`@("`@("`@("`@
M("`@)&UE<W-A9V4@/2`D;65S<V%G92T^=&]3=')I;F<H*3L*("`@("`@("`@
M("`@?2!E;'-E(&EF("AM971H;V1?97AI<W1S*"1M97-S86=E+"`G7U]T;W-T
M<FEN9R<I*2!["B`@("`@("`@("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E
M*%!(4%]615)324].+"`G-2XP+C`G+"`G9V4G*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1M97-S86=E(#T@*'-T<FEN9RDD;65S<V%G93L*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&UE<W-A9V4@
M/2`D;65S<V%G92T^7U]T;U-T<FEN9R@I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@
M/2!P<FEN=%]R*"1M97-S86=E+"!T<G5E*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS92!I9B`H:7-?87)R87DH)&UE<W-A9V4I*2!["B`@("`@("`@
M("`@(&EF("AI<W-E="@D;65S<V%G95LG;65S<V%G92==*2D@>PH@("`@("`@
M("`@("`@("`@)&UE<W-A9V4@/2`D;65S<V%G95LG;65S<V%G92==.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!P
M<FEN=%]R*"1M97-S86=E+"!T<G5E*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@+RH@3W1H97)W:7-E+"!W92!A<W-U;64@=&AE(&UE<W-A
M9V4@:7,@82!S=')I;F<N("HO"B`@("`@("`@<F5T=7)N("1M97-S86=E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@57-I;F<@9&5B=6=?8F%C:W1R86-E*"DL
M(')E='5R;G,@=&AE(&9I;&4L(&QI;F4L(&%N9"!E;F-L;W-I;F<@9G5N8W1I
M;VX*("`@("`J(&YA;64@;V8@=&AE('-O=7)C92!C;V1E(&-O;G1E>'0@9G)O
M;2!W:&EC:"!L;V<H*2!W87,@:6YV;VMV960N"B`@("`@*@H@("`@("H@0'!A
M<F%M("`@:6YT("`@("`D9&5P=&@@(%1H92!I;FET:6%L(&YU;6)E<B!O9B!F
M<F%M97,@=V4@<VAO=6QD('-T97`*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("!B86-K(&EN=&\@=&AE('1R86-E+@H@("`@("H*("`@("`J($!R
M971U<FX@(&%R<F%Y("`@07)R87D@8V]N=&%I;FEN9R!T:')E92!S=')I;F=S
M.B!T:&4@9FEL96YA;64L('1H92!L:6YE+`H@("`@("H@("`@("`@("`@("`@
M("`@("!A;F0@=&AE(&9U;F-T:6]N(&YA;64@9G)O;2!W:&EC:"!L;V<H*2!W
M87,@8V%L;&5D+@H@("`@("H*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@
M("`J($!S:6YC92`@($QO9R`Q+CDN-`H@("`@("HO"B`@("!F=6YC=&EO;B!?
M9V5T0F%C:W1R86-E5F%R<R@D9&5P=&@I"B`@("!["B`@("`@("`@+RH@4W1A
M<G0@8GD@9V5N97)A=&EN9R!A(&)A8VMT<F%C92!F<F]M('1H92!C=7)R96YT
M(&-A;&P@*&AE<F4I+B`J+PH@("`@("`@("1B86-K=')A8V4@/2!D96)U9U]B
M86-K=')A8V4H*3L*"B`@("`@("`@+RH*("`@("`@("`@*B!792=R92!I;G1E
M<F5S=&5D(&EN('1H92!F<F%M92!W:&EC:"!I;G9O:V5D('1H92!L;V<H*2!F
M=6YC=&EO;BP@<V\*("`@("`@("`@*B!W92!N965D('1O('=A;&L@8F%C:R!S
M;VUE(&YU;6)E<B!O9B!F<F%M97,@:6YT;R!T:&4@8F%C:W1R86-E+B`@5&AE
M"B`@("`@("`@("H@)&1E<'1H('!A<F%M971E<B!T96QL<R!U<R!W:&5R92!T
M;R!S=&%R="!L;V]K:6YG+B`@(%=E(&=O(&]N92!S=&5P"B`@("`@("`@("H@
M9G5R=&AE<B!B86-K('1O(&9I;F0@=&AE(&YA;64@;V8@=&AE(&5N8V%P<W5L
M871I;F<@9G5N8W1I;VX@9G)O;0H@("`@("`@("`J('=H:6-H(&QO9R@I('=A
M<R!C86QL960N"B`@("`@("`@("HO"B`@("`@("`@)&9I;&4@/2!`)&)A8VMT
M<F%C95LD9&5P=&A=6R=F:6QE)UT["B`@("`@("`@)&QI;F4@/2!`)&)A8VMT
M<F%C95LD9&5P=&A=6R=L:6YE)UT["B`@("`@("`@)&9U;F,@/2!`)&)A8VMT
M<F%C95LD9&5P=&@@*R`Q75LG9G5N8W1I;VXG73L*"B`@("`@("`@+RH*("`@
M("`@("`@*B!(;W=E=F5R+"!I9B!L;V<H*2!W87,@8V%L;&5D(&9R;VT@;VYE
M(&]F(&]U<B`B<VAO<G1C=70B(&9U;F-T:6]N<RP*("`@("`@("`@*B!W92=R
M92!G;VEN9R!T;R!N965D('1O(&=O(&)A8VL@86X@861D:71I;VYA;"!S=&5P
M+@H@("`@("`@("`J+PH@("`@("`@(&EF("AI;E]A<G)A>2@D9G5N8RP@87)R
M87DH)V5M97)G)RP@)V%L97)T)RP@)V-R:70G+"`G97)R)RP@)W=A<FYI;F<G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYO=&EC92<L
M("=I;F9O)RP@)V1E8G5G)RDI*2!["B`@("`@("`@("`@("1F:6QE(#T@0"1B
M86-K=')A8V5;)&1E<'1H("L@,5U;)V9I;&4G73L*("`@("`@("`@("`@)&QI
M;F4@/2!`)&)A8VMT<F%C95LD9&5P=&@@*R`Q75LG;&EN92==.PH@("`@("`@
M("`@("`D9G5N8R`]($`D8F%C:W1R86-E6R1D97!T:"`K(#)=6R=F=6YC=&EO
M;B==.PH@("`@("`@('T*"B`@("`@("`@+RH*("`@("`@("`@*B!)9B!W92!C
M;W5L9&XG="!E>'1R86-T(&$@9G5N8W1I;VX@;F%M92`H<&5R:&%P<R!B96-A
M=7-E('=E('=E<F4*("`@("`@("`@*B!E>&5C=71E9"!F<F]M('1H92`B;6%I
M;B(@8V]N=&5X="DL('!R;W9I9&4@82!D969A=6QT('9A;'5E+@H@("`@("`@
M("`J+PH@("`@("`@(&EF("AI<U]N=6QL*"1F=6YC*2D@>PH@("`@("`@("`@
M("`D9G5N8R`]("<H;F]N92DG.PH@("`@("`@('T*"B`@("`@("`@+RH@4F5T
M=7)N(&$@,RUT=7!L92!C;VYT86EN:6YG("AF:6QE+"!L:6YE+"!F=6YC=&EO
M;BDN("HO"B`@("`@("`@<F5T=7)N(&%R<F%Y*"1F:6QE+"`D;&EN92P@)&9U
M;F,I.PH@("`@?0H*("`@("\J*@H@("`@("H@4')O9'5C97,@82!F;W)M871T
M960@;&]G(&QI;F4@8F%S960@;VX@82!F;W)M870@<W1R:6YG(&%N9"!A('-E
M="!O9@H@("`@("H@=F%R:6%B;&5S(')E<')E<V5N=&EN9R!T:&4@8W5R<F5N
M="!L;V<@<F5C;W)D(&%N9"!S=&%T92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M("!S=')I;F<@($9O<FUA='1E9"!L;V<@<W1R:6YG+@H@("`@("H*("`@("`J
M($!A8V-E<W,@('!R:79A=&4*("`@("`J($!S:6YC92`@($QO9R`Q+CDN-`H@
M("`@("HO"B`@("!F=6YC=&EO;B!?9F]R;6%T*"1F;W)M870L("1T:6UE<W1A
M;7`L("1P<FEO<FET>2P@)&UE<W-A9V4I"B`@("!["B`@("`@("`@+RH*("`@
M("`@("`@*B!)9B!T:&4@9F]R;6%T('-T<FEN9R!R969E<F5N8V5S(&%N>2!O
M9B!T:&4@8F%C:W1R86-E+61R:79E;@H@("`@("`@("`J('9A<FEA8FQE<R`H
M)34L("4V+"`E-RDL(&=E;F5R871E('1H92!B86-K=')A8V4@86YD(&9E=&-H
M('1H96TN"B`@("`@("`@("HO"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R\E
M6S4V-UTO)RP@)&9O<FUA="DI('L*("`@("`@("`@("`@;&ES="@D9FEL92P@
M)&QI;F4L("1F=6YC*2`]("1T:&ES+3Y?9V5T0F%C:W1R86-E5F%R<R@R*3L*
M("`@("`@("!]"@H@("`@("`@("\J"B`@("`@("`@("H@0G5I;&0@=&AE(&9O
M<FUA='1E9"!S=')I;F<N("!792!U<V4@=&AE('-P<FEN=&8H*2!F=6YC=&EO
M;B=S"B`@("`@("`@("H@(F%R9W5M96YT('-W87!P:6YG(B!C87!A8FEL:71Y
M('1O(&1Y;F%M:6-A;&QY('-E;&5C="!A;F0@<&]S:71I;VX*("`@("`@("`@
M*B!T:&4@=F%R:6%B;&5S('=H:6-H('=I;&P@=6QT:6UA=&5L>2!A<'!E87(@
M:6X@=&AE(&QO9R!S=')I;F<N"B`@("`@("`@("HO"B`@("`@("`@<F5T=7)N
M('-P<FEN=&8H)&9O<FUA="P*("`@("`@("`@("`@("`@("`@("`@("`D=&EM
M97-T86UP+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:61E;G0L
M"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G!R:6]R:71Y5&]3=')I
M;F<H)'!R:6]R:71Y*2P*("`@("`@("`@("`@("`@("`@("`@("`D;65S<V%G
M92P*("`@("`@("`@("`@("`@("`@("`@("!I<W-E="@D9FEL92D@/R`D9FEL
M92`Z("<G+`H@("`@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1L:6YE*2`_
M("1L:6YE(#H@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@:7-S970H)&9U
M;F,I(#\@)&9U;F,@.B`G)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@82!014%27TQ/1U\J
M(&EN=&5G97(@8V]N<W1A;G0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`D
M<')I;W)I='D@("`@($$@4$5!4E],3T=?*B!I;G1E9V5R(&-O;G-T86YT+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@("`@("`@("!4:&4@<W1R
M:6YG(')E<')E<V5N=&%T:6]N(&]F("1L979E;"X*("`@("`J"B`@("`@*B!`
M<VEN8V4@("!,;V<@,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N('!R:6]R:71Y
M5&]3=')I;F<H)'!R:6]R:71Y*0H@("`@>PH@("`@("`@("1L979E;',@/2!A
M<G)A>2@*("`@("`@("`@("`@4$5!4E],3T=?14U%4D<@("`]/B`G96UE<F=E
M;F-Y)RP*("`@("`@("`@("`@4$5!4E],3T=?04Q%4E0@("`]/B`G86QE<G0G
M+`H@("`@("`@("`@("!014%27TQ/1U]#4DE4("`@(#T^("=C<FET:6-A;"<L
M"B`@("`@("`@("`@(%!%05)?3$]'7T524B`@("`@/3X@)V5R<F]R)RP*("`@
M("`@("`@("`@4$5!4E],3T=?5T%23DE.1R`]/B`G=V%R;FEN9R<L"B`@("`@
M("`@("`@(%!%05)?3$]'7TY/5$E#12`@/3X@)VYO=&EC92<L"B`@("`@("`@
M("`@(%!%05)?3$]'7TE.1D\@("`@/3X@)VEN9F\G+`H@("`@("`@("`@("!0
M14%27TQ/1U]$14)51R`@(#T^("=D96)U9R<*("`@("`@("`I.PH*("`@("`@
M("!R971U<FX@)&QE=F5L<ULD<')I;W)I='E=.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@=&AE(%!%05)?3$]'7RH@:6YT96=E<B!C;VYS
M=&%N="!F;W(@=&AE(&=I=F5N('-T<FEN9PH@("`@("H@<F5P<F5S96YT871I
M;VX@;V8@82!P<FEO<FET>2!N86UE+B`@5&AI<R!F=6YC=&EO;B!P97)F;W)M
M<R!A"B`@("`@*B!C87-E+6EN<V5N<VET:79E('-E87)C:"X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@4W1R:6YG(&-O;G1A:6YI
M;F<@82!P<FEO<FET>2!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("`@("`@("`@("!4:&4@4$5!4E],3T=?*B!I;G1E9V5R(&-O;G1S=&%N
M="!C;W)R97-P;VYD:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@=&AE('1H92!S<&5C:69I960@<')I;W)I='D@;F%M92X*("`@("`J"B`@
M("`@*B!`<VEN8V4@("!,;V<@,2XY+C`*("`@("`J+PH@("`@9G5N8W1I;VX@
M<W1R:6YG5&]0<FEO<FET>2@D;F%M92D*("`@('L*("`@("`@("`D;&5V96QS
M(#T@87)R87DH"B`@("`@("`@("`@("=E;65R9V5N8WDG(#T^(%!%05)?3$]'
M7T5-15)'+`H@("`@("`@("`@("`G86QE<G0G("`@("`]/B!014%27TQ/1U]!
M3$525"P*("`@("`@("`@("`@)V-R:71I8V%L)R`@/3X@4$5!4E],3T=?0U))
M5"P*("`@("`@("`@("`@)V5R<F]R)R`@("`@/3X@4$5!4E],3T=?15)2+`H@
M("`@("`@("`@("`G=V%R;FEN9R<@("`]/B!014%27TQ/1U]705).24Y'+`H@
M("`@("`@("`@("`G;F]T:6-E)R`@("`]/B!014%27TQ/1U].3U1)0T4L"B`@
M("`@("`@("`@("=I;F9O)R`@("`@(#T^(%!%05)?3$]'7TE.1D\L"B`@("`@
M("`@("`@("=D96)U9R<@("`@(#T^(%!%05)?3$]'7T1%0E5'"B`@("`@("`@
M*3L*"B`@("`@("`@<F5T=7)N("1L979E;'-;<W1R=&]L;W=E<B@D;F%M92E=
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0V%L8W5L871E('1H92!L;V<@;6%S
M:R!F;W(@=&AE(&=I=F5N('!R:6]R:71Y+@H@("`@("H*("`@("`J(%1H:7,@
M;65T:&]D(&UA>2!B92!C86QL960@<W1A=&EC86QL>2X*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`@("1P<FEO<FET>2`@(%1H92!P<FEO<FET>2!W
M:&]S92!M87-K('=I;&P@8F4@8V%L8W5L871E9"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&EN=&5G97(@(%1H92!C86QC=6QA=&5D(&QO9R!M87-K+@H@("`@
M("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I;F-E("`@3&]G
M(#$N-RXP"B`@("`@*B\*("`@(&9U;F-T:6]N($U!4TLH)'!R:6]R:71Y*0H@
M("`@>PH@("`@("`@(')E='5R;B`H,2`\/"`D<')I;W)I='DI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0V%L8W5L871E('1H92!L;V<@;6%S:R!F;W(@86QL
M('!R:6]R:71I97,@=7`@=&\@=&AE(&=I=F5N('!R:6]R:71Y+@H@("`@("H*
M("`@("`J(%1H:7,@;65T:&]D(&UA>2!B92!C86QL960@<W1A=&EC86QL>2X*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`@("1P<FEO<FET>2`@(%1H
M92!M87AI;75M('!R:6]R:71Y(&-O=F5R960@8GD@=&AI<R!M87-K+@H@("`@
M("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(')E<W5L=&EN9R!L;V<@
M;6%S:RX*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!S
M:6YC92`@($QO9R`Q+C<N,`H@("`@("H*("`@("`J($!D97!R96-A=&5D(&1E
M<')E8V%T960@<VEN8V4@3&]G(#$N.2XT.R!U<V4@3&]G.CI-05@H*2!I;G-T
M96%D"B`@("`@*B\*("`@(&9U;F-T:6]N(%505$\H)'!R:6]R:71Y*0H@("`@
M>PH@("`@("`@(')E='5R;B!,;V<Z.DU!6"@D<')I;W)I='DI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0V%L8W5L871E('1H92!L;V<@;6%S:R!F;W(@86QL
M('!R:6]R:71I97,@9W)E871E<B!T:&%N(&]R(&5Q=6%L('1O('1H90H@("`@
M("H@9VEV96X@<')I;W)I='DN("!);B!O=&AE<B!W;W)D<RP@)'!R:6]R:71Y
M('=I;&P@8F4@=&AE(&QO=V5S="!P<FEO<FET>0H@("`@("H@;6%T8VAE9"!B
M>2!T:&4@<F5S=6QT:6YG(&UA<VLN"B`@("`@*@H@("`@("H@5&AI<R!M971H
M;V0@;6%Y(&)E(&-A;&QE9"!S=&%T:6-A;&QY+@H@("`@("H*("`@("`J($!P
M87)A;2!I;G1E9V5R("`@)'!R:6]R:71Y("`@5&AE(&UI;FEM=6T@<')I;W)I
M='D@8V]V97)E9"!B>2!T:&ES(&UA<VLN"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G1E9V5R("!4:&4@<F5S=6QT:6YG(&QO9R!M87-K+@H@("`@("H*("`@
M("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I;F-E("`@3&]G(#$N.2XT
M"B`@("`@*B\*("`@(&9U;F-T:6]N($U)3B@D<')I;W)I='DI"B`@("!["B`@
M("`@("`@<F5T=7)N(%!%05)?3$]'7T%,3"!>("@H,2`\/"`D<')I;W)I='DI
M("T@,2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#86QC=6QA=&4@=&AE(&QO
M9R!M87-K(&9O<B!A;&P@<')I;W)I=&EE<R!L97-S('1H86X@;W(@97%U86P@
M=&\@=&AE"B`@("`@*B!G:79E;B!P<FEO<FET>2X@($EN(&]T:&5R('=O<F1S
M+"`D<')I;W)I='D@=VEL;"!B92!T:&4@:&EG:&5S=',@<')I;W)I='D*("`@
M("`J(&UA=&-H960@8GD@=&AE(')E<W5L=&EN9R!M87-K+@H@("`@("H*("`@
M("`J(%1H:7,@;65T:&]D(&UA>2!B92!C86QL960@<W1A=&EC86QL>2X*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`@("1P<FEO<FET>2`@(%1H92!M
M87AI;75M('!R:6]R:71Y(&-O=F5R960@8GD@=&AI<R!M87-K+@H@("`@("H*
M("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(')E<W5L=&EN9R!L;V<@;6%S
M:RX*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!S:6YC
M92`@($QO9R`Q+CDN-`H@("`@("HO"B`@("!F=6YC=&EO;B!-05@H)'!R:6]R
M:71Y*0H@("`@>PH@("`@("`@(')E='5R;B`H*#$@/#P@*"1P<FEO<FET>2`K
M(#$I*2`M(#$I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T(&%N9"!R971U
M<FX@=&AE(&QE=F5L(&UA<VL@9F]R('1H92!C=7)R96YT($QO9R!I;G-T86YC
M92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;6%S:R`@("`@02!B
M:71W:7-E(&UA<VL@;V8@;&]G(&QE=F5L<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN=&5G97(@("`@("`@("`@5&AE(&-U<G)E;G0@;&5V96P@;6%S:RX*
M("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!S:6YC92`@
M($QO9R`Q+C<N,`H@("`@("HO"B`@("!F=6YC=&EO;B!S971-87-K*"1M87-K
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;6%S:R`]("1M87-K.PH*("`@("`@
M("!R971U<FX@)'1H:7,M/E]M87-K.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@8W5R<F5N="!L979E;"!M87-K+@H@("`@("H*("`@("`J
M($!R971U<FX@:6YT97)G97(@("`@("`@("!4:&4@8W5R<F5N="!L979E;"!M
M87-K+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I
M;F-E("`@3&]G(#$N-RXP"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$UA<VLH
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VUA<VL["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#:&5C:R!I9B!T:&4@9VEV96X@<')I;W)I='D@:7,@
M:6YC;'5D960@:6X@=&AE(&-U<G)E;G0@;&5V96P@;6%S:RX*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`@("1P<FEO<FET>2`@(%1H92!P<FEO<FET
M>2!T;R!C:&5C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R
M=64@:68@=&AE(&=I=F5N('!R:6]R:71Y(&ES(&EN8VQU9&5D(&EN('1H92!C
M=7)R96YT"B`@("`@*B`@("`@("`@("`@("`@("`@(&QO9R!M87-K+@H@("`@
M("H*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J($!S:6YC92`@($QO
M9R`Q+C<N,`H@("`@("HO"B`@("!F=6YC=&EO;B!?:7--87-K960H)'!R:6]R
M:71Y*0H@("`@>PH@("`@("`@(')E='5R;B`H3&]G.CI-05-+*"1P<FEO<FET
M>2D@)B`D=&AI<RT^7VUA<VLI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@8W5R<F5N="!D969A=6QT('!R:6]R:71Y+@H@("`@("H*("`@
M("`J($!R971U<FX@:6YT96=E<B`@5&AE(&-U<G)E;G0@9&5F875L="!P<FEO
M<FET>2X*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!S
M:6YC92`@($QO9R`Q+C@N-`H@("`@("HO"B`@("!F=6YC=&EO;B!G9710<FEO
M<FET>2@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<')I;W)I='D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!D969A=6QT('!R:6]R
M:71Y('1O('1H92!S<&5C:69I960@=F%L=64N"B`@("`@*@H@("`@("H@0'!A
M<F%M("`@:6YT96=E<B`D<')I;W)I='D@("!4:&4@;F5W(&1E9F%U;'0@<')I
M;W)I='DN"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`
M<VEN8V4@("!,;V<@,2XX+C0*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T4')I
M;W)I='DH)'!R:6]R:71Y*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<')I;W)I
M='D@/2`D<')I;W)I='D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@
M3&]G7V]B<V5R=F5R(&EN<W1A;F-E('1O('1H92!L:7-T(&]F(&]B<V5R=F5R
M<R!T:&%T(&%R92!L:7-T96YI;F<*("`@("`J(&9O<B!M97-S86=E<R!E;6ET
M=&5D(&)Y('1H:7,@3&]G(&EN<W1A;F-E+@H@("`@("H*("`@("`J($!P87)A
M;2!O8FIE8W0@("`@)&]B<V5R=F5R("`@5&AE($QO9U]O8G-E<G9E<B!I;G-T
M86YC92!T;R!A='1A8V@@87,@80H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!L:7-T96YE<BX*("`@("`J"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`@(%1R=64@:68@=&AE(&]B<V5R=F5R(&ES('-U8V-E<W-F=6QL>2!A
M='1A8VAE9"X*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J
M($!S:6YC92`@($QO9R`Q+C`*("`@("`J+PH@("`@9G5N8W1I;VX@871T86-H
M*"8D;V)S97)V97(I"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1O8G-E<G9E
M<BP@)TQO9U]O8G-E<G9E<B<I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?;&ES=&5N97)S6R1O8G-E
M<G9E<BT^7VED72`]("8D;V)S97)V97(["@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!A($QO9U]O8G-E<G9E
M<B!I;G-T86YC92!F<F]M('1H92!L:7-T(&]F(&]B<V5R=F5R<RX*("`@("`J
M"B`@("`@*B!`<&%R86T@;V)J96-T("`@("1O8G-E<G9E<B`@(%1H92!,;V=?
M;V)S97)V97(@:6YS=&%N8V4@=&\@9&5T86-H(&9R;VT*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&QI<W0@;V8@;&ES=&5N97)S
M+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("`@5')U92!I9B!T:&4@
M;V)S97)V97(@:7,@<W5C8V5S<V9U;&QY(&1E=&%C:&5D+@H@("`@("H*("`@
M("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I;F-E("`@3&]G(#$N,`H@
M("`@("HO"B`@("!F=6YC=&EO;B!D971A8V@H)&]B<V5R=F5R*0H@("`@>PH@
M("`@("`@(&EF("@A:7-?82@D;V)S97)V97(L("=,;V=?;V)S97)V97(G*2!\
M?`H@("`@("`@("`@("`A:7-S970H)'1H:7,M/E]L:7-T96YE<G-;)&]B<V5R
M=F5R+3Y?:61=*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("!U;G-E="@D=&AI<RT^7VQI<W1E;F5R<ULD;V)S97)V
M97(M/E]I9%TI.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J($EN9F]R;7,@96%C:"!R96=I<W1E<F5D(&]B<V5R=F5R(&EN
M<W1A;F-E('1H870@82!N97<@;65S<V%G92!H87,@8F5E;@H@("`@("H@;&]G
M9V5D+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@("`@)&5V96YT("`@
M("`@02!H87-H(&1E<V-R:6)I;F<@=&AE(&QO9R!E=F5N="X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V%N
M;F]U;F-E*"1E=F5N="D*("`@('L*("`@("`@("!F;W)E86-H("@D=&AI<RT^
M7VQI<W1E;F5R<R!A<R`D:60@/3X@)&QI<W1E;F5R*2!["B`@("`@("`@("`@
M(&EF("@D979E;G1;)W!R:6]R:71Y)UT@/#T@)'1H:7,M/E]L:7-T96YE<G-;
M)&ED72T^7W!R:6]R:71Y*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VQI
M<W1E;F5R<ULD:61=+3YN;W1I9GDH)&5V96YT*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($EN9&EC871E<R!W:&5T
M:&5R('1H:7,@:7,@82!C;VUP;W-I=&4@8VQA<W,N"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("`@("`@("`@(%1R=64@:68@=&AI<R!I<R!A(&-O
M;7!O<VET92!C;&%S<RX*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*
M("`@("`J($!S:6YC92`@($QO9R`Q+C`*("`@("`J+PH@("`@9G5N8W1I;VX@
M:7-#;VUP;W-I=&4H*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AI<R!,;V<@:6YS=&%N8V4G<R!I
M9&5N=&EF:6-A=&EO;B!S=')I;F<N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`@("`D:61E;G0@("`@("!4:&4@;F5W(&ED96YT:69I8V%T:6]N('-T
M<FEN9RX*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!S
M:6YC92`@($QO9R`Q+C8N,PH@("`@("HO"B`@("!F=6YC=&EO;B!S971)9&5N
M="@D:61E;G0I"B`@("!["B`@("`@("`@)'1H:7,M/E]I9&5N="`]("1I9&5N
M=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-U<G)E;G0@
M:61E;G1I9FEC871I;VX@<W1R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("`@5&AE(&-U<G)E;G0@3&]G(&EN<W1A;F-E)W,@:61E;G1I9FEC
M871I;VX@<W1R:6YG+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@
M("`@("H@0'-I;F-E("`@3&]G(#$N-BXS"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$ED96YT*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]I9&5N
M=#L*("`@('T*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+TUA:6PO````````````````````````
M````````````````````````````````````````````````````````````
M`#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S
M-S0S`#`Q-S0V-@`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O36%I;"]M
M86EL+G!H<```````````````````````````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,3$W,S<`,3`U,34T,S,W-#,`,#(Q,3,R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\O"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P
M>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@
M=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@
M=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE
M($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R
M7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L
M:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E
M('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N
M(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O"B\O("1)9#H@;6%I;"YP:'`L=B`Q+C$U(#(P,#4O,3`O,3`@,#0Z
M,38Z,C8@:F]N($5X<"`D"@HO*BH*("H@:6YT97)N86P@4$A0+6UA:6PH*2!I
M;7!L96UE;G1A=&EO;B!O9B!T:&4@4$5!4B!-86EL.CH@:6YT97)F86-E+@H@
M*B!`<&%C:V%G92!-86EL"B`J($!V97)S:6]N("12979I<VEO;CH@,2XQ-2`D
M"B`J+PIC;&%S<R!-86EL7VUA:6P@97AT96YD<R!-86EL('L*"B`@("`O*BH*
M("`@("`J($%N>2!A<F=U;65N=',@=&\@<&%S<R!T;R!T:&4@;6%I;"@I(&9U
M;F-T:6]N+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?
M<&%R86US(#T@)R<["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@
M("`J"B`@("`@*B!);G-T86YT:6%T97,@82!N97<@36%I;%]M86EL.CH@;V)J
M96-T(&)A<V5D(&]N('1H92!P87)A;65T97)S"B`@("`@*B!P87-S960@:6XN
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@17AT<F$@87)G
M=6UE;G1S(&9O<B!T:&4@;6%I;"@I(&9U;F-T:6]N+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!-86EL7VUA:6PH)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@
M("`@+RH@5&AE(&]T:&5R(&UA:6P@:6UP;&5M96YT871I;VYS(&%C8V5P="!P
M87)A;65T97)S(&%S(&%R<F%Y<RX*("`@("`@("`@*B!);B!T:&4@:6YT97)E
M<W0@;V8@8F5I;F<@8V]N<VES=&5N="P@97AP;&]D92!A;B!A<G)A>2!I;G1O
M"B`@("`@("`@("H@82!S=')I;F<@;V8@<&%R86UE=&5R(&%R9W5M96YT<RX@
M*B\*("`@("`@("!I9B`H:7-?87)R87DH)'!A<F%M<RDI('L*("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7,@/2!J;VEN*"<@)RP@)'!A<F%M<RD["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R
M86US.PH@("`@("`@('T*"B`@("`@("`@+RH@0F5C875S92!T:&4@;6%I;"@I
M(&9U;F-T:6]N(&UA>2!P87-S(&AE861E<G,@87,@8V]M;6%N9`H@("`@("`@
M("`J(&QI;F4@87)G=6UE;G1S+"!W92!C86XG="!G=6%R86YT964@=&AE('5S
M92!O9B!T:&4@<W1A;F1A<F0*("`@("`@("`@*B`B7')<;B(@<V5P87)A=&]R
M+B`@26YS=&5A9"P@=V4@=7-E('1H92!S>7-T96TG<R!N871I=F4@;&EN90H@
M("`@("`@("`J('-E<&%R871O<BX@*B\*("`@("`@("!I9B`H9&5F:6YE9"A0
M2%!?14],*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5P(#T@4$A07T5/3#L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^<V5P(#T@*'-T
M<G!O<RA02%!?3U,L("=724XG*2`]/3T@9F%L<V4I(#\@(EQN(B`Z(")<<EQN
M(CL*("`@("`@("!]"B`@("!]"@H)+RHJ"B`@("`@*B!);7!L96UE;G1S($UA
M:6Q?;6%I;#HZ<V5N9"@I(&9U;F-T:6]N('5S:6YG('!H<"=S(&)U:6QT+6EN
M(&UA:6PH*0H@("`@("H@8V]M;6%N9"X*("`@("`J"B`@("`@*B!`<&%R86T@
M;6EX960@)')E8VEP:65N=',@16ET:&5R(&$@8V]M;6$M<V5P97)A=&5D(&QI
M<W0@;V8@<F5C:7!I96YT<PH@("`@("H@("`@("`@("`@("`@("A21D,X,C(@
M8V]M<&QI86YT*2P@;W(@86X@87)R87D@;V8@<F5C:7!I96YT<RP*("`@("`J
M("`@("`@("`@("`@("!E86-H(%)&0S@R,B!V86QI9"X@5&AI<R!M87D@8V]N
M=&%I;B!R96-I<&EE;G1S(&YO=`H@("`@("H@("`@("`@("`@("`@('-P96-I
M9FEE9"!I;B!T:&4@:&5A9&5R<RP@9F]R($)C8SHL(')E<V5N9&EN9PH@("`@
M("H@("`@("`@("`@("`@(&UE<W-A9V5S+"!E=&,N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1H96%D97)S(%1H92!A<G)A>2!O9B!H96%D97)S('1O
M('-E;F0@=VET:"!T:&4@;6%I;"P@:6X@86X*("`@("`J("`@("`@("`@("`@
M("!A<W-O8VEA=&EV92!A<G)A>2P@=VAE<F4@=&AE(&%R<F%Y(&ME>2!I<R!T
M:&4*("`@("`J("`@("`@("`@("`@("!H96%D97(@;F%M92`H:64L("=3=6)J
M96-T)RDL(&%N9"!T:&4@87)R87D@=F%L=64*("`@("`J("`@("`@("`@("`@
M("!I<R!T:&4@:&5A9&5R('9A;'5E("AI92P@)W1E<W0G*2X@5&AE(&AE861E
M<@H@("`@("H@("`@("`@("`@("`@('!R;V1U8V5D(&9R;VT@=&AO<V4@=F%L
M=65S('=O=6QD(&)E("=3=6)J96-T.@H@("`@("H@("`@("`@("`@("`@('1E
M<W0G+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&)O9'D@5&AE(&9U
M;&P@=&5X="!O9B!T:&4@;65S<V%G92!B;V1Y+"!I;F-L=61I;F<@86YY"B`@
M("`@*B`@("`@("`@("`@("`@($UI;64@<&%R=',L(&5T8RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@=')U92!O;B!S=6-C97-S+"!O
M<B!A(%!%05)?17)R;W(*("`@("`J("`@("`@("`@("`@("`@8V]N=&%I;FEN
M9R!A(&1E<V-R:7!T:79E(&5R<F]R(&UE<W-A9V4@;VX*("`@("`J("`@("`@
M("`@("`@("`@9F%I;'5R92X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!S96YD*"1R96-I<&EE;G1S+"`D:&5A
M9&5R<RP@)&)O9'DI"B`@("!["B`@("`@("`@+R\@268@=V4G<F4@<&%S<V5D
M(&%N(&%R<F%Y(&]F(')E8VEP:65N=',L(&EM<&QO9&4@:70N"B`@("`@("`@
M:68@*&ES7V%R<F%Y*"1R96-I<&EE;G1S*2D@>PH@("`@("`@("`@("`D<F5C
M:7!I96YT<R`](&EM<&QO9&4H)RP@)RP@)')E8VEP:65N=',I.PH@("`@("`@
M('T*"B`@("`@("`@+R\@1V5T('1H92!3=6)J96-T(&]U="!O9B!T:&4@:&5A
M9&5R<R!A<G)A>2!S;R!T:&%T('=E(&-A;@H@("`@("`@("\O('!A<W,@:70@
M87,@82!S97!E<F%T92!A<F=U;65N="!T;R!M86EL*"DN"B`@("`@("`@)'-U
M8FIE8W0@/2`G)SL*("`@("`@("!I9B`H:7-S970H)&AE861E<G-;)U-U8FIE
M8W0G72DI('L*("`@("`@("`@("`@)'-U8FIE8W0@/2`D:&5A9&5R<ULG4W5B
M:F5C="==.PH@("`@("`@("`@("!U;G-E="@D:&5A9&5R<ULG4W5B:F5C="==
M*3L*("`@("`@("!]"@H@("`@("`@("\O($9L871T96X@=&AE(&AE861E<G,@
M;W5T+@H@("`@("`@("1H96%D97)%;&5M96YT<R`]("1T:&ES+3YP<F5P87)E
M2&5A9&5R<R@D:&5A9&5R<RD["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&AE861E<D5L96UE;G1S*2D@>PH@("`@("`@("`@("!R971U<FX@)&AE861E
M<D5L96UE;G1S.PH@("`@("`@('T*("`@("`@("!L:7-T*"P@)'1E>'1?:&5A
M9&5R<RD@/2`D:&5A9&5R16QE;65N=',["@H@("`@("`@("\J"B`@("`@("`@
M("H@5V4@;VYL>2!U<V4@;6%I;"@I)W,@;W!T:6]N86P@9FEF=&@@<&%R86UE
M=&5R(&EF('1H92!A9&1I=&EO;F%L"B`@("`@("`@("H@<&%R86UE=&5R<R!H
M879E(&)E96X@<')O=FED960@86YD('=E)W)E(&YO="!R=6YN:6YG(&EN('-A
M9F4@;6]D92X*("`@("`@("`@*B\*("`@("`@("!I9B`H96UP='DH)'1H:7,M
M/E]P87)A;7,I('Q\(&EN:5]G970H)W-A9F5?;6]D92<I*2!["B`@("`@("`@
M("`@("1R97-U;'0@/2!M86EL*"1R96-I<&EE;G1S+"`D<W5B:F5C="P@)&)O
M9'DL("1T97AT7VAE861E<G,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1R97-U;'0@/2!M86EL*"1R96-I<&EE;G1S+"`D<W5B:F5C="P@)&)O
M9'DL("1T97AT7VAE861E<G,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US*3L*("`@("`@("!]"@H@("`@("`@("\J"B`@("`@
M("`@("H@268@=&AE(&UA:6PH*2!F=6YC=&EO;B!R971U<FYE9"!F86EL=7)E
M+"!W92!N965D('1O(&-R96%T92!A"B`@("`@("`@("H@4$5!4E]%<G)O<B!O
M8FIE8W0@86YD(')E='5R;B!I="!I;G-T96%D(&]F('1H92!B;V]L96%N(')E
M<W5L="X*("`@("`@("`@*B\*("`@("`@("!I9B`H)')E<W5L="`]/3T@9F%L
M<V4I('L*("`@("`@("`@("`@)')E<W5L="`](%!%05(Z.G)A:7-E17)R;W(H
M)VUA:6PH*2!R971U<FYE9"!F86EL=7)E)RD["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@('T*"GT*````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+TUA:6PO;6EM92YP:'``````````````````````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#8Q,#8S`#$P-3$U-#,S-S0S`#`R,3$S-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*B!V:6TZ
M('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B
M<W1O<#TT.B`J+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@0V]P>7)I9VAT("AC*2`R,#`R+3(P,#,@(%)I8VAA<F0@2&5Y97,@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!#;W!Y<FEG:'0@
M*&,I(#(P,#,M,C`P-2`@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\($%L;"!R:6=H=',@<F5S97)V960N("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!2961I
M<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS
M+"!W:71H(&]R('=I=&AO=70@("`@?`HO+R!\(&UO9&EF:6-A=&EO;BP@87)E
M('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET
M:6]N<R`@("!\"B\O('P@87)E(&UE=#H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&\@4F5D:7-T<FEB
M=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C
M;W!Y<FEG:'0@("`@("!\"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C
M;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N("`@("`@
M('P*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T
M(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT("`@?`HO+R!\("`@;F]T
M:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN
M9R!D:7-C;&%I;65R(&EN('1H92!\"B\O('P@("!D;V-U;65N=&%T:6]N(&%N
M9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4@9&ES=')I
M8G5T:6]N+GP*+R\@?"!O(%1H92!N86UE<R!O9B!T:&4@875T:&]R<R!M87D@
M;F]T(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E("`@("`@?`HO+R!\
M("`@<')O9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4@=VET:&]U
M="!S<&5C:69I8R!P<FEO<B!W<FET=&5N("!\"B\O('P@("!P97)M:7-S:6]N
M+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R!\(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E2
M24=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,@("!\"B\O('P@(D%3($E3
M(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,
M541)3D<L($)55"!.3U0@("`@('P*+R\@?"!,24U)5$5$(%1/+"!42$4@24U0
M3$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!3D0@1DE43D53
M4R!&3U(@?`HO+R!\($$@4$%25$E#54Q!4B!055)03U-%($%212!$25-#3$%)
M345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@0T]065))1TA4("!\"B\O('P@
M3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),12!&3U(@04Y9($1)4D5#
M5"P@24Y$25)%0U0L($E.0TE$14Y404PL('P*+R\@?"!34$5#24%,+"!%6$5-
M4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+"!"
M550@3D]4("`@("`@?`HO+R!\($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&
M(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%+"!\
M"B\O('P@1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)255!4
M24].*2!(3U=%5D52($-!55-%1"!!3D0@3TX@04Y9('P*+R\@?"!42$5/4ED@
M3T8@3$E!0DE,2519+"!72$542$52($E.($-/3E1204-4+"!35%))0U0@3$E!
M0DE,2519+"!/4B!43U)4("`@?`HO+R!\("A)3D-,541)3D<@3D5'3$E'14Y#
M12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X@04Y9(%=!62!/550@3T8@5$A%
M(%5312!\"B\O('P@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)4T5$
M($]&(%1(12!03U-324))3$E462!/1B!354-(($1!34%'12X@('P*+R\@?"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@075T:&]R.B!2:6-H87)D($AE>65S(#QR:6-H
M87)D0'!H<&=U<G4N;W)G/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"`@("`@("`@(%1O;6%S(%8N5BY#;W@@/&-O>$!I9&5C;F5T+F-O;3X@
M*'!O<G0@=&\@4$5!4BD@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@;6EM92YP:'`L=B`Q+C,Y
M(#(P,#4O,#8O,3,@,C$Z,C0Z,38@8VEP<FD@17AP("0*"G)E<75I<F5?;VYC
M92@G4$5!4BYP:'`G*3L*<F5Q=6ER95]O;F-E*"=-86EL+VUI;65087)T+G!H
M<"<I.PH*+RHJ"B`J($UI;64@;6%I;"!C;VUP;W-E<B!C;&%S<RX@0V%N(&AA
M;F1L93H@=&5X="!A;F0@:'1M;"!B;V1I97,L(&5M8F5D9&5D(&AT;6P*("H@
M:6UA9V5S(&%N9"!A='1A8VAM96YT<RX*("H@1&]C=6UE;G1A=&EO;B!A;F0@
M97AA;7!L97,@;V8@=&AI<R!C;&%S<R!A<F4@879A:6)L92!H97)E.@H@*B!H
M='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"\*("H*("H@0&YO=&5S(%1H:7,@
M8VQA<W,@:7,@8F%S960@;VX@2%1-3"!-:6UE($UA:6P@8VQA<W,@9G)O;0H@
M*B`@(%)I8VAA<F0@2&5Y97,@/')I8VAA<F1`<&AP9W5R=2YO<F<^('=H:6-H
M('=A<R!B87-E9"!A;'-O"B`J("`@:6X@=&AE(&UI;65?;6%I;"YC;&%S<R!B
M>2!4;V)I87,@4F%T<V-H:6QL97(@/'1O8FEA<T!D;F5T+FET/B!A;F0*("H@
M("!387-C:&$@4V-H=6UA;FX@/'-A<V-H84!S8VAU;6%N;BYC>#X*("H*("H@
M0&%U=&AO<B`@(%)I8VAA<F0@2&5Y97,@/')I8VAA<F0N:&5Y97-`:&5Y97,M
M8V]M<'5T:6YG+FYE=#X*("H@0&%U=&AO<B`@(%1O;6%S(%8N5BY#;W@@/&-O
M>$!I9&5C;F5T+F-O;3X*("H@0'!A8VMA9V4@($UA:6P*("H@0&%C8V5S<R`@
M('!U8FQI8PH@*B\*8VQA<W,@36%I;%]M:6UE"GL*("`@("\J*@H@("`@("H@
M0V]N=&%I;G,@=&AE('!L86EN('1E>'0@<&%R="!O9B!T:&4@96UA:6P*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W1X=&)O9'D["B`@
M("`O*BH*("`@("`J($-O;G1A:6YS('1H92!H=&UL('!A<G0@;V8@=&AE(&5M
M86EL"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]H=&UL
M8F]D>3L*("`@("\J*@H@("`@("H@8V]N=&%I;G,@=&AE(&UI;64@96YC;V1E
M9"!T97AT"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]M
M:6UE.PH@("`@+RHJ"B`@("`@*B!C;VYT86EN<R!T:&4@;75L=&EP87)T(&-O
M;G1E;G0*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VUU
M;'1I<&%R=#L*("`@("\J*@H@("`@("H@;&ES="!O9B!T:&4@871T86-H960@
M:6UA9V5S"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7VAT
M;6Q?:6UA9V5S(#T@87)R87DH*3L*("`@("\J*@H@("`@("H@;&ES="!O9B!T
M:&4@871T86-H96UE;G1S"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D7W!A<G1S(#T@87)R87DH*3L*("`@("\J*@H@("`@("H@0G5I;&0@
M<&%R86UE=&5R<PH@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)%]B=6EL9%]P87)A;7,@/2!A<G)A>2@I.PH@("`@+RHJ"B`@("`@*B!(96%D
M97)S(&9O<B!T:&4@;6%I;`H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]H96%D97)S(#T@87)R87DH*3L*("`@("\J*@H@("`@("H@16YD
M($]F($QI;F4@<V5Q=65N8V4@*&9O<B!S97)I86QI>F4I"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]E;VP["@H*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T;W(@9G5N8W1I;VX*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!-86EL7VUI;64H)&-R;&8@
M/2`B7')<;B(I"B`@("!["B`@("`@("`@)'1H:7,M/E]S971%3TPH)&-R;&8I
M.PH@("`@("`@("1T:&ES+3Y?8G5I;&1?<&%R86US(#T@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&5X=%]E;F-O9&EN
M9R<@/3X@)S=B:70G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VAT;6Q?96YC;V1I;F<G(#T^("=Q=6]T960M<')I;G1A8FQE)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<W8FET7W=R
M87`G("`@("`]/B`Y.3@L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G:'1M;%]C:&%R<V5T)R`@/3X@)TE33RTX.#4Y+3$G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1E>'1?8VAA<G-E
M="<@(#T^("=)4T\M.#@U.2TQ)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=H96%D7V-H87)S970G("`]/B`G25-/+3@X-3DM,2<*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%=A:V5U<"`H=6YS97)I86QI>F4I("T@<F4M<V5T
M<R!%3TP@8V]N<W1A;G0*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@9G5N8W1I;VX@7U]W86ME=7`H*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?<V5T14],*"1T:&ES+3Y?96]L*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($%C8V5S<V]R(&9U;F-T:6]N('1O('-E="!T:&4@8F]D>2!T97AT
M+B!";V1Y('1E>'0@:7,@=7-E9"!I9@H@("`@("H@:70G<R!N;W0@86X@:'1M
M;"!M86EL(&)E:6YG('-E;G0@;W(@96QS92!I<R!U<V5D('1O(&9I;&P@=&AE
M"B`@("`@*B!T97AT+W!L86EN('!A<G0@=&AA="!E;6%I;',@8VQI96YT<R!W
M:&\@9&]N)W0@<W5P<&]R=`H@("`@("H@:'1M;"!S:&]U;&0@<VAO=RX*("`@
M("`J"B`@("`@*B!`<&%R86T@('-T<FEN9R`@)&1A=&$@("!%:71H97(@82!S
M=')I;F<@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('1H92!F
M:6QE(&YA;64@=VET:"!T:&4@8V]N=&5N=',*("`@("`J($!P87)A;2`@8F]O
M;"`@("`D:7-F:6QE($EF('1R=64@=&AE(&9I<G-T('!A<F%M('-H;W5L9"!B
M92!T<F5A=&5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!A<R!A
M(&9I;&4@;F%M92P@96QS92!A<R!A('-T<FEN9R`H9&5F875L="D*("`@("`J
M($!P87)A;2`@8F]O;"`@("`D87!P96YD($EF('1R=64@=&AE('1E>'0@;W(@
M9FEL92!I<R!A<'!E;F1E9"!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@=&AE(&5X:7-T:6YG(&)O9'DL(&5L<V4@=&AE(&]L9"!B;V1Y(&ES
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!O=F5R=W)I='1E;@H@
M("`@("H@0')E='5R;B!M:7AE9"`@('1R=64@;VX@<W5C8V5S<R!O<B!014%2
M7T5R<F]R(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5T5%A40F]D>2@D9&%T82P@)&ES9FEL92`](&9A;'-E
M+"`D87!P96YD(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"$D:7-F:6QE
M*2!["B`@("`@("`@("`@(&EF("@A)&%P<&5N9"D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]T>'1B;V1Y(#T@)&1A=&$["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W1X=&)O9'D@+CT@)&1A=&$[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M8V]N="`]("1T:&ES+3Y?9FEL93)S='(H)&1A=&$I.PH@("`@("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D8V]N="DI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D8V]N=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(21A
M<'!E;F0I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?='AT8F]D>2`]("1C
M;VYT.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]T>'1B;V1Y("X]("1C;VYT.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M061D<R!A(&AT;6P@<&%R="!T;R!T:&4@;6%I;`H@("`@("H*("`@("`J($!P
M87)A;2`@<W1R:6YG("`D9&%T82`@($5I=&AE<B!A('-T<FEN9R!O<B!T:&4@
M9FEL92!N86UE('=I=&@@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("!C;VYT96YT<PH@("`@("H@0'!A<F%M("!B;V]L("`@("1I<V9I;&4@
M268@=')U92!T:&4@9FER<W0@<&%R86T@<VAO=6QD(&)E('1R96%T960*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@(&%S(&$@9FEL92!N86UE+"!E
M;'-E(&%S(&$@<W1R:6YG("AD969A=6QT*0H@("`@("H@0')E='5R;B!M:7AE
M9"`@('1R=64@;VX@<W5C8V5S<R!O<B!014%27T5R<F]R(&]B:F5C=`H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T2%1-
M3$)O9'DH)&1A=&$L("1I<V9I;&4@/2!F86QS92D*("`@('L*("`@("`@("!I
M9B`H(21I<V9I;&4I('L*("`@("`@("`@("`@)'1H:7,M/E]H=&UL8F]D>2`]
M("1D871A.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C;VYT(#T@
M)'1H:7,M/E]F:6QE,G-T<B@D9&%T82D["B`@("`@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1C;VYT*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1C
M;VYT.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?:'1M;&)O
M9'D@/2`D8V]N=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@061D<R!A;B!I;6%G92!T;R!T:&4@;&ES
M="!O9B!E;6)E9&1E9"!I;6%G97,N"B`@("`@*@H@("`@("H@0'!A<F%M("!S
M=')I;F<@("1F:6QE("`@("`@(%1H92!I;6%G92!F:6QE(&YA;64@3U(@:6UA
M9V4@9&%T82!I='-E;&8*("`@("`J($!P87)A;2`@<W1R:6YG("`D8U]T>7!E
M("`@("!4:&4@8V]N=&5N="!T>7!E"B`@("`@*B!`<&%R86T@('-T<FEN9R`@
M)&YA;64@("`@("`@5&AE(&9I;&5N86UE(&]F('1H92!I;6%G92X*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!/;FQY('5S92!I9B`D9FEL
M92!I<R!T:&4@:6UA9V4@9&%T80H@("`@("H@0'!A<F%M("!B;V]L("`@("1I
M<V9I;&5N86UE(%=H971H97(@)&9I;&4@:7,@82!F:6QE;F%M92!O<B!N;W0*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$969A=6QT<R!T
M;R!T<G5E"B`@("`@*B!`<F5T=7)N(&UI>&5D("`@=')U92!O;B!S=6-C97-S
M(&]R(%!%05)?17)R;W(@;V)J96-T"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("HO"B`@("!F=6YC=&EO;B!A9&1(5$U,26UA9V4H)&9I;&4L("1C7W1Y
M<&4])V%P<&QI8V%T:6]N+V]C=&5T+7-T<F5A;2<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&YA;64@/2`G)RP@)&ES9FEL96YA;64@/2!T<G5E*0H@
M("`@>PH@("`@("`@("1F:6QE9&%T82`]("@D:7-F:6QE;F%M92`]/3T@=')U
M92D@/R`D=&AI<RT^7V9I;&4R<W1R*"1F:6QE*0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`D9FEL93L*("`@("`@("!I
M9B`H)&ES9FEL96YA;64@/3T]('1R=64I('L*("`@("`@("`@("`@)&9I;&5N
M86UE(#T@*"1N86UE(#T]("<G(#\@8F%S96YA;64H)&9I;&4I(#H@8F%S96YA
M;64H)&YA;64I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9FEL
M96YA;64@/2!B87-E;F%M92@D;F%M92D["B`@("`@("`@?0H@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1F:6QE9&%T82DI('L*("`@("`@("`@("`@<F5T
M=7)N("1F:6QE9&%T83L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]H=&UL
M7VEM86=E<UM=(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V)O9'DG("`@/3X@)&9I;&5D871A+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N86UE)R`@(#T^("1F:6QE
M;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M8U]T>7!E)R`]/B`D8U]T>7!E+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=C:60G("`@(#T^(&UD-2AU;FEQ:60H=&EM92@I*2D*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("D["B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@
M9FEL92!T;R!T:&4@;&ES="!O9B!A='1A8VAM96YT<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@('-T<FEN9R`@)&9I;&4@("`@("`@5&AE(&9I;&4@;F%M92!O
M9B!T:&4@9FEL92!T;R!A='1A8V@*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!/4B!T:&4@9FEL92!D871A(&ET<V5L9@H@("`@("H@0'!A
M<F%M("!S=')I;F<@("1C7W1Y<&4@("`@(%1H92!C;VYT96YT('1Y<&4*("`@
M("`J($!P87)A;2`@<W1R:6YG("`D;F%M92`@("`@("!4:&4@9FEL96YA;64@
M;V8@=&AE(&%T=&%C:&UE;G0*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!/;FQY('5S92!I9B`D9FEL92!I<R!T:&4@9FEL92!D871A"B`@
M("`@*B!`<&%R86T@(&)O;VP@("`@)&ES1FEL96YA;64@5VAE=&AE<B`D9FEL
M92!I<R!A(&9I;&5N86UE(&]R(&YO=`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($1E9F%U;'1S('1O('1R=64*("`@("`J($!R971U<FX@
M;6EX960@=')U92!O;B!S=6-C97-S(&]R(%!%05)?17)R;W(@;V)J96-T"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!A9&1!
M='1A8VAM96YT*"1F:6QE+"`D8U]T>7!E(#T@)V%P<&QI8V%T:6]N+V]C=&5T
M+7-T<F5A;2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE(#T@
M)R<L("1I<V9I;&5N86UE(#T@=')U92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&5N8V]D:6YG(#T@)V)A<V4V-"<I"B`@("!["B`@("`@("`@)&9I
M;&5D871A(#T@*"1I<V9I;&5N86UE(#T]/2!T<G5E*2`_("1T:&ES+3Y?9FEL
M93)S='(H)&9I;&4I"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`Z("1F:6QE.PH@("`@("`@(&EF("@D:7-F:6QE;F%M92`]
M/3T@=')U92D@>PH@("`@("`@("`@("`O+R!&;W)C92!T:&4@;F%M92!T:&4@
M=7-E<B!S=7!P;&EE9"P@;W1H97)W:7-E('5S92`D9FEL90H@("`@("`@("`@
M("`D9FEL96YA;64@/2`H(65M<'1Y*"1N86UE*2D@/R`D;F%M92`Z("1F:6QE
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F:6QE;F%M92`]("1N
M86UE.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&9I;&5N86UE*2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@*("`@("`@
M("`@("`@("`G5&AE('-U<'!L:65D(&9I;&5N86UE(&9O<B!T:&4@871T86-H
M;65N="!C86Y<)W0@8F4@96UP='DG"B`@("`@("`@("`@("D["B`@("`@("`@
M?0H@("`@("`@("1F:6QE;F%M92`](&)A<V5N86UE*"1F:6QE;F%M92D["B`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)&9I;&5D871A*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&9I;&5D871A.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/E]P87)T<UM=(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V)O9'DG("`@("`]/B`D9FEL961A=&$L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VYA;64G("`@("`]/B`D9FEL96YA;64L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-?='EP92<@("`]
M/B`D8U]T>7!E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=E
M;F-O9&EN9R<@/3X@)&5N8V]D:6YG"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`I.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1V5T('1H92!C;VYT96YT<R!O9B!T:&4@9VEV96X@9FEL92!N
M86UE(&%S('-T<FEN9PH@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG("`D
M9FEL95]N86UE("!P871H(&]F(&9I;&4@=&\@<')O8V5S<PH@("`@("H@0')E
M='5R;B!S=')I;F<@(&-O;G1E;G1S(&]F("1F:6QE7VYA;64*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B`F7V9I;&4R<W1R
M*"1F:6QE7VYA;64I"B`@("!["B`@("`@("`@:68@*"%I<U]R96%D86)L92@D
M9FEL95]N86UE*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G1FEL92!I<R!N;W0@<F5A9&%B;&4@)R`N("1F:6QE7VYA;64I.PH@
M("`@("`@('T*("`@("`@("!I9B`H(21F9"`](&9O<&5N*"1F:6QE7VYA;64L
M("=R8B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=#;W5L9"!N;W0@;W!E;B`G("X@)&9I;&5?;F%M92D["B`@("`@("`@?0H@
M("`@("`@("1F:6QE<VEZ92`](&9I;&5S:7IE*"1F:6QE7VYA;64I.PH@("`@
M("`@(&EF("@D9FEL97-I>F4@/3T@,"E["B`@("`@("`@("`@("1C;VYT(#T@
M("(B.PH@("`@("`@('UE;'-E>PH@("`@("`@("`@("`D8V]N="`](&9R96%D
M*"1F9"P@)&9I;&5S:7IE*3L*("`@("`@("!]"B`@("`@("`@9F-L;W-E*"1F
M9"D["B`@("`@("`@<F5T=7)N("1C;VYT.PH@("`@?0H*("`@("\J*@H@("`@
M("H@061D<R!A('1E>'0@<W5B<&%R="!T;R!T:&4@;6EM95!A<G0@;V)J96-T
M(&%N9`H@("`@("H@<F5T=7)N<R!I="!D=7)I;F<@=&AE(&)U:6QD('!R;V-E
M<W,N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("`@(%1H92!O8FIE8W0@
M=&\@861D('1H92!P87)T('1O+"!O<@H@("`@("H@("`@("`@("`@("`@("`@
M(&YU;&P@:68@82!N97<@;V)J96-T(&ES('1O(&)E(&-R96%T960N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("`@5&AE('1E>'0@=&\@861D+@H@("`@("H@0')E
M='5R;B!O8FIE8W0@(%1H92!T97AT(&UI;65087)T(&]B:F5C=`H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N("9?861D5&5X
M=%!A<G0H)B1O8FHL("1T97AT*0H@("`@>PH@("`@("`@("1P87)A;7-;)V-O
M;G1E;G1?='EP92==(#T@)W1E>'0O<&QA:6XG.PH@("`@("`@("1P87)A;7-;
M)V5N8V]D:6YG)UT@("`@(#T@)'1H:7,M/E]B=6EL9%]P87)A;7-;)W1E>'1?
M96YC;V1I;F<G73L*("`@("`@("`D<&%R86US6R=C:&%R<V5T)UT@("`@("`]
M("1T:&ES+3Y?8G5I;&1?<&%R86US6R=T97AT7V-H87)S970G73L*("`@("`@
M("!I9B`H:7-?;V)J96-T*"1O8FHI*2!["B`@("`@("`@("`@(')E='5R;B`D
M;V)J+3YA9&13=6)P87)T*"1T97AT+"`D<&%R86US*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R971U<FX@;F5W($UA:6Q?;6EM95!A<G0H)'1E
M>'0L("1P87)A;7,I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($%D9',@82!H=&UL('-U8G!A<G0@=&\@=&AE(&UI;65087)T(&]B:F5C="!A
M;F0*("`@("`J(')E='5R;G,@:70@9'5R:6YG('1H92!B=6EL9"!P<F]C97-S
M+@H@("`@("H*("`@("`J($!P87)A;2`@;6EX960@("!4:&4@;V)J96-T('1O
M(&%D9"!T:&4@<&%R="!T;RP@;W(*("`@("`J("`@("`@("`@("`@("`@("!N
M=6QL(&EF(&$@;F5W(&]B:F5C="!I<R!T;R!B92!C<F5A=&5D+@H@("`@("H@
M0')E='5R;B!O8FIE8W0@(%1H92!H=&UL(&UI;65087)T(&]B:F5C=`H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N("9?861D
M2'1M;%!A<G0H)B1O8FHI"B`@("!["B`@("`@("`@)'!A<F%M<ULG8V]N=&5N
M=%]T>7!E)UT@/2`G=&5X="]H=&UL)SL*("`@("`@("`D<&%R86US6R=E;F-O
M9&EN9R==("`@("`]("1T:&ES+3Y?8G5I;&1?<&%R86US6R=H=&UL7V5N8V]D
M:6YG)UT["B`@("`@("`@)'!A<F%M<ULG8VAA<G-E="==("`@("`@/2`D=&AI
M<RT^7V)U:6QD7W!A<F%M<ULG:'1M;%]C:&%R<V5T)UT["B`@("`@("`@:68@
M*&ES7V]B:F5C="@D;V)J*2D@>PH@("`@("`@("`@("!R971U<FX@)&]B:BT^
M861D4W5B<&%R="@D=&AI<RT^7VAT;6QB;V1Y+"`D<&%R86US*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@;F5W($UA:6Q?;6EM95!A
M<G0H)'1H:7,M/E]H=&UL8F]D>2P@)'!A<F%M<RD["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A(&YE=R!M:6UE4&%R="!O8FIE
M8W0L('5S:6YG(&UU;'1I<&%R="]M:7AE9"!A<PH@("`@("H@=&AE(&EN:71I
M86P@8V]N=&5N="UT>7!E(&%N9"!R971U<FYS(&ET(&1U<FEN9R!T:&4*("`@
M("`J(&)U:6QD('!R;V-E<W,N"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE
M8W0@(%1H92!M=6QT:7!A<G0O;6EX960@;6EM95!A<G0@;V)J96-T"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@)E]A9&1-
M:7AE9%!A<G0H*0H@("`@>PH@("`@("`@("1P87)A;7-;)V-O;G1E;G1?='EP
M92==(#T@)VUU;'1I<&%R="]M:7AE9"<["B`@("`@("`@<F5T=7)N(&YE=R!-
M86EL7VUI;65087)T*"<G+"`D<&%R86US*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($%D9',@82!M=6QT:7!A<G0O86QT97)N871I=F4@<&%R="!T;R!A(&UI
M;65087)T"B`@("`@*B!O8FIE8W0@*&]R(&-R96%T97,@;VYE*2P@86YD(')E
M='5R;G,@:70@9'5R:6YG"B`@("`@*B!T:&4@8G5I;&0@<')O8V5S<RX*("`@
M("`J"B`@("`@*B!`<&%R86T@(&UI>&5D("`@5&AE(&]B:F5C="!T;R!A9&0@
M=&AE('!A<G0@=&\L(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@;G5L;"!I
M9B!A(&YE=R!O8FIE8W0@:7,@=&\@8F4@8W)E871E9"X*("`@("`J($!R971U
M<FX@;V)J96-T("!4:&4@;75L=&EP87)T+VUI>&5D(&UI;65087)T(&]B:F5C
M=`H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9?861D06QT97)N871I=F5087)T*"8D;V)J*0H@("`@>PH@("`@("`@("1P
M87)A;7-;)V-O;G1E;G1?='EP92==(#T@)VUU;'1I<&%R="]A;'1E<FYA=&EV
M92<["B`@("`@("`@:68@*&ES7V]B:F5C="@D;V)J*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&]B:BT^861D4W5B<&%R="@G)RP@)'!A<F%M<RD["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&YE=R!-86EL7VUI;650
M87)T*"<G+"`D<&%R86US*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!9&1S(&$@;75L=&EP87)T+W)E;&%T960@<&%R="!T;R!A(&UI;650
M87)T"B`@("`@*B!O8FIE8W0@*&]R(&-R96%T97,@;VYE*2P@86YD(')E='5R
M;G,@:70@9'5R:6YG"B`@("`@*B!T:&4@8G5I;&0@<')O8V5S<RX*("`@("`J
M"B`@("`@*B!`<&%R86T@;6EX960@("`@5&AE(&]B:F5C="!T;R!A9&0@=&AE
M('!A<G0@=&\L(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@;G5L;"!I9B!A
M(&YE=R!O8FIE8W0@:7,@=&\@8F4@8W)E871E9`H@("`@("H@0')E='5R;B!O
M8FIE8W0@(%1H92!M=6QT:7!A<G0O;6EX960@;6EM95!A<G0@;V)J96-T"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@)E]A
M9&1296QA=&5D4&%R="@F)&]B:BD*("`@('L*("`@("`@("`D<&%R86US6R=C
M;VYT96YT7W1Y<&4G72`]("=M=6QT:7!A<G0O<F5L871E9"<["B`@("`@("`@
M:68@*&ES7V]B:F5C="@D;V)J*2D@>PH@("`@("`@("`@("!R971U<FX@)&]B
M:BT^861D4W5B<&%R="@G)RP@)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N(&YE=R!-86EL7VUI;65087)T*"<G+"`D<&%R
M86US*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&%N
M(&AT;6P@:6UA9V4@<W5B<&%R="!T;R!A(&UI;65087)T(&]B:F5C=`H@("`@
M("H@86YD(')E='5R;G,@:70@9'5R:6YG('1H92!B=6EL9"!P<F]C97-S+@H@
M("`@("H*("`@("`J($!P87)A;2`@;V)J96-T("!4:&4@;6EM95!A<G0@=&\@
M861D('1H92!I;6%G92!T;PH@("`@("H@0'!A<F%M("!A<G)A>2`@(%1H92!I
M;6%G92!I;F9O<FUA=&EO;@H@("`@("H@0')E='5R;B!O8FIE8W0@(%1H92!I
M;6%G92!M:6UE4&%R="!O8FIE8W0*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!F=6YC=&EO;B`F7V%D9$AT;6Q);6%G95!A<G0H)B1O8FHL
M("1V86QU92D*("`@('L*("`@("`@("`D<&%R86US6R=C;VYT96YT7W1Y<&4G
M72`]("1V86QU95LG8U]T>7!E)UT["B`@("`@("`@)'!A<F%M<ULG96YC;V1I
M;F<G72`@("`@/2`G8F%S938T)SL*("`@("`@("`D<&%R86US6R=D:7-P;W-I
M=&EO;B==("`]("=I;FQI;F4G.PH@("`@("`@("1P87)A;7-;)V1F:6QE;F%M
M92==("`@(#T@)'9A;'5E6R=N86UE)UT["B`@("`@("`@)'!A<F%M<ULG8VED
M)UT@("`@("`@("`@/2`D=F%L=65;)V-I9"==.PH@("`@("`@("1O8FHM/F%D
M9%-U8G!A<G0H)'9A;'5E6R=B;V1Y)UTL("1P87)A;7,I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@061D<R!A;B!A='1A8VAM96YT('-U8G!A<G0@=&\@82!M
M:6UE4&%R="!O8FIE8W0*("`@("`J(&%N9"!R971U<FYS(&ET(&1U<FEN9R!T
M:&4@8G5I;&0@<')O8V5S<RX*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C
M="`@5&AE(&UI;65087)T('1O(&%D9"!T:&4@:6UA9V4@=&\*("`@("`J($!P
M87)A;2`@87)R87D@("!4:&4@871T86-H;65N="!I;F9O<FUA=&EO;@H@("`@
M("H@0')E='5R;B!O8FIE8W0@(%1H92!I;6%G92!M:6UE4&%R="!O8FIE8W0*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B`F
M7V%D9$%T=&%C:&UE;G1087)T*"8D;V)J+"`D=F%L=64I"B`@("!["B`@("`@
M("`@)'!A<F%M<ULG8V]N=&5N=%]T>7!E)UT@/2`D=F%L=65;)V-?='EP92==
M.PH@("`@("`@("1P87)A;7-;)V5N8V]D:6YG)UT@("`@(#T@)'9A;'5E6R=E
M;F-O9&EN9R==.PH@("`@("`@("1P87)A;7-;)V1I<W!O<VET:6]N)UT@(#T@
M)V%T=&%C:&UE;G0G.PH@("`@("`@("1P87)A;7-;)V1F:6QE;F%M92==("`@
M(#T@)'9A;'5E6R=N86UE)UT["B`@("`@("`@)&]B:BT^861D4W5B<&%R="@D
M=F%L=65;)V)O9'DG72P@)'!A<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!"=6EL9',@=&AE(&UU;'1I<&%R="!M97-S86=E(&9R;VT@=&AE(&QI<W0@
M*"1T:&ES+3Y?<&%R=',I(&%N9`H@("`@("H@<F5T=7)N<R!T:&4@;6EM92!C
M;VYT96YT+@H@("`@("H*("`@("`J($!P87)A;2`@87)R87D@($)U:6QD('!A
M<F%M971E<G,@=&AA="!C:&%N9V4@=&AE('=A>2!T:&4@96UA:6P*("`@("`J
M("`@("`@("`@("`@("`@(&ES(&)U:6QT+B!3:&]U;&0@8F4@87-S;V-I871I
M=F4N($-A;B!C;VYT86EN.@H@("`@("H@("`@("`@("`@("`@("`@=&5X=%]E
M;F-O9&EN9R`@+2`@5VAA="!E;F-O9&EN9R!T;R!U<V4@9F]R('!L86EN('1E
M>'0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($1E
M9F%U;'0@:7,@-V)I=`H@("`@("H@("`@("`@("`@("`@("`@:'1M;%]E;F-O
M9&EN9R`@+2`@5VAA="!E;F-O9&EN9R!T;R!U<V4@9F]R(&AT;6P*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($1E9F%U;'0@:7,@
M<75O=&5D+7!R:6YT86)L90H@("`@("H@("`@("`@("`@("`@("`@-V)I=%]W
M<F%P("`@("`@+2`@3G5M8F5R(&]F(&-H87)A8W1E<G,@8F5F;W)E('1E>'0@
M:7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('=R
M87!P960@:6X@-V)I="!E;F-O9&EN9PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@1&5F875L="!I<R`Y.3@*("`@("`J("`@("`@
M("`@("`@("`@(&AT;6Q?8VAA<G-E="`@("T@(%1H92!C:&%R86-T97(@<V5T
M('1O('5S92!F;W(@:'1M;"X*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($1E9F%U;'0@:7,@:7-O+3@X-3DM,0H@("`@("H@("`@
M("`@("`@("`@("`@=&5X=%]C:&%R<V5T("`@+2`@5&AE(&-H87)A8W1E<B!S
M970@=&\@=7-E(&9O<B!T97AT+@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@1&5F875L="!I<R!I<V\M.#@U.2TQ"B`@("`@*B`@
M("`@("`@("`@("`@("!H96%D7V-H87)S970@("`M("!4:&4@8VAA<F%C=&5R
M('-E="!T;R!U<V4@9F]R(&AE861E<G,N"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!$969A=6QT(&ES(&ES;RTX.#4Y+3$*("`@
M("`J($!R971U<FX@<W1R:6YG(%1H92!M:6UE(&-O;G1E;G0*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N("9G970H)&)U:6QD
M7W!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1B=6EL
M9%]P87)A;7,I*2!["B`@("`@("`@("`@('=H:6QE("AL:7-T*"1K97DL("1V
M86QU92D@/2!E86-H*"1B=6EL9%]P87)A;7,I*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V)U:6QD7W!A<F%M<ULD:V5Y72`]("1V86QU93L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^
M7VAT;6Q?:6UA9V5S*2!!3D0@:7-S970H)'1H:7,M/E]H=&UL8F]D>2DI('L*
M("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]H=&UL7VEM86=E<R!A<R`D
M=F%L=64I('L*("`@("`@("`@("`@("`@("1R96=E>"`]("<C*%QS*2@H/VDI
M<W)C?&)A8VMG<F]U;F1\:')E9B@_+6DI*5QS*CU<<RHH6R)<)UT_*2<@+B!P
M<F5G7W%U;W1E*"1V86QU95LG;F%M92==+"`G(R<I("X*("`@("`@("`@("`@
M("`@("`@("`@("`@("=<,R,G.PH@("`@("`@("`@("`@("`@)')E<"`]("=<
M,5PR/5PS8VED.B<@+B`D=F%L=65;)V-I9"==("XG7#,G.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]H=&UL8F]D>2`]('!R96=?<F5P;&%C92@D<F5G97@L
M("1R97`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?:'1M;&)O9'D*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D
M;G5L;"`@("`@("`@/2!N=6QL.PH@("`@("`@("1A='1A8VAM96YT<R`]("%E
M;7!T>2@D=&AI<RT^7W!A<G1S*2`@("`@("`@("`@("`@("`_('1R=64@.B!F
M86QS93L*("`@("`@("`D:'1M;%]I;6%G97,@/2`A96UP='DH)'1H:7,M/E]H
M=&UL7VEM86=E<RD@("`@("`@("`@/R!T<G5E(#H@9F%L<V4["B`@("`@("`@
M)&AT;6P@("`@("`@(#T@(65M<'1Y*"1T:&ES+3Y?:'1M;&)O9'DI("`@("`@
M("`@("`@(#\@=')U92`Z(&9A;'-E.PH@("`@("`@("1T97AT("`@("`@("`]
M("@A)&AT;6P@04Y$("%E;7!T>2@D=&AI<RT^7W1X=&)O9'DI*2`_('1R=64@
M.B!F86QS93L*"B`@("`@("`@<W=I=&-H("AT<G5E*2!["B`@("`@("`@8V%S
M92`D=&5X="!!3D0@(21A='1A8VAM96YT<SH*("`@("`@("`@("`@)&UE<W-A
M9V4@/28@)'1H:7,M/E]A9&1497AT4&%R="@D;G5L;"P@)'1H:7,M/E]T>'1B
M;V1Y*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@(21T97AT
M($%.1"`A)&AT;6P@04Y$("1A='1A8VAM96YT<SH*("`@("`@("`@("`@)&UE
M<W-A9V4@/28@)'1H:7,M/E]A9&1-:7AE9%!A<G0H*3L*("`@("`@("`@("`@
M9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)'1H:7,M/E]P87)T<RD[("1I*RLI
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?861D071T86-H;65N=%!A<G0H
M)&UE<W-A9V4L("1T:&ES+3Y?<&%R='-;)&E=*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`D=&5X="!!3D0@)&%T
M=&%C:&UE;G1S.@H@("`@("`@("`@("`D;65S<V%G92`])B`D=&AI<RT^7V%D
M9$UI>&5D4&%R="@I.PH@("`@("`@("`@("`D=&AI<RT^7V%D9%1E>'1087)T
M*"1M97-S86=E+"`D=&AI<RT^7W1X=&)O9'DI.PH@("`@("`@("`@("!F;W(@
M*"1I(#T@,#L@)&D@/"!C;W5N="@D=&AI<RT^7W!A<G1S*3L@)&DK*RD@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1!='1A8VAM96YT4&%R="@D;65S
M<V%G92P@)'1H:7,M/E]P87)T<ULD:5TI.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("1H=&UL($%.1"`A)&%T=&%C
M:&UE;G1S($%.1"`A)&AT;6Q?:6UA9V5S.@H@("`@("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/E]T>'1B;V1Y*2D@>PH@("`@("`@("`@("`@("`@)&UE<W-A
M9V4@/28@)'1H:7,M/E]A9&1!;'1E<FYA=&EV95!A<G0H)&YU;&PI.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]A9&1497AT4&%R="@D;65S<V%G92P@)'1H
M:7,M/E]T>'1B;V1Y*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?861D2'1M
M;%!A<G0H)&UE<W-A9V4I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)&UE<W-A9V4@/28@)'1H:7,M/E]A9&1(=&UL4&%R="@D;G5L
M;"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@)&AT;6P@04Y$("$D871T86-H;65N=',@04Y$("1H=&UL7VEM86=E
M<SH*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?='AT8F]D>2DI('L*
M("`@("`@("`@("`@("`@("1M97-S86=E(#TF("1T:&ES+3Y?861D06QT97)N
M871I=F5087)T*"1N=6QL*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?861D
M5&5X=%!A<G0H)&UE<W-A9V4L("1T:&ES+3Y?='AT8F]D>2D["B`@("`@("`@
M("`@("`@("`D<F5L871E9"`])B`D=&AI<RT^7V%D9%)E;&%T961087)T*"1M
M97-S86=E*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1M97-S86=E(#TF("1T:&ES+3Y?861D4F5L871E9%!A<G0H)&YU;&PI.PH@
M("`@("`@("`@("`@("`@)')E;&%T960@/28@)&UE<W-A9V4["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)'1H:7,M/E]A9&1(=&UL4&%R="@D<F5L871E
M9"D["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1T:&ES
M+3Y?:'1M;%]I;6%G97,I.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V%D9$AT;6Q);6%G95!A<G0H)')E;&%T960L("1T:&ES+3Y?:'1M;%]I
M;6%G97-;)&E=*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@8V%S92`D:'1M;"!!3D0@)&%T=&%C:&UE;G1S($%.1"`A)&AT
M;6Q?:6UA9V5S.@H@("`@("`@("`@("`D;65S<V%G92`])B`D=&AI<RT^7V%D
M9$UI>&5D4&%R="@I.PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]T
M>'1B;V1Y*2D@>PH@("`@("`@("`@("`@("`@)&%L="`])B`D=&AI<RT^7V%D
M9$%L=&5R;F%T:79E4&%R="@D;65S<V%G92D["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V%D9%1E>'1087)T*"1A;'0L("1T:&ES+3Y?='AT8F]D>2D["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V%D9$AT;6Q087)T*"1A;'0I.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1(
M=&UL4&%R="@D;65S<V%G92D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)'1H:7,M/E]P87)T<RD[("1I*RLI
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?861D071T86-H;65N=%!A<G0H
M)&UE<W-A9V4L("1T:&ES+3Y?<&%R='-;)&E=*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`D:'1M;"!!3D0@)&%T
M=&%C:&UE;G1S($%.1"`D:'1M;%]I;6%G97,Z"B`@("`@("`@("`@("1M97-S
M86=E(#TF("1T:&ES+3Y?861D36EX961087)T*"D["B`@("`@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7W1X=&)O9'DI*2!["B`@("`@("`@("`@("`@("`D
M86QT(#TF("1T:&ES+3Y?861D06QT97)N871I=F5087)T*"1M97-S86=E*3L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?861D5&5X=%!A<G0H)&%L="P@)'1H
M:7,M/E]T>'1B;V1Y*3L*("`@("`@("`@("`@("`@("1R96P@/28@)'1H:7,M
M/E]A9&1296QA=&5D4&%R="@D86QT*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1R96P@/28@)'1H:7,M/E]A9&1296QA=&5D4&%R
M="@D;65S<V%G92D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M
M/E]A9&1(=&UL4&%R="@D<F5L*3L*("`@("`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@8V]U;G0H)'1H:7,M/E]H=&UL7VEM86=E<RD[("1I*RLI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?861D2'1M;$EM86=E4&%R="@D<F5L+"`D
M=&AI<RT^7VAT;6Q?:6UA9V5S6R1I72D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)'1H:7,M/E]P87)T<RD[
M("1I*RLI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?861D071T86-H;65N
M=%!A<G0H)&UE<W-A9V4L("1T:&ES+3Y?<&%R='-;)&E=*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@?0H*("`@("`@("!I
M9B`H:7-S970H)&UE<W-A9V4I*2!["B`@("`@("`@("`@("1O=71P=70@/2`D
M;65S<V%G92T^96YC;V1E*"D["B`@("`@("`@("`@("1T:&ES+3Y?:&5A9&5R
M<R`](&%R<F%Y7VUE<F=E*"1T:&ES+3Y?:&5A9&5R<RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U=%LG:&5A9&5R
M<R==*3L*("`@("`@("`@("`@<F5T=7)N("1O=71P=71;)V)O9'DG73L*"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@87)R87D@
M=VET:"!T:&4@:&5A9&5R<R!N965D960@=&\@<')E<&5N9"!T;R!T:&4@96UA
M:6P*("`@("`J("A-24U%+59E<G-I;VX@86YD($-O;G1E;G0M5'EP92DN($9O
M<FUA="!O9B!A<F=U;65N="!I<SH*("`@("`J("1A<G)A>5LG:&5A9&5R+6YA
M;64G72`]("=H96%D97(M=F%L=64G.PH@("`@("H*("`@("`J($!P87)A;2`@
M87)R87D@)'AT<F%?:&5A9&5R<R!!<W-O8R!A<G)A>2!W:71H(&%N>2!E>'1R
M82!H96%D97)S+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($]P=&EO;F%L+@H@("`@("H@0')E='5R;B!A<G)A>2!!<W-O8R!A<G)A>2!W
M:71H('1H92!M:6UE(&AE861E<G,*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9H96%D97)S*"1X=')A7VAE861E<G,@/2!N
M=6QL*0H@("`@>PH@("`@("`@("\O($-O;G1E;G0M5'EP92!H96%D97(@<VAO
M=6QD(&%L<F5A9'D@8F4@<')E<V5N="P*("`@("`@("`O+R!3;R!J=7-T(&%D
M9"!M:6UE('9E<G-I;VX@:&5A9&5R"B`@("`@("`@)&AE861E<G-;)TU)344M
M5F5R<VEO;B==(#T@)S$N,"<["B`@("`@("`@:68@*&ES<V5T*"1X=')A7VAE
M861E<G,I*2!["B`@("`@("`@("`@("1H96%D97)S(#T@87)R87E?;65R9V4H
M)&AE861E<G,L("1X=')A7VAE861E<G,I.PH@("`@("`@('T*("`@("`@("`D
M=&AI<RT^7VAE861E<G,@/2!A<G)A>5]M97)G92@D:&5A9&5R<RP@)'1H:7,M
M/E]H96%D97)S*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?96YC;V1E2&5A
M9&5R<R@D=&AI<RT^7VAE861E<G,I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1V5T('1H92!T97AT('9E<G-I;VX@;V8@=&AE(&AE861E<G,*("`@("`J("AU
M<V5F=6QL(&EF('EO=2!W86YT('1O('5S92!T:&4@4$A0(&UA:6PH*2!F=6YC
M=&EO;BD*("`@("`J"B`@("`@*B!`<&%R86T@(&%R<F%Y("`@)'AT<F%?:&5A
M9&5R<R!!<W-O8R!A<G)A>2!W:71H(&%N>2!E>'1R82!H96%D97)S+@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@3W!T:6]N86PN"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@4&QA:6X@=&5X="!H96%D97)S"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!T>'1(96%D
M97)S*"1X=')A7VAE861E<G,@/2!N=6QL*0H@("`@>PH@("`@("`@("1H96%D
M97)S(#T@)'1H:7,M/FAE861E<G,H)'AT<F%?:&5A9&5R<RD["B`@("`@("`@
M)')E="`]("<G.PH@("`@("`@(&9O<F5A8V@@*"1H96%D97)S(&%S("1K97D@
M/3X@)'9A;"D@>PH@("`@("`@("`@("`D<F5T("X]("(D:V5Y.B`D=F%L(B`N
M($U!24Q?34E-15]#4DQ&.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')E
M=#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(%-U8FIE8W0@:&5A
M9&5R"B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<@)'-U8FIE8W0@4W1R
M:6YG('1O('-E="!T:&4@<W5B:F5C="!T;PH@("`@("H@86-C97-S("!P=6)L
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T4W5B:F5C="@D<W5B:F5C="D*
M("`@('L*("`@("`@("`D=&AI<RT^7VAE861E<G-;)U-U8FIE8W0G72`]("1S
M=6)J96-T.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T(&%N(&5M86EL('1O
M('1H92!&<F]M("AT:&4@<V5N9&5R*2!H96%D97(*("`@("`J"B`@("`@*B!`
M<&%R86T@('-T<FEN9R`D96UA:6P@5&AE(&5M86EL(&1I<F5C=&EO;B!T;R!A
M9&0*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E=$9R;VTH)&5M86EL*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:&5A9&5R
M<ULG1G)O;2==(#T@)&5M86EL.PH@("`@?0H*("`@("\J*@H@("`@("H@061D
M(&%N(&5M86EL('1O('1H92!#8R`H8V%R8F]N(&-O<'DI(&AE861E<@H@("`@
M("H@*&UU;'1I<&QE(&-A;&QS('1O('1H:7,@;65T:&]D(&%R92!A;&QO=V5D
M*0H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG("1E;6%I;"!4:&4@96UA
M:6P@9&ER96-T:6]N('1O(&%D9`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@861D0V,H)&5M86EL*0H@("`@>PH@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7VAE861E<G-;)T-C)UTI*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?:&5A9&5R<ULG0V,G72`N/2`B+"`D96UA:6PB.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?:&5A9&5R<ULG0V,G
M72`]("1E;6%I;#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!
M9&0@86X@96UA:6P@=&\@=&AE($)C8R`H8FQA;FL@8V%R8F]N(&-O<'DI(&AE
M861E<@H@("`@("H@*&UU;'1I<&QE(&-A;&QS('1O('1H:7,@;65T:&]D(&%R
M92!A;&QO=V5D*0H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG("1E;6%I
M;"!4:&4@96UA:6P@9&ER96-T:6]N('1O(&%D9`H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@861D0F-C*"1E;6%I;"D*("`@
M('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]H96%D97)S6R="8V,G72DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]H96%D97)S6R="8V,G72`N/2`B+"`D
M96UA:6PB.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?
M:&5A9&5R<ULG0F-C)UT@/2`D96UA:6P["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@16YC;V1E<R!A(&AE861E<B!A<R!P97(@4D9#,C`T-PH@
M("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG("`D:6YP=70@5&AE(&AE861E
M<B!D871A('1O(&5N8V]D90H@("`@("H@0')E='5R;B!S=')I;F<@($5N8V]D
M960@9&%T80H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]E;F-O9&5(96%D97)S*"1I;G!U="D*("`@('L*("`@("`@("!F
M;W)E86-H("@D:6YP=70@87,@)&AD<E]N86UE(#T^("1H9')?=F%L=64I('L*
M("`@("`@("`@("`@<')E9U]M871C:%]A;&PH)R\H7'<J6UQX.#`M7'A&1ETK
M7'<J*2\G+"`D:&1R7W9A;'5E+"`D;6%T8VAE<RD["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1M871C:&5S6S%=(&%S("1V86QU92D@>PH@("`@("`@("`@("`@
M("`@)')E<&QA8V5M96YT(#T@<')E9U]R97!L86-E*"<O*%M<>#@P+5QX1D9=
M*2]E)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G(CTB("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!S=')T;W5P<&5R*&1E8VAE>"AO<F0H(EPQ(BDI*2<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A
M;'5E*3L*("`@("`@("`@("`@("`@("1H9')?=F%L=64@/2!S=')?<F5P;&%C
M92@D=F%L=64L("<]/R<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8G5I;&1?<&%R86US6R=H96%D7V-H87)S
M970G72`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)S]1/R<@+B`D<F5P;&%C96UE;G0@+B`G/STG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1H9')?=F%L=64I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1I;G!U=%LD:&1R7VYA;65=(#T@)&AD
M<E]V86QU93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YP=70["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&]B:F5C="=S(&5N9"UO9BUL
M:6YE(&%N9"!D969I;F4@=&AE(&-O;G-T86YT(&EF(&%P<&QI8V%B;&4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1E;VP@16YD($]F($QI;F4@<V5Q
M=65N8V4*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC
M=&EO;B!?<V5T14],*"1E;VPI"B`@("!["B`@("`@("`@)'1H:7,M/E]E;VP@
M/2`D96]L.PH@("`@("`@(&EF("@A9&5F:6YE9"@G34%)3%]-24U%7T-23$8G
M*2D@>PH@("`@("`@("`@("!D969I;F4H)TU!24Q?34E-15]#4DQ&)RP@)'1H
M:7,M/E]E;VPL('1R=64I.PH@("`@("`@('T*("`@('T*"B`@("`*"GT@+R\@
M16YD(&]F(&-L87-S"C\^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+TUA:6PO;6EM941E8V]D92YP:'``````````````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#<T-C4V`#$P-3$U-#,S-S0S`#`R,C(U
M-``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED
M=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`R,#`R+3(P,#,@(%)I8VAA
M<F0@2&5Y97,@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M?"!#;W!Y<FEG:'0@*&,I(#(P,#,M,C`P-2`@5&AE(%!(4"!'<F]U<"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($%L;"!R:6=H=',@
M<F5S97)V960N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@
M8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70@("`@?`HO+R!\(&UO9&EF
M:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL
M;W=I;F<@8V]N9&ET:6]N<R`@("!\"B\O('P@87)E(&UE=#H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\
M(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN
M('1H92!A8F]V92!C;W!Y<FEG:'0@("`@("!\"B\O('P@("!N;W1I8V4L('1H
M:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L
M86EM97(N("`@("`@('P*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA
M<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT("`@
M?`HO+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@
M=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN('1H92!\"B\O('P@("!D;V-U
M;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET
M:"!T:&4@9&ES=')I8G5T:6]N+GP*+R\@?"!O(%1H92!N86UE<R!O9B!T:&4@
M875T:&]R<R!M87D@;F]T(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E
M("`@("`@?`HO+R!\("`@<')O9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F
M='=A<F4@=VET:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N("!\"B\O('P@
M("!P97)M:7-S:6]N+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@
M0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,@("!\
M"B\O('P@(D%3($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)2
M04Y42453+"!)3D-,541)3D<L($)55"!.3U0@("`@('P*+R\@?"!,24U)5$5$
M(%1/+"!42$4@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E4
M62!!3D0@1DE43D534R!&3U(@?`HO+R!\($$@4$%25$E#54Q!4B!055)03U-%
M($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@0T]065))
M1TA4("!\"B\O('P@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),12!&
M3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL('P*+R\@?"!3
M4$5#24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H
M24Y#3%5$24Y'+"!"550@3D]4("`@("`@?`HO+R!\($Q)34E4140@5$\L(%!2
M3T-54D5-14Y4($]&(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[($Q/
M4U,@3T8@55-%+"!\"B\O('P@1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%
M4U,@24Y415)255!424].*2!(3U=%5D52($-!55-%1"!!3D0@3TX@04Y9('P*
M+R\@?"!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E.($-/3E1204-4
M+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4("`@?`HO+R!\("A)3D-,541)
M3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X@04Y9(%=!
M62!/550@3T8@5$A%(%5312!\"B\O('P@3T8@5$A)4R!33T945T%212P@159%
M3B!)1B!!1%9)4T5$($]&(%1(12!03U-324))3$E462!/1B!354-(($1!34%'
M12X@('P*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R.B!2:6-H87)D
M($AE>65S(#QR:6-H87)D0'!H<&=U<G4N;W)G/B`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*
M<F5Q=6ER95]O;F-E("=014%2+G!H<"<["@HO*BH**B`@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM($E-4$]25$%.5"`M+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"BH@('P@57-A9V4@;V8@=&AI<R!C;&%S<R!C;VUP
M87)E9"!T;R!N871I=F4@<&AP(&5X=&5N<VEO;G,@<W5C:"!A<R`@("`@("`@
M?`HJ("!\(&UA:6QP87)S92!O<B!I;6%P+"!I<R!S;&]W(&%N9"!M87D@8F4@
M9F5A='5R92!D969I8VEE;G0N($EF(&%V86EL86)L97P**B`@?"!Y;W4@87)E
M(%-44D].1TQ9(')E8V]M;65N9&5D('1O('5S92!T:&4@<&AP(&5X=&5N<VEO
M;G,N("`@("`@("`@("`@("!\"BH@("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHJ"BH@36EM92!$96-O9&EN9R!C;&%S<PHJ"BH@5&AI<R!C;&%S<R!W
M:6QL('!A<G-E(&$@<F%W(&UI;64@96UA:6P@86YD(')E='5R;@HJ('1H92!S
M=')U8W1U<F4N(%)E='5R;F5D('-T<G5C='5R92!I<R!S:6UI;&%R('1O"BH@
M=&AA="!R971U<FYE9"!B>2!I;6%P7V9E=&-H<W1R=6-T=7)E*"DN"BH**B!5
M4T%'13H@*&%S<W5M92`D:6YP=70@:7,@>6]U<B!R87<@96UA:6PI"BH**B`D
M9&5C;V1E(#T@;F5W($UA:6Q?;6EM941E8V]D92@D:6YP=70L(")<<EQN(BD[
M"BH@)'-T<G5C='5R92`]("1D96-O9&4M/F1E8V]D92@I.PHJ('!R:6YT7W(H
M)'-T<G5C='5R92D["BH**B!/<B!S=&%T:6-A;&QY.@HJ"BH@)'!A<F%M<ULG
M:6YP=70G72`]("1I;G!U=#L**B`D<W1R=6-T=7)E(#T@36%I;%]M:6UE1&5C
M;V1E.CID96-O9&4H)'!A<F%M<RD["BH@<')I;G1?<B@D<W1R=6-T=7)E*3L*
M*@HJ(%1/1$\Z"BH@(&\@26UP;&5M96YT(&UU;'1I<&%R="]A<'!L961O=6)L
M90HJ("!O(%541C@Z(#\_/PH*"0D^(#0N(%=E(&AA=F4@86QS;R!F;W5N9"!A
M('-O;'5T:6]N(&9O<B!D96-O9&EN9R!T:&4@551&+3@@"@D)/B!H96%D97)S
M+B!4:&5R969O<F4@22!M861E('1H92!F;VQL;W=I;F<@9G5N8W1I;VXZ"@D)
M/B`*"0D^(&9U;F-T:6]N(&1E8V]D95]U=&8X*"1T>'0I('L*"0D^("1T<F%N
M<SUA<G)A>2@BQ28C.#(Q-CLB/3XBP[4B+"+%L2(]/B+#NR(L(L60(CT^(L,F
M(S@R,C8[(BPBQ;`B"@D)/3XBPR8C.#(U,#LB*3L*"0D^("1T>'0]<W1R='(H
M)'1X="PD=')A;G,I.PH)"3X@<F5T=7)N*'5T9CA?9&5C;V1E*"1T>'0I*3L*
M"0D^('T*"0D^(`H)"3X@06YD($D@:&%V92!I;G-E<G1E9"!T:&4@9F]L;&]W
M:6YG(&QI;F4@=&\@=&AE(&-L87-S.@H)"3X@"@D)/B!I9B`H<W1R=&]L;W=E
M<B@D8VAA<G-E="D]/2)U=&8M."(I("1T97AT/61E8V]D95]U=&8X*"1T97AT
M*3L*"0D^(`H)"3X@+BXN(&)E9F]R92!T:&4@9F]L;&]W:6YG(&]N92!I;B!T
M:&4@(E]D96-O9&5(96%D97(B(&9U;F-T:6]N.@H)"3X@"@D)/B`D:6YP=70@
M/2!S=')?<F5P;&%C92@D96YC;V1E9"P@)'1E>'0L("1I;G!U="D["@D)/B`*
M"0D^(%1H:7,@=V%Y(&9R;VT@;F]W(&]N(&ET(&-A;B!E87-I;'D@9&5C;V1E
M('1H92!55$8M."!H96%D97)S('1O;RX*"BH**B!`875T:&]R("!2:6-H87)D
M($AE>65S(#QR:6-H87)D0'!H<&=U<G4N;W)G/@HJ($!V97)S:6]N("12979I
M<VEO;CH@,2XT-B`D"BH@0'!A8VMA9V4@36%I;`HJ+PIC;&%S<R!-86EL7VUI
M;65$96-O9&4@97AT96YD<R!014%2"GL*("`@("\J*@H@("`@("H@5&AE(')A
M=R!E;6%I;"!T;R!D96-O9&4*("`@("`J($!V87(@("`@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D7VEN<'5T.PH*("`@("\J*@H@("`@("H@5&AE(&AE861E
M<B!P87)T(&]F('1H92!I;G!U=`H@("`@("H@0'9A<B`@("!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1?:&5A9&5R.PH*("`@("\J*@H@("`@("H@5&AE(&)O
M9'D@<&%R="!O9B!T:&4@:6YP=70*("`@("`J($!V87(@("`@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7V)O9'D["@H@("`@+RHJ"B`@("`@*B!)9B!A;B!E
M<G)O<B!O8V-U<G,L('1H:7,@:7,@=7-E9"!T;R!S=&]R92!T:&4@;65S<V%G
M90H@("`@("H@0'9A<B`@("!S=')I;F<*("`@("`J+PH@("`@=F%R("1?97)R
M;W(["@H@("`@+RHJ"B`@("`@*B!&;&%G('1O(&1E=&5R;6EN92!W:&5T:&5R
M('1O(&EN8VQU9&4@8F]D:65S(&EN('1H90H@("`@("H@<F5T=7)N960@;V)J
M96-T+@H@("`@("H@0'9A<B`@("!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D
M7VEN8VQU9&5?8F]D:65S.PH*("`@("\J*@H@("`@("H@1FQA9R!T;R!D971E
M<FUI;F4@=VAE=&AE<B!T;R!D96-O9&4@8F]D:65S"B`@("`@*B!`=F%R("`@
M(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?9&5C;V1E7V)O9&EE<SL*"B`@
M("`O*BH*("`@("`J($9L86<@=&\@9&5T97)M:6YE('=H971H97(@=&\@9&5C
M;V1E(&AE861E<G,*("`@("`J($!V87(@("`@8F]O;&5A;@H@("`@("HO"B`@
M("!V87(@)%]D96-O9&5?:&5A9&5R<SL*"B`@("`O*BH*("`@("`J($-O;G-T
M<G5C=&]R+@H@("`@("H*("`@("`J(%-E=',@=7`@=&AE(&]B:F5C="P@:6YI
M=&EA;&ES92!T:&4@=F%R:6%B;&5S+"!A;F0@<W!L:71S(&%N9`H@("`@("H@
M<W1O<F5S('1H92!H96%D97(@86YD(&)O9'D@;V8@=&AE(&EN<'5T+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@5&AE(&EN<'5T('1O(&1E8V]D90H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@36%I
M;%]M:6UE1&5C;V1E*"1I;G!U="D*("`@('L*("`@("`@("!L:7-T*"1H96%D
M97(L("1B;V1Y*2`@(#T@)'1H:7,M/E]S<&QI=$)O9'E(96%D97(H)&EN<'5T
M*3L*"B`@("`@("`@)'1H:7,M/E]I;G!U="`@("`@("`@("`]("1I;G!U=#L*
M("`@("`@("`D=&AI<RT^7VAE861E<B`@("`@("`@(#T@)&AE861E<CL*("`@
M("`@("`D=&AI<RT^7V)O9'D@("`@("`@("`@(#T@)&)O9'D["B`@("`@("`@
M)'1H:7,M/E]D96-O9&5?8F]D:65S("`](&9A;'-E.PH@("`@("`@("1T:&ES
M+3Y?:6YC;'5D95]B;V1I97,@/2!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0F5G:6YS('1H92!D96-O9&EN9R!P<F]C97-S+B!)9B!C86QL960@<W1A
M=&EC86QL>0H@("`@("H@:70@=VEL;"!C<F5A=&4@86X@;V)J96-T(&%N9"!C
M86QL('1H92!D96-O9&4H*2!M971H;V0*("`@("`J(&]F(&ET+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2!!;B!A<G)A>2!O9B!V87)I;W5S('!A<F%M
M971E<G,@=&AA="!D971E<FUI;F4*("`@("`J("`@("`@("`@("`@("!V87)I
M;W5S('1H:6YG<SH*("`@("`J("`@("`@("`@("`@("!I;F-L=61E7V)O9&EE
M<R`M(%=H971H97(@=&\@:6YC;'5D92!T:&4@8F]D>2!I;B!T:&4@<F5T=7)N
M960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]B:F5C
M="X*("`@("`J("`@("`@("`@("`@("!D96-O9&5?8F]D:65S("`M(%=H971H
M97(@=&\@9&5C;V1E('1H92!B;V1I97,*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&]F('1H92!P87)T<RX@*%1R86YS9F5R(&5N8V]D
M:6YG*0H@("`@("H@("`@("`@("`@("`@(&1E8V]D95]H96%D97)S("T@5VAE
M=&AE<B!T;R!D96-O9&4@:&5A9&5R<PH@("`@("H@("`@("`@("`@("`@(&EN
M<'5T("`@("`@("`@("T@268@8V%L;&5D('-T871I8V%L;'DL('1H:7,@=VEL
M;"!B92!T<F5A=&5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<R!T:&4@:6YP=70*("`@("`J($!R971U<FX@;V)J96-T($1E8V]D
M960@<F5S=6QT<PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@9&5C;V1E*"1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@
M("\O(&1E=&5R;6EN92!I9B!T:&ES(&UE=&AO9"!H87,@8F5E;B!C86QL960@
M<W1A=&EC86QL>0H@("`@("`@("1I<U-T871I8R`]("$H:7-S970H)'1H:7,I
M("8F(&=E=%]C;&%S<R@D=&AI<RD@/3T@7U]#3$%34U]?*3L*"B`@("`@("`@
M+R\@2&%V92!W92!B965N(&-A;&QE9"!S=&%T:6-A;&QY/PH)+R\@268@<V\L
M(&-R96%T92!A;B!O8FIE8W0@86YD('!A<W,@9&5T86EL<R!T;R!T:&%T+@H@
M("`@("`@(&EF("@D:7-3=&%T:6,@04Y$(&ES<V5T*"1P87)A;7-;)VEN<'5T
M)UTI*2!["@H@("`@("`@("`@("`D;V)J(#T@;F5W($UA:6Q?;6EM941E8V]D
M92@D<&%R86US6R=I;G!U="==*3L*("`@("`@("`@("`@)'-T<G5C='5R92`]
M("1O8FHM/F1E8V]D92@D<&%R86US*3L*"B`@("`@("`@+R\@0V%L;&5D('-T
M871I8V%L;'D@8G5T(&YO(&EN<'5T"B`@("`@("`@?2!E;'-E:68@*"1I<U-T
M871I8RD@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G
M0V%L;&5D('-T871I8V%L;'D@86YD(&YO(&EN<'5T(&=I=F5N)RD["@H@("`@
M("`@("\O($-A;&QE9"!V:6$@86X@;V)J96-T"B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'1H:7,M/E]I;F-L=61E7V)O9&EE<R`](&ES<V5T*"1P
M87)A;7-;)VEN8VQU9&5?8F]D:65S)UTI(#\*"2`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'!A<F%M<ULG:6YC;'5D95]B;V1I97,G72`Z(&9A;'-E
M.PH@("`@("`@("`@("`D=&AI<RT^7V1E8V]D95]B;V1I97,@(#T@:7-S970H
M)'!A<F%M<ULG9&5C;V1E7V)O9&EE<R==*2`_"@D@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P87)A;7-;)V1E8V]D95]B;V1I97,G72`@.B!F86QS
M93L*("`@("`@("`@("`@)'1H:7,M/E]D96-O9&5?:&5A9&5R<R`](&ES<V5T
M*"1P87)A;7-;)V1E8V]D95]H96%D97)S)UTI(#\*"2`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'!A<F%M<ULG9&5C;V1E7VAE861E<G,G72`Z(&9A
M;'-E.PH*("`@("`@("`@("`@)'-T<G5C='5R92`]("1T:&ES+3Y?9&5C;V1E
M*"1T:&ES+3Y?:&5A9&5R+"`D=&AI<RT^7V)O9'DI.PH@("`@("`@("`@("!I
M9B`H)'-T<G5C='5R92`]/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1S
M=')U8W1U<F4@/2`D=&AI<RT^<F%I<V5%<G)O<B@D=&AI<RT^7V5R<F]R*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1S=')U
M8W1U<F4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!097)F;W)M<R!T:&4@9&5C
M;V1I;F<N($1E8V]D97,@=&AE(&)O9'D@<W1R:6YG('!A<W-E9"!T;R!I=`H@
M("`@("H@268@:70@9FEN9',@8V5R=&%I;B!C;VYT96YT+71Y<&5S(&ET('=I
M;&P@8V%L;"!I='-E;&8@:6X@80H@("`@("H@<F5C=7)S:79E(&9A<VAI;VX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG($AE861E<B!S96-T:6]N"B`@
M("`@*B!`<&%R86T@<W1R:6YG($)O9'D@<V5C=&EO;@H@("`@("H@0')E='5R
M;B!O8FIE8W0@4F5S=6QT<R!O9B!D96-O9&EN9R!P<F]C97-S"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V1E8V]D92@D
M:&5A9&5R<RP@)&)O9'DL("1D969A=6QT7V-T>7!E(#T@)W1E>'0O<&QA:6XG
M*0H@("`@>PH@("`@("`@("1R971U<FX@/2!N97<@<W1D0VQA<W,["B`@("`@
M("`@)')E='5R;BT^:&5A9&5R<R`](&%R<F%Y*"D["B`@("`@("`@)&AE861E
M<G,@/2`D=&AI<RT^7W!A<G-E2&5A9&5R<R@D:&5A9&5R<RD["@H@("`@("`@
M(&9O<F5A8V@@*"1H96%D97)S(&%S("1V86QU92D@>PH@("`@("`@("`@("!I
M9B`H:7-S970H)')E='5R;BT^:&5A9&5R<UMS=')T;VQO=V5R*"1V86QU95LG
M;F%M92==*5TI($%.1"`A:7-?87)R87DH)')E='5R;BT^:&5A9&5R<UMS=')T
M;VQO=V5R*"1V86QU95LG;F%M92==*5TI*2!["B`@("`@("`@("`@("`@("`D
M<F5T=7)N+3YH96%D97)S6W-T<G1O;&]W97(H)'9A;'5E6R=N86UE)UTI72`@
M(#T@87)R87DH)')E='5R;BT^:&5A9&5R<UMS=')T;VQO=V5R*"1V86QU95LG
M;F%M92==*5TI.PH@("`@("`@("`@("`@("`@)')E='5R;BT^:&5A9&5R<UMS
M=')T;VQO=V5R*"1V86QU95LG;F%M92==*5U;72`]("1V86QU95LG=F%L=64G
M73L*"B`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D<F5T=7)N+3YH96%D
M97)S6W-T<G1O;&]W97(H)'9A;'5E6R=N86UE)UTI72DI('L*("`@("`@("`@
M("`@("`@("1R971U<FXM/FAE861E<G-;<W1R=&]L;W=E<B@D=F%L=65;)VYA
M;64G72E=6UT@/2`D=F%L=65;)W9A;'5E)UT["@H@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)')E='5R;BT^:&5A9&5R<UMS=')T;VQO
M=V5R*"1V86QU95LG;F%M92==*5T@/2`D=F%L=65;)W9A;'5E)UT["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E<V5T*"1H96%D97)S*3L*
M("`@("`@("!W:&EL92`H;&ES="@D:V5Y+"`D=F%L=64I(#T@96%C:"@D:&5A
M9&5R<RDI('L*("`@("`@("`@("`@)&AE861E<G-;)&ME>5U;)VYA;64G72`]
M('-T<G1O;&]W97(H)&AE861E<G-;)&ME>5U;)VYA;64G72D["B`@("`@("`@
M("`@('-W:71C:"`H)&AE861E<G-;)&ME>5U;)VYA;64G72D@>PH*("`@("`@
M("`@("`@("`@(&-A<V4@)V-O;G1E;G0M='EP92<Z"B`@("`@("`@("`@("`@
M("`@("`@)&-O;G1E;G1?='EP92`]("1T:&ES+3Y?<&%R<V5(96%D97)686QU
M92@D:&5A9&5R<ULD:V5Y75LG=F%L=64G72D["@H@("`@("`@("`@("`@("`@
M("`@(&EF("AP<F5G7VUA=&-H*"<O*%LP+3EA+7HK+BU=*RE<+RA;,"TY82UZ
M*RXM72LI+VDG+"`D8V]N=&5N=%]T>7!E6R=V86QU92==+"`D<F5G<RDI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)')E='5R;BT^8W1Y<&5?<')I;6%R
M>2`@(#T@)')E9W-;,5T["B`@("`@("`@("`@("`@("`@("`@("`@("1R971U
M<FXM/F-T>7!E7W-E8V]N9&%R>2`]("1R96=S6S)=.PH@("`@("`@("`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1C;VYT
M96YT7W1Y<&5;)V]T:&5R)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M('=H:6QE("AL:7-T*"1P7VYA;64L("1P7W9A;'5E*2`](&5A8V@H)&-O;G1E
M;G1?='EP95LG;W1H97(G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1R971U<FXM/F-T>7!E7W!A<F%M971E<G-;)'!?;F%M95T@/2`D<%]V
M86QU93L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("`@("!C87-E("=C;VYT96YT+61I<W!O<VET:6]N)SH*("`@("`@("`@
M("`@("`@("`@("`D8V]N=&5N=%]D:7-P;W-I=&EO;B`]("1T:&ES+3Y?<&%R
M<V5(96%D97)686QU92@D:&5A9&5R<ULD:V5Y75LG=F%L=64G72D["B`@("`@
M("`@("`@("`@("`@("`@)')E='5R;BT^9&ES<&]S:71I;VX@("`]("1C;VYT
M96YT7V1I<W!O<VET:6]N6R=V86QU92==.PH@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D8V]N=&5N=%]D:7-P;W-I=&EO;ELG;W1H97(G72DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@=VAI;&4@*&QI<W0H)'!?;F%M92P@
M)'!?=F%L=64I(#T@96%C:"@D8V]N=&5N=%]D:7-P;W-I=&EO;ELG;W1H97(G
M72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R971U<FXM/F1?
M<&%R86UE=&5R<ULD<%]N86UE72`]("1P7W9A;'5E.PH@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)V-O;G1E
M;G0M=')A;G-F97(M96YC;V1I;F<G.@H@("`@("`@("`@("`@("`@("`@("1C
M;VYT96YT7W1R86YS9F5R7V5N8V]D:6YG(#T@)'1H:7,M/E]P87)S94AE861E
M<E9A;'5E*"1H96%D97)S6R1K97E=6R=V86QU92==*3L*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@:68@*&ES<V5T*"1C;VYT96YT7W1Y<&4I*2!["B`@("`@("`@("`@('-W
M:71C:"`H<W1R=&]L;W=E<B@D8V]N=&5N=%]T>7!E6R=V86QU92==*2D@>PH@
M("`@("`@("`@("`@("`@8V%S92`G=&5X="]P;&%I;B<Z"B`@("`@("`@("`@
M("`@("`@("`@)&5N8V]D:6YG(#T@:7-S970H)&-O;G1E;G1?=')A;G-F97)?
M96YC;V1I;F<I(#\@)&-O;G1E;G1?=')A;G-F97)?96YC;V1I;F=;)W9A;'5E
M)UT@.B`G-V)I="<["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;F-L
M=61E7V)O9&EE<R`_("1R971U<FXM/F)O9'D@/2`H)'1H:7,M/E]D96-O9&5?
M8F]D:65S(#\@)'1H:7,M/E]D96-O9&5";V1Y*"1B;V1Y+"`D96YC;V1I;F<I
M(#H@)&)O9'DI(#H@;G5L;#L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@("`@("!C87-E("=T97AT+VAT;6PG.@H@("`@("`@("`@
M("`@("`@("`@("1E;F-O9&EN9R`](&ES<V5T*"1C;VYT96YT7W1R86YS9F5R
M7V5N8V]D:6YG*2`_("1C;VYT96YT7W1R86YS9F5R7V5N8V]D:6YG6R=V86QU
M92==(#H@)S=B:70G.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YC
M;'5D95]B;V1I97,@/R`D<F5T=7)N+3YB;V1Y(#T@*"1T:&ES+3Y?9&5C;V1E
M7V)O9&EE<R`_("1T:&ES+3Y?9&5C;V1E0F]D>2@D8F]D>2P@)&5N8V]D:6YG
M*2`Z("1B;V1Y*2`Z(&YU;&P["B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("`@("`@8V%S92`G;75L=&EP87)T+W!A<F%L;&5L)SH*
M("`@("`@("`@("`@("`@(&-A<V4@)VUU;'1I<&%R="]R97!O<G0G.B`O+R!2
M1D,Q.#DR"B`@("`@("`@("`@("`@("!C87-E("=M=6QT:7!A<G0O<VEG;F5D
M)SH@+R\@4$=0"B`@("`@("`@("`@("`@("!C87-E("=M=6QT:7!A<G0O9&EG
M97-T)SH*("`@("`@("`@("`@("`@(&-A<V4@)VUU;'1I<&%R="]A;'1E<FYA
M=&EV92<Z"B`@("`@("`@("`@("`@("!C87-E("=M=6QT:7!A<G0O<F5L871E
M9"<Z"B`@("`@("`@("`@("`@("!C87-E("=M=6QT:7!A<G0O;6EX960G.@H@
M("`@("`@("`@("`@("`@("`@(&EF*"%I<W-E="@D8V]N=&5N=%]T>7!E6R=O
M=&AE<B==6R=B;W5N9&%R>2==*2E["B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?97)R;W(@/2`G3F\@8F]U;F1A<GD@9F]U;F0@9F]R("<@+B`D
M8V]N=&5N=%]T>7!E6R=V86QU92==("X@)R!P87)T)SL*("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`@("`@)&1E9F%U;'1?8W1Y<&4@/2`H<W1R
M=&]L;W=E<B@D8V]N=&5N=%]T>7!E6R=V86QU92==*2`]/3T@)VUU;'1I<&%R
M="]D:6=E<W0G*2`_("=M97-S86=E+W)F8S@R,B<@.B`G=&5X="]P;&%I;B<[
M"@H@("`@("`@("`@("`@("`@("`@("1P87)T<R`]("1T:&ES+3Y?8F]U;F1A
M<GE3<&QI="@D8F]D>2P@)&-O;G1E;G1?='EP95LG;W1H97(G75LG8F]U;F1A
M<GDG72D["B`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M8V]U;G0H)'!A<G1S*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!L:7-T*"1P87)T7VAE861E<BP@)'!A<G1?8F]D>2D@/2`D=&AI<RT^7W-P
M;&ET0F]D>4AE861E<B@D<&%R='-;)&E=*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@)'!A<G0@/2`D=&AI<RT^7V1E8V]D92@D<&%R=%]H96%D97(L("1P
M87)T7V)O9'DL("1D969A=6QT7V-T>7!E*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@:68H)'!A<G0@/3T](&9A;'-E*0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!A<G0@/2`D=&AI<RT^<F%I<V5%<G)O<B@D=&AI<RT^7V5R
M<F]R*3L*("`@("`@("`@("`@("`@("`@("`@("`@)')E='5R;BT^<&%R='-;
M72`]("1P87)T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=M97-S86=E
M+W)F8S@R,B<Z"B`@("`@("`@("`@("`@("`@("`@)&]B:B`]("9N97<@36%I
M;%]M:6UE1&5C;V1E*"1B;V1Y*3L*("`@("`@("`@("`@("`@("`@("`D<F5T
M=7)N+3YP87)T<UM=(#T@)&]B:BT^9&5C;V1E*&%R<F%Y*"=I;F-L=61E7V)O
M9&EE<R<@/3X@)'1H:7,M/E]I;F-L=61E7V)O9&EE<RP*"0D)"0D@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D96-O9&5?8F]D:65S
M)R`@/3X@)'1H:7,M/E]D96-O9&5?8F]D:65S+`H)"0D)"0D)"0D)"0D)"2`@
M)V1E8V]D95]H96%D97)S)R`]/B`D=&AI<RT^7V1E8V]D95]H96%D97)S*2D[
M"B`@("`@("`@("`@("`@("`@("`@=6YS970H)&]B:BD["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@9&5F875L=#H*("`@
M("`@("`@("`@("`@("`@("!I9B@A:7-S970H)&-O;G1E;G1?=')A;G-F97)?
M96YC;V1I;F=;)W9A;'5E)UTI*0H@("`@("`@("`@("`@("`@("`@("`@("`D
M8V]N=&5N=%]T<F%N<V9E<E]E;F-O9&EN9ULG=F%L=64G72`]("<W8FET)SL*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VEN8VQU9&5?8F]D:65S(#\@
M)')E='5R;BT^8F]D>2`]("@D=&AI<RT^7V1E8V]D95]B;V1I97,@/R`D=&AI
M<RT^7V1E8V]D94)O9'DH)&)O9'DL("1C;VYT96YT7W1R86YS9F5R7V5N8V]D
M:6YG6R=V86QU92==*2`Z("1B;V1Y*2`Z(&YU;&P["B`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@('T*"B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&-T>7!E(#T@97AP;&]D92@G+R<L("1D969A=6QT7V-T
M>7!E*3L*("`@("`@("`@("`@)')E='5R;BT^8W1Y<&5?<')I;6%R>2`@(#T@
M)&-T>7!E6S!=.PH@("`@("`@("`@("`D<F5T=7)N+3YC='EP95]S96-O;F1A
M<GD@/2`D8W1Y<&5;,5T["B`@("`@("`@("`@("1T:&ES+3Y?:6YC;'5D95]B
M;V1I97,@/R`D<F5T=7)N+3YB;V1Y(#T@*"1T:&ES+3Y?9&5C;V1E7V)O9&EE
M<R`_("1T:&ES+3Y?9&5C;V1E0F]D>2@D8F]D>2D@.B`D8F]D>2D@.B!N=6QL
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R971U<FX["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!':79E;B!T:&4@;W5T<'5T(&]F('1H92!A8F]V92!F
M=6YC=&EO;BP@=&AI<R!W:6QL(')E='5R;B!A;@H@("`@("H@87)R87D@;V8@
M<F5F97)E;F-E<R!T;R!T:&4@<&%R=',L(&EN9&5X960@8GD@;6EM92!N=6UB
M97(N"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0@)'-T<G5C='5R92`@
M(%1H92!S=')U8W1U<F4@=&\@9V\@=&AR;W5G:`H@("`@("H@0'!A<F%M("!S
M=')I;F<@)&UI;65?;G5M8F5R($EN=&5R;F%L('5S92!O;FQY+@H@("`@("H@
M0')E='5R;B!A<G)A>2`@("`@("`@("`@("`@($UI;64@;G5M8F5R<PH@("`@
M("HO"B`@("!F=6YC=&EO;B`F9V5T36EM94YU;6)E<G,H)B1S=')U8W1U<F4L
M("1N;U]R969S(#T@9F%L<V4L("1M:6UE7VYU;6)E<B`]("<G+"`D<')E<&5N
M9"`]("<G*0H@("`@>PH@("`@("`@("1R971U<FX@/2!A<G)A>2@I.PH@("`@
M("`@(&EF("@A96UP='DH)'-T<G5C='5R92T^<&%R=',I*2!["B`@("`@("`@
M("`@(&EF("@D;6EM95]N=6UB97(@(3T@)R<I('L*("`@("`@("`@("`@("`@
M("1S=')U8W1U<F4M/FUI;65?:60@/2`D<')E<&5N9"`N("1M:6UE7VYU;6)E
M<CL*("`@("`@("`@("`@("`@("1R971U<FY;)'!R97!E;F0@+B`D;6EM95]N
M=6UB97)=(#T@)B1S=')U8W1U<F4["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)'-T<G5C='5R92T^<&%R=',I
M.R`D:2LK*2!["@H@("`@("`@("`@("`*("`@("`@("`@("`@("`@(&EF("@A
M96UP='DH)'-T<G5C='5R92T^:&5A9&5R<ULG8V]N=&5N="UT>7!E)UTI($%.
M1"!S=6)S='(H<W1R=&]L;W=E<B@D<W1R=6-T=7)E+3YH96%D97)S6R=C;VYT
M96YT+71Y<&4G72DL(#`L(#@I(#T]("=M97-S86=E+R<I('L*("`@("`@("`@
M("`@("`@("`@("`D<')E<&5N9"`@("`@(#T@)'!R97!E;F0@+B`D;6EM95]N
M=6UB97(@+B`G+B<["B`@("`@("`@("`@("`@("`@("`@)%]M:6UE7VYU;6)E
M<B`]("<G.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D7VUI;65?;G5M8F5R(#T@*"1M:6UE7VYU;6)E<B`]/2`G)R`_
M("1I("L@,2`Z('-P<FEN=&8H)R5S+B5S)RP@)&UI;65?;G5M8F5R+"`D:2`K
M(#$I*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D87)R
M(#T@)DUA:6Q?;6EM941E8V]D93HZ9V5T36EM94YU;6)E<G,H)'-T<G5C='5R
M92T^<&%R='-;)&E=+"`D;F]?<F5F<RP@)%]M:6UE7VYU;6)E<BP@)'!R97!E
M;F0I.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&%R<B!A<R`D:V5Y(#T^
M("1V86PI('L*("`@("`@("`@("`@("`@("`@("`D;F]?<F5F<R`_("1R971U
M<FY;)&ME>5T@/2`G)R`Z("1R971U<FY;)&ME>5T@/2`F)&%R<ELD:V5Y73L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(&EF("@D;6EM95]N=6UB97(@/3T@)R<I('L*("`@
M("`@("`@("`@("`@("1M:6UE7VYU;6)E<B`]("<Q)SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D<W1R=6-T=7)E+3YM:6UE7VED(#T@)'!R97!E;F0@
M+B`D;6EM95]N=6UB97(["B`@("`@("`@("`@("1N;U]R969S(#\@)')E='5R
M;ELD<')E<&5N9"`N("1M:6UE7VYU;6)E<ET@/2`G)R`Z("1R971U<FY;)'!R
M97!E;F0@+B`D;6EM95]N=6UB97)=(#T@)B1S=')U8W1U<F4["B`@("`@("`@
M?0H@("`@("`@(`H@("`@("`@(')E='5R;B`D<F5T=7)N.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1VEV96X@82!S=')I;F<@8V]N=&%I;FEN9R!A(&AE861E
M<B!A;F0@8F]D>0H@("`@("H@<V5C=&EO;BP@=&AI<R!F=6YC=&EO;B!W:6QL
M('-P;&ET('1H96T@*&%T('1H92!F:7)S=`H@("`@("H@8FQA;FL@;&EN92D@
M86YD(')E='5R;B!T:&5M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M26YP=70@=&\@<W!L:70@87!A<G0*("`@("`J($!R971U<FX@87)R87D@0V]N
M=&%I;G,@:&5A9&5R(&%N9"!B;V1Y('-E8W1I;VX*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?<W!L:71";V1Y2&5A9&5R
M*"1I;G!U="D*("`@('L*("`@("`@("!I9B`H<')E9U]M871C:"@B+UXH+BH_
M*5QR/UQN7'(_7&XH+BHI+W,B+"`D:6YP=70L("1M871C:"DI('L*("`@("`@
M("`@("`@<F5T=7)N(&%R<F%Y*"1M871C:%LQ72P@)&UA=&-H6S)=*3L*("`@
M("`@("!]"B`@("`@("`@)'1H:7,M/E]E<G)O<B`]("=#;W5L9"!N;W0@<W!L
M:70@:&5A9&5R(&%N9"!B;V1Y)SL*("`@("`@("!R971U<FX@9F%L<V4["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!087)S92!H96%D97)S(&=I=F5N(&EN("1I
M;G!U="!A;F0@<F5T=7)N"B`@("`@*B!A<R!A<W-O8R!A<G)A>2X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG($AE861E<G,@=&\@<&%R<V4*("`@("`J
M($!R971U<FX@87)R87D@0V]N=&%I;G,@<&%R<V5D(&AE861E<G,*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5(
M96%D97)S*"1I;G!U="D*("`@('L*"B`@("`@("`@:68@*"1I;G!U="`A/3T@
M)R<I('L*("`@("`@("`@("`@+R\@56YF;VQD('1H92!I;G!U=`H@("`@("`@
M("`@("`D:6YP=70@("`]('!R96=?<F5P;&%C92@B+UQR/UQN+R(L(")<<EQN
M(BP@)&EN<'5T*3L*("`@("`@("`@("`@)&EN<'5T("`@/2!P<F5G7W)E<&QA
M8V4H(B]<<EQN*%QT?"`I*R\B+"`G("<L("1I;G!U="D["B`@("`@("`@("`@
M("1H96%D97)S(#T@97AP;&]D92@B7')<;B(L('1R:6TH)&EN<'5T*2D["@H@
M("`@("`@("`@("!F;W)E86-H("@D:&5A9&5R<R!A<R`D=F%L=64I('L*("`@
M("`@("`@("`@("`@("1H9')?;F%M92`]('-U8G-T<B@D=F%L=64L(#`L("1P
M;W,@/2!S=')P;W,H)'9A;'5E+"`G.B<I*3L*("`@("`@("`@("`@("`@("1H
M9')?=F%L=64@/2!S=6)S='(H)'9A;'5E+"`D<&]S*S$I.PH@("`@("`@("`@
M("`@("`@:68H)&AD<E]V86QU95LP72`]/2`G("<I"B`@("`@("`@("`@("`@
M("`@("`@)&AD<E]V86QU92`]('-U8G-T<B@D:&1R7W9A;'5E+"`Q*3L*"B`@
M("`@("`@("`@("`@("`D<F5T=7)N6UT@/2!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=N86UE)R`@/3X@)&AD<E]N86UE+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9A;'5E)R`]/B`D
M=&AI<RT^7V1E8V]D95]H96%D97)S(#\@)'1H:7,M/E]D96-O9&5(96%D97(H
M)&AD<E]V86QU92D@.B`D:&1R7W9A;'5E"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D<F5T=7)N(#T@87)R87DH*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D<F5T=7)N.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1G5N8W1I;VX@=&\@<&%R<V4@82!H96%D97(@=F%L=64L"B`@("`@*B!E>'1R
M86-T(&9I<G-T('!A<G0L(&%N9"!A;GD@<V5C;VYD87)Y"B`@("`@*B!P87)T
M<R`H869T97(@.RD@5&AI<R!F=6YC=&EO;B!I<R!N;W0@87,*("`@("`J(')O
M8G5S="!A<R!I="!C;W5L9"!B92X@16<N(&AE861E<B!C;VUM96YT<PH@("`@
M("H@:6X@=&AE('=R;VYG('!L86-E('=I;&P@<')O8F%B;'D@8G)E86L@:70N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!(96%D97(@=F%L=64@=&\@
M<&%R<V4*("`@("`J($!R971U<FX@87)R87D@0V]N=&%I;G,@<&%R<V5D(')E
M<W5L=`H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]P87)S94AE861E<E9A;'5E*"1I;G!U="D*("`@('L*"B`@("`@("`@
M:68@*"@D<&]S(#T@<W1R<&]S*"1I;G!U="P@)SLG*2D@(3T](&9A;'-E*2![
M"@H@("`@("`@("`@("`D<F5T=7)N6R=V86QU92==(#T@=')I;2AS=6)S='(H
M)&EN<'5T+"`P+"`D<&]S*2D["B`@("`@("`@("`@("1I;G!U="`]('1R:6TH
M<W5B<W1R*"1I;G!U="P@)'!O<RLQ*2D["@H@("`@("`@("`@("!I9B`H<W1R
M;&5N*"1I;G!U="D@/B`P*2!["@H@("`@("`@("`@("`@("`@+R\@5&AI<R!S
M<&QI=',@;VX@82!S96UI+6-O;&]N+"!I9B!T:&5R92=S(&YO('!R96-E961I
M;F<@8F%C:W-L87-H"B`@("`@("`@("`@("`@("`O+R!.;W<@=V]R:W,@=VET
M:"!Q=6]T960@=F%L=65S.R!H860@=&\@9VQU92!T:&4@7#L@8G)E86MS(&EN
M(%!(4`H@("`@("`@("`@("`@("`@+R\@=&AE(')E9V5X(&ES(&%L<F5A9'D@
M8F]R9&5R:6YG(&]N(&EN8V]M<')E:&5N<VEB;&4*("`@("`@("`@("`@("`@
M("1S<&QI=%)E9V5X(#T@)R\H6UX[7"<B72I;7"<B72A;7EPG(ETJ*%M>7"<B
M72HI*BE;7"<B75M>.UPG(ETJ?"A;7CM=*RDI*#M\)"DO)SL*("`@("`@("`@
M("`@("`@('!R96=?;6%T8VA?86QL*"1S<&QI=%)E9V5X+"`D:6YP=70L("1M
M871C:&5S*3L*("`@("`@("`@("`@("`@("1P87)A;65T97)S(#T@87)R87DH
M*3L*("`@("`@("`@("`@("`@(&9O<B`H)&D],#L@)&D\8V]U;G0H)&UA=&-H
M97-;,%TI.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@)'!A<F%M(#T@
M)&UA=&-H97-;,%U;)&E=.PH@("`@("`@("`@("`@("`@("`@('=H:6QE("AS
M=6)S='(H)'!A<F%M+"`M,BD@/3T@)UP[)RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D<&%R86T@+CT@)&UA=&-H97-;,%U;*RLD:5T["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1P87)A;65T97)S
M6UT@/2`D<&%R86T["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)'!A<F%M971E<G,I.R`D:2LK
M*2!["B`@("`@("`@("`@("`@("`@("`@)'!A<F%M7VYA;64@(#T@=')I;2AS
M=6)S='(H)'!A<F%M971E<G-;)&E=+"`P+"`D<&]S(#T@<W1R<&]S*"1P87)A
M;65T97)S6R1I72P@)STG*2DL("(G7"([7'1<7"`B*3L*("`@("`@("`@("`@
M("`@("`@("`D<&%R86U?=F%L=64@/2!T<FEM*'-T<E]R97!L86-E*"=<.R<L
M("<[)RP@<W5B<W1R*"1P87)A;65T97)S6R1I72P@)'!O<R`K(#$I*2P@(B=<
M(CM<=%Q<("(I.PH@("`@("`@("`@("`@("`@("`@(&EF("@D<&%R86U?=F%L
M=65;,%T@/3T@)R(G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1P87)A
M;5]V86QU92`]('-U8G-T<B@D<&%R86U?=F%L=64L(#$L("TQ*3L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)')E='5R;ELG
M;W1H97(G75LD<&%R86U?;F%M95T@/2`D<&%R86U?=F%L=64["B`@("`@("`@
M("`@("`@("`@("`@)')E='5R;ELG;W1H97(G75MS=')T;VQO=V5R*"1P87)A
M;5]N86UE*5T@/2`D<&%R86U?=F%L=64["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5T
M=7)N6R=V86QU92==(#T@=')I;2@D:6YP=70I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1R971U<FX["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES
M(&9U;F-T:6]N('-P;&ET<R!T:&4@:6YP=70@8F%S960*("`@("`J(&]N('1H
M92!G:79E;B!B;W5N9&%R>0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M26YP=70@=&\@<&%R<V4*("`@("`J($!R971U<FX@87)R87D@0V]N=&%I;G,@
M87)R87D@;V8@<F5S=6QT:6YG(&UI;64@<&%R=',*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?8F]U;F1A<GE3<&QI="@D
M:6YP=70L("1B;W5N9&%R>2D*("`@('L*("`@("`@("`D<&%R=',@/2!A<G)A
M>2@I.PH*("`@("`@("`D8G-?<&]S<VEB;&4@/2!S=6)S='(H)&)O=6YD87)Y
M+"`R+"`M,BD["B`@("`@("`@)&)S7V-H96-K(#T@)UPB)R`N("1B<U]P;W-S
M:6)L92`N("=<(B<["@H@("`@("`@(&EF("@D8F]U;F1A<GD@/3T@)&)S7V-H
M96-K*2!["B`@("`@("`@("`@("1B;W5N9&%R>2`]("1B<U]P;W-S:6)L93L*
M("`@("`@("!]"@H@("`@("`@("1T;7`@/2!E>'!L;V1E*"<M+2<@+B`D8F]U
M;F1A<GDL("1I;G!U="D["@H@("`@("`@(&9O<B`H)&D@/2`Q.R`D:2`\(&-O
M=6YT*"1T;7`I("T@,3L@)&DK*RD@>PH@("`@("`@("`@("`D<&%R='-;72`]
M("1T;7!;)&E=.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P87)T<SL*
M("`@('T*"B`@("`O*BH*("`@("`J($=I=F5N(&$@:&5A9&5R+"!T:&ES(&9U
M;F-T:6]N('=I;&P@9&5C;V1E(&ET"B`@("`@*B!A8V-O<F1I;F<@=&\@4D9#
M,C`T-RX@4')O8F%B;'D@;F]T("IE>&%C=&QY*@H@("`@("H@8V]N9F]R;6%N
M="P@8G5T(&ET(&1O97,@<&%S<R!A;&P@=&AE(&=I=F5N"B`@("`@*B!E>&%M
M<&QE<R`H:6X@4D9#,C`T-RDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R!);G!U="!H96%D97(@=F%L=64@=&\@9&5C;V1E"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R!$96-O9&5D(&AE861E<B!V86QU90H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D96-O9&5(96%D97(H)&EN
M<'5T*0H@("`@>PH@("`@("`@("\O(%)E;6]V92!W:&ET92!S<&%C92!B971W
M965N(&5N8V]D960M=V]R9',*("`@("`@("`D:6YP=70@/2!P<F5G7W)E<&QA
M8V4H)R\H/5P_6UX_72M</RAQ?&(I7#];7C]=*EP_/2DH7',I*SU</R]I)RP@
M)UPQ/3\G+"`D:6YP=70I.PH*("`@("`@("`O+R!&;W(@96%C:"!E;F-O9&5D
M+7=O<F0N+BX*("`@("`@("!W:&EL92`H<')E9U]M871C:"@G+R@]7#\H6UX_
M72LI7#\H<7QB*5P_*%M>/UTJ*5P_/2DO:2<L("1I;G!U="P@)&UA=&-H97,I
M*2!["@H@("`@("`@("`@("`D96YC;V1E9"`@/2`D;6%T8VAE<ULQ73L*("`@
M("`@("`@("`@)&-H87)S970@(#T@)&UA=&-H97-;,ET["B`@("`@("`@("`@
M("1E;F-O9&EN9R`]("1M871C:&5S6S-=.PH@("`@("`@("`@("`D=&5X="`@
M("`@/2`D;6%T8VAE<ULT73L*"B`@("`@("`@("`@('-W:71C:"`H<W1R=&]L
M;W=E<B@D96YC;V1I;F<I*2!["B`@("`@("`@("`@("`@("!C87-E("=B)SH*
M("`@("`@("`@("`@("`@("`@("`D=&5X="`](&)A<V4V-%]D96-O9&4H)'1E
M>'0I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M("`@(&-A<V4@)W$G.@H@("`@("`@("`@("`@("`@("`@("1T97AT(#T@<W1R
M7W)E<&QA8V4H)U\G+"`G("<L("1T97AT*3L*("`@("`@("`@("`@("`@("`@
M("!P<F5G7VUA=&-H7V%L;"@G+STH6V$M9C`M.5U[,GTI+VDG+"`D=&5X="P@
M)&UA=&-H97,I.PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@H)&UA=&-H
M97-;,5T@87,@)'9A;'5E*0H@("`@("`@("`@("`@("`@("`@("`@("`D=&5X
M="`]('-T<E]R97!L86-E*"<])RXD=F%L=64L(&-H<BAH97AD96,H)'9A;'5E
M*2DL("1T97AT*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)&EN<'5T(#T@<W1R7W)E<&QA8V4H)&5N
M8V]D960L("1T97AT+"`D:6YP=70I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1I;G!U=#L*("`@('T*"B`@("`O*BH*("`@("`J($=I=F5N(&$@8F]D
M>2!S=')I;F<@86YD(&%N(&5N8V]D:6YG('1Y<&4L"B`@("`@*B!T:&ES(&9U
M;F-T:6]N('=I;&P@9&5C;V1E(&%N9"!R971U<FX@:70N"B`@("`@*@H@("`@
M("H@0'!A<F%M("!S=')I;F<@26YP=70@8F]D>2!T;R!D96-O9&4*("`@("`J
M($!P87)A;2`@<W1R:6YG($5N8V]D:6YG('1Y<&4@=&\@=7-E+@H@("`@("H@
M0')E='5R;B!S=')I;F<@1&5C;V1E9"!B;V1Y"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V1E8V]D94)O9'DH)&EN<'5T
M+"`D96YC;V1I;F<@/2`G-V)I="<I"B`@("!["B`@("`@("`@<W=I=&-H("AS
M=')T;VQO=V5R*"1E;F-O9&EN9RDI('L*("`@("`@("`@("`@8V%S92`G-V)I
M="<Z"B`@("`@("`@("`@("`@("!R971U<FX@)&EN<'5T.PH@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=Q=6]T960M<')I;G1A
M8FQE)SH*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W%U;W1E9%!R
M:6YT86)L941E8V]D92@D:6YP=70I.PH@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("!C87-E("=B87-E-C0G.@H@("`@("`@("`@("`@("`@
M<F5T=7)N(&)A<V4V-%]D96-O9&4H)&EN<'5T*3L*("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@
M(')E='5R;B`D:6YP=70["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@1VEV96X@82!Q=6]T960M<')I;G1A8FQE('-T<FEN9RP@=&AI<PH@("`@
M("H@9G5N8W1I;VX@=VEL;"!D96-O9&4@86YD(')E='5R;B!I="X*("`@("`J
M"B`@("`@*B!`<&%R86T@('-T<FEN9R!);G!U="!B;V1Y('1O(&1E8V]D90H@
M("`@("H@0')E='5R;B!S=')I;F<@1&5C;V1E9"!B;V1Y"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7W%U;W1E9%!R:6YT
M86)L941E8V]D92@D:6YP=70I"B`@("!["B`@("`@("`@+R\@4F5M;W9E('-O
M9G0@;&EN92!B<F5A:W,*("`@("`@("`D:6YP=70@/2!P<F5G7W)E<&QA8V4H
M(B\]7'(_7&XO(BP@)R<L("1I;G!U="D["@H@("`@("`@("\O(%)E<&QA8V4@
M96YC;V1E9"!C:&%R86-T97)S"@D))&EN<'5T(#T@<')E9U]R97!L86-E*"<O
M/2A;82UF,"TY77LR?2DO:64G+"`B8VAR*&AE>&1E8R@G7%PQ)RDI(BP@)&EN
M<'5T*3L*"B`@("`@("`@<F5T=7)N("1I;G!U=#L*("`@('T*"B`@("`O*BH*
M("`@("`J($-H96-K<R!T:&4@:6YP=70@9F]R('5U96YC;V1E9"!F:6QE<R!A
M;F0@<F5T=7)N<PH@("`@("H@86X@87)R87D@;V8@=&AE;2X@0V%N(&)E(&-A
M;&QE9"!S=&%T:6-A;&QY+"!E9SH*("`@("`J"B`@("`@*B`D9FEL97,@/28@
M36%I;%]M:6UE1&5C;V1E.CIU=61E8V]D92@D<V]M95]T97AT*3L*("`@("`J
M"B`@("`@*B!)="!W:6QL(&-H96-K(&9O<B!T:&4@8F5G:6X@-C8V("XN+B!E
M;F0@<WEN=&%X"B`@("`@*B!H;W=E=F5R(&%N9"!W;VXG="!J=7-T(&)L:6YD
M;'D@9&5C;V1E('=H871E=F5R('EO=0H@("`@("H@<&%S<R!I="X*("`@("`J
M"B`@("`@*B!`<&%R86T@('-T<FEN9R!);G!U="!B;V1Y('1O(&QO;VL@9F]R
M(&%T=&%H8VUE;G1S(&EN"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!$96-O9&5D
M(&)O9&EE<RP@9FEL96YA;65S(&%N9"!P97)M:7-S:6]N<PH@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!A=71H;W(@56YK;F]W;@H@("`@("HO"B`@
M("!F=6YC=&EO;B`F=75D96-O9&4H)&EN<'5T*0H@("`@>PH@("`@("`@("\O
M($9I;F0@86QL('5U96YC;V1E9"!S96-T:6]N<PH@("`@("`@('!R96=?;6%T
M8VA?86QL*"(O8F5G:6X@*%LP+3==>S-]*2`H+BLI7'(_7&XH+BLI7'(_7&YE
M;F0O57,B+"`D:6YP=70L("1M871C:&5S*3L*"B`@("`@("`@9F]R("@D:B`]
M(#`[("1J(#P@8V]U;G0H)&UA=&-H97-;,UTI.R`D:BLK*2!["@H@("`@("`@
M("`@("`D<W1R("`@("`@/2`D;6%T8VAE<ULS75LD:ET["B`@("`@("`@("`@
M("1F:6QE;F%M92`]("1M871C:&5S6S)=6R1J73L*("`@("`@("`@("`@)&9I
M;&5P97)M(#T@)&UA=&-H97-;,5U;)&I=.PH*("`@("`@("`@("`@)&9I;&4@
M/2`G)SL*("`@("`@("`@("`@)'-T<B`]('!R96=?<W!L:70H(B]<<C]<;B\B
M+"!T<FEM*"1S='(I*3L*("`@("`@("`@("`@)'-T<FQE;B`](&-O=6YT*"1S
M='(I.PH*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)'-T<FQE;CL@
M)&DK*RD@>PH@("`@("`@("`@("`@("`@)'!O<R`](#$["B`@("`@("`@("`@
M("`@("`D9"`](#`["B`@("`@("`@("`@("`@("`D;&5N/2AI;G0I*"@H;W)D
M*'-U8G-T<B@D<W1R6R1I72PP+#$I*2`M,S(I("T@)R`G*2`F(#`W-RD["@H@
M("`@("`@("`@("`@("`@=VAI;&4@*"@D9"`K(#,@/#T@)&QE;BD@04Y$("@D
M<&]S("L@-"`\/2!S=')L96XH)'-T<ELD:5TI*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1C,"`]("AO<F0H<W5B<W1R*"1S=');)&E=+"1P;W,L,2DI(%X@
M,'@R,"D["B`@("`@("`@("`@("`@("`@("`@)&,Q(#T@*&]R9"AS=6)S='(H
M)'-T<ELD:5TL)'!O<RLQ+#$I*2!>(#!X,C`I.PH@("`@("`@("`@("`@("`@
M("`@("1C,B`]("AO<F0H<W5B<W1R*"1S=');)&E=+"1P;W,K,BPQ*2D@7B`P
M>#(P*3L*("`@("`@("`@("`@("`@("`@("`D8S,@/2`H;W)D*'-U8G-T<B@D
M<W1R6R1I72PD<&]S*S,L,2DI(%X@,'@R,"D["B`@("`@("`@("`@("`@("`@
M("`@)&9I;&4@+CT@8VAR*"@H*"1C,"`M("<@)RD@)B`P-S<I(#P\(#(I('P@
M*"@H)&,Q("T@)R`G*2`F(#`W-RD@/CX@-"DI.PH*("`@("`@("`@("`@("`@
M("`@("`D9FEL92`N/2!C:'(H*"@H)&,Q("T@)R`G*2`F(#`W-RD@/#P@-"D@
M?"`H*"@D8S(@+2`G("<I("8@,#<W*2`^/B`R*2D["@H@("`@("`@("`@("`@
M("`@("`@("1F:6QE("X](&-H<B@H*"@D8S(@+2`G("<I("8@,#<W*2`\/"`V
M*2!\("`H*"1C,R`M("<@)RD@)B`P-S<I*3L*"B`@("`@("`@("`@("`@("`@
M("`@)'!O<R`K/2`T.PH@("`@("`@("`@("`@("`@("`@("1D("L](#,["B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*"@D9"`K(#(@
M/#T@)&QE;BD@)B8@*"1P;W,@*R`S(#P]('-T<FQE;B@D<W1R6R1I72DI*2![
M"B`@("`@("`@("`@("`@("`@("`@)&,P(#T@*&]R9"AS=6)S='(H)'-T<ELD
M:5TL)'!O<RPQ*2D@7B`P>#(P*3L*("`@("`@("`@("`@("`@("`@("`D8S$@
M/2`H;W)D*'-U8G-T<B@D<W1R6R1I72PD<&]S*S$L,2DI(%X@,'@R,"D["B`@
M("`@("`@("`@("`@("`@("`@)&,R(#T@*&]R9"AS=6)S='(H)'-T<ELD:5TL
M)'!O<RLR+#$I*2!>(#!X,C`I.PH@("`@("`@("`@("`@("`@("`@("1F:6QE
M("X](&-H<B@H*"@D8S`@+2`G("<I("8@,#<W*2`\/"`R*2!\("@H*"1C,2`M
M("<@)RD@)B`P-S<I(#X^(#0I*3L*"B`@("`@("`@("`@("`@("`@("`@)&9I
M;&4@+CT@8VAR*"@H*"1C,2`M("<@)RD@)B`P-S<I(#P\(#0I('P@*"@H)&,R
M("T@)R`G*2`F(#`W-RD@/CX@,BDI.PH*("`@("`@("`@("`@("`@("`@("`D
M<&]S("L](#,["B`@("`@("`@("`@("`@("`@("`@)&0@*ST@,CL*("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H*"1D("L@,2`\/2`D
M;&5N*2`F)B`H)'!O<R`K(#(@/#T@<W1R;&5N*"1S=');)&E=*2DI('L*("`@
M("`@("`@("`@("`@("`@("`D8S`@/2`H;W)D*'-U8G-T<B@D<W1R6R1I72PD
M<&]S+#$I*2!>(#!X,C`I.PH@("`@("`@("`@("`@("`@("`@("1C,2`]("AO
M<F0H<W5B<W1R*"1S=');)&E=+"1P;W,K,2PQ*2D@7B`P>#(P*3L*("`@("`@
M("`@("`@("`@("`@("`D9FEL92`N/2!C:'(H*"@H)&,P("T@)R`G*2`F(#`W
M-RD@/#P@,BD@?"`H*"@D8S$@+2`G("<I("8@,#<W*2`^/B`T*2D["@H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1F:6QE
M<UM=(#T@87)R87DH)V9I;&5N86UE)R`]/B`D9FEL96YA;64L("=F:6QE<&5R
M;2<@/3X@)&9I;&5P97)M+"`G9FEL961A=&$G(#T^("1F:6QE*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D9FEL97,["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!G971396YD07)R87DH*2!R971U<FYS('1H92!A<F=U;65N=',@<F5Q
M=6ER960@9F]R($UA:6PZ.G-E;F0H*0H@("`@("H@=7-E9"!T;R!B=6EL9"!T
M:&4@87)G=6UE;G1S(&9O<B!A(&UA:6PZ.G-E;F0H*2!C86QL(`H@("`@("H*
M("`@("`J(%5S86=E.@H@("`@("H@)&UA:6QT97AT(#T@1G5L;"!E;6%I;"`H
M9F]R(&5X86UP;&4@9V5N97)A=&5D(&)Y(&$@=&5M<&QA=&4I"B`@("`@*B`D
M9&5C;V1E<B`](&YE=R!-86EL7VUI;65$96-O9&4H)&UA:6QT97AT*3L*("`@
M("`J("1P87)T<R`]("`D9&5C;V1E<BT^9V5T4V5N9$%R<F%Y*"D["B`@("`@
M*B!I9B`H(5!%05(Z.FES17)R;W(H)'!A<G1S*2!["B`@("`@*B`@("`@;&ES
M="@D<F5C:7!E;G1S+"1H96%D97)S+"1B;V1Y*2`]("1P87)T<SL*("`@("`J
M("`@("`D;6%I;"`]($UA:6PZ.F9A8W1O<GDH)W-M='`G*3L*("`@("`J("`@
M("`D;6%I;"T^<V5N9"@D<F5C:7!E;G1S+"1H96%D97)S+"1B;V1Y*3L*("`@
M("`J('T@96QS92!["B`@("`@*B`@("`@96-H;R`D<&%R=',M/FUE<W-A9V4[
M"B`@("`@*B!]"B`@("`@*B!`<F5T=7)N(&UI>&5D("`@87)R87D@;V8@<F5C
M:7!E:6YT+"!H96%D97)S+&)O9'D@;W(@4&5A<E]%<G)O<@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!A=71H;W(@06QA;B!+;F]W;&5S(#QA;&%N
M0&%K8FMH;VUE+F-O;3X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4V5N9$%R
M<F%Y*"D*("`@('L*("`@("`@("`O+R!P<F5V96YT('=A<FYI;F<@:68@=&AI
M<R!I<R!N;W0@<V5T"B`@("`@("`@)'1H:7,M/E]D96-O9&5?:&5A9&5R<R`]
M($9!3%-%.PH@("`@("`@("1H96%D97)L:7-T(#TD=&AI<RT^7W!A<G-E2&5A
M9&5R<R@D=&AI<RT^7VAE861E<BD["B`@("`@("`@)'1O(#T@(B(["B`@("`@
M("`@:68@*"$D:&5A9&5R;&ES="D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H(DUE<W-A9V4@9&ED(&YO="!C;VYT86EN(&AE861E
M<G,B*3L*("`@("`@("!]"B`@("`@("`@9F]R96%C:"@D:&5A9&5R;&ES="!A
M<R`D:71E;2D@>PH@("`@("`@("`@("`D:&5A9&5R6R1I=&5M6R=N86UE)UU=
M(#T@)&ET96U;)W9A;'5E)UT["B`@("`@("`@("`@('-W:71C:"`H<W1R=&]L
M;W=E<B@D:71E;5LG;F%M92==*2D@>PH@("`@("`@("`@("`@("`@8V%S92`B
M=&\B.@H@("`@("`@("`@("`@("`@8V%S92`B8V,B.@H@("`@("`@("`@("`@
M("`@8V%S92`B8F-C(CH*("`@("`@("`@("`@("`@("`@("`D=&\@/2`B+"(N
M)&ET96U;)W9A;'5E)UT["B`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@:68@*"1T;R`]/2`B(BD@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H(DUE<W-A9V4@9&ED(&YO="!C;VYT86EN(&%N
M>2!R96-I<&5N=',B*3L*("`@("`@("!]"B`@("`@("`@)'1O(#T@<W5B<W1R
M*"1T;RPQ*3L*("`@("`@("!R971U<FX@87)R87DH)'1O+"1H96%D97(L)'1H
M:7,M/E]B;V1Y*3L*("`@('T@"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@
M>&UL(&-O<'D@;V8@=&AE(&]U='!U="!O9@H@("`@("H@36%I;%]M:6UE1&5C
M;V1E.CID96-O9&4N(%!A<W,@=&AE(&]U='!U="!I;B!A<R!T:&4*("`@("`J
M(&%R9W5M96YT+B!4:&ES(&9U;F-T:6]N(&-A;B!B92!C86QL960@<W1A=&EC
M86QL>2X@16<Z"B`@("`@*@H@("`@("H@)&]U='!U="`]("1O8FHM/F1E8V]D
M92@I.PH@("`@("H@)'AM;"`@("`]($UA:6Q?;6EM941E8V]D93HZ9V5T6$U,
M*"1O=71P=70I.PH@("`@("H*("`@("`J(%1H92!$5$0@=7-E9"!F;W(@=&AI
M<R!S:&]U;&0@:&%V92!B965N(&EN('1H92!P86-K86=E+B!/<@H@("`@("H@
M86QT97)N871I=F5L>2!Y;W4@8V%N(&=E="!I="!F<F]M(&-V<RP@;W(@:&5R
M93H*("`@("`J(&AT='`Z+R]W=W<N<&AP9W5R=2YO<F<O>&UA:6PO>&UA:6PN
M9'1D+@H@("`@("H*("`@("`J($!P87)A;2`@;V)J96-T($EN<'5T('1O(&-O
M;G9E<G0@=&\@>&UL+B!4:&ES('-H;W5L9"!B92!T:&4*("`@("`J("`@("`@
M("`@("`@("`@(&]U='!U="!O9B!T:&4@36%I;%]M:6UE1&5C;V1E.CID96-O
M9&4@9G5N8W1I;VX*("`@("`J($!R971U<FX@<W1R:6YG(%A-3"!V97)S:6]N
M(&]F(&EN<'5T"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!G971834PH)&EN<'5T*0H@("`@>PH@("`@("`@("1C<FQF("`@
M(#T@(")<<EQN(CL*("`@("`@("`D;W5T<'5T("`]("<\/WAM;"!V97)S:6]N
M/5PG,2XP7"<_/B<@+B`D8W)L9B`N"B`@("`@("`@("`@("`@("`@("`G/"%$
M3T-465!%(&5M86EL(%-94U1%32`B:'1T<#HO+W=W=RYP:'!G=7)U+F]R9R]X
M;6%I;"]X;6%I;"YD=&0B/B<@+B`D8W)L9B`N"B`@("`@("`@("`@("`@("`@
M("`G/&5M86EL/B<@+B`D8W)L9B`N"B`@("`@("`@("`@("`@("`@("!-86EL
M7VUI;65$96-O9&4Z.E]G971834PH)&EN<'5T*2`N"B`@("`@("`@("`@("`@
M("`@("`G/"]E;6%I;#XG.PH*("`@("`@("!R971U<FX@)&]U='!U=#L*("`@
M('T*"B`@("`O*BH*("`@("`J($9U;F-T:6]N('1H870@9&]E<R!T:&4@86-T
M=6%L(&-O;G9E<G-I;VX@=&\@>&UL+B!$;V5S(&$@<VEN9VQE"B`@("`@*B!M
M:6UE<&%R="!A="!A('1I;64N"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE
M8W0@($EN<'5T('1O(&-O;G9E<G0@=&\@>&UL+B!4:&ES(&ES(&$@;6EM97!A
M<G0@;V)J96-T+@H@("`@("H@("`@("`@("`@("`@("`@($ET(&UA>2!O<B!M
M87D@;F]T(&-O;G1A:6X@<W5B<&%R=',N"B`@("`@*B!`<&%R86T@(&EN=&5G
M97(@3G5M8F5R(&]F('1A8G,@=&\@:6YD96YT"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@6$U,('9E<G-I;VX@;V8@:6YP=70*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T6$U,*"1I;G!U="P@)&EN
M9&5N="`](#$I"B`@("!["B`@("`@("`@)&AT86(@("`@/2`@(EQT(CL*("`@
M("`@("`D8W)L9B`@("`]("`B7')<;B(["B`@("`@("`@)&]U='!U="`@/2`@
M)R<["B`@("`@("`@)&AE861E<G,@/2!`*&%R<F%Y*21I;G!U="T^:&5A9&5R
M<SL*"B`@("`@("`@9F]R96%C:"`H)&AE861E<G,@87,@)&AD<E]N86UE(#T^
M("1H9')?=F%L=64I('L*"B`@("`@("`@("`@("\O($UU;'1I<&QE(&AE861E
M<G,@=VET:"!T:&ES(&YA;64*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1H
M96%D97)S6R1H9')?;F%M95TI*2!["B`@("`@("`@("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"!C;W5N="@D:&1R7W9A;'5E*3L@)&DK*RD@>PH@("`@("`@
M("`@("`@("`@("`@("1O=71P=70@+CT@36%I;%]M:6UE1&5C;V1E.CI?9V5T
M6$U,7VAE;'!E<B@D:&1R7VYA;64L("1H9')?=F%L=65;)&E=+"`D:6YD96YT
M*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O($]N;'D@;VYE
M(&AE861E<B!O9B!T:&ES('-O<G0*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1O=71P=70@+CT@36%I;%]M:6UE1&5C;V1E.CI?9V5T
M6$U,7VAE;'!E<B@D:&1R7VYA;64L("1H9')?=F%L=64L("1I;F1E;G0I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1I
M;G!U="T^<&%R=',I*2!["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M(&-O=6YT*"1I;G!U="T^<&%R=',I.R`D:2LK*2!["B`@("`@("`@("`@("`@
M("`D;W5T<'5T("X]("1C<FQF("X@<W1R7W)E<&5A="@D:'1A8BP@)&EN9&5N
M="D@+B`G/&UI;65P87)T/B<@+B`D8W)L9B`N"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@($UA:6Q?;6EM941E8V]D93HZ7V=E=%A-3"@D:6YP=70M/G!A
M<G1S6R1I72P@)&EN9&5N="LQ*2`N"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@('-T<E]R97!E870H)&AT86(L("1I;F1E;G0I("X@)SPO;6EM97!A<G0^
M)R`N("1C<FQF.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*&ES
M<V5T*"1I;G!U="T^8F]D>2DI('L*("`@("`@("`@("`@)&]U='!U="`N/2`D
M8W)L9B`N('-T<E]R97!E870H)&AT86(L("1I;F1E;G0I("X@)SQB;V1Y/CPA
M6T-$051!6R<@+@H@("`@("`@("`@("`@("`@("`@("`@("1I;G!U="T^8F]D
M>2`N("==73X\+V)O9'D^)R`N("1C<FQF.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1O=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!(96QP97(@
M9G5N8W1I;VX@=&\@7V=E=%A-3"@I+B!2971U<FYS('AM;"!O9B!A(&AE861E
M<BX*("`@("`J"B`@("`@*B!`<&%R86T@('-T<FEN9R`@3F%M92!O9B!H96%D
M97(*("`@("`J($!P87)A;2`@<W1R:6YG("!686QU92!O9B!H96%D97(*("`@
M("`J($!P87)A;2`@:6YT96=E<B!.=6UB97(@;V8@=&%B<R!T;R!I;F1E;G0*
M("`@("`J($!R971U<FX@<W1R:6YG("!834P@=F5R<VEO;B!O9B!I;G!U=`H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G
M971834Q?:&5L<&5R*"1H9')?;F%M92P@)&AD<E]V86QU92P@)&EN9&5N="D*
M("`@('L*("`@("`@("`D:'1A8B`@(#T@(EQT(CL*("`@("`@("`D8W)L9B`@
M(#T@(EQR7&XB.PH@("`@("`@("1R971U<FX@/2`G)SL*"B`@("`@("`@)&YE
M=U]H9')?=F%L=64@/2`H)&AD<E]N86UE("$]("=R96-E:79E9"<I(#\@36%I
M;%]M:6UE1&5C;V1E.CI?<&%R<V5(96%D97)686QU92@D:&1R7W9A;'5E*2`Z
M(&%R<F%Y*"=V86QU92<@/3X@)&AD<E]V86QU92D["B`@("`@("`@)&YE=U]H
M9')?;F%M92`@/2!S=')?<F5P;&%C92@G("<L("<M)RP@=6-W;W)D<RAS=')?
M<F5P;&%C92@G+2<L("<@)RP@)&AD<E]N86UE*2DI.PH*("`@("`@("`O+R!3
M;W)T(&]U="!A;GD@<&%R86UE=&5R<PH@("`@("`@(&EF("@A96UP='DH)&YE
M=U]H9')?=F%L=65;)V]T:&5R)UTI*2!["B`@("`@("`@("`@(&9O<F5A8V@@
M*"1N97=?:&1R7W9A;'5E6R=O=&AE<B==(&%S("1P87)A;6YA;64@/3X@)'!A
M<F%M=F%L=64I('L*("`@("`@("`@("`@("`@("1P87)A;7-;72`]('-T<E]R
M97!E870H)&AT86(L("1I;F1E;G0I("X@)&AT86(@+B`G/'!A<F%M971E<CXG
M("X@)&-R;&8@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R7W)E
M<&5A="@D:'1A8BP@)&EN9&5N="D@+B`D:'1A8B`N("1H=&%B("X@)SQP87)A
M;6YA;64^)R`N(&AT;6QS<&5C:6%L8VAA<G,H)'!A<F%M;F%M92D@+B`G/"]P
M87)A;6YA;64^)R`N("1C<FQF("X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('-T<E]R97!E870H)&AT86(L("1I;F1E;G0I("X@)&AT86(@+B`D:'1A
M8B`N("<\<&%R86UV86QU93XG("X@:'1M;'-P96-I86QC:&%R<R@D<&%R86UV
M86QU92D@+B`G/"]P87)A;79A;'5E/B<@+B`D8W)L9B`N"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!S=')?<F5P96%T*"1H=&%B+"`D:6YD96YT*2`N
M("1H=&%B("X@)SPO<&%R86UE=&5R/B<@+B`D8W)L9CL*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@)'!A<F%M<R`](&EM<&QO9&4H)R<L("1P87)A;7,I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P87)A;7,@/2`G)SL*
M("`@("`@("!]"@H@("`@("`@("1R971U<FX@/2!S=')?<F5P96%T*"1H=&%B
M+"`D:6YD96YT*2`N("<\:&5A9&5R/B<@+B`D8W)L9B`N"B`@("`@("`@("`@
M("`@("`@('-T<E]R97!E870H)&AT86(L("1I;F1E;G0I("X@)&AT86(@+B`G
M/&AE861E<FYA;64^)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&YE=U]H9')?;F%M
M92D@+B`G/"]H96%D97)N86UE/B<@+B`D8W)L9B`N"B`@("`@("`@("`@("`@
M("`@('-T<E]R97!E870H)&AT86(L("1I;F1E;G0I("X@)&AT86(@+B`G/&AE
M861E<G9A;'5E/B<@+B!H=&UL<W!E8VEA;&-H87)S*"1N97=?:&1R7W9A;'5E
M6R=V86QU92==*2`N("<\+VAE861E<G9A;'5E/B<@+B`D8W)L9B`N"B`@("`@
M("`@("`@("`@("`@("1P87)A;7,@+@H@("`@("`@("`@("`@("`@("!S=')?
M<F5P96%T*"1H=&%B+"`D:6YD96YT*2`N("<\+VAE861E<CXG("X@)&-R;&8[
M"@H@("`@("`@(')E='5R;B`D<F5T=7)N.PH@("`@?0H*?2`O+R!%;F0@;V8@
M8VQA<W,*/SX*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]-86EL+VUI;65087)T
M+G!H<```````````````````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S,3$Q
M,``Q,#4Q-30S,S<T,P`P,C$W-3$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`-"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L-"B\O('P@0V]P>7)I9VAT("AC*2`R,#`R+3(P,#,@(%)I
M8VAA<F0@2&5Y97,@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`T*+R\@?"!!;&P@<FEG:'1S(')E<V5R=F5D+B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!2961I<W1R:6)U=&EO
M;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R
M('=I=&AO=70@("`@?`T*+R\@?"!M;V1I9FEC871I;VXL(&%R92!P97)M:71T
M960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,@("`@
M?`T*+R\@?"!A<F4@;65T.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!O(%)E9&ES=')I8G5T:6]N
M<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I
M9VAT("`@("`@?`T*+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I
M=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX@("`@("`@?`T*
M+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E
M<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT("`@?`T*+R\@?"`@(&YO=&EC
M92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@
M9&ES8VQA:6UE<B!I;B!T:&4@?`T*+R\@?"`@(&1O8W5M96YT871I;VX@86YD
M+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H92!D:7-T<FEB
M=71I;VXN?`T*+R\@?"!O(%1H92!N86UE<R!O9B!T:&4@875T:&]R<R!M87D@
M;F]T(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E("`@("`@?`T*+R\@
M?"`@('!R;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO
M=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B`@?`T*+R\@?"`@('!E<FUI<W-I
M;VXN("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`T*+R\@?"!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#
M3U!94DE'2%0@2$],1$524R!!3D0@0T].5%))0E543U)3("`@?`T*+R\@?"`B
M05,@25,B($%.1"!!3ED@15A04D534R!/4B!)35!,245$(%=!4E)!3E1)15,L
M($E.0TQ51$E.1RP@0E54($Y/5"`@("`@?`T*+R\@?"!,24U)5$5$(%1/+"!4
M2$4@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!3D0@
M1DE43D534R!&3U(@?`T*+R\@?"!!(%!!4E1)0U5,05(@4%524$]312!!4D4@
M1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%($-/4%E224=(5"`@
M?`T*+R\@?"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%($9/4B!!
M3ED@1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@?`T*+R\@?"!34$5#
M24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#
M3%5$24Y'+"!"550@3D]4("`@("`@?`T*+R\@?"!,24U)5$5$(%1/+"!04D]#
M55)%345.5"!/1B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3
M($]&(%5312P@?`T*+R\@?"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D53
M4R!)3E1%4E)54%1)3TXI($A/5T5615(@0T%54T5$($%.1"!/3B!!3ED@?`T*
M+R\@?"!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E.($-/3E1204-4
M+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4("`@?`T*+R\@?"`H24Y#3%5$
M24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E.($%.62!7
M05D@3U54($]&(%1(12!54T4@?`T*+R\@?"!/1B!42$E3(%-/1E1705)%+"!%
M5D5.($E&($%$5DE3140@3T8@5$A%(%!/4U-)0DE,2519($]&(%-50T@@1$%-
M04=%+B`@?`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!!=71H;W(Z(%)I
M8VAA<F0@2&5Y97,@/')I8VAA<F1`<&AP9W5R=2YO<F<^("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PT*#0HO*BH-"BH-"BH@(%)A=R!M:6UE(&5N8V]D:6YG(&-L87-S#0HJ
M#0HJ(%=H870@:7,@:70_#0HJ("`@5&AI<R!C;&%S<R!E;F%B;&5S('EO=2!T
M;R!M86YI<'5L871E(&%N9"!B=6EL9`T**B`@(&$@;6EM92!E;6%I;"!F<F]M
M('1H92!G<F]U;F0@=7`N#0HJ#0HJ(%=H>2!U<V4@=&AI<R!I;G-T96%D(&]F
M(&UI;64N<&AP/PT**B`@(&UI;64N<&AP(&ES(&$@=7-E<F9R:65N9&QY(&%P
M:2!T;R!T:&ES(&-L87-S(&9O<@T**B`@('!E;W!L92!W:&\@87)E;B=T(&EN
M=&5R97-T960@:6X@=&AE(&EN=&5R;F%L<R!O9@T**B`@(&UI;64@;6%I;"X@
M5&AI<R!C;&%S<R!H;W=E=F5R(&%L;&]W<R!F=6QL(&-O;G1R;VP-"BH@("!O
M=F5R('1H92!E;6%I;"X-"BH-"BH@16<N#0HJ#0HJ("\O(%-I;F-E(&UU;'1I
M<&%R="]M:7AE9"!H87,@;F\@<F5A;"!B;V1Y+"`H=&AE(&)O9'D@:7,-"BH@
M+R\@=&AE('-U8G!A<G0I+"!W92!S970@=&AE(&)O9'D@87)G=6UE;G0@=&\@
M8FQA;FLN#0HJ#0HJ("1P87)A;7-;)V-O;G1E;G1?='EP92==(#T@)VUU;'1I
M<&%R="]M:7AE9"<[#0HJ("1E;6%I;"`](&YE=R!-86EL7VUI;65087)T*"<G
M+"`D<&%R86US*3L-"BH-"BH@+R\@2&5R92!W92!A9&0@82!T97AT('!A<G0@
M=&\@=&AE(&UU;'1I<&%R="!W92!H879E#0HJ("\O(&%L<F5A9'DN($%S<W5M
M92`D8F]D>2!C;VYT86EN<R!P;&%I;B!T97AT+@T**@T**B`D<&%R86US6R=C
M;VYT96YT7W1Y<&4G72`]("=T97AT+W!L86EN)SL-"BH@)'!A<F%M<ULG96YC
M;V1I;F<G72`@("`@/2`G-V)I="<[#0HJ("1T97AT(#T@)&5M86EL+3YA9&13
M=6)087)T*"1B;V1Y+"`D<&%R86US*3L-"BH-"BH@+R\@3F]W(&%D9"!A;B!A
M='1A8VAM96YT+B!!<W-U;64@)&%T=&%C:"!I<PT**B!T:&4@8V]N=&5N=',@
M;V8@=&AE(&%T=&%C:&UE;G0-"BH-"BH@)'!A<F%M<ULG8V]N=&5N=%]T>7!E
M)UT@/2`G87!P;&EC871I;VXO>FEP)SL-"BH@)'!A<F%M<ULG96YC;V1I;F<G
M72`@("`@/2`G8F%S938T)SL-"BH@)'!A<F%M<ULG9&ES<&]S:71I;VXG72`@
M/2`G871T86-H;65N="<[#0HJ("1P87)A;7-;)V1F:6QE;F%M92==("`@(#T@
M)V5X86UP;&4N>FEP)SL-"BH@)&%T=&%C:"`])B`D96UA:6PM/F%D9%-U8E!A
M<G0H)&)O9'DL("1P87)A;7,I.PT**@T**B`O+R!.;W<@8G5I;&0@=&AE(&5M
M86EL+B!.;W1E('1H870@=&AE(&5N8V]D90T**B`O+R!F=6YC=&EO;B!R971U
M<FYS(&%N(&%S<V]C:6%T:79E(&%R<F%Y(&-O;G1A:6YI;F<@='=O#0HJ("\O
M(&5L96UE;G1S+"!B;V1Y(&%N9"!H96%D97)S+B!9;W4@=VEL;"!N965D('1O
M(&%D9"!E>'1R80T**B`O+R!H96%D97)S+"`H96<N($UI;64M5F5R<VEO;BD@
M8F5F;W)E('-E;F1I;F<N#0HJ#0HJ("1E;6%I;"`]("1M97-S86=E+3YE;F-O
M9&4H*3L-"BH@)&5M86EL6R=H96%D97)S)UU;72`]("=-:6UE+59E<G-I;VXZ
M(#$N,"<[#0HJ#0HJ#0HJ($9U<G1H97(@97AA;7!L97,@87)E(&%V86EL86)L
M92!A="!H='1P.B\O=W=W+G!H<&=U<G4N;W)G#0HJ#0HJ(%1/1$\Z#0HJ("`M
M(%-E="!E;F-O9&4H*2!T;R!R971U<FX@=&AE("1O8FHM/F5N8V]D960@:68@
M96YC;V1E*"D-"BH@("`@:&%S(&%L<F5A9'D@8F5E;B!R=6XN(%5N;&5S<R!A
M(&9L86<@:7,@<&%S<V5D('1O('-P96-I9FEC86QL>0T**B`@("!R92UB=6EL
M9"!T:&4@;65S<V%G92X-"BH-"BH@0&%U=&AO<B`@4FEC:&%R9"!(97EE<R`\
M<FEC:&%R9$!P:'!G=7)U+F]R9SX-"BH@0'9E<G-I;VX@)%)E=FES:6]N.B`Q
M+C$S("0-"BH@0'!A8VMA9V4@36%I;`T**B\-"@T*8VQA<W,@36%I;%]M:6UE
M4&%R="![#0H-"B`@("\J*@T*("`@("H@5&AE(&5N8V]D:6YG('1Y<&4@;V8@
M=&AI<R!P87)T#0H@("`@*B!`=F%R('-T<FEN9PT*("`@("HO#0H@("`@=F%R
M("1?96YC;V1I;F<[#0H-"B`@("\J*@T*("`@("H@06X@87)R87D@;V8@<W5B
M<&%R=',-"B`@("`J($!V87(@87)R87D-"B`@("`J+PT*("`@('9A<B`D7W-U
M8G!A<G1S.PT*#0H@("`O*BH-"B`@("`J(%1H92!O=71P=70@;V8@=&AI<R!P
M87)T(&%F=&5R(&)E:6YG(&)U:6QT#0H@("`@*B!`=F%R('-T<FEN9PT*("`@
M("HO#0H@("`@=F%R("1?96YC;V1E9#L-"@T*("`@+RHJ#0H@("`@*B!(96%D
M97)S(&9O<B!T:&ES('!A<G0-"B`@("`J($!V87(@87)R87D-"B`@("`J+PT*
M("`@('9A<B`D7VAE861E<G,[#0H-"B`@("\J*@T*("`@("H@5&AE(&)O9'D@
M;V8@=&AI<R!P87)T("AN;W0@96YC;V1E9"D-"B`@("`J($!V87(@<W1R:6YG
M#0H@("`@*B\-"B`@("!V87(@)%]B;V1Y.PT*#0H@("`@+RHJ#0H@("`@("H@
M0V]N<W1R=6-T;W(N#0H@("`@("H-"B`@("`@*B!3971S('5P('1H92!O8FIE
M8W0N#0H@("`@("H-"B`@("`@*B!`<&%R86T@)&)O9'D@("`M(%1H92!B;V1Y
M(&]F('1H92!M:6UE('!A<G0@:68@86YY+@T*("`@("`J($!P87)A;2`D<&%R
M86US("T@06X@87-S;V-I871I=F4@87)R87D@;V8@<&%R86UE=&5R<SH-"B`@
M("`@*B`@("`@("`@("`@("`@("`@(&-O;G1E;G1?='EP92`M(%1H92!C;VYT
M96YT('1Y<&4@9F]R('1H:7,@<&%R="!E9R!M=6QT:7!A<G0O;6EX960-"B`@
M("`@*B`@("`@("`@("`@("`@("`@(&5N8V]D:6YG("`@("`M(%1H92!E;F-O
M9&EN9R!T;R!U<V4L(#=B:70L(#AB:70L(&)A<V4V-"P@;W(@<75O=&5D+7!R
M:6YT86)L90T*("`@("`J("`@("`@("`@("`@("`@("`@8VED("`@("`@("`@
M("T@0V]N=&5N="!)1"!T;R!A<'!L>0T*("`@("`J("`@("`@("`@("`@("`@
M("`@9&ES<&]S:71I;VX@("T@0V]N=&5N="!D:7-P;W-I=&EO;BP@:6YL:6YE
M(&]R(&%T=&%C:&UE;G0-"B`@("`@*B`@("`@("`@("`@("`@("`@(&1F:6QE
M;F%M92`@("`M($]P=&EO;F%L(&9I;&5N86UE('!A<F%M971E<B!F;W(@8V]N
M=&5N="!D:7-P;W-I=&EO;@T*("`@("`J("`@("`@("`@("`@("`@("`@9&5S
M8W)I<'1I;VX@("T@0V]N=&5N="!D97-C<FEP=&EO;@T*("`@("`J("`@("`@
M("`@("`@("`@("`@8VAA<G-E="`@("`@("T@0VAA<F%C=&5R('-E="!T;R!U
M<V4-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N($UA:6Q?;6EM95!A<G0H)&)O9'D@/2`G)RP@)'!A<F%M<R`](&%R<F%Y
M*"DI#0H@("`@>PT*("`@("`@("!I9B`H(61E9FEN960H)TU!24Q?34E-15!!
M4E1?0U),1B<I*2![#0H@("`@("`@("`@("!D969I;F4H)TU!24Q?34E-15!!
M4E1?0U),1B<L(&1E9FEN960H)TU!24Q?34E-15]#4DQ&)RD@/R!-04E,7TU)
M345?0U),1B`Z(")<<EQN(BP@5%)512D[#0H@("`@("`@('T-"@T*("`@("`@
M("!F;W)E86-H("@D<&%R86US(&%S("1K97D@/3X@)'9A;'5E*2![#0H@("`@
M("`@("`@("!S=VET8V@@*"1K97DI('L-"B`@("`@("`@("`@("`@("!C87-E
M("=C;VYT96YT7W1Y<&4G.@T*("`@("`@("`@("`@("`@("`@("`D:&5A9&5R
M<ULG0V]N=&5N="U4>7!E)UT@/2`D=F%L=64@+B`H:7-S970H)&-H87)S970I
M(#\@)SL@8VAA<G-E=#TB)R`N("1C:&%R<V5T("X@)R(G(#H@)R<I.PT*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL-"@T*("`@("`@("`@("`@("`@(&-A
M<V4@)V5N8V]D:6YG)SH-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]E
M;F-O9&EN9R`]("1V86QU93L-"B`@("`@("`@("`@("`@("`@("`@)&AE861E
M<G-;)T-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<G72`]("1V86QU93L-"B`@
M("`@("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@("`@("!C
M87-E("=C:60G.@T*("`@("`@("`@("`@("`@("`@("`D:&5A9&5R<ULG0V]N
M=&5N="U)1"==(#T@)SPG("X@)'9A;'5E("X@)SXG.PT*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL-"@T*("`@("`@("`@("`@("`@(&-A<V4@)V1I<W!O
M<VET:6]N)SH-"B`@("`@("`@("`@("`@("`@("`@)&AE861E<G-;)T-O;G1E
M;G0M1&ES<&]S:71I;VXG72`]("1V86QU92`N("AI<W-E="@D9&9I;&5N86UE
M*2`_("<[(&9I;&5N86UE/2(G("X@)&1F:6QE;F%M92`N("<B)R`Z("<G*3L-
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@("`@
M("!C87-E("=D9FEL96YA;64G.@T*("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&AE861E<G-;)T-O;G1E;G0M1&ES<&]S:71I;VXG72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1H96%D97)S6R=#;VYT96YT+41I<W!O
M<VET:6]N)UT@+CT@)SL@9FEL96YA;64](B<@+B`D=F%L=64@+B`G(B<[#0H@
M("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D9&9I;&5N86UE(#T@)'9A;'5E.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*#0H@("`@("`@
M("`@("`@("`@8V%S92`G9&5S8W)I<'1I;VXG.@T*("`@("`@("`@("`@("`@
M("`@("`D:&5A9&5R<ULG0V]N=&5N="U$97-C<FEP=&EO;B==(#T@)'9A;'5E
M.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"@T*("`@("`@("`@("`@
M("`@(&-A<V4@)V-H87)S970G.@T*("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&AE861E<G-;)T-O;G1E;G0M5'EP92==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)&AE861E<G-;)T-O;G1E;G0M5'EP92==("X]("<[
M(&-H87)S970](B<@+B`D=F%L=64@+B`G(B<[#0H@("`@("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`D8VAA<G-E
M="`]("1V86QU93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M#0H@("`@("`@("\O($1E9F%U;'0@8V]N=&5N="UT>7!E#0H@("`@("`@(&EF
M("@A:7-S970H)&AE861E<G-;)T-O;G1E;G0M5'EP92==*2D@>PT*("`@("`@
M("`@("`@)&AE861E<G-;)T-O;G1E;G0M5'EP92==(#T@)W1E>'0O<&QA:6XG
M.PT*("`@("`@("!]#0H-"B`@("`@("`@+R]$969A=6QT(&5N8V]D:6YG#0H@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]E;F-O9&EN9RDI('L-"B`@("`@
M("`@("`@("1T:&ES+3Y?96YC;V1I;F<@/2`G-V)I="<[#0H@("`@("`@('T-
M"@T*("`@("`@("`O+R!!<W-I9VX@<W1U9F8@=&\@;65M8F5R('9A<FEA8FQE
M<PT*("`@("`@("`D=&AI<RT^7V5N8V]D960@(#T@87)R87DH*3L-"B`@("`@
M("`@)'1H:7,M/E]H96%D97)S("`]("1H96%D97)S.PT*("`@("`@("`D=&AI
M<RT^7V)O9'D@("`@(#T@)&)O9'D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@96YC;V1E*"D-"B`@("`@*@T*("`@("`J($5N8V]D97,@86YD(')E='5R
M;G,@=&AE(&5M86EL+B!!;'-O('-T;W)E<PT*("`@("`J(&ET(&EN('1H92!E
M;F-O9&5D(&UE;6)E<B!V87)I86)L90T*("`@("`J#0H@("`@("H@0')E='5R
M;B!!;B!A<W-O8VEA=&EV92!A<G)A>2!C;VYT86EN:6YG('1W;R!E;&5M96YT
M<RP-"B`@("`@*B`@("`@("`@(&)O9'D@86YD(&AE861E<G,N(%1H92!H96%D
M97)S(&5L96UE;G0@:7,@:71S96QF#0H@("`@("H@("`@("`@("!A;B!I;F1E
M>&5D(&%R<F%Y+@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@96YC;V1E*"D-"B`@("![#0H@("`@("`@("1E;F-O9&5D
M(#TF("1T:&ES+3Y?96YC;V1E9#L-"@T*("`@("`@("!I9B`H(65M<'1Y*"1T
M:&ES+3Y?<W5B<&%R=',I*2![#0H@("`@("`@("`@("!S<F%N9"@H9&]U8FQE
M*6UI8W)O=&EM92@I*C$P,#`P,#`I.PT*("`@("`@("`@("`@)&)O=6YD87)Y
M(#T@)SU?)R`N(&UD-2AR86YD*"D@+B!M:6-R;W1I;64H*2D[#0H@("`@("`@
M("`@("`D=&AI<RT^7VAE861E<G-;)T-O;G1E;G0M5'EP92==("X]("<[)R`N
M($U!24Q?34E-15!!4E1?0U),1B`N(")<="(@+B`G8F]U;F1A<GD](B<@+B`D
M8F]U;F1A<GD@+B`G(B<[#0H-"B`@("`@("`@("`@("\O($%D9"!B;V1Y('!A
M<G1S('1O("1S=6)P87)T<PT*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I
M(#P@8V]U;G0H)'1H:7,M/E]S=6)P87)T<RD[("1I*RLI('L-"B`@("`@("`@
M("`@("`@("`D:&5A9&5R<R`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@
M)'1M<"`]("1T:&ES+3Y?<W5B<&%R='-;)&E=+3YE;F-O9&4H*3L-"B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D=&UP6R=H96%D97)S)UT@87,@)&ME>2`]
M/B`D=F%L=64I('L-"B`@("`@("`@("`@("`@("`@("`@)&AE861E<G-;72`]
M("1K97D@+B`G.B`G("X@)'9A;'5E.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`D<W5B<&%R='-;72`](&EM<&QO9&4H34%)3%]-24U%
M4$%25%]#4DQ&+"`D:&5A9&5R<RD@+B!-04E,7TU)345005)47T-23$8@+B!-
M04E,7TU)345005)47T-23$8@+B`D=&UP6R=B;V1Y)UT[#0H@("`@("`@("`@
M("!]#0H-"B`@("`@("`@("`@("1E;F-O9&5D6R=B;V1Y)UT@/2`G+2TG("X@
M)&)O=6YD87)Y("X@34%)3%]-24U%4$%25%]#4DQ&("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I;7!L;V1E*"<M+2<@+B`D8F]U;F1A<GD@
M+B!-04E,7TU)345005)47T-23$8L("1S=6)P87)T<RD@+@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("<M+2<@+B`D8F]U;F1A<GDN)RTM)R`N
M($U!24Q?34E-15!!4E1?0U),1CL-"@T*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@)&5N8V]D961;)V)O9'DG72`]("1T:&ES+3Y?9V5T16YC;V1E
M9$1A=&$H)'1H:7,M/E]B;V1Y+"`D=&AI<RT^7V5N8V]D:6YG*2`N($U!24Q?
M34E-15!!4E1?0U),1CL-"B`@("`@("`@?0T*#0H@("`@("`@("\O($%D9"!H
M96%D97)S('1O("1E;F-O9&5D#0H@("`@("`@("1E;F-O9&5D6R=H96%D97)S
M)UT@/28@)'1H:7,M/E]H96%D97)S.PT*#0H@("`@("`@(')E='5R;B`D96YC
M;V1E9#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B`F861D4W5B4&%R="@I
M#0H@("`@("H-"B`@("`@*B!!9&1S(&$@<W5B<&%R="!T;R!C=7)R96YT(&UI
M;64@<&%R="!A;F0@<F5T=7)N<PT*("`@("`J(&$@<F5F97)E;F-E('1O(&ET
M#0H@("`@("H-"B`@("`@*B!`<&%R86T@)&)O9'D@("!4:&4@8F]D>2!O9B!T
M:&4@<W5B<&%R="P@:68@86YY+@T*("`@("`J($!P87)A;2`D<&%R86US(%1H
M92!P87)A;65T97)S(&9O<B!T:&4@<W5B<&%R="P@<V%M90T*("`@("`J("`@
M("`@("`@("`@("`@(&%S('1H92`D<&%R86US(&%R9W5M96YT(&9O<B!C;VYS
M=')U8W1O<BX-"B`@("`@*B!`<F5T=7)N($$@<F5F97)E;F-E('1O('1H92!P
M87)T('EO=2!J=7-T(&%D9&5D+B!)="!I<PT*("`@("`J("`@("`@("`@8W)U
M8VEA;"!I9B!U<VEN9R!M=6QT:7!A<G0O*B!I;B!Y;W5R('-U8G!A<G1S('1H
M870-"B`@("`@*B`@("`@("`@('EO=2!U<V4@/28@:6X@>6]U<B!S8W)I<'0@
M=VAE;B!C86QL:6YG('1H:7,@9G5N8W1I;VXL#0H@("`@("H@("`@("`@("!O
M=&AE<G=I<V4@>6]U('=I;&P@;F]T(&)E(&%B;&4@=&\@861D(&9U<G1H97(@
M<W5B<&%R=',N#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B`F861D4W5B4&%R="@D8F]D>2P@)'!A<F%M<RD-"B`@("![
M#0H@("`@("`@("1T:&ES+3Y?<W5B<&%R='-;72`](&YE=R!-86EL7VUI;650
M87)T*"1B;V1Y+"`D<&%R86US*3L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<W5B<&%R='-;8V]U;G0H)'1H:7,M/E]S=6)P87)T<RD@+2`Q73L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!?9V5T16YC;V1E9$1A=&$H*0T*("`@("`J
M#0H@("`@("H@4F5T=7)N<R!E;F-O9&5D(&1A=&$@8F%S960@=7!O;B!E;F-O
M9&EN9R!P87-S960@=&\@:70-"B`@("`@*@T*("`@("`J($!P87)A;2`D9&%T
M82`@("`@5&AE(&1A=&$@=&\@96YC;V1E+@T*("`@("`J($!P87)A;2`D96YC
M;V1I;F<@5&AE(&5N8V]D:6YG('1Y<&4@=&\@=7-E+"`W8FET+"!B87-E-C0L
M#0H@("`@("H@("`@("`@("`@("`@("`@("!O<B!Q=6]T960M<')I;G1A8FQE
M+@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T
M:6]N(%]G971%;F-O9&5D1&%T82@D9&%T82P@)&5N8V]D:6YG*0T*("`@('L-
M"B`@("`@("`@<W=I=&-H("@D96YC;V1I;F<I('L-"B`@("`@("`@("`@(&-A
M<V4@)SAB:70G.@T*("`@("`@("`@("`@8V%S92`G-V)I="<Z#0H@("`@("`@
M("`@("`@("`@<F5T=7)N("1D871A.PT*("`@("`@("`@("`@("`@(&)R96%K
M.PT*#0H@("`@("`@("`@("!C87-E("=Q=6]T960M<')I;G1A8FQE)SH-"B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]Q=6]T9610<FEN=&%B;&5%
M;F-O9&4H)&1A=&$I.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*#0H@("`@
M("`@("`@("!C87-E("=B87-E-C0G.@T*("`@("`@("`@("`@("`@(')E='5R
M;B!R=')I;2AC:'5N:U]S<&QI="AB87-E-C1?96YC;V1E*"1D871A*2P@-S8L
M($U!24Q?34E-15!!4E1?0U),1BDI.PT*("`@("`@("`@("`@("`@(&)R96%K
M.PT*#0H@("`@("`@("`@("!D969A=6QT.@T*("`@("`@("`@("`@("`@(')E
M='5R;B`D9&%T83L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@
M("`J('%U;W1E8610<FEN=&%B;&5%;F-O9&4H*0T*("`@("`J#0H@("`@("H@
M16YC;V1E<R!D871A('1O('%U;W1E9"UP<FEN=&%B;&4@<W1A;F1A<F0N#0H@
M("`@("H-"B`@("`@*B!`<&%R86T@)&EN<'5T("`@(%1H92!D871A('1O(&5N
M8V]D90T*("`@("`J($!P87)A;2`D;&EN95]M87@@3W!T:6]N86P@;6%X(&QI
M;F4@;&5N9W1H+B!3:&]U;&0-"B`@("`@*B`@("`@("`@("`@("`@("`@(&YO
M="!B92!M;W)E('1H86X@-S8@8VAA<G,-"B`@("`@*@T*("`@("`J($!A8V-E
M<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]Q=6]T9610<FEN
M=&%B;&5%;F-O9&4H)&EN<'5T("P@)&QI;F5?;6%X(#T@-S8I#0H@("`@>PT*
M("`@("`@("`D;&EN97,@(#T@<')E9U]S<&QI="@B+UQR/UQN+R(L("1I;G!U
M="D[#0H@("`@("`@("1E;VP@("`@/2!-04E,7TU)345005)47T-23$8[#0H@
M("`@("`@("1E<V-A<&4@/2`G/2<[#0H@("`@("`@("1O=71P=70@/2`G)SL-
M"@T*("`@("`@("!W:&EL92AL:7-T*"P@)&QI;F4I(#T@96%C:"@D;&EN97,I
M*7L-"@T*("`@("`@("`@("`@)&QI;FQE;B`@("`@/2!S=')L96XH)&QI;F4I
M.PT*("`@("`@("`@("`@)&YE=VQI;F4@/2`G)SL-"@T*("`@("`@("`@("`@
M9F]R("@D:2`](#`[("1I(#P@)&QI;FQE;CL@)&DK*RD@>PT*("`@("`@("`@
M("`@("`@("1C:&%R(#T@<W5B<W1R*"1L:6YE+"`D:2P@,2D[#0H@("`@("`@
M("`@("`@("`@)&1E8R`@/2!O<F0H)&-H87(I.PT*#0H@("`@("`@("`@("`@
M("`@:68@*"@D9&5C(#T](#,R*2!!3D0@*"1I(#T]("@D;&EN;&5N("T@,2DI
M*7L@("`@+R\@8V]N=F5R="!S<&%C92!A="!E;VP@;VYL>0T*("`@("`@("`@
M("`@("`@("`@("`D8VAA<B`]("<],C`G.PT*#0H@("`@("`@("`@("`@("`@
M?2!E;'-E:68H*"1D96,@/3T@.2D@04Y$("@D:2`]/2`H)&QI;FQE;B`M(#$I
M*2D@>R`@+R\@8V]N=F5R="!T86(@870@96]L(&]N;'D-"B`@("`@("`@("`@
M("`@("`@("`@)&-H87(@/2`G/3`Y)SL-"B`@("`@("`@("`@("`@("!](&5L
M<V5I9B@D9&5C(#T](#DI('L-"B`@("`@("`@("`@("`@("`@("`@.R`O+R!$
M;R!N;W1H:6YG(&EF(&$@=&%B+@T*("`@("`@("`@("`@("`@('T@96QS96EF
M*"@D9&5C(#T](#8Q*2!/4B`H)&1E8R`\(#,R("D@3U(@*"1D96,@/B`Q,C8I
M*2![#0H@("`@("`@("`@("`@("`@("`@("1C:&%R(#T@)&5S8V%P92`N('-T
M<G1O=7!P97(H<W!R:6YT9B@G)3`R<R<L(&1E8VAE>"@D9&5C*2DI.PT*("`@
M("`@("`@("`@("`@('T-"@T*("`@("`@("`@("`@("`@(&EF("@H<W1R;&5N
M*"1N97=L:6YE*2`K('-T<FQE;B@D8VAA<BDI(#X]("1L:6YE7VUA>"D@>R`@
M("`@("`@+R\@34%)3%]-24U%4$%25%]#4DQ&(&ES(&YO="!C;W5N=&5D#0H@
M("`@("`@("`@("`@("`@("`@("1O=71P=70@("X]("1N97=L:6YE("X@)&5S
M8V%P92`N("1E;VP[("`@("`@("`@("`@("`@("`@("`O+R!S;V9T(&QI;F4@
M8G)E86L[("(@/5QR7&XB(&ES(&]K87D-"B`@("`@("`@("`@("`@("`@("`@
M)&YE=VQI;F4@(#T@)R<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("1N97=L:6YE("X]("1C:&%R.PT*("`@("`@("`@("`@?2`O+R!E
M;F0@;V8@9F]R#0H@("`@("`@("`@("`D;W5T<'5T("X]("1N97=L:6YE("X@
M)&5O;#L-"B`@("`@("`@?0T*("`@("`@("`D;W5T<'5T(#T@<W5B<W1R*"1O
M=71P=70L(#`L("TQ("H@<W1R;&5N*"1E;VPI*3L@+R\@1&]N)W0@=V%N="!L
M87-T(&-R;&8-"B`@("`@("`@<F5T=7)N("1O=71P=70[#0H@("`@?0T*?2`O
M+R!%;F0@;V8@8VQA<W,-"C\^#0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]-86EL
M+VYU;&PN<&AP````````````````````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-#<W,0`Q,#4Q-30S,S<T,P`P,C$Q-C(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+R\*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#
M;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T
M;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@
M?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I
M;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0
M(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO
M=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C
M86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R
M.B!0:&EL($ME<FYI8VL@/'!H:6QK0')O=&9L+F-O;2YA=3X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\*+R\@)$ED.B!N=6QL+G!H<"QV(#$N,B`R,#`T+S`T+S`V(#`U
M.C$Y.C`S(&IO;B!%>'`@)`HO+PH*+RHJ"B`J($YU;&P@:6UP;&5M96YT871I
M;VX@;V8@=&AE(%!%05(@36%I;#HZ(&EN=&5R9F%C92X*("H@0&%C8V5S<R!P
M=6)L:6,*("H@0'!A8VMA9V4@36%I;`H@*B!`=F5R<VEO;B`D4F5V:7-I;VXZ
M(#$N,B`D"B`J+PIC;&%S<R!-86EL7VYU;&P@97AT96YD<R!-86EL('L*"B`@
M("`O*BH*("`@("`J($EM<&QE;65N=',@36%I;%]N=6QL.CIS96YD*"D@9G5N
M8W1I;VXN(%-I;&5N=&QY(&1I<V-A<F1S(&%L;`H@("`@("H@;6%I;"X*("`@
M("`J"B`@("`@*B!`<&%R86T@;6EX960@)')E8VEP:65N=',@16ET:&5R(&$@
M8V]M;6$M<V5P97)A=&5D(&QI<W0@;V8@<F5C:7!I96YT<PH@("`@("H@("`@
M("`@("`@("`@("A21D,X,C(@8V]M<&QI86YT*2P@;W(@86X@87)R87D@;V8@
M<F5C:7!I96YT<RP*("`@("`J("`@("`@("`@("`@("!E86-H(%)&0S@R,B!V
M86QI9"X@5&AI<R!M87D@8V]N=&%I;B!R96-I<&EE;G1S(&YO=`H@("`@("H@
M("`@("`@("`@("`@('-P96-I9FEE9"!I;B!T:&4@:&5A9&5R<RP@9F]R($)C
M8SHL(')E<V5N9&EN9PH@("`@("H@("`@("`@("`@("`@(&UE<W-A9V5S+"!E
M=&,N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1H96%D97)S(%1H92!A
M<G)A>2!O9B!H96%D97)S('1O('-E;F0@=VET:"!T:&4@;6%I;"P@:6X@86X*
M("`@("`J("`@("`@("`@("`@("!A<W-O8VEA=&EV92!A<G)A>2P@=VAE<F4@
M=&AE(&%R<F%Y(&ME>2!I<R!T:&4*("`@("`J("`@("`@("`@("`@("!H96%D
M97(@;F%M92`H:64L("=3=6)J96-T)RDL(&%N9"!T:&4@87)R87D@=F%L=64*
M("`@("`J("`@("`@("`@("`@("!I<R!T:&4@:&5A9&5R('9A;'5E("AI92P@
M)W1E<W0G*2X@5&AE(&AE861E<@H@("`@("H@("`@("`@("`@("`@('!R;V1U
M8V5D(&9R;VT@=&AO<V4@=F%L=65S('=O=6QD(&)E("=3=6)J96-T.@H@("`@
M("H@("`@("`@("`@("`@('1E<W0G+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&)O9'D@5&AE(&9U;&P@=&5X="!O9B!T:&4@;65S<V%G92!B;V1Y
M+"!I;F-L=61I;F<@86YY"B`@("`@*B`@("`@("`@("`@("`@($UI;64@<&%R
M=',L(&5T8RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@
M=')U92!O;B!S=6-C97-S+"!O<B!A(%!%05)?17)R;W(*("`@("`J("`@("`@
M("`@("`@("`@8V]N=&%I;FEN9R!A(&1E<V-R:7!T:79E(&5R<F]R(&UE<W-A
M9V4@;VX*("`@("`J("`@("`@("`@("`@("`@9F%I;'5R92X*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-E;F0H)')E8VEP
M:65N=',L("1H96%D97)S+"`D8F]D>2D*("`@('L*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"GT*`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]-86EL+U)&0S@R,BYP:'``````````````````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`W-C8R,P`Q,#4Q-30S,S<T,P`P,C$P-C,`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H
M="`H8RD@,C`P,2TR,#`R+"!2:6-H87)D($AE>65S("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@06QL(')I9VAT<R!R97-E<G9E9"X@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(%)E
M9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R
M;7,L('=I=&@@;W(@=VET:&]U="`@("!\"B\O('P@;6]D:69I8V%T:6]N+"!A
M<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD
M:71I;VYS("`@('P*+R\@?"!A<F4@;65T.B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@;R!2961I<W1R
M:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E
M(&-O<'ER:6=H="`@("`@('P*+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F
M(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX@("`@
M("`@?`HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU
M<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@("!\"B\O('P@("!N
M;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W
M:6YG(&1I<V-L86EM97(@:6X@=&AE('P*+R\@?"`@(&1O8W5M96YT871I;VX@
M86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H92!D:7-T
M<FEB=71I;VXN?`HO+R!\(&\@5&AE(&YA;65S(&]F('1H92!A=71H;W)S(&UA
M>2!N;W0@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@("`@("!\"B\O
M('P@("!P<F]D=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H
M;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@('P*+R\@?"`@('!E<FUI<W-I
M;VXN("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0T]0
M65))1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]24R`@('P*+R\@?"`B05,@
M25,B($%.1"!!3ED@15A04D534R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.
M0TQ51$E.1RP@0E54($Y/5"`@("`@?`HO+R!\($Q)34E4140@5$\L(%1(12!)
M35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519($%.1"!&251.
M15-3($9/4B!\"B\O('P@02!005)424-53$%2(%!54E!/4T4@05)%($1)4T-,
M04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'2%0@('P*+R\@
M?"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%($9/4B!!3ED@1$E2
M14-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@?`HO+R!\(%-014-)04PL($58
M14U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L
M($)55"!.3U0@("`@("!\"B\O('P@3$E-251%1"!43RP@4%)/0U5214U%3E0@
M3T8@4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L
M('P*+R\@?"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)5
M4%1)3TXI($A/5T5615(@0T%54T5$($%.1"!/3B!!3ED@?`HO+R!\(%1(14]2
M62!/1B!,24%"24Q)5%DL(%=(151(15(@24X@0T].5%)!0U0L(%-44DE#5"!,
M24%"24Q)5%DL($]2(%1/4E0@("!\"B\O('P@*$E.0TQ51$E.1R!.14=,24=%
M3D-%($]2($]42$525TE312D@05))4TE.1R!)3B!!3ED@5T%9($]55"!/1B!4
M2$4@55-%('P*+R\@?"!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3
M140@3T8@5$A%(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+B`@?`HO+R!\
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!2:6-H87)D($AE>65S(#QR
M:6-H87)D0'!H<&=U<G4N;W)G/B`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R!\("`@("`@("`@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/B`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*"B\J*@H@*B!21D,@.#(R($5M86EL(&%D
M9')E<W,@;&ES="!V86QI9&%T:6]N(%5T:6QI='D*("H*("H@5VAA="!I<R!I
M=#\*("H*("H@5&AI<R!C;&%S<R!W:6QL('1A:V4@86X@861D<F5S<R!S=')I
M;F<L(&%N9"!P87)S92!I="!I;G1O(&ET)W,@8V]N<VET=65N=`H@*B!P87)T
M<RP@8F4@=&AA="!E:71H97(@861D<F5S<V5S+"!G<F]U<',L(&]R(&-O;6)I
M;F%T:6]N<RX@3F5S=&5D(&=R;W5P<PH@*B!A<F4@;F]T('-U<'!O<G1E9"X@
M5&AE('-T<G5C='5R92!I="!R971U<FYS(&ES('!R971T>2!S=')A:6=H="!F
M;W)W87)D+`H@*B!A;F0@:7,@<VEM:6QA<B!T;R!T:&%T('!R;W9I9&5D(&)Y
M('1H92!I;6%P7W)F8S@R,E]P87)S95]A9')L:7-T*"DN(%5S90H@*B!P<FEN
M=%]R*"D@=&\@=FEE=R!T:&4@<W1R=6-T=7)E+@H@*@H@*B!(;W<@9&\@22!U
M<V4@:70_"B`J"B`J("1A9&1R97-S7W-T<FEN9R`]("=->2!'<F]U<#H@(E)I
M8VAA<F0B(#QR:6-H87)D0&QO8V%L:&]S=#X@*$$@8V]M;65N="DL('1E9$!E
M>&%M<&QE+F-O;2`H5&5D($)L;V=G<RDL($)A<FYE>3LG.PH@*B`D<W1R=6-T
M=7)E(#T@36%I;%]21D,X,C(Z.G!A<G-E061D<F5S<TQI<W0H)&%D9')E<W-?
M<W1R:6YG+"`G97AA;7!L92YC;VTG+"!T<G5E*0H@*B!P<FEN=%]R*"1S=')U
M8W1U<F4I.PH@*@H@*B!`875T:&]R("!2:6-H87)D($AE>65S(#QR:6-H87)D
M0'!H<&=U<G4N;W)G/@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H@0'9E<G-I;VX@)%)E=FES:6]N.B`Q+C(R("0*
M("H@0&QI8V5N<V4@0E-$"B`J($!P86-K86=E($UA:6P*("HO"F-L87-S($UA
M:6Q?4D9#.#(R('L*"B`@("`O*BH*("`@("`J(%1H92!A9&1R97-S(&)E:6YG
M('!A<G-E9"!B>2!T:&4@4D9#.#(R(&]B:F5C="X*("`@("`J($!V87(@<W1R
M:6YG("1A9&1R97-S"B`@("`@*B\*("`@('9A<B`D861D<F5S<R`]("<G.PH*
M("`@("\J*@H@("`@("H@5&AE(&1E9F%U;'0@9&]M86EN('1O('5S92!F;W(@
M=6YQ=6%L:69I960@861D<F5S<V5S+@H@("`@("H@0'9A<B!S=')I;F<@)&1E
M9F%U;'1?9&]M86EN"B`@("`@*B\*("`@('9A<B`D9&5F875L=%]D;VUA:6X@
M/2`G;&]C86QH;W-T)SL*"B`@("`O*BH*("`@("`J(%-H;W5L9"!W92!R971U
M<FX@82!N97-T960@87)R87D@<VAO=VEN9R!G<F]U<',L(&]R(&9L871T96X@
M979E<GET:&EN9S\*("`@("`J($!V87(@8F]O;&5A;B`D;F5S=$=R;W5P<PH@
M("`@("HO"B`@("!V87(@)&YE<W1'<F]U<',@/2!T<G5E.PH*("`@("\J*@H@
M("`@("H@5VAE=&AE<B!O<B!N;W0@=&\@=F%L:61A=&4@871O;7,@9F]R(&YO
M;BUA<V-I:2!C:&%R86-T97)S+@H@("`@("H@0'9A<B!B;V]L96%N("1V86QI
M9&%T90H@("`@("HO"B`@("!V87(@)'9A;&ED871E(#T@=')U93L*"B`@("`O
M*BH*("`@("`J(%1H92!A<G)A>2!O9B!R87<@861D<F5S<V5S(&)U:6QT('5P
M(&%S('=E('!A<G-E+@H@("`@("H@0'9A<B!A<G)A>2`D861D<F5S<V5S"B`@
M("`@*B\*("`@('9A<B`D861D<F5S<V5S(#T@87)R87DH*3L*"B`@("`O*BH*
M("`@("`J(%1H92!F:6YA;"!A<G)A>2!O9B!P87)S960@861D<F5S<R!I;F9O
M<FUA=&EO;B!T:&%T('=E(&)U:6QD('5P+@H@("`@("H@0'9A<B!A<G)A>2`D
M<W1R=6-T=7)E"B`@("`@*B\*("`@('9A<B`D<W1R=6-T=7)E(#T@87)R87DH
M*3L*"B`@("`O*BH*("`@("`J(%1H92!C=7)R96YT(&5R<F]R(&UE<W-A9V4L
M(&EF(&%N>2X*("`@("`J($!V87(@<W1R:6YG("1E<G)O<@H@("`@("HO"B`@
M("!V87(@)&5R<F]R(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($%N(&EN=&5R
M;F%L(&-O=6YT97(O<&]I;G1E<BX*("`@("`J($!V87(@:6YT96=E<B`D:6YD
M97@*("`@("`J+PH@("`@=F%R("1I;F1E>"`](&YU;&P["@H@("`@+RHJ"B`@
M("`@*B!4:&4@;G5M8F5R(&]F(&=R;W5P<R!T:&%T(&AA=F4@8F5E;B!F;W5N
M9"!I;B!T:&4@861D<F5S<R!L:7-T+@H@("`@("H@0'9A<B!I;G1E9V5R("1N
M=6U?9W)O=7!S"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!V
M87(@)&YU;5]G<F]U<',@/2`P.PH*("`@("\J*@H@("`@("H@02!V87)I86)L
M92!S;R!T:&%T('=E(&-A;B!T96QL('=H971H97(@;W(@;F]T('=E)W)E(&EN
M<VED92!A"B`@("`@*B!-86EL7U)&0S@R,B!O8FIE8W0N"B`@("`@*B!`=F%R
M(&)O;VQE86X@)&UA:6Q21D,X,C(*("`@("`J+PH@("`@=F%R("1M86EL4D9#
M.#(R(#T@=')U93L*"B`@("`O*BH*("`@("H@02!L:6UI="!A9G1E<B!W:&EC
M:"!P<F]C97-S:6YG('-T;W!S"B`@("`J($!V87(@:6YT("1L:6UI=`H@("`@
M*B\*("`@('9A<B`D;&EM:70@/2!N=6QL.PH*("`@("\J*@H@("`@("H@4V5T
M<R!U<"!T:&4@;V)J96-T+B!4:&4@861D<F5S<R!M=7-T(&5I=&AE<B!B92!S
M970@:&5R92!O<B!W:&5N"B`@("`@*B!C86QL:6YG('!A<G-E061D<F5S<TQI
M<W0H*2X@3VYE(&]R('1H92!O=&AE<BX*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H@0'!A<F%M('-T<FEN9R`@)&%D9')E<W,@("`@("`@
M("!4:&4@861D<F5S<RAE<RD@=&\@=F%L:61A=&4N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("`D9&5F875L=%]D;VUA:6X@($1E9F%U;'0@9&]M86EN+VAO<W0@
M971C+B!)9B!N;W0@<W5P<&QI960L('=I;&P@8F4@<V5T('1O(&QO8V%L:&]S
M="X*("`@("`J($!P87)A;2!B;V]L96%N("1N97-T7V=R;W5P<R`@("`@5VAE
M=&AE<B!T;R!R971U<FX@=&AE('-T<G5C='5R92!W:71H(&=R;W5P<R!N97-T
M960@9F]R(&5A<VEE<B!V:65W:6YG+@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)'9A;&ED871E("`@("`@("!7:&5T:&5R('1O('9A;&ED871E(&%T;VUS+B!4
M=7)N('1H:7,@;V9F(&EF('EO=2!N965D('1O(')U;B!A9&1R97-S97,@=&AR
M;W5G:"!B969O<F4@96YC;V1I;F<@=&AE('!E<G-O;F%L(&YA;65S+"!F;W(@
M:6YS=&%N8V4N"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@36%I;%]2
M1D,X,C(@02!N97<@36%I;%]21D,X,C(@;V)J96-T+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!-86EL7U)&0S@R,B@D861D<F5S<R`](&YU;&PL("1D969A=6QT
M7V1O;6%I;B`](&YU;&PL("1N97-T7V=R;W5P<R`](&YU;&PL("1V86QI9&%T
M92`](&YU;&PL("1L:6UI="`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES
M<V5T*"1A9&1R97-S*2D@("`@("`@("1T:&ES+3YA9&1R97-S("`@("`@("`]
M("1A9&1R97-S.PH@("`@("`@(&EF("AI<W-E="@D9&5F875L=%]D;VUA:6XI
M*2`D=&AI<RT^9&5F875L=%]D;VUA:6X@/2`D9&5F875L=%]D;VUA:6X["B`@
M("`@("`@:68@*&ES<V5T*"1N97-T7V=R;W5P<RDI("`@("1T:&ES+3YN97-T
M1W)O=7!S("`@("`]("1N97-T7V=R;W5P<SL*("`@("`@("!I9B`H:7-S970H
M)'9A;&ED871E*2D@("`@("`@)'1H:7,M/G9A;&ED871E("`@("`@(#T@)'9A
M;&ED871E.PH@("`@("`@(&EF("AI<W-E="@D;&EM:70I*2`@("`@("`@("`D
M=&AI<RT^;&EM:70@("`@("`@("`@/2`D;&EM:70["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3=&%R=',@=&AE('=H;VQE('!R;V-E<W,N(%1H92!A9&1R97-S
M(&UU<W0@96ET:&5R(&)E('-E="!H97)E"B`@("`@*B!O<B!W:&5N(&-R96%T
M:6YG('1H92!O8FIE8W0N($]N92!O<B!T:&4@;W1H97(N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!S=')I;F<@("1A9&1R
M97-S("`@("`@("`@5&AE(&%D9')E<W,H97,I('1O('9A;&ED871E+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)&1E9F%U;'1?9&]M86EN("!$969A=6QT(&1O
M;6%I;B]H;W-T(&5T8RX*("`@("`J($!P87)A;2!B;V]L96%N("1N97-T7V=R
M;W5P<R`@("`@5VAE=&AE<B!T;R!R971U<FX@=&AE('-T<G5C='5R92!W:71H
M(&=R;W5P<R!N97-T960@9F]R(&5A<VEE<B!V:65W:6YG+@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)'9A;&ED871E("`@("`@("!7:&5T:&5R('1O('9A;&ED
M871E(&%T;VUS+B!4=7)N('1H:7,@;V9F(&EF('EO=2!N965D('1O(')U;B!A
M9&1R97-S97,@=&AR;W5G:"!B969O<F4@96YC;V1I;F<@=&AE('!E<G-O;F%L
M(&YA;65S+"!F;W(@:6YS=&%N8V4N"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2!!('-T<G5C='5R960@87)R87D@;V8@861D<F5S<V5S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!P87)S94%D9')E<W-,:7-T*"1A9&1R97-S(#T@;G5L
M;"P@)&1E9F%U;'1?9&]M86EN(#T@;G5L;"P@)&YE<W1?9W)O=7!S(#T@;G5L
M;"P@)'9A;&ED871E(#T@;G5L;"P@)&QI;6ET(#T@;G5L;"D*("`@('L*("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES*2!\?"`A:7-S970H)'1H:7,M/FUA:6Q2
M1D,X,C(I*2!["B`@("`@("`@("`@("1O8FH@/2!N97<@36%I;%]21D,X,C(H
M)&%D9')E<W,L("1D969A=6QT7V1O;6%I;BP@)&YE<W1?9W)O=7!S+"`D=F%L
M:61A=&4L("1L:6UI="D["B`@("`@("`@("`@(')E='5R;B`D;V)J+3YP87)S
M94%D9')E<W-,:7-T*"D["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H
M)&%D9')E<W,I*2`@("`@("`@)'1H:7,M/F%D9')E<W,@("`@("`@(#T@)&%D
M9')E<W,["B`@("`@("`@:68@*&ES<V5T*"1D969A=6QT7V1O;6%I;BDI("1T
M:&ES+3YD969A=6QT7V1O;6%I;B`]("1D969A=6QT7V1O;6%I;CL*("`@("`@
M("!I9B`H:7-S970H)&YE<W1?9W)O=7!S*2D@("`@)'1H:7,M/FYE<W1'<F]U
M<',@("`@(#T@)&YE<W1?9W)O=7!S.PH@("`@("`@(&EF("AI<W-E="@D=F%L
M:61A=&4I*2`@("`@("`D=&AI<RT^=F%L:61A=&4@("`@("`@/2`D=F%L:61A
M=&4["B`@("`@("`@:68@*&ES<V5T*"1L:6UI="DI("`@("`@("`@("1T:&ES
M+3YL:6UI="`@("`@("`@("`]("1L:6UI=#L*"B`@("`@("`@)'1H:7,M/G-T
M<G5C='5R92`@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3YA9&1R97-S97,@
M(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^97)R;W(@("`@("`](&YU;&P[
M"B`@("`@("`@)'1H:7,M/FEN9&5X("`@("`@/2!N=6QL.PH*("`@("`@("`O
M+R!5;F9O;&0@86YY(&QO;F<@;&EN97,@:6X@)'1H:7,M/F%D9')E<W,N"B`@
M("`@("`@)'1H:7,M/F%D9')E<W,@/2!P<F5G7W)E<&QA8V4H)R]<<C]<;B\G
M+"`B7')<;B(L("1T:&ES+3YA9&1R97-S*3L*("`@("`@("`D=&AI<RT^861D
M<F5S<R`]('!R96=?<F5P;&%C92@G+UQR7&XH7'1\("DK+R<L("<@)RP@)'1H
M:7,M/F%D9')E<W,I.PH*("`@("`@("!W:&EL92`H)'1H:7,M/F%D9')E<W,@
M/2`D=&AI<RT^7W-P;&ET061D<F5S<V5S*"1T:&ES+3YA9&1R97-S*2D["@H@
M("`@("`@(&EF("@D=&AI<RT^861D<F5S<R`]/3T@9F%L<V4@?'P@:7-S970H
M)'1H:7,M/F5R<F]R*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%
M05(N<&AP)SL*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)'1H:7,M/F5R<F]R*3L*("`@("`@("!]"@H@("`@("`@("\O(%9A;&ED871E
M(&5A8V@@861D<F5S<R!I;F1I=FED=6%L;'DN("!)9B!W92!E;F-O=6YT97(@
M86X@:6YV86QI9`H@("`@("`@("\O(&%D9')E<W,L('-T;W`@:71E<F%T:6YG
M(&%N9"!R971U<FX@86X@97)R;W(@:6UM961I871E;'DN"B`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/F%D9')E<W-E<R!A<R`D861D<F5S<RD@>PH@("`@("`@
M("`@("`D=F%L:60@/2`D=&AI<RT^7W9A;&ED871E061D<F5S<R@D861D<F5S
M<RD["@H@("`@("`@("`@("!I9B`H)'9A;&ED(#T]/2!F86QS92!\?"!I<W-E
M="@D=&AI<RT^97)R;W(I*2!["B`@("`@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)U!%05(N<&AP)SL*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"1T:&ES+3YE<G)O<BD["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(&EF("@A)'1H:7,M/FYE<W1'<F]U<',I('L*("`@("`@("`@("`@
M("`@("1T:&ES+3YS=')U8W1U<F4@/2!A<G)A>5]M97)G92@D=&AI<RT^<W1R
M=6-T=7)E+"`D=F%L:60I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/G-T<G5C='5R95M=(#T@)'9A;&ED.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/G-T<G5C
M='5R93L*("`@('T*"B`@("`O*BH*("`@("`J(%-P;&ET<R!A;B!A9&1R97-S
M(&EN=&\@<V5P87)A=&4@861D<F5S<V5S+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H@0'!A<F%M('-T<FEN9R`D861D<F5S<R!4:&4@
M861D<F5S<V5S('1O('-P;&ET+@H@("`@("H@0')E='5R;B!B;V]L96%N(%-U
M8V-E<W,@;W(@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7W-P;&ET
M061D<F5S<V5S*"1A9&1R97-S*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH
M)'1H:7,M/FQI;6ET*2`F)B!C;W5N="@D=&AI<RT^861D<F5S<V5S*2`]/2`D
M=&AI<RT^;&EM:70I('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"1T:&ES+3Y?:7-'<F]U<"@D861D<F5S<RD@)B8@
M(6ES<V5T*"1T:&ES+3YE<G)O<BDI('L*("`@("`@("`@("`@)'-P;&ET7V-H
M87(@/2`G.R<["B`@("`@("`@("`@("1I<U]G<F]U<"`@(#T@=')U93L*("`@
M("`@("!](&5L<V5I9B`H(6ES<V5T*"1T:&ES+3YE<G)O<BDI('L*("`@("`@
M("`@("`@)'-P;&ET7V-H87(@/2`G+"<["B`@("`@("`@("`@("1I<U]G<F]U
M<"`@(#T@9F%L<V4["B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3YE
M<G)O<BDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@+R\@4W!L:70@=&AE('-T<FEN9R!B87-E9"!O;B!T:&4@86)O
M=F4@=&5N(&]R('-O(&QI;F5S+@H@("`@("`@("1P87)T<R`@/2!E>'!L;V1E
M*"1S<&QI=%]C:&%R+"`D861D<F5S<RD["B`@("`@("`@)'-T<FEN9R`]("1T
M:&ES+3Y?<W!L:71#:&5C:R@D<&%R=',L("1S<&QI=%]C:&%R*3L*"B`@("`@
M("`@+R\@268@82!G<F]U<"XN+@H@("`@("`@(&EF("@D:7-?9W)O=7`I('L*
M("`@("`@("`@("`@+R\@268@)'-T<FEN9R!D;V5S(&YO="!C;VYT86EN(&$@
M8V]L;VX@;W5T<VED92!O9@H@("`@("`@("`@("`O+R!B<F%C:V5T<R]Q=6]T
M97,@971C('1H96X@<V]M971H:6YG)W,@9G5B87(N"@H@("`@("`@("`@("`O
M+R!&:7)S="!C:&5C:R!T:&5R92=S(&$@8V]L;VX@870@86QL.@H@("`@("`@
M("`@("!I9B`H<W1R<&]S*"1S=')I;F<L("<Z)RD@/3T](&9A;'-E*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^97)R;W(@/2`G26YV86QI9"!A9&1R97-S
M.B`G("X@)'-T<FEN9SL*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@3F]W(&-H96-K(&ET)W,@
M;W5T<VED92!O9B!B<F%C:V5T<R]Q=6]T97,Z"B`@("`@("`@("`@(&EF("@A
M)'1H:7,M/E]S<&QI=$-H96-K*&5X<&QO9&4H)SHG+"`D<W1R:6YG*2P@)SHG
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`O+R!792!M=7-T(&AA=F4@82!G<F]U<"!A="!T
M:&ES('!O:6YT+"!S;R!I;F-R96%S92!T:&4@8V]U;G1E<CH*("`@("`@("`@
M("`@)'1H:7,M/FYU;5]G<F]U<',K*SL*("`@("`@("!]"@H@("`@("`@("\O
M("1S=')I;F<@;F]W(&-O;G1A:6YS('1H92!F:7)S="!F=6QL(&%D9')E<W,O
M9W)O=7`N"B`@("`@("`@+R\@061D('1O('1H92!A9&1R97-S97,@87)R87DN
M"B`@("`@("`@)'1H:7,M/F%D9')E<W-E<UM=(#T@87)R87DH"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%D9')E<W,G(#T^('1R:6TH
M)'-T<FEN9RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V=R;W5P)R`@(#T^("1I<U]G<F]U<`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("D["@H@("`@("`@("\O(%)E;6]V92!T:&4@;F]W('-T
M;W)E9"!A9&1R97-S(&9R;VT@=&AE(&EN:71I86P@;&EN92P@=&AE("LQ"B`@
M("`@("`@+R\@:7,@=&\@86-C;W5N="!F;W(@=&AE(&5X<&QO9&4@8VAA<F%C
M=&5R+@H@("`@("`@("1A9&1R97-S(#T@=')I;2AS=6)S='(H)&%D9')E<W,L
M('-T<FQE;B@D<W1R:6YG*2`K(#$I*3L*"B`@("`@("`@+R\@268@=&AE(&YE
M>'0@8VAA<B!I<R!A(&-O;6UA(&%N9"!T:&ES('=A<R!A(&=R;W5P+"!T:&5N
M"B`@("`@("`@+R\@=&AE<F4@87)E(&UO<F4@861D<F5S<V5S+"!O=&AE<G=I
M<V4L(&EF('1H97)E(&%R92!A;GD@;6]R90H@("`@("`@("\O(&-H87)S+"!T
M:&5N('1H97)E(&ES(&%N;W1H97(@861D<F5S<RX*("`@("`@("!I9B`H)&ES
M7V=R;W5P("8F('-U8G-T<B@D861D<F5S<RP@,"P@,2D@/3T@)RPG*7L*("`@
M("`@("`@("`@)&%D9')E<W,@/2!T<FEM*'-U8G-T<B@D861D<F5S<RP@,2DI
M.PH@("`@("`@("`@("!R971U<FX@)&%D9')E<W,["@H@("`@("`@('T@96QS
M96EF("AS=')L96XH)&%D9')E<W,I(#X@,"D@>PH@("`@("`@("`@("!R971U
M<FX@)&%D9')E<W,["@H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B`G)SL*("`@("`@("!]"@H@("`@("`@("\O($EF('EO=2!G;W0@:&5R
M92!T:&5N('-O;65T:&EN9R=S(&]F9@H@("`@("`@(')E='5R;B!F86QS93L*
M("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!F;W(@82!G<F]U<"!A="!T
M:&4@<W1A<G0@;V8@=&AE('-T<FEN9RX*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J($!P87)A;2!S=')I;F<@)&%D9')E<W,@5&AE(&%D
M9')E<W,@=&\@8VAE8VLN"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@5VAE=&AE
M<B!O<B!N;W0@=&AE<F4@:7,@82!G<F]U<"!A="!T:&4@<W1A<G0@;V8@=&AE
M('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@7VES1W)O=7`H)&%D9')E
M<W,I"B`@("!["B`@("`@("`@+R\@1FER<W0@8V]M;6$@;F]T(&EN('%U;W1E
M<RP@86YG;&5S(&]R(&5S8V%P960Z"B`@("`@("`@)'!A<G1S("`](&5X<&QO
M9&4H)RPG+"`D861D<F5S<RD["B`@("`@("`@)'-T<FEN9R`]("1T:&ES+3Y?
M<W!L:71#:&5C:R@D<&%R=',L("<L)RD["@H@("`@("`@("\O($YO=R!W92!H
M879E('1H92!F:7)S="!A9&1R97-S+"!W92!C86X@<F5L:6%B;'D@8VAE8VL@
M9F]R(&$*("`@("`@("`O+R!G<F]U<"!B>2!S96%R8VAI;F<@9F]R(&$@8V]L
M;VX@=&AA="=S(&YO="!E<V-A<&5D(&]R(&EN"B`@("`@("`@+R\@<75O=&5S
M(&]R(&%N9VQE(&)R86-K971S+@H@("`@("`@(&EF("AC;W5N="@D<&%R=',@
M/2!E>'!L;V1E*"<Z)RP@)'-T<FEN9RDI(#X@,2D@>PH@("`@("`@("`@("`D
M<W1R:6YG,B`]("1T:&ES+3Y?<W!L:71#:&5C:R@D<&%R=',L("<Z)RD["B`@
M("`@("`@("`@(')E='5R;B`H)'-T<FEN9S(@(3T]("1S=')I;F<I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!(&-O;6UO;B!F=6YC=&EO;B!T
M:&%T('=I;&P@8VAE8VL@86X@97AP;&]D960@<W1R:6YG+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)T
M<R!4:&4@97AL;V1E9"!S=')I;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C
M:&%R("!4:&4@8VAA<B!T:&%T('=A<R!E>'!L;V1E9"!O;BX*("`@("`J($!R
M971U<FX@;6EX960@1F%L<V4@:68@=&AE('-T<FEN9R!C;VYT86EN<R!U;F-L
M;W-E9"!Q=6]T97,O8G)A8VME=',L(&]R('1H92!S=')I;F<@;VX@<W5C8V5S
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-P;&ET0VAE8VLH)'!A<G1S+"`D
M8VAA<BD*("`@('L*("`@("`@("`D<W1R:6YG(#T@)'!A<G1S6S!=.PH*("`@
M("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D<&%R=',I.R`D:2LK*2![
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^7VAA<U5N8VQO<V5D475O=&5S*"1S
M=')I;F<I"B`@("`@("`@("`@("`@("!\?"`D=&AI<RT^7VAA<U5N8VQO<V5D
M0G)A8VME=',H)'-T<FEN9RP@)SP^)RD*("`@("`@("`@("`@("`@('Q\("1T
M:&ES+3Y?:&%S56YC;&]S961"<F%C:V5T<R@D<W1R:6YG+"`G6UTG*0H@("`@
M("`@("`@("`@("`@?'P@)'1H:7,M/E]H87-5;F-L;W-E9$)R86-K971S*"1S
M=')I;F<L("<H*2<I"B`@("`@("`@("`@("`@("!\?"!S=6)S='(H)'-T<FEN
M9RP@+3$I(#T]("=<7"<I('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M<&%R='-;)&D@*R`Q72DI('L*("`@("`@("`@("`@("`@("`@("`D<W1R:6YG
M(#T@)'-T<FEN9R`N("1C:&%R("X@)'!A<G1S6R1I("L@,5T["B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YE
M<G)O<B`]("=);G9A;&ED(&%D9')E<W,@<W!E8RX@56YC;&]S960@8G)A8VME
M="!O<B!Q=6]T97,G.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1T:&ES+3YI;F1E>"`]("1I.PH@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D<W1R:6YG.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS(&EF
M(&$@<W1R:6YG(&AA<R!A;B!U;F-L;W-E9"!Q=6]T97,@;W(@;F]T+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<W1R:6YG(%1H92!S=')I;F<@=&\@8VAE8VLN"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@5')U92!I9B!T:&5R92!A<F4@=6YC;&]S960@<75O=&5S(&EN
M<VED92!T:&4@<W1R:6YG+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]H87-5;F-L;W-E9%%U;W1E<R@D<W1R:6YG*0H@("`@>PH@
M("`@("`@("1S=')I;F<@("`@(#T@97AP;&]D92@G(B<L("1S=')I;F<I.PH@
M("`@("`@("1S=')I;F=?8VYT(#T@8V]U;G0H)'-T<FEN9RD["@H@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\("AC;W5N="@D<W1R:6YG*2`M(#$I.R`D:2LK
M*0H@("`@("`@("`@("!I9B`H<W5B<W1R*"1S=')I;F=;)&E=+"`M,2D@/3T@
M)UQ<)RD*("`@("`@("`@("`@("`@("1S=')I;F=?8VYT+2T["@H@("`@("`@
M(')E='5R;B`H)'-T<FEN9U]C;G0@)2`R(#T]/2`P*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($-H96-K<R!I9B!A('-T<FEN9R!H87,@86X@=6YC;&]S960@
M8G)A8VME=',@;W(@;F]T+B!)35!/4E1!3E0Z"B`@("`@*B!4:&ES(&9U;F-T
M:6]N(&AA;F1L97,@8F]T:"!A;F=L92!B<F%C:V5T<R!A;F0@<W%U87)E(&)R
M86-K971S.PH@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<W1R:6YG(%1H92!S=')I;F<@=&\@8VAE8VLN"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C:&%R<R`@5&AE(&-H87)A8W1E<G,@=&\@
M8VAE8VL@9F]R+@H@("`@("H@0')E='5R;B!B;V]L96%N(%1R=64@:68@=&AE
M<F4@87)E('5N8VQO<V5D(&)R86-K971S(&EN<VED92!T:&4@<W1R:6YG+"!F
M86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]H87-5;F-L
M;W-E9$)R86-K971S*"1S=')I;F<L("1C:&%R<RD*("`@('L*("`@("`@("`D
M;G5M7V%N9VQE7W-T87)T(#T@<W5B<W1R7V-O=6YT*"1S=')I;F<L("1C:&%R
M<ULP72D["B`@("`@("`@)&YU;5]A;F=L95]E;F0@("`]('-U8G-T<E]C;W5N
M="@D<W1R:6YG+"`D8VAA<G-;,5TI.PH*("`@("`@("`D=&AI<RT^7VAA<U5N
M8VQO<V5D0G)A8VME='-3=6(H)'-T<FEN9RP@)&YU;5]A;F=L95]S=&%R="P@
M)&-H87)S6S!=*3L*("`@("`@("`D=&AI<RT^7VAA<U5N8VQO<V5D0G)A8VME
M='-3=6(H)'-T<FEN9RP@)&YU;5]A;F=L95]E;F0L("1C:&%R<ULQ72D["@H@
M("`@("`@(&EF("@D;G5M7V%N9VQE7W-T87)T(#P@)&YU;5]A;F=L95]E;F0I
M('L*("`@("`@("`@("`@)'1H:7,M/F5R<F]R(#T@)TEN=F%L:60@861D<F5S
M<R!S<&5C+B!5;FUA=&-H960@<75O=&4@;W(@8G)A8VME="`H)R`N("1C:&%R
M<R`N("<I)SL*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B`H)&YU;5]A;F=L95]S=&%R="`^
M("1N=6U?86YG;&5?96YD*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3=6(@9G5N8W1I;VX@=&AA="!I<R!U<V5D(&]N;'D@8GD@:&%S56YC
M;&]S961"<F%C:V5T<R@I+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1R:6YG(%1H92!S=')I;F<@=&\@
M8VAE8VLN"B`@("`@*B!`<&%R86T@:6YT96=E<B`F)&YU;2`@("!4:&4@;G5M
M8F5R(&]F(&]C8W5R96YC97,N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:&%R
M("`@5&AE(&-H87)A8W1E<B!T;R!C;W5N="X*("`@("`J($!R971U<FX@:6YT
M96=E<B!4:&4@;G5M8F5R(&]F(&]C8W5R96YC97,@;V8@)&-H87(@:6X@)'-T
M<FEN9RP@861J=7-T960@9F]R(&)A8VMS;&%S:&5S+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?:&%S56YC;&]S961"<F%C:V5T<U-U8B@D<W1R:6YG+"`F)&YU
M;2P@)&-H87(I"B`@("!["B`@("`@("`@)'!A<G1S(#T@97AP;&]D92@D8VAA
M<BP@)'-T<FEN9RD["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H
M)'!A<G1S*3L@)&DK*RE["B`@("`@("`@("`@(&EF("AS=6)S='(H)'!A<G1S
M6R1I72P@+3$I(#T]("=<7"<@?'P@)'1H:7,M/E]H87-5;F-L;W-E9%%U;W1E
M<R@D<&%R='-;)&E=*2D*("`@("`@("`@("`@("`@("1N=6TM+3L*("`@("`@
M("`@("`@:68@*&ES<V5T*"1P87)T<ULD:2`K(#%=*2D*("`@("`@("`@("`@
M("`@("1P87)T<ULD:2`K(#%=(#T@)'!A<G1S6R1I72`N("1C:&%R("X@)'!A
M<G1S6R1I("L@,5T["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&YU;3L*
M("`@('T*"B`@("`O*BH*("`@("`J($9U;F-T:6]N('1O(&)E9VEN(&-H96-K
M:6YG('1H92!A9&1R97-S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H@0'!A<F%M('-T<FEN9R`D861D<F5S<R!4:&4@861D<F5S<R!T
M;R!V86QI9&%T92X*("`@("`J($!R971U<FX@;6EX960@1F%L<V4@;VX@9F%I
M;'5R92P@;W(@82!S=')U8W1U<F5D(&%R<F%Y(&]F(&%D9')E<W,@:6YF;W)M
M871I;VX@;VX@<W5C8V5S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W9A;&ED
M871E061D<F5S<R@D861D<F5S<RD*("`@('L*("`@("`@("`D:7-?9W)O=7`@
M/2!F86QS93L*("`@("`@("`D861D<F5S<V5S(#T@87)R87DH*3L*"B`@("`@
M("`@:68@*"1A9&1R97-S6R=G<F]U<"==*2!["B`@("`@("`@("`@("1I<U]G
M<F]U<"`]('1R=64["@H@("`@("`@("`@("`O+R!'970@=&AE(&=R;W5P('!A
M<G0@;V8@=&AE(&YA;64*("`@("`@("`@("`@)'!A<G1S("`@("`](&5X<&QO
M9&4H)SHG+"`D861D<F5S<ULG861D<F5S<R==*3L*("`@("`@("`@("`@)&=R
M;W5P;F%M92`]("1T:&ES+3Y?<W!L:71#:&5C:R@D<&%R=',L("<Z)RD["B`@
M("`@("`@("`@("1S=')U8W1U<F4@/2!A<G)A>2@I.PH*("`@("`@("`@("`@
M+R\@06YD('9A;&ED871E('1H92!G<F]U<"!P87)T(&]F('1H92!N86UE+@H@
M("`@("`@("`@("!I9B`H(21T:&ES+3Y?=F%L:61A=&50:')A<V4H)&=R;W5P
M;F%M92DI>PH@("`@("`@("`@("`@("`@)'1H:7,M/F5R<F]R(#T@)T=R;W5P
M(&YA;64@9&ED(&YO="!V86QI9&%T92XG.PH@("`@("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@+R\@1&]N)W0@:6YC;'5D92!G<F]U<',@:68@=V4@87)E(&YO="!N97-T
M:6YG"B`@("`@("`@("`@("`@("`O+R!T:&5M+B!4:&ES(&%V;VED<R!R971U
M<FYI;F<@:6YV86QI9"!A9&1R97-S97,N"B`@("`@("`@("`@("`@("!I9B`H
M)'1H:7,M/FYE<W1'<F]U<',I('L*("`@("`@("`@("`@("`@("`@("`D<W1R
M=6-T=7)E(#T@;F5W('-T9$-L87-S.PH@("`@("`@("`@("`@("`@("`@("1S
M=')U8W1U<F4M/F=R;W5P;F%M92`]("1G<F]U<&YA;64["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1A9&1R97-S6R=A
M9&1R97-S)UT@/2!L=')I;2AS=6)S='(H)&%D9')E<W-;)V%D9')E<W,G72P@
M<W1R;&5N*"1G<F]U<&YA;64@+B`G.B<I*2D["B`@("`@("`@?0H*("`@("`@
M("`O+R!)9B!A(&=R;W5P('1H96X@<W!L:70@;VX@8V]M;6$@86YD('!U="!I
M;G1O(&%N(&%R<F%Y+@H@("`@("`@("\O($]T:&5R=VES92P@2G5S="!P=70@
M=&AE('=H;VQE(&%D9')E<W,@:6X@86X@87)R87DN"B`@("`@("`@:68@*"1I
M<U]G<F]U<"D@>PH@("`@("`@("`@("!W:&EL92`H<W1R;&5N*"1A9&1R97-S
M6R=A9&1R97-S)UTI(#X@,"D@>PH@("`@("`@("`@("`@("`@)'!A<G1S("`@
M("`@(#T@97AP;&]D92@G+"<L("1A9&1R97-S6R=A9&1R97-S)UTI.PH@("`@
M("`@("`@("`@("`@)&%D9')E<W-E<UM=(#T@)'1H:7,M/E]S<&QI=$-H96-K
M*"1P87)T<RP@)RPG*3L*("`@("`@("`@("`@("`@("1A9&1R97-S6R=A9&1R
M97-S)UT@/2!T<FEM*'-U8G-T<B@D861D<F5S<ULG861D<F5S<R==+"!S=')L
M96XH96YD*"1A9&1R97-S97,I("X@)RPG*2DI.PH@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&%D9')E<W-E<UM=(#T@)&%D
M9')E<W-;)V%D9')E<W,G73L*("`@("`@("!]"@H@("`@("`@("\O($-H96-K
M('1H870@)&%D9')E<W-E<R!I<R!S970L(&EF(&%D9')E<W,@;&EK92!T:&ES
M.@H@("`@("`@("\O($=R;W5P;F%M93H["B`@("`@("`@+R\@5&AE;B!E<G)O
M<G,@=V5R92!A<'!E87)I;F<N"B`@("`@("`@:68@*"%C;W5N="@D861D<F5S
M<V5S*2E["B`@("`@("`@("`@("1T:&ES+3YE<G)O<B`]("=%;7!T>2!G<F]U
M<"XG.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("`O+R!4<FEM('1H92!W:&ET97-P86-E(&9R;VT@86QL(&]F('1H92!A
M9&1R97-S('-T<FEN9W,N"B`@("`@("`@87)R87E?;6%P*"=T<FEM)RP@)&%D
M9')E<W-E<RD["@H@("`@("`@("\O(%9A;&ED871E(&5A8V@@;6%I;&)O>"X*
M("`@("`@("`O+R!&;W)M870@8V]U;&0@8F4@;VYE(&]F.B!N86UE(#QG965Z
M97)`9&]M86EN+F-O;3X*("`@("`@("`O+R`@("`@("`@("`@("`@("`@("`@
M("`@("!G965Z97)`9&]M86EN+F-O;0H@("`@("`@("\O("`@("`@("`@("`@
M("`@("`@("`@("`@(&=E97IE<@H@("`@("`@("\O("XN+B!O<B!A;GD@;W1H
M97(@9F]R;6%T('9A;&ED(&)Y(%)&0R`X,C(N"B`@("`@("`@9F]R("@D:2`]
M(#`[("1I(#P@8V]U;G0H)&%D9')E<W-E<RD[("1I*RLI('L*("`@("`@("`@
M("`@:68@*"$D=&AI<RT^=F%L:61A=&5-86EL8F]X*"1A9&1R97-S97-;)&E=
M*2D@>PH@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3YE<G)O<BDI
M('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^97)R;W(@/2`G5F%L:61A
M=&EO;B!F86EL960@9F]R.B`G("X@)&%D9')E<W-E<ULD:5T["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($YE<W1E9"!F;W)M870*
M("`@("`@("!I9B`H)'1H:7,M/FYE<W1'<F]U<',I('L*("`@("`@("`@("`@
M:68@*"1I<U]G<F]U<"D@>PH@("`@("`@("`@("`@("`@)'-T<G5C='5R92T^
M861D<F5S<V5S(#T@)&%D9')E<W-E<SL*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1S=')U8W1U<F4@/2`D861D<F5S<V5S6S!=.PH@
M("`@("`@("`@("!]"@H@("`@("`@("\O($9L870@9F]R;6%T"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@:68@*"1I<U]G<F]U<"D@>PH@("`@("`@
M("`@("`@("`@)'-T<G5C='5R92`](&%R<F%Y7VUE<F=E*"1S=')U8W1U<F4L
M("1A9&1R97-S97,I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)'-T<G5C='5R92`]("1A9&1R97-S97,["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<W1R=6-T=7)E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1G5N8W1I;VX@=&\@=F%L:61A=&4@82!P:')A<V4N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P:')A<V4@5&AE('!H<F%S92!T;R!C:&5C:RX*("`@("`J($!R
M971U<FX@8F]O;&5A;B!3=6-C97-S(&]R(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]V86QI9&%T95!H<F%S92@D<&AR87-E*0H@("`@>PH@("`@
M("`@("\O(%-P;&ET<R!O;B!O;F4@;W(@;6]R92!486(@;W(@<W!A8V4N"B`@
M("`@("`@)'!A<G1S(#T@<')E9U]S<&QI="@G+UL@7%QX,#E=*R\G+"`D<&AR
M87-E+"`M,2P@4%)%1U]34$Q)5%].3U]%35!462D["@H@("`@("`@("1P:')A
M<V5?<&%R=',@/2!A<G)A>2@I.PH@("`@("`@('=H:6QE("AC;W5N="@D<&%R
M=',I(#X@,"E["B`@("`@("`@("`@("1P:')A<V5?<&%R='-;72`]("1T:&ES
M+3Y?<W!L:71#:&5C:R@D<&%R=',L("<@)RD["B`@("`@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\("1T:&ES+3YI;F1E>"`K(#$[("1I*RLI"B`@("`@("`@
M("`@("`@("!A<G)A>5]S:&EF="@D<&%R=',I.PH@("`@("`@('T*"B`@("`@
M("`@9F]R96%C:"`H)'!H<F%S95]P87)T<R!A<R`D<&%R="D@>PH@("`@("`@
M("`@("`O+R!)9B!Q=6]T960@<W1R:6YG.@H@("`@("`@("`@("!I9B`H<W5B
M<W1R*"1P87)T+"`P+"`Q*2`]/2`G(B<I('L*("`@("`@("`@("`@("`@(&EF
M("@A)'1H:7,M/E]V86QI9&%T95%U;W1E9%-T<FEN9R@D<&%R="DI('L*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@+R\@3W1H97)W:7-E(&ET)W,@86X@871O;3H*("`@("`@
M("`@("`@:68@*"$D=&AI<RT^7W9A;&ED871E071O;2@D<&%R="DI(')E='5R
M;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1G5N8W1I;VX@=&\@=F%L:61A=&4@86X@871O
M;2!W:&EC:"!F<F]M(')F8S@R,B!I<SH*("`@("`J(&%T;VT@/2`Q*CQA;GD@
M0TA!4B!E>&-E<'0@<W!E8VEA;',L(%-004-%(&%N9"!#5$QS/@H@("`@("H*
M("`@("`J($EF('9A;&ED871I;VX@*"1T:&ES+3YV86QI9&%T92D@:&%S(&)E
M96X@='5R;F5D(&]F9BP@=&AE;@H@("`@("H@=F%L:61A=&5!=&]M*"D@9&]E
M<VXG="!A8W1U86QL>2!C:&5C:R!A;GET:&EN9RX@5&AI<R!I<R!S;R!T:&%T
M('EO=0H@("`@("H@8V%N('-P;&ET(&$@;&ES="!O9B!A9&1R97-S97,@=7`@
M8F5F;W)E(&5N8V]D:6YG('!E<G-O;F%L(&YA;65S"B`@("`@*B`H=6UL875T
M<RP@971C+BDL(&9O<B!E>&%M<&QE+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H@0'!A<F%M('-T<FEN9R`D871O;2!4:&4@<W1R:6YG
M('1O(&-H96-K+@H@("`@("H@0')E='5R;B!B;V]L96%N(%-U8V-E<W,@;W(@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7W9A;&ED871E071O;2@D
M871O;2D*("`@('L*("`@("`@("!I9B`H(21T:&ES+3YV86QI9&%T92D@>PH@
M("`@("`@("`@("`O+R!686QI9&%T:6]N(&AA<R!B965N('1U<FYE9"!O9F8[
M(&%S<W5M92!T:&4@871O;2!I<R!O:V%Y+@H@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("!]"@H@("`@("`@("\O($-H96-K(&9O<B!A;GD@8VAA
M<B!F<F]M($%30TE)(#`@+2!!4T-)22`Q,C<*("`@("`@("!I9B`H(7!R96=?
M;6%T8V@H)R]>6UQ<>#`P+5Q<>#=%72LD+VDG+"`D871O;2P@)&UA=&-H97,I
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@("\O($-H96-K(&9O<B!S<&5C:6%L<SH*("`@("`@("!I9B`H<')E9U]M
M871C:"@G+UM=6R@I/#Y`+#M<7#HB+B!=+R<L("1A=&]M*2D@>PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O+R!#:&5C
M:R!F;W(@8V]N=')O;"!C:&%R86-T97)S("A!4T-)22`P+3,Q*3H*("`@("`@
M("!I9B`H<')E9U]M871C:"@G+UM<7'@P,"U<7'@Q1ETK+R<L("1A=&]M*2D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($9U;F-T:6]N
M('1O('9A;&ED871E('%U;W1E9"!S=')I;F<L('=H:6-H(&ES.@H@("`@("H@
M<75O=&5D+7-T<FEN9R`](#PB/B`J*'%T97AT+W%U;W1E9"UP86ER*2`\(CX*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2!S
M=')I;F<@)'%S=')I;F<@5&AE('-T<FEN9R!T;R!C:&5C:PH@("`@("H@0')E
M='5R;B!B;V]L96%N(%-U8V-E<W,@;W(@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W9A;&ED871E475O=&5D4W1R:6YG*"1Q<W1R:6YG*0H@("`@
M>PH@("`@("`@("\O($QE861I;F<@86YD('1R86EL:6YG("(*("`@("`@("`D
M<7-T<FEN9R`]('-U8G-T<B@D<7-T<FEN9RP@,2P@+3$I.PH*("`@("`@("`O
M+R!097)F;W)M(&-H96-K+"!R96UO=FEN9R!Q=6]T960@8VAA<F%C=&5R<R!F
M:7)S="X*("`@("`@("!R971U<FX@(7!R96=?;6%T8V@H)R];7'@P1%Q<7%PB
M72\G+"!P<F5G7W)E<&QA8V4H)R]<7%Q<+B\G+"`G)RP@)'%S=')I;F<I*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($9U;F-T:6]N('1O('9A;&ED871E(&$@
M;6%I;&)O>"P@=VAI8V@@:7,Z"B`@("`@*B!M86EL8F]X(#T@("!A9&1R+7-P
M96,@("`@("`@("`[('-I;7!L92!A9&1R97-S"B`@("`@*B`@("`@("`@("`@
M+R!P:')A<V4@<F]U=&4M861D<B`[(&YA;64@86YD(')O=71E+6%D9'(*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M('-T<FEN
M9R`F)&UA:6QB;W@@5&AE('-T<FEN9R!T;R!C:&5C:RX*("`@("`J($!R971U
M<FX@8F]O;&5A;B!3=6-C97-S(&]R(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('9A;&ED871E36%I;&)O>"@F)&UA:6QB;W@I"B`@("!["B`@("`@
M("`@+R\@02!C;W5P;&4@;V8@9&5F875L=',N"B`@("`@("`@)'!H<F%S92`@
M/2`G)SL*("`@("`@("`D8V]M;65N="`]("<G.PH@("`@("`@("1C;VUM96YT
M<R`](&%R<F%Y*"D["@H@("`@("`@("\O($-A=&-H(&%N>2!21D,X,C(@8V]M
M;65N=',@86YD('-T;W)E('1H96T@<V5P87)A=&5L>2X*("`@("`@("`D7VUA
M:6QB;W@@/2`D;6%I;&)O>#L*("`@("`@("!W:&EL92`H<W1R;&5N*'1R:6TH
M)%]M86EL8F]X*2D@/B`P*2!["B`@("`@("`@("`@("1P87)T<R`](&5X<&QO
M9&4H)R@G+"`D7VUA:6QB;W@I.PH@("`@("`@("`@("`D8F5F;W)E7V-O;6UE
M;G0@/2`D=&AI<RT^7W-P;&ET0VAE8VLH)'!A<G1S+"`G*"<I.PH@("`@("`@
M("`@("!I9B`H)&)E9F]R95]C;VUM96YT("$]("1?;6%I;&)O>"D@>PH@("`@
M("`@("`@("`@("`@+R\@1FER<W0@8VAA<B!S:&]U;&0@8F4@82`H+@H@("`@
M("`@("`@("`@("`@)&-O;6UE;G0@("`@/2!S=6)S='(H<W1R7W)E<&QA8V4H
M)&)E9F]R95]C;VUM96YT+"`G)RP@)%]M86EL8F]X*2P@,2D["B`@("`@("`@
M("`@("`@("`D<&%R=',@("`@("`](&5X<&QO9&4H)RDG+"`D8V]M;65N="D[
M"B`@("`@("`@("`@("`@("`D8V]M;65N="`@("`]("1T:&ES+3Y?<W!L:71#
M:&5C:R@D<&%R=',L("<I)RD["B`@("`@("`@("`@("`@("`D8V]M;65N='-;
M72`]("1C;VUM96YT.PH*("`@("`@("`@("`@("`@("\O("LQ(&ES(&9O<B!T
M:&4@=')A:6QI;F<@*0H@("`@("`@("`@("`@("`@)%]M86EL8F]X("`@/2!S
M=6)S='(H)%]M86EL8F]X+"!S=')P;W,H)%]M86EL8F]X+"`D8V]M;65N="DK
M<W1R;&5N*"1C;VUM96YT*2LQ*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!F;W)E86-H("@D8V]M;65N=',@87,@)&-O;6UE;G0I('L*("`@
M("`@("`@("`@)&UA:6QB;W@@/2!S=')?<F5P;&%C92@B*"1C;VUM96YT*2(L
M("<G+"`D;6%I;&)O>"D["B`@("`@("`@?0H*("`@("`@("`D;6%I;&)O>"`]
M('1R:6TH)&UA:6QB;W@I.PH*("`@("`@("`O+R!#:&5C:R!F;W(@;F%M92`K
M(')O=71E+6%D9'(*("`@("`@("!I9B`H<W5B<W1R*"1M86EL8F]X+"`M,2D@
M/3T@)SXG("8F('-U8G-T<B@D;6%I;&)O>"P@,"P@,2D@(3T@)SPG*2!["B`@
M("`@("`@("`@("1P87)T<R`@/2!E>'!L;V1E*"<\)RP@)&UA:6QB;W@I.PH@
M("`@("`@("`@("`D;F%M92`@(#T@)'1H:7,M/E]S<&QI=$-H96-K*"1P87)T
M<RP@)SPG*3L*"B`@("`@("`@("`@("1P:')A<V4@("`@(#T@=')I;2@D;F%M
M92D["B`@("`@("`@("`@("1R;W5T95]A9&1R(#T@=')I;2AS=6)S='(H)&UA
M:6QB;W@L('-T<FQE;B@D;F%M92XG/"<I+"`M,2DI.PH*("`@("`@("`@("`@
M:68@*"1T:&ES+3Y?=F%L:61A=&50:')A<V4H)'!H<F%S92D@/3T](&9A;'-E
M('Q\("@D<F]U=&5?861D<B`]("1T:&ES+3Y?=F%L:61A=&52;W5T94%D9'(H
M)')O=71E7V%D9'(I*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("`@("`@?0H*("`@("`@("`O+R!/;FQY(&=O
M="!A9&1R+7-P96,*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!&
M:7)S="!S;FEP(&%N9VQE(&)R86-K971S(&EF('!R97-E;G0N"B`@("`@("`@
M("`@(&EF("AS=6)S='(H)&UA:6QB;W@L(#`L(#$I(#T]("<\)R`F)B!S=6)S
M='(H)&UA:6QB;W@L("TQ*2`]/2`G/B<I('L*("`@("`@("`@("`@("`@("1A
M9&1R7W-P96,@/2!S=6)S='(H)&UA:6QB;W@L(#$L("TQ*3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1A9&1R7W-P96,@/2`D;6%I
M;&)O>#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"@D861D<E]S
M<&5C(#T@)'1H:7,M/E]V86QI9&%T94%D9')3<&5C*"1A9&1R7W-P96,I*2`]
M/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@0V]N<W1R=6-T('1H
M92!O8FIE8W0@=&AA="!W:6QL(&)E(')E='5R;F5D+@H@("`@("`@("1M8F]X
M(#T@;F5W('-T9$-L87-S*"D["@H@("`@("`@("\O($%D9"!T:&4@<&AR87-E
M("AE=F5N(&EF(&5M<'1Y*2!A;F0@8V]M;65N=',*("`@("`@("`D;6)O>"T^
M<&5R<V]N86P@/2`D<&AR87-E.PH@("`@("`@("1M8F]X+3YC;VUM96YT("`]
M(&ES<V5T*"1C;VUM96YT<RD@/R`D8V]M;65N=',@.B!A<G)A>2@I.PH*("`@
M("`@("!I9B`H:7-S970H)')O=71E7V%D9'(I*2!["B`@("`@("`@("`@("1M
M8F]X+3YM86EL8F]X(#T@)')O=71E7V%D9');)VQO8V%L7W!A<G0G73L*("`@
M("`@("`@("`@)&UB;W@M/FAO<W0@("`@/2`D<F]U=&5?861D<ELG9&]M86EN
M)UT["B`@("`@("`@("`@("1R;W5T95]A9&1R6R=A9&PG72`A/3T@)R<@/R`D
M;6)O>"T^861L(#T@)')O=71E7V%D9');)V%D;"==(#H@)R<["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&UB;W@M/FUA:6QB;W@@/2`D861D<E]S
M<&5C6R=L;V-A;%]P87)T)UT["B`@("`@("`@("`@("1M8F]X+3YH;W-T("`@
M(#T@)&%D9')?<W!E8ULG9&]M86EN)UT["B`@("`@("`@?0H*("`@("`@("`D
M;6%I;&)O>"`]("1M8F]X.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@5&AI<R!F=6YC=&EO;B!V86QI9&%T97,@82!R;W5T
M92UA9&1R('=H:6-H(&ES.@H@("`@("H@<F]U=&4M861D<B`]("(\(B!;<F]U
M=&5=(&%D9'(M<W!E8R`B/B(*("`@("`J"B`@("`@*B!!;F=L92!B<F%C:V5T
M<R!H879E(&%L<F5A9'D@8F5E;B!R96UO=F5D(&%T('1H92!P;VEN="!O9@H@
M("`@("H@9V5T=&EN9R!T;R!T:&ES(&9U;F-T:6]N+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M('-T<FEN9R`D<F]U=&5?
M861D<B!4:&4@<W1R:6YG('1O(&-H96-K+@H@("`@("H@0')E='5R;B!M:7AE
M9"!&86QS92!O;B!F86EL=7)E+"!O<B!A;B!A<G)A>2!C;VYT86EN:6YG('9A
M;&ED871E9"!A9&1R97-S+W)O=71E(&EN9F]R;6%T:6]N(&]N('-U8V-E<W,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]V86QI9&%T95)O=71E061D<B@D<F]U
M=&5?861D<BD*("`@('L*("`@("`@("`O+R!#:&5C:R!F;W(@8V]L;VXN"B`@
M("`@("`@:68@*'-T<G!O<R@D<F]U=&5?861D<BP@)SHG*2`A/3T@9F%L<V4I
M('L*("`@("`@("`@("`@)'!A<G1S(#T@97AP;&]D92@G.B<L("1R;W5T95]A
M9&1R*3L*("`@("`@("`@("`@)')O=71E(#T@)'1H:7,M/E]S<&QI=$-H96-K
M*"1P87)T<RP@)SHG*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M<F]U=&4@/2`D<F]U=&5?861D<CL*("`@("`@("!]"@H@("`@("`@("\O($EF
M("1R;W5T92!I<R!S86UE(&%S("1R;W5T95]A9&1R('1H96X@=&AE(&-O;&]N
M('=A<R!I;@H@("`@("`@("\O('%U;W1E<R!O<B!B<F%C:V5T<R!O<BP@;V8@
M8V]U<G-E+"!N;VX@97AI<W1E;G0N"B`@("`@("`@:68@*"1R;W5T92`]/3T@
M)')O=71E7V%D9'(I>PH@("`@("`@("`@("!U;G-E="@D<F]U=&4I.PH@("`@
M("`@("`@("`D861D<E]S<&5C(#T@)')O=71E7V%D9'(["B`@("`@("`@("`@
M(&EF("@H)&%D9')?<W!E8R`]("1T:&ES+3Y?=F%L:61A=&5!9&1R4W!E8R@D
M861D<E]S<&5C*2D@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`O+R!686QI9&%T92!R;W5T92!P87)T+@H@("`@("`@("`@("!I
M9B`H*"1R;W5T92`]("1T:&ES+3Y?=F%L:61A=&52;W5T92@D<F]U=&4I*2`]
M/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)&%D9')?<W!E8R`]('-U8G-T<B@D
M<F]U=&5?861D<BP@<W1R;&5N*"1R;W5T92`N("<Z)RDI.PH*("`@("`@("`@
M("`@+R\@5F%L:61A=&4@861D<BUS<&5C('!A<G0N"B`@("`@("`@("`@(&EF
M("@H)&%D9')?<W!E8R`]("1T:&ES+3Y?=F%L:61A=&5!9&1R4W!E8R@D861D
M<E]S<&5C*2D@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("AI
M<W-E="@D<F]U=&4I*2!["B`@("`@("`@("`@("1R971U<FY;)V%D;"==(#T@
M)')O=71E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R971U<FY;
M)V%D;"==(#T@)R<["B`@("`@("`@?0H*("`@("`@("`D<F5T=7)N(#T@87)R
M87E?;65R9V4H)')E='5R;BP@)&%D9')?<W!E8RD["B`@("`@("`@<F5T=7)N
M("1R971U<FX["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC=&EO;B!T;R!V
M86QI9&%T92!A(')O=71E+"!W:&EC:"!I<SH*("`@("`J(')O=71E(#T@,2,H
M(D`B(&1O;6%I;BD@(CHB"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1R;W5T92!4:&4@<W1R:6YG('1O(&-H
M96-K+@H@("`@("H@0')E='5R;B!M:7AE9"!&86QS92!O;B!F86EL=7)E+"!O
M<B!T:&4@=F%L:61A=&5D("1R;W5T92!O;B!S=6-C97-S+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?=F%L:61A=&52;W5T92@D<F]U=&4I"B`@("!["B`@("`@
M("`@+R\@4W!L:70@;VX@8V]M;6$N"B`@("`@("`@)&1O;6%I;G,@/2!E>'!L
M;V1E*"<L)RP@=')I;2@D<F]U=&4I*3L*"B`@("`@("`@9F]R96%C:"`H)&1O
M;6%I;G,@87,@)&1O;6%I;BD@>PH@("`@("`@("`@("`D9&]M86EN(#T@<W1R
M7W)E<&QA8V4H)T`G+"`G)RP@=')I;2@D9&]M86EN*2D["B`@("`@("`@("`@
M(&EF("@A)'1H:7,M/E]V86QI9&%T941O;6%I;B@D9&]M86EN*2D@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R;W5T93L*("`@
M('T*"B`@("`O*BH*("`@("`J($9U;F-T:6]N('1O('9A;&ED871E(&$@9&]M
M86EN+"!T:&]U9V@@=&AI<R!I<R!N;W0@<75I=&4@=VAA=`H@("`@("H@>6]U
M(&5X<&5C="!O9B!A('-T<FEC="!I;G1E<FYE="!D;VUA:6XN"B`@("`@*@H@
M("`@("H@9&]M86EN(#T@<W5B+61O;6%I;B`J*"(N(B!S=6(M9&]M86EN*0H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9&]M86EN(%1H92!S=')I;F<@=&\@8VAE8VLN"B`@("`@*B!`<F5T
M=7)N(&UI>&5D($9A;'-E(&]N(&9A:6QU<F4L(&]R('1H92!V86QI9&%T960@
M9&]M86EN(&]N('-U8V-E<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]V86QI
M9&%T941O;6%I;B@D9&]M86EN*0H@("`@>PH@("`@("`@("\O($YO=&4@=&AE
M(&1I9F9E<F5N="!U<V4@;V8@)'-U8F1O;6%I;G,@86YD("1S=6)?9&]M86EN
M<PH@("`@("`@("1S=6)D;VUA:6YS(#T@97AP;&]D92@G+B<L("1D;VUA:6XI
M.PH*("`@("`@("!W:&EL92`H8V]U;G0H)'-U8F1O;6%I;G,I(#X@,"D@>PH@
M("`@("`@("`@("`D<W5B7V1O;6%I;G-;72`]("1T:&ES+3Y?<W!L:71#:&5C
M:R@D<W5B9&]M86EN<RP@)RXG*3L*("`@("`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@)'1H:7,M/FEN9&5X("L@,3L@)&DK*RD*("`@("`@("`@("`@("`@
M(&%R<F%Y7W-H:69T*"1S=6)D;VUA:6YS*3L*("`@("`@("!]"@H@("`@("`@
M(&9O<F5A8V@@*"1S=6)?9&]M86EN<R!A<R`D<W5B7V1O;6%I;BD@>PH@("`@
M("`@("`@("!I9B`H(21T:&ES+3Y?=F%L:61A=&53=6)D;VUA:6XH=')I;2@D
M<W5B7V1O;6%I;BDI*0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@+R\@36%N86=E9"!T;R!G970@:&5R92P@<V\@
M<F5T=7)N(&EN<'5T+@H@("`@("`@(')E='5R;B`D9&]M86EN.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1G5N8W1I;VX@=&\@=F%L:61A=&4@82!S=6)D;VUA
M:6XZ"B`@("`@*B`@('-U8F1O;6%I;B`](&1O;6%I;BUR968@+R!D;VUA:6XM
M;&ET97)A;`H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<W5B9&]M86EN(%1H92!S=')I;F<@=&\@8VAE8VLN
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@4W5C8V5S<R!O<B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?=F%L:61A=&53=6)D;VUA:6XH)'-U8F1O
M;6%I;BD*("`@('L*("`@("`@("!I9B`H<')E9U]M871C:"@G?%Y<6R@N*BE=
M)'PG+"`D<W5B9&]M86EN+"`D87)R*2E["B`@("`@("`@("`@(&EF("@A)'1H
M:7,M/E]V86QI9&%T941L:71E<F%L*"1A<G);,5TI*2!R971U<FX@9F%L<V4[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"$D=&AI<RT^7W9A
M;&ED871E071O;2@D<W5B9&]M86EN*2D@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*"B`@("`@("`@+R\@1V]T(&AE<F4L('-O(')E='5R;B!S=6-C97-S9G5L
M+@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1G5N8W1I;VX@=&\@=F%L:61A=&4@82!D;VUA:6X@;&ET97)A;#H*("`@("`J
M("`@9&]M86EN+6QI=&5R86P@/2`@(ELB("HH9'1E>'0@+R!Q=6]T960M<&%I
M<BD@(ETB"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1D;&ET97)A;"!4:&4@<W1R:6YG('1O(&-H96-K+@H@
M("`@("H@0')E='5R;B!B;V]L96%N(%-U8V-E<W,@;W(@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7W9A;&ED871E1&QI=&5R86PH)&1L:71E<F%L
M*0H@("`@>PH@("`@("`@(')E='5R;B`A<')E9U]M871C:"@G+R@N*5M=6UQX
M,$1<7%Q<72\G+"`D9&QI=&5R86PL("1M871C:&5S*2`F)B`D;6%T8VAE<ULQ
M72`A/2`G7%PG.PH@("`@?0H*("`@("\J*@H@("`@("H@1G5N8W1I;VX@=&\@
M=F%L:61A=&4@86X@861D<BUS<&5C+@H@("`@("H*("`@("`J(&%D9'(M<W!E
M8R`](&QO8V%L+7!A<G0@(D`B(&1O;6%I;@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H@0'!A<F%M('-T<FEN9R`D861D<E]S<&5C(%1H
M92!S=')I;F<@=&\@8VAE8VLN"B`@("`@*B!`<F5T=7)N(&UI>&5D($9A;'-E
M(&]N(&9A:6QU<F4L(&]R('1H92!V86QI9&%T960@861D<BUS<&5C(&]N('-U
M8V-E<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]V86QI9&%T94%D9')3<&5C
M*"1A9&1R7W-P96,I"B`@("!["B`@("`@("`@)&%D9')?<W!E8R`]('1R:6TH
M)&%D9')?<W!E8RD["@H@("`@("`@("\O(%-P;&ET(&]N($`@<VEG;B!I9B!T
M:&5R92!I<R!O;F4N"B`@("`@("`@:68@*'-T<G!O<R@D861D<E]S<&5C+"`G
M0"<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`D<&%R=',@("`@("`](&5X
M<&QO9&4H)T`G+"`D861D<E]S<&5C*3L*("`@("`@("`@("`@)&QO8V%L7W!A
M<G0@/2`D=&AI<RT^7W-P;&ET0VAE8VLH)'!A<G1S+"`G0"<I.PH@("`@("`@
M("`@("`D9&]M86EN("`@("`]('-U8G-T<B@D861D<E]S<&5C+"!S=')L96XH
M)&QO8V%L7W!A<G0@+B`G0"<I*3L*"B`@("`@("`@+R\@3F\@0"!S:6=N('-O
M(&%S<W5M92!T:&4@9&5F875L="!D;VUA:6XN"B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&QO8V%L7W!A<G0@/2`D861D<E]S<&5C.PH@("`@("`@
M("`@("`D9&]M86EN("`@("`]("1T:&ES+3YD969A=6QT7V1O;6%I;CL*("`@
M("`@("!]"@H@("`@("`@(&EF("@H)&QO8V%L7W!A<G0@/2`D=&AI<RT^7W9A
M;&ED871E3&]C86Q087)T*"1L;V-A;%]P87)T*2D@/3T](&9A;'-E*2!R971U
M<FX@9F%L<V4["B`@("`@("`@:68@*"@D9&]M86EN("`@("`]("1T:&ES+3Y?
M=F%L:61A=&5$;VUA:6XH)&1O;6%I;BDI(#T]/2!F86QS92D@<F5T=7)N(&9A
M;'-E.PH*("`@("`@("`O+R!';W0@:&5R92!S;R!R971U<FX@<W5C8V5S<V9U
M;"X*("`@("`@("!R971U<FX@87)R87DH)VQO8V%L7W!A<G0G(#T^("1L;V-A
M;%]P87)T+"`G9&]M86EN)R`]/B`D9&]M86EN*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($9U;F-T:6]N('1O('9A;&ED871E('1H92!L;V-A;"!P87)T(&]F
M(&%N(&%D9')E<W,Z"B`@("`@*B`@(&QO8V%L+7!A<G0@/2!W;W)D("HH(BXB
M('=O<F0I"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1L;V-A;%]P87)T"B`@("`@*B!`<F5T=7)N(&UI>&5D
M($9A;'-E(&]N(&9A:6QU<F4L(&]R('1H92!V86QI9&%T960@;&]C86P@<&%R
M="!O;B!S=6-C97-S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=F%L:61A=&5,
M;V-A;%!A<G0H)&QO8V%L7W!A<G0I"B`@("!["B`@("`@("`@)'!A<G1S(#T@
M97AP;&]D92@G+B<L("1L;V-A;%]P87)T*3L*("`@("`@("`D=V]R9',@/2!A
M<G)A>2@I.PH*("`@("`@("`O+R!3<&QI="!T:&4@;&]C86Q?<&%R="!I;G1O
M('=O<F1S+@H@("`@("`@('=H:6QE("AC;W5N="@D<&%R=',I(#X@,"E["B`@
M("`@("`@("`@("1W;W)D<UM=(#T@)'1H:7,M/E]S<&QI=$-H96-K*"1P87)T
M<RP@)RXG*3L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)'1H:7,M
M/FEN9&5X("L@,3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@87)R87E?<VAI
M9G0H)'!A<G1S*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M+R\@5F%L:61A=&4@96%C:"!W;W)D+@H@("`@("`@(&9O<F5A8V@@*"1W;W)D
M<R!A<R`D=V]R9"D@>PH@("`@("`@("`@("`O+R!)9B!T:&ES('=O<F0@8V]N
M=&%I;G,@86X@=6YQ=6]T960@<W!A8V4L(&ET(&ES(&EN=F%L:60N("@V+C(N
M-"D*("`@("`@("`@("`@:68@*'-T<G!O<R@D=V]R9"P@)R`G*2`F)B`D=V]R
M9%LP72`A/3T@)R(G*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D
M=&AI<RT^7W9A;&ED871E4&AR87-E*'1R:6TH)'=O<F0I*2`]/3T@9F%L<V4I
M(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\O($UA;F%G960@
M=&\@9V5T(&AE<F4L('-O(')E='5R;B!T:&4@:6YP=70N"B`@("`@("`@<F5T
M=7)N("1L;V-A;%]P87)T.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!A;B!A<'!R;WAI;6%T92!C;W5N="!O9B!H;W<@;6%N>2!A9&1R97-S97,@
M87)E(&EN('1H90H@("`@("H@9VEV96X@<W1R:6YG+B!4:&ES(&ES($%04%)/
M6$E-051%(&%S(&ET(&]N;'D@<W!L:71S(&)A<V5D(&]N(&$*("`@("`J(&-O
M;6UA('=H:6-H(&AA<R!N;R!P<F5C961I;F<@8F%C:W-L87-H+B!#;W5L9"!B
M92!U<V5F=6P@87,*("`@("`J(&QA<F=E(&%M;W5N=',@;V8@861D<F5S<V5S
M('=I;&P@96YD('5P('!R;V1U8VEN9R`J;&%R9V4J"B`@("`@*B!S=')U8W1U
M<F5S('=H96X@=7-E9"!W:71H('!A<G-E061D<F5S<TQI<W0H*2X*("`@("`J
M"B`@("`@*B!`<&%R86T@('-T<FEN9R`D9&%T82!!9&1R97-S97,@=&\@8V]U
M;G0*("`@("`J($!R971U<FX@:6YT("`@("`@("`@($%P<')O>&EM871E(&-O
M=6YT"B`@("`@*B\*("`@(&9U;F-T:6]N(&%P<')O>&EM871E0V]U;G0H)&1A
M=&$I"B`@("!["B`@("`@("`@<F5T=7)N(&-O=6YT*'!R96=?<W!L:70H)R\H
M/SPA7%Q<7"DL+R<L("1D871A*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4
M:&ES(&ES(&$@96UA:6P@=F%L:61A=&EN9R!F=6YC=&EO;B!S97!A<F%T92!T
M;R!T:&4@<F5S="!O9B!T:&4*("`@("`J(&-L87-S+B!)="!S:6UP;'D@=F%L
M:61A=&5S('=H971H97(@86X@96UA:6P@:7,@;V8@=&AE(&-O;6UO;@H@("`@
M("H@:6YT97)N970@9F]R;3H@/'5S97(^0#QD;VUA:6X^+B!4:&ES(&-A;B!B
M92!S=69F:6-I96YT(&9O<B!M;W-T"B`@("`@*B!P96]P;&4N($]P=&EO;F%L
M('-T<FEC=&5R(&UO9&4@8V%N(&)E('5T:6QI<V5D('=H:6-H(')E<W1R:6-T
M<PH@("`@("H@;6%I;&)O>"!C:&%R86-T97)S(&%L;&]W960@=&\@86QP:&%N
M=6UE<FEC+"!F=6QL('-T;W`L(&AY<&AE;@H@("`@("H@86YD('5N9&5R<V-O
M<F4N"B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<@("1D871A("`@061D
M<F5S<R!T;R!C:&5C:PH@("`@("H@0'!A<F%M("!B;V]L96%N("1S=')I8W0@
M3W!T:6]N86P@<W1R:6-T97(@;6]D90H@("`@("H@0')E='5R;B!M:7AE9"`@
M("`@("`@("`@1F%L<V4@:68@:70@9F%I;',L(&%N(&EN9&5X960@87)R87D*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('5S97)N86UE+V1O;6%I
M;B!I9B!I="!M871C:&5S"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES5F%L:61)
M;F5T061D<F5S<R@D9&%T82P@)'-T<FEC="`](&9A;'-E*0H@("`@>PH@("`@
M("`@("1R96=E>"`]("1S=')I8W0@/R`G+UXH6RXP+3EA+7I?*RU=*RE`*"A;
M,"TY82UZ+5TK7"XI*ULP+3EA+7I=>S(L-'TI)"]I)R`Z("<O7BA;*BLA+B8C
M)'Q<)UQ<)5PO,"TY82UZ7E]@>WT]/WXZ+5TK*4`H*%LP+3EA+7HM72M<+BDK
M6S`M.6$M>EU[,BPT?2DD+VDG.PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"1R
M96=E>"P@=')I;2@D9&%T82DL("1M871C:&5S*2D@>PH@("`@("`@("`@("!R
M971U<FX@87)R87DH)&UA=&-H97-;,5TL("1M871C:&5S6S)=*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+TUA:6PO<V5N9&UA:6PN<&AP````````````````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$S,S8V`#$P-3$U-#,S-S0S`#`R
M,C`P-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H
M92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0
M(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H
M:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@
M('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T
M;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I
M871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!!=71H;W(Z($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/B`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*+RHJ"B`J(%-E;F1M86EL(&EM
M<&QE;65N=&%T:6]N(&]F('1H92!014%2($UA:6PZ.B!I;G1E<F9A8V4N"B`J
M($!A8V-E<W,@<'5B;&EC"B`J($!P86-K86=E($UA:6P*("H@0'9E<G-I;VX@
M)%)E=FES:6]N.B`Q+C$S("0*("HO"F-L87-S($UA:6Q?<V5N9&UA:6P@97AT
M96YD<R!-86EL('L*"@DO*BH*("`@("`J(%1H92!L;V-A=&EO;B!O9B!T:&4@
M<V5N9&UA:6P@;W(@<V5N9&UA:6P@=W)A<'!E<B!B:6YA<GD@;VX@=&AE"B`@
M("`@*B!F:6QE<WES=&5M+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1S96YD;6%I;%]P871H(#T@)R]U<W(O<V)I;B]S96YD;6%I;"<[
M"@H)+RHJ"B`@("`@*B!!;GD@97AT<F$@8V]M;6%N9"UL:6YE('!A<F%M971E
M<G,@=&\@<&%S<R!T;R!T:&4@<V5N9&UA:6P@;W(*("`@("`J('-E;F1M86EL
M('=R87!P97(@8FEN87)Y+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1S96YD;6%I;%]A<F=S(#T@)R<["@H)+RHJ"B`@("`@*B!#;VYS
M=')U8W1O<BX*("`@("`J"B`@("`@*B!);G-T86YT:6%T97,@82!N97<@36%I
M;%]S96YD;6%I;#HZ(&]B:F5C="!B87-E9"!O;B!T:&4@<&%R86UE=&5R<PH@
M("`@("H@<&%S<V5D(&EN+B!)="!L;V]K<R!F;W(@=&AE(&9O;&QO=VEN9R!P
M87)A;65T97)S.@H@("`@("H@("`@('-E;F1M86EL7W!A=&@@("`@5&AE(&QO
M8V%T:6]N(&]F('1H92!S96YD;6%I;"!B:6YA<GD@;VX@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("!F:6QE<WES=&5M+B!$969A=6QT<R!T;R`G
M+W5S<B]S8FEN+W-E;F1M86EL)RX*("`@("`J"B`@("`@*B`@("`@<V5N9&UA
M:6Q?87)G<R`@("!!;GD@97AT<F$@<&%R86UE=&5R<R!T;R!P87-S('1O('1H
M92!S96YD;6%I;`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@;W(@<V5N
M9&UA:6P@=W)A<'!E<B!B:6YA<GDN"B`@("`@*@H@("`@("H@268@82!P87)A
M;65T97(@:7,@<')E<V5N="!I;B!T:&4@)'!A<F%M<R!A<G)A>2P@:70@<F5P
M;&%C97,@=&AE"B`@("`@*B!D969A=6QT+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US($AA<V@@8V]N=&%I;FEN9R!A;GD@<&%R86UE=&5R
M<R!D:69F97)E;G0@9G)O;2!T:&4*("`@("`J("`@("`@("`@("`@("!D969A
M=6QT<RX*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N($UA:6Q?<V5N9&UA:6PH)'!A<F%M<RD*("`@('L*("`@("`@("!I9B`H
M:7-S970H)'!A<F%M<ULG<V5N9&UA:6Q?<&%T:"==*2D@)'1H:7,M/G-E;F1M
M86EL7W!A=&@@/2`D<&%R86US6R=S96YD;6%I;%]P871H)UT["B`@("`@("`@
M:68@*&ES<V5T*"1P87)A;7-;)W-E;F1M86EL7V%R9W,G72DI("1T:&ES+3YS
M96YD;6%I;%]A<F=S(#T@)'!A<F%M<ULG<V5N9&UA:6Q?87)G<R==.PH*("`@
M("`@("`O*@H@("`@("`@("`J($)E8V%U<V4@=V4@;F5E9"!T;R!P87-S(&UE
M<W-A9V4@:&5A9&5R<R!T;R!T:&4@<V5N9&UA:6P@<')O9W)A;2!O;@H@("`@
M("`@("`J('1H92!C;VUM86YD;&EN92P@=V4@8V%N)W0@9W5A<F%N=&5E('1H
M92!U<V4@;V8@=&AE('-T86YD87)D(")<<EQN(@H@("`@("`@("`J('-E<&%R
M871O<BX@($EN<W1E860L('=E('5S92!T:&4@<WES=&5M)W,@;F%T:79E(&QI
M;F4@<V5P87)A=&]R+@H@("`@("`@("`J+PH@("`@("`@(&EF("AD969I;F5D
M*%!(4%]%3TPI*2!["B`@("`@("`@("`@("1T:&ES+3YS97`@/2!02%!?14],
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YS97`@/2`H
M<W1R<&]S*%!(4%]/4RP@)U=)3B<I(#T]/2!F86QS92D@/R`B7&XB(#H@(EQR
M7&XB.PH@("`@("`@('T*("`@('T*"@DO*BH*("`@("`J($EM<&QE;65N=',@
M36%I;#HZ<V5N9"@I(&9U;F-T:6]N('5S:6YG('1H92!S96YD;6%I;`H@("`@
M("H@8V]M;6%N9"UL:6YE(&)I;F%R>2X*("`@("`J"B`@("`@*B!`<&%R86T@
M;6EX960@)')E8VEP:65N=',@16ET:&5R(&$@8V]M;6$M<V5P97)A=&5D(&QI
M<W0@;V8@<F5C:7!I96YT<PH@("`@("H@("`@("`@("`@("`@("A21D,X,C(@
M8V]M<&QI86YT*2P@;W(@86X@87)R87D@;V8@<F5C:7!I96YT<RP*("`@("`J
M("`@("`@("`@("`@("!E86-H(%)&0S@R,B!V86QI9"X@5&AI<R!M87D@8V]N
M=&%I;B!R96-I<&EE;G1S(&YO=`H@("`@("H@("`@("`@("`@("`@('-P96-I
M9FEE9"!I;B!T:&4@:&5A9&5R<RP@9F]R($)C8SHL(')E<V5N9&EN9PH@("`@
M("H@("`@("`@("`@("`@(&UE<W-A9V5S+"!E=&,N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1H96%D97)S(%1H92!A<G)A>2!O9B!H96%D97)S('1O
M('-E;F0@=VET:"!T:&4@;6%I;"P@:6X@86X*("`@("`J("`@("`@("`@("`@
M("!A<W-O8VEA=&EV92!A<G)A>2P@=VAE<F4@=&AE(&%R<F%Y(&ME>2!I<R!T
M:&4*("`@("`J("`@("`@("`@("`@("!H96%D97(@;F%M92`H:64L("=3=6)J
M96-T)RDL(&%N9"!T:&4@87)R87D@=F%L=64*("`@("`J("`@("`@("`@("`@
M("!I<R!T:&4@:&5A9&5R('9A;'5E("AI92P@)W1E<W0G*2X@5&AE(&AE861E
M<@H@("`@("H@("`@("`@("`@("`@('!R;V1U8V5D(&9R;VT@=&AO<V4@=F%L
M=65S('=O=6QD(&)E("=3=6)J96-T.@H@("`@("H@("`@("`@("`@("`@('1E
M<W0G+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&)O9'D@5&AE(&9U
M;&P@=&5X="!O9B!T:&4@;65S<V%G92!B;V1Y+"!I;F-L=61I;F<@86YY"B`@
M("`@*B`@("`@("`@("`@("`@($UI;64@<&%R=',L(&5T8RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@=')U92!O;B!S=6-C97-S+"!O
M<B!A(%!%05)?17)R;W(*("`@("`J("`@("`@("`@("`@("`@8V]N=&%I;FEN
M9R!A(&1E<V-R:7!T:79E(&5R<F]R(&UE<W-A9V4@;VX*("`@("`J("`@("`@
M("`@("`@("`@9F%I;'5R92X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E;F0H)')E8VEP:65N=',L("1H96%D97)S+"`D
M8F]D>2D*("`@('L*("`@("`@("`D<F5C:7!I96YT<R`]("1T:&ES+3YP87)S
M95)E8VEP:65N=',H)')E8VEP:65N=',I.PH@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1R96-I<&EE;G1S*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M8VEP:65N=',["B`@("`@("`@?0H@("`@("`@("1R96-I<&EE;G1S(#T@97-C
M87!E4VAE;&Q#;60H:6UP;&]D92@G("<L("1R96-I<&EE;G1S*2D["@H@("`@
M("`@("1H96%D97)%;&5M96YT<R`]("1T:&ES+3YP<F5P87)E2&5A9&5R<R@D
M:&5A9&5R<RD["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&AE861E<D5L
M96UE;G1S*2D@>PH@("`@("`@("`@("!R971U<FX@)&AE861E<D5L96UE;G1S
M.PH@("`@("`@('T*("`@("`@("!L:7-T*"1F<F]M+"`D=&5X=%]H96%D97)S
M*2`]("1H96%D97)%;&5M96YT<SL*"B`@("`@("`@:68@*"%I<W-E="@D9G)O
M;2DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TYO
M(&9R;VT@861D<F5S<R!G:79E;BXG*3L*("`@("`@("!](&5L<V5I9B`H<W1R
M<&]S*"1F<F]M+"`G("<I("$]/2!F86QS92!\?`H@("`@("`@("`@("`@("`@
M("!S=')P;W,H)&9R;VTL("<[)RD@(3T](&9A;'-E('Q\"B`@("`@("`@("`@
M("`@("`@('-T<G!O<R@D9G)O;2P@)R8G*2`A/3T@9F%L<V4@?'P*("`@("`@
M("`@("`@("`@("`@<W1R<&]S*"1F<F]M+"`G8"<I("$]/2!F86QS92D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1G)O;2!A9&1R
M97-S('-P96-I9FEE9"!W:71H(&1A;F=E<F]U<R!C:&%R86-T97)S+B<I.PH@
M("`@("`@('T*"B`@("`@("`@)&9R;VT@/2!E<V-A<&53:&5L;$-M9"@D9G)O
M;2D["B`@("`@("`@)&UA:6P@/2!`<&]P96XH)'1H:7,M/G-E;F1M86EL7W!A
M=&@@+B`H(65M<'1Y*"1T:&ES+3YS96YD;6%I;%]A<F=S*2`_("<@)R`N("1T
M:&ES+3YS96YD;6%I;%]A<F=S(#H@)R<I("X@(B`M9B1F<F]M("TM("1R96-I
M<&EE;G1S(BP@)W<G*3L*("`@("`@("!I9B`H(21M86EL*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=&86EL960@=&\@;W!E;B!S
M96YD;6%I;"!;)R`N("1T:&ES+3YS96YD;6%I;%]P871H("X@)UT@9F]R(&5X
M96-U=&EO;BXG*3L*("`@("`@("!]"@H@("`@("`@(&9P=71S*"1M86EL+"`D
M=&5X=%]H96%D97)S*3L*("`@("`@("!F<'5T<R@D;6%I;"P@)'1H:7,M/G-E
M<"D[("`O+R!N97=L:6YE('1O(&5N9"!T:&4@:&5A9&5R<R!S96-T:6]N"B`@
M("`@("`@9G!U=',H)&UA:6PL("1B;V1Y*3L*("`@("`@("`D<F5S=6QT(#T@
M<&-L;W-E*"1M86EL*3L*("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*'!H
M<'9E<G-I;VXH*2P@)S0N,BXS)RD@/3T@+3$I('L*("`@("`@("`@("`@+R\@
M5VET:"!O;&1E<B!P:'`@=F5R<VEO;G,L('=E(&YE960@=&\@<VAI9G0@=&AE
M('!C;&]S90H@("`@("`@("`@("`O+R!R97-U;'0@=&\@9V5T('1H92!E>&ET
M(&-O9&4N"B`@("`@("`@("`@("1R97-U;'0@/2`D<F5S=6QT(#X^(#@@)B`P
M>$9&.PH@("`@("`@('T*"B`@("`@("`@:68@*"1R97-U;'0@(3T@,"D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G<V5N9&UA:6P@
M<F5T=7)N960@97)R;W(@8V]D92`G("X@)')E<W5L="P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)')E<W5L="D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O36%I;"]S;71P+G!H<```````````````````````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S`P-#8`,3`U,34T,S,W-#,`,#(Q,38U
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(
M4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(
M4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F
M:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC
M96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P
M86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO
M+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A
M="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A
M(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@
M?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@
M<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E
M0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PHO+R!\($%U=&AO<G,Z($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@
M("`@("!*;VX@4&%R:7-E(#QJ;VY`<&AP+FYE=#X@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PH*+RHJ($5R<F]R.B!&86EL960@=&\@8W)E871E(&$@3F5T7U--
M5%`@;V)J96-T("HO"F1E9FEN92@G4$5!4E]-04E,7U--5%!?15)23U)?0U)%
M051%)RP@,3`P,#`I.PH*+RHJ($5R<F]R.B!&86EL960@=&\@8V]N;F5C="!T
M;R!33510('-E<G9E<B`J+PID969I;F4H)U!%05)?34%)3%]335107T524D]2
M7T-/3DY%0U0G+"`Q,#`P,2D["@HO*BH@17)R;W(Z(%--5%`@875T:&5N=&EC
M871I;VX@9F%I;'5R92`J+PID969I;F4H)U!%05)?34%)3%]335107T524D]2
M7T%55$@G+"`Q,#`P,BD["@HO*BH@17)R;W(Z($YO($9R;VTZ(&%D9')E<W,@
M:&%S(&)E96X@<')O=FED960@*B\*9&5F:6YE*"=014%27TU!24Q?4TU44%]%
M4E)/4E]&4D]-)RP@,3`P,#,I.PH*+RHJ($5R<F]R.B!&86EL960@=&\@<V5T
M('-E;F1E<B`J+PID969I;F4H)U!%05)?34%)3%]335107T524D]27U-%3D1%
M4B<L(#$P,#`T*3L*"B\J*B!%<G)O<CH@1F%I;&5D('1O(&%D9"!R96-I<&EE
M;G0@*B\*9&5F:6YE*"=014%27TU!24Q?4TU44%]%4E)/4E]214-)4$E%3E0G
M+"`Q,#`P-2D["@HO*BH@17)R;W(Z($9A:6QE9"!T;R!S96YD(&1A=&$@*B\*
M9&5F:6YE*"=014%27TU!24Q?4TU44%]%4E)/4E]$051!)RP@,3`P,#8I.PH*
M+RHJ"B`J(%--5%`@:6UP;&5M96YT871I;VX@;V8@=&AE(%!%05(@36%I;"!I
M;G1E<F9A8V4N(%)E<75I<F5S('1H92!.971?4TU44"!C;&%S<RX*("H@0&%C
M8V5S<R!P=6)L:6,*("H@0'!A8VMA9V4@36%I;`H@*B!`=F5R<VEO;B`D4F5V
M:7-I;VXZ(#$N,C8@)`H@*B\*8VQA<W,@36%I;%]S;71P(&5X=&5N9',@36%I
M;"!["@H@("`@+RHJ"B`@("`@*B!33510(&-O;FYE8W1I;VX@;V)J96-T+@H@
M("`@("H*("`@("`J($!V87(@;V)J96-T"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@=F%R("1?<VUT<"`](&YU;&P["@H@("`@+RHJ"B`@
M("`@*B!4:&4@4TU44"!H;W-T('1O(&-O;FYE8W0@=&\N"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)&AO<W0@/2`G;&]C86QH;W-T)SL*
M"B`@("`O*BH*("`@("`J(%1H92!P;W)T('1H92!33510('-E<G9E<B!I<R!O
M;BX*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)'!O<G0@
M/2`R-3L*"B`@("`O*BH*("`@("`J(%-H;W5L9"!33510(&%U=&AE;G1I8V%T
M:6]N(&)E('5S960_"B`@("`@*@H@("`@("H@5&AI<R!V86QU92!M87D@8F4@
M<V5T('1O('1R=64L(&9A;'-E(&]R('1H92!N86UE(&]F(&$@<W!E8VEF:6,*
M("`@("`J(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"X*("`@("`J"B`@("`@*B!)
M9B!T:&4@=F%L=64@:7,@<V5T('1O('1R=64L('1H92!.971?4TU44"!P86-K
M86=E('=I;&P@871T96UP="!T;R!U<V4*("`@("`J('1H92!B97-T(&%U=&AE
M;G1I8V%T:6]N(&UE=&AO9"!A9'9E<G1I<V5D(&)Y('1H92!R96UO=&4@4TU4
M4"!S97)V97(N"B`@("`@*@H@("`@("H@0'9A<B!M:7AE9`H@("`@("HO"B`@
M("!V87(@)&%U=&@@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%1H92!U<V5R
M;F%M92!T;R!U<V4@:68@=&AE(%--5%`@<V5R=F5R(')E<75I<F5S(&%U=&AE
M;G1I8V%T:6]N+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1U<V5R;F%M92`]("<G.PH*("`@("\J*@H@("`@("H@5&AE('!A<W-W;W)D
M('1O('5S92!I9B!T:&4@4TU44"!S97)V97(@<F5Q=6ER97,@875T:&5N=&EC
M871I;VXN"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)'!A
M<W-W;W)D(#T@)R<["@H@("`@+RHJ"B`@("`@*B!(;W-T;F%M92!O<B!D;VUA
M:6X@=&AA="!W:6QL(&)E('-E;G0@=&\@=&AE(')E;6]T92!33510('-E<G9E
M<B!I;B!T:&4*("`@("`J($A%3$\@+R!%2$Q/(&UE<W-A9V4N"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1L;V-A;&AO<W0@
M/2`G;&]C86QH;W-T)SL*"B`@("`O*BH*("`@("`J(%--5%`@8V]N;F5C=&EO
M;B!T:6UE;W5T('9A;'5E+B`@3E5,3"!I;F1I8V%T97,@;F\@=&EM96]U="X*
M("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1T
M:6UE;W5T(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%=H971H97(@=&\@=7-E
M(%9%4E`@;W(@;F]T+B!)9B!N;W0@82!B;V]L96%N+"!T:&4@<W1R:6YG('9A
M;'5E"B`@("`@*B!W:6QL(&)E('5S960@87,@=&AE(%9%4E`@<V5P87)A=&]R
M<RX*("`@("`J"B`@("`@*B!`=F%R(&UI>&5D(&)O;VQE86X@;W(@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D=F5R<"`](&9A;'-E.PH*("`@("\J*@H@("`@
M("H@5'5R;B!O;B!.971?4TU44"!D96)U9V=I;F<_"B`@("`@*@H@("`@("H@
M0'9A<B!B;V]L96%N("1D96)U9PH@("`@("HO"B`@("!V87(@)&1E8G5G(#T@
M9F%L<V4["@H@("`@+RHJ"B`@("`@*B!);F1I8V%T97,@=VAE=&AE<B!O<B!N
M;W0@=&AE(%--5%`@8V]N;F5C=&EO;B!S:&]U;&0@<&5R<VES="!O=F5R"B`@
M("`@*B!M=6QT:7!L92!C86QL<R!T;R!T:&4@<V5N9"@I(&UE=&AO9"X*("`@
M("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1P97)S
M:7-T(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@
M("`J"B`@("`@*B!);G-T86YT:6%T97,@82!N97<@36%I;%]S;71P.CH@;V)J
M96-T(&)A<V5D(&]N('1H92!P87)A;65T97)S"B`@("`@*B!P87-S960@:6XN
M($ET(&QO;VMS(&9O<B!T:&4@9F]L;&]W:6YG('!A<F%M971E<G,Z"B`@("`@
M*B`@("`@:&]S="`@("`@("`@5&AE('-E<G9E<B!T;R!C;VYN96-T('1O+B!$
M969A=6QT<R!T;R!L;V-A;&AO<W0N"B`@("`@*B`@("`@<&]R="`@("`@("`@
M5&AE('!O<G0@=&\@8V]N;F5C="!T;RX@1&5F875L=',@=&\@,C4N"B`@("`@
M*B`@("`@875T:"`@("`@("`@4TU44"!A=71H96YT:6-A=&EO;BX@($1E9F%U
M;'1S('1O(&YO;F4N"B`@("`@*B`@("`@=7-E<FYA;64@("`@5&AE('5S97)N
M86UE('1O('5S92!F;W(@4TU44"!A=71H+B!.;R!D969A=6QT+@H@("`@("H@
M("`@('!A<W-W;W)D("`@(%1H92!P87-S=V]R9"!T;R!U<V4@9F]R(%--5%`@
M875T:"X@3F\@9&5F875L="X*("`@("`J("`@("!L;V-A;&AO<W0@("!4:&4@
M;&]C86P@:&]S=&YA;64@+R!D;VUA:6XN($1E9F%U;'1S('1O(&QO8V%L:&]S
M="X*("`@("`J("`@("!T:6UE;W5T("`@("!4:&4@4TU44"!C;VYN96-T:6]N
M('1I;65O=70N($1E9F%U;'1S('1O(&YO;F4N"B`@("`@*B`@("`@=F5R<"`@
M("`@("`@5VAE=&AE<B!T;R!U<V4@5D524"!O<B!N;W0N($1E9F%U;'1S('1O
M(&9A;'-E+@H@("`@("H@("`@(&1E8G5G("`@("`@($%C=&EV871E(%--5%`@
M9&5B=6<@;6]D93\@1&5F875L=',@=&\@9F%L<V4N"B`@("`@*B`@("`@<&5R
M<VES="`@("`@4VAO=6QD('1H92!33510(&-O;FYE8W1I;VX@<&5R<VES=#\*
M("`@("`J"B`@("`@*B!)9B!A('!A<F%M971E<B!I<R!P<F5S96YT(&EN('1H
M92`D<&%R86US(&%R<F%Y+"!I="!R97!L86-E<R!T:&4*("`@("`J(&1E9F%U
M;'0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y($AA<V@@8V]N=&%I;FEN
M9R!A;GD@<&%R86UE=&5R<R!D:69F97)E;G0@9G)O;2!T:&4*("`@("`J("`@
M("`@("`@("`@("!D969A=6QT<RX*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N($UA:6Q?<VUT<"@D<&%R86US*0H@("`@>PH@
M("`@("`@(&EF("AI<W-E="@D<&%R86US6R=H;W-T)UTI*2`D=&AI<RT^:&]S
M="`]("1P87)A;7-;)VAO<W0G73L*("`@("`@("!I9B`H:7-S970H)'!A<F%M
M<ULG<&]R="==*2D@)'1H:7,M/G!O<G0@/2`D<&%R86US6R=P;W)T)UT["B`@
M("`@("`@:68@*&ES<V5T*"1P87)A;7-;)V%U=&@G72DI("1T:&ES+3YA=71H
M(#T@)'!A<F%M<ULG875T:"==.PH@("`@("`@(&EF("AI<W-E="@D<&%R86US
M6R=U<V5R;F%M92==*2D@)'1H:7,M/G5S97)N86UE(#T@)'!A<F%M<ULG=7-E
M<FYA;64G73L*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG<&%S<W=O<F0G
M72DI("1T:&ES+3YP87-S=V]R9"`]("1P87)A;7-;)W!A<W-W;W)D)UT["B`@
M("`@("`@:68@*&ES<V5T*"1P87)A;7-;)VQO8V%L:&]S="==*2D@)'1H:7,M
M/FQO8V%L:&]S="`]("1P87)A;7-;)VQO8V%L:&]S="==.PH@("`@("`@(&EF
M("AI<W-E="@D<&%R86US6R=T:6UE;W5T)UTI*2`D=&AI<RT^=&EM96]U="`]
M("1P87)A;7-;)W1I;65O=70G73L*("`@("`@("!I9B`H:7-S970H)'!A<F%M
M<ULG=F5R<"==*2D@)'1H:7,M/G9E<G`@/2`D<&%R86US6R=V97)P)UT["B`@
M("`@("`@:68@*&ES<V5T*"1P87)A;7-;)V1E8G5G)UTI*2`D=&AI<RT^9&5B
M=6<@/2`H8F]O;&5A;BDD<&%R86US6R=D96)U9R==.PH@("`@("`@(&EF("AI
M<W-E="@D<&%R86US6R=P97)S:7-T)UTI*2`D=&AI<RT^<&5R<VES="`]("AB
M;V]L96%N*21P87)A;7-;)W!E<G-I<W0G73L*"B`@("`@("`@<F5G:7-T97)?
M<VAU=&1O=VY?9G5N8W1I;VXH87)R87DH)B1T:&ES+"`G7TUA:6Q?<VUT<"<I
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E<W1R=6-T;W(@:6UP;&5M96YT
M871I;VX@=&\@96YS=7)E('1H870@=V4@9&ES8V]N;F5C="!F<F]M(&%N>0H@
M("`@("H@<&]T96YT:6%L;'DM86QI=F4@<&5R<VES=&5N="!33510(&-O;FYE
M8W1I;VYS+@H@("`@("HO"B`@("!F=6YC=&EO;B!?36%I;%]S;71P*"D*("`@
M('L*("`@("`@("`D=&AI<RT^9&ES8V]N;F5C="@I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@26UP;&5M96YT<R!-86EL.CIS96YD*"D@9G5N8W1I;VX@=7-I
M;F<@4TU44"X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)')E8VEP:65N
M=',@16ET:&5R(&$@8V]M;6$M<V5P97)A=&5D(&QI<W0@;V8@<F5C:7!I96YT
M<PH@("`@("H@("`@("`@("`@("`@("A21D,X,C(@8V]M<&QI86YT*2P@;W(@
M86X@87)R87D@;V8@<F5C:7!I96YT<RP*("`@("`J("`@("`@("`@("`@("!E
M86-H(%)&0S@R,B!V86QI9"X@5&AI<R!M87D@8V]N=&%I;B!R96-I<&EE;G1S
M(&YO=`H@("`@("H@("`@("`@("`@("`@('-P96-I9FEE9"!I;B!T:&4@:&5A
M9&5R<RP@9F]R($)C8SHL(')E<V5N9&EN9PH@("`@("H@("`@("`@("`@("`@
M(&UE<W-A9V5S+"!E=&,N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1H
M96%D97)S(%1H92!A<G)A>2!O9B!H96%D97)S('1O('-E;F0@=VET:"!T:&4@
M;6%I;"P@:6X@86X*("`@("`J("`@("`@("`@("`@("!A<W-O8VEA=&EV92!A
M<G)A>2P@=VAE<F4@=&AE(&%R<F%Y(&ME>2!I<R!T:&4*("`@("`J("`@("`@
M("`@("`@("!H96%D97(@;F%M92`H92YG+BP@)U-U8FIE8W0G*2P@86YD('1H
M92!A<G)A>2!V86QU90H@("`@("H@("`@("`@("`@("`@(&ES('1H92!H96%D
M97(@=F%L=64@*&4N9RXL("=T97-T)RDN(%1H92!H96%D97(*("`@("`J("`@
M("`@("`@("`@("!P<F]D=6-E9"!F<F]M('1H;W-E('9A;'5E<R!W;W5L9"!B
M92`G4W5B:F5C=#H*("`@("`J("`@("`@("`@("`@("!T97-T)RX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1B;V1Y(%1H92!F=6QL('1E>'0@;V8@
M=&AE(&UE<W-A9V4@8F]D>2P@:6YC;'5D:6YG(&%N>0H@("`@("H@("`@("`@
M("`@("`@("!-:6UE('!A<G1S+"!E=&,N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"!2971U<FYS('1R=64@;VX@<W5C8V5S<RP@;W(@82!014%27T5R
M<F]R"B`@("`@*B`@("`@("`@("`@("`@(&-O;G1A:6YI;F<@82!D97-C<FEP
M=&EV92!E<G)O<B!M97-S86=E(&]N"B`@("`@*B`@("`@("`@("`@("`@(&9A
M:6QU<F4N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!S96YD*"1R96-I<&EE;G1S+"`D:&5A9&5R<RP@)&)O9'DI"B`@("![
M"B`@("`@("`@:6YC;'5D95]O;F-E("=.970O4TU44"YP:'`G.PH*("`@("`@
M("`O*B!)9B!W92!D;VXG="!A;')E861Y(&AA=F4@86X@4TU44"!O8FIE8W0L
M(&-R96%T92!O;F4N("HO"B`@("`@("`@:68@*&ES7V]B:F5C="@D=&AI<RT^
M7W-M='`I(#T]/2!F86QS92D@>PH@("`@("`@("`@("`D=&AI<RT^7W-M='`@
M/28@;F5W($YE=%]33510*"1T:&ES+3YH;W-T+"`D=&AI<RT^<&]R="P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M;&]C86QH;W-T*3L*"B`@("`@("`@("`@("\J($EF('=E('-T:6QL(&1O;B=T
M(&AA=F4@86X@4TU44"!O8FIE8W0@870@=&AI<R!P;VEN="P@9F%I;"X@*B\*
M("`@("`@("`@("`@:68@*&ES7V]B:F5C="@D=&AI<RT^7W-M='`I(#T]/2!F
M86QS92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)T9A:6QE9"!T;R!C<F5A=&4@82!.971?4TU44"!O8FIE8W0G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E]-04E,
M7U--5%!?15)23U)?0U)%051%*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+RH@0V]N9FEG=7)E('1H92!33510(&-O;FYE8W1I;VXN("HO"B`@("`@
M("`@("`@(&EF("@D=&AI<RT^9&5B=6<I('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<VUT<"T^<V5T1&5B=6<H=')U92D["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("\J($%T=&5M<'0@=&\@8V]N;F5C="!T;R!T:&4@8V]N9FEG
M=7)E9"!33510('-E<G9E<BX@*B\*("`@("`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)')E<R`]("1T:&ES+3Y?<VUT<"T^8V]N;F5C="@D=&AI<RT^=&EM
M96]U="DI*2!["B`@("`@("`@("`@("`@("`D97)R;W(@/2`D=&AI<RT^7V5R
M<F]R*"=&86EL960@=&\@8V]N;F5C="!T;R`G("X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FAO<W0@+B`G.B<@+B`D
M=&AI<RT^<&]R="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)')E<RD["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@D97)R;W(L(%!%05)?34%)3%]335107T524D]27T-/3DY%0U0I
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!!='1E;7!T('1O(&%U
M=&AE;G1I8V%T92!I9B!A=71H96YT:6-A=&EO;B!H87,@8F5E;B!E;F%B;&5D
M+B`J+PH@("`@("`@("`@("!I9B`H)'1H:7,M/F%U=&@I('L*("`@("`@("`@
M("`@("`@("1M971H;V0@/2!I<U]S=')I;F<H)'1H:7,M/F%U=&@I(#\@)'1H
M:7,M/F%U=&@@.B`G)SL*"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D<F5S(#T@)'1H:7,M/E]S;71P+3YA=71H*"1T:&ES+3YU<V5R;F%M
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G!A<W-W;W)D+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D;65T:&]D*2DI('L*("`@("`@("`@("`@("`@("`@("`D97)R;W(@
M/2`D=&AI<RT^7V5R<F]R*"(D;65T:&]D(&%U=&AE;G1I8V%T:6]N(&9A:6QU
M<F4B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)')E<RD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S;71P+3YR
M<V5T*"D["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)&5R<F]R+"!014%27TU!24Q?4TU44%]%4E)/4E]!551(*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@)&AE861E<D5L96UE;G1S(#T@)'1H:7,M/G!R97!A<F5(96%D97)S*"1H
M96%D97)S*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:&5A9&5R16QE
M;65N=',I*2!["B`@("`@("`@("`@("1T:&ES+3Y?<VUT<"T^<G-E="@I.PH@
M("`@("`@("`@("!R971U<FX@)&AE861E<D5L96UE;G1S.PH@("`@("`@('T*
M("`@("`@("!L:7-T*"1F<F]M+"`D=&5X=$AE861E<G,I(#T@)&AE861E<D5L
M96UE;G1S.PH*("`@("`@("`O*B!3:6YC92!F97<@351!<R!A<F4@9V]I;F<@
M=&\@86QL;W<@=&AI<R!H96%D97(@=&\@8F4@9F]R9V5D"B`@("`@("`@("H@
M=6YL97-S(&ET)W,@:6X@=&AE($U!24P@1E)/33H@97AC:&%N9V4L('=E)VQL
M('5S90H@("`@("`@("`J(%)E='5R;BU0871H(&EN<W1E860@;V8@1G)O;3H@
M:68@:70G<R!S970N("HO"B`@("`@("`@:68@*"%E;7!T>2@D:&5A9&5R<ULG
M4F5T=7)N+5!A=&@G72DI('L*("`@("`@("`@("`@)&9R;VT@/2`D:&5A9&5R
M<ULG4F5T=7)N+5!A=&@G73L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-S
M970H)&9R;VTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<VUT<"T^<G-E="@I
M.PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G3F\@1G)O
M;3H@861D<F5S<R!H87,@8F5E;B!P<F]V:61E9"<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%!%05)?34%)3%]335107T524D]27T92
M3TTI.PH@("`@("`@('T*"B`@("`@("`@)&%R9W-;)W9E<G`G72`]("1T:&ES
M+3YV97)P.PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R97,@/2`D=&AI
M<RT^7W-M='`M/FUA:6Q&<F]M*"1F<F]M+"`D87)G<RDI*2!["B`@("`@("`@
M("`@("1E<G)O<B`]("1T:&ES+3Y?97)R;W(H(D9A:6QE9"!T;R!S970@<V5N
M9&5R.B`D9G)O;2(L("1R97,I.PH@("`@("`@("`@("`D=&AI<RT^7W-M='`M
M/G)S970H*3L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)&5R<F]R+"!014%27TU!24Q?4TU44%]%4E)/4E]314Y$15(I.PH@("`@("`@
M('T*"B`@("`@("`@)')E8VEP:65N=',@/2`D=&AI<RT^<&%R<V5296-I<&EE
M;G1S*"1R96-I<&EE;G1S*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M<F5C:7!I96YT<RDI('L*("`@("`@("`@("`@)'1H:7,M/E]S;71P+3YR<V5T
M*"D["B`@("`@("`@("`@(')E='5R;B`D<F5C:7!I96YT<SL*("`@("`@("!]
M"@H@("`@("`@(&9O<F5A8V@@*"1R96-I<&EE;G1S(&%S("1R96-I<&EE;G0I
M('L*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<R`]("1T:&ES
M+3Y?<VUT<"T^<F-P=%1O*"1R96-I<&EE;G0I*2D@>PH@("`@("`@("`@("`@
M("`@)&5R<F]R(#T@)'1H:7,M/E]E<G)O<B@B1F%I;&5D('1O(&%D9"!R96-I
M<&EE;G0Z("1R96-I<&EE;G0B+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<F5S*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<VUT<"T^<G-E="@I.PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)&5R<F]R+"!014%27TU!24Q?4TU44%]%4E)/4E]214-)4$E%
M3E0I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!396YD
M('1H92!M97-S86=E)W,@:&5A9&5R<R!A;F0@=&AE(&)O9'D@87,@4TU44"!D
M871A+B`J+PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R97,@/2`D=&AI
M<RT^7W-M='`M/F1A=&$H(B1T97AT2&5A9&5R<UQR7&XD8F]D>2(I*2D@>PH@
M("`@("`@("`@("`D97)R;W(@/2`D=&AI<RT^7V5R<F]R*"=&86EL960@=&\@
M<V5N9"!D871A)RP@)')E<RD["B`@("`@("`@("`@("1T:&ES+3Y?<VUT<"T^
M<G-E="@I.PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D
M97)R;W(L(%!%05)?34%)3%]335107T524D]27T1!5$$I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@268@<&5R<VES=&5N="!C;VYN96-T:6]N<R!A<F4@9&ES
M86)L960L(&1E<W1R;WD@;W5R(%--5%`@;V)J96-T+B`J+PH@("`@("`@(&EF
M("@D=&AI<RT^<&5R<VES="`]/3T@9F%L<V4I('L*("`@("`@("`@("`@)'1H
M:7,M/F1I<V-O;FYE8W0H*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1&ES8V]N;F5C="!A;F0@9&5S
M=')O>2!T:&4@8W5R<F5N="!33510(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N(%1R=64@:68@=&AE(%--5%`@8V]N;F5C=&EO
M;B!N;R!L;VYG97(@97AI<W1S+@H@("`@("H*("`@("`J($!S:6YC92`@,2XQ
M+CD*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&1I<V-O;FYE8W0H*0H@("`@>PH@("`@("`@("\J($EF('=E(&AA=F4@86X@
M4TU44"!O8FIE8W0L(&1I<V-O;FYE8W0@86YD(&1E<W1R;WD@:70N("HO"B`@
M("`@("`@:68@*&ES7V]B:F5C="@D=&AI<RT^7W-M='`I("8F("1T:&ES+3Y?
M<VUT<"T^9&ES8V]N;F5C="@I*2!["B`@("`@("`@("`@("1T:&ES+3Y?<VUT
M<"`](&YU;&P["B`@("`@("`@?0H*("`@("`@("`O*B!792!A<F4@9&ES8V]N
M;F5C=&5D(&EF('=E(&YO(&QO;F=E<B!H879E(&%N(%--5%`@;V)J96-T+B`J
M+PH@("`@("`@(')E='5R;B`H)'1H:7,M/E]S;71P(#T]/2!N=6QL*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($)U:6QD(&$@<W1A;F1A<F1I>F5D('-T<FEN
M9R!D97-C<FEB:6YG('1H92!C=7)R96YT(%--5%`@97)R;W(N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@0W5S=&]M('-T<FEN9R!D97-C
M<FEB:6YG('1H92!E<G)O<B!C;VYT97AT+@H@("`@("H@0'!A<F%M(&]B:F5C
M="`D97)R;W(@4F5F97)E;F-E('1O('1H92!C=7)R96YT(%!%05)?17)R;W(@
M;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@("`@($$@
M<W1R:6YG(&1E<V-R:6)I;F<@=&AE(&-U<G)E;G0@4TU44"!E<G)O<BX*("`@
M("`J"B`@("`@*B!`<VEN8V4@(#$N,2XW"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V5R<F]R*"1T97AT+"`F)&5R<F]R
M*0H@("`@>PH@("`@("`@("\J(%-P;&ET('1H92!33510(')E<W!O;G-E(&EN
M=&\@82!C;V1E(&%N9"!A(')E<W!O;G-E('-T<FEN9RX@*B\*("`@("`@("!L
M:7-T*"1C;V1E+"`D<F5S<&]N<V4I(#T@)'1H:7,M/E]S;71P+3YG971297-P
M;VYS92@I.PH*("`@("`@("`O*B!"=6EL9"!O=7(@<W1A;F1A<F1I>F5D(&5R
M<F]R('-T<FEN9RX@*B\*("`@("`@("`D;7-G(#T@)'1E>'0["B`@("`@("`@
M)&US9R`N/2`G(%M33510.B`G("X@)&5R<F]R+3YG971-97-S86=E*"D["B`@
M("`@("`@)&US9R`N/2`B("AC;V1E.B`D8V]D92P@<F5S<&]N<V4Z("1R97-P
M;VYS92E=(CL*"B`@("`@("`@<F5T=7)N("1M<V<["B`@("!]"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+TUA:6PN<&AP````````````````````````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#$W-C`Q`#$P-3$U-#,S-S0S`#`R,#(P-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO+PHO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO
M;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S
M=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@
M("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I
M;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I
M;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F
M('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O
M8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S
M96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T
M('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!!=71H;W(Z($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z($UA:6PN<&AP+'8@,2XQ,B`R,#`U
M+S`X+S(R(#`Q.C$Y.C(W(&IO;B!%>'`@)`H*<F5Q=6ER95]O;F-E("=014%2
M+G!H<"<["@HO*BH*("H@4$5!4B=S($UA:6PZ.B!I;G1E<F9A8V4N($1E9FEN
M97,@=&AE(&EN=&5R9F%C92!F;W(@:6UP;&5M96YT:6YG"B`J(&UA:6QE<G,@
M=6YD97(@=&AE(%!%05(@:&EE<F%R8VAY+"!A;F0@<')O=FED97,@<W5P<&]R
M=&EN9R!F=6YC=&EO;G,*("H@=7-E9G5L(&EN(&UU;'1I<&QE(&UA:6QE<B!B
M86-K96YD<RX*("H*("H@0&%C8V5S<R!P=6)L:6,*("H@0'9E<G-I;VX@)%)E
M=FES:6]N.B`Q+C$R("0*("H@0'!A8VMA9V4@36%I;`H@*B\*8VQA<W,@36%I
M;`I["B`@("`O*BH*("`@("`J($QI;F4@=&5R;6EN871O<B!U<V5D(&9O<B!S
M97!A<F%T:6YG(&AE861E<B!L:6YE<RX*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D<V5P(#T@(EQR7&XB.PH*("`@("\J*@H@("`@("H@
M4')O=FED97,@86X@:6YT97)F86-E(&9O<B!G96YE<F%T:6YG($UA:6PZ.B!O
M8FIE8W1S(&]F('9A<FEO=7,*("`@("`J('1Y<&5S"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9')I=F5R(%1H92!K:6YD(&]F($UA:6PZ.B!O8FIE
M8W0@=&\@:6YS=&%N=&EA=&4N"B`@("`@*B!`<&%R86T@87)R87D@("1P87)A
M;7,@5&AE('!A<F%M971E<G,@=&\@<&%S<R!T;R!T:&4@36%I;#HZ(&]B:F5C
M="X*("`@("`J($!R971U<FX@;V)J96-T($UA:6P@82!I;G-T86YC92!O9B!T
M:&4@9')I=F5R(&-L87-S(&]R(&EF(&9A:6QS(&$@4$5!4B!%<G)O<@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O
M<GDH)&1R:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M)&1R:79E<B`]('-T<G1O;&]W97(H)&1R:79E<BD["B`@("`@("`@0&EN8VQU
M9&5?;VYC92`G36%I;"\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("`D
M8VQA<W,@/2`G36%I;%\G("X@)&1R:79E<CL*("`@("`@("!I9B`H8VQA<W-?
M97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)&UA:6QE<B`](&YE=R`D
M8VQA<W,H)'!A<F%M<RD["B`@("`@("`@("`@(')E='5R;B`D;6%I;&5R.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*"=5;F%B;&4@=&\@9FEN9"!C;&%S<R!F;W(@9')I=F5R("<@+B`D
M9')I=F5R*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!);7!L
M96UE;G1S($UA:6PZ.G-E;F0H*2!F=6YC=&EO;B!U<VEN9R!P:'`G<R!B=6EL
M="UI;B!M86EL*"D*("`@("`J(&-O;6UA;F0N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&UI>&5D("1R96-I<&EE;G1S($5I=&AE<B!A(&-O;6UA+7-E<&5R871E
M9"!L:7-T(&]F(')E8VEP:65N=',*("`@("`J("`@("`@("`@("`@("`H4D9#
M.#(R(&-O;7!L:6%N="DL(&]R(&%N(&%R<F%Y(&]F(')E8VEP:65N=',L"B`@
M("`@*B`@("`@("`@("`@("`@96%C:"!21D,X,C(@=F%L:60N(%1H:7,@;6%Y
M(&-O;G1A:6X@<F5C:7!I96YT<R!N;W0*("`@("`J("`@("`@("`@("`@("!S
M<&5C:69I960@:6X@=&AE(&AE861E<G,L(&9O<B!"8V,Z+"!R97-E;F1I;F<*
M("`@("`J("`@("`@("`@("`@("!M97-S86=E<RP@971C+@H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D:&5A9&5R<R!4:&4@87)R87D@;V8@:&5A9&5R
M<R!T;R!S96YD('=I=&@@=&AE(&UA:6PL(&EN(&%N"B`@("`@*B`@("`@("`@
M("`@("`@87-S;V-I871I=F4@87)R87DL('=H97)E('1H92!A<G)A>2!K97D@
M:7,@=&AE"B`@("`@*B`@("`@("`@("`@("`@:&5A9&5R(&YA;64@*&EE+"`G
M4W5B:F5C="<I+"!A;F0@=&AE(&%R<F%Y('9A;'5E"B`@("`@*B`@("`@("`@
M("`@("`@:7,@=&AE(&AE861E<B!V86QU92`H:64L("=T97-T)RDN(%1H92!H
M96%D97(*("`@("`J("`@("`@("`@("`@("!P<F]D=6-E9"!F<F]M('1H;W-E
M('9A;'5E<R!W;W5L9"!B92`G4W5B:F5C=#H*("`@("`J("`@("`@("`@("`@
M("!T97-T)RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1B;V1Y(%1H
M92!F=6QL('1E>'0@;V8@=&AE(&UE<W-A9V4@8F]D>2P@:6YC;'5D:6YG(&%N
M>0H@("`@("H@("`@("`@("`@("`@("!-:6UE('!A<G1S+"!E=&,N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"!2971U<FYS('1R=64@;VX@<W5C8V5S
M<RP@;W(@82!014%27T5R<F]R"B`@("`@*B`@("`@("`@("`@("`@(&-O;G1A
M:6YI;F<@82!D97-C<FEP=&EV92!E<G)O<B!M97-S86=E(&]N"B`@("`@*B`@
M("`@("`@("`@("`@(&9A:6QU<F4N"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H@0&1E<')E8V%T960@=7-E($UA:6Q?;6%I;#HZ<V5N9"!I;G-T96%D
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E;F0H)')E8VEP:65N=',L("1H96%D
M97)S+"`D8F]D>2D*("`@('L*("`@("`@("`O+R!I9B!W92=R92!P87-S960@
M86X@87)R87D@;V8@<F5C:7!I96YT<RP@:6UP;&]D92!I="X*("`@("`@("!I
M9B`H:7-?87)R87DH)')E8VEP:65N=',I*2!["B`@("`@("`@("`@("1R96-I
M<&EE;G1S(#T@:6UP;&]D92@G+"`G+"`D<F5C:7!I96YT<RD["B`@("`@("`@
M?0H*("`@("`@("`O+R!G970@=&AE(%-U8FIE8W0@;W5T(&]F('1H92!H96%D
M97)S(&%R<F%Y('-O('1H870@=V4@8V%N"B`@("`@("`@+R\@<&%S<R!I="!A
M<R!A('-E<&5R871E(&%R9W5M96YT('1O(&UA:6PH*2X*("`@("`@("`D<W5B
M:F5C="`]("<G.PH@("`@("`@(&EF("AI<W-E="@D:&5A9&5R<ULG4W5B:F5C
M="==*2D@>PH@("`@("`@("`@("`D<W5B:F5C="`]("1H96%D97)S6R=3=6)J
M96-T)UT["B`@("`@("`@("`@('5N<V5T*"1H96%D97)S6R=3=6)J96-T)UTI
M.PH@("`@("`@('T*"B`@("`@("`@+R\@9FQA='1E;B!T:&4@:&5A9&5R<R!O
M=70N"B`@("`@("`@;&ES="@L)'1E>'1?:&5A9&5R<RD@/2!-86EL.CIP<F5P
M87)E2&5A9&5R<R@D:&5A9&5R<RD["@H@("`@("`@(')E='5R;B!M86EL*"1R
M96-I<&EE;G1S+"`D<W5B:F5C="P@)&)O9'DL("1T97AT7VAE861E<G,I.PH*
M("`@('T*"B`@("`O*BH*("`@("`J(%1A:V4@86X@87)R87D@;V8@;6%I;"!H
M96%D97)S(&%N9"!R971U<FX@82!S=')I;F<@8V]N=&%I;FEN9PH@("`@("H@
M=&5X="!U<V%B;&4@:6X@<V5N9&EN9R!A(&UE<W-A9V4N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1H96%D97)S(%1H92!A<G)A>2!O9B!H96%D97)S
M('1O('!R97!A<F4L(&EN(&%N(&%S<V]C:6%T:79E"B`@("`@*B`@("`@("`@
M("`@("`@87)R87DL('=H97)E('1H92!A<G)A>2!K97D@:7,@=&AE(&AE861E
M<B!N86UE("AI92P*("`@("`J("`@("`@("`@("`@("`G4W5B:F5C="<I+"!A
M;F0@=&AE(&%R<F%Y('9A;'5E(&ES('1H92!H96%D97(*("`@("`J("`@("`@
M("`@("`@("!V86QU92`H:64L("=T97-T)RDN(%1H92!H96%D97(@<')O9'5C
M960@9G)O;2!T:&]S90H@("`@("H@("`@("`@("`@("`@('9A;'5E<R!W;W5L
M9"!B92`G4W5B:F5C=#H@=&5S="<N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"!2971U<FYS(&9A;'-E(&EF(&ET(&5N8V]U;G1E<G,@82!B860@861D
M<F5S<RP*("`@("`J("`@("`@("`@("`@("`@;W1H97)W:7-E(')E='5R;G,@
M86X@87)R87D@8V]N=&%I;FEN9R!T=V\*("`@("`J("`@("`@("`@("`@("`@
M96QE;65N=',Z($%N>2!&<F]M.B!A9&1R97-S(&9O=6YD(&EN('1H92!H96%D
M97)S+`H@("`@("H@("`@("`@("`@("`@("!A;F0@=&AE('!L86EN('1E>'0@
M=F5R<VEO;B!O9B!T:&4@:&5A9&5R<RX*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!F=6YC=&EO;B!P<F5P87)E2&5A9&5R<R@D:&5A9&5R
M<RD*("`@('L*("`@("`@("`D;&EN97,@/2!A<G)A>2@I.PH@("`@("`@("1F
M<F]M(#T@;G5L;#L*"B`@("`@("`@9F]R96%C:"`H)&AE861E<G,@87,@)&ME
M>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@:68@*'-T<F-A<V5C;7`H)&ME
M>2P@)T9R;VTG*2`]/3T@,"D@>PH@("`@("`@("`@("`@("`@:6YC;'5D95]O
M;F-E("=-86EL+U)&0S@R,BYP:'`G.PH@("`@("`@("`@("`@("`@)'!A<G-E
M<B`]("9N97<@36%I;%]21D,X,C(H*3L*("`@("`@("`@("`@("`@("1A9&1R
M97-S97,@/2`D<&%R<V5R+3YP87)S94%D9')E<W-,:7-T*"1V86QU92P@)VQO
M8V%L:&]S="<L(&9A;'-E*3L*("`@("`@("`@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1A9&1R97-S97,I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1A9&1R97-S97,["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`@("`@)&9R;VT@/2`D861D<F5S<V5S6S!=+3YM86EL8F]X("X@)T`G("X@
M)&%D9')E<W-E<ULP72T^:&]S=#L*"B`@("`@("`@("`@("`@("`O+R!296IE
M8W0@96YV96QO<&4@1G)O;3H@861D<F5S<V5S('=I=&@@<W!A8V5S+@H@("`@
M("`@("`@("`@("`@:68@*'-T<G-T<B@D9G)O;2P@)R`G*2D@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("`@("`D;&EN97-;72`]("1K97D@+B`G.B`G("X@)'9A
M;'5E.PH@("`@("`@("`@("!](&5L<V5I9B`H<W1R8V%S96-M<"@D:V5Y+"`G
M4F5C96EV960G*2`]/3T@,"D@>PH@("`@("`@("`@("`@("`@)')E8V5I=F5D
M(#T@87)R87DH*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=F%L
M=64I*2!["B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E(&%S
M("1L:6YE*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1R96-E:79E9%M=
M(#T@)&ME>2`N("<Z("<@+B`D;&EN93L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`D<F5C96EV961;72`]("1K97D@+B`G.B`G("X@
M)'9A;'5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@+R\@
M4'5T(%)E8V5I=F5D.B!H96%D97)S(&%T('1H92!T;W`N("!3<&%M(&1E=&5C
M=&]R<R!O9G1E;@H@("`@("`@("`@("`@("`@+R\@9FQA9R!M97-S86=E<R!W
M:71H(%)E8V5I=F5D.B!H96%D97)S(&%F=&5R('1H92!3=6)J96-T.@H@("`@
M("`@("`@("`@("`@+R\@87,@<W!A;2X*("`@("`@("`@("`@("`@("1L:6YE
M<R`](&%R<F%Y7VUE<F=E*"1R96-E:79E9"P@)&QI;F5S*3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\O($EF("1V86QU92!I<R!A
M;B!A<G)A>2`H:2YE+BP@82!L:7-T(&]F(&%D9')E<W-E<RDL(&-O;G9E<G0*
M("`@("`@("`@("`@("`@("\O(&ET('1O(&$@8V]M;6$M9&5L:6UI=&5D('-T
M<FEN9R!O9B!I=',@96QE;65N=',@*&%D9')E<W-E<RDN"B`@("`@("`@("`@
M("`@("!I9B`H:7-?87)R87DH)'9A;'5E*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1V86QU92`](&EM<&QO9&4H)RP@)RP@)'9A;'5E*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1L:6YE<UM=(#T@)&ME>2`N("<Z
M("<@+B`D=F%L=64["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!A<G)A>2@D9G)O;2P@:F]I;B@D=&AI<RT^<V5P+"`D;&EN97,I
M("X@)'1H:7,M/G-E<"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!486ME(&$@
M<V5T(&]F(')E8VEP:65N=',@86YD('!A<G-E('1H96TL(')E='5R;FEN9R!A
M;B!A<G)A>2!O9@H@("`@("H@8F%R92!A9&1R97-S97,@*&9O<G=A<F0@<&%T
M:',I('1H870@8V%N(&)E('!A<W-E9"!T;R!S96YD;6%I;`H@("`@("H@;W(@
M86X@<VUT<"!S97)V97(@=VET:"!T:&4@<F-P="!T;SH@8V]M;6%N9"X*("`@
M("`J"B`@("`@*B!`<&%R86T@;6EX960@16ET:&5R(&$@8V]M;6$M<V5P97)A
M=&5D(&QI<W0@;V8@<F5C:7!I96YT<PH@("`@("H@("`@("`@("`@("`@("A2
M1D,X,C(@8V]M<&QI86YT*2P@;W(@86X@87)R87D@;V8@<F5C:7!I96YT<RP*
M("`@("`J("`@("`@("`@("`@("!E86-H(%)&0S@R,B!V86QI9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y($%N(&%R<F%Y(&]F(&9O<G=A<F0@<&%T
M:',@*&)A<F4@861D<F5S<V5S*2X*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!F=6YC=&EO;B!P87)S95)E8VEP:65N=',H)')E8VEP:65N
M=',I"B`@("!["B`@("`@("`@:6YC;'5D95]O;F-E("=-86EL+U)&0S@R,BYP
M:'`G.PH*("`@("`@("`O+R!I9B!W92=R92!P87-S960@86X@87)R87DL(&%S
M<W5M92!A9&1R97-S97,@87)E('9A;&ED(&%N9`H@("`@("`@("\O(&EM<&QO
M9&4@=&AE;2!B969O<F4@<&%R<VEN9RX*("`@("`@("!I9B`H:7-?87)R87DH
M)')E8VEP:65N=',I*2!["B`@("`@("`@("`@("1R96-I<&EE;G1S(#T@:6UP
M;&]D92@G+"`G+"`D<F5C:7!I96YT<RD["B`@("`@("`@?0H*("`@("`@("`O
M+R!087)S92!R96-I<&EE;G1S+"!L96%V:6YG(&]U="!A;&P@<&5R<V]N86P@
M:6YF;RX@5&AI<R!I<PH@("`@("`@("\O(&9O<B!S;71P(')E8VEP:65N=',L
M(&5T8RX@06QL(')E;&5V86YT('!E<G-O;F%L(&EN9F]R;6%T:6]N"B`@("`@
M("`@+R\@<VAO=6QD(&%L<F5A9'D@8F4@:6X@=&AE(&AE861E<G,N"B`@("`@
M("`@)&%D9')E<W-E<R`]($UA:6Q?4D9#.#(R.CIP87)S94%D9')E<W-,:7-T
M*"1R96-I<&EE;G1S+"`G;&]C86QH;W-T)RP@9F%L<V4I.PH@("`@("`@("1R
M96-I<&EE;G1S(#T@87)R87DH*3L*("`@("`@("!I9B`H:7-?87)R87DH)&%D
M9')E<W-E<RDI('L*("`@("`@("`@("`@9F]R96%C:"`H)&%D9')E<W-E<R!A
M<R`D;V(I('L*("`@("`@("`@("`@("`@("1R96-I<&EE;G1S6UT@/2`D;V(M
M/FUA:6QB;W@@+B`G0"<@+B`D;V(M/FAO<W0["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D<F5C:7!I96YT<SL*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B].970O````````````````````````
M````````````````````````````````````````````````````````````
M```P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,S<T,P`P,3<S,S(`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TYE="]&
M5%`O````````````````````````````````````````````````````````
M`````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-3$U-#,S-S0S`#`Q-S<V,P`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O3F5T+T944"]/8G-E<G9E<BYP:'``````````````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4V,C(`,3`U,34T,S,W-#,`,#(R,C<P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED
M=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J($YE=%]&5%`@;V)S97)V
M97(N"B`J"B`J(%1H:7,@8VQA<W,@:6UP;&5M96YT<R!T:&4@3V)S97)V97(@
M<&%R="!O9B!A(%-U8FIE8W0M3V)S97)V97(*("H@9&5S:6=N('!A='1E<FXN
M($ET(&QI<W1E;G,@=&\@=&AE(&5V96YT<R!S96YT(&)Y(&$@3F5T7T944"!I
M;G-T86YC92X*("H@5&AI<R!M;V1U;&4@:&%D(&UA;GD@:6YF;'5E;F-E<R!F
M<F]M('1H92!,;V=?;V)S97)V97(@8V]D92X*("H*("H@4$A0('9E<G-I;VYS
M(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S
M=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90H@*B!T
M:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A
M="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y
M(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A
M:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A(&YO=&4@
M=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@
M:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@($YE='=O<FMI;F<*("H@
M0'!A8VMA9V4@("`@1E10"B`J($!A=71H;W(@("`@(%1O8FEA<R!38VAL:71T
M(#QT;V)Y0'!H<"YN970^"B`J($!A=71H;W(@("`@($QA=7)E;G0@3&%V:6QL
M92`\<&5A<D!L875R96YT+6QA=FEL;&4N;W)G/@H@*B!`875T:&]R("`@("!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&-O<'ER:6=H
M="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@
M,RXP"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!/8G-E<G9E<BYP:'`L=B`Q
M+C(@,C`P-2\P,B\R,R`Q,CHQ,CHR,R!T;V)Y($5X<"`D"B`J($!L:6YK("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92].971?1E10"B`J($!S
M:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XP+C$*
M("HO"@HO*BH*("H@5&AI<R!C;&%S<R!I;7!L96UE;G1S('1H92!/8G-E<G9E
M<B!P87)T(&]F(&$@4W5B:F5C="U/8G-E<G9E<@H@*B!D97-I9VX@<&%T=&5R
M;BX@270@;&ES=&5N<R!T;R!T:&4@979E;G1S('-E;G0@8GD@82!.971?1E10
M(&EN<W1A;F-E+@H@*B!4:&ES(&UO9'5L92!H860@;6%N>2!I;F9L=65N8V5S
M(&9R;VT@=&AE($QO9U]O8G-E<G9E<B!C;V1E+@H@*@H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC
M96YS92`S+C`*("H@0&-A=&5G;W)Y("`@3F5T=V]R:VEN9PH@*B!`<&%C:V%G
M92`@("!&5%`*("H@0&%U=&AO<B`@("`@3&%U<F5N="!,879I;&QE(#QP96%R
M0&QA=7)E;G0M;&%V:6QL92YO<F<^"B`J($!A=71H;W(@("`@($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("`@("!4;V)I
M87,@4V-H;&ET="`\=&]B>4!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW
M+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q
M+C,N,0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA
M9V4O3F5T7T944`H@*B!`<VEN8V4@("`@("`Q+C,N,"XP"B`J($!A8V-E<W,@
M("`@('!U8FQI8PH@*@H@*B!`97AA;7!L92`@("!O8G-E<G9E<E]U<&QO860N
M<&AP("`@("`@("`@($%N(&5X86UP;&4@;V8@3F5T7T944%]/8G-E<G9E<B!I
M;7!L96UE;G1A=&EO;BX*("HO"F-L87-S($YE=%]&5%!?3V)S97)V97(*>PH@
M("`@+RHJ"B`@("`@*B!);G-T86YC92US<&5C:69I8R!U;FEQ=64@:61E;G1I
M9FEC871I;VX@;G5M8F5R+@H@("`@("H*("`@("`J($!V87(@("`@("`@(&EN
M=&5G97(*("`@("`J($!S:6YC92`@("`@(#$N,RXP"B`@("`@*B!`86-C97-S
M("`@("!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7VED.PH*("`@("\J*@H@
M("`@("H@0W)E871E<R!A(&YE=R!B87-I8R!.971?1E107T]B<V5R=F5R(&EN
M<W1A;F-E+@H@("`@("H*("`@("`J($!S:6YC92`@("`@(#$N,RXP"B`@("`@
M*B!`86-C97-S("`@("!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@3F5T
M7T944%]/8G-E<G9E<B@I"B`@("!["B`@("`@("`@)'1H:7,M/E]I9"`](&UD
M-2AM:6-R;W1I;64H*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!L:7-T96YE<B=S(&ED96YT:69I97(*("`@("`J"B`@("`@*B!`<F5T
M=7)N("`@("!S=')I;F<*("`@("`J($!S:6YC92`@("`@(#$N,RXP"B`@("`@
M*B!`86-C97-S("`@("!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M260H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VED.PH@("`@?0H*
M("`@("\J*@H@("`@("H@5&AI<R!I<R!A('-T=6(@;65T:&]D('1O(&UA:V4@
M<W5R92!T:&%T($YE=%]&5%!?3V)S97)V97(@8VQA<W-E<R!D;PH@("`@("H@
M<V]M971H:6YG('=H96X@=&AE>2!A<F4@;F]T:69I960@;V8@82!M97-S86=E
M+B`@5&AE(&1E9F%U;'0@8F5H879I;W(*("`@("`J(&ES('1O(&IU<W0@9&\@
M;F]T:&EN9RX*("`@("`J(%EO=2!S:&]U;&0@;W9E<G)I9&4@=&AI<R!M971H
M;V0N"B`@("`@*@H@("`@("H@0'!A<F%M("`@("`@;6EX960@("`@("1E=F5N
M="`@("`@("`@($$@:&%S:"!D97-C<FEB:6YG('1H92!N970@979E;G0N"B`@
M("`@*@H@("`@("H@0'-I;F-E("`@("`@,2XS+C`*("`@("`J($!A8V-E<W,@
M("`@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!N;W1I9GDH)&5V96YT
M*0H@("`@>PH@("`@("`@(')E='5R;CL*("`@('T*?0H_/@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B].970O
M1E10+G!H<```````````````````````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#(Q,C$R-``Q,#4Q-30S,S<T,P`P,C`T-S8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RH@=FEM.B!S970@
M97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]
M-#H@*B\*"B\J*@H@*B!.971?1E10(&UA:6X@9FEL92X*("H*("H@5&AI<R!F
M:6QE(&UU<W0@8F4@:6YC;'5D960@=&\@=7-E('1H92!.971?1E10('!A8VMA
M9V4N"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z
M(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O
M9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G
M:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@
M9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@
M86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@
M<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T
M96=O<GD@("!.971W;W)K:6YG"B`J($!P86-K86=E("`@($944`H@*B!`875T
M:&]R("`@("!4;V)I87,@4V-H;&ET="`\=&]B>4!P:'`N;F5T/@H@*B!`8V]P
M>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC
M96YS92`S+C`*("H@0'9E<G-I;VX@("`@0U93.B`D260Z($944"YP:'`L=B`Q
M+C0R(#(P,#4O,#,O,S$@,C`Z,#<Z-3@@=&]B>2!%>'`@)`H@*B!`;&EN:R`@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O3F5T7T944`H@*B!`
M<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#`N,"XQ
M"B`J+PH*<F5Q=6ER95]O;F-E("=014%2+G!H<"<["@HO*BH*("H@3W!T:6]N
M('1O(&QE="!T:&4@;',H*2!M971H;V0@<F5T=7)N(&]N;'D@9FEL97,N"B`J
M"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]&24Q%4U]/3DQ9"B`J
M($!S964@3F5T7T944#HZ;',H*0H@*B\*9&5F:6YE*"=.151?1E107T9)3$53
M7T].3%DG+"`P+"!T<G5E*3L*"B\J*@H@*B!/<'1I;VX@=&\@;&5T('1H92!L
M<R@I(&UE=&AO9"!R971U<FX@;VYL>2!D:7)E8W1O<FEE<RX*("H*("H@0'-I
M;F-E(#$N,PH@*B!`;F%M92!.151?1E107T1)4E-?3TY,60H@*B!`<V5E($YE
M=%]&5%`Z.FQS*"D*("HO"F1E9FEN92@G3D547T944%]$25)37T].3%DG+"`Q
M+"!T<G5E*3L*"B\J*@H@*B!/<'1I;VX@=&\@;&5T('1H92!L<R@I(&UE=&AO
M9"!R971U<FX@9&ER96-T;W)I97,@86YD(&9I;&5S("AD969A=6QT*2X*("H*
M("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E107T1)4E-?1DE,15,*("H@
M0'-E92!.971?1E10.CIL<R@I"B`J+PID969I;F4H)TY%5%]&5%!?1$E24U]&
M24Q%4R<L(#(L('1R=64I.PH*+RHJ"B`J($]P=&EO;B!T;R!L970@=&AE(&QS
M*"D@;65T:&]D(')E='5R;B!T:&4@<F%W(&1I<F5C=&]R>2!L:7-T:6YG(&9R
M;VT@9G1P7W)A=VQI<W0H*2X*("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.
M151?1E107U)!5TQ)4U0*("H@0'-E92!.971?1E10.CIL<R@I"B`J+PID969I
M;F4H)TY%5%]&5%!?4D%73$E35"<L(#,L('1R=64I.PH*"B\J*@H@*B!%<G)O
M<B!C;V1E('1O(&EN9&EC871E(&$@9F%I;&5D(&-O;FYE8W1I;VX*("H@5&AI
M<R!E<G)O<B!C;V1E(&EN9&EC871E<RP@=&AA="!T:&4@8V]N;F5C=&EO;B!Y
M;W4@=')Y960@=&\@<V5T('5P"B`J(&-O=6QD(&YO="!B92!E<W1A8FQI<VAE
M9"X@0VAE8VL@>6]U<B!C;VYN96-T:6]N('-E='1I;F=S("AH;W-T("8@<&]R
M="DA"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?0T].
M3D5#5%]&04E,140*("H@0'-E92!.971?1E10.CIC;VYN96-T*"D*("HO"F1E
M9FEN92@G3D547T944%]%4E)?0T].3D5#5%]&04E,140G+"`M,2D["@HO*BH*
M("H@17)R;W(@8V]D92!T;R!I;F1I8V%T92!A(&9A:6QE9"!L;V=I;@H@*B!4
M:&ES(&5R<F]R(&-O9&4@:6YD:6-A=&5S+"!T:&%T('1H92!L;V=I;B!T;R!T
M:&4@1E10('-E<G9E<B!F86EL960N($-H96-K"B`J('EO=7(@=7-E<B!D871A
M("AU<V5R;F%M92`F('!A<W-W;W)D*2X*("H*("H@0'-I;F-E(#$N,PH@*B!`
M;F%M92!.151?1E107T524E],3T=)3E]&04E,140*("H@0'-E92!.971?1E10
M.CIL;V=I;B@I"B`J+PID969I;F4H)TY%5%]&5%!?15)27TQ/1TE.7T9!24Q%
M1"<L("TR*3L*"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E(&$@9F%I
M;&5D(&1I<F5C=&]R>2!C:&%N9V4*("H@5&AE(&-D*"D@;65T:&]D(&9A:6QE
M9"X@16YS=7)E('1H870@=&AE(&1I<F5C=&]R>2!Y;W4@=V%N=&5D('1O(&%C
M8V5S<R!E>&ES=',N"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T94
M4%]%4E)?1$E20TA!3D=%7T9!24Q%1`H@*B!`<V5E($YE=%]&5%`Z.F-D*"D*
M("HO"F1E9FEN92@G3D547T944%]%4E)?1$E20TA!3D=%7T9!24Q%1"<L(#(I
M.R`O+R!#;VUP871I8FEL;&ET>2!R96%S;VYS(0H*+RHJ"B`J($5R<F]R(&-O
M9&4@=&\@:6YD:6-A=&4@=&AA="!.971?1E10(&-O=6QD(&YO="!D971E<FUI
M;F4@=&AE(&-U<G)E;G0@<&%T:`H@*B!4:&4@8W=D*"D@;65T:&]D(&9A:6QE
M9"!A;F0@8V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<&%T:"!Y;W4@8W5R<F5N
M=&QY(')E<VED90H@*B!I;B!O;B!T:&4@1E10('-E<G9E<BX*("H*("H@0'-I
M;F-E(#$N,PH@*B!`;F%M92!.151?1E107T524E]$151%4DU)3D50051(7T9!
M24Q%1`H@*B!`<V5E($YE=%]&5%`Z.G!W9"@I"B`J+PID969I;F4H)TY%5%]&
M5%!?15)27T1%5$5234E.15!!5$A?1D%)3$5$)RP@-"D[("\O($-O;7!A=&EB
M:6QL:71Y(')E87-O;G,A"@HO*BH*("H@17)R;W(@8V]D92!T;R!I;F1I8V%T
M92!T:&%T('1H92!C<F5A=&EO;B!O9B!A(&1I<F5C=&]R>2!F86EL960*("H@
M5&AE(&1I<F5C=&]R>2!Y;W4@=')Y960@=&\@8W)E871E(&-O=6QD(&YO="!B
M92!C<F5A=&5D+B!#:&5C:R!T:&4*("H@86-C97-S(')I9VAT<R!O;B!T:&4@
M<&%R96YT(&1I<F5C=&]R>2$*("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.
M151?1E107T524E]#4D5!5$5$25)?1D%)3$5$"B`J($!S964@3F5T7T944#HZ
M;6MD:7(H*0H@*B\*9&5F:6YE*"=.151?1E107T524E]#4D5!5$5$25)?1D%)
M3$5$)RP@+30I.PH*+RHJ"B`J($5R<F]R(&-O9&4@=&\@:6YD:6-A=&4@=&AA
M="!T:&4@15A%0R!E>&5C=71I;VX@9F%I;&5D+@H@*B!4:&4@97AE8W5T:6]N
M(&]F(&$@8V]M;6%N9"!U<VEN9R!%6$5#(&9A:6QE9"X@16YS=7)E+"!T:&%T
M('EO=7(*("H@1E10('-E<G9E<B!S=7!P;W)T<R!T:&4@15A%0R!C;VUM86YD
M+@H@*@H@*B!`<VEN8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?15)27T5814-?
M1D%)3$5$"B`J($!S964@3F5T7T944#HZ97AE8W5T92@I"B`J+PID969I;F4H
M)TY%5%]&5%!?15)27T5814-?1D%)3$5$)RP@+34I.PH*+RHJ"B`J($5R<F]R
M(&-O9&4@=&\@:6YD:6-A=&4@=&AA="!T:&4@4TE412!C;VUM86YD(&9A:6QE
M9"X*("H@5&AE(&5X96-U=&EO;B!O9B!A(&-O;6UA;F0@=7-I;F<@4TE412!F
M86EL960N($5N<W5R92P@=&AA="!Y;W5R"B`J($944"!S97)V97(@<W5P<&]R
M=',@=&AE(%-)5$4@8V]M;6%N9"X*("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M
M92!.151?1E107T524E]3251%7T9!24Q%1`H@*B!`<V5E($YE=%]&5%`Z.G-I
M=&4H*0H@*B\*9&5F:6YE*"=.151?1E107T524E]3251%7T9!24Q%1"<L("TV
M*3L*"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E('1H870@=&AE($-(
M34]$(&-O;6UA;F0@9F%I;&5D+@H@*B!4:&4@97AE8W5T:6]N(&]F($-(34]$
M(&9A:6QE9"X@16YS=7)E+"!T:&%T('EO=7(*("H@1E10('-E<G9E<B!S=7!P
M;W)T<R!T:&4@0TA-3T0@8V]M;6%N9"!A;F0@=&AA="!Y;W4@:&%V92!T:&4@
M87!P<F]P<FEA=&4*("H@86-C97-S(')I9VAT<R!T;R!U<V4@0TA-3T0N"B`J
M"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?0TA-3T1?1D%)
M3$5$"B`J($!S964@3F5T7T944#HZ8VAM;V0H*0H@*B\*9&5F:6YE*"=.151?
M1E107T524E]#2$U/1%]&04E,140G+"`M-RD["@HO*BH*("H@17)R;W(@8V]D
M92!T;R!I;F1I8V%T92!T:&%T(&$@9FEL92!R96YA;64@9F%I;&5D"B`J(%1H
M92!R96YA;6EN9R!O9B!A(&9I;&4@;VX@=&AE('-E<G9E<B!F86EL960N($5N
M<W5R92!T:&%T('EO=2!H879E('1H90H@*B!A<'!R;W!R:6%T92!A8V-E<W,@
M<FEG:'1S('1O(')E;F%M92!T:&4@9FEL92X*("H*("H@0'-I;F-E(#$N,PH@
M*B!`;F%M92!.151?1E107T524E]214Y!345?1D%)3$5$"B`J($!S964@3F5T
M7T944#HZ<F5N86UE*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?4D5.04U%
M7T9!24Q%1"<L("TX*3L*"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E
M('1H870@=&AE($U$5$T@8V]M;6%N9"!F86EL960*("H@5&AE($U$5$T@8V]M
M;6%N9"!I<R!N;W0@<W5P<&]R=&5D(&9O<B!D:7)E8W1O<FEE<RX@16YS=7)E
M('1H870@>6]U(&=A=F4*("H@82!F:6QE('!A=&@@=&\@=&AE(&UD=&TH*2!M
M971H;V0L(&YO="!A(&1I<F5C=&]R>2!P871H+@H@*@H@*B!`<VEN8V4@,2XS
M"B`J($!N86UE($Y%5%]&5%!?15)27TU$5$U$25)?54Y355!03U)4140*("H@
M0'-E92!.971?1E10.CIM9'1M*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?
M3414341)4E]53E-54%!/4E1%1"<L("TY*3L*"B\J*@H@*B!%<G)O<B!C;V1E
M('1O(&EN9&EC871E('1H870@=&AE($U$5$T@8V]M;6%N9"!F86EL960*("H@
M5&AE($U$5$T@8V]M;6%N9"!F86EL960N($5N<W5R92!T:&%T('EO=7(@<V5R
M=F5R('-U<'!O<G1S('1H92!-1%1-(&-O;6UA;F0N"B`J"B`J($!S:6YC92`Q
M+C,*("H@0&YA;64@3D547T944%]%4E)?341435]&04E,140*("H@0'-E92!.
M971?1E10.CIM9'1M*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?341435]&
M04E,140G+"`M,3`I.PH*+RHJ"B`J($5R<F]R(&-O9&4@=&\@:6YD:6-A=&4@
M=&AA="!A(&1A=&4@<F5T=7)N960@8GD@=&AE('-E<G9E<B!W87,@;6ES9F]R
M;6%T960*("H@02!D871E('-T<FEN9R!R971U<FYE9"!B>2!Y;W5R('-E<G9E
M<B!S965M<R!T;R!B92!M:7-S9F]R;6%T960@86YD(&-O=6QD(&YO="!B90H@
M*B!P87)S960N($-H96-K('1H870@=&AE('-E<G9E<B!I<R!C;VYF:6=U<F5D
M(&-O<G)E8W1L>2X@268@>6]U)W)E('-U<F4L('!L96%S90H@*B!S96YD(&%N
M(&5M86EL('1O('1H92!A=6AT;W(@=VET:"!A(&1U;7!E9"!O=71P=70@;V8@
M)&9T<"T^;',H)RXO)RP@3D547T944%]205=,25-4*3L*("H@=&\@9V5T('1H
M92!D871E(&9O<FUA="!S=7!P;W)T960N"B`J"B`J($!S:6YC92`Q+C,*("H@
M0&YA;64@3D547T944%]%4E)?1$%4149/4DU!5%]&04E,140*("H@0'-E92!.
M971?1E10.CIM9'1M*"DL($YE=%]&5%`Z.FQS*"D*("HO"F1E9FEN92@G3D54
M7T944%]%4E)?1$%4149/4DU!5%]&04E,140G+"`M,3$I.PH*+RHJ"B`J($5R
M<F]R(&-O9&4@=&\@:6YD:6-A=&4@=&AA="!T:&4@4TE:12!C;VUM86YD(&9A
M:6QE9`H@*B!4:&4@9&5T97)M:6YA=&EO;B!O9B!T:&4@9FEL97-I>F4@;V8@
M82!F:6QE(&9A:6QE9"X@16YS=7)E('1H870@>6]U<B!S97)V97(@<W5P<&]R
M=',@=&AE"B`J(%-)6D4@8V]M;6%N9"X*("H*("H@0'-I;F-E(#$N,PH@*B!`
M;F%M92!.151?1E107T524E]325I%7T9!24Q%1`H@*B!`<V5E($YE=%]&5%`Z
M.G-I>F4H*0H@*B\*9&5F:6YE*"=.151?1E107T524E]325I%7T9!24Q%1"<L
M("TQ,BD["@HO*BH*("H@17)R;W(@8V]D92!T;R!I;F1I8V%T92!T:&%T(&$@
M;&]C86P@9FEL92!C;W5L9"!N;W0@8F4@;W9E<G=R:71T96X*("H@66]U('-P
M96-I9FEE9"!N;W0@=&\@;W9E<G=R:71E(&9I;&5S+B!4:&5R969O<F4@=&AE
M(&QO8V%L(&9I;&4@:&%S(&YO="!B965N"B`J(&]V97)W<FET96XN($EF('EO
M=2!W86YT('1O(&=E="!T:&4@9FEL92!O=F5R=W)I=&5N+"!P;&5A<V4@<V5T
M('1H92!O<'1I;VX@=&\*("H@9&\@<V\N"B`J"B`J($!S:6YC92`Q+C,*("H@
M0&YA;64@3D547T944%]%4E)?3U9%4E=2251%3$]#04Q&24Q%7T9/4D))1$1%
M3@H@*B!`<V5E($YE=%]&5%`Z.F=E="@I+"!.971?1E10.CIG971296-U<G-I
M=F4H*0H@*B\*9&5F:6YE*"=.151?1E107T524E]/5D525U))5$5,3T-!3$9)
M3$5?1D]20DE$1$5.)RP@+3$S*3L*"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN
M9&EC871E('1H870@82!L;V-A;"!F:6QE(&-O=6QD(&YO="!B92!O=F5R=W)I
M='1E;@H@*B!!;'-O('EO=2!S<&5C:69I960@=&\@;W9E<G=R:71E('1H92!L
M;V-A;"!F:6QE('EO=2!W86YT('1O(&1O=VYL;V%D('1O+`H@*B!I="!H87,@
M;F]T(&)E96X@<&]S<VEB;&4@=&\@9&\@<V\N($-H96-K('1H870@>6]U(&AA
M=F4@=&AE(&%P<')O<')I871E(&%C8V5S<PH@*B!R:6=H=',@;VX@=&AE(&QO
M8V%L(&9I;&4@=&\@;W9E<G=R:71E(&ET+@H@*@H@*B!`<VEN8V4@,2XS"B`J
M($!N86UE($Y%5%]&5%!?15)27T]615)74DE414Q/0T%,1DE,15]&04E,140*
M("H@0'-E92!.971?1E10.CIG970H*2P@3F5T7T944#HZ9V5T4F5C=7)S:79E
M*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?3U9%4E=2251%3$]#04Q&24Q%
M7T9!24Q%1"<L("TQ-"D["@HO*BH*("H@17)R;W(@8V]D92!T;R!I;F1I8V%T
M92!T:&%T('1H92!F:6QE('EO=2!W86YT960@=&\@=7!L;V%D(&1O97,@;F]T
M(&5X:7-T"B`J(%1H92!F:6QE('EO=2!T<FEE9"!T;R!U<&QO860@9&]E<R!N
M;W0@97AI<W0N($5N<W5R92!T:&%T(&ET(&5X:7-T<RX*("H*("H@0'-I;F-E
M(#$N,PH@*B!`;F%M92!.151?1E107T524E],3T-!3$9)3$5.3U1%6$E35`H@
M*B!`<V5E($YE=%]&5%`Z.G!U="@I+"!.971?1E10.CIP=71296-U<G-I=F4H
M*0H@*B\*9&5F:6YE*"=.151?1E107T524E],3T-!3$9)3$5.3U1%6$E35"<L
M("TQ-2D["@HO*BH*("H@17)R;W(@8V]D92!T;R!I;F1I8V%T92!T:&%T(&$@
M<F5M;W1E(&9I;&4@8V]U;&0@;F]T(&)E(&]V97)W<FET=&5N"B`J(%EO=2!S
M<&5C:69I960@;F]T('1O(&]V97)W<FET92!F:6QE<RX@5&AE<F5F;W)E('1H
M92!R96UO=&4@9FEL92!H87,@;F]T(&)E96X*("H@;W9E<G=R:71E;BX@268@
M>6]U('=A;G0@=&\@9V5T('1H92!F:6QE(&]V97)W<FET96XL('!L96%S92!S
M970@=&AE(&]P=&EO;B!T;PH@*B!D;R!S;RX*("H*("H@0'-I;F-E(#$N,PH@
M*B!`;F%M92!.151?1E107T524E]/5D525U))5$5214U/5$5&24Q%7T9/4D))
M1$1%3@H@*B!`<V5E($YE=%]&5%`Z.G!U="@I+"!.971?1E10.CIP=71296-U
M<G-I=F4H*0H@*B\*9&5F:6YE*"=.151?1E107T524E]/5D525U))5$5214U/
M5$5&24Q%7T9/4D))1$1%3B<L("TQ-BD["@HO*BH*("H@17)R;W(@8V]D92!T
M;R!I;F1I8V%T92!T:&%T('1H92!U<&QO860@;V8@82!F:6QE(&9A:6QE9`H@
M*B!4:&4@=7!L;V%D('EO=2!T<FEE9"!F86EL960N($5N<W5R92!T:&%T('EO
M=2!H879E(&%P<')O<')I871E(&%C8V5S<R!R:6=H=',*("H@=&\@=7!L;V%D
M('1H92!D97-I<F5D(&9I;&4N"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA;64@
M3D547T944%]%4E)?55!,3T%$1DE,15]&04E,140*("H@0'-E92!.971?1E10
M.CIP=70H*2P@3F5T7T944#HZ<'5T4F5C=7)S:79E*"D*("HO"F1E9FEN92@G
M3D547T944%]%4E)?55!,3T%$1DE,15]&04E,140G+"`M,3<I.PH*+RHJ"B`J
M($5R<F]R(&-O9&4@=&\@:6YD:6-A=&4@=&AA="!Y;W4@<W!E8VEF:65D(&%N
M(&EN8V]R<F5C="!D:7)E8W1O<GD@<&%T:`H@*B!4:&4@<F5M;W1E('!A=&@@
M>6]U('-P96-I9FEE9"!S965M<R!N;W0@=&\@8F4@82!D:7)E8W1O<GDN($5N
M<W5R92!T:&%T"B`J('1H92!P871H('EO=2!S<&5C:69Y(&ES(&$@9&ER96-T
M;W)Y(&%N9"!T:&%T('1H92!P871H('-T<FEN9R!E;F1S('=I=&@*("H@82`O
M+@H@*@H@*B!`<VEN8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?15)27U)%34]4
M15!!5$A.3T1)4@H@*B!`<V5E($YE=%]&5%`Z.G!U=%)E8W5R<VEV92@I+"!.
M971?1E10.CIG971296-U<G-I=F4H*0H@*B\*9&5F:6YE*"=.151?1E107T52
M4E]214U/5$50051(3D]$25(G+"`M,3@I.PH*+RHJ"B`J($5R<F]R(&-O9&4@
M=&\@:6YD:6-A=&4@=&AA="!Y;W4@<W!E8VEF:65D(&%N(&EN8V]R<F5C="!D
M:7)E8W1O<GD@<&%T:`H@*B!4:&4@;&]C86P@<&%T:"!Y;W4@<W!E8VEF:65D
M('-E96US(&YO="!T;R!B92!A(&1I<F5C=&]R>2X@16YS=7)E('1H870*("H@
M=&AE('!A=&@@>6]U('-P96-I9GD@:7,@82!D:7)E8W1O<GD@86YD('1H870@
M=&AE('!A=&@@<W1R:6YG(&5N9',@=VET:`H@*B!A("\N"B`J"B`J($!S:6YC
M92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?3$]#04Q0051(3D]$25(*("H@
M0'-E92!.971?1E10.CIP=71296-U<G-I=F4H*2P@3F5T7T944#HZ9V5T4F5C
M=7)S:79E*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?3$]#04Q0051(3D]$
M25(G+"`M,3DI.PH*+RHJ"B`J($5R<F]R(&-O9&4@=&\@:6YD:6-A=&4@=&AA
M="!A(&QO8V%L(&1I<F5C=&]R>2!F86EL960@=&\@8F4@8W)E871E9`H@*B!9
M;W4@=')I960@=&\@8W)E871E(&$@;&]C86P@9&ER96-T;W)Y('1H<F]U9V@@
M9V5T4F5C=7)S:79E*"D@;65T:&]D+`H@*B!W:&EC:"!H87,@9F%I;&5D+B!%
M;G-U<F4@=&AA="!Y;W4@:&%V92!T:&4@87!P<F]P<FEA=&4@86-C97-S(')I
M9VAT<PH@*B!T;R!C<F5A=&4@:70N"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA
M;64@3D547T944%]%4E)?0U)%051%3$]#04Q$25)?1D%)3$5$"B`J($!S964@
M3F5T7T944#HZ9V5T4F5C=7)S:79E*"D*("HO"F1E9FEN92@G3D547T944%]%
M4E)?0U)%051%3$]#04Q$25)?1D%)3$5$)RP@+3(P*3L*"B\J*@H@*B!%<G)O
M<B!C;V1E('1O(&EN9&EC871E('1H870@=&AE('!R;W9I9&5D(&AO<W1N86UE
M('=A<R!I;F-O<G)E8W0*("H@5&AE(&AO<W1N86UE('EO=2!P<F]V:61E9"!W
M87,@:6YV86QI9"X@16YS=7)E('1O('!R;W9I9&4@96ET:&5R(&$*("H@9G5L
M;"!Q=6%L:69I960@9&]M86EN(&YA;64@;W(@86X@25`@861D<F5S<RX*("H*
M("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E107T524E](3U-43D%-14Y/
M4U1224Y'"B`J($!S964@3F5T7T944#HZ<V5T2&]S=&YA;64H*0H@*B\*9&5F
M:6YE*"=.151?1E107T524E](3U-43D%-14Y/4U1224Y')RP@+3(Q*3L*"B\J
M*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E('1H870@=&AE('!R;W9I9&5D
M('!O<G0@=V%S(&EN8V]R<F5C=`H@*B!4:&4@<&]R="!N=6UB97(@>6]U('!R
M;W9I9&5D('=A<R!I;G9A;&ED+B!%;G-U<F4@=&\@<')O=FED92!E:71H97(@
M80H@*B!A(&YU;65R:6,@<&]R="!N=6UB97(@9W)E871E<B!Z97)O+@H@*@H@
M*B!`<VEN8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?15)27U!/4E1,15-36D52
M3PH@*B!`<V5E($YE=%]&5%`Z.G-E=%!O<G0H*0H@*B\*9&5F:6YE*"=.151?
M1E107T524E]03U)43$534UI%4D\G+"`M,C(I.PH*+RHJ"B`J($5R<F]R(&-O
M9&4@=&\@:6YD:6-A=&4@=&AA="!Y;W4@<')O=FED960@86X@:6YV86QI9"!M
M;V1E(&-O;G-T86YT"B`J(%1H92!M;V1E(&-O;G-T86YT('EO=2!P<F]V:61E
M9"!W87,@:6YV86QI9"X@66]U(&UA>2!O;FQY('!R;W9I9&4*("H@1E107T%3
M0TE)(&]R($944%]"24Y!4EDN"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA;64@
M3D547T944%]%4E)?3D]-3T1%0T].4U0*("H@0'-E92!.971?1E10.CIS971-
M;V1E*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?3D]-3T1%0T].4U0G+"`M
M,C,I.PH*+RHJ"B`J($5R<F]R(&-O9&4@=&\@:6YD:6-A=&4@=&AA="!Y;W4@
M<')O=FED960@86X@:6YV86QI9"!T:6UE;W5T"B`J(%1H92!T:6UE;W5T('EO
M=2!P<F]V:61E9"!W87,@:6YV86QI9"X@66]U(&AA=F4@=&\@<')O=FED92!A
M('1I;65O=70@9W)E871E<@H@*B!O<B!E<75A;"!T;R!Z97)O+@H@*@H@*B!`
M<VEN8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?15)27U1)345/551,15-36D52
M3PH@*B!`<V5E($YE=%]&5%`Z.DYE=%]&5%`H*2P@3F5T7T944#HZ<V5T5&EM
M96]U="@I"B`J+PID969I;F4H)TY%5%]&5%!?15)27U1)345/551,15-36D52
M3R<L("TR-"D["@HO*BH*("H@17)R;W(@8V]D92!T;R!I;F1I8V%T92!T:&%T
M('EO=2!P<F]V:61E9"!A;B!I;G9A;&ED('1I;65O=70*("H@06X@97)R;W(@
M;V-C=7)E9"!W:&EL92!S971T:6YG('1H92!T:6UE;W5T+B!%;G-U<F4@=&AA
M="!Y;W4@<')O=FED92!A"B`J('9A;&ED(&EN=&5G97(@9F]R('1H92!T:6UE
M;W5N="!A;F0@=&AA="!Y;W5R(%!(4"!I;G-T86QL871I;VX@=V]R:W,*("H@
M8V]R<F5C=&QY+@H@*@H@*B!`<VEN8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?
M15)27U-%5%1)345/551?1D%)3$5$"B`J($!S964@3F5T7T944#HZ3F5T7T94
M4"@I+"!.971?1E10.CIS9714:6UE;W5T*"D*("HO"F1E9FEN92@G3D547T94
M4%]%4E)?4T545$E-14]55%]&04E,140G+"`M,C4I.PH*+RHJ"B`J($5R<F]R
M(&-O9&4@=&\@:6YD:6-A=&4@=&AA="!T:&4@<')O=FED960@97AT96YS:6]N
M(&9I;&4@9&]E<VXG="!E>&ES=`H@*B!4:&4@<')O=FED960@97AT96YS:6]N
M(&9I;&4@9&]E<R!N;W0@97AI<W0N($5N<W5R92!T;R!P<F]V:61E9"!A;@H@
M*B!E>&ES=&%N="!E>'1E;G-I;VX@9FEL92X*("H*("H@0'-I;F-E(#$N,PH@
M*B!`;F%M92!.151?1E107T524E]%6%1&24Q%3D]415A)4U0*("H@0'-E92!.
M971?1E10.CIG971%>'1E;G-I;VY&:6QE*"D*("HO"F1E9FEN92@G3D547T94
M4%]%4E)?15A41DE,14Y/5$5825-4)RP@+3(V*3L*"B\J*@H@*B!%<G)O<B!C
M;V1E('1O(&EN9&EC871E('1H870@=&AE('!R;W9I9&5D(&5X=&5N<VEO;B!F
M:6QE(&ES(&YO="!R96%D86)L90H@*B!4:&4@<')O=FED960@97AT96YS:6]N
M(&9I;&4@:7,@;F]T(')E861A8FQE+B!%;G-U<F4@=&\@:&%V92!S=69F:6-I
M96YT"B`J(&%C8V5S<R!R:6=H=',@9F]R(&ET+@H@*@H@*B!`<VEN8V4@,2XS
M"B`J($!N86UE($Y%5%]&5%!?15)27T585$9)3$5214%$7T9!24Q%1`H@*B!`
M<V5E($YE=%]&5%`Z.F=E=$5X=&5N<VEO;D9I;&4H*0H@*B\*9&5F:6YE*"=.
M151?1E107T524E]%6%1&24Q%4D5!1%]&04E,140G+"`M,C<I.PH*+RHJ"B`J
M($5R<F]R(&-O9&4@=&\@:6YD:6-A=&4@=&AA="!T:&4@9&5L971I;VX@;V8@
M82!F:6QE(&9A:6QE9`H@*B!4:&4@<W!E8VEF:65D(&9I;&4@8V]U;&0@;F]T
M(&)E(&1E;&5T960N($5N<W5R92!T;R!H879E('-U9F9I8VEE;G0*("H@86-C
M97-S(')I9VAT<R!T;R!D96QE=&4@=&AE(&9I;&4N"B`J"B`J($!S:6YC92`Q
M+C,*("H@0&YA;64@3D547T944%]%4E)?15A41DE,15)%041?1D%)3$5$"B`J
M($!S964@3F5T7T944#HZ<FTH*0H@*B\*9&5F:6YE*"=.151?1E107T524E]$
M14Q%5$5&24Q%7T9!24Q%1"<L("TR."D["@HO*BH*("H@17)R;W(@8V]D92!T
M;R!I;F1I8V%T92!T:&%T('1H92!D96QE=&EO;B!O9B!A(&1I<F5C=&]R>2!F
M86EL9`H@*B!4:&4@<W!E8VEF:65D(&9I;&4@8V]U;&0@;F]T(&)E(&1E;&5T
M960N($5N<W5R92!T;R!H879E('-U9F9I8VEE;G0*("H@86-C97-S(')I9VAT
M<R!T;R!D96QE=&4@=&AE(&9I;&4N"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA
M;64@3D547T944%]%4E)?15A41DE,15)%041?1D%)3$5$"B`J($!S964@3F5T
M7T944#HZ<FTH*0H@*B\*9&5F:6YE*"=.151?1E107T524E]$14Q%5$5$25)?
M1D%)3$5$)RP@+3(Y*3L*"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E
M('1H870@=&AE(&1I<F5C=&]R>2!L:7-T:6YG(&9A:6QE9`H@*B!02%`@8V]U
M;&0@;F]T(&QI<W0@=&AE(&1I<F5C=&]R>2!C;VYT96YT<R!O;B!T:&4@<V5R
M=F5R+B!%;G-U<F4*("H@=&AA="!Y;W5R('-E<G9E<B!I<R!C;VYF:6=U<F5D
M(&%P<')O<')I871E+@H@*@H@*B!`<VEN8V4@,2XS"B`J($!N86UE($Y%5%]&
M5%!?15)27U)!5T1)4DQ)4U1?1D%)3$5$"B`J($!S964@3F5T7T944#HZ;',H
M*0H@*B\*9&5F:6YE*"=.151?1E107T524E]205=$25),25-47T9!24Q%1"<L
M("TS,"D["@HO*BH*("H@17)R;W(@8V]D92!T;R!I;F1I8V%T92!T:&%T('1H
M92!D:7)E8W1O<GD@;&ES=&EN9R!F86EL960*("H@5&AE(&1I<F5C=&]R>2!L
M:7-T:6YG(&9O<FUA="!Y;W5R('-E<G9E<B!U<V5S('-E96US(&YO="!T;PH@
M*B!B92!S=7!P;W)T960@8GD@3F5T7T944"X@4&QE87-E('-E;F0@=&AE(&]U
M='!U="!O9B!T:&4*("H@8V%L;"!L<R@G+B\G+"!.151?1E107U)!5TQ)4U0I
M.R!T;R!T:&4@875T:&]R(&]F('1H:7,*("H@8VQA<W,@=&\@9V5T(&ET('-U
M<'!O<G1E9"X*("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E107T52
M4E]$25),25-47U5.4U504$]25$5$"B`J($!S964@3F5T7T944#HZ;',H*0H@
M*B\*9&5F:6YE*"=.151?1E107T524E]$25),25-47U5.4U504$]25$5$)RP@
M+3,Q*3L*"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E(&9A:6QE9"!D
M:7-C;VYN96-T:6YG"B`J(%1H:7,@97)R;W(@8V]D92!I;F1I8V%T97,L('1H
M870@9&ES8V]N;F5C=&EO;B!W87,@;F]T('!O<W-I8FQE+@H@*@H@*B!`<VEN
M8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?15)27T1)4T-/3DY%0U1?1D%)3$5$
M"B`J($!S964@3F5T7T944#HZ9&ES8V]N;F5C="@I"B`J+PID969I;F4H)TY%
M5%]&5%!?15)27T1)4T-/3DY%0U1?1D%)3$5$)RP@+3,R*3L*"B\J*@H@*B!%
M<G)O<B!C;V1E('1O(&EN9&EC871E('1H870@=&AE('5S97)N86UE('EO=2!P
M<F]V:61E9"!W87,@:6YV86QI9"X*("H@0VAE8VL@=&AA="!Y;W4@<')O=FED
M960@82!N;VXM96UP='D@<W1R:6YG(&%S('1H92!U<V5R;F%M92X*("H*("H@
M0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E107T524E]54T523D%-14Y/4U12
M24Y'"B`J($!S964@3F5T7T944#HZ<V5T57-E<FYA;64H*0H@*B\*9&5F:6YE
M*"=.151?1E107T524E]54T523D%-14Y/4U1224Y')RP@+3,S*3L*"B\J*@H@
M*B!%<G)O<B!C;V1E('1O(&EN9&EC871E('1H870@=&AE('5S97)N86UE('EO
M=2!P<F]V:61E9"!W87,@:6YV86QI9"X*("H@0VAE8VL@=&AA="!Y;W4@<')O
M=FED960@82!N;VXM96UP='D@<W1R:6YG(&%S('1H92!U<V5R;F%M92X*("H*
M("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E107T524E]005-35T]21$Y/
M4U1224Y'"B`J($!S964@3F5T7T944#HZ<V5T4&%S<W=O<F0H*0H@*B\*9&5F
M:6YE*"=.151?1E107T524E]005-35T]21$Y/4U1224Y')RP@+3,S*3L*"B\J
M*@H@*B!#;&%S<R!F;W(@8V]M9F]R=&%B;&4@1E10+6-O;6UU;FEC871I;VX*
M("H*("H@5&AI<R!C;&%S<R!P<F]V:61E<R!C;VUF;W)T86)L92!C;VUM=6YI
M8V%T:6]N('=I=&@@1E10+7-E<G9E<G,N(%EO=2!M87D@9&\@979E<GET:&EN
M9PH@*B!E;F%B;&5D(&)Y('1H92!02%`M1E10+65X=&5N<VEO;B!A;F0@9G5R
M=&AE<B!F=6YC=&EO;F%L:71I97,L(&QI:V4@<F5C=7)S:79E+61E;&5T:6]N
M+`H@*B`M=7`M(&%N9"`M9&]W;FQO860N($%N;W1H97(@9F5A='5R92!I<R!T
M;R!C<F5A=&4@9&ER96-T;W)I97,@<F5C=7)S:79E;'DN"B`J"B`J($!L:6-E
M;G-E("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0
M($QI8V5N<V4@,RXP"B`J($!C871E9V]R>2`@3F5T=V]R:VEN9PH@*B!`<&%C
M:V%G92`@($944`H@*B!`875T:&]R("`@(%1O8FEA<R!38VAL:71T(#QT;V)Y
M0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@,3DY-RTR,#`U(%1H92!02%`@1W)O
M=7`*("H@0'9E<G-I;VX@("!296QE87-E.B`Q+C,N,0H@*B!`;&EN:R`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92].971?1E10"B`J($!S:6YC
M92`@("`@,"XP+C$*("H@0&%C8V5S<R`@("!P=6)L:6,*("HO"F-L87-S($YE
M=%]&5%`@97AT96YD<R!014%2(`I["B`@("`O*BH*("`@("`J(%1H92!H;W-T
M('1O(&-O;FYE8W0@=&\*("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E
M"B`@("`@*B!`=F%R("`@("!S=')I;F<*("`@("`J+PH@("`@"B`@("!V87(@
M)%]H;W-T;F%M93L*"B`@("`O*BH*("`@("`J(%1H92!P;W)T(&9O<B!F='`M
M8V]N;F5C=&EO;B`H<W1A;F1A<F0@:7,@,C$I"B`@("`@*@H@("`@("H@0&%C
M8V5S<R`@<')I=F%T90H@("`@("H@0'9A<B`@("`@:6YT"B`@("`@*B\*("`@
M(`H@("`@=F%R("1?<&]R="`](#(Q.PH*("`@("\J*@H@("`@("H@5&AE('5S
M97)N86UE(&9O<B!L;V=I;@H@("`@("H*("`@("`J($!A8V-E<W,@('!R:79A
M=&4*("`@("`J($!V87(@("`@('-T<FEN9PH@("`@("HO"B`@("`*("`@('9A
M<B`D7W5S97)N86UE.PH*("`@("\J*@H@("`@("H@5&AE('!A<W-W;W)D(&9O
M<B!L;V=I;@H@("`@("H*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J
M($!V87(@("`@('-T<FEN9PH@("`@("HO"B`@("`*("`@('9A<B`D7W!A<W-W
M;W)D.PH*("`@("\J*@H@("`@("H@1&5T97)M:6YE('=H971H97(@=&\@=7-E
M('!A<W-I=F4M;6]D92`H=')U92D@;W(@86-T:79E+6UO9&4@*&9A;'-E*0H@
M("`@("H*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J($!V87(@("`@
M(&)O;VP*("`@("`J+PH@("`@"B`@("!V87(@)%]P87-S=CL*"B`@("`O*BH*
M("`@("`J(%1H92!S=&%N9&%R9"!M;V1E(&9O<B!F='`M=')A;G-F97(*("`@
M("`J"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B!`=F%R("`@("!I
M;G0*("`@("`J+PH@("`@"B`@("!V87(@)%]M;V1E(#T@1E107T))3D%263L*
M"B`@("`O*BH*("`@("`J(%1H:7,@:&]L9',@=&AE(&AA;F1L92!F;W(@=&AE
M(&9T<"UC;VYN96-T:6]N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<')I=F%T
M90H@("`@("H@0'9A<B`@("`@<F5S;W5R8V4*("`@("`J+PH@("`@"B`@("!V
M87(@)%]H86YD;&4["@H@("`@+RHJ"B`@("`@*B!#;VYT86EN<R!T:&4@=&EM
M96]U="!F;W(@1E10(&]P97)A=&EO;G,*("`@("`J"B`@("`@*B!`86-C97-S
M("!P<FEV871E"B`@("`@*B!`=F%R("`@("!I;G0*("`@("`J($!S:6YC92`@
M(#$N,PH@("`@("HO"B`@("`*("`@('9A<B`D7W1I;65O=70@/2`Y,#L*("`@
M("`@("`*("`@("\J*@H@("`@("H@4V%V97,@9FEL92UE>'1E;G-I;VYS(&9O
M<B!A<V-I:2T@86YD(&)I;F%R>2UM;V1E"B`@("`@*@H@("`@("H@5&AE(&%R
M<F%Y(&-O;G1A:6YS(#(@<W5B+6%R<F%Y<R`H(F%S8VEI(B!A;F0@(F)I;F%R
M>2(I+"!W:&EC:"!B;W1H(&-O;G1A:6X*("`@("`J(&9I;&4M97AT96YS:6]N
M<R!W:71H;W5T('1H92`B+B(@*"(N<&AP(B`](")P:'`B*2X*("`@("`J"B`@
M("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B!`=F%R("`@("!A<G)A>0H@
M("`@("HO"B`@("`*("`@('9A<B`D7V9I;&5?97AT96YS:6]N<SL*"B`@("`O
M*BH*("`@("`J(&QS(&UA=&-H"B`@("`@*B!-871C:&5S('1H92!L<R!E;G1R
M:65S(&%G86EN<W0@82!R96=E>"!A;F0@;6%P<R!T:&4@<F5S=6QT:6YG(&%R
M<F%Y('1O('-P96%K:6YG(&YA;65S"B`@("`@*@H@("`@("H@0&%C8V5S<R`@
M<')I=F%T90H@("`@("H@0'9A<B`@("`@87)R87D*("`@("`J($!S:6YC92`@
M(#$N,PH@("`@("HO"B`@("`*("`@('9A<B`D7VQS7VUA=&-H(#T@87)R87DH
M"B`@("`@("`@)W5N:7@G("`@(#T^(&%R<F%Y*`H@("`@("`@("`@("`G<&%T
M=&5R;B<@/3X@)R\H/SHH9"E\+BDH6W)W>'0M72LI7',K*%QW*RE<<RLH6UQW
M7&1=*RE<<RLH6UQW7&1=*RE<<RLH7'<K*5QS*RA<4RM<<RM<4RM<<RM<4RLI
M7',K*"XK*2\G+`H@("`@("`@("`@("`G;6%P)R`@("`@/3X@87)R87DH)VYA
M;64G/3XX+"=S:7IE)ST^-BPG<FEG:'1S)ST^,BPG=7-E<B<]/C0L)V=R;W5P
M)ST^-2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9I;&5S7VEN
M<VED92<]/C,L)V1A=&4G/3XW+"=I<U]D:7(G/3XQ*0H@("`@("`@("DL"B`@
M("`@("`@)W=I;F1O=W,G(#T^(&%R<F%Y*`H@("`@("`@("`@("`G<&%T=&5R
M;B<@/3X@)R\H+BLI7',K*"XK*5QS*R@H/$1)4CXI?%LP+3E=*RE<<RLH+BLI
M+R<L"B`@("`@("`@("`@("=M87`G("`@("`]/B!A<G)A>2@G;F%M92<]/C4L
M)V1A=&4G/3XQ+"=I<U]D:7(G/3XS*0H@("`@("`@("D*("`@("D["B`@("`*
M("`@("\J*@H@("`@("H@;6%T8VAE<@H@("`@("H@4W1O<F5S('1H92!M871C
M:&5R(&9O<B!T:&4@8W5R<F5N="!C;VYN96-T:6]N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R`@<')I=F%T90H@("`@("H@0'9A<B`@("`@87)R87D*("`@("`J
M($!S:6YC92`@(#$N,PH@("`@("HO"B`@("!V87(@)%]M871C:&5R(#T@;G5L
M;#L*("`@(`H@("`@+RHJ"B`@("`@*B!(;VQD<R!A;&P@3F5T7T944%]/8G-E
M<G9E<B!O8FIE8W1S(`H@("`@("H@=&AA="!W:7-H('1O(&)E(&YO=&EF:65D
M(&]F(&YE=R!M97-S86=E<RX*("`@("`J"B`@("`@*B!`=F%R("`@("!A<G)A
M>0H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("H@0'-I;F-E("`@,2XS
M"B`@("`@*B\*("`@(`H@("`@=F%R("1?;&ES=&5N97)S(#T@87)R87DH*3L*
M"B`@("`O*BH*("`@("`J(%1H:7,@9V5N97)A=&5S(&$@;F5W($944"U/8FIE
M8W0N(%1H92!&5%`M8V]N;F5C=&EO;B!W:6QL(&YO="!B92!E<W1A8FQI<VAE
M9"P@>65T+@H@("`@("H@66]U(&-A;B!L96%V92`D:&]S="!A;F0@)'!O<G0@
M8FQA;FLL(&EF('EO=2!W86YT+B!4:&4@)&AO<W0@=VEL;"!N;W0@8F4@<V5T
M"B`@("`@*B!A;F0@=&AE("1P;W)T('=I;&P@8F4@;&5F="!A="`R,2X@66]U
M(&AA=F4@=&\@<V5T('1H92`D:&]S="!M86YU86QY(&)E9F]R90H@("`@("H@
M=')Y:6YG('1O(&-O;FYE8W0@;W(@=VET:"!T:&4@8V]N;F5C="@I(&UE=&AO
M9"X*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!P87)A
M;2`@('-T<FEN9R`D:&]S="`@("`H;W!T:6]N86PI(%1H92!H;W-T;F%M92`*
M("`@("`J($!P87)A;2`@(&EN="`@("`D<&]R="`@("`H;W!T:6]N86PI(%1H
M92!P;W)T"B`@("`@*B!`<&%R86T@("!I;G0@("`@)'1I;65O=70@*&]P=&EO
M;F%L*2!3971S('1H92!S=&%N9&%R9"!T:6UE;W5T"B`@("`@*B!`<F5T=7)N
M("!V;VED"B`@("`@*B!`<V5E("`@("!.971?1E10.CIS971(;W-T;F%M92@I
M+"!.971?1E10.CIS9710;W)T*"DL($YE=%]&5%`Z.F-O;FYE8W0H*0H@("`@
M("HO"B`@("`*("`@(&9U;F-T:6]N($YE=%]&5%`H)&AO<W0@/2!N=6QL+"`D
M<&]R="`](&YU;&PL("1T:6UE;W5T(#T@.3`I"B`@("!["B`@("`@("`@)'1H
M:7,M/E!%05(H*3L*("`@("`@("!I9B`H:7-S970H)&AO<W0I*2!["B`@("`@
M("`@("`@("1T:&ES+3YS971(;W-T;F%M92@D:&]S="D["B`@("`@("`@?0H@
M("`@("`@(&EF("AI<W-E="@D<&]R="DI('L*("`@("`@("`@("`@)'1H:7,M
M/G-E=%!O<G0H)'!O<G0I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7W1I
M;65O=70@/2`D=&EM96]U=#L*("`@("`@("`D=&AI<RT^7V9I;&5?97AT96YS
M:6]N<UM&5%!?05-#24E=(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^7V9I
M;&5?97AT96YS:6]N<UM&5%!?0DE.05)972`](&%R<F%Y*"D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!4:&ES(&9U;F-T:6]N(&=E;F5R871E<R!T:&4@1E10
M+6-O;FYE8W1I;VXN(%EO=2!C86X@;W!T:6]N86QL>2!D969I;F4@80H@("`@
M("H@:&]S=&YA;64@86YD+V]R(&$@<&]R="X@268@>6]U(&1O('-O+"!T:&ES
M(&1A=&$@:7,@<W1O<F5D(&EN<VED92!T:&4@;V)J96-T+@H@("`@("H*("`@
M("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'!A<F%M("`@<W1R:6YG("1H
M;W-T("`@("AO<'1I;VYA;"D@5&AE($AO<W1N86UE"B`@("`@*B!`<&%R86T@
M("!I;G0@("`@)'!O<G0@("`@*&]P=&EO;F%L*2!4:&4@4&]R="`*("`@("`J
M($!R971U<FX@(&UI>&5D("`@("`@("`@("!4<G5E(&]N('-U8V-E<W,L(&]T
M:&5R=VES92!014%2.CI%<G)O<@H@("`@("H@0'-E92`@("`@3D547T944%]%
M4E)?0T].3D5#5%]&04E,140*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!C
M;VYN96-T*"1H;W-T(#T@;G5L;"P@)'!O<G0@/2!N=6QL*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?;6%T8VAE<B`](&YU;&P["B`@("`@("`@:68@*&ES<V5T
M*"1H;W-T*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T2&]S=&YA;64H)&AO
M<W0I.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)'!O<G0I*2!["B`@
M("`@("`@("`@("1T:&ES+3YS9710;W)T*"1P;W)T*3L*("`@("`@("!]"B`@
M("`@("`@)&AA;F1L92`]($!F='!?8V]N;F5C="@D=&AI<RT^9V5T2&]S=&YA
M;64H*2P@)'1H:7,M/F=E=%!O<G0H*2P@)'1H:7,M/E]T:6UE;W5T*3L*("`@
M("`@("!I9B`H(21H86YD;&4I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*")#;VYN96-T:6]N('1O(&AO<W0@9F%I;&5D(BP@3D54
M7T944%]%4E)?0T].3D5#5%]&04E,140I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1T:&ES+3Y?:&%N9&QE(#TF("1H86YD;&4["B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%1H:7,@9G5N8W1I;VX@8VQO<V4@=&AE($944"UC;VYN96-T:6]N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<F5T=7)N("!B
M;V]L?%!%05)?17)R;W(@4F5T=7)N<R!T<G5E(&]N('-U8V-E<W,L(%!%05)?
M17)R;W(@;VX@9F%I;'5R90H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N(&1I
M<V-O;FYE8W0H*0H@("`@>PH@("`@("`@("1R97,@/2!`9G1P7V-L;W-E*"1T
M:&ES+3Y?:&%N9&QE*3L*("`@("`@("!I9B`H(21R97,I('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T1I<V-O;FYE8W0@9F%I;&5D
M+B<L($Y%5%]&5%!?15)27T1)4T-/3DY%0U1?1D%)3$5$*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4
M:&ES(&QO9V=E<R!Y;W4@:6YT;R!T:&4@9G1P+7-E<G9E<BX@66]U(&%R92!F
M<F5E('1O('-P96-I9GD@=7-E<FYA;64@86YD('!A<W-W;W)D"B`@("`@*B!I
M;B!T:&ES(&UE=&AO9"X@268@>6]U('-P96-I9GD@:70L('1H92!V86QU97,@
M=VEL;"!B92!T86ME;B!I;G1O('1H92!C;W)R97-P;VYD:6YG"B`@("`@*B!A
M='1R:6)U=&5S+"!I9B!D;R!N;W0@<W!E8VEF>2P@=&AE(&%T=')I8G5T97,@
M87)E('1A:V5N+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@
M("H@0'!A<F%M("`@<W1R:6YG("1U<V5R;F%M92`@*&]P=&EO;F%L*2!4:&4@
M=7-E<FYA;64@=&\@=7-E(`H@("`@("H@0'!A<F%M("`@<W1R:6YG("1P87-S
M=V]R9"`@*&]P=&EO;F%L*2!4:&4@<&%S<W=O<F0@=&\@=7-E"B`@("`@*B!`
M<F5T=7)N("!M:7AE9"`@("`@("`@("`@("!4<G5E(&]N('-U8V-E<W,L(&]T
M:&5R=VES92!014%2.CI%<G)O<@H@("`@("H@0'-E92`@("`@3D547T944%]%
M4E)?3$]'24Y?1D%)3$5$"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@;&]G
M:6XH)'5S97)N86UE(#T@;G5L;"P@)'!A<W-W;W)D(#T@;G5L;"D*("`@('L*
M("`@("`@("!I9B`H(6ES<V5T*"1U<V5R;F%M92DI('L*("`@("`@("`@("`@
M)'5S97)N86UE(#T@)'1H:7,M/F=E=%5S97)N86UE*"D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'1H:7,M/G-E=%5S97)N86UE*"1U<V5R;F%M
M92D["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES<V5T*"1P87-S=V]R9"DI
M('L*("`@("`@("`@("`@)'!A<W-W;W)D(#T@)'1H:7,M/F=E=%!A<W-W;W)D
M*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/G-E=%!A
M<W-W;W)D*"1P87-S=V]R9"D["B`@("`@("`@?0H*("`@("`@("`D<F5S(#T@
M0&9T<%]L;V=I;B@D=&AI<RT^7VAA;F1L92P@)'5S97)N86UE+"`D<&%S<W=O
M<F0I.PH*("`@("`@("!I9B`H(21R97,I('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*")5;F%B;&4@=&\@;&]G:6XB+"!.151?1E10
M7T524E],3T=)3E]&04E,140I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%1H:7,@8VAA;F=E<R!T:&4@8W5R<F5N=&QY('5S960@9&ER96-T;W)Y
M+B!9;W4@8V%N('5S92!E:71H97(@86X@86)S;VQU=&4*("`@("`J(&1I<F5C
M=&]R>2UP871H("AE+F<N("(O:&]M92]B;&%H(BD@;W(@82!R96QA=&EV92!O
M;F4@*&4N9RX@(BXN+W1E<W0B*2X*("`@("`J"B`@("`@*B!`86-C97-S("!P
M=6)L:6,*("`@("`J($!P87)A;2`@('-T<FEN9R`D9&ER("!4:&4@9&ER96-T
M;W)Y('1O(&=O('1O+@H@("`@("H@0')E='5R;B`@;6EX960@("`@("`@(%1R
M=64@;VX@<W5C8V5S<RP@;W1H97)W:7-E(%!%05(Z.D5R<F]R"B`@("`@*B!`
M<V5E("`@("!.151?1E107T524E]$25)#2$%.1T5?1D%)3$5$"B`@("`@*B\*
M("`@(`H@("`@9G5N8W1I;VX@8V0H)&1I<BD*("`@('L*("`@("`@("`D97)G
M(#T@0&9T<%]C:&1I<B@D=&AI<RT^7VAA;F1L92P@)&1I<BD["B`@("`@("`@
M:68@*"$D97)G*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@B1&ER96-T;W)Y(&-H86YG92!F86EL960B+"!.151?1E107T524E]$
M25)#2$%.1T5?1D%)3$5$*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3:&]W)W,@>6]U('1H92!A8W1U86P@<&%T:"!O;B!T:&4@<V5R=F5R"B`@
M("`@*B!4:&ES(&9U;F-T:6]N('%U97-T:6]N<R!T:&4@9G1P+6AA;F1L92!F
M;W(@=&AE(&%C='5A;"!S96QE8W1E9"!P871H(&%N9"!R971U<FYS(&ET+@H@
M("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0')E='5R;B`@
M;6EX960@("`@("`@(%1H92!A8W1U86P@<&%T:"!O<B!014%2.CI%<G)O<@H@
M("`@("H@0'-E92`@("`@3D547T944%]%4E)?1$5415)-24Y%4$%42%]&04E,
M140*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!P=V0H*0H@("`@>PH@("`@
M("`@("1R97,@/2!`9G1P7W!W9"@D=&AI<RT^7VAA;F1L92D["B`@("`@("`@
M:68@*"$D<F5S*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@86-T=6%L('!A=&@N(BP@
M3D547T944%]%4E)?1$5415)-24Y%4$%42%]&04E,140I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J(%1H:7,@=V]R:W,@<VEM:6QA<B!T;R!T:&4@
M;6MD:7(M8V]M;6%N9"!O;B!Y;W5R(&QO8V%L(&UA8VAI;F4N(%EO=2!C86X@
M96ET:&5R(&=I=F4*("`@("`J(&ET(&%N(&%B<V]L=71E(&]R(')E;&%T:79E
M('!A=&@N(%1H92!R96QA=&EV92!P871H('=I;&P@8F4@8V]M<&QE=&5D('=I
M=&@@=&AE(&%C='5A;`H@("`@("H@<V5L96-T960@<V5R=F5R+7!A=&@N("AS
M964Z('!W9"@I*0H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@
M("H@0'!A<F%M("`@<W1R:6YG("1D:7(@("`@("`@06)S;VQU=&4@;W(@<F5L
M871I=F4@9&ER+7!A=&@*("`@("`J($!P87)A;2`@(&)O;VP@("`D<F5C=7)S
M:79E("AO<'1I;VYA;"D@0W)E871E(&%L;"!N965D960@9&ER96-T;W)I97,*
M("`@("`J($!R971U<FX@(&UI>&5D("`@("`@("`@("`@(%1R=64@;VX@<W5C
M8V5S<RP@;W1H97)W:7-E(%!%05(Z.D5R<F]R"B`@("`@*B!`<V5E("`@("!.
M151?1E107T524E]#4D5!5$5$25)?1D%)3$5$"B`@("`@*B\*("`@(`H@("`@
M9G5N8W1I;VX@;6MD:7(H)&1I<BP@)')E8W5R<VEV92`](&9A;'-E*0H@("`@
M>PH@("`@("`@("1D:7(@/2`D=&AI<RT^7V-O;G-T<G5C=%]P871H*"1D:7(I
M.PH@("`@("`@("1S879E9&ER(#T@)'1H:7,M/G!W9"@I.PH@("`@("`@("1T
M:&ES+3YP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["B`@
M("`@("`@)&4@/2`D=&AI<RT^8V0H)&1I<BD["B`@("`@("`@)'1H:7,M/G!O
M<$5R<F]R2&%N9&QI;F<H*3L*("`@("`@("!I9B`H)&4@/3T]('1R=64I('L*
M("`@("`@("`@("`@)'1H:7,M/F-D*"1S879E9&ER*3L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YC9"@D<V%V
M961I<BD["B`@("`@("`@:68@*"1R96-U<G-I=F4@/3T](&9A;'-E*7L*("`@
M("`@("`@("`@)')E<R`]($!F='!?;6MD:7(H)'1H:7,M/E]H86YD;&4L("1D
M:7(I.PH@("`@("`@("`@("!I9B`H(21R97,I('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B0W)E871I;VX@;V8@)R1D:7(G
M(&9A:6QE9"(L($Y%5%]&5%!?15)27T-214%4141)4E]&04E,140I.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I
M9BAS=')P;W,H)&1I<BP@)R\G*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^;6MD:7(H)&1I<BQF86QS92D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)'!O<R`](#`["B`@("`@("`@("`@("1R97,@
M/2`D=&AI<RT^;6MD:7(H9&ER;F%M92@D9&ER*2P@=')U92D["B`@("`@("`@
M("`@("1R97,@/2`D=&AI<RT^;6MD:7(H)&1I<BP@9F%L<V4I.PH@("`@("`@
M("`@("!I9B`H)')E<R`A/3T@=')U92D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1R97,["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N('1R
M=64["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!M971H
M;V0@=')I97,@97AE8W5T:6YG(&$@8V]M;6%N9"!O;B!T:&4@9G1P+"!U<VEN
M9R!3251%($5814,N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@
M("`@*B!`<&%R86T@("!S=')I;F<@)&-O;6UA;F0@5&AE(&-O;6UA;F0@=&\@
M97AE8W5T90H@("`@("H@0')E='5R;B`@;6EX960@("`@("`@("`@(%1H92!R
M97-U;'0@;V8@=&AE(&-O;6UA;F0@*&EF('-U8V-E<W-F=6QL*2P@;W1H97)W
M:7-E(%!%05(Z.D5R<F]R"B`@("`@*B!`<V5E("`@("!.151?1E107T524E]%
M6$5#7T9!24Q%1`H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N(&5X96-U=&4H
M)&-O;6UA;F0I"B`@("!["B`@("`@("`@)')E<R`]($!F='!?97AE8R@D=&AI
M<RT^7VAA;F1L92P@)&-O;6UA;F0I.PH@("`@("`@(&EF("@A)')E<RD@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D5X96-U=&EO
M;B!O9B!C;VUM86YD("<D8V]M;6%N9"<@9F%I;&5D+B(L($Y%5%]&5%!?15)2
M7T5814-?1D%)3$5$*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@)')E<SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!%
M>&5C=71E(&$@4TE412!C;VUM86YD(&]N('1H92!S97)V97(*("`@("`J(%1H
M:7,@;65T:&]D('1R:65S('1O(&5X96-U=&4@82!3251%(&-O;6UA;F0@;VX@
M=&AE(&9T<"!S97)V97(N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC
M"B`@("`@*B!`<&%R86T@("!S=')I;F<@)&-O;6UA;F0@("!4:&4@8V]M;6%N
M9"!W:71H('!A<F%M971E<G,@=&\@97AE8W5T90H@("`@("H@0')E='5R;B`@
M;6EX960@("`@("`@("`@("`@5')U92!I9B!S=6-C97-S9G5L+"!O=&AE<G=I
M<V4@4$5!4CHZ17)R;W(*("`@("`J($!S964@("`@($Y%5%]&5%!?15)27U-)
M5$5?1D%)3$5$"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@<VET92@D8V]M
M;6%N9"D*("`@('L*("`@("`@("`D<F5S(#T@0&9T<%]S:71E*"1T:&ES+3Y?
M:&%N9&QE+"`D8V]M;6%N9"D["B`@("`@("`@:68@*"$D<F5S*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B17AE8W5T:6]N(&]F
M(%-)5$4@8V]M;6%N9"`G)&-O;6UA;F0G(&9A:6QE9"XB+"!.151?1E107T52
M4E]3251%7T9!24Q%1"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N("1R97,["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M5&AI<R!M971H;V0@=VEL;"!T<GD@=&\@8VAM;V0@=&AE(&9I;&4@<W!E8VEF
M:65D(&]N('1H92!S97)V97(*("`@("`J($-U<G)E;G1L>2P@>6]U(&UU<W0@
M9VEV92!A(&YU;6)E<B!A<R!T:&4@=&AE('!E<FUI<W-I;VX@87)G=6UE;G0@
M*#<W-R!O<@H@("`@("H@<VEM:6QA<BDN(%1H92!F:6QE(&-A;B!B92!E:71H
M97(@82!R96QA=&EV92!O<B!A8G-O;'5T92!P871H+@H@("`@("H@3D]413H@
M4V]M92!S97)V97)S(&1O(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X@26X@
M=&AA="!C87-E+"!Y;W4@=VEL;`H@("`@("H@9V5T(&$@4$5!4B!E<G)O<B!O
M8FIE8W0@<F5T=7)N960N($EF('-U8V-E<W-F=6PL('1H92!M971H;V0@<F5T
M=7)N<R!T<G5E"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@
M*B!`<&%R86T@("!M:7AE9"`@("1T87)G970@("`@("`@(%1H92!F:6QE(&]R
M(&%R<F%Y(&]F(&9I;&5S('1O('-E="!P97)M:7-S:6]N<R!F;W(*("`@("`J
M($!P87)A;2`@(&EN=&5G97(@)'!E<FUI<W-I;VYS("`@5&AE(&UO9&4@=&\@
M<V5T('1H92!F:6QE('!E<FUI<W-I;VYS('1O"B`@("`@*B!`<F5T=7)N("!M
M:7AE9"`@("`@("`@("`@("`@("`@(%1R=64@:68@<W5C8V5S<V9U;"P@;W1H
M97)W:7-E(%!%05(Z.D5R<F]R"B`@("`@*B!`<V5E("`@("!.151?1E107T52
M4E]#2$U/1%]&04E,140*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!C:&UO
M9"@D=&%R9V5T+"`D<&5R;6ES<VEO;G,I"B`@("!["B`@("`@("`@+R\@268@
M)'1A<F=E="!I<R!A;B!A<G)A>3H@3&]O<"!T:')O=6=H(&ET+@H@("`@("`@
M(&EF("AI<U]A<G)A>2@D=&%R9V5T*2D@>PH*("`@("`@("`@("`@9F]R("@D
M:2`](#`[("1I(#P@8V]U;G0H)'1A<F=E="D[("1I*RLI('L*("`@("`@("`@
M("`@("`@("1R97,@/2`D=&AI<RT^8VAM;V0H)'1A<F=E=%LD:5TL("1P97)M
M:7-S:6]N<RD["B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M<F5S*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@
M("`@("`@("`@("`@?2`O+R!E;F0@:68@:7-%<G)O<@H@("`@("`@("`@("!]
M("\O(&5N9"!F;W(@:2`\(&-O=6YT*"1T87)G970I"@H@("`@("`@('T@96QS
M92!["@H@("`@("`@("`@("`D<F5S(#T@)'1H:7,M/G-I=&4H(D-(34]$("(@
M+B`D<&5R;6ES<VEO;G,@+B`B("(@+B`D=&%R9V5T*3L*("`@("`@("`@("`@
M:68@*"$D<F5S*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@B0TA-3T0@(B`N("1P97)M:7-S:6]N<R`N("(@(B`N("1T87)G
M970@+B`B(&9A:6QE9"(L($Y%5%]&5%!?15)27T-(34]$7T9!24Q%1"D["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@)')E
M<SL*("`@("`@("`@("`@?0H*("`@("`@("!]("\O(&5N9"!I9B!I<U]A<G)A
M>0H*("`@('T@+R\@96YD(&UE=&AO9"!C:&UO9`H*("`@("\J*@H@("`@("H@
M5&AI<R!M971H;V0@=VEL;"!T<GD@=&\@8VAM;V0@82!F;VQD97(@86YD(&%L
M;"!O9B!I=',@8V]N=&5N=',*("`@("`J(&]N('1H92!S97)V97(N(%1H92!T
M87)G970@87)G=6UE;G0@;75S="!B92!A(&9O;&1E<B!O<B!A;B!A<G)A>2!O
M9B!F;VQD97)S"B`@("`@*B!A;F0@=&AE('!E<FUI<W-I;VYS(&%R9W5M96YT
M(&AA=F4@=&\@8F4@86X@:6YT96=E<B`H:2YE+B`W-S<I+@H@("`@("H@5&AE
M(&9I;&4@8V%N(&)E(&5I=&AE<B!A(')E;&%T:79E(&]R(&%B<V]L=71E('!A
M=&@N"B`@("`@*B!.3U1%.B!3;VUE('-E<G9E<G,@9&\@;F]T('-U<'!O<G0@
M=&AI<R!F96%T=7)E+B!);B!T:&%T(&-A<V4L('EO=0H@("`@("H@=VEL;"!G
M970@82!014%2(&5R<F]R(&]B:F5C="!R971U<FYE9"X@268@<W5C8V5S<V9U
M;"P@=&AE(&UE=&AO9`H@("`@("H@<F5T=7)N<R!T<G5E"B`@("`@*@H@("`@
M("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<&%R86T@("!M:7AE9"`@("1T
M87)G970@("`@("`@(%1H92!F;VQD97(@;W(@87)R87D@;V8@9F]L9&5R<R!T
M;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S970@
M<&5R;6ES<VEO;G,@9F]R"B`@("`@*B!`<&%R86T@("!I;G1E9V5R("1P97)M
M:7-S:6]N<R`@(%1H92!M;V1E('1O('-E="!T:&4@9F]L9&5R"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%N9"!F:6QE('!E<FUI
M<W-I;VYS('1O"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@("`@("`@("`@("`@
M("`@(%1R=64@:68@<W5C8V5S<V9U;"P@;W1H97)W:7-E(%!%05(Z.D5R<F]R
M"B`@("`@*B!`<V5E("`@("!.151?1E107T524E]#2$U/1%]&04E,140L($Y%
M5%]&5%!?15)27T1%5$5234E.15!!5$A?1D%)3$5$+"!.151?1E107T524E]2
M05=$25),25-47T9!24Q%1"P@3D547T944%]%4E)?1$E23$E35%]53E-54%!/
M4E1%1`H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N(&-H;6]D4F5C=7)S:79E
M*"1T87)G970L("1P97)M:7-S:6]N<RD*("`@('L*("`@("`@("!S=&%T:6,@
M)&1I<E]P97)M:7-S:6]N<SL*"B`@("`@("`@:68H(6ES<V5T*"1D:7)?<&5R
M;6ES<VEO;G,I*7L@+R\@36%K:6YG(&1I<F5C=&]R>2!S<&5C:69I8R!P97)M
M:7-S:6]N<PH@("`@("`@("`@("`D9&ER7W!E<FUI<W-I;VYS(#T@)'1H:7,M
M/E]M86ME1&ER4&5R;6ES<VEO;G,H)'!E<FUI<W-I;VYS*3L*("`@("`@("!]
M"@H@("`@("`@("\O($EF("1T87)G970@:7,@86X@87)R87DZ($QO;W`@=&AR
M;W5G:"!I=`H@("`@("`@(&EF("AI<U]A<G)A>2@D=&%R9V5T*2D@>PH*("`@
M("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)'1A<F=E="D[("1I
M*RLI('L*("`@("`@("`@("`@("`@("1R97,@/2`D=&AI<RT^8VAM;V1296-U
M<G-I=F4H)'1A<F=E=%LD:5TL("1P97)M:7-S:6]N<RD["B`@("`@("`@("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@("`@("`@("`@?2`O+R!E;F0@
M:68@:7-%<G)O<@H@("`@("`@("`@("!]("\O(&5N9"!F;W(@:2`\(&-O=6YT
M*"1T87)G970I"@H@("`@("`@('T@96QS92!["@H@("`@("`@("`@("`D<F5M
M;W1E7W!A=&@@/2`D=&AI<RT^7V-O;G-T<G5C=%]P871H*"1T87)G970I.PH*
M("`@("`@("`@("`@+R\@0VAM;V0@=&AE(&1I<F5C=&]R>2!I='-E;&8*("`@
M("`@("`@("`@)')E<W5L="`]("1T:&ES+3YC:&UO9"@D<F5M;W1E7W!A=&@L
M("1D:7)?<&5R;6ES<VEO;G,I.PH*("`@("`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!)9B`D<F5M;W1E
M7W!A=&@@;&%S="!C:&%R86-T97(@:7,@;F]T(&$@<VQA<V@L(&%D9"!O;F4*
M("`@("`@("`@("`@:68@*'-U8G-T<B@D<F5M;W1E7W!A=&@L('-T<FQE;B@D
M<F5M;W1E7W!A=&@I+3$I("$]("(O(BD@>PH*("`@("`@("`@("`@("`@("1R
M96UO=&5?<&%T:"`N/2`B+R(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1D:7)?;&ES="`](&%R<F%Y*"D["B`@("`@("`@("`@("1M;V1E(#T@3D54
M7T944%]$25)37T].3%D["B`@("`@("`@("`@("1D:7)?;&ES="`]("1T:&ES
M+3YL<R@D<F5M;W1E7W!A=&@L("1M;V1E*3L*("`@("`@("`@("`@9F]R96%C
M:"`H)&1I<E]L:7-T(&%S("1D:7)?96YT<GDI('L*"B`@("`@("`@("`@("`@
M("`D<F5M;W1E7W!A=&A?;F5W(#T@)')E;6]T95]P871H+B1D:7)?96YT<GE;
M(FYA;64B72XB+R(["@H@("`@("`@("`@("`@("`@+R\@0VAM;V0@=&AE(&1I
M<F5C=&]R>2!W92=R92!A8F]U="!T;R!E;G1E<@H@("`@("`@("`@("`@("`@
M)')E<W5L="`]("1T:&ES+3YC:&UO9"@D<F5M;W1E7W!A=&A?;F5W+"`D9&ER
M7W!E<FUI<W-I;VYS*3L*"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^8VAM;V1296-U<G-I=F4H)')E;6]T95]P871H7VYE
M=RP@)'!E<FUI<W-I;VYS*3L*"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@?2`O
M+R!E;F0@9F]R96%C:"!D:7)?;&ES="!A<R!D:7)?96YT<GD*"B`@("`@("`@
M("`@("1F:6QE7VQI<W0@/2!A<G)A>2@I.PH@("`@("`@("`@("`D;6]D92`]
M($Y%5%]&5%!?1DE,15-?3TY,63L*("`@("`@("`@("`@)&9I;&5?;&ES="`]
M("1T:&ES+3YL<R@D<F5M;W1E7W!A=&@L("1M;V1E*3L*"B`@("`@("`@("`@
M(&9O<F5A8V@@*"1F:6QE7VQI<W0@87,@)&9I;&5?96YT<GDI('L*"B`@("`@
M("`@("`@("`@("`D<F5M;W1E7V9I;&4@/2`D<F5M;W1E7W!A=&@N)&9I;&5?
M96YT<GE;(FYA;64B73L*"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H
M:7,M/F-H;6]D*"1R96UO=&5?9FEL92P@)'!E<FUI<W-I;VYS*3L*"B`@("`@
M("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@?2`O+R!E;F0@9F]R96%C:"`D9FEL95]L:7-T
M"@H@("`@("`@('T@+R\@96YD(&EF(&ES7V%R<F%Y"@H@("`@("`@(')E='5R
M;B!T<G5E.R`O+R!.;R!E<G)O<G,*"B`@("!]("\O(&5N9"!M971H;V0@8VAM
M;V1296-U<G-I=F4*"B`@("`O*BH*("`@("`J(%)E;F%M92!O<B!M;W9E(&$@
M9FEL92!O<B!A(&1I<F5C=&]R>2!F<F]M('1H92!F='`M<V5R=F5R"B`@("`@
M*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<&%R86T@("!S=')I
M;F<@)')E;6]T95]F<F]M(%1H92!R96UO=&4@9FEL92!O<B!D:7)E8W1O<GD@
M;W)I9VEN86P@=&\@<F5N86UE(&]R(&UO=F4*("`@("`J($!P87)A;2`@('-T
M<FEN9R`D<F5M;W1E7W1O(%1H92!R96UO=&4@9FEL92!O<B!D:7)E8W1O<GD@
M9FEN86P@=&\@<F5N86UE(&]R(&UO=F4*("`@("`J($!R971U<FX@(&)O;VP@
M)')E<R!4<G5E(&]N('-U8V-E<W,L(&]T:&5R=VES92!014%2.CI%<G)O<@H@
M("`@("H@0'-E92`@("`@3D547T944%]%4E)?4D5.04U%7T9!24Q%1`H@("`@
M("HO"@H@("`@9G5N8W1I;VX@<F5N86UE("@D<F5M;W1E7V9R;VTL("1R96UO
M=&5?=&\I(`H@("`@>PH@("`@("`@("1R97,@/2!`9G1P7W)E;F%M92@D=&AI
M<RT^7VAA;F1L92P@)')E;6]T95]F<F]M+"`D<F5M;W1E7W1O*3L*("`@("`@
M("!I9B@A)')E<RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H(D-O=6QD(&YO="!R96YA;64@(BXD<F5M;W1E7V9R;VTN(B!T;R`B
M+B1R96UO=&5?=&\N(B`A(BP@3D547T944%]%4E)?4D5.04U%7T9!24Q%1"D[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@5&AI<R!W:6QL(')E='5R;B!L;V=I8V%L('!E<FUI<W-I;VYS
M(&UA<VL@9F]R(&1I<F5C=&]R>2X*("`@("`J(&EF(&1I<F5C=&]R>2!H879E
M('1O(&)E('=R:71E86)L92!I="!H879E(&%L<V\@8F4@97AE8W5T86)L90H@
M("`@("H*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J($!P87)A;2`@
M('-T<FEN9R`D<&5R;6ES<VEO;G,@("`@1FEL92!P97)M:7-S:6]N<R!I;B!D
M:6=I=',@9F]R(&9I;&4@*&DN92X@-C8V*0H@("`@("H@0')E='5R;B`@<W1R
M:6YG("`@("`@("`@("`@("`@("!&:6QE('!E<FUI<W-I;VYS(&EN(&1I9VET
M<R!F;W(@9&ER96-T;W)Y("AI+F4N(#<W-RD*("`@("`J+PH*("`@(&9U;F-T
M:6]N(%]M86ME1&ER4&5R;6ES<VEO;G,H)'!E<FUI<W-I;VYS*7L*("`@("`@
M("`D<&5R;6ES<VEO;G,@/2`H<W1R:6YG*21P97)M:7-S:6]N<SL*"B`@("`@
M("`@9F]R*"1I(#T@,#L@)&D@/"!S=')L96XH)'!E<FUI<W-I;VYS*3L@)&DK
M*RE[("\O(&=O:6YG('1H<F]U9V@@*'5S97(L(&=R;W5P+"!W;W)L9"D*("`@
M("`@("`@("`@:68H*&EN="DD<&5R;6ES<VEO;G-[)&E]("8@-"!A;F0@(2@H
M:6YT*21P97)M:7-S:6]N<WLD:7T@)B`Q*2E[("\O(%)E860@<&5R;6ES<VEO
M;B!I<R!S970*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(&)U
M="!E>&5C=71E(&YO="!Y970*("`@("`@("`@("`@("`@("AI;G0I)'!E<FUI
M<W-I;VYS>R1I?2`]("AI;G0I)'!E<FUI<W-I;VYS>R1I?2`K(#$[("\O($%D
M9&EN9R!E>&5C=71E(&9L86<*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("AS=')I;F<I)'!E<FUI<W-I;VYS.PH@("`@?0H*("`@
M("\J*@H@("`@("H@5&AI<R!W:6QL(')E='5R;B!T:&4@;&%S="!M;V1I9FEC
M871I;VXM=&EM92!O9B!A(&9I;&4N(%EO=2!C86X@96ET:&5R(&=I=F4@=&AI
M<PH@("`@("H@9G5N8W1I;VX@82!R96QA=&EV92!O<B!A;B!A8G-O;'5T92!P
M871H('1O('1H92!F:6QE('1O(&-H96-K+@H@("`@("H@3D]413H@4V]M92!S
M97)V97)S('=I;&P@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E(&%N9"!T:&4@
M9G5N8W1I;VX@=V]R:W,*("`@("`J(&]N;'D@;VX@9FEL97,L(&YO="!D:7)E
M8W1O<FEE<R$@5VAE;B!S=6-C97-S9G5L+`H@("`@("H@:70@=VEL;"!R971U
M<FX@=&AE(&QA<W0@;6]D:69I8V%T:6]N+71I;64@87,@82!U;FEX+71I;65S
M=&%M<"!O<BP@=VAE;B`D9F]R;6%T(&ES"B`@("`@*B!S<&5C:69I960L(&$@
M<')E9F]R;6%T960@=&EM97-T<FEN9RX*("`@("`J"B`@("`@*B!`86-C97-S
M("!P=6)L:6,*("`@("`J($!P87)A;2`@('-T<FEN9R`D9FEL92`@("!4:&4@
M9FEL92!T;R!C:&5C:PH@("`@("H@0'!A<F%M("`@<W1R:6YG("1F;W)M870@
M("AO<'1I;VYA;"D@5&AE(&9O<FUA="!T;R!G:79E('1H92!D871E(&)A8VL@
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@:68@;F]T('-E="P@
M:70@=VEL;"!R971U<FX@82!5;FEX('1I;65S=&%M<`H@("`@("H@0')E='5R
M;B`@;6EX960@("`@("`@("`@(%5N:7@@=&EM97-T86UP+"!A('!R969O<FUA
M=&5D(&1A=&4M<W1R:6YG(&]R(%!%05(Z.D5R<F]R"B`@("`@*B!`<V5E("`@
M("!.151?1E107T524E]-1%1-1$E27U5.4U504$]25$5$+"!.151?1E107T52
M4E]-1%1-7T9!24Q%1"P@3D547T944%]%4E)?1$%4149/4DU!5%]&04E,140*
M("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!M9'1M*"1F:6QE+"`D9F]R;6%T
M(#T@;G5L;"D*("`@('L*("`@("`@("`D9FEL92`]("1T:&ES+3Y?8V]N<W1R
M=6-T7W!A=&@H)&9I;&4I.PH@("`@("`@(&EF("@D=&AI<RT^7V-H96-K7V1I
M<B@D9FEL92DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*")&:6QE;F%M92`G)&9I;&4G('-E96US('1O(&)E(&$@9&ER96-T;W)Y
M+B(L($Y%5%]&5%!?15)27TU$5$U$25)?54Y355!03U)4140I.PH@("`@("`@
M('T*("`@("`@("`D<F5S(#T@0&9T<%]M9'1M*"1T:&ES+3Y?:&%N9&QE+"`D
M9FEL92D["B`@("`@("`@:68@*"1R97,@/3T@+3$I('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")#;W5L9"!N;W0@9V5T(&QA<W0M
M;6]D:69I8V%T:6]N+61A=&4@;V8@)R1F:6QE)RXB+"!.151?1E107T524E]-
M1%1-7T9!24Q%1"D["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D9F]R
M;6%T*2D@>PH@("`@("`@("`@("`D<F5S(#T@9&%T92@D9F]R;6%T+"`D<F5S
M*3L*("`@("`@("`@("`@:68@*"$D<F5S*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D1A=&4M9F]R;6%T(&9A:6QE9"!O
M;B!T:6UE<W1A;7`@)R1R97,G+B(L($Y%5%]&5%!?15)27T1!5$5&3U)-051?
M1D%)3$5$*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U
M<FX@)')E<SL*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@=VEL;"!R971U
M<FX@=&AE('-I>F4@;V8@82!G:79E;B!F:6QE(&EN(&)Y=&5S+B!9;W4@8V%N
M(&5I=&AE<B!G:79E('1H:7,@9G5N8W1I;VX*("`@("`J(&$@<F5L871I=F4@
M;W(@86X@86)S;VQU=&4@9FEL92UP871H+B!.3U1%.B!3;VUE('-E<G9E<G,@
M9&\@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E(0H@("`@("H*("`@("`J($!A
M8V-E<W,@('!U8FQI8PH@("`@("H@0'!A<F%M("`@<W1R:6YG("1F:6QE("`@
M5&AE(&9I;&4@=&\@8VAE8VL*("`@("`J($!R971U<FX@(&UI>&5D("`@("`@
M("`@(%-I>F4@:6X@8GET97,@;W(@4$5!4CHZ17)R;W(*("`@("`J($!S964@
M("`@($Y%5%]&5%!?15)27U-)6D5?1D%)3$5$"B`@("`@*B\*("`@(`H@("`@
M9G5N8W1I;VX@<VEZ92@D9FEL92D*("`@('L*("`@("`@("`D9FEL92`]("1T
M:&ES+3Y?8V]N<W1R=6-T7W!A=&@H)&9I;&4I.PH@("`@("`@("1R97,@/2!`
M9G1P7W-I>F4H)'1H:7,M/E]H86YD;&4L("1F:6QE*3L*("`@("`@("!I9B`H
M)')E<R`]/2`M,2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H(D-O=6QD(&YO="!D971E<FUI;F4@9FEL97-I>F4@;V8@)R1F:6QE
M)RXB+"!.151?1E107T524E]325I%7T9!24Q%1"D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@5&AI<R!M971H;V0@<F5T=7)N<R!A(&1I<F5C=&]R
M>2UL:7-T(&]F('1H92!C=7)R96YT(&1I<F5C=&]R>2!O<B!G:79E;B!O;F4N
M"B`@("`@*B!4;R!D:7-P;&%Y('1H92!C=7)R96YT('-E;&5C=&5D(&1I<F5C
M=&]R>2P@<VEM<&QY('-E="!T:&4@9FER<W0@<&%R86UE=&5R('1O(&YU;&P*
M("`@("`J(&]R(&QE879E(&ET(&)L86YK+"!I9B!Y;W4@9&\@;F]T('=A;G0@
M=&\@=7-E(&%N>2!O=&AE<B!P87)A;65T97)S+@H@("`@("H@/$)2/CQ"4CX*
M("`@("`J(%1H97)E(&%R92`T(&1I9F9E<F5N="!M;V1E<R!O9B!L:7-T:6YG
M(&1I<F5C=&]R:65S+B!%:71H97(@=&\@;&ES="!O;FQY"B`@("`@*B!T:&4@
M9FEL97,@*'5S:6YG($Y%5%]&5%!?1DE,15-?3TY,62DL('1O(&QI<W0@;VYL
M>2!D:7)E8W1O<FEE<R`H=7-I;F<*("`@("`J($Y%5%]&5%!?1$E24U]/3DQ9
M*2!O<B!T;R!S:&]W(&)O=&@@*'5S:6YG($Y%5%]&5%!?1$E24U]&24Q%4RP@
M=VAI8V@@:7,@9&5F875L="DN"B`@("`@*B`\0E(^/$)2/@H@("`@("H@5&AE
M(#1T:"!O;F4@:7,@=&AE($Y%5%]&5%!?4D%73$E35"P@=VAI8V@@<F5T=7)N
M<R!J=7-T('1H92!A<G)A>2!C<F5A=&5D(&)Y('1H90H@("`@("H@9G1P7W)A
M=VQI<W0H*2UF=6YC=&EO;B!B=6EL9"!I;G1O(%!(4"X*("`@("`J(#Q"4CX\
M0E(^"B`@("`@*B!4:&4@;W1H97(@9G5N8W1I;VXM;6]D97,@=VEL;"!R971U
M<FX@86X@87)R87D@8V]N=&%I;FEN9R!T:&4@<F5Q=65S=&5D(&1A=&$N"B`@
M("`@*B!4:&4@9FEL97,@86YD(&1I<G,@87)E(&QI<W1E9"!I;B!H=6UA;BUS
M;W)T960@;W)D97(L(&)U="!I9B!Y;W4@<V5L96-T"B`@("`@*B!.151?1E10
M7T1)4E-?1DE,15,@=&AE(&1I<F5C=&]R:65S('=I;&P@8F4@861D960@86)O
M=F4@=&AE(&9I;&5S+`H@("`@("H@8G5T(&%L=&AO=6=H(&)O=&@@<V]R=&5D
M+@H@("`@("H@/$)2/CQ"4CX*("`@("`J($%L;"!E;&5M96YT<R!I;B!T:&4@
M87)R87ES(&%R92!A<W-O8VEA=&EV92!A<G)A>7,@=&AE;7-E;'9E<RX@5&AE
M(&AA=F4@=&AE(&9O;&QO=VEN9PH@("`@("H@<W1R=6-T=7)E.@H@("`@("H@
M/$)2/CQ"4CX*("`@("`J($1I<G,Z/$)2/@H@("`@("H@("`@("`@("`@(%LB
M;F%M92)=("`@("`@("`]/B`@<W1R:6YG(%1H92!N86UE(&]F('1H92!D:7)E
M8W1O<GD\0E(^"B`@("`@*B`@("`@("`@("`@6R)R:6=H=',B72`@("`@(#T^
M("!S=')I;F<@5&AE(')I9VAT<R!O9B!T:&4@9&ER96-T;W)Y("AI;B!S='EL
M92`B<G=X<BUX<BUX(BD\0E(^"B`@("`@*B`@("`@("`@("`@6R)U<V5R(ET@
M("`@("`@(#T^("!S=')I;F<@5&AE(&]W;F5R(&]F('1H92!D:7)E8W1O<GD\
M0E(^"B`@("`@*B`@("`@("`@("`@6R)G<F]U<")=("`@("`@(#T^("!S=')I
M;F<@5&AE(&=R;W5P+6]W;F5R(&]F('1H92!D:7)E8W1O<GD\0E(^"B`@("`@
M*B`@("`@("`@("`@6R)F:6QE<U]I;G-I9&4B73T^("!S=')I;F<@5&AE(&YU
M;6)E<B!O9B!F:6QE<R]D:7)S(&EN<VED92!T:&4@9&ER96-T;W)Y"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@97AC;'5D
M:6YG("(N(B!A;F0@(BXN(CQ"4CX*("`@("`J("`@("`@("`@("!;(F1A=&4B
M72`@("`@("`@/3X@(&EN="!4:&4@8W)E871I;VXM9&%T92!A<R!5;FEX('1I
M;65S=&%M<#Q"4CX*("`@("`J("`@("`@("`@("!;(FES7V1I<B)=("`@("`@
M/3X@(&)O;VP@=')U92P@8V%U<V4@=&AI<R!I<R!A(&1I<CQ"4CX*("`@("`J
M(#Q"4CX\0E(^"B`@("`@*B!&:6QE<SH\0E(^"B`@("`@*B`@("`@("`@("`@
M6R)N86UE(ET@("`@("`@(#T^("!S=')I;F<@5&AE(&YA;64@;V8@=&AE(&9I
M;&4\0E(^"B`@("`@*B`@("`@("`@("`@6R)S:7IE(ET@("`@("`@(#T^("!I
M;G0@4VEZ92!I;B!B>71E<SQ"4CX*("`@("`J("`@("`@("`@("!;(G)I9VAT
M<R)=("`@("`@/3X@('-T<FEN9R!4:&4@<FEG:'1S(&]F('1H92!F:6QE("AI
M;B!S='EL92`B<G=X<BUX<BUX(BD\0E(^"B`@("`@*B`@("`@("`@("`@6R)U
M<V5R(ET@("`@("`@(#T^("!S=')I;F<@5&AE(&]W;F5R(&]F('1H92!F:6QE
M/$)2/@H@("`@("H@("`@("`@("`@(%LB9W)O=7`B72`@("`@("`]/B`@<W1R
M:6YG(%1H92!G<F]U<"UO=VYE<B!O9B!T:&4@9FEL93Q"4CX*("`@("`J("`@
M("`@("`@("!;(F1A=&4B72`@("`@("`@/3X@(&EN="!4:&4@8W)E871I;VXM
M9&%T92!A<R!5;FEX('1I;65S=&%M<#Q"4CX*("`@("`J("`@("`@("`@("!;
M(FES7V1I<B)=("`@("`@/3X@(&)O;VP@9F%L<V4L(&-A=7-E('1H:7,@:7,@
M82!F:6QE/$)2/@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@
M("H@0'!A<F%M("`@<W1R:6YG("1D:7(@("`H;W!T:6]N86PI(%1H92!D:7)E
M8W1O<GD@=&\@;&ES="!O<B!N=6QL+"!W:&5N(&QI<W1I;F<@=&AE(&-U<G)E
M;G0@9&ER96-T;W)Y+@H@("`@("H@0'!A<F%M("`@:6YT("`@("1M;V1E("`H
M;W!T:6]N86PI(%1H92!M;V1E('=H:6-H('1Y<&5S('1O(&QI<W0@*&9I;&5S
M+"!D:7)E8W1O<FEE<R!O<B!B;W1H*2X*("`@("`J($!R971U<FX@(&UI>&5D
M("`@("`@("`@5&AE(&1I<F5C=&]R>2!L:7-T(&%S(&1E<V-R:6)E9"!A8F]V
M92!O<B!014%2.CI%<G)O<B!O;B!F86EL=7)E+@H@("`@("H@0'-E92`@("`@
M3D547T944%]$25)37T9)3$53+"!.151?1E107T1)4E-?3TY,62P@3D547T94
M4%]&24Q%4U]/3DQ9+"!.151?1E107U)!5TQ)4U0L($Y%5%]&5%!?15)27T1%
M5$5234E.15!!5$A?1D%)3$5$+"!.151?1E107T524E]205=$25),25-47T9!
M24Q%1"P@3D547T944%]%4E)?1$E23$E35%]53E-54%!/4E1%1`H@("`@("HO
M"B`@("`@"B`@("!F=6YC=&EO;B!L<R@D9&ER(#T@;G5L;"P@)&UO9&4@/2!.
M151?1E107T1)4E-?1DE,15,I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D
M9&ER*2D@>PH@("`@("`@("`@("`D9&ER(#T@0&9T<%]P=V0H)'1H:7,M/E]H
M86YD;&4I.PH@("`@("`@("`@("!I9B`H(21D:7(I('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B0V]U;&0@;F]T(')E=')I
M979E(&-U<G)E;G0@9&ER96-T;W)Y(BP@3D547T944%]%4E)?1$5415)-24Y%
M4$%42%]&04E,140I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@
M(&EF("@H)&UO9&4@(3T@3D547T944%]&24Q%4U]/3DQ9*2`F)B`H)&UO9&4@
M(3T@3D547T944%]$25)37T].3%DI("8F("@D;6]D92`A/2!.151?1E107U)!
M5TQ)4U0I*2!["B`@("`@("`@("`@("1M;V1E(#T@3D547T944%]$25)37T9)
M3$53.PH@("`@("`@('T*"B`@("`@("`@<W=I=&-H("@D;6]D92D@>PH@("`@
M("`@("`@("!C87-E($Y%5%]&5%!?1$E24U]&24Q%4SH@("`@)')E<R`]("1T
M:&ES+3Y?;'-?8F]T:"`H("1D:7(@*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E($Y%
M5%]&5%!?1$E24U]/3DQ9.B`@("`@)')E<R`]("1T:&ES+3Y?;'-?9&ER<R`H
M("1D:7(@*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!C87-E($Y%5%]&5%!?1DE,15-?3TY,
M63H@("`@)')E<R`]("1T:&ES+3Y?;'-?9FEL97,@*"`D9&ER("D["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@8V%S92!.151?1E107U)!5TQ)4U0Z("`@("`@("1R97,@/2!`
M9G1P7W)A=VQI<W0H)'1H:7,M/E]H86YD;&4L("1D:7(I.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)')E<SL*("`@('T*"B`@("`O*BH*("`@("`J
M(%1H:7,@;65T:&]D('=I;&P@9&5L971E('1H92!G:79E;B!F:6QE(&]R(&1I
M<F5C=&]R>2`H)'!A=&@I(&9R;VT@=&AE('-E<G9E<@H@("`@("H@*&UA>6)E
M(')E8W5R<VEV92DN"B`@("`@*@H@("`@("H@5VAE=&AE<B!T:&4@9VEV96X@
M<W1R:6YG(&ES(&$@9FEL92!O<B!D:7)E8W1O<GD@:7,@;VYL>2!D971E<FUI
M;F5D(&)Y('1H92!L87-T"B`@("`@*B!S:6=N(&EN<VED92!T:&4@<W1R:6YG
M("@B+R(@;W(@;F]T*2X*("`@("`J"B`@("`@*B!)9B!Y;W4@<W!E8VEF>2!A
M(&1I<F5C=&]R>2P@>6]U(&-A;B!O<'1I;VYA;&QY('-P96-I9GD@)')E8W5R
M<VEV92!A<R!T<G5E+`H@("`@("H@=&\@;&5T('1H92!D:7)E8W1O<GD@8F4@
M9&5L971E9"!R96-U<G-I=F4@*'=I=&@@86QL('-U8BUD:7)E8W1O<FEE<R!A
M;F0@9FEL97,*("`@("`J(&EN:&5R:71E9"DN"B`@("`@*@H@("`@("H@66]U
M(&-A;B!E:71H97(@9VEV92!A(&%B<V]L=71E(&]R(')E;&%T:79E('!A=&@@
M9F]R('1H92!F:6QE("\@9&ER+B!)9B!Y;W4@8VAO;W-E('1O"B`@("`@*B!U
M<V4@=&AE(')E;&%T:79E('!A=&@L(&ET('=I;&P@8F4@875T;VUA=&EC86QL
M>2!C;VUP;&5T960@=VET:"!T:&4@86-T=6%L"B`@("`@*B!S96QE8W1E9"!D
M:7)E8W1O<GDN"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@
M*B!`<&%R86T@("!S=')I;F<@)'!A=&@@("`@("!4:&4@86)S;VQU=&4@;W(@
M<F5L871I=F4@<&%T:"!T;R!T:&4@9FEL92`O(&1I<F5C=&]R>2X*("`@("`J
M($!P87)A;2`@(&)O;VP@("`D<F5C=7)S:79E("AO<'1I;VYA;"D*("`@("`J
M($!R971U<FX@(&UI>&5D("`@("`@("`@("`@(%1R=64@;VX@<W5C8V5S<RP@
M;W1H97)W:7-E(%!%05(Z.D5R<F]R"B`@("`@*B!`<V5E("`@("!.151?1E10
M7T524E]$14Q%5$5&24Q%7T9!24Q%1"P@3D547T944%]%4E)?1$5,151%1$E2
M7T9!24Q%1"P@3D547T944%]%4E)?4D5-3U1%4$%42$Y/1$E2"B`@("`@*B\*
M("`@(`H@("`@9G5N8W1I;VX@<FTH)'!A=&@L("1R96-U<G-I=F4@/2!F86QS
M92D*("`@('L*("`@("`@("`D<&%T:"`]("1T:&ES+3Y?8V]N<W1R=6-T7W!A
M=&@H)'!A=&@I.PH*("`@("`@("!I9B`H)'1H:7,M/E]C:&5C:U]D:7(H)'!A
M=&@I*2!["B`@("`@("`@("`@(&EF("@D<F5C=7)S:79E*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]R;5]D:7)?<F5C=7)S:79E*"1P871H
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7W)M7V1I<B@D<&%T:"D["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R;5]F:6QE
M*"1P871H*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES
M(&9U;F-T:6]N('=I;&P@9&]W;FQO860@82!F:6QE(&9R;VT@=&AE(&9T<"US
M97)V97(N(%EO=2!C86X@96ET:&5R('-P8VEF>2!A(&%B<V]L=71E"B`@("`@
M*B!P871H('1O('1H92!F:6QE("AB96=I;FYI;F<@=VET:"`B+R(I(&]R(&$@
M<F5L871I=F4@;VYE+"!W:&EC:"!W:6QL(&)E(&-O;7!L971E9`H@("`@("H@
M=VET:"!T:&4@86-T=6%L(&1I<F5C=&]R>2!Y;W4@<V5L96-T960@;VX@=&AE
M('-E<G9E<BX@66]U(&-A;B!S<&5C:69Y"B`@("`@*B!T:&4@<&%T:"!T;R!W
M:&EC:"!T:&4@9FEL92!W:6QL(&)E(&1O=VYL;V%D960@;VX@=&AE(&QO8V%L
M"B`@("`@*B!M87-C:&EN92P@:68@=&AE(&9I;&4@<VAO=6QD(&)E(&]V97)W
M<FET=&5N(&EF(&ET(&5X:7-T<R`H;W!T:6]N86QL>2P@9&5F875L="!I<PH@
M("`@("H@;F\@;W9E<G=R:71I;F<I(&%N9"!I;B!W:&EC:"!M;V1E("A&5%!?
M05-#24D@;W(@1E107T))3D%262D@=&AE(&9I;&4@<VAO=6QD(&)E"B`@("`@
M*B!D;W=N;&]A9&5D("AI9B!Y;W4@9&\@;F]T('-P96-I9GD@=&AI<RP@=&AE
M(&UE=&AO9"!T<FEE<R!T;R!D971E<FUI;F4@:70@875T;VUA=&EC86QL>0H@
M("`@("H@9G)O;2!T:&4@;6]D92UD:7)E8W1O<GD@;W(@=7-E<R!T:&4@9&5F
M875L="UM;V1E+"!S970@8GD@>6]U*2X@268@>6]U(&=I=F4@82!R96QA=&EV
M90H@("`@("H@<&%T:"!T;R!T:&4@;&]C86PM9FEL92P@=&AE('-C<FEP="UP
M871H(&ES('5S960@87,@8F%S97!A=&@N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R`@<'5B;&EC"B`@("`@*B!`<&%R86T@("!S=')I;F<@)')E;6]T95]F:6QE
M(%1H92!A8G-O;'5T92!O<B!R96QA=&EV92!P871H('1O('1H92!F:6QE('1O
M(&1O=VYL;V%D"B`@("`@*B!`<&%R86T@("!S=')I;F<@)&QO8V%L7V9I;&4@
M(%1H92!L;V-A;"!F:6QE('1O('!U="!T:&4@9&]W;FQO861E9"!I;@H@("`@
M("H@0'!A<F%M("`@8F]O;"`@("1O=F5R=W)I=&4@("`H;W!T:6]N86PI(%=H
M971H97(@=&\@;W9E<G=R:71E(&5X:7-T:6YG(&9I;&4*("`@("`J($!P87)A
M;2`@(&EN="`@("`D;6]D92`@("`@("`@*&]P=&EO;F%L*2!%:71H97(@1E10
M7T%30TE)(&]R($944%]"24Y!4ED*("`@("`J($!R971U<FX@(&UI>&5D("`@
M("`@("`@("`@("`@5')U92!O;B!S=6-C97-S+"!O=&AE<G=I<V4@4$5!4CHZ
M17)R;W(*("`@("`J($!S964@("`@($Y%5%]&5%!?15)27T]615)74DE414Q/
M0T%,1DE,15]&3U)"241$14XL($Y%5%]&5%!?15)27T]615)74DE414Q/0T%,
M1DE,15]&04E,140L($Y%5%]&5%!?15)27T]615)74DE414Q/0T%,1DE,15]&
M04E,140*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!G970H)')E;6]T95]F
M:6QE+"`D;&]C86Q?9FEL92P@)&]V97)W<FET92`](&9A;'-E+"`D;6]D92`]
M(&YU;&PI"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D;6]D92DI('L*("`@
M("`@("`@("`@)&UO9&4@/2`D=&AI<RT^8VAE8VM&:6QE17AT96YS:6]N*"1R
M96UO=&5?9FEL92D["B`@("`@("`@?0H*("`@("`@("`D<F5M;W1E7V9I;&4@
M/2`D=&AI<RT^7V-O;G-T<G5C=%]P871H*"1R96UO=&5?9FEL92D["@H@("`@
M("`@(&EF("A`9FEL95]E>&ES=',H)&QO8V%L7V9I;&4I("8F("$D;W9E<G=R
M:71E*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B
M3&]C86P@9FEL92`G)&QO8V%L7V9I;&4G(&5X:7-T<R!A;F0@;6%Y(&YO="!B
M92!O=F5R=W)I=&5N+B(L($Y%5%]&5%!?15)27T]615)74DE414Q/0T%,1DE,
M15]&3U)"241$14XI.PH@("`@("`@('T*("`@("`@("!I9B`H0&9I;&5?97AI
M<W1S*"1L;V-A;%]F:6QE*2`F)B`A0&ES7W=R:71E86)L92@D;&]C86Q?9FEL
M92D@)B8@)&]V97)W<FET92D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H(DQO8V%L(&9I;&4@)R1L;V-A;%]F:6QE)R!I<R!N;W0@
M=W)I=&5A8FQE+B!#86X@;F]T(&]V97)W<FET92XB+"!.151?1E107T524E]/
M5D525U))5$5,3T-!3$9)3$5?1D%)3$5$*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("A`9G5N8W1I;VY?97AI<W1S*"=F='!?;F)?9V5T)RDI>PH@("`@("`@
M("`@("`D<F5S(#T@0&9T<%]N8E]G970H)'1H:7,M/E]H86YD;&4L("1L;V-A
M;%]F:6QE+"`D<F5M;W1E7V9I;&4L("1M;V1E*3L*("`@("`@("`@("`@=VAI
M;&4@*"1R97,@/3T@1E107TU/4D5$051!*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V%N;F]U;F-E*"=N8E]G970G*3L*("`@("`@("`@("`@("`@("1R
M97,@/2!`9G1P7VYB7V-O;G1I;G5E("@D=&AI<RT^7VAA;F1L92D["B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S(#T@
M0&9T<%]G970H)'1H:7,M/E]H86YD;&4L("1L;V-A;%]F:6QE+"`D<F5M;W1E
M7V9I;&4L("1M;V1E*3L*("`@("`@("!]"B`@("`@("`@:68@*"$D<F5S*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B1FEL92`G
M)')E;6]T95]F:6QE)R!C;W5L9"!N;W0@8F4@9&]W;FQO861E9"!T;R`G)&QO
M8V%L7V9I;&4G+B(L($Y%5%]&5%!?15)27T]615)74DE414Q/0T%,1DE,15]&
M04E,140I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@9G5N
M8W1I;VX@=VEL;"!U<&QO860@82!F:6QE('1O('1H92!F='`M<V5R=F5R+B!9
M;W4@8V%N(&5I=&AE<B!S<&5C:69Y(&$@86)S;VQU=&4*("`@("`J('!A=&@@
M=&\@=&AE(')E;6]T92UF:6QE("AB96=I;FYI;F<@=VET:"`B+R(I(&]R(&$@
M<F5L871I=F4@;VYE+"!W:&EC:"!W:6QL(&)E(&-O;7!L971E9`H@("`@("H@
M=VET:"!T:&4@86-T=6%L(&1I<F5C=&]R>2!Y;W4@<V5L96-T960@;VX@=&AE
M('-E<G9E<BX@66]U(&-A;B!S<&5C:69Y"B`@("`@*B!T:&4@<&%T:"!F<F]M
M('=H:6-H('1H92!F:6QE('=I;&P@8F4@=7!L;V%D960@;VX@=&AE(&QO8V%L
M"B`@("`@*B!M87-C:&EN92P@:68@=&AE(&9I;&4@<VAO=6QD(&)E(&]V97)W
M<FET=&5N(&EF(&ET(&5X:7-T<R`H;W!T:6]N86QL>2P@9&5F875L="!I<PH@
M("`@("H@;F\@;W9E<G=R:71I;F<I(&%N9"!I;B!W:&EC:"!M;V1E("A&5%!?
M05-#24D@;W(@1E107T))3D%262D@=&AE(&9I;&4@<VAO=6QD(&)E"B`@("`@
M*B!D;W=N;&]A9&5D("AI9B!Y;W4@9&\@;F]T('-P96-I9GD@=&AI<RP@=&AE
M(&UE=&AO9"!T<FEE<R!T;R!D971E<FUI;F4@:70@875T;VUA=&EC86QL>0H@
M("`@("H@9G)O;2!T:&4@;6]D92UD:7)E8W1O<GD@;W(@=7-E<R!T:&4@9&5F
M875L="UM;V1E+"!S970@8GD@>6]U*2X@268@>6]U(&=I=F4@82!R96QA=&EV
M90H@("`@("H@<&%T:"!T;R!T:&4@;&]C86PM9FEL92P@=&AE('-C<FEP="UP
M871H(&ES('5S960@87,@8F%S97!A=&@N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R`@<'5B;&EC"B`@("`@*B!`<&%R86T@("!S=')I;F<@)&QO8V%L7V9I;&4@
M(%1H92!L;V-A;"!F:6QE('1O('5P;&]A9`H@("`@("H@0'!A<F%M("`@<W1R
M:6YG("1R96UO=&5?9FEL92!4:&4@86)S;VQU=&4@;W(@<F5L871I=F4@<&%T
M:"!T;R!T:&4@9FEL92!T;R!U<&QO860@=&\*("`@("`J($!P87)A;2`@(&)O
M;VP@("`D;W9E<G=R:71E("`@*&]P=&EO;F%L*2!7:&5T:&5R('1O(&]V97)W
M<FET92!E>&ES=&EN9R!F:6QE"B`@("`@*B!`<&%R86T@("!I;G0@("`@)&UO
M9&4@("`@("`@("AO<'1I;VYA;"D@16ET:&5R($944%]!4T-)22!O<B!&5%!?
M0DE.05)9"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@("`@("`@("`@("`@(%1R
M=64@;VX@<W5C8V5S<RP@;W1H97)W:7-E(%!%05(Z.D5R<F]R"B`@("`@*B!`
M<V5E("`@("!.151?1E107T524E],3T-!3$9)3$5.3U1%6$E35"P@3D547T94
M4%]%4E)?3U9%4E=2251%4D5-3U1%1DE,15]&3U)"241$14XL($Y%5%]&5%!?
M15)27U503$]!1$9)3$5?1D%)3$5$"B`@("`@*B\*("`@(`H@("`@9G5N8W1I
M;VX@<'5T*"1L;V-A;%]F:6QE+"`D<F5M;W1E7V9I;&4L("1O=F5R=W)I=&4@
M/2!F86QS92P@)&UO9&4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-S
M970H)&UO9&4I*2!["B`@("`@("`@("`@("1M;V1E(#T@)'1H:7,M/F-H96-K
M1FEL945X=&5N<VEO;B@D;&]C86Q?9FEL92D["B`@("`@("`@?0H@("`@("`@
M("1R96UO=&5?9FEL92`]("1T:&ES+3Y?8V]N<W1R=6-T7W!A=&@H)')E;6]T
M95]F:6QE*3L*"B`@("`@("`@:68@*"%`9FEL95]E>&ES=',H)&QO8V%L7V9I
M;&4I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B
M3&]C86P@9FEL92`G)&QO8V%L7V9I;&4G(&1O97,@;F]T(&5X:7-T+B(L($Y%
M5%]&5%!?15)27TQ/0T%,1DE,14Y/5$5825-4*3L*("`@("`@("!]"B`@("`@
M("`@:68@*"A`9G1P7W-I>F4H)'1H:7,M/E]H86YD;&4L("1R96UO=&5?9FEL
M92D@(3T@+3$I("8F("$D;W9E<G=R:71E*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B4F5M;W1E(&9I;&4@)R1R96UO=&5?9FEL
M92<@97AI<W1S(&%N9"!M87D@;F]T(&)E(&]V97)W<FET96XN(BP@3D547T94
M4%]%4E)?3U9%4E=2251%4D5-3U1%1DE,15]&3U)"241$14XI.PH@("`@("`@
M('T*"B`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G9G1P7VYB7W!U="<I
M*7L*("`@("`@("`@("`@)')E<R`]($!F='!?;F)?<'5T*"1T:&ES+3Y?:&%N
M9&QE+"`D<F5M;W1E7V9I;&4L("1L;V-A;%]F:6QE+"`D;6]D92D["B`@("`@
M("`@("`@('=H:6QE("@D<F5S(#T]($944%]-3U)%1$%402D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]A;FYO=6YC92@G;F)?<'5T)RD["B`@("`@("`@
M("`@("`@("`D<F5S(#T@0&9T<%]N8E]C;VYT:6YU92@D=&AI<RT^7VAA;F1L
M92D["B`@("`@("`@("`@('T*"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)')E<R`]($!F='!?<'5T*"1T:&ES+3Y?:&%N9&QE+"`D<F5M;W1E7V9I
M;&4L("1L;V-A;%]F:6QE+"`D;6]D92D["B`@("`@("`@?0H@("`@("`@(&EF
M("@A)')E<RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(D9I;&4@)R1L;V-A;%]F:6QE)R!C;W5L9"!N;W0@8F4@=7!L;V%D960@
M=&\@)R1R96UO=&5?9FEL92<N(BP@3D547T944%]%4E)?55!,3T%$1DE,15]&
M04E,140I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@9G5N
M8W1I;VYA;&ET>2!A;&QO=W,@>6]U('1O('1R86YS9F5R(&$@=VAO;&4@9&ER
M96-T;W)Y+7-T<G5C='5R92!F<F]M('1H90H@("`@("H@<F5M;W1E+69T<"!T
M;R!Y;W5R(&QO8V%L(&AO<W0N(%EO=2!H879E('1O(&=I=F4@82!R96UO=&4M
M9&ER96-T;W)Y("AE;F1I;F<@=VET:`H@("`@("H@)R\G*2!A;F0@=&AE(&QO
M8V%L(&1I<F5C=&]R>2`H96YD:6YG('=I=&@@)R\G*2!W:&5R92!T;R!P=70@
M=&AE(&9I;&5S('EO=2!D;W=N;&]A9"X*("`@("`J(%1H92!R96UO=&4@<&%T
M:"!I<R!A=71O;6%T:6-A;&QY(&-O;7!L971E9"!W:71H('1H92!C=7)R96YT
M+7)E;6]T92UD:7(L(&EF('EO=2!G:79E"B`@("`@*B!A(')E;&%T:79E('!A
M=&@@=&\@=&AI<R!F=6YC=&EO;BX@66]U(&-A;B!G:79E(&$@<F5L871I=F4@
M<&%T:"!F;W(@=&AE("1L;V-A;%]P871H+`H@("`@("H@=&]O+B!4:&5N('1H
M92!S8W)I<'0M8F%S961I<B!W:6QL(&)E('5S960@9F]R(&-O;6QE=&EO;B!O
M9B!T:&4@<&%T:"X*("`@("`J(%1H92!P87)A;65T97(@)&]V97)W<FET92!W
M:6QL(&1E=&5R;6EN92P@=VAE=&AE<B!T;R!O=F5R=W)I=&4@97AI<W1I;F<@
M9FEL97,@;W(@;F]T+@H@("`@("H@4W1A;F1A<F0@9F]R('1H:7,@:7,@9F%L
M<V4N($9O=7)T:"!Y;W4@8V%N(&5X<&QI8VET;'D@<V5T(&$@;6]D92!F;W(@
M86QL('1R86YS9F5R+0H@("`@("H@86-T:6]N<R!D;VYE+B!)9B!Y;W4@9&\@
M;F]T('-E="!T:&ES+"!T:&4@;65T:&]D('1R:65S('1O(&1E=&5R;6EN92!T
M:&4@=')A;G-F97(M"B`@("`@*B!M;V1E(&)Y(&-H96-K:6YG('EO=7(@;6]D
M92UD:7)E8W1O<GD@9F]R('1H92!F:6QE+65X=&5N<VEO;BX@268@=&AE(&5X
M=&5N<VEO;B!I<R!N;W0*("`@("`J(&EN<VED92!T:&4@;6]D92UD:7)E8W1O
M<GDL(&ET('=I;&P@9V5T('EO=7(@9&5F875L="UM;V1E+@H@("`@("H*("`@
M("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'!A<F%M("`@<W1R:6YG("1R
M96UO=&5?<&%T:"!4:&4@<&%T:"!T;R!D;W=N;&]A9`H@("`@("H@0'!A<F%M
M("`@<W1R:6YG("1L;V-A;%]P871H("!4:&4@<&%T:"!T;R!D;W=N;&]A9"!T
M;PH@("`@("H@0'!A<F%M("`@8F]O;"`@("1O=F5R=W)I=&4@("`H;W!T:6]N
M86PI(%=H971H97(@=&\@;W9E<G=R:71E(&5X:7-T:6YG(&9I;&5S("AT<G5E
M*2!O<B!N;W0@*&9A;'-E+"!S=&%N9&%R9"DN"B`@("`@*B!`<&%R86T@("!I
M;G0@("`@)&UO9&4@("`@("`@("AO<'1I;VYA;"D@5&AE('1R86YS9F5R;6]D
M92`H96ET:&5R($944%]!4T-)22!O<B!&5%!?0DE.05)9*2X*("`@("`J($!R
M971U<FX@(&UI>&5D("`@("`@("`@("`@("`@5')U92!O;B!S=6-C97,L(&]T
M:&5R=VES92!014%2.CI%<G)O<@H@("`@("H@0'-E92`@("`@3D547T944%]%
M4E)?3U9%4E=2251%3$]#04Q&24Q%7T9/4D))1$1%3BP@3D547T944%]%4E)?
M3U9%4E=2251%3$]#04Q&24Q%7T9!24Q%1"P@3D547T944%]%4E)?3U9%4E=2
M251%3$]#04Q&24Q%7T9!24Q%1"P@3D547T944%]%4E)?4D5-3U1%4$%42$Y/
M1$E2+"!.151?1E107T524E],3T-!3%!!5$A.3T1)4BQ.151?1E107T524E]#
M4D5!5$5,3T-!3$1)4E]&04E,140*("`@("`J+PH@("`@"B`@("!F=6YC=&EO
M;B!G971296-U<G-I=F4H)')E;6]T95]P871H+"`D;&]C86Q?<&%T:"P@)&]V
M97)W<FET92`](&9A;'-E+"`D;6]D92`](&YU;&PI"B`@("!["B`@("`@("`@
M)')E;6]T95]P871H(#T@)'1H:7,M/E]C;VYS=')U8W1?<&%T:"@D<F5M;W1E
M7W!A=&@I.PH@("`@("`@(&EF("@A)'1H:7,M/E]C:&5C:U]D:7(H)')E;6]T
M95]P871H*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(D=I=F5N(')E;6]T92UP871H("<D<F5M;W1E7W!A=&@G('-E96US(&YO
M="!T;R!B92!A(&1I<F5C=&]R>2XB+"!.151?1E107T524E]214U/5$50051(
M3D]$25(I.PH@("`@("`@('T*("`@("`@("!I9B`H(21T:&ES+3Y?8VAE8VM?
M9&ER*"1L;V-A;%]P871H*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H(D=I=F5N(&QO8V%L+7!A=&@@)R1L;V-A;%]P871H)R!S
M965M<R!N;W0@=&\@8F4@82!D:7)E8W1O<GDN(BP@3D547T944%]%4E)?3$]#
M04Q0051(3D]$25(I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%`:7-?9&ER
M*"1L;V-A;%]P871H*2D@>PH@("`@("`@("`@("`D<F5S(#T@0&UK9&ER*"1L
M;V-A;%]P871H*3L*("`@("`@("`@("`@:68@*"$D<F5S*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D-O=6QD(&YO="!C
M<F5A=&4@9&ER("<D;&]C86Q?<&%T:"<B+"!.151?1E107T524E]#4D5!5$5,
M3T-!3$1)4E]&04E,140I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@("1D:7)?;&ES="`](&%R<F%Y*"D["B`@("`@("`@)&1I<E]L:7-T(#T@
M)'1H:7,M/FQS*"1R96UO=&5?<&%T:"P@3D547T944%]$25)37T].3%DI.PH@
M("`@("`@(&9O<F5A8V@@*"1D:7)?;&ES="!A<R`D9&ER7V5N=')Y*2!["B`@
M("`@("`@("`@(&EF("@D9&ER7V5N=')Y6R=N86UE)UT@(3T@)RXG("8F("1D
M:7)?96YT<GE;)VYA;64G72`A/2`G+BXG*2!["B`@("`@("`@("`@("`@("`D
M<F5M;W1E7W!A=&A?;F5W(#T@)')E;6]T95]P871H+B1D:7)?96YT<GE;(FYA
M;64B72XB+R(["B`@("`@("`@("`@("`@("`D;&]C86Q?<&%T:%]N97<@/2`D
M;&]C86Q?<&%T:"XD9&ER7V5N=')Y6R)N86UE(ETN(B\B.PH@("`@("`@("`@
M("`@("`@)')E<W5L="`]("1T:&ES+3YG971296-U<G-I=F4H)')E;6]T95]P
M871H7VYE=RP@)&QO8V%L7W!A=&A?;F5W+"`D;W9E<G=R:71E+"`D;6]D92D[
M"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/FES17)R;W(H)')E<W5L="DI
M('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D
M9FEL95]L:7-T(#T@87)R87DH*3L*("`@("`@("`D9FEL95]L:7-T(#T@)'1H
M:7,M/FQS*"1R96UO=&5?<&%T:"P@3D547T944%]&24Q%4U]/3DQ9*3L*("`@
M("`@("!F;W)E86-H("@D9FEL95]L:7-T(&%S("1F:6QE7V5N=')Y*2!["B`@
M("`@("`@("`@("1R96UO=&5?9FEL92`]("1R96UO=&5?<&%T:"XD9FEL95]E
M;G1R>5LB;F%M92)=.PH@("`@("`@("`@("`D;&]C86Q?9FEL92`]("1L;V-A
M;%]P871H+B1F:6QE7V5N=')Y6R)N86UE(ET["B`@("`@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^9V5T*"1R96UO=&5?9FEL92P@)&QO8V%L7V9I;&4L("1O
M=F5R=W)I=&4L("1M;V1E*3L*("`@("`@("`@("`@:68@*"1T:&ES+3YI<T5R
M<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@9G5N8W1I;VYA;&ET>2!A
M;&QO=W,@>6]U('1O('1R86YS9F5R(&$@=VAO;&4@9&ER96-T;W)Y+7-T<G5C
M='5R92!F<F]M('EO=7(*("`@("`J(&QO8V%L(&AO<W0@=&\@=&AE(')E;6]T
M92UF='`N(%EO=2!H879E('1O(&=I=F4@82!R96UO=&4M9&ER96-T;W)Y("AE
M;F1I;F<@=VET:`H@("`@("H@)R\G*2!A;F0@=&AE(&QO8V%L(&1I<F5C=&]R
M>2`H96YD:6YG('=I=&@@)R\G*2!W:&5R92!T;R!P=70@=&AE(&9I;&5S('EO
M=2!D;W=N;&]A9"X*("`@("`J(%1H92!R96UO=&4@<&%T:"!I<R!A=71O;6%T
M:6-A;&QY(&-O;7!L971E9"!W:71H('1H92!C=7)R96YT+7)E;6]T92UD:7(L
M(&EF('EO=2!G:79E"B`@("`@*B!A(')E;&%T:79E('!A=&@@=&\@=&AI<R!F
M=6YC=&EO;BX@66]U(&-A;B!G:79E(&$@<F5L871I=F4@<&%T:"!F;W(@=&AE
M("1L;V-A;%]P871H+`H@("`@("H@=&]O+B!4:&5N('1H92!S8W)I<'0M8F%S
M961I<B!W:6QL(&)E('5S960@9F]R(&-O;6QE=&EO;B!O9B!T:&4@<&%T:"X*
M("`@("`J(%1H92!P87)A;65T97(@)&]V97)W<FET92!W:6QL(&1E=&5R;6EN
M92P@=VAE=&AE<B!T;R!O=F5R=W)I=&4@97AI<W1I;F<@9FEL97,@;W(@;F]T
M+@H@("`@("H@4W1A;F1A<F0@9F]R('1H:7,@:7,@9F%L<V4N($9O=7)T:"!Y
M;W4@8V%N(&5X<&QI8VET;'D@<V5T(&$@;6]D92!F;W(@86QL('1R86YS9F5R
M+0H@("`@("H@86-T:6]N<R!D;VYE+B!)9B!Y;W4@9&\@;F]T('-E="!T:&ES
M+"!T:&4@;65T:&]D('1R:65S('1O(&1E=&5R;6EN92!T:&4@=')A;G-F97(M
M"B`@("`@*B!M;V1E(&)Y(&-H96-K:6YG('EO=7(@;6]D92UD:7)E8W1O<GD@
M9F]R('1H92!F:6QE+65X=&5N<VEO;BX@268@=&AE(&5X=&5N<VEO;B!I<R!N
M;W0*("`@("`J(&EN<VED92!T:&4@;6]D92UD:7)E8W1O<GDL(&ET('=I;&P@
M9V5T('EO=7(@9&5F875L="UM;V1E+@H@("`@("H*("`@("`J($!A8V-E<W,@
M('!U8FQI8PH@("`@("H@0'!A<F%M("`@<W1R:6YG("1R96UO=&5?<&%T:"!4
M:&4@<&%T:"!T;R!D;W=N;&]A9"`*("`@("`J($!P87)A;2`@('-T<FEN9R`D
M;&]C86Q?<&%T:"`@5&AE('!A=&@@=&\@9&]W;FQO860@=&\*("`@("`J($!P
M87)A;2`@(&)O;VP@("`D;W9E<G=R:71E("`@*&]P=&EO;F%L*2!7:&5T:&5R
M('1O(&]V97)W<FET92!E>&ES=&EN9R!F:6QE<R`H=')U92D@;W(@;F]T("AF
M86QS92P@<W1A;F1A<F0I+@H@("`@("H@0'!A<F%M("`@:6YT("`@("1M;V1E
M("`@("`@("`H;W!T:6]N86PI(%1H92!T<F%N<V9E<FUO9&4@*&5I=&AE<B!&
M5%!?05-#24D@;W(@1E107T))3D%262DN"B`@("`@*B!`<F5T=7)N("!M:7AE
M9"`@("`@("`@("`@("`@(%1R=64@;VX@<W5C8V5S+"!O=&AE<G=I<V4@4$5!
M4CHZ17)R;W(*("`@("`J($!S964@("`@($Y%5%]&5%!?15)27TQ/0T%,1DE,
M14Y/5$5825-4+"!.151?1E107T524E]/5D525U))5$5214U/5$5&24Q%7T9/
M4D))1$1%3BP@3D547T944%]%4E)?55!,3T%$1DE,15]&04E,140L($Y%5%]&
M5%!?15)27TQ/0T%,4$%42$Y/1$E2+"!.151?1E107T524E]214U/5$50051(
M3D]$25(*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!P=71296-U<G-I=F4H
M)&QO8V%L7W!A=&@L("1R96UO=&5?<&%T:"P@)&]V97)W<FET92`](&9A;'-E
M+"`D;6]D92`](&YU;&PI"B`@("!["B`@("`@("`@)')E;6]T95]P871H(#T@
M)'1H:7,M/E]C;VYS=')U8W1?<&%T:"@D<F5M;W1E7W!A=&@I.PH@("`@("`@
M(&EF("@A)'1H:7,M/E]C:&5C:U]D:7(H)&QO8V%L7W!A=&@I('Q\("%I<U]D
M:7(H)&QO8V%L7W!A=&@I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@B1VEV96X@;&]C86PM<&%T:"`G)&QO8V%L7W!A=&@G('-E
M96US(&YO="!T;R!B92!A(&1I<F5C=&]R>2XB+"!.151?1E107T524E],3T-!
M3%!!5$A.3T1)4BD["B`@("`@("`@?0H@("`@("`@(&EF("@A)'1H:7,M/E]C
M:&5C:U]D:7(H)')E;6]T95]P871H*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H(D=I=F5N(')E;6]T92UP871H("<D<F5M;W1E
M7W!A=&@G('-E96US(&YO="!T;R!B92!A(&1I<F5C=&]R>2XB+"!.151?1E10
M7T524E]214U/5$50051(3D]$25(I.PH@("`@("`@('T*("`@("`@("`D;VQD
M7W!A=&@@/2`D=&AI<RT^<'=D*"D["B`@("`@("`@:68@*"1T:&ES+3YI<T5R
M<F]R*"1T:&ES+3YC9"@D<F5M;W1E7W!A=&@I*2D@>PH@("`@("`@("`@("`D
M<F5S(#T@)'1H:7,M/FUK9&ER*"1R96UO=&5?<&%T:"D["B`@("`@("`@("`@
M(&EF("@D=&AI<RT^:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1R97,["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M)'1H:7,M/F-D*"1O;&1?<&%T:"D["B`@("`@("`@)&1I<E]L:7-T(#T@)'1H
M:7,M/E]L<U]L;V-A;"@D;&]C86Q?<&%T:"D["B`@("`@("`@9F]R96%C:"`H
M)&1I<E]L:7-T6R)D:7)S(ET@87,@)&1I<E]E;G1R>2D@>PH@("`@("`@("`@
M("`D<F5M;W1E7W!A=&A?;F5W(#T@)')E;6]T95]P871H+B1D:7)?96YT<GDN
M(B\B.PH@("`@("`@("`@("`D;&]C86Q?<&%T:%]N97<@/2`D;&]C86Q?<&%T
M:"XD9&ER7V5N=')Y+B(O(CL*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3YP=71296-U<G-I=F4H)&QO8V%L7W!A=&A?;F5W+"`D<F5M;W1E7W!A=&A?
M;F5W+"`D;W9E<G=R:71E+"`D;6]D92D["B`@("`@("`@("`@(&EF("@D=&AI
M<RT^:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&9O
M<F5A8V@@*"1D:7)?;&ES=%LB9FEL97,B72!A<R`D9FEL95]E;G1R>2D@>PH@
M("`@("`@("`@("`D<F5M;W1E7V9I;&4@/2`D<F5M;W1E7W!A=&@N)&9I;&5?
M96YT<GD["B`@("`@("`@("`@("1L;V-A;%]F:6QE(#T@)&QO8V%L7W!A=&@N
M)&9I;&5?96YT<GD["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^<'5T
M*"1L;V-A;%]F:6QE+"`D<F5M;W1E7V9I;&4L("1O=F5R=W)I=&4L("1M;V1E
M*3L*("`@("`@("`@("`@:68@*"1T:&ES+3YI<T5R<F]R*"1R97-U;'0I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%1H:7,@8VAE8VMS+"!W:&5T:&5R(&$@9FEL92!S:&]U;&0@
M8F4@=')A;G-F97)E9"!I;B!A<V-I:2T@;W(@8FEN87)Y+6UO9&4*("`@("`J
M(&)Y(&ET)W,@9FEL92UE>'1E;G-I;VXN($EF('1H92!F:6QE+65X=&5N<VEO
M;B!I<R!N;W0@<V5T(&]R"B`@("`@*B!T:&4@97AT96YS:6]N(&ES(&YO="!I
M;G-I9&4@;VYE(&]F('1H92!E>'1E;G-I;VXM9&ER<RP@=&AE(&%C='5A;"!S
M970*("`@("`J('1R86YS9F5R+6UO9&4@:7,@<F5T=7)N960N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<&%R86T@("!S=')I;F<@
M)&9I;&5N86UE("!4:&4@9FEL96YA;64@=&\@8F4@8VAE8VME9`H@("`@("H@
M0')E='5R;B`@:6YT("`@("`@("`@("`@("`@16ET:&5R($944%]!4T-)22!O
M<B!&5%!?0DE.05)9"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@8VAE8VM&
M:6QE17AT96YS:6]N*"1F:6QE;F%M92D*("`@('L*("`@("`@("`D<&%T=&5R
M;B`]("(O7"XH+BHI)"\B.PH@("`@("`@("1H87-?97AT96YS:6]N(#T@<')E
M9U]M871C:"@D<&%T=&5R;BP@)&9I;&5N86UE+"`D97)E9W,I.PH@("`@("`@
M(&EF("@A)&AA<U]E>'1E;G-I;VXI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?;6]D93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D97AT
M(#T@)&5R96=S6S%=.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D
M=&AI<RT^7V9I;&5?97AT96YS:6]N<ULD97AT72DI('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?9FEL95]E>'1E;G-I;VYS6R1E>'1=.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;6]D93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E="!T:&4@2&]S=&YA;64*("`@("`J"B`@("`@*B!`86-C
M97-S("!P=6)L:6,*("`@("`J($!P87)A;2`@('-T<FEN9R`D:&]S="!4:&4@
M2&]S=&YA;64@=&\@<V5T"B`@("`@*B!`<F5T=7)N("!B;V]L(%1R=64@;VX@
M<W5C8V5S<RP@;W1H97)W:7-E(%!%05(Z.D5R<F]R"B`@("`@*B!`<V5E("`@
M("!.151?1E107T524E](3U-43D%-14Y/4U1224Y'"B`@("`@*B\*("`@(`H@
M("`@9G5N8W1I;VX@<V5T2&]S=&YA;64H)&AO<W0I"B`@("!["B`@("`@("`@
M:68@*"%I<U]S=')I;F<H)&AO<W0I*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*")(;W-T;F%M92!M=7-T(&)E(&$@<W1R:6YG+B(L
M($Y%5%]&5%!?15)27TA/4U1.04U%3D]35%))3D<I.PH@("`@("`@('T*("`@
M("`@("`D=&AI<RT^7VAO<W1N86UE(#T@)&AO<W0["B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(%!O<G0*("`@
M("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!P87)A;2`@(&EN
M="`D<&]R="`@("!4:&4@4&]R="!T;R!S970*("`@("`J($!R971U<FX@(&)O
M;VP@5')U92!O;B!S=6-C97-S+"!O=&AE<G=I<V4@4$5!4CHZ17)R;W(*("`@
M("`J($!S964@("`@($Y%5%]&5%!?15)27U!/4E1,15-36D523PH@("`@("HO
M"B`@("`*("`@(&9U;F-T:6]N('-E=%!O<G0H)'!O<G0I"B`@("!["B`@("`@
M("`@:68@*"%I<U]I;G0H)'!O<G0I('Q\("@D<&]R="`\(#`I*2!["B`@("`@
M("`@("`@(%!%05(Z.G)A:7-E17)R;W(H(DEN=F%L:60@<&]R="X@2&%S('1O
M(&)E(&EN=&5G97(@/CT@,"(L($Y%5%]&5%!?15)27U!/4E1,15-36D523RD[
M"B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?<&]R="`]("1P;W)T.PH@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H
M92!5<V5R;F%M90H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@
M("H@0'!A<F%M("`@<W1R:6YG("1U<V5R(%1H92!5<V5R;F%M92!T;R!S970*
M("`@("`J($!R971U<FX@(&UI>&5D(%1R=64@;VX@<W5C8V5S<RP@;W1H97)W
M:7-E(%!%05(Z.D5R<F]R"B`@("`@*B!`<V5E("`@("!.151?1E107T524E]5
M4T523D%-14Y/4U1224Y'"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@<V5T
M57-E<FYA;64H)'5S97(I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1U<V5R
M*2!\?"`A:7-?<W1R:6YG*"1U<V5R*2D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G57-E<FYA;64@)'5S97(@:6YV86QI9"XG+"!.
M151?1E107T524E]54T523D%-14Y/4U1224Y'*3L*("`@("`@("!]"B`@("`@
M("`@)'1H:7,M/E]U<V5R;F%M92`]("1U<V5R.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4V5T('1H92!087-S=V]R9`H@("`@("H*("`@("`J($!A8V-E<W,@
M('!R:79A=&4*("`@("`J($!P87)A;2`@('-T<FEN9R`D<&%S<W=O<F0@(%1H
M92!087-S=V]R9"!T;R!S970*("`@("`J($!R971U<FX@('9O:60*("`@("`J
M($!S964@("`@($Y%5%]&5%!?15)27U!!4U-73U)$3D]35%))3D<*("`@("`J
M+PH@("`@"B`@("!F=6YC=&EO;B!S971087-S=V]R9"@D<&%S<W=O<F0I"B`@
M("!["B`@("`@("`@:68@*&5M<'1Y*"1P87-S=V]R9"D@?'P@(6ES7W-T<FEN
M9R@D<&%S<W=O<F0I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*"=087-S=V]R9"!X>'@@:6YV86QI9"XG+"!.151?1E107T524E]0
M05-35T]21$Y/4U1224Y'*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]P
M87-S=V]R9"`]("1P87-S=V]R9#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E
M="!T:&4@=')A;G-F97(M;6]D92X@66]U(&-A;B!U<V4@=&AE('!R961E9FEN
M960@8V]N<W1A;G1S"B`@("`@*B!&5%!?05-#24D@;W(@1E107T))3D%262X@
M5&AE(&UO9&4@=VEL;"!B92!S=&]R960@9F]R(&%N>2!F=7)T:&5R('1R86YS
M9F5R<RX*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!P
M87)A;2`@(&EN="`@("`D;6]D92`@5&AE(&UO9&4@=&\@<V5T"B`@("`@*B!`
M<F5T=7)N("!M:7AE9"`@("`@("`@(%1R=64@;VX@<W5C8V5S<RP@;W1H97)W
M:7-E(%!%05(Z.D5R<F]R"B`@("`@*B!`<V5E("`@("!.151?1E107T524E].
M3TU/1$5#3TY35`H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N('-E=$UO9&4H
M)&UO9&4I"B`@("!["B`@("`@("`@:68@*"@D;6]D92`]/2!&5%!?05-#24DI
M('Q\("@D;6]D92`]/2!&5%!?0DE.05)9*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^7VUO9&4@/2`D;6]D93L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"=&5%`M36]D92!H87,@96ET:&5R('1O(&)E($944%]!4T-)22!O
M<B!&5%!?0DE.05)9)RP@3D547T944%]%4E)?3D]-3T1%0T].4U0I.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@=')A;G-F97(M
M;65T:&]D('1O('!A<W-I=F4@;6]D90H@("`@("H*("`@("`J($!A8V-E<W,@
M('!U8FQI8PH@("`@("H@0')E='5R;B`@=F]I9`H@("`@("HO"B`@("`*("`@
M(&9U;F-T:6]N('-E=%!A<W-I=F4H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M<&%S<W8@/2!T<G5E.PH@("`@("`@($!F='!?<&%S=B@D=&AI<RT^7VAA;F1L
M92P@=')U92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE('1R86YS
M9F5R+6UE=&AO9"!T;R!A8W1I=F4@;6]D90H@("`@("H*("`@("`J($!A8V-E
M<W,@('!U8FQI8PH@("`@("H@0')E='5R;B`@=F]I9`H@("`@("HO"B`@("`*
M("`@(&9U;F-T:6]N('-E=$%C=&EV92@I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]P87-S=B`](&9A;'-E.PH@("`@("`@($!F='!?<&%S=B@D=&AI<RT^7VAA
M;F1L92P@9F%L<V4I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!T
M:6UE;W5T(&9O<B!&5%`@;W!E<F%T:6]N<PH@("`@("H@57-E('1H:7,@;65T
M:&]D('1O('-E="!A('1I;65O=70@9F]R($944"!O<&5R871I;VXN(%1I;65O
M=70@:&%S('1O(&)E(&%N(&EN=&5G97(N"B`@("`@*@H@("`@("H@0&%C97-S
M("`@<'5B;&EC"B`@("`@*B!`<&%R86T@("!I;G0@)'1I;65O=70@=&AE('1I
M;65O=70@=&\@=7-E"B`@("`@*B!`<F5T=7)N("!B;V]L(%1R=64@;VX@<W5C
M8V5S<RP@;W1H97)W:7-E(%!%05(Z.D5R<F]R"B`@("`@*B!`<V5E("`@("!.
M151?1E107T524E]424U%3U543$534UI%4D\L($Y%5%]&5%!?15)27U-%5%1)
M345/551?1D%)3$5$"B`@("`@*B\*("`@("`*("`@(&9U;F-T:6]N('-E=%1I
M;65O=70@*"`D=&EM96]U="`](#`@*2`*("`@('L*("`@("`@("!I9B`H(6ES
M7VEN="@D=&EM96]U="D@?'P@*"1T:6UE;W5T(#P@,"DI('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(E1I;65O=70@)'1I;65O=70@
M:7,@:6YV86QI9"P@:&%S('1O(&)E(&%N(&EN=&5G97(@/CT@,"(L($Y%5%]&
M5%!?15)27U1)345/551,15-36D523RD["B`@("`@("`@?0H@("`@("`@("1T
M:&ES+3Y?=&EM96]U="`]("1T:6UE;W5T.PH@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7VAA;F1L92D@)B8@:7-?<F5S;W5R8V4H)'1H:7,M/E]H86YD;&4I
M*2!["B`@("`@("`@("`@("1R97,@/2!`9G1P7W-E=%]O<'1I;VXH)'1H:7,M
M/E]H86YD;&4L($944%]424U%3U547U-%0RP@)'1I;65O=70I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1R97,@/2!T<G5E.PH@("`@("`@('T*
M("`@("`@("!I9B`H(21R97,I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H(E-E="!T:6UE;W5T(&9A:6QE9"XB+"!.151?1E107T52
M4E]3151424U%3U547T9!24Q%1"D["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?2`@("`@("`@"B`@("`*("`@("\J*@H@("`@("H@061D
M<R!A;B!E>'1E;G-I;VX@=&\@82!M;V1E+61I<F5C=&]R>0H@("`@("H@5&AE
M(&UO9&4M9&ER96-T;W)Y('-A=F5S(&9I;&4M97AT96YS:6]N<R!C;W)E<W!O
M;F1I;F<@=&\@9FEL971Y<&5S"B`@("`@*B`H87-C:6D@92YG+CH@)W!H<"<L
M("=T>'0G+"`G:'1M)RPN+BX[(&)I;F%R>2!E+F<N.B`G:G!G)RP@)V=I9B<L
M("=E>&4G+"XN+BDN"B`@("`@*B!4:&4@97AT96YS:6]N<R!H879E('1O(&)E
M('-A=F5D('=I=&AO=70@=&AE("<N)RX@06YD"B`@("`@*B!C86X@8F4@<')E
M9&5F:6YE9"!I;B!A;B!E>'1E<FYA;"!F:6QE("AS964Z(&=E=$5X=&5N<VEO
M;G-&:6QE*"DI+@H@("`@("H*("`@("`J(%1H92!A<G)A>2!I<R!B=6EL9"!L
M:6ME('1H:7,Z("=P:'`G(#T^($944%]!4T-)22P@)W!N9R<@/3X@1E107T))
M3D%260H@("`@("H*("`@("`J(%1O(&-H86YG92!T:&4@;6]D92!O9B!A;B!E
M>'1E;G-I;VXL(&IU<W0@861D(&ET(&%G86EN('=I=&@@=&AE(&YE=R!M;V1E
M(0H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'!A<F%M
M("`@:6YT("`@("1M;V1E("!%:71H97(@1E107T%30TE)(&]R($944%]"24Y!
M4ED*("`@("`J($!P87)A;2`@('-T<FEN9R`D97AT("`@17AT96YS:6]N"B`@
M("`@*B!`<F5T=7)N("!V;VED"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@
M861D17AT96YS:6]N*"1M;V1E+"`D97AT*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?9FEL95]E>'1E;G-I;VYS6R1E>'1=(#T@)&UO9&4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!4:&ES(&9U;F-T:6]N(')E;6]V97,@86X@97AT96YS:6]N
M(&9R;VT@=&AE(&UO9&4M9&ER96-T;W)I97,@"B`@("`@*B`H9&5S8W)I8F5D
M(&%B;W9E*2X*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J
M($!P87)A;2`@('-T<FEN9R`D97AT("!4:&4@97AT96YS:6]N('1O(')E;6]V
M90H@("`@("H@0')E='5R;B`@=F]I9`H@("`@("HO"B`@("`*("`@(&9U;F-T
M:6]N(')E;6]V945X=&5N<VEO;B@D97AT*0H@("`@>PH@("`@("`@('5N<V5T
M*"1T:&ES+3Y?9FEL95]E>'1E;G-I;VYS6R1E>'1=*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%1H:7,@9V5T)W,@8F]T:"`H87-C:6DM(&%N9"!B:6YA<GDM
M;6]D92UD:7)E8W1O<FEE<RD@9G)O;2!T:&4@9VEV96X@9FEL92X*("`@("`J
M($)E=V%R92P@:68@>6]U(')E860@82!F:6QE(&EN=&\@=&AE(&UO9&4M9&ER
M96-T;W)Y+"!A;&P@9F]R;65R('-E="!V86QU97,@"B`@("`@*B!W:6QL(&)E
M('5N<V5T(0H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@
M0'!A<F%M("`@<W1R:6YG("1F:6QE;F%M92`@5&AE(&9I;&4@=&\@9V5T(&9R
M;VT*("`@("`J($!R971U<FX@(&UI>&5D("`@("`@("`@("`@(%1R=64@;VX@
M<W5C8V5S<RP@;W1H97)W:7-E(%!%05(Z.D5R<F]R"B`@("`@*B!`<V5E("`@
M("!.151?1E107T524E]%6%1&24Q%3D]415A)4U0L($Y%5%]&5%!?15)27T58
M5$9)3$5214%$7T9!24Q%1`H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N(&=E
M=$5X=&5N<VEO;G-&:6QE*"1F:6QE;F%M92D*("`@('L*("`@("`@("!I9B`H
M(69I;&5?97AI<W1S*"1F:6QE;F%M92DI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*")%>'1E;G-I;VYS+69I;&4@)R1F:6QE;F%M
M92<@9&]E<R!N;W0@97AI<W0B+"!.151?1E107T524E]%6%1&24Q%3D]415A)
M4U0I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<U]R96%D86)L92@D9FEL
M96YA;64I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B17AT96YS:6]N<RUF:6QE("<D9FEL96YA;64G(&ES(&YO="!R96%D86)L
M92(L($Y%5%]&5%!?15)27T585$9)3$5214%$7T9!24Q%1"D["B`@("`@("`@
M?0H*("`@("`@("`D=&AI<RT^7V9I;&5?97AT96YS:6]N(#T@0'!A<G-E7VEN
M:5]F:6QE*"1F:6QE;F%M92D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!(;W-T;F%M90H@("`@("H*
M("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0')E='5R;B`@<W1R:6YG
M("!4:&4@2&]S=&YA;64*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!G971(
M;W-T;F%M92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?:&]S=&YA
M;64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!0;W)T"B`@
M("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<F5T=7)N("!I
M;G0@("`@(%1H92!0;W)T"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@9V5T
M4&]R="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&]R=#L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(%5S97)N86UE"B`@("`@
M*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<F5T=7)N("!S=')I
M;F<@(%1H92!5<V5R;F%M90H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N(&=E
M=%5S97)N86UE*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]U<V5R
M;F%M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(%!A<W-W
M;W)D"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<F5T
M=7)N("!S=')I;F<@(%1H92!087-S=V]R9`H@("`@("HO"B`@("`*("`@(&9U
M;F-T:6]N(&=E=%!A<W-W;W)D*"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]P87-S=V]R9#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE(%1R86YS9F5R;6]D90H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI
M8PH@("`@("H@0')E='5R;B`@:6YT("`@("!4:&4@=')A;G-F97)M;V1E+"!E
M:71H97(@1E107T%30TE)(&]R($944%]"24Y!4EDN"B`@("`@*B\*("`@(`H@
M("`@9G5N8W1I;VX@9V5T36]D92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?;6]D93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,L('=H
M971H97(@=&AE(&-O;FYE8W1I;VX@:7,@<V5T('1O('!A<W-I=F4@;6]D92!O
M<B!N;W0*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!R
M971U<FX@(&)O;VP@("`@5')U92!I9B!P87-S:79E+2P@9F%L<V4@:68@86-T
M:79E+6UO9&4*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!I<U!A<W-I=F4H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W!A<W-V.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;6]D92!S970@9F]R(&$@9FEL
M92UE>'1E;G-I;VX*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@
M("`J($!P87)A;2`@('-T<FEN9R`@("1E>'0@("`@5&AE(&5X=&5N<VEO;B!Y
M;W4@=V%N;F$@87-K(&9O<@H@("`@("H@0')E='5R;B`@:6YT("`@("`@("`@
M("`@("!%:71H97(@1E107T%30TE)+"!&5%!?0DE.05)9(&]R($Y53$P@*&EF
M(&YO="!S970@82!M;V1E(&9O<B!I="D*("`@("`J+PH@("`@"B`@("!F=6YC
M=&EO;B!G971%>'1E;G-I;VY-;V1E*"1E>'0I"B`@("!["B`@("`@("`@<F5T
M=7)N($`D=&AI<RT^7V9I;&5?97AT96YS:6]N<ULD97AT73L*("`@('T*"B`@
M("`O*BH*("`@("`J($=E="!T:&4@8W5R<F5N=&QY('-E="!T:6UE;W5T+@H@
M("`@("H@4F5T=7)N<R!T:&4@86-T=6%L('1I;65O=70@<V5T+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&EN="!4:&4@
M86-T=6%L('1I;65O=70*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!G9714
M:6UE;W5T("@@*0H@("`@>PH@("`@("`@(')E='5R;B!F='!?9V5T7V]P=&EO
M;B@D=&AI<RT^7VAA;F1L92P@1E107U1)345/551?4T5#*3L*("`@('T@("`@
M"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@3F5T7T944%]/8G-E<G9E<B!I;G-T
M86YC92!T;R!T:&4@;&ES="!O9B!O8G-E<G9E<G,@"B`@("`@*B!T:&%T(&%R
M92!L:7-T96YI;F<@9F]R(&UE<W-A9V5S(&5M:71T960@8GD@=&AI<R!.971?
M1E10(&EN<W1A;F-E+@H@("`@("H*("`@("`J($!P87)A;2`@(&]B:F5C="`@
M("1O8G-E<G9E<B`@("`@5&AE($YE=%]&5%!?3V)S97)V97(@:6YS=&%N8V4@
M=&\@871T86-H(`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<R!A(&QI<W1E;F5R+@H@("`@("H@0')E='5R;B`@8F]O;&5A;B`@
M("`@("`@("`@("`@("!4<G5E(&EF('1H92!O8G-E<G9E<B!I<R!S=6-C97-S
M9G5L;'D@871T86-H960N"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J
M($!S:6YC92`@(#$N,PH@("`@("HO"B`@("`*("`@(&9U;F-T:6]N(&%T=&%C
M:"@F)&]B<V5R=F5R*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D;V)S97)V
M97(L("=.971?1E107T]B<V5R=F5R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]L:7-T96YE<G-;
M)&]B<V5R=F5R+3YG971)9"@I72`]("8D;V)S97)V97(["B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(&$@3F5T
M7T944%]/8G-E<G9E<B!I;G-T86YC92!F<F]M('1H92!L:7-T(&]F(&]B<V5R
M=F5R<RX*("`@("`J"B`@("`@*B!`<&%R86T@("!O8FIE8W0@("`D;V)S97)V
M97(@("`@(%1H92!.971?1E107T]B<V5R=F5R(&EN<W1A;F-E('1O(&1E=&%C
M:"`*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9G)O
M;2!T:&4@;&ES="!O9B!L:7-T96YE<G,N"B`@("`@*B!`<F5T=7)N("!B;V]L
M96%N("`@("`@("`@("`@("`@(%1R=64@:68@=&AE(&]B<V5R=F5R(&ES('-U
M8V-E<W-F=6QL>2!D971A8VAE9"X*("`@("`J($!A8V-E<W,@('!U8FQI8PH@
M("`@("H@0'-I;F-E("`@,2XS"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@
M9&5T86-H*"1O8G-E<G9E<BD*("`@('L*("`@("`@("!I9B`H(6ES7V$H)&]B
M<V5R=F5R+"`G3F5T7T944%]/8G-E<G9E<B<I('Q\"B`@("`@("`@("`@("%I
M<W-E="@D=&AI<RT^7VQI<W1E;F5R<ULD;V)S97)V97(M/F=E=$ED*"E=*2D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("!U;G-E="@D=&AI<RT^7VQI<W1E;F5R<ULD;V)S97)V97(M/F=E=$ED*"E=
M*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M($EN9F]R;7,@96%C:"!R96=I<W1E<F5D(&]B<V5R=F5R(&EN<W1A;F-E('1H
M870@82!N97<@;65S<V%G92!H87,@8F5E;@H@("`@("H@<V5N="X@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`*
M("`@("`J($!P87)A;2`@(&UI>&5D("`@("`D979E;G0@("`@("`@02!H87-H
M(&1E<V-R:6)I;F<@=&AE(&YE="!E=F5N="X@("`*("`@("`J($!A8V-E<W,@
M('!R:79A=&4@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(`H@("`@("H@0'-I;F-E("`@,2XS("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@"B`@("`@*B\@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`*("`@(`H@("`@
M9G5N8W1I;VX@7V%N;F]U;F-E*"1E=F5N="D*("`@('L*("`@("`@("!F;W)E
M86-H("@D=&AI<RT^7VQI<W1E;F5R<R!A<R`D:60@/3X@)&QI<W1E;F5R*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?;&ES=&5N97)S6R1I9%TM/FYO=&EF>2@D
M979E;G0I.PH@("`@("`@('T*("`@('T*("`@(`H@("`@("`@("\J*@H@("`@
M("H@4F5B=6EL9"!T:&4@<&%T:"P@:68@9VEV96X@<F5L871I=F4*("`@("`J
M"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B!`<&%R86T@("!S=')I
M;F<@)'!A=&@@("!4:&4@<&%T:"!T;R!C:&5C:R!A;F0@8V]N<W1R=6-T"B`@
M("`@*B!`<F5T=7)N("!S=')I;F<@("`@("`@("!4:&4@8G5I;&0@<&%T:`H@
M("`@("HO"B`@("`*("`@(&9U;F-T:6]N(%]C;VYS=')U8W1?<&%T:"@D<&%T
M:"D*("`@('L*("`@("`@("!I9B`H*'-U8G-T<B@D<&%T:"P@,"P@,2D@(3T@
M(B\B*2`F)B`H<W5B<W1R*"1P871H+"`P+"`R*2`A/2`B+B\B*2D@>PH@("`@
M("`@("`@("`D86-T=6%L7V1I<B`]($!F='!?<'=D*"1T:&ES+3Y?:&%N9&QE
M*3L*("`@("`@("`@("`@:68@*'-U8G-T<B@D86-T=6%L7V1I<BP@*'-T<FQE
M;B@D86-T=6%L7V1I<BD@+2`R*2P@,2D@(3T@(B\B*2!["B`@("`@("`@("`@
M("`@("`D86-T=6%L7V1I<B`N/2`B+R(["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'!A=&@@/2`D86-T=6%L7V1I<BXD<&%T:#L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1P871H.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE
M8VMS+"!W:&5T:&5R(&$@9VEV96X@<W1R:6YG(&ES(&$@9&ER96-T;W)Y+7!A
M=&@@*&5N9',@=VET:"`B+R(I(&]R(&YO="X*("`@("`J"B`@("`@*B!`86-C
M97-S("!P<FEV871E"B`@("`@*B!`<&%R86T@("!S=')I;F<@)'!A=&@@(%!A
M=&@@=&\@8VAE8VL*("`@("`J($!R971U<FX@(&)O;VP@("`@("`@("`@5')U
M92!I9B`D<&%T:"!I<R!A(&1I<F5C=&]R>2P@;W1H97)W:7-E(&9A;'-E"B`@
M("`@*B\*("`@(`H@("`@9G5N8W1I;VX@7V-H96-K7V1I<B@D<&%T:"D*("`@
M('L*("`@("`@("!I9B`H(65M<'1Y*"1P871H*2`F)B!S=6)S='(H)'!A=&@L
M("AS=')L96XH)'!A=&@I("T@,2DL(#$I(#T]("(O(BD@>PH@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M5&AI<R!W:6QL(')E;6]V92!A(&9I;&4*("`@("`J"B`@("`@*B!`86-C97-S
M("!P<FEV871E"B`@("`@*B!`<&%R86T@("!S=')I;F<@)&9I;&4@("!4:&4@
M9FEL92!T;R!D96QE=&4*("`@("`J($!R971U<FX@(&UI>&5D("`@("`@("`@
M(%1R=64@;VX@<W5C8V5S<RP@;W1H97)W:7-E(%!%05(Z.D5R<F]R"B`@("`@
M*B!`<V5E("`@("!.151?1E107T524E]$14Q%5$5&24Q%7T9!24Q%1`H@("`@
M("HO"B`@("`*("`@(&9U;F-T:6]N(%]R;5]F:6QE*"1F:6QE*0H@("`@>PH@
M("`@("`@(&EF("AS=6)S='(H)&9I;&4L(#`L(#$I("$]("(O(BD@>PH@("`@
M("`@("`@("`D86-T=6%L7V1I<B`]($!F='!?<'=D*"1T:&ES+3Y?:&%N9&QE
M*3L*("`@("`@("`@("`@:68@*'-U8G-T<B@D86-T=6%L7V1I<BP@*'-T<FQE
M;B@D86-T=6%L7V1I<BD@+2`R*2P@,2D@(3T@(B\B*2!["B`@("`@("`@("`@
M("`@("`D86-T=6%L7V1I<B`N/2`B+R(["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&9I;&4@/2`D86-T=6%L7V1I<BXD9FEL93L*("`@("`@("!]"B`@
M("`@("`@)')E<R`]($!F='!?9&5L971E*"1T:&ES+3Y?:&%N9&QE+"`D9FEL
M92D["B`@("`@("`@"B`@("`@("`@:68@*"$D<F5S*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B0V]U;&0@;F]T(&1E;&5T92!F
M:6QE("<D9FEL92<N(BP@3D547T944%]%4E)?1$5,151%1DE,15]&04E,140I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@=VEL;"!R96UO
M=F4@82!D:7(*("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@
M*B!`<&%R86T@("!S=')I;F<@)&1I<B`@5&AE(&1I<B!T;R!D96QE=&4*("`@
M("`J($!R971U<FX@(&UI>&5D("`@("`@("!4<G5E(&]N('-U8V-E<W,L(&]T
M:&5R=VES92!014%2.CI%<G)O<@H@("`@("H@0'-E92`@("`@3D547T944%]%
M4E)?4D5-3U1%4$%42$Y/1$E2+"!.151?1E107T524E]$14Q%5$5$25)?1D%)
M3$5$"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@7W)M7V1I<B@D9&ER*0H@
M("`@>PH@("`@("`@(&EF("AS=6)S='(H)&1I<BP@*'-T<FQE;B@D9&ER*2`M
M(#$I+"`Q*2`A/2`B+R(I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*")$:7)E8W1O<GD@;F%M92`G)&1I<B<@:7,@:6YV86QI9"P@
M:&%S('1O(&5N9"!W:71H("<O)R(L($Y%5%]&5%!?15)27U)%34]415!!5$A.
M3T1)4BD["B`@("`@("`@?0H@("`@("`@("1R97,@/2!`9G1P7W)M9&ER*"1T
M:&ES+3Y?:&%N9&QE+"`D9&ER*3L*("`@("`@("!I9B`H(21R97,I('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")#;W5L9"!N;W0@
M9&5L971E(&1I<F5C=&]R>2`G)&1I<B<N(BP@3D547T944%]%4E)?1$5,151%
M1$E27T9!24Q%1"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5&AI
M<R!W:6QL(')E;6]V92!A(&1I<B!A;F0@86QL('-U8F1I<G,@86YD("UF:6QE
M<PH@("`@("H*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J($!P87)A
M;2`@('-T<FEN9R`D9FEL92`@5&AE(&1I<B!T;R!D96QE=&4@<F5C=7)S:79E
M;'D*("`@("`J($!R971U<FX@(&UI>&5D("`@("`@("`@5')U92!O;B!S=6-C
M97-S+"!O=&AE<G=I<V4@4$5!4CHZ17)R;W(*("`@("`J($!S964@("`@($Y%
M5%]&5%!?15)27U)%34]415!!5$A.3T1)4BP@3D547T944%]%4E)?1$5,151%
M1$E27T9!24Q%1`H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N(%]R;5]D:7)?
M<F5C=7)S:79E*"1D:7(I"B`@("!["B`@("`@("`@:68@*'-U8G-T<B@D9&ER
M+"`H<W1R;&5N*"1D:7(I("T@,2DL(#$I("$]("(O(BD@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D1I<F5C=&]R>2!N86UE("<D
M9&ER)R!I<R!I;G9A;&ED+"!H87,@=&\@96YD('=I=&@@)R\G(BP@3D547T94
M4%]%4E)?4D5-3U1%4$%42$Y/1$E2*3L*("`@("`@("!]"B`@("`@("`@)&9I
M;&5?;&ES="`]("1T:&ES+3Y?;'-?9FEL97,H)&1I<BD["B`@("`@("`@9F]R
M96%C:"`H)&9I;&5?;&ES="!A<R`D9FEL92D@>PH@("`@("`@("`@("`D9FEL
M92`]("1D:7(N)&9I;&5;(FYA;64B73L*("`@("`@("`@("`@)')E<R`]("1T
M:&ES+3YR;2@D9FEL92D["B`@("`@("`@("`@(&EF("@D=&AI<RT^:7-%<G)O
M<B@D<F5S*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("`@("`@)&1I<E]L:7-T(#T@)'1H:7,M
M/E]L<U]D:7)S*"1D:7(I.PH@("`@("`@(&9O<F5A8V@@*"1D:7)?;&ES="!A
M<R`D;F5W7V1I<BD@>PH@("`@("`@("`@("`D;F5W7V1I<B`]("1D:7(N)&YE
M=U]D:7);(FYA;64B72XB+R(["B`@("`@("`@("`@("1R97,@/2`D=&AI<RT^
M7W)M7V1I<E]R96-U<G-I=F4H)&YE=U]D:7(I.PH@("`@("`@("`@("!I9B`H
M)'1H:7,M/FES17)R;W(H)')E<RDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D<F5S.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1R97,@
M/2`D=&AI<RT^7W)M7V1I<B@D9&ER*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D<F5S*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!,:7-T<R!U<"!F:6QE<R!A;F0@9&ER
M96-T;W)I97,*("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@
M*B!`<&%R86T@("!S=')I;F<@)&1I<B`@5&AE(&1I<F5C=&]R>2!T;R!L:7-T
M('5P"B`@("`@*B!`<F5T=7)N("!A<G)A>2`@("`@("`@06X@87)R87D@;V8@
M9&ER<R!A;F0@9FEL97,*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!?;'-?
M8F]T:"@D9&ER*0H@("`@>PH@("`@("`@("1L:7-T7W-P;&ET=&5D(#T@)'1H
M:7,M/E]L:7-T7V%N9%]P87)S92@D9&ER*3L*("`@("`@("!I9B`H(6ES7V%R
M<F%Y*"1L:7-T7W-P;&ET=&5D6R)F:6QE<R)=*2D@>PH@("`@("`@("`@("`D
M;&ES=%]S<&QI='1E9%LB9FEL97,B72`](&%R<F%Y*"D["B`@("`@("`@?0H@
M("`@("`@(&EF("@A:7-?87)R87DH)&QI<W1?<W!L:71T961;(F1I<G,B72DI
M('L*("`@("`@("`@("`@)&QI<W1?<W!L:71T961;(F1I<G,B72`](&%R<F%Y
M*"D["B`@("`@("`@?0H@("`@("`@("1R97,@/2!A<G)A>2@I.PH@("`@("`@
M($!A<G)A>5]S<&QI8V4H)')E<RP@,"P@,"P@)&QI<W1?<W!L:71T961;(F9I
M;&5S(ETI.PH@("`@("`@($!A<G)A>5]S<&QI8V4H)')E<RP@,"P@,"P@)&QI
M<W1?<W!L:71T961;(F1I<G,B72D["B`@("`@("`@<F5T=7)N("1R97,["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!,:7-T<R!U<"!D:7)E8W1O<FEE<PH@("`@
M("H*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J($!P87)A;2`@('-T
M<FEN9R`D9&ER("!4:&4@9&ER96-T;W)Y('1O(&QI<W0@=7`*("`@("`J($!R
M971U<FX@(&%R<F%Y("`@("`@("!!;B!A<G)A>2!O9B!D:7)S"B`@("`@*B\*
M("`@(`H@("`@9G5N8W1I;VX@7VQS7V1I<G,H)&1I<BD*("`@('L*("`@("`@
M("`D;&ES="`]("1T:&ES+3Y?;&ES=%]A;F1?<&%R<V4H)&1I<BD["B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&QI<W0I*2!["B`@("`@("`@("`@(')E
M='5R;B`D;&ES=#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1L:7-T6R)D
M:7)S(ET["B`@("!]"@H@("`@+RHJ"B`@("`@*B!,:7-T<R!U<"!F:6QE<PH@
M("`@("H*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J($!P87)A;2`@
M('-T<FEN9R`D9&ER("!4:&4@9&ER96-T;W)Y('1O(&QI<W0@=7`*("`@("`J
M($!R971U<FX@(&%R<F%Y("`@("`@("!!;B!A<G)A>2!O9B!F:6QE<PH@("`@
M("HO"B`@("`*("`@(&9U;F-T:6]N(%]L<U]F:6QE<R@D9&ER*0H@("`@>PH@
M("`@("`@("1L:7-T(#T@)'1H:7,M/E]L:7-T7V%N9%]P87)S92@D9&ER*3L*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D;&ES="DI('L*("`@("`@("`@
M("`@<F5T=7)N("1L:7-T.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&QI
M<W1;(F9I;&5S(ET["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&QI<W1S
M('5P('1H92!D:7)E8W1O<GDM8V]N=&5N="!A;F0@<&%R<V5S('1H92!I=&5M
M<R!I;G1O('=E;&PM9F]R;6%T960@87)R87ES"B`@("`@*B!4:&4@<F5S=6QT
M<R!O9B!T:&ES(&%R<F%Y(&%R92!S;W)T960@*&1I<G,@;VX@=&]P+"!S;W)T
M960@8GD@;F%M93L*("`@("`J(&9I;&5S(&)E;&]W+"!S;W)T960@8GD@;F%M
M92DN"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("H@0'!A
M<F%M("`@<W1R:6YG("1D:7(@(%1H92!D:7)E8W1O<GD@=&\@<&%R<V4*("`@
M("`J($!R971U<FX@(&%R<F%Y("`@("`@("!,:7-T<R!O9B!D:7)S(&%N9"!F
M:6QE<PH@("`@("H@0'-E92`@("`@3D547T944%]%4E)?4D%71$E23$E35%]&
M04E,140*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!?;&ES=%]A;F1?<&%R
M<V4H)&1I<BD*("`@('L*("`@("`@("`D9&ER<U]L:7-T(#T@87)R87DH*3L*
M("`@("`@("`D9FEL97-?;&ES="`](&%R<F%Y*"D["B`@("`@("`@)&1I<E]L
M:7-T(#T@0&9T<%]R87=L:7-T*"1T:&ES+3Y?:&%N9&QE+"`D9&ER*3L*("`@
M("`@("!I9B`H(6ES7V%R<F%Y*"1D:7)?;&ES="DI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-O=6QD(&YO="!G970@<F%W(&1I
M<F5C=&]R>2!L:7-T:6YG+B<L($Y%5%]&5%!?15)27U)!5T1)4DQ)4U1?1D%)
M3$5$*3L*("`@("`@("!]"B`@("`@("`@+R\@2&%N9&QE(&5M<'1Y(&1I<F5C
M=&]R:65S"B`@("`@("`@:68@*&-O=6YT*"1D:7)?;&ES="D@/3T@,"D@>PH@
M("`@("`@("`@("!R971U<FX@87)R87DH)V1I<G,G(#T^("1D:7)S7VQI<W0L
M("=F:6QE<R<@/3X@)&9I;&5S7VQI<W0I.PH@("`@("`@('T*("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3Y?;6%T8VAE<BD@?'P@4$5!4CHZ:7-%<G)O<B@D
M=&AI<RT^7VUA=&-H97(I*2!["B`@("`@("`@("`@("1T:&ES+3Y?;6%T8VAE
M<B`]("1T:&ES+3Y?9&5T97)M:6YE7V]S7VUA=&-H*"1D:7)?;&ES="D["B`@
M("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1T:&ES+3Y?;6%T8VAE<BDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VUA=&-H97(["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H)&1I<E]L
M:7-T(&%S("1E;G1R>2D@>PH@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H
M)'1H:7,M/E]M871C:&5R6R=P871T97)N)UTL("1E;G1R>2P@)&TI*2!["B`@
M("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D96YT<GD@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D
M=&AI<RT^7VUA=&-H97);)VUA<"==(&%S("1K97D]/B1V86PI('L*("`@("`@
M("`@("`@("`@("1E;G1R>5LD:V5Y72`]("1M6R1V86Q=.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1E;G1R>5LG<W1A;7`G72`]("1T:&ES+3Y?<&%R
M<V5?1&%T92@D96YT<GE;)V1A=&4G72D["@H@("`@("`@("`@("!I9B`H)&5N
M=')Y6R=I<U]D:7(G72D@>PH@("`@("`@("`@("`@("`@)&1I<G-?;&ES=%M=
M(#T@)&5N=')Y.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)&9I;&5S7VQI<W1;72`]("1E;G1R>3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("!`=7-O<G0H)&1I<G-?;&ES="P@87)R87DH(DYE=%]&
M5%`B+"`B7VYA=%]S;W)T(BDI.PH@("`@("`@($!U<V]R="@D9FEL97-?;&ES
M="P@87)R87DH(DYE=%]&5%`B+"`B7VYA=%]S;W)T(BDI.PH@("`@("`@("1R
M97-;(F1I<G,B72`]("AI<U]A<G)A>2@D9&ER<U]L:7-T*2D@/R`D9&ER<U]L
M:7-T(#H@87)R87DH*3L*("`@("`@("`D<F5S6R)F:6QE<R)=(#T@*&ES7V%R
M<F%Y*"1F:6QE<U]L:7-T*2D@/R`D9FEL97-?;&ES="`Z(&%R<F%Y*"D["B`@
M("`@("`@<F5T=7)N("1R97,["B`@("!]"B`@("`*("`@("\J*@H@("`@("H@
M1&5T97)M:6YE('-E<G9E<B!/4PH@("`@("H@5&AI<R!D971E<FUI;F5S('1H
M92!S97)V97(@3U,@86YD(')E='5R;G,@82!V86QI9"!R96=E>"!T;R!P87)S
M90H@("`@("H@;',H*2!O=71P=70N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@
M<')I=F%T90H@("`@("H@0'!A<F%M("`@87)R87D@)&1I<E]L:7-T(%1H92!R
M87<@9&ER(&QI<W0@=&\@<&%R<V4*("`@("`J($!R971U<FX@(&UI>&5D($%N
M(&%R<F%Y(&]F("=P871T97)N)R!A;F0@)VUA<"<@;VX@<W5C8V5S<RP@;W1H
M97)W:7-E(%!%05(Z.D5R<F]R"B`@("`@*B!`<V5E("`@("!.151?1E107T52
M4E]$25),25-47U5.4U504$]25$5$"B`@("`@*B\*("`@(`H@("`@9G5N8W1I
M;VX@7V1E=&5R;6EN95]O<U]M871C:"@F)&1I<E]L:7-T*2!["B`@("!F;W)E
M86-H("@D9&ER7VQI<W0@87,@)&5N=')Y*2!["B`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/E]L<U]M871C:"!A<R`D;W,@/3X@)&UA=&-H*2!["B`@("`@("`@
M("`@(&EF("AP<F5G7VUA=&-H*"1M871C:%LG<&%T=&5R;B==+"`D96YT<GDI
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1M871C:#L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@?0H@("`@("`@("1E<G)O
M<B`]("=4:&4@;&ES="!S='EL92!O9B!Y;W5R('-E<G9E<B!S965M<R!N;W0@
M=&\@8F4@<W5P<&]R=&5D+B!0;&5A<V4@96UA:6P@82`B)&9T<"T^;',H3D54
M7T944%]205=,25-4*3LB(&]U='!U="!P;'5S(&EN9F\@;VX@=&AE('-E<G9E
M<B!T;R!T:&4@;6%I;G1A:6YE<B!O9B!T:&ES('!A8VMA9V4@=&\@9V5T(&ET
M('-U<'!O<G1E9"$@5&AA;FMS(&9O<B!Y;W5R(&AE;'`A)SL*("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D97)R;W(L($Y%5%]&5%!?15)27T1)
M4DQ)4U1?54Y355!03U)4140I.PH@("`@?0H@("`@+RHJ"B`@("`@*B!,:7-T
M<R!A(&QO8V%L(&1I<F5C=&]R>0H@("`@("H*("`@("`J($!A8V-E<W,@('!R
M:79A=&4*("`@("`J($!P87)A;2`@('-T<FEN9R`D9&ER7W!A=&@@(%1H92!D
M:7(@=&\@;&ES=`H@("`@("H@0')E='5R;B`@87)R87D@("`@("`@("`@("`@
M5&AE(&QI<W0@;V8@9&ER<R!A;F0@9FEL97,*("`@("`J+PH@("`@"B`@("!F
M=6YC=&EO;B!?;'-?;&]C86PH)&1I<E]P871H*0H@("`@>PH@("`@("`@("1D
M:7(@/2!D:7(H)&1I<E]P871H*3L*("`@("`@("`D9&ER7VQI<W0@/2!A<G)A
M>2@I.PH@("`@("`@("1F:6QE7VQI<W0@/2!A<G)A>2@I.PH@("`@("`@('=H
M:6QE("AF86QS92`A/3T@*"1E;G1R>2`]("1D:7(M/G)E860H*2DI('L*("`@
M("`@("`@("`@:68@*"@D96YT<GD@(3T@)RXG*2`F)B`H)&5N=')Y("$]("<N
M+B<I*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?9&ER*"1D:7)?<&%T:"XD
M96YT<GDI*2!["B`@("`@("`@("`@("`@("`@("`@)&1I<E]L:7-T6UT@/2`D
M96YT<GD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1F:6QE7VQI<W1;72`]("1E;G1R>3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D9&ER+3YC;&]S
M92@I.PH@("`@("`@("1R97-;)V1I<G,G72`]("1D:7)?;&ES=#L*("`@("`@
M("`D<F5S6R=F:6QE<R==(#T@)&9I;&5?;&ES=#L*("`@("`@("!R971U<FX@
M)')E<SL*("`@('T*"B`@("`O*BH*("`@("`J($9U;F-T:6]N(&9O<B!U<V4@
M=VET:"!U<V]R="@I+@H@("`@("H@0V]M<&%R97,@=&AE(&QI<W0M87)R87DM
M96QE;65N=',@8GD@;F%M92X*("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV
M871E"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@7VYA=%]S;W)T*"1I=&5M
M7S$L("1I=&5M7S(I"B`@("!["B`@("`@("`@<F5T=7)N('-T<FYA=&-M<"@D
M:71E;5\Q6R=N86UE)UTL("1I=&5M7S);)VYA;64G72D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!087)S92!D871E<R!T;R!T:6UE<W1A;7!S"B`@("`@*@H@
M("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("H@0'!A<F%M("`@<W1R:6YG
M("1D871E("!$871E"B`@("`@*B!`<F5T=7)N("!I;G0@("`@("`@("`@(%1I
M;65S=&%M<`H@("`@("H@0'-E92`@("`@3D547T944%]%4E)?1$%4149/4DU!
M5%]&04E,140*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!?<&%R<V5?1&%T
M92@D9&%T92D*("`@('L*("`@("`@("`O+R!397`@,3`@,C(Z,#8@/3X@4V5P
M(#$P+"`\>65A<CX@,C(Z,#8*("`@("`@("!I9B`H<')E9U]M871C:"@G+RA;
M02U:82UZ72LI6R!=*RA;,"TY72LI6R!=*RA;,"TY72LI.BA;,"TY72LI+R<L
M("1D871E+"`D<F5S*2D@>PH@("`@("`@("`@("`D>65A<B`](&1A=&4H)UDG
M*3L*("`@("`@("`@("`@)&UO;G1H(#T@)')E<ULQ73L*("`@("`@("`@("`@
M)&1A>2`]("1R97-;,ET["B`@("`@("`@("`@("1H;W5R(#T@)')E<ULS73L*
M("`@("`@("`@("`@)&UI;G5T92`]("1R97-;-%T["B`@("`@("`@("`@("1D
M871E(#T@(B1M;VYT:"`D9&%Y+"`D>65A<B`D:&]U<CHD;6EN=71E(CL*("`@
M("`@("`@("`@)'1M<$1A=&4@/2!S=')T;W1I;64H)&1A=&4I.PH@("`@("`@
M("`@("!I9B`H)'1M<$1A=&4@/B!T:6UE*"DI('L*("`@("`@("`@("`@("`@
M("1Y96%R+2T["B`@("`@("`@("`@("`@("`D9&%T92`]("(D;6]N=&@@)&1A
M>2P@)'EE87(@)&AO=7(Z)&UI;G5T92(["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@+R\@,#DM,3`M,#0@/3X@,#DO,3`O,#0*("`@("`@("!E
M;'-E:68@*'!R96=?;6%T8V@H)R]>7&1<9"U<9%QD+5QD7&0O)RPD9&%T92DI
M('L*("`@("`@("`@("`@)&1A=&4@/2!S=')?<F5P;&%C92@G+2<L)R\G+"1D
M871E*3L*("`@("`@("!]"B`@("`@("`@)')E<R`]('-T<G1O=&EM92@D9&%T
M92D["B`@("`@("`@:68@*"$D<F5S*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@G1&%T96-O;G9E<G-I;VX@9F%I;&5D+B<L($Y%
M5%]&5%!?15)27T1!5$5&3U)-051?1D%)3$5$*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1R97,["B`@("!]"GT*/SX*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O3F5T+U--5%`N
M<&AP````````````````````````````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M-S0R,C4`,3`U,34T,S,W-#,`,#(P-C0P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N
M9'1A8B!S;V9T=&%B<W1O<#TT('1A8G-T;W`]-"!S:&EF='=I9'1H/30Z("HO
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S
M:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U
M<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@
M("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E
M(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V
M86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@
M;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\
M(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E
M('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN
M970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\($%U=&AO<G,Z($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("!*
M;VX@4&%R:7-E(#QJ;VY`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@1&%M:6%N($%L96IA;F1R
M;R!&97)N86YD97H@4V]S82`\9&%M;&ES='-`8VYB82YU8F$N87(^("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!3
M3510+G!H<"QV(#$N-34@,C`P-B\P,B\P-B`P-CHP,#HR,B!J;VX@17AP("0*
M"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PIR97%U:7)E7V]N8V4@)TYE="]3
M;V-K970N<&AP)SL*"B\J*@H@*B!0<F]V:61E<R!A;B!I;7!L96UE;G1A=&EO
M;B!O9B!T:&4@4TU44"!P<F]T;V-O;"!U<VEN9R!014%2)W,*("H@3F5T7U-O
M8VME=#HZ(&-L87-S+@H@*@H@*B!`<&%C:V%G92!.971?4TU44`H@*B!`875T
M:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U
M=&AO<B`@2F]N(%!A<FES92`\:F]N0'!H<"YN970^"B`J($!A=71H;W(@($1A
M;6EA;B!!;&5J86YD<F\@1F5R;F%N9&5Z(%-O<V$@/&1A;6QI<W1S0&-N8F$N
M=6)A+F%R/@H@*@H@*B!`97AA;7!L92!B87-I8RYP:'`@("!!(&)A<VEC(&EM
M<&QE;65N=&%T:6]N(&]F('1H92!.971?4TU44"!P86-K86=E+@H@*B\*8VQA
M<W,@3F5T7U--5%`*>PH@("`@+RHJ"B`@("`@*B!4:&4@<V5R=F5R('1O(&-O
M;FYE8W0@=&\N"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J+PH@("`@=F%R("1H;W-T(#T@)VQO8V%L:&]S="<["@H@
M("`@+RHJ"B`@("`@*B!4:&4@<&]R="!T;R!C;VYN96-T('1O+@H@("`@("H@
M0'9A<B!I;G0*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@('9A
M<B`D<&]R="`](#(U.PH*("`@("\J*@H@("`@("H@5&AE('9A;'5E('1O(&=I
M=F4@=VAE;B!S96YD:6YG($5(3$\@;W(@2$5,3RX*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!V87(@)&QO
M8V%L:&]S="`]("=L;V-A;&AO<W0G.PH*("`@("\J*@H@("`@("H@3&ES="!O
M9B!S=7!P;W)T960@875T:&5N=&EC871I;VX@;65T:&]D<RP@:6X@<')E9F5R
M96YT:6%L(&]R9&5R+@H@("`@("H@0'9A<B!A<G)A>0H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J+PH@("`@=F%R("1A=71H7VUE=&AO9',@/2!A<G)A
M>2@G1$E'15-4+4U$-2<L("=#4D%-+4U$-2<L("=,3T=)3B<L("=03$%)3B<I
M.PH*("`@("\J*@H@("`@("H@4VAO=6QD(&1E8G5G9VEN9R!O=71P=70@8F4@
M96YA8FQE9#\*("`@("`J($!V87(@8F]O;&5A;@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B\*("`@('9A<B`D7V1E8G5G(#T@9F%L<V4["@H@("`@
M+RHJ"B`@("`@*B!4:&4@<V]C:V5T(')E<V]U<F-E(&)E:6YG('5S960@=&\@
M8V]N;F5C="!T;R!T:&4@4TU44"!S97)V97(N"B`@("`@*B!`=F%R(')E<V]U
M<F-E"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?
M<V]C:V5T(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%1H92!M;W-T(')E8V5N
M="!S97)V97(@<F5S<&]N<V4@8V]D92X*("`@("`J($!V87(@:6YT"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?8V]D92`]("TQ
M.PH*("`@("\J*@H@("`@("H@5&AE(&UO<W0@<F5C96YT('-E<G9E<B!R97-P
M;VYS92!A<F=U;65N=',N"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?87)G=6UE;G1S(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("`J(%-T;W)E<R!D971E8W1E9"!F96%T=7)E
M<R!O9B!T:&4@4TU44"!S97)V97(N"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?97-M='`@/2!A
M<G)A>2@I.PH*("`@("\J*@H@("`@("H@26YS=&%N=&EA=&5S(&$@;F5W($YE
M=%]33510(&]B:F5C="P@;W9E<G)I9&EN9R!A;GD@9&5F875L=',*("`@("`J
M('=I=&@@<&%R86UE=&5R<R!T:&%T(&%R92!P87-S960@:6XN"B`@("`@*@H@
M("`@("H@268@>6]U(&AA=F4@4U-,('-U<'!O<G0@:6X@4$A0+"!Y;W4@8V%N
M(&-O;FYE8W0@=&\@82!S97)V97(*("`@("`J(&]V97(@4U-,('5S:6YG(&%N
M("=S<VPZ+R\G('!R969I>#H*("`@("`J"B`@("`@*B`@("\O(#0V-2!I<R!A
M(&-O;6UO;B!S;71P<R!P;W)T+@H@("`@("H@("`D<VUT<"`](&YE=R!.971?
M4TU44"@G<W-L.B\O;6%I;"YH;W-T+F-O;2<L(#0V-2D["B`@("`@*B`@("1S
M;71P+3YC;VYN96-T*"D["B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@
M)&AO<W0@("`@("`@5&AE('-E<G9E<B!T;R!C;VYN96-T('1O+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)'!O<G0@("`@("`@5&AE('!O<G0@=&\@8V]N;F5C
M="!T;RX*("`@("`J($!P87)A;2!S=')I;F<@("1L;V-A;&AO<W0@(%1H92!V
M86QU92!T;R!G:79E('=H96X@<V5N9&EN9R!%2$Q/(&]R($A%3$\N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<VEN8V4@("`Q+C`*
M("`@("`J+PH@("`@9G5N8W1I;VX@3F5T7U--5%`H)&AO<W0@/2!N=6QL+"`D
M<&]R="`](&YU;&PL("1L;V-A;&AO<W0@/2!N=6QL*0H@("`@>PH@("`@("`@
M(&EF("AI<W-E="@D:&]S="DI("1T:&ES+3YH;W-T(#T@)&AO<W0["B`@("`@
M("`@:68@*&ES<V5T*"1P;W)T*2D@)'1H:7,M/G!O<G0@/2`D<&]R=#L*("`@
M("`@("!I9B`H:7-S970H)&QO8V%L:&]S="DI("1T:&ES+3YL;V-A;&AO<W0@
M/2`D;&]C86QH;W-T.PH*("`@("`@("`D=&AI<RT^7W-O8VME="`]("9N97<@
M3F5T7U-O8VME="@I.PH*("`@("`@("`O*@H@("`@("`@("`J($EN8VQU9&4@
M=&AE($%U=&A?4T%33"!P86-K86=E+B`@268@=&AE('!A8VMA9V4@:7,@;F]T
M(&%V86EL86)L92P*("`@("`@("`@*B!W92!D:7-A8FQE('1H92!A=71H96YT
M:6-A=&EO;B!M971H;V1S('1H870@9&5P96YD('5P;VX@:70N"B`@("`@("`@
M("HO"B`@("`@("`@:68@*"A`:6YC;'5D95]O;F-E("=!=71H+U-!4TPN<&AP
M)RD@/3T](&9A;'-E*2!["B`@("`@("`@("`@("1P;W,@/2!A<G)A>5]S96%R
M8V@H)T1)1T535"U-1#4G+"`D=&AI<RT^875T:%]M971H;V1S*3L*("`@("`@
M("`@("`@=6YS970H)'1H:7,M/F%U=&A?;65T:&]D<ULD<&]S72D["B`@("`@
M("`@("`@("1P;W,@/2!A<G)A>5]S96%R8V@H)T-204TM340U)RP@)'1H:7,M
M/F%U=&A?;65T:&]D<RD["B`@("`@("`@("`@('5N<V5T*"1T:&ES+3YA=71H
M7VUE=&AO9'-;)'!O<UTI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E="!T:&4@=F%L=64@;V8@=&AE(&1E8G5G9VEN9R!F;&%G+@H@("`@
M("H*("`@("`J($!P87)A;2`@(&)O;VQE86X@)&1E8G5G("`@("`@3F5W('9A
M;'5E(&9O<B!T:&4@9&5B=6=G:6YG(&9L86<N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R`@<'5B;&EC"B`@("`@*B!`<VEN8V4@("`Q+C$N,`H@("`@("HO"B`@
M("!F=6YC=&EO;B!S971$96)U9R@D9&5B=6<I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]D96)U9R`]("1D96)U9SL*("`@('T*"B`@("`O*BH*("`@("`J(%-E
M;F0@=&AE(&=I=F5N('-T<FEN9R!O9B!D871A('1O('1H92!S97)V97(N"B`@
M("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`D9&%T82`@("`@("!4:&4@
M<W1R:6YG(&]F(&1A=&$@=&\@<V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M("!M:7AE9"`@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J
M96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<')I=F%T
M90H@("`@("H@0'-I;F-E("`@,2XQ+C`*("`@("`J+PH@("`@9G5N8W1I;VX@
M7W-E;F0H)&1A=&$I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?9&5B=6<I
M('L*("`@("`@("`@("`@96-H;R`B1$5"54<Z(%-E;F0Z("1D871A7&XB.PH@
M("`@("`@('T*"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@
M)'1H:7,M/E]S;V-K970M/G=R:71E*"1D871A*2DI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T;R!W<FET92!T;R!S
M;V-K970Z("<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D97)R;W(M/F=E=$UE<W-A9V4H*2D["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E;F0@82!C;VUM
M86YD('1O('1H92!S97)V97(@=VET:"!A;B!O<'1I;VYA;"!S=')I;F<@;V8*
M("`@("`J(&%R9W5M96YT<RX@($$@8V%R<FEA9V4@<F5T=7)N("\@;&EN969E
M960@*$-23$8I('-E<75E;F-E('=I;&P*("`@("`J(&)E(&%P<&5N9&5D('1O
M(&5A8V@@8V]M;6%N9"!S=')I;F<@8F5F;W)E(&ET(&ES('-E;G0@=&\@=&AE
M"B`@("`@*B!33510('-E<G9E<B`M(&%N(&5R<F]R('=I;&P@8F4@=&AR;W=N
M(&EF('1H92!C;VUM86YD('-T<FEN9PH@("`@("H@86QR96%D>2!C;VYT86EN
M<R!A;GD@;F5W;&EN92!C:&%R86-T97)S+B!5<V4@7W-E;F0H*2!F;W(*("`@
M("`J(&-O;6UA;F1S('1H870@;75S="!C;VYT86EN(&YE=VQI;F5S+@H@("`@
M("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@)&-O;6UA;F0@("`@5&AE(%--
M5%`@8V]M;6%N9"!T;R!S96YD('1O('1H92!S97)V97(N"B`@("`@*B!`<&%R
M86T@("!S=')I;F<@("1A<F=S("`@("`@($$@<W1R:6YG(&]F(&]P=&EO;F%L
M(&%R9W5M96YT<R!T;R!A<'!E;F0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@=&\@=&AE(&-O;6UA;F0N"B`@("`@*@H@("`@("H@0')E
M='5R;B`@;6EX960@("!4:&4@<F5S=6QT(&]F('1H92!?<V5N9"@I(&-A;&PN
M"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("H@0'-I;F-E
M("`@,2XQ+C`*("`@("`J+PH@("`@9G5N8W1I;VX@7W!U="@D8V]M;6%N9"P@
M)&%R9W,@/2`G)RD*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1A<F=S*2D@
M>PH@("`@("`@("`@("`D8V]M;6%N9"`N/2`G("<@+B`D87)G<SL*("`@("`@
M("!]"@H@("`@("`@(&EF("AS=')C<W!N*"1C;VUM86YD+"`B7')<;B(I("$]
M/2!S=')L96XH)&-O;6UA;F0I*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"=#;VUM86YD<R!C86YN;W0@8V]N=&%I;B!N97=L:6YE
M<R<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<V5N9"@D
M8V]M;6%N9"`N(")<<EQN(BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296%D
M(&$@<F5P;'D@9G)O;2!T:&4@4TU44"!S97)V97(N("!4:&4@<F5P;'D@8V]N
M<VES=',@;V8@82!R97-P;VYS90H@("`@("H@8V]D92!A;F0@82!R97-P;VYS
M92!M97-S86=E+@H@("`@("H*("`@("`J($!P87)A;2`@(&UI>&5D("`@)'9A
M;&ED("`@("`@5&AE('-E="!O9B!V86QI9"!R97-P;VYS92!C;V1E<RX@(%1H
M97-E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&UA>2!B
M92!S<&5C:69I960@87,@86X@87)R87D@;V8@:6YT96=E<@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!V86QU97,@;W(@87,@82!S:6YG
M;&4@:6YT96=E<B!V86QU92X*("`@("`J"B`@("`@*B!`<F5T=7)N("!M:7AE
M9"`@(%1R=64@:68@=&AE('-E<G9E<B!R971U<FYE9"!A('9A;&ED(')E<W!O
M;G-E(&-O9&4@;W(*("`@("`J("`@("`@("`@("`@("`@("`@82!014%27T5R
M<F]R(&]B:F5C="!I<R!A;B!E<G)O<B!C;VYD:71I;VX@:7,@<F5A8VAE9"X*
M("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B!`<VEN8V4@
M("`Q+C$N,`H@("`@("H*("`@("`J($!S964@("`@(&=E=%)E<W!O;G-E"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]P87)S95)E<W!O;G-E*"1V86QI9"D*("`@
M('L*("`@("`@("`D=&AI<RT^7V-O9&4@/2`M,3L*("`@("`@("`D=&AI<RT^
M7V%R9W5M96YT<R`](&%R<F%Y*"D["@H@("`@("`@('=H:6QE("@D;&EN92`]
M("1T:&ES+3Y?<V]C:V5T+3YR96%D3&EN92@I*2!["B`@("`@("`@("`@(&EF
M("@D=&AI<RT^7V1E8G5G*2!["B`@("`@("`@("`@("`@("!E8VAO(")$14)5
M1SH@4F5C=CH@)&QI;F5<;B(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("\J($EF('=E(')E8V5I=F4@86X@96UP='D@;&EN92P@=&AE(&-O;FYE8W1I
M;VX@:&%S(&)E96X@8VQO<V5D+B`J+PH@("`@("`@("`@("!I9B`H96UP='DH
M)&QI;F4I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^9&ES8V]N;F5C="@I
M.PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-O
M;FYE8W1I;VX@=V%S('5N97AP96-T961L>2!C;&]S960G*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@+RH@4F5A9"!T:&4@8V]D92!A;F0@<W1O<F4@
M=&AE(')E<W0@:6X@=&AE(&%R9W5M96YT<R!A<G)A>2X@*B\*("`@("`@("`@
M("`@)&-O9&4@/2!S=6)S='(H)&QI;F4L(#`L(#,I.PH@("`@("`@("`@("`D
M=&AI<RT^7V%R9W5M96YT<UM=(#T@=')I;2AS=6)S='(H)&QI;F4L(#0I*3L*
M"B`@("`@("`@("`@("\J($-H96-K('1H92!S>6YT87@@;V8@=&AE(')E<W!O
M;G-E(&-O9&4N("HO"B`@("`@("`@("`@(&EF("AI<U]N=6UE<FEC*"1C;V1E
M*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C;V1E(#T@*&EN="DD8V]D
M93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?8V]D92`]("TQ.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("\J($EF('1H:7,@:7,@;F]T(&$@;75L=&EL
M:6YE(')E<W!O;G-E+"!W92=R92!D;VYE+B`J+PH@("`@("`@("`@("!I9B`H
M<W5B<W1R*"1L:6YE+"`S+"`Q*2`A/2`G+2<I('L*("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!#
M;VUP87)E('1H92!S97)V97(G<R!R97-P;VYS92!C;V1E('=I=&@@=&AE('9A
M;&ED(&-O9&4N("HO"B`@("`@("`@:68@*&ES7VEN="@D=F%L:60I("8F("@D
M=&AI<RT^7V-O9&4@/3T]("1V86QI9"DI('L*("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!W92!W97)E(&=I=F5N
M(&%N(&%R<F%Y(&]F('9A;&ED(')E<W!O;G-E(&-O9&5S+"!C:&5C:R!E86-H
M(&]N92X@*B\*("`@("`@("!I9B`H:7-?87)R87DH)'9A;&ED*2D@>PH@("`@
M("`@("`@("!F;W)E86-H("@D=F%L:60@87,@)'9A;&ED7V-O9&4I('L*("`@
M("`@("`@("`@("`@(&EF("@D=&AI<RT^7V-O9&4@/3T]("1V86QI9%]C;V1E
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*"=);G9A;&ED(')E<W!O;G-E(&-O9&4@
M<F5C96EV960@9G)O;2!S97)V97(G*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;B!A(#(M='5P;&4@8V]N=&%I;FEN9R!T:&4@;&%S="!R97-P;VYS
M92!F<F]M('1H92!33510('-E<G9E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M("!A<G)A>2`@($$@='=O+65L96UE;G0@87)R87DZ('1H92!F:7)S="!E;&5M
M96YT(&-O;G1A:6YS('1H90H@("`@("H@("`@("`@("`@("`@("`@("!R97-P
M;VYS92!C;V1E(&%S(&%N(&EN=&5G97(@86YD('1H92!S96-O;F0@96QE;65N
M=`H@("`@("H@("`@("`@("`@("`@("`@("!C;VYT86EN<R!T:&4@<F5S<&]N
M<V4G<R!A<F=U;65N=',@87,@82!S=')I;F<N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R`@<'5B;&EC"B`@("`@*B!`<VEN8V4@("`Q+C$N,`H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971297-P;VYS92@I"B`@("!["B`@("`@("`@<F5T=7)N
M(&%R<F%Y*"1T:&ES+3Y?8V]D92P@:F]I;B@B7&XB+"`D=&AI<RT^7V%R9W5M
M96YT<RDI.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP="!T;R!C;VYN
M96-T('1O('1H92!33510('-E<G9E<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M("!I;G0@("`@("1T:6UE;W5T("`@(%1H92!T:6UE;W5T('9A;'5E("AI;B!S
M96-O;F1S*2!F;W(@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-O8VME="!C;VYN96-T:6]N+@H@("`@("H@0'!A<F%M("`@8F]O
M;"`@("`D<&5R<VES=&5N="!3:&]U;&0@82!P97)S:7-T96YT('-O8VME="!C
M;VYN96-T:6]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&)E('5S960_"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!2971U<FYS
M(&$@4$5!4E]%<G)O<B!W:71H(&%N(&5R<F]R(&UE<W-A9V4@;VX@86YY"B`@
M("`@*B`@("`@("`@("`@("`@(&MI;F0@;V8@9F%I;'5R92P@;W(@=')U92!O
M;B!S=6-C97-S+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S:6YC
M92`@,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;FYE8W0H)'1I;65O=70@
M/2!N=6QL+"`D<&5R<VES=&5N="`](&9A;'-E*0H@("`@>PH@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^7W-O8VME="T^8V]N;F5C="@D=&AI<RT^:&]S="P@
M)'1H:7,M/G!O<G0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P97)S:7-T96YT+"`D=&EM96]U="D["B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T;R!C;VYN96-T('-O8VME=#H@
M)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97-U
M;'0M/F=E=$UE<W-A9V4H*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!A<G-E4F5S<&]N<V4H,C(P
M*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"B`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]N96=O
M=&EA=&4H*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@071T96UP="!T;R!D:7-C;VYN96-T(&9R;VT@=&AE(%--5%`@<V5R=F5R
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@4F5T=7)N<R!A(%!%05)?
M17)R;W(@=VET:"!A;B!E<G)O<B!M97-S86=E(&]N(&%N>0H@("`@("H@("`@
M("`@("`@("`@("!K:6YD(&]F(&9A:6QU<F4L(&]R('1R=64@;VX@<W5C8V5S
M<RX*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<VEN8V4@(#$N,`H@
M("`@("HO"B`@("!F=6YC=&EO;B!D:7-C;VYN96-T*"D*("`@('L*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U="@G455)
M5"<I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!A
M<G-E4F5S<&]N<V4H,C(Q*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O
M<CL*("`@("`@("!]"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R
M(#T@)'1H:7,M/E]S;V-K970M/F1I<V-O;FYE8W0H*2DI('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T;R!D:7-C;VYN
M96-T('-O8VME=#H@)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1E<G)O<BT^9V5T365S<V%G92@I*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP
M="!T;R!S96YD('1H92!%2$Q/(&-O;6UA;F0@86YD(&]B=&%I;B!A(&QI<W0@
M;V8@15--5%`*("`@("`J(&5X=&5N<VEO;G,@879A:6QA8FQE+"!A;F0@9F%I
M;&EN9R!T:&%T(&IU<W0@<V5N9"!(14Q/+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@4F5T=7)N<R!A(%!%05)?17)R;W(@=VET:"!A;B!E<G)O<B!M
M97-S86=E(&]N(&%N>0H@("`@("H@("`@("`@("`@("`@("!K:6YD(&]F(&9A
M:6QU<F4L(&]R('1R=64@;VX@<W5C8V5S<RX*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J($!S:6YC92`@,2XQ+C`*("`@("`J+PH@("`@
M9G5N8W1I;VX@7VYE9V]T:6%T92@I"B`@("!["B`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P=70H)T5(3$\G+"`D=&AI<RT^
M;&]C86QH;W-T*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@
M("`@("!]"@H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1T:&ES+3Y?<&%R
M<V5297-P;VYS92@R-3`I*2D@>PH@("`@("`@("`@("`O*B!)9B!W92!R96-E
M:79E(&$@-3`S(')E<W!O;G-E+"!W92=R92!A;')E861Y(&%U=&AE;G1I8V%T
M960N("HO"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V-O9&4@/3T](#4P,RD@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("\J($EF('1H92!%2$Q/(&9A:6QE9"P@=')Y('1H92!S
M:6UP;&5R($A%3$\@8V]M;6%N9"X@*B\*("`@("`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P=70H)TA%3$\G+"`D=&AI<RT^
M;&]C86QH;W-T*2DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D97)R;W([
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)'1H:7,M/E]P87)S95)E<W!O;G-E*#(U,"DI*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G2$5,3R!W87,@;F]T(&%C8V5P
M=&5D.B`G+"`D=&AI<RT^7V-O9&4I.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@
M*"1T:&ES+3Y?87)G=6UE;G1S(&%S("1A<F=U;65N="D@>PH@("`@("`@("`@
M("`D=F5R8B`]('-T<G1O:R@D87)G=6UE;G0L("<@)RD["B`@("`@("`@("`@
M("1A<F=U;65N=',@/2!S=6)S='(H)&%R9W5M96YT+"!S=')L96XH)'9E<F(I
M("L@,2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=')L96XH
M)&%R9W5M96YT*2`M('-T<FQE;B@D=F5R8BD@+2`Q*3L*("`@("`@("`@("`@
M)'1H:7,M/E]E<VUT<%LD=F5R8ET@/2`D87)G=6UE;G1S.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!N86UE(&]F('1H92!B97-T(&%U=&AE;G1I8V%T:6]N(&UE
M=&AO9"!T:&%T('1H92!S97)V97(*("`@("`J(&AA<R!A9'9E<G1I<V5D+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@("`@4F5T=7)N<R!A('-T<FEN
M9R!C;VYT86EN:6YG('1H92!N86UE(&]F('1H92!B97-T"B`@("`@*B`@("`@
M("`@("`@("`@("`@('-U<'!O<G1E9"!A=71H96YT:6-A=&EO;B!M971H;V0@
M;W(@82!014%27T5R<F]R(&]B:F5C=`H@("`@("H@("`@("`@("`@("`@("`@
M("!I9B!A(&9A:6QU<F4@8V]N9&ET:6]N(&ES(&5N8V]U;G1E<F5D+@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<VEN8V4@(#$N,2XP"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]G971"97-T075T:$UE=&AO9"@I"B`@("!["B`@
M("`@("`@)&%V86EL86)L95]M971H;V1S(#T@97AP;&]D92@G("<L("1T:&ES
M+3Y?97-M='!;)T%55$@G72D["@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YA
M=71H7VUE=&AO9',@87,@)&UE=&AO9"D@>PH@("`@("`@("`@("!I9B`H:6Y?
M87)R87DH)&UE=&AO9"P@)&%V86EL86)L95]M971H;V1S*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1M971H;V0["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=.;R!S=7!P
M;W)T960@875T:&5N=&EC871I;VX@;65T:&]D<R<I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@071T96UP="!T;R!D;R!33510(&%U=&AE;G1I8V%T:6]N+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@5&AE('5S97)I9"!T;R!A=71H
M96YT:6-A=&4@87,N"B`@("`@*B!`<&%R86T@<W1R:6YG(%1H92!P87-S=V]R
M9"!T;R!A=71H96YT:6-A=&4@=VET:"X*("`@("`J($!P87)A;2!S=')I;F<@
M5&AE(')E<75E<W1E9"!A=71H96YT:6-A=&EO;B!M971H;V0N("!)9B!N;VYE
M(&ES"B`@("`@*B`@("`@("`@("`@("`@('-P96-I9FEE9"P@=&AE(&)E<W0@
M<W5P<&]R=&5D(&UE=&AO9"!W:6QL(&)E('5S960N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"!2971U<FYS(&$@4$5!4E]%<G)O<B!W:71H(&%N(&5R
M<F]R(&UE<W-A9V4@;VX@86YY"B`@("`@*B`@("`@("`@("`@("`@(&MI;F0@
M;V8@9F%I;'5R92P@;W(@=')U92!O;B!S=6-C97-S+@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J($!S:6YC92`@,2XP"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%U=&@H)'5I9"P@)'!W9"`L("1M971H;V0@/2`G)RD*("`@('L*("`@
M("`@("!I9B`H96UP='DH)'1H:7,M/E]E<VUT<%LG05542"==*2D@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4TU44"!S97)V97(@
M9&]E<R!N;R!S=7!P;W)T(&%U=&AE;G1I8V%T:6]N)RD["B`@("`@("`@?0H*
M("`@("`@("`O*B!)9B!N;R!M971H;V0@:&%S(&)E96X@<W!E8VEF:65D+"!G
M970@=&AE(&YA;64@;V8@=&AE(&)E<W0*("`@("`@("`@*B!S=7!P;W)T960@
M;65T:&]D(&%D=F5R=&ES960@8GD@=&AE(%--5%`@<V5R=F5R+B`J+PH@("`@
M("`@(&EF("AE;7!T>2@D;65T:&]D*2D@>PH@("`@("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D;65T:&]D(#T@)'1H:7,M/E]G971"97-T075T:$UE=&AO
M9"@I*2D@>PH@("`@("`@("`@("`@("`@+RH@4F5T=7)N('1H92!014%27T5R
M<F]R(&]B:F5C="!F<F]M(%]G971"97-T075T:$UE=&AO9"@I+B`J+PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1M971H;V0["B`@("`@("`@("`@('T*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;65T:&]D(#T@<W1R=&]U<'!E
M<B@D;65T:&]D*3L*("`@("`@("`@("`@:68@*"%I;E]A<G)A>2@D;65T:&]D
M+"`D=&AI<RT^875T:%]M971H;V1S*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H(B1M971H;V0@:7,@;F]T(&$@<W5P<&]R
M=&5D(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"(I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!S=VET8V@@*"1M971H;V0I('L*("`@("`@("`@
M("`@8V%S92`G1$E'15-4+4U$-2<Z"B`@("`@("`@("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/E]A=71H1&EG97-T7TU$-2@D=6ED+"`D<'=D*3L*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=#4D%-+4U$-2<Z
M"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]A=71H0U)!35]-
M1#4H)'5I9"P@)'!W9"D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@8V%S92`G3$]'24XG.@H@("`@("`@("`@("`@("`@)')E<W5L="`]
M("1T:&ES+3Y?875T:$QO9VEN*"1U:60L("1P=V0I.PH@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)U!,04E.)SH*("`@("`@("`@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V%U=&A0;&%I;B@D=6ED+"`D<'=D
M*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!D969A=6QT
M.@H@("`@("`@("`@("`@("`@)')E<W5L="`](%!%05(Z.G)A:7-E17)R;W(H
M(B1M971H;V0@:7,@;F]T(&$@<W5P<&]R=&5D(&%U=&AE;G1I8V%T:6]N(&UE
M=&AO9"(I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@
M("`@("`O*B!)9B!A;B!E<G)O<B!W87,@96YC;W5N=&5R960L(')E='5R;B!T
M:&4@4$5!4E]%<G)O<B!O8FIE8W0N("HO"B`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J($%U=&AE;G1I8V%T97,@=&AE('5S97(@=7-I;F<@=&AE($1)
M1T535"U-1#4@;65T:&]D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M5&AE('5S97)I9"!T;R!A=71H96YT:6-A=&4@87,N"B`@("`@*B!`<&%R86T@
M<W1R:6YG(%1H92!P87-S=V]R9"!T;R!A=71H96YT:6-A=&4@=VET:"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@82!014%27T5R<F]R
M('=I=&@@86X@97)R;W(@;65S<V%G92!O;B!A;GD*("`@("`J("`@("`@("`@
M("`@("`@:VEN9"!O9B!F86EL=7)E+"!O<B!T<G5E(&]N('-U8V-E<W,N"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!S:6YC92`@,2XQ+C`*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V%U=&A$:6=E<W1?340U*"1U:60L("1P=V0I
M"B`@("!["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H
M:7,M/E]P=70H)T%55$@G+"`G1$E'15-4+4U$-2<I*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*("`@("`@("`O*B`S,S0Z($-O
M;G1I;G5E(&%U=&AE;G1I8V%T:6]N(')E<75E<W0@*B\*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!A<G-E4F5S<&]N<V4H
M,S,T*2DI('L*("`@("`@("`@("`@+RH@-3`S.B!%<G)O<CH@86QR96%D>2!A
M=71H96YT:6-A=&5D("HO"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V-O9&4@
M/3T](#4P,RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]
M"@H@("`@("`@("1C:&%L;&5N9V4@/2!B87-E-C1?9&5C;V1E*"1T:&ES+3Y?
M87)G=6UE;G1S6S!=*3L*("`@("`@("`D9&EG97-T(#T@)D%U=&A?4T%33#HZ
M9F%C=&]R>2@G9&EG97-T;60U)RD["B`@("`@("`@)&%U=&A?<W1R(#T@8F%S
M938T7V5N8V]D92@D9&EG97-T+3YG971297-P;VYS92@D=6ED+"`D<'=D+"`D
M8VAA;&QE;F=E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FAO<W0L(")S;71P(BDI.PH*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U
M="@D875T:%]S='(I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@
M("`@("`@('T*("`@("`@("`O*B`S,S0Z($-O;G1I;G5E(&%U=&AE;G1I8V%T
M:6]N(')E<75E<W0@*B\*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R
M;W(@/2`D=&AI<RT^7W!A<G-E4F5S<&]N<V4H,S,T*2DI('L*("`@("`@("`@
M("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@("\J(%=E(&1O
M;B=T('5S92!T:&4@<')O=&]C;VPG<R!T:&ER9"!S=&5P(&)E8V%U<V4@4TU4
M4"!D;V5S;B=T"B`@("`@("`@("H@86QL;W<@<W5B<V5Q=65N="!A=71H96YT
M:6-A=&EO;BP@<V\@=V4@:G5S="!S:6QE;G1L>2!I9VYO<F4*("`@("`@("`@
M*B!I="X@*B\*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D
M=&AI<RT^7W!U="@G("<I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R
M.PH@("`@("`@('T*("`@("`@("`O*B`R,S4Z($%U=&AE;G1I8V%T:6]N('-U
M8V-E<W-F=6P@*B\*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@
M/2`D=&AI<RT^7W!A<G-E4F5S<&]N<V4H,C,U*2DI('L*("`@("`@("`@("`@
M<F5T=7)N("1E<G)O<CL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!=71H96YT:6-A=&5S('1H92!U<V5R('5S:6YG('1H92!#4D%-+4U$-2!M
M971H;V0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!4:&4@=7-E<FED
M('1O(&%U=&AE;G1I8V%T92!A<RX*("`@("`J($!P87)A;2!S=')I;F<@5&AE
M('!A<W-W;W)D('1O(&%U=&AE;G1I8V%T92!W:71H+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@4F5T=7)N<R!A(%!%05)?17)R;W(@=VET:"!A;B!E
M<G)O<B!M97-S86=E(&]N(&%N>0H@("`@("H@("`@("`@("`@("`@("!K:6YD
M(&]F(&9A:6QU<F4L(&]R('1R=64@;VX@<W5C8V5S<RX*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H@0'-I;F-E("`Q+C$N,`H@("`@("HO"B`@("!F
M=6YC=&EO;B!?875T:$-204U?340U*"1U:60L("1P=V0I"B`@("!["B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P=70H)T%5
M5$@G+"`G0U)!32U-1#4G*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O
M<CL*("`@("`@("!]"B`@("`@("`@+RH@,S,T.B!#;VYT:6YU92!A=71H96YT
M:6-A=&EO;B!R97%U97-T("HO"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E<W!O;G-E*#,S-"DI*2!["B`@("`@
M("`@("`@("\J(#4P,SH@17)R;W(Z(&%L<F5A9'D@875T:&5N=&EC871E9"`J
M+PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]C;V1E(#T]/2`U,#,I('L*("`@
M("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@("`@("`D8VAA
M;&QE;F=E(#T@8F%S938T7V1E8V]D92@D=&AI<RT^7V%R9W5M96YT<ULP72D[
M"B`@("`@("`@)&-R86T@/2`F075T:%]305-,.CIF86-T;W)Y*"=C<F%M;60U
M)RD["B`@("`@("`@)&%U=&A?<W1R(#T@8F%S938T7V5N8V]D92@D8W)A;2T^
M9V5T4F5S<&]N<V4H)'5I9"P@)'!W9"P@)&-H86QL96YG92DI.PH*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U="@D875T
M:%]S='(I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@
M('T*"B`@("`@("`@+RH@,C,U.B!!=71H96YT:6-A=&EO;B!S=6-C97-S9G5L
M("HO"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M
M/E]P87)S95)E<W!O;G-E*#(S-2DI*2!["B`@("`@("`@("`@(')E='5R;B`D
M97)R;W(["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@075T:&5N
M=&EC871E<R!T:&4@=7-E<B!U<VEN9R!T:&4@3$]'24X@;65T:&]D+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@5&AE('5S97)I9"!T;R!A=71H96YT
M:6-A=&4@87,N"B`@("`@*B!`<&%R86T@<W1R:6YG(%1H92!P87-S=V]R9"!T
M;R!A=71H96YT:6-A=&4@=VET:"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D(%)E='5R;G,@82!014%27T5R<F]R('=I=&@@86X@97)R;W(@;65S<V%G
M92!O;B!A;GD*("`@("`J("`@("`@("`@("`@("`@:VEN9"!O9B!F86EL=7)E
M+"!O<B!T<G5E(&]N('-U8V-E<W,N"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J($!S:6YC92`@,2XQ+C`*("`@("`J+PH@("`@9G5N8W1I;VX@7V%U
M=&A,;V=I;B@D=6ED+"`D<'=D*0H@("`@>PH@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?<'5T*"=!551()RP@)TQ/1TE.)RDI
M*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H@("`@
M("`@("\J(#,S-#H@0V]N=&EN=64@875T:&5N=&EC871I;VX@<F5Q=65S="`J
M+PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?
M<&%R<V5297-P;VYS92@S,S0I*2D@>PH@("`@("`@("`@("`O*B`U,#,Z($5R
M<F]R.B!A;')E861Y(&%U=&AE;G1I8V%T960@*B\*("`@("`@("`@("`@:68@
M*"1T:&ES+3Y?8V]D92`]/3T@-3`S*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)&5R
M<F]R.PH@("`@("`@('T*"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R
M<F]R(#T@)'1H:7,M/E]P=70H8F%S938T7V5N8V]D92@D=6ED*2DI*2!["B`@
M("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H@("`@("`@("\J
M(#,S-#H@0V]N=&EN=64@875T:&5N=&EC871I;VX@<F5Q=65S="`J+PH@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?<&%R<V52
M97-P;VYS92@S,S0I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@
M("`@("`@('T*"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@
M)'1H:7,M/E]P=70H8F%S938T7V5N8V]D92@D<'=D*2DI*2!["B`@("`@("`@
M("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@("`@("`O*B`R,S4Z
M($%U=&AE;G1I8V%T:6]N('-U8V-E<W-F=6P@*B\*("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!A<G-E4F5S<&]N<V4H,C,U
M*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@075T
M:&5N=&EC871E<R!T:&4@=7-E<B!U<VEN9R!T:&4@4$Q!24X@;65T:&]D+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@5&AE('5S97)I9"!T;R!A=71H
M96YT:6-A=&4@87,N"B`@("`@*B!`<&%R86T@<W1R:6YG(%1H92!P87-S=V]R
M9"!T;R!A=71H96YT:6-A=&4@=VET:"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D(%)E='5R;G,@82!014%27T5R<F]R('=I=&@@86X@97)R;W(@;65S
M<V%G92!O;B!A;GD*("`@("`J("`@("`@("`@("`@("`@:VEN9"!O9B!F86EL
M=7)E+"!O<B!T<G5E(&]N('-U8V-E<W,N"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J($!S:6YC92`@,2XQ+C`*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V%U=&A0;&%I;B@D=6ED+"`D<'=D*0H@("`@>PH@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?<'5T*"=!551()RP@)U!,04E.
M)RDI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H@
M("`@("`@("\J(#,S-#H@0V]N=&EN=64@875T:&5N=&EC871I;VX@<F5Q=65S
M="`J+PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES
M+3Y?<&%R<V5297-P;VYS92@S,S0I*2D@>PH@("`@("`@("`@("`O*B`U,#,Z
M($5R<F]R.B!A;')E861Y(&%U=&AE;G1I8V%T960@*B\*("`@("`@("`@("`@
M:68@*"1T:&ES+3Y?8V]D92`]/3T@-3`S*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@
M)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@)&%U=&A?<W1R(#T@8F%S938T
M7V5N8V]D92AC:'(H,"D@+B`D=6ED("X@8VAR*#`I("X@)'!W9"D["@H@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?<'5T*"1A
M=71H7W-T<BDI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@
M("`@?0H*("`@("`@("`O*B`R,S4Z($%U=&AE;G1I8V%T:6]N('-U8V-E<W-F
M=6P@*B\*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI
M<RT^7W!A<G-E4F5S<&]N<V4H,C,U*2DI('L*("`@("`@("`@("`@<F5T=7)N
M("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4V5N9"!T:&4@2$5,3R!C;VUM86YD+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@5&AE(&1O;6%I;B!N86UE('1O('-A
M>2!W92!A<F4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!2971U<FYS
M(&$@4$5!4E]%<G)O<B!W:71H(&%N(&5R<F]R(&UE<W-A9V4@;VX@86YY"B`@
M("`@*B`@("`@("`@("`@("`@(&MI;F0@;V8@9F%I;'5R92P@;W(@=')U92!O
M;B!S=6-C97-S+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S:6YC
M92`@,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(&AE;&\H)&1O;6%I;BD*("`@
M('L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^
M7W!U="@G2$5,3R<L("1D;VUA:6XI*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&5R<F]R.PH@("`@("`@('T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M97)R;W(@/2`D=&AI<RT^7W!A<G-E4F5S<&]N<V4H,C4P*2DI('L*("`@("`@
M("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5N9"!T:&4@34%)3"!&
M4D]-.B!C;VUM86YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-E
M;F1E<B`@("!4:&4@<V5N9&5R("AR979E<G-E('!A=&@I('1O('-E="X*("`@
M("`J($!P87)A;2!S=')I;F<@)'!A<F%M<R`@("!3=')I;F<@8V]N=&%I;FEN
M9R!A9&1I=&EO;F%L($U!24P@<&%R86UE=&5R<RP*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("!S=6-H(&%S('1H92!.3U1)1ED@9FQA9W,@9&5F
M:6YE9"!B>2!21D,@,3@Y,0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@(&]R('1H92!615)0('!R;W1O8V]L+@H@("`@("H*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("!)9B`D<&%R86US(&ES(&%N(&%R<F%Y+"!O
M;FQY('1H92`G=F5R<"<@;W!T:6]N"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@:7,@<W5P<&]R=&5D+B`@268@)W9E<G`G(&ES('1R=64L('1H
M92!85D524`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('!A<F%M
M971E<B!I<R!A<'!E;F1E9"!T;R!T:&4@34%)3"!C;VUM86YD+B`@268*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@)W9E<G`G('9A;'5E
M(&ES(&$@<W1R:6YG+"!T:&4@9G5L;`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@(%A615)0/79A;'5E('!A<F%M971E<B!I<R!A<'!E;F1E9"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@82!014%27T5R
M<F]R('=I=&@@86X@97)R;W(@;65S<V%G92!O;B!A;GD*("`@("`J("`@("`@
M("`@("`@("`@:VEN9"!O9B!F86EL=7)E+"!O<B!T<G5E(&]N('-U8V-E<W,N
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-I;F-E("`Q+C`*("`@
M("`J+PH@("`@9G5N8W1I;VX@;6%I;$9R;VTH)'-E;F1E<BP@)'!A<F%M<R`]
M(&YU;&PI"B`@("!["B`@("`@("`@)&%R9W,@/2`B1E)/33H\)'-E;F1E<CXB
M.PH*("`@("`@("`O*B!3=7!P;W)T('1H92!D97!R96-A=&5D(&%R<F%Y(&9O
M<FT@;V8@)'!A<F%M<RX@*B\*("`@("`@("!I9B`H:7-?87)R87DH)'!A<F%M
M<RD@)B8@:7-S970H)'!A<F%M<ULG=F5R<"==*2D@>PH@("`@("`@("`@("`O
M*B!85D524"`J+PH@("`@("`@("`@("!I9B`H)'!A<F%M<ULG=F5R<"==(#T]
M/2!T<G5E*2!["B`@("`@("`@("`@("`@("`D87)G<R`N/2`G(%A615)0)SL*
M"B`@("`@("`@("`@("\J(%A615)0/7-O;65T:&EN9R`J+PH@("`@("`@("`@
M("!](&5L<V5I9B`H=')I;2@D<&%R86US6R=V97)P)UTI*2!["B`@("`@("`@
M("`@("`@("`D87)G<R`N/2`G(%A615)0/2<@+B`D<&%R86US6R=V97)P)UT[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H:7-?<W1R:6YG*"1P
M87)A;7,I*2!["B`@("`@("`@("`@("1A<F=S("X]("<@)R`N("1P87)A;7,[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@
M/2`D=&AI<RT^7W!U="@G34%)3"<L("1A<F=S*2DI('L*("`@("`@("`@("`@
M<F5T=7)N("1E<G)O<CL*("`@("`@("!]"B`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E<W!O;G-E*#(U,"DI*2![
M"B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E;F0@=&AE
M(%)#4%0@5$\Z(&-O;6UA;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<F5C:7!I96YT(%1H92!R96-I<&EE;G0@*&9O<G=A<F0@<&%T:"D@=&\@
M861D+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%R86US("`@(%-T<FEN9R!C
M;VYT86EN:6YG(&%D9&ET:6]N86P@4D-05"!P87)A;65T97)S+`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@('-U8V@@87,@=&AE($Y/5$E&62!F
M;&%G<R!D969I;F5D(&)Y(%)&0R`Q.#DQ+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@4F5T=7)N<R!A(%!%05)?17)R;W(@=VET:"!A;B!E<G)O<B!M
M97-S86=E(&]N(&%N>0H@("`@("H@("`@("`@("`@("`@("!K:6YD(&]F(&9A
M:6QU<F4L(&]R('1R=64@;VX@<W5C8V5S<RX*("`@("`J"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("H@0'-I;F-E("`Q+C`*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F-P=%1O*"1R96-I<&EE;G0L("1P87)A;7,@/2!N=6QL*0H@("`@
M>PH@("`@("`@("1A<F=S(#T@(E1/.CPD<F5C:7!I96YT/B(["B`@("`@("`@
M:68@*&ES7W-T<FEN9R@D<&%R86US*2D@>PH@("`@("`@("`@("`D87)G<R`N
M/2`G("<@+B`D<&%R86US.PH@("`@("`@('T*"B`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P=70H)U)#4%0G+"`D87)G<RDI
M*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?<&%R<V52
M97-P;VYS92AA<G)A>2@R-3`L(#(U,2DI*2D@>PH@("`@("`@("`@("!R971U
M<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!1=6]T92!T:&4@9&%T82!S;R!T:&%T(&ET
M(&UE971S(%--5%`@<W1A;F1A<F1S+@H@("`@("H*("`@("`J(%1H:7,@:7,@
M<')O=FED960@87,@82!S97!A<F%T92!P=6)L:6,@9G5N8W1I;VX@=&\@9F%C
M:6QI=&%T90H@("`@("H@96%S:65R(&]V97)L;V%D:6YG(&9O<B!T:&4@8V%S
M97,@=VAE<F4@:70@:7,@9&5S:7)A8FQE('1O"B`@("`@*B!C=7-T;VUI>F4@
M=&AE('%U;W1I;F<@8F5H879I;W(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9&%T82`@5&AE(&UE<W-A9V4@=&5X="!T;R!Q=6]T92X@5&AE('-T
M<FEN9R!M=7-T(&)E('!A<W-E9`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@8GD@<F5F97)E;F-E+"!A;F0@=&AE('1E>'0@=VEL;"!B92!M;V1I9FEE
M9"!I;B!P;&%C92X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H@0'-I;F-E("`Q+C(*("`@("`J+PH@("`@9G5N8W1I;VX@<75O=&5D871A
M*"8D9&%T82D*("`@('L*("`@("`@("`O*B!#:&%N9V4@56YI>"`H7&XI(&%N
M9"!-86,@*%QR*2!L:6YE9F5E9',@:6YT;PH@("`@("`@("`J($EN=&5R;F5T
M+7-T86YD87)D($-23$8@*%QR7&XI(&QI;F5F965D<RX@*B\*("`@("`@("`D
M9&%T82`]('!R96=?<F5P;&%C92AA<G)A>2@G+R@_/"%<<BE<;B\G+"<O7'(H
M/R%<;BDO)RDL(")<<EQN(BP@)&1A=&$I.PH*("`@("`@("`O*B!"96-A=7-E
M(&$@<VEN9VQE(&QE861I;F<@<&5R:6]D("@N*2!S:6=N:69I97,@86X@96YD
M('1O('1H90H@("`@("`@("`J(&1A=&$L(&QE9VET:6UA=&4@;&5A9&EN9R!P
M97)I;V1S(&YE960@=&\@8F4@(F1O=6)L960B"B`@("`@("`@("H@*&4N9RX@
M)RXN)RDN("HO"B`@("`@("`@)&1A=&$@/2!S=')?<F5P;&%C92@B7&XN(BP@
M(EQN+BXB+"`D9&%T82D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!396YD('1H
M92!$051!(&-O;6UA;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9&%T82`@5&AE(&UE<W-A9V4@8F]D>2!T;R!S96YD+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@4F5T=7)N<R!A(%!%05)?17)R;W(@=VET:"!A;B!E
M<G)O<B!M97-S86=E(&]N(&%N>0H@("`@("H@("`@("`@("`@("`@("!K:6YD
M(&]F(&9A:6QU<F4L(&]R('1R=64@;VX@<W5C8V5S<RX*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B!`<VEN8V4@(#$N,`H@("`@("HO"B`@("!F=6YC
M=&EO;B!D871A*"1D871A*0H@("`@>PH@("`@("`@("\J(%)&0R`Q.#<P+"!S
M96-T:6]N(#,L('-U8G-E8W1I;VX@,R!S=&%T97,@(F$@=F%L=64@;V8@>F5R
M;PH@("`@("`@("`J(&EN9&EC871E<R!T:&%T(&YO(&9I>&5D(&UA>&EM=6T@
M;65S<V%G92!S:7IE(&ES(&EN(&9O<F-E(BX*("`@("`@("`@*B!&=7)T:&5R
M;6]R92P@:70@<V%Y<R!T:&%T(&EF(")T:&4@<&%R86UE=&5R(&ES(&]M:71T
M960@;F\*("`@("`@("`@*B!I;F9O<FUA=&EO;B!I<R!C;VYV97EE9"!A8F]U
M="!T:&4@<V5R=F5R)W,@9FEX960@;6%X:6UU;0H@("`@("`@("`J(&UE<W-A
M9V4@<VEZ92(N("HO"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?97-M='!;
M)U-)6D4G72D@)B8@*"1T:&ES+3Y?97-M='!;)U-)6D4G72`^(#`I*2!["B`@
M("`@("`@("`@(&EF("AS=')L96XH)&1A=&$I(#X]("1T:&ES+3Y?97-M='!;
M)U-)6D4G72D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F1I<V-O;FYE8W0H
M*3L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=-
M97-S86=E('-I>F4@97AC961E<R!T:&4@<V5R=F5R(&QI;6ET)RD["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%%U;W1E('1H92!D871A
M(&)A<V5D(&]N('1H92!33510('-T86YD87)D<RX@*B\*("`@("`@("`D=&AI
M<RT^<75O=&5D871A*"1D871A*3L*"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&5R<F]R(#T@)'1H:7,M/E]P=70H)T1!5$$G*2DI('L*("`@("`@("`@
M("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"B`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E<W!O;G-E*#,U-"DI
M*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S=6QT(#T@)'1H:7,M/E]S96YD
M*"1D871A("X@(EQR7&XN7')<;B(I*2D@>PH@("`@("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E<W!O;G-E*#(U,"DI*2!["B`@("`@
M("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E;F0@=&AE(%-%3D0@
M1E)/33H@8V]M;6%N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG(%1H
M92!R979E<G-E('!A=&@@=&\@<V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D(%)E='5R;G,@82!014%27T5R<F]R('=I=&@@86X@97)R;W(@;65S
M<V%G92!O;B!A;GD*("`@("`J("`@("`@("`@("`@("`@:VEN9"!O9B!F86EL
M=7)E+"!O<B!T<G5E(&]N('-U8V-E<W,N"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("H@0'-I;F-E("`Q+C(N-@H@("`@("HO"B`@("!F=6YC=&EO;B!S
M96YD1G)O;2@D<&%T:"D*("`@('L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D97)R;W(@/2`D=&AI<RT^7W!U="@G4T5.1"<L(")&4D]-.CPD<&%T:#XB
M*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"B`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P87)S
M95)E<W!O;G-E*#(U,"DI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W([
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J($)A8VMW87)D<RUC;VUP871I8FEL:71Y('=R87!P97(@9F]R
M('-E;F1&<F]M*"DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!4:&4@
M<F5V97)S92!P871H('1O('-E;F0N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"!2971U<FYS(&$@4$5!4E]%<G)O<B!W:71H(&%N(&5R<F]R(&UE<W-A
M9V4@;VX@86YY"B`@("`@*B`@("`@("`@("`@("`@(&MI;F0@;V8@9F%I;'5R
M92P@;W(@=')U92!O;B!S=6-C97-S+@H@("`@("H*("`@("`J($!A8V-E<W,@
M("`@("!P=6)L:6,*("`@("`J($!S:6YC92`@("`@("`Q+C`*("`@("`J($!D
M97!R96-A=&5D("`Q+C(N-@H@("`@("HO"B`@("!F=6YC=&EO;B!S96YD7V9R
M;VTH)'!A=&@I"B`@("!["B`@("`@("`@<F5T=7)N('-E;F1&<F]M*"1P871H
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E;F0@=&AE(%-/34P@1E)/33H@
M8V]M;6%N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG(%1H92!R979E
M<G-E('!A=&@@=&\@<V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M(%)E='5R;G,@82!014%27T5R<F]R('=I=&@@86X@97)R;W(@;65S<V%G92!O
M;B!A;GD*("`@("`J("`@("`@("`@("`@("`@:VEN9"!O9B!F86EL=7)E+"!O
M<B!T<G5E(&]N('-U8V-E<W,N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H@0'-I;F-E("`Q+C(N-@H@("`@("HO"B`@("!F=6YC=&EO;B!S;VUL1G)O
M;2@D<&%T:"D*("`@('L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R
M;W(@/2`D=&AI<RT^7W!U="@G4T]-3"<L(")&4D]-.CPD<&%T:#XB*2DI('L*
M("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"B`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E<W!O
M;G-E*#(U,"DI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J($)A8VMW87)D<RUC;VUP871I8FEL:71Y('=R87!P97(@9F]R('-O;6Q&
M<F]M*"DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!4:&4@<F5V97)S
M92!P871H('1O('-E;F0N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!2
M971U<FYS(&$@4$5!4E]%<G)O<B!W:71H(&%N(&5R<F]R(&UE<W-A9V4@;VX@
M86YY"B`@("`@*B`@("`@("`@("`@("`@(&MI;F0@;V8@9F%I;'5R92P@;W(@
M=')U92!O;B!S=6-C97-S+@H@("`@("H*("`@("`J($!A8V-E<W,@("`@("!P
M=6)L:6,*("`@("`J($!S:6YC92`@("`@("`Q+C`*("`@("`J($!D97!R96-A
M=&5D("`Q+C(N-@H@("`@("HO"B`@("!F=6YC=&EO;B!S;VUL7V9R;VTH)'!A
M=&@I"B`@("!["B`@("`@("`@<F5T=7)N('-O;6Q&<F]M*"1P871H*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E;F0@=&AE(%-!34P@1E)/33H@8V]M;6%N
M9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG(%1H92!R979E<G-E('!A
M=&@@=&\@<V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R
M;G,@82!014%27T5R<F]R('=I=&@@86X@97)R;W(@;65S<V%G92!O;B!A;GD*
M("`@("`J("`@("`@("`@("`@("`@:VEN9"!O9B!F86EL=7)E+"!O<B!T<G5E
M(&]N('-U8V-E<W,N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-I
M;F-E("`Q+C(N-@H@("`@("HO"B`@("!F=6YC=&EO;B!S86UL1G)O;2@D<&%T
M:"D*("`@('L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D
M=&AI<RT^7W!U="@G4T%-3"<L(")&4D]-.CPD<&%T:#XB*2DI('L*("`@("`@
M("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"B`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E<W!O;G-E*#(U
M,"DI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($)A
M8VMW87)D<RUC;VUP871I8FEL:71Y('=R87!P97(@9F]R('-A;6Q&<F]M*"DN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!4:&4@<F5V97)S92!P871H
M('1O('-E;F0N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!2971U<FYS
M(&$@4$5!4E]%<G)O<B!W:71H(&%N(&5R<F]R(&UE<W-A9V4@;VX@86YY"B`@
M("`@*B`@("`@("`@("`@("`@(&MI;F0@;V8@9F%I;'5R92P@;W(@=')U92!O
M;B!S=6-C97-S+@H@("`@("H*("`@("`J($!A8V-E<W,@("`@("!P=6)L:6,*
M("`@("`J($!S:6YC92`@("`@("`Q+C`*("`@("`J($!D97!R96-A=&5D("`Q
M+C(N-@H@("`@("HO"B`@("!F=6YC=&EO;B!S86UL7V9R;VTH)'!A=&@I"B`@
M("!["B`@("`@("`@<F5T=7)N('-A;6Q&<F]M*"1P871H*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E;F0@=&AE(%)3150@8V]M;6%N9"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@82!014%27T5R<F]R('=I=&@@
M86X@97)R;W(@;65S<V%G92!O;B!A;GD*("`@("`J("`@("`@("`@("`@("`@
M:VEN9"!O9B!F86EL=7)E+"!O<B!T<G5E(&]N('-U8V-E<W,N"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0'-I;F-E("`Q+C`*("`@("`J+PH@("`@
M9G5N8W1I;VX@<G-E="@I"B`@("!["B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&5R<F]R(#T@)'1H:7,M/E]P=70H)U)3150G*2DI('L*("`@("`@("`@
M("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"B`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E<W!O;G-E*#(U,"DI
M*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E;F0@
M=&AE(%921ED@8V]M;6%N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M(%1H92!S=')I;F<@=&\@=F5R:69Y"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"!2971U<FYS(&$@4$5!4E]%<G)O<B!W:71H(&%N(&5R<F]R(&UE<W-A
M9V4@;VX@86YY"B`@("`@*B`@("`@("`@("`@("`@(&MI;F0@;V8@9F%I;'5R
M92P@;W(@=')U92!O;B!S=6-C97-S+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J($!S:6YC92`@,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N('9R9GDH
M)'-T<FEN9RD*("`@('L*("`@("`@("`O*B!.;W1E.B`R-3$@:7,@86QS;R!A
M('9A;&ED(')E<W!O;G-E(&-O9&4@*B\*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U="@G5E)&62<L("1S=')I;F<I*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!A<G-E4F5S
M<&]N<V4H87)R87DH,C4P+"`R-3(I*2DI('L*("`@("`@("`@("`@<F5T=7)N
M("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4V5N9"!T:&4@3D]/4"!C;VUM86YD+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@4F5T=7)N<R!A(%!%05)?17)R;W(@
M=VET:"!A;B!E<G)O<B!M97-S86=E(&]N(&%N>0H@("`@("H@("`@("`@("`@
M("`@("!K:6YD(&]F(&9A:6QU<F4L(&]R('1R=64@;VX@<W5C8V5S<RX*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<VEN8V4@(#$N,`H@("`@("HO
M"B`@("!F=6YC=&EO;B!N;V]P*"D*("`@('L*("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U="@G3D]/4"<I*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!A<G-E4F5S<&]N<V4H
M,C4P*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0F%C:W=A<F1S+6-O;7!A=&EB:6QI='D@;65T:&]D+B`@:61E;G1I9GE396YD
M97(H*2=S(&9U;F-T:6]N86QI='D@:7,*("`@("`J(&YO=R!H86YD;&5D(&EN
M=&5R;F%L;'DN"B`@("`@*@H@("`@("H@0')E='5R;B`@8F]O;&5A;B`@("`@
M5&AI<R!M971H;V0@86QW87ES(')E='5R;B!T<G5E+@H@("`@("H*("`@("`J
M($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I;F-E("`@,2XP"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&ED96YT:69Y4V5N9&5R*"D*("`@('L*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+TYE="]3;V-K970N<&AP````````````````````````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#,U-S<U`#$P-3$U-#,S-S0S`#`R,3,Q-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@
M5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@
M1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL
M92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS
M92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C
M:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@
M?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C
M;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*
M+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L
M96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P
M:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN
M("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!!=71H;W)S.B!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@
M("`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\*+R\@)$ED.B!3;V-K970N<&AP+'8@,2XR-"`R,#`U+S`R+S`S
M(#(P.C0P.C$V(&-H86=E;F)U($5X<"`D"@IR97%U:7)E7V]N8V4@)U!%05(N
M<&AP)SL*"F1E9FEN92@G3D547U-/0TM%5%]214%$)RP@(#$I.PID969I;F4H
M)TY%5%]33T-+151?5U))5$4G+"`R*3L*9&5F:6YE*"=.151?4T]#2T547T52
M4D]2)RP@,RD["@HO*BH*("H@1V5N97)A;&EZ960@4V]C:V5T(&-L87-S+@H@
M*@H@*B!`=F5R<VEO;B`Q+C$*("H@0&%U=&AO<B!3=&EG($)A:VME;B`\<W-B
M0'!H<"YN970^"B`J($!A=71H;W(@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J+PIC;&%S<R!.971?4V]C:V5T(&5X=&5N9',@4$5!4B![
M"@H@("`@+RHJ"B`@("`@*B!3;V-K970@9FEL92!P;VEN=&5R+@H@("`@("H@
M0'9A<B!R97-O=7)C92`D9G`*("`@("`J+PH@("`@=F%R("1F<"`](&YU;&P[
M"@H@("`@+RHJ"B`@("`@*B!7:&5T:&5R('1H92!S;V-K970@:7,@8FQO8VMI
M;F<N($1E9F%U;'1S('1O('1R=64N"B`@("`@*B!`=F%R(&)O;VQE86X@)&)L
M;V-K:6YG"B`@("`@*B\*("`@('9A<B`D8FQO8VMI;F<@/2!T<G5E.PH*("`@
M("\J*@H@("`@("H@5VAE=&AE<B!T:&4@<V]C:V5T(&ES('!E<G-I<W1E;G0N
M($1E9F%U;'1S('1O(&9A;'-E+@H@("`@("H@0'9A<B!B;V]L96%N("1P97)S
M:7-T96YT"B`@("`@*B\*("`@('9A<B`D<&5R<VES=&5N="`](&9A;'-E.PH*
M("`@("\J*@H@("`@("H@5&AE($E0(&%D9')E<W,@=&\@8V]N;F5C="!T;RX*
M("`@("`J($!V87(@<W1R:6YG("1A9&1R"B`@("`@*B\*("`@('9A<B`D861D
M<B`]("<G.PH*("`@("\J*@H@("`@("H@5&AE('!O<G0@;G5M8F5R('1O(&-O
M;FYE8W0@=&\N"B`@("`@*B!`=F%R(&EN=&5G97(@)'!O<G0*("`@("`J+PH@
M("`@=F%R("1P;W)T(#T@,#L*"B`@("`O*BH*("`@("`J($YU;6)E<B!O9B!S
M96-O;F1S('1O('=A:70@;VX@<V]C:V5T(&-O;FYE8W1I;VYS(&)E9F]R92!A
M<W-U;6EN9PH@("`@("H@=&AE<F4G<R!N;R!M;W)E(&1A=&$N($1E9F%U;'1S
M('1O(&YO('1I;65O=70N"B`@("`@*B!`=F%R(&EN=&5G97(@)'1I;65O=70*
M("`@("`J+PH@("`@=F%R("1T:6UE;W5T(#T@9F%L<V4["@H@("`@+RHJ"B`@
M("`@*B!.=6UB97(@;V8@8GET97,@=&\@<F5A9"!A="!A('1I;64@:6X@<F5A
M9$QI;F4H*2!A;F0*("`@("`J(')E861!;&PH*2X@1&5F875L=',@=&\@,C`T
M."X*("`@("`J($!V87(@:6YT96=E<B`D;&EN94QE;F=T:`H@("`@("HO"B`@
M("!V87(@)&QI;F5,96YG=&@@/2`R,#0X.PH*("`@("\J*@H@("`@("H@0V]N
M;F5C="!T;R!T:&4@<W!E8VEF:65D('!O<G0N($EF(&-A;&QE9"!W:&5N('1H
M92!S;V-K970@:7,*("`@("`J(&%L<F5A9'D@8V]N;F5C=&5D+"!I="!D:7-C
M;VYN96-T<R!A;F0@8V]N;F5C=',@86=A:6XN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`@)&%D9'(@("`@("`@($E0(&%D9')E<W,@;W(@:&]S="!N
M86UE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'!O<G0@("`@("`@(%1#4"!P
M;W)T(&YU;6)E<BX*("`@("`J($!P87)A;2!B;V]L96%N("1P97)S:7-T96YT
M("`H;W!T:6]N86PI(%=H971H97(@=&AE(&-O;FYE8W1I;VX@:7,*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!P97)S:7-T96YT("AK97!T
M(&]P96X@8F5T=V5E;B!R97%U97-T<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&)Y('1H92!W96(@<V5R=F5R*2X*("`@("`J($!P87)A
M;2!I;G1E9V5R("1T:6UE;W5T("`@("`H;W!T:6]N86PI($AO=R!L;VYG('1O
M('=A:70@9F]R(&1A=&$N"B`@("`@*B!`<&%R86T@87)R87D@("`D;W!T:6]N
M<R`@("`@4V5E(&]P=&EO;G,@9F]R('-T<F5A;5]C;VYT97AT7V-R96%T92X*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B!\(%!%05)?17)R;W(@(%1R=64@;VX@<W5C8V5S<R!O
M<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@8V]N;F5C="@D861D<BP@)'!O<G0@/2`P+"`D<&5R<VES=&5N="`](&YU
M;&PL("1T:6UE;W5T(#T@;G5L;"P@)&]P=&EO;G,@/2!N=6QL*0H@("`@>PH@
M("`@("`@(&EF("AI<U]R97-O=7)C92@D=&AI<RT^9G`I*2!["B`@("`@("`@
M("`@($!F8VQO<V4H)'1H:7,M/F9P*3L*("`@("`@("`@("`@)'1H:7,M/F9P
M(#T@;G5L;#L*("`@("`@("!]"@H@("`@("`@(&EF("@A)&%D9'(I('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"<D861D<B!C86YN
M;W0@8F4@96UP='DG*3L*("`@("`@("!](&5L<V5I9B`H<W1R<W!N*"1A9&1R
M+"`G+C`Q,C,T-38W.#DG*2`]/2!S=')L96XH)&%D9'(I('Q\"B`@("`@("`@
M("`@("`@("`@('-T<G-T<B@D861D<BP@)R\G*2`A/3T@9F%L<V4I('L*("`@
M("`@("`@("`@)'1H:7,M/F%D9'(@/2`D861D<CL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=&AI<RT^861D<B`]($!G971H;W-T8GEN86UE*"1A
M9&1R*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YP;W)T(#T@)'!O<G0@
M)2`V-34S-CL*"B`@("`@("`@:68@*"1P97)S:7-T96YT("$]/2!N=6QL*2![
M"B`@("`@("`@("`@("1T:&ES+3YP97)S:7-T96YT(#T@)'!E<G-I<W1E;G0[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H)'1I;65O=70@(3T](&YU;&PI('L*
M("`@("`@("`@("`@)'1H:7,M/G1I;65O=70@/2`D=&EM96]U=#L*("`@("`@
M("!]"@H@("`@("`@("1O<&5N9G5N8R`]("1T:&ES+3YP97)S:7-T96YT(#\@
M)W!F<V]C:V]P96XG(#H@)V9S;V-K;W!E;B<["B`@("`@("`@)&5R<FYO(#T@
M,#L*("`@("`@("`D97)R<W1R(#T@)R<["B`@("`@("`@:68@*"1O<'1I;VYS
M("8F(&9U;F-T:6]N7V5X:7-T<R@G<W1R96%M7V-O;G1E>'1?8W)E871E)RDI
M('L*("`@("`@("`@("`@:68@*"1T:&ES+3YT:6UE;W5T*2!["B`@("`@("`@
M("`@("`@("`D=&EM96]U="`]("1T:&ES+3YT:6UE;W5T.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1I;65O=70@/2`P.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1C;VYT97AT(#T@<W1R96%M7V-O;G1E
M>'1?8W)E871E*"1O<'1I;VYS*3L*("`@("`@("`@("`@)&9P(#T@0"1O<&5N
M9G5N8R@D=&AI<RT^861D<BP@)'1H:7,M/G!O<G0L("1E<G)N;RP@)&5R<G-T
M<BP@)'1I;65O=70L("1C;VYT97AT*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!I9B`H)'1H:7,M/G1I;65O=70I('L*("`@("`@("`@("`@("`@
M("1F<"`]($`D;W!E;F9U;F,H)'1H:7,M/F%D9'(L("1T:&ES+3YP;W)T+"`D
M97)R;F\L("1E<G)S='(L("1T:&ES+3YT:6UE;W5T*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1F<"`]($`D;W!E;F9U;F,H)'1H
M:7,M/F%D9'(L("1T:&ES+3YP;W)T+"`D97)R;F\L("1E<G)S='(I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(21F<"D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&5R<G-T<BP@)&5R
M<FYO*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YF<"`]("1F<#L*"B`@
M("`@("`@<F5T=7)N("1T:&ES+3YS971";&]C:VEN9R@D=&AI<RT^8FQO8VMI
M;F<I.PH@("`@?0H*("`@("\J*@H@("`@("H@1&ES8V]N;F5C=',@9G)O;2!T
M:&4@<&5E<BP@8VQO<V5S('1H92!S;V-K970N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@;6EX960@=')U92!O;B!S=6-C
M97-S(&]R(&%N(&5R<F]R(&]B:F5C="!O=&AE<G=I<V4*("`@("`J+PH@("`@
M9G5N8W1I;VX@9&ES8V]N;F5C="@I"B`@("!["B`@("`@("`@:68@*"%I<U]R
M97-O=7)C92@D=&AI<RT^9G`I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@G;F]T(&-O;FYE8W1E9"<I.PH@("`@("`@('T*"B`@
M("`@("`@0&9C;&]S92@D=&AI<RT^9G`I.PH@("`@("`@("1T:&ES+3YF<"`]
M(&YU;&P["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!&:6YD(&]U="!I9B!T:&4@<V]C:V5T(&ES(&EN(&)L;V-K:6YG(&UO
M9&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5&AE(&-U<G)E;G0@8FQO8VMI;F<@;6]D92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@:7-";&]C:VEN9R@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3YB;&]C:VEN9SL*("`@('T*"B`@("`O*BH*("`@("`J(%-E
M=',@=VAE=&AE<B!T:&4@<V]C:V5T(&-O;FYE8W1I;VX@<VAO=6QD(&)E(&)L
M;V-K:6YG(&]R"B`@("`@*B!N;W0N($$@<F5A9"!C86QL('1O(&$@;F]N+6)L
M;V-K:6YG('-O8VME="!W:6QL(')E='5R;B!I;6UE9&EA=&5L>0H@("`@("H@
M:68@=&AE<F4@:7,@;F\@9&%T82!A=F%I;&%B;&4L('=H97)E87,@:70@=VEL
M;"!B;&]C:R!U;G1I;"!T:&5R90H@("`@("H@:7,@9&%T82!F;W(@8FQO8VMI
M;F<@<V]C:V5T<RX*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;6]D
M92`@5')U92!F;W(@8FQO8VMI;F<@<V]C:V5T<RP@9F%L<V4@9F]R(&YO;F)L
M;V-K:6YG+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@
M;6EX960@=')U92!O;B!S=6-C97-S(&]R(&%N(&5R<F]R(&]B:F5C="!O=&AE
M<G=I<V4*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T0FQO8VMI;F<H)&UO9&4I
M"B`@("!["B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^9G`I*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G;F]T(&-O
M;FYE8W1E9"<I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/F)L;V-K:6YG
M(#T@)&UO9&4["B`@("`@("`@<V]C:V5T7W-E=%]B;&]C:VEN9R@D=&AI<RT^
M9G`L("1T:&ES+3YB;&]C:VEN9RD["B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!T:6UE;W5T('9A;'5E(&]N
M('-O8VME="!D97-C<FEP=&]R+`H@("`@("H@97AP<F5S<V5D(&EN('1H92!S
M=6T@;V8@<V5C;VYD<R!A;F0@;6EC<F]S96-O;F1S"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)'-E8V]N9',@(%-E8V]N9',N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D;6EC<F]S96-O;F1S("!-:6-R;W-E8V]N9',N"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!M:7AE9"!T<G5E(&]N
M('-U8V-E<W,@;W(@86X@97)R;W(@;V)J96-T(&]T:&5R=VES90H@("`@("HO
M"B`@("!F=6YC=&EO;B!S9714:6UE;W5T*"1S96-O;F1S+"`D;6EC<F]S96-O
M;F1S*0H@("`@>PH@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)'1H:7,M/F9P
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)VYO
M="!C;VYN96-T960G*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!S;V-K
M971?<V5T7W1I;65O=70H)'1H:7,M/F9P+"`D<V5C;VYD<RP@)&UI8W)O<V5C
M;VYD<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&EN9F]R;6%T
M:6]N(&%B;W5T(&%N(&5X:7-T:6YG('-O8VME="!R97-O=7)C92X*("`@("`J
M($-U<G)E;G1L>2!R971U<FYS(&9O=7(@96YT<FEE<R!I;B!T:&4@<F5S=6QT
M(&%R<F%Y.@H@("`@("H*("`@("`J(#QP/@H@("`@("H@=&EM961?;W5T("AB
M;V]L*2`M(%1H92!S;V-K970@=&EM960@;W5T('=A:71I;F<@9F]R(&1A=&$\
M8G(^"B`@("`@*B!B;&]C:V5D("AB;V]L*2`M(%1H92!S;V-K970@=V%S(&)L
M;V-K960\8G(^"B`@("`@*B!E;V8@*&)O;VPI("T@26YD:6-A=&5S($5/1B!E
M=F5N=#QB<CX*("`@("`J('5N<F5A9%]B>71E<R`H:6YT*2`M($YU;6)E<B!O
M9B!B>71E<R!L969T(&EN('1H92!S;V-K970@8G5F9F5R/&)R/@H@("`@("H@
M/"]P/@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T
M=7)N(&UI>&5D($%R<F%Y(&-O;G1A:6YI;F<@:6YF;W)M871I;VX@86)O=70@
M97AI<W1I;F<@<V]C:V5T(')E<V]U<F-E(&]R(&%N(&5R<F]R(&]B:F5C="!O
M=&AE<G=I<V4*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4W1A='5S*"D*("`@
M('L*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1T:&ES+3YF<"DI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=N;W0@8V]N;F5C
M=&5D)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@<V]C:V5T7V=E=%]S
M=&%T=7,H)'1H:7,M/F9P*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A
M('-P96-I9FEE9"!L:6YE(&]F(&1A=&$*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H@0')E='5R;B`D<VEZ92!B>71E<R!O9B!D871A(&9R
M;VT@=&AE('-O8VME="P@;W(@82!014%27T5R<F]R(&EF"B`@("`@*B`@("`@
M("`@(&YO="!C;VYN96-T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=',H
M)'-I>F4I"B`@("!["B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^
M9G`I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G
M;F]T(&-O;FYE8W1E9"<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N($!F
M9V5T<R@D=&AI<RT^9G`L("1S:7IE*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E860@82!S<&5C:69I960@86UO=6YT(&]F(&1A=&$N(%1H:7,@:7,@9W5A
M<F%N=&5E9"!T;R!R971U<FXL"B`@("`@*B!A;F0@:&%S('1H92!A9&1E9"!B
M96YE9FET(&]F(&=E='1I;F<@979E<GET:&EN9R!I;B!O;F4@9G)E860H*0H@
M("`@("H@8VAU;FL[(&EF('EO=2!K;F]W('1H92!S:7IE(&]F('1H92!D871A
M('EO=2=R92!G971T:6YG"B`@("`@*B!B969O<F5H86YD+"!T:&ES(&ES(&1E
M9FEN:71E;'D@=&AE('=A>2!T;R!G;RX*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D<VEZ92`@5&AE(&YU;6)E<B!O9B!B>71E<R!T;R!R96%D(&9R
M;VT@=&AE('-O8VME="X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`
M<F5T=7)N("1S:7IE(&)Y=&5S(&]F(&1A=&$@9G)O;2!T:&4@<V]C:V5T+"!O
M<B!A(%!%05)?17)R;W(@:68*("`@("`J("`@("`@("`@;F]T(&-O;FYE8W1E
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9"@D<VEZ92D*("`@('L*("`@
M("`@("!I9B`H(6ES7W)E<V]U<F-E*"1T:&ES+3YF<"DI('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=N;W0@8V]N;F5C=&5D)RD[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@0&9R96%D*"1T:&ES+3YF<"P@
M)'-I>F4I.PH@("`@?0H*("`@("\J*@H@("`@("H@5W)I=&4@82!S<&5C:69I
M960@86UO=6YT(&]F(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@)&1A=&$@("`@("`@1&%T82!T;R!W<FET92X*("`@("`J($!P87)A;2!I
M;G1E9V5R("1B;&]C:W-I>F4@($%M;W5N="!O9B!D871A('1O('=R:71E(&%T
M(&]N8V4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!.54Q,
M(&UE86YS(&%L;"!A="!O;F-E+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<F5T=7)N(&UI>&5D('1R=64@;VX@<W5C8V5S<R!O<B!A
M;B!E<G)O<B!O8FIE8W0@;W1H97)W:7-E"B`@("`@*B\*("`@(&9U;F-T:6]N
M('=R:71E*"1D871A+"`D8FQO8VMS:7IE(#T@;G5L;"D*("`@('L*("`@("`@
M("!I9B`H(6ES7W)E<V]U<F-E*"1T:&ES+3YF<"DI('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=N;W0@8V]N;F5C=&5D)RD["B`@
M("`@("`@?0H*("`@("`@("!I9B`H:7-?;G5L;"@D8FQO8VMS:7IE*2`F)B`A
M3U-?5TE.1$]74RD@>PH@("`@("`@("`@("!R971U<FX@9G=R:71E*"1T:&ES
M+3YF<"P@)&1A=&$I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF
M("AI<U]N=6QL*"1B;&]C:W-I>F4I*2!["B`@("`@("`@("`@("`@("`D8FQO
M8VMS:7IE(#T@,3`R-#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'!O
M<R`](#`["B`@("`@("`@("`@("1S:7IE(#T@<W1R;&5N*"1D871A*3L*("`@
M("`@("`@("`@=VAI;&4@*"1P;W,@/"`D<VEZ92D@>PH@("`@("`@("`@("`@
M("`@)'=R:71T96X@/2!`9G=R:71E*"1T:&ES+3YF<"P@<W5B<W1R*"1D871A
M+"`D<&]S+"`D8FQO8VMS:7IE*2D["B`@("`@("`@("`@("`@("!I9B`H)'=R
M:71T96X@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'!O
M<R`K/2`D=W)I='1E;CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<F5T
M=7)N("1P;W,["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5W)I
M=&4@82!L:6YE(&]F(&1A=&$@=&\@=&AE('-O8VME="P@9F]L;&]W960@8GD@
M82!T<F%I;&EN9R`B7')<;B(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J($!R971U<FX@;6EX960@9G!U=',@<F5S=6QT+"!O<B!A;B!E
M<G)O<@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET94QI;F4H)&1A=&$I"B`@
M("!["B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^9G`I*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G;F]T(&-O;FYE
M8W1E9"<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9W<FET92@D=&AI
M<RT^9G`L("1D871A("X@(EQR7&XB*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%1E<W1S(&9O<B!E;F0M;V8M9FEL92!O;B!A('-O8VME="!D97-C<FEP=&]R
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N
M(&)O;VP*("`@("`J+PH@("`@9G5N8W1I;VX@96]F*"D*("`@('L*("`@("`@
M("!R971U<FX@*&ES7W)E<V]U<F-E*"1T:&ES+3YF<"D@)B8@9F5O9B@D=&AI
M<RT^9G`I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E861S(&$@8GET92!O
M9B!D871A"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R
M971U<FX@,2!B>71E(&]F(&1A=&$@9G)O;2!T:&4@<V]C:V5T+"!O<B!A(%!%
M05)?17)R;W(@:68*("`@("`J("`@("`@("`@;F]T(&-O;FYE8W1E9"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F5A9$)Y=&4H*0H@("`@>PH@("`@("`@(&EF
M("@A:7-?<F5S;W5R8V4H)'1H:7,M/F9P*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)VYO="!C;VYN96-T960G*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!O<F0H0&9R96%D*"1T:&ES+3YF<"P@,2DI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5A9',@82!W;W)D(&]F(&1A=&$*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B`Q
M('=O<F0@;V8@9&%T82!F<F]M('1H92!S;V-K970L(&]R(&$@4$5!4E]%<G)O
M<B!I9@H@("`@("H@("`@("`@("!N;W0@8V]N;F5C=&5D+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R96%D5V]R9"@I"B`@("!["B`@("`@("`@:68@*"%I<U]R
M97-O=7)C92@D=&AI<RT^9G`I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@G;F]T(&-O;FYE8W1E9"<I.PH@("`@("`@('T*"B`@
M("`@("`@)&)U9B`]($!F<F5A9"@D=&AI<RT^9G`L(#(I.PH@("`@("`@(')E
M='5R;B`H;W)D*"1B=69;,%TI("L@*&]R9"@D8G5F6S%=*2`\/"`X*2D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!296%D<R!A;B!I;G0@;V8@9&%T80H@("`@
M("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&EN=&5G
M97(@(#$@:6YT(&]F(&1A=&$@9G)O;2!T:&4@<V]C:V5T+"!O<B!A(%!%05)?
M17)R;W(@:68*("`@("`J("`@("`@("`@("`@("`@("`@;F]T(&-O;FYE8W1E
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9$EN="@I"B`@("!["B`@("`@
M("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^9G`I*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G;F]T(&-O;FYE8W1E9"<I.PH@
M("`@("`@('T*"B`@("`@("`@)&)U9B`]($!F<F5A9"@D=&AI<RT^9G`L(#0I
M.PH@("`@("`@(')E='5R;B`H;W)D*"1B=69;,%TI("L@*&]R9"@D8G5F6S%=
M*2`\/"`X*2`K"B`@("`@("`@("`@("`@("`H;W)D*"1B=69;,ETI(#P\(#$V
M*2`K("AO<F0H)&)U9ELS72D@/#P@,C0I*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E861S(&$@>F5R;RUT97)M:6YA=&5D('-T<FEN9R!O9B!D871A"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@<W1R
M:6YG+"!O<B!A(%!%05)?17)R;W(@:68*("`@("`J("`@("`@("`@;F]T(&-O
M;FYE8W1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9%-T<FEN9R@I"B`@
M("!["B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^9G`I*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G;F]T(&-O;FYE
M8W1E9"<I.PH@("`@("`@('T*"B`@("`@("`@)'-T<FEN9R`]("<G.PH@("`@
M("`@('=H:6QE("@H)&-H87(@/2!`9G)E860H)'1H:7,M/F9P+"`Q*2D@(3T@
M(EQX,#`B*2`@>PH@("`@("`@("`@("`D<W1R:6YG("X]("1C:&%R.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)'-T<FEN9SL*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E861S(&%N($E0($%D9')E<W,@86YD(')E='5R;G,@:70@:6X@
M82!D;W0@9F]R;6%T960@<W1R:6YG"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J($!R971U<FX@1&]T(&9O<FUA=&5D('-T<FEN9RP@;W(@
M82!014%27T5R<F]R(&EF"B`@("`@*B`@("`@("`@(&YO="!C;VYN96-T960N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E861)4$%D9')E<W,H*0H@("`@>PH@
M("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)'1H:7,M/F9P*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)VYO="!C;VYN96-T960G
M*3L*("`@("`@("!]"@H@("`@("`@("1B=68@/2!`9G)E860H)'1H:7,M/F9P
M+"`T*3L*("`@("`@("!R971U<FX@<W!R:6YT9B@B)7,N)7,N)7,N)7,B+"!O
M<F0H)&)U9ELP72DL(&]R9"@D8G5F6S%=*2P*("`@("`@("`@("`@("`@("`@
M("`@("!O<F0H)&)U9ELR72DL(&]R9"@D8G5F6S-=*2D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!296%D('5N=&EL(&5I=&AE<B!T:&4@96YD(&]F('1H92!S
M;V-K970@;W(@82!N97=L:6YE+"!W:&EC:&5V97(*("`@("`J(&-O;65S(&9I
M<G-T+B!3=')I<',@=&AE('1R86EL:6YG(&YE=VQI;F4@9G)O;2!T:&4@<F5T
M=7)N960@9&%T82X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H@0')E='5R;B!!;&P@879A:6QA8FQE(&1A=&$@=7`@=&\@82!N97=L:6YE
M+"!W:71H;W5T('1H870*("`@("`J("`@("`@("`@;F5W;&EN92P@;W(@=6YT
M:6P@=&AE(&5N9"!O9B!T:&4@<V]C:V5T+"!O<B!A(%!%05)?17)R;W(@:68*
M("`@("`J("`@("`@("`@;F]T(&-O;FYE8W1E9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5A9$QI;F4H*0H@("`@>PH@("`@("`@(&EF("@A:7-?<F5S;W5R
M8V4H)'1H:7,M/F9P*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H)VYO="!C;VYN96-T960G*3L*("`@("`@("!]"@H@("`@("`@
M("1L:6YE(#T@)R<["B`@("`@("`@)'1I;65O=70@/2!T:6UE*"D@*R`D=&AI
M<RT^=&EM96]U=#L*("`@("`@("!W:&EL92`H(69E;V8H)'1H:7,M/F9P*2`F
M)B`H(21T:&ES+3YT:6UE;W5T('Q\('1I;64H*2`\("1T:6UE;W5T*2D@>PH@
M("`@("`@("`@("`D;&EN92`N/2!`9F=E=',H)'1H:7,M/F9P+"`D=&AI<RT^
M;&EN94QE;F=T:"D["B`@("`@("`@("`@(&EF("AS=6)S='(H)&QI;F4L("TQ
M*2`]/2`B7&XB*2!["B`@("`@("`@("`@("`@("!R971U<FX@<G1R:6TH)&QI
M;F4L(")<<EQN(BD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1L:6YE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5A9"!U;G1I
M;"!T:&4@<V]C:V5T(&-L;W-E<RP@;W(@=6YT:6P@=&AE<F4@:7,@;F\@;6]R
M92!D871A(&EN"B`@("`@*B!T:&4@:6YN97(@4$A0(&)U9F9E<BX@268@=&AE
M(&EN;F5R(&)U9F9E<B!I<R!E;7!T>2P@:6X@8FQO8VMI;F<*("`@("`J(&UO
M9&4@=V4@=V%I="!F;W(@870@;&5A<W0@,2!B>71E(&]F(&1A=&$N(%1H97)E
M9F]R92P@:6X*("`@("`J(&)L;V-K:6YG(&UO9&4L(&EF('1H97)E(&ES(&YO
M(&1A=&$@870@86QL('1O(&)E(')E860L('1H:7,*("`@("`J(&9U;F-T:6]N
M('=I;&P@;F5V97(@97AI="`H=6YL97-S('1H92!S;V-K970@:7,@8VQO<V5D
M(&]N('1H90H@("`@("H@<F5M;W1E(&5N9"DN"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@06QL
M(&1A=&$@=6YT:6P@=&AE('-O8VME="!C;&]S97,L(&]R(&$@4$5!4E]%<G)O
M<B!I9@H@("`@("H@("`@("`@("`@("`@("`@(&YO="!C;VYN96-T960N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E861!;&PH*0H@("`@>PH@("`@("`@(&EF
M("@A:7-?<F5S;W5R8V4H)'1H:7,M/F9P*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)VYO="!C;VYN96-T960G*3L*("`@("`@
M("!]"@H@("`@("`@("1D871A(#T@)R<["B`@("`@("`@=VAI;&4@*"%F96]F
M*"1T:&ES+3YF<"DI('L*("`@("`@("`@("`@)&1A=&$@+CT@0&9R96%D*"1T
M:&ES+3YF<"P@)'1H:7,M/FQI;F5,96YG=&@I.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2=6YS('1H
M92!E<75I=F%L96YT(&]F('1H92!S96QE8W0H*2!S>7-T96T@8V%L;"!O;B!T
M:&4@<V]C:V5T"B`@("`@*B!W:71H(&$@=&EM96]U="!S<&5C:69I960@8GD@
M='9?<V5C(&%N9"!T=E]U<V5C+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E
M9V5R("1S=&%T92`@("!7:&EC:"!O9B!R96%D+W=R:71E+V5R<F]R('1O(&-H
M96-K(&9O<BX*("`@("`J($!P87)A;2!I;G1E9V5R("1T=E]S96,@("!.=6UB
M97(@;V8@<V5C;VYD<R!F;W(@=&EM96]U="X*("`@("`J($!P87)A;2!I;G1E
M9V5R("1T=E]U<V5C("!.=6UB97(@;V8@;6EC<F]S96-O;F1S(&9O<B!T:6UE
M;W5T+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T
M=7)N($9A;'-E(&EF('-E;&5C="!F86EL<RP@:6YT96=E<B!D97-C<FEB:6YG
M('=H:6-H(&]F(')E860O=W)I=&4O97)R;W(*("`@("`J("`@("`@("`@87)E
M(')E861Y+"!O<B!014%27T5R<F]R(&EF(&YO="!C;VYN96-T960N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E;&5C="@D<W1A=&4L("1T=E]S96,L("1T=E]U
M<V5C(#T@,"D*("`@('L*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1T:&ES
M+3YF<"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*"=N;W0@8V]N;F5C=&5D)RD["B`@("`@("`@?0H*("`@("`@("`D<F5A9"`]
M(&YU;&P["B`@("`@("`@)'=R:71E(#T@;G5L;#L*("`@("`@("`D97AC97!T
M(#T@;G5L;#L*("`@("`@("!I9B`H)'-T871E("8@3D547U-/0TM%5%]214%$
M*2!["B`@("`@("`@("`@("1R96%D6UT@/2`D=&AI<RT^9G`["B`@("`@("`@
M?0H@("`@("`@(&EF("@D<W1A=&4@)B!.151?4T]#2T547U=2251%*2!["B`@
M("`@("`@("`@("1W<FET95M=(#T@)'1H:7,M/F9P.PH@("`@("`@('T*("`@
M("`@("!I9B`H)'-T871E("8@3D547U-/0TM%5%]%4E)/4BD@>PH@("`@("`@
M("`@("`D97AC97!T6UT@/2`D=&AI<RT^9G`["B`@("`@("`@?0H@("`@("`@
M(&EF("AF86QS92`]/3T@*"1S<B`]('-T<F5A;5]S96QE8W0H)')E860L("1W
M<FET92P@)&5X8V5P="P@)'1V7W-E8RP@)'1V7W5S96,I*2D@>PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT
M(#T@,#L*("`@("`@("!I9B`H8V]U;G0H)')E860I*2!["B`@("`@("`@("`@
M("1R97-U;'0@?#T@3D547U-/0TM%5%]214%$.PH@("`@("`@('T*("`@("`@
M("!I9B`H8V]U;G0H)'=R:71E*2D@>PH@("`@("`@("`@("`D<F5S=6QT('P]
M($Y%5%]33T-+151?5U))5$4["B`@("`@("`@?0H@("`@("`@(&EF("AC;W5N
M="@D97AC97!T*2D@>PH@("`@("`@("`@("`D<F5S=6QT('P]($Y%5%]33T-+
M151?15)23U(["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@?0H*?0H````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O3F5T
M+U523"YP:'``````````````````````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,S(V,S0`,3`U,34T,S,W-#,`,#(P-3$U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP#0HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\($-O<'ER:6=H="`H8RD@,C`P
M,BTR,#`T+"!2:6-H87)D($AE>65S("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\#0HO+R!\($%L;"!R:6=H=',@<F5S97)V960N("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO
M+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\(%)E9&ES=')I
M8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I
M=&@@;W(@=VET:&]U="`@("!\#0HO+R!\(&UO9&EF:6-A=&EO;BP@87)E('!E
M<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N
M<R`@("!\#0HO+R!\(&%R92!M970Z("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\(&\@4F5D:7-T<FEB
M=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C
M;W!Y<FEG:'0@("`@("!\#0HO+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@
M8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+B`@("`@
M("!\#0HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU
M<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@("!\#0HO+R!\("`@
M;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO
M=VEN9R!D:7-C;&%I;65R(&EN('1H92!\#0HO+R!\("`@9&]C=6UE;G1A=&EO
M;B!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I
M<W1R:6)U=&EO;BY\#0HO+R!\(&\@5&AE(&YA;65S(&]F('1H92!A=71H;W)S
M(&UA>2!N;W0@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@("`@("!\
M#0HO+R!\("`@<')O9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4@
M=VET:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N("!\#0HO+R!\("`@<&5R
M;6ES<VEO;BX@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\#0HO+R!\("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\#0HO+R!\(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@
M5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,@("!\#0HO
M+R!\(")!4R!)4R(@04Y$($%.62!%6%!215-3($]2($E-4$Q)140@5T%24D%.
M5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4("`@("!\#0HO+R!\($Q)34E4140@
M5$\L(%1(12!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519
M($%.1"!&251.15-3($9/4B!\#0HO+R!\($$@4$%25$E#54Q!4B!055)03U-%
M($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@0T]065))
M1TA4("!\#0HO+R!\($]73D52($]2($-/3E1224)55$]24R!"12!,24%"3$4@
M1D]2($%.62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!\#0HO+R!\
M(%-014-)04PL($5814U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!1T53
M("A)3D-,541)3D<L($)55"!.3U0@("`@("!\#0HO+R!\($Q)34E4140@5$\L
M(%!23T-54D5-14Y4($]&(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[
M($Q/4U,@3T8@55-%+"!\#0HO+R!\($1!5$$L($]2(%!23T9)5%,[($]2($)5
M4TE.15-3($E.5$524E505$E/3BD@2$]7159%4B!#0553140@04Y$($].($%.
M62!\#0HO+R!\(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X@0T].
M5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL($]2(%1/4E0@("!\#0HO+R!\("A)
M3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X@
M04Y9(%=!62!/550@3T8@5$A%(%5312!\#0HO+R!\($]&(%1(25,@4T]&5%=!
M4D4L($5614X@248@041625-%1"!/1B!42$4@4$]34TE"24Q)5%D@3T8@4U5#
M2"!$04U!1T4N("!\#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\($%U=&AO
M<CH@4FEC:&%R9"!(97EE<R`\<FEC:&%R9"!A="!P:'`@;F5T/B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK#0HO+PT*+R\@)$ED.B!54DPN<&AP+'8@,2XS-B`R,#`T+S`V
M+S$Y(#$X.C4X.C4P(')I8VAA<F0@17AP("0-"B\O#0HO+R!.971?55),($-L
M87-S#0H-"F-L87-S($YE=%]54DP-"GL-"B`@("`O*BH-"B`@("`J($9U;&P@
M=7)L#0H@("`@*B!`=F%R('-T<FEN9PT*("`@("HO#0H@("`@=F%R("1U<FP[
M#0H-"B`@("`O*BH-"B`@("`J(%!R;W1O8V]L#0H@("`@*B!`=F%R('-T<FEN
M9PT*("`@("HO#0H@("`@=F%R("1P<F]T;V-O;#L-"@T*("`@("\J*@T*("`@
M("H@57-E<FYA;64-"B`@("`J($!V87(@<W1R:6YG#0H@("`@*B\-"B`@("!V
M87(@)'5S97)N86UE.PT*#0H@("`@+RHJ#0H@("`@*B!087-S=V]R9`T*("`@
M("H@0'9A<B!S=')I;F<-"B`@("`J+PT*("`@('9A<B`D<&%S<W=O<F0[#0H-
M"B`@("`O*BH-"B`@("`J($AO<W0-"B`@("`J($!V87(@<W1R:6YG#0H@("`@
M*B\-"B`@("!V87(@)&AO<W0[#0H-"B`@("`O*BH-"B`@("`J(%!O<G0-"B`@
M("`J($!V87(@:6YT96=E<@T*("`@("HO#0H@("`@=F%R("1P;W)T.PT*#0H@
M("`@+RHJ#0H@("`@*B!0871H#0H@("`@*B!`=F%R('-T<FEN9PT*("`@("HO
M#0H@("`@=F%R("1P871H.PT*#0H@("`@+RHJ#0H@("`@*B!1=65R>2!S=')I
M;F<-"B`@("`J($!V87(@87)R87D-"B`@("`J+PT*("`@('9A<B`D<75E<GES
M=')I;F<[#0H-"B`@("`O*BH-"B`@("`J($%N8VAO<@T*("`@("H@0'9A<B!S
M=')I;F<-"B`@("`J+PT*("`@('9A<B`D86YC:&]R.PT*#0H@("`@+RHJ#0H@
M("`@*B!7:&5T:&5R('1O('5S92!;70T*("`@("H@0'9A<B!B;V]L#0H@("`@
M*B\-"B`@("!V87(@)'5S94)R86-K971S.PT*#0H@("`@+RHJ#0H@("`@*B!0
M2%`T($-O;G-T<G5C=&]R#0H@("`@*@T*("`@("H@0'-E92!?7V-O;G-T<G5C
M="@I#0H@("`@*B\-"B`@("!F=6YC=&EO;B!.971?55),*"1U<FP@/2!N=6QL
M+"`D=7-E0G)A8VME=',@/2!T<G5E*0T*("`@('L-"B`@("`@("`@)'1H:7,M
M/E]?8V]N<W1R=6-T*"1U<FPL("1U<V5"<F%C:V5T<RD[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@*B!02%`U($-O;G-T<G5C=&]R#0H@("`@*@T*("`@("H@
M4&%R<V5S('1H92!G:79E;B!U<FP@86YD('-T;W)E<R!T:&4@=F%R:6]U<R!P
M87)T<PT*("`@("H@1&5F875L=',@87)E('5S960@:6X@8V5R=&%I;B!C87-E
M<PT*("`@("H-"B`@("`J($!P87)A;2!S=')I;F<@)'5R;"`@("`@("`@($]P
M=&EO;F%L(%523`T*("`@("H@0'!A<F%M(&)O;VP@("`D=7-E0G)A8VME=',@
M5VAE=&AE<B!T;R!U<V4@<W%U87)E(&)R86-K971S('=H96X-"B`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&UU;'1I<&QE('%U97)Y<W1R:6YG
M<R!W:71H('1H92!S86UE(&YA;64-"B`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&5X:7-T#0H@("`@*B\-"B`@("!F=6YC=&EO;B!?7V-O;G-T
M<G5C="@D=7)L(#T@;G5L;"P@)'5S94)R86-K971S(#T@=')U92D-"B`@("![
M#0H@("`@("`@("1(5%107U-%4E9%4E]605)3("`]("%E;7!T>2@D7U-%4E9%
M4BD@/R`D7U-%4E9%4B`Z("1'3$]"04Q36R=(5%107U-%4E9%4E]605)3)UT[
M#0H-"B`@("`@("`@)'1H:7,M/G5S94)R86-K971S(#T@)'5S94)R86-K971S
M.PT*("`@("`@("`D=&AI<RT^=7)L("`@("`@("`@/2`D=7)L.PT*("`@("`@
M("`D=&AI<RT^=7-E<B`@("`@("`@/2`G)SL-"B`@("`@("`@)'1H:7,M/G!A
M<W,@("`@("`@(#T@)R<[#0H@("`@("`@("1T:&ES+3YH;W-T("`@("`@("`]
M("<G.PT*("`@("`@("`D=&AI<RT^<&]R="`@("`@("`@/2`X,#L-"B`@("`@
M("`@)'1H:7,M/G!A=&@@("`@("`@(#T@)R<[#0H@("`@("`@("1T:&ES+3YQ
M=65R>7-T<FEN9R`](&%R<F%Y*"D[#0H@("`@("`@("1T:&ES+3YA;F-H;W(@
M("`@("`]("<G.PT*#0H@("`@("`@("\O($]N;'D@=7-E(&1E9F%U;'1S(&EF
M(&YO="!A;B!A8G-O;'5T92!54DP@9VEV96X-"B`@("`@("`@:68@*"%P<F5G
M7VUA=&-H*"<O7EMA+7HP+3E=*SI<+UPO+VDG+"`D=7)L*2D@>PT*#0H@("`@
M("`@("`@("`D=&AI<RT^<')O=&]C;VP@("`@/2`H0"1(5%107U-%4E9%4E]6
M05)36R=(5%104R==(#T]("=O;B<@/R`G:'1T<',G(#H@)VAT='`G*3L-"@T*
M("`@("`@("`@("`@+RHJ#0H@("`@("`@("`@("`J($9I9W5R92!O=70@:&]S
M="]P;W)T#0H@("`@("`@("`@("`J+PT*("`@("`@("`@("`@:68@*"%E;7!T
M>2@D2%144%]315)615)?5D%24ULG2%144%](3U-4)UTI($%.1"!P<F5G7VUA
M=&-H*"<O7B@N*BDH.BA;,"TY72LI*3\D+U4G+"`D2%144%]315)615)?5D%2
M4ULG2%144%](3U-4)UTL("1M871C:&5S*2D@>PT*("`@("`@("`@("`@("`@
M("1H;W-T(#T@)&UA=&-H97-;,5T[#0H@("`@("`@("`@("`@("`@:68@*"%E
M;7!T>2@D;6%T8VAE<ULS72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'!O
M<G0@/2`D;6%T8VAE<ULS73L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`D<&]R="`]("1T:&ES+3YG9713=&%N9&%R
M9%!O<G0H)'1H:7,M/G!R;W1O8V]L*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H-"B`@("`@("`@("`@("1T:&ES+3YU<V5R("`@("`@
M("`]("<G.PT*("`@("`@("`@("`@)'1H:7,M/G!A<W,@("`@("`@(#T@)R<[
M#0H@("`@("`@("`@("`D=&AI<RT^:&]S="`@("`@("`@/2`A96UP='DH)&AO
M<W0I(#\@)&AO<W0@.B`H:7-S970H)$A45%!?4T525D527U9!4E-;)U-%4E9%
M4E].04U%)UTI(#\@)$A45%!?4T525D527U9!4E-;)U-%4E9%4E].04U%)UT@
M.B`G;&]C86QH;W-T)RD[#0H@("`@("`@("`@("`D=&AI<RT^<&]R="`@("`@
M("`@/2`A96UP='DH)'!O<G0I(#\@)'!O<G0@.B`H:7-S970H)$A45%!?4T52
M5D527U9!4E-;)U-%4E9%4E]03U)4)UTI(#\@)$A45%!?4T525D527U9!4E-;
M)U-%4E9%4E]03U)4)UT@.B`D=&AI<RT^9V5T4W1A;F1A<F10;W)T*"1T:&ES
M+3YP<F]T;V-O;"DI.PT*("`@("`@("`@("`@)'1H:7,M/G!A=&@@("`@("`@
M(#T@(65M<'1Y*"1(5%107U-%4E9%4E]605)36R=02%!?4T5,1B==*2`_("1(
M5%107U-%4E9%4E]605)36R=02%!?4T5,1B==(#H@)R\G.PT*("`@("`@("`@
M("`@)'1H:7,M/G%U97)Y<W1R:6YG(#T@:7-S970H)$A45%!?4T525D527U9!
M4E-;)U%515)97U-44DE.1R==*2`_("1T:&ES+3Y?<&%R<V5287=1=65R>7-T
M<FEN9R@D2%144%]315)615)?5D%24ULG455%4EE?4U1224Y')UTI(#H@;G5L
M;#L-"B`@("`@("`@("`@("1T:&ES+3YA;F-H;W(@("`@("`]("<G.PT*("`@
M("`@("!]#0H-"B`@("`@("`@+R\@4&%R<V4@=&AE('5R;"!A;F0@<W1O<F4@
M=&AE('9A<FEO=7,@<&%R=',-"B`@("`@("`@:68@*"%E;7!T>2@D=7)L*2D@
M>PT*("`@("`@("`@("`@)'5R;&EN9F\@/2!P87)S95]U<FPH)'5R;"D[#0H-
M"B`@("`@("`@("`@("\O($1E9F%U;'0@<75E<GES=')I;F<-"B`@("`@("`@
M("`@("1T:&ES+3YQ=65R>7-T<FEN9R`](&%R<F%Y*"D[#0H-"B`@("`@("`@
M("`@(&9O<F5A8V@@*"1U<FQI;F9O(&%S("1K97D@/3X@)'9A;'5E*2![#0H@
M("`@("`@("`@("`@("`@<W=I=&-H("@D:V5Y*2![#0H@("`@("`@("`@("`@
M("`@("`@(&-A<V4@)W-C:&5M92<Z#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^<')O=&]C;VP@/2`D=F%L=64[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^<&]R="`@("`@/2`D=&AI<RT^9V5T4W1A;F1A<F10
M;W)T*"1V86QU92D[#0H@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL-
M"@T*("`@("`@("`@("`@("`@("`@("!C87-E("=U<V5R)SH-"B`@("`@("`@
M("`@("`@("`@("`@8V%S92`G<&%S<R<Z#0H@("`@("`@("`@("`@("`@("`@
M(&-A<V4@)VAO<W0G.@T*("`@("`@("`@("`@("`@("`@("!C87-E("=P;W)T
M)SH-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3XD:V5Y(#T@)'9A
M;'5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@
M("`@("`@("`@("`@("`@8V%S92`G<&%T:"<Z#0H@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H)'9A;'5E>S!](#T]("<O)RD@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YP871H(#T@)'9A;'5E.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<&%T:"`](&1I<FYA;64H)'1H:7,M/G!A=&@I(#T]($1)
M4D5#5$]265]315!!4D%43U(@/R`G)R`Z(&1I<FYA;64H)'1H:7,M/G!A=&@I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YP871H(#T@
M<W!R:6YT9B@G)7,O)7,G+"`D<&%T:"P@)'9A;'5E*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PT*#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@)W%U97)Y)SH-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YQ=65R>7-T<FEN9R`]("1T:&ES
M+3Y?<&%R<V5287=1=65R>5-T<FEN9R@D=F%L=64I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@("`@("`@("`@8V%S
M92`G9G)A9VUE;G0G.@T*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/F%N8VAO<B`]("1V86QU93L-"B`@("`@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("H@4F5T=7)N<R!F=6QL('5R
M;`T*("`@("H-"B`@("`J($!R971U<FX@<W1R:6YG($9U;&P@=7)L#0H@("`@
M*B!`86-C97-S('!U8FQI8PT*("`@("HO#0H@("`@9G5N8W1I;VX@9V5T55),
M*"D-"B`@("![#0H@("`@("`@("1Q=65R>7-T<FEN9R`]("1T:&ES+3YG9711
M=65R>5-T<FEN9R@I.PT*#0H@("`@("`@("1T:&ES+3YU<FP@/2`D=&AI<RT^
M<')O=&]C;VP@+B`G.B\O)PT*("`@("`@("`@("`@("`@("`@("X@)'1H:7,M
M/G5S97(@+B`H(65M<'1Y*"1T:&ES+3YP87-S*2`_("<Z)R`Z("<G*0T*("`@
M("`@("`@("`@("`@("`@("X@)'1H:7,M/G!A<W,@+B`H(65M<'1Y*"1T:&ES
M+3YU<V5R*2`_("=`)R`Z("<G*0T*("`@("`@("`@("`@("`@("`@("X@)'1H
M:7,M/FAO<W0@+B`H)'1H:7,M/G!O<G0@/3T@)'1H:7,M/F=E=%-T86YD87)D
M4&]R="@D=&AI<RT^<')O=&]C;VPI(#\@)R<@.B`G.B<@+B`D=&AI<RT^<&]R
M="D-"B`@("`@("`@("`@("`@("`@("`N("1T:&ES+3YP871H#0H@("`@("`@
M("`@("`@("`@("`@+B`H(65M<'1Y*"1Q=65R>7-T<FEN9RD@/R`G/R<@+B`D
M<75E<GES=')I;F<@.B`G)RD-"B`@("`@("`@("`@("`@("`@("`N("@A96UP
M='DH)'1H:7,M/F%N8VAO<BD@/R`G(R<@+B`D=&AI<RT^86YC:&]R(#H@)R<I
M.PT*#0H@("`@("`@(')E='5R;B`D=&AI<RT^=7)L.PT*("`@('T-"@T*("`@
M("\J*@T*("`@("H@061D<R!A('%U97)Y<W1R:6YG(&ET96T-"B`@("`J#0H@
M("`@*B!`<&%R86T@('-T<FEN9R`D;F%M92`@("`@("!.86UE(&]F(&ET96T-
M"B`@("`J($!P87)A;2`@<W1R:6YG("1V86QU92`@("`@(%9A;'5E(&]F(&ET
M96T-"B`@("`J($!P87)A;2`@8F]O;"`@("1P<F5E;F-O9&5D(%=H971H97(@
M=F%L=64@:7,@=7)L96YC;V1E9"!O<B!N;W0L(&1E9F%U;'0@/2!N;W0-"B`@
M("`J($!A8V-E<W,@<'5B;&EC#0H@("`@*B\-"B`@("!F=6YC=&EO;B!A9&11
M=65R>5-T<FEN9R@D;F%M92P@)'9A;'5E+"`D<')E96YC;V1E9"`](&9A;'-E
M*0T*("`@('L-"B`@("`@("`@:68@*"1P<F5E;F-O9&5D*2![#0H@("`@("`@
M("`@("`D=&AI<RT^<75E<GES=')I;F=;)&YA;65=(#T@)'9A;'5E.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M/G%U97)Y<W1R:6YG
M6R1N86UE72`](&ES7V%R<F%Y*"1V86QU92D@/R!A<G)A>5]M87`H)W)A=W5R
M;&5N8V]D92<L("1V86QU92DZ(')A=W5R;&5N8V]D92@D=F%L=64I.PT*("`@
M("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@*B!296UO=F5S(&$@<75E
M<GES=')I;F<@:71E;0T*("`@("H-"B`@("`J($!P87)A;2`@<W1R:6YG("1N
M86UE($YA;64@;V8@:71E;0T*("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`J
M+PT*("`@(&9U;F-T:6]N(')E;6]V95%U97)Y4W1R:6YG*"1N86UE*0T*("`@
M('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YQ=65R>7-T<FEN9ULD;F%M
M95TI*2![#0H@("`@("`@("`@("!U;G-E="@D=&AI<RT^<75E<GES=')I;F=;
M)&YA;65=*3L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("H@
M4V5T<R!T:&4@<75E<GES=')I;F<@=&\@;&ET97)A;&QY('=H870@>6]U('-U
M<'!L>0T*("`@("H-"B`@("`J($!P87)A;2`@<W1R:6YG("1Q=65R>7-T<FEN
M9R!4:&4@<75E<GES=')I;F<@9&%T82X@4VAO=6QD(&)E(&]F('1H92!F;W)M
M870@9F]O/6)A<B9X/7D@971C#0H@("`@*B!`86-C97-S('!U8FQI8PT*("`@
M("HO#0H@("`@9G5N8W1I;VX@861D4F%W475E<GE3=')I;F<H)'%U97)Y<W1R
M:6YG*0T*("`@('L-"B`@("`@("`@)'1H:7,M/G%U97)Y<W1R:6YG(#T@)'1H
M:7,M/E]P87)S95)A=U%U97)Y4W1R:6YG*"1Q=65R>7-T<FEN9RD[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@*B!2971U<FYS(&9L870@<75E<GES=')I;F<-
M"B`@("`J#0H@("`@*B!`<F5T=7)N('-T<FEN9R!1=65R>7-T<FEN9PT*("`@
M("H@0&%C8V5S<R!P=6)L:6,-"B`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%%U
M97)Y4W1R:6YG*"D-"B`@("![#0H@("`@("`@(&EF("@A96UP='DH)'1H:7,M
M/G%U97)Y<W1R:6YG*2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M
M/G%U97)Y<W1R:6YG(&%S("1N86UE(#T^("1V86QU92D@>PT*("`@("`@("`@
M("`@("`@(&EF("AI<U]A<G)A>2@D=F%L=64I*2![#0H@("`@("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1V86QU92!A<R`D:R`]/B`D=BD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'%U97)Y<W1R:6YG6UT@/2`D=&AI<RT^=7-E
M0G)A8VME=',@/R!S<')I;G1F*"<E<ULE<UT])7,G+"`D;F%M92P@)&LL("1V
M*2`Z("@D;F%M92`N("<])R`N("1V*3L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@('T@96QS96EF("@A:7-?;G5L;"@D=F%L=64I
M*2![#0H@("`@("`@("`@("`@("`@("`@("1Q=65R>7-T<FEN9UM=(#T@)&YA
M;64@+B`G/2<@+B`D=F%L=64[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@)'%U97)Y<W1R:6YG6UT@/2`D;F%M93L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`D<75E<GES=')I;F<@/2!I;7!L;V1E*&EN:5]G970H)V%R9U]S97!A<F%T
M;W(N;W5T<'5T)RDL("1Q=65R>7-T<FEN9RD[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`D<75E<GES=')I;F<@/2`G)SL-"B`@("`@("`@?0T*
M#0H@("`@("`@(')E='5R;B`D<75E<GES=')I;F<[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@*B!087)S97,@<F%W('%U97)Y<W1R:6YG(&%N9"!R971U<FYS
M(&%N(&%R<F%Y(&]F(&ET#0H@("`@*@T*("`@("H@0'!A<F%M("!S=')I;F<@
M("1Q=65R>7-T<FEN9R!4:&4@<75E<GES=')I;F<@=&\@<&%R<V4-"B`@("`J
M($!R971U<FX@87)R87D@("`@("`@("`@("`@("`@06X@87)R87D@;V8@=&AE
M('%U97)Y<W1R:6YG(&1A=&$-"B`@("`J($!A8V-E<W,@<')I=F%T90T*("`@
M("HO#0H@("`@9G5N8W1I;VX@7W!A<G-E4F%W475E<GES=')I;F<H)'%U97)Y
M<W1R:6YG*0T*("`@('L-"B`@("`@("`@)'!A<G1S("`]('!R96=?<W!L:70H
M)R];)R`N('!R96=?<75O=&4H:6YI7V=E="@G87)G7W-E<&%R871O<BYI;G!U
M="<I+"`G+R<I("X@)UTO)RP@)'%U97)Y<W1R:6YG+"`M,2P@4%)%1U]34$Q)
M5%].3U]%35!462D[#0H@("`@("`@("1R971U<FX@/2!A<G)A>2@I.PT*#0H@
M("`@("`@(&9O<F5A8V@@*"1P87)T<R!A<R`D<&%R="D@>PT*("`@("`@("`@
M("`@:68@*'-T<G!O<R@D<&%R="P@)STG*2`A/3T@9F%L<V4I('L-"B`@("`@
M("`@("`@("`@("`D=F%L=64@/2!S=6)S='(H)'!A<G0L('-T<G!O<R@D<&%R
M="P@)STG*2`K(#$I.PT*("`@("`@("`@("`@("`@("1K97D@("`]('-U8G-T
M<B@D<&%R="P@,"P@<W1R<&]S*"1P87)T+"`G/2<I*3L-"B`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@)'9A;'5E(#T@;G5L;#L-"B`@
M("`@("`@("`@("`@("`D:V5Y("`@/2`D<&%R=#L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&EF("AS=6)S='(H)&ME>2P@+3(I(#T]("=;72<I('L-
M"B`@("`@("`@("`@("`@("`D:V5Y(#T@<W5B<W1R*"1K97DL(#`L("TR*3L-
M"B`@("`@("`@("`@("`@("!I9B`H0"%I<U]A<G)A>2@D<F5T=7)N6R1K97E=
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<F5T=7)N6R1K97E=("`@/2!A
M<G)A>2@I.PT*("`@("`@("`@("`@("`@("`@("`D<F5T=7)N6R1K97E=6UT@
M/2`D=F%L=64[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@)')E='5R;ELD:V5Y75M=(#T@)'9A;'5E.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS96EF("@A)'1H:7,M/G5S
M94)R86-K971S($%.1"`A96UP='DH)')E='5R;ELD:V5Y72DI('L-"B`@("`@
M("`@("`@("`@("`D<F5T=7)N6R1K97E=("`@/2`H87)R87DI)')E='5R;ELD
M:V5Y73L-"B`@("`@("`@("`@("`@("`D<F5T=7)N6R1K97E=6UT@/2`D=F%L
M=64[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1R
M971U<FY;)&ME>5T@/2`D=F%L=64[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"@T*("`@("`@("!R971U<FX@)')E='5R;CL-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`J(%)E<V]L=F5S("\O+"`N+B\@86YD("XO(&9R;VT@82!P871H
M(&%N9"!R971U<FYS#0H@("`@*B!T:&4@<F5S=6QT+B!%9SH-"B`@("`J#0H@
M("`@*B`O9F]O+V)A<B\N+B]B;V\N<&AP("`@(#T^("]F;V\O8F]O+G!H<`T*
M("`@("H@+V9O;R]B87(O+BXO+BXO8F]O+G!H<"`]/B`O8F]O+G!H<`T*("`@
M("H@+V9O;R]B87(O+BXO+B\O8F]O+G!H<"`]/B`O9F]O+V)O;RYP:'`-"B`@
M("`J#0H@("`@*B!4:&ES(&UE=&AO9"!C86X@86QS;R!B92!C86QL960@<W1A
M=&EC86QL>2X-"B`@("`J#0H@("`@*B!`<&%R86T@('-T<FEN9R`D=7)L(%52
M3"!P871H('1O(')E<V]L=F4-"B`@("`J($!R971U<FX@<W1R:6YG("`@("`@
M5&AE(')E<W5L=`T*("`@("HO#0H@("`@9G5N8W1I;VX@<F5S;VQV95!A=&@H
M)'!A=&@I#0H@("`@>PT*("`@("`@("`D<&%T:"`](&5X<&QO9&4H)R\G+"!S
M=')?<F5P;&%C92@G+R\G+"`G+R<L("1P871H*2D[#0H-"B`@("`@("`@9F]R
M("@D:3TP.R`D:3QC;W5N="@D<&%T:"D[("1I*RLI('L-"B`@("`@("`@("`@
M(&EF("@D<&%T:%LD:5T@/3T@)RXG*2![#0H@("`@("`@("`@("`@("`@=6YS
M970H)'!A=&A;)&E=*3L-"B`@("`@("`@("`@("`@("`D<&%T:"`](&%R<F%Y
M7W9A;'5E<R@D<&%T:"D[#0H@("`@("`@("`@("`@("`@)&DM+3L-"@T*("`@
M("`@("`@("`@?2!E;'-E:68@*"1P871H6R1I72`]/2`G+BXG($%.1"`H)&D@
M/B`Q($]2("@D:2`]/2`Q($%.1"`D<&%T:%LP72`A/2`G)RD@*2`I('L-"B`@
M("`@("`@("`@("`@("!U;G-E="@D<&%T:%LD:5TI.PT*("`@("`@("`@("`@
M("`@('5N<V5T*"1P871H6R1I+3%=*3L-"B`@("`@("`@("`@("`@("`D<&%T
M:"`](&%R<F%Y7W9A;'5E<R@D<&%T:"D[#0H@("`@("`@("`@("`@("`@)&D@
M+3T@,CL-"@T*("`@("`@("`@("`@?2!E;'-E:68@*"1P871H6R1I72`]/2`G
M+BXG($%.1"`D:2`]/2`Q($%.1"`D<&%T:%LP72`]/2`G)RD@>PT*("`@("`@
M("`@("`@("`@('5N<V5T*"1P871H6R1I72D[#0H@("`@("`@("`@("`@("`@
M)'!A=&@@/2!A<G)A>5]V86QU97,H)'!A=&@I.PT*("`@("`@("`@("`@("`@
M("1I+2T[#0H-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"@T*("`@
M("`@("!R971U<FX@:6UP;&]D92@G+R<L("1P871H*3L-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`J(%)E='5R;G,@=&AE('-T86YD87)D('!O<G0@;G5M8F5R
M(&9O<B!A('!R;W1O8V]L#0H@("`@*@T*("`@("H@0'!A<F%M("!S=')I;F<@
M("1S8VAE;64@5&AE('!R;W1O8V]L('1O(&QO;VMU<`T*("`@("H@0')E='5R
M;B!I;G1E9V5R("`@("`@("`@4&]R="!N=6UB97(@;W(@3E5,3"!I9B!N;R!S
M8VAE;64@;6%T8VAE<PT*("`@("H-"B`@("`J($!A=71H;W(@4&AI;&EP<&4@
M2F%U<VEO;G,@/%!H:6QI<'!E+DIA=7-I;VYS0#$Q86)A8W5S+F-O;3X-"B`@
M("`J+PT*("`@(&9U;F-T:6]N(&=E=%-T86YD87)D4&]R="@D<V-H96UE*0T*
M("`@('L-"B`@("`@("`@<W=I=&-H("AS=')T;VQO=V5R*"1S8VAE;64I*2![
M#0H@("`@("`@("`@("!C87-E("=H='1P)SH@("`@<F5T=7)N(#@P.PT*("`@
M("`@("`@("`@8V%S92`G:'1T<',G.B`@(')E='5R;B`T-#,[#0H@("`@("`@
M("`@("!C87-E("=F='`G.B`@("`@<F5T=7)N(#(Q.PT*("`@("`@("`@("`@
M8V%S92`G:6UA<"<Z("`@(')E='5R;B`Q-#,[#0H@("`@("`@("`@("!C87-E
M("=I;6%P<R<Z("`@<F5T=7)N(#DY,SL-"B`@("`@("`@("`@(&-A<V4@)W!O
M<#,G.B`@("!R971U<FX@,3$P.PT*("`@("`@("`@("`@8V%S92`G<&]P,W,G
M.B`@(')E='5R;B`Y.34[#0H@("`@("`@("`@("!D969A=6QT.B`@("`@("`@
M<F5T=7)N(&YU;&P[#0H@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@
M("H@1F]R8V5S('1H92!54DP@=&\@82!P87)T:6-U;&%R('!R;W1O8V]L#0H@
M("`@*@T*("`@("H@0'!A<F%M('-T<FEN9R`@)'!R;W1O8V]L(%!R;W1O8V]L
M('1O(&9O<F-E('1H92!54DP@=&\-"B`@("`J($!P87)A;2!I;G1E9V5R("1P
M;W)T("`@("!/<'1I;VYA;"!P;W)T("AS=&%N9&%R9"!P;W)T(&ES('5S960@
M8GD@9&5F875L="D-"B`@("`J+PT*("`@(&9U;F-T:6]N('-E=%!R;W1O8V]L
M*"1P<F]T;V-O;"P@)'!O<G0@/2!N=6QL*0T*("`@('L-"B`@("`@("`@)'1H
M:7,M/G!R;W1O8V]L(#T@)'!R;W1O8V]L.PT*("`@("`@("`D=&AI<RT^<&]R
M="`](&ES7VYU;&PH)'!O<G0I(#\@)'1H:7,M/F=E=%-T86YD87)D4&]R="@I
M(#H@)'!O<G0[#0H@("`@?0T*#0I]#0H_/@T*````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]/4R\`````````````````````````
M````````````````````````````````````````````````````````````
M```P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,S<T,0`P,3<Q,C,`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T]3+T=U
M97-S+G!H<```````````````````````````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#(U-S4W`#$P-3$U-#,S-S0Q`#`R,#<T,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`T*+RHJ#0H@*B!4:&4@
M3U-?1W5E<W,@8VQA<W,-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*
M("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T
M;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@
M879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F
M;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@
M*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET
M('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L
M:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE
M9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G
M92`@("!014%2#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H
M<"YN970^#0H@*B!`875T:&]R("`@("!'<F5G;W)Y($)E879E<B`\8V5L;&]G
M0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'
M<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#
M5E,Z("1)9#H@1W5E<W,N<&AP+'8@,2XR,"`R,#`U+S$P+S(V(#$Y.C,S.C`S
M(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA
M8FQE('-I;F-E(%!%05(@,"XQ#0H@*B\-"@T*+R\@>WM[('5N86UE(&5X86UP
M;&5S#0H-"B\O('!H<%]U;F%M92@I('=I=&AO=70@87)G<R!R971U<FYS('1H
M92!S86UE(&%S("=U;F%M92`M82<L(&]R(&$@4$A0+6-U<W1O;0T*+R\@<W1R
M:6YG(&9O<B!7:6YD;W=S+@T*+R\@4$A0('9E<G-I;VYS('!R:6]R('1O(#0N
M,R!R971U<FX@=&AE('5N86UE(&]F('1H92!H;W-T('=H97)E(%!(4"!W87,@
M8G5I;'0L#0HO+R!A<R!O9B`T+C,@:70@<F5T=7)N<R!T:&4@=6YA;64@;V8@
M=&AE(&AO<W0@<G5N;FEN9R!T:&4@4$A0(&-O9&4N#0HO+PT*+R\@4$,@4F5D
M2&%T($QI;G5X(#<N,3H-"B\O($QI;G5X(&AO<W0N97AA;7!L92YC;VT@,BXT
M+C(M,B`C,2!3=6X@07!R(#@@,C`Z-#$Z,S`@1414(#(P,#$@:38X-B!U;FMN
M;W=N#0HO+PT*+R\@4$,@1&5B:6%N(%!O=&%T;SH-"B\O($QI;G5X(&AO<W0@
M,BXT+C$W(",R(%--4"!4=64@1F5B(#$R(#$U.C$P.C`T($-%5"`R,#`R(&DV
M.#8@=6YK;F]W;@T*+R\-"B\O(%!#($9R965"4T0@,RXS.@T*+R\@1G)E94)3
M1"!H;W-T+F5X86UP;&4N8V]M(#,N,RU35$%"3$4@1G)E94)31"`S+C,M4U1!
M0DQ%(",P.B!-;VX@1F5B(#(Q(#`P.C0R.C,Q($-%5"`R,#`P("`@("!R;V]T
M0&5X86UP;&4N8V]M.B]U<W(O<W)C+W-Y<R]C;VUP:6QE+T-/3D9)1R`@:3,X
M-@T*+R\-"B\O(%!#($9R965"4T0@-"XS.@T*+R\@1G)E94)31"!H;W-T+F5X
M86UP;&4N8V]M(#0N,RU214Q%05-%($9R965"4T0@-"XS+5)%3$5!4T4@(S$Z
M($UO;B!*=6X@,C4@,3$Z,3DZ-#,@1414(#(P,#$@("`@(')O;W1`97AA;7!L
M92YC;VTZ+W5S<B]S<F,O<WES+V-O;7!I;&4O0T].1DE'("!I,S@V#0HO+PT*
M+R\@4$,@1G)E94)31"`T+C4Z#0HO+R!&<F5E0E-$(&AO<W0N97AA;7!L92YC
M;VT@-"XU+5-404),12!&<F5E0E-$(#0N-2U35$%"3$4@(S`Z(%=E9"!&96(@
M(#8@,C,Z-3DZ,C,@0T54(#(P,#(@("`@(')O;W1`97AA;7!L92YC;VTZ+W5S
M<B]S<F,O<WES+V-O;7!I;&4O0T].1DE'("!I,S@V#0HO+PT*+R\@4$,@1G)E
M94)31"`T+C4@=R]U;F%M92!F<F]M($=.52!S:&5L;'5T:6QS.@T*+R\@1G)E
M94)31"!H;W-T+F5X86UP;&4N8V]M(#0N-2U35$%"3$4@1G)E94)31"`T+C4M
M4U1!0DQ%(",P.B!7960@1F5B("!I,S@V('5N:VYO=VX-"B\O#0HO+R!(4"`Y
M,#`P+S<Q,B!(4"U56"`Q,#H-"B\O($A0+558(&EQ($(N,3`N,3`@02`Y,#`P
M+S<Q,B`R,#`X-#(Y,3$S('1W;RUU<V5R(&QI8V5N<V4-"B\O#0HO+R!(4"`Y
M,#`P+S<Q,B!(4"U56"`Q,"!W+W5N86UE(&9R;VT@1TY5('-H96QL=71I;',Z
M#0HO+R!(4"U56"!H;W-T($(N,3`N,3`@02`Y,#`P+S<Q,B!U;FMN;W=N#0HO
M+PT*+R\@24)-(%)3-C`P,"\U-3`@04E8(#0N,SH-"B\O($%)6"!H;W-T(#,@
M-"`P,#`P,#,U,S%#,#`-"B\O#0HO+R!!25@@-"XS('<O=6YA;64@9G)O;2!'
M3E4@<VAE;&QU=&EL<SH-"B\O($%)6"!H;W-T(#,@-"`P,#`P,#,U,S%#,#`@
M=6YK;F]W;@T*+R\-"B\O(%-'22!/;GEX($E225@@-BXU('<O=6YA;64@9G)O
M;2!'3E4@<VAE;&QU=&EL<SH-"B\O($E225@V-"!H;W-T(#8N-2`P,3`Y,3@R
M,"!)4#$Y(&UI<',-"B\O#0HO+R!31TD@3VYY>"!)4DE8(#8N-3H-"B\O($E2
M25@V-"!H;W-T(#8N-2`P,3`Y,3@R,"!)4#$Y#0HO+PT*+R\@4W!A<F-3=&%T
M:6]N(#(P(%-O;&%R:7,@."!W+W5N86UE(&9R;VT@1TY5('-H96QL=71I;',Z
M#0HO+R!3=6Y/4R!H;W-T+F5X86UP;&4N8V]M(#4N."!'96YE<FEC7S$P.#4R
M."TQ,B!S=6XT;2!S<&%R8PT*+R\-"B\O(%-P87)C4W1A=&EO;B`R,"!3;VQA
M<FES(#@Z#0HO+R!3=6Y/4R!H;W-T+F5X86UP;&4N8V]M(#4N."!'96YE<FEC
M7S$P.#4R."TQ,B!S=6XT;2!S<&%R8R!354Y7+%-005)#<W1A=&EO;BTR,`T*
M+R\-"B\O($UA8R!/4R!8("A$87)W:6XI#0HO+R!$87)W:6X@:&]M92UE9&5N
M+FQO8V%L(#<N-2XP($1A<G=I;B!+97)N96P@5F5R<VEO;B`W+C4N,#H@5&AU
M($%U9R`@-2`Q.3HR-CHQ-B!01%0@,C`P-#L@<F]O=#IX;G4O>&YU+34Q-RXW
M+C(Q+F]B:GXS+U)%3$5!4T5?4%!#("!0;W=E<B!-86-I;G1O<V@-"B\O#0HO
M+R!-86,@3U,@6"!E87)L>2!V97)S:6]N<PT*+R\@#0H-"B\O('U]?0T*#0HO
M*B!43T1/.@T*("H@+2!D969I;F4@96YD:6%N;F5S<RP@=&\@86QL;W<@;6%T
M8VA3:6=N871U<F4H(F)I9V5N9"(I(&5T8RX-"B`J+PT*#0HO*BH-"B`J(%)E
M=')I979E<R!I;F9O<FUA=&EO;B!A8F]U="!T:&4@8W5R<F5N="!O<&5R871I
M;F<@<WES=&5M#0H@*@T*("H@5&AI<R!C;&%S<R!U<V5S('!H<%]U;F%M92@I
M('1O(&=R;VL@:6YF;W)M871I;VX@86)O=70@=&AE(&-U<G)E;G0@3U,-"B`J
M#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@
M*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`
M875T:&]R("`@("!'<F5G;W)Y($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@
M*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`T*("H@0&QI
M8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@
M4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N
M.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!2
M96QE87-E(#`N,0T*("HO#0IC;&%S<R!/4U]'=65S<PT*>PT*("`@('9A<B`D
M<WES;F%M93L-"B`@("!V87(@)&YO9&5N86UE.PT*("`@('9A<B`D8W!U.PT*
M("`@('9A<B`D<F5L96%S93L-"B`@("!V87(@)&5X=')A.PT*#0H@("`@9G5N
M8W1I;VX@3U-?1W5E<W,H)'5N86UE(#T@;G5L;"D-"B`@("![#0H@("`@("`@
M(&QI<W0H)'1H:7,M/G-Y<VYA;64L#0H@("`@("`@("`@("`@)'1H:7,M/G)E
M;&5A<V4L#0H@("`@("`@("`@("`@)'1H:7,M/F-P=2P-"B`@("`@("`@("`@
M("`D=&AI<RT^97AT<F$L#0H@("`@("`@("`@("`@)'1H:7,M/FYO9&5N86UE
M*2`]("1T:&ES+3YP87)S95-I9VYA='5R92@D=6YA;64I.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N('!A<G-E4VEG;F%T=7)E*"1U;F%M92`](&YU;&PI#0H@
M("`@>PT*("`@("`@("!S=&%T:6,@)'-Y<VUA<"`](&%R<F%Y*`T*("`@("`@
M("`@("`@)TA0+558)R`]/B`G:'!U>"<L#0H@("`@("`@("`@("`G25))6#8T
M)R`]/B`G:7)I>"<L#0H@("`@("`@("D[#0H@("`@("`@('-T871I8R`D8W!U
M;6%P(#T@87)R87DH#0H@("`@("`@("`@("`G:34X-B<@/3X@)VDS.#8G+`T*
M("`@("`@("`@("`@)VDV.#8G(#T^("=I,S@V)RP-"B`@("`@("`@("`@("=P
M<&,G(#T^("=P;W=E<G!C)RP-"B`@("`@("`@*3L-"B`@("`@("`@:68@*"1U
M;F%M92`]/3T@;G5L;"D@>PT*("`@("`@("`@("`@)'5N86UE(#T@<&AP7W5N
M86UE*"D[#0H@("`@("`@('T-"B`@("`@("`@)'!A<G1S(#T@<W!L:70H)UM;
M.G-P86-E.EU=*R<L('1R:6TH)'5N86UE*2D[#0H@("`@("`@("1N(#T@8V]U
M;G0H)'!A<G1S*3L-"@T*("`@("`@("`D<F5L96%S92`]("1M86-H:6YE(#T@
M)&-P=2`]("<G.PT*("`@("`@("`D<WES;F%M92`]("1P87)T<ULP73L-"B`@
M("`@("`@)&YO9&5N86UE(#T@)'!A<G1S6S%=.PT*("`@("`@("`D8W!U(#T@
M)'!A<G1S6R1N+3%=.PT*("`@("`@("`D97AT<F$@/2`G)SL-"B`@("`@("`@
M:68@*"1C<'4@/3T@)W5N:VYO=VXG*2![#0H@("`@("`@("`@("`D8W!U(#T@
M)'!A<G1S6R1N+3)=.PT*("`@("`@("!]#0H-"B`@("`@("`@<W=I=&-H("@D
M<WES;F%M92D@>PT*("`@("`@("`@("`@8V%S92`G04E8)R`Z#0H@("`@("`@
M("`@("`@("`@)')E;&5A<V4@/2`B)'!A<G1S6S-=+B1P87)T<ULR72([#0H@
M("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=7:6YD
M;W=S)R`Z#0H@("`@("`@("`@("`@("`@<W=I=&-H("@D<&%R='-;,5TI('L-
M"B`@("`@("`@("`@("`@("`@("`@8V%S92`G.34O.3@G.@T*("`@("`@("`@
M("`@("`@("`@("`@("`@)')E;&5A<V4@/2`G.7@G.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@(&1E9F%U
M;'0Z#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5L96%S92`]("1P87)T
M<ULQ73L-"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D8W!U(#T@)VDS.#8G.PT*
M("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G3&EN
M=7@G(#H-"B`@("`@("`@("`@("`@("`D97AT<F$@/2`D=&AI<RT^7V1E=&5C
M=$=L:6)C5F5R<VEO;B@I.PT*("`@("`@("`@("`@("`@("\O('5S92!O;FQY
M('1H92!F:7)S="!T=V\@9&EG:71S(&9R;VT@=&AE(&ME<FYE;"!V97)S:6]N
M#0H@("`@("`@("`@("`@("`@)')E;&5A<V4@/2!E<F5G7W)E<&QA8V4H)UXH
M6ULZ9&EG:70Z75TK7"Y;6SID:6=I=#I=72LI+BHG+"`G7#$G+"`D<&%R='-;
M,ETI.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S
M92`G36%C)R`Z#0H@("`@("`@("`@("`@("`@)'-Y<VYA;64@/2`G9&%R=VEN
M)SL-"B`@("`@("`@("`@("`@("`D;F]D96YA;64@/2`D<&%R='-;,ET[#0H@
M("`@("`@("`@("`@("`@)')E;&5A<V4@/2`D<&%R='-;,UT[#0H@("`@("`@
M("`@("`@("`@:68@*"1C<'4@/3T@)TUA8VEN=&]S:"<I('L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1P87)T<ULD;B`M(#)=(#T]("=0;W=E<B<I('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1C<'4@/2`G<&]W97)P8R<[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=$87)W:6XG
M(#H-"B`@("`@("`@("`@("`@("!I9B`H)&-P=2`]/2`G36%C:6YT;W-H)RD@
M>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)'!A<G1S6R1N("T@,ET@/3T@
M)U!O=V5R)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-P=2`]("=P
M;W=E<G!C)SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`D<F5L96%S92`](&5R96=?<F5P;&%C
M92@G7BA;6SID:6=I=#I=72M<+EM;.F1I9VET.EU=*RDN*B<L("=<,2<L("1P
M87)T<ULR72D[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@
M("!D969A=6QT.@T*("`@("`@("`@("`@("`@("1R96QE87-E(#T@97)E9U]R
M97!L86-E*"<M+BHG+"`G)RP@)'!A<G1S6S)=*3L-"B`@("`@("`@("`@("`@
M("!B<F5A:SL-"B`@("`@("`@?0T*#0H-"B`@("`@("`@:68@*&ES<V5T*"1S
M>7-M87!;)'-Y<VYA;65=*2D@>PT*("`@("`@("`@("`@)'-Y<VYA;64@/2`D
M<WES;6%P6R1S>7-N86UE73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("1S>7-N86UE(#T@<W1R=&]L;W=E<B@D<WES;F%M92D[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1C<'5M87!;)&-P=5TI*2![#0H@("`@
M("`@("`@("`D8W!U(#T@)&-P=6UA<%LD8W!U73L-"B`@("`@("`@?0T*("`@
M("`@("!R971U<FX@87)R87DH)'-Y<VYA;64L("1R96QE87-E+"`D8W!U+"`D
M97AT<F$L("1N;V1E;F%M92D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7V1E
M=&5C=$=L:6)C5F5R<VEO;B@I#0H@("`@>PT*("`@("`@("!S=&%T:6,@)&=L
M:6)C(#T@9F%L<V4[#0H@("`@("`@(&EF("@D9VQI8F,@(3T](&9A;'-E*2![
M#0H@("`@("`@("`@("!R971U<FX@)&=L:6)C.R`O+R!N;R!N965D('1O(')U
M;B!T:&ES(&UU;'1I<&QE('1I;65S#0H@("`@("`@('T-"B`@("`@("`@:6YC
M;'5D95]O;F-E(")3>7-T96TN<&AP(CL-"B`@("`@("`@:68@*"%F:6QE7V5X
M:7-T<R@G+W5S<B]B:6XO8W!P)RD@?'P@(6ES7V5X96-U=&%B;&4H)R]U<W(O
M8FEN+V-P<"<I*2![#0H@("`@("`@("`@("`O+R!5<V4@9VQI8F,G<R`\9F5A
M='5R97,N:#X@:&5A9&5R(&9I;&4@=&\-"B`@("`@("`@("`@("\O(&=E="!M
M86IO<B!A;F0@;6EN;W(@=F5R<VEO;B!N=6UB97(Z#0H@("`@("`@("`@("!I
M9B`H)&9E871U<F5S7V9I;&4@/2!`9F]P96XH)R]U<W(O:6YC;'5D92]F96%T
M=7)E<RYH)RP@)W)B)RD@*2![#0H@("`@("`@("`@("`@("`@=VAI;&4@*"%F
M96]F*"1F96%T=7)E<U]F:6QE*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M;&EN92`](&9G971S*"1F96%T=7)E<U]F:6QE+"`X,3DR*3L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"$D;&EN92!\?"`H<W1R<&]S*"1L:6YE+"`G(V1E
M9FEN92<I(#T]/2!F86QS92DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@(&EF("AS=')P;W,H)&QI;F4L("=?7T=,24)#7U\G*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@;6%J;W(@=F5R<VEO;B!N=6UB
M97(@(V1E9FEN92!?7T=,24)#7U\@=F5R<VEO;@T*("`@("`@("`@("`@("`@
M("`@("`@("`@)&QI;F4@/2!P<F5G7W-P;&ET*"<O7',K+R<L("1L:6YE*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1G;&EB8U]M86IO<B`]('1R:6TH
M)&QI;F5;,ETI.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1G;&EB8U]M:6YO<BDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("AS=')P;W,H)&QI;F4L("=?
M7T=,24)#7TU)3D]27U\G*2D@('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("\O(&=O="!T:&4@;6EN;W(@=F5R<VEO;B!N=6UB97(-"B`@("`@("`@("`@
M("`@("`@("`@("`@("\O("-D969I;F4@7U]'3$E"0U]-24Y/4E]?('9E<G-I
M;VX-"B`@("`@("`@("`@("`@("`@("`@("`@("1L:6YE(#T@<')E9U]S<&QI
M="@G+UQS*R\G+"`D;&EN92D[#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M9VQI8F-?;6EN;W(@/2!T<FEM*"1L:6YE6S)=*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D9VQI8F-?;6%J;W(I*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!F8VQO<V4H)&9E871U<F5S7V9I;&4I.PT*("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)&=L:6)C7VUA:F]R*2!\?"`A:7-S970H
M)&=L:6)C7VUI;F]R*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)&=L:6)C(#T@)R<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(')E='5R;B`D9VQI8F,@/2`G9VQI8F,G("X@=')I;2@D9VQI8F-?;6%J
M;W(I("X@(BXB("X@=')I;2@D9VQI8F-?;6EN;W(I(#L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(')E='5R;B`D9VQI8F,@/2`G)SL-"B`@("`@("`@
M?0T*("`@("`@("`D=&UP9FEL92`](%-Y<W1E;3HZ;6MT96UP*")G;&EB8W1E
M<W0B*3L-"B`@("`@("`@)&9P(#T@9F]P96XH)'1M<&9I;&4L(")W(BD[#0H@
M("`@("`@(&9W<FET92@D9G`L("(C:6YC;'5D92`\9F5A='5R97,N:#Y<;E]?
M1TQ)0D-?7R!?7T=,24)#7TU)3D]27U]<;B(I.PT*("`@("`@("!F8VQO<V4H
M)&9P*3L-"B`@("`@("`@)&-P<"`]('!O<&5N*"(O=7-R+V)I;B]C<'`@)'1M
M<&9I;&4B+"`B<B(I.PT*("`@("`@("`D;6%J;W(@/2`D;6EN;W(@/2`P.PT*
M("`@("`@("!W:&EL92`H)&QI;F4@/2!F9V5T<R@D8W!P+"`Q,#(T*2D@>PT*
M("`@("`@("`@("`@:68@*"1L:6YE>S!](#T]("<C)R!\?"!T<FEM*"1L:6YE
M*2`]/2`G)RD@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@:68@*&QI<W0H)&UA:F]R+"`D;6EN;W(I
M(#T@97AP;&]D92@G("<L('1R:6TH)&QI;F4I*2D@>PT*("`@("`@("`@("`@
M("`@(&)R96%K.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M('!C;&]S92@D8W!P*3L-"B`@("`@("`@=6YL:6YK*"1T;7!F:6QE*3L-"B`@
M("`@("`@:68@*"$H)&UA:F]R("8F("1M:6YO<BD@)B8@:7-?;&EN:R@G+VQI
M8B]L:6)C+G-O+C8G*2D@>PT*("`@("`@("`@("`@+R\@3&5T)W,@=')Y(')E
M861I;F<@=&AE(&QI8F,N<V\N-B!S>6UL:6YK#0H@("`@("`@("`@("!I9B`H
M97)E9R@G7FQI8F,M*%LN*ETI7"YS;R0G+"!B87-E;F%M92AR96%D;&EN:R@G
M+VQI8B]L:6)C+G-O+C8G*2DL("1M871C:&5S*2D@>PT*("`@("`@("`@("`@
M("`@(&QI<W0H)&UA:F]R+"`D;6EN;W(I(#T@97AP;&]D92@G+B<L("1M871C
M:&5S*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M(2@D;6%J;W(@)B8@)&UI;F]R*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1G
M;&EB8R`]("<G.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D9VQI8F,@
M/2`B9VQI8F-[)&UA:F]R?2Y[)&UI;F]R?2([#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@9V5T4VEG;F%T=7)E*"D-"B`@("![#0H@("`@("`@(&EF("AE;7!T
M>2@D=&AI<RT^97AT<F$I*2![#0H@("`@("`@("`@("!R971U<FX@(GLD=&AI
M<RT^<WES;F%M97TM>R1T:&ES+3YR96QE87-E?2U[)'1H:7,M/F-P=7TB.PT*
M("`@("`@("!]#0H@("`@("`@(')E='5R;B`B>R1T:&ES+3YS>7-N86UE?2U[
M)'1H:7,M/G)E;&5A<V5]+7LD=&AI<RT^8W!U?2U[)'1H:7,M/F5X=')A?2([
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T4WES;F%M92@I#0H@("`@>PT*
M("`@("`@("!R971U<FX@)'1H:7,M/G-Y<VYA;64[#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@9V5T3F]D96YA;64H*0T*("`@('L-"B`@("`@("`@<F5T=7)N
M("1T:&ES+3YN;V1E;F%M93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971#
M<'4H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YC<'4[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@9V5T4F5L96%S92@I#0H@("`@>PT*("`@("`@
M("!R971U<FX@)'1H:7,M/G)E;&5A<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@9V5T17AT<F$H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YE
M>'1R83L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!M871C:%-I9VYA='5R92@D
M;6%T8V@I#0H@("`@>PT*("`@("`@("!I9B`H:7-?87)R87DH)&UA=&-H*2D@
M>PT*("`@("`@("`@("`@)&9R86=M96YT<R`]("1M871C:#L-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("1F<F%G;65N=',@/2!E>'!L;V1E*"<M
M)RP@)&UA=&-H*3L-"B`@("`@("`@?0T*("`@("`@("`D;B`](&-O=6YT*"1F
M<F%G;65N=',I.PT*("`@("`@("`D;6%T8VAE<R`](#`[#0H@("`@("`@(&EF
M("@D;B`^(#`I('L-"B`@("`@("`@("`@("1M871C:&5S("L]("1T:&ES+3Y?
M;6%T8VA&<F%G;65N="@D9G)A9VUE;G1S6S!=+"`D=&AI<RT^<WES;F%M92D[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"1N(#X@,2D@>PT*("`@("`@("`@
M("`@)&UA=&-H97,@*ST@)'1H:7,M/E]M871C:$9R86=M96YT*"1F<F%G;65N
M='-;,5TL("1T:&ES+3YR96QE87-E*3L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H)&X@/B`R*2![#0H@("`@("`@("`@("`D;6%T8VAE<R`K/2`D=&AI<RT^
M7VUA=&-H1G)A9VUE;G0H)&9R86=M96YT<ULR72P@)'1H:7,M/F-P=2D[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"1N(#X@,RD@>PT*("`@("`@("`@("`@
M)&UA=&-H97,@*ST@)'1H:7,M/E]M871C:$9R86=M96YT*"1F<F%G;65N='-;
M,UTL("1T:&ES+3YE>'1R82D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M("@D;6%T8VAE<R`]/2`D;BD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7VUA
M=&-H1G)A9VUE;G0H)&9R86=M96YT+"`D=F%L=64I#0H@("`@>PT*("`@("`@
M("!I9B`H<W1R8W-P;B@D9G)A9VUE;G0L("<J/R<I(#P@<W1R;&5N*"1F<F%G
M;65N="DI('L-"B`@("`@("`@("`@("1R96<@/2`G7B<@+B!S=')?<F5P;&%C
M92AA<G)A>2@G*B<L("<_)RP@)R\G*2P@87)R87DH)RXJ)RP@)RXG+"`G7%PO
M)RDL("1F<F%G;65N="D@+B`G)"<[#0H@("`@("`@("`@("!R971U<FX@97)E
M9VDH)')E9RP@)'9A;'5E*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M*"1F<F%G;65N="`]/2`G*B<@?'P@(7-T<F-A<V5C;7`H)&9R86=M96YT+"`D
M=F%L=64I*3L-"B`@("!]#0H-"GT-"B\J#0H@*B!,;V-A;"!687)I86)L97,Z
M#0H@*B!I;F1E;G0M=&%B<RUM;V1E.B!N:6P-"B`J(&,M8F%S:6,M;V9F<V5T
M.B`T#0H@*B!%;F0Z#0H@*B\-"C\^#0H``````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+P``````````````````
M````````````````````````````````````````````````````````````
M```````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q
M-30S,S<T,0`P,3<S,S$`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%
M05(O075T;VQO861E<BYP:'``````````````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#$U-S0Q`#$P-3$U-#,S-S0Q`#`R,C$U,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`T*+RHJ#0H@*B!#
M;&%S<R!A=71O+6QO861E<@T*("H-"B`J(%!(4"!V97)S:6]N<R`T#0H@*@T*
M("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E
M<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I
M;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO
M=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H
M92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR
M;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@
M(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE
M=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@
M*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED
M.B!!=71O;&]A9&5R+G!H<"QV(#$N,3,@,C`P-B\P,2\P-B`P-#HT-SHS-B!C
M96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O;6%N=6%L+V5N+V-O<F4N<'!M+G!H<"-C;W)E+G!P;2YP96%R+6%U=&]L
M;V%D97(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E
M;&5A<V4@,"XQ#0H@*B!`9&5P<F5C871E9"!&:6QE(&1E<')E8V%T960@:6X@
M4F5L96%S92`Q+C0N,&$Q#0H@*B\-"@T*+R\@+RH@=FEM.B!S970@97AP86YD
M=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30Z("HO#0H-"FEF("@A97AT96YS
M:6]N7VQO861E9"@B;W9E<FQO860B*2D@>PT*("`@("\O(&1I92!H87)D('=I
M=&AO=70@97AT+V]V97)L;V%D#0H@("`@9&EE*")296)U:6QD(%!(4"!W:71H
M('1H92!@;W9E<FQO860G(&5X=&5N<VEO;B!T;R!U<V4@4$5!4E]!=71O;&]A
M9&5R(BD[#0I]#0H-"B\J*@T*("H@26YC;'5D92!F;W(@4$5!4E]%<G)O<B!A
M;F0@4$5!4B!C;&%S<V5S#0H@*B\-"G)E<75I<F5?;VYC92`B4$5!4BYP:'`B
M.PT*#0HO*BH-"B`J(%1H:7,@8VQA<W,@:7,@9F]R(&]B:F5C=',@=VAE<F4@
M>6]U('=A;G0@=&\@<V5P87)A=&4@=&AE(&-O9&4@9F]R#0H@*B!S;VUE(&UE
M=&AO9',@:6YT;R!S97!A<F%T92!C;&%S<V5S+B`@5&AI<R!I<R!U<V5F=6P@
M:68@>6]U(&AA=F4@80T*("H@8VQA<W,@=VET:"!N;W0M9G)E<75E;G1L>2UU
M<V5D(&UE=&AO9',@=&AA="!C;VYT86EN(&QO=',@;V8@8V]D90T*("H@=&AA
M="!Y;W4@=V]U;&0@;&EK92!T;R!A=F]I9"!A;'=A>7,@<&%R<VEN9RX-"B`J
M#0H@*B!4:&4@4$5!4E]!=71O;&]A9&5R(&-L87-S('!R;W9I9&5S(&%U=&]L
M;V%D:6YG(&%N9"!A9V=R96=A=&EO;BX-"B`J(%1H92!A=71O;&]A9&EN9R!L
M971S('EO=2!S970@=7`@:6X@=VAI8V@@8VQA<W-E<R!T:&4@<V5P87)A=&5D
M#0H@*B!M971H;V1S(&%R92!F;W5N9"X@($%G9W)E9V%T:6]N(&ES('1H92!T
M96-H;FEQ=64@=7-E9"!T;R!I;7!O<G0@;F5W#0H@*B!M971H;V1S+"!A;B!I
M;G-T86YC92!O9B!E86-H(&-L87-S('!R;W9I9&EN9R!S97!A<F%T960@;65T
M:&]D<R!I<PT*("H@<W1O<F5D(&%N9"!C86QL960@979E<GD@=&EM92!T:&4@
M86=G<F5G871E9"!M971H;V0@:7,@8V%L;&5D+@T*("H-"B`J($!C871E9V]R
M>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@4W1I
M9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR
M,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@
M0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+V-O<F4N<'!M+G!H<"-C;W)E
M+G!P;2YP96%R+6%U=&]L;V%D97(-"B`J($!S:6YC92`@("`@($9I;&4@879A
M:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B!`9&5P<F5C871E9"!&:6QE
M(&1E<')E8V%T960@:6X@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S(%!%
M05)?075T;VQO861E<B!E>'1E;F1S(%!%05(-"GL-"B`@("`O+R![>WL@<')O
M<&5R=&EE<PT*#0H@("`@+RHJ#0H@("`@("H@36%P(&]F(&UE=&AO9',@86YD
M(&-L87-S97,@=VAE<F4@=&AE>2!A<F4@9&5F:6YE9`T*("`@("`J#0H@("`@
M("H@0'9A<B!A<G)A>0T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P<FEV871E
M#0H@("`@("HO#0H@("`@=F%R("1?875T;VQO861?;6%P(#T@87)R87DH*3L-
M"@T*("`@("\J*@T*("`@("`J($UA<"!O9B!M971H;V1S(&%N9"!A9V=R96=A
M=&4@;V)J96-T<PT*("`@("`J#0H@("`@("H@0'9A<B!A<G)A>0T*("`@("`J
M#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?
M;65T:&]D7VUA<"`](&%R<F%Y*"D[#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@861D075T;VQO860H*0T*#0H@("`@+RHJ#0H@("`@("H@061D(&]N92!O
M<B!M;W)E(&%U=&]L;V%D(&5N=')I97,N#0H@("`@("H-"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1M971H;V0@("`@('=H:6-H(&UE=&AO9"!T;R!A=71O;&]A
M9`T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D8VQA<W-N86UE("`H
M;W!T:6]N86PI('=H:6-H(&-L87-S('1O(&9I;F0@=&AE(&UE=&AO9"!I;BX-
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@($EF('1H92`D;65T
M:&]D('!A<F%M971E<B!I<R!A;B!A<G)A>2P@=&AI<PT*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R(&UA>2!B92!O;6ET=&5D
M("AA;F0@=VEL;"!B92!I9VYO<F5D#0H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I9B!N;W0I+"!A;F0@=&AE("1M971H;V0@<&%R86UE=&5R
M('=I;&P@8F4-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@('1R
M96%T960@87,@86X@87-S;V-I871I=F4@87)R87D@=VET:"!M971H;V0-"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&YA;65S(&%S(&ME>7,@
M86YD(&-L87-S(&YA;65S(&%S('9A;'5E<RX-"B`@("`@*@T*("`@("`J($!R
M971U<FX@=F]I9`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!A9&1!=71O;&]A9"@D;65T:&]D+"`D8VQA
M<W-N86UE(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&EF("AI<U]A<G)A>2@D
M;65T:&]D*2D@>PT*("`@("`@("`@("`@87)R87E?=V%L:R@D;65T:&]D+"!C
M<F5A=&5?9G5N8W1I;VXH)R1A+"8D8B<L("<D8B`]('-T<G1O;&]W97(H)&(I
M.R<I*3L-"B`@("`@("`@("`@("1T:&ES+3Y?875T;VQO861?;6%P(#T@87)R
M87E?;65R9V4H)'1H:7,M/E]A=71O;&]A9%]M87`L("1M971H;V0I.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M/E]A=71O;&]A9%]M
M87!;<W1R=&]L;W=E<B@D;65T:&]D*5T@/2`D8VQA<W-N86UE.PT*("`@("`@
M("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(')E;6]V94%U
M=&]L;V%D*"D-"@T*("`@("\J*@T*("`@("`J(%)E;6]V92!A;B!A=71O;&]A
M9"!E;G1R>2X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)&UE=&AO
M9"`@=VAI8V@@;65T:&]D('1O(')E;6]V92!T:&4@875T;VQO860@96YT<GD@
M9F]R#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&)O;VP@5%)512!I9B!A;B!E
M;G1R>2!W87,@<F5M;W9E9"P@1D%,4T4@:68@;F]T#0H@("`@("H-"B`@("`@
M*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(')E;6]V
M94%U=&]L;V%D*"1M971H;V0I#0H@("`@>PT*("`@("`@("`D;65T:&]D(#T@
M<W1R=&]L;W=E<B@D;65T:&]D*3L-"B`@("`@("`@)&]K(#T@:7-S970H)'1H
M:7,M/E]A=71O;&]A9%]M87!;)&UE=&AO9%TI.PT*("`@("`@("!U;G-E="@D
M=&AI<RT^7V%U=&]L;V%D7VUA<%LD;65T:&]D72D[#0H@("`@("`@(')E='5R
M;B`D;VL[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&%D9$%G
M9W)E9V%T94]B:F5C="@I#0H-"B`@("`O*BH-"B`@("`@*B!!9&0@86X@86=G
M<F5G871E(&]B:F5C="!T;R!T:&ES(&]B:F5C="X@($EF('1H92!S<&5C:69I
M960@8VQA<W,-"B`@("`@*B!I<R!N;W0@9&5F:6YE9"P@;&]A9&EN9R!I="!W
M:6QL(&)E(&%T=&5M<'1E9"!F;VQL;W=I;F<@4$5!4B=S#0H@("`@("H@9FEL
M92!N86UI;F<@<V-H96UE+B`@06QL('1H92!M971H;V1S(&EN('1H92!C;&%S
M<R!W:6QL(&)E#0H@("`@("H@86=G<F5G871E9"P@97AC97!T('!R:79A=&4@
M;VYE<R`H;F%M92!S=&%R=&EN9R!W:71H(&%N#0H@("`@("H@=6YD97)S8V]R
M92D@86YD(&-O;G-T<G5C=&]R<RX-"B`@("`@*@T*("`@("`J($!P87)A;2!S
M=')I;F<@)&-L87-S;F%M92`@=VAA="!C;&%S<R!T;R!I;G-T86YT:6%T92!F
M;W(@=&AE(&]B:F5C="X-"B`@("`@*@T*("`@("`J($!R971U<FX@=F]I9`T*
M("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!A9&1!9V=R96=A=&5/8FIE8W0H)&-L87-S;F%M92D-"B`@("![
M#0H@("`@("`@("1C;&%S<VYA;64@/2!S=')T;VQO=V5R*"1C;&%S<VYA;64I
M.PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@D8VQA<W-N86UE*2D@>PT*
M("`@("`@("`@("`@)&EN8VQU9&5?9FEL92`]('!R96=?<F5P;&%C92@G+UM>
M82UZ,"TY72]I)RP@)U\G+"`D8VQA<W-N86UE*3L-"B`@("`@("`@("`@(&EN
M8VQU9&5?;VYC92`D:6YC;'5D95]F:6QE.PT*("`@("`@("!]#0H@("`@("`@
M("1O8FH@/28@;F5W("1C;&%S<VYA;64[#0H@("`@("`@("1M971H;V1S(#T@
M9V5T7V-L87-S7VUE=&AO9',H)&-L87-S;F%M92D[#0H@("`@("`@(&9O<F5A
M8V@@*"1M971H;V1S(&%S("1M971H;V0I('L-"B`@("`@("`@("`@("\O(&1O
M;B=T(&EM<&]R="!P<FEV:6%T92!M971H;V1S(&%N9"!C;VYS=')U8W1O<G,-
M"B`@("`@("`@("`@(&EF("@D;65T:&]D>S!]("$]("=?)R`F)B`D;65T:&]D
M("$]("1C;&%S<VYA;64I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VUE
M=&AO9%]M87!;)&UE=&AO9%T@/2`D;V)J.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(')E;6]V
M94%G9W)E9V%T94]B:F5C="@I#0H-"B`@("`O*BH-"B`@("`@*B!296UO=F4@
M86X@86=G<F5G871E(&]B:F5C="X-"B`@("`@*@T*("`@("`J($!P87)A;2!S
M=')I;F<@)&-L87-S;F%M92`@=&AE(&-L87-S(&]F('1H92!O8FIE8W0@=&\@
M<F5M;W9E#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&)O;VP@(%12544@:68@
M86X@;V)J96-T('=A<R!R96UO=F5D+"!&04Q312!I9B!N;W0-"B`@("`@*@T*
M("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M<F5M;W9E06=G<F5G871E3V)J96-T*"1C;&%S<VYA;64I#0H@("`@>PT*("`@
M("`@("`D;VL@/2!F86QS93L-"B`@("`@("`@)&-L87-S;F%M92`]('-T<G1O
M;&]W97(H)&-L87-S;F%M92D[#0H@("`@("`@(')E<V5T*"1T:&ES+3Y?;65T
M:&]D7VUA<"D[#0H@("`@("`@('=H:6QE("AL:7-T*"1M971H;V0L("1O8FHI
M(#T@96%C:"@D=&AI<RT^7VUE=&AO9%]M87`I*2![#0H@("`@("`@("`@("!I
M9B`H:7-?82@D;V)J+"`D8VQA<W-N86UE*2D@>PT*("`@("`@("`@("`@("`@
M('5N<V5T*"1T:&ES+3Y?;65T:&]D7VUA<%LD;65T:&]D72D[#0H@("`@("`@
M("`@("`@("`@)&]K(#T@=')U93L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@)&]K.PT*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!?7V-A;&PH*0T*#0H@("`@+RHJ#0H@("`@("H@3W9E<FQO
M861E9"!O8FIE8W0@8V%L;"!H86YD;&5R+"!C86QL960@96%C:"!T:6UE(&%N
M#0H@("`@("H@=6YD969I;F5D+V%G9W)E9V%T960@;65T:&]D(&ES(&EN=F]K
M960N("!4:&ES(&UE=&AO9"!R97!E871S#0H@("`@("H@=&AE(&-A;&P@:6X@
M=&AE(')I9VAT(&%G9W)E9V%T92!O8FIE8W0@86YD('!A<W-E<R!O;B!T:&4@
M<F5T=7)N#0H@("`@("H@=F%L=64N#0H@("`@("H-"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1M971H;V0@('=H:6-H(&UE=&AO9"!T:&%T('=A<R!C86QL960-
M"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)&%R9W,@("`@06X@87)R
M87D@;V8@=&AE('!A<F%M971E<G,@<&%S<V5D(&EN('1H90T*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@;W)I9VEN86P@8V%L;`T*("`@("`J#0H@
M("`@("H@0')E='5R;B!M:7AE9"`@5&AE(')E='5R;B!V86QU92!F<F]M('1H
M92!A9V=R96=A=&5D(&UE=&AO9"P@;W(@82!014%2#0H@("`@("H@("`@("`@
M("`@("`@("`@97)R;W(@:68@=&AE(&-A;&QE9"!M971H;V0@=V%S('5N:VYO
M=VXN#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7U]C86QL*"1M971H;V0L("1A
M<F=S+"`F)')E='9A;"D-"B`@("![#0H@("`@("`@("1M971H;V0@/2!S=')T
M;VQO=V5R*"1M971H;V0I.PT*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]M
M971H;V1?;6%P6R1M971H;V1=*2`F)B!I<W-E="@D=&AI<RT^7V%U=&]L;V%D
M7VUA<%LD;65T:&]D72DI('L-"B`@("`@("`@("`@("1T:&ES+3YA9&1!9V=R
M96=A=&5/8FIE8W0H)'1H:7,M/E]A=71O;&]A9%]M87!;)&UE=&AO9%TI.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VUE=&AO9%]M
M87!;)&UE=&AO9%TI*2![#0H@("`@("`@("`@("`D<F5T=F%L(#T@8V%L;%]U
M<V5R7V9U;F-?87)R87DH87)R87DH)'1H:7,M/E]M971H;V1?;6%P6R1M971H
M;V1=+"`D;65T:&]D*2P@)&%R9W,I.PT*("`@("`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-
M"@T*("`@("\O('U]?0T*?0T*#0IO=F5R;&]A9"@B4$5!4E]!=71O;&]A9&5R
M(BD[#0H-"C\^#0H`````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O0G5I;&1E<BYP:'``
M````````````````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,U,C<W`#$P
M-3$U-#,S-S0Q`#`R,30T-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`T*+RHJ#0H@*B!014%27T)U:6QD97(@9F]R
M(&)U:6QD:6YG(%!(4"!E>'1E;G-I;VYS("A014-,('!A8VMA9V5S*0T*("H-
M"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H
M92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A
M;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P
M;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C
M871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H
M;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@
M("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG
M:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS
M92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!"=6EL9&5R+G!H<"QV
M(#$N,C<@,C`P-B\P,2\P-B`P-#HT-SHS-B!C96QL;V<@17AP("0-"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@
M*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#`N
M,0T*("HO#0H-"B\J*@T*("H@3F5E9&5D(&9O<B!E>'1E;F1I;F<@4$5!4E]"
M=6EL9&5R#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4B]#;VUM;VXN<&AP)SL-
M"G)E<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL92YP:'`G.PT*+RHJ#0H@
M*B!#;&%S<R!T;R!H86YD;&4@8G5I;&1I;F<@*&-O;7!I;&EN9RD@97AT96YS
M:6]N<RX-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@
M("!014%2#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN
M970^#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN
M970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E
M.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S
M:6YC92!02%`@-"XP+C(-"B`J($!S964@("`@("`@(&AT='`Z+R]P96%R+G!H
M<"YN970O;6%N=6%L+V5N+V-O<F4N<'!M+G!E87(M8G5I;&1E<BYP:'`-"B`J
M+PT*8VQA<W,@4$5!4E]"=6EL9&5R(&5X=&5N9',@4$5!4E]#;VUM;VX-"GL-
M"B`@("`O+R![>WL@<')O<&5R=&EE<PT*#0H@("`@=F%R("1P:'!?87!I7W9E
M<G-I;VX@/2`P.PT*("`@('9A<B`D>F5N9%]M;V1U;&5?87!I7VYO(#T@,#L-
M"B`@("!V87(@)'IE;F1?97AT96YS:6]N7V%P:5]N;R`](#`[#0H-"B`@("!V
M87(@)&5X=&5N<VEO;G-?8G5I;'0@/2!A<G)A>2@I.PT*#0H@("`@=F%R("1C
M=7)R96YT7V-A;&QB86-K(#T@;G5L;#L-"@T*("`@("\O('5S960@9F]R(&US
M9&5V(&)U:6QD<PT*("`@('9A<B`D7VQA<W1L:6YE(#T@;G5L;#L-"B`@("!V
M87(@)%]F:7)S=&QI;F4@/2!N=6QL.PT*("`@("\O('U]?0T*("`@("\O('M[
M>R!C;VYS=')U8W1O<@T*#0H@("`@+RHJ#0H@("`@("H@4$5!4E]"=6EL9&5R
M(&-O;G-T<G5C=&]R+@T*("`@("`J#0H@("`@("H@0'!A<F%M(&]B:F5C="`D
M=6D@=7-E<B!I;G1E<F9A8V4@;V)J96-T("AI;G-T86YC92!O9B!014%27T9R
M;VYT96YD7RHI#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N(%!%05)?0G5I;&1E<B@F)'5I*0T*("`@('L-
M"B`@("`@("`@<&%R96YT.CI014%27T-O;6UO;B@I.PT*("`@("`@("`D=&AI
M<RT^<V5T1G)O;G1E;F1/8FIE8W0H)'5I*3L-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"@T*("`@("\O('M[>R!?8G5I;&1?=VEN,S(H*0T*#0H@("`@+RHJ#0H@
M("`@("H@0G5I;&0@86X@97AT96YS:6]N(&9R;VT@<V]U<F-E(&]N('=I;F1O
M=W,N#0H@("`@("H@<F5Q=6ER97,@;7-D978-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!?8G5I;&1?=VEN,S(H)&1E<V-F:6QE+"`D8V%L;&)A8VL@/2!N=6QL
M*0T*("`@('L-"B`@("`@("`@:68@*&ES7V]B:F5C="@D9&5S8V9I;&4I*2![
M#0H@("`@("`@("`@("`D<&MG(#T@)&1E<V-F:6QE.PT*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@)'!F(#T@)FYE=R!014%27U!A8VMA9V5&:6QE
M*"1T:&ES+3YC;VYF:6<L("1T:&ES+3YD96)U9RD[#0H@("`@("`@("`@("`D
M<&MG(#T@)B1P9BT^9G)O;5!A8VMA9V5&:6QE*"1D97-C9FEL92P@4$5!4E]6
M04Q)1$%415].3U)-04PI.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)'!K9RDI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'!K9SL-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D9&ER(#T@9&ER;F%M
M92@D<&MG+3YG971!<F-H:79E1FEL92@I*3L-"B`@("`@("`@)&]L9%]C=V0@
M/2!G971C=V0H*3L-"@T*("`@("`@("!I9B`H(4!C:&1I<B@D9&ER*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")C;W5L9"!N
M;W0@8VAD:7(@=&\@)&1I<B(I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES
M+3YL;V<H,BP@(F)U:6QD:6YG(&EN("1D:7(B*3L-"@T*("`@("`@("`D9'-P
M(#T@)'!K9RT^9V5T4&%C:V%G92@I+B<N9'-P)SL-"B`@("`@("`@:68@*"%`
M:7-?9FEL92@B)&1I<B\D9'-P(BDI('L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@B5&AE($134"`D9'-P(&1O97,@;F]T(&5X:7-T
M+B(I.PT*("`@("`@("!]#0H@("`@("`@("\O(%A86"!43T1/.B!M86ME(')E
M;&5A<V4@8G5I;&0@='EP92!C;VYF:6=U<F%B;&4-"B`@("`@("`@)&-O;6UA
M;F0@/2`G;7-D978@)RXD9'-P+B<@+TU!2T4@(B<N)&EN9F];)W!A8VMA9V4G
M72X@)R`M(%)E;&5A<V4B)SL-"@T*("`@("`@("`D=&AI<RT^8W5R<F5N=%]C
M86QL8F%C:R`]("1C86QL8F%C:SL-"B`@("`@("`@)&5R<B`]("1T:&ES+3Y?
M<G5N0V]M;6%N9"@D8V]M;6%N9"P@87)R87DH)B1T:&ES+"`G;7-D979#86QL
M8F%C:R<I*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<BDI('L-
M"B`@("`@("`@("`@(')E='5R;B`D97)R.PT*("`@("`@("!]#0H-"B`@("`@
M("`@+R\@9FEG=7)E(&]U="!T:&4@8G5I;&0@<&QA=&9O<FT@86YD('1Y<&4-
M"B`@("`@("`@)'!L871F;W)M(#T@)U=I;C,R)SL-"B`@("`@("`@)&)U:6QD
M='EP92`]("=296QE87-E)SL-"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R\N
M*C\G+B1P:V<M/F=E=%!A8VMA9V4H*2XG7',M7',H7'<K*5QS*"XJ/RDM*R]I
M)RPD=&AI<RT^7V9I<G-T;&EN92PD;6%T8VAE<RDI('L-"B`@("`@("`@("`@
M("1P;&%T9F]R;2`]("1M871C:&5S6S%=.PT*("`@("`@("`@("`@)&)U:6QD
M='EP92`]("1M871C:&5S6S)=.PT*("`@("`@("!]#0H-"B`@("`@("`@:68@
M*'!R96=?;6%T8V@H)R\H+BHI/UQS+5QS*%QD*RDN*C\H7&0K*2\G+"1T:&ES
M+3Y?;&%S=&QI;F4L)&UA=&-H97,I*2![#0H@("`@("`@("`@("!I9B`H)&UA
M=&-H97-;,ETI('L-"B`@("`@("`@("`@("`@("`O+R!T:&5R92!W97)E(&5R
M<F]R<R!I;B!T:&4@8G5I;&0-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H(E1H97)E('=E<F4@97)R;W)S(&1U<FEN9R!C;VUP
M:6QA=&EO;BXB*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1O=70@
M/2`D;6%T8VAE<ULQ73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B1&ED(&YO="!U;F1E<G-T86YD
M('1H92!C;VUP;&5T:6]N('-T871U<R!R971U<FYE9"!F<F]M(&US9&5V+F5X
M92XB*3L-"B`@("`@("`@?0T*#0H@("`@("`@("\O(&US9&5V(&1O97-N)W0@
M=&5L;"!U<R!T:&4@;W5T<'5T(&1I<F5C=&]R>2`Z+PT*("`@("`@("`O+R!O
M<&5N('1H92!D<W`L(&9I;F0@+V]U="!A;F0@=7-E('1H870@9&ER96-T;W)Y
M#0H@("`@("`@("1D<W!T97AT(#T@:F]I;BAF:6QE*"1D<W`I+"<G*3L-"@T*
M("`@("`@("`O+R!T:&ES(')E9V5X(&1E<&5N9',@;VX@=&AE(&)U:6QD('!L
M871F;W)M(&%N9"!T>7!E(&AA=FEN9R!B965N#0H@("`@("`@("\O(&-O<G)E
M8W1L>2!I9&5N=&EF:65D(&%B;W9E+@T*("`@("`@("`D<F5G97@@/2<O+BH_
M(4E&7',K(EPD7"A#1D=<*2)<<RL]/5QS*R@B)RX-"B`@("`@("`@("`@("`@
M("`@("`@)'!K9RT^9V5T4&%C:V%G92@I+B=<<RU<<R<N#0H@("`@("`@("`@
M("`@("`@("`@("1P;&%T9F]R;2XG7',G+@T*("`@("`@("`@("`@("`@("`@
M("`D8G5I;&1T>7!E+B<B*2XJ/R<N#0H@("`@("`@("`@("`@("`@("`@("=<
M+V]U=#HB*"XJ/RDB+VES)SL-"@T*("`@("`@("!I9B`H)&1S<'1E>'0@)B8@
M<')E9U]M871C:"@D<F5G97@L)&1S<'1E>'0L)&UA=&-H97,I*2![#0H@("`@
M("`@("`@("`O+R!W:&%T('=E(&=E="!B86-K(&ES(&$@<F5L871I=F4@<&%T
M:"!T;R!T:&4@;W5T<'5T(&9I;&4@:71S96QF+@T*("`@("`@("`@("`@)&]U
M=&9I;&4@/2!R96%L<&%T:"@D;6%T8VAE<ULR72D[#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D-O
M=6QD(&YO="!R971R:65V92!O=71P=70@:6YF;W)M871I;VX@9G)O;2`D9'-P
M+B(I.PT*("`@("`@("!]#0H@("`@("`@(&EF("A`8V]P>2@D;W5T9FEL92P@
M(B1D:7(O)&]U="(I*2![#0H@("`@("`@("`@("`D;W5T9FEL92`]("(D9&ER
M+R1O=70B.PT*("`@("`@("!]#0H-"B`@("`@("`@)&)U:6QT7V9I;&5S6UT@
M/2!A<G)A>2@-"B`@("`@("`@("`@("=F:6QE)R`]/B`B)&]U=&9I;&4B+`T*
M("`@("`@("`@("`@)W!H<%]A<&DG(#T^("1T:&ES+3YP:'!?87!I7W9E<G-I
M;VXL#0H@("`@("`@("`@("`G>F5N9%]M;V1?87!I)R`]/B`D=&AI<RT^>F5N
M9%]M;V1U;&5?87!I7VYO+`T*("`@("`@("`@("`@)WIE;F1?97AT7V%P:2<@
M/3X@)'1H:7,M/GIE;F1?97AT96YS:6]N7V%P:5]N;RP-"B`@("`@("`@("`@
M("D[#0H-"B`@("`@("`@<F5T=7)N("1B=6EL=%]F:6QE<SL-"B`@("!]#0H@
M("`@+R\@?7U]#0H-"B`@("`O+R![>WL@;7-D979#86QL8F%C:R@I#0H@("`@
M9G5N8W1I;VX@;7-D979#86QL8F%C:R@D=VAA="P@)&1A=&$I#0H@("`@>PT*
M("`@("`@("!I9B`H(21T:&ES+3Y?9FER<W1L:6YE*0T*("`@("`@("`@("`@
M)'1H:7,M/E]F:7)S=&QI;F4@/2`D9&%T83L-"B`@("`@("`@)'1H:7,M/E]L
M87-T;&EN92`]("1D871A.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O
M('M[>R!?:&%R=F5N=$EN<W1$:7(-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@
M<W1R:6YG#0H@("`@("H@0'!A<F%M('-T<FEN9PT*("`@("`J($!P87)A;2!A
M<G)A>0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(%]H87)V97-T26YS=$1I<B@D9&5S=%]P<F5F:7@L("1D:7)N86UE
M+"`F)&)U:6QT7V9I;&5S*0T*("`@('L-"B`@("`@("`@)&0@/2!O<&5N9&ER
M*"1D:7)N86UE*3L-"B`@("`@("`@:68@*"$D9"D-"B`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"@T*("`@("`@("`D<F5T(#T@=')U93L-"B`@("`@("`@
M=VAI;&4@*"@D96YT(#T@<F5A9&1I<B@D9"DI("$]/2!F86QS92D@>PT*("`@
M("`@("`@("`@:68@*"1E;G1[,'T@/3T@)RXG*0T*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*#0H@("`@("`@("`@("`D9G5L;"`]("1D:7)N86UE("X@
M1$E214-43U)97U-%4$%2051/4B`N("1E;G0[#0H@("`@("`@("`@("!I9B`H
M:7-?9&ER*"1F=6QL*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M
M/E]H87)V97-T26YS=$1I<B@-"B`@("`@("`@("`@("`@("`@("`@("`@("1D
M97-T7W!R969I>"`N($1)4D5#5$]265]315!!4D%43U(@+B`D96YT+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@)&9U;&PL("1B=6EL=%]F:6QE<RDI('L-
M"B`@("`@("`@("`@("`@("`@("`@)')E="`](&9A;'-E.PT*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1D97-T(#T@)&1E<W1?
M<')E9FEX("X@1$E214-43U)97U-%4$%2051/4B`N("1E;G0[#0H@("`@("`@
M("`@("`@("`@)&)U:6QT7V9I;&5S6UT@/2!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`@("`@("`@("=F:6QE)R`]/B`D9G5L;"P-"B`@("`@("`@("`@("`@
M("`@("`@("`@("=D97-T)R`]/B`D9&5S="P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("=P:'!?87!I)R`]/B`D=&AI<RT^<&AP7V%P:5]V97)S:6]N+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@)WIE;F1?;6]D7V%P:2<@/3X@)'1H
M:7,M/GIE;F1?;6]D=6QE7V%P:5]N;RP-"B`@("`@("`@("`@("`@("`@("`@
M("`@("=Z96YD7V5X=%]A<&DG(#T^("1T:&ES+3YZ96YD7V5X=&5N<VEO;E]A
M<&E?;F\L#0H@("`@("`@("`@("`@("`@("`@("`@("`I.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(&-L;W-E9&ER*"1D*3L-"B`@("`@
M("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@("`O
M+R![>WL@8G5I;&0H*0T*#0H@("`@+RHJ#0H@("`@("H@0G5I;&0@86X@97AT
M96YS:6]N(&9R;VT@<V]U<F-E+B`@4G5N<R`B<&AP:7IE(B!I;B!T:&4@<V]U
M<F-E#0H@("`@("H@9&ER96-T;W)Y+"!B=70@8V]M<&EL97,@:6X@82!T96UP
M;W)A<GD@9&ER96-T;W)Y#0H@("`@("H@*"]V87(O=&UP+W!E87(M8G5I;&0M
M55-%4B]004-+04=%+59%4E-)3TXI+@T*("`@("`J#0H@("`@("H@0'!A<F%M
M('-T<FEN9WQ014%27U!A8VMA9V5&:6QE7W8J("1D97-C9FEL92!P871H('1O
M(%A-3"!P86-K86=E(&1E<V-R:7!T:6]N(&9I;&4L(&]R#0H@("`@("H@("`@
M("`@("`@("`@("!A(%!%05)?4&%C:V%G949I;&4@;V)J96-T#0H@("`@("H-
M"B`@("`@*B!`<&%R86T@;6EX960@)&-A;&QB86-K(&-A;&QB86-K(&9U;F-T
M:6]N('5S960@=&\@<F5P;W)T(&]U='!U="P-"B`@("`@*B!S964@4$5!4E]"
M=6EL9&5R.CI?<G5N0V]M;6%N9"!F;W(@9&5T86EL<PT*("`@("`J#0H@("`@
M("H@0')E='5R;B!A<G)A>2!A;B!A<G)A>2!O9B!A<W-O8VEA=&EV92!A<G)A
M>7,@=VET:"!B=6EL="!F:6QE<RP-"B`@("`@*B!F;W)M870Z#0H@("`@("H@
M87)R87DH(&%R<F%Y*"`G9FEL92<@/3X@)R]P871H+W1O+V5X="YS;R<L#0H@
M("`@("H@("`@("`@("`@("`@("`G<&AP7V%P:2<@/3X@65E964U-1$0L#0H@
M("`@("H@("`@("`@("`@("`@("`G>F5N9%]M;V1?87!I)R`]/B!965E934U$
M1"P-"B`@("`@*B`@("`@("`@("`@("`@("=Z96YD7V5X=%]A<&DG(#T^(%E9
M65E-341$("DL#0H@("`@("H@("`@("`@("XN+B`I#0H@("`@("H-"B`@("`@
M*B!`86-C97-S('!U8FQI8PT*("`@("`J#0H@("`@("H@0'-E92!014%27T)U
M:6QD97(Z.E]R=6Y#;VUM86YD#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8G5I
M;&0H)&1E<V-F:6QE+"`D8V%L;&)A8VL@/2!N=6QL*0T*("`@('L-"B`@("`@
M("`@:68@*%!%05)?3U,@/3T@(E=I;F1O=W,B*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]B=6EL9%]W:6XS,B@D9&5S8V9I;&4L)&-A;&QB86-K
M*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H4$5!4E]/4R`A/2`G56YI>"<I
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8G5I
M;&1I;F<@97AT96YS:6]N<R!N;W0@<W5P<&]R=&5D(&]N('1H:7,@<&QA=&9O
M<FTB*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-?;V)J96-T*"1D97-C
M9FEL92DI('L-"B`@("`@("`@("`@("1P:V<@/2`D9&5S8V9I;&4[#0H@("`@
M("`@("`@("`D9&5S8V9I;&4@/2`D<&MG+3YG971086-K86=E1FEL92@I.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'!F(#T@)FYE=R!014%2
M7U!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<I.PT*("`@("`@("`@("`@)'!K
M9R`]("8D<&8M/F9R;VU086-K86=E1FEL92@D9&5S8V9I;&4L(%!%05)?5D%,
M241!5$5?3D]234%,*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1P:V<I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1P:V<[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&1I<B`](&1I<FYA;64H
M)&1E<V-F:6QE*3L-"B`@("`@("`@)&]L9%]C=V0@/2!G971C=V0H*3L-"B`@
M("`@("`@:68@*"%`8VAD:7(H)&1I<BDI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B8V]U;&0@;F]T(&-H9&ER('1O("1D:7(B
M*3L-"B`@("`@("`@?0T*("`@("`@("`D=F1I<B`]("1P:V<M/F=E=%!A8VMA
M9V4H*2`N("<M)R`N("1P:V<M/F=E=%9E<G-I;VXH*3L-"B`@("`@("`@:68@
M*&ES7V1I<B@D=F1I<BDI('L-"B`@("`@("`@("`@(&-H9&ER*"1V9&ER*3L-
M"B`@("`@("`@?0T*("`@("`@("`D9&ER(#T@9V5T8W=D*"D[#0H@("`@("`@
M("1T:&ES+3YL;V<H,BP@(F)U:6QD:6YG(&EN("1D:7(B*3L-"B`@("`@("`@
M)'1H:7,M/F-U<G)E;G1?8V%L;&)A8VL@/2`D8V%L;&)A8VL[#0H@("`@("`@
M('!U=&5N=B@G4$%42#TG("X@)'1H:7,M/F-O;F9I9RT^9V5T*"=B:6Y?9&ER
M)RD@+B`G.B<@+B!G971E;G8H)U!!5$@G*2D[#0H@("`@("`@("1E<G(@/2`D
M=&AI<RT^7W)U;D-O;6UA;F0H(G!H<&EZ92(L(&%R<F%Y*"8D=&AI<RP@)W!H
M<&EZ94-A;&QB86-K)RDI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M97)R*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E<G([#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"$D97)R*2![#0H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H(F!P:'!I>F4G(&9A:6QE9"(I.PT*("`@("`@("!]
M#0H-"B`@("`@("`@+R\@>WM[('-T87)T(&]F(&EN=&5R86-T:79E('!A<G0-
M"B`@("`@("`@)&-O;F9I9W5R95]C;VUM86YD(#T@(B1D:7(O8V]N9FEG=7)E
M(CL-"B`@("`@("`@)&-O;F9I9W5R95]O<'1I;VYS(#T@)'!K9RT^9V5T0V]N
M9FEG=7)E3W!T:6]N<R@I.PT*("`@("`@("!I9B`H)&-O;F9I9W5R95]O<'1I
M;VYS*2![#0H@("`@("`@("`@("!F;W)E86-H("@D8V]N9FEG=7)E7V]P=&EO
M;G,@87,@)&\I('L-"B`@("`@("`@("`@("`@("!L:7-T*"1R*2`]("1T:&ES
M+3YU:2T^=7-E<D1I86QO9R@G8G5I;&0G+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1O6R=P<F]M
M<'0G72DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)W1E>'0G*2P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2A`)&];)V1E
M9F%U;'0G72DI.PT*("`@("`@("`@("`@("`@(&EF("AS=6)S='(H)&];)VYA
M;64G72P@,"P@-2D@/3T@)W=I=&@M)R`F)@T*("`@("`@("`@("`@("`@("`@
M("`H)'(@/3T@)WEE<R<@?'P@)'(@/3T@)V%U=&]D971E8W0G*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D8V]N9FEG=7)E7V-O;6UA;F0@+CT@(B`M+21O
M6VYA;65=(CL-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`D8V]N9FEG=7)E7V-O;6UA;F0@+CT@(B`M+21O6VYA;65=
M/2(N=')I;2@D<BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@("\O('U]?2!E;F0@;V8@:6YT97)A8W1I
M=F4@<&%R=`T*#0H@("`@("`@("\O($9)6$U%(&UA:V4@8V]N9FEG=7)A8FQE
M#0H@("`@("`@(&EF*"$D=7-E<CUG971E;G8H)U5315(G*2E[#0H@("`@("`@
M("`@("`D=7-E<CTG9&5F875L='5S97(G.PT*("`@("`@("!]#0H@("`@("`@
M("1B=6EL9%]B87-E9&ER(#T@(B]V87(O=&UP+W!E87(M8G5I;&0M)'5S97(B
M.PT*("`@("`@("`D8G5I;&1?9&ER(#T@(B1B=6EL9%]B87-E9&ER+R1V9&ER
M(CL-"B`@("`@("`@)&EN<W1?9&ER(#T@(B1B=6EL9%]B87-E9&ER+VEN<W1A
M;&PM)'9D:7(B.PT*("`@("`@("`D=&AI<RT^;&]G*#$L(")B=6EL9&EN9R!I
M;B`D8G5I;&1?9&ER(BD[#0H@("`@("`@(&EF("AI<U]D:7(H)&)U:6QD7V1I
M<BDI('L-"B`@("`@("`@("`@(%-Y<W1E;3HZ<FTH87)R87DH)RUR9B<L("1B
M=6EL9%]D:7(I*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(5-Y<W1E;3HZ
M;6M$:7(H87)R87DH)RUP)RP@)&)U:6QD7V1I<BDI*2![#0H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F-O=6QD(&YO="!C<F5A=&4@
M8G5I;&0@9&ER.B`D8G5I;&1?9&ER(BD[#0H@("`@("`@('T-"B`@("`@("`@
M)'1H:7,M/F%D9%1E;7!&:6QE*"1B=6EL9%]D:7(I.PT*("`@("`@("!I9B`H
M(5-Y<W1E;3HZ;6M$:7(H87)R87DH)RUP)RP@)&EN<W1?9&ER*2DI('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8V]U;&0@;F]T
M(&-R96%T92!T96UP;W)A<GD@:6YS=&%L;"!D:7(Z("1I;G-T7V1I<B(I.PT*
M("`@("`@("!]#0H@("`@("`@("1T:&ES+3YA9&1496UP1FEL92@D:6YS=%]D
M:7(I.PT*#0H@("`@("`@(&EF("AG971E;G8H)TU!2T4G*2D@>PT*("`@("`@
M("`@("`@)&UA:V5?8V]M;6%N9"`](&=E=&5N=B@G34%+12<I.PT*("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@)&UA:V5?8V]M;6%N9"`]("=M86ME
M)SL-"B`@("`@("`@?0T*("`@("`@("`D=&]?<G5N(#T@87)R87DH#0H@("`@
M("`@("`@("`D8V]N9FEG=7)E7V-O;6UA;F0L#0H@("`@("`@("`@("`D;6%K
M95]C;VUM86YD+`T*("`@("`@("`@("`@(B1M86ME7V-O;6UA;F0@24Y35$%,
M3%]23T]4/5PB)&EN<W1?9&ER7"(@:6YS=&%L;"(L#0H@("`@("`@("`@("`B
M9FEN9"!<(B1I;G-T7V1I<EPB("UL<R(-"B`@("`@("`@("`@("D[#0H@("`@
M("`@(&EF("@A0&-H9&ER*"1B=6EL9%]D:7(I*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F-O=6QD(&YO="!C:&1I<B!T;R`D
M8G5I;&1?9&ER(BD[#0H@("`@("`@('T-"B`@("`@("`@<'5T96YV*"=02%!?
M4$5!4E]615)324]./3$N-"XY)RD[#0H@("`@("`@(&9O<F5A8V@@*"1T;U]R
M=6X@87,@)&-M9"D@>PT*("`@("`@("`@("`@)&5R<B`]("1T:&ES+3Y?<G5N
M0V]M;6%N9"@D8VUD+"`D8V%L;&)A8VLI.PT*("`@("`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)&5R<BDI('L-"B`@("`@("`@("`@("`@("!C:&1I<B@D
M;VQD7V-W9"D[#0H@("`@("`@("`@("`@("`@<F5T=7)N("1E<G([#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(21E<G(I('L-"B`@("`@("`@
M("`@("`@("!C:&1I<B@D;VQD7V-W9"D[#0H@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*")@)&-M9"<@9F%I;&5D(BD[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"$H)&1P(#T@;W!E
M;F1I<B@B;6]D=6QE<R(I*2D@>PT*("`@("`@("`@("`@8VAD:7(H)&]L9%]C
M=V0I.PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")N
M;R!@;6]D=6QE<R<@9&ER96-T;W)Y(&9O=6YD(BD[#0H@("`@("`@('T-"B`@
M("`@("`@)&)U:6QT7V9I;&5S(#T@87)R87DH*3L-"B`@("`@("`@)'!R969I
M>"`](&5X96,H(G!H<"UC;VYF:6<@+2UP<F5F:7@B*3L-"B`@("`@("`@)'1H
M:7,M/E]H87)V97-T26YS=$1I<B@D<')E9FEX+"`D:6YS=%]D:7(@+B!$25)%
M0U1/4EE?4T5005)!5$]2("X@)'!R969I>"P@)&)U:6QT7V9I;&5S*3L-"B`@
M("`@("`@8VAD:7(H)&]L9%]C=V0I.PT*("`@("`@("!R971U<FX@)&)U:6QT
M7V9I;&5S.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!P:'!I
M>F5#86QL8F%C:R@I#0H-"B`@("`O*BH-"B`@("`@*B!-97-S86=E(&-A;&QB
M86-K(&9U;F-T:6]N('5S960@=VAE;B!R=6YN:6YG('1H92`B<&AP:7IE(@T*
M("`@("`J('!R;V=R86TN("!%>'1R86-T<R!T:&4@05!)(&YU;6)E<G,@=7-E
M9"X@($EG;F]R97,@;W1H97(@;65S<V%G90T*("`@("`J('1Y<&5S('1H86X@
M(F-M9&]U='!U="(N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1W
M:&%T('1H92!T>7!E(&]F(&UE<W-A9V4-"B`@("`@*B!`<&%R86T@;6EX960@
M)&1A=&$@=&AE(&UE<W-A9V4-"B`@("`@*@T*("`@("`J($!R971U<FX@=F]I
M9`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!P:'!I>F5#86QL8F%C:R@D=VAA="P@)&1A=&$I#0H@("`@
M>PT*("`@("`@("!I9B`H)'=H870@(3T@)V-M9&]U='!U="<I('L-"B`@("`@
M("`@("`@(')E='5R;CL-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^;&]G
M*#$L(')T<FEM*"1D871A*2D[#0H@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O
M66]U('-H;W5L9"!U<&1A=&4@>6]U<B`N86-L;V-A;"YM-"\G+"`D9&%T82DI
M('L-"B`@("`@("`@("`@(')E='5R;CL-"B`@("`@("`@?0T*("`@("`@("`D
M;6%T8VAE<R`](&%R<F%Y*"D[#0H@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O
M7EQS*RA<4UM>.ETK*3I<<RLH7&1[.'TI+R<L("1D871A+"`D;6%T8VAE<RDI
M('L-"B`@("`@("`@("`@("1M96UB97(@/2!P<F5G7W)E<&QA8V4H)R];7F$M
M>ETO)RP@)U\G+"!S=')T;VQO=V5R*"1M871C:&5S6S%=*2D[#0H@("`@("`@
M("`@("`D87!I;F\@/2`H:6YT*21M871C:&5S6S)=.PT*("`@("`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3XD;65M8F5R*2D@>PT*("`@("`@("`@("`@("`@
M("1T:&ES+3XD;65M8F5R(#T@)&%P:6YO.PT*("`@("`@("`@("`@("`@("\O
M)&US9R`]('-P<FEN=&8H(B4M,C)S(#H@)60B+"`D;6%T8VAE<ULQ72P@)&%P
M:6YO*3L-"B`@("`@("`@("`@("`@("`O+R1T:&ES+3YL;V<H,2P@)&US9RD[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@7W)U;D-O;6UA;F0H*0T*#0H@("`@+RHJ#0H@("`@
M("H@4G5N(&%N(&5X=&5R;F%L(&-O;6UA;F0L('5S:6YG(&$@;65S<V%G92!C
M86QL8F%C:R!T;R!R97!O<G0-"B`@("`@*B!O=71P=70N("!4:&4@8V]M;6%N
M9"!W:6QL(&)E(')U;B!T:')O=6=H('!O<&5N(&%N9"!O=71P=70@:7,-"B`@
M("`@*B!R97!O<G1E9"!F;W(@979E<GD@;&EN92!W:71H(&$@(F-M9&]U='!U
M="(@;65S<V%G92!W:71H('1H90T*("`@("`J(&QI;F4@<W1R:6YG+"!I;F-L
M=61I;F<@;F5W;&EN97,L(&%S('!A>6QO860N#0H@("`@("H-"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1C;VUM86YD('1H92!C;VUM86YD('1O(')U;@T*("`@
M("`J#0H@("`@("H@0'!A<F%M(&UI>&5D("1C86QL8F%C:R`H;W!T:6]N86PI
M(&9U;F-T:6]N('1O('5S92!A<R!M97-S86=E#0H@("`@("H@8V%L;&)A8VL-
M"B`@("`@*@T*("`@("`J($!R971U<FX@8F]O;"!W:&5T:&5R('1H92!C;VUM
M86YD('=A<R!S=6-C97-S9G5L("AE>&ET(&-O9&4@,`T*("`@("`J(&UE86YS
M('-U8V-E<W,L(&%N>2!O=&AE<B!M96%N<R!F86EL=7)E*0T*("`@("`J#0H@
M("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M7W)U;D-O;6UA;F0H)&-O;6UA;F0L("1C86QL8F%C:R`](&YU;&PI#0H@("`@
M>PT*("`@("`@("`D=&AI<RT^;&]G*#$L(")R=6YN:6YG.B`D8V]M;6%N9"(I
M.PT*("`@("`@("`D<'`@/2!`<&]P96XH(B1C;VUM86YD(#(^)C$B+"`B<B(I
M.PT*("`@("`@("!I9B`H(21P<"D@>PT*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*")F86EL960@=&\@<G5N(&`D8V]M;6%N9"<B*3L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)&-A;&QB86-K("8F("1C86QL8F%C
M:ULP72T^9&5B=6<@/3T@,2D@>PT*("`@("`@("`@("`@)&]L9&1B9R`]("1C
M86QL8F%C:ULP72T^9&5B=6<[#0H@("`@("`@("`@("`D8V%L;&)A8VM;,%TM
M/F1E8G5G(#T@,CL-"B`@("`@("`@?0T*#0H@("`@("`@('=H:6QE("@D;&EN
M92`](&9G971S*"1P<"P@,3`R-"DI('L-"B`@("`@("`@("`@(&EF("@D8V%L
M;&)A8VLI('L-"B`@("`@("`@("`@("`@("!C86QL7W5S97)?9G5N8R@D8V%L
M;&)A8VLL("=C;61O=71P=70G+"`D;&EN92D[#0H@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,BP@<G1R:6TH)&QI
M;F4I*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M)&-A;&QB86-K("8F(&ES<V5T*"1O;&1D8F<I*2![#0H@("`@("`@("`@("`D
M8V%L;&)A8VM;,%TM/F1E8G5G(#T@)&]L9&1B9SL-"B`@("`@("`@?0T*("`@
M("`@("`D97AI=&-O9&4@/2!`<&-L;W-E*"1P<"D[#0H@("`@("`@(')E='5R
M;B`H)&5X:71C;V1E(#T](#`I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R!L;V<H*0T*#0H@("`@9G5N8W1I;VX@;&]G*"1L979E;"P@)&US
M9RD-"B`@("![#0H@("`@("`@(&EF("@D=&AI<RT^8W5R<F5N=%]C86QL8F%C
M:RD@>PT*("`@("`@("`@("`@:68@*"1T:&ES+3YD96)U9R`^/2`D;&5V96PI
M('L-"B`@("`@("`@("`@("`@("!C86QL7W5S97)?9G5N8R@D=&AI<RT^8W5R
M<F5N=%]C86QL8F%C:RP@)V]U='!U="<L("1M<V<I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@<F5T=7)N.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!014%27T-O;6UO;CHZ;&]G*"1L979E;"P@)&US9RD[#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0I]#0H-"C\^#0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O4$5!4B]#:&%N;F5L1FEL92\`````````````````
M````````````````````````````````````````````````````,#`P,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-#$`,#(Q
M-3`Q`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T-H86YN96Q&
M:6QE+U!A<G-E<BYP:'``````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#(S
M,``Q,#4Q-30S,S<T,0`P,C,T-#4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`-"B\J*@T*("H@4$5!4E]#:&%N;F5L
M1FEL95]087)S97(@9F]R('!A<G-I;F<@8VAA;FYE;"YX;6P-"B`J#0H@*B!0
M2%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U
M<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0
M(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R
M92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E
M#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N
M(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O
M<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@
M("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT
M("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@
M,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@4&%R<V5R+G!H<"QV(#$N
M-"`R,#`V+S`Q+S`V(#`T.C0W.C,V(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S
M:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A
M,0T*("HO#0H-"B\J*@T*("H@8F%S92!X;6P@<&%R<V5R(&-L87-S#0H@*B\-
M"G)E<75I<F5?;VYC92`G4$5!4B]834Q087)S97(N<&AP)SL-"G)E<75I<F5?
M;VYC92`G4$5!4B]#:&%N;F5L1FEL92YP:'`G.PT*+RHJ#0H@*B!087)S97(@
M9F]R(&-H86YN96PN>&UL#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C
M:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L
M;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(
M4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@
M("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V
M86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!
M4E]#:&%N;F5L1FEL95]087)S97(@97AT96YD<R!014%27UA-3%!A<G-E<@T*
M>PT*("`@('9A<B`D7V-O;F9I9SL-"B`@("!V87(@)%]L;V=G97([#0H@("`@
M=F%R("1?<F5G:7-T<GD[#0H-"B`@("!F=6YC=&EO;B!S971#;VYF:6<H)B1C
M*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]C;VYF:6<@/2`F)&,[#0H@("`@
M("`@("1T:&ES+3Y?<F5G:7-T<GD@/2`F)&,M/F=E=%)E9VES=')Y*"D[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T3&]G9V5R*"8D;"D-"B`@("![#0H@
M("`@("`@("1T:&ES+3Y?;&]G9V5R(#T@)B1L.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N('!A<G-E*"1D871A+"`D9FEL92D-"B`@("![#0H@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1E<G(@/2!P87)E;G0Z.G!A<G-E*"1D871A+"`D
M9FEL92DI*2![#0H@("`@("`@("`@("!R971U<FX@)&5R<CL-"B`@("`@("`@
M?0T*("`@("`@("`D<F5T(#T@;F5W(%!%05)?0VAA;FYE;$9I;&4[#0H@("`@
M("`@("1R970M/G-E=$-O;F9I9R@D=&AI<RT^7V-O;F9I9RD[#0H@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7VQO9V=E<BDI('L-"B`@("`@("`@("`@("1R
M970M/G-E=$QO9V=E<B@D=&AI<RT^7VQO9V=E<BD[#0H@("`@("`@('T-"B`@
M("`@("`@)')E="T^9G)O;4%R<F%Y*"1T:&ES+3Y?=6YS97)I86QI>F5D1&%T
M82D[#0H@("`@("`@("\O(&UA:V4@<W5R92!T:&4@9FEL96QI<W0@:7,@:6X@
M=&AE(&5A<WD@=&\@<F5A9"!F;W)M870@;F5E9&5D#0H@("`@("`@("1R970M
M/F9L871T96Y&:6QE;&ES="@I.PT*("`@("`@("`D<F5T+3YS971086-K86=E
M9FEL92@D9FEL92P@)&%R8VAI=F4I.PT*("`@("`@("!R971U<FX@)')E=#L-
M"B`@("!]#0I]#0H_/@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]0
M14%2+T-H86YN96Q&:6QE+G!H<```````````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#$V,3<W,P`Q,#4Q-30S,S<T,0`P,C(R,S$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`-"B\J*@T*("H@
M4$5!4E]#:&%N;F5L1FEL92P@=&AE(&-H86YN96P@:&%N9&QI;F<@8VQA<W,-
M"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z
M(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O
M9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*
M("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO
M=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N
M<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E
M8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@
M*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`
M875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`
M8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N
M<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0
M($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@0VAA;FYE
M;$9I;&4N<&AP+'8@,2XW-2`R,#`V+S`S+S`R(#$X.C$T.C$R(&-E;&QO9R!%
M>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E
M(%)E;&5A<V4@,2XT+C!A,0T*("HO#0H-"B\J*@T*("H@3F5E9&5D(&9O<B!E
M<G)O<B!H86YD;&EN9PT*("HO#0IR97%U:7)E7V]N8V4@)U!%05(O17)R;W)3
M=&%C:RYP:'`G.PT*<F5Q=6ER95]O;F-E("=014%2+UA-3%!A<G-E<BYP:'`G
M.PT*<F5Q=6ER95]O;F-E("=014%2+T-O;6UO;BYP:'`G.PT*#0HO*BH-"B`J
M($5R<F]R(&-O9&4@:68@=&AE(&-H86YN96PN>&UL(#QC:&%N;F5L/B!T86<@
M9&]E<R!N;W0@8V]N=&%I;B!A('9A;&ED('9E<G-I;VX-"B`J+PT*9&5F:6YE
M*"=014%27T-(04Y.14Q&24Q%7T524D]27TY/7U9%4E-)3TXG+"`Q*3L-"B\J
M*@T*("H@17)R;W(@8V]D92!I9B!T:&4@8VAA;FYE;"YX;6P@/&-H86YN96P^
M('1A9R!V97)S:6]N(&ES(&YO="!S=7!P;W)T960@*'9E<G-I;VX@,2XP(&ES
M('1H92!O;FQY('-U<'!O<G1E9"!V97)S:6]N+`T*("H@8W5R<F5N=&QY#0H@
M*B\-"F1E9FEN92@G4$5!4E]#2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$7U9%
M4E-)3TXG+"`R*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E(&EF('!A<G-I;F<@
M:7,@871T96UP=&5D('=I=&@@;F\@>&UL(&5X=&5N<VEO;@T*("HO#0ID969I
M;F4H)U!%05)?0TA!3DY%3$9)3$5?15)23U)?3D]?6$U,7T585"<L(#,I.PT*
M#0HO*BH-"B`J($5R<F]R(&-O9&4@:68@8W)E871I;F<@=&AE('AM;"!P87)S
M97(@<F5S;W5R8V4@9F%I;',-"B`J+PT*9&5F:6YE*"=014%27T-(04Y.14Q&
M24Q%7T524D]27T-!3E1?34%+15]005)315(G+"`T*3L-"@T*+RHJ#0H@*B!%
M<G)O<B!C;V1E('5S960@9F]R(&%L;"!S87@@>&UL('!A<G-I;F<@97)R;W)S
M#0H@*B\-"F1E9FEN92@G4$5!4E]#2$%.3D5,1DE,15]%4E)/4E]005)315)?
M15)23U(G+"`U*3L-"@T*+RHJ(T`K#0H@*B!686QI9&%T:6]N(&5R<F]R<PT*
M("HO#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!C:&%N;F5L(&YA;64@:7,@
M;6ES<VEN9PT*("HO#0ID969I;F4H)U!%05)?0TA!3DY%3$9)3$5?15)23U)?
M3D]?3D%-12<L(#8I.PT*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@8VAA;FYE
M;"!N86UE(&ES(&EN=F%L:60-"B`J+PT*9&5F:6YE*"=014%27T-(04Y.14Q&
M24Q%7T524D]27TE.5D%,241?3D%-12<L(#<I.PT*+RHJ#0H@*B!%<G)O<B!C
M;V1E('=H96X@8VAA;FYE;"!S=6UM87)Y(&ES(&UI<W-I;F<-"B`J+PT*9&5F
M:6YE*"=014%27T-(04Y.14Q&24Q%7T524D]27TY/7U-534U!4EDG+"`X*3L-
M"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&-H86YN96P@<W5M;6%R>2!I<R!M
M=6QT:2UL:6YE#0H@*B\-"F1E9FEN92@G4$5!4E]#2$%.3D5,1DE,15]%4E)/
M4E]-54Q424Q)3D5?4U5-34%262<L(#DI.PT*+RHJ#0H@*B!%<G)O<B!C;V1E
M('=H96X@8VAA;FYE;"!S97)V97(@:7,@;6ES<VEN9R!F;W(@>&UL<G!C(&]R
M('-O87`@<')O=&]C;VP-"B`J+PT*9&5F:6YE*"=014%27T-(04Y.14Q&24Q%
M7T524D]27TY/7TA/4U0G+"`Q,"D[#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE
M;B!C:&%N;F5L('-E<G9E<B!I<R!I;G9A;&ED(&9O<B!X;6QR<&,@;W(@<V]A
M<"!P<F]T;V-O;`T*("HO#0ID969I;F4H)U!%05)?0TA!3DY%3$9)3$5?15)2
M3U)?24Y604Q)1%](3U-4)RP@,3$I.PT*+RHJ#0H@*B!%<G)O<B!C;V1E('=H
M96X@82!M:7)R;W(@;F%M92!I<R!I;G9A;&ED#0H@*B\-"F1E9FEN92@G4$5!
M4E]#2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$7TU)4E)/4B<L(#(Q*3L-"B\J
M*@T*("H@17)R;W(@8V]D92!W:&5N(&$@;6ER<F]R('1Y<&4@:7,@:6YV86QI
M9`T*("HO#0ID969I;F4H)U!%05)?0TA!3DY%3$9)3$5?15)23U)?24Y604Q)
M1%]-25)23U)465!%)RP@,C(I.PT*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@
M86X@871T96UP="!I<R!M861E('1O(&=E;F5R871E('AM;"P@8G5T('1H92!P
M87)S960@8V]N=&5N="!I<R!I;G9A;&ED#0H@*B\-"F1E9FEN92@G4$5!4E]#
M2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$)RP@,C,I.PT*+RHJ#0H@*B!%<G)O
M<B!C;V1E('=H96X@86X@96UP='D@<&%C:V%G92!N86UE('9A;&ED871E(')E
M9V5X(&ES('!A<W-E9"!I;@T*("HO#0ID969I;F4H)U!%05)?0TA!3DY%3$9)
M3$5?15)23U)?14U05%E?4D5'15@G+"`R-"D[#0HO*BH-"B`J($5R<F]R(&-O
M9&4@=VAE;B!A(#QF=6YC=&EO;CX@=&%G(&AA<R!N;R!V97)S:6]N#0H@*B\-
M"F1E9FEN92@G4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U]&54Y#5$E/3E9%
M4E-)3TXG+"`R-2D[#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A(#QF=6YC
M=&EO;CX@=&%G(&AA<R!N;R!N86UE#0H@*B\-"F1E9FEN92@G4$5!4E]#2$%.
M3D5,1DE,15]%4E)/4E].3U]&54Y#5$E/3DY!344G+"`R-BD[#0HO*BH-"B`J
M($5R<F]R(&-O9&4@=VAE;B!A(#QV86QI9&%T97!A8VMA9V4^('1A9R!H87,@
M;F\@;F%M90T*("HO#0ID969I;F4H)U!%05)?0TA!3DY%3$9)3$5?15)23U)?
M3D]604Q)1$%415].04U%)RP@,C<I.PT*+RHJ#0H@*B!%<G)O<B!C;V1E('=H
M96X@82`\=F%L:61A=&5P86-K86=E/B!T86<@:&%S(&YO('9E<G-I;VX@871T
M<FEB=71E#0H@*B\-"F1E9FEN92@G4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].
M3U9!3$E$051%7U9%4E-)3TXG+"`R."D[#0HO*BH-"B`J($5R<F]R(&-O9&4@
M=VAE;B!A(&UI<G)O<B!D;V5S(&YO="!E>&ES="!B=70@:7,@8V%L;&5D(&9O
M<B!I;B!O;F4@;V8@=&AE('-E="H-"B`J(&UE=&AO9',N#0H@*B\-"F1E9FEN
M92@G4$5!4E]#2$%.3D5,1DE,15]%4E)/4E]-25)23U)?3D]47T9/54Y$)RP@
M,S(I.PT*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@82!S97)V97(@<&]R="!I
M<R!N;W0@;G5M97)I8PT*("HO#0ID969I;F4H)U!%05)?0TA!3DY%3$9)3$5?
M15)23U)?24Y604Q)1%]03U)4)RP@,S,I.PT*+RHJ#0H@*B!%<G)O<B!C;V1E
M('=H96X@/'-T871I8SX@8V]N=&%I;G,@;F\@=F5R<VEO;B!A='1R:6)U=&4-
M"B`J+PT*9&5F:6YE*"=014%27T-(04Y.14Q&24Q%7T524D]27TY/7U-4051)
M0U9%4E-)3TXG+"`S-"D[#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B`\8F%S
M975R;#X@8V]N=&%I;G,@;F\@='EP92!A='1R:6)U=&4@:6X@82`\<F5S=#X@
M<')O=&]C;VP@9&5F:6YI=&EO;@T*("HO#0ID969I;F4H)U!%05)?0TA!3DY%
M3$9)3$5?15)23U)?3D]"05-%55),5%E012<L(#,U*3L-"B\J*B`-"B`J($5R
M<F]R(&-O9&4@=VAE;B!A(&UI<G)O<B!I<R!D969I;F5D(&%N9"!T:&4@8VAA
M;FYE;"YX;6P@<F5P<F5S96YT<R!T:&4@7U]U<FD@<'-E=61O+6-H86YN96P-
M"B`J+PT*9&5F:6YE*"=014%27T-(04Y.14Q&24Q%7U5225]#04Y47TU)4E)/
M4B<L(#,V*3L-"B\J*B`-"B`J($5R<F]R(&-O9&4@=VAE;B!S<VP@871T<FEB
M=71E(&ES('!R97-E;G0@86YD(&ES(&YO="`B>65S(@T*("HO#0ID969I;F4H
M)U!%05)?0TA!3DY%3$9)3$5?15)23U)?24Y604Q)1%]34TPG+"`S-RD[#0HO
M*BHC0"TJ+PT*#0HO*BH-"B`J($UI<G)O<B!T>7!E<R!A;&QO=V5D+B`@0W5R
M<F5N=&QY(&]N;'D@:6YT97)N970@<V5R=F5R<R!A<F4@<F5C;V=N:7IE9"X-
M"B`J+PT*)$=,3T)!3%-;)U]014%27T-(04Y.14Q37TU)4E)/4E]465!%4R==
M(#T@(&%R<F%Y*"=S97)V97(G*3L-"@T*#0HO*BH-"B`J(%1H92!#:&%N;F5L
M(&AA;F1L:6YG(&-L87-S#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@
M0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@
M/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H
M92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I
M;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P
M96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S
M<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S
M(%!%05)?0VAA;FYE;$9I;&4@>PT*("`@("\J*@T*("`@("`J($!A8V-E<W,@
M<')I=F%T90T*("`@("`J($!V87(@4$5!4E]%<G)O<E-T86-K#0H@("`@("H@
M0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?<W1A8VL[#0H@
M("`@#0H@("`@+RHJ#0H@("`@("H@4W5P<&]R=&5D(&-H86YN96PN>&UL('9E
M<G-I;VYS+"!F;W(@<&%R<VEN9PT*("`@("`J($!V87(@87)R87D-"B`@("`@
M*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@)%]S=7!P;W)T
M961697)S:6]N<R`](&%R<F%Y*"<Q+C`G*3L-"@T*("`@("\J*@T*("`@("`J
M(%!A<G-E9"!C:&%N;F5L(&EN9F]R;6%T:6]N#0H@("`@("H@0'9A<B!A<G)A
M>0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D
M7V-H86YN96Q);F9O.PT*#0H@("`@+RHJ#0H@("`@("H@:6YD97@@:6YT;R!T
M:&4@<W5B8VAA;FYE;',@87)R87DL('5S960@9F]R('!A<G-I;F<@>&UL#0H@
M("`@("H@0'9A<B!I;G0-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@
M*B\-"B`@("!V87(@)%]S=6)C:&%N;F5L26YD97@[#0H-"B`@("`O*BH-"B`@
M("`@*B!I;F1E>"!I;G1O('1H92!M:7)R;W)S(&%R<F%Y+"!U<V5D(&9O<B!P
M87)S:6YG('AM;`T*("`@("`J($!V87(@:6YT#0H@("`@("H@0&%C8V5S<R!P
M<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?;6ER<F]R26YD97@[#0H@("`@
M#0H@("`@+RHJ#0H@("`@("H@1FQA9R!U<V5D('1O(&1E=&5R;6EN92!T:&4@
M=F%L:61I='D@;V8@<&%R<V5D(&-O;G1E;G0-"B`@("`@*B!`=F%R(&)O;VQE
M86X-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@
M)%]I<U9A;&ED(#T@9F%L<V4[#0H-"B`@("!F=6YC=&EO;B!014%27T-H86YN
M96Q&:6QE*"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VL@/2`F;F5W
M(%!%05)?17)R;W)3=&%C:R@G4$5!4E]#:&%N;F5L1FEL92<I.PT*("`@("`@
M("`D=&AI<RT^7W-T86-K+3YS971%<G)O<DUE<W-A9V5496UP;&%T92@D=&AI
M<RT^7V=E=$5R<F]R365S<V%G92@I*3L-"B`@("`@("`@)'1H:7,M/E]I<U9A
M;&ED(#T@9F%L<V4[#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J($!R
M971U<FX@87)R87D-"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(%]G971%<G)O<DUE<W-A9V4H*0T*("`@('L-"B`@
M("`@("`@<F5T=7)N#0H@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@
M("`@("!014%27T-(04Y.14Q&24Q%7T524D]27TE.5D%,241?5D524TE/3B`]
M/@T*("`@("`@("`@("`@("`@("`@("`G5VAI;&4@<&%R<VEN9R!C:&%N;F5L
M+GAM;"P@86X@:6YV86QI9"!V97)S:6]N(&YU;6)E<B`B)79E<G-I;VXE('=A
M<R!P87-S960@:6XL(&5X<&5C=&EN9R!O;F4@;V8@)79E<G-I;VYS)2<L#0H@
M("`@("`@("`@("`@("`@4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U]615)3
M24].(#T^#0H@("`@("`@("`@("`@("`@("`@("=.;R!V97)S:6]N(&YU;6)E
M<B!F;W5N9"!I;B`\8VAA;FYE;#X@=&%G)RP-"B`@("`@("`@("`@("`@("!0
M14%27T-(04Y.14Q&24Q%7T524D]27TY/7UA-3%]%6%0@/3X-"B`@("`@("`@
M("`@("`@("`@("`@)R5E<G)O<B4G+`T*("`@("`@("`@("`@("`@(%!%05)?
M0TA!3DY%3$9)3$5?15)23U)?0T%.5%]-04M%7U!!4E-%4B`]/@T*("`@("`@
M("`@("`@("`@("`@("`G56YA8FQE('1O(&-R96%T92!834P@<&%R<V5R)RP-
M"B`@("`@("`@("`@("`@("!014%27T-(04Y.14Q&24Q%7T524D]27U!!4E-%
M4E]%4E)/4B`]/@T*("`@("`@("`@("`@("`@("`@("`G)65R<F]R)2<L#0H@
M("`@("`@("`@("`@("`@4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U].04U%
M(#T^#0H@("`@("`@("`@("`@("`@("`@("=-:7-S:6YG(&-H86YN96P@;F%M
M92<L#0H@("`@("`@("`@("`@("`@4$5!4E]#2$%.3D5,1DE,15]%4E)/4E])
M3E9!3$E$7TY!344@/3X-"B`@("`@("`@("`@("`@("`@("`@)TEN=F%L:60@
M8VAA;FYE;"`E=&%G)2`B)6YA;64E(B<L#0H@("`@("`@("`@("`@("`@4$5!
M4E]#2$%.3D5,1DE,15]%4E)/4E].3U]354U-05)9(#T^#0H@("`@("`@("`@
M("`@("`@("`@("=-:7-S:6YG(&-H86YN96P@<W5M;6%R>2<L#0H@("`@("`@
M("`@("`@("`@4$5!4E]#2$%.3D5,1DE,15]%4E)/4E]-54Q424Q)3D5?4U5-
M34%262`]/@T*("`@("`@("`@("`@("`@("`@("`G0VAA;FYE;"!S=6UM87)Y
M('-H;W5L9"!B92!O;B!O;F4@;&EN92P@8G5T(&ES(&UU;'1I+6QI;F4G+`T*
M("`@("`@("`@("`@("`@(%!%05)?0TA!3DY%3$9)3$5?15)23U)?3D]?2$]3
M5"`]/@T*("`@("`@("`@("`@("`@("`@("`G36ES<VEN9R!C:&%N;F5L('-E
M<G9E<B!F;W(@)71Y<&4E('-E<G9E<B<L#0H@("`@("`@("`@("`@("`@4$5!
M4E]#2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$7TA/4U0@/3X-"B`@("`@("`@
M("`@("`@("`@("`@)U-E<G9E<B!N86UE("(E<V5R=F5R)2(@:7,@:6YV86QI
M9"!F;W(@)71Y<&4E('-E<G9E<B<L#0H@("`@("`@("`@("`@("`@4$5!4E]#
M2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$7TU)4E)/4B`]/@T*("`@("`@("`@
M("`@("`@("`@("`G26YV86QI9"!M:7)R;W(@;F%M92`B)6YA;64E(BP@;6ER
M<F]R('1Y<&4@)71Y<&4E)RP-"B`@("`@("`@("`@("`@("!014%27T-(04Y.
M14Q&24Q%7T524D]27TE.5D%,241?34E24D]25%E012`]/@T*("`@("`@("`@
M("`@("`@("`@("`G26YV86QI9"!M:7)R;W(@='EP92`B)71Y<&4E(B<L#0H@
M("`@("`@("`@("`@("`@4$5!4E]#2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$
M(#T^#0H@("`@("`@("`@("`@("`@("`@("=#86YN;W0@9V5N97)A=&4@>&UL
M+"!C;VYT96YT<R!A<F4@:6YV86QI9"<L#0H@("`@("`@("`@("`@("`@4$5!
M4E]#2$%.3D5,1DE,15]%4E)/4E]%35!465]214=%6"`]/@T*("`@("`@("`@
M("`@("`@("`@("`G<&%C:V%G96YA;65R96=E>"!C86YN;W0@8F4@96UP='DG
M+`T*("`@("`@("`@("`@("`@(%!%05)?0TA!3DY%3$9)3$5?15)23U)?3D]?
M1E5.0U1)3TY615)324].(#T^#0H@("`@("`@("`@("`@("`@("`@("<E<&%R
M96YT)2`E<')O=&]C;VPE(&9U;F-T:6]N(&AA<R!N;R!V97)S:6]N)RP-"B`@
M("`@("`@("`@("`@("!014%27T-(04Y.14Q&24Q%7T524D]27TY/7T953D-4
M24].3D%-12`]/@T*("`@("`@("`@("`@("`@("`@("`G)7!A<F5N="4@)7!R
M;W1O8V]L)2!F=6YC=&EO;B!H87,@;F\@;F%M92<L#0H@("`@("`@("`@("`@
M("`@4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3T)!4T554DQ465!%(#T^#0H@
M("`@("`@("`@("`@("`@("`@("<E<&%R96YT)2!R97-T(&)A<V5U<FP@:&%S
M(&YO('1Y<&4G+`T*("`@("`@("`@("`@("`@(%!%05)?0TA!3DY%3$9)3$5?
M15)23U)?3D]604Q)1$%415].04U%(#T^#0H@("`@("`@("`@("`@("`@("`@
M("=686QI9&%T:6]N('!A8VMA9V4@:&%S(&YO(&YA;64@:6X@/'9A;&ED871E
M<&%C:V%G93X@=&%G)RP-"B`@("`@("`@("`@("`@("!014%27T-(04Y.14Q&
M24Q%7T524D]27TY/5D%,241!5$5?5D524TE/3B`]/@T*("`@("`@("`@("`@
M("`@("`@("`G5F%L:61A=&EO;B!P86-K86=E("(E<&%C:V%G924B(&AA<R!N
M;R!V97)S:6]N)RP-"B`@("`@("`@("`@("`@("!014%27T-(04Y.14Q&24Q%
M7T524D]27TU)4E)/4E].3U1?1D]53D0@/3X-"B`@("`@("`@("`@("`@("`@
M("`@)TUI<G)O<B`B)6UI<G)O<B4B(&1O97,@;F]T(&5X:7-T)RP-"B`@("`@
M("`@("`@("`@("!014%27T-(04Y.14Q&24Q%7T524D]27TE.5D%,241?4$]2
M5"`]/@T*("`@("`@("`@("`@("`@("`@("`G4&]R="`B)7!O<G0E(B!M=7-T
M(&)E(&YU;65R:6,G+`T*("`@("`@("`@("`@("`@(%!%05)?0TA!3DY%3$9)
M3$5?15)23U)?3D]?4U1!5$E#5D524TE/3B`]/@T*("`@("`@("`@("`@("`@
M("`@("`G/'-T871I8SX@=&%G(&UU<W0@8V]N=&%I;B!V97)S:6]N(&%T=')I
M8G5T92<L#0H@("`@("`@("`@("`@("`@4$5!4E]#2$%.3D5,1DE,15]54DE?
M0T%.5%]-25)23U(@/3X-"B`@("`@("`@("`@("`@("`@("`@)U1H92!?7W5R
M:2!P<V5U9&\M8VAA;FYE;"!C86YN;W0@:&%V92!M:7)R;W)S)RP-"B`@("`@
M("`@("`@("`@("!014%27T-(04Y.14Q&24Q%7T524D]27TE.5D%,241?4U-,
M(#T^#0H@("`@("`@("`@("`@("`@("`@("<E<V5R=F5R)2!H87,@:6YV86QI
M9"!S<VP@871T<FEB=71E("(E<W-L)2(@8V%N(&]N;'D@8F4@>65S(&]R(&YO
M="!P<F5S96YT)RP-"B`@("`@("`@("`@("D[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@0'!A<F%M('-T<FEN9R!C;VYT96YT<R!O9B!P86-K86=E+GAM
M;"!F:6QE#0H@("`@("H@0')E='5R;B!B;V]L('-U8V-E<W,@;V8@<&%R<VEN
M9PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&9R;VU8;6Q3=')I;F<H)&1A=&$I
M#0H@("`@>PT*("`@("`@("!I9B`H<')E9U]M871C:"@G+SQC:&%N;F5L7',K
M=F5R<VEO;CTB*%LP+3E=*UPN6S`M.5TK*2(O)RP@)&1A=&$L("1C:&%N;F5L
M=F5R<VEO;BDI('L-"B`@("`@("`@("`@(&EF("@A:6Y?87)R87DH)&-H86YN
M96QV97)S:6]N6S%=+"`D=&AI<RT^7W-U<'!O<G1E9%9E<G-I;VYS*2D@>PT*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H4$5!4E]#2$%.
M3D5,1DE,15]%4E)/4E])3E9!3$E$7U9%4E-)3TXL("=E<G)O<B<L#0H@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"=V97)S:6]N)R`]/B`D8VAA;FYE;'9E
M<G-I;VY;,5TI*3L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`D<&%R<V5R(#T@;F5W(%!%05)?
M6$U,4&%R<V5R.PT*("`@("`@("`@("`@)')E<W5L="`]("1P87)S97(M/G!A
M<G-E*"1D871A*3L-"B`@("`@("`@("`@(&EF("@D<F5S=6QT("$]/2!T<G5E
M*2![#0H@("`@("`@("`@("`@("`@:68@*"1R97-U;'0M/F=E=$-O9&4H*2`]
M/2`Q*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U
M<V@H4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U]834Q?15A4+"`G97)R;W(G
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V5R<F]R)R`]/B`D
M97)R;W(I*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%!%05)?0TA!3DY%3$9)
M3$5?15)23U)?0T%.5%]-04M%7U!!4E-%4BP@)V5R<F]R)RD[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("1T:&ES+3Y?8VAA;FYE;$EN9F\@
M/2`D<&%R<V5R+3YG971$871A*"D[#0H@("`@("`@("`@("!R971U<FX@=')U
M93L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T:&ES+3Y?<W1A
M8VLM/G!U<V@H4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U]615)324].+"`G
M97)R;W(G+"!A<G)A>2@G>&UL)R`]/B`D9&%T82DI.PT*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@?0T*("`@(`T*("`@("\J
M*@T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!T;T%R<F%Y*"D-"B`@("![#0H@("`@("`@(&EF("@A)'1H:7,M/E]I<U9A
M;&ED("8F("$D=&AI<RT^=F%L:61A=&4H*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D=&AI<RT^
M7V-H86YN96Q);F9O.PT*("`@('T-"B`@("`-"B`@("`O*BH-"B`@("`@*B!`
M<&%R86T@87)R87D-"B`@("`@*B!`<W1A=&EC#0H@("`@("H@0')E='5R;B!0
M14%27T-H86YN96Q&:6QE?&9A;'-E(&9A;'-E(&EF(&EN=F%L:60-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B`F9G)O;4%R<F%Y*"1D871A+"`D8V]M<&%T:6)I
M;&ET>2`](&9A;'-E+"`D<W1A8VM#;&%S<R`]("=014%27T5R<F]R4W1A8VLG
M*0T*("`@('L-"B`@("`@("`@)&$@/2!N97<@4$5!4E]#:&%N;F5L1FEL92@D
M8V]M<&%T:6)I;&ET>2P@)'-T86-K0VQA<W,I.PT*("`@("`@("`D82T^7V9R
M;VU!<G)A>2@D9&%T82D[#0H@("`@("`@(&EF("@A)&$M/G9A;&ED871E*"DI
M('L-"B`@("`@("`@("`@("1A(#T@9F%L<V4[#0H@("`@("`@("`@("!R971U
M<FX@)&$[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1A.PT*("`@('T-
M"@T*("`@("\J*@T*("`@("`J(%5N;&EK92![0&QI;FL@9G)O;4%R<F%Y*"E]
M('1H:7,@9&]E<R!N;W0@9&\@86YY('9A;&ED871I;VX-"B`@("`@*B!`<&%R
M86T@87)R87D-"B`@("`@*B!`<W1A=&EC#0H@("`@("H@0')E='5R;B!014%2
M7T-H86YN96Q&:6QE#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F9R;VU!<G)A
M>5=I=&A%<G)O<G,H)&1A=&$L("1C;VUP871I8FEL:71Y(#T@9F%L<V4L#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T86-K0VQA<W,@
M/2`G4$5!4E]%<G)O<E-T86-K)RD-"B`@("![#0H@("`@("`@("1A(#T@;F5W
M(%!%05)?0VAA;FYE;$9I;&4H)&-O;7!A=&EB:6QI='DL("1S=&%C:T-L87-S
M*3L-"B`@("`@("`@)&$M/E]F<F]M07)R87DH)&1A=&$I.PT*("`@("`@("!R
M971U<FX@)&$[#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J($!P87)A
M;2!A<G)A>0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(%]F<F]M07)R87DH)&1A=&$I#0H@("`@>PT*("`@("`@("`D
M=&AI<RT^7V-H86YN96Q);F9O(#T@)&1A=&$[#0H@("`@?0T*("`@(`T*("`@
M("\J*@T*("`@("`J(%=R87!P97(@=&\@>T!L:6YK(%!%05)?17)R;W)3=&%C
M:SHZ9V5T17)R;W)S*"E]#0H@("`@("H@0'!A<F%M(&)O;VQE86X@9&5T97)M
M:6YE<R!W:&5T:&5R('1O('!U<F=E('1H92!E<G)O<B!S=&%C:R!A9G1E<B!R
M971R:65V:6YG#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(&=E=$5R<F]R<R@D<'5R9V4@/2!F86QS92D-"B`@("![#0H@
M("`@("`@(')E='5R;B`D=&AI<RT^7W-T86-K+3YG971%<G)O<G,H)'!U<F=E
M*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!5;FEN9&5N="!G:79E;B!S
M=')I;F<@*#\I#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1S='(@
M5&AE('-T<FEN9R!T:&%T(&AA<R!T;R!B92!U;FEN9&5N=&5D+@T*("`@("`J
M($!R971U<FX@<W1R:6YG#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@7W5N26YD96YT*"1S='(I#0H@("`@>PT*("`@
M("`@("`O+R!R96UO=F4@;&5A9&EN9R!N97=L:6YE<PT*("`@("`@("`D<W1R
M(#T@<')E9U]R97!L86-E*"<O7EM<<EQN72LO)RP@)R<L("1S='(I.PT*("`@
M("`@("`O+R!F:6YD('=H:71E<W!A8V4@870@=&AE(&)E9VEN;FEN9R!O9B!T
M:&4@9FER<W0@;&EN90T*("`@("`@("`D:6YD96YT7VQE;B`]('-T<G-P;B@D
M<W1R+"`B(%QT(BD[#0H@("`@("`@("1I;F1E;G0@/2!S=6)S='(H)'-T<BP@
M,"P@)&EN9&5N=%]L96XI.PT*("`@("`@("`D9&%T82`]("<G.PT*("`@("`@
M("`O+R!R96UO=F4@=&AE('-A;64@86UO=6YT(&]F('=H:71E<W!A8V4@9G)O
M;2!F;VQL;W=I;F<@;&EN97,-"B`@("`@("`@9F]R96%C:"`H97AP;&]D92@B
M7&XB+"`D<W1R*2!A<R`D;&EN92D@>PT*("`@("`@("`@("`@:68@*'-U8G-T
M<B@D;&EN92P@,"P@)&EN9&5N=%]L96XI(#T]("1I;F1E;G0I('L-"B`@("`@
M("`@("`@("`@("`D9&%T82`N/2!S=6)S='(H)&QI;F4L("1I;F1E;G1?;&5N
M*2`N(")<;B([#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N("1D871A.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%!A<G-E
M(&$@8VAA;FYE;"YX;6P@9FEL92X@($5X<&5C=',@=&AE(&YA;64@;V8-"B`@
M("`@*B!A(&-H86YN96P@>&UL(&9I;&4@87,@:6YP=70N#0H@("`@("H-"B`@
M("`@*B!`<&%R86T@<W1R:6YG("`D9&5S8V9I;&4@(&YA;64@;V8@8VAA;FYE
M;"!X;6P@9FEL90T*("`@("`J($!R971U<FX@8F]O;"!S=6-C97-S(&]F('!A
M<G-I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!F<F]M6&UL1FEL92@D9&5S
M8V9I;&4I#0H@("`@>PT*("`@("`@("!I9B`H(4!I<U]F:6QE*"1D97-C9FEL
M92D@?'P@(6ES7W)E861A8FQE*"1D97-C9FEL92D@?'P-"B`@("`@("`@("`@
M("`H(21F<"`]($!F;W!E;B@D9&5S8V9I;&4L("=R)RDI*2![#0H@("`@("`@
M("`@("!R97%U:7)E7V]N8V4@)U!%05(N<&AP)SL-"B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*")5;F%B;&4@=&\@;W!E;B`D9&5S8V9I
M;&4B*3L-"B`@("`@("`@?0T*#0H@("`@("`@("\O(')E860@=&AE('=H;VQE
M('1H:6YG('-O('=E(&]N;'D@9V5T(&]N92!C9&%T82!C86QL8F%C:PT*("`@
M("`@("`O+R!F;W(@96%C:"!B;&]C:R!O9B!C9&%T80T*("`@("`@("!I9B`H
M9G5N8W1I;VY?97AI<W1S*"=F:6QE7V=E=%]C;VYT96YT<R<I*2![#0H@("`@
M("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@("`@("1D871A(#T@9FEL
M95]G971?8V]N=&5N=',H)&1E<V-F:6QE*3L-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("1D871A(#T@9G)E860H)&9P+"!F:6QE<VEZ92@D9&5S
M8V9I;&4I*3L-"B`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B`D=&AI<RT^9G)O;5AM;%-T<FEN9R@D9&%T82D[
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4&%R<V4@8VAA;FYE;"!I;F9O
M<FUA=&EO;B!F<F]M(&1I9F9E<F5N="!S;W5R8V5S#0H@("`@("H-"B`@("`@
M*B!4:&ES(&UE=&AO9"!I<R!A8FQE('1O(&5X=')A8W0@:6YF;W)M871I;VX@
M86)O=70@82!C:&%N;F5L#0H@("`@("H@9G)O;2!A;B`N>&UL(&9I;&4@;W(@
M82!S=')I;F<-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@
M("H@0'!A<F%M("!S=')I;F<@1FEL96YA;64@;V8@=&AE('-O=7)C92!O<B!T
M:&4@<V]U<F-E(&ET<V5L9@T*("`@("`J($!R971U<FX@8F]O;`T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(&9R;VU!;GDH)&EN9F\I#0H@("`@>PT*("`@("`@
M("!I9B`H:7-?<W1R:6YG*"1I;F9O*2`F)B!F:6QE7V5X:7-T<R@D:6YF;RD@
M)B8@<W1R;&5N*"1I;F9O*2`\(#(U-2D@>PT*("`@("`@("`@("`@)'1M<"`]
M('-U8G-T<B@D:6YF;RP@+30I.PT*("`@("`@("`@("`@:68@*"1T;7`@/3T@
M)RYX;6PG*2![#0H@("`@("`@("`@("`@("`@)&EN9F\@/2`D=&AI<RT^9G)O
M;5AM;$9I;&4H)&EN9F\I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`D9G`@/2!F;W!E;B@D:6YF;RP@(G(B*3L-"B`@("`@("`@
M("`@("`@("`D=&5S="`](&9R96%D*"1F<"P@-2D[#0H@("`@("`@("`@("`@
M("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("`@("`@("`@:68@*"1T97-T(#T]
M("(\/WAM;"(I('L-"B`@("`@("`@("`@("`@("`@("`@)&EN9F\@/2`D=&AI
M<RT^9G)O;5AM;$9I;&4H)&EN9F\I.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1I
M;F9O*2D@>PT*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4BYP
M:'`G.PT*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"1I;F9O*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H:7-?<W1R:6YG*"1I;F9O*2D@>PT*("`@("`@("`@("`@)&EN9F\@/2`D
M=&AI<RT^9G)O;5AM;%-T<FEN9R@D:6YF;RD[#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N("1I;F9O.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%)E
M='5R;B!A;B!834P@9&]C=6UE;G0@8F%S960@;VX@<')E=FEO=7,@<&%R<VEN
M9R!A;F0@;6]D:69I8V%T:6]N<PT*("`@("`J#0H@("`@("H@0')E='5R;B!S
M=')I;F<@6$U,(&1A=&$-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=&]8;6PH*0T*("`@('L-"B`@("`@
M("`@:68@*"$D=&AI<RT^7VES5F%L:60@)B8@(21T:&ES+3YV86QI9&%T92@I
M*2![#0H@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]#
M2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$*3L-"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?8VAA;FYE;$EN9F];)V%T=')I8G,G75LG=F5R<VEO;B==*2D@>PT*("`@
M("`@("`@("`@)'1H:7,M/E]C:&%N;F5L26YF;ULG871T<FEB<R==6R=V97)S
M:6]N)UT@/2`G,2XP)SL-"B`@("`@("`@?0T*("`@("`@("`D8VAA;FYE;$EN
M9F\@/2`D=&AI<RT^7V-H86YN96Q);F9O.PT*("`@("`@("`D<F5T(#T@(CP_
M>&UL('9E<G-I;VX]7"(Q+C!<(B!E;F-O9&EN9SU<(DE33RTX.#4Y+3%<(B`_
M/EQN(CL-"B`@("`@("`@)')E="`N/2`B/&-H86YN96P@=F5R<VEO;CU<(B(@
M+@T*("`@("`@("`@("`@)&-H86YN96Q);F9O6R=A='1R:6)S)UU;)W9E<G-I
M;VXG72`N(")<(B!X;6QN<SU<(FAT='`Z+R]P96%R+G!H<"YN970O8VAA;FYE
M;"TQ+C!<(@T*("!X;6QN<SIX<VD]7")H='1P.B\O=W=W+G<S+F]R9R\R,#`Q
M+UA-3%-C:&5M82UI;G-T86YC95PB#0H@('AS:3IS8VAE;6%,;V-A=&EO;CU<
M(FAT='`Z+R]P96%R+G!H<"YN970O9'1D+V-H86YN96PM(@T*("`@("`@("`@
M("`@+B`D8VAA;FYE;$EN9F];)V%T=')I8G,G75LG=F5R<VEO;B==("X@(B!H
M='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]C:&%N;F5L+2(@+@T*("`@("`@("`@
M("`@)&-H86YN96Q);F9O6R=A='1R:6)S)UU;)W9E<G-I;VXG72`N("(N>'-D
M7"(^#0H@/&YA;64^)&-H86YN96Q);F9O6VYA;65=/"]N86UE/@T*(#QS=6UM
M87)Y/B(@+B!H=&UL<W!E8VEA;&-H87)S*"1C:&%N;F5L26YF;ULG<W5M;6%R
M>2==*2XB/"]S=6UM87)Y/@T*(CL-"B`@("`@("`@:68@*&ES<V5T*"1C:&%N
M;F5L26YF;ULG<W5G9V5S=&5D86QI87,G72DI('L-"B`@("`@("`@("`@("1R
M970@+CT@)R`\<W5G9V5S=&5D86QI87,^)R`N("1C:&%N;F5L26YF;ULG<W5G
M9V5S=&5D86QI87,G72`N("(\+W-U9V=E<W1E9&%L:6%S/EQN(CL-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H:7-S970H)&-H86YN96Q);F9O6R=V86QI9&%T
M97!A8VMA9V4G72DI('L-"B`@("`@("`@("`@("1R970@+CT@)R`\=F%L:61A
M=&5P86-K86=E('9E<G-I;VX](B<@+@T*("`@("`@("`@("`@("`@("1C:&%N
M;F5L26YF;ULG=F%L:61A=&5P86-K86=E)UU;)V%T=')I8G,G75LG=F5R<VEO
M;B==+B`G(CXG("X-"B`@("`@("`@("`@("`@("!H=&UL<W!E8VEA;&-H87)S
M*"1C:&%N;F5L26YF;ULG=F%L:61A=&5P86-K86=E)UU;)U]C;VYT96YT)UTI
M("X-"B`@("`@("`@("`@("`@("`B/"]V86QI9&%T97!A8VMA9V4^7&XB.PT*
M("`@("`@("!]#0H@("`@("`@("1R970@+CT@(B`\<V5R=F5R<SY<;B([#0H@
M("`@("`@("1R970@+CT@)R`@/'!R:6UA<GDG.PT*("`@("`@("!I9B`H:7-S
M970H)&-H86YN96Q);F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LG871T<FEB
M<R==6R=S<VPG72DI('L-"B`@("`@("`@("`@("1R970@+CT@)R!S<VP](B<@
M+B`D8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R=A='1R:6)S
M)UU;)W-S;"==("X@)R(G.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E
M="@D8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R=A='1R:6)S
M)UU;)W!O<G0G72DI('L-"B`@("`@("`@("`@("1R970@+CT@)R!P;W)T/2(G
M("X@)&-H86YN96Q);F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LG871T<FEB
M<R==6R=P;W)T)UT@+B`G(B<[#0H@("`@("`@('T-"B`@("`@("`@)')E="`N
M/2`B/EQN(CL-"B`@("`@("`@:68@*&ES<V5T*"1C:&%N;F5L26YF;ULG<V5R
M=F5R<R==6R=P<FEM87)Y)UU;)WAM;')P8R==*2D@>PT*("`@("`@("`@("`@
M)')E="`N/2`D=&AI<RT^7VUA:V58;6QR<&-8;6PH)&-H86YN96Q);F9O6R=S
M97)V97)S)UU;)W!R:6UA<GDG75LG>&UL<G!C)UTL("<@("`G*3L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H:7-S970H)&-H86YN96Q);F9O6R=S97)V97)S
M)UU;)W!R:6UA<GDG75LG<F5S="==*2D@>PT*("`@("`@("`@("`@)')E="`N
M/2`D=&AI<RT^7VUA:V5297-T6&UL*"1C:&%N;F5L26YF;ULG<V5R=F5R<R==
M6R=P<FEM87)Y)UU;)W)E<W0G72P@)R`@("<I.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("AI<W-E="@D8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG<')I;6%R
M>2==6R=S;V%P)UTI*2![#0H@("`@("`@("`@("`D<F5T("X]("1T:&ES+3Y?
M;6%K95-O87!8;6PH)&-H86YN96Q);F9O6R=S97)V97)S)UU;)W!R:6UA<GDG
M75LG<V]A<"==+"`G("`@)RD[#0H@("`@("`@('T-"B`@("`@("`@)')E="`N
M/2`B("`\+W!R:6UA<GD^7&XB.PT*("`@("`@("!I9B`H:7-S970H)&-H86YN
M96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==*2D@>PT*("`@("`@("`@("`@
M)')E="`N/2`D=&AI<RT^7VUA:V5-:7)R;W)S6&UL*"1C:&%N;F5L26YF;RD[
M#0H@("`@("`@('T-"B`@("`@("`@)')E="`N/2`B(#PO<V5R=F5R<SY<;B([
M#0H@("`@("`@("1R970@+CT@(CPO8VAA;FYE;#XB.PT*("`@("`@("!R971U
M<FX@<W1R7W)E<&QA8V4H(EQR(BP@(EQN(BP@<W1R7W)E<&QA8V4H(EQR7&XB
M+"`B7&XB+"`D<F5T*2D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@1V5N
M97)A=&4@=&AE(#QX;6QR<&,^('1A9PT*("`@("`J($!A8V-E<W,@<')I=F%T
M90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]M86ME6&UL<G!C6&UL*"1I;F9O
M+"`D:6YD96YT*0T*("`@('L-"B`@("`@("`@)')E="`]("1I;F1E;G0@+B`B
M/'AM;')P8R([#0H@("`@("`@(&EF("AI<W-E="@D:6YF;ULG871T<FEB<R==
M6R=P871H)UTI*2![#0H@("`@("`@("`@("`D<F5T("X]("<@<&%T:#TB)R`N
M(&AT;6QS<&5C:6%L8VAA<G,H)&EN9F];)V%T=')I8G,G75LG<&%T:"==*2`N
M("<B)SL-"B`@("`@("`@?0T*("`@("`@("`D<F5T("X]("(^7&XB.PT*("`@
M("`@("`D<F5T("X]("1T:&ES+3Y?;6%K949U;F-T:6]N<UAM;"@D:6YF;ULG
M9G5N8W1I;VXG72P@(B1I;F1E;G0@(BD[#0H@("`@("`@("1R970@+CT@)&EN
M9&5N="`N("(\+WAM;')P8SY<;B([#0H@("`@("`@(')E='5R;B`D<F5T.PT*
M("`@('T-"@T*("`@("\J*@T*("`@("`J($=E;F5R871E('1H92`\<V]A<#X@
M=&%G#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@7VUA:V53;V%P6&UL*"1I;F9O+"`D:6YD96YT*0T*("`@('L-"B`@
M("`@("`@)')E="`]("1I;F1E;G0@+B`B/'-O87`B.PT*("`@("`@("!I9B`H
M:7-S970H)&EN9F];)V%T=')I8G,G75LG<&%T:"==*2D@>PT*("`@("`@("`@
M("`@)')E="`N/2`G('!A=&@](B<@+B!H=&UL<W!E8VEA;&-H87)S*"1I;F9O
M6R=A='1R:6)S)UU;)W!A=&@G72D@+B`G(B<[#0H@("`@("`@('T-"B`@("`@
M("`@)')E="`N/2`B/EQN(CL-"B`@("`@("`@)')E="`N/2`D=&AI<RT^7VUA
M:V5&=6YC=&EO;G-8;6PH)&EN9F];)V9U;F-T:6]N)UTL("(D:6YD96YT("(I
M.PT*("`@("`@("`D<F5T("X]("1I;F1E;G0@+B`B/"]S;V%P/EQN(CL-"B`@
M("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M1V5N97)A=&4@=&AE(#QR97-T/B!T86<-"B`@("`@*B!`86-C97-S('!R:79A
M=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?;6%K95)E<W18;6PH)&EN9F\L
M("1I;F1E;G0I#0H@("`@>PT*("`@("`@("`D<F5T(#T@)&EN9&5N="`N("(\
M<F5S=#Y<;B([#0H@("`@("`@(&EF("@A:7-S970H)&EN9F];)V)A<V5U<FPG
M75LP72DI('L-"B`@("`@("`@("`@("1I;F9O6R=B87-E=7)L)UT@/2!A<G)A
M>2@D:6YF;ULG8F%S975R;"==*3L-"B`@("`@("`@?0T*("`@("`@("!F;W)E
M86-H("@D:6YF;ULG8F%S975R;"==(&%S("1U<FPI('L-"B`@("`@("`@("`@
M("1R970@+CT@(B1I;F1E;G0@/&)A<V5U<FP@='EP93U<(B(@+B`D=7)L6R=A
M='1R:6)S)UU;)W1Y<&4G72`N(")<(B([#0H@("`@("`@("`@("`D<F5T("X]
M("(^(B`N("1U<FQ;)U]C;VYT96YT)UT@+B`B/"]B87-E=7)L/EQN(CL-"B`@
M("`@("`@?0T*("`@("`@("`D<F5T("X]("1I;F1E;G0@+B`B/"]R97-T/EQN
M(CL-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@1V5N97)A=&4@=&AE(#QM:7)R;W)S/B!T86<-"B`@("`@*B!`86-C
M97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?;6%K94UI<G)O
M<G-8;6PH)&-H86YN96Q);F9O*0T*("`@('L-"B`@("`@("`@)')E="`]("(B
M.PT*("`@("`@("!I9B`H(6ES<V5T*"1C:&%N;F5L26YF;ULG<V5R=F5R<R==
M6R=M:7)R;W(G75LP72DI('L-"B`@("`@("`@("`@("1C:&%N;F5L26YF;ULG
M<V5R=F5R<R==6R=M:7)R;W(G72`](&%R<F%Y*"1C:&%N;F5L26YF;ULG<V5R
M=F5R<R==6R=M:7)R;W(G72D[#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C
M:"`H)&-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==(&%S("1M:7)R
M;W(I('L-"B`@("`@("`@("`@("1R970@+CT@)R`@/&UI<G)O<B!H;W-T/2(G
M("X@)&UI<G)O<ELG871T<FEB<R==6R=H;W-T)UT@+B`G(B<[#0H@("`@("`@
M("`@("!I9B`H:7-S970H)&UI<G)O<ELG871T<FEB<R==6R=P;W)T)UTI*2![
M#0H@("`@("`@("`@("`@("`@)')E="`N/2`G('!O<G0](B<@+B`D;6ER<F]R
M6R=A='1R:6)S)UU;)W!O<G0G72`N("<B)SL-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("AI<W-E="@D;6ER<F]R6R=A='1R:6)S)UU;)W-S;"==
M*2D@>PT*("`@("`@("`@("`@("`@("1R970@+CT@)R!S<VP](B<@+B`D;6ER
M<F]R6R=A='1R:6)S)UU;)W-S;"==("X@)R(G.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@)')E="`N/2`B/EQN(CL-"B`@("`@("`@("`@(&EF("AI
M<W-E="@D;6ER<F]R6R=X;6QR<&,G72D@?'P@:7-S970H)&UI<G)O<ELG<V]A
M<"==*2D@>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D;6ER<F]R6R=X
M;6QR<&,G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)')E="`N/2`D=&AI
M<RT^7VUA:V58;6QR<&-8;6PH)&UI<G)O<ELG>&UL<G!C)UTL("<@("`G*3L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1M:7)R;W);)W)E<W0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)')E
M="`N/2`D=&AI<RT^7VUA:V5297-T6&UL*"1M:7)R;W);)W)E<W0G72P@)R`@
M("<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&UI<G)O<ELG<V]A<"==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D<F5T("X]("1T:&ES+3Y?;6%K95-O87!8;6PH)&UI<G)O<ELG<V]A<"==
M+"`G("`@)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("1R970@+CT@(B`@/"]M:7)R;W(^7&XB.PT*("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`D<F5T("X]("(O/EQN(CL-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!'96YE<F%T92!T:&4@/&9U;F-T:6]N<SX@
M=&%G#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@7VUA:V5&=6YC=&EO;G-8;6PH)&9U;F-T:6]N<RP@)&EN9&5N="P@
M)')E<W0@/2!F86QS92D-"B`@("![#0H@("`@("`@("1R970@/2`G)SL-"B`@
M("`@("`@:68@*"%I<W-E="@D9G5N8W1I;VYS6S!=*2D@>PT*("`@("`@("`@
M("`@)&9U;F-T:6]N<R`](&%R<F%Y*"1F=6YC=&EO;G,I.PT*("`@("`@("!]
M#0H@("`@("`@(&9O<F5A8V@@*"1F=6YC=&EO;G,@87,@)&9U;F-T:6]N*2![
M#0H@("`@("`@("`@("`D<F5T("X]("(D:6YD96YT/&9U;F-T:6]N('9E<G-I
M;VX]7"(B("X@)&9U;F-T:6]N6R=A='1R:6)S)UU;)W9E<G-I;VXG72`N(")<
M(B([#0H@("`@("`@("`@("!I9B`H)')E<W0I('L-"B`@("`@("`@("`@("`@
M("`D<F5T("X]("<@=7)I/2(G("X@)&9U;F-T:6]N6R=A='1R:6)S)UU;)W5R
M:2==("X@)R(G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)')E="`N
M/2`B/B(@+B`D9G5N8W1I;VY;)U]C;VYT96YT)UT@+B`B/"]F=6YC=&EO;CY<
M;B([#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*
M#0H@("`@+RHJ#0H@("`@("H@5F%L:61A=&EO;B!E<G)O<BX@($%L<V\@;6%R
M:W,@=&AE(&]B:F5C="!C;VYT96YT<R!A<R!I;G9A;&ED#0H@("`@("H@0'!A
M<F%M(&5R<F]R(&-O9&4-"B`@("`@*B!`<&%R86T@87)R87D@97)R;W(@:6YF
M;W)M871I;VX-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!?=F%L:61A=&5%<G)O<B@D8V]D92P@)'!A<F%M<R`](&%R
M<F%Y*"DI#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*"1C
M;V1E+"`G97)R;W(G+"`D<&%R86US*3L-"B`@("`@("`@)'1H:7,M/E]I<U9A
M;&ED(#T@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@5F%L:61A
M=&EO;B!W87)N:6YG+B`@1&]E<R!N;W0@;6%R:R!T:&4@;V)J96-T(&-O;G1E
M;G1S(&EN=F%L:60N#0H@("`@("H@0'!A<F%M(&5R<F]R(&-O9&4-"B`@("`@
M*B!`<&%R86T@87)R87D@97)R;W(@:6YF;W)M871I;VX-"B`@("`@*B!`86-C
M97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?=F%L:61A=&57
M87)N:6YG*"1C;V1E+"`D<&%R86US(#T@87)R87DH*2D-"B`@("![#0H@("`@
M("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H)&-O9&4L("=W87)N:6YG)RP@)'!A
M<F%M<RD[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@5F%L:61A=&4@<&%R
M<V5D(&9I;&4N#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@
M("`J($!R971U<FX@8F]O;&5A;@T*("`@("`J+PT*("`@(&9U;F-T:6]N('9A
M;&ED871E*"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`]('1R
M=64[#0H@("`@("`@("1I;F9O(#T@)'1H:7,M/E]C:&%N;F5L26YF;SL-"B`@
M("`@("`@:68@*&5M<'1Y*"1I;F9O6R=N86UE)UTI*2![#0H@("`@("`@("`@
M("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]#2$%.3D5,1DE,15]%4E)/
M4E].3U].04U%*3L-"B`@("`@("`@?2!E;'-E:68@*"$D=&AI<RT^=F%L:61#
M:&%N;F5L4V5R=F5R*"1I;F9O6R=N86UE)UTI*2![#0H@("`@("`@("`@("!I
M9B`H)&EN9F];)VYA;64G72`A/2`G7U]U<FDG*2![#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?0TA!3DY%3$9)3$5?15)2
M3U)?24Y604Q)1%].04U%+"!A<G)A>2@G=&%G)R`]/B`G;F%M92<L#0H@("`@
M("`@("`@("`@("`@("`@("=N86UE)R`]/B`D:6YF;ULG;F%M92==*2D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&5M<'1Y*"1I
M;F9O6R=S=6UM87)Y)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W9A;&ED
M871E17)R;W(H4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U]354U-05)9*3L-
M"B`@("`@("`@?2!E;'-E:68@*'-T<G!O<RAT<FEM*"1I;F9O6R=S=6UM87)Y
M)UTI+"`B7&XB*2`A/3T@9F%L<V4I('L-"B`@("`@("`@("`@("1T:&ES+3Y?
M=F%L:61A=&5787)N:6YG*%!%05)?0TA!3DY%3$9)3$5?15)23U)?355,5$E,
M24Y%7U-534U!4EDL#0H@("`@("`@("`@("`@("`@87)R87DH)W-U;6UA<GDG
M(#T^("1I;F9O6R=S=6UM87)Y)UTI*3L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H:7-S970H)&EN9F];)W-U9V=E<W1E9&%L:6%S)UTI*2![#0H@("`@("`@
M("`@("!I9B`H(21T:&ES+3YV86QI9$-H86YN96Q397)V97(H)&EN9F];)W-U
M9V=E<W1E9&%L:6%S)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]V
M86QI9&%T945R<F]R*%!%05)?0TA!3DY%3$9)3$5?15)23U)?24Y604Q)1%].
M04U%+`T*("`@("`@("`@("`@("`@("`@("!A<G)A>2@G=&%G)R`]/B`G<W5G
M9V5S=&5D86QI87,G+"`G;F%M92<@/3XD:6YF;ULG<W5G9V5S=&5D86QI87,G
M72DI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI
M<W-E="@D:6YF;ULG;&]C86QA;&EA<R==*2D@>PT*("`@("`@("`@("`@:68@
M*"$D=&AI<RT^=F%L:61#:&%N;F5L4V5R=F5R*"1I;F9O6R=L;V-A;&%L:6%S
M)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R
M*%!%05)?0TA!3DY%3$9)3$5?15)23U)?24Y604Q)1%].04U%+`T*("`@("`@
M("`@("`@("`@("`@("!A<G)A>2@G=&%G)R`]/B`G;&]C86QA;&EA<R<L("=N
M86UE)R`]/B1I;F9O6R=L;V-A;&%L:6%S)UTI*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&EN9F];)W9A;&ED871E
M<&%C:V%G92==*2D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D:6YF;ULG
M=F%L:61A=&5P86-K86=E)UU;)U]C;VYT96YT)UTI*2![#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?0TA!3DY%3$9)3$5?
M15)23U)?3D]604Q)1$%415].04U%*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("@A:7-S970H)&EN9F];)W9A;&ED871E<&%C:V%G92==6R=A
M='1R:6)S)UU;)W9E<G-I;VXG72DI('L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7W9A;&ED871E17)R;W(H4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U9!
M3$E$051%7U9%4E-)3TXL#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=P
M86-K86=E)R`]/B!`)&EN9F];)W9A;&ED871E<&%C:V%G92==6R=?8V]N=&5N
M="==*2D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&ES<V5T*"1I;F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LG871T<FEB<R==
M6R=P;W)T)UTI("8F#0H@("`@("`@("`@("`@("%I<U]N=6UE<FEC*"1I;F9O
M6R=S97)V97)S)UU;)W!R:6UA<GDG75LG871T<FEB<R==6R=P;W)T)UTI*2![
M#0H@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]#2$%.
M3D5,1DE,15]%4E)/4E])3E9!3$E$7U!/4E0L#0H@("`@("`@("`@("`@("`@
M87)R87DH)W!O<G0G(#T^("1I;F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LG
M871T<FEB<R==6R=P;W)T)UTI*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M:7-S970H)&EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R=A='1R:6)S)UU;
M)W-S;"==*2`F)@T*("`@("`@("`@("`@("`D:6YF;ULG<V5R=F5R<R==6R=P
M<FEM87)Y)UU;)V%T=')I8G,G75LG<W-L)UT@(3T@)WEE<R<I('L-"B`@("`@
M("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27T-(04Y.14Q&24Q%
M7T524D]27TE.5D%,241?4U-,+`T*("`@("`@("`@("`@("`@(&%R<F%Y*"=S
M<VPG(#T^("1I;F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LG871T<FEB<R==
M6R=S<VPG72P-"B`@("`@("`@("`@("`@("`@("`@)W-E<G9E<B<@/3X@)&EN
M9F];)VYA;64G72DI.PT*("`@("`@("!]#0H-"B`@("`@("`@:68@*&ES<V5T
M*"1I;F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LG>&UL<G!C)UTI("8F#0H@
M("`@("`@("`@("`@(&ES<V5T*"1I;F9O6R=S97)V97)S)UU;)W!R:6UA<GDG
M75LG>&UL<G!C)UU;)V9U;F-T:6]N)UTI*2![#0H@("`@("`@("`@("`D=&AI
M<RT^7W9A;&ED871E1G5N8W1I;VYS*"=X;6QR<&,G+"`D:6YF;ULG<V5R=F5R
M<R==6R=P<FEM87)Y)UU;)WAM;')P8R==6R=F=6YC=&EO;B==*3L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H:7-S970H)&EN9F];)W-E<G9E<G,G75LG<')I
M;6%R>2==6R=S;V%P)UTI("8F#0H@("`@("`@("`@("`@(&ES<V5T*"1I;F9O
M6R=S97)V97)S)UU;)W!R:6UA<GDG75LG<V]A<"==6R=F=6YC=&EO;B==*2D@
M>PT*("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T949U;F-T:6]N<R@G<V]A
M<"<L("1I;F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LG<V]A<"==6R=F=6YC
M=&EO;B==*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&EN9F];
M)W-E<G9E<G,G75LG<')I;6%R>2==6R=R97-T)UTI("8F#0H@("`@("`@("`@
M("`@(&ES<V5T*"1I;F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LG<F5S="==
M6R=B87-E=7)L)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E
M1G5N8W1I;VYS*"=R97-T)RP@)&EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==
M6R=R97-T)UU;)V)A<V5U<FPG72D[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&ES<V5T*"1I;F9O6R=S97)V97)S)UU;)VUI<G)O<B==*2D@>PT*("`@("`@
M("`@("`@:68@*"1T:&ES+3Y?8VAA;FYE;$EN9F];)VYA;64G72`]/2`G7U]U
M<FDG*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R
M*%!%05)?0TA!3DY%3$9)3$5?55))7T-!3E1?34E24D]2*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&EF("@A:7-S970H)&EN9F];)W-E<G9E<G,G
M75LG;6ER<F]R)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@)&EN9F];)W-E
M<G9E<G,G75LG;6ER<F]R)UT@/2!A<G)A>2@D:6YF;ULG<V5R=F5R<R==6R=M
M:7)R;W(G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D:2`](#`[
M#0H@("`@("`@("`@("!F;W)E86-H("@D:6YF;ULG<V5R=F5R<R==6R=M:7)R
M;W(G72!A<R`D;6ER<F]R*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D;6ER<F]R6R=A='1R:6)S)UU;)VAO<W0G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?0TA!3DY%3$9)
M3$5?15)23U)?3D]?2$]35"P-"B`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G='EP92<@/3X@)VUI<G)O<B<I*3L-"B`@("`@("`@("`@("`@("!](&5L
M<V5I9B`H(21T:&ES+3YV86QI9$-H86YN96Q397)V97(H)&UI<G)O<ELG871T
M<FEB<R==6R=H;W-T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?=F%L:61A=&5%<G)O<BA014%27T-(04Y.14Q&24Q%7T524D]27TE.5D%,
M241?2$]35"P-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=S97)V
M97(G(#T^("1M:7)R;W);)V%T=')I8G,G75LG:&]S="==+"`G='EP92<@/3X@
M)VUI<G)O<B<I*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1M:7)R;W);)V%T=')I8G,G75LG<W-L)UTI("8F("1M
M:7)R;W);)V%T=')I8G,G75LG<W-L)UT@(3T@)WEE<R<I('L-"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?0TA!3DY%
M3$9)3$5?15)23U)?24Y604Q)1%]34TPL#0H@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@G<W-L)R`]/B`D:6YF;ULG<W-L)UTL("=S97)V97(G(#T^
M("1M:7)R;W);)V%T=')I8G,G75LG:&]S="==*2D[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D;6ER<F]R6R=X;6QR
M<&,G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T
M949U;F-T:6]N<R@G>&UL<G!C)RP-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1M:7)R;W);)WAM;')P8R==6R=F=6YC=&EO;B==+"`D;6ER<F]R6R=A='1R
M:6)S)UU;)VAO<W0G72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D;6ER<F]R6R=S;V%P)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5&=6YC=&EO;G,H)W-O87`G
M+"`D;6ER<F]R6R=S;V%P)UU;)V9U;F-T:6]N)UTL#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D;6ER<F]R6R=A='1R:6)S)UU;)VAO<W0G72D[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D;6ER
M<F]R6R=R97-T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M=F%L:61A=&5&=6YC=&EO;G,H)W)E<W0G+"`D;6ER<F]R6R=R97-T)UU;)V)A
M<V5U<FPG72P-"B`@("`@("`@("`@("`@("`@("`@("`@("1M:7)R;W);)V%T
M=')I8G,G75LG:&]S="==*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?:7-6
M86QI9#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG
M('AM;')P8R!O<B!S;V%P("T@<')O=&]C;VP@;F%M92!T:&ES(&9U;F-T:6]N
M(&%P<&QI97,@=&\-"B`@("`@*B!`<&%R86T@87)R87D@=&AE(&9U;F-T:6]N
M<PT*("`@("`J($!P87)A;2!S=')I;F<@=&AE(&YA;64@;V8@=&AE('!A<F5N
M="!E;&5M96YT("AM:7)R;W(@;F%M92P@9F]R(&EN<W1A;F-E*0T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(%]V86QI9&%T949U;F-T:6]N<R@D<')O=&]C;VPL
M("1F=6YC=&EO;G,L("1P87)E;G0@/2`G)RD-"B`@("![#0H@("`@("`@(&EF
M("@A:7-S970H)&9U;F-T:6]N<ULP72DI('L-"B`@("`@("`@("`@("1F=6YC
M=&EO;G,@/2!A<G)A>2@D9G5N8W1I;VYS*3L-"B`@("`@("`@?0T*("`@("`@
M("!F;W)E86-H("@D9G5N8W1I;VYS(&%S("1F=6YC=&EO;BD@>PT*("`@("`@
M("`@("`@:68@*"%I<W-E="@D9G5N8W1I;VY;)U]C;VYT96YT)UTI('Q\(&5M
M<'1Y*"1F=6YC=&EO;ELG7V-O;G1E;G0G72DI('L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]#2$%.3D5,1DE,15]%4E)/
M4E].3U]&54Y#5$E/3DY!344L#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=P87)E;G0G(#T^("1P87)E;G0L("=P<F]T;V-O;"<@/3X@)'!R;W1O8V]L
M*2D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)'!R;W1O8V]L
M(#T]("=R97-T)RD@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&9U
M;F-T:6]N6R=A='1R:6)S)UU;)W1Y<&4G72D@?'P-"B`@("`@("`@("`@("`@
M("`@("`@("!E;7!T>2@D9G5N8W1I;VY;)V%T=')I8G,G75LG='EP92==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H
M4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U]"05-%55),5%E012P-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=P87)E;G0G(#T^("1P87)E;G0L
M("=P<F]T;V-O;"<@/3X@)'!R;W1O8V]L*2D[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1F=6YC=&EO;ELG871T<FEB<R==6R=V97)S:6]N)UTI('Q\#0H@
M("`@("`@("`@("`@("`@("`@("`@96UP='DH)&9U;F-T:6]N6R=A='1R:6)S
M)UU;)W9E<G-I;VXG72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]V86QI9&%T945R<F]R*%!%05)?0TA!3DY%3$9)3$5?15)23U)?3D]?1E5.
M0U1)3TY615)324].+`T*("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)W!A<F5N="<@/3X@)'!A<F5N="P@)W!R;W1O8V]L)R`]/B`D<')O=&]C;VPI
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!497-T('=H971H97(@82!S
M=')I;F<@8V]N=&%I;G,@82!V86QI9"!C:&%N;F5L('-E<G9E<BX-"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1V97(@=&AE('!A8VMA9V4@=F5R<VEO;B!T;R!T
M97-T#0H@("`@("H@0')E='5R;B!B;V]L#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@=F%L:61#:&%N;F5L4V5R=F5R*"1S97)V97(I#0H@("`@>PT*("`@("`@
M("!I9B`H)'-E<G9E<B`]/2`G7U]U<FDG*2![#0H@("`@("`@("`@("!R971U
M<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@*&)O;VPI('!R
M96=?;6%T8V@H4$5!4E]#2$%.3D5,4U]315)615)?4%)%1RP@)'-E<G9E<BD[
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0')E='5R;B!S=')I;F=\9F%L
M<V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971.86UE*"D-"B`@("![#0H@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-H86YN96Q);F9O6R=N86UE)UTI
M*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]C:&%N;F5L26YF;ULG
M;F%M92==.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M0')E='5R;B!S=')I;F=\9F%L<V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G
M971397)V97(H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M8VAA;FYE;$EN9F];)VYA;64G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7V-H86YN96Q);F9O6R=N86UE)UT[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N(&EN='PX,"!P;W)T(&YU;6)E
M<B!T;R!C;VYN96-T('1O#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T4&]R
M="@D;6ER<F]R(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H)&UI<G)O
M<BD@>PT*("`@("`@("`@("`@:68@*"1M:7(@/2`D=&AI<RT^9V5T36ER<F]R
M*"1M:7)R;W(I*2![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1M:7);
M)V%T=')I8G,G75LG<&]R="==*2D@>PT*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)&UI<ELG871T<FEB<R==6R=P;W)T)UT[#0H@("`@("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YG
M97134TPH)&UI<G)O<BDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`T-#,[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(#@P.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R
M=F5R<R==6R=P<FEM87)Y)UU;)V%T=')I8G,G75LG<&]R="==*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G
M75LG<')I;6%R>2==6R=A='1R:6)S)UU;)W!O<G0G73L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H)'1H:7,M/F=E=%-33"@I*2![#0H@("`@("`@("`@("!R
M971U<FX@-#0S.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`X,#L-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N(&)O;VP@1&5T97)M:6YE
M<R!W:&5T:&5R('-E8W5R92!S;V-K971S(&QA>65R("A34TPI(&ES('5S960@
M=&\@8V]N;F5C="!T;R!T:&ES(&-H86YN96P-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!G97134TPH)&UI<G)O<B`](&9A;'-E*0T*("`@('L-"B`@("`@("`@
M:68@*"1M:7)R;W(I('L-"B`@("`@("`@("`@(&EF("@D;6ER(#T@)'1H:7,M
M/F=E=$UI<G)O<B@D;6ER<F]R*2D@>PT*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D;6ER6R=A='1R:6)S)UU;)W-S;"==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7V-H86YN96Q);F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LG871T<FEB<R==
M6R=S<VPG72DI('L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!`<F5T=7)N('-T<FEN9WQF86QS90T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(&=E=%-U;6UA<GDH*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-U;6UA<GDG72DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7V-H86YN96Q);F9O6R=S=6UM87)Y)UT[#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R
M:6YG('AM;')P8R!O<B!S;V%P#0H@("`@("H@0'!A<F%M('-T<FEN9WQF86QS
M92!M:7)R;W(@;F%M92!O<B!F86QS92!F;W(@<')I;6%R>2!S97)V97(-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!G9710871H*"1P<F]T;V-O;"P@)&UI<G)O
M<B`](&9A;'-E*0T*("`@('L@("`-"B`@("`@("`@:68@*"%I;E]A<G)A>2@D
M<')O=&]C;VPL(&%R<F%Y*"=X;6QR<&,G+"`G<V]A<"<I*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M;6ER<F]R*2![#0H@("`@("`@("`@("!I9B`H(2@D;6ER(#T@)'1H:7,M/F=E
M=$UI<G)O<B@D;6ER<F]R*2DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H
M)&UI<ELD<')O=&]C;VQ=6R=A='1R:6)S)UU;)W!A=&@G72DI('L-"B`@("`@
M("`@("`@("`@("!R971U<FX@)&UI<ELD<')O=&]C;VQ=6R=A='1R:6)S)UU;
M)W!A=&@G73L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@<F5T=7)N("1P<F]T;V-O;"`N("<N<&AP)SL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];
M)W-E<G9E<G,G75LG<')I;6%R>2==6R1P<F]T;V-O;%U;)V%T=')I8G,G75LG
M<&%T:"==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8VAA;FYE
M;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R1P<F]T;V-O;%U;)V%T=')I
M8G,G75LG<&%T:"==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<')O
M=&]C;VP@+B`G+G!H<"<[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A
M<F%M('-T<FEN9R!P<F]T;V-O;"!T>7!E("AX;6QR<&,L('-O87`I#0H@("`@
M("H@0'!A<F%M('-T<FEN9R!-:7)R;W(@;F%M90T*("`@("`J($!R971U<FX@
M87)R87E\9F%L<V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971&=6YC=&EO
M;G,H)'!R;W1O8V]L+"`D;6ER<F]R(#T@9F%L<V4I#0H@("`@>PT*("`@("`@
M("!I9B`H)'1H:7,M/F=E=$YA;64H*2`]/2`G7U]U<FDG*2![#0H@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1P
M<F]T;V-O;"`]/2`G<F5S="<I('L-"B`@("`@("`@("`@("1F=6YC=&EO;B`]
M("=B87-E=7)L)SL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1F
M=6YC=&EO;B`]("=F=6YC=&EO;B<[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"1M:7)R;W(I('L-"B`@("`@("`@("`@(&EF("@D;6ER(#T@)'1H:7,M/F=E
M=$UI<G)O<B@D;6ER<F]R*2D@>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D;6ER6R1P<F]T;V-O;%U;)&9U;F-T:6]N72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1M:7);)'!R;W1O8V]L75LD9G5N8W1I;VY=.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)'!R
M;W1O8V]L75LD9G5N8W1I;VY=*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R1P<F]T
M;V-O;%U;)&9U;F-T:6]N73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J
M*@T*("`@("`J($!P87)A;2!S=')I;F<@4')O=&]C;VP@='EP90T*("`@("`J
M($!P87)A;2!S=')I;F<@1G5N8W1I;VX@;F%M92`H;G5L;"!T;R!R971U<FX@
M=&AE#0H@("`@("H@("`@("`@("`@("`@("!F:7)S="!P<F]T;V-O;"!O9B!T
M:&4@='EP92!R97%U97-T960I#0H@("`@("H@0'!A<F%M('-T<FEN9R!-:7)R
M;W(@;F%M92P@:68@86YY#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@("`J
M+PT*("`@("!F=6YC=&EO;B!G971&=6YC=&EO;B@D='EP92P@)&YA;64@/2!N
M=6QL+"`D;6ER<F]R(#T@9F%L<V4I#0H@("`@('L-"B`@("`@("`@)'!R;W1O
M8V]L<R`]("1T:&ES+3YG971&=6YC=&EO;G,H)'1Y<&4L("1M:7)R;W(I.PT*
M("`@("`@("!I9B`H(21P<F]T;V-O;',I('L-"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D<')O=&]C
M;VQS(&%S("1P<F]T;V-O;"D@>PT*("`@("`@("`@("`@:68@*"1N86UE(#T]
M/2!N=6QL*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1P<F]T;V-O;#L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D<')O=&]C;VQ;)U]C
M;VYT96YT)UT@(3T@)&YA;64I('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D<')O=&]C
M;VP[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG('!R;W1O8V]L('1Y
M<&4-"B`@("`@*B!`<&%R86T@<W1R:6YG('!R;W1O8V]L(&YA;64-"B`@("`@
M*B!`<&%R86T@<W1R:6YG('9E<G-I;VX-"B`@("`@*B!`<&%R86T@<W1R:6YG
M(&UI<G)O<B!N86UE#0H@("`@("H@0')E='5R;B!B;V]L96%N#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@<W5P<&]R=',H)'1Y<&4L("1N86UE(#T@;G5L;"P@
M)&UI<G)O<B`](&9A;'-E+"`D=F5R<VEO;B`]("<Q+C`G*0T*("`@('L-"B`@
M("`@("`@)'!R;W1O8V]L<R`]("1T:&ES+3YG971&=6YC=&EO;G,H)'1Y<&4L
M("1M:7)R;W(I.PT*("`@("`@("!I9B`H(21P<F]T;V-O;',I('L-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!F;W)E
M86-H("@D<')O=&]C;VQS(&%S("1P<F]T;V-O;"D@>PT*("`@("`@("`@("`@
M:68@*"1P<F]T;V-O;%LG871T<FEB<R==6R=V97)S:6]N)UT@(3T@)'9E<G-I
M;VXI('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF("@D;F%M92`]/3T@;G5L;"D@>PT*("`@("`@
M("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@:68@*"1P<F]T;V-O;%LG7V-O;G1E;G0G72`A/2`D;F%M92D@>PT*
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($1E=&5R;6EN
M97,@=VAE=&AE<B!A(&-H86YN96P@<W5P<&]R=',@4F5P<F5S96YT871I;VYA
M;"!3=&%T92!4<F%N<V9E<B`H4D535"D@<')O=&]C;VQS#0H@("`@("H@9F]R
M(')E=')I979I;F<@8VAA;FYE;"!I;F9O<FUA=&EO;@T*("`@("`J($!P87)A
M;2!S=')I;F<-"B`@("`@*B!`<F5T=7)N(&)O;VP-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!S=7!P;W)T<U)%4U0H)&UI<G)O<B`](&9A;'-E*0T*("`@('L-
M"B`@("`@("`@:68@*"1M:7)R;W(@/3T@)'1H:7,M/E]C:&%N;F5L26YF;ULG
M;F%M92==*2![#0H@("`@("`@("`@("`D;6ER<F]R(#T@9F%L<V4[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"1M:7)R;W(I('L-"B`@("`@("`@("`@(&EF
M("@D;6ER(#T@)'1H:7,M/F=E=$UI<G)O<B@D;6ER<F]R*2D@>PT*("`@("`@
M("`@("`@("`@(')E='5R;B!I<W-E="@D;6ER6R=R97-T)UTI.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7V-H86YN96Q);F9O6R=S
M97)V97)S)UU;)W!R:6UA<GDG75LG<F5S="==*3L-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!'970@=&AE(%523"!T;R!A8V-E<W,@82!B87-E(')E<V]U
M<F-E+@T*("`@("`J#0H@("`@("H@2'EP97)L:6YK<R!I;B!T:&4@<F5T=7)N
M960@>&UL('=I;&P@8F4@=7-E9"!T;R!R971R:65V92!T:&4@<')O<&5R(&EN
M9F]R;6%T:6]N#0H@("`@("H@;F5E9&5D+B`@5&AI<R!A;&QO=W,@97AT<F5M
M92!E>'1E;G-I8FEL:71Y(&%N9"!F;&5X:6)I;&ET>2!I;B!I;7!L96UE;G1A
M=&EO;@T*("`@("`J($!P87)A;2!S=')I;F<@4F5S;W5R8V4@5'EP92!T;R!R
M971R:65V90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$)A<V554DPH)')E
M<V]U<F-E5'EP92P@)&UI<G)O<B`](&9A;'-E*0T*("`@('L-"B`@("`@("`@
M:68@*"1M:7)R;W(@/3T@)'1H:7,M/E]C:&%N;F5L26YF;ULG;F%M92==*2![
M#0H@("`@("`@("`@("`D;6ER<F]R(#T@9F%L<V4[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"1M:7)R;W(I('L-"B`@("`@("`@("`@(&EF("@D;6ER(#T@
M)'1H:7,M/F=E=$UI<G)O<B@D;6ER<F]R*2D@>PT*("`@("`@("`@("`@("`@
M("1R97-T(#T@)&UI<ELG<F5S="==.PT*("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`D<V5R=F5R(#T@)&UI<G)O<CL-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("1R97-T(#T@)'1H:7,M/E]C:&%N;F5L26YF
M;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)W)E<W0G73L-"B`@("`@("`@("`@
M("1S97)V97(@/2`D=&AI<RT^9V5T4V5R=F5R*"D[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"%I<W-E="@D<F5S=%LG8F%S975R;"==6S!=*2D@>PT*("`@
M("`@("`@("`@)')E<W1;)V)A<V5U<FPG72`](&%R<F%Y*"1R97-T6R=B87-E
M=7)L)UTI.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1R97-T6R=B
M87-E=7)L)UT@87,@)&)A<V5U<FPI('L-"B`@("`@("`@("`@(&EF("AS=')T
M;VQO=V5R*"1B87-E=7)L6R=A='1R:6)S)UU;)W1Y<&4G72D@/3T@<W1R=&]L
M;W=E<B@D<F5S;W5R8V54>7!E*2D@>PT*("`@("`@("`@("`@("`@(')E='5R
M;B`D8F%S975R;%LG7V-O;G1E;G0G73L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@4VEN8V4@4D535"!D;V5S(&YO="!I;7!L96UE;G0@4E!#+"!P
M<F]V:61E('1H:7,@87,@82!L;V=I8V%L('=R87!P97(@87)O=6YD#0H@("`@
M("H@<F5S971&=6YC=&EO;G,@9F]R(%)%4U0-"B`@("`@*B!`<&%R86T@<W1R
M:6YG?&9A;'-E(&UI<G)O<B!N86UE+"!I9B!A;GD-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!R97-E=%)%4U0H)&UI<G)O<B`](&9A;'-E*0T*("`@('L-"B`@
M("`@("`@<F5T=7)N("1T:&ES+3YR97-E=$9U;F-T:6]N<R@G<F5S="<L("1M
M:7)R;W(I.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($5M<'1Y(&%L;"!P
M<F]T;V-O;"!D969I;FET:6]N<PT*("`@("`J($!P87)A;2!S=')I;F<@<')O
M=&]C;VP@='EP92`H>&UL<G!C+"!S;V%P*0T*("`@("`J($!P87)A;2!S=')I
M;F=\9F%L<V4@;6ER<F]R(&YA;64L(&EF(&%N>0T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(')E<V5T1G5N8W1I;VYS*"1T>7!E+"`D;6ER<F]R(#T@9F%L<V4I
M#0H@("`@>PT*("`@("`@("!I9B`H)&UI<G)O<BD@>PT*("`@("`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER
M<F]R)UTI*2![#0H@("`@("`@("`@("`@("`@)&UI<G)O<G,@/2`D=&AI<RT^
M7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==.PT*("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)&UI<G)O<G-;,%TI*2![#0H@("`@("`@("`@
M("`@("`@("`@("1M:7)R;W)S(#T@87)R87DH)&UI<G)O<G,I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D;6ER<F]R
M<R!A<R`D:2`]/B`D;6ER*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@D
M;6ER6R=A='1R:6)S)UU;)VAO<W0G72`]/2`D;6ER<F]R*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C:&%N;F5L26YF
M;ULG<V5R=F5R<R==6R=M:7)R;W(G75LD:5U;)'1Y<&5=*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?8VAA;FYE;$EN
M9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;)&E=6R1T>7!E72D[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FX@=')U93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;
M)W!R:6UA<GDG75LD='EP95TI*2![#0H@("`@("`@("`@("`@("`@=6YS970H
M)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)'1Y
M<&5=*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4V5T(&$@
M8VAA;FYE;"=S('!R;W1O8V]L<R!T;R!T:&4@<')O=&]C;VQS('-U<'!O<G1E
M9"!B>2!P96%R=V5B#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T1&5F875L
M=%!%05)0<F]T;V-O;',H)'9E<G-I;VX@/2`G,2XP)RP@)&UI<G)O<B`](&9A
M;'-E*0T*("`@('L-"B`@("`@("`@<W=I=&-H("@D=F5R<VEO;BD@>PT*("`@
M("`@("`@("`@8V%S92`G,2XP)R`Z#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/G)E<V5T1G5N8W1I;VYS*"=X;6QR<&,G+"`D;6ER<F]R*3L-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^<F5S971&=6YC=&EO;G,H)W-O87`G+"`D;6ER<F]R
M*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^<F5S971215-4*"1M:7)R;W(I
M.PT*("`@("`@("`@("`@("`@("1T:&ES+3YA9&1&=6YC=&EO;B@G>&UL<G!C
M)RP@)S$N,"<L("=L;V=I;G1E<W0G+"`D;6ER<F]R*3L-"B`@("`@("`@("`@
M("`@("`D=&AI<RT^861D1G5N8W1I;VXH)WAM;')P8R<L("<Q+C`G+"`G<&%C
M:V%G92YL:7-T3&%T97-T4F5L96%S97,G+"`D;6ER<F]R*3L-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^861D1G5N8W1I;VXH)WAM;')P8R<L("<Q+C`G+"`G
M<&%C:V%G92YL:7-T06QL)RP@)&UI<G)O<BD[#0H@("`@("`@("`@("`@("`@
M)'1H:7,M/F%D9$9U;F-T:6]N*"=X;6QR<&,G+"`G,2XP)RP@)W!A8VMA9V4N
M:6YF;R<L("1M:7)R;W(I.PT*("`@("`@("`@("`@("`@("1T:&ES+3YA9&1&
M=6YC=&EO;B@G>&UL<G!C)RP@)S$N,"<L("=P86-K86=E+F=E=$1O=VYL;V%D
M55),)RP@)&UI<G)O<BD[#0H@("`@("`@("`@("`@("`@)'1H:7,M/F%D9$9U
M;F-T:6]N*"=X;6QR<&,G+"`G,2XQ)RP@)W!A8VMA9V4N9V5T1&]W;FQO8615
M4DPG+"`D;6ER<F]R*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^861D1G5N
M8W1I;VXH)WAM;')P8R<L("<Q+C`G+"`G<&%C:V%G92YG971$97!$;W=N;&]A
M9%523"<L("1M:7)R;W(I.PT*("`@("`@("`@("`@("`@("1T:&ES+3YA9&1&
M=6YC=&EO;B@G>&UL<G!C)RP@)S$N,2<L("=P86-K86=E+F=E=$1E<$1O=VYL
M;V%D55),)RP@)&UI<G)O<BD[#0H@("`@("`@("`@("`@("`@)'1H:7,M/F%D
M9$9U;F-T:6]N*"=X;6QR<&,G+"`G,2XP)RP@)W!A8VMA9V4N<V5A<F-H)RP@
M)&UI<G)O<BD[#0H@("`@("`@("`@("`@("`@)'1H:7,M/F%D9$9U;F-T:6]N
M*"=X;6QR<&,G+"`G,2XP)RP@)V-H86YN96PN;&ES=$%L;"<L("1M:7)R;W(I
M.PT*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@("`@("!D969A=6QT(#H-"B`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M?0T*("`@('T-"B`@("`-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T36ER<F]R<R@I#0H@("`@>PT*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R
M<R==6R=M:7)R;W(G72DI('L-"B`@("`@("`@("`@("1M:7)R;W)S(#T@)'1H
M:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G73L-"B`@("`@
M("`@("`@(&EF("@A:7-S970H)&UI<G)O<G-;,%TI*2![#0H@("`@("`@("`@
M("`@("`@)&UI<G)O<G,@/2!A<G)A>2@D;6ER<F]R<RD[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!R971U<FX@)&UI<G)O<G,[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("!R971U<FX@87)R87DH*3L-"B`@("`@("`@
M?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@=6YS97)I86QI
M>F5D(%A-3"!R97!R97-E;G1I;F<@82!M:7)R;W(-"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y?&9A;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T36ER<F]R
M*"1S97)V97(I#0H@("`@>PT*("`@("`@("!F;W)E86-H("@D=&AI<RT^9V5T
M36ER<F]R<R@I(&%S("1M:7)R;W(I('L-"B`@("`@("`@("`@(&EF("@D;6ER
M<F]R6R=A='1R:6)S)UU;)VAO<W0G72`]/2`D<V5R=F5R*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N("1M:7)R;W([#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B!`<F5T=7)N('-T<FEN
M9WQF86QS90T*("`@("`J($!E<G)O<B!014%27T-(04Y.14Q&24Q%7T524D]2
M7TY/7TY!344-"B`@("`@*B!`97)R;W(@4$5!4E]#2$%.3D5,1DE,15]%4E)/
M4E])3E9!3$E$7TY!344-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971.86UE
M*"1N86UE*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YS971397)V
M97(H)&YA;64I.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%-E="!T:&4@
M<V]C:V5T(&YU;6)E<B`H<&]R="D@=&AA="!I<R!U<V5D('1O(&-O;FYE8W0@
M=&\@=&AI<R!C:&%N;F5L#0H@("`@("H@0'!A<F%M(&EN=&5G97(-"B`@("`@
M*B!`<&%R86T@<W1R:6YG?&9A;'-E(&YA;64@;V8@=&AE(&UI<G)O<B!S97)V
M97(L(&]R(&9A;'-E(&9O<B!T:&4@<')I;6%R>0T*("`@("`J+PT*("`@(&9U
M;F-T:6]N('-E=%!O<G0H)'!O<G0L("1M:7)R;W(@/2!F86QS92D-"B`@("![
M#0H@("`@("`@(&EF("@D;6ER<F]R*2![#0H@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UTI
M*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%
M05)?0TA!3DY%3$9)3$5?15)23U)?34E24D]27TY/5%]&3U5.1"P-"B`@("`@
M("`@("`@("`@("`@("`@87)R87DH)VUI<G)O<B<@/3X@)&UI<G)O<BDI.PT*
M("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1S971M:7)R;W(@/2!F86QS93L-"B`@("`@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI
M<G)O<B==6S!=*2D@>PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UT@87,@)&D@/3X@
M)&UI<BD@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)&UI<G)O<B`]/2`D
M;6ER6R=A='1R:6)S)UU;)VAO<W0G72D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G
M75LD:5U;)V%T=')I8G,G75LG<&]R="==(#T@)'!O<G0[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@("`@("!](&5L<V5I9B`H)'1H:7,M/E]C:&%N
M;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G75LG871T<FEB<R==6R=H;W-T
M)UT@/3T@)&UI<G)O<BD@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAA
M;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;)V%T=')I8G,G75LG<&]R
M="==(#T@)'!O<G0[#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]I<U9A;&ED
M(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]C:&%N;F5L
M26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)V%T=')I8G,G75LG<&]R="==
M(#T@)'!O<G0[#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](&9A;'-E.PT*
M("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!3970@=&AE('-O8VME="!N=6UB97(@*'!O<G0I('1H870@:7,@=7-E9"!T
M;R!C;VYN96-T('1O('1H:7,@8VAA;FYE;`T*("`@("`J($!P87)A;2!B;V]L
M($1E=&5R;6EN97,@=VAE=&AE<B!T;R!T=7)N(&]N(%-33"!S=7!P;W)T(&]R
M('1U<FX@:70@;V9F#0H@("`@("H@0'!A<F%M('-T<FEN9WQF86QS92!N86UE
M(&]F('1H92!M:7)R;W(@<V5R=F5R+"!O<B!F86QS92!F;W(@=&AE('!R:6UA
M<GD-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S97134TPH)'-S;"`]('1R=64L
M("1M:7)R;W(@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@D;6ER<F]R
M*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN
M9F];)W-E<G9E<G,G75LG;6ER<F]R)UTI*2![#0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?0TA!3DY%3$9)3$5?15)23U)?
M34E24D]27TY/5%]&3U5.1"P-"B`@("`@("`@("`@("`@("`@("`@87)R87DH
M)VUI<G)O<B<@/3X@)&UI<G)O<BDI.PT*("`@("`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1S971M:7)R
M;W(@/2!F86QS93L-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-H
M86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==6S!=*2D@>PT*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E
M<G,G75LG;6ER<F]R)UT@87,@)&D@/3X@)&UI<BD@>PT*("`@("`@("`@("`@
M("`@("`@("!I9B`H)&UI<G)O<B`]/2`D;6ER6R=A='1R:6)S)UU;)VAO<W0G
M72D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"$D<W-L*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;)&E=#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@6R=A='1R:6)S)UU;)W-S;"==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D
M=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==6R1I75LG
M871T<FEB<R==6R=S<VPG72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-H86YN96Q);F9O6R=S
M97)V97)S)UU;)VUI<G)O<B==6R1I75LG871T<FEB<R==6R=S<VPG72`]("=Y
M97,G.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?8VAA;FYE
M;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;)V%T=')I8G,G75LG:&]S="==
M(#T]("1M:7)R;W(I('L-"B`@("`@("`@("`@("`@("!I9B`H(21S<VPI('L-
M"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8VAA;FYE
M;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;)V%T=')I8G,G75LG<W-L)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^7V-H
M86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==6R=A='1R:6)S)UU;)W-S
M;"==*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAA;FYE
M;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;)V%T=')I8G,G75LG<W-L)UT@
M/2`G>65S)SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]I<U9A;&ED(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"1S<VPI('L-"B`@("`@("`@("`@("1T:&ES+3Y?8VAA;FYE;$EN9F];
M)W-E<G9E<G,G75LG<')I;6%R>2==6R=A='1R:6)S)UU;)W-S;"==(#T@)WEE
M<R<[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)V%T
M=')I8G,G75LG<W-L)UTI*2![#0H@("`@("`@("`@("`@("`@=6YS970H)'1H
M:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)V%T=')I
M8G,G75LG<W-L)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@("1T:&ES+3Y?:7-686QI9"`](&9A;'-E.PT*("`@("`@("!R971U<FX@
M=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!3970@=&AE('-O8VME
M="!N=6UB97(@*'!O<G0I('1H870@:7,@=7-E9"!T;R!C;VYN96-T('1O('1H
M:7,@8VAA;FYE;`T*("`@("`J($!P87)A;2!I;G1E9V5R#0H@("`@("H@0'!A
M<F%M('-T<FEN9WQF86QS92!N86UE(&]F('1H92!M:7)R;W(@<V5R=F5R+"!O
M<B!F86QS92!F;W(@=&AE('!R:6UA<GD-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!S9710871H*"1P<F]T;V-O;"P@)'!A=&@L("1M:7)R;W(@/2!F86QS92D-
M"B`@("![#0H@("`@("`@(&EF("@A:6Y?87)R87DH)'!R;W1O8V]L+"!A<G)A
M>2@G>&UL<G!C)RP@)W-O87`G*2DI('L-"B`@("`@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&UI<G)O<BD@>PT*("`@
M("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V
M97)S)UU;)VUI<G)O<B==*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M=F%L:61A=&5%<G)O<BA014%27T-(04Y.14Q&24Q%7T524D]27TU)4E)/4E].
M3U1?1D]53D0L#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=M:7)R;W(G
M(#T^("1M:7)R;W(I*3L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<V5T;6ER<F]R(#T@9F%L
M<V4[#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C:&%N;F5L26YF
M;ULG<V5R=F5R<R==6R=M:7)R;W(G75LP72DI('L-"B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI
M<G)O<B==(&%S("1I(#T^("1M:7(I('L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"1M:7)R;W(@/3T@)&UI<ELG871T<FEB<R==6R=H;W-T)UTI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E
M<G9E<G,G75LG;6ER<F]R)UU;)&E=6R1P<F]T;V-O;%U;)V%T=')I8G,G75LG
M<&%T:"==(#T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%T:#L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27T-(04Y.14Q&24Q%
M7T524D]27TU)4E)/4E].3U1?1D]53D0L#0H@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"=M:7)R;W(G(#T^("1M:7)R;W(I*3L-"B`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!](&5L<V5I9B`H)'1H:7,M
M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G75LG871T<FEB<R==
M6R=H;W-T)UT@/3T@)&UI<G)O<BD@>PT*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;)'!R;W1O8V]L
M75LG871T<FEB<R==6R=P871H)UT@/2`D<&%T:#L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7VES5F%L:60@/2!F86QS93L-"B`@("`@("`@("`@("`@("!R
M971U<FX@=')U93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("`D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LD
M<')O=&]C;VQ=6R=A='1R:6)S)UU;)W!A=&@G72`]("1P871H.PT*("`@("`@
M("`D=&AI<RT^7VES5F%L:60@/2!F86QS93L-"B`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9PT*
M("`@("`J($!R971U<FX@<W1R:6YG?&9A;'-E#0H@("`@("H@0&5R<F]R(%!%
M05)?0TA!3DY%3$9)3$5?15)23U)?3D]?4T525D52#0H@("`@("H@0&5R<F]R
M(%!%05)?0TA!3DY%3$9)3$5?15)23U)?24Y604Q)1%]315)615(-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!S971397)V97(H)'-E<G9E<BP@)&UI<G)O<B`]
M(&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*&5M<'1Y*"1S97)V97(I*2![
M#0H@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]#2$%.
M3D5,1DE,15]%4E)/4E].3U]315)615(I.PT*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("!](&5L<V5I9B`H(21T:&ES+3YV86QI9$-H86YN
M96Q397)V97(H)'-E<G9E<BDI('L-"B`@("`@("`@("`@("1T:&ES+3Y?=F%L
M:61A=&5%<G)O<BA014%27T-(04Y.14Q&24Q%7T524D]27TE.5D%,241?3D%-
M12P-"B`@("`@("`@("`@("`@("!A<G)A>2@G=&%G)R`]/B`G;F%M92<L("=N
M86UE)R`]/B`D<V5R=F5R*2D[#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"1M:7)R;W(I('L-"B`@("`@("`@
M("`@("1F;W5N9"`](&9A;'-E.PT*("`@("`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G72!A<R`D:2`]
M/B`D;6ER*2![#0H@("`@("`@("`@("`@("`@:68@*"1M:7)R;W(@/3T@)&UI
M<ELG871T<FEB<R==6R=H;W-T)UTI('L-"B`@("`@("`@("`@("`@("`@("`@
M)&9O=6YD(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*"$D9F]U;F0I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED
M871E17)R;W(H4$5!4E]#2$%.3D5,1DE,15]%4E)/4E]-25)23U)?3D]47T9/
M54Y$+`T*("`@("`@("`@("`@("`@("`@("!A<G)A>2@G;6ER<F]R)R`]/B`D
M;6ER<F]R*2D[#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)'1H:7,M/E]C:&%N;F5L26YF;ULG
M;6ER<F]R)UU;)&E=6R=A='1R:6)S)UU;)VAO<W0G72`]("1S97)V97([#0H@
M("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("`D
M=&AI<RT^7V-H86YN96Q);F9O6R=N86UE)UT@/2`D<V5R=F5R.PT*("`@("`@
M("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R
M86T@<W1R:6YG#0H@("`@("H@0')E='5R;B!B;V]L96%N('-U8V-E<W,-"B`@
M("`@*B!`97)R;W(@4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U]354U-05)9
M#0H@("`@("H@0'=A<FYI;F<@4$5!4E]#2$%.3D5,1DE,15]%4E)/4E]-54Q4
M24Q)3D5?4U5-34%260T*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=%-U;6UA
M<GDH)'-U;6UA<GDI#0H@("`@>PT*("`@("`@("!I9B`H96UP='DH)'-U;6UA
M<GDI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!
M4E]#2$%.3D5,1DE,15]%4E)/4E].3U]354U-05)9*3L-"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@?2!E;'-E:68@*'-T<G!O<RAT<FEM
M*"1S=6UM87)Y*2P@(EQN(BD@(3T](&9A;'-E*2![#0H@("`@("`@("`@("`D
M=&AI<RT^7W9A;&ED871E5V%R;FEN9RA014%27T-(04Y.14Q&24Q%7T524D]2
M7TU53%1)3$E.15]354U-05)9+`T*("`@("`@("`@("`@("`@(&%R<F%Y*"=S
M=6UM87)Y)R`]/B`D<W5M;6%R>2DI.PT*("`@("`@("!]#0H@("`@("`@("1T
M:&ES+3Y?8VAA;FYE;$EN9F];)W-U;6UA<GDG72`]("1S=6UM87)Y.PT*("`@
M("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`
M<&%R86T@<W1R:6YG#0H@("`@("H@0'!A<F%M(&)O;VQE86X@9&5T97)M:6YE
M<R!W:&5T:&5R('1H92!A;&EA<R!I<R!I;B!C:&%N;F5L+GAM;"!O<B!L;V-A
M;`T*("`@("`J($!R971U<FX@8F]O;&5A;B!S=6-C97-S#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@<V5T06QI87,H)&%L:6%S+"`D;&]C86P@/2!F86QS92D-
M"B`@("![#0H@("`@("`@(&EF("@A)'1H:7,M/G9A;&ED0VAA;FYE;%-E<G9E
M<B@D86QI87,I*2![#0H@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R
M;W(H4$5!4E]#2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$7TY!344L#0H@("`@
M("`@("`@("`@("`@87)R87DH)W1A9R<@/3X@)W-U9V=E<W1E9&%L:6%S)RP@
M)VYA;64G(#T^("1A;&EA<RDI.PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D;&]C86PI('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?8VAA;FYE;$EN9F];)VQO8V%L86QI87,G72`]("1A;&EA
M<SL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T:&ES+3Y?8VAA
M;FYE;$EN9F];)W-U9V=E<W1E9&%L:6%S)UT@/2`D86QI87,[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@0')E='5R;B!S=')I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G
M971!;&EA<R@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C
M:&%N;F5L26YF;ULG;&]C86QA;&EA<R==*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?8VAA;FYE;$EN9F];)VQO8V%L86QI87,G73L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C:&%N;F5L26YF;ULG
M<W5G9V5S=&5D86QI87,G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7V-H86YN96Q);F9O6R=S=6=G97-T961A;&EA<R==.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-H86YN96Q);F9O6R=N86UE
M)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]C:&%N;F5L26YF
M;ULG;F%M92==.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@4V5T('1H92!P86-K86=E('9A;&ED871I;VX@;V)J96-T(&EF(&ET(&1I
M9F9E<G,@9G)O;2!014%2)W,@9&5F875L=`T*("`@("`J(%1H92!C;&%S<R!M
M=7-T(&)E(&EN8VQU9&5A8FQE('9I82!C:&%N9VEN9R!?(&EN('1H92!C;&%S
M<VYA;64@=&\@<&%T:"!S97!A<F%T;W(L#0H@("`@("H@8G5T(&YO(&-H96-K
M:6YG(&]F('1H:7,@:7,@;6%D92X-"B`@("`@*B!`<&%R86T@<W1R:6YG?&9A
M;'-E('!A<W,@:6X@9F%L<V4@=&\@<F5S970@=&\@=&AE(&1E9F%U;'0@<&%C
M:V%G96YA;64@<F5G97@-"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@<W5C8V5S
M<PT*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=%9A;&ED871I;VY086-K86=E
M*"1V86QI9&%T96-L87-S+"`D=F5R<VEO;BD-"B`@("![#0H@("`@("`@(&EF
M("AE;7!T>2@D=F%L:61A=&5C;&%S<RDI('L-"B`@("`@("`@("`@('5N<V5T
M*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W9A;&ED871E<&%C:V%G92==*3L-"B`@
M("`@("`@?0T*("`@("`@("`D=&AI<RT^7V-H86YN96Q);F9O6R=V86QI9&%T
M97!A8VMA9V4G72`](&%R<F%Y*"=?8V]N=&5N="<@/3X@)'9A;&ED871E8VQA
M<W,I.PT*("`@("`@("`D=&AI<RT^7V-H86YN96Q);F9O6R=V86QI9&%T97!A
M8VMA9V4G75LG871T<FEB<R==(#T@87)R87DH)W9E<G-I;VXG(#T^("1V97)S
M:6]N*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!!9&0@82!P<F]T;V-O
M;"!T;R!T:&4@<')O=FED97,@<V5C=&EO;@T*("`@("`J($!P87)A;2!S=')I
M;F<@<')O=&]C;VP@='EP90T*("`@("`J($!P87)A;2!S=')I;F<@<')O=&]C
M;VP@=F5R<VEO;@T*("`@("`J($!P87)A;2!S=')I;F<@<')O=&]C;VP@;F%M
M92P@:68@86YY#0H@("`@("H@0'!A<F%M('-T<FEN9R!M:7)R;W(@;F%M92P@
M:68@=&AI<R!I<R!A(&UI<G)O<B=S('!R;W1O8V]L#0H@("`@("H@0')E='5R
M;B!B;V]L#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D1G5N8W1I;VXH)'1Y
M<&4L("1V97)S:6]N+"`D;F%M92`]("<G+"`D;6ER<F]R(#T@9F%L<V4I#0H@
M("`@>PT*("`@("`@("!I9B`H)&UI<G)O<BD@>PT*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YA9&1-:7)R;W)&=6YC=&EO;B@D;6ER<F]R+"`D='EP92P@
M)'9E<G-I;VXL("1N86UE*3L-"B`@("`@("`@?0T*("`@("`@("`D<V5T(#T@
M87)R87DH)V%T=')I8G,G(#T^(&%R<F%Y*"=V97)S:6]N)R`]/B`D=F5R<VEO
M;BDL("=?8V]N=&5N="<@/3X@)&YA;64I.PT*("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R1T
M>7!E75LG9G5N8W1I;VXG72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?8VAA
M;FYE;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R1T>7!E75LG9G5N8W1I
M;VXG72`]("1S970[#0H@("`@("`@("`@("`D=&AI<RT^7VES5F%L:60@/2!F
M86QS93L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!](&5L
M<V5I9B`H(6ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG
M<')I;6%R>2==6R1T>7!E75LG9G5N8W1I;VXG75LP72DI('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==
M6R1T>7!E75LG9G5N8W1I;VXG72`](&%R<F%Y*`T*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R1T
M>7!E75LG9G5N8W1I;VXG72D[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M
M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)'1Y<&5=6R=F
M=6YC=&EO;B==6UT@/2`D<V5T.PT*("`@("`@("!R971U<FX@=')U93L-"B`@
M("!]#0H@("`@+RHJ#0H@("`@("H@061D(&$@<')O=&]C;VP@=&\@82!M:7)R
M;W(G<R!P<F]V:61E<R!S96-T:6]N#0H@("`@("H@0'!A<F%M('-T<FEN9R!M
M:7)R;W(@;F%M92`H<V5R=F5R*0T*("`@("`J($!P87)A;2!S=')I;F<@<')O
M=&]C;VP@='EP90T*("`@("`J($!P87)A;2!S=')I;F<@<')O=&]C;VP@=F5R
M<VEO;@T*("`@("`J($!P87)A;2!S=')I;F<@<')O=&]C;VP@;F%M92P@:68@
M86YY#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D36ER<F]R1G5N8W1I;VXH
M)&UI<G)O<BP@)'1Y<&4L("1V97)S:6]N+"`D;F%M92`]("<G*0T*("`@('L-
M"B`@("`@("`@)&9O=6YD(#T@9F%L<V4[#0H@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G72DI('L-
M"B`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27T-(04Y.
M14Q&24Q%7T524D]27TU)4E)/4E].3U1?1D]53D0L#0H@("`@("`@("`@("`@
M("`@87)R87DH)VUI<G)O<B<@/3X@)&UI<G)O<BDI.PT*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1S971M:7)R;W(@
M/2!F86QS93L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN
M9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;,%TI*2![#0H@("`@("`@("`@("!F
M;W)E86-H("@D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O
M<B==(&%S("1I(#T^("1M:7(I('L-"B`@("`@("`@("`@("`@("!I9B`H)&UI
M<G)O<B`]/2`D;6ER6R=A='1R:6)S)UU;)VAO<W0G72D@>PT*("`@("`@("`@
M("`@("`@("`@("`D<V5T;6ER<F]R(#T@)B1T:&ES+3Y?8VAA;FYE;$EN9F];
M)W-E<G9E<G,G75LG;6ER<F]R)UU;)&E=.PT*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]C:&%N
M;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G75LG871T<FEB<R==6R=H;W-T
M)UT@/3T@)&UI<G)O<BD@>PT*("`@("`@("`@("`@("`@("1S971M:7)R;W(@
M/2`F)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G73L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21S971M
M:7)R;W(I('L-"B`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA0
M14%27T-(04Y.14Q&24Q%7T524D]27TU)4E)/4E].3U1?1D]53D0L#0H@("`@
M("`@("`@("`@("`@87)R87DH)VUI<G)O<B<@/3X@)&UI<G)O<BDI.PT*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1S
M970@/2!A<G)A>2@G871T<FEB<R<@/3X@87)R87DH)W9E<G-I;VXG(#T^("1V
M97)S:6]N*2P@)U]C;VYT96YT)R`]/B`D;F%M92D[#0H@("`@("`@(&EF("@A
M:7-S970H)'-E=&UI<G)O<ELD='EP95U;)V9U;F-T:6]N)UTI*2![#0H@("`@
M("`@("`@("`D<V5T;6ER<F]R6R1T>7!E75LG9G5N8W1I;VXG72`]("1S970[
M#0H@("`@("`@("`@("`D=&AI<RT^7VES5F%L:60@/2!F86QS93L-"B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!](&5L<V5I9B`H(6ES<V5T
M*"1S971M:7)R;W);)'1Y<&5=6R=F=6YC=&EO;B==6S!=*2D@>PT*("`@("`@
M("`@("`@)'-E=&UI<G)O<ELD='EP95U;)V9U;F-T:6]N)UT@/2!A<G)A>2@D
M<V5T;6ER<F]R6R1T>7!E75LG9G5N8W1I;VXG72D[#0H@("`@("`@('T-"B`@
M("`@("`@)'-E=&UI<G)O<ELD='EP95U;)V9U;F-T:6]N)UU;72`]("1S970[
M#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](&9A;'-E.PT*("`@("`@("!R
M971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@
M<W1R:6YG(%)E<V]U<F-E(%1Y<&4@=&AI<R!U<FP@;&EN:W,@=&\-"B`@("`@
M*B!`<&%R86T@<W1R:6YG(%523`T*("`@("`J($!P87)A;2!S=')I;F=\9F%L
M<V4@;6ER<F]R(&YA;64L(&EF('1H:7,@:7,@;F]T(&$@<')I;6%R>2!S97)V
M97(@4D535"!B87-E(%523`T*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=$)A
M<V554DPH)')E<V]U<F-E5'EP92P@)'5R;"P@)&UI<G)O<B`](&9A;'-E*0T*
M("`@('L-"B`@("`@("`@:68@*"1M:7)R;W(I('L-"B`@("`@("`@("`@("1F
M;W5N9"`](&9A;'-E.PT*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==*2D@>PT*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27T-(04Y.14Q&
M24Q%7T524D]27TU)4E)/4E].3U1?1D]53D0L#0H@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"=M:7)R;W(G(#T^("1M:7)R;W(I*3L-"B`@("`@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`D<V5T;6ER<F]R(#T@9F%L<V4[#0H@("`@("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G75LP72DI
M('L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7V-H86YN96Q)
M;F9O6R=S97)V97)S)UU;)VUI<G)O<B==(&%S("1I(#T^("1M:7(I('L-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"1M:7)R;W(@/3T@)&UI<ELG871T<FEB
M<R==6R=H;W-T)UTI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1S971M
M:7)R;W(@/2`F)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R
M;W(G75LD:5T[#0H@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?
M8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;)V%T=')I8G,G75LG
M:&]S="==(#T]("1M:7)R;W(I('L-"B`@("`@("`@("`@("`@("`@("`@)'-E
M=&UI<G)O<B`]("8D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI
M<G)O<B==.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1S971M:7)R;W(@/2`F)'1H
M:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UT[#0H@("`@
M("`@('T-"B`@("`@("`@)'-E="`](&%R<F%Y*"=A='1R:6)S)R`]/B!A<G)A
M>2@G='EP92<@/3X@)')E<V]U<F-E5'EP92DL("=?8V]N=&5N="<@/3X@)'5R
M;"D[#0H@("`@("`@(&EF("@A:7-S970H)'-E=&UI<G)O<ELG<F5S="==6R=B
M87-E=7)L)UTI*2![#0H@("`@("`@("`@("`D<V5T;6ER<F]R6R=R97-T)UU;
M)V)A<V5U<FPG72`]("1S970[#0H@("`@("`@("`@("`D=&AI<RT^7VES5F%L
M:60@/2!F86QS93L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@
M("!](&5L<V5I9B`H(6ES<V5T*"1S971M:7)R;W);)W)E<W0G75LG8F%S975R
M;"==6S!=*2D@>PT*("`@("`@("`@("`@)'-E=&UI<G)O<ELG<F5S="==6R=B
M87-E=7)L)UT@/2!A<G)A>2@D<V5T;6ER<F]R6R=R97-T)UU;)V)A<V5U<FPG
M72D[#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)'-E=&UI<G)O<ELG
M<F5S="==6R=B87-E=7)L)UT@87,@)&D@/3X@)'5R;"D@>PT*("`@("`@("`@
M("`@:68@*"1U<FQ;)V%T=')I8G,G75LG='EP92==(#T]("1R97-O=7)C951Y
M<&4I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VES5F%L:60@/2!F86QS
M93L-"B`@("`@("`@("`@("`@("`D<V5T;6ER<F]R6R=R97-T)UU;)V)A<V5U
M<FPG75LD:5T@/2`D<V5T.PT*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1S971M:7)R
M;W);)W)E<W0G75LG8F%S975R;"==6UT@/2`D<V5T.PT*("`@("`@("`D=&AI
M<RT^7VES5F%L:60@/2!F86QS93L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9R!M:7)R;W(@
M<V5R=F5R#0H@("`@("H@0'!A<F%M(&EN="!M:7)R;W(@:'1T<"!P;W)T#0H@
M("`@("H@0')E='5R;B!B;V]L96%N#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M861D36ER<F]R*"1S97)V97(L("1P;W)T(#T@;G5L;"D-"B`@("![#0H@("`@
M("`@(&EF("@D=&AI<RT^7V-H86YN96Q);F9O6R=N86UE)UT@/3T@)U]?=7)I
M)RD@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.R`O+R!T:&4@7U]U<FD@
M8VAA;FYE;"!C86YN;W0@:&%V92!M:7)R;W)S(&)Y(&1E9FEN:71I;VX-"B`@
M("`@("`@?0T*("`@("`@("`D<V5T(#T@87)R87DH)V%T=')I8G,G(#T^(&%R
M<F%Y*"=H;W-T)R`]/B`D<V5R=F5R*2D[#0H@("`@("`@(&EF("AI<U]N=6UE
M<FEC*"1P;W)T*2D@>PT*("`@("`@("`@("`@)'-E=%LG871T<FEB<R==6R=P
M;W)T)UT@/2`D<&]R=#L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UTI*2![
M#0H@("`@("`@("`@("`D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;
M)VUI<G)O<B==(#T@)'-E=#L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==6S!=*2D@>PT*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G
M75LG;6ER<F]R)UT@/0T*("`@("`@("`@("`@("`@("`@("!A<G)A>2@D=&AI
M<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7V-H86YN96Q)
M;F9O6R=S97)V97)S)UU;)VUI<G)O<B==6UT@/2`D<V5T.PT*("`@("`@("!R
M971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!2971R:65V
M92!T:&4@;F%M92!O9B!T:&4@=F%L:61A=&EO;B!P86-K86=E(&9O<B!T:&ES
M(&-H86YN96P-"B`@("`@*B!`<F5T=7)N('-T<FEN9WQF86QS90T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(&=E=%9A;&ED871I;VY086-K86=E*"D-"B`@("![
M#0H@("`@("`@(&EF("@A)'1H:7,M/E]I<U9A;&ED("8F("$D=&AI<RT^=F%L
M:61A=&4H*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]C:&%N;F5L26YF;ULG
M=F%L:61A=&5P86-K86=E)UTI*2![#0H@("`@("`@("`@("!R971U<FX@87)R
M87DH)V%T=')I8G,G(#T^(&%R<F%Y*"=V97)S:6]N)R`]/B`G9&5F875L="<I
M+`T*("`@("`@("`@("`@("`@("=?8V]N=&5N="<@/3X@)U!%05)?5F%L:61A
M=&4G*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/E]C:&%N
M;F5L26YF;ULG=F%L:61A=&5P86-K86=E)UT[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@4F5T<FEE=F4@=&AE(&]B:F5C="!T:&%T(&-A;B!B92!U<V5D
M(&9O<B!C=7-T;VT@=F%L:61A=&EO;@T*("`@("`J($!P87)A;2!S=')I;F=\
M9F%L<V4@=&AE(&YA;64@;V8@=&AE('!A8VMA9V4@=&\@=F%L:61A=&4N("!)
M9B!T:&4@<&%C:V%G92!I<PT*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M=&AE(&-H86YN96P@=F%L:61A=&EO;B!P86-K86=E+"!014%27U9A;&ED871E
M(&ES(')E='5R;F5D#0H@("`@("H@0')E='5R;B!014%27U9A;&ED871E?&9A
M;'-E(&9A;'-E(&ES(')E='5R;F5D(&EF('1H92!V86QI9&%T:6]N('!A8VMA
M9V4-"B`@("`@*B`@("`@("`@(&-A;FYO="!B92!L;V-A=&5D#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@)F=E=%9A;&ED871I;VY/8FIE8W0H)'!A8VMA9V4@
M/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=0
M14%27U9A;&ED871E)RDI('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G
M4$5!4B]686QI9&%T92YP:'`G.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A
M)'1H:7,M/E]I<U9A;&ED*2![#0H@("`@("`@("`@("!I9B`H(21T:&ES+3YV
M86QI9&%T92@I*2![#0H@("`@("`@("`@("`@("`@)&$@/2!F86QS93L-"B`@
M("`@("`@("`@("`@("!R971U<FX@)&$[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];
M)W9A;&ED871E<&%C:V%G92==*2D@>PT*("`@("`@("`@("`@:68@*"1P86-K
M86=E(#T]("1T:&ES+3Y?8VAA;FYE;$EN9F];)W9A;&ED871E<&%C:V%G92==
M*2![#0H@("`@("`@("`@("`@("`@+R\@8VAA;FYE;"!V86QI9&%T:6]N('!A
M8VMA9V5S(&%R92!A;'=A>7,@=F%L:61A=&5D(&)Y(%!%05)?5F%L:61A=&4-
M"B`@("`@("`@("`@("`@("`D=F%L(#T@)FYE=R!014%27U9A;&ED871E.PT*
M("`@("`@("`@("`@("`@(')E='5R;B`D=F%L.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H<W1R7W)E<&QA8V4H)RXG
M+"`G7R<L#0H@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-H86YN96Q);F9O
M6R=V86QI9&%T97!A8VMA9V4G75LG7V-O;G1E;G0G72DI*2![#0H@("`@("`@
M("`@("`@("`@:68@*"1T:&ES+3YI<TEN8VQU9&5A8FQE*'-T<E]R97!L86-E
M*"=?)RP@)R\G+`T*("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAA
M;FYE;$EN9F];)W9A;&ED871E<&%C:V%G92==6R=?8V]N=&5N="==*2`N("<N
M<&AP)RDI('L-"B`@("`@("`@("`@("`@("`@("`@:6YC;'5D95]O;F-E('-T
M<E]R97!L86-E*"=?)RP@)R\G+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]C:&%N;F5L26YF;ULG=F%L:61A=&5P86-K86=E)UU;)U]C;VYT
M96YT)UTI("X@)RYP:'`G.PT*("`@("`@("`@("`@("`@("`@("`D=F-L87-S
M(#T@<W1R7W)E<&QA8V4H)RXG+"`G7R<L#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V-H86YN96Q);F9O6R=V86QI9&%T97!A8VMA9V4G75LG
M7V-O;G1E;G0G72D[#0H@("`@("`@("`@("`@("`@("`@("1V86P@/2`F;F5W
M("1V8VQA<W,[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@)&$@/2!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1A.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@)'9C;&%S<R`]('-T<E]R97!L86-E
M*"<N)RP@)U\G+`T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-H86YN
M96Q);F9O6R=V86QI9&%T97!A8VMA9V4G75LG7V-O;G1E;G0G72D[#0H@("`@
M("`@("`@("`@("`@)'9A;"`]("9N97<@)'9C;&%S<SL-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1V86P@/2`F;F5W
M(%!%05)?5F%L:61A=&4[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1V
M86P[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@:7-);F-L=61E86)L92@D<&%T
M:"D-"B`@("![#0H@("`@("`@("1P;W-S:6)I;&ET:65S(#T@97AP;&]D92A0
M051(7U-%4$%2051/4BP@:6YI7V=E="@G:6YC;'5D95]P871H)RDI.PT*("`@
M("`@("!F;W)E86-H("@D<&]S<VEB:6QI=&EE<R!A<R`D9&ER*2![#0H@("`@
M("`@("`@("!I9B`H9FEL95]E>&ES=',H)&1I<B`N($1)4D5#5$]265]315!!
M4D%43U(@+B`D<&%T:"D-"B`@("`@("`@("`@("`@("`@("8F(&ES7W)E861A
M8FQE*"1D:7(@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)'!A=&@I*2![#0H@
M("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@
M("\J*@T*("`@("`J(%1H:7,@9G5N8W1I;VX@:7,@=7-E9"!B>2!T:&4@8VAA
M;FYE;"!U<&1A=&5R(&%N9"!R971R:65V97,@82!V86QU92!S970@8GD-"B`@
M("`@*B!T:&4@<F5G:7-T<GDL(&]R('1H92!C=7)R96YT('1I;64@:68@:70@
M:&%S(&YO="!B965N('-E=`T*("`@("`J($!R971U<FX@<W1R:6YG#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@;&%S=$UO9&EF:65D*"D-"B`@("![#0H@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7V-H86YN96Q);F9O6R=?;&%S=&UO9&EF
M:65D)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]C:&%N;F5L
M26YF;ULG7VQA<W1M;V1I9FEE9"==.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!T:6UE*"D[#0H@("`@?0T*?0T*/SX-"@``````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"\`````````````````
M`````````````````````````````````````````````````````````#`P
M,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S0P
M`#`R,#<P-@`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM
M86YD+T%U=&@N<&AP````````````````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,3,P-3``,3`U,34T,S,W-#``,#(R,S$W`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP#0HO*BH-"B`J(%!%05)?0V]M
M;6%N9%]!=71H("AL;V=I;BP@;&]G;W5T(&-O;6UA;F1S*0T*("H-"B`J(%!(
M4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@
M;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@
M<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E
M('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-
M"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@
M;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R
M>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@
M(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@($=R
M96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y
M.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-
M"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!!=71H+G!H<"QV(#$N,C,@,C`P
M-B\P,R\P,B`Q.#HQ-#HQ,R!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@
M("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#`N,0T*("HO#0H-
M"B\J*@T*("H@8F%S92!C;&%S<PT*("HO#0IR97%U:7)E7V]N8V4@)U!%05(O
M0V]M;6%N9"]#;VUM;VXN<&AP)SL-"G)E<75I<F5?;VYC92`G4$5!4B]#;VYF
M:6<N<&AP)SL-"@T*+RHJ#0H@*B!014%2(&-O;6UA;F1S(&9O<B!L;V=I;B]L
M;V=O=70-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@
M("!014%2#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN
M970^#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN
M970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E
M.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S
M:6YC92!296QE87-E(#`N,0T*("HO#0IC;&%S<R!014%27T-O;6UA;F1?075T
M:"!E>'1E;F1S(%!%05)?0V]M;6%N9%]#;VUM;VX-"GL-"B`@("`O+R![>WL@
M<')O<&5R=&EE<PT*#0H@("`@=F%R("1C;VUM86YD<R`](&%R<F%Y*`T*("`@
M("`@("`G;&]G:6XG(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG
M(#T^("=#;VYN96-T<R!A;F0@875T:&5N=&EC871E<R!T;R!R96UO=&4@<V5R
M=F5R)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)VQI)RP-"B`@("`@
M("`@("`@("=F=6YC=&EO;B<@/3X@)V1O3&]G:6XG+`T*("`@("`@("`@("`@
M)V]P=&EO;G,G(#T^(&%R<F%Y*"DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G
M#0I,;V<@:6X@=&\@=&AE(')E;6]T92!S97)V97(N("!4;R!U<V4@<F5M;W1E
M(&9U;F-T:6]N<R!I;B!T:&4@:6YS=&%L;&5R#0IT:&%T(')E<75I<F4@86YY
M(&MI;F0@;V8@<')I=FEL96=E<RP@>6]U(&YE960@=&\@;&]G(&EN(&9I<G-T
M+B`@5&AE#0IU<V5R;F%M92!A;F0@<&%S<W=O<F0@>6]U(&5N=&5R(&AE<F4@
M=VEL;"!B92!S=&]R960@:6X@>6]U<B!P97(M=7-E<@T*4$5!4B!C;VYF:6=U
M<F%T:6]N("A^+RYP96%R<F,@;VX@56YI>"UL:6ME('-Y<W1E;7,I+B`@069T
M97(@;&]G9VEN9PT*:6XL('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D('=I
M;&P@8F4@<V5N="!A;&]N9R!I;B!S=6)S97%U96YT#0IO<&5R871I;VYS(&]N
M('1H92!R96UO=&4@<V5R=F5R+B<L#0H@("`@("`@("`@("`I+`T*("`@("`@
M("`G;&]G;W5T)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]
M/B`G3&]G<R!O=70@9G)O;2!T:&4@<F5M;W1E('-E<G9E<B<L#0H@("`@("`@
M("`@("`G<VAO<G1C=70G(#T^("=L;R<L#0H@("`@("`@("`@("`G9G5N8W1I
M;VXG(#T^("=D;TQO9V]U="<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@
M87)R87DH*2P-"B`@("`@("`@("`@("=D;V,G(#T^("<-"DQO9W,@;W5T(&9R
M;VT@=&AE(')E;6]T92!S97)V97(N("!4:&ES(&-O;6UA;F0@9&]E<R!N;W0@
M86-T=6%L;'D-"F-O;FYE8W0@=&\@=&AE(')E;6]T92!S97)V97(L(&ET(&]N
M;'D@9&5L971E<R!T:&4@<W1O<F5D('5S97)N86UE(&%N9`T*<&%S<W=O<F0@
M9G)O;2!Y;W5R('5S97(@8V]N9FEG=7)A=&EO;BXG+`T*("`@("`@("`@("`@
M*0T*#0H@("`@("`@("D[#0H-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!C
M;VYS=')U8W1O<@T*#0H@("`@+RHJ#0H@("`@("H@4$5!4E]#;VUM86YD7T%U
M=&@@8V]N<W1R=6-T;W(N#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI
M8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(%!%05)?0V]M;6%N9%]!=71H*"8D
M=6DL("8D8V]N9FEG*0T*("`@('L-"B`@("`@("`@<&%R96YT.CI014%27T-O
M;6UA;F1?0V]M;6]N*"1U:2P@)&-O;F9I9RD[#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H-"B`@("`O+R![>WL@9&],;V=I;B@I#0H-"B`@("`O*BH-"B`@("`@
M*B!%>&5C=71E('1H92`G;&]G:6XG(&-O;6UA;F0N#0H@("`@("H-"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1C;VUM86YD(&-O;6UA;F0@;F%M90T*("`@("`J
M#0H@("`@("H@0'!A<F%M(&%R<F%Y("1O<'1I;VYS(&]P=&EO;E]N86UE(#T^
M('9A;'5E#0H@("`@("H-"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R!L
M:7-T(&]F(&%D9&ET:6]N86P@<&%R86UE=&5R<PT*("`@("`J#0H@("`@("H@
M0')E='5R;B!B;V]L(%12544@;VX@<W5C8V5S<R!O<@T*("`@("`J(&$@4$5!
M4B!E<G)O<B!O;B!F86EL=7)E#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U
M8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&1O3&]G:6XH)&-O;6UA;F0L
M("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@)')E9R`]("8D
M=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("`D8VAA;FYE
M;"`]("1T:&ES+3YC;VYF:6<M/F=E="@G9&5F875L=%]C:&%N;F5L)RD[#0H@
M("`@("`@("1C:&%N(#T@)')E9RT^9V5T0VAA;FYE;"@D8VAA;FYE;"D[#0H@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C:&%N*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1C:&%N*3L-"B`@("`@("`@
M?0T*("`@("`@("`D<V5R=F5R(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F
M97)R961?;6ER<F]R)RD[#0H@("`@("`@("1R96UO=&4@/2`F)'1H:7,M/F-O
M;F9I9RT^9V5T4F5M;W1E*"D[#0H@("`@("`@("1U<V5R;F%M92`]("1T:&ES
M+3YC;VYF:6<M/F=E="@G=7-E<FYA;64G*3L-"B`@("`@("`@:68@*&5M<'1Y
M*"1U<V5R;F%M92DI('L-"B`@("`@("`@("`@("1U<V5R;F%M92`]($`D7T5.
M5ELG55-%4B==.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YU:2T^;W5T
M<'5T1&%T82@B3&]G9VEN9R!I;B!T;R`D<V5R=F5R+B(L("1C;VUM86YD*3L-
M"B`@("`@("`@#0H@("`@("`@(&QI<W0H)'5S97)N86UE+"`D<&%S<W=O<F0I
M(#T@)'1H:7,M/G5I+3YU<V5R1&EA;&]G*`T*("`@("`@("`@("`@)&-O;6UA
M;F0L#0H@("`@("`@("`@("!A<G)A>2@G57-E<FYA;64G+"`G4&%S<W=O<F0G
M*2P-"B`@("`@("`@("`@(&%R<F%Y*"=T97AT)RP@("`@("=P87-S=V]R9"<I
M+`T*("`@("`@("`@("`@87)R87DH)'5S97)N86UE+"`@)R<I#0H@("`@("`@
M("`@("`I.PT*("`@("`@("`D=7-E<FYA;64@/2!T<FEM*"1U<V5R;F%M92D[
M#0H@("`@("`@("1P87-S=V]R9"`]('1R:6TH)'!A<W-W;W)D*3L-"B`@("`@
M("`@#0H@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E="@G=7-E<FYA;64G+"`D
M=7-E<FYA;64I.PT*("`@("`@("`D=&AI<RT^8V]N9FEG+3YS970H)W!A<W-W
M;W)D)RP@)'!A<W-W;W)D*3L-"@T*("`@("`@("!I9B`H)&-H86XM/G-U<'!O
M<G1S4D535"@I*2![#0H@("`@("`@("`@("`D;VL@/2!T<G5E.PT*("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@)')E;6]T92T^97AP96-T17)R;W(H
M-#`Q*3L-"B`@("`@("`@("`@("1O:R`]("1R96UO=&4M/F-A;&PH)VQO9VEN
M=&5S="<I.PT*("`@("`@("`@("`@)')E;6]T92T^<&]P17AP96-T*"D[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"1O:R`]/3T@=')U92D@>PT*("`@("`@
M("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"),;V=G960@:6XN(BP@)&-O
M;6UA;F0I.PT*("`@("`@("`@("`@)'1H:7,M/F-O;F9I9RT^<W1O<F4H*3L-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@B3&]G:6X@9F%I;&5D(2(I.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O
M('M[>R!D;TQO9V]U="@I#0H-"B`@("`O*BH-"B`@("`@*B!%>&5C=71E('1H
M92`G;&]G;W5T)R!C;VUM86YD+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8V]M;6%N9"!C;VUM86YD(&YA;64-"B`@("`@*@T*("`@("`J($!P
M87)A;2!A<G)A>2`D;W!T:6]N<R!O<'1I;VY?;F%M92`]/B!V86QU90T*("`@
M("`J#0H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@;&ES="!O9B!A9&1I
M=&EO;F%L('!A<F%M971E<G,-"B`@("`@*@T*("`@("`J($!R971U<FX@8F]O
M;"!44E5%(&]N('-U8V-E<W,@;W(-"B`@("`@*B!A(%!%05(@97)R;W(@;VX@
M9F%I;'5R90T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!D;TQO9V]U="@D8V]M;6%N9"P@)&]P=&EO;G,L
M("1P87)A;7,I#0H@("`@>PT*("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF
M:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@("1C:&%N;F5L(#T@)'1H:7,M
M/F-O;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*3L-"B`@("`@("`@)&-H
M86X@/2`D<F5G+3YG971#:&%N;F5L*"1C:&%N;F5L*3L-"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&-H86XI*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)&-H86XI.PT*("`@("`@("!]#0H@("`@("`@
M("1S97)V97(@/2`D=&AI<RT^8V]N9FEG+3YG970H)W!R969E<G)E9%]M:7)R
M;W(G*3L-"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"),;V=G:6YG
M(&]U="!F<F]M("1S97)V97(N(BP@)&-O;6UA;F0I.PT*("`@("`@("`D=&AI
M<RT^8V]N9FEG+3YR96UO=F4H)W5S97)N86UE)RD[#0H@("`@("`@("1T:&ES
M+3YC;VYF:6<M/G)E;6]V92@G<&%S<W=O<F0G*3L-"B`@("`@("`@)'1H:7,M
M/F-O;F9I9RT^<W1O<F4H*3L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0I]#0H-"C\^````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O
M075T:"YX;6P`````````````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,38U
M,``Q,#4Q-30S,S<T,``P,C(S,S,`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/&-O;6UA;F1S('9E<G-I;VX](C$N,"(^#0H@
M/&QO9VEN/@T*("`\<W5M;6%R>3Y#;VYN96-T<R!A;F0@875T:&5N=&EC871E
M<R!T;R!R96UO=&4@<V5R=F5R/"]S=6UM87)Y/@T*("`\<VAO<G1C=70^;&D\
M+W-H;W)T8W5T/@T*("`\9G5N8W1I;VX^9&],;V=I;CPO9G5N8W1I;VX^#0H@
M(#QO<'1I;VYS("\^#0H@(#QD;V,^#0I,;V<@:6X@=&\@=&AE(')E;6]T92!S
M97)V97(N("!4;R!U<V4@<F5M;W1E(&9U;F-T:6]N<R!I;B!T:&4@:6YS=&%L
M;&5R#0IT:&%T(')E<75I<F4@86YY(&MI;F0@;V8@<')I=FEL96=E<RP@>6]U
M(&YE960@=&\@;&]G(&EN(&9I<G-T+B`@5&AE#0IU<V5R;F%M92!A;F0@<&%S
M<W=O<F0@>6]U(&5N=&5R(&AE<F4@=VEL;"!B92!S=&]R960@:6X@>6]U<B!P
M97(M=7-E<@T*4$5!4B!C;VYF:6=U<F%T:6]N("A^+RYP96%R<F,@;VX@56YI
M>"UL:6ME('-Y<W1E;7,I+B`@069T97(@;&]G9VEN9PT*:6XL('EO=7(@=7-E
M<FYA;64@86YD('!A<W-W;W)D('=I;&P@8F4@<V5N="!A;&]N9R!I;B!S=6)S
M97%U96YT#0IO<&5R871I;VYS(&]N('1H92!R96UO=&4@<V5R=F5R+CPO9&]C
M/@T*(#PO;&]G:6X^#0H@/&QO9V]U=#X-"B`@/'-U;6UA<GD^3&]G<R!O=70@
M9G)O;2!T:&4@<F5M;W1E('-E<G9E<CPO<W5M;6%R>3X-"B`@/'-H;W)T8W5T
M/FQO/"]S:&]R=&-U=#X-"B`@/&9U;F-T:6]N/F1O3&]G;W5T/"]F=6YC=&EO
M;CX-"B`@/&]P=&EO;G,@+SX-"B`@/&1O8SX-"DQO9W,@;W5T(&9R;VT@=&AE
M(')E;6]T92!S97)V97(N("!4:&ES(&-O;6UA;F0@9&]E<R!N;W0@86-T=6%L
M;'D-"F-O;FYE8W0@=&\@=&AE(')E;6]T92!S97)V97(L(&ET(&]N;'D@9&5L
M971E<R!T:&4@<W1O<F5D('5S97)N86UE(&%N9`T*<&%S<W=O<F0@9G)O;2!Y
M;W5R('5S97(@8V]N9FEG=7)A=&EO;BX\+V1O8SX-"B`\+VQO9V]U=#X-"CPO
M8V]M;6%N9',^````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T-O
M;6UA;F0O0G5I;&0N<&AP````````````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P-38P,``Q,#4Q-30S,S<T,``P,C(T-3<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`-"B\J*@T*("H@4$5!4E]#
M;VUM86YD7T%U=&@@*&)U:6QD(&-O;6UA;F0I#0H@*@T*("H@4$A0('9E<G-I
M;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE
M(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E
M#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E
M(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE
M('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N
M9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO
M=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A
M<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"
M86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@5&]M87,@5BY6
M+D-O>"`\8V]X0&ED96-N970N8V]M/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"
M96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR
M,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@
M0'9E<G-I;VX@("`@0U93.B`D260Z($)U:6QD+G!H<"QV(#$N,3,@,C`P-B\P
M,2\P-B`P-#HT-SHS-B!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@
M("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#`N,0T*("HO#0H-"B\J
M*@T*("H@8F%S92!C;&%S<PT*("HO#0IR97%U:7)E7V]N8V4@)U!%05(O0V]M
M;6%N9"]#;VUM;VXN<&AP)SL-"@T*+RHJ#0H@*B!014%2(&-O;6UA;F1S(&9O
M<B!B=6EL9&EN9R!E>'1E;G-I;VYS+@T*("H-"B`J($!C871E9V]R>2`@('!E
M87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@
M0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@(%1O;6%S(%8N
M5BY#;W@@/&-O>$!I9&5C;F5T+F-O;3X-"B`J($!A=71H;W(@("`@($=R96<@
M0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M
M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J
M($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@
M("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"F-L
M87-S(%!%05)?0V]M;6%N9%]"=6EL9"!E>'1E;F1S(%!%05)?0V]M;6%N9%]#
M;VUM;VX-"GL-"B`@("`O+R![>WL@<')O<&5R=&EE<PT*#0H@("`@=F%R("1C
M;VUM86YD<R`](&%R<F%Y*`T*("`@("`@("`G8G5I;&0G(#T^(&%R<F%Y*`T*
M("`@("`@("`@("`@)W-U;6UA<GDG(#T^("="=6EL9"!A;B!%>'1E;G-I;VX@
M1G)O;2!#(%-O=7)C92<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D
M;T)U:6QD)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)V(G+`T*("`@
M("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*"DL#0H@("`@("`@("`@("`G
M9&]C)R`]/B`G6W!A8VMA9V4N>&UL70T*0G5I;&1S(&]N92!O<B!M;W)E(&5X
M=&5N<VEO;G,@8V]N=&%I;F5D(&EN(&$@<&%C:V%G92XG#0H@("`@("`@("`@
M("`I+`T*("`@("`@("`I.PT*#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@
M8V]N<W1R=6-T;W(-"@T*("`@("\J*@T*("`@("`J(%!%05)?0V]M;6%N9%]"
M=6EL9"!C;VYS=')U8W1O<BX-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B
M;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@4$5!4E]#;VUM86YD7T)U:6QD
M*"8D=6DL("8D8V]N9FEG*0T*("`@('L-"B`@("`@("`@<&%R96YT.CI014%2
M7T-O;6UA;F1?0V]M;6]N*"1U:2P@)&-O;F9I9RD[#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H-"B`@("`O+R![>WL@9&]"=6EL9"@I#0H-"B`@("!F=6YC=&EO
M;B!D;T)U:6QD*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![
M#0H@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]"=6EL9&5R+G!H<"<[#0H@
M("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@/"`Q*2![#0H@("`@("`@("`@
M("`D<&%R86US6S!=(#T@)W!A8VMA9V4N>&UL)SL-"B`@("`@("`@?0T*("`@
M("`@("`D8G5I;&1E<B`]("9N97<@4$5!4E]"=6EL9&5R*"1T:&ES+3YU:2D[
M#0H@("`@("`@("1T:&ES+3YD96)U9R`]("1T:&ES+3YC;VYF:6<M/F=E="@G
M=F5R8F]S92<I.PT*("`@("`@("`D97)R(#T@)&)U:6QD97(M/F)U:6QD*"1P
M87)A;7-;,%TL(&%R<F%Y*"8D=&AI<RP@)V)U:6QD0V%L;&)A8VLG*2D[#0H@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G(I*2![#0H@("`@("`@("`@
M("!R971U<FX@)&5R<CL-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@=')U
M93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8G5I;&1#86QL
M8F%C:R@I#0H-"B`@("!F=6YC=&EO;B!B=6EL9$-A;&QB86-K*"1W:&%T+"`D
M9&%T82D-"B`@("![#0H@("`@("`@(&EF("@H)'=H870@/3T@)V-M9&]U='!U
M="<@)B8@)'1H:7,M/F1E8G5G(#X@,2D@?'P-"B`@("`@("`@("`@("@D=VAA
M="`]/2`G;W5T<'5T)R`F)B`D=&AI<RT^9&5B=6<@/B`P*2D@>PT*("`@("`@
M("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*')T<FEM*"1D871A*2P@)V)U
M:6QD)RD[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O+R!]?7T-"GT-"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]"=6EL9"YX;6P`
M````````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#$U`#$P-3$U-#,S
M-S0P`#`R,C0V-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\8V]M;6%N9',@=F5R<VEO;CTB,2XP(CX-"B`\8G5I;&0^#0H@
M(#QS=6UM87)Y/D)U:6QD(&%N($5X=&5N<VEO;B!&<F]M($,@4V]U<F-E/"]S
M=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]"=6EL9#PO9G5N8W1I;VX^#0H@(#QS
M:&]R=&-U=#YB/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,@+SX-"B`@/&1O8SY;
M<&%C:V%G92YX;6Q=#0I"=6EL9',@;VYE(&]R(&UO<F4@97AT96YS:6]N<R!C
M;VYT86EN960@:6X@82!P86-K86=E+CPO9&]C/@T*(#PO8G5I;&0^#0H\+V-O
M;6UA;F1S/@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O0VAA;FYE;',N<&AP````````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#$P,30R,@`Q,#4Q-30S,S<T,``P,C,Q-3(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`-"B\O("\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W
M:61T:#TT.B`J+PT*+RHJ#0H@*B!014%27T-O;6UA;F1?0VAA;FYE;',@*&QI
M<W0M8VAA;FYE;',L('5P9&%T92UC:&%N;F5L<RP@8VAA;FYE;"UD96QE=&4L
M(&-H86YN96PM861D+`T*("H@8VAA;FYE;"UU<&1A=&4L(&-H86YN96PM:6YF
M;RP@8VAA;FYE;"UA;&EA<RP@8VAA;FYE;"UD:7-C;W9E<B!C;VUM86YD<RD-
M"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z
M(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O
M9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*
M("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO
M=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N
M<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E
M8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@
M*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`
M875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T
M:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P
M>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@
M("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI
M8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@0VAA;FYE;',N
M<&AP+'8@,2XT-"`R,#`V+S`S+S`R(#$X.C$T.C$S(&-E;&QO9R!%>'`@)`T*
M("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%
M05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XT+C!A,0T*("HO#0H-"B\J*@T*("H@8F%S92!C;&%S<PT*("HO#0IR
M97%U:7)E7V]N8V4@)U!%05(O0V]M;6%N9"]#;VUM;VXN<&AP)SL-"@T*+RHJ
M#0H@*B!014%2(&-O;6UA;F1S(&9O<B!M86YA9VEN9R!C:&%N;F5L<RX-"B`J
M#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@
M*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@
M*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI
M8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@
M4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N
M.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!2
M96QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!4E]#;VUM86YD7T-H86YN
M96QS(&5X=&5N9',@4$5!4E]#;VUM86YD7T-O;6UO;@T*>PT*("`@("\O('M[
M>R!P<F]P97)T:65S#0H-"B`@("!V87(@)&-O;6UA;F1S(#T@87)R87DH#0H@
M("`@("`@("=L:7-T+6-H86YN96QS)R`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("=S=6UM87)Y)R`]/B`G3&ES="!!=F%I;&%B;&4@0VAA;FYE;',G+`T*("`@
M("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&],:7-T)RP-"B`@("`@("`@("`@
M("=S:&]R=&-U="<@/3X@)VQC)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]
M/B!A<G)A>2@I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)PT*3&ES="!A;&P@
M879A:6QA8FQE(&-H86YN96QS(&9O<B!I;G-T86QL871I;VXN#0HG+`T*("`@
M("`@("`@("`@*2P-"B`@("`@("`@)W5P9&%T92UC:&%N;F5L<R<@/3X@87)R
M87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)U5P9&%T92!T:&4@0VAA
M;FYE;"!,:7-T)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O57!D
M871E06QL)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)W5C)RP-"B`@
M("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@I+`T*("`@("`@("`@("`@
M)V1O8R<@/3X@)PT*3&ES="!A;&P@:6YS=&%L;&5D('!A8VMA9V5S(&EN(&%L
M;"!C:&%N;F5L<RX-"B<-"B`@("`@("`@("`@("DL#0H@("`@("`@("=C:&%N
M;F5L+61E;&5T92<@/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@
M/3X@)U)E;6]V92!A($-H86YN96P@1G)O;2!T:&4@3&ES="<L#0H@("`@("`@
M("`@("`G9G5N8W1I;VXG(#T^("=D;T1E;&5T92<L#0H@("`@("`@("`@("`G
M<VAO<G1C=70G(#T^("=C9&4G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^
M(&%R<F%Y*"DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G/&-H86YN96P@;F%M
M93X-"D1E;&5T92!A(&-H86YN96P@9G)O;2!T:&4@<F5G:7-T<GDN("!9;W4@
M;6%Y(&YO=`T*<F5M;W9E(&%N>2!C:&%N;F5L('1H870@:&%S(&EN<W1A;&QE
M9"!P86-K86=E<RX-"B<-"B`@("`@("`@("`@("DL#0H@("`@("`@("=C:&%N
M;F5L+6%D9"<@/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@
M)T%D9"!A($-H86YN96PG+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G
M9&]!9&0G+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G8V$G+`T*("`@
M("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*"DL#0H@("`@("`@("`@("`G
M9&]C)R`]/B`G/&-H86YN96PN>&UL/@T*061D(&$@<')I=F%T92!C:&%N;F5L
M('1O('1H92!C:&%N;F5L(&QI<W0N("!.;W1E('1H870@86QL#0IP=6)L:6,@
M8VAA;FYE;',@<VAO=6QD(&)E('-Y;F-E9"!U<VEN9R`B=7!D871E+6-H86YN
M96QS(BX-"E!A<F%M971E<B!M87D@8F4@96ET:&5R(&$@;&]C86P@9FEL92!O
M<B!R96UO=&4@55),('1O(&$-"F-H86YN96PN>&UL+@T*)PT*("`@("`@("`@
M("`@*2P-"B`@("`@("`@)V-H86YN96PM=7!D871E)R`]/B!A<G)A>2@-"B`@
M("`@("`@("`@("=S=6UM87)Y)R`]/B`G57!D871E(&%N($5X:7-T:6YG($-H
M86YN96PG+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]5<&1A=&4G
M+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G8W4G+`T*("`@("`@("`@
M("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=F;W)C
M92<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@
M/3X@)V8G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G=VEL;"!F
M;W)C92!D;W=N;&]A9"!O9B!N97<@8VAA;FYE;"YX;6P@:68@86X@97AI<W1I
M;F<@8VAA;FYE;"!N86UE(&ES('5S960G+`T*("`@("`@("`@("`@("`@("`@
M("`I+`T*("`@("`@("`@("`@("`@("=C:&%N;F5L)R`]/B!A<G)A>2@-"B`@
M("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G8R<L#0H@("`@("`@
M("`@("`@("`@("`@("=A<F<G(#T^("=#2$%.3D5,)RP-"B`@("`@("`@("`@
M("`@("`@("`@)V1O8R<@/3X@)W=I;&P@9F]R8V4@9&]W;FQO860@;V8@;F5W
M(&-H86YN96PN>&UL(&EF(&%N(&5X:7-T:6YG(&-H86YN96P@;F%M92!I<R!U
M<V5D)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"BDL#0H@("`@("`@("`@
M("`G9&]C)R`]/B`G6SQC:&%N;F5L+GAM;#Y\/&-H86YN96P@;F%M93Y=#0I5
M<&1A=&4@82!C:&%N;F5L(&EN('1H92!C:&%N;F5L(&QI<W0@9&ER96-T;'DN
M("!.;W1E('1H870@86QL#0IP=6)L:6,@8VAA;FYE;',@8V%N(&)E('-Y;F-E
M9"!U<VEN9R`B=7!D871E+6-H86YN96QS(BX-"E!A<F%M971E<B!M87D@8F4@
M82!L;V-A;"!O<B!R96UO=&4@8VAA;FYE;"YX;6PL(&]R('1H92!N86UE(&]F
M#0IA;B!E>&ES=&EN9R!C:&%N;F5L+@T*)PT*("`@("`@("`@("`@*2P-"B`@
M("`@("`@)V-H86YN96PM:6YF;R<@/3X@87)R87DH#0H@("`@("`@("`@("`G
M<W5M;6%R>2<@/3X@)U)E=')I979E($EN9F]R;6%T:6]N(&]N(&$@0VAA;FYE
M;"<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;TEN9F\G+`T*("`@
M("`@("`@("`@)W-H;W)T8W5T)R`]/B`G8VDG+`T*("`@("`@("`@("`@)V]P
M=&EO;G,G(#T^(&%R<F%Y*"DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G/'!A
M8VMA9V4^#0I,:7-T('1H92!F:6QE<R!I;B!A;B!I;G-T86QL960@<&%C:V%G
M92X-"B<-"B`@("`@("`@("`@("DL#0H@("`@("`@("=C:&%N;F5L+6%L:6%S
M)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G4W!E8VEF
M>2!A;B!A;&EA<R!T;R!A(&-H86YN96P@;F%M92<L#0H@("`@("`@("`@("`G
M9G5N8W1I;VXG(#T^("=D;T%L:6%S)RP-"B`@("`@("`@("`@("=S:&]R=&-U
M="<@/3X@)V-H82<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH
M*2P-"B`@("`@("`@("`@("=D;V,G(#T^("<\8VAA;FYE;#X@/&%L:6%S/@T*
M4W!E8VEF>2!A('-P96-I9FEC(&%L:6%S('1O('5S92!F;W(@82!C:&%N;F5L
M(&YA;64N#0I4:&4@86QI87,@;6%Y(&YO="!B92!A;B!E>&ES=&EN9R!C:&%N
M;F5L(&YA;64@;W(-"F%L:6%S+@T*)PT*("`@("`@("`@("`@*2P-"B`@("`@
M("`@)V-H86YN96PM9&ES8V]V97(G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M)W-U;6UA<GDG(#T^("=);FET:6%L:7IE(&$@0VAA;FYE;"!F<F]M(&ET<R!S
M97)V97(G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]$:7-C;W9E
M<B<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=D:2<L#0H@("`@("`@
M("`@("`G;W!T:6]N<R<@/3X@87)R87DH*2P-"B`@("`@("`@("`@("=D;V,G
M(#T^("<\<&%C:V%G93X-"DQI<W0@=&AE(&9I;&5S(&EN(&%N(&EN<W1A;&QE
M9"!P86-K86=E+@T*)PT*("`@("`@("`@("`@*2P-"B`@("`@("`@*3L-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R!C;VYS=')U8W1O<@T*#0H@("`@+RHJ
M#0H@("`@("H@4$5!4E]#;VUM86YD7U)E9VES=')Y(&-O;G-T<G5C=&]R+@T*
M("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!014%27T-O;6UA;F1?0VAA;FYE;',H)B1U:2P@)B1C;VYF:6<I
M#0H@("`@>PT*("`@("`@("!P87)E;G0Z.E!%05)?0V]M;6%N9%]#;VUM;VXH
M)'5I+"`D8V]N9FEG*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*("`@("\O
M('M[>R!D;TQI<W0H*0T*("`@(`T*("`@(&9U;F-T:6]N(%]S;W)T0VAA;FYE
M;',H)&$L("1B*0T*("`@('L-"B`@("`@("`@<F5T=7)N('-T<FYA=&-A<V5C
M;7`H)&$M/F=E=$YA;64H*2P@)&(M/F=E=$YA;64H*2D[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@9&],:7-T*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M
M<RD-"B`@("![#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T
M4F5G:7-T<GDH*3L-"B`@("`@("`@)')E9VES=&5R960@/2`D<F5G+3YG971#
M:&%N;F5L<R@I.PT*("`@("`@("!U<V]R="@D<F5G:7-T97)E9"P@87)R87DH
M)B1T:&ES+"`G7W-O<G1C:&%N;F5L<R<I*3L-"B`@("`@("`@)&D@/2`D:B`]
M(#`[#0H@("`@("`@("1D871A(#T@87)R87DH#0H@("`@("`@("`@("`G8V%P
M=&EO;B<@/3X@)U)E9VES=&5R960@0VAA;FYE;',Z)RP-"B`@("`@("`@("`@
M("=B;W)D97(G(#T^('1R=64L#0H@("`@("`@("`@("`G:&5A9&QI;F4G(#T^
M(&%R<F%Y*"=#:&%N;F5L)RP@)U-U;6UA<GDG*0T*("`@("`@("`@("`@*3L-
M"B`@("`@("`@9F]R96%C:"`H)')E9VES=&5R960@87,@)&-H86YN96PI('L-
M"B`@("`@("`@("`@("1D871A6R=D871A)UU;72`](&%R<F%Y*"1C:&%N;F5L
M+3YG971.86UE*"DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1C:&%N;F5L+3YG9713=6UM87)Y*"DI.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("AC;W5N="@D<F5G:7-T97)E9"D]/3`I('L-"B`@("`@("`@
M("`@("1D871A(#T@)RAN;R!R96=I<W1E<F5D(&-H86YN96QS*2<[#0H@("`@
M("`@('T-"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1D871A+"`D
M8V]M;6%N9"D[#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"B`@("`-
M"B`@("!F=6YC=&EO;B!D;U5P9&%T94%L;"@D8V]M;6%N9"P@)&]P=&EO;G,L
M("1P87)A;7,I#0H@("`@>PT*("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF
M:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@("1S879E8VAA;FYE;"`]("1T
M:&ES+3YC;VYF:6<M/F=E="@G9&5F875L=%]C:&%N;F5L)RD[#0H@("`@("`@
M(&EF("AI<W-E="@D;W!T:6]N<ULG8VAA;FYE;"==*2D@>PT*("`@("`@("`@
M("`@:68@*"$D<F5G+3YC:&%N;F5L17AI<W1S*"1O<'1I;VYS6R=C:&%N;F5L
M)UTI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"=5;FMN;W=N(&-H86YN96P@(B<@+B`D;W!T:6]N<ULG8VAA;FYE;"==
M("X@)R(G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T:&ES+3YC
M;VYF:6<M/G-E="@G9&5F875L=%]C:&%N;F5L)RP@)&]P=&EO;G-;)V-H86YN
M96PG72D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=&AI<RT^
M8V]N9FEG+3YS970H)V1E9F%U;'1?8VAA;FYE;"<L("=P96%R+G!H<"YN970G
M*3L-"B`@("`@("`@?0T*("`@("`@("`D<F5M;W1E(#T@)B1T:&ES+3YC;VYF
M:6<M/F=E=%)E;6]T92@I.PT*("`@("`@("`D8VAA;FYE;',@/2`D<F5M;W1E
M+3YC86QL*"=C:&%N;F5L+FQI<W1!;&PG*3L-"B`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&-H86YN96QS*2D@>PT*("`@("`@("`@("`@)'1H:7,M/F-O
M;F9I9RT^<V5T*"=D969A=6QT7V-H86YN96PG+"`D<V%V96-H86YN96PI.PT*
M("`@("`@("`@("`@<F5T=7)N("1C:&%N;F5L<SL-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H(6ES7V%R<F%Y*"1C:&%N;F5L<RD@?'P@:7-S970H)&-H86YN
M96QS6R=F875L=$-O9&4G72DI('L-"B`@("`@("`@("`@("1T:&ES+3YC;VYF
M:6<M/G-E="@G9&5F875L=%]C:&%N;F5L)RP@)'-A=F5C:&%N;F5L*3L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B26YC;W)R96-T
M(&-H86YN96P@;&ES=&EN9R!R971U<FYE9"!F<F]M(&-H86YN96P@)R1C:&%N
M)R(I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A8V]U;G0H)&-H86YN96QS
M*2D@>PT*("`@("`@("`@("`@)&1A=&$@/2`G;F\@=7!D871E<R!A=F%I;&%B
M;&4G.PT*("`@("`@("!]#0H@("`@("`@("1D;"`]("8D=&AI<RT^9V5T1&]W
M;FQO861E<B@I.PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4WES=&5M
M)RDI('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4WES=&5M+G!H<"<[
M#0H@("`@("`@('T-"B`@("`@("`@)'1M<&1I<B`](%-Y<W1E;3HZ;6MT96UP
M*&%R<F%Y*"<M9"<I*3L-"B`@("`@("`@9F]R96%C:"`H)&-H86YN96QS(&%S
M("1C:&%N;F5L*2![#0H@("`@("`@("`@("`D8VAA;FYE;"`]("1C:&%N;F5L
M6S!=.PT*("`@("`@("`@("`@)'-A=F4@/2`D8VAA;FYE;#L-"B`@("`@("`@
M("`@(&EF("@D<F5G+3YC:&%N;F5L17AI<W1S*"1C:&%N;F5L+"!T<G5E*2D@
M>PT*("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@B57!D
M871I;F<@8VAA;FYE;"!<(B1C:&%N;F5L7"(B+"`D8V]M;6%N9"D[#0H@("`@
M("`@("`@("`@("`@)'1E<W0@/2`D<F5G+3YG971#:&%N;F5L*"1C:&%N;F5L
M+"!T<G5E*3L-"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M=&5S="DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P
M=71$871A*")#:&%N;F5L("<D8VAA;FYE;"<@:7,@8V]R<G5P="!I;B!R96=I
M<W1R>2$B+"`D8V]M;6%N9"D[#0H@("`@("`@("`@("`@("`@("`@("1L87-T
M;6]D:69I960@/2!F86QS93L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`D;&%S=&UO9&EF:65D(#T@)'1E<W0M/FQA
M<W1-;V1I9FEE9"@I.PT*("`@("`@("`@("`@("`@("`@("`-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4'5S:$5R
M<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`@("`@
M("`@("1C;VYT96YT<R`]("1D;"T^9&]W;FQO861(='1P*"=H='1P.B\O)R`N
M("1T97-T+3YG971.86UE*"D@+B`G+V-H86YN96PN>&UL)RP-"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G5I+"`D=&UP9&ER+"!N=6QL+"`D;&%S=&UO
M9&EF:65D*3L-"B`@("`@("`@("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O
M<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&-O;G1E;G1S*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M=6DM/F]U='!U=$1A=&$H)T524D]2.B!#86YN;W0@<F5T<FEE=F4@8VAA;FYE
M;"YX;6P@9F]R(&-H86YN96P@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@
M("`@)'1E<W0M/F=E=$YA;64H*2`N("<B)RP@)&-O;6UA;F0I.PT*("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@:68@*"$D8V]N=&5N=',I('L-"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*")#:&%N;F5L(%PB)&-H
M86YN96Q<(B!I<R!U<"UT;RUD871E(BP@)&-O;6UA;F0I.PT*("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@;&ES="@D8V]N=&5N=',L("1L87-T;6]D:69I960I(#T@
M)&-O;G1E;G1S.PT*("`@("`@("`@("`@("`@("1I;F9O(#T@:6UP;&]D92@G
M)RP@9FEL92@D8V]N=&5N=',I*3L-"B`@("`@("`@("`@("`@("!I9B`H(21I
M;F9O*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T
M1&%T82@B0VAA;FYE;"!<(B1C:&%N;F5L7"(@:7,@=7`M=&\M9&%T92(L("1C
M;VUM86YD*3L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@A8VQA<W-?97AI
M<W1S*"=014%27T-H86YN96Q&:6QE)RDI('L-"B`@("`@("`@("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E("=014%2+T-H86YN96Q&:6QE+G!H<"<[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1C:&%N;F5L:6YF;R`]
M(&YE=R!014%27T-H86YN96Q&:6QE.PT*("`@("`@("`@("`@("`@("1C:&%N
M;F5L:6YF;RT^9G)O;5AM;%-T<FEN9R@D:6YF;RD[#0H@("`@("`@("`@("`@
M("`@:68@*"1C:&%N;F5L:6YF;RT^9V5T17)R;W)S*"DI('L-"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*")$;W=N;&]A9&5D
M(&-H86YN96P@9&%T82!F<F]M(&-H86YN96P@7"(D8VAA;FYE;%PB("(@+B`-
M"B`@("`@("`@("`@("`@("`@("`@("`@("=I<R!C;W)R=7!T+"!S:VEP<&EN
M9R<L("1C;VUM86YD*3L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1C:&%N;F5L
M(#T@)&-H86YN96QI;F9O.PT*("`@("`@("`@("`@("`@(&EF("@D8VAA;FYE
M;"T^9V5T3F%M92@I("$]("1S879E*2![#0H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G15)23U(Z(%-E8W5R:71Y(')I<VL@
M+2!D;W=N;&]A9&5D(&-H86YN96P@)R`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`G9&5F:6YI=&EO;B!F:6QE(&9O<B!C:&%N;F5L("(G#0H@("`@("`@
M("`@("`@("`@("`@("`@("`N("1C:&%N;F5L+3YG971.86UE*"D@+B`G(&9R
M;VT@8VAA;FYE;"`B)R`N("1S879E("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("<B+B`@5&\@=7-E(&%N>7=A>2P@=7-E(&-H86YN96PM=7!D871E)RP@
M)&-O;6UA;F0I.PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)')E9RT^=7!D871E
M0VAA;FYE;"@D8VAA;FYE;"P@)&QA<W1M;V1I9FEE9"D[#0H@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(&EF("@D<F5G+3YI<T%L:6%S
M*"1C:&%N;F5L*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&5M<"`]("8D
M<F5G+3YG971#:&%N;F5L*"1C:&%N;F5L*3L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)'1E;7`I*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)'1E;7`I.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1T
M96UP+3YS971!;&EA<R@D=&5M<"T^9V5T3F%M92@I+"!T<G5E*3L@+R\@<V5T
M('1H92!A;&EA<R!T;R!T:&4@8VAA;FYE;"!N86UE#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@D<F5G+3YC:&%N;F5L17AI<W1S*"1T96UP+3YG971.86UE
M*"DI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U
M='!U=$1A=&$H)T524D]2.B!E>&ES=&EN9R!C:&%N;F5L("(G("X@)'1E;7`M
M/F=E=$YA;64H*2`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(@
M:7,@86QI87-E9"!T;R`B)R`N("1C:&%N;F5L("X@)R(@86QR96%D>2!A;F0@
M8V%N;F]T(&)E("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R
M92UA;&EA<V5D('1O("(G("X@)'1E;7`M/F=E=$YA;64H*2`N("<B(&)E8V%U
M<V4@82!C:&%N;F5L('=I=&@@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W1H870@;F%M92!O<B!A;&EA<R!A;')E861Y(&5X:7-T<R$@(%!L
M96%S92!R92UA;&EA<R!A;F0@=')Y("<@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=A9V%I;BXG+"`D8V]M;6%N9"D[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D=&AI<RT^=6DM
M/F]U='!U=$1A=&$H(D%D9&EN9R!N97<@8VAA;FYE;"!<(B1C:&%N;F5L7"(B
M+"`D8V]M;6%N9"D[#0H@("`@("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4'5S
M:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`@
M("`@("`@("1C;VYT96YT<R`]("1D;"T^9&]W;FQO861(='1P*"=H='1P.B\O
M)R`N("1C:&%N;F5L("X@)R]C:&%N;F5L+GAM;"<L#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YU:2P@)'1M<&1I<BP@;G5L;"P@9F%L<V4I.PT*("`@
M("`@("`@("`@("`@(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-
M"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8V]N=&5N=',I
M*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T
M82@G15)23U(Z($-A;FYO="!R971R:65V92!C:&%N;F5L+GAM;"!F;W(@8VAA
M;FYE;"`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`D8VAA;FYE;"`N
M("<B)RP@)&-O;6UA;F0I.PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@;&ES="@D
M8V]N=&5N=',L("1L87-T;6]D:69I960I(#T@)&-O;G1E;G1S.PT*("`@("`@
M("`@("`@("`@("1I;F9O(#T@:6UP;&]D92@G)RP@9FEL92@D8V]N=&5N=',I
M*3L-"B`@("`@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]#
M:&%N;F5L1FEL92<I*2![#0H@("`@("`@("`@("`@("`@("`@(')E<75I<F5?
M;VYC92`G4$5!4B]#:&%N;F5L1FEL92YP:'`G.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`D8VAA;FYE;&EN9F\@/2!N97<@4$5!4E]#
M:&%N;F5L9FEL93L-"B`@("`@("`@("`@("`@("`D8VAA;FYE;&EN9F\M/F9R
M;VU8;6Q3=')I;F<H)&EN9F\I.PT*("`@("`@("`@("`@("`@(&EF("@D8VAA
M;FYE;&EN9F\M/F=E=$5R<F]R<R@I*2![#0H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YU:2T^;W5T<'5T1&%T82@B1&]W;FQO861E9"!C:&%N;F5L(&1A
M=&$@9G)O;2!C:&%N;F5L(%PB)&-H86YN96Q<(B(@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@)R!I<R!C;W)R=7!T+"!S:VEP<&EN9R<L("1C;VUM86YD
M*3L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("1C:&%N;F5L(#T@)&-H86YN96QI
M;F9O.PT*("`@("`@("`@("`@("`@(&EF("@D8VAA;FYE;"T^9V5T3F%M92@I
M("$]("1S879E*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^
M;W5T<'5T1&%T82@G15)23U(Z(%-E8W5R:71Y(')I<VL@+2!D;W=N;&]A9&5D
M(&-H86YN96P@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G9&5F:6YI
M=&EO;B!F:6QE(&9O<B!C:&%N;F5L("(G#0H@("`@("`@("`@("`@("`@("`@
M("`@("`N("1C:&%N;F5L+3YG971.86UE*"D@+B`G(B!F<F]M(&-H86YN96P@
M(B<@+B`D<V%V92`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G(BX@(%1O
M('5S92!A;GEW87DL('5S92!C:&%N;F5L+75P9&%T92<L("1C;VUM86YD*3L-
M"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("1R96<M/F%D9$-H86YN96PH)&-H86YN
M96PL("1L87-T;6]D:69I960I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E="@G9&5F875L=%]C:&%N;F5L
M)RP@)'-A=F5C:&%N;F5L*3L-"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$
M871A*"=U<&1A=&4M8VAA;FYE;',@8V]M<&QE=&4G+"`D8V]M;6%N9"D[#0H@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"B`@("`-"B`@("!F=6YC=&EO
M;B!D;TEN9F\H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-
M"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`A/2`Q*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(DYO(&-H86YN96P@<W!E
M8VEF:65D(BD[#0H@("`@("`@('T-"B`@("`@("`@)')E9R`]("8D=&AI<RT^
M8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("`D8VAA;FYE;"`]('-T
M<G1O;&]W97(H)'!A<F%M<ULP72D[#0H@("`@("`@(&EF("@D<F5G+3YC:&%N
M;F5L17AI<W1S*"1C:&%N;F5L*2D@>PT*("`@("`@("`@("`@)&-H86X@/2`D
M<F5G+3YG971#:&%N;F5L*"1C:&%N;F5L*3L-"B`@("`@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1C:&%N*2D@>PT*("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@D8VAA;BD[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I9B`H<W1R<&]S*"1C:&%N
M;F5L+"`G.B\O)RDI('L-"B`@("`@("`@("`@("`@("`D9&]W;FQO861E<B`]
M("8D=&AI<RT^9V5T1&]W;FQO861E<B@I.PT*("`@("`@("`@("`@("`@(&EF
M("@A8VQA<W-?97AI<W1S*"=3>7-T96TG*2D@>PT*("`@("`@("`@("`@("`@
M("`@("!R97%U:7)E7V]N8V4@)U-Y<W1E;2YP:'`G.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`D=&UP9&ER(#T@4WES=&5M.CIM:W1E
M;7`H87)R87DH)RUD)RDI.PT*("`@("`@("`@("`@("`@(%!%05(Z.G-T871I
M8U!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@
M("`@("`@("`@("`D;&]C(#T@)&1O=VYL;V%D97(M/F1O=VYL;V%D2'1T<"@D
M8VAA;FYE;"P@)'1H:7,M/G5I+"`D=&UP9&ER*3L-"B`@("`@("`@("`@("`@
M("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)&QO8RDI('L-"B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#86YN;W0@;W!E
M;B`B)R`N("1C:&%N;F5L("X@)R(G*3L-"B`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`D8V]N=&5N=',@/2!I;7!L;V1E
M*"<G+"!F:6QE*"1L;V,I*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1F<"`]($!F;W!E;B@D
M<&%R86US6S!=+"`G<B<I.PT*("`@("`@("`@("`@("`@(&EF("@A)&9P*2![
M#0H@("`@("`@("`@("`@("`@("`@(&EF("A`9FEL95]E>&ES=',H)'!A<F%M
M<ULP72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@G0V%N;F]T(&]P96X@(B<@+B`D<&%R86US6S!=("X@
M)R(G*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G56YK
M;F]W;B!C:&%N;F5L("(G("X@)&-H86YN96P@+B`G(B<I.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("1C;VYT96YT<R`]("<G.PT*("`@("`@("`@("`@("`@('=H:6QE("@A
M9F5O9B@D9G`I*2![#0H@("`@("`@("`@("`@("`@("`@("1C;VYT96YT<R`N
M/2!F<F5A9"@D9G`L(#$P,C0I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T-H86YN96Q&:6QE)RDI
M('L-"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O0VAA;FYE
M;$9I;&4N<&AP)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1C:&%N
M(#T@;F5W(%!%05)?0VAA;FYE;$9I;&4[#0H@("`@("`@("`@("`D8VAA;BT^
M9G)O;5AM;%-T<FEN9R@D8V]N=&5N=',I.PT*("`@("`@("`@("`@)&-H86XM
M/G9A;&ED871E*"D[#0H@("`@("`@("`@("!I9B`H)&5R<G,@/2`D8VAA;BT^
M9V5T17)R;W)S*'1R=64I*2![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)&5R<G,@87,@)&5R<BD@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M=6DM/F]U='!U=$1A=&$H)&5R<ELG;&5V96PG72`N("<Z("<@+B`D97)R6R=M
M97-S86=E)UTI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-H86YN96P@9FEL92`B)R`N
M("1P87)A;7-;,%T@+B`G(B!I<R!N;W0@=F%L:60G*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&-H86XI('L-"B`@("`@("`@
M("`@("1C:&%N;F5L(#T@)&-H86XM/F=E=$YA;64H*3L-"B`@("`@("`@("`@
M("1C87!T:6]N(#T@)T-H86YN96P@)R`N("1C:&%N;F5L("X@)R!);F9O<FUA
M=&EO;CHG.PT*("`@("`@("`@("`@)&1A=&$Q(#T@87)R87DH#0H@("`@("`@
M("`@("`@("`@)V-A<'1I;VXG(#T^("1C87!T:6]N+`T*("`@("`@("`@("`@
M("`@("=B;W)D97(G(#T^('1R=64I.PT*("`@("`@("`@("`@)&1A=&$Q6R=D
M871A)UU;)W-E<G9E<B==(#T@87)R87DH)TYA;64@86YD(%-E<G9E<B<L("1C
M:&%N+3YG971.86UE*"DI.PT*("`@("`@("`@("`@:68@*"1C:&%N+3YG971!
M;&EA<R@I("$]("1C:&%N+3YG971.86UE*"DI('L-"B`@("`@("`@("`@("`@
M("`D9&%T83%;)V1A=&$G75LG86QI87,G72`](&%R<F%Y*"=!;&EA<R<L("1C
M:&%N+3YG971!;&EA<R@I*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("1D871A,5LG9&%T82==6R=S=6UM87)Y)UT@/2!A<G)A>2@G4W5M;6%R>2<L
M("1C:&%N+3YG9713=6UM87)Y*"DI.PT*("`@("`@("`@("`@)'9A;&ED871E
M(#T@)&-H86XM/F=E=%9A;&ED871I;VY086-K86=E*"D[#0H@("`@("`@("`@
M("`D9&%T83%;)V1A=&$G75LG=G!A8VMA9V4G72`](&%R<F%Y*"=686QI9&%T
M:6]N(%!A8VMA9V4@3F%M92<L("1V86QI9&%T95LG7V-O;G1E;G0G72D[#0H@
M("`@("`@("`@("`D9&%T83%;)V1A=&$G75LG=G!A8VMA9V5V97)S:6]N)UT@
M/0T*("`@("`@("`@("`@("`@(&%R<F%Y*"=686QI9&%T:6]N(%!A8VMA9V4@
M5F5R<VEO;B<L("1V86QI9&%T95LG871T<FEB<R==6R=V97)S:6]N)UTI.PT*
M("`@("`@("`@("`@)&0@/2!A<G)A>2@I.PT*("`@("`@("`@("`@)&1;)VUA
M:6XG72`]("1D871A,3L-"@T*("`@("`@("`@("`@)&1A=&%;)V1A=&$G72`]
M(&%R<F%Y*"D[#0H@("`@("`@("`@("`D9&%T85LG8V%P=&EO;B==(#T@)U-E
M<G9E<B!#87!A8FEL:71I97,G.PT*("`@("`@("`@("`@)&1A=&%;)VAE861L
M:6YE)UT@/2!A<G)A>2@G5'EP92<L("=697)S:6]N+U)%4U0@='EP92<L("=&
M=6YC=&EO;B!.86UE+U)%4U0@8F%S92<I.PT*("`@("`@("`@("`@)&-A<&%B
M:6QI=&EE<R`]("1C:&%N+3YG971&=6YC=&EO;G,H)WAM;')P8R<I.PT*("`@
M("`@("`@("`@)'-O87!S(#T@)&-H86XM/F=E=$9U;F-T:6]N<R@G<V]A<"<I
M.PT*("`@("`@("`@("`@:68@*"1C87!A8FEL:71I97,@?'P@)'-O87!S('Q\
M("1C:&%N+3YS=7!P;W)T<U)%4U0H*2D@>PT*("`@("`@("`@("`@("`@(&EF
M("@D8V%P86)I;&ET:65S*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)&-A<&%B:6QI=&EE<ULP72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1C87!A8FEL:71I97,@/2!A<G)A>2@D8V%P86)I;&ET:65S*3L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!F
M;W)E86-H("@D8V%P86)I;&ET:65S(&%S("1P<F]T;V-O;"D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&1A=&%;)V1A=&$G75M=(#T@87)R87DH)WAM
M;')P8R<L("1P<F]T;V-O;%LG871T<FEB<R==6R=V97)S:6]N)UTL#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'!R;W1O8V]L6R=?8V]N=&5N="==
M*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!I9B`H)'-O87!S*2![#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)'-O87!S6S!=*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)'-O87!S(#T@87)R87DH)'-O87!S*3L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M<V]A<',@87,@)'!R;W1O8V]L*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@G<V]A<"<L("1P<F]T;V-O;%LG
M871T<FEB<R==6R=V97)S:6]N)UTL#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!R;W1O8V]L6R=?8V]N=&5N="==*3L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I
M9B`H)&-H86XM/G-U<'!O<G1S4D535"@I*2![#0H@("`@("`@("`@("`@("`@
M("`@("1F=6YC<R`]("1C:&%N+3YG971&=6YC=&EO;G,H)W)E<W0G*3L-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9G5N8W-;,%TI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D9G5N8W,@/2!A<G)A>2@D9G5N8W,I
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1F=6YC<R!A<R`D<')O=&]C;VPI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1D871A6R=D871A)UU;72`](&%R<F%Y*"=R97-T)RP@
M)'!R;W1O8V]L6R=A='1R:6)S)UU;)W1Y<&4G72P-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<')O=&]C;VQ;)U]C;VYT96YT)UTI.R`-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&1A=&%;)V1A=&$G75M=
M(#T@87)R87DH)TYO('-U<'!O<G1E9"!P<F]T;V-O;',G*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("1D6R=P<F]T;V-O;',G72`]("1D871A.PT*
M("`@("`@("`@("`@)&1A=&%;)V1A=&$G72`](&%R<F%Y*"D[#0H@("`@("`@
M("`@("`D;6ER<F]R<R`]("1C:&%N+3YG971-:7)R;W)S*"D[#0H@("`@("`@
M("`@("!I9B`H)&UI<G)O<G,I('L-"B`@("`@("`@("`@("`@("`D9&%T85LG
M8V%P=&EO;B==(#T@)T-H86YN96P@)R`N("1C:&%N;F5L("X@)R!-:7)R;W)S
M.B<[#0H@("`@("`@("`@("`@("`@=6YS970H)&1A=&%;)VAE861L:6YE)UTI
M.PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1M:7)R;W)S(&%S("1M:7)R
M;W(I('L-"B`@("`@("`@("`@("`@("`@("`@)&1A=&%;)V1A=&$G75M=(#T@
M87)R87DH)&UI<G)O<ELG871T<FEB<R==6R=H;W-T)UTI.PT*("`@("`@("`@
M("`@("`@("`@("`D9%LG;6ER<F]R<R==(#T@)&1A=&$[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1M:7)R;W)S(&%S
M("1M:7)R;W(I('L-"B`@("`@("`@("`@("`@("`@("`@)&1A=&%;)V1A=&$G
M72`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@("`@("1D871A6R=C87!T
M:6]N)UT@/2`G36ER<F]R("<@+B`D;6ER<F]R6R=A='1R:6)S)UU;)VAO<W0G
M72`N("<@0V%P86)I;&ET:65S)SL-"B`@("`@("`@("`@("`@("`@("`@)&1A
M=&%;)VAE861L:6YE)UT@/2!A<G)A>2@G5'EP92<L("=697)S:6]N+U)%4U0@
M='EP92<L("=&=6YC=&EO;B!.86UE+U)%4U0@8F%S92<I.PT*("`@("`@("`@
M("`@("`@("`@("`D8V%P86)I;&ET:65S(#T@)&-H86XM/F=E=$9U;F-T:6]N
M<R@G>&UL<G!C)RP@)&UI<G)O<ELG871T<FEB<R==6R=H;W-T)UTI.PT*("`@
M("`@("`@("`@("`@("`@("`D<V]A<',@/2`D8VAA;BT^9V5T1G5N8W1I;VYS
M*"=S;V%P)RP@)&UI<G)O<ELG871T<FEB<R==6R=H;W-T)UTI.PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H)&-A<&%B:6QI=&EE<R!\?"`D<V]A<',@?'P@
M)&-H86XM/G-U<'!O<G1S4D535"@D;6ER<F]R6R=A='1R:6)S)UU;)VAO<W0G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D8V%P86)I;&ET
M:65S*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D8V%P86)I;&ET:65S6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D8V%P86)I;&ET:65S(#T@87)R87DH)&-A<&%B:6QI=&EE
M<RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1C87!A8FEL:71I97,@87,@
M)'!R;W1O8V]L*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D871A6R=D871A)UU;72`](&%R<F%Y*"=X;6QR<&,G+"`D<')O=&]C;VQ;
M)V%T=')I8G,G75LG=F5R<VEO;B==+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'!R;W1O8V]L6R=?8V]N=&5N="==*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'-O87!S*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<V]A
M<'-;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S
M;V%P<R`](&%R<F%Y*"1S;V%P<RD[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1S;V%P<R!A<R`D<')O=&]C;VPI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&1A=&%;)V1A=&$G75M=(#T@87)R87DH)W-O87`G+"`D
M<')O=&]C;VQ;)V%T=')I8G,G75LG=F5R<VEO;B==+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'!R;W1O8V]L6R=?8V]N=&5N="==
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M)&-H86XM/G-U<'!O<G1S4D535"@D;6ER<F]R6R=A='1R:6)S)UU;)VAO<W0G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9G5N8W,@/2`D
M8VAA;BT^9V5T1G5N8W1I;VYS*"=R97-T)RP@)&UI<G)O<ELG871T<FEB<R==
M6R=H;W-T)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)&9U;F-S6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9G5N8W,@/2!A<G)A>2@D9G5N8W,I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D9G5N8W,@87,@)'!R;W1O8V]L*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1D871A6R=D871A)UU;72`](&%R<F%Y
M*"=R97-T)RP@)'!R;W1O8V]L6R=A='1R:6)S)UU;)W1Y<&4G72P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<F]T;V-O;%LG7V-O
M;G1E;G0G72D[(`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1D871A6R=D871A
M)UU;72`](&%R<F%Y*"=.;R!S=7!P;W)T960@<')O=&]C;VQS)RD[#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)&1;)VUI
M<G)O<G!R;W1O8V]L<R==(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$
M871A*"1D+"`G8VAA;FYE;"UI;F9O)RD[#0H@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)U-E<FEO=7,@
M97)R;W(Z($-H86YN96P@(B<@+B`D<&%R86US6S!=("X-"B`@("`@("`@("`@
M("`@("`G(B!H87,@82!C;W)R=7!T960@<F5G:7-T<GD@96YT<GDG*3L-"B`@
M("`@("`@?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@(`T*("`@(&9U;F-T
M:6]N(&1O1&5L971E*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@
M("![#0H@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@(3T@,2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=C:&%N;F5L+61E
M;&5T93H@;F\@8VAA;FYE;"!S<&5C:69I960G*3L-"B`@("`@("`@?0T*("`@
M("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@
M("`@("`@(&EF("@A)')E9RT^8VAA;FYE;$5X:7-T<R@D<&%R86US6S!=*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=C:&%N
M;F5L+61E;&5T93H@8VAA;FYE;"`B)R`N("1P87)A;7-;,%T@+B`G(B!D;V5S
M(&YO="!E>&ES="<I.PT*("`@("`@("!]#0H@("`@("`@("1C:&%N;F5L(#T@
M)')E9RT^8VAA;FYE;$YA;64H)'!A<F%M<ULP72D[#0H@("`@("`@(&EF("@D
M8VAA;FYE;"`]/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*"=#86YN;W0@9&5L971E('1H92!P96%R
M+G!H<"YN970@8VAA;FYE;"<I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M8VAA;FYE;"`]/2`G<&5C;"YP:'`N;F5T)RD@>PT*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*"=#86YN;W0@9&5L971E('1H92!P96-L
M+G!H<"YN970@8VAA;FYE;"<I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M8VAA;FYE;"`]/2`G7U]U<FDG*2![#0H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H)T-A;FYO="!D96QE=&4@=&AE(%]?=7)I('!S975D
M;RUC:&%N;F5L)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)&5R<B`]("1R96<M/FQI<W1086-K86=E<R@D8VAA;FYE;"DI*2![
M#0H@("`@("`@("`@("!R971U<FX@)&5R<CL-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H8V]U;G0H)&5R<BDI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@G0VAA;FYE;"`B)R`N("1C:&%N;F5L("X-"B`@("`@
M("`@("`@("`@("`G(B!H87,@:6YS=&%L;&5D('!A8VMA9V5S+"!C86YN;W0@
M9&5L971E)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D<F5G+3YD96QE
M=&5#:&%N;F5L*"1C:&%N;F5L*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*"=#:&%N;F5L("(G("X@)&-H86YN96P@+B`G(B!D
M96QE=&EO;B!F86EL960G*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("1T:&ES+3YC;VYF:6<M/F1E;&5T94-H86YN96PH)&-H86YN96PI.PT*
M("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"=#:&%N;F5L("(G
M("X@)&-H86YN96P@+B`G(B!D96QE=&5D)RP@)&-O;6UA;F0I.PT*("`@("`@
M("!]#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9&]!9&0H)&-O;6UA;F0L("1O
M<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@:68@*'-I>F5O9B@D
M<&%R86US*2`A/2`Q*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H)V-H86YN96PM861D.B!N;R!C:&%N;F5L(&9I;&4@<W!E8VEF
M:65D)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*'-T<G!O<R@D<&%R86US
M6S!=+"`G.B\O)RDI('L-"B`@("`@("`@("`@("1D;W=N;&]A9&5R(#T@)B1T
M:&ES+3YG971$;W=N;&]A9&5R*"D[#0H@("`@("`@("`@("!I9B`H(6-L87-S
M7V5X:7-T<R@G4WES=&5M)RDI('L-"B`@("`@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)U-Y<W1E;2YP:'`G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@)'1M<&1I<B`](%-Y<W1E;3HZ;6MT96UP*&%R<F%Y*"<M9"<I*3L-"B`@
M("`@("`@("`@(%!%05(Z.G-T871I8U!U<VA%<G)O<DAA;F1L:6YG*%!%05)?
M15)23U)?4D5455).*3L-"B`@("`@("`@("`@("1L;V,@/2`D9&]W;FQO861E
M<BT^9&]W;FQO861(='1P*"1P87)A;7-;,%TL("1T:&ES+3YU:2P@)'1M<&1I
M<BP@;G5L;"P@9F%L<V4I.PT*("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4&]P
M17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&QO8RDI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H)V-H86YN96PM861D.B!#86YN;W0@;W!E;B`B)R`N("1P87)A
M;7-;,%T@+B`G(B<I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("!L:7-T*"1L;V,L("1L87-T;6]D:69I960I(#T@)&QO8SL-"B`@
M("`@("`@("`@("`@("`D8V]N=&5N=',@/2!I;7!L;V1E*"<G+"!F:6QE*"1L
M;V,I*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1L87-T;6]D:69I960@/2!F86QS93L-"B`@("`@("`@("`@("1F
M<"`]($!F;W!E;B@D<&%R86US6S!=+"`G<B<I.PT*("`@("`@("`@("`@:68@
M*"$D9G`I('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)V-H86YN96PM861D.B!C86YN;W0@;W!E;B`B)R`N("1P87)A;7-;
M,%T@+B`G(B<I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&-O;G1E
M;G1S(#T@)R<[#0H@("`@("`@("`@("!W:&EL92`H(69E;V8H)&9P*2D@>PT*
M("`@("`@("`@("`@("`@("1C;VYT96YT<R`N/2!F<F5A9"@D9G`L(#$P,C0I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?0VAA
M;FYE;$9I;&4G*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2
M+T-H86YN96Q&:6QE+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@)&-H86YN
M96P@/2!N97<@4$5!4E]#:&%N;F5L1FEL93L-"B`@("`@("`@4$5!4CHZ<W1A
M=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@
M("`@("`D<F5S=6QT(#T@)&-H86YN96PM/F9R;VU8;6Q3=')I;F<H)&-O;G1E
M;G1S*3L-"B`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN9R@I
M.PT*("`@("`@("!I9B`H(21R97-U;'0I('L-"B`@("`@("`@("`@("1E>&ET
M(#T@9F%L<V4[#0H@("`@("`@("`@("!I9B`H8V]U;G0H)&5R<F]R<R`]("1C
M:&%N;F5L+3YG971%<G)O<G,H=')U92DI*2![#0H@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)&5R<F]R<R!A<R`D97)R;W(I('L-"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*'5C9FER<W0H)&5R<F]R6R=L
M979E;"==("X@)SH@)R`N("1E<G)O<ELG;65S<V%G92==*2D[#0H@("`@("`@
M("`@("`@("`@("`@(&EF("@A)&5X:70I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1E>&ET(#T@)&5R<F]R6R=L979E;"==(#T]("=E<G)O<B<@/R!T
M<G5E(#H@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1E>&ET*2![#0H@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G8VAA
M;FYE;"UA9&0Z(&EN=F%L:60@8VAA;FYE;"YX;6P@9FEL92<I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@
M("`@(&EF("@D<F5G+3YC:&%N;F5L17AI<W1S*"1C:&%N;F5L+3YG971.86UE
M*"DI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M)V-H86YN96PM861D.B!#:&%N;F5L("(G("X@)&-H86YN96PM/F=E=$YA;64H
M*2`N#0H@("`@("`@("`@("`@("`@)R(@97AI<W1S+"!U<V4@8VAA;FYE;"UU
M<&1A=&4@=&\@=7!D871E(&5N=')Y)RD[#0H@("`@("`@('T-"B`@("`@("`@
M)')E="`]("1R96<M/F%D9$-H86YN96PH)&-H86YN96PL("1L87-T;6]D:69I
M960I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5T*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1R970[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"$D<F5T*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H)V-H86YN96PM861D.B!A9&1I;F<@0VAA;FYE;"`B)R`N("1C:&%N;F5L
M+3YG971.86UE*"D@+@T*("`@("`@("`@("`@("`@("<B('1O(')E9VES=')Y
M(&9A:6QE9"<I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YC;VYF:6<M
M/G-E=$-H86YN96QS*"1R96<M/FQI<W1#:&%N;F5L<R@I*3L-"B`@("`@("`@
M)'1H:7,M/F-O;F9I9RT^=W)I=&5#;VYF:6=&:6QE*"D[#0H@("`@("`@("1T
M:&ES+3YU:2T^;W5T<'5T1&%T82@G061D:6YG($-H86YN96P@(B<@+B`D8VAA
M;FYE;"T^9V5T3F%M92@I("X@)R(@<W5C8V5E9&5D)RP@)&-O;6UA;F0I.PT*
M("`@('T-"@T*("`@(&9U;F-T:6]N(&1O57!D871E*"1C;VUM86YD+"`D;W!T
M:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@(&EF("@A8VQA<W-?97AI
M<W1S*"=3>7-T96TG*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=3
M>7-T96TN<&AP)SL-"B`@("`@("`@?0T*("`@("`@("`D=&UP9&ER(#T@4WES
M=&5M.CIM:W1E;7`H87)R87DH)RUD)RDI.PT*("`@("`@("`D<F5G(#T@)B1T
M:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@(&EF("AS:7IE
M;V8H)'!A<F%M<RD@(3T@,2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*").;R!C:&%N;F5L(&9I;&4@<W!E8VEF:65D(BD[#0H@
M("`@("`@('T-"B`@("`@("`@)&QA<W1M;V1I9FEE9"`](&9A;'-E.PT*("`@
M("`@("!I9B`H*"%F:6QE7V5X:7-T<R@D<&%R86US6S!=*2!\?"!I<U]D:7(H
M)'!A<F%M<ULP72DI#0H@("`@("`@("`@("`@("8F("1R96<M/F-H86YN96Q%
M>&ES=',H<W1R=&]L;W=E<B@D<&%R86US6S!=*2DI('L-"B`@("`@("`@("`@
M("1C(#T@)')E9RT^9V5T0VAA;FYE;"AS=')T;VQO=V5R*"1P87)A;7-;,%TI
M*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C*2D@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D8RD[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A
M=&$H)U)E=')I979I;F<@8VAA;FYE;"YX;6P@9G)O;2!R96UO=&4@<V5R=F5R
M)RD[#0H@("`@("`@("`@("`D9&P@/2`F)'1H:7,M/F=E=$1O=VYL;V%D97(H
M87)R87DH*2D[#0H@("`@("`@("`@("`O+R!I9B!F;W)C92!I<R!S<&5C:69I
M960L('5S92!A('1I;65S=&%M<"!O9B`B,2(@=&\@9F]R8V4@<F5T<FEE=F%L
M#0H@("`@("`@("`@("`D;&%S=&UO9&EF:65D(#T@:7-S970H)&]P=&EO;G-;
M)V9O<F-E)UTI(#\@9F%L<V4@.B`D8RT^;&%S=$UO9&EF:65D*"D[#0H@("`@
M("`@("`@("!014%2.CIS=&%T:6-0=7-H17)R;W)(86YD;&EN9RA014%27T52
M4D]27U)%5%523BD[#0H@("`@("`@("`@("`D8V]N=&5N=',@/2`D9&PM/F1O
M=VYL;V%D2'1T<"@G:'1T<#HO+R<@+B`D8RT^9V5T3F%M92@I("X@)R]C:&%N
M;F5L+GAM;"<L#0H@("`@("`@("`@("`@("`@)'1H:7,M/G5I+"`D=&UP9&ER
M+"!N=6QL+"`D;&%S=&UO9&EF:65D*3L-"B`@("`@("`@("`@(%!%05(Z.G-T
M871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1C;VYT96YT<RDI('L-"B`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-A;FYO="!R971R:65V92!C:&%N;F5L
M+GAM;"!F;W(@8VAA;FYE;"`B)R`N#0H@("`@("`@("`@("`@("`@("`@("1C
M+3YG971.86UE*"D@+B`G(B<I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@;&ES="@D8V]N=&5N=',L("1L87-T;6]D:69I960I(#T@)&-O;G1E;G1S
M.PT*("`@("`@("`@("`@:68@*"$D8V]N=&5N=',I('L-"B`@("`@("`@("`@
M("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H(D-H86YN96P@)'!A<F%M<ULP
M72!C:&%N;F5L+GAM;"!I<R!U<"!T;R!D871E(BD[#0H@("`@("`@("`@("`@
M("`@<F5T=7)N.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&-O;G1E
M;G1S(#T@:6UP;&]D92@G)RP@9FEL92@D8V]N=&5N=',I*3L-"B`@("`@("`@
M("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T-H86YN96Q&:6QE)RDI('L-
M"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O0VAA;FYE;$9I
M;&4N<&AP)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1C:&%N;F5L
M(#T@;F5W(%!%05)?0VAA;FYE;$9I;&4[#0H@("`@("`@("`@("`D8VAA;FYE
M;"T^9G)O;5AM;%-T<FEN9R@D8V]N=&5N=',I.PT*("`@("`@("`@("`@:68@
M*"$D8VAA;FYE;"T^9V5T17)R;W)S*"DI('L-"B`@("`@("`@("`@("`@("`O
M+R!S96-U<FET>2!C:&5C:SH@:7,@=&AE(&1O=VYL;V%D960@9FEL92!F;W(@
M=&AE(&-H86YN96P@=V4@9V]T(&ET(&9R;VT_#0H@("`@("`@("`@("`@("`@
M:68@*'-T<G1O;&]W97(H)&-H86YN96PM/F=E=$YA;64H*2D@(3T@<W1R=&]L
M;W=E<B@D8RT^9V5T3F%M92@I*2D@>PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)&]P=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^=6DM/FQO9R@P+"`G5T%23DE.1SH@9&]W;FQO
M861E9"!C:&%N;F5L(&1E9FEN:71I;VX@9FEL92<@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("<@9F]R(&-H86YN96P@(B<@+B`D8VAA;FYE;"T^
M9V5T3F%M92@I("X@)R(@9G)O;2!C:&%N;F5L("(G("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!S=')T;VQO=V5R*"1C+3YG971.86UE*"DI("X@
M)R(G*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G15)2
M3U(Z(&1O=VYL;V%D960@8VAA;FYE;"!D969I;FET:6]N(&9I;&4G("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G(&9O<B!C:&%N;F5L("(G("X@
M)&-H86YN96PM/F=E=$YA;64H*2`N("<B(&9R;VT@8VAA;FYE;"`B)R`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R=&]L;W=E<B@D8RT^9V5T
M3F%M92@I*2`N("<B)RD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("!I9B`H<W1R<&]S*"1P87)A;7-;,%TL("<Z+R\G*2D@
M>PT*("`@("`@("`@("`@("`@("1D;"`]("8D=&AI<RT^9V5T1&]W;FQO861E
M<B@I.PT*("`@("`@("`@("`@("`@(%!%05(Z.G-T871I8U!U<VA%<G)O<DAA
M;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@("`@("`@("`D
M;&]C(#T@)&1L+3YD;W=N;&]A9$AT='`H)'!A<F%M<ULP72P-"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G5I+"`D=&UP9&ER+"!N=6QL+"`D;&%S=&UO
M9&EF:65D*3L-"B`@("`@("`@("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O
M<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&QO8RDI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*")#86YN;W0@;W!E;B`B("X@)'!A<F%M<ULP72D[#0H@
M("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@
M;&ES="@D;&]C+"`D;&%S=&UO9&EF:65D*2`]("1L;V,[#0H@("`@("`@("`@
M("`@("`@("`@("1C;VYT96YT<R`](&EM<&QO9&4H)R<L(&9I;&4H)&QO8RDI
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@)&9P(#T@0&9O<&5N*"1P87)A;7-;,%TL("=R)RD[
M#0H@("`@("`@("`@("`@("`@:68@*"$D9G`I('L-"B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")#86YN;W0@;W!E;B`B
M("X@)'!A<F%M<ULP72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("1C;VYT96YT<R`]("<G.PT*("`@("`@("`@("`@("`@('=H:6QE
M("@A9F5O9B@D9G`I*2![#0H@("`@("`@("`@("`@("`@("`@("1C;VYT96YT
M<R`N/2!F<F5A9"@D9G`L(#$P,C0I.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T-H86YN96Q&:6QE
M)RDI('L-"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O0VAA
M;FYE;$9I;&4N<&AP)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1C
M:&%N;F5L(#T@;F5W(%!%05)?0VAA;FYE;$9I;&4[#0H@("`@("`@("`@("`D
M8VAA;FYE;"T^9G)O;5AM;%-T<FEN9R@D8V]N=&5N=',I.PT*("`@("`@("!]
M#0H@("`@("`@("1E>&ET(#T@9F%L<V4[#0H@("`@("`@(&EF("AC;W5N="@D
M97)R;W)S(#T@)&-H86YN96PM/F=E=$5R<F]R<RAT<G5E*2DI('L-"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1E<G)O<G,@87,@)&5R<F]R*2![#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*'5C9FER<W0H)&5R<F]R
M6R=L979E;"==("X@)SH@)R`N("1E<G)O<ELG;65S<V%G92==*2D[#0H@("`@
M("`@("`@("`@("`@:68@*"$D97AI="D@>PT*("`@("`@("`@("`@("`@("`@
M("`D97AI="`]("1E<G)O<ELG;&5V96PG72`]/2`G97)R;W(G(#\@=')U92`Z
M(&9A;'-E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("@D97AI="D@>PT*("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@G26YV86QI9"!C:&%N;F5L+GAM;"!F:6QE
M)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D
M<F5G+3YC:&%N;F5L17AI<W1S*"1C:&%N;F5L+3YG971.86UE*"DI*2![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T5R<F]R.B!#
M:&%N;F5L("(G("X@)&-H86YN96PM/F=E=$YA;64H*2`N#0H@("`@("`@("`@
M("`@("`@)R(@9&]E<R!N;W0@97AI<W0L('5S92!C:&%N;F5L+6%D9"!T;R!A
M9&0@86X@96YT<GDG*3L-"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@)')E
M9RT^=7!D871E0VAA;FYE;"@D8VAA;FYE;"P@)&QA<W1M;V1I9FEE9"D[#0H@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R970I*2![#0H@("`@("`@("`@
M("!R971U<FX@)')E=#L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21R970I
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G57!D
M871I;F<@0VAA;FYE;"`B)R`N("1C:&%N;F5L+3YG971.86UE*"D@+@T*("`@
M("`@("`@("`@("`@("<B(&EN(')E9VES=')Y(&9A:6QE9"<I.PT*("`@("`@
M("!]#0H@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E=$-H86YN96QS*"1R96<M
M/FQI<W1#:&%N;F5L<R@I*3L-"B`@("`@("`@)'1H:7,M/F-O;F9I9RT^=W)I
M=&5#;VYF:6=&:6QE*"D[#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T
M82@G57!D871E(&]F($-H86YN96P@(B<@+B`D8VAA;FYE;"T^9V5T3F%M92@I
M("X@)R(@<W5C8V5E9&5D)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@)F=E
M=$1O=VYL;V%D97(H*0T*("`@('L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES
M=',H)U!%05)?1&]W;FQO861E<B<I*2![#0H@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)U!%05(O1&]W;FQO861E<BYP:'`G.PT*("`@("`@("!]#0H@("`@
M("`@("1A(#T@;F5W(%!%05)?1&]W;FQO861E<B@D=&AI<RT^=6DL(&%R<F%Y
M*"DL("1T:&ES+3YC;VYF:6<I.PT*("`@("`@("!R971U<FX@)&$[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@9&]!;&EA<R@D8V]M;6%N9"P@)&]P=&EO;G,L
M("1P87)A;7,I#0H@("`@>PT*("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF
M:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M
M<RD@/3T@,2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"=.;R!C:&%N;F5L(&%L:6%S('-P96-I9FEE9"<I.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@(3T@,BD@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*`T*("`@("`@("`@("`@
M("`@("=);G9A;&ED(&9O<FUA="P@8V]R<F5C="!I<SH@8VAA;FYE;"UA;&EA
M<R!C:&%N;F5L(&%L:6%S)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D
M<F5G+3YC:&%N;F5L17AI<W1S*"1P87)A;7-;,%TL('1R=64I*2![#0H@("`@
M("`@("`@("!I9B`H)')E9RT^:7-!;&EA<R@D<&%R86US6S!=*2D@>PT*("`@
M("`@("`@("`@("`@("1E>'1R82`]("<@*'5S92`B8VAA;FYE;"UA;&EA<R`G
M("X@)')E9RT^8VAA;FYE;$YA;64H)'!A<F%M<ULP72D@+B`G("<@+@T*("`@
M("`@("`@("`@("`@("`@("!S=')T;VQO=V5R*"1P87)A;7-;,5TI("X@)R(I
M)SL-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&5X
M=')A(#T@)R<[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)R(G("X@)'!A<F%M<ULP72`N("<B(&ES(&YO
M="!A('9A;&ED(&-H86YN96PG("X@)&5X=')A*3L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H)')E9RT^:7-!;&EA<R@D<&%R86US6S%=*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#:&%N;F5L("(G("X@
M)')E9RT^8VAA;FYE;$YA;64H)'!A<F%M<ULQ72D@+B`G(B!I<R`G("X-"B`@
M("`@("`@("`@("`@("`G86QR96%D>2!A;&EA<V5D('1O("(G("X@<W1R=&]L
M;W=E<B@D<&%R86US6S%=*2`N("<B+"!C86YN;W0@<F4M86QI87,G*3L-"B`@
M("`@("`@?0T*("`@("`@("`D8VAA;B`]("8D<F5G+3YG971#:&%N;F5L*"1P
M87)A;7-;,%TI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VAA;BDI
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V]R
M<G5P="!R96=I<W1R>3\@($5R<F]R(')E=')I979I;F<@8VAA;FYE;"`B)R`N
M("1P87)A;7-;,%T@+@T*("`@("`@("`@("`@("`@("<B(&EN9F]R;6%T:6]N
M("@G("X@)&-H86XM/F=E=$UE<W-A9V4H*2`N("<I)RD[#0H@("`@("`@('T-
M"B`@("`@("`@+R\@;6%K92!I="!A(&QO8V%L(&%L:6%S#0H@("`@("`@(&EF
M("@A)&-H86XM/G-E=$%L:6%S*'-T<G1O;&]W97(H)'!A<F%M<ULQ72DL('1R
M=64I*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M)T%L:6%S("(G("X@<W1R=&]L;W=E<B@D<&%R86US6S%=*2`N#0H@("`@("`@
M("`@("`@("`@)R(@:7,@;F]T(&$@=F%L:60@8VAA;FYE;"!A;&EA<R<I.PT*
M("`@("`@("!]#0H@("`@("`@("1R96<M/G5P9&%T94-H86YN96PH)&-H86XI
M.PT*("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)T-H86YN96P@(B<@
M+B`D8VAA;BT^9V5T3F%M92@I("X@)R(@86QI87-E9"!S=6-C97-S9G5L;'D@
M=&\@(B<@+@T*("`@("`@("`@("`@<W1R=&]L;W=E<B@D<&%R86US6S%=*2`N
M("<B)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9&]$:7-C;W9E<B@D8V]M
M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@("`D<F5G
M(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@(&EF
M("AS:7IE;V8H)'!A<F%M<RD@(3T@,2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*").;R!C:&%N;F5L('-E<G9E<B!S<&5C:69I
M960B*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)')E9RT^8VAA;FYE;$5X
M:7-T<R@D<&%R86US6S!=*2D@>PT*("`@("`@("`@("`@:68@*"1R96<M/FES
M06QI87,H)'!A<F%M<ULP72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H(D$@8VAA;FYE;"!A;&EA<R!N86UE9"!<(B1P
M87)A;7-;,%U<(B`B("X-"B`@("`@("`@("`@("`@("`@("`@)V%L<F5A9'D@
M97AI<W1S+"!A;&EA<VEN9R!C:&%N;F5L("(G("X@)')E9RT^8VAA;FYE;$YA
M;64H)'!A<F%M<ULP72D-"B`@("`@("`@("`@("`@("`@("`@+B`G(B<I.PT*
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H(D-H86YN96P@7"(D<&%R86US6S!=7"(@:7,@
M86QR96%D>2!I;FET:6%L:7IE9"(I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@("1T:&ES+3YP=7-H17)R;W)(86YD;&EN9RA014%27T52
M4D]27U)%5%523BD[#0H@("`@("`@("1E<G(@/2`D=&AI<RT^9&]!9&0H)&-O
M;6UA;F0L("1O<'1I;VYS+"!A<G)A>2@G:'1T<#HO+R<@+B`D<&%R86US6S!=
M("X@)R]C:&%N;F5L+GAM;"<I*3L-"B`@("`@("`@)'1H:7,M/G!O<$5R<F]R
M2&%N9&QI;F<H*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<BDI
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B1&ES
M8V]V97)Y(&]F(&-H86YN96P@7"(D<&%R86US6S!=7"(@9F%I;&5D("@B("X-
M"B`@("`@("`@("`@("`@("`D97)R+3YG971-97-S86=E*"D@+B`G*2<I.PT*
M("`@("`@("!]#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@B1&ES
M8V]V97)Y(&]F(&-H86YN96P@7"(D<&%R86US6S!=7"(@<W5C8V5E9&5D(BP@
M)&-O;6UA;F0I.PT*("`@('T-"GT-"C\^#0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]#:&%N;F5L
M<RYX;6P`````````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U,C<Q`#$P-3$U
M-#,S-S0P`#`R,S$W,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\8V]M;6%N9',@=F5R<VEO;CTB,2XP(CX-"B`\;&ES="UC
M:&%N;F5L<SX-"B`@/'-U;6UA<GD^3&ES="!!=F%I;&%B;&4@0VAA;FYE;',\
M+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;TQI<W0\+V9U;F-T:6]N/@T*("`\
M<VAO<G1C=70^;&,\+W-H;W)T8W5T/@T*("`\;W!T:6]N<R`O/@T*("`\9&]C
M/@T*3&ES="!A;&P@879A:6QA8FQE(&-H86YN96QS(&9O<B!I;G-T86QL871I
M;VXN#0H\+V1O8SX-"B`\+VQI<W0M8VAA;FYE;',^#0H@/'5P9&%T92UC:&%N
M;F5L<SX-"B`@/'-U;6UA<GD^57!D871E('1H92!#:&%N;F5L($QI<W0\+W-U
M;6UA<GD^#0H@(#QF=6YC=&EO;CYD;U5P9&%T94%L;#PO9G5N8W1I;VX^#0H@
M(#QS:&]R=&-U=#YU8SPO<VAO<G1C=70^#0H@(#QO<'1I;VYS("\^#0H@(#QD
M;V,^#0I,:7-T(&%L;"!I;G-T86QL960@<&%C:V%G97,@:6X@86QL(&-H86YN
M96QS+@T*/"]D;V,^#0H@/"]U<&1A=&4M8VAA;FYE;',^#0H@/&-H86YN96PM
M9&5L971E/@T*("`\<W5M;6%R>3Y296UO=F4@82!#:&%N;F5L($9R;VT@=&AE
M($QI<W0\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;T1E;&5T93PO9G5N8W1I
M;VX^#0H@(#QS:&]R=&-U=#YC9&4\+W-H;W)T8W5T/@T*("`\;W!T:6]N<R`O
M/@T*("`\9&]C/B9L=#MC:&%N;F5L(&YA;64F9W0[#0I$96QE=&4@82!C:&%N
M;F5L(&9R;VT@=&AE(')E9VES=')Y+B`@66]U(&UA>2!N;W0-"G)E;6]V92!A
M;GD@8VAA;FYE;"!T:&%T(&AA<R!I;G-T86QL960@<&%C:V%G97,N#0H\+V1O
M8SX-"B`\+V-H86YN96PM9&5L971E/@T*(#QC:&%N;F5L+6%D9#X-"B`@/'-U
M;6UA<GD^061D(&$@0VAA;FYE;#PO<W5M;6%R>3X-"B`@/&9U;F-T:6]N/F1O
M061D/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/F-A/"]S:&]R=&-U=#X-"B`@
M/&]P=&EO;G,@+SX-"B`@/&1O8SXF;'0[8VAA;FYE;"YX;6PF9W0[#0I!9&0@
M82!P<FEV871E(&-H86YN96P@=&\@=&AE(&-H86YN96P@;&ES="X@($YO=&4@
M=&AA="!A;&P-"G!U8FQI8R!C:&%N;F5L<R!S:&]U;&0@8F4@<WEN8V5D('5S
M:6YG("9Q=6]T.W5P9&%T92UC:&%N;F5L<R9Q=6]T.RX-"E!A<F%M971E<B!M
M87D@8F4@96ET:&5R(&$@;&]C86P@9FEL92!O<B!R96UO=&4@55),('1O(&$-
M"F-H86YN96PN>&UL+@T*/"]D;V,^#0H@/"]C:&%N;F5L+6%D9#X-"B`\8VAA
M;FYE;"UU<&1A=&4^#0H@(#QS=6UM87)Y/E5P9&%T92!A;B!%>&ES=&EN9R!#
M:&%N;F5L/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]5<&1A=&4\+V9U;F-T
M:6]N/@T*("`\<VAO<G1C=70^8W4\+W-H;W)T8W5T/@T*("`\;W!T:6]N<SX-
M"B`@(#QF;W)C93X-"B`@("`\<VAO<G1O<'0^9CPO<VAO<G1O<'0^#0H@("`@
M/&1O8SYW:6QL(&9O<F-E(&1O=VYL;V%D(&]F(&YE=R!C:&%N;F5L+GAM;"!I
M9B!A;B!E>&ES=&EN9R!C:&%N;F5L(&YA;64@:7,@=7-E9#PO9&]C/@T*("`@
M/"]F;W)C93X-"B`@(#QC:&%N;F5L/@T*("`@(#QS:&]R=&]P=#YC/"]S:&]R
M=&]P=#X-"B`@("`\87)G/D-(04Y.14P\+V%R9SX-"B`@("`\9&]C/G=I;&P@
M9F]R8V4@9&]W;FQO860@;V8@;F5W(&-H86YN96PN>&UL(&EF(&%N(&5X:7-T
M:6YG(&-H86YN96P@;F%M92!I<R!U<V5D/"]D;V,^#0H@("`\+V-H86YN96P^
M#0H@(#PO;W!T:6]N<SX-"B`@/&1O8SY;)FQT.V-H86YN96PN>&UL)F=T.WPF
M;'0[8VAA;FYE;"!N86UE)F=T.UT-"E5P9&%T92!A(&-H86YN96P@:6X@=&AE
M(&-H86YN96P@;&ES="!D:7)E8W1L>2X@($YO=&4@=&AA="!A;&P-"G!U8FQI
M8R!C:&%N;F5L<R!C86X@8F4@<WEN8V5D('5S:6YG("9Q=6]T.W5P9&%T92UC
M:&%N;F5L<R9Q=6]T.RX-"E!A<F%M971E<B!M87D@8F4@82!L;V-A;"!O<B!R
M96UO=&4@8VAA;FYE;"YX;6PL(&]R('1H92!N86UE(&]F#0IA;B!E>&ES=&EN
M9R!C:&%N;F5L+@T*/"]D;V,^#0H@/"]C:&%N;F5L+75P9&%T93X-"B`\8VAA
M;FYE;"UI;F9O/@T*("`\<W5M;6%R>3Y2971R:65V92!);F9O<FUA=&EO;B!O
M;B!A($-H86YN96P\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;TEN9F\\+V9U
M;F-T:6]N/@T*("`\<VAO<G1C=70^8VD\+W-H;W)T8W5T/@T*("`\;W!T:6]N
M<R`O/@T*("`\9&]C/B9L=#MP86-K86=E)F=T.PT*3&ES="!T:&4@9FEL97,@
M:6X@86X@:6YS=&%L;&5D('!A8VMA9V4N#0H\+V1O8SX-"B`\+V-H86YN96PM
M:6YF;SX-"B`\8VAA;FYE;"UA;&EA<SX-"B`@/'-U;6UA<GD^4W!E8VEF>2!A
M;B!A;&EA<R!T;R!A(&-H86YN96P@;F%M93PO<W5M;6%R>3X-"B`@/&9U;F-T
M:6]N/F1O06QI87,\+V9U;F-T:6]N/@T*("`\<VAO<G1C=70^8VAA/"]S:&]R
M=&-U=#X-"B`@/&]P=&EO;G,@+SX-"B`@/&1O8SXF;'0[8VAA;FYE;"9G=#L@
M)FQT.V%L:6%S)F=T.PT*4W!E8VEF>2!A('-P96-I9FEC(&%L:6%S('1O('5S
M92!F;W(@82!C:&%N;F5L(&YA;64N#0I4:&4@86QI87,@;6%Y(&YO="!B92!A
M;B!E>&ES=&EN9R!C:&%N;F5L(&YA;64@;W(-"F%L:6%S+@T*/"]D;V,^#0H@
M/"]C:&%N;F5L+6%L:6%S/@T*(#QC:&%N;F5L+61I<V-O=F5R/@T*("`\<W5M
M;6%R>3Y);FET:6%L:7IE(&$@0VAA;FYE;"!F<F]M(&ET<R!S97)V97(\+W-U
M;6UA<GD^#0H@(#QF=6YC=&EO;CYD;T1I<V-O=F5R/"]F=6YC=&EO;CX-"B`@
M/'-H;W)T8W5T/F1I/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,@+SX-"B`@/&1O
M8SXF;'0[<&%C:V%G929G=#L-"DQI<W0@=&AE(&9I;&5S(&EN(&%N(&EN<W1A
M;&QE9"!P86-K86=E+@T*/"]D;V,^#0H@/"]C:&%N;F5L+61I<V-O=F5R/@T*
M/"]C;VUM86YD<SX`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O4$5!4B]#;VUM86YD+T-O;6UO;BYP:'``````````````````
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,C$P-S,`,3`U,34T,S,W-#``,#(R-C4R`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M#0HO*BH-"B`J(%!%05)?0V]M;6%N9%]#;VUM;VX@8F%S92!C;&%S<PT*("H-
M"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H
M92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A
M;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P
M;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C
M871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H
M;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@
M("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG
M:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS
M92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!#;VUM;VXN<&AP+'8@
M,2XS,B`R,#`V+S`S+S`R(#$V.C,Y.C$T('!A:F]Y92!%>'`@)`T*("H@0&QI
M;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J
M($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ
M#0H@*B\-"@T*+RHJ#0H@*B!B87-E(&-L87-S#0H@*B\-"G)E<75I<F5?;VYC
M92`G4$5!4BYP:'`G.PT*#0HO*BH-"B`J(%!%05(@8V]M;6%N9',@8F%S92!C
M;&%S<PT*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@
M(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE
M=#X-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE
M=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@
M*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z
M(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A
M8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I
M;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"F-L87-S(%!%05)?0V]M;6%N9%]#;VUM
M;VX@97AT96YD<R!014%2#0I[#0H@("`@+R\@>WM[('!R;W!E<G1I97,-"@T*
M("`@("\J*@T*("`@("`J(%!%05)?0V]N9FEG(&]B:F5C="!U<V5D('1O('!A
M<W,@=7-E<B!S>7-T96T@86YD(&-O;F9I9W5R871I;VX-"B`@("`@*B!O;B!W
M:&5N(&5X96-U=&EN9R!C;VUM86YD<PT*("`@("`J#0H@("`@("H@0'9A<B!0
M14%27T-O;F9I9PT*("`@("`J+PT*("`@('9A<B`D8V]N9FEG.PT*("`@("\J
M*@T*("`@("`J($!V87(@4$5!4E]296=I<W1R>0T*("`@("`J($!A8V-E<W,@
M<')O=&5C=&5D#0H@("`@("HO#0H@("`@=F%R("1?<F5G:7-T<GD[#0H-"B`@
M("`O*BH-"B`@("`@*B!5<V5R($EN=&5R9F%C92!O8FIE8W0L(&9O<B!A;&P@
M:6YT97)A8W1I;VX@=VET:"!T:&4@=7-E<BX-"B`@("`@*B!`=F%R(&]B:F5C
M=`T*("`@("`J+PT*("`@('9A<B`D=6D[#0H-"B`@("!V87(@)%]D97!S7W)E
M;%]T<F%N<R`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VQT)R`]/B`G/"<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G;&4G(#T^("<\/2<L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G97$G(#T^("<])RP-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=N92<@/3X@)R$])RP-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=G="<@/3X@)SXG+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V=E)R`]/B`G/CTG+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VAA<R<@/3X@)ST])PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*3L-"@T*("`@('9A<B`D7V1E<'-?
M='EP95]T<F%N<R`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=P:V<G(#T^("=P86-K86=E)RP-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G97AT96YS:6]N)R`]/B`G97AT96YS:6]N
M)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&AP)R`]
M/B`G4$A0)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<')O9R<@/3X@)V5X=&5R;F%L('!R;V=R86TG+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=L9&QI8B<@/3X@)V5X=&5R;F%L(&QI8G)A
M<GD@9F]R(&QI;FMI;F<G+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=R=&QI8B<@/3X@)V5X=&5R;F%L(')U;G1I;64@;&EB<F%R>2<L
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V]S)R`]/B`G
M;W!E<F%T:6YG('-Y<W1E;2<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W=E8G-R=B<@/3X@)W=E8B!S97)V97(G+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=S87!I)R`]/B`G4T%022!B86-K
M96YD)PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("D[#0H-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8V]N<W1R=6-T;W(-"@T*("`@("\J
M*@T*("`@("`J(%!%05)?0V]M;6%N9%]#;VUM;VX@8V]N<W1R=6-T;W(N#0H@
M("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U
M;F-T:6]N(%!%05)?0V]M;6%N9%]#;VUM;VXH)B1U:2P@)B1C;VYF:6<I#0H@
M("`@>PT*("`@("`@("!P87)E;G0Z.E!%05(H*3L-"B`@("`@("`@)'1H:7,M
M/F-O;F9I9R`]("8D8V]N9FEG.PT*("`@("`@("`D=&AI<RT^=6D@/2`F)'5I
M.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&=E=$-O;6UA
M;F1S*"D-"@T*("`@("\J*@T*("`@("`J(%)E='5R;B!A(&QI<W0@;V8@86QL
M('1H92!C;VUM86YD<R!D969I;F5D(&)Y('1H:7,@8VQA<W,N#0H@("`@("H@
M0')E='5R;B!A<G)A>2!L:7-T(&]F(&-O;6UA;F1S#0H@("`@("H@0&%C8V5S
M<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971#;VUM86YD<R@I
M#0H@("`@>PT*("`@("`@("`D<F5T(#T@87)R87DH*3L-"B`@("`@("`@9F]R
M96%C:"`H87)R87E?:V5Y<R@D=&AI<RT^8V]M;6%N9',I(&%S("1C;VUM86YD
M*2![#0H@("`@("`@("`@("`D<F5T6R1C;VUM86YD72`]("1T:&ES+3YC;VUM
M86YD<ULD8V]M;6%N9%U;)W-U;6UA<GDG73L-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@9V5T4VAO<G1C=71S*"D-"@T*("`@("\J*@T*("`@("`J(%)E='5R;B!A
M(&QI<W0@;V8@86QL('1H92!C;VUM86YD('-H;W)T8W5T<R!D969I;F5D(&)Y
M('1H:7,@8VQA<W,N#0H@("`@("H@0')E='5R;B!A<G)A>2!S:&]R=&-U="`]
M/B!C;VUM86YD#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!G9713:&]R=&-U=',H*0T*("`@('L-"B`@("`@("`@)')E
M="`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H)'1H
M:7,M/F-O;6UA;F1S*2!A<R`D8V]M;6%N9"D@>PT*("`@("`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3YC;VUM86YD<ULD8V]M;6%N9%U;)W-H;W)T8W5T)UTI
M*2![#0H@("`@("`@("`@("`@("`@)')E=%LD=&AI<RT^8V]M;6%N9'-;)&-O
M;6UA;F1=6R=S:&]R=&-U="==72`]("1C;VUM86YD.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R!G971/<'1I;VYS*"D-"@T*("`@(&9U
M;F-T:6]N(&=E=$]P=&EO;G,H)&-O;6UA;F0I#0H@("`@>PT*("`@("`@("`D
M<VAO<G1C=71S(#T@)'1H:7,M/F=E=%-H;W)T8W5T<R@I.PT*("`@("`@("!I
M9B`H:7-S970H)'-H;W)T8W5T<ULD8V]M;6%N9%TI*2![#0H@("`@("`@("`@
M("`D8V]M;6%N9"`]("1S:&]R=&-U='-;)&-O;6UA;F1=.PT*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B!`)'1H:7,M/F-O;6UA;F1S6R1C;VUM86YD75LG
M;W!T:6]N<R==.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G
M971'971O<'1!<F=S*"D-"@T*("`@(&9U;F-T:6]N(&=E=$=E=&]P=$%R9W,H
M)&-O;6UA;F0L("8D<VAO<G1?87)G<RP@)B1L;VYG7V%R9W,I#0H@("`@>PT*
M("`@("`@("`D<VAO<G1?87)G<R`]("(B.PT*("`@("`@("`D;&]N9U]A<F=S
M(#T@87)R87DH*3L-"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3YC;VUM86YD
M<ULD8V]M;6%N9%TI('Q\(&5M<'1Y*"1T:&ES+3YC;VUM86YD<ULD8V]M;6%N
M9%U;)V]P=&EO;G,G72DI('L-"B`@("`@("`@("`@(')E='5R;CL-"B`@("`@
M("`@?0T*("`@("`@("!R97-E="@D=&AI<RT^8V]M;6%N9'-;)&-O;6UA;F1=
M6R=O<'1I;VYS)UTI.PT*("`@("`@("!W:&EL92`H;&ES="@D;W!T:6]N+"`D
M:6YF;RD@/2!E86-H*"1T:&ES+3YC;VUM86YD<ULD8V]M;6%N9%U;)V]P=&EO
M;G,G72DI('L-"B`@("`@("`@("`@("1L87)G(#T@)'-A<F<@/2`G)SL-"B`@
M("`@("`@("`@(&EF("AI<W-E="@D:6YF;ULG87)G)UTI*2![#0H@("`@("`@
M("`@("`@("`@:68@*"1I;F9O6R=A<F<G77LP?2`]/2`G*"<I('L-"B`@("`@
M("`@("`@("`@("`@("`@)&QA<F<@/2`G/3TG.PT*("`@("`@("`@("`@("`@
M("`@("`D<V%R9R`]("<Z.B<[#0H@("`@("`@("`@("`@("`@("`@("1A<F<@
M/2!S=6)S='(H)&EN9F];)V%R9R==+"`Q+"`M,2D[#0H@("`@("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)&QA<F<@/2`G/2<[
M#0H@("`@("`@("`@("`@("`@("`@("1S87)G(#T@)SHG.PT*("`@("`@("`@
M("`@("`@("`@("`D87)G(#T@)&EN9F];)V%R9R==.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D
M:6YF;ULG<VAO<G1O<'0G72DI('L-"B`@("`@("`@("`@("`@("`D<VAO<G1?
M87)G<R`N/2`D:6YF;ULG<VAO<G1O<'0G72`N("1S87)G.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@)&QO;F=?87)G<UM=(#T@)&]P=&EO;B`N("1L
M87)G.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(&=E=$AE;'`H*0T*("`@("\J*@T*("`@("H@4F5T=7)N<R!T:&4@:&5L
M<"!M97-S86=E(&9O<B!T:&4@9VEV96X@8V]M;6%N9`T*("`@("H-"B`@("`J
M($!P87)A;2!S=')I;F<@)&-O;6UA;F0@5&AE(&-O;6UA;F0-"B`@("`J($!R
M971U<FX@;6EX960@02!F86EL('-T<FEN9R!I9B!T:&4@8V]M;6%N9"!D;V5S
M(&YO="!H879E(&AE;'`@;W(-"B`@("`J("`@("`@("`@("`@("`@82!T=V\@
M96QE;65N=',@87)R87D@8V]N=&%I;FEN9R!;,%T]/FAE;'`@<W1R:6YG+`T*
M("`@("H@("`@("`@("`@("`@("!;,5T]/B!H96QP('-T<FEN9R!F;W(@=&AE
M(&%C8V5P=&5D(&-M9"!A<F=S#0H@("`@*B\-"B`@("!F=6YC=&EO;B!G971(
M96QP*"1C;VUM86YD*0T*("`@('L-"B`@("`@("`@)&-O;F9I9R`]("9014%2
M7T-O;F9I9SHZ<VEN9VQE=&]N*"D[#0H@("`@("`@("1H96QP(#T@0"1T:&ES
M+3YC;VUM86YD<ULD8V]M;6%N9%U;)V1O8R==.PT*("`@("`@("!I9B`H96UP
M='DH)&AE;'`I*2![#0H@("`@("`@("`@("`O+R!86%@@*&-O>"D@1F%L;&)A
M8VL@=&\@<W5M;6%R>2!I9B!T:&5R92!I<R!N;R!D;V,@*'-H;W<@8F]T:#\I
M#0H@("`@("`@("`@("!I9B`H(21H96QP(#T@0"1T:&ES+3YC;VUM86YD<ULD
M8V]M;6%N9%U;)W-U;6UA<GDG72D@>PT*("`@("`@("`@("`@("`@(')E='5R
M;B`B3F\@:&5L<"!F;W(@8V]M;6%N9"!<(B1C;VUM86YD7"(B.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AP<F5G7VUA=&-H7V%L
M;"@G+WMC;VYF:6=<<RLH6UY<?5TK*7TO92<L("1H96QP+"`D;6%T8VAE<RDI
M('L-"B`@("`@("`@("`@(&9O<F5A8V@H)&UA=&-H97-;,%T@87,@)&L@/3X@
M)'8I('L-"B`@("`@("`@("`@("`@("`D:&5L<"`]('!R96=?<F5P;&%C92@B
M+R1V+R(L("1C;VYF:6<M/F=E="@D;6%T8VAE<ULQ75LD:UTI+"`D:&5L<"D[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&%R
M<F%Y*"1H96QP+"`D=&AI<RT^9V5T2&5L<$%R9W,H)&-O;6UA;F0I*3L-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T2&5L<$%R9W,H*0T*
M("`@("\J*@T*("`@("H@4F5T=7)N<R!T:&4@:&5L<"!F;W(@=&AE(&%C8V5P
M=&5D(&%R9W5M96YT<R!O9B!A(&-O;6UA;F0-"B`@("`J#0H@("`@*B!`<&%R
M86T@('-T<FEN9R`D8V]M;6%N9`T*("`@("H@0')E='5R;B!S=')I;F<@5&AE
M(&AE;'`@<W1R:6YG#0H@("`@*B\-"B`@("!F=6YC=&EO;B!G971(96QP07)G
M<R@D8V]M;6%N9"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M8V]M;6%N9'-;)&-O;6UA;F1=6R=O<'1I;VYS)UTI("8F#0H@("`@("`@("`@
M("!C;W5N="@D=&AI<RT^8V]M;6%N9'-;)&-O;6UA;F1=6R=O<'1I;VYS)UTI
M*0T*("`@("`@("![#0H@("`@("`@("`@("`D:&5L<"`](")/<'1I;VYS.EQN
M(CL-"B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YC;VUM86YD<ULD8V]M
M;6%N9%U;)V]P=&EO;G,G72!A<R`D:R`]/B`D=BD@>PT*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D=ELG87)G)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@D=ELG87)G)UU[,'T@/3T@)R@G*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D87)G(#T@<W5B<W1R*"1V6R=A<F<G72P@,2P@+3$I.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)'-A<'`@/2`B(%LD87)G72([#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D;&%P<"`](");/21A<F==(CL-"B`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1S87!P(#T@(B`D=EMA<F==(CL-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1L87!P(#T@(CTD=EMA<F==(CL-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@("1S87!P(#T@)&QA<'`@/2`B(CL-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1V6R=S:&]R=&]P="==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`D<R`]("1V6R=S:&]R=&]P="==.PT*
M("`@("`@("`@("`@("`@("`@("!`)&AE;'`@+CT@(B`@+21S)'-A<'`L("TM
M)&LD;&%P<%QN(CL-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("!`)&AE;'`@+CT@(B`@+2TD:R1L87!P7&XB.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D<"`]("(@("`@("`@
M("([#0H@("`@("`@("`@("`@("`@)&1O8R`](')T<FEM*'-T<E]R97!L86-E
M*")<;B(L(")<;B1P(BP@)'9;)V1O8R==*2D[#0H@("`@("`@("`@("`@("`@
M)&AE;'`@+CT@(B`@("`@("`@)&1O8UQN(CL-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(')E='5R;B`D:&5L<#L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@;G5L;#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@
M<G5N*"D-"@T*("`@(&9U;F-T:6]N(')U;B@D8V]M;6%N9"P@)&]P=&EO;G,L
M("1P87)A;7,I#0H@("`@>PT*("`@("`@("!I9B`H96UP='DH)'1H:7,M/F-O
M;6UA;F1S6R1C;VUM86YD75LG9G5N8W1I;VXG72DI('L-"B`@("`@("`@("`@
M("\O(&QO;VL@9F]R('-H;W)T8W5T<PT*("`@("`@("`@("`@9F]R96%C:"`H
M87)R87E?:V5Y<R@D=&AI<RT^8V]M;6%N9',I(&%S("1C;60I('L-"B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/F-O;6UA;F1S6R1C;61=6R=S
M:&]R=&-U="==*2`F)B`D=&AI<RT^8V]M;6%N9'-;)&-M9%U;)W-H;W)T8W5T
M)UT@/3T@)&-O;6UA;F0I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&5M
M<'1Y*"1T:&ES+3YC;VUM86YD<ULD8VUD75LG9G5N8W1I;VXG72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B=6YK;F]W;B!C;VUM86YD(&`D8V]M;6%N9"<B*3L-"B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1F
M=6YC(#T@)'1H:7,M/F-O;6UA;F1S6R1C;61=6R=F=6YC=&EO;B==.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1C;VUM
M86YD(#T@)&-M9#L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@)&9U;F,@/2`D=&AI<RT^8V]M;6%N9'-;)&-O;6UA
M;F1=6R=F=6YC=&EO;B==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D
M=&AI<RT^)&9U;F,H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*3L-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"GT-"@T*/SX-"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O0V]N9FEG+G!H<```````
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S-C,R-P`Q,#4Q-30S,S<T,``P
M,C(V,S<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`-"B\J*@T*("H@4$5!4E]#;VUM86YD7T-O;F9I9R`H8V]N9FEG
M+7-H;W<L(&-O;F9I9RUG970L(&-O;F9I9RUS970L(&-O;F9I9RUH96QP+"!C
M;VYF:6<M8W)E871E(&-O;6UA;F1S*0T*("H-"B`J(%!(4"!V97)S:6]N<R`T
M(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S
M=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@
M=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O
M<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O
M8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N
M;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J
M($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N
M(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC
M96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@
M4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N
M("`@($-64SH@)$ED.B!#;VYF:6<N<&AP+'8@,2XU,2`R,#`V+S`S+S`R(#$S
M.C,R.C,X('!A:F]Y92!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@
M879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"@T*+RHJ#0H@*B!B
M87-E(&-L87-S#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4B]#;VUM86YD+T-O
M;6UO;BYP:'`G.PT*#0HO*BH-"B`J(%!%05(@8V]M;6%N9',@9F]R(&UA;F%G
M:6YG(&-O;F9I9W5R871I;VX@9&%T82X-"B`J#0H@*B!`8V%T96=O<GD@("!P
M96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!3=&EG
M($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!'<F5G($)E
M879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P
M,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`
M=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@
M($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#`N,0T*("HO#0IC;&%S
M<R!014%27T-O;6UA;F1?0V]N9FEG(&5X=&5N9',@4$5!4E]#;VUM86YD7T-O
M;6UO;@T*>PT*("`@("\O('M[>R!P<F]P97)T:65S#0H-"B`@("!V87(@)&-O
M;6UA;F1S(#T@87)R87DH#0H@("`@("`@("=C;VYF:6<M<VAO=R<@/3X@87)R
M87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)U-H;W<@06QL(%-E='1I
M;F=S)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O0V]N9FEG4VAO
M=R<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=C<V@G+`T*("`@("`@
M("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=C
M:&%N;F5L)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T
M;W!T)R`]/B`G8R<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=S
M:&]W(&-O;F9I9W5R871I;VX@=F%R:6%B;&5S(&9O<B!A;F]T:&5R(&-H86YN
M96PG+`T*("`@("`@("`@("`@("`@("`@("`G87)G)R`]/B`G0TA!3B<L#0H@
M("`@("`@("`@("`@("`@("`@("DL#0HI+`T*("`@("`@("`@("`@)V1O8R<@
M/3X@)UML87EE<ET-"D1I<W!L87ES(&%L;"!C;VYF:6=U<F%T:6]N('9A;'5E
M<RX@($%N(&]P=&EO;F%L(&%R9W5M96YT#0IM87D@8F4@=7-E9"!T;R!T96QL
M('=H:6-H(&-O;F9I9W5R871I;VX@;&%Y97(@=&\@9&ES<&QA>2X@(%9A;&ED
M#0IC;VYF:6=U<F%T:6]N(&QA>65R<R!A<F4@(G5S97(B+"`B<WES=&5M(B!A
M;F0@(F1E9F%U;'0B+B!4;R!D:7-P;&%Y#0IC;VYF:6=U<F%T:6]N<R!F;W(@
M9&EF9F5R96YT(&-H86YN96QS+"!S970@=&AE(&1E9F%U;'1?8VAA;FYE;`T*
M8V]N9FEG=7)A=&EO;B!V87)I86)L92!A;F0@<G5N(&-O;F9I9RUS:&]W(&%G
M86EN+@T*)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@("=C;VYF:6<M9V5T
M)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G4VAO=R!/
M;F4@4V5T=&EN9R<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;T-O
M;F9I9T=E="<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=C9R<L#0H@
M("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@
M("`@)V-H86YN96PG(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G
M<VAO<G1O<'0G(#T^("=C)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@
M/3X@)W-H;W<@8V]N9FEG=7)A=&EO;B!V87)I86)L97,@9F]R(&%N;W1H97(@
M8VAA;FYE;"<L#0H@("`@("`@("`@("`@("`@("`@("=A<F<G(#T^("=#2$%.
M)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"BDL#0H@("`@("`@("`@("`G
M9&]C)R`]/B`G/'!A<F%M971E<CX@6VQA>65R70T*1&ES<&QA>7,@=&AE('9A
M;'5E(&]F(&]N92!C;VYF:6=U<F%T:6]N('!A<F%M971E<BX@(%1H90T*9FER
M<W0@87)G=6UE;G0@:7,@=&AE(&YA;64@;V8@=&AE('!A<F%M971E<BP@86X@
M;W!T:6]N86P@<V5C;VYD(&%R9W5M96YT#0IM87D@8F4@=7-E9"!T;R!T96QL
M('=H:6-H(&-O;F9I9W5R871I;VX@;&%Y97(@=&\@;&]O:R!I;BX@(%9A;&ED
M(&-O;F9I9W5R871I;VX-"FQA>65R<R!A<F4@(G5S97(B+"`B<WES=&5M(B!A
M;F0@(F1E9F%U;'0B+B`@268@;F\@;&%Y97(@:7,@<W!E8VEF:65D+"!A('9A
M;'5E#0IW:6QL(&)E('!I8VME9"!F<F]M('1H92!F:7)S="!L87EE<B!T:&%T
M(&1E9FEN97,@=&AE('!A<F%M971E<BP@:6X@=&AE(&]R9&5R#0IJ=7-T('-P
M96-I9FEE9"X@(%1H92!C;VYF:6=U<F%T:6]N('9A;'5E('=I;&P@8F4@<F5T
M<FEE=F5D(&9O<B!T:&4@8VAA;FYE;`T*<W!E8VEF:65D(&)Y('1H92!D969A
M=6QT7V-H86YN96P@8V]N9FEG=7)A=&EO;B!V87)I86)L92X-"B<L#0H@("`@
M("`@("`@("`I+`T*("`@("`@("`G8V]N9FEG+7-E="<@/3X@87)R87DH#0H@
M("`@("`@("`@("`G<W5M;6%R>2<@/3X@)T-H86YG92!3971T:6YG)RP-"B`@
M("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O0V]N9FEG4V5T)RP-"B`@("`@
M("`@("`@("=S:&]R=&-U="<@/3X@)V-S)RP-"B`@("`@("`@("`@("=O<'1I
M;VYS)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`G8VAA;FYE;"<@/3X@
M87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)V,G
M+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G<VAO=R!C;VYF:6=U
M<F%T:6]N('9A<FEA8FQE<R!F;W(@86YO=&AE<B!C:&%N;F5L)RP-"B`@("`@
M("`@("`@("`@("`@("`@)V%R9R<@/3X@)T-(04XG+`T*("`@("`@("`@("`@
M("`@("`@("`I+`T**2P-"B`@("`@("`@("`@("=D;V,G(#T^("<\<&%R86UE
M=&5R/B`\=F%L=64^(%ML87EE<ET-"E-E=',@=&AE('9A;'5E(&]F(&]N92!C
M;VYF:6=U<F%T:6]N('!A<F%M971E<BX@(%1H92!F:7)S="!A<F=U;65N="!I
M<PT*=&AE(&YA;64@;V8@=&AE('!A<F%M971E<BP@=&AE('-E8V]N9"!A<F=U
M;65N="!I<R!T:&4@;F5W('9A;'5E+B`@4V]M90T*<&%R86UE=&5R<R!A<F4@
M<W5B:F5C="!T;R!V86QI9&%T:6]N+"!A;F0@=&AE(&-O;6UA;F0@=VEL;"!F
M86EL('=I=&@-"F%N(&5R<F]R(&UE<W-A9V4@:68@=&AE(&YE=R!V86QU92!D
M;V5S(&YO="!M86ME('-E;G-E+B`@06X@;W!T:6]N86P-"G1H:7)D(&%R9W5M
M96YT(&UA>2!B92!U<V5D('1O('-P96-I9GD@:6X@=VAI8V@@;&%Y97(@=&\@
M<V5T('1H90T*8V]N9FEG=7)A=&EO;B!P87)A;65T97(N("!4:&4@9&5F875L
M="!L87EE<B!I<R`B=7-E<B(N("!4:&4-"F-O;F9I9W5R871I;VX@=F%L=64@
M=VEL;"!B92!S970@9F]R('1H92!C=7)R96YT(&-H86YN96PL('=H:6-H#0II
M<R!C;VYT<F]L;&5D(&)Y('1H92!D969A=6QT7V-H86YN96P@8V]N9FEG=7)A
M=&EO;B!V87)I86)L92X-"B<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`G
M8V]N9FEG+6AE;'`G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG
M(#T^("=3:&]W($EN9F]R;6%T:6]N($%B;W5T(%-E='1I;F<G+`T*("`@("`@
M("`@("`@)V9U;F-T:6]N)R`]/B`G9&]#;VYF:6=(96QP)RP-"B`@("`@("`@
M("`@("=S:&]R=&-U="<@/3X@)V-H)RP-"B`@("`@("`@("`@("=O<'1I;VYS
M)R`]/B!A<G)A>2@I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)UMP87)A;65T
M97)=#0I$:7-P;&%Y<R!H96QP(&9O<B!A(&-O;F9I9W5R871I;VX@<&%R86UE
M=&5R+B`@5VET:&]U="!A<F=U;65N=',@:70-"F1I<W!L87ES(&AE;'`@9F]R
M(&%L;"!C;VYF:6=U<F%T:6]N('!A<F%M971E<G,N#0HG+`T*("`@("`@("`@
M("`I+`T*("`@("`@("`G8V]N9FEG+6-R96%T92<@/3X@87)R87DH#0H@("`@
M("`@("`@("`G<W5M;6%R>2<@/3X@)T-R96%T92!A($1E9F%U;'0@8V]N9FEG
M=7)A=&EO;B!F:6QE)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O
M0V]N9FEG0W)E871E)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)V-O
M8R<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH#0H@("`@("`@
M("`@("`@("`@)W=I;F1O=W,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@
M("`@("`G<VAO<G1O<'0G(#T^("=W)RP-"B`@("`@("`@("`@("`@("`@("`@
M)V1O8R<@/3X@)V-R96%T92!A(&-O;F9I9R!F:6QE(&9O<B!A('=I;F1O=W,@
M:6YS=&%L;"<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@
M("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)SQR;V]T('!A=&@^(#QF:6QE
M;F%M93X-"D-R96%T92!A(&1E9F%U;'0@8V]N9FEG=7)A=&EO;B!F:6QE('=I
M=&@@86QL(&1I<F5C=&]R>2!C;VYF:6=U<F%T:6]N#0IV87)I86)L97,@<V5T
M('1O('-U8F1I<F5C=&]R:65S(&]F(#QR;V]T('!A=&@^+"!A;F0@<V%V92!I
M="!A<R`\9FEL96YA;64^+@T*5&AI<R!I<R!U<V5F=6P@97-P96-I86QL>2!F
M;W(@8W)E871I;F<@82!C;VYF:6=U<F%T:6]N(&9I;&4@9F]R(&$@<F5M;W1E
M#0I014%2(&EN<W1A;&QA=&EO;B`H=7-I;F<@=&AE("TM<F5M;W1E8V]N9FEG
M(&]P=&EO;B!O9B!I;G-T86QL+"!U<&=R861E+`T*86YD('5N:6YS=&%L;"DN
M#0HG+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@*3L-"@T*("`@("\O('U]
M?0T*("`@("\O('M[>R!C;VYS=')U8W1O<@T*#0H@("`@+RHJ#0H@("`@("H@
M4$5!4E]#;VUM86YD7T-O;F9I9R!C;VYS=')U8W1O<BX-"B`@("`@*@T*("`@
M("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@4$5!
M4E]#;VUM86YD7T-O;F9I9R@F)'5I+"`F)&-O;F9I9RD-"B`@("![#0H@("`@
M("`@('!A<F5N=#HZ4$5!4E]#;VUM86YD7T-O;6UO;B@D=6DL("1C;VYF:6<I
M.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&1O0V]N9FEG
M4VAO=R@I#0H-"B`@("!F=6YC=&EO;B!D;T-O;F9I9U-H;W<H)&-O;6UA;F0L
M("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1P87)A;7,I*2![#0H@("`@("`@("`@("`D;&%Y97(@/2!I<W-E="@D
M<&%R86US6S!=*2`_("1P87)A;7-;,%T@.B!.54Q,.PT*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@)&QA>65R(#T@3E5,3#L-"B`@("`@("`@?0T*
M#0H@("`@("`@("\O("1P87)A;7-;,%T@+3X@=&AE(&QA>65R#0H@("`@("`@
M(&EF("@D97)R;W(@/2`D=&AI<RT^7V-H96-K3&%Y97(H)&QA>65R*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")C;VYF:6<M
M<VAO=SHD97)R;W(B*3L-"B`@("`@("`@?0T*("`@("`@("`D:V5Y<R`]("1T
M:&ES+3YC;VYF:6<M/F=E=$ME>7,H*3L-"B`@("`@("`@<V]R="@D:V5Y<RD[
M#0H@("`@("`@("1C:&%N;F5L(#T@:7-S970H)&]P=&EO;G-;)V-H86YN96PG
M72D@/R`D;W!T:6]N<ULG8VAA;FYE;"==(#H-"B`@("`@("`@("`@("1T:&ES
M+3YC;VYF:6<M/F=E="@G9&5F875L=%]C:&%N;F5L)RD[#0H@("`@("`@("1R
M96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@
M:68@*"$D<F5G+3YC:&%N;F5L17AI<W1S*"1C:&%N;F5L*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#:&%N;F5L("(G("X@
M)&-H86YN96P@+B`G(B!D;V5S(&YO="!E>&ES="<I.PT*("`@("`@("!]#0H@
M("`@("`@("1D871A(#T@87)R87DH)V-A<'1I;VXG(#T^("=#;VYF:6=U<F%T
M:6]N("AC:&%N;F5L("<@+B`D8VAA;FYE;"`N("<I.B<I.PT*("`@("`@("!F
M;W)E86-H("@D:V5Y<R!A<R`D:V5Y*2![#0H@("`@("`@("`@("`D='EP92`]
M("1T:&ES+3YC;VYF:6<M/F=E=%1Y<&4H)&ME>2D[#0H@("`@("`@("`@("`D
M=F%L=64@/2`D=&AI<RT^8V]N9FEG+3YG970H)&ME>2P@)&QA>65R+"`D8VAA
M;FYE;"D[#0H@("`@("`@("`@("!I9B`H)'1Y<&4@/3T@)W!A<W-W;W)D)R`F
M)B`D=F%L=64I('L-"B`@("`@("`@("`@("`@("`D=F%L=64@/2`G*BHJ*BHJ
M*BHG.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1V86QU92`]
M/3T@9F%L<V4I('L-"B`@("`@("`@("`@("`@("`D=F%L=64@/2`G9F%L<V4G
M.PT*("`@("`@("`@("`@?2!E;'-E:68@*"1V86QU92`]/3T@=')U92D@>PT*
M("`@("`@("`@("`@("`@("1V86QU92`]("=T<G5E)SL-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("1D871A6R=D871A)UU;)'1H:7,M/F-O;F9I9RT^
M9V5T1W)O=7`H)&ME>2E=6UT@/2!A<G)A>2@D=&AI<RT^8V]N9FEG+3YG9710
M<F]M<'0H)&ME>2D@+"`D:V5Y+"`D=F%L=64I.PT*("`@("`@("!]#0H@("`@
M("`@(&9O<F5A8V@@*"1T:&ES+3YC;VYF:6<M/F=E=$QA>65R<R@I(&%S("1L
M87EE<BD@>PT*("`@("`@("`@("`@)&1A=&%;)V1A=&$G75LG0V]N9FEG($9I
M;&5S)UU;72`](&%R<F%Y*'5C9FER<W0H)&QA>65R*2`N("<@0V]N9FEG=7)A
M=&EO;B!&:6QE)RP@)T9I;&5N86UE)R`L("1T:&ES+3YC;VYF:6<M/F=E=$-O
M;F9&:6QE*"1L87EE<BDI.PT*("`@("`@("!]#0H-"B`@("`@("`@)'1H:7,M
M/G5I+3YO=71P=71$871A*"1D871A+"`D8V]M;6%N9"D[#0H@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!D
M;T-O;F9I9T=E="@I#0H-"B`@("!F=6YC=&EO;B!D;T-O;F9I9T=E="@D8V]M
M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@("!I9B`H
M(6ES7V%R<F%Y*"1P87)A;7,I*2![#0H@("`@("`@("`@("`D87)G<U]C;G0@
M/2`P.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&%R9W-?8VYT
M("`](&-O=6YT*"1P87)A;7,I.PT*("`@("`@("!]#0H-"B`@("`@("`@<W=I
M=&-H("@D87)G<U]C;G0I('L-"B`@("`@("`@("`@(&-A<V4@,3H-"B`@("`@
M("`@("`@("`@("`D8V]N9FEG7VME>2`]("1P87)A;7-;,%T[#0H@("`@("`@
M("`@("`@("`@)&QA>65R(#T@3E5,3#L-"B`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@(&-A<V4@,CH-"B`@("`@("`@("`@("`@("`D8V]N
M9FEG7VME>2`]("1P87)A;7-;,%T[#0H@("`@("`@("`@("`@("`@)&QA>65R
M(#T@)'!A<F%M<ULQ73L-"B`@("`@("`@("`@("`@("!I9B`H)&5R<F]R(#T@
M)'1H:7,M/E]C:&5C:TQA>65R*"1L87EE<BDI('L-"B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")C;VYF:6<M9V5T.B1E
M<G)O<B(I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!B
M<F5A:SL-"B`@("`@("`@("`@(&-A<V4@,#H-"B`@("`@("`@("`@(&1E9F%U
M;'0Z#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*")C;VYF:6<M9V5T(&5X<&5C=',@,2!O<B`R('!A<F%M971E<G,B*3L-"B`@
M("`@("`@?0T*#0H@("`@("`@("1C:&%N;F5L(#T@:7-S970H)&]P=&EO;G-;
M)V-H86YN96PG72D@/R`D;W!T:6]N<ULG8VAA;FYE;"==(#H@)'1H:7,M/F-O
M;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*3L-"B`@("`@("`@)')E9R`]
M("8D=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I.PT*#0H@("`@("`@(&EF
M("@A)')E9RT^8VAA;FYE;$5X:7-T<R@D8VAA;FYE;"DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G0VAA;FYE;"`B)R`N("1C
M:&%N;F5L("X@)R(@9&]E<R!N;W0@97AI<W0G*3L-"B`@("`@("`@?0T*#0H@
M("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D=&AI<RT^8V]N9FEG+3YG
M970H)&-O;F9I9U]K97DL("1L87EE<BP@)&-H86YN96PI+"`D8V]M;6%N9"D[
M#0H-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[(&1O0V]N9FEG4V5T*"D-"@T*("`@(&9U;F-T:6]N(&1O
M0V]N9FEG4V5T*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![
M#0H@("`@("`@("\O("1P87)A;5LP72`M/B!A('!A<F%M971E<B!T;R!S970-
M"B`@("`@("`@+R\@)'!A<F%M6S%=("T^('1H92!V86QU92!F;W(@=&AE('!A
M<F%M971E<@T*("`@("`@("`O+R`D<&%R86U;,ET@+3X@=&AE(&QA>65R#0H@
M("`@("`@("1F86EL;7-G(#T@)R<[#0H@("`@("`@(&EF("AS:7IE;V8H)'!A
M<F%M<RD@/"`R('Q\('-I>F5O9B@D<&%R86US*2`^(#,I('L-"B`@("`@("`@
M("`@("1F86EL;7-G("X](")C;VYF:6<M<V5T(&5X<&5C=',@,B!O<B`S('!A
M<F%M971E<G,B.PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)&9A:6QM<V<I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D97)R;W(@
M/2`D=&AI<RT^7V-H96-K3&%Y97(H0"1P87)A;7-;,ETI*2![#0H@("`@("`@
M("`@("`D9F%I;&US9R`N/2`D97)R;W([#0H@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@B8V]N9FEG+7-E=#HD9F%I;&US9R(I.PT*("`@
M("`@("!]#0H@("`@("`@("1C:&%N;F5L(#T@:7-S970H)&]P=&EO;G-;)V-H
M86YN96PG72D@/R`D;W!T:6]N<ULG8VAA;FYE;"==(#H-"B`@("`@("`@("`@
M("1T:&ES+3YC;VYF:6<M/F=E="@G9&5F875L=%]C:&%N;F5L)RD[#0H@("`@
M("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@
M("`@("`@:68@*"$D<F5G+3YC:&%N;F5L17AI<W1S*"1C:&%N;F5L*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#:&%N;F5L
M("(G("X@)&-H86YN96P@+B`G(B!D;V5S(&YO="!E>&ES="<I.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@D<&%R86US6S!=(#T]("=D969A=6QT7V-H86YN
M96PG*2![#0H@("`@("`@("`@("!I9B`H(21R96<M/F-H86YN96Q%>&ES=',H
M)'!A<F%M<ULQ72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)T-H86YN96P@(B<@+B`D<&%R86US6S%=("X@)R(@9&]E
M<R!N;W0@97AI<W0G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H8V]U;G0H)'!A<F%M<RD@/3T@,BD@>PT*("`@("`@("`@("`@
M87)R87E?<'5S:"@D<&%R86US+"`G=7-E<B<I.PT*("`@("`@("`@("`@)&QA
M>65R(#T@)W5S97(G.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M)&QA>65R(#T@)'!A<F%M<ULR73L-"B`@("`@("`@?0T*("`@("`@("!A<G)A
M>5]P=7-H*"1P87)A;7,L("1C:&%N;F5L*3L-"B`@("`@("`@:68@*"%C86QL
M7W5S97)?9G5N8U]A<G)A>2AA<G)A>2@F)'1H:7,M/F-O;F9I9RP@)W-E="<I
M+"`D<&%R86US*2D-"B`@("`@("`@>PT*("`@("`@("`@("`@87)R87E?<&]P
M*"1P87)A;7,I.PT*("`@("`@("`@("`@)&9A:6QM<V<@/2`B8V]N9FEG+7-E
M="`H(B`N(&EM<&QO9&4H(BP@(BP@)'!A<F%M<RD@+B`B*2!F86EL960L(&-H
M86YN96P@)&-H86YN96PB.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@)'1H:7,M/F-O;F9I9RT^<W1O<F4H)&QA>65R*3L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H)&9A:6QM<V<I('L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@D9F%I;&US9RD[#0H@("`@("`@('T-"B`@("`@
M("`@)'1H:7,M/G5I+3YO=71P=71$871A*"=C;VYF:6<M<V5T('-U8V-E961E
M9"<L("1C;VUM86YD*3L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&1O0V]N9FEG2&5L<"@I#0H-"B`@
M("!F=6YC=&EO;B!D;T-O;F9I9TAE;'`H)&-O;6UA;F0L("1O<'1I;VYS+"`D
M<&%R86US*0T*("`@('L-"B`@("`@("`@:68@*&5M<'1Y*"1P87)A;7,I*2![
M#0H@("`@("`@("`@("`D<&%R86US(#T@)'1H:7,M/F-O;F9I9RT^9V5T2V5Y
M<R@I.PT*("`@("`@("!]#0H@("`@("`@("1D871A6R=C87!T:6]N)UT@(#T@
M(D-O;F9I9R!H96QP(B`N("@H8V]U;G0H)'!A<F%M<RD@/3T@,2D@/R`B(&9O
M<B`D<&%R86US6S!=(B`Z("<G*3L-"B`@("`@("`@)&1A=&%;)VAE861L:6YE
M)UT@/2!A<G)A>2@G3F%M92<L("=4>7!E)RP@)T1E<V-R:7!T:6]N)RD[#0H@
M("`@("`@("1D871A6R=B;W)D97(G72`@(#T@=')U93L-"B`@("`@("`@9F]R
M96%C:"`H)'!A<F%M<R!A<R`D;F%M92D@>PT*("`@("`@("`@("`@)'1Y<&4@
M/2`D=&AI<RT^8V]N9FEG+3YG9714>7!E*"1N86UE*3L-"B`@("`@("`@("`@
M("1D;V-S(#T@)'1H:7,M/F-O;F9I9RT^9V5T1&]C<R@D;F%M92D[#0H@("`@
M("`@("`@("!I9B`H)'1Y<&4@/3T@)W-E="<I('L-"B`@("`@("`@("`@("`@
M("`D9&]C<R`](')T<FEM*"1D;V-S*2`N(")<;E9A;&ED('-E=#H@(B`N#0H@
M("`@("`@("`@("`@("`@("`@(&EM<&QO9&4H)R`G+"`D=&AI<RT^8V]N9FEG
M+3YG9713971686QU97,H)&YA;64I*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("1D871A6R=D871A)UU;72`](&%R<F%Y*"1N86UE+"`D='EP92P@
M)&1O8W,I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T
M1&%T82@D9&%T82P@)&-O;6UA;F0I.PT*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!D;T-O;F9I9T-R96%T92@I#0H-"B`@("!F=6YC=&EO;B!D
M;T-O;F9I9T-R96%T92@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@
M("`@>PT*("`@("`@("!I9B`H8V]U;G0H)'!A<F%M<RD@(3T@,BD@>PT*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)V-O;F9I9RUC<F5A
M=&4Z(&UU<W0@:&%V92`R('!A<F%M971E<G,L(')O;W0@<&%T:"!A;F0@)R`N
M#0H@("`@("`@("`@("`@("`@)V9I;&5N86UE('1O('-A=F4@87,G*3L-"B`@
M("`@("`@?0T*("`@("`@("`D<F]O="`]("1P87)A;7-;,%T[#0H@("`@("`@
M("\O($-L96%N('5P('1H92!$25)%0U1/4EE?4T5005)!5$]2(&UE<W,-"B`@
M("`@("`@)&1S,B`]($1)4D5#5$]265]315!!4D%43U(@+B!$25)%0U1/4EE?
M4T5005)!5$]2.PT*("`@("`@("`D<F]O="`]('!R96=?<F5P;&%C92AA<G)A
M>2@G(5Q<7%PK(2<L("<A+RLA)RP@(B$D9',R*R$B*2P-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87DH)R\G+"`G+R<L("<O)RDL#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)')O;W0I.PT*("`@("`@("!I9B`H
M)')O;W1[,'T@(3T@)R\G*2![#0H@("`@("`@("`@("!I9B`H:7-S970H)&]P
M=&EO;G-;)W=I;F1O=W,G72DI('L-"B`@("`@("`@("`@("`@("!I9B`H(7!R
M96=?;6%T8V@H)R]>6T$M6F$M>ETZ+R<L("1R;V]T*2D@>PT*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4F]O="!D:7)E
M8W1O<GD@;75S="!B92!A;B!A8G-O;'5T92!P871H(&)E9VEN;FEN9R`G("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("=W:71H(")<7"(@;W(@(D,Z7%PB
M+"!W87,Z("(G("X@)')O;W0@+B`G(B<I.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)U)O;W0@9&ER96-T;W)Y(&UU<W0@8F4@86X@
M86)S;VQU=&4@<&%T:"!B96=I;FYI;F<@)R`N#0H@("`@("`@("`@("`@("`@
M("`@("=W:71H("(O(BP@=V%S.B`B)R`N("1R;V]T("X@)R(G*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D=VEN9&]W<R`](&ES<V5T
M*"1O<'1I;VYS6R=W:6YD;W=S)UTI.PT*("`@("`@("!I9B`H)'=I;F1O=W,I
M('L-"B`@("`@("`@("`@("1R;V]T(#T@<W1R7W)E<&QA8V4H)R\G+"`G7%PG
M+"`D<F]O="D[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%F:6QE7V5X:7-T
M<R@D<&%R86US6S%=*2D@>PT*("`@("`@("`@("`@:68@*"%`=&]U8V@H)'!A
M<F%M<ULQ72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G0V]U;&0@;F]T(&-R96%T92`B)R`N("1P87)A;7-;,5T@+B`G
M(B<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1P87)A
M;7-;,5T@/2!R96%L<&%T:"@D<&%R86US6S%=*3L-"B`@("`@("`@)&-O;F9I
M9R`]("9N97<@4$5!4E]#;VYF:6<H)'!A<F%M<ULQ72P@)R-N;R-S>7-T96TC
M8V]N9FEG(R<L(&9A;'-E+"!F86QS92D[#0H@("`@("`@(&EF("@D<F]O='MS
M=')L96XH)')O;W0I("T@,7T@/3T@)R\G*2![#0H@("`@("`@("`@("`D<F]O
M="`]('-U8G-T<B@D<F]O="P@,"P@<W1R;&5N*"1R;V]T*2`M(#$I.PT*("`@
M("`@("!]#0H@("`@("`@("1C;VYF:6<M/FYO4F5G:7-T<GDH*3L-"B`@("`@
M("`@)&-O;F9I9RT^<V5T*"=P:'!?9&ER)RP@)'=I;F1O=W,@/R`B)')O;W1<
M7'!E87)<7'!H<"(@.B`B)')O;W0O<&5A<B]P:'`B+"`G=7-E<B<I.PT*("`@
M("`@("`D8V]N9FEG+3YS970H)V1A=&%?9&ER)RP@)'=I;F1O=W,@/R`B)')O
M;W1<7'!E87)<7&1A=&$B(#H@(B1R;V]T+W!E87(O9&%T82(I.PT*("`@("`@
M("`D8V]N9FEG+3YS970H)V5X=%]D:7(G+"`D=VEN9&]W<R`_("(D<F]O=%Q<
M<&5A<EQ<97AT(B`Z("(D<F]O="]P96%R+V5X="(I.PT*("`@("`@("`D8V]N
M9FEG+3YS970H)V1O8U]D:7(G+"`D=VEN9&]W<R`_("(D<F]O=%Q<<&5A<EQ<
M9&]C<R(@.B`B)')O;W0O<&5A<B]D;V-S(BD[#0H@("`@("`@("1C;VYF:6<M
M/G-E="@G=&5S=%]D:7(G+"`D=VEN9&]W<R`_("(D<F]O=%Q<<&5A<EQ<=&5S
M=',B(#H@(B1R;V]T+W!E87(O=&5S=',B*3L-"B`@("`@("`@)&-O;F9I9RT^
M<V5T*"=C86-H95]D:7(G+"`D=VEN9&]W<R`_("(D<F]O=%Q<<&5A<EQ<8V%C
M:&4B(#H@(B1R;V]T+W!E87(O8V%C:&4B*3L-"B`@("`@("`@)&-O;F9I9RT^
M<V5T*"=B:6Y?9&ER)RP@)'=I;F1O=W,@/R`B)')O;W1<7'!E87(B(#H@(B1R
M;V]T+W!E87(B*3L-"B`@("`@("`@)&-O;F9I9RT^=W)I=&5#;VYF:6=&:6QE
M*"D[#0H@("`@("`@("1T:&ES+3Y?<VAO=T-O;F9I9R@D8V]N9FEG*3L-"B`@
M("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"=3=6-C97-S9G5L;'D@8W)E
M871E9"!D969A=6QT(&-O;F9I9W5R871I;VX@9FEL92`B)R`N("1P87)A;7-;
M,5T@+B`G(B<L#0H@("`@("`@("`@("`D8V]M;6%N9"D[#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H-"B`@("!F=6YC=&EO;B!?<VAO=T-O;F9I9R@F)&-O;F9I
M9RD-"B`@("![#0H@("`@("`@("1P87)A;7,@/2!A<G)A>2@G=7-E<B<I.PT*
M("`@("`@("`D:V5Y<R`]("1C;VYF:6<M/F=E=$ME>7,H*3L-"B`@("`@("`@
M<V]R="@D:V5Y<RD[#0H@("`@("`@("1C:&%N;F5L(#T@)W!E87(N<&AP+FYE
M="<[#0H@("`@("`@("1D871A(#T@87)R87DH)V-A<'1I;VXG(#T^("=#;VYF
M:6=U<F%T:6]N("AC:&%N;F5L("<@+B`D8VAA;FYE;"`N("<I.B<I.PT*("`@
M("`@("!F;W)E86-H("@D:V5Y<R!A<R`D:V5Y*2![#0H@("`@("`@("`@("`D
M='EP92`]("1C;VYF:6<M/F=E=%1Y<&4H)&ME>2D[#0H@("`@("`@("`@("`D
M=F%L=64@/2`D8V]N9FEG+3YG970H)&ME>2P@)W5S97(G+"`D8VAA;FYE;"D[
M#0H@("`@("`@("`@("!I9B`H)'1Y<&4@/3T@)W!A<W-W;W)D)R`F)B`D=F%L
M=64I('L-"B`@("`@("`@("`@("`@("`D=F%L=64@/2`G*BHJ*BHJ*BHG.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1V86QU92`]/3T@9F%L
M<V4I('L-"B`@("`@("`@("`@("`@("`D=F%L=64@/2`G9F%L<V4G.PT*("`@
M("`@("`@("`@?2!E;'-E:68@*"1V86QU92`]/3T@=')U92D@>PT*("`@("`@
M("`@("`@("`@("1V86QU92`]("=T<G5E)SL-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("1D871A6R=D871A)UU;)&-O;F9I9RT^9V5T1W)O=7`H)&ME
M>2E=6UT@/0T*("`@("`@("`@("`@("`@(&%R<F%Y*"1C;VYF:6<M/F=E=%!R
M;VUP="@D:V5Y*2`L("1K97DL("1V86QU92D[#0H@("`@("`@('T-"B`@("`@
M("`@9F]R96%C:"`H)&-O;F9I9RT^9V5T3&%Y97)S*"D@87,@)&QA>65R*2![
M#0H@("`@("`@("`@("`D9&%T85LG9&%T82==6R=#;VYF:6<@1FEL97,G75M=
M(#T-"B`@("`@("`@("`@("`@("!A<G)A>2AU8V9I<G-T*"1L87EE<BD@+B`G
M($-O;F9I9W5R871I;VX@1FEL92<L("=&:6QE;F%M92<@+`T*("`@("`@("`@
M("`@("`@("`@("`D8V]N9FEG+3YG971#;VYF1FEL92@D;&%Y97(I*3L-"B`@
M("`@("`@?0T*#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D9&%T
M82P@)V-O;F9I9RUS:&]W)RD[#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M('T-"B`@("`O+R![>WL@7V-H96-K3&%Y97(H*0T*#0H@("`@+RHJ#0H@("`@
M("H@0VAE8VMS(&EF(&$@;&%Y97(@:7,@9&5F:6YE9"!O<B!N;W0-"B`@("`@
M*@T*("`@("`J($!P87)A;2!S=')I;F<@)&QA>65R(%1H92!L87EE<B!T;R!S
M96%R8V@@9F]R#0H@("`@("H@0')E='5R;B!M:7AE9"!&86QS92!O;B!N;R!E
M<G)O<B!O<B!T:&4@97)R;W(@;65S<V%G90T*("`@("`J+PT*("`@(&9U;F-T
M:6]N(%]C:&5C:TQA>65R*"1L87EE<B`](&YU;&PI#0H@("`@>PT*("`@("`@
M("!I9B`H(65M<'1Y*"1L87EE<BD@)B8@)&QA>65R("$]("=D969A=6QT)RD@
M>PT*("`@("`@("`@("`@)&QA>65R<R`]("1T:&ES+3YC;VYF:6<M/F=E=$QA
M>65R<R@I.PT*("`@("`@("`@("`@:68@*"%I;E]A<G)A>2@D;&%Y97(L("1L
M87EE<G,I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("(@;VYL>2!T:&4@
M;&%Y97)S.B!<(B(@+B!I;7!L;V1E*"<B(&]R("(G+"`D;&%Y97)S*2`N(")<
M(B!A<F4@<W5P<&]R=&5D(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+R\@?7U]#0I]
M#0H-"C\^#0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+T-O;F9I9RYX;6P`
M````````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8V,C$`,3`U,34T,S,W
M-#``,#(R-C0R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#QC;VUM86YD<R!V97)S:6]N/2(Q+C`B/@T*(#QC;VYF:6<M<VAO
M=SX-"B`@/'-U;6UA<GD^4VAO=R!!;&P@4V5T=&EN9W,\+W-U;6UA<GD^#0H@
M(#QF=6YC=&EO;CYD;T-O;F9I9U-H;W<\+V9U;F-T:6]N/@T*("`\<VAO<G1C
M=70^8W-H/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,^#0H@("`\8VAA;FYE;#X-
M"B`@("`\<VAO<G1O<'0^8SPO<VAO<G1O<'0^#0H@("`@/&1O8SYS:&]W(&-O
M;F9I9W5R871I;VX@=F%R:6%B;&5S(&9O<B!A;F]T:&5R(&-H86YN96P\+V1O
M8SX-"B`@("`\87)G/D-(04X\+V%R9SX-"B`@(#PO8VAA;FYE;#X-"B`@/"]O
M<'1I;VYS/@T*("`\9&]C/EML87EE<ET-"D1I<W!L87ES(&%L;"!C;VYF:6=U
M<F%T:6]N('9A;'5E<RX@($%N(&]P=&EO;F%L(&%R9W5M96YT#0IM87D@8F4@
M=7-E9"!T;R!T96QL('=H:6-H(&-O;F9I9W5R871I;VX@;&%Y97(@=&\@9&ES
M<&QA>2X@(%9A;&ED#0IC;VYF:6=U<F%T:6]N(&QA>65R<R!A<F4@)G%U;W0[
M=7-E<B9Q=6]T.RP@)G%U;W0[<WES=&5M)G%U;W0[(&%N9"`F<75O=#MD969A
M=6QT)G%U;W0[+B!4;R!D:7-P;&%Y#0IC;VYF:6=U<F%T:6]N<R!F;W(@9&EF
M9F5R96YT(&-H86YN96QS+"!S970@=&AE(&1E9F%U;'1?8VAA;FYE;`T*8V]N
M9FEG=7)A=&EO;B!V87)I86)L92!A;F0@<G5N(&-O;F9I9RUS:&]W(&%G86EN
M+@T*/"]D;V,^#0H@/"]C;VYF:6<M<VAO=SX-"B`\8V]N9FEG+6=E=#X-"B`@
M/'-U;6UA<GD^4VAO=R!/;F4@4V5T=&EN9SPO<W5M;6%R>3X-"B`@/&9U;F-T
M:6]N/F1O0V]N9FEG1V5T/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/F-G/"]S
M:&]R=&-U=#X-"B`@/&]P=&EO;G,^#0H@("`\8VAA;FYE;#X-"B`@("`\<VAO
M<G1O<'0^8SPO<VAO<G1O<'0^#0H@("`@/&1O8SYS:&]W(&-O;F9I9W5R871I
M;VX@=F%R:6%B;&5S(&9O<B!A;F]T:&5R(&-H86YN96P\+V1O8SX-"B`@("`\
M87)G/D-(04X\+V%R9SX-"B`@(#PO8VAA;FYE;#X-"B`@/"]O<'1I;VYS/@T*
M("`\9&]C/B9L=#MP87)A;65T97(F9W0[(%ML87EE<ET-"D1I<W!L87ES('1H
M92!V86QU92!O9B!O;F4@8V]N9FEG=7)A=&EO;B!P87)A;65T97(N("!4:&4-
M"F9I<G-T(&%R9W5M96YT(&ES('1H92!N86UE(&]F('1H92!P87)A;65T97(L
M(&%N(&]P=&EO;F%L('-E8V]N9"!A<F=U;65N=`T*;6%Y(&)E('5S960@=&\@
M=&5L;"!W:&EC:"!C;VYF:6=U<F%T:6]N(&QA>65R('1O(&QO;VL@:6XN("!6
M86QI9"!C;VYF:6=U<F%T:6]N#0IL87EE<G,@87)E("9Q=6]T.W5S97(F<75O
M=#LL("9Q=6]T.W-Y<W1E;29Q=6]T.R!A;F0@)G%U;W0[9&5F875L="9Q=6]T
M.RX@($EF(&YO(&QA>65R(&ES('-P96-I9FEE9"P@82!V86QU90T*=VEL;"!B
M92!P:6-K960@9G)O;2!T:&4@9FER<W0@;&%Y97(@=&AA="!D969I;F5S('1H
M92!P87)A;65T97(L(&EN('1H92!O<F1E<@T*:G5S="!S<&5C:69I960N("!4
M:&4@8V]N9FEG=7)A=&EO;B!V86QU92!W:6QL(&)E(')E=')I979E9"!F;W(@
M=&AE(&-H86YN96P-"G-P96-I9FEE9"!B>2!T:&4@9&5F875L=%]C:&%N;F5L
M(&-O;F9I9W5R871I;VX@=F%R:6%B;&4N#0H\+V1O8SX-"B`\+V-O;F9I9RUG
M970^#0H@/&-O;F9I9RUS970^#0H@(#QS=6UM87)Y/D-H86YG92!3971T:6YG
M/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]#;VYF:6=3970\+V9U;F-T:6]N
M/@T*("`\<VAO<G1C=70^8W,\+W-H;W)T8W5T/@T*("`\;W!T:6]N<SX-"B`@
M(#QC:&%N;F5L/@T*("`@(#QS:&]R=&]P=#YC/"]S:&]R=&]P=#X-"B`@("`\
M9&]C/G-H;W<@8V]N9FEG=7)A=&EO;B!V87)I86)L97,@9F]R(&%N;W1H97(@
M8VAA;FYE;#PO9&]C/@T*("`@(#QA<F<^0TA!3CPO87)G/@T*("`@/"]C:&%N
M;F5L/@T*("`\+V]P=&EO;G,^#0H@(#QD;V,^)FQT.W!A<F%M971E<B9G=#L@
M)FQT.W9A;'5E)F=T.R!;;&%Y97)=#0I3971S('1H92!V86QU92!O9B!O;F4@
M8V]N9FEG=7)A=&EO;B!P87)A;65T97(N("!4:&4@9FER<W0@87)G=6UE;G0@
M:7,-"G1H92!N86UE(&]F('1H92!P87)A;65T97(L('1H92!S96-O;F0@87)G
M=6UE;G0@:7,@=&AE(&YE=R!V86QU92X@(%-O;64-"G!A<F%M971E<G,@87)E
M('-U8FIE8W0@=&\@=F%L:61A=&EO;BP@86YD('1H92!C;VUM86YD('=I;&P@
M9F%I;"!W:71H#0IA;B!E<G)O<B!M97-S86=E(&EF('1H92!N97<@=F%L=64@
M9&]E<R!N;W0@;6%K92!S96YS92X@($%N(&]P=&EO;F%L#0IT:&ER9"!A<F=U
M;65N="!M87D@8F4@=7-E9"!T;R!S<&5C:69Y(&EN('=H:6-H(&QA>65R('1O
M('-E="!T:&4-"F-O;F9I9W5R871I;VX@<&%R86UE=&5R+B`@5&AE(&1E9F%U
M;'0@;&%Y97(@:7,@)G%U;W0[=7-E<B9Q=6]T.RX@(%1H90T*8V]N9FEG=7)A
M=&EO;B!V86QU92!W:6QL(&)E('-E="!F;W(@=&AE(&-U<G)E;G0@8VAA;FYE
M;"P@=VAI8V@-"FES(&-O;G1R;VQL960@8GD@=&AE(&1E9F%U;'1?8VAA;FYE
M;"!C;VYF:6=U<F%T:6]N('9A<FEA8FQE+@T*/"]D;V,^#0H@/"]C;VYF:6<M
M<V5T/@T*(#QC;VYF:6<M:&5L<#X-"B`@/'-U;6UA<GD^4VAO=R!);F9O<FUA
M=&EO;B!!8F]U="!3971T:6YG/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]#
M;VYF:6=(96QP/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/F-H/"]S:&]R=&-U
M=#X-"B`@/&]P=&EO;G,@+SX-"B`@/&1O8SY;<&%R86UE=&5R70T*1&ES<&QA
M>7,@:&5L<"!F;W(@82!C;VYF:6=U<F%T:6]N('!A<F%M971E<BX@(%=I=&AO
M=70@87)G=6UE;G1S(&ET#0ID:7-P;&%Y<R!H96QP(&9O<B!A;&P@8V]N9FEG
M=7)A=&EO;B!P87)A;65T97)S+@T*/"]D;V,^#0H@/"]C;VYF:6<M:&5L<#X-
M"B`\8V]N9FEG+6-R96%T93X-"B`@/'-U;6UA<GD^0W)E871E(&$@1&5F875L
M="!C;VYF:6=U<F%T:6]N(&9I;&4\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD
M;T-O;F9I9T-R96%T93PO9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YC;V,\+W-H
M;W)T8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QW:6YD;W=S/@T*("`@(#QS:&]R
M=&]P=#YW/"]S:&]R=&]P=#X-"B`@("`\9&]C/F-R96%T92!A(&-O;F9I9R!F
M:6QE(&9O<B!A('=I;F1O=W,@:6YS=&%L;#PO9&]C/@T*("`@/"]W:6YD;W=S
M/@T*("`\+V]P=&EO;G,^#0H@(#QD;V,^)FQT.W)O;W0@<&%T:"9G=#L@)FQT
M.V9I;&5N86UE)F=T.PT*0W)E871E(&$@9&5F875L="!C;VYF:6=U<F%T:6]N
M(&9I;&4@=VET:"!A;&P@9&ER96-T;W)Y(&-O;F9I9W5R871I;VX-"G9A<FEA
M8FQE<R!S970@=&\@<W5B9&ER96-T;W)I97,@;V8@)FQT.W)O;W0@<&%T:"9G
M=#LL(&%N9"!S879E(&ET(&%S("9L=#MF:6QE;F%M929G=#LN#0I4:&ES(&ES
M('5S969U;"!E<W!E8VEA;&QY(&9O<B!C<F5A=&EN9R!A(&-O;F9I9W5R871I
M;VX@9FEL92!F;W(@82!R96UO=&4-"E!%05(@:6YS=&%L;&%T:6]N("AU<VEN
M9R!T:&4@+2UR96UO=&5C;VYF:6<@;W!T:6]N(&]F(&EN<W1A;&PL('5P9W)A
M9&4L#0IA;F0@=6YI;G-T86QL*2X-"CPO9&]C/@T*(#PO8V]N9FEG+6-R96%T
M93X-"CPO8V]M;6%N9',^````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]);G-T86QL+G!H
M<```````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3`Q,30U`#$P-3$U-#,S
M-S0P`#`R,S`R-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`T*+RHJ#0H@*B!014%27T-O;6UA;F1?26YS=&%L;"`H
M:6YS=&%L;"P@=7!G<F%D92P@=7!G<F%D92UA;&PL('5N:6YS=&%L;"P@8G5N
M9&QE+"!R=6XM<V-R:7!T<R!C;VUM86YD<RD-"B`J#0H@*B!02%`@=F5R<VEO
M;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-
M"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M
M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@
M82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@
M=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD
M(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U
M(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R
M#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!3=&EG($)A
M:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!'<F5G($)E879E
M<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@
M5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R
M<VEO;B`@("!#5E,Z("1)9#H@26YS=&%L;"YP:'`L=B`Q+C$Q-2`R,#`V+S`S
M+S`R(#$X.C$T.C$S(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@
M($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"@T*+RHJ
M#0H@*B!B87-E(&-L87-S#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4B]#;VUM
M86YD+T-O;6UO;BYP:'`G.PT*#0HO*BH-"B`J(%!%05(@8V]M;6%N9',@9F]R
M(&EN<W1A;&QA=&EO;B!O<B!D96EN<W1A;&QA=&EO;B]U<&=R861I;F<@;V8-
M"B`J('!A8VMA9V5S+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P
M86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS
M<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL
M;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0
M($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@
M(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A
M:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"F-L87-S(%!%05)?0V]M
M;6%N9%]);G-T86QL(&5X=&5N9',@4$5!4E]#;VUM86YD7T-O;6UO;@T*>PT*
M("`@("\O('M[>R!P<F]P97)T:65S#0H-"B`@("!V87(@)&-O;6UA;F1S(#T@
M87)R87DH#0H@("`@("`@("=I;G-T86QL)R`]/B!A<G)A>2@-"B`@("`@("`@
M("`@("=S=6UM87)Y)R`]/B`G26YS=&%L;"!086-K86=E)RP-"B`@("`@("`@
M("`@("=F=6YC=&EO;B<@/3X@)V1O26YS=&%L;"<L#0H@("`@("`@("`@("`G
M<VAO<G1C=70G(#T^("=I)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`G9F]R8V4G(#T^(&%R<F%Y*`T*("`@
M("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=F)RP-"B`@("`@("`@
M("`@("`@("`@("`@)V1O8R<@/3X@)W=I;&P@;W9E<G=R:71E(&YE=V5R(&EN
M<W1A;&QE9"!P86-K86=E<R<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@
M("`@("`@("`@("`@("`@)VQO;W-E)R`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`@("`@)W-H;W)T;W!T)R`]/B`G;"<L#0H@("`@("`@("`@("`@("`@
M("`@("=D;V,G(#T^("=D;R!N;W0@8VAE8VL@9F]R(')E8V]M;65N9&5D(&1E
M<&5N9&5N8WD@=F5R<VEO;B<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@
M("`@("`@("`@("`@("`@)VYO9&5P<R<@/3X@87)R87DH#0H@("`@("`@("`@
M("`@("`@("`@("=S:&]R=&]P="<@/3X@)VXG+`T*("`@("`@("`@("`@("`@
M("`@("`G9&]C)R`]/B`G:6=N;W)E(&1E<&5N9&5N8VEE<RP@:6YS=&%L;"!A
M;GEW87DG+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@
M("`@("=R96=I<W1E<BUO;FQY)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@)W-H;W)T;W!T)R`]/B`G<B<L#0H@("`@("`@("`@("`@("`@("`@
M("=D;V,G(#T^("=D;R!N;W0@:6YS=&%L;"!F:6QE<RP@;VYL>2!R96=I<W1E
M<B!T:&4@<&%C:V%G92!A<R!I;G-T86QL960G+`T*("`@("`@("`@("`@("`@
M("`@("`I+`T*("`@("`@("`@("`@("`@("=S;V9T)R`]/B!A<G)A>2@-"B`@
M("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G<R<L#0H@("`@("`@
M("`@("`@("`@("`@("=D;V,G(#T^("=S;V9T(&EN<W1A;&PL(&9A:6P@<VEL
M96YT;'DL(&]R('5P9W)A9&4@:68@86QR96%D>2!I;G-T86QL960G+`T*("`@
M("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=N;V)U:6QD
M)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]
M/B`G0B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=D;VY<)W0@
M8G5I;&0@0R!E>'1E;G-I;VYS)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-
M"B`@("`@("`@("`@("`@("`G;F]C;VUP<F5S<R<@/3X@87)R87DH#0H@("`@
M("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)UHG+`T*("`@("`@("`@
M("`@("`@("`@("`G9&]C)R`]/B`G<F5Q=65S="!U;F-O;7!R97-S960@9FEL
M97,@=VAE;B!D;W=N;&]A9&EN9R<L#0H@("`@("`@("`@("`@("`@("`@("DL
M#0H@("`@("`@("`@("`@("`@)VEN<W1A;&QR;V]T)R`]/B!A<G)A>2@-"B`@
M("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G4B<L#0H@("`@("`@
M("`@("`@("`@("`@("=A<F<G(#T^("=$25(G+`T*("`@("`@("`@("`@("`@
M("`@("`G9&]C)R`]/B`G<F]O="!D:7)E8W1O<GD@=7-E9"!W:&5N(&EN<W1A
M;&QI;F<@9FEL97,@*&%L82!02%!<)W,@24Y35$%,3%]23T]4*2P@=7-E('!A
M8VMA9VEN9W)O;W0@9F]R(%)032<L#0H@("`@("`@("`@("`@("`@("`@("DL
M#0H@("`@("`@("`@("`@("`@)W!A8VMA9VEN9W)O;W0G(#T^(&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=0)RP-"B`@("`@
M("`@("`@("`@("`@("`@)V%R9R<@/3X@)T1)4B<L#0H@("`@("`@("`@("`@
M("`@("`@("=D;V,G(#T^("=R;V]T(&1I<F5C=&]R>2!U<V5D('=H96X@<&%C
M:V%G:6YG(&9I;&5S+"!L:6ME(%)032!P86-K86=I;F<G+`T*("`@("`@("`@
M("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=I9VYO<F4M97)R;W)S
M)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)V9O
M<F-E(&EN<W1A;&P@979E;B!I9B!T:&5R92!W97)E(&5R<F]R<R<L#0H@("`@
M("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)V%L;&1E<',G
M(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^
M("=A)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)VEN<W1A;&P@
M86QL(')E<75I<F5D(&%N9"!O<'1I;VYA;"!D97!E;F1E;F-I97,G+`T*("`@
M("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=O;FQY<F5Q
M9&5P<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P
M="<@/3X@)V\G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G:6YS
M=&%L;"!A;&P@<F5Q=6ER960@9&5P96YD96YC:65S)RP-"B`@("`@("`@("`@
M("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G;V9F;&EN92<@/3X@87)R
M87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)T\G+`T*
M("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G9&\@;F]T(&%T=&5M<'0@
M=&\@9&]W;FQO860@86YY('5R;',@;W(@8V]N=&%C="!C:&%N;F5L<R<L#0H@
M("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)W!R971E
M;F0G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G
M(#T^("=P)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)T]N;'D@
M;&ES="!T:&4@<&%C:V%G97,@=&AA="!W;W5L9"!B92!D;W=N;&]A9&5D)RP-
M"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`I+`T*
M("`@("`@("`@("`@)V1O8R<@/3X@)UMC:&%N;F5L+UT\<&%C:V%G93X@+BXN
M#0I);G-T86QL<R!O;F4@;W(@;6]R92!014%2('!A8VMA9V5S+B`@66]U(&-A
M;B!S<&5C:69Y(&$@<&%C:V%G92!T;PT*:6YS=&%L;"!I;B!F;W5R('=A>7,Z
M#0H-"B)086-K86=E+3$N,"YT9WHB(#H@:6YS=&%L;',@9G)O;2!A(&QO8V%L
M(&9I;&4-"@T*(FAT='`Z+R]E>&%M<&QE+F-O;2]086-K86=E+3$N,"YT9WHB
M(#H@:6YS=&%L;',@9G)O;0T*86YY=VAE<F4@;VX@=&AE(&YE="X-"@T*(G!A
M8VMA9V4N>&UL(B`Z(&EN<W1A;&QS('1H92!P86-K86=E(&1E<V-R:6)E9"!I
M;@T*<&%C:V%G92YX;6PN("!5<V5F=6P@9F]R('1E<W1I;F<L(&]R(&9O<B!W
M<F%P<&EN9R!A(%!%05(@<&%C:V%G92!I;@T*86YO=&AE<B!P86-K86=E(&UA
M;F%G97(@<W5C:"!A<R!24$TN#0H-"B)086-K86=E6RUV97)S:6]N+W-T871E
M75LN=&%R72(@.B!Q=65R:65S('EO=7(@9&5F875L="!C:&%N;F5L7"=S('-E
M<G9E<@T**'MC;VYF:6<@;6%S=&5R7W-E<G9E<GTI(&%N9"!D;W=N;&]A9',@
M=&AE(&YE=V5S="!P86-K86=E('=I=&@-"G1H92!P<F5F97)R960@<75A;&ET
M>2]S=&%T92`H>V-O;F9I9R!P<F5F97)R961?<W1A=&5]*2X-"@T*5&\@<F5T
M<FEE=F4@4&%C:V%G92!V97)S:6]N(#$N,2P@=7-E(")086-K86=E+3$N,2PB
M('1O(')E=')I979E#0I086-K86=E('-T871E(&)E=&$L('5S92`B4&%C:V%G
M92UB971A+B(@(%1O(')E=')I979E(&%N('5N8V]M<')E<W-E9`T*9FEL92P@
M87!P96YD("YT87(@*&UA:V4@<W5R92!T:&5R92!I<R!N;R!F:6QE(&)Y('1H
M92!S86UE(&YA;64@9FER<W0I#0H-"E1O(&1O=VYL;V%D(&$@<&%C:V%G92!F
M<F]M(&%N;W1H97(@8VAA;FYE;"P@<')E9FEX('=I=&@@=&AE(&-H86YN96P@
M;F%M92!L:6ME#0HB8VAA;FYE;"]086-K86=E(@T*#0I-;W)E('1H86X@;VYE
M('!A8VMA9V4@;6%Y(&)E('-P96-I9FEE9"!A="!O;F-E+B`@270@:7,@;VL@
M=&\@;6EX('1H97-E#0IF;W5R('=A>7,@;V8@<W!E8VEF>6EN9R!P86-K86=E
M<RX-"B<I+`T*("`@("`@("`G=7!G<F%D92<@/3X@87)R87DH#0H@("`@("`@
M("`@("`G<W5M;6%R>2<@/3X@)U5P9W)A9&4@4&%C:V%G92<L#0H@("`@("`@
M("`@("`G9G5N8W1I;VXG(#T^("=D;TEN<W1A;&PG+`T*("`@("`@("`@("`@
M)W-H;W)T8W5T)R`]/B`G=7`G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^
M(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=F;W)C92<@/3X@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)V8G+`T*("`@("`@
M("`@("`@("`@("`@("`G9&]C)R`]/B`G;W9E<G=R:71E(&YE=V5R(&EN<W1A
M;&QE9"!P86-K86=E<R<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@
M("`@("`@("`@("`@)VQO;W-E)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@)W-H;W)T;W!T)R`]/B`G;"<L#0H@("`@("`@("`@("`@("`@("`@
M("=D;V,G(#T^("=D;R!N;W0@8VAE8VL@9F]R(')E8V]M;65N9&5D(&1E<&5N
M9&5N8WD@=F5R<VEO;B<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@
M("`@("`@("`@("`@)VYO9&5P<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`@("=S:&]R=&]P="<@/3X@)VXG+`T*("`@("`@("`@("`@("`@("`@
M("`G9&]C)R`]/B`G:6=N;W)E(&1E<&5N9&5N8VEE<RP@=7!G<F%D92!A;GEW
M87DG+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@
M("=R96=I<W1E<BUO;FQY)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@
M("`@)W-H;W)T;W!T)R`]/B`G<B<L#0H@("`@("`@("`@("`@("`@("`@("=D
M;V,G(#T^("=D;R!N;W0@:6YS=&%L;"!F:6QE<RP@;VYL>2!R96=I<W1E<B!T
M:&4@<&%C:V%G92!A<R!U<&=R861E9"<L#0H@("`@("`@("`@("`@("`@("`@
M("DL#0H@("`@("`@("`@("`@("`@)VYO8G5I;&0G(#T^(&%R<F%Y*`T*("`@
M("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=")RP-"B`@("`@("`@
M("`@("`@("`@("`@)V1O8R<@/3X@)V1O;EPG="!B=6EL9"!#(&5X=&5N<VEO
M;G,G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@
M("=N;V-O;7!R97-S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@
M)W-H;W)T;W!T)R`]/B`G6B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G
M(#T^("=R97%U97-T('5N8V]M<')E<W-E9"!F:6QE<R!W:&5N(&1O=VYL;V%D
M:6YG)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@
M("`G:6YS=&%L;')O;W0G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@
M("`G<VAO<G1O<'0G(#T^("=2)RP-"B`@("`@("`@("`@("`@("`@("`@)V%R
M9R<@/3X@)T1)4B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=R
M;V]T(&1I<F5C=&]R>2!U<V5D('=H96X@:6YS=&%L;&EN9R!F:6QE<R`H86QA
M(%!(4%PG<R!)3E-404Q,7U)/3U0I+"!U<V4@<&%C:V%G:6YG<F]O="!F;W(@
M4E!-)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@
M("`G<&%C:V%G:6YG<F]O="<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@
M("`@("=S:&]R=&]P="<@/3X@)U`G+`T*("`@("`@("`@("`@("`@("`@("`G
M87)G)R`]/B`G1$E2)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@
M)W)O;W0@9&ER96-T;W)Y('5S960@=VAE;B!P86-K86=I;F<@9FEL97,L(&QI
M:V4@4E!-('!A8VMA9VEN9R<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@
M("`@("`@("`@("`@("`@)VEG;F]R92UE<G)O<G,G(#T^(&%R<F%Y*`T*("`@
M("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G9F]R8V4@:6YS=&%L;"!E=F5N
M(&EF('1H97)E('=E<F4@97)R;W)S)RP-"B`@("`@("`@("`@("`@("`@("`@
M*2P-"B`@("`@("`@("`@("`@("`G86QL9&5P<R<@/3X@87)R87DH#0H@("`@
M("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)V$G+`T*("`@("`@("`@
M("`@("`@("`@("`G9&]C)R`]/B`G:6YS=&%L;"!A;&P@<F5Q=6ER960@86YD
M(&]P=&EO;F%L(&1E<&5N9&5N8VEE<R<L#0H@("`@("`@("`@("`@("`@("`@
M("DL#0H@("`@("`@("`@("`@("`@)V]N;'ER97%D97!S)R`]/B!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G;R<L#0H@("`@
M("`@("`@("`@("`@("`@("=D;V,G(#T^("=I;G-T86QL(&%L;"!R97%U:7)E
M9"!D97!E;F1E;F-I97,G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@
M("`@("`@("`@("`@("=O9F9L:6YE)R`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`@("`@)W-H;W)T;W!T)R`]/B`G3R<L#0H@("`@("`@("`@("`@("`@
M("`@("=D;V,G(#T^("=D;R!N;W0@871T96UP="!T;R!D;W=N;&]A9"!A;GD@
M=7)L<R!O<B!C;VYT86-T(&-H86YN96QS)RP-"B`@("`@("`@("`@("`@("`@
M("`@*2P-"B`@("`@("`@("`@("`@("`G<')E=&5N9"<@/3X@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)W`G+`T*("`@("`@
M("`@("`@("`@("`@("`G9&]C)R`]/B`G3VYL>2!L:7-T('1H92!P86-K86=E
M<R!T:&%T('=O=6QD(&)E(&1O=VYL;V%D960G+`T*("`@("`@("`@("`@("`@
M("`@("`I+`T*("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`G9&]C
M)R`]/B`G/'!A8VMA9V4^("XN+@T*57!G<F%D97,@;VYE(&]R(&UO<F4@4$5!
M4B!P86-K86=E<RX@(%-E92!D;V-U;65N=&%T:6]N(&9O<B!T:&4-"B)I;G-T
M86QL(B!C;VUM86YD(&9O<B!W87ES('1O('-P96-I9GD@82!P86-K86=E+@T*
M#0I7:&5N('5P9W)A9&EN9RP@>6]U<B!P86-K86=E('=I;&P@8F4@=7!D871E
M9"!I9B!T:&4@<')O=FED960@;F5W#0IP86-K86=E(&AA<R!A(&AI9VAE<B!V
M97)S:6]N(&YU;6)E<B`H=7-E('1H92`M9B!O<'1I;VX@:68@>6]U(&YE960@
M=&\-"G5P9W)A9&4@86YY=V%Y*2X-"@T*36]R92!T:&%N(&]N92!P86-K86=E
M(&UA>2!B92!S<&5C:69I960@870@;VYC92X-"B<I+`T*("`@("`@("`G=7!G
M<F%D92UA;&PG(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^
M("=5<&=R861E($%L;"!086-K86=E<R<L#0H@("`@("`@("`@("`G9G5N8W1I
M;VXG(#T^("=D;TEN<W1A;&PG+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]
M/B`G=6$G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@
M("`@("`@("`@("`@("=N;V1E<',G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("`@("`G<VAO<G1O<'0G(#T^("=N)RP-"B`@("`@("`@("`@("`@("`@
M("`@)V1O8R<@/3X@)VEG;F]R92!D97!E;F1E;F-I97,L('5P9W)A9&4@86YY
M=V%Y)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@
M("`G<F5G:7-T97(M;VYL>2<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@
M("`@("=S:&]R=&]P="<@/3X@)W(G+`T*("`@("`@("`@("`@("`@("`@("`G
M9&]C)R`]/B`G9&\@;F]T(&EN<W1A;&P@9FEL97,L(&]N;'D@<F5G:7-T97(@
M=&AE('!A8VMA9V4@87,@=7!G<F%D960G+`T*("`@("`@("`@("`@("`@("`@
M("`I+`T*("`@("`@("`@("`@("`@("=N;V)U:6QD)R`]/B!A<G)A>2@-"B`@
M("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G0B<L#0H@("`@("`@
M("`@("`@("`@("`@("=D;V,G(#T^("=D;VY<)W0@8G5I;&0@0R!E>'1E;G-I
M;VYS)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@
M("`G;F]C;VUP<F5S<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@
M("=S:&]R=&]P="<@/3X@)UHG+`T*("`@("`@("`@("`@("`@("`@("`G9&]C
M)R`]/B`G<F5Q=65S="!U;F-O;7!R97-S960@9FEL97,@=VAE;B!D;W=N;&]A
M9&EN9R<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@
M("`@)VEN<W1A;&QR;V]T)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@
M("`@)W-H;W)T;W!T)R`]/B`G4B<L#0H@("`@("`@("`@("`@("`@("`@("=A
M<F<G(#T^("=$25(G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G
M<F]O="!D:7)E8W1O<GD@=7-E9"!W:&5N(&EN<W1A;&QI;F<@9FEL97,@*&%L
M82!02%!<)W,@24Y35$%,3%]23T]4*2P@=7-E('!A8VMA9VEN9W)O;W0@9F]R
M(%)032<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@
M("`@)VEG;F]R92UE<G)O<G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@
M("`@("`G9&]C)R`]/B`G9F]R8V4@:6YS=&%L;"!E=F5N(&EF('1H97)E('=E
M<F4@97)R;W)S)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@
M("`@("`@("`G;&]O<V4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@
M("`G9&]C)R`]/B`G9&\@;F]T(&-H96-K(&9O<B!R96-O;6UE;F1E9"!D97!E
M;F1E;F-Y('9E<G-I;VXG+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@
M("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G#0I5<&=R
M861E<R!A;&P@<&%C:V%G97,@=&AA="!H879E(&$@;F5W97(@<F5L96%S92!A
M=F%I;&%B;&4N("!5<&=R861E<R!A<F4-"F1O;F4@;VYL>2!I9B!T:&5R92!I
M<R!A(')E;&5A<V4@879A:6QA8FQE(&]F('1H92!S=&%T92!S<&5C:69I960@
M:6X-"B)P<F5F97)R961?<W1A=&4B("AC=7)R96YT;'D@>V-O;F9I9R!P<F5F
M97)R961?<W1A=&5]*2P@;W(@82!S=&%T92!C;VYS:61E<F5D#0IM;W)E('-T
M86)L92X-"B<I+`T*("`@("`@("`G=6YI;G-T86QL)R`]/B!A<G)A>2@-"B`@
M("`@("`@("`@("=S=6UM87)Y)R`]/B`G56XM:6YS=&%L;"!086-K86=E)RP-
M"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O56YI;G-T86QL)RP-"B`@
M("`@("`@("`@("=S:&]R=&-U="<@/3X@)W5N)RP-"B`@("`@("`@("`@("=O
M<'1I;VYS)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`G;F]D97!S)R`]
M/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G
M;B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=I9VYO<F4@9&5P
M96YD96YC:65S+"!U;FEN<W1A;&P@86YY=V%Y)RP-"B`@("`@("`@("`@("`@
M("`@("`@*2P-"B`@("`@("`@("`@("`@("`G<F5G:7-T97(M;VYL>2<@/3X@
M87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)W(G
M+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G9&\@;F]T(')E;6]V
M92!F:6QE<RP@;VYL>2!R96=I<W1E<B!T:&4@<&%C:V%G97,@87,@;F]T(&EN
M<W1A;&QE9"<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@
M("`@("`@)VEN<W1A;&QR;V]T)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@)W-H;W)T;W!T)R`]/B`G4B<L#0H@("`@("`@("`@("`@("`@("`@
M("=A<F<G(#T^("=$25(G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]
M/B`G<F]O="!D:7)E8W1O<GD@=7-E9"!W:&5N(&EN<W1A;&QI;F<@9FEL97,@
M*&%L82!02%!<)W,@24Y35$%,3%]23T]4*2<L#0H@("`@("`@("`@("`@("`@
M("`@("DL#0H@("`@("`@("`@("`@("`@)VEG;F]R92UE<G)O<G,G(#T^(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G9F]R8V4@:6YS
M=&%L;"!E=F5N(&EF('1H97)E('=E<F4@97)R;W)S)RP-"B`@("`@("`@("`@
M("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G;V9F;&EN92<@/3X@87)R
M87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)T\G+`T*
M("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G9&\@;F]T(&%T=&5M<'0@
M=&\@=6YI;G-T86QL(')E;6]T96QY)RP-"B`@("`@("`@("`@("`@("`@("`@
M*2P-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@
M)UMC:&%N;F5L+UT\<&%C:V%G93X@+BXN#0I5;FEN<W1A;&QS(&]N92!O<B!M
M;W)E(%!%05(@<&%C:V%G97,N("!-;W)E('1H86X@;VYE('!A8VMA9V4@;6%Y
M(&)E#0IS<&5C:69I960@870@;VYC92X@(%!R969I>"!W:71H(&-H86YN96P@
M;F%M92!T;R!U;FEN<W1A;&P@9G)O;2!A#0IC:&%N;F5L(&YO="!I;B!Y;W5R
M(&1E9F%U;'0@8VAA;FYE;"`H>V-O;F9I9R!D969A=6QT7V-H86YN96Q]*0T*
M)RDL#0H@("`@("`@("=B=6YD;&4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M)W-U;6UA<GDG(#T^("=5;G!A8VMS(&$@4&5C;"!086-K86=E)RP-"B`@("`@
M("`@("`@("=F=6YC=&EO;B<@/3X@)V1O0G5N9&QE)RP-"B`@("`@("`@("`@
M("=S:&]R=&-U="<@/3X@)V)U;B<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@
M/3X@87)R87DH#0H@("`@("`@("`@("`@("`@)V1E<W1I;F%T:6]N)R`]/B!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=D)RP-
M"B`@("`@("`@("`@("`@("`@("`@)V%R9R<@/3X@)T1)4B<L#0H@("`@("`@
M("`@("`@("`@("`@("=D;V,G(#T^("=/<'1I;VYA;"!D97-T:6YA=&EO;B!D
M:7)E8W1O<GD@9F]R('5N<&%C:VEN9R`H9&5F875L=',@=&\@8W5R<F5N="!P
M871H(&]R(")E>'0B(&EF(&5X:7-T<RDG+`T*("`@("`@("`@("`@("`@("`@
M("`I+`T*("`@("`@("`@("`@("`@("=F;W)C92<@/3X@87)R87DH#0H@("`@
M("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)V8G+`T*("`@("`@("`@
M("`@("`@("`@("`G9&]C)R`]/B`G1F]R8V4@=&AE('5N<&%C:VEN9R!E=F5N
M(&EF('1H97)E('=E<F4@97)R;W)S(&EN('1H92!P86-K86=E)RP-"B`@("`@
M("`@("`@("`@("`I+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("=D
M;V,G(#T^("<\<&%C:V%G93X-"E5N<&%C:W,@82!096-L(%!A8VMA9V4@:6YT
M;R!T:&4@<V5L96-T960@;&]C871I;VXN($ET('=I;&P@9&]W;FQO860@=&AE
M#0IP86-K86=E(&EF(&YE961E9"X-"B<I+`T*("`@("`@("`G<G5N+7-C<FEP
M=',G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=2=6X@
M4&]S="U);G-T86QL(%-C<FEP=',@8G5N9&QE9"!W:71H(&$@<&%C:V%G92<L
M#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;U)U;E-C<FEP=',G+`T*
M("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G<G,G+`T*("`@("`@("`@("`@
M)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@*2P-"B`@("`@("`@
M("`@("=D;V,G(#T^("<\<&%C:V%G93X-"E)U;B!P;W-T+6EN<W1A;&QA=&EO
M;B!S8W)I<'1S(&EN('!A8VMA9V4@/'!A8VMA9V4^+"!I9B!A;GD@97AI<W0N
M#0HG*2P-"B`@("`I.PT*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&-O;G-T
M<G5C=&]R#0H-"B`@("`O*BH-"B`@("`@*B!014%27T-O;6UA;F1?26YS=&%L
M;"!C;VYS=')U8W1O<BX-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@4$5!4E]#;VUM86YD7TEN<W1A;&PH
M)B1U:2P@)B1C;VYF:6<I#0H@("`@>PT*("`@("`@("!P87)E;G0Z.E!%05)?
M0V]M;6%N9%]#;VUM;VXH)'5I+"`D8V]N9FEG*3L-"B`@("!]#0H-"B`@("`O
M+R!]?7T-"@T*("`@("\J*@T*("`@("`J($9O<B!U;FET('1E<W1I;F<@<'5R
M<&]S97,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F9V5T1&]W;FQO861E<B@F
M)'5I+"`D;W!T:6]N<RP@)B1C;VYF:6<I#0H@("`@>PT*("`@("`@("!I9B`H
M(6-L87-S7V5X:7-T<R@G4$5!4E]$;W=N;&]A9&5R)RDI('L-"B`@("`@("`@
M("`@(')E<75I<F5?;VYC92`G4$5!4B]$;W=N;&]A9&5R+G!H<"<[#0H@("`@
M("`@('T-"B`@("`@("`@)&$@/2`F;F5W(%!%05)?1&]W;FQO861E<B@D=6DL
M("1O<'1I;VYS+"`D8V]N9FEG*3L-"B`@("`@("`@<F5T=7)N("1A.PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J($9O<B!U;FET('1E<W1I;F<@<'5R<&]S
M97,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F9V5T26YS=&%L;&5R*"8D=6DI
M#0H@("`@>PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]);G-T
M86QL97(G*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+TEN
M<W1A;&QE<BYP:'`G.PT*("`@("`@("!]#0H@("`@("`@("1A(#T@)FYE=R!0
M14%27TEN<W1A;&QE<B@D=6DI.PT*("`@("`@("!R971U<FX@)&$[#0H@("`@
M?0T*#0H@("`@+R\@>WM[(&1O26YS=&%L;"@I#0H-"B`@("!F=6YC=&EO;B!D
M;TEN<W1A;&PH)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-
M"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3YI;G-T86QL97(I*2![#0H@("`@
M("`@("`@("`D=&AI<RT^:6YS=&%L;&5R(#T@)B1T:&ES+3YG971);G-T86QL
M97(H)'1H:7,M/G5I*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&-O;6UA
M;F0@/3T@)W5P9W)A9&4G*2![#0H@("`@("`@("`@("`D;W!T:6]N<ULG=7!G
M<F%D92==(#T@=')U93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H
M)&]P=&EO;G-;)VEN<W1A;&QR;V]T)UTI("8F(&ES<V5T*"1O<'1I;VYS6R=P
M86-K86=I;F=R;V]T)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)T524D]2.B!C86YN;W0@=7-E(&)O=&@@+2UI;G-T86QL
M<F]O="!A;F0@+2UP86-K86=I;F=R;V]T)RD[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&ES<V5T*"1O<'1I;VYS6R=P86-K86=I;F=R;V]T)UTI("8F("1T
M:&ES+3YC;VYF:6<M/F=E="@G=F5R8F]S92<I(#X@,BD@>PT*("`@("`@("`@
M("`@)'1H:7,M/G5I+3YO=71P=71$871A*"=U<VEN9R!P86-K86=E(')O;W0Z
M("<@+B`D;W!T:6]N<ULG<&%C:V%G:6YG<F]O="==*3L-"B`@("`@("`@?0T*
M("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[
M#0H@("`@("`@(&EF("@D8V]M;6%N9"`]/2`G=7!G<F%D92UA;&PG*2![#0H@
M("`@("`@("`@("`D;W!T:6]N<ULG=7!G<F%D92==(#T@=')U93L-"B`@("`@
M("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-
M"B`@("`@("`@("`@("1S879E8VAA;FYE;"`]("1T:&ES+3YC;VYF:6<M/F=E
M="@G9&5F875L=%]C:&%N;F5L)RD[#0H@("`@("`@("`@("`D<&%R86US(#T@
M87)R87DH*3L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1R96<M/FQI<W1#:&%N
M;F5L<R@I(&%S("1C:&%N;F5L*2![#0H@("`@("`@("`@("`@("`@:68@*"1C
M:&%N;F5L(#T]("=?7W5R:2<I('L-"B`@("`@("`@("`@("`@("`@("`@8V]N
M=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T
M:&ES+3YC;VYF:6<M/G-E="@G9&5F875L=%]C:&%N;F5L)RP@)&-H86YN96PI
M.PT*("`@("`@("`@("`@("`@("1C:&%N(#T@)B1R96<M/F=E=$-H86YN96PH
M)&-H86YN96PI.PT*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1C:&%N*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)&-H86XI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!I9B`H)&-H86XM/G-U<'!O<G1S4D535"@D=&AI<RT^8V]N
M9FEG+3YG970H)W!R969E<G)E9%]M:7)R;W(G*2D@)B8-"B`@("`@("`@("`@
M("`@("`@("`@("`D8F%S92`]("1C:&%N+3YG971"87-E55),*"=215-4,2XP
M)RP@)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?;6ER<F]R)RDI*2![
M#0H@("`@("`@("`@("`@("`@("`@("1D;W)E<W0@/2!T<G5E.PT*("`@("`@
M("`@("`@("`@("`@("!U;G-E="@D<F5M;W1E*3L-"B`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D9&]R97-T(#T@9F%L
M<V4[#0H@("`@("`@("`@("`@("`@("`@("1R96UO=&4@/2`F)'1H:7,M/F-O
M;F9I9RT^9V5T4F5M;W1E*"1T:&ES+3YC;VYF:6<I.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`D<W1A=&4@/2`D=&AI<RT^8V]N9FEG
M+3YG970H)W!R969E<G)E9%]S=&%T92<I.PT*("`@("`@("`@("`@("`@("1I
M;G-T86QL960@/2!A<G)A>5]F;&EP*"1R96<M/FQI<W1086-K86=E<R@D8VAA
M;FYE;"DI.PT*("`@("`@("`@("`@("`@(%!%05(Z.G-T871I8U!U<VA%<G)O
M<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@("`@("`@
M("!I9B`H)&1O<F5S="D@>PT*("`@("`@("`@("`@("`@("`@("`D<F5S="`]
M("8D=&AI<RT^8V]N9FEG+3YG971215-4*"<Q+C`G+"!A<G)A>2@I*3L-"B`@
M("`@("`@("`@("`@("`@("`@)&QA=&5S="`]("1R97-T+3YL:7-T3&%T97-T
M57!G<F%D97,H)&)A<V4L("1S=&%T92P@)&EN<W1A;&QE9"P@)&-H86YN96PL
M("1R96<I.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@(&EF("AE;7!T>2@D<W1A=&4I('Q\("1S=&%T92`]/2`G86YY
M)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&QA=&5S="`]("1R96UO
M=&4M/F-A;&PH(G!A8VMA9V4N;&ES=$QA=&5S=%)E;&5A<V5S(BD[#0H@("`@
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D;&%T97-T(#T@)')E;6]T92T^8V%L;"@B<&%C:V%G92YL:7-T3&%T
M97-T4F5L96%S97,B+"`D<W1A=&4I.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(%!%05(Z.G-T
M871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D;&%T97-T*2!\?"`A:7-?87)R87DH)&QA=&5S="DI
M('L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1L871E<W0@87,@
M)'!A8VMA9V4@/3X@)&EN9F\I('L-"B`@("`@("`@("`@("`@("`@("`@)'!A
M8VMA9V4@/2!S=')T;VQO=V5R*"1P86-K86=E*3L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D:6YS=&%L;&5D6R1P86-K86=E72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("\O('-K:7`@<&%C:V%G97,@=V4@9&]N
M)W0@:&%V92!I;G-T86QL960-"B`@("`@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("1I;G-T7W9E<G-I;VX@/2`D<F5G+3YP86-K86=E26YF;R@D<&%C
M:V%G92P@)W9E<G-I;VXG+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@
M("`@(&EF("AV97)S:6]N7V-O;7!A<F4H(B1I;F9O6W9E<G-I;VY=(BP@(B1I
M;G-T7W9E<G-I;VXB+"`B;&4B*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@:6YS=&%L;&5D('9E<G-I;VX@:7,@=7`M=&\M9&%T90T*("`@("`@
M("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@)'!A<F%M<UM=(#T@)')E9RT^
M<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9RAA<G)A>2@G<&%C:V%G92<@/3X@
M)'!A8VMA9V4L#0H@("`@("`@("`@("`@("`@("`@("`@("`G8VAA;FYE;"<@
M/3X@)&-H86YN96PI*3L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5I
M+3YO=71P=71$871A*&%R<F%Y*"=D871A)R`]/B`B5VEL;"!U<&=R861E("1P
M86-K86=E(BDL("1C;VUM86YD*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^8V]N9FEG+3YS970H)V1E
M9F%U;'1?8VAA;FYE;"<L("1S879E8VAA;FYE;"D[#0H@("`@("`@('T-"B`@
M("`@("`@)'1H:7,M/F1O=VYL;V%D97(@/2`F)'1H:7,M/F=E=$1O=VYL;V%D
M97(H)'1H:7,M/G5I+"`D;W!T:6]N<RP@)'1H:7,M/F-O;F9I9RD[#0H@("`@
M("`@("1E<G)O<G,@/2!A<G)A>2@I.PT*("`@("`@("`D9&]W;FQO861E9"`]
M(&%R<F%Y*"D[#0H@("`@("`@("1D;W=N;&]A9&5D(#T@)B1T:&ES+3YD;W=N
M;&]A9&5R+3YD;W=N;&]A9"@D<&%R86US*3L-"B`@("`@("`@)&5R<F]R<R`]
M("1T:&ES+3YD;W=N;&]A9&5R+3YG971%<G)O<DUS9W,H*3L-"B`@("`@("`@
M:68@*&-O=6YT*"1E<G)O<G,I*2![#0H@("`@("`@("`@("!F;W)E86-H("@D
M97)R;W)S(&%S("1E<G)O<BD@>PT*("`@("`@("`@("`@("`@("1E<G);)V1A
M=&$G75M=(#T@87)R87DH)&5R<F]R*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("1E<G);)VAE861L:6YE)UT@/2`G26YS=&%L;"!%<G)O<G,G.PT*
M("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1E<G(I.PT*("`@
M("`@("`@("`@:68@*"%C;W5N="@D9&]W;FQO861E9"DI('L-"B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(B1C;VUM86YD(&9A
M:6QE9"(I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1D
M871A(#T@87)R87DH#0H@("`@("`@("`@("`G:&5A9&QI;F4G(#T^("=086-K
M86=E<R!T:&%T('=O=6QD(&)E($EN<W1A;&QE9"<-"B`@("`@("`@*3L-"B`@
M("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=P<F5T96YD)UTI*2![#0H@("`@
M("`@("`@("!F;W)E86-H("@D9&]W;FQO861E9"!A<R`D<&%C:V%G92D@>PT*
M("`@("`@("`@("`@("`@("1D871A6R=D871A)UU;72`](&%R<F%Y*"1R96<M
M/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H)'!A8VMA9V4M/F=E=%!A<G-E
M9%!A8VMA9V4H*2DI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1H
M:7,M/G5I+3YO=71P=71$871A*"1D871A+"`G<')E=&5N9"<I.PT*("`@("`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M
M/FEN<W1A;&QE<BT^<V5T3W!T:6]N<R@D;W!T:6]N<RD[#0H@("`@("`@("1T
M:&ES+3YI;G-T86QL97(M/G-O<G1086-K86=E<T9O<DEN<W1A;&PH)&1O=VYL
M;V%D960I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R(#T@)'1H
M:7,M/FEN<W1A;&QE<BT^<V5T1&]W;FQO861E9%!A8VMA9V5S*"1D;W=N;&]A
M9&5D*2DI('L-"B`@("`@("`@("`@("1T:&ES+3YR86ES945R<F]R*"1E<G(M
M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("!R971U<FX@=')U93L-"B`@
M("`@("`@?0T*("`@("`@("`D97AT<F%I;F9O(#T@87)R87DH*3L-"B`@("`@
M("`@9F]R96%C:"`H)&1O=VYL;V%D960@87,@)'!A<F%M*2![#0H@("`@("`@
M("`@("!014%2.CIS=&%T:6-0=7-H17)R;W)(86YD;&EN9RA014%27T524D]2
M7U)%5%523BD[#0H@("`@("`@("`@("`D:6YF;R`]("1T:&ES+3YI;G-T86QL
M97(M/FEN<W1A;&PH)'!A<F%M+"`D;W!T:6]N<RD[#0H@("`@("`@("`@("!0
M14%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@("`@("`@("`D
M;VQD:6YF;R`]("1I;F9O.PT*("`@("`@("`@("`@("`@("1P:V<@/2`F)'!A
M<F%M+3YG971086-K86=E1FEL92@I.PT*("`@("`@("`@("`@("`@(&EF("@D
M:6YF;RT^9V5T0V]D92@I("$](%!%05)?24Y35$%,3$527TY/0DE.05)9*2![
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@A*"1I;F9O(#T@)'!K9RT^:6YS
M=&%L;$)I;F%R>2@D=&AI<RT^:6YS=&%L;&5R*2DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G15)23U(Z("<@
M+B1O;&1I;F9O+3YG971-97-S86=E*"DI.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@+R\@=V4@:G5S="!I;G-T86QL960@82!D:69F97)E
M;G0@<&%C:V%G92!T:&%N(')E<75E<W1E9"P-"B`@("`@("`@("`@("`@("`@
M("`@+R\@;&5T)W,@8VAA;F=E('1H92!P87)A;2!A;F0@:6YF;R!S;R!T:&%T
M('1H92!R97-T(&]F('1H:7,@=V]R:W,-"B`@("`@("`@("`@("`@("`@("`@
M)'!A<F%M(#T@)&EN9F];,%T[#0H@("`@("`@("`@("`@("`@("`@("1I;F9O
M(#T@)&EN9F];,5T[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1I;F9O*2D@>PT*("`@("`@
M("`@("`@("`@(&EF("@D<&%R86TM/F=E=%!A8VMA9V54>7!E*"D@/3T@)V5X
M='-R8R<@?'P-"B`@("`@("`@("`@("`@("`@("`@("`D<&%R86TM/F=E=%!A
M8VMA9V54>7!E*"D@/3T@)V5X=&)I;B<I('L-"B`@("`@("`@("`@("`@("`@
M("`@)'!K9R`]("8D<&%R86TM/F=E=%!A8VMA9V5&:6QE*"D[#0H@("`@("`@
M("`@("`@("`@("`@(&EF("@D:6YS=&)I;B`]("1P:V<M/F=E=$EN<W1A;&QE
M9$)I;F%R>2@I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D:6YS='!K
M9R`]("8D<F5G+3YG971086-K86=E*"1I;G-T8FEN+"`D<&MG+3YG971#:&%N
M;F5L*"DI.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&EN<W1P:V<@/2`F)')E9RT^9V5T4&%C:V%G
M92@D<&MG+3YG971086-K86=E*"DL("1P:V<M/F=E=$-H86YN96PH*2D[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)&EN<W1P:V<M/F=E=$9I;&5L:7-T*"D@87,@)&YA;64@/3X@)&%T
M=',I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1P:6YF;R`]('!A=&AI
M;F9O*"1A='1S6R=I;G-T86QL961?87,G72D[#0H@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1P:6YF;ULG97AT96YS:6]N)UTI('Q\#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I;E]A<G)A>2@D<&EN9F];
M)V5X=&5N<VEO;B==+"!A<G)A>2@G8R<L("=H)RDI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8V]N=&EN=64[("\O(&UA:V4@<W5R92!W92!D
M;VXG="!M871C:"!P:'!?8FQA:"YH#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H*'-T<G!O<R@D<&EN
M9F];)V)A<V5N86UE)UTL("=P:'!?)RD@/3T](#`@)B8-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P:6YF;ULG97AT96YS:6]N)UT@/3T@)V1L
M;"<I('Q\#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!M;W-T
M('5N:6-E<PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!I;F9O
M6R=E>'1E;G-I;VXG72`]/2`G<V\G('Q\#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!H<"UU>`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!I;F9O6R=E>'1E;G-I;VXG72`]/2`G<VPG*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&5X=')A:6YF;UM=(#T@)UEO=2!S:&]U
M;&0@861D(")E>'1E;G-I;VX])R`N("1P:6YF;ULG8F%S96YA;64G70T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("<B('1O('!H<"YI;FDG
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^
M8V]N9FEG+3YG970H)W9E<F)O<V4G*2`^(#`I('L-"B`@("`@("`@("`@("`@
M("`@("`@)&-H86YN96P@/2`D<&%R86TM/F=E=$-H86YN96PH*3L-"B`@("`@
M("`@("`@("`@("`@("`@)&QA8F5L(#T@)')E9RT^<&%R<V5D4&%C:V%G94YA
M;654;U-T<FEN9R@-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C:&%N;F5L)R`]/B`D8VAA
M;FYE;"P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&%C:V%G92<@
M/3X@)'!A<F%M+3YG971086-K86=E*"DL#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W9E<G-I;VXG(#T^("1P87)A;2T^9V5T5F5R<VEO;B@I+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@*2D[#0H@("`@("`@("`@("`@("`@
M("`@("1O=70@/2!A<G)A>2@G9&%T82<@/3X@(B1C;VUM86YD(&]K.B`D;&%B
M96PB*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=R
M96QE87-E7W=A<FYI;F=S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D;W5T6R=R96QE87-E7W=A<FYI;F=S)UT@/2`D:6YF;ULG<F5L96%S95]W
M87)N:6YG<R==.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D;W5T+"`D8V]M;6%N
M9"D[#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;
M)W)E9VES=&5R+6]N;'DG72D@)B8@(6ES<V5T*"1O<'1I;VYS6R=O9F9L:6YE
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F-O
M;F9I9RT^:7-$969I;F5D3&%Y97(H)V9T<"<I*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H
M4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1I;F9O(#T@)'1H:7,M/FEN<W1A;&QE<BT^9G1P26YS=&%L;"@D<&%R
M86TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05(Z.G-T871I
M8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1I
M;F9O+3YG971-97-S86=E*"DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H(G)E;6]T92!I;G-T86QL
M(&9A:6QE9#H@)&QA8F5L(BD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/G5I+3YO=71P=71$871A*")R96UO=&4@:6YS=&%L;"!O:SH@)&QA
M8F5L(BD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1D97!S(#T@)'!A
M<F%M+3YG971$97!S*"D[#0H@("`@("`@("`@("`@("`@:68@*"1D97!S*2![
M#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P<ULG9W)O=7`G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1G<F]U<',@/2`D9&5P
M<ULG9W)O=7`G73L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)&=R;W5P<ULP72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9W)O=7!S(#T@87)R87DH)&=R;W5P<RD[#0H@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M9W)O=7!S(&%S("1G<F]U<"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@D9W)O=7!;)V%T=')I8G,G75LG;F%M92==(#T]("=D969A=6QT
M)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!D969A
M=6QT(&=R;W5P(&ES(&%L=V%Y<R!I;G-T86QL960L('5N;&5S<R!T:&4@=7-E
M<@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!E>'!L:6-I
M=&QY(&-H;V]S97,@=&\@:6YS=&%L;"!A;F]T:&5R(&=R;W5P#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)'!A<F%M+3YG971086-K86=E
M*"D@+B`G.B!/<'1I;VYA;"!F96%T=7)E("<@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9W)O=7!;)V%T=')I8G,G75LG;F%M92==("X@
M)R!A=F%I;&%B;&4@*"<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9W)O=7!;)V%T=')I8G,G75LG:&EN="==("X@)RDG*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1E>'1R86EN9F];72`]("=4;R!I;G-T86QL('5S92`B<&5A<B!I;G-T86QL
M("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R96<M/G!A<G-E
M9%!A8VMA9V5.86UE5&]3=')I;F<H#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*"=P86-K86=E)R`]/B`D<&%R86TM/F=E=%!A8VMA
M9V4H*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V-H86YN96PG(#T^("1P87)A;2T^9V5T0VAA;FYE;"@I*2P@=')U92D@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<C9F5A='5R96YA
M;64B)SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)VEN<W1A
M;&QR;V]T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1R96<@/2`F)'1H
M:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)'!K9R`]("8D<F5G+3YG971086-K86=E*"1P
M87)A;2T^9V5T4&%C:V%G92@I+"`D<&%R86TM/F=E=$-H86YN96PH*2D[#0H@
M("`@("`@("`@("`@("`@+R\@)'!K9R!M87D@8F4@3E5,3"!I9B!I;G-T86QL
M(&ES(&$@)V9A:V4G(&EN<W1A;&P@=FEA("TM<&%C:V%G:6YG<F]O=`T*("`@
M("`@("`@("`@("`@(&EF("AI<U]O8FIE8W0H)'!K9RDI('L-"B`@("`@("`@
M("`@("`@("`@("`@)'!K9RT^<V5T0V]N9FEG*"1T:&ES+3YC;VYF:6<I.PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H)&QI<W0@/2`D<&MG+3YL:7-T4&]S
M=&EN<W1A;&Q38W)I<'1S*"DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1P;B`]("1R96<M/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H87)R87DH
M)V-H86YN96PG(#T^#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R
M86TM/F=E=$-H86YN96PH*2P@)W!A8VMA9V4G(#T^("1P87)A;2T^9V5T4&%C
M:V%G92@I*2P@=')U92D[#0H@("`@("`@("`@("`@("`@("`@("`@("`D97AT
M<F%I;F9O6UT@/2`D<&X@+B`G(&AA<R!P;W-T+6EN<W1A;&P@<V-R:7!T<SHG
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&QI<W0@87,@
M)&9I;&4I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D97AT<F%I
M;F9O6UT@/2`D9FEL93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1E>'1R86EN9F];72`]("=5<V4@(G!E
M87(@<G5N+7-C<FEP=',@)R`N("1P;B`N("<B('1O(')U;B<[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D97AT<F%I;F9O6UT@/2`G1$\@3D]4(%)53B!3
M0U))4%13($923TT@54Y44E535$5$(%-/55)#15,G.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(B1C;VUM86YD(&9A:6QE9"(I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(&EF("AC;W5N="@D97AT<F%I;F9O*2D@>PT*("`@("`@
M("`@("`@9F]R96%C:"`H)&5X=')A:6YF;R!A<R`D:6YF;RD@>PT*("`@("`@
M("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D:6YF;RD[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&1O56YI;G-T86QL*"D-
M"@T*("`@(&9U;F-T:6]N(&1O56YI;G-T86QL*"1C;VUM86YD+"`D;W!T:6]N
M<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^
M:6YS=&%L;&5R*2D@>PT*("`@("`@("`@("`@)'1H:7,M/FEN<W1A;&QE<B`]
M("8D=&AI<RT^9V5T26YS=&%L;&5R*"1T:&ES+3YU:2D[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=R96UO=&5C;VYF:6<G72DI
M('L-"B`@("`@("`@("`@("1E(#T@)'1H:7,M/F-O;F9I9RT^<F5A9$944$-O
M;F9I9T9I;&4H)&]P=&EO;G-;)W)E;6]T96-O;F9I9R==*3L-"B`@("`@("`@
M("`@(&EF("@A4$5!4CHZ:7-%<G)O<B@D92DI('L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^:6YS=&%L;&5R+3YS971#;VYF:6<H)'1H:7,M/F-O;F9I9RD[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*'-I>F5O
M9B@D<&%R86US*2`\(#$I('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@B4&QE87-E('-U<'!L>2!T:&4@<&%C:V%G92AS*2!Y;W4@
M=V%N="!T;R!U;FEN<W1A;&PB*3L-"B`@("`@("`@?0T*("`@("`@("`D<F5G
M(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@("1N
M97=P87)A;7,@/2!A<G)A>2@I.PT*("`@("`@("`D8F%D<&%R86US(#T@87)R
M87DH*3L-"B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D<&MG*2![#0H@
M("`@("`@("`@("`D8VAA;FYE;"`]("1T:&ES+3YC;VYF:6<M/F=E="@G9&5F
M875L=%]C:&%N;F5L)RD[#0H@("`@("`@("`@("!014%2.CIS=&%T:6-0=7-H
M17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("`@
M("`D<&%R<V5D(#T@)')E9RT^<&%R<V5086-K86=E3F%M92@D<&MG+"`D8VAA
M;FYE;"D[#0H@("`@("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L
M:6YG*"D[#0H@("`@("`@("`@("!I9B`H(21P87)S960@?'P@4$5!4CHZ:7-%
M<G)O<B@D<&%R<V5D*2D@>PT*("`@("`@("`@("`@("`@("1B861P87)A;7-;
M72`]("1P:V<[#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`D<&%C:V%G92`]("1P87)S961;)W!A8VMA
M9V4G73L-"B`@("`@("`@("`@("1C:&%N;F5L(#T@)'!A<G-E9%LG8VAA;FYE
M;"==.PT*("`@("`@("`@("`@)&EN9F\@/2`F)')E9RT^9V5T4&%C:V%G92@D
M<&%C:V%G92P@)&-H86YN96PI.PT*("`@("`@("`@("`@:68@*"1I;F9O(#T]
M/2!N=6QL("8F#0H@("`@("`@("`@("`@("`@("@D8VAA;FYE;"`]/2`G<&5A
M<BYP:'`N;F5T)R!\?"`D8VAA;FYE;"`]/2`G<&5C;"YP:'`N;F5T)RDI('L-
M"B`@("`@("`@("`@("`@("`O+R!M86ME('-U<F4@=&AI<R!I<VXG="!A('!A
M8VMA9V4@=&AA="!H87,@9FQI<'!E9"!F<F]M('!E87(@=&\@<&5C;"!B=70-
M"B`@("`@("`@("`@("`@("`O+R!U<V5D(&$@<&%C:V%G92YX;6P@,2XP#0H@
M("`@("`@("`@("`@("`@)'1E<W1C(#T@*"1C:&%N;F5L(#T]("=P96%R+G!H
M<"YN970G*2`_("=P96-L+G!H<"YN970G(#H@)W!E87(N<&AP+FYE="<[#0H@
M("`@("`@("`@("`@("`@)&EN9F\@/2`F)')E9RT^9V5T4&%C:V%G92@D<&%C
M:V%G92P@)'1E<W1C*3L-"B`@("`@("`@("`@("`@("!I9B`H)&EN9F\@(3T]
M(&YU;&PI('L-"B`@("`@("`@("`@("`@("`@("`@)&-H86YN96P@/2`D=&5S
M=&,[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@:68@*"1I;F9O(#T]/2!N=6QL*2![#0H@("`@("`@("`@("`@("`@
M)&)A9'!A<F%M<UM=(#T@)'!K9SL-"B`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@)&YE=W!A<F%M<UM=(#T@)B1I;F9O.PT*("`@("`@
M("`@("`@("`@("\O(&-H96-K(&9O<B!B:6YA<GD@<&%C:V%G97,@*'1H:7,@
M:7,@86X@86QI87,@9F]R('1H;W-E('!A8VMA9V5S(&EF('-O*0T*("`@("`@
M("`@("`@("`@(&EF("@D:6YS=&%L;&5D8FEN87)Y(#T@)&EN9F\M/F=E=$EN
M<W1A;&QE9$)I;F%R>2@I*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YU:2T^;&]G*"=A9&1I;F<@8FEN87)Y('!A8VMA9V4@)R`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D<F5G+3YP87)S961086-K86=E3F%M951O4W1R
M:6YG*&%R<F%Y*"=C:&%N;F5L)R`]/B`D8VAA;FYE;"P-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<&%C:V%G92<@/3X@)&EN<W1A;&QE9&)I;F%R
M>2DL('1R=64I*3L-"B`@("`@("`@("`@("`@("`@("`@)&YE=W!A<F%M<UM=
M(#T@)B1R96<M/F=E=%!A8VMA9V4H)&EN<W1A;&QE9&)I;F%R>2P@)&-H86YN
M96PI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`O+R!A
M9&0@=&AE(&-O;G1E;G1S(&]F(&$@9&5P96YD96YC>2!G<F]U<"!T;R!T:&4@
M;&ES="!O9B!I;G-T86QL960@<&%C:V%G97,-"B`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)'!A<G-E9%LG9W)O=7`G72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@)&=R;W5P(#T@)&EN9F\M/F=E=$1E<&5N9&5N8WE'<F]U<"@D<&%R
M<V5D6R=G<F]U<"==*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1G<F]U
M<"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&EN<W1A;&QE9"`]("8D
M<F5G+3YG971);G-T86QL961'<F]U<"@D9W)O=7`I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"1I;G-T86QL960I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("@D:6YS=&%L;&5D(&%S("1I(#T^("1P
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N97=P87)A
M;7-;72`]("8D:6YS=&%L;&5D6R1I73L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@)&5R<B`]("1T:&ES+3YI;G-T86QL
M97(M/G-O<G1086-K86=E<T9O<E5N:6YS=&%L;"@D;F5W<&%R86US*3L-"B`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<BDI('L-"B`@("`@("`@("`@
M("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D97)R+3YG971-97-S86=E*"DL("1C
M;VUM86YD*3L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]
M#0H@("`@("`@("1P87)A;7,@/2`D;F5W<&%R86US.PT*("`@("`@("`O+R!T
M=VES="!T:&ES('1O('5S92!I="!T;R!C:&5C:R!O;B!W:&5T:&5R(&1E<&5N
M9&5N="!P86-K86=E<R!A<F4@86QS;R!B96EN9R!U;FEN<W1A;&QE9`T*("`@
M("`@("`O+R!F;W(@8VER8W5L87(@9&5P96YD96YC:65S(&QI:V4@<W5B<&%C
M:V%G97,-"B`@("`@("`@)'1H:7,M/FEN<W1A;&QE<BT^<V5T56YI;G-T86QL
M4&%C:V%G97,H)&YE=W!A<F%M<RD[#0H@("`@("`@("1P87)A;7,@/2!A<G)A
M>5]M97)G92@D<&%R86US+"`D8F%D<&%R86US*3L-"B`@("`@("`@9F]R96%C
M:"`H)'!A<F%M<R!A<R`D<&MG*2![#0H@("`@("`@("`@("`D=&AI<RT^:6YS
M=&%L;&5R+3YP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[
M#0H@("`@("`@("`@("!I9B`H)&5R<B`]("1T:&ES+3YI;G-T86QL97(M/G5N
M:6YS=&%L;"@D<&MG+"`D;W!T:6]N<RDI('L-"B`@("`@("`@("`@("`@("`D
M=&AI<RT^:6YS=&%L;&5R+3YP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@
M("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<BDI('L-"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1E<G(M/F=E=$UE
M<W-A9V4H*2P@)&-O;6UA;F0I.PT*("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'-A
M=F5P:V<@/2`D<&MG.PT*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^8V]N
M9FEG+3YG970H)W9E<F)O<V4G*2`^(#`I('L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*&ES7V]B:F5C="@D<&MG*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'!K9R`]("1R96<M/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H
M)'!K9RD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*")U;FEN<W1A;&P@;VLZ("1P
M:V<B+"`D8V]M;6%N9"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)V]F9FQI;F4G72D@)B8@:7-?
M;V)J96-T*"1S879E<&MG*2`F)@T*("`@("`@("`@("`@("`@("`@("`@(&1E
M9FEN960H)U!%05)?4D5-3U1%24Y35$%,3%]/2R<I*2![#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@D=&AI<RT^8V]N9FEG+3YI<T1E9FEN961,87EE<B@G
M9G1P)RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YI;G-T
M86QL97(M/G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O(#T@)'1H:7,M/FEN<W1A
M;&QE<BT^9G1P56YI;G-T86QL*"1S879E<&MG*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YI;G-T86QL97(M/G!O<$5R<F]R2&%N9&QI;F<H
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1I;F9O*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YU:2T^;W5T<'5T1&%T82@D:6YF;RT^9V5T365S<V%G92@I*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H
M(G)E;6]T92!U;FEN<W1A;&P@9F%I;&5D.B`D<&MG(BD[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@B<F5M;W1E('5N:6YS=&%L
M;"!O:SH@)'!K9R(I.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^:6YS=&%L
M;&5R+3YP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("`@("`@:68@
M*&ES7V]B:F5C="@D<&MG*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<&MG
M(#T@)')E9RT^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@D<&MG*3L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*")U;FEN<W1A;&P@9F%I;&5D.B`D<&MG(BD[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@?0T*#0H@("`@+R\@?7U]#0H-"@T*("`@("\O('U]?0T*("`@("\O('M[
M>R!D;T)U;F1L92@I#0H@("`@+RH-"B`@("`H8V]X*2!)="!J=7-T(&1O=VYL
M;V%D<R!A;F0@=6YT87)S('1H92!P86-K86=E+"!D;V5S(&YO="!D;PT*("`@
M("`@("`@("`@86YY(&-H96-K('1H870@=&AE(%!%05)?26YS=&%L;&5R.CI?
M:6YS=&%L;$9I;&4H*2!D;V5S+@T*("`@("HO#0H-"B`@("!F=6YC=&EO;B!D
M;T)U;F1L92@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*
M("`@("`@("`D9&]W;FQO861E<B`]("8D=&AI<RT^9V5T1&]W;FQO861E<B@D
M=&AI<RT^=6DL(&%R<F%Y*"=F;W)C92<@/3X@=')U92P@)VYO9&5P<R<@/3X@
M=')U92P-"B`@("`@("`@("`@("=S;V9T)R`]/B!T<G5E*2P@)'1H:7,M/F-O
M;F9I9RD[#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G
M:7-T<GDH*3L-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`\(#$I('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B4&QE87-E
M('-U<'!L>2!T:&4@<&%C:V%G92!Y;W4@=V%N="!T;R!B=6YD;&4B*3L-"B`@
M("`@("`@?0T*#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG9&5S=&EN
M871I;VXG72DI('L-"B`@("`@("`@("`@(&EF("@A:7-?9&ER*"1O<'1I;VYS
M6R=D97-T:6YA=&EO;B==*2D@>PT*("`@("`@("`@("`@("`@(%-Y<W1E;3HZ
M;6MD:7(H)RUP("<@+B`D;W!T:6]N<ULG9&5S=&EN871I;VXG72D[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D9&5S="`](')E86QP871H*"1O<'1I
M;VYS6R=D97-T:6YA=&EO;B==*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1P=V0@/2!G971C=V0H*3L-"B`@("`@("`@("`@(&EF("AI<U]D
M:7(H)'!W9"`N($1)4D5#5$]265]315!!4D%43U(@+B`G97AT)RDI('L-"B`@
M("`@("`@("`@("`@("`D9&5S="`]("1P=V0@+B!$25)%0U1/4EE?4T5005)!
M5$]2("X@)V5X="<[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("1D97-T(#T@)'!W9#L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("`D9&]W;FQO861E<BT^<V5T1&]W;FQO861$:7(H)&1E<W0I
M.PT*("`@("`@("`D<F5S=6QT(#T@)B1D;W=N;&]A9&5R+3YD;W=N;&]A9"AA
M<G)A>2@D<&%R86US6S!=*2D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1R97-U;'0I*2![#0H@("`@("`@("`@("!R971U<FX@)')E<W5L=#L-"B`@
M("`@("`@?0T*("`@("`@("`D<&MG9FEL92`]("8D<F5S=6QT6S!=+3YG9710
M86-K86=E1FEL92@I.PT*("`@("`@("`D<&MG;F%M92`]("1P:V=F:6QE+3YG
M971.86UE*"D[#0H@("`@("`@("1P:V=V97)S:6]N(#T@)'!K9V9I;&4M/F=E
M=%9E<G-I;VXH*3L-"@T*("`@("`@("`O+R!5;G!A8VMI;F<@+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0T*("`@
M("`@("`D9&5S="`N/2!$25)%0U1/4EE?4T5005)!5$]2("X@)'!K9VYA;64[
M#0H@("`@("`@("1O<FEG(#T@)'!K9VYA;64@+B`G+2<@+B`D<&MG=F5R<VEO
M;CL-"@T*("`@("`@("`D=&%R(#T@)FYE=R!!<F-H:79E7U1A<B@D<&MG9FEL
M92T^9V5T07)C:&EV949I;&4H*2D[#0H@("`@("`@(&EF("@A0"1T87(M/F5X
M=')A8W1-;V1I9GDH)&1E<W0L("1O<FEG*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*"=U;F%B;&4@=&\@=6YP86-K("<@+B`D
M<&MG9FEL92T^9V5T07)C:&EV949I;&4H*2D[#0H@("`@("`@('T-"B`@("`@
M("`@)'1H:7,M/G5I+3YO=71P=71$871A*")086-K86=E(')E861Y(&%T("<D
M9&5S="<B*3L-"B`@("`O+R!]?7T-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*
M("`@(&9U;F-T:6]N(&1O4G5N4V-R:7!T<R@D8V]M;6%N9"P@)&]P=&EO;G,L
M("1P87)A;7,I#0H@("`@>PT*("`@("`@("!I9B`H(6ES<V5T*"1P87)A;7-;
M,%TI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M)W)U;BUS8W)I<'1S(&5X<&5C=',@,2!P87)A;65T97(Z(&$@<&%C:V%G92!N
M86UE)RD[#0H@("`@("`@('T-"B`@("`@("`@)')E9R`]("8D=&AI<RT^8V]N
M9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("!014%2.CIS=&%T:6-0=7-H
M17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("1P
M87)S960@/2`D<F5G+3YP87)S95!A8VMA9V5.86UE*"1P87)A;7-;,%TL("1T
M:&ES+3YC;VYF:6<M/F=E="@G9&5F875L=%]C:&%N;F5L)RDI.PT*("`@("`@
M("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1P87)S960I*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)'!A<G-E9"D[#0H@("`@("`@('T-"B`@
M("`@("`@)'!A8VMA9V4@/2`F)')E9RT^9V5T4&%C:V%G92@D<&%R<V5D6R=P
M86-K86=E)UTL("1P87)S961;)V-H86YN96PG72D[#0H@("`@("`@(&EF("AI
M<U]O8FIE8W0H)'!A8VMA9V4I*2![#0H@("`@("`@("`@("`D<&%C:V%G92T^
M<V5T0V]N9FEG*"1T:&ES+3YC;VYF:6<I.PT*("`@("`@("`@("`@)'!A8VMA
M9V4M/G)U;E!O<W1I;G-T86QL4V-R:7!T<R@I.PT*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#;W5L
M9"!N;W0@<F5T<FEE=F4@<&%C:V%G92`B)R`N("1P87)A;7-;,%T@+B`G(B!F
M<F]M(')E9VES=')Y)RD[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/G5I
M+3YO=71P=71$871A*"=);G-T86QL('-C<FEP=',@8V]M<&QE=&4G+"`D8V]M
M;6%N9"D[#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"GT-"C\^#0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM
M86YD+TEN<W1A;&PN>&UL````````````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,3<V,#0`,3`U,34T,S,W-#``,#(S,#0V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#QC;VUM86YD<R!V97)S:6]N/2(Q+C`B
M/@T*(#QI;G-T86QL/@T*("`\<W5M;6%R>3Y);G-T86QL(%!A8VMA9V4\+W-U
M;6UA<GD^#0H@(#QF=6YC=&EO;CYD;TEN<W1A;&P\+V9U;F-T:6]N/@T*("`\
M<VAO<G1C=70^:3PO<VAO<G1C=70^#0H@(#QO<'1I;VYS/@T*("`@/&9O<F-E
M/@T*("`@(#QS:&]R=&]P=#YF/"]S:&]R=&]P=#X-"B`@("`\9&]C/G=I;&P@
M;W9E<G=R:71E(&YE=V5R(&EN<W1A;&QE9"!P86-K86=E<SPO9&]C/@T*("`@
M/"]F;W)C93X-"B`@(#QL;V]S93X-"B`@("`\<VAO<G1O<'0^;#PO<VAO<G1O
M<'0^#0H@("`@/&1O8SYD;R!N;W0@8VAE8VL@9F]R(')E8V]M;65N9&5D(&1E
M<&5N9&5N8WD@=F5R<VEO;CPO9&]C/@T*("`@/"]L;V]S93X-"B`@(#QN;V1E
M<',^#0H@("`@/'-H;W)T;W!T/FX\+W-H;W)T;W!T/@T*("`@(#QD;V,^:6=N
M;W)E(&1E<&5N9&5N8VEE<RP@:6YS=&%L;"!A;GEW87D\+V1O8SX-"B`@(#PO
M;F]D97!S/@T*("`@/')E9VES=&5R+6]N;'D^#0H@("`@/'-H;W)T;W!T/G(\
M+W-H;W)T;W!T/@T*("`@(#QD;V,^9&\@;F]T(&EN<W1A;&P@9FEL97,L(&]N
M;'D@<F5G:7-T97(@=&AE('!A8VMA9V4@87,@:6YS=&%L;&5D/"]D;V,^#0H@
M("`\+W)E9VES=&5R+6]N;'D^#0H@("`\<V]F=#X-"B`@("`\<VAO<G1O<'0^
M<SPO<VAO<G1O<'0^#0H@("`@/&1O8SYS;V9T(&EN<W1A;&PL(&9A:6P@<VEL
M96YT;'DL(&]R('5P9W)A9&4@:68@86QR96%D>2!I;G-T86QL960\+V1O8SX-
M"B`@(#PO<V]F=#X-"B`@(#QN;V)U:6QD/@T*("`@(#QS:&]R=&]P=#Y"/"]S
M:&]R=&]P=#X-"B`@("`\9&]C/F1O;B9A<&]S.W0@8G5I;&0@0R!E>'1E;G-I
M;VYS/"]D;V,^#0H@("`\+VYO8G5I;&0^#0H@("`\;F]C;VUP<F5S<SX-"B`@
M("`\<VAO<G1O<'0^6CPO<VAO<G1O<'0^#0H@("`@/&1O8SYR97%U97-T('5N
M8V]M<')E<W-E9"!F:6QE<R!W:&5N(&1O=VYL;V%D:6YG/"]D;V,^#0H@("`\
M+VYO8V]M<')E<W,^#0H@("`\:6YS=&%L;')O;W0^#0H@("`@/'-H;W)T;W!T
M/E(\+W-H;W)T;W!T/@T*("`@(#QA<F<^1$E2/"]A<F<^#0H@("`@/&1O8SYR
M;V]T(&1I<F5C=&]R>2!U<V5D('=H96X@:6YS=&%L;&EN9R!F:6QE<R`H86QA
M(%!(4"9A<&]S.W,@24Y35$%,3%]23T]4*3PO9&]C/@T*("`@/"]I;G-T86QL
M<F]O=#X-"B`@(#QI9VYO<F4M97)R;W)S/@T*("`@(#QD;V,^9F]R8V4@:6YS
M=&%L;"!E=F5N(&EF('1H97)E('=E<F4@97)R;W)S/"]D;V,^#0H@("`\+VEG
M;F]R92UE<G)O<G,^#0H@("`\86QL9&5P<SX-"B`@("`\<VAO<G1O<'0^83PO
M<VAO<G1O<'0^#0H@("`@/&1O8SYI;G-T86QL(&%L;"!R97%U:7)E9"!A;F0@
M;W!T:6]N86P@9&5P96YD96YC:65S/"]D;V,^#0H@("`\+V%L;&1E<',^#0H@
M("`\;VYL>7)E<61E<',^#0H@("`@/'-H;W)T;W!T/F\\+W-H;W)T;W!T/@T*
M("`@(#QD;V,^:6YS=&%L;"!A;&P@<F5Q=6ER960@9&5P96YD96YC:65S/"]D
M;V,^#0H@("`\+V]N;'ER97%D97!S/@T*("`@/&]F9FQI;F4^#0H@("`@/'-H
M;W)T;W!T/D\\+W-H;W)T;W!T/@T*("`@(#QD;V,^9&\@;F]T(&%T=&5M<'0@
M=&\@9&]W;FQO860@86YY('5R;',@;W(@8V]N=&%C="!C:&%N;F5L<SPO9&]C
M/@T*("`@/"]O9F9L:6YE/@T*("`@/'!R971E;F0^#0H@("`@/'-H;W)T;W!T
M/G`\+W-H;W)T;W!T/@T*("`@(#QD;V,^3VYL>2!L:7-T('1H92!P86-K86=E
M<R!T:&%T('=O=6QD(&)E(&1O=VYL;V%D960\+V1O8SX-"B`@(#PO<')E=&5N
M9#X-"B`@/"]O<'1I;VYS/@T*("`\9&]C/EMC:&%N;F5L+UTF;'0[<&%C:V%G
M929G=#L@+BXN#0I);G-T86QL<R!O;F4@;W(@;6]R92!014%2('!A8VMA9V5S
M+B`@66]U(&-A;B!S<&5C:69Y(&$@<&%C:V%G92!T;PT*:6YS=&%L;"!I;B!F
M;W5R('=A>7,Z#0H-"B9Q=6]T.U!A8VMA9V4M,2XP+G1G>B9Q=6]T.R`Z(&EN
M<W1A;&QS(&9R;VT@82!L;V-A;"!F:6QE#0H-"B9Q=6]T.VAT='`Z+R]E>&%M
M<&QE+F-O;2]086-K86=E+3$N,"YT9WHF<75O=#L@.B!I;G-T86QL<R!F<F]M
M#0IA;GEW:&5R92!O;B!T:&4@;F5T+@T*#0HF<75O=#MP86-K86=E+GAM;"9Q
M=6]T.R`Z(&EN<W1A;&QS('1H92!P86-K86=E(&1E<V-R:6)E9"!I;@T*<&%C
M:V%G92YX;6PN("!5<V5F=6P@9F]R('1E<W1I;F<L(&]R(&9O<B!W<F%P<&EN
M9R!A(%!%05(@<&%C:V%G92!I;@T*86YO=&AE<B!P86-K86=E(&UA;F%G97(@
M<W5C:"!A<R!24$TN#0H-"B9Q=6]T.U!A8VMA9V5;+79E<G-I;VXO<W1A=&5=
M6RYT87)=)G%U;W0[(#H@<75E<FEE<R!Y;W5R(&1E9F%U;'0@8VAA;FYE;"9A
M<&]S.W,@<V5R=F5R#0HH>V-O;F9I9R!M87-T97)?<V5R=F5R?2D@86YD(&1O
M=VYL;V%D<R!T:&4@;F5W97-T('!A8VMA9V4@=VET:`T*=&AE('!R969E<G)E
M9"!Q=6%L:71Y+W-T871E("A[8V]N9FEG('!R969E<G)E9%]S=&%T97TI+@T*
M#0I4;R!R971R:65V92!086-K86=E('9E<G-I;VX@,2XQ+"!U<V4@)G%U;W0[
M4&%C:V%G92TQ+C$L)G%U;W0[('1O(')E=')I979E#0I086-K86=E('-T871E
M(&)E=&$L('5S92`F<75O=#M086-K86=E+6)E=&$N)G%U;W0[("!4;R!R971R
M:65V92!A;B!U;F-O;7!R97-S960-"F9I;&4L(&%P<&5N9"`N=&%R("AM86ME
M('-U<F4@=&AE<F4@:7,@;F\@9FEL92!B>2!T:&4@<V%M92!N86UE(&9I<G-T
M*0T*#0I4;R!D;W=N;&]A9"!A('!A8VMA9V4@9G)O;2!A;F]T:&5R(&-H86YN
M96PL('!R969I>"!W:71H('1H92!C:&%N;F5L(&YA;64@;&EK90T*)G%U;W0[
M8VAA;FYE;"]086-K86=E)G%U;W0[#0H-"DUO<F4@=&AA;B!O;F4@<&%C:V%G
M92!M87D@8F4@<W!E8VEF:65D(&%T(&]N8V4N("!)="!I<R!O:R!T;R!M:7@@
M=&AE<V4-"F9O=7(@=V%Y<R!O9B!S<&5C:69Y:6YG('!A8VMA9V5S+@T*/"]D
M;V,^#0H@/"]I;G-T86QL/@T*(#QU<&=R861E/@T*("`\<W5M;6%R>3Y5<&=R
M861E(%!A8VMA9V4\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;TEN<W1A;&P\
M+V9U;F-T:6]N/@T*("`\<VAO<G1C=70^=7`\+W-H;W)T8W5T/@T*("`\;W!T
M:6]N<SX-"B`@(#QF;W)C93X-"B`@("`\<VAO<G1O<'0^9CPO<VAO<G1O<'0^
M#0H@("`@/&1O8SYO=F5R=W)I=&4@;F5W97(@:6YS=&%L;&5D('!A8VMA9V5S
M/"]D;V,^#0H@("`\+V9O<F-E/@T*("`@/&QO;W-E/@T*("`@(#QS:&]R=&]P
M=#YL/"]S:&]R=&]P=#X-"B`@("`\9&]C/F1O(&YO="!C:&5C:R!F;W(@<F5C
M;VUM96YD960@9&5P96YD96YC>2!V97)S:6]N/"]D;V,^#0H@("`\+VQO;W-E
M/@T*("`@/&YO9&5P<SX-"B`@("`\<VAO<G1O<'0^;CPO<VAO<G1O<'0^#0H@
M("`@/&1O8SYI9VYO<F4@9&5P96YD96YC:65S+"!U<&=R861E(&%N>7=A>3PO
M9&]C/@T*("`@/"]N;V1E<',^#0H@("`\<F5G:7-T97(M;VYL>3X-"B`@("`\
M<VAO<G1O<'0^<CPO<VAO<G1O<'0^#0H@("`@/&1O8SYD;R!N;W0@:6YS=&%L
M;"!F:6QE<RP@;VYL>2!R96=I<W1E<B!T:&4@<&%C:V%G92!A<R!U<&=R861E
M9#PO9&]C/@T*("`@/"]R96=I<W1E<BUO;FQY/@T*("`@/&YO8G5I;&0^#0H@
M("`@/'-H;W)T;W!T/D(\+W-H;W)T;W!T/@T*("`@(#QD;V,^9&]N)F%P;W,[
M="!B=6EL9"!#(&5X=&5N<VEO;G,\+V1O8SX-"B`@(#PO;F]B=6EL9#X-"B`@
M(#QN;V-O;7!R97-S/@T*("`@(#QS:&]R=&]P=#Y:/"]S:&]R=&]P=#X-"B`@
M("`\9&]C/G)E<75E<W0@=6YC;VUP<F5S<V5D(&9I;&5S('=H96X@9&]W;FQO
M861I;F<\+V1O8SX-"B`@(#PO;F]C;VUP<F5S<SX-"B`@(#QI;G-T86QL<F]O
M=#X-"B`@("`\<VAO<G1O<'0^4CPO<VAO<G1O<'0^#0H@("`@/&%R9SY$25(\
M+V%R9SX-"B`@("`\9&]C/G)O;W0@9&ER96-T;W)Y('5S960@=VAE;B!I;G-T
M86QL:6YG(&9I;&5S("AA;&$@4$A0)F%P;W,[<R!)3E-404Q,7U)/3U0I/"]D
M;V,^#0H@("`\+VEN<W1A;&QR;V]T/@T*("`@/&EG;F]R92UE<G)O<G,^#0H@
M("`@/&1O8SYF;W)C92!I;G-T86QL(&5V96X@:68@=&AE<F4@=V5R92!E<G)O
M<G,\+V1O8SX-"B`@(#PO:6=N;W)E+65R<F]R<SX-"B`@(#QA;&QD97!S/@T*
M("`@(#QS:&]R=&]P=#YA/"]S:&]R=&]P=#X-"B`@("`\9&]C/FEN<W1A;&P@
M86QL(')E<75I<F5D(&%N9"!O<'1I;VYA;"!D97!E;F1E;F-I97,\+V1O8SX-
M"B`@(#PO86QL9&5P<SX-"B`@(#QO;FQY<F5Q9&5P<SX-"B`@("`\<VAO<G1O
M<'0^;SPO<VAO<G1O<'0^#0H@("`@/&1O8SYI;G-T86QL(&%L;"!R97%U:7)E
M9"!D97!E;F1E;F-I97,\+V1O8SX-"B`@(#PO;VYL>7)E<61E<',^#0H@("`\
M;V9F;&EN93X-"B`@("`\<VAO<G1O<'0^3SPO<VAO<G1O<'0^#0H@("`@/&1O
M8SYD;R!N;W0@871T96UP="!T;R!D;W=N;&]A9"!A;GD@=7)L<R!O<B!C;VYT
M86-T(&-H86YN96QS/"]D;V,^#0H@("`\+V]F9FQI;F4^#0H@("`\<')E=&5N
M9#X-"B`@("`\<VAO<G1O<'0^<#PO<VAO<G1O<'0^#0H@("`@/&1O8SY/;FQY
M(&QI<W0@=&AE('!A8VMA9V5S('1H870@=V]U;&0@8F4@9&]W;FQO861E9#PO
M9&]C/@T*("`@/"]P<F5T96YD/@T*("`\+V]P=&EO;G,^#0H@(#QD;V,^)FQT
M.W!A8VMA9V4F9W0[("XN+@T*57!G<F%D97,@;VYE(&]R(&UO<F4@4$5!4B!P
M86-K86=E<RX@(%-E92!D;V-U;65N=&%T:6]N(&9O<B!T:&4-"B9Q=6]T.VEN
M<W1A;&PF<75O=#L@8V]M;6%N9"!F;W(@=V%Y<R!T;R!S<&5C:69Y(&$@<&%C
M:V%G92X-"@T*5VAE;B!U<&=R861I;F<L('EO=7(@<&%C:V%G92!W:6QL(&)E
M('5P9&%T960@:68@=&AE('!R;W9I9&5D(&YE=PT*<&%C:V%G92!H87,@82!H
M:6=H97(@=F5R<VEO;B!N=6UB97(@*'5S92!T:&4@+68@;W!T:6]N(&EF('EO
M=2!N965D('1O#0IU<&=R861E(&%N>7=A>2DN#0H-"DUO<F4@=&AA;B!O;F4@
M<&%C:V%G92!M87D@8F4@<W!E8VEF:65D(&%T(&]N8V4N#0H\+V1O8SX-"B`\
M+W5P9W)A9&4^#0H@/'5P9W)A9&4M86QL/@T*("`\<W5M;6%R>3Y5<&=R861E
M($%L;"!086-K86=E<SPO<W5M;6%R>3X-"B`@/&9U;F-T:6]N/F1O26YS=&%L
M;#PO9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YU83PO<VAO<G1C=70^#0H@(#QO
M<'1I;VYS/@T*("`@/&YO9&5P<SX-"B`@("`\<VAO<G1O<'0^;CPO<VAO<G1O
M<'0^#0H@("`@/&1O8SYI9VYO<F4@9&5P96YD96YC:65S+"!U<&=R861E(&%N
M>7=A>3PO9&]C/@T*("`@/"]N;V1E<',^#0H@("`\<F5G:7-T97(M;VYL>3X-
M"B`@("`\<VAO<G1O<'0^<CPO<VAO<G1O<'0^#0H@("`@/&1O8SYD;R!N;W0@
M:6YS=&%L;"!F:6QE<RP@;VYL>2!R96=I<W1E<B!T:&4@<&%C:V%G92!A<R!U
M<&=R861E9#PO9&]C/@T*("`@/"]R96=I<W1E<BUO;FQY/@T*("`@/&YO8G5I
M;&0^#0H@("`@/'-H;W)T;W!T/D(\+W-H;W)T;W!T/@T*("`@(#QD;V,^9&]N
M)F%P;W,[="!B=6EL9"!#(&5X=&5N<VEO;G,\+V1O8SX-"B`@(#PO;F]B=6EL
M9#X-"B`@(#QN;V-O;7!R97-S/@T*("`@(#QS:&]R=&]P=#Y:/"]S:&]R=&]P
M=#X-"B`@("`\9&]C/G)E<75E<W0@=6YC;VUP<F5S<V5D(&9I;&5S('=H96X@
M9&]W;FQO861I;F<\+V1O8SX-"B`@(#PO;F]C;VUP<F5S<SX-"B`@(#QI;G-T
M86QL<F]O=#X-"B`@("`\<VAO<G1O<'0^4CPO<VAO<G1O<'0^#0H@("`@/&%R
M9SY$25(\+V%R9SX-"B`@("`\9&]C/G)O;W0@9&ER96-T;W)Y('5S960@=VAE
M;B!I;G-T86QL:6YG(&9I;&5S("AA;&$@4$A0)F%P;W,[<R!)3E-404Q,7U)/
M3U0I/"]D;V,^#0H@("`\+VEN<W1A;&QR;V]T/@T*("`@/&EG;F]R92UE<G)O
M<G,^#0H@("`@/&1O8SYF;W)C92!I;G-T86QL(&5V96X@:68@=&AE<F4@=V5R
M92!E<G)O<G,\+V1O8SX-"B`@(#PO:6=N;W)E+65R<F]R<SX-"B`@(#QL;V]S
M93X-"B`@("`\9&]C/F1O(&YO="!C:&5C:R!F;W(@<F5C;VUM96YD960@9&5P
M96YD96YC>2!V97)S:6]N/"]D;V,^#0H@("`\+VQO;W-E/@T*("`\+V]P=&EO
M;G,^#0H@(#QD;V,^#0I5<&=R861E<R!A;&P@<&%C:V%G97,@=&AA="!H879E
M(&$@;F5W97(@<F5L96%S92!A=F%I;&%B;&4N("!5<&=R861E<R!A<F4-"F1O
M;F4@;VYL>2!I9B!T:&5R92!I<R!A(')E;&5A<V4@879A:6QA8FQE(&]F('1H
M92!S=&%T92!S<&5C:69I960@:6X-"B9Q=6]T.W!R969E<G)E9%]S=&%T929Q
M=6]T.R`H8W5R<F5N=&QY('MC;VYF:6<@<')E9F5R<F5D7W-T871E?2DL(&]R
M(&$@<W1A=&4@8V]N<VED97)E9`T*;6]R92!S=&%B;&4N#0H\+V1O8SX-"B`\
M+W5P9W)A9&4M86QL/@T*(#QU;FEN<W1A;&P^#0H@(#QS=6UM87)Y/E5N+6EN
M<W1A;&P@4&%C:V%G93PO<W5M;6%R>3X-"B`@/&9U;F-T:6]N/F1O56YI;G-T
M86QL/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/G5N/"]S:&]R=&-U=#X-"B`@
M/&]P=&EO;G,^#0H@("`\;F]D97!S/@T*("`@(#QS:&]R=&]P=#YN/"]S:&]R
M=&]P=#X-"B`@("`\9&]C/FEG;F]R92!D97!E;F1E;F-I97,L('5N:6YS=&%L
M;"!A;GEW87D\+V1O8SX-"B`@(#PO;F]D97!S/@T*("`@/')E9VES=&5R+6]N
M;'D^#0H@("`@/'-H;W)T;W!T/G(\+W-H;W)T;W!T/@T*("`@(#QD;V,^9&\@
M;F]T(')E;6]V92!F:6QE<RP@;VYL>2!R96=I<W1E<B!T:&4@<&%C:V%G97,@
M87,@;F]T(&EN<W1A;&QE9#PO9&]C/@T*("`@/"]R96=I<W1E<BUO;FQY/@T*
M("`@/&EN<W1A;&QR;V]T/@T*("`@(#QS:&]R=&]P=#Y2/"]S:&]R=&]P=#X-
M"B`@("`\87)G/D1)4CPO87)G/@T*("`@(#QD;V,^<F]O="!D:7)E8W1O<GD@
M=7-E9"!W:&5N(&EN<W1A;&QI;F<@9FEL97,@*&%L82!02%`F87!O<SMS($E.
M4U1!3$Q?4D]/5"D\+V1O8SX-"B`@(#PO:6YS=&%L;')O;W0^#0H@("`\:6=N
M;W)E+65R<F]R<SX-"B`@("`\9&]C/F9O<F-E(&EN<W1A;&P@979E;B!I9B!T
M:&5R92!W97)E(&5R<F]R<SPO9&]C/@T*("`@/"]I9VYO<F4M97)R;W)S/@T*
M("`@/&]F9FQI;F4^#0H@("`@/'-H;W)T;W!T/D\\+W-H;W)T;W!T/@T*("`@
M(#QD;V,^9&\@;F]T(&%T=&5M<'0@=&\@=6YI;G-T86QL(')E;6]T96QY/"]D
M;V,^#0H@("`\+V]F9FQI;F4^#0H@(#PO;W!T:6]N<SX-"B`@/&1O8SY;8VAA
M;FYE;"]=)FQT.W!A8VMA9V4F9W0[("XN+@T*56YI;G-T86QL<R!O;F4@;W(@
M;6]R92!014%2('!A8VMA9V5S+B`@36]R92!T:&%N(&]N92!P86-K86=E(&UA
M>2!B90T*<W!E8VEF:65D(&%T(&]N8V4N("!0<F5F:7@@=VET:"!C:&%N;F5L
M(&YA;64@=&\@=6YI;G-T86QL(&9R;VT@80T*8VAA;FYE;"!N;W0@:6X@>6]U
M<B!D969A=6QT(&-H86YN96P@*'MC;VYF:6<@9&5F875L=%]C:&%N;F5L?2D-
M"CPO9&]C/@T*(#PO=6YI;G-T86QL/@T*(#QB=6YD;&4^#0H@(#QS=6UM87)Y
M/E5N<&%C:W,@82!096-L(%!A8VMA9V4\+W-U;6UA<GD^#0H@(#QF=6YC=&EO
M;CYD;T)U;F1L93PO9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YB=6X\+W-H;W)T
M8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QD97-T:6YA=&EO;CX-"B`@("`\<VAO
M<G1O<'0^9#PO<VAO<G1O<'0^#0H@("`@/&%R9SY$25(\+V%R9SX-"B`@("`\
M9&]C/D]P=&EO;F%L(&1E<W1I;F%T:6]N(&1I<F5C=&]R>2!F;W(@=6YP86-K
M:6YG("AD969A=6QT<R!T;R!C=7)R96YT('!A=&@@;W(@)G%U;W0[97AT)G%U
M;W0[(&EF(&5X:7-T<RD\+V1O8SX-"B`@(#PO9&5S=&EN871I;VX^#0H@("`\
M9F]R8V4^#0H@("`@/'-H;W)T;W!T/F8\+W-H;W)T;W!T/@T*("`@(#QD;V,^
M1F]R8V4@=&AE('5N<&%C:VEN9R!E=F5N(&EF('1H97)E('=E<F4@97)R;W)S
M(&EN('1H92!P86-K86=E/"]D;V,^#0H@("`\+V9O<F-E/@T*("`\+V]P=&EO
M;G,^#0H@(#QD;V,^)FQT.W!A8VMA9V4F9W0[#0I5;G!A8VMS(&$@4&5C;"!0
M86-K86=E(&EN=&\@=&AE('-E;&5C=&5D(&QO8V%T:6]N+B!)="!W:6QL(&1O
M=VYL;V%D('1H90T*<&%C:V%G92!I9B!N965D960N#0H\+V1O8SX-"B`\+V)U
M;F1L93X-"B`\<G5N+7-C<FEP=',^#0H@(#QS=6UM87)Y/E)U;B!0;W-T+4EN
M<W1A;&P@4V-R:7!T<R!B=6YD;&5D('=I=&@@82!P86-K86=E/"]S=6UM87)Y
M/@T*("`\9G5N8W1I;VX^9&]2=6Y38W)I<'1S/"]F=6YC=&EO;CX-"B`@/'-H
M;W)T8W5T/G)S/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,@+SX-"B`@/&1O8SXF
M;'0[<&%C:V%G929G=#L-"E)U;B!P;W-T+6EN<W1A;&QA=&EO;B!S8W)I<'1S
M(&EN('!A8VMA9V4@)FQT.W!A8VMA9V4F9W0[+"!I9B!A;GD@97AI<W0N#0H\
M+V1O8SX-"B`\+W)U;BUS8W)I<'1S/@T*/"]C;VUM86YD<SX`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+U!%05(O0V]M;6%N9"]-:7)R;W(N<&AP````````````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#$R-#4R`#$P-3$U-#,S-S0P`#`R,C8W-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`T*+RHJ#0H@*B!014%27T-O;6UA;F1?36ER<F]R("AD;W=N;&]A9"UA;&P@
M8V]M;6%N9"D-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J
M($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S
M:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA
M8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I
M;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@
M4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E
M0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!0
M14%2#0H@*B!`875T:&]R("`@("!!;&5X86YD97(@365R>B`\86QE>&UE<GI`
M<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R
M;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-6
M4SH@)$ED.B!-:7)R;W(N<&AP+'8@,2XQ."`R,#`V+S`S+S`R(#$X.C$T.C$S
M(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA
M8FQE('-I;F-E(%)E;&5A<V4@,2XR+C`-"B`J+PT*#0HO*BH-"B`J(&)A<V4@
M8VQA<W,-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+T-O;6UA;F0O0V]M;6]N
M+G!H<"<[#0H-"B\J*@T*("H@4$5!4B!C;VUM86YD<R!F;W(@<')O=FED:6YG
M(&9I;&4@;6ER<F]R<PT*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P
M86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($%L97AA;F1E<B!-97)Z
M(#QA;&5X;65R>D!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V
M(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E
M<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#
M;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C(N,`T*("HO#0IC;&%S
M<R!014%27T-O;6UA;F1?36ER<F]R(&5X=&5N9',@4$5!4E]#;VUM86YD7T-O
M;6UO;@T*>PT*("`@("\O('M[>R!P<F]P97)T:65S#0H-"B`@("!V87(@)&-O
M;6UA;F1S(#T@87)R87DH#0H@("`@("`@("=D;W=N;&]A9"UA;&PG(#T^(&%R
M<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=$;W=N;&]A9',@96%C
M:"!A=F%I;&%B;&4@<&%C:V%G92!F<F]M('1H92!D969A=6QT(&-H86YN96PG
M+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]$;W=N;&]A9$%L;"<L
M#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=D82<L#0H@("`@("`@("`@
M("`G;W!T:6]N<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@)V-H86YN
M96PG(#T^#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=C)RP-"B`@("`@("`@("`@("`@
M("`@("`@)V1O8R<@/3X@)W-P96-I9GD@82!C:&%N;F5L(&]T:&5R('1H86X@
M=&AE(&1E9F%U;'0@8VAA;FYE;"<L#0H@("`@("`@("`@("`@("`@("`@("=A
M<F<G(#T^("=#2$%.)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@
M("`@("`@("`@("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)PT*4F5Q=65S
M=',@82!L:7-T(&]F(&%V86EL86)L92!P86-K86=E<R!F<F]M('1H92!D969A
M=6QT(&-H86YN96P@*'MC;VYF:6<@9&5F875L=%]C:&%N;F5L?2D-"F%N9"!D
M;W=N;&]A9',@=&AE;2!T;R!C=7)R96YT('=O<FMI;F<@9&ER96-T;W)Y+B`@
M3F]T93H@;VYL>0T*<&%C:V%G97,@=VET:&EN('!R969E<G)E9%]S=&%T92`H
M>V-O;F9I9R!P<F5F97)R961?<W1A=&5]*2!W:6QL(&)E(&1O=VYL;V%D960G
M#0H@("`@("`@("`@("`I+`T*("`@("`@("`I.PT*#0H@("`@+R\@?7U]#0H-
M"B`@("`O+R![>WL@8V]N<W1R=6-T;W(-"@T*("`@("\J*@T*("`@("`J(%!%
M05)?0V]M;6%N9%]-:7)R;W(@8V]N<W1R=6-T;W(N#0H@("`@("H-"B`@("`@
M*B!`86-C97-S('!U8FQI8PT*("`@("`J($!P87)A;2!O8FIE8W0@4$5!4E]&
M<F]N=&5N9"!A(')E9F5R96YC92!T;R!A;B!F<F]N=&5N9`T*("`@("`J($!P
M87)A;2!O8FIE8W0@4$5!4E]#;VYF:6<@82!R969E<F5N8V4@=&\@=&AE(&-O
M;F9I9W5R871I;VX@9&%T80T*("`@("`J+PT*("`@(&9U;F-T:6]N(%!%05)?
M0V]M;6%N9%]-:7)R;W(H)B1U:2P@)B1C;VYF:6<I#0H@("`@>PT*("`@("`@
M("!P87)E;G0Z.E!%05)?0V]M;6%N9%]#;VUM;VXH)'5I+"`D8V]N9FEG*3L-
M"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*("`@("\J*@T*("`@("`J($9O<B!U
M;FET+71E<W1I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D
M82D-"B`@("![#0H@("`@("`@("1A(#T@)E!%05)?0V]M;6%N9#HZ9F%C=&]R
M>2@D82P@)'1H:7,M/F-O;F9I9RD[#0H@("`@("`@(')E='5R;B`D83L-"B`@
M("!]#0H-"B`@("`O+R![>WL@9&]$;W=N;&]A9$%L;"@I#0H@("`@+RHJ#0H@
M("`@*B!R971R:65V97,@82!L:7-T(&]F(&%V86EB;&4@4&%C:V%G97,@9G)O
M;2!M87-T97(@<V5R=F5R#0H@("`@*B!A;F0@9&]W;FQO861S('1H96T-"B`@
M("`J#0H@("`@*B!`86-C97-S('!U8FQI8PT*("`@("H@0'!A<F%M('-T<FEN
M9R`D8V]M;6%N9"!T:&4@8V]M;6%N9`T*("`@("H@0'!A<F%M(&%R<F%Y("1O
M<'1I;VYS('1H92!C;VUM86YD(&]P=&EO;G,@8F5F;W)E('1H92!C;VUM86YD
M#0H@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R!T:&4@<W1U9F8@869T97(@
M=&AE(&-O;6UA;F0@;F%M90T*("`@("H@0')E='5R;B!B;V]L('1R=64@:68@
M<W5C8V5S9G5L#0H@("`@*B!`=&AR;W<@4$5!4E]%<G)O<B`-"B`@("`J+PT*
M("`@(&9U;F-T:6]N(&1O1&]W;FQO861!;&PH)&-O;6UA;F0L("1O<'1I;VYS
M+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@)'-A=F5C:&%N;F5L(#T@)'1H
M:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*3L-"B`@("`@("`@
M)')E9R`]("8D=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@
M("`D8VAA;FYE;"`](&ES<V5T*"1O<'1I;VYS6R=C:&%N;F5L)UTI(#\@)&]P
M=&EO;G-;)V-H86YN96PG72`Z#0H@("`@("`@("`@("`D=&AI<RT^8V]N9FEG
M+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I.PT*("`@("`@("!I9B`H(21R96<M
M/F-H86YN96Q%>&ES=',H)&-H86YN96PI*2![#0H@("`@("`@("`@("`D=&AI
M<RT^8V]N9FEG+3YS970H)V1E9F%U;'1?8VAA;FYE;"<L("1S879E8VAA;FYE
M;"D[#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-H
M86YN96P@(B<@+B`D8VAA;FYE;"`N("<B(&1O97,@;F]T(&5X:7-T)RD[#0H@
M("`@("`@('T-"B`@("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T*"=D969A=6QT
M7V-H86YN96PG+"`D8VAA;FYE;"D[#0H@("`@("`@("1T:&ES+3YU:2T^;W5T
M<'5T1&%T82@G57-I;F<@0VAA;FYE;"`G("X@)'1H:7,M/F-O;F9I9RT^9V5T
M*"=D969A=6QT7V-H86YN96PG*2D[#0H@("`@("`@("1C:&%N(#T@)')E9RT^
M9V5T0VAA;FYE;"@D8VAA;FYE;"D[#0H@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1C:&%N*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"1C:&%N*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&-H86XM
M/G-U<'!O<G1S4D535"@D=&AI<RT^8V]N9FEG+3YG970H)W!R969E<G)E9%]M
M:7)R;W(G*2D@)B8-"B`@("`@("`@("`@("`@)&)A<V4@/2`D8VAA;BT^9V5T
M0F%S95523"@G4D535#$N,"<L("1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R
M<F5D7VUI<G)O<B<I*2D@>PT*("`@("`@("`@("`@)')E<W0@/2`F)'1H:7,M
M/F-O;F9I9RT^9V5T4D535"@G,2XP)RP@87)R87DH*2D[#0H@("`@("`@("`@
M("`D<F5M;W1E26YF;R`](&%R<F%Y7V9L:7`H)')E<W0M/FQI<W1086-K86=E
M<R@D8F%S92DI.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)')E
M;6]T92`]("8D=&AI<RT^8V]N9FEG+3YG971296UO=&4H*3L-"B`@("`@("`@
M("`@("1S=&%B;&4@/2`H)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?
M<W1A=&4G*2`]/2`G<W1A8FQE)RD[#0H@("`@("`@("`@("`D<F5M;W1E26YF
M;R`]("1R96UO=&4M/F-A;&PH(G!A8VMA9V4N;&ES=$%L;"(L('1R=64L("1S
M=&%B;&4L(&9A;'-E*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D<F5M;W1E26YF;RDI('L-"B`@("`@("`@("`@(')E='5R;B`D
M<F5M;W1E26YF;SL-"B`@("`@("`@?0T*("`@("`@("`D8VUD(#T@)B1T:&ES
M+3YF86-T;W)Y*")D;W=N;&]A9"(I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D8VUD*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1C;60[#0H@("`@
M("`@('T-"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"=5<VEN9R!0
M<F5F97)R960@4W1A=&4@;V8@)R`N#0H@("`@("`@("`@("`D=&AI<RT^8V]N
M9FEG+3YG970H)W!R969E<G)E9%]S=&%T92<I*3L-"B`@("`@("`@)'1H:7,M
M/G5I+3YO=71P=71$871A*"='871H97)I;F<@<F5L96%S92!I;F9O<FUA=&EO
M;BP@<&QE87-E('=A:70N+BXG*3L-"B`@("`@("`@+RHJ#0H@("`@("`@("`J
M($5R<F]R(&AA;F1L:6YG(&YO="!N96-E<W-A<GDL(&)E8V%U<V4@86QR96%D
M>2!D;VYE(&)Y(`T*("`@("`@("`@*B!T:&4@9&]W;FQO860@8V]M;6%N9`T*
M("`@("`@("`@*B\-"B`@("`@("`@4$5!4CHZ<W1A=&EC4'5S:$5R<F]R2&%N
M9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`D97)R(#T@)&-M
M9"T^<G5N*"=D;W=N;&]A9"<L(&%R<F%Y*"=D;W=N;&]A9&]N;'DG(#T^('1R
M=64I+"!A<G)A>5]K97ES*"1R96UO=&5);F9O*2D[#0H@("`@("`@(%!%05(Z
M.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@)'1H:7,M/F-O
M;F9I9RT^<V5T*"=D969A=6QT7V-H86YN96PG+"`D<V%V96-H86YN96PI.PT*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R*2D@>PT*("`@("`@("`@
M("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1E<G(M/F=E=$UE<W-A9V4H*2D[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0I]#0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N
M9"]-:7)R;W(N>&UL````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q
M,3<R`#$P-3$U-#,S-S0P`#`R,C<P,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\8V]M;6%N9',@=F5R<VEO;CTB,2XP(CX-
M"B`\9&]W;FQO860M86QL/@T*("`\<W5M;6%R>3Y$;W=N;&]A9',@96%C:"!A
M=F%I;&%B;&4@<&%C:V%G92!F<F]M('1H92!D969A=6QT(&-H86YN96P\+W-U
M;6UA<GD^#0H@(#QF=6YC=&EO;CYD;T1O=VYL;V%D06QL/"]F=6YC=&EO;CX-
M"B`@/'-H;W)T8W5T/F1A/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,^#0H@("`\
M8VAA;FYE;#X-"B`@("`\<VAO<G1O<'0^8SPO<VAO<G1O<'0^#0H@("`@/&1O
M8SYS<&5C:69Y(&$@8VAA;FYE;"!O=&AE<B!T:&%N('1H92!D969A=6QT(&-H
M86YN96P\+V1O8SX-"B`@("`\87)G/D-(04X\+V%R9SX-"B`@(#PO8VAA;FYE
M;#X-"B`@/"]O<'1I;VYS/@T*("`\9&]C/@T*4F5Q=65S=',@82!L:7-T(&]F
M(&%V86EL86)L92!P86-K86=E<R!F<F]M('1H92!D969A=6QT(&-H86YN96P@
M*'MC;VYF:6<@9&5F875L=%]C:&%N;F5L?2D-"F%N9"!D;W=N;&]A9',@=&AE
M;2!T;R!C=7)R96YT('=O<FMI;F<@9&ER96-T;W)Y+B`@3F]T93H@;VYL>0T*
M<&%C:V%G97,@=VET:&EN('!R969E<G)E9%]S=&%T92`H>V-O;F9I9R!P<F5F
M97)R961?<W1A=&5]*2!W:6QL(&)E(&1O=VYL;V%D960\+V1O8SX-"B`\+V1O
M=VYL;V%D+6%L;#X-"CPO8V]M;6%N9',^````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O
M0V]M;6%N9"]086-K86=E+G!H<```````````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,3,W,#0W`#$P-3$U-#,S-S0P`#`R,C<V-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`T*+RHJ#0H@*B!014%2
M7T-O;6UA;F1?4&%C:V%G92`H<&%C:V%G92P@<&%C:V%G92UV86QI9&%T92P@
M8W9S9&EF9BP@8W9S=&%G+"!P86-K86=E+61E<&5N9&5N8VEE<RP-"B`J('-I
M9VXL(&UA:V5R<&TL(&-O;G9E<G0@8V]M;6%N9',I#0H@*@T*("H@4$A0('9E
M<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F
M:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E
M;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@
M<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL
M('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@
M<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I
M9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@36%R=&EN
M($IA;G-E;B`\;6I`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@($=R96<@0F5A
M=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P
M-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V
M97)S:6]N("`@($-64SH@)$ED.B!086-K86=E+G!H<"QV(#$N,3$Y(#(P,#8O
M,#,O,#(@,3@Z,30Z,3,@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@
M("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*#0HO
M*BH-"B`J(&)A<V4@8VQA<W,-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+T-O
M;6UA;F0O0V]M;6]N+G!H<"<[#0H-"B\J*@T*("H@4$5!4B!C;VUM86YD<R!F
M;W(@;&]G:6XO;&]G;W5T#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@
M0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@
M/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@36%R=&EN($IA;G-E;B`\
M;6I`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL
M;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0
M($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@
M(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A
M:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"@T*8VQA<W,@4$5!4E]#
M;VUM86YD7U!A8VMA9V4@97AT96YD<R!014%27T-O;6UA;F1?0V]M;6]N#0I[
M#0H@("`@+R\@>WM[('!R;W!E<G1I97,-"@T*("`@('9A<B`D8V]M;6%N9',@
M/2!A<G)A>2@-"B`@("`@("`@)W!A8VMA9V4G(#T^(&%R<F%Y*`T*("`@("`@
M("`@("`@)W-U;6UA<GDG(#T^("="=6EL9"!086-K86=E)RP-"B`@("`@("`@
M("`@("=F=6YC=&EO;B<@/3X@)V1O4&%C:V%G92<L#0H@("`@("`@("`@("`G
M<VAO<G1C=70G(#T^("=P)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`G;F]C;VUP<F5S<R<@/3X@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)UHG+`T*("`@
M("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G1&\@;F]T(&=Z:7`@=&AE('!A
M8VMA9V4@9FEL92<-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@
M("`@("`@("`G<VAO=VYA;64G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@
M("`@("`G<VAO<G1O<'0G(#T^("=N)RP-"B`@("`@("`@("`@("`@("`@("`@
M)V1O8R<@/3X@)U!R:6YT('1H92!N86UE(&]F('1H92!P86-K86=E9"!F:6QE
M+B<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@
M*2P-"B`@("`@("`@("`@("=D;V,G(#T^("=;9&5S8V9I;&5=(%MD97-C9FEL
M93)=#0I#<F5A=&5S(&$@4$5!4B!P86-K86=E(&9R;VT@:71S(&1E<V-R:7!T
M:6]N(&9I;&4@*'5S=6%L;'D@8V%L;&5D#0IP86-K86=E+GAM;"DN("!)9B!A
M('-E8V]N9"!P86-K86=E9FEL92!I<R!P87-S960@:6XL('1H96X-"G1H92!P
M86-K86=E<B!W:6QL(&-H96-K('1O(&UA:V4@<W5R92!T:&%T(&]N92!I<R!A
M('!A8VMA9V4N>&UL#0IV97)S:6]N(#$N,"P@86YD('1H92!O=&AE<B!I<R!A
M('!A8VMA9V4N>&UL('9E<G-I;VX@,BXP+B`@5&AE#0IP86-K86=E+GAM;"!V
M97)S:6]N(#$N,"!W:6QL(&)E('-A=F5D(&%S(")P86-K86=E+GAM;"(@:6X@
M=&AE(&%R8VAI=F4L#0IA;F0@=&AE(&]T:&5R(&%S(")P86-K86=E,BYX;6PB
M(&EN('1H92!A<F-H:79E(@T*)PT*("`@("`@("`@("`@*2P-"B`@("`@("`@
M)W!A8VMA9V4M=F%L:61A=&4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U
M;6UA<GDG(#T^("=686QI9&%T92!086-K86=E($-O;G-I<W1E;F-Y)RP-"B`@
M("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O4&%C:V%G959A;&ED871E)RP-
M"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)W!V)RP-"B`@("`@("`@("`@
M("=O<'1I;VYS)R`]/B!A<G)A>2@I+`T*("`@("`@("`@("`@)V1O8R<@/3X@
M)PT*)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@("=C=G-D:69F)R`]/B!A
M<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G4G5N(&$@(F-V<R!D
M:69F(B!F;W(@86QL(&9I;&5S(&EN(&$@<&%C:V%G92<L#0H@("`@("`@("`@
M("`G9G5N8W1I;VXG(#T^("=D;T-V<T1I9F8G+`T*("`@("`@("`@("`@)W-H
M;W)T8W5T)R`]/B`G8V0G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("=Q=6EE="<@/3X@87)R87DH#0H@("`@
M("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)W$G+`T*("`@("`@("`@
M("`@("`@("`@("`G9&]C)R`]/B`G0F4@<75I970G+`T*("`@("`@("`@("`@
M("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=R96%L;'EQ=6EE="<@/3X@
M87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)U$G
M+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G0F4@<F5A;&QY('%U
M:65T)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@
M("`G9&%T92<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R
M=&]P="<@/3X@)T0G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G
M1&EF9B!A9V%I;G-T(')E=FES:6]N(&]F($1!5$4G+`T*("`@("`@("`@("`@
M("`@("`@("`G87)G)R`]/B`G1$%412<L#0H@("`@("`@("`@("`@("`@("`@
M("DL#0H@("`@("`@("`@("`@("`@)W)E;&5A<V4G(#T^(&%R<F%Y*`T*("`@
M("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=2)RP-"B`@("`@("`@
M("`@("`@("`@("`@)V1O8R<@/3X@)T1I9F8@86=A:6YS="!T86<@9F]R('!A
M8VMA9V4@<F5L96%S92!214PG+`T*("`@("`@("`@("`@("`@("`@("`G87)G
M)R`]/B`G4D5,)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@
M("`@("`@("`G<F5V:7-I;VXG(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@
M("`@("`G<VAO<G1O<'0G(#T^("=R)RP-"B`@("`@("`@("`@("`@("`@("`@
M)V1O8R<@/3X@)T1I9F8@86=A:6YS="!R979I<VEO;B!2158G+`T*("`@("`@
M("`@("`@("`@("`@("`G87)G)R`]/B`G4D56)RP-"B`@("`@("`@("`@("`@
M("`@("`@*2P-"B`@("`@("`@("`@("`@("`G8V]N=&5X="<@/3X@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)V,G+`T*("`@
M("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G1V5N97)A=&4@8V]N=&5X="!D
M:69F)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@
M("`G=6YI9FEE9"<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S
M:&]R=&]P="<@/3X@)W4G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]
M/B`G1V5N97)A=&4@=6YI9FEE9"!D:69F)RP-"B`@("`@("`@("`@("`@("`@
M("`@*2P-"B`@("`@("`@("`@("`@("`G:6=N;W)E+6-A<V4G(#T^(&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=I)RP-"B`@
M("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)TEG;F]R92!C87-E+"!C;VYS
M:61E<B!U<'!E<BT@86YD(&QO=V5R+6-A<V4@;&5T=&5R<R!E<75I=F%L96YT
M)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G
M:6=N;W)E+7=H:71E<W!A8V4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@
M("`@("`G<VAO<G1O<'0G(#T^("=B)RP-"B`@("`@("`@("`@("`@("`@("`@
M)V1O8R<@/3X@)TEG;F]R92!C:&%N9V5S(&EN(&%M;W5N="!O9B!W:&ET92!S
M<&%C92<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@
M("`@)VEG;F]R92UB;&%N:RUL:6YE<R<@/3X@87)R87DH#0H@("`@("`@("`@
M("`@("`@("`@("=S:&]R=&]P="<@/3X@)T(G+`T*("`@("`@("`@("`@("`@
M("`@("`G9&]C)R`]/B`G26=N;W)E(&-H86YG97,@=&AA="!I;G-E<G0@;W(@
M9&5L971E(&)L86YK(&QI;F5S)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-
M"B`@("`@("`@("`@("`@("`G8G)I968G(#T^(&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("`@("`G9&]C)R`]/B`G4F5P;W)T(&]N;'D@=VAE=&AE<B!T:&4@
M9FEL97,@9&EF9F5R+"!N;R!D971A:6QS)RP-"B`@("`@("`@("`@("`@("`@
M("`@*2P-"B`@("`@("`@("`@("`@("`G9')Y+7)U;B<@/3X@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)VXG+`T*("`@("`@
M("`@("`@("`@("`@("`G9&]C)R`]/B`G1&]N7"=T(&1O(&%N>71H:6YG+"!J
M=7-T('!R971E;F0G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@
M("`@("`@("`@("DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G/'!A8VMA9V4N
M>&UL/@T*0V]M<&%R97,@86QL('1H92!F:6QE<R!I;B!A('!A8VMA9V4N("!7
M:71H;W5T(&%N>2!O<'1I;VYS+"!T:&ES#0IC;VUM86YD('=I;&P@8V]M<&%R
M92!T:&4@8W5R<F5N="!C;V1E('=I=&@@=&AE(&QA<W0@8VAE8VME9"UI;B!C
M;V1E+@T*57-I;F<@=&AE("UR(&]R("U2(&]P=&EO;B!Y;W4@;6%Y(&-O;7!A
M<F4@=&AE(&-U<G)E;G0@8V]D92!W:71H('1H870-"F]F(&$@<W!E8VEF:6,@
M<F5L96%S92X-"B<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`G8W9S=&%G
M)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G4V5T($-6
M4R!296QE87-E(%1A9R<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D
M;T-V<U1A9R<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=C="<L#0H@
M("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@
M("`@)W%U:65T)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H
M;W)T;W!T)R`]/B`G<2<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^
M("="92!Q=6EE="<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@
M("`@("`@("`@)W)E86QL>7%U:65T)R`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`@("`@)W-H;W)T;W!T)R`]/B`G42<L#0H@("`@("`@("`@("`@("`@
M("`@("=D;V,G(#T^("="92!R96%L;'D@<75I970G+`T*("`@("`@("`@("`@
M("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=S;&ED92<@/3X@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)T8G+`T*("`@
M("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G36]V92`H<VQI9&4I('1A9R!I
M9B!I="!E>&ES=',G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@
M("`@("`@("`@("=D96QE=&4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@
M("`@("`G<VAO<G1O<'0G(#T^("=D)RP-"B`@("`@("`@("`@("`@("`@("`@
M)V1O8R<@/3X@)U)E;6]V92!T86<G+`T*("`@("`@("`@("`@("`@("`@("`I
M+`T*("`@("`@("`@("`@("`@("=D<GDM<G5N)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G;B<L#0H@("`@("`@("`@
M("`@("`@("`@("=D;V,G(#T^("=$;VY<)W0@9&\@86YY=&AI;F<L(&IU<W0@
M<')E=&5N9"<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@
M("`@("`@*2P-"B`@("`@("`@("`@("=D;V,G(#T^("<\<&%C:V%G92YX;6P^
M(%MF:6QE<RXN+ET-"E-E=',@82!#5E,@=&%G(&]N(&%L;"!F:6QE<R!I;B!A
M('!A8VMA9V4N("!5<V4@=&AI<R!C;VUM86YD(&%F=&5R('EO=2!H879E#0IP
M86-K86=E9"!A(&1I<W1R:6)U=&EO;B!T87)B86QL('=I=&@@=&AE(")P86-K
M86=E(B!C;VUM86YD('1O('1A9R!W:&%T#0IR979I<VEO;G,@;V8@=VAA="!F
M:6QE<R!W97)E(&EN('1H870@<F5L96%S92X@($EF(&YE960@=&\@9FEX('-O
M;65T:&EN9PT*869T97(@<G5N;FEN9R!C=G-T86<@;VYC92P@8G5T(&)E9F]R
M92!T:&4@=&%R8F%L;"!I<R!R96QE87-E9"!T;R!T:&4@<'5B;&EC+`T*=7-E
M('1H92`B<VQI9&4B(&]P=&EO;B!T;R!M;W9E('1H92!R96QE87-E('1A9RX-
M"@T*=&\@:6YC;'5D92!F:6QE<R`H<W5C:"!A<R!A('-E8V]N9"!P86-K86=E
M+GAM;"P@;W(@=&5S=',@;F]T(&EN8VQU9&5D(&EN('1H90T*<F5L96%S92DL
M('!A<W,@=&AE;2!A<R!A9&1I=&EO;F%L('!A<F%M971E<G,N#0HG+`T*("`@
M("`@("`@("`@*2P-"B`@("`@("`@)W!A8VMA9V4M9&5P96YD96YC:65S)R`]
M/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G4VAO=R!P86-K
M86=E(&1E<&5N9&5N8VEE<R<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^
M("=D;U!A8VMA9V5$97!E;F1E;F-I97,G+`T*("`@("`@("`@("`@)W-H;W)T
M8W5T)R`]/B`G<&0G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y
M*"DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G#0I,:7-T(&%L;"!D97!E;F-I
M97,@=&AE('!A8VMA9V4@:&%S+B<-"B`@("`@("`@("`@("DL#0H@("`@("`@
M("=S:6=N)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G
M4VEG;B!A('!A8VMA9V4@9&ES=')I8G5T:6]N(&9I;&4G+`T*("`@("`@("`@
M("`@)V9U;F-T:6]N)R`]/B`G9&]3:6=N)RP-"B`@("`@("`@("`@("=S:&]R
M=&-U="<@/3X@)W-I)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A
M>2@I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)SQP86-K86=E+69I;&4^#0I3
M:6=N<R!A('!A8VMA9V4@9&ES=')I8G5T:6]N("@N=&%R(&]R("YT9WHI(&9I
M;&4@=VET:"!';G501RXG+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@)VUA
M:V5R<&TG(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("="
M=6EL9',@86X@4E!-('-P96,@9FEL92!F<F]M(&$@4$5!4B!P86-K86=E)RP-
M"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O36%K95)032<L#0H@("`@
M("`@("`@("`G<VAO<G1C=70G(#T^("=R<&TG+`T*("`@("`@("`@("`@)V]P
M=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=S<&5C+71E;7!L
M871E)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T
M)R`]/B`G="<L#0H@("`@("`@("`@("`@("`@("`@("=A<F<G(#T^("=&24Q%
M)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)U5S92!&24Q%(&%S
M(%)032!S<&5C(&9I;&4@=&5M<&QA=&4G#0H@("`@("`@("`@("`@("`@("`@
M("DL#0H@("`@("`@("`@("`@("`@)W)P;2UP:V=N86UE)R`]/B!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G<"<L#0H@("`@
M("`@("`@("`@("`@("`@("=A<F<G(#T^("=&3U)-050G+`T*("`@("`@("`@
M("`@("`@("`@("`G9&]C)R`]/B`G57-E($9/4DU!5"!A<R!F;W)M870@<W1R
M:6YG(&9O<B!24$T@<&%C:V%G92!N86UE+"`E<R!I<R!R97!L86-E9`T*8GD@
M=&AE(%!%05(@<&%C:V%G92!N86UE+"!D969A=6QT<R!T;R`B4$5!4CHZ)7,B
M+B<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@
M*2P-"B`@("`@("`@("`@("=D;V,G(#T^("<\<&%C:V%G92UF:6QE/@T*#0I#
M<F5A=&5S(&%N(%)032`N<W!E8R!F:6QE(&9O<B!W<F%P<&EN9R!A(%!%05(@
M<&%C:V%G92!I;G-I9&4@86X@4E!-#0IP86-K86=E+B`@26YT96YD960@=&\@
M8F4@=7-E9"!F<F]M('1H92!34$5#4R!D:7)E8W1O<GDL('=I=&@@=&AE(%!%
M05(-"G!A8VMA9V4@=&%R8F%L;"!I;B!T:&4@4T]54D-%4R!D:7)E8W1O<GDZ
M#0H-"B0@<&5A<B!M86ME<G!M("XN+U-/55)#15,O3F5T7U-O8VME="TQ+C`N
M=&=Z#0I7<F]T92!24$T@<W!E8R!F:6QE(%!%05(Z.DYE=%]'96\M,2XP+G-P
M96,-"B0@<G!M("UB8B!014%2.CI.971?4V]C:V5T+3$N,"YS<&5C#0HN+BX-
M"E=R;W1E.B`O=7-R+W-R8R]R961H870O4E!-4R]I,S@V+U!%05(Z.DYE=%]3
M;V-K970M,2XP+3$N:3,X-BYR<&T-"B<L#0H@("`@("`@("`@("`I+`T*("`@
M("`@("`G8V]N=F5R="<@/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R
M>2<@/3X@)T-O;G9E<G0@82!P86-K86=E+GAM;"`Q+C`@=&\@<&%C:V%G92YX
M;6P@,BXP(&9O<FUA="<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D
M;T-O;G9E<G0G+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G8S(G+`T*
M("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("=F;&%T)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H
M;W)T;W!T)R`]/B`G9B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^
M("=D;R!N;W0@8F5A=71I9GD@=&AE(&9I;&5L:7-T+B<L#0H@("`@("`@("`@
M("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@
M("=D;V,G(#T^("=;9&5S8V9I;&5=(%MD97-C9FEL93)=#0I#;VYV97)T<R!A
M('!A8VMA9V4N>&UL(&EN(#$N,"!F;W)M870@:6YT;R!A('!A8VMA9V4N>&UL
M#0II;B`R+C`@9F]R;6%T+B`@5&AE(&YE=R!F:6QE('=I;&P@8F4@;F%M960@
M<&%C:V%G93(N>&UL(&)Y(&1E9F%U;'0L#0IA;F0@<&%C:V%G92YX;6P@=VEL
M;"!B92!U<V5D(&%S('1H92!O;&0@9FEL92!B>2!D969A=6QT+@T*5&AI<R!I
M<R!N;W0@=&AE(&UO<W0@:6YT96QL:6=E;G0@8V]N=F5R<VEO;BP@86YD('-H
M;W5L9"!O;FQY(&)E#0IU<V5D(&9O<B!A=71O;6%T960@8V]N=F5R<VEO;B!O
M<B!L96%R;FEN9R!T:&4@9F]R;6%T+@T*)PT*("`@("`@("`@("`@*2P-"B`@
M("`@("`@*3L-"@T*("`@('9A<B`D;W5T<'5T.PT*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(&-O;G-T<G5C=&]R#0H-"B`@("`O*BH-"B`@("`@*B!014%2
M7T-O;6UA;F1?4&%C:V%G92!C;VYS=')U8W1O<BX-"B`@("`@*@T*("`@("`J
M($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@4$5!4E]#
M;VUM86YD7U!A8VMA9V4H)B1U:2P@)B1C;VYF:6<I#0H@("`@>PT*("`@("`@
M("!P87)E;G0Z.E!%05)?0V]M;6%N9%]#;VUM;VXH)'5I+"`D8V]N9FEG*3L-
M"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?9&ES<&QA>59A
M;&ED871I;VY297-U;'1S*"D-"@T*("`@(&9U;F-T:6]N(%]D:7-P;&%Y5F%L
M:61A=&EO;E)E<W5L=',H)&5R<BP@)'=A<FXL("1S=')I8W0@/2!F86QS92D-
M"B`@("![#0H@("`@("`@(&9O<F5A8V@@*"1E<G(@87,@)&4I('L-"B`@("`@
M("`@("`@("1T:&ES+3YO=71P=70@+CT@(D5R<F]R.B`D95QN(CL-"B`@("`@
M("`@?0T*("`@("`@("!F;W)E86-H("@D=V%R;B!A<R`D=RD@>PT*("`@("`@
M("`@("`@)'1H:7,M/F]U='!U="`N/2`B5V%R;FEN9SH@)'=<;B([#0H@("`@
M("`@('T-"B`@("`@("`@)'1H:7,M/F]U='!U="`N/2!S<')I;G1F*"=686QI
M9&%T:6]N.B`E9"!E<G)O<BAS*2P@)60@=V%R;FEN9RAS*2<N(EQN(BP-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-I>F5O9B@D
M97)R*2P@<VEZ96]F*"1W87)N*2D[#0H@("`@("`@(&EF("@D<W1R:6-T("8F
M('-I>F5O9B@D97)R*2`^(#`I('L-"B`@("`@("`@("`@("1T:&ES+3YO=71P
M=70@+CT@(D9I>"!T:&5S92!E<G)O<G,@86YD('1R>2!A9V%I;BXB.PT*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@(&9U;F-T:6]N
M("9G971086-K86=E<B@I#0H@("`@>PT*("`@("`@("!I9B`H(6-L87-S7V5X
M:7-T<R@G4$5!4E]086-K86=E<B<I*2![#0H@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)U!%05(O4&%C:V%G97(N<&AP)SL-"B`@("`@("`@?0T*("`@("`@
M("`D82`]("9N97<@4$5!4E]086-K86=E<CL-"B`@("`@("`@<F5T=7)N("1A
M.PT*("`@('T-"@T*("`@(&9U;F-T:6]N("9G971086-K86=E1FEL92@D8V]N
M9FEG+"`D9&5B=6<@/2!F86QS92P@)'1M<&1I<B`](&YU;&PI#0H@("`@>PT*
M("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]#;VUM;VXG*2D@>PT*
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T-O;6UO;BYP:'`G.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%2+U!A
M8VMA9V5&:6QE+G!H<"<I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)U!%05(O4&%C:V%G949I;&4N<&AP)SL-"B`@("`@("`@?0T*("`@("`@("`D
M82`]("9N97<@4$5!4E]086-K86=E1FEL92@D8V]N9FEG+"`D9&5B=6<L("1T
M;7!D:7(I.PT*("`@("`@("`D8V]M;6]N(#T@;F5W(%!%05)?0V]M;6]N.PT*
M("`@("`@("`D8V]M;6]N+3YU:2`]("1T:&ES+3YU:3L-"B`@("`@("`@)&$M
M/G-E=$QO9V=E<B@D8V]M;6]N*3L-"B`@("`@("`@<F5T=7)N("1A.PT*("`@
M('T-"B`@("`O+R![>WL@9&]086-K86=E*"D-"@T*("`@(&9U;F-T:6]N(&1O
M4&%C:V%G92@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*
M("`@("`@("`D=&AI<RT^;W5T<'5T(#T@)R<[#0H@("`@("`@("1P:V=I;F9O
M9FEL92`](&ES<V5T*"1P87)A;7-;,%TI(#\@)'!A<F%M<ULP72`Z("=P86-K
M86=E+GAM;"<[#0H@("`@("`@("1P:V<R(#T@:7-S970H)'!A<F%M<ULQ72D@
M/R`D<&%R86US6S%=(#H@;G5L;#L-"B`@("`@("`@:68@*"$D<&MG,B`F)B`A
M:7-S970H)'!A<F%M<ULP72DI('L-"B`@("`@("`@("`@(&EF("AF:6QE7V5X
M:7-T<R@G<&%C:V%G93(N>&UL)RDI('L-"B`@("`@("`@("`@("`@("`D<&MG
M,B`]("=P86-K86=E,BYX;6PG.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@("1P86-K86=E<B`]("8D=&AI<RT^9V5T4&%C:V%G97(H*3L-
M"B`@("`@("`@)&-O;7!R97-S(#T@96UP='DH)&]P=&EO;G-;)VYO8V]M<')E
M<W,G72D@/R!T<G5E(#H@9F%L<V4[#0H@("`@("`@("1R97-U;'0@/2`D<&%C
M:V%G97(M/G!A8VMA9V4H)'!K9VEN9F]F:6QE+"`D8V]M<')E<W,L("1P:V<R
M*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<W5L="DI('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L-
M"B`@("`@("`@?0T*("`@("`@("`O+R!$;VXG="!W86YT(&]U='!U="P@;VYL
M>2!T:&4@<&%C:V%G92!F:6QE(&YA;64@:G5S="!C<F5A=&5D#0H@("`@("`@
M(&EF("AI<W-E="@D;W!T:6]N<ULG<VAO=VYA;64G72DI('L-"B`@("`@("`@
M("`@("1T:&ES+3YO=71P=70@/2`D<F5S=6QT.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("@D=&AI<RT^;W5T<'5T*2![#0H@("`@("`@("`@("`D=&AI<RT^
M=6DM/F]U='!U=$1A=&$H)'1H:7,M/F]U='!U="P@)&-O;6UA;F0I.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O
M('U]?0T*("`@("\O('M[>R!D;U!A8VMA9V5686QI9&%T92@I#0H-"B`@("!F
M=6YC=&EO;B!D;U!A8VMA9V5686QI9&%T92@D8V]M;6%N9"P@)&]P=&EO;G,L
M("1P87)A;7,I#0H@("`@>PT*("`@("`@("`D=&AI<RT^;W5T<'5T(#T@)R<[
M#0H@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@/"`Q*2![#0H@("`@("`@
M("`@("`D<&%R86US6S!=(#T@(G!A8VMA9V4N>&UL(CL-"B`@("`@("`@?0T*
M("`@("`@("`D;V)J(#T@)B1T:&ES+3YG971086-K86=E1FEL92@D=&AI<RT^
M8V]N9FEG+"`D=&AI<RT^7V1E8G5G*3L-"B`@("`@("`@)&]B:BT^<F%W4F5T
M=7)N*"D[#0H@("`@("`@(%!%05(Z.G-T871I8U!U<VA%<G)O<DAA;F1L:6YG
M*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@)&EN9F\@/2`D;V)J+3YF
M<F]M5&=Z1FEL92@D<&%R86US6S!=+"!014%27U9!3$E$051%7TY/4DU!3"D[
M#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1I;F9O*2D@>PT*("`@("`@
M("`@("`@)&EN9F\@/2`D;V)J+3YF<F]M4&%C:V%G949I;&4H)'!A<F%M<ULP
M72P@4$5!4E]604Q)1$%415].3U)-04PI.PT*("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@)&%R8VAI=F4@/2`D:6YF;RT^9V5T07)C:&EV949I;&4H
M*3L-"B`@("`@("`@("`@("1T87(@/2`F;F5W($%R8VAI=F5?5&%R*"1A<F-H
M:79E*3L-"B`@("`@("`@("`@("1T87(M/F5X=')A8W0H9&ER;F%M92@D:6YF
M;RT^9V5T4&%C:V%G949I;&4H*2DI.PT*("`@("`@("`@("`@)&EN9F\M/G-E
M=%!A8VMA9V5&:6QE*&1I<FYA;64H)&EN9F\M/F=E=%!A8VMA9V5&:6QE*"DI
M("X@1$E214-43U)97U-%4$%2051/4B`N#0H@("`@("`@("`@("`@("`@)&EN
M9F\M/F=E=%!A8VMA9V4H*2`N("<M)R`N("1I;F9O+3YG971697)S:6]N*"D@
M+B!$25)%0U1/4EE?4T5005)!5$]2("X-"B`@("`@("`@("`@("`@("!B87-E
M;F%M92@D:6YF;RT^9V5T4&%C:V%G949I;&4H*2DI.PT*("`@("`@("!]#0H@
M("`@("`@(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\I*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&EN9F\I.PT*("`@("`@("!]#0H@
M("`@("`@("1V86QI9"`](&9A;'-E.PT*("`@("`@("!I9B`H)&EN9F\M/F=E
M=%!A8VMA9V5X;6Q697)S:6]N*"D@/3T@)S(N,"<I('L-"B`@("`@("`@("`@
M(&EF("@D=F%L:60@/2`D:6YF;RT^=F%L:61A=&4H4$5!4E]604Q)1$%415].
M3U)-04PI*2![#0H@("`@("`@("`@("`@("`@)&EN9F\M/F9L871T96Y&:6QE
M3&ES="@I.PT*("`@("`@("`@("`@("`@("1V86QI9"`]("1I;F9O+3YV86QI
M9&%T92A014%27U9!3$E$051%7U!!0TM!1TE.1RD[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=F%L:60@/2`D:6YF
M;RT^=F%L:61A=&4H4$5!4E]604Q)1$%415]004-+04=)3D<I.PT*("`@("`@
M("!]#0H@("`@("`@("1E<G(@/2!A<G)A>2@I.PT*("`@("`@("`D=V%R;B`]
M(&%R<F%Y*"D[#0H@("`@("`@(&EF("@A)'9A;&ED*2![#0H@("`@("`@("`@
M("!F;W)E86-H("@D:6YF;RT^9V5T5F%L:61A=&EO;E=A<FYI;F=S*"D@87,@
M)&5R<F]R*2![#0H@("`@("`@("`@("`@("`@:68@*"1E<G)O<ELG;&5V96PG
M72`]/2`G=V%R;FEN9R<I('L-"B`@("`@("`@("`@("`@("`@("`@)'=A<FY;
M72`]("1E<G)O<ELG;65S<V%G92==.PT*("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("1E<G);72`]("1E<G)O<ELG;65S
M<V%G92==.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("`D=&AI<RT^7V1I<W!L87E686QI9&%T:6]N4F5S
M=6QT<R@D97)R+"`D=V%R;BD[#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T
M1&%T82@D=&AI<RT^;W5T<'5T+"`D8V]M;6%N9"D[#0H@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!D;T-V
M<U1A9R@I#0H-"B`@("!F=6YC=&EO;B!D;T-V<U1A9R@D8V]M;6%N9"P@)&]P
M=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@("`D=&AI<RT^;W5T<'5T
M(#T@)R<[#0H@("`@("`@("1?8VUD(#T@)&-O;6UA;F0[#0H@("`@("`@(&EF
M("AS:7IE;V8H)'!A<F%M<RD@/"`Q*2![#0H@("`@("`@("`@("`D:&5L<"`]
M("1T:&ES+3YG971(96QP*"1C;VUM86YD*3L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B)&-O;6UA;F0Z(&UI<W-I;F<@<&%R86UE
M=&5R.B`D:&5L<%LP72(I.PT*("`@("`@("!]#0H@("`@("`@("1O8FH@/2`F
M)'1H:7,M/F=E=%!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<L("1T:&ES+3Y?
M9&5B=6<I.PT*("`@("`@("`D:6YF;R`]("1O8FHM/F9R;VU!;GE&:6QE*"1P
M87)A;7-;,%TL(%!%05)?5D%,241!5$5?3D]234%,*3L-"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&EN9F\I*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)&EN9F\I.PT*("`@("`@("!]#0H@("`@("`@
M("1E<G(@/2`D=V%R;B`](&%R<F%Y*"D[#0H@("`@("`@(&EF("@A)&EN9F\M
M/G9A;&ED871E*"DI('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O+3YG
M971686QI9&%T:6]N5V%R;FEN9W,H*2!A<R`D97)R;W(I('L-"B`@("`@("`@
M("`@("`@("!I9B`H)&5R<F]R6R=L979E;"==(#T]("=W87)N:6YG)RD@>PT*
M("`@("`@("`@("`@("`@("`@("`D=V%R;EM=(#T@)&5R<F]R6R=M97-S86=E
M)UT[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@)&5R<EM=(#T@)&5R<F]R6R=M97-S86=E)UT[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF
M("@A)'1H:7,M/E]D:7-P;&%Y5F%L:61A=&EO;E)E<W5L=',H)&5R<BP@)'=A
M<FXL('1R=64I*2![#0H@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A
M=&$H)'1H:7,M/F]U='!U="P@)&-O;6UA;F0I.PT*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*"=#5E,@=&%G(&9A:6QE9"<I.PT*("`@
M("`@("!]#0H@("`@("`@("1V97)S:6]N(#T@)&EN9F\M/F=E=%9E<G-I;VXH
M*3L-"B`@("`@("`@)&-V<W9E<G-I;VX@/2!P<F5G7W)E<&QA8V4H)R];7F$M
M>C`M.5TO:2<L("=?)RP@)'9E<G-I;VXI.PT*("`@("`@("`D8W9S=&%G(#T@
M(E)%3$5!4T5?)&-V<W9E<G-I;VXB.PT*("`@("`@("`D9FEL97,@/2!A<G)A
M>5]K97ES*"1I;F9O+3YG971&:6QE;&ES="@I*3L-"B`@("`@("`@)&-O;6UA
M;F0@/2`B8W9S(CL-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=Q=6EE
M="==*2D@>PT*("`@("`@("`@("`@)&-O;6UA;F0@+CT@)R`M<2<[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=R96%L;'EQ=6EE
M="==*2D@>PT*("`@("`@("`@("`@)&-O;6UA;F0@+CT@)R`M42<[#0H@("`@
M("`@('T-"B`@("`@("`@)&-O;6UA;F0@+CT@)R!T86<G.PT*("`@("`@("!I
M9B`H:7-S970H)&]P=&EO;G-;)W-L:61E)UTI*2![#0H@("`@("`@("`@("`D
M8V]M;6%N9"`N/2`G("U&)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S
M970H)&]P=&EO;G-;)V1E;&5T92==*2D@>PT*("`@("`@("`@("`@)&-O;6UA
M;F0@+CT@)R`M9"<[#0H@("`@("`@('T-"B`@("`@("`@)&-O;6UA;F0@+CT@
M)R`G("X@)&-V<W1A9R`N("<@)R`N(&5S8V%P97-H96QL87)G*"1P87)A;7-;
M,%TI.PT*("`@("`@("!A<G)A>5]S:&EF="@D<&%R86US*3L-"B`@("`@("`@
M:68@*&-O=6YT*"1P87)A;7,I*2![#0H@("`@("`@("`@("`O+R!A9&0@:6X@
M861D:71I;VYA;"!F:6QE<R!T;R!B92!T86=G960-"B`@("`@("`@("`@("1F
M:6QE<R`](&%R<F%Y7VUE<F=E*"1F:6QE<RP@)'!A<F%M<RD[#0H@("`@("`@
M('T-"B`@("`@("`@9F]R96%C:"`H)&9I;&5S(&%S("1F:6QE*2![#0H@("`@
M("`@("`@("`D8V]M;6%N9"`N/2`G("<@+B!E<V-A<&5S:&5L;&%R9R@D9FEL
M92D[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES+3YC;VYF:6<M/F=E
M="@G=F5R8F]S92<I(#X@,2D@>PT*("`@("`@("`@("`@)'1H:7,M/F]U='!U
M="`N/2`B*R`D8V]M;6%N9%QN(CL-"B`@("`@("`@?0T*("`@("`@("`D=&AI
M<RT^;W5T<'5T("X]("(K("1C;VUM86YD7&XB.PT*("`@("`@("!I9B`H96UP
M='DH)&]P=&EO;G-;)V1R>2UR=6XG72DI('L-"B`@("`@("`@("`@("1F<"`]
M('!O<&5N*"1C;VUM86YD+"`B<B(I.PT*("`@("`@("`@("`@=VAI;&4@*"1L
M:6YE(#T@9F=E=',H)&9P+"`Q,#(T*2D@>PT*("`@("`@("`@("`@("`@("1T
M:&ES+3YO=71P=70@+CT@<G1R:6TH)&QI;F4I+B)<;B([#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!P8VQO<V4H)&9P*3L-"B`@("`@("`@?0T*("`@
M("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)'1H:7,M/F]U='!U="P@)%]C
M;60I.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@9&]#=G-$:69F*"D-"@T*("`@(&9U;F-T:6]N(&1O
M0W9S1&EF9B@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*
M("`@("`@("`D=&AI<RT^;W5T<'5T(#T@)R<[#0H@("`@("`@(&EF("AS:7IE
M;V8H)'!A<F%M<RD@/"`Q*2![#0H@("`@("`@("`@("`D:&5L<"`]("1T:&ES
M+3YG971(96QP*"1C;VUM86YD*3L-"B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@B)&-O;6UA;F0Z(&UI<W-I;F<@<&%R86UE=&5R.B`D
M:&5L<%LP72(I.PT*("`@("`@("!]#0H@("`@("`@("1O8FH@/2`F)'1H:7,M
M/F=E=%!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<L("1T:&ES+3Y?9&5B=6<I
M.PT*("`@("`@("`D:6YF;R`]("1O8FHM/F9R;VU!;GE&:6QE*"1P87)A;7-;
M,%TL(%!%05)?5D%,241!5$5?3D]234%,*3L-"B`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&EN9F\I*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)&EN9F\I.PT*("`@("`@("!]#0H@("`@("`@("1E<G(@
M/2`D=V%R;B`](&%R<F%Y*"D[#0H@("`@("`@(&EF("@A)&EN9F\M/G9A;&ED
M871E*"DI('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O+3YG971686QI
M9&%T:6]N5V%R;FEN9W,H*2!A<R`D97)R;W(I('L-"B`@("`@("`@("`@("`@
M("!I9B`H)&5R<F]R6R=L979E;"==(#T]("=W87)N:6YG)RD@>PT*("`@("`@
M("`@("`@("`@("`@("`D=V%R;EM=(#T@)&5R<F]R6R=M97-S86=E)UT[#0H@
M("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@
M)&5R<EM=(#T@)&5R<F]R6R=M97-S86=E)UT[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@A)'1H
M:7,M/E]D:7-P;&%Y5F%L:61A=&EO;E)E<W5L=',H)&5R<BP@)'=A<FXL('1R
M=64I*2![#0H@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)'1H
M:7,M/F]U='!U="P@)&-O;6UA;F0I.PT*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*"=#5E,@9&EF9B!F86EL960G*3L-"B`@("`@("`@
M?0T*("`@("`@("`D:6YF;S$@/2`D:6YF;RT^9V5T1FEL96QI<W0H*3L-"B`@
M("`@("`@)&9I;&5S(#T@)&EN9F\Q.PT*("`@("`@("`D8VUD(#T@(F-V<R([
M#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<75I970G72DI('L-"B`@
M("`@("`@("`@("1C;60@+CT@)R`M<2<[#0H@("`@("`@("`@("!U;G-E="@D
M;W!T:6]N<ULG<75I970G72D[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES
M<V5T*"1O<'1I;VYS6R=R96%L;'EQ=6EE="==*2D@>PT*("`@("`@("`@("`@
M)&-M9"`N/2`G("U1)SL-"B`@("`@("`@("`@('5N<V5T*"1O<'1I;VYS6R=R
M96%L;'EQ=6EE="==*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H
M)&]P=&EO;G-;)W)E;&5A<V4G72DI('L-"B`@("`@("`@("`@("1C=G-V97)S
M:6]N(#T@<')E9U]R97!L86-E*"<O6UYA+7HP+3E=+VDG+"`G7R<L("1O<'1I
M;VYS6R=R96QE87-E)UTI.PT*("`@("`@("`@("`@)&-V<W1A9R`](")214Q%
M05-%7R1C=G-V97)S:6]N(CL-"B`@("`@("`@("`@("1O<'1I;VYS6R=R979I
M<VEO;B==(#T@)&-V<W1A9SL-"B`@("`@("`@("`@('5N<V5T*"1O<'1I;VYS
M6R=R96QE87-E)UTI.PT*("`@("`@("!]#0H@("`@("`@("1E>&5C=71E(#T@
M=')U93L-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=D<GDM<G5N)UTI
M*2![#0H@("`@("`@("`@("`D97AE8W5T92`](&9A;'-E.PT*("`@("`@("`@
M("`@=6YS970H)&]P=&EO;G-;)V1R>2UR=6XG72D[#0H@("`@("`@('T-"B`@
M("`@("`@)&-M9"`N/2`G(&1I9F8G.PT*("`@("`@("`O+R!T:&4@<F5S="!O
M9B!T:&4@;W!T:6]N<R!A<F4@<&%S<V5D(')I9VAT(&]N('1O(")C=G,@9&EF
M9B(-"B`@("`@("`@9F]R96%C:"`H)&]P=&EO;G,@87,@)&]P=&EO;B`]/B`D
M;W!T87)G*2![#0H@("`@("`@("`@("`D87)G(#T@0"1T:&ES+3YC;VUM86YD
M<ULD8V]M;6%N9%U;)V]P=&EO;G,G75LD;W!T:6]N75LG87)G)UT[#0H@("`@
M("`@("`@("`D<VAO<G0@/2!`)'1H:7,M/F-O;6UA;F1S6R1C;VUM86YD75LG
M;W!T:6]N<R==6R1O<'1I;VY=6R=S:&]R=&]P="==.PT*("`@("`@("`@("`@
M)&-M9"`N/2`D<VAO<G0@/R`B("TD<VAO<G0B(#H@(B`M+21O<'1I;VXB.PT*
M("`@("`@("`@("`@:68@*"1A<F<@)B8@)&]P=&%R9RD@>PT*("`@("`@("`@
M("`@("`@("1C;60@+CT@*"1S:&]R="`_("<G(#H@)STG*2`N(&5S8V%P97-H
M96QL87)G*"1O<'1A<F<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(&9O<F5A8V@@*"1F:6QE<R!A<R`D9FEL92D@>PT*("`@("`@("`@
M("`@)&-M9"`N/2`G("<@+B!E<V-A<&5S:&5L;&%R9R@D9FEL95LG;F%M92==
M*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1H:7,M/F-O;F9I9RT^9V5T
M*"=V97)B;W-E)RD@/B`Q*2![#0H@("`@("`@("`@("`D=&AI<RT^;W5T<'5T
M("X]("(K("1C;61<;B([#0H@("`@("`@('T-"B`@("`@("`@:68@*"1E>&5C
M=71E*2![#0H@("`@("`@("`@("`D9G`@/2!P;W!E;B@D8VUD+"`B<B(I.PT*
M("`@("`@("`@("`@=VAI;&4@*"1L:6YE(#T@9F=E=',H)&9P+"`Q,#(T*2D@
M>PT*("`@("`@("`@("`@("`@("1T:&ES+3YO=71P=70@+CT@<G1R:6TH)&QI
M;F4I+B)<;B([#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!P8VQO<V4H
M)&9P*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A
M=&$H)'1H:7,M/F]U='!U="P@)&-O;6UA;F0I.PT*("`@("`@("!R971U<FX@
M=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9&]086-K
M86=E1&5P96YD96YC:65S*"D-"@T*("`@(&9U;F-T:6]N(&1O4&%C:V%G941E
M<&5N9&5N8VEE<R@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@
M>PT*("`@("`@("`O+R`D<&%R86US6S!=("T^('1H92!014%2('!A8VMA9V4@
M=&\@;&ES="!I=',@:6YF;W)M871I;VX-"B`@("`@("`@:68@*'-I>F5O9B@D
M<&%R86US*2`A/2`Q*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H(F)A9"!P87)A;65T97(H<RDL('1R>2!<(FAE;'`@)&-O;6UA
M;F1<(B(I.PT*("`@("`@("!]#0H@("`@("`@("1O8FH@/2`F)'1H:7,M/F=E
M=%!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<L("1T:&ES+3Y?9&5B=6<I.PT*
M("`@("`@("`D:6YF;R`]("1O8FHM/F9R;VU!;GE&:6QE*"1P87)A;7-;,%TL
M(%!%05)?5D%,241!5$5?3D]234%,*3L-"B`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)&EN9F\I*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H)&EN9F\I.PT*("`@("`@("!]#0H@("`@("`@("1D97!S(#T@
M)&EN9F\M/F=E=$1E<',H*3L-"B`@("`@("`@:68@*&ES7V%R<F%Y*"1D97!S
M*2D@>PT*("`@("`@("`@("`@:68@*"1I;F9O+3YG971086-K86=E>&UL5F5R
M<VEO;B@I(#T]("<Q+C`G*2![#0H@("`@("`@("`@("`@("`@)&1A=&$@/2!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)V-A<'1I;VXG(#T^("=$97!E
M;F1E;F-I97,@9F]R('!E87(O)R`N("1I;F9O+3YG971086-K86=E*"DL#0H@
M("`@("`@("`@("`@("`@("`@("=B;W)D97(G(#T^('1R=64L#0H@("`@("`@
M("`@("`@("`@("`@("=H96%D;&EN92<@/3X@87)R87DH(E)E<75I<F5D/R(L
M(")4>7!E(BP@(DYA;64B+"`B4F5L871I;VXB+"`B5F5R<VEO;B(I+`T*("`@
M("`@("`@("`@("`@("`@("`I.PT*#0H@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&1E<',@87,@)&0I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1D6R=O<'1I;VYA;"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"1D6R=O<'1I;VYA;"==(#T]("=Y97,G*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)')E<2`]("=.;R<[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1R97$@/2`G665S)SL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1R97$@/2`G665S)SL-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]D97!S
M7W)E;%]T<F%N<ULD9%LG<F5L)UU=*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)')E;"`]("1T:&ES+3Y?9&5P<U]R96Q?=')A;G-;)&1;)W)E;"==
M73L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1R96P@/2`D9%LG<F5L)UT[#0H@("`@("`@("`@("`@
M("`@("`@('T-"@T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]D97!S7W1Y<&5?=')A;G-;)&1;)W1Y<&4G75TI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D='EP92`]('5C9FER<W0H)'1H:7,M/E]D97!S
M7W1Y<&5?=')A;G-;)&1;)W1Y<&4G75TI.PT*("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1Y<&4@/2`D
M9%LG='EP92==.PT*("`@("`@("`@("`@("`@("`@("!]#0H-"B`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1D6R=N86UE)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D;F%M92`]("1D6R=N86UE)UT[#0H@("`@("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D;F%M92`]("<G.PT*("`@("`@("`@("`@("`@("`@("!]#0H-"B`@("`@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D6R=V97)S:6]N)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=F5R<VEO;B`]("1D6R=V97)S:6]N
M)UT[#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D=F5R<VEO;B`]("<G.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H-"B`@("`@("`@("`@("`@("`@("`@)&1A=&%;)V1A=&$G75M=
M(#T@87)R87DH)')E<2P@)'1Y<&4L("1N86UE+"`D<F5L+"`D=F5R<VEO;BD[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E('L@+R\@
M<&%C:V%G92YX;6P@,BXP(&1E<&5N9&5N8VEE<R!D:7-P;&%Y#0H@("`@("`@
M("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T1E<&5N9&5N8WDR+G!H<"<[
M#0H@("`@("`@("`@("`@("`@)&1E<',@/2`D:6YF;RT^9V5T1&5P96YD96YC
M:65S*"D[#0H@("`@("`@("`@("`@("`@)')E9R`]("8D=&AI<RT^8V]N9FEG
M+3YG971296=I<W1R>2@I.PT*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D9&5P<RDI('L-"B`@("`@("`@("`@("`@("`@("`@)&0@/2!N97<@4$5!
M4E]$97!E;F1E;F-Y,B@D=&AI<RT^8V]N9FEG+"!A<G)A>2@I+"`G)RD[#0H@
M("`@("`@("`@("`@("`@("`@("1D871A(#T@87)R87DH#0H@("`@("`@("`@
M("`@("`@("`@("`@("`G8V%P=&EO;B<@/3X@)T1E<&5N9&5N8VEE<R!F;W(@
M)R`N("1I;F9O+3YG971086-K86=E*"DL#0H@("`@("`@("`@("`@("`@("`@
M("`@("`G8F]R9&5R)R`]/B!T<G5E+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@)VAE861L:6YE)R`]/B!A<G)A>2@B4F5Q=6ER960_(BP@(E1Y<&4B+"`B
M3F%M92(L("=697)S:6]N:6YG)RP@)T=R;W5P)RDL#0H@("`@("`@("`@("`@
M("`@("`@("`@("`I.PT*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M9&5P<R!A<R`D='EP92`]/B`D<W5B9"D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)')E<2`]("@D='EP92`]/2`G<F5Q=6ER960G*2`_("=997,G(#H@
M)TYO)SL-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D='EP92`]/2`G
M9W)O=7`G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&=R;W5P
M(#T@)'-U8F1;)V%T=')I8G,G75LG;F%M92==.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9W)O=7`@/2`G)SL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'-U8F1;,%TI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-U8F0@/2!A<G)A>2@D
M<W5B9"D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("@D<W5B9"!A<R`D9W)O=7!A*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&=R;W5P82!A
M<R`D9&5P='EP92`]/B`D9&5P:6YF;RD@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H)&1E<'1Y<&4@/3T@)V%T=')I8G,G*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&1E<'1Y<&4@/3T@)W!E87)I
M;G-T86QL97(G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9&5P='EP92`]("=P96%R($EN<W1A;&QE<B<[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P:6YF;ULP72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!I;F9O(#T@87)R
M87DH)&1E<&EN9F\I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1D97!I;F9O(&%S("1I;F8I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1N86UE(#T@)R<[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&EN9ELG8VAA;FYE;"==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A
M;&EA<R`]("1R96<M/F-H86YN96Q!;&EA<R@D:6YF6R=C:&%N;F5L)UTI.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A
M)&%L:6%S*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1A;&EA<R`]("<H8VAA;FYE;#\I("<@+B1I;F9;)V-H86YN
M96PG73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&YA;64@/2`D86QI87,@+B`G+R<[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&EN9ELG;F%M92==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE("X]("1I;F9;
M)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T@96QS96EF("AI<W-E="@D:6YF6R=P871T97)N)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YA;64@+CT@)&EN
M9ELG<&%T=&5R;B==.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D;F%M92`N/2`G)SL-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D:6YF6R=U<FDG72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F%M92`N/2`G(%LG
M("X@)&EN9ELG=7)I)UT@+B`@)UTG.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1I;F9;)V-O;F9L:6-T<R==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V97(@/2`G
M8V]N9FQI8W1S)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'9E<B`]("1D+3Y?9V5T17AT<F%3=')I;F<H)&EN9BD[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T85LG9&%T82==6UT@
M/2!A<G)A>2@D<F5Q+"!U8V9I<G-T*"1D97!T>7!E*2P@)&YA;64L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9E<BP@)&=R
M;W5P*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T-"@T*("`@("`@("`@("`@)'1H:7,M/G5I
M+3YO=71P=71$871A*"1D871A+"`D8V]M;6%N9"D[#0H@("`@("`@("`@("!R
M971U<FX@=')U93L-"B`@("`@("`@?0T*#0H@("`@("`@("\O($9A;&QB86-K
M#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@B5&AI<R!P86-K86=E
M(&1O97,@;F]T(&AA=F4@86YY(&1E<&5N9&5N8VEE<RXB+"`D8V]M;6%N9"D[
M#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&1O4VEG;B@I#0H-
M"B`@("!F=6YC=&EO;B!D;U-I9VXH)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R
M86US*0T*("`@('L-"B`@("`@("`@<F5Q=6ER95]O;F-E("=3>7-T96TN<&AP
M)SL-"B`@("`@("`@<F5Q=6ER95]O;F-E("=!<F-H:79E+U1A<BYP:'`G.PT*
M("`@("`@("`O+R!S:&]U;&0@;6]V92!M;W-T(&]F('1H:7,@8V]D92!I;G1O
M(%!%05)?4&%C:V%G97(-"B`@("`@("`@+R\@<V\@:70G;&P@8F4@96%S>2!T
M;R!I;7!L96UE;G0@(G!E87(@<&%C:V%G92`M+7-I9VXB#0H@("`@("`@(&EF
M("AS:7IE;V8H)'!A<F%M<RD@(3T@,2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*")B860@<&%R86UE=&5R*',I+"!T<GD@7")H
M96QP("1C;VUM86YD7"(B*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(69I
M;&5?97AI<W1S*"1P87)A;7-;,%TI*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H(F9I;&4@9&]E<R!N;W0@97AI<W0Z("1P87)A
M;7-;,%TB*3L-"B`@("`@("`@?0T*("`@("`@("`D;V)J(#T@)'1H:7,M/F=E
M=%!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<L("1T:&ES+3Y?9&5B=6<I.PT*
M("`@("`@("`D:6YF;R`]("1O8FHM/F9R;VU49WI&:6QE*"1P87)A;7-;,%TL
M(%!%05)?5D%,241!5$5?3D]234%,*3L-"B`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)&EN9F\I*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H)&EN9F\I.PT*("`@("`@("!]#0H@("`@("`@("1T87(@/2!N
M97<@07)C:&EV95]487(H)'!A<F%M<ULP72D[#0H@("`@("`@("1T;7!D:7(@
M/2!3>7-T96TZ.FUK=&5M<"@G+60@<&5A<G-I9VXG*3L-"B`@("`@("`@:68@
M*"$D=&%R+3YE>'1R86-T3&ES="@G<&%C:V%G93(N>&UL('!A8VMA9V4N<VEG
M)RP@)'1M<&1I<BDI('L-"B`@("`@("`@("`@(&EF("@A)'1A<BT^97AT<F%C
M=$QI<W0H)W!A8VMA9V4N>&UL('!A8VMA9V4N<VEG)RP@)'1M<&1I<BDI('L-
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F9A
M:6QE9"!T;R!E>'1R86-T('1A<B!F:6QE(BD[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@:68@*&9I;&5?97AI<W1S*"(D=&UP9&ER+W!A
M8VMA9V4N<VEG(BDI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@B<&%C:V%G92!A;')E861Y('-I9VYE9"(I.PT*("`@("`@("!]
M#0H@("`@("`@("1P86-K86=E>&UL(#T@)W!A8VMA9V4N>&UL)SL-"B`@("`@
M("`@:68@*&9I;&5?97AI<W1S*"(D=&UP9&ER+W!A8VMA9V4R+GAM;"(I*2![
M#0H@("`@("`@("`@("`D<&%C:V%G97AM;"`]("=P86-K86=E,BYX;6PG.PT*
M("`@("`@("!]#0H@("`@("`@($!U;FQI;FLH(B1T;7!D:7(O<&%C:V%G92YS
M:6<B*3L-"B`@("`@("`@)&EN<'5T(#T@)'1H:7,M/G5I+3YU<V5R1&EA;&]G
M*"1C;VUM86YD+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH)T=N=5!'(%!A<W-P:')A<V4G*2P-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=P87-S=V]R9"<I
M*3L-"B`@("`@("`@)&=P9R`]('!O<&5N*")G<&<@+2UB871C:"`M+7!A<W-P
M:')A<V4M9F0@,"`M+6%R;6]R("TM9&5T86-H+7-I9VX@+2UO=71P=70@)'1M
M<&1I<B]P86-K86=E+G-I9R`D=&UP9&ER+R1P86-K86=E>&UL(#(^+V1E=B]N
M=6QL(BP@(G<B*3L-"B`@("`@("`@:68@*"$D9W!G*2![#0H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F=P9R!C;VUM86YD(&9A:6QE
M9"(I.PT*("`@("`@("!]#0H@("`@("`@(&9W<FET92@D9W!G+"`B)&EN<'5T
M6S!=7&XB*3L-"B`@("`@("`@:68@*'!C;&]S92@D9W!G*2!\?"`A9FEL95]E
M>&ES=',H(B1T;7!D:7(O<&%C:V%G92YS:6<B*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")G<&<@<VEG;B!F86EL960B*3L-
M"B`@("`@("`@?0T*("`@("`@("`D=&%R+3YA9&1-;V1I9GDH(B1T;7!D:7(O
M<&%C:V%G92YS:6<B+"`G)RP@)'1M<&1I<BD[#0H@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@+RHJ#0H@("`@("H@
M1F]R('5N:70@=&5S=&EN9R!P=7)P;W-E<PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N("9G971);G-T86QL97(H)B1U:2D-"B`@("![#0H@("`@("`@(&EF("@A
M8VQA<W-?97AI<W1S*"=014%27TEN<W1A;&QE<B<I*2![#0H@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)U!%05(O26YS=&%L;&5R+G!H<"<[#0H@("`@("`@
M('T-"B`@("`@("`@)&$@/2`F;F5W(%!%05)?26YS=&%L;&5R*"1U:2D[#0H@
M("`@("`@(')E='5R;B`D83L-"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@("`@
M("H@1F]R('5N:70@=&5S=&EN9R!P=7)P;W-E<PT*("`@("`J+PT*("`@(&9U
M;F-T:6]N("9G971#;VUM86YD4&%C:V%G:6YG*"8D=6DL("8D8V]N9FEG*0T*
M("`@('L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?0V]M;6%N
M9%]086-K86=I;F<G*2D@>PT*("`@("`@("`@("`@0&EN8VQU9&5?;VYC92`G
M4$5!4B]#;VUM86YD+U!A8VMA9VEN9RYP:'`G.PT*("`@("`@("!]#0H@("`@
M("`@(`T*("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"=014%27T-O;6UA;F1?
M4&%C:V%G:6YG)RDI('L-"B`@("`@("`@("`@("1A(#T@)FYE=R!014%27T-O
M;6UA;F1?4&%C:V%G:6YG*"1U:2P@)&-O;F9I9RD[#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`D82`](&YU;&P[#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N("1A.PT*("`@('T-"@T*("`@("\O('M[>R!D;TUA:V524$TH
M*0T*#0H@("`@9G5N8W1I;VX@9&]-86ME4E!-*"1C;VUM86YD+"`D;W!T:6]N
M<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@(')E<75I<F5?;VYC92`G4WES
M=&5M+G!H<"<[#0H@("`@("`@(')E<75I<F5?;VYC92`G07)C:&EV92]487(N
M<&AP)SL-"@T*("`@("`@("`O+R!#:&5C:R!T;R!S964@:68@4$5!4E]#;VUM
M86YD7U!A8VMA9VEN9R!I<R!I;G-T86QL960L(&%N9`T*("`@("`@("`O+R!T
M<F%N<W!A<F5N=&QY('-W:71C:"!T;R!U<V4@=&AE(")M86ME+7)P;2US<&5C
M(B!C;VUM86YD(&9R;VT@:70-"B`@("`@("`@+R\@:6YS=&5A9"P@:68@:70@
M9&]E<RX@3W1H97)W:7-E+"!C;VYT:6YU92!T;R!U<V4@=&AE(&]L9"!V97)S
M:6]N#0H@("`@("`@("\O(&]F(")M86ME<G!M(B!S=7!P;&EE9"!W:71H('1H
M:7,@<&%C:V%G92`H4$5!4BDN#0H@("`@("`@("1P86-K86=I;F=?8VUD(#T@
M)'1H:7,M/F=E=$-O;6UA;F1086-K86=I;F<H)'1H:7,M/G5I+"`D=&AI<RT^
M8V]N9FEG*3L-"B`@("`@("`@:68@*"1P86-K86=I;F=?8VUD("$]/2!N=6QL
M*2![#0H@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)U!%05)?
M0V]M;6%N9%]086-K86=I;F<@:7,@:6YS=&%L;&5D.R!U<VEN9R`G+@T*("`@
M("`@("`@("`@("`@("=N97=E<B`B;6%K92UR<&TM<W!E8R(@8V]M;6%N9"!I
M;G-T96%D)RD[#0H@("`@("`@("`@("!R971U<FX@)'!A8VMA9VEN9U]C;60M
M/G)U;B@G;6%K92UR<&TM<W!E8R<L("1O<'1I;VYS+"`D<&%R86US*3L-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T
M1&%T82@G5T%23DE.1SH@(G!E87(@;6%K97)P;2(@:7,@;F]W(&1E<')E8V%T
M960[(&%N("<N#0H@("`@("`@("`@("`@("=I;7!R;W9E9"!V97)S:6]N(&ES
M(&%V86EL86)L92!V:6$@(G!E87(@;6%K92UR<&TM<W!E8R(L('=H:6-H("<N
M#0H@("`@("`@("`@("`@("=I<R!A=F%I;&%B;&4@8GD@:6YS=&%L;&EN9R!0
M14%27T-O;6UA;F1?4&%C:V%G:6YG)RD[#0H@("`@("`@('T-"B`@("`@("`@
M#0H@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@(3T@,2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")B860@<&%R86UE=&5R
M*',I+"!T<GD@7")H96QP("1C;VUM86YD7"(B*3L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H(69I;&5?97AI<W1S*"1P87)A;7-;,%TI*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F9I;&4@9&]E<R!N;W0@
M97AI<W0Z("1P87)A;7-;,%TB*3L-"B`@("`@("`@?0T*("`@("`@("`D<F5G
M(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@("1P
M:V<@/2`F)'1H:7,M/F=E=%!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<L("1T
M:&ES+3Y?9&5B=6<I.PT*("`@("`@("`D<&8@/2`F)'!K9RT^9G)O;4%N>49I
M;&4H)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].3U)-04PI.PT*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&8I*2![#0H@("`@("`@("`@("`D=2`]
M("1P9BT^9V5T57-E<FEN9F\H*3L-"B`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D=2DI('L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D=2!A<R`D97)R
M*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D97)R*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&5R<B`]("1E<G);)VUE<W-A
M9V4G73L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&5R<BD[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*"(D<&%R86US6S!=(&ES(&YO="!A('9A;&ED('!A
M8VMA9V4B*3L-"B`@("`@("`@?0T*("`@("`@("`D=&UP9&ER(#T@4WES=&5M
M.CIM:W1E;7`H87)R87DH)RUD)RP@)W!E87(R<G!M)RDI.PT*("`@("`@("`D
M:6YS=')O;W0@/2!3>7-T96TZ.FUK=&5M<"AA<G)A>2@G+60G+"`G<&5A<C)R
M<&TG*2D[#0H@("`@("`@("1T;7`@/2`D=&AI<RT^8V]N9FEG+3YG970H)W9E
M<F)O<V4G*3L-"B`@("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T*"=V97)B;W-E
M)RP@,"D[#0H@("`@("`@("1I;G-T86QL97(@/2`D=&AI<RT^9V5T26YS=&%L
M;&5R*"1T:&ES+3YU:2D[#0H@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]$
M;W=N;&]A9&5R+U!A8VMA9V4N<&AP)SL-"B`@("`@("`@)'!A8VL@/2!N97<@
M4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4H)&EN<W1A;&QE<BD[#0H@("`@("`@
M("1P86-K+3YS971086-K86=E1FEL92@D<&8I.PT*("`@("`@("`D<&%R86US
M6S!=(#T@)B1P86-K.PT*("`@("`@("`D:6YS=&%L;&5R+3YS971/<'1I;VYS
M*&%R<F%Y*"=I;G-T86QL<F]O="<@/3X@)&EN<W1R;V]T+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYO9&5P<R<@/3X@
M=')U92P@)W-O9G0G(#T^('1R=64I*3L-"B`@("`@("`@)&EN<W1A;&QE<BT^
M<V5T1&]W;FQO861E9%!A8VMA9V5S*"1P87)A;7,I.PT*("`@("`@("`D:6YF
M;R`]("1I;G-T86QL97(M/FEN<W1A;&PH)'!A<F%M<ULP72P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=I;G-T86QL<F]O
M="<@/3X@)&EN<W1R;V]T+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VYO9&5P<R<@/3X@=')U92P@)W-O9G0G(#T^('1R
M=64I*3L-"B`@("`@("`@)'!K9V1I<B`]("1P9BT^9V5T4&%C:V%G92@I("X@
M)RTG("X@)'!F+3YG971697)S:6]N*"D[#0H@("`@("`@("1I;F9O6R=R<&U?
M>&UL7V1I<B==(#T@)R]V87(O;&EB+W!E87(G.PT*("`@("`@("`D=&AI<RT^
M8V]N9FEG+3YS970H)W9E<F)O<V4G+"`D=&UP*3L-"B`@("`@("`@:68@*&ES
M<V5T*"1O<'1I;VYS6R=S<&5C+71E;7!L871E)UTI*2![#0H@("`@("`@("`@
M("`D<W!E8U]T96UP;&%T92`]("1O<'1I;VYS6R=S<&5C+71E;7!L871E)UT[
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D<W!E8U]T96UP;&%T
M92`]("<O=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D871A+U!%05(O
M=&5M<&QA=&4N<W!E8R<[#0H@("`@("`@('T-"B`@("`@("`@)&EN9F];)W!O
M<W-I8FQE7V-H86YN96PG72`]("<G.PT*("`@("`@("`D:6YF;ULG97AT<F%?
M8V]N9FEG)UT@/2`G)SL-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=R
M<&TM<&MG;F%M92==*2D@>PT*("`@("`@("`@("`@)')P;5]P:V=N86UE7V9O
M<FUA="`]("1O<'1I;VYS6R=R<&TM<&MG;F%M92==.PT*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@:68@*"1P9BT^9V5T0VAA;FYE;"@I(#T]("=P
M96%R+G!H<"YN970G('Q\("1P9BT^9V5T0VAA;FYE;"@I(#T]("=P96-L+G!H
M<"YN970G*2![#0H@("`@("`@("`@("`@("`@)&%L:6%S(#T@)U!%05(G.PT*
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D8VAA;B`]
M("8D<F5G+3YG971#:&%N;F5L*"1P9BT^9V5T0VAA;FYE;"@I*3L-"B`@("`@
M("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VAA;BDI('L-"B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1C:&%N
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&%L:6%S
M(#T@)&-H86XM/F=E=$%L:6%S*"D[#0H@("`@("`@("`@("`@("`@)&%L:6%S
M(#T@<W1R=&]U<'!E<B@D86QI87,I.PT*("`@("`@("`@("`@("`@("1I;F9O
M6R=P;W-S:6)L95]C:&%N;F5L)UT@/2`D<&8M/F=E=$-H86YN96PH*2`N("<O
M)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1R<&U?<&MG;F%M95]F
M;W)M870@/2`D86QI87,@+B`G.CHE<R<[#0H@("`@("`@('T-"@T*("`@("`@
M("`D:6YF;ULG97AT<F%?:&5A9&5R<R==(#T@)R<[#0H@("`@("`@("1I;F9O
M6R=D;V-?9FEL97,G72`]("<G.PT*("`@("`@("`D:6YF;ULG9FEL97,G72`]
M("<G.PT*("`@("`@("`D:6YF;ULG<&%C:V%G93)X;6PG72`]("<G.PT*("`@
M("`@("`D:6YF;ULG<G!M7W!A8VMA9V4G72`]('-P<FEN=&8H)')P;5]P:V=N
M86UE7V9O<FUA="P@)'!F+3YG971086-K86=E*"DI.PT*("`@("`@("`D<W)C
M9FEL97,@/2`P.PT*("`@("`@("!F;W)E86-H("@D:6YF;ULG9FEL96QI<W0G
M72!A<R`D;F%M92`]/B`D871T<BD@>PT*("`@("`@("`@("`@:68@*"%I<W-E
M="@D871T<ELG<F]L92==*2D@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&YA;64@/2!P<F5G7W)E
M<&QA8V4H)R%;+SI<7%Q<72$G+"`G+R<L("1N86UE*3L-"B`@("`@("`@("`@
M(&EF("@D871T<ELG<F]L92==(#T]("=D;V,G*2![#0H@("`@("`@("`@("`@
M("`@)&EN9F];)V1O8U]F:6QE<R==("X]("(@)&YA;64B.PT*("`@("`@("`@
M("`@+R\@36%P(')O;&4@=&\@=&AE(')P;2!V87)S#0H@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("1C7W!R969I>"`]("<E>U]L:6)D
M:7)]+W!H<"]P96%R)SL-"B`@("`@("`@("`@("`@("!S=VET8V@@*"1A='1R
M6R=R;VQE)UTI('L-"B`@("`@("`@("`@("`@("`@("`@8V%S92`G<&AP)SH-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1P<F5F:7@@/2`D8U]P<F5F:7@[
M#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@
M("`@("!C87-E("=E>'0G.@T*("`@("`@("`@("`@("`@("`@("`@("`@)'!R
M969I>"`]("<E>U]L:6)D:7)]+W!H<"<[#0H@("`@("`@("`@("`@("`@("`@
M(&)R96%K.R`O+R!86%@@9V]O9"!P;&%C93\-"B`@("`@("`@("`@("`@("`@
M("`@8V%S92`G<W)C)SH-"B`@("`@("`@("`@("`@("`@("`@("`@("1S<F-F
M:6QE<RLK.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'!R969I>"`]("<E
M>U]I;F-L=61E9&ER?2]P:'`G.PT*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL@+R\@6%A8(&=O;V0@<&QA8V4_#0H@("`@("`@("`@("`@("`@("`@(&-A
M<V4@)W1E<W0G.@T*("`@("`@("`@("`@("`@("`@("`@("`@)'!R969I>"`]
M("(D8U]P<F5F:7@O=&5S=',O(B`N("1P9BT^9V5T4&%C:V%G92@I.PT*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@
M8V%S92`G9&%T82<Z#0H@("`@("`@("`@("`@("`@("`@("`@("`D<')E9FEX
M(#T@(B1C7W!R969I>"]D871A+R(@+B`D<&8M/F=E=%!A8VMA9V4H*3L-"B`@
M("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@
M(&-A<V4@)W-C<FEP="<Z#0H@("`@("`@("`@("`@("`@("`@("`@("`D<')E
M9FEX(#T@)R5[7V)I;F1I<GTG.PT*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@("`@("`@("`@9&5F875L=#H@+R\@;F]N+7-T86YD
M87)D(')O;&5S#0H@("`@("`@("`@("`@("`@("`@("`@("`D<')E9FEX(#T@
M(B1C7W!R969I>"\D871T<EMR;VQE72\B("X@)'!F+3YG971086-K86=E*"D[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULG97AT<F%?8V]N9FEG
M)UT@+CT-"B`@("`@("`@("`@("`@("`@("`@("`@(")<;B`@("`@("`@+60@
M>R1A='1R6W)O;&5=?5]D:7(])&-?<')E9FEX+WLD871T<EMR;VQE77T@7%PB
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$
M871A*"=705).24Y'.B!R;VQE("(G("X@)&%T=');)W)O;&4G72`N("<B('5S
M960L("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A;F0@=VEL
M;"!B92!I;G-T86QL960@:6X@(B<@+B`D8U]P<F5F:7@@+B`G+R<@+B`D871T
M<ELG<F]L92==("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G+R<@
M+B`D<&8M/F=E=%!A8VMA9V4H*2`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)R`M(&AA;F0M961I="!T:&4@9FEN86P@+G-P96,@:68@=&AI<R!I
M<R!W<F]N9R<L("1C;VUM86YD*3L-"B`@("`@("`@("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1N86UE
M(#T@<W1R7W)E<&QA8V4H)UQ<)RP@)R\G+"`D;F%M92D[#0H@("`@("`@("`@
M("`@("`@)&EN9F];)V9I;&5S)UT@+CT@(B1P<F5F:7@O)&YA;65<;B([#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1S<F-F:6QE
M<R`^(#`I('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G3U,O1W5E<W,N
M<&AP)SL-"B`@("`@("`@("`@("1O<R`](&YE=R!/4U]'=65S<SL-"B`@("`@
M("`@("`@("1A<F-H(#T@)&]S+3YG971#<'4H*3L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1A<F-H(#T@)VYO87)C:"<[#0H@("`@("`@('T-
M"B`@("`@("`@)&-F9R`](&%R<F%Y*"=M87-T97)?<V5R=F5R)RP@)W!H<%]D
M:7(G+"`G97AT7V1I<B<L("=D;V-?9&ER)RP-"B`@("`@("`@("`@("`@("`@
M("`@("=B:6Y?9&ER)RP@)V1A=&%?9&ER)RP@)W1E<W1?9&ER)RD[#0H@("`@
M("`@(&9O<F5A8V@@*"1C9F<@87,@)&LI('L-"B`@("`@("`@("`@(&EF("@D
M:R`]/2`G;6%S=&5R7W-E<G9E<B<I('L-"B`@("`@("`@("`@("`@("`D8VAA
M;B`]("1R96<M/F=E=$-H86YN96PH)'!F+3YG971#:&%N;F5L*"DI.PT*("`@
M("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C:&%N*2D@>PT*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&-H
M86XI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D:6YF
M;ULD:UT@/2`D8VAA;BT^9V5T4V5R=F5R*"D[#0H@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D:6YF;ULD
M:UT@/2`D=&AI<RT^8V]N9FEG+3YG970H)&LI.PT*("`@("`@("!]#0H@("`@
M("`@("1I;F9O6R=A<F-H)UT@/2`D87)C:#L-"B`@("`@("`@)&9P(#T@0&9O
M<&5N*"1S<&5C7W1E;7!L871E+"`B<B(I.PT*("`@("`@("!I9B`H(21F<"D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")C;W5L
M9"!N;W0@;W!E;B!24$T@<W!E8R!F:6QE('1E;7!L871E("1S<&5C7W1E;7!L
M871E.B`D<&AP7V5R<F]R;7-G(BD[#0H@("`@("`@('T-"B`@("`@("`@)&EN
M9F];)W!A8VMA9V4G72`]("1P9BT^9V5T4&%C:V%G92@I.PT*("`@("`@("`D
M:6YF;ULG=F5R<VEO;B==(#T@)'!F+3YG971697)S:6]N*"D[#0H@("`@("`@
M("1I;F9O6R=R96QE87-E7VQI8V5N<V4G72`]("1P9BT^9V5T3&EC96YS92@I
M.PT*("`@("`@("!I9B`H)'!F+3YG971$97!S*"DI('L-"B`@("`@("`@("`@
M(&EF("@D<&8M/F=E=%!A8VMA9V5X;6Q697)S:6]N*"D@/3T@)S$N,"<I('L-
M"B`@("`@("`@("`@("`@("`D<F5Q=6ER97,@/2`D8V]N9FQI8W1S(#T@87)R
M87DH*3L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D<&8M/F=E=$1E<',H
M*2!A<R`D9&5P*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M9&5P6R=O<'1I;VYA;"==*2`F)B`D9&5P6R=O<'1I;VYA;"==(#T]("=Y97,G
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H)&1E
M<%LG='EP92==("$]("=P:V<G*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG8VAA;FYE;"==*2`F)B`D9&5P
M6R=C:&%N;F5L)UT@(3T@)W!E87(N<&AP+FYE="<@)B8-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&1E<%LG8VAA;FYE;"==("$]("=P96-L+G!H<"YN
M970G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D8VAA;B`]("8D<F5G
M+3YG971#:&%N;F5L*"1D97!;)V-H86YN96PG72D[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VAA;BDI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H)&-H86XI.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@)'!A8VMA9V4@/2!S=')T;W5P<&5R*"1C:&%N
M+3YG971!;&EA<R@I*2`N("<Z.B<@+B`D9&5P6R=N86UE)UT[#0H@("`@("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D<&%C:V%G92`]("=014%2.CHG("X@)&1E<%LG;F%M92==.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1T<F%N<R`]
M(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@)SXG(#T^("<^)RP-
M"B`@("`@("`@("`@("`@("`@("`@("`@("<\)R`]/B`G/"<L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`G/CTG(#T^("<^/2<L#0H@("`@("`@("`@("`@
M("`@("`@("`@("`G/#TG(#T^("<\/2<L#0H@("`@("`@("`@("`@("`@("`@
M("`@("`G/2<@/3X@)STG+`T*("`@("`@("`@("`@("`@("`@("`@("`@)V=T
M)R`]/B`G/B<L#0H@("`@("`@("`@("`@("`@("`@("`@("`G;'0G(#T^("<\
M)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("=G92<@/3X@)SX])RP-"B`@
M("`@("`@("`@("`@("`@("`@("`@("=L92<@/3X@)SP])RP-"B`@("`@("`@
M("`@("`@("`@("`@("`@("=E<2<@/3X@)STG+`T*("`@("`@("`@("`@("`@
M("`@("`I.PT*("`@("`@("`@("`@("`@("`@("!I9B`H)&1E<%LG<F5L)UT@
M/3T@)VAA<R<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R97%U:7)E
M<UM=(#T@)'!A8VMA9V4[#0H@("`@("`@("`@("`@("`@("`@('T@96QS96EF
M("@D9&5P6R=R96PG72`]/2`G;F]T)RD@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)&-O;F9L:6-T<UM=(#T@)'!A8VMA9V4[#0H@("`@("`@("`@("`@
M("`@("`@('T@96QS96EF("@D9&5P6R=R96PG72`]/2`G;F4G*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D8V]N9FQI8W1S6UT@/2`D<&%C:V%G92`N
M("<@/2`G("X@)&1E<%LG=F5R<VEO;B==.PT*("`@("`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H:7-S970H)'1R86YS6R1D97!;)W)E;"==72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1R97%U:7)E<UM=(#T@)'!A8VMA9V4@
M+B`G("<@+B`D=')A;G-;)&1E<%LG<F5L)UU=("X@)R`G("X@)&1E<%LG=F5R
M<VEO;B==.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&EF("AC;W5N="@D<F5Q=6ER97,I*2![
M#0H@("`@("`@("`@("`@("`@("`@("1I;F9O6R=E>'1R85]H96%D97)S)UT@
M+CT@)U)E<75I<F5S.B`G("X@:6UP;&]D92@G+"`G+"`D<F5Q=6ER97,I("X@
M(EQN(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@
M*&-O=6YT*"1C;VYF;&EC=',I*2![#0H@("`@("`@("`@("`@("`@("`@("1I
M;F9O6R=E>'1R85]H96%D97)S)UT@+CT@)T-O;F9L:6-T<SH@)R`N(&EM<&QO
M9&4H)RP@)RP@)&-O;F9L:6-T<RD@+B`B7&XB.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&EN
M9F];)W!A8VMA9V4R>&UL)UT@/2`G,B<[("\O('1E;&P@=&AE('-P96,@=&\@
M=7-E('!A8VMA9V4R+GAM;`T*("`@("`@("`@("`@("`@("1R97%U:7)E<R`]
M("1C;VYF;&EC=',@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@("1D97!S
M(#T@)'!F+3YG971$97!S*'1R=64I.PT*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D9&5P<ULG<F5Q=6ER960G75LG<&%C:V%G92==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!S6R=R97%U:7)E9"==6R=P
M86-K86=E)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D9&5P
M<ULG<F5Q=6ER960G75LG<&%C:V%G92==(#T@87)R87DH)&1E<'-;)W)E<75I
M<F5D)UU;)W!A8VMA9V4G72D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&1E<'-;)W)E<75I<F5D)UU;
M)W!A8VMA9V4G72!A<R`D9&5P*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H)&1E<%LG8VAA;FYE;"==("$]("=P96%R+G!H<"YN970G("8F("`D
M9&5P6R=C:&%N;F5L)UT@(3T@)W!E8VPN<&AP+FYE="<I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D8VAA;B`]("8D<F5G+3YG971#:&%N;F5L
M*"1D97!;)V-H86YN96PG72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&-H86XI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D
M8VAA;BD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E(#T@<W1R=&]U<'!E<B@D
M8VAA;BT^9V5T06QI87,H*2D@+B`G.CHG("X@)&1E<%LG;F%M92==.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<&%C:V%G92`]("=014%2.CHG("X@)&1E<%LG;F%M
M92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)V-O;F9L:6-T<R==*2`F)B`H
M:7-S970H)&1E<%LG;6EN)UTI('Q\#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I<W-E="@D9&5P6R=M87@G72DI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&1E<')A;F=E(#T@87)R87DH*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG;6EN)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!R86YG95M=
M(#T@87)R87DH)&1E<%LG;6EN)UTL)SX])RD[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D9&5P6R=M87@G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&1E<')A;F=E6UT@/2!A<G)A>2@D9&5P6R=M87@G72P@
M)SP])RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=E>&-L=61E
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-?87)R87DH)&1E<%LG97AC;'5D92==*2!\?`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`A:7-S970H)&1E<%LG97AC;'5D92==
M6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&1E<%LG97AC;'5D92==(#T@87)R87DH)&1E<%LG97AC;'5D92==*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)&1E<')A;F=E*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5X8VP@/2`D
M9&5P6R=E>&-L=61E)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!C:&%N9V4@/CT@=&\@/B!I9B!E>&-L=61I;F<@=&AE(&UI
M;B!V97)S:6]N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!C:&%N9V4@/#T@=&\@/"!I9B!E>&-L=61I;F<@=&AE(&UA>"!V97)S
M:6]N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W(H
M)&D@/2`P.R`D:2`\(&-O=6YT*"1E>&-L*3L@)&DK*RD@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P
M<F%N9V5;,%TI("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&5X8VQ;)&E=(#T]("1D97!R86YG95LP75LP72D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9&5P<F%N9V5;,%U;,5T@/2`G/"<[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1D97!;)V5X8VQU9&4G
M75LD:5TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&1E<')A;F=E6S%=*2`F)@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E>&-L6R1I72`]/2`D
M9&5P<F%N9V5;,5U;,%TI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&1E<')A;F=E6S%=6S%=(#T@)SXG.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!U;G-E
M="@D9&5P6R=E>&-L=61E)UU;)&E=*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&-O
M=6YT*"1D97!;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1D97!;)V5X8VQU9&4G72`](&%R<F%Y7W9A;'5E
M<R@D9&5P6R=E>&-L=61E)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&YE=V1E<')A;F=E(#T@87)R87DH*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(')E;6]V92!E>&-L=61E
M<R!T:&%T(&%R92!O=71S:61E('1H92!E>&ES=&EN9R!R86YG90T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I
M(#P@8V]U;G0H)&1E<%LG97AC;'5D92==*3L@)&DK*RD@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D9&5P6R=E>&-L
M=61E)UU;)&E=(#P@)&1E<%LG;6EN)UT@?'P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P6R=E>&-L=61E)UU;
M)&E=(#X@)&1E<%LG;6%X)UTI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=6YS970H)&1E<%LG97AC;'5D92==6R1I
M72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<%LG97AC;'5D
M92==(#T@87)R87E?=F%L=65S*"1D97!;)V5X8VQU9&4G72D[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!U<V]R="@D9&5P6R=E>&-L
M=61E)UTL("=V97)S:6]N7V-O;7!A<F4G*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O('1A:V4@=&AE(')E;6%I;FEN9R!E>&-L
M=61E<R!A;F0-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("\O('-P;&ET('1H92!D97!E;F1E;F-Y(&EN=&\@<W5B+7)A;F=E<PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&QA<W1M:6X@/2`D
M9&5P<F%N9V5;,%T[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D9&5P6R=E>&-L=61E)UTI
M("T@,3L@)&DK*RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1N97=D97!R86YG95M=(#T@)R@G("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V4@+B`B
M('LD;&%S=&UI;ELQ77T@>R1L87-T;6EN6S!=?2!A;F0@(B`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E
M("X@)R`\("<@+B`D9&5P6R=E>&-L=61E)UU;)&E=("X@)RDG.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1L87-T;6EN(#T@
M87)R87DH)&1E<%LG97AC;'5D92==6R1I72P@)SXG*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=M87@G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F5W
M9&5P<F%N9V5;72`]("<H)R`N("1P86-K86=E("X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(B![)&QA<W1M:6Y;,5U]
M('LD;&%S=&UI;ELP77T@86YD("(@+@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<&%C:V%G92`N("<@/"`G("X@)&1E
M<%LG;6%X)UT@+B`G*2<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D8V]N9FQI8W1S6UT@/2!I;7!L;V1E*"<@;W(@)RP@)&1E<')A;F=E*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VYF;&EC='-;
M72`]("1P86-K86=E("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`B('LD9&5P<F%N9V5;,%U;,5U]('LD9&5P<F%N9V5;,%U;
M,%U](B`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@*&ES<V5T*"1D97!R86YG95LQ72D@/R`-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`B(&%N9"`D<&%C:V%G92![)&1E<')A
M;F=E6S%=6S%=?2![)&1E<')A;F=E6S%=6S!=?2(-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Z("<G*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)&1E<%LG;6EN)UTI("8F("%I<W-E="@D
M9&5P6R=M87@G72D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("%I<W-E="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)V-O;F9L:6-T<R==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]N9FQI8W1S6UT@
M/2`D<&%C:V%G93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5Q=6ER
M97-;72`]("1P86-K86=E.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)VUI;B==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5Q=6ER97-;
M72`]("1P86-K86=E("X@)R`^/2`G("X@)&1E<%LG;6EN)UT[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D9&5P6R=M87@G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)')E<75I<F5S6UT@/2`D<&%C:V%G92`N
M("<@/#T@)R`N("1D97!;)VUA>"==.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D97@@/2`D9&5P6R=E>&-L=61E)UT[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&5X*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5X(#T@87)R
M87DH)&5X*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D97@@
M87,@)'9E<BD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&-O;F9L:6-T<UM=(#T@)'!A8VMA9V4@+B`G(#T@)R`N("1V97([#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E("=!<F-H:79E+U1A<BYP:'`G.PT*("`@("`@("`@("`@
M("`@("`@("`D=&%R(#T@;F5W($%R8VAI=F5?5&%R*"1P9BT^9V5T07)C:&EV
M949I;&4H*2D[#0H@("`@("`@("`@("`@("`@("`@("1T87(M/G!U<VA%<G)O
M<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@("`@("`@
M("`@("`@)&$@/2`D=&%R+3YE>'1R86-T26Y3=')I;F<H)W!A8VMA9V4R+GAM
M;"<I.PT*("`@("`@("`@("`@("`@("`@("`D=&%R+3YP;W!%<G)O<DAA;F1L
M:6YG*"D[#0H@("`@("`@("`@("`@("`@("`@(&EF("@D82`]/3T@;G5L;"!\
M?"!014%2.CII<T5R<F]R*"1A*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)&EN9F];)W!A8VMA9V4R>&UL)UT@/2`G)SL-"B`@("`@("`@("`@("`@
M("`@("`@("`@("\O('1H:7,@9&]E<VXG="!H879E(&$@<&%C:V%G92YX;6P@
M=F5R<VEO;B`Q+C`-"B`@("`@("`@("`@("`@("`@("`@("`@("1R97%U:7)E
M<UM=(#T@)U!%05(Z.E!%05(@/CT@)R`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&1E<'-;)W)E<75I<F5D)UU;)W!E87)I;G-T86QL97(G75LG
M;6EN)UT[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@:68@*&-O=6YT*"1R97%U:7)E<RDI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1I;F9O6R=E>'1R85]H96%D97)S)UT@+CT@)U)E<75I<F5S
M.B`G("X@:6UP;&]D92@G+"`G+"`D<F5Q=6ER97,I("X@(EQN(CL-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H8V]U
M;G0H)&-O;F9L:6-T<RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1I
M;F9O6R=E>'1R85]H96%D97)S)UT@+CT@)T-O;F9L:6-T<SH@)R`N(&EM<&QO
M9&4H)RP@)RP@)&-O;F9L:6-T<RD@+B`B7&XB.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H-"B`@("`@("`@+R\@<F5M;W9E('1H92!T<F%I;&EN9R!N97=L
M:6YE#0H@("`@("`@("1I;F9O6R=E>'1R85]H96%D97)S)UT@/2!T<FEM*"1I
M;F9O6R=E>'1R85]H96%D97)S)UTI.PT*("`@("`@("!I9B`H9G5N8W1I;VY?
M97AI<W1S*"=F:6QE7V=E=%]C;VYT96YT<R<I*2![#0H@("`@("`@("`@("!F
M8VQO<V4H)&9P*3L-"B`@("`@("`@("`@("1S<&5C7V-O;G1E;G1S(#T@<')E
M9U]R97!L86-E*"<O0"A;82UZ,"TY7RU=*RE`+V4G+"`G)&EN9F];(EPQ(ETG
M+`T*("`@("`@("`@("`@("`@(&9I;&5?9V5T7V-O;G1E;G1S*"1S<&5C7W1E
M;7!L871E*2D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D<W!E
M8U]C;VYT96YT<R`]('!R96=?<F5P;&%C92@G+T`H6V$M>C`M.5\M72LI0"]E
M)RP@)R1I;F9O6R)<,2)=)RP-"B`@("`@("`@("`@("`@("!F<F5A9"@D9G`L
M(&9I;&5S:7IE*"1S<&5C7W1E;7!L871E*2DI.PT*("`@("`@("`@("`@9F-L
M;W-E*"1F<"D[#0H@("`@("`@('T-"B`@("`@("`@)'-P96-?9FEL92`]("(D
M:6YF;UMR<&U?<&%C:V%G95TM)&EN9F];=F5R<VEO;ETN<W!E8R([#0H@("`@
M("`@("1W<"`](&9O<&5N*"1S<&5C7V9I;&4L(")W8B(I.PT*("`@("`@("!I
M9B`H(21W<"D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*")C;W5L9"!N;W0@=W)I=&4@4E!-('-P96,@9FEL92`D<W!E8U]F:6QE
M.B`D<&AP7V5R<F]R;7-G(BD[#0H@("`@("`@('T-"B`@("`@("`@9G=R:71E
M*"1W<"P@)'-P96-?8V]N=&5N=',I.PT*("`@("`@("!F8VQO<V4H)'=P*3L-
M"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*")7<F]T92!24$T@<W!E
M8R!F:6QE("1S<&5C7V9I;&4B+"`D8V]M;6%N9"D[#0H-"B`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9&]#;VYV97)T*"1C
M;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1P
M86-K86=E>&UL(#T@:7-S970H)'!A<F%M<ULP72D@/R`D<&%R86US6S!=(#H@
M)W!A8VMA9V4N>&UL)SL-"B`@("`@("`@)&YE=W!A8VMA9V5X;6P@/2!I<W-E
M="@D<&%R86US6S%=*2`_("1P87)A;7-;,5T@.B!D:7)N86UE*"1P86-K86=E
M>&UL*2`N#0H@("`@("`@("`@("!$25)%0U1/4EE?4T5005)!5$]2("X@)W!A
M8VMA9V4R+GAM;"<[#0H@("`@("`@("1P:V<@/2`F)'1H:7,M/F=E=%!A8VMA
M9V5&:6QE*"1T:&ES+3YC;VYF:6<L("1T:&ES+3Y?9&5B=6<I.PT*("`@("`@
M("!014%2.CIS=&%T:6-0=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%
M5%523BD[#0H@("`@("`@("1P9B`]("1P:V<M/F9R;VU086-K86=E1FEL92@D
M<&%C:V%G97AM;"P@4$5!4E]604Q)1$%415].3U)-04PI.PT*("`@("`@("!0
M14%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@(&EF("@A
M4$5!4CHZ:7-%<G)O<B@D<&8I*2![#0H@("`@("`@("`@("!I9B`H:7-?82@D
M<&8L("=014%27U!A8VMA9V5&:6QE7W8R)RDI('L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)'!A8VMA9V5X;6P@+B`G(&ES(&%L
M<F5A9'D@82!P86-K86=E+GAM;"!V97)S:6]N(#(N,"<I.PT*("`@("`@("`@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@)&=E;B`]("8D<&8M/F=E=$1E9F%U;'1'96YE<F%T;W(H*3L-"B`@("`@
M("`@("`@("1N97=P9B`]("8D9V5N+3YT;U8R*"D[#0H@("`@("`@("`@("`D
M;F5W<&8M/G-E=%!A8VMA9V5F:6QE*"1N97=P86-K86=E>&UL*3L-"B`@("`@
M("`@("`@("1G96X@/2`F)&YE=W!F+3YG971$969A=6QT1V5N97)A=&]R*"D[
M#0H@("`@("`@("`@("!014%2.CIS=&%T:6-0=7-H17)R;W)(86YD;&EN9RA0
M14%27T524D]27U)%5%523BD[#0H@("`@("`@("`@("`D<W1A=&4@/2`H:7-S
M970H)&]P=&EO;G-;)V9L870G72D@/R!014%27U9!3$E$051%7U!!0TM!1TE.
M1R`Z(%!%05)?5D%,241!5$5?3D]234%,*3L-"B`@("`@("`@("`@("1S879E
M9"`]("1G96XM/G1O4&%C:V%G949I;&4H9&ER;F%M92@D;F5W<&%C:V%G97AM
M;"DL("1S=&%T92P-"B`@("`@("`@("`@("`@("!B87-E;F%M92@D;F5W<&%C
M:V%G97AM;"DI.PT*("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(
M86YD;&EN9R@I.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'-A
M=F5D*2D@>PT*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<V%V960M
M/F=E=%5S97));F9O*"DI*2![#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1S879E9"T^9V5T57-E<DEN9F\H*2!A<R`D=V%R;FEN9RD@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1W
M87)N:6YG6R=M97-S86=E)UTI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^
M;W5T<'5T1&%T82@D<V%V960M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)U=R;W1E(&YE=R!V97)S:6]N(#(N
M,"!P86-K86=E+GAM;"!T;R`B)R`N("1S879E9"`N("<B)RD[#0H@("`@("`@
M("`@("!R971U<FX@=')U93L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@(&EF("AI<U]A<G)A>2@D<&8M/F=E=%5S97));F9O*"DI*2![#0H@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)'!F+3YG9715<V5R26YF;R@I(&%S("1W
M87)N:6YG*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T
M<'5T1&%T82@D=V%R;FEN9ULG;65S<V%G92==*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)'!F*3L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O
M('U]?0T*?0T*#0H_/@T*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+U!A8VMA9V4N
M<&AP+F]R:6<`````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,S<P-3$`,3`U,34T
M,S,W-#``,#(S-S(P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP#0HO*BH-"B`J(%!%05)?0V]M;6%N9%]086-K86=E
M("AP86-K86=E+"!P86-K86=E+79A;&ED871E+"!C=G-D:69F+"!C=G-T86<L
M('!A8VMA9V4M9&5P96YD96YC:65S+`T*("H@<VEG;BP@;6%K97)P;2P@8V]N
M=F5R="!C;VUM86YD<RD-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*
M("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T
M;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@
M879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F
M;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@
M*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET
M('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L
M:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE
M9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G
M92`@("!014%2#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H
M<"YN970^#0H@*B!`875T:&]R("`@("!-87)T:6X@2F%N<V5N(#QM:D!P:'`N
M;F5T/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N
M;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-
M"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D
M260Z(%!A8VMA9V4N<&AP+'8@,2XQ,3D@,C`P-B\P,R\P,B`Q.#HQ-#HQ,R!C
M96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L
M92!S:6YC92!296QE87-E(#`N,0T*("HO#0H-"B\J*@T*("H@8F%S92!C;&%S
M<PT*("HO#0IR97%U:7)E7V]N8V4@)U!%05(O0V]M;6%N9"]#;VUM;VXN<&AP
M)SL-"@T*+RHJ#0H@*B!014%2(&-O;6UA;F1S(&9O<B!L;V=I;B]L;V=O=70-
M"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2
M#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@
M*B!`875T:&]R("`@("!-87)T:6X@2F%N<V5N(#QM:D!P:'`N;F5T/@T*("H@
M0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@
M0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(
M4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]0
M14%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L
M96%S92`P+C$-"B`J+PT*#0IC;&%S<R!014%27T-O;6UA;F1?4&%C:V%G92!E
M>'1E;F1S(%!%05)?0V]M;6%N9%]#;VUM;VX-"GL-"B`@("`O+R![>WL@<')O
M<&5R=&EE<PT*#0H@("`@=F%R("1C;VUM86YD<R`](&%R<F%Y*`T*("`@("`@
M("`G<&%C:V%G92<@/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@
M/3X@)T)U:6QD(%!A8VMA9V4G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]
M/B`G9&]086-K86=E)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)W`G
M+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("=N;V-O;7!R97-S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@)W-H;W)T;W!T)R`]/B`G6B<L#0H@("`@("`@("`@("`@("`@("`@
M("=D;V,G(#T^("=$;R!N;W0@9WII<"!T:&4@<&%C:V%G92!F:6QE)PT*("`@
M("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=S:&]W;F%M
M92<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@
M/3X@)VXG+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G4')I;G0@
M=&AE(&YA;64@;V8@=&AE('!A8VMA9V5D(&9I;&4N)RP-"B`@("`@("`@("`@
M("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@
M)V1O8R<@/3X@)UMD97-C9FEL95T@6V1E<V-F:6QE,ET-"D-R96%T97,@82!0
M14%2('!A8VMA9V4@9G)O;2!I=',@9&5S8W)I<'1I;VX@9FEL92`H=7-U86QL
M>2!C86QL960-"G!A8VMA9V4N>&UL*2X@($EF(&$@<V5C;VYD('!A8VMA9V5F
M:6QE(&ES('!A<W-E9"!I;BP@=&AE;@T*=&AE('!A8VMA9V5R('=I;&P@8VAE
M8VL@=&\@;6%K92!S=7)E('1H870@;VYE(&ES(&$@<&%C:V%G92YX;6P-"G9E
M<G-I;VX@,2XP+"!A;F0@=&AE(&]T:&5R(&ES(&$@<&%C:V%G92YX;6P@=F5R
M<VEO;B`R+C`N("!4:&4-"G!A8VMA9V4N>&UL('9E<G-I;VX@,2XP('=I;&P@
M8F4@<V%V960@87,@(G!A8VMA9V4N>&UL(B!I;B!T:&4@87)C:&EV92P-"F%N
M9"!T:&4@;W1H97(@87,@(G!A8VMA9V4R+GAM;"(@:6X@=&AE(&%R8VAI=F4B
M#0HG#0H@("`@("`@("`@("`I+`T*("`@("`@("`G<&%C:V%G92UV86QI9&%T
M92<@/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)U9A;&ED
M871E(%!A8VMA9V4@0V]N<VES=&5N8WDG+`T*("`@("`@("`@("`@)V9U;F-T
M:6]N)R`]/B`G9&]086-K86=E5F%L:61A=&4G+`T*("`@("`@("`@("`@)W-H
M;W)T8W5T)R`]/B`G<'8G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R
M<F%Y*"DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G#0HG+`T*("`@("`@("`@
M("`@*2P-"B`@("`@("`@)V-V<V1I9F8G(#T^(&%R<F%Y*`T*("`@("`@("`@
M("`@)W-U;6UA<GDG(#T^("=2=6X@82`B8W9S(&1I9F8B(&9O<B!A;&P@9FEL
M97,@:6X@82!P86-K86=E)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@
M)V1O0W9S1&EF9B<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=C9"<L
M#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH#0H@("`@("`@("`@
M("`@("`@)W%U:65T)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@
M)W-H;W)T;W!T)R`]/B`G<2<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G
M(#T^("="92!Q=6EE="<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@
M("`@("`@("`@("`@)W)E86QL>7%U:65T)R`]/B!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G42<L#0H@("`@("`@("`@("`@
M("`@("`@("=D;V,G(#T^("="92!R96%L;'D@<75I970G+`T*("`@("`@("`@
M("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=D871E)R`]/B!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G1"<L#0H@
M("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=$:69F(&%G86EN<W0@<F5V
M:7-I;VX@;V8@1$%412<L#0H@("`@("`@("`@("`@("`@("`@("=A<F<G(#T^
M("=$051%)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@
M("`@("`G<F5L96%S92<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@
M("=S:&]R=&]P="<@/3X@)U(G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C
M)R`]/B`G1&EF9B!A9V%I;G-T('1A9R!F;W(@<&%C:V%G92!R96QE87-E(%)%
M3"<L#0H@("`@("`@("`@("`@("`@("`@("=A<F<G(#T^("=214PG+`T*("`@
M("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=R979I<VEO
M;B<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@
M/3X@)W(G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G1&EF9B!A
M9V%I;G-T(')E=FES:6]N(%)%5B<L#0H@("`@("`@("`@("`@("`@("`@("=A
M<F<G(#T^("=2158G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@
M("`@("`@("`@("=C;VYT97AT)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@)W-H;W)T;W!T)R`]/B`G8R<L#0H@("`@("`@("`@("`@("`@("`@
M("=D;V,G(#T^("='96YE<F%T92!C;VYT97AT(&1I9F8G+`T*("`@("`@("`@
M("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=U;FEF:65D)R`]/B!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G=2<L
M#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("='96YE<F%T92!U;FEF
M:65D(&1I9F8G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@
M("`@("`@("=I9VYO<F4M8V%S92<@/3X@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`@("=S:&]R=&]P="<@/3X@)VDG+`T*("`@("`@("`@("`@("`@("`@
M("`G9&]C)R`]/B`G26=N;W)E(&-A<V4L(&-O;G-I9&5R('5P<&5R+2!A;F0@
M;&]W97(M8V%S92!L971T97)S(&5Q=6EV86QE;G0G+`T*("`@("`@("`@("`@
M("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=I9VYO<F4M=VAI=&5S<&%C
M92<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@
M/3X@)V(G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G26=N;W)E
M(&-H86YG97,@:6X@86UO=6YT(&]F('=H:71E('-P86-E)RP-"B`@("`@("`@
M("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G:6=N;W)E+6)L86YK
M+6QI;F5S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T
M;W!T)R`]/B`G0B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=)
M9VYO<F4@8VAA;F=E<R!T:&%T(&EN<V5R="!O<B!D96QE=&4@8FQA;FL@;&EN
M97,G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@
M("=B<FEE9B<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=D;V,G
M(#T^("=297!O<G0@;VYL>2!W:&5T:&5R('1H92!F:6QE<R!D:69F97(L(&YO
M(&1E=&%I;',G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@
M("`@("`@("=D<GDM<G5N)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@
M("`@)W-H;W)T;W!T)R`]/B`G;B<L#0H@("`@("`@("`@("`@("`@("`@("=D
M;V,G(#T^("=$;VY<)W0@9&\@86YY=&AI;F<L(&IU<W0@<')E=&5N9"<L#0H@
M("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@*2P-"B`@
M("`@("`@("`@("=D;V,G(#T^("<\<&%C:V%G92YX;6P^#0I#;VUP87)E<R!A
M;&P@=&AE(&9I;&5S(&EN(&$@<&%C:V%G92X@(%=I=&AO=70@86YY(&]P=&EO
M;G,L('1H:7,-"F-O;6UA;F0@=VEL;"!C;VUP87)E('1H92!C=7)R96YT(&-O
M9&4@=VET:"!T:&4@;&%S="!C:&5C:V5D+6EN(&-O9&4N#0I5<VEN9R!T:&4@
M+7(@;W(@+5(@;W!T:6]N('EO=2!M87D@8V]M<&%R92!T:&4@8W5R<F5N="!C
M;V1E('=I=&@@=&AA=`T*;V8@82!S<&5C:69I8R!R96QE87-E+@T*)RP-"B`@
M("`@("`@("`@("DL#0H@("`@("`@("=C=G-T86<G(#T^(&%R<F%Y*`T*("`@
M("`@("`@("`@)W-U;6UA<GDG(#T^("=3970@0U93(%)E;&5A<V4@5&%G)RP-
M"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O0W9S5&%G)RP-"B`@("`@
M("`@("`@("=S:&]R=&-U="<@/3X@)V-T)RP-"B`@("`@("`@("`@("=O<'1I
M;VYS)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`G<75I970G(#T^(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=Q)RP-
M"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)T)E('%U:65T)RP-"B`@
M("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G<F5A;&QY
M<75I970G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O
M<'0G(#T^("=1)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)T)E
M(')E86QL>2!Q=6EE="<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@
M("`@("`@("`@("`@)W-L:61E)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@)W-H;W)T;W!T)R`]/B`G1B<L#0H@("`@("`@("`@("`@("`@("`@
M("=D;V,G(#T^("=-;W9E("AS;&ED92D@=&%G(&EF(&ET(&5X:7-T<R<L#0H@
M("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)V1E;&5T
M92<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@
M/3X@)V0G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G4F5M;W9E
M('1A9R<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@
M("`@)V1R>2UR=6XG(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G
M<VAO<G1O<'0G(#T^("=N)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@
M/3X@)T1O;EPG="!D;R!A;GET:&EN9RP@:G5S="!P<F5T96YD)RP-"B`@("`@
M("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@
M("`@("`@)V1O8R<@/3X@)SQP86-K86=E+GAM;#X@6V9I;&5S+BXN70T*4V5T
M<R!A($-64R!T86<@;VX@86QL(&9I;&5S(&EN(&$@<&%C:V%G92X@(%5S92!T
M:&ES(&-O;6UA;F0@869T97(@>6]U(&AA=F4-"G!A8VMA9V5D(&$@9&ES=')I
M8G5T:6]N('1A<F)A;&P@=VET:"!T:&4@(G!A8VMA9V4B(&-O;6UA;F0@=&\@
M=&%G('=H870-"G)E=FES:6]N<R!O9B!W:&%T(&9I;&5S('=E<F4@:6X@=&AA
M="!R96QE87-E+B`@268@;F5E9"!T;R!F:7@@<V]M971H:6YG#0IA9G1E<B!R
M=6YN:6YG(&-V<W1A9R!O;F-E+"!B=70@8F5F;W)E('1H92!T87)B86QL(&ES
M(')E;&5A<V5D('1O('1H92!P=6)L:6,L#0IU<V4@=&AE(")S;&ED92(@;W!T
M:6]N('1O(&UO=F4@=&AE(')E;&5A<V4@=&%G+@T*#0IT;R!I;F-L=61E(&9I
M;&5S("AS=6-H(&%S(&$@<V5C;VYD('!A8VMA9V4N>&UL+"!O<B!T97-T<R!N
M;W0@:6YC;'5D960@:6X@=&AE#0IR96QE87-E*2P@<&%S<R!T:&5M(&%S(&%D
M9&ET:6]N86P@<&%R86UE=&5R<RX-"B<L#0H@("`@("`@("`@("`I+`T*("`@
M("`@("`G<&%C:V%G92UD97!E;F1E;F-I97,G(#T^(&%R<F%Y*`T*("`@("`@
M("`@("`@)W-U;6UA<GDG(#T^("=3:&]W('!A8VMA9V4@9&5P96YD96YC:65S
M)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O4&%C:V%G941E<&5N
M9&5N8VEE<R<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=P9"<L#0H@
M("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH*2P-"B`@("`@("`@("`@
M("=D;V,G(#T^("<-"DQI<W0@86QL(&1E<&5N8VEE<R!T:&4@<&%C:V%G92!H
M87,N)PT*("`@("`@("`@("`@*2P-"B`@("`@("`@)W-I9VXG(#T^(&%R<F%Y
M*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=3:6=N(&$@<&%C:V%G92!D
M:7-T<FEB=71I;VX@9FEL92<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^
M("=D;U-I9VXG+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G<VDG+`T*
M("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*"DL#0H@("`@("`@("`@
M("`G9&]C)R`]/B`G/'!A8VMA9V4M9FEL93X-"E-I9VYS(&$@<&%C:V%G92!D
M:7-T<FEB=71I;VX@*"YT87(@;W(@+G1G>BD@9FEL92!W:71H($=N=5!'+B<L
M#0H@("`@("`@("`@("`I+`T*("`@("`@("`G;6%K97)P;2<@/3X@87)R87DH
M#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)T)U:6QD<R!A;B!24$T@<W!E
M8R!F:6QE(&9R;VT@82!014%2('!A8VMA9V4G+`T*("`@("`@("`@("`@)V9U
M;F-T:6]N)R`]/B`G9&]-86ME4E!-)RP-"B`@("`@("`@("`@("=S:&]R=&-U
M="<@/3X@)W)P;2<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH
M#0H@("`@("`@("`@("`@("`@)W-P96,M=&5M<&QA=&4G(#T^(&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=T)RP-"B`@("`@
M("`@("`@("`@("`@("`@)V%R9R<@/3X@)T9)3$4G+`T*("`@("`@("`@("`@
M("`@("`@("`G9&]C)R`]/B`G57-E($9)3$4@87,@4E!-('-P96,@9FEL92!T
M96UP;&%T92<-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@
M("`@("`G<G!M+7!K9VYA;64G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@
M("`@("`G<VAO<G1O<'0G(#T^("=P)RP-"B`@("`@("`@("`@("`@("`@("`@
M)V%R9R<@/3X@)T9/4DU!5"<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G
M(#T^("=5<V4@1D]234%4(&%S(&9O<FUA="!S=')I;F<@9F]R(%)032!P86-K
M86=E(&YA;64L("5S(&ES(')E<&QA8V5D#0IB>2!T:&4@4$5!4B!P86-K86=E
M(&YA;64L(&1E9F%U;'1S('1O(")014%2.CHE<R(N)RP-"B`@("`@("`@("`@
M("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@
M)V1O8R<@/3X@)SQP86-K86=E+69I;&4^#0H-"D-R96%T97,@86X@4E!-("YS
M<&5C(&9I;&4@9F]R('=R87!P:6YG(&$@4$5!4B!P86-K86=E(&EN<VED92!A
M;B!24$T-"G!A8VMA9V4N("!);G1E;F1E9"!T;R!B92!U<V5D(&9R;VT@=&AE
M(%-014-3(&1I<F5C=&]R>2P@=VET:"!T:&4@4$5!4@T*<&%C:V%G92!T87)B
M86QL(&EN('1H92!33U520T53(&1I<F5C=&]R>3H-"@T*)"!P96%R(&UA:V5R
M<&T@+BXO4T]54D-%4R].971?4V]C:V5T+3$N,"YT9WH-"E=R;W1E(%)032!S
M<&5C(&9I;&4@4$5!4CHZ3F5T7T=E;RTQ+C`N<W!E8PT*)"!R<&T@+6)B(%!%
M05(Z.DYE=%]3;V-K970M,2XP+G-P96,-"BXN+@T*5W)O=&4Z("]U<W(O<W)C
M+W)E9&AA="]24$U3+VDS.#8O4$5!4CHZ3F5T7U-O8VME="TQ+C`M,2YI,S@V
M+G)P;0T*)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@("=C;VYV97)T)R`]
M/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G0V]N=F5R="!A
M('!A8VMA9V4N>&UL(#$N,"!T;R!P86-K86=E+GAM;"`R+C`@9F]R;6%T)RP-
M"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O0V]N=F5R="<L#0H@("`@
M("`@("`@("`G<VAO<G1C=70G(#T^("=C,B<L#0H@("`@("`@("`@("`G;W!T
M:6]N<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@)V9L870G(#T^(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=F)RP-
M"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)V1O(&YO="!B96%U=&EF
M>2!T:&4@9FEL96QI<W0N)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@
M("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)UMD97-C
M9FEL95T@6V1E<V-F:6QE,ET-"D-O;G9E<G1S(&$@<&%C:V%G92YX;6P@:6X@
M,2XP(&9O<FUA="!I;G1O(&$@<&%C:V%G92YX;6P-"FEN(#(N,"!F;W)M870N
M("!4:&4@;F5W(&9I;&4@=VEL;"!B92!N86UE9"!P86-K86=E,BYX;6P@8GD@
M9&5F875L="P-"F%N9"!P86-K86=E+GAM;"!W:6QL(&)E('5S960@87,@=&AE
M(&]L9"!F:6QE(&)Y(&1E9F%U;'0N#0I4:&ES(&ES(&YO="!T:&4@;6]S="!I
M;G1E;&QI9V5N="!C;VYV97)S:6]N+"!A;F0@<VAO=6QD(&]N;'D@8F4-"G5S
M960@9F]R(&%U=&]M871E9"!C;VYV97)S:6]N(&]R(&QE87)N:6YG('1H92!F
M;W)M870N#0HG#0H@("`@("`@("`@("`I+`T*("`@("`@("`I.PT*#0H@("`@
M=F%R("1O=71P=70[#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8V]N<W1R
M=6-T;W(-"@T*("`@("\J*@T*("`@("`J(%!%05)?0V]M;6%N9%]086-K86=E
M(&-O;G-T<G5C=&]R+@T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!014%27T-O;6UA;F1?4&%C:V%G92@F
M)'5I+"`F)&-O;F9I9RD-"B`@("![#0H@("`@("`@('!A<F5N=#HZ4$5!4E]#
M;VUM86YD7T-O;6UO;B@D=6DL("1C;VYF:6<I.PT*("`@('T-"@T*("`@("\O
M('U]?0T*#0H@("`@+R\@>WM[(%]D:7-P;&%Y5F%L:61A=&EO;E)E<W5L=',H
M*0T*#0H@("`@9G5N8W1I;VX@7V1I<W!L87E686QI9&%T:6]N4F5S=6QT<R@D
M97)R+"`D=V%R;BP@)'-T<FEC="`](&9A;'-E*0T*("`@('L-"B`@("`@("`@
M9F]R96%C:"`H)&5R<B!A<R`D92D@>PT*("`@("`@("`@("`@)'1H:7,M/F]U
M='!U="`N/2`B17)R;W(Z("1E7&XB.PT*("`@("`@("!]#0H@("`@("`@(&9O
M<F5A8V@@*"1W87)N(&%S("1W*2![#0H@("`@("`@("`@("`D=&AI<RT^;W5T
M<'5T("X](")787)N:6YG.B`D=UQN(CL-"B`@("`@("`@?0T*("`@("`@("`D
M=&AI<RT^;W5T<'5T("X]('-P<FEN=&8H)U9A;&ED871I;VXZ("5D(&5R<F]R
M*',I+"`E9"!W87)N:6YG*',I)RXB7&XB+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<VEZ96]F*"1E<G(I+"!S:7IE;V8H)'=A
M<FXI*3L-"B`@("`@("`@:68@*"1S=')I8W0@)B8@<VEZ96]F*"1E<G(I(#X@
M,"D@>PT*("`@("`@("`@("`@)'1H:7,M/F]U='!U="`N/2`B1FEX('1H97-E
M(&5R<F]R<R!A;F0@=')Y(&%G86EN+B([#0H@("`@("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@9G5N8W1I;VX@)F=E=%!A8VMA9V5R*"D-
M"B`@("![#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27U!A8VMA
M9V5R)RDI('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]086-K
M86=E<BYP:'`G.PT*("`@("`@("!]#0H@("`@("`@("1A(#T@)FYE=R!014%2
M7U!A8VMA9V5R.PT*("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@)F=E=%!A8VMA9V5&:6QE*"1C;VYF:6<L("1D96)U9R`](&9A
M;'-E+"`D=&UP9&ER(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&EF("@A8VQA
M<W-?97AI<W1S*"=014%27T-O;6UO;B<I*2![#0H@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)U!%05(O0V]M;6]N+G!H<"<[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05(O4&%C:V%G949I;&4N<&AP)RDI
M('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL
M92YP:'`G.PT*("`@("`@("!]#0H@("`@("`@("1A(#T@)FYE=R!014%27U!A
M8VMA9V5&:6QE*"1C;VYF:6<L("1D96)U9RP@)'1M<&1I<BD[#0H@("`@("`@
M("1C;VUM;VX@/2!N97<@4$5!4E]#;VUM;VX[#0H@("`@("`@("1C;VUM;VXM
M/G5I(#T@)'1H:7,M/G5I.PT*("`@("`@("`D82T^<V5T3&]G9V5R*"1C;VUM
M;VXI.PT*("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*("`@("\O('M[>R!D
M;U!A8VMA9V4H*0T*#0H@("`@9G5N8W1I;VX@9&]086-K86=E*"1C;VUM86YD
M+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1T:&ES+3YO
M=71P=70@/2`G)SL-"B`@("`@("`@)'!K9VEN9F]F:6QE(#T@:7-S970H)'!A
M<F%M<ULP72D@/R`D<&%R86US6S!=(#H@)W!A8VMA9V4N>&UL)SL-"B`@("`@
M("`@)'!K9S(@/2!I<W-E="@D<&%R86US6S%=*2`_("1P87)A;7-;,5T@.B!N
M=6QL.PT*("`@("`@("!I9B`H(21P:V<R("8F("%I<W-E="@D<&%R86US6S!=
M*2D@>PT*("`@("`@("`@("`@:68@*&9I;&5?97AI<W1S*"=P86-K86=E,BYX
M;6PG*2D@>PT*("`@("`@("`@("`@("`@("1P:V<R(#T@)W!A8VMA9V4R+GAM
M;"<[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'!A8VMA
M9V5R(#T@)B1T:&ES+3YG971086-K86=E<B@I.PT*("`@("`@("`D8V]M<')E
M<W,@/2!E;7!T>2@D;W!T:6]N<ULG;F]C;VUP<F5S<R==*2`_('1R=64@.B!F
M86QS93L-"B`@("`@("`@)')E<W5L="`]("1P86-K86=E<BT^<&%C:V%G92@D
M<&MG:6YF;V9I;&4L("1C;VUP<F5S<RP@)'!K9S(I.PT*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"1R97-U;'0I.PT*("`@("`@("!]#0H@("`@
M("`@("\O($1O;B=T('=A;G0@;W5T<'5T+"!O;FQY('1H92!P86-K86=E(&9I
M;&4@;F%M92!J=7-T(&-R96%T960-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I
M;VYS6R=S:&]W;F%M92==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/F]U='!U
M="`]("1R97-U;'0[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES+3YO
M=71P=70I('L-"B`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D
M=&AI<RT^;W5T<'5T+"`D8V]M;6%N9"D[#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[
M(&1O4&%C:V%G959A;&ED871E*"D-"@T*("`@(&9U;F-T:6]N(&1O4&%C:V%G
M959A;&ED871E*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![
M#0H@("`@("`@("1T:&ES+3YO=71P=70@/2`G)SL-"B`@("`@("`@:68@*'-I
M>F5O9B@D<&%R86US*2`\(#$I('L-"B`@("`@("`@("`@("1P87)A;7-;,%T@
M/2`B<&%C:V%G92YX;6PB.PT*("`@("`@("!]#0H@("`@("`@("1O8FH@/2`F
M)'1H:7,M/F=E=%!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<L("1T:&ES+3Y?
M9&5B=6<I.PT*("`@("`@("`D;V)J+3YR87=2971U<FXH*3L-"B`@("`@("`@
M4$5!4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]21515
M4DXI.PT*("`@("`@("`D:6YF;R`]("1O8FHM/F9R;VU49WI&:6QE*"1P87)A
M;7-;,%TL(%!%05)?5D%,241!5$5?3D]234%,*3L-"B`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)&EN9F\I*2![#0H@("`@("`@("`@("`D:6YF;R`]("1O
M8FHM/F9R;VU086-K86=E1FEL92@D<&%R86US6S!=+"!014%27U9!3$E$051%
M7TY/4DU!3"D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D87)C
M:&EV92`]("1I;F9O+3YG971!<F-H:79E1FEL92@I.PT*("`@("`@("`@("`@
M)'1A<B`]("9N97<@07)C:&EV95]487(H)&%R8VAI=F4I.PT*("`@("`@("`@
M("`@)'1A<BT^97AT<F%C="AD:7)N86UE*"1I;F9O+3YG971086-K86=E1FEL
M92@I*2D[#0H@("`@("`@("`@("`D:6YF;RT^<V5T4&%C:V%G949I;&4H9&ER
M;F%M92@D:6YF;RT^9V5T4&%C:V%G949I;&4H*2D@+B!$25)%0U1/4EE?4T50
M05)!5$]2("X-"B`@("`@("`@("`@("`@("`D:6YF;RT^9V5T4&%C:V%G92@I
M("X@)RTG("X@)&EN9F\M/F=E=%9E<G-I;VXH*2`N($1)4D5#5$]265]315!!
M4D%43U(@+@T*("`@("`@("`@("`@("`@(&)A<V5N86UE*"1I;F9O+3YG9710
M86-K86=E1FEL92@I*2D[#0H@("`@("`@('T-"B`@("`@("`@4$5!4CHZ<W1A
M=&EC4&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D:6YF;RDI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@D:6YF;RD[#0H@("`@("`@('T-"B`@("`@("`@)'9A;&ED(#T@
M9F%L<V4[#0H@("`@("`@(&EF("@D:6YF;RT^9V5T4&%C:V%G97AM;%9E<G-I
M;VXH*2`]/2`G,BXP)RD@>PT*("`@("`@("`@("`@:68@*"1V86QI9"`]("1I
M;F9O+3YV86QI9&%T92A014%27U9!3$E$051%7TY/4DU!3"DI('L-"B`@("`@
M("`@("`@("`@("`D:6YF;RT^9FQA='1E;D9I;&5,:7-T*"D[#0H@("`@("`@
M("`@("`@("`@)'9A;&ED(#T@)&EN9F\M/G9A;&ED871E*%!%05)?5D%,241!
M5$5?4$%#2T%'24Y'*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1V86QI9"`]("1I;F9O+3YV86QI9&%T92A014%2
M7U9!3$E$051%7U!!0TM!1TE.1RD[#0H@("`@("`@('T-"B`@("`@("`@)&5R
M<B`](&%R<F%Y*"D[#0H@("`@("`@("1W87)N(#T@87)R87DH*3L-"B`@("`@
M("`@:68@*"$D=F%L:60I('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O
M+3YG971686QI9&%T:6]N5V%R;FEN9W,H*2!A<R`D97)R;W(I('L-"B`@("`@
M("`@("`@("`@("!I9B`H)&5R<F]R6R=L979E;"==(#T]("=W87)N:6YG)RD@
M>PT*("`@("`@("`@("`@("`@("`@("`D=V%R;EM=(#T@)&5R<F]R6R=M97-S
M86=E)UT[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@)&5R<EM=(#T@)&5R<F]R6R=M97-S86=E)UT[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M("1T:&ES+3Y?9&ES<&QA>59A;&ED871I;VY297-U;'1S*"1E<G(L("1W87)N
M*3L-"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1T:&ES+3YO=71P
M=70L("1C;VUM86YD*3L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&1O0W9S5&%G*"D-"@T*("`@(&9U
M;F-T:6]N(&1O0W9S5&%G*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-
M"B`@("![#0H@("`@("`@("1T:&ES+3YO=71P=70@/2`G)SL-"B`@("`@("`@
M)%]C;60@/2`D8V]M;6%N9#L-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US
M*2`\(#$I('L-"B`@("`@("`@("`@("1H96QP(#T@)'1H:7,M/F=E=$AE;'`H
M)&-O;6UA;F0I.PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"(D8V]M;6%N9#H@;6ES<VEN9R!P87)A;65T97(Z("1H96QP6S!=(BD[
M#0H@("`@("`@('T-"B`@("`@("`@)&]B:B`]("8D=&AI<RT^9V5T4&%C:V%G
M949I;&4H)'1H:7,M/F-O;F9I9RP@)'1H:7,M/E]D96)U9RD[#0H@("`@("`@
M("1I;F9O(#T@)&]B:BT^9G)O;4%N>49I;&4H)'!A<F%M<ULP72P@4$5!4E]6
M04Q)1$%415].3U)-04PI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M:6YF;RDI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@D:6YF;RD[#0H@("`@("`@('T-"B`@("`@("`@)&5R<B`]("1W87)N(#T@
M87)R87DH*3L-"B`@("`@("`@:68@*"$D:6YF;RT^=F%L:61A=&4H*2D@>PT*
M("`@("`@("`@("`@9F]R96%C:"`H)&EN9F\M/F=E=%9A;&ED871I;VY787)N
M:6YG<R@I(&%S("1E<G)O<BD@>PT*("`@("`@("`@("`@("`@(&EF("@D97)R
M;W);)VQE=F5L)UT@/3T@)W=A<FYI;F<G*2![#0H@("`@("`@("`@("`@("`@
M("`@("1W87)N6UT@/2`D97)R;W);)VUE<W-A9V4G73L-"B`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D97)R6UT@/2`D
M97)R;W);)VUE<W-A9V4G73L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D=&AI<RT^7V1I<W!L
M87E686QI9&%T:6]N4F5S=6QT<R@D97)R+"`D=V%R;BP@=')U92DI('L-"B`@
M("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D=&AI<RT^;W5T<'5T
M+"`D8V]M;6%N9"D[#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)T-64R!T86<@9F%I;&5D)RD[#0H@("`@("`@('T-"B`@("`@("`@
M)'9E<G-I;VX@/2`D:6YF;RT^9V5T5F5R<VEO;B@I.PT*("`@("`@("`D8W9S
M=F5R<VEO;B`]('!R96=?<F5P;&%C92@G+UM>82UZ,"TY72]I)RP@)U\G+"`D
M=F5R<VEO;BD[#0H@("`@("`@("1C=G-T86<@/2`B4D5,14%315\D8W9S=F5R
M<VEO;B([#0H@("`@("`@("1F:6QE<R`](&%R<F%Y7VME>7,H)&EN9F\M/F=E
M=$9I;&5L:7-T*"DI.PT*("`@("`@("`D8V]M;6%N9"`](")C=G,B.PT*("`@
M("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W%U:65T)UTI*2![#0H@("`@("`@
M("`@("`D8V]M;6%N9"`N/2`G("UQ)SL-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H:7-S970H)&]P=&EO;G-;)W)E86QL>7%U:65T)UTI*2![#0H@("`@("`@
M("`@("`D8V]M;6%N9"`N/2`G("U1)SL-"B`@("`@("`@?0T*("`@("`@("`D
M8V]M;6%N9"`N/2`G('1A9R<[#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N
M<ULG<VQI9&4G72DI('L-"B`@("`@("`@("`@("1C;VUM86YD("X]("<@+48G
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG9&5L
M971E)UTI*2![#0H@("`@("`@("`@("`D8V]M;6%N9"`N/2`G("UD)SL-"B`@
M("`@("`@?0T*("`@("`@("`D8V]M;6%N9"`N/2`G("<@+B`D8W9S=&%G("X@
M)R`G("X@97-C87!E<VAE;&QA<F<H)'!A<F%M<ULP72D[#0H@("`@("`@(&%R
M<F%Y7W-H:69T*"1P87)A;7,I.PT*("`@("`@("!I9B`H8V]U;G0H)'!A<F%M
M<RDI('L-"B`@("`@("`@("`@("\O(&%D9"!I;B!A9&1I=&EO;F%L(&9I;&5S
M('1O(&)E('1A9V=E9`T*("`@("`@("`@("`@)&9I;&5S(#T@87)R87E?;65R
M9V4H)&9I;&5S+"`D<&%R86US*3L-"B`@("`@("`@?0T*("`@("`@("!F;W)E
M86-H("@D9FEL97,@87,@)&9I;&4I('L-"B`@("`@("`@("`@("1C;VUM86YD
M("X]("<@)R`N(&5S8V%P97-H96QL87)G*"1F:6QE*3L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H)'1H:7,M/F-O;F9I9RT^9V5T*"=V97)B;W-E)RD@/B`Q
M*2![#0H@("`@("`@("`@("`D=&AI<RT^;W5T<'5T("X]("(K("1C;VUM86YD
M7&XB.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YO=71P=70@+CT@(BL@
M)&-O;6UA;F1<;B([#0H@("`@("`@(&EF("AE;7!T>2@D;W!T:6]N<ULG9')Y
M+7)U;B==*2D@>PT*("`@("`@("`@("`@)&9P(#T@<&]P96XH)&-O;6UA;F0L
M(")R(BD[#0H@("`@("`@("`@("!W:&EL92`H)&QI;F4@/2!F9V5T<R@D9G`L
M(#$P,C0I*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/F]U='!U="`N/2!R
M=')I;2@D;&EN92DN(EQN(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('!C;&]S92@D9G`I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YU:2T^
M;W5T<'5T1&%T82@D=&AI<RT^;W5T<'5T+"`D7V-M9"D[#0H@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!D
M;T-V<T1I9F8H*0T*#0H@("`@9G5N8W1I;VX@9&]#=G-$:69F*"1C;VUM86YD
M+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1T:&ES+3YO
M=71P=70@/2`G)SL-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`\(#$I
M('L-"B`@("`@("`@("`@("1H96QP(#T@)'1H:7,M/F=E=$AE;'`H)&-O;6UA
M;F0I.PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"(D
M8V]M;6%N9#H@;6ES<VEN9R!P87)A;65T97(Z("1H96QP6S!=(BD[#0H@("`@
M("`@('T-"B`@("`@("`@)&]B:B`]("8D=&AI<RT^9V5T4&%C:V%G949I;&4H
M)'1H:7,M/F-O;F9I9RP@)'1H:7,M/E]D96)U9RD[#0H@("`@("`@("1I;F9O
M(#T@)&]B:BT^9G)O;4%N>49I;&4H)'!A<F%M<ULP72P@4$5!4E]604Q)1$%4
M15].3U)-04PI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF
M;RD[#0H@("`@("`@('T-"B`@("`@("`@)&5R<B`]("1W87)N(#T@87)R87DH
M*3L-"B`@("`@("`@:68@*"$D:6YF;RT^=F%L:61A=&4H*2D@>PT*("`@("`@
M("`@("`@9F]R96%C:"`H)&EN9F\M/F=E=%9A;&ED871I;VY787)N:6YG<R@I
M(&%S("1E<G)O<BD@>PT*("`@("`@("`@("`@("`@(&EF("@D97)R;W);)VQE
M=F5L)UT@/3T@)W=A<FYI;F<G*2![#0H@("`@("`@("`@("`@("`@("`@("1W
M87)N6UT@/2`D97)R;W);)VUE<W-A9V4G73L-"B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D97)R6UT@/2`D97)R;W);
M)VUE<W-A9V4G73L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D=&AI<RT^7V1I<W!L87E686QI
M9&%T:6]N4F5S=6QT<R@D97)R+"`D=V%R;BP@=')U92DI('L-"B`@("`@("`@
M("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D=&AI<RT^;W5T<'5T+"`D8V]M
M;6%N9"D[#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M)T-64R!D:69F(&9A:6QE9"<I.PT*("`@("`@("!]#0H@("`@("`@("1I;F9O
M,2`]("1I;F9O+3YG971&:6QE;&ES="@I.PT*("`@("`@("`D9FEL97,@/2`D
M:6YF;S$[#0H@("`@("`@("1C;60@/2`B8W9S(CL-"B`@("`@("`@:68@*&ES
M<V5T*"1O<'1I;VYS6R=Q=6EE="==*2D@>PT*("`@("`@("`@("`@)&-M9"`N
M/2`G("UQ)SL-"B`@("`@("`@("`@('5N<V5T*"1O<'1I;VYS6R=Q=6EE="==
M*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W)E
M86QL>7%U:65T)UTI*2![#0H@("`@("`@("`@("`D8VUD("X]("<@+5$G.PT*
M("`@("`@("`@("`@=6YS970H)&]P=&EO;G-;)W)E86QL>7%U:65T)UTI.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<F5L96%S
M92==*2D@>PT*("`@("`@("`@("`@)&-V<W9E<G-I;VX@/2!P<F5G7W)E<&QA
M8V4H)R];7F$M>C`M.5TO:2<L("=?)RP@)&]P=&EO;G-;)W)E;&5A<V4G72D[
M#0H@("`@("`@("`@("`D8W9S=&%G(#T@(E)%3$5!4T5?)&-V<W9E<G-I;VXB
M.PT*("`@("`@("`@("`@)&]P=&EO;G-;)W)E=FES:6]N)UT@/2`D8W9S=&%G
M.PT*("`@("`@("`@("`@=6YS970H)&]P=&EO;G-;)W)E;&5A<V4G72D[#0H@
M("`@("`@('T-"B`@("`@("`@)&5X96-U=&4@/2!T<G5E.PT*("`@("`@("!I
M9B`H:7-S970H)&]P=&EO;G-;)V1R>2UR=6XG72DI('L-"B`@("`@("`@("`@
M("1E>&5C=71E(#T@9F%L<V4[#0H@("`@("`@("`@("!U;G-E="@D;W!T:6]N
M<ULG9')Y+7)U;B==*3L-"B`@("`@("`@?0T*("`@("`@("`D8VUD("X]("<@
M9&EF9B<[#0H@("`@("`@("\O('1H92!R97-T(&]F('1H92!O<'1I;VYS(&%R
M92!P87-S960@<FEG:'0@;VX@=&\@(F-V<R!D:69F(@T*("`@("`@("!F;W)E
M86-H("@D;W!T:6]N<R!A<R`D;W!T:6]N(#T^("1O<'1A<F<I('L-"B`@("`@
M("`@("`@("1A<F<@/2!`)'1H:7,M/F-O;6UA;F1S6R1C;VUM86YD75LG;W!T
M:6]N<R==6R1O<'1I;VY=6R=A<F<G73L-"B`@("`@("`@("`@("1S:&]R="`]
M($`D=&AI<RT^8V]M;6%N9'-;)&-O;6UA;F1=6R=O<'1I;VYS)UU;)&]P=&EO
M;EU;)W-H;W)T;W!T)UT[#0H@("`@("`@("`@("`D8VUD("X]("1S:&]R="`_
M("(@+21S:&]R="(@.B`B("TM)&]P=&EO;B([#0H@("`@("`@("`@("!I9B`H
M)&%R9R`F)B`D;W!T87)G*2![#0H@("`@("`@("`@("`@("`@)&-M9"`N/2`H
M)'-H;W)T(#\@)R<@.B`G/2<I("X@97-C87!E<VAE;&QA<F<H)&]P=&%R9RD[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H
M)&9I;&5S(&%S("1F:6QE*2![#0H@("`@("`@("`@("`D8VUD("X]("<@)R`N
M(&5S8V%P97-H96QL87)G*"1F:6QE6R=N86UE)UTI.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@D=&AI<RT^8V]N9FEG+3YG970H)W9E<F)O<V4G*2`^(#$I
M('L-"B`@("`@("`@("`@("1T:&ES+3YO=71P=70@+CT@(BL@)&-M9%QN(CL-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)&5X96-U=&4I('L-"B`@("`@("`@
M("`@("1F<"`]('!O<&5N*"1C;60L(")R(BD[#0H@("`@("`@("`@("!W:&EL
M92`H)&QI;F4@/2!F9V5T<R@D9G`L(#$P,C0I*2![#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/F]U='!U="`N/2!R=')I;2@D;&EN92DN(EQN(CL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('!C;&]S92@D9G`I.PT*("`@("`@("!]
M#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D=&AI<RT^;W5T<'5T
M+"`D8V]M;6%N9"D[#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R!D;U!A8VMA9V5$97!E;F1E;F-I97,H
M*0T*#0H@("`@9G5N8W1I;VX@9&]086-K86=E1&5P96YD96YC:65S*"1C;VUM
M86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("\O("1P
M87)A;7-;,%T@+3X@=&AE(%!%05(@<&%C:V%G92!T;R!L:7-T(&ET<R!I;F9O
M<FUA=&EO;@T*("`@("`@("!I9B`H<VEZ96]F*"1P87)A;7,I("$](#$I('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8F%D('!A
M<F%M971E<BAS*2P@=')Y(%PB:&5L<"`D8V]M;6%N9%PB(BD[#0H@("`@("`@
M('T-"B`@("`@("`@)&]B:B`]("8D=&AI<RT^9V5T4&%C:V%G949I;&4H)'1H
M:7,M/F-O;F9I9RP@)'1H:7,M/E]D96)U9RD[#0H@("`@("`@("1I;F9O(#T@
M)&]B:BT^9G)O;4%N>49I;&4H)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].
M3U)-04PI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD[
M#0H@("`@("`@('T-"B`@("`@("`@)&1E<',@/2`D:6YF;RT^9V5T1&5P<R@I
M.PT*("`@("`@("!I9B`H:7-?87)R87DH)&1E<',I*2![#0H@("`@("`@("`@
M("!I9B`H)&EN9F\M/F=E=%!A8VMA9V5X;6Q697)S:6]N*"D@/3T@)S$N,"<I
M('L-"B`@("`@("`@("`@("`@("`D9&%T82`](&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("`@("`G8V%P=&EO;B<@/3X@)T1E<&5N9&5N8VEE<R!F;W(@<&5A
M<B\G("X@)&EN9F\M/F=E=%!A8VMA9V4H*2P-"B`@("`@("`@("`@("`@("`@
M("`@)V)O<F1E<B<@/3X@=')U92P-"B`@("`@("`@("`@("`@("`@("`@)VAE
M861L:6YE)R`]/B!A<G)A>2@B4F5Q=6ER960_(BP@(E1Y<&4B+"`B3F%M92(L
M(")296QA=&EO;B(L(")697)S:6]N(BDL#0H@("`@("`@("`@("`@("`@("`@
M("D[#0H-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D9&5P<R!A<R`D9"D@
M>PT*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1;)V]P=&EO;F%L
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&1;)V]P=&EO
M;F%L)UT@/3T@)WEE<R<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<F5Q(#T@)TYO)SL-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<2`]("=997,G
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E<2`]
M("=997,G.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V1E<'-?<F5L7W1R86YS6R1D6R=R
M96PG75TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5L(#T@)'1H
M:7,M/E]D97!S7W)E;%]T<F%N<ULD9%LG<F5L)UU=.PT*("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E
M;"`]("1D6R=R96PG73L-"B`@("`@("`@("`@("`@("`@("`@?0T*#0H@("`@
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V1E<'-?='EP95]T
M<F%N<ULD9%LG='EP92==72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1T>7!E(#T@=6-F:7)S="@D=&AI<RT^7V1E<'-?='EP95]T<F%N<ULD9%LG
M='EP92==72D[#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D='EP92`]("1D6R=T>7!E)UT[#0H@("`@
M("`@("`@("`@("`@("`@('T-"@T*("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&1;)VYA;64G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1N86UE(#T@)&1;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1N86UE(#T@)R<[#0H@
M("`@("`@("`@("`@("`@("`@('T-"@T*("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)&1;)W9E<G-I;VXG72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1V97)S:6]N(#T@)&1;)W9E<G-I;VXG73L-"B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1V
M97)S:6]N(#T@)R<[#0H@("`@("`@("`@("`@("`@("`@('T-"@T*("`@("`@
M("`@("`@("`@("`@("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@D<F5Q+"`D
M='EP92P@)&YA;64L("1R96PL("1V97)S:6]N*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!](&5L<V4@>R`O+R!P86-K86=E+GAM;"`R+C`@
M9&5P96YD96YC:65S(&1I<W!L87D-"B`@("`@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)U!%05(O1&5P96YD96YC>3(N<&AP)SL-"B`@("`@("`@("`@("`@
M("`D9&5P<R`]("1I;F9O+3YG971$97!E;F1E;F-I97,H*3L-"B`@("`@("`@
M("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[
M#0H@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1D97!S*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D9"`](&YE=R!014%27T1E<&5N9&5N8WDR*"1T
M:&ES+3YC;VYF:6<L(&%R<F%Y*"DL("<G*3L-"B`@("`@("`@("`@("`@("`@
M("`@)&1A=&$@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("=C
M87!T:6]N)R`]/B`G1&5P96YD96YC:65S(&9O<B`G("X@)&EN9F\M/F=E=%!A
M8VMA9V4H*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("=B;W)D97(G(#T^
M('1R=64L#0H@("`@("`@("`@("`@("`@("`@("`@("`G:&5A9&QI;F4G(#T^
M(&%R<F%Y*")297%U:7)E9#\B+"`B5'EP92(L(").86UE(BP@)U9E<G-I;VYI
M;F<G+"`G1W)O=7`G*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("D[#0H@
M("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1D97!S(&%S("1T>7!E(#T^
M("1S=6)D*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5Q(#T@*"1T
M>7!E(#T]("=R97%U:7)E9"<I(#\@)UEE<R<@.B`G3F\G.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"1T>7!E(#T]("=G<F]U<"<I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9W)O=7`@/2`D<W5B9%LG871T<FEB
M<R==6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1G<F]U<"`]("<G.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D<W5B9%LP72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<W5B9"`](&%R<F%Y*"1S=6)D*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1S=6)D(&%S("1G<F]U<&$I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D9W)O=7!A(&%S("1D97!T>7!E(#T^("1D
M97!I;F9O*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@D9&5P='EP92`]/2`G871T<FEB<R<I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@D9&5P='EP92`]/2`G<&5A<FEN<W1A;&QE<B<I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!T>7!E(#T@
M)W!E87(@26YS=&%L;&5R)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1D97!I;F9O6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&1E<&EN9F\@/2!A<G)A>2@D9&5P:6YF;RD[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&1E<&EN9F\@87,@)&EN
M9BD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YA
M;64@/2`G)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D:6YF6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%L:6%S(#T@)')E9RT^8VAA
M;FYE;$%L:6%S*"1I;F9;)V-H86YN96PG72D[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"$D86QI87,I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%L:6%S
M(#T@)RAC:&%N;F5L/RD@)R`N)&EN9ELG8VAA;FYE;"==.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F%M92`]("1A;&EA<R`N
M("<O)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D:6YF6R=N86UE)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&YA;64@+CT@)&EN9ELG;F%M92==.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T
M*"1I;F9;)W!A='1E<FXG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D;F%M92`N/2`D:6YF6R=P871T97)N)UT[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE
M("X]("<G.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1I;F9;)W5R:2==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1N86UE("X]("<@6R<@+B`D:6YF6R=U<FDG72`N
M("`G72<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&EN9ELG8V]N9FQI8W1S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'9E<B`]("=C;VYF;&EC=',G.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F5R(#T@
M)&0M/E]G971%>'1R85-T<FEN9R@D:6YF*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1D871A6R=D871A)UU;72`](&%R<F%Y*"1R97$L('5C
M9FER<W0H)&1E<'1Y<&4I+"`D;F%M92P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=F5R+"`D9W)O=7`I.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?0T*#0H@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&1A
M=&$L("1C;VUM86YD*3L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M("`@("!]#0H-"B`@("`@("`@+R\@1F%L;&)A8VL-"B`@("`@("`@)'1H:7,M
M/G5I+3YO=71P=71$871A*")4:&ES('!A8VMA9V4@9&]E<R!N;W0@:&%V92!A
M;GD@9&5P96YD96YC:65S+B(L("1C;VUM86YD*3L-"B`@("!]#0H-"B`@("`O
M+R!]?7T-"B`@("`O+R![>WL@9&]3:6=N*"D-"@T*("`@(&9U;F-T:6]N(&1O
M4VEG;B@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@
M("`@("!R97%U:7)E7V]N8V4@)U-Y<W1E;2YP:'`G.PT*("`@("`@("!R97%U
M:7)E7V]N8V4@)T%R8VAI=F4O5&%R+G!H<"<[#0H@("`@("`@("\O('-H;W5L
M9"!M;W9E(&UO<W0@;V8@=&AI<R!C;V1E(&EN=&\@4$5!4E]086-K86=E<@T*
M("`@("`@("`O+R!S;R!I="=L;"!B92!E87-Y('1O(&EM<&QE;65N="`B<&5A
M<B!P86-K86=E("TM<VEG;B(-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US
M*2`A/2`Q*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(F)A9"!P87)A;65T97(H<RDL('1R>2!<(FAE;'`@)&-O;6UA;F1<(B(I
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A9FEL95]E>&ES=',H)'!A<F%M
M<ULP72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B9FEL92!D;V5S(&YO="!E>&ES=#H@)'!A<F%M<ULP72(I.PT*("`@("`@
M("!]#0H@("`@("`@("1O8FH@/2`D=&AI<RT^9V5T4&%C:V%G949I;&4H)'1H
M:7,M/F-O;F9I9RP@)'1H:7,M/E]D96)U9RD[#0H@("`@("`@("1I;F9O(#T@
M)&]B:BT^9G)O;51G>D9I;&4H)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].
M3U)-04PI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD[
M#0H@("`@("`@('T-"B`@("`@("`@)'1A<B`](&YE=R!!<F-H:79E7U1A<B@D
M<&%R86US6S!=*3L-"B`@("`@("`@)'1M<&1I<B`](%-Y<W1E;3HZ;6MT96UP
M*"<M9"!P96%R<VEG;B<I.PT*("`@("`@("!I9B`H(21T87(M/F5X=')A8W1,
M:7-T*"=P86-K86=E,BYX;6P@<&%C:V%G92YS:6<G+"`D=&UP9&ER*2D@>PT*
M("`@("`@("`@("`@:68@*"$D=&%R+3YE>'1R86-T3&ES="@G<&%C:V%G92YX
M;6P@<&%C:V%G92YS:6<G+"`D=&UP9&ER*2D@>PT*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B9F%I;&5D('1O(&5X=')A8W0@
M=&%R(&9I;&4B*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H9FEL95]E>&ES=',H(B1T;7!D:7(O<&%C:V%G92YS:6<B*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")P86-K86=E
M(&%L<F5A9'D@<VEG;F5D(BD[#0H@("`@("`@('T-"B`@("`@("`@)'!A8VMA
M9V5X;6P@/2`G<&%C:V%G92YX;6PG.PT*("`@("`@("!I9B`H9FEL95]E>&ES
M=',H(B1T;7!D:7(O<&%C:V%G93(N>&UL(BDI('L-"B`@("`@("`@("`@("1P
M86-K86=E>&UL(#T@)W!A8VMA9V4R+GAM;"<[#0H@("`@("`@('T-"B`@("`@
M("`@0'5N;&EN:R@B)'1M<&1I<B]P86-K86=E+G-I9R(I.PT*("`@("`@("`D
M:6YP=70@/2`D=&AI<RT^=6DM/G5S97)$:6%L;V<H)&-O;6UA;F0L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G1VYU
M4$<@4&%S<W!H<F%S92<I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)W!A<W-W;W)D)RDI.PT*("`@("`@("`D9W!G
M(#T@<&]P96XH(F=P9R`M+6)A=&-H("TM<&%S<W!H<F%S92UF9"`P("TM87)M
M;W(@+2UD971A8V@M<VEG;B`M+6]U='!U="`D=&UP9&ER+W!A8VMA9V4N<VEG
M("1T;7!D:7(O)'!A8VMA9V5X;6P@,CXO9&5V+VYU;&PB+"`B=R(I.PT*("`@
M("`@("!I9B`H(21G<&<I('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@B9W!G(&-O;6UA;F0@9F%I;&5D(BD[#0H@("`@("`@('T-
M"B`@("`@("`@9G=R:71E*"1G<&<L("(D:6YP=71;,%U<;B(I.PT*("`@("`@
M("!I9B`H<&-L;W-E*"1G<&<I('Q\("%F:6QE7V5X:7-T<R@B)'1M<&1I<B]P
M86-K86=E+G-I9R(I*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H(F=P9R!S:6=N(&9A:6QE9"(I.PT*("`@("`@("!]#0H@("`@
M("`@("1T87(M/F%D9$UO9&EF>2@B)'1M<&1I<B]P86-K86=E+G-I9R(L("<G
M+"`D=&UP9&ER*3L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H-"B`@("`O*BH-"B`@("`@*B!&;W(@=6YI="!T97-T:6YG
M('!U<G!O<V5S#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F=E=$EN<W1A;&QE
M<B@F)'5I*0T*("`@('L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%
M05)?26YS=&%L;&5R)RDI('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G
M4$5!4B]);G-T86QL97(N<&AP)SL-"B`@("`@("`@?0T*("`@("`@("`D82`]
M("9N97<@4$5!4E]);G-T86QL97(H)'5I*3L-"B`@("`@("`@<F5T=7)N("1A
M.PT*("`@('T-"B`@("`-"B`@("`O*BH-"B`@("`@*B!&;W(@=6YI="!T97-T
M:6YG('!U<G!O<V5S#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F=E=$-O;6UA
M;F1086-K86=I;F<H)B1U:2P@)B1C;VYF:6<I#0H@("`@>PT*("`@("`@("!I
M9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]#;VUM86YD7U!A8VMA9VEN9R<I*2![
M#0H@("`@("`@("`@("!`:6YC;'5D95]O;F-E("=014%2+T-O;6UA;F0O4&%C
M:V%G:6YG+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@#0H@("`@("`@(&EF
M("AC;&%S<U]E>&ES=',H)U!%05)?0V]M;6%N9%]086-K86=I;F<G*2D@>PT*
M("`@("`@("`@("`@)&$@/2`F;F5W(%!%05)?0V]M;6%N9%]086-K86=I;F<H
M)'5I+"`D8V]N9FEG*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("1A(#T@;G5L;#L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&$[#0H@
M("`@?0T*#0H@("`@+R\@>WM[(&1O36%K95)032@I#0H-"B`@("!F=6YC=&EO
M;B!D;TUA:V524$TH)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@
M('L-"B`@("`@("`@<F5Q=6ER95]O;F-E("=3>7-T96TN<&AP)SL-"B`@("`@
M("`@<F5Q=6ER95]O;F-E("=!<F-H:79E+U1A<BYP:'`G.PT*#0H@("`@("`@
M("\O($-H96-K('1O('-E92!I9B!014%27T-O;6UA;F1?4&%C:V%G:6YG(&ES
M(&EN<W1A;&QE9"P@86YD#0H@("`@("`@("\O('1R86YS<&%R96YT;'D@<W=I
M=&-H('1O('5S92!T:&4@(FUA:V4M<G!M+7-P96,B(&-O;6UA;F0@9G)O;2!I
M=`T*("`@("`@("`O+R!I;G-T96%D+"!I9B!I="!D;V5S+B!/=&AE<G=I<V4L
M(&-O;G1I;G5E('1O('5S92!T:&4@;VQD('9E<G-I;VX-"B`@("`@("`@+R\@
M;V8@(FUA:V5R<&TB('-U<'!L:65D('=I=&@@=&AI<R!P86-K86=E("A014%2
M*2X-"B`@("`@("`@)'!A8VMA9VEN9U]C;60@/2`D=&AI<RT^9V5T0V]M;6%N
M9%!A8VMA9VEN9R@D=&AI<RT^=6DL("1T:&ES+3YC;VYF:6<I.PT*("`@("`@
M("!I9B`H)'!A8VMA9VEN9U]C;60@(3T](&YU;&PI('L-"B`@("`@("`@("`@
M("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G4$5!4E]#;VUM86YD7U!A8VMA9VEN
M9R!I<R!I;G-T86QL960[('5S:6YG("<N#0H@("`@("`@("`@("`@("`@)VYE
M=V5R(")M86ME+7)P;2US<&5C(B!C;VUM86YD(&EN<W1E860G*3L-"B`@("`@
M("`@("`@(')E='5R;B`D<&%C:V%G:6YG7V-M9"T^<G5N*"=M86ME+7)P;2US
M<&5C)RP@)&]P=&EO;G,L("1P87)A;7,I.PT*("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"=705).24Y'.B`B
M<&5A<B!M86ME<G!M(B!I<R!N;W<@9&5P<F5C871E9#L@86X@)RX-"B`@("`@
M("`@("`@("`@)VEM<')O=F5D('9E<G-I;VX@:7,@879A:6QA8FQE('9I82`B
M<&5A<B!M86ME+7)P;2US<&5C(BP@=VAI8V@@)RX-"B`@("`@("`@("`@("`@
M)VES(&%V86EL86)L92!B>2!I;G-T86QL:6YG(%!%05)?0V]M;6%N9%]086-K
M86=I;F<G*3L-"B`@("`@("`@?0T*("`@("`@("`-"B`@("`@("`@:68@*'-I
M>F5O9B@D<&%R86US*2`A/2`Q*2![#0H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H(F)A9"!P87)A;65T97(H<RDL('1R>2!<(FAE;'`@
M)&-O;6UA;F1<(B(I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A9FEL95]E
M>&ES=',H)'!A<F%M<ULP72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@B9FEL92!D;V5S(&YO="!E>&ES=#H@)'!A<F%M<ULP
M72(I.PT*("`@("`@("!]#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I
M9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@)'!K9R`]("8D=&AI<RT^9V5T
M4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I9RP@)'1H:7,M/E]D96)U9RD[#0H@
M("`@("`@("1P9B`]("8D<&MG+3YF<F]M06YY1FEL92@D<&%R86US6S!=+"!0
M14%27U9!3$E$051%7TY/4DU!3"D[#0H@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1P9BDI('L-"B`@("`@("`@("`@("1U(#T@)'!F+3YG9715<V5R:6YF
M;R@I.PT*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1U*2D@>PT*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1U(&%S("1E<G(I('L-"B`@("`@("`@("`@
M("`@("`@("`@:68@*&ES7V%R<F%Y*"1E<G(I*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D97)R(#T@)&5R<ELG;65S<V%G92==.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^
M;W5T<'5T1&%T82@D97)R*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M(B1P87)A;7-;,%T@:7,@;F]T(&$@=F%L:60@<&%C:V%G92(I.PT*("`@("`@
M("!]#0H@("`@("`@("1T;7!D:7(@/2!3>7-T96TZ.FUK=&5M<"AA<G)A>2@G
M+60G+"`G<&5A<C)R<&TG*2D[#0H@("`@("`@("1I;G-T<F]O="`](%-Y<W1E
M;3HZ;6MT96UP*&%R<F%Y*"<M9"<L("=P96%R,G)P;2<I*3L-"B`@("`@("`@
M)'1M<"`]("1T:&ES+3YC;VYF:6<M/F=E="@G=F5R8F]S92<I.PT*("`@("`@
M("`D=&AI<RT^8V]N9FEG+3YS970H)W9E<F)O<V4G+"`P*3L-"B`@("`@("`@
M)&EN<W1A;&QE<B`]("1T:&ES+3YG971);G-T86QL97(H)'1H:7,M/G5I*3L-
M"B`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T1O=VYL;V%D97(O4&%C:V%G
M92YP:'`G.PT*("`@("`@("`D<&%C:R`](&YE=R!014%27T1O=VYL;V%D97)?
M4&%C:V%G92@D:6YS=&%L;&5R*3L-"B`@("`@("`@)'!A8VLM/G-E=%!A8VMA
M9V5&:6QE*"1P9BD[#0H@("`@("`@("1P87)A;7-;,%T@/2`F)'!A8VL[#0H@
M("`@("`@("1I;G-T86QL97(M/G-E=$]P=&EO;G,H87)R87DH)VEN<W1A;&QR
M;V]T)R`]/B`D:6YS=')O;W0L#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G;F]D97!S)R`]/B!T<G5E+"`G<V]F="<@/3X@
M=')U92DI.PT*("`@("`@("`D:6YS=&%L;&5R+3YS971$;W=N;&]A9&5D4&%C
M:V%G97,H)'!A<F%M<RD[#0H@("`@("`@("1I;F9O(#T@)&EN<W1A;&QE<BT^
M:6YS=&%L;"@D<&%R86US6S!=+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)VEN<W1A;&QR;V]T)R`]/B`D:6YS=')O;W0L
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M;F]D97!S)R`]/B!T<G5E+"`G<V]F="<@/3X@=')U92DI.PT*("`@("`@("`D
M<&MG9&ER(#T@)'!F+3YG971086-K86=E*"D@+B`G+2<@+B`D<&8M/F=E=%9E
M<G-I;VXH*3L-"B`@("`@("`@)&EN9F];)W)P;5]X;6Q?9&ER)UT@/2`G+W9A
M<B]L:6(O<&5A<B<[#0H@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E="@G=F5R
M8F]S92<L("1T;7`I.PT*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W-P
M96,M=&5M<&QA=&4G72DI('L-"B`@("`@("`@("`@("1S<&5C7W1E;7!L871E
M(#T@)&]P=&EO;G-;)W-P96,M=&5M<&QA=&4G73L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1S<&5C7W1E;7!L871E(#T@)R]H;VUE+VQU8V5R
M+W=O<FLO<&5A<B]S:&%R92]P:'`O9&%T82]014%2+W1E;7!L871E+G-P96,G
M.PT*("`@("`@("!]#0H@("`@("`@("1I;F9O6R=P;W-S:6)L95]C:&%N;F5L
M)UT@/2`G)SL-"B`@("`@("`@)&EN9F];)V5X=')A7V-O;F9I9R==(#T@)R<[
M#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<G!M+7!K9VYA;64G72DI
M('L-"B`@("`@("`@("`@("1R<&U?<&MG;F%M95]F;W)M870@/2`D;W!T:6]N
M<ULG<G!M+7!K9VYA;64G73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@(&EF("@D<&8M/F=E=$-H86YN96PH*2`]/2`G<&5A<BYP:'`N;F5T)R!\
M?"`D<&8M/F=E=$-H86YN96PH*2`]/2`G<&5C;"YP:'`N;F5T)RD@>PT*("`@
M("`@("`@("`@("`@("1A;&EA<R`]("=014%2)SL-"B`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@)&-H86X@/2`F)')E9RT^9V5T0VAA
M;FYE;"@D<&8M/F=E=$-H86YN96PH*2D[#0H@("`@("`@("`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&-H86XI*2![#0H@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D8VAA;BD[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("1A;&EA<R`]("1C:&%N+3YG971!
M;&EA<R@I.PT*("`@("`@("`@("`@("`@("1A;&EA<R`]('-T<G1O=7!P97(H
M)&%L:6%S*3L-"B`@("`@("`@("`@("`@("`D:6YF;ULG<&]S<VEB;&5?8VAA
M;FYE;"==(#T@)'!F+3YG971#:&%N;F5L*"D@+B`G+R<[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`D<G!M7W!K9VYA;65?9F]R;6%T(#T@)&%L:6%S
M("X@)SHZ)7,G.PT*("`@("`@("!]#0H-"B`@("`@("`@)&EN9F];)V5X=')A
M7VAE861E<G,G72`]("<G.PT*("`@("`@("`D:6YF;ULG9&]C7V9I;&5S)UT@
M/2`G)SL-"B`@("`@("`@)&EN9F];)V9I;&5S)UT@/2`G)SL-"B`@("`@("`@
M)&EN9F];)W!A8VMA9V4R>&UL)UT@/2`G)SL-"B`@("`@("`@)&EN9F];)W)P
M;5]P86-K86=E)UT@/2!S<')I;G1F*"1R<&U?<&MG;F%M95]F;W)M870L("1P
M9BT^9V5T4&%C:V%G92@I*3L-"B`@("`@("`@)'-R8V9I;&5S(#T@,#L-"B`@
M("`@("`@9F]R96%C:"`H)&EN9F];)V9I;&5L:7-T)UT@87,@)&YA;64@/3X@
M)&%T='(I('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&%T=');)W)O;&4G
M72DI('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("1N86UE(#T@<')E9U]R97!L86-E*"<A6R\Z7%Q<
M7%TA)RP@)R\G+"`D;F%M92D[#0H@("`@("`@("`@("!I9B`H)&%T=');)W)O
M;&4G72`]/2`G9&]C)RD@>PT*("`@("`@("`@("`@("`@("1I;F9O6R=D;V-?
M9FEL97,G72`N/2`B("1N86UE(CL-"B`@("`@("`@("`@("\O($UA<"!R;VQE
M('1O('1H92!R<&T@=F%R<PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`D8U]P<F5F:7@@/2`G)7M?;&EB9&ER?2]P:'`O<&5A<B<[
M#0H@("`@("`@("`@("`@("`@<W=I=&-H("@D871T<ELG<F]L92==*2![#0H@
M("`@("`@("`@("`@("`@("`@(&-A<V4@)W!H<"<Z#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D<')E9FEX(#T@)&-?<')E9FEX.PT*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@8V%S92`G97AT
M)SH-"B`@("`@("`@("`@("`@("`@("`@("`@("1P<F5F:7@@/2`G)7M?;&EB
M9&ER?2]P:'`G.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL@+R\@6%A8
M(&=O;V0@<&QA8V4_#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@)W-R8R<Z
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D<W)C9FEL97,K*SL-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1P<F5F:7@@/2`G)7M?:6YC;'5D961I<GTO
M<&AP)SL-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[("\O(%A86"!G;V]D
M('!L86-E/PT*("`@("`@("`@("`@("`@("`@("!C87-E("=T97-T)SH-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1P<F5F:7@@/2`B)&-?<')E9FEX+W1E
M<W1S+R(@+B`D<&8M/F=E=%!A8VMA9V4H*3L-"B`@("`@("`@("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@)V1A=&$G.@T*
M("`@("`@("`@("`@("`@("`@("`@("`@)'!R969I>"`]("(D8U]P<F5F:7@O
M9&%T82\B("X@)'!F+3YG971086-K86=E*"D[#0H@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("!C87-E("=S8W)I<'0G
M.@T*("`@("`@("`@("`@("`@("`@("`@("`@)'!R969I>"`]("<E>U]B:6YD
M:7)])SL-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@
M("`@("`@("`@(&1E9F%U;'0Z("\O(&YO;BUS=&%N9&%R9"!R;VQE<PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)'!R969I>"`]("(D8U]P<F5F:7@O)&%T
M=');<F]L95TO(B`N("1P9BT^9V5T4&%C:V%G92@I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)&EN9F];)V5X=')A7V-O;F9I9R==("X]#0H@("`@("`@
M("`@("`@("`@("`@("`@("`B7&X@("`@("`@("UD('LD871T<EMR;VQE77U?
M9&ER/21C7W!R969I>"][)&%T=');<F]L95U](%Q<(CL-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G5T%23DE.1SH@
M<F]L92`B)R`N("1A='1R6R=R;VQE)UT@+B`G(B!U<V5D+"`G("X-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G86YD('=I;&P@8F4@:6YS=&%L;&5D
M(&EN("(G("X@)&-?<')E9FEX("X@)R\G("X@)&%T=');)W)O;&4G72`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)R\G("X@)'!F+3YG971086-K
M86=E*"D@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("<@+2!H86YD
M+65D:70@=&AE(&9I;F%L("YS<&5C(&EF('1H:7,@:7,@=W)O;F<G+"`D8V]M
M;6%N9"D[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`D;F%M92`]('-T<E]R97!L86-E
M*"=<7"<L("<O)RP@)&YA;64I.PT*("`@("`@("`@("`@("`@("1I;F9O6R=F
M:6QE<R==("X]("(D<')E9FEX+R1N86UE7&XB.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(&EF("@D<W)C9FEL97,@/B`P*2![#0H@("`@
M("`@("`@("!R97%U:7)E7V]N8V4@)T]3+T=U97-S+G!H<"<[#0H@("`@("`@
M("`@("`D;W,@/2!N97<@3U-?1W5E<W,[#0H@("`@("`@("`@("`D87)C:"`]
M("1O<RT^9V5T0W!U*"D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D87)C:"`]("=N;V%R8V@G.PT*("`@("`@("!]#0H@("`@("`@("1C9F<@
M/2!A<G)A>2@G;6%S=&5R7W-E<G9E<B<L("=P:'!?9&ER)RP@)V5X=%]D:7(G
M+"`G9&]C7V1I<B<L#0H@("`@("`@("`@("`@("`@("`@("`G8FEN7V1I<B<L
M("=D871A7V1I<B<L("=T97-T7V1I<B<I.PT*("`@("`@("!F;W)E86-H("@D
M8V9G(&%S("1K*2![#0H@("`@("`@("`@("!I9B`H)&L@/3T@)VUA<W1E<E]S
M97)V97(G*2![#0H@("`@("`@("`@("`@("`@)&-H86X@/2`D<F5G+3YG971#
M:&%N;F5L*"1P9BT^9V5T0VAA;FYE;"@I*3L-"B`@("`@("`@("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D8VAA;BDI('L-"B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1C:&%N*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&EN9F];)&M=(#T@)&-H86XM
M/F=E=%-E<G9E<B@I.PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)&EN9F];)&M=(#T@)'1H:7,M/F-O
M;F9I9RT^9V5T*"1K*3L-"B`@("`@("`@?0T*("`@("`@("`D:6YF;ULG87)C
M:"==(#T@)&%R8V@[#0H@("`@("`@("1F<"`]($!F;W!E;B@D<W!E8U]T96UP
M;&%T92P@(G(B*3L-"B`@("`@("`@:68@*"$D9G`I('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8V]U;&0@;F]T(&]P96X@4E!-
M('-P96,@9FEL92!T96UP;&%T92`D<W!E8U]T96UP;&%T93H@)'!H<%]E<G)O
M<FUS9R(I.PT*("`@("`@("!]#0H@("`@("`@("1I;F9O6R=P86-K86=E)UT@
M/2`D<&8M/F=E=%!A8VMA9V4H*3L-"B`@("`@("`@)&EN9F];)W9E<G-I;VXG
M72`]("1P9BT^9V5T5F5R<VEO;B@I.PT*("`@("`@("`D:6YF;ULG<F5L96%S
M95]L:6-E;G-E)UT@/2`D<&8M/F=E=$QI8V5N<V4H*3L-"B`@("`@("`@:68@
M*"1P9BT^9V5T1&5P<R@I*2![#0H@("`@("`@("`@("!I9B`H)'!F+3YG9710
M86-K86=E>&UL5F5R<VEO;B@I(#T]("<Q+C`G*2![#0H@("`@("`@("`@("`@
M("`@)')E<75I<F5S(#T@)&-O;F9L:6-T<R`](&%R<F%Y*"D[#0H@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)'!F+3YG971$97!S*"D@87,@)&1E<"D@>PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG;W!T:6]N86PG
M72D@)B8@)&1E<%LG;W!T:6]N86PG72`]/2`G>65S)RD@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"1D97!;)W1Y<&4G72`A/2`G
M<&MG)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1D97!;)V-H86YN96PG72D@)B8@)&1E<%LG8VAA;FYE;"==("$]
M("=P96%R+G!H<"YN970G("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D97!;)V-H86YN96PG72`A/2`G<&5C;"YP:'`N;F5T)RD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&-H86X@/2`F)')E9RT^9V5T0VAA;FYE;"@D
M9&5P6R=C:&%N;F5L)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&-H86XI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1C:&%N*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1P86-K86=E(#T@<W1R=&]U<'!E<B@D8VAA;BT^9V5T06QI87,H*2D@
M+B`G.CHG("X@)&1E<%LG;F%M92==.PT*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V4@/2`G
M4$5!4CHZ)R`N("1D97!;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`D=')A;G,@/2!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`@("`@("`@("<^)R`]/B`G/B<L#0H@("`@("`@("`@("`@
M("`@("`@("`@("`G/"<@/3X@)SPG+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@)SX])R`]/B`G/CTG+`T*("`@("`@("`@("`@("`@("`@("`@("`@)SP]
M)R`]/B`G/#TG+`T*("`@("`@("`@("`@("`@("`@("`@("`@)STG(#T^("<]
M)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("=G="<@/3X@)SXG+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@)VQT)R`]/B`G/"<L#0H@("`@("`@("`@
M("`@("`@("`@("`@("`G9V4G(#T^("<^/2<L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`G;&4G(#T^("<\/2<L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`G97$G(#T^("<])RP-"B`@("`@("`@("`@("`@("`@("`@*3L-"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1D97!;)W)E;"==(#T]("=H87,G*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D<F5Q=6ER97-;72`]("1P86-K86=E
M.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&1E<%LG<F5L)UT@
M/3T@)VYO="<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C;VYF;&EC
M='-;72`]("1P86-K86=E.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H)&1E<%LG<F5L)UT@/3T@)VYE)RD@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)&-O;F9L:6-T<UM=(#T@)'!A8VMA9V4@+B`G(#T@)R`N("1D97!;
M)W9E<G-I;VXG73L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES
M<V5T*"1T<F%N<ULD9&5P6R=R96PG75TI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5Q=6ER97-;72`]("1P86-K86=E("X@)R`G("X@)'1R86YS
M6R1D97!;)W)E;"==72`N("<@)R`N("1D97!;)W9E<G-I;VXG73L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!I9B`H8V]U;G0H)')E<75I<F5S*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`D:6YF;ULG97AT<F%?:&5A9&5R<R==("X]("=297%U:7)E<SH@
M)R`N(&EM<&QO9&4H)RP@)RP@)')E<75I<F5S*2`N(")<;B([#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AC;W5N="@D8V]N9FQI
M8W1S*2D@>PT*("`@("`@("`@("`@("`@("`@("`D:6YF;ULG97AT<F%?:&5A
M9&5R<R==("X]("=#;VYF;&EC=',Z("<@+B!I;7!L;V1E*"<L("<L("1C;VYF
M;&EC=',I("X@(EQN(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1I;F9O6R=P86-K86=E,GAM
M;"==(#T@)S(G.R`O+R!T96QL('1H92!S<&5C('1O('5S92!P86-K86=E,BYX
M;6P-"B`@("`@("`@("`@("`@("`D<F5Q=6ER97,@/2`D8V]N9FQI8W1S(#T@
M87)R87DH*3L-"B`@("`@("`@("`@("`@("`D9&5P<R`]("1P9BT^9V5T1&5P
M<RAT<G5E*3L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<'-;)W)E
M<75I<F5D)UU;)W!A8VMA9V4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D9&5P<ULG<F5Q=6ER960G75LG<&%C:V%G92==6S!=*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&1E<'-;)W)E<75I<F5D)UU;
M)W!A8VMA9V4G72`](&%R<F%Y*"1D97!S6R=R97%U:7)E9"==6R=P86-K86=E
M)UTI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1D97!S6R=R97%U:7)E9"==6R=P86-K86=E)UT@87,@
M)&1E<"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1D97!;)V-H
M86YN96PG72`A/2`G<&5A<BYP:'`N;F5T)R`F)B`@)&1E<%LG8VAA;FYE;"==
M("$]("=P96-L+G!H<"YN970G*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&-H86X@/2`F)')E9RT^9V5T0VAA;FYE;"@D9&5P6R=C:&%N;F5L
M)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1C:&%N*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&-H86XI.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&%C:V%G92`]('-T<G1O=7!P97(H)&-H86XM/F=E=$%L:6%S
M*"DI("X@)SHZ)R`N("1D97!;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!A8VMA9V4@/2`G4$5!4CHZ)R`N("1D97!;)VYA;64G73L-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D9&5P6R=C;VYF;&EC=',G72D@)B8@*&ES<V5T*"1D97!;)VUI
M;B==*2!\?`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:7-S970H
M)&1E<%LG;6%X)UTI*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D97!R86YG92`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1D97!;)VUI;B==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9&5P<F%N9V5;72`](&%R<F%Y*"1D97!;
M)VUI;B==+"<^/2<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG
M;6%X)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D
M97!R86YG95M=(#T@87)R87DH)&1E<%LG;6%X)UTL("<\/2<I.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1D97!;
M)V5X8VQU9&4G72D@?'P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(6ES<V5T*"1D97!;)V5X8VQU9&4G75LP72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!;)V5X8VQU9&4G
M72`](&%R<F%Y*"1D97!;)V5X8VQU9&4G72D[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*&-O=6YT*"1D97!R86YG92DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1E>&-L(#T@)&1E<%LG97AC;'5D92==
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@8VAA
M;F=E(#X]('1O(#X@:68@97AC;'5D:6YG('1H92!M:6X@=F5R<VEO;@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@8VAA;F=E(#P]
M('1O(#P@:68@97AC;'5D:6YG('1H92!M87@@=F5R<VEO;@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R*"1I(#T@,#L@)&D@/"!C
M;W5N="@D97AC;"D[("1I*RLI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<')A;F=E6S!=*2`F)@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1E>&-L6R1I72`]/2`D9&5P<F%N9V5;,%U;,%TI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<')A;F=E6S!=
M6S%=(#T@)SPG.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!U;G-E="@D9&5P6R=E>&-L=61E)UU;)&E=*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D
M97!R86YG95LQ72D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D97AC;%LD:5T@/3T@)&1E<')A;F=E6S%=6S!=
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1D97!R86YG95LQ75LQ72`]("<^)SL-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)&1E<%LG97AC;'5D
M92==6R1I72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AC;W5N="@D9&5P6R=E>&-L
M=61E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9&5P6R=E>&-L=61E)UT@/2!A<G)A>5]V86QU97,H)&1E<%LG97AC;'5D
M92==*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N
M97=D97!R86YG92`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!R96UO=F4@97AC;'5D97,@=&AA="!A<F4@;W5T
M<VED92!T:&4@97AI<W1I;F<@<F%N9V4-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1D97!;
M)V5X8VQU9&4G72D[("1I*RLI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)&1E<%LG97AC;'5D92==6R1I72`\("1D
M97!;)VUI;B==('Q\#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&1E<%LG97AC;'5D92==6R1I72`^("1D97!;)VUA
M>"==*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('5N<V5T*"1D97!;)V5X8VQU9&4G75LD:5TI.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1D97!;)V5X8VQU9&4G72`](&%R<F%Y7W9A
M;'5E<R@D9&5P6R=E>&-L=61E)UTI.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=7-O<G0H)&1E<%LG97AC;'5D92==+"`G=F5R<VEO
M;E]C;VUP87)E)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!T86ME('1H92!R96UA:6YI;F<@97AC;'5D97,@86YD#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!S<&QI="!T:&4@
M9&5P96YD96YC>2!I;G1O('-U8BUR86YG97,-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1L87-T;6EN(#T@)&1E<')A;F=E6S!=.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`]
M(#`[("1I(#P@8V]U;G0H)&1E<%LG97AC;'5D92==*2`M(#$[("1I*RLI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F5W
M9&5P<F%N9V5;72`]("<H)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P86-K86=E("X@(B![)&QA<W1M:6Y;,5U]
M('LD;&%S=&UI;ELP77T@86YD("(@+@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<&%C:V%G92`N("<@/"`G("X@)&1E
M<%LG97AC;'5D92==6R1I72`N("<I)SL-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D;&%S=&UI;B`](&%R<F%Y*"1D97!;)V5X
M8VQU9&4G75LD:5TL("<^)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&1E<%LG;6%X)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YE=V1E<')A;F=E6UT@/2`G
M*"<@+B`D<&%C:V%G92`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("(@>R1L87-T;6EN6S%=?2![)&QA<W1M:6Y;,%U]
M(&%N9"`B("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!A8VMA9V4@+B`G(#P@)R`N("1D97!;)VUA>"==("X@)RDG
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;F9L:6-T<UM=
M(#T@:6UP;&]D92@G(&]R("<L("1D97!R86YG92D[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D8V]N9FQI8W1S6UT@/2`D<&%C:V%G92`N
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(B![
M)&1E<')A;F=E6S!=6S%=?2![)&1E<')A;F=E6S!=6S!=?2(@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("AI<W-E="@D9&5P
M<F%N9V5;,5TI(#\@#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(B!A;F0@)'!A8VMA9V4@>R1D97!R86YG95LQ75LQ77T@>R1D
M97!R86YG95LQ75LP77TB#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`G)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1D97!;)VUI;B==*2`F)B`A:7-S970H)&1E<%LG;6%X)UTI("8F
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`A:7-S970H)&1E<%LG
M97AC;'5D92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D9&5P6R=C;VYF;&EC=',G72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&-O;F9L:6-T<UM=(#T@)'!A8VMA9V4[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)')E<75I<F5S6UT@/2`D<&%C:V%G
M93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D9&5P6R=M:6XG72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)')E<75I<F5S6UT@/2`D<&%C:V%G92`N
M("<@/CT@)R`N("1D97!;)VUI;B==.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&1E<%LG;6%X)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1R97%U:7)E<UM=(#T@)'!A8VMA9V4@+B`G(#P]("<@+B`D9&5P
M6R=M87@G73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)V5X8VQU
M9&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5X
M(#T@)&1E<%LG97AC;'5D92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H(6ES7V%R<F%Y*"1E>"DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1E>"`](&%R<F%Y*"1E>"D[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&5X(&%S("1V97(I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VYF;&EC='-;
M72`]("1P86-K86=E("X@)R`]("<@+B`D=F5R.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G
M07)C:&EV92]487(N<&AP)SL-"B`@("`@("`@("`@("`@("`@("`@)'1A<B`]
M(&YE=R!!<F-H:79E7U1A<B@D<&8M/F=E=$%R8VAI=F5&:6QE*"DI.PT*("`@
M("`@("`@("`@("`@("`@("`D=&%R+3YP=7-H17)R;W)(86YD;&EN9RA014%2
M7T524D]27U)%5%523BD[#0H@("`@("`@("`@("`@("`@("`@("1A(#T@)'1A
M<BT^97AT<F%C=$EN4W1R:6YG*"=P86-K86=E,BYX;6PG*3L-"B`@("`@("`@
M("`@("`@("`@("`@)'1A<BT^<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H)&$@/3T](&YU;&P@?'P@4$5!4CHZ:7-%<G)O
M<B@D82DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R=P86-K
M86=E,GAM;"==(#T@)R<[#0H@("`@("`@("`@("`@("`@("`@("`@("`O+R!T
M:&ES(&1O97-N)W0@:&%V92!A('!A8VMA9V4N>&UL('9E<G-I;VX@,2XP#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D<F5Q=6ER97-;72`]("=014%2.CI0
M14%2(#X]("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!S
M6R=R97%U:7)E9"==6R=P96%R:6YS=&%L;&5R)UU;)VUI;B==.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("AC;W5N
M="@D<F5Q=6ER97,I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D:6YF
M;ULG97AT<F%?:&5A9&5R<R==("X]("=297%U:7)E<SH@)R`N(&EM<&QO9&4H
M)RP@)RP@)')E<75I<F5S*2`N(")<;B([#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1C;VYF;&EC=',I
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULG97AT<F%?:&5A
M9&5R<R==("X]("=#;VYF;&EC=',Z("<@+B!I;7!L;V1E*"<L("<L("1C;VYF
M;&EC=',I("X@(EQN(CL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@("`@
M("`@("\O(')E;6]V92!T:&4@=')A:6QI;F<@;F5W;&EN90T*("`@("`@("`D
M:6YF;ULG97AT<F%?:&5A9&5R<R==(#T@=')I;2@D:6YF;ULG97AT<F%?:&5A
M9&5R<R==*3L-"B`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G9FEL95]G
M971?8V]N=&5N=',G*2D@>PT*("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@
M("`@("`@("`@("`D<W!E8U]C;VYT96YT<R`]('!R96=?<F5P;&%C92@G+T`H
M6V$M>C`M.5\M72LI0"]E)RP@)R1I;F9O6R)<,2)=)RP-"B`@("`@("`@("`@
M("`@("!F:6QE7V=E=%]C;VYT96YT<R@D<W!E8U]T96UP;&%T92DI.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'-P96-?8V]N=&5N=',@/2!P
M<F5G7W)E<&QA8V4H)R]`*%MA+7HP+3E?+5TK*4`O92<L("<D:6YF;ULB7#$B
M72<L#0H@("`@("`@("`@("`@("`@9G)E860H)&9P+"!F:6QE<VEZ92@D<W!E
M8U]T96UP;&%T92DI*3L-"B`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@
M("`@("!]#0H@("`@("`@("1S<&5C7V9I;&4@/2`B)&EN9F];<G!M7W!A8VMA
M9V5=+21I;F9O6W9E<G-I;VY=+G-P96,B.PT*("`@("`@("`D=W`@/2!F;W!E
M;B@D<W!E8U]F:6QE+"`B=V(B*3L-"B`@("`@("`@:68@*"$D=W`I('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8V]U;&0@;F]T
M('=R:71E(%)032!S<&5C(&9I;&4@)'-P96-?9FEL93H@)'!H<%]E<G)O<FUS
M9R(I.PT*("`@("`@("!]#0H@("`@("`@(&9W<FET92@D=W`L("1S<&5C7V-O
M;G1E;G1S*3L-"B`@("`@("`@9F-L;W-E*"1W<"D[#0H@("`@("`@("1T:&ES
M+3YU:2T^;W5T<'5T1&%T82@B5W)O=&4@4E!-('-P96,@9FEL92`D<W!E8U]F
M:6QE(BP@)&-O;6UA;F0I.PT*#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N(&1O0V]N=F5R="@D8V]M;6%N9"P@)&]P=&EO
M;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@("`D<&%C:V%G97AM;"`](&ES
M<V5T*"1P87)A;7-;,%TI(#\@)'!A<F%M<ULP72`Z("=P86-K86=E+GAM;"<[
M#0H@("`@("`@("1N97=P86-K86=E>&UL(#T@:7-S970H)'!A<F%M<ULQ72D@
M/R`D<&%R86US6S%=(#H@9&ER;F%M92@D<&%C:V%G97AM;"D@+@T*("`@("`@
M("`@("`@1$E214-43U)97U-%4$%2051/4B`N("=P86-K86=E,BYX;6PG.PT*
M("`@("`@("`D<&MG(#T@)B1T:&ES+3YG971086-K86=E1FEL92@D=&AI<RT^
M8V]N9FEG+"`D=&AI<RT^7V1E8G5G*3L-"B`@("`@("`@4$5!4CHZ<W1A=&EC
M4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@
M("`D<&8@/2`D<&MG+3YF<F]M4&%C:V%G949I;&4H)'!A8VMA9V5X;6PL(%!%
M05)?5D%,241!5$5?3D]234%,*3L-"B`@("`@("`@4$5!4CHZ<W1A=&EC4&]P
M17)R;W)(86YD;&EN9R@I.PT*("`@("`@("!I9B`H(5!%05(Z.FES17)R;W(H
M)'!F*2D@>PT*("`@("`@("`@("`@:68@*&ES7V$H)'!F+"`G4$5!4E]086-K
M86=E1FEL95]V,B<I*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO
M=71P=71$871A*"1P86-K86=E>&UL("X@)R!I<R!A;')E861Y(&$@<&%C:V%G
M92YX;6P@=F5R<VEO;B`R+C`G*3L-"B`@("`@("`@("`@("`@("!R971U<FX@
M=')U93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1G96X@/2`F)'!F
M+3YG971$969A=6QT1V5N97)A=&]R*"D[#0H@("`@("`@("`@("`D;F5W<&8@
M/2`F)&=E;BT^=&]6,B@I.PT*("`@("`@("`@("`@)&YE=W!F+3YS971086-K
M86=E9FEL92@D;F5W<&%C:V%G97AM;"D[#0H@("`@("`@("`@("`D9V5N(#T@
M)B1N97=P9BT^9V5T1&5F875L=$=E;F5R871O<B@I.PT*("`@("`@("`@("`@
M4$5!4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]21515
M4DXI.PT*("`@("`@("`@("`@)'-T871E(#T@*&ES<V5T*"1O<'1I;VYS6R=F
M;&%T)UTI(#\@4$5!4E]604Q)1$%415]004-+04=)3D<@.B!014%27U9!3$E$
M051%7TY/4DU!3"D[#0H@("`@("`@("`@("`D<V%V960@/2`D9V5N+3YT;U!A
M8VMA9V5&:6QE*&1I<FYA;64H)&YE=W!A8VMA9V5X;6PI+"`D<W1A=&4L#0H@
M("`@("`@("`@("`@("`@8F%S96YA;64H)&YE=W!A8VMA9V5X;6PI*3L-"B`@
M("`@("`@("`@(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@
M("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1S879E9"DI('L-"B`@("`@
M("`@("`@("`@("!I9B`H:7-?87)R87DH)'-A=F5D+3YG9715<V5R26YF;R@I
M*2D@>PT*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D<V%V960M/F=E
M=%5S97));F9O*"D@87,@)'=A<FYI;F<I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D=V%R;FEN9ULG;65S<V%G
M92==*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)'-A
M=F5D+3YG971-97-S86=E*"DI.PT*("`@("`@("`@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1H:7,M/G5I+3YO
M=71P=71$871A*"=7<F]T92!N97<@=F5R<VEO;B`R+C`@<&%C:V%G92YX;6P@
M=&\@(B<@+B`D<V%V960@+B`G(B<I.PT*("`@("`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I9B`H:7-?87)R
M87DH)'!F+3YG9715<V5R26YF;R@I*2D@>PT*("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1P9BT^9V5T57-E<DEN9F\H*2!A<R`D=V%R;FEN9RD@>PT*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)'=A<FYI
M;F=;)VUE<W-A9V4G72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1P
M9BD[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O+R!]?7T-"GT-"@T*/SX-
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]014%2+T-O;6UA;F0O4&%C:V%G92YX;6P`````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`Q,S4P,P`Q,#4Q-30S,S<T,``P,C(W-C4`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/&-O;6UA
M;F1S('9E<G-I;VX](C$N,"(^#0H@/'!A8VMA9V4^#0H@(#QS=6UM87)Y/D)U
M:6QD(%!A8VMA9V4\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;U!A8VMA9V4\
M+V9U;F-T:6]N/@T*("`\<VAO<G1C=70^<#PO<VAO<G1C=70^#0H@(#QO<'1I
M;VYS/@T*("`@/&YO8V]M<')E<W,^#0H@("`@/'-H;W)T;W!T/EH\+W-H;W)T
M;W!T/@T*("`@(#QD;V,^1&\@;F]T(&=Z:7`@=&AE('!A8VMA9V4@9FEL93PO
M9&]C/@T*("`@/"]N;V-O;7!R97-S/@T*("`@/'-H;W=N86UE/@T*("`@(#QS
M:&]R=&]P=#YN/"]S:&]R=&]P=#X-"B`@("`\9&]C/E!R:6YT('1H92!N86UE
M(&]F('1H92!P86-K86=E9"!F:6QE+CPO9&]C/@T*("`@/"]S:&]W;F%M93X-
M"B`@/"]O<'1I;VYS/@T*("`\9&]C/EMD97-C9FEL95T@6V1E<V-F:6QE,ET-
M"D-R96%T97,@82!014%2('!A8VMA9V4@9G)O;2!I=',@9&5S8W)I<'1I;VX@
M9FEL92`H=7-U86QL>2!C86QL960-"G!A8VMA9V4N>&UL*2X@($EF(&$@<V5C
M;VYD('!A8VMA9V5F:6QE(&ES('!A<W-E9"!I;BP@=&AE;@T*=&AE('!A8VMA
M9V5R('=I;&P@8VAE8VL@=&\@;6%K92!S=7)E('1H870@;VYE(&ES(&$@<&%C
M:V%G92YX;6P-"G9E<G-I;VX@,2XP+"!A;F0@=&AE(&]T:&5R(&ES(&$@<&%C
M:V%G92YX;6P@=F5R<VEO;B`R+C`N("!4:&4-"G!A8VMA9V4N>&UL('9E<G-I
M;VX@,2XP('=I;&P@8F4@<V%V960@87,@)G%U;W0[<&%C:V%G92YX;6PF<75O
M=#L@:6X@=&AE(&%R8VAI=F4L#0IA;F0@=&AE(&]T:&5R(&%S("9Q=6]T.W!A
M8VMA9V4R+GAM;"9Q=6]T.R!I;B!T:&4@87)C:&EV929Q=6]T.PT*/"]D;V,^
M#0H@/"]P86-K86=E/@T*(#QP86-K86=E+79A;&ED871E/@T*("`\<W5M;6%R
M>3Y686QI9&%T92!086-K86=E($-O;G-I<W1E;F-Y/"]S=6UM87)Y/@T*("`\
M9G5N8W1I;VX^9&]086-K86=E5F%L:61A=&4\+V9U;F-T:6]N/@T*("`\<VAO
M<G1C=70^<'8\+W-H;W)T8W5T/@T*("`\;W!T:6]N<R`O/@T*("`\9&]C/@T*
M/"]D;V,^#0H@/"]P86-K86=E+79A;&ED871E/@T*(#QC=G-D:69F/@T*("`\
M<W5M;6%R>3Y2=6X@82`F<75O=#MC=G,@9&EF9B9Q=6]T.R!F;W(@86QL(&9I
M;&5S(&EN(&$@<&%C:V%G93PO<W5M;6%R>3X-"B`@/&9U;F-T:6]N/F1O0W9S
M1&EF9CPO9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YC9#PO<VAO<G1C=70^#0H@
M(#QO<'1I;VYS/@T*("`@/'%U:65T/@T*("`@(#QS:&]R=&]P=#YQ/"]S:&]R
M=&]P=#X-"B`@("`\9&]C/D)E('%U:65T/"]D;V,^#0H@("`\+W%U:65T/@T*
M("`@/')E86QL>7%U:65T/@T*("`@(#QS:&]R=&]P=#Y1/"]S:&]R=&]P=#X-
M"B`@("`\9&]C/D)E(')E86QL>2!Q=6EE=#PO9&]C/@T*("`@/"]R96%L;'EQ
M=6EE=#X-"B`@(#QD871E/@T*("`@(#QS:&]R=&]P=#Y$/"]S:&]R=&]P=#X-
M"B`@("`\9&]C/D1I9F8@86=A:6YS="!R979I<VEO;B!O9B!$051%/"]D;V,^
M#0H@("`@/&%R9SY$051%/"]A<F<^#0H@("`\+V1A=&4^#0H@("`\<F5L96%S
M93X-"B`@("`\<VAO<G1O<'0^4CPO<VAO<G1O<'0^#0H@("`@/&1O8SY$:69F
M(&%G86EN<W0@=&%G(&9O<B!P86-K86=E(')E;&5A<V4@4D5,/"]D;V,^#0H@
M("`@/&%R9SY214P\+V%R9SX-"B`@(#PO<F5L96%S93X-"B`@(#QR979I<VEO
M;CX-"B`@("`\<VAO<G1O<'0^<CPO<VAO<G1O<'0^#0H@("`@/&1O8SY$:69F
M(&%G86EN<W0@<F5V:7-I;VX@4D56/"]D;V,^#0H@("`@/&%R9SY2158\+V%R
M9SX-"B`@(#PO<F5V:7-I;VX^#0H@("`\8V]N=&5X=#X-"B`@("`\<VAO<G1O
M<'0^8SPO<VAO<G1O<'0^#0H@("`@/&1O8SY'96YE<F%T92!C;VYT97AT(&1I
M9F8\+V1O8SX-"B`@(#PO8V]N=&5X=#X-"B`@(#QU;FEF:65D/@T*("`@(#QS
M:&]R=&]P=#YU/"]S:&]R=&]P=#X-"B`@("`\9&]C/D=E;F5R871E('5N:69I
M960@9&EF9CPO9&]C/@T*("`@/"]U;FEF:65D/@T*("`@/&EG;F]R92UC87-E
M/@T*("`@(#QS:&]R=&]P=#YI/"]S:&]R=&]P=#X-"B`@("`\9&]C/DEG;F]R
M92!C87-E+"!C;VYS:61E<B!U<'!E<BT@86YD(&QO=V5R+6-A<V4@;&5T=&5R
M<R!E<75I=F%L96YT/"]D;V,^#0H@("`\+VEG;F]R92UC87-E/@T*("`@/&EG
M;F]R92UW:&ET97-P86-E/@T*("`@(#QS:&]R=&]P=#YB/"]S:&]R=&]P=#X-
M"B`@("`\9&]C/DEG;F]R92!C:&%N9V5S(&EN(&%M;W5N="!O9B!W:&ET92!S
M<&%C93PO9&]C/@T*("`@/"]I9VYO<F4M=VAI=&5S<&%C93X-"B`@(#QI9VYO
M<F4M8FQA;FLM;&EN97,^#0H@("`@/'-H;W)T;W!T/D(\+W-H;W)T;W!T/@T*
M("`@(#QD;V,^26=N;W)E(&-H86YG97,@=&AA="!I;G-E<G0@;W(@9&5L971E
M(&)L86YK(&QI;F5S/"]D;V,^#0H@("`\+VEG;F]R92UB;&%N:RUL:6YE<SX-
M"B`@(#QB<FEE9CX-"B`@("`\9&]C/E)E<&]R="!O;FQY('=H971H97(@=&AE
M(&9I;&5S(&1I9F9E<BP@;F\@9&5T86EL<SPO9&]C/@T*("`@/"]B<FEE9CX-
M"B`@(#QD<GDM<G5N/@T*("`@(#QS:&]R=&]P=#YN/"]S:&]R=&]P=#X-"B`@
M("`\9&]C/D1O;B9A<&]S.W0@9&\@86YY=&AI;F<L(&IU<W0@<')E=&5N9#PO
M9&]C/@T*("`@/"]D<GDM<G5N/@T*("`\+V]P=&EO;G,^#0H@(#QD;V,^)FQT
M.W!A8VMA9V4N>&UL)F=T.PT*0V]M<&%R97,@86QL('1H92!F:6QE<R!I;B!A
M('!A8VMA9V4N("!7:71H;W5T(&%N>2!O<'1I;VYS+"!T:&ES#0IC;VUM86YD
M('=I;&P@8V]M<&%R92!T:&4@8W5R<F5N="!C;V1E('=I=&@@=&AE(&QA<W0@
M8VAE8VME9"UI;B!C;V1E+@T*57-I;F<@=&AE("UR(&]R("U2(&]P=&EO;B!Y
M;W4@;6%Y(&-O;7!A<F4@=&AE(&-U<G)E;G0@8V]D92!W:71H('1H870-"F]F
M(&$@<W!E8VEF:6,@<F5L96%S92X-"CPO9&]C/@T*(#PO8W9S9&EF9CX-"B`\
M8W9S=&%G/@T*("`\<W5M;6%R>3Y3970@0U93(%)E;&5A<V4@5&%G/"]S=6UM
M87)Y/@T*("`\9G5N8W1I;VX^9&]#=G-486<\+V9U;F-T:6]N/@T*("`\<VAO
M<G1C=70^8W0\+W-H;W)T8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QQ=6EE=#X-
M"B`@("`\<VAO<G1O<'0^<3PO<VAO<G1O<'0^#0H@("`@/&1O8SY"92!Q=6EE
M=#PO9&]C/@T*("`@/"]Q=6EE=#X-"B`@(#QR96%L;'EQ=6EE=#X-"B`@("`\
M<VAO<G1O<'0^43PO<VAO<G1O<'0^#0H@("`@/&1O8SY"92!R96%L;'D@<75I
M970\+V1O8SX-"B`@(#PO<F5A;&QY<75I970^#0H@("`\<VQI9&4^#0H@("`@
M/'-H;W)T;W!T/D8\+W-H;W)T;W!T/@T*("`@(#QD;V,^36]V92`H<VQI9&4I
M('1A9R!I9B!I="!E>&ES=',\+V1O8SX-"B`@(#PO<VQI9&4^#0H@("`\9&5L
M971E/@T*("`@(#QS:&]R=&]P=#YD/"]S:&]R=&]P=#X-"B`@("`\9&]C/E)E
M;6]V92!T86<\+V1O8SX-"B`@(#PO9&5L971E/@T*("`@/&1R>2UR=6X^#0H@
M("`@/'-H;W)T;W!T/FX\+W-H;W)T;W!T/@T*("`@(#QD;V,^1&]N)F%P;W,[
M="!D;R!A;GET:&EN9RP@:G5S="!P<F5T96YD/"]D;V,^#0H@("`\+V1R>2UR
M=6X^#0H@(#PO;W!T:6]N<SX-"B`@/&1O8SXF;'0[<&%C:V%G92YX;6PF9W0[
M#0I3971S(&$@0U93('1A9R!O;B!A;&P@9FEL97,@:6X@82!P86-K86=E+B`@
M57-E('1H:7,@8V]M;6%N9"!A9G1E<B!Y;W4@:&%V90T*<&%C:V%G960@82!D
M:7-T<FEB=71I;VX@=&%R8F%L;"!W:71H('1H92`F<75O=#MP86-K86=E)G%U
M;W0[(&-O;6UA;F0@=&\@=&%G('=H870-"G)E=FES:6]N<R!O9B!W:&%T(&9I
M;&5S('=E<F4@:6X@=&AA="!R96QE87-E+B`@268@;F5E9"!T;R!F:7@@<V]M
M971H:6YG#0IA9G1E<B!R=6YN:6YG(&-V<W1A9R!O;F-E+"!B=70@8F5F;W)E
M('1H92!T87)B86QL(&ES(')E;&5A<V5D('1O('1H92!P=6)L:6,L#0IU<V4@
M=&AE("9Q=6]T.W-L:61E)G%U;W0[(&]P=&EO;B!T;R!M;W9E('1H92!R96QE
M87-E('1A9RX-"CPO9&]C/@T*(#PO8W9S=&%G/@T*(#QP86-K86=E+61E<&5N
M9&5N8VEE<SX-"B`@/'-U;6UA<GD^4VAO=R!P86-K86=E(&1E<&5N9&5N8VEE
M<SPO<W5M;6%R>3X-"B`@/&9U;F-T:6]N/F1O4&%C:V%G941E<&5N9&5N8VEE
M<SPO9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YP9#PO<VAO<G1C=70^#0H@(#QO
M<'1I;VYS("\^#0H@(#QD;V,^#0I,:7-T(&%L;"!D97!E;F-I97,@=&AE('!A
M8VMA9V4@:&%S+CPO9&]C/@T*(#PO<&%C:V%G92UD97!E;F1E;F-I97,^#0H@
M/'-I9VX^#0H@(#QS=6UM87)Y/E-I9VX@82!P86-K86=E(&1I<W1R:6)U=&EO
M;B!F:6QE/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]3:6=N/"]F=6YC=&EO
M;CX-"B`@/'-H;W)T8W5T/G-I/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,@+SX-
M"B`@/&1O8SXF;'0[<&%C:V%G92UF:6QE)F=T.PT*4VEG;G,@82!P86-K86=E
M(&1I<W1R:6)U=&EO;B`H+G1A<B!O<B`N=&=Z*2!F:6QE('=I=&@@1VYU4$<N
M/"]D;V,^#0H@/"]S:6=N/@T*(#QM86ME<G!M/@T*("`\<W5M;6%R>3Y"=6EL
M9',@86X@4E!-('-P96,@9FEL92!F<F]M(&$@4$5!4B!P86-K86=E/"]S=6UM
M87)Y/@T*("`\9G5N8W1I;VX^9&]-86ME4E!-/"]F=6YC=&EO;CX-"B`@/'-H
M;W)T8W5T/G)P;3PO<VAO<G1C=70^#0H@(#QO<'1I;VYS/@T*("`@/'-P96,M
M=&5M<&QA=&4^#0H@("`@/'-H;W)T;W!T/G0\+W-H;W)T;W!T/@T*("`@(#QA
M<F<^1DE,13PO87)G/@T*("`@(#QD;V,^57-E($9)3$4@87,@4E!-('-P96,@
M9FEL92!T96UP;&%T93PO9&]C/@T*("`@/"]S<&5C+71E;7!L871E/@T*("`@
M/')P;2UP:V=N86UE/@T*("`@(#QS:&]R=&]P=#YP/"]S:&]R=&]P=#X-"B`@
M("`\87)G/D9/4DU!5#PO87)G/@T*("`@(#QD;V,^57-E($9/4DU!5"!A<R!F
M;W)M870@<W1R:6YG(&9O<B!24$T@<&%C:V%G92!N86UE+"`E<R!I<R!R97!L
M86-E9`T*8GD@=&AE(%!%05(@<&%C:V%G92!N86UE+"!D969A=6QT<R!T;R`F
M<75O=#M014%2.CHE<R9Q=6]T.RX\+V1O8SX-"B`@(#PO<G!M+7!K9VYA;64^
M#0H@(#PO;W!T:6]N<SX-"B`@/&1O8SXF;'0[<&%C:V%G92UF:6QE)F=T.PT*
M#0I#<F5A=&5S(&%N(%)032`N<W!E8R!F:6QE(&9O<B!W<F%P<&EN9R!A(%!%
M05(@<&%C:V%G92!I;G-I9&4@86X@4E!-#0IP86-K86=E+B`@26YT96YD960@
M=&\@8F4@=7-E9"!F<F]M('1H92!34$5#4R!D:7)E8W1O<GDL('=I=&@@=&AE
M(%!%05(-"G!A8VMA9V4@=&%R8F%L;"!I;B!T:&4@4T]54D-%4R!D:7)E8W1O
M<GDZ#0H-"B0@<&5A<B!M86ME<G!M("XN+U-/55)#15,O3F5T7U-O8VME="TQ
M+C`N=&=Z#0I7<F]T92!24$T@<W!E8R!F:6QE(%!%05(Z.DYE=%]'96\M,2XP
M+G-P96,-"B0@<G!M("UB8B!014%2.CI.971?4V]C:V5T+3$N,"YS<&5C#0HN
M+BX-"E=R;W1E.B`O=7-R+W-R8R]R961H870O4E!-4R]I,S@V+U!%05(Z.DYE
M=%]3;V-K970M,2XP+3$N:3,X-BYR<&T-"CPO9&]C/@T*(#PO;6%K97)P;3X-
M"B`\8V]N=F5R=#X-"B`@/'-U;6UA<GD^0V]N=F5R="!A('!A8VMA9V4N>&UL
M(#$N,"!T;R!P86-K86=E+GAM;"`R+C`@9F]R;6%T/"]S=6UM87)Y/@T*("`\
M9G5N8W1I;VX^9&]#;VYV97)T/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/F,R
M/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,^#0H@("`\9FQA=#X-"B`@("`\<VAO
M<G1O<'0^9CPO<VAO<G1O<'0^#0H@("`@/&1O8SYD;R!N;W0@8F5A=71I9GD@
M=&AE(&9I;&5L:7-T+CPO9&]C/@T*("`@/"]F;&%T/@T*("`\+V]P=&EO;G,^
M#0H@(#QD;V,^6V1E<V-F:6QE72!;9&5S8V9I;&4R70T*0V]N=F5R=',@82!P
M86-K86=E+GAM;"!I;B`Q+C`@9F]R;6%T(&EN=&\@82!P86-K86=E+GAM;`T*
M:6X@,BXP(&9O<FUA="X@(%1H92!N97<@9FEL92!W:6QL(&)E(&YA;65D('!A
M8VMA9V4R+GAM;"!B>2!D969A=6QT+`T*86YD('!A8VMA9V4N>&UL('=I;&P@
M8F4@=7-E9"!A<R!T:&4@;VQD(&9I;&4@8GD@9&5F875L="X-"E1H:7,@:7,@
M;F]T('1H92!M;W-T(&EN=&5L;&EG96YT(&-O;G9E<G-I;VXL(&%N9"!S:&]U
M;&0@;VYL>2!B90T*=7-E9"!F;W(@875T;VUA=&5D(&-O;G9E<G-I;VX@;W(@
M;&5A<FYI;F<@=&AE(&9O<FUA="X-"CPO9&]C/@T*(#PO8V]N=F5R=#X-"CPO
M8V]M;6%N9',^````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+U!%05(O0V]M;6%N9"]0:6-K;&4N<&AP````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#0P,#8R`#$P-3$U-#,S-S0P`#`R,C8S,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`T*+RHJ
M#0H@*B!014%27T-O;6UA;F1?4&EC:VQE("AP:6-K;&4@8V]M;6%N9"D-"B`J
M#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T
M:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D
M:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@
M86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@
M<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@
M=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`
M8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T
M:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P
M>7)I9VAT("`R,#`U+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@
M("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI
M8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@4&EC:VQE+G!H
M<"QV(#$N-2`R,#`V+S`Q+S`V(#`T.C0W.C,V(&-E;&QO9R!%>'`@)`T*("H@
M0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-
M"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@
M,2XT+C$-"B`J+PT*#0HO*BH-"B`J(&)A<V4@8VQA<W,-"B`J+PT*<F5Q=6ER
M95]O;F-E("=014%2+T-O;6UA;F0O0V]M;6]N+G!H<"<[#0H-"B\J*@T*("H@
M4$5!4B!C;VUM86YD<R!F;W(@;&]G:6XO;&]G;W5T#0H@*@T*("H@0&-A=&5G
M;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@
M("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H
M="`@,C`P-2TR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E
M(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK
M("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`
M<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N
M,0T*("HO#0H-"F-L87-S(%!%05)?0V]M;6%N9%]0:6-K;&4@97AT96YD<R!0
M14%27T-O;6UA;F1?0V]M;6]N#0I[#0H@("`@=F%R("1C;VUM86YD<R`](&%R
M<F%Y*`T*("`@("`@("`G<&EC:VQE)R`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("=S=6UM87)Y)R`]/B`G0G5I;&0@4$5#3"!086-K86=E)RP-"B`@("`@("`@
M("`@("=F=6YC=&EO;B<@/3X@)V1O4&%C:V%G92<L#0H@("`@("`@("`@("`G
M<VAO<G1C=70G(#T^("=P:2<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@
M87)R87DH#0H@("`@("`@("`@("`@("`@)VYO8V]M<')E<W,G(#T^(&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=:)RP-"B`@
M("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)T1O(&YO="!G>FEP('1H92!P
M86-K86=E(&9I;&4G#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@
M("`@("`@("`@)W-H;W=N86UE)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@)W-H;W)T;W!T)R`]/B`G;B<L#0H@("`@("`@("`@("`@("`@("`@
M("=D;V,G(#T^("=0<FEN="!T:&4@;F%M92!O9B!T:&4@<&%C:V%G960@9FEL
M92XG+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@
M("DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G6V1E<V-F:6QE70T*0W)E871E
M<R!A(%!%0TP@<&%C:V%G92!F<F]M(&ET<R!P86-K86=E,BYX;6P@9FEL92X-
M"@T*06X@875T;VUA=&EC(&-O;G9E<G-I;VX@=VEL;"!B92!M861E('1O(&$@
M<&%C:V%G92YX;6P@,2XP(&%N9"!W<FET=&5N(&]U="!T;PT*9&ES:R!I;B!T
M:&4@8W5R<F5N="!D:7)E8W1O<GD@87,@(G!A8VMA9V4N>&UL(BX@($YO=&4@
M=&AA=`T*;VYL>2!S:6UP;&4@<&%C:V%G92YX;6P@,BXP('=I;&P@8F4@8V]N
M=F5R=&5D+B`@<&%C:V%G92YX;6P@,BXP('=I=&@Z#0H-"B`M(&1E<&5N9&5N
M8WD@='EP97,@;W1H97(@=&AA;B!R97%U:7)E9"]O<'1I;VYA;"!014-,('!A
M8VMA9V4O97AT+W!H<"]P96%R:6YS=&%L;&5R#0H@+2!M;W)E('1H86X@;VYE
M(&5X='-R8W)E;&5A<V4-"B`M(&5X=&)I;G)E;&5A<V4L('!H<')E;&5A<V4L
M(&]R(&)U;F1L92!R96QE87-E('1Y<&4-"B`M(&1E<&5N9&5N8WD@9W)O=7!S
M#0H@+2!I9VYO<F4@=&%G<R!I;B!R96QE87-E(&9I;&5L:7-T#0H@+2!T87-K
M<R!O=&AE<B!T:&%N(')E<&QA8V4-"B`M(&-U<W1O;2!R;VQE<PT*#0IW:6QL
M(&-A=7-E('!I8VML92!T;R!F86EL+"!A;F0@;W5T<'5T(&%N(&5R<F]R(&UE
M<W-A9V4N("!)9B!Y;W5R('!A8VMA9V4R+GAM;`T*=7-E<R!A;GD@;V8@=&AE
M<V4@9F5A='5R97,L('EO=2!A<F4@8F5S="!O9F8@=7-I;F<@4$5!4E]086-K
M86=E1FEL94UA;F%G97(@=&\-"F=E;F5R871E(&)O=&@@<&%C:V%G92YX;6PN
M#0HG#0H@("`@("`@("`@("`I+`T*("`@("`@("`I.PT*#0H@("`@+RHJ#0H@
M("`@("H@4$5!4E]#;VUM86YD7U!A8VMA9V4@8V]N<W1R=6-T;W(N#0H@("`@
M("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N(%!%05)?0V]M;6%N9%]0:6-K;&4H)B1U:2P@)B1C;VYF:6<I#0H@("`@
M>PT*("`@("`@("!P87)E;G0Z.E!%05)?0V]M;6%N9%]#;VUM;VXH)'5I+"`D
M8V]N9FEG*3L-"B`@("!]#0H-"@T*("`@("\J*@T*("`@("`J($9O<B!U;FET
M+71E<W1I;F<@96%S90T*("`@("`J#0H@("`@("H@0')E='5R;B!014%27U!A
M8VMA9V5R#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F=E=%!A8VMA9V5R*"D-
M"B`@("![#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27U!A8VMA
M9V5R)RDI('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]086-K
M86=E<BYP:'`G.PT*("`@("`@("!]#0H@("`@("`@("1A(#T@)FYE=R!014%2
M7U!A8VMA9V5R.PT*("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@1F]R('5N:70M=&5S=&EN9R!E87-E#0H@("`@("H-"B`@
M("`@*B!`<&%R86T@4$5!4E]#;VYF:6<@)&-O;F9I9PT*("`@("`J($!P87)A
M;2!B;V]L("1D96)U9PT*("`@("`J($!P87)A;2!S=')I;F=\;G5L;"`D=&UP
M9&ER#0H@("`@("H@0')E='5R;B!014%27U!A8VMA9V5&:6QE#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@)F=E=%!A8VMA9V5&:6QE*"1C;VYF:6<L("1D96)U
M9R`](&9A;'-E+"`D=&UP9&ER(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&EF
M("@A8VQA<W-?97AI<W1S*"=014%27T-O;6UO;B<I*2![#0H@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)U!%05(O0V]M;6]N+G!H<"<[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05(O4&%C:V%G949I;&4N
M<&AP)RDI('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]086-K
M86=E1FEL92YP:'`G.PT*("`@("`@("!]#0H@("`@("`@("1A(#T@)FYE=R!0
M14%27U!A8VMA9V5&:6QE*"1C;VYF:6<L("1D96)U9RP@)'1M<&1I<BD[#0H@
M("`@("`@("1C;VUM;VX@/2!N97<@4$5!4E]#;VUM;VX[#0H@("`@("`@("1C
M;VUM;VXM/G5I(#T@)'1H:7,M/G5I.PT*("`@("`@("`D82T^<V5T3&]G9V5R
M*"1C;VUM;VXI.PT*("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@9&]086-K86=E*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M
M<RD-"B`@("![#0H@("`@("`@("1T:&ES+3YO=71P=70@/2`G)SL-"B`@("`@
M("`@)'!K9VEN9F]F:6QE(#T@:7-S970H)'!A<F%M<ULP72D@/R`D<&%R86US
M6S!=(#H@)W!A8VMA9V4R+GAM;"<[#0H@("`@("`@("1P86-K86=E<B`]("8D
M=&AI<RT^9V5T4&%C:V%G97(H*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&5R<B`]("1T:&ES+3Y?8V]N=F5R=%!A8VMA9V4H)'!K9VEN9F]F:6QE
M*2DI('L-"B`@("`@("`@("`@(')E='5R;B`D97)R.PT*("`@("`@("!]#0H@
M("`@("`@("1C;VUP<F5S<R`](&5M<'1Y*"1O<'1I;VYS6R=N;V-O;7!R97-S
M)UTI(#\@=')U92`Z(&9A;'-E.PT*("`@("`@("`D<F5S=6QT(#T@)'!A8VMA
M9V5R+3YP86-K86=E*"1P:V=I;F9O9FEL92P@)&-O;7!R97-S+"`G<&%C:V%G
M92YX;6PG*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<W5L="DI
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S
M=6QT*3L-"B`@("`@("`@?0T*("`@("`@("`O+R!$;VXG="!W86YT(&]U='!U
M="P@;VYL>2!T:&4@<&%C:V%G92!F:6QE(&YA;64@:G5S="!C<F5A=&5D#0H@
M("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<VAO=VYA;64G72DI('L-"B`@
M("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D<F5S=6QT+"`D8V]M
M;6%N9"D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@7V-O;G9E<G1086-K86=E*"1P86-K86=E>&UL
M*0T*("`@('L-"B`@("`@("`@)'!K9R`]("8D=&AI<RT^9V5T4&%C:V%G949I
M;&4H)'1H:7,M/F-O;F9I9RD[#0H@("`@("`@("1P9C(@/2`F)'!K9RT^9G)O
M;5!A8VMA9V5&:6QE*"1P86-K86=E>&UL+"!014%27U9!3$E$051%7TY/4DU!
M3"D[#0H@("`@("`@(&EF("@A:7-?82@D<&8R+"`G4$5!4E]086-K86=E1FEL
M95]V,B<I*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H)T-A;FYO="!P<F]C97-S("(G("X-"B`@("`@("`@("`@("`@("`D<&%C
M:V%G97AM;"`N("<B+"!I<R!N;W0@82!P86-K86=E+GAM;"`R+C`G*3L-"B`@
M("`@("`@?0T*("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G949I
M;&4O=C$N<&AP)SL-"B`@("`@("`@)'!F(#T@;F5W(%!%05)?4&%C:V%G949I
M;&5?=C$[#0H@("`@("`@("1P9BT^<V5T0V]N9FEG*"1T:&ES+3YC;VYF:6<I
M.PT*("`@("`@("!I9B`H:7-?87)R87DH)'!F,BT^9V5T4&%C:V%G951Y<&4H
M*2`A/2`G97AT<W)C)RDI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@G0V%N;F]T('-A9F5L>2!C;VYV97)T("(G("X@)'!A8VMA
M9V5X;6P@+@T*("`@("`@("`@("`@)R(L(&ES(&YO="!A;B!E>'1E;G-I;VX@
M<V]U<F-E('!A8VMA9V4N("!5<VEN9R!A(%!%05)?4&%C:V%G949I;&5-86YA
M9V5R+6)A<V5D("<@+@T*("`@("`@("`@("`@)W-C<FEP="!I<R!A;B!O<'1I
M;VXG*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-?87)R87DH)'!F,BT^
M9V5T57-E<U)O;&4H*2DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@G0V%N;F]T('-A9F5L>2!C;VYV97)T("(G("X@)'!A8VMA
M9V5X;6P@+@T*("`@("`@("`@("`@)R(L(&-O;G1A:6YS(&-U<W1O;2!R;VQE
M<RX@(%5S:6YG(&$@4$5!4E]086-K86=E1FEL94UA;F%G97(M8F%S960@<V-R
M:7!T(&]R("<@+@T*("`@("`@("`@("`@)W1H92!C;VYV97)T(&-O;6UA;F0@
M:7,@86X@;W!T:6]N)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1P9C(M/F=E=%5S97-487-K*"DI*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-A;FYO="!S869E;'D@8V]N=F5R="`B
M)R`N("1P86-K86=E>&UL("X-"B`@("`@("`@("`@("<B+"!C;VYT86EN<R!C
M=7-T;VT@=&%S:W,N("!5<VEN9R!A(%!%05)?4&%C:V%G949I;&5-86YA9V5R
M+6)A<V5D('-C<FEP="!O<B`G("X-"B`@("`@("`@("`@("=T:&4@8V]N=F5R
M="!C;VUM86YD(&ES(&%N(&]P=&EO;B<I.PT*("`@("`@("!]#0H@("`@("`@
M("1D97!S(#T@)'!F,BT^9V5T1&5P96YD96YC:65S*"D[#0H@("`@("`@(&EF
M("AI<W-E="@D9&5P<ULG9W)O=7`G72DI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V%N;F]T('-A9F5L>2!C;VYV97)T("(G
M("X@)'!A8VMA9V5X;6P@+@T*("`@("`@("`@("`@)R(L(&-O;G1A:6YS(&1E
M<&5N9&5N8WD@9W)O=7!S+B`@57-I;F<@82!014%27U!A8VMA9V5&:6QE36%N
M86=E<BUB87-E9"!S8W)I<'0@)R`N#0H@("`@("`@("`@("`G;W(@=&AE(&-O
M;G9E<G0@8V]M;6%N9"!I<R!A;B!O<'1I;VXG*3L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H:7-S970H)&1E<'-;)W)E<75I<F5D)UU;)W-U8G!A8VMA9V4G
M72D@?'P-"B`@("`@("`@("`@("`@:7-S970H)&1E<'-;)V]P=&EO;F%L)UU;
M)W-U8G!A8VMA9V4G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@G0V%N;F]T('-A9F5L>2!C;VYV97)T("(G("X@)'!A8VMA
M9V5X;6P@+@T*("`@("`@("`@("`@)R(L(&-O;G1A:6YS('-U8G!A8VMA9V4@
M9&5P96YD96YC:65S+B`@57-I;F<@82!014%27U!A8VMA9V5&:6QE36%N86=E
M<BUB87-E9"`@)RX-"B`@("`@("`@("`@("=S8W)I<'0@:7,@86X@;W!T:6]N
M)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!S6R=R97%U
M:7)E9"==6R=O<R==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*"=#86YN;W0@<V%F96QY(&-O;G9E<G0@(B<@+B`D<&%C:V%G
M97AM;"`N#0H@("`@("`@("`@("`G(BP@8V]N=&%I;G,@;W,@9&5P96YD96YC
M:65S+B`@57-I;F<@82!014%27U!A8VMA9V5&:6QE36%N86=E<BUB87-E9"`@
M)RX-"B`@("`@("`@("`@("=S8W)I<'0@:7,@86X@;W!T:6]N)RD[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!S6R=R97%U:7)E9"==6R=A
M<F-H)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H)T-A;FYO="!S869E;'D@8V]N=F5R="`B)R`N("1P86-K86=E>&UL("X-
M"B`@("`@("`@("`@("<B+"!C;VYT86EN<R!A<F-H(&1E<&5N9&5N8VEE<RX@
M(%5S:6YG(&$@4$5!4E]086-K86=E1FEL94UA;F%G97(M8F%S960@("<N#0H@
M("`@("`@("`@("`G<V-R:7!T(&ES(&%N(&]P=&EO;B<I.PT*("`@("`@("!]
M#0H@("`@("`@("1P9BT^<V5T4&%C:V%G92@D<&8R+3YG971086-K86=E*"DI
M.PT*("`@("`@("`D<&8M/G-E=%-U;6UA<GDH)'!F,BT^9V5T4W5M;6%R>2@I
M*3L-"B`@("`@("`@)'!F+3YS971$97-C<FEP=&EO;B@D<&8R+3YG971$97-C
M<FEP=&EO;B@I*3L-"B`@("`@("`@9F]R96%C:"`H)'!F,BT^9V5T36%I;G1A
M:6YE<G,H*2!A<R`D;6%I;G1A:6YE<BD@>PT*("`@("`@("`@("`@)'!F+3YA
M9&1-86EN=&%I;F5R*"1M86EN=&%I;F5R6R=R;VQE)UTL("1M86EN=&%I;F5R
M6R=H86YD;&4G72P-"B`@("`@("`@("`@("`@("`D;6%I;G1A:6YE<ELG;F%M
M92==+"`D;6%I;G1A:6YE<ELG96UA:6PG72D[#0H@("`@("`@('T-"B`@("`@
M("`@)'!F+3YS971697)S:6]N*"1P9C(M/F=E=%9E<G-I;VXH*2D[#0H@("`@
M("`@("1P9BT^<V5T1&%T92@D<&8R+3YG971$871E*"DI.PT*("`@("`@("`D
M<&8M/G-E=$QI8V5N<V4H)'!F,BT^9V5T3&EC96YS92@I*3L-"B`@("`@("`@
M)'!F+3YS9713=&%T92@D<&8R+3YG9713=&%T92@I*3L-"B`@("`@("`@)'!F
M+3YS971.;W1E<R@D<&8R+3YG971.;W1E<R@I*3L-"B`@("`@("`@)'!F+3YA
M9&10:'!$97`H)&1E<'-;)W)E<75I<F5D)UU;)W!H<"==6R=M:6XG72P@)V=E
M)RD[#0H@("`@("`@(&EF("AI<W-E="@D9&5P<ULG<F5Q=6ER960G75LG<&AP
M)UU;)VUA>"==*2D@>PT*("`@("`@("`@("`@)'!F+3YA9&10:'!$97`H)&1E
M<'-;)W)E<75I<F5D)UU;)W!H<"==6R=M87@G72P@)VQE)RD[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!S6R=R97%U:7)E9"==6R=P86-K
M86=E)UTI*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!S6R=R97%U
M:7)E9"==6R=P86-K86=E)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@)&1E
M<'-;)W)E<75I<F5D)UU;)W!A8VMA9V4G72`](&%R<F%Y*"1D97!S6R=R97%U
M:7)E9"==6R=P86-K86=E)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@9F]R96%C:"`H)&1E<'-;)W)E<75I<F5D)UU;)W!A8VMA9V4G72!A<R`D
M9&5P*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P6R=C:&%N
M;F5L)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@G0V%N;F]T('-A9F5L>2!C;VYV97)T("(G("X@)'!A8VMA
M9V5X;6P@+B`G(B<@+@T*("`@("`@("`@("`@("`@("`@("`G(&-O;G1A:6YS
M('5R:2UB87-E9"!D97!E;F1E;F-Y(&]N(&$@<&%C:V%G92X@(%5S:6YG(&$@
M)R`N#0H@("`@("`@("`@("`@("`@("`@("=014%27U!A8VMA9V5&:6QE36%N
M86=E<BUB87-E9"!S8W)I<'0@:7,@86X@;W!T:6]N)RD[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D9&5P6R=C:&%N;F5L)UT@
M(3T@)W!E87(N<&AP+FYE="<@)B8@)&1E<%LG8VAA;FYE;"==("$]("=P96-L
M+G!H<"YN970G*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@G0V%N;F]T('-A9F5L>2!C;VYV97)T("(G("X@)'!A
M8VMA9V5X;6P@+B`G(B<@+@T*("`@("`@("`@("`@("`@("`@("`G(&-O;G1A
M:6YS(&1E<&5N9&5N8WD@;VX@82!N;VXM<W1A;F1A<F0@8VAA;FYE;"!P86-K
M86=E+B`@57-I;F<@82`G("X-"B`@("`@("`@("`@("`@("`@("`@)U!%05)?
M4&%C:V%G949I;&5-86YA9V5R+6)A<V5D('-C<FEP="!I<R!A;B!O<'1I;VXG
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1D97!;)V-O;F9L:6-T<R==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-A;FYO="!S869E;'D@8V]N
M=F5R="`B)R`N("1P86-K86=E>&UL("X@)R(G("X-"B`@("`@("`@("`@("`@
M("`@("`@)R!C;VYT86EN<R!C;VYF;&EC=',@9&5P96YD96YC>2X@(%5S:6YG
M(&$@)R`N#0H@("`@("`@("`@("`@("`@("`@("=014%27U!A8VMA9V5&:6QE
M36%N86=E<BUB87-E9"!S8W)I<'0@:7,@86X@;W!T:6]N)RD[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=E
M>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^
M;W5T<'5T1&%T82@G5T%23DE.1SH@97AC;'5D92!T86=S(&%R92!I9VYO<F5D
M(&EN(&-O;G9E<G-I;VXG*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1D97!;)VUI;B==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D<&8M/F%D9%!A8VMA9V5$97`H)&1E<%LG;F%M92==+"`D
M9&5P6R=M:6XG72P@)V=E)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=M87@G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@)'!F+3YA9&1086-K86=E1&5P*"1D97!;)VYA;64G72P@
M)&1E<%LG;6%X)UTL("=L92<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&1E<'-;
M)W)E<75I<F5D)UU;)V5X=&5N<VEO;B==*2D@>PT*("`@("`@("`@("`@:68@
M*"%I<W-E="@D9&5P<ULG<F5Q=6ER960G75LG97AT96YS:6]N)UU;,%TI*2![
M#0H@("`@("`@("`@("`@("`@)&1E<'-;)W)E<75I<F5D)UU;)V5X=&5N<VEO
M;B==(#T@87)R87DH)&1E<'-;)W)E<75I<F5D)UU;)V5X=&5N<VEO;B==*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1D97!S6R=R
M97%U:7)E9"==6R=E>'1E;G-I;VXG72!A<R`D9&5P*2![#0H@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1D97!;)V-O;F9L:6-T<R==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-A;FYO
M="!S869E;'D@8V]N=F5R="`B)R`N("1P86-K86=E>&UL("X@)R(G("X-"B`@
M("`@("`@("`@("`@("`@("`@)R!C;VYT86EN<R!C;VYF;&EC=',@9&5P96YD
M96YC>2X@(%5S:6YG(&$@)R`N#0H@("`@("`@("`@("`@("`@("`@("=014%2
M7U!A8VMA9V5&:6QE36%N86=E<BUB87-E9"!S8W)I<'0@:7,@86X@;W!T:6]N
M)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G5T%23DE.1SH@97AC;'5D92!T86=S
M(&%R92!I9VYO<F5D(&EN(&-O;G9E<G-I;VXG*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)VUI;B==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`D<&8M/F%D9$5X=&5N<VEO;D1E<"@D
M9&5P6R=N86UE)UTL("1D97!;)VUI;B==+"`G9V4G*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)VUA>"==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<&8M/F%D9$5X=&5N<VEO;D1E
M<"@D9&5P6R=N86UE)UTL("1D97!;)VUA>"==+"`G;&4G*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES<V5T*"1D97!S6R=O<'1I;VYA;"==6R=P86-K86=E)UTI*2![#0H@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!S6R=O<'1I;VYA;"==6R=P86-K
M86=E)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@)&1E<'-;)V]P=&EO;F%L
M)UU;)W!A8VMA9V4G72`](&%R<F%Y*"1D97!S6R=O<'1I;VYA;"==6R=P86-K
M86=E)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H
M)&1E<'-;)V]P=&EO;F%L)UU;)W!A8VMA9V4G72!A<R`D9&5P*2![#0H@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P6R=C:&%N;F5L)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G
M0V%N;F]T('-A9F5L>2!C;VYV97)T("(G("X@)'!A8VMA9V5X;6P@+B`G(B<@
M+@T*("`@("`@("`@("`@("`@("`@("`G(&-O;G1A:6YS('5R:2UB87-E9"!D
M97!E;F1E;F-Y(&]N(&$@<&%C:V%G92X@(%5S:6YG(&$@)R`N#0H@("`@("`@
M("`@("`@("`@("`@("=014%27U!A8VMA9V5&:6QE36%N86=E<BUB87-E9"!S
M8W)I<'0@:7,@86X@;W!T:6]N)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@(&EF("@D9&5P6R=C:&%N;F5L)UT@(3T@)W!E87(N<&AP
M+FYE="<@)B8@)&1E<%LG8VAA;FYE;"==("$]("=P96-L+G!H<"YN970G*2![
M#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@G0V%N;F]T('-A9F5L>2!C;VYV97)T("(G("X@)'!A8VMA9V5X;6P@+B`G
M(B<@+@T*("`@("`@("`@("`@("`@("`@("`G(&-O;G1A:6YS(&1E<&5N9&5N
M8WD@;VX@82!N;VXM<W1A;F1A<F0@8VAA;FYE;"!P86-K86=E+B`@57-I;F<@
M82`G("X-"B`@("`@("`@("`@("`@("`@("`@)U!%05)?4&%C:V%G949I;&5-
M86YA9V5R+6)A<V5D('-C<FEP="!I<R!A;B!O<'1I;VXG*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)V5X
M8VQU9&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO
M=71P=71$871A*"=705).24Y'.B!E>&-L=61E('1A9W,@87)E(&EG;F]R960@
M:6X@8V]N=F5R<VEO;B<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&1E<%LG;6EN)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("1P9BT^861D4&%C:V%G941E<"@D9&5P6R=N86UE)UTL("1D
M97!;)VUI;B==+"`G9V4G+"`G>65S)RD[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=M87@G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@)'!F+3YA9&1086-K86=E1&5P*"1D97!;)VYA
M;64G72P@)&1E<%LG;6%X)UTL("=L92<L("=Y97,G*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&ES<V5T*"1D97!S6R=O<'1I;VYA;"==6R=E>'1E;G-I;VXG72DI('L-"B`@
M("`@("`@("`@(&EF("@A:7-S970H)&1E<'-;)V]P=&EO;F%L)UU;)V5X=&5N
M<VEO;B==6S!=*2D@>PT*("`@("`@("`@("`@("`@("1D97!S6R=O<'1I;VYA
M;"==6R=E>'1E;G-I;VXG72`](&%R<F%Y*"1D97!S6R=O<'1I;VYA;"==6R=E
M>'1E;G-I;VXG72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E
M86-H("@D9&5P<ULG;W!T:6]N86PG75LG97AT96YS:6]N)UT@87,@)&1E<"D@
M>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=E>&-L=61E)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T
M82@G5T%23DE.1SH@97AC;'5D92!T86=S(&%R92!I9VYO<F5D(&EN(&-O;G9E
M<G-I;VXG*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1D97!;)VUI;B==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D<&8M/F%D9$5X=&5N<VEO;D1E<"@D9&5P6R=N86UE)UTL("1D97!;)VUI
M;B==+"`G9V4G+"`G>65S)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=M87@G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@)'!F+3YA9&1%>'1E;G-I;VY$97`H)&1E<%LG;F%M92==
M+"`D9&5P6R=M87@G72P@)VQE)RP@)WEE<R<I.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D8V]N=&5N
M=',@/2`D<&8R+3YG971#;VYT96YT<R@I.PT*("`@("`@("`D<F5L96%S92`]
M("1P9C(M/F=E=%)E;&5A<V5S*"D[#0H@("`@("`@(&EF("AI<W-E="@D<F5L
M96%S97-;,%TI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)T-A;FYO="!S869E;'D@<')O8V5S<R`B)R`N("1P86-K86=E>&UL
M("X@)R(@8V]N=&%I;G,@)R`-"B`@("`@("`@("`@("X@)VUU;'1I<&QE(&5X
M='-R8W)E;&5A<V4@=&%G<RX@(%5S:6YG(&$@4$5!4E]086-K86=E1FEL94UA
M;F%G97(M8F%S960@<V-R:7!T("<@+@T*("`@("`@("`@("`@)V]R('1H92!C
M;VYV97)T(&-O;6UA;F0@:7,@86X@;W!T:6]N)RD[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"1C;VYF:6=O<'1I;VYS(#T@)'!F,BT^9V5T0V]N9FEG=7)E
M3W!T:6]N<R@I*2![#0H@("`@("`@("`@("!F;W)E86-H("@D8V]N9FEG;W!T
M:6]N<R!A<R`D;W!T:6]N*2![#0H@("`@("`@("`@("`@("`@)'!F+3YA9&1#
M;VYF:6=U<F5/<'1I;VXH)&]P=&EO;ELG;F%M92==+"`D;W!T:6]N6R=P<F]M
M<'0G72P-"B`@("`@("`@("`@("`@("`@("`@:7-S970H)&]P=&EO;ELG9&5F
M875L="==*2`_("1O<'1I;VY;)V1E9F%U;'0G72`Z(&9A;'-E*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)')E;&5A
M<V5;)V9I;&5L:7-T)UU;)VEG;F]R92==*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*"=#86YN;W0@<V%F96QY('!R;V-E<W,@
M(B<@+B`D<&%C:V%G97AM;"`N("<B(&-O;G1A:6YS("<@#0H@("`@("`@("`@
M("`N("=I9VYO<F4@=&%G<RX@(%5S:6YG(&$@4$5!4E]086-K86=E1FEL94UA
M;F%G97(M8F%S960@<V-R:7!T(&]R('1H92!C;VYV97)T)R`N#0H@("`@("`@
M("`@("`G(&-O;6UA;F0@:7,@86X@;W!T:6]N)RD[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*&ES<V5T*"1R96QE87-E6R=F:6QE;&ES="==6R=I;G-T86QL
M)UTI("8F#0H@("`@("`@("`@("`@("%I<W-E="@D<F5L96%S95LG9FEL96QI
M<W0G75LG:6YS=&%L;"==6S!=*2D@>PT*("`@("`@("`@("`@)')E;&5A<V5;
M)V9I;&5L:7-T)UU;)VEN<W1A;&PG72`](&%R<F%Y*"1R96QE87-E6R=F:6QE
M;&ES="==6R=I;G-T86QL)UTI.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI
M<W-E="@D8V]N=&5N='-;)V1I<B==6R=A='1R:6)S)UU;)V)A<V5I;G-T86QL
M9&ER)UTI*2![#0H@("`@("`@("`@("`D8F%S96EN<W1A;&QD:7(@/2`D8V]N
M=&5N='-;)V1I<B==6R=A='1R:6)S)UU;)V)A<V5I;G-T86QL9&ER)UT[#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D8F%S96EN<W1A;&QD:7(@
M/2!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES<V5T*"1C;VYT
M96YT<ULG9&ER)UU;)V9I;&4G75LP72DI('L-"B`@("`@("`@("`@("1C;VYT
M96YT<ULG9&ER)UU;)V9I;&4G72`](&%R<F%Y*"1C;VYT96YT<ULG9&ER)UU;
M)V9I;&4G72D[#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)&-O;G1E
M;G1S6R=D:7(G75LG9FEL92==(&%S("1F:6QE*2![#0H@("`@("`@("`@("!I
M9B`H)&)A<V5I;G-T86QL9&ER("8F("%I<W-E="@D9FEL95LG871T<FEB<R==
M6R=B87-E:6YS=&%L;&1I<B==*2D@>PT*("`@("`@("`@("`@("`@("1F:6QE
M6R=A='1R:6)S)UU;)V)A<V5I;G-T86QL9&ER)UT@/2`D8F%S96EN<W1A;&QD
M:7([#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<')O8V5S<T9I;&4@
M/2`D9FEL93L-"B`@("`@("`@("`@('5N<V5T*"1P<F]C97-S1FEL95LG871T
M<FEB<R==*3L-"B`@("`@("`@("`@(&EF("AC;W5N="@D<')O8V5S<T9I;&4I
M*2![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!R;V-E<W-&:6QE(&%S
M("1N86UE(#T^("1T87-K*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@D
M;F%M92`A/2`D<&8R+3YG971487-K<TYS*"D@+B`G.G)E<&QA8V4G*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H)T-A;FYO="!S869E;'D@<')O8V5S<R`B)R`N("1P86-K86=E>&UL("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("<B(&-O;G1A:6YS('1A<VMS(&]T
M:&5R('1H86X@<F5P;&%C92X@(%5S:6YG(&$@)R`N#0H@("`@("`@("`@("`@
M("`@("`@("`@("`G4$5!4E]086-K86=E1FEL94UA;F%G97(M8F%S960@<V-R
M:7!T(&ES(&%N(&]P=&EO;BXG*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`D9FEL95LG871T<FEB<R==6R=R97!L86-E
M)UU;72`]("1T87-K.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF("@A:6Y?87)R87DH)&9I;&5;)V%T=')I8G,G
M75LG<F]L92==+"!014%27T-O;6UO;CHZ9V5T1FEL95)O;&5S*"DI*2![#0H@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#86YN
M;W0@<V%F96QY(&-O;G9E<G0@(B<@+B`D<&%C:V%G97AM;"`N#0H@("`@("`@
M("`@("`@("`@)R(L(&-O;G1A:6YS(&-U<W1O;2!R;VQE<RX@(%5S:6YG(&$@
M4$5!4E]086-K86=E1FEL94UA;F%G97(M8F%S960@<V-R:7!T("<@+@T*("`@
M("`@("`@("`@("`@("=O<B!T:&4@8V]N=F5R="!C;VUM86YD(&ES(&%N(&]P
M=&EO;B<I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T
M*"1R96QE87-E6R=F:6QE;&ES="==6R=I;G-T86QL)UTI*2![#0H@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)')E;&5A<V5;)V9I;&5L:7-T)UU;)VEN<W1A
M;&PG72!A<R`D:6YS=&%L;&%S*2![#0H@("`@("`@("`@("`@("`@("`@(&EF
M("@D:6YS=&%L;&%S6R=A='1R:6)S)UU;)VYA;64G72`]/2`D9FEL95LG871T
M<FEB<R==6R=N86UE)UTI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1F
M:6QE6R=A='1R:6)S)UU;)VEN<W1A;&PM87,G72`]("1I;G-T86QL87-;)V%T
M=')I8G,G75LG87,G73L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1P9BT^
M861D1FEL92@G+R<L("1F:6QE6R=A='1R:6)S)UU;)VYA;64G72P@)&9I;&5;
M)V%T=')I8G,G72D[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1P9C(M/F=E
M=$-H86YG94QO9R@I*2![#0H@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U
M=$1A=&$H)U=!4DY)3D<Z(&-H86YG96QO9R!I<R!N;W0@=')A;G-L871E9"!T
M;R!P86-K86=E+GAM;"`G("X-"B`@("`@("`@("`@("`@("`G,2XP+"!U<V4@
M4$5!4E]086-K86=E1FEL94UA;F%G97(M8F%S960@<V-R:7!T(&EF('EO=2!N
M965D(&-H86YG96QO9RTG("X-"B`@("`@("`@("`@("`@("`G=')A;G-L871I
M;VX@9F]R('!A8VMA9V4N>&UL(#$N,"<I.PT*("`@("`@("!]#0H@("`@("`@
M("1G96X@/2`F)'!F+3YG971$969A=6QT1V5N97)A=&]R*"D[#0H@("`@("`@
M("1G96XM/G1O4&%C:V%G949I;&4H)RXG*3L-"B`@("!]#0I]#0H-"C\^#0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!
M4B]#;VUM86YD+U!I8VML92YX;6P`````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(W-C,`,3`U,34T,S,W-#``,#(R-C0W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#QC;VUM86YD<R!V97)S:6]N
M/2(Q+C`B/@T*(#QP:6-K;&4^#0H@(#QS=6UM87)Y/D)U:6QD(%!%0TP@4&%C
M:V%G93PO<W5M;6%R>3X-"B`@/&9U;F-T:6]N/F1O4&%C:V%G93PO9G5N8W1I
M;VX^#0H@(#QS:&]R=&-U=#YP:3PO<VAO<G1C=70^#0H@(#QO<'1I;VYS/@T*
M("`@/&YO8V]M<')E<W,^#0H@("`@/'-H;W)T;W!T/EH\+W-H;W)T;W!T/@T*
M("`@(#QD;V,^1&\@;F]T(&=Z:7`@=&AE('!A8VMA9V4@9FEL93PO9&]C/@T*
M("`@/"]N;V-O;7!R97-S/@T*("`@/'-H;W=N86UE/@T*("`@(#QS:&]R=&]P
M=#YN/"]S:&]R=&]P=#X-"B`@("`\9&]C/E!R:6YT('1H92!N86UE(&]F('1H
M92!P86-K86=E9"!F:6QE+CPO9&]C/@T*("`@/"]S:&]W;F%M93X-"B`@/"]O
M<'1I;VYS/@T*("`\9&]C/EMD97-C9FEL95T@6V1E<V-F:6QE,ET-"D-R96%T
M97,@82!014-,('!A8VMA9V4@9G)O;2!I=',@9&5S8W)I<'1I;VX@9FEL92`H
M=7-U86QL>2!C86QL960-"G!A8VMA9V4N>&UL*2X@($EF(&$@<V5C;VYD('!A
M8VMA9V5F:6QE(&ES('!A<W-E9"!I;BP@=&AE;@T*=&AE('!A8VMA9V5R('=I
M;&P@8VAE8VL@=&\@;6%K92!S=7)E('1H870@;VYE(&ES(&$@<&%C:V%G92YX
M;6P-"G9E<G-I;VX@,2XP+"!A;F0@=&AE(&]T:&5R(&ES(&$@<&%C:V%G92YX
M;6P@=F5R<VEO;B`R+C`N("!4:&4-"G!A8VMA9V4N>&UL('9E<G-I;VX@,2XP
M('=I;&P@8F4@<V%V960@87,@)G%U;W0[<&%C:V%G92YX;6PF<75O=#L@:6X@
M=&AE(&%R8VAI=F4L#0IA;F0@=&AE(&]T:&5R(&%S("9Q=6]T.W!A8VMA9V4R
M+GAM;"9Q=6]T.R!I;B!T:&4@87)C:&EV929Q=6]T.PT*#0I)9B!N;R!S96-O
M;F0@9FEL92!I<R!P87-S960@:6XL(&%N9"!;9&5S8V9I;&5=(&ES(&$@<&%C
M:V%G92YX;6P@,BXP+`T*86X@875T;VUA=&EC(&-O;G9E<G-I;VX@=VEL;"!B
M92!M861E('1O(&$@<&%C:V%G92YX;6P@,2XP+B`@3F]T92!T:&%T#0IO;FQY
M('-I;7!L92!P86-K86=E+GAM;"`R+C`@=VEL;"!B92!C;VYV97)T960N("!P
M86-K86=E+GAM;"`R+C`@=VET:#H-"@T*("T@9&5P96YD96YC>2!T>7!E<R!O
M=&AE<B!T:&%N(')E<75I<F5D+V]P=&EO;F%L(%!%0TP@<&%C:V%G92]E>'0O
M<&AP+W!E87)I;G-T86QL97(-"B`M(&UO<F4@=&AA;B!O;F4@97AT<W)C<F5L
M96%S90T*("T@97AT8FEN<F5L96%S92P@<&AP<F5L96%S92P@;W(@8G5N9&QE
M(')E;&5A<V4@='EP90T*("T@9&5P96YD96YC>2!G<F]U<',-"B`M(&EG;F]R
M92!T86=S(&EN(')E;&5A<V4@9FEL96QI<W0-"B`M('1A<VMS(&]T:&5R('1H
M86X@<F5P;&%C90T*("T@8W5S=&]M(')O;&5S#0H-"G=I;&P@8V%U<V4@<&EC
M:VQE('1O(&9A:6PL(&%N9"!O=71P=70@86X@97)R;W(@;65S<V%G92X@($EF
M('EO=7(@<&%C:V%G93(N>&UL#0IU<V5S(&%N>2!O9B!T:&5S92!F96%T=7)E
M<RP@>6]U(&%R92!B97-T(&]F9B!U<VEN9R!014%27U!A8VMA9V5&:6QE36%N
M86=E<B!T;PT*9V5N97)A=&4@8F]T:"!P86-K86=E+GAM;"X\+V1O8SX-"B`\
M+W!I8VML93X-"CPO8V]M;6%N9',^`````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O4F5G:7-T<GDN<&AP
M```````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$R-S0U-0`Q,#4Q-30S,S<T
M,``P,C,R-#4`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`-"B\J*@T*("H@4$5!4E]#;VUM86YD7U)E9VES=')Y("AL
M:7-T+"!L:7-T+69I;&5S+"!S:&5L;"UT97-T+"!I;F9O(&-O;6UA;F1S*0T*
M("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@
M5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F
M('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G
M:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@
M*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS
M92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B
M+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S
M;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J
M($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A
M=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H
M;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y
M<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC
M96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!296=I<W1R>2YP
M:'`L=B`Q+C<P(#(P,#8O,#$O,#8@,#0Z-#<Z,S8@8V5L;&]G($5X<"`D#0H@
M*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!
M4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S
M92`P+C$-"B`J+PT*#0HO*BH-"B`J(&)A<V4@8VQA<W,-"B`J+PT*<F5Q=6ER
M95]O;F-E("=014%2+T-O;6UA;F0O0V]M;6]N+G!H<"<[#0H-"B\J*@T*("H@
M4$5!4B!C;VUM86YD<R!F;W(@<F5G:7-T<GD@;6%N:7!U;&%T:6]N#0H@*@T*
M("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@
M0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U
M=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2
M#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S
M92`P+C$-"B`J+PT*8VQA<W,@4$5!4E]#;VUM86YD7U)E9VES=')Y(&5X=&5N
M9',@4$5!4E]#;VUM86YD7T-O;6UO;@T*>PT*("`@("\O('M[>R!P<F]P97)T
M:65S#0H-"B`@("!V87(@)&-O;6UA;F1S(#T@87)R87DH#0H@("`@("`@("=L
M:7-T)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G3&ES
M="!);G-T86QL960@4&%C:V%G97,@26X@5&AE($1E9F%U;'0@0VAA;FYE;"<L
M#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;TQI<W0G+`T*("`@("`@
M("`@("`@)W-H;W)T8W5T)R`]/B`G;"<L#0H@("`@("`@("`@("`G;W!T:6]N
M<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@)V-H86YN96PG(#T^(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=C)RP-
M"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)VQI<W0@:6YS=&%L;&5D
M('!A8VMA9V5S(&9R;VT@=&AI<R!C:&%N;F5L)RP-"B`@("`@("`@("`@("`@
M("`@("`@)V%R9R<@/3X@)T-(04XG+`T*("`@("`@("`@("`@("`@("`@("`I
M+`T*("`@("`@("`@("`@("`@("=A;&QC:&%N;F5L<R<@/3X@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)V$G+`T*("`@("`@
M("`@("`@("`@("`@("`G9&]C)R`]/B`G;&ES="!I;G-T86QL960@<&%C:V%G
M97,@9G)O;2!A;&P@8VAA;FYE;',G+`T*("`@("`@("`@("`@("`@("`@("`I
M+`T*("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G
M/'!A8VMA9V4^#0I)9B!I;G9O:V5D('=I=&AO=70@<&%R86UE=&5R<RP@=&AI
M<R!C;VUM86YD(&QI<W1S('1H92!014%2('!A8VMA9V5S#0II;G-T86QL960@
M:6X@>6]U<B!P:'!?9&ER("A[8V]N9FEG('!H<%]D:7)]*2X@(%=I=&@@82!P
M87)A;65T97(L(&ET#0IL:7-T<R!T:&4@9FEL97,@:6X@82!P86-K86=E+@T*
M)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@("=L:7-T+69I;&5S)R`]/B!A
M<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G3&ES="!&:6QE<R!)
M;B!);G-T86QL960@4&%C:V%G92<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG
M(#T^("=D;T9I;&5,:7-T)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@
M)V9L)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@I+`T*("`@
M("`@("`@("`@)V1O8R<@/3X@)SQP86-K86=E/@T*3&ES="!T:&4@9FEL97,@
M:6X@86X@:6YS=&%L;&5D('!A8VMA9V4N#0HG#0H@("`@("`@("`@("`I+`T*
M("`@("`@("`G<VAE;&PM=&5S="<@/3X@87)R87DH#0H@("`@("`@("`@("`G
M<W5M;6%R>2<@/3X@)U-H96QL(%-C<FEP="!497-T)RP-"B`@("`@("`@("`@
M("=F=6YC=&EO;B<@/3X@)V1O4VAE;&Q497-T)RP-"B`@("`@("`@("`@("=S
M:&]R=&-U="<@/3X@)W-T)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A
M<G)A>2@I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)SQP86-K86=E/B!;6W)E
M;&%T:6]N72!V97)S:6]N70T*5&5S=',@:68@82!P86-K86=E(&ES(&EN<W1A
M;&QE9"!I;B!T:&4@<WES=&5M+B!7:6QL(&5X:70H,2D@:68@:70@:7,@;F]T
M+@T*("`@/')E;&%T:6]N/B`@(%1H92!V97)S:6]N(&-O;7!A<FES;VX@;W!E
M<F%T;W(N($]N92!O9CH-"B`@("`@("`@("`@("`@("`\+"!L="P@/#TL(&QE
M+"`^+"!G="P@/CTL(&=E+"`]/2P@/2P@97$L("$]+"`\/BP@;F4-"B`@(#QV
M97)S:6]N/B`@("!4:&4@=F5R<VEO;B!T;R!C;VUP87)E('=I=&@-"B<I+`T*
M("`@("`@("`G:6YF;R<@/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R
M>2<@(#T^("=$:7-P;&%Y(&EN9F]R;6%T:6]N(&%B;W5T(&$@<&%C:V%G92<L
M#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;TEN9F\G+`T*("`@("`@
M("`@("`@)W-H;W)T8W5T)R`]/B`G:6XG+`T*("`@("`@("`@("`@)V]P=&EO
M;G,G("`]/B!A<G)A>2@I+`T*("`@("`@("`@("`@)V1O8R<@("`@("`]/B`G
M/'!A8VMA9V4^#0I$:7-P;&%Y<R!I;F9O<FUA=&EO;B!A8F]U="!A('!A8VMA
M9V4N(%1H92!P86-K86=E(&%R9W5M96YT(&UA>2!B92!A#0IL;V-A;"!P86-K
M86=E(&9I;&4L(&%N(%523"!T;R!A('!A8VMA9V4@9FEL92P@;W(@=&AE(&YA
M;64@;V8@86X-"FEN<W1A;&QE9"!P86-K86=E+B<-"B`@("`@("`@("`@("D-
M"B`@("`@("`@*3L-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!C;VYS=')U
M8W1O<@T*#0H@("`@+RHJ#0H@("`@("H@4$5!4E]#;VUM86YD7U)E9VES=')Y
M(&-O;G-T<G5C=&]R+@T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!014%27T-O;6UA;F1?4F5G:7-T<GDH
M)B1U:2P@)B1C;VYF:6<I#0H@("`@>PT*("`@("`@("!P87)E;G0Z.E!%05)?
M0V]M;6%N9%]#;VUM;VXH)'5I+"`D8V]N9FEG*3L-"B`@("!]#0H-"B`@("`O
M+R!]?7T-"@T*("`@("\O('M[>R!D;TQI<W0H*0T*#0H@("`@9G5N8W1I;VX@
M7W-O<G1I;F9O*"1A+"`D8BD-"B`@("![#0H@("`@("`@("1A<&%C:V%G92`]
M(&ES<V5T*"1A6R=P86-K86=E)UTI(#\@)&%;)W!A8VMA9V4G72`Z("1A6R=N
M86UE)UT[#0H@("`@("`@("1B<&%C:V%G92`](&ES<V5T*"1B6R=P86-K86=E
M)UTI(#\@)&);)W!A8VMA9V4G72`Z("1B6R=N86UE)UT[#0H@("`@("`@(')E
M='5R;B!S=')C;7`H)&%P86-K86=E+"`D8G!A8VMA9V4I.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N(&1O3&ES="@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A
M;7,I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)V%L;&-H
M86YN96QS)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/F1O3&ES
M=$%L;"@D8V]M;6%N9"P@87)R87DH*2P@)'!A<F%M<RD[#0H@("`@("`@('T-
M"B`@("`@("`@)')E9R`]("8D=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I
M.PT*("`@("`@("!I9B`H8V]U;G0H)'!A<F%M<RD@/3T@,2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YD;T9I;&5,:7-T*"1C;VUM86YD+"`D;W!T
M:6]N<RP@)'!A<F%M<RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T
M*"1O<'1I;VYS6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("!I9B`H)')E
M9RT^8VAA;FYE;$5X:7-T<R@D;W!T:6]N<ULG8VAA;FYE;"==*2D@>PT*("`@
M("`@("`@("`@("`@("1C:&%N;F5L(#T@)')E9RT^8VAA;FYE;$YA;64H)&]P
M=&EO;G-;)V-H86YN96PG72D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G0VAA;FYE
M;"`B)R`N("1O<'1I;VYS6R=C:&%N;F5L)UT@+B<B(&1O97,@;F]T(&5X:7-T
M)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`D8VAA;FYE;"`]("1T:&ES+3YC;VYF:6<M/F=E="@G9&5F875L=%]C
M:&%N;F5L)RD[#0H@("`@("`@('T-"B`@("`@("`@)&EN<W1A;&QE9"`]("1R
M96<M/G!A8VMA9V5);F9O*&YU;&PL(&YU;&PL("1C:&%N;F5L*3L-"B`@("`@
M("`@=7-O<G0H)&EN<W1A;&QE9"P@87)R87DH)B1T:&ES+"`G7W-O<G1I;F9O
M)RDI.PT*("`@("`@("`D:2`]("1J(#T@,#L-"B`@("`@("`@)&1A=&$@/2!A
M<G)A>2@-"B`@("`@("`@("`@("=C87!T:6]N)R`]/B`G26YS=&%L;&5D('!A
M8VMA9V5S+"!C:&%N;F5L("<@+@T*("`@("`@("`@("`@("`@("1C:&%N;F5L
M("X@)SHG+`T*("`@("`@("`@("`@)V)O<F1E<B<@/3X@=')U92P-"B`@("`@
M("`@("`@("=H96%D;&EN92<@/3X@87)R87DH)U!A8VMA9V4G+"`G5F5R<VEO
M;B<L("=3=&%T92<I#0H@("`@("`@("`@("`I.PT*("`@("`@("!F;W)E86-H
M("@D:6YS=&%L;&5D(&%S("1P86-K86=E*2![#0H@("`@("`@("`@("`D<&]B
M:B`]("1R96<M/F=E=%!A8VMA9V4H:7-S970H)'!A8VMA9V5;)W!A8VMA9V4G
M72D@/PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1P86-K86=E6R=P86-K86=E)UT@.B`D<&%C:V%G95LG;F%M92==+"`D8VAA
M;FYE;"D[#0H@("`@("`@("`@("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@D
M<&]B:BT^9V5T4&%C:V%G92@I+"`D<&]B:BT^9V5T5F5R<VEO;B@I+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O8FHM/F=E=%-T
M871E*"D@/R`D<&]B:BT^9V5T4W1A=&4H*2`Z(&YU;&PI.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AC;W5N="@D:6YS=&%L;&5D*3T],"D@>PT*("`@("`@
M("`@("`@)&1A=&$@/2`G*&YO('!A8VMA9V5S(&EN<W1A;&QE9"!F<F]M(&-H
M86YN96P@)R`N("1C:&%N;F5L("X@)RDG.PT*("`@("`@("!]#0H@("`@("`@
M("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D9&%T82P@)&-O;6UA;F0I.PT*("`@
M("`@("!R971U<FX@=')U93L-"B`@("!]#0H@("`@#0H@("`@9G5N8W1I;VX@
M9&],:7-T06QL*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![
M#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH
M*3L-"B`@("`@("`@)&EN<W1A;&QE9"`]("1R96<M/G!A8VMA9V5);F9O*&YU
M;&PL(&YU;&PL(&YU;&PI.PT*("`@("`@("!F;W)E86-H("@D:6YS=&%L;&5D
M(&%S("1C:&%N;F5L(#T^("1P86-K86=E<RD@>PT*("`@("`@("`@("`@=7-O
M<G0H)'!A8VMA9V5S+"!A<G)A>2@D=&AI<RP@)U]S;W)T:6YF;R<I*3L-"B`@
M("`@("`@("`@("1I(#T@)&H@/2`P.PT*("`@("`@("`@("`@)&1A=&$@/2!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`G8V%P=&EO;B<@/3X@)TEN<W1A;&QE
M9"!P86-K86=E<RP@8VAA;FYE;"`G("X@)&-H86YN96P@+B`G.B<L#0H@("`@
M("`@("`@("`@("`@)V)O<F1E<B<@/3X@=')U92P-"B`@("`@("`@("`@("`@
M("`G:&5A9&QI;F4G(#T^(&%R<F%Y*"=086-K86=E)RP@)U9E<G-I;VXG+"`G
M4W1A=&4G*0T*("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("!F;W)E
M86-H("@D<&%C:V%G97,@87,@)'!A8VMA9V4I('L-"B`@("`@("`@("`@("`@
M("`D<&]B:B`]("1R96<M/F=E=%!A8VMA9V4H:7-S970H)'!A8VMA9V5;)W!A
M8VMA9V4G72D@/PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<&%C:V%G95LG<&%C:V%G92==(#H@)'!A8VMA9V5;)VYA
M;64G72P@)&-H86YN96PI.PT*("`@("`@("`@("`@("`@("1D871A6R=D871A
M)UU;72`](&%R<F%Y*"1P;V)J+3YG971086-K86=E*"DL("1P;V)J+3YG9716
M97)S:6]N*"DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!O8FHM/F=E=%-T871E*"D@/R`D<&]B:BT^9V5T4W1A=&4H*2`Z
M(&YU;&PI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&-O=6YT
M*"1P86-K86=E<RD]/3`I('L-"B`@("`@("`@("`@("`@("`D9&%T82`](&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G8V%P=&EO;B<@/3X@)TEN<W1A
M;&QE9"!P86-K86=E<RP@8VAA;FYE;"`G("X@)&-H86YN96P@+B`G.B<L#0H@
M("`@("`@("`@("`@("`@("`@("=B;W)D97(G(#T^('1R=64L#0H@("`@("`@
M("`@("`@("`@("`@("=D871A)R`]/B!A<G)A>2AA<G)A>2@G*&YO('!A8VMA
M9V5S(&EN<W1A;&QE9"DG*2DL#0H@("`@("`@("`@("`@("`@("`@("D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A
M=&$H)&1A=&$L("1C;VUM86YD*3L-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@=')U93L-"B`@("!]#0H@("`@#0H@("`@9G5N8W1I;VX@9&]&:6QE3&ES
M="@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@
M("!I9B`H8V]U;G0H)'!A<F%M<RD@(3T@,2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*"=L:7-T+69I;&5S(&5X<&5C=',@,2!P
M87)A;65T97(G*3L-"B`@("`@("`@?0T*("`@("`@("`D<F5G(#T@)B1T:&ES
M+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@(&EF("@A:7-?9&ER
M*"1P87)A;7-;,%TI("8F("AF:6QE7V5X:7-T<R@D<&%R86US6S!=*2!\?"`D
M9G`@/2!`9F]P96XH)'!A<F%M<ULP72P-"B`@("`@("`@("`@("`@)W(G*2DI
M('L-"B`@("`@("`@("`@($!F8VQO<V4H)&9P*3L-"B`@("`@("`@("`@(&EF
M("@A8VQA<W-?97AI<W1S*"=014%27U!A8VMA9V5&:6QE)RDI('L-"B`@("`@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G949I;&4N<&AP
M)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1P:V<@/2`F;F5W(%!%
M05)?4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I9RP@)'1H:7,M/E]D96)U9RD[
M#0H@("`@("`@("`@("!014%2.CIS=&%T:6-0=7-H17)R;W)(86YD;&EN9RA0
M14%27T524D]27U)%5%523BD[#0H@("`@("`@("`@("`D:6YF;R`]("8D<&MG
M+3YF<F]M06YY1FEL92@D<&%R86US6S!=+"!014%27U9!3$E$051%7TY/4DU!
M3"D[#0H@("`@("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG
M*"D[#0H@("`@("`@("`@("`D:&5A9&EN9W,@/2!A<G)A>2@G4&%C:V%G92!&
M:6QE)RP@)TEN<W1A;&P@4&%T:"<I.PT*("`@("`@("`@("`@)&EN<W1A;&QE
M9"`](&9A;'-E.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@4$5!
M4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI
M.PT*("`@("`@("`@("`@)'!A<G-E9"`]("1R96<M/G!A<G-E4&%C:V%G94YA
M;64H)'!A<F%M<ULP72P@)'1H:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT7V-H
M86YN96PG*2D[#0H@("`@("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA
M;F1L:6YG*"D[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&%R
M<V5D*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@D<&%R<V5D*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1I
M;F9O(#T@)B1R96<M/F=E=%!A8VMA9V4H)'!A<G-E9%LG<&%C:V%G92==+"`D
M<&%R<V5D6R=C:&%N;F5L)UTI.PT*("`@("`@("`@("`@)&AE861I;F=S(#T@
M87)R87DH)U1Y<&4G+"`G26YS=&%L;"!0871H)RD[#0H@("`@("`@("`@("`D
M:6YS=&%L;&5D(#T@=')U93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@D:6YF;RD[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"1I;F9O(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H(F`D<&%R86US6S!=)R!N;W0@:6YS=&%L;&5D(BD[#0H@
M("`@("`@('T-"B`@("`@("`@)&QI<W0@/2`H)&EN9F\M/F=E=%!A8VMA9V5X
M;6Q697)S:6]N*"D@/3T@)S$N,"<@?'P@)&EN<W1A;&QE9"D@/PT*("`@("`@
M("`@("`@)&EN9F\M/F=E=$9I;&5L:7-T*"D@.B`D:6YF;RT^9V5T0V]N=&5N
M=',H*3L-"B`@("`@("`@:68@*"1I;G-T86QL960I('L-"B`@("`@("`@("`@
M("1C87!T:6]N(#T@)TEN<W1A;&QE9"!&:6QE<R!&;W(@)R`N("1P87)A;7-;
M,%T[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D8V%P=&EO;B`]
M("=#;VYT96YT<R!O9B`G("X@8F%S96YA;64H)'!A<F%M<ULP72D[#0H@("`@
M("`@('T-"B`@("`@("`@)&1A=&$@/2!A<G)A>2@-"B`@("`@("`@("`@("=C
M87!T:6]N)R`]/B`D8V%P=&EO;BP-"B`@("`@("`@("`@("=B;W)D97(G(#T^
M('1R=64L#0H@("`@("`@("`@("`G:&5A9&QI;F4G(#T^("1H96%D:6YG<RD[
M#0H@("`@("`@(&EF("@D:6YF;RT^9V5T4&%C:V%G97AM;%9E<G-I;VXH*2`]
M/2`G,2XP)R!\?"`D:6YS=&%L;&5D*2![#0H@("`@("`@("`@("!F;W)E86-H
M("@D;&ES="!A<R`D9FEL92`]/B`D871T*2![#0H@("`@("`@("`@("`@("`@
M:68@*"1I;G-T86QL960I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&5M
M<'1Y*"1A='1;)VEN<W1A;&QE9%]A<R==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@)&1A=&%;)V1A=&$G75M=(#T@87)R87DH)&%T
M=%LG<F]L92==+"`D871T6R=I;G-T86QL961?87,G72D[#0H@("`@("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1A='1;)V)A<V5I;G-T86QL9&ER)UTI("8F("%I;E]A<G)A>2@D871T6R=R
M;VQE)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=T97-T
M)RP@)V1A=&$G+"`G9&]C)RDI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D9&5S="`]("1A='1;)V)A<V5I;G-T86QL9&ER)UT@+B!$25)%0U1/4EE?
M4T5005)!5$]2("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEL
M93L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1D97-T(#T@)&9I;&4[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@<W=I=&-H("@D871T6R=R;VQE
M)UTI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)W1E<W0G.@T*
M("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G9&%T82<Z#0H@("`@("`@
M("`@("`@("`@("`@("`@("!C87-E("=D;V,G.@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1R;VQE(#T@)&%T=%LG<F]L92==.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("@D<F]L92`]/2`G=&5S="<I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')O;&4@+CT@)W,G.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&5S="`]("1T:&ES+3YC;VYF:6<M/F=E="@D<F]L
M92`N("=?9&ER)RD@+B!$25)%0U1/4EE?4T5005)!5$]2("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F\M/F=E=%!A8VMA9V4H*2`N
M($1)4D5#5$]265]315!!4D%43U(@+B`D9&5S=#L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&-A<V4@)W!H<"<Z#0H@("`@("`@("`@("`@("`@("`@("`@("!D969A=6QT
M.@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97-T(#T@)'1H:7,M
M/F-O;F9I9RT^9V5T*"=P:'!?9&ER)RD@+B!$25)%0U1/4EE?4T5005)!5$]2
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<W0[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)&1S
M,B`]($1)4D5#5$]265]315!!4D%43U(@+B!$25)%0U1/4EE?4T5005)!5$]2
M.PT*("`@("`@("`@("`@("`@("`@("`D9&5S="`]('!R96=?<F5P;&%C92AA
M<G)A>2@G(5Q<7%PK(2<L("<A+R$G+"`B(21D<S(K(2(I+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*$1)4D5#5$]265]315!!4D%43U(L#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1$E214-4
M3U)97U-%4$%2051/4BP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$25)%0U1/4EE?4T5005)!
M5$]2*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&5S="D[#0H@("`@("`@("`@("`@("`@("`@("1F
M:6QE(#T@<')E9U]R97!L86-E*"<A+RLA)RP@)R\G+"`D9FEL92D[#0H@("`@
M("`@("`@("`@("`@("`@("1D871A6R=D871A)UU;72`](&%R<F%Y*"1F:6QE
M+"`D9&5S="D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("!](&5L<V4@>R`O+R!P86-K86=E+GAM;"`R+C`L(&YO="!I;G-T
M86QL960-"B`@("`@("`@("`@(&EF("@A:7-S970H)&QI<W1;)V1I<B==6R=F
M:6QE)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@)&QI<W1;)V1I<B==6R=F
M:6QE)UT@/2!A<G)A>2@D;&ES=%LG9&ER)UU;)V9I;&4G72D[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!F;W)E86-H("@D;&ES=%LG9&ER)UU;)V9I
M;&4G72!A<R`D871T*2![#0H@("`@("`@("`@("`@("`@)&%T="`]("1A='1;
M)V%T=')I8G,G73L-"B`@("`@("`@("`@("`@("`D9FEL92`]("1A='1;)VYA
M;64G73L-"B`@("`@("`@("`@("`@("`D<F]L92`]("9014%27TEN<W1A;&QE
M<E]2;VQE.CIF86-T;W)Y*"1I;F9O+"`D871T6R=R;VQE)UTL("1T:&ES+3YC
M;VYF:6<I.PT*("`@("`@("`@("`@("`@("1R;VQE+3YS971U<"@D=&AI<RP@
M)&EN9F\L("1A='0L("1F:6QE*3L-"B`@("`@("`@("`@("`@("!I9B`H(21R
M;VQE+3YI<TEN<W1A;&QA8FQE*"DI('L-"B`@("`@("`@("`@("`@("`@("`@
M)&1E<W0@/2`G*&YO="!I;G-T86QL86)L92DG.PT*("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1D97-T(#T@)')O;&4M
M/G!R;V-E<W-);G-T86QL871I;VXH)&EN9F\L("1A='0L("1F:6QE+"`G)RD[
M#0H@("`@("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1D97-T
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&1E<W0@/2`G*%5N:VYO
M=VX@<F]L92`B)R`N("1A='1;)W)O;&4G72`N("<I)SL-"B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&QI
M<W0H+"P@)&1E<W0I(#T@)&1E<W0[#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&1A=&%;)V1A
M=&$G75M=(#T@87)R87DH)&9I;&4L("1D97-T*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&1A
M=&$L("1C;VUM86YD*3L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&1O4VAE;&Q497-T*"D-"@T*("`@
M(&9U;F-T:6]N(&1O4VAE;&Q497-T*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A
M<F%M<RD-"B`@("![#0H@("`@("`@("1T:&ES+3YP=7-H17)R;W)(86YD;&EN
M9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("1R96<@/2`F)'1H:7,M
M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@)&EN9F\@/2`D<F5G
M+3YP87)S95!A8VMA9V5.86UE*"1P87)A;7-;,%TL("1T:&ES+3YC;VYF:6<M
M/F=E="@G9&5F875L=%]C:&%N;F5L)RDI.PT*("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@("`@(&5X:70H,2D[("\O(&EN
M=F%L:60@<&%C:V%G92!N86UE#0H@("`@("`@('T-"B`@("`@("`@)'!A8VMA
M9V4@/2`D:6YF;ULG<&%C:V%G92==.PT*("`@("`@("`D8VAA;FYE;"`]("1I
M;F9O6R=C:&%N;F5L)UT[#0H@("`@("`@("\O(")P96%R('-H96QL+71E<W0@
M1F]O(@T*("`@("`@("!I9B`H(21R96<M/G!A8VMA9V5%>&ES=',H)'!A8VMA
M9V4L("1C:&%N;F5L*2D@>PT*("`@("`@("`@("`@:68@*"1C:&%N;F5L(#T]
M("=P96-L+G!H<"YN970G*2![#0H@("`@("`@("`@("`@("`@:68@*"1R96<M
M/G!A8VMA9V5%>&ES=',H)'!A8VMA9V4L("=P96%R+G!H<"YN970G*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D8VAA;FYE;"`]("=P96%R+G!H<"YN970G
M.R`O+R!M86=I8V%L;'D@8VAA;F=E(&-H86YN96QS(&9O<B!E>'1E;G-I;VYS
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@/3T@,2D@>PT*("`@("`@
M("`@("`@:68@*"$D<F5G+3YP86-K86=E17AI<W1S*"1P86-K86=E+"`D8VAA
M;FYE;"DI('L-"B`@("`@("`@("`@("`@("!E>&ET*#$I.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@+R\@(G!E87(@<VAE;&PM=&5S="!&;V\@,2XP
M(@T*("`@("`@("!](&5L<V5I9B`H<VEZ96]F*"1P87)A;7,I(#T](#(I('L-
M"B`@("`@("`@("`@("1V(#T@)')E9RT^<&%C:V%G94EN9F\H)'!A8VMA9V4L
M("=V97)S:6]N)RP@)&-H86YN96PI.PT*("`@("`@("`@("`@:68@*"$D=B!\
M?"`A=F5R<VEO;E]C;VUP87)E*"(D=B(L(")[)'!A<F%M<ULQ77TB+"`B9V4B
M*2D@>PT*("`@("`@("`@("`@("`@(&5X:70H,2D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`O+R`B<&5A<B!S:&5L;"UT97-T($9O;R!G92`Q+C`B
M#0H@("`@("`@('T@96QS96EF("AS:7IE;V8H)'!A<F%M<RD@/3T@,RD@>PT*
M("`@("`@("`@("`@)'8@/2`D<F5G+3YP86-K86=E26YF;R@D<&%C:V%G92P@
M)W9E<G-I;VXG+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("!I9B`H(21V('Q\
M("%V97)S:6]N7V-O;7!A<F4H(B1V(BP@(GLD<&%R86US6S)=?2(L("1P87)A
M;7-;,5TI*2![#0H@("`@("`@("`@("`@("`@97AI="@Q*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T:&ES+3YP
M;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("`D=&AI<RT^<F%I<V5%
M<G)O<B@B)&-O;6UA;F0Z(&5X<&5C=',@,2!T;R`S('!A<F%M971E<G,B*3L-
M"B`@("`@("`@("`@(&5X:70H,2D[#0H@("`@("`@('T-"B`@("!]#0H-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@9&]);F9O#0H-"B`@("!F=6YC=&EO;B!D
M;TEN9F\H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@
M("`@("`@:68@*&-O=6YT*"1P87)A;7,I("$](#$I('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G<&5A<B!I;F9O(&5X<&5C=',@
M,2!P87)A;65T97(G*3L-"B`@("`@("`@?0T*("`@("`@("`D:6YF;R`](&9A
M;'-E.PT*("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES
M=')Y*"D[#0H@("`@("`@(&EF("@H0&ES7V9I;&4H)'!A<F%M<ULP72D@)B8@
M(6ES7V1I<B@D<&%R86US6S!=*2D@?'P@)&9P(#T@0&9O<&5N*"1P87)A;7-;
M,%TL("=R)RDI('L-"B`@("`@("`@("`@($!F8VQO<V4H)&9P*3L-"B`@("`@
M("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27U!A8VMA9V5&:6QE)RDI
M('L-"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G
M949I;&4N<&AP)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1P:V<@
M/2`F;F5W(%!%05)?4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I9RP@)'1H:7,M
M/E]D96)U9RD[#0H@("`@("`@("`@("!014%2.CIS=&%T:6-0=7-H17)R;W)(
M86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("`@("`D;V)J
M(#T@)B1P:V<M/F9R;VU!;GE&:6QE*"1P87)A;7-;,%TL(%!%05)?5D%,241!
M5$5?3D]234%,*3L-"B`@("`@("`@("`@(%!%05(Z.G-T871I8U!O<$5R<F]R
M2&%N9&QI;F<H*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1O
M8FHI*2![#0H@("`@("`@("`@("`@("`@)'5I;F9O(#T@)&]B:BT^9V5T57-E
M<DEN9F\H*3L-"B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)'5I;F9O
M*2D@>PT*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D=6EN9F\@87,@
M)&UE<W-A9V4I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2@D;65S<V%G92DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D;65S<V%G92`]("1M97-S86=E6R=M97-S86=E)UT[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^=6DM/F]U='!U=$1A=&$H)&UE<W-A9V4I.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D;V)J*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&EF("@D;V)J+3YG971086-K86=E>&UL5F5R<VEO;B@I
M(#T]("<Q+C`G*2![#0H@("`@("`@("`@("`@("`@)&EN9F\@/2`D;V)J+3YT
M;T%R<F%Y*"D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7V1O26YF;S(H)&-O;6UA;F0L("1O<'1I;VYS
M+"`D<&%R86US+"`D;V)J+"!F86QS92D[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`D<&%R<V5D(#T@)')E9RT^<&%R
M<V5086-K86=E3F%M92@D<&%R86US6S!=+"`D=&AI<RT^8V]N9FEG+3YG970H
M)V1E9F%U;'1?8VAA;FYE;"<I*3L-"B`@("`@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1P87)S960I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*"1P87)S960I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)'!A8VMA9V4@/2`D<&%R<V5D6R=P86-K86=E)UT[#0H@("`@
M("`@("`@("`D8VAA;FYE;"`]("1P87)S961;)V-H86YN96PG73L-"B`@("`@
M("`@("`@("1I;F9O(#T@)')E9RT^<&%C:V%G94EN9F\H)'!A8VMA9V4L(&YU
M;&PL("1C:&%N;F5L*3L-"B`@("`@("`@("`@(&EF("AI<W-E="@D:6YF;ULG
M;VQD)UTI*2![#0H@("`@("`@("`@("`@("`@)&]B:B`]("1R96<M/F=E=%!A
M8VMA9V4H)'!A8VMA9V4L("1C:&%N;F5L*3L-"B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]D;TEN9F\R*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A
M<F%M<RP@)&]B:BP@=')U92D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\I*2![#0H@("`@("`@
M("`@("!R971U<FX@)&EN9F\[#0H@("`@("`@('T-"B`@("`@("`@:68@*&5M
M<'1Y*"1I;F9O*2D@>PT*("`@("`@("`@("`@)'1H:7,M/G)A:7-E17)R;W(H
M(DYO(&EN9F]R;6%T:6]N(&9O=6YD(&9O<B!@)'!A<F%M<ULP72<B*3L-"B`@
M("`@("`@("`@(')E='5R;CL-"B`@("`@("`@?0T*("`@("`@("!U;G-E="@D
M:6YF;ULG9FEL96QI<W0G72D[#0H@("`@("`@('5N<V5T*"1I;F9O6R=D:7)T
M<F5E)UTI.PT*("`@("`@("!U;G-E="@D:6YF;ULG8VAA;F=E;&]G)UTI.PT*
M("`@("`@("!I9B`H:7-S970H)&EN9F];)WAS9'9E<G-I;VXG72DI('L-"B`@
M("`@("`@("`@("1I;F9O6R=P86-K86=E+GAM;"!V97)S:6]N)UT@/2`D:6YF
M;ULG>'-D=F5R<VEO;B==.PT*("`@("`@("`@("`@=6YS970H)&EN9F];)WAS
M9'9E<G-I;VXG72D[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1I
M;F9O6R=P86-K86=E<G9E<G-I;VXG72DI('L-"B`@("`@("`@("`@("1I;F9O
M6R=P86-K86=E9"!W:71H(%!%05(@=F5R<VEO;B==(#T@)&EN9F];)W!A8VMA
M9V5R=F5R<VEO;B==.PT*("`@("`@("`@("`@=6YS970H)&EN9F];)W!A8VMA
M9V5R=F5R<VEO;B==*3L-"B`@("`@("`@?0T*("`@("`@("`D:V5Y<R`](&%R
M<F%Y7VME>7,H)&EN9F\I.PT*("`@("`@("`D;&]N9W1E>'0@/2!A<G)A>2@G
M9&5S8W)I<'1I;VXG+"`G<W5M;6%R>2<I.PT*("`@("`@("!F;W)E86-H("@D
M:V5Y<R!A<R`D:V5Y*2![#0H@("`@("`@("`@("!I9B`H:7-?87)R87DH)&EN
M9F];)&ME>5TI*2![#0H@("`@("`@("`@("`@("`@<W=I=&-H("@D:V5Y*2![
M#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@)VUA:6YT86EN97)S)SH@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&D@/2`P.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)&US='(@/2`G)SL-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1I;F9O6R1K97E=(&%S("1M*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"1I*RL@/B`P*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1M<W1R("X](")<;B([#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1M<W1R("X]("1M6R=N86UE)UT@+B`B(#PB.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D;5LG96UA:6PG72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&US='(@+CT@)&U;
M)V5M86EL)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&US='(@+CT@
M)&U;)VAA;F1L92==("X@)T!P:'`N;F5T)SL-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&US
M='(@+CT@(CX@*"1M6W)O;&5=*2([#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULD:V5Y72`]("1M
M<W1R.PT*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@8V%S92`G<F5L
M96%S95]D97!S)SH@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&D@/2`P
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&1S='(@/2`G)SL-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O6R1K97E=(&%S("1D
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3Y?9&5P<U]R96Q?=')A;G-;)&1;)W)E;"==72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)')E;"`]("1T:&ES+3Y?9&5P<U]R
M96Q?=')A;G-;)&1;)W)E;"==73L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<F5L(#T@)&1;)W)E;"==.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]D97!S7W1Y<&5?=')A;G-;)&1;)W1Y<&4G75TI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T>7!E(#T@=6-F:7)S="@D
M=&AI<RT^7V1E<'-?='EP95]T<F%N<ULD9%LG='EP92==72D[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1Y<&4@/2`D9%LG='EP92==.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&1;)VYA;64G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&YA;64@/2`D9%LG;F%M92==("X@)R`G
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE(#T@)R<[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D9%LG=F5R<VEO;B==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=F5R<VEO;B`]("1D6R=V97)S
M:6]N)UT@+B`G("<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9E<G-I
M;VX@/2`G)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D6R=O<'1I;VYA
M;"==*2`F)B`D9%LG;W!T:6]N86PG72`]/2`G>65S)RD@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D;W!T:6]N86P@/2`G("AO<'1I;VYA
M;"DG.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1O<'1I;VYA;"`]("<G
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9'-T<B`N/2`B)'1Y<&4@)&YA;64D<F5L("1V
M97)S:6]N)&]P=&EO;F%L7&XB.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];)&ME>5T@/2`D9'-T
M<CL-"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@)W!R;W9I
M9&5S)R`Z('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1D96)U9R`]("1T
M:&ES+3YC;VYF:6<M/F=E="@G=F5R8F]S92<I.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"1D96)U9R`\(#(I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<'-T<B`]("=#;&%S<V5S.B`G.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<'-T<B`]("<G.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@)&D@/2`P.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)&EN9F];)&ME>5T@87,@)'`I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&1E8G5G(#P@,B`F)B`D
M<%LG='EP92==("$](")C;&%S<R(I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($]N;'D@
M<')I;G0@8VQA<W-E<R!W:&5N('9E<F)O<VET>2!M;V1E(&ES(#P@,@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D9&5B=6<@/"`R*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D:2LK(#X@,"D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!S='(@
M+CT@(BP@(CL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<'-T<B`N/2`D<%LG
M;F%M92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D:2LK(#X@
M,"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!S
M='(@+CT@(EQN(CL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<'-T<B`N/2!U
M8V9I<G-T*"1P6R=T>7!E)UTI("X@(B`B("X@)'!;)VYA;64G73L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P6R=E>'!L
M:6-I="==*2`F)B`D<%LG97AP;&EC:70G72`]/2`Q*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<'-T<B`N/2`B("AE>'!L:6-I
M="DB.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];)&ME>5T@
M/2`D<'-T<CL-"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@
M)V-O;F9I9W5R95]O<'1I;VYS)R`Z('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1I;F9O6R1K97E=(&%S("1I(#T^("1P*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];)&ME>5U;)&E=(#T@87)R
M87E?;6%P*&YU;&PL(&%R<F%Y7VME>7,H)'`I+"!A<G)A>5]V86QU97,H)'`I
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULD:V5Y75LD
M:5T@/2!A<G)A>5]M87`H8W)E871E7V9U;F-T:6]N*"<D82<L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=R971U<FX@:F]I;B@B(#T@(BPD
M82D[)RDL("1I;F9O6R1K97E=6R1I72D[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&EN9F];)&ME>5U;)&E=(#T@:6UP;&]D92@G+"`G+"`D:6YF
M;ULD:V5Y75LD:5TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@)&EN9F];)&ME>5T@/2!I;7!L;V1E*")<
M;B(L("1I;F9O6R1K97E=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@(&1E9F%U;'0Z('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O
M6R1K97E=(#T@:6UP;&]D92@B+"`B+"`D:6YF;ULD:V5Y72D[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF("@D:V5Y(#T]("=?;&%S=&UO9&EF:65D)RD@>PT*("`@("`@("`@
M("`@("`@("1H9&%T92`](&1A=&4H)UDM;2UD)RP@)&EN9F];)&ME>5TI.PT*
M("`@("`@("`@("`@("`@('5N<V5T*"1I;F9O6R1K97E=*3L-"B`@("`@("`@
M("`@("`@("`D:6YF;ULG3&%S="!-;V1I9FEE9"==(#T@)&AD871E.PT*("`@
M("`@("`@("`@?2!E;'-E:68@*"1K97D@/3T@)U]L87-T=F5R<VEO;B<I('L-
M"B`@("`@("`@("`@("`@("`D:6YF;ULG3&%S="!);G-T86QL960@5F5R<VEO
M;B==(#T@)&EN9F];)&ME>5T@/R`D:6YF;ULD:V5Y72`Z("<M($YO;F4@+2<[
M#0H@("`@("`@("`@("`@("`@=6YS970H)&EN9F];)&ME>5TI.PT*("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D:6YF;ULD:V5Y72`]
M('1R:6TH)&EN9F];)&ME>5TI.PT*("`@("`@("`@("`@("`@(&EF("AI;E]A
M<G)A>2@D:V5Y+"`D;&]N9W1E>'0I*2![#0H@("`@("`@("`@("`@("`@("`@
M("1I;F9O6R1K97E=(#T@<')E9U]R97!L86-E*"<O("`K+R<L("<@)RP@)&EN
M9F];)&ME>5TI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("`D8V%P=&EO;B`]("=!8F]U="`G("X@)&EN
M9F];)W!A8VMA9V4G72`N("<M)R`N("1I;F9O6R=V97)S:6]N)UT[#0H@("`@
M("`@("1D871A(#T@87)R87DH#0H@("`@("`@("`@("`G8V%P=&EO;B<@/3X@
M)&-A<'1I;VXL#0H@("`@("`@("`@("`G8F]R9&5R)R`]/B!T<G5E*3L-"B`@
M("`@("`@9F]R96%C:"`H)&EN9F\@87,@)&ME>2`]/B`D=F%L=64I('L-"B`@
M("`@("`@("`@("1K97D@/2!U8W=O<F1S*'1R:6TH<W1R7W)E<&QA8V4H)U\G
M+"`G("<L("1K97DI*2D[#0H@("`@("`@("`@("`D9&%T85LG9&%T82==6UT@
M/2!A<G)A>2@D:V5Y+"`D=F%L=64I.PT*("`@("`@("!]#0H@("`@("`@("1D
M871A6R=R87<G72`]("1I;F9O.PT*#0H@("`@("`@("1T:&ES+3YU:2T^;W5T
M<'5T1&%T82@D9&%T82P@)W!A8VMA9V4M:6YF;R<I.PT*("`@('T-"@T*("`@
M("\O('U]?0T*#0H@("`@+RHJ#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@7V1O26YF;S(H)&-O;6UA;F0L("1O<'1I
M;VYS+"`D<&%R86US+"`F)&]B:BP@)&EN<W1A;&QE9"D-"B`@("![#0H@("`@
M("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@
M("`@("`@)&-A<'1I;VX@/2`G06)O=70@)R`N("1O8FHM/F=E=$-H86YN96PH
M*2`N("<O)R`N)&]B:BT^9V5T4&%C:V%G92@I("X@)RTG("X-"B`@("`@("`@
M("`@("1O8FHM/F=E=%9E<G-I;VXH*3L-"B`@("`@("`@)&1A=&$@/2!A<G)A
M>2@-"B`@("`@("`@("`@("=C87!T:6]N)R`]/B`D8V%P=&EO;BP-"B`@("`@
M("`@("`@("=B;W)D97(G(#T^('1R=64I.PT*("`@("`@("!S=VET8V@@*"1O
M8FHM/F=E=%!A8VMA9V54>7!E*"DI('L-"B`@("`@("`@("`@(&-A<V4@)W!H
M<"<@.@T*("`@("`@("`@("`@("`@("1R96QE87-E(#T@)U!%05(M<W1Y;&4@
M4$A0+6)A<V5D(%!A8VMA9V4G.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@("`@("!C87-E("=E>'1S<F,G(#H-"B`@("`@("`@("`@("`@("`D<F5L
M96%S92`]("=014-,+7-T>6QE(%!(4"!E>'1E;G-I;VX@*'-O=7)C92!C;V1E
M*2<[#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)V5X
M=&)I;B<@.@T*("`@("`@("`@("`@("`@("1R96QE87-E(#T@)U!%0TPM<W1Y
M;&4@4$A0(&5X=&5N<VEO;B`H8FEN87)Y*2<[#0H@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@(&-A<V4@)V)U;F1L92<@.@T*("`@("`@("`@("`@
M("`@("1R96QE87-E(#T@)U!A8VMA9V4@8G5N9&QE("AC;VQL96-T:6]N(&]F
M('!A8VMA9V5S*2<[#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@?0T*
M("`@("`@("`D97AT96YD<R`]("1O8FHM/F=E=$5X=&5N9',H*3L-"B`@("`@
M("`@)&5X=&5N9',@/2`D97AT96YD<R`_#0H@("`@("`@("`@("`D;V)J+3YG
M971086-K86=E*"D@+B`G("AE>'1E;F1S("<@+B`D97AT96YD<R`N("<I)R`Z
M("1O8FHM/F=E=%!A8VMA9V4H*3L-"B`@("`@("`@:68@*"1S<F,@/2`D;V)J
M+3YG9713;W5R8V5086-K86=E*"DI('L-"B`@("`@("`@("`@("1E>'1E;F1S
M("X]("<@*'-O=7)C92!P86-K86=E("<@+B`D<W)C6R=C:&%N;F5L)UT@+B`G
M+R<@+B`D<W)C6R=P86-K86=E)UT@+B`G*2<[#0H@("`@("`@('T-"B`@("`@
M("`@)&EN9F\@/2!A<G)A>2@-"B`@("`@("`@("`@("=296QE87-E(%1Y<&4G
M(#T^("1R96QE87-E+`T*("`@("`@("`@("`@)TYA;64G(#T^("1E>'1E;F1S
M+`T*("`@("`@("`@("`@)T-H86YN96PG(#T^("1O8FHM/F=E=$-H86YN96PH
M*2P-"B`@("`@("`@("`@("=3=6UM87)Y)R`]/B!P<F5G7W)E<&QA8V4H)R\@
M("LO)RP@)R`G+"`D;V)J+3YG9713=6UM87)Y*"DI+`T*("`@("`@("`@("`@
M)T1E<V-R:7!T:6]N)R`]/B!P<F5G7W)E<&QA8V4H)R\@("LO)RP@)R`G+"`D
M;V)J+3YG971$97-C<FEP=&EO;B@I*2P-"B`@("`@("`@("`@("D[#0H@("`@
M("`@("1I;F9O6R=-86EN=&%I;F5R<R==(#T@)R<[#0H@("`@("`@(&9O<F5A
M8V@@*&%R<F%Y*"=L96%D)RP@)V1E=F5L;W!E<B<L("=C;VYT<FEB=71O<B<L
M("=H96QP97(G*2!A<R`D<F]L92D@>PT*("`@("`@("`@("`@)&QE861S(#T@
M)&]B:BT^>R)G971[)')O;&5]<R)]*"D[#0H@("`@("`@("`@("!I9B`H(21L
M96%D<RD@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1L96%D<ULG86-T:79E)UTI
M*2![#0H@("`@("`@("`@("`@("`@)&QE861S(#T@87)R87DH)&QE861S*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1L96%D<R!A
M<R`D;&5A9"D@>PT*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&EN9F];
M)TUA:6YT86EN97)S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1I;F9O
M6R=-86EN=&%I;F5R<R==("X](")<;B([#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("1I;F9O6R=-86EN=&%I;F5R<R==("X]("1L96%D
M6R=N86UE)UT@+B`G(#PG.PT*("`@("`@("`@("`@("`@("1I;F9O6R=-86EN
M=&%I;F5R<R==("X]("1L96%D6R=E;6%I;"==("X@(CX@*"1R;VQE*2([#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&EN9F];)U)E;&5A
M<V4@1&%T92==(#T@)&]B:BT^9V5T1&%T92@I.PT*("`@("`@("!I9B`H)'1I
M;64@/2`D;V)J+3YG9714:6UE*"DI('L-"B`@("`@("`@("`@("1I;F9O6R=2
M96QE87-E($1A=&4G72`N/2`G("<@+B`D=&EM93L-"B`@("`@("`@?0T*("`@
M("`@("`D:6YF;ULG4F5L96%S92!697)S:6]N)UT@/2`D;V)J+3YG971697)S
M:6]N*"D@+B`G("@G("X@)&]B:BT^9V5T4W1A=&4H*2`N("<I)SL-"B`@("`@
M("`@)&EN9F];)T%022!697)S:6]N)UT@/2`D;V)J+3YG971697)S:6]N*"=A
M<&DG*2`N("<@*"<@+B`D;V)J+3YG9713=&%T92@G87!I)RD@+B`G*2<[#0H@
M("`@("`@("1I;F9O6R=,:6-E;G-E)UT@/2`D;V)J+3YG971,:6-E;G-E*"D[
M#0H@("`@("`@("1U<FD@/2`D;V)J+3YG971,:6-E;G-E3&]C871I;VXH*3L-
M"B`@("`@("`@:68@*"1U<FDI('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D
M=7)I6R=U<FDG72DI('L-"B`@("`@("`@("`@("`@("`D:6YF;ULG3&EC96YS
M92==("X]("<@*"<@+B`D=7)I6R=U<FDG72`N("<I)SL-"B`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@)&5X=')A(#T@)&]B:BT^9V5T
M26YS=&%L;&5D3&]C871I;VXH)&EN9F];)V9I;&5S;W5R8V4G72D[#0H@("`@
M("`@("`@("`@("`@:68@*"1E>'1R82D@>PT*("`@("`@("`@("`@("`@("`@
M("`D:6YF;ULG3&EC96YS92==("X]("<@*"<@+B`D=7)I6R=F:6QE<V]U<F-E
M)UT@+B`G*2<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@("1I;F9O6R=296QE87-E($YO=&5S)UT@/2`D
M;V)J+3YG971.;W1E<R@I.PT*("`@("`@("!I9B`H)&-O;7!A="`]("1O8FHM
M/F=E=$-O;7!A=&EB;&4H*2D@>PT*("`@("`@("`@("`@)&EN9F];)T-O;7!A
M=&EB;&4@=VET:"==(#T@)R<[#0H@("`@("`@("`@("!F;W)E86-H("@D8V]M
M<&%T(&%S("1P86-K86=E*2![#0H@("`@("`@("`@("`@("`@)&EN9F];)T-O
M;7!A=&EB;&4@=VET:"==("X]("1P86-K86=E6R=C:&%N;F5L)UT@+B`G+R<@
M+B`D<&%C:V%G95LG<&%C:V%G92==("X-"B`@("`@("`@("`@("`@("`@("`@
M(EQN5F5R<VEO;G,@/CT@(B`N("1P86-K86=E6R=M:6XG72`N("<L(#P]("<@
M+B`D<&%C:V%G95LG;6%X)UT[#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1P86-K86=E6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M(&EF("AI<U]A<G)A>2@D<&%C:V%G95LG97AC;'5D92==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'!A8VMA9V5;)V5X8VQU9&4G72`](&EM<&QO
M9&4H)RP@)RP@)'!A8VMA9V5;)V5X8VQU9&4G72D[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D:6YF
M;ULG3F]T($-O;7!A=&EB;&4@=VET:"==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)&EN9F];)TYO="!#;VUP871I8FQE('=I=&@G72`]("<G.PT*
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)&EN9F];)TYO="!#;VUP871I8FQE('=I=&@G72`N/2`B7&XB
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("1I;F9O6R=.;W0@0V]M<&%T:6)L92!W:71H)UT@+CT@)'!A8VMA9V5;)V-H
M86YN96PG72`N("<O)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&%C
M:V%G95LG<&%C:V%G92==("X@(EQN5F5R<VEO;G,@(B`N("1P86-K86=E6R=E
M>&-L=61E)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@("1U<V5S<F]L92`]("1O8FHM/F=E=%5S97-R
M;VQE*"D[#0H@("`@("`@(&EF("@D=7-E<W)O;&4I('L-"B`@("`@("`@("`@
M(&EF("@A:7-S970H)'5S97-R;VQE6S!=*2D@>PT*("`@("`@("`@("`@("`@
M("1U<V5S<F]L92`](&%R<F%Y*"1U<V5S<F]L92D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!F;W)E86-H("@D=7-E<W)O;&4@87,@)')O;&5D871A
M*2![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=5<V5S($-U
M<W1O;2!2;VQE<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D:6YF;ULG
M57-E<R!#=7-T;VT@4F]L97,G72`N/2`B7&XB.PT*("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1I;F9O6R=5<V5S($-U
M<W1O;2!2;VQE<R==(#T@)R<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D<F]L961A=&%;)W!A8VMA9V4G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)')O;&5P86-K86=E(#T@)')E9RT^<&%R
M<V5D4&%C:V%G94YA;654;U-T<FEN9R@D<F]L961A=&$L('1R=64I.PT*("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1R
M;VQE<&%C:V%G92`]("1R;VQE9&%T85LG=7)I)UT[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("1I;F9O6R=5<V5S($-U<W1O;2!2;VQE
M<R==("X]("1R;VQE9&%T85LG<F]L92==("X@)R`H)R`N("1R;VQE<&%C:V%G
M92`N("<I)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D
M=7-E<W1A<VL@/2`D;V)J+3YG9715<V5S=&%S:R@I.PT*("`@("`@("!I9B`H
M)'5S97-T87-K*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1U<V5S=&%S
M:ULP72DI('L-"B`@("`@("`@("`@("`@("`D=7-E<W1A<VL@/2!A<G)A>2@D
M=7-E<W1A<VLI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C
M:"`H)'5S97-T87-K(&%S("1T87-K9&%T82D@>PT*("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D:6YF;ULG57-E<R!#=7-T;VT@5&%S:W,G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@)&EN9F];)U5S97,@0W5S=&]M(%1A<VMS)UT@
M+CT@(EQN(CL-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`D:6YF;ULG57-E<R!#=7-T;VT@5&%S:W,G72`]("<G.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)'1A<VMD871A6R=P86-K86=E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("1T87-K<&%C:V%G92`]("1R96<M/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I
M;F<H)'1A<VMD871A+"!T<G5E*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("`D=&%S:W!A8VMA9V4@/2`D=&%S:V1A
M=&%;)W5R:2==.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`D:6YF;ULG57-E<R!#=7-T;VT@5&%S:W,G72`N/2`D=&%S:V1A=&%;)W1A
M<VLG72`N("<@*"<@+B`D=&%S:W!A8VMA9V4@+B`G*2<[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@)&1E<',@/2`D;V)J+3YG971$97!E
M;F1E;F-I97,H*3L-"B`@("`@("`@)&EN9F];)U)E<75I<F5D($1E<&5N9&5N
M8VEE<R==(#T@)U!(4"!V97)S:6]N("<@+B`D9&5P<ULG<F5Q=6ER960G75LG
M<&AP)UU;)VUI;B==.PT*("`@("`@("!I9B`H:7-S970H)&1E<'-;)W)E<75I
M<F5D)UU;)W!H<"==6R=M87@G72DI('L-"B`@("`@("`@("`@("1I;F9O6R=2
M97%U:7)E9"!$97!E;F1E;F-I97,G72`N/2`G+2<@+B`D9&5P<ULG<F5Q=6ER
M960G75LG<&AP)UU;)VUA>"==("X@(EQN(CL-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("1I;F9O6R=297%U:7)E9"!$97!E;F1E;F-I97,G72`N
M/2`B7&XB.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P<ULG
M<F5Q=6ER960G75LG<&AP)UU;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@
M(&EF("@A:7-S970H)&EN9F];)TYO="!#;VUP871I8FQE('=I=&@G72DI('L-
M"B`@("`@("`@("`@("`@("`D:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==
M(#T@)R<[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("1I;F9O6R=.;W0@0V]M<&%T:6)L92!W:71H)UT@+CT@(EQN(CL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D9&5P<ULG<F5Q
M=6ER960G75LG<&AP)UU;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@("`@
M("`D9&5P<ULG<F5Q=6ER960G75LG<&AP)UU;)V5X8VQU9&4G72`]#0H@("`@
M("`@("`@("`@("`@("`@(&EM<&QO9&4H)RP@)RP@)&1E<'-;)W)E<75I<F5D
M)UU;)W!H<"==6R=E>&-L=61E)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@)&EN9F];)TYO="!#;VUP871I8FQE('=I=&@G72`N/2`B4$A0('9E
M<G-I;VYS7&X@("(@+@T*("`@("`@("`@("`@("`@("1D97!S6R=R97%U:7)E
M9"==6R=P:'`G75LG97AC;'5D92==.PT*("`@("`@("!]#0H@("`@("`@("1I
M;F9O6R=297%U:7)E9"!$97!E;F1E;F-I97,G72`N/2`G4$5!4B!I;G-T86QL
M97(@=F5R<VEO;B<[#0H@("`@("`@(&EF("AI<W-E="@D9&5P<ULG<F5Q=6ER
M960G75LG<&5A<FEN<W1A;&QE<B==6R=M87@G72DI('L-"B`@("`@("`@("`@
M("1I;F9O6R=297%U:7)E9"!$97!E;F1E;F-I97,G72`N/2`G<R`G("X-"B`@
M("`@("`@("`@("`@("`D9&5P<ULG<F5Q=6ER960G75LG<&5A<FEN<W1A;&QE
M<B==6R=M:6XG72`N("<M)R`N#0H@("`@("`@("`@("`@("`@)&1E<'-;)W)E
M<75I<F5D)UU;)W!E87)I;G-T86QL97(G75LG;6%X)UT[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`D:6YF;ULG4F5Q=6ER960@1&5P96YD96YC
M:65S)UT@+CT@)R`G("X-"B`@("`@("`@("`@("`@("`D9&5P<ULG<F5Q=6ER
M960G75LG<&5A<FEN<W1A;&QE<B==6R=M:6XG72`N("<@;W(@;F5W97(G.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P<ULG<F5Q=6ER960G
M75LG<&5A<FEN<W1A;&QE<B==6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1I;F9O6R=.;W0@0V]M<&%T:6)L92!W:71H)UTI*2![
M#0H@("`@("`@("`@("`@("`@)&EN9F];)TYO="!#;VUP871I8FQE('=I=&@G
M72`]("<G.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`D:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==("X](")<;B([#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-?87)R87DH)&1E<'-;)W)E
M<75I<F5D)UU;)W!E87)I;G-T86QL97(G75LG97AC;'5D92==*2D@>PT*("`@
M("`@("`@("`@("`@("1D97!S6R=R97%U:7)E9"==6R=P96%R:6YS=&%L;&5R
M)UU;)V5X8VQU9&4G72`]#0H@("`@("`@("`@("`@("`@("`@(&EM<&QO9&4H
M)RP@)RP@)&1E<'-;)W)E<75I<F5D)UU;)W!E87)I;G-T86QL97(G75LG97AC
M;'5D92==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1I;F9O6R=.
M;W0@0V]M<&%T:6)L92!W:71H)UT@+CT@(E!%05(@:6YS=&%L;&5R7&X@(%9E
M<G-I;VYS("(@+@T*("`@("`@("`@("`@("`@("1D97!S6R=R97%U:7)E9"==
M6R=P96%R:6YS=&%L;&5R)UU;)V5X8VQU9&4G73L-"B`@("`@("`@?0T*("`@
M("`@("!F;W)E86-H("AA<G)A>2@G4&%C:V%G92<L("=%>'1E;G-I;VXG*2!A
M<R`D='EP92D@>PT*("`@("`@("`@("`@)&EN9&5X(#T@<W1R=&]L;W=E<B@D
M='EP92D[#0H@("`@("`@("`@("!I9B`H:7-S970H)&1E<'-;)W)E<75I<F5D
M)UU;)&EN9&5X72DI('L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E
M<'-;)W)E<75I<F5D)UU;)&EN9&5X75LG;F%M92==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D9&5P<ULG<F5Q=6ER960G75LD:6YD97A=(#T@87)R87DH
M)&1E<'-;)W)E<75I<F5D)UU;)&EN9&5X72D[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1D97!S6R=R97%U:7)E9"==
M6R1I;F1E>%T@87,@)'!A8VMA9V4I('L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1P86-K86=E6R=C;VYF;&EC=',G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1I;F9O:6YD97@@/2`G3F]T($-O;7!A=&EB;&4@
M=VET:"<[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1I
M;F9O6R=.;W0@0V]M<&%T:6)L92!W:71H)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&EN9F];)TYO="!#;VUP871I8FQE('=I=&@G72`]
M("<G.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULG3F]T($-O;7!A=&EB;&4@
M=VET:"==("X](")<;B([#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D:6YF;VEN9&5X(#T@)U)E<75I<F5D($1E<&5N9&5N8VEE<R<[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULD:6YF;VEN9&5X72`N
M/2`B7&XB.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@D:6YD97@@/3T@)V5X=&5N<VEO;B<I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1N86UE(#T@)'!A8VMA9V5;)VYA;64G73L-"B`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG8VAA;FYE;"==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE(#T@)'!A8VMA9V5;)V-H
M86YN96PG72`N("<O)R`N("1P86-K86=E6R=N86UE)UT[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1N86UE(#T@)U]?=7)I+R<@+B`D<&%C:V%G95LG;F%M92==("X@
M)R`H<W1A=&EC(%5222DG.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1I
M;F9O6R1I;F9O:6YD97A=("X]("(D='EP92`D;F%M92([#0H@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG=7)I)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D:6YF;ULD:6YF;VEN9&5X72`N/2`B7&X@
M($1O=VYL;V%D(%5223H@)'!A8VMA9V5;=7)I72([#0H@("`@("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;)VUA>"==
M*2`F)B!I<W-E="@D<&%C:V%G95LG;6EN)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D:6YF;ULD:6YF;VEN9&5X72`N/2`B(%QN("!697)S:6]N
M<R`B("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%C:V%G95LG
M;6EN)UT@+B`G+2<@+B`D<&%C:V%G95LG;6%X)UT[#0H@("`@("`@("`@("`@
M("`@("`@('T@96QS96EF("AI<W-E="@D<&%C:V%G95LG;6EN)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULD:6YF;VEN9&5X72`N/2`B
M(%QN("!697)S:6]N("(@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1P86-K86=E6R=M:6XG72`N("<@;W(@;F5W97(G.PT*("`@("`@("`@("`@
M("`@("`@("!](&5L<V5I9B`H:7-S970H)'!A8VMA9V5;)VUA>"==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];)&EN9F]I;F1E>%T@+CT@
M(B!<;B`@5F5R<VEO;B`B("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<&%C:V%G95LG;6%X)UT@+B`G(&]R(&]L9&5R)SL-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A
M8VMA9V5;)W)E8V]M;65N9&5D)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D:6YF;ULD:6YF;VEN9&5X72`N/2`B7&X@(%)E8V]M;65N9&5D('9E
M<G-I;VXZ("1P86-K86=E6W)E8V]M;65N9&5D72([#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P86-K
M86=E6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1I;F9O6R=.;W0@0V]M<&%T:6)L92!W:71H)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];)TYO="!#;VUP871I
M8FQE('=I=&@G72`]("<G.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULG3F]T
M($-O;7!A=&EB;&4@=VET:"==("X](")<;B([#0H@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-?87)R
M87DH)'!A8VMA9V5;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<&%C:V%G95LG97AC;'5D92==(#T@:6UP;&]D92@G+"`G
M+"`D<&%C:V%G95LG97AC;'5D92==*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=P86-K
M86=E)UT@/2`D<&%C:V%G95LG;F%M92==.R`O+R!F;W(@<&%R<V5D4&%C:V%G
M94YA;654;U-T<FEN9PT*("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D<&%C:V%G95LG8V]N9FQI8W1S)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&EN9F];)TYO="!#;VUP871I8FQE('=I=&@G72`N
M/2`G/3X@97AC97!T("<[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R=.;W0@0V]M<&%T:6)L92!W
M:71H)UT@+CT@)U!A8VMA9V4@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)')E9RT^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@D<&%C:V%G
M92P@=')U92D[#0H@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULG3F]T
M($-O;7!A=&EB;&4@=VET:"==("X](")<;B`@5F5R<VEO;G,@(B`N("1P86-K
M86=E6R=E>&-L=61E)UT[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&ES<V5T*"1D97!S6R=R97%U:7)E9"==6R=O<R==*2D@>PT*("`@
M("`@("`@("`@:68@*&ES<V5T*"1D97!S6R=R97%U:7)E9"==6R=O<R==6R=N
M86UE)UTI*2![#0H@("`@("`@("`@("`@("`@)&1E<%LG<F5Q=6ER960G75LG
M;W,G75LG;F%M92==(#T@87)R87DH)&1E<%LG<F5Q=6ER960G75LG;W,G75LG
M;F%M92==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@
M*"1D97!;)W)E<75I<F5D)UU;)V]S)UT@87,@)&]S*2![#0H@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1O<ULG8V]N9FQI8W1S)UTI("8F("1O<ULG8V]N
M9FQI8W1S)UT@/3T@)WEE<R<I('L-"B`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)&EN9F];)TYO="!#;VUP871I8FQE('=I
M=&@G72`]("<G.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)&EN9F];)TYO="!#;VUP871I8FQE('=I
M=&@G72`N/2`B7&XB.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("1I;F9O6R=.;W0@0V]M<&%T:6)L92!W:71H)UT@+CT@
M(B1O<UMN86UE72!/<&5R871I;F<@4WES=&5M(CL-"B`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D:6YF;ULG4F5Q=6ER
M960@1&5P96YD96YC:65S)UT@+CT@(EQN(CL-"B`@("`@("`@("`@("`@("`@
M("`@)&EN9F];)U)E<75I<F5D($1E<&5N9&5N8VEE<R==("X]("(D;W-;;F%M
M95T@3W!E<F%T:6YG(%-Y<W1E;2([#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P
M<ULG<F5Q=6ER960G75LG87)C:"==*2D@>PT*("`@("`@("`@("`@:68@*&ES
M<V5T*"1D97!S6R=R97%U:7)E9"==6R=A<F-H)UU;)W!A='1E<FXG72DI('L-
M"B`@("`@("`@("`@("`@("`D9&5P6R=R97%U:7)E9"==6R=A<F-H)UU;)W!A
M='1E<FXG72`](&%R<F%Y*"1D97!;)W)E<75I<F5D)UU;)V]S)UU;)W!A='1E
M<FXG72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E86-H("@D
M9&5P6R=R97%U:7)E9"==6R=A<F-H)UT@87,@)&]S*2![#0H@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1O<ULG8V]N9FQI8W1S)UTI("8F("1O<ULG8V]N
M9FQI8W1S)UT@/3T@)WEE<R<I('L-"B`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)&EN9F];)TYO="!#;VUP871I8FQE('=I
M=&@G72`]("<G.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)&EN9F];)TYO="!#;VUP871I8FQE('=I
M=&@G72`N/2`B7&XB.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("1I;F9O6R=.;W0@0V]M<&%T:6)L92!W:71H)UT@+CT@
M(D]3+T%R8V@@;6%T8VAI;F<@<&%T=&5R;B`G+R1O<UMP871T97)N72\G(CL-
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@
M("`D:6YF;ULG4F5Q=6ER960@1&5P96YD96YC:65S)UT@+CT@(EQN(CL-"B`@
M("`@("`@("`@("`@("`@("`@)&EN9F];)U)E<75I<F5D($1E<&5N9&5N8VEE
M<R==("X](")/4R]!<F-H(&UA=&-H:6YG('!A='1E<FX@)R\D;W-;<&%T=&5R
M;ETO)R([#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P<ULG;W!T:6]N86PG72DI
M('L-"B`@("`@("`@("`@(&9O<F5A8V@@*&%R<F%Y*"=086-K86=E)RP@)T5X
M=&5N<VEO;B<I(&%S("1T>7!E*2![#0H@("`@("`@("`@("`@("`@)&EN9&5X
M(#T@<W1R=&]L;W=E<B@D='EP92D[#0H@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1D97!S6R=O<'1I;VYA;"==6R1I;F1E>%TI*2![#0H@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D9&5P<ULG;W!T:6]N86PG75LD:6YD97A=
M6R=N86UE)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D9&5P<ULG
M;W!T:6]N86PG75LD:6YD97A=(#T@87)R87DH)&1E<'-;)V]P=&EO;F%L)UU;
M)&EN9&5X72D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&1E<'-;)V]P=&EO;F%L)UU;)&EN9&5X72!A
M<R`D<&%C:V%G92D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1P86-K86=E6R=C;VYF;&EC=',G72D@)B8@)'!A8VMA9V5;)V-O;F9L
M:6-T<R==(#T]("=Y97,G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&EN9F]I;F1E>"`]("=.;W0@0V]M<&%T:6)L92!W:71H)SL-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1I;F9O6R=.;W0@
M0V]M<&%T:6)L92!W:71H)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1I;F9O6R=.;W0@0V]M<&%T:6)L92!W:71H)UT@/2`G)SL-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULG3F]T($-O;7!A=&EB
M;&4@=VET:"==("X](")<;B([#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D:6YF;VEN9&5X(#T@)T]P=&EO;F%L
M($1E<&5N9&5N8VEE<R<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D:6YF;ULG3W!T:6]N86P@1&5P96YD96YC:65S)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R=/<'1I
M;VYA;"!$97!E;F1E;F-I97,G72`]("<G.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1I;F9O6R=/<'1I;VYA;"!$97!E;F1E;F-I97,G72`N/2`B7&XB
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D
M:6YD97@@/3T@)V5X=&5N<VEO;B<I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D;F%M92`]("1P86-K86=E6R=N86UE)UT[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG8VAA;FYE;"==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F%M92`]("1P86-K86=E
M6R=C:&%N;F5L)UT@+B`G+R<@+B`D<&%C:V%G95LG;F%M92==.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1N86UE(#T@)U]?=7)I+R<@+B`D<&%C:V%G
M95LG;F%M92==("X@)R`H<W1A=&EC(%5222DG.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R1I;F9O:6YD97A=("X]("(D
M='EP92`D;F%M92([#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)'!A8VMA9V5;)W5R:2==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1I;F9O6R1I;F9O:6YD97A=("X](")<;B`@1&]W;FQO860@55))
M.B`D<&%C:V%G95MU<FE=(CL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("@D:6YF;VEN9&5X(#T]("=.;W0@0V]M
M<&%T:6)L92!W:71H)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("\O(&-O;F9L:6-T<R!I<R!O;FQY('5S960@=&\@<V%Y('1H870@86QL('9E
M<G-I;VYS(&-O;F9L:6-T#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;)VUA>"==*2`F
M)B!I<W-E="@D<&%C:V%G95LG;6EN)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&EN9F];)&EN9F]I;F1E>%T@+CT@(B!<;B`@5F5R<VEO
M;G,@(B`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P86-K
M86=E6R=M:6XG72`N("<M)R`N("1P86-K86=E6R=M87@G73L-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D<&%C:V%G95LG;6EN
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];)&EN
M9F]I;F1E>%T@+CT@(B!<;B`@5F5R<VEO;B`B("X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!A8VMA9V5;)VUI;B==("X@)R!O<B!N97=E
M<B<[#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H
M)'!A8VMA9V5;)VUA>"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1I;F9O6R1I;F9O:6YD97A=("X]("(@7&X@(%9E<G-I;VX@(B`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=M:6XG
M72`N("<@;W(@;VQD97(G.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P86-K86=E6R=R
M96-O;6UE;F1E9"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1I;F9O6R1I;F9O:6YD97A=("X](")<;B`@4F5C;VUM96YD960@=F5R<VEO
M;CH@)'!A8VMA9V5;<F5C;VUM96YD961=(CL-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M<&%C:V%G95LG97AC;'5D92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)&EN9F];)TYO="!#;VUP871I8FQE('=I=&@G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];
M)TYO="!#;VUP871I8FQE('=I=&@G72`]("<G.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1I;F9O6R=.;W0@0V]M<&%T:6)L92!W:71H)UT@+CT@(EQN
M(CL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1P86-K86=E6R=E>&-L
M=61E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M86-K86=E6R=E>&-L=61E)UT@/2!I;7!L;V1E*"<L("<L("1P86-K86=E6R=E
M>&-L=61E)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULG3F]T($-O;7!A=&EB
M;&4@=VET:"==("X](")086-K86=E("1P86-K86=E7&X@(%9E<G-I;VYS("(@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%C:V%G95LG
M97AC;'5D92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P<ULG9W)O
M=7`G72DI('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&1E<'-;)V=R;W5P
M)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@)&1E<'-;)V=R;W5P)UT@/2!A
M<G)A>2@D9&5P<ULG9W)O=7`G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!F;W)E86-H("@D9&5P<ULG9W)O=7`G72!A<R`D9W)O=7`I('L-"B`@
M("`@("`@("`@("`@("`D:6YF;ULG1&5P96YD96YC>2!'<F]U<"`G("X@)&=R
M;W5P6R=A='1R:6)S)UU;)VYA;64G75T@/2`D9W)O=7!;)V%T=')I8G,G75LG
M:&EN="==.PT*("`@("`@("`@("`@("`@("1G<F]U<&EN9&5X(#T@)&=R;W5P
M6R=A='1R:6)S)UU;)VYA;64G72`N("<@0V]N=&5N=',G.PT*("`@("`@("`@
M("`@("`@("1I;F9O6R1G<F]U<&EN9&5X72`]("<G.PT*("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*&%R<F%Y*"=086-K86=E)RP@)T5X=&5N<VEO;B<I(&%S
M("1T>7!E*2![#0H@("`@("`@("`@("`@("`@("`@("1I;F1E>"`]('-T<G1O
M;&]W97(H)'1Y<&4I.PT*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)&=R;W5P6R1I;F1E>%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)&=R;W5P6R1I;F1E>%U;)VYA;64G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9W)O=7!;)&EN9&5X72`](&%R<F%Y*"1G
M<F]U<%LD:6YD97A=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1G<F]U<%LD:6YD97A=
M(&%S("1P86-K86=E*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"%E;7!T>2@D:6YF;ULD9W)O=7!I;F1E>%TI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R1G<F]U<&EN9&5X72`N/2`B
M7&XB.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H)&EN9&5X(#T]("=E>'1E;G-I;VXG
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE(#T@
M)'!A8VMA9V5;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)'!A8VMA9V5;)V-H86YN96PG72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE(#T@)'!A8VMA9V5;)V-H
M86YN96PG72`N("<O)R`N("1P86-K86=E6R=N86UE)UT[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D;F%M92`]("=?7W5R:2\G("X@)'!A
M8VMA9V5;)VYA;64G72`N("<@*'-T871I8R!54DDI)SL-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)'!A8VMA9V5;)W5R:2==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;)V-O;F9L:6-T<R==*2`F
M)B`D<&%C:V%G95LG8V]N9FQI8W1S)UT@/3T@)WEE<R<I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R1G<F]U<&EN9&5X
M72`N/2`B3F]T($-O;7!A=&EB;&4@=VET:"`D='EP92`D;F%M92([#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULD9W)O=7!I;F1E
M>%T@+CT@(B1T>7!E("1N86UE(CL-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M:6YF;ULD9W)O=7!I;F1E>%T@+CT@(EQN("!$;W=N;&]A9"!54DDZ("1P86-K
M86=E6W5R:5TB.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C
M;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P86-K86=E6R=C
M;VYF;&EC=',G72D@)B8@)'!A8VMA9V5;)V-O;F9L:6-T<R==(#T]("=Y97,G
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R1G
M<F]U<&EN9&5X72`N/2`B3F]T($-O;7!A=&EB;&4@=VET:"`D='EP92`D;F%M
M92([#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D:6YF;ULD9W)O=7!I;F1E>%T@+CT@(B1T>7!E
M("1N86UE(CL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)'!A8VMA9V5;)VUA>"==*2`F)B!I<W-E="@D<&%C:V%G95LG;6EN)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R1G
M<F]U<&EN9&5X72`N/2`B(%QN("!697)S:6]N<R`B("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=M:6XG72`N("<M
M)R`N("1P86-K86=E6R=M87@G73L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H:7-S970H)'!A8VMA9V5;)VUI;B==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULD9W)O=7!I;F1E
M>%T@+CT@(B!<;B`@5F5R<VEO;B`B("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P86-K86=E6R=M:6XG72`N("<@;W(@;F5W97(G
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI<W-E
M="@D<&%C:V%G95LG;6%X)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1I;F9O6R1G<F]U<&EN9&5X72`N/2`B(%QN("!697)S:6]N
M("(@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A
M8VMA9V5;)VUI;B==("X@)R!O<B!O;&1E<B<[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D<&%C:V%G95LG<F5C;VUM96YD960G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];)&=R;W5P:6YD97A=("X]
M(")<;B`@4F5C;VUM96YD960@=F5R<VEO;CH@)'!A8VMA9V5;<F5C;VUM96YD
M961=(CL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P86-K86=E6R=E>&-L
M=61E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)&EN9F];)TYO="!#;VUP871I8FQE('=I=&@G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R=.;W0@
M0V]M<&%T:6)L92!W:71H)UT@/2`G)SL-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1I;F9O6R1G<F]U<&EN9&5X72`N/2`B3F]T($-O;7!A
M=&EB;&4@=VET:%QN(CL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-?
M87)R87DH)'!A8VMA9V5;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=E>&-L=61E)UT@/2!I
M;7!L;V1E*"<L("<L("1P86-K86=E6R=E>&-L=61E)UTI.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1I;F9O6R1G<F]U<&EN9&5X72`N/2`B("!086-K86=E
M("1P86-K86=E7&X@(%9E<G-I;VYS("(@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!A8VMA9V5;)V5X8VQU9&4G73L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1O
M8FHM/F=E=%!A8VMA9V54>7!E*"D@/3T@)V)U;F1L92<I('L-"B`@("`@("`@
M("`@("1I;F9O6R="=6YD;&5D(%!A8VMA9V5S)UT@/2`G)SL-"B`@("`@("`@
M("`@(&9O<F5A8V@@*"1O8FHM/F=E=$)U;F1L961086-K86=E<R@I(&%S("1P
M86-K86=E*2![#0H@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D:6YF;ULG
M0G5N9&QE9"!086-K86=E<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M:6YF;ULG0G5N9&QE9"!086-K86=E<R==("X](")<;B([#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG
M=7)I)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1I;F9O6R="=6YD;&5D
M(%!A8VMA9V5S)UT@+CT@)U]?=7)I+R<@+B`D<&%C:V%G95LG;F%M92==.PT*
M("`@("`@("`@("`@("`@("`@("`D:6YF;ULG0G5N9&QE9"!086-K86=E<R==
M("X](")<;B`@*%5223H@)'!A8VMA9V5;=7)I72([#0H@("`@("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)&EN9F];)T)U;F1L
M960@4&%C:V%G97,G72`N/2`D<&%C:V%G95LG8VAA;FYE;"==("X@)R\G("X@
M)'!A8VMA9V5;)VYA;64G73L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&EN9F];)W!A8VMA9V4N>&UL
M('9E<G-I;VXG72`]("<R+C`G.PT*("`@("`@("!I9B`H)&EN<W1A;&QE9"D@
M>PT*("`@("`@("`@("`@:68@*"1O8FHM/F=E=$QA<W1-;V1I9FEE9"@I*2![
M#0H@("`@("`@("`@("`@("`@)&EN9F];)TQA<W0@36]D:69I960G72`](&1A
M=&4H)UDM;2UD($@Z:2<L("1O8FHM/F=E=$QA<W1-;V1I9FEE9"@I*3L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("1V(#T@)&]B:BT^9V5T3&%S=$EN
M<W1A;&QE9%9E<G-I;VXH*3L-"B`@("`@("`@("`@("1I;F9O6R=,87-T($EN
M<W1A;&QE9"!697)S:6]N)UT@/2`D=B`_("1V(#H@)RT@3F]N92`M)SL-"B`@
M("`@("`@?0T*("`@("`@("!F;W)E86-H("@D:6YF;R!A<R`D:V5Y(#T^("1V
M86QU92D@>PT*("`@("`@("`@("`@)&1A=&%;)V1A=&$G75M=(#T@87)R87DH
M)&ME>2P@)'9A;'5E*3L-"B`@("`@("`@?0T*("`@("`@("`D9&%T85LG<F%W
M)UT@/2`D;V)J+3YG971!<G)A>2@I.R`O+R!N;R!V86QI9&%T:6]N(&YE961E
M9`T*#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D9&%T82P@)W!A
M8VMA9V4M:6YF;R<I.PT*("`@('T-"GT-"@T*/SX-"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O4$5!4B]#;VUM86YD+U)E9VES=')Y+GAM;```````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#,R-C4`,3`U,34T,S,W-#``,#(S,C0V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#QC;VUM86YD<R!V
M97)S:6]N/2(Q+C`B/@T*(#QL:7-T/@T*("`\<W5M;6%R>3Y,:7-T($EN<W1A
M;&QE9"!086-K86=E<R!);B!4:&4@1&5F875L="!#:&%N;F5L/"]S=6UM87)Y
M/@T*("`\9G5N8W1I;VX^9&],:7-T/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T
M/FP\+W-H;W)T8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QC:&%N;F5L/@T*("`@
M(#QS:&]R=&]P=#YC/"]S:&]R=&]P=#X-"B`@("`\9&]C/FQI<W0@:6YS=&%L
M;&5D('!A8VMA9V5S(&9R;VT@=&AI<R!C:&%N;F5L/"]D;V,^#0H@("`@/&%R
M9SY#2$%./"]A<F<^#0H@("`\+V-H86YN96P^#0H@("`\86QL8VAA;FYE;',^
M#0H@("`@/'-H;W)T;W!T/F$\+W-H;W)T;W!T/@T*("`@(#QD;V,^;&ES="!I
M;G-T86QL960@<&%C:V%G97,@9G)O;2!A;&P@8VAA;FYE;',\+V1O8SX-"B`@
M(#PO86QL8VAA;FYE;',^#0H@(#PO;W!T:6]N<SX-"B`@/&1O8SXF;'0[<&%C
M:V%G929G=#L-"DEF(&EN=F]K960@=VET:&]U="!P87)A;65T97)S+"!T:&ES
M(&-O;6UA;F0@;&ES=',@=&AE(%!%05(@<&%C:V%G97,-"FEN<W1A;&QE9"!I
M;B!Y;W5R('!H<%]D:7(@*'MC;VYF:6<@<&AP7V1I<GTI+B`@5VET:"!A('!A
M<F%M971E<BP@:70-"FQI<W1S('1H92!F:6QE<R!I;B!A('!A8VMA9V4N#0H\
M+V1O8SX-"B`\+VQI<W0^#0H@/&QI<W0M9FEL97,^#0H@(#QS=6UM87)Y/DQI
M<W0@1FEL97,@26X@26YS=&%L;&5D(%!A8VMA9V4\+W-U;6UA<GD^#0H@(#QF
M=6YC=&EO;CYD;T9I;&5,:7-T/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/F9L
M/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,@+SX-"B`@/&1O8SXF;'0[<&%C:V%G
M929G=#L-"DQI<W0@=&AE(&9I;&5S(&EN(&%N(&EN<W1A;&QE9"!P86-K86=E
M+@T*/"]D;V,^#0H@/"]L:7-T+69I;&5S/@T*(#QS:&5L;"UT97-T/@T*("`\
M<W5M;6%R>3Y3:&5L;"!38W)I<'0@5&5S=#PO<W5M;6%R>3X-"B`@/&9U;F-T
M:6]N/F1O4VAE;&Q497-T/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/G-T/"]S
M:&]R=&-U=#X-"B`@/&]P=&EO;G,@+SX-"B`@/&1O8SXF;'0[<&%C:V%G929G
M=#L@6UMR96QA=&EO;ET@=F5R<VEO;ET-"E1E<W1S(&EF(&$@<&%C:V%G92!I
M<R!I;G-T86QL960@:6X@=&AE('-Y<W1E;2X@5VEL;"!E>&ET*#$I(&EF(&ET
M(&ES(&YO="X-"B`@("9L=#MR96QA=&EO;B9G=#L@("!4:&4@=F5R<VEO;B!C
M;VUP87)I<V]N(&]P97)A=&]R+B!/;F4@;V8Z#0H@("`@("`@("`@("`@("`@
M)FQT.RP@;'0L("9L=#L]+"!L92P@)F=T.RP@9W0L("9G=#L]+"!G92P@/3TL
M(#TL(&5Q+"`A/2P@)FQT.R9G=#LL(&YE#0H@("`F;'0[=F5R<VEO;B9G=#L@
M("`@5&AE('9E<G-I;VX@=&\@8V]M<&%R92!W:71H#0H\+V1O8SX-"B`\+W-H
M96QL+71E<W0^#0H@/&EN9F\^#0H@(#QS=6UM87)Y/D1I<W!L87D@:6YF;W)M
M871I;VX@86)O=70@82!P86-K86=E/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^
M9&]);F9O/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/FEN/"]S:&]R=&-U=#X-
M"B`@/&]P=&EO;G,@+SX-"B`@/&1O8SXF;'0[<&%C:V%G929G=#L-"D1I<W!L
M87ES(&EN9F]R;6%T:6]N(&%B;W5T(&$@<&%C:V%G92X@5&AE('!A8VMA9V4@
M87)G=6UE;G0@;6%Y(&)E(&$-"FQO8V%L('!A8VMA9V4@9FEL92P@86X@55),
M('1O(&$@<&%C:V%G92!F:6QE+"!O<B!T:&4@;F%M92!O9B!A;@T*:6YS=&%L
M;&5D('!A8VMA9V4N/"]D;V,^#0H@/"]I;F9O/@T*/"]C;VUM86YD<SX`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%
M05(O0V]M;6%N9"]296UO=&4N<&AP````````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#8S-S(S`#$P-3$U-#,S-S0P`#`R,C8V-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`T*+RHJ#0H@*B!0
M14%27T-O;6UA;F1?4F5M;W1E("AR96UO=&4M:6YF;RP@;&ES="UU<&=R861E
M<RP@<F5M;W1E+6QI<W0L('-E87)C:"P@;&ES="UA;&PL(&1O=VYL;V%D+`T*
M("H@8VQE87(M8V%C:&4@8V]M;6%N9',I#0H@*@T*("H@4$A0('9E<G-I;VYS
M(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@
M*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A
M(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*
M("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK
M96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@
M/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H
M92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I
M;VX@("`@0U93.B`D260Z(%)E;6]T92YP:'`L=B`Q+CDP+C(N,B`R,#`V+S`S
M+S(S(#`U.C0U.C$W(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@
M($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"@T*+RHJ
M#0H@*B!B87-E(&-L87-S#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4B]#;VUM
M86YD+T-O;6UO;BYP:'`G.PT*<F5Q=6ER95]O;F-E("=014%2+U)%4U0N<&AP
M)SL-"@T*+RHJ#0H@*B!014%2(&-O;6UA;F1S(&9O<B!R96UO=&4@<V5R=F5R
M('%U97)Y:6YG#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA
M9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P
M:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P
M:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O
M=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L
M96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B
M;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*8VQA<W,@4$5!4E]#;VUM86YD
M7U)E;6]T92!E>'1E;F1S(%!%05)?0V]M;6%N9%]#;VUM;VX-"GL-"B`@("`O
M+R![>WL@8V]M;6%N9"!D969I;FET:6]N<PT*#0H@("`@=F%R("1C;VUM86YD
M<R`](&%R<F%Y*`T*("`@("`@("`G<F5M;W1E+6EN9F\G(#T^(&%R<F%Y*`T*
M("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=);F9O<FUA=&EO;B!!8F]U="!2
M96UO=&4@4&%C:V%G97,G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G
M9&]296UO=&5);F9O)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)W)I
M)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@I+`T*("`@("`@
M("`@("`@)V1O8R<@/3X@)SQP86-K86=E/@T*1V5T(&1E=&%I;',@;VX@82!P
M86-K86=E(&9R;VT@=&AE('-E<G9E<BXG+`T*("`@("`@("`@("`@*2P-"B`@
M("`@("`@)VQI<W0M=7!G<F%D97,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M)W-U;6UA<GDG(#T^("=,:7-T($%V86EL86)L92!5<&=R861E<R<L#0H@("`@
M("`@("`@("`G9G5N8W1I;VXG(#T^("=D;TQI<W15<&=R861E<R<L#0H@("`@
M("`@("`@("`G<VAO<G1C=70G(#T^("=L=2<L#0H@("`@("`@("`@("`G;W!T
M:6]N<R<@/3X@87)R87DH*2P-"B`@("`@("`@("`@("=D;V,G(#T^("=;<')E
M9F5R<F5D7W-T871E70T*3&ES="!R96QE87-E<R!O;B!T:&4@<V5R=F5R(&]F
M('!A8VMA9V5S('EO=2!H879E(&EN<W1A;&QE9"!W:&5R90T*82!N97=E<B!V
M97)S:6]N(&ES(&%V86EL86)L92!W:71H('1H92!S86UE(')E;&5A<V4@<W1A
M=&4@*'-T86)L92!E=&,N*0T*;W(@=&AE('-T871E('!A<W-E9"!A<R!T:&4@
M<V5C;VYD('!A<F%M971E<BXG#0H@("`@("`@("`@("`I+`T*("`@("`@("`G
M<F5M;W1E+6QI<W0G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG
M(#T^("=,:7-T(%)E;6]T92!086-K86=E<R<L#0H@("`@("`@("`@("`G9G5N
M8W1I;VXG(#T^("=D;U)E;6]T94QI<W0G+`T*("`@("`@("`@("`@)W-H;W)T
M8W5T)R`]/B`G<FPG+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("=C:&%N;F5L)R`]/@T*("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T
M)R`]/B`G8R<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=S<&5C
M:69Y(&$@8VAA;FYE;"!O=&AE<B!T:&%N('1H92!D969A=6QT(&-H86YN96PG
M+`T*("`@("`@("`@("`@("`@("`@("`G87)G)R`]/B`G0TA!3B<L#0H@("`@
M("`@("`@("`@("`@("`@("D-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@
M("`@("`@)V1O8R<@/3X@)PT*3&ES=',@=&AE('!A8VMA9V5S(&%V86EL86)L
M92!O;B!T:&4@8V]N9FEG=7)E9"!S97)V97(@86QO;F<@=VET:"!T:&4-"FQA
M=&5S="!S=&%B;&4@<F5L96%S92!O9B!E86-H('!A8VMA9V4N)RP-"B`@("`@
M("`@("`@("DL#0H@("`@("`@("=S96%R8V@G(#T^(&%R<F%Y*`T*("`@("`@
M("`@("`@)W-U;6UA<GDG(#T^("=396%R8V@@<F5M;W1E('!A8VMA9V4@9&%T
M86)A<V4G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]396%R8V@G
M+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G<W`G+`T*("`@("`@("`@
M("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=C:&%N
M;F5L)R`]/@T*("`@("`@("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G8R<L#0H@("`@("`@("`@("`@
M("`@("`@("=D;V,G(#T^("=S<&5C:69Y(&$@8VAA;FYE;"!O=&AE<B!T:&%N
M('1H92!D969A=6QT(&-H86YN96PG+`T*("`@("`@("`@("`@("`@("`@("`G
M87)G)R`]/B`G0TA!3B<L#0H@("`@("`@("`@("`@("`@("`@("D-"B`@("`@
M("`@("`@("`@("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)UMP86-K86=E
M;F%M95T@6W!A8VMA9V5I;F9O70T*3&ES=',@86QL('!A8VMA9V5S('=H:6-H
M(&UA=&-H('1H92!S96%R8V@@<&%R86UE=&5R<RX@(%1H92!F:7)S=`T*<&%R
M86UE=&5R(&ES(&$@9G)A9VUE;G0@;V8@82!P86-K86=E;F%M92X@(%1H92!D
M969A=6QT(&-H86YN96P-"G=I;&P@8F4@=7-E9"!U;FQE<W,@97AP;&EC:71L
M>2!O=F5R<FED9&5N+B`@5&AE('-E8V]N9"!P87)A;65T97(-"G=I;&P@8F4@
M=7-E9"!T;R!M871C:"!A;GD@<&]R=&EO;B!O9B!T:&4@<W5M;6%R>2]D97-C
M<FEP=&EO;B<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`G;&ES="UA;&PG
M(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=,:7-T($%L
M;"!086-K86=E<R<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;TQI
M<W1!;&PG+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G;&$G+`T*("`@
M("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@
M("=C:&%N;F5L)R`]/@T*("`@("`@("`@("`@("`@("`@("!A<G)A>2@-"B`@
M("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G8R<L#0H@("`@("`@
M("`@("`@("`@("`@("=D;V,G(#T^("=S<&5C:69Y(&$@8VAA;FYE;"!O=&AE
M<B!T:&%N('1H92!D969A=6QT(&-H86YN96PG+`T*("`@("`@("`@("`@("`@
M("`@("`G87)G)R`]/B`G0TA!3B<L#0H@("`@("`@("`@("`@("`@("`@("D-
M"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)PT*
M3&ES=',@=&AE('!A8VMA9V5S(&%V86EL86)L92!O;B!T:&4@8V]N9FEG=7)E
M9"!S97)V97(@86QO;F<@=VET:"!T:&4-"FQA=&5S="!S=&%B;&4@<F5L96%S
M92!O9B!E86-H('!A8VMA9V4N)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@
M("=D;W=N;&]A9"<@/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@
M/3X@)T1O=VYL;V%D(%!A8VMA9V4G+`T*("`@("`@("`@("`@)V9U;F-T:6]N
M)R`]/B`G9&]$;W=N;&]A9"<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^
M("=D)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`G;F]C;VUP<F5S<R<@/3X@87)R87DH#0H@("`@("`@("`@
M("`@("`@("`@("=S:&]R=&]P="<@/3X@)UHG+`T*("`@("`@("`@("`@("`@
M("`@("`G9&]C)R`]/B`G9&]W;FQO860@86X@=6YC;VUP<F5S<V5D("@N=&%R
M*2!F:6QE)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@
M("`@("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)SQP86-K86=E/BXN+@T*
M1&]W;FQO860@<&%C:V%G92!T87)B86QL<RX@(%1H92!F:6QE<R!W:6QL(&)E
M(&YA;65D(&%S('-U9V=E<W1E9"!B>2!T:&4-"G-E<G9E<BP@9F]R(&5X86UP
M;&4@:68@>6]U(&1O=VYL;V%D('1H92!$0B!P86-K86=E(&%N9"!T:&4@;&%T
M97-T('-T86)L90T*=F5R<VEO;B!O9B!$0B!I<R`Q+C8N-2P@=&AE(&1O=VYL
M;V%D960@9FEL92!W:6QL(&)E($1"+3$N-BXU+G1G>BXG+`T*("`@("`@("`@
M("`@*2P-"B`@("`@("`@)V-L96%R+6-A8VAE)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("=S=6UM87)Y)R`]/B`G0VQE87(@5V5B(%-E<G9I8V5S($-A8VAE
M)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O0VQE87)#86-H92<L
M#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=C8R<L#0H@("`@("`@("`@
M("`G;W!T:6]N<R<@/3X@87)R87DH*2P-"B`@("`@("`@("`@("=D;V,G(#T^
M("<-"D-L96%R('1H92!834PM4E!#+U)%4U0@8V%C:&4N("!3964@86QS;R!T
M:&4@8V%C:&5?='1L(&-O;F9I9W5R871I;VX-"G!A<F%M971E<BX-"B<L#0H@
M("`@("`@("`@("`I+`T*("`@("`@("`I.PT*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(&-O;G-T<G5C=&]R#0H-"B`@("`O*BH-"B`@("`@*B!014%27T-O
M;6UA;F1?4F5M;W1E(&-O;G-T<G5C=&]R+@T*("`@("`J#0H@("`@("H@0&%C
M8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!014%27T-O;6UA
M;F1?4F5M;W1E*"8D=6DL("8D8V]N9FEG*0T*("`@('L-"B`@("`@("`@<&%R
M96YT.CI014%27T-O;6UA;F1?0V]M;6]N*"1U:2P@)&-O;F9I9RD[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H-"B`@("!F=6YC=&EO;B!?8VAE8VM#:&%N;F5L
M1F]R4W1A='5S*"1C:&%N;F5L+"`D8VAA;BD-"B`@("![#0H@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1C:&%N*2D@>PT*("`@("`@("`@("`@)'1H:7,M
M/G)A:7-E17)R;W(H)&-H86XI.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A
M:7-?82@D8VAA;BP@)U!%05)?0VAA;FYE;$9I;&4G*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=);G1E<FYA;"!C;W)R=7!T
M:6]N(&5R<F]R.B!I;G9A;&ED(&-H86YN96P@(B<@+@T*("`@("`@("`@("`@
M("`@("1C:&%N;F5L("X@)R(G*3L-"B`@("`@("`@?0T*("`@("`@("`D<F5S
M="`](&YE=R!014%27U)%4U0H)'1H:7,M/F-O;F9I9RD[#0H@("`@("`@(%!%
M05(Z.G-T871I8U!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).
M*3L-"B`@("`@("`@)&$@/2`D<F5S="T^9&]W;FQO861(='1P*"=H='1P.B\O
M)R`N("1C:&%N;F5L("X-"B`@("`@("`@("`@("<O8VAA;FYE;"YX;6PG+"`D
M8VAA;BT^;&%S=$UO9&EF:65D*"DI.PT*("`@("`@("!014%2.CIS=&%T:6-0
M;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@(&EF("@A4$5!4CHZ:7-%<G)O
M<B@D82D@)B8@)&$I('L-"B`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T
M1&%T82@G5T%23DE.1SH@8VAA;FYE;"`B)R`N("1C:&%N;F5L("X@)R(@:&%S
M("<@+@T*("`@("`@("`@("`@("`@("=U<&1A=&5D(&ET<R!P<F]T;V-O;',L
M('5S92`B8VAA;FYE;"UU<&1A=&4@)R`N("1C:&%N;F5L("X-"B`@("`@("`@
M("`@("`@("`G(B!T;R!U<&1A=&4G*3L-"B`@("`@("`@?0T*("`@('T-"@T*
M("`@("\O('M[>R!D;U)E;6]T94EN9F\H*0T*#0H@("`@9G5N8W1I;VX@9&]2
M96UO=&5);F9O*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![
M#0H@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@(3T@,2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"(D8V]M;6%N9"!E>'!E
M8W1S(&]N92!P87)A;3H@=&AE(')E;6]T92!P86-K86=E(&YA;64B*3L-"B`@
M("`@("`@?0T*("`@("`@("`D<V%V96-H86YN96P@/2`D8VAA;FYE;"`]("1T
M:&ES+3YC;VYF:6<M/F=E="@G9&5F875L=%]C:&%N;F5L)RD[#0H@("`@("`@
M("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@
M("`@)'!A8VMA9V4@/2`D<&%R86US6S!=.PT*("`@("`@("`D<&%R<V5D(#T@
M)')E9RT^<&%R<V5086-K86=E3F%M92@D<&%C:V%G92P@)&-H86YN96PI.PT*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&%R<V5D*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=);G9A;&ED('!A8VMA
M9V4@;F%M92`B)R`N("1P86-K86=E("X@)R(G*3L-"B`@("`@("`@?0T*("`@
M("`@("`-"B`@("`@("`@)&-H86YN96P@/2`D<&%R<V5D6R=C:&%N;F5L)UT[
M#0H@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E="@G9&5F875L=%]C:&%N;F5L
M)RP@)&-H86YN96PI.PT*("`@("`@("`D8VAA;B`]("1R96<M/F=E=$-H86YN
M96PH)&-H86YN96PI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]
M("1T:&ES+3Y?8VAE8VM#:&%N;F5L1F]R4W1A='5S*"1C:&%N;F5L+"`D8VAA
M;BDI*2![#0H@("`@("`@("`@("!R971U<FX@)&4[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"1C:&%N+3YS=7!P;W)T<U)%4U0H)'1H:7,M/F-O;F9I9RT^
M9V5T*"=P<F5F97)R961?;6ER<F]R)RDI("8F#0H@("`@("`@("`@("`@("1B
M87-E(#T@)&-H86XM/F=E=$)A<V554DPH)U)%4U0Q+C`G+"`D=&AI<RT^8V]N
M9FEG+3YG970H)W!R969E<G)E9%]M:7)R;W(G*2DI('L-"B`@("`@("`@("`@
M("1R97-T(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)%4U0H)S$N,"<L(&%R<F%Y
M*"DI.PT*("`@("`@("`@("`@)&EN9F\@/2`D<F5S="T^<&%C:V%G94EN9F\H
M)&)A<V4L("1P87)S961;)W!A8VMA9V4G72D[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`D<B`]("8D=&AI<RT^8V]N9FEG+3YG971296UO=&4H
M*3L-"B`@("`@("`@("`@("1I;F9O(#T@)'(M/F-A;&PH)W!A8VMA9V4N:6YF
M;R<L("1P87)S961;)W!A8VMA9V4G72D[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&EN9F\I*2![#0H@("`@("`@("`@("`D=&AI
M<RT^8V]N9FEG+3YS970H)V1E9F%U;'1?8VAA;FYE;"<L("1S879E8VAA;FYE
M;"D[#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&EN
M9F\I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)&EN9F];)VYA
M;64G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@G3F\@<F5M;W1E('!A8VMA9V4@(B<@+B`D<&%C:V%G92`N("<B('=A<R!F
M;W5N9"<I.PT*("`@("`@("!]#0H-"B`@("`@("`@)&EN<W1A;&QE9"`]("1R
M96<M/G!A8VMA9V5);F9O*"1I;F9O6R=N86UE)UTL(&YU;&PL("1C:&%N;F5L
M*3L-"B`@("`@("`@)&EN9F];)VEN<W1A;&QE9"==(#T@)&EN<W1A;&QE9%LG
M=F5R<VEO;B==(#\@)&EN<W1A;&QE9%LG=F5R<VEO;B==(#H@)RT@;F\@+2<[
M#0H@("`@("`@(&EF("AI<U]A<G)A>2@D:6YF;ULG:6YS=&%L;&5D)UTI*2![
M#0H@("`@("`@("`@("`D:6YF;ULG:6YS=&%L;&5D)UT@/2`D:6YF;ULG:6YS
M=&%L;&5D)UU;)W)E;&5A<V4G73L-"B`@("`@("`@?0T*#0H@("`@("`@("1T
M:&ES+3YU:2T^;W5T<'5T1&%T82@D:6YF;RP@)&-O;6UA;F0I.PT*("`@("`@
M("`D=&AI<RT^8V]N9FEG+3YS970H)V1E9F%U;'1?8VAA;FYE;"<L("1S879E
M8VAA;FYE;"D[#0H-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(&1O4F5M;W1E3&ES="@I#0H-"B`@("!F
M=6YC=&EO;B!D;U)E;6]T94QI<W0H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R
M86US*0T*("`@('L-"B`@("`@("`@)'-A=F5C:&%N;F5L(#T@)&-H86YN96P@
M/2`D=&AI<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I.PT*("`@
M("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@
M("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG8VAA;FYE;"==*2D@>PT*("`@
M("`@("`@("`@)&-H86YN96P@/2`D;W!T:6]N<ULG8VAA;FYE;"==.PT*("`@
M("`@("`@("`@:68@*"1R96<M/F-H86YN96Q%>&ES=',H)&-H86YN96PI*2![
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T*"=D969A=6QT
M7V-H86YN96PG+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G0VAA
M;FYE;"`B)R`N("1C:&%N;F5L("X@)R(@9&]E<R!N;W0@97AI<W0G*3L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D8VAA;B`]("1R96<M
M/F=E=$-H86YN96PH)&-H86YN96PI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D92`]("1T:&ES+3Y?8VAE8VM#:&%N;F5L1F]R4W1A='5S*"1C:&%N
M;F5L+"`D8VAA;BDI*2![#0H@("`@("`@("`@("!R971U<FX@)&4[#0H@("`@
M("`@('T-"B`@("`@("`@)&QI<W1?;W!T:6]N<R`](&9A;'-E.PT*("`@("`@
M("!I9B`H)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?<W1A=&4G*2`]
M/2`G<W1A8FQE)RD@>PT*("`@("`@("`@("`@)&QI<W1?;W!T:6]N<R`]('1R
M=64[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1C:&%N+3YS=7!P;W)T<U)%
M4U0H)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?;6ER<F]R)RDI("8F
M#0H@("`@("`@("`@("`@("1B87-E(#T@)&-H86XM/F=E=$)A<V554DPH)U)%
M4U0Q+C$G+"`D=&AI<RT^8V]N9FEG+3YG970H)W!R969E<G)E9%]M:7)R;W(G
M*2DI('L-"B`@("`@("`@("`@("\O('5S92!F87-T97(@;&ES="UA;&P@:68@
M879A:6QA8FQE#0H@("`@("`@("`@("`D<F5S="`]("8D=&AI<RT^8V]N9FEG
M+3YG971215-4*"<Q+C$G+"!A<G)A>2@I*3L-"B`@("`@("`@("`@("1A=F%I
M;&%B;&4@/2`D<F5S="T^;&ES=$%L;"@D8F%S92P@)&QI<W1?;W!T:6]N<RD[
M#0H@("`@("`@('T@96QS96EF("@D8VAA;BT^<W5P<&]R='-215-4*"1T:&ES
M+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D7VUI<G)O<B<I*2`F)@T*("`@("`@
M("`@("`@("`D8F%S92`]("1C:&%N+3YG971"87-E55),*"=215-4,2XP)RP@
M)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?;6ER<F]R)RDI*2![#0H@
M("`@("`@("`@("`D<F5S="`]("8D=&AI<RT^8V]N9FEG+3YG971215-4*"<Q
M+C`G+"!A<G)A>2@I*3L-"B`@("`@("`@("`@("1A=F%I;&%B;&4@/2`D<F5S
M="T^;&ES=$%L;"@D8F%S92P@)&QI<W1?;W!T:6]N<RD[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`D<B`]("8D=&AI<RT^8V]N9FEG+3YG9712
M96UO=&4H*3L-"B`@("`@("`@("`@(&EF("@D8VAA;FYE;"`]/2`G<&5A<BYP
M:'`N;F5T)RD@>PT*("`@("`@("`@("`@("`@("\O(&AA8VL@8F5C875S92!O
M9B!P;V]R('!E87)W96(@9&5S:6=N#0H@("`@("`@("`@("`@("`@)&%V86EL
M86)L92`]("1R+3YC86QL*"=P86-K86=E+FQI<W1!;&PG+"!T<G5E+"`D;&ES
M=%]O<'1I;VYS+"!F86QS92D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("1A=F%I;&%B;&4@/2`D<BT^8V%L;"@G<&%C:V%G92YL
M:7-T06QL)RP@=')U92P@)&QI<W1?;W!T:6]N<RD[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&%V86EL
M86)L92DI('L-"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E="@G9&5F
M875L=%]C:&%N;F5L)RP@)'-A=F5C:&%N;F5L*3L-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D879A:6QA8FQE*3L-"B`@("`@("`@
M?0T*("`@("`@("`D:2`]("1J(#T@,#L-"B`@("`@("`@)&1A=&$@/2!A<G)A
M>2@-"B`@("`@("`@("`@("=C87!T:6]N)R`]/B`G0VAA;FYE;"`G("X@)&-H
M86YN96P@+B`G($%V86EL86)L92!P86-K86=E<SHG+`T*("`@("`@("`@("`@
M)V)O<F1E<B<@/3X@=')U92P-"B`@("`@("`@("`@("=H96%D;&EN92<@/3X@
M87)R87DH)U!A8VMA9V4G+"`G5F5R<VEO;B<I+`T*("`@("`@("`@("`@*3L-
M"B`@("`@("`@:68@*&-O=6YT*"1A=F%I;&%B;&4I/3TP*2![#0H@("`@("`@
M("`@("`D9&%T82`]("<H;F\@<&%C:V%G97,@879A:6QA8FQE('EE="DG.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@9F]R96%C:"`H)&%V86EL
M86)L92!A<R`D;F%M92`]/B`D:6YF;RD@>PT*("`@("`@("`@("`@("`@("1D
M871A6R=D871A)UU;72`](&%R<F%Y*"1N86UE+"`H:7-S970H)&EN9F];)W-T
M86)L92==*2`F)B`D:6YF;ULG<W1A8FQE)UTI#0H@("`@("`@("`@("`@("`@
M("`@(#\@)&EN9F];)W-T86)L92==(#H@)RUN+V$M)RD[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A
M*"1D871A+"`D8V]M;6%N9"D[#0H@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E
M="@G9&5F875L=%]C:&%N;F5L)RP@)'-A=F5C:&%N;F5L*3L-"B`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[
M(&1O3&ES=$%L;"@I#0H-"B`@("!F=6YC=&EO;B!D;TQI<W1!;&PH)&-O;6UA
M;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@)'-A=F5C
M:&%N;F5L(#T@)&-H86YN96P@/2`D=&AI<RT^8V]N9FEG+3YG970H)V1E9F%U
M;'1?8VAA;FYE;"<I.PT*("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M
M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG
M8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@)&-H86YN96P@/2`D;W!T:6]N
M<ULG8VAA;FYE;"==.PT*("`@("`@("`@("`@:68@*"1R96<M/F-H86YN96Q%
M>&ES=',H)&-H86YN96PI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/F-O
M;F9I9RT^<V5T*"=D969A=6QT7V-H86YN96PG+"`D8VAA;FYE;"D[#0H@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@B0VAA;FYE;"!<(B1C:&%N;F5L7"(@9&]E<R!N;W0@
M97AI<W0B*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D
M;&ES=%]O<'1I;VYS(#T@9F%L<V4[#0H@("`@("`@(&EF("@D=&AI<RT^8V]N
M9FEG+3YG970H)W!R969E<G)E9%]S=&%T92<I(#T]("=S=&%B;&4G*2![#0H@
M("`@("`@("`@("`D;&ES=%]O<'1I;VYS(#T@=')U93L-"B`@("`@("`@?0T*
M("`@("`@("`D8VAA;B`]("1R96<M/F=E=$-H86YN96PH)&-H86YN96PI.PT*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1T:&ES+3Y?8VAE8VM#
M:&%N;F5L1F]R4W1A='5S*"1C:&%N;F5L+"`D8VAA;BDI*2![#0H@("`@("`@
M("`@("!R971U<FX@)&4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1C:&%N
M+3YS=7!P;W)T<U)%4U0H)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?
M;6ER<F]R)RDI("8F#0H@("`@("`@("`@("`@("1B87-E(#T@)&-H86XM/F=E
M=$)A<V554DPH)U)%4U0Q+C$G+"`D=&AI<RT^8V]N9FEG+3YG970H)W!R969E
M<G)E9%]M:7)R;W(G*2DI('L-"B`@("`@("`@("`@("\O('5S92!F87-T97(@
M;&ES="UA;&P@:68@879A:6QA8FQE#0H@("`@("`@("`@("`D<F5S="`]("8D
M=&AI<RT^8V]N9FEG+3YG971215-4*"<Q+C$G+"!A<G)A>2@I*3L-"B`@("`@
M("`@("`@("1A=F%I;&%B;&4@/2`D<F5S="T^;&ES=$%L;"@D8F%S92P@)&QI
M<W1?;W!T:6]N<RP@9F%L<V4I.PT*("`@("`@("!](&5L<V5I9B`H)&-H86XM
M/G-U<'!O<G1S4D535"@D=&AI<RT^8V]N9FEG+3YG970H)W!R969E<G)E9%]M
M:7)R;W(G*2D@)B8-"B`@("`@("`@("`@("`@)&)A<V4@/2`D8VAA;BT^9V5T
M0F%S95523"@G4D535#$N,"<L("1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R
M<F5D7VUI<G)O<B<I*2D@>PT*("`@("`@("`@("`@)')E<W0@/2`F)'1H:7,M
M/F-O;F9I9RT^9V5T4D535"@G,2XP)RP@87)R87DH*2D[#0H@("`@("`@("`@
M("`D879A:6QA8FQE(#T@)')E<W0M/FQI<W1!;&PH)&)A<V4L("1L:7-T7V]P
M=&EO;G,L(&9A;'-E*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("1R(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E;6]T92@I.PT*("`@("`@("`@
M("`@:68@*"1C:&%N;F5L(#T]("=P96%R+G!H<"YN970G*2![#0H@("`@("`@
M("`@("`@("`@+R\@:&%C:R!B96-A=7-E(&]F('!O;W(@<&5A<G=E8B!D97-I
M9VX-"B`@("`@("`@("`@("`@("`D879A:6QA8FQE(#T@)'(M/F-A;&PH)W!A
M8VMA9V4N;&ES=$%L;"<L('1R=64L("1L:7-T7V]P=&EO;G,L(&9A;'-E*3L-
M"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&%V86EL
M86)L92`]("1R+3YC86QL*"=P86-K86=E+FQI<W1!;&PG+"!T<G5E+"`D;&ES
M=%]O<'1I;VYS*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D879A:6QA8FQE*2D@>PT*("`@("`@("`@
M("`@)'1H:7,M/F-O;F9I9RT^<V5T*"=D969A=6QT7V-H86YN96PG+"`D<V%V
M96-H86YN96PI.PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"=4:&4@<&%C:V%G92!L:7-T(&-O=6QD(&YO="!B92!F971C:&5D(&9R
M;VT@=&AE(')E;6]T92!S97)V97(N(%!L96%S92!T<GD@86=A:6XN("A$96)U
M9R!I;F9O.B`B)R`N("1A=F%I;&%B;&4M/F=E=$UE<W-A9V4H*2`N("<B*2<I
M.PT*("`@("`@("!]#0H@("`@("`@("1D871A(#T@87)R87DH#0H@("`@("`@
M("`@("`G8V%P=&EO;B<@/3X@)T%L;"!P86-K86=E<SHG+`T*("`@("`@("`@
M("`@)V)O<F1E<B<@/3X@=')U92P-"B`@("`@("`@("`@("=H96%D;&EN92<@
M/3X@87)R87DH)U!A8VMA9V4G+"`G3&%T97-T)RP@)TQO8V%L)RDL#0H@("`@
M("`@("`@("`I.PT*("`@("`@("`D;&]C86Q?<&MG<R`]("1R96<M/FQI<W10
M86-K86=E<R@D8VAA;FYE;"D[#0H-"B`@("`@("`@9F]R96%C:"`H)&%V86EL
M86)L92!A<R`D;F%M92`]/B`D:6YF;RD@>PT*("`@("`@("`@("`@)&EN<W1A
M;&QE9"`]("1R96<M/G!A8VMA9V5);F9O*"1N86UE+"!N=6QL+"`D8VAA;FYE
M;"D[#0H@("`@("`@("`@("!I9B`H:7-?87)R87DH)&EN<W1A;&QE9%LG=F5R
M<VEO;B==*2D@>PT*("`@("`@("`@("`@("`@("1I;G-T86QL961;)W9E<G-I
M;VXG72`]("1I;G-T86QL961;)W9E<G-I;VXG75LG<F5L96%S92==.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)&1E<V,@/2`D:6YF;ULG<W5M;6%R
M>2==.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;)&YA;65=*2D@
M>PT*("`@("`@("`@("`@("`@("1D97-C("X](")<;EQN(BXD:6YF;ULG9&5S
M8W)I<'1I;VXG73L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI
M<W-E="@D;W!T:6]N<ULG;6]D92==*2D-"B`@("`@("`@("`@('L-"B`@("`@
M("`@("`@("`@("!I9B`H)&]P=&EO;G-;)VUO9&4G72`]/2`G:6YS=&%L;&5D
M)R`F)B`A:7-S970H)&EN<W1A;&QE9%LG=F5R<VEO;B==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@:68@*"1O<'1I;VYS6R=M;V1E)UT@/3T@)VYO=&EN
M<W1A;&QE9"<@)B8@:7-S970H)&EN<W1A;&QE9%LG=F5R<VEO;B==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@:68@*"1O<'1I;VYS6R=M;V1E)UT@/3T@
M)W5P9W)A9&5S)PT*("`@("`@("`@("`@("`@("`@("`@("8F("@A:7-S970H
M)&EN<W1A;&QE9%LG=F5R<VEO;B==*2!\?"!V97)S:6]N7V-O;7!A<F4H)&EN
M<W1A;&QE9%LG=F5R<VEO;B==+`T*("`@("`@("`@("`@("`@("`@("`@("1I
M;F9O6R=S=&%B;&4G72P@)SX])RDI*2![#0H@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1P;W,@/2!A<G)A>5]S96%R8V@H<W1R=&]L;W=E<B@D
M;F%M92DL("1L;V-A;%]P:V=S*3L-"B`@("`@("`@("`@(&EF("@D<&]S("$]
M/2!F86QS92D@>PT*("`@("`@("`@("`@("`@('5N<V5T*"1L;V-A;%]P:V=S
M6R1P;W-=*3L-"B`@("`@("`@("`@('T-"@T*("`@("`@("`@("`@:68@*&ES
M<V5T*"1I;F9O6R=S=&%B;&4G72D@)B8@(21I;F9O6R=S=&%B;&4G72D@>PT*
M("`@("`@("`@("`@("`@("1I;F9O6R=S=&%B;&4G72`](&YU;&P[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D9&%T85LG9&%T82==6R1I;F9O6R=C
M871E9V]R>2==75M=(#T@87)R87DH#0H@("`@("`@("`@("`@("`@)')E9RT^
M8VAA;FYE;$%L:6%S*"1C:&%N;F5L*2`N("<O)R`N("1N86UE+`T*("`@("`@
M("`@("`@("`@($`D:6YF;ULG<W1A8FQE)UTL#0H@("`@("`@("`@("`@("`@
M0"1I;G-T86QL961;)W9E<G-I;VXG72P-"B`@("`@("`@("`@("`@("!`)&1E
M<V,L#0H@("`@("`@("`@("`@("`@0"1I;F9O6R=D97!S)UTL#0H@("`@("`@
M("`@("`@("`@*3L-"B`@("`@("`@?0T*#0H@("`@("`@(&EF("AI<W-E="@D
M;W!T:6]N<ULG;6]D92==*2`F)B!I;E]A<G)A>2@D;W!T:6]N<ULG;6]D92==
M+"!A<G)A>2@G;F]T:6YS=&%L;&5D)RP@)W5P9W)A9&5S)RDI*2![#0H@("`@
M("`@("`@("`D=&AI<RT^8V]N9FEG+3YS970H)V1E9F%U;'1?8VAA;FYE;"<L
M("1S879E8VAA;FYE;"D[#0H@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U
M=$1A=&$H)&1A=&$L("1C;VUM86YD*3L-"B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1L;V-A;%]P:V=S
M(&%S("1N86UE*2![#0H@("`@("`@("`@("`D:6YF;R`]("8D<F5G+3YG9710
M86-K86=E*"1N86UE+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("`D9&%T85LG
M9&%T82==6R=,;V-A;"==6UT@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`D
M<F5G+3YC:&%N;F5L06QI87,H)&-H86YN96PI("X@)R\G("X@)&EN9F\M/F=E
M=%!A8VMA9V4H*2P-"B`@("`@("`@("`@("`@("`G)RP-"B`@("`@("`@("`@
M("`@("`D:6YF;RT^9V5T5F5R<VEO;B@I+`T*("`@("`@("`@("`@("`@("1I
M;F9O+3YG9713=6UM87)Y*"DL#0H@("`@("`@("`@("`@("`@)&EN9F\M/F=E
M=$1E<',H*0T*("`@("`@("`@("`@("`@("D[#0H@("`@("`@('T-"@T*("`@
M("`@("`D=&AI<RT^8V]N9FEG+3YS970H)V1E9F%U;'1?8VAA;FYE;"<L("1S
M879E8VAA;FYE;"D[#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D
M9&%T82P@)&-O;6UA;F0I.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]
M#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9&]396%R8V@H*0T*#0H@("`@
M9G5N8W1I;VX@9&]396%R8V@H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US
M*0T*("`@('L-"B`@("`@("`@:68@*"@A:7-S970H)'!A<F%M<ULP72D@?'P@
M96UP='DH)'!A<F%M<ULP72DI#0H@("`@("`@("`@("`F)B`H(6ES<V5T*"1P
M87)A;7-;,5TI('Q\(&5M<'1Y*"1P87)A;7-;,5TI*2D-"B`@("`@("`@>PT*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=N;R!V86QI
M9"!S96%R8V@@<W1R:6YG('-U<'!L:65D)RD[#0H@("`@("`@('T[#0H-"B`@
M("`@("`@)'-A=F5C:&%N;F5L(#T@)&-H86YN96P@/2`D=&AI<RT^8V]N9FEG
M+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I.PT*("`@("`@("`D<F5G(#T@)B1T
M:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@("1P86-K86=E
M(#T@)'!A<F%M<ULP73L-"B`@("`@("`@)'-U;6UA<GD@/2!I<W-E="@D<&%R
M86US6S%=*2`_("1P87)A;7-;,5T@.B!F86QS93L-"B`@("`@("`@:68@*&ES
M<V5T*"1O<'1I;VYS6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`D<F5G
M(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@("`@
M("`D8VAA;FYE;"`]("1O<'1I;VYS6R=C:&%N;F5L)UT[#0H@("`@("`@("`@
M("!I9B`H)')E9RT^8VAA;FYE;$5X:7-T<R@D8VAA;FYE;"DI('L-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^8V]N9FEG+3YS970H)V1E9F%U;'1?8VAA;FYE
M;"<L("1C:&%N;F5L*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#:&%N;F5L("(G
M("X@)&-H86YN96P@+B`G(B!D;V5S(&YO="!E>&ES="<I.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@("1C:&%N(#T@)')E9RT^9V5T0VAA
M;FYE;"@D8VAA;FYE;"D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E
M(#T@)'1H:7,M/E]C:&5C:T-H86YN96Q&;W)3=&%T=7,H)&-H86YN96PL("1C
M:&%N*2DI('L-"B`@("`@("`@("`@(')E='5R;B`D93L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H)&-H86XM/G-U<'!O<G1S4D535"@D=&AI<RT^8V]N9FEG
M+3YG970H)W!R969E<G)E9%]M:7)R;W(G*2D@)B8-"B`@("`@("`@("`@("`@
M)&)A<V4@/2`D8VAA;BT^9V5T0F%S95523"@G4D535#$N,"<L("1T:&ES+3YC
M;VYF:6<M/F=E="@G<')E9F5R<F5D7VUI<G)O<B<I*2D@>PT*("`@("`@("`@
M("`@)')E<W0@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4D535"@G,2XP)RP@87)R
M87DH*2D[#0H@("`@("`@("`@("`D879A:6QA8FQE(#T@)')E<W0M/FQI<W1!
M;&PH)&)A<V4L(&9A;'-E+"!F86QS92P@)'!A8VMA9V4L("1S=6UM87)Y*3L-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1R(#T@)B1T:&ES+3YC
M;VYF:6<M/F=E=%)E;6]T92@I.PT*("`@("`@("`@("`@)&%V86EL86)L92`]
M("1R+3YC86QL*"=P86-K86=E+G-E87)C:"<L("1P86-K86=E+"`D<W5M;6%R
M>2P@=')U92P@#0H@("`@("`@("`@("`@("`@)'1H:7,M/F-O;F9I9RT^9V5T
M*"=P<F5F97)R961?<W1A=&4G*2`]/2`G<W1A8FQE)RP@=')U92D[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&%V86EL86)L92DI
M('L-"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E="@G9&5F875L=%]C
M:&%N;F5L)RP@)'-A=F5C:&%N;F5L*3L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@D879A:6QA8FQE*3L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H(21A=F%I;&%B;&4I('L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@G;F\@<&%C:V%G97,@9F]U;F0@=&AA="!M871C
M:"!P871T97)N("(G("X@)'!A8VMA9V4@+B`G(B<I.PT*("`@("`@("!]#0H@
M("`@("`@("1D871A(#T@87)R87DH#0H@("`@("`@("`@("`G8V%P=&EO;B<@
M/3X@)TUA=&-H960@<&%C:V%G97,L(&-H86YN96P@)R`N("1C:&%N;F5L("X@
M)SHG+`T*("`@("`@("`@("`@)V)O<F1E<B<@/3X@=')U92P-"B`@("`@("`@
M("`@("=H96%D;&EN92<@/3X@87)R87DH)U!A8VMA9V4G+"`G4W1A8FQE+RA,
M871E<W0I)RP@)TQO8V%L)RDL#0H@("`@("`@("`@("`I.PT*#0H@("`@("`@
M(&9O<F5A8V@@*"1A=F%I;&%B;&4@87,@)&YA;64@/3X@)&EN9F\I('L-"B`@
M("`@("`@("`@("1I;G-T86QL960@/2`D<F5G+3YP86-K86=E26YF;R@D;F%M
M92P@;G5L;"P@)&-H86YN96PI.PT*("`@("`@("`@("`@)&1E<V,@/2`D:6YF
M;ULG<W5M;6%R>2==.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;
M)&YA;65=*2D-"B`@("`@("`@("`@("`@("`D9&5S8R`N/2`B7&Y<;B(N)&EN
M9F];)V1E<V-R:7!T:6]N)UT[#0H-"B`@("`@("`@("`@("1U;G-T86)L92`]
M("<G.PT*("`@("`@("`@("`@:68@*"1I;F9O6R=U;G-T86)L92==*2![#0H@
M("`@("`@("`@("`@("`@)'5N<W1A8FQE(#T@)R\H)R`N("1I;F9O6R=U;G-T
M86)L92==("X@)R`G("X@)&EN9F];)W-T871E)UT@+B`G*2<[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1I;F9O6R=S=&%B;&4G
M72D@?'P@(21I;F9O6R=S=&%B;&4G72D@>PT*("`@("`@("`@("`@("`@("1I
M;F9O6R=S=&%B;&4G72`]("=N;VYE)SL-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("1V97)S:6]N(#T@:7-?87)R87DH)&EN<W1A;&QE9%LG=F5R<VEO
M;B==*2`_("1I;G-T86QL961;)W9E<G-I;VXG75LG<F5L96%S92==(#H-"B`@
M("`@("`@("`@("`@("`D:6YS=&%L;&5D6R=V97)S:6]N)UT[#0H@("`@("`@
M("`@("`D9&%T85LG9&%T82==6R1I;F9O6R=C871E9V]R>2==75M=(#T@87)R
M87DH#0H@("`@("`@("`@("`@("`@)&YA;64L#0H@("`@("`@("`@("`@("`@
M)&EN9F];)W-T86)L92==("X@)'5N<W1A8FQE+`T*("`@("`@("`@("`@("`@
M("1V97)S:6]N+`T*("`@("`@("`@("`@("`@("1D97-C+`T*("`@("`@("`@
M("`@("`@("D[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/G5I+3YO=71P
M=71$871A*"1D871A+"`D8V]M;6%N9"D[#0H@("`@("`@("1T:&ES+3YC;VYF
M:6<M/G-E="@G9&5F875L=%]C:&%N;F5L)RP@)&-H86YN96PI.PT*("`@("`@
M("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("!F=6YC
M=&EO;B`F9V5T1&]W;FQO861E<B@D;W!T:6]N<RD-"B`@("![#0H@("`@("`@
M(&EF("@A8VQA<W-?97AI<W1S*"=014%27T1O=VYL;V%D97(G*2D@>PT*("`@
M("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T1O=VYL;V%D97(N<&AP)SL-
M"B`@("`@("`@?0T*("`@("`@("`D82`]("9N97<@4$5!4E]$;W=N;&]A9&5R
M*"1T:&ES+3YU:2P@)&]P=&EO;G,L("1T:&ES+3YC;VYF:6<I.PT*("`@("`@
M("!R971U<FX@)&$[#0H@("`@?0T*("`@("\O('M[>R!D;T1O=VYL;V%D*"D-
M"@T*("`@(&9U;F-T:6]N(&1O1&]W;FQO860H)&-O;6UA;F0L("1O<'1I;VYS
M+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@+R\@;6%K92!C97)T86EN('1H
M870@9&5P96YD96YC:65S(&%R92!I9VYO<F5D#0H@("`@("`@("1O<'1I;VYS
M6R=D;W=N;&]A9&]N;'DG72`](#$[#0H@("`@("`@("\O(&5L:6UI;F%T92!E
M<G)O<B!M97-S86=E<R!F;W(@<')E9F5R<F5D7W-T871E+7)E;&%T960@97)R
M;W)S#0H@("`@("`@("1O<'1I;VYS6R=I9VYO<F5P<F5F97)R961?<W1A=&4G
M72`](#$[#0H@("`@("`@("1D;W=N;&]A9&5R(#T@)B1T:&ES+3YG971$;W=N
M;&]A9&5R*"1O<'1I;VYS*3L-"B`@("`@("`@)&1O=VYL;V%D97(M/G-E=$1O
M=VYL;V%D1&ER*&=E=&-W9"@I*3L-"B`@("`@("`@)&5R<F]R<R`](&%R<F%Y
M*"D[#0H@("`@("`@("1D;W=N;&]A9&5D(#T@87)R87DH*3L-"B`@("`@("`@
M)&5R<B`]("1D;W=N;&]A9&5R+3YD;W=N;&]A9"@D<&%R86US*3L-"B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&5R<BDI('L-"B`@("`@("`@("`@(')E
M='5R;B`D97)R.PT*("`@("`@("!]#0H@("`@("`@("1E<G)O<G,@/2`D9&]W
M;FQO861E<BT^9V5T17)R;W)-<V=S*"D[#0H@("`@("`@(&EF("AC;W5N="@D
M97)R;W)S*2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H)&5R<F]R<R!A<R`D
M97)R;W(I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A
M=&$H)&5R<F]R*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B)&-O;6UA;F0@9F%I;&5D(BD[#0H@("`@
M("`@('T-"B`@("`@("`@)&1O=VYL;V%D960@/2`D9&]W;FQO861E<BT^9V5T
M1&]W;FQO861E9%!A8VMA9V5S*"D[#0H@("`@("`@(&9O<F5A8V@@*"1D;W=N
M;&]A9&5D(&%S("1P:V<I('L-"B`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T
M<'5T1&%T82@B1FEL92`D<&MG6V9I;&5=(&1O=VYL;V%D960B+"`D8V]M;6%N
M9"D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@9&]W;FQO861#86QL8F%C:R@D;7-G+"`D<&%R86US
M(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&EF("@D;7-G(#T]("=D;VYE)RD@
M>PT*("`@("`@("`@("`@)'1H:7,M/F)Y=&5S7V1O=VYL;V%D960@/2`D<&%R
M86US.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(&1O3&ES=%5P9W)A9&5S*"D-"@T*("`@(&9U;F-T:6]N(&1O3&ES=%5P
M9W)A9&5S*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@
M("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]#;VUM;VXN<&AP)SL-"B`@("`@
M("`@:68@*&ES<V5T*"1P87)A;7-;,%TI("8F("%014%27T-O;6UO;CHZ8F5T
M=&5R4W1A=&5S*"1P87)A;7-;,%TI*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)'!A<F%M<ULP72`N("<@:7,@;F]T(&$@=F%L
M:60@<W1A=&4@*'-T86)L92]B971A+V%L<&AA+V1E=F5L+V5T8RXI('1R>2`B
M<&5A<B!H96QP(&QI<W0M=7!G<F%D97,B)RD[#0H@("`@("`@('T-"B`@("`@
M("`@)'-A=F5C:&%N;F5L(#T@)&-H86YN96P@/2`D=&AI<RT^8V]N9FEG+3YG
M970H)V1E9F%U;'1?8VAA;FYE;"<I.PT*("`@("`@("`D<F5G(#T@)B1T:&ES
M+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1R
M96<M/FQI<W1#:&%N;F5L<R@I(&%S("1C:&%N;F5L*2![#0H@("`@("`@("`@
M("`D:6YS="`](&%R<F%Y7V9L:7`H)')E9RT^;&ES=%!A8VMA9V5S*"1C:&%N
M;F5L*2D[#0H@("`@("`@("`@("!I9B`H(6-O=6YT*"1I;G-T*2D@>PT*("`@
M("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@:68@*"1C:&%N;F5L(#T]("=?7W5R:2<I('L-"B`@("`@("`@("`@
M("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T
M:&ES+3YC;VYF:6<M/G-E="@G9&5F875L=%]C:&%N;F5L)RP@)&-H86YN96PI
M.PT*("`@("`@("`@("`@:68@*&5M<'1Y*"1P87)A;7-;,%TI*2![#0H@("`@
M("`@("`@("`@("`@)'-T871E(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F
M97)R961?<W1A=&4G*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@)'-T871E(#T@)'!A<F%M<ULP73L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1C87!T:6]N(#T@)&-H86YN96P@+B`G($%V86EL86)L
M92!5<&=R861E<R<[#0H@("`@("`@("`@("`D8VAA;B`]("1R96<M/F=E=$-H
M86YN96PH)&-H86YN96PI.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&4@/2`D=&AI<RT^7V-H96-K0VAA;FYE;$9O<E-T871U<R@D8VAA;FYE
M;"P@)&-H86XI*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D93L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D8VAA;BT^<W5P<&]R='-2
M15-4*"1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D7VUI<G)O<B<I*2`F
M)@T*("`@("`@("`@("`@("`@("`@)&)A<V4@/2`D8VAA;BT^9V5T0F%S9552
M3"@G4D535#$N,"<L("1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D7VUI
M<G)O<B<I*2D@>PT*("`@("`@("`@("`@("`@("1R97-T(#T@)B1T:&ES+3YC
M;VYF:6<M/F=E=%)%4U0H)S$N,"<L(&%R<F%Y*"DI.PT*("`@("`@("`@("`@
M("`@(&EF("AE;7!T>2@D<W1A=&4I('Q\("1S=&%T92`]/2`G86YY)RD@>PT*
M("`@("`@("`@("`@("`@("`@("`D<W1A=&4@/2!F86QS93L-"B`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D8V%P=&EO
M;B`N/2`G("@G("X@:6UP;&]D92@G+"`G+"!014%27T-O;6UO;CHZ8F5T=&5R
M4W1A=&5S*"1S=&%T92P@=')U92DI("X@)RDG.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!014%2.CIS=&%T:6-0=7-H17)R;W)(86YD
M;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("`@("`@("`@)&QA
M=&5S="`]("1R97-T+3YL:7-T3&%T97-T57!G<F%D97,H)&)A<V4L("1S=&%T
M92P@)&EN<W0L("1C:&%N;F5L+"`D<F5G*3L-"B`@("`@("`@("`@("`@("!0
M14%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("1R96UO=&4@/2`F)'1H:7,M/F-O
M;F9I9RT^9V5T4F5M;W1E*"D[#0H@("`@("`@("`@("`@("`@)')E;6]T92T^
M<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@
M("`@("`@("`@(&EF("AE;7!T>2@D<W1A=&4I('Q\("1S=&%T92`]/2`G86YY
M)RD@>PT*("`@("`@("`@("`@("`@("`@("`D;&%T97-T(#T@)')E;6]T92T^
M8V%L;"@B<&%C:V%G92YL:7-T3&%T97-T4F5L96%S97,B*3L-"B`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D;&%T97-T
M(#T@)')E;6]T92T^8V%L;"@B<&%C:V%G92YL:7-T3&%T97-T4F5L96%S97,B
M+"`D<W1A=&4I.PT*("`@("`@("`@("`@("`@("`@("`D8V%P=&EO;B`N/2`G
M("@G("X@:6UP;&]D92@G+"`G+"!014%27T-O;6UO;CHZ8F5T=&5R4W1A=&5S
M*"1S=&%T92P@=')U92DI("X@)RDG.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`D<F5M;W1E+3YP;W!%<G)O<DAA;F1L:6YG*"D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M;&%T97-T*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T
M1&%T82@D;&%T97-T+3YG971-97-S86=E*"DI.PT*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&-A<'1I
M;VX@+CT@)SHG.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&QA
M=&5S="DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^8V]N9FEG+3YS970H
M)V1E9F%U;'1?8VAA;FYE;"<L("1S879E8VAA;FYE;"D[#0H@("`@("`@("`@
M("`@("`@<F5T=7)N("1L871E<W0[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`D9&%T82`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("=C87!T:6]N
M)R`]/B`D8V%P=&EO;BP-"B`@("`@("`@("`@("`@("`G8F]R9&5R)R`]/B`Q
M+`T*("`@("`@("`@("`@("`@("=H96%D;&EN92<@/3X@87)R87DH)T-H86YN
M96PG+"`G4&%C:V%G92<L("=,;V-A;"<L("=296UO=&4G+"`G4VEZ92<I+`T*
M("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("!F;W)E86-H("@H87)R
M87DI)&QA=&5S="!A<R`D<&MG(#T^("1I;F9O*2![#0H@("`@("`@("`@("`@
M("`@)'!A8VMA9V4@/2!S=')T;VQO=V5R*"1P:V<I.PT*("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)&EN<W1;)'!A8VMA9V5=*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`O+R!S:VEP('!A8VMA9V5S('=E(&1O;B=T(&AA=F4@:6YS
M=&%L;&5D#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!E>'1R86-T*"1I;F9O*3L-
M"B`@("`@("`@("`@("`@("`D:6YS=%]V97)S:6]N(#T@)')E9RT^<&%C:V%G
M94EN9F\H)'!A8VMA9V4L("=V97)S:6]N)RP@)&-H86YN96PI.PT*("`@("`@
M("`@("`@("`@("1I;G-T7W-T871E("`@/2`D<F5G+3YP86-K86=E26YF;R@D
M<&%C:V%G92P@)W)E;&5A<V5?<W1A=&4G+"`D8VAA;FYE;"D[#0H@("`@("`@
M("`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92@B)'9E<G-I;VXB+"`B)&EN
M<W1?=F5R<VEO;B(L(")L92(I*2![#0H@("`@("`@("`@("`@("`@("`@("\O
M(&EN<W1A;&QE9"!V97)S:6]N(&ES('5P+71O+61A=&4-"B`@("`@("`@("`@
M("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&EF("@D9FEL97-I>F4@/CT@,C`T.#`I('L-"B`@("`@("`@
M("`@("`@("`@("`@)&9I;&5S:7IE("L](#$P,C0@+2`H)&9I;&5S:7IE("4@
M,3`R-"D[#0H@("`@("`@("`@("`@("`@("`@("1F<R`]('-P<FEN=&8H(B5D
M:T(B+"`D9FEL97-I>F4@+R`Q,#(T*3L-"B`@("`@("`@("`@("`@("!](&5L
M<V5I9B`H)&9I;&5S:7IE(#X@,"D@>PT*("`@("`@("`@("`@("`@("`@("`D
M9FEL97-I>F4@*ST@,3`S("T@*"1F:6QE<VEZ92`E(#$P,RD[#0H@("`@("`@
M("`@("`@("`@("`@("1F<R`]('-P<FEN=&8H(B4N,69K0B(L("1F:6QE<VEZ
M92`O(#$P,C0N,"D[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@)&9S(#T@(B`@+2([("\O(%A86"!C96YT97(@:6YS
M=&5A9`T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D9&%T
M85LG9&%T82==6UT@/2!A<G)A>2@D8VAA;FYE;"P@)'!K9RP@(B1I;G-T7W9E
M<G-I;VX@*"1I;G-T7W-T871E*2(L("(D=F5R<VEO;B`H)'-T871E*2(L("1F
M<RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H96UP='DH)&1A
M=&%;)V1A=&$G72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U
M='!U=$1A=&$H)T-H86YN96P@)R`N("1C:&%N;F5L("X@)SH@3F\@=7!G<F%D
M97,@879A:6QA8FQE)RD[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D9&%T82P@)&-O;6UA
M;F0I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1T:&ES
M+3YC;VYF:6<M/G-E="@G9&5F875L=%]C:&%N;F5L)RP@)'-A=F5C:&%N;F5L
M*3L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[(&1O0VQE87)#86-H92@I#0H-"B`@("!F=6YC=&EO;B!D
M;T-L96%R0V%C:&4H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@
M('L-"B`@("`@("`@)&-A8VAE7V1I<B`]("1T:&ES+3YC;VYF:6<M/F=E="@G
M8V%C:&5?9&ER)RD[#0H@("`@("`@("1V97)B;W-E(#T@)'1H:7,M/F-O;F9I
M9RT^9V5T*"=V97)B;W-E)RD[#0H@("`@("`@("1O=71P=70@/2`G)SL-"B`@
M("`@("`@:68@*"$H)&1P(#T@0&]P96YD:7(H)&-A8VAE7V1I<BDI*2![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F]P96YD:7(H
M)&-A8VAE7V1I<BD@9F%I;&5D.B`D<&AP7V5R<F]R;7-G(BD[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"1V97)B;W-E(#X](#$I('L-"B`@("`@("`@("`@
M("1O=71P=70@+CT@(G)E861I;F<@9&ER96-T;W)Y("1C86-H95]D:7)<;B([
M#0H@("`@("`@('T-"B`@("`@("`@)&YU;2`](#`[#0H@("`@("`@('=H:6QE
M("@D96YT(#T@<F5A9&1I<B@D9'`I*2![#0H@("`@("`@("`@("!I9B`H<')E
M9U]M871C:"@G+UYX;6QR<&-?8V%C:&5?6V$M>C`M.5U[,S)])"\G+"`D96YT
M*2!\?`T*("`@("`@("`@("`@("`@("`@<')E9U]M871C:"@G+W)E<W0N8V%C
M:&4H9FEL97QI9"DD+R<L("1E;G0I*2![#0H@("`@("`@("`@("`@("`@)'!A
M=&@@/2`D8V%C:&5?9&ER("X@1$E214-43U)97U-%4$%2051/4B`N("1E;G0[
M#0H@("`@("`@("`@("`@("`@)&]K(#T@0'5N;&EN:R@D<&%T:"D[#0H@("`@
M("`@("`@("`@("`@:68@*"1O:RD@>PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H)'9E<F)O<V4@/CT@,BD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)&]U='!U="`N/2`B9&5L971E9"`D<&%T:%QN(CL-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D;G5M*RL[#0H@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*"1V97)B;W-E(#X](#$I('L-"B`@("`@("`@
M("`@("`@("`@("`@)&]U='!U="`N/2`B9F%I;&5D('1O(&1E;&5T92`D<&%T
M:%QN(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@8VQO<V5D:7(H)&1P*3L-"B`@("`@("`@:68@*"1V
M97)B;W-E(#X](#$I('L-"B`@("`@("`@("`@("1O=71P=70@+CT@(B1N=6T@
M8V%C:&4@96YT<FEE<R!C;&5A<F5D7&XB.PT*("`@("`@("!]#0H@("`@("`@
M("1T:&ES+3YU:2T^;W5T<'5T1&%T82AR=')I;2@D;W5T<'5T*2P@)&-O;6UA
M;F0I.PT*("`@("`@("!R971U<FX@)&YU;3L-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"GT-"@T*/SX-"@``````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]0
M14%2+T-O;6UA;F0O4F5M;W1E+GAM;```````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-34R,``Q,#4Q-30S,S<T,``P,C(V-C4`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/&-O;6UA;F1S('9E<G-I
M;VX](C$N,"(^#0H@/')E;6]T92UI;F9O/@T*("`\<W5M;6%R>3Y);F9O<FUA
M=&EO;B!!8F]U="!296UO=&4@4&%C:V%G97,\+W-U;6UA<GD^#0H@(#QF=6YC
M=&EO;CYD;U)E;6]T94EN9F\\+V9U;F-T:6]N/@T*("`\<VAO<G1C=70^<FD\
M+W-H;W)T8W5T/@T*("`\;W!T:6]N<R`O/@T*("`\9&]C/B9L=#MP86-K86=E
M)F=T.PT*1V5T(&1E=&%I;',@;VX@82!P86-K86=E(&9R;VT@=&AE('-E<G9E
M<BX\+V1O8SX-"B`\+W)E;6]T92UI;F9O/@T*(#QL:7-T+75P9W)A9&5S/@T*
M("`\<W5M;6%R>3Y,:7-T($%V86EL86)L92!5<&=R861E<SPO<W5M;6%R>3X-
M"B`@/&9U;F-T:6]N/F1O3&ES=%5P9W)A9&5S/"]F=6YC=&EO;CX-"B`@/'-H
M;W)T8W5T/FQU/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,@+SX-"B`@/&1O8SY;
M<')E9F5R<F5D7W-T871E70T*3&ES="!R96QE87-E<R!O;B!T:&4@<V5R=F5R
M(&]F('!A8VMA9V5S('EO=2!H879E(&EN<W1A;&QE9"!W:&5R90T*82!N97=E
M<B!V97)S:6]N(&ES(&%V86EL86)L92!W:71H('1H92!S86UE(')E;&5A<V4@
M<W1A=&4@*'-T86)L92!E=&,N*0T*;W(@=&AE('-T871E('!A<W-E9"!A<R!T
M:&4@<V5C;VYD('!A<F%M971E<BX\+V1O8SX-"B`\+VQI<W0M=7!G<F%D97,^
M#0H@/')E;6]T92UL:7-T/@T*("`\<W5M;6%R>3Y,:7-T(%)E;6]T92!086-K
M86=E<SPO<W5M;6%R>3X-"B`@/&9U;F-T:6]N/F1O4F5M;W1E3&ES=#PO9G5N
M8W1I;VX^#0H@(#QS:&]R=&-U=#YR;#PO<VAO<G1C=70^#0H@(#QO<'1I;VYS
M/@T*("`@/&-H86YN96P^#0H@("`@/'-H;W)T;W!T/F,\+W-H;W)T;W!T/@T*
M("`@(#QD;V,^<W!E8VEF>2!A(&-H86YN96P@;W1H97(@=&AA;B!T:&4@9&5F
M875L="!C:&%N;F5L/"]D;V,^#0H@("`@/&%R9SY#2$%./"]A<F<^#0H@("`\
M+V-H86YN96P^#0H@(#PO;W!T:6]N<SX-"B`@/&1O8SX-"DQI<W1S('1H92!P
M86-K86=E<R!A=F%I;&%B;&4@;VX@=&AE(&-O;F9I9W5R960@<V5R=F5R(&%L
M;VYG('=I=&@@=&AE#0IL871E<W0@<W1A8FQE(')E;&5A<V4@;V8@96%C:"!P
M86-K86=E+CPO9&]C/@T*(#PO<F5M;W1E+6QI<W0^#0H@/'-E87)C:#X-"B`@
M/'-U;6UA<GD^4V5A<F-H(')E;6]T92!P86-K86=E(&1A=&%B87-E/"]S=6UM
M87)Y/@T*("`\9G5N8W1I;VX^9&]396%R8V@\+V9U;F-T:6]N/@T*("`\<VAO
M<G1C=70^<W`\+W-H;W)T8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QC:&%N;F5L
M/@T*("`@(#QS:&]R=&]P=#YC/"]S:&]R=&]P=#X-"B`@("`\9&]C/G-P96-I
M9GD@82!C:&%N;F5L(&]T:&5R('1H86X@=&AE(&1E9F%U;'0@8VAA;FYE;#PO
M9&]C/@T*("`@(#QA<F<^0TA!3CPO87)G/@T*("`@/"]C:&%N;F5L/@T*("`\
M+V]P=&EO;G,^#0H@(#QD;V,^6W!A8VMA9V5N86UE72!;<&%C:V%G96EN9F]=
M#0I,:7-T<R!A;&P@<&%C:V%G97,@=VAI8V@@;6%T8V@@=&AE('-E87)C:"!P
M87)A;65T97)S+B`@5&AE(&9I<G-T#0IP87)A;65T97(@:7,@82!F<F%G;65N
M="!O9B!A('!A8VMA9V5N86UE+B`@5&AE(&1E9F%U;'0@8VAA;FYE;`T*=VEL
M;"!B92!U<V5D('5N;&5S<R!E>'!L:6-I=&QY(&]V97)R:61D96XN("!4:&4@
M<V5C;VYD('!A<F%M971E<@T*=VEL;"!B92!U<V5D('1O(&UA=&-H(&%N>2!P
M;W)T:6]N(&]F('1H92!S=6UM87)Y+V1E<V-R:7!T:6]N/"]D;V,^#0H@/"]S
M96%R8V@^#0H@/&QI<W0M86QL/@T*("`\<W5M;6%R>3Y,:7-T($%L;"!086-K
M86=E<SPO<W5M;6%R>3X-"B`@/&9U;F-T:6]N/F1O3&ES=$%L;#PO9G5N8W1I
M;VX^#0H@(#QS:&]R=&-U=#YL83PO<VAO<G1C=70^#0H@(#QO<'1I;VYS/@T*
M("`@/&-H86YN96P^#0H@("`@/'-H;W)T;W!T/F,\+W-H;W)T;W!T/@T*("`@
M(#QD;V,^<W!E8VEF>2!A(&-H86YN96P@;W1H97(@=&AA;B!T:&4@9&5F875L
M="!C:&%N;F5L/"]D;V,^#0H@("`@/&%R9SY#2$%./"]A<F<^#0H@("`\+V-H
M86YN96P^#0H@(#PO;W!T:6]N<SX-"B`@/&1O8SX-"DQI<W1S('1H92!P86-K
M86=E<R!A=F%I;&%B;&4@;VX@=&AE(&-O;F9I9W5R960@<V5R=F5R(&%L;VYG
M('=I=&@@=&AE#0IL871E<W0@<W1A8FQE(')E;&5A<V4@;V8@96%C:"!P86-K
M86=E+CPO9&]C/@T*(#PO;&ES="UA;&P^#0H@/&1O=VYL;V%D/@T*("`\<W5M
M;6%R>3Y$;W=N;&]A9"!086-K86=E/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^
M9&]$;W=N;&]A9#PO9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YD/"]S:&]R=&-U
M=#X-"B`@/&]P=&EO;G,^#0H@("`\;F]C;VUP<F5S<SX-"B`@("`\<VAO<G1O
M<'0^6CPO<VAO<G1O<'0^#0H@("`@/&1O8SYD;W=N;&]A9"!A;B!U;F-O;7!R
M97-S960@*"YT87(I(&9I;&4\+V1O8SX-"B`@(#PO;F]C;VUP<F5S<SX-"B`@
M/"]O<'1I;VYS/@T*("`\9&]C/B9L=#MP86-K86=E)F=T.RXN+@T*1&]W;FQO
M860@<&%C:V%G92!T87)B86QL<RX@(%1H92!F:6QE<R!W:6QL(&)E(&YA;65D
M(&%S('-U9V=E<W1E9"!B>2!T:&4-"G-E<G9E<BP@9F]R(&5X86UP;&4@:68@
M>6]U(&1O=VYL;V%D('1H92!$0B!P86-K86=E(&%N9"!T:&4@;&%T97-T('-T
M86)L90T*=F5R<VEO;B!O9B!$0B!I<R`Q+C8N-2P@=&AE(&1O=VYL;V%D960@
M9FEL92!W:6QL(&)E($1"+3$N-BXU+G1G>BX\+V1O8SX-"B`\+V1O=VYL;V%D
M/@T*(#QC;&5A<BUC86-H93X-"B`@/'-U;6UA<GD^0VQE87(@5V5B(%-E<G9I
M8V5S($-A8VAE/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]#;&5A<D-A8VAE
M/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/F-C/"]S:&]R=&-U=#X-"B`@/&]P
M=&EO;G,@+SX-"B`@/&1O8SX-"D-L96%R('1H92!834PM4E!#+U)%4U0@8V%C
M:&4N("!3964@86QS;R!T:&4@8V%C:&5?='1L(&-O;F9I9W5R871I;VX-"G!A
M<F%M971E<BX-"CPO9&]C/@T*(#PO8VQE87(M8V%C:&4^#0H\+V-O;6UA;F1S
M/@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]497-T
M+G!H<```````````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(S-S(P`#$P
M-3$U-#,S-S0P`#`R,C,T,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`T*+RHJ#0H@*B!014%27T-O;6UA;F1?5&5S
M="`H<G5N+71E<W1S*0T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@
M*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O
M('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A
M=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O
M;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J
M('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@
M=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI
M8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D
M:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E
M("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP
M+FYE=#X-"B`J($!A=71H;W(@("`@($UA<G1I;B!*86YS96X@/&UJ0'!H<"YN
M970^#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN
M970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)
M9#H@5&5S="YP:'`L=B`Q+CD@,C`P-B\P,B\P,R`R,CHR.#HP."!C96QL;V<@
M17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC
M92!296QE87-E(#`N,0T*("HO#0H-"B\J*@T*("H@8F%S92!C;&%S<PT*("HO
M#0IR97%U:7)E7V]N8V4@)U!%05(O0V]M;6%N9"]#;VUM;VXN<&AP)SL-"@T*
M+RHJ#0H@*B!014%2(&-O;6UA;F1S(&9O<B!L;V=I;B]L;V=O=70-"B`J#0H@
M*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`
M875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T
M:&]R("`@("!-87)T:6X@2F%N<V5N(#QM:D!P:'`N;F5T/@T*("H@0&%U=&AO
M<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER
M:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E
M;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@
M*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P
M+C$-"B`J+PT*#0IC;&%S<R!014%27T-O;6UA;F1?5&5S="!E>'1E;F1S(%!%
M05)?0V]M;6%N9%]#;VUM;VX-"GL-"B`@("`O+R![>WL@<')O<&5R=&EE<PT*
M#0H@("`@=F%R("1C;VUM86YD<R`](&%R<F%Y*`T*("`@("`@("`G<G5N+71E
M<W1S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G4G5N
M(%)E9W)E<W-I;VX@5&5S=',G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]
M/B`G9&]2=6Y497-T<R<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=R
M="<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH#0H@("`@("`@
M("`@("`@("`@)W)E8W5R)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@
M("`@)W-H;W)T;W!T)R`]/B`G<B<L#0H@("`@("`@("`@("`@("`@("`@("=D
M;V,G(#T^("=2=6X@=&5S=',@:6X@8VAI;&0@9&ER96-T;W)I97,L(')E8W5R
M<VEV96QY+B`@-"!D:7)S(&1E97`@;6%X:6UU;2<L#0H@("`@("`@("`@("`@
M("`@*2P-"B`@("`@("`@("`@("`@("`G:6YI)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G:2<L#0H@("`@("`@("`@
M("`@("`@("`@("=D;V,G(#T^("=A8W1U86P@<W1R:6YG(&]F('-E='1I;F=S
M('1O('!A<W,@=&\@<&AP(&EN(&9O<FUA="`B("UD('-E='1I;F<]8FQA:"(G
M+`T*("`@("`@("`@("`@("`@("`@("`G87)G)R`]/B`G4T545$E.1U,G#0H@
M("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G<F5A;'1I;65L
M;V<G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G
M(#T^("=L)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)TQO9R!T
M97-T(')U;G,O<F5S=6QT<R!A<R!T:&5Y(&%R92!R=6XG+`T*("`@("`@("`@
M("`@("`@("DL#0H@("`@("`@("`@("`@("`@)W%U:65T)R`]/B!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G<2<L#0H@("`@
M("`@("`@("`@("`@("`@("=D;V,G(#T^("=/;FQY(&1I<W!L87D@9&5T86EL
M(&9O<B!F86EL960@=&5S=',G+`T*("`@("`@("`@("`@("`@("DL#0H@("`@
M("`@("`@("`@("`@)W-I;7!L92<@/3X@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`@("=S:&]R=&]P="<@/3X@)W,G+`T*("`@("`@("`@("`@("`@("`@
M("`G9&]C)R`]/B`G1&ES<&QA>2!S:6UP;&4@;W5T<'5T(&9O<B!A;&P@=&5S
M=',G+`T*("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)W!A
M8VMA9V4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O
M<'0G(#T^("=P)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)U1R
M96%T('!A<F%M971E<G,@87,@:6YS=&%L;&5D('!A8VMA9V5S(&9R;VT@=VAI
M8V@@=&\@<G5N('1E<W1S)RP-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@
M("`@("`@("`@("=P:'!U;FET)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@)W-H;W)T;W!T)R`]/B`G=2<L#0H@("`@("`@("`@("`@("`@("`@
M("=D;V,G(#T^("=396%R8V@@<&%R86UE=&5R<R!F;W(@06QL5&5S=',N<&AP
M+"!A;F0@=7-E('1H870@=&\@<G5N('!H<'5N:70M8F%S960@=&5S=',G+`T*
M("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`I+`T*("`@("`@("`@
M("`@)V1O8R<@/3X@)UMT97-T9FEL97QD:7(@+BXN70T*4G5N(')E9W)E<W-I
M;VX@=&5S=',@=VET:"!02%!<)W,@<F5G<F5S<VEO;B!T97-T:6YG('-C<FEP
M="`H<G5N+71E<W1S+G!H<"DN)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@
M("D[#0H-"B`@("!V87(@)&]U='!U=#L-"@T*("`@("\O('U]?0T*("`@("\O
M('M[>R!C;VYS=')U8W1O<@T*#0H@("`@+RHJ#0H@("`@("H@4$5!4E]#;VUM
M86YD7U1E<W0@8V]N<W1R=6-T;W(N#0H@("`@("H-"B`@("`@*B!`86-C97-S
M('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(%!%05)?0V]M;6%N9%]4
M97-T*"8D=6DL("8D8V]N9FEG*0T*("`@('L-"B`@("`@("`@<&%R96YT.CI0
M14%27T-O;6UA;F1?0V]M;6]N*"1U:2P@)&-O;F9I9RD[#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(&1O4G5N5&5S=',H*0T*#0H@("`@9G5N
M8W1I;VX@9&]2=6Y497-T<R@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I
M#0H@("`@>PT*("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O0V]M;6]N+G!H
M<"<[#0H@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]2=6Y497-T+G!H<"<[
M#0H@("`@("`@(')E<75I<F5?;VYC92`G4WES=&5M+G!H<"<[#0H@("`@("`@
M("1L;V<@/2!N97<@4$5!4E]#;VUM;VX[#0H@("`@("`@("1L;V<M/G5I(#T@
M)B1T:&ES+3YU:3L@+R\@<VQI9VAT;'D@:&%C:WDL(&)U="!I="!W:6QL('=O
M<FL-"B`@("`@("`@)')U;B`](&YE=R!014%27U)U;E1E<W0H)&QO9RP@)&]P
M=&EO;G,I.PT*("`@("`@("`D=&5S=',@/2!A<G)A>2@I.PT*("`@("`@("!I
M9B`H:7-S970H)&]P=&EO;G-;)W)E8W5R)UTI*2![#0H@("`@("`@("`@("`D
M9&5P=&@@/2`T.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&1E
M<'1H(#T@,3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6-O=6YT*"1P87)A
M;7,I*2![#0H@("`@("`@("`@("`D<&%R86US6UT@/2`G+B<[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=P86-K86=E)UTI*2![
M#0H@("`@("`@("`@("`D;VQD<&%R86US(#T@)'!A<F%M<SL-"B`@("`@("`@
M("`@("1P87)A;7,@/2!A<G)A>2@I.PT*("`@("`@("`@("`@)')E9R`]("8D
M=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("`@("`@9F]R
M96%C:"`H)&]L9'!A<F%M<R!A<R`D<&%R86TI('L-"B`@("`@("`@("`@("`@
M("`D<&YA;64@/2`D<F5G+3YP87)S95!A8VMA9V5.86UE*"1P87)A;2P@)'1H
M:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*2D[#0H@("`@("`@
M("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'!N86UE*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)'!N86UE
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'!A8VMA
M9V4@/2`F)')E9RT^9V5T4&%C:V%G92@D<&YA;65;)W!A8VMA9V4G72P@)'!N
M86UE6R=C:&%N;F5L)UTI.PT*("`@("`@("`@("`@("`@(&EF("@A)'!A8VMA
M9V4I('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)U5N:VYO=VX@<&%C:V%G92`B)R`N#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5G+3YP87)S961086-K86=E3F%M951O4W1R:6YG*"1P;F%M
M92D@+B`G(B<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`D9FEL96QI<W0@/2`D<&%C:V%G92T^9V5T1FEL96QI<W0H*3L-"B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D9FEL96QI<W0@87,@)&YA;64@/3X@)&%T
M=',I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A='1S6R=R
M;VQE)UTI("8F("1A='1S6R=R;VQE)UT@(3T@)W1E<W0G*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;
M)W!H<'5N:70G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A
M<')E9U]M871C:"@G+T%L;%1E<W1S7"YP:'`D+VDG+"`D;F%M92DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@G
M+UPN<&AP="0O)RP@)&YA;64I*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)'!A
M<F%M<UM=(#T@)&%T='-;)VEN<W1A;&QE9%]A<R==.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!F;W)E
M86-H("@D<&%R86US(&%S("1P*2![#0H@("`@("`@("`@("!I9B`H:7-?9&ER
M*"1P*2D@>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG
M<&AP=6YI="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D9&ER(#T@4WES
M=&5M.CIF:6YD*&%R<F%Y*"1P+"`G+71Y<&4G+"`G9B<L#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G+6UA>&1E
M<'1H)RP@)&1E<'1H+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)RUN86UE)RP@)T%L;%1E<W1S+G!H<"<I*3L-
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@
M("`D9&ER(#T@4WES=&5M.CIF:6YD*&%R<F%Y*"1P+"`G+71Y<&4G+"`G9B<L
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G+6UA>&1E<'1H)RP@)&1E<'1H+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)RUN86UE)RP@)RHN<&AP
M="<I*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'1E
M<W1S(#T@87)R87E?;65R9V4H)'1E<W1S+"`D9&ER*3L-"B`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS
M6R=P:'!U;FET)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A<')E
M9U]M871C:"@G+T%L;%1E<W1S7"YP:'`D+VDG+"`D<"DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("1T97-T<UM=(#T@)'`[#0H@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@:68@
M*"%`9FEL95]E>&ES=',H)'`I*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H(7!R96=?;6%T8V@H)R]<+G!H<'0D+R<L("1P*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P("X]("<N<&AP="<[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M9&ER(#T@4WES=&5M.CIF:6YD*&%R<F%Y*&1I<FYA;64H)'`I+"`G+71Y<&4G
M+"`G9B<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)RUM87AD97!T:"<L("1D97!T:"P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M+6YA;64G+"`D<"DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1E<W1S
M(#T@87)R87E?;65R9V4H)'1E<W1S+"`D9&ER*3L-"B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T97-T
M<UM=(#T@)'`[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&EN
M:5]S971T:6YG<R`]("<G.PT*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;
M)VEN:2==*2D@>PT*("`@("`@("`@("`@)&EN:5]S971T:6YG<R`N/2`D;W!T
M:6]N<ULG:6YI)UT[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1?
M14Y66R=415-47U!(4%])3D-,541%7U!!5$@G72DI('L-"B`@("`@("`@("`@
M("1I;FE?<V5T=&EN9W,@+CT@(B`M9"!I;F-L=61E7W!A=&@]>R1?14Y66R=4
M15-47U!(4%])3D-,541%7U!!5$@G77TB.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("@D:6YI7W-E='1I;F=S*2![#0H@("`@("`@("`@("`D=&AI<RT^=6DM
M/F]U='!U=$1A=&$H)U5S:6YG($E.22!S971T:6YG<SH@(B<@+B`D:6YI7W-E
M='1I;F=S("X@)R(G*3L-"B`@("`@("`@?0T*("`@("`@("`D<VMI<'!E9"`]
M("1P87-S960@/2`D9F%I;&5D(#T@87)R87DH*3L-"B`@("`@("`@)'1H:7,M
M/G5I+3YO=71P=71$871A*"=2=6YN:6YG("<@+B!C;W5N="@D=&5S=',I("X@
M)R!T97-T<R<L("1C;VUM86YD*3L-"B`@("`@("`@)'-T87)T(#T@=&EM92@I
M.PT*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W)E86QT:6UE;&]G)UTI
M*2![#0H@("`@("`@("`@("!`=6YL:6YK*"=R=6XM=&5S=',N;&]G)RD[#0H@
M("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)'1E<W1S(&%S("1T*2![#0H@
M("`@("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W)E86QT:6UE;&]G)UTI
M*2![#0H@("`@("`@("`@("`@("`@)&9P(#T@0&9O<&5N*"=R=6XM=&5S=',N
M;&]G)RP@)V$G*3L-"B`@("`@("`@("`@("`@("!I9B`H)&9P*2![#0H@("`@
M("`@("`@("`@("`@("`@(&9W<FET92@D9G`L(")2=6YN:6YG('1E<W0@)'0N
M+BXB*3L-"B`@("`@("`@("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@4$5!
M4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI
M.PT*("`@("`@("`@("`@)')E<W5L="`]("1R=6XM/G)U;B@D="P@)&EN:5]S
M971T:6YG<RD[#0H@("`@("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA
M;F1L:6YG*"D[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S
M=6QT*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;&]G*#`L("1R
M97-U;'0M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@8V]N=&EN
M=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)&]P
M=&EO;G-;)W)E86QT:6UE;&]G)UTI*2![#0H@("`@("`@("`@("`@("`@)&9P
M(#T@0&9O<&5N*"=R=6XM=&5S=',N;&]G)RP@)V$G*3L-"B`@("`@("`@("`@
M("`@("!I9B`H)&9P*2![#0H@("`@("`@("`@("`@("`@("`@(&9W<FET92@D
M9G`L("(D<F5S=6QT7&XB*3L-"B`@("`@("`@("`@("`@("`@("`@9F-L;W-E
M*"1F<"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@:68@*"1R97-U;'0@/3T@)T9!24Q%1"<I('L-"B`@("`@("`@
M("`@(`DD9F%I;&5D6UT@/2`D=#L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF("@D<F5S=6QT(#T]("=005-3140G*2![#0H@("`@("`@("`@("`)
M)'!A<W-E9%M=(#T@)'0[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H)')E<W5L="`]/2`G4TM)4%!%1"<I('L-"B`@("`@("`@("`@(`DD<VMI
M<'!E9%M=(#T@)'0[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@)'1O=&%L(#T@9&%T92@G:3IS)RP@=&EM92@I("T@)'-T87)T*3L-"B`@
M("`@("`@:68@*&-O=6YT*"1F86EL960I*2![#0H@("`@("`@("`@("`D;W5T
M<'5T(#T@(E1/5$%,(%1)344Z("1T;W1A;%QN(CL-"B`@("`@("`@("`@("1O
M=71P=70@+CT@8V]U;G0H)'!A<W-E9"D@+B`B(%!!4U-%1"!415-44UQN(CL-
M"B`@("`@("`@("`@("1O=71P=70@+CT@8V]U;G0H)'-K:7!P960I("X@(B!3
M2TE04$5$(%1%4U137&XB.PT*("`@(`D))&]U='!U="`N/2!C;W5N="@D9F%I
M;&5D*2`N("(@1D%)3$5$(%1%4U13.EQN(CL-"B`@("`@("`@"69O<F5A8V@@
M*"1F86EL960@87,@)&9A:6QU<F4I('L-"B`@("`@("`@"0DD;W5T<'5T("X]
M("1F86EL=7)E("X@(EQN(CL-"B`@("`@("`@"7T-"B`@("`@("`@("`@(&EF
M("AI<W-E="@D;W!T:6]N<ULG<F5A;'1I;65L;V<G72DI('L-"B`@("`@("`@
M("`@("`@("`D9G`@/2!`9F]P96XH)W)U;BUT97-T<RYL;V<G+"`G82<I.PT*
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D9G`@/2!`
M9F]P96XH)W)U;BUT97-T<RYL;V<G+"`G=R<I.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*"1F<"D@>PT*("`@("`@("`@("`@("`@(&9W<FET
M92@D9G`L("1O=71P=70L('-T<FQE;B@D;W5T<'5T*2D[#0H@("`@("`@("`@
M("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("`@("`@("`@)'1H:7,M/G5I
M+3YO=71P=71$871A*"=W<F]T92!L;V<@=&\@(B<@+B!R96%L<&%T:"@G<G5N
M+71E<W1S+FQO9R<I("X@)R(G+"`D8V]M;6%N9"D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T@96QS96EF("A`9FEL95]E>&ES=',H)W)U;BUT97-T<RYL
M;V<G*2`F)B`A0&ES7V1I<B@G<G5N+71E<W1S+FQO9R<I*2![#0H@("`@("`@
M("`@("!`=6YL:6YK*"=R=6XM=&5S=',N;&]G)RD[#0H@("`@("`@('T-"B`@
M("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"=43U1!3"!424U%.B`G("X@
M)'1O=&%L*3L-"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*&-O=6YT
M*"1P87-S960I("X@)R!005-3140@5$535%,G+"`D8V]M;6%N9"D[#0H@("`@
M("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82AC;W5N="@D<VMI<'!E9"D@+B`G
M(%-+25!0140@5$535%,G+"`D8V]M;6%N9"D[#0H@("`@("`@(&EF("AC;W5N
M="@D9F%I;&5D*2D@>PT*("`@(`D))'1H:7,M/G5I+3YO=71P=71$871A*&-O
M=6YT*"1F86EL960I("X@)R!&04E,140@5$535%,Z)RP@)&-O;6UA;F0I.PT*
M("`@("`@("`)9F]R96%C:"`H)&9A:6QE9"!A<R`D9F%I;'5R92D@>PT*("`@
M("`@("`)"21T:&ES+3YU:2T^;W5T<'5T1&%T82@D9F%I;'5R92P@)&-O;6UA
M;F0I.PT*("`@("`@("`)?0T*("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N
M('1R=64[#0H@("`@?0T*("`@("\O('U]?0T*?0T*#0H_/@T*````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]497-T+GAM
M;```````````````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S(R`#$P-3$U
M-#,S-S0P`#`R,C,T-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\8V]M;6%N9',@=F5R<VEO;CTB,2XP(CX-"B`\<G5N+71E
M<W1S/@T*("`\<W5M;6%R>3Y2=6X@4F5G<F5S<VEO;B!497-T<SPO<W5M;6%R
M>3X-"B`@/&9U;F-T:6]N/F1O4G5N5&5S=',\+V9U;F-T:6]N/@T*("`\<VAO
M<G1C=70^<G0\+W-H;W)T8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QR96-U<CX-
M"B`@("`\<VAO<G1O<'0^<CPO<VAO<G1O<'0^#0H@("`@/&1O8SY2=6X@=&5S
M=',@:6X@8VAI;&0@9&ER96-T;W)I97,L(')E8W5R<VEV96QY+B`@-"!D:7)S
M(&1E97`@;6%X:6UU;3PO9&]C/@T*("`@/"]R96-U<CX-"B`@(#QI;FD^#0H@
M("`@/'-H;W)T;W!T/FD\+W-H;W)T;W!T/@T*("`@(#QD;V,^86-T=6%L('-T
M<FEN9R!O9B!S971T:6YG<R!T;R!P87-S('1O('!H<"!I;B!F;W)M870@)G%U
M;W0[("UD('-E='1I;F<]8FQA:"9Q=6]T.SPO9&]C/@T*("`@(#QA<F<^4T54
M5$E.1U,\+V%R9SX-"B`@(#PO:6YI/@T*("`@/')E86QT:6UE;&]G/@T*("`@
M(#QS:&]R=&]P=#YL/"]S:&]R=&]P=#X-"B`@("`\9&]C/DQO9R!T97-T(')U
M;G,O<F5S=6QT<R!A<R!T:&5Y(&%R92!R=6X\+V1O8SX-"B`@(#PO<F5A;'1I
M;65L;V<^#0H@("`\<75I970^#0H@("`@/'-H;W)T;W!T/G$\+W-H;W)T;W!T
M/@T*("`@(#QD;V,^3VYL>2!D:7-P;&%Y(&1E=&%I;"!F;W(@9F%I;&5D('1E
M<W1S/"]D;V,^#0H@("`\+W%U:65T/@T*("`@/'-I;7!L93X-"B`@("`\<VAO
M<G1O<'0^<SPO<VAO<G1O<'0^#0H@("`@/&1O8SY$:7-P;&%Y('-I;7!L92!O
M=71P=70@9F]R(&%L;"!T97-T<SPO9&]C/@T*("`@/"]S:6UP;&4^#0H@("`\
M<&%C:V%G93X-"B`@("`\<VAO<G1O<'0^<#PO<VAO<G1O<'0^#0H@("`@/&1O
M8SY4<F5A="!P87)A;65T97)S(&%S(&EN<W1A;&QE9"!P86-K86=E<R!F<F]M
M('=H:6-H('1O(')U;B!T97-T<SPO9&]C/@T*("`@/"]P86-K86=E/@T*("`@
M/'!H<'5N:70^#0H@("`@/'-H;W)T;W!T/G4\+W-H;W)T;W!T/@T*("`@(#QD
M;V,^4V5A<F-H('!A<F%M971E<G,@9F]R($%L;%1E<W1S+G!H<"P@86YD('5S
M92!T:&%T('1O(')U;B!P:'!U;FET+6)A<V5D('1E<W1S/"]D;V,^#0H@("`\
M+W!H<'5N:70^#0H@(#PO;W!T:6]N<SX-"B`@/&1O8SY;=&5S=&9I;&5\9&ER
M("XN+ET-"E)U;B!R96=R97-S:6]N('1E<W1S('=I=&@@4$A0)F%P;W,[<R!R
M96=R97-S:6]N('1E<W1I;F<@<V-R:7!T("AR=6XM=&5S=',N<&AP*2X\+V1O
M8SX-"B`\+W)U;BUT97-T<SX-"CPO8V]M;6%N9',^````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O4$5!4B]#;VUM86YD+G!H<```````````````````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,S$V,S$`,3`U,34T,S,W-#$`,#(Q-#(T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP#0HO*BH-
M"B`J(%!%05)?0V]M;6%N9"P@8V]M;6%N9"!P871T97)N(&-L87-S#0H@*@T*
M("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES
M('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE
M(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED
M(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N
M9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L
M96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E
M(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A
M=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO
M<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@
M("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H
M="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E
M(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z($-O;6UA;F0N<&AP+'8@
M,2XS-B`R,#`V+S`Q+S`V(#`T.C0W.C,V(&-E;&QO9R!%>'`@)`T*("H@0&QI
M;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J
M($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ
M#0H@*B\-"@T*+RHJ#0H@*B!.965D960@9F]R(&5R<F]R(&AA;F1L:6YG#0H@
M*B\-"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PT*<F5Q=6ER95]O;F-E("=0
M14%2+T9R;VYT96YD+G!H<"<[#0IR97%U:7)E7V]N8V4@)U!%05(O6$U,4&%R
M<V5R+G!H<"<[#0H-"B\J*@T*("H@3&ES="!O9B!C;VUM86YD<R!A;F0@=VAA
M="!C;&%S<V5S('1H97D@87)E(&EM<&QE;65N=&5D(&EN+@T*("H@0'9A<B!A
M<G)A>2!C;VUM86YD(#T^(&EM<&QE;65N=&EN9R!C;&%S<PT*("HO#0HD1TQ/
M0D%,4ULG7U!%05)?0V]M;6%N9%]C;VUM86YD;&ES="==(#T@87)R87DH*3L-
M"@T*+RHJ#0H@*B!,:7-T(&]F('-H;W)T8W5T<R!T;R!C;VUM;VX@8V]M;6%N
M9',N#0H@*B!`=F%R(&%R<F%Y('-H;W)T8W5T(#T^(&-O;6UA;F0-"B`J+PT*
M)$=,3T)!3%-;)U]014%27T-O;6UA;F1?<VAO<G1C=71S)UT@/2!A<G)A>2@I
M.PT*#0HO*BH-"B`J($%R<F%Y(&]F(&-O;6UA;F0@;V)J96-T<PT*("H@0'9A
M<B!A<G)A>2!C;&%S<R`]/B!O8FIE8W0-"B`J+PT*)$=,3T)!3%-;)U]014%2
M7T-O;6UA;F1?;V)J96-T<R==(#T@87)R87DH*3L-"@T*+RHJ#0H@*B!014%2
M(&-O;6UA;F0@8VQA<W,L(&$@<VEM<&QE(&9A8W1O<GD@8VQA<W,@9F]R(&%D
M;6EN:7-T<F%T:79E#0H@*B!C;VUM86YD<RX-"B`J#0H@*B!(;W<@=&\@:6UP
M;&5M96YT(&-O;6UA;F0@8VQA<W-E<SH-"B`J#0H@*B`M(%1H92!C;&%S<R!M
M=7-T(&)E(&-A;&QE9"!014%27T-O;6UA;F1?3FYN+"!I;G-T86QL960@:6X@
M=&AE#0H@*B`@(")014%2+T-O;6UO;B(@<W5B9&ER+"!W:71H(&$@;65T:&]D
M(&-A;&QE9"!G971#;VUM86YD<R@I('1H870-"B`J("`@<F5T=7)N<R!A;B!A
M<G)A>2!O9B!T:&4@8V]M;6%N9',@:6UP;&5M96YT960@8GD@=&AE(&-L87-S
M("AS964-"B`J("`@4$5!4B]#;VUM86YD+TEN<W1A;&PN<&AP(&9O<B!A;B!E
M>&%M<&QE*2X-"B`J#0H@*B`M(%1H92!C;&%S<R!M=7-T(&EM<&QE;65N="!A
M(')U;B@I(&9U;F-T:6]N('1H870@:7,@8V%L;&5D('=I=&@@=&AR964-"B`J
M("`@<&%R86US.@T*("H-"B`J("`@("AS=')I;F<I(&-O;6UA;F0@;F%M90T*
M("H@("`@*&%R<F%Y*2`@87-S;V,@87)R87D@=VET:"!O<'1I;VYS+"!F<F5E
M;'D@9&5F:6YE9"!B>2!E86-H#0H@*B`@("`@("`@("`@("!C;VUM86YD+"!F
M;W(@97AA;7!L93H-"B`J("`@("`@("`@("`@(&%R<F%Y*"=F;W)C92<@/3X@
M=')U92D-"B`J("`@("AA<G)A>2D@(&QI<W0@;V8@=&AE(&]T:&5R('!A<F%M
M971E<G,-"B`J#0H@*B`@(%1H92!R=6XH*2!F=6YC=&EO;B!R971U<FYS(&$@
M4$5!4E]#;VUM86YD4F5S<&]N<V4@;V)J96-T+B`@57-E#0H@*B`@('1H97-E
M(&UE=&AO9',@=&\@9V5T(&EN9F]R;6%T:6]N.@T*("H-"B`J("`@(&EN="!G
M9713=&%T=7,H*2`@(%)E='5R;G,@4$5!4E]#3TU-04Y$7RA354-#15-3?$9!
M24Q54D5\4$%25$E!3"D-"B`J("`@("`@("`@("`@("`@("`@("`@("I?4$%2
M5$E!3"!M96%N<R!T:&%T('EO=2!N965D('1O(&ES<W5E(&%T(&QE87-T#0H@
M*B`@("`@("`@("`@("`@("`@("`@("!O;F4@;6]R92!C;VUM86YD('1O(&-O
M;7!L971E('1H92!O<&5R871I;VX-"B`J("`@("`@("`@("`@("`@("`@("`@
M("AU<V5D(&9O<B!E>&%M<&QE(&9O<B!V86QI9&%T:6]N('-T97!S*2X-"B`J
M#0H@*B`@("!S=')I;F<@9V5T365S<V%G92@I("!2971U<FYS(&$@;65S<V%G
M92!F;W(@=&AE('5S97(N("!296UE;6)E<BP-"B`J("`@("`@("`@("`@("`@
M("`@("`@("`@(&YO($A434P@;W(@;W1H97(@:6YT97)F86-E+7-P96-I9FEC
M(&UA<FMU<"X-"B`J#0H@*B`@($EF('-O;65T:&EN9R!U;F5X<&5C=&5D(&AA
M<'!E;G,L(')U;B@I(')E='5R;G,@82!014%2(&5R<F]R+@T*("H-"B`J("T@
M1$].)U0@3U544%54($%.651(24Y'(2!2971U<FX@=&5X="!F;W(@;W5T<'5T
M(&EN<W1E860N#0H@*@T*("H@+2!$3TXG5"!54T4@2%1-3"$@5&AE('1E>'0@
M>6]U(')E='5R;B!W:6QL(&)E('5S960@9G)O;2!B;W1H($=T:RP-"B`J("`@
M=V5B(&%N9"!C;VUM86YD+6QI;F4@:6YT97)F86-E<RP@<V\@9F]R(&YO=RP@
M:V5E<"!E=F5R>71H:6YG('1O#0H@*B`@('!L86EN('1E>'0N#0H@*@T*("H@
M+2!$3TXG5"!54T4@15A)5"!/4B!$244A($%L=V%Y<R!U<V4@<&5A<B!E<G)O
M<G,N("!&<F]M('-T871I8PT*("H@("!C;&%S<V5S(&1O(%!%05(Z.G)A:7-E
M17)R;W(H*2P@9G)O;2!O=&AE<B!C;&%S<V5S(&1O#0H@*B`@("1T:&ES+3YR
M86ES945R<F]R*"DN#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G
M92`@("!014%2#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H
M<"YN970^#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H
M<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U
M<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE
M87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L
M92!S:6YC92!296QE87-E(#`N,0T*("HO#0IC;&%S<R!014%27T-O;6UA;F0-
M"GL-"B`@("`O+R![>WL@9F%C=&]R>2@I#0H-"B`@("`O*BH-"B`@("`@*B!'
M970@=&AE(')I9VAT(&]B:F5C="!F;W(@97AE8W5T:6YG(&$@8V]M;6%N9"X-
M"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)&-O;6UA;F0@5&AE(&YA
M;64@;V8@=&AE(&-O;6UA;F0-"B`@("`@*B!`<&%R86T@;V)J96-T("1C;VYF
M:6<@($EN<W1A;F-E(&]F(%!%05)?0V]N9FEG(&]B:F5C=`T*("`@("`J#0H@
M("`@("H@0')E='5R;B!O8FIE8W0@=&AE(&-O;6UA;F0@;V)J96-T(&]R(&$@
M4$5!4B!E<G)O<@T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@
M("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F9A8W1O<GDH
M)&-O;6UA;F0L("8D8V]N9FEG*0T*("`@('L-"B`@("`@("`@:68@*&5M<'1Y
M*"1'3$]"04Q36R=?4$5!4E]#;VUM86YD7V-O;6UA;F1L:7-T)UTI*2![#0H@
M("`@("`@("`@("!014%27T-O;6UA;F0Z.G)E9VES=&5R0V]M;6%N9',H*3L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)$=,3T)!3%-;)U]014%2
M7T-O;6UA;F1?<VAO<G1C=71S)UU;)&-O;6UA;F1=*2D@>PT*("`@("`@("`@
M("`@)&-O;6UA;F0@/2`D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]S:&]R=&-U
M=',G75LD8V]M;6%N9%T[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E
M="@D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]C;VUM86YD;&ES="==6R1C;VUM
M86YD72DI('L-"B`@("`@("`@("`@("1A(#T@4$5!4CHZ<F%I<V5%<G)O<B@B
M=6YK;F]W;B!C;VUM86YD(&`D8V]M;6%N9"<B*3L-"B`@("`@("`@("`@(')E
M='5R;B`D83L-"B`@("`@("`@?0T*("`@("`@("`D8VQA<W,@/2`D1TQ/0D%,
M4ULG7U!%05)?0V]M;6%N9%]C;VUM86YD;&ES="==6R1C;VUM86YD73L-"B`@
M("`@("`@:68@*"%C;&%S<U]E>&ES=',H)&-L87-S*2D@>PT*("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E("1'3$]"04Q36R=?4$5!4E]#;VUM86YD7V]B:F5C
M=',G75LD8VQA<W-=.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A8VQA<W-?
M97AI<W1S*"1C;&%S<RDI('L-"B`@("`@("`@("`@("1A(#T@4$5!4CHZ<F%I
M<V5%<G)O<B@B=6YK;F]W;B!C;VUM86YD(&`D8V]M;6%N9"<B*3L-"B`@("`@
M("`@("`@(')E='5R;B`D83L-"B`@("`@("`@?0T*("`@("`@("`D=6D@/28@
M4$5!4E]#;VUM86YD.CIG971&<F]N=&5N9$]B:F5C="@I.PT*("`@("`@("`D
M;V)J(#T@)FYE=R`D8VQA<W,H)'5I+"`D8V]N9FEG*3L-"B`@("`@("`@<F5T
M=7)N("1O8FH[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[("8@
M9V5T3V)J96-T*"D-"B`@("!F=6YC=&EO;B`F9V5T3V)J96-T*"1C;VUM86YD
M*0T*("`@('L-"B`@("`@("`@)&-L87-S(#T@)$=,3T)!3%-;)U]014%27T-O
M;6UA;F1?8V]M;6%N9&QI<W0G75LD8V]M;6%N9%T[#0H@("`@("`@(&EF("@A
M8VQA<W-?97AI<W1S*"1C;&%S<RDI('L-"B`@("`@("`@("`@(')E<75I<F5?
M;VYC92`D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]O8FIE8W1S)UU;)&-L87-S
M73L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@D8VQA
M<W,I*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B
M=6YK;F]W;B!C;VUM86YD(&`D8V]M;6%N9"<B*3L-"B`@("`@("`@?0T*("`@
M("`@("`D=6D@/28@4$5!4E]#;VUM86YD.CIG971&<F]N=&5N9$]B:F5C="@I
M.PT*("`@("`@("`D8V]N9FEG(#T@)E!%05)?0V]N9FEG.CIS:6YG;&5T;VXH
M*3L-"B`@("`@("`@)&]B:B`]("9N97<@)&-L87-S*"1U:2P@)&-O;F9I9RD[
M#0H@("`@("`@(')E='5R;B`D;V)J.PT*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R`F(&=E=$9R;VYT96YD3V)J96-T*"D-"@T*("`@("\J*@T*
M("`@("`J($=E="!I;G-T86YC92!O9B!F<F]N=&5N9"!O8FIE8W0N#0H@("`@
M("H-"B`@("`@*B!`<F5T=7)N(&]B:F5C='Q014%27T5R<F]R#0H@("`@("H@
M0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N("9G971&<F]N=&5N9$]B
M:F5C="@I#0H@("`@>PT*("`@("`@("`D82`]("9014%27T9R;VYT96YD.CIS
M:6YG;&5T;VXH*3L-"B`@("`@("`@<F5T=7)N("1A.PT*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R`F('-E=$9R;VYT96YD0VQA<W,H*0T*#0H@
M("`@+RHJ#0H@("`@("H@3&]A9"!C=7)R96YT(&9R;VYT96YD(&-L87-S+@T*
M("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D=6EC;&%S<R!.86UE(&]F
M(&-L87-S(&EM<&QE;65N=&EN9R!T:&4@9G)O;G1E;F0-"B`@("`@*@T*("`@
M("`J($!R971U<FX@;V)J96-T('1H92!F<F]N=&5N9"!O8FIE8W0L(&]R(&$@
M4$5!4B!E<G)O<@T*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B`F<V5T1G)O;G1E;F1#;&%S<R@D=6EC;&%S<RD-"B`@("![#0H@("`@
M("`@("1A(#T@)E!%05)?1G)O;G1E;F0Z.G-E=$9R;VYT96YD0VQA<W,H)'5I
M8VQA<W,I.PT*("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[('-E=$9R;VYT96YD5'EP92@I#0H-"B`@("`O*BH-
M"B`@("`@*B!3970@8W5R<F5N="!F<F]N=&5N9"X-"B`@("`@*@T*("`@("`J
M($!P87)A;2!S=')I;F<@)'5I='EP92!.86UE(&]F('1H92!F<F]N=&5N9"!T
M>7!E("AF;W(@97AA;7!L92`B0TQ)(BD-"B`@("`@*@T*("`@("`J($!R971U
M<FX@;V)J96-T('1H92!F<F]N=&5N9"!O8FIE8W0L(&]R(&$@4$5!4B!E<G)O
M<@T*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971&
M<F]N=&5N9%1Y<&4H)'5I='EP92D-"B`@("![#0H@("`@("`@("1U:6-L87-S
M(#T@)U!%05)?1G)O;G1E;F1?)R`N("1U:71Y<&4[#0H@("`@("`@(')E='5R
M;B!014%27T-O;6UA;F0Z.G-E=$9R;VYT96YD0VQA<W,H)'5I8VQA<W,I.PT*
M("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!R96=I<W1E<D-O;6UA
M;F1S*"D-"@T*("`@("\J*@T*("`@("`J(%-C86X@=&AR;W5G:"!T:&4@0V]M
M;6%N9"!D:7)E8W1O<GD@;&]O:VEN9R!F;W(@8VQA<W-E<PT*("`@("`J(&%N
M9"!S964@=VAA="!C;VUM86YD<R!T:&5Y(&EM<&QE;65N="X-"B`@("`@*@T*
M("`@("`J($!P87)A;2!B;V]L("`@*&]P=&EO;F%L*2!I9B!&04Q312`H9&5F
M875L="DL('1H92!N97<@;&ES="!O9@T*("`@("`J("`@("`@("`@("`@("`@
M8V]M;6%N9',@<VAO=6QD(')E<&QA8V4@=&AE(&-U<G)E;G0@;VYE+B`@268@
M5%)512P-"B`@("`@*B`@("`@("`@("`@("`@(&YE=R!E;G1R:65S('=I;&P@
M8F4@;65R9V5D('=I=&@@;VQD+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T
M<FEN9R`H;W!T:6]N86PI('=H97)E("AW:&%T(&1I<F5C=&]R>2D@=&\@;&]O
M:R!F;W(-"B`@("`@*B`@("`@("`@("`@("`@(&-L87-S97,L(&1E9F%U;'1S
M('1O('1H92!#;VUM86YD('-U8F1I<F5C=&]R>2!O9@T*("`@("`J("`@("`@
M("`@("`@("`@=&AE(&1I<F5C=&]R>2!F<F]M('=H97)E('1H:7,@9FEL92`H
M7U]&24Q%7U\I(&ES#0H@("`@("H@("`@("`@("`@("`@("!I;F-L=61E9"X-
M"B`@("`@*@T*("`@("`J($!R971U<FX@8F]O;"!44E5%(&]N('-U8V-E<W,L
M(&$@4$5!4B!E<G)O<B!O;B!F86EL=7)E#0H@("`@("H-"B`@("`@*B!`86-C
M97-S('!U8FQI8PT*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!R96=I<W1E<D-O;6UA;F1S*"1M97)G92`](&9A;'-E+"`D9&ER(#T@
M;G5L;"D-"B`@("![#0H@("`@("`@("1P87)S97(@/2!N97<@4$5!4E]834Q0
M87)S97([#0H@("`@("`@(&EF("@D9&ER(#T]/2!N=6QL*2![#0H@("`@("`@
M("`@("`D9&ER(#T@9&ER;F%M92A?7T9)3$5?7RD@+B`G+T-O;6UA;F0G.PT*
M("`@("`@("!]#0H@("`@("`@("1D<"`]($!O<&5N9&ER*"1D:7(I.PT*("`@
M("`@("!I9B`H96UP='DH)&1P*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H(G)E9VES=&5R0V]M;6%N9',Z(&]P96YD:7(H)&1I
M<BD@9F%I;&5D(BD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D;65R9V4I
M('L-"B`@("`@("`@("`@("1'3$]"04Q36R=?4$5!4E]#;VUM86YD7V-O;6UA
M;F1L:7-T)UT@/2!A<G)A>2@I.PT*("`@("`@("!]#0H@("`@("`@('=H:6QE
M("@D96YT<GD@/2!R96%D9&ER*"1D<"DI('L-"B`@("`@("`@("`@(&EF("@D
M96YT<GE[,'T@/3T@)RXG('Q\('-U8G-T<B@D96YT<GDL("TT*2`A/2`G+GAM
M;"<I('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("1C;&%S<R`](")014%27T-O;6UA;F1?(BYS=6)S
M='(H)&5N=')Y+"`P+"`M-"D[#0H@("`@("`@("`@("`D9FEL92`]("(D9&ER
M+R1E;G1R>2([#0H@("`@("`@("`@("`D<&%R<V5R+3YP87)S92AF:6QE7V=E
M=%]C;VYT96YT<R@D9FEL92DI.PT*("`@("`@("`@("`@)&EM<&QE;65N=',@
M/2`D<&%R<V5R+3YG971$871A*"D[#0H@("`@("`@("`@("`O+R!,:7-T(&]F
M(&-O;6UA;F1S#0H@("`@("`@("`@("!I9B`H96UP='DH)$=,3T)!3%-;)U]0
M14%27T-O;6UA;F1?;V)J96-T<R==6R1C;&%S<UTI*2![#0H@("`@("`@("`@
M("`@("`@)$=,3T)!3%-;)U]014%27T-O;6UA;F1?;V)J96-T<R==6R1C;&%S
M<UT@/2`B)&1I<B\B("X@<W5B<W1R*"1E;G1R>2P@,"P@+30I("X-"B`@("`@
M("`@("`@("`@("`@("`@)RYP:'`G.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@9F]R96%C:"`H)&EM<&QE;65N=',@87,@)&-O;6UA;F0@/3X@)&1E
M<V,I('L-"B`@("`@("`@("`@("`@("!I9B`H)&-O;6UA;F0@/3T@)V%T=')I
M8G,G*2![#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)$=,3T)!
M3%-;)U]014%27T-O;6UA;F1?8V]M;6%N9&QI<W0G75LD8V]M;6%N9%TI*2![
M#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=#;VUM86YD("(G("X@)&-O;6UA;F0@+B`G(B!A;')E861Y(')E9VES=&5R
M960@:6X@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G8VQA<W,@(B<@
M+B`D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]C;VUM86YD;&ES="==6R1C;VUM
M86YD72`N("<B)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("1'3$]"04Q36R=?4$5!4E]#;VUM86YD7V-O;6UA;F1L:7-T)UU;)&-O
M;6UA;F1=(#T@)&-L87-S.PT*("`@("`@("`@("`@("`@("1'3$]"04Q36R=?
M4$5!4E]#;VUM86YD7V-O;6UA;F1D97-C)UU;)&-O;6UA;F1=(#T@)&1E<V-;
M)W-U;6UA<GDG73L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<V-;
M)W-H;W)T8W5T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1S:&]R=&-U
M="`]("1D97-C6R=S:&]R=&-U="==.PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)$=,3T)!3%-;)U]014%27T-O;6UA;F1?<VAO<G1C=71S)UU;
M)'-H;W)T8W5T72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=#;VUM86YD('-H;W)T8W5T("(G("X@)'-H
M;W)T8W5T("X@)R(@86QR96%D>2`G("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<F5G:7-T97)E9"!T;R!C;VUM86YD("(G("X@)&-O;6UA;F0@
M+B`G(B!I;B!C;&%S<R`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)$=,3T)!3%-;)U]014%27T-O;6UA;F1?8V]M;6%N9&QI<W0G75LD8V]M
M;6%N9%T@+B`G(B<I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("1'3$]"04Q36R=?4$5!4E]#;VUM86YD7W-H;W)T8W5T
M<R==6R1S:&]R=&-U=%T@/2`D8V]M;6%N9#L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97-C6R=O<'1I;VYS)UTI
M("8F("1D97-C6R=O<'1I;VYS)UTI('L-"B`@("`@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)&1E<V-;)V]P=&EO;G,G72!A<R`D;VYA;64@/3X@)&]P=&EO
M;BD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1O<'1I
M;VY;)W-H;W)T;W!T)UTI("8F('-T<FQE;B@D;W!T:6]N6R=S:&]R=&]P="==
M*2`^(#$I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G3W!T:6]N("(G("X@)&]N86UE("X@)R(@<VAO
M<G0@;W!T:6]N("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&]P=&EO;ELG<VAO<G1O<'0G72`N("<B(&UU<W0@8F4@)R`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=O;FQY(#$@8VAA<F%C=&5R
M(&EN($-O;6UA;F0@(B<@+B`D8V]M;6%N9"`N("<B(&EN(&-L87-S("(G("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-L87-S("X@)R(G
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("!K<V]R="@D1TQ/0D%,4ULG7U!%05)?0V]M;6%N
M9%]S:&]R=&-U=',G72D[#0H@("`@("`@(&MS;W)T*"1'3$]"04Q36R=?4$5!
M4E]#;VUM86YD7V-O;6UA;F1L:7-T)UTI.PT*("`@("`@("!`8VQO<V5D:7(H
M)&1P*3L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(&=E=$-O;6UA;F1S*"D-"@T*("`@("\J*@T*("`@
M("`J($=E="!T:&4@;&ES="!O9B!C=7)R96YT;'D@<W5P<&]R=&5D(&-O;6UA
M;F1S+"!A;F0@=VAA=`T*("`@("`J(&-L87-S97,@:6UP;&5M96YT('1H96TN
M#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&%R<F%Y(&-O;6UA;F0@/3X@:6UP
M;&5M96YT:6YG(&-L87-S#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI
M8PT*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971#
M;VUM86YD<R@I#0H@("`@>PT*("`@("`@("!I9B`H96UP='DH)$=,3T)!3%-;
M)U]014%27T-O;6UA;F1?8V]M;6%N9&QI<W0G72DI('L-"B`@("`@("`@("`@
M(%!%05)?0V]M;6%N9#HZ<F5G:7-T97)#;VUM86YD<R@I.PT*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]C;VUM
M86YD;&ES="==.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G
M9713:&]R=&-U=',H*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!L:7-T
M(&]F(&-O;6UA;F0@<VAO<G1C=71S+@T*("`@("`J#0H@("`@("H@0')E='5R
M;B!A<G)A>2!S:&]R=&-U="`]/B!C;VUM86YD#0H@("`@("H-"B`@("`@*B!`
M86-C97-S('!U8FQI8PT*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!G9713:&]R=&-U=',H*0T*("`@('L-"B`@("`@("`@:68@*&5M
M<'1Y*"1'3$]"04Q36R=?4$5!4E]#;VUM86YD7W-H;W)T8W5T<R==*2D@>PT*
M("`@("`@("`@("`@4$5!4E]#;VUM86YD.CIR96=I<W1E<D-O;6UA;F1S*"D[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1'3$]"04Q36R=?4$5!4E]#
M;VUM86YD7W-H;W)T8W5T<R==.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R!G971'971O<'1!<F=S*"D-"@T*("`@("\J*@T*("`@("`J($-O
M;7!I;&5S(&%R9W5M96YT<R!F;W(@9V5T;W!T+@T*("`@("`J#0H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8V]M;6%N9"`@("`@8V]M;6%N9"!T;R!G970@;W!T
M<W1R:6YG(&9O<@T*("`@("`J($!P87)A;2!S=')I;F<@)'-H;W)T7V%R9W,@
M("AR969E<F5N8V4I('-H;W)T(&=E=&]P="!F;W)M870-"B`@("`@*B!`<&%R
M86T@87)R87D@("1L;VYG7V%R9W,@("`H<F5F97)E;F-E*2!L;VYG(&=E=&]P
M="!F;W)M870-"B`@("`@*@T*("`@("`J($!R971U<FX@=F]I9`T*("`@("`J
M#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`<W1A=&EC#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@9V5T1V5T;W!T07)G<R@D8V]M;6%N9"P@)B1S
M:&]R=%]A<F=S+"`F)&QO;F=?87)G<RD-"B`@("![#0H@("`@("`@(&EF("AE
M;7!T>2@D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]C;VUM86YD;&ES="==*2D@
M>PT*("`@("`@("`@("`@4$5!4E]#;VUM86YD.CIR96=I<W1E<D-O;6UA;F1S
M*"D[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1'3$]"04Q36R=?
M4$5!4E]#;VUM86YD7W-H;W)T8W5T<R==6R1C;VUM86YD72DI('L-"B`@("`@
M("`@("`@("1C;VUM86YD(#T@)$=,3T)!3%-;)U]014%27T-O;6UA;F1?<VAO
M<G1C=71S)UU;)&-O;6UA;F1=.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A
M:7-S970H)$=,3T)!3%-;)U]014%27T-O;6UA;F1?8V]M;6%N9&QI<W0G75LD
M8V]M;6%N9%TI*2![#0H@("`@("`@("`@("!R971U<FX@;G5L;#L-"B`@("`@
M("`@?0T*("`@("`@("`D;V)J(#T@)E!%05)?0V]M;6%N9#HZ9V5T3V)J96-T
M*"1C;VUM86YD*3L-"B`@("`@("`@<F5T=7)N("1O8FHM/F=E=$=E=&]P=$%R
M9W,H)&-O;6UA;F0L("1S:&]R=%]A<F=S+"`D;&]N9U]A<F=S*3L-"B`@("!]
M#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T1&5S8W)I<'1I;VXH*0T*
M#0H@("`@+RHJ#0H@("`@("H@1V5T(&1E<V-R:7!T:6]N(&9O<B!A(&-O;6UA
M;F0N#0H@("`@("H-"B`@("`@*B!`<&%R86T@('-T<FEN9R`D8V]M;6%N9"!.
M86UE(&]F('1H92!C;VUM86YD#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R!C;VUM86YD(&1E<V-R:7!T:6]N#0H@("`@("H-"B`@("`@*B!`86-C
M97-S('!U8FQI8PT*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!G971$97-C<FEP=&EO;B@D8V]M;6%N9"D-"B`@("![#0H@("`@("`@
M(&EF("@A:7-S970H)$=,3T)!3%-;)U]014%27T-O;6UA;F1?8V]M;6%N9&1E
M<V,G75LD8V]M;6%N9%TI*2![#0H@("`@("`@("`@("!R971U<FX@;G5L;#L-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)$=,3T)!3%-;)U]014%27T-O
M;6UA;F1?8V]M;6%N9&1E<V,G75LD8V]M;6%N9%T[#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H@("`@+R\@>WM[(&=E=$AE;'`H*0T*#0H@("`@+RHJ#0H@("`@
M("H@1V5T(&AE;'`@9F]R(&-O;6UA;F0N#0H@("`@("H-"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1C;VUM86YD($YA;64@;V8@=&AE(&-O;6UA;F0@=&\@<F5T
M=7)N(&AE;'`@9F]R#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*
M("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971(96QP
M*"1C;VUM86YD*0T*("`@('L-"B`@("`@("`@)&-M9',@/2!014%27T-O;6UA
M;F0Z.F=E=$-O;6UA;F1S*"D[#0H@("`@("`@(&EF("AI<W-E="@D1TQ/0D%,
M4ULG7U!%05)?0V]M;6%N9%]S:&]R=&-U=',G75LD8V]M;6%N9%TI*2![#0H@
M("`@("`@("`@("`D8V]M;6%N9"`]("1'3$]"04Q36R=?4$5!4E]#;VUM86YD
M7W-H;W)T8W5T<R==6R1C;VUM86YD73L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H:7-S970H)&-M9'-;)&-O;6UA;F1=*2D@>PT*("`@("`@("`@("`@)&]B
M:B`]("9014%27T-O;6UA;F0Z.F=E=$]B:F5C="@D8V]M;6%N9"D[#0H@("`@
M("`@("`@("!R971U<FX@)&]B:BT^9V5T2&5L<"@D8V]M;6%N9"D[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"B`@("`O+R!]
M?7T-"GT-"@T*/SX-"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O4$5!4B]#;VUM;VXN<&AP````````````````````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,#<W,S0`,3`U,34T,S,W-#$`,#(Q,S`V
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP#0HO*BH-"B`J(%!%05)?0V]M;6]N+"!T:&4@8F%S92!C;&%S<R!F;W(@
M=&AE(%!%05(@26YS=&%L;&5R#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD
M(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE
M8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T
M(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T
M:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O
M9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I
M;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@
M=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@
M:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A
M8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S
M8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@5&]M87,@5BX@5BX@0V]X(#QC
M;WA`:61E8VYE="YC;VT^#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\
M8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE
M(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO
M;B`@("!#5E,Z("1)9#H@0V]M;6]N+G!H<"QV(#$N,34U(#(P,#8O,#,O,#(@
M,3@Z,30Z,3(@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL
M92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$N,`T*("H@0&1E<')E8V%T
M960@1FEL92!D97!R96-A=&5D('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO
M#0H-"B\J*@T*("H@26YC;'5D92!E<G)O<B!H86YD;&EN9PT*("HO#0IR97%U
M:7)E7V]N8V4@)U!%05(N<&AP)SL-"@T*+R\@>WM[(&-O;G-T86YT<R!A;F0@
M9VQO8F%L<PT*#0HO*BH-"B`J(%!%05)?0V]M;6]N(&5R<F]R('=H96X@86X@
M:6YV86QI9"!02%`@9FEL92!I<R!P87-S960@=&\@4$5!4E]#;VUM;VXZ.F%N
M86QY>F53;W5R8V5#;V1E*"D-"B`J+PT*9&5F:6YE*"=014%27T-/34U/3E]%
M4E)/4E])3E9!3$E$4$A0)RP@,2D[#0ID969I;F4H)U]014%27T-/34U/3E]0
M04-+04=%7TY!345?4%)%1R<L("=;02U:82UZ75MA+7I!+5HP+3E?72LG*3L-
M"F1E9FEN92@G4$5!4E]#3TU-3TY?4$%#2T%'15].04U%7U!214<G+"`G+UXG
M("X@7U!%05)?0T]-34].7U!!0TM!1T5?3D%-15]04D5'("X@)R0O)RD[#0H-
M"B\O('1H:7,@<VAO=6QD(&%L;&]W.B`Q+"`Q+C`L(#$N,%)#,2P@,2XP9&5V
M+"`Q+C!D978Q,C,R,S0R,S0R,S0L(#$N,&$Q+"`Q+C!B,2P@,2XP<&PQ#0ID
M969I;F4H)U]014%27T-/34U/3E]004-+04=%7U9%4E-)3TY?4%)%1R<L("=<
M9"LH/SI<+EQD*RDJ*#\Z6V$M>D$M6ETK7&0J*3\G*3L-"F1E9FEN92@G4$5!
M4E]#3TU-3TY?4$%#2T%'15]615)324].7U!214<G+"`G+UXG("X@7U!%05)?
M0T]-34].7U!!0TM!1T5?5D524TE/3E]04D5'("X@)R0O:2<I.PT*#0HO+R!8
M6%@@9F%R(&9R;VT@<&5R9F5C="`Z+2D-"F1E9FEN92@G7U!%05)?0T]-34].
M7U!!0TM!1T5?1$]73DQ/041?4%)%1R<L("<H)R`N(%]014%27T-/34U/3E]0
M04-+04=%7TY!345?4%)%1R`N#0H@("`@)RDH+2A;+C`M.6$M>D$M6ETK*2D_
M)RD[#0ID969I;F4H)U!%05)?0T]-34].7U!!0TM!1T5?1$]73DQ/041?4%)%
M1R<L("<O7B<@+B!?4$5!4E]#3TU-3TY?4$%#2T%'15]$3U=.3$]!1%]04D5'
M("X-"B`@("`G)"\G*3L-"@T*9&5F:6YE*"=?4$5!4E]#2$%.3D5,4U].04U%
M7U!214<G+"`G6T$M6F$M>EU;82UZ02U:,"TY7"Y=*R<I.PT*9&5F:6YE*"=0
M14%27T-(04Y.14Q37TY!345?4%)%1R<L("<O7B<@+B!?4$5!4E]#2$%.3D5,
M4U].04U%7U!214<@+B`G)"\G*3L-"@T*+R\@=&AI<R!S:&]U;&0@86QL;W<@
M86YY(&1N<R!O<B!)4"!A9&1R97-S+"!P;'5S(&$@<&%T:"`M($Y/(%5.1$52
M4T-/4D53($%,3$]7140-"F1E9FEN92@G7U!%05)?0TA!3DY%3%-?4T525D52
M7U!214<G+"`G6V$M>D$M6C`M.5PM72LH/SI<+EMA+7I!+5HP+3E<+5TK*2HH
M7"];82UZ02U:,"TY7"U=*RDJ)RD[#0ID969I;F4H)U!%05)?0TA!3DY%3%-?
M4T525D527U!214<G+"`G+UXG("X@7U!%05)?0TA!3DY%3%-?4T525D527U!2
M14<@+B`G)"]I)RD[#0H-"F1E9FEN92@G7U!%05)?0TA!3DY%3%-?4$%#2T%'
M15]04D5')RP@("<H)R`N7U!%05)?0TA!3DY%3%-?4T525D527U!214<@+B`G
M*5PO*"<-"B`@("`@("`@("X@7U!%05)?0T]-34].7U!!0TM!1T5?3D%-15]0
M4D5'("X@)RDG*3L-"F1E9FEN92@G4$5!4E]#2$%.3D5,4U]004-+04=%7U!2
M14<G+"`G+UXG("X@7U!%05)?0TA!3DY%3%-?4$%#2T%'15]04D5'("X@)R0O
M:2<I.PT*#0ID969I;F4H)U]014%27T-/34U/3E]#2$%.3D5,7T1/5TY,3T%$
M7U!214<G+"`G*"<@+B!?4$5!4E]#2$%.3D5,4U].04U%7U!214<@+B`G*3HZ
M*"<-"B`@("`N(%]014%27T-/34U/3E]004-+04=%7TY!345?4%)%1R`N("<I
M*"TH6RXP+3EA+7I!+5I=*RDI/R<I.PT*9&5F:6YE*"=014%27T-/34U/3E]#
M2$%.3D5,7T1/5TY,3T%$7U!214<G+"`G+UXG("X@7U!%05)?0T]-34].7T-(
M04Y.14Q?1$]73DQ/041?4%)%1R`N("<D+R<I.PT*#0HO*BH-"B`J($QI<W0@
M;V8@=&5M<&]R87)Y(&9I;&5S(&%N9"!D:7)E8W1O<FEE<R!R96=I<W1E<F5D
M(&)Y#0H@*B!014%27T-O;6UO;CHZ861D5&5M<$9I;&4H*2X-"B`J($!V87(@
M87)R87D-"B`J+PT*)$=,3T)!3%-;)U]014%27T-O;6UO;E]T96UP9FEL97,G
M72`](&%R<F%Y*"D[#0H-"B\J*@T*("H@5F%L:60@;6%I;G1A:6YE<B!R;VQE
M<PT*("H@0'9A<B!A<G)A>0T*("HO#0HD1TQ/0D%,4ULG7U!%05)?0V]M;6]N
M7VUA:6YT86EN97)?<F]L97,G72`](&%R<F%Y*"=L96%D)RPG9&5V96QO<&5R
M)RPG8V]N=')I8G5T;W(G+"=H96QP97(G*3L-"@T*+RHJ#0H@*B!686QI9"!R
M96QE87-E('-T871E<PT*("H@0'9A<B!A<G)A>0T*("HO#0HD1TQ/0D%,4ULG
M7U!%05)?0V]M;6]N7W)E;&5A<V5?<W1A=&5S)UT@/2!A<G)A>2@G86QP:&$G
M+"=B971A)RPG<W1A8FQE)RPG<VYA<'-H;W0G+"=D979E;"<I.PT*#0HO*BH-
M"B`J(%9A;&ED(&1E<&5N9&5N8WD@='EP97,-"B`J($!V87(@87)R87D-"B`J
M+PT*)$=,3T)!3%-;)U]014%27T-O;6UO;E]D97!E;F1E;F-Y7W1Y<&5S)UT@
M/2!A<G)A>2@G<&MG)RPG97AT)RPG<&AP)RPG<')O9R<L)VQD;&EB)RPG<G1L
M:6(G+"=O<R<L)W=E8G-R=B<L)W-A<&DG*3L-"@T*+RHJ#0H@*B!686QI9"!D
M97!E;F1E;F-Y(')E;&%T:6]N<PT*("H@0'9A<B!A<G)A>0T*("HO#0HD1TQ/
M0D%,4ULG7U!%05)?0V]M;6]N7V1E<&5N9&5N8WE?<F5L871I;VYS)UT@/2!A
M<G)A>2@G:&%S)RPG97$G+"=L="<L)VQE)RPG9W0G+"=G92<L)VYO="<L("=N
M92<I.PT*#0HO*BH-"B`J(%9A;&ED(&9I;&4@<F]L97,-"B`J($!V87(@87)R
M87D-"B`J+PT*)$=,3T)!3%-;)U]014%27T-O;6UO;E]F:6QE7W)O;&5S)UT@
M/2!A<G)A>2@G<&AP)RPG97AT)RPG=&5S="<L)V1O8R<L)V1A=&$G+"=S<F,G
M+"=S8W)I<'0G*3L-"@T*+RHJ#0H@*B!686QI9"!R97!L86-E;65N="!T>7!E
M<PT*("H@0'9A<B!A<G)A>0T*("HO#0HD1TQ/0D%,4ULG7U!%05)?0V]M;6]N
M7W)E<&QA8V5M96YT7W1Y<&5S)UT@/2!A<G)A>2@G<&AP+6-O;G-T)RP@)W!E
M87(M8V]N9FEG)RP@)W!A8VMA9V4M:6YF;R<I.PT*#0HO*BH-"B`J(%9A;&ED
M(")P<F]V:61E(B!T>7!E<PT*("H@0'9A<B!A<G)A>0T*("HO#0HD1TQ/0D%,
M4ULG7U!%05)?0V]M;6]N7W!R;W9I9&5?='EP97,G72`](&%R<F%Y*"=E>'0G
M+"`G<')O9R<L("=C;&%S<R<L("=F=6YC=&EO;B<L("=F96%T=7)E)RP@)V%P
M:2<I.PT*#0HO*BH-"B`J(%9A;&ED(")P<F]V:61E(B!T>7!E<PT*("H@0'9A
M<B!A<G)A>0T*("HO#0HD1TQ/0D%,4ULG7U!%05)?0V]M;6]N7W-C<FEP=%]P
M:&%S97,G72`](&%R<F%Y*"=P<F4M:6YS=&%L;"<L("=P;W-T+6EN<W1A;&PG
M+"`G<')E+75N:6YS=&%L;"<L("=P;W-T+75N:6YS=&%L;"<L("=P<F4M8G5I
M;&0G+"`G<&]S="UB=6EL9"<L("=P<F4M8V]N9FEG=7)E)RP@)W!O<W0M8V]N
M9FEG=7)E)RP@)W!R92US971U<"<L("=P;W-T+7-E='5P)RD[#0H-"B\O('U]
M?0T*#0HO*BH-"B`J($-L87-S('!R;W9I9&EN9R!C;VUM;VX@9G5N8W1I;VYA
M;&ET>2!F;W(@4$5!4B!A9&UI;FES=')A=&EO;B!C;&%S<V5S+@T*("H@0&-A
M=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO
M<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@
M("`@5&]M87,@5BX@5BX@0V]X(#QC;WA`:61E8VYE="YC;VT^#0H@*B!`875T
M:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P
M>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@
M("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI
M8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@
M0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-
M"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E
M(#$N-"XP83$-"B`J($!D97!R96-A=&5D(%1H:7,@8VQA<W,@=VEL;"!D:7-A
M<'!E87(L(&%N9"!I=',@8V]M<&]N96YT<R!W:6QL(&)E('-P<F5A9`T*("H@
M("`@("`@("`@("`@:6YT;R!S;6%L;&5R(&-L87-S97,L(&QI:V4@=&AE($%4
M)E0@8G)E86MU<"P@87,@;V8@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S
M(%!%05)?0V]M;6]N(&5X=&5N9',@4$5!4@T*>PT*("`@("\O('M[>R!P<F]P
M97)T:65S#0H-"B`@("`O*BH@<W1A8VL@;V8@96QE;65N=',L(&=I=F5S('-O
M;64@<V]R="!O9B!834P@8V]N=&5X="`J+PT*("`@('9A<B`D96QE;65N=%]S
M=&%C:R`](&%R<F%Y*"D[#0H-"B`@("`O*BH@;F%M92!O9B!C=7)R96YT;'D@
M<&%R<V5D(%A-3"!E;&5M96YT("HO#0H@("`@=F%R("1C=7)R96YT7V5L96UE
M;G0[#0H-"B`@("`O*BH@87)R87D@;V8@871T<FEB=71E<R!O9B!T:&4@8W5R
M<F5N=&QY('!A<G-E9"!834P@96QE;65N="`J+PT*("`@('9A<B`D8W5R<F5N
M=%]A='1R:6)U=&5S(#T@87)R87DH*3L-"@T*("`@("\J*B!A<W-O8R!W:71H
M(&EN9F]R;6%T:6]N(&%B;W5T(&$@<&%C:V%G92`J+PT*("`@('9A<B`D<&MG
M:6YF;R`](&%R<F%Y*"D[#0H-"B`@("`O*BH-"B`@("`@*B!5<V5R($EN=&5R
M9F%C92!O8FIE8W0@*%!%05)?1G)O;G1E;F1?*B!C;&%S<RDN("!)9B!N=6QL
M+`T*("`@("`J('1H92!L;V<H*2!M971H;V0@=7-E<R!P<FEN="X-"B`@("`@
M*B!`=F%R(&]B:F5C=`T*("`@("`J+PT*("`@('9A<B`D=6D@/2!N=6QL.PT*
M#0H@("`@+RHJ#0H@("`@("H@0V]N9FEG=7)A=&EO;B!O8FIE8W0@*%!%05)?
M0V]N9FEG*2X-"B`@("`@*B!`=F%R(&]B:F5C=`T*("`@("`J+PT*("`@('9A
M<B`D8V]N9FEG(#T@;G5L;#L-"@T*("`@('9A<B`D8W5R<F5N=%]P871H(#T@
M;G5L;#L-"@T*("`@("\J*@T*("`@("`J(%!%05)?4V]U<F-E06YA;'EZ97(@
M:6YS=&%N8V4-"B`@("`@*B!`=F%R(&]B:F5C=`T*("`@("`J+PT*("`@('9A
M<B`D<V]U<F-E7V%N86QY>F5R(#T@;G5L;#L-"B`@("`O*BH-"B`@("`@*B!&
M;&%G('9A<FEA8FQE('5S960@=&\@;6%R:R!A('9A;&ED('!A8VMA9V4@9FEL
M90T*("`@("`J($!V87(@8F]O;&5A;@T*("`@("`J($!A8V-E<W,@<')I=F%T
M90T*("`@("`J+PT*("`@('9A<B`D7W9A;&ED4&%C:V%G949I;&4[#0H-"B`@
M("`O+R!]?7T-"@T*("`@("\O('M[>R!C;VYS=')U8W1O<@T*#0H@("`@+RHJ
M#0H@("`@("H@4$5!4E]#;VUM;VX@8V]N<W1R=6-T;W(-"B`@("`@*@T*("`@
M("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@4$5!
M4E]#;VUM;VXH*0T*("`@('L-"B`@("`@("`@<&%R96YT.CI014%2*"D[#0H@
M("`@("`@("1T:&ES+3YC;VYF:6<@/2`F4$5!4E]#;VYF:6<Z.G-I;F=L971O
M;B@I.PT*("`@("`@("`D=&AI<RT^9&5B=6<@/2`D=&AI<RT^8V]N9FEG+3YG
M970H)W9E<F)O<V4G*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@9&5S=')U8W1O<@T*#0H@("`@+RHJ#0H@("`@("H@4$5!4E]#;VUM;VX@
M9&5S=')U8W1O<@T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@7U!%05)?0V]M;6]N*"D-"B`@("![#0H@
M("`@("`@("\O(&1O97-N)W0@=V]R:R!D=64@=&\@8G5G(",Q-#<T-`T*("`@
M("`@("`O+R1T96UP9FEL97,@/2`D=&AI<RT^7W1E;7!F:6QE<SL-"B`@("`@
M("`@)'1E;7!F:6QE<R`])B`D1TQ/0D%,4ULG7U!%05)?0V]M;6]N7W1E;7!F
M:6QE<R==.PT*("`@("`@("!W:&EL92`H)&9I;&4@/2!A<G)A>5]S:&EF="@D
M=&5M<&9I;&5S*2D@>PT*("`@("`@("`@("`@:68@*$!I<U]D:7(H)&9I;&4I
M*2![#0H@("`@("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U-Y<W1E
M;2<I*2![#0H@("`@("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4WES
M=&5M+G!H<"<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(%-Y<W1E;3HZ<FTH87)R87DH)RUR9B<L("1F:6QE*2D[#0H@("`@("`@("`@
M("!](&5L<V5I9B`H9FEL95]E>&ES=',H)&9I;&4I*2![#0H@("`@("`@("`@
M("`@("`@=6YL:6YK*"1F:6QE*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!A9&1496UP1FEL
M92@I#0H-"B`@("`O*BH-"B`@("`@*B!296=I<W1E<B!A('1E;7!O<F%R>2!F
M:6QE(&]R(&1I<F5C=&]R>2X@(%=H96X@=&AE(&1E<W1R=6-T;W(@:7,-"B`@
M("`@*B!E>&5C=71E9"P@86QL(')E9VES=&5R960@=&5M<&]R87)Y(&9I;&5S
M(&%N9"!D:7)E8W1O<FEE<R!A<F4-"B`@("`@*B!R96UO=F5D+@T*("`@("`J
M#0H@("`@("H@0'!A<F%M('-T<FEN9R`@)&9I;&4@(&YA;64@;V8@9FEL92!O
M<B!D:7)E8W1O<GD-"B`@("`@*@T*("`@("`J($!R971U<FX@=F]I9`T*("`@
M("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!A9&1496UP1FEL92@D9FEL92D-"B`@("![#0H@("`@("`@(&EF("@A
M8VQA<W-?97AI<W1S*"=014%27T9R;VYT96YD)RDI('L-"B`@("`@("`@("`@
M(')E<75I<F5?;VYC92`G4$5!4B]&<F]N=&5N9"YP:'`G.PT*("`@("`@("!]
M#0H@("`@("`@(%!%05)?1G)O;G1E;F0Z.F%D9%1E;7!&:6QE*"1F:6QE*3L-
M"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@;6M$:7)(:65R*"D-
M"@T*("`@("\J*@T*("`@("`J(%=R87!P97(@=&\@4WES=&5M.CIM:T1I<B@I
M+"!C<F5A=&5S(&$@9&ER96-T;W)Y(&%S('=E;&P@87,-"B`@("`@*B!A;GD@
M;F5C97-S87)Y('!A<F5N="!D:7)E8W1O<FEE<RX-"B`@("`@*@T*("`@("`J
M($!P87)A;2!S=')I;F<@("1D:7(@(&1I<F5C=&]R>2!N86UE#0H@("`@("H-
M"B`@("`@*B!`<F5T=7)N(&)O;VP@5%)512!O;B!S=6-C97-S+"!O<B!A(%!%
M05(@97)R;W(-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@;6M$:7)(:65R*"1D:7(I#0H@("`@>PT*("`@
M("`@("`D=&AI<RT^;&]G*#(L("(K(&-R96%T92!D:7(@)&1I<B(I.PT*("`@
M("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4WES=&5M)RDI('L-"B`@("`@("`@
M("`@(')E<75I<F5?;VYC92`G4WES=&5M+G!H<"<[#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N(%-Y<W1E;3HZ;6M$:7(H87)R87DH)RUP)RP@)&1I<BDI
M.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!L;V<H*0T*#0H@
M("`@+RHJ#0H@("`@("H@3&]G9VEN9R!M971H;V0N#0H@("`@("H-"B`@("`@
M*B!`<&%R86T@:6YT("`@("1L979E;"`@;&]G(&QE=F5L("@P(&ES('%U:65T
M+"!H:6=H97(@:7,@;F]I<VEE<BD-"B`@("`@*B!`<&%R86T@<W1R:6YG("1M
M<V<@("`@;65S<V%G92!T;R!W<FET92!T;R!T:&4@;&]G#0H@("`@("H-"B`@
M("`@*B!`<F5T=7)N('9O:60-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B
M;&EC#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&QO
M9R@D;&5V96PL("1M<V<L("1A<'!E;F1?8W)L9B`]('1R=64I#0H@("`@>PT*
M("`@("`@("!I9B`H)'1H:7,M/F1E8G5G(#X]("1L979E;"D@>PT*("`@("`@
M("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?1G)O;G1E;F0G*2D@>PT*
M("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]&<F]N=&5N9"YP
M:'`G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'5I(#T@)E!%05)?
M1G)O;G1E;F0Z.G-I;F=L971O;B@I.PT*("`@("`@("`@("`@:68@*&ES7V$H
M)'5I+"`G4$5!4E]&<F]N=&5N9"<I*2![#0H@("`@("`@("`@("`@("`@)'5I
M+3YL;V<H)&US9RP@)&%P<&5N9%]C<FQF*3L-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@<')I;G0@(B1M<V=<;B([#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O
M+R![>WL@;6M496UP1&ER*"D-"@T*("`@("\J*@T*("`@("`J($-R96%T92!A
M;F0@<F5G:7-T97(@82!T96UP;W)A<GD@9&ER96-T;W)Y+@T*("`@("`J#0H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=&UP9&ER("AO<'1I;VYA;"D@1&ER96-T
M;W)Y('1O('5S92!A<R!T;7!D:7(N#0H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@(%=I;&P@=7-E('-Y<W1E;2!D969A=6QT<R`H9F]R(&5X86UP;&4-
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@+W1M<"!O<B!C.EQW:6YD
M;W=S7'1E;7`I(&EF(&YO="!S<&5C:69I960-"B`@("`@*@T*("`@("`J($!R
M971U<FX@<W1R:6YG(&YA;64@;V8@8W)E871E9"!D:7)E8W1O<GD-"B`@("`@
M*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@;6M496UP1&ER*"1T;7!D:7(@/2`G)RD-"B`@("![#0H@("`@("`@(&EF
M("@D=&UP9&ER*2![#0H@("`@("`@("`@("`D=&]P="`](&%R<F%Y*"<M="<L
M("1T;7!D:7(I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1O
M<'0@/2!A<G)A>2@I.PT*("`@("`@("!]#0H@("`@("`@("1T;W!T(#T@87)R
M87E?;65R9V4H)'1O<'0L(&%R<F%Y*"<M9"<L("=P96%R)RDI.PT*("`@("`@
M("!I9B`H(6-L87-S7V5X:7-T<R@G4WES=&5M)RDI('L-"B`@("`@("`@("`@
M(')E<75I<F5?;VYC92`G4WES=&5M+G!H<"<[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"$D=&UP9&ER(#T@4WES=&5M.CIM:W1E;7`H)'1O<'0I*2![#0H@
M("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@
M)'1H:7,M/F%D9%1E;7!&:6QE*"1T;7!D:7(I.PT*("`@("`@("!R971U<FX@
M)'1M<&1I<CL-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@<V5T
M1G)O;G1E;F1/8FIE8W0H*0T*#0H@("`@+RHJ#0H@("`@("H@4V5T(&]B:F5C
M="!T:&%T(')E<')E<V5N=',@=&AE(&9R;VYT96YD('1O(&)E('5S960N#0H@
M("`@("H-"B`@("`@*B!`<&%R86T@(&]B:F5C="!2969E<F5N8V4@;V8@=&AE
M(&9R;VYT96YD(&]B:F5C=`T*("`@("`J($!R971U<FX@=F]I9`T*("`@("`J
M($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T1G)O
M;G1E;F1/8FIE8W0H)B1U:2D-"B`@("![#0H@("`@("`@("1T:&ES+3YU:2`]
M("8D=6D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@:6YF
M;T9R;VU49WI&:6QE*"D-"@T*("`@("\J*@T*("`@("`J(%)E='5R;G,@:6YF
M;W)M871I;VX@86)O=70@82!P86-K86=E(&9I;&4N("!%>'!E8W1S('1H92!N
M86UE(&]F#0H@("`@("H@82!G>FEP<&5D('1A<B!F:6QE(&%S(&EN<'5T+@T*
M("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`@)&9I;&4@(&YA;64@;V8@
M+G1G>B!F:6QE#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!A<G)A
M>2!W:71H('!A8VMA9V4@:6YF;W)M871I;VX-"B`@("`@*@T*("`@("`J($!A
M8V-E<W,@<'5B;&EC#0H@("`@("H@0&1E<')E8V%T960@=7-E(%!%05)?4&%C
M:V%G949I;&4M/F9R;VU49WI&:6QE*"D@:6YS=&5A9`T*("`@("`J#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@:6YF;T9R;VU49WI&:6QE*"1F:6QE*0T*("`@
M('L-"B`@("`@("`@)'!A8VMA9V5F:6QE(#T@)FYE=R!014%27U!A8VMA9V5&
M:6QE*"1T:&ES+3YC;VYF:6<I.PT*("`@("`@("`D<&8@/2`F)'!A8VMA9V5F
M:6QE+3YF<F]M5&=Z1FEL92@D9FEL92P@4$5!4E]604Q)1$%415].3U)-04PI
M.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&8I*2![#0H@("`@("`@
M("`@("`D97)R<R`]("1P9BT^9V5T57-E<FEN9F\H*3L-"B`@("`@("`@("`@
M(&EF("AI<U]A<G)A>2@D97)R<RDI('L-"B`@("`@("`@("`@("`@("!F;W)E
M86-H("@D97)R<R!A<R`D97)R;W(I('L-"B`@("`@("`@("`@("`@("`@("`@
M)&4@/2`D=&AI<RT^<F%I<V5%<G)O<B@D97)R;W);)VUE<W-A9V4G72P@)&5R
M<F]R6R=C;V1E)UTL(&YU;&PL(&YU;&PL("1E<G)O<BD[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N("1P
M9CL-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/E]P;W-T4')O
M8V5S<U9A;&ED4&%C:V%G97AM;"@D<&8I.PT*("`@('T-"@T*("`@("\O('U]
M?0T*("`@("\O('M[>R!I;F9O1G)O;41E<V-R:7!T:6]N1FEL92@I#0H-"B`@
M("`O*BH-"B`@("`@*B!2971U<FYS(&EN9F]R;6%T:6]N(&%B;W5T(&$@<&%C
M:V%G92!F:6QE+B`@17AP96-T<R!T:&4@;F%M92!O9@T*("`@("`J(&$@<&%C
M:V%G92!X;6P@9FEL92!A<R!I;G!U="X-"B`@("`@*@T*("`@("`J($!P87)A
M;2!S=')I;F<@("1D97-C9FEL92`@;F%M92!O9B!P86-K86=E('AM;"!F:6QE
M#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!A<G)A>2!W:71H('!A
M8VMA9V4@:6YF;W)M871I;VX-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B
M;&EC#0H@("`@("H@0&1E<')E8V%T960@=7-E(%!%05)?4&%C:V%G949I;&4M
M/F9R;VU086-K86=E1FEL92@I(&EN<W1E860-"B`@("`@*@T*("`@("`J+PT*
M("`@(&9U;F-T:6]N(&EN9F]&<F]M1&5S8W)I<'1I;VY&:6QE*"1D97-C9FEL
M92D-"B`@("![#0H@("`@("`@("1P86-K86=E9FEL92`]("9N97<@4$5!4E]0
M86-K86=E1FEL92@D=&AI<RT^8V]N9FEG*3L-"B`@("`@("`@)'!F(#T@)B1P
M86-K86=E9FEL92T^9G)O;5!A8VMA9V5&:6QE*"1D97-C9FEL92P@4$5!4E]6
M04Q)1$%415].3U)-04PI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M<&8I*2![#0H@("`@("`@("`@("`D97)R<R`]("1P9BT^9V5T57-E<FEN9F\H
M*3L-"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D97)R<RDI('L-"B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D97)R<R!A<R`D97)R;W(I('L-"B`@("`@
M("`@("`@("`@("`@("`@)&4@/2`D=&AI<RT^<F%I<V5%<G)O<B@D97)R;W);
M)VUE<W-A9V4G72P@)&5R<F]R6R=C;V1E)UTL(&YU;&PL(&YU;&PL("1E<G)O
M<BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@<F5T=7)N("1P9CL-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M)'1H:7,M/E]P;W-T4')O8V5S<U9A;&ED4&%C:V%G97AM;"@D<&8I.PT*("`@
M('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!I;F9O1G)O;5-T<FEN9R@I
M#0H-"B`@("`O*BH-"B`@("`@*B!2971U<FYS(&EN9F]R;6%T:6]N(&%B;W5T
M(&$@<&%C:V%G92!F:6QE+B`@17AP96-T<R!T:&4@8V]N=&5N=',-"B`@("`@
M*B!O9B!A('!A8VMA9V4@>&UL(&9I;&4@87,@:6YP=70N#0H@("`@("H-"B`@
M("`@*B!`<&%R86T@<W1R:6YG("`D9&%T82`@8V]N=&5N=',@;V8@<&%C:V%G
M92YX;6P@9FEL90T*("`@("`J#0H@("`@("H@0')E='5R;B!A<G)A>2`@(&%R
M<F%Y('=I=&@@<&%C:V%G92!I;F9O<FUA=&EO;@T*("`@("`J#0H@("`@("H@
M0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`9&5P<F5C871E9"!U<V4@4$5!4E]0
M86-K86=E1FEL92T^9G)O;5AM;'-T<FEN9R@I(&EN<W1E860-"B`@("`@*@T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(&EN9F]&<F]M4W1R:6YG*"1D871A*0T*
M("`@('L-"B`@("`@("`@)'!A8VMA9V5F:6QE(#T@)FYE=R!014%27U!A8VMA
M9V5&:6QE*"1T:&ES+3YC;VYF:6<I.PT*("`@("`@("`D<&8@/2`F)'!A8VMA
M9V5F:6QE+3YF<F]M6&UL4W1R:6YG*"1D871A+"!014%27U9!3$E$051%7TY/
M4DU!3"P@9F%L<V4I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&8I
M*2![#0H@("`@("`@("`@("`D97)R<R`]("1P9BT^9V5T57-E<FEN9F\H*3L-
M"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D97)R<RDI('L-"B`@("`@("`@
M("`@("`@("!F;W)E86-H("@D97)R<R!A<R`D97)R;W(I('L-"B`@("`@("`@
M("`@("`@("`@("`@)&4@/2`D=&AI<RT^<F%I<V5%<G)O<B@D97)R;W);)VUE
M<W-A9V4G72P@)&5R<F]R6R=C;V1E)UTL(&YU;&PL(&YU;&PL("1E<G)O<BD[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@<F5T=7)N("1P9CL-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1H
M:7,M/E]P;W-T4')O8V5S<U9A;&ED4&%C:V%G97AM;"@D<&8I.PT*("`@('T-
M"B`@("`O+R!]?7T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!014%27U!A
M8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7W!O<W10<F]C97-S
M5F%L:61086-K86=E>&UL*"8D<&8I#0H@("`@>PT*("`@("`@("!I9B`H:7-?
M82@D<&8L("=014%27U!A8VMA9V5&:6QE7W8R)RDI('L-"B`@("`@("`@("`@
M("\O('-O<G0@;V8@;6%K92!T:&ES(&EN=&\@82!P86-K86=E+GAM;"`Q+C`M
M<W1Y;&4@87)R87D-"B`@("`@("`@("`@("\O(&-H86YG96QO9R!I<R!N;W0@
M8V]N=F5R=&5D('1O(&]L9"!F;W)M870N#0H@("`@("`@("`@("`D87)R(#T@
M)'!F+3YT;T%R<F%Y*'1R=64I.PT*("`@("`@("`@("`@)&%R<B`](&%R<F%Y
M7VUE<F=E*"1A<G(L("1A<G);)V]L9"==*3L-"B`@("`@("`@("`@('5N<V5T
M*"1A<G);)V]L9"==*3L-"B`@("`@("`@("`@('5N<V5T*"1A<G);)WAS9'9E
M<G-I;VXG72D[#0H@("`@("`@("`@("!U;G-E="@D87)R6R=C;VYT96YT<R==
M*3L-"B`@("`@("`@("`@('5N<V5T*"1A<G);)V-O;7!A=&EB;&4G72D[#0H@
M("`@("`@("`@("!U;G-E="@D87)R6R=C:&%N;F5L)UTI.PT*("`@("`@("`@
M("`@=6YS970H)&%R<ELG=7)I)UTI.PT*("`@("`@("`@("`@=6YS970H)&%R
M<ELG9&5P96YD96YC:65S)UTI.PT*("`@("`@("`@("`@=6YS970H)&%R<ELG
M<&AP<F5L96%S92==*3L-"B`@("`@("`@("`@('5N<V5T*"1A<G);)V5X='-R
M8W)E;&5A<V4G72D[#0H@("`@("`@("`@("!U;G-E="@D87)R6R=E>'1B:6YR
M96QE87-E)UTI.PT*("`@("`@("`@("`@=6YS970H)&%R<ELG8G5N9&QE)UTI
M.PT*("`@("`@("`@("`@=6YS970H)&%R<ELG;&5A9"==*3L-"B`@("`@("`@
M("`@('5N<V5T*"1A<G);)V1E=F5L;W!E<B==*3L-"B`@("`@("`@("`@('5N
M<V5T*"1A<G);)VAE;'!E<B==*3L-"B`@("`@("`@("`@('5N<V5T*"1A<G);
M)V-O;G1R:6)U=&]R)UTI.PT*("`@("`@("`@("`@)&%R<ELG9FEL96QI<W0G
M72`]("1P9BT^9V5T1FEL96QI<W0H*3L-"B`@("`@("`@("`@("1T:&ES+3YP
M:V=I;F9O(#T@)&%R<CL-"B`@("`@("`@("`@(')E='5R;B`D87)R.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M/G!K9VEN9F\@/2`D
M<&8M/G1O07)R87DH*3L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<&MG
M:6YF;SL-"B`@("`@("`@?0T*("`@('T-"B`@("`O+R![>WL@:6YF;T9R;VU!
M;GDH*0T*#0H@("`@+RHJ#0H@("`@("H@4F5T=7)N<R!P86-K86=E(&EN9F]R
M;6%T:6]N(&9R;VT@9&EF9F5R96YT('-O=7)C97,-"B`@("`@*@T*("`@("`J
M(%1H:7,@;65T:&]D(&ES(&%B;&4@=&\@97AT<F%C="!I;F9O<FUA=&EO;B!A
M8F]U="!A('!A8VMA9V4-"B`@("`@*B!F<F]M(&$@+G1G>B!A<F-H:79E(&]R
M(&9R;VT@82!834P@<&%C:V%G92!D969I;FET:6]N(&9I;&4N#0H@("`@("H-
M"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!P87)A;2`@<W1R:6YG
M($9I;&5N86UE(&]F('1H92!S;W5R8V4@*"=P86-K86=E+GAM;"<L("<\<&%C
M:V%G93XN=&=Z)RD-"B`@("`@*B!`<F5T=7)N('-T<FEN9PT*("`@("`J($!D
M97!R96-A=&5D('5S92!014%27U!A8VMA9V5&:6QE+3YF<F]M06YY1FEL92@I
M(&EN<W1E860-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I;F9O1G)O;4%N>2@D
M:6YF;RD-"B`@("![#0H@("`@("`@(&EF("AI<U]S=')I;F<H)&EN9F\I("8F
M(&9I;&5?97AI<W1S*"1I;F9O*2D@>PT*("`@("`@("`@("`@)'!A8VMA9V5F
M:6QE(#T@)FYE=R!014%27U!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<I.PT*
M("`@("`@("`@("`@)'!F(#T@)B1P86-K86=E9FEL92T^9G)O;4%N>49I;&4H
M)&EN9F\L(%!%05)?5D%,241!5$5?3D]234%,*3L-"B`@("`@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1P9BDI('L-"B`@("`@("`@("`@("`@("`D97)R
M<R`]("1P9BT^9V5T57-E<FEN9F\H*3L-"B`@("`@("`@("`@("`@("!I9B`H
M:7-?87)R87DH)&5R<G,I*2![#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1E<G)S(&%S("1E<G)O<BD@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)&4@/2`D=&AI<RT^<F%I<V5%<G)O<B@D97)R;W);)VUE<W-A9V4G72P@
M)&5R<F]R6R=C;V1E)UTL(&YU;&PL(&YU;&PL("1E<G)O<BD[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@<F5T=7)N("1P9CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7W!O<W10<F]C97-S5F%L:61086-K86=E>&UL*"1P
M9BD[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1I;F9O.PT*("`@('T-
M"@T*("`@("\O('U]?0T*("`@("\O('M[>R!X;6Q&<F]M26YF;R@I#0H-"B`@
M("`O*BH-"B`@("`@*B!2971U<FX@86X@6$U,(&1O8W5M96YT(&)A<V5D(&]N
M('1H92!P86-K86=E(&EN9F\@*&%S(')E='5R;F5D#0H@("`@("H@8GD@=&AE
M(%!%05)?0V]M;6]N.CII;F9O1G)O;2H@;65T:&]D<RDN#0H@("`@("H-"B`@
M("`@*B!`<&%R86T@87)R87D@("1P:V=I;F9O("!P86-K86=E(&EN9F\-"B`@
M("`@*@T*("`@("`J($!R971U<FX@<W1R:6YG(%A-3"!D871A#0H@("`@("H-
M"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!D97!R96-A=&5D('5S
M92!A(%!%05)?4&%C:V%G949I;&5?=BH@;V)J96-T)W,@9V5N97)A=&]R(&EN
M<W1E860-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!X;6Q&<F]M26YF;R@D<&MG
M:6YF;RD-"B`@("![#0H@("`@("`@("1C;VYF:6<@/2`F4$5!4E]#;VYF:6<Z
M.G-I;F=L971O;B@I.PT*("`@("`@("`D<&%C:V%G969I;&4@/2`F;F5W(%!%
M05)?4&%C:V%G949I;&4H)&-O;F9I9RD[#0H@("`@("`@("1P9B`]("8D<&%C
M:V%G969I;&4M/F9R;VU!<G)A>2@D<&MG:6YF;RD[#0H@("`@("`@("1G96X@
M/2`F)'!F+3YG971$969A=6QT1V5N97)A=&]R*"D[#0H@("`@("`@(')E='5R
M;B`D9V5N+3YT;UAM;"A014%27U9!3$E$051%7U!!0TM!1TE.1RD[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[('9A;&ED871E4&%C:V%G94EN
M9F\H*0T*#0H@("`@+RHJ#0H@("`@("H@5F%L:61A=&4@6$U,('!A8VMA9V4@
M9&5F:6YI=&EO;B!F:6QE+@T*("`@("`J#0H@("`@("H@0'!A<F%M("!S=')I
M;F<@)&EN9F\@1FEL96YA;64@;V8@=&AE('!A8VMA9V4@87)C:&EV92!O<B!O
M9B!T:&4-"B`@("`@*B`@("`@("`@("`@("`@("!P86-K86=E(&1E9FEN:71I
M;VX@9FEL90T*("`@("`J($!P87)A;2`@87)R87D@)&5R<F]R<R!!<G)A>2!T
M:&%T('=I;&P@8V]N=&%I;B!T:&4@97)R;W)S#0H@("`@("H@0'!A<F%M("!A
M<G)A>2`D=V%R;FEN9W,@07)R87D@=&AA="!W:6QL(&-O;G1A:6X@=&AE('=A
M<FYI;F=S#0H@("`@("H@0'!A<F%M("!S=')I;F<@)&1I<E]P<F5F:7@@*&]P
M=&EO;F%L*2!D:7)E8W1O<GD@=VAE<F4@<V]U<F-E(&9I;&5S#0H@("`@("H@
M("`@("`@("`@("`@("`@;6%Y(&)E(&9O=6YD+"!O<B!E;7!T>2!I9B!T:&5Y
M(&%R92!N;W0@879A:6QA8FQE#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X-"B`@("`@*B!`9&5P<F5C871E9"!U<V4@
M=&AE('9A;&ED871I;VX@;V8@4$5!4E]086-K86=E1FEL92!O8FIE8W1S#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@=F%L:61A=&5086-K86=E26YF;R@D:6YF
M;RP@)B1E<G)O<G,L("8D=V%R;FEN9W,L("1D:7)?<')E9FEX(#T@)R<I#0H@
M("`@>PT*("`@("`@("`D8V]N9FEG(#T@)E!%05)?0V]N9FEG.CIS:6YG;&5T
M;VXH*3L-"B`@("`@("`@)'!A8VMA9V5F:6QE(#T@)FYE=R!014%27U!A8VMA
M9V5&:6QE*"1C;VYF:6<I.PT*("`@("`@("!014%2.CIS=&%T:6-0=7-H17)R
M;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@(&EF("AS
M=')P;W,H)&EN9F\L("<\/WAM;"<I("$]/2!F86QS92D@>PT*("`@("`@("`@
M("`@)'!F(#T@)B1P86-K86=E9FEL92T^9G)O;5AM;%-T<FEN9R@D:6YF;RP@
M4$5!4E]604Q)1$%415].3U)-04PL("<G*3L-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("1P9B`]("8D<&%C:V%G969I;&4M/F9R;VU!;GE&:6QE
M*"1I;F9O+"!014%27U9!3$E$051%7TY/4DU!3"D[#0H@("`@("`@('T-"B`@
M("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&8I*2![#0H@("`@("`@("`@("`D97)R
M<R`]("1P9BT^9V5T57-E<FEN9F\H*3L-"B`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2@D97)R<RDI('L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D97)R
M<R!A<R`D97)R;W(I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1E<G)O
M<ELG;&5V96PG72`]/2`G97)R;W(G*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D97)R;W)S6UT@/2`D97)R;W);)VUE<W-A9V4G73L-"B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1W87)N:6YG<UM=(#T@)&5R<F]R6R=M97-S86=E)UT[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(&)U:6QD4')O=FED97-!<G)A>2@I#0H-"B`@("`O*BH-"B`@("`@*B!"
M=6EL9"!A(")P<F]V:61E<R(@87)R87D@9G)O;2!D871A(')E='5R;F5D(&)Y
M#0H@("`@("H@86YA;'EZ95-O=7)C94-O9&4H*2X@(%1H92!F;W)M870@;V8@
M=&AE(&)U:6QT(&%R<F%Y(&ES(&QI:V4-"B`@("`@*B!T:&ES.@T*("`@("`J
M#0H@("`@("H@(&%R<F%Y*`T*("`@("`J("`@("=C;&%S<SM->4-L87-S)R`]
M/B`G87)R87DH)W1Y<&4G(#T^("=C;&%S<R<L("=N86UE)R`]/B`G37E#;&%S
M<R<I+`T*("`@("`J("`@("XN+@T*("`@("`J("`I#0H@("`@("H-"B`@("`@
M*@T*("`@("`J($!P87)A;2!A<G)A>2`D<W)C:6YF;R!A<G)A>2!W:71H(&EN
M9F]R;6%T:6]N(&%B;W5T(&$@<V]U<F-E(&9I;&4-"B`@("`@*B!A<R!R971U
M<FYE9"!B>2!T:&4@86YA;'EZ95-O=7)C94-O9&4H*2!M971H;V0N#0H@("`@
M("H-"B`@("`@*B!`<F5T=7)N('9O:60-"B`@("`@*@T*("`@("`J($!A8V-E
M<W,@<'5B;&EC#0H@("`@("H-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!B=6EL
M9%!R;W9I9&5S07)R87DH)'-R8VEN9F\I#0H@("`@>PT*("`@("`@("`D9FEL
M92`](&)A<V5N86UE*"1S<F-I;F9O6R=S;W5R8V5?9FEL92==*3L-"B`@("`@
M("`@)'!N(#T@)R<[#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA
M9V5.86UE*2D@>PT*("`@("`@("`@("`@)'!N(#T@)'1H:7,M/E]P86-K86=E
M3F%M93L-"B`@("`@("`@?0T*("`@("`@("`D<&YL(#T@<W1R;&5N*"1P;BD[
M#0H@("`@("`@(&9O<F5A8V@@*"1S<F-I;F9O6R=D96-L87)E9%]C;&%S<V5S
M)UT@87,@)&-L87-S*2![#0H@("`@("`@("`@("`D:V5Y(#T@(F-L87-S.R1C
M;&%S<R([#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/G!K9VEN9F];
M)W!R;W9I9&5S)UU;)&ME>5TI*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN
M=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^<&MG:6YF
M;ULG<')O=FED97,G75LD:V5Y72`]#0H@("`@("`@("`@("`@("`@87)R87DH
M)V9I;&4G/3X@)&9I;&4L("=T>7!E)R`]/B`G8VQA<W,G+"`G;F%M92<@/3X@
M)&-L87-S*3L-"B`@("`@("`@("`@(&EF("AI<W-E="@D<W)C:6YF;ULG:6YH
M97)I=&%N8V4G75LD8VQA<W-=*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES
M+3YP:V=I;F9O6R=P<F]V:61E<R==6R1K97E=6R=E>'1E;F1S)UT@/0T*("`@
M("`@("`@("`@("`@("`@("`D<W)C:6YF;ULG:6YH97)I=&%N8V4G75LD8VQA
M<W-=.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&9O<F5A
M8V@@*"1S<F-I;F9O6R=D96-L87)E9%]M971H;V1S)UT@87,@)&-L87-S(#T^
M("1M971H;V1S*2![#0H@("`@("`@("`@("!F;W)E86-H("@D;65T:&]D<R!A
M<R`D;65T:&]D*2![#0H@("`@("`@("`@("`@("`@)&9U;F-T:6]N(#T@(B1C
M;&%S<SHZ)&UE=&AO9"([#0H@("`@("`@("`@("`@("`@)&ME>2`](")F=6YC
M=&EO;CLD9G5N8W1I;VXB.PT*("`@("`@("`@("`@("`@(&EF("@D;65T:&]D
M>S!](#T]("=?)R!\?"`A<W1R8V%S96-M<"@D;65T:&]D+"`D8VQA<W,I('Q\
M#0H@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1T:&ES+3YP:V=I;F9O6R=P
M<F]V:61E<R==6R1K97E=*2D@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/G!K9VEN9F];)W!R;W9I9&5S)UU;)&ME>5T@/0T*("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@G9FEL92<]/B`D9FEL92P@)W1Y<&4G(#T^("=F=6YC
M=&EO;B<L("=N86UE)R`]/B`D9G5N8W1I;VXI.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H-"B`@("`@("`@9F]R96%C:"`H)'-R8VEN9F];)V1E8VQA
M<F5D7V9U;F-T:6]N<R==(&%S("1F=6YC=&EO;BD@>PT*("`@("`@("`@("`@
M)&ME>2`](")F=6YC=&EO;CLD9G5N8W1I;VXB.PT*("`@("`@("`@("`@:68@
M*"1F=6YC=&EO;GLP?2`]/2`G7R<@?'P@:7-S970H)'1H:7,M/G!K9VEN9F];
M)W!R;W9I9&5S)UU;)&ME>5TI*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN
M=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(7-T<G-T<B@D
M9G5N8W1I;VXL("<Z.B<I("8F('-T<FYC87-E8VUP*"1F=6YC=&EO;BP@)'!N
M+"`D<&YL*2D@>PT*("`@("`@("`@("`@("`@("1W87)N:6YG<UM=(#T@(FEN
M,2`B("X@)&9I;&4@+B`B.B!F=6YC=&EO;B!<(B1F=6YC=&EO;EPB(&YO="!P
M<F5F:7AE9"!W:71H('!A8VMA9V4@;F%M92!<(B1P;EPB(CL-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("1T:&ES+3YP:V=I;F9O6R=P<F]V:61E<R==
M6R1K97E=(#T-"B`@("`@("`@("`@("`@("!A<G)A>2@G9FEL92<]/B`D9FEL
M92P@)W1Y<&4G(#T^("=F=6YC=&EO;B<L("=N86UE)R`]/B`D9G5N8W1I;VXI
M.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[
M(&%N86QY>F53;W5R8V5#;V1E*"D-"@T*("`@("\J*@T*("`@("`J($%N86QY
M>F4@=&AE('-O=7)C92!C;V1E(&]F('1H92!G:79E;B!02%`@9FEL90T*("`@
M("`J#0H@("`@("H@0'!A<F%M("!S=')I;F<@1FEL96YA;64@;V8@=&AE(%!(
M4"!F:6QE#0H@("`@("H@0')E='5R;B!M:7AE9`T*("`@("`J($!A8V-E<W,@
M<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@86YA;'EZ95-O=7)C94-O
M9&4H)&9I;&4I#0H@("`@>PT*("`@("`@("!I9B`H(69U;F-T:6]N7V5X:7-T
M<R@B=&]K96Y?9V5T7V%L;"(I*2![#0H@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%D969I;F5D*"=47T1/0U]#
M3TU-14Y4)RDI('L-"B`@("`@("`@("`@(&1E9FEN92@G5%]$3T-?0T]-345.
M5"<L(%1?0T]-345.5"D[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%D969I
M;F5D*"=47TE.5$521D%#12<I*2![#0H@("`@("`@("`@("!D969I;F4H)U1?
M24Y415)&04-%)RP@+3$I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A9&5F
M:6YE9"@G5%])35!,14U%3E13)RDI('L-"B`@("`@("`@("`@(&1E9FEN92@G
M5%])35!,14U%3E13)RP@+3$I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A
M)&9P(#T@0&9O<&5N*"1F:6QE+"`B<B(I*2![#0H@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*&9U;F-T:6]N7V5X
M:7-T<R@G9FEL95]G971?8V]N=&5N=',G*2D@>PT*("`@("`@("`@("`@9F-L
M;W-E*"1F<"D[#0H@("`@("`@("`@("`D8V]N=&5N=',@/2!F:6QE7V=E=%]C
M;VYT96YT<R@D9FEL92D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D8V]N=&5N=',@/2!F<F5A9"@D9G`L(&9I;&5S:7IE*"1F:6QE*2D[#0H@
M("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@?0T*("`@("`@("`D
M=&]K96YS(#T@=&]K96Y?9V5T7V%L;"@D8V]N=&5N=',I.PT*+RH-"B`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1T;VME;G,I.R`D:2LK*2![
M#0H@("`@("`@("`@("!`;&ES="@D=&]K96XL("1D871A*2`]("1T;VME;G-;
M)&E=.PT*("`@("`@("`@("`@:68@*&ES7W-T<FEN9R@D=&]K96XI*2![#0H@
M("`@("`@("`@("`@("`@=F%R7V1U;7`H)'1O:V5N*3L-"B`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@<')I;G0@=&]K96Y?;F%M92@D
M=&]K96XI("X@)R`G.PT*("`@("`@("`@("`@("`@('9A<E]D=6UP*')T<FEM
M*"1D871A*2D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"BHO#0H@("`@
M("`@("1L;V]K7V9O<B`](#`[#0H@("`@("`@("1P87)E;E]L979E;"`](#`[
M#0H@("`@("`@("1B<F%C:V5T7VQE=F5L(#T@,#L-"B`@("`@("`@)&)R86-E
M7VQE=F5L(#T@,#L-"B`@("`@("`@)&QA<W1P:'!D;V,@/2`G)SL-"B`@("`@
M("`@)&-U<G)E;G1?8VQA<W,@/2`G)SL-"B`@("`@("`@)&-U<G)E;G1?:6YT
M97)F86-E(#T@)R<[#0H@("`@("`@("1C=7)R96YT7V-L87-S7VQE=F5L(#T@
M+3$[#0H@("`@("`@("1C=7)R96YT7V9U;F-T:6]N(#T@)R<[#0H@("`@("`@
M("1C=7)R96YT7V9U;F-T:6]N7VQE=F5L(#T@+3$[#0H@("`@("`@("1D96-L
M87)E9%]C;&%S<V5S(#T@87)R87DH*3L-"B`@("`@("`@)&1E8VQA<F5D7VEN
M=&5R9F%C97,@/2!A<G)A>2@I.PT*("`@("`@("`D9&5C;&%R961?9G5N8W1I
M;VYS(#T@87)R87DH*3L-"B`@("`@("`@)&1E8VQA<F5D7VUE=&AO9',@/2!A
M<G)A>2@I.PT*("`@("`@("`D=7-E9%]C;&%S<V5S(#T@87)R87DH*3L-"B`@
M("`@("`@)'5S961?9G5N8W1I;VYS(#T@87)R87DH*3L-"B`@("`@("`@)&5X
M=&5N9',@/2!A<G)A>2@I.PT*("`@("`@("`D:6UP;&5M96YT<R`](&%R<F%Y
M*"D[#0H@("`@("`@("1N;V1E<',@/2!A<G)A>2@I.PT*("`@("`@("`D:6YQ
M=6]T92`](&9A;'-E.PT*("`@("`@("`D:6YT97)F86-E(#T@9F%L<V4[#0H@
M("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D=&]K96YS*3L@)&DK
M*RD@>PT*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1T;VME;G-;)&E=*2D@
M>PT*("`@("`@("`@("`@("`@(&QI<W0H)'1O:V5N+"`D9&%T82D@/2`D=&]K
M96YS6R1I73L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@)'1O:V5N(#T@)'1O:V5N<ULD:5T[#0H@("`@("`@("`@("`@("`@)&1A
M=&$@/2`G)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D:6YQ
M=6]T92D@>PT*("`@("`@("`@("`@("`@(&EF("@D=&]K96X@(3T@)R(G*2![
M#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1I;G%U;W1E(#T@
M9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@('-W:71C
M:"`H)'1O:V5N*2![#0H@("`@("`@("`@("`@("`@8V%S92!47U=(251%4U!!
M0T4Z#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@("`@(&-A<V4@)SLG.@T*("`@("`@("`@("`@("`@("`@("!I9B`H)&EN
M=&5R9F%C92D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?
M9G5N8W1I;VX@/2`G)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R
M96YT7V9U;F-T:6]N7VQE=F5L(#T@+3$[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@
M("`@8V%S92`G(B<Z#0H@("`@("`@("`@("`@("`@("`@("1I;G%U;W1E(#T@
M=')U93L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@
M("`@("`@8V%S92!47T-54DQ97T]014XZ#0H@("`@("`@("`@("`@("`@8V%S
M92!47T1/3$Q!4E]/4$5.7T-54DQ97T)204-%4SH-"B`@("`@("`@("`@("`@
M("!C87-E("=[)SH@)&)R86-E7VQE=F5L*RL[(&-O;G1I;G5E(#([#0H@("`@
M("`@("`@("`@("`@8V%S92`G?2<Z#0H@("`@("`@("`@("`@("`@("`@("1B
M<F%C95]L979E;"TM.PT*("`@("`@("`@("`@("`@("`@("!I9B`H)&-U<G)E
M;G1?8VQA<W-?;&5V96P@/3T@)&)R86-E7VQE=F5L*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D8W5R<F5N=%]C;&%S<R`]("<G.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)&-U<G)E;G1?8VQA<W-?;&5V96P@/2`M,3L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H
M)&-U<G)E;G1?9G5N8W1I;VY?;&5V96P@/3T@)&)R86-E7VQE=F5L*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]F=6YC=&EO;B`]("<G
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?9G5N8W1I;VY?
M;&5V96P@/2`M,3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU92`R.PT*("`@("`@("`@("`@("`@(&-A<V4@
M)ULG.B`D8G)A8VME=%]L979E;"LK.R!C;VYT:6YU92`R.PT*("`@("`@("`@
M("`@("`@(&-A<V4@)UTG.B`D8G)A8VME=%]L979E;"TM.R!C;VYT:6YU92`R
M.PT*("`@("`@("`@("`@("`@(&-A<V4@)R@G.B`D<&%R96Y?;&5V96PK*SL@
M("!C;VYT:6YU92`R.PT*("`@("`@("`@("`@("`@(&-A<V4@)RDG.B`D<&%R
M96Y?;&5V96PM+3L@("!C;VYT:6YU92`R.PT*("`@("`@("`@("`@("`@(&-A
M<V4@5%])3E1%4D9!0T4Z#0H@("`@("`@("`@("`@("`@("`@("1I;G1E<F9A
M8V4@/2!T<G5E.PT*("`@("`@("`@("`@("`@(&-A<V4@5%]#3$%34SH-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"@D8W5R<F5N=%]C;&%S<U]L979E;"`A
M/2`M,2D@?'P@*"1C=7)R96YT7V9U;F-T:6]N7VQE=F5L("$]("TQ*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@4$5!4CHZ<F%I<V5%<G)O<B@B4&%R
M<V5R(&5R<F]R.B!I;G9A;&ED(%!(4"!F;W5N9"!I;B!F:6QE(%PB)&9I;&5<
M(B(L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E]#3TU-3TY?
M15)23U)?24Y604Q)1%!(4"D[#0H@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!C87-E(%1?1E5.0U1)3TXZ#0H@("`@("`@("`@("`@("`@8V%S
M92!47TY%5SH-"B`@("`@("`@("`@("`@("!C87-E(%1?15A414Y$4SH-"B`@
M("`@("`@("`@("`@("!C87-E(%1?24U03$5-14Y44SH-"B`@("`@("`@("`@
M("`@("`@("`@)&QO;VM?9F]R(#T@)'1O:V5N.PT*("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU92`R.PT*("`@("`@("`@("`@("`@(&-A<V4@5%]35%))
M3D<Z#0H@("`@("`@("`@("`@("`@("`@(&EF("AV97)S:6]N7V-O;7!A<F4H
M>F5N9%]V97)S:6]N*"DL("<R+C`G+"`G/"<I*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H:6Y?87)R87DH<W1R=&]L;W=E<B@D9&%T82DL#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W!U8FQI8R<L("=P
M<FEV871E)RP@)W!R;W1E8W1E9"<L("=A8G-T<F%C="<L#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)VEN=&5R9F%C92<L("=I;7!L96UE
M;G1S)RP@)W1H<F]W)RD@#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!4CHZ
M<F%I<V5%<G)O<B@G17)R;W(Z(%!(4#4@=&]K96X@96YC;W5N=&5R960@:6X@
M)R`N("1F:6QE("X@#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!A
M8VMA9VEN9R!S:&]U;&0@8F4@9&]N92!I;B!02%`@-2<I.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("!I9B`H)&QO;VM?9F]R(#T](%1?0TQ!4U,I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V-L87-S(#T@)&1A=&$[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]C;&%S<U]L979E
M;"`]("1B<F%C95]L979E;#L-"B`@("`@("`@("`@("`@("`@("`@("`@("1D
M96-L87)E9%]C;&%S<V5S6UT@/2`D8W5R<F5N=%]C;&%S<SL-"B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E:68@*"1L;V]K7V9O<B`]/2!47TE.5$521D%#
M12D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?:6YT97)F
M86-E(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N
M=%]C;&%S<U]L979E;"`]("1B<F%C95]L979E;#L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1D96-L87)E9%]I;G1E<F9A8V5S6UT@/2`D8W5R<F5N=%]I
M;G1E<F9A8V4[#0H@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D;&]O
M:U]F;W(@/3T@5%])35!,14U%3E13*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D:6UP;&5M96YT<ULD8W5R<F5N=%]C;&%S<UT@/2`D9&%T83L-"B`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1L;V]K7V9O<B`]/2!47T58
M5$5.1%,I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1E>'1E;F1S6R1C
M=7)R96YT7V-L87-S72`]("1D871A.PT*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V5I9B`H)&QO;VM?9F]R(#T](%1?1E5.0U1)3TXI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@D8W5R<F5N=%]C;&%S<RD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V9U;F-T:6]N(#T@(B1C
M=7)R96YT7V-L87-S.CHD9&%T82([#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1E8VQA<F5D7VUE=&AO9'-;)&-U<G)E;G1?8VQA<W-=6UT@/2`D
M9&%T83L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D8W5R
M<F5N=%]I;G1E<F9A8V4I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D8W5R<F5N=%]F=6YC=&EO;B`]("(D8W5R<F5N=%]I;G1E<F9A8V4Z.B1D
M871A(CL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5C;&%R961?
M;65T:&]D<ULD8W5R<F5N=%]I;G1E<F9A8V5=6UT@/2`D9&%T83L-"B`@("`@
M("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&-U<G)E;G1?9G5N8W1I;VX@/2`D9&%T83L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9&5C;&%R961?9G5N8W1I;VYS6UT@
M/2`D8W5R<F5N=%]F=6YC=&EO;CL-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V9U;F-T:6]N
M7VQE=F5L(#T@)&)R86-E7VQE=F5L.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)&T@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H)&QO;VM?9F]R(#T](%1?3D57*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D=7-E9%]C;&%S<V5S6R1D871A72`]('1R=64[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)&QO;VM?9F]R(#T@
M,#L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64@,CL-"B`@("`@("`@
M("`@("`@("!C87-E(%1?5D%224%"3$4Z#0H@("`@("`@("`@("`@("`@("`@
M("1L;V]K7V9O<B`](#`[#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M(#([#0H@("`@("`@("`@("`@("`@8V%S92!47T1/0U]#3TU-14Y4.@T*("`@
M("`@("`@("`@("`@(&-A<V4@5%]#3TU-14Y4.@T*("`@("`@("`@("`@("`@
M("`@("!I9B`H<')E9U]M871C:"@G(5XO7"I<*EQS(2<L("1D871A*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&QA<W1P:'!D;V,@/2`D9&%T83L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H7V%L;"@G
M+T!N;V1E<%QS*RA<4RLI+R<L("1L87-T<&AP9&]C+"`D;2DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D;F]D97!S(#T@87)R87E?;65R9V4H
M)&YO9&5P<RP@)&U;,5TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E(#([#0H@("`@("`@("`@("`@("`@8V%S92!47T1/54),15]#3TQ/
M3CH-"B`@("`@("`@("`@("`@("`@("`@:68@*"$H)'1O:V5N<ULD:2`M(#%=
M6S!=(#T](%1?5TA)5$534$%#12!\?"`D=&]K96YS6R1I("T@,5U;,%T@/3T@
M5%]35%))3D<I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!014%2.CIR
M86ES945R<F]R*")087)S97(@97)R;W(Z(&EN=F%L:60@4$A0(&9O=6YD(&EN
M(&9I;&4@7"(D9FEL95PB(BP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!014%27T-/34U/3E]%4E)/4E])3E9!3$E$4$A0*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`D8VQA<W,@/2`D=&]K96YS6R1I
M("T@,5U;,5T[#0H@("`@("`@("`@("`@("`@("`@(&EF("AS=')T;VQO=V5R
M*"1C;&%S<RD@(3T@)W!A<F5N="<I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1U<V5D7V-L87-S97-;)&-L87-S72`]('1R=64[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64@,CL-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@87)R
M87DH#0H@("`@("`@("`@("`B<V]U<F-E7V9I;&4B(#T^("1F:6QE+`T*("`@
M("`@("`@("`@(F1E8VQA<F5D7V-L87-S97,B(#T^("1D96-L87)E9%]C;&%S
M<V5S+`T*("`@("`@("`@("`@(F1E8VQA<F5D7VEN=&5R9F%C97,B(#T^("1D
M96-L87)E9%]I;G1E<F9A8V5S+`T*("`@("`@("`@("`@(F1E8VQA<F5D7VUE
M=&AO9',B(#T^("1D96-L87)E9%]M971H;V1S+`T*("`@("`@("`@("`@(F1E
M8VQA<F5D7V9U;F-T:6]N<R(@/3X@)&1E8VQA<F5D7V9U;F-T:6]N<RP-"B`@
M("`@("`@("`@(")U<V5D7V-L87-S97,B(#T^(&%R<F%Y7V1I9F8H87)R87E?
M:V5Y<R@D=7-E9%]C;&%S<V5S*2P@)&YO9&5P<RDL#0H@("`@("`@("`@("`B
M:6YH97)I=&%N8V4B(#T^("1E>'1E;F1S+`T*("`@("`@("`@("`@(FEM<&QE
M;65N=',B(#T^("1I;7!L96UE;G1S+`T*("`@("`@("`@("`@*3L-"B`@("!]
M#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@(&)E='1E<E-T871E<R@I#0H-
M"B`@("`O*BH-"B`@("`@*B!2971U<FX@86X@87)R87D@8V]N=&%I;FEN9R!A
M;&P@;V8@=&AE('-T871E<R!T:&%T(&%R92!M;W)E('-T86)L92!T:&%N#0H@
M("`@("H@;W(@97%U86P@=&\@=&AE('!A<W-E9"!I;B!S=&%T90T*("`@("`J
M#0H@("`@("H@0'!A<F%M('-T<FEN9R!296QE87-E('-T871E#0H@("`@("H@
M0'!A<F%M(&)O;VQE86X@1&5T97)M:6YE<R!W:&5T:&5R('1O(&EN8VQU9&4@
M)'-T871E(&EN('1H92!L:7-T#0H@("`@("H@0')E='5R;B!F86QS97QA<G)A
M>2!&86QS92!I9B`D<W1A=&4@:7,@;F]T(&$@=F%L:60@<F5L96%S92!S=&%T
M90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&)E='1E<E-T871E<R@D<W1A=&4L
M("1I;F-L=61E(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!S=&%T:6,@)'-T
M871E<R`](&%R<F%Y*"=S;F%P<VAO="<L("=D979E;"<L("=A;'!H82<L("=B
M971A)RP@)W-T86)L92<I.PT*("`@("`@("`D:2`](&%R<F%Y7W-E87)C:"@D
M<W1A=&4L("1S=&%T97,I.PT*("`@("`@("!I9B`H)&D@/3T](&9A;'-E*2![
M#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"1I;F-L=61E*2![#0H@("`@("`@("`@("`D:2TM.PT*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B!A<G)A>5]S;&EC92@D<W1A=&5S+"`D:2`K
M(#$I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!D971E8W1$
M97!E;F1E;F-I97,H*0T*#0H@("`@9G5N8W1I;VX@9&5T96-T1&5P96YD96YC
M:65S*"1A;GDL("1S=&%T=7-?8V%L;&)A8VL@/2!N=6QL*0T*("`@('L-"B`@
M("`@("`@:68@*"%F=6YC=&EO;E]E>&ES=',H(G1O:V5N7V=E=%]A;&PB*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1I;F9O(#T@)'1H:7,M/FEN9F]&<F]M
M06YY*"1A;GDI*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"1I;F9O*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES7V%R
M<F%Y*"1I;F9O*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M("`@("!]#0H@("`@("`@("1D97!S(#T@87)R87DH*3L-"B`@("`@("`@)'5S
M961?8R`]("1D96-L7V,@/2`D9&5C;%]F(#T@)&1E8VQ?;2`](&%R<F%Y*"D[
M#0H@("`@("`@(&9O<F5A8V@@*"1I;F9O6R=F:6QE;&ES="==(&%S("1F:6QE
M(#T^("1F82D@>PT*("`@("`@("`@("`@)'1M<"`]("1T:&ES+3YA;F%L>7IE
M4V]U<F-E0V]D92@D9FEL92D[#0H@("`@("`@("`@("`D=7-E9%]C(#T@0&%R
M<F%Y7VUE<F=E*"1U<V5D7V,L("1T;7!;)W5S961?8VQA<W-E<R==*3L-"B`@
M("`@("`@("`@("1D96-L7V,@/2!`87)R87E?;65R9V4H)&1E8VQ?8RP@)'1M
M<%LG9&5C;&%R961?8VQA<W-E<R==*3L-"B`@("`@("`@("`@("1D96-L7V8@
M/2!`87)R87E?;65R9V4H)&1E8VQ?9BP@)'1M<%LG9&5C;&%R961?9G5N8W1I
M;VYS)UTI.PT*("`@("`@("`@("`@)&1E8VQ?;2`]($!A<G)A>5]M97)G92@D
M9&5C;%]M+"`D=&UP6R=D96-L87)E9%]M971H;V1S)UTI.PT*("`@("`@("`@
M("`@)&EN:&5R:2`]($!A<G)A>5]M97)G92@D:6YH97)I+"`D=&UP6R=I;FAE
M<FET86YC92==*3L-"B`@("`@("`@?0T*("`@("`@("`D=7-E9%]C(#T@87)R
M87E?=6YI<75E*"1U<V5D7V,I.PT*("`@("`@("`D9&5C;%]C(#T@87)R87E?
M=6YI<75E*"1D96-L7V,I.PT*("`@("`@("`D=6YD96-L7V,@/2!A<G)A>5]D
M:69F*"1U<V5D7V,L("1D96-L7V,I.PT*("`@("`@("!R971U<FX@87)R87DH
M)W5S961?8VQA<W-E<R<@/3X@)'5S961?8RP-"B`@("`@("`@("`@("`@("`@
M("`@("=D96-L87)E9%]C;&%S<V5S)R`]/B`D9&5C;%]C+`T*("`@("`@("`@
M("`@("`@("`@("`@)V1E8VQA<F5D7VUE=&AO9',G(#T^("1D96-L7VTL#0H@
M("`@("`@("`@("`@("`@("`@("`G9&5C;&%R961?9G5N8W1I;VYS)R`]/B`D
M9&5C;%]F+`T*("`@("`@("`@("`@("`@("`@("`@)W5N9&5C;&%R961?8VQA
M<W-E<R<@/3X@)'5N9&5C;%]C+`T*("`@("`@("`@("`@("`@("`@("`@)VEN
M:&5R:71A;F-E)R`]/B`D:6YH97)I+`T*("`@("`@("`@("`@("`@("`@("`@
M*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T57-E<E)O
M;&5S*"D-"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@=F%L:60@<F]L97,@
M9F]R(&$@4$5!4B!P86-K86=E(&UA:6YT86EN97(-"B`@("`@*@T*("`@("`J
M($!R971U<FX@87)R87D-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@9V5T57-E<E)O;&5S*"D-"B`@("![#0H@("`@("`@(')E='5R
M;B`D1TQ/0D%,4ULG7U!%05)?0V]M;6]N7VUA:6YT86EN97)?<F]L97,G73L-
M"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T4F5L96%S95-T
M871E<R@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE('9A;&ED('!A8VMA
M9V4@<F5L96%S92!S=&%T97,@;V8@<&%C:V%G97,-"B`@("`@*@T*("`@("`J
M($!R971U<FX@87)R87D-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@9V5T4F5L96%S95-T871E<R@I#0H@("`@>PT*("`@("`@("!R
M971U<FX@)$=,3T)!3%-;)U]014%27T-O;6UO;E]R96QE87-E7W-T871E<R==
M.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G971$97!E;F1E
M;F-Y5'EP97,H*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!I;7!L96UE
M;G1E9"!D97!E;F1E;F-Y('1Y<&5S("AP:'`L(&5X="P@<&MG(&5T8RXI#0H@
M("`@("H-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("H@0'-T871I8PT*
M("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$1E<&5N9&5N8WE4>7!E<R@I#0H@
M("`@>PT*("`@("`@("!R971U<FX@)$=,3T)!3%-;)U]014%27T-O;6UO;E]D
M97!E;F1E;F-Y7W1Y<&5S)UT[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(&=E=$1E<&5N9&5N8WE296QA=&EO;G,H*0T*#0H@("`@+RHJ#0H@
M("`@("H@1V5T('1H92!I;7!L96UE;G1E9"!D97!E;F1E;F-Y(')E;&%T:6]N
M<R`H:&%S+"!L="P@9V4@971C+BD-"B`@("`@*@T*("`@("`J($!R971U<FX@
M87)R87D-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M9V5T1&5P96YD96YC>5)E;&%T:6]N<R@I#0H@("`@>PT*("`@("`@("!R971U
M<FX@)$=,3T)!3%-;)U]014%27T-O;6UO;E]D97!E;F1E;F-Y7W)E;&%T:6]N
M<R==.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G971&:6QE
M4F]L97,H*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!I;7!L96UE;G1E
M9"!F:6QE(')O;&5S#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@
M("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$9I;&52
M;VQE<R@I#0H@("`@>PT*("`@("`@("!R971U<FX@)$=,3T)!3%-;)U]014%2
M7T-O;6UO;E]F:6QE7W)O;&5S)UT[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(&=E=%)E<&QA8V5M96YT5'EP97,H*0T*#0H@("`@+RHJ#0H@
M("`@("H@1V5T('1H92!I;7!L96UE;G1E9"!F:6QE(')E<&QA8V5M96YT('1Y
M<&5S(&EN#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("H@
M0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%)E<&QA8V5M96YT
M5'EP97,H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1'3$]"04Q36R=?4$5!
M4E]#;VUM;VY?<F5P;&%C96UE;G1?='EP97,G73L-"B`@("!]#0H-"B`@("`O
M+R!]?7T-"B`@("`O+R![>WL@9V5T4')O=FED951Y<&5S*"D-"@T*("`@("\J
M*@T*("`@("`J($=E="!T:&4@:6UP;&5M96YT960@9FEL92!R97!L86-E;65N
M="!T>7!E<R!I;@T*("`@("`J#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@
M("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G9710<F]V:61E
M5'EP97,H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1'3$]"04Q36R=?4$5!
M4E]#;VUM;VY?<')O=FED95]T>7!E<R==.PT*("`@('T-"@T*("`@("\O('U]
M?0T*("`@("\O('M[>R!G97138W)I<'10:&%S97,H*0T*#0H@("`@+RHJ#0H@
M("`@("H@1V5T('1H92!I;7!L96UE;G1E9"!F:6QE(')E<&QA8V5M96YT('1Y
M<&5S(&EN#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("H@
M0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%-C<FEP=%!H87-E
M<R@I#0H@("`@>PT*("`@("`@("!R971U<FX@)$=,3T)!3%-;)U]014%27T-O
M;6UO;E]S8W)I<'1?<&AA<V5S)UT[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[('9A;&ED4&%C:V%G94YA;64H*0T*#0H@("`@+RHJ#0H@("`@
M("H@5&5S="!W:&5T:&5R(&$@<W1R:6YG(&-O;G1A:6YS(&$@=F%L:60@<&%C
M:V%G92!N86UE+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M
M92!T:&4@<&%C:V%G92!N86UE('1O('1E<W0-"B`@("`@*@T*("`@("`J($!R
M971U<FX@8F]O;`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9%!A8VMA9V5.86UE*"1N86UE*0T*
M("`@('L-"B`@("`@("`@<F5T=7)N("AB;V]L*7!R96=?;6%T8V@H4$5!4E]#
M3TU-3TY?4$%#2T%'15].04U%7U!214<L("1N86UE*3L-"B`@("!]#0H-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R!V86QI9%!A8VMA9V5697)S:6]N*"D-
M"@T*("`@("\J*@T*("`@("`J(%1E<W0@=VAE=&AE<B!A('-T<FEN9R!C;VYT
M86EN<R!A('9A;&ED('!A8VMA9V4@=F5R<VEO;BX-"B`@("`@*@T*("`@("`J
M($!P87)A;2!S=')I;F<@)'9E<B!T:&4@<&%C:V%G92!V97)S:6]N('1O('1E
M<W0-"B`@("`@*@T*("`@("`J($!R971U<FX@8F]O;`T*("`@("`J#0H@("`@
M("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI
M9%!A8VMA9V5697)S:6]N*"1V97(I#0H@("`@>PT*("`@("`@("!R971U<FX@
M*&)O;VPI<')E9U]M871C:"A014%27T-/34U/3E]004-+04=%7U9%4E-)3TY?
M4%)%1RP@)'9E<BD[#0H@("`@?0T*#0H-"B`@("`O+R!]?7T-"@T*("`@("\O
M('M[>R!D;W=N;&]A9$AT='`H*0T*#0H@("`@+RHJ#0H@("`@("H@1&]W;FQO
M860@82!F:6QE('1H<F]U9V@@2%144"X@($-O;G-I9&5R<R!S=6=G97-T960@
M9FEL92!N86UE(&EN#0H@("`@("H@0V]N=&5N="UD:7-P;W-I=&EO;CH@:&5A
M9&5R(&%N9"!C86X@<G5N(&$@8V%L;&)A8VL@9G5N8W1I;VX@9F]R#0H@("`@
M("H@9&EF9F5R96YT(&5V96YT<RX@(%1H92!C86QL8F%C:R!W:6QL(&)E(&-A
M;&QE9"!W:71H('1W;PT*("`@("`J('!A<F%M971E<G,Z('1H92!C86QL8F%C
M:R!T>7!E+"!A;F0@<&%R86UE=&5R<RX@(%1H92!I;7!L96UE;G1E9`T*("`@
M("`J(&-A;&QB86-K('1Y<&5S(&%R93H-"B`@("`@*@T*("`@("`J("`G<V5T
M=7`G("`@("`@(&-A;&QE9"!A="!T:&4@=F5R>2!B96=I;FYI;F<L('!A<F%M
M971E<B!I<R!A(%5)(&]B:F5C=`T*("`@("`J("`@("`@("`@("`@("`@('1H
M870@<VAO=6QD(&)E('5S960@9F]R(&%L;"!O=71P=70-"B`@("`@*B`@)VUE
M<W-A9V4G("`@("!T:&4@<&%R86UE=&5R(&ES(&$@<W1R:6YG('=I=&@@86X@
M:6YF;W)M871I;VYA;"!M97-S86=E#0H@("`@("H@("=S879E87,G("`@("`@
M;6%Y(&)E('5S960@=&\@<V%V92!W:71H(&$@9&EF9F5R96YT(&9I;&4@;F%M
M92P@=&AE#0H@("`@("H@("`@("`@("`@("`@("`@<&%R86UE=&5R(&ES('1H
M92!F:6QE;F%M92!T:&%T(&ES(&%B;W5T('1O(&)E('5S960N#0H@("`@("H@
M("`@("`@("`@("`@("`@268@82`G<V%V96%S)R!C86QL8F%C:R!R971U<FYS
M(&$@;F]N+65M<'1Y('-T<FEN9RP-"B`@("`@*B`@("`@("`@("`@("`@("!T
M:&%T(&9I;&4@;F%M92!W:6QL(&)E('5S960@87,@=&AE(&9I;&5N86UE(&EN
M<W1E860N#0H@("`@("H@("`@("`@("`@("`@("`@3F]T92!T:&%T("1S879E
M7V1I<B!W:6QL(&YO="!B92!A9F9E8W1E9"!B>2!T:&ES+"!O;FQY#0H@("`@
M("H@("`@("`@("`@("`@("`@=&AE(&)A<V5N86UE(&]F('1H92!F:6QE+@T*
M("`@("`J("`G<W1A<G0G("`@("`@(&1O=VYL;V%D(&ES('-T87)T:6YG+"!P
M87)A;65T97(@:7,@;G5M8F5R(&]F(&)Y=&5S#0H@("`@("H@("`@("`@("`@
M("`@("`@=&AA="!A<F4@97AP96-T960L(&]R("TQ(&EF('5N:VYO=VX-"B`@
M("`@*B`@)V)Y=&5S<F5A9"<@("!P87)A;65T97(@:7,@=&AE(&YU;6)E<B!O
M9B!B>71E<R!R96%D('-O(&9A<@T*("`@("`J("`G9&]N92<@("`@("`@(&1O
M=VYL;V%D(&ES(&-O;7!L971E+"!P87)A;65T97(@:7,@=&AE('1O=&%L(&YU
M;6)E<@T*("`@("`J("`@("`@("`@("`@("`@(&]F(&)Y=&5S(')E860-"B`@
M("`@*B`@)V-O;FYF86EL960G("!I9B!T:&4@5$-0(&-O;FYE8W1I;VX@9F%I
M;',L('1H:7,@8V%L;&)A8VL@:7,@8V%L;&5D#0H@("`@("H@("`@("`@("`@
M("`@("`@=VET:"!A<G)A>2AH;W-T+'!O<G0L97)R;F\L97)R;7-G*0T*("`@
M("`J("`G=W)I=&5F86EL960G(&EF('=R:71I;F<@=&\@9&ES:R!F86EL<RP@
M=&AI<R!C86QL8F%C:R!I<R!C86QL960-"B`@("`@*B`@("`@("`@("`@("`@
M("!W:71H(&%R<F%Y*&1E<W1F:6QE+&5R<FUS9RD-"B`@("`@*@T*("`@("`J
M($EF(&%N($A45%`@<')O>'D@:&%S(&)E96X@8V]N9FEG=7)E9"`H:'1T<%]P
M<F]X>2!014%27T-O;F9I9PT*("`@("`J('-E='1I;F<I+"!T:&4@<')O>'D@
M=VEL;"!B92!U<V5D+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`@
M)'5R;"`@("`@("!T:&4@55),('1O(&1O=VYL;V%D#0H@("`@("H@0'!A<F%M
M(&]B:F5C="`@)'5I("`@("`@("!014%27T9R;VYT96YD7RH@:6YS=&%N8V4-
M"B`@("`@*B!`<&%R86T@;V)J96-T("`D8V]N9FEG("`@(%!%05)?0V]N9FEG
M(&EN<W1A;F-E#0H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-A=F5?9&ER("`H
M;W!T:6]N86PI(&1I<F5C=&]R>2!T;R!S879E(&9I;&4@:6X-"B`@("`@*B!`
M<&%R86T@;6EX960@("`D8V%L;&)A8VL@("AO<'1I;VYA;"D@9G5N8W1I;VXO
M;65T:&]D('1O(&-A;&P@9F]R('-T871U<PT*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=7!D871E<PT*("`@("`J#0H@("`@("H@0')E='5R
M;B!S=')I;F<@(%)E='5R;G,@=&AE(&9U;&P@<&%T:"!O9B!T:&4@9&]W;FQO
M861E9"!F:6QE(&]R(&$@4$5!4@T*("`@("`J("`@("`@("`@("`@("`@("!E
M<G)O<B!O;B!F86EL=7)E+B`@268@=&AE(&5R<F]R(&ES(&-A=7-E9"!B>0T*
M("`@("`J("`@("`@("`@("`@("`@("!S;V-K970M<F5L871E9"!E<G)O<G,L
M('1H92!E<G)O<B!O8FIE8W0@=VEL;`T*("`@("`J("`@("`@("`@("`@("`@
M("!H879E('1H92!F<V]C:V]P96X@97)R;W(@8V]D92!A=F%I;&%B;&4@=&AR
M;W5G:`T*("`@("`J("`@("`@("`@("`@("`@("!G971#;V1E*"DN#0H@("`@
M("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!D97!R96-A=&5D
M(&EN(&9A=F]R(&]F(%!%05)?1&]W;FQO861E<CHZ9&]W;FQO861(='1P*"D-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!D;W=N;&]A9$AT='`H)'5R;"P@)B1U
M:2P@)'-A=F5?9&ER(#T@)RXG+"`D8V%L;&)A8VL@/2!N=6QL*0T*("`@('L-
M"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?1&]W;FQO861E<B<I
M*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O1&]W;FQO861E
M<BYP:'`G.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!014%27T1O=VYL
M;V%D97(Z.F1O=VYL;V%D2'1T<"@D=7)L+"`D=6DL("1S879E7V1I<BP@)&-A
M;&QB86-K*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*("`@("\J*@T*("`@
M("`J($!P87)A;2!S=')I;F<@)'!A=&@@<F5L871I=F4@;W(@86)S;VQU=&4@
M:6YC;'5D92!P871H#0H@("`@("H@0')E='5R;B!B;V]L96%N#0H@("`@("H@
M0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&ES26YC;'5D96%B;&4H
M)'!A=&@I#0H@("`@>PT*("`@("`@("!I9B`H9FEL95]E>&ES=',H)'!A=&@I
M("8F(&ES7W)E861A8FQE*"1P871H*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M('1R=64[#0H@("`@("`@('T-"B`@("`@("`@)&EP871H(#T@97AP;&]D92A0
M051(7U-%4$%2051/4BP@:6YI7V=E="@G:6YC;'5D95]P871H)RDI.PT*("`@
M("`@("!F;W)E86-H("@D:7!A=&@@87,@)&EN8VQU9&4I('L-"B`@("`@("`@
M("`@("1T97-T(#T@<F5A;'!A=&@H)&EN8VQU9&4@+B!$25)%0U1/4EE?4T50
M05)!5$]2("X@)'!A=&@I.PT*("`@("`@("`@("`@:68@*&9I;&5?97AI<W1S
M*"1T97-T*2`F)B!I<U]R96%D86)L92@D=&5S="DI('L-"B`@("`@("`@("`@
M("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*?0T*<F5Q=6ER95]O;F-E
M("=014%2+T-O;F9I9RYP:'`G.PT*<F5Q=6ER95]O;F-E("=014%2+U!A8VMA
M9V5&:6QE+G!H<"<[#0H_/@``````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T-O
M;F9I9RYP:'``````````````````````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#(P-S,W,P`Q,#4Q-30S,S<T,0`P,C$R-C,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`-"B\J*@T*("H@4$5!4E]#
M;VYF:6<L(&-U<W1O;6EZ960@8V]N9FEG=7)A=&EO;B!H86YD;&EN9R!F;W(@
M=&AE(%!%05(@26YS=&%L;&5R#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD
M(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE
M8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T
M(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T
M:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O
M9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I
M;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@
M=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@
M:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A
M8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S
M8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO
M9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@
M1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@
M0U93.B`D260Z($-O;F9I9RYP:'`L=B`Q+C$R-"`R,#`V+S`S+S`R(#$X.C$T
M.C$R(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A
M:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"@T*+RHJ#0H@*B!297%U
M:7)E9"!F;W(@97)R;W(@:&%N9&QI;F<-"B`J+PT*<F5Q=6ER95]O;F-E("=0
M14%2+G!H<"<[#0IR97%U:7)E7V]N8V4@)U!%05(O4F5G:7-T<GDN<&AP)SL-
M"G)E<75I<F5?;VYC92`G4$5!4B]);G-T86QL97(O4F]L92YP:'`G.PT*<F5Q
M=6ER95]O;F-E("=3>7-T96TN<&AP)SL-"G)E<75I<F5?;VYC92`G4$5!4B]2
M96UO=&4N<&AP)SL-"@T*+RHJ#0H@*B!,87-T(&-R96%T960@4$5!4E]#;VYF
M:6<@:6YS=&%N8V4N#0H@*B!`=F%R(&]B:F5C=`T*("HO#0HD1TQ/0D%,4ULG
M7U!%05)?0V]N9FEG7VEN<W1A;F-E)UT@/2!N=6QL.PT*:68@*"%D969I;F5D
M*"=014%27TE.4U1!3$Q?1$E2)RD@?'P@(5!%05)?24Y35$%,3%]$25(I('L-
M"B`@("`D4$5!4E])3E-404Q,7T1)4B`](%!(4%],24)$25(@+B!$25)%0U1/
M4EE?4T5005)!5$]2("X@)W!E87(G.PT*?2!E;'-E('L-"B`@("`D4$5!4E])
M3E-404Q,7T1)4B`](%!%05)?24Y35$%,3%]$25([#0I]#0H-"B\O($)E;&]W
M('=E(&1E9FEN92!C;VYS=&%N=',@=VET:"!D969A=6QT('9A;'5E<R!F;W(@
M86QL(&-O;F9I9W5R871I;VX-"B\O('!A<F%M971E<G,@97AC97!T('5S97)N
M86UE+W!A<W-W;W)D+B`@06QL(&]F('1H96T@8V%N(&AA=F4@=&AE:7(-"B\O
M(&1E9F%U;'1S('-E="!T:')O=6=H(&5N=FER;VYM96YT('9A<FEA8FQE<RX@
M(%1H92!R96%S;VX@=V4@=7-E('1H90T*+R\@4$A07R!P<F5F:7@@:7,@9F]R
M('-O;64@<V5C=7)I='DL(%!(4"!P<F]T96-T<R!E;G9I<F]N;65N=`T*+R\@
M=F%R:6%B;&5S('-T87)T:6YG('=I=&@@4$A07RHN#0H-"B\O(&1E9F%U;'0@
M8VAA;FYE;"!A;F0@<')E9F5R<F5D(&UI<G)O<B!I<R!B87-E9"!O;B!W:&5T
M:&5R('=E(&%R92!I;G9O:V5D('1H<F]U9V@-"B\O('1H92`B<&5A<B(@;W(@
M=&AE(")P96-L(B!C;VUM86YD#0H-"FEF("@A9&5F:6YE9"@G4$5!4E]254Y4
M65!%)RD@?'P@4$5!4E]254Y465!%(#T]("=P96%R)RD@>PT*("`@(&1E9FEN
M92@G4$5!4E]#3TY&24=?1$5&055,5%]#2$%.3D5,)RP@)W!E87(N<&AP+FYE
M="<I.PT*?2!E;'-E('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%5
M3%1?0TA!3DY%3"<L("=P96-L+G!H<"YN970G*3L-"GT-"@T*:68@*&=E=&5N
M=B@G4$A07U!%05)?4UE30T].1E]$25(G*2D@>PT*("`@(&1E9FEN92@G4$5!
M4E]#3TY&24=?4UE30T].1D1)4B<L(&=E=&5N=B@G4$A07U!%05)?4UE30T].
M1E]$25(G*2D[#0I](&5L<V5I9B`H9V5T96YV*"=3>7-T96U2;V]T)RDI('L-
M"B`@("!D969I;F4H)U!%05)?0T].1DE'7U-94T-/3D9$25(G+"!G971E;G8H
M)U-Y<W1E;5)O;W0G*2D[#0I](&5L<V4@>PT*("`@(&1E9FEN92@G4$5!4E]#
M3TY&24=?4UE30T].1D1)4B<L(%!(4%]365-#3TY&1$E2*3L-"GT-"@T*+R\@
M1&5F875L="!F;W(@;6%S=&5R7W-E<G9E<@T*:68@*&=E=&5N=B@G4$A07U!%
M05)?34%35$527U-%4E9%4B<I*2![#0H@("`@9&5F:6YE*"=014%27T-/3D9)
M1U]$149!54Q47TU!4U1%4E]315)615(G+"!G971E;G8H)U!(4%]014%27TU!
M4U1%4E]315)615(G*2D[#0I](&5L<V4@>PT*("`@(&1E9FEN92@G4$5!4E]#
M3TY&24=?1$5&055,5%]-05-415)?4T525D52)RP@)W!E87(N<&AP+FYE="<I
M.PT*?0T*#0HO+R!$969A=6QT(&9O<B!H='1P7W!R;WAY#0II9B`H9V5T96YV
M*"=02%!?4$5!4E](5%107U!23UA9)RDI('L-"B`@("!D969I;F4H)U!%05)?
M0T].1DE'7T1%1D%53%1?2%144%]04D]862<L(&=E=&5N=B@G4$A07U!%05)?
M2%144%]04D]862<I*3L-"GT@96QS96EF("AG971E;G8H)VAT='!?<')O>'DG
M*2D@>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%](5%107U!2
M3UA9)RP@9V5T96YV*"=H='1P7W!R;WAY)RDI.PT*?2!E;'-E('L-"B`@("!D
M969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?2%144%]04D]862<L("<G*3L-
M"GT-"@T*+R\@1&5F875L="!F;W(@<&AP7V1I<@T*:68@*&=E=&5N=B@G4$A0
M7U!%05)?24Y35$%,3%]$25(G*2D@>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&
M24=?1$5&055,5%]02%!?1$E2)RP@9V5T96YV*"=02%!?4$5!4E])3E-404Q,
M7T1)4B<I*3L-"GT@96QS92![#0H@("`@:68@*$!I<U]D:7(H)%!%05)?24Y3
M5$%,3%]$25(I*2![#0H@("`@("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&
M055,5%]02%!?1$E2)RP-"B`@("`@("`@("`@("`@("1014%27TE.4U1!3$Q?
M1$E2*3L-"B`@("!](&5L<V4@>PT*("`@("`@("!D969I;F4H)U!%05)?0T].
M1DE'7T1%1D%53%1?4$A07T1)4B<L("1014%27TE.4U1!3$Q?1$E2*3L-"B`@
M("!]#0I]#0H-"B\O($1E9F%U;'0@9F]R(&5X=%]D:7(-"FEF("AG971E;G8H
M)U!(4%]014%27T585$5.4TE/3E]$25(G*2D@>PT*("`@(&1E9FEN92@G4$5!
M4E]#3TY&24=?1$5&055,5%]%6%1?1$E2)RP@9V5T96YV*"=02%!?4$5!4E]%
M6%1%3E-)3TY?1$E2)RDI.PT*?2!E;'-E('L-"B`@("!I9B`H:6YI7V=E="@G
M97AT96YS:6]N7V1I<B<I*2![#0H@("`@("`@(&1E9FEN92@G4$5!4E]#3TY&
M24=?1$5&055,5%]%6%1?1$E2)RP@:6YI7V=E="@G97AT96YS:6]N7V1I<B<I
M*3L-"B`@("!](&5L<V5I9B`H9&5F:6YE9"@G4$5!4E]%6%1%3E-)3TY?1$E2
M)RD@)B8@0&ES7V1I<BA014%27T585$5.4TE/3E]$25(I*2![#0H@("`@("`@
M(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]%6%1?1$E2)RP@4$5!4E]%
M6%1%3E-)3TY?1$E2*3L-"B`@("!](&5L<V5I9B`H9&5F:6YE9"@G4$A07T58
M5$5.4TE/3E]$25(G*2D@>PT*("`@("`@("!D969I;F4H)U!%05)?0T].1DE'
M7T1%1D%53%1?15A47T1)4B<L(%!(4%]%6%1%3E-)3TY?1$E2*3L-"B`@("!]
M(&5L<V4@>PT*("`@("`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?
M15A47T1)4B<L("<N)RD[#0H@("`@?0T*?0T*#0HO+R!$969A=6QT(&9O<B!D
M;V-?9&ER#0II9B`H9V5T96YV*"=02%!?4$5!4E]$3T-?1$E2)RDI('L-"B`@
M("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?1$]#7T1)4B<L(&=E=&5N
M=B@G4$A07U!%05)?1$]#7T1)4B<I*3L-"GT@96QS92![#0H@("`@9&5F:6YE
M*"=014%27T-/3D9)1U]$149!54Q47T1/0U]$25(G+`T*("`@("`@("`@("`D
M4$5!4E])3E-404Q,7T1)4BY$25)%0U1/4EE?4T5005)!5$]2+B=D;V-S)RD[
M#0I]#0H-"B\O($1E9F%U;'0@9F]R(&)I;E]D:7(-"FEF("AG971E;G8H)U!(
M4%]014%27T))3E]$25(G*2D@>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?
M1$5&055,5%]"24Y?1$E2)RP@9V5T96YV*"=02%!?4$5!4E]"24Y?1$E2)RDI
M.PT*?2!E;'-E('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?
M0DE.7T1)4B<L(%!(4%]"24Y$25(I.PT*?0T*#0HO+R!$969A=6QT(&9O<B!D
M871A7V1I<@T*:68@*&=E=&5N=B@G4$A07U!%05)?1$%405]$25(G*2D@>PT*
M("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]$051!7T1)4B<L(&=E
M=&5N=B@G4$A07U!%05)?1$%405]$25(G*2D[#0I](&5L<V4@>PT*("`@(&1E
M9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]$051!7T1)4B<L#0H@("`@("`@
M("`@("1014%27TE.4U1!3$Q?1$E2+D1)4D5#5$]265]315!!4D%43U(N)V1A
M=&$G*3L-"GT-"@T*+R\@1&5F875L="!F;W(@=&5S=%]D:7(-"FEF("AG971E
M;G8H)U!(4%]014%27U1%4U1?1$E2)RDI('L-"B`@("!D969I;F4H)U!%05)?
M0T].1DE'7T1%1D%53%1?5$535%]$25(G+"!G971E;G8H)U!(4%]014%27U1%
M4U1?1$E2)RDI.PT*?2!E;'-E('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'
M7T1%1D%53%1?5$535%]$25(G+`T*("`@("`@("`@("`D4$5!4E])3E-404Q,
M7T1)4BY$25)%0U1/4EE?4T5005)!5$]2+B=T97-T<R<I.PT*?0T*#0HO+R!$
M969A=6QT(&9O<B!C86-H95]D:7(-"FEF("AG971E;G8H)U!(4%]014%27T-!
M0TA%7T1)4B<I*2![#0H@("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q4
M7T-!0TA%7T1)4B<L(&=E=&5N=B@G4$A07U!%05)?0T%#2$5?1$E2)RDI.PT*
M?2!E;'-E('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?0T%#
M2$5?1$E2)RP-"B`@("`@("`@("`@4WES=&5M.CIT;7!D:7(H*2`N($1)4D5#
M5$]265]315!!4D%43U(@+B`G<&5A<B<@+@T*("`@("`@("`@("!$25)%0U1/
M4EE?4T5005)!5$]2("X@)V-A8VAE)RD[#0I]#0H-"B\O($1E9F%U;'0@9F]R
M('!H<%]B:6X-"FEF("AG971E;G8H)U!(4%]014%27U!(4%]"24XG*2D@>PT*
M("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]02%!?0DE.)RP@9V5T
M96YV*"=02%!?4$5!4E]02%!?0DE.)RDI.PT*?2!E;'-E('L-"B`@("!D969I
M;F4H)U!%05)?0T].1DE'7T1%1D%53%1?4$A07T))3B<L(%!%05)?0T].1DE'
M7T1%1D%53%1?0DE.7T1)4BX-"B`@("`@("`@("`@1$E214-43U)97U-%4$%2
M051/4BXG<&AP)RXH3U-?5TE.1$]74R`_("<N97AE)R`Z("<G*2D[#0I]#0H-
M"B\O($1E9F%U;'0@9F]R('9E<F)O<V4-"FEF("AG971E;G8H)U!(4%]014%2
M7U9%4D)/4T4G*2D@>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,
M5%]615)"3U-%)RP@9V5T96YV*"=02%!?4$5!4E]615)"3U-%)RDI.PT*?2!E
M;'-E('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?5D520D]3
M12<L(#$I.PT*?0T*#0HO+R!$969A=6QT(&9O<B!P<F5F97)R961?<W1A=&4-
M"FEF("AG971E;G8H)U!(4%]014%27U!2149%4E)%1%]35$%412<I*2![#0H@
M("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q47U!2149%4E)%1%]35$%4
M12<L(&=E=&5N=B@G4$A07U!%05)?4%)%1D524D5$7U-4051%)RDI.PT*?2!E
M;'-E('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?4%)%1D52
M4D5$7U-4051%)RP@)W-T86)L92<I.PT*?0T*#0HO+R!$969A=6QT(&9O<B!U
M;6%S:PT*:68@*&=E=&5N=B@G4$A07U!%05)?54U!4TLG*2D@>PT*("`@(&1E
M9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]534%32R<L(&=E=&5N=B@G4$A0
M7U!%05)?54U!4TLG*2D[#0I](&5L<V4@>PT*("`@(&1E9FEN92@G4$5!4E]#
M3TY&24=?1$5&055,5%]534%32R<L(&1E8V]C="AU;6%S:R@I*2D[#0I]#0H-
M"B\O($1E9F%U;'0@9F]R(&-A8VAE7W1T;`T*:68@*&=E=&5N=B@G4$A07U!%
M05)?0T%#2$5?5%1,)RDI('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%
M1D%53%1?0T%#2$5?5%1,)RP@9V5T96YV*"=02%!?4$5!4E]#04-(15]45$PG
M*2D[#0I](&5L<V4@>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,
M5%]#04-(15]45$PG+"`S-C`P*3L-"GT-"@T*+R\@1&5F875L="!F;W(@<VEG
M7W1Y<&4-"FEF("AG971E;G8H)U!(4%]014%27U-)1U]465!%)RDI('L-"B`@
M("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?4TE'7U194$4G+"!G971E
M;G8H)U!(4%]014%27U-)1U]465!%)RDI.PT*?2!E;'-E('L-"B`@("!D969I
M;F4H)U!%05)?0T].1DE'7T1%1D%53%1?4TE'7U194$4G+"`G9W!G)RD[#0I]
M#0H-"B\O($1E9F%U;'0@9F]R('-I9U]B:6X-"FEF("AG971E;G8H)U!(4%]0
M14%27U-)1U]"24XG*2D@>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&
M055,5%]324=?0DE.)RP@9V5T96YV*"=02%!?4$5!4E]324=?0DE.)RDI.PT*
M?2!E;'-E('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?4TE'
M7T))3B<L#0H@("`@("`@("`@(%-Y<W1E;3HZ=VAI8V@H#0H@("`@("`@("`@
M("`@("`G9W!G)RP@3U-?5TE.1$]74R`_("=C.EQG;G5P9UQG<&<N97AE)R`Z
M("<O=7-R+VQO8V%L+V)I;B]G<&<G*2D[#0I]#0H-"B\O($1E9F%U;'0@9F]R
M('-I9U]K97ED:7(-"FEF("AG971E;G8H)U!(4%]014%27U-)1U]+15E$25(G
M*2D@>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]324=?2T59
M1$E2)RP@9V5T96YV*"=02%!?4$5!4E]324=?2T591$E2)RDI.PT*?2!E;'-E
M('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?4TE'7TM%641)
M4B<L#0H@("`@("`@("`@(%!%05)?0T].1DE'7U-94T-/3D9$25(@+B!$25)%
M0U1/4EE?4T5005)!5$]2("X@)W!E87)K97ES)RD[#0I]#0H-"B\J*@T*("H@
M5&AI<R!I<R!A(&-L87-S(&9O<B!S=&]R:6YG(&-O;F9I9W5R871I;VX@9&%T
M82P@:V5E<&EN9R!T<F%C:R!O9@T*("H@=VAI8V@@87)E('-Y<W1E;2UD969I
M;F5D+"!U<V5R+61E9FEN960@;W(@9&5F875L=&5D+@T*("H@0&-A=&5G;W)Y
M("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@
M4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@1W)E
M9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY
M-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*
M("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@
M("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*
M8VQA<W,@4$5!4E]#;VYF:6<@97AT96YD<R!014%2#0I[#0H@("`@+R\@>WM[
M('!R;W!E<G1I97,-"@T*("`@("\J*@T*("`@("`J($%R<F%Y(&]F(&-O;F9I
M9R!F:6QE<R!U<V5D+@T*("`@("`J#0H@("`@("H@0'9A<B!A<G)A>2!L87EE
M<B`]/B!C;VYF:6<@9FEL90T*("`@("`J+PT*("`@('9A<B`D9FEL97,@/2!A
M<G)A>2@-"B`@("`@("`@)W-Y<W1E;2<@/3X@)R<L#0H@("`@("`@("=U<V5R
M)R`]/B`G)RP-"B`@("`@("`@*3L-"@T*("`@('9A<B`D;&%Y97)S(#T@87)R
M87DH*3L-"B`@("`-"B`@("`O*BH-"B`@("`@*B!#;VYF:6=U<F%T:6]N(&1A
M=&$L('1W;RUD:6UE;G-I;VYA;"!A<G)A>2!W:&5R92!T:&4@9FER<W0-"B`@
M("`@*B!D:6UE;G-I;VX@:7,@=&AE(&-O;F9I9R!L87EE<B`H)W5S97(G+"`G
M<WES=&5M)R!A;F0@)V1E9F%U;'0G*2P-"B`@("`@*B!A;F0@=&AE('-E8V]N
M9"!D:6UE;G-I;VX@:7,@:V5Y;F%M92`]/B!V86QU92X-"B`@("`@*@T*("`@
M("`J(%1H92!O<F1E<B!I;B!T:&4@9FER<W0@9&EM96YS:6]N(&ES(&EM<&]R
M=&%N="$@($5A<FQI97(-"B`@("`@*B!L87EE<G,@=VEL;"!S:&%D;W<@;&%T
M97(@;VYE<R!W:&5N(&$@8V]N9FEG('9A;'5E(&ES#0H@("`@("H@<F5Q=65S
M=&5D("AI9B!A("=U<V5R)R!V86QU92!E>&ES=',L(&ET('=I;&P@8F4@<F5T
M=7)N960@9FER<W0L#0H@("`@("H@=&AE;B`G<WES=&5M)R!A;F0@9FEN86QL
M>2`G9&5F875L="<I+@T*("`@("`J#0H@("`@("H@0'9A<B!A<G)A>2!L87EE
M<B`]/B!A<G)A>2AK97EN86UE(#T^('9A;'5E+"`N+BXI#0H@("`@("HO#0H@
M("`@=F%R("1C;VYF:6=U<F%T:6]N(#T@87)R87DH#0H@("`@("`@("=U<V5R
M)R`]/B!A<G)A>2@I+`T*("`@("`@("`G<WES=&5M)R`]/B!A<G)A>2@I+`T*
M("`@("`@("`G9&5F875L="<@/3X@87)R87DH*2P-"B`@("`@("`@*3L-"B`@
M("`-"B`@("`O*BH-"B`@("`@*B!#;VYF:6=U<F%T:6]N('9A;'5E<R!T:&%T
M(&-A;B!B92!S970@9F]R(&$@8VAA;FYE;`T*("`@("`J#0H@("`@("H@06QL
M(&]T:&5R(&-O;F9I9W5R871I;VX@=F%L=65S(&-A;B!O;FQY(&AA=F4@82!G
M;&]B86P@=F%L=64-"B`@("`@*B!`=F%R(&%R<F%Y#0H@("`@("H@0&%C8V5S
M<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?8VAA;FYE;$-O;F9I9TEN
M9F\@/2!A<G)A>2@-"B`@("`@("`@)W!H<%]D:7(G+"`G97AT7V1I<B<L("=D
M;V-?9&ER)RP@)V)I;E]D:7(G+"`G9&%T85]D:7(G+`T*("`@("`@("`G=&5S
M=%]D:7(G+"`G<&AP7V)I;B<L("=U<V5R;F%M92<L("=P87-S=V]R9"<L("=V
M97)B;W-E)RP-"B`@("`@("`@)W!R969E<G)E9%]S=&%T92<L("=U;6%S:R<L
M("=P<F5F97)R961?;6ER<F]R)RP-"B`@("`@("`@*3L-"@T*("`@("\J*@T*
M("`@("`J($-H86YN96QS('1H870@8V%N(&)E(&%C8V5S<V5D#0H@("`@("H@
M0'-E92!S971#:&%N;F5L<R@I#0H@("`@("H@0'9A<B!A<G)A>0T*("`@("`J
M($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7V-H86YN96QS
M(#T@87)R87DH)W!E87(N<&AP+FYE="<L("=P96-L+G!H<"YN970G+"`G7U]U
M<FDG*3L-"@T*("`@("\J*@T*("`@("`J(%1H:7,@=F%R:6%B;&4@:7,@=7-E
M9"!T;R!C;VYT<F]L('1H92!D:7)E8W1O<GD@=F%L=65S(')E='5R;F5D#0H@
M("`@("H@0'-E92!S971);G-T86QL4F]O="@I.PT*("`@("`J($!V87(@<W1R
M:6YG?&9A;'-E#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@
M("`@=F%R("1?:6YS=&%L;%)O;W0@/2!F86QS93L-"@T*("`@("\J*@T*("`@
M("`J($EF(')E<75E<W1E9"P@=&AI<R!W:6QL(&%L=V%Y<R!R969E<B!T;R!T
M:&4@<F5G:7-T<GD-"B`@("`@*B!C;VYT86EN960@:6X@<&AP7V1I<@T*("`@
M("`J($!V87(@4$5!4E]296=I<W1R>0T*("`@("`J+PT*("`@('9A<B`D7W)E
M9VES=')Y(#T@87)R87DH*3L-"@T*("`@("\J*@T*("`@("`J($!V87(@87)R
M87D-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@
M)%]R96=);FET:6%L:7IE9"`](&%R<F%Y*"D[#0H-"B`@("`O*BH-"B`@("`@
M*B!`=F%R(&)O;VP-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-
M"B`@("!V87(@)%]N;U)E9VES=')Y(#T@9F%L<V4[#0H-"B`@("`O*BH-"B`@
M("`@*B!A;6]U;G0@;V8@97)R;W)S(&9O=6YD('=H:6QE('!A<G-I;F<@8V]N
M9FEG#0H@("`@("H@0'9A<B!I;G1E9V5R#0H@("`@("H@0&%C8V5S<R!P<FEV
M871E#0H@("`@("HO#0H@("`@=F%R("1?97)R;W)S1F]U;F0@/2`P.PT*("`@
M('9A<B`D7VQA<W1%<G)O<B`](&YU;&P[#0H-"B`@("`O*BH-"B`@("`@*B!)
M;F9O<FUA=&EO;B!A8F]U="!T:&4@8V]N9FEG=7)A=&EO;B!D871A+B`@4W1O
M<F5S('1H92!T>7!E+`T*("`@("`J(&1E9F%U;'0@=F%L=64@86YD(&$@9&]C
M=6UE;G1A=&EO;B!S=')I;F<@9F]R(&5A8V@@8V]N9FEG=7)A=&EO;@T*("`@
M("`J('9A;'5E+@T*("`@("`J#0H@("`@("H@0'9A<B!A<G)A>2!L87EE<B`]
M/B!A<G)A>2AI;F9O='EP92`]/B!V86QU92P@+BXN*0T*("`@("`J+PT*("`@
M('9A<B`D8V]N9FEG=7)A=&EO;E]I;F9O(#T@87)R87DH#0H@("`@("`@("\O
M($-H86YN96QS+TEN=&5R;F5T($%C8V5S<PT*("`@("`@("`G9&5F875L=%]C
M:&%N;F5L)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=T>7!E)R`]/B`G<W1R
M:6YG)RP-"B`@("`@("`@("`@("=D969A=6QT)R`]/B!014%27T-/3D9)1U]$
M149!54Q47T-(04Y.14PL#0H@("`@("`@("`@("`G9&]C)R`]/B`G=&AE(&1E
M9F%U;'0@8VAA;FYE;"!T;R!U<V4@9F]R(&%L;"!N;VX@97AP;&EC:70@8V]M
M;6%N9',G+`T*("`@("`@("`@("`@)W!R;VUP="<@/3X@)T1E9F%U;'0@0VAA
M;FYE;"<L#0H@("`@("`@("`@("`G9W)O=7`G(#T^("=);G1E<FYE="!!8V-E
M<W,G+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@)W!R969E<G)E9%]M:7)R
M;W(G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W1Y<&4G(#T^("=S=')I;F<G
M+`T*("`@("`@("`@("`@)V1E9F%U;'0G(#T^(%!%05)?0T].1DE'7T1%1D%5
M3%1?0TA!3DY%3"P-"B`@("`@("`@("`@("=D;V,G(#T^("=T:&4@9&5F875L
M="!S97)V97(@;W(@;6ER<F]R('1O('5S92!F;W(@8VAA;FYE;"!A8W1I;VYS
M)RP-"B`@("`@("`@("`@("=P<F]M<'0G(#T^("=$969A=6QT($-H86YN96P@
M36ER<F]R)RP-"B`@("`@("`@("`@("=G<F]U<"<@/3X@)TEN=&5R;F5T($%C
M8V5S<R<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`G<F5M;W1E7V-O;F9I
M9R<@/3X@87)R87DH#0H@("`@("`@("`@("`G='EP92<@/3X@)W!A<W-W;W)D
M)RP-"B`@("`@("`@("`@("=D969A=6QT)R`]/B`G)RP-"B`@("`@("`@("`@
M("=D;V,G(#T^("=F='`@=7)L(&]F(')E;6]T92!C;VYF:6=U<F%T:6]N(&9I
M;&4@=&\@=7-E(&9O<B!S>6YC:')O;FEZ960@:6YS=&%L;"<L#0H@("`@("`@
M("`@("`G<')O;7!T)R`]/B`G4F5M;W1E($-O;F9I9W5R871I;VX@1FEL92<L
M#0H@("`@("`@("`@("`G9W)O=7`G(#T^("=);G1E<FYE="!!8V-E<W,G+`T*
M("`@("`@("`@("`@*2P-"B`@("`@("`@)V%U=&]?9&ES8V]V97(G(#T^(&%R
M<F%Y*`T*("`@("`@("`@("`@)W1Y<&4G(#T^("=I;G1E9V5R)RP-"B`@("`@
M("`@("`@("=D969A=6QT)R`]/B`P+`T*("`@("`@("`@("`@)V1O8R<@/3X@
M)W=H971H97(@=&\@875T;VUA=&EC86QL>2!D:7-C;W9E<B!N97<@8VAA;FYE
M;',G+`T*("`@("`@("`@("`@)W!R;VUP="<@/3X@)T%U=&\M9&ES8V]V97(@
M;F5W($-H86YN96QS)RP-"B`@("`@("`@("`@("=G<F]U<"<@/3X@)TEN=&5R
M;F5T($%C8V5S<R<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`O+R!);G1E
M<FYE="!!8V-E<W,-"B`@("`@("`@)VUA<W1E<E]S97)V97(G(#T^(&%R<F%Y
M*`T*("`@("`@("`@("`@)W1Y<&4G(#T^("=S=')I;F<G+`T*("`@("`@("`@
M("`@)V1E9F%U;'0G(#T^("=P96%R+G!H<"YN970G+`T*("`@("`@("`@("`@
M)V1O8R<@/3X@)VYA;64@;V8@=&AE(&UA:6X@4$5!4B!S97)V97(@6TY/5"!5
M4T5$($E.(%1(25,@5D524TE/3ETG+`T*("`@("`@("`@("`@)W!R;VUP="<@
M/3X@)U!%05(@<V5R=F5R(%M$15!214-!5$5$72<L#0H@("`@("`@("`@("`G
M9W)O=7`G(#T^("=);G1E<FYE="!!8V-E<W,G+`T*("`@("`@("`@("`@*2P-
M"B`@("`@("`@)VAT='!?<')O>'DG(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=S=')I;F<G+`T*("`@("`@("`@("`@)V1E9F%U;'0G(#T^
M(%!%05)?0T].1DE'7T1%1D%53%1?2%144%]04D]862P-"B`@("`@("`@("`@
M("=D;V,G(#T^("=(5%10('!R;WAY("AH;W-T.G!O<G0I('1O('5S92!W:&5N
M(&1O=VYL;V%D:6YG('!A8VMA9V5S)RP-"B`@("`@("`@("`@("=P<F]M<'0G
M(#T^("=(5%10(%!R;WAY(%-E<G9E<B!!9&1R97-S)RP-"B`@("`@("`@("`@
M("=G<F]U<"<@/3X@)TEN=&5R;F5T($%C8V5S<R<L#0H@("`@("`@("`@("`I
M+`T*("`@("`@("`O+R!&:6QE($QO8V%T:6]N<PT*("`@("`@("`G<&AP7V1I
M<B<@/3X@87)R87DH#0H@("`@("`@("`@("`G='EP92<@/3X@)V1I<F5C=&]R
M>2<L#0H@("`@("`@("`@("`G9&5F875L="<@/3X@4$5!4E]#3TY&24=?1$5&
M055,5%]02%!?1$E2+`T*("`@("`@("`@("`@)V1O8R<@/3X@)V1I<F5C=&]R
M>2!W:&5R92`N<&AP(&9I;&5S(&%R92!I;G-T86QL960G+`T*("`@("`@("`@
M("`@)W!R;VUP="<@/3X@)U!%05(@9&ER96-T;W)Y)RP-"B`@("`@("`@("`@
M("=G<F]U<"<@/3X@)T9I;&4@3&]C871I;VYS)RP-"B`@("`@("`@("`@("DL
M#0H@("`@("`@("=E>'1?9&ER)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=T
M>7!E)R`]/B`G9&ER96-T;W)Y)RP-"B`@("`@("`@("`@("=D969A=6QT)R`]
M/B!014%27T-/3D9)1U]$149!54Q47T585%]$25(L#0H@("`@("`@("`@("`G
M9&]C)R`]/B`G9&ER96-T;W)Y('=H97)E(&QO861A8FQE(&5X=&5N<VEO;G,@
M87)E(&EN<W1A;&QE9"<L#0H@("`@("`@("`@("`G<')O;7!T)R`]/B`G4$A0
M(&5X=&5N<VEO;B!D:7)E8W1O<GDG+`T*("`@("`@("`@("`@)V=R;W5P)R`]
M/B`G1FEL92!,;V-A=&EO;G,G+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@
M)V1O8U]D:7(G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W1Y<&4G(#T^("=D
M:7)E8W1O<GDG+`T*("`@("`@("`@("`@)V1E9F%U;'0G(#T^(%!%05)?0T].
M1DE'7T1%1D%53%1?1$]#7T1)4BP-"B`@("`@("`@("`@("=D;V,G(#T^("=D
M:7)E8W1O<GD@=VAE<F4@9&]C=6UE;G1A=&EO;B!I<R!I;G-T86QL960G+`T*
M("`@("`@("`@("`@)W!R;VUP="<@/3X@)U!%05(@9&]C=6UE;G1A=&EO;B!D
M:7)E8W1O<GDG+`T*("`@("`@("`@("`@)V=R;W5P)R`]/B`G1FEL92!,;V-A
M=&EO;G,G+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@)V)I;E]D:7(G(#T^
M(&%R<F%Y*`T*("`@("`@("`@("`@)W1Y<&4G(#T^("=D:7)E8W1O<GDG+`T*
M("`@("`@("`@("`@)V1E9F%U;'0G(#T^(%!%05)?0T].1DE'7T1%1D%53%1?
M0DE.7T1)4BP-"B`@("`@("`@("`@("=D;V,G(#T^("=D:7)E8W1O<GD@=VAE
M<F4@97AE8W5T86)L97,@87)E(&EN<W1A;&QE9"<L#0H@("`@("`@("`@("`G
M<')O;7!T)R`]/B`G4$5!4B!E>&5C=71A8FQE<R!D:7)E8W1O<GDG+`T*("`@
M("`@("`@("`@)V=R;W5P)R`]/B`G1FEL92!,;V-A=&EO;G,G+`T*("`@("`@
M("`@("`@*2P-"B`@("`@("`@)V1A=&%?9&ER)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("=T>7!E)R`]/B`G9&ER96-T;W)Y)RP-"B`@("`@("`@("`@("=D
M969A=6QT)R`]/B!014%27T-/3D9)1U]$149!54Q47T1!5$%?1$E2+`T*("`@
M("`@("`@("`@)V1O8R<@/3X@)V1I<F5C=&]R>2!W:&5R92!D871A(&9I;&5S
M(&%R92!I;G-T86QL960G+`T*("`@("`@("`@("`@)W!R;VUP="<@/3X@)U!%
M05(@9&%T82!D:7)E8W1O<GDG+`T*("`@("`@("`@("`@)V=R;W5P)R`]/B`G
M1FEL92!,;V-A=&EO;G,@*$%D=F%N8V5D*2<L#0H@("`@("`@("`@("`I+`T*
M("`@("`@("`G=&5S=%]D:7(G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W1Y
M<&4G(#T^("=D:7)E8W1O<GDG+`T*("`@("`@("`@("`@)V1E9F%U;'0G(#T^
M(%!%05)?0T].1DE'7T1%1D%53%1?5$535%]$25(L#0H@("`@("`@("`@("`G
M9&]C)R`]/B`G9&ER96-T;W)Y('=H97)E(')E9W)E<W-I;VX@=&5S=',@87)E
M(&EN<W1A;&QE9"<L#0H@("`@("`@("`@("`G<')O;7!T)R`]/B`G4$5!4B!T
M97-T(&1I<F5C=&]R>2<L#0H@("`@("`@("`@("`G9W)O=7`G(#T^("=&:6QE
M($QO8V%T:6]N<R`H061V86YC960I)RP-"B`@("`@("`@("`@("DL#0H@("`@
M("`@("=C86-H95]D:7(G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W1Y<&4G
M(#T^("=D:7)E8W1O<GDG+`T*("`@("`@("`@("`@)V1E9F%U;'0G(#T^(%!%
M05)?0T].1DE'7T1%1D%53%1?0T%#2$5?1$E2+`T*("`@("`@("`@("`@)V1O
M8R<@/3X@)V1I<F5C=&]R>2!W:&EC:"!I<R!U<V5D(&9O<B!834Q24$,@8V%C
M:&4G+`T*("`@("`@("`@("`@)W!R;VUP="<@/3X@)U!%05(@26YS=&%L;&5R
M(&-A8VAE(&1I<F5C=&]R>2<L#0H@("`@("`@("`@("`G9W)O=7`G(#T^("=&
M:6QE($QO8V%T:6]N<R`H061V86YC960I)RP-"B`@("`@("`@("`@("DL#0H@
M("`@("`@("=P:'!?8FEN)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=T>7!E
M)R`]/B`G9FEL92<L#0H@("`@("`@("`@("`G9&5F875L="<@/3X@4$5!4E]#
M3TY&24=?1$5&055,5%]02%!?0DE.+`T*("`@("`@("`@("`@)V1O8R<@/3X@
M)U!(4"!#3$DO0T=)(&)I;F%R>2!F;W(@97AE8W5T:6YG('-C<FEP=',G+`T*
M("`@("`@("`@("`@)W!R;VUP="<@/3X@)U!(4"!#3$DO0T=)(&)I;F%R>2<L
M#0H@("`@("`@("`@("`G9W)O=7`G(#T^("=&:6QE($QO8V%T:6]N<R`H061V
M86YC960I)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@("\O($UA:6YT86EN
M97)S#0H@("`@("`@("=U<V5R;F%M92<@/3X@87)R87DH#0H@("`@("`@("`@
M("`G='EP92<@/3X@)W-T<FEN9R<L#0H@("`@("`@("`@("`G9&5F875L="<@
M/3X@)R<L#0H@("`@("`@("`@("`G9&]C)R`]/B`G*&UA:6YT86EN97)S*2!Y
M;W5R(%!%05(@86-C;W5N="!N86UE)RP-"B`@("`@("`@("`@("=P<F]M<'0G
M(#T^("=014%2('5S97)N86UE("AF;W(@;6%I;G1A:6YE<G,I)RP-"B`@("`@
M("`@("`@("=G<F]U<"<@/3X@)TUA:6YT86EN97)S)RP-"B`@("`@("`@("`@
M("DL#0H@("`@("`@("=P87-S=V]R9"<@/3X@87)R87DH#0H@("`@("`@("`@
M("`G='EP92<@/3X@)W!A<W-W;W)D)RP-"B`@("`@("`@("`@("=D969A=6QT
M)R`]/B`G)RP-"B`@("`@("`@("`@("=D;V,G(#T^("<H;6%I;G1A:6YE<G,I
M('EO=7(@4$5!4B!A8V-O=6YT('!A<W-W;W)D)RP-"B`@("`@("`@("`@("=P
M<F]M<'0G(#T^("=014%2('!A<W-W;W)D("AF;W(@;6%I;G1A:6YE<G,I)RP-
M"B`@("`@("`@("`@("=G<F]U<"<@/3X@)TUA:6YT86EN97)S)RP-"B`@("`@
M("`@("`@("DL#0H@("`@("`@("\O($%D=F%N8V5D#0H@("`@("`@("=V97)B
M;W-E)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=T>7!E)R`]/B`G:6YT96=E
M<B<L#0H@("`@("`@("`@("`G9&5F875L="<@/3X@4$5!4E]#3TY&24=?1$5&
M055,5%]615)"3U-%+`T*("`@("`@("`@("`@)V1O8R<@/3X@)W9E<F)O<VET
M>2!L979E;`T*,#H@<F5A;&QY('%U:65T#0HQ.B!S;VUE=VAA="!Q=6EE=`T*
M,CH@=F5R8F]S90T*,SH@9&5B=6<G+`T*("`@("`@("`@("`@)W!R;VUP="<@
M/3X@)T1E8G5G($QO9R!,979E;"<L#0H@("`@("`@("`@("`G9W)O=7`G(#T^
M("=!9'9A;F-E9"<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`G<')E9F5R
M<F5D7W-T871E)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=T>7!E)R`]/B`G
M<V5T)RP-"B`@("`@("`@("`@("=D969A=6QT)R`]/B!014%27T-/3D9)1U]$
M149!54Q47U!2149%4E)%1%]35$%412P-"B`@("`@("`@("`@("=D;V,G(#T^
M("=T:&4@:6YS=&%L;&5R('=I;&P@<')E9F5R(')E;&5A<V5S('=I=&@@=&AI
M<R!S=&%T92!W:&5N(&EN<W1A;&QI;F<@<&%C:V%G97,@=VET:&]U="!A('9E
M<G-I;VX@;W(@<W1A=&4@<W!E8VEF:65D)RP-"B`@("`@("`@("`@("=V86QI
M9%]S970G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=S=&%B;&4G+"`G
M8F5T82<L("=A;'!H82<L("=D979E;"<L("=S;F%P<VAO="<I+`T*("`@("`@
M("`@("`@)W!R;VUP="<@/3X@)U!R969E<G)E9"!086-K86=E(%-T871E)RP-
M"B`@("`@("`@("`@("=G<F]U<"<@/3X@)T%D=F%N8V5D)RP-"B`@("`@("`@
M("`@("DL#0H@("`@("`@("=U;6%S:R<@/3X@87)R87DH#0H@("`@("`@("`@
M("`G='EP92<@/3X@)VUA<VLG+`T*("`@("`@("`@("`@)V1E9F%U;'0G(#T^
M(%!%05)?0T].1DE'7T1%1D%53%1?54U!4TLL#0H@("`@("`@("`@("`G9&]C
M)R`]/B`G=6UA<VL@=7-E9"!W:&5N(&-R96%T:6YG(&9I;&5S("A5;FEX+6QI
M:V4@<WES=&5M<R!O;FQY*2<L#0H@("`@("`@("`@("`G<')O;7!T)R`]/B`G
M56YI>"!F:6QE(&UA<VLG+`T*("`@("`@("`@("`@)V=R;W5P)R`]/B`G061V
M86YC960G+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@)V-A8VAE7W1T;"<@
M/3X@87)R87DH#0H@("`@("`@("`@("`G='EP92<@/3X@)VEN=&5G97(G+`T*
M("`@("`@("`@("`@)V1E9F%U;'0G(#T^(%!%05)?0T].1DE'7T1%1D%53%1?
M0T%#2$5?5%1,+`T*("`@("`@("`@("`@)V1O8R<@/3X@)V%M;W5N="!O9B!S
M96-S('=H97)E('1H92!L;V-A;"!C86-H92!I<R!U<V5D(&%N9"!N;W0@=7!D
M871E9"<L#0H@("`@("`@("`@("`G<')O;7!T)R`]/B`G0V%C:&4@5&EM951O
M3&EV92<L#0H@("`@("`@("`@("`G9W)O=7`G(#T^("=!9'9A;F-E9"<L#0H@
M("`@("`@("`@("`I+`T*("`@("`@("`G<VEG7W1Y<&4G(#T^(&%R<F%Y*`T*
M("`@("`@("`@("`@)W1Y<&4G(#T^("=S970G+`T*("`@("`@("`@("`@)V1E
M9F%U;'0G(#T^(%!%05)?0T].1DE'7T1%1D%53%1?4TE'7U194$4L#0H@("`@
M("`@("`@("`G9&]C)R`]/B`G=VAI8V@@<&%C:V%G92!S:6=N871U<F4@;65C
M:&%N:7-M('1O('5S92<L#0H@("`@("`@("`@("`G=F%L:61?<V5T)R`]/B!A
M<G)A>2@G9W!G)RDL#0H@("`@("`@("`@("`G<')O;7!T)R`]/B`G4&%C:V%G
M92!3:6=N871U<F4@5'EP92<L#0H@("`@("`@("`@("`G9W)O=7`G(#T^("=-
M86EN=&%I;F5R<R<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`G<VEG7V)I
M;B<@/3X@87)R87DH#0H@("`@("`@("`@("`G='EP92<@/3X@)W-T<FEN9R<L
M#0H@("`@("`@("`@("`G9&5F875L="<@/3X@4$5!4E]#3TY&24=?1$5&055,
M5%]324=?0DE.+`T*("`@("`@("`@("`@)V1O8R<@/3X@)W=H:6-H('!A8VMA
M9V4@<VEG;F%T=7)E(&UE8VAA;FES;2!T;R!U<V4G+`T*("`@("`@("`@("`@
M)W!R;VUP="<@/3X@)U-I9VYA='5R92!(86YD;&EN9R!0<F]G<F%M)RP-"B`@
M("`@("`@("`@("=G<F]U<"<@/3X@)TUA:6YT86EN97)S)RP-"B`@("`@("`@
M("`@("DL#0H@("`@("`@("=S:6=?:V5Y:60G(#T^(&%R<F%Y*`T*("`@("`@
M("`@("`@)W1Y<&4G(#T^("=S=')I;F<G+`T*("`@("`@("`@("`@)V1E9F%U
M;'0G(#T^("<G+`T*("`@("`@("`@("`@)V1O8R<@/3X@)W=H:6-H(&ME>2!T
M;R!U<V4@9F]R('-I9VYI;F<@=VET:"<L#0H@("`@("`@("`@("`G<')O;7!T
M)R`]/B`G4VEG;F%T=7)E($ME>2!)9"<L#0H@("`@("`@("`@("`G9W)O=7`G
M(#T^("=-86EN=&%I;F5R<R<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`G
M<VEG7VME>61I<B<@/3X@87)R87DH#0H@("`@("`@("`@("`G='EP92<@/3X@
M)V1I<F5C=&]R>2<L#0H@("`@("`@("`@("`G9&5F875L="<@/3X@4$5!4E]#
M3TY&24=?1$5&055,5%]324=?2T591$E2+`T*("`@("`@("`@("`@)V1O8R<@
M/3X@)V1I<F5C=&]R>2!W:&5R92!S:6=N871U<F4@:V5Y<R!A<F4@;&]C871E
M9"<L#0H@("`@("`@("`@("`G<')O;7!T)R`]/B`G4VEG;F%T=7)E($ME>2!$
M:7)E8W1O<GDG+`T*("`@("`@("`@("`@)V=R;W5P)R`]/B`G36%I;G1A:6YE
M<G,G+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@+R\@7U]C:&%N;F5L<R!I
M<R!R97-E<G9E9"`M('5S960@9F]R(&-H86YN96PM<W!E8VEF:6,@8V]N9FEG
M=7)A=&EO;@T*("`@("`@("`I.PT*#0H@("`@+R\@?7U]#0H-"B`@("`O+R![
M>WL@4$5!4E]#;VYF:6<H6V9I;&5=+"!;9&5F875L='-?9FEL95TI#0H-"B`@
M("`O*BH-"B`@("`@*B!#;VYS=')U8W1O<BX-"B`@("`@*@T*("`@("`J($!P
M87)A;2!S=')I;F<@9FEL92!T;R!R96%D('5S97(M9&5F:6YE9"!O<'1I;VYS
M(&9R;VT-"B`@("`@*B!`<&%R86T@<W1R:6YG(&9I;&4@=&\@<F5A9"!S>7-T
M96TM=VED92!D969A=6QT<R!F<F]M#0H@("`@("H@0'!A<F%M(&)O;VP@("!D
M971E<FUI;F5S('=H971H97(@82!R96=I<W1R>2!O8FIE8W0@(F9O;&QO=W,B
M#0H@("`@("H@("`@("`@("`@("`@("!T:&4@=F%L=64@;V8@<&AP7V1I<B`H
M:7,@875T;VUA=&EC86QL>2!C<F5A=&5D#0H@("`@("H@("`@("`@("`@("`@
M("!A;F0@;6]V960@=VAE;B!P:'!?9&ER(&ES(&-H86YG960I#0H@("`@("H@
M0'!A<F%M(&)O;VP@("!I9B!T<G5E+"!F86EL<R!I9B!C;VYF:6=U<F%T:6]N
M(&9I;&5S(&-A;FYO="!B92!L;V%D960-"B`@("`@*@T*("`@("`J($!A8V-E
M<W,@<'5B;&EC#0H@("`@("H-"B`@("`@*B!`<V5E(%!%05)?0V]N9FEG.CIS
M:6YG;&5T;VX-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!014%27T-O;F9I9R@D
M=7-E<E]F:6QE(#T@)R<L("1S>7-T96U?9FEL92`]("<G+"`D9G1P7V9I;&4@
M/2!F86QS92P-"B`@("`@("`@("`@("`@("`@("`@("`@("`D<W1R:6-T(#T@
M=')U92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y014%2*"D[#0H@("`@("`@
M(%!%05)?26YS=&%L;&5R7U)O;&4Z.FEN:71I86QI>F5#;VYF:6<H)'1H:7,I
M.PT*("`@("`@("`D<VP@/2!$25)%0U1/4EE?4T5005)!5$]2.PT*("`@("`@
M("!I9B`H96UP='DH)'5S97)?9FEL92DI('L-"B`@("`@("`@("`@(&EF("A/
M4U]724Y$3U=3*2![#0H@("`@("`@("`@("`@("`@)'5S97)?9FEL92`](%!%
M05)?0T].1DE'7U-94T-/3D9$25(@+B`D<VP@+B`G<&5A<BYI;FDG.PT*("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D=7-E<E]F:6QE
M(#T@9V5T96YV*"=(3TU%)RD@+B`D<VP@+B`G+G!E87)R8R<[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&5M<'1Y*"1S>7-T96U?
M9FEL92DI('L-"B`@("`@("`@("`@(&EF("A/4U]724Y$3U=3*2![#0H@("`@
M("`@("`@("`@("`@)'-Y<W1E;5]F:6QE(#T@4$5!4E]#3TY&24=?4UE30T].
M1D1)4B`N("1S;"`N("=P96%R<WES+FEN:2<[#0H@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("1S>7-T96U?9FEL92`](%!%05)?0T].
M1DE'7U-94T-/3D9$25(@+B`D<VP@+B`G<&5A<BYC;VYF)SL-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@("1T:&ES+3YL87EE<G,@/2!A
M<G)A>5]K97ES*"1T:&ES+3YC;VYF:6=U<F%T:6]N*3L-"B`@("`@("`@)'1H
M:7,M/F9I;&5S6R=U<V5R)UT@/2`D=7-E<E]F:6QE.PT*("`@("`@("`D=&AI
M<RT^9FEL97-;)W-Y<W1E;2==(#T@)'-Y<W1E;5]F:6QE.PT*("`@("`@("!I
M9B`H)'5S97)?9FEL92`F)B!`9FEL95]E>&ES=',H)'5S97)?9FEL92DI('L-
M"B`@("`@("`@("`@("1T:&ES+3YP=7-H17)R;W)(86YD;&EN9RA014%27T52
M4D]27U)%5%523BD[#0H@("`@("`@("`@("`D=&AI<RT^<F5A9$-O;F9I9T9I
M;&4H)'5S97)?9FEL92P@)W5S97(G+"`D<W1R:6-T*3L-"B`@("`@("`@("`@
M("1T:&ES+3YP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("!I9B`H
M)'1H:7,M/E]E<G)O<G-&;W5N9"`^(#`I('L-"B`@("`@("`@("`@("`@("!R
M971U<FX[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"@T*("`@("`@("!I
M9B`H)'-Y<W1E;5]F:6QE("8F($!F:6QE7V5X:7-T<R@D<WES=&5M7V9I;&4I
M*2![#0H@("`@("`@("`@("`D=&AI<RT^;65R9V5#;VYF:6=&:6QE*"1S>7-T
M96U?9FEL92P@9F%L<V4L("=S>7-T96TG+"`D<W1R:6-T*3L-"B`@("`@("`@
M("`@(&EF("@D=&AI<RT^7V5R<F]R<T9O=6YD(#X@,"D@>PT*("`@("`@("`@
M("`@("`@(')E='5R;CL-"B`@("`@("`@("`@('T-"@T*("`@("`@("!]#0H-
M"B`@("`@("`@:68@*"$D9G1P7V9I;&4I('L-"B`@("`@("`@("`@("1F='!?
M9FEL92`]("1T:&ES+3YG970H)W)E;6]T95]C;VYF:6<G*3L-"B`@("`@("`@
M?0T*#0H@("`@("`@(&EF("@D9G1P7V9I;&4@)B8@9&5F:6YE9"@G4$5!4E]2
M14U/5$5)3E-404Q,7T]+)RDI('L-"B`@("`@("`@("`@("1T:&ES+3YR96%D
M1E100V]N9FEG1FEL92@D9G1P7V9I;&4I.PT*("`@("`@("!]#0H-"B`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/F-O;F9I9W5R871I;VY?:6YF;R!A<R`D:V5Y
M(#T^("1I;F9O*2![#0H@("`@("`@("`@("`D=&AI<RT^8V]N9FEG=7)A=&EO
M;ELG9&5F875L="==6R1K97E=(#T@)&EN9F];)V1E9F%U;'0G73L-"B`@("`@
M("`@?0T*#0H@("`@("`@("1T:&ES+3Y?<F5G:7-T<GE;)V1E9F%U;'0G72`]
M("9N97<@4$5!4E]296=I<W1R>2@D=&AI<RT^8V]N9FEG=7)A=&EO;ELG9&5F
M875L="==6R=P:'!?9&ER)UTI.PT*("`@("`@("`D=&AI<RT^7W)E9VES=')Y
M6R=D969A=6QT)UTM/G-E=$-O;F9I9R@D=&AI<RD[#0H@("`@("`@("1T:&ES
M+3Y?<F5G26YI=&EA;&EZ961;)V1E9F%U;'0G72`](&9A;'-E.PT*("`@("`@
M("`O+R1'3$]"04Q36R=?4$5!4E]#;VYF:6=?:6YS=&%N8V4G72`]("8D=&AI
M<SL-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@<VEN9VQE=&]N
M*%MF:6QE72P@6V1E9F%U;'1S7V9I;&5=*0T*#0H@("`@+RHJ#0H@("`@("H@
M4W1A=&EC('-I;F=L971O;B!M971H;V0N("!)9B!Y;W4@=V%N="!T;R!K965P
M(&]N;'D@;VYE(&EN<W1A;F-E#0H@("`@("H@;V8@=&AI<R!C;&%S<R!I;B!U
M<V4L('1H:7,@;65T:&]D('=I;&P@9VEV92!Y;W4@82!R969E<F5N8V4@=&\-
M"B`@("`@*B!T:&4@;&%S="!C<F5A=&5D(%!%05)?0V]N9FEG(&]B:F5C="!I
M9B!O;F4@97AI<W1S+"!O<B!C<F5A=&4@80T*("`@("`J(&YE=R!O8FIE8W0N
M#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("AO<'1I;VYA;"D@9FEL
M92!T;R!R96%D('5S97(M9&5F:6YE9"!O<'1I;VYS(&9R;VT-"B`@("`@*B!`
M<&%R86T@<W1R:6YG("AO<'1I;VYA;"D@9FEL92!T;R!R96%D('-Y<W1E;2UW
M:61E(&1E9F%U;'1S(&9R;VT-"B`@("`@*@T*("`@("`J($!R971U<FX@;V)J
M96-T(&%N(&5X:7-T:6YG(&]R(&YE=R!014%27T-O;F9I9R!I;G-T86YC90T*
M("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*@T*("`@("`J
M($!S964@4$5!4E]#;VYF:6<Z.E!%05)?0V]N9FEG#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@)G-I;F=L971O;B@D=7-E<E]F:6QE(#T@)R<L("1S>7-T96U?
M9FEL92`]("<G+"`D<W1R:6-T(#T@=')U92D-"B`@("![#0H@("`@("`@(&EF
M("AI<U]O8FIE8W0H)$=,3T)!3%-;)U]014%27T-O;F9I9U]I;G-T86YC92==
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q36R=?4$5!4E]#;VYF
M:6=?:6YS=&%N8V4G73L-"B`@("`@("`@?0T*#0H@("`@("`@("1T7V-O;F8@
M/2`F;F5W(%!%05)?0V]N9FEG*"1U<V5R7V9I;&4L("1S>7-T96U?9FEL92P@
M9F%L<V4L("1S=')I8W0I.PT*("`@("`@("!I9B`H)'1?8V]N9BT^7V5R<F]R
M<T9O=6YD(#X@,"D@>PT*("`@("`@("`@("`@(')E='5R;B`D=%]C;VYF+3YL
M87-T17)R;W([#0H@("`@("`@('T-"@T*("`@("`@("`D1TQ/0D%,4ULG7U!%
M05)?0V]N9FEG7VEN<W1A;F-E)UT@/2`F)'1?8V]N9CL-"B`@("`@("`@<F5T
M=7)N("1'3$]"04Q36R=?4$5!4E]#;VYF:6=?:6YS=&%N8V4G73L-"B`@("!]
M#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@=F%L:61#;VYF:6=U<F%T:6]N
M*"D-"@T*("`@("\J*@T*("`@("`J($1E=&5R;6EN92!W:&5T:&5R(&%N>2!C
M;VYF:6=U<F%T:6]N(&9I;&5S(&AA=F4@8F5E;B!D971E8W1E9"P@86YD('=H
M971H97(@80T*("`@("`J(')E9VES=')Y(&]B:F5C="!C86X@8F4@<F5T<FEE
M=F5D(&9R;VT@=&AI<R!C;VYF:6=U<F%T:6]N+@T*("`@("`J($!R971U<FX@
M8F]O;`T*("`@("`J($!S:6YC92!014%2(#$N-"XP83$-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!V86QI9$-O;F9I9W5R871I;VXH*0T*("`@('L-"B`@("`@
M("`@:68@*"1T:&ES+3YI<T1E9FEN961,87EE<B@G=7-E<B<I('Q\("1T:&ES
M+3YI<T1E9FEN961,87EE<B@G<WES=&5M)RDI('L-"B`@("`@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@<F5A9$-O;F9I9T9I
M;&4H6V9I;&5=+"!;;&%Y97)=*0T*#0H@("`@+RHJ#0H@("`@("H@4F5A9',@
M8V]N9FEG=7)A=&EO;B!D871A(&9R;VT@82!F:6QE+B`@06QL(&5X:7-T:6YG
M('9A;'5E<R!I;@T*("`@("`J('1H92!C;VYF:6<@;&%Y97(@87)E(&1I<V-A
M<F1E9"!A;F0@<F5P;&%C960@=VET:"!D871A(&9R;VT@=&AE#0H@("`@("H@
M9FEL92X-"B`@("`@*B!`<&%R86T@<W1R:6YG(&9I;&4@=&\@<F5A9"!F<F]M
M+"!I9B!.54Q,(&]R(&YO="!S<&5C:69I960L('1H90T*("`@("`J("`@("`@
M("`@("`@("`@;&%S="UU<V5D(&9I;&4@9F]R('1H92!S86UE(&QA>65R("AS
M96-O;F0@<&%R86TI(&ES('5S960-"B`@("`@*B!`<&%R86T@<W1R:6YG(&-O
M;F9I9R!L87EE<B!T;R!I;G-E<G0@9&%T82!I;G1O("@G=7-E<B<@;W(@)W-Y
M<W1E;2<I#0H@("`@("H@0')E='5R;B!B;V]L(%12544@;VX@<W5C8V5S<R!O
M<B!A(%!%05(@97)R;W(@;VX@9F%I;'5R90T*("`@("`J+PT*("`@(&9U;F-T
M:6]N(')E861#;VYF:6=&:6QE*"1F:6QE(#T@;G5L;"P@)&QA>65R(#T@)W5S
M97(G+"`D<W1R:6-T(#T@=')U92D-"B`@("![#0H@("`@("`@(&EF("AE;7!T
M>2@D=&AI<RT^9FEL97-;)&QA>65R72DI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B=6YK;F]W;B!C;VYF:6<@;&%Y97(@8"1L
M87EE<B<B*3L-"B`@("`@("`@?0T*#0H@("`@("`@(&EF("@D9FEL92`]/3T@
M;G5L;"D@>PT*("`@("`@("`@("`@)&9I;&4@/2`D=&AI<RT^9FEL97-;)&QA
M>65R73L-"B`@("`@("`@?0T*#0H@("`@("`@("1D871A(#T@)'1H:7,M/E]R
M96%D0V]N9FEG1&%T849R;VTH)&9I;&4I.PT*#0H@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1D871A*2D@>PT*("`@("`@("`@("`@:68@*"1S=')I8W0I
M('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V5R<F]R<T9O=6YD*RL[#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/FQA<W1%<G)O<B`]("1D871A.PT*#0H@
M("`@("`@("`@("`@("`@<F5T=7)N("1D871A.PT*("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T:&ES+3YF
M:6QE<ULD;&%Y97)=(#T@)&9I;&4[#0H@("`@("`@('T-"@T*("`@("`@("`D
M=&AI<RT^7V1E8V]D94EN<'5T*"1D871A*3L-"B`@("`@("`@)'1H:7,M/F-O
M;F9I9W5R871I;VY;)&QA>65R72`]("1D871A.PT*("`@("`@("`D=&AI<RT^
M7W-E='5P0VAA;FYE;',H*3L-"B`@("`@("`@:68@*"$D=&AI<RT^7VYO4F5G
M:7-T<GD@)B8@*"1P:'!D:7(@/2`D=&AI<RT^9V5T*"=P:'!?9&ER)RP@)&QA
M>65R+"`G<&5A<BYP:'`N;F5T)RDI*2![#0H@("`@("`@("`@("`D=&AI<RT^
M7W)E9VES=')Y6R1L87EE<ET@/2`F;F5W(%!%05)?4F5G:7-T<GDH)'!H<&1I
M<BD[#0H@("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y6R1L87EE<ETM/G-E
M=$-O;F9I9R@D=&AI<RD[#0H@("`@("`@("`@("`D=&AI<RT^7W)E9TEN:71I
M86QI>F5D6R1L87EE<ET@/2!F86QS93L-"B`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@('5N<V5T*"1T:&ES+3Y?<F5G:7-T<GE;)&QA>65R72D[#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG('5R;"!T
M;R!T:&4@<F5M;W1E(&-O;F9I9R!F:6QE+"!L:6ME(&9T<#HO+W=W=RYE>&%M
M<&QE+F-O;2]P96%R+V-O;F9I9RYI;FD-"B`@("`@*B!`<F5T=7)N('1R=65\
M4$5!4E]%<G)O<@T*("`@("`J+PT*("`@(&9U;F-T:6]N(')E861&5%!#;VYF
M:6=&:6QE*"1P871H*0T*("`@('L-"B`@("`@("`@9&\@>R`O+R!P;V]R(&UA
M;B=S('1R>0T*("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)TYE=%]&
M5%`G*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=0
M14%27T-O;6UO;B<I*2![#0H@("`@("`@("`@("`@("`@("`@(')E<75I<F5?
M;VYC92`G4$5!4B]#;VUM;VXN<&AP)SL-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@:68@*%!%05)?0V]M;6]N.CII<TEN8VQU9&5A8FQE
M*"=.970O1E10+G!H<"<I*2![#0H@("`@("`@("`@("`@("`@("`@(&EN8VQU
M9&5?;VYC92`G3F5T+T944"YP:'`G.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)TYE
M=%]&5%`G*2`F)@T*("`@("`@("`@("`@("`@("`@*&-L87-S7V5X:7-T<R@G
M4$5!4E]&5%`G*2!\?"!014%27T-O;6UO;CHZ:7-);F-L=61E86)L92@G4$5!
M4B]&5%`N<&AP)RDI*2![#0H@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E
M("=014%2+T944"YP:'`G.PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?9G1P
M(#T@)FYE=R!014%27T944#L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V9T
M<"T^<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@
M("`@("`@("`@("`@("1E(#T@)'1H:7,M/E]F='`M/FEN:70H)'!A=&@I.PT*
M("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V9T<"T^<&]P17)R;W)(86YD;&EN
M9R@I.PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)&4[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T;7`@/2!3>7-T96TZ.FUK
M=&5M<"@G+60G*3L-"B`@("`@("`@("`@("`@("!014%27T-O;6UO;CHZ861D
M5&5M<$9I;&4H)'1M<"D[#0H@("`@("`@("`@("`@("`@)&4@/2`D=&AI<RT^
M7V9T<"T^9V5T*&)A<V5N86UE*"1P871H*2P@)'1M<"`N($1)4D5#5$]265]3
M15!!4D%43U(@+@T*("`@("`@("`@("`@("`@("`@("`G<&5A<BYI;FDG+"!F
M86QS92P@1E107T))3D%262D[#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&4I*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9G1P+3YP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@4$5!4E]#;VUM;VXZ.F%D9%1E;7!&:6QE*"1T;7`@+B!$25)%0U1/4EE?
M4T5005)!5$]2("X@)W!E87(N:6YI)RD[#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/E]F='`M/F1I<V-O;FYE8W0H*3L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V9T<"T^<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@
M("1T:&ES+3YF:6QE<ULG9G1P)UT@/2`D=&UP("X@1$E214-43U)97U-%4$%2
M051/4B`N("=P96%R+FEN:2<[#0H@("`@("`@("`@("`@("`@)&4@/2`D=&AI
M<RT^<F5A9$-O;F9I9T9I;&4H;G5L;"P@)V9T<"<I.PT*("`@("`@("`@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1E*2D@>PT*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)&4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("1F86EL(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("!F;W)E
M86-H("@D=&AI<RT^8V]N9FEG=7)A=&EO;E]I;F9O(&%S("1K97D@/3X@)'9A
M;"D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H:6Y?87)R87DH)'1H:7,M
M/F=E=$=R;W5P*"1K97DI+`T*("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G1FEL92!,;V-A=&EO;G,G+"`G1FEL92!,;V-A=&EO;G,@*$%D=F%N
M8V5D*2<I*2`F)@T*("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M9V5T5'EP92@D:V5Y*2`]/2`G9&ER96-T;W)Y)RD@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@86YY(&1I<F5C=&]R>2!C;VYF:6=S(&UU<W0@8F4@
M<V5T(&9O<B!T:&ES('1O('=O<FL-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY;)V9T<"==6R1K97E=
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F86EL6UT@/2`D
M:V5Y.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&EF("AC;W5N="@D9F%I;"DI('L-"B`@("`@("`@("`@("`@("`@("`@)&9A
M:6P@/2`G(B<@+B!I;7!L;V1E*"<B+"`B)RP@)&9A:6PI("X@)R(G.PT*("`@
M("`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^9FEL97-;)V9T<"==*3L-
M"B`@("`@("`@("`@("`@("`@("`@=6YS970H)'1H:7,M/F-O;F9I9W5R871I
M;VY;)V9T<"==*3L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)T524D]2.B!&='`@8V]N9FEG=7)A=&EO;B!F:6QE(&UU
M<W0@<V5T(&%L;"`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("=D:7)E
M8W1O<GD@8V]N9FEG=7)A=&EO;B!V87)I86)L97,N("!4:&5S92!V87)I86)L
M97,@=V5R92!N;W0@<V5T.B`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1F86EL*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=.971?1E10(&UU<W0@8F4@:6YS=&%L;&5D('1O
M('5S92!R96UO=&4@8V]N9FEG)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T@=VAI;&4@*&9A;'-E*3L@+R\@<&]O<B!M86XG<R!C871C:`T*("`@("`@
M("!U;G-E="@D=&AI<RT^9FEL97-;)V9T<"==*3L-"B`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)VYO(')E;6]T92!H;W-T('-P96-I9FEE9"<I
M.PT*("`@('T-"@T*("`@("\O('M[>R!?<V5T=7!#:&%N;F5L<R@I#0H@("`@
M#0H@("`@+RHJ#0H@("`@("H@4F5A9',@=&AE(&5X:7-T:6YG(&-O;F9I9W5R
M871I;VYS(&%N9"!C<F5A=&5S('1H92!?8VAA;FYE;',@87)R87D@9G)O;2!I
M=`T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]S971U<$-H86YN96QS*"D-"B`@
M("![#0H@("`@("`@("1S970@/2!A<G)A>5]F;&EP*&%R<F%Y7W9A;'5E<R@D
M=&AI<RT^7V-H86YN96QS*2D[#0H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YC
M;VYF:6=U<F%T:6]N(&%S("1L87EE<B`]/B`D9&%T82D@>PT*("`@("`@("`@
M("`@)&D@/2`Q,#`P.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1D871A6R=?
M7V-H86YN96QS)UTI*2![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&1A
M=&%;)U]?8VAA;FYE;',G72!A<R`D8VAA;FYE;"`]/B`D:6YF;RD@>PT*("`@
M("`@("`@("`@("`@("`@("`D<V5T6R1C:&%N;F5L72`]("1I*RL[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@("1T:&ES+3Y?8VAA;FYE;',@/2!A<G)A>5]V86QU97,H87)R87E?9FQI
M<"@D<V5T*2D[#0H@("`@("`@("1T:&ES+3YS971#:&%N;F5L<R@D=&AI<RT^
M7V-H86YN96QS*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@
M9&5L971E0VAA;FYE;"AC:&%N;F5L*0T*#0H@("`@9G5N8W1I;VX@9&5L971E
M0VAA;FYE;"@D8VAA;FYE;"D-"B`@("![#0H@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3YC;VYF:6=U<F%T:6]N(&%S("1L87EE<B`]/B`D9&%T82D@>PT*("`@
M("`@("`@("`@:68@*&ES<V5T*"1D871A6R=?7V-H86YN96QS)UTI*2![#0H@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D871A6R=?7V-H86YN96QS)UU;
M<W1R=&]L;W=E<B@D8VAA;FYE;"E=*2D@>PT*("`@("`@("`@("`@("`@("`@
M("!U;G-E="@D=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=6R=?7V-H86YN
M96QS)UU;<W1R=&]L;W=E<B@D8VAA;FYE;"E=*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M
M/E]C:&%N;F5L<R`](&%R<F%Y7V9L:7`H)'1H:7,M/E]C:&%N;F5L<RD[#0H@
M("`@("`@('5N<V5T*"1T:&ES+3Y?8VAA;FYE;'-;<W1R=&]L;W=E<B@D8VAA
M;FYE;"E=*3L-"B`@("`@("`@)'1H:7,M/E]C:&%N;F5L<R`](&%R<F%Y7V9L
M:7`H)'1H:7,M/E]C:&%N;F5L<RD[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(&UE<F=E0V]N9FEG1FEL92AF:6QE+"!;;W9E<G)I9&5=+"!;
M;&%Y97)=*0T*#0H@("`@+RHJ#0H@("`@("H@365R9V5S(&1A=&$@:6YT;R!A
M(&-O;F9I9R!L87EE<B!F<F]M(&$@9FEL92X@($1O97,@=&AE('-A;64-"B`@
M("`@*B!T:&EN9R!A<R!R96%D0V]N9FEG1FEL92P@97AC97!T(&ET(&1O97,@
M;F]T(')E<&QA8V4@86QL#0H@("`@("H@97AI<W1I;F<@=F%L=65S(&EN('1H
M92!C;VYF:6<@;&%Y97(N#0H@("`@("H@0'!A<F%M('-T<FEN9R!F:6QE('1O
M(')E860@9G)O;0T*("`@("`J($!P87)A;2!B;V]L('=H971H97(@=&\@;W9E
M<G=R:71E(&5X:7-T:6YG(&1A=&$@*&1E9F%U;'0@5%)512D-"B`@("`@*B!`
M<&%R86T@<W1R:6YG(&-O;F9I9R!L87EE<B!T;R!I;G-E<G0@9&%T82!I;G1O
M("@G=7-E<B<@;W(@)W-Y<W1E;2<I#0H@("`@("H@0'!A<F%M('-T<FEN9R!I
M9B!T<G5E+"!E<G)O<G,@87)E(')E='5R;F5D(&EF(&9I;&4@;W!E;FEN9R!F
M86EL<PT*("`@("`J($!R971U<FX@8F]O;"!44E5%(&]N('-U8V-E<W,@;W(@
M82!014%2(&5R<F]R(&]N(&9A:6QU<F4-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!M97)G94-O;F9I9T9I;&4H)&9I;&4L("1O=F5R<FED92`]('1R=64L("1L
M87EE<B`]("=U<V5R)RP@)'-T<FEC="`]('1R=64I#0H@("`@>PT*("`@("`@
M("!I9B`H96UP='DH)'1H:7,M/F9I;&5S6R1L87EE<ETI*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(G5N:VYO=VX@8V]N9FEG
M(&QA>65R(&`D;&%Y97(G(BD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1F
M:6QE(#T]/2!N=6QL*2![#0H@("`@("`@("`@("`D9FEL92`]("1T:&ES+3YF
M:6QE<ULD;&%Y97)=.PT*("`@("`@("!]#0H@("`@("`@("1D871A(#T@)'1H
M:7,M/E]R96%D0V]N9FEG1&%T849R;VTH)&9I;&4I.PT*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D9&%T82DI('L-"B`@("`@("`@("`@(&EF("@D<W1R
M:6-T*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]E<G)O<G-&;W5N9"LK
M.PT*("`@("`@("`@("`@("`@("1T:&ES+3YL87-T17)R;W(@/2`D9&%T83L-
M"@T*("`@("`@("`@("`@("`@(')E='5R;B`D9&%T83L-"B`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]D96-O9&5)
M;G!U="@D9&%T82D[#0H@("`@("`@(&EF("@D;W9E<G)I9&4I('L-"B`@("`@
M("`@("`@("1T:&ES+3YC;VYF:6=U<F%T:6]N6R1L87EE<ET@/0T*("`@("`@
M("`@("`@("`@(%!%05)?0V]N9FEG.CIA<G)A>4UE<F=E4F5C=7)S:79E*"1T
M:&ES+3YC;VYF:6=U<F%T:6]N6R1L87EE<ETL("1D871A*3L-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6=U<F%T:6]N6R1L
M87EE<ET@/0T*("`@("`@("`@("`@("`@(%!%05)?0V]N9FEG.CIA<G)A>4UE
M<F=E4F5C=7)S:79E*"1D871A+"`D=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y
M97)=*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W-E='5P0VAA;FYE
M;',H*3L-"B`@("`@("`@:68@*"$D=&AI<RT^7VYO4F5G:7-T<GD@)B8@*"1P
M:'!D:7(@/2`D=&AI<RT^9V5T*"=P:'!?9&ER)RP@)&QA>65R+"`G<&5A<BYP
M:'`N;F5T)RDI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y6R1L
M87EE<ET@/2`F;F5W(%!%05)?4F5G:7-T<GDH)'!H<&1I<BD[#0H@("`@("`@
M("`@("`D=&AI<RT^7W)E9VES=')Y6R1L87EE<ETM/G-E=$-O;F9I9R@D=&AI
M<RD[#0H@("`@("`@("`@("`D=&AI<RT^7W)E9TEN:71I86QI>F5D6R1L87EE
M<ET@/2!F86QS93L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@('5N
M<V5T*"1T:&ES+3Y?<F5G:7-T<GE;)&QA>65R72D[#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(&%R<F%Y365R9V5296-U<G-I=F4H)&%R<C(L("1A<G(Q*0T*("`@
M("\J*@T*("`@("`J($!P87)A;2!A<G)A>0T*("`@("`J($!P87)A;2!A<G)A
M>0T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@*B!`<W1A=&EC#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@87)R87E-97)G95)E8W5R<VEV92@D87)R,BP@
M)&%R<C$I#0H@("`@>PT*("`@("`@("`D<F5T(#T@87)R87DH*3L-"B`@("`@
M("`@9F]R96%C:"`H)&%R<C(@87,@)&ME>2`]/B`D9&%T82D@>PT*("`@("`@
M("`@("`@:68@*"%I<W-E="@D87)R,5LD:V5Y72DI('L-"B`@("`@("`@("`@
M("`@("`D<F5T6R1K97E=(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@=6YS
M970H)&%R<C%;)&ME>5TI.PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1D871A
M*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&%R<C%;)&ME
M>5TI*2![#0H@("`@("`@("`@("`@("`@("`@("1R971;)&ME>5T@/2`D87)R
M,5LD:V5Y73L-"B`@("`@("`@("`@("`@("`@("`@=6YS970H)&%R<C%;)&ME
M>5TI.PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@)')E=%LD:V5Y72`](%!%05)?
M0V]N9FEG.CIA<G)A>4UE<F=E4F5C=7)S:79E*"1A<G(Q6R1K97E=+"`D87)R
M,ELD:V5Y72D[#0H@("`@("`@("`@("`@("`@=6YS970H)&%R<C%;)&ME>5TI
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B!A
M<G)A>5]M97)G92@D<F5T+"`D87)R,2D[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[('=R:71E0V]N9FEG1FEL92A;9FEL95TL(%ML87EE<ETI
M#0H-"B`@("`O*BH-"B`@("`@*B!7<FET97,@9&%T82!I;G1O(&$@8V]N9FEG
M(&QA>65R(&9R;VT@82!F:6QE+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T
M<FEN9WQN=6QL(&9I;&4@=&\@<F5A9"!F<F]M+"!O<B!N=6QL(&9O<B!D969A
M=6QT#0H@("`@("H@0'!A<F%M('-T<FEN9R!C;VYF:6<@;&%Y97(@=&\@:6YS
M97)T(&1A=&$@:6YT;R`H)W5S97(G(&]R#0H@("`@("H@("`@("`@("`@("`@
M("`G<WES=&5M)RD-"B`@("`@*B!`<&%R86T@<W1R:6YG?&YU;&P@9&%T82!T
M;R!W<FET92!T;R!C;VYF:6<@9FEL92!O<B!N=6QL(&9O<B!I;G1E<FYA;"!D
M871A(%M$15!214-!5$5$70T*("`@("`J($!R971U<FX@8F]O;"!44E5%(&]N
M('-U8V-E<W,@;W(@82!014%2(&5R<F]R(&]N(&9A:6QU<F4-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!W<FET94-O;F9I9T9I;&4H)&9I;&4@/2!N=6QL+"`D
M;&%Y97(@/2`G=7-E<B<L("1D871A(#T@;G5L;"D-"B`@("![#0H@("`@("`@
M("1T:&ES+3Y?;&%Z>4-H86YN96Q3971U<"@D;&%Y97(I.PT*("`@("`@("!I
M9B`H)&QA>65R(#T]("=B;W1H)R!\?"`D;&%Y97(@/3T@)V%L;"<I('L-"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YF:6QE<R!A<R`D='EP92`]/B`D
M9FEL92D@>PT*("`@("`@("`@("`@("`@("1E<G(@/2`D=&AI<RT^=W)I=&5#
M;VYF:6=&:6QE*"1F:6QE+"`D='EP92P@)&1A=&$I.PT*("`@("`@("`@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1E<G(I*2![#0H@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D97)R.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^9FEL97-;)&QA>65R72DI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B=6YK;F]W
M;B!C;VYF:6<@9FEL92!T>7!E(&`D;&%Y97(G(BD[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"1F:6QE(#T]/2!N=6QL*2![#0H@("`@("`@("`@("`D9FEL
M92`]("1T:&ES+3YF:6QE<ULD;&%Y97)=.PT*("`@("`@("!]#0H@("`@("`@
M("1D871A(#T@*"1D871A(#T]/2!N=6QL*2`_("1T:&ES+3YC;VYF:6=U<F%T
M:6]N6R1L87EE<ET@.B`D9&%T83L-"B`@("`@("`@)'1H:7,M/E]E;F-O9&5/
M=71P=70H)&1A=&$I.PT*("`@("`@("`D;W!T(#T@87)R87DH)RUP)RP@9&ER
M;F%M92@D9FEL92DI.PT*("`@("`@("!I9B`H(4!3>7-T96TZ.FUK1&ER*"1O
M<'0I*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M(F-O=6QD(&YO="!C<F5A=&4@9&ER96-T;W)Y.B`B("X@9&ER;F%M92@D9FEL
M92DI.PT*("`@("`@("!]#0H@("`@("`@(&EF("A`:7-?9FEL92@D9FEL92D@
M)B8@(4!I<U]W<FET96%B;&4H)&9I;&4I*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H(FYO('=R:71E(&%C8V5S<R!T;R`D9FEL
M92$B*3L-"B`@("`@("`@?0T*("`@("`@("`D9G`@/2!`9F]P96XH)&9I;&4L
M(")W(BD[#0H@("`@("`@(&EF("@A)&9P*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H(E!%05)?0V]N9FEG.CIW<FET94-O;F9I
M9T9I;&4@9F]P96XH)R1F:6QE)RPG=R<I(&9A:6QE9"(I.PT*("`@("`@("!]
M#0H@("`@("`@("1C;VYT96YT<R`]("(C4$5!4E]#;VYF:6<@,"XY7&XB("X@
M<V5R:6%L:7IE*"1D871A*3L-"B`@("`@("`@:68@*"%`9G=R:71E*"1F<"P@
M)&-O;G1E;G1S*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*")014%27T-O;F9I9SHZ=W)I=&5#;VYF:6=&:6QE.B!F=W)I=&4@
M9F%I;&5D(BD[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]R96%D0V]N9FEG1&%T
M849R;VTH9FEL92D-"@T*("`@("\J*@T*("`@("`J(%)E861S(&-O;F9I9W5R
M871I;VX@9&%T82!F<F]M(&$@9FEL92!A;F0@<F5T=7)N<R!T:&4@<&%R<V5D
M(&1A=&$-"B`@("`@*B!I;B!A;B!A<G)A>2X-"B`@("`@*@T*("`@("`J($!P
M87)A;2!S=')I;F<@9FEL92!T;R!R96%D(&9R;VT-"B`@("`@*@T*("`@("`J
M($!R971U<FX@87)R87D@8V]N9FEG=7)A=&EO;B!D871A(&]R(&$@4$5!4B!E
M<G)O<B!O;B!F86EL=7)E#0H@("`@("H-"B`@("`@*B!`86-C97-S('!R:79A
M=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?<F5A9$-O;F9I9T1A=&%&<F]M
M*"1F:6QE*0T*("`@('L-"B`@("`@("`@)&9P(#T@0&9O<&5N*"1F:6QE+"`B
M<B(I.PT*("`@("`@("!I9B`H(21F<"D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*")014%27T-O;F9I9SHZ<F5A9$-O;F9I9T9I
M;&4@9F]P96XH)R1F:6QE)RPG<B<I(&9A:6QE9"(I.PT*("`@("`@("!]#0H@
M("`@("`@("1S:7IE(#T@9FEL97-I>F4H)&9I;&4I.PT*("`@("`@("`D<G0@
M/2!G971?;6%G:6-?<75O=&5S7W)U;G1I;64H*3L-"B`@("`@("`@<V5T7VUA
M9VEC7W%U;W1E<U]R=6YT:6UE*#`I.PT*("`@("`@("!I9B`H9G5N8W1I;VY?
M97AI<W1S*"=F:6QE7V=E=%]C;VYT96YT<R<I*2![#0H@("`@("`@("`@("!F
M8VQO<V4H)&9P*3L-"B`@("`@("`@("`@("1C;VYT96YT<R`](&9I;&5?9V5T
M7V-O;G1E;G1S*"1F:6QE*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("1C;VYT96YT<R`]($!F<F5A9"@D9G`L("1S:7IE*3L-"B`@("`@("`@
M("`@(&9C;&]S92@D9G`I.PT*("`@("`@("!]#0H@("`@("`@(&EF("AE;7!T
M>2@D8V]N=&5N=',I*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H)T-O;F9I9W5R871I;VX@9FEL92`B)R`N("1F:6QE("X@)R(@
M:7,@96UP='DG*3L-"B`@("`@("`@?0T*("`@("`@("`-"B`@("`@("`@<V5T
M7VUA9VEC7W%U;W1E<U]R=6YT:6UE*"1R="D[#0H-"B`@("`@("`@)'9E<G-I
M;VX@/2!F86QS93L-"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>(U!%05)?
M0V]N9FEG7',K*%Q3*RE<<RLO<VDG+"`D8V]N=&5N=',L("1M871C:&5S*2D@
M>PT*("`@("`@("`@("`@)'9E<G-I;VX@/2`D;6%T8VAE<ULQ73L-"B`@("`@
M("`@("`@("1C;VYT96YT<R`]('-U8G-T<B@D8V]N=&5N=',L('-T<FQE;B@D
M;6%T8VAE<ULP72DI.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M+R\@375S975M(&-O;F9I9R!F:6QE#0H@("`@("`@("`@("!I9B`H<W5B<W1R
M*"1C;VYT96YT<RPP+#(I(#T]("=A.B<I('L-"B`@("`@("`@("`@("`@("`D
M=F5R<VEO;B`]("<P+C$G.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(&EF("@D=F5R<VEO;B`F)B!V97)S:6]N7V-O;7!A<F4H(B1V97)S
M:6]N(BP@)S$G+"`G/"<I*2![#0H-"B`@("`@("`@("`@("\O(&YO("=`)RP@
M:70@:7,@<&]S<VEB;&4@=&AA="!U;G-E<FEA;&EZ90T*("`@("`@("`@("`@
M+R\@<F%I<V5S(&$@;F]T:6-E(&)U="!I="!S965M<R!T;R!B;&]C:R!)3R!T
M;PT*("`@("`@("`@("`@+R\@4U1$3U54(&EF(&$@)T`G(&ES('5S960@86YD
M(&$@;F]T:6-E(&ES(')A:7-E#0H@("`@("`@("`@("`D9&%T82`]('5N<V5R
M:6%L:7IE*"1C;VYT96YT<RD[#0H-"B`@("`@("`@("`@(&EF("@A:7-?87)R
M87DH)&1A=&$I("8F("$D9&%T82D@>PT*("`@("`@("`@("`@("`@(&EF("@D
M8V]N=&5N=',@/3T@<V5R:6%L:7IE*&9A;'-E*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`D9&%T82`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)&5R<B`]("1T:&ES+3YR86ES
M945R<F]R*")014%27T-O;F9I9SH@8F%D(&1A=&$@:6X@)&9I;&4B*3L-"B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1E<G([#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%I<U]A<G)A
M>2@D9&%T82DI('L-"B`@("`@("`@("`@("`@("!I9B`H<W1R;&5N*'1R:6TH
M)&-O;G1E;G1S*2D@/B`P*2![#0H@("`@("`@("`@("`@("`@("`@("1E<G)O
M<B`](")014%27T-O;F9I9SH@8F%D(&1A=&$@:6X@)&9I;&4B.PT*("`@("`@
M("`@("`@("`@("`@("`D97)R(#T@)'1H:7,M/G)A:7-E17)R;W(H)&5R<F]R
M*3L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1E<G([#0H@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)&1A=&$@
M/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-
M"B`@("`@("`@+R\@861D('!A<G-I;F<@;V8@;F5W97(@9F]R;6%T<R!H97)E
M+BXN#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D97)R(#T@)'1H
M:7,M/G)A:7-E17)R;W(H(B1F:6QE.B!U;FMN;W=N('9E<G-I;VX@8"1V97)S
M:6]N)R(I.PT*("`@("`@("`@("`@<F5T=7)N("1E<G([(`T*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B`D9&%T83L-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"B`@("`O+R![>WL@9V5T0V]N9D9I;&4H;&%Y97(I#0H@("`@+RHJ#0H@("`@
M*B!'971S('1H92!F:6QE('5S960@9F]R('-T;W)I;F<@=&AE(&-O;F9I9R!F
M;W(@82!L87EE<@T*("`@("H-"B`@("`J($!P87)A;2!S=')I;F<@)&QA>65R
M("=U<V5R)R!O<B`G<WES=&5M)PT*("`@("HO#0H-"B`@("!F=6YC=&EO;B!G
M971#;VYF1FEL92@D;&%Y97(I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H
M:7,M/F9I;&5S6R1L87EE<ET[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@
M("`O*BH-"B`@("`@*B!`<&%R86T@87)R87D@:6YF;W)M871I;VX@;VX@82!R
M;VQE(&%S('!A<G-E9"!F<F]M(&ET<R!X;6P@9FEL90T*("`@("`J($!R971U
M<FX@=')U97Q014%27T5R<F]R#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@7V%D9$-O;F9I9U9A<G,H)'9A<G,I#0H@
M("`@>PT*("`@("`@("!I9B`H8V]U;G0H)'9A<G,I(#X@,RD@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=2;VQE<R!C86X@;VYL
M>2!D969I;F4@,R!N97<@8V]N9FEG('9A<FEA8FQE<R!O<B!L97-S)RD[#0H@
M("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)'9A<G,@87,@)&YA;64@/3X@
M)'9A<BD@>PT*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D=F%R*2D@>PT*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!M=7-T(&)E(&%N(&%R<F%Y)RD[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1V87);)W1Y
M<&4G72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)T-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@;75S="!C;VYT86EN
M(&$@='EP92<I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("!I9B`H(6EN7V%R<F%Y*"1V87);)W1Y<&4G72P-"B`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@G<W1R:6YG)RP@)VUA<VLG+"`G<&%S<W=O<F0G
M+"`G9&ER96-T;W)Y)RP@)V9I;&4G+"`G<V5T)RDI*2![#0H@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@-"B`@("`@("`@
M("`@("`@("`@("`@("`@("=#;VYF:6=U<F%T:6]N('1Y<&4@;75S="!B92!O
M;F4@;V8@9&ER96-T;W)Y+"!F:6QE+"!S=')I;F<L("<@+@T*("`@("`@("`@
M("`@("`@("`@("`@("`@)VUA<VLL('-E="P@;W(@<&%S<W=O<F0G*3L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1V87);)V1E9F%U;'0G72DI('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H#0H@("`@("`@("`@("`@("`@
M("`@("=#;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N(&UU<W0@8V]N=&%I;B!A
M(&1E9F%U;'0@=F%L=64@*")D969A=6QT(B!I;F1E>"DG*3L-"B`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1V
M87);)V1E9F%U;'0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)')E86Q?
M9&5F875L="`]("<G.PT*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M=F%R6R=D969A=6QT)UT@87,@)&-O;F9I9U]V87(@/3X@)'9A;"D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D8V]N9FEG7W9A<BP@
M)W1E>'0G*2`]/3T@,"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1R96%L7V1E9F%U;'0@+CT@)'9A;#L-"B`@("`@("`@("`@("`@("`@("`@
M("`@('T@96QS96EF("AS=')P;W,H)&-O;F9I9U]V87(L("=C;VYS=&%N="<I
M(#T]/2`P*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&1E
M9FEN960H)'9A;"DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)')E86Q?9&5F875L="`N/2!C;VYS=&%N="@D=F%L*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G56YK;F]W;B!C
M;VYS=&%N="`B)R`N("1V86P@+B`G(B!R97%U97-T960@:6X@)R`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L="!V86QU
M92!F;W(@8V]N9FEG=7)A=&EO;B!V87)I86)L92`B)R`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D;F%M92`N("<B)RD[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3YC;VYF:6=U<F%T:6]N7VEN
M9F];)&-O;F9I9U]V87)=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1R96%L7V1E9F%U;'0@+CT-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/F-O;F9I9W5R871I;VY?:6YF;ULD8V]N9FEG7W9A
M<EU;)V1E9F%U;'0G73L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G56YK;F]W;B!R97%U97-T(&9O<B`B)R`N("1C;VYF:6=?=F%R("X@)R(@
M=F%L=64@:6X@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=D969A=6QT('9A;'5E(&9O<B!C;VYF:6=U<F%T:6]N('9A<FEA8FQE("(G
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YA;64@+B`G
M(B<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1V87);)V1E9F%U;'0G
M72`]("1R96%L7V1E9F%U;'0[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&EF("@D=F%R6R=T>7!E)UT@/3T@)VEN=&5G97(G*2![#0H@
M("`@("`@("`@("`@("`@("`@("1V87);)V1E9F%U;'0G72`]("AI;G1E9V5R
M*2`D=F%R6R=D969A=6QT)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@:68@*"%I<W-E="@D=F%R6R=D;V,G72DI
M('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M#0H@("`@("`@("`@("`@("`@("`@("=#;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N(&UU<W0@8V]N=&%I;B!A('-U;6UA<GD@*")D;V,B(&EN9&5X*2<I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%I<W-E="@D=F%R6R=P
M<F]M<'0G72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H#0H@("`@("`@("`@("`@("`@("`@("=#;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N(&UU<W0@8V]N=&%I;B!A('-I;7!L92!P<F]M<'0@*")P
M<F]M<'0B(&EN9&5X*2<I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*"%I<W-E="@D=F%R6R=G<F]U<"==*2D@>PT*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@-"B`@("`@("`@("`@("`@("`@
M("`@)T-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@;75S="!C;VYT86EN(&$@
M<VEM<&QE(&=R;W5P("@B9W)O=7`B(&EN9&5X*2<I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YC;VYF:6=U<F%T:6]N
M7VEN9F];)&YA;65=*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@G0V]N9FEG=7)A=&EO;B!V87)I86)L92`B)R`N("1N
M86UE("X-"B`@("`@("`@("`@("`@("`@("`@)R(@86QR96%D>2!E>&ES=',G
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6=U
M<F%T:6]N7VEN9F];)&YA;65=(#T@)'9A<CL-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R![>WL@7V5N8V]D94]U
M='!U="@F9&%T82D-"@T*("`@("\J*@T*("`@("`J($5N8V]D97,O<V-R86UB
M;&5S(&-O;F9I9W5R871I;VX@9&%T82!B969O<F4@=W)I=&EN9R!T;R!F:6QE
M<RX-"B`@("`@*B!#=7)R96YT;'DL("=P87-S=V]R9"<@=F%L=65S('=I;&P@
M8F4@8F%S938T+65N8V]D960@87,@=&\@879O:60-"B`@("`@*B!T:&%T('!E
M;W!L92!S<&]T(&-L96%R=&5X="!P87-S=V]R9',@8GD@86-C:61E;G0N#0H@
M("`@("H-"B`@("`@*B!`<&%R86T@87)R87D@*')E9F5R96YC92D@87)R87D@
M=&\@96YC;V1E('9A;'5E<R!I;@T*("`@("`J#0H@("`@("H@0')E='5R;B!B
M;V]L(%12544@;VX@<W5C8V5S<PT*("`@("`J#0H@("`@("H@0&%C8V5S<R!P
M<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V5N8V]D94]U='!U="@F
M)&1A=&$I#0H@("`@>PT*("`@("`@("!F;W)E86-H("@D9&%T82!A<R`D:V5Y
M(#T^("1V86QU92D@>PT*("`@("`@("`@("`@:68@*"1K97D@/3T@)U]?8VAA
M;FYE;',G*2![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&1A=&%;)U]?
M8VAA;FYE;',G72!A<R`D8VAA;FYE;"`]/B`D8FQA:"D@>PT*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V5N8V]D94]U='!U="@D9&%T85LG7U]C:&%N
M;F5L<R==6R1C:&%N;F5L72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^8V]N9FEG
M=7)A=&EO;E]I;F9O6R1K97E=*2D@>PT*("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1Y<&4@/2`D=&AI
M<RT^8V]N9FEG=7)A=&EO;E]I;F9O6R1K97E=6R=T>7!E)UT[#0H@("`@("`@
M("`@("!S=VET8V@@*"1T>7!E*2![#0H@("`@("`@("`@("`@("`@+R\@=V4@
M8F%S938T+65N8V]D92!P87-S=V]R9',@<V\@=&AE>2!A<F4@870@;&5A<W0-
M"B`@("`@("`@("`@("`@("`O+R!N;W0@<VAO=VX@:6X@<&QA:6X@8GD@86-C
M:61E;G0-"B`@("`@("`@("`@("`@("!C87-E("=P87-S=V]R9"<Z('L-"B`@
M("`@("`@("`@("`@("`@("`@)&1A=&%;)&ME>5T@/2!B87-E-C1?96YC;V1E
M*"1D871A6R1K97E=*3L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&-A<V4@)VUA<VLG
M.B![#0H@("`@("`@("`@("`@("`@("`@("1D871A6R1K97E=(#T@;V-T9&5C
M*"1D871A6R1K97E=*3L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R!?9&5C;V1E26YP=70H)F1A=&$I#0H-"B`@("`O*BH-"B`@("`@
M*B!$96-O9&5S+W5N<V-R86UB;&5S(&-O;F9I9W5R871I;VX@9&%T82!A9G1E
M<B!R96%D:6YG(&9R;VT@9FEL97,N#0H@("`@("H-"B`@("`@*B!`<&%R86T@
M87)R87D@*')E9F5R96YC92D@87)R87D@=&\@96YC;V1E('9A;'5E<R!I;@T*
M("`@("`J#0H@("`@("H@0')E='5R;B!B;V]L(%12544@;VX@<W5C8V5S<PT*
M("`@("`J#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("H-"B`@("`@
M*B!`<V5E(%!%05)?0V]N9FEG.CI?96YC;V1E3W5T<'5T#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@7V1E8V]D94EN<'5T*"8D9&%T82D-"B`@("![#0H@("`@
M("`@(&EF("@A:7-?87)R87DH)&1A=&$I*2![#0H@("`@("`@("`@("!R971U
M<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D9&%T82!A
M<R`D:V5Y(#T^("1V86QU92D@>PT*("`@("`@("`@("`@:68@*"1K97D@/3T@
M)U]?8VAA;FYE;',G*2![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&1A
M=&%;)U]?8VAA;FYE;',G72!A<R`D8VAA;FYE;"`]/B`D8FQA:"D@>PT*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V1E8V]D94EN<'5T*"1D871A6R=?
M7V-H86YN96QS)UU;)&-H86YN96Q=*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YC
M;VYF:6=U<F%T:6]N7VEN9F];)&ME>5TI*2![#0H@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D='EP92`]
M("1T:&ES+3YC;VYF:6=U<F%T:6]N7VEN9F];)&ME>5U;)W1Y<&4G73L-"B`@
M("`@("`@("`@('-W:71C:"`H)'1Y<&4I('L-"B`@("`@("`@("`@("`@("!C
M87-E("=P87-S=V]R9"<Z('L-"B`@("`@("`@("`@("`@("`@("`@)&1A=&%;
M)&ME>5T@/2!B87-E-C1?9&5C;V1E*"1D871A6R1K97E=*3L-"B`@("`@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&-A<V4@)VUA<VLG.B![#0H@("`@("`@("`@("`@("`@("`@
M("1D871A6R1K97E=(#T@9&5C;V-T*"1D871A6R1K97E=*3L-"B`@("`@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G971$969A=6QT0VAA;FYE
M;"A;;&%Y97)=*0T*("`@("\J*@T*("`@("`J(%)E=')I979E('1H92!D969A
M=6QT(&-H86YN96PN#0H@("`@("H-"B`@("`@*B!/;B!S=&%R='5P+"!C:&%N
M;F5L<R!A<F4@;F]T(&EN:71I86QI>F5D+"!S;R!I9B!T:&4@9&5F875L="!C
M:&%N;F5L(&ES(&YO=`T*("`@("`J('!E87(N<&AP+FYE="P@=&AE;B!I;FET
M:6%L:7IE('1H92!C;VYF:6<N#0H@("`@("H@0'!A<F%M('-T<FEN9R!R96=I
M<W1R>2!L87EE<@T*("`@("`J($!R971U<FX@<W1R:6YG?&9A;'-E#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@9V5T1&5F875L=$-H86YN96PH)&QA>65R(#T@
M;G5L;"D-"B`@("![#0H@("`@("`@("1R970@/2!F86QS93L-"B`@("`@("`@
M:68@*"1L87EE<B`]/3T@;G5L;"D@>PT*("`@("`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/FQA>65R<R!A<R`D;&%Y97(I('L-"B`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R75LG9&5F875L
M=%]C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1R970@/2`D
M=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=6R=D969A=6QT7V-H86YN96PG
M73L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V5I9B`H:7-S970H
M)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R75LG9&5F875L=%]C:&%N;F5L
M)UTI*2![#0H@("`@("`@("`@("`D<F5T(#T@)'1H:7,M/F-O;F9I9W5R871I
M;VY;)&QA>65R75LG9&5F875L=%]C:&%N;F5L)UT[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"1R970@/3T@)W!E87(N<&AP+FYE="<@)B8@9&5F:6YE9"@G
M4$5!4E]254Y465!%)RD@)B8@4$5!4E]254Y465!%(#T]("=P96-L)RD@>PT*
M("`@("`@("`@("`@)')E="`]("=P96-L+G!H<"YN970G.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@D<F5T*2![#0H@("`@("`@("`@("!I9B`H)')E="`A
M/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M;&%Z>4-H86YN96Q3971U<"@I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@<F5T=7)N("1R970[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(%!%
M05)?0T].1DE'7T1%1D%53%1?0TA!3DY%3#L-"B`@("!]#0H-"B`@("`O+R![
M>WL@9V5T*&ME>2P@6VQA>65R72D-"B`@("`O*BH-"B`@("`@*B!2971U<FYS
M(&$@8V]N9FEG=7)A=&EO;B!V86QU92P@<')I;W)I=&EZ:6YG(&QA>65R<R!A
M<R!P97(@=&AE#0H@("`@("H@;&%Y97)S('!R;W!E<G1Y+@T*("`@("`J#0H@
M("`@("H@0'!A<F%M('-T<FEN9R!C;VYF:6<@:V5Y#0H@("`@("H-"B`@("`@
M*B!`<F5T=7)N(&UI>&5D('1H92!C;VYF:6<@=F%L=64L(&]R($Y53$P@:68@
M;F]T(&9O=6YD#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N(&=E="@D:V5Y+"`D;&%Y97(@/2!N=6QL+"`D
M8VAA;FYE;"`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^8V]N9FEG=7)A=&EO;E]I;F9O6R1K97E=*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N(&YU;&P[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1K97D@
M/3T@)U]?8VAA;FYE;',G*2![#0H@("`@("`@("`@("!R971U<FX@;G5L;#L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)&ME>2`]/2`G9&5F875L=%]C:&%N
M;F5L)RD@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG971$969A=6QT
M0VAA;FYE;"@D;&%Y97(I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A)&-H
M86YN96PI('L-"B`@("`@("`@("`@("1C:&%N;F5L(#T@)'1H:7,M/F=E=$1E
M9F%U;'1#:&%N;F5L*"D[#0H@("`@("`@('T@96QS96EF("@D8VAA;FYE;"`A
M/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@("`@("`@)'1H:7,M/E]L87IY
M0VAA;FYE;%-E='5P*"D[#0H@("`@("`@('T-"B`@("`@("`@)&-H86YN96P@
M/2!S=')T;VQO=V5R*"1C:&%N;F5L*3L-"B`@("`@("`@#0H@("`@("`@("1T
M97-T(#T@*&EN7V%R<F%Y*"1K97DL("1T:&ES+3Y?8VAA;FYE;$-O;F9I9TEN
M9F\I*2`_#0H@("`@("`@("`@("`D=&AI<RT^7V=E=$-H86YN96Q686QU92@D
M:V5Y+"`D;&%Y97(L("1C:&%N;F5L*2`Z#0H@("`@("`@("`@("!N=6QL.PT*
M("`@("`@("!I9B`H)'1E<W0@(3T](&YU;&PI('L-"B`@("`@("`@("`@(&EF
M("@D=&AI<RT^7VEN<W1A;&Q2;V]T*2![#0H@("`@("`@("`@("`@("`@:68@
M*&EN7V%R<F%Y*"1T:&ES+3YG971'<F]U<"@D:V5Y*2P-"B`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@G1FEL92!,;V-A=&EO;G,G+"`G1FEL92!,;V-A
M=&EO;G,@*$%D=F%N8V5D*2<I*2`F)@T*("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YG9714>7!E*"1K97DI(#T]("=D:7)E8W1O<GDG*2![#0H@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!R97!E;F10871H*"1T
M97-T+"`D=&AI<RT^7VEN<W1A;&Q2;V]T*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)'1E<W0[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"1L87EE<B`]/3T@;G5L;"D@>PT*("`@
M("`@("`@("`@9F]R96%C:"`H)'1H:7,M/FQA>65R<R!A<R`D;&%Y97(I('L-
M"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/F-O;F9I9W5R871I
M;VY;)&QA>65R75LD:V5Y72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1E
M<W0@/2`D=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=6R1K97E=.PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]I;G-T86QL4F]O="D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1T:&ES+3YG
M971'<F]U<"@D:V5Y*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"=&:6QE($QO8V%T:6]N<R<L("=&:6QE($QO8V%T:6]N<R`H061V
M86YC960I)RDI("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^9V5T5'EP92@D:V5Y*2`]/2`G9&ER96-T;W)Y)RD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!R97!E;F10
M871H*"1T97-T+"`D=&AI<RT^7VEN<W1A;&Q2;V]T*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("!I9B`H)&ME>2`]/2`G<')E9F5R<F5D7VUI<G)O<B<I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R96<@/2`F)'1H:7,M/F=E
M=%)E9VES=')Y*"D[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-?
M;V)J96-T*"1R96<I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&-H86X@/2`F)')E9RT^9V5T0VAA;FYE;"@D8VAA;FYE;"D[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&-H86XI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M8VAA;FYE;#L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"$D8VAA;BT^9V5T36ER<F]R
M*"1T97-T*2`F)B`D8VAA;BT^9V5T3F%M92@I("$]("1T97-T*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D8VAA;FYE;#L@
M+R\@;6ER<F]R(&1O97,@;F]T(&5X:7-T#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M=&5S=#L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T@96QS96EF("AI<W-E="@D=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y
M97)=6R1K97E=*2D@>PT*("`@("`@("`@("`@)'1E<W0@/2`D=&AI<RT^8V]N
M9FEG=7)A=&EO;ELD;&%Y97)=6R1K97E=.PT*("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?:6YS=&%L;%)O;W0I('L-"B`@("`@("`@("`@("`@("!I9B`H:6Y?
M87)R87DH)'1H:7,M/F=E=$=R;W5P*"1K97DI+`T*("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=&:6QE($QO8V%T:6]N<R<L("=&:6QE($QO8V%T:6]N
M<R`H061V86YC960I)RDI("8F#0H@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/F=E=%1Y<&4H)&ME>2D@/3T@)V1I<F5C=&]R>2<I('L-"B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<')E<&5N9%!A=&@H)'1E<W0L
M("1T:&ES+3Y?:6YS=&%L;%)O;W0I.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D:V5Y(#T]("=P<F5F97)R
M961?;6ER<F]R)RD@>PT*("`@("`@("`@("`@("`@("1R96<@/2`F)'1H:7,M
M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@("`@("`@("`@:68@*&ES7V]B:F5C
M="@D<F5G*2D@>PT*("`@("`@("`@("`@("`@("`@("`D8VAA;B`]("8D<F5G
M+3YG971#:&%N;F5L*"1C:&%N;F5L*3L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&-H86XI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)&-H86YN96P[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"$D8VAA;BT^9V5T36ER<F]R
M*"1T97-T*2`F)B`D8VAA;BT^9V5T3F%M92@I("$]("1T97-T*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("!R971U<FX@)&-H86YN96P[("\O(&UI<G)O
M<B!D;V5S(&YO="!E>&ES=`T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T
M=7)N("1T97-T.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!N=6QL.PT*
M("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!?9V5T0VAA;FYE;%9A
M;'5E*&ME>2P@=F%L=64L(%ML87EE<ETI#0H@("`@+RHJ#0H@("`@("H@4F5T
M=7)N<R!A(&-H86YN96PM<W!E8VEF:6,@8V]N9FEG=7)A=&EO;B!V86QU92P@
M<')I;W)I=&EZ:6YG(&QA>65R<R!A<R!P97(@=&AE#0H@("`@("H@;&%Y97)S
M('!R;W!E<G1Y+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R!C;VYF
M:6<@:V5Y#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&UI>&5D('1H92!C;VYF
M:6<@=F%L=64L(&]R($Y53$P@:68@;F]T(&9O=6YD#0H@("`@("H-"B`@("`@
M*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?9V5T
M0VAA;FYE;%9A;'5E*"1K97DL("1L87EE<BP@)&-H86YN96PI#0H@("`@>PT*
M("`@("`@("!I9B`H)&ME>2`]/2`G7U]C:&%N;F5L<R<@?'P@)&-H86YN96P@
M/3T@)W!E87(N<&AP+FYE="<I('L-"B`@("`@("`@("`@(')E='5R;B!N=6QL
M.PT*("`@("`@("!]#0H@("`@("`@("1R970@/2!N=6QL.PT*("`@("`@("!I
M9B`H)&QA>65R(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!F;W)E86-H("@D
M=&AI<RT^;&%Y97)S(&%S("1I;&%Y97(I('L-"B`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY;)&EL87EE<EU;)U]?8VAA
M;FYE;',G75LD8VAA;FYE;%U;)&ME>5TI*2![#0H@("`@("`@("`@("`@("`@
M("`@("1R970@/2`D=&AI<RT^8V]N9FEG=7)A=&EO;ELD:6QA>65R75LG7U]C
M:&%N;F5L<R==6R1C:&%N;F5L75LD:V5Y73L-"B`@("`@("`@("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("!](&5L<V5I9B`H:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY;
M)&QA>65R75LG7U]C:&%N;F5L<R==6R1C:&%N;F5L75LD:V5Y72DI('L-"B`@
M("`@("`@("`@("1R970@/2`D=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=
M6R=?7V-H86YN96QS)UU;)&-H86YN96Q=6R1K97E=.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@D:V5Y(#T]("=P<F5F97)R961?;6ER<F]R)RD@>PT*("`@
M("`@("`@("`@:68@*"1R970@(3T](&YU;&PI('L-"B`@("`@("`@("`@("`@
M("`D<F5G(#T@)B1T:&ES+3YG971296=I<W1R>2@D;&%Y97(I.PT*("`@("`@
M("`@("`@("`@(&EF("AI<U]O8FIE8W0H)')E9RDI('L-"B`@("`@("`@("`@
M("`@("`@("`@)&-H86X@/2`F)')E9RT^9V5T0VAA;FYE;"@D8VAA;FYE;"D[
M#0H@("`@("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C:&%N
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1C:&%N;F5L
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M(&EF("@A)&-H86XM/F=E=$UI<G)O<B@D<F5T*2`F)B`D8VAA;BT^9V5T3F%M
M92@I("$]("1R970I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D8VAA;FYE;#L@+R\@;6ER<F]R(&1O97,@;F]T(&5X:7-T#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@<F5T=7)N("1R970[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H)&-H86YN96P@/3T@)'1H:7,M/F=E=$1E9F%U;'1#:&%N;F5L*"1L
M87EE<BDI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)&-H86YN96P[("\O
M('=E(&UU<W0@=7-E('1H92!C:&%N;F5L(&YA;64@87,@=&AE('!R969E<G)E
M9"!M:7)R;W(-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O
M(&EF('1H92!U<V5R(&AA<R!N;W0@8VAO<V5N(&%N(&%L=&5R;F%T90T*("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/F=E=$1E9F%U;'1#:&%N;F5L*"1L87EE<BD[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@<V5T*&ME>2P@=F%L=64L(%ML87EE
M<ETI#0H-"B`@("`O*BH-"B`@("`@*B!3970@82!C;VYF:6<@=F%L=64@:6X@
M82!S<&5C:69I8R!L87EE<B`H9&5F875L=',@=&\@)W5S97(G*2X-"B`@("`@
M*B!%;F9O<F-E<R!T:&4@='EP97,@9&5F:6YE9"!I;B!T:&4@8V]N9FEG=7)A
M=&EO;E]I;F9O(&%R<F%Y+B`@06X-"B`@("`@*B!I;G1E9V5R(&-O;F9I9R!V
M87)I86)L92!W:6QL(&)E(&-A<W0@=&\@:6YT+"!A;F0@82!S970@8V]N9FEG
M#0H@("`@("H@=F%R:6%B;&4@=VEL;"!B92!V86QI9&%T960@86=A:6YS="!I
M=',@;&5G86P@=F%L=65S+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN
M9R!C;VYF:6<@:V5Y#0H@("`@("H@0'!A<F%M('-T<FEN9R!C;VYF:6<@=F%L
M=64-"B`@("`@*B!`<&%R86T@<W1R:6YG("AO<'1I;VYA;"D@8V]N9FEG(&QA
M>65R#0H@("`@("H@0'!A<F%M('-T<FEN9R!C:&%N;F5L('1O('-E="!T:&ES
M('9A;'5E(&9O<BP@;W(@;G5L;"!F;W(@9VQO8F%L('9A;'5E#0H@("`@("H@
M0')E='5R;B!B;V]L(%12544@;VX@<W5C8V5S<RP@1D%,4T4@;VX@9F%I;'5R
M90T*("`@("`J+PT*("`@(&9U;F-T:6]N('-E="@D:V5Y+"`D=F%L=64L("1L
M87EE<B`]("=U<V5R)RP@)&-H86YN96P@/2!F86QS92D-"B`@("![#0H@("`@
M("`@(&EF("@D:V5Y(#T]("=?7V-H86YN96QS)RD@>PT*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R72DI('L-"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&ME>2`]
M/2`G9&5F875L=%]C:&%N;F5L)RD@>PT*("`@("`@("`@("`@+R\@8V%N(&]N
M;'D@<V5T('1H:7,@=F%L=64@9VQO8F%L;'D-"B`@("`@("`@("`@("1C:&%N
M;F5L(#T@)W!E87(N<&AP+FYE="<[#0H@("`@("`@("`@("!I9B`H)'9A;'5E
M("$]("=P96%R+G!H<"YN970G*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/E]L87IY0VAA;FYE;%-E='5P*"1L87EE<BD[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"1K97D@/3T@)W!R969E<G)E9%]M:7)R
M;W(G*2![#0H@("`@("`@("`@("!I9B`H)&-H86YN96P@/3T@)U]?=7)I)RD@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L@+R\@8V%N)W0@<V5T
M('1H92!?7W5R:2!P<V5U9&\M8VAA;FYE;"=S(&UI<G)O<@T*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@)')E9R`]("8D=&AI<RT^9V5T4F5G:7-T<GDH
M)&QA>65R*3L-"B`@("`@("`@("`@(&EF("AI<U]O8FIE8W0H)')E9RDI('L-
M"B`@("`@("`@("`@("`@("`D8VAA;B`]("8D<F5G+3YG971#:&%N;F5L*"1C
M:&%N;F5L(#\@)&-H86YN96P@.B`G<&5A<BYP:'`N;F5T)RD[#0H@("`@("`@
M("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&-H86XI*2![#0H@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@:68@*"$D8VAA;BT^9V5T36ER<F]R*"1V86QU
M92D@)B8@)&-H86XM/F=E=$YA;64H*2`A/2`D=F%L=64I('L-"B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.R`O+R!M:7)R;W(@9&]E<R!N;W0@
M97AI<W0-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3YC;VYF:6=U<F%T:6]N
M7VEN9F];)&ME>5TI*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("`@('T-"B`@("`@("`@97AT<F%C="@D=&AI<RT^8V]N9FEG=7)A=&EO
M;E]I;F9O6R1K97E=*3L-"B`@("`@("`@<W=I=&-H("@D='EP92D@>PT*("`@
M("`@("`@("`@8V%S92`G:6YT96=E<B<Z#0H@("`@("`@("`@("`@("`@)'9A
M;'5E(#T@*&EN="DD=F%L=64[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("!C87-E("=S970G.B![#0H@("`@("`@("`@("`@("`@+R\@
M268@82!V86QI9%]S970@:7,@<W!E8VEF:65D+"!R97%U:7)E('1H92!V86QU
M92!T;PT*("`@("`@("`@("`@("`@("\O(&)E(&EN('1H92!S970N("!)9B!T
M:&5R92!I<R!N;R!V86QI9%]S970L(&%C8V5P=`T*("`@("`@("`@("`@("`@
M("\O(&%N>2!V86QU92X-"B`@("`@("`@("`@("`@("!I9B`H)'9A;&ED7W-E
M="D@>PT*("`@("`@("`@("`@("`@("`@("!R97-E="@D=F%L:61?<V5T*3L-
M"B`@("`@("`@("`@("`@("`@("`@:68@*"AK97DH)'9A;&ED7W-E="D@/3T]
M(#`@)B8@(6EN7V%R<F%Y*"1V86QU92P@)'9A;&ED7W-E="DI('Q\#0H@("`@
M("`@("`@("`@("`@("`@("`@("`H:V5Y*"1V86QI9%]S970I("$]/2`P("8F
M(&5M<'1Y*"1V86QI9%]S971;)'9A;'5E72DI*0T*("`@("`@("`@("`@("`@
M("`@("![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"$D8VAA;FYE;"D@>PT*("`@("`@("`@("`@)&-H
M86YN96P@/2`D=&AI<RT^9V5T*"=D969A=6QT7V-H86YN96PG+"!N=6QL+"`G
M<&5A<BYP:'`N;F5T)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I;E]A
M<G)A>2@D8VAA;FYE;"P@)'1H:7,M/E]C:&%N;F5L<RDI('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?;&%Z>4-H86YN96Q3971U<"@D;&%Y97(I.PT*("`@("`@
M("`@("`@)')E9R`]("8D=&AI<RT^9V5T4F5G:7-T<GDH)&QA>65R*3L-"B`@
M("`@("`@("`@(&EF("@D<F5G*2![#0H@("`@("`@("`@("`@("`@)&-H86YN
M96P@/2`D<F5G+3YC:&%N;F5L3F%M92@D8VAA;FYE;"D[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!I9B`H(6EN7V%R<F%Y*"1C:&%N;F5L+"`D=&AI
M<RT^7V-H86YN96QS*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&-H
M86YN96P@(3T@)W!E87(N<&AP+FYE="<I('L-"B`@("`@("`@("`@(&EF("AI
M;E]A<G)A>2@D:V5Y+"`D=&AI<RT^7V-H86YN96Q#;VYF:6=);F9O*2D@>PT*
M("`@("`@("`@("`@("`@("1T:&ES+3YC;VYF:6=U<F%T:6]N6R1L87EE<EU;
M)U]?8VAA;FYE;',G75LD8VAA;FYE;%U;)&ME>5T@/2`D=F%L=64[#0H@("`@
M("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(&EF("@D:V5Y(#T]
M("=D969A=6QT7V-H86YN96PG*2![#0H@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D<F5G*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<F5G(#T@)B1T
M:&ES+3YG971296=I<W1R>2@D;&%Y97(I.PT*("`@("`@("`@("`@("`@("`@
M("!I9B`H(21R96<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R96<@
M/2`F)'1H:7,M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1R
M96<I('L-"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@)')E9RT^8VAA
M;FYE;$YA;64H)'9A;'5E*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@:68@*"$D=F%L=64I('L-"B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^8V]N9FEG=7)A=&EO;ELD
M;&%Y97)=6R1K97E=(#T@)'9A;'5E.PT*("`@("`@("!I9B`H)&ME>2`]/2`G
M<&AP7V1I<B<@)B8@(21T:&ES+3Y?;F]296=I<W1R>2D@>PT*("`@("`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7W)E9VES=')Y6R1L87EE<ETI('Q\#0H@
M("`@("`@("`@("`@("`@("`D=F%L=64@(3T@)'1H:7,M/E]R96=I<W1R>5LD
M;&%Y97)=+3YI;G-T86QL7V1I<BD@>PT*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<F5G:7-T<GE;)&QA>65R72`]("9N97<@4$5!4E]296=I<W1R>2@D=F%L
M=64I.PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G26YI=&EA;&EZ961;
M)&QA>65R72`](&9A;'-E.PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G
M:7-T<GE;)&QA>65R72T^<V5T0V]N9FEG*"1T:&ES*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"B`@("!F=6YC=&EO;B!?;&%Z>4-H86YN96Q3971U<"@D
M=7-E;&%Y97(@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@D=&AI<RT^
M7VYO4F5G:7-T<GDI('L-"B`@("`@("`@("`@(')E='5R;CL-"B`@("`@("`@
M?0T*("`@("`@("`D;65R9V4@/2!F86QS93L-"B`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/E]R96=I<W1R>2!A<R`D;&%Y97(@/3X@)'`I('L-"B`@("`@("`@
M("`@(&EF("@D=7-E;&%Y97(@)B8@)'5S96QA>65R("$]("1L87EE<BD@>PT*
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@:68@*"$D=&AI<RT^7W)E9TEN:71I86QI>F5D6R1L87EE<ETI
M('L-"B`@("`@("`@("`@("`@("!I9B`H)&QA>65R(#T]("=D969A=6QT)R`F
M)B!I<W-E="@D=&AI<RT^7W)E9VES=')Y6R=U<V5R)UTI('Q\#0H@("`@("`@
M("`@("`@("`@("`@("`@:7-S970H)'1H:7,M/E]R96=I<W1R>5LG<WES=&5M
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("\O(&]N;'D@=7-E('1H92!D
M969A=6QT(')E9VES=')Y(&EF('1H97)E(&%R92!N;R!A;'1E<FYA=&EV97,-
M"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&EF("@A:7-?;V)J96-T*"1T:&ES+3Y?
M<F5G:7-T<GE;)&QA>65R72DI('L-"B`@("`@("`@("`@("`@("`@("`@:68@
M*"1P:'!D:7(@/2`D=&AI<RT^9V5T*"=P:'!?9&ER)RP@)&QA>65R+"`G<&5A
M<BYP:'`N;F5T)RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<F5G:7-T<GE;)&QA>65R72`]("9N97<@4$5!4E]296=I<W1R>2@D<&AP
M9&ER*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T
M<GE;)&QA>65R72T^<V5T0V]N9FEG*"1T:&ES*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<F5G26YI=&EA;&EZ961;)&QA>65R72`](&9A
M;'-E.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@=6YS970H)'1H:7,M/E]R96=I<W1R>5LD;&%Y97)=
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;CL-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T0VAA;FYE;',H)'1H:7,M/E]R96=I<W1R>5LD;&%Y
M97)=+3YL:7-T0VAA;FYE;',H*2P@)&UE<F=E*3L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7W)E9TEN:71I86QI>F5D6R1L87EE<ET@/2!T<G5E.PT*("`@
M("`@("`@("`@("`@("1M97)G92`]('1R=64[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("!]#0H@("`@+R\@>WM[('-E=$-H86YN96QS*"D-"B`@
M("`-"B`@("`O*BH-"B`@("`@*B!3970@=&AE(&QI<W0@;V8@8VAA;FYE;',N
M#0H@("`@("H-"B`@("`@*B!4:&ES('-H;W5L9"!B92!S970@=FEA(&$@8V%L
M;"!T;R![0&QI;FL@4$5!4E]296=I<W1R>3HZ;&ES=$-H86YN96QS*"E]#0H@
M("`@("H@0'!A<F%M(&%R<F%Y#0H@("`@("H@0'!A<F%M(&)O;VP-"B`@("`@
M*B!`<F5T=7)N(&)O;VP@<W5C8V5S<R!O9B!O<&5R871I;VX-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!S971#:&%N;F5L<R@D8VAA;FYE;',L("1M97)G92`]
M(&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D8VAA;FYE
M;',I*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"1M97)G92D@>PT*("`@("`@("`@("`@)'1H:7,M/E]C
M:&%N;F5L<R`](&%R<F%Y7VUE<F=E*"1T:&ES+3Y?8VAA;FYE;',L("1C:&%N
M;F5L<RD[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=&AI<RT^
M7V-H86YN96QS(#T@)&-H86YN96QS.PT*("`@("`@("!]#0H@("`@("`@(&9O
M<F5A8V@@*"1C:&%N;F5L<R!A<R`D8VAA;FYE;"D@>PT*("`@("`@("`@("`@
M)&-H86YN96P@/2!S=')T;VQO=V5R*"1C:&%N;F5L*3L-"B`@("`@("`@("`@
M(&EF("@D8VAA;FYE;"`]/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/FQA>65R<R!A<R`D;&%Y97(I('L-"B`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YC;VYF:6=U<F%T:6]N6R1L87EE
M<EU;)U]?8VAA;FYE;',G75LD8VAA;FYE;%TI#0H@("`@("`@("`@("`@("`@
M("`@("`@?'P@(6ES7V%R<F%Y*"1T:&ES+3YC;VYF:6=U<F%T:6]N6R1L87EE
M<EU;)U]?8VAA;FYE;',G75LD8VAA;FYE;%TI*2![#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YC;VYF:6=U<F%T:6]N6R1L87EE<EU;)U]?8VAA;FYE
M;',G75LD8VAA;FYE;%T@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@=')U
M93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T5'EP92AK
M97DI#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE('1Y<&4@;V8@82!C;VYF
M:6<@=F%L=64N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("!C;VYF
M:6<@:V5Y#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('-T<FEN9R!T>7!E+"!O
M;F4@;V8@(G-T<FEN9R(L(")I;G1E9V5R(BP@(F9I;&4B+`T*("`@("`J(")D
M:7)E8W1O<GDB+"`B<V5T(B!O<B`B<&%S<W=O<F0B+@T*("`@("`J#0H@("`@
M("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*@T*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&=E=%1Y<&4H)&ME>2D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^8V]N9FEG=7)A=&EO;E]I;F9O6R1K97E=*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YC;VYF:6=U<F%T:6]N7VEN9F];)&ME>5U;)W1Y
M<&4G73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=$1O8W,H:V5Y*0T*#0H@
M("`@+RHJ#0H@("`@("H@1V5T('1H92!D;V-U;65N=&%T:6]N(&9O<B!A(&-O
M;F9I9R!V86QU92X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@(&-O
M;F9I9R!K97D-"B`@("`@*@T*("`@("`J($!R971U<FX@<W1R:6YG(&1O8W5M
M96YT871I;VX@<W1R:6YG#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI
M8PT*("`@("`J#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T1&]C<R@D:V5Y
M*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YC;VYF:6=U<F%T
M:6]N7VEN9F];)&ME>5TI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/F-O;F9I9W5R871I;VY?:6YF;ULD:V5Y75LG9&]C)UT[#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"B`@("`@("`O+R!]?7T-
M"B`@("`O+R![>WL@9V5T4')O;7!T*&ME>2D-"@T*("`@("\J*@T*("`@("`J
M($=E="!T:&4@<VAO<G0@9&]C=6UE;G1A=&EO;B!F;W(@82!C;VYF:6<@=F%L
M=64N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("!C;VYF:6<@:V5Y
M#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('-T<FEN9R!S:&]R="!D;V-U;65N
M=&%T:6]N('-T<FEN9PT*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-
M"B`@("`@*@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%!R;VUP="@D:V5Y
M*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YC;VYF:6=U<F%T
M:6]N7VEN9F];)&ME>5TI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/F-O;F9I9W5R871I;VY?:6YF;ULD:V5Y75LG<')O;7!T)UT[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"B`@("`O+R!]?7T-
M"B`@("`O+R![>WL@9V5T1W)O=7`H:V5Y*0T*#0H@("`@+RHJ#0H@("`@("H@
M1V5T('1H92!P87)A;65T97(@9W)O=7`@9F]R(&$@8V]N9FEG(&ME>2X-"B`@
M("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@(&-O;F9I9R!K97D-"B`@("`@
M*@T*("`@("`J($!R971U<FX@<W1R:6YG('!A<F%M971E<B!G<F]U<`T*("`@
M("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*@T*("`@("`J+PT*
M("`@(&9U;F-T:6]N(&=E=$=R;W5P*"1K97DI#0H@("`@>PT*("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY?:6YF;ULD:V5Y72DI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^8V]N9FEG=7)A=&EO;E]I;F9O
M6R1K97E=6R=G<F]U<"==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T1W)O
M=7!S*"D-"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@;&ES="!O9B!P87)A
M;65T97(@9W)O=7!S+@T*("`@("`J#0H@("`@("H@0')E='5R;B!A<G)A>2!L
M:7-T(&]F('!A<F%M971E<B!G<F]U<',-"B`@("`@*@T*("`@("`J($!A8V-E
M<W,@<'5B;&EC#0H@("`@("H-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971'
M<F]U<',H*0T*("`@('L-"B`@("`@("`@)'1M<"`](&%R<F%Y*"D[#0H@("`@
M("`@(&9O<F5A8V@@*"1T:&ES+3YC;VYF:6=U<F%T:6]N7VEN9F\@87,@)&ME
M>2`]/B`D:6YF;RD@>PT*("`@("`@("`@("`@)'1M<%LD:6YF;ULG9W)O=7`G
M75T@/2`Q.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!A<G)A>5]K97ES
M*"1T;7`I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G971'
M<F]U<$ME>7,H*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!L:7-T(&]F
M('1H92!P87)A;65T97)S(&EN(&$@9W)O=7`N#0H@("`@("H-"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1G<F]U<"!P87)A;65T97(@9W)O=7`-"B`@("`@*@T*
M("`@("`J($!R971U<FX@87)R87D@;&ES="!O9B!P87)A;65T97)S(&EN("1G
M<F]U<`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*@T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$=R;W5P2V5Y<R@D9W)O=7`I#0H@
M("`@>PT*("`@("`@("`D:V5Y<R`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3YC;VYF:6=U<F%T:6]N7VEN9F\@87,@)&ME>2`]/B`D:6YF
M;RD@>PT*("`@("`@("`@("`@:68@*"1I;F9O6R=G<F]U<"==(#T]("1G<F]U
M<"D@>PT*("`@("`@("`@("`@("`@("1K97ES6UT@/2`D:V5Y.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D:V5Y<SL-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T4V5T5F%L=65S*&ME
M>2D-"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@;&ES="!O9B!A;&QO=V5D
M('-E="!V86QU97,@9F]R(&$@8V]N9FEG('9A;'5E+B`@4F5T=7)N<PT*("`@
M("`J($Y53$P@9F]R(&-O;F9I9R!V86QU97,@=&AA="!A<F4@;F]T('-E=',N
M#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("!C;VYF:6<@:V5Y#0H@
M("`@("H-"B`@("`@*B!`<F5T=7)N(&%R<F%Y(&5N=6UE<F%T960@87)R87D@
M;V8@<V5T('9A;'5E<RP@;W(@3E5,3"!I9B!T:&4-"B`@("`@*B`@("`@("`@
M("`@("`@(&-O;F9I9R!K97D@:7,@=6YK;F]W;B!O<B!N;W0@82!S970-"B`@
M("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!G9713971686QU97,H)&ME>2D-"B`@("![#0H@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^8V]N9FEG=7)A=&EO;E]I;F9O6R1K97E=
M*2`F)@T*("`@("`@("`@("`@:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY?
M:6YF;ULD:V5Y75LG='EP92==*2`F)@T*("`@("`@("`@("`@)'1H:7,M/F-O
M;F9I9W5R871I;VY?:6YF;ULD:V5Y75LG='EP92==(#T]("=S970G*0T*("`@
M("`@("![#0H@("`@("`@("`@("`D=F%L:61?<V5T(#T@)'1H:7,M/F-O;F9I
M9W5R871I;VY?:6YF;ULD:V5Y75LG=F%L:61?<V5T)UT[#0H@("`@("`@("`@
M("!R97-E="@D=F%L:61?<V5T*3L-"B`@("`@("`@("`@(&EF("AK97DH)'9A
M;&ED7W-E="D@/3T](#`I('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'9A
M;&ED7W-E=#L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B!A
M<G)A>5]K97ES*"1V86QI9%]S970I.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!N=6QL.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G
M971+97ES*"D-"@T*("`@("\J*@T*("`@("`J($=E="!A;&P@=&AE(&-U<G)E
M;G0@8V]N9FEG(&ME>7,N#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M('-I;7!L92!A<G)A>2!O9B!C;VYF:6<@:V5Y<PT*("`@("`J#0H@("`@("H@
M0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971+97ES
M*"D-"B`@("![#0H@("`@("`@("1K97ES(#T@87)R87DH*3L-"B`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/FQA>65R<R!A<R`D;&%Y97(I('L-"B`@("`@("`@
M("`@("1T97-T(#T@)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R73L-"B`@
M("`@("`@("`@(&EF("AI<W-E="@D=&5S=%LG7U]C:&%N;F5L<R==*2D@>PT*
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T97-T6R=?7V-H86YN96QS)UT@
M87,@)&-H86YN96P@/3X@)&-O;F9I9W,I('L-"B`@("`@("`@("`@("`@("`@
M("`@)&ME>7,@/2!A<G)A>5]M97)G92@D:V5Y<RP@)&-O;F9I9W,I.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@('5N
M<V5T*"1T97-T6R=?7V-H86YN96QS)UTI.PT*("`@("`@("`@("`@)&ME>7,@
M/2!A<G)A>5]M97)G92@D:V5Y<RP@)'1E<W0I.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B!A<G)A>5]K97ES*"1K97ES*3L-"B`@("!]#0H-"B`@("`O
M+R!]?7T-"B`@("`O+R![>WL@<F5M;W9E*&ME>2P@6VQA>65R72D-"@T*("`@
M("\J*@T*("`@("`J(%)E;6]V92!T:&4@82!C;VYF:6<@:V5Y(&9R;VT@82!S
M<&5C:69I8R!C;VYF:6<@;&%Y97(N#0H@("`@("H-"B`@("`@*B!`<&%R86T@
M<W1R:6YG(&-O;F9I9R!K97D-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I
M;F<@*&]P=&EO;F%L*2!C;VYF:6<@;&%Y97(-"B`@("`@*@T*("`@("`J($!R
M971U<FX@8F]O;"!44E5%(&]N('-U8V-E<W,L($9!3%-%(&]N(&9A:6QU<F4-
M"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@<F5M;W9E*"1K97DL("1L87EE<B`]("=U<V5R)RD-"B`@("![
M#0H@("`@("`@("1C:&%N;F5L(#T@)'1H:7,M/F=E=$1E9F%U;'1#:&%N;F5L
M*"D[#0H@("`@("`@(&EF("@D8VAA;FYE;"`A/3T@)W!E87(N<&AP+FYE="<I
M('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^8V]N9FEG=7)A=&EO
M;ELD;&%Y97)=6R=?7V-H86YN96QS)UU;)&-H86YN96Q=6R1K97E=*2D@>PT*
M("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3YC;VYF:6=U<F%T:6]N6R1L
M87EE<EU;)U]?8VAA;FYE;',G75LD8VAA;FYE;%U;)&ME>5TI.PT*("`@("`@
M("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^8V]N9FEG=7)A=&EO;ELD
M;&%Y97)=6R1K97E=*2D@>PT*("`@("`@("`@("`@=6YS970H)'1H:7,M/F-O
M;F9I9W5R871I;VY;)&QA>65R75LD:V5Y72D[#0H@("`@("`@("`@("!R971U
M<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(')E;6]V94QA>65R*&QA
M>65R*0T*#0H@("`@+RHJ#0H@("`@("H@5&5M<&]R87)I;'D@<F5M;W9E(&%N
M(&5N=&ER92!C;VYF:6<@;&%Y97(N("!54T4@5TE42"!#05)%(0T*("`@("`J
M#0H@("`@("H@0'!A<F%M('-T<FEN9R!C;VYF:6<@:V5Y#0H@("`@("H-"B`@
M("`@*B!`<&%R86T@<W1R:6YG("AO<'1I;VYA;"D@8V]N9FEG(&QA>65R#0H@
M("`@("H-"B`@("`@*B!`<F5T=7)N(&)O;VP@5%)512!O;B!S=6-C97-S+"!&
M04Q312!O;B!F86EL=7)E#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI
M8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(')E;6]V94QA>65R*"1L87EE<BD-
M"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^8V]N9FEG=7)A=&EO
M;ELD;&%Y97)=*2D@>PT*("`@("`@("`@("`@)'1H:7,M/F-O;F9I9W5R871I
M;VY;)&QA>65R72`](&%R<F%Y*"D[#0H@("`@("`@("`@("!R971U<FX@=')U
M93L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[('-T;W)E*%ML87EE<ETI#0H-"B`@
M("`O*BH-"B`@("`@*B!3=&]R97,@8V]N9FEG=7)A=&EO;B!D871A(&EN(&$@
M;&%Y97(N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG(&-O;F9I9R!L
M87EE<B!T;R!S=&]R90T*("`@("`J#0H@("`@("H@0')E='5R;B!B;V]L(%12
M544@;VX@<W5C8V5S<RP@;W(@4$5!4B!E<G)O<B!O;B!F86EL=7)E#0H@("`@
M("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N('-T;W)E*"1L87EE<B`]("=U<V5R)RP@)&1A=&$@/2!N=6QL*0T*("`@
M('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YW<FET94-O;F9I9T9I;&4H;G5L
M;"P@)&QA>65R+"`D9&%T82D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[('1O1&5F875L="AK97DI#0H-"B`@("`O*BH-"B`@("`@*B!5;G-E
M="!T:&4@=7-E<BUD969I;F5D('9A;'5E(&]F(&$@8V]N9FEG(&ME>2P@<F5V
M97)T:6YG('1H90T*("`@("`J('9A;'5E('1O('1H92!S>7-T96TM9&5F:6YE
M9"!O;F4N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG(&-O;F9I9R!K
M97D-"B`@("`@*@T*("`@("`J($!R971U<FX@8F]O;"!44E5%(&]N('-U8V-E
M<W,L($9!3%-%(&]N(&9A:6QU<F4-"B`@("`@*@T*("`@("`J($!A8V-E<W,@
M<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=&]$969A=6QT*"1K97DI
M#0H@("`@>PT*("`@("`@("!T<FEG9V5R7V5R<F]R*")014%27T-O;F9I9SHZ
M=&]$969A=6QT*"D@9&5P<F5C871E9"P@=7-E(%!%05)?0V]N9FEG.CIR96UO
M=F4H*2!I;G-T96%D(BP@15]54T527TY/5$E#12D[#0H@("`@("`@(')E='5R
M;B`D=&AI<RT^<F5M;W9E*"1K97DL("=U<V5R)RD[#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H@("`@+R\@>WM[(&1E9FEN961">2AK97DI#0H-"B`@("`O*BH-
M"B`@("`@*B!496QL<R!W:&%T(&-O;F9I9R!L87EE<B!T:&%T(&=E=',@=&\@
M9&5F:6YE(&$@:V5Y+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R!C
M;VYF:6<@:V5Y#0H@("`@("H@0'!A<F%M(&)O;VQE86X@<F5T=7)N('1H92!D
M969I;FEN9R!C:&%N;F5L#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('-T<FEN
M9WQA<G)A>2!T:&4@8V]N9FEG(&QA>65R+"!O<B!A;B!E;7!T>2!S=')I;F<@
M:68@;F]T(&9O=6YD+@T*("`@("`J#0H@("`@("H@("`@("`@("!I9B`D<F5T
M=7)N8VAA;FYE;"P@=&AE(')E='5R;B!I<R!A;B!A<G)A>2!A<G)A>2@G;&%Y
M97(G(#T^(&QA>65R;F%M92P-"B`@("`@*B`@("`@("`@("=C:&%N;F5L)R`]
M/B!C:&%N;F5L;F%M92DL(&]R(&%N(&5M<'1Y('-T<FEN9R!I9B!N;W0@9F]U
M;F0-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@9&5F:6YE9$)Y*"1K97DL("1R971U<FYC:&%N;F5L(#T@
M9F%L<V4I#0H@("`@>PT*("`@("`@("!F;W)E86-H("@D=&AI<RT^;&%Y97)S
M(&%S("1L87EE<BD@>PT*("`@("`@("`@("`@)&-H86YN96P@/2`D=&AI<RT^
M9V5T1&5F875L=$-H86YN96PH*3L-"B`@("`@("`@("`@(&EF("@D8VAA;FYE
M;"`A/3T@)W!E87(N<&AP+FYE="<I('L-"B`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R75LG7U]C:&%N;F5L
M<R==6R1C:&%N;F5L75LD:V5Y72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"1R971U<FYC:&%N;F5L*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FX@87)R87DH)VQA>65R)R`]/B`D;&%Y97(L("=C:&%N;F5L)R`]
M/B`D8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1L87EE<CL-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/F-O;F9I9W5R871I;VY;)&QA>65R75LD:V5Y72DI('L-"B`@("`@("`@("`@
M("`@("!I9B`H)')E='5R;F-H86YN96PI('L-"B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(&%R<F%Y*"=L87EE<B<@/3X@)&QA>65R+"`G8VAA;FYE;"<@
M/3X@)W!E87(N<&AP+FYE="<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!R971U<FX@)&QA>65R.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B`G)SL-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@:7-$969A=6QT960H:V5Y*0T*#0H@("`@+RHJ#0H@
M("`@("H@5&5L;',@=VAE=&AE<B!A(&-O;F9I9R!V86QU92!H87,@82!S>7-T
M96TM9&5F:6YE9"!V86QU92X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I
M;F<@("!C;VYF:6<@:V5Y#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&)O;VP-
M"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H-"B`@("`@
M*B!`9&5P<F5C871E9`T*("`@("`J+PT*("`@(&9U;F-T:6]N(&ES1&5F875L
M=&5D*"1K97DI#0H@("`@>PT*("`@("`@("!T<FEG9V5R7V5R<F]R*")014%2
M7T-O;F9I9SHZ:7-$969A=6QT960H*2!D97!R96-A=&5D+"!U<V4@4$5!4E]#
M;VYF:6<Z.F1E9FEN961">2@I(&EN<W1E860B+"!%7U5315)?3D]424-%*3L-
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YD969I;F5D0GDH)&ME>2D@/3T@)W-Y
M<W1E;2<[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&ES1&5F
M:6YE9"AK97DI#0H-"B`@("`O*BH-"B`@("`@*B!496QL<R!W:&5T:&5R(&$@
M9VEV96X@:V5Y(&5X:7-T<R!A<R!A(&-O;F9I9R!V86QU92X-"B`@("`@*@T*
M("`@("`J($!P87)A;2!S=')I;F<@8V]N9FEG(&ME>0T*("`@("`J#0H@("`@
M("H@0')E='5R;B!B;V]L('=H971H97(@/&-O;F9I9R!K97D^(&5X:7-T<R!I
M;B!T:&ES(&]B:F5C=`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I<T1E9FEN960H)&ME>2D-"B`@("![
M#0H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YL87EE<G,@87,@)&QA>65R*2![
M#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY;
M)&QA>65R75LD:V5Y72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@=')U
M93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&ES1&5F
M:6YE9$QA>65R*&ME>2D-"@T*("`@("\J*@T*("`@("`J(%1E;&QS('=H971H
M97(@82!G:79E;B!C;VYF:6<@;&%Y97(@97AI<W1S+@T*("`@("`J#0H@("`@
M("H@0'!A<F%M('-T<FEN9R!C;VYF:6<@;&%Y97(-"B`@("`@*@T*("`@("`J
M($!R971U<FX@8F]O;"!W:&5T:&5R(#QC;VYF:6<@;&%Y97(^(&5X:7-T<R!I
M;B!T:&ES(&]B:F5C=`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I<T1E9FEN961,87EE<B@D;&%Y97(I
M#0H@("`@>PT*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/F-O;F9I9W5R
M871I;VY;)&QA>65R72D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(&=E=$QA>65R<R@I#0H-"B`@("`O*BH-"B`@("`@*B!2971U<FYS('1H
M92!L87EE<G,@9&5F:6YE9"`H97AC97!T('1H92`G9&5F875L="<@;VYE*0T*
M("`@("`J#0H@("`@("H@0')E='5R;B!A<G)A>2!O9B!T:&4@9&5F:6YE9"!L
M87EE<G,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971,87EE<G,H*0T*("`@
M('L-"B`@("`@("`@)&-F(#T@)'1H:7,M/F-O;F9I9W5R871I;VX[#0H@("`@
M("`@('5N<V5T*"1C9ELG9&5F875L="==*3L-"B`@("`@("`@<F5T=7)N(&%R
M<F%Y7VME>7,H)&-F*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@87!I5F5R<VEO;B@I#0H@("`@9G5N8W1I;VX@87!I5F5R<VEO;B@I#0H@
M("`@>PT*("`@("`@("!R971U<FX@)S$N,2<[#0H@("`@?0T*("`@("\O('U]
M?0T*#0H@("`@+RHJ#0H@("`@("H@0')E='5R;B!014%27U)E9VES=')Y#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@)F=E=%)E9VES=')Y*"1U<V4@/2!N=6QL
M*0T*("`@('L-"B`@("`@("`@:68@*"1U<V4@/3T](&YU;&PI('L-"B`@("`@
M("`@("`@("1L87EE<B`]("=U<V5R)SL-"B`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("1L87EE<B`]("1U<V4[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<F5G:7-T<GE;)&QA>65R72DI('L-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7W)E9VES=')Y6R1L87EE<ET[#0H@("`@
M("`@('T@96QS96EF("@D=7-E(#T]/2!N=6QL("8F(&ES<V5T*"1T:&ES+3Y?
M<F5G:7-T<GE;)W-Y<W1E;2==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<F5G:7-T<GE;)W-Y<W1E;2==.PT*("`@("`@("!](&5L<V5I9B`H
M)'5S92`]/3T@;G5L;"`F)B!I<W-E="@D=&AI<RT^7W)E9VES=')Y6R=D969A
M=6QT)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R96=I<W1R
M>5LG9&5F875L="==.PT*("`@("`@("!](&5L<V5I9B`H)'5S92D@>PT*("`@
M("`@("`@("`@)&$@/2!F86QS93L-"B`@("`@("`@("`@(')E='5R;B`D83L-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("\O(&]N;'D@9V\@:&5R
M92!I9B!N=6QL('=A<R!P87-S960@:6X-"B`@("`@("`@("`@(&1I92@B0U))
M5$E#04P@15)23U(Z(%)E9VES=')Y(&-O=6QD(&YO="!B92!I;FET:6%L:7IE
M9"!F<F]M(&%N>2!V86QU92(I.PT*("`@("`@("!]#0H@("`@?0T*("`@("\J
M*@T*("`@("`J(%1H:7,@:7,@=&\@86QL;W<@8W5S=&]M:7IA=&EO;B!L:6ME
M('1H92!U<V4@;V8@:6YS=&%L;')O;W0-"B`@("`@*B!`<&%R86T@4$5!4E]2
M96=I<W1R>0T*("`@("`J($!R971U<FX@8F]O;`T*("`@("`J+PT*("`@(&9U
M;F-T:6]N('-E=%)E9VES=')Y*"8D<F5G+"`D;&%Y97(@/2`G=7-E<B<I#0H@
M("`@>PT*("`@("`@("!I9B`H)'1H:7,M/E]N;U)E9VES=')Y*2![#0H@("`@
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"%I;E]A<G)A>2@D;&%Y97(L(&%R<F%Y*"=U<V5R)RP@)W-Y<W1E;2<I*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@
M("`@("1T:&ES+3Y?<F5G:7-T<GE;)&QA>65R72`]("8D<F5G.PT*("`@("`@
M("!I9B`H:7-?;V)J96-T*"1R96<I*2![#0H@("`@("`@("`@("`D=&AI<RT^
M7W)E9VES=')Y6R1L87EE<ETM/G-E=$-O;F9I9R@D=&AI<RD[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@;F]296=I<W1R>2@I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7VYO4F5G
M:7-T<GD@/2!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!R971U
M<FX@4$5!4E]296UO=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F9V5T4F5M
M;W1E*"D-"B`@("![#0H@("`@("`@("1R96UO=&4@/2`F;F5W(%!%05)?4F5M
M;W1E*"1T:&ES*3L-"B`@("`@("`@<F5T=7)N("1R96UO=&4[#0H@("`@?0T*
M#0H@("`@+RHJ#0H@("`@("H@0')E='5R;B!014%27U)%4U0-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B`F9V5T4D535"@D=F5R<VEO;BP@)&]P=&EO;G,@/2!A
M<G)A>2@I*0T*("`@('L-"B`@("`@("`@)'9E<G-I;VX@/2!S=')?<F5P;&%C
M92@G+B<L("<G+"`D=F5R<VEO;BD[#0H@("`@("`@(&EF("@A8VQA<W-?97AI
M<W1S*"1C;&%S<R`]("=014%27U)%4U1?)R`N("1V97)S:6]N*2D@>PT*("`@
M("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+U)%4U0O)R`N("1V97)S:6]N
M("X@)RYP:'`G.PT*("`@("`@("!]#0H@("`@("`@("1R96UO=&4@/2`F;F5W
M("1C;&%S<R@D=&AI<RP@)&]P=&EO;G,I.PT*("`@("`@("!R971U<FX@)')E
M;6]T93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!4:&4@9G1P('-E<G9E
M<B!I<R!S970@:6X@>T!L:6YK(')E861&5%!#;VYF:6=&:6QE*"E]+B`@270@
M97AI<W1S(&]N;'D@:68@80T*("`@("`J(')E;6]T92!C;VYF:6=U<F%T:6]N
M(&9I;&4@:&%S(&)E96X@<W!E8VEF:65D#0H@("`@("H@0')E='5R;B!014%2
M7T944'QF86QS90T*("`@("`J+PT*("`@(&9U;F-T:6]N("9G971&5%`H*0T*
M("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?9G1P*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9G1P.PT*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@)&$@/2!F86QS93L-"B`@("`@("`@("`@(')E='5R
M;B`D83L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O('M[>R!?<')E<&5N
M9%!A=&@H)'!A=&@L("1P<F5P96YD*0T*#0H@("`@9G5N8W1I;VX@7W!R97!E
M;F10871H*"1P871H+"`D<')E<&5N9"D-"B`@("![#0H@("`@("`@(&EF("AS
M=')L96XH)'!R97!E;F0I(#X@,"D@>PT*("`@("`@("`@("`@:68@*$]37U=)
M3D1/5U,@)B8@<')E9U]M871C:"@G+UY;82UZ73HO:2<L("1P871H*2D@>PT*
M("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7EMA+7I=.B]I)RP@
M)'!R97!E;F0I*2![#0H@("`@("`@("`@("`@("`@("`@("1P<F5P96YD(#T@
M<W5B<W1R*"1P<F5P96YD+"`R*3L-"B`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H)'!R97!E;F1[,'T@(3T@)UQ<)RD@>PT*("`@("`@("`@("`@("`@("`@
M("`D<')E<&5N9"`](")<7"1P<F5P96YD(CL-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)'!A=&@@/2!S=6)S='(H)'!A=&@L(#`L(#(I
M("X@)'!R97!E;F0@+B!S=6)S='(H)'!A=&@L(#(I.PT*("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D<&%T:"`]("1P<F5P96YD("X@
M)'!A=&@[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N("1P871H.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\J*@T*("`@
M("`J($!P87)A;2!S=')I;F=\9F%L<V4@:6YS=&%L;&%T:6]N(&1I<F5C=&]R
M>2!T;R!P<F5P96YD('1O(&%L;"!?9&ER('9A<FEA8FQE<RP@;W(@9F%L<V4@
M=&\-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&1I<V%B;&4-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!S971);G-T86QL4F]O="@D<F]O="D-"B`@("![
M#0H@("`@("`@(&EF("AS=6)S='(H)')O;W0L("TQ*2`]/2!$25)%0U1/4EE?
M4T5005)!5$]2*2![#0H@("`@("`@("`@("`D<F]O="`]('-U8G-T<B@D<F]O
M="P@,"P@+3$I.PT*("`@("`@("!]#0H@("`@("`@("1O;&0@/2`D=&AI<RT^
M7VEN<W1A;&Q2;V]T.PT*("`@("`@("`D=&AI<RT^7VEN<W1A;&Q2;V]T(#T@
M)')O;W0[#0H@("`@("`@(&EF("@H)&]L9"`A/2`D<F]O="D@)B8@(21T:&ES
M+3Y?;F]296=I<W1R>2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H87)R87E?
M:V5Y<R@D=&AI<RT^7W)E9VES=')Y*2!A<R`D;&%Y97(I('L-"B`@("`@("`@
M("`@("`@("!I9B`H)&QA>65R(#T]("=F='`G('Q\("%I<W-E="@D=&AI<RT^
M7W)E9VES=')Y6R1L87EE<ETI*2![#0H@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7W)E9VES=')Y6R1L87EE<ET@/0T*("`@("`@("`@("`@("`@("`@
M("`F;F5W(%!%05)?4F5G:7-T<GDH)'1H:7,M/F=E="@G<&AP7V1I<B<L("1L
M87EE<BP@)W!E87(N<&AP+FYE="<I*3L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7W)E9VES=')Y6R1L87EE<ETM/G-E=$-O;F9I9R@D=&AI<RD[#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/E]R96=);FET:6%L:7IE9%LD;&%Y97)=(#T@
M9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0I]#0H-
M"C\^#0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]$97!E;F1E;F-Y+G!H
M<```````````````````````````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#,R,C(`,3`U
M,34T,S,W-#$`,#(R,3(S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP#0HO+PT*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK#0HO+R!\(%!(4"!697)S:6]N(#4@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!#;W!Y<FEG:'0@
M*&,I(#$Y.3<M,C`P-"!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L-"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I
M;VX@,RXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`T*+R\@?"!T:&%T
M(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#
M14Y312P@86YD(&ES("`@("`@("!\#0HO+R!\(&%V86EL86)L92!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG('5R;#H@("`@
M("`@("`@('P-"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@
M?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI
M8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\#0HO+R!\(&]B=&%I;B!I="!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E
M('1O("`@("`@("`@('P-"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A
M;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@
M?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\($%U=&AO
M<G,Z(%1O;6%S(%8N5BY#;W@@/&-O>$!I9&5C;F5T+F-O;3X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P-"B\O('P@("`@("`@("`@4W1I9R!"86MK
M96X@/'-S8D!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+PT*
M+R\@5$A)4R!&24Q%($E3($1%4%)%0T%4140@24X@1D%63U(@3T8@1$5014Y$
M14Y#63(N4$A0+"!!3D0@25,@3D]4(%53140@24X@5$A%($E.4U1!3$Q%4@T*
M+R\@)$ED.B!$97!E;F1E;F-Y+G!H<"QV(#$N-#$@,C`P-B\P,2\P-B`P-#HT
M-SHS-B!C96QL;V<@17AP("0-"@T*<F5Q=6ER95]O;F-E(")014%2+G!H<"([
M#0IR97%U:7)E7V]N8V4@(D]3+T=U97-S+G!H<"([#0H-"F1E9FEN92@G4$5!
M4E]$15!%3D1%3D-97TU)4U-)3D<G+"`@("`@("`@+3$I.PT*9&5F:6YE*"=0
M14%27T1%4$5.1$5.0UE?0T].1DQ)0U0G+"`@("`@("`M,BD[#0ID969I;F4H
M)U!%05)?1$5014Y$14Y#65]54$=2041%7TU)3D]2)RP@("TS*3L-"F1E9FEN
M92@G4$5!4E]$15!%3D1%3D-97U501U)!1$5?34%*3U(G+"`@+30I.PT*9&5F
M:6YE*"=014%27T1%4$5.1$5.0UE?0D%$7T1%4$5.1$5.0UDG+"`M-2D[#0ID
M969I;F4H)U!%05)?1$5014Y$14Y#65]-25-324Y'7T]05$E/3D%,)RP@+38I
M.PT*9&5F:6YE*"=014%27T1%4$5.1$5.0UE?0T].1DQ)0U1?3U!424].04PG
M+"`@("`@("`M-RD[#0ID969I;F4H)U!%05)?1$5014Y$14Y#65]54$=2041%
M7TU)3D]27T]05$E/3D%,)RP@("TX*3L-"F1E9FEN92@G4$5!4E]$15!%3D1%
M3D-97U501U)!1$5?34%*3U)?3U!424].04PG+"`@+3DI.PT*#0HO*BH-"B`J
M($1E<&5N9&5N8WD@8VAE8VL@9F]R(%!%05(@<&%C:V%G97,-"B`J#0H@*B!4
M:&4@8VQA<W,@:7,@8F%S960@;VX@=&AE(&1E<&5N9&5N8WD@4D9#('1H870@
M8V%N(&)E(&9O=6YD(&%T#0H@*B!H='1P.B\O8W9S+G!H<"YN970O8W9S+G!H
M<"]P96%R=V5B+W)F8RX@270@<F5Q=6ER97,@4$A0(#X](#0N,0T*("H-"B`J
M($!A=71H;W(@5&]M87,@5BY6+E9O>"`\8V]X0&ED96-N970N8V]M/@T*("H@
M0&%U=&AO<B!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B\-"F-L87-S
M(%!%05)?1&5P96YD96YC>0T*>PT*("`@("\O('M[>R!C;VYS=')U8W1O<@T*
M("`@("\J*@T*("`@("`J($-O;G-T<G5C=&]R#0H@("`@("H-"B`@("`@*B!`
M86-C97-S('!U8FQI8PT*("`@("`J($!P87)A;2`@;V)J96-T(%)E9VES=')Y
M(&]B:F5C=`T*("`@("`J($!R971U<FX@=F]I9`T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(%!%05)?1&5P96YD96YC>2@F)')E9VES=')Y*0T*("`@('L-"B`@
M("`@("`@)'1H:7,M/G)E9VES=')Y(#T@)B1R96=I<W1R>3L-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8V%L;$-H96-K365T:&]D*"D-"@T*
M("`@("\J*@T*("`@("H@5&AI<R!M971H;V0@;6%P<R!T:&4@6$U,(&1E<&5N
M9&5N8WD@9&5F:6YI=&EO;B!T;R!T:&4-"B`@("`J(&-O<G)E<W!O;F1I;F<@
M;VYE(&9R;VT@4$5!4E]$97!E;F1E;F-Y#0H@("`@*@T*("`@("H@/'!R93X-
M"B`@("`J("1O<'1S(#T^($%R<F%Y#0H@("`@*B`@("`H#0H@("`@*B`@("`@
M("`@6W1Y<&5=(#T^('!K9PT*("`@("H@("`@("`@(%MR96Q=(#T^(&=E#0H@
M("`@*B`@("`@("`@6W9E<G-I;VY=(#T^(#,N-`T*("`@("H@("`@("`@(%MN
M86UE72`]/B!(5$U,7T-O;6UO;@T*("`@("H@("`@("`@(%MO<'1I;VYA;%T@
M/3X@9F%L<V4-"B`@("`J("`@("D-"B`@("`J(#PO<')E/@T*("`@("H-"B`@
M("`J($!P87)A;2`@<W1R:6YG($5R<F]R(&UE<W-A9V4-"B`@("`J($!P87)A
M;2`@87)R87D@($]P=&EO;G,-"B`@("`J($!R971U<FX@8F]O;&5A;@T*("`@
M("HO#0H@("`@9G5N8W1I;VX@8V%L;$-H96-K365T:&]D*"8D97)R;7-G+"`D
M;W!T<RD-"B`@("![#0H@("`@("`@("1R96P@/2!I<W-E="@D;W!T<ULG<F5L
M)UTI(#\@)&]P='-;)W)E;"==(#H@)VAA<R<[#0H@("`@("`@("1R97$@/2!I
M<W-E="@D;W!T<ULG=F5R<VEO;B==*2`_("1O<'1S6R=V97)S:6]N)UT@.B!N
M=6QL.PT*("`@("`@("`D;F%M92`](&ES<V5T*"1O<'1S6R=N86UE)UTI(#\@
M)&]P='-;)VYA;64G72`Z(&YU;&P[#0H@("`@("`@("1C:&%N;F5L(#T@:7-S
M970H)&]P='-;)V-H86YN96PG72D@/R`D;W!T<ULG8VAA;FYE;"==(#H@)W!E
M87(N<&AP+FYE="<[#0H@("`@("`@("1O<'0@/2`H:7-S970H)&]P='-;)V]P
M=&EO;F%L)UTI("8F("1O<'1S6R=O<'1I;VYA;"==(#T]("=Y97,G*2`_#0H@
M("`@("`@("`@("`D;W!T<ULG;W!T:6]N86PG72`Z(&YU;&P[#0H@("`@("`@
M("1E<G)M<V<@/2`G)SL-"B`@("`@("`@<W=I=&-H("@D;W!T<ULG='EP92==
M*2![#0H@("`@("`@("`@("!C87-E("=P:V<G.@T*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^8VAE8VM086-K86=E*"1E<G)M<V<L("1N86UE+"`D
M<F5Q+"`D<F5L+"`D;W!T+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@("`@("!C87-E("=E>'0G.@T*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^8VAE8VM%>'1E;G-I;VXH)&5R<FUS9RP@)&YA
M;64L("1R97$L("1R96PL("1O<'0I.PT*("`@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("`@("`@8V%S92`G<&AP)SH-"B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/F-H96-K4$A0*"1E<G)M<V<L("1R97$L("1R96PI.PT*
M("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G<')O
M9R<Z#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YC:&5C:U!R;V=R
M86TH)&5R<FUS9RP@)&YA;64I.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("`@("`@8V%S92`G;W,G.@T*("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^8VAE8VM/4R@D97)R;7-G+"`D;F%M92D[#0H@("`@("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=S87!I)SH-"B`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/F-H96-K4T%022@D97)R;7-G+"`D
M;F%M92D[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C
M87-E("=Z96YD)SH-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/F-H
M96-K6F5N9"@D97)R;7-G+"`D;F%M92D[#0H@("`@("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@("`@("!D969A=6QT.@T*("`@("`@("`@("`@("`@(')E
M='5R;B`B)WLD;W!T<ULG='EP92==?2<@9&5P96YD96YC>2!T>7!E(&YO="!S
M=7!P;W)T960B.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(&-H96-K4&%C:V%G92@I#0H-"B`@("`O*BH-"B`@("`@*B!0
M86-K86=E(&1E<&5N9&5N8VEE<R!C:&5C:R!M971H;V0-"B`@("`@*@T*("`@
M("`J($!P87)A;2!S=')I;F<@)&5R<FUS9R`@("!%;7!T>2!S=')I;F<L(&ET
M('=I;&P@8F4@<&]P=6QA=&5D('=I=&@@86X@97)R;W(@;65S<V%G92P@:68@
M86YY#0H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@($YA;64@;V8@
M=&AE('!A8VMA9V4@=&\@=&5S=`T*("`@("`J($!P87)A;2!S=')I;F<@)')E
M<2`@("`@("!4:&4@<&%C:V%G92!V97)S:6]N(')E<75I<F5D#0H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<F5L871I;VX@($AO=R!T;R!C;VUP87)E('9E<G-I
M;VYS('=I=&@@96%C:"!O=&AE<@T*("`@("`J($!P87)A;2!B;V]L("`@)&]P
M="`@("`@("!7:&5T:&5R('1H92!R96QA=&EO;G-H:7`@:7,@;W!T:6]N86P-
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:&%N;F5L("`@0VAA;FYE;"!N86UE
M#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&UI>&5D(&)O;VP@9F%L<V4@:68@
M;F\@97)R;W(@;W(@=&AE(&5R<F]R('-T<FEN9PT*("`@("`J+PT*("`@(&9U
M;F-T:6]N(&-H96-K4&%C:V%G92@F)&5R<FUS9RP@)&YA;64L("1R97$@/2!N
M=6QL+"`D<F5L871I;VX@/2`G:&%S)RP-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&]P="`](&9A;'-E+"`D8VAA;FYE;"`]("=P96%R+G!H<"YN970G
M*0T*("`@('L-"B`@("`@("`@:68@*&ES7W-T<FEN9R@D<F5Q*2`F)B!S=6)S
M='(H)')E<2P@,"P@,BD@/3T@)W8N)RD@>PT*("`@("`@("`@("`@)')E<2`]
M('-U8G-T<B@D<F5Q+"`R*3L-"B`@("`@("`@?0T*("`@("`@("!S=VET8V@@
M*"1R96QA=&EO;BD@>PT*("`@("`@("`@("`@8V%S92`G:&%S)SH-"B`@("`@
M("`@("`@("`@("!I9B`H(21T:&ES+3YR96=I<W1R>2T^<&%C:V%G945X:7-T
M<R@D;F%M92P@)&-H86YN96PI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF
M("@D;W!T*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D97)R;7-G(#T@
M(G!A8VMA9V4@8"1C:&%N;F5L+R1N86UE)R!I<R!R96-O;6UE;F1E9"!T;R!U
M=&EL:7IE('-O;64@9F5A='5R97,N(CL-"B`@("`@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!014%27T1%4$5.1$5.0UE?34E34TE.1U]/4%1)3TY!3#L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D
M97)R;7-G(#T@(G)E<75I<F5S('!A8VMA9V4@8"1C:&%N;F5L+R1N86UE)R([
M#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%27T1%4$5.1$5.0UE?
M34E34TE.1SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@8V%S92`G;F]T)SH-"B`@("`@
M("`@("`@("`@("!I9B`H)'1H:7,M/G)E9VES=')Y+3YP86-K86=E17AI<W1S
M*"1N86UE+"`D8VAA;FYE;"DI('L-"B`@("`@("`@("`@("`@("`@("`@)&5R
M<FUS9R`](")C;VYF;&EC=',@=VET:"!P86-K86=E(&`D8VAA;FYE;"\D;F%M
M92<B.PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4E]$15!%3D1%
M3D-97T-/3D9,24-4.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!C87-E("=L="<Z#0H@
M("`@("`@("`@("!C87-E("=L92<Z#0H@("`@("`@("`@("!C87-E("=E<2<Z
M#0H@("`@("`@("`@("!C87-E("=N92<Z#0H@("`@("`@("`@("!C87-E("=G
M92<Z#0H@("`@("`@("`@("!C87-E("=G="<Z#0H@("`@("`@("`@("`@("`@
M)'9E<G-I;VX@/2`D=&AI<RT^<F5G:7-T<GDM/G!A8VMA9V5);F9O*"1N86UE
M+"`G=F5R<VEO;B<L("1C:&%N;F5L*3L-"B`@("`@("`@("`@("`@("!I9B`H
M(21T:&ES+3YR96=I<W1R>2T^<&%C:V%G945X:7-T<R@D;F%M92P@)&-H86YN
M96PI#0H@("`@("`@("`@("`@("`@("`@('Q\("%V97)S:6]N7V-O;7!A<F4H
M(B1V97)S:6]N(BP@(B1R97$B+"`D<F5L871I;VXI*0T*("`@("`@("`@("`@
M("`@('L-"B`@("`@("`@("`@("`@("`@("`@)&-O9&4@/2`D=&AI<RT^8V]D
M949R;VU296QA=&EO;B@D<F5L871I;VXL("1V97)S:6]N+"`D<F5Q+"`D;W!T
M*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1O<'0I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1E<G)M<V<@/2`B<&%C:V%G92!@)&-H86YN96PO
M)&YA;64G('9E<G-I;VX@(B`N("1T:&ES+3YS:6=N3W!E<F%T;W(H)')E;&%T
M:6]N*2`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(B`D<F5Q(&ES
M(')E8V]M;65N9&5D('1O('5T:6QI>F4@<V]M92!F96%T=7)E<RXB.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"1V97)S:6]N*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&5R<FUS9R`N/2`B("!);G-T86QL960@
M=F5R<VEO;B!I<R`D=F5R<VEO;B([#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)&-O9&4[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)&5R
M<FUS9R`](")R97%U:7)E<R!P86-K86=E(&`D8VAA;FYE;"\D;F%M92<@(B`N
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<VEG;D]P97)A=&]R
M*"1R96QA=&EO;BD@+B`B("1R97$B.PT*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)&-O9&4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D97)R;7-G
M(#T@(G)E;&%T:6]N("<D<F5L871I;VXG('=I=&@@<F5Q=6ER96UE;G0@)R1R
M97$G(&ES(&YO="!S=7!P;W)T960@*&YA;64])&-H86YN96PO)&YA;64I(CL-
M"B`@("`@("`@<F5T=7)N(%!%05)?1$5014Y$14Y#65]"041?1$5014Y$14Y#
M63L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8VAE8VM086-K
M86=E56YI;G-T86QL*"D-"@T*("`@("\J*@T*("`@("`J($-H96-K('!A8VMA
M9V4@9&5P96YD96YC:65S(&]N('5N:6YS=&%L;`T*("`@("`J#0H@("`@("H@
M0'!A<F%M('-T<FEN9R`D97)R;W(@("`@(%1H92!R97-U;'1A;G0@97)R;W(@
M<W1R:6YG#0H@("`@("H@0'!A<F%M('-T<FEN9R`D=V%R;FEN9R`@(%1H92!R
M97-U;'1A;G0@=V%R;FEN9R!S=')I;F<-"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("`@("`@3F%M92!O9B!T:&4@<&%C:V%G92!T;R!T97-T#0H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8VAA;FYE;"`@($-H86YN96P@;F%M92!O9B!T
M:&4@<&%C:V%G90T*("`@("`J#0H@("`@("H@0')E='5R;B!B;V]L('1R=64@
M:68@=&AE<F4@=V5R92!E<G)O<G,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!C
M:&5C:U!A8VMA9V55;FEN<W1A;&PH)B1E<G)O<BP@)B1W87)N:6YG+"`D<&%C
M:V%G92P@)&-H86YN96P@/2`G<&5A<BYP:'`N;F5T)RD-"B`@("![#0H@("`@
M("`@("1C:&%N;F5L(#T@<W1R=&]L;W=E<B@D8VAA;FYE;"D[#0H@("`@("`@
M("1E<G)O<B`](&YU;&P[#0H@("`@("`@("1C:&%N;F5L<R`]("1T:&ES+3YR
M96=I<W1R>2T^;&ES=$%L;%!A8VMA9V5S*"D[#0H@("`@("`@(&9O<F5A8V@@
M*"1C:&%N;F5L<R!A<R`D8VAA;FYE;&YA;64@/3X@)'!A8VMA9V5S*2![#0H@
M("`@("`@("`@("!F;W)E86-H("@D<&%C:V%G97,@87,@)'!K9RD@>PT*("`@
M("`@("`@("`@("`@(&EF("@D<&MG(#T]("1P86-K86=E("8F("1C:&%N;F5L
M(#T]("1C:&%N;F5L;F%M92D@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&1E
M<',@/2`D=&AI<RT^<F5G:7-T<GDM/G!A8VMA9V5);F9O*"1P:V<L("=R96QE
M87-E7V1E<',G+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@:68@*&5M
M<'1Y*"1D97!S*2D@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)&1E<',@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@("`@("`D9&5P8VAA
M;FYE;"`](&ES<V5T*"1D97!;)V-H86YN96PG72D@/R`D9&5P6R=C:&%N;F5L
M)UT@.B`G<&5A<BYP:'`N;F5T)SL-"B`@("`@("`@("`@("`@("`@("`@:68@
M*"1D97!;)W1Y<&4G72`]/2`G<&MG)R`F)B`H<W1R8V%S96-M<"@D9&5P6R=N
M86UE)UTL("1P86-K86=E*2`]/2`P*2`F)@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`H)&1E<&-H86YN96P@/3T@)&-H86YN96PI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)&1E<%LG<F5L)UT@/3T@)VYE)RD@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1D97!;)V]P=&EO;F%L)UTI("8F("1D97!;)V]P=&EO;F%L
M)UT@/3T@)WEE<R<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=V%R;FEN9R`N/2`B7&Y787)N:6YG.B!086-K86=E("<D9&5P8VAA;FYE;"\D
M<&MG)R!O<'1I;VYA;&QY(&1E<&5N9',@;VX@)R1C:&%N;F5L.B]P86-K86=E
M)R([#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1E<G)O<B`N/2`B4&%C:V%G92`G)&1E
M<&-H86YN96PO)'!K9R<@9&5P96YD<R!O;B`G)&-H86YN96PO)'!A8VMA9V4G
M7&XB.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(')E='5R;B`H)&5R<F]R*2`_('1R=64@.B!F
M86QS93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8VAE8VM%
M>'1E;G-I;VXH*0T*#0H@("`@+RHJ#0H@("`@("H@17AT96YS:6]N(&1E<&5N
M9&5N8VEE<R!C:&5C:R!M971H;V0-"B`@("`@*@T*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@("`@("`@($YA;64@;V8@=&AE(&5X=&5N<VEO;B!T;R!T
M97-T#0H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5Q7V5X=%]V97(@4F5Q=6ER
M960@97AT96YS:6]N('9E<G-I;VX@=&\@8V]M<&%R92!W:71H#0H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<F5L871I;VX@("`@2&]W('1O(&-O;7!A<F4@=F5R
M<VEO;G,@=VET:"!E86-H;W1H97(-"B`@("`@*B!`<&%R86T@8F]O;"`@("1O
M<'0@("`@("`@("!7:&5T:&5R('1H92!R96QA=&EO;G-H:7`@:7,@;W!T:6]N
M86P-"B`@("`@*@T*("`@("`J($!R971U<FX@;6EX960@8F]O;"!F86QS92!I
M9B!N;R!E<G)O<B!O<B!T:&4@97)R;W(@<W1R:6YG#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@8VAE8VM%>'1E;G-I;VXH)B1E<G)M<V<L("1N86UE+"`D<F5Q
M(#T@;G5L;"P@)')E;&%T:6]N(#T@)VAA<R<L#0H@("`@("`@("1O<'0@/2!F
M86QS92D-"B`@("![#0H@("`@("`@(&EF("@D<F5L871I;VX@/3T@)VYO="<I
M('L-"B`@("`@("`@("`@(&EF("AE>'1E;G-I;VY?;&]A9&5D*"1N86UE*2D@
M>PT*("`@("`@("`@("`@("`@("1E<G)M<V<@/2`B8V]N9FQI8W1S('=I=&@@
M(%!(4"!E>'1E;G-I;VX@)R1N86UE)R([#0H@("`@("`@("`@("`@("`@<F5T
M=7)N(%!%05)?1$5014Y$14Y#65]#3TY&3$E#5#L-"B`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@:68@*"%E>'1E;G-I;VY?
M;&]A9&5D*"1N86UE*2D@>PT*("`@("`@("`@("`@:68@*"1R96QA=&EO;B`]
M/2`G;F4G*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1O<'0I('L-"B`@("`@("`@
M("`@("`@("`D97)R;7-G(#T@(B<D;F%M92<@4$A0(&5X=&5N<VEO;B!I<R!R
M96-O;6UE;F1E9"!T;R!U=&EL:7IE('-O;64@9F5A='5R97,B.PT*("`@("`@
M("`@("`@("`@(')E='5R;B!014%27T1%4$5.1$5.0UE?34E34TE.1U]/4%1)
M3TY!3#L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1E<G)M<V<@/2`B
M)R1N86UE)R!02%`@97AT96YS:6]N(&ES(&YO="!I;G-T86QL960B.PT*("`@
M("`@("`@("`@<F5T=7)N(%!%05)?1$5014Y$14Y#65]-25-324Y'.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("@D<F5L871I;VX@/3T@)VAA<R<I('L-"B`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D
M8V]D92`](&9A;'-E.PT*("`@("`@("!I9B`H:7-?<W1R:6YG*"1R97$I("8F
M('-U8G-T<B@D<F5Q+"`P+"`R*2`]/2`G=BXG*2![#0H@("`@("`@("`@("`D
M<F5Q(#T@<W5B<W1R*"1R97$L(#(I.PT*("`@("`@("!]#0H@("`@("`@("1E
M>'1?=F5R(#T@<&AP=F5R<VEO;B@D;F%M92D[#0H@("`@("`@("1O<&5R871O
M<B`]("1R96QA=&EO;CL-"B`@("`@("`@+R\@1F]R8V4@<&%R86US('1O(&)E
M('-T<FEN9W,L(&]T:&5R=VES92!T:&4@8V]M<&%R871I;VX@=VEL;"!F86EL
M("AE>"X@,"XY/3TP+CDP*0T*("`@("`@("!I9B`H(79E<G-I;VY?8V]M<&%R
M92@B)&5X=%]V97(B+"`B)')E<2(L("1O<&5R871O<BDI('L-"B`@("`@("`@
M("`@("1E<G)M<V<@/2`B)R1N86UE)R!02%`@97AT96YS:6]N('9E<G-I;VX@
M(B`N#0H@("`@("`@("`@("`@("`@)'1H:7,M/G-I9VY/<&5R871O<B@D;W!E
M<F%T;W(I("X@(B`D<F5Q(&ES(')E<75I<F5D(CL-"B`@("`@("`@("`@("1C
M;V1E(#T@)'1H:7,M/F-O9&5&<F]M4F5L871I;VXH)')E;&%T:6]N+"`D97AT
M7W9E<BP@)')E<2P@)&]P="D[#0H@("`@("`@("`@("!I9B`H)&]P="D@>PT*
M("`@("`@("`@("`@("`@("1E<G)M<V<@/2`B)R1N86UE)R!02%`@97AT96YS
M:6]N('9E<G-I;VX@(B`N("1T:&ES+3YS:6=N3W!E<F%T;W(H)&]P97)A=&]R
M*2`N#0H@("`@("`@("`@("`@("`@("`@("(@)')E<2!I<R!R96-O;6UE;F1E
M9"!T;R!U=&EL:7IE('-O;64@9F5A='5R97,B.PT*("`@("`@("`@("`@("`@
M(')E='5R;B`D8V]D93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!R971U<FX@)&-O9&4[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(&-H96-K3U,H*0T*#0H@("`@+RHJ#0H@("`@("H@3W!E<F%T:6YG
M('-Y<W1E;2`@9&5P96YD96YC:65S(&-H96-K(&UE=&AO9`T*("`@("`J#0H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;W,@($YA;64@;V8@=&AE(&]P97)A=&EN
M9R!S>7-T96T-"B`@("`@*@T*("`@("`J($!R971U<FX@;6EX960@8F]O;"!F
M86QS92!I9B!N;R!E<G)O<B!O<B!T:&4@97)R;W(@<W1R:6YG#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@8VAE8VM/4R@F)&5R<FUS9RP@)&]S*0T*("`@('L-
M"B`@("`@("`@+R\@6%A8($9I>&UE.B!);7!L96UE;G0@82!M;W)E(&9L97AI
M8FQE('=A>2P@;&EK90T*("`@("`@("`O+R!C;VUM82!S97!A<F%T960@=F%L
M=65S(&]R('-O;65T:&EN9R!S:6UI;&%R('1O(%!%05)?3U,-"B`@("`@("`@
M<W1A=&EC("1M>6]S.PT*("`@("`@("!I9B`H96UP='DH)&UY;W,I*2![#0H@
M("`@("`@("`@("`D;7EO<R`](&YE=R!/4U]'=65S<R@I.PT*("`@("`@("!]
M#0H@("`@("`@("\O(&]N;'D@)VAA<R<@<F5L871I;VX@:7,@8W5R<F5N=&QY
M('-U<'!O<G1E9`T*("`@("`@("!I9B`H)&UY;W,M/FUA=&-H4VEG;F%T=7)E
M*"1O<RDI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("`D97)R;7-G(#T@(B<D;W,G(&]P97)A=&EN9R!S>7-T96T@
M;F]T('-U<'!O<G1E9"([#0H@("`@("`@(')E='5R;B!014%27T1%4$5.1$5.
M0UE?0T].1DQ)0U0[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[
M(&-H96-K4$A0*"D-"@T*("`@("\J*@T*("`@("`J(%!(4"!V97)S:6]N(&-H
M96-K(&UE=&AO9`T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5Q
M("`@=VAI8V@@=F5R<VEO;B!T;R!C;VUP87)E#0H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<F5L871I;VX@(&AO=R!T;R!C;VUP87)E('1H92!V97)S:6]N#0H@
M("`@("H-"B`@("`@*B!`<F5T=7)N(&UI>&5D(&)O;VP@9F%L<V4@:68@;F\@
M97)R;W(@;W(@=&AE(&5R<F]R('-T<FEN9PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&-H96-K4$A0*"8D97)R;7-G+"`D<F5Q+"`D<F5L871I;VX@/2`G9V4G
M*0T*("`@('L-"B`@("`@("`@+R\@=&AI<R!W;W5L9"!B92!A(&)I="!S='5P
M:60L(&)U="!O:"!W96QL(#HI#0H@("`@("`@(&EF("@D<F5L871I;VX@/3T@
M)VAA<R<I('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H)')E;&%T:6]N(#T]("=N;W0G*2![#0H@("`@("`@
M("`@("`D97)R;7-G(#T@(DEN=F%L:60@9&5P96YD96YC>2`M("=N;W0G(&ES
M(&%L;&]W960@=VAE;B!S<&5C:69Y:6YG(%!(4"P@>6]U(&UU<W0@<G5N(%!(
M4"!I;B!02%`B.PT*("`@("`@("`@("`@<F5T=7)N(%!%05)?1$5014Y$14Y#
M65]"041?1$5014Y$14Y#63L-"B`@("`@("`@?0T*("`@("`@("!I9B`H<W5B
M<W1R*"1R97$L(#`L(#(I(#T]("=V+B<I('L-"B`@("`@("`@("`@("1R97$@
M/2!S=6)S='(H)')E<2PR+"!S=')L96XH)')E<2D@+2`R*3L-"B`@("`@("`@
M?0T*("`@("`@("`D<&AP7W9E<B`]('!H<'9E<G-I;VXH*3L-"B`@("`@("`@
M)&]P97)A=&]R(#T@)')E;&%T:6]N.PT*("`@("`@("!I9B`H(79E<G-I;VY?
M8V]M<&%R92@B)'!H<%]V97(B+"`B)')E<2(L("1O<&5R871O<BDI('L-"B`@
M("`@("`@("`@("1E<G)M<V<@/2`B4$A0('9E<G-I;VX@(B`N("1T:&ES+3YS
M:6=N3W!E<F%T;W(H)&]P97)A=&]R*2`N#0H@("`@("`@("`@("`@("`@(B`D
M<F5Q(&ES(')E<75I<F5D(CL-"B`@("`@("`@("`@(')E='5R;B!014%27T1%
M4$5.1$5.0UE?0T].1DQ)0U0[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!C:&5C
M:U!R;V=R86TH*0T*#0H@("`@+RHJ#0H@("`@("H@17AT97)N86P@<')O9W)A
M;2!C:&5C:R!M971H;V0N("!,;V]K<R!F;W(@97AE8W5T86)L92!F:6QE<R!I
M;@T*("`@("`J(&1I<F5C=&]R:65S(&QI<W1E9"!I;B!T:&4@4$%42"!E;G9I
M<F]N;65N="!V87)I86)L92X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I
M;F<@)'!R;V=R86T@("!W:&EC:"!P<F]G<F%M('1O(&QO;VL@9F]R#0H@("`@
M("H-"B`@("`@*B!`<F5T=7)N(&UI>&5D(&)O;VP@9F%L<V4@:68@;F\@97)R
M;W(@;W(@=&AE(&5R<F]R('-T<FEN9PT*("`@("`J+PT*("`@(&9U;F-T:6]N
M(&-H96-K4')O9W)A;2@F)&5R<FUS9RP@)'!R;V=R86TI#0H@("`@>PT*("`@
M("`@("`O+R!86%@@1DE8344@:&]N;W(@<V%F92!M;V1E#0H@("`@("`@("1E
M>&5?<W5F9FEX(#T@3U-?5TE.1$]74R`_("<N97AE)R`Z("<G.PT*("`@("`@
M("`D<&%T:%]E;&5M96YT<R`](&5X<&QO9&4H4$%42%]315!!4D%43U(L(&=E
M=&5N=B@G4$%42"<I*3L-"B`@("`@("`@9F]R96%C:"`H)'!A=&A?96QE;65N
M=',@87,@)&1I<BD@>PT*("`@("`@("`@("`@)&9I;&4@/2`D9&ER("X@1$E2
M14-43U)97U-%4$%2051/4B`N("1P<F]G<F%M("X@)&5X95]S=69F:7@[#0H@
M("`@("`@("`@("!I9B`H0&9I;&5?97AI<W1S*"1F:6QE*2`F)B!`:7-?97AE
M8W5T86)L92@D9FEL92DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&5R<FUS
M9R`]("(G)'!R;V=R86TG('!R;V=R86T@:7,@;F]T('!R97-E;G0@:6X@=&AE
M(%!!5$@B.PT*("`@("`@("!R971U<FX@4$5!4E]$15!%3D1%3D-97TU)4U-)
M3D<[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&-H96-K4T%0
M22@I#0H-"B`@("`O*BH-"B`@("`@*B!305!)(&)A8VME;F0@8VAE8VL@;65T
M:&]D+B`@5F5R<VEO;B!C;VUP87)I<V]N(&ES(&YO="!Y970-"B`@("`@*B!A
M=F%I;&%B;&4@:&5R92X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@
M)&YA;64@("`@("!N86UE(&]F(%-!4$D@8F%C:V5N9`T*("`@("`J($!P87)A
M;2!S=')I;F<@)')E<2`@('=H:6-H('9E<G-I;VX@=&\@8V]M<&%R90T*("`@
M("`J($!P87)A;2!S=')I;F<@)')E;&%T:6]N("!H;W<@=&\@8V]M<&%R92!V
M97)S:6]N<R`H8W5R<F5N=&QY#0H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@(&AA<F1C;V1E9"!T;R`G:&%S)RD-"B`@("`@*B!`<F5T=7)N(&UI
M>&5D(&)O;VP@9F%L<V4@:68@;F\@97)R;W(@;W(@=&AE(&5R<F]R('-T<FEN
M9PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&-H96-K4T%022@F)&5R<FUS9RP@
M)&YA;64L("1R97$@/2!N=6QL+"`D<F5L871I;VX@/2`G:&%S)RD-"B`@("![
M#0H@("`@("`@("\O(%A86"!&:7AM93H@5&AE<F4@:7,@;F\@=V%Y('1O(&MN
M;W<@:68@=&AE('5S97(@:&%S(&]R#0H@("`@("`@("\O(&YO="!O=&AE<B!3
M05!)(&)A8VME;F1S(&EN<W1A;&QE9"!T:&%N('1H92!I;G-T86QL97(@;VYE
M#0H-"B`@("`@("`@)'-A<&E?8F%C:V5N9"`]('!H<%]S87!I7VYA;64H*3L-
M"B`@("`@("`@+R\@5F5R<VEO;B!C;VUP87)I<V]N<R!N;W0@<W5P<&]R=&5D
M+"!S87!I(&)A8VME;F1S(&1O;B=T(&AA=F4-"B`@("`@("`@+R\@=F5R<VEO
M;B!I;F9O<FUA=&EO;B!Y970N#0H@("`@("`@(&EF("@D<V%P:5]B86-K96YD
M(#T]("1N86UE*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@('T-"B`@("`@("`@)&5R<FUS9R`]("(G)'-A<&E?8F%C:V5N9"<@4T%0
M22!B86-K96YD(&YO="!S=7!P;W)T960B.PT*("`@("`@("!R971U<FX@4$5!
M4E]$15!%3D1%3D-97T-/3D9,24-4.PT*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!C:&5C:UIE;F0H*0T*#0H@("`@+RHJ#0H@("`@("H@6F5N
M9"!V97)S:6]N(&-H96-K(&UE=&AO9`T*("`@("`J#0H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<F5Q("`@=VAI8V@@=F5R<VEO;B!T;R!C;VUP87)E#0H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<F5L871I;VX@(&AO=R!T;R!C;VUP87)E('1H
M92!V97)S:6]N#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&UI>&5D(&)O;VP@
M9F%L<V4@:68@;F\@97)R;W(@;W(@=&AE(&5R<F]R('-T<FEN9PT*("`@("`J
M+PT*("`@(&9U;F-T:6]N(&-H96-K6F5N9"@F)&5R<FUS9RP@)')E<2P@)')E
M;&%T:6]N(#T@)V=E)RD-"B`@("![#0H@("`@("`@(&EF("AS=6)S='(H)')E
M<2P@,"P@,BD@/3T@)W8N)RD@>PT*("`@("`@("`@("`@)')E<2`]('-U8G-T
M<B@D<F5Q+#(L('-T<FQE;B@D<F5Q*2`M(#(I.PT*("`@("`@("!]#0H@("`@
M("`@("1Z96YD7W9E<B`]('IE;F1?=F5R<VEO;B@I.PT*("`@("`@("`D;W!E
M<F%T;W(@/2!S=6)S='(H)')E;&%T:6]N+#`L,BD[#0H@("`@("`@(&EF("@A
M=F5R<VEO;E]C;VUP87)E*"(D>F5N9%]V97(B+"`B)')E<2(L("1O<&5R871O
M<BDI('L-"B`@("`@("`@("`@("1E<G)M<V<@/2`B6F5N9"!V97)S:6]N("(@
M+B`D=&AI<RT^<VEG;D]P97)A=&]R*"1O<&5R871O<BD@+@T*("`@("`@("`@
M("`@("`@("(@)')E<2!I<R!R97%U:7)E9"([#0H@("`@("`@("`@("!R971U
M<FX@4$5!4E]$15!%3D1%3D-97T-/3D9,24-4.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O
M+R![>WL@<VEG;D]P97)A=&]R*"D-"@T*("`@("\J*@T*("`@("`J($-O;G9E
M<G1S('1E>'0@8V]M<&%R:6YG(&]P97)A=&]R<R!T;R!T:&5M('-I9VX@97%U
M:79A;&5N=',-"B`@("`@*@T*("`@("`J($5X86UP;&4Z("=G92<@=&\@)SX]
M)PT*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`<&%R
M86T@('-T<FEN9R!/<&5R871O<@T*("`@("`J($!R971U<FX@<W1R:6YG(%-I
M9VX@97%U:79A;&5N=`T*("`@("`J+PT*("`@(&9U;F-T:6]N('-I9VY/<&5R
M871O<B@D;W!E<F%T;W(I#0H@("`@>PT*("`@("`@("!S=VET8V@H)&]P97)A
M=&]R*2![#0H@("`@("`@("`@("!C87-E("=L="<Z(')E='5R;B`G/"<[#0H@
M("`@("`@("`@("!C87-E("=L92<Z(')E='5R;B`G/#TG.PT*("`@("`@("`@
M("`@8V%S92`G9W0G.B!R971U<FX@)SXG.PT*("`@("`@("`@("`@8V%S92`G
M9V4G.B!R971U<FX@)SX])SL-"B`@("`@("`@("`@(&-A<V4@)V5Q)SH@<F5T
M=7)N("<]/2<[#0H@("`@("`@("`@("!C87-E("=N92<Z(')E='5R;B`G(3TG
M.PT*("`@("`@("`@("`@9&5F875L=#H-"B`@("`@("`@("`@("`@("!R971U
M<FX@)&]P97)A=&]R.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[(&-O9&5&<F]M4F5L871I;VXH*0T*#0H@("`@+RHJ#0H@
M("`@("H@0V]N=F5R="!R96QA=&EO;B!I;G1O(&-O<G)E<W!O;F1I;F<@8V]D
M90T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`<&%R
M86T@('-T<FEN9R!296QA=&EO;@T*("`@("`J($!P87)A;2`@<W1R:6YG(%9E
M<G-I;VX-"B`@("`@*B!`<&%R86T@('-T<FEN9R!297%U:7)E;65N=`T*("`@
M("`J($!P87)A;2`@8F]O;"`@($]P=&EO;F%L(&1E<&5N9&5N8WD@:6YD:6-A
M=&]R#0H@("`@("H@0')E='5R;B!I;G1E9V5R#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@8V]D949R;VU296QA=&EO;B@D<F5L871I;VXL("1V97)S:6]N+"`D
M<F5Q+"`D;W!T(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D8V]D92`](%!%
M05)?1$5014Y$14Y#65]"041?1$5014Y$14Y#63L-"B`@("`@("`@<W=I=&-H
M("@D<F5L871I;VXI('L-"B`@("`@("`@("`@(&-A<V4@)V=T)SH@8V%S92`G
M9V4G.B!C87-E("=E<2<Z#0H@("`@("`@("`@("`@("`@+R\@=7!G<F%D90T*
M("`@("`@("`@("`@("`@("1H879E7VUA:F]R(#T@<')E9U]R97!L86-E*"<O
M7$0N*B\G+"`G)RP@)'9E<G-I;VXI.PT*("`@("`@("`@("`@("`@("1N965D
M7VUA:F]R(#T@<')E9U]R97!L86-E*"<O7$0N*B\G+"`G)RP@)')E<2D[#0H@
M("`@("`@("`@("`@("`@:68@*"1N965D7VUA:F]R(#X@)&AA=F5?;6%J;W(I
M('L-"B`@("`@("`@("`@("`@("`@("`@)&-O9&4@/2`D;W!T(#\@4$5!4E]$
M15!%3D1%3D-97U501U)!1$5?34%*3U)?3U!424].04P@.@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!014%27T1%4$5.1$5.0UE?55!'
M4D%$15]-04I/4CL-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`D8V]D92`]("1O<'0@/R!014%27T1%4$5.1$5.0UE?
M55!'4D%$15]-24Y/4E]/4%1)3TY!3"`Z#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%!%05)?1$5014Y$14Y#65]54$=2041%7TU)3D]2
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@(&-A<V4@)VQT)SH@8V%S92`G;&4G.B!C87-E("=N92<Z
M#0H@("`@("`@("`@("`@("`@)&-O9&4@/2`D;W!T(#\@4$5!4E]$15!%3D1%
M3D-97T-/3D9,24-47T]05$E/3D%,(#H-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!014%27T1%4$5.1$5.0UE?0T].1DQ)0U0[#0H@("`@("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1C
M;V1E.PT*("`@('T-"@T*("`@("\O('U]?0T*?0T*/SX-"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T1E<&5N9&5N8WDR+G!H
M<```````````````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$T,3`V,0`Q,#4Q
M-30S,S<T,0`P,C(R,#4`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`-"B\J*@T*("H@4$5!4E]$97!E;F1E;F-Y,BP@
M861V86YC960@9&5P96YD96YC>2!V86QI9&%T:6]N#0H@*@T*("H@4$A0('9E
M<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F
M:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E
M;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@
M<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL
M('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@
M<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E
M9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY
M-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*
M("H@0'9E<G-I;VX@("`@0U93.B`D260Z($1E<&5N9&5N8WDR+G!H<"QV(#$N
M-3`@,C`P-B\P,2\P-B`P-#HT-SHS-B!C96QL;V<@17AP("0-"B`J($!L:6YK
M("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`
M<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP
M83$-"B`J+PT*#0HO*BH-"B`J(%)E<75I<F5D(&9O<B!T:&4@4$5!4E]604Q)
M1$%415\J(&-O;G-T86YT<PT*("HO#0IR97%U:7)E7V]N8V4@)U!%05(O5F%L
M:61A=&4N<&AP)SL-"@T*+RHJ#0H@*B!$97!E;F1E;F-Y(&-H96-K(&9O<B!0
M14%2('!A8VMA9V5S#0H@*@T*("H@5&AI<R!C;&%S<R!H86YD;&5S(&)O=&@@
M=F5R<VEO;B`Q+C`@86YD(#(N,"!D97!E;F1E;F-I97,-"B`J(%=!4DY)3D<Z
M("IA;GDJ(&-H86YG97,@=&\@=&AI<R!C;&%S<R!M=7-T(&)E(&1U<&QI8V%T
M960@:6X@=&AE#0H@*B!T97-T7U!%05)?1&5P96YD96YC>3(@8VQA<W,@9F]U
M;F0@:6X@=&5S=',O4$5!4E]$97!E;F1E;F-Y,B]S971U<"YP:'`N:6YC+`T*
M("H@;W(@=6YI="!T97-T<R!W:6QL(&YO="!A8W1U86QL>2!V86QI9&%T92!T
M:&4@8VAA;F=E<PT*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@
M("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P
M:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O
M=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L
M96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B
M;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S(%!%05)?1&5P
M96YD96YC>3(-"GL-"B`@("`O*BH-"B`@("`@*B!/;F4@;V8@=&AE(%!%05)?
M5D%,241!5$5?*B!S=&%T97,-"B`@("`@*B!`<V5E(%!%05)?5D%,241!5$5?
M3D]234%,#0H@("`@("H@0'9A<B!I;G1E9V5R#0H@("`@("HO#0H@("`@=F%R
M("1?<W1A=&4[#0H@("`@+RHJ#0H@("`@("H@0V]M;6%N9"UL:6YE(&]P=&EO
M;G,@=&\@:6YS=&%L;"]U<&=R861E+W5N:6YS=&%L;"!C;VUM86YD<PT*("`@
M("`J($!P87)A;2!A<G)A>0T*("`@("`J+PT*("`@('9A<B`D7V]P=&EO;G,[
M#0H@("`@+RHJ#0H@("`@("H@0'9A<B!/4U]'=65S<PT*("`@("`J+PT*("`@
M('9A<B`D7V]S.PT*("`@("\J*@T*("`@("`J($!V87(@4$5!4E]296=I<W1R
M>0T*("`@("`J+PT*("`@('9A<B`D7W)E9VES=')Y.PT*("`@("\J*@T*("`@
M("`J($!V87(@4$5!4E]#;VYF:6<-"B`@("`@*B\-"B`@("!V87(@)%]C;VYF
M:6<[#0H@("`@+RHJ#0H@("`@("H@0'9A<B!014%27T1E<&5N9&5N8WE$0@T*
M("`@("`J+PT*("`@('9A<B`D7V1E<&5N9&5N8WED8CL-"B`@("`O*BH-"B`@
M("`@*B!/=71P=70@;V8@4$5!4E]296=I<W1R>3HZ<&%R<V5D4&%C:V%G94YA
M;64H*0T*("`@("`J($!V87(@87)R87D-"B`@("`@*B\-"B`@("!V87(@)%]C
M=7)R96YT4&%C:V%G93L-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@4$5!4E]#
M;VYF:6<-"B`@("`@*B!`<&%R86T@87)R87D@:6YS=&%L;&%T:6]N(&]P=&EO
M;G,-"B`@("`@*B!`<&%R86T@87)R87D@9F]R;6%T(&]F(%!%05)?4F5G:7-T
M<GDZ.G!A<G-E9%!A8VMA9V5.86UE*"D-"B`@("`@*B!`<&%R86T@:6YT(&EN
M<W1A;&QA=&EO;B!S=&%T92`H;VYE(&]F(%!%05)?5D%,241!5$5?*BD-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!014%27T1E<&5N9&5N8WDR*"8D8V]N9FEG
M+"`D:6YS=&%L;&]P=&EO;G,L("1P86-K86=E+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'-T871E(#T@4$5!4E]604Q)1$%415])3E-404Q,
M24Y'*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]C;VYF:6<@/2`F)&-O;F9I
M9SL-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?1&5P96YD96YC
M>41")RDI('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]$97!E
M;F1E;F-Y1$(N<&AP)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H
M)&EN<W1A;&QO<'1I;VYS6R=P86-K86=I;F=R;V]T)UTI*2![#0H@("`@("`@
M("`@("`O+R!M86ME('-U<F4@9&5P9&(@:7,@:6X@=&AE(')I9VAT(&QO8V%T
M:6]N#0H@("`@("`@("`@("`D8V]N9FEG+3YS971);G-T86QL4F]O="@D:6YS
M=&%L;&]P=&EO;G-;)W!A8VMA9VEN9W)O;W0G72D[#0H@("`@("`@('T-"B`@
M("`@("`@)'1H:7,M/E]R96=I<W1R>2`]("8D8V]N9FEG+3YG971296=I<W1R
M>2@I.PT*("`@("`@("`D=&AI<RT^7V1E<&5N9&5N8WED8B`]("9014%27T1E
M<&5N9&5N8WE$0CHZ<VEN9VQE=&]N*"1C;VYF:6<I.PT*("`@("`@("!I9B`H
M:7-S970H)&EN<W1A;&QO<'1I;VYS6R=P86-K86=I;F=R;V]T)UTI*2![#0H@
M("`@("`@("`@("`D8V]N9FEG+3YS971);G-T86QL4F]O="AF86QS92D[#0H@
M("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]O<'1I;VYS(#T@)&EN<W1A;&QO
M<'1I;VYS.PT*("`@("`@("`D=&AI<RT^7W-T871E(#T@)'-T871E.PT*("`@
M("`@("!I9B`H(6-L87-S7V5X:7-T<R@G3U-?1W5E<W,G*2D@>PT*("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E("=/4R]'=65S<RYP:'`G.PT*("`@("`@("!]
M#0H@("`@("`@("1T:&ES+3Y?;W,@/2!N97<@3U-?1W5E<W,[#0H@("`@("`@
M("1T:&ES+3Y?8W5R<F5N=%!A8VMA9V4@/2`D<&%C:V%G93L-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!?9V5T17AT<F%3=')I;F<H)&1E<"D-"B`@("![#0H@
M("`@("`@("1E>'1R82`]("<@*"<[#0H@("`@("`@(&EF("AI<W-E="@D9&5P
M6R=U<FDG72DI('L-"B`@("`@("`@("`@(')E='5R;B`G)SL-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H:7-S970H)&1E<%LG<F5C;VUM96YD960G72DI('L-
M"B`@("`@("`@("`@("1E>'1R82`N/2`G<F5C;VUM96YD960@=F5R<VEO;B`G
M("X@)&1E<%LG<F5C;VUM96YD960G73L-"B`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=M:6XG72DI('L-"B`@("`@("`@
M("`@("`@("`D97AT<F$@+CT@)W9E<G-I;VX@/CT@)R`N("1D97!;)VUI;B==
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;
M)VUA>"==*2D@>PT*("`@("`@("`@("`@("`@(&EF("@D97AT<F$@(3T@)R`H
M)RD@>PT*("`@("`@("`@("`@("`@("`@("`D97AT<F$@+CT@)RP@)SL-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&5X=')A("X]("=V
M97)S:6]N(#P]("<@+B`D9&5P6R=M87@G73L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@
M("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D9&5P6R=E>&-L=61E)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("1D97!;)V5X8VQU9&4G72`](&%R<F%Y
M*"1D97!;)V5X8VQU9&4G72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&EF("@D97AT<F$@(3T@)R`H)RD@>PT*("`@("`@("`@("`@
M("`@("`@("`D97AT<F$@+CT@)RP@)SL-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@)&5X=')A("X]("=E>&-L=61E9"!V97)S:6]N<SH@
M)SL-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D9&5P6R=E>&-L=61E)UT@
M87,@)&D@/3X@)&5X8VQU9&4I('L-"B`@("`@("`@("`@("`@("`@("`@:68@
M*"1I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D97AT<F$@+CT@)RP@
M)SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`D97AT<F$@+CT@)&5X8VQU9&4[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1E>'1R82`N/2`G*2<[
M#0H@("`@("`@(&EF("@D97AT<F$@/3T@)R`H*2<I('L-"B`@("`@("`@("`@
M("1E>'1R82`]("<G.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D97AT
M<F$[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@5&AI<R!M86ME<R!U;FET
M+71E<W1I;F<@82!H96-K(&]F(&$@;&]T(&5A<VEE<@T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(&=E=%!(4%]/4R@I#0H@("`@>PT*("`@("`@("!R971U<FX@
M4$A07T]3.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%1H:7,@;6%K97,@
M=6YI="UT97-T:6YG(&$@:&5C:R!O9B!A(&QO="!E87-I97(-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!G971S>7-N86UE*"D-"B`@("![#0H@("`@("`@(')E
M='5R;B`D=&AI<RT^7V]S+3YG9713>7-N86UE*"D[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@4W!E8VEF>2!A(&1E<&5N9&5N8WD@;VX@86X@3U,N("!5
M<V4@87)C:"!F;W(@9&5T86EL960@;W,O<')O8V5S<V]R(&EN9F]R;6%T:6]N
M#0H@("`@("H-"B`@("`@*B!4:&5R92!A<F4@='=O(&=E;F5R:6,@3U,@9&5P
M96YD96YC:65S('1H870@=VEL;"!B92!T:&4@;6]S="!C;VUM;VXL('5N:7@@
M86YD('=I;F1O=W,N#0H@("`@("H@3W1H97(@;W!T:6]N<R!A<F4@;&EN=7@L
M(&9R965B<V0L(&1A<G=I;B`H3U,@6"DL('-U;F]S+"!I<FEX+"!H<'5X+"!A
M:7@-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9&%T94]S1&5P96YD96YC
M>2@D9&5P*0T*("`@('L-"B`@("`@("`@:68@*"1T:&ES+3Y?<W1A=&4@(3T@
M4$5!4E]604Q)1$%415])3E-404Q,24Y'("8F#0H@("`@("`@("`@("`@("1T
M:&ES+3Y?<W1A=&4@(3T@4$5!4E]604Q)1$%415]$3U=.3$]!1$E.1RD@>PT*
M("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES<V5T*"1D97!;)V-O;F9L:6-T<R==*2D@>PT*("`@("`@("`@("`@
M)&YO="`]('1R=64[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M;F]T(#T@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1D97!;)VYA
M;64G72`]/2`G*B<I('L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M("`@("!]#0H@("`@("`@('-W:71C:"`H<W1R=&]L;W=E<B@D9&5P6R=N86UE
M)UTI*2![#0H@("`@("`@("`@("!C87-E("=W:6YD;W=S)R`Z#0H@("`@("`@
M("`@("`@("`@:68@*"1N;W0I('L-"B`@("`@("`@("`@("`@("`@("`@:68@
M*'-T<G1O;&]W97(H<W5B<W1R*"1T:&ES+3YG97102%!?3U,H*2P@,"P@,RDI
M(#T]("=W:6XG*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI("8F#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=F
M;W)C92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B0V%N;F]T(&EN<W1A;&P@)7,@;VX@5VEN
M9&]W<R(I.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G=A<FYI
M;F<H(G=A<FYI;F<Z($-A;FYO="!I;G-T86QL("5S(&]N(%=I;F1O=W,B*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@(&EF("AS=')T;VQO=V5R*'-U8G-T<B@D=&AI<RT^9V5T4$A07T]3
M*"DL(#`L(#,I*2`A/2`G=VEN)RD@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)VYO9&5P<R==*2`F)@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(6ES<V5T*"1T:&ES+3Y?
M;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D-A;B!O;FQY(&EN<W1A
M;&P@)7,@;VX@5VEN9&]W<R(I.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G=A<FYI;F<H(G=A<FYI;F<Z($-A;B!O;FQY(&EN<W1A;&P@)7,@
M;VX@5VEN9&]W<R(I.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=U;FEX)R`Z#0H@("`@
M("`@("`@("`@("`@)'5N:6-E<R`](&%R<F%Y*"=L:6YU>"<L("=F<F5E8G-D
M)RP@)V1A<G=I;B<L("=S=6YO<R<L("=I<FEX)RP@)VAP=7@G+"`G86EX)RD[
M#0H@("`@("`@("`@("`@("`@:68@*"1N;W0I('L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*&EN7V%R<F%Y*"1T:&ES+3YG9713>7-N86UE*"DL("1U;FEC
M97,I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI("8F#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=F;W)C92==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@B0V%N;F]T(&EN<W1A;&P@)7,@;VX@86YY(%5N:7@@
M<WES=&5M(BD[#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R
M;FEN9R@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(G=A<FYI
M;F<Z($-A;FYO="!I;G-T86QL("5S(&]N(&%N>2!5;FEX('-Y<W1E;2(I.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*"%I;E]A<G)A>2@D=&AI<RT^9V5T4WES;F%M92@I+"`D=6YI
M8V5S*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^7V]P=&EO;G-;)VYO9&5P<R==*2`F)@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H(D-A;B!O;FQY(&EN<W1A;&P@)7,@;VX@82!5;FEX
M('-Y<W1E;2(I.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G=A
M<FYI;F<H#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(")W87)N
M:6YG.B!#86X@;VYL>2!I;G-T86QL("5S(&]N(&$@56YI>"!S>7-T96TB*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("`@("`@9&5F875L="`Z#0H@("`@("`@("`@("`@("`@:68@*"1N
M;W0I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H)&1E
M<%LG;F%M92==*2`]/2!S=')T;VQO=V5R*"1T:&ES+3YG9713>7-N86UE*"DI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?;W!T:6]N<ULG;F]D97!S)UTI("8F#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=F;W)C92==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@G0V%N;F]T(&EN<W1A;&P@)7,@;VX@)R`N("1D97!;)VYA
M;64G72`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<@;W!E
M<F%T:6YG('-Y<W1E;2<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G=A<FYI;F<H)W=A<FYI;F<Z($-A;FYO="!I;G-T86QL("5S(&]N("<@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P6R=N86UE
M)UT@+B`G(&]P97)A=&EN9R!S>7-T96TG*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@(&EF("AS=')T;VQO
M=V5R*"1D97!;)VYA;64G72D@(3T@<W1R=&]L;W=E<B@D=&AI<RT^9V5T4WES
M;F%M92@I*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7V]P=&EO;G-;)VYO9&5P<R==*2`F)@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R
M8V4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)T-A;FYO="!I;G-T86QL("5S(&]N("<@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9V5T4WES
M;F%M92@I("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R!O
M<&5R871I;F<@<WES=&5M+"!C86X@;VYL>2!I;G-T86QL(&]N("<@+B`D9&5P
M6R=N86UE)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G=A
M<FYI;F<H)W=A<FYI;F<Z($-A;FYO="!I;G-T86QL("5S(&]N("<@+@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9V5T4WES;F%M
M92@I("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R!O<&5R
M871I;F<@<WES=&5M+"!C86X@;VYL>2!I;G-T86QL(&]N("<@+B`D9&5P6R=N
M86UE)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J
M(%1H:7,@;6%K97,@=6YI="UT97-T:6YG(&$@:&5C:R!O9B!A(&QO="!E87-I
M97(-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!M871C:%-I9VYA='5R92@D<&%T
M=&5R;BD-"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^7V]S+3YM871C
M:%-I9VYA='5R92@D<&%T=&5R;BD[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@4W!E8VEF>2!A(&-O;7!L97@@9&5P96YD96YC>2!O;B!A;B!/4R]P<F]C
M97-S;W(O:V5R;F5L('9E<G-I;VXL#0H@("`@("H@57-E($]3(&9O<B!S:6UP
M;&4@;W!E<F%T:6YG('-Y<W1E;2!D97!E;F1E;F-Y+@T*("`@("`J#0H@("`@
M("H@5&AI<R!I<R!T:&4@;VYL>2!D97!E;F1E;F-Y('1H870@86-C97!T<R!A
M;B!E<F5G86)L92!P871T97)N+B`@5&AE('!A='1E<FX-"B`@("`@*B!W:6QL
M(&)E(&UA=&-H960@86=A:6YS="!T:&4@<&AP7W5N86UE*"D@;W5T<'5T('!A
M<G-E9"!B>2!/4U]'=65S<PT*("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED
M871E07)C:$1E<&5N9&5N8WDH)&1E<"D-"B`@("![#0H@("`@("`@(&EF("@D
M=&AI<RT^7W-T871E("$](%!%05)?5D%,241!5$5?24Y35$%,3$E.1RD@>PT*
M("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES<V5T*"1D97!;)V-O;F9L:6-T<R==*2D@>PT*("`@("`@("`@("`@
M)&YO="`]('1R=64[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M;F]T(#T@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D=&AI<RT^
M;6%T8VA3:6=N871U<F4H)&1E<%LG<&%T=&5R;B==*2D@>PT*("`@("`@("`@
M("`@:68@*"$D;F]T*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^7V]P=&EO;G-;)VYO9&5P<R==*2`F)B`A:7-S970H)'1H:7,M/E]O
M<'1I;VYS6R=F;W)C92==*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)R5S($%R8VAI=&5C='5R92!D97!E;F1E
M;F-Y(&9A:6QE9"P@9&]E<R!N;W0@)R`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`G;6%T8V@@(B<@+B`D9&5P6R=P871T97)N)UT@+B`G(B<I.PT*("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^=V%R;FEN9R@G=V%R;FEN9SH@)7,@07)C:&ET96-T=7)E
M(&1E<&5N9&5N8WD@9F%I;&5D+"!D;V5S("<@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@)VYO="!M871C:"`B)R`N("1D97!;)W!A='1E<FXG72`N("<B
M)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("!I9B`H)&YO="D@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G72D@)B8@(6ES<V5T*"1T:&ES+3Y?
M;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*"<E<R!!<F-H:71E8W1U<F4@9&5P96YD
M96YC>2!F86EL960L(')E<75I<F5D("(G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1D97!;)W!A='1E<FXG72`N("<B)RD[#0H@("`@("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YW87)N:6YG*"=W87)N:6YG.B`E<R!!<F-H:71E8W1U<F4@9&5P96YD96YC
M>2!F86EL960L("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)W)E<75I
M<F5D("(G("X@)&1E<%LG<&%T=&5R;B==("X@)R(G*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@=')U
M93L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J(%1H:7,@
M;6%K97,@=6YI="UT97-T:6YG(&$@:&5C:R!O9B!A(&QO="!E87-I97(-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!E>'1E;G-I;VY?;&]A9&5D*"1N86UE*0T*
M("`@('L-"B`@("`@("`@<F5T=7)N(&5X=&5N<VEO;E]L;V%D960H)&YA;64I
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%1H:7,@;6%K97,@=6YI="UT
M97-T:6YG(&$@:&5C:R!O9B!A(&QO="!E87-I97(-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!P:'!V97)S:6]N*"1N86UE(#T@;G5L;"D-"B`@("![#0H@("`@
M("`@(&EF("@D;F%M92`A/3T@;G5L;"D@>PT*("`@("`@("`@("`@<F5T=7)N
M('!H<'9E<G-I;VXH)&YA;64I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@<F5T=7)N('!H<'9E<G-I;VXH*3L-"B`@("`@("`@?0T*("`@('T-
M"@T*("`@(&9U;F-T:6]N('9A;&ED871E17AT96YS:6]N1&5P96YD96YC>2@D
M9&5P+"`D<F5Q=6ER960@/2!T<G5E*0T*("`@('L-"B`@("`@("`@:68@*"1T
M:&ES+3Y?<W1A=&4@(3T@4$5!4E]604Q)1$%415])3E-404Q,24Y'("8F#0H@
M("`@("`@("`@("`@("1T:&ES+3Y?<W1A=&4@(3T@4$5!4E]604Q)1$%415]$
M3U=.3$]!1$E.1RD@>PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M("`@('T-"B`@("`@("`@)&QO861E9"`]("1T:&ES+3YE>'1E;G-I;VY?;&]A
M9&5D*"1D97!;)VYA;64G72D[#0H@("`@("`@("1E>'1R82`]("1T:&ES+3Y?
M9V5T17AT<F%3=')I;F<H)&1E<"D[#0H@("`@("`@(&EF("AI<W-E="@D9&5P
M6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1D
M97!;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@("`@("`D9&5P6R=E>&-L
M=61E)UT@/2!A<G)A>2@D9&5P6R=E>&-L=61E)UTI.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)&1E<%LG;6EN)UTI
M("8F("%I<W-E="@D9&5P6R=M87@G72D@)B8-"B`@("`@("`@("`@("`@(6ES
M<V5T*"1D97!;)W)E8V]M;65N9&5D)UTI("8F("%I<W-E="@D9&5P6R=E>&-L
M=61E)UTI*2![#0H@("`@("`@("`@("!I9B`H)&QO861E9"D@>PT*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=C;VYF;&EC=',G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;
M)VYO9&5P<R==*2`F)B`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=F;W)C92==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*"<E<R!C;VYF;&EC=',@=VET:"!02%`@97AT96YS:6]N("(G
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P6R=N86UE)UT@
M+B`G(B<@+B`D97AT<F$I.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N
M:6YG*"=W87)N:6YG.B`E<R!C;VYF;&EC=',@=VET:"!02%`@97AT96YS:6]N
M("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P6R=N86UE
M)UT@+B`G(B<@+B`D97AT<F$I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&1E<%LG8V]N9FQI8W1S)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!I9B`H)')E<75I<F5D*2![#0H@("`@("`@("`@("`@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G72D@)B8@(6ES
M<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G)7,@<F5Q
M=6ER97,@4$A0(&5X=&5N<VEO;B`B)R`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&1E<%LG;F%M92==("X@)R(G("X@)&5X=')A*3L-"B`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G=V%R;FEN9SH@)7,@<F5Q=6ER
M97,@4$A0(&5X=&5N<VEO;B`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1E<%LG;F%M92==("X@)R(G("X@)&5X=')A*3L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G)7,@8V%N
M(&]P=&EO;F%L;'D@=7-E(%!(4"!E>'1E;G-I;VX@(B<@+@T*("`@("`@("`@
M("`@("`@("`@("`@("`@)&1E<%LG;F%M92==("X@)R(G("X@)&5X=')A*3L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"$D;&]A9&5D*2![#0H@("`@("`@("`@("!I9B`H:7-S
M970H)&1E<%LG8V]N9FQI8W1S)UTI*2![#0H@("`@("`@("`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(21R
M97%U:7)E9"D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R
M;FEN9R@G)7,@8V%N(&]P=&EO;F%L;'D@=7-E(%!(4"!E>'1E;G-I;VX@(B<@
M+@T*("`@("`@("`@("`@("`@("`@("`D9&5P6R=N86UE)UT@+B`G(B<@+B`D
M97AT<F$I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI("8F("%I
M<W-E="@D=&AI<RT^7V]P=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G)7,@<F5Q=6ER
M97,@4$A0(&5X=&5N<VEO;B`B)R`N("1D97!;)VYA;64G72`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`G(B<@+B`D97AT<F$I.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N
M:6YG*"=W87)N:6YG.B`E<R!R97%U:7)E<R!02%`@97AT96YS:6]N("(G("X@
M)&1E<%LG;F%M92==("X-"B`@("`@("`@("`@("`@("`@("`@("`@("<B)R`N
M("1E>'1R82D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M)'9E<G-I;VX@/2`H<W1R:6YG*2`D=&AI<RT^<&AP=F5R<VEO;B@D9&5P6R=N
M86UE)UTI.PT*("`@("`@("!I9B`H96UP='DH)'9E<G-I;VXI*2![#0H@("`@
M("`@("`@("`D=F5R<VEO;B`]("<P)SL-"B`@("`@("`@?0T*("`@("`@("`D
M9F%I;"`](&9A;'-E.PT*("`@("`@("!I9B`H:7-S970H)&1E<%LG;6EN)UTI
M*2![#0H@("`@("`@("`@("!I9B`H(79E<G-I;VY?8V]M<&%R92@D=F5R<VEO
M;BP@)&1E<%LG;6EN)UTL("<^/2<I*2![#0H@("`@("`@("`@("`@("`@)&9A
M:6P@/2!T<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(&EF("AI<W-E="@D9&5P6R=M87@G72DI('L-"B`@("`@("`@("`@(&EF("@A
M=F5R<VEO;E]C;VUP87)E*"1V97)S:6]N+"`D9&5P6R=M87@G72P@)SP])RDI
M('L-"B`@("`@("`@("`@("`@("`D9F%I;"`]('1R=64[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1F86EL("8F("%I<W-E="@D
M9&5P6R=C;VYF;&EC=',G72DI('L-"B`@("`@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G72D@)B8@(6ES<V5T*"1T:&ES+3Y?
M;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)R5S(')E<75I<F5S(%!(4"!E>'1E;G-I;VX@
M(B<@+B`D9&5P6R=N86UE)UT@+@T*("`@("`@("`@("`@("`@("`@("`G(B<@
M+B`D97AT<F$@+B`G+"!I;G-T86QL960@=F5R<VEO;B!I<R`G("X@)'9E<G-I
M;VXI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G=A<FYI;F<H)W=A<FYI;F<Z("5S(')E<75I<F5S(%!(
M4"!E>'1E;G-I;VX@(B<@+B`D9&5P6R=N86UE)UT@+@T*("`@("`@("`@("`@
M("`@("`@("`G(B<@+B`D97AT<F$@+B`G+"!I;G-T86QL960@=F5R<VEO;B!I
M<R`G("X@)'9E<G-I;VXI.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L
M<V5I9B`H*&ES<V5T*"1D97!;)VUI;B==*2!\?"!I<W-E="@D9&5P6R=M87@G
M72DI("8F("$D9F%I;"`F)B!I<W-E="@D9&5P6R=C;VYF;&EC=',G72DI('L-
M"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E
M<',G72D@)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)R5S
M(&-O;F9L:6-T<R!W:71H(%!(4"!E>'1E;G-I;VX@(B<@+@T*("`@("`@("`@
M("`@("`@("`@("`D9&5P6R=N86UE)UT@+B`G(B<@+B`D97AT<F$@+B`G+"!I
M;G-T86QL960@=F5R<VEO;B!I<R`G("X@)'9E<G-I;VXI.PT*("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G=A
M<FYI;F<H)W=A<FYI;F<Z("5S(&-O;F9L:6-T<R!W:71H(%!(4"!E>'1E;G-I
M;VX@(B<@+@T*("`@("`@("`@("`@("`@("`@("`D9&5P6R=N86UE)UT@+B`G
M(B<@+B`D97AT<F$@+B`G+"!I;G-T86QL960@=F5R<VEO;B!I<R`G("X@)'9E
M<G-I;VXI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF
M("AI<W-E="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("!F;W)E
M86-H("@D9&5P6R=E>&-L=61E)UT@87,@)&5X8VQU9&4I('L-"B`@("`@("`@
M("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*"1V97)S:6]N+"`D97AC;'5D
M92P@)ST])RDI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D
M97!;)V-O;F9L:6-T<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)VYO9&5P<R==
M*2`F)@T*("`@("`@("`@("`@("`@("`@("`@("`@("`A:7-S970H)'1H:7,M
M/E]O<'1I;VYS6R=F;W)C92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"<E<R!I<R!N;W0@8V]M<&%T
M:6)L92!W:71H(%!(4"!E>'1E;G-I;VX@(B<@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1D97!;)VYA;64G72`N("<B('9E<G-I;VX@)R`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5X8VQU9&4I.PT*("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"=W87)N:6YG.B`E<R!I<R!N;W0@
M8V]M<&%T:6)L92!W:71H(%!(4"!E>'1E;G-I;VX@(B<@+@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1D97!;)VYA;64G72`N("<B('9E<G-I;VX@
M)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5X8VQU9&4I.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?2!E;'-E
M:68@*'9E<G-I;VY?8V]M<&%R92@D=F5R<VEO;BP@)&5X8VQU9&4L("<A/2<I
M("8F(&ES<V5T*"1D97!;)V-O;F9L:6-T<R==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI
M("8F("%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M)R5S(&-O;F9L:6-T<R!W:71H(%!(4"!E>'1E;G-I;VX@(B<@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1D97!;)VYA;64G72`N("<B)R`N("1E
M>'1R82`N("<L(&EN<W1A;&QE9"!V97)S:6]N(&ES("<@+B`D=F5R<VEO;BD[
M#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G=A<FYI;F<H)W=A<FYI;F<Z("5S
M(&-O;F9L:6-T<R!W:71H(%!(4"!E>'1E;G-I;VX@(B<@+@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1D97!;)VYA;64G72`N("<B)R`N("1E>'1R
M82`N("<L(&EN<W1A;&QE9"!V97)S:6]N(&ES("<@+B`D=F5R<VEO;BD[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!;
M)W)E8V]M;65N9&5D)UTI*2![#0H@("`@("`@("`@("!I9B`H=F5R<VEO;E]C
M;VUP87)E*"1V97)S:6]N+"`D9&5P6R=R96-O;6UE;F1E9"==+"`G/3TG*2D@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?
M;W!T:6]N<ULG;F]D97!S)UTI("8F("%I<W-E="@D=&AI<RT^7V]P=&EO;G-;
M)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@G)7,@9&5P96YD96YC>3H@4$A0(&5X=&5N<VEO;B`G
M("X@)&1E<%LG;F%M92==("X-"B`@("`@("`@("`@("`@("`@("`@("`@("<@
M=F5R<VEO;B`B)R`N("1V97)S:6]N("X@)R(G("X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("<@:7,@;F]T('1H92!R96-O;6UE;F1E9"!V97)S:6]N("(G
M("X@)&1E<%LG<F5C;VUM96YD960G72`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`G(BP@8G5T(&UA>2!B92!C;VUP871I8FQE+"!U<V4@+2UF;W)C92!T
M;R!I;G-T86QL)RD[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"=W87)N:6YG
M.B`E<R!D97!E;F1E;F-Y.B!02%`@97AT96YS:6]N("<@+@T*("`@("`@("`@
M("`@("`@("`@("`@("`@)&1E<%LG;F%M92==("X@)R!V97)S:6]N("(G("X@
M)'9E<G-I;VX@+B`G(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)R!I
M<R!N;W0@=&AE(')E8V]M;65N9&5D('9E<G-I;VX@(B<@+B`D9&5P6R=R96-O
M;6UE;F1E9"==+B<B)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N('9A;&ED871E4&AP1&5P96YD96YC>2@D9&5P*0T*
M("`@('L-"B`@("`@("`@:68@*"1T:&ES+3Y?<W1A=&4@(3T@4$5!4E]604Q)
M1$%415])3E-404Q,24Y'("8F#0H@("`@("`@("`@("`@("1T:&ES+3Y?<W1A
M=&4@(3T@4$5!4E]604Q)1$%415]$3U=.3$]!1$E.1RD@>PT*("`@("`@("`@
M("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@)'9E<G-I;VX@
M/2`D=&AI<RT^<&AP=F5R<VEO;B@I.PT*("`@("`@("`D97AT<F$@/2`D=&AI
M<RT^7V=E=$5X=')A4W1R:6YG*"1D97`I.PT*("`@("`@("!I9B`H:7-S970H
M)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@("`@("`@:68@*"%I<U]A<G)A
M>2@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@)&1E<%LG
M97AC;'5D92==(#T@87)R87DH)&1E<%LG97AC;'5D92==*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&1E<%LG;6EN
M)UTI*2![#0H@("`@("`@("`@("!I9B`H(79E<G-I;VY?8V]M<&%R92@D=F5R
M<VEO;BP@)&1E<%LG;6EN)UTL("<^/2<I*2![#0H@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)VYO9&5P<R==*2`F)B`A:7-S
M970H)'1H:7,M/E]O<'1I;VYS6R=F;W)C92==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)R5S(')E<75I<F5S
M(%!(4"<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)&5X=')A("X@)RP@
M:6YS=&%L;&5D('9E<G-I;VX@:7,@)R`N("1V97)S:6]N*3L-"B`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G=A<FYI;F<H)W=A<FYI;F<Z("5S(')E<75I<F5S(%!(4"<@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@)&5X=')A("X@)RP@:6YS=&%L;&5D
M('9E<G-I;VX@:7,@)R`N("1V97)S:6]N*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T
M*"1D97!;)VUA>"==*2D@>PT*("`@("`@("`@("`@:68@*"%V97)S:6]N7V-O
M;7!A<F4H)'9E<G-I;VXL("1D97!;)VUA>"==+"`G/#TG*2D@>PT*("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G
M72D@)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"<E
M<R!R97%U:7)E<R!02%`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("1E
M>'1R82`N("<L(&EN<W1A;&QE9"!V97)S:6]N(&ES("<@+B`D=F5R<VEO;BD[
M#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"=W87)N:6YG.B`E<R!R97%U:7)E
M<R!02%`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("1E>'1R82`N("<L
M(&EN<W1A;&QE9"!V97)S:6]N(&ES("<@+B`D=F5R<VEO;BD[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(&EF("AI<W-E="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("!F
M;W)E86-H("@D9&5P6R=E>&-L=61E)UT@87,@)&5X8VQU9&4I('L-"B`@("`@
M("`@("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*"1V97)S:6]N+"`D97AC
M;'5D92P@)ST])RDI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7V]P=&EO;G-;)VYO9&5P<R==*2`F)@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=F;W)C92==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*"<E<R!I<R!N;W0@8V]M<&%T:6)L92!W:71H(%!(4"!V97)S
M:6]N("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E>&-L=61E
M*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G=V%R;FEN9SH@)7,@:7,@;F]T(&-O;7!A
M=&EB;&4@=VET:"!02%`@=F5R<VEO;B`G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D97AC;'5D92D[#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@5&AI<R!M86ME<R!U;FET+71E<W1I;F<@82!H96-K(&]F(&$@;&]T(&5A
M<VEE<@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%!%05)697)S:6]N*"D-
M"B`@("![#0H@("`@("`@(')E='5R;B`G,2XT+CDG.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N('9A;&ED871E4&5A<FEN<W1A;&QE<D1E<&5N9&5N8WDH)&1E
M<"D-"B`@("![#0H@("`@("`@("1P96%R=F5R<VEO;B`]("1T:&ES+3YG9710
M14%25F5R<VEO;B@I.PT*("`@("`@("`D97AT<F$@/2`D=&AI<RT^7V=E=$5X
M=')A4W1R:6YG*"1D97`I.PT*("`@("`@("!I9B`H:7-S970H)&1E<%LG97AC
M;'5D92==*2D@>PT*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D9&5P6R=E
M>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@)&1E<%LG97AC;'5D92==
M(#T@87)R87DH)&1E<%LG97AC;'5D92==*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*"1P96%R=F5R
M<VEO;BP@)&1E<%LG;6EN)UTL("<\)RDI('L-"B`@("`@("`@("`@(&EF("@A
M:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G72D@)B8@(6ES<V5T*"1T
M:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)R5S(')E<75I<F5S(%!%05(@26YS
M=&%L;&5R)R`N("1E>'1R82`N#0H@("`@("`@("`@("`@("`@("`@("<L(&EN
M<W1A;&QE9"!V97)S:6]N(&ES("<@+B`D<&5A<G9E<G-I;VXI.PT*("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G=A<FYI;F<H)W=A<FYI;F<Z("5S(')E<75I<F5S(%!%05(@26YS=&%L;&5R
M)R`N("1E>'1R82`N#0H@("`@("`@("`@("`@("`@("`@("<L(&EN<W1A;&QE
M9"!V97)S:6]N(&ES("<@+B`D<&5A<G9E<G-I;VXI.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=M87@G72DI
M('L-"B`@("`@("`@("`@(&EF("AV97)S:6]N7V-O;7!A<F4H)'!E87)V97)S
M:6]N+"`D9&5P6R=M87@G72P@)SXG*2D@>PT*("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G72D@)B8@(6ES<V5T
M*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"<E<R!R97%U:7)E<R!0
M14%2($EN<W1A;&QE<B<@+B`D97AT<F$@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@)RP@:6YS=&%L;&5D('9E<G-I;VX@:7,@)R`N("1P96%R=F5R<VEO
M;BD[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"=W87)N:6YG.B`E<R!R97%U
M:7)E<R!014%2($EN<W1A;&QE<B<@+B`D97AT<F$@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@)RP@:6YS=&%L;&5D('9E<G-I;VX@:7,@)R`N("1P96%R
M=F5R<VEO;BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=E>&-L=61E)UTI
M*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!;)V5X8VQU9&4G75LP
M72DI('L-"B`@("`@("`@("`@("`@("`D9&5P6R=E>&-L=61E)UT@/2!A<G)A
M>2@D9&5P6R=E>&-L=61E)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@9F]R96%C:"`H)&1E<%LG97AC;'5D92==(&%S("1E>&-L=61E*2![#0H@
M("`@("`@("`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92@D97AC;'5D92P@
M)'!E87)V97)S:6]N+"`G/3TG*2D@>PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI("8F("%I<W-E
M="@D=&AI<RT^7V]P=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)R5S(&ES(&YO
M="!C;VUP871I8FQE('=I=&@@4$5!4B!);G-T86QL97(@)R`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W9E<G-I;VX@)R`N("1E>&-L=61E*3L-
M"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G=V%R;FEN9SH@)7,@
M:7,@;F]T(&-O;7!A=&EB;&4@=VET:"!014%2("<@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=);G-T86QL97(@=F5R<VEO;B`G("X@)&5X8VQU
M9&4I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('9A;&ED871E4W5B<&%C:V%G
M941E<&5N9&5N8WDH)&1E<"P@)')E<75I<F5D+"`D<&%R86US*0T*("`@('L-
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YV86QI9&%T95!A8VMA9V5$97!E;F1E
M;F-Y*"1D97`L("1R97%U:7)E9"P@)'!A<F%M<RD[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@0'!A<F%M(&%R<F%Y(&1E<&5N9&5N8WD@:6YF;W)M871I
M;VX@*#(N,"!F;W)M870I#0H@("`@("H@0'!A<F%M(&)O;VQE86X@=VAE=&AE
M<B!T:&ES(&ES(&$@<F5Q=6ER960@9&5P96YD96YC>0T*("`@("`J($!P87)A
M;2!A<G)A>2!A(&QI<W0@;V8@9&]W;FQO861E9"!P86-K86=E<R!T;R!B92!I
M;G-T86QL960L(&EF(&%N>0T*("`@("`J($!P87)A;2!B;V]L96%N(&EF('1R
M=64L('1H96X@9&5P<R!O;B!P96%R+G!H<"YN970@=&AA="!F86EL('=I;&P@
M86QS;R!C:&5C:PT*("`@("`J("`@("`@("`@("`@("`@(&%G86EN<W0@<&5C
M;"YP:'`N;F5T('!A8VMA9V5S('1O(&%C8V]M;V1A=&4@97AT96YS:6]N<R!T
M:&%T(&AA=F4-"B`@("`@*B`@("`@("`@("`@("`@("!M;W9E9"!T;R!P96-L
M+G!H<"YN970@9G)O;2!P96%R+G!H<"YN970-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!V86QI9&%T95!A8VMA9V5$97!E;F1E;F-Y*"1D97`L("1R97%U:7)E
M9"P@)'!A<F%M<RP@)&1E<'8Q(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I
M9B`H)'1H:7,M/E]S=&%T92`A/2!014%27U9!3$E$051%7TE.4U1!3$Q)3D<@
M)B8-"B`@("`@("`@("`@("`@)'1H:7,M/E]S=&%T92`A/2!014%27U9!3$E$
M051%7T1/5TY,3T%$24Y'*2![#0H@("`@("`@("`@("!R971U<FX@=')U93L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&1E<%LG<')O=FED97-E
M>'1E;G-I;VXG72DI('L-"B`@("`@("`@("`@(&EF("@D=&AI<RT^97AT96YS
M:6]N7VQO861E9"@D9&5P6R=P<F]V:61E<V5X=&5N<VEO;B==*2D@>PT*("`@
M("`@("`@("`@("`@("1S879E(#T@)&1E<#L-"B`@("`@("`@("`@("`@("`D
M<W5B9&5P(#T@)&1E<#L-"B`@("`@("`@("`@("`@("`D<W5B9&5P6R=N86UE
M)UT@/2`D<W5B9&5P6R=P<F]V:61E<V5X=&5N<VEO;B==.PT*("`@("`@("`@
M("`@("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D54
M55).*3L-"B`@("`@("`@("`@("`@("`D<F5T(#T@)'1H:7,M/G9A;&ED871E
M17AT96YS:6]N1&5P96YD96YC>2@D<W5B9&5P+"`D<F5Q=6ER960I.PT*("`@
M("`@("`@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@
M("`@("`@("`@("!I9B`H(5!%05(Z.FES17)R;W(H)')E="DI('L-"B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@D=&AI
M<RT^7W-T871E(#T](%!%05)?5D%,241!5$5?24Y35$%,3$E.1RD@>PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?=F%L:61A=&5086-K86=E26YS=&%L
M;"@D9&5P+"`D<F5Q=6ER960L("1D97!V,2D[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"1T:&ES+3Y?<W1A=&4@/3T@4$5!4E]604Q)1$%415]$3U=.3$]!
M1$E.1RD@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?=F%L:61A=&50
M86-K86=E1&]W;FQO860H)&1E<"P@)')E<75I<F5D+"`D<&%R86US+"`D9&5P
M=C$I.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7W9A;&ED
M871E4&%C:V%G941O=VYL;V%D*"1D97`L("1R97%U:7)E9"P@)'!A<F%M<RP@
M)&1E<'8Q(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D9&5P6R=P86-K86=E
M)UT@/2`D9&5P6R=N86UE)UT[#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=U
M<FDG72DI('L-"B`@("`@("`@("`@("1D97!;)V-H86YN96PG72`]("=?7W5R
M:2<[#0H@("`@("`@('T-"B`@("`@("`@)&1E<&YA;64@/2`D=&AI<RT^7W)E
M9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*"1D97`L('1R=64I
M.PT*("`@("`@("`D9F]U;F0@/2!F86QS93L-"B`@("`@("`@9F]R96%C:"`H
M)'!A<F%M<R!A<R`D<&%R86TI('L-"B`@("`@("`@("`@(&EF("@D<&%R86TM
M/FES17%U86PH#0H@("`@("`@("`@("`@("`@("!A<G)A>2@G<&%C:V%G92<@
M/3X@)&1E<%LG;F%M92==+`T*("`@("`@("`@("`@("`@("`@("`@("`@)V-H
M86YN96PG(#T^("1D97!;)V-H86YN96PG72DI*2![#0H@("`@("`@("`@("`@
M("`@)&9O=6YD(#T@=')U93L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D9&5P=C$@)B8@)&1E<%LG
M8VAA;FYE;"==(#T]("=P96%R+G!H<"YN970G*2![#0H@("`@("`@("`@("`@
M("`@:68@*"1P87)A;2T^:7-%<75A;"@-"B`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=P86-K86=E)R`]/B`D9&5P6R=N86UE)UTL#0H@("`@("`@("`@("`@
M("`@("`@("`@("`G8VAA;FYE;"<@/3X@)W!E8VPN<&AP+FYE="<I*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D9F]U;F0@/2!T<G5E.PT*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D9F]U;F0@)B8@:7-S
M970H)&1E<%LG<')O=FED97-E>'1E;G-I;VXG72DI('L-"B`@("`@("`@("`@
M(&9O<F5A8V@@*"1P87)A;7,@87,@)'!A<F%M*2![#0H@("`@("`@("`@("`@
M("`@:68@*"1P87)A;2T^:7-%>'1E;G-I;VXH)&1E<%LG<')O=FED97-E>'1E
M;G-I;VXG72DI('L-"B`@("`@("`@("`@("`@("`@("`@)&9O=6YD(#T@=')U
M93L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@D
M9F]U;F0I('L-"B`@("`@("`@("`@("1V97)S:6]N(#T@)'!A<F%M+3YG9716
M97)S:6]N*"D[#0H@("`@("`@("`@("`D:6YS=&%L;&5D(#T@9F%L<V4[#0H@
M("`@("`@("`@("`D9&]W;FQO861E9"`]('1R=64[#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]R96=I<W1R>2T^<&%C:V%G
M945X:7-T<R@D9&5P6R=N86UE)UTL("1D97!;)V-H86YN96PG72DI('L-"B`@
M("`@("`@("`@("`@("`D:6YS=&%L;&5D(#T@=')U93L-"B`@("`@("`@("`@
M("`@("`D9&]W;FQO861E9"`](&9A;'-E.PT*("`@("`@("`@("`@("`@("1V
M97)S:6]N(#T@)'1H:7,M/E]R96=I<W1R>2T^<&%C:V%G96EN9F\H)&1E<%LG
M;F%M92==+"`G=F5R<VEO;B<L#0H@("`@("`@("`@("`@("`@("`@("1D97!;
M)V-H86YN96PG72D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@(&EF("@D9&5P6R=C:&%N;F5L)UT@/3T@)W!E8VPN<&AP+FYE="<@
M)B8@)'1H:7,M/E]R96=I<W1R>2T^<&%C:V%G945X:7-T<R@D9&5P6R=N86UE
M)UTL#0H@("`@("`@("`@("`@("`@("`@("`@)W!E87(N<&AP+FYE="<I*2![
M#0H@("`@("`@("`@("`@("`@("`@("1I;G-T86QL960@/2!T<G5E.PT*("`@
M("`@("`@("`@("`@("`@("`D9&]W;FQO861E9"`](&9A;'-E.PT*("`@("`@
M("`@("`@("`@("`@("`D=F5R<VEO;B`]("1T:&ES+3Y?<F5G:7-T<GDM/G!A
M8VMA9V5I;F9O*"1D97!;)VYA;64G72P@)W9E<G-I;VXG+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@)W!E87(N<&AP+FYE="<I.PT*("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1V97)S:6]N(#T@
M)VYO="!I;G-T86QL960@;W(@9&]W;FQO861E9"<[#0H@("`@("`@("`@("`@
M("`@("`@("1I;G-T86QL960@/2!F86QS93L-"B`@("`@("`@("`@("`@("`@
M("`@)&1O=VYL;V%D960@/2!F86QS93L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&5X=')A(#T@)'1H
M:7,M/E]G971%>'1R85-T<FEN9R@D9&5P*3L-"B`@("`@("`@:68@*&ES<V5T
M*"1D97!;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@(&EF("@A:7-?87)R
M87DH)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@("`@("`@("`@("1D97!;
M)V5X8VQU9&4G72`](&%R<F%Y*"1D97!;)V5X8VQU9&4G72D[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D9&5P6R=M
M:6XG72D@)B8@(6ES<V5T*"1D97!;)VUA>"==*2`F)@T*("`@("`@("`@("`@
M("`A:7-S970H)&1E<%LG<F5C;VUM96YD960G72D@)B8@(6ES<V5T*"1D97!;
M)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@(&EF("@D:6YS=&%L;&5D('Q\
M("1D;W=N;&]A9&5D*2![#0H@("`@("`@("`@("`@("`@)&EN<W1A;&QE9"`]
M("1I;G-T86QL960@/R`G:6YS=&%L;&5D)R`Z("=D;W=N;&]A9&5D)SL-"B`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG8V]N9FQI8W1S)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@D=F5R<VEO;BD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)')E<W0@/2`B+"`D:6YS=&%L;&5D('9E<G-I
M;VX@:7,@(B`N("1V97)S:6]N.PT*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E<W0@/2`G)SL-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI("8F("%I<W-E="@D
M=&AI<RT^7V]P=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)R5S(&-O;F9L:6-T
M<R!W:71H('!A8VMA9V4@(B<@+B`D9&5P;F%M92`N("<B)R`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&5X=')A("X@)')E<W0I.PT*("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"=W87)N:6YG.B`E<R!C;VYF;&EC
M=',@=VET:"!P86-K86=E("(G("X@)&1E<&YA;64@+B`G(B<@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1E>'1R82`N("1R97-T*3L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)V-O;F9L:6-T<R==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1R97%U:7)E9"D@>PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N
M<ULG;F]D97!S)UTI("8F("%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)V9O<F-E
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)R5S(')E<75I<F5S('!A8VMA9V4@(B<@+B`D9&5P;F%M
M92`N("<B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5X=')A
M*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G=V%R;FEN9SH@
M)7,@<F5Q=6ER97,@<&%C:V%G92`B)R`N("1D97!N86UE("X@)R(G("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D97AT<F$I.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"<E<R!C86X@
M;W!T:6]N86QL>2!U<V4@<&%C:V%G92`B)R`N("1D97!N86UE("X@)R(G("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1E>'1R82D[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF
M("@A)&EN<W1A;&QE9"`F)B`A)&1O=VYL;V%D960I('L-"B`@("`@("`@("`@
M(&EF("AI<W-E="@D9&5P6R=C;VYF;&EC=',G72DI('L-"B`@("`@("`@("`@
M("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&EF("@D<F5Q=6ER960I('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI("8F("%I<W-E="@D=&AI<RT^
M7V]P=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G)7,@<F5Q=6ER97,@<&%C:V%G92`B
M)R`N("1D97!N86UE("X@)R(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1E>'1R82D[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"=W87)N:6YG.B`E
M<R!R97%U:7)E<R!P86-K86=E("(G("X@)&1E<&YA;64@+B`G(B<@+@T*("`@
M("`@("`@("`@("`@("`@("`@("`@)&5X=')A*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^=V%R;FEN9R@G)7,@8V%N(&]P=&EO;F%L;'D@=7-E('!A
M8VMA9V4@(B<@+B`D9&5P;F%M92`N("<B)R`N#0H@("`@("`@("`@("`@("`@
M("`@("1E>'1R82D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@)&9A:6P@/2!F86QS93L-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)VUI
M;B==*2D@>PT*("`@("`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92@D=F5R
M<VEO;BP@)&1E<%LG;6EN)UTL("<\)RDI('L-"B`@("`@("`@("`@("`@("`D
M9F%I;"`]('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&ES<V5T*"1D97!;)VUA>"==*2D@>PT*("`@("`@("`@("`@:68@
M*'9E<G-I;VY?8V]M<&%R92@D=F5R<VEO;BP@)&1E<%LG;6%X)UTL("<^)RDI
M('L-"B`@("`@("`@("`@("`@("`D9F%I;"`]('1R=64[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1F86EL("8F("%I<W-E="@D
M9&5P6R=C;VYF;&EC=',G72DI('L-"B`@("`@("`@("`@("1I;G-T86QL960@
M/2`D:6YS=&%L;&5D(#\@)VEN<W1A;&QE9"<@.B`G9&]W;FQO861E9"<[#0H@
M("`@("`@("`@("`D9&5P6R=P86-K86=E)UT@/2`D9&5P6R=N86UE)UT[#0H@
M("`@("`@("`@("`D9&5P(#T@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C
M:V%G94YA;654;U-T<FEN9R@D9&5P+"!T<G5E*3L-"B`@("`@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G72D@)B8@(6ES<V5T
M*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)R5S(')E<75I<F5S('!A8VMA
M9V4@(B<@+B`D9&5P;F%M92`N("<B)R`N#0H@("`@("`@("`@("`@("`@("`@
M("1E>'1R82`N("(L("1I;G-T86QL960@=F5R<VEO;B!I<R`B("X@)'9E<G-I
M;VXI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G=A<FYI;F<H)W=A<FYI;F<Z("5S(')E<75I<F5S('!A
M8VMA9V4@(B<@+B`D9&5P;F%M92`N("<B)R`N#0H@("`@("`@("`@("`@("`@
M("`@("1E>'1R82`N("(L("1I;G-T86QL960@=F5R<VEO;B!I<R`B("X@)'9E
M<G-I;VXI.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V5I9B`H*&ES
M<V5T*"1D97!;)VUI;B==*2!\?"!I<W-E="@D9&5P6R=M87@G72DI("8F("$D
M9F%I;"`F)@T*("`@("`@("`@("`@("!I<W-E="@D9&5P6R=C;VYF;&EC=',G
M72D@)B8@(6ES<V5T*"1D97!;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@
M("1I;G-T86QL960@/2`D:6YS=&%L;&5D(#\@)VEN<W1A;&QE9"<@.B`G9&]W
M;FQO861E9"<[#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T
M:6]N<ULG;F]D97!S)UTI("8F("%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)V9O
M<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"<E<R!C;VYF;&EC=',@=VET:"!P86-K86=E("(G("X@)&1E<&YA
M;64@+B`G(B<@+B`D97AT<F$@+@T*("`@("`@("`@("`@("`@("`@("`B+"`D
M:6YS=&%L;&5D('9E<G-I;VX@:7,@(B`N("1V97)S:6]N*3L-"B`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW
M87)N:6YG*"=W87)N:6YG.B`E<R!C;VYF;&EC=',@=VET:"!P86-K86=E("(G
M("X@)&1E<&YA;64@+B`G(B<@+@T*("`@("`@("`@("`@("`@("`@("`D97AT
M<F$@+B`B+"`D:6YS=&%L;&5D('9E<G-I;VX@:7,@(B`N("1V97)S:6]N*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H
M)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@("`@("`@)&EN<W1A;&QE9"`]
M("1I;G-T86QL960@/R`G:6YS=&%L;&5D)R`Z("=D;W=N;&]A9&5D)SL-"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1D97!;)V5X8VQU9&4G72!A<R`D97AC;'5D
M92D@>PT*("`@("`@("`@("`@("`@(&EF("AV97)S:6]N7V-O;7!A<F4H)'9E
M<G-I;VXL("1E>&-L=61E+"`G/3TG*2`F)B`A:7-S970H)&1E<%LG8V]N9FQI
M8W1S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]O<'1I;VYS6R=N;V1E<',G72D@)B8-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@G)7,@:7,@;F]T(&-O;7!A=&EB;&4@=VET:"`G("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D:6YS=&%L;&5D("X@)R!P86-K86=E("(G
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P;F%M92`N("<B
M('9E<G-I;VX@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5X
M8VQU9&4I.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"=W87)N
M:6YG.B`E<R!I<R!N;W0@8V]M<&%T:6)L92!W:71H("<@+@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1I;G-T86QL960@+B`G('!A8VMA9V4@(B<@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!N86UE("X@)R(@
M=F5R<VEO;B`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D97AC
M;'5D92D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H=F5R<VEO;E]C;VUP87)E*"1V97)S:6]N+"`D97AC;'5D
M92P@)R$])RD@)B8@:7-S970H)&1E<%LG8V]N9FQI8W1S)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("1I;G-T86QL960@/2`D:6YS=&%L;&5D(#\@)VEN
M<W1A;&QE9"<@.B`G9&]W;FQO861E9"<[#0H@("`@("`@("`@("`@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G72D@)B8@(6ES
M<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G)7,@8V]N
M9FQI8W1S('=I=&@@<&%C:V%G92`B)R`N("1D97!N86UE("X@)R(G("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D97AT<F$@+B`B+"`D:6YS=&%L
M;&5D('9E<G-I;VX@:7,@(B`N("1V97)S:6]N*3L-"B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^=V%R;FEN9R@G=V%R;FEN9SH@)7,@8V]N9FQI8W1S('=I=&@@
M<&%C:V%G92`B)R`N("1D97!N86UE("X@)R(G("X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D97AT<F$@+B`B+"`D:6YS=&%L;&5D('9E<G-I;VX@
M:7,@(B`N("1V97)S:6]N*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H:7-S970H)&1E<%LG<F5C;VUM96YD960G72DI('L-"B`@("`@
M("`@("`@("1I;G-T86QL960@/2`D:6YS=&%L;&5D(#\@)VEN<W1A;&QE9"<@
M.B`G9&]W;FQO861E9"<[#0H@("`@("`@("`@("!I9B`H=F5R<VEO;E]C;VUP
M87)E*"1V97)S:6]N+"`D9&5P6R=R96-O;6UE;F1E9"==+"`G/3TG*2D@>PT*
M("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("!I9B`H(21F;W5N9"`F)B`D:6YS=&%L
M;&5D*2![#0H@("`@("`@("`@("`@("`@("`@("1P87)A;2`]("1T:&ES+3Y?
M<F5G:7-T<GDM/F=E=%!A8VMA9V4H)&1E<%LG;F%M92==+"`D9&5P6R=C:&%N
M;F5L)UTI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I
M9B`H)'!A<F%M*2![#0H@("`@("`@("`@("`@("`@("`@("1F;W5N9"`](&9A
M;'-E.PT*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D<&%R86US(&%S
M("1P87)E;G0I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D<&%R
M96YT+3YI<T5Q=6%L*"1T:&ES+3Y?8W5R<F5N=%!A8VMA9V4I*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&9O=6YD(#T@=')U93L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!I9B`H)&9O=6YD*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H)'!A<F%M+3YI<T-O;7!A=&EB;&4H)'!A<F5N="DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L@+R\@=&AI<R!I<R!F;W(@=F%L:61086-K86=E*"D@8V%L;',-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1P87)E;G0@/2`D=&AI<RT^7W)E9VES
M=')Y+3YG971086-K86=E*"1T:&ES+3Y?8W5R<F5N=%!A8VMA9V5;)W!A8VMA
M9V4G72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-U
M<G)E;G1086-K86=E6R=C:&%N;F5L)UTI.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"1P87)E;G0@(3T](&YU;&PI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H)'!A<F%M+3YI<T-O;7!A=&EB;&4H)'!A<F5N
M="DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G72D@)B8@(6ES<V5T*"1T:&ES+3Y?
M;W!T:6]N<ULG9F]R8V4G72D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`A
M:7-S970H)'1H:7,M/E]O<'1I;VYS6R=L;V]S92==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)R5S(&1E<&5N
M9&5N8WD@<&%C:V%G92`B)R`N("1D97!N86UE("X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("<B("<@+B`D:6YS=&%L;&5D("X@)R!V97)S:6]N("<@+B`D
M=F5R<VEO;B`N(`T*("`@("`@("`@("`@("`@("`@("`@("`@)R!I<R!N;W0@
M=&AE(')E8V]M;65N9&5D('9E<G-I;VX@)R`N("1D97!;)W)E8V]M;65N9&5D
M)UT@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)RP@8G5T(&UA>2!B92!C
M;VUP871I8FQE+"!U<V4@+2UF;W)C92!T;R!I;G-T86QL)RD[#0H@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YW87)N:6YG*"=W87)N:6YG.B`E<R!D97!E;F1E;F-Y('!A8VMA
M9V4@(B<@+B`D9&5P;F%M92`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G
M(B`G("X@)&EN<W1A;&QE9"`N("<@=F5R<VEO;B`G("X@)'9E<G-I;VX@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@)R!I<R!N;W0@=&AE(')E8V]M;65N
M9&5D('9E<G-I;VX@)R`N("1D97!;)W)E8V]M;65N9&5D)UTI.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?=F%L:61A
M=&5086-K86=E26YS=&%L;"@D9&5P+"`D<F5Q=6ER960L("1D97!V,2`](&9A
M;'-E*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=F%L:61A=&50
M86-K86=E1&]W;FQO860H)&1E<"P@)')E<75I<F5D+"!A<G)A>2@I+"`D9&5P
M=C$I.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%9E<FEF>2!T:&%T('5N
M:6YS=&%L;&EN9R!P86-K86=E<R!P87-S960@:6X@=&\@8V]M;6%N9"!L:6YE
M(&ES($]++@T*("`@("`J#0H@("`@("H@0'!A<F%M(%!%05)?26YS=&%L;&5R
M("1D;`T*("`@("`J($!R971U<FX@4$5!4E]%<G)O<GQT<G5E#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@=F%L:61A=&5086-K86=E56YI;G-T86QL*"8D9&PI
M#0H@("`@>PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D=&AI<RT^7V1E
M<&5N9&5N8WED8BDI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1E
M<&5N9&5N8WED8CL-"B`@("`@("`@?0T*("`@("`@("`D<&%R86US(#T@87)R
M87DH*3L-"B`@("`@("`@+R\@8V]N<W1R=6-T(&%N(&%R<F%Y(&]F(")D;W=N
M;&]A9&5D(B!P86-K86=E<R!T;R!F;V]L('1H92!P86-K86=E(&1E<&5N9&5N
M8WD@8VAE8VME<@T*("`@("`@("`O+R!I;G1O('5S:6YG('1H97-E('1O('9A
M;&ED871E('5N:6YS=&%L;',@;V8@8VER8W5L87(@9&5P96YD96YC:65S#0H@
M("`@("`@("1D;W=N;&]A9&5D(#T@)B1D;"T^9V5T56YI;G-T86QL4&%C:V%G
M97,H*3L-"B`@("`@("`@9F]R96%C:"`H)&1O=VYL;V%D960@87,@)&D@/3X@
M)'!F*2![#0H@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]$
M;W=N;&]A9&5R7U!A8VMA9V4G*2D@>PT*("`@("`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G4$5!4B]$;W=N;&]A9&5R+U!A8VMA9V4N<&AP)SL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("1D<"`]("9N97<@4$5!4E]$;W=N;&]A
M9&5R7U!A8VMA9V4H)&1L*3L-"B`@("`@("`@("`@("1D<"T^<V5T4&%C:V%G
M949I;&4H)&1O=VYL;V%D961;)&E=*3L-"B`@("`@("`@("`@("1P87)A;7-;
M)&E=(#T@)B1D<#L-"B`@("`@("`@?0T*("`@("`@("`D9&5P<R`]("1T:&ES
M+3Y?9&5P96YD96YC>61B+3YG971$97!E;F1E;G1086-K86=E1&5P96YD96YC
M:65S*"1T:&ES+3Y?8W5R<F5N=%!A8VMA9V4I.PT*("`@("`@("`D9F%I;"`]
M(&9A;'-E.PT*("`@("`@("!I9B`H)&1E<',I('L-"B`@("`@("`@("`@(&9O
M<F5A8V@@*"1D97!S(&%S("1C:&%N;F5L(#T^("1I;F9O*2![#0H@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&EN9F\@87,@)'!A8VMA9V4@/3X@)&1S*2![
M#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1D<R!A<R`D9"D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&1;)V1E<"==6R=P86-K86=E)UT@
M/2`D9%LG9&5P)UU;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1C:&5C:V5R(#T@)FYE=R!014%27T1E<&5N9&5N8WDR*"1T:&ES+3Y?8V]N
M9FEG+"`D=&AI<RT^7V]P=&EO;G,L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH)V-H86YN96PG(#T^("1C:&%N;F5L+"`G<&%C:V%G92<@
M/3X@)'!A8VMA9V4I+"`D=&AI<RT^7W-T871E*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1D97`@/2`D9%LG9&5P)UT[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5Q=6ER960@/2`D9%LG='EP92==(#T]("=R97%U:7)E9"<[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5T(#T@)&-H96-K97(M/E]V
M86QI9&%T95!A8VMA9V55;FEN<W1A;&PH)&1E<"P@)')E<75I<F5D+"`D<&%R
M86US+"`D9&PI.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES7V%R
M<F%Y*"1R970I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1L
M+3YL;V<H,"P@)')E=%LP72D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M(&5L<V5I9B`H4$5!4CHZ:7-%<G)O<B@D<F5T*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1D;"T^;&]G*#`L("1R970M/F=E=$UE<W-A9V4H
M*2D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9A:6P@/2!T<G5E
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(&EF("@D9F%I;"D@>PT*("`@("`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI('Q\(&ES<V5T*"1T
M:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G=A<FYI;F<H#0H@("`@("`@("`@("`@("`@("`@("=W
M87)N:6YG.B`E<R!S:&]U;&0@;F]T(&)E('5N:6YS=&%L;&5D+"!O=&AE<B!I
M;G-T86QL960@<&%C:V%G97,@9&5P96YD("<@+@T*("`@("`@("`@("`@("`@
M("`@("`G;VX@=&AI<R!P86-K86=E)RD[#0H@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@-
M"B`@("`@("`@("`@("`@("`@("`@)R5S(&-A;FYO="!B92!U;FEN<W1A;&QE
M9"P@;W1H97(@:6YS=&%L;&5D('!A8VMA9V5S(&1E<&5N9"!O;B!T:&ES('!A
M8VMA9V4G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@=')U93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?=F%L:61A=&50
M86-K86=E56YI;G-T86QL*"1D97`L("1R97%U:7)E9"P@)'!A<F%M<RP@)B1D
M;"D-"B`@("![#0H@("`@("`@("1D97!;)W!A8VMA9V4G72`]("1D97!;)VYA
M;64G73L-"B`@("`@("`@)&1E<&YA;64@/2`D=&AI<RT^7W)E9VES=')Y+3YP
M87)S961086-K86=E3F%M951O4W1R:6YG*"1D97`L('1R=64I.PT*("`@("`@
M("`D9F]U;F0@/2!F86QS93L-"B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A
M<R`D<&%R86TI('L-"B`@("`@("`@("`@(&EF("@D<&%R86TM/FES17%U86PH
M)'1H:7,M/E]C=7)R96YT4&%C:V%G92DI('L-"B`@("`@("`@("`@("`@("`D
M9F]U;F0@/2!T<G5E.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1V97)S:6]N(#T@)'1H:7,M
M/E]R96=I<W1R>2T^<&%C:V%G96EN9F\H)&1E<%LG;F%M92==+"`G=F5R<VEO
M;B<L#0H@("`@("`@("`@("`D9&5P6R=C:&%N;F5L)UTI.PT*("`@("`@("!I
M9B`H(21V97)S:6]N*2![#0H@("`@("`@("`@("!R971U<FX@=')U93L-"B`@
M("`@("`@?0T*("`@("`@("`D97AT<F$@/2`D=&AI<RT^7V=E=$5X=')A4W1R
M:6YG*"1D97`I.PT*("`@("`@("!I9B`H:7-S970H)&1E<%LG97AC;'5D92==
M*2D@>PT*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D9&5P6R=E>&-L=61E
M)UTI*2![#0H@("`@("`@("`@("`@("`@)&1E<%LG97AC;'5D92==(#T@87)R
M87DH)&1E<%LG97AC;'5D92==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H:7-S970H)&1E<%LG8V]N9FQI8W1S)UTI*2![#0H@
M("`@("`@("`@("!R971U<FX@=')U93L@+R\@=6YI;G-T86QL($]+("T@=&AE
M<V4@<&%C:V%G97,@8V]N9FQI8W0@*'!R;V)A8FQY(&EN<W1A;&QE9"!W:71H
M("TM9F]R8V4I#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D9&5P
M6R=M:6XG72D@)B8@(6ES<V5T*"1D97!;)VUA>"==*2D@>PT*("`@("`@("`@
M("`@:68@*"1R97%U:7)E9"D@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G72D@)B8@(6ES<V5T*"1T:&ES
M+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"<E<R<@+B`D97AT<F$@+B`G(&ES
M(')E<75I<F5D(&)Y(&EN<W1A;&QE9"!P86-K86=E("(G("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1D97!N86UE("X@)R(G*3L-"B`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G=A<FYI;F<H)W=A<FYI;F<Z("5S)R`N("1E>'1R82`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`G(&ES(')E<75I<F5D(&)Y(&EN<W1A;&QE9"!P
M86-K86=E("(G("X@)&1E<&YA;64@+B`G(B<I.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YW87)N:6YG*"<E<R<@+B`D97AT<F$@+@T*("`@("`@("`@
M("`@("`@("`@("`G(&-A;B!B92!O<'1I;VYA;&QY('5S960@8GD@:6YS=&%L
M;&5D('!A8VMA9V4@(B<@+B`D9&5P;F%M92`N("<B)RD[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@)&9A:6P@/2!F86QS93L-"B`@("`@
M("`@:68@*&ES<V5T*"1D97!;)VUI;B==*2D@>PT*("`@("`@("`@("`@:68@
M*'9E<G-I;VY?8V]M<&%R92@D=F5R<VEO;BP@)&1E<%LG;6EN)UTL("<^/2<I
M*2![#0H@("`@("`@("`@("`@("`@)&9A:6P@/2!T<G5E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=M87@G
M72DI('L-"B`@("`@("`@("`@(&EF("AV97)S:6]N7V-O;7!A<F4H)'9E<G-I
M;VXL("1D97!;)VUA>"==+"`G/#TG*2D@>PT*("`@("`@("`@("`@("`@("1F
M86EL(#T@=')U93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H)&9A:6PI('L-"B`@("`@("`@("`@(&EF("@D9F]U;F0I('L-"B`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1D;"T^7U]?8VAE8VME9%LD=&AI
M<RT^7V-U<G)E;G1086-K86=E6R=C:&%N;F5L)UU=#0H@("`@("`@("`@("`@
M("`@("`@("`@6R1T:&ES+3Y?8W5R<F5N=%!A8VMA9V5;)W!A8VMA9V4G75TI
M*2![#0H@("`@("`@("`@("`@("`@("`@("1D;"T^7U]?8VAE8VME9%LD=&AI
M<RT^7V-U<G)E;G1086-K86=E6R=C:&%N;F5L)UU=#0H@("`@("`@("`@("`@
M("`@("`@("`@6R1T:&ES+3Y?8W5R<F5N=%!A8VMA9V5;)W!A8VMA9V4G75T@
M/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`D9&5P<R`]("1T:&ES+3Y?
M9&5P96YD96YC>61B+3YG971$97!E;F1E;G1086-K86=E1&5P96YD96YC:65S
M*`T*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT4&%C
M:V%G92D[#0H@("`@("`@("`@("`@("`@("`@(&EF("@D9&5P<RD@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&1E<',@87,@)&-H86YN
M96P@/3X@)&EN9F\I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F
M;W)E86-H("@D:6YF;R!A<R`D<&%C:V%G92`]/B`D9',I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&1S(&%S("1D*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9%LG9&5P
M)UU;)W!A8VMA9V4G72`]("1D6R=D97`G75LG;F%M92==.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-H96-K97(@/2`F;F5W(%!%
M05)?1&5P96YD96YC>3(H)'1H:7,M/E]C;VYF:6<L("1T:&ES+3Y?;W!T:6]N
M<RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G8VAA;FYE;"<@/3X@)&-H86YN96PL("=P86-K86=E)R`]/B`D<&%C
M:V%G92DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]S=&%T92D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9&5P(#T@)&1;)V1E<"==.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)')E<75I<F5D(#T@)&1;)W1Y<&4G72`]
M/2`G<F5Q=6ER960G.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)')E="`]("1C:&5C:V5R+3Y?=F%L:61A=&5086-K86=E56YI;G-T
M86QL*"1D97`L("1R97%U:7)E9"P@)'!A<F%M<RP-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9&PI.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E
M="DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9F%I;"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8G)E86L@,SL-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9F%I;"`](&9A;'-E.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*"$D9F%I;"D@>PT*("`@("`@("`@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1R
M97%U:7)E9"D@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]O<'1I;VYS6R=N;V1E<',G72D@)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N
M<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*"1D97!N86UE("X@)&5X=')A("X@)R!I<R!R97%U
M:7)E9"!B>2!I;G-T86QL960@<&%C:V%G92<@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@)R`B)7,B)RD[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"=W
M87)N:6YG.B`G("X@)&1E<&YA;64@+B`D97AT<F$@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@)R!I<R!R97%U:7)E9"!B>2!I;G-T86QL960@<&%C:V%G
M92`B)7,B)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G=A<FYI;F<H
M)&1E<&YA;64@+B`D97AT<F$@+B`G(&-A;B!B92!O<'1I;VYA;&QY('5S960@
M8GD@:6YS=&%L;&5D('!A8VMA9V4G("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("<@(B5S(B<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J('9A
M;&ED871E(&$@9&]W;FQO861E9"!P86-K86=E(&%G86EN<W0@:6YS=&%L;&5D
M('!A8VMA9V5S#0H@("`@("H@#0H@("`@("H@07,@;V8@4$5!4B`Q+C0N,RP@
M=&AI<R!W:6QL(&]N;'D@=F%L:61A=&4-"B`@("`@*@T*("`@("`J($!P87)A
M;2!A<G)A>7Q014%27T1O=VYL;V%D97)?4&%C:V%G97Q014%27U!A8VMA9V5&
M:6QE7W8Q?%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B`@("`@("`@("`@
M("`@)'!K9R!P86-K86=E(&ED96YT:69I97(@*&5I=&AE<@T*("`@("`J("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"=P86-K86=E)R`]/B!B;&%H+"`G8VAA
M;FYE;"<@/3X@8FQA:"D@;W(@86X@87)R87D@=VET:`T*("`@("`J("`@("`@
M("`@("`@("`@("`@(&EN9&5X("=I;F9O)R!R969E<F5N8VEN9R!A;B!O8FIE
M8W0I#0H@("`@("H@0'!A<F%M(%!%05)?1&]W;FQO861E<B`D9&P-"B`@("`@
M*B!`<&%R86T@87)R87D@)'!A<F%M<R!F=6QL(&QI<W0@;V8@<&%C:V%G97,@
M=&\@:6YS=&%L;`T*("`@("`J($!R971U<FX@=')U97Q014%27T5R<F]R#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@=F%L:61A=&5086-K86=E*"1P:V<L("8D
M9&PL("1P87)A;7,@/2!A<G)A>2@I*0T*("`@('L-"B`@("`@("`@:68@*&ES
M7V%R<F%Y*"1P:V<I("8F(&ES<V5T*"1P:V=;)VEN9F\G72DI('L-"B`@("`@
M("`@("`@("1D97!S(#T@)'1H:7,M/E]D97!E;F1E;F-Y9&(M/F=E=$1E<&5N
M9&5N=%!A8VMA9V5$97!E;F1E;F-I97,H)'!K9ULG:6YF;R==*3L-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("1D97!S(#T@)'1H:7,M/E]D97!E
M;F1E;F-Y9&(M/F=E=$1E<&5N9&5N=%!A8VMA9V5$97!E;F1E;F-I97,H)'!K
M9RD[#0H@("`@("`@('T-"B`@("`@("`@)&9A:6P@/2!F86QS93L-"B`@("`@
M("`@:68@*"1D97!S*2![#0H@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T
M<R@G4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4G*2D@>PT*("`@("`@("`@("`@
M("`@(')E<75I<F5?;VYC92`G4$5!4B]$;W=N;&]A9&5R+U!A8VMA9V4N<&AP
M)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1D<"`]("9N97<@4$5!
M4E]$;W=N;&]A9&5R7U!A8VMA9V4H)&1L*3L-"B`@("`@("`@("`@(&EF("AI
M<U]O8FIE8W0H)'!K9RDI('L-"B`@("`@("`@("`@("`@("`D9'`M/G-E=%!A
M8VMA9V5&:6QE*"1P:V<I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`D9'`M/G-E=$1O=VYL;V%D55),*"1P:V<I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@4$5!4CHZ<'5S:$5R<F]R2&%N9&QI;F<H
M4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`@("`@9F]R96%C:"`H)&1E
M<',@87,@)&-H86YN96P@/3X@)&EN9F\I('L-"B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D:6YF;R!A<R`D<&%C:V%G92`]/B`D9',I('L-"B`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D<&%C:V0I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("AS=')T;VQO=V5R*"1P86-K9"T^
M9V5T4&%C:V%G92@I*2`]/2!S=')T;VQO=V5R*"1P86-K86=E*2`F)@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMD+3YG971#:&%N;F5L
M*"D@/3T@)&-H86YN96PI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9&PM/FQO9R@S+"`G<VMI<'!I;F<@:6YS=&%L;&5D('!A8VMA9V4@8VAE
M8VL@;V8@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3
M=')I;F<H#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=C:&%N;F5L)R`]/B`D8VAA;FYE;"P@)W!A8VMA9V4G
M(#T^("1P86-K86=E*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=')U92D@+@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("<B+"!V97)S:6]N("(G("X@)'!A8VMD+3YG
M971697)S:6]N*"D@+B`G(B!W:6QL(&)E("<@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=D;W=N;&]A9&5D(&%N9"!I;G-T
M86QL960G*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M92`R.R`O+R!J=6UP('1O(&YE>'0@<&%C:V%G90T*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1D<R!A<R`D9"D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)&-H96-K97(@/2`F;F5W(%!%05)?1&5P96YD96YC>3(H
M)'1H:7,M/E]C;VYF:6<L("1T:&ES+3Y?;W!T:6]N<RP-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@G8VAA;FYE;"<@/3X@)&-H86YN96PL
M("=P86-K86=E)R`]/B`D<&%C:V%G92DL("1T:&ES+3Y?<W1A=&4I.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)&1E<"`]("1D6R=D97`G73L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1R97%U:7)E9"`]("1D6R=T>7!E)UT@/3T@
M)W)E<75I<F5D)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("1R970@/2`D
M8VAE8VME<BT^7W9A;&ED871E4&%C:V%G941O=VYL;V%D*"1D97`L("1R97%U
M:7)E9"P@87)R87DH)B1D<"DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*&ES7V%R<F%Y*"1R970I*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1L+3YL;V<H,"P@)')E=%LP72D[#0H@("`@("`@("`@("`@("`@
M("`@("`@("!](&5L<V5I9B`H4$5!4CHZ:7-%<G)O<B@D<F5T*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1D;"T^;&]G*#`L("1R970M/F=E
M=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9A
M:6P@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN9R@I.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@D9F%I;"D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*`T*("`@("`@("`@("`@("`@("<E
M<R!C86YN;W0@8F4@:6YS=&%L;&5D+"!C;VYF;&EC=',@=VET:"!I;G-T86QL
M960@<&%C:V%G97,G*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@=')U
M93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!V86QI9&%T92!A('!A8VMA
M9V4N>&UL(#$N,"!D97!E;F1E;F-Y#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M=F%L:61A=&5$97!E;F1E;F-Y,2@D9&5P+"`D<&%R86US(#T@87)R87DH*2D-
M"B`@("![#0H@("`@("`@(&EF("@A:7-S970H)&1E<%LG;W!T:6]N86PG72DI
M('L-"B`@("`@("`@("`@("1D97!;)V]P=&EO;F%L)UT@/2`G;F\G.PT*("`@
M("`@("!]#0H@("`@("`@(&QI<W0H)&YE=V1E<"P@)'1Y<&4I(#T@)'1H:7,M
M/FYO<FUA;&EZ941E<"@D9&5P*3L-"B`@("`@("`@:68@*"$D;F5W9&5P*2![
M#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(DEN=F%L
M:60@1&5P96YD96YC>2(I.PT*("`@("`@("!]#0H@("`@("`@(&EF("AM971H
M;V1?97AI<W1S*"1T:&ES+"`B=F%L:61A=&5[)'1Y<&5]1&5P96YD96YC>2(I
M*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/GLB=F%L:61A=&5[)'1Y
M<&5]1&5P96YD96YC>2)]*"1N97=D97`L("1D97!;)V]P=&EO;F%L)UT@/3T@
M)VYO)RP-"B`@("`@("`@("`@("`@("`D<&%R86US+"!T<G5E*3L-"B`@("`@
M("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J($-O;G9E<G0@82`Q+C`@
M9&5P(&EN=&\@82`R+C`@9&5P#0H@("`@("HO#0H@("`@9G5N8W1I;VX@;F]R
M;6%L:7IE1&5P*"1D97`I#0H@("`@>PT*("`@("`@("`D='EP97,@/2!A<G)A
M>2@-"B`@("`@("`@("`@("=P:V<G(#T^("=086-K86=E)RP-"B`@("`@("`@
M("`@("=E>'0G(#T^("=%>'1E;G-I;VXG+`T*("`@("`@("`@("`@)V]S)R`]
M/B`G3W,G+`T*("`@("`@("`@("`@)W!H<"<@/3X@)U!H<"<-"B`@("`@("`@
M*3L-"B`@("`@("`@:68@*&ES<V5T*"1T>7!E<ULD9&5P6R=T>7!E)UU=*2D@
M>PT*("`@("`@("`@("`@)'1Y<&4@/2`D='EP97-;)&1E<%LG='EP92==73L-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R;B!A<G)A>2AF
M86QS92P@9F%L<V4I.PT*("`@("`@("!]#0H@("`@("`@("1N97=D97`@/2!A
M<G)A>2@I.PT*("`@("`@("!S=VET8V@@*"1T>7!E*2![#0H@("`@("`@("`@
M("!C87-E("=086-K86=E)R`Z#0H@("`@("`@("`@("`@("`@)&YE=V1E<%LG
M8VAA;FYE;"==(#T@)W!E87(N<&AP+FYE="<[#0H@("`@("`@("`@("!C87-E
M("=%>'1E;G-I;VXG(#H-"B`@("`@("`@("`@(&-A<V4@)T]S)R`Z#0H@("`@
M("`@("`@("`@("`@)&YE=V1E<%LG;F%M92==(#T@)&1E<%LG;F%M92==.PT*
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@('T-"B`@("`@("`@)&1E<%LG
M<F5L)UT@/2!014%27T1E<&5N9&5N8WDR.CIS:6=N3W!E<F%T;W(H)&1E<%LG
M<F5L)UTI.PT*("`@("`@("!S=VET8V@@*"1D97!;)W)E;"==*2![#0H@("`@
M("`@("`@("!C87-E("=H87,G(#H-"B`@("`@("`@("`@("`@("!R971U<FX@
M87)R87DH)&YE=V1E<"P@)'1Y<&4I.PT*("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("!C87-E("=N;W0G(#H-"B`@("`@("`@("`@("`@("`D;F5W
M9&5P6R=C;VYF;&EC=',G72`]('1R=64[#0H@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@(&-A<V4@)SX])R`Z#0H@("`@("`@("`@("!C87-E("<^
M)R`Z#0H@("`@("`@("`@("`@("`@)&YE=V1E<%LG;6EN)UT@/2`D9&5P6R=V
M97)S:6]N)UT[#0H@("`@("`@("`@("`@("`@:68@*"1D97!;)W)E;"==(#T]
M("<^)RD@>PT*("`@("`@("`@("`@("`@("`@("`D;F5W9&5P6R=E>&-L=61E
M)UT@/2`D9&5P6R=V97)S:6]N)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("<\/2<@.@T*("`@
M("`@("`@("`@8V%S92`G/"<@.@T*("`@("`@("`@("`@("`@("1N97=D97!;
M)VUA>"==(#T@)&1E<%LG=F5R<VEO;B==.PT*("`@("`@("`@("`@("`@(&EF
M("@D9&5P6R=R96PG72`]/2`G/"<I('L-"B`@("`@("`@("`@("`@("`@("`@
M)&YE=V1E<%LG97AC;'5D92==(#T@)&1E<%LG=F5R<VEO;B==.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@
M8V%S92`G;F4G(#H-"B`@("`@("`@("`@(&-A<V4@)R$])R`Z#0H@("`@("`@
M("`@("`@("`@)&YE=V1E<%LG;6EN)UT@/2`G,"<[#0H@("`@("`@("`@("`@
M("`@)&YE=V1E<%LG;6%X)UT@/2`G,3`P,#`P)SL-"B`@("`@("`@("`@("`@
M("`D;F5W9&5P6R=E>&-L=61E)UT@/2`D9&5P6R=V97)S:6]N)UT[#0H@("`@
M("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)ST])R`Z#0H@("`@
M("`@("`@("`@("`@)&YE=V1E<%LG;6EN)UT@/2`D9&5P6R=V97)S:6]N)UT[
M#0H@("`@("`@("`@("`@("`@)&YE=V1E<%LG;6%X)UT@/2`D9&5P6R=V97)S
M:6]N)UT[#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H)'1Y<&4@/3T@)U!H<"<I('L-"B`@("`@("`@("`@(&EF("@A:7-S
M970H)&YE=V1E<%LG;6EN)UTI*2![#0H@("`@("`@("`@("`@("`@)&YE=V1E
M<%LG;6EN)UT@/2`G-"XR+C`G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@:68@*"%I<W-E="@D;F5W9&5P6R=M87@G72DI('L-"B`@("`@("`@("`@
M("`@("`D;F5W9&5P6R=M87@G72`]("<V+C`N,"<[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&%R<F%Y*"1N97=D97`L("1T
M>7!E*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!#;VYV97)T<R!T97AT
M(&-O;7!A<FEN9R!O<&5R871O<G,@=&\@=&AE;2!S:6=N(&5Q=6EV86QE;G1S
M#0H@("`@("H-"B`@("`@*B!%>&%M<&QE.B`G9V4G('1O("<^/2<-"B`@("`@
M*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0'!A<F%M("!S=')I
M;F<@3W!E<F%T;W(-"B`@("`@*B!`<F5T=7)N('-T<FEN9R!3:6=N(&5Q=6EV
M86QE;G0-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S:6=N3W!E<F%T;W(H)&]P
M97)A=&]R*0T*("`@('L-"B`@("`@("`@<W=I=&-H*"1O<&5R871O<BD@>PT*
M("`@("`@("`@("`@8V%S92`G;'0G.B!R971U<FX@)SPG.PT*("`@("`@("`@
M("`@8V%S92`G;&4G.B!R971U<FX@)SP])SL-"B`@("`@("`@("`@(&-A<V4@
M)V=T)SH@<F5T=7)N("<^)SL-"B`@("`@("`@("`@(&-A<V4@)V=E)SH@<F5T
M=7)N("<^/2<[#0H@("`@("`@("`@("!C87-E("=E<2<Z(')E='5R;B`G/3TG
M.PT*("`@("`@("`@("`@8V%S92`G;F4G.B!R971U<FX@)R$])SL-"B`@("`@
M("`@("`@(&1E9F%U;'0Z#0H@("`@("`@("`@("`@("`@<F5T=7)N("1O<&5R
M871O<CL-"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T:6]N(')A:7-E
M17)R;W(H)&US9RD-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7V]P=&EO;G-;)VEG;F]R92UE<G)O<G,G72DI('L-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^=V%R;FEN9R@D;7-G*3L-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*"1M<V<L("1T:&ES
M+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H#0H@("`@
M("`@("`@("`D=&AI<RT^7V-U<G)E;G1086-K86=E+"!T<G5E*2DI.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N('=A<FYI;F<H)&US9RD-"B`@("![#0H@("`@
M("`@(')E='5R;B!A<G)A>2AS<')I;G1F*"1M<V<L("1T:&ES+3Y?<F5G:7-T
M<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H#0H@("`@("`@("`@("`D
M=&AI<RT^7V-U<G)E;G1086-K86=E+"!T<G5E*2DI.PT*("`@('T-"GT-"C\^
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]0
M14%2+T1E<&5N9&5N8WE$0BYP:'``````````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`U-C$V,@`Q,#4Q-30S,S<T,0`P,C(S-#``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`-"B\J*@T*("H@
M4$5!4E]$97!E;F1E;F-Y1$(L(&%D=F%N8V5D(&EN<W1A;&QE9"!P86-K86=E
M<R!D97!E;F1E;F-Y(&1A=&%B87-E#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@
M86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U
M8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T
M:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A
M="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P
M>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B
M=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO
M=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O
M<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@
M0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@5&]M87,@5BX@5BX@
M0V]X(#QC;WA`:61E8VYE="YC;VT^#0H@*B!`875T:&]R("`@("!'<F5G($)E
M879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P
M,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`
M=F5R<VEO;B`@("!#5E,Z("1)9#H@1&5P96YD96YC>41"+G!H<"QV(#$N,S`@
M,C`P-B\P,2\P-B`P-#HT-SHS-B!C96QL;V<@17AP("0-"B`J($!L:6YK("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN
M8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-
M"B`J+PT*#0HO*BH-"B`J($YE961E9"!F;W(@97)R;W(@:&%N9&QI;F<-"B`J
M+PT*<F5Q=6ER95]O;F-E("=014%2+G!H<"<[#0IR97%U:7)E7V]N8V4@)U!%
M05(O0V]N9FEG+G!H<"<[#0H-"B\J*@T*("H@5')A8VL@9&5P96YD96YC>2!R
M96QA=&EO;G-H:7!S(&)E='=E96X@:6YS=&%L;&5D('!A8VMA9V5S#0H@*B!`
M8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T
M:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`875T
M:&]R("`@("!4;VUA<R!6+E8N0V]X(#QC;WA`:61E8RYN970N8V]M/@T*("H@
M0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(
M4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]0
M14%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L
M96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S(%!%05)?1&5P96YD96YC>41"#0I[
M#0H@("`@+R\@>WM[('!R;W!E<G1I97,-"@T*("`@("\J*@T*("`@("`J(%1H
M:7,@:7,@:6YI=&EA;&EZ960@8GD@>T!L:6YK('-E=$-O;F9I9R@I?0T*("`@
M("`J($!V87(@4$5!4E]#;VYF:6<-"B`@("`@*B!`86-C97-S('!R:79A=&4-
M"B`@("`@*B\-"B`@("!V87(@)%]C;VYF:6<[#0H@("`@+RHJ#0H@("`@("H@
M5&AI<R!I<R!I;FET:6%L:7IE9"!B>2![0&QI;FL@<V5T0V]N9FEG*"E]#0H@
M("`@("H@0'9A<B!014%27U)E9VES=')Y#0H@("`@("H@0&%C8V5S<R!P<FEV
M871E#0H@("`@("HO#0H@("`@=F%R("1?<F5G:7-T<GD[#0H@("`@+RHJ#0H@
M("`@("H@1FEL96YA;64@;V8@=&AE(&1E<&5N9&5N8WD@1$(@*'5S=6%L;'D@
M+F1E<&1B*0T*("`@("`J($!V87(@<W1R:6YG#0H@("`@("H@0&%C8V5S<R!P
M<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?9&5P9&(@/2!F86QS93L-"B`@
M("`O*BH-"B`@("`@*B!&:6QE(&YA;64@;V8@=&AE(&QO8VMF:6QE("AU<W5A
M;&QY("YD97!D8FQO8VLI#0H@("`@("H@0'9A<B!S=')I;F<-"B`@("`@*B!`
M86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@)%]L;V-K9FEL92`]
M(&9A;'-E.PT*("`@("\J*@T*("`@("`J($]P96X@9FEL92!R97-O=7)C92!F
M;W(@;&]C:VEN9R!T:&4@;&]C:V9I;&4-"B`@("`@*B!`=F%R(')E<V]U<F-E
M?&9A;'-E#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@
M=F%R("1?;&]C:T9P(#T@9F%L<V4[#0H@("`@+RHJ#0H@("`@("H@05!)('9E
M<G-I;VX@;V8@=&AI<R!C;&%S<RP@=7-E9"!T;R!V86QI9&%T92!A(&9I;&4@
M;VXM9&ES:PT*("`@("`J($!V87(@<W1R:6YG#0H@("`@("H@0&%C8V5S<R!P
M<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?=F5R<VEO;B`]("<Q+C`G.PT*
M("`@("\J*@T*("`@("`J($-A8VAE9"!D97!E;F1E;F-Y(&1A=&%B87-E(&9I
M;&4-"B`@("`@*B!`=F%R(&%R<F%Y?&YU;&P-"B`@("`@*B!`86-C97-S('!R
M:79A=&4-"B`@("`@*B\-"B`@("!V87(@)%]C86-H93L-"@T*("`@("\O('U]
M?0T*("`@("\O('M[>R`F('-I;F=L971O;B@I#0H-"B`@("`O*BH-"B`@("`@
M*B!'970@82!R87<@9&5P96YD96YC>2!D871A8F%S92X@($-A;&QS('-E=$-O
M;F9I9R@I(&%N9"!A<W-E<G1$97!S1$(H*0T*("`@("`J($!P87)A;2!014%2
M7T-O;F9I9PT*("`@("`J($!P87)A;2!S=')I;F=\9F%L<V4@9G5L;"!P871H
M('1O('1H92!D97!E;F1E;F-Y(&1A=&%B87-E+"!O<B!F86QS92!T;R!U<V4@
M9&5F875L=`T*("`@("`J($!R971U<FX@4$5!4E]$97!E;F1E;F-Y1$)\4$5!
M4E]%<G)O<@T*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B`F<VEN9VQE=&]N*"8D8V]N9FEG+"`D9&5P9&(@/2!F86QS92D-"B`@("![
M#0H@("`@("`@(&EF("@A:7-S970H)$=,3T)!3%-;)U]014%27T1%4$5.1$5.
M0UE$0E])3E-404Y#12==#0H@("`@("`@("`@("`@(%LD8V]N9FEG+3YG970H
M)W!H<%]D:7(G+"!N=6QL+"`G<&5A<BYP:'`N;F5T)RE=*2D@>PT*("`@("`@
M("`@("`@)&$@/2!N97<@4$5!4E]$97!E;F1E;F-Y1$([#0H@("`@("`@("`@
M("`D1TQ/0D%,4ULG7U!%05)?1$5014Y$14Y#641"7TE.4U1!3D-%)UT-"B`@
M("`@("`@("`@("`@6R1C;VYF:6<M/F=E="@G<&AP7V1I<B<L(&YU;&PL("=P
M96%R+G!H<"YN970G*5T@/2`F)&$[#0H@("`@("`@("`@("`D82T^<V5T0V]N
M9FEG*"1C;VYF:6<L("1D97!D8BD[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D92`]("1A+3YA<W-E<G1$97!S1$(H*2DI('L-"B`@("`@("`@
M("`@("`@("!R971U<FX@)&4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N("1'3$]"04Q36R=?4$5!4E]$15!%3D1%3D-91$)?
M24Y35$%.0T4G70T*("`@("`@("`@("`@("!;)&-O;F9I9RT^9V5T*"=P:'!?
M9&ER)RP@;G5L;"P@)W!E87(N<&AP+FYE="<I73L-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!3970@=7`@=&AE(')E9VES=')Y+VQO8V%T:6]N(&]F(&1E
M<&5N9&5N8WD@1$(-"B`@("`@*B!`<&%R86T@4$5!4E]#;VYF:6=\9F%L<V4-
M"B`@("`@*B!`<&%R86T@<W1R:6YG?&9A;'-E(&9U;&P@<&%T:"!T;R!T:&4@
M9&5P96YD96YC>2!D871A8F%S92P@;W(@9F%L<V4@=&\@=7-E(&1E9F%U;'0-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971#;VYF:6<H)B1C;VYF:6<L("1D
M97!D8B`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"$D8V]N9FEG*2![
M#0H@("`@("`@("`@("`D=&AI<RT^7V-O;F9I9R`]("9014%27T-O;F9I9SHZ
M<VEN9VQE=&]N*"D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M=&AI<RT^7V-O;F9I9R`]("8D8V]N9FEG.PT*("`@("`@("!]#0H@("`@("`@
M("1T:&ES+3Y?<F5G:7-T<GD@/2`F)'1H:7,M/E]C;VYF:6<M/F=E=%)E9VES
M=')Y*"D[#0H@("`@("`@(&EF("@A)&1E<&1B*2![#0H@("`@("`@("`@("`D
M=&AI<RT^7V1E<&1B(#T@)'1H:7,M/E]C;VYF:6<M/F=E="@G<&AP7V1I<B<L
M(&YU;&PL("=P96%R+G!H<"YN970G*2`N#0H@("`@("`@("`@("`@("`@1$E2
M14-43U)97U-%4$%2051/4B`N("<N9&5P9&(G.PT*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@)'1H:7,M/E]D97!D8B`]("1D97!D8CL-"B`@("`@
M("`@?0T*("`@("`@("`D=&AI<RT^7VQO8VMF:6QE(#T@9&ER;F%M92@D=&AI
M<RT^7V1E<&1B*2`N($1)4D5#5$]265]315!!4D%43U(@+B`G+F1E<&1B;&]C
M:R<[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@9G5N8W1I;VX@:&%S5W)I
M=&5!8V-E<W,H*0T*("`@('L-"B`@("`@("`@:68@*"%`9FEL95]E>&ES=',H
M)'1H:7,M/E]D97!D8BDI('L-"B`@("`@("`@("`@("1D:7(@/2`D=&AI<RT^
M7V1E<&1B.PT*("`@("`@("`@("`@=VAI;&4@*"1D:7(@)B8@)&1I<B`A/2`G
M+B<I('L-"B`@("`@("`@("`@("`@("`D9&ER(#T@9&ER;F%M92@D9&ER*3L@
M+R\@8V0@+BX-"B`@("`@("`@("`@("`@("!I9B`H)&1I<B`A/2`G+B<@)B8@
M0&9I;&5?97AI<W1S*"1D:7(I*2![#0H@("`@("`@("`@("`@("`@("`@(&EF
M("A`:7-?=W)I=&5A8FQE*"1D:7(I*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@0&ES7W=R:71E86)L92@D=&AI<RT^7V1E<&1B
M*3L-"B`@("!]#0H-"B`@("`O+R![>WL@87-S97)T1&5P<T1"*"D-"@T*("`@
M("\J*@T*("`@("`J($-R96%T92!T:&4@9&5P96YD96YC>2!D871A8F%S92P@
M:68@:70@9&]E<VXG="!E>&ES="X@($5R<F]R(&EF('1H92!D871A8F%S92!I
M<PT*("`@("`J(&YE=V5R('1H86X@=&AE(&-O9&4@<F5A9&EN9R!I="X-"B`@
M("`@*B!`<F5T=7)N('9O:61\4$5!4E]%<G)O<@T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(&%S<V5R=$1E<'-$0B@I#0H@("`@>PT*("`@("`@("!I9B`H(6ES
M7V9I;&4H)'1H:7,M/E]D97!D8BDI('L-"B`@("`@("`@("`@("1T:&ES+3YR
M96)U:6QD1$(H*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1D
M97!D8B`]("1T:&ES+3Y?9V5T1&5P1$(H*3L-"B`@("`@("`@("`@("\O($1A
M=&%T>7!E(&9O<FUA="!H87,@8F5E;B!C:&%N9V5D+"!R96)U:6QD('1H92!$
M97!S($1"#0H@("`@("`@("`@("!I9B`H)&1E<&1B6R=?=F5R<VEO;B==(#P@
M)'1H:7,M/E]V97)S:6]N*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/G)E
M8G5I;&1$0B@I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1D
M97!D8ELG7W9E<G-I;VXG77LP?2`^("1T:&ES+3Y?=F5R<VEO;GLP?2D@>PT*
M("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=$97!E
M;F1E;F-Y(&1A=&%B87-E(&ES('9E<G-I;VX@)R`N#0H@("`@("`@("`@("`@
M("`@("`@("1D97!D8ELG7W9E<G-I;VXG72`N("<L(&%N9"!W92!A<F4@=F5R
M<VEO;B`G("X-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V97)S:6]N
M("X@)RP@8V%N;F]T(&-O;G1I;G5E)RD[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!'970@82!L:7-T(&]F
M(&EN<W1A;&QE9"!P86-K86=E<R!T:&%T(&1E<&5N9"!O;B!T:&ES('!A8VMA
M9V4-"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V,7Q014%27U!A
M8VMA9V5&:6QE7W8R?&%R<F%Y#0H@("`@("H@0')E='5R;B!A<G)A>7QF86QS
M90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$1E<&5N9&5N=%!A8VMA9V5S
M*"8D<&MG*0T*("`@('L-"B`@("`@("`@)&1A=&$@/2`D=&AI<RT^7V=E=$1E
M<$1"*"D[#0H@("`@("`@(&EF("AI<U]O8FIE8W0H)'!K9RDI('L-"B`@("`@
M("`@("`@("1C:&%N;F5L(#T@<W1R=&]L;W=E<B@D<&MG+3YG971#:&%N;F5L
M*"DI.PT*("`@("`@("`@("`@)'!A8VMA9V4@/2!S=')T;VQO=V5R*"1P:V<M
M/F=E=%!A8VMA9V4H*2D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D8VAA;FYE;"`]('-T<G1O;&]W97(H)'!K9ULG8VAA;FYE;"==*3L-"B`@
M("`@("`@("`@("1P86-K86=E(#T@<W1R=&]L;W=E<B@D<&MG6R=P86-K86=E
M)UTI.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&%T85LG<&%C
M:V%G97,G75LD8VAA;FYE;%U;)'!A8VMA9V5=*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1D871A6R=P86-K86=E<R==6R1C:&%N;F5L75LD<&%C:V%G95T[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("`J($=E="!A(&QI<W0@;V8@=&AE(&%C='5A;"!D97!E
M;F1E;F-I97,@;V8@:6YS=&%L;&5D('!A8VMA9V5S('1H870@9&5P96YD(&]N
M#0H@("`@("H@82!P86-K86=E+@T*("`@("`J($!P87)A;2!014%27U!A8VMA
M9V5&:6QE7W8Q?%!%05)?4&%C:V%G949I;&5?=C)\87)R87D-"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y?&9A;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T
M1&5P96YD96YT4&%C:V%G941E<&5N9&5N8VEE<R@F)'!K9RD-"B`@("![#0H@
M("`@("`@("1D871A(#T@)'1H:7,M/E]G971$97!$0B@I.PT*("`@("`@("!I
M9B`H:7-?;V)J96-T*"1P:V<I*2![#0H@("`@("`@("`@("`D8VAA;FYE;"`]
M('-T<G1O;&]W97(H)'!K9RT^9V5T0VAA;FYE;"@I*3L-"B`@("`@("`@("`@
M("1P86-K86=E(#T@<W1R=&]L;W=E<B@D<&MG+3YG971086-K86=E*"DI.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&-H86YN96P@/2!S=')T
M;VQO=V5R*"1P:V=;)V-H86YN96PG72D[#0H@("`@("`@("`@("`D<&%C:V%G
M92`]('-T<G1O;&]W97(H)'!K9ULG<&%C:V%G92==*3L-"B`@("`@("`@?0T*
M("`@("`@("`D9&5P96YD(#T@)'1H:7,M/F=E=$1E<&5N9&5N=%!A8VMA9V5S
M*"1P:V<I.PT*("`@("`@("!I9B`H(21D97!E;F0I('L-"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D9&5P96YD96YC
M:65S(#T@87)R87DH*3L-"B`@("`@("`@9F]R96%C:"`H)&1E<&5N9"!A<R`D
M:6YF;RD@>PT*("`@("`@("`@("`@)'1E;7`@/2`D=&AI<RT^9V5T1&5P96YD
M96YC:65S*"1I;F9O*3L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1T96UP(&%S
M("1D97`I('L-"B`@("`@("`@("`@("`@("!I9B`H<W1R=&]L;W=E<B@D9&5P
M6R=D97`G75LG8VAA;FYE;"==*2`]/2!S=')T;VQO=V5R*"1C:&%N;F5L*2`F
M)@T*("`@("`@("`@("`@("`@("`@("`@('-T<G1O;&]W97(H)&1E<%LG9&5P
M)UU;)VYA;64G72D@/3T@<W1R=&]L;W=E<B@D<&%C:V%G92DI('L-"B`@("`@
M("`@("`@("`@("`@("`@)&1E<&5N9&5N8VEE<ULD:6YF;ULG8VAA;FYE;"==
M75LD:6YF;ULG<&%C:V%G92==75M=(#T@)&1E<#L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M("1D97!E;F1E;F-I97,[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@1V5T
M(&$@;&ES="!O9B!D97!E;F1E;F-I97,@;V8@=&AI<R!I;G-T86QL960@<&%C
M:V%G90T*("`@("`J($!P87)A;2!014%27U!A8VMA9V5&:6QE7W8Q?%!%05)?
M4&%C:V%G949I;&5?=C)\87)R87D-"B`@("`@*B!`<F5T=7)N(&%R<F%Y?&9A
M;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T1&5P96YD96YC:65S*"8D
M<&MG*0T*("`@('L-"B`@("`@("`@:68@*&ES7V]B:F5C="@D<&MG*2D@>PT*
M("`@("`@("`@("`@)&-H86YN96P@/2!S=')T;VQO=V5R*"1P:V<M/F=E=$-H
M86YN96PH*2D[#0H@("`@("`@("`@("`D<&%C:V%G92`]('-T<G1O;&]W97(H
M)'!K9RT^9V5T4&%C:V%G92@I*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1C:&%N;F5L(#T@<W1R=&]L;W=E<B@D<&MG6R=C:&%N;F5L)UTI
M.PT*("`@("`@("`@("`@)'!A8VMA9V4@/2!S=')T;VQO=V5R*"1P:V=;)W!A
M8VMA9V4G72D[#0H@("`@("`@('T-"B`@("`@("`@)&1A=&$@/2`D=&AI<RT^
M7V=E=$1E<$1"*"D[#0H@("`@("`@(&EF("AI<W-E="@D9&%T85LG9&5P96YD
M96YC:65S)UU;)&-H86YN96Q=6R1P86-K86=E72DI('L-"B`@("`@("`@("`@
M(')E='5R;B`D9&%T85LG9&5P96YD96YC:65S)UU;)&-H86YN96Q=6R1P86-K
M86=E73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@1&5T97)M:6YE('=H971H97(@)'!A<F5N
M="!D97!E;F1S(&]N("1C:&EL9"P@;F5A<B!O<B!D965P#0H@("`@("H@0'!A
M<F%M(&%R<F%Y?%!%05)?4&%C:V%G949I;&5?=C)\4$5!4E]086-K86=E1FEL
M95]V,@T*("`@("`J($!P87)A;2!A<G)A>7Q014%27U!A8VMA9V5&:6QE7W8R
M?%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!D
M97!E;F1S3VXH)'!A<F5N="P@)&-H:6QD*0T*("`@('L-"B`@("`@("`@)&,@
M/2!A<G)A>2@I.PT*("`@("`@("`D=&AI<RT^7V=E=$1E<$1"*"D[#0H@("`@
M("`@(')E='5R;B`D=&AI<RT^7V1E<&5N9'-/;B@D<&%R96YT+"`D8VAI;&0L
M("1C*3L-"B`@("!]#0H@("`@#0H@("`@9G5N8W1I;VX@7V1E<&5N9'-/;B@D
M<&%R96YT+"`D8VAI;&0L("8D8VAE8VME9"D-"B`@("![#0H@("`@("`@(&EF
M("AI<U]O8FIE8W0H)'!A<F5N="DI('L-"B`@("`@("`@("`@("1C:&%N;F5L
M(#T@<W1R=&]L;W=E<B@D<&%R96YT+3YG971#:&%N;F5L*"DI.PT*("`@("`@
M("`@("`@)'!A8VMA9V4@/2!S=')T;VQO=V5R*"1P87)E;G0M/F=E=%!A8VMA
M9V4H*2D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D8VAA;FYE
M;"`]('-T<G1O;&]W97(H)'!A<F5N=%LG8VAA;FYE;"==*3L-"B`@("`@("`@
M("`@("1P86-K86=E(#T@<W1R=&]L;W=E<B@D<&%R96YT6R=P86-K86=E)UTI
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<U]O8FIE8W0H)&-H:6QD*2D@
M>PT*("`@("`@("`@("`@)&1E<&-H86YN96P@/2!S=')T;VQO=V5R*"1C:&EL
M9"T^9V5T0VAA;FYE;"@I*3L-"B`@("`@("`@("`@("1D97!P86-K86=E(#T@
M<W1R=&]L;W=E<B@D8VAI;&0M/F=E=%!A8VMA9V4H*2D[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`D9&5P8VAA;FYE;"`]('-T<G1O;&]W97(H
M)&-H:6QD6R=C:&%N;F5L)UTI.PT*("`@("`@("`@("`@)&1E<'!A8VMA9V4@
M/2!S=')T;VQO=V5R*"1C:&EL9%LG<&%C:V%G92==*3L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H:7-S970H)&-H96-K961;)&-H86YN96Q=6R1P86-K86=E
M75LD9&5P8VAA;FYE;%U;)&1E<'!A8VMA9V5=*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.R`O+R!A=F]I9"!E;F1L97-S(')E8W5R<VEO;@T*("`@
M("`@("!]#0H@("`@("`@("1C:&5C:V5D6R1C:&%N;F5L75LD<&%C:V%G95U;
M)&1E<&-H86YN96Q=6R1D97!P86-K86=E72`]('1R=64[#0H@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]C86-H95LG9&5P96YD96YC:65S)UU;)&-H86YN
M96Q=6R1P86-K86=E72DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V-A8VAE6R=D
M97!E;F1E;F-I97,G75LD8VAA;FYE;%U;)'!A8VMA9V5=(&%S("1I;F9O*2![
M#0H@("`@("`@("`@("!I9B`H<W1R=&]L;W=E<B@D:6YF;ULG9&5P)UU;)V-H
M86YN96PG72D@/3T@<W1R=&]L;W=E<B@D9&5P8VAA;FYE;"D@)B8-"B`@("`@
M("`@("`@("`@("`@('-T<G1O;&]W97(H)&EN9F];)V1E<"==6R=N86UE)UTI
M(#T]('-T<G1O;&]W97(H)&1E<'!A8VMA9V4I*2![#0H@("`@("`@("`@("`@
M("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/E]C86-H95LG9&5P96YD96YC:65S)UU;
M)&-H86YN96Q=6R1P86-K86=E72!A<R`D:6YF;RD@>PT*("`@("`@("`@("`@
M:68@*"1T:&ES+3Y?9&5P96YD<T]N*&%R<F%Y*`T*("`@("`@("`@("`@("`@
M("`@("`G8VAA;FYE;"<@/3X@)&EN9F];)V1E<"==6R=C:&%N;F5L)UTL#0H@
M("`@("`@("`@("`@("`@("`@("=P86-K86=E)R`]/B`D:6YF;ULG9&5P)UU;
M)VYA;64G72DL("1C:&EL9"P@)&-H96-K960I*2![#0H@("`@("`@("`@("`@
M("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J
M(%)E9VES=&5R(&1E<&5N9&5N8VEE<R!O9B!A('!A8VMA9V4@=&AA="!I<R!B
M96EN9R!I;G-T86QL960@;W(@=7!G<F%D960-"B`@("`@*B!`<&%R86T@4$5!
M4E]086-K86=E1FEL95]V,GQ014%27U!A8VMA9V5&:6QE7W8R#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@:6YS=&%L;%!A8VMA9V4H)B1P86-K86=E*0T*("`@
M('L-"B`@("`@("`@)&1A=&$@/2`D=&AI<RT^7V=E=$1E<$1"*"D[#0H@("`@
M("`@('5N<V5T*"1T:&ES+3Y?8V%C:&4I.PT*("`@("`@("`D=&AI<RT^7W-E
M=%!A8VMA9V5$97!S*"1D871A+"`D<&%C:V%G92D[#0H@("`@("`@("1T:&ES
M+3Y?=W)I=&5$97!$0B@D9&%T82D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@4F5M;W9E(&1E<&5N9&5N8VEE<R!O9B!A('!A8VMA9V4@=&AA="!I<R!B
M96EN9R!U;FEN<W1A;&QE9"P@;W(@=7!G<F%D960N#0H@("`@("H-"B`@("`@
M*B!5<&=R861E9"!P86-K86=E<R!F:7)S="!U;FEN<W1A;&PL('1H96X@:6YS
M=&%L;`T*("`@("`J($!P87)A;2!014%27U!A8VMA9V5&:6QE7W8Q?%!%05)?
M4&%C:V%G949I;&5?=C)\87)R87D@268@86X@87)R87DL('1H96X@:70@;75S
M="!H879E#0H@("`@("H@("`@("`@(&EN9&EC97,@)V-H86YN96PG(&%N9"`G
M<&%C:V%G92<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!U;FEN<W1A;&Q086-K
M86=E*"8D<&MG*0T*("`@('L-"B`@("`@("`@)&1A=&$@/2`D=&AI<RT^7V=E
M=$1E<$1"*"D[#0H@("`@("`@('5N<V5T*"1T:&ES+3Y?8V%C:&4I.PT*("`@
M("`@("!I9B`H:7-?;V)J96-T*"1P:V<I*2![#0H@("`@("`@("`@("`D8VAA
M;FYE;"`]('-T<G1O;&]W97(H)'!K9RT^9V5T0VAA;FYE;"@I*3L-"B`@("`@
M("`@("`@("1P86-K86=E(#T@<W1R=&]L;W=E<B@D<&MG+3YG971086-K86=E
M*"DI.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&-H86YN96P@
M/2!S=')T;VQO=V5R*"1P:V=;)V-H86YN96PG72D[#0H@("`@("`@("`@("`D
M<&%C:V%G92`]('-T<G1O;&]W97(H)'!K9ULG<&%C:V%G92==*3L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H(6ES<V5T*"1D871A6R=D97!E;F1E;F-I97,G
M75LD8VAA;FYE;%U;)'!A8VMA9V5=*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M('1R=64[#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)&1A=&%;)V1E
M<&5N9&5N8VEE<R==6R1C:&%N;F5L75LD<&%C:V%G95T@87,@)&1E<"D@>PT*
M("`@("`@("`@("`@)&9O=6YD(#T@9F%L<V4[#0H@("`@("`@("`@("!I9B`H
M:7-S970H)&1E<%LG9&5P)UU;)W5R:2==*2D@>PT*("`@("`@("`@("`@("`@
M("1D97!C:&%N;F5L(#T@)U]?=7)I)SL-"B`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@)&1E<&-H86YN96P@/2!S=')T;VQO=V5R*"1D
M97!;)V1E<"==6R=C:&%N;F5L)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@:68@*&ES<V5T*"1D871A6R=P86-K86=E<R==6R1D97!C:&%N;F5L
M75MS=')T;VQO=V5R*"1D97!;)V1E<"==6R=N86UE)UTI72DI('L-"B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D9&%T85LG<&%C:V%G97,G75LD9&5P8VAA
M;FYE;%U;<W1R=&]L;W=E<B@D9&5P6R=D97`G75LG;F%M92==*5T@87,-"B`@
M("`@("`@("`@("`@("`@("`@("`D:2`]/B`D:6YF;RD@>PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H)&EN9F];)V-H86YN96PG72`]/2`D8VAA;FYE;"`F
M)@T*("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULG<&%C:V%G92==
M(#T]("1P86-K86=E*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D9F]U
M;F0@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)&9O=6YD*2![#0H@("`@("`@
M("`@("`@("`@=6YS970H)&1A=&%;)W!A8VMA9V5S)UU;)&1E<&-H86YN96Q=
M6W-T<G1O;&]W97(H)&1E<%LG9&5P)UU;)VYA;64G72E=6R1I72D[#0H@("`@
M("`@("`@("`@("`@:68@*"%C;W5N="@D9&%T85LG<&%C:V%G97,G75LD9&5P
M8VAA;FYE;%U;<W1R=&]L;W=E<B@D9&5P6R=D97`G75LG;F%M92==*5TI*2![
M#0H@("`@("`@("`@("`@("`@("`@('5N<V5T*"1D871A6R=P86-K86=E<R==
M6R1D97!C:&%N;F5L75MS=')T;VQO=V5R*"1D97!;)V1E<"==6R=N86UE)UTI
M72D[#0H@("`@("`@("`@("`@("`@("`@(&EF("@A8V]U;G0H)&1A=&%;)W!A
M8VMA9V5S)UU;)&1E<&-H86YN96Q=*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@=6YS970H)&1A=&%;)W!A8VMA9V5S)UU;)&1E<&-H86YN96Q=*3L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("1D871A6R=P86-K86=E<R==6R1D
M97!C:&%N;F5L75MS=')T;VQO=V5R*"1D97!;)V1E<"==6R=N86UE)UTI72`]
M#0H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]V86QU97,H#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&%;)W!A8VMA9V5S)UU;)&1E
M<&-H86YN96Q=6W-T<G1O;&]W97(H)&1E<%LG9&5P)UU;)VYA;64G72E=*3L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@=6YS970H)&1A=&%;)V1E<&5N9&5N8VEE<R==6R1C:&%N;F5L
M75LD<&%C:V%G95TI.PT*("`@("`@("!I9B`H(6-O=6YT*"1D871A6R=D97!E
M;F1E;F-I97,G75LD8VAA;FYE;%TI*2![#0H@("`@("`@("`@("!U;G-E="@D
M9&%T85LG9&5P96YD96YC:65S)UU;)&-H86YN96Q=*3L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H(6-O=6YT*"1D871A6R=D97!E;F1E;F-I97,G72DI('L-
M"B`@("`@("`@("`@('5N<V5T*"1D871A6R=D97!E;F1E;F-I97,G72D[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"%C;W5N="@D9&%T85LG<&%C:V%G97,G
M72DI('L-"B`@("`@("`@("`@('5N<V5T*"1D871A6R=P86-K86=E<R==*3L-
M"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W=R:71E1&5P1$(H)&1A=&$I
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%)E8G5I;&0@=&AE(&1E<&5N
M9&5N8WD@1$(@8GD@<F5A9&EN9R!R96=I<W1R>2!E;G1R:65S+@T*("`@("`J
M($!R971U<FX@=')U97Q014%27T5R<F]R#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@<F5B=6EL9$1"*"D-"B`@("![#0H@("`@("`@("1D97!D8B`](&%R<F%Y
M*"=?=F5R<VEO;B<@/3X@)'1H:7,M/E]V97)S:6]N*3L-"B`@("`@("`@:68@
M*"$D=&AI<RT^:&%S5W)I=&5!8V-E<W,H*2D@>PT*("`@("`@("`@("`@+R\@
M86QL;W<@<W1A<G1U<"!F;W(@<F5A9"UO;FQY('=I=&@@;VQD97(@4F5G:7-T
M<GD-"B`@("`@("`@("`@(')E='5R;B`D9&5P9&([#0H@("`@("`@('T-"B`@
M("`@("`@)'!A8VMA9V5S(#T@)'1H:7,M/E]R96=I<W1R>2T^;&ES=$%L;%!A
M8VMA9V5S*"D[#0H@("`@("`@(&9O<F5A8V@@*"1P86-K86=E<R!A<R`D8VAA
M;FYE;"`]/B`D<',I('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1P<R!A<R`D
M<&%C:V%G92D@>PT*("`@("`@("`@("`@("`@("1P86-K86=E(#T@)'1H:7,M
M/E]R96=I<W1R>2T^9V5T4&%C:V%G92@D<&%C:V%G92P@)&-H86YN96PI.PT*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T4&%C:V%G941E<',H)&1E<&1B
M+"`D<&%C:V%G92D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@)&5R<F]R(#T@)'1H:7,M/E]W<FET941E<$1"*"1D97!D8BD[#0H@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<BDI('L-"B`@("`@("`@("`@
M(')E='5R;B`D97)R;W([#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]C
M86-H92`]("1D97!D8CL-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*
M#0H@("`@+RHJ#0H@("`@("H@4F5G:7-T97(@=7-A9V4@;V8@=&AE(&1E<&5N
M9&5N8WD@1$(@=&\@<')E=F5N="!R86-E(&-O;F1I=&EO;G,-"B`@("`@*B!`
M<&%R86T@:6YT(&]N92!O9B!T:&4@3$]#2U\J(&-O;G-T86YT<PT*("`@("`J
M($!R971U<FX@=')U97Q014%27T5R<F]R#0H@("`@("H@0&%C8V5S<R!P<FEV
M871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7VQO8VLH)&UO9&4@/2!,3T-+
M7T58*0T*("`@('L-"B`@("`@("`@:68@*"%E<F5G:2@G5VEN9&]W<R`Y)RP@
M<&AP7W5N86UE*"DI*2![#0H@("`@("`@("`@("!I9B`H)&UO9&4@(3T@3$]#
M2U]53B`F)B!I<U]R97-O=7)C92@D=&AI<RT^7VQO8VM&<"DI('L-"B`@("`@
M("`@("`@("`@("`O+R!86%@@9&]E<R!N;W0@8VAE8VL@='EP92!O9B!L;V-K
M("A,3T-+7U-(+TQ/0TM?15@I#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D;W!E;E]M;V1E(#T@
M)W<G.PT*("`@("`@("`@("`@+R\@6%A8(%!E;W!L92!R97!O<G1E9"!P<F]B
M;&5M<R!W:71H($Q/0TM?4T@@86YD("=W)PT*("`@("`@("`@("`@:68@*"1M
M;V1E(#T]/2!,3T-+7U-(*2![#0H@("`@("`@("`@("`@("`@:68@*$`A:7-?
M9FEL92@D=&AI<RT^7VQO8VMF:6QE*2D@>PT*("`@("`@("`@("`@("`@("`@
M("!T;W5C:"@D=&AI<RT^7VQO8VMF:6QE*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)&]P96Y?;6]D92`]("=R)SL-"B`@("`@("`@
M("`@('T-"@T*("`@("`@("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^
M7VQO8VM&<"DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VQO8VM&<"`]
M($!F;W!E;B@D=&AI<RT^7VQO8VMF:6QE+"`D;W!E;E]M;V1E*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)'1H:7,M
M/E]L;V-K1G`I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H(F-O=6QD(&YO="!C<F5A=&4@1&5P96YD96YC>2!L;V-K(&9I
M;&4B("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@*&ES<V5T*"1P:'!?97)R;W)M<V<I(#\@(CH@(B`N("1P:'!?97)R;W)M
M<V<@.B`B(BDI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"$H
M:6YT*69L;V-K*"1T:&ES+3Y?;&]C:T9P+"`D;6]D92DI('L-"B`@("`@("`@
M("`@("`@("!S=VET8V@@*"1M;V1E*2![#0H@("`@("`@("`@("`@("`@("`@
M(&-A<V4@3$]#2U]32#H@)'-T<B`]("=S:&%R960G.R`@("!B<F5A:SL-"B`@
M("`@("`@("`@("`@("`@("`@8V%S92!,3T-+7T58.B`D<W1R(#T@)V5X8VQU
M<VEV92<[(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("!C87-E($Q/0TM?
M54XZ("1S='(@/2`G=6YL;V-K)SL@("`@8G)E86L[#0H@("`@("`@("`@("`@
M("`@("`@(&1E9F%U;'0Z("`@("`@)'-T<B`]("=U;FMN;W=N)SL@("!B<F5A
M:SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H(F-O=6QD(&YO="!A8W%U:7)E("1S='(@;&]C
M:R`H)'1H:7,M/E]L;V-K9FEL92DB*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!296QE87-E('5S86=E(&]F(&1E<&5N9&5N8WD@1$(-"B`@("`@
M*B!`<F5T=7)N('1R=65\4$5!4E]%<G)O<@T*("`@("`J($!A8V-E<W,@<')I
M=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]U;FQO8VLH*0T*("`@('L-
M"B`@("`@("`@)')E="`]("1T:&ES+3Y?;&]C:RA,3T-+7U5.*3L-"B`@("`@
M("`@:68@*&ES7W)E<V]U<F-E*"1T:&ES+3Y?;&]C:T9P*2D@>PT*("`@("`@
M("`@("`@9F-L;W-E*"1T:&ES+3Y?;&]C:T9P*3L-"B`@("`@("`@?0T*("`@
M("`@("`D=&AI<RT^7VQO8VM&<"`](&YU;&P[#0H@("`@("`@(')E='5R;B`D
M<F5T.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($QO860@=&AE(&1E<&5N
M9&5N8WD@9&%T86)A<V4@9G)O;2!D:7-K+"!O<B!R971U<FX@=&AE(&-A8VAE
M#0H@("`@("H@0')E='5R;B!A<G)A>7Q014%27T5R<F]R#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@7V=E=$1E<$1"*"D-"B`@("![#0H@("`@("`@(&EF("@A
M)'1H:7,M/FAA<U=R:71E06-C97-S*"DI('L-"B`@("`@("`@("`@(')E='5R
M;B!A<G)A>2@G7W9E<G-I;VXG(#T^("1T:&ES+3Y?=F5R<VEO;BD[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8V%C:&4I*2![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]C86-H93L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H(21F<"`](&9O<&5N*"1T:&ES+3Y?9&5P9&(L("=R)RDI
M('L-"B`@("`@("`@("`@("1E<G(@/2!014%2.CIR86ES945R<F]R*")#;W5L
M9"!N;W0@;W!E;B!D97!E;F1E;F-I97,@9FEL92!@(BXD=&AI<RT^7V1E<&1B
M+B(G(BD[#0H@("`@("`@("`@("!R971U<FX@)&5R<CL-"B`@("`@("`@?0T*
M("`@("`@("`D<G0@/2!G971?;6%G:6-?<75O=&5S7W)U;G1I;64H*3L-"B`@
M("`@("`@<V5T7VUA9VEC7W%U;W1E<U]R=6YT:6UE*#`I.PT*("`@("`@("!C
M;&5A<G-T871C86-H92@I.PT*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S
M*"=F:6QE7V=E=%]C;VYT96YT<R<I*2![#0H@("`@("`@("`@("!F8VQO<V4H
M)&9P*3L-"B`@("`@("`@("`@("1D871A(#T@=6YS97)I86QI>F4H9FEL95]G
M971?8V]N=&5N=',H)'1H:7,M/E]D97!D8BDI.PT*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@)&1A=&$@/2!U;G-E<FEA;&EZ92AF<F5A9"@D9G`L
M(&9I;&5S:7IE*"1T:&ES+3Y?9&5P9&(I*2D[#0H@("`@("`@("`@("!F8VQO
M<V4H)&9P*3L-"B`@("`@("`@?0T*("`@("`@("!S971?;6%G:6-?<75O=&5S
M7W)U;G1I;64H)')T*3L-"B`@("`@("`@)'1H:7,M/E]C86-H92`]("1D871A
M.PT*("`@("`@("!R971U<FX@)&1A=&$[#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@5W)I=&4@;W5T('1H92!D97!E;F1E;F-Y(&1A=&%B87-E('1O(&1I
M<VL-"B`@("`@*B!`<&%R86T@87)R87D@=&AE(&1A=&%B87-E#0H@("`@("H@
M0')E='5R;B!T<G5E?%!%05)?17)R;W(-"B`@("`@*B!`86-C97-S('!R:79A
M=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?=W)I=&5$97!$0B@F)&1E<',I
M#0H@("`@>PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1T:&ES
M+3Y?;&]C:RA,3T-+7T58*2DI('L-"B`@("`@("`@("`@(')E='5R;B`D93L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H(21F<"`](&9O<&5N*"1T:&ES+3Y?
M9&5P9&(L("=W8B<I*2![#0H@("`@("`@("`@("`D=&AI<RT^7W5N;&]C:R@I
M.PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-O=6QD
M(&YO="!O<&5N(&1E<&5N9&5N8VEE<R!F:6QE(&`B+B1T:&ES+3Y?9&5P9&(N
M(B<@9F]R('=R:71I;F<B*3L-"B`@("`@("`@?0T*("`@("`@("`D<G0@/2!G
M971?;6%G:6-?<75O=&5S7W)U;G1I;64H*3L-"B`@("`@("`@<V5T7VUA9VEC
M7W%U;W1E<U]R=6YT:6UE*#`I.PT*("`@("`@("!F=W)I=&4H)&9P+"!S97)I
M86QI>F4H)&1E<',I*3L-"B`@("`@("`@<V5T7VUA9VEC7W%U;W1E<U]R=6YT
M:6UE*"1R="D[#0H@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("`D=&AI
M<RT^7W5N;&]C:R@I.PT*("`@("`@("`D=&AI<RT^7V-A8VAE(#T@)&1E<',[
M#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("`J(%)E9VES=&5R(&%L;"!D97!E;F1E;F-I97,@9G)O;2!A('!A8VMA9V4@
M:6X@=&AE(&1E<&5N9&5N8VEE<R!D871A8F%S92P@:6X@97-S96YC90T*("`@
M("`J(")I;G-T86QL:6YG(B!T:&4@<&%C:V%G92=S(&1E<&5N9&5N8WD@:6YF
M;W)M871I;VX-"B`@("`@*B!`<&%R86T@87)R87D@=&AE(&1A=&%B87-E#0H@
M("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]086-K86=E
M1FEL95]V,@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(%]S971086-K86=E1&5P<R@F)&1A=&$L("8D<&MG*0T*("`@
M('L-"B`@("`@("`@)'!K9RT^<V5T0V]N9FEG*"1T:&ES+3Y?8V]N9FEG*3L-
M"B`@("`@("`@:68@*"1P:V<M/F=E=%!A8VMA9V5X;6Q697)S:6]N*"D@/3T@
M)S$N,"<I('L-"B`@("`@("`@("`@("1G96X@/2`F)'!K9RT^9V5T1&5F875L
M=$=E;F5R871O<B@I.PT*("`@("`@("`@("`@)&1E<',@/2`D9V5N+3YD97!E
M;F1E;F-I97-4;U8R*"D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D9&5P<R`]("1P:V<M/F=E=$1E<',H=')U92D[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"$D9&5P<RD@>PT*("`@("`@("`@("`@<F5T=7)N.PT*("`@
M("`@("!]#0H@("`@("`@("1D871A6R=D97!E;F1E;F-I97,G75MS=')T;VQO
M=V5R*"1P:V<M/F=E=$-H86YN96PH*2E=6W-T<G1O;&]W97(H)'!K9RT^9V5T
M4&%C:V%G92@I*5T-"B`@("`@("`@("`@(#T@87)R87DH*3L-"B`@("`@("`@
M:68@*&ES<V5T*"1D97!S6R=R97%U:7)E9"==6R=P86-K86=E)UTI*2![#0H@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!S6R=R97%U:7)E9"==6R=P86-K
M86=E)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@)&1E<'-;)W)E<75I<F5D
M)UU;)W!A8VMA9V4G72`](&%R<F%Y*"1D97!S6R=R97%U:7)E9"==6R=P86-K
M86=E)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H
M)&1E<'-;)W)E<75I<F5D)UU;)W!A8VMA9V4G72!A<R`D9&5P*2![#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1E<D1E<"@D9&%T82P@)'!K9RP@
M)&1E<"P@)W)E<75I<F5D)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@:68@*&ES<V5T*"1D97!S6R=O<'1I;VYA;"==6R=P86-K86=E
M)UTI*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!S6R=O<'1I;VYA
M;"==6R=P86-K86=E)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@)&1E<'-;
M)V]P=&EO;F%L)UU;)W!A8VMA9V4G72`](&%R<F%Y*"1D97!S6R=O<'1I;VYA
M;"==6R=P86-K86=E)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M9F]R96%C:"`H)&1E<'-;)V]P=&EO;F%L)UU;)W!A8VMA9V4G72!A<R`D9&5P
M*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1E<D1E<"@D9&%T
M82P@)'!K9RP@)&1E<"P@)V]P=&EO;F%L)RD[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!S6R=R97%U:7)E9"==
M6R=S=6)P86-K86=E)UTI*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1D
M97!S6R=R97%U:7)E9"==6R=S=6)P86-K86=E)UU;,%TI*2![#0H@("`@("`@
M("`@("`@("`@)&1E<'-;)W)E<75I<F5D)UU;)W-U8G!A8VMA9V4G72`](&%R
M<F%Y*"1D97!S6R=R97%U:7)E9"==6R=S=6)P86-K86=E)UTI.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)&1E<'-;)W)E<75I<F5D
M)UU;)W-U8G!A8VMA9V4G72!A<R`D9&5P*2![#0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]R96=I<W1E<D1E<"@D9&%T82P@)'!K9RP@)&1E<"P@)W)E<75I
M<F5D)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&ES<V5T*"1D97!S6R=O<'1I;VYA;"==6R=S=6)P86-K86=E)UTI*2![#0H@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!S6R=O<'1I;VYA;"==6R=S=6)P
M86-K86=E)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@)&1E<'-;)V]P=&EO
M;F%L)UU;)W-U8G!A8VMA9V4G72`](&%R<F%Y*"1D97!S6R=O<'1I;VYA;"==
M6R=S=6)P86-K86=E)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M9F]R96%C:"`H)&1E<'-;)V]P=&EO;F%L)UU;)W-U8G!A8VMA9V4G72!A<R`D
M9&5P*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1E<D1E<"@D
M9&%T82P@)'!K9RP@)&1E<"P@)V]P=&EO;F%L)RD[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!S6R=G<F]U<"==
M*2D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P<ULG9W)O=7`G75LP
M72DI('L-"B`@("`@("`@("`@("`@("`D9&5P<ULG9W)O=7`G72`](&%R<F%Y
M*"1D97!S6R=G<F]U<"==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&9O<F5A8V@@*"1D97!S6R=G<F]U<"==(&%S("1G<F]U<"D@>PT*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D9W)O=7!;)W!A8VMA9V4G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9W)O=7!;)W!A8VMA9V4G
M75LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1G<F]U<%LG<&%C
M:V%G92==(#T@87)R87DH)&=R;W5P6R=P86-K86=E)UTI.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1G
M<F]U<%LG<&%C:V%G92==(&%S("1D97`I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<F5G:7-T97)$97`H)&1A=&$L("1P:V<L("1D97`L
M("=O<'1I;VYA;"<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&=R
M;W5P6R=A='1R:6)S)UU;)VYA;64G72D[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1G<F]U<%LG<W5B<&%C:V%G92==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1G<F]U<%LG<W5B<&%C:V%G92==6S!=*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&=R;W5P6R=S=6)P86-K86=E)UT@
M/2!A<G)A>2@D9W)O=7!;)W-U8G!A8VMA9V4G72D[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&=R;W5P
M6R=S=6)P86-K86=E)UT@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]R96=I<W1E<D1E<"@D9&%T82P@)'!K9RP@)&1E<"P@
M)V]P=&EO;F%L)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9W)O
M=7!;)V%T=')I8G,G75LG;F%M92==*3L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H)&1A=&%;)V1E<&5N9&5N8VEE<R==6W-T<G1O;&]W
M97(H)'!K9RT^9V5T0VAA;FYE;"@I*5T-"B`@("`@("`@("`@("`@6W-T<G1O
M;&]W97(H)'!K9RT^9V5T4&%C:V%G92@I*5T@/3T@87)R87DH*2D@>PT*("`@
M("`@("`@("`@=6YS970H)&1A=&%;)V1E<&5N9&5N8VEE<R==6W-T<G1O;&]W
M97(H)'!K9RT^9V5T0VAA;FYE;"@I*5T-"B`@("`@("`@("`@("`@6W-T<G1O
M;&]W97(H)'!K9RT^9V5T4&%C:V%G92@I*5TI.PT*("`@("`@("`@("`@:68@
M*"%C;W5N="@D9&%T85LG9&5P96YD96YC:65S)UU;<W1R=&]L;W=E<B@D<&MG
M+3YG971#:&%N;F5L*"DI72DI('L-"B`@("`@("`@("`@("`@("!U;G-E="@D
M9&%T85LG9&5P96YD96YC:65S)UU;<W1R=&]L;W=E<B@D<&MG+3YG971#:&%N
M;F5L*"DI72D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*B!`<&%R86T@87)R87D@=&AE(&1A=&%B87-E#0H@
M("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]086-K86=E
M1FEL95]V,@T*("`@("`J($!P87)A;2!A<G)A>2!T:&4@<W!E8VEF:6,@9&5P
M96YD96YC>0T*("`@("`J($!P87)A;2!R97%U:7)E9'QO<'1I;VYA;"!W:&5T
M:&5R('1H:7,@:7,@82!R97%U:7)E9"!O<B!A;B!O<'1I;VYA;"!D97`-"B`@
M("`@*B!`<&%R86T@<W1R:6YG?&9A;'-E(&1E<&5N9&5N8WD@9W)O=7`@=&AI
M<R!D97!E;F1E;F-Y(&ES(&9R;VTL(&]R(&9A;'-E(&9O<B!O<F1I;F%R>2!D
M97`-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?<F5G:7-T97)$97`H)B1D871A
M+"`F)'!K9RP@)&1E<"P@)'1Y<&4L("1G<F]U<"`](&9A;'-E*0T*("`@('L-
M"B`@("`@("`@)&EN9F\@/2!A<G)A>2@-"B`@("`@("`@("`@("=D97`G(#T^
M("1D97`L#0H@("`@("`@("`@("`G='EP92<@/3X@)'1Y<&4L#0H@("`@("`@
M("`@("`G9W)O=7`G(#T^("1G<F]U<"D[#0H-"B`@("`@("`@:68@*&ES<V5T
M*"1D97!;)V-H86YN96PG72DI('L-"B`@("`@("`@("`@("1D97!C:&%N;F5L
M(#T@)&1E<%LG8VAA;FYE;"==.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@)&1E<&-H86YN96P@/2`G7U]U<FDG.PT*("`@("`@("!]#0H@("`@
M("`@("1D871A6R=D97!E;F1E;F-I97,G75MS=')T;VQO=V5R*"1P:V<M/F=E
M=$-H86YN96PH*2E=6W-T<G1O;&]W97(H)'!K9RT^9V5T4&%C:V%G92@I*5U;
M70T*("`@("`@("`@("`@/2`D:6YF;SL-"B`@("`@("`@:68@*&ES<V5T*"1D
M871A6R=P86-K86=E<R==6W-T<G1O;&]W97(H)&1E<&-H86YN96PI75MS=')T
M;VQO=V5R*"1D97!;)VYA;64G72E=*2D@>PT*("`@("`@("`@("`@)&9O=6YD
M(#T@9F%L<V4[#0H@("`@("`@("`@("!F;W)E86-H("@D9&%T85LG<&%C:V%G
M97,G75MS=')T;VQO=V5R*"1D97!C:&%N;F5L*5U;<W1R=&]L;W=E<B@D9&5P
M6R=N86UE)UTI70T*("`@("`@("`@("`@("`@("`@87,@)&D@/3X@)'`I('L-
M"B`@("`@("`@("`@("`@("!I9B`H)'!;)V-H86YN96PG72`]/2!S=')T;VQO
M=V5R*"1P:V<M/F=E=$-H86YN96PH*2D@)B8-"B`@("`@("`@("`@("`@("`@
M("`@("`D<%LG<&%C:V%G92==(#T]('-T<G1O;&]W97(H)'!K9RT^9V5T4&%C
M:V%G92@I*2D@>PT*("`@("`@("`@("`@("`@("`@("`D9F]U;F0@/2!T<G5E
M.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(21F;W5N9"D@
M>PT*("`@("`@("`@("`@("`@("1D871A6R=P86-K86=E<R==6W-T<G1O;&]W
M97(H)&1E<&-H86YN96PI75MS=')T;VQO=V5R*"1D97!;)VYA;64G72E=6UT-
M"B`@("`@("`@("`@("`@("`@("`@/2!A<G)A>2@G8VAA;FYE;"<@/3X@<W1R
M=&]L;W=E<B@D<&MG+3YG971#:&%N;F5L*"DI+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=P86-K86=E)R`]/B!S=')T;VQO=V5R*"1P:V<M/F=E
M=%!A8VMA9V4H*2DI.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@)&1A=&%;)W!A8VMA9V5S)UU;<W1R=&]L;W=E<B@D
M9&5P8VAA;FYE;"E=6W-T<G1O;&]W97(H)&1E<%LG;F%M92==*5U;70T*("`@
M("`@("`@("`@("`@(#T@87)R87DH)V-H86YN96PG(#T^('-T<G1O;&]W97(H
M)'!K9RT^9V5T0VAA;FYE;"@I*2P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("=P86-K86=E)R`]/B!S=')T;VQO=V5R*"1P:V<M/F=E=%!A8VMA9V4H*2DI
M.PT*("`@("`@("!]#0H@("`@?0T*?0T*/SX`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]014%2+T1O=VYL;V%D97(O````````````````````````````````
M```````````````````````````````````````P,#`P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<T,``P,C$T,C8`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O1&]W;FQO861E<B]086-K86=E
M+G!H<```````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,C$T,38U`#$P-3$U-#,S
M-S0P`#`R,S4P,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`T*+RHJ#0H@*B!014%27T1O=VYL;V%D97)?4&%C:V%G
M90T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y3
M13H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP
M(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ
M#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC
M96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@
M=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE
M="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-
M"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J
M($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J
M($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC
M96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!0
M2%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!086-K
M86=E+G!H<"QV(#$N.3$@,C`P-B\P,2\R,R`Q.3HP-3HU,B!C96QL;V<@17AP
M("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!2
M96QE87-E(#$N-"XP83$-"B`J+PT*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@
M<&%R86UE=&5R(&EN:71I86QI>F%T:6]N(&9A:6QS(&)E8V%U<V4@;F\@<F5L
M96%S97,-"B`J(&5X:7-T('=I=&AI;B!P<F5F97)R961?<W1A=&4L(&)U="!R
M96QE87-E<R!D;R!E>&ES=`T*("HO#0ID969I;F4H)U!%05)?1$]73DQ/041%
M4E]004-+04=%7U-4051%)RP@+3$P,#,I.PT*+RHJ#0H@*B!#;V]R9&EN871E
M<R!D;W=N;&]A9"!P87)A;65T97)S(&%N9"!M86YA9V5S('1H96ER(&1E<&5N
M9&5N8VEE<PT*("H@<')I;W(@=&\@9&]W;FQO861I;F<@=&AE;2X-"B`J#0H@
M*B!);G!U="!C86X@8V]M92!F<F]M('1H<F5E('-O=7)C97,Z#0H@*@T*("H@
M+2!L;V-A;"!F:6QE<R`H87)C:&EV97,@;W(@<&%C:V%G92YX;6PI#0H@*B`M
M(')E;6]T92!F:6QE<R`H9&]W;FQO861A8FQE('5R;',I#0H@*B`M(&%B<W1R
M86-T('!A8VMA9V4@;F%M97,-"B`J#0H@*B!4:&4@9FER<W0@='=O(&5L96UE
M;G1S(&%R92!H86YD;&5D(&-L96%N;'D@8GD@4$5!4E]086-K86=E1FEL92P@
M8G5T('1H92!T:&ER9"!R97%U:7)E<PT*("H@86-C97-S:6YG('!E87)W96(G
M<R!X;6PM<G!C(&EN=&5R9F%C92!T;R!D971E<FUI;F4@;F5C97-S87)Y(&1E
M<&5N9&5N8VEE<RP@86YD('1H90T*("H@9F]R;6%T(')E='5R;F5D(&]F(&1E
M<&5N9&5N8VEE<R!I<R!S;&EG:'1L>2!D:69F97)E;G0@9G)O;2!T:&%T('5S
M960@:6X@<&%C:V%G92YX;6PN#0H@*@T*("H@5&AI<R!C;&%S<R!H:61E<R!T
M:&4@9&EF9F5R96YC97,@8F5T=V5E;B!T:&5S92!E;&5M96YT<RP@86YD(&UA
M:V5S(&%U=&]M871I8PT*("H@9&5P96YD96YC>2!R97-O;'5T:6]N(&$@<&EE
M8V4@;V8@8V%K92X@($ET(&%L<V\@;6%N86=E<R!C;VYF;&EC=',@=VAE;@T*
M("H@='=O(&-L87-S97,@9&5P96YD(&]N(&EN8V]M<&%T:6)L92!D97!E;F1E
M;F-I97,L(&]R(&1I9F9E<FEN9R!V97)S:6]N<R!O9B!T:&4@<V%M90T*("H@
M<&%C:V%G92!D97!E;F1E;F-Y+B`@26X@861D:71I;VXL(&1O=VYL;V%D('=I
M;&P@;F]T(&)E(&%T=&5M<'1E9"!I9B!T:&4@<&AP('9E<G-I;VX@:7,-"B`J
M(&YO="!S=7!P;W)T960L(%!%05(@:6YS=&%L;&5R('9E<G-I;VX@:7,@;F]T
M('-U<'!O<G1E9"P@;W(@;F]N+5!%0TP@97AT96YS:6]N<R!A<F4@;F]T#0H@
M*B!I;G-T86QL960N#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G
M92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G
M0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'
M<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!2
M96QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL
M86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!4E]$
M;W=N;&]A9&5R7U!A8VMA9V4-"GL-"B`@("`O*BH-"B`@("`@*B!`=F%R(%!%
M05)?1&]W;FQO861E<@T*("`@("`J+PT*("`@('9A<B`D7V1O=VYL;V%D97([
M#0H@("`@+RHJ#0H@("`@("H@0'9A<B!014%27T-O;F9I9PT*("`@("`J+PT*
M("`@('9A<B`D7V-O;F9I9SL-"B`@("`O*BH-"B`@("`@*B!`=F%R(%!%05)?
M4F5G:7-T<GD-"B`@("`@*B\-"B`@("!V87(@)%]R96=I<W1R>3L-"B`@("`O
M*BH-"B`@("`@*B!5<V5D('1O(&EM<&QE;65N="!P86-K86=I;F=R;V]T('!R
M;W!E<FQY#0H@("`@("H@0'9A<B!014%27U)E9VES=')Y#0H@("`@("HO#0H@
M("`@=F%R("1?:6YS=&%L;%)E9VES=')Y.PT*("`@("\J*@T*("`@("`J($!V
M87(@4$5!4E]086-K86=E1FEL95]V,7Q014%27U!A8VMA9V5&:6QE?'8R#0H@
M("`@("HO#0H@("`@=F%R("1?<&%C:V%G969I;&4[#0H@("`@+RHJ#0H@("`@
M("H@0'9A<B!A<G)A>0T*("`@("`J+PT*("`@('9A<B`D7W!A<G-E9&YA;64[
M#0H@("`@+RHJ#0H@("`@("H@0'9A<B!A<G)A>0T*("`@("`J+PT*("`@('9A
M<B`D7V1O=VYL;V%D55),.PT*("`@("\J*@T*("`@("`J($!V87(@87)R87D-
M"B`@("`@*B\-"B`@("!V87(@)%]D;W=N;&]A9$1E<',@/2!A<G)A>2@I.PT*
M("`@("\J*@T*("`@("`J($!V87(@8F]O;&5A;@T*("`@("`J+PT*("`@('9A
M<B`D7W9A;&ED(#T@9F%L<V4[#0H@("`@+RHJ#0H@("`@("H@0'9A<B!B;V]L
M96%N#0H@("`@("HO#0H@("`@=F%R("1?86YA;'EZ960@/2!F86QS93L-"B`@
M("`O*BH-"B`@("`@*B!I9B!T:&ES(&]R(&$@<&%R96YT('!A8VMA9V4@=V%S
M(&EN=F]K960@=VET:"!086-K86=E+7-T871E+"!T:&ES(&ES('-E="!T;R!T
M:&4-"B`@("`@*B!S=&%T92!V87)I86)L92X-"B`@("`@*@T*("`@("`J(%1H
M:7,@86QL;W=S('1E;7!O<F%R>2!R96%S<VEG;FUE;G0@;V8@<')E9F5R<F5D
M7W-T871E(&9O<B!A('!A<F5N="!P86-K86=E(&%N9"!A;&P@;V8-"B`@("`@
M*B!I=',@9&5P96YD96YC:65S+@T*("`@("`J($!V87(@<W1R:6YG?&9A;'-E
M#0H@("`@("HO#0H@("`@=F%R("1?97AP;&EC:713=&%T92`](&9A;'-E.PT*
M("`@("\J*@T*("`@("`J($EF('1H:7,@<&%C:V%G92!I<R!I;G9O:V5D('=I
M=&@@4&%C:V%G92-G<F]U<"P@=&AI<R!V87)I86)L92!W:6QL(&)E('1R=64-
M"B`@("`@*B\-"B`@("!V87(@)%]E>'!L:6-I=$=R;W5P(#T@9F%L<V4[#0H@
M("`@+RHJ#0H@("`@("H@4&%C:V%G92!T>7!E(&QO8V%L?'5R;'QX;6QR<&,-
M"B`@("`@*B!`=F%R('-T<FEN9PT*("`@("`J+PT*("`@('9A<B`D7W1Y<&4[
M#0H@("`@+RHJ#0H@("`@("H@0V]N=&5N=',@;V8@<&%C:V%G92YX;6PL(&EF
M(&1O=VYL;V%D960@9G)O;2!A(')E;6]T92!C:&%N;F5L#0H@("`@("H@0'9A
M<B!S=')I;F=\9F%L<V4-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@
M*B\-"B`@("!V87(@)%]R87=P86-K86=E9FEL93L-"B`@("`O*BH-"B`@("`@
M*B!`=F%R(&)O;VQE86X-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@
M*B\-"B`@("!V87(@)%]V86QI9&%T960@/2!F86QS93L-"@T*("`@("\J*@T*
M("`@("`J($!P87)A;2!014%27T1O=VYL;V%D97(-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!014%27T1O=VYL;V%D97)?4&%C:V%G92@F)&1O=VYL;V%D97(I
M#0H@("`@>PT*("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(@/2`F)&1O=VYL
M;V%D97([#0H@("`@("`@("1T:&ES+3Y?8V]N9FEG(#T@)B1T:&ES+3Y?9&]W
M;FQO861E<BT^8V]N9FEG.PT*("`@("`@("`D=&AI<RT^7W)E9VES=')Y(#T@
M)B1T:&ES+3Y?8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("`D;W!T
M:6]N<R`]("1D;W=N;&]A9&5R+3YG971/<'1I;VYS*"D[#0H@("`@("`@(&EF
M("AI<W-E="@D;W!T:6]N<ULG<&%C:V%G:6YG<F]O="==*2D@>PT*("`@("`@
M("`@("`@)'1H:7,M/E]C;VYF:6<M/G-E=$EN<W1A;&Q2;V]T*"1O<'1I;VYS
M6R=P86-K86=I;F=R;V]T)UTI.PT*("`@("`@("`@("`@)'1H:7,M/E]I;G-T
M86QL4F5G:7-T<GD@/2`F)'1H:7,M/E]C;VYF:6<M/F=E=%)E9VES=')Y*"D[
M#0H@("`@("`@("`@("`D=&AI<RT^7V-O;F9I9RT^<V5T26YS=&%L;%)O;W0H
M9F%L<V4I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M
M/E]I;G-T86QL4F5G:7-T<GD@/2`F)'1H:7,M/E]R96=I<W1R>3L-"B`@("`@
M("`@?0T*("`@("`@("`D=&AI<RT^7W9A;&ED(#T@)'1H:7,M/E]A;F%L>7IE
M9"`](&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%!A<G-E('1H
M92!I;G!U="!A;F0@9&5T97)M:6YE('=H971H97(@=&AI<R!I<R!A(&QO8V%L
M(&9I;&4L(&$@<F5M;W1E('5R:2P@;W(@86X-"B`@("`@*B!A8G-T<F%C="!P
M86-K86=E(&YA;64N#0H@("`@("H-"B`@("`@*B!4:&ES(&ES('1H92!H96%R
M="!O9B!T:&4@4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4H*2P@86YD(&ES('5S
M960@:6X-"B`@("`@*B![0&QI;FL@4$5!4E]$;W=N;&]A9&5R.CID;W=N;&]A
M9"@I?0T*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B!`<F5T=7)N(&)O
M;VQ\4$5!4E]%<G)O<@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&EN:71I86QI
M>F4H)'!A<F%M*0T*("`@('L-"B`@("`@("`@)&]R:6=%<G(@/2`D=&AI<RT^
M7V9R;VU&:6QE*"1P87)A;2D[#0H@("`@("`@(&EF("@A)'1H:7,M/E]V86QI
M9"D@>PT*("`@("`@("`@("`@)&]P=&EO;G,@/2`D=&AI<RT^7V1O=VYL;V%D
M97(M/F=E=$]P=&EO;G,H*3L-"B`@("`@("`@("`@(&EF("AI<W-E="@D;W!T
M:6]N<ULG;V9F;&EN92==*2D@>PT*("`@("`@("`@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1O<FEG17)R*2D@>PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(M/FQO9R@P+"`D;W)I9T5R
M<BT^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G0V%N;F]T(&1O=VYL;V%D(&YO;BUL;V-A;"!P86-K86=E
M("(G("X@)'!A<F%M("X@)R(G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("1E<G(@/2`D=&AI<RT^7V9R;VU5<FPH)'!A<F%M*3L-"B`@("`@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1E<G(I('Q\("$D=&AI<RT^7W9A;&ED
M*2![#0H@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?='EP92`]/2`G=7)L
M)RD@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M97)R*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G*#`L("1E<G(M/F=E=$UE<W-A
M9V4H*2D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H(DEN=F%L:60@;W(@;6ES<VEN9R!R96UO=&4@<&%C:V%G
M92!F:6QE(BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("1E<G(@/2`D=&AI<RT^7V9R;VU3=')I;F<H)'!A<F%M*3L-"B`@("`@("`@
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R*2!\?"`A)'1H:7,M/E]V
M86QI9"D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D97)R*2`F)@T*("`@("`@("`@("`@("`@("`@("`@("`@("`D97)R+3YG
M971#;V1E*"D@/3T@4$5!4E]$3U=.3$]!1$527U!!0TM!1T5?4U1!5$4I('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L@+R\@:6YS
M=')U8W0@=&AE(&1O=VYL;V%D97(@=&\@<VEL96YT;'D@<VMI<`T*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7W1Y<&4I("8F("1T:&ES+3Y?='EP92`]/2`G;&]C86PG("8F
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05(Z.FES17)R;W(H)&]R
M:6=%<G(I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-?87)R
M87DH)&]R:6=%<G(M/F=E=%5S97));F9O*"DI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)&]R:6=%<G(M/F=E=%5S97));F9O
M*"D@87,@)&5R<BD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-?87)R87DH)&5R<BDI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1E<G(@/2`D97)R6R=M97-S86=E)UT[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]D;W=N;&]A9&5R+3YL;V<H,"P@)&5R<BD[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A
M9&5R+3YL;V<H,"P@)&]R:6=%<G(M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-?87)R87DH)'!A<F%M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P87)A;2`]("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA
M9V5.86UE5&]3=')I;F<H)'!A<F%M+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!T<G5E*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(")#86YN;W0@:6YI
M=&EA;&EZ92`G)'!A<F%M)RP@:6YV86QI9"!O<B!M:7-S:6YG('!A8VMA9V4@
M9FEL92(I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G(I*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A
M9&5R+3YL;V<H,"P@)&5R<BT^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)'!A<F%M*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'!A<F%M(#T@)'1H:7,M/E]R96=I<W1R>2T^
M<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@D<&%R86TL('1R=64I.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*`T*("`@("`@("`@("`@("`@("`@("`@("`@
M(D-A;FYO="!I;FET:6%L:7IE("<D<&%R86TG+"!I;G9A;&ED(&]R(&UI<W-I
M;F<@<&%C:V%G92!F:6QE(BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J(%)E=')I979E(&%N>2!N;VXM;&]C86P@
M<&%C:V%G97,-"B`@("`@*B!`<F5T=7)N(%!%05)?4&%C:V%G949I;&5?=C%\
M4$5!4E]086-K86=E1FEL95]V,GQ014%27T5R<F]R#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@)F1O=VYL;V%D*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7W!A8VMA9V5F:6QE*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<&%C:V%G969I;&4[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?9&]W;FQO86154DQ;)W5R;"==*2D@>PT*("`@("`@
M("`@("`@)'1H:7,M/E]I<W9A;&ED(#T@9F%L<V4[#0H@("`@("`@("`@("`D
M:6YF;R`]("1T:&ES+3YG971087)S961086-K86=E*"D[#0H@("`@("`@("`@
M("!F;W)E86-H("@D:6YF;R!A<R`D:2`]/B`D<"D@>PT*("`@("`@("`@("`@
M("`@("1I;F9O6R1I72`]('-T<G1O;&]W97(H)'`I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@)&5R<B`]("1T:&ES+3Y?9G)O;55R;"@D=&AI<RT^
M7V1O=VYL;V%D55),6R=U<FPG72P-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*"1T:&ES+3Y?
M<&%R<V5D;F%M92P@=')U92DI.PT*("`@("`@("`@("`@)&YE=VEN9F\@/2`D
M=&AI<RT^9V5T4&%R<V5D4&%C:V%G92@I.PT*("`@("`@("`@("`@9F]R96%C
M:"`H)&YE=VEN9F\@87,@)&D@/3X@)'`I('L-"B`@("`@("`@("`@("`@("`D
M;F5W:6YF;ULD:5T@/2!S=')T;VQO=V5R*"1P*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&EF("@D:6YF;R`A/2`D;F5W:6YF;RD@>PT*("`@("`@
M("`@("`@("`@(&1O('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1I;F9O
M6R=P86-K86=E)UT@/3T@)W!E8VPN<&AP+FYE="<@)B8@)&YE=VEN9F];)W!A
M8VMA9V4G72`]/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)&EN9F];)W!A8VMA9V4G72`]("=P96%R+G!H<"YN970G.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1I;F9O(#T]("1N97=I;F9O
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@<VMI<"!T:&4@
M8VAA;FYE;"!C:&5C:R!I9B!A('!E8VP@<&%C:V%G92!S87ES(&ET)W,@82!0
M14%2('!A8VMA9V4-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G0U))5$E#04P@15)23U(Z(%=E(&%R92`G("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA
M9V5.86UE5&]3=')I;F<H)&EN9F\I("X@)RP@8G5T('1H92!F:6QE("<@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@)V1O=VYL;V%D960@8VQA:6US('1O
M(&)E("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96=I
M<W1R>2T^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@D=&AI<RT^9V5T4&%R
M<V5D4&%C:V%G92@I*2D[#0H@("`@("`@("`@("`@("`@?2!W:&EL92`H9F%L
M<V4I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)&5R<BD@?'P@(21T:&ES+3Y?=F%L:60I('L-"B`@("`@("`@("`@
M("`@("!R971U<FX@)&5R<CL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("`D=&AI<RT^7W1Y<&4@/2`G;&]C86PG.PT*("`@("`@("!R971U
M<FX@)'1H:7,M/E]P86-K86=E9FEL93L-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B`F9V5T4&%C:V%G949I;&4H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<&%C:V%G969I;&4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@)F=E
M=$1O=VYL;V%D97(H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M9&]W;FQO861E<CL-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G9714>7!E*"D@
M#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/E]T>7!E.PT*("`@('T-
M"@T*("`@("\J*@T*("`@("`J($QI:V4@>T!L:6YK(&EN:71I86QI>F4H*7TL
M(&)U="!O<&5R871E<R!O;B!A(&1E<&5N9&5N8WD-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!F<F]M1&5P55),*"1D97`I#0H@("`@>PT*("`@("`@("`D=&AI
M<RT^7V1O=VYL;V%D55),(#T@)&1E<#L-"B`@("`@("`@:68@*&ES<V5T*"1D
M97!;)W5R:2==*2D@>PT*("`@("`@("`@("`@)&]P=&EO;G,@/2`D=&AI<RT^
M7V1O=VYL;V%D97(M/F=E=$]P=&EO;G,H*3L-"B`@("`@("`@("`@(&EF("@A
M97AT96YS:6]N7VQO861E9"@B>FQI8B(I('Q\(&ES<V5T*"1O<'1I;VYS6R=N
M;V-O;7!R97-S)UTI*2![#0H@("`@("`@("`@("`@("`@)&5X="`]("<N=&%R
M)SL-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&5X
M="`]("<N=&=Z)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(%!%05(Z
M.G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@
M("`@("`@("1E<G(@/2`D=&AI<RT^7V9R;VU5<FPH)&1E<%LG=7)I)UT@+B`D
M97AT*3L-"B`@("`@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-
M"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G(I*2![#0H@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(M/FQO9R@P
M+"`D97)R+3YG971-97-S86=E*"DI.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G26YV86QI
M9"!U<FD@9&5P96YD96YC>2`B)R`N("1D97!;)W5R:2==("X@)&5X="`N("<B
M+"`G("X-"B`@("`@("`@("`@("`@("`@("`@)V-A;FYO="!D;W=N;&]A9"<I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@)'1H:7,M/E]P87)S961N86UE(#T-"B`@("`@("`@("`@("`@("!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`@("`@)W!A8VMA9V4G(#T^("1D97!;)VEN
M9F\G72T^9V5T4&%C:V%G92@I+`T*("`@("`@("`@("`@("`@("`@("`G8VAA
M;FYE;"<@/3X@)&1E<%LG:6YF;R==+3YG971#:&%N;F5L*"DL#0H@("`@("`@
M("`@("`@("`@("`@("=V97)S:6]N)R`]/B`D9&5P6R=V97)S:6]N)UT-"B`@
M("`@("`@("`@("`@("`I.PT*("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P
M6R=N;V1E9F%U;'0G72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<G-E9&YA;65;)V=R;W5P)UT@/2`G9&5F875L="<[("\O(&1O=VYL;V%D('1H
M92!D969A=6QT(&1E<&5N9&5N8WD@9W)O=7`-"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V5X<&QI8VET1W)O=7`@/2!F86QS93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1T:&ES+3Y?<F%W<&%C:V%G969I;&4@/2`D9&5P6R=R
M87<G73L-"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T:6]N(&1E=&5C
M=$1E<&5N9&5N8VEE<R@D<&%R86US*0T*("`@('L-"B`@("`@("`@)&]P=&EO
M;G,@/2`D=&AI<RT^7V1O=VYL;V%D97(M/F=E=$]P=&EO;G,H*3L-"B`@("`@
M("`@:68@*&ES<V5T*"1O<'1I;VYS6R=D;W=N;&]A9&]N;'DG72DI('L-"B`@
M("`@("`@("`@(')E='5R;CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S
M970H)&]P=&EO;G-;)V]F9FQI;F4G72DI('L-"B`@("`@("`@("`@("1T:&ES
M+3Y?9&]W;FQO861E<BT^;&]G*#,L("=3:VEP<&EN9R!D97!E;F1E;F-Y(&1O
M=VYL;V%D(&-H96-K+"`M+6]F9FQI;F4@<W!E8VEF:65D)RD[#0H@("`@("`@
M("`@("!R971U<FX[#0H@("`@("`@('T-"B`@("`@("`@)'!N86UE(#T@)'1H
M:7,M/F=E=%!A<G-E9%!A8VMA9V4H*3L-"B`@("`@("`@:68@*"$D<&YA;64I
M('L-"B`@("`@("`@("`@(')E='5R;CL-"B`@("`@("`@?0T*("`@("`@("`D
M9&5P<R`]("1T:&ES+3YG971$97!S*"D[#0H@("`@("`@(&EF("@A)&1E<',I
M('L-"B`@("`@("`@("`@(')E='5R;CL-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H:7-S970H)&1E<'-;)W)E<75I<F5D)UTI*2![("\O('!A8VMA9V4N>&UL
M(#(N,`T*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&5T96-T,B@D9&5P
M<RP@)'!N86UE+"`D;W!T:6]N<RP@)'!A<F%M<RD[#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D971E8W0Q*"1D97!S
M+"`D<&YA;64L("1O<'1I;VYS+"`D<&%R86US*3L-"B`@("`@("`@?0T*("`@
M('T-"@T*("`@(&9U;F-T:6]N('-E=%9A;&ED871E9"@I#0H@("`@>PT*("`@
M("`@("`D=&AI<RT^7W9A;&ED871E9"`]('1R=64[#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@86QR96%D>59A;&ED871E9"@I#0H@("`@>PT*("`@("`@("!R
M971U<FX@)'1H:7,M/E]V86QI9&%T960[#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@4F5M;W9E('!A8VMA9V5S('1O(&)E(&1O=VYL;V%D960@=&AA="!A
M<F4@86QR96%D>2!I;G-T86QL960-"B`@("`@*B!`<&%R86T@87)R87D@;V8@
M4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4@;V)J96-T<PT*("`@("`J($!S=&%T
M:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!R96UO=F5);G-T86QL960H)B1P
M87)A;7,I#0H@("`@>PT*("`@("`@("!I9B`H(6ES<V5T*"1P87)A;7-;,%TI
M*2![#0H@("`@("`@("`@("!R971U<FX[#0H@("`@("`@('T-"B`@("`@("`@
M)&]P=&EO;G,@/2`D<&%R86US6S!=+3Y?9&]W;FQO861E<BT^9V5T3W!T:6]N
M<R@I.PT*("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=D;W=N;&]A9&]N
M;'DG72DI('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)&D@
M/3X@)'!A<F%M*2![#0H@("`@("`@("`@("`@("`@+R\@<F5M;W9E('-E;&8@
M:68@86QR96%D>2!I;G-T86QL960@=VET:"!T:&ES('9E<G-I;VX-"B`@("`@
M("`@("`@("`@("`O+R!T:&ES(&1O97,@;F]T(&YE960@86YY('!E8VP@;6%G
M:6,@+2!W92!O;FQY(')E;6]V92!E>&%C="!M871C:&5S#0H@("`@("`@("`@
M("`@("`@:68@*"1P87)A;2T^7VEN<W1A;&Q296=I<W1R>2T^<&%C:V%G945X
M:7-T<R@D<&%R86TM/F=E=%!A8VMA9V4H*2P@)'!A<F%M+3YG971#:&%N;F5L
M*"DI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AV97)S:6]N7V-O;7!A
M<F4H)'!A<F%M+3Y?:6YS=&%L;%)E9VES=')Y+3YP86-K86=E26YF;R@D<&%R
M86TM/F=E=%!A8VMA9V4H*2P@)W9E<G-I;VXG+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<&%R86TM/F=E=$-H86YN96PH*2DL("1P87)A;2T^9V5T
M5F5R<VEO;B@I+"`G/3TG*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D:6YF;R`]("1P87)A;2T^9V5T4&%R<V5D4&%C
M:V%G92@I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1I
M;F9O6R=V97)S:6]N)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('5N<V5T*"1I;F9O6R=S=&%T92==*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;2T^7V1O=VYL;V%D
M97(M/FQO9R@Q+"`G4VMI<'!I;F<@<&%C:V%G92`B)R`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86TM/F=E=%-H;W)T3F%M
M92@I("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<B
M+"!A;')E861Y(&EN<W1A;&QE9"!A<R!V97)S:6]N("<@+@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M+3Y?:6YS=&%L;%)E
M9VES=')Y+3YP86-K86=E26YF;R@D<&%R86TM/F=E=%!A8VMA9V4H*2P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=F5R<VEO
M;B<L("1P87)A;2T^9V5T0VAA;FYE;"@I*2D[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M87)A;7-;)&E=(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@A:7-S970H)&]P=&EO
M;G-;)V9O<F-E)UTI("8F("%I<W-E="@D;W!T:6]N<ULG=7!G<F%D92==*2`F
M)@T*("`@("`@("`@("`@("`@("`@("`@("`@("`A:7-S970H)&]P=&EO;G-;
M)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O(#T@
M)'!A<F%M+3YG971087)S961086-K86=E*"D[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D<&%R86TM/E]D;W=N;&]A9&5R+3YL;V<H,2P@)U-K:7!P:6YG
M('!A8VMA9V4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M87)A;2T^9V5T4VAO<G1.86UE*"D@+@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("<B+"!A;')E861Y(&EN<W1A;&QE9"!A<R!V97)S:6]N("<@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;2T^7VEN<W1A;&Q2
M96=I<W1R>2T^<&%C:V%G94EN9F\H)'!A<F%M+3YG971086-K86=E*"DL("=V
M97)S:6]N)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A
M<F%M+3YG971#:&%N;F5L*"DI*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1P87)A;7-;)&E=(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4Z.G)E;6]V941U<&QI
M8V%T97,H)'!A<F%M<RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7V1E=&5C
M=#(H)&1E<',L("1P;F%M92P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*
M("`@("`@("`D=&AI<RT^7V1O=VYL;V%D1&5P<R`](&%R<F%Y*"D[#0H@("`@
M("`@("1G<F]U<&YO=&9O=6YD(#T@9F%L<V4[#0H@("`@("`@(&9O<F5A8V@@
M*&%R<F%Y*"=P86-K86=E)RP@)W-U8G!A8VMA9V4G*2!A<R`D<&%C:V%G971Y
M<&4I('L-"B`@("`@("`@("`@("\O(&=E="!R97%U:7)E9"!D97!E;F1E;F-Y
M(&=R;W5P#0H@("`@("`@("`@("!I9B`H:7-S970H)&1E<'-;)W)E<75I<F5D
M)UU;)'!A8VMA9V5T>7!E72DI('L-"B`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&1E<'-;)W)E<75I<F5D)UU;)'!A8VMA9V5T>7!E75LP72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&1E<'-;)W)E<75I<F5D)UU;
M)'!A8VMA9V5T>7!E72!A<R`D9&5P*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&1E<%LG8V]N9FQI8W1S)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@<VMI<"!A;GD@<&%C:V%G92!T:&%T
M('1H:7,@<&%C:V%G92!C;VYF;&EC=',@=VET:`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)')E="`]("1T:&ES+3Y?
M9&5T96-T,D1E<"@D9&5P+"`D<&YA;64L("=R97%U:7)E9"<L("1P87)A;7,I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1R970I
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N
M;&]A9$1E<'-;72`]("1R970[#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`D9&5P(#T@)&1E<'-;)W)E<75I
M<F5D)UU;)'!A8VMA9V5T>7!E73L-"B`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D9&5P6R=C;VYF;&EC=',G72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("\O('-K:7`@86YY('!A8VMA9V4@=&AA="!T:&ES('!A8VMA
M9V4@8V]N9FQI8W1S('=I=&@-"B`@("`@("`@("`@("`@("`@("`@("`@("1R
M970@/2`D=&AI<RT^7V1E=&5C=#)$97`H)&1E<"P@)'!N86UE+"`G<F5Q=6ER
M960G+"`D<&%R86US*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI
M<U]A<G)A>2@D<F5T*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?9&]W;FQO861$97!S6UT@/2`D<F5T.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@+R\@9V5T
M(&]P=&EO;F%L(&1E<&5N9&5N8WD@9W)O=7`L(&EF(&%N>0T*("`@("`@("`@
M("`@:68@*&ES<V5T*"1D97!S6R=O<'1I;VYA;"==6R1P86-K86=E='EP95TI
M*2![#0H@("`@("`@("`@("`@("`@)'-K:7!N86UE<R`](&%R<F%Y*"D[#0H@
M("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P<ULG;W!T:6]N86PG75LD
M<&%C:V%G971Y<&5=6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`D9&5P
M<ULG;W!T:6]N86PG75LD<&%C:V%G971Y<&5=(#T@87)R87DH)&1E<'-;)V]P
M=&EO;F%L)UU;)'!A8VMA9V5T>7!E72D[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1D97!S6R=O<'1I;VYA;"==6R1P
M86-K86=E='EP95T@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@("`@("`D
M<VMI<"`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1O<'1I;VYS6R=A;&QD97!S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D9&5P6R=P86-K86=E)UT@/2`D9&5P6R=N86UE)UT[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N
M;&]A9&5R+3YL;V<H,RP@)TYO=&EC93H@<&%C:V%G92`B)R`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y+3YP87)S
M961086-K86=E3F%M951O4W1R:6YG*"1T:&ES+3YG971087)S961086-K86=E
M*"DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T<G5E
M*2`N("<B(&]P=&EO;F%L(&1E<&5N9&5N8WD@(B<@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y+3YP87)S9610
M86-K86=E3F%M951O4W1R:6YG*&%R<F%Y*"=P86-K86=E)R`]/@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<%LG;F%M92==+"`G
M8VAA;FYE;"<@/3X@)W!E87(N<&AP+FYE="<I+"!T<G5E*2`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("<B('=I;&P@;F]T(&)E(&%U=&]M
M871I8V%L;'D@9&]W;FQO861E9"<I.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)'-K:7!N86UE<UM=(#T@
M)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@D
M9&5P+"!T<G5E*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1S:VEP(#T@
M=')U93L-"B`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1D97!;)W!A
M8VMA9V4G72D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@:68@*"$H)')E="`]("1T:&ES+3Y?9&5T96-T,D1E<"@D9&5P
M+"`D<&YA;64L("=O<'1I;VYA;"<L("1P87)A;7,I*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)&1E<%LG<&%C:V%G92==(#T@)&1E<%LG;F%M92==
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*$`D<VMI<&YA;65S6V-O
M=6YT*"1S:VEP;F%M97,I("T@,5T@/3T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE
M5&]3=')I;F<H)&1E<"P@=')U92DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>5]P;W`H)'-K:7!N86UE<RD[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"$D<VMI<"`F)B!I<U]A<G)A>2@D<F5T*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9$1E<'-;
M72`]("1R970[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1S:VEP;F%M97,I
M*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;
M)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9&]W;FQO861E<BT^;&]G*#$L("=$:60@;F]T(&1O=VYL;V%D(&]P=&EO;F%L
M(&1E<&5N9&5N8VEE<SH@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:6UP;&]D92@G+"`G+"`D<VMI<&YA;65S*2`N#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)RP@=7-E("TM86QL9&5P<R!T;R!D;W=N;&]A9"!A
M=71O;6%T:6-A;&QY)RD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`O+R!G
M970@<F5Q=65S=&5D(&1E<&5N9&5N8WD@9W)O=7`L(&EF(&%N>0T*("`@("`@
M("`@("`@)&=R;W5P;F%M92`]("1T:&ES+3YG971'<F]U<"@I.PT*("`@("`@
M("`@("`@)&5X<&QI8VET(#T@)'1H:7,M/E]E>'!L:6-I=$=R;W5P.PT*("`@
M("`@("`@("`@:68@*"$D9W)O=7!N86UE*2![#0H@("`@("`@("`@("`@("`@
M:68@*"1T:&ES+3YC86Y$969A=6QT*"DI('L-"B`@("`@("`@("`@("`@("`@
M("`@)&=R;W5P;F%M92`]("=D969A=6QT)SL@+R\@=')Y('1H92!D969A=6QT
M(&1E<&5N9&5N8WD@9W)O=7`-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)&=R;W5P;F]T
M9F]U;F0I('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D9&5P<ULG9W)O=7`G72DI
M('L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<'-;)V=R;W5P)UU;
M)V%T=')I8G,G72DI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*'-T<G1O
M;&]W97(H)&1E<'-;)V=R;W5P)UU;)V%T=')I8G,G75LG;F%M92==*2`]/2!S
M=')T;VQO=V5R*"1G<F]U<&YA;64I*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D9W)O=7`@/2`D9&5P<ULG9W)O=7`G73L-"B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E:68@*"1E>'!L:6-I="D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^
M;&]G*#`L("=787)N:6YG.B!P86-K86=E("(G("X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C
M:V%G94YA;654;U-T<FEN9R@D<&YA;64L('1R=64I("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)R(@:&%S(&YO(&1E<&5N9&5N8WD@)R`N
M("=G<F]U<"!N86UE9"`B)R`N("1G<F]U<&YA;64@+B`G(B<I.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M)&=R;W5P;F]T9F]U;F0@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D9F]U;F0@
M/2!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&1E<'-;
M)V=R;W5P)UT@87,@)&=R;W5P*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H<W1R=&]L;W=E<B@D9W)O=7!;)V%T=')I8G,G75LG;F%M92==*2`]
M/2!S=')T;VQO=V5R*"1G<F]U<&YA;64I*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&9O=6YD(#T@=')U93L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I
M9B`H(21F;W5N9"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1E
M>'!L:6-I="D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YL;V<H,"P@)U=A
M<FYI;F<Z('!A8VMA9V4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA
M;654;U-T<FEN9R@D<&YA;64L('1R=64I("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("<B(&AA<R!N;R!D97!E;F1E;F-Y("<@+B`G
M9W)O=7`@;F%M960@(B<@+B`D9W)O=7!N86UE("X@)R(G*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`D9W)O=7!N;W1F;W5N9"`]
M('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D9W)O=7`I*2![#0H@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1G<F]U<%LD<&%C:V%G971Y<&5=
M*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&=R;W5P6R1P
M86-K86=E='EP95U;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!F
M;W)E86-H("@D9W)O=7!;)'!A8VMA9V5T>7!E72!A<R`D9&5P*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)')E="`]("1T:&ES+3Y?9&5T96-T
M,D1E<"@D9&5P+"`D<&YA;64L("=D97!E;F1E;F-Y(&=R;W5P("(G("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&=R;W5P6R=A='1R:6)S
M)UU;)VYA;64G72`N("<B)RP@)'!A<F%M<RD[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1R970I*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&]W;FQO861$97!S6UT@
M/2`D<F5T.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R970@/2`D=&AI<RT^
M7V1E=&5C=#)$97`H)&=R;W5P6R1P86-K86=E='EP95TL("1P;F%M92P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5P96YD96YC>2!G<F]U<"`B
M)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&=R;W5P6R=A='1R
M:6)S)UU;)VYA;64G72`N("<B)RP@)'!A<F%M<RD[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-?87)R87DH)')E="DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D1&5P<UM=(#T@)')E
M=#L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T:6]N(%]D971E8W0R1&5P*"1D
M97`L("1P;F%M92P@)&=R;W5P+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@
M:68@*&ES<V5T*"1D97!;)V-O;F9L:6-T<R==*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@)&]P=&EO;G,@/2`D
M=&AI<RT^7V1O=VYL;V%D97(M/F=E=$]P=&EO;G,H*3L-"B`@("`@("`@:68@
M*&ES<V5T*"1D97!;)W5R:2==*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&%R
M<F%Y*"=U<FDG(#T^("1D97!;)W5R:2==+"`G9&5P)R`]/B`D9&5P*3L[#0H@
M("`@("`@('T-"B`@("`@("`@)'1E<W1D97`@/2`D9&5P.PT*("`@("`@("`D
M=&5S=&1E<%LG<&%C:V%G92==(#T@)&1E<%LG;F%M92==.PT*("`@("`@("!I
M9B`H4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4Z.G=I;&Q$;W=N;&]A9"@D=&5S
M=&1E<"P@)'!A<F%M<RDI('L-"B`@("`@("`@("`@("1D97!;)W!A8VMA9V4G
M72`]("1D97!;)VYA;64G73L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&]P
M=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V1O
M=VYL;V%D97(M/FQO9R@R+"`D=&AI<RT^9V5T4VAO<G1.86UE*"D@+B`G.B!3
M:VEP<&EN9R`G("X@)&=R;W5P("X-"B`@("`@("`@("`@("`@("`@("`@)R!D
M97!E;F1E;F-Y("(G("X-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R
M96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@D9&5P+"!T<G5E
M*2`N#0H@("`@("`@("`@("`@("`@("`@("<B+"!W:6QL(&)E(&EN<W1A;&QE
M9"<I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("!]#0H@("`@("`@("1O<'1I;VYS(#T@)'1H:7,M/E]D;W=N
M;&]A9&5R+3YG971/<'1I;VYS*"D[#0H@("`@("`@(%!%05(Z.G!U<VA%<G)O
M<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@:68@*"1T
M:&ES+3Y?97AP;&EC:713=&%T92D@>PT*("`@("`@("`@("`@)'!N86UE6R=S
M=&%T92==(#T@)'1H:7,M/E]E>'!L:6-I=%-T871E.PT*("`@("`@("!]#0H@
M("`@("`@("1U<FP@/0T*("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R
M+3Y?9V5T1&5P4&%C:V%G941O=VYL;V%D57)L*"1D97`L("1P;F%M92D[#0H@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1U<FPI*2![#0H@("`@("`@("`@
M("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("!R971U
M<FX@)'5R;#L-"B`@("`@("`@?0T*("`@("`@("`D9&5P6R=P86-K86=E)UT@
M/2`D9&5P6R=N86UE)UT[#0H@("`@("`@("1R970@/2`D=&AI<RT^7V%N86QY
M>F5$;W=N;&]A9%523"@D=7)L+"`G9&5P96YD96YC>2<L("1D97`L("1P87)A
M;7,L("1G<F]U<"`]/2`G;W!T:6]N86PG("8F#0H@("`@("`@("`@("`A:7-S
M970H)&]P=&EO;G-;)V%L;&1E<',G72DI.PT*("`@("`@("!014%2.CIP;W!%
M<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R
M970I*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T
M)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YL
M;V<H,"P@)')E="T^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("\O(&-H96-K('1O('-E92!I9B!A(&1E<"!I<R!A;')E861Y
M(&EN<W1A;&QE9"!A;F0@:7,@=&AE('-A;64@;W(@;F5W97(-"B`@("`@("`@
M("`@(&EF("@A:7-S970H)&1E<%LG;6EN)UTI("8F("%I<W-E="@D9&5P6R=M
M87@G72D@)B8@(6ES<V5T*"1D97!;)W)E8V]M;65N9&5D)UTI*2![#0H@("`@
M("`@("`@("`@("`@)&]P97(@/2`G:&%S)SL-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@)&]P97(@/2`G9W0G.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@+R\@9&\@;F]T('1R>2!T;R!M;W9E('1H:7,@
M8F5F;W)E(&=E=$1E<%!A8VMA9V5$;W=N;&]A9%523`T*("`@("`@("`@("`@
M+R\@=V4@8V%N)W0@9&5T97)M:6YE('=H971H97(@=7!G<F%D92!I<R!N96-E
M<W-A<GD@=6YT:6P@=V4@:VYO=R!W:&%T#0H@("`@("`@("`@("`O+R!V97)S
M:6]N('=O=6QD(&)E(&1O=VYL;V%D960-"B`@("`@("`@("`@(&EF("@A:7-S
M970H)&]P=&EO;G-;)V9O<F-E)UTI("8F("1T:&ES+3YI<TEN<W1A;&QE9"@D
M<F5T+"`D;W!E<BDI('L-"B`@("`@("`@("`@("`@("`D=F5R<VEO;B`]("1T
M:&ES+3Y?:6YS=&%L;%)E9VES=')Y+3YP86-K86=E26YF;R@D9&5P6R=N86UE
M)UTL("=V97)S:6]N)RP-"B`@("`@("`@("`@("`@("`@("`@)&1E<%LG8VAA
M;FYE;"==*3L-"B`@("`@("`@("`@("`@("`D9&5P6R=P86-K86=E)UT@/2`D
M9&5P6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T
M:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V1O=VYL;V%D97(M/FQO9R@S+"`D=&AI<RT^9V5T4VAO<G1.86UE*"D@+B`G
M.B!3:VEP<&EN9R`G("X@)&=R;W5P("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("<@9&5P96YD96YC>2`B)R`N#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H)&1E
M<"P@=')U92D@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)R(@=F5R<VEO
M;B`G("X@)'5R;%LG=F5R<VEO;B==("X@)RP@86QR96%D>2!I;G-T86QL960@
M87,@=F5R<VEO;B`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("1V97)S
M:6]N*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(&EF("AI<W-E="@D9&5P6R=N;V1E9F%U;'0G72DI('L-"B`@("`@("`@("`@
M("1R971;)VYO9&5F875L="==(#T@=')U93L-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?9&5T96-T
M,2@D9&5P<RP@)'!N86UE+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@
M("`@("`@("1T:&ES+3Y?9&]W;FQO861$97!S(#T@87)R87DH*3L-"B`@("`@
M("`@)'-K:7!N86UE<R`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1D
M97!S(&%S("1D97`I('L-"B`@("`@("`@("`@("1N;V1O=VYL;V%D(#T@9F%L
M<V4[#0H@("`@("`@("`@("!I9B`H)&1E<%LG='EP92==(#T]("=P:V<G*2![
M#0H@("`@("`@("`@("`@("`@)&1E<%LG8VAA;FYE;"==(#T@)W!E87(N<&AP
M+FYE="<[#0H@("`@("`@("`@("`@("`@)&1E<%LG<&%C:V%G92==(#T@)&1E
M<%LG;F%M92==.PT*("`@("`@("`@("`@("`@('-W:71C:"`H)&1E<%LG<F5L
M)UTI('L-"B`@("`@("`@("`@("`@("`@("`@8V%S92`G;F]T)R`Z#0H@("`@
M("`@("`@("`@("`@("`@("`@("!C;VYT:6YU92`R.PT*("`@("`@("`@("`@
M("`@("`@("!C87-E("=G92<@.@T*("`@("`@("`@("`@("`@("`@("!C87-E
M("=E<2<@.@T*("`@("`@("`@("`@("`@("`@("!C87-E("=G="<@.@T*("`@
M("`@("`@("`@("`@("`@("!C87-E("=H87,G(#H-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1G<F]U<"`]("@A:7-S970H)&1E<%LG;W!T:6]N86PG72D@
M?'P@)&1E<%LG;W!T:6]N86PG72`]/2`G;F\G*2`_#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W)E<75I<F5D)R`Z#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V]P=&EO;F%L)SL-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("A014%27T1O=VYL;V%D97)?4&%C:V%G93HZ=VEL;$1O=VYL;V%D
M*"1D97`L("1P87)A;7,I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YL;V<H,BP@)'1H:7,M/F=E=%-H;W)T
M3F%M92@I("X@)SH@4VMI<'!I;F<@)R`N("1G<F]U<`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`N("<@9&5P96YD96YC>2`B)R`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GDM
M/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H)&1E<"P@=')U92D@+@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G(BP@=VEL;"!B92!I;G-T
M86QL960G*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M92`R.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@)&9A:V5D<"`](&YE=R!014%27U!A8VMA9V5&:6QE7W8Q
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&9A:V5D<"T^<V5T4&%C:V%G
M92@D9&5P6R=N86UE)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M<VMI<"!I;G1E<FYE="!C:&5C:R!I9B!W92!A<F4@;F]T('5P9W)A9&EN9R`H
M8G5G(",U.#$P*0T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D;W!T:6]N<ULG=7!G<F%D92==*2`F)B`D=&AI<RT^:7-);G-T86QL960H
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F%K961P+"`D9&5P
M6R=R96PG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V1O=VYL;V%D97(M/FQO9R@R+"`D=&AI<RT^9V5T4VAO<G1.86UE*"D@
M+B`G.B!3:VEP<&EN9R`G("X@)&=R;W5P#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("X@)R!D97!E;F1E;F-Y("(G("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D
M4&%C:V%G94YA;654;U-T<FEN9R@D9&5P+"!T<G5E*2`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("<B+"!I<R!A;')E861Y(&EN<W1A;&QE
M9"<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E(#([
M#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG*%!%
M05)?15)23U)?4D5455).*3L-"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M
M/E]E>'!L:6-I=%-T871E*2![#0H@("`@("`@("`@("`@("`@("`@("1P;F%M
M95LG<W1A=&4G72`]("1T:&ES+3Y?97AP;&EC:713=&%T93L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'5R;"`]#0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^7V=E=$1E<%!A8VMA9V5$
M;W=N;&]A9%5R;"@D9&5P+"`D<&YA;64I.PT*("`@("`@("`@("`@("`@("1C
M:&%N(#T@)W!E87(N<&AP+FYE="<[#0H@("`@("`@("`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)'5R;"DI('L-"B`@("`@("`@("`@("`@("`@("`@+R\@
M8VAE8VL@=&\@<V5E(&EF('1H:7,@:7,@82!P96-L('!A8VMA9V4@=&AA="!H
M87,@:G5M<&5D#0H@("`@("`@("`@("`@("`@("`@("\O(&9R;VT@<&5A<BYP
M:'`N;F5T('1O('!E8VPN<&AP+FYE="!C:&%N;F5L#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T1E<&5N9&5N8WDR)RDI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!
M4B]$97!E;F1E;F-Y,BYP:'`G.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("1N97=D97`@/2!014%27T1E<&5N9&5N8WDR
M.CIN;W)M86QI>F5$97`H)&1E<"D[#0H@("`@("`@("`@("`@("`@("`@("1N
M97=D97`@/2`D;F5W9&5P6S!=.PT*("`@("`@("`@("`@("`@("`@("`D;F5W
M9&5P6R=C:&%N;F5L)UT@/2`G<&5C;"YP:'`N;F5T)SL-"B`@("`@("`@("`@
M("`@("`@("`@)&-H86X@/2`G<&5C;"YP:'`N;F5T)SL-"B`@("`@("`@("`@
M("`@("`@("`@)'5R;"`]#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V1O=VYL;V%D97(M/E]G971$97!086-K86=E1&]W;FQO8615<FPH)&YE
M=V1E<"P@)'!N86UE*3L-"B`@("`@("`@("`@("`@("`@("`@)&]B:B`]("8D
M=&AI<RT^7VEN<W1A;&Q296=I<W1R>2T^9V5T4&%C:V%G92@D9&5P6R=N86UE
M)UTI.PT*("`@("`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M=7)L*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@4$5!4CHZ<&]P17)R
M;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1O
M8FH@(3T](&YU;&P@)B8@)'1H:7,M/FES26YS=&%L;&5D*"1O8FHL("1D97!;
M)W)E;"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1G<F]U
M<"`]("@A:7-S970H)&1E<%LG;W!T:6]N86PG72D@?'P@)&1E<%LG;W!T:6]N
M86PG72`]/2`G;F\G*2`_#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=R97%U:7)E9"<@.@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G;W!T:6]N86PG.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D97!;)W!A8VMA9V4G72`]("1D97!;)VYA;64G73L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9&]W;FQO861E<BT^;&]G*#,L("1T:&ES+3YG9713:&]R=$YA;64H*2`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G.B!3:VEP<&EN
M9R`G("X@)&=R;W5P("X@)R!D97!E;F1E;F-Y("(G("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GDM/G!A
M<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H)&1E<"P@=')U92D@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(L(&%L<F5A9'D@:6YS
M=&%L;&5D(&%S('9E<G-I;VX@)R`N("1O8FHM/F=E=%9E<G-I;VXH*2D[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("A`)'-K:7!N86UE<UMC;W5N="@D<VMI<&YA;65S
M*2`M(#%=(#T]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@D
M9&5P+"!T<G5E*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>5]P;W`H)'-K:7!N86UE<RD[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG;W!T:6]N
M86PG72D@)B8@)&1E<%LG;W!T:6]N86PG72`]/2`G>65S)RD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(M
M/FQO9R@R+"`D=&AI<RT^9V5T4VAO<G1.86UE*"D@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)SH@4VMI<'!I;F<@)R`N("1G<F]U
M<`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G(&1E
M<&5N9&5N8WD@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA;654;U-T
M<FEN9R@D9&5P+"!T<G5E*2`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G(BP@;F\@<F5L96%S97,@97AI<W0G*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1U<FP[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=A;&QD97!S)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=O<'1I;VYA;"==
M*2`F)B`D9&5P6R=O<'1I;VYA;"==(#T]("=Y97,G*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A
M9&5R+3YL;V<H,RP@)TYO=&EC93H@<&%C:V%G92`B)R`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YG9713:&]R=$YA;64H*2`N
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<B(&]P=&EO;F%L
M(&1E<&5N9&5N8WD@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R
M:6YG*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)V-H86YN96PG(#T^("1C:&%N+"`G<&%C:V%G92<@/3X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!;)VYA;64G72DL('1R
M=64I("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(@=VEL
M;"!N;W0@8F4@875T;VUA=&EC86QL>2!D;W=N;&]A9&5D)RD[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M<VMI<&YA;65S6UT@/2`D=&AI<RT^7W)E9VES=')Y+3YP87)S961086-K86=E
M3F%M951O4W1R:6YG*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@G8VAA;FYE;"<@/3X@)&-H86XL("=P86-K86=E)R`]/@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P6R=N86UE)UTI+"!T
M<G5E*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1N;V1O=VYL;V%D(#T@
M=')U93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=A;&QD
M97!S)UTI("8F("%I<W-E="@D;W!T:6]N<ULG;VYL>7)E<61E<',G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P6R=O<'1I;VYA
M;"==*2!\?"`D9&5P6R=O<'1I;VYA;"==(#T]("=N;R<I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1O=VYL
M;V%D97(M/FQO9R@S+"`G3F]T:6-E.B!P86-K86=E("(G("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E=%-H;W)T3F%M92@I
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(@<F5Q=6ER
M960@9&5P96YD96YC>2`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3
M=')I;F<H#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G8VAA;FYE;"<@/3X@)&-H86XL("=P86-K86=E)R`]/@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<%LG;F%M92==*2P@
M=')U92D@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G(B!W
M:6QL(&YO="!B92!A=71O;6%T:6-A;&QY(&1O=VYL;V%D960G*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1S:VEP;F%M97-;72`]("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA
M9V5.86UE5&]3=')I;F<H#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"=C:&%N;F5L)R`]/B`D8VAA;BP@)W!A8VMA9V4G(#T^#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!;)VYA;64G72DL
M('1R=64I.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&YO9&]W;FQO860@
M/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("\O(&-H96-K('1O('-E92!I9B!A(&1E
M<"!I<R!A;')E861Y(&EN<W1A;&QE9`T*("`@("`@("`@("`@("`@("\O(&1O
M(&YO="!T<GD@=&\@;6]V92!T:&ES(&)E9F]R92!G971$97!086-K86=E1&]W
M;FQO86154DP-"B`@("`@("`@("`@("`@("`O+R!W92!C86XG="!D971E<FUI
M;F4@=VAE=&AE<B!U<&=R861E(&ES(&YE8V5S<V%R>2!U;G1I;"!W92!K;F]W
M('=H870-"B`@("`@("`@("`@("`@("`O+R!V97)S:6]N('=O=6QD(&)E(&1O
M=VYL;V%D960-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS
M6R=F;W)C92==*2`F)B`D=&AI<RT^:7-);G-T86QL960H#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D=7)L+"`D9&5P6R=R96PG72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@)&=R;W5P(#T@*"%I<W-E="@D9&5P6R=O<'1I;VYA;"==
M*2!\?"`D9&5P6R=O<'1I;VYA;"==(#T]("=N;R<I(#\-"B`@("`@("`@("`@
M("`@("`@("`@("`@("=R97%U:7)E9"<@.@T*("`@("`@("`@("`@("`@("`@
M("`@("`@)V]P=&EO;F%L)SL-"B`@("`@("`@("`@("`@("`@("`@)&1E<%LG
M<&%C:V%G92==(#T@)&1E<%LG;F%M92==.PT*("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&YE=V1E<"DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1V97)S:6]N(#T@)'1H:7,M/E]I;G-T86QL4F5G:7-T<GDM/G!A8VMA
M9V5);F9O*"1N97=D97!;)VYA;64G72P@)W9E<G-I;VXG+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1N97=D97!;)V-H86YN96PG72D[#0H@("`@
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D=F5R<VEO;B`]("1T:&ES+3Y?:6YS=&%L;%)E9VES=')Y+3YP86-K
M86=E26YF;R@D9&5P6R=N86UE)UTL("=V97)S:6]N)RD[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)&1E<%LG=F5R<VEO
M;B==(#T@)'5R;%LG=F5R<VEO;B==.PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(M/FQO9R@S+"`D=&AI<RT^
M9V5T4VAO<G1.86UE*"D@+B`G.B!3:VEP<&EN9R`G("X@)&=R;W5P("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G(&1E<&5N9&5N8WD@(B<@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GDM
M/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H)&1E<"P@=')U92D@+@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("<B+"!A;')E861Y(&EN<W1A;&QE
M9"!A<R!V97)S:6]N("<@+B`D=F5R<VEO;BD[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*$`D<VMI<&YA;65S6V-O
M=6YT*"1S:VEP;F%M97,I("T@,5T@/3T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA;654;U-T
M<FEN9R@D9&5P+"!T<G5E*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87E?<&]P*"1S:VEP;F%M97,I.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!I9B`H)&YO9&]W;FQO860I('L-"B`@
M("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG*%!%
M05)?15)23U)?4D5455).*3L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)&YE=V1E<"DI('L-"B`@("`@("`@("`@("`@("`@("`@)&1E<"`]("1N97=D
M97`[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1D97!;
M)W!A8VMA9V4G72`]("1D97!;)VYA;64G73L-"B`@("`@("`@("`@("`@("`D
M<F5T(#T@)'1H:7,M/E]A;F%L>7IE1&]W;FQO86154DPH)'5R;"P@)V1E<&5N
M9&5N8WDG+"`D9&5P+"`D<&%R86US+`T*("`@("`@("`@("`@("`@("`@("!I
M<W-E="@D9&5P6R=O<'1I;VYA;"==*2`F)B`D9&5P6R=O<'1I;VYA;"==(#T]
M("=Y97,G("8F#0H@("`@("`@("`@("`@("`@("`@("%I<W-E="@D;W!T:6]N
M<ULG86QL9&5P<R==*2D[#0H@("`@("`@("`@("`@("`@4$5!4CHZ<&]P17)R
M;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1R970I*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G*#`L("1R970M/F=E=$UE<W-A9V4H
M*2D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9&]W;FQO861$97!S6UT@/2`D<F5T.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AC;W5N="@D<VMI<&YA;65S
M*2D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==
M*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G
M*#$L("=$:60@;F]T(&1O=VYL;V%D(&1E<&5N9&5N8VEE<SH@)R`N#0H@("`@
M("`@("`@("`@("`@("`@(&EM<&QO9&4H)RP@)RP@)'-K:7!N86UE<RD@+@T*
M("`@("`@("`@("`@("`@("`@("`G+"!U<V4@+2UA;&QD97!S(&]R("TM;VYL
M>7)E<61E<',@=&\@9&]W;FQO860@875T;VUA=&EC86QL>2<I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T
M1&]W;FQO86154DPH)'!K9RD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?9&]W
M;FQO86154DP@/2`D<&MG.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%-E
M="!T:&4@<&%C:V%G92YX;6P@;V)J96-T(&9O<B!T:&ES(&1O=VYL;V%D960@
M<&%C:V%G90T*("`@("`J#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I
M;&5?=C%\4$5!4E]086-K86=E1FEL95]V,B`D<&MG#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@<V5T4&%C:V%G949I;&4H)B1P:V<I#0H@("`@>PT*("`@("`@
M("`D=&AI<RT^7W!A8VMA9V5F:6QE(#T@)B1P:V<[#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@9V5T4VAO<G1.86UE*"D-"B`@("![#0H@("`@("`@(')E='5R
M;B`D=&AI<RT^7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG
M*&%R<F%Y*"=C:&%N;F5L)R`]/B`D=&AI<RT^9V5T0VAA;FYE;"@I+`T*("`@
M("`@("`@("`@)W!A8VMA9V4G(#T^("1T:&ES+3YG971086-K86=E*"DI+"!T
M<G5E*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971087)S961086-K86=E
M*"D-"B`@("![("`@#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA
M9V5F:6QE*2!\?"!I<W-E="@D=&AI<RT^7W!A<G-E9&YA;64I*2![#0H@("`@
M("`@("`@("!R971U<FX@87)R87DH)V-H86YN96PG(#T^("1T:&ES+3YG971#
M:&%N;F5L*"DL#0H@("`@("`@("`@("`@("`@)W!A8VMA9V4G(#T^("1T:&ES
M+3YG971086-K86=E*"DL#0H@("`@("`@("`@("`@("`@)W9E<G-I;VXG(#T^
M("1T:&ES+3YG971697)S:6]N*"DI.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971$;W=N;&]A
M9%523"@I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/E]D;W=N;&]A
M9%523#L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!C86Y$969A=6QT*"D-"B`@
M("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V1O=VYL;V%D55),*2D@
M>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?9&]W;FQO86154DQ;
M)VYO9&5F875L="==*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M=')U93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971086-K86=E*"D-"B`@
M("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5F:6QE*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E
M=%!A8VMA9V4H*3L-"B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3Y?
M9&]W;FQO86154DQ;)VEN9F\G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7V1O=VYL;V%D55),6R=I;F9O)UTM/F=E=%!A8VMA9V4H*3L-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!014%2
M7U!A8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!I<U-U8G!A8VMA9V4H)B1P9BD-"B`@("![#0H@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5F:6QE*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G969I;&4M/FES4W5B<&%C:V%G
M92@D<&8I.PT*("`@("`@("!](&5L<V5I9B`H:7-S970H)'1H:7,M/E]D;W=N
M;&]A9%523%LG:6YF;R==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?9&]W;FQO86154DQ;)VEN9F\G72T^:7-3=6)P86-K86=E*"1P9BD[#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("`@('T-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971086-K86=E5'EP
M92@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E
M9FEL92DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5F
M:6QE+3YG971086-K86=E5'EP92@I.PT*("`@("`@("!](&5L<V5I9B`H:7-S
M970H)'1H:7,M/E]D;W=N;&]A9%523%LG:6YF;R==*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?9&]W;FQO86154DQ;)VEN9F\G72T^9V5T4&%C
M:V%G951Y<&4H*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T:6]N
M(&ES0G5N9&QE*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7W!A8VMA9V5F:6QE*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<&%C:V%G969I;&4M/F=E=%!A8VMA9V54>7!E*"D@/3T@)V)U;F1L92<[#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("`@('T-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971086-K86=E6&UL
M5F5R<VEO;B@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P
M86-K86=E9FEL92DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A
M8VMA9V5F:6QE+3YG971086-K86=E>&UL5F5R<VEO;B@I.PT*("`@("`@("!]
M(&5L<V5I9B`H:7-S970H)'1H:7,M/E]D;W=N;&]A9%523%LG:6YF;R==*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&]W;FQO86154DQ;)VEN
M9F\G72T^9V5T4&%C:V%G97AM;%9E<G-I;VXH*3L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@(')E='5R;B`G,2XP)SL-"B`@("`@("`@?0T*("`@
M('T-"@T*("`@(&9U;F-T:6]N(&=E=$-H86YN96PH*0T*("`@('L-"B`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G969I;&4I*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E9FEL92T^9V5T0VAA;FYE;"@I
M.PT*("`@("`@("!](&5L<V5I9B`H:7-S970H)'1H:7,M/E]D;W=N;&]A9%52
M3%LG:6YF;R==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&]W
M;FQO86154DQ;)VEN9F\G72T^9V5T0VAA;FYE;"@I.PT*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T55))*"D-"B`@("![#0H@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5F:6QE*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=%5222@I.PT*("`@
M("`@("!](&5L<V5I9B`H:7-S970H)'1H:7,M/E]D;W=N;&]A9%523%LG:6YF
M;R==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&]W;FQO8615
M4DQ;)VEN9F\G72T^9V5T55))*"D[#0H@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!G971697)S:6]N*"D-"B`@("![#0H@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W!A8VMA9V5F:6QE*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=%9E<G-I;VXH*3L-"B`@("`@
M("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3Y?9&]W;FQO86154DQ;)W9E<G-I
M;VXG72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1O=VYL;V%D
M55),6R=V97)S:6]N)UT[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!I<T-O;7!A=&EB;&4H)'!F*0T*("`@('L-"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?<&%C:V%G969I;&4I*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]P86-K86=E9FEL92T^:7-#;VUP871I8FQE*"1P9BD[#0H@
M("`@("`@('T@96QS96EF("AI<W-E="@D=&AI<RT^7V1O=VYL;V%D55),6R=I
M;F9O)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D;W=N;&]A
M9%523%LG:6YF;R==+3YI<T-O;7!A=&EB;&4H)'!F*3L-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T1W)O=7`H)&=R;W5P*0T*("`@('L-
M"B`@("`@("`@)'1H:7,M/E]P87)S961N86UE6R=G<F]U<"==(#T@)&=R;W5P
M.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$=R;W5P*"D-"B`@("![#0H@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A<G-E9&YA;65;)V=R;W5P)UTI
M*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P87)S961N86UE6R=G
M<F]U<"==.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N
M("<G.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@:7-%>'1E
M;G-I;VXH)&YA;64I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]P86-K86=E9FEL92DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7W!A8VMA9V5F:6QE+3YI<T5X=&5N<VEO;B@D;F%M92D[#0H@("`@("`@('T@
M96QS96EF("AI<W-E="@D=&AI<RT^7V1O=VYL;V%D55),6R=I;F9O)UTI*2![
M#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D;W=N;&]A9%523%LG:6YF
M;R==+3YG9710<F]V:61E<T5X=&5N<VEO;B@I(#T]("1N86UE.PT*("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@
M("!]#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T1&5P<R@I#0H@("`@>PT*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E9FEL92DI('L-"B`@
M("`@("`@("`@(&EF("@D=&AI<RT^7W!A8VMA9V5F:6QE+3YG971086-K86=E
M>&UL5F5R<VEO;B@I(#T]("<R+C`G*2![#0H@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=$1E<',H=')U92D[#0H@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7W!A8VMA9V5F:6QE+3YG971$97!S*"D[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T@96QS96EF("AI<W-E="@D=&AI<RT^7V1O=VYL;V%D55),6R=I
M;F9O)UTI*2![#0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]D;W=N;&]A9%52
M3%LG:6YF;R==+3YG971086-K86=E>&UL5F5R<VEO;B@I(#T]("<R+C`G*2![
M#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&]W;FQO86154DQ;
M)VEN9F\G72T^9V5T1&5P<RAT<G5E*3L-"B`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&]W;FQO86154DQ;
M)VEN9F\G72T^9V5T1&5P<R@I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"D[#0H@("`@("`@
M('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@87)R87D@4&%R
M<V5D(&%R<F%Y(&9R;VT@>T!L:6YK(%!%05)?4F5G:7-T<GDZ.G!A<G-E4&%C
M:V%G94YA;64H*7T@;W(@82!D97!E;F1E;F-Y#0H@("`@("H@("`@("`@("`@
M("`@("`@("`@("!R971U<FYE9"!F<F]M(&=E=$1E<$1O=VYL;V%D55),*"D-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I<T5Q=6%L*"1P87)A;2D-"B`@("![
M#0H@("`@("`@(&EF("AI<U]O8FIE8W0H)'!A<F%M*2D@>PT*("`@("`@("`@
M("`@)&-H86YN96P@/2`D<&%R86TM/F=E=$-H86YN96PH*3L-"B`@("`@("`@
M("`@("1P86-K86=E(#T@)'!A<F%M+3YG971086-K86=E*"D[#0H@("`@("`@
M("`@("!I9B`H)'!A<F%M+3YG97154DDH*2D@>PT*("`@("`@("`@("`@("`@
M("1P87)A;2`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G8VAA;FYE
M;"<@/3X@)'!A<F%M+3YG971#:&%N;F5L*"DL#0H@("`@("`@("`@("`@("`@
M("`@("=P86-K86=E)R`]/B`D<&%R86TM/F=E=%!A8VMA9V4H*2P-"B`@("`@
M("`@("`@("`@("`@("`@)W9E<G-I;VXG(#T^("1P87)A;2T^9V5T5F5R<VEO
M;B@I+`T*("`@("`@("`@("`@("`@("`@("`G=7)I)R`]/B`D<&%R86TM/F=E
M=%5222@I+`T*("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("1P87)A;2`](&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("`@("`G8VAA;FYE;"<@/3X@)'!A<F%M+3YG971#:&%N;F5L
M*"DL#0H@("`@("`@("`@("`@("`@("`@("=P86-K86=E)R`]/B`D<&%R86TM
M/F=E=%!A8VMA9V4H*2P-"B`@("`@("`@("`@("`@("`@("`@)W9E<G-I;VXG
M(#T^("1P87)A;2T^9V5T5F5R<VEO;B@I+`T*("`@("`@("`@("`@("`@("D[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("!I9B`H:7-S970H)'!A<F%M6R=U<FDG72DI('L-"B`@("`@("`@("`@("`@
M("`D<&%R86U;)V-H86YN96PG72`]("=?7W5R:2<[#0H@("`@("`@("`@("`@
M("`@)'!A<F%M6R=P86-K86=E)UT@/2`D<&%R86U;)V1E<"==6R=N86UE)UT[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<&%C:V%G92`](&ES<V5T
M*"1P87)A;5LG<&%C:V%G92==*2`_("1P87)A;5LG<&%C:V%G92==(#H-"B`@
M("`@("`@("`@("`@("`D<&%R86U;)VEN9F\G72T^9V5T4&%C:V%G92@I.PT*
M("`@("`@("`@("`@)&-H86YN96P@/2!I<W-E="@D<&%R86U;)V-H86YN96PG
M72D@/R`D<&%R86U;)V-H86YN96PG72`Z#0H@("`@("`@("`@("`@("`@)'!A
M<F%M6R=I;F9O)UTM/F=E=$-H86YN96PH*3L-"B`@("`@("`@("`@(&EF("AI
M<W-E="@D<&%R86U;)W)E;"==*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A
M8VQA<W-?97AI<W1S*"=014%27T1E<&5N9&5N8WDR)RDI('L-"B`@("`@("`@
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T1E<&5N9&5N8WDR+G!H
M<"<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1N97=D
M97`@/2!014%27T1E<&5N9&5N8WDR.CIN;W)M86QI>F5$97`H)'!A<F%M*3L-
M"B`@("`@("`@("`@("`@("`D;F5W9&5P(#T@)&YE=V1E<%LP73L-"B`@("`@
M("`@("`@('T@96QS96EF("AI<W-E="@D<&%R86U;)VUI;B==*2D@>PT*("`@
M("`@("`@("`@("`@("1N97=D97`@/2`D<&%R86T[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1N97=D97`I*2![#0H@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1N97=D97!;)VUI;B==*2D@>PT*("`@
M("`@("`@("`@("`@("1N97=D97!;)VUI;B==(#T@)S`G.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@:68@*"%I<W-E="@D;F5W9&5P6R=M87@G72DI
M('L-"B`@("`@("`@("`@("`@("`D;F5W9&5P6R=M87@G72`]("<Q,#`P,#`P
M,#`P,#`P,#`P,#`P,#`G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M+R\@=7-E(&UA9VEC('1O('-U<'!O<G0@<&5C;"!P86-K86=E<R!S=61D96YL
M>2!J=6UP:6YG('1O('1H92!P96-L(&-H86YN96P-"B`@("`@("`@("`@("\O
M('=E(&YE960@=&\@<W5P<&]R="!B;W1H(&1E<&5N9&5N8WD@<&]S<VEB:6QI
M=&EE<PT*("`@("`@("`@("`@:68@*"1C:&%N;F5L(#T]("=P96%R+G!H<"YN
M970G("8F("1T:&ES+3YG971#:&%N;F5L*"D@/3T@)W!E8VPN<&AP+FYE="<I
M('L-"B`@("`@("`@("`@("`@("!I9B`H)'!A8VMA9V4@/3T@)'1H:7,M/F=E
M=%!A8VMA9V4H*2D@>PT*("`@("`@("`@("`@("`@("`@("`D8VAA;FYE;"`]
M("=P96-L+G!H<"YN970G.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&EF("@D8VAA;FYE;"`]/2`G<&5C;"YP:'`N
M;F5T)R`F)B`D=&AI<RT^9V5T0VAA;FYE;"@I(#T]("=P96%R+G!H<"YN970G
M*2![#0H@("`@("`@("`@("`@("`@:68@*"1P86-K86=E(#T]("1T:&ES+3YG
M971086-K86=E*"DI('L-"B`@("`@("`@("`@("`@("`@("`@)&-H86YN96P@
M/2`G<&5A<BYP:'`N;F5T)SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!R971U<FX@*'-T<G1O;&]W97(H)'!A8VMA
M9V4I(#T]('-T<G1O;&]W97(H)'1H:7,M/F=E=%!A8VMA9V4H*2D@)B8-"B`@
M("`@("`@("`@("`@("`D8VAA;FYE;"`]/2`D=&AI<RT^9V5T0VAA;FYE;"@I
M("8F#0H@("`@("`@("`@("`@("`@=F5R<VEO;E]C;VUP87)E*"1N97=D97!;
M)VUI;B==+"`D=&AI<RT^9V5T5F5R<VEO;B@I+"`G/#TG*2`F)@T*("`@("`@
M("`@("`@("`@('9E<G-I;VY?8V]M<&%R92@D;F5W9&5P6R=M87@G72P@)'1H
M:7,M/F=E=%9E<G-I;VXH*2P@)SX])RDI.PT*("`@("`@("!]#0H@("`@("`@
M("\O('5S92!M86=I8R!T;R!S=7!P;W)T('!E8VP@<&%C:V%G97,@<W5D9&5N
M;'D@:G5M<&EN9R!T;R!T:&4@<&5C;"!C:&%N;F5L#0H@("`@("`@(&EF("@D
M8VAA;FYE;"`]/2`G<&5C;"YP:'`N;F5T)R`F)B`D=&AI<RT^9V5T0VAA;FYE
M;"@I(#T]("=P96%R+G!H<"YN970G*2![#0H@("`@("`@("`@("!I9B`H<W1R
M=&]L;W=E<B@D<&%C:V%G92D@/3T@<W1R=&]L;W=E<B@D=&AI<RT^9V5T4&%C
M:V%G92@I*2D@>PT*("`@("`@("`@("`@("`@("1C:&%N;F5L(#T@)W!E87(N
M<&AP+FYE="<[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES<V5T*"1P87)A;5LG=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("AS=')T;VQO=V5R*"1P86-K86=E*2`]/2!S=')T;VQO=V5R*"1T
M:&ES+3YG971086-K86=E*"DI("8F#0H@("`@("`@("`@("`@("`@)&-H86YN
M96P@/3T@)'1H:7,M/F=E=$-H86YN96PH*2`F)@T*("`@("`@("`@("`@("`@
M("1P87)A;5LG=F5R<VEO;B==(#T]("1T:&ES+3YG971697)S:6]N*"DI.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N('-T<G1O;&]W
M97(H)'!A8VMA9V4I(#T]('-T<G1O;&]W97(H)'1H:7,M/F=E=%!A8VMA9V4H
M*2D@)B8-"B`@("`@("`@("`@("`@("`D8VAA;FYE;"`]/2`D=&AI<RT^9V5T
M0VAA;FYE;"@I.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M:7-);G-T86QL960H)&1E<"P@)&]P97(@/2`G/3TG*0T*("`@('L-"B`@("`@
M("`@:68@*"$D9&5P*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"1O<&5R("$]("=G92<@)B8@)&]P97(@
M(3T@)V=T)R`F)B`D;W!E<B`A/2`G:&%S)R`F)B`D;W!E<B`A/2`G/3TG*2![
M#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&ES7V]B:F5C="@D9&5P*2D@>PT*("`@("`@("`@("`@)'!A8VMA
M9V4@/2`D9&5P+3YG971086-K86=E*"D[#0H@("`@("`@("`@("`D8VAA;FYE
M;"`]("1D97`M/F=E=$-H86YN96PH*3L-"B`@("`@("`@("`@(&EF("@D9&5P
M+3YG97154DDH*2D@>PT*("`@("`@("`@("`@("`@("1D97`@/2!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`@("`@)W5R:2<@/3X@)&1E<"T^9V5T55))*"DL
M#0H@("`@("`@("`@("`@("`@("`@("=V97)S:6]N)R`]/B`D9&5P+3YG9716
M97)S:6]N*"DL#0H@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@)&1E<"`](&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("`@("`G=F5R<VEO;B<@/3X@)&1E<"T^9V5T5F5R<VEO;B@I
M+`T*("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG=7)I)UTI
M*2![#0H@("`@("`@("`@("`@("`@)&-H86YN96P@/2`G7U]U<FDG.PT*("`@
M("`@("`@("`@("`@("1P86-K86=E(#T@)&1E<%LG9&5P)UU;)VYA;64G73L-
M"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&-H86YN
M96P@/2`D9&5P6R=I;F9O)UTM/F=E=$-H86YN96PH*3L-"B`@("`@("`@("`@
M("`@("`D<&%C:V%G92`]("1D97!;)VEN9F\G72T^9V5T4&%C:V%G92@I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1O<'1I;VYS(#T@
M)'1H:7,M/E]D;W=N;&]A9&5R+3YG971/<'1I;VYS*"D[#0H@("`@("`@("1T
M97-T(#T@)'1H:7,M/E]I;G-T86QL4F5G:7-T<GDM/G!A8VMA9V5%>&ES=',H
M)'!A8VMA9V4L("1C:&%N;F5L*3L-"B`@("`@("`@:68@*"$D=&5S="`F)B`D
M8VAA;FYE;"`]/2`G<&5C;"YP:'`N;F5T)RD@>PT*("`@("`@("`@("`@+R\@
M9&\@;6%G:6,@=&\@86QL;W<@=7!G<F%D:6YG(&9R;VT@;VQD('!E8VP@<&%C
M:V%G97,@=&\@;F5W(&]N97,-"B`@("`@("`@("`@("1T97-T(#T@)'1H:7,M
M/E]I;G-T86QL4F5G:7-T<GDM/G!A8VMA9V5%>&ES=',H)'!A8VMA9V4L("=P
M96%R+G!H<"YN970G*3L-"B`@("`@("`@("`@("1C:&%N;F5L(#T@)W!E87(N
M<&AP+FYE="<[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T97-T*2![#0H@
M("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG=7)I)UTI*2![#0H@("`@("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?:6YS=&%L;%)E9VES=')Y+3YP86-K86=E
M26YF;R@D<&%C:V%G92P@)W5R:2<L("=?7W5R:2<I(#T]("1D97!;)W5R:2==
M*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI
M<W-E="@D;W!T:6]N<ULG=7!G<F%D92==*2D@>PT*("`@("`@("`@("`@("`@
M(&EF("@D;W!E<B`]/2`G:&%S)RD@>PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H=F5R<VEO;E]C;VUP87)E*"1T:&ES+3Y?:6YS=&%L;%)E9VES=')Y+3YP
M86-K86=E26YF;R@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA
M9V4L("=V97)S:6]N)RP@)&-H86YN96PI+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9&5P6R=V97)S:6]N)UTL("<^/2<I*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@(&EF("AV97)S:6]N7V-O
M;7!A<F4H)'1H:7,M/E]I;G-T86QL4F5G:7-T<GDM/G!A8VMA9V5);F9O*`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%C:V%G92P@)W9E<G-I;VXG
M+"`D8VAA;FYE;"DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!;
M)W9E<G-I;VXG72P@)SX])RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@=')U93L-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@0'!A<F%M(&%R<F%Y#0H@("`@("H@0'-T871I8PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N(')E;6]V941U<&QI8V%T97,H)B1P87)A;7,I
M#0H@("`@>PT*("`@("`@("`D<&YA;65S(#T@87)R87DH*3L-"B`@("`@("`@
M9F]R96%C:"`H)'!A<F%M<R!A<R`D:2`]/B`D<&%R86TI('L-"B`@("`@("`@
M("`@(&EF("@A)'!A<F%M*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)'!A<F%M+3YG9710
M86-K86=E*"DI('L-"B`@("`@("`@("`@("`@("`D<&YA;65S6R1I72`]("1P
M87)A;2T^9V5T0VAA;FYE;"@I("X@)R\G("X-"B`@("`@("`@("`@("`@("`@
M("`@)'!A<F%M+3YG971086-K86=E*"D@+B`G+2<@+B`D<&%R86TM/F=E=%9E
M<G-I;VXH*2`N("<C)R`N("1P87)A;2T^9V5T1W)O=7`H*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("`D<&YA;65S(#T@87)R87E?=6YI
M<75E*"1P;F%M97,I.PT*("`@("`@("`D=6YS970@/2!A<G)A>5]D:69F*&%R
M<F%Y7VME>7,H)'!A<F%M<RDL(&%R<F%Y7VME>7,H)'!N86UE<RDI.PT*("`@
M("`@("`D=&5S='`@/2!A<G)A>5]F;&EP*"1P;F%M97,I.PT*("`@("`@("!F
M;W)E86-H("@D<&%R86US(&%S("1I(#T^("1P87)A;2D@>PT*("`@("`@("`@
M("`@:68@*"$D<&%R86TI('L-"B`@("`@("`@("`@("`@("`D=6YS971;72`]
M("1I.PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*"%I<U]A*"1P87)A;2P@)U!%05)?1&]W;FQO
M861E<E]086-K86=E)RDI('L-"B`@("`@("`@("`@("`@("`D=6YS971;72`]
M("1I.PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*"%I<W-E="@D=&5S='!;)'!A<F%M+3YG971#
M:&%N;F5L*"D@+B`G+R<@+B`D<&%R86TM/F=E=%!A8VMA9V4H*2`N("<M)R`N
M#0H@("`@("`@("`@("`@("`@("`D<&%R86TM/F=E=%9E<G-I;VXH*2`N("<C
M)R`N("1P87)A;2T^9V5T1W)O=7`H*5TI*2![#0H@("`@("`@("`@("`@("`@
M)'5N<V5T6UT@/2`D:3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!F;W)E86-H("@D=6YS970@87,@)&DI('L-"B`@("`@("`@("`@('5N
M<V5T*"1P87)A;7-;)&E=*3L-"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@
M87)R87DH*3L-"B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D:2`]/B`D
M<&%R86TI('L-"B`@("`@("`@("`@("1R971;72`]("8D<&%R86US6R1I73L-
M"B`@("`@("`@?0T*("`@("`@("`D<&%R86US(#T@87)R87DH*3L-"B`@("`@
M("`@9F]R96%C:"`H)')E="!A<R`D:2`]/B`D<&%R86TI('L-"B`@("`@("`@
M("`@("1P87)A;7-;72`]("8D<F5T6R1I73L-"B`@("`@("`@?0T*("`@('T-
M"@T*("`@(&9U;F-T:6]N(&5X<&QI8VET4W1A=&4H*0T*("`@('L-"B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?97AP;&EC:713=&%T93L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!S971%>'!L:6-I=%-T871E*"1S*0T*("`@('L-"B`@("`@
M("`@)'1H:7,M/E]E>'!L:6-I=%-T871E(#T@)',[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&UE
M<F=E1&5P96YD96YC:65S*"8D<&%R86US*0T*("`@('L-"B`@("`@("`@)&YE
M=W!A<F%M<R`](&%R<F%Y*"D[#0H@("`@("`@("1B=6YD;&5S(#T@87)R87DH
M*3L-"B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D:2`]/B`D<&%R86TI
M('L-"B`@("`@("`@("`@(&EF("@A)'!A<F%M+3YI<T)U;F1L92@I*2![#0H@
M("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D8G5N9&QE<UM=(#T@)&D[#0H@("`@("`@("`@("`D<&8@/2`F
M)'!A<F%M+3YG971086-K86=E1FEL92@I.PT*("`@("`@("`@("`@)&YE=V1E
M<',@/2!A<G)A>2@I.PT*("`@("`@("`@("`@)&-O;G1E;G1S(#T@)'!F+3YG
M971"=6YD;&5D4&%C:V%G97,H*3L-"B`@("`@("`@("`@(&EF("@A:7-?87)R
M87DH)&-O;G1E;G1S*2D@>PT*("`@("`@("`@("`@("`@("1C;VYT96YT<R`]
M(&%R<F%Y*"1C;VYT96YT<RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!F;W)E86-H("@D8V]N=&5N=',@87,@)&9I;&4I('L-"B`@("`@("`@("`@
M("`@("`D9FEL96-O;G1E;G1S(#T@)'!F+3YG971&:6QE0V]N=&5N=',H)&9I
M;&4I.PT*("`@("`@("`@("`@("`@("1D;"`]("8D<&%R86TM/F=E=$1O=VYL
M;V%D97(H*3L-"B`@("`@("`@("`@("`@("`D;W!T:6]N<R`]("1D;"T^9V5T
M3W!T:6]N<R@I.PT*("`@("`@("`@("`@("`@("1F<"`]($!F;W!E;B@D9&PM
M/F=E=$1O=VYL;V%D1&ER*"D@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)&9I
M;&4L("=W8B<I.PT*("`@("`@("`@("`@("`@(&EF("@A)&9P*2![#0H@("`@
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!F=W)I=&4H)&9P+"`D9FEL96-O;G1E;G1S+"!S
M=')L96XH)&9I;&5C;VYT96YT<RDI.PT*("`@("`@("`@("`@("`@(&9C;&]S
M92@D9G`I.PT*("`@("`@("`@("`@("`@(&EF("@D<R`]("1P87)A;7-;)&E=
M+3YE>'!L:6-I=%-T871E*"DI('L-"B`@("`@("`@("`@("`@("`@("`@)&]B
M:BT^<V5T17AP;&EC:713=&%T92@D<RD[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("1O8FH@/2`F;F5W(%!%05)?1&]W;FQO861E<E]0
M86-K86=E*"1P87)A;7-;)&E=+3YG971$;W=N;&]A9&5R*"DI.PT*("`@("`@
M("`@("`@("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M4D5455).*3L-"B`@("`@("`@("`@("`@("`D92`]("1O8FHM/E]F<F]M1FEL
M92@D82`]("1D;"T^9V5T1&]W;FQO861$:7(H*2`N($1)4D5#5$]265]315!!
M4D%43U(@+B`D9FEL92D[#0H@("`@("`@("`@("`@("`@4$5!4CHZ<&]P17)R
M;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1E*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O
M<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M9&PM/FQO9R@P+"`D92T^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&H@/2`F)&]B:CL-"B`@
M("`@("`@("`@("`@("!I9B`H(5!%05)?1&]W;FQO861E<E]086-K86=E.CIW
M:6QL1&]W;FQO860H)&HL#0H@("`@("`@("`@("`@("`@("`@("`@87)R87E?
M;65R9V4H)'!A<F%M<RP@)&YE=W!A<F%M<RDI("8F("$D<&%R86TM/FES26YS
M=&%L;&5D*"1J*2D@>PT*("`@("`@("`@("`@("`@("`@("`D;F5W<&%R86US
M6UT@/2`F)&H[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1B=6YD;&5S(&%S("1I*2![
M#0H@("`@("`@("`@("!U;G-E="@D<&%R86US6R1I72D[("\O(')E;6]V92!B
M=6YD;&5S("T@;VYL>2!T:&5I<B!C;VYT96YT<R!M871T97(@9F]R(&EN<W1A
M;&QA=&EO;@T*("`@("`@("!]#0H@("`@("`@(%!%05)?1&]W;FQO861E<E]0
M86-K86=E.CIR96UO=F5$=7!L:6-A=&5S*"1P87)A;7,I.R`O+R!S=')I<"!A
M;GD@=6YS970@:6YD:6-E<PT*("`@("`@("!I9B`H8V]U;G0H)&YE=W!A<F%M
M<RDI('L@+R\@861D(&EN(&)U;F1L960@<&%C:V%G97,@9F]R(&EN<W1A;&P-
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1N97=P87)A;7,@87,@)&D@/3X@)'5N
M=7-E9"D@>PT*("`@("`@("`@("`@("`@("1P87)A;7-;72`]("8D;F5W<&%R
M86US6R1I73L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1N97=P87)A
M;7,@/2!A<G)A>2@I.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1P
M87)A;7,@87,@)&D@/3X@)'!A<F%M*2![#0H@("`@("`@("`@("`D;F5W9&5P
M<R`](&%R<F%Y*"D[#0H@("`@("`@("`@("!F;W)E86-H("@D<&%R86TM/E]D
M;W=N;&]A9$1E<',@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@(&EF("@A
M4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4Z.G=I;&Q$;W=N;&]A9"@D9&5P+`T*
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7VUE<F=E*"1P87)A;7,L("1N
M97=P87)A;7,I*2`F)B`A)'!A<F%M+3YI<TEN<W1A;&QE9"@D9&5P*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D;F5W9&5P<UM=(#T@)&1E<#L-"B`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`O+R!D
M971E8W0@=F5R<VEO;FEN9R!C;VYF;&EC=',@:&5R90T*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("\O(&-O;G9E<G0@
M=&AE(&1E<&5N9&5N8VEE<R!I;G1O(%!%05)?1&]W;FQO861E<E]086-K86=E
M(&]B:F5C=',@9F]R('1H92!N97AT('1I;64-"B`@("`@("`@("`@("\O(&%R
M;W5N9`T*("`@("`@("`@("`@)'!A<F%M<ULD:5TM/E]D;W=N;&]A9$1E<',@
M/2!A<G)A>2@I.PT*("`@("`@("`@("`@9F]R96%C:"`H)&YE=V1E<',@87,@
M)&1E<"D@>PT*("`@("`@("`@("`@("`@("1O8FH@/2`F;F5W(%!%05)?1&]W
M;FQO861E<E]086-K86=E*"1P87)A;7-;)&E=+3YG971$;W=N;&]A9&5R*"DI
M.PT*("`@("`@("`@("`@("`@(&EF("@D<R`]("1P87)A;7-;)&E=+3YE>'!L
M:6-I=%-T871E*"DI('L-"B`@("`@("`@("`@("`@("`@("`@)&]B:BT^<V5T
M17AP;&EC:713=&%T92@D<RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M4D5455).*3L-"B`@("`@("`@("`@("`@("`D92`]("1O8FHM/F9R;VU$97!5
M4DPH)&1E<"D[#0H@("`@("`@("`@("`@("`@4$5!4CHZ<&]P17)R;W)(86YD
M;&EN9R@I.PT*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E
M*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS
M6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D;V)J+3Y?
M9&]W;FQO861E<BT^;&]G*#`L("1E+3YG971-97-S86=E*"DI.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D92`]("1O
M8FHM/F1E=&5C=$1E<&5N9&5N8VEE<R@D<&%R86US*3L-"B`@("`@("`@("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92DI('L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&]B:BT^7V1O=VYL;V%D97(M/FQO9R@P+"`D
M92T^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D:B`]("8D;V)J.PT*
M("`@("`@("`@("`@("`@("1N97=P87)A;7-;72`]("8D:CL-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H8V]U;G0H)&YE=W!A<F%M
M<RDI('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1N97=P87)A;7,@87,@)&D@
M/3X@)'5N=7-E9"D@>PT*("`@("`@("`@("`@("`@("1P87)A;7-;72`]("8D
M;F5W<&%R86US6R1I73L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@?0T*#0H-"B`@("`O*BH-"B`@
M("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=VEL;$1O=VYL
M;V%D*"1P87)A;2P@)'!A<F%M<RD-"B`@("![#0H@("`@("`@(&EF("@A:7-?
M87)R87DH)'!A<F%M<RDI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D<&%R86US(&%S("1O8FHI
M('L-"B`@("`@("`@("`@(&EF("@D;V)J+3YI<T5Q=6%L*"1P87)A;2DI('L-
M"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@1F]R('-I;7!L97(@=6YI="UT97-T:6YG#0H@("`@
M("H@0'!A<F%M(%!%05)?0V]N9FEG#0H@("`@("H@0'!A<F%M(&EN=`T*("`@
M("`J($!P87)A;2!S=')I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F9V5T
M4&%C:V%G969I;&5/8FIE8W0H)B1C+"`D9"P@)'0@/2!F86QS92D-"B`@("![
M#0H@("`@("`@("1A(#T@)FYE=R!014%27U!A8VMA9V5&:6QE*"1C+"`D9"P@
M)'0I.PT*("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*#0H-"B`@("`O*BH-
M"B`@("`@*B!4:&ES('=I;&P@<F5T<FEE=F4@9G)O;2!A(&QO8V%L(&9I;&4@
M:68@<&]S<VEB;&4L(&%N9"!P87)S92!O=70-"B`@("`@*B!A(&=R;W5P(&YA
M;64@87,@=V5L;"X@(%1H92!O<FEG:6YA;"!P87)A;65T97(@=VEL;"!B92!M
M;V1I9FEE9"!T;R!R969L96-T('1H:7,N#0H@("`@("H@0'!A<F%M('-T<FEN
M9WQA<G)A>2!C86X@8F4@82!P87)S960@<&%C:V%G92!N86UE(&%S('=E;&P-
M"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!?9G)O;49I;&4H)B1P87)A;2D-"B`@("![#0H@("`@("`@(&EF("AI<U]S
M=')I;F<H)'!A<F%M*2`F)B`A0&ES7V9I;&4H)'!A<F%M*2D@>PT*("`@("`@
M("`@("`@)'1E<W0@/2!E>'!L;V1E*"<C)RP@)'!A<F%M*3L-"B`@("`@("`@
M("`@("1G<F]U<"`](&%R<F%Y7W!O<"@D=&5S="D[#0H@("`@("`@("`@("!I
M9B`H0&ES7V9I;&4H:6UP;&]D92@G(R<L("1T97-T*2DI('L-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^<V5T1W)O=7`H)&=R;W5P*3L-"B`@("`@("`@("`@
M("`@("`D<&%R86T@/2!I;7!L;V1E*"<C)RP@)'1E<W0I.PT*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?97AP;&EC:71'<F]U<"`]('1R=64[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*$!I<U]F:6QE*"1P87)A
M;2DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?='EP92`]("=L;V-A;"<[#0H@
M("`@("`@("`@("`D;W!T:6]N<R`]("1T:&ES+3Y?9&]W;FQO861E<BT^9V5T
M3W!T:6]N<R@I.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=D
M;W=N;&]A9&]N;'DG72DI('L-"B`@("`@("`@("`@("`@("`D<&MG(#T@)B1T
M:&ES+3YG971086-K86=E9FEL94]B:F5C="@D=&AI<RT^7V-O;F9I9RP-"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3Y?9&5B=6<I
M.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D<&MG
M(#T@)B1T:&ES+3YG971086-K86=E9FEL94]B:F5C="@D=&AI<RT^7V-O;F9I
M9RP-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3Y?
M9&5B=6<L("1T:&ES+3Y?9&]W;FQO861E<BT^9V5T1&]W;FQO861$:7(H*2D[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!014%2.CIP=7-H17)R;W)(
M86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("`@("`D<&8@
M/2`F)'!K9RT^9G)O;4%N>49I;&4H)'!A<F%M+"!014%27U9!3$E$051%7TE.
M4U1!3$Q)3D<I.PT*("`@("`@("`@("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN
M9R@I.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'!F*2D@>PT*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:60@/2!F86QS93L-"B`@("`@
M("`@("`@("`@("!R971U<FX@)'!F.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@)'1H:7,M/E]P86-K86=E9FEL92`]("8D<&8[#0H@("`@("`@("`@
M("!I9B`H(21T:&ES+3YG971'<F]U<"@I*2![#0H@("`@("`@("`@("`@("`@
M)'1H:7,M/G-E=$=R;W5P*"=D969A=6QT)RD[("\O(&EN<W1A;&P@=&AE(&1E
M9F%U;'0@9&5P96YD96YC>2!G<F]U<`T*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?=F%L:60@/2!T<G5E.PT*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B`D=&AI<RT^7W9A;&ED(#T@9F%L<V4[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@7V9R;VU5<FPH)'!A<F%M+"`D<V%V97!A<F%M
M(#T@)R<I#0H@("`@>PT*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P87)A;2D@
M)B8-"B`@("`@("`@("`@("`@*'!R96=?;6%T8V@H)R->*&AT='!\9G1P*3HO
M+R,G+"`D<&%R86TI*2D@>PT*("`@("`@("`@("`@)&]P=&EO;G,@/2`D=&AI
M<RT^7V1O=VYL;V%D97(M/F=E=$]P=&EO;G,H*3L-"B`@("`@("`@("`@("1T
M:&ES+3Y?='EP92`]("=U<FPG.PT*("`@("`@("`@("`@)&-A;&QB86-K(#T@
M)'1H:7,M/E]D;W=N;&]A9&5R+3YU:2`_#0H@("`@("`@("`@("`@("`@87)R
M87DH)B1T:&ES+3Y?9&]W;FQO861E<BP@)U]D;W=N;&]A9$-A;&QB86-K)RD@
M.B!N=6QL.PT*("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YP=7-H
M17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("`@
M("`D9FEL92`]("1T:&ES+3Y?9&]W;FQO861E<BT^9&]W;FQO861(='1P*"1P
M87)A;2P@)'1H:7,M/E]D;W=N;&]A9&5R+3YU:2P-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V1O=VYL;V%D97(M/F=E=$1O=VYL;V%D1&ER*"DL("1C86QL
M8F%C:RD[#0H@("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(M/G!O<$5R
M<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1F:6QE*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'-A=F5P
M87)A;2DI('L-"B`@("`@("`@("`@("`@("`@("`@)'-A=F5P87)A;2`]("(L
M(&-A;FYO="!D;W=N;&]A9"!<(B1S879E<&%R86U<(B([#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("1E<G(@/2!014%2.CIR86ES945R
M<F]R*"=#;W5L9"!N;W0@9&]W;FQO860@9G)O;2`B)R`N("1P87)A;2`N#0H@
M("`@("`@("`@("`@("`@("`@("<B)R`N("1S879E<&%R86TI.PT*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)&5R<CL-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("@D=&AI<RT^7W)A=W!A8VMA9V5F:6QE*2![#0H@("`@
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=!<F-H:79E+U1A<BYP:'`G.PT*
M("`@("`@("`@("`@("`@("1T87(@/2`F;F5W($%R8VAI=F5?5&%R*"1F:6QE
M*3L-"B`@("`@("`@("`@("`@("`D<&%C:V%G97AM;"`]("1T87(M/F5X=')A
M8W1);E-T<FEN9R@G<&%C:V%G93(N>&UL)RD[#0H@("`@("`@("`@("`@("`@
M:68@*"$D<&%C:V%G97AM;"D@>PT*("`@("`@("`@("`@("`@("`@("`D<&%C
M:V%G97AM;"`]("1T87(M/F5X=')A8W1);E-T<FEN9R@G<&%C:V%G92YX;6PG
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*'-T
M<E]R97!L86-E*&%R<F%Y*")<;B(L(")<<B(I+"!A<G)A>2@G)RPG)RDL("1P
M86-K86=E>&UL*2`A/0T*("`@("`@("`@("`@("`@("`@("`@('-T<E]R97!L
M86-E*&%R<F%Y*")<;B(L(")<<B(I+"!A<G)A>2@G)RPG)RDL("1T:&ES+3Y?
M<F%W<&%C:V%G969I;&4I*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@D
M=&AI<RT^9V5T0VAA;FYE;"@I(#T]("=P96%R+G!H<"YN970G*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!B92!M;W)E(&QA>"!F;W(@=&AE(&5X
M:7-T:6YG(%!%05(@<&%C:V%G97,@=&AA="!H879E(&YO="UO:PT*("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@8VAA<F%C=&5R<R!I;B!T:&5I<B!P86-K
M86=E+GAM;`T*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N
M;&]A9&5R+3YL;V<H,"P@)T-2251)0T%,(%=!4DY)3D<Z(%1H92`B)R`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E=%!A8VMA9V4H
M*2`N("<B('!A8VMA9V4@:&%S(&EN=F%L:60@8VAA<F%C=&5R<R!I;B!I=',@
M)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!A8VMA9V4N>&UL
M+B`@5&AE(&YE>'0@=F5R<VEO;B!O9B!014%2(&UA>2!N;W0@8F4@86)L92!T
M;R!I;G-T86QL("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T
M:&ES('!A8VMA9V4@9F]R('-E8W5R:71Y(')E87-O;G,N("!0;&5A<V4@;W!E
M;B!A(&)U9R!R97!O<G0@870@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VAT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92\G("X@)'1H:7,M
M/F=E=%!A8VMA9V4H*2`N("<O8G5G<R<I.PT*("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)T-2251)0T%,($524D]2.B!P86-K86=E+GAM;"!D
M;W=N;&]A9&5D(&1O97,@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VYO="!M871C:"!V86QU92!R971U<FYE9"!F<F]M('AM;"UR<&,G*3L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("\O('=H97<L(&1O=VYL;V%D('=O
M<FME9"$-"B`@("`@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG9&]W;FQO
M861O;FQY)UTI*2![#0H@("`@("`@("`@("`@("`@)'!K9R`]("8D=&AI<RT^
M9V5T4&%C:V%G969I;&5/8FIE8W0H)'1H:7,M/E]C;VYF:6<L("1T:&ES+3Y?
M9&]W;FQO861E<BT^9&5B=6<I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`D<&MG(#T@)B1T:&ES+3YG971086-K86=E9FEL94]B
M:F5C="@D=&AI<RT^7V-O;F9I9RP@)'1H:7,M/E]D;W=N;&]A9&5R+3YD96)U
M9RP-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YG
M971$;W=N;&]A9$1I<B@I*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-
M"B`@("`@("`@("`@("1P9B`]("8D<&MG+3YF<F]M06YY1FEL92@D9FEL92P@
M4$5!4E]604Q)1$%415])3E-404Q,24Y'*3L-"B`@("`@("`@("`@(%!%05(Z
M.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1P9BDI('L-"B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH
M)'!F+3YG9715<V5R26YF;R@I*2D@>PT*("`@("`@("`@("`@("`@("`@("!F
M;W)E86-H("@D<&8M/F=E=%5S97));F9O*"D@87,@)&5R<BD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1E<G(I*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&5R<B`]("1E<G);)VUE<W-A9V4G
M73L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(M
M/FQO9R@P+"`B5F%L:61A=&EO;B!%<G)O<CH@)&5R<B(I.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P
M=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]D;W=N;&]A9&5R+3YL;V<H,"P@)'!F+3YG971-97-S86=E*"DI.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D97)R(#T@4$5!4CHZ
M<F%I<V5%<G)O<B@G1&]W;FQO860@;V8@(B<@+B`H)'-A=F5P87)A;2`_("1S
M879E<&%R86T@.@T*("`@("`@("`@("`@("`@("`@("`D<&%R86TI("X@)R(@
M<W5C8V5E9&5D+"!B=70@:70@:7,@;F]T(&$@=F%L:60@<&%C:V%G92!A<F-H
M:79E)RD[#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9"`](&9A;'-E
M.PT*("`@("`@("`@("`@("`@(')E='5R;B`D97)R.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E9FEL92`]("8D<&8[#0H@
M("`@("`@("`@("`D=&AI<RT^<V5T1W)O=7`H)V1E9F%U;'0G*3L@+R\@:6YS
M=&%L;"!T:&4@9&5F875L="!D97!E;F1E;F-Y(&=R;W5P#0H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]V86QI9"`]('1R=64[#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?=F%L:60@/2!F86QS93L-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F=\87)R87D@
M<&%S<R!I;B!A;B!A<G)A>2!O9B!F;W)M870-"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*`T*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("=P86-K86=E)R`]/B`G<&YA;64G+`T*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@6R=C:&%N;F5L)R`]/B`G8VAA;FYA;64G+%T-"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@(%LG=F5R<VEO;B<@/3X@)W9E<G-I;VXG+%T-"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@(%LG<W1A=&4G(#T^("=S=&%T92<L
M72D-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&]R(&$@<W1R:6YG(&]F
M(&9O<FUA="!;8VAA;FYA;64O77!N86UE6RUV97)S:6]N?"US=&%T95T-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!?9G)O;5-T<FEN9R@D<&%R86TI#0H@("`@
M>PT*("`@("`@("`D;W!T:6]N<R`]("1T:&ES+3Y?9&]W;FQO861E<BT^9V5T
M3W!T:6]N<R@I.PT*("`@("`@("!014%2.CIP=7-H17)R;W)(86YD;&EN9RA0
M14%27T524D]27U)%5%523BD[#0H@("`@("`@("1P;F%M92`]("1T:&ES+3Y?
M<F5G:7-T<GDM/G!A<G-E4&%C:V%G94YA;64H)'!A<F%M+`T*("`@("`@("`@
M("`@)'1H:7,M/E]C;VYF:6<M/F=E="@G9&5F875L=%]C:&%N;F5L)RDI.PT*
M("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1P;F%M92DI('L-"B`@("`@("`@("`@(&EF("@D
M<&YA;64M/F=E=$-O9&4H*2`]/2`G:6YV86QI9"<I('L-"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W9A;&ED(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@
M*"1P;F%M92T^9V5T0V]D92@I(#T]("=C:&%N;F5L)RD@>PT*("`@("`@("`@
M("`@("`@("1P87)S960@/2`D<&YA;64M/F=E=%5S97));F9O*"D[#0H@("`@
M("`@("`@("`@("`@:68@*"1T:&ES+3Y?9&]W;FQO861E<BT^9&ES8V]V97(H
M)'!A<G-E9%LG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H)'1H:7,M/E]C;VYF:6<M/F=E="@G875T;U]D:7-C;W9E<B<I*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("!014%2.CIP=7-H17)R;W)(86YD;&EN
M9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D<&YA;64@/2`D=&AI<RT^7W)E9VES=')Y+3YP87)S95!A8VMA9V5.86UE
M*"1P87)A;2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V-O;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*2D[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YL;V<H
M,"P@)T-H86YN96P@(B<@+B`D<&%R<V5D6R=C:&%N;F5L)UT@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G(B!I<R!N;W0@:6YI=&EA;&EZ
M960L('5S92`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)R)P96%R(&-H86YN96PM9&ES8V]V97(@)R`N("1P87)S961;)V-H86YN96PG
M72`N("<B('1O(&EN:71I86QI>F4G("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V]R('!E87(@8V]N9FEG+7-E="!A=71O7V1I<V-O=F5R
M(#$G*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&YA;64I*2![#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G*#`L
M("1P;F%M92T^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)'!A<F%M*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M(#T@)'1H:7,M/E]R
M96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@D<&%R86TI.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1E
M<G(@/2!014%2.CIR86ES945R<F]R*"=I;G9A;&ED('!A8VMA9V4@;F%M92]P
M86-K86=E(&9I;&4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)'!A
M<F%M("X@)R(G*3L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI
M9"`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)&5R<CL-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YL;V<H
M,"P@)'!N86UE+3YG971-97-S86=E*"DI.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`D97)R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G:6YV
M86QI9"!P86-K86=E(&YA;64O<&%C:V%G92!F:6QE("(G("X-"B`@("`@("`@
M("`@("`@("`@("`@)'!A<F%M("X@)R(G*3L-"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7W9A;&ED(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@<F5T=7)N
M("1E<G([#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7W1Y<&4I*2![#0H@("`@("`@("`@("`D=&AI<RT^
M7W1Y<&4@/2`G>&UL<G!C)SL-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^
M7W!A<G-E9&YA;64@/2`D<&YA;64[#0H@("`@("`@(&EF("AI<W-E="@D<&YA
M;65;)W-T871E)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7V5X<&QI8VET
M4W1A=&4@/2`D<&YA;65;)W-T871E)UT[#0H@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`D=&AI<RT^7V5X<&QI8VET4W1A=&4@/2!F86QS93L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'!N86UE6R=G<F]U<"==*2D@
M>PT*("`@("`@("`@("`@)'1H:7,M/E]E>'!L:6-I=$=R;W5P(#T@=')U93L-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T:&ES+3Y?97AP;&EC
M:71'<F]U<"`](&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1I;F9O(#T@
M)'1H:7,M/E]D;W=N;&]A9&5R+3Y?9V5T4&%C:V%G941O=VYL;V%D57)L*"1P
M;F%M92D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1I;F9O*2D@>PT*
M("`@("`@("`@("`@:68@*"1P;F%M95LG8VAA;FYE;"==(#T]("=P96%R+G!H
M<"YN970G*2![#0H@("`@("`@("`@("`@("`@+R\@=')Y('!E8VP-"B`@("`@
M("`@("`@("`@("`D<&YA;65;)V-H86YN96PG72`]("=P96-L+G!H<"YN970G
M.PT*("`@("`@("`@("`@("`@(&EF("@D=&5S="`]("1T:&ES+3Y?9&]W;FQO
M861E<BT^7V=E=%!A8VMA9V5$;W=N;&]A9%5R;"@D<&YA;64I*2![#0H@("`@
M("`@("`@("`@("`@("`@(&EF("@A4$5!4CHZ:7-%<G)O<B@D=&5S="DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O(#T@4$5!4CHZ<F%I<V5%
M<G)O<B@D:6YF;RT^9V5T365S<V%G92@I("X@)R`M('!A8VMA9V4@)R`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R>2T^
M<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@D<&YA;64L('1R=64I("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G(&-A;B!B92!I;G-T86QL960@
M=VET:"`B<&5C;"!I;G-T86QL("<@+B`D<&YA;65;)W!A8VMA9V4G72`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(G*3L-"B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1P
M;F%M95LG8VAA;FYE;"==(#T@)W!E87(N<&AP+FYE="<[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`D<&YA;65;)V-H86YN96PG72`]("=P96%R+G!H<"YN
M970G.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(')E='5R;B`D:6YF;SL-"B`@("`@("`@?0T*("`@("`@("`D=&AI
M<RT^7W)A=W!A8VMA9V5F:6QE(#T@)&EN9F];)W)A=R==.PT*("`@("`@("`D
M<F5T(#T@)'1H:7,M/E]A;F%L>7IE1&]W;FQO86154DPH)&EN9F\L("1P87)A
M;2P@)'!N86UE*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E="DI
M('L-"B`@("`@("`@("`@(')E='5R;B`D<F5T.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("@D<F5T*2![#0H@("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D
M55),(#T@)')E=#L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W9A;&ED
M(#T@*&)O;VPI("1R970[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!`<&%R86T@87)R87D@;W5T<'5T(&]F('!A8VMA9V4N9V5T1&]W
M;FQO86154DP-"B`@("`@*B!`<&%R86T@<W1R:6YG?&%R<F%Y?&]B:F5C="!I
M;F9O<FUA=&EO;B!F;W(@9&5T96-T:6YG('!A8VMA9V5S('1O(&)E(&1O=VYL
M;V%D960L(&%N9`T*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&9O<B!E<G)O<G,-"B`@("`@*B!`<&%R86T@87)R87D@;F%M92!I;F9O<FUA
M=&EO;B!O9B!T:&4@<&%C:V%G90T*("`@("`J($!P87)A;2!A<G)A>7QN=6QL
M('!A8VMA9V5S('1O(&)E(&1O=VYL;V%D960-"B`@("`@*B!`<&%R86T@8F]O
M;"!I<R!T:&ES(&%N(&]P=&EO;F%L(&1E<&5N9&5N8WD_#0H@("`@("H@0&%C
M8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V%N86QY>F5$
M;W=N;&]A9%523"@D:6YF;RP@)'!A<F%M+"`D<&YA;64L("1P87)A;7,@/2!N
M=6QL+"`D;W!T:6]N86P@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@A
M:7-?<W1R:6YG*"1P87)A;2D@)B8@4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4Z
M.G=I;&Q$;W=N;&]A9"@D<&%R86TL("1P87)A;7,I*2![#0H@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D:6YF
M;RD@>PT*("`@("`@("`@("`@:68@*"%I<U]S=')I;F<H)'!A<F%M*2D@>PT*
M("`@("`@("`@("`@("`@("1S879E<&%R86T@/2`B+"!C86YN;W0@9&]W;FQO
M860@7"(D<&%R86U<(B([#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("1S879E<&%R86T@/2`G)SL-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("\O(&YO(')E;&5A<V5S(&5X:7-T#0H@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G3F\@<F5L96%S97,@9F]R('!A8VMA
M9V4@(B<@+@T*("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GDM/G!A
M<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H)'!N86UE+"!T<G5E*2`N("<B(&5X
M:7-T)R`N("1S879E<&%R86TI.PT*("`@("`@("!]#0H@("`@("`@(&EF("AS
M=')T;VQO=V5R*"1I;F9O6R=I;F9O)UTM/F=E=$-H86YN96PH*2D@(3T@<W1R
M=&]L;W=E<B@D<&YA;65;)V-H86YN96PG72DI('L-"B`@("`@("`@("`@("1E
M<G(@/2!F86QS93L-"B`@("`@("`@("`@(&EF("@D<&YA;65;)V-H86YN96PG
M72`]/2`G<&5C;"YP:'`N;F5T)RD@>PT*("`@("`@("`@("`@("`@(&EF("@D
M:6YF;ULG:6YF;R==+3YG971#:&%N;F5L*"D@(3T@)W!E87(N<&AP+FYE="<I
M('L-"B`@("`@("`@("`@("`@("`@("`@)&5R<B`]('1R=64[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E:68@*"1I;F9O6R=I;F9O
M)UTM/F=E=$-H86YN96PH*2`]/2`G<&5C;"YP:'`N;F5T)RD@>PT*("`@("`@
M("`@("`@("`@(&EF("@D<&YA;65;)V-H86YN96PG72`A/2`G<&5A<BYP:'`N
M;F5T)RD@>PT*("`@("`@("`@("`@("`@("`@("`D97)R(#T@=')U93L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("1E<G(@/2!T<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@:68@*"1E<G(I('L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@G4T5#55))5%D@15)23U(Z('!A8VMA9V4@:6X@8VAA
M;FYE;"`B)R`N("1P;F%M95LG8VAA;FYE;"==("X-"B`@("`@("`@("`@("`@
M("`@("`@)R(@<F5T<FEE=F5D(&%N;W1H97(@8VAA;FYE;%PG<R!N86UE(&9O
M<B!D;W=N;&]A9"$@*"(G("X-"B`@("`@("`@("`@("`@("`@("`@)&EN9F];
M)VEN9F\G72T^9V5T0VAA;FYE;"@I("X@)R(I)RD[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D:6YF;ULG=7)L)UTI
M*2![#0H@("`@("`@("`@("`D:6YS=&5A9"`]("`G+"!W:6QL(&EN<W1E860@
M9&]W;FQO860@=F5R<VEO;B`G("X@)&EN9F];)W9E<G-I;VXG72`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`G+"!S=&%B:6QI='D@(B<@+B`D:6YF;ULG
M:6YF;R==+3YG9713=&%T92@I("X@)R(G.PT*("`@("`@("`@("`@+R\@<F5L
M96%S97,@97AI<W0L(&)U="!W92!F86EL960@=&\@9V5T(&%N>0T*("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?9&]W;FQO861E<BT^7V]P=&EO;G-;
M)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P;F%M
M95LG=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=G,@/2`G
M+"!V97)S:6]N("(G("X@)'!N86UE6R=V97)S:6]N)UT@+B`G(B<[#0H@("`@
M("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1P;F%M95LG<W1A=&4G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)'9S(#T@)RP@<W1A8FEL:71Y("(G
M("X@)'!N86UE6R=S=&%T92==("X@)R(G.PT*("`@("`@("`@("`@("`@('T@
M96QS96EF("@D<&%R86T@/3T@)V1E<&5N9&5N8WDG*2![#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T-O;6UO;B<I*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O
M0V]M;6]N+G!H<"<[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"%I;E]A<G)A>2@D:6YF;ULG:6YF;R==+3YG9713
M=&%T92@I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("!014%27T-O;6UO
M;CHZ8F5T=&5R4W1A=&5S*"1T:&ES+3Y?8V]N9FEG+3YG970H)W!R969E<G)E
M9%]S=&%T92<I+"!T<G5E*2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@D;W!T:6]N86PI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!D;VXG="!S<&ET(&]U="!C;VYF=7-I;F<@97)R;W(@;65S<V%G90T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1O
M=VYL;V%D97(M/E]G971086-K86=E1&]W;FQO8615<FPH#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=P86-K86=E)R`]/B`D<&YA
M;65;)W!A8VMA9V4G72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V-H86YN96PG(#T^("1P;F%M95LG8VAA;FYE;"==+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=F5R<VEO;B<@
M/3X@)&EN9F];)W9E<G-I;VXG72DI.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)'9S(#T@)R!W:71H:6X@
M<')E9F5R<F5D('-T871E("(G("X@)'1H:7,M/E]C;VYF:6<M/F=E="@G<')E
M9F5R<F5D7W-T871E)RD@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("<B)SL-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T1E<&5N
M9&5N8WDR)RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)U!%05(O1&5P96YD96YC>3(N<&AP)SL-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D
M;W!T:6]N86PI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!D
M;VXG="!S<&ET(&]U="!C;VYF=7-I;F<@97)R;W(@;65S<V%G90T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1O=VYL;V%D
M97(M/E]G971086-K86=E1&]W;FQO8615<FPH#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"=P86-K86=E)R`]/B`D<&YA;65;)W!A
M8VMA9V4G72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V-H86YN96PG(#T^("1P;F%M95LG8VAA;FYE;"==+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=F5R<VEO;B<@/3X@)&EN
M9F];)W9E<G-I;VXG72DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@)'9S(#T@4$5!4E]$97!E;F1E;F-Y
M,CHZ7V=E=$5X=')A4W1R:6YG*"1P;F%M92D[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D:6YS=&5A9"`]("<G.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@)'9S(#T@)R!W:71H:6X@<')E9F5R<F5D('-T871E("(G("X@)'1H:7,M
M/E]C;VYF:6<M/F=E="@-"B`@("`@("`@("`@("`@("`@("`@("`@("=P<F5F
M97)R961?<W1A=&4G*2`N("<B)SL-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(M/FQO9R@Q
M+"`G5T%23DE.1SH@9F%I;&5D('1O(&1O=VYL;V%D("<@+B`D<&YA;65;)V-H
M86YN96PG72`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G+R<@+B`D<&YA
M;65;)W!A8VMA9V4G72`N("1V<R`N("1I;G-T96%D*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@+R\@9&]W;FQO860@=&AE(&QA=&5S
M="!R96QE87-E#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&]W
M;FQO861E<BT^7V=E=%!A8VMA9V5$;W=N;&]A9%5R;"@-"B`@("`@("`@("`@
M("`@("`@("`@87)R87DH)W!A8VMA9V4G(#T^("1P;F%M95LG<&%C:V%G92==
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`G8VAA;FYE;"<@/3X@)'!N
M86UE6R=C:&%N;F5L)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("=V
M97)S:6]N)R`]/B`D:6YF;ULG=F5R<VEO;B==*2D[#0H@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("\O(&-O;G-T<G5C="!H96QP9G5L
M(&5R<F]R(&UE<W-A9V4-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!N
M86UE6R=V97)S:6]N)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1V<R`]
M("<L('9E<G-I;VX@(B<@+B`D<&YA;65;)W9E<G-I;VXG72`N("<B)SL-"B`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)'!N86UE6R=S=&%T92==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=G,@/2`G+"!S=&%B:6QI='D@
M(B<@+B`D<&YA;65;)W-T871E)UT@+B`G(B<[#0H@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*"1P87)A;2`]/2`G9&5P96YD96YC>2<I('L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?0V]M;6]N)RDI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!
M4B]#;VUM;VXN<&AP)SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("!I9B`H(6EN7V%R<F%Y*"1I;F9O6R=I;F9O)UTM/F=E
M=%-T871E*"DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?0V]M
M;6]N.CIB971T97)3=&%T97,H)'1H:7,M/E]C;VYF:6<M/F=E="@G<')E9F5R
M<F5D7W-T871E)RDL('1R=64I*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"1O<'1I;VYA;"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("\O(&1O;B=T('-P:70@;W5T(&-O;F9U<VEN9R!E<G)O<B!M97-S86=E
M+"!A;F0@9&]N)W0@9&EE(&]N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@;W!T:6]N86P@9&5P(&9A:6QU<F4A#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&]W;FQO861E<BT^7V=E=%!A
M8VMA9V5$;W=N;&]A9%5R;"@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH)W!A8VMA9V4G(#T^("1P;F%M95LG<&%C:V%G92==+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8VAA;FYE
M;"<@/3X@)'!N86UE6R=C:&%N;F5L)UTL#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=V97)S:6]N)R`]/B`D:6YF;ULG=F5R<VEO
M;B==*2D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D=G,@/2`G('=I=&AI;B!P<F5F97)R960@<W1A=&4@
M(B<@+B`D=&AI<RT^7V-O;F9I9RT^9V5T*"=P<F5F97)R961?<W1A=&4G*2`N
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(G.PT*("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"%C;&%S<U]E>&ES=',H)U!%05)?1&5P96YD96YC>3(G*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]$
M97!E;F1E;F-Y,BYP:'`G.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1O<'1I;VYA;"D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("\O(&1O;B=T('-P:70@;W5T(&-O
M;F9U<VEN9R!E<G)O<B!M97-S86=E+"!A;F0@9&]N)W0@9&EE(&]N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@;W!T:6]N86P@9&5P(&9A:6QU
M<F4A#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?9&]W;FQO861E<BT^7V=E=%!A8VMA9V5$;W=N;&]A9%5R;"@-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W!A8VMA9V4G(#T^
M("1P;F%M95LG<&%C:V%G92==+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G8VAA;FYE;"<@/3X@)'!N86UE6R=C:&%N;F5L)UTL
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V97)S
M:6]N)R`]/B`D:6YF;ULG=F5R<VEO;B==*2D[#0H@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`D=G,@/2!014%2
M7T1E<&5N9&5N8WDR.CI?9V5T17AT<F%3=')I;F<H)'!N86UE*3L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@("`@("1V<R`]("<@=VET:&EN('!R969E<G)E9"!S
M=&%T92`B)R`N("1T:&ES+3Y?9&]W;FQO861E<BT^8V]N9FEG+3YG970H#0H@
M("`@("`@("`@("`@("`@("`@("`@("`G<')E9F5R<F5D7W-T871E)RD@+B`G
M(B<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1O<'1I
M;VYS(#T@)'1H:7,M/E]D;W=N;&]A9&5R+3YG971/<'1I;VYS*"D[#0H@("`@
M("`@("`@("`@("`@+R\@=&AI<R!I<R!O;FQY('-E="!B>2!T:&4@(F1O=VYL
M;V%D+6%L;"(@8V]M;6%N9`T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M;W!T:6]N<ULG:6=N;W)E<')E9F5R<F5D7W-T871E)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("1E<G(@/2!014%2.CIR86ES945R<F]R*`T*("`@("`@
M("`@("`@("`@("`@("`@("`@)T9A:6QE9"!T;R!D;W=N;&]A9"`G("X@)'1H
M:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G8VAA;FYE;"<@/3X@
M)'!N86UE6R=C:&%N;F5L)UTL("=P86-K86=E)R`]/B`D<&YA;65;)W!A8VMA
M9V4G72DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1R=64I
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@+B`D=G,@+@T*("`@("`@("`@
M("`@("`@("`@("`@("`@)RP@;&%T97-T(')E;&5A<V4@:7,@=F5R<VEO;B`G
M("X@)&EN9F];)W9E<G-I;VXG72`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`G+"!S=&%B:6QI='D@(B<@+B`D:6YF;ULG:6YF;R==+3YG9713=&%T92@I
M("X@)R(L('5S92`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=C:&%N;F5L)R`]/B`D
M<&YA;65;)V-H86YN96PG72P@)W!A8VMA9V4G(#T^("1P;F%M95LG<&%C:V%G
M92==+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V97)S:6]N)R`]
M/B`D:6YF;ULG=F5R<VEO;B==*2D@+B`G(B!T;R!I;G-T86QL)RP-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!014%27T1/5TY,3T%$15)?4$%#2T%'
M15]35$%412D[#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D97)R.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D97)R(#T@4$5!
M4CHZ<F%I<V5%<G)O<B@-"B`@("`@("`@("`@("`@("`@("`@)T9A:6QE9"!T
M;R!D;W=N;&]A9"`G("X@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G
M94YA;654;U-T<FEN9R@-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=C:&%N;F5L)R`]/B`D<&YA;65;)V-H86YN96PG72P@)W!A8VMA9V4G(#T^
M("1P;F%M95LG<&%C:V%G92==*2P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!T<G5E*0T*("`@("`@("`@("`@("`@("`@("`@+B`D=G,@+@T*("`@
M("`@("`@("`@("`@("`@("`G+"!L871E<W0@<F5L96%S92!I<R!V97)S:6]N
M("<@+B`D:6YF;ULG=F5R<VEO;B==("X-"B`@("`@("`@("`@("`@("`@("`@
M)RP@<W1A8FEL:71Y("(G("X@)&EN9F];)VEN9F\G72T^9V5T4W1A=&4H*2`N
M("<B+"!U<V4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)E
M9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*`T*("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)V-H86YN96PG(#T^("1P;F%M95LG8VAA
M;FYE;"==+"`G<&%C:V%G92<@/3X@)'!N86UE6R=P86-K86=E)UTL#0H@("`@
M("`@("`@("`@("`@("`@("`@("`G=F5R<VEO;B<@/3X@)&EN9F];)W9E<G-I
M;VXG72DI("X@)R(@=&\@:6YS=&%L;"<I.PT*("`@("`@("`@("`@("`@(')E
M='5R;B`D97)R.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B`D:6YF;SL-"B`@("!]#0I]#0H_/@T*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O4$5!4B]$;W=N;&]A9&5R+G!H<```````````````````````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`Q-C8T,3,`,3`U,34T,S,W-#$`,#(R,34S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP#0HO
M*BH-"B`J(%!%05)?1&]W;FQO861E<BP@=&AE(%!%05(@26YS=&%L;&5R)W,@
M9&]W;FQO860@=71I;&ET>2!C;&%S<PT*("H-"B`J(%!(4"!V97)S:6]N<R`T
M(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S
M=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@
M=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O
M<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O
M8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N
M;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J
M($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R
M(#QC96QL;V=`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N
M(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@(%1O;6%S(%8N(%8N($-O
M>"`\8V]X0&ED96-N970N8V]M/@T*("H@0&%U=&AO<B`@("`@36%R=&EN($IA
M;G-E;B`\;6I`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4
M:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S
M:6]N("`@($-64SH@)$ED.B!$;W=N;&]A9&5R+G!H<"QV(#$N.3D@,C`P-B\P
M,R\P,B`Q.#HQ-#HQ,R!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@
M("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N,RXP#0H@*B\-"@T*
M+RHJ#0H@*B!.965D960@9F]R(&-O;G-T86YT<RP@97AT96YD:6YG#0H@*B\-
M"G)E<75I<F5?;VYC92`G4$5!4B]#;VUM;VXN<&AP)SL-"@T*9&5F:6YE*"=0
M14%27TE.4U1!3$Q%4E]/2R<L("`@("`@(#$I.PT*9&5F:6YE*"=014%27TE.
M4U1!3$Q%4E]&04E,140G+"`@(#`I.PT*9&5F:6YE*"=014%27TE.4U1!3$Q%
M4E]32TE04$5$)RP@+3$I.PT*9&5F:6YE*"=014%27TE.4U1!3$Q%4E]%4E)/
M4E].3U]04D5&7U-4051%)RP@,BD[#0H-"B\J*@T*("H@061M:6YI<W1R871I
M;VX@8VQA<W,@=7-E9"!T;R!D;W=N;&]A9"!A;GET:&EN9R!F<F]M('1H92!I
M;G1E<FYE="`H4$5!4B!086-K86=E<RP-"B`J('-T871I8R!54DQS+"!X;6P@
M9FEL97,I#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@
M("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P
M:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N
M;F5T/@T*("H@0&%U=&AO<B`@("`@5&]M87,@5BX@5BX@0V]X(#QC;WA`:61E
M8VYE="YC;VT^#0H@*B!`875T:&]R("`@("!-87)T:6X@2F%N<V5N(#QM:D!P
M:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O
M=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L
M96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B
M;&4@<VEN8V4@4F5L96%S92`Q+C,N,`T*("HO#0IC;&%S<R!014%27T1O=VYL
M;V%D97(@97AT96YD<R!014%27T-O;6UO;@T*>PT*("`@("\J*@T*("`@("`J
M($!V87(@4$5!4E]296=I<W1R>0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*
M("`@("`J+PT*("`@('9A<B`D7W)E9VES=')Y.PT*#0H@("`@+RHJ#0H@("`@
M("H@0'9A<B!014%27U)E;6]T90T*("`@("`J($!A8V-E<W,@<')I=F%T90T*
M("`@("`J+PT*("`@('9A<B`D7W)E;6]T93L-"@T*("`@("\J*@T*("`@("`J
M(%!R969E<G)E9"!);G-T86QL871I;VX@4W1A=&4@*'-N87!S:&]T+"!D979E
M;"P@86QP:&$L(&)E=&$L('-T86)L92D-"B`@("`@*B!`=F%R('-T<FEN9WQN
M=6QL#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R
M("1?<')E9F5R<F5D4W1A=&4[#0H-"B`@("`O*BH-"B`@("`@*B!/<'1I;VYS
M(&9R;VT@8V]M;6%N9"UL:6YE('!A<W-E9"!T;R!);G-T86QL+@T*("`@("`J
M#0H@("`@("H@4F5C;V=N:7IE9"!O<'1I;VYS.CQB<B`O/@T*("`@("`J("`M
M(&]N;'ER97%D97!S("`@.B!I;G-T86QL(&%L;"!R97%U:7)E9"!D97!E;F1E
M;F-I97,@87,@=V5L;`T*("`@("`J("`M(&%L;&1E<',@("`@("`@.B!I;G-T
M86QL(&%L;"!D97!E;F1E;F-I97,L(&EN8VQU9&EN9R!O<'1I;VYA;`T*("`@
M("`J("`M(&EN<W1A;&QR;V]T("`@.B!B87-E(')E;&%T:79E('!A=&@@=&\@
M:6YS=&%L;"!F:6QE<R!I;@T*("`@("`J("`M(&9O<F-E("`@("`@("`@.B!F
M;W)C92!A(&1O=VYL;V%D(&5V96X@:68@=V%R;FEN9W,@=V]U;&0@<')E=F5N
M="!I=`T*("`@("`J("`M(&YO8V]M<')E<W,@("`@.B!D;W=N;&]A9"!U;F-O
M;7!R97-S960@=&%R8F%L;',-"B`@("`@*B!`<V5E(%!%05)?0V]M;6%N9%])
M;G-T86QL#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("H@0'9A<B!A
M<G)A>0T*("`@("`J+PT*("`@('9A<B`D7V]P=&EO;G,[#0H-"B`@("`O*BH-
M"B`@("`@*B!$;W=N;&]A9&5D(%!A8VMA9V5S(&%F=&5R(&$@8V%L;"!T;R!D
M;W=N;&]A9"@I+@T*("`@("`J#0H@("`@("H@1F]R;6%T(&]F(&5A8V@@96YT
M<GDZ#0H@("`@("H-"B`@("`@*B`\8V]D93X-"B`@("`@*B!A<G)A>2@G<&MG
M)R`]/B`G<&%C:V%G95]N86UE)RP@)V9I;&4G(#T^("<O<&%T:"]T;R]L;V-A
M;"]F:6QE)RP-"B`@("`@*B`@("`G:6YF;R<@/3X@87)R87DH*2`O+R!P87)S
M960@<&%C:V%G92YX;6P-"B`@("`@*B`I.PT*("`@("`J(#PO8V]D93X-"B`@
M("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B!`=F%R(&%R<F%Y#0H@("`@
M("HO#0H@("`@=F%R("1?9&]W;FQO861E9%!A8VMA9V5S(#T@87)R87DH*3L-
M"@T*("`@("\J*@T*("`@("`J(%!A8VMA9V5S('-L871E9"!F;W(@9&]W;FQO
M860N#0H@("`@("H-"B`@("`@*B!4:&ES(&ES('5S960@=&\@<')E=F5N="!D
M;W=N;&]A9&EN9R!A('!A8VMA9V4@;6]R92!T:&%N(&]N8V4@<VAO=6QD(&ET
M(&)E(&$@9&5P96YD96YC>0T*("`@("`J(&9O<B!T=V\@<&%C:V%G97,@=&\@
M8F4@:6YS=&%L;&5D+@T*("`@("`J($9O<FUA="!O9B!E86-H(&5N=')Y.@T*
M("`@("`J#0H@("`@("H@/'!R93X-"B`@("`@*B!A<G)A>2@G<&%C:V%G95]N
M86UE,2<@/3X@<&%R<V5D('!A8VMA9V4N>&UL+"`G<&%C:V%G95]N86UE,B<@
M/3X@<&%R<V5D('!A8VMA9V4N>&UL+`T*("`@("`J("D[#0H@("`@("H@/"]P
M<F4^#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("H@0'9A<B!A<G)A
M>0T*("`@("`J+PT*("`@('9A<B`D7W1O1&]W;FQO860@/2!A<G)A>2@I.PT*
M#0H@("`@+RHJ#0H@("`@("H@07)R87D@;V8@979E<GD@<&%C:V%G92!I;G-T
M86QL960L('=I=&@@;F%M97,@;&]W97(M8V%S960N#0H@("`@("H-"B`@("`@
M*B!&;W)M870Z#0H@("`@("H@/&-O9&4^#0H@("`@("H@87)R87DH)W!A8VMA
M9V4Q)R`]/B`P+"`G<&%C:V%G93(G(#T^(#$L("D[#0H@("`@("H@/"]C;V1E
M/@T*("`@("`J($!V87(@87)R87D-"B`@("`@*B\-"B`@("!V87(@)%]I;G-T
M86QL960@/2!A<G)A>2@I.PT*#0H@("`@+RHJ#0H@("`@("H@0'9A<B!A<G)A
M>0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D
M7V5R<F]R4W1A8VL@/2!A<G)A>2@I.PT*("`@(`T*("`@("\J*@T*("`@("`J
M($!V87(@8F]O;&5A;@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J
M+PT*("`@('9A<B`D7VEN=&5R;F%L1&]W;FQO860@/2!F86QS93L-"@T*("`@
M("\J*@T*("`@("`J(%1E;7!O<F%R>2!V87)I86)L92!U<V5D(&EN('-O<G1I
M;F<@<&%C:V%G97,@8GD@9&5P96YD96YC>2!I;B![0&QI;FL@<V]R=%!K9T1E
M<',H*7T-"B`@("`@*B!`=F%R(&%R<F%Y#0H@("`@("H@0&%C8V5S<R!P<FEV
M871E#0H@("`@("HO#0H@("`@=F%R("1?<&%C:V%G95-O<G14<F5E.PT*#0H@
M("`@+RHJ#0H@("`@("H@5&5M<&]R87)Y(&1I<F5C=&]R>2P@;W(@8V]N9FEG
M=7)A=&EO;B!V86QU92!W:&5R92!D;W=N;&]A9',@=VEL;"!O8V-U<@T*("`@
M("`J($!V87(@<W1R:6YG#0H@("`@("HO#0H@("`@=F%R("1?9&]W;FQO861$
M:7([#0H@("`@+R\@>WM[(%!%05)?1&]W;FQO861E<B@I#0H-"B`@("`O*BH-
M"B`@("`@*B!`<&%R86T@4$5!4E]&<F]N=&5N9%\J#0H@("`@("H@0'!A<F%M
M(&%R<F%Y#0H@("`@("H@0'!A<F%M(%!%05)?0V]N9FEG#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@4$5!4E]$;W=N;&]A9&5R*"8D=6DL("1O<'1I;VYS+"`F
M)&-O;F9I9RD-"B`@("![#0H@("`@("`@('!A<F5N=#HZ4$5!4E]#;VUM;VXH
M*3L-"B`@("`@("`@)'1H:7,M/E]O<'1I;VYS(#T@)&]P=&EO;G,[#0H@("`@
M("`@("1T:&ES+3YC;VYF:6<@/2`F)&-O;F9I9SL-"B`@("`@("`@)'1H:7,M
M/E]P<F5F97)R9613=&%T92`]("1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R
M<F5D7W-T871E)RD[#0H@("`@("`@("1T:&ES+3YU:2`]("8D=6D[#0H@("`@
M("`@(&EF("@A)'1H:7,M/E]P<F5F97)R9613=&%T92D@>PT*("`@("`@("`@
M("`@+R\@9&]N)W0@:6YA9'9E<G1A;G1L>2!U<V4@82!N;VXM<V5T('!R969E
M<G)E9%]S=&%T90T*("`@("`@("`@("`@)'1H:7,M/E]P<F5F97)R9613=&%T
M92`](&YU;&P[#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]O<'1I;VYS6R=I;G-T86QL<F]O="==*2D@>PT*("`@("`@("`@("`@
M)'1H:7,M/F-O;F9I9RT^<V5T26YS=&%L;%)O;W0H)'1H:7,M/E]O<'1I;VYS
M6R=I;G-T86QL<F]O="==*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^
M7W)E9VES=')Y(#T@)B1C;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@
M("1T:&ES+3Y?<F5M;W1E(#T@)B1C;VYF:6<M/F=E=%)E;6]T92@I.PT*#0H@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V]P=&EO;G-;)V%L;&1E<',G72D@
M?'P@:7-S970H)'1H:7,M/E]O<'1I;VYS6R=O;FQY<F5Q9&5P<R==*2D@>PT*
M("`@("`@("`@("`@)'1H:7,M/E]I;G-T86QL960@/2`D=&AI<RT^7W)E9VES
M=')Y+3YL:7-T06QL4&%C:V%G97,H*3L-"B`@("`@("`@("`@(&9O<F5A8V@@
M*"1T:&ES+3Y?:6YS=&%L;&5D(&%S("1K97D@/3X@)'5N=7-E9"D@>PT*("`@
M("`@("`@("`@("`@(&EF("@A8V]U;G0H)'5N=7-E9"DI('L-"B`@("`@("`@
M("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@($!A<G)A>5]W86QK*"1T:&ES+3Y?:6YS=&%L;&5D6R1K
M97E=+"`G<W1R=&]L;W=E<B<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@071T96UP="!T;R!D:7-C;W9E
M<B!A(&-H86YN96PG<R!R96UO=&4@8V%P86)I;&ET:65S(&9R;VT-"B`@("`@
M*B!I=',@<V5R=F5R(&YA;64-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@("`@
M("H@0')E='5R;B!B;V]L96%N#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9&ES
M8V]V97(H)&-H86YN96PI#0H@("`@>PT*("`@("`@("`D=&AI<RT^;&]G*#$L
M("=!='1E;7!T:6YG('1O(&1I<V-O=F5R(&-H86YN96P@(B<@+B`D8VAA;FYE
M;"`N("<B+BXN)RD[#0H@("`@("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG
M*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@)&-A;&QB86-K(#T@)'1H
M:7,M/G5I(#\@87)R87DH)B1T:&ES+"`G7V1O=VYL;V%D0V%L;&)A8VLG*2`Z
M(&YU;&P[#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=3>7-T96TG*2D@
M>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=3>7-T96TN<&AP)SL-"B`@
M("`@("`@?0T*("`@("`@("`D82`]("1T:&ES+3YD;W=N;&]A9$AT='`H)VAT
M='`Z+R\G("X@)&-H86YN96P@+B`G+V-H86YN96PN>&UL)RP@)'1H:7,M/G5I
M+`T*("`@("`@("`@("`@4WES=&5M.CIM:W1E;7`H87)R87DH)RUD)RDI+"`D
M8V%L;&)A8VLL(&9A;'-E*3L-"B`@("`@("`@4$5!4CHZ<&]P17)R;W)(86YD
M;&EN9R@I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D82DI('L-"B`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!L
M:7-T*"1A+"`D;&%S=&UO9&EF:65D*2`]("1A.PT*("`@("`@("!I9B`H(6-L
M87-S7V5X:7-T<R@G4$5!4B]#:&%N;F5L1FEL92YP:'`G*2D@>PT*("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E("=014%2+T-H86YN96Q&:6QE+G!H<"<[#0H@
M("`@("`@('T-"B`@("`@("`@)&(@/2!N97<@4$5!4E]#:&%N;F5L1FEL93L-
M"B`@("`@("`@:68@*"1B+3YF<F]M6&UL1FEL92@D82DI('L-"B`@("`@("`@
M("`@($!U;FQI;FLH)&$I.PT*("`@("`@("`@("`@:68@*"1T:&ES+3YC;VYF
M:6<M/F=E="@G875T;U]D:7-C;W9E<B<I*2![#0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]R96=I<W1R>2T^861D0VAA;FYE;"@D8BP@)&QA<W1M;V1I9FEE
M9"D[#0H@("`@("`@("`@("`@("`@)&%L:6%S(#T@)&(M/F=E=$YA;64H*3L-
M"B`@("`@("`@("`@("`@("!I9B`H)&(M/F=E=$YA;64H*2`]/2`D=&AI<RT^
M7W)E9VES=')Y+3YC:&%N;F5L3F%M92@D8BT^9V5T06QI87,H*2DI('L-"B`@
M("`@("`@("`@("`@("`@("`@)&%L:6%S(#T@)&(M/F=E=$%L:6%S*"D[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H
M,2P@)T%U=&\M9&ES8V]V97)E9"!C:&%N;F5L("(G("X@)&-H86YN96P@+@T*
M("`@("`@("`@("`@("`@("`@("`G(BP@86QI87,@(B<@+B`D86QI87,@+B`G
M(BP@861D:6YG('1O(')E9VES=')Y)RD[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("!`=6YL
M:6YK*"1A*3L-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@
M("\J*@T*("`@("`J($9O<B!S:6UP;&5R('5N:70M=&5S=&EN9PT*("`@("`J
M($!P87)A;2!014%27T1O=VYL;V%D97(-"B`@("`@*B!`<F5T=7)N(%!%05)?
M1&]W;FQO861E<E]086-K86=E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)FYE
M=T1O=VYL;V%D97)086-K86=E*"8D="D-"B`@("![#0H@("`@("`@(&EF("@A
M8VQA<W-?97AI<W1S*"=014%27T1O=VYL;V%D97)?4&%C:V%G92<I*2![#0H@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O1&]W;FQO861E<B]086-K
M86=E+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@)&$@/2`F;F5W(%!%05)?
M1&]W;FQO861E<E]086-K86=E*"1T*3L-"B`@("`@("`@<F5T=7)N("1A.PT*
M("`@('T-"@T*("`@("\J*@T*("`@("`J($9O<B!S:6UP;&5R('5N:70M=&5S
M=&EN9PT*("`@("`J($!P87)A;2!014%27T-O;F9I9PT*("`@("`J($!P87)A
M;2!A<G)A>0T*("`@("`J($!P87)A;2!A<G)A>0T*("`@("`J($!P87)A;2!I
M;G0-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F9V5T1&5P96YD96YC>3)/8FIE
M8W0H)B1C+"`D:2P@)'`L("1S*0T*("`@('L-"B`@("`@("`@:68@*"%C;&%S
M<U]E>&ES=',H)U!%05(O1&5P96YD96YC>3(N<&AP)RDI('L-"B`@("`@("`@
M("`@(')E<75I<F5?;VYC92`G4$5!4B]$97!E;F1E;F-Y,BYP:'`G.PT*("`@
M("`@("!]#0H@("`@("`@("1Z(#T@)FYE=R!014%27T1E<&5N9&5N8WDR*"1C
M+"`D:2P@)'`L("1S*3L-"B`@("`@("`@<F5T=7)N("1Z.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N("9D;W=N;&]A9"@D<&%R86US*0T*("`@('L-"B`@("`@
M("`@:68@*"%C;W5N="@D<&%R86US*2D@>PT*("`@("`@("`@("`@)&$@/2!A
M<G)A>2@I.PT*("`@("`@("`@("`@<F5T=7)N("1A.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]R96=I<W1R>2DI('L-"B`@("`@
M("`@("`@("1T:&ES+3Y?<F5G:7-T<GD@/2`F)'1H:7,M/F-O;F9I9RT^9V5T
M4F5G:7-T<GDH*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?<F5M;W1E*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]R96UO=&4@
M/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5M;W1E*"D[#0H@("`@("`@('T-"B`@
M("`@("`@)&-H86YN96QS8VAE8VME9"`](&%R<F%Y*"D[#0H@("`@("`@("\O
M(&-O;G9E<G0@86QL('!A<F%M971E<G,@:6YT;R!014%27T1O=VYL;V%D97)?
M4&%C:V%G92!O8FIE8W1S#0H@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@
M)&D@/3X@)'!A<F%M*2![#0H@("`@("`@("`@("`D<&%R86US6R1I72`]("8D
M=&AI<RT^;F5W1&]W;FQO861E<E!A8VMA9V4H)'1H:7,I.PT*("`@("`@("`@
M("`@4$5!4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]2
M15154DXI.PT*("`@("`@("`@("`@)&5R<B`]("1P87)A;7-;)&E=+3YI;FET
M:6%L:7IE*"1P87)A;2D[#0H@("`@("`@("`@("!014%2.CIS=&%T:6-0;W!%
M<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("!I9B`H(21E<G(I('L-"B`@
M("`@("`@("`@("`@("`O+R!S:VEP('!A<F%M971E<G,@=&AA="!W97)E(&UI
M<W-E9"!B>2!P<F5F97)R961?<W1A=&4-"B`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1E<G(I*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^7V]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/FQO9R@P+"`D97)R+3YG971-97-S86=E*"DI.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D<&%R86US6R1I72`](&9A
M;'-E.PT*("`@("`@("`@("`@("`@(&EF("AI<U]O8FIE8W0H)'!A<F%M*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`D<&%R86T@/2`D<&%R86TM/F=E=$-H
M86YN96PH*2`N("<O)R`N("1P87)A;2T^9V5T4&%C:V%G92@I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D=&AI<RT^<'5S:$5R<F]R
M*"=086-K86=E("(G("X@)'!A<F%M("X@)R(@:7,@;F]T('9A;&ED)RP-"B`@
M("`@("`@("`@("`@("`@("`@4$5!4E])3E-404Q,15)?4TM)4%!%1"D[#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(&EF("@D<&%R
M86US6R1I72`F)B`A:7-S970H)&-H86YN96QS8VAE8VME9%LD<&%R86US6R1I
M72T^9V5T0VAA;FYE;"@I72D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`A
M:7-S970H)'1H:7,M/E]O<'1I;VYS6R=O9F9L:6YE)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("1C:&%N;F5L<V-H96-K961;)'!A<F%M<ULD:5TM/F=E
M=$-H86YN96PH*5T@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!014%2
M.CIS=&%T:6-0=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=3>7-T
M96TG*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E
M("=3>7-T96TN<&AP)SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`D8W5R8VAA;FYE;"`]("8D=&AI<RT^7W)E9VES=')Y
M+3YG971#:&%N;F5L*"1P87)A;7-;)&E=+3YG971#:&%N;F5L*"DI.PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8W5R8VAA;FYE
M;"DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(%!%05(Z.G-T871I8U!O
M<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D8W5R8VAA;FYE;"D[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)&$@/2`D=&AI
M<RT^9&]W;FQO861(='1P*"=H='1P.B\O)R`N("1P87)A;7-;)&E=+3YG971#
M:&%N;F5L*"D@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)R]C:&%N;F5L
M+GAM;"<L("1T:&ES+3YU:2P-"B`@("`@("`@("`@("`@("`@("`@("`@(%-Y
M<W1E;3HZ;6MT96UP*&%R<F%Y*"<M9"<I*2P@;G5L;"P@)&-U<F-H86YN96PM
M/FQA<W1-;V1I9FEE9"@I*3L-"B`@("`@("`@("`@("`@("`@("`@4$5!4CHZ
M<W1A=&EC4&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D82D@?'P@(21A*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("=705).24Y'
M.B!C:&%N;F5L("(G("X@)'!A<F%M<ULD:5TM/F=E=$-H86YN96PH*2`N("<B
M(&AA<R`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("=U<&1A=&5D(&ET
M<R!P<F]T;V-O;',L('5S92`B8VAA;FYE;"UU<&1A=&4@)R`N("1P87)A;7-;
M)&E=+3YG971#:&%N;F5L*"D@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M)R(@=&\@=7!D871E)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(&EF("@D<&%R86US6R1I72`F)B`A:7-S970H)'1H:7,M/E]O<'1I
M;VYS6R=D;W=N;&]A9&]N;'DG72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG<&%C:V%G:6YG<F]O="==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-H96-K9&ER(#T@)'1H:7,M
M/E]P<F5P96YD4&%T:"@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^8V]N9FEG+3YG970H)W!H<%]D:7(G+"!N=6QL+"`D<&%R86US6R1I
M72T^9V5T0VAA;FYE;"@I*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V]P=&EO;G-;)W!A8VMA9VEN9W)O;W0G72D[#0H@("`@("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D8VAE8VMD:7(@/2`D=&AI<RT^8V]N9FEG+3YG970H)W!H<%]D:7(G+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL("1P87)A;7-;)&E=
M+3YG971#:&%N;F5L*"DI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@('=H:6QE("@D8VAE8VMD:7(@)B8@)&-H96-K9&ER
M("$]("<O)R`F)B`A9FEL95]E>&ES=',H)&-H96-K9&ER*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&-H96-K9&ER(#T@9&ER;F%M92@D8VAE8VMD
M:7(I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@D8VAE8VMD:7(@/3T@)RXG*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D8VAE8VMD:7(@/2`G+R<[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"%`:7-?=W)I=&5A8FQE*"1C
M:&5C:V1I<BDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=#86YN;W0@:6YS=&%L;"P@<&AP7V1I<B!F;W(@
M8VAA;FYE;"`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A
M<F%M<ULD:5TM/F=E=$-H86YN96PH*2`N("<B(&ES(&YO="!W<FET96%B;&4@
M8GD@=&AE(&-U<G)E;G0@=7-E<B<I.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@('5N<V5T*"1C:&%N;F5L<V-H96-K960I.PT*("`@("`@("!0
M14%27T1O=VYL;V%D97)?4&%C:V%G93HZ<F5M;W9E1'5P;&EC871E<R@D<&%R
M86US*3L-"B`@("`@("`@:68@*"%C;W5N="@D<&%R86US*2D@>PT*("`@("`@
M("`@("`@)&$@/2!A<G)A>2@I.PT*("`@("`@("`@("`@<F5T=7)N("1A.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS
M6R=N;V1E<',G72D@)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;V9F;&EN
M92==*2D@>PT*("`@("`@("`@("`@)')E=F5R:69Y(#T@=')U93L-"B`@("`@
M("`@("`@('=H:6QE("@D<F5V97)I9GDI('L-"B`@("`@("`@("`@("`@("`D
M<F5V97)I9GD@/2!F86QS93L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D
M<&%R86US(&%S("1I(#T^("1P87)A;2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D<F5T(#T@)'!A<F%M<ULD:5TM/F1E=&5C=$1E<&5N9&5N8VEE<R@D<&%R
M86US*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)')E="DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R979E<FEF>2`]
M('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US6R1I72`]
M(&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E]$;W=N;&]A
M9&5R7U!A8VMA9V4Z.G)E;6]V941U<&QI8V%T97,H)'!A<F%M<RD[#0H@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N
M<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YL;V<H,"P@)')E="T^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I
M;G5E(#([#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;V9F;&EN92==*2D@>PT*("`@("`@("`@
M("`@)'1H:7,M/FQO9R@S+"`G4VMI<'!I;F<@9&5P96YD96YC>2!D;W=N;&]A
M9"!C:&5C:RP@+2UO9F9L:6YE('-P96-I9FEE9"<I.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@A8V]U;G0H)'!A<F%M<RDI('L-"B`@("`@("`@("`@("1A
M(#T@87)R87DH*3L-"B`@("`@("`@("`@(')E='5R;B`D83L-"B`@("`@("`@
M?0T*("`@("`@("!W:&EL92`H4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4Z.FUE
M<F=E1&5P96YD96YC:65S*"1P87)A;7,I*3L-"B`@("`@("`@4$5!4E]$;W=N
M;&]A9&5R7U!A8VMA9V4Z.G)E;6]V94EN<W1A;&QE9"@D<&%R86US*3L-"B`@
M("`@("`@:68@*"%C;W5N="@D<&%R86US*2D@>PT*("`@("`@("`@("`@)'1H
M:7,M/G!U<VA%<G)O<B@G3F\@=F%L:60@<&%C:V%G97,@9F]U;F0G+"!014%2
M7TE.4U1!3$Q%4E]&04E,140I.PT*("`@("`@("`@("`@)&$@/2!A<G)A>2@I
M.PT*("`@("`@("`@("`@<F5T=7)N("1A.PT*("`@("`@("!]#0H@("`@("`@
M(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-
M"B`@("`@("`@)&5R<B`]("1T:&ES+3YA;F%L>7IE1&5P96YD96YC:65S*"1P
M87)A;7,I.PT*("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@
M("`@("`@(&EF("@A8V]U;G0H)'!A<F%M<RDI('L-"B`@("`@("`@("`@("1T
M:&ES+3YP=7-H17)R;W(H)TYO('9A;&ED('!A8VMA9V5S(&9O=6YD)RP@4$5!
M4E])3E-404Q,15)?1D%)3$5$*3L-"B`@("`@("`@("`@("1A(#T@87)R87DH
M*3L-"B`@("`@("`@("`@(')E='5R;B`D83L-"B`@("`@("`@?0T*("`@("`@
M("`D<F5T(#T@87)R87DH*3L-"B`@("`@("`@)&YE=W!A<F%M<R`](&%R<F%Y
M*"D[#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V]P=&EO;G-;)W!R971E
M;F0G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D<&%R86US.PT*("`@("`@
M("!]#0H@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)&D@/3X@)'!A8VMA
M9V4I('L-"B`@("`@("`@("`@(%!%05(Z.G-T871I8U!U<VA%<G)O<DAA;F1L
M:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@("`@("1P9B`]("8D
M<&%R86US6R1I72T^9&]W;FQO860H*3L-"B`@("`@("`@("`@(%!%05(Z.G-T
M871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1P9BDI('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^;&]G*#$L("1P9BT^9V5T365S<V%G92@I*3L-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`G17)R;W(Z(&-A;FYO="!D
M;W=N;&]A9"`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*"1P86-K86=E
M+3YG971087)S961086-K86=E*"DL#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=')U92D@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)R(G*3L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D;F5W<&%R86US6UT@/2`F
M)'!A<F%M<ULD:5T[#0H@("`@("`@("`@("`D<F5T6UT@/2!A<G)A>2@G9FEL
M92<@/3X@)'!F+3YG971!<F-H:79E1FEL92@I+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G:6YF;R<@/3X@)B1P9BP-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!K9R<@/3X@)'!F+3YG9710
M86-K86=E*"DI.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?9&]W;FQO
M861E9%!A8VMA9V5S(#T@)')E=#L-"B`@("`@("`@<F5T=7)N("1N97=P87)A
M;7,[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&%R<F%Y(&%L
M;"!P86-K86=E<R!T;R!B92!I;G-T86QL960-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!A;F%L>7IE1&5P96YD96YC:65S*"8D<&%R86US*0T*("`@('L-"B`@
M("`@("`@)&AA<V9A:6QE9"`]("1F86EL960@/2!F86QS93L-"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9&]W;FQO861O;FQY)UTI*2![
M#0H@("`@("`@("`@("!R971U<FX[#0H@("`@("`@('T-"B`@("`@("`@4$5!
M4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI
M.PT*("`@("`@("`D<F5D;R`]('1R=64[#0H@("`@("`@("1R97-E="`](&9A
M;'-E.PT*("`@("`@("!W:&EL92`H)')E9&\I('L-"B`@("`@("`@("`@("1R
M961O(#T@9F%L<V4[#0H@("`@("`@("`@("!F;W)E86-H("@D<&%R86US(&%S
M("1I(#T^("1P87)A;2D@>PT*("`@("`@("`@("`@("`@("1D97!S(#T@)'!A
M<F%M+3YG971$97!S*"D[#0H@("`@("`@("`@("`@("`@:68@*"$D9&5P<RD@
M>PT*("`@("`@("`@("`@("`@("`@("`D9&5P8VAE8VME<B`]("8D=&AI<RT^
M9V5T1&5P96YD96YC>3)/8FIE8W0H)'1H:7,M/F-O;F9I9RP@)'1H:7,M/F=E
M=$]P=&EO;G,H*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;2T^
M9V5T4&%R<V5D4&%C:V%G92@I+"!014%27U9!3$E$051%7T1/5TY,3T%$24Y'
M*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1P87)A;2T^9V5T5'EP92@I
M(#T]("=X;6QR<&,G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D<V5N
M9"`]("1P87)A;2T^9V5T1&]W;FQO86154DPH*3L-"B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1S96YD
M(#T@)'!A<F%M+3YG971086-K86=E1FEL92@I.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1I;G-T86QL8VAE8VL@/2`D
M9&5P8VAE8VME<BT^=F%L:61A=&5086-K86=E*"1S96YD+"`D=&AI<RP@)'!A
M<F%M<RD[#0H@("`@("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1I;G-T86QL8VAE8VLI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@)&EN<W1A;&QC
M:&5C:RT^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1H87-F86EL960@/2!T<G5E
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<ULD:5T@/2!F86QS
M93L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R97-E="`]('1R=64[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D<F5D;R`]('1R=64[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D9F%I;&5D(#T@9F%L<V4[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!014%27T1O=VYL;V%D97)?4&%C:V%G93HZ<F5M;W9E
M1'5P;&EC871E<R@D<&%R86US*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E(#([#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@(&EF("@A)')E<V5T("8F("1P87)A;2T^86QR96%D>59A
M;&ED871E9"@I*2![#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H8V]U;G0H
M)&1E<',I*2![#0H@("`@("`@("`@("`@("`@("`@("1D97!C:&5C:V5R(#T@
M)B1T:&ES+3YG971$97!E;F1E;F-Y,D]B:F5C="@D=&AI<RT^8V]N9FEG+"`D
M=&AI<RT^9V5T3W!T:6]N<R@I+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M)'!A<F%M+3YG971087)S961086-K86=E*"DL(%!%05)?5D%,241!5$5?1$]7
M3DQ/041)3D<I.PT*("`@("`@("`@("`@("`@("`@("!I9B`H)'!A<F%M+3YG
M9714>7!E*"D@/3T@)WAM;')P8R<I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1S96YD(#T@)'!A<F%M+3YG971$;W=N;&]A9%523"@I.PT*("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)'-E;F0@/2`D<&%R86TM/F=E=%!A8VMA9V5&:6QE*"D[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)&EN<W1A;&QC
M:&5C:R`]("1D97!C:&5C:V5R+3YV86QI9&%T95!A8VMA9V4H)'-E;F0L("1T
M:&ES+"`D<&%R86US*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&EN<W1A;&QC:&5C:RDI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=S;V9T)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`D
M:6YS=&%L;&-H96-K+3YG971-97-S86=E*"DI.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)&AA<V9A:6QE
M9"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US6R1I
M72`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E<V5T(#T@
M=')U93L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R961O(#T@=')U93L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1F86EL960@/2!F86QS93L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(%!%05)?1&]W;FQO861E<E]086-K86=E
M.CIR96UO=F5$=7!L:6-A=&5S*"1P87)A;7,I.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`D9F%I;&5D(#T@9F%L<V4[#0H@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P<ULG<F5Q=6ER960G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1D97!S6R=R97%U
M:7)E9"==(&%S("1T>7!E(#T^("1D97`I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!N;W1E.B!$97!E;F1E;F-Y,B!W:6QL(&YE=F5R(')E
M='5R;B!A(%!%05)?17)R;W(@:68@:6=N;W)E+65R<F]R<PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O(&ES('-P96-I9FEE9"P@<V\@<V]F="!I
M<R!N965D960@=&\@='5R;B!O9F8@;&]G9VEN9PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@A:7-S970H)&1E<%LP72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4@
M/2`D9&5P8VAE8VME<BT^>R)V86QI9&%T97LD='EP97U$97!E;F1E;F-Y(GTH
M)&1E<"P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=')U92P@)'!A<F%M<RDI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9F%I;&5D(#T@=')U93L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS
M6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/FQO9R@P+"`D92T^9V5T365S<V%G92@I*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1E
M*2`F)B`A)'!A<F%M+3YA;')E861Y5F%L:61A=&5D*"DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`D95LP72D[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!F;W)E86-H("@D9&5P(&%S("1D*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P
M8VAE8VME<BT^>R)V86QI9&%T97LD='EP97U$97!E;F1E;F-Y(GTH)&0L#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T<G5E
M+"`D<&%R86US*2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9F%I;&5D(#T@=')U93L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T
M:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("1E+3YG971-97-S86=E
M*"DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M96EF("AI<U]A<G)A>2@D92D@)B8@(21P87)A;2T^86QR96%D>59A;&ED871E
M9"@I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)W-O9G0G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/FQO9R@P+"`D95LP72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1D97!S6R=O<'1I;VYA;"==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1D97!S6R=O<'1I;VYA;"==(&%S("1T>7!E
M(#T^("1D97`I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D9&5P6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4@/0T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<&-H96-K
M97(M/GLB=F%L:61A=&5[)'1Y<&5]1&5P96YD96YC>2)]*"1D97`L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F86QS92P@
M)'!A<F%M<RDI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&9A:6QE9"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO
M;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`D92T^9V5T365S<V%G92@I
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H:7-?87)R87DH)&4I("8F("$D<&%R86TM/F%L<F5A9'E686QI9&%T960H
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YL;V<H,"P@)&5;,%TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1D97`@87,@)&0I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E
M<&-H96-K97(M/GLB=F%L:61A=&5[)'1Y<&5]1&5P96YD96YC>2)]*"1D+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&9A;'-E+"`D<&%R86US*2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&9A:6QE9"`]('1R=64[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G
M*#`L("1E+3YG971-97-S86=E*"DI.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1E*2`F
M)B`A)'!A<F%M+3YA;')E861Y5F%L:61A=&5D*"DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^7V]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@
M)&5;,%TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)&=R;W5P;F%M92`]("1P
M87)A;2T^9V5T1W)O=7`H*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D9&5P<ULG9W)O=7`G72D@)B8@)&=R;W5P;F%M92D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&1E<'-;)V=R
M;W5P)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D97!S6R=G<F]U<"==(#T@87)R87DH)&1E<'-;)V=R;W5P)UTI.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9F]U;F0@/2!F86QS93L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D9&5P<ULG9W)O=7`G72!A<R`D9W)O=7`I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1G<F]U
M<%LG871T<FEB<R==6R=N86UE)UT@/3T@)&=R;W5P;F%M92D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O=6YD(#T@=')U93L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@D9F]U;F0I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=6YS970H)&=R;W5P6R=A='1R:6)S)UTI.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D9W)O=7`@87,@)'1Y<&4@
M/3X@)&1E<"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D9&5P6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E(#T-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9&5P8VAE8VME<BT^>R)V86QI9&%T97LD='EP97U$97!E;F1E;F-Y(GTH
M)&1E<"P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!F86QS92P@)'!A<F%M<RDI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F86EL960@/2!T<G5E.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/FQO9R@P+"`D92T^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI<U]A<G)A
M>2@D92D@)B8@(21P87)A;2T^86QR96%D>59A;&ED871E9"@I*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)'1H:7,M/E]O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M;&]G*#`L("1E6S!=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)&1E<"!A<R`D9"D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D92`]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1D97!C:&5C:V5R+3Y[(G9A;&ED871E>R1T
M>7!E?41E<&5N9&5N8WDB?2@D9"P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9F%L<V4L("1P87)A;7,I*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&9A:6QE9"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?
M;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@)&4M
M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D92D@
M)B8@(21P87)A;2T^86QR96%D>59A;&ED871E9"@I*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YL;V<H,"P@)&5;,%TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&1E<',@
M87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1E(#T@)&1E<&-H96-K97(M/G9A;&ED871E1&5P96YD
M96YC>3$H)&1E<"P@)'!A<F%M<RDI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1F86EL960@/2!T<G5E.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG
M<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/FQO9R@P+"`D92T^9V5T365S<V%G92@I*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D92D@)B8@(21P87)A;2T^
M86QR96%D>59A;&ED871E9"@I*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=S;V9T)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^;&]G*#`L("1E6S!=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`D<&%R86US6R1I72T^<V5T5F%L:61A=&5D
M*"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D
M9F%I;&5D*2![#0H@("`@("`@("`@("`@("`@("`@("1H87-F86EL960@/2!T
M<G5E.PT*("`@("`@("`@("`@("`@("`@("`D<&%R86US6R1I72`](&9A;'-E
M.PT*("`@("`@("`@("`@("`@("`@("`D<F5S970@/2!T<G5E.PT*("`@("`@
M("`@("`@("`@("`@("`D<F5D;R`]('1R=64[#0H@("`@("`@("`@("`@("`@
M("`@("1F86EL960@/2!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@4$5!
M4E]$;W=N;&]A9&5R7U!A8VMA9V4Z.G)E;6]V941U<&QI8V%T97,H)'!A<F%M
M<RD[#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E(#([#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@:68@
M*"1H87-F86EL960@)B8@*&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG:6=N;W)E
M+65R<F]R<R==*2!\?`T*("`@("`@("`@("`@("!I<W-E="@D=&AI<RT^7V]P
M=&EO;G-;)VYO9&5P<R==*2DI('L-"B`@("`@("`@("`@("\O('1H:7,@:7,@
M<')O8F%B;'D@;F]T(&YE961E9"P@8G5T(&IU<W0@:6X@8V%S90T*("`@("`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)W-O9G0G72DI('L-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("=705).24Y'.B!D97!E
M;F1E;F-I97,@9F%I;&5D)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!2971R:65V92!T:&4@9&ER96-T
M;W)Y('1H870@9&]W;FQO861S('=I;&P@:&%P<&5N(&EN#0H@("`@("H@0&%C
M8V5S<R!P<FEV871E#0H@("`@("H@0')E='5R;B!S=')I;F<-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!G971$;W=N;&]A9$1I<B@I#0H@("`@>PT*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]D;W=N;&]A9$1I<BDI('L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7V1O=VYL;V%D1&ER.PT*("`@("`@("!]#0H@
M("`@("`@("1D;W=N;&]A9&1I<B`]("1T:&ES+3YC;VYF:6<M/F=E="@G9&]W
M;FQO861?9&ER)RD[#0H@("`@("`@(&EF("AE;7!T>2@D9&]W;FQO861D:7(I
M*2![#0H@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4WES=&5M)RDI
M('L-"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U-Y<W1E;2YP:'`G
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&1O=VYL;V%D9&ER(#T@4WES=&5M.CIM:W1E;7`H)RUD)RDI*2![#0H@
M("`@("`@("`@("`@("`@<F5T=7)N("1D;W=N;&]A9&1I<CL-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("1T:&ES+3YL;V<H,RP@)RL@=&UP(&1I<B!C
M<F5A=&5D(&%T("<@+B`D9&]W;FQO861D:7(I.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B`D=&AI<RT^7V1O=VYL;V%D1&ER(#T@)&1O=VYL;V%D9&ER
M.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=$1O=VYL;V%D1&ER*"1D:7(I
M#0H@("`@>PT*("`@("`@("`D=&AI<RT^7V1O=VYL;V%D1&ER(#T@)&1I<CL-
M"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8V]N9FEG4V5T*"D-
M"B`@("!F=6YC=&EO;B!C;VYF:6=3970H)&ME>2P@)'9A;'5E+"`D;&%Y97(@
M/2`G=7-E<B<L("1C:&%N;F5L(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D
M=&AI<RT^8V]N9FEG+3YS970H)&ME>2P@)'9A;'5E+"`D;&%Y97(L("1C:&%N
M;F5L*3L-"B`@("`@("`@)'1H:7,M/E]P<F5F97)R9613=&%T92`]("1T:&ES
M+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D7W-T871E)RP@;G5L;"P@)&-H86YN
M96PI.PT*("`@("`@("!I9B`H(21T:&ES+3Y?<')E9F5R<F5D4W1A=&4I('L-
M"B`@("`@("`@("`@("\O(&1O;B=T(&EN861V97)T86YT;'D@=7-E(&$@;F]N
M+7-E="!P<F5F97)R961?<W1A=&4-"B`@("`@("`@("`@("1T:&ES+3Y?<')E
M9F5R<F5D4W1A=&4@/2!N=6QL.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H@("`@+R\@>WM[('-E=$]P=&EO;G,H*0T*("`@(&9U;F-T:6]N
M('-E=$]P=&EO;G,H)&]P=&EO;G,I#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M7V]P=&EO;G,@/2`D;W!T:6]N<SL-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@
M("`O+R![>WL@<V5T3W!T:6]N<R@I#0H@("`@9G5N8W1I;VX@9V5T3W!T:6]N
M<R@I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/E]O<'1I;VYS.PT*
M("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@+RHJ#0H@("`@("H@1F]R('-I
M;7!L97(@=6YI="UT97-T:6YG#0H@("`@("H@0'!A<F%M(%!%05)?0V]N9FEG
M#0H@("`@("H@0'!A<F%M(&EN=`T*("`@("`J($!P87)A;2!S=')I;F<-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B`F9V5T4&%C:V%G969I;&5/8FIE8W0H)B1C
M+"`D9"P@)'0@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@A8VQA<W-?
M97AI<W1S*"=014%27U!A8VMA9V5&:6QE)RDI('L-"B`@("`@("`@("`@(')E
M<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL92YP:'`G.PT*("`@("`@("!]
M#0H@("`@("`@("1A(#T@)FYE=R!014%27U!A8VMA9V5&:6QE*"1C+"`D9"P@
M)'0I.PT*("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*#0H@("`@+R\@>WM[
M(%]G971086-K86=E1&]W;FQO8615<FPH*0T*#0H@("`@+RHJ#0H@("`@("H@
M0'!A<F%M(&%R<F%Y(&]U='!U="!O9B![0&QI;FL@<&%R<V5086-K86=E3F%M
M92@I?0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(%]G971086-K86=E1&]W;FQO8615<FPH)'!A<G(I#0H@("`@>PT*
M("`@("`@("`D8W5R8VAA;FYE;"`]("1T:&ES+3YC;VYF:6<M/F=E="@G9&5F
M875L=%]C:&%N;F5L)RD[#0H@("`@("`@("1T:&ES+3YC;VYF:6=3970H)V1E
M9F%U;'1?8VAA;FYE;"<L("1P87)R6R=C:&%N;F5L)UTI.PT*("`@("`@("`O
M+R!G971$;W=N;&]A9%523"!R971U<FYS(&%N(&%R<F%Y+B`@3VX@97)R;W(L
M(&ET(&]N;'D@8V]N=&%I;G,@:6YF;W)M871I;VX-"B`@("`@("`@+R\@;VX@
M=&AE(&QA=&5S="!R96QE87-E(&%S(&%R<F%Y*'9E<G-I;VXL(&EN9F\I+B`@
M3VX@<W5C8V5S<R!I="!C;VYT86EN<PT*("`@("`@("`O+R!A<G)A>2AV97)S
M:6]N+"!I;F9O+"!D;W=N;&]A9"!U<FP@<W1R:6YG*0T*("`@("`@("`D<W1A
M=&4@/2!I<W-E="@D<&%R<ELG<W1A=&4G72D@/R`D<&%R<ELG<W1A=&4G72`Z
M("1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D7W-T871E)RD[#0H@("`@
M("`@(&EF("@A)'1H:7,M/E]R96=I<W1R>2T^8VAA;FYE;$5X:7-T<R@D<&%R
M<ELG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@9&\@>PT*("`@("`@("`@
M("`@("`@(&EF("@D=&AI<RT^8V]N9FEG+3YG970H)V%U=&]?9&ES8V]V97(G
M*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F1I<V-O=F5R
M*"1P87)R6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`D=&AI<RT^8V]N9FEG4V5T*"=D969A
M=6QT7V-H86YN96PG+"`D8W5R8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U5N:VYO=VX@<F5M;W1E(&-H86YN
M96PZ("<@+B`D<F5M;W1E8VAA;FYE;"D[#0H@("`@("`@("`@("!]('=H:6QE
M("AF86QS92D[#0H@("`@("`@('T-"B`@("`@("`@)&-H86X@/2`F)'1H:7,M
M/E]R96=I<W1R>2T^9V5T0VAA;FYE;"@D<&%R<ELG8VAA;FYE;"==*3L-"B`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)&-H86XI*2![#0H@("`@("`@("`@
M("!R971U<FX@)&-H86X[#0H@("`@("`@('T-"B`@("`@("`@)'9E<G-I;VX@
M/2`D=&AI<RT^7W)E9VES=')Y+3YP86-K86=E26YF;R@D<&%R<ELG<&%C:V%G
M92==+"`G=F5R<VEO;B<L#0H@("`@("`@("`@("`D<&%R<ELG8VAA;FYE;"==
M*3L-"B`@("`@("`@:68@*"1C:&%N+3YS=7!P;W)T<U)%4U0H)'1H:7,M/F-O
M;F9I9RT^9V5T*"=P<F5F97)R961?;6ER<F]R)RDI("8F#0H@("`@("`@("`@
M("`@("1B87-E(#T@)&-H86XM/F=E=$)A<V554DPH)U)%4U0Q+C`G+"`D=&AI
M<RT^8V]N9FEG+3YG970H)W!R969E<G)E9%]M:7)R;W(G*2DI('L-"B`@("`@
M("`@("`@("1R97-T(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)%4U0H)S$N,"<L
M("1T:&ES+3Y?;W!T:6]N<RD[#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1P
M87)R6R=V97)S:6]N)UTI("8F("%I<W-E="@D<&%R<ELG<W1A=&4G72D@)B8@
M)'9E<G-I;VX-"B`@("`@("`@("`@("`@("`@("8F("%I<W-E="@D=&AI<RT^
M7V]P=&EO;G-;)V1O=VYL;V%D;VYL>2==*2D@>PT*("`@("`@("`@("`@("`@
M("1U<FP@/2`D<F5S="T^9V5T1&]W;FQO86154DPH)&)A<V4L("1P87)R+"`D
M<W1A=&4L("1V97)S:6]N*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@)'5R;"`]("1R97-T+3YG971$;W=N;&]A9%523"@D8F%S
M92P@)'!A<G(L("1S=&%T92P@9F%L<V4I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'5R;"DI('L-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^8V]N9FEG4V5T*"=D969A=6QT7V-H86YN96PG+"`D
M8W5R8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@<F5T=7)N("1U<FP[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)'!A<G);)V-H86YN96PG
M72`A/2`D8W5R8VAA;FYE;"D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YC
M;VYF:6=3970H)V1E9F%U;'1?8VAA;FYE;"<L("1C=7)C:&%N;F5L*3L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)'5R;"DI
M('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'5R;#L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("1U<FQ;)W)A=R==(#T@9F%L<V4[("\O(&YO(&-H
M96-K:6YG(&ES(&YE8V5S<V%R>2!F;W(@4D535`T*("`@("`@("`@("`@:68@
M*"%I<U]A<G)A>2@D=7)L6R=I;F9O)UTI*2![#0H@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TEN=F%L:60@<F5M;W1E(&1E<&5N
M9&5N8VEE<R!R971R:65V960@9G)O;2!215-4("T@)R`N#0H@("`@("`@("`@
M("`@("`@("`@("=T:&ES('-H;W5L9"!N979E<B!H87!P96XG*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D=7)L6R=I;F9O)UU;
M)W)E<75I<F5D)UTI('Q\("1U<FQ;)V-O;7!A=&EB;&4G72D@>PT*("`@("`@
M("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL92]V,BYP
M:'`G.PT*("`@("`@("`@("`@("`@("1P9B`](&YE=R!014%27U!A8VMA9V5&
M:6QE7W8R.PT*("`@("`@("`@("`@("`@("1P9BT^<V5T4F%W0VAA;FYE;"@D
M<&%R<ELG8VAA;FYE;"==*3L-"B`@("`@("`@("`@("`@("!I9B`H)'5R;%LG
M8V]M<&%T:6)L92==*2![#0H@("`@("`@("`@("`@("`@("`@("1P9BT^<V5T
M4F%W0V]M<&%T:6)L92@D=7)L6R=C;VUP871I8FQE)UTI.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E("=014%2+U!A8VMA9V5&:6QE+W8Q+G!H<"<[#0H@
M("`@("`@("`@("`@("`@)'!F(#T@;F5W(%!%05)?4&%C:V%G949I;&5?=C$[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<&8M/G-E=%)A=U!A8VMA
M9V4H)'5R;%LG<&%C:V%G92==*3L-"B`@("`@("`@("`@("1P9BT^<V5T1&5P
M<R@D=7)L6R=I;F9O)UTI.PT*("`@("`@("`@("`@)'!F+3YS971287=3=&%T
M92@D=7)L6R=S=&%B:6QI='DG72D[#0H@("`@("`@("`@("`D=7)L6R=I;F9O
M)UT@/2`F)'!F.PT*("`@("`@("`@("`@:68@*"%E>'1E;G-I;VY?;&]A9&5D
M*")Z;&EB(BD@?'P@:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V-O;7!R97-S
M)UTI*2![#0H@("`@("`@("`@("`@("`@)&5X="`]("<N=&%R)SL-"B`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&5X="`]("<N=&=Z
M)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D
M=7)L*2D@>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=7)L6R=U<FPG
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'5R;%LG=7)L)UT@+CT@)&5X
M=#L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!R971U<FX@)'5R;#L-"B`@("`@("`@?2!E;'-E:68@*"1C:&%N+3YS
M=7!P;W)T<R@G>&UL<G!C)RP@)W!A8VMA9V4N9V5T1&]W;FQO86154DPG+"!F
M86QS92P@)S$N,2<I*2![#0H@("`@("`@("`@("`O+R!D;VXG="!I;G-T86QL
M('=I=&@@=&AE(&]L9"!V97)S:6]N(&EN9F]R;6%T:6]N('5N;&5S<R!W92=R
M92!D;VEN9R!A('!L86EN#0H@("`@("`@("`@("`O+R!V86YI;&QA('-I;7!L
M92!I;G-T86QL871I;VXN("!)9B!T:&4@=7-E<B!S87ES('1O(&EN<W1A;&P@
M82!P87)T:6-U;&%R#0H@("`@("`@("`@("`O+R!V97)S:6]N(&]R('-T871E
M+"!I9VYO<F4@=&AE(&-U<G)E;G0@:6YS=&%L;&5D('9E<G-I;VX-"B`@("`@
M("`@("`@(&EF("@A:7-S970H)'!A<G);)W9E<G-I;VXG72D@)B8@(6ES<V5T
M*"1P87)R6R=S=&%T92==*2`F)B`D=F5R<VEO;@T*("`@("`@("`@("`@("`@
M("`@)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9&]W;FQO861O;FQY)UTI
M*2![#0H@("`@("`@("`@("`@("`@)'5R;"`]("1T:&ES+3Y?<F5M;W1E+3YC
M86QL*"=P86-K86=E+F=E=$1O=VYL;V%D55),)RP@)'!A<G(L("1S=&%T92P@
M)'9E<G-I;VXI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`D=7)L(#T@)'1H:7,M/E]R96UO=&4M/F-A;&PH)W!A8VMA9V4N9V5T
M1&]W;FQO86154DPG+"`D<&%R<BP@)'-T871E*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1U<FP@/2`D=&AI<RT^
M7W)E;6]T92T^8V%L;"@G<&%C:V%G92YG971$;W=N;&]A9%523"<L("1P87)R
M+"`D<W1A=&4I.PT*("`@("`@("!]#0H@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1U<FPI*2![#0H@("`@("`@("`@("!R971U<FX@)'5R;#L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H)'!A<G);)V-H86YN96PG72`A/2`D8W5R8VAA
M;FYE;"D@>PT*("`@("`@("`@("`@)'1H:7,M/F-O;F9I9U-E="@G9&5F875L
M=%]C:&%N;F5L)RP@)&-U<F-H86YN96PI.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("AI<W-E="@D=7)L6R=?7U!%05)?15)23U)?0TQ!4U-?7R==*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)'5R;%LG;65S
M<V%G92==*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1U
M<FPI*2![#0H@("`@("`@("`@("!R971U<FX@)'5R;#L-"B`@("`@("`@?0T*
M("`@("`@("`D=7)L6R=R87<G72`]("1U<FQ;)VEN9F\G73L-"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9&]W;FQO861O;FQY)UTI*2![
M#0H@("`@("`@("`@("`D<&MG(#T@)B1T:&ES+3YG971086-K86=E9FEL94]B
M:F5C="@D=&AI<RT^8V]N9FEG+"`D=&AI<RT^9&5B=6<I.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@)'!K9R`]("8D=&AI<RT^9V5T4&%C:V%G
M969I;&5/8FIE8W0H)'1H:7,M/F-O;F9I9RP@)'1H:7,M/F1E8G5G+`T*("`@
M("`@("`@("`@("`@("1T:&ES+3YG971$;W=N;&]A9$1I<B@I*3L-"B`@("`@
M("`@?0T*("`@("`@("!014%2.CIS=&%T:6-0=7-H17)R;W)(86YD;&EN9RA0
M14%27T524D]27U)%5%523BD[#0H@("`@("`@("1P:6YF;R`]("8D<&MG+3YF
M<F]M6&UL4W1R:6YG*"1U<FQ;)VEN9F\G72P@4$5!4E]604Q)1$%415]$3U=.
M3$]!1$E.1RP@)W)E;6]T92<I.PT*("`@("`@("!014%2.CIS=&%T:6-0;W!%
M<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1P
M:6YF;RDI('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I
M;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P
M+"`D<&EN9F\M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4F5M;W1E('!A8VMA
M9V4N>&UL(&ES(&YO="!V86QI9"`M('1H:7,@<VAO=6QD(&YE=F5R(&AA<'!E
M;B<I.PT*("`@("`@("!]#0H@("`@("`@("1U<FQ;)VEN9F\G72`]("8D<&EN
M9F\[#0H@("`@("`@(&EF("@A97AT96YS:6]N7VQO861E9"@B>FQI8B(I('Q\
M(&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]C;VUP<F5S<R==*2D@>PT*("`@
M("`@("`@("`@)&5X="`]("<N=&%R)SL-"B`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("1E>'0@/2`G+G1G>B<[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES7V%R<F%Y*"1U<FPI*2![#0H@("`@("`@("`@("!I9B`H:7-S970H
M)'5R;%LG=7)L)UTI*2![#0H@("`@("`@("`@("`@("`@)'5R;%LG=7)L)UT@
M+CT@)&5X=#L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@)'5R;#L-"B`@("!]#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E
M=$1E<%!A8VMA9V5$;W=N;&]A9%5R;"@I#0H-"B`@("`O*BH-"B`@("`@*B!`
M<&%R86T@87)R87D@9&5P96YD96YC>2!A<G)A>0T*("`@("`J($!A8V-E<W,@
M<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]G971$97!086-K86=E
M1&]W;FQO8615<FPH)&1E<"P@)'!A<G(I#0H@("`@>PT*("`@("`@("`D>'-D
M=F5R<VEO;B`](&ES<V5T*"1D97!;)W)E;"==*2`_("<Q+C`G(#H@)S(N,"<[
M#0H@("`@("`@("1C=7)C:&%N;F5L(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=D
M969A=6QT7V-H86YN96PG*3L-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)V-H
M86YN96PG72DI('L-"B`@("`@("`@("`@("1R96UO=&5C:&%N;F5L(#T@)&1E
M<%LG8VAA;FYE;"==.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M)')E;6]T96-H86YN96P@/2`G<&5A<BYP:'`N;F5T)SL-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H(21T:&ES+3Y?<F5G:7-T<GDM/F-H86YN96Q%>&ES=',H
M)')E;6]T96-H86YN96PI*2![#0H@("`@("`@("`@("!D;R![#0H@("`@("`@
M("`@("`@("`@:68@*"1T:&ES+3YC;VYF:6<M/F=E="@G875T;U]D:7-C;W9E
M<B<I*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^9&ES8V]V
M97(H)')E;6]T96-H86YN96PI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G56YK;F]W;B!R96UO=&4@8VAA;FYE;#H@)R`N("1R96UO=&5C:&%N;F5L
M*3L-"B`@("`@("`@("`@('T@=VAI;&4@*&9A;'-E*3L-"B`@("`@("`@?0T*
M("`@("`@("`D=&AI<RT^8V]N9FEG4V5T*"=D969A=6QT7V-H86YN96PG+"`D
M<F5M;W1E8VAA;FYE;"D[#0H@("`@("`@("1S=&%T92`](&ES<V5T*"1P87)R
M6R=S=&%T92==*2`_("1P87)R6R=S=&%T92==(#H@)'1H:7,M/F-O;F9I9RT^
M9V5T*"=P<F5F97)R961?<W1A=&4G*3L-"B`@("`@("`@:68@*&ES<V5T*"1P
M87)R6R=S=&%T92==*2`F)B!I<W-E="@D<&%R<ELG=F5R<VEO;B==*2D@>PT*
M("`@("`@("`@("`@=6YS970H)'!A<G);)W-T871E)UTI.PT*("`@("`@("!]
M#0H@("`@("`@("1C:&%N(#T@)B1T:&ES+3Y?<F5G:7-T<GDM/F=E=$-H86YN
M96PH)')E;6]T96-H86YN96PI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D8VAA;BDI('L-"B`@("`@("`@("`@(')E='5R;B`D8VAA;CL-"B`@("`@
M("`@?0T*("`@("`@("`D=F5R<VEO;B`]("1T:&ES+3Y?<F5G:7-T<GDM/G!A
M8VMA9V5);F9O*"1D97!;)VYA;64G72P@)W9E<G-I;VXG+`T*("`@("`@("`@
M("`@)')E;6]T96-H86YN96PI.PT*("`@("`@("!I9B`H)&-H86XM/G-U<'!O
M<G1S4D535"@D=&AI<RT^8V]N9FEG+3YG970H)W!R969E<G)E9%]M:7)R;W(G
M*2D@)B8-"B`@("`@("`@("`@("`@)&)A<V4@/2`D8VAA;BT^9V5T0F%S9552
M3"@G4D535#$N,"<L("1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D7VUI
M<G)O<B<I*2D@>PT*("`@("`@("`@("`@)')E<W0@/2`F)'1H:7,M/F-O;F9I
M9RT^9V5T4D535"@G,2XP)RP@)'1H:7,M/E]O<'1I;VYS*3L-"B`@("`@("`@
M("`@("1U<FP@/2`D<F5S="T^9V5T1&5P1&]W;FQO86154DPH)&)A<V4L("1X
M<V1V97)S:6]N+"`D9&5P+"`D<&%R<BP-"B`@("`@("`@("`@("`@("`@("`@
M)'-T871E+"`D=F5R<VEO;BD[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D=7)L*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=7)L.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1P87)R6R=C:&%N;F5L
M)UT@(3T@)&-U<F-H86YN96PI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M8V]N9FEG4V5T*"=D969A=6QT7V-H86YN96PG+"`D8W5R8VAA;FYE;"D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1U<FPI
M*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1U<FP[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`D=7)L6R=R87<G72`](&9A;'-E.R`O+R!N;R!C
M:&5C:VEN9R!I<R!N96-E<W-A<GD@9F]R(%)%4U0-"B`@("`@("`@("`@(&EF
M("@A:7-?87)R87DH)'5R;%LG:6YF;R==*2D@>PT*("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*"=);G9A;&ED(')E;6]T92!D97!E
M;F1E;F-I97,@<F5T<FEE=F5D(&9R;VT@4D535"`M("<@+@T*("`@("`@("`@
M("`@("`@("`@("`G=&AI<R!S:&]U;&0@;F5V97(@:&%P<&5N)RD[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)'5R;%LG:6YF;R==
M6R=R97%U:7)E9"==*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A8VQA<W-?
M97AI<W1S*"=014%27U!A8VMA9V5&:6QE7W8R)RDI('L-"B`@("`@("`@("`@
M("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+U!A8VMA9V5&:6QE+W8R+G!H
M<"<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1P9B`]
M(&YE=R!014%27U!A8VMA9V5&:6QE7W8R.PT*("`@("`@("`@("`@("`@("1P
M9BT^<V5T4F%W0VAA;FYE;"@D<F5M;W1E8VAA;FYE;"D[#0H@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S
M*"=014%27U!A8VMA9V5&:6QE7W8Q)RDI('L-"B`@("`@("`@("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E("=014%2+U!A8VMA9V5&:6QE+W8Q+G!H<"<[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1P9B`](&YE=R!0
M14%27U!A8VMA9V5&:6QE7W8Q.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@)'!F+3YS971287=086-K86=E*"1U<FQ;)W!A8VMA9V4G72D[#0H@("`@
M("`@("`@("`D<&8M/G-E=$1E<',H)'5R;%LG:6YF;R==*3L-"B`@("`@("`@
M("`@("1P9BT^<V5T4F%W4W1A=&4H)'5R;%LG<W1A8FEL:71Y)UTI.PT*("`@
M("`@("`@("`@)'5R;%LG:6YF;R==(#T@)B1P9CL-"B`@("`@("`@("`@(&EF
M("@A97AT96YS:6]N7VQO861E9"@B>FQI8B(I('Q\(&ES<V5T*"1T:&ES+3Y?
M;W!T:6]N<ULG;F]C;VUP<F5S<R==*2D@>PT*("`@("`@("`@("`@("`@("1E
M>'0@/2`G+G1A<B<[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("1E>'0@/2`G+G1G>B<[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!I9B`H:7-?87)R87DH)'5R;"DI('L-"B`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)'5R;%LG=7)L)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("1U<FQ;)W5R;"==("X]("1E>'0[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N("1U<FP[#0H@("`@("`@
M('T@96QS96EF("@D8VAA;BT^<W5P<&]R=',H)WAM;')P8R<L("=P86-K86=E
M+F=E=$1E<$1O=VYL;V%D55),)RP@9F%L<V4L("<Q+C$G*2D@>PT*("`@("`@
M("`@("`@:68@*"1V97)S:6]N*2![#0H@("`@("`@("`@("`@("`@)'5R;"`]
M("1T:&ES+3Y?<F5M;W1E+3YC86QL*"=P86-K86=E+F=E=$1E<$1O=VYL;V%D
M55),)RP@)'AS9'9E<G-I;VXL("1D97`L("1P87)R+`T*("`@("`@("`@("`@
M("`@("`@("`D<W1A=&4L("1V97)S:6]N*3L-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@)'5R;"`]("1T:&ES+3Y?<F5M;W1E+3YC
M86QL*"=P86-K86=E+F=E=$1E<$1O=VYL;V%D55),)RP@)'AS9'9E<G-I;VXL
M("1D97`L("1P87)R+`T*("`@("`@("`@("`@("`@("`@("`D<W1A=&4I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M)'5R;"`]("1T:&ES+3Y?<F5M;W1E+3YC86QL*"=P86-K86=E+F=E=$1E<$1O
M=VYL;V%D55),)RP@)'AS9'9E<G-I;VXL("1D97`L("1P87)R+"`D<W1A=&4I
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D<&%R<ELG8VAA;FYE;"==("$]
M("1C=7)C:&%N;F5L*2![#0H@("`@("`@("`@("`D=&AI<RT^8V]N9FEG4V5T
M*"=D969A=6QT7V-H86YN96PG+"`D8W5R8VAA;FYE;"D[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"%I<U]A<G)A>2@D=7)L*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1U<FP[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1U
M<FQ;)U]?4$5!4E]%4E)/4E]#3$%34U]?)UTI*2![#0H@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D=7)L6R=M97-S86=E)UTI.PT*("`@
M("`@("!]#0H@("`@("`@("1U<FQ;)W)A=R==(#T@)'5R;%LG:6YF;R==.PT*
M("`@("`@("`D<&MG(#T@)B1T:&ES+3YG971086-K86=E9FEL94]B:F5C="@D
M=&AI<RT^8V]N9FEG+"`D=&AI<RT^9&5B=6<I.PT*("`@("`@("!014%2.CIS
M=&%T:6-0=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@
M("`@("`@("1P:6YF;R`]("8D<&MG+3YF<F]M6&UL4W1R:6YG*"1U<FQ;)VEN
M9F\G72P@4$5!4E]604Q)1$%415]$3U=.3$]!1$E.1RP@)W)E;6]T92<I.PT*
M("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1P:6YF;RDI('L-"B`@("`@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`D<&EN9F\M/F=E=$UE<W-A9V4H
M*2D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G4F5M;W1E('!A8VMA9V4N>&UL(&ES(&YO="!V86QI9"`M
M('1H:7,@<VAO=6QD(&YE=F5R(&AA<'!E;B<I.PT*("`@("`@("!]#0H@("`@
M("`@("1U<FQ;)VEN9F\G72`]("8D<&EN9F\[#0H@("`@("`@(&EF("AI<U]A
M<G)A>2@D=7)L*2D@>PT*("`@("`@("`@("`@:68@*"%E>'1E;G-I;VY?;&]A
M9&5D*")Z;&EB(BD@?'P@:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V-O;7!R
M97-S)UTI*2![#0H@("`@("`@("`@("`@("`@)&5X="`]("<N=&%R)SL-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&5X="`]("<N
M=&=Z)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D
M=7)L6R=U<FPG72DI('L-"B`@("`@("`@("`@("`@("`D=7)L6R=U<FPG72`N
M/2`D97AT.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B`D=7)L.PT*("`@('T-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T
M4&%C:V%G941O=VYL;V%D57)L*"D-"@T*("`@("\J*@T*("`@("`J($!D97!R
M96-A=&5D(&EN(&9A=F]R(&]F(%]G971086-K86=E1&]W;FQO8615<FP-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!G971086-K86=E1&]W;FQO8615<FPH)'!A
M8VMA9V4L("1V97)S:6]N(#T@;G5L;"P@)&-H86YN96P@/2!F86QS92D-"B`@
M("![#0H@("`@("`@(&EF("@D=F5R<VEO;BD@>PT*("`@("`@("`@("`@)'!A
M8VMA9V4@+CT@(BTD=F5R<VEO;B([#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"1T:&ES(#T]/2!N=6QL('Q\("1T:&ES+3Y?<F5G:7-T<GD@/3T](&YU;&PI
M('L-"B`@("`@("`@("`@("1P86-K86=E(#T@(FAT='`Z+R]P96%R+G!H<"YN
M970O9V5T+R1P86-K86=E(CL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("1C:&%N(#T@)'1H:7,M/E]R96=I<W1R>2T^9V5T0VAA;FYE;"@D8VAA
M;FYE;"D[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VAA;BDI
M('L-"B`@("`@("`@("`@("`@("!R971U<FX@)R<[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`D<&%C:V%G92`](")H='1P.B\O(B`N("1C:&%N+3YG
M971397)V97(H*2`N("(O9V5T+R1P86-K86=E(CL-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H(65X=&5N<VEO;E]L;V%D960H(GIL:6(B*2D@>PT*("`@("`@
M("`@("`@)'!A8VMA9V4@+CT@)S]U;F-O;7!R97-S/7EE<R<[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N("1P86-K86=E.PT*("`@('T-"@T*("`@("\O
M('U]?0T*("`@("\O('M[>R!G971$;W=N;&]A9&5D4&%C:V%G97,H*0T*#0H@
M("`@+RHJ#0H@("`@("H@4F5T<FEE=F4@82!L:7-T(&]F(&1O=VYL;V%D960@
M<&%C:V%G97,@869T97(@82!C86QL('1O('M`;&EN:R!D;W=N;&]A9"@I?2X-
M"B`@("`@*@T*("`@("`J($%L<V\@<F5S971S('1H92!L:7-T(&]F(&1O=VYL
M;V%D960@<&%C:V%G97,N#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(&=E=$1O=VYL;V%D961086-K86=E<R@I#0H@("`@
M>PT*("`@("`@("`D<F5T(#T@)'1H:7,M/E]D;W=N;&]A9&5D4&%C:V%G97,[
M#0H@("`@("`@("1T:&ES+3Y?9&]W;FQO861E9%!A8VMA9V5S(#T@87)R87DH
M*3L-"B`@("`@("`@)'1H:7,M/E]T;T1O=VYL;V%D(#T@87)R87DH*3L-"B`@
M("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(%]D;W=N;&]A9$-A;&QB86-K*"D-"@T*("`@(&9U;F-T:6]N(%]D
M;W=N;&]A9$-A;&QB86-K*"1M<V<L("1P87)A;7,@/2!N=6QL*0T*("`@('L-
M"B`@("`@("`@<W=I=&-H("@D;7-G*2![#0H@("`@("`@("`@("!C87-E("=S
M879E87,G.@T*("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,2P@(F1O=VYL
M;V%D:6YG("1P87)A;7,@+BXN(BD[#0H@("`@("`@("`@("`@("`@8G)E86L[
M#0H@("`@("`@("`@("!C87-E("=D;VYE)SH-"B`@("`@("`@("`@("`@("`D
M=&AI<RT^;&]G*#$L("<N+BYD;VYE.B`G("X@;G5M8F5R7V9O<FUA="@D<&%R
M86US+"`P+"`G)RP@)RPG*2`N("<@8GET97,G*3L-"B`@("`@("`@("`@("`@
M("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)V)Y=&5S<F5A9"<Z#0H@("`@
M("`@("`@("`@("`@<W1A=&EC("1B>71E<SL-"B`@("`@("`@("`@("`@("!I
M9B`H96UP='DH)&)Y=&5S*2D@>PT*("`@("`@("`@("`@("`@("`@("`D8GET
M97,@/2`P.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I
M9B`H(2@D8GET97,@)2`Q,#(T,"DI('L-"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/FQO9R@Q+"`G+B<L(&9A;'-E*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)&)Y=&5S("L]("1P87)A;7,[#0H@("`@("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=S=&%R="<Z#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@Q+"`B4W1A<G1I;F<@=&\@9&]W
M;FQO860@>R1P87)A;7-;,%U]("@B+FYU;6)E<E]F;W)M870H)'!A<F%M<ULQ
M72P@,"P@)R<L("<L)RDN(B!B>71E<RDB*3L-"B`@("`@("`@("`@("`@("!B
M<F5A:SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H;65T:&]D7V5X:7-T<R@D
M=&AI<RT^=6DL("=?9&]W;FQO861#86QL8F%C:R<I*0T*("`@("`@("`@("`@
M)'1H:7,M/G5I+3Y?9&]W;FQO861#86QL8F%C:R@D;7-G+"`D<&%R86US*3L-
M"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7W!R97!E;F10871H
M*"1P871H+"`D<')E<&5N9"D-"@T*("`@(&9U;F-T:6]N(%]P<F5P96YD4&%T
M:"@D<&%T:"P@)'!R97!E;F0I#0H@("`@>PT*("`@("`@("!I9B`H<W1R;&5N
M*"1P<F5P96YD*2`^(#`I('L-"B`@("`@("`@("`@(&EF("A/4U]724Y$3U=3
M("8F('!R96=?;6%T8V@H)R]>6V$M>ETZ+VDG+"`D<&%T:"DI('L-"B`@("`@
M("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UY;82UZ73HO:2<L("1P<F5P
M96YD*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<')E<&5N9"`]('-U8G-T
M<B@D<')E<&5N9"P@,BD[#0H@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1P
M<F5P96YD>S!]("$]("=<7"<I('L-"B`@("`@("`@("`@("`@("`@("`@)'!R
M97!E;F0@/2`B7%PD<')E<&5N9"([#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("1P871H(#T@<W5B<W1R*"1P871H+"`P+"`R*2`N("1P
M<F5P96YD("X@<W5B<W1R*"1P871H+"`R*3L-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@)'!A=&@@/2`D<')E<&5N9"`N("1P871H
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D
M<&%T:#L-"B`@("!]#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[('!U<VA%<G)O
M<B@D97)R;7-G+"`D8V]D92D-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S
M=')I;F<-"B`@("`@*B!`<&%R86T@:6YT96=E<@T*("`@("`J+PT*("`@(&9U
M;F-T:6]N('!U<VA%<G)O<B@D97)R;7-G+"`D8V]D92`]("TQ*0T*("`@('L-
M"B`@("`@("`@87)R87E?<'5S:"@D=&AI<RT^7V5R<F]R4W1A8VLL(&%R<F%Y
M*"1E<G)M<V<L("1C;V1E*2D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(&=E=$5R<F]R37-G<R@I#0H-"B`@("!F=6YC=&EO;B!G971%<G)O
M<DUS9W,H*0T*("`@('L-"B`@("`@("`@)&US9W,@/2!A<G)A>2@I.PT*("`@
M("`@("`D97)R<R`]("1T:&ES+3Y?97)R;W)3=&%C:SL-"B`@("`@("`@9F]R
M96%C:"`H)&5R<G,@87,@)&5R<BD@>PT*("`@("`@("`@("`@)&US9W-;72`]
M("1E<G);,%T[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]E<G)O<E-T
M86-K(#T@87)R87DH*3L-"B`@("`@("`@<F5T=7)N("1M<V=S.PT*("`@('T-
M"@T*("`@("\O('U]?0T*#0H@("`@+RHJ#0H@("`@("H@9F]R($)##0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@<V]R=%!K9T1E<',H)B1P86-K86=E<RP@)'5N
M:6YS=&%L;"`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)'5N:6YS=&%L;"`_
M(`T*("`@("`@("`@("`@)'1H:7,M/G-O<G1086-K86=E<T9O<E5N:6YS=&%L
M;"@D<&%C:V%G97,I(#H-"B`@("`@("`@("`@("1T:&ES+3YS;W)T4&%C:V%G
M97-&;W));G-T86QL*"1P86-K86=E<RD[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@7V=E=$1E<%1R965$4"@D<&%C:V%G92P@)'!A8VMA9V5S+"`F)&1E<',L
M("8D8VAE8VME9"D-"B`@("![#0H@("`@("`@("1P9B`]("1P86-K86=E+3YG
M971086-K86=E1FEL92@I.PT*("`@("`@("`D8VAE8VME9%MS=')T;VQO=V5R
M*"1P86-K86=E+3YG971#:&%N;F5L*"DI75MS=')T;VQO=V5R*"1P86-K86=E
M+3YG971086-K86=E*"DI70T*("`@("`@("`@("`@/2!T<G5E.PT*("`@("`@
M("`D<&1E<',@/2`D<&8M/F=E=$1E<',H=')U92D[#0H@("`@("`@(&EF("@A
M)'!D97!S*2![#0H@("`@("`@("`@("!R971U<FX[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"1P9BT^9V5T4&%C:V%G97AM;%9E<G-I;VXH*2`]/2`G,2XP
M)RD@>PT*("`@("`@("`@("`@9F]R96%C:"`H)'!D97!S(&%S("1D97`I('L-
M"B`@("`@("`@("`@("`@("!I9B`H)&1E<%LG='EP92==("$]("=P:V<G*2![
M#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`D9&5P<ULG<&5A<BYP:'`N;F5T)UU;
M<W1R=&]L;W=E<B@D9&5P6R=N86UE)UTI72`]('1R=64[#0H@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)'!A8VMA9V5S(&%S("1P*2![#0H@("`@("`@("`@
M("`@("`@("`@("1D97!;)V-H86YN96PG72`]("=P96%R+G!H<"YN970G.PT*
M("`@("`@("`@("`@("`@("`@("`D9&5P6R=P86-K86=E)UT@/2`D9&5P6R=N
M86UE)UT[#0H@("`@("`@("`@("`@("`@("`@(&EF("@D<"T^:7-%<75A;"@D
M9&5P*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M8VAE8VME9%MS=')T;VQO=V5R*"1P+3YG971#:&%N;F5L*"DI70T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@6W-T<G1O;&]W97(H)'`M/F=E=%!A
M8VMA9V4H*2E=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O
M(&%D9"!T:&4@9&5P96YD96YC>2=S(&1E<&5N9&5N8VEE<R!T;R!T:&4@=')E
M90T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T1&5P
M5')E9410*"1P+"`D<&%C:V%G97,L("1D97!S+"`D8VAE8VME9"D[#0H@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`D=&1E<',@/2!A<G)A>2@I.PT*("`@("`@
M("`@("`@:68@*&ES<V5T*"1P9&5P<ULG<F5Q=6ER960G75LG<&%C:V%G92==
M*2D@>PT*("`@("`@("`@("`@("`@("1T(#T@)'!D97!S6R=R97%U:7)E9"==
M6R=P86-K86=E)UT[#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=%LP
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'0@/2!A<G)A>2@D="D[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T9&5P<R`](&%R
M<F%Y7VUE<F=E*"1T9&5P<RP@)'0I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@:68@*&ES<V5T*"1P9&5P<ULG<F5Q=6ER960G75LG<W5B<&%C:V%G
M92==*2D@>PT*("`@("`@("`@("`@("`@("1T(#T@)'!D97!S6R=R97%U:7)E
M9"==6R=S=6)P86-K86=E)UT[#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D=%LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'0@/2!A<G)A>2@D
M="D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T9&5P
M<R`](&%R<F%Y7VUE<F=E*"1T9&5P<RP@)'0I.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*&ES<V5T*"1P9&5P<ULG;W!T:6]N86PG75LG<&%C
M:V%G92==*2D@>PT*("`@("`@("`@("`@("`@("1T(#T@)'!D97!S6R=O<'1I
M;VYA;"==6R=P86-K86=E)UT[#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D=%LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'0@/2!A<G)A>2@D
M="D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T9&5P
M<R`](&%R<F%Y7VUE<F=E*"1T9&5P<RP@)'0I.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*&ES<V5T*"1P9&5P<ULG;W!T:6]N86PG75LG<W5B
M<&%C:V%G92==*2D@>PT*("`@("`@("`@("`@("`@("1T(#T@)'!D97!S6R=O
M<'1I;VYA;"==6R=S=6)P86-K86=E)UT[#0H@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D=%LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'0@/2!A
M<G)A>2@D="D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("1T9&5P<R`](&%R<F%Y7VUE<F=E*"1T9&5P<RP@)'0I.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1P9&5P<ULG9W)O=7`G72DI
M('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1P9&5P<ULG9W)O=7`G
M75LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'!D97!S6R=G<F]U<"==
M(#T@87)R87DH)'!D97!S6R=G<F]U<"==*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!D97!S6R=G<F]U<"==(&%S
M("1G<F]U<"D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&=R
M;W5P6R=P86-K86=E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M="`]("1G<F]U<%LG<&%C:V%G92==.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D=%LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D="`](&%R<F%Y*"1T*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1T9&5P<R`](&%R<F%Y
M7VUE<F=E*"1T9&5P<RP@)'0I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9W)O=7!;)W-U8G!A8VMA
M9V4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T(#T@)&=R;W5P
M6R=S=6)P86-K86=E)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1T6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T(#T@87)R87DH)'0I.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1D97!S(#T@87)R87E?;65R9V4H
M)'1D97!S+"`D="D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E86-H
M("@D=&1E<',@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)&1E<%LG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M9&5P8VAA;FYE;"`]("=?7W5R:2<[#0H@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@)&1E<&-H86YN96P@/2`D9&5P6R=C
M:&%N;F5L)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("1D97!S6R1D97!C:&%N;F5L75MS=')T;VQO=V5R*"1D97!;)VYA;64G72E=
M(#T@=')U93L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D<&%C:V%G97,@
M87,@)'`I('L-"B`@("`@("`@("`@("`@("`@("`@)&1E<%LG8VAA;FYE;"==
M(#T@)&1E<&-H86YN96P[#0H@("`@("`@("`@("`@("`@("`@("1D97!;)W!A
M8VMA9V4G72`]("1D97!;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"1P+3YI<T5Q=6%L*"1D97`I*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1C:&5C:V5D6W-T<G1O;&]W97(H)'`M/F=E=$-H
M86YN96PH*2E=#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!;<W1R
M=&]L;W=E<B@D<"T^9V5T4&%C:V%G92@I*5TI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@861D('1H92!D97!E;F1E;F-Y)W,@9&5P96YD
M96YC:65S('1O('1H92!T<F5E#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]G971$97!4<F5E1%`H)'`L("1P86-K86=E<RP@)&1E<',L
M("1C:&5C:V5D*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J(%-O
M<G0@82!L:7-T(&]F(&%R<F%Y<R!O9B!A<G)A>2AD;W=N;&]A9&5D('!A8VMA
M9V5F:6QE;F%M92D@8GD@9&5P96YD96YC>2X-"B`@("`@*@T*("`@("`J($ET
M(&%L<V\@<F5M;W9E<R!D=7!L:6-A=&4@9&5P96YD96YC:65S#0H@("`@("H@
M0'!A<F%M(&%R<F%Y(&%N(&%R<F%Y(&]F(&1O=VYL;V%D960@4$5!4E]$;W=N
M;&]A9&5R7U!A8VMA9V5S#0H@("`@("H@0')E='5R;B!A<G)A>2!A<G)A>2!O
M9B!A<G)A>2AP86-K86=E9FEL96YA;64L('!A8VMA9V4N>&UL(&-O;G1E;G1S
M*0T*("`@("`J+PT*("`@(&9U;F-T:6]N('-O<G1086-K86=E<T9O<DEN<W1A
M;&PH)B1P86-K86=E<RD-"B`@("![#0H@("`@("`@(&9O<F5A8V@@*"1P86-K
M86=E<R!A<R`D:2`]/B`D<&%C:V%G92D@>PT*("`@("`@("`@("`@)&-H96-K
M960@/2`D9&5P<R`](&%R<F%Y*"D[#0H@("`@("`@("`@("`D=&AI<RT^7V=E
M=$1E<%1R965$4"@D<&%C:V%G97-;)&E=+"`D<&%C:V%G97,L("1D97!S+"`D
M8VAE8VME9"D[#0H@("`@("`@("`@("`D=&AI<RT^7V1E<%1R965;)'!A8VMA
M9V4M/F=E=$-H86YN96PH*5U;)'!A8VMA9V4M/F=E=%!A8VMA9V4H*5T@/2`D
M9&5P<SL-"B`@("`@("`@?0T*("`@("`@("!U<V]R="@D<&%C:V%G97,L(&%R
M<F%Y*"8D=&AI<RP@)U]S;W)T26YS=&%L;"<I*3L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!?9&5P96YD<T]N*"1A+"`D8BD-"B`@("![#0H@("`@("`@(')E
M='5R;B`D=&AI<RT^7V-H96-K1&5P5')E92AS=')T;VQO=V5R*"1A+3YG971#
M:&%N;F5L*"DI+"!S=')T;VQO=V5R*"1A+3YG971086-K86=E*"DI+`T*("`@
M("`@("`@("`@)&(I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]C:&5C:T1E
M<%1R964H)&-H86YN96PL("1P86-K86=E+"`D8BP@)&-H96-K960@/2!A<G)A
M>2@I*0T*("`@('L-"B`@("`@("`@)&-H96-K961;)&-H86YN96Q=6R1P86-K
M86=E72`]('1R=64[#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]D97!4
M<F5E6R1C:&%N;F5L75LD<&%C:V%G95TI*2![#0H@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?9&5P5')E95LD8VAA;FYE;%U;)'!A8VMA9V5=6W-T<G1O;&]W97(H)&(M
M/F=E=$-H86YN96PH*2E=#0H@("`@("`@("`@("`@(%MS=')T;VQO=V5R*"1B
M+3YG971086-K86=E*"DI72DI('L-"B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?9&5P5')E
M95LD8VAA;FYE;%U;)'!A8VMA9V5=(&%S("1C:"`]/B`D<&%C:V%G97,I('L-
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1P86-K86=E<R!A<R`D<&$@/3X@)'1R
M=64I('L-"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]C:&5C:T1E<%1R
M964H)&-H+"`D<&$L("1B+"`D8VAE8VME9"DI('L-"B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("!]#0H-"B`@("!F=6YC=&EO;B!?<V]R=$EN<W1A;&PH)&$L("1B*0T*("`@
M('L-"B`@("`@("`@:68@*"$D82T^9V5T1&5P<R@I("8F("$D8BT^9V5T1&5P
M<R@I*2![#0H@("`@("`@("`@("!R971U<FX@,#L@+R\@;F5I=&AE<B!P86-K
M86=E(&AA<R!D97!E;F1E;F-I97,L(&]R9&5R(&ES(&EN<VEG;FEF:6-A;G0-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)&$M/F=E=$1E<',H*2`F)B`A)&(M
M/F=E=$1E<',H*2D@>PT*("`@("`@("`@("`@<F5T=7)N(#$[("\O("1A(&UU
M<W0@8F4@:6YS=&%L;&5D(&%F=&5R("1B(&)E8V%U<V4@)&$@:&%S(&1E<&5N
M9&5N8VEE<PT*("`@("`@("!]#0H@("`@("`@(&EF("@A)&$M/F=E=$1E<',H
M*2`F)B`D8BT^9V5T1&5P<R@I*2![#0H@("`@("`@("`@("!R971U<FX@+3$[
M("\O("1B(&UU<W0@8F4@:6YS=&%L;&5D(&%F=&5R("1A(&)E8V%U<V4@)&(@
M:&%S(&1E<&5N9&5N8VEE<PT*("`@("`@("!]#0H@("`@("`@("\O(&)O=&@@
M<&%C:V%G97,@:&%V92!D97!E;F1E;F-I97,-"B`@("`@("`@:68@*"1T:&ES
M+3Y?9&5P96YD<T]N*"1A+"`D8BDI('L-"B`@("`@("`@("`@(')E='5R;B`Q
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D=&AI<RT^7V1E<&5N9'-/;B@D
M8BP@)&$I*2![#0H@("`@("`@("`@("!R971U<FX@+3$[#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N(#`[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M1&]W;FQO860@82!F:6QE('1H<F]U9V@@2%144"X@($-O;G-I9&5R<R!S=6=G
M97-T960@9FEL92!N86UE(&EN#0H@("`@("H@0V]N=&5N="UD:7-P;W-I=&EO
M;CH@:&5A9&5R(&%N9"!C86X@<G5N(&$@8V%L;&)A8VL@9G5N8W1I;VX@9F]R
M#0H@("`@("H@9&EF9F5R96YT(&5V96YT<RX@(%1H92!C86QL8F%C:R!W:6QL
M(&)E(&-A;&QE9"!W:71H('1W;PT*("`@("`J('!A<F%M971E<G,Z('1H92!C
M86QL8F%C:R!T>7!E+"!A;F0@<&%R86UE=&5R<RX@(%1H92!I;7!L96UE;G1E
M9`T*("`@("`J(&-A;&QB86-K('1Y<&5S(&%R93H-"B`@("`@*@T*("`@("`J
M("`G<V5T=7`G("`@("`@(&-A;&QE9"!A="!T:&4@=F5R>2!B96=I;FYI;F<L
M('!A<F%M971E<B!I<R!A(%5)(&]B:F5C=`T*("`@("`J("`@("`@("`@("`@
M("`@('1H870@<VAO=6QD(&)E('5S960@9F]R(&%L;"!O=71P=70-"B`@("`@
M*B`@)VUE<W-A9V4G("`@("!T:&4@<&%R86UE=&5R(&ES(&$@<W1R:6YG('=I
M=&@@86X@:6YF;W)M871I;VYA;"!M97-S86=E#0H@("`@("H@("=S879E87,G
M("`@("`@;6%Y(&)E('5S960@=&\@<V%V92!W:71H(&$@9&EF9F5R96YT(&9I
M;&4@;F%M92P@=&AE#0H@("`@("H@("`@("`@("`@("`@("`@<&%R86UE=&5R
M(&ES('1H92!F:6QE;F%M92!T:&%T(&ES(&%B;W5T('1O(&)E('5S960N#0H@
M("`@("H@("`@("`@("`@("`@("`@268@82`G<V%V96%S)R!C86QL8F%C:R!R
M971U<FYS(&$@;F]N+65M<'1Y('-T<FEN9RP-"B`@("`@*B`@("`@("`@("`@
M("`@("!T:&%T(&9I;&4@;F%M92!W:6QL(&)E('5S960@87,@=&AE(&9I;&5N
M86UE(&EN<W1E860N#0H@("`@("H@("`@("`@("`@("`@("`@3F]T92!T:&%T
M("1S879E7V1I<B!W:6QL(&YO="!B92!A9F9E8W1E9"!B>2!T:&ES+"!O;FQY
M#0H@("`@("H@("`@("`@("`@("`@("`@=&AE(&)A<V5N86UE(&]F('1H92!F
M:6QE+@T*("`@("`J("`G<W1A<G0G("`@("`@(&1O=VYL;V%D(&ES('-T87)T
M:6YG+"!P87)A;65T97(@:7,@;G5M8F5R(&]F(&)Y=&5S#0H@("`@("H@("`@
M("`@("`@("`@("`@=&AA="!A<F4@97AP96-T960L(&]R("TQ(&EF('5N:VYO
M=VX-"B`@("`@*B`@)V)Y=&5S<F5A9"<@("!P87)A;65T97(@:7,@=&AE(&YU
M;6)E<B!O9B!B>71E<R!R96%D('-O(&9A<@T*("`@("`J("`G9&]N92<@("`@
M("`@(&1O=VYL;V%D(&ES(&-O;7!L971E+"!P87)A;65T97(@:7,@=&AE('1O
M=&%L(&YU;6)E<@T*("`@("`J("`@("`@("`@("`@("`@(&]F(&)Y=&5S(')E
M860-"B`@("`@*B`@)V-O;FYF86EL960G("!I9B!T:&4@5$-0+U-33"!C;VYN
M96-T:6]N(&9A:6QS+"!T:&ES(&-A;&QB86-K(&ES(&-A;&QE9`T*("`@("`J
M("`@("`@("`@("`@("`@('=I=&@@87)R87DH:&]S="QP;W)T+&5R<FYO+&5R
M<FUS9RD-"B`@("`@*B`@)W=R:71E9F%I;&5D)R!I9B!W<FET:6YG('1O(&1I
M<VL@9F%I;',L('1H:7,@8V%L;&)A8VL@:7,@8V%L;&5D#0H@("`@("H@("`@
M("`@("`@("`@("`@=VET:"!A<G)A>2AD97-T9FEL92QE<G)M<V<I#0H@("`@
M("H-"B`@("`@*B!)9B!A;B!(5%10('!R;WAY(&AA<R!B965N(&-O;F9I9W5R
M960@*&AT='!?<')O>'D@4$5!4E]#;VYF:6<-"B`@("`@*B!S971T:6YG*2P@
M=&AE('!R;WAY('=I;&P@8F4@=7-E9"X-"B`@("`@*@T*("`@("`J($!P87)A
M;2!S=')I;F<@("1U<FP@("`@("`@=&AE(%523"!T;R!D;W=N;&]A9`T*("`@
M("`J($!P87)A;2!O8FIE8W0@("1U:2`@("`@("`@4$5!4E]&<F]N=&5N9%\J
M(&EN<W1A;F-E#0H@("`@("H@0'!A<F%M(&]B:F5C="`@)&-O;F9I9R`@("!0
M14%27T-O;F9I9R!I;G-T86YC90T*("`@("`J($!P87)A;2!S=')I;F<@("1S
M879E7V1I<B`@9&ER96-T;W)Y('1O('-A=F4@9FEL92!I;@T*("`@("`J($!P
M87)A;2!M:7AE9"`@("1C86QL8F%C:R`@9G5N8W1I;VXO;65T:&]D('1O(&-A
M;&P@9F]R('-T871U<PT*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@=7!D871E<PT*("`@("`J($!P87)A;2!F86QS97QS=')I;F=\87)R87D@
M)&QA<W1M;V1I9FEE9"!H96%D97(@=F%L=65S('1O(&-H96-K(&%G86EN<W0@
M9F]R(&-A8VAI;F<-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M('5S92!F86QS92!T;R!R971U<FX@=&AE(&AE861E<B!V86QU97,@9G)O;2!T
M:&ES(&1O=VYL;V%D#0H@("`@("H@0'!A<F%M(&9A;'-E?&%R<F%Y("1A8V-E
M<'0@06-C97!T(&AE861E<G,@=&\@<V5N9`T*("`@("`J($!R971U<FX@<W1R
M:6YG?&%R<F%Y("!2971U<FYS('1H92!F=6QL('!A=&@@;V8@=&AE(&1O=VYL
M;V%D960@9FEL92!O<B!A(%!%05(-"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@97)R;W(@;VX@9F%I;'5R92X@($EF('1H92!E<G)O<B!I<R!C875S
M960@8GD-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<V]C:V5T+7)E
M;&%T960@97)R;W)S+"!T:&4@97)R;W(@;V)J96-T('=I;&P-"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@:&%V92!T:&4@9G-O8VMO<&5N(&5R<F]R
M(&-O9&4@879A:6QA8FQE('1H<F]U9V@-"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@9V5T0V]D92@I+B`@268@8V%C:&EN9R!I<R!R97%U97-T960L
M('1H96X@<F5T=7)N('1H92!H96%D97(-"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@=F%L=65S+@T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L
M:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!D;W=N;&]A9$AT='`H)'5R;"P@
M)B1U:2P@)'-A=F5?9&ER(#T@)RXG+"`D8V%L;&)A8VL@/2!N=6QL+"`D;&%S
M=&UO9&EF:65D(#T@;G5L;"P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&%C8V5P="`](&9A;'-E*0T*("`@('L-"B`@("`@("`@<W1A=&EC("1R961I
M<F5C="`](#`[#0H@("`@("`@("\O(&%L;'=A>7,@<F5S970@+"!S;R!W92!A
M<F4@8VQE86X@8V%S92!O9B!E<G)O<@T*("`@("`@("`D=V%S<F5D:7)E8W0@
M/2`D<F5D:7)E8W0[#0H@("`@("`@("1R961I<F5C="`](#`[#0H@("`@("`@
M(&EF("@D8V%L;&)A8VLI('L-"B`@("`@("`@("`@(&-A;&Q?=7-E<E]F=6YC
M*"1C86QL8F%C:RP@)W-E='5P)RP@87)R87DH)B1U:2DI.PT*("`@("`@("!]
M#0H@("`@("`@("1I;F9O(#T@<&%R<V5?=7)L*"1U<FPI.PT*("`@("`@("!I
M9B`H(6ES<V5T*"1I;F9O6R=S8VAE;64G72D@?'P@(6EN7V%R<F%Y*"1I;F9O
M6R=S8VAE;64G72P@87)R87DH)VAT='`G+"`G:'1T<',G*2DI('L-"B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=#86YN;W0@9&]W;FQO
M860@;F]N+6AT='`@55),("(G("X@)'5R;"`N("<B)RD[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"%I<W-E="@D:6YF;ULG:&]S="==*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-A;FYO="!D;W=N;&]A
M9"!F<F]M(&YO;BU54DP@(B<@+B`D=7)L("X@)R(G*3L-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("1H;W-T(#T@0"1I;F9O6R=H;W-T)UT[#0H@
M("`@("`@("`@("`D<&]R="`]($`D:6YF;ULG<&]R="==.PT*("`@("`@("`@
M("`@)'!A=&@@/2!`)&EN9F];)W!A=&@G73L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H:7-S970H)'1H:7,I*2![#0H@("`@("`@("`@("`D8V]N9FEG(#T@
M)B1T:&ES+3YC;VYF:6<[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D8V]N9FEG(#T@)E!%05)?0V]N9FEG.CIS:6YG;&5T;VXH*3L-"B`@("`@
M("`@?0T*("`@("`@("`D<')O>'E?:&]S="`]("1P<F]X>5]P;W)T(#T@)'!R
M;WAY7W5S97(@/2`D<')O>'E?<&%S<R`]("<G.PT*("`@("`@("!I9B`H)&-O
M;F9I9RT^9V5T*"=H='1P7W!R;WAY)RDF)B`-"B`@("`@("`@("`@("`@)'!R
M;WAY(#T@<&%R<V5?=7)L*"1C;VYF:6<M/F=E="@G:'1T<%]P<F]X>2<I*2D@
M>PT*("`@("`@("`@("`@)'!R;WAY7VAO<W0@/2!`)'!R;WAY6R=H;W-T)UT[
M#0H@("`@("`@("`@("!I9B`H:7-S970H)'!R;WAY6R=S8VAE;64G72D@)B8@
M)'!R;WAY6R=S8VAE;64G72`]/2`G:'1T<',G*2![#0H@("`@("`@("`@("`@
M("`@)'!R;WAY7VAO<W0@/2`G<W-L.B\O)R`N("1P<F]X>5]H;W-T.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)'!R;WAY7W!O<G0@/2!`)'!R;WAY
M6R=P;W)T)UT[#0H@("`@("`@("`@("`D<')O>'E?=7-E<B`]($`D<')O>'E;
M)W5S97(G73L-"B`@("`@("`@("`@("1P<F]X>5]P87-S(#T@0"1P<F]X>5LG
M<&%S<R==.PT*#0H@("`@("`@("`@("!I9B`H)'!R;WAY7W!O<G0@/3T@)R<I
M('L-"B`@("`@("`@("`@("`@("`D<')O>'E?<&]R="`](#@P.#`[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)&-A;&QB86-K*2![#0H@("`@
M("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F,H)&-A;&QB86-K+"`G;65S<V%G
M92<L(")5<VEN9R!(5%10('!R;WAY("1H;W-T.B1P;W)T(BD[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&5M<'1Y*"1P;W)T*2D@
M>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=S8VAE;64G72D@)B8@
M)&EN9F];)W-C:&5M92==(#T]("=H='1P<R<I('L-"B`@("`@("`@("`@("`@
M("`D<&]R="`](#0T,SL-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@)'!O<G0@/2`X,#L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H)'!R;WAY7VAO<W0@(3T@)R<I('L-"B`@("`@("`@
M("`@("1F<"`]($!F<V]C:V]P96XH)'!R;WAY7VAO<W0L("1P<F]X>5]P;W)T
M+"`D97)R;F\L("1E<G)S='(I.PT*("`@("`@("`@("`@:68@*"$D9G`I('L-
M"B`@("`@("`@("`@("`@("!I9B`H)&-A;&QB86-K*2![#0H@("`@("`@("`@
M("`@("`@("`@(&-A;&Q?=7-E<E]F=6YC*"1C86QL8F%C:RP@)V-O;FYF86EL
M960G+"!A<G)A>2@D<')O>'E?:&]S="P@)'!R;WAY7W!O<G0L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D97)R;F\L("1E<G)S='(I*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H(D-O;FYE8W1I;VX@=&\@8"1P<F]X>5]H;W-T.B1P<F]X>5]P;W)T)R!F
M86EL960Z("1E<G)S='(B+"`D97)R;F\I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@:68@*"1L87-T;6]D:69I960@/3T](&9A;'-E('Q\("1L87-T
M;6]D:69I960I('L-"B`@("`@("`@("`@("`@("`D<F5Q=65S="`](")'150@
M)'5R;"!(5%10+S$N,5QR7&XB.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`D<F5Q=65S="`](")'150@)'5R;"!(5%10+S$N,%QR
M7&XB.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@:68@*&ES<V5T*"1I;F9O6R=S8VAE;64G72D@)B8@)&EN9F];)W-C
M:&5M92==(#T]("=H='1P<R<I('L-"B`@("`@("`@("`@("`@("`D:&]S="`]
M("=S<VPZ+R\G("X@)&AO<W0[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`D9G`@/2!`9G-O8VMO<&5N*"1H;W-T+"`D<&]R="P@)&5R<FYO+"`D97)R
M<W1R*3L-"B`@("`@("`@("`@(&EF("@A)&9P*2![#0H@("`@("`@("`@("`@
M("`@:68@*"1C86QL8F%C:RD@>PT*("`@("`@("`@("`@("`@("`@("!C86QL
M7W5S97)?9G5N8R@D8V%L;&)A8VLL("=C;VYN9F%I;&5D)RP@87)R87DH)&AO
M<W0L("1P;W)T+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5R<FYO+"`D97)R
M<W1R*2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*")#;VYN96-T:6]N('1O(&`D:&]S=#HD
M<&]R="<@9F%I;&5D.B`D97)R<W1R(BP@)&5R<FYO*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF("@D;&%S=&UO9&EF:65D(#T]/2!F86QS92!\
M?"`D;&%S=&UO9&EF:65D*2![#0H@("`@("`@("`@("`@("`@)')E<75E<W0@
M/2`B1T54("1P871H($A45%`O,2XQ7')<;B([#0H@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("1R97%U97-T(#T@(D=%5"`D<&%T:"!(
M5%10+S$N,%QR7&XB.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@("1I9FUO9&EF:65D<VEN8V4@/2`G)SL-"B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1L87-T;6]D:69I960I*2![#0H@("`@("`@("`@("!I9B`H:7-S970H
M)&QA<W1M;V1I9FEE9%LG3&%S="U-;V1I9FEE9"==*2D@>PT*("`@("`@("`@
M("`@("`@("1I9FUO9&EF:65D<VEN8V4@/2`G268M36]D:69I960M4VEN8V4Z
M("<@+B`D;&%S=&UO9&EF:65D6R=,87-T+4UO9&EF:65D)UT@+B`B7')<;B([
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)&QA<W1M
M;V1I9FEE9%LG151A9R==*2D@>PT*("`@("`@("`@("`@("`@("1I9FUO9&EF
M:65D<VEN8V4@+CT@(DEF+4YO;F4M36%T8V@Z("1L87-T;6]D:69I961;151A
M9UU<<EQN(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("1I9FUO9&EF:65D<VEN8V4@/2`H)&QA<W1M;V1I9FEE9"`_
M("))9BU-;V1I9FEE9"U3:6YC93H@)&QA<W1M;V1I9FEE9%QR7&XB(#H@)R<I
M.PT*("`@("`@("!]#0H@("`@("`@("1R97%U97-T("X](")(;W-T.B`D:&]S
M=#HD<&]R=%QR7&XB("X@)&EF;6]D:69I961S:6YC92`N#0H@("`@("`@("`@
M("`B57-E<BU!9V5N=#H@4$5!4B\Q+C0N.2]02%`O(B`N(%!(4%]615)324].
M("X@(EQR7&XB.PT*("`@("`@("!I9B`H:7-S970H)'1H:7,I*2![("\O(&]N
M;'D@<&%S<R!I;B!A=71H96YT:6-A=&EO;B!F;W(@;F]N+7-T871I8R!C86QL
M<PT*("`@("`@("`@("`@)'5S97)N86UE(#T@)&-O;F9I9RT^9V5T*"=U<V5R
M;F%M92<I.PT*("`@("`@("`@("`@)'!A<W-W;W)D(#T@)&-O;F9I9RT^9V5T
M*"=P87-S=V]R9"<I.PT*("`@("`@("`@("`@:68@*"1U<V5R;F%M92`F)B`D
M<&%S<W=O<F0I('L-"B`@("`@("`@("`@("`@("`D=&UP(#T@8F%S938T7V5N
M8V]D92@B)'5S97)N86UE.B1P87-S=V]R9"(I.PT*("`@("`@("`@("`@("`@
M("1R97%U97-T("X](")!=71H;W)I>F%T:6]N.B!"87-I8R`D=&UP7')<;B([
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1P<F]X
M>5]H;W-T("$]("<G("8F("1P<F]X>5]U<V5R("$]("<G*2![#0H@("`@("`@
M("`@("`D<F5Q=65S="`N/2`G4')O>'DM075T:&]R:7IA=&EO;CH@0F%S:6,@
M)R`N#0H@("`@("`@("`@("`@("`@8F%S938T7V5N8V]D92@D<')O>'E?=7-E
M<B`N("<Z)R`N("1P<F]X>5]P87-S*2`N(")<<EQN(CL-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H)&%C8V5P="D@>PT*("`@("`@("`@("`@)')E<75E<W0@
M+CT@)T%C8V5P=#H@)R`N(&EM<&QO9&4H)RP@)RP@)&%C8V5P="D@+B`B7')<
M;B([#0H@("`@("`@('T-"B`@("`@("`@)')E<75E<W0@+CT@(D-O;FYE8W1I
M;VXZ(&-L;W-E7')<;B([#0H@("`@("`@("1R97%U97-T("X](")<<EQN(CL-
M"B`@("`@("`@9G=R:71E*"1F<"P@)')E<75E<W0I.PT*("`@("`@("`D:&5A
M9&5R<R`](&%R<F%Y*"D[#0H@("`@("`@("1R97!L>2`](#`[#0H@("`@("`@
M('=H:6QE("AT<FEM*"1L:6YE(#T@9F=E=',H)&9P+"`Q,#(T*2DI('L-"B`@
M("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7BA;7CI=*RDZ7',K*"XJ*5QS
M*B0O)RP@)&QI;F4L("1M871C:&5S*2D@>PT*("`@("`@("`@("`@("`@("1H
M96%D97)S6W-T<G1O;&]W97(H)&UA=&-H97-;,5TI72`]('1R:6TH)&UA=&-H
M97-;,ETI.PT*("`@("`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)WQ>
M2%144"\Q+ELP,5T@*%LP+3E=>S-]*2!\)RP@)&QI;F4L("1M871C:&5S*2D@
M>PT*("`@("`@("`@("`@("`@("1R97!L>2`]("AI;G0I("1M871C:&5S6S%=
M.PT*("`@("`@("`@("`@("`@(&EF("@D<F5P;'D@/3T@,S`T("8F("@D;&%S
M=&UO9&EF:65D('Q\("@D;&%S=&UO9&EF:65D(#T]/2!F86QS92DI*2![#0H@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"$@:6Y?87)R87DH)')E<&QY
M+"!A<G)A>2@R,#`L(#,P,2P@,S`R+"`S,#,L(#,P-2P@,S`W*2DI('L-"B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D9I
M;&4@:'1T<#HO+R1H;W-T.B1P;W)T)'!A=&@@;F]T('9A;&ED("AR96-E:79E
M9#H@)&QI;F4I(BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(&EF("@D<F5P;'D@(3T@,C`P*2![#0H@
M("`@("`@("`@("!I9B`H:7-S970H)&AE861E<G-;)VQO8V%T:6]N)UTI*2![
M#0H@("`@("`@("`@("`@("`@:68@*"1W87-R961I<F5C="`\(#4I('L-"B`@
M("`@("`@("`@("`@("`@("`@)')E9&ER96-T(#T@)'=A<W)E9&ER96-T("L@
M,3L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YD;W=N;&]A
M9$AT='`H)&AE861E<G-;)VQO8V%T:6]N)UTL#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'5I+"`D<V%V95]D:7(L("1C86QL8F%C:RP@)&QA<W1M
M;V1I9FEE9"P@)&%C8V5P="D[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M(D9I;&4@:'1T<#HO+R1H;W-T.B1P;W)T)'!A=&@@;F]T('9A;&ED("AR961I
M<F5C=&EO;B!L;V]P960@;6]R92!T:&%N(#4@=&EM97,I(BD[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B1FEL92!H='1P.B\O)&AO
M<W0Z)'!O<G0D<&%T:"!N;W0@=F%L:60@*')E9&ER96-T960@8G5T(&YO(&QO
M8V%T:6]N*2(I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(&EF("AI<W-E="@D:&5A9&5R<ULG8V]N=&5N="UD:7-P;W-I=&EO;B==*2`F
M)@T*("`@("`@("`@("`@<')E9U]M871C:"@G+UQS9FEL96YA;64]7"(H6UX[
M72I<4RE<(EQS*B@[?"0I+R<L("1H96%D97)S6R=C;VYT96YT+61I<W!O<VET
M:6]N)UTL("1M871C:&5S*2D@>PT*("`@("`@("`@("`@)'-A=F5?87,@/2!B
M87-E;F%M92@D;6%T8VAE<ULQ72D[#0H@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`D<V%V95]A<R`](&)A<V5N86UE*"1U<FPI.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@D8V%L;&)A8VLI('L-"B`@("`@("`@("`@("1T;7`@
M/2!C86QL7W5S97)?9G5N8R@D8V%L;&)A8VLL("=S879E87,G+"`D<V%V95]A
M<RD[#0H@("`@("`@("`@("!I9B`H)'1M<"D@>PT*("`@("`@("`@("`@("`@
M("1S879E7V%S(#T@)'1M<#L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("`D9&5S=%]F:6QE(#T@)'-A=F5?9&ER("X@1$E214-43U)97U-%
M4$%2051/4B`N("1S879E7V%S.PT*("`@("`@("!I9B`H(21W<"`]($!F;W!E
M;B@D9&5S=%]F:6QE+"`G=V(G*2D@>PT*("`@("`@("`@("`@9F-L;W-E*"1F
M<"D[#0H@("`@("`@("`@("!I9B`H)&-A;&QB86-K*2![#0H@("`@("`@("`@
M("`@("`@8V%L;%]U<V5R7V9U;F,H)&-A;&QB86-K+"`G=W)I=&5F86EL960G
M+"!A<G)A>2@D9&5S=%]F:6QE+"`D<&AP7V5R<F]R;7-G*2D[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B
M8V]U;&0@;F]T(&]P96X@)&1E<W1?9FEL92!F;W(@=W)I=&EN9R(I.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D:&5A9&5R<ULG8V]N=&5N="UL
M96YG=&@G72DI('L-"B`@("`@("`@("`@("1L96YG=&@@/2`D:&5A9&5R<ULG
M8V]N=&5N="UL96YG=&@G73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("1L96YG=&@@/2`M,3L-"B`@("`@("`@?0T*("`@("`@("`D8GET97,@
M/2`P.PT*("`@("`@("!I9B`H)&-A;&QB86-K*2![#0H@("`@("`@("`@("!C
M86QL7W5S97)?9G5N8R@D8V%L;&)A8VLL("=S=&%R="<L(&%R<F%Y*&)A<V5N
M86UE*"1D97-T7V9I;&4I+"`D;&5N9W1H*2D[#0H@("`@("`@('T-"B`@("`@
M("`@=VAI;&4@*"1D871A(#T@0&9R96%D*"1F<"P@,3`R-"DI('L-"B`@("`@
M("`@("`@("1B>71E<R`K/2!S=')L96XH)&1A=&$I.PT*("`@("`@("`@("`@
M:68@*"1C86QL8F%C:RD@>PT*("`@("`@("`@("`@("`@(&-A;&Q?=7-E<E]F
M=6YC*"1C86QL8F%C:RP@)V)Y=&5S<F5A9"<L("1B>71E<RD[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!I9B`H(4!F=W)I=&4H)'=P+"`D9&%T82DI
M('L-"B`@("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@("`@
M("`@("!I9B`H)&-A;&QB86-K*2![#0H@("`@("`@("`@("`@("`@("`@(&-A
M;&Q?=7-E<E]F=6YC*"1C86QL8F%C:RP@)W=R:71E9F%I;&5D)RP@87)R87DH
M)&1E<W1?9FEL92P@)'!H<%]E<G)O<FUS9RDI.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B
M)&1E<W1?9FEL93H@=W)I=&4@9F%I;&5D("@D<&AP7V5R<F]R;7-G*2(I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&9C;&]S92@D9G`I
M.PT*("`@("`@("!F8VQO<V4H)'=P*3L-"B`@("`@("`@:68@*"1C86QL8F%C
M:RD@>PT*("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F,H)&-A;&QB86-K+"`G
M9&]N92<L("1B>71E<RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1L87-T
M;6]D:69I960@/3T](&9A;'-E('Q\("1L87-T;6]D:69I960I('L-"B`@("`@
M("`@("`@(&EF("AI<W-E="@D:&5A9&5R<ULG971A9R==*2D@>PT*("`@("`@
M("`@("`@("`@("1L87-T;6]D:69I960@/2!A<G)A>2@G151A9R<@/3X@)&AE
M861E<G-;)V5T86<G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H:7-S970H)&AE861E<G-;)VQA<W0M;6]D:69I960G72DI('L-"B`@("`@
M("`@("`@("`@("!I9B`H:7-?87)R87DH)&QA<W1M;V1I9FEE9"DI('L-"B`@
M("`@("`@("`@("`@("`@("`@)&QA<W1M;V1I9FEE9%LG3&%S="U-;V1I9FEE
M9"==(#T@)&AE861E<G-;)VQA<W0M;6]D:69I960G73L-"B`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D;&%S=&UO9&EF
M:65D(#T@)&AE861E<G-;)VQA<W0M;6]D:69I960G73L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@87)R
M87DH)&1E<W1?9FEL92P@)&QA<W1M;V1I9FEE9"P@)&AE861E<G,I.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B`D9&5S=%]F:6QE.PT*("`@('T-"GT-
M"B\O('U]?0T*#0H_/@T*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]%<G)O<E-T86-K+G!H<```````
M````````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,#,V,3,`,3`U,34T,S,W
M-#$`,#(R,3(U`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP#0HO*BH-"B`J($5R<F]R(%-T86-K($EM<&QE;65N=&%T
M:6]N#0H@*B`-"B`J(%1H:7,@:7,@86X@:6YC<F5D:6)L>2!S:6UP;&4@:6UP
M;&5M96YT871I;VX@;V8@82!V97)Y(&-O;7!L97@@97)R;W(@:&%N9&QI;F<-
M"B`J(&9A8VEL:71Y+B`@270@8V]N=&%I;G,@=&AE(&%B:6QI='D-"B`J('1O
M('1R86-K(&UU;'1I<&QE(&5R<F]R<R!F<F]M(&UU;'1I<&QE('!A8VMA9V5S
M('-I;75L=&%N96]U<VQY+B`@26X@861D:71I;VXL#0H@*B!I="!C86X@=')A
M8VL@97)R;W)S(&]F(&UA;GD@;&5V96QS+"!S879E(&1A=&$@86QO;F<@=VET
M:"!T:&4@97)R;W(L(&-O;G1E>'0-"B`J(&EN9F]R;6%T:6]N('-U8V@@87,@
M=&AE(&5X86-T(&9I;&4L(&QI;F4@;G5M8F5R+"!C;&%S<R!A;F0@9G5N8W1I
M;VX@=&AA=`T*("H@9V5N97)A=&5D('1H92!E<G)O<BP@86YD(&EF(&YE8V5S
M<V%R>2P@:70@8V%N(')A:7-E(&$@=')A9&ET:6]N86P@4$5!4E]%<G)O<BX-
M"B`J($ET(&AA<R!B=6EL="UI;B!S=7!P;W)T(&9O<B!014%2.CI,;V<L('1O
M(&QO9R!E<G)O<G,@87,@=&AE>2!O8V-U<@T*("H@#0H@*B!3:6YC92!V97)S
M:6]N(#`N,F%L<&AA+"!I="!I<R!A;'-O('!O<W-I8FQE('1O('-E;&5C=&EV
M96QY(&EG;F]R92!E<G)O<G,L#0H@*B!T:')O=6=H('1H92!U<V4@;V8@86X@
M97)R;W(@8V%L;&)A8VLL('-E92![0&QI;FL@<'5S:$-A;&QB86-K*"E]#0H@
M*B`-"B`J(%-I;F-E('9E<G-I;VX@,"XS86QP:&$L(&ET(&ES('!O<W-I8FQE
M('1O('-P96-I9GD@=&AE(&5X8V5P=&EO;B!C;&%S<PT*("H@<F5T=7)N960@
M9G)O;2![0&QI;FL@<'5S:"@I?0T*("H-"B`J(%-I;F-E('9E<G-I;VX@4$5!
M4C$N,RXR+"!%<G)O<E-T86-K(&YO(&QO;F=E<B!I;G-T86YT:6%T97,@86X@
M97AC97!T:6]N(&-L87-S+B`@5&AI<R!C86X-"B`J('-T:6QL(&)E(&1O;F4@
M<75I=&4@:&%N9&EL>2!I;B!A;B!E<G)O<B!C86QL8F%C:R!O<B!B>2!M86YI
M<'5L871I;F<@=&AE(')E='5R;F5D(&%R<F%Y#0H@*B!`8V%T96=O<GD@("!$
M96)U9V=I;F<-"B`J($!P86-K86=E("`@(%!%05)?17)R;W)3=&%C:PT*("H@
M0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@
M0&-O<'ER:6=H="`@,C`P-"TR,#`V($=R96<@0F5A=F5R#0H@*B!`;&EC96YS
M92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@
M3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!%<G)O<E-T
M86-K+G!H<"QV(#$N,C(@,C`P-B\P,2\P-B`P-#HT-SHS-B!C96QL;V<@17AP
M("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]014%27T5R<F]R4W1A8VL-"B`J+PT*#0HO*BH-"B`J(%-I;F=L971O;B!S
M=&]R86=E#0H@*B`-"B`J($9O<FUA=#H-"B`J(#QP<F4^#0H@*B!A<G)A>2@-
M"B`J("`G<&%C:V%G93$G(#T^(%!%05)?17)R;W)3=&%C:R!O8FIE8W0L#0H@
M*B`@)W!A8VMA9V4R)R`]/B!014%27T5R<F]R4W1A8VL@;V)J96-T+`T*("H@
M("XN+@T*("H@*0T*("H@/"]P<F4^#0H@*B!`86-C97-S('!R:79A=&4-"B`J
M($!G;&]B86P@87)R87D@)$=,3T)!3%-;)U]014%27T524D]24U1!0TM?4TE.
M1TQ%5$].)UT-"B`J+PT*)$=,3T)!3%-;)U]014%27T524D]24U1!0TM?4TE.
M1TQ%5$].)UT@/2!A<G)A>2@I.PT*#0HO*BH-"B`J($=L;V)A;"!E<G)O<B!C
M86QL8F%C:R`H9&5F875L="D-"B`J(`T*("H@5&AI<R!I<R!O;FQY('5S960@
M:68@<V5T('1O(&YO;BUF86QS92X@("H@:7,@=&AE(&1E9F%U;'0@8V%L;&)A
M8VL@9F]R#0H@*B!A;&P@<&%C:V%G97,L('=H97)E87,@<W!E8VEF:6,@<&%C
M:V%G97,@;6%Y('-E="!A(&1E9F%U;'0@8V%L;&)A8VL-"B`J(&9O<B!A;&P@
M:6YS=&%N8V5S+"!R96=A<F1L97-S(&]F('=H971H97(@=&AE>2!A<F4@82!S
M:6YG;&5T;VX@;W(@;F]T+@T*("H-"B`J(%1O(&5X8VQU9&4@;F]N+7-I;F=L
M971O;G,L(&]N;'D@<V5T('1H92!L;V-A;"!C86QL8F%C:R!F;W(@=&AE('-I
M;F=L971O;@T*("H@0'-E92!014%27T5R<F]R4W1A8VLZ.G-E=$1E9F%U;'1#
M86QL8F%C:R@I#0H@*B!`86-C97-S('!R:79A=&4-"B`J($!G;&]B86P@87)R
M87D@)$=,3T)!3%-;)U]014%27T524D]24U1!0TM?1$5&055,5%]#04Q,0D%#
M2R==#0H@*B\-"B1'3$]"04Q36R=?4$5!4E]%4E)/4E-404-+7T1%1D%53%1?
M0T%,3$)!0TLG72`](&%R<F%Y*`T*("`@("<J)R`]/B!F86QS92P-"BD[#0H-
M"B\J*@T*("H@1VQO8F%L($QO9R!O8FIE8W0@*&1E9F%U;'0I#0H@*B`-"B`J
M(%1H:7,@:7,@;VYL>2!U<V5D(&EF('-E="!T;R!N;VXM9F%L<V4N("!5<V4@
M=&\@<V5T(&$@9&5F875L="!L;V<@;V)J96-T(&9O<@T*("H@86QL('-T86-K
M<RP@<F5G87)D;&5S<R!O9B!I;G-T86YT:6%T:6]N(&]R9&5R(&]R(&QO8V%T
M:6]N#0H@*B!`<V5E(%!%05)?17)R;W)3=&%C:SHZ<V5T1&5F875L=$QO9V=E
M<B@I#0H@*B!`86-C97-S('!R:79A=&4-"B`J($!G;&]B86P@87)R87D@)$=,
M3T)!3%-;)U]014%27T524D]24U1!0TM?1$5&055,5%],3T='15(G70T*("HO
M#0HD1TQ/0D%,4ULG7U!%05)?15)23U)35$%#2U]$149!54Q47TQ/1T=%4B==
M(#T@9F%L<V4[#0H-"B\J*@T*("H@1VQO8F%L($]V97)R:61I;F<@0V%L;&)A
M8VL-"B`J(`T*("H@5&AI<R!C86QL8F%C:R!W:6QL(&]V97)R:61E(&%N>2!E
M<G)O<B!C86QL8F%C:W,@=&AA="!S<&5C:69I8R!L;V=G97)S(&AA=F4@<V5T
M+@T*("H@57-E('=I=&@@15A44D5-12!C875T:6]N#0H@*B!`<V5E(%!%05)?
M17)R;W)3=&%C:SHZ<W1A=&EC4'5S:$-A;&QB86-K*"D-"B`J($!A8V-E<W,@
M<')I=F%T90T*("H@0&=L;V)A;"!A<G)A>2`D1TQ/0D%,4ULG7U!%05)?15)2
M3U)35$%#2U]$149!54Q47TQ/1T=%4B==#0H@*B\-"B1'3$]"04Q36R=?4$5!
M4E]%4E)/4E-404-+7T]615)2241%7T-!3$Q"04-+)UT@/2!A<G)A>2@I.PT*
M#0HO*BHC0"L-"B`J($]N92!O9B!F;W5R('!O<W-I8FQE(')E='5R;B!V86QU
M97,@9G)O;2!T:&4@97)R;W(@0V%L;&)A8VL-"B`J($!S964@4$5!4E]%<G)O
M<E-T86-K.CI?97)R;W)#86QL8F%C:R@I#0H@*B\-"B\J*@T*("H@268@=&AI
M<R!I<R!R971U<FYE9"P@=&AE;B!T:&4@97)R;W(@=VEL;"!B92!B;W1H('!U
M<VAE9"!O;G1O('1H92!S=&%C:PT*("H@86YD(&QO9V=E9"X-"B`J+PT*9&5F
M:6YE*"=014%27T524D]24U1!0TM?4%532$%.1$Q/1R<L(#$I.PT*+RHJ#0H@
M*B!)9B!T:&ES(&ES(')E='5R;F5D+"!T:&5N('1H92!E<G)O<B!W:6QL(&]N
M;'D@8F4@<'5S:&5D(&]N=&\@=&AE('-T86-K+`T*("H@86YD(&YO="!L;V=G
M960N#0H@*B\-"F1E9FEN92@G4$5!4E]%4E)/4E-404-+7U!54T@G+"`R*3L-
M"B\J*@T*("H@268@=&AI<R!I<R!R971U<FYE9"P@=&AE;B!T:&4@97)R;W(@
M=VEL;"!O;FQY(&)E(&QO9V=E9"P@8G5T(&YO="!P=7-H960-"B`J(&]N=&\@
M=&AE(&5R<F]R('-T86-K+@T*("HO#0ID969I;F4H)U!%05)?15)23U)35$%#
M2U],3T<G+"`S*3L-"B\J*@T*("H@268@=&AI<R!I<R!R971U<FYE9"P@=&AE
M;B!T:&4@97)R;W(@:7,@8V]M<&QE=&5L>2!I9VYO<F5D+@T*("HO#0ID969I
M;F4H)U!%05)?15)23U)35$%#2U])1TY/4D4G+"`T*3L-"B\J*@T*("H@268@
M=&AI<R!I<R!R971U<FYE9"P@=&AE;B!T:&4@97)R;W(@:7,@;&]G9V5D(&%N
M9"!D:64H*2!I<R!C86QL960N#0H@*B\-"F1E9FEN92@G4$5!4E]%4E)/4E-4
M04-+7T1)12<L(#4I.PT*+RHJ(T`M*B\-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E
M(&9O<B!A;B!A='1E;7!T('1O(&EN<W1A;G1I871E(&$@;F]N+6-L87-S(&%S
M(&$@4$5!4E]%<G)O<E-T86-K(&EN#0H@*B!T:&4@<VEN9VQE=&]N(&UE=&AO
M9"X-"B`J+PT*9&5F:6YE*"=014%27T524D]24U1!0TM?15)27TY/3D-,05-3
M)RP@,2D[#0H-"B\J*@T*("H@17)R;W(@8V]D92!F;W(@86X@871T96UP="!T
M;R!P87-S(&%N(&]B:F5C="!I;G1O('M`;&EN:R!014%27T5R<F]R4W1A8VLZ
M.F=E=$UE<W-A9V4H*7T-"B`J('1H870@:&%S(&YO(%]?=&]3=')I;F<H*2!M
M971H;V0-"B`J+PT*9&5F:6YE*"=014%27T524D]24U1!0TM?15)27T]"2E1/
M4U1224Y')RP@,BD[#0HO*BH-"B`J($5R<F]R(%-T86-K($EM<&QE;65N=&%T
M:6]N#0H@*@T*("H@57-A9V4Z#0H@*B`\8V]D93X-"B`J("\O(&=L;V)A;"!E
M<G)O<B!S=&%C:PT*("H@)&=L;V)A;%]S=&%C:R`]("9014%27T5R<F]R4W1A
M8VLZ.G-I;F=L971O;B@G37E086-K86=E)RD[#0H@*B`O+R!L;V-A;"!E<G)O
M<B!S=&%C:PT*("H@)&QO8V%L7W-T86-K(#T@;F5W(%!%05)?17)R;W)3=&%C
M:R@G37E086-K86=E)RD[#0H@*B`\+V-O9&4^#0H@*B!`875T:&]R("`@("!'
M<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`=F5R<VEO;B`@("`Q
M+C0N.0T*("H@0'!A8VMA9V4@("`@4$5!4E]%<G)O<E-T86-K#0H@*B!`8V%T
M96=O<GD@("!$96)U9V=I;F<-"B`J($!C;W!Y<FEG:'0@(#(P,#0M,C`P-B!'
M<F5G($)E879E<@T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO
M;B`@("!#5E,Z("1)9#H@17)R;W)3=&%C:RYP:'`L=B`Q+C(R(#(P,#8O,#$O
M,#8@,#0Z-#<Z,S8@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4E]%<G)O<E-T86-K#0H@*B\-
M"F-L87-S(%!%05)?17)R;W)3=&%C:R![#0H@("`@+RHJ#0H@("`@("H@17)R
M;W)S(&%R92!S=&]R960@:6X@=&AE(&]R9&5R('1H870@=&AE>2!A<F4@<'5S
M:&5D(&]N('1H92!S=&%C:RX-"B`@("`@*B!`<VEN8V4@,"XT86QP:&$@17)R
M;W)S(&%R92!N;R!L;VYG97(@;W)G86YI>F5D(&)Y(&5R<F]R(&QE=F5L+@T*
M("`@("`J(%1H:7,@<F5N9&5R<R!P;W`H*2!N96%R;'D@=6YU<V%B;&4L(&%N
M9"!L979E;',@8V]U;&0@8F4@;6]R92!E87-I;'D-"B`@("`@*B!H86YD;&5D
M(&EN(&$@8V%L;&)A8VL@86YY=V%Y#0H@("`@("H@0'9A<B!A<G)A>0T*("`@
M("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7V5R<F]R
M<R`](&%R<F%Y*"D[#0H-"B`@("`O*BH-"B`@("`@*B!3=&]R86=E(&]F(&5R
M<F]R<R!B>2!L979E;"X-"B`@("`@*@T*("`@("`J($%L;&]W<R!E87-Y(')E
M=')I979A;"!A;F0@9&5L971I;VX@;V8@;VYL>2!E<G)O<G,@9G)O;2!A('!A
M<G1I8W5L87(@;&5V96P-"B`@("`@*B!`<VEN8V4@4$5!4B`Q+C0N,&1E=@T*
M("`@("`J($!V87(@87)R87D-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@
M("`@*B\-"B`@("!V87(@)%]E<G)O<G-">4QE=F5L(#T@87)R87DH*3L-"@T*
M("`@("\J*@T*("`@("`J(%!A8VMA9V4@;F%M92!T:&ES(&5R<F]R('-T86-K
M(')E<')E<V5N=',-"B`@("`@*B!`=F%R('-T<FEN9PT*("`@("`J($!A8V-E
M<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@=F%R("1?<&%C:V%G93L-"B`@
M("`-"B`@("`O*BH-"B`@("`@*B!$971E<FUI;F5S('=H971H97(@82!014%2
M7T5R<F]R(&ES('1H<F]W;B!U<&]N(&5V97)Y(&5R<F]R(&%D9&ET:6]N#0H@
M("`@("H@0'9A<B!B;V]L96%N#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@
M("`@("HO#0H@("`@=F%R("1?8V]M<&%T(#T@9F%L<V4[#0H@("`@#0H@("`@
M+RHJ#0H@("`@("H@268@<V5T('1O(&$@=F%L:60@8V%L;&)A8VLL('1H:7,@
M=VEL;"!B92!U<V5D('1O(&=E;F5R871E('1H92!E<G)O<@T*("`@("`J(&UE
M<W-A9V4@9G)O;2!T:&4@97)R;W(@8V]D92P@;W1H97)W:7-E('1H92!M97-S
M86=E('!A<W-E9"!I;B!W:6QL(&)E#0H@("`@("H@=7-E9`T*("`@("`J($!V
M87(@9F%L<V5\<W1R:6YG?&%R<F%Y#0H@("`@("H@0&%C8V5S<R!P<FEV871E
M#0H@("`@("HO#0H@("`@=F%R("1?;7-G0V%L;&)A8VL@/2!F86QS93L-"B`@
M("`-"B`@("`O*BH-"B`@("`@*B!)9B!S970@=&\@82!V86QI9"!C86QL8F%C
M:RP@=&AI<R!W:6QL(&)E('5S960@=&\@9V5N97)A=&4@=&AE(&5R<F]R#0H@
M("`@("H@8V]N=&5X="!F;W(@86X@97)R;W(N("!&;W(@4$A0+7)E;&%T960@
M97)R;W)S+"!T:&ES('=I;&P@8F4@82!F:6QE#0H@("`@("H@86YD(&QI;F4@
M;G5M8F5R(&%S(')E=')I979E9"!F<F]M(&1E8G5G7V)A8VMT<F%C92@I+"!B
M=70@8V%N(&)E#0H@("`@("H@8W5S=&]M:7IE9"!F;W(@;W1H97(@<'5R<&]S
M97,N("!4:&4@97)R;W(@;6EG:'0@86-T=6%L;'D@8F4@:6X@82!S97!A<F%T
M90T*("`@("`J(&-O;F9I9W5R871I;VX@9FEL92P@;W(@:6X@82!D871A8F%S
M92!Q=65R>2X-"B`@("`@*B!`=F%R(&9A;'-E?'-T<FEN9WQA<G)A>0T*("`@
M("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@=F%R("1?8V]N
M=&5X=$-A;&QB86-K(#T@9F%L<V4[#0H@("`@#0H@("`@+RHJ#0H@("`@("H@
M268@<V5T('1O(&$@=F%L:60@8V%L;&)A8VLL('1H:7,@=VEL;"!B92!C86QL
M960@979E<GD@=&EM92!A;B!E<G)O<@T*("`@("`J(&ES('!U<VAE9"!O;G1O
M('1H92!S=&%C:RX@(%1H92!R971U<FX@=F%L=64@=VEL;"!B92!U<V5D('1O
M(&1E=&5R;6EN90T*("`@("`J('=H971H97(@=&\@86QL;W<@86X@97)R;W(@
M=&\@8F4@<'5S:&5D(&]R(&QO9V=E9"X-"B`@("`@*B`-"B`@("`@*B!4:&4@
M<F5T=7)N('9A;'5E(&UU<W0@8F4@;VYE(&%N(%!%05)?15)23U)35$%#2U\J
M(&-O;G-T86YT#0H@("`@("H@0'-E92!014%27T524D]24U1!0TM?4%532$%.
M1$Q/1RP@4$5!4E]%4E)/4E-404-+7U!54T@L(%!%05)?15)23U)35$%#2U],
M3T<-"B`@("`@*B!`=F%R(&9A;'-E?'-T<FEN9WQA<G)A>0T*("`@("`J($!A
M8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@=F%R("1?97)R;W)#86QL
M8F%C:R`](&%R<F%Y*"D[#0H@("`@#0H@("`@+RHJ#0H@("`@("H@4$5!4CHZ
M3&]G(&]B:F5C="!F;W(@;&]G9VEN9R!E<G)O<G,-"B`@("`@*B!`=F%R(&9A
M;'-E?$QO9PT*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@
M("`@=F%R("1?;&]G9V5R(#T@9F%L<V4[#0H@("`@#0H@("`@+RHJ#0H@("`@
M("H@17)R;W(@;65S<V%G97,@+2!D97-I9VYE9"!T;R!B92!O=F5R<FED9&5N
M#0H@("`@("H@0'9A<B!A<G)A>0T*("`@("`J($!A8G-T<F%C=`T*("`@("`J
M+PT*("`@('9A<B`D7V5R<F]R37-G<R`](&%R<F%Y*"D[#0H@("`@#0H@("`@
M+RHJ#0H@("`@("H@4V5T('5P(&$@;F5W(&5R<F]R('-T86-K#0H@("`@("H@
M#0H@("`@("H@0'!A<F%M('-T<FEN9R`@("1P86-K86=E(&YA;64@;V8@=&AE
M('!A8VMA9V4@=&AI<R!E<G)O<B!S=&%C:R!R97!R97-E;G1S#0H@("`@("H@
M0'!A<F%M(&-A;&QB86-K("1M<V=#86QL8F%C:R!C86QL8F%C:R!U<V5D(&9O
M<B!E<G)O<B!M97-S86=E(&=E;F5R871I;VX-"B`@("`@*B!`<&%R86T@8V%L
M;&)A8VL@)&-O;G1E>'1#86QL8F%C:R!C86QL8F%C:R!U<V5D(&9O<B!C;VYT
M97AT(&=E;F5R871I;VXL#0H@("`@("H@("`@("`@("`@("`@("`@(&1E9F%U
M;'1S('1O('M`;&EN:R!G971&:6QE3&EN92@I?0T*("`@("`J($!P87)A;2!B
M;V]L96%N("`D=&AR;W=014%27T5R<F]R#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@4$5!4E]%<G)O<E-T86-K*"1P86-K86=E+"`D;7-G0V%L;&)A8VL@/2!F
M86QS92P@)&-O;G1E>'1#86QL8F%C:R`](&9A;'-E+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:')O=U!%05)?17)R;W(@/2!F86QS92D-"B`@("![
M#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G92`]("1P86-K86=E.PT*("`@("`@
M("`D=&AI<RT^<V5T365S<V%G94-A;&QB86-K*"1M<V=#86QL8F%C:RD[#0H@
M("`@("`@("1T:&ES+3YS971#;VYT97AT0V%L;&)A8VLH)&-O;G1E>'1#86QL
M8F%C:RD[#0H@("`@("`@("1T:&ES+3Y?8V]M<&%T(#T@)'1H<F]W4$5!4E]%
M<G)O<CL-"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@("`@("H@4F5T=7)N(&$@
M<VEN9VQE(&5R<F]R('-T86-K(&9O<B!T:&ES('!A8VMA9V4N#0H@("`@("H@
M#0H@("`@("H@3F]T92!T:&%T(&%L;"!P87)A;65T97)S(&%R92!I9VYO<F5D
M(&EF('1H92!S=&%C:R!F;W(@<&%C:V%G92`D<&%C:V%G90T*("`@("`J(&AA
M<R!A;')E861Y(&)E96X@:6YS=&%N=&EA=&5D#0H@("`@("H@0'!A<F%M('-T
M<FEN9R`@("1P86-K86=E(&YA;64@;V8@=&AE('!A8VMA9V4@=&AI<R!E<G)O
M<B!S=&%C:R!R97!R97-E;G1S#0H@("`@("H@0'!A<F%M(&-A;&QB86-K("1M
M<V=#86QL8F%C:R!C86QL8F%C:R!U<V5D(&9O<B!E<G)O<B!M97-S86=E(&=E
M;F5R871I;VX-"B`@("`@*B!`<&%R86T@8V%L;&)A8VL@)&-O;G1E>'1#86QL
M8F%C:R!C86QL8F%C:R!U<V5D(&9O<B!C;VYT97AT(&=E;F5R871I;VXL#0H@
M("`@("H@("`@("`@("`@("`@("`@(&1E9F%U;'1S('1O('M`;&EN:R!G971&
M:6QE3&EN92@I?0T*("`@("`J($!P87)A;2!B;V]L96%N("`D=&AR;W=014%2
M7T5R<F]R#0H@("`@("H@0'!A<F%M('-T<FEN9R`@("1S=&%C:T-L87-S(&-L
M87-S('1O(&EN<W1A;G1I871E#0H@("`@("H@0'-T871I8PT*("`@("`J($!R
M971U<FX@4$5!4E]%<G)O<E-T86-K#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M)G-I;F=L971O;B@D<&%C:V%G92P@)&US9T-A;&QB86-K(#T@9F%L<V4L("1C
M;VYT97AT0V%L;&)A8VL@/2!F86QS92P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AR;W=014%27T5R<F]R(#T@9F%L<V4L("1S=&%C:T-L87-S(#T@
M)U!%05)?17)R;W)3=&%C:R<I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H
M)$=,3T)!3%-;)U]014%27T524D]24U1!0TM?4TE.1TQ%5$].)UU;)'!A8VMA
M9V5=*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q36R=?4$5!4E]%
M4E)/4E-404-+7U-)3D=,151/3B==6R1P86-K86=E73L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@D<W1A8VM#;&%S<RDI('L-"B`@
M("`@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V1E8G5G7V)A8VMT<F%C
M92<I*2![#0H@("`@("`@("`@("`@("`@)'1R86-E(#T@9&5B=6=?8F%C:W1R
M86-E*"D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!014%27T5R<F]R
M4W1A8VLZ.G-T871I8U!U<V@H)U!%05)?17)R;W)3=&%C:R<L(%!%05)?15)2
M3U)35$%#2U]%4E)?3D].0TQ!4U,L#0H@("`@("`@("`@("`@("`@)V5X8V5P
M=&EO;B<L(&%R<F%Y*"=S=&%C:V-L87-S)R`]/B`D<W1A8VM#;&%S<RDL#0H@
M("`@("`@("`@("`@("`@)W-T86-K(&-L87-S("(E<W1A8VMC;&%S<R4B(&ES
M(&YO="!A('9A;&ED(&-L87-S(&YA;64@*'-H;W5L9"!B92!L:6ME(%!%05)?
M17)R;W)3=&%C:RDG+`T*("`@("`@("`@("`@("`@(&9A;'-E+"`D=')A8V4I
M.PT*("`@("`@("!]#0H@("`@("`@("1'3$]"04Q36R=?4$5!4E]%4E)/4E-4
M04-+7U-)3D=,151/3B==6R1P86-K86=E72`]#0H@("`@("`@("`@("!N97<@
M)'-T86-K0VQA<W,H)'!A8VMA9V4L("1M<V=#86QL8F%C:RP@)&-O;G1E>'1#
M86QL8F%C:RP@)'1H<F]W4$5!4E]%<G)O<BD[#0H-"B`@("`@("`@<F5T=7)N
M("1'3$]"04Q36R=?4$5!4E]%4E)/4E-404-+7U-)3D=,151/3B==6R1P86-K
M86=E73L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!);G1E<FYA;"!E<G)O
M<B!H86YD;&5R(&9O<B!014%27T5R<F]R4W1A8VL@8VQA<W,-"B`@("`@*B`-
M"B`@("`@*B!$:65S(&EF('1H92!E<G)O<B!I<R!A;B!E>&-E<'1I;VX@*&%N
M9"!W;W5L9"!H879E(&1I960@86YY=V%Y*0T*("`@("`J($!A8V-E<W,@<')I
M=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]H86YD;&5%<G)O<B@D97)R
M*0T*("`@('L-"B`@("`@("`@:68@*"1E<G);)VQE=F5L)UT@/3T@)V5X8V5P
M=&EO;B<I('L-"B`@("`@("`@("`@("1M97-S86=E(#T@)&5R<ELG;65S<V%G
M92==.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1?4T525D526R=215%515-4
M7U5222==*2D@>PT*("`@("`@("`@("`@("`@(&5C:&\@)SQB<B`O/B<[#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(&5C:&\@(EQN
M(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@('9A<E]D=6UP*"1E<G);
M)V-O;G1E>'0G72D[#0H@("`@("`@("`@("!D:64H)&UE<W-A9V4I.PT*("`@
M("`@("!]#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J(%-E="!U<"!A
M(%!%05(Z.DQO9R!O8FIE8W0@9F]R(&%L;"!E<G)O<B!S=&%C:W,@=&AA="!D
M;VXG="!H879E(&]N90T*("`@("`J($!P87)A;2!,;V<@)&QO9R`-"B`@("`@
M*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T1&5F875L=$QO
M9V=E<B@F)&QO9RD-"B`@("![#0H@("`@("`@(&EF("AI<U]O8FIE8W0H)&QO
M9RD@)B8@;65T:&]D7V5X:7-T<R@D;&]G+"`G;&]G)RD@*2![#0H@("`@("`@
M("`@("`D1TQ/0D%,4ULG7U!%05)?15)23U)35$%#2U]$149!54Q47TQ/1T=%
M4B==(#T@)B1L;V<[#0H@("`@("`@('T@96QS96EF("AI<U]C86QL86)L92@D
M;&]G*2D@>PT*("`@("`@("`@("`@)$=,3T)!3%-;)U]014%27T524D]24U1!
M0TM?1$5&055,5%],3T='15(G72`]("8D;&]G.PT*"7T-"B`@("!]#0H@("`@
M#0H@("`@+RHJ#0H@("`@("H@4V5T('5P(&$@4$5!4CHZ3&]G(&]B:F5C="!F
M;W(@=&AI<R!E<G)O<B!S=&%C:PT*("`@("`J($!P87)A;2!,;V<@)&QO9R`-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971,;V=G97(H)B1L;V<I#0H@("`@
M>PT*("`@("`@("!I9B`H:7-?;V)J96-T*"1L;V<I("8F(&UE=&AO9%]E>&ES
M=',H)&QO9RP@)VQO9R<I("D@>PT*("`@("`@("`@("`@)'1H:7,M/E]L;V=G
M97(@/2`F)&QO9SL-"B`@("`@("`@?2!E;'-E:68@*&ES7V-A;&QA8FQE*"1L
M;V<I*2![#0H@("`@("`@("`@("`D=&AI<RT^7VQO9V=E<B`]("8D;&]G.PT*
M("`@("`@("!]#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J(%-E="!A
M;B!E<G)O<B!C;V1E(#T^(&5R<F]R(&UE<W-A9V4@;6%P<&EN9R!C86QL8F%C
M:PT*("`@("`J(`T*("`@("`J(%1H:7,@;65T:&]D('-E=',@=&AE(&-A;&QB
M86-K('1H870@8V%N(&)E('5S960@=&\@9V5N97)A=&4@97)R;W(-"B`@("`@
M*B!M97-S86=E<R!F;W(@86YY(&EN<W1A;F-E#0H@("`@("H@0'!A<F%M(&%R
M<F%Y?'-T<FEN9R!#86QL8F%C:R!F=6YC=&EO;B]M971H;V0-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!S971-97-S86=E0V%L;&)A8VLH)&US9T-A;&QB86-K
M*0T*("`@('L-"B`@("`@("`@:68@*"$D;7-G0V%L;&)A8VLI('L-"B`@("`@
M("`@("`@("1T:&ES+3Y?;7-G0V%L;&)A8VL@/2!A<G)A>2@F)'1H:7,L("=G
M971%<G)O<DUE<W-A9V4G*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@(&EF("AI<U]C86QL86)L92@D;7-G0V%L;&)A8VLI*2![#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]M<V=#86QL8F%C:R`]("1M<V=#86QL8F%C:SL-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"B`@("`-"B`@("`O
M*BH-"B`@("`@*B!'970@86X@97)R;W(@8V]D92`]/B!E<G)O<B!M97-S86=E
M(&UA<'!I;F<@8V%L;&)A8VL-"B`@("`@*B`-"B`@("`@*B!4:&ES(&UE=&AO
M9"!R971U<FYS('1H92!C=7)R96YT(&-A;&QB86-K('1H870@8V%N(&)E('5S
M960@=&\@9V5N97)A=&4@97)R;W(-"B`@("`@*B!M97-S86=E<PT*("`@("`J
M($!R971U<FX@87)R87E\<W1R:6YG?&9A;'-E($-A;&QB86-K(&9U;F-T:6]N
M+VUE=&AO9"!O<B!F86QS92!I9B!N;VYE#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@9V5T365S<V%G94-A;&QB86-K*"D-"B`@("![#0H@("`@("`@(')E='5R
M;B`D=&AI<RT^7VUS9T-A;&QB86-K.PT*("`@('T-"B`@("`-"B`@("`O*BH-
M"B`@("`@*B!3971S(&$@9&5F875L="!C86QL8F%C:R!T;R!B92!U<V5D(&)Y
M(&%L;"!E<G)O<B!S=&%C:W,-"B`@("`@*B`-"B`@("`@*B!4:&ES(&UE=&AO
M9"!S971S('1H92!C86QL8F%C:R!T:&%T(&-A;B!B92!U<V5D('1O(&=E;F5R
M871E(&5R<F]R#0H@("`@("H@;65S<V%G97,@9F]R(&$@<VEN9VQE=&]N#0H@
M("`@("H@0'!A<F%M(&%R<F%Y?'-T<FEN9R!#86QL8F%C:R!F=6YC=&EO;B]M
M971H;V0-"B`@("`@*B!`<&%R86T@<W1R:6YG(%!A8VMA9V4@;F%M92P@;W(@
M9F%L<V4@9F]R(&%L;"!P86-K86=E<PT*("`@("`J($!S=&%T:6,-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!S971$969A=6QT0V%L;&)A8VLH)&-A;&QB86-K
M(#T@9F%L<V4L("1P86-K86=E(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I
M9B`H(6ES7V-A;&QA8FQE*"1C86QL8F%C:RDI('L-"B`@("`@("`@("`@("1C
M86QL8F%C:R`](&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1P86-K86=E
M(#T@)'!A8VMA9V4@/R`D<&%C:V%G92`Z("<J)SL-"B`@("`@("`@)$=,3T)!
M3%-;)U]014%27T524D]24U1!0TM?1$5&055,5%]#04Q,0D%#2R==6R1P86-K
M86=E72`]("1C86QL8F%C:SL-"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@("`@
M("H@4V5T(&$@8V%L;&)A8VL@=&AA="!G96YE<F%T97,@8V]N=&5X="!I;F9O
M<FUA=&EO;B`H;&]C871I;VX@;V8@97)R;W(I(&9O<B!A;B!E<G)O<B!S=&%C
M:PT*("`@("`J(`T*("`@("`J(%1H:7,@;65T:&]D('-E=',@=&AE(&-A;&QB
M86-K('1H870@8V%N(&)E('5S960@=&\@9V5N97)A=&4@8V]N=&5X=`T*("`@
M("`J(&EN9F]R;6%T:6]N(&9O<B!A;B!E<G)O<BX@(%!A<W-I;F<@:6X@3E5,
M3"!W:6QL(&1I<V%B;&4@8V]N=&5X="!G96YE<F%T:6]N#0H@("`@("H@86YD
M(')E;6]V92!T:&4@97AP96YS:79E(&-A;&P@=&\@9&5B=6=?8F%C:W1R86-E
M*"D-"B`@("`@*B!`<&%R86T@87)R87E\<W1R:6YG?&YU;&P@0V%L;&)A8VL@
M9G5N8W1I;VXO;65T:&]D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T0V]N
M=&5X=$-A;&QB86-K*"1C;VYT97AT0V%L;&)A8VLI#0H@("`@>PT*("`@("`@
M("!I9B`H)&-O;G1E>'1#86QL8F%C:R`]/3T@;G5L;"D@>PT*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?8V]N=&5X=$-A;&QB86-K(#T@9F%L<V4[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"$D8V]N=&5X=$-A;&QB86-K*2![#0H@
M("`@("`@("`@("`D=&AI<RT^7V-O;G1E>'1#86QL8F%C:R`](&%R<F%Y*"8D
M=&AI<RP@)V=E=$9I;&5,:6YE)RD[#0H@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("!I9B`H:7-?8V%L;&%B;&4H)&-O;G1E>'1#86QL8F%C:RDI('L-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;G1E>'1#86QL8F%C:R`]("1C
M;VYT97AT0V%L;&)A8VL[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("!]#0H@("`@#0H@("`@+RHJ#0H@("`@("H@4V5T(&%N(&5R<F]R($-A;&QB
M86-K#0H@("`@("H@268@<V5T('1O(&$@=F%L:60@8V%L;&)A8VLL('1H:7,@
M=VEL;"!B92!C86QL960@979E<GD@=&EM92!A;B!E<G)O<@T*("`@("`J(&ES
M('!U<VAE9"!O;G1O('1H92!S=&%C:RX@(%1H92!R971U<FX@=F%L=64@=VEL
M;"!B92!U<V5D('1O(&1E=&5R;6EN90T*("`@("`J('=H971H97(@=&\@86QL
M;W<@86X@97)R;W(@=&\@8F4@<'5S:&5D(&]R(&QO9V=E9"X-"B`@("`@*B`-
M"B`@("`@*B!4:&4@<F5T=7)N('9A;'5E(&UU<W0@8F4@;VYE(&]F('1H92!%
M4E)/4E-404-+7RH@8V]N<W1A;G1S+@T*("`@("`J(`T*("`@("`J(%1H:7,@
M9G5N8W1I;VYA;&ET>2!C86X@8F4@=7-E9"!T;R!E;75L871E(%!%05(G<R!P
M=7-H17)R;W)(86YD;&EN9RP@86YD#0H@("`@("H@=&AE(%!%05)?15)23U)?
M0T%,3$)!0TL@;6]D92P@=VET:&]U="!A9F9E8W1I;F<@=&AE(&EN=&5G<FET
M>2!O9@T*("`@("`J('1H92!E<G)O<B!S=&%C:R!O<B!L;V=G:6YG#0H@("`@
M("H@0'-E92!014%27T524D]24U1!0TM?4%532$%.1$Q/1RP@4$5!4E]%4E)/
M4E-404-+7U!54T@L(%!%05)?15)23U)35$%#2U],3T<-"B`@("`@*B!`<V5E
M('!O<$-A;&QB86-K*"D-"B`@("`@*B!`<&%R86T@<W1R:6YG?&%R<F%Y("1C
M8@T*("`@("`J+PT*("`@(&9U;F-T:6]N('!U<VA#86QL8F%C:R@D8V(I#0H@
M("`@>PT*("`@("`@("!A<G)A>5]P=7-H*"1T:&ES+3Y?97)R;W)#86QL8F%C
M:RP@)&-B*3L-"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@("`@("H@4F5M;W9E
M(&$@8V%L;&)A8VL@9G)O;2!T:&4@97)R;W(@8V%L;&)A8VL@<W1A8VL-"B`@
M("`@*B!`<V5E('!U<VA#86QL8F%C:R@I#0H@("`@("H@0')E='5R;B!A<G)A
M>7QS=')I;F=\9F%L<V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!P;W!#86QL
M8F%C:R@I#0H@("`@>PT*("`@("`@("!I9B`H(6-O=6YT*"1T:&ES+3Y?97)R
M;W)#86QL8F%C:RDI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@87)R87E?<&]P*"1T:&ES+3Y?97)R
M;W)#86QL8F%C:RD[#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J(%-E
M="!A('1E;7!O<F%R>2!O=F5R<FED:6YG(&5R<F]R(&-A;&QB86-K(&9O<B!E
M=F5R>2!P86-K86=E(&5R<F]R('-T86-K#0H@("`@("H-"B`@("`@*B!5<V4@
M=&AI<R!T;R!T96UP;W)A<FEL>2!D:7-A8FQE(&%L;"!E>&ES=&EN9R!C86QL
M8F%C:W,@*&-A;B!B92!U<V5D#0H@("`@("H@=&\@96UU;&%T92!T:&4@0"!O
M<&5R871O<BP@9F]R(&EN<W1A;F-E*0T*("`@("`J($!S964@4$5!4E]%4E)/
M4E-404-+7U!54TA!3D1,3T<L(%!%05)?15)23U)35$%#2U]055-(+"!014%2
M7T524D]24U1!0TM?3$]'#0H@("`@("H@0'-E92!S=&%T:6-0;W!#86QL8F%C
M:R@I+"!P=7-H0V%L;&)A8VLH*0T*("`@("`J($!P87)A;2!S=')I;F=\87)R
M87D@)&-B#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N
M('-T871I8U!U<VA#86QL8F%C:R@D8V(I#0H@("`@>PT*("`@("`@("!A<G)A
M>5]P=7-H*"1'3$]"04Q36R=?4$5!4E]%4E)/4E-404-+7T]615)2241%7T-!
M3$Q"04-+)UTL("1C8BD[#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J
M(%)E;6]V92!A('1E;7!O<F%R>2!O=F5R<FED:6YG(&5R<F]R(&-A;&QB86-K
M#0H@("`@("H@0'-E92!S=&%T:6-0=7-H0V%L;&)A8VLH*0T*("`@("`J($!R
M971U<FX@87)R87E\<W1R:6YG?&9A;'-E#0H@("`@("H@0'-T871I8PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N('-T871I8U!O<$-A;&QB86-K*"D-"B`@("![
M#0H@("`@("`@("1R970@/2!A<G)A>5]P;W`H)$=,3T)!3%-;)U]014%27T52
M4D]24U1!0TM?3U9%4E))1$5?0T%,3$)!0TLG72D[#0H@("`@("`@(&EF("@A
M:7-?87)R87DH)$=,3T)!3%-;)U]014%27T524D]24U1!0TM?3U9%4E))1$5?
M0T%,3$)!0TLG72DI('L-"B`@("`@("`@("`@("1'3$]"04Q36R=?4$5!4E]%
M4E)/4E-404-+7T]615)2241%7T-!3$Q"04-+)UT@/2!A<G)A>2@I.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"B`@("`-"B`@
M("`O*BH-"B`@("`@*B!!9&0@86X@97)R;W(@=&\@=&AE('-T86-K#0H@("`@
M("H@#0H@("`@("H@268@=&AE(&UE<W-A9V4@9V5N97)A=&]R(&5X:7-T<RP@
M:70@:7,@8V%L;&5D('=I=&@@,B!P87)A;65T97)S+@T*("`@("`J("`M('1H
M92!C=7)R96YT($5R<F]R(%-T86-K(&]B:F5C=`T*("`@("`J("`M(&%N(&%R
M<F%Y('1H870@:7,@:6X@=&AE('-A;64@9F]R;6%T(&%S(&%N(&5R<F]R+B`@
M079A:6QA8FQE(&EN9&EC97,-"B`@("`@*B`@("!A<F4@)V-O9&4G+"`G<&%C
M:V%G92<L("=T:6UE)RP@)W!A<F%M<R<L("=L979E;"<L(&%N9"`G8V]N=&5X
M="<-"B`@("`@*B`-"B`@("`@*B!.97AT+"!I9B!T:&4@97)R;W(@<VAO=6QD
M(&-O;G1A:6X@8V]N=&5X="!I;F9O<FUA=&EO;BP@=&AI<R!I<PT*("`@("`J
M(&AA;F1L960@8GD@=&AE(&-O;G1E>'0@9W)A8F)I;F<@;65T:&]D+@T*("`@
M("`J($9I;F%L;'DL('1H92!E<G)O<B!I<R!P=7-H960@;VYT;R!T:&4@<')O
M<&5R(&5R<F]R('-T86-K#0H@("`@("H@0'!A<F%M(&EN="`@("`D8V]D92`@
M("`@(%!A8VMA9V4M<W!E8VEF:6,@97)R;W(@8V]D90T*("`@("`J($!P87)A
M;2!S=')I;F<@)&QE=F5L("`@("!%<G)O<B!L979E;"X@(%1H:7,@:7,@3D]4
M('-P96QL+6-H96-K960-"B`@("`@*B!`<&%R86T@87)R87D@("1P87)A;7,@
M("`@87-S;V-I871I=F4@87)R87D@;V8@97)R;W(@<&%R86UE=&5R<PT*("`@
M("`J($!P87)A;2!S=')I;F<@)&US9R`@("`@("!%<G)O<B!M97-S86=E+"!O
M<B!A('!O<G1I;VX@;V8@:70@:68@=&AE(&UE<W-A9V4-"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@:7,@=&\@8F4@9V5N97)A=&5D#0H@("`@
M("H@0'!A<F%M(&%R<F%Y("`D<F5P86-K86=E($EF('1H:7,@97)R;W(@<F4M
M<&%C:V%G97,@86X@97)R;W(@<'5S:&5D(&)Y#0H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%N;W1H97(@<&%C:V%G92P@<&QA8V4@=&AE(&%R
M<F%Y(')E='5R;F5D(&9R;VT-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@>T!L:6YK('!O<"@I?2!I;B!T:&ES('!A<F%M971E<@T*("`@("`J
M($!P87)A;2!A<G)A>2`@)&)A8VMT<F%C92!0<F]T96-T960@<&%R86UE=&5R
M.B!U<V4@=&AI<R!T;R!P87-S(&EN('1H90T*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("![0&QI;FL@9&5B=6=?8F%C:W1R86-E*"E]('1H870@
M<VAO=6QD(&)E('5S960-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@=&\@9FEN9"!E<G)O<B!C;VYT97AT#0H@("`@("H@0')E='5R;B!014%2
M7T5R<F]R?&%R<F%Y?$5X8V5P=&EO;@T*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("!I9B!C;VUP871I8FEL:71Y(&UO9&4@:7,@;VXL(&$@4$5!
M4E]%<G)O<B!I<R!A;'-O#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@('1H<F]W;BX@($EF('1H92!C;&%S<R!%>&-E<'1I;VX@97AI<W1S+"!T
M:&5N(&]N90T*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!I<R!R
M971U<FYE9"!T;R!A;&QO=R!C;V1E(&QI:V4Z#0H@("`@("H@/&-O9&4^#0H@
M("`@("H@=&AR;W<@*"1S=&%C:RT^<'5S:"A-65]%4E)/4E]#3T1%+"`G97)R
M;W(G+"!A<G)A>2@G=7-E<FYA;64G(#T^("=G<F]B)RDI*3L-"B`@("`@*B`\
M+V-O9&4^#0H@("`@("H@#0H@("`@("H@5&AE(&5R<F]R1&%T82!P<F]P97)T
M>2!O9B!T:&4@97AC97!T:6]N(&-L87-S('=I;&P@8F4@<V5T('1O('1H92!A
M<G)A>0T*("`@("`J('1H870@=V]U;&0@;F]R;6%L;'D@8F4@<F5T=7)N960N
M("!)9B!A(%!%05)?17)R;W(@:7,@<F5T=7)N960L('1H92!U<V5R:6YF;PT*
M("`@("`J('!R;W!E<G1Y(&ES('-E="!T;R!T:&4@87)R87D-"B`@("`@*B`-
M"B`@("`@*B!/=&AE<G=I<V4L(&%N(&%R<F%Y(&ES(')E='5R;F5D(&EN('1H
M:7,@9F]R;6%T.@T*("`@("`J(#QC;V1E/@T*("`@("`J(&%R<F%Y*`T*("`@
M("`J("`@("=C;V1E)R`]/B`D8V]D92P-"B`@("`@*B`@("`G<&%R86US)R`]
M/B`D<&%R86US+`T*("`@("`J("`@("=P86-K86=E)R`]/B`D=&AI<RT^7W!A
M8VMA9V4L#0H@("`@("H@("`@)VQE=F5L)R`]/B`D;&5V96PL#0H@("`@("H@
M("`@)W1I;64G(#T^('1I;64H*2P-"B`@("`@*B`@("`G8V]N=&5X="<@/3X@
M)&-O;G1E>'0L#0H@("`@("H@("`@)VUE<W-A9V4G(#T^("1M<V<L#0H@("`@
M("H@+R];)W)E<&%C:V%G92<@/3X@)&5R<ET@<F5P86-K86=E9"!E<G)O<B!A
M<G)A>2]%>&-E<'1I;VX@8VQA<W,-"B`@("`@*B`I.PT*("`@("`J(#PO8V]D
M93X-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!P=7-H*"1C;V1E+"`D;&5V96P@
M/2`G97)R;W(G+"`D<&%R86US(#T@87)R87DH*2P@)&US9R`](&9A;'-E+`T*
M("`@("`@("`@("`@("`@("`@)')E<&%C:V%G92`](&9A;'-E+"`D8F%C:W1R
M86-E(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D8V]N=&5X="`](&9A;'-E
M.PT*("`@("`@("`O+R!G<F%B(&5R<F]R(&-O;G1E>'0-"B`@("`@("`@:68@
M*"1T:&ES+3Y?8V]N=&5X=$-A;&QB86-K*2![#0H@("`@("`@("`@("!I9B`H
M(21B86-K=')A8V4I('L-"B`@("`@("`@("`@("`@("`D8F%C:W1R86-E(#T@
M9&5B=6=?8F%C:W1R86-E*"D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`D8V]N=&5X="`](&-A;&Q?=7-E<E]F=6YC*"1T:&ES+3Y?8V]N=&5X=$-A
M;&QB86-K+"`D8V]D92P@)'!A<F%M<RP@)&)A8VMT<F%C92D[#0H@("`@("`@
M('T-"B`@("`@("`@#0H@("`@("`@("\O('-A=F4@97)R;W(-"B`@("`@("`@
M)'1I;64@/2!E>'!L;V1E*"<@)RP@;6EC<F]T:6UE*"DI.PT*("`@("`@("`D
M=&EM92`]("1T:6UE6S%=("L@)'1I;65;,%T[#0H@("`@("`@("1E<G(@/2!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`G8V]D92<@/3X@)&-O9&4L#0H@("`@
M("`@("`@("`@("`@)W!A<F%M<R<@/3X@)'!A<F%M<RP-"B`@("`@("`@("`@
M("`@("`G<&%C:V%G92<@/3X@)'1H:7,M/E]P86-K86=E+`T*("`@("`@("`@
M("`@("`@("=L979E;"<@/3X@)&QE=F5L+`T*("`@("`@("`@("`@("`@("=T
M:6UE)R`]/B`D=&EM92P-"B`@("`@("`@("`@("`@("`G8V]N=&5X="<@/3X@
M)&-O;G1E>'0L#0H@("`@("`@("`@("`@("`@)VUE<W-A9V4G(#T^("1M<V<L
M#0H@("`@("`@("`@("`@("`I.PT*#0H@("`@("`@(&EF("@D<F5P86-K86=E
M*2![#0H@("`@("`@("`@("`D97)R6R=R97!A8VMA9V4G72`]("1R97!A8VMA
M9V4[#0H@("`@("`@('T-"@T*("`@("`@("`O+R!S970@=7`@=&AE(&5R<F]R
M(&UE<W-A9V4L(&EF(&YE8V5S<V%R>0T*("`@("`@("!I9B`H)'1H:7,M/E]M
M<V=#86QL8F%C:RD@>PT*("`@("`@("`@("`@)&US9R`](&-A;&Q?=7-E<E]F
M=6YC7V%R<F%Y*"1T:&ES+3Y?;7-G0V%L;&)A8VLL#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)B1T:&ES+"`D97)R
M*2D[#0H@("`@("`@("`@("`D97)R6R=M97-S86=E)UT@/2`D;7-G.PT*("`@
M("`@("!]("`@("`@("`-"B`@("`@("`@)'!U<V@@/2`D;&]G(#T@=')U93L-
M"B`@("`@("`@)&1I92`](&9A;'-E.PT*("`@("`@("`O+R!T<GD@=&AE(&]V
M97)R:61I;F<@8V%L;&)A8VL@9FER<W0-"B`@("`@("`@)&-A;&QB86-K(#T@
M)'1H:7,M/G-T871I8U!O<$-A;&QB86-K*"D[#0H@("`@("`@(&EF("@D8V%L
M;&)A8VLI('L-"B`@("`@("`@("`@("1T:&ES+3YS=&%T:6-0=7-H0V%L;&)A
M8VLH)&-A;&QB86-K*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES7V-A
M;&QA8FQE*"1C86QL8F%C:RDI('L-"B`@("`@("`@("`@("\O('1R>2!T:&4@
M;&]C86P@8V%L;&)A8VL@;F5X=`T*("`@("`@("`@("`@)&-A;&QB86-K(#T@
M)'1H:7,M/G!O<$-A;&QB86-K*"D[#0H@("`@("`@("`@("!I9B`H:7-?8V%L
M;&%B;&4H)&-A;&QB86-K*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YP
M=7-H0V%L;&)A8VLH)&-A;&QB86-K*3L-"B`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@+R\@=')Y('1H92!D969A=6QT(&-A;&QB86-K
M#0H@("`@("`@("`@("`@("`@)&-A;&QB86-K(#T@:7-S970H)$=,3T)!3%-;
M)U]014%27T524D]24U1!0TM?1$5&055,5%]#04Q,0D%#2R==6R1T:&ES+3Y?
M<&%C:V%G95TI(#\-"B`@("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)U]0
M14%27T524D]24U1!0TM?1$5&055,5%]#04Q,0D%#2R==6R1T:&ES+3Y?<&%C
M:V%G95T@.@T*("`@("`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG7U!%05)?
M15)23U)35$%#2U]$149!54Q47T-!3$Q"04-+)UU;)RHG73L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-?8V%L;&%B;&4H)&-A
M;&QB86-K*2D@>PT*("`@("`@("`@("`@<W=I=&-H*&-A;&Q?=7-E<E]F=6YC
M*"1C86QL8F%C:RP@)&5R<BDI>PT*("`@("`@("`@("`@"6-A<V4@4$5!4E]%
M4E)/4E-404-+7TE'3D]213H@#0H@("`@("`@("`@("`)"7)E='5R;B`D97)R
M.PT*("`@("`@("`)"6)R96%K.PT*("`@("`@("`@("`@"6-A<V4@4$5!4E]%
M4E)/4E-404-+7U!54T@Z(`T*("`@("`@("`@("`@"0DD;&]G(#T@9F%L<V4[
M#0H@("`@("`@(`D)8G)E86L[#0H@("`@("`@("`@("`)8V%S92!014%27T52
M4D]24U1!0TM?3$]'.B`-"B`@("`@("`@("`@(`D))'!U<V@@/2!F86QS93L-
M"B`@("`@("`@"0EB<F5A:SL-"B`@("`@("`@("`@(`EC87-E(%!%05)?15)2
M3U)35$%#2U]$244Z(`T*("`@("`@("`@("`@"0DD9&EE(#T@=')U93L-"B`@
M("`@("`@"0EB<F5A:SL-"B`@("`@("`@("`@("`@("`O+R!A;GET:&EN9R!E
M;'-E(')E='5R;F5D(&AA<R!T:&4@<V%M92!E9F9E8W0@87,@<'5S:&%N9&QO
M9PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@D<'5S
M:"D@>PT*("`@("`@("`@("`@87)R87E?=6YS:&EF="@D=&AI<RT^7V5R<F]R
M<RP@)&5R<BD[#0H@("`@("`@("`@("`D=&AI<RT^7V5R<F]R<T)Y3&5V96Q;
M)&5R<ELG;&5V96PG75U;72`]("8D=&AI<RT^7V5R<F]R<ULP73L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H)&QO9RD@>PT*("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?;&]G9V5R('Q\("1'3$]"04Q36R=?4$5!4E]%4E)/4E-404-+7T1%
M1D%53%1?3$]'1T52)UTI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VQO
M9R@D97)R*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H)&1I92D@>PT*("`@("`@("`@("`@9&EE*"D[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"1T:&ES+3Y?8V]M<&%T("8F("1P=7-H*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&US9RP@)&-O9&4L(&YU
M;&PL(&YU;&PL("1E<G(I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D
M97)R.PT*("`@('T-"B`@("`-"B`@("`O*BH-"B`@("`@*B!3=&%T:6,@=F5R
M<VEO;B!O9B![0&QI;FL@<'5S:"@I?0T*("`@("`J(`T*("`@("`J($!P87)A
M;2!S=')I;F<@)'!A8VMA9V4@("!086-K86=E(&YA;64@=&AI<R!E<G)O<B!B
M96QO;F=S('1O#0H@("`@("H@0'!A<F%M(&EN="`@("`D8V]D92`@("`@(%!A
M8VMA9V4M<W!E8VEF:6,@97)R;W(@8V]D90T*("`@("`J($!P87)A;2!S=')I
M;F<@)&QE=F5L("`@("!%<G)O<B!L979E;"X@(%1H:7,@:7,@3D]4('-P96QL
M+6-H96-K960-"B`@("`@*B!`<&%R86T@87)R87D@("1P87)A;7,@("`@87-S
M;V-I871I=F4@87)R87D@;V8@97)R;W(@<&%R86UE=&5R<PT*("`@("`J($!P
M87)A;2!S=')I;F<@)&US9R`@("`@("!%<G)O<B!M97-S86=E+"!O<B!A('!O
M<G1I;VX@;V8@:70@:68@=&AE(&UE<W-A9V4-"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@:7,@=&\@8F4@9V5N97)A=&5D#0H@("`@("H@0'!A
M<F%M(&%R<F%Y("`D<F5P86-K86=E($EF('1H:7,@97)R;W(@<F4M<&%C:V%G
M97,@86X@97)R;W(@<'5S:&5D(&)Y#0H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%N;W1H97(@<&%C:V%G92P@<&QA8V4@=&AE(&%R<F%Y(')E
M='5R;F5D(&9R;VT-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M>T!L:6YK('!O<"@I?2!I;B!T:&ES('!A<F%M971E<@T*("`@("`J($!P87)A
M;2!A<G)A>2`@)&)A8VMT<F%C92!0<F]T96-T960@<&%R86UE=&5R.B!U<V4@
M=&AI<R!T;R!P87-S(&EN('1H90T*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("![0&QI;FL@9&5B=6=?8F%C:W1R86-E*"E]('1H870@<VAO=6QD
M(&)E('5S960-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=&\@
M9FEN9"!E<G)O<B!C;VYT97AT#0H@("`@("H@0')E='5R;B!014%27T5R<F]R
M?&YU;&Q\17AC97!T:6]N#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF(&-O;7!A=&EB:6QI='D@;6]D92!I<R!O;BP@82!014%27T5R<F]R
M(&ES(&%L<V\-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=&AR
M;W=N+B`@268@=&AE(&-L87-S($5X8V5P=&EO;B!E>&ES=',L('1H96X@;VYE
M#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&ES(')E='5R;F5D
M('1O(&%L;&]W(&-O9&4@;&EK93H-"B`@("`@*B`\8V]D93X-"B`@("`@*B!T
M:')O=R`H)'-T86-K+3YP=7-H*$U97T524D]27T-/1$4L("=E<G)O<B<L(&%R
M<F%Y*"=U<V5R;F%M92<@/3X@)V=R;V(G*2DI.PT*("`@("`J(#PO8V]D93X-
M"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<W1A=&EC
M4'5S:"@D<&%C:V%G92P@)&-O9&4L("1L979E;"`]("=E<G)O<B<L("1P87)A
M;7,@/2!A<G)A>2@I+`T*("`@("`@("`@("`@("`@("`@("`@("`@)&US9R`]
M(&9A;'-E+"`D<F5P86-K86=E(#T@9F%L<V4L("1B86-K=')A8V4@/2!F86QS
M92D-"B`@("![#0H@("`@("`@("1S(#T@)E!%05)?17)R;W)3=&%C:SHZ<VEN
M9VQE=&]N*"1P86-K86=E*3L-"B`@("`@("`@:68@*"1S+3Y?8V]N=&5X=$-A
M;&QB86-K*2![#0H@("`@("`@("`@("!I9B`H(21B86-K=')A8V4I('L-"B`@
M("`@("`@("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=D96)U9U]B86-K
M=')A8V4G*2D@>PT*("`@("`@("`@("`@("`@("`@("`D8F%C:W1R86-E(#T@
M9&5B=6=?8F%C:W1R86-E*"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<RT^<'5S:"@D
M8V]D92P@)&QE=F5L+"`D<&%R86US+"`D;7-G+"`D<F5P86-K86=E+"`D8F%C
M:W1R86-E*3L-"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@("`@("H@3&]G(&%N
M(&5R<F]R('5S:6YG(%!%05(Z.DQO9PT*("`@("`J($!P87)A;2!A<G)A>2`D
M97)R($5R<F]R(&%R<F%Y#0H@("`@("H@0'!A<F%M(&%R<F%Y("1L979E;',@
M17)R;W(@;&5V96P@/3X@3&]G(&-O;G-T86YT(&UA<`T*("`@("`J($!A8V-E
M<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7VQO9R@D97)R
M*0T*("`@('L-"B`@("`@("`@:68@*"1T:&ES+3Y?;&]G9V5R*2![#0H@("`@
M("`@("`@("`D;&]G9V5R(#T@)B1T:&ES+3Y?;&]G9V5R.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@)&QO9V=E<B`]("8D1TQ/0D%,4ULG7U!%
M05)?15)23U)35$%#2U]$149!54Q47TQ/1T=%4B==.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("AI<U]A*"1L;V=G97(L("=,;V<G*2D@>PT*("`@("`@("`@
M("`@)&QE=F5L<R`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("=E>&-E<'1I
M;VXG(#T^(%!%05)?3$]'7T-2250L#0H@("`@("`@("`@("`@("`@)V%L97)T
M)R`]/B!014%27TQ/1U]!3$525"P-"B`@("`@("`@("`@("`@("`G8W)I=&EC
M86PG(#T^(%!%05)?3$]'7T-2250L#0H@("`@("`@("`@("`@("`@)V5R<F]R
M)R`]/B!014%27TQ/1U]%4E(L#0H@("`@("`@("`@("`@("`@)W=A<FYI;F<G
M(#T^(%!%05)?3$]'7U=!4DY)3D<L#0H@("`@("`@("`@("`@("`@)VYO=&EC
M92<@/3X@4$5!4E],3T=?3D]424-%+`T*("`@("`@("`@("`@("`@("=I;F9O
M)R`]/B!014%27TQ/1U])3D9/+`T*("`@("`@("`@("`@("`@("=D96)U9R<@
M/3X@4$5!4E],3T=?1$5"54<I.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1L
M979E;'-;)&5R<ELG;&5V96PG75TI*2![#0H@("`@("`@("`@("`@("`@)&QE
M=F5L(#T@)&QE=F5L<ULD97)R6R=L979E;"==73L-"B`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@)&QE=F5L(#T@4$5!4E],3T=?24Y&
M3SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1L;V=G97(M/FQO9R@D
M97)R6R=M97-S86=E)UTL("1L979E;"P@)&5R<BD[#0H@("`@("`@('T@96QS
M92![("\O('-U<'!O<G0@;F]N+7-T86YD87)D(&QO9W,-"B`@("`@("`@("`@
M(&-A;&Q?=7-E<E]F=6YC*"1L;V=G97(L("1E<G(I.PT*("`@("`@("!]#0H@
M("`@?0T*#0H@("`@#0H@("`@+RHJ#0H@("`@("H@4&]P(&%N(&5R<F]R(&]F
M9B!O9B!T:&4@97)R;W(@<W1A8VL-"B`@("`@*B`-"B`@("`@*B!`<F5T=7)N
M(&9A;'-E?&%R<F%Y#0H@("`@("H@0'-I;F-E(#`N-&%L<&AA(&ET(&ES(&YO
M(&QO;F=E<B!P;W-S:6)L92!T;R!S<&5C:69Y(&$@<W!E8VEF:6,@97)R;W(-
M"B`@("`@*B!L979E;"!T;R!R971U<FX@+2!T:&4@;&%S="!E<G)O<B!P=7-H
M960@=VEL;"!B92!R971U<FYE9"P@:6YS=&5A9`T*("`@("`J+PT*("`@(&9U
M;F-T:6]N('!O<"@I#0H@("`@>PT*("`@("`@("!R971U<FX@0&%R<F%Y7W-H
M:69T*"1T:&ES+3Y?97)R;W)S*3L-"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@
M("`@("H@1&5T97)M:6YE('=H971H97(@=&AE<F4@87)E(&%N>2!E<G)O<G,@
M;VX@=&AE('-T86-K#0H@("`@("H@0'!A<F%M('-T<FEN9WQA<G)A>2!,979E
M;"!N86UE+B`@57-E('1O(&1E=&5R;6EN92!I9B!A;GD@97)R;W)S#0H@("`@
M("H@;V8@;&5V96P@*'-T<FEN9RDL(&]R(&QE=F5L<R`H87)R87DI(&AA=F4@
M8F5E;B!P=7-H960-"B`@("`@*B!`<F5T=7)N(&)O;VQE86X-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!H87-%<G)O<G,H)&QE=F5L(#T@9F%L<V4I#0H@("`@
M>PT*("`@("`@("!I9B`H)&QE=F5L*2![#0H@("`@("`@("`@("!R971U<FX@
M:7-S970H)'1H:7,M/E]E<G)O<G-">4QE=F5L6R1L979E;%TI.PT*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B!C;W5N="@D=&AI<RT^7V5R<F]R<RD[#0H@
M("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J(%)E=')I979E(&%L;"!E<G)O
M<G,@<VEN8V4@;&%S="!P=7)G90T*("`@("`J(`T*("`@("`J($!P87)A;2!B
M;V]L96%N('-E="!I;B!O<F1E<B!T;R!E;7!T>2!T:&4@97)R;W(@<W1A8VL-
M"B`@("`@*B!`<&%R86T@<W1R:6YG(&QE=F5L(&YA;64L('1O(')E='5R;B!O
M;FQY(&5R<F]R<R!O9B!A('!A<G1I8W5L87(@<V5V97)I='D-"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T17)R;W)S
M*"1P=7)G92`](&9A;'-E+"`D;&5V96P@/2!F86QS92D-"B`@("![#0H@("`@
M("`@(&EF("@A)'!U<F=E*2![#0H@("`@("`@("`@("!I9B`H)&QE=F5L*2![
M#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V5R<F]R<T)Y
M3&5V96Q;)&QE=F5L72DI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M(&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?97)R;W)S0GE,979E;%LD;&5V
M96Q=.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?97)R;W)S.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@D;&5V96PI('L-
M"B`@("`@("`@("`@("1R970@/2`D=&AI<RT^7V5R<F]R<T)Y3&5V96Q;)&QE
M=F5L73L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?97)R;W)S0GE,
M979E;%LD;&5V96Q=(&%S("1I(#T^("1U;G5S960I('L-"B`@("`@("`@("`@
M("`@("`O+R!E;G1R:65S(&%R92!R969E<F5N8V5S('1O('1H92`D7V5R<F]R
M<R!A<G)A>0T*("`@("`@("`@("`@("`@("1T:&ES+3Y?97)R;W)S0GE,979E
M;%LD;&5V96Q=6R1I72`](&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@+R\@87)R87E?9FEL=&5R(')E;6]V97,@86QL(&5N=')I97,@/3T]
M(&9A;'-E#0H@("`@("`@("`@("`D=&AI<RT^7V5R<F]R<R`](&%R<F%Y7V9I
M;'1E<B@D=&AI<RT^7V5R<F]R<RD[#0H@("`@("`@("`@("!U;G-E="@D=&AI
M<RT^7V5R<F]R<T)Y3&5V96Q;)&QE=F5L72D[#0H@("`@("`@("`@("!R971U
M<FX@)')E=#L-"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@)'1H:7,M/E]E
M<G)O<G,[#0H@("`@("`@("1T:&ES+3Y?97)R;W)S(#T@87)R87DH*3L-"B`@
M("`@("`@)'1H:7,M/E]E<G)O<G-">4QE=F5L(#T@87)R87DH*3L-"B`@("`@
M("`@<F5T=7)N("1R970[#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J
M($1E=&5R;6EN92!W:&5T:&5R('1H97)E(&%R92!A;GD@97)R;W)S(&]N(&$@
M<VEN9VQE(&5R<F]R('-T86-K+"!O<B!O;B!A;GD@97)R;W(@<W1A8VL-"B`@
M("`@*@T*("`@("`J(%1H92!O<'1I;VYA;"!P87)A;65T97(@8V%N(&)E('5S
M960@=&\@=&5S="!T:&4@97AI<W1E;F-E(&]F(&%N>2!E<G)O<G,@=VET:&]U
M="!T:&4@;F5E9"!O9@T*("`@("`J('-I;F=L971O;B!I;G-T86YT:6%T:6]N
M#0H@("`@("H@0'!A<F%M('-T<FEN9WQF86QS92!086-K86=E(&YA;64@=&\@
M8VAE8VL@9F]R(&5R<F]R<PT*("`@("`J($!P87)A;2!S=')I;F<@3&5V96P@
M;F%M92!T;R!C:&5C:R!F;W(@82!P87)T:6-U;&%R('-E=F5R:71Y#0H@("`@
M("H@0')E='5R;B!B;V]L96%N#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*
M("`@(&9U;F-T:6]N('-T871I8TAA<T5R<F]R<R@D<&%C:V%G92`](&9A;'-E
M+"`D;&5V96P@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@D<&%C:V%G
M92D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D1TQ/0D%,4ULG7U!%05)?
M15)23U)35$%#2U]324Y'3$543TXG75LD<&%C:V%G95TI*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@<F5T=7)N("1'3$]"04Q36R=?4$5!4E]%4E)/4E-404-+7U-)3D=,
M151/3B==6R1P86-K86=E72T^:&%S17)R;W)S*"1L979E;"D[#0H@("`@("`@
M('T-"B`@("`@("`@9F]R96%C:"`H)$=,3T)!3%-;)U]014%27T524D]24U1!
M0TM?4TE.1TQ%5$].)UT@87,@)'!A8VMA9V4@/3X@)&]B:BD@>PT*("`@("`@
M("`@("`@:68@*"1O8FHM/FAA<T5R<F]R<R@D;&5V96PI*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"B`@("`-"B`@("`O
M*BH-"B`@("`@*B!'970@82!L:7-T(&]F(&%L;"!E<G)O<G,@<VEN8V4@;&%S
M="!P=7)G92P@;W)G86YI>F5D(&)Y('!A8VMA9V4-"B`@("`@*B!`<VEN8V4@
M4$5!4B`Q+C0N,&1E=B!"0R!B<F5A:R$@)&QE=F5L(&ES(&YO=R!I;B!T:&4@
M<&QA8V4@)&UE<F=E('5S960@=&\@8F4-"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D<'5R9V4@4V5T('1O('!U<F=E('1H92!E<G)O<B!S=&%C:R!O9B!E>&ES
M=&EN9R!E<G)O<G,-"B`@("`@*B!`<&%R86T@<W1R:6YG("`D;&5V96P@4V5T
M('1O(&$@;&5V96P@;F%M92!I;B!O<F1E<B!T;R!R971R:65V92!O;FQY(&5R
M<F]R<R!O9B!A('!A<G1I8W5L87(@;&5V96P-"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D;65R9V4@4V5T('1O(')E='5R;B!A(&9L870@87)R87DL(&YO="!O
M<F=A;FEZ960@8GD@<&%C:V%G90T*("`@("`J($!P87)A;2!A<G)A>2`@("1S
M;W)T9G5N8R!&=6YC=&EO;B!U<V5D('1O('-O<G0@82!M97)G960@87)R87D@
M+2!D969A=6QT#0H@("`@("H@("`@("`@('-O<G1S(&)Y('1I;64L(&%N9"!S
M:&]U;&0@8F4@9V]O9"!F;W(@;6]S="!C87-E<PT*("`@("`J($!S=&%T:6,-
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y(`T*("`@("`J+PT*("`@(&9U;F-T:6]N
M('-T871I8T=E=$5R<F]R<R@D<'5R9V4@/2!F86QS92P@)&QE=F5L(#T@9F%L
M<V4L("1M97)G92`](&9A;'-E+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<V]R=&9U;F,@/2!A<G)A>2@G4$5!4E]%<G)O<E-T86-K)RP@)U]S
M;W)T17)R;W)S)RDI#0H@("`@>PT*("`@("`@("`D<F5T(#T@87)R87DH*3L-
M"B`@("`@("`@:68@*"%I<U]C86QL86)L92@D<V]R=&9U;F,I*2![#0H@("`@
M("`@("`@("`D<V]R=&9U;F,@/2!A<G)A>2@G4$5!4E]%<G)O<E-T86-K)RP@
M)U]S;W)T17)R;W)S)RD[#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H
M)$=,3T)!3%-;)U]014%27T524D]24U1!0TM?4TE.1TQ%5$].)UT@87,@)'!A
M8VMA9V4@/3X@)&]B:BD@>PT*("`@("`@("`@("`@)'1E<W0@/2`D1TQ/0D%,
M4ULG7U!%05)?15)23U)35$%#2U]324Y'3$543TXG75LD<&%C:V%G95TM/F=E
M=$5R<F]R<R@D<'5R9V4L("1L979E;"D[#0H@("`@("`@("`@("!I9B`H)'1E
M<W0I('L-"B`@("`@("`@("`@("`@("!I9B`H)&UE<F=E*2![#0H@("`@("`@
M("`@("`@("`@("`@("1R970@/2!A<G)A>5]M97)G92@D<F5T+"`D=&5S="D[
M#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@)')E=%LD<&%C:V%G95T@/2`D=&5S=#L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1M97)G
M92D@>PT*("`@("`@("`@("`@=7-O<G0H)')E="P@)'-O<G1F=6YC*3L-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H@("`@#0H@
M("`@+RHJ#0H@("`@("H@17)R;W(@<V]R=&EN9R!F=6YC=&EO;BP@<V]R=',@
M8GD@=&EM90T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(%]S;W)T17)R;W)S*"1A+"`D8BD-"B`@("![#0H@("`@("`@
M(&EF("@D85LG=&EM92==(#T]("1B6R=T:6UE)UTI('L-"B`@("`@("`@("`@
M(')E='5R;B`P.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D85LG=&EM92==
M(#P@)&);)W1I;64G72D@>PT*("`@("`@("`@("`@<F5T=7)N(#$[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N("TQ.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("`J(%-T86YD87)D(&9I;&4O;&EN92!N=6UB97(O9G5N8W1I;VXO8VQA
M<W,@8V]N=&5X="!C86QL8F%C:PT*("`@("`J#0H@("`@("H@5&AI<R!F=6YC
M=&EO;B!U<V5S(&$@8F%C:W1R86-E(&=E;F5R871E9"!F<F]M('M`;&EN:R!D
M96)U9U]B86-K=')A8V4H*7T-"B`@("`@*B!A;F0@<V\@=VEL;"!N;W0@=V]R
M:R!A="!A;&P@:6X@4$A0(#P@-"XS+C`N("!4:&4@9G)A;64@<VAO=6QD#0H@
M("`@("H@<F5F97)E;F-E('1H92!F<F%M92!T:&%T(&-O;G1A:6YS('1H92!S
M;W5R8V4@;V8@=&AE(&5R<F]R+@T*("`@("`J($!R971U<FX@87)R87E\9F%L
M<V4@96ET:&5R(&%R<F%Y*"=F:6QE)R`]/B!F:6QE+"`G;&EN92<@/3X@;&EN
M92P-"B`@("`@*B`@("`@("`@("=F=6YC=&EO;B<@/3X@9G5N8W1I;VX@;F%M
M92P@)V-L87-S)R`]/B!C;&%S<R!N86UE*2!O<@T*("`@("`J("`@("`@("`@
M:68@=&AI<R!D;V5S;B=T('=O<FLL('1H96X@9F%L<V4-"B`@("`@*B!`<&%R
M86T@=6YU<V5D#0H@("`@("H@0'!A<F%M(&EN=&5G97(@8F%C:W1R86-E(&9R
M86UE+@T*("`@("`J($!P87)A;2!A<G)A>2!297-U;'1S(&]F(&1E8G5G7V)A
M8VMT<F%C92@I#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&=E=$9I;&5,:6YE*"1C;V1E+"`D<&%R86US+"`D8F%C:W1R86-E(#T@
M;G5L;"D-"B`@("![#0H@("`@("`@(&EF("@D8F%C:W1R86-E(#T]/2!N=6QL
M*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@
M("`@("`@)&9R86UE(#T@,#L-"B`@("`@("`@)&9U;F-T:6]N9G)A;64@/2`Q
M.PT*("`@("`@("!I9B`H(6ES<V5T*"1B86-K=')A8V5;,5TI*2![#0H@("`@
M("`@("`@("`D9G5N8W1I;VYF<F%M92`](#`[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("!W:&EL92`H:7-S970H)&)A8VMT<F%C95LD9G5N8W1I
M;VYF<F%M95U;)V9U;F-T:6]N)UTI("8F#0H@("`@("`@("`@("`@("`@("`D
M8F%C:W1R86-E6R1F=6YC=&EO;F9R86UE75LG9G5N8W1I;VXG72`]/2`G979A
M;"<@)B8-"B`@("`@("`@("`@("`@("`@(&ES<V5T*"1B86-K=')A8V5;)&9U
M;F-T:6]N9G)A;64@*R`Q72DI('L-"B`@("`@("`@("`@("`@("`D9G5N8W1I
M;VYF<F%M92LK.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(&EF("AI<W-E="@D8F%C:W1R86-E6R1F<F%M95TI*2![#0H@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1B86-K=')A8V5;)&9R86UE75LG9FEL92==*2D@>PT*
M("`@("`@("`@("`@("`@("1F<F%M92LK.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)&9U;F-B86-K=')A8V4@/2`D8F%C:W1R86-E6R1F=6YC=&EO
M;F9R86UE73L-"B`@("`@("`@("`@("1F:6QE8F%C:W1R86-E(#T@)&)A8VMT
M<F%C95LD9G)A;65=.PT*("`@("`@("`@("`@)')E="`](&%R<F%Y*"=F:6QE
M)R`]/B`D9FEL96)A8VMT<F%C95LG9FEL92==+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("=L:6YE)R`]/B`D9FEL96)A8VMT<F%C95LG;&EN92==*3L-
M"B`@("`@("`@("`@("\O(')E87)R86YG92!F;W(@979A;"=D(&-O9&4@;W(@
M8W)E871E(&9U;F-T:6]N(&5R<F]R<PT*("`@("`@("`@("`@:68@*'-T<G!O
M<R@D9FEL96)A8VMT<F%C95LG9FEL92==+"`G*"<I("8F(`T*("`@("`@("`@
M("`@"2`@<')E9U]M871C:"@G.UXH+BH_*5PH*%QD*RE<*2`Z("@N*C\I)#LG
M+"`D9FEL96)A8VMT<F%C95LG9FEL92==+`T*("`@("`@("`@("`@("`@("`@
M)&UA=&-H97,I*2![#0H@("`@("`@("`@("`@("`@)')E=%LG9FEL92==(#T@
M)&UA=&-H97-;,5T[#0H@("`@("`@("`@("`@("`@)')E=%LG;&EN92==(#T@
M)&UA=&-H97-;,ET@*R`P.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*&ES<V5T*"1F=6YC8F%C:W1R86-E6R=F=6YC=&EO;B==*2`F)B!I<W-E
M="@D8F%C:W1R86-E6S%=*2D@>PT*("`@("`@("`@("`@("`@(&EF("@D9G5N
M8V)A8VMT<F%C95LG9G5N8W1I;VXG72`A/2`G979A;"<I('L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1F=6YC8F%C:W1R86-E6R=F=6YC=&EO;B==(#T]
M("=?7VQA;6)D85]F=6YC)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)')E=%LG9G5N8W1I;VXG72`]("=C<F5A=&5?9G5N8W1I;VXH*2!C;V1E)SL-
M"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1R971;)V9U;F-T:6]N)UT@/2`D9G5N8V)A8VMT<F%C95LG
M9G5N8W1I;VXG73L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E
M="@D9G5N8V)A8VMT<F%C95LG8VQA<W,G72D@)B8@:7-S970H)&)A8VMT<F%C
M95LQ72DI('L-"B`@("`@("`@("`@("`@("`D<F5T6R=C;&%S<R==(#T@)&9U
M;F-B86-K=')A8V5;)V-L87-S)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!R971U<FX@)')E=#L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J(%-T86YD87)D
M(&5R<F]R(&UE<W-A9V4@9V5N97)A=&EO;B!C86QL8F%C:PT*("`@("`J(`T*
M("`@("`J(%1H:7,@;65T:&]D(&UA>2!A;'-O(&)E(&-A;&QE9"!B>2!A(&-U
M<W1O;2!E<G)O<B!M97-S86=E(&=E;F5R871O<@T*("`@("`J('1O(&9I;&P@
M:6X@=&5M<&QA=&4@=F%L=65S(&9R;VT@=&AE('!A<F%M<R!A<G)A>2P@<VEM
M<&QY#0H@("`@("H@<V5T('1H92!T:&ER9"!P87)A;65T97(@=&\@=&AE(&5R
M<F]R(&UE<W-A9V4@=&5M<&QA=&4@<W1R:6YG('1O('5S90T*("`@("`J(`T*
M("`@("`J(%1H92!S<&5C:6%L('9A<FEA8FQE("5?7VUS9R4@:7,@<F5S97)V
M960Z('5S92!I="!O;FQY('1O('-P96-I9GD-"B`@("`@*B!W:&5R92!A(&UE
M<W-A9V4@<&%S<V5D(&EN(&)Y('1H92!U<V5R('-H;W5L9"!B92!P;&%C960@
M:6X@=&AE('1E;7!L871E+`T*("`@("`J(&QI:V4@<V\Z#0H@("`@("H@#0H@
M("`@("H@17)R;W(@;65S<V%G93H@)6US9R4@+2!I;G1E<FYA;"!E<G)O<@T*
M("`@("`J(`T*("`@("`J($EF('1H92!M97-S86=E('!A<W-E9"!L:6ME('-O
M.@T*("`@("`J(`T*("`@("`J(#QC;V1E/@T*("`@("`J("1S=&%C:RT^<'5S
M:"A%4E)/4E]#3T1%+"`G97)R;W(G+"!A<G)A>2@I+"`G<V5R=F5R(&5R<F]R
M(#4P,"<I.PT*("`@("`J(#PO8V]D93X-"B`@("`@*B`-"B`@("`@*B!4:&4@
M<F5T=7)N960@97)R;W(@;65S<V%G92!W:6QL(&)E(")%<G)O<B!M97-S86=E
M.B!S97)V97(@97)R;W(@-3`P("T-"B`@("`@*B!I;G1E<FYA;"!E<G)O<B(-
M"B`@("`@*B!`<&%R86T@4$5!4E]%<G)O<E-T86-K#0H@("`@("H@0'!A<F%M
M(&%R<F%Y#0H@("`@("H@0'!A<F%M('-T<FEN9WQF86QS92!0<F4M9V5N97)A
M=&5D(&5R<F]R(&UE<W-A9V4@=&5M<&QA=&4-"B`@("`@*B!`<W1A=&EC#0H@
M("`@("H@0')E='5R;B!S=')I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G
M971%<G)O<DUE<W-A9V4H)B1S=&%C:RP@)&5R<BP@)'1E;7!L871E(#T@9F%L
M<V4I#0H@("`@>PT*("`@("`@("!I9B`H)'1E;7!L871E*2![#0H@("`@("`@
M("`@("`D;6%I;FUS9R`]("1T96UP;&%T93L-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("1M86EN;7-G(#T@)'-T86-K+3YG971%<G)O<DUE<W-A
M9V5496UP;&%T92@D97)R6R=C;V1E)UTI.PT*("`@("`@("!]#0H@("`@("`@
M("1M86EN;7-G(#T@<W1R7W)E<&QA8V4H)R5?7VUS9R4G+"`D97)R6R=M97-S
M86=E)UTL("1M86EN;7-G*3L-"B`@("`@("`@:68@*&ES7V%R<F%Y*"1E<G);
M)W!A<F%M<R==*2`F)B!C;W5N="@D97)R6R=P87)A;7,G72DI('L-"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1E<G);)W!A<F%M<R==(&%S("1N86UE(#T^("1V
M86PI('L-"B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)'9A;"DI('L-
M"B`@("`@("`@("`@("`@("`@("`@+R\@0"!I<R!N965D960@:6X@8V%S92`D
M=F%L(&ES(&$@;75L=&DM9&EM96YS:6]N86P@87)R87D-"B`@("`@("`@("`@
M("`@("`@("`@)'9A;"`]($!I;7!L;V1E*"<L("<L("1V86PI.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H:7-?;V)J96-T*"1V
M86PI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AM971H;V1?97AI<W1S
M*"1V86PL("=?7W1O4W1R:6YG)RDI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1V86P@/2`D=F%L+3Y?7W1O4W1R:6YG*"D[#0H@("`@("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("!014%2
M7T5R<F]R4W1A8VLZ.G-T871I8U!U<V@H)U!%05)?17)R;W)3=&%C:R<L(%!%
M05)?15)23U)35$%#2U]%4E)?3T)*5$]35%))3D<L#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W=A<FYI;F<G+"!A<G)A>2@G;V)J)R`]/B!G971?
M8VQA<W,H)'9A;"DI+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=O
M8FIE8W0@)6]B:B4@<&%S<V5D(&EN=&\@9V5T17)R;W)-97-S86=E+"!B=70@
M:&%S(&YO(%]?=&]3=')I;F<H*2!M971H;V0G*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1V86P@/2`G3V)J96-T)SL-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D;6%I
M;FUS9R`]('-T<E]R97!L86-E*"<E)R`N("1N86UE("X@)R4G+"`D=F%L+"`D
M;6%I;FUS9RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N("1M86EN;7-G.PT*("`@('T-"B`@("`-"B`@("`O*BH-"B`@("`@
M*B!3=&%N9&%R9"!%<G)O<B!-97-S86=E(%1E;7!L871E(&=E;F5R871O<B!F
M<F]M(&-O9&4-"B`@("`@*B!`<F5T=7)N('-T<FEN9PT*("`@("`J+PT*("`@
M(&9U;F-T:6]N(&=E=$5R<F]R365S<V%G951E;7!L871E*"1C;V1E*0T*("`@
M('L-"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V5R<F]R37-G<ULD8V]D
M95TI*2![#0H@("`@("`@("`@("!R971U<FX@)R5?7VUS9R4G.PT*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B`D=&AI<RT^7V5R<F]R37-G<ULD8V]D95T[
M#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J(%-E="!T:&4@17)R;W(@
M365S<V%G92!496UP;&%T92!A<G)A>0T*("`@("`J(`T*("`@("`J(%1H92!A
M<G)A>2!F;W)M870@;75S="!B93H-"B`@("`@*B`\<')E/@T*("`@("`J(&%R
M<F%Y*&5R<F]R(&-O9&4@/3X@)VUE<W-A9V4@=&5M<&QA=&4G+"XN+BD-"B`@
M("`@*B`\+W!R93X-"B`@("`@*B`-"B`@("`@*B!%<G)O<B!M97-S86=E('!A
M<F%M971E<G,@<&%S<V5D(&EN=&\@>T!L:6YK('!U<V@H*7T@=VEL;"!B92!U
M<V5D(&%S(&EN<'5T#0H@("`@("H@9F]R('1H92!E<G)O<B!M97-S86=E+B`@
M268@=&AE('1E;7!L871E(&ES("=M97-S86=E("5F;V\E('=A<R`E8F%R)2<L
M(&%N9"!T:&4-"B`@("`@*B!P87)A;65T97)S(&%R92!A<G)A>2@G9F]O)R`]
M/B`G;VYE)RP@)V)A<B<@/3X@)W-I>"<I+"!T:&4@97)R;W(@;65S<V%G92!R
M971U<FYE9"!W:6QL#0H@("`@("H@8F4@)VUE<W-A9V4@;VYE('=A<R!S:7@G
M#0H@("`@("H@0')E='5R;B!S=')I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!S971%<G)O<DUE<W-A9V5496UP;&%T92@D=&5M<&QA=&4I#0H@("`@>PT*
M("`@("`@("`D=&AI<RT^7V5R<F]R37-G<R`]("1T96UP;&%T93L-"B`@("!]
M#0H@("`@#0H@("`@#0H@("`@+RHJ#0H@("`@("H@96UU;&%T92!014%2.CIR
M86ES945R<F]R*"D-"B`@("`@*B`-"B`@("`@*B!`<F5T=7)N(%!%05)?17)R
M;W(-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!R86ES945R<F]R*"D-"B`@("![
M#0H@("`@("`@(')E<75I<F5?;VYC92`G4$5!4BYP:'`G.PT*("`@("`@("`D
M87)G<R`](&9U;F-?9V5T7V%R9W,H*3L-"B`@("`@("`@<F5T=7)N(&-A;&Q?
M=7-E<E]F=6YC7V%R<F%Y*&%R<F%Y*"=014%2)RP@)W)A:7-E17)R;W(G*2P@
M)&%R9W,I.PT*("`@('T-"GT-"B1S=&%C:R`]("9014%27T5R<F]R4W1A8VLZ
M.G-I;F=L971O;B@G4$5!4E]%<G)O<E-T86-K)RD[#0HD<W1A8VLM/G!U<VA#
M86QL8F%C:RAA<G)A>2@G4$5!4E]%<G)O<E-T86-K)RP@)U]H86YD;&5%<G)O
M<B<I*3L-"C\^#0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]%>&-E<'1I;VXN<&AP````
M````````````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S$V,3``,3`U,34T
M,S,W-#$`,#(R,#`Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP#0HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O
M<#TT('-H:69T=VED=&@]-"!F;VQD;65T:&]D/6UA<FME<CH@*B\-"B\J*@T*
M("H@4$5!4E]%>&-E<'1I;VX-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@
M-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C
M="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@
M:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H
M92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F
M#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN
M(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T
M;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I
M;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C
M:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!4;VUA<R!6+B!6+B!#;W@@
M/&-O>$!I9&5C;F5T+F-O;3X-"B`J($!A=71H;W(@("`@($AA;G,@3&5L;&5L
M:60@/&AA;G-`=F5L=6TN;F5T/@T*("H@0&%U=&AO<B`@("`@0F5R=')A;F0@
M36%N<VEO;B`\8FUA;G-I;VY`;6%M87-A;2YC;VT^#0H@*B!`875T:&]R("`@
M("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT
M("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@
M,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@17AC97!T:6]N+G!H<"QV
M(#$N,C,@,C`P-B\P,2\P-B`P-#HT-SHS-B!C96QL;V<@17AP("0-"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@
M*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N
M,RXS#0H@*B\-"@T*#0HO*BH-"B`J($)A<V4@4$5!4E]%>&-E<'1I;VX@0VQA
M<W,-"B`J#0H@*B`Q*2!&96%T=7)E<SH-"B`J#0H@*B`M($YE<W1A8FQE(&5X
M8V5P=&EO;G,@*'1H<F]W(&YE=R!014%27T5X8V5P=&EO;B@D;7-G+"`D<')E
M=E]E>&-E<'1I;VXI*0T*("H@+2!$969I;F%B;&4@=')I9V=E<G,L('-H;W0@
M=VAE;B!E>&-E<'1I;VYS(&]C8W5R#0H@*B`M(%!R971T>2!A;F0@:6YF;W)M
M871I=F4@97)R;W(@;65S<V%G97,-"B`J("T@061D960@;6]R92!C;VYT97AT
M(&EN9F\@879A:6QA8FQE("AL:6ME(&-L87-S+"!M971H;V0@;W(@8V%U<V4I
M#0H@*B`M(&-A=7-E(&-A;B!B92!A(%!%05)?17AC97!T:6]N(&]R(&%N(&%R
M<F%Y(&]F(&UI>&5D#0H@*B`@(%!%05)?17AC97!T:6]N<R]014%27T5R<F]R
M4W1A8VL@=V%R;FEN9W,-"B`J("T@8V%L;&)A8VMS(&9O<B!S<&5C:69I8R!E
M>&-E<'1I;VX@8VQA<W-E<R!A;F0@=&AE:7(@8VAI;&1R96X-"B`J#0H@*B`R
M*2!)9&5A<SH-"B`J#0H@*B`M($UA>6)E(&$@=V%Y('1O(&1E9FEN92!A("=T
M96UP;&%T92<@9F]R('1H92!O=71P=70-"B`J#0H@*B`S*2!);FAE<FET960@
M<')O<&5R=&EE<R!F<F]M(%!(4"!%>&-E<'1I;VX@0VQA<W,Z#0H@*@T*("H@
M<')O=&5C=&5D("1M97-S86=E#0H@*B!P<F]T96-T960@)&-O9&4-"B`J('!R
M;W1E8W1E9"`D;&EN90T*("H@<')O=&5C=&5D("1F:6QE#0H@*B!P<FEV871E
M("`@)'1R86-E#0H@*@T*("H@-"D@26YH97)I=&5D(&UE=&AO9',@9G)O;2!0
M2%`@17AC97!T:6]N($-L87-S.@T*("H-"B`J(%]?8VQO;F4-"B`J(%]?8V]N
M<W1R=6-T#0H@*B!G971-97-S86=E#0H@*B!G971#;V1E#0H@*B!G971&:6QE
M#0H@*B!G971,:6YE#0H@*B!G9714<F%C95-A9F4-"B`J(&=E=%1R86-E4V%F
M94%S4W1R:6YG#0H@*B!?7W1O4W1R:6YG#0H@*@T*("H@-2D@57-A9V4@97AA
M;7!L90T*("H-"B`J(#QC;V1E/@T*("H@(')E<75I<F5?;VYC92`G4$5!4B]%
M>&-E<'1I;VXN<&AP)SL-"B`J#0H@*B`@8VQA<W,@5&5S="![#0H@*B`@("`@
M9G5N8W1I;VX@9F]O*"D@>PT*("H@("`@("`@("!T:')O=R!N97<@4$5!4E]%
M>&-E<'1I;VXH)T5R<F]R($UE<W-A9V4G+"!%4E)/4E]#3T1%*3L-"B`J("`@
M("!]#0H@*B`@?0T*("H-"B`J("!F=6YC=&EO;B!M>4QO9V=E<B@D<&5A<E]E
M>&-E<'1I;VXI('L-"B`J("`@("!E8VAO("1P96%R7V5X8V5P=&EO;BT^9V5T
M365S<V%G92@I.PT*("H@('T-"B`J("`O+R!E86-H('1I;64@82!E>&-E<'1I
M;VX@:7,@=&AR;W=N('1H92`G;7E,;V=G97(G('=I;&P@8F4@8V%L;&5D#0H@
M*B`@+R\@*&ET<R!U<V4@:7,@8V]M<&QE=&5L>2!O<'1I;VYA;"D-"B`J("!0
M14%27T5X8V5P=&EO;CHZ861D3V)S97)V97(H)VUY3&]G9V5R)RD[#0H@*B`@
M)'1E<W0@/2!N97<@5&5S=#L-"B`J("!T<GD@>PT*("H@("`@("1T97-T+3YF
M;V\H*3L-"B`J("!](&-A=&-H("A014%27T5X8V5P=&EO;B`D92D@>PT*("H@
M("`@('!R:6YT("1E.PT*("H@('T-"B`J(#PO8V]D93X-"B`J#0H@*B!`8V%T
M96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R
M("`@("!4;VUA<R!6+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^#0H@*B!`875T
M:&]R("`@("!(86YS($QE;&QE;&ED(#QH86YS0'9E;'5M+FYE=#X-"B`J($!A
M=71H;W(@("`@($)E<G1R86YD($UA;G-I;VX@/&)M86YS:6]N0&UA;6%S86TN
M8V]M/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N
M;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-
M"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S
M93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@
M<VEN8V4@4F5L96%S92`Q+C,N,PT*("H-"B`J+PT*8VQA<W,@4$5!4E]%>&-E
M<'1I;VX@97AT96YD<R!%>&-E<'1I;VX-"GL-"B`@("!C;VYS="!/0E-%4E9%
M4E]04DE.5"`]("TR.PT*("`@(&-O;G-T($]"4T525D527U1224='15(@/2`M
M-#L-"B`@("!C;VYS="!/0E-%4E9%4E]$244@/2`M.#L-"B`@("!P<F]T96-T
M960@)&-A=7-E.PT*("`@('!R:79A=&4@<W1A=&EC("1?;V)S97)V97)S(#T@
M87)R87DH*3L-"B`@("!P<FEV871E('-T871I8R`D7W5N:7%U96ED(#T@,#L-
M"B`@("!P<FEV871E("1?=')A8V4[#0H-"B`@("`O*BH-"B`@("`@*B!3=7!P
M;W)T960@<VEG;F%T=7)E<SH-"B`@("`@*B!014%27T5X8V5P=&EO;BAS=')I
M;F<@)&UE<W-A9V4I.PT*("`@("`J(%!%05)?17AC97!T:6]N*'-T<FEN9R`D
M;65S<V%G92P@:6YT("1C;V1E*3L-"B`@("`@*B!014%27T5X8V5P=&EO;BAS
M=')I;F<@)&UE<W-A9V4L($5X8V5P=&EO;B`D8V%U<V4I.PT*("`@("`J(%!%
M05)?17AC97!T:6]N*'-T<FEN9R`D;65S<V%G92P@17AC97!T:6]N("1C875S
M92P@:6YT("1C;V1E*3L-"B`@("`@*B!014%27T5X8V5P=&EO;BAS=')I;F<@
M)&UE<W-A9V4L(&%R<F%Y("1C875S97,I.PT*("`@("`J(%!%05)?17AC97!T
M:6]N*'-T<FEN9R`D;65S<V%G92P@87)R87D@)&-A=7-E<RP@:6YT("1C;V1E
M*3L-"B`@("`@*B\-"B`@("!P=6)L:6,@9G5N8W1I;VX@7U]C;VYS=')U8W0H
M)&UE<W-A9V4L("1P,B`](&YU;&PL("1P,R`](&YU;&PI#0H@("`@>PT*("`@
M("`@("!I9B`H:7-?:6YT*"1P,BDI('L-"B`@("`@("`@("`@("1C;V1E(#T@
M)'`R.PT*("`@("`@("`@("`@)'1H:7,M/F-A=7-E(#T@;G5L;#L-"B`@("`@
M("`@?2!E;'-E:68@*"1P,B!I;G-T86YC96]F($5X8V5P=&EO;B!\?"!I<U]A
M<G)A>2@D<#(I*2![#0H@("`@("`@("`@("`D8V]D92`]("1P,SL-"B`@("`@
M("`@("`@(&EF("AI<U]A<G)A>2@D<#(I("8F(&ES<V5T*"1P,ELG;65S<V%G
M92==*2D@>PT*("`@("`@("`@("`@("`@("\O(&9I>"!P;W1E;G1I86P@<')O
M8FQE;2!O9B!P87-S:6YG(&EN(&$@<VEN9VQE('=A<FYI;F<-"B`@("`@("`@
M("`@("`@("`D<#(@/2!A<G)A>2@D<#(I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)'1H:7,M/F-A=7-E(#T@)'`R.PT*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@)&-O9&4@/2!N=6QL.PT*("`@("`@("`@("`@)'1H
M:7,M/F-A=7-E(#T@;G5L;#L-"B`@("`@("`@?0T*("`@("`@("!P87)E;G0Z
M.E]?8V]N<W1R=6-T*"1M97-S86=E+"`D8V]D92D[#0H@("`@("`@("1T:&ES
M+3YS:6=N86PH*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@
M;6EX960@)&-A;&QB86-K("`M($$@=F%L:60@<&AP(&-A;&QB86-K+"!S964@
M<&AP(&9U;F,@:7-?8V%L;&%B;&4H*0T*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("T@02!014%27T5X8V5P=&EO;CHZ3T)315)615)?*B!C;VYS
M=&%N=`T*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@06X@87)R
M87DH8V]N<W0@4$5!4E]%>&-E<'1I;VXZ.D]"4T525D527RHL#0H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("!M:7AE9"`D;W!T:6]N<RD-"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1L86)E;"`@("!4:&4@;F%M92!O9B!T:&4@
M;V)S97)V97(N(%5S92!T:&ES(&EF('EO=2!W86YT#0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@=&\@<F5M;W9E(&ET(&QA=&5R('=I=&@@<F5M
M;W9E3V)S97)V97(H*0T*("`@("`J+PT*("`@('!U8FQI8R!S=&%T:6,@9G5N
M8W1I;VX@861D3V)S97)V97(H)&-A;&QB86-K+"`D;&%B96P@/2`G9&5F875L
M="<I#0H@("`@>PT*("`@("`@("!S96QF.CHD7V]B<V5R=F5R<ULD;&%B96Q=
M(#T@)&-A;&QB86-K.PT*("`@('T-"@T*("`@('!U8FQI8R!S=&%T:6,@9G5N
M8W1I;VX@<F5M;W9E3V)S97)V97(H)&QA8F5L(#T@)V1E9F%U;'0G*0T*("`@
M('L-"B`@("`@("`@=6YS970H<V5L9CHZ)%]O8G-E<G9E<G-;)&QA8F5L72D[
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0')E='5R;B!I;G0@=6YI<75E
M(&ED96YT:69I97(@9F]R(&%N(&]B<V5R=F5R#0H@("`@("HO#0H@("`@<'5B
M;&EC('-T871I8R!F=6YC=&EO;B!G9715;FEQ=65)9"@I#0H@("`@>PT*("`@
M("`@("!R971U<FX@<V5L9CHZ)%]U;FEQ=65I9"LK.PT*("`@('T-"@T*("`@
M('!R:79A=&4@9G5N8W1I;VX@<VEG;F%L*"D-"B`@("![#0H@("`@("`@(&9O
M<F5A8V@@*'-E;&8Z.B1?;V)S97)V97)S(&%S("1F=6YC*2![#0H@("`@("`@
M("`@("!I9B`H:7-?8V%L;&%B;&4H)&9U;F,I*2![#0H@("`@("`@("`@("`@
M("`@8V%L;%]U<V5R7V9U;F,H)&9U;F,L("1T:&ES*3L-"B`@("`@("`@("`@
M("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@('-E
M='1Y<&4H)&9U;F,L("=A<G)A>2<I.PT*("`@("`@("`@("`@<W=I=&-H("@D
M9G5N8ULP72D@>PT*("`@("`@("`@("`@("`@(&-A<V4@<V5L9CHZ3T)315)6
M15)?4%))3E0@.@T*("`@("`@("`@("`@("`@("`@("`D9B`]("AI<W-E="@D
M9G5N8ULQ72DI(#\@)&9U;F-;,5T@.B`G)7,G.PT*("`@("`@("`@("`@("`@
M("`@("!P<FEN=&8H)&8L("1T:&ES+3YG971-97-S86=E*"DI.PT*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!C87-E('-E
M;&8Z.D]"4T525D527U1224='15(@.@T*("`@("`@("`@("`@("`@("`@("`D
M9B`]("AI<W-E="@D9G5N8ULQ72DI(#\@)&9U;F-;,5T@.B!%7U5315)?3D]4
M24-%.PT*("`@("`@("`@("`@("`@("`@("!T<FEG9V5R7V5R<F]R*"1T:&ES
M+3YG971-97-S86=E*"DL("1F*3L-"B`@("`@("`@("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@("`@("`@("`@8V%S92!S96QF.CI/0E-%4E9%4E]$244@
M.@T*("`@("`@("`@("`@("`@("`@("`D9B`]("AI<W-E="@D9G5N8ULQ72DI
M(#\@)&9U;F-;,5T@.B`G)7,G.PT*("`@("`@("`@("`@("`@("`@("!D:64H
M<')I;G1F*"1F+"`D=&AI<RT^9V5T365S<V%G92@I*2D[#0H@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@(&1E9F%U;'0Z#0H@
M("`@("`@("`@("`@("`@("`@('1R:6=G97)?97)R;W(H)VEN=F%L:60@;V)S
M97)V97(@='EP92<L($5?55-%4E]705).24Y'*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J(%)E='5R;B!S
M<&5C:69I8R!E<G)O<B!I;F9O<FUA=&EO;B!T:&%T(&-A;B!B92!U<V5D(&9O
M<B!M;W)E(&1E=&%I;&5D#0H@("`@("H@97)R;W(@;65S<V%G97,@;W(@=')A
M;G-L871I;VXN#0H@("`@("H-"B`@("`@*B!4:&ES(&UE=&AO9"!M87D@8F4@
M;W9E<G)I9&1E;B!I;B!C:&EL9"!E>&-E<'1I;VX@8VQA<W-E<R!I;B!O<F1E
M<@T*("`@("`J('1O(&%D9"!F=6YC=&EO;F%L:71Y(&YO="!P<F5S96YT(&EN
M(%!%05)?17AC97!T:6]N(&%N9"!I<R!A('!L86-E:&]L9&5R#0H@("`@("H@
M=&\@9&5F:6YE($%020T*("`@("`J#0H@("`@("H@5&AE(')E='5R;F5D(&%R
M<F%Y(&UU<W0@8F4@86X@87-S;V-I871I=F4@87)R87D@;V8@<&%R86UE=&5R
M(#T^('9A;'5E(&QI:V4@<V\Z#0H@("`@("H@/'!R93X-"B`@("`@*B!A<G)A
M>2@G;F%M92<@/3X@)&YA;64L("=C;VYT97AT)R`]/B!A<G)A>2@N+BXI*0T*
M("`@("`J(#PO<')E/@T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@*B\-
M"B`@("!P=6)L:6,@9G5N8W1I;VX@9V5T17)R;W)$871A*"D-"B`@("![#0H@
M("`@("`@(')E='5R;B!A<G)A>2@I.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("`J(%)E='5R;G,@=&AE(&5X8V5P=&EO;B!T:&%T(&-A=7-E9"!T:&ES(&5X
M8V5P=&EO;B!T;R!B92!T:')O=VX-"B`@("`@*B!`86-C97-S('!U8FQI8PT*
M("`@("`J($!R971U<FX@17AC97!T:6]N?&%R<F%Y(%1H92!C;VYT97AT(&]F
M('1H92!E>&-E<'1I;VX-"B`@("`@*B\-"B`@("!P=6)L:6,@9G5N8W1I;VX@
M9V5T0V%U<V4H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YC875S
M93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!&=6YC=&EO;B!M=7-T(&)E
M('!U8FQI8R!T;R!C86QL(&]N(&-A=7-E9"!E>&-E<'1I;VYS#0H@("`@("H@
M0'!A<F%M(&%R<F%Y#0H@("`@("HO#0H@("`@<'5B;&EC(&9U;F-T:6]N(&=E
M=$-A=7-E365S<V%G92@F)&-A=7-E<RD-"B`@("![#0H@("`@("`@("1T<F%C
M92`]("1T:&ES+3YG9714<F%C95-A9F4H*3L-"B`@("`@("`@)&-A=7-E(#T@
M87)R87DH)V-L87-S)R`@(#T^(&=E=%]C;&%S<R@D=&AI<RDL#0H@("`@("`@
M("`@("`@("`@("`@("`@("=M97-S86=E)R`]/B`D=&AI<RT^;65S<V%G92P-
M"B`@("`@("`@("`@("`@("`@("`@("`@)V9I;&4G(#T^("=U;FMN;W=N)RP-
M"B`@("`@("`@("`@("`@("`@("`@("`@)VQI;F4G(#T^("=U;FMN;W=N)RD[
M#0H@("`@("`@(&EF("AI<W-E="@D=')A8V5;,%TI*2![#0H@("`@("`@("`@
M("!I9B`H:7-S970H)'1R86-E6S!=6R=F:6QE)UTI*2![#0H@("`@("`@("`@
M("`@("`@)&-A=7-E6R=F:6QE)UT@/2`D=')A8V5;,%U;)V9I;&4G73L-"B`@
M("`@("`@("`@("`@("`D8V%U<V5;)VQI;F4G72`]("1T<F%C95LP75LG;&EN
M92==.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1C875S
M97-;72`]("1C875S93L-"B`@("`@("`@:68@*"1T:&ES+3YC875S92!I;G-T
M86YC96]F(%!%05)?17AC97!T:6]N*2![#0H@("`@("`@("`@("`D=&AI<RT^
M8V%U<V4M/F=E=$-A=7-E365S<V%G92@D8V%U<V5S*3L-"B`@("`@("`@?2!E
M;'-E:68@*"1T:&ES+3YC875S92!I;G-T86YC96]F($5X8V5P=&EO;BD@>PT*
M("`@("`@("`@("`@)&-A=7-E<UM=(#T@87)R87DH)V-L87-S)R`@(#T^(&=E
M=%]C;&%S<R@D8V%U<V4I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VUE<W-A9V4G(#T^("1C875S92T^9V5T365S<V%G92@I+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V9I;&4G(#T^("1C875S92T^9V5T1FEL92@I
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI;F4G(#T^("1C875S
M92T^9V5T3&EN92@I*3L-"@T*("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH
M)'1H:7,M/F-A=7-E*2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M
M/F-A=7-E(&%S("1C875S92D@>PT*("`@("`@("`@("`@("`@(&EF("@D8V%U
M<V4@:6YS=&%N8V5O9B!014%27T5X8V5P=&EO;BD@>PT*("`@("`@("`@("`@
M("`@("`@("`D8V%U<V4M/F=E=$-A=7-E365S<V%G92@D8V%U<V5S*3L-"B`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H)&-A=7-E(&EN<W1A;F-E;V8@17AC
M97!T:6]N*2![#0H@("`@("`@("`@("`@("`@("`@("1C875S97-;72`](&%R
M<F%Y*"=C;&%S<R<@("`]/B!G971?8VQA<W,H)&-A=7-E*2P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUE<W-A9V4G(#T^("1C875S
M92T^9V5T365S<V%G92@I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G9FEL92<@/3X@)&-A=7-E+3YG971&:6QE*"DL#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=L:6YE)R`]/B`D8V%U<V4M
M/F=E=$QI;F4H*2D[#0H@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES7V%R
M<F%Y*"1C875S92D@)B8@:7-S970H)&-A=7-E6R=M97-S86=E)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("\O(%!%05)?17)R;W)3=&%C:R!W87)N:6YG
M#0H@("`@("`@("`@("`@("`@("`@("1C875S97-;72`](&%R<F%Y*`T*("`@
M("`@("`@("`@("`@("`@("`@("`@)V-L87-S)R`]/B`D8V%U<V5;)W!A8VMA
M9V4G72P-"B`@("`@("`@("`@("`@("`@("`@("`@("=M97-S86=E)R`]/B`D
M8V%U<V5;)VUE<W-A9V4G72P-"B`@("`@("`@("`@("`@("`@("`@("`@("=F
M:6QE)R`]/B!I<W-E="@D8V%U<V5;)V-O;G1E>'0G75LG9FEL92==*2`_#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C
M875S95LG8V]N=&5X="==6R=F:6QE)UT@.@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=6YK;F]W;B<L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`G;&EN92<@/3X@:7-S970H)&-A=7-E6R=C;VYT
M97AT)UU;)VQI;F4G72D@/PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D8V%U<V5;)V-O;G1E>'0G75LG;&EN92==(#H-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W5N:VYO=VXG+`T*("`@("`@("`@("`@("`@("`@("`I.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"@T*
M("`@('!U8FQI8R!F=6YC=&EO;B!G9714<F%C95-A9F4H*0T*("`@('L@("`-
M"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W1R86-E*2D@>PT*("`@("`@
M("`@("`@)'1H:7,M/E]T<F%C92`]("1T:&ES+3YG9714<F%C92@I.PT*("`@
M("`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?=')A8V4I*2![#0H@("`@("`@
M("`@("`@("`@)&)A8VMT<F%C92`](&1E8G5G7V)A8VMT<F%C92@I.PT*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?=')A8V4@/2!A<G)A>2@D8F%C:W1R86-E
M6V-O=6YT*"1B86-K=')A8V4I+3%=*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/E]T<F%C93L-"B`@("!]#0H-
M"B`@("!P=6)L:6,@9G5N8W1I;VX@9V5T17)R;W)#;&%S<R@I#0H@("`@>PT*
M("`@("`@("`D=')A8V4@/2`D=&AI<RT^9V5T5')A8V53869E*"D[#0H@("`@
M("`@(')E='5R;B`D=')A8V5;,%U;)V-L87-S)UT[#0H@("`@?0T*#0H@("`@
M<'5B;&EC(&9U;F-T:6]N(&=E=$5R<F]R365T:&]D*"D-"B`@("![#0H@("`@
M("`@("1T<F%C92`]("1T:&ES+3YG9714<F%C95-A9F4H*3L-"B`@("`@("`@
M<F5T=7)N("1T<F%C95LP75LG9G5N8W1I;VXG73L-"B`@("!]#0H-"B`@("!P
M=6)L:6,@9G5N8W1I;VX@7U]T;U-T<FEN9R@I#0H@("`@>PT*("`@("`@("!I
M9B`H:7-S970H)%]315)615);)U)%455%4U1?55)))UTI*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G1O2'1M;"@I.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B`D=&AI<RT^=&]497AT*"D[#0H@("`@?0T*#0H@("`@<'5B
M;&EC(&9U;F-T:6]N('1O2'1M;"@I#0H@("`@>PT*("`@("`@("`D=')A8V4@
M/2`D=&AI<RT^9V5T5')A8V53869E*"D[#0H@("`@("`@("1C875S97,@/2!A
M<G)A>2@I.PT*("`@("`@("`D=&AI<RT^9V5T0V%U<V5-97-S86=E*"1C875S
M97,I.PT*("`@("`@("`D:'1M;"`]("`G/'1A8FQE(&)O<F1E<CTB,2(@8V5L
M;'-P86-I;F<](C`B/B<@+B`B7&XB.PT*("`@("`@("!F;W)E86-H("@D8V%U
M<V5S(&%S("1I(#T^("1C875S92D@>PT*("`@("`@("`@("`@)&AT;6P@+CT@
M)SQT<CX\=&0@8V]L<W!A;CTB,R(@8F=C;VQO<CTB(V9F.3DY.2(^)PT*("`@
M("`@("`@("`@("`@+B!S=')?<F5P96%T*"<M)RP@)&DI("X@)R`\8CXG("X@
M)&-A=7-E6R=C;&%S<R==("X@)SPO8CXZ("<-"B`@("`@("`@("`@("`@("X@
M:'1M;'-P96-I86QC:&%R<R@D8V%U<V5;)VUE<W-A9V4G72D@+B`G(&EN(#QB
M/B<@+B`D8V%U<V5;)V9I;&4G72`N("<\+V(^("<-"B`@("`@("`@("`@("`@
M("X@)V]N(&QI;F4@/&(^)R`N("1C875S95LG;&EN92==("X@)SPO8CXG#0H@
M("`@("`@("`@("`@("`N("(\+W1D/CPO='(^7&XB.PT*("`@("`@("!]#0H@
M("`@("`@("1H=&UL("X]("<\='(^/'1D(&-O;'-P86X](C,B(&)G8V]L;W(]
M(B-A86%A86$B(&%L:6=N/2)C96YT97(B/CQB/D5X8V5P=&EO;B!T<F%C93PO
M8CX\+W1D/CPO='(^)R`N(")<;B(-"B`@("`@("`@("`@("`@("X@)SQT<CX\
M=&0@86QI9VX](F-E;G1E<B(@8F=C;VQO<CTB(V-C8V-C8R(@=VED=&@](C(P
M(CX\8CXC/"]B/CPO=&0^)PT*("`@("`@("`@("`@("`@+B`G/'1D(&%L:6=N
M/2)C96YT97(B(&)G8V]L;W(](B-C8V-C8V,B/CQB/D9U;F-T:6]N/"]B/CPO
M=&0^)PT*("`@("`@("`@("`@("`@+B`G/'1D(&%L:6=N/2)C96YT97(B(&)G
M8V]L;W(](B-C8V-C8V,B/CQB/DQO8V%T:6]N/"]B/CPO=&0^/"]T<CXG("X@
M(EQN(CL-"@T*("`@("`@("!F;W)E86-H("@D=')A8V4@87,@)&L@/3X@)'8I
M('L-"B`@("`@("`@("`@("1H=&UL("X]("<\='(^/'1D(&%L:6=N/2)C96YT
M97(B/B<@+B`D:R`N("<\+W1D/B<-"B`@("`@("`@("`@("`@("`@("`N("<\
M=&0^)SL-"B`@("`@("`@("`@(&EF("@A96UP='DH)'9;)V-L87-S)UTI*2![
M#0H@("`@("`@("`@("`@("`@)&AT;6P@+CT@)'9;)V-L87-S)UT@+B`D=ELG
M='EP92==.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&AT;6P@+CT@
M)'9;)V9U;F-T:6]N)UT[#0H@("`@("`@("`@("`D87)G<R`](&%R<F%Y*"D[
M#0H@("`@("`@("`@("!I9B`H(65M<'1Y*"1V6R=A<F=S)UTI*2![#0H@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)'9;)V%R9W,G72!A<R`D87)G*2![#0H@
M("`@("`@("`@("`@("`@("`@(&EF("AI<U]N=6QL*"1A<F<I*2`D87)G<UM=
M(#T@)VYU;&PG.PT*("`@("`@("`@("`@("`@("`@("!E;'-E:68@*&ES7V%R
M<F%Y*"1A<F<I*2`D87)G<UM=(#T@)T%R<F%Y)SL-"B`@("`@("`@("`@("`@
M("`@("`@96QS96EF("AI<U]O8FIE8W0H)&%R9RDI("1A<F=S6UT@/2`G3V)J
M96-T*"<N9V5T7V-L87-S*"1A<F<I+B<I)SL-"B`@("`@("`@("`@("`@("`@
M("`@96QS96EF("AI<U]B;V]L*"1A<F<I*2`D87)G<UM=(#T@)&%R9R`_("=T
M<G5E)R`Z("=F86QS92<[#0H@("`@("`@("`@("`@("`@("`@(&5L<V5I9B`H
M:7-?:6YT*"1A<F<I('Q\(&ES7V1O=6)L92@D87)G*2D@)&%R9W-;72`]("1A
M<F<[#0H@("`@("`@("`@("`@("`@("`@(&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)&%R9R`]("AS=')I;F<I)&%R9SL-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1S='(@/2!H=&UL<W!E8VEA;&-H87)S*'-U8G-T<B@D
M87)G+"`P+"`Q-BDI.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*'-T
M<FQE;B@D87)G*2`^(#$V*2`D<W1R("X]("<F:&5L;&EP.R<[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D87)G<UM=(#T@(B<B("X@)'-T<B`N("(G(CL-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("1H=&UL("X]("<H)R`N(&EM<&QO
M9&4H)RP@)RPD87)G<RD@+B`G*2<-"B`@("`@("`@("`@("`@("`@("`N("<\
M+W1D/B<-"B`@("`@("`@("`@("`@("`@("`N("<\=&0^)R`N("AI<W-E="@D
M=ELG9FEL92==*2`_("1V6R=F:6QE)UT@.B`G=6YK;F]W;B<I#0H@("`@("`@
M("`@("`@("`@("`@+B`G.B<@+B`H:7-S970H)'9;)VQI;F4G72D@/R`D=ELG
M;&EN92==(#H@)W5N:VYO=VXG*0T*("`@("`@("`@("`@("`@("`@("X@)SPO
M=&0^/"]T<CXG("X@(EQN(CL-"B`@("`@("`@?0T*("`@("`@("`D:'1M;"`N
M/2`G/'1R/CQT9"!A;&EG;CTB8V5N=&5R(CXG("X@*"1K*S$I("X@)SPO=&0^
M)PT*("`@("`@("`@("`@("`@+B`G/'1D/GMM86EN?3PO=&0^)PT*("`@("`@
M("`@("`@("`@+B`G/'1D/B9N8G-P.SPO=&0^/"]T<CXG("X@(EQN(@T*("`@
M("`@("`@("`@("`@+B`G/"]T86)L93XG.PT*("`@("`@("!R971U<FX@)&AT
M;6P[#0H@("`@?0T*#0H@("`@<'5B;&EC(&9U;F-T:6]N('1O5&5X="@I#0H@
M("`@>PT*("`@("`@("`D8V%U<V5S(#T@87)R87DH*3L-"B`@("`@("`@)'1H
M:7,M/F=E=$-A=7-E365S<V%G92@D8V%U<V5S*3L-"B`@("`@("`@)&-A=7-E
M37-G(#T@)R<[#0H@("`@("`@(&9O<F5A8V@@*"1C875S97,@87,@)&D@/3X@
M)&-A=7-E*2![#0H@("`@("`@("`@("`D8V%U<V5-<V<@+CT@<W1R7W)E<&5A
M="@G("<L("1I*2`N("1C875S95LG8VQA<W,G72`N("<Z("<-"B`@("`@("`@
M("`@("`@("`@("`N("1C875S95LG;65S<V%G92==("X@)R!I;B`G("X@)&-A
M=7-E6R=F:6QE)UT-"B`@("`@("`@("`@("`@("`@("`N("<@;VX@;&EN92`G
M("X@)&-A=7-E6R=L:6YE)UT@+B`B7&XB.PT*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B`D8V%U<V5-<V<@+B`D=&AI<RT^9V5T5')A8V5!<U-T<FEN9R@I
M.PT*("`@('T-"GT-"@T*/SX`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]&<F]N=&5N
M9"\`````````````````````````````````````````````````````````
M````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`U,34T,S,W-#``,#(Q,3`W`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]014%2+T9R;VYT96YD+T-,22YP:'``````````````````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`V-#0P-0`Q,#4Q-30S,S<T,``P,C(R-#``(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`-"B\J
M*@T*("H@4$5!4E]&<F]N=&5N9%]#3$D-"B`J#0H@*B!02%`@=F5R<VEO;G,@
M-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@
M<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J
M('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C
M;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@
M;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@
M;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@
M8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@
M*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME
M;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\
M8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE
M(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO
M;B`@("!#5E,Z("1)9#H@0TQ)+G!H<"QV(#$N-3D@,C`P-B\P,R\P,B`Q,SHQ
M-CHQ.2!P86IO>64@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V
M86EL86)L92!S:6YC92!296QE87-E(#`N,0T*("HO#0HO*BH-"B`J(&)A<V4@
M8VQA<W,-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+T9R;VYT96YD+G!H<"<[
M#0H-"B\J*@T*("H@0V]M;6%N9"UL:6YE($9R;VYT96YD(&9O<B!T:&4@4$5!
M4B!);G-T86QL97(-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E
M("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP
M+FYE=#X-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP
M+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P
M#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A
M<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE
M('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"F-L87-S(%!%05)?1G)O;G1E;F1?
M0TQ)(&5X=&5N9',@4$5!4E]&<F]N=&5N9`T*>PT*("`@("\O('M[>R!P<F]P
M97)T:65S#0H-"B`@("`O*BH-"B`@("`@*B!7:&%T('1Y<&4@;V8@=7-E<B!I
M;G1E<F9A8V4@=&AI<R!F<F]N=&5N9"!I<R!F;W(N#0H@("`@("H@0'9A<B!S
M=')I;F<-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@('9A
M<B`D='EP92`]("=#3$DG.PT*("`@('9A<B`D;'`@/2`G)SL@+R\@;&EN92!P
M<F5F:7@-"@T*("`@('9A<B`D<&%R86US(#T@87)R87DH*3L-"B`@("!V87(@
M)'1E<FT@/2!A<G)A>2@-"B`@("`@("`@)V)O;&0G(#T^("<G+`T*("`@("`@
M("`G;F]R;6%L)R`]/B`G)RP-"B`@("`@("`@*3L-"@T*("`@("\O('U]?0T*
M#0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R#0H-"B`@("!F=6YC=&EO;B!014%2
M7T9R;VYT96YD7T-,22@I#0H@("`@>PT*("`@("`@("!P87)E;G0Z.E!%05(H
M*3L-"B`@("`@("`@)'1E<FT@/2!G971E;G8H)U1%4DTG*3L@+R\H8V]X*2`D
M7T5.5B!I<R!E;7!T>2!F;W(@;64@:6X@-"XQ+C$-"B`@("`@("`@:68@*&9U
M;F-T:6]N7V5X:7-T<R@G<&]S:7A?:7-A='1Y)RD@)B8@(7!O<VEX7VES871T
M>2@Q*2D@>PT*("`@("`@("`@("`@+R\@;W5T<'5T(&ES(&)E:6YG(')E9&ER
M96-T960@=&\@82!F:6QE(&]R('1H<F]U9V@@82!P:7!E#0H@("`@("`@('T@
M96QS96EF("@D=&5R;2D@>PT*("`@("`@("`@("`@+R\@6%A8(&-A;B!U<V4@
M;F-U<G-E<R!E>'1E;G-I;VX@:&5R92P@:68@879A:6QA8FQE#0H@("`@("`@
M("`@("!I9B`H<')E9U]M871C:"@G+UXH>'1E<FU\=G0R,C!\;&EN=7@I+R<L
M("1T97)M*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YT97)M6R=B;VQD
M)UT@/2!S<')I;G1F*"(E8R5C)6,E8R(L(#(W+"`Y,2P@-#DL(#$P.2D[#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/G1E<FU;)VYO<FUA;"==/7-P<FEN=&8H
M(B5C)6,E8R(L(#(W+"`Y,2P@,3`Y*3L-"B`@("`@("`@("`@('T@96QS96EF
M("AP<F5G7VUA=&-H*"<O7G9T,3`P+R<L("1T97)M*2D@>PT*("`@("`@("`@
M("`@("`@("1T:&ES+3YT97)M6R=B;VQD)UT@/2!S<')I;G1F*"(E8R5C)6,E
M8R5C)6,B+"`R-RP@.3$L(#0Y+"`Q,#DL(#`L(#`I.PT*("`@("`@("`@("`@
M("`@("1T:&ES+3YT97)M6R=N;W)M86PG73US<')I;G1F*"(E8R5C)6,E8R5C
M(BP@,C<L(#DQ+"`Q,#DL(#`L(#`I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!](&5L<V5I9B`H3U-?5TE.1$]74RD@>PT*("`@("`@("`@("`@+R\@6%A8
M(&%D9"!!3E-)(&-O9&5S(&AE<F4-"B`@("`@("`@?0T*("`@('T-"@T*("`@
M("\O('U]?0T*#0H@("`@+R\@>WM[(&1I<W!L87E,:6YE*'1E>'0I#0H-"B`@
M("!F=6YC=&EO;B!D:7-P;&%Y3&EN92@D=&5X="D-"B`@("![#0H@("`@("`@
M('1R:6=G97)?97)R;W(H(E!%05)?1G)O;G1E;F1?0TQ).CID:7-P;&%Y3&EN
M92!D97!R96-A=&5D(BP@15]54T527T524D]2*3L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!?9&ES<&QA>4QI;F4H)'1E>'0I#0H@("`@>PT*("`@("`@("!P
M<FEN="`B)'1H:7,M/FQP)'1E>'1<;B([#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[(&1I<W!L87DH=&5X="D-"@T*("`@(&9U;F-T:6]N(&1I
M<W!L87DH)'1E>'0I#0H@("`@>PT*("`@("`@("!T<FEG9V5R7V5R<F]R*")0
M14%27T9R;VYT96YD7T-,23HZ9&ES<&QA>2!D97!R96-A=&5D(BP@15]54T52
M7T524D]2*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?9&ES<&QA>2@D=&5X
M="D-"B`@("![#0H@("`@("`@('!R:6YT("1T97AT.PT*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!D:7-P;&%Y17)R;W(H96]B:BD-"@T*("`@
M("\J*@T*("`@("`J($!P87)A;2!O8FIE8W0@4$5!4E]%<G)O<B!O8FIE8W0-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!D:7-P;&%Y17)R;W(H)&5O8FHI#0H@
M("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/E]D:7-P;&%Y3&EN92@D96]B
M:BT^9V5T365S<V%G92@I*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O
M+R![>WL@9&ES<&QA>49A=&%L17)R;W(H96]B:BD-"@T*("`@("\J*@T*("`@
M("`J($!P87)A;2!O8FIE8W0@4$5!4E]%<G)O<B!O8FIE8W0-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!D:7-P;&%Y1F%T86Q%<G)O<B@D96]B:BD-"B`@("![
M#0H@("`@("`@("1T:&ES+3YD:7-P;&%Y17)R;W(H)&5O8FHI.PT*("`@("`@
M("!I9B`H8VQA<W-?97AI<W1S*"=014%27T-O;F9I9R<I*2![#0H@("`@("`@
M("`@("`D8V]N9FEG(#T@)E!%05)?0V]N9FEG.CIS:6YG;&5T;VXH*3L-"B`@
M("`@("`@("`@(&EF("@D8V]N9FEG+3YG970H)W9E<F)O<V4G*2`^(#4I('L-
M"B`@("`@("`@("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=D96)U9U]P
M<FEN=%]B86-K=')A8V4G*2D@>PT*("`@("`@("`@("`@("`@("`@("!D96)U
M9U]P<FEN=%]B86-K=')A8V4H*3L-"B`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H9G5N8W1I;VY?97AI<W1S*"=D96)U9U]B86-K=')A8V4G*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D=')A8V4@/2!D96)U9U]B86-K=')A8V4H*3L-
M"B`@("`@("`@("`@("`@("`@("`@)')A:7-E9"`](&9A;'-E.PT*("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("@D=')A8V4@87,@)&D@/3X@)&9R86UE
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(21R86ES960I('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&9R86UE
M6R=C;&%S<R==*2`F)B!S=')T;VQO=V5R*"1F<F%M95LG8VQA<W,G72D@/3T-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&5A<B<@)B8@
M<W1R=&]L;W=E<B@D9G)A;65;)V9U;F-T:6]N)UTI(#T]("=R86ES965R<F]R
M)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F%I<V5D
M(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!`)'1H:7,M
M/E]D:7-P;&%Y3&EN92@B(R1I.B`D9G)A;65;8VQA<W-=)&9R86UE6W1Y<&5=
M)&9R86UE6V9U;F-T:6]N72`D9G)A;65;;&EN95TB*3L-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!E>&ET*#$I.PT*("`@('T-"@T*("`@("\O
M('U]?0T*("`@("\O('M[>R!D:7-P;&%Y2&5A9&EN9RAT:71L92D-"@T*("`@
M(&9U;F-T:6]N(&1I<W!L87E(96%D:6YG*"1T:71L92D-"B`@("![#0H@("`@
M("`@('1R:6=G97)?97)R;W(H(E!%05)?1G)O;G1E;F1?0TQ).CID:7-P;&%Y
M2&5A9&EN9R!D97!R96-A=&5D(BP@15]54T527T524D]2*3L-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!?9&ES<&QA>4AE861I;F<H)'1I=&QE*0T*("`@('L-
M"B`@("`@("`@<')I;G0@)'1H:7,M/FQP+B1T:&ES+3YB;VQD*"1T:71L92DN
M(EQN(CL-"B`@("`@("`@<')I;G0@)'1H:7,M/FQP+G-T<E]R97!E870H(CTB
M+"!S=')L96XH)'1I=&QE*2DN(EQN(CL-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"@T*("`@("\J*@T*("`@("`J($EN<W1R=6-T('1H92!R=6Y);G-T86QL4V-R
M:7!T(&UE=&AO9"!T;R!S:VEP(&$@<&%R86UG<F]U<"!T:&%T(&UA=&-H97,@
M=&AE#0H@("`@("H@:60@=F%L=64@<&%S<V5D(&EN+@T*("`@("`J#0H@("`@
M("H@5&AI<R!M971H;V0@:7,@=7-E9G5L(&9O<B!D>6YA;6EC86QL>2!C;VYF
M:6=U<FEN9R!W:&EC:"!S96-T:6]N<R!O9B!A('!O<W0M:6YS=&%L;"!S8W)I
M<'0-"B`@("`@*B!W:6QL(&)E(')U;B!B87-E9"!O;B!T:&4@=7-E<B=S('-E
M='5P+"!W:&EC:"!I<R!V97)Y('5S969U;"!F;W(@;6%K:6YG(&9L97AI8FQE
M#0H@("`@("H@<&]S="UI;G-T86QL('-C<FEP=',@=VET:&]U="!L;W-I;F<@
M=&AE(&-R;W-S+49R;VYT96YD(&%B:6QI='D@=&\@<F5T<FEE=F4@=7-E<B!I
M;G!U=`T*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!S:VEP4&%R86UG<F]U<"@D:60I#0H@("`@>PT*("`@("`@("`D=&AI
M<RT^7W-K:7!396-T:6]N<ULD:61=(#T@=')U93L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!R=6Y0;W-T:6YS=&%L;%-C<FEP=',H)B1S8W)I<'1S*0T*("`@
M('L-"B`@("`@("`@9F]R96%C:"`H)'-C<FEP=',@87,@)&D@/3X@)'-C<FEP
M="D@>PT*("`@("`@("`@("`@)'1H:7,M/G)U;DEN<W1A;&Q38W)I<'0H)'-C
M<FEP='-;)&E=+3Y?<&%R86US+"`D<V-R:7!T<ULD:5TM/E]O8FHI.PT*("`@
M("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&%R<F%Y
M("1X;6P@8V]N=&5N=',@;V8@<&]S=&EN<W1A;&QS8W)I<'0@=&%G#0H@("`@
M("H@0'!A<F%M(&]B:F5C="`D<V-R:7!T('!O<W0M:6YS=&%L;&%T:6]N('-C
M<FEP=`T*("`@("`J($!P87)A;2!S=')I;F<@:6YS=&%L;'QU<&=R861E#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@<G5N26YS=&%L;%-C<FEP="@D>&UL+"`F
M)'-C<FEP="D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<VMI<%-E8W1I;VYS
M(#T@87)R87DH*3L-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D>&UL*2!\?"`A
M:7-S970H)'AM;%LG<&%R86UG<F]U<"==*2D@>PT*("`@("`@("`@("`@)'-C
M<FEP="T^<G5N*&%R<F%Y*"DL("=?9&5F875L="<I.PT*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@)&-O;7!L971E9%!H87-E<R`](&%R<F%Y*"D[
M#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1X;6Q;)W!A<F%M9W)O=7`G75LP
M72DI('L-"B`@("`@("`@("`@("`@("`D>&UL6R=P87)A;6=R;W5P)UT@/2!A
M<G)A>2@D>&UL6R=P87)A;6=R;W5P)UTI.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@9F]R96%C:"`H)'AM;%LG<&%R86UG<F]U<"==(&%S("1G<F]U
M<"D@>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W-K:7!3
M96-T:6]N<ULD9W)O=7!;)VED)UU=*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`O+R!T:&4@<&]S="UI;G-T86QL('-C<FEP="!C:&]S92!T;R!S:VEP('1H
M:7,@<V5C=&EO;B!D>6YA;6EC86QL>0T*("`@("`@("`@("`@("`@("`@("!C
M;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1G<F]U<%LG;F%M92==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D<&%R86UN86UE(#T@97AP;&]D92@G.CHG+"`D9W)O=7!;)VYA;64G
M72D[#0H@("`@("`@("`@("`@("`@("`@(&EF("@D;&%S=&=R;W5P6R=I9"==
M("$]("1P87)A;6YA;65;,%TI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("1G<F]U<%LG;F%M92==(#T@)'!A<F%M;F%M95LQ73L-"B`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A;G-W97)S*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A;G-W97)S6R1G<F]U
M<%LG;F%M92==72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!S
M=VET8V@@*"1G<F]U<%LG8V]N9&ET:6]N='EP92==*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)STG(#H-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D86YS=V5R<ULD9W)O=7!;
M)VYA;64G75T@(3T@)&=R;W5P6R=V86QU92==*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64@,CL-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)R$])R`Z#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H)&%N<W=E<G-;)&=R;W5P6R=N86UE
M)UU=(#T]("1G<F]U<%LG=F%L=64G72D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!C87-E("=P<F5G7VUA=&-H)R`Z#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H(4!P<F5G7VUA=&-H*"<O)R`N
M("1G<F]U<%LG=F%L=64G72`N("<O)RP-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1A;G-W97)S6R1G<F]U<%LG;F%M92==
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!C;VYT:6YU92`R.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9&5F875L="`Z
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;CL-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@("`@("!R971U<FX[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&QA
M<W1G<F]U<"`]("1G<F]U<#L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)&=R;W5P6R=I;G-T<G5C=&EO;G,G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]D:7-P;&%Y*"1G<F]U<%LG:6YS=')U8W1I;VYS)UTI.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1G<F]U<%LG<&%R86TG75LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M)&=R;W5P6R=P87)A;2==(#T@87)R87DH)&=R;W5P6R=P87)A;2==*3L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1G
M<F]U<%LG<&%R86TG72DI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&UE
M=&AO9%]E>&ES=',H)'-C<FEP="P@)W!O<W10<F]C97-S4')O;7!T<R<I*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D<')O;7!T<R`]("1S8W)I<'0M
M/G!O<W10<F]C97-S4')O;7!T<R@D9W)O=7!;)W!A<F%M)UTL("1G<F]U<%LG
M:60G72D[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y
M*"1P<F]M<'1S*2!\?"!C;W5N="@D<')O;7!T<RD@(3T@8V]U;G0H)&=R;W5P
M6R=P87)A;2==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YO=71P=71$871A*"=P;W-T:6YS=&%L;"<L("=%<G)O<CH@<&]S="UI
M;G-T86QL('-C<FEP="!D:60@;F]T("<@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<F5T=7)N('!R;W!E<B!P;W-T+7!R;V-E<W-E9"!P
M<F]M<'1S)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!R;VUP
M=',@/2`D9W)O=7!;)W!A<F%M)UT[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1P<F]M<'1S(&%S("1I(#T^("1V87(I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D=F%R*2!\?"`A:7-S
M970H)'9A<ELG<')O;7!T)UTI('Q\#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("%I<W-E="@D=F%R6R=N86UE)UTI('Q\#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("@D=F%R6R=N86UE
M)UT@(3T@)&=R;W5P6R=P87)A;2==6R1I75LG;F%M92==*2!\?`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`H)'9A<ELG='EP92==
M("$]("1G<F]U<%LG<&%R86TG75LD:5U;)W1Y<&4G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YO=71P=71$871A
M*"=P;W-T:6YS=&%L;"<L("=%<G)O<CH@<&]S="UI;G-T86QL('-C<FEP="`G
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M;6]D:69I960@=&AE('9A<FEA8FQE<R!O<B!P<F]M<'1S+"!S979E<F4@<V5C
M=7)I='D@<FES:RX@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)U=I;&P@:6YS=&5A9"!U<V4@=&AE(&1E9F%U;'1S(&9R
M;VT@=&AE('!A8VMA9V4N>&UL)RD[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<')O;7!T<R`]("1G<F]U<%LG<&%R86TG73L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1A;G-W97)S(#T@)'1H:7,M/F-O
M;F9I<FU$:6%L;V<H)'!R;VUP=',I.PT*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&%N<W=E<G,@/2`D
M=&AI<RT^8V]N9FER;41I86QO9R@D9W)O=7!;)W!A<F%M)UTI.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(&EF("@H:7-S970H)&%N<W=E<G,I("8F("1A;G-W97)S*2!\?"`A
M:7-S970H)&=R;W5P6R=P87)A;2==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1A;G-W97)S*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)&%N<W=E<G,@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W5N<VAI9G0H)&-O;7!L
M971E9%!H87-E<RP@)&=R;W5P6R=I9"==*3L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*"$D<V-R:7!T+3YR=6XH)&%N<W=E<G,L("1G<F]U<%LG:60G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1S8W)I<'0M/G)U;B@D8V]M
M<&QE=&5D4&AA<V5S+"`G7W5N9&]/;D5R<F]R)RD[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D
M<V-R:7!T+3YR=6XH)&-O;7!L971E9%!H87-E<RP@)U]U;F1O3VY%<G)O<B<I
M.PT*("`@("`@("`@("`@("`@("`@("!R971U<FX[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@07-K(&9O<B!U<V5R(&EN<'5T+"!C;VYF:7)M('1H92!A
M;G-W97)S(&%N9"!C;VYT:6YU92!U;G1I;"!T:&4@=7-E<B!I<R!S871I<V9I
M960-"B`@("`@*B!`<&%R86T@87)R87D@86X@87)R87D@;V8@87)R87ES+"!F
M;W)M870@87)R87DH)VYA;64G(#T^("=P87)A;6YA;64G+"`G<')O;7!T)R`]
M/@T*("`@("`J("`@("`@("`@("`@("`G=&5X="!T;R!D:7-P;&%Y)RP@)W1Y
M<&4G(#T^("=S=')I;F<G6RP@9&5F875L="`]/B`G9&5F875L="!V86QU92==
M*0T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!C;VYF:7)M1&EA;&]G*"1P87)A;7,I#0H@("`@>PT*("`@("`@("`D86YS
M=V5R<R`](&%R<F%Y*"D[#0H@("`@("`@("1P<F]M<'1S(#T@)'1Y<&5S(#T@
M87)R87DH*3L-"B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D<&%R86TI
M('L-"B`@("`@("`@("`@("1P<F]M<'1S6R1P87)A;5LG;F%M92==72`]("1P
M87)A;5LG<')O;7!T)UT[#0H@("`@("`@("`@("`D='EP97-;)'!A<F%M6R=N
M86UE)UU=(#T@)'!A<F%M6R=T>7!E)UT[#0H@("`@("`@("`@("!I9B`H:7-S
M970H)'!A<F%M6R=D969A=6QT)UTI*2![#0H@("`@("`@("`@("`@("`@)&%N
M<W=E<G-;)'!A<F%M6R=N86UE)UU=(#T@)'!A<F%M6R=D969A=6QT)UT[#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1A;G-W97)S
M6R1P87)A;5LG;F%M92==72`]("<G.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(&1O('L-"B`@("`@("`@("`@("1O:R`](&%R<F%Y*"=Y
M97-N;R<@/3X@)VYO)RD[#0H@("`@("`@("`@("!D;R![#0H@("`@("`@("`@
M("`@("`@)&%N<W=E<G,@/2`D=&AI<RT^=7-E<D1I86QO9R@G)RP@)'!R;VUP
M=',L("1T>7!E<RP@)&%N<W=E<G,I.PT*("`@("`@("`@("`@?2!W:&EL92`H
M8V]U;G0H87)R87E?9FEL=&5R*"1A;G-W97)S*2D@(3T@8V]U;G0H)'!R;VUP
M=',I*3L-"B`@("`@("`@("`@("1T:&ES+3YO=71P=71$871A*"=9;W5R(&-H
M;VEC97,Z)RD[#0H@("`@("`@("`@("!F;W)E86-H("@D<')O;7!T<R!A<R`D
M;F%M92`]/B`D<')O;7!T*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/F]U
M='!U=$1A=&$H)'!R;VUP="`N("<Z("<@+B`D86YS=V5R<ULD;F%M95TI.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&]K(#T@)'1H:7,M/G5S97)$
M:6%L;V<H)R<L#0H@("`@("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@
M("`@("`@("`@("=Y97-N;R<@/3X@)U1H97-E($-H;VEC97,@3TL_("AU<V4@
M(F%B;W)T(B!T;R!H86QT*2<-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@
M("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G>65S;F\G
M(#T^("=S=')I;F<G+`T*("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@
M("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=Y97-N;R<@/3X@
M)WEE<R<-"B`@("`@("`@("`@("`@("`I#0H@("`@("`@("`@("`I.PT*("`@
M("`@("`@("`@:68@*"1O:ULG>65S;F\G72`]/2`G86)O<G0G*2![#0H@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]('=H:6QE("@D;VM;)WEE<VYO)UT@(3T@)WEE<R<I.PT*("`@("`@
M("!R971U<FX@)&%N<W=E<G,[#0H@("`@?0T*("`@("\O('M[>R!U<V5R1&EA
M;&]G*'!R;VUP="P@6W1Y<&5=+"!;9&5F875L=%TI#0H-"B`@("!F=6YC=&EO
M;B!U<V5R1&EA;&]G*"1C;VUM86YD+"`D<')O;7!T<RP@)'1Y<&5S(#T@87)R
M87DH*2P@)&1E9F%U;'1S(#T@87)R87DH*2D-"B`@("![#0H@("`@("`@("1R
M97-U;'0@/2!A<G)A>2@I.PT*("`@("`@("!I9B`H:7-?87)R87DH)'!R;VUP
M=',I*2![#0H@("`@("`@("`@("`O+R!P:'`@-2XP+C`@:6YE>'!L:6-A8FQY
M(&)R96%K<R!"0R!W:71H('1H:7,@8F5H879I;W(-"B`@("`@("`@("`@("\O
M(&YO=R!R96%D:6YG(&9R;VT@4U1$24X@:7,@=&AE(&EN=&5N9&5D('-Y;G1A
M>`T*("`@("`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92AP:'!V97)S:6]N
M*"DL("<U+C`N,"<L("<\)RDI('L-"B`@("`@("`@("`@("`@("`D9G`@/2!F
M;W!E;B@B<&AP.B\O<W1D:6XB+"`B<B(I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@9F]R96%C:"`H)'!R;VUP=',@87,@)&ME>2`]/B`D<')O;7!T
M*2![#0H@("`@("`@("`@("`@("`@)'1Y<&4@/2`D='EP97-;)&ME>5T[#0H@
M("`@("`@("`@("`@("`@)&1E9F%U;'0@/2!`)&1E9F%U;'1S6R1K97E=.PT*
M("`@("`@("`@("`@("`@(&EF("@D='EP92`]/2`G<&%S<W=O<F0G*2![#0H@
M("`@("`@("`@("`@("`@("`@('-Y<W1E;2@G<W1T>2`M96-H;R<I.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!P<FEN="`B)'1H:7,M
M/FQP)'!R;VUP="`B.PT*("`@("`@("`@("`@("`@(&EF("@D9&5F875L="D@
M>PT*("`@("`@("`@("`@("`@("`@("!P<FEN="`B6R1D969A=6QT72`B.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!P<FEN="`B.B`B
M.PT*("`@("`@("`@("`@("`@(&EF("AV97)S:6]N7V-O;7!A<F4H<&AP=F5R
M<VEO;B@I+"`G-2XP+C`G+"`G/"<I*2![#0H@("`@("`@("`@("`@("`@("`@
M("1L:6YE(#T@9F=E=',H)&9P+"`R,#0X*3L-"B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(61E9FEN960H)U-4
M1$E.)RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&1E9FEN92@G4U1$
M24XG+"!F;W!E;B@G<&AP.B\O<W1D:6XG+"`G<B<I*3L-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D;&EN92`](&9G971S
M*%-41$E.+"`R,#0X*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@:68@*"1T>7!E(#T]("=P87-S=V]R9"<I('L-"B`@("`@("`@("`@
M("`@("`@("`@<WES=&5M*"=S='1Y(&5C:&\G*3L-"B`@("`@("`@("`@("`@
M("`@("`@<')I;G0@(EQN(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@:68@*"1D969A=6QT("8F('1R:6TH)&QI;F4I(#T]("(B*2![
M#0H@("`@("`@("`@("`@("`@("`@("1R97-U;'1;)&ME>5T@/2`D9&5F875L
M=#L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("`D<F5S=6QT6R1K97E=(#T@=')I;2@D;&EN92D[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*'9E<G-I
M;VY?8V]M<&%R92AP:'!V97)S:6]N*"DL("<U+C`N,"<L("<\)RDI('L-"B`@
M("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@)')E<W5L=#L-"B`@("!]#0H-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@=7-E<D-O;F9I<FTH<')O;7!T+"!;9&5F
M875L=%TI#0H-"B`@("!F=6YC=&EO;B!U<V5R0V]N9FER;2@D<')O;7!T+"`D
M9&5F875L="`]("=Y97,G*0T*("`@('L-"B`@("`@("`@=')I9V=E<E]E<G)O
M<B@B4$5!4E]&<F]N=&5N9%]#3$DZ.G5S97)#;VYF:7)M(&YO="!Y970@8V]N
M=F5R=&5D(BP@15]54T527T524D]2*3L-"B`@("`@("`@<W1A=&EC("1P;W-I
M=&EV97,@/2!A<G)A>2@G>2<L("=Y97,G+"`G;VXG+"`G,2<I.PT*("`@("`@
M("!S=&%T:6,@)&YE9V%T:79E<R`](&%R<F%Y*"=N)RP@)VYO)RP@)V]F9B<L
M("<P)RD[#0H@("`@("`@('!R:6YT("(D=&AI<RT^;'`D<')O;7!T(%LD9&5F
M875L=%T@.B`B.PT*("`@("`@("`D9G`@/2!F;W!E;B@B<&AP.B\O<W1D:6XB
M+"`B<B(I.PT*("`@("`@("`D;&EN92`](&9G971S*"1F<"P@,C`T."D[#0H@
M("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("`D86YS=V5R(#T@<W1R=&]L
M;W=E<BAT<FEM*"1L:6YE*2D[#0H@("`@("`@(&EF("AE;7!T>2@D86YS=V5R
M*2D@>PT*("`@("`@("`@("`@)&%N<W=E<B`]("1D969A=6QT.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("AI;E]A<G)A>2@D86YS=V5R+"`D<&]S:71I=F5S
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*&EN7V%R<F%Y*"1A;G-W97(L("1N96=A=&EV97,I*2![#0H@
M("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&EN7V%R<F%Y*"1D969A=6QT+"`D<&]S:71I=F5S*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!S=&%R
M=%1A8FQE*%MP87)A;7-=*0T*#0H@("`@9G5N8W1I;VX@<W1A<G1486)L92@D
M<&%R86US(#T@87)R87DH*2D-"B`@("![#0H@("`@("`@('1R:6=G97)?97)R
M;W(H(E!%05)?1G)O;G1E;F1?0TQ).CIS=&%R=%1A8FQE(&1E<')E8V%T960B
M+"!%7U5315)?15)23U(I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]S=&%R
M=%1A8FQE*"1P87)A;7,@/2!A<G)A>2@I*0T*("`@('L-"B`@("`@("`@)'!A
M<F%M<ULG=&%B;&5?9&%T82==(#T@87)R87DH*3L-"B`@("`@("`@)'!A<F%M
M<ULG=VED97-T)UT@/2!A<G)A>2@I.R`@+R\@:6YD97AE9"!B>2!C;VQU;6X-
M"B`@("`@("`@)'!A<F%M<ULG:&EG:&5S="==(#T@87)R87DH*3L@+R\@:6YD
M97AE9"!B>2!R;W<-"B`@("`@("`@)'!A<F%M<ULG;F-O;',G72`](#`[#0H@
M("`@("`@("1T:&ES+3YP87)A;7,@/2`D<&%R86US.PT*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!T86)L95)O=RAC;VQU;6YS+"!;<F]W<&%R
M86US72P@6V-O;'!A<F%M<UTI#0H-"B`@("!F=6YC=&EO;B!T86)L95)O=R@D
M8V]L=6UN<RP@)')O=W!A<F%M<R`](&%R<F%Y*"DL("1C;VQP87)A;7,@/2!A
M<G)A>2@I*0T*("`@('L-"B`@("`@("`@=')I9V=E<E]E<G)O<B@B4$5!4E]&
M<F]N=&5N9%]#3$DZ.G1A8FQE4F]W(&1E<')E8V%T960B+"!%7U5315)?15)2
M3U(I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]T86)L95)O=R@D8V]L=6UN
M<RP@)')O=W!A<F%M<R`](&%R<F%Y*"DL("1C;VQP87)A;7,@/2!A<G)A>2@I
M*0T*("`@('L-"B`@("`@("`@)&AI9VAE<W0@/2`Q.PT*("`@("`@("!F;W(@
M*"1I(#T@,#L@)&D@/"!S:7IE;V8H)&-O;'5M;G,I.R`D:2LK*2![#0H@("`@
M("`@("`@("`D8V]L(#T@)B1C;VQU;6YS6R1I73L-"B`@("`@("`@("`@(&EF
M("AI<W-E="@D8V]L<&%R86US6R1I72D@)B8@(65M<'1Y*"1C;VQP87)A;7-;
M)&E=6R=W<F%P)UTI*2![#0H@("`@("`@("`@("`@("`@)&-O;"`]('=O<F1W
M<F%P*"1C;VPL("1C;VQP87)A;7-;)&E=6R=W<F%P)UTL(")<;B(L(#`I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*'-T<G!O<R@D8V]L+"`B
M7&XB*2`A/3T@9F%L<V4I('L-"B`@("`@("`@("`@("`@("`D;75L=&EL:6YE
M(#T@97AP;&]D92@B7&XB+"`D8V]L*3L-"B`@("`@("`@("`@("`@("`D=R`]
M(#`[#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&UU;'1I;&EN92!A<R`D
M;B`]/B`D;&EN92D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H<W1R;&5N
M*"1L:6YE*2`^("1W*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=R`]
M('-T<FQE;B@D;&EN92D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&QI;F5S(#T@<VEZ96]F
M*"1M=6QT:6QI;F4I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`D=R`]('-T<FQE;B@D8V]L*3L-"B`@("`@("`@("`@('T-"@T*
M("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YP87)A;7-;)W=I9&5S="==
M6R1I72DI('L-"B`@("`@("`@("`@("`@("!I9B`H)'<@/B`D=&AI<RT^<&%R
M86US6R=W:61E<W0G75LD:5TI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G!A<F%M<ULG=VED97-T)UU;)&E=(#T@)'<[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D
M=&AI<RT^<&%R86US6R=W:61E<W0G75LD:5T@/2`D=SL-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("1T;7`@/2!C;W5N=%]C:&%R<R@D8V]L=6UN<ULD
M:5TL(#$I.PT*("`@("`@("`@("`@+R\@:&%N9&QE('5N:7@L(&UA8R!A;F0@
M=VEN9&]W<R!F;W)M871S#0H@("`@("`@("`@("`D;&EN97,@/2`H:7-S970H
M)'1M<%LQ,%TI(#\@)'1M<%LQ,%T@.B`H:7-S970H)'1M<%LQ,UTI(#\@)'1M
M<%LQ,UT@.B`P*2D@*R`Q.PT*("`@("`@("`@("`@:68@*"1L:6YE<R`^("1H
M:6=H97-T*2![#0H@("`@("`@("`@("`@("`@)&AI9VAE<W0@/2`D;&EN97,[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*'-I>F5O
M9B@D8V]L=6UN<RD@/B`D=&AI<RT^<&%R86US6R=N8V]L<R==*2![#0H@("`@
M("`@("`@("`D=&AI<RT^<&%R86US6R=N8V]L<R==(#T@<VEZ96]F*"1C;VQU
M;6YS*3L-"B`@("`@("`@?0T*("`@("`@("`D;F5W7W)O=R`](&%R<F%Y*`T*
M("`@("`@("`@("`@)V1A=&$G(#T^("1C;VQU;6YS+`T*("`@("`@("`@("`@
M)VAE:6=H="<@/3X@)&AI9VAE<W0L#0H@("`@("`@("`@("`G<F]W<&%R86US
M)R`]/B`D<F]W<&%R86US+`T*("`@("`@("`@("`@)V-O;'!A<F%M<R<@/3X@
M)&-O;'!A<F%M<RP-"B`@("`@("`@("`@("D[#0H@("`@("`@("1T:&ES+3YP
M87)A;7-;)W1A8FQE7V1A=&$G75M=(#T@)&YE=U]R;W<[#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(&5N9%1A8FQE*"D-"@T*("`@(&9U;F-T
M:6]N(&5N9%1A8FQE*"D-"B`@("![#0H@("`@("`@('1R:6=G97)?97)R;W(H
M(E!%05)?1G)O;G1E;F1?0TQ).CIE;F1486)L92!D97!R96-A=&5D(BP@15]5
M4T527T524D]2*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?96YD5&%B;&4H
M*0T*("`@('L-"B`@("`@("`@97AT<F%C="@D=&AI<RT^<&%R86US*3L-"B`@
M("`@("`@:68@*"%E;7!T>2@D8V%P=&EO;BDI('L-"B`@("`@("`@("`@("1T
M:&ES+3Y?9&ES<&QA>4AE861I;F<H)&-A<'1I;VXI.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("AC;W5N="@D=&%B;&5?9&%T82D@/3T@,"D@>PT*("`@("`@
M("`@("`@<F5T=7)N.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H
M)'=I9'1H*2D@>PT*("`@("`@("`@("`@)'=I9'1H(#T@)'=I9&5S=#L-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M("1N8V]L<SL@)&DK*RD@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)'=I9'1H6R1I72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'=I9'1H6R1I
M72`]("1W:61E<W1;)&E=.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("`D8F]R9&5R(#T@9F%L<V4[#0H@
M("`@("`@(&EF("AE;7!T>2@D8F]R9&5R*2D@>PT*("`@("`@("`@("`@)&-E
M;&QS=&%R="`]("<G.PT*("`@("`@("`@("`@)&-E;&QE;F0@/2`G("<[#0H@
M("`@("`@("`@("`D<F]W96YD(#T@)R<[#0H@("`@("`@("`@("`D<&%D<F]W
M96YD(#T@9F%L<V4[#0H@("`@("`@("`@("`D8F]R9&5R;&EN92`]("<G.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&-E;&QS=&%R="`]("=\
M("<[#0H@("`@("`@("`@("`D8V5L;&5N9"`]("<@)SL-"B`@("`@("`@("`@
M("1R;W=E;F0@/2`G?"<[#0H@("`@("`@("`@("`D<&%D<F]W96YD(#T@=')U
M93L-"B`@("`@("`@("`@("1B;W)D97)L:6YE(#T@)RLG.PT*("`@("`@("`@
M("`@9F]R96%C:"`H)'=I9'1H(&%S("1W*2![#0H@("`@("`@("`@("`@("`@
M)&)O<F1E<FQI;F4@+CT@<W1R7W)E<&5A="@G+2<L("1W("L@<W1R;&5N*"1C
M96QL<W1A<G0I("L@<W1R;&5N*"1C96QL96YD*2`M(#$I.PT*("`@("`@("`@
M("`@("`@("1B;W)D97)L:6YE("X]("<K)SL-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H)&)O<F1E<FQI;F4I('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?9&ES<&QA>4QI;F4H)&)O<F1E<FQI;F4I.PT*("`@("`@
M("!]#0H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D=&%B;&5?
M9&%T82D[("1I*RLI('L-"B`@("`@("`@("`@(&5X=')A8W0H)'1A8FQE7V1A
M=&%;)&E=*3L-"B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)')O=W!A<F%M
M<RDI('L-"B`@("`@("`@("`@("`@("`D<F]W<&%R86US(#T@87)R87DH*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&-O
M;'!A<F%M<RDI('L-"B`@("`@("`@("`@("`@("`D8V]L<&%R86US(#T@87)R
M87DH*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1R;W=L:6YE<R`]
M(&%R<F%Y*"D[#0H@("`@("`@("`@("!I9B`H)&AE:6=H="`^(#$I('L-"B`@
M("`@("`@("`@("`@("!F;W(@*"1C(#T@,#L@)&,@/"!S:7IE;V8H)&1A=&$I
M.R`D8RLK*2![#0H@("`@("`@("`@("`@("`@("`@("1R;W=L:6YE<ULD8UT@
M/2!P<F5G7W-P;&ET*"<O*%QR/UQN?%QR*2\G+"`D9&%T85LD8UTI.PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H<VEZ96]F*"1R;W=L:6YE<ULD8UTI(#P@
M)&AE:6=H="D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)')O=VQI;F5S
M6R1C72`](&%R<F%Y7W!A9"@D<F]W;&EN97-;)&-=+"`D:&5I9VAT+"`G)RD[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(&9O<B`H)&,@
M/2`P.R`D8R`\('-I>F5O9B@D9&%T82D[("1C*RLI('L-"B`@("`@("`@("`@
M("`@("`@("`@)')O=VQI;F5S6R1C72`](&%R<F%Y*"1D871A6R1C72D[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M9F]R("@D<B`](#`[("1R(#P@)&AE:6=H=#L@)'(K*RD@>PT*("`@("`@("`@
M("`@("`@("1R;W=T97AT(#T@)R<[#0H@("`@("`@("`@("`@("`@9F]R("@D
M8R`](#`[("1C(#P@<VEZ96]F*"1D871A*3L@)&,K*RD@>PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&-O;'!A<F%M<ULD8UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D871T<FEB<R`](&%R<F%Y7VUE<F=E*"1R
M;W=P87)A;7,L("1C;VQP87)A;7,I.PT*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&%T=')I8G,@/2`D
M<F]W<&%R86US.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("1W(#T@:7-S970H)'=I9'1H6R1C72D@/R`D=VED=&A;)&-=
M(#H@,#L-"B`@("`@("`@("`@("`@("`@("`@+R\D8V5L;"`]("1D871A6R1C
M73L-"B`@("`@("`@("`@("`@("`@("`@)&-E;&P@/2`D<F]W;&EN97-;)&-=
M6R1R73L-"B`@("`@("`@("`@("`@("`@("`@)&P@/2!S=')L96XH)&-E;&PI
M.PT*("`@("`@("`@("`@("`@("`@("!I9B`H)&P@/B`D=RD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&-E;&P@/2!S=6)S='(H)&-E;&PL(#`L("1W
M*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&%T=')I8G-;)V)O;&0G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1C96QL(#T@)'1H:7,M/F)O;&0H)&-E;&PI.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@D
M;"`\("1W*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`O+R!N;W0@=7-I
M;F<@<W1R7W!A9"!H97)E(&)E8V%U<V4@=V4@;6%Y#0H@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!A9&0@8F]L9"!E<V-A<&4@8VAA<F%C=&5R<R!T;R`D
M8V5L;`T*("`@("`@("`@("`@("`@("`@("`@("`@)&-E;&P@+CT@<W1R7W)E
M<&5A="@G("<L("1W("T@)&PI.PT*("`@("`@("`@("`@("`@("`@("!]#0H-
M"B`@("`@("`@("`@("`@("`@("`@)')O=W1E>'0@+CT@)&-E;&QS=&%R="`N
M("1C96QL("X@)&-E;&QE;F0[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&EF("@A)&)O<F1E<BD@>PT*("`@("`@("`@("`@("`@("`@
M("`D<F]W=&5X="`](')T<FEM*"1R;W=T97AT*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@)')O=W1E>'0@+CT@)')O=V5N9#L-"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V1I<W!L87E,:6YE*"1R;W=T97AT*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&)O<F1E
M<FQI;F4I('L-"B`@("`@("`@("`@("1T:&ES+3Y?9&ES<&QA>4QI;F4H)&)O
M<F1E<FQI;F4I.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(&]U='!U=$1A=&$H*0T*#0H@("`@9G5N8W1I;VX@;W5T<'5T
M1&%T82@D9&%T82P@)&-O;6UA;F0@/2`G7V1E9F%U;'0G*0T*("`@('L-"B`@
M("`@("`@<W=I=&-H("@D8V]M;6%N9"D@>PT*("`@("`@("`@("`@8V%S92`G
M8VAA;FYE;"UI;F9O)SH-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D9&%T
M82!A<R`D='EP92`]/B`D<V5C=&EO;BD@>PT*("`@("`@("`@("`@("`@("`@
M("!I9B`H)'1Y<&4@/3T@)VUA:6XG*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D<V5C=&EO;ELG9&%T82==(#T@87)R87E?=F%L=65S*"1S96-T:6]N
M6R=D871A)UTI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YO=71P=71$871A*"1S96-T:6]N*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M("`@("!C87-E("=I;G-T86QL)SH-"B`@("`@("`@("`@(&-A<V4@)W5P9W)A
M9&4G.@T*("`@("`@("`@("`@8V%S92`G=7!G<F%D92UA;&PG.@T*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D9&%T85LG<F5L96%S95]W87)N:6YG<R==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1I<W!L87E,:6YE
M*"<G*3L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S=&%R=%1A8FQE
M*&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@)V)O<F1E<B<@/3X@
M9F%L<V4L#0H@("`@("`@("`@("`@("`@("`@("`@("`G8V%P=&EO;B<@/3X@
M)U)E;&5A<V4@5V%R;FEN9W,G#0H@("`@("`@("`@("`@("`@("`@("`@("`I
M*3L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T86)L95)O=RAA<G)A
M>2@D9&%T85LG<F5L96%S95]W87)N:6YG<R==*2P@;G5L;"P@87)R87DH,2`]
M/B!A<G)A>2@G=W)A<"<@/3X@-34I*2D[#0H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?96YD5&%B;&4H*3L-"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]D:7-P;&%Y3&EN92@G)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9&ES<&QA>4QI;F4H)&1A=&%;)V1A=&$G
M72D[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E
M("=S96%R8V@G.@T*("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1A<G1486)L
M92@D9&%T82D[#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D871A6R=H
M96%D;&EN92==*2`F)B!I<U]A<G)A>2@D9&%T85LG:&5A9&QI;F4G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T86)L95)O=R@D9&%T85LG
M:&5A9&QI;F4G72P@87)R87DH)V)O;&0G(#T^('1R=64I+"!A<G)A>2@Q(#T^
M(&%R<F%Y*"=W<F%P)R`]/B`U-2DI*3L-"B`@("`@("`@("`@("`@("!]#0H-
M"B`@("`@("`@("`@("`@("!F;W)E86-H*"1D871A6R=D871A)UT@87,@)&-A
M=&5G;W)Y*2![#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@H)&-A=&5G
M;W)Y(&%S("1P:V<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?=&%B;&52;W<H)'!K9RP@;G5L;"P@87)R87DH,2`]/B!A<G)A>2@G=W)A
M<"<@/3X@-34I*2D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!].PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?96YD5&%B;&4H
M*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@
M)VQI<W0M86QL)SH-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-T87)T5&%B
M;&4H)&1A=&$I.PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&%T85LG
M:&5A9&QI;F4G72D@)B8@:7-?87)R87DH)&1A=&%;)VAE861L:6YE)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=&%B;&52;W<H)&1A=&%;
M)VAE861L:6YE)UTL(&%R<F%Y*"=B;VQD)R`]/B!T<G5E*2P@87)R87DH,2`]
M/B!A<G)A>2@G=W)A<"<@/3X@-34I*2D[#0H@("`@("`@("`@("`@("`@?0T*
M#0H@("`@("`@("`@("`@("`@9F]R96%C:"@D9&%T85LG9&%T82==(&%S("1C
M871E9V]R>2D@>PT*("`@("`@("`@("`@("`@("`@("!F;W)E86-H*"1C871E
M9V]R>2!A<R`D<&MG*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!U;G-E
M="@D<&MG6S1=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1P
M:V=;-5TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T86)L
M95)O=R@D<&MG+"!N=6QL+"!A<G)A>2@Q(#T^(&%R<F%Y*"=W<F%P)R`]/B`U
M-2DI*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M('T[#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]E;F1486)L92@I.PT*("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G8V]N9FEG
M+7-H;W<G.@T*("`@("`@("`@("`@("`@("1D871A6R=B;W)D97(G72`](&9A
M;'-E.PT*("`@("`@("`@("`@("`@("1O<'1S(#T@87)R87DH,"`]/B!A<G)A
M>2@G=W)A<"<@/3X@,S`I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@,2`]/B!A<G)A>2@G=W)A<"<@/3X@,C`I+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@,B`]/B!A<G)A>2@G=W)A<"<@/3X@,S4I*3L-"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7W-T87)T5&%B;&4H)&1A=&$I.PT*("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D9&%T85LG:&5A9&QI;F4G72D@)B8@
M:7-?87)R87DH)&1A=&%;)VAE861L:6YE)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?=&%B;&52;W<H)&1A=&%;)VAE861L:6YE)UTL#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V)O
M;&0G(#T^('1R=64I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1O<'1S*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@9F]R96%C:"@D9&%T85LG9&%T82==(&%S("1G<F]U<"D@>PT*("`@
M("`@("`@("`@("`@("`@("!F;W)E86-H*"1G<F]U<"!A<R`D=F%L=64I('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D=F%L=65;,ET@/3T@)R<I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=65;,ET@/2`B
M/&YO="!S970^(CL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=&%B;&52;W<H)'9A;'5E+"!N
M=6QL+"`D;W!T<RD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]E;F1486)L92@I
M.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G
M<F5M;W1E+6EN9F\G.@T*("`@("`@("`@("`@("`@("1D871A(#T@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`@("=C87!T:6]N)R`]/B`G4&%C:V%G92!D
M971A:6QS.B<L#0H@("`@("`@("`@("`@("`@("`@("=B;W)D97(G(#T^(&9A
M;'-E+`T*("`@("`@("`@("`@("`@("`@("`G9&%T82<@/3X@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@B3&%T97-T(BP@("`@)&1A
M=&%;)W-T86)L92==*2P-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"));G-T86QL960B+"`D9&%T85LG:6YS=&%L;&5D)UTI+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH(E!A8VMA9V4B+"`@("1D871A6R=N86UE
M)UTI+`T*("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH(DQI8V5N<V4B
M+"`@("1D871A6R=L:6-E;G-E)UTI+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH(D-A=&5G;W)Y(BP@("1D871A6R=C871E9V]R>2==*2P-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*")3=6UM87)Y(BP@("`D9&%T
M85LG<W5M;6%R>2==*2P-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*")$97-C<FEP=&EO;B(L("1D871A6R=D97-C<FEP=&EO;B==*2P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@("`@("D[
M#0H@("`@("`@("`@("!D969A=6QT.B![#0H@("`@("`@("`@("`@("`@:68@
M*&ES7V%R<F%Y*"1D871A*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W-T87)T5&%B;&4H)&1A=&$I.PT*("`@("`@("`@("`@("`@("`@("`D
M8V]U;G0@/2!C;W5N="@D9&%T85LG9&%T82==6S!=*3L-"B`@("`@("`@("`@
M("`@("`@("`@:68@*"1C;W5N="`]/2`R*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D;W!T<R`](&%R<F%Y*#`@/3X@87)R87DH)W=R87`G(#T^(#(U
M*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,2`]
M/B!A<G)A>2@G=W)A<"<@/3X@-#@I#0H@("`@("`@("`@("`@("`@("`@("`@
M("`I.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&-O=6YT(#T]
M(#,I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1O<'1S(#T@87)R87DH
M,"`]/B!A<G)A>2@G=W)A<"<@/3X@,S`I+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Q(#T^(&%R<F%Y*"=W<F%P)R`]/B`R,"DL
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#(@/3X@
M87)R87DH)W=R87`G(#T^(#,U*0T*("`@("`@("`@("`@("`@("`@("`@("`@
M*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1O<'1S(#T@;G5L;#L-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1A=&%;)VAE
M861L:6YE)UTI("8F(&ES7V%R<F%Y*"1D871A6R=H96%D;&EN92==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T86)L95)O=R@D9&%T
M85LG:&5A9&QI;F4G72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)V)O;&0G(#T^('1R=64I+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;W!T<RD[#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C
M:"@D9&%T85LG9&%T82==(&%S("1R;W<I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?=&%B;&52;W<H)')O=RP@;G5L;"P@)&]P=',I.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?96YD5&%B;&4H*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1I<W!L87E,:6YE*"1D871A
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@;&]G*'1E>'0I
M#0H-"@T*("`@(&9U;F-T:6]N(&QO9R@D=&5X="P@)&%P<&5N9%]C<FQF(#T@
M=')U92D-"B`@("![#0H@("`@("`@(&EF("@D87!P96YD7V-R;&8I('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1I<W!L87E,:6YE*"1T97AT*3L-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/E]D:7-P;&%Y*"1T
M97AT*3L-"B`@("!]#0H-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!B;VQD
M*"1T97AT*0T*#0H@("`@9G5N8W1I;VX@8F]L9"@D=&5X="D-"B`@("![#0H@
M("`@("`@(&EF("AE;7!T>2@D=&AI<RT^=&5R;5LG8F]L9"==*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N('-T<G1O=7!P97(H)'1E>'0I.PT*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B`D=&AI<RT^=&5R;5LG8F]L9"==("X@)'1E>'0@
M+B`D=&AI<RT^=&5R;5LG;F]R;6%L)UT[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0I]#0H-"C\^#0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T9R;VYT96YD+G!H<```````
M````````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-#$W-``Q,#4Q-30S
M,S<T,0`P,C$V,S``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`-"B\J*@T*("H@4$5!4E]&<F]N=&5N9"P@=&AE('-I
M;F=L971O;BUB87-E9"!F<F]N=&5N9"!F;W(@=7-E<B!I;G!U="]O=71P=70-
M"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z
M(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O
M9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*
M("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO
M=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N
M<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E
M8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@
M*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`
M875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`
M8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N
M<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0
M($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@1G)O;G1E
M;F0N<&AP+'8@,2XY(#(P,#8O,#,O,#,@,3,Z,3,Z,#<@<&%J;WEE($5X<"`D
M#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L
M96%S92`Q+C0N,&$Q#0H@*B\-"@T*+RHJ#0H@*B!7:&EC:"!U<V5R(&EN=&5R
M9F%C92!C;&%S<R!I<R!B96EN9R!U<V5D+@T*("H@0'9A<B!S=')I;F<@8VQA
M<W,@;F%M90T*("HO#0HD1TQ/0D%,4ULG7U!%05)?1E)/3E1%3D1?0TQ!4U,G
M72`]("=014%27T9R;VYT96YD7T-,22<[#0H-"B\J*@T*("H@26YS=&%N8V4@
M;V8@)%]014%27T-O;6UA;F1?=6EC;&%S<RX-"B`J($!V87(@;V)J96-T#0H@
M*B\-"B1'3$]"04Q36R=?4$5!4E]&4D].5$5.1%]324Y'3$543TXG72`](&YU
M;&P[#0H-"B\J*@T*("H@4VEN9VQE=&]N+6)A<V5D(&9R;VYT96YD(&9O<B!0
M14%2('5S97(@:6YP=70O;W5T<'5T#0H@*@T*("H@3F]T92!T:&%T(&9R;VYT
M96YD(&-L87-S97,@;75S="!I;7!L96UE;G0@=7-E<D-O;F9I<FTH*2P@86YD
M('-H;W5L(&EM<&QE;65N=`T*("H@9&ES<&QA>49A=&%L17)R;W(H*2!A;F0@
M;W5T<'5T1&%T82@I#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G
M92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G
M0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'
M<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!2
M96QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL
M86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!4E]&
M<F]N=&5N9"!E>'1E;F1S(%!%05(-"GL-"B`@("`O*BH-"B`@("`@*B!2971R
M:65V92!T:&4@9G)O;G1E;F0@;V)J96-T#0H@("`@("H@0')E='5R;B!014%2
M7T9R;VYT96YD7T-,27Q014%27T9R;VYT96YD7U=E8GQ014%27T9R;VYT96YD
M7T=T:PT*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F
M<VEN9VQE=&]N*"1T>7!E(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&EF("@D
M='EP92`]/3T@;G5L;"D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D1TQ/
M0D%,4ULG7U!%05)?1E)/3E1%3D1?4TE.1TQ%5$].)UTI*2![#0H@("`@("`@
M("`@("`@("`@)&$@/2!F86QS93L-"B`@("`@("`@("`@("`@("!R971U<FX@
M)&$[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)$=,3T)!
M3%-;)U]014%27T923TY414Y$7U-)3D=,151/3B==.PT*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@)&$@/2!014%27T9R;VYT96YD.CIS971&<F]N
M=&5N9$-L87-S*"1T>7!E*3L-"B`@("`@("`@("`@(')E='5R;B`D83L-"B`@
M("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J(%-E="!T:&4@9G)O
M;G1E;F0@8VQA<W,@=&AA="!W:6QL(&)E('5S960@8GD@8V%L;',@=&\@>T!L
M:6YK('-I;F=L971O;B@I?0T*("`@("`J#0H@("`@("H@1G)O;G1E;F1S(&%R
M92!E>'!E8W1E9"!T;R!C;VYF;W)M('1O('1H92!014%2(&YA;6EN9R!S=&%N
M9&%R9"!O9@T*("`@("`J(%\@/3X@1$E214-43U)97U-%4$%2051/4B`H4$5!
M4E]&<F]N=&5N9%]#3$D@:7,@:6X@4$5!4B]&<F]N=&5N9"]#3$DN<&AP*0T*
M("`@("`J($!P87)A;2!S=')I;F<@)'5I8VQA<W,@9G5L;"!C;&%S<R!N86UE
M#0H@("`@("H@0')E='5R;B!014%27T9R;VYT96YD#0H@("`@("H@0'-T871I
M8PT*("`@("`J+PT*("`@(&9U;F-T:6]N("9S971&<F]N=&5N9$-L87-S*"1U
M:6-L87-S*0T*("`@('L-"B`@("`@("`@:68@*&ES7V]B:F5C="@D1TQ/0D%,
M4ULG7U!%05)?1E)/3E1%3D1?4TE.1TQ%5$].)UTI("8F#0H@("`@("`@("`@
M("`@(&ES7V$H)$=,3T)!3%-;)U]014%27T923TY414Y$7U-)3D=,151/3B==
M+"`D=6EC;&%S<RDI('L-"B`@("`@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG
M7U!%05)?1E)/3E1%3D1?4TE.1TQ%5$].)UT[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"%C;&%S<U]E>&ES=',H)'5I8VQA<W,I*2![#0H@("`@("`@("`@
M("`D9FEL92`]('-T<E]R97!L86-E*"=?)RP@)R\G+"`D=6EC;&%S<RD@+B`G
M+G!H<"<[#0H@("`@("`@("`@("!I9B`H4$5!4E]&<F]N=&5N9#HZ:7-);F-L
M=61E86)L92@D9FEL92DI('L-"B`@("`@("`@("`@("`@("!I;F-L=61E7V]N
M8V4@)&9I;&4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&-L87-S7V5X:7-T<R@D=6EC;&%S<RDI('L-"B`@("`@("`@("`@("1O
M8FH@/2`F;F5W("1U:6-L87-S.PT*("`@("`@("`@("`@+R\@<75I8VL@=&5S
M="!T;R!S964@:68@=&AI<R!C;&%S<R!I;7!L96UE;G1S(&$@9F5W(&]F('1H
M92!M;W-T#0H@("`@("`@("`@("`O+R!I;7!O<G1A;G0@9G)O;G1E;F0@;65T
M:&]D<PT*("`@("`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H)&]B:BP@)W5S
M97)#;VYF:7)M)RDI('L-"B`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG7U!%
M05)?1E)/3E1%3D1?4TE.1TQ%5$].)UT@/2`F)&]B:CL-"B`@("`@("`@("`@
M("`@("`D1TQ/0D%,4ULG7U!%05)?1E)/3E1%3D1?0TQ!4U,G72`]("1U:6-L
M87-S.PT*("`@("`@("`@("`@("`@(')E='5R;B`D;V)J.PT*("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D97)R(#T@4$5!4CHZ<F%I
M<V5%<G)O<B@B;F]T(&$@9G)O;G1E;F0@8VQA<W,Z("1U:6-L87-S(BD[#0H@
M("`@("`@("`@("`@("`@<F5T=7)N("1E<G([#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@)&5R<B`](%!%05(Z.G)A:7-E17)R;W(H(FYO
M('-U8V@@8VQA<W,Z("1U:6-L87-S(BD[#0H@("`@("`@(')E='5R;B`D97)R
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%-E="!T:&4@9G)O;G1E;F0@
M8VQA<W,@=&AA="!W:6QL(&)E('5S960@8GD@8V%L;',@=&\@>T!L:6YK('-I
M;F=L971O;B@I?0T*("`@("`J#0H@("`@("H@1G)O;G1E;F1S(&%R92!E>'!E
M8W1E9"!T;R!B92!A(&1E<V-E;F1A;G0@;V8@4$5!4E]&<F]N=&5N9`T*("`@
M("`J($!P87)A;2!014%27T9R;VYT96YD#0H@("`@("H@0')E='5R;B!014%2
M7T9R;VYT96YD#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N("9S971&<F]N=&5N9$]B:F5C="@D=6EO8FIE8W0I#0H@("`@>PT*("`@
M("`@("!I9B`H:7-?;V)J96-T*"1'3$]"04Q36R=?4$5!4E]&4D].5$5.1%]3
M24Y'3$543TXG72D@)B8-"B`@("`@("`@("`@("`@:7-?82@D1TQ/0D%,4ULG
M7U!%05)?1E)/3E1%3D1?4TE.1TQ%5$].)UTL(&=E=%]C;&%S<R@D=6EO8FIE
M8W0I*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q36R=?4$5!4E]&
M4D].5$5.1%]324Y'3$543TXG73L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M(6ES7V$H)'5I;V)J96-T+"`G4$5!4E]&<F]N=&5N9"<I*2![#0H@("`@("`@
M("`@("`D97)R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G;F]T(&$@=F%L:60@9G)O
M;G1E;F0@8VQA<W,Z("@G("X-"B`@("`@("`@("`@("`@("!G971?8VQA<W,H
M)'5I;V)J96-T*2`N("<I)RD[#0H@("`@("`@("`@("!R971U<FX@)&5R<CL-
M"B`@("`@("`@?0T*("`@("`@("`O+R!Q=6EC:R!T97-T('1O('-E92!I9B!T
M:&ES(&-L87-S(&EM<&QE;65N=',@82!F97<@;V8@=&AE(&UO<W0-"B`@("`@
M("`@+R\@:6UP;W)T86YT(&9R;VYT96YD(&UE=&AO9',-"B`@("`@("`@:68@
M*&UE=&AO9%]E>&ES=',H)'5I;V)J96-T+"`G=7-E<D-O;F9I<FTG*2D@>PT*
M("`@("`@("`@("`@)$=,3T)!3%-;)U]014%27T923TY414Y$7U-)3D=,151/
M3B==(#T@)B1U:6]B:F5C=#L-"B`@("`@("`@("`@("1'3$]"04Q36R=?4$5!
M4E]&4D].5$5.1%]#3$%34R==(#T@9V5T7V-L87-S*"1U:6]B:F5C="D[#0H@
M("`@("`@("`@("!R971U<FX@)'5I;V)J96-T.PT*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@)&5R<B`](%!%05(Z.G)A:7-E17)R;W(H(FYO="!A
M('9A;'5E(&9R;VYT96YD(&-L87-S.B`H(B`N(&=E=%]C;&%S<R@D=6EO8FIE
M8W0I#0H@("`@("`@("`@("`@("`@+B`G*2<I.PT*("`@("`@("`@("`@<F5T
M=7)N("1E<G([#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1P871H(')E;&%T:79E(&]R(&%B<V]L=71E(&EN
M8VQU9&4@<&%T:`T*("`@("`J($!R971U<FX@8F]O;&5A;@T*("`@("`J($!S
M=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I<TEN8VQU9&5A8FQE*"1P
M871H*0T*("`@('L-"B`@("`@("`@:68@*&9I;&5?97AI<W1S*"1P871H*2`F
M)B!I<U]R96%D86)L92@D<&%T:"DI('L-"B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@("`@("!]#0H@("`@("`@("1I<&%T:"`](&5X<&QO9&4H4$%4
M2%]315!!4D%43U(L(&EN:5]G970H)VEN8VQU9&5?<&%T:"<I*3L-"B`@("`@
M("`@9F]R96%C:"`H)&EP871H(&%S("1I;F-L=61E*2![#0H@("`@("`@("`@
M("`D=&5S="`](')E86QP871H*"1I;F-L=61E("X@1$E214-43U)97U-%4$%2
M051/4B`N("1P871H*3L-"B`@("`@("`@("`@(&EF("@A)'1E<W0I('L@+R\@
M<W5P<&]R="!W<F%P<&5R<R!L:6ME('!H87(@*')E86QP871H(&IU<W0@9&]N
M)W0@=V]R:R!W:71H('1H96TI#0H@("`@("`@("`@("`@("`@)'1E<W0@/2`D
M:6YC;'5D92`N($1)4D5#5$]265]315!!4D%43U(@+B`D<&%T:#L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D=&5S="D@
M)B8@:7-?<F5A9&%B;&4H)'1E<W0I*2![#0H@("`@("`@("`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A
M;2!014%27T-O;F9I9PT*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=$-O;F9I
M9R@F)&-O;F9I9RD-"B`@("![#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M5&AI<R!C86X@8F4@;W9E<G)I9&1E;B!T;R!A;&QO=R!S97-S:6]N+6)A<V5D
M('1E;7!O<F%R>2!F:6QE(&UA;F%G96UE;G0-"B`@("`@*@T*("`@("`J($)Y
M(&1E9F%U;'0L(&%L;"!F:6QE<R!A<F4@9&5L971E9"!A="!T:&4@96YD(&]F
M(&$@<V5S<VEO;BX@(%1H92!W96(@:6YS=&%L;&5R#0H@("`@("H@;F5E9',@
M=&\@8F4@86)L92!T;R!S=7-T86EN(&$@;&ES="!O=F5R(&UA;GD@<V5S<VEO
M;G,@:6X@;W)D97(@=&\@<W5P<&]R=`T*("`@("`J('5S97(@:6YT97)A8W1I
M;VX@=VET:"!I;G-T86QL('-C<FEP=',-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!A9&1496UP1FEL92@D9FEL92D-"B`@("![#0H@("`@("`@("1'3$]"04Q3
M6R=?4$5!4E]#;VUM;VY?=&5M<&9I;&5S)UU;72`]("1F:6QE.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N(&QO9R@D;7-G+"`D87!P96YD7V-R;&8@/2!T<G5E
M*0T*("`@('L-"B`@("!]#0I]#0H_/@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T
M86QL97(O````````````````````````````````````````````````````
M````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`U,34T,S,W-#``,#(Q,C8U`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]014%2+TEN<W1A;&QE<B]2;VQE+P``````````````````````
M```````````````````````````````````````````P,#`P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<T,``P,C(Q-C8`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O26YS=&%L;&5R+U)O;&4O
M0V]M;6]N+G!H<```````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$U,C0T`#$P-3$U
M-#,S-S0P`#`R-#$S-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`T*+RHJ#0H@*B!"87-E(&-L87-S(&9O<B!A;&P@
M:6YS=&%L;&%T:6]N(')O;&5S+@T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N
M9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J
M96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA
M="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@
M=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@
M;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A
M:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E
M('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y
M(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P
M86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC
M96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@
M4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N
M("`@($-64SH@)$ED.B!#;VUM;VXN<&AP+'8@,2XQ,"`R,#`V+S`Q+S`V(#`T
M.C0W.C,W(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@
M879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0HO*BH-"B`J
M($)A<V4@8VQA<W,@9F]R(&%L;"!I;G-T86QL871I;VX@<F]L97,N#0H@*@T*
M("H@5&AI<R!C;&%S<R!A;&QO=W,@97AT96YS:6)I;&ET>2!O9B!F:6QE(')O
M;&5S+B`@4&%C:V%G97,@=VET:"!C;VUP;&5X#0H@*B!C=7-T;VUI>F%T:6]N
M(&-A;B!N;W<@<')O=FED92!C=7-T;VT@9FEL92!R;VQE<R!A;&]N9R!W:71H
M('1H92!P;W-S:6)I;&ET>2!O9@T*("H@861D:6YG(&-O;F9I9W5R871I;VX@
M=F%L=65S('1O(&UA=&-H+@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A
M8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E
M;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!0
M2%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@
M("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S(%!%
M05)?26YS=&%L;&5R7U)O;&5?0V]M;6]N#0I[#0H@("`@+RHJ#0H@("`@("H@
M0'9A<B!014%27T-O;F9I9PT*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@
M("`@("HO#0H@("`@=F%R("1C;VYF:6<[#0H-"B`@("`O*BH-"B`@("`@*B!`
M<&%R86T@4$5!4E]#;VYF:6<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!014%2
M7TEN<W1A;&QE<E]2;VQE7T-O;6UO;B@F)&-O;F9I9RD-"B`@("![#0H@("`@
M("`@("1T:&ES+3YC;VYF:6<@/2`D8V]N9FEG.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J(%)E=')I979E(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M86)O=70@82!F:6QE(')O;&4@9G)O;2!I=',@6$U,(&EN9F\-"B`@("`@*@T*
M("`@("`J($!P87)A;2!S=')I;F<@)')O;&4@4F]L92!#;&%S<VYA;64L(&%S
M(&EN(")014%27TEN<W1A;&QE<E]2;VQE7T1A=&$B#0H@("`@("H@0')E='5R
M;B!A<G)A>0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$EN9F\H)')O;&4I
M#0H@("`@>PT*("`@("`@("!I9B`H96UP='DH)$=,3T)!3%-;)U]014%27TE.
M4U1!3$Q%4E]23TQ%4R==6R1R;VQE72DI('L-"B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=5;FMN;W=N(%)O;&4@8VQA<W,Z("(G("X@
M)')O;&4@+B`G(B<I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D1TQ/
M0D%,4ULG7U!%05)?24Y35$%,3$527U)/3$53)UU;)')O;&5=.PT*("`@('T-
M"@T*("`@("\J*@T*("`@("`J(%1H:7,@:7,@8V%L;&5D(&9O<B!E86-H(&9I
M;&4@=&\@<V5T('5P('1H92!D:7)E8W1O<FEE<R!A;F0@9FEL97,-"B`@("`@
M*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V,7Q014%27U!A8VMA9V5&:6QE
M7W8R#0H@("`@("H@0'!A<F%M(&%R<F%Y(&%T=')I8G5T97,@9G)O;2!T:&4@
M/&9I;&4^('1A9PT*("`@("`J($!P87)A;2!S=')I;F<@9FEL92!N86UE#0H@
M("`@("H@0')E='5R;B!A<G)A>2!A;B!A<G)A>2!C;VYS:7-T:6YG(&]F.@T*
M("`@("`J#0H@("`@("H@("`@,2!T:&4@;W)I9VEN86PL('!R92UB87-E:6YS
M=&%L;&1I<B!I;G-T86QL871I;VX@9&ER96-T;W)Y#0H@("`@("H@("`@,B!T
M:&4@9FEN86P@:6YS=&%L;&%T:6]N(&1I<F5C=&]R>0T*("`@("`J("`@(#,@
M=&AE(&9U;&P@<&%T:"!T;R!T:&4@9FEN86P@;&]C871I;VX@;V8@=&AE(&9I
M;&4-"B`@("`@*B`@("`T('1H92!L;V-A=&EO;B!O9B!T:&4@<')E+6EN<W1A
M;&QA=&EO;B!F:6QE#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<')O8V5S<TEN
M<W1A;&QA=&EO;B@D<&MG+"`D871T<RP@)&9I;&4L("1T;7!?<&%T:"P@)&QA
M>65R(#T@;G5L;"D-"B`@("![#0H@("`@("`@("1R;VQE26YF;R`](%!%05)?
M26YS=&%L;&5R7U)O;&5?0V]M;6]N.CIG971);F9O*"=014%27TEN<W1A;&QE
M<E]2;VQE7R<@+B`-"B`@("`@("`@("`@('5C9FER<W0H<W1R7W)E<&QA8V4H
M)W!E87)?:6YS=&%L;&5R7W)O;&5?)RP@)R<L('-T<G1O;&]W97(H9V5T7V-L
M87-S*"1T:&ES*2DI*2D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R
M;VQE26YF;RDI('L-"B`@("`@("`@("`@(')E='5R;B`D<F]L94EN9F\[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"$D<F]L94EN9F];)VQO8V%T:6]N8V]N
M9FEG)UTI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H)')O;&5);F9O6R=H;VYO<G-B87-E:6YS=&%L;"==
M*2![#0H@("`@("`@("`@("`D9&5S=%]D:7(@/2`D<V%V95]D97-T9&ER(#T@
M)'1H:7,M/F-O;F9I9RT^9V5T*"1R;VQE26YF;ULG;&]C871I;VYC;VYF:6<G
M72P@)&QA>65R+`T*("`@("`@("`@("`@("`@("1P:V<M/F=E=$-H86YN96PH
M*2D[#0H@("`@("`@("`@("!I9B`H(65M<'1Y*"1A='1S6R=B87-E:6YS=&%L
M;&1I<B==*2D@>PT*("`@("`@("`@("`@("`@("1D97-T7V1I<B`N/2!$25)%
M0U1/4EE?4T5005)!5$]2("X@)&%T='-;)V)A<V5I;G-T86QL9&ER)UT[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T@96QS96EF("@D<F]L94EN9F];)W5N
M=7-U86QB87-E:6YS=&%L;"==*2![#0H@("`@("`@("`@("`D9&5S=%]D:7(@
M/2`D<V%V95]D97-T9&ER(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"1R;VQE26YF
M;ULG;&]C871I;VYC;VYF:6<G72P-"B`@("`@("`@("`@("`@("`@("`@;G5L
M;"P@)'!K9RT^9V5T0VAA;FYE;"@I*2`N($1)4D5#5$]265]315!!4D%43U(@
M+B`D<&MG+3YG971086-K86=E*"D[#0H@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1A='1S6R=B87-E:6YS=&%L;&1I<B==*2D@>PT*("`@("`@("`@("`@("`@
M("1D97-T7V1I<B`N/2!$25)%0U1/4EE?4T5005)!5$]2("X@)&%T='-;)V)A
M<V5I;G-T86QL9&ER)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`D9&5S=%]D:7(@/2`D<V%V95]D97-T9&ER(#T@
M)'1H:7,M/F-O;F9I9RT^9V5T*"1R;VQE26YF;ULG;&]C871I;VYC;VYF:6<G
M72P-"B`@("`@("`@("`@("`@("`@("`@;G5L;"P@)'!K9RT^9V5T0VAA;FYE
M;"@I*2`N($1)4D5#5$]265]315!!4D%43U(@+B`D<&MG+3YG971086-K86=E
M*"D[#0H@("`@("`@('T-"B`@("`@("`@:68@*&1I<FYA;64H)&9I;&4I("$]
M("<N)R`F)B!E;7!T>2@D871T<ULG:6YS=&%L;"UA<R==*2D@>PT*("`@("`@
M("`@("`@)&1E<W1?9&ER("X]($1)4D5#5$]265]315!!4D%43U(@+B!D:7)N
M86UE*"1F:6QE*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H96UP='DH)&%T
M='-;)VEN<W1A;&PM87,G72DI('L-"B`@("`@("`@("`@("1D97-T7V9I;&4@
M/2`D9&5S=%]D:7(@+B!$25)%0U1/4EE?4T5005)!5$]2("X@8F%S96YA;64H
M)&9I;&4I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&1E<W1?
M9FEL92`]("1D97-T7V1I<B`N($1)4D5#5$]265]315!!4D%43U(@+B`D871T
M<ULG:6YS=&%L;"UA<R==.PT*("`@("`@("!]#0H@("`@("`@("1O<FEG7V9I
M;&4@/2`D=&UP7W!A=&@@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)&9I;&4[
M#0H-"B`@("`@("`@+R\@0VQE86X@=7`@=&AE($1)4D5#5$]265]315!!4D%4
M3U(@;65S<PT*("`@("`@("`D9',R(#T@1$E214-43U)97U-%4$%2051/4B`N
M($1)4D5#5$]265]315!!4D%43U([#0H@("`@("`@(`T*("`@("`@("!L:7-T
M*"1D97-T7V1I<BP@)&1E<W1?9FEL92P@)&]R:6=?9FEL92D@/2!P<F5G7W)E
M<&QA8V4H87)R87DH)R%<7%Q<*R$G+"`G(2\A)RP@(B$D9',R*R$B*2P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2A$25)%0U1/4EE?4T5005)!5$]2+"!$25)%0U1/4EE?4T50
M05)!5$]2+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@($1)4D5#5$]265]315!!4D%43U(I+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"1D97-T7V1I<BP@)&1E<W1?9FEL92P@)&]R:6=?9FEL
M92DI.PT*("`@("`@("!R971U<FX@87)R87DH)'-A=F5?9&5S=&1I<BP@)&1E
M<W1?9&ER+"`D9&5S=%]F:6QE+"`D;W)I9U]F:6QE*3L-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!'970@=&AE(&YA;64@;V8@=&AE(&-O;F9I9W5R871I
M;VX@=F%R:6%B;&4@=&AA="!S<&5C:69I97,@=&AE(&QO8V%T:6]N(&]F('1H
M:7,@9FEL90T*("`@("`J($!R971U<FX@<W1R:6YG?&9A;'-E#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@9V5T3&]C871I;VY#;VYF:6<H*0T*("`@('L-"B`@
M("`@("`@)')O;&5);F9O(#T@4$5!4E]);G-T86QL97)?4F]L95]#;VUM;VXZ
M.F=E=$EN9F\H)U!%05)?26YS=&%L;&5R7U)O;&5?)R`N(`T*("`@("`@("`@
M("`@=6-F:7)S="AS=')?<F5P;&%C92@G<&5A<E]I;G-T86QL97)?<F]L95\G
M+"`G)RP@<W1R=&]L;W=E<BAG971?8VQA<W,H)'1H:7,I*2DI*3L-"B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)')O;&5);F9O*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N("1R;VQE26YF;SL-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@)')O;&5);F9O6R=L;V-A=&EO;F-O;F9I9R==.PT*("`@('T-"@T*("`@
M("\J*@T*("`@("`J($1O(&%N>2!U;G5S=6%L('-E='5P(&AE<F4-"B`@("`@
M*B!`<&%R86T@4$5!4E]);G-T86QL97(-"B`@("`@*B!`<&%R86T@4$5!4E]0
M86-K86=E1FEL95]V,@T*("`@("`J($!P87)A;2!A<G)A>2!F:6QE(&%T=')I
M8G5T97,-"B`@("`@*B!`<&%R86T@<W1R:6YG(&9I;&4@;F%M90T*("`@("`J
M+PT*("`@(&9U;F-T:6]N('-E='5P*"8D:6YS=&%L;&5R+"`D<&MG+"`D871T
M<RP@)&9I;&4I#0H@("`@>PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&ES17AE
M8W5T86)L92@I#0H@("`@>PT*("`@("`@("`D<F]L94EN9F\@/2!014%27TEN
M<W1A;&QE<E]2;VQE7T-O;6UO;CHZ9V5T26YF;R@G4$5!4E]);G-T86QL97)?
M4F]L95\G("X@#0H@("`@("`@("`@("!U8V9I<G-T*'-T<E]R97!L86-E*"=P
M96%R7VEN<W1A;&QE<E]R;VQE7R<L("<G+"!S=')T;VQO=V5R*&=E=%]C;&%S
M<R@D=&AI<RDI*2DI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F]L
M94EN9F\I*2![#0H@("`@("`@("`@("!R971U<FX@)')O;&5);F9O.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B`D<F]L94EN9F];)V5X96-U=&%B;&4G
M73L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!I<TEN<W1A;&QA8FQE*"D-"B`@
M("![#0H@("`@("`@("1R;VQE26YF;R`](%!%05)?26YS=&%L;&5R7U)O;&5?
M0V]M;6]N.CIG971);F9O*"=014%27TEN<W1A;&QE<E]2;VQE7R<@+B`-"B`@
M("`@("`@("`@('5C9FER<W0H<W1R7W)E<&QA8V4H)W!E87)?:6YS=&%L;&5R
M7W)O;&5?)RP@)R<L('-T<G1O;&]W97(H9V5T7V-L87-S*"1T:&ES*2DI*2D[
M#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R;VQE26YF;RDI('L-"B`@
M("`@("`@("`@(')E='5R;B`D<F]L94EN9F\[#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N("1R;VQE26YF;ULG:6YS=&%L;&%B;&4G73L-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!I<T5X=&5N<VEO;B@I#0H@("`@>PT*("`@("`@("`D
M<F]L94EN9F\@/2!014%27TEN<W1A;&QE<E]2;VQE7T-O;6UO;CHZ9V5T26YF
M;R@G4$5!4E]);G-T86QL97)?4F]L95\G("X@#0H@("`@("`@("`@("!U8V9I
M<G-T*'-T<E]R97!L86-E*"=P96%R7VEN<W1A;&QE<E]R;VQE7R<L("<G+"!S
M=')T;VQO=V5R*&=E=%]C;&%S<R@D=&AI<RDI*2DI.PT*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D<F]L94EN9F\I*2![#0H@("`@("`@("`@("!R971U
M<FX@)')O;&5);F9O.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F]L
M94EN9F];)W!H<&5X=&5N<VEO;B==.PT*("`@('T-"GT-"C\^````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+U!%05(O26YS=&%L;&5R+U)O;&4O1&%T82YP:'``````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S(Q`#$P-3$U-#,S-S0P`#`R,S4T-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`T*+RHJ#0H@*B!014%27TEN<W1A;&QE<E]2;VQE7T1A=&$-"B`J#0H@*B!0
M2%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U
M<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0
M(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R
M92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E
M#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N
M(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O
M<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@
M("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT
M("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@
M,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@1&%T82YP:'`L=B`Q+C8@
M,C`P-B\P,2\P-B`P-#HT-SHS-R!C96QL;V<@17AP("0-"B`J($!L:6YK("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN
M8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-
M"B`J+PT*#0HO*BH-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E
M("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`
M<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R
M;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E
M;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N
M;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA
M8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0IC;&%S<R!014%27TEN
M<W1A;&QE<E]2;VQE7T1A=&$@97AT96YD<R!014%27TEN<W1A;&QE<E]2;VQE
M7T-O;6UO;B![?0T*/SX`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL
M97(O4F]L92]$871A+GAM;```````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U
M,30`,3`U,34T,S,W-#``,#(S-38Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#QR;VQE('9E<G-I;VX](C$N,"(^#0H@/')E
M;&5A<V5T>7!E<SYP:'`\+W)E;&5A<V5T>7!E<SX-"B`\<F5L96%S971Y<&5S
M/F5X='-R8SPO<F5L96%S971Y<&5S/@T*(#QR96QE87-E='EP97,^97AT8FEN
M/"]R96QE87-E='EP97,^#0H@/&EN<W1A;&QA8FQE/C$\+VEN<W1A;&QA8FQE
M/@T*(#QL;V-A=&EO;F-O;F9I9SYD871A7V1I<CPO;&]C871I;VYC;VYF:6<^
M#0H@/&AO;F]R<V)A<V5I;G-T86QL("\^#0H@/'5N=7-U86QB87-E:6YS=&%L
M;"`O/@T*(#QP:'!F:6QE("\^#0H@/&5X96-U=&%B;&4@+SX-"B`\<&AP97AT
M96YS:6]N("\^#0H@/&-O;F9I9U]V87)S("\^#0H\+W)O;&4^````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O26YS=&%L;&5R+U)O;&4O1&]C
M+G!H<```````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S$V`#$P-3$U-#,S
M-S0P`#`R,S0P-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`T*+RHJ#0H@*B!014%27TEN<W1A;&QE<E]2;VQE7T1O
M8PT*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y3
M13H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP
M(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ
M#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC
M96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@
M=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE
M="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-
M"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J
M($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J
M($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC
M96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!0
M2%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!$;V,N
M<&AP+'8@,2XV(#(P,#8O,#$O,#8@,#0Z-#<Z,S<@8V5L;&]G($5X<"`D#0H@
M*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!
M4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S
M92`Q+C0N,&$Q#0H@*B\-"@T*+RHJ#0H@*B!`8V%T96=O<GD@("!P96%R#0H@
M*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E
M<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@
M5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R
M<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L
M87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*8VQA
M<W,@4$5!4E]);G-T86QL97)?4F]L95]$;V,@97AT96YD<R!014%27TEN<W1A
M;&QE<E]2;VQE7T-O;6UO;B![?0T*/SX`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M4$5!4B]);G-T86QL97(O4F]L92]$;V,N>&UL````````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`U,3,`,3`U,34T,S,W-#``,#(S-#$T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#QR;VQE('9E<G-I;VX]
M(C$N,"(^#0H@/')E;&5A<V5T>7!E<SYP:'`\+W)E;&5A<V5T>7!E<SX-"B`\
M<F5L96%S971Y<&5S/F5X='-R8SPO<F5L96%S971Y<&5S/@T*(#QR96QE87-E
M='EP97,^97AT8FEN/"]R96QE87-E='EP97,^#0H@/&EN<W1A;&QA8FQE/C$\
M+VEN<W1A;&QA8FQE/@T*(#QL;V-A=&EO;F-O;F9I9SYD;V-?9&ER/"]L;V-A
M=&EO;F-O;F9I9SX-"B`\:&]N;W)S8F%S96EN<W1A;&P@+SX-"B`\=6YU<W5A
M;&)A<V5I;G-T86QL("\^#0H@/'!H<&9I;&4@+SX-"B`\97AE8W5T86)L92`O
M/@T*(#QP:'!E>'1E;G-I;VX@+SX-"B`\8V]N9FEG7W9A<G,@+SX-"CPO<F]L
M93X`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O26YS=&%L
M;&5R+U)O;&4O17AT+G!H<```````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R
M,S$V`#$P-3$U-#,S-S0P`#`R,S0T,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`T*+RHJ#0H@*B!014%27TEN<W1A
M;&QE<E]2;VQE7T5X=`T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@
M*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O
M('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A
M=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O
M;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J
M('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@
M=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI
M8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D
M:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E
M("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`
M<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R
M;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-6
M4SH@)$ED.B!%>'0N<&AP+'8@,2XV(#(P,#8O,#$O,#8@,#0Z-#<Z,S<@8V5L
M;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@
M<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"@T*+RHJ#0H@*B!`8V%T96=O
M<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@
M("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT
M("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@
M,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S
M:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP
M83$-"B`J+PT*8VQA<W,@4$5!4E]);G-T86QL97)?4F]L95]%>'0@97AT96YD
M<R!014%27TEN<W1A;&QE<E]2;VQE7T-O;6UO;B![?0T*/SX`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]%>'0N>&UL````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`T-#,`,3`U,34T,S,W-#``,#(S-#4Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#QR
M;VQE('9E<G-I;VX](C$N,"(^#0H@/')E;&5A<V5T>7!E<SYE>'1B:6X\+W)E
M;&5A<V5T>7!E<SX-"B`\:6YS=&%L;&%B;&4^,3PO:6YS=&%L;&%B;&4^#0H@
M/&QO8V%T:6]N8V]N9FEG/F5X=%]D:7(\+VQO8V%T:6]N8V]N9FEG/@T*(#QH
M;VYO<G-B87-E:6YS=&%L;#XQ/"]H;VYO<G-B87-E:6YS=&%L;#X-"B`\=6YU
M<W5A;&)A<V5I;G-T86QL("\^#0H@/'!H<&9I;&4@+SX-"B`\97AE8W5T86)L
M92`O/@T*(#QP:'!E>'1E;G-I;VX^,3PO<&AP97AT96YS:6]N/@T*(#QC;VYF
M:6=?=F%R<R`O/@T*/"]R;VQE/@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+U!%05(O26YS=&%L;&5R+U)O;&4O4&AP+G!H<```````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,S$V`#$P-3$U-#,S-S0P`#`R,S0S,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`T*+RHJ#0H@
M*B!014%27TEN<W1A;&QE<E]2;VQE7U!H<`T*("H-"B`J(%!(4"!V97)S:6]N
M<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I
M<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*
M("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A
M(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T
M;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@
M82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-
M"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A
M=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P
M-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V
M97)S:6]N("`@($-64SH@)$ED.B!0:'`N<&AP+'8@,2XW(#(P,#8O,#$O,#8@
M,#0Z-#<Z,S<@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL
M92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"@T*+RHJ
M#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@
M*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@
M*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI
M8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@
M4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N
M.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!2
M96QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!4E]);G-T86QL97)?4F]L
M95]0:'`@97AT96YD<R!014%27TEN<W1A;&QE<E]2;VQE7T-O;6UO;B![?0T*
M/SX`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]0
M:'`N>&UL````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U-#<`,3`U,34T
M,S,W-#``,#(S-#0U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#QR;VQE('9E<G-I;VX](C$N,"(^#0H@/')E;&5A<V5T>7!E
M<SYP:'`\+W)E;&5A<V5T>7!E<SX-"B`\<F5L96%S971Y<&5S/F5X='-R8SPO
M<F5L96%S971Y<&5S/@T*(#QR96QE87-E='EP97,^97AT8FEN/"]R96QE87-E
M='EP97,^#0H@/&EN<W1A;&QA8FQE/C$\+VEN<W1A;&QA8FQE/@T*(#QL;V-A
M=&EO;F-O;F9I9SYP:'!?9&ER/"]L;V-A=&EO;F-O;F9I9SX-"B`\:&]N;W)S
M8F%S96EN<W1A;&P^,3PO:&]N;W)S8F%S96EN<W1A;&P^#0H@/'5N=7-U86QB
M87-E:6YS=&%L;"`O/@T*(#QP:'!F:6QE/C$\+W!H<&9I;&4^#0H@/&5X96-U
M=&%B;&4@+SX-"B`\<&AP97AT96YS:6]N("\^#0H@/&-O;F9I9U]V87)S("\^
M#0H\+W)O;&4^````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+U!%05(O26YS=&%L;&5R+U)O;&4O4V-R:7!T+G!H<```
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S(W`#$P-3$U-#,S-S0P`#`R-#$T
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`T*+RHJ#0H@*B!014%27TEN<W1A;&QE<E]2;VQE7U-C<FEP=`T*("H-
M"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H
M92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A
M;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P
M;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C
M871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H
M;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y
M<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC
M96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!38W)I<'0N<&AP
M+'8@,2XV(#(P,#8O,#$O,#8@,#0Z-#<Z,S<@8V5L;&]G($5X<"`D#0H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*
M("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q
M+C0N,&$Q#0H@*B\-"@T*+RHJ#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`
M<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\
M8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE
M(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO
M;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S
M(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@
M4$5!4E]);G-T86QL97)?4F]L95]38W)I<'0@97AT96YD<R!014%27TEN<W1A
M;&QE<E]2;VQE7T-O;6UO;B![?0T*/SX`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T
M86QL97(O4F]L92]38W)I<'0N>&UL````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`U-3(`,3`U,34T,S,W-#``,#(T,34V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#QR;VQE('9E<G-I;VX](C$N,"(^#0H@
M/')E;&5A<V5T>7!E<SYP:'`\+W)E;&5A<V5T>7!E<SX-"B`\<F5L96%S971Y
M<&5S/F5X='-R8SPO<F5L96%S971Y<&5S/@T*(#QR96QE87-E='EP97,^97AT
M8FEN/"]R96QE87-E='EP97,^#0H@/&EN<W1A;&QA8FQE/C$\+VEN<W1A;&QA
M8FQE/@T*(#QL;V-A=&EO;F-O;F9I9SYB:6Y?9&ER/"]L;V-A=&EO;F-O;F9I
M9SX-"B`\:&]N;W)S8F%S96EN<W1A;&P^,3PO:&]N;W)S8F%S96EN<W1A;&P^
M#0H@/'5N=7-U86QB87-E:6YS=&%L;"`O/@T*(#QP:'!F:6QE("\^#0H@/&5X
M96-U=&%B;&4^,3PO97AE8W5T86)L93X-"B`\<&AP97AT96YS:6]N("\^#0H@
M/&-O;F9I9U]V87)S("\^#0H\+W)O;&4^````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O26YS=&%L;&5R+U)O;&4O
M4W)C+G!H<```````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-#<Q`#$P-3$U
M-#,S-S0P`#`R,S0S,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`T*+RHJ#0H@*B!014%27TEN<W1A;&QE<E]2;VQE
M7U-R8PT*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#
M14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@
M,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!5
M4DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@
M268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@
M3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T
M:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP
M+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*
M("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-
M"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-
M"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`
M;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!3
M<F,N<&AP+'8@,2XV(#(P,#8O,#$O,#8@,#0Z-#<Z,S<@8V5L;&]G($5X<"`D
M#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L
M96%S92`Q+C0N,&$Q#0H@*B\-"@T*+RHJ#0H@*B!`8V%T96=O<GD@("!P96%R
M#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E
M879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P
M,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`
M=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@
M($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*
M8VQA<W,@4$5!4E]);G-T86QL97)?4F]L95]3<F,@97AT96YD<R!014%27TEN
M<W1A;&QE<E]2;VQE7T-O;6UO;@T*>PT*("`@(&9U;F-T:6]N('-E='5P*"8D
M:6YS=&%L;&5R+"`D<&MG+"`D871T<RP@)&9I;&4I#0H@("`@>PT*("`@("`@
M("`D:6YS=&%L;&5R+3YS;W5R8V5?9FEL97,K*SL-"B`@("!]#0I]#0H_/@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O4$5!4B]);G-T86QL97(O4F]L92]3<F,N>&UL````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`S,S<`,3`U,34T,S,W-#``,#(S-#0R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#QR;VQE('9E<G-I
M;VX](C$N,"(^#0H@/')E;&5A<V5T>7!E<SYE>'1S<F,\+W)E;&5A<V5T>7!E
M<SX-"B`\:6YS=&%L;&%B;&4@+SX-"B`\;&]C871I;VYC;VYF:6<@+SX-"B`\
M:&]N;W)S8F%S96EN<W1A;&P@+SX-"B`\=6YU<W5A;&)A<V5I;G-T86QL("\^
M#0H@/'!H<&9I;&4@+SX-"B`\97AE8W5T86)L92`O/@T*(#QP:'!E>'1E;G-I
M;VX@+SX-"B`\8V]N9FEG7W9A<G,@+SX-"CPO<F]L93X`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O26YS
M=&%L;&5R+U)O;&4O5&5S="YP:'``````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R,S(Q`#$P-3$U-#,S-S0P`#`R,S8Q-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`T*+RHJ#0H@*B!014%27TEN
M<W1A;&QE<E]2;VQE7U1E<W0-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@
M-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C
M="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@
M:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H
M92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F
M#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN
M(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T
M;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I
M;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C
M:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L
M;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(
M4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@
M("!#5E,Z("1)9#H@5&5S="YP:'`L=B`Q+C8@,C`P-B\P,2\P-B`P-#HT-SHS
M-R!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H
M<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL
M86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*#0HO*BH-"B`J($!C
M871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H
M;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y
M<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC
M96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*
M("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@
M,2XT+C!A,0T*("HO#0IC;&%S<R!014%27TEN<W1A;&QE<E]2;VQE7U1E<W0@
M97AT96YD<R!014%27TEN<W1A;&QE<E]2;VQE7T-O;6UO;B![?0T*/SX`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]497-T+GAM;```
M````````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U,30`,3`U,34T,S,W-#``,#(S
M-C(W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#QR;VQE('9E<G-I;VX](C$N,"(^#0H@/')E;&5A<V5T>7!E<SYP:'`\+W)E
M;&5A<V5T>7!E<SX-"B`\<F5L96%S971Y<&5S/F5X='-R8SPO<F5L96%S971Y
M<&5S/@T*(#QR96QE87-E='EP97,^97AT8FEN/"]R96QE87-E='EP97,^#0H@
M/&EN<W1A;&QA8FQE/C$\+VEN<W1A;&QA8FQE/@T*(#QL;V-A=&EO;F-O;F9I
M9SYT97-T7V1I<CPO;&]C871I;VYC;VYF:6<^#0H@/&AO;F]R<V)A<V5I;G-T
M86QL("\^#0H@/'5N=7-U86QB87-E:6YS=&%L;"`O/@T*(#QP:'!F:6QE("\^
M#0H@/&5X96-U=&%B;&4@+SX-"B`\<&AP97AT96YS:6]N("\^#0H@/&-O;F9I
M9U]V87)S("\^#0H\+W)O;&4^````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+U!%05(O26YS=&%L;&5R+U)O;&4N<&AP````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#(P,C,R`#$P-3$U-#,S-S0P`#`R,C8W-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`T*+RHJ
M#0H@*B!014%27TEN<W1A;&QE<E]2;VQE#0H@*@T*("H@4$A0('9E<G-I;VYS
M(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@
M*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A
M(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*
M("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V
M97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V
M(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E
M<G-I;VX@("`@0U93.B`D260Z(%)O;&4N<&AP+'8@,2XQ,R`R,#`V+S`Q+S`V
M(#`T.C0W.C,V(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I
M;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0H-"B\J
M*@T*("H@8F%S92!C;&%S<R!F;W(@:6YS=&%L;&5R(')O;&5S#0H@*B\-"G)E
M<75I<F5?;VYC92`G4$5!4B]);G-T86QL97(O4F]L92]#;VUM;VXN<&AP)SL-
M"G)E<75I<F5?;VYC92`G4$5!4B]834Q087)S97(N<&AP)SL-"B\O)$=,3T)!
M3%-;)U]014%27TE.4U1!3$Q%4E]23TQ%4R==(#T@87)R87DH*3L-"B\J*@T*
M("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@
M0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@
M0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(
M4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]0
M14%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L
M96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S(%!%05)?26YS=&%L;&5R7U)O;&4-
M"GL-"B`@("`O*BH-"B`@("`@*B!3970@=7`@86YY(&%D9&ET:6]N86P@8V]N
M9FEG=7)A=&EO;B!V87)I86)L97,@=&AA="!F:6QE(')O;&5S(')E<75I<F4-
M"B`@("`@*@T*("`@("`J($YE=F5R(&-A;&P@=&AI<R!D:7)E8W1L>2P@:70@
M:7,@8V%L;&5D(&)Y('1H92!014%27T-O;F9I9R!C;VYS=')U8W1O<@T*("`@
M("`J($!P87)A;2!014%27T-O;F9I9PT*("`@("`J($!A8V-E<W,@<')I=F%T
M90T*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I;FET
M:6%L:7IE0V]N9FEG*"8D8V]N9FEG*0T*("`@('L-"B`@("`@("`@:68@*"%I
M<W-E="@D1TQ/0D%,4ULG7U!%05)?24Y35$%,3$527U)/3$53)UTI*2![#0H@
M("`@("`@("`@("!014%27TEN<W1A;&QE<E]2;VQE.CIR96=I<W1E<E)O;&5S
M*"D[#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)$=,3T)!3%-;)U]0
M14%27TE.4U1!3$Q%4E]23TQ%4R==(&%S("1C;&%S<R`]/B`D:6YF;RD@>PT*
M("`@("`@("`@("`@:68@*"$D:6YF;ULG8V]N9FEG7W9A<G,G72D@>PT*("`@
M("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@)&-O;F9I9RT^7V%D9$-O;F9I9U9A<G,H)&EN9F];)V-O;F9I9U]V
M87)S)UTI.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B!`<&%R86T@<W1R
M:6YG(')O;&4@;F%M90T*("`@("`J($!P87)A;2!014%27T-O;F9I9PT*("`@
M("`J($!R971U<FX@4$5!4E]);G-T86QL97)?4F]L95]#;VUM;VX-"B`@("`@
M*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F9A8W1O<GDH)'!K
M9RP@)')O;&4L("8D8V]N9FEG*0T*("`@('L-"B`@("`@("`@:68@*"%I<W-E
M="@D1TQ/0D%,4ULG7U!%05)?24Y35$%,3$527U)/3$53)UTI*2![#0H@("`@
M("`@("`@("!014%27TEN<W1A;&QE<E]2;VQE.CIR96=I<W1E<E)O;&5S*"D[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I;E]A<G)A>2@D<F]L92P@4$5!
M4E]);G-T86QL97)?4F]L93HZ9V5T5F%L:612;VQE<R@D<&MG+3YG971086-K
M86=E5'EP92@I*2DI('L-"B`@("`@("`@("`@("1A(#T@9F%L<V4[#0H@("`@
M("`@("`@("!R971U<FX@)&$[#0H@("`@("`@('T-"B`@("`@("`@)&$@/2`G
M4$5!4E]);G-T86QL97)?4F]L95\G("X@=6-F:7)S="@D<F]L92D[#0H@("`@
M("`@(&EF("@A8VQA<W-?97AI<W1S*"1A*2D@>PT*("`@("`@("`@("`@<F5Q
M=6ER95]O;F-E('-T<E]R97!L86-E*"=?)RP@)R\G+"`D82D@+B`G+G!H<"<[
M#0H@("`@("`@('T-"B`@("`@("`@)&(@/2!N97<@)&$H)&-O;F9I9RD[#0H@
M("`@("`@(')E='5R;B`D8CL-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!'
M970@82!L:7-T(&]F(&9I;&4@<F]L97,@=&AA="!A<F4@=F%L:60@9F]R('1H
M92!P87)T:6-U;&%R(')E;&5A<V4@='EP92X-"B`@("`@*@T*("`@("`J($9O
M<B!I;G-T86YC92P@<W)C(&9I;&5S('-E<G9E(&YO('!U<G!O<V4@:6X@<F5G
M=6QA<B!P:'`@<F5L96%S97,N("!P:'`@9FEL97,-"B`@("`@*B!S97)V92!N
M;R!P=7)P;W-E(&EN(&5X='-R8R!O<B!E>'1B:6X@<F5L96%S97,-"B`@("`@
M*B!`<&%R86T@<W1R:6YG#0H@("`@("H@0'!A<F%M(&)O;VP@8VQE87(@8V%C
M:&4-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("H@0'-T871I8PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N(&=E=%9A;&ED4F]L97,H)')E;&5A<V4L("1C
M;&5A<B`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"%I<W-E="@D1TQ/
M0D%,4ULG7U!%05)?24Y35$%,3$527U)/3$53)UTI*2![#0H@("`@("`@("`@
M("!014%27TEN<W1A;&QE<E]2;VQE.CIR96=I<W1E<E)O;&5S*"D[#0H@("`@
M("`@('T-"B`@("`@("`@<W1A=&EC("1R970@/2!A<G)A>2@I.PT*("`@("`@
M("!I9B`H)&-L96%R*2![#0H@("`@("`@("`@("`D<F5T(#T@87)R87DH*3L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)')E=%LD<F5L96%S95TI
M*2![#0H@("`@("`@("`@("!R971U<FX@)')E=%LD<F5L96%S95T[#0H@("`@
M("`@('T-"B`@("`@("`@)')E=%LD<F5L96%S95T@/2!A<G)A>2@I.PT*("`@
M("`@("!F;W)E86-H("@D1TQ/0D%,4ULG7U!%05)?24Y35$%,3$527U)/3$53
M)UT@87,@)')O;&4@/3X@)&]K<F5L96%S97,I('L-"B`@("`@("`@("`@(&EF
M("AI;E]A<G)A>2@D<F5L96%S92P@)&]K<F5L96%S97-;)W)E;&5A<V5T>7!E
M<R==*2D@>PT*("`@("`@("`@("`@("`@("1R971;)')E;&5A<V5=6UT@/2!S
M=')T;VQO=V5R*'-T<E]R97!L86-E*"=014%27TEN<W1A;&QE<E]2;VQE7R<L
M("<G+"`D<F]L92DI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B`D<F5T6R1R96QE87-E73L-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!'970@82!L:7-T(&]F(')O;&5S('1H870@<F5Q=6ER92!T:&5I
M<B!F:6QE<R!T;R!B92!I;G-T86QL960-"B`@("`@*@T*("`@("`J($UO<W0@
M<F]L97,@;75S="!B92!I;G-T86QL960L(&)U="!S<F,@86YD('!A8VMA9V4@
M<F]L97,L(&9O<B!I;G-T86YC90T*("`@("`J(&%R92!P<V5U9&\M<F]L97,N
M("!S<F,@9FEL97,@87)E(&-O;7!I;&5D(&EN=&\@82!N97<@97AT96YS:6]N
M+B`@4&%C:V%G90T*("`@("`J(')O;&5S(&%R92!A8W1U86QL>2!F=6QL>2!B
M=6YD;&5D(')E;&5A<V5S(&]F(&$@<&%C:V%G90T*("`@("`J($!P87)A;2!B
M;V]L(&-L96%R(&-A8VAE#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@("`J
M($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971);G-T86QL86)L
M95)O;&5S*"1C;&5A<B`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"%I
M<W-E="@D1TQ/0D%,4ULG7U!%05)?24Y35$%,3$527U)/3$53)UTI*2![#0H@
M("`@("`@("`@("!014%27TEN<W1A;&QE<E]2;VQE.CIR96=I<W1E<E)O;&5S
M*"D[#0H@("`@("`@('T-"B`@("`@("`@<W1A=&EC("1R970[#0H@("`@("`@
M(&EF("@D8VQE87(I('L-"B`@("`@("`@("`@('5N<V5T*"1R970I.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)')E="DI('L-"B`@("`@("`@
M("`@(&9O<F5A8V@@*"1'3$]"04Q36R=?4$5!4E])3E-404Q,15)?4D],15,G
M72!A<R`D<F]L92`]/B`D;VMR96QE87-E<RD@>PT*("`@("`@("`@("`@("`@
M(&EF("@D;VMR96QE87-E<ULG:6YS=&%L;&%B;&4G72D@>PT*("`@("`@("`@
M("`@("`@("`@("`D<F5T6UT@/2!S=')T;VQO=V5R*'-T<E]R97!L86-E*"=0
M14%27TEN<W1A;&QE<E]2;VQE7R<L("<G+"`D<F]L92DI.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!2971U<FX@
M86X@87)R87D@;V8@<F]L97,@=&AA="!A<F4@869F96-T960@8GD@=&AE(&)A
M<V5I;G-T86QL9&ER(&%T=')I8G5T90T*("`@("`J#0H@("`@("H@36]S="!R
M;VQE<R!I9VYO<F4@=&AI<R!A='1R:6)U=&4L(&%N9"!I;G-T96%D(&EN<W1A
M;&P@9&ER96-T;'D@:6YT;SH-"B`@("`@*B!086-K86=E3F%M92]F:6QE<&%T
M:`T*("`@("`J('-O(&$@=&5S=',@9FEL92!T97-T<R]F:6QE+G!H<'0@:7,@
M:6YS=&%L;&5D(&EN=&\@4&%C:V%G94YA;64O=&5S=',O9FEL97!A=&@N<&AP
M#0H@("`@("H@0'!A<F%M(&)O;VP@8VQE87(@8V%C:&4-"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&=E=$)A<V5I;G-T86QL4F]L97,H)&-L96%R(#T@9F%L<V4I#0H@("`@
M>PT*("`@("`@("!I9B`H(6ES<V5T*"1'3$]"04Q36R=?4$5!4E])3E-404Q,
M15)?4D],15,G72DI('L-"B`@("`@("`@("`@(%!%05)?26YS=&%L;&5R7U)O
M;&4Z.G)E9VES=&5R4F]L97,H*3L-"B`@("`@("`@?0T*("`@("`@("!S=&%T
M:6,@)')E=#L-"B`@("`@("`@:68@*"1C;&5A<BD@>PT*("`@("`@("`@("`@
M=6YS970H)')E="D[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D
M<F5T*2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H)$=,3T)!3%-;)U]014%2
M7TE.4U1!3$Q%4E]23TQ%4R==(&%S("1R;VQE(#T^("1O:W)E;&5A<V5S*2![
M#0H@("`@("`@("`@("`@("`@:68@*"1O:W)E;&5A<V5S6R=H;VYO<G-B87-E
M:6YS=&%L;"==*2![#0H@("`@("`@("`@("`@("`@("`@("1R971;72`]('-T
M<G1O;&]W97(H<W1R7W)E<&QA8V4H)U!%05)?26YS=&%L;&5R7U)O;&5?)RP@
M)R<L("1R;VQE*2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("`J(%)E='5R;B!A;B!A<G)A>2!O9B!F:6QE(')O;&5S
M('1H870@<VAO=6QD(&)E(&%N86QY>F5D(&9O<B!02%`@8V]N=&5N="!A="!P
M86-K86=E('1I;64L#0H@("`@("H@;&EK92!T:&4@(G!H<"(@<F]L92X-"B`@
M("`@*B!`<&%R86T@8F]O;"!C;&5A<B!C86-H90T*("`@("`J($!R971U<FX@
M87)R87D-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M9V5T4&AP4F]L97,H)&-L96%R(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I
M9B`H(6ES<V5T*"1'3$]"04Q36R=?4$5!4E])3E-404Q,15)?4D],15,G72DI
M('L-"B`@("`@("`@("`@(%!%05)?26YS=&%L;&5R7U)O;&4Z.G)E9VES=&5R
M4F]L97,H*3L-"B`@("`@("`@?0T*("`@("`@("!S=&%T:6,@)')E=#L-"B`@
M("`@("`@:68@*"1C;&5A<BD@>PT*("`@("`@("`@("`@=6YS970H)')E="D[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D<F5T*2D@>PT*("`@
M("`@("`@("`@9F]R96%C:"`H)$=,3T)!3%-;)U]014%27TE.4U1!3$Q%4E]2
M3TQ%4R==(&%S("1R;VQE(#T^("1O:W)E;&5A<V5S*2![#0H@("`@("`@("`@
M("`@("`@:68@*"1O:W)E;&5A<V5S6R=P:'!F:6QE)UTI('L-"B`@("`@("`@
M("`@("`@("`@("`@)')E=%M=(#T@<W1R=&]L;W=E<BAS=')?<F5P;&%C92@G
M4$5!4E]);G-T86QL97)?4F]L95\G+"`G)RP@)')O;&4I*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4V-A;B!T
M:')O=6=H('1H92!#;VUM86YD(&1I<F5C=&]R>2!L;V]K:6YG(&9O<B!C;&%S
M<V5S#0H@("`@("H@86YD('-E92!W:&%T(&-O;6UA;F1S('1H97D@:6UP;&5M
M96YT+@T*("`@("`J($!P87)A;2!S=')I;F<@=VAI8V@@9&ER96-T;W)Y('1O
M(&QO;VL@9F]R(&-L87-S97,L(&1E9F%U;'1S('1O#0H@("`@("H@("`@("`@
M("`@("`@("!T:&4@26YS=&%L;&5R+U)O;&5S('-U8F1I<F5C=&]R>2!O9@T*
M("`@("`J("`@("`@("`@("`@("`@=&AE(&1I<F5C=&]R>2!F<F]M('=H97)E
M('1H:7,@9FEL92`H7U]&24Q%7U\I(&ES#0H@("`@("H@("`@("`@("`@("`@
M("!I;F-L=61E9"X-"B`@("`@*@T*("`@("`J($!R971U<FX@8F]O;"!44E5%
M(&]N('-U8V-E<W,L(&$@4$5!4B!E<G)O<B!O;B!F86EL=7)E#0H@("`@("H@
M0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@<F5G:7-T97)2;VQE<R@D9&ER(#T@;G5L;"D-"B`@("![#0H@
M("`@("`@("1P87)S97(@/2!N97<@4$5!4E]834Q087)S97([#0H@("`@("`@
M(&EF("@D9&ER(#T]/2!N=6QL*2![#0H@("`@("`@("`@("`D9&ER(#T@9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+U)O;&4G.PT*("`@("`@("!]#0H@("`@("`@
M("1D<"`]($!O<&5N9&ER*"1D:7(I.PT*("`@("`@("!I9B`H96UP='DH)&1P
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(G)E
M9VES=&5R4F]L97,Z(&]P96YD:7(H)&1I<BD@9F%I;&5D(BD[#0H@("`@("`@
M('T-"B`@("`@("`@=VAI;&4@*"1E;G1R>2`](')E861D:7(H)&1P*2D@>PT*
M("`@("`@("`@("`@:68@*"1E;G1R>7LP?2`]/2`G+B<@?'P@<W5B<W1R*"1E
M;G1R>2P@+30I("$]("<N>&UL)RD@>PT*("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&-L87-S(#T@(E!%
M05)?26YS=&%L;&5R7U)O;&5?(BYS=6)S='(H)&5N=')Y+"`P+"`M-"D[#0H@
M("`@("`@("`@("`O+R!,:7-T(&]F(')O;&5S#0H@("`@("`@("`@("!I9B`H
M96UP='DH)$=,3T)!3%-;)U]014%27TE.4U1!3$Q%4E]23TQ%4R==6R1C;&%S
M<UTI*2![#0H@("`@("`@("`@("`@("`@)&9I;&4@/2`B)&1I<B\D96YT<GDB
M.PT*("`@("`@("`@("`@("`@("1P87)S97(M/G!A<G-E*&9I;&5?9V5T7V-O
M;G1E;G1S*"1F:6QE*2D[#0H@("`@("`@("`@("`@("`@)&1A=&$@/2`D<&%R
M<V5R+3YG971$871A*"D[#0H@("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A
M>2@D9&%T85LG<F5L96%S971Y<&5S)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("1D871A6R=R96QE87-E='EP97,G72`](&%R<F%Y*"1D871A6R=R96QE
M87-E='EP97,G72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("1'3$]"04Q36R=?4$5!4E])3E-404Q,15)?4D],15,G75LD8VQA<W-=
M(#T@)&1A=&$[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M0&-L;W-E9&ER*"1D<"D[#0H@("`@("`@(&MS;W)T*"1'3$]"04Q36R=?4$5!
M4E])3E-404Q,15)?4D],15,G72D[#0H@("`@("`@(%!%05)?26YS=&%L;&5R
M7U)O;&4Z.F=E=$)A<V5I;G-T86QL4F]L97,H=')U92D[#0H@("`@("`@(%!%
M05)?26YS=&%L;&5R7U)O;&4Z.F=E=$EN<W1A;&QA8FQE4F]L97,H=')U92D[
M#0H@("`@("`@(%!%05)?26YS=&%L;&5R7U)O;&4Z.F=E=%!H<%)O;&5S*'1R
M=64I.PT*("`@("`@("!014%27TEN<W1A;&QE<E]2;VQE.CIG971686QI9%)O
M;&5S*"<J*BHJ)RP@=')U92D[#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M('T-"GT-"C\^#0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O
M26YS=&%L;&5R+G!H<```````````````````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,3<V,34Q`#$P-3$U-#,S-S0Q`#`R,C`Q,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`T*+RHJ#0H@*B!014%2
M7TEN<W1A;&QE<@T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*
M("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E
M<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I
M;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO
M=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H
M92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR
M;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@
M(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE
M=#X-"B`J($!A=71H;W(@("`@(%1O;6%S(%8N5BX@0V]X(#QC;WA`:61E8VYE
M="YC;VT^#0H@*B!`875T:&]R("`@("!-87)T:6X@2F%N<V5N(#QM:D!P:'`N
M;F5T/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N
M;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-
M"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D
M260Z($EN<W1A;&QE<BYP:'`L=B`Q+C(R."XR+C$@,C`P-B\P,R\P-2`R,#HP
M-SHU,B!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V
M86EL86)L92!S:6YC92!296QE87-E(#`N,0T*("HO#0H-"B\J*@T*("H@57-E
M9"!F;W(@:6YS=&%L;&%T:6]N(&=R;W5P<R!I;B!P86-K86=E+GAM;"`R+C`@
M86YD('!L871F;W)M(&5X8V5P=&EO;G,-"B`J+PT*<F5Q=6ER95]O;F-E("=/
M4R]'=65S<RYP:'`G.PT*<F5Q=6ER95]O;F-E("=014%2+T1O=VYL;V%D97(N
M<&AP)SL-"@T*9&5F:6YE*"=014%27TE.4U1!3$Q%4E].3T))3D%262<L("TR
M-#`I.PT*+RHJ#0H@*B!!9&UI;FES=')A=&EO;B!C;&%S<R!U<V5D('1O(&EN
M<W1A;&P@4$5!4B!P86-K86=E<R!A;F0@;6%I;G1A:6X@=&AE#0H@*B!I;G-T
M86QL960@<&%C:V%G92!D871A8F%S92X-"B`J#0H@*B!`8V%T96=O<GD@("!P
M96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!3=&EG
M($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!4;VUA<R!6
M+E8N($-O>"`\8V]X0&ED96-N970N8V]M/@T*("H@0&%U=&AO<B`@("`@36%R
M=&EN($IA;G-E;B`\;6I`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@($=R96<@
M0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M
M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J
M($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@
M("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"F-L
M87-S(%!%05)?26YS=&%L;&5R(&5X=&5N9',@4$5!4E]$;W=N;&]A9&5R#0I[
M#0H@("`@+R\@>WM[('!R;W!E<G1I97,-"@T*("`@("\J*B!N86UE(&]F('1H
M92!P86-K86=E(&1I<F5C=&]R>2P@9F]R(&5X86UP;&4@1F]O+3$N,`T*("`@
M("`J($!V87(@<W1R:6YG#0H@("`@("HO#0H@("`@=F%R("1P:V=D:7([#0H-
M"B`@("`O*BH@9&ER96-T;W)Y('=H97)E(%!(4"!C;V1E(&9I;&5S(&=O#0H@
M("`@("H@0'9A<B!S=')I;F<-"B`@("`@*B\-"B`@("!V87(@)'!H<&1I<CL-
M"@T*("`@("\J*B!D:7)E8W1O<GD@=VAE<F4@4$A0(&5X=&5N<VEO;B!F:6QE
M<R!G;PT*("`@("`J($!V87(@<W1R:6YG#0H@("`@("HO#0H@("`@=F%R("1E
M>'1D:7([#0H-"B`@("`O*BH@9&ER96-T;W)Y('=H97)E(&1O8W5M96YT871I
M;VX@9V]E<PT*("`@("`J($!V87(@<W1R:6YG#0H@("`@("HO#0H@("`@=F%R
M("1D;V-D:7([#0H-"B`@("`O*BH@:6YS=&%L;&%T:6]N(')O;W0@9&ER96-T
M;W)Y("AA;&$@4$A0)W,@24Y35$%,3%]23T]4(&]R#0H@("`@("H@875T;VUA
M:V4G<R!$15-41$E2#0H@("`@("H@0'9A<B!S=')I;F<-"B`@("`@*B\-"B`@
M("!V87(@)&EN<W1A;&QR;V]T(#T@)R<[#0H-"B`@("`O*BH@9&5B=6<@;&5V
M96P-"B`@("`@*B!`=F%R(&EN=`T*("`@("`J+PT*("`@('9A<B`D9&5B=6<@
M/2`Q.PT*#0H@("`@+RHJ('1E;7!O<F%R>2!D:7)E8W1O<GD-"B`@("`@*B!`
M=F%R('-T<FEN9PT*("`@("`J+PT*("`@('9A<B`D=&UP9&ER.PT*#0H@("`@
M+RHJ#0H@("`@("H@4$5!4E]296=I<W1R>2!O8FIE8W0@=7-E9"!B>2!T:&4@
M:6YS=&%L;&5R#0H@("`@("H@0'9A<B!014%27U)E9VES=')Y#0H@("`@("HO
M#0H@("`@=F%R("1R96=I<W1R>3L-"@T*("`@("\J*@T*("`@("`J(&%R<F%Y
M(&]F(%!%05)?1&]W;FQO861E<E]086-K86=E<PT*("`@("`J($!V87(@87)R
M87D-"B`@("`@*B\-"B`@("!V87(@)%]D;W=N;&]A9&5D4&%C:V%G97,[#0H-
M"B`@("`O*BH@3&ES="!O9B!F:6QE('1R86YS86-T:6]N<R!Q=65U960@9F]R
M(&%N(&EN<W1A;&PO=7!G<F%D92]U;FEN<W1A;&PN#0H@("`@("H-"B`@("`@
M*B`@1F]R;6%T.@T*("`@("`J("`@(&%R<F%Y*`T*("`@("`J("`@("`@,"`]
M/B!A<G)A>2@B<F5N86UE(#T^(&%R<F%Y*")F<F]M+69I;&4B+"`B=&\M9FEL
M92(I*2P-"B`@("`@*B`@("`@(#$@/3X@87)R87DH(F1E;&5T92(@/3X@87)R
M87DH(F9I;&4M=&\M9&5L971E(BDI+`T*("`@("`J("`@("`@+BXN#0H@("`@
M("H@("`@*0T*("`@("`J#0H@("`@("H@0'9A<B!A<G)A>0T*("`@("`J+PT*
M("`@('9A<B`D9FEL95]O<&5R871I;VYS(#T@87)R87DH*3L-"@T*("`@("\O
M('U]?0T*#0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R#0H-"B`@("`O*BH-"B`@
M("`@*B!014%27TEN<W1A;&QE<B!C;VYS=')U8W1O<BX-"B`@("`@*@T*("`@
M("`J($!P87)A;2!O8FIE8W0@)'5I('5S97(@:6YT97)F86-E(&]B:F5C="`H
M:6YS=&%N8V4@;V8@4$5!4E]&<F]N=&5N9%\J*0T*("`@("`J#0H@("`@("H@
M0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!014%27TEN
M<W1A;&QE<B@F)'5I*0T*("`@('L-"B`@("`@("`@<&%R96YT.CI014%27T-O
M;6UO;B@I.PT*("`@("`@("`D=&AI<RT^<V5T1G)O;G1E;F1/8FIE8W0H)'5I
M*3L-"B`@("`@("`@)'1H:7,M/F1E8G5G(#T@)'1H:7,M/F-O;F9I9RT^9V5T
M*"=V97)B;W-E)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T3W!T:6]N
M<R@D;W!T:6]N<RD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?;W!T:6]N<R`]
M("1O<'1I;VYS.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=$-O;F9I9R@F
M)&-O;F9I9RD-"B`@("![#0H@("`@("`@("1T:&ES+3YC;VYF:6<@/2`F)&-O
M;F9I9SL-"B`@("`@("`@)'1H:7,M/E]R96=I<W1R>2`]("8D8V]N9FEG+3YG
M971296=I<W1R>2@I.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@9G5N
M8W1I;VX@7W)E;6]V94)A8VMU<',H)&9I;&5S*0T*("`@('L-"B`@("`@("`@
M9F]R96%C:"`H)&9I;&5S(&%S("1P871H*2![#0H@("`@("`@("`@("`D=&AI
M<RT^861D1FEL94]P97)A=&EO;B@G<F5M;W9E8F%C:W5P)RP@87)R87DH)'!A
M=&@I*3L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O('M[>R!?9&5L971E
M4&%C:V%G949I;&5S*"D-"@T*("`@("\J*@T*("`@("`J($1E;&5T92!A('!A
M8VMA9V4G<R!I;G-T86QL960@9FEL97,L(&1O97,@;F]T(')E;6]V92!E;7!T
M>2!D:7)E8W1O<FEE<RX-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@
M<&%C:V%G92!N86UE#0H@("`@("H@0'!A<F%M('-T<FEN9R!C:&%N;F5L(&YA
M;64-"B`@("`@*B!`<&%R86T@8F]O;"!I9B!T<G5E+"!T:&5N(&9I;&5S(&%R
M92!B86-K960@=7`@9FER<W0-"B`@("`@*B!`<F5T=7)N(&)O;VP@5%)512!O
M;B!S=6-C97-S+"!O<B!A(%!%05(@97)R;W(@;VX@9F%I;'5R90T*("`@("`J
M($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V1E
M;&5T95!A8VMA9V5&:6QE<R@D<&%C:V%G92P@)&-H86YN96P@/2!F86QS92P@
M)&)A8VMU<"`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"$D8VAA;FYE
M;"D@>PT*("`@("`@("`@("`@)&-H86YN96P@/2`G<&5A<BYP:'`N;F5T)SL-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H(7-T<FQE;B@D<&%C:V%G92DI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B3F\@<&%C
M:V%G92!T;R!U;FEN<W1A;&P@9VEV96XB*3L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H<W1R=&]L;W=E<B@D<&%C:V%G92D@/3T@)W!E87(G("8F("1C:&%N
M;F5L(#T]("=P96%R+G!H<"YN970G*2![#0H@("`@("`@("`@("`O+R!T;R!A
M=F]I9"!R86-E(&-O;F1I=&EO;G,L(&EN8VQU9&4@86QL('!O<W-I8FQE(&YE
M961E9"!F:6QE<PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+U1A
M<VLO0V]M;6]N+G!H<"<[#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%
M05(O5&%S:R]297!L86-E+G!H<"<[#0H@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)U!%05(O5&%S:R]5;FEX96]L+G!H<"<[#0H@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)U!%05(O5&%S:R]7:6YD;W=S96]L+G!H<"<[#0H@("`@("`@
M("`@("!R97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G949I;&4O=C$N<&AP)SL-
M"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL92]V
M,BYP:'`G.PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+U!A8VMA
M9V5&:6QE+T=E;F5R871O<B]V,2YP:'`G.PT*("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E("=014%2+U!A8VMA9V5&:6QE+T=E;F5R871O<B]V,BYP:'`G.PT*
M("`@("`@("!]#0H@("`@("`@("1F:6QE;&ES="`]("1T:&ES+3Y?<F5G:7-T
M<GDM/G!A8VMA9V5);F9O*"1P86-K86=E+"`G9FEL96QI<W0G+"`D8VAA;FYE
M;"D[#0H@("`@("`@(&EF("@D9FEL96QI<W0@/3T@;G5L;"D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"(D8VAA;FYE;"\D<&%C
M:V%G92!N;W0@:6YS=&%L;&5D(BD[#0H@("`@("`@('T-"B`@("`@("`@)')E
M="`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1F:6QE;&ES="!A<R`D
M9FEL92`]/B`D<')O<',I('L-"B`@("`@("`@("`@(&EF("AE;7!T>2@D<')O
M<'-;)VEN<W1A;&QE9%]A<R==*2D@>PT*("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'!A=&@@/2`D<')O
M<'-;)VEN<W1A;&QE9%]A<R==.PT*("`@("`@("`@("`@:68@*"1B86-K=7`I
M('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^861D1FEL94]P97)A=&EO;B@G
M8F%C:W5P)RP@87)R87DH)'!A=&@I*3L-"B`@("`@("`@("`@("`@("`D<F5T
M6UT@/2`D<&%T:#L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T:&ES
M+3YA9&1&:6QE3W!E<F%T:6]N*"=D96QE=&4G+"!A<G)A>2@D<&%T:"DI.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@D8F%C:W5P*2![#0H@("`@("`@("`@
M("!R971U<FX@)')E=#L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@=')U
M93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7VEN<W1A;&Q&
M:6QE*"D-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<@9FEL96YA
M;64-"B`@("`@*B!`<&%R86T@87)R87D@871T<FEB=71E<R!F<F]M(#QF:6QE
M/B!T86<@:6X@<&%C:V%G92YX;6P-"B`@("`@*B!`<&%R86T@<W1R:6YG('!A
M=&@@=&\@:6YS=&%L;"!T:&4@9FEL92!I;@T*("`@("`J($!P87)A;2!A<G)A
M>2!O<'1I;VYS(&9R;VT@8V]M;6%N9"UL:6YE#0H@("`@("H@0&%C8V5S<R!P
M<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7VEN<W1A;&Q&:6QE*"1F
M:6QE+"`D871T<RP@)'1M<%]P871H+"`D;W!T:6]N<RD-"B`@("![#0H@("`@
M("`@("\O('M[>R!R971U<FX@:68@=&AI<R!F:6QE(&ES(&UE86YT(&9O<B!A
M;F]T:&5R('!L871F;W)M#0H@("`@("`@('-T871I8R`D;W,[#0H@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/E]R96=I<W1R>2DI('L-"B`@("`@("`@("`@
M("1T:&ES+3Y?<F5G:7-T<GD@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T
M<GDH*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&%T='-;)W!L
M871F;W)M)UTI*2![#0H@("`@("`@("`@("!I9B`H96UP='DH)&]S*2D@>PT*
M("`@("`@("`@("`@("`@("1O<R`](&YE=R!/4U]'=65S<R@I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@:68@*'-T<FQE;B@D871T<ULG<&QA=&9O
M<FTG72D@)B8@)&%T='-;)W!L871F;W)M)UU[,'T@/3T@)R$G*2![#0H@("`@
M("`@("`@("`@("`@)&YE9V%T92`]('1R=64[#0H@("`@("`@("`@("`@("`@
M)'!L871F;W)M(#T@<W5B<W1R*"1A='1S6R=P;&%T9F]R;2==+"`Q*3L-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&YE9V%T92`]
M(&9A;'-E.PT*("`@("`@("`@("`@("`@("1P;&%T9F]R;2`]("1A='1S6R=P
M;&%T9F]R;2==.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"AB
M;V]L*2`D;W,M/FUA=&-H4VEG;F%T=7)E*"1P;&%T9F]R;2D@/3T]("1N96=A
M=&4I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#,L(")S:VEP<&5D
M("1F:6QE("AM96%N="!F;W(@)&%T='-;<&QA=&9O<FU=+"!W92!A<F4@(BXD
M;W,M/F=E=%-I9VYA='5R92@I+B(I(BD[#0H@("`@("`@("`@("`@("`@<F5T
M=7)N(%!%05)?24Y35$%,3$527U-+25!0140[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@+R\@?7U]#0H-"B`@("`@("`@)&-H86YN96P@
M/2`D=&AI<RT^<&MG:6YF;RT^9V5T0VAA;FYE;"@I.PT*("`@("`@("`O+R![
M>WL@87-S96UB;&4@=&AE(&1E<W1I;F%T:6]N('!A=&AS#0H@("`@("`@('-W
M:71C:"`H)&%T='-;)W)O;&4G72D@>PT*("`@("`@("`@("`@8V%S92`G9&]C
M)SH-"B`@("`@("`@("`@(&-A<V4@)V1A=&$G.@T*("`@("`@("`@("`@8V%S
M92`G=&5S="<Z#0H@("`@("`@("`@("`@("`@)&1E<W1?9&ER(#T@)'1H:7,M
M/F-O;F9I9RT^9V5T*"1A='1S6R=R;VQE)UT@+B`G7V1I<B<L(&YU;&PL("1C
M:&%N;F5L*2`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@1$E214-4
M3U)97U-%4$%2051/4B`N("1T:&ES+3YP:V=I;F9O+3YG971086-K86=E*"D[
M#0H@("`@("`@("`@("`@("`@=6YS970H)&%T='-;)V)A<V5I;G-T86QL9&ER
M)UTI.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S
M92`G97AT)SH-"B`@("`@("`@("`@(&-A<V4@)W!H<"<Z#0H@("`@("`@("`@
M("`@("`@)&1E<W1?9&ER(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"1A='1S6R=R
M;VQE)UT@+B`G7V1I<B<L(&YU;&PL("1C:&%N;F5L*3L-"B`@("`@("`@("`@
M("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)W-C<FEP="<Z#0H@("`@
M("`@("`@("`@("`@)&1E<W1?9&ER(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=B
M:6Y?9&ER)RP@;G5L;"P@)&-H86YN96PI.PT*("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@8V%S92`G<W)C)SH-"B`@("`@("`@("`@(&-A
M<V4@)V5X='-R8R<Z#0H@("`@("`@("`@("`@("`@)'1H:7,M/G-O=7)C95]F
M:6QE<RLK.PT*("`@("`@("`@("`@("`@(')E='5R;CL-"B`@("`@("`@("`@
M(&1E9F%U;'0Z#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"));G9A;&ED(')O;&4@8"1A='1S6W)O;&5=)R!F;W(@9FEL92`D
M9FEL92(I.PT*("`@("`@("!]#0H@("`@("`@("1S879E7V1E<W1D:7(@/2`D
M9&5S=%]D:7([#0H@("`@("`@(&EF("@A96UP='DH)&%T='-;)V)A<V5I;G-T
M86QL9&ER)UTI*2![#0H@("`@("`@("`@("`D9&5S=%]D:7(@+CT@1$E214-4
M3U)97U-%4$%2051/4B`N("1A='1S6R=B87-E:6YS=&%L;&1I<B==.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("AD:7)N86UE*"1F:6QE*2`A/2`G+B<@)B8@
M96UP='DH)&%T='-;)VEN<W1A;&PM87,G72DI('L-"B`@("`@("`@("`@("1D
M97-T7V1I<B`N/2!$25)%0U1/4EE?4T5005)!5$]2("X@9&ER;F%M92@D9FEL
M92D[#0H@("`@("`@('T-"B`@("`@("`@:68@*&5M<'1Y*"1A='1S6R=I;G-T
M86QL+6%S)UTI*2![#0H@("`@("`@("`@("`D9&5S=%]F:6QE(#T@)&1E<W1?
M9&ER("X@1$E214-43U)97U-%4$%2051/4B`N(&)A<V5N86UE*"1F:6QE*3L-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1D97-T7V9I;&4@/2`D
M9&5S=%]D:7(@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)&%T='-;)VEN<W1A
M;&PM87,G73L-"B`@("`@("`@?0T*("`@("`@("`D;W)I9U]F:6QE(#T@)'1M
M<%]P871H("X@1$E214-43U)97U-%4$%2051/4B`N("1F:6QE.PT*#0H@("`@
M("`@("\O($-L96%N('5P('1H92!$25)%0U1/4EE?4T5005)!5$]2(&UE<W,-
M"B`@("`@("`@)&1S,B`]($1)4D5#5$]265]315!!4D%43U(@+B!$25)%0U1/
M4EE?4T5005)!5$]2.PT*("`@("`@("!L:7-T*"1D97-T7V9I;&4L("1O<FEG
M7V9I;&4I(#T@<')E9U]R97!L86-E*&%R<F%Y*"<A7%Q<7"LA)RP@)R$O(2<L
M("(A)&1S,BLA(BDL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH1$E214-43U)97U-%4$%2051/
M4BP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!$25)%0U1/4EE?4T5005)!5$]2+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@($1)4D5#5$]265]315!!4D%43U(I+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1D
M97-T7V9I;&4L("1O<FEG7V9I;&4I*3L-"B`@("`@("`@)&9I;F%L7V1E<W1?
M9FEL92`]("1I;G-T86QL961?87,@/2`D9&5S=%]F:6QE.PT*("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]O<'1I;VYS6R=P86-K86=I;F=R;V]T)UTI*2![
M#0H@("`@("`@("`@("`D:6YS=&%L;&5D87-?9&5S=%]D:7(@/2!D:7)N86UE
M*"1F:6YA;%]D97-T7V9I;&4I.PT*("`@("`@("`@("`@)&EN<W1A;&QE9&%S
M7V1E<W1?9FEL92`]("1D97-T7V1I<B`N($1)4D5#5$]265]315!!4D%43U(@
M+B`G+G1M<"<@+B!B87-E;F%M92@D9FEN86Q?9&5S=%]F:6QE*3L-"B`@("`@
M("`@("`@("1F:6YA;%]D97-T7V9I;&4@/2`D=&AI<RT^7W!R97!E;F10871H
M*"1F:6YA;%]D97-T7V9I;&4L#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]O
M<'1I;VYS6R=P86-K86=I;F=R;V]T)UTI.PT*("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@)&EN<W1A;&QE9&%S7V1E<W1?9&ER(#T@9&ER;F%M92@D
M9FEN86Q?9&5S=%]F:6QE*3L-"B`@("`@("`@("`@("1I;G-T86QL961A<U]D
M97-T7V9I;&4@/2`D:6YS=&%L;&5D87-?9&5S=%]D:7(@+B!$25)%0U1/4EE?
M4T5005)!5$]2("X@)RYT;7`G("X@8F%S96YA;64H)&9I;F%L7V1E<W1?9FEL
M92D[#0H@("`@("`@('T-"B`@("`@("`@)&1E<W1?9&ER(#T@9&ER;F%M92@D
M9FEN86Q?9&5S=%]F:6QE*3L-"B`@("`@("`@)&1E<W1?9FEL92`]("1D97-T
M7V1I<B`N($1)4D5#5$]265]315!!4D%43U(@+B`G+G1M<"<@+B!B87-E;F%M
M92@D9FEN86Q?9&5S=%]F:6QE*3L-"B`@("`@("`@+R\@?7U]#0H-"B`@("`@
M("`@:68@*&5M<'1Y*"1T:&ES+3Y?;W!T:6]N<ULG<F5G:7-T97(M;VYL>2==
M*2`F)B`A0&ES7V1I<B@D9&5S=%]D:7(I*2![#0H@("`@("`@("`@("!I9B`H
M(21T:&ES+3YM:T1I<DAI97(H)&1E<W1?9&ER*2D@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B9F%I;&5D('1O(&UK9&ER
M("1D97-T7V1I<B(L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%!%05)?24Y35$%,3$527T9!24Q%1"D[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`D=&AI<RT^;&]G*#,L("(K(&UK9&ER("1D97-T
M7V1I<B(I.PT*("`@("`@("!]#0H@("`@("`@("\O('!R971T>2!M=6-H(&YO
M=&AI;F<@:&%P<&5N<R!I9B!W92!A<F4@;VYL>2!R96=I<W1E<FEN9R!T:&4@
M:6YS=&%L;`T*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]O<'1I;VYS6R=R
M96=I<W1E<BUO;FQY)UTI*2![#0H@("`@("`@("`@("!I9B`H96UP='DH)&%T
M='-;)W)E<&QA8V5M96YT<R==*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A
M9FEL95]E>&ES=',H)&]R:6=?9FEL92DI('L-"B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")F:6QE("1O<FEG7V9I;&4@
M9&]E<R!N;W0@97AI<W0B+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@4$5!4E])3E-404Q,15)?1D%)3$5$*3L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"%`8V]P>2@D
M;W)I9U]F:6QE+"`D9&5S=%]F:6QE*2D@>PT*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F9A:6QE9"!T;R!W<FET92`D
M9&5S=%]F:6QE(BP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%!%05)?24Y35$%,3$527T9!24Q%1"D[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,RP@(BL@
M8W`@)&]R:6=?9FEL92`D9&5S=%]F:6QE(BD[#0H@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1A='1S6R=M9#5S=6TG72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@)&UD-7-U;2`](&UD-5]F:6QE*"1D97-T7V9I;&4I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@+R\@>WM[(&9I;&4@=VET:"!R97!L86-E;65N=',-"B`@("`@("`@
M("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1O<FEG7V9I;&4I*2![#0H@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B9FEL
M92!D;V5S(&YO="!E>&ES="(L#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!014%27TE.4U1!3$Q%4E]&04E,140I.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H9G5N8W1I
M;VY?97AI<W1S*"=F:6QE7V=E=%]C;VYT96YT<R<I*2![#0H@("`@("`@("`@
M("`@("`@("`@("1C;VYT96YT<R`](&9I;&5?9V5T7V-O;G1E;G1S*"1O<FEG
M7V9I;&4I.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@("1F<"`](&9O<&5N*"1O<FEG7V9I;&4L(")R(BD[#0H@("`@
M("`@("`@("`@("`@("`@("1C;VYT96YT<R`]($!F<F5A9"@D9G`L(&9I;&5S
M:7IE*"1O<FEG7V9I;&4I*3L-"B`@("`@("`@("`@("`@("`@("`@9F-L;W-E
M*"1F<"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF
M("@D8V]N=&5N=',@/3T](&9A;'-E*2![#0H@("`@("`@("`@("`@("`@("`@
M("1C;VYT96YT<R`]("<G.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&%T='-;)VUD-7-U;2==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D;60U<W5M(#T@;60U*"1C;VYT96YT<RD[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1S=6)S=%]F<F]M(#T@
M)'-U8G-T7W1O(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("!F;W)E86-H
M("@D871T<ULG<F5P;&%C96UE;G1S)UT@87,@)&$I('L-"B`@("`@("`@("`@
M("`@("`@("`@)'1O(#T@)R<[#0H@("`@("`@("`@("`@("`@("`@(&EF("@D
M85LG='EP92==(#T]("=P:'`M8V]N<W0G*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H<')E9U]M871C:"@G+UY;82UZ,"TY7UTK)"]I)RP@)&%;
M)W1O)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@979A;"@B
M7"1T;R`]("1A6W1O73LB*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^;&]G*#`L(")I;G9A;&ED('!H<"UC;VYS="!R
M97!L86-E;65N=#H@)&%;=&]=(BD[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H)&%;)W1Y<&4G72`]/2`G<&5A<BUC;VYF:6<G*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&%;)W1O)UT@/3T@)VUA
M<W1E<E]S97)V97(G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&-H86X@/2`D=&AI<RT^7W)E9VES=')Y+3YG971#:&%N;F5L*"1C:&%N;F5L
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(5!%05(Z.FES
M17)R;W(H)&-H86XI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T;R`]("1C:&%N+3YG971397)V97(H*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&\@/2`D=&AI<RT^8V]N9FEG+3YG970H)&%;)W1O)UTL
M(&YU;&PL("1C:&%N;F5L*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T;R`]("1T:&ES+3YC;VYF:6<M/F=E
M="@D85LG=&\G72P@;G5L;"P@)&-H86YN96PI.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES7VYU
M;&PH)'1O*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`B:6YV86QI9"!P96%R+6-O
M;F9I9R!R97!L86-E;65N=#H@)&%;=&]=(BD[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H)&%;)W1Y<&4G72`]/2`G<&%C:V%G92UI
M;F9O)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1T(#T@)'1H
M:7,M/G!K9VEN9F\M/G!A8VMA9V5);F9O*"1A6R=T;R==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T;R`]("1T.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@(FEN=F%L
M:60@<&%C:V%G92UI;F9O(')E<&QA8V5M96YT.B`D85MT;UTB*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"%I<U]N=6QL*"1T;RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1S=6)S=%]F<F]M6UT@/2`D85LG9G)O;2==.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)'-U8G-T7W1O6UT@/2`D=&\[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/FQO9R@S+"`B9&]I;F<@(BYS:7IE;V8H)'-U8G-T7V9R;VTI+B(@<W5B
M<W1I='5T:6]N*',I(&9O<B`D9FEN86Q?9&5S=%]F:6QE(BD[#0H@("`@("`@
M("`@("`@("`@:68@*'-I>F5O9B@D<W5B<W1?9G)O;2DI('L-"B`@("`@("`@
M("`@("`@("`@("`@)&-O;G1E;G1S(#T@<W1R7W)E<&QA8V4H)'-U8G-T7V9R
M;VTL("1S=6)S=%]T;RP@)&-O;G1E;G1S*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)'=P(#T@0&9O<&5N*"1D97-T7V9I;&4L(")W
M8B(I.PT*("`@("`@("`@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)'=P*2D@
M>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(F9A:6QE9"!T;R!C<F5A=&4@)&1E<W1?9FEL93H@)'!H<%]E<G)O<FUS
M9R(L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!014%27TE.4U1!3$Q%4E]&04E,140I.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!I9B`H9G=R:71E*"1W<"P@)&-O;G1E;G1S
M*2`]/3T@9F%L<V4I('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*")F86EL960@=W)I=&EN9R!T;R`D9&5S=%]F:6QE
M.B`D<&AP7V5R<F]R;7-G(BP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%!%05)?24Y35$%,3$527T9!24Q%1"D[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&9C;&]S92@D=W`I
M.PT*("`@("`@("`@("`@("`@("\O('U]?0T*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@+R\@>WM[(&-H96-K('1H92!M9#4-"B`@("`@("`@("`@(&EF
M("AI<W-E="@D;60U<W5M*2D@>PT*("`@("`@("`@("`@("`@(&EF("AS=')T
M;VQO=V5R*"1M9#5S=6TI(#T]('-T<G1O;&]W97(H)&%T='-;)VUD-7-U;2==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#(L(")M9#5S
M=6T@;VLZ("1F:6YA;%]D97-T7V9I;&4B*3L-"B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H96UP='DH)&]P=&EO
M;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`O+R!D
M96QE=&4@=&AE(&9I;&4-"B`@("`@("`@("`@("`@("`@("`@("`@($!U;FQI
M;FLH)&1E<W1?9FEL92D[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1O<'1I;VYS6R=I9VYO<F4M97)R;W)S)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*")B860@;60U<W5M(&9O<B!F:6QE("1F:6YA;%]D97-T7V9I;&4B+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%!%05)?24Y35$%,3$527T9!24Q%1"D[#0H@("`@("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`B=V%R;FEN9R`Z(&)A
M9"!M9#5S=6T@9F]R(&9I;&4@)&9I;F%L7V1E<W1?9FEL92(I.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L
M(")W87)N:6YG(#H@8F%D(&UD-7-U;2!F;W(@9FEL92`D9FEN86Q?9&5S=%]F
M:6QE(BD[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`O+R!]?7T-"B`@("`@("`@("`@("\O('M[>R!S970@
M9FEL92!P97)M:7-S:6]N<PT*("`@("`@("`@("`@:68@*"%/4U]724Y$3U=3
M*2![#0H@("`@("`@("`@("`@("`@:68@*"1A='1S6R=R;VQE)UT@/3T@)W-C
M<FEP="<I('L-"B`@("`@("`@("`@("`@("`@("`@)&UO9&4@/2`P-S<W("8@
M?BAI;G0I;V-T9&5C*"1T:&ES+3YC;VYF:6<M/F=E="@G=6UA<VLG*2D[#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,RP@(BL@8VAM;V0@*W@@
M)&1E<W1?9FEL92(I.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@("1M;V1E(#T@,#8V-B`F('XH:6YT*6]C=&1E8R@D
M=&AI<RT^8V]N9FEG+3YG970H)W5M87-K)RDI.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`D=&AI<RT^861D1FEL94]P97)A=&EO;B@B
M8VAM;V0B+"!A<G)A>2@D;6]D92P@)&1E<W1?9FEL92DI.PT*("`@("`@("`@
M("`@("`@(&EF("@A0&-H;6]D*"1D97-T7V9I;&4L("1M;V1E*2D@>PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L(")F
M86EL960@=&\@8VAA;F=E(&UO9&4@;V8@)&1E<W1?9FEL92(I.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@+R\@?7U]#0H@("`@("`@("`@("`D=&AI<RT^
M861D1FEL94]P97)A=&EO;B@B<F5N86UE(BP@87)R87DH)&1E<W1?9FEL92P@
M)&9I;F%L7V1E<W1?9FEL92P-"B`@("`@("`@("`@("`@("`D871T<ULG<F]L
M92==(#T]("=E>'0G*2D[#0H@("`@("`@('T-"B`@("`@("`@+R\@4W1O<F4@
M=&AE(&9U;&P@<&%T:"!W:&5R92!T:&4@9FEL92!W87,@:6YS=&%L;&5D(&9O
M<B!E87-Y('5N:7-T86QL#0H@("`@("`@("1T:&ES+3YA9&1&:6QE3W!E<F%T
M:6]N*")I;G-T86QL961?87,B+"!A<G)A>2@D9FEL92P@)&EN<W1A;&QE9%]A
M<RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-A=F5?9&5S
M=&1I<BP@9&ER;F%M92AS=6)S='(H)&EN<W1A;&QE9&%S7V1E<W1?9FEL92P@
M<W1R;&5N*"1S879E7V1E<W1D:7(I*2DI*3L-"@T*("`@("`@("`O+R1T:&ES
M+3YL;V<H,BP@(FEN<W1A;&QE9#H@)&1E<W1?9FEL92(I.PT*("`@("`@("!R
M971U<FX@4$5!4E])3E-404Q,15)?3TL[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[(%]I;G-T86QL1FEL93(H*0T*#0H@("`@+RHJ#0H@("`@
M("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]086-K86=E1FEL
M95]V,@T*("`@("`J($!P87)A;2!S=')I;F<@9FEL96YA;64-"B`@("`@*B!`
M<&%R86T@87)R87D@871T<FEB=71E<R!F<F]M(#QF:6QE/B!T86<@:6X@<&%C
M:V%G92YX;6P-"B`@("`@*B!`<&%R86T@<W1R:6YG('!A=&@@=&\@:6YS=&%L
M;"!T:&4@9FEL92!I;@T*("`@("`J($!P87)A;2!A<G)A>2!O<'1I;VYS(&9R
M;VT@8V]M;6%N9"UL:6YE#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@7VEN<W1A;&Q&:6QE,B@F)'!K9RP@)&9I;&4L
M("1A='1S+"`D=&UP7W!A=&@L("1O<'1I;VYS*0T*("`@('L-"B`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^7W)E9VES=')Y*2D@>PT*("`@("`@("`@("`@
M)'1H:7,M/E]R96=I<W1R>2`]("8D=&AI<RT^8V]N9FEG+3YG971296=I<W1R
M>2@I.PT*("`@("`@("!]#0H-"B`@("`@("`@)&-H86YN96P@/2`D<&MG+3YG
M971#:&%N;F5L*"D[#0H@("`@("`@("\O('M[>R!A<W-E;6)L92!T:&4@9&5S
M=&EN871I;VX@<&%T:',-"B`@("`@("`@:68@*"%I;E]A<G)A>2@D871T<ULG
M871T<FEB<R==6R=R;VQE)UTL#0H@("`@("`@("`@("`@(%!%05)?26YS=&%L
M;&5R7U)O;&4Z.F=E=%9A;&ED4F]L97,H)'!K9RT^9V5T4&%C:V%G951Y<&4H
M*2DI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M)TEN=F%L:60@<F]L92!@)R`N("1A='1S6R=A='1R:6)S)UU;)W)O;&4G72`N
M#0H@("`@("`@("`@("`@("`@("`@("(G(&9O<B!F:6QE("1F:6QE(BD[#0H@
M("`@("`@('T-"B`@("`@("`@)')O;&4@/2`F4$5!4E]);G-T86QL97)?4F]L
M93HZ9F%C=&]R>2@D<&MG+"`D871T<ULG871T<FEB<R==6R=R;VQE)UTL("1T
M:&ES+3YC;VYF:6<I.PT*("`@("`@("`D97)R(#T@)')O;&4M/G-E='5P*"1T
M:&ES+"`D<&MG+"`D871T<ULG871T<FEB<R==+"`D9FEL92D[#0H@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1E<G(I*2![#0H@("`@("`@("`@("!R971U
M<FX@)&5R<CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21R;VQE+3YI<TEN
M<W1A;&QA8FQE*"DI('L-"B`@("`@("`@("`@(')E='5R;CL-"B`@("`@("`@
M?0T*("`@("`@("`D:6YF;R`]("1R;VQE+3YP<F]C97-S26YS=&%L;&%T:6]N
M*"1P:V<L("1A='1S6R=A='1R:6)S)UTL("1F:6QE+"`D=&UP7W!A=&@I.PT*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@
M("`@(')E='5R;B`D:6YF;SL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@(&QI<W0H)'-A=F5?9&5S=&1I<BP@)&1E<W1?9&ER+"`D9&5S=%]F:6QE
M+"`D;W)I9U]F:6QE*2`]("1I;F9O.PT*("`@("`@("!]#0H@("`@("`@("1F
M:6YA;%]D97-T7V9I;&4@/2`D:6YS=&%L;&5D7V%S(#T@)&1E<W1?9FEL93L-
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG<&%C:V%G:6YG
M<F]O="==*2D@>PT*("`@("`@("`@("`@)&9I;F%L7V1E<W1?9FEL92`]("1T
M:&ES+3Y?<')E<&5N9%!A=&@H)&9I;F%L7V1E<W1?9FEL92P-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V]P=&EO;G-;)W!A8VMA9VEN9W)O;W0G72D[#0H@
M("`@("`@('T-"B`@("`@("`@)&1E<W1?9&ER(#T@9&ER;F%M92@D9FEN86Q?
M9&5S=%]F:6QE*3L-"B`@("`@("`@)&1E<W1?9FEL92`]("1D97-T7V1I<B`N
M($1)4D5#5$]265]315!!4D%43U(@+B`G+G1M<"<@+B!B87-E;F%M92@D9FEN
M86Q?9&5S=%]F:6QE*3L-"B`@("`@("`@+R\@?7U]#0H-"B`@("`@("`@:68@
M*&5M<'1Y*"1T:&ES+3Y?;W!T:6]N<ULG<F5G:7-T97(M;VYL>2==*2D@>PT*
M("`@("`@("`@("`@:68@*"%`:7-?9&ER*"1D97-T7V1I<BDI('L-"B`@("`@
M("`@("`@("`@("!I9B`H(21T:&ES+3YM:T1I<DAI97(H)&1E<W1?9&ER*2D@
M>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(F9A:6QE9"!T;R!M:V1I<B`D9&5S=%]D:7(B+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E])3E-404Q,
M15)?1D%)3$5$*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/FQO9R@S+"`B*R!M:V1I<B`D9&5S=%]D:7(B*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D871T<FEB<R`]("1A='1S
M6R=A='1R:6)S)UT[#0H@("`@("`@('5N<V5T*"1A='1S6R=A='1R:6)S)UTI
M.PT*("`@("`@("`O+R!P<F5T='D@;75C:"!N;W1H:6YG(&AA<'!E;G,@:68@
M=V4@87)E(&]N;'D@<F5G:7-T97)I;F<@=&AE(&EN<W1A;&P-"B`@("`@("`@
M:68@*&5M<'1Y*"1T:&ES+3Y?;W!T:6]N<ULG<F5G:7-T97(M;VYL>2==*2D@
M>PT*("`@("`@("`@("`@:68@*"%C;W5N="@D871T<RDI('L@+R\@;F\@=&%S
M:W,-"B`@("`@("`@("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1O<FEG7V9I
M;&4I*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@B9FEL92`D;W)I9U]F:6QE(&1O97,@;F]T(&5X:7-T(BP-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%
M05)?24Y35$%,3$527T9!24Q%1"D[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@(&EF("@A0&-O<'DH)&]R:6=?9FEL92P@)&1E<W1?9FEL
M92DI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*")F86EL960@=&\@=W)I=&4@)&1E<W1?9FEL92(L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!014%27TE.
M4U1!3$Q%4E]&04E,140I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^;&]G*#,L("(K(&-P("1O<FEG7V9I;&4@)&1E<W1?
M9FEL92(I.PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D871T<FEB<ULG
M;60U<W5M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1M9#5S=6T@/2!M
M9#5?9FEL92@D9&5S=%]F:6QE*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!](&5L<V4@>R`O+R!F:6QE('=I=&@@=&%S:W,-"B`@("`@("`@
M("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1O<FEG7V9I;&4I*2![#0H@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B9FEL
M92`D;W)I9U]F:6QE(&1O97,@;F]T(&5X:7-T(BP-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?24Y35$%,3$52
M7T9!24Q%1"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L-
M"B`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G1S(#T@9FEL95]G971?8V]N
M=&5N=',H)&]R:6=?9FEL92D[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@)&9P(#T@9F]P96XH)&]R:6=?9FEL92P@
M(G(B*3L-"B`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G1S(#T@0&9R96%D
M*"1F<"P@9FEL97-I>F4H)&]R:6=?9FEL92DI.R`O+R!F:6QE<VEZ92!C86X@
M8F4@,`T*("`@("`@("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1C;VYT96YT<R`]
M/3T@9F%L<V4I('L-"B`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G1S(#T@
M)R<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D871T<FEB<ULG;60U<W5M)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("1M9#5S=6T@/2!M9#4H)&-O;G1E;G1S*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&%T=',@87,@)'1A9R`]
M/B`D<F%W*2![#0H@("`@("`@("`@("`@("`@("`@("1T86<@/2!S=')?<F5P
M;&%C92@D<&MG+3YG971487-K<TYS*"D@+B`G.B<L("<G+"`D=&%G*3L-"B`@
M("`@("`@("`@("`@("`@("`@)'1A<VL@/2`B4$5!4E]487-K7R1T86<B.PT*
M("`@("`@("`@("`@("`@("`@("`D=&%S:R`]("9N97<@)'1A<VLH)'1H:7,M
M/F-O;F9I9RP@)'1H:7,L(%!%05)?5$%32U])3E-404Q,*3L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"$D=&%S:RT^:7-38W)I<'0H*2D@>R`O+R!S8W)I
M<'1S(&%R92!O;FQY(&AA;F1L960@869T97(@:6YS=&%L;&%T:6]N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D=&%S:RT^:6YI="@D<F%W+"`D871T<FEB
M<RP@)'!K9RT^9V5T3&%S=$EN<W1A;&QE9%9E<G-I;VXH*2D[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D<F5S(#T@)'1A<VLM/G-T87)T4V5S<VEO;B@D
M<&MG+"`D8V]N=&5N=',L("1F:6YA;%]D97-T7V9I;&4I.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"1R97,@/3T](&9A;'-E*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[("\O('-K:7`@=&AI<R!F
M:6QE#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)&-O
M;G1E;G1S(#T@)')E<SL@+R\@<V%V92!C:&%N9V5S#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)'=P(#T@0&9O<&5N*"1D
M97-T7V9I;&4L(")W8B(I.PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES
M7W)E<V]U<F-E*"1W<"DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B9F%I;&5D('1O(&-R96%T92`D9&5S
M=%]F:6QE.B`D<&AP7V5R<F]R;7-G(BP-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!014%27TE.4U1!3$Q%4E]&
M04E,140I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@(&EF("AF=W)I=&4H)'=P+"`D8V]N=&5N=',I(#T]/2!F86QS92D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*")F86EL960@=W)I=&EN9R!T;R`D9&5S=%]F:6QE.B`D<&AP7V5R
M<F]R;7-G(BP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!014%27TE.4U1!3$Q%4E]&04E,140I.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&9C;&]S92@D
M=W`I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("\O('M[>R!C:&5C:R!T:&4@;60U#0H@("`@("`@("`@("!I9B`H
M:7-S970H)&UD-7-U;2DI('L-"B`@("`@("`@("`@("`@("!I9B`H<W1R=&]L
M;W=E<B@D;60U<W5M*2`]/2!S=')T;VQO=V5R*"1A='1R:6)S6R=M9#5S=6TG
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@R+"`B;60U
M<W5M(&]K.B`D9FEN86Q?9&5S=%]F:6QE(BD[#0H@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1O<'1I
M;VYS6R=F;W)C92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M9&5L971E('1H92!F:6QE#0H@("`@("`@("`@("`@("`@("`@("`@("!`=6YL
M:6YK*"1D97-T7V9I;&4I.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D;W!T:6]N<ULG:6=N;W)E+65R<F]R<R==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B8F%D(&UD-7-U;2!F;W(@9FEL92`D9FEN86Q?9&5S=%]F:6QE(BP-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@4$5!4E])3E-404Q,15)?1D%)3$5$*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L(")W87)N:6YG
M(#H@8F%D(&UD-7-U;2!F;W(@9FEL92`D9FEN86Q?9&5S=%]F:6QE(BD[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F
M="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL
M;V<H,"P@(G=A<FYI;F<@.B!B860@;60U<W5M(&9O<B!F:6QE("1F:6YA;%]D
M97-T7V9I;&4B*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("\O('U]?0T*("`@("`@("`@("`@+R\@>WM[
M('-E="!F:6QE('!E<FUI<W-I;VYS#0H@("`@("`@("`@("!I9B`H(4]37U=)
M3D1/5U,I('L-"B`@("`@("`@("`@("`@("!I9B`H)')O;&4M/FES17AE8W5T
M86)L92@I*2![#0H@("`@("`@("`@("`@("`@("`@("1M;V1E(#T@,#<W-R`F
M('XH:6YT*6]C=&1E8R@D=&AI<RT^8V]N9FEG+3YG970H)W5M87-K)RDI.PT*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#,L("(K(&-H;6]D("MX
M("1D97-T7V9I;&4B*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`D;6]D92`](#`V-C8@)B!^*&EN="EO8W1D96,H
M)'1H:7,M/F-O;F9I9RT^9V5T*"=U;6%S:R<I*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@)'1H:7,M/F%D9$9I;&5/<&5R871I;VXH
M(F-H;6]D(BP@87)R87DH)&UO9&4L("1D97-T7V9I;&4I*3L-"B`@("`@("`@
M("`@("`@("!I9B`H(4!C:&UO9"@D9&5S=%]F:6QE+"`D;6]D92DI('L-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`B
M9F%I;&5D('1O(&-H86YG92!M;V1E(&]F("1D97-T7V9I;&4B*3L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("\O('U]?0T*("`@("`@("`@("`@)'1H:7,M
M/F%D9$9I;&5/<&5R871I;VXH(G)E;F%M92(L(&%R<F%Y*"1D97-T7V9I;&4L
M("1F:6YA;%]D97-T7V9I;&4L("1R;VQE+3YI<T5X=&5N<VEO;B@I*2D[#0H@
M("`@("`@('T-"B`@("`@("`@+R\@4W1O<F4@=&AE(&9U;&P@<&%T:"!W:&5R
M92!T:&4@9FEL92!W87,@:6YS=&%L;&5D(&9O<B!E87-Y('5N:6YS=&%L;`T*
M("`@("`@("`D=&AI<RT^861D1FEL94]P97)A=&EO;B@B:6YS=&%L;&5D7V%S
M(BP@87)R87DH)&9I;&4L("1I;G-T86QL961?87,L#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'-A=F5?9&5S=&1I<BP@9&ER;F%M92AS=6)S='(H
M)&1E<W1?9FEL92P@<W1R;&5N*"1S879E7V1E<W1D:7(I*2DI*3L-"@T*("`@
M("`@("`O+R1T:&ES+3YL;V<H,BP@(FEN<W1A;&QE9#H@)&1E<W1?9FEL92(I
M.PT*("`@("`@("!R971U<FX@4$5!4E])3E-404Q,15)?3TL[#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&%D9$9I;&5/<&5R871I;VXH*0T*
M#0H@("`@+RHJ#0H@("`@("H@061D(&$@9FEL92!O<&5R871I;VX@=&\@=&AE
M(&-U<G)E;G0@9FEL92!T<F%N<V%C=&EO;BX-"B`@("`@*@T*("`@("`J($!S
M964@<W1A<G1&:6QE5')A;G-A8W1I;VXH*0T*("`@("`J($!P87)A;2!S=')I
M;F<@)'1Y<&4@5&AI<R!C86X@8F4@;VYE(&]F.@T*("`@("`J("`@("T@<F5N
M86UE.B`@<F5N86UE(&$@9FEL92`H)&1A=&$@:&%S(#,@=F%L=65S*0T*("`@
M("`J("`@("T@8F%C:W5P.B`@8F%C:W5P(&%N(&5X:7-T:6YG(&9I;&4@*"1D
M871A(&AA<R`Q('9A;'5E*0T*("`@("`J("`@("T@<F5M;W9E8F%C:W5P.B`@
M8VQE86X@=7`@8F%C:W5P<R!C<F5A=&5D(&1U<FEN9R!I;G-T86QL("@D9&%T
M82!H87,@,2!V86QU92D-"B`@("`@*B`@("`M(&-H;6]D.B`@(&-H86YG92!P
M97)M:7-S:6]N<R!O;B!A(&9I;&4@*"1D871A(&AA<R`R('9A;'5E<RD-"B`@
M("`@*B`@("`M(&1E;&5T93H@(&1E;&5T92!A(&9I;&4@*"1D871A(&AA<R`Q
M('9A;'5E*0T*("`@("`J("`@("T@<FUD:7(Z("`@9&5L971E(&$@9&ER96-T
M;W)Y(&EF(&5M<'1Y("@D9&%T82!H87,@,2!V86QU92D-"B`@("`@*B`@("`M
M(&EN<W1A;&QE9%]A<SH@;6%R:R!A(&9I;&4@87,@:6YS=&%L;&5D("@D9&%T
M82!H87,@-"!V86QU97,I+@T*("`@("`J($!P87)A;2!A<G)A>2`D9&%T82!&
M;W(@86QL(&9I;&4@;W!E<F%T:6]N<RP@=&AI<R!A<G)A>2!M=7-T(&-O;G1A
M:6X@=&AE#0H@("`@("H@("`@9G5L;"!P871H('1O('1H92!F:6QE(&]R(&1I
M<F5C=&]R>2!T:&%T(&ES(&)E:6YG(&]P97)A=&5D(&]N+B`@1F]R#0H@("`@
M("H@("`@=&AE(')E;F%M92!C;VUM86YD+"!T:&4@9FER<W0@<&%R86UE=&5R
M(&UU<W0@8F4@=&AE(&9I;&4@=&\@<F5N86UE+`T*("`@("`J("`@('1H92!S
M96-O;F0@:71S(&YE=R!N86UE+"!T:&4@=&AI<F0@=VAE=&AE<B!T:&ES(&ES
M(&$@4$A0(&5X=&5N<VEO;BX-"B`@("`@*@T*("`@("`J("`@(%1H92!I;G-T
M86QL961?87,@;W!E<F%T:6]N(&-O;G1A:6YS(#0@96QE;65N=',@:6X@=&AI
M<R!O<F1E<CH-"B`@("`@*B`@("`Q+B!&:6QE;F%M92!A<R!L:7-T960@:6X@
M=&AE(&9I;&5L:7-T(&5L96UE;G0@9G)O;2!P86-K86=E+GAM;`T*("`@("`J
M("`@(#(N($9U;&P@<&%T:"!T;R!T:&4@:6YS=&%L;&5D(&9I;&4-"B`@("`@
M*B`@("`S+B!&=6QL('!A=&@@9G)O;2!T:&4@<&AP7V1I<B!C;VYF:6=U<F%T
M:6]N('9A<FEA8FQE('5S960@:6X@=&AI<PT*("`@("`J("`@("`@(&EN<W1A
M;&QA=&EO;@T*("`@("`J("`@(#0N(%)E;&%T:79E('!A=&@@9G)O;2!T:&4@
M<&AP7V1I<B!T:&%T('1H:7,@9FEL92!I<R!I;G-T86QL960@:6X-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!A9&1&:6QE3W!E<F%T:6]N*"1T>7!E+"`D9&%T
M82D-"B`@("![#0H@("`@("`@(&EF("@A:7-?87)R87DH)&1A=&$I*2![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)TEN=&5R;F%L
M($5R<F]R.B`D9&%T82!I;B!A9&1&:6QE3W!E<F%T:6]N)PT*("`@("`@("`@
M("`@("`@("X@)R!M=7-T(&)E(&%N(&%R<F%Y+"!W87,@)R`N(&=E='1Y<&4H
M)&1A=&$I*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1Y<&4@/3T@)V-H
M;6]D)RD@>PT*("`@("`@("`@("`@)&]C=&UO9&4@/2!D96-O8W0H)&1A=&%;
M,%TI.PT*("`@("`@("`@("`@)'1H:7,M/FQO9R@S+"`B861D:6YG('1O('1R
M86YS86-T:6]N.B`D='EP92`D;V-T;6]D92`D9&%T85LQ72(I.PT*("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M/FQO9R@S+"`B861D:6YG
M('1O('1R86YS86-T:6]N.B`D='EP92`B("X@:6UP;&]D92@B("(L("1D871A
M*2D[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/F9I;&5?;W!E<F%T:6]N
M<UM=(#T@87)R87DH)'1Y<&4L("1D871A*3L-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@<W1A<G1&:6QE5')A;G-A8W1I;VXH*0T*#0H@("`@
M9G5N8W1I;VX@<W1A<G1&:6QE5')A;G-A8W1I;VXH)')O;&QB86-K7VEN7V-A
M<V4@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("AC;W5N="@D=&AI<RT^
M9FEL95]O<&5R871I;VYS*2`F)B`D<F]L;&)A8VM?:6Y?8V%S92D@>PT*("`@
M("`@("`@("`@)'1H:7,M/G)O;&QB86-K1FEL951R86YS86-T:6]N*"D[#0H@
M("`@("`@('T-"B`@("`@("`@)'1H:7,M/F9I;&5?;W!E<F%T:6]N<R`](&%R
M<F%Y*"D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&-O;6UI
M=$9I;&54<F%N<V%C=&EO;B@I#0H-"B`@("!F=6YC=&EO;B!C;VUM:71&:6QE
M5')A;G-A8W1I;VXH*0T*("`@('L-"B`@("`@("`@)&X@/2!C;W5N="@D=&AI
M<RT^9FEL95]O<&5R871I;VYS*3L-"B`@("`@("`@)'1H:7,M/FQO9R@R+"`B
M86)O=70@=&\@8V]M;6ET("1N(&9I;&4@;W!E<F%T:6]N<R(I.PT*("`@("`@
M("`O+R![>WL@9FER<W0L(&-H96-K('!E<FUI<W-I;VYS(&%N9"!S=6-H(&UA
M;G5A;&QY#0H@("`@("`@("1E<G)O<G,@/2!A<G)A>2@I.PT*("`@("`@("!F
M;W)E86-H("@D=&AI<RT^9FEL95]O<&5R871I;VYS(&%S("1T<BD@>PT*("`@
M("`@("`@("`@;&ES="@D='EP92P@)&1A=&$I(#T@)'1R.PT*("`@("`@("`@
M("`@<W=I=&-H("@D='EP92D@>PT*("`@("`@("`@("`@("`@(&-A<V4@)W)E
M;F%M92<Z#0H@("`@("`@("`@("`@("`@("`@(&EF("@A9FEL95]E>&ES=',H
M)&1A=&%;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D97)R;W)S
M6UT@/2`B8V%N;F]T(')E;F%M92!F:6QE("1D871A6S!=+"!D;V5S;B=T(&5X
M:7-T(CL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`O+R!C:&5C:R!T:&%T(&1E<W0@9&ER+B!I<R!W<FET86)L90T*("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES7W=R:71A8FQE*&1I<FYA;64H)&1A
M=&%;,5TI*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&5R<F]R<UM=
M(#T@(G!E<FUI<W-I;VX@9&5N:65D("@D='EP92DZ("1D871A6S%=(CL-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@("`@("!C87-E("=C:&UO9"<Z#0H@("`@("`@("`@
M("`@("`@("`@("\O(&-H96-K('1H870@9FEL92!I<R!W<FET86)L90T*("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES7W=R:71A8FQE*"1D871A6S%=*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&5R<F]R<UM=(#T@(G!E<FUI
M<W-I;VX@9&5N:65D("@D='EP92DZ("1D871A6S%=("(@+B!D96-O8W0H)&1A
M=&%;,%TI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@(&-A<V4@)V1E;&5T92<Z
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@A9FEL95]E>&ES=',H)&1A=&%;
M,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#(L
M(")W87)N:6YG.B!F:6QE("1D871A6S!=(&1O97-N)W0@97AI<W0L(&-A;B=T
M(&)E(&1E;&5T960B*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`O+R!C:&5C:R!T:&%T(&1I<F5C=&]R>2!I<R!W<FET
M86)L90T*("`@("`@("`@("`@("`@("`@("!I9B`H9FEL95]E>&ES=',H)&1A
M=&%;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7W=R
M:71A8FQE*&1I<FYA;64H)&1A=&%;,%TI*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1E<G)O<G-;72`](")P97)M:7-S:6]N(&1E;FEE9"`H
M)'1Y<&4I.B`D9&%T85LP72([#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(&UA:V4@
M<W5R92!T:&4@9FEL92!T;R!B92!D96QE=&5D(&-A;B!B92!O<&5N960@9F]R
M('=R:71I;F<-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9G`@/2!F
M86QS93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7V1I
M<B@D9&%T85LP72D@)B8@(2@D9G`@/2!`9F]P96XH)&1A=&%;,%TL("=A)RDI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E<G)O<G-;
M72`](")P97)M:7-S:6]N(&1E;FEE9"`H)'1Y<&4I.B`D9&%T85LP72([#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1F<"D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@
M?0T*("`@("`@("`O+R!]?7T-"B`@("`@("`@)&T@/2!S:7IE;V8H)&5R<F]R
M<RD[#0H@("`@("`@(&EF("@D;2`^(#`I('L-"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1E<G)O<G,@87,@)&5R<F]R*2![#0H@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/FQO9R@Q+"`D97)R;W(I.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]O<'1I;VYS6R=I9VYO<F4M97)R;W)S)UTI*2![#0H@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@("1T:&ES+3Y?9&ER=')E92`](&%R<F%Y*"D[#0H@
M("`@("`@("\O('M[>R!R96%L;'D@8V]M;6ET('1H92!T<F%N<V%C=&EO;@T*
M("`@("`@("!F;W)E86-H("@D=&AI<RT^9FEL95]O<&5R871I;VYS(&%S("1T
M<BD@>PT*("`@("`@("`@("`@;&ES="@D='EP92P@)&1A=&$I(#T@)'1R.PT*
M("`@("`@("`@("`@<W=I=&-H("@D='EP92D@>PT*("`@("`@("`@("`@("`@
M(&-A<V4@)V)A8VMU<"<Z#0H@("`@("`@("`@("`@("`@("`@($!C;W!Y*"1D
M871A6S!=+"`D9&%T85LP72`N("<N8F%K)RD[#0H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YL;V<H,RP@(BL@8F%C:W5P("1D871A6S!=('1O("1D871A
M6S!=+F)A:R(I.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@("`@("`@("!C87-E("=R96UO=F5B86-K=7`G.@T*("`@("`@("`@("`@
M("`@("`@("!`=6YL:6YK*"1D871A6S!=("X@)RYB86LG*3L-"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/FQO9R@S+"`B*R!R;2!B86-K=7`@;V8@)&1A
M=&%;,%T@*"1D871A6S!=+F)A:RDB*3L-"B`@("`@("`@("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@("`@("`@("`@8V%S92`G<F5N86UE)SH-"B`@("`@
M("`@("`@("`@("`@("`@)'1E<W0@/2!`=6YL:6YK*"1D871A6S%=*3L-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"$D=&5S="`F)B!F:6QE7V5X:7-T<R@D
M9&%T85LQ72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D9&%T
M85LR72D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E>'1R82`]
M("<L('1H:7,@97AT96YS:6]N(&UU<W0@8F4@:6YS=&%L;&5D(&UA;G5A;&QY
M+B`@4F5N86UE('1O("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8F%S96YA;64H)&1A=&%;,5TI("X@)R(G.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D97AT<F$@/2`G)SL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O
M<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/FQO9R@Q+"`G0V]U;&0@;F]T(&1E;&5T92`G("X@)&1A=&%;
M,5T@+B`G+"!C86YN;W0@<F5N86UE("<@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&%T85LP72`N("1E>'1R82D[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG:6=N;W)E+65R<F]R<R==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!`<F5N86UE*"1D871A6S!=+"`D9&%T
M85LQ72D[#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,RP@(BL@
M;78@)&1A=&%;,%T@)&1A=&%;,5TB*3L-"B`@("`@("`@("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@("`@("`@("`@8V%S92`G8VAM;V0G.@T*("`@("`@
M("`@("`@("`@("`@("!`8VAM;V0H)&1A=&%;,5TL("1D871A6S!=*3L-"B`@
M("`@("`@("`@("`@("`@("`@)&]C=&UO9&4@/2!D96-O8W0H)&1A=&%;,%TI
M.PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#,L("(K(&-H;6]D
M("1O8W1M;V1E("1D871A6S%=(BD[#0H@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@("`@(&-A<V4@)V1E;&5T92<Z#0H@("`@("`@
M("`@("`@("`@("`@($!U;FQI;FLH)&1A=&%;,%TI.PT*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^;&]G*#,L("(K(')M("1D871A6S!=(BD[#0H@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@(&-A<V4@
M)W)M9&ER)SH-"B`@("`@("`@("`@("`@("`@("`@0')M9&ER*"1D871A6S!=
M*3L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@S+"`B*R!R;61I
M<B`D9&%T85LP72(I.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@
M("`@("`@("`@("`@("!C87-E("=I;G-T86QL961?87,G.@T*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<&MG:6YF;RT^<V5T26YS=&%L;&5D07,H)&1A
M=&%;,%TL("1D871A6S%=*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7V1I<G1R965;9&ER;F%M92@D9&%T85LQ72E=*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D:7)T<F5E6V1I<FYA
M;64H)&1A=&%;,5TI72`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^<&MG:6YF;RT^<V5T1&ER=')E92AD:7)N86UE*"1D871A6S%=
M*2D[#0H-"B`@("`@("`@("`@("`@("`@("`@("`@('=H:6QE*"%E;7!T>2@D
M9&%T85LS72D@)B8@)&1A=&%;,UT@(3T@)R\G("8F("1D871A6S-=("$]("=<
M7"<-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("8F("1D871A6S-=
M("$]("<N)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YP:V=I;F9O+3YS971$:7)T<F5E*"1P<"`]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<')E<&5N9%!A=&@H)&1A=&%;,UTL
M("1D871A6S)=*2D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]D:7)T<F5E6R1P<%T@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1D871A6S-=(#T@9&ER;F%M92@D9&%T85LS72D[#0H@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@+R\@?7U]#0H@("`@("`@("1T:&ES+3YL;V<H
M,BP@(G-U8V-E<W-F=6QL>2!C;VUM:71T960@)&X@9FEL92!O<&5R871I;VYS
M(BD[#0H@("`@("`@("1T:&ES+3YF:6QE7V]P97)A=&EO;G,@/2!A<G)A>2@I
M.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"B`@("`O+R![>WL@<F]L;&)A8VM&:6QE5')A;G-A8W1I;VXH*0T*#0H@("`@
M9G5N8W1I;VX@<F]L;&)A8VM&:6QE5')A;G-A8W1I;VXH*0T*("`@('L-"B`@
M("`@("`@)&X@/2!C;W5N="@D=&AI<RT^9FEL95]O<&5R871I;VYS*3L-"B`@
M("`@("`@)'1H:7,M/FQO9R@R+"`B<F]L;&EN9R!B86-K("1N(&9I;&4@;W!E
M<F%T:6]N<R(I.PT*("`@("`@("!F;W)E86-H("@D=&AI<RT^9FEL95]O<&5R
M871I;VYS(&%S("1T<BD@>PT*("`@("`@("`@("`@;&ES="@D='EP92P@)&1A
M=&$I(#T@)'1R.PT*("`@("`@("`@("`@<W=I=&-H("@D='EP92D@>PT*("`@
M("`@("`@("`@("`@(&-A<V4@)V)A8VMU<"<Z#0H@("`@("`@("`@("`@("`@
M("`@(&EF("AF:6QE7V5X:7-T<R@D9&%T85LP72`N("<N8F%K)RDI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@($!U;FQI;FLH)&1A=&%;,%TI.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@0&-O<'DH)&1A=&%;,%T@+B`G+F)A:R<L
M("1D871A6S!=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL
M;V<H,RP@(BL@<F5S=&]R92`D9&%T85LP72!F<F]M("1D871A6S!=+F)A:R(I
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PT*("`@("`@("`@("`@("`@(&-A<V4@)W)E;F%M92<Z#0H@("`@
M("`@("`@("`@("`@("`@($!U;FQI;FLH)&1A=&%;,%TI.PT*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^;&]G*#,L("(K(')M("1D871A6S!=(BD[#0H@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@(&-A
M<V4@)VUK9&ER)SH-"B`@("`@("`@("`@("`@("`@("`@0')M9&ER*"1D871A
M6S!=*3L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@S+"`B*R!R
M;61I<B`D9&%T85LP72(I.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@("`@("!C87-E("=C:&UO9"<Z#0H@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@(&-A<V4@)V1E;&5T92<Z
M#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@
M(&-A<V4@)VEN<W1A;&QE9%]A<R<Z#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YP:V=I;F9O+3YS971);G-T86QL961!<R@D9&%T85LP72P@9F%L<V4I
M.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^<&MG:6YF;RT^<F5S971$:7)T
M<F5E*"D[#0H@("`@("`@("1T:&ES+3YF:6QE7V]P97)A=&EO;G,@/2!A<G)A
M>2@I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!M:T1I<DAI
M97(H)&1I<BD-"@T*("`@(&9U;F-T:6]N(&UK1&ER2&EE<B@D9&ER*0T*("`@
M('L-"B`@("`@("`@)'1H:7,M/F%D9$9I;&5/<&5R871I;VXH)VUK9&ER)RP@
M87)R87DH)&1I<BDI.PT*("`@("`@("!R971U<FX@<&%R96YT.CIM:T1I<DAI
M97(H)&1I<BD[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&1O
M=VYL;V%D*"D-"@T*("`@("\J*@T*("`@("`J($1O=VYL;V%D(&%N>2!F:6QE
M<R!A;F0@=&AE:7(@9&5P96YD96YC:65S+"!I9B!N96-E<W-A<GD-"B`@("`@
M*@T*("`@("`J($!P87)A;2!A<G)A>2!A(&UI>&5D(&QI<W0@;V8@<&%C:V%G
M92!N86UE<RP@;&]C86P@9FEL97,L(&]R('!A8VMA9V4N>&UL#0H@("`@("H@
M0'!A<F%M(%!%05)?0V]N9FEG#0H@("`@("H@0'!A<F%M(&%R<F%Y(&]P=&EO
M;G,@9G)O;2!T:&4@8V]M;6%N9"!L:6YE#0H@("`@("H@0'!A<F%M(&%R<F%Y
M('1H:7,@:7,@=&AE(&%R<F%Y('1H870@=VEL;"!B92!P;W!U;&%T960@=VET
M:"!P86-K86=E<R!T;PT*("`@("`J("`@("`@("`@("`@("!I;G-T86QL+B`@
M1F]R;6%T(&]F(&5A8V@@96YT<GDZ#0H@("`@("H-"B`@("`@*B`\8V]D93X-
M"B`@("`@*B!A<G)A>2@G<&MG)R`]/B`G<&%C:V%G95]N86UE)RP@)V9I;&4G
M(#T^("<O<&%T:"]T;R]L;V-A;"]F:6QE)RP-"B`@("`@*B`@("`G:6YF;R<@
M/3X@87)R87DH*2`O+R!P87)S960@<&%C:V%G92YX;6P-"B`@("`@*B`I.PT*
M("`@("`J(#PO8V]D93X-"B`@("`@*B!`<&%R86T@87)R87D@=&AI<R!W:6QL
M(&)E('!O<'5L871E9"!W:71H(&%N>2!E<G)O<B!M97-S86=E<PT*("`@("`J
M($!P87)A;2!F86QS92!P<FEV871E(')E8W5R<VEO;B!V87)I86)L90T*("`@
M("`J($!P87)A;2!F86QS92!P<FEV871E(')E8W5R<VEO;B!V87)I86)L90T*
M("`@("`J($!P87)A;2!F86QS92!P<FEV871E(')E8W5R<VEO;B!V87)I86)L
M90T*("`@("`J($!D97!R96-A=&5D(&EN(&9A=F]R(&]F(%!%05)?1&]W;FQO
M861E<@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&1O=VYL;V%D*"1P86-K86=E
M<RP@)&]P=&EO;G,L("8D8V]N9FEG+"`F)&EN<W1A;&QP86-K86=E<RP-"B`@
M("`@("`@("`@("`@("`@("`@("`F)&5R<F]R<RP@)&EN<W1A;&QE9"`](&9A
M;'-E+"`D=VEL;&EN<W1A;&P@/2!F86QS92P@)'-T871E(#T@9F%L<V4I#0H@
M("`@>PT*("`@("`@("`O+R!T<FEC:VEN97-S.B!I;FET:6%L:7IE(&AE<F4-
M"B`@("`@("`@<&%R96YT.CI014%27T1O=VYL;V%D97(H)'1H:7,M/G5I+"`D
M;W!T:6]N<RP@)&-O;F9I9RD[#0H@("`@("`@("1R970@/2!P87)E;G0Z.F1O
M=VYL;V%D*"1P86-K86=E<RD[#0H@("`@("`@("1E<G)O<G,@/2`D=&AI<RT^
M9V5T17)R;W)-<V=S*"D[#0H@("`@("`@("1I;G-T86QL<&%C:V%G97,@/2`D
M=&AI<RT^9V5T1&]W;FQO861E9%!A8VMA9V5S*"D[#0H@("`@("`@('1R:6=G
M97)?97)R;W(H(E!%05(@5V%R;FEN9SH@4$5!4E]);G-T86QL97(Z.F1O=VYL
M;V%D*"D@:7,@9&5P<F5C871E9"`B("X-"B`@("`@("`@("`@("`@("`@("`@
M("`B:6X@9F%V;W(@;V8@4$5!4E]$;W=N;&]A9&5R(&-L87-S(BP@15]54T52
M7U=!4DY)3D<I.PT*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@7W!A<G-E4&%C:V%G95AM;"@I#0H-"B`@
M("!F=6YC=&EO;B!?<&%R<V5086-K86=E6&UL*"8D9&5S8V9I;&4L("8D=&UP
M9&ER*0T*("`@('L-"B`@("`@("`@:68@*'-U8G-T<B@D9&5S8V9I;&4L("TT
M*2`]/2`G+GAM;"<I('L-"B`@("`@("`@("`@("1T;7!D:7(@/2!F86QS93L-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("\O('M[>R!$96-O;7!R
M97-S('!A8VL@:6X@=&UP(&1I<B`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM#0H-"B`@("`@("`@("`@("\O(%1O(&%L;&]W(')E;&%T
M:79E('!A8VMA9V4@9FEL92!N86UE<PT*("`@("`@("`@("`@)&1E<V-F:6QE
M(#T@<F5A;'!A=&@H)&1E<V-F:6QE*3L-"@T*("`@("`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)'1M<&1I<B`](%-Y<W1E;3HZ;6MT96UP*"<M9"<I*2D@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&UP9&ER.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@)'1H:7,M/FQO9R@S+"`G*R!T;7`@9&ER(&-R
M96%T960@870@)R`N("1T;7!D:7(I.PT*("`@("`@("`@("`@+R\@?7U]#0H@
M("`@("`@('T-"B`@("`@("`@+R\@4&%R<V4@>&UL(&9I;&4@+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T-"B`@("`@
M("`@)'!K9R`](&YE=R!014%27U!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<L
M("1T:&ES+3YD96)U9RP@)'1M<&1I<BD[#0H@("`@("`@(%!%05(Z.G-T871I
M8U!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@
M("`@)'`@/2`F)'!K9RT^9G)O;4%N>49I;&4H)&1E<V-F:6QE+"!014%27U9!
M3$E$051%7TE.4U1!3$Q)3D<I.PT*("`@("`@("!014%2.CIS=&%T:6-0;W!%
M<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1P
M*2D@>PT*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1P+3YG9715<V5R26YF
M;R@I*2D@>PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1P+3YG9715<V5R
M26YF;R@I(&%S("1E<G(I('L-"B`@("`@("`@("`@("`@("`@("`@)&QO9VQE
M=F5L(#T@)&5R<ELG;&5V96PG72`]/2`G97)R;W(G(#\@,"`Z(#$[#0H@("`@
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=S
M;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G
M*"1L;V=L979E;"P@=6-F:7)S="@D97)R6R=L979E;"==*2`N("<Z("<@+B`D
M97)R6R=M97-S86=E)UTI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*"=);G-T86QL871I;VX@9F%I;&5D.B!I
M;G9A;&ED('!A8VMA9V4@9FEL92<I.PT*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@)&1E<V-F:6QE(#T@)'`M/F=E=%!A8VMA9V5&:6QE*"D[#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N("1P.PT*("`@('T-"@T*("`@("\O
M('U]?0T*("`@("\J*@T*("`@("`J(%-E="!T:&4@;&ES="!O9B!014%27T1O
M=VYL;V%D97)?4&%C:V%G92!O8FIE8W1S('1O(&%L;&]W(&UO<F4@<V%N90T*
M("`@("`J(&1E<&5N9&5N8WD@=F%L:61A=&EO;@T*("`@("`J($!P87)A;2!A
M<G)A>0T*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=$1O=VYL;V%D961086-K
M86=E<R@F)'!K9W,I#0H@("`@>PT*("`@("`@("!014%2.CIP=7-H17)R;W)(
M86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("1E<G(@/2`D
M=&AI<RT^86YA;'EZ941E<&5N9&5N8VEE<R@D<&MG<RD[#0H@("`@("`@(%!%
M05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)&5R<BDI('L-"B`@("`@("`@("`@(')E='5R;B`D97)R.PT*("`@
M("`@("!]#0H@("`@("`@("1T:&ES+3Y?9&]W;FQO861E9%!A8VMA9V5S(#T@
M)B1P:V=S.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%-E="!T:&4@;&ES
M="!O9B!014%27T1O=VYL;V%D97)?4&%C:V%G92!O8FIE8W1S('1O(&%L;&]W
M(&UO<F4@<V%N90T*("`@("`J(&1E<&5N9&5N8WD@=F%L:61A=&EO;@T*("`@
M("`J($!P87)A;2!A<G)A>0T*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=%5N
M:6YS=&%L;%!A8VMA9V5S*"8D<&MG<RD-"B`@("![#0H@("`@("`@("1T:&ES
M+3Y?9&]W;FQO861E9%!A8VMA9V5S(#T@)B1P:V=S.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N(&=E=$EN<W1A;&Q086-K86=E<R@I#0H@("`@>PT*("`@("`@
M("!R971U<FX@)'1H:7,M/E]D;W=N;&]A9&5D4&%C:V%G97,[#0H@("`@?0T*
M#0H@("`@+R\@>WM[(&EN<W1A;&PH*0T*#0H@("`@+RHJ#0H@("`@("H@26YS
M=&%L;',@=&AE(&9I;&5S('=I=&AI;B!T:&4@<&%C:V%G92!F:6QE('-P96-I
M9FEE9"X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F=\4$5!4E]$;W=N
M;&]A9&5R7U!A8VMA9V4@)'!K9V9I;&4@<&%T:"!T;R!T:&4@<&%C:V%G92!F
M:6QE+`T*("`@("`J("`@("`@("!O<B!A('!R92UI;FET:6%L:7IE9"!P86-K
M86=E9FEL92!O8FIE8W0-"B`@("`@*B!`<&%R86T@87)R87D@)&]P=&EO;G,-
M"B`@("`@*B!R96-O9VYI>F5D(&]P=&EO;G,Z#0H@("`@("H@+2!I;G-T86QL
M<F]O="`@(#H@;W!T:6]N86P@<')E9FEX(&1I<F5C=&]R>2!F;W(@:6YS=&%L
M;&%T:6]N#0H@("`@("H@+2!F;W)C92`@("`@("`@(#H@9F]R8V4@:6YS=&%L
M;&%T:6]N#0H@("`@("H@+2!R96=I<W1E<BUO;FQY(#H@=7!D871E(')E9VES
M=')Y(&)U="!D;VXG="!I;G-T86QL(&9I;&5S#0H@("`@("H@+2!U<&=R861E
M("`@("`@(#H@=7!G<F%D92!E>&ES=&EN9R!I;G-T86QL#0H@("`@("H@+2!S
M;V9T("`@("`@("`@(#H@9F%I;"!S:6QE;G1L>0T*("`@("`J("T@;F]D97!S
M("`@("`@("`Z(&EG;F]R92!D97!E;F1E;F-Y(&-O;F9L:6-T<R]M:7-S:6YG
M(&1E<&5N9&5N8VEE<PT*("`@("`J("T@86QL9&5P<R`@("`@("`Z(&EN<W1A
M;&P@86QL(&1E<&5N9&5N8VEE<PT*("`@("`J("T@;VYL>7)E<61E<',@("`Z
M(&EN<W1A;&P@;VYL>2!R97%U:7)E9"!D97!E;F1E;F-I97,-"B`@("`@*@T*
M("`@("`J($!R971U<FX@87)R87E\4$5!4E]%<G)O<B!P86-K86=E(&EN9F\@
M:68@<W5C8V5S<V9U;`T*("`@("`J+PT*#0H@("`@9G5N8W1I;VX@:6YS=&%L
M;"@D<&MG9FEL92P@)&]P=&EO;G,@/2!A<G)A>2@I*0T*("`@('L-"B`@("`@
M("`@)'1H:7,M/E]O<'1I;VYS(#T@)&]P=&EO;G,[#0H@("`@("`@("1T:&ES
M+3Y?<F5G:7-T<GD@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-
M"B`@("`@("`@:68@*&ES7V]B:F5C="@D<&MG9FEL92DI('L-"B`@("`@("`@
M("`@("1D;'!K9R`]("8D<&MG9FEL93L-"B`@("`@("`@("`@("1P:V<@/2`D
M<&MG9FEL92T^9V5T4&%C:V%G949I;&4H*3L-"B`@("`@("`@("`@("1P:V=F
M:6QE(#T@)'!K9RT^9V5T07)C:&EV949I;&4H*3L-"B`@("`@("`@("`@("1D
M97-C9FEL92`]("1P:V<M/F=E=%!A8VMA9V5&:6QE*"D[#0H@("`@("`@("`@
M("`D=&UP9&ER(#T@9&ER;F%M92@D9&5S8V9I;&4I.PT*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@)&1E<V-F:6QE(#T@)'!K9V9I;&4[#0H@("`@
M("`@("`@("`D=&UP9&ER(#T@)R<[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D<&MG(#T@)B1T:&ES+3Y?<&%R<V5086-K86=E6&UL*"1D97-C
M9FEL92P@)'1M<&1I<BDI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1P
M:V<[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H
M<F5A;'!A=&@H)&1E<V-F:6QE*2`A/2!R96%L<&%T:"@D<&MG9FEL92DI('L-
M"B`@("`@("`@("`@("1T87(@/2!N97<@07)C:&EV95]487(H)'!K9V9I;&4I
M.PT*("`@("`@("`@("`@:68@*"%`)'1A<BT^97AT<F%C="@D=&UP9&ER*2D@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B
M=6YA8FQE('1O('5N<&%C:R`D<&MG9FEL92(I.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H-"B`@("`@("`@)'!K9VYA;64@/2`D<&MG+3YG971.86UE
M*"D[#0H@("`@("`@("1C:&%N;F5L(#T@)'!K9RT^9V5T0VAA;FYE;"@I.PT*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]O<'1I;VYS6R=P86-K86=I;F=R
M;V]T)UTI*2![#0H@("`@("`@("`@("`D<&%C:W)O;W1P:'!?9&ER(#T@)'1H
M:7,M/E]P<F5P96YD4&%T:"@-"B`@("`@("`@("`@("`@("`D=&AI<RT^8V]N
M9FEG+3YG970H)W!H<%]D:7(G+"!N=6QL+"`D8VAA;FYE;"DL#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]O<'1I;VYS6R=P86-K86=I;F=R;V]T)UTI.PT*
M("`@("`@("!]#0H-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=I;G-T
M86QL<F]O="==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T
M26YS=&%L;%)O;W0H)&]P=&EO;G-;)VEN<W1A;&QR;V]T)UTI.PT*("`@("`@
M("`@("`@)'1H:7,M/E]R96=I<W1R>2`]("8D=&AI<RT^8V]N9FEG+3YG9712
M96=I<W1R>2@I.PT*("`@("`@("`@("`@)&EN<W1A;&QR96=I<W1R>2`]("8D
M=&AI<RT^7W)E9VES=')Y.PT*("`@("`@("`@("`@)'1H:7,M/FEN<W1A;&QR
M;V]T(#T@)R<[("\O(&%L;"!D;VYE(&%U=&]M86=I8V%L;'D@;F]W#0H@("`@
M("`@("`@("`D<&AP7V1I<B`]("1T:&ES+3YC;VYF:6<M/F=E="@G<&AP7V1I
M<B<L(&YU;&PL("1C:&%N;F5L*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1T:&ES+3YC;VYF:6<M/G-E=$EN<W1A;&Q2;V]T*&9A;'-E*3L-
M"B`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GD@/2`F)'1H:7,M/F-O;F9I
M9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7V]P=&EO;G-;)W!A8VMA9VEN9W)O;W0G72DI('L-"B`@("`@("`@("`@
M("`@("`D:6YS=&%L;')E9VES=')Y(#T@)FYE=R!014%27U)E9VES=')Y*"1P
M86-K<F]O='!H<%]D:7(I.PT*("`@("`@("`@("`@("`@("1P:'!?9&ER(#T@
M)'!A8VMR;V]T<&AP7V1I<CL-"B`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@)&EN<W1A;&QR96=I<W1R>2`]("8D=&AI<RT^7W)E9VES
M=')Y.PT*("`@("`@("`@("`@("`@("1P:'!?9&ER(#T@)'1H:7,M/F-O;F9I
M9RT^9V5T*"=P:'!?9&ER)RP@;G5L;"P@)&-H86YN96PI.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@)'1H:7,M/FEN<W1A;&QR;V]T(#T@)R<[#0H@
M("`@("`@('T-"@T*("`@("`@("`O+R![>WL@8VAE8VMS('1O(&1O('=H96X@
M;F]T(&EN(")F;W)C92(@;6]D90T*("`@("`@("!I9B`H96UP='DH)&]P=&EO
M;G-;)V9O<F-E)UTI("8F($!I<U]D:7(H)'1H:7,M/F-O;F9I9RT^9V5T*"=P
M:'!?9&ER)RDI*2![#0H@("`@("`@("`@("`D=&5S='`@/2`D8VAA;FYE;"`]
M/2`G<&5A<BYP:'`N;F5T)R`_("1P:V=N86UE(#H@87)R87DH)&-H86YN96PL
M("1P:V=N86UE*3L-"B`@("`@("`@("`@("1I;G-T9FEL96QI<W0@/2`D<&MG
M+3YG971);G-T86QL871I;VY&:6QE3&ES="AT<G5E*3L-"B`@("`@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1I;G-T9FEL96QI<W0I*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N("1I;G-T9FEL96QI<W0[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`D=&5S="`]("1I;G-T86QL<F5G:7-T<GDM/F-H96-K
M1FEL94UA<"@D:6YS=&9I;&5L:7-T+"`D=&5S='`L("<Q+C$G*3L-"B`@("`@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1T97-T*2D@>PT*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&5S=#L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF("AS:7IE;V8H)'1E<W0I*2![#0H@("`@("`@("`@("`@("`@)'!K
M9W,@/2`D=&AI<RT^9V5T26YS=&%L;%!A8VMA9V5S*"D[#0H@("`@("`@("`@
M("`@("`@)&9O=6YD(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)'!K9W,@87,@)'!A<F%M*2![#0H@("`@("`@("`@("`@("`@("`@(&EF
M("@D<&MG+3YI<U-U8G!A8VMA9V5/9B@D<&%R86TI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D9F]U;F0@/2!T<G5E.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1F;W5N9"D@>PT*
M("`@("`@("`@("`@("`@("`@("`O+R!S=6)P86-K86=E<R!C86X@8V]N9FQI
M8W0@=VET:"!E87)L:65R('9E<G-I;VYS(&]F('!A<F5N="!P86-K86=E<PT*
M("`@("`@("`@("`@("`@("`@("`D<&%R96YT<F5G(#T@)&EN<W1A;&QR96=I
M<W1R>2T^<&%C:V%G94EN9F\H)'!A<F%M+3YG971086-K86=E*"DL(&YU;&PL
M("1P87)A;2T^9V5T0VAA;FYE;"@I*3L-"B`@("`@("`@("`@("`@("`@("`@
M)'1M<"`]("1T97-T.PT*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M=&UP(&%S("1F:6QE(#T^("1I;F9O*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-?87)R87DH)&EN9F\I*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H)&EN9F];,5TI(#T]('-T<G1O
M;&]W97(H)'!A<F%M+3YG971086-K86=E*"DI("8F#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<W1R=&]L;W=E<B@D:6YF;ULP72D@/3T@
M<W1R=&]L;W=E<B@D<&%R86TM/F=E=$-H86YN96PH*2DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)'1E<W1;)&9I;&5=*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)'!A<F5N
M=')E9ULG9FEL96QI<W0G75LD9FEL95TI.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H
M)'!A<F%M+3YG971#:&%N;F5L*"DI("$]("=P96%R+G!H<"YN970G*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H<W1R=&]L;W=E<B@D:6YF;RD@/3T@<W1R=&]L;W=E
M<B@D<&%R86TM/F=E=%!A8VMA9V4H*2DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=6YS970H)'1E<W1;)&9I;&5=*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)'!A<F5N=')E9ULG9FEL
M96QI<W0G75LD9FEL95TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D<&9K(#T@)FYE=R!014%2
M7U!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<I.PT*("`@("`@("`@("`@("`@
M("`@("`D<&%R96YT<&MG(#T@)B1P9FLM/F9R;VU!<G)A>2@D<&%R96YT<F5G
M*3L-"B`@("`@("`@("`@("`@("`@("`@)&EN<W1A;&QR96=I<W1R>2T^=7!D
M871E4&%C:V%G93(H)'!A<F5N='!K9RD[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@(&EF("@D<&%R86TM/F=E=$-H86YN96PH*2`]/2`G
M<&5C;"YP:'`N;F5T)R`F)B!I<W-E="@D;W!T:6]N<ULG=7!G<F%D92==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`D=&UP(#T@)'1E<W0[#0H@("`@("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1T;7`@87,@)&9I;&4@/3X@)&EN9F\I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]S=')I;F<H)&EN
M9F\I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@<&5A<BYP
M:'`N;F5T('!A8VMA9V5S(&%R92!A;'=A>7,@<W1O<F5D(&%S('-T<FEN9W,-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H<W1R=&]L;W=E<B@D
M:6YF;RD@/3T@<W1R=&]L;W=E<B@D<&%R86TM/F=E=%!A8VMA9V4H*2DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@=7!G<F%D:6YG
M(&5X:7-T:6YG('!A8VMA9V4-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=6YS970H)'1E<W1;)&9I;&5=*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@:68@*'-I>F5O9B@D=&5S="DI('L-"B`@("`@("`@("`@("`@
M("`@("`@)&US9R`]("(D8VAA;FYE;"\D<&MG;F%M93H@8V]N9FQI8W1I;F<@
M9FEL97,@9F]U;F0Z7&XB.PT*("`@("`@("`@("`@("`@("`@("`D;&]N9V5S
M="`](&UA>"AA<G)A>5]M87`H(G-T<FQE;B(L(&%R<F%Y7VME>7,H)'1E<W0I
M*2D[#0H@("`@("`@("`@("`@("`@("`@("1F;70@/2`B)21[;&]N9V5S='US
M("@E<RE<;B([#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T97-T
M(&%S("1F:6QE(#T^("1I;F9O*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H(6ES7V%R<F%Y*"1I;F9O*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1I;F9O(#T@87)R87DH)W!E87(N<&AP+FYE="<L("1I;F9O
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1I;F9O(#T@)&EN9F];,%T@+B`G+R<@+B`D:6YF;ULQ73L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1M<V<@+CT@<W!R:6YT9B@D9FUT
M+"`D9FEL92P@)&EN9F\I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)VEG;F]R92UE
M<G)O<G,G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@D;7-G*3L-"B`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^;&]G*#`L(")705).24Y'.B`D;7-G(BD[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@+R\@?7U]#0H-"B`@("`@("`@)'1H:7,M/G-T87)T1FEL951R86YS
M86-T:6]N*"D[#0H-"B`@("`@("`@:68@*&5M<'1Y*"1O<'1I;VYS6R=U<&=R
M861E)UTI("8F(&5M<'1Y*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@
M("`@("`O+R!C:&5C:W,@=&\@9&\@;VYL>2!W:&5N(&EN<W1A;&QI;F<@;F5W
M('!A8VMA9V5S#0H@("`@("`@("`@("!I9B`H)&-H86YN96P@/3T@)W!E8VPN
M<&AP+FYE="<I('L-"B`@("`@("`@("`@("`@("`D=&5S="`]("1I;G-T86QL
M<F5G:7-T<GDM/G!A8VMA9V5%>&ES=',H)'!K9VYA;64L("1C:&%N;F5L*3L-
M"B`@("`@("`@("`@("`@("!I9B`H(21T97-T*2![#0H@("`@("`@("`@("`@
M("`@("`@("1T97-T(#T@)&EN<W1A;&QR96=I<W1R>2T^<&%C:V%G945X:7-T
M<R@D<&MG;F%M92P@)W!E87(N<&AP+FYE="<I.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)'1E
M<W0@/2`D:6YS=&%L;')E9VES=')Y+3YP86-K86=E17AI<W1S*"1P:V=N86UE
M+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M96UP='DH)&]P=&EO;G-;)V9O<F-E)UTI("8F("1T97-T*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"(D8VAA;FYE;"\D
M<&MG;F%M92!I<R!A;')E861Y(&EN<W1A;&QE9"(I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'5S96-H86YN96P@
M/2`D8VAA;FYE;#L-"B`@("`@("`@("`@(&EF("@D8VAA;FYE;"`]/2`G<&5C
M;"YP:'`N;F5T)RD@>PT*("`@("`@("`@("`@("`@("1T97-T(#T@)&EN<W1A
M;&QR96=I<W1R>2T^<&%C:V%G945X:7-T<R@D<&MG;F%M92P@)&-H86YN96PI
M.PT*("`@("`@("`@("`@("`@(&EF("@A)'1E<W0I('L-"B`@("`@("`@("`@
M("`@("`@("`@)'1E<W0@/2`D:6YS=&%L;')E9VES=')Y+3YP86-K86=E17AI
M<W1S*"1P:V=N86UE+"`G<&5A<BYP:'`N;F5T)RD[#0H@("`@("`@("`@("`@
M("`@("`@("1U<V5C:&%N;F5L(#T@)W!E87(N<&AP+FYE="<[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`D=&5S="`]("1I;G-T86QL<F5G:7-T<GDM/G!A8VMA9V5%>&ES=',H
M)'!K9VYA;64L("1C:&%N;F5L*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF("@D=&5S="D@>PT*("`@("`@("`@("`@("`@("1V,2`]("1I;G-T
M86QL<F5G:7-T<GDM/G!A8VMA9V5);F9O*"1P:V=N86UE+"`G=F5R<VEO;B<L
M("1U<V5C:&%N;F5L*3L-"B`@("`@("`@("`@("`@("`D=C(@/2`D<&MG+3YG
M971697)S:6]N*"D[#0H@("`@("`@("`@("`@("`@)&-M<"`]('9E<G-I;VY?
M8V]M<&%R92@B)'8Q(BP@(B1V,B(L("=G="<I.PT*("`@("`@("`@("`@("`@
M(&EF("AE;7!T>2@D;W!T:6]N<ULG9F]R8V4G72D@)B8@(79E<G-I;VY?8V]M
M<&%R92@B)'8R(BP@(B1V,2(L("=G="<I*2![#0H@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B=7!G<F%D92!T;R!A(&YE
M=V5R('9E<G-I;VX@*"1V,B!I<R!N;W0@;F5W97(@=&AA;B`D=C$I(BD[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D
M;W!T:6]N<ULG<F5G:7-T97(M;VYL>2==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`O+R!W:&5N('5P9W)A9&EN9RP@<F5M;W9E(&]L9"!R96QE87-E)W,@
M9FEL97,@9FER<W0Z#0H@("`@("`@("`@("`@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1E<G(@/2`D=&AI<RT^7V1E;&5T95!A8VMA9V5&:6QE<R@D<&MG
M;F%M92P@)'5S96-H86YN96PL#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M('1R=64I*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D;W!T:6]N<ULG:6=N;W)E+65R<F]R<R==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D97)R
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F
M="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^;&]G*#`L("=705).24Y'.B`G("X@)&5R<BT^9V5T365S<V%G92@I*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D8F%C:V5D=7`@/2`D97)R.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@+R\@>WM[($-O<'D@9FEL
M97,@=&\@9&5S="!D:7(@+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM#0H-"B`@("`@("`@+R\@:6YF;R!F<F]M('1H92!P86-K86=E
M(&ET('-E;&8@=V4@=V%N="!T;R!A8V-E<W,@9G)O;2!?:6YS=&%L;$9I;&4-
M"B`@("`@("`@)'1H:7,M/G!K9VEN9F\@/2`F)'!K9SL-"B`@("`@("`@+R\@
M=7-E9"!T;R!D971E<FUI;F4@=VAE=&AE<B!W92!S:&]U;&0@8G5I;&0@86YY
M($,@8V]D90T*("`@("`@("`D=&AI<RT^<V]U<F-E7V9I;&5S(#T@,#L-"@T*
M("`@("`@("`D<V%V96-H86YN96P@/2`D=&AI<RT^8V]N9FEG+3YG970H)V1E
M9F%U;'1?8VAA;FYE;"<I.PT*("`@("`@("!I9B`H96UP='DH)&]P=&EO;G-;
M)W)E9VES=&5R+6]N;'DG72D@)B8@(6ES7V1I<B@D<&AP7V1I<BDI('L-"B`@
M("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*%-Y<W1E;3HZ;6MD:7(H87)R
M87DH)RUP)RDL("1P:'!?9&ER*2DI('L-"B`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H(FYO(&EN<W1A;&QA=&EO;B!D97-T:6YA
M=&EO;B!D:7)E8W1O<GD@)R1P:'!?9&ER)UQN(BD[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"@T*("`@("`@("`D=&UP7W!A=&@@/2!D:7)N86UE*"1D
M97-C9FEL92D[#0H@("`@("`@(&EF("AS=6)S='(H)'!K9V9I;&4L("TT*2`A
M/2`G+GAM;"<I('L-"B`@("`@("`@("`@("1T;7!?<&%T:"`N/2!$25)%0U1/
M4EE?4T5005)!5$]2("X@)'!K9VYA;64@+B`G+2<@+B`D<&MG+3YG971697)S
M:6]N*"D[#0H@("`@("`@('T-"@T*("`@("`@("`D=&AI<RT^8V]N9FEG4V5T
M*"=D969A=6QT7V-H86YN96PG+"`D8VAA;FYE;"D[#0H@("`@("`@("\O('M[
M>R!I;G-T86QL(&9I;&5S#0H@("`@("`@(`T*("`@("`@("!I9B`H)'!K9RT^
M9V5T4&%C:V%G97AM;%9E<G-I;VXH*2`]/2`G,BXP)RD@>PT*("`@("`@("`@
M("`@)&9I;&5L:7-T(#T@)'!K9RT^9V5T26YS=&%L;&%T:6]N1FEL96QI<W0H
M*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1F:6QE;&ES="`]
M("1P:V<M/F=E=$9I;&5,:7-T*"D[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&9I;&5L:7-T*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1F:6QE;&ES=#L-"B`@("`@("`@?0T*("`@("`@("`D<&MG+3YR97-E
M=$9I;&5L:7-T*"D[#0H@("`@("`@("1P:V<M/G-E=$QA<W1);G-T86QL9616
M97)S:6]N*"1I;G-T86QL<F5G:7-T<GDM/G!A8VMA9V5);F9O*"1P:V<M/F=E
M=%!A8VMA9V4H*2P-"B`@("`@("`@("`@("=V97)S:6]N)RP@)'!K9RT^9V5T
M0VAA;FYE;"@I*2D[#0H@("`@("`@(&9O<F5A8V@@*"1F:6QE;&ES="!A<R`D
M9FEL92`]/B`D871T<RD@>PT*("`@("`@("`@("`@:68@*"1P:V<M/F=E=%!A
M8VMA9V5X;6Q697)S:6]N*"D@/3T@)S$N,"<I('L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^97AP96-T17)R;W(H4$5!4E])3E-404Q,15)?1D%)3$5$*3L-
M"B`@("`@("`@("`@("`@("`D<F5S(#T@)'1H:7,M/E]I;G-T86QL1FEL92@D
M9FEL92P@)&%T=',L("1T;7!?<&%T:"P@)&]P=&EO;G,I.PT*("`@("`@("`@
M("`@("`@("1T:&ES+3YP;W!%>'!E8W0H*3L-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@)'1H:7,M/F5X<&5C=$5R<F]R*%!%05)?
M24Y35$%,3$527T9!24Q%1"D[#0H@("`@("`@("`@("`@("`@)')E<R`]("1T
M:&ES+3Y?:6YS=&%L;$9I;&4R*"1P:V<L("1F:6QE+"`D871T<RP@)'1M<%]P
M871H+"`D;W!T:6]N<RD[#0H@("`@("`@("`@("`@("`@)'1H:7,M/G!O<$5X
M<&5C="@I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)')E<RDI('L-"B`@("`@("`@("`@("`@("!I9B`H96UP='DH
M)&]P=&EO;G-;)VEG;F]R92UE<G)O<G,G72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G)O;&QB86-K1FEL951R86YS86-T:6]N*"D[#0H@("`@
M("`@("`@("`@("`@("`@(&EF("@D<F5S+3YG971-97-S86=E*"D@/3T@(F9I
M;&4@9&]E<R!N;W0@97AI<W0B*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^<F%I<V5%<G)O<B@B9FEL92`D9FEL92!I;B!P86-K86=E+GAM
M;"!D;V5S(&YO="!E>&ES="(I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D
M<F5S*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L(")787)N:6YG.B`B
M("X@)')E<RT^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF("@D<F5S(#T](%!%05)?24Y35$%,3$527T]+*2![#0H@("`@("`@
M("`@("`@("`@+R\@4F5G:7-T97(@9FEL97,@=&AA="!W97)E(&EN<W1A;&QE
M9`T*("`@("`@("`@("`@("`@("1P:V<M/FEN<W1A;&QE9$9I;&4H)&9I;&4L
M("1A='1S*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`O
M+R!]?7T-"@T*("`@("`@("`O+R![>WL@8V]M<&EL92!A;F0@:6YS=&%L;"!S
M;W5R8V4@9FEL97,-"B`@("`@("`@:68@*"1T:&ES+3YS;W5R8V5?9FEL97,@
M/B`P("8F(&5M<'1Y*"1O<'1I;VYS6R=N;V)U:6QD)UTI*2![#0H@("`@("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R(#T-"B`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?8V]M<&EL95-O=7)C949I;&5S*"1S879E8VAA;FYE;"P@
M)'!K9RDI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1E<G([#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@+R\@?7U]#0H-"B`@("`@
M("`@:68@*&ES<V5T*"1B86-K961U<"DI('L-"B`@("`@("`@("`@("1T:&ES
M+3Y?<F5M;W9E0F%C:W5P<R@D8F%C:V5D=7`I.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("@A)'1H:7,M/F-O;6UI=$9I;&54<F%N<V%C=&EO;B@I*2![#0H@
M("`@("`@("`@("`D=&AI<RT^<F]L;&)A8VM&:6QE5')A;G-A8W1I;VXH*3L-
M"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6=3970H)V1E9F%U;'1?8VAA;FYE
M;"<L("1S879E8VAA;FYE;"D[#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H(F-O;6UI="!F86EL960B+"!014%27TE.4U1!3$Q%4E]&
M04E,140I.PT*("`@("`@("!]#0H@("`@("`@("\O('U]?0T*#0H@("`@("`@
M("1R970@/2!F86QS93L-"B`@("`@("`@)&EN<W1A;&QP:&%S92`]("=I;G-T
M86QL)SL-"B`@("`@("`@)&]L9'9E<G-I;VX@/2!F86QS93L-"B`@("`@("`@
M+R\@>WM[(%)E9VES=&5R('1H870@=&AE('!A8VMA9V4@:7,@:6YS=&%L;&5D
M("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM#0H@("`@("`@(&EF("AE;7!T>2@D
M;W!T:6]N<ULG=7!G<F%D92==*2D@>PT*("`@("`@("`@("`@+R\@:68@)V9O
M<F-E)R!I<R!U<V5D+"!R97!L86-E('1H92!I;F9O(&EN(')E9VES=')Y#0H@
M("`@("`@("`@("`D=7-E8VAA;FYE;"`]("1C:&%N;F5L.PT*("`@("`@("`@
M("`@:68@*"1C:&%N;F5L(#T]("=P96-L+G!H<"YN970G*2![#0H@("`@("`@
M("`@("`@("`@)'1E<W0@/2`D:6YS=&%L;')E9VES=')Y+3YP86-K86=E17AI
M<W1S*"1P:V=N86UE+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@:68@
M*"$D=&5S="D@>PT*("`@("`@("`@("`@("`@("`@("`D=&5S="`]("1I;G-T
M86QL<F5G:7-T<GDM/G!A8VMA9V5%>&ES=',H)'!K9VYA;64L("=P96%R+G!H
M<"YN970G*3L-"B`@("`@("`@("`@("`@("`@("`@)'5S96-H86YN96P@/2`G
M<&5A<BYP:'`N;F5T)SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1T97-T(#T@)&EN<W1A;&QR
M96=I<W1R>2T^<&%C:V%G945X:7-T<R@D<&MG;F%M92P@)&-H86YN96PI.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%E;7!T>2@D;W!T:6]N
M<ULG9F]R8V4G72D@)B8@)'1E<W0I('L-"B`@("`@("`@("`@("`@("`D;VQD
M=F5R<VEO;B`]("1I;G-T86QL<F5G:7-T<GDM/G!A8VMA9V5);F9O*"1P:V=N
M86UE+"`G=F5R<VEO;B<L("1U<V5C:&%N;F5L*3L-"B`@("`@("`@("`@("`@
M("`D:6YS=&%L;')E9VES=')Y+3YD96QE=&5086-K86=E*"1P:V=N86UE+"`D
M=7-E8VAA;FYE;"D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<F5T
M(#T@)&EN<W1A;&QR96=I<W1R>2T^861D4&%C:V%G93(H)'!K9RD[#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`D=7-E8VAA;FYE;"`]("1C:&%N
M;F5L.PT*("`@("`@("`@("`@:68@*"1C:&%N;F5L(#T]("=P96-L+G!H<"YN
M970G*2![#0H@("`@("`@("`@("`@("`@)'1E<W0@/2`D:6YS=&%L;')E9VES
M=')Y+3YP86-K86=E17AI<W1S*"1P:V=N86UE+"`D8VAA;FYE;"D[#0H@("`@
M("`@("`@("`@("`@:68@*"$D=&5S="D@>PT*("`@("`@("`@("`@("`@("`@
M("`D=&5S="`]("1I;G-T86QL<F5G:7-T<GDM/G!A8VMA9V5%>&ES=',H)'!K
M9VYA;64L("=P96%R+G!H<"YN970G*3L-"B`@("`@("`@("`@("`@("`@("`@
M)'5S96-H86YN96P@/2`G<&5A<BYP:'`N;F5T)SL-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1T
M97-T(#T@)&EN<W1A;&QR96=I<W1R>2T^<&%C:V%G945X:7-T<R@D<&MG;F%M
M92P@)&-H86YN96PI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@+R\@
M;F5W.B!U<&=R861E(&EN<W1A;&QS(&$@<&%C:V%G92!I9B!I="!I<VXG="!I
M;G-T86QL960-"B`@("`@("`@("`@(&EF("@A)'1E<W0I('L-"B`@("`@("`@
M("`@("`@("`D<F5T(#T@)&EN<W1A;&QR96=I<W1R>2T^861D4&%C:V%G93(H
M)'!K9RD[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M(&EF("@D=7-E8VAA;FYE;"`A/2`D8VAA;FYE;"D@>PT*("`@("`@("`@("`@
M("`@("`@("`D:6YS=&%L;')E9VES=')Y+3YD96QE=&5086-K86=E*"1P:V=N
M86UE+"`D=7-E8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@("`@("1R970@
M/2`D:6YS=&%L;')E9VES=')Y+3YA9&1086-K86=E,B@D<&MG*3L-"B`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D<F5T
M(#T@)&EN<W1A;&QR96=I<W1R>2T^=7!D871E4&%C:V%G93(H)'!K9RD[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1I;G-T86QL<&AA
M<V4@/2`G=7!G<F%D92<[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"$D<F5T*2![#0H@("`@("`@("`@("`D=&AI<RT^8V]N9FEG
M4V5T*"=D969A=6QT7V-H86YN96PG+"`D<V%V96-H86YN96PI.PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")!9&1I;F<@<&%C:V%G
M92`D8VAA;FYE;"\D<&MG;F%M92!T;R!R96=I<W1R>2!F86EL960B*3L-"B`@
M("`@("`@?0T*("`@("`@("`O+R!]?7T-"B`@("`@("`@)'1H:7,M/F-O;F9I
M9U-E="@G9&5F875L=%]C:&%N;F5L)RP@)'-A=F5C:&%N;F5L*3L-"B`@("`@
M("`@:68@*&-L87-S7V5X:7-T<R@G4$5!4E]487-K7T-O;6UO;B<I*2![("\O
M('1H:7,@:7,@875T;RUI;F-L=61E9"!I9B!A;GD@=&%S:W,@97AI<W0-"B`@
M("`@("`@("`@(&EF("A014%27U1A<VM?0V]M;6]N.CIH87-0;W-T:6YS=&%L
M;%1A<VMS*"DI('L-"B`@("`@("`@("`@("`@("!014%27U1A<VM?0V]M;6]N
M.CIR=6Y0;W-T:6YS=&%L;%1A<VMS*"1I;G-T86QL<&AA<V4I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<&MG+3YT;T%R
M<F%Y*'1R=64I.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[
M(%]C;VUP:6QE4V]U<F-E1FEL97,H*0T*("`@("\J*@T*("`@("`J($!P87)A
M;2!S=')I;F<-"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V,7Q0
M14%27U!A8VMA9V5&:6QE7W8R#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V-O
M;7!I;&53;W5R8V5&:6QE<R@D<V%V96-H86YN96PL("8D9FEL96QI<W0I#0H@
M("`@>PT*("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O0G5I;&1E<BYP:'`G
M.PT*("`@("`@("`D=&AI<RT^;&]G*#$L("(D=&AI<RT^<V]U<F-E7V9I;&5S
M('-O=7)C92!F:6QE<RP@8G5I;&1I;F<B*3L-"B`@("`@("`@)&)O8B`]("9N
M97<@4$5!4E]"=6EL9&5R*"1T:&ES+3YU:2D[#0H@("`@("`@("1B;V(M/F1E
M8G5G(#T@)'1H:7,M/F1E8G5G.PT*("`@("`@("`D8G5I;'0@/2`D8F]B+3YB
M=6EL9"@D9FEL96QI<W0L(&%R<F%Y*"8D=&AI<RP@)U]B=6EL9$-A;&QB86-K
M)RDI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8G5I;'0I*2![#0H@
M("`@("`@("`@("`D=&AI<RT^<F]L;&)A8VM&:6QE5')A;G-A8W1I;VXH*3L-
M"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6=3970H)V1E9F%U;'1?8VAA;FYE
M;"<L("1S879E8VAA;FYE;"D[#0H@("`@("`@("`@("!R971U<FX@)&)U:6QT
M.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YL;V<H,2P@(EQN0G5I;&0@
M<')O8V5S<R!C;VUP;&5T960@<W5C8V5S<V9U;&QY(BD[#0H@("`@("`@(&9O
M<F5A8V@@*"1B=6EL="!A<R`D97AT*2![#0H@("`@("`@("`@("`D8FX@/2!B
M87-E;F%M92@D97AT6R=F:6QE)UTI.PT*("`@("`@("`@("`@;&ES="@D7V5X
M=%]N86UE+"`D7V5X=%]S=69F*2`](&5X<&QO9&4H)RXG+"`D8FXI.PT*("`@
M("`@("`@("`@:68@*"1?97AT7W-U9F8@/3T@)RYS;R<@?'P@)%]E>'1?<W5F
M9B`]/2`G+F1L;"<I('L-"B`@("`@("`@("`@("`@("!I9B`H97AT96YS:6]N
M7VQO861E9"@D7V5X=%]N86UE*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^<F%I<V5%<G)O<B@B17AT96YS:6]N("<D7V5X=%]N86UE)R!A;')E
M861Y(&QO861E9"X@(B`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=0;&5A<V4@=6YL;V%D(&ET(&EN('EO=7(@<&AP+FEN:2!F
M:6QE("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<')I;W(@=&\@:6YS=&%L;"!O<B!U<&=R861E)RD[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("1R;VQE(#T@)V5X="<[#0H@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1R;VQE(#T@)W-R
M8R<[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D9&5S="`]("1E>'1;
M)V1E<W0G73L-"B`@("`@("`@("`@("1T:&ES+3YL;V<H,2P@(DEN<W1A;&QI
M;F<@)R1E>'1;9FEL95TG(BD[#0H@("`@("`@("`@("`D<&%C:V%G:6YG<F]O
M="`]("<G.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;W!T:6]N
M<ULG<&%C:V%G:6YG<F]O="==*2D@>PT*("`@("`@("`@("`@("`@("1P86-K
M86=I;F=R;V]T(#T@)'1H:7,M/E]O<'1I;VYS6R=P86-K86=I;F=R;V]T)UT[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D8V]P>71O(#T@)'1H:7,M
M/E]P<F5P96YD4&%T:"@D9&5S="P@)'!A8VMA9VEN9W)O;W0I.PT*("`@("`@
M("`@("`@)&-O<'ED:7(@/2!D:7)N86UE*"1C;W!Y=&\I.PT*("`@("`@("`@
M("`@+R\@<')E='1Y(&UU8V@@;F]T:&EN9R!H87!P96YS(&EF('=E(&%R92!O
M;FQY(')E9VES=&5R:6YG('1H92!I;G-T86QL#0H@("`@("`@("`@("!I9B`H
M96UP='DH)'1H:7,M/E]O<'1I;VYS6R=R96=I<W1E<BUO;FQY)UTI*2![#0H@
M("`@("`@("`@("`@("`@:68@*"%`:7-?9&ER*"1C;W!Y9&ER*2D@>PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YM:T1I<DAI97(H)&-O<'ED
M:7(I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H(F9A:6QE9"!T;R!M:V1I<B`D8V]P>61I<B(L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E])3E-404Q,15)?1D%)3$5$
M*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^;&]G*#,L("(K(&UK9&ER("1C;W!Y9&ER(BD[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@A0&-O<'DH)&5X=%LG
M9FEL92==+"`D8V]P>71O*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H(F9A:6QE9"!T;R!W<FET92`D8V]P>71O
M(BP@4$5!4E])3E-404Q,15)?1D%)3$5$*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@S+"`B*R!C<"`D97AT6V9I
M;&5=("1C;W!Y=&\B*3L-"B`@("`@("`@("`@("`@("!I9B`H(4]37U=)3D1/
M5U,I('L-"B`@("`@("`@("`@("`@("`@("`@)&UO9&4@/2`P-C8V("8@?BAI
M;G0I;V-T9&5C*"1T:&ES+3YC;VYF:6<M/F=E="@G=6UA<VLG*2D[#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YA9&1&:6QE3W!E<F%T:6]N*"=C:&UO
M9"<L(&%R<F%Y*"1M;V1E+"`D8V]P>71O*2D[#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@A0&-H;6]D*"1C;W!Y=&\L("1M;V1E*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`B9F%I;&5D('1O(&-H86YG
M92!M;V1E(&]F("1C;W!Y=&\B*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D=&AI<RT^861D
M1FEL94]P97)A=&EO;B@G<F5N86UE)RP@87)R87DH)&5X=%LG9FEL92==+"`D
M8V]P>71O*2D[#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@(&EF("@D
M9FEL96QI<W0M/F=E=%!A8VMA9V58;6Q697)S:6]N*"D@/3T@)S$N,"<I('L-
M"B`@("`@("`@("`@("`@("`D9FEL96QI<W0M/FEN<W1A;&QE9$9I;&4H)&)N
M+"!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W)O;&4G(#T^("1R;VQE
M+`T*("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@)&)N+`T*("`@("`@
M("`@("`@("`@("`@("`G:6YS=&%L;&5D7V%S)R`]/B`D9&5S="P-"B`@("`@
M("`@("`@("`@("`@("`@)W!H<%]A<&DG(#T^("1E>'1;)W!H<%]A<&DG72P-
M"B`@("`@("`@("`@("`@("`@("`@)WIE;F1?;6]D7V%P:2<@/3X@)&5X=%LG
M>F5N9%]M;V1?87!I)UTL#0H@("`@("`@("`@("`@("`@("`@("=Z96YD7V5X
M=%]A<&DG(#T^("1E>'1;)WIE;F1?97AT7V%P:2==+`T*("`@("`@("`@("`@
M("`@("`@("`I*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@)&9I;&5L:7-T+3YI;G-T86QL961&:6QE*"1B;BP@87)R87DH)V%T
M=')I8G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<F]L92<@
M/3X@)')O;&4L#0H@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B`D8FXL
M#0H@("`@("`@("`@("`@("`@("`@("=I;G-T86QL961?87,G(#T^("1D97-T
M+`T*("`@("`@("`@("`@("`@("`@("`G<&AP7V%P:2<@/3X@)&5X=%LG<&AP
M7V%P:2==+`T*("`@("`@("`@("`@("`@("`@("`G>F5N9%]M;V1?87!I)R`]
M/B`D97AT6R=Z96YD7VUO9%]A<&DG72P-"B`@("`@("`@("`@("`@("`@("`@
M)WIE;F1?97AT7V%P:2<@/3X@)&5X=%LG>F5N9%]E>'1?87!I)UTL#0H@("`@
M("`@("`@("`@("`@("`@("DI*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@(&9U;F-T:6]N("9G9715;FEN
M<W1A;&Q086-K86=E<R@I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M
M/E]D;W=N;&]A9&5D4&%C:V%G97,[#0H@("`@?0T*("`@("\O('M[>R!U;FEN
M<W1A;&PH*0T*#0H@("`@+RHJ#0H@("`@("H@56YI;G-T86QL(&$@<&%C:V%G
M90T*("`@("`J#0H@("`@("H@5&AI<R!M971H;V0@<F5M;W9E<R!A;&P@9FEL
M97,@:6YS=&%L;&5D(&)Y('1H92!A<'!L:6-A=&EO;BP@86YD('1H96X-"B`@
M("`@*B!R96UO=F5S(&%N>2!E;7!T>2!D:7)E8W1O<FEE<RX-"B`@("`@*B!`
M<&%R86T@<W1R:6YG('!A8VMA9V4@;F%M90T*("`@("`J($!P87)A;2!A<G)A
M>2!#;VUM86YD+6QI;F4@;W!T:6]N<RX@(%!O<W-I8FEL:71I97,@:6YC;'5D
M93H-"B`@("`@*@T*("`@("`J("`@("`@("`@("`@("`M(&EN<W1A;&QR;V]T
M.B!B87-E(&EN<W1A;&QA=&EO;B!D:7(L(&EF(&YO="!T:&4@9&5F875L=`T*
M("`@("`J("`@("`@("`@("`@("`M(&YO9&5P<SH@9&\@;F]T('!R;V-E<W,@
M9&5P96YD96YC:65S(&]F(&]T:&5R('!A8VMA9V5S('1O(&5N<W5R90T*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@=6YI;G-T86QL871I;VX@9&]E
M<R!N;W0@8G)E86L@=&AI;F=S#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=6YI
M;G-T86QL*"1P86-K86=E+"`D;W!T:6]N<R`](&%R<F%Y*"DI#0H@("`@>PT*
M("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)VEN<W1A;&QR;V]T)UTI*2![
M#0H@("`@("`@("`@("`D=&AI<RT^8V]N9FEG+3YS971);G-T86QL4F]O="@D
M;W!T:6]N<ULG:6YS=&%L;')O;W0G72D[#0H@("`@("`@("`@("`D=&AI<RT^
M:6YS=&%L;')O;W0@/2`G)SL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("1T:&ES+3YC;VYF:6<M/G-E=$EN<W1A;&Q2;V]T*"<G*3L-"B`@("`@
M("`@("`@("1T:&ES+3YI;G-T86QL<F]O="`]("<G.PT*("`@("`@("!]#0H@
M("`@("`@("1T:&ES+3Y?<F5G:7-T<GD@/2`F)'1H:7,M/F-O;F9I9RT^9V5T
M4F5G:7-T<GDH*3L-"B`@("`@("`@:68@*&ES7V]B:F5C="@D<&%C:V%G92DI
M('L-"B`@("`@("`@("`@("1C:&%N;F5L(#T@)'!A8VMA9V4M/F=E=$-H86YN
M96PH*3L-"B`@("`@("`@("`@("1P:V<@/2`D<&%C:V%G93L-"B`@("`@("`@
M("`@("1P86-K86=E(#T@)'!K9RT^9V5T4&%C:V%G92@I.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@)'!K9R`](&9A;'-E.PT*("`@("`@("`@
M("`@)&EN9F\@/2`D=&AI<RT^7W)E9VES=')Y+3YP87)S95!A8VMA9V5.86UE
M*"1P86-K86=E+`T*("`@("`@("`@("`@("`@("1T:&ES+3YC;VYF:6<M/F=E
M="@G9&5F875L=%]C:&%N;F5L)RDI.PT*("`@("`@("`@("`@)&-H86YN96P@
M/2`D:6YF;ULG8VAA;FYE;"==.PT*("`@("`@("`@("`@)'!A8VMA9V4@/2`D
M:6YF;ULG<&%C:V%G92==.PT*("`@("`@("!]#0H@("`@("`@("1S879E8VAA
M;FYE;"`]("1T:&ES+3YC;VYF:6<M/F=E="@G9&5F875L=%]C:&%N;F5L)RD[
M#0H@("`@("`@("1T:&ES+3YC;VYF:6=3970H)V1E9F%U;'1?8VAA;FYE;"<L
M("1C:&%N;F5L*3L-"B`@("`@("`@:68@*"%I<U]O8FIE8W0H)'!K9RDI('L-
M"B`@("`@("`@("`@("1P:V<@/2`D=&AI<RT^7W)E9VES=')Y+3YG971086-K
M86=E*"1P86-K86=E+"`D8VAA;FYE;"D[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"$D<&MG*2![#0H@("`@("`@("`@("`D=&AI<RT^8V]N9FEG4V5T*"=D
M969A=6QT7V-H86YN96PG+"`D<V%V96-H86YN96PI.PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1T:&ES+3Y?<F5G:7-T<GDM/G!A
M<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H#0H@("`@("`@("`@("`@("`@87)R
M87DH#0H@("`@("`@("`@("`@("`@("`@("=C:&%N;F5L)R`]/B`D8VAA;FYE
M;"P-"B`@("`@("`@("`@("`@("`@("`@)W!A8VMA9V4G(#T^("1P86-K86=E
M#0H@("`@("`@("`@("`@("`@*2P@=')U92D@+B`G(&YO="!I;G-T86QL960G
M*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'!K9RT^9V5T26YS=&%L;&5D
M0FEN87)Y*"DI('L-"B`@("`@("`@("`@("\O('1H:7,@:7,@:G5S="!A;B!A
M;&EA<R!F;W(@82!B:6YA<GD@<&%C:V%G90T*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<F5G:7-T<GDM/F1E;&5T95!A8VMA9V4H)'!A8VMA9V4L("1C
M:&%N;F5L*3L-"B`@("`@("`@?0T*("`@("`@("`D9FEL96QI<W0@/2`D<&MG
M+3YG971&:6QE;&ES="@I.PT*("`@("`@("!014%2.CIS=&%T:6-0=7-H17)R
M;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@(&EF("@A
M8VQA<W-?97AI<W1S*"=014%27T1E<&5N9&5N8WDR)RDI('L-"B`@("`@("`@
M("`@(')E<75I<F5?;VYC92`G4$5!4B]$97!E;F1E;F-Y,BYP:'`G.PT*("`@
M("`@("!]#0H@("`@("`@("1D97!C:&5C:V5R(#T@)FYE=R!014%27T1E<&5N
M9&5N8WDR*"1T:&ES+3YC;VYF:6<L("1O<'1I;VYS+"`-"B`@("`@("`@("`@
M(&%R<F%Y*"=C:&%N;F5L)R`]/B`D8VAA;FYE;"P@)W!A8VMA9V4G(#T^("1P
M86-K86=E*2P-"B`@("`@("`@("`@(%!%05)?5D%,241!5$5?54Y)3E-404Q,
M24Y'*3L-"B`@("`@("`@)&4@/2`D9&5P8VAE8VME<BT^=F%L:61A=&5086-K
M86=E56YI;G-T86QL*"1T:&ES*3L-"B`@("`@("`@4$5!4CHZ<W1A=&EC4&]P
M17)R;W)(86YD;&EN9R@I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M92DI('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)VEG;F]R
M92UE<G)O<G,G72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)&4I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@)U=!4DY)3D<Z("<@
M+B`D92T^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D92DI('L-
M"B`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("1E6S!=*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`O+R![>WL@1&5L971E('1H
M92!F:6QE<PT*("`@("`@("`D=&AI<RT^<W1A<G1&:6QE5')A;G-A8W1I;VXH
M*3L-"B`@("`@("`@4$5!4CHZ<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/
M4E]215154DXI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R(#T@
M)'1H:7,M/E]D96QE=&5086-K86=E1FEL97,H)'!A8VMA9V4L("1C:&%N;F5L
M*2DI('L-"B`@("`@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-
M"B`@("`@("`@("`@("1T:&ES+3YR;VQL8F%C:T9I;&54<F%N<V%C=&EO;B@I
M.PT*("`@("`@("`@("`@)'1H:7,M/F-O;F9I9U-E="@G9&5F875L=%]C:&%N
M;F5L)RP@)'-A=F5C:&%N;F5L*3L-"B`@("`@("`@("`@(&EF("@A:7-S970H
M)&]P=&EO;G-;)VEG;F]R92UE<G)O<G,G72DI('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&5R<BD[#0H@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO
M;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO
M9R@P+"`G5T%23DE.1SH@)R`N("1E<G(M/F=E=$UE<W-A9V4H*2D[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN9R@I.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("@A)'1H:7,M/F-O;6UI=$9I;&54<F%N<V%C
M=&EO;B@I*2![#0H@("`@("`@("`@("`D=&AI<RT^<F]L;&)A8VM&:6QE5')A
M;G-A8W1I;VXH*3L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;
M)VEG;F]R92UE<G)O<G,G72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H(G5N:6YS=&%L;"!F86EL960B*3L-"B`@("`@
M("`@("`@('T@96QS96EF("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("=705).24Y'.B!U;FEN
M<W1A;&P@9F%I;&5D)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`D=&AI<RT^<W1A<G1&:6QE5')A;G-A8W1I;VXH
M*3L-"B`@("`@("`@("`@(&EF("@D9&ER=')E92`]("1P:V<M/F=E=$1I<E1R
M964H*2D@>PT*("`@("`@("`@("`@("`@("\O(&%T=&5M<'0@=&\@9&5L971E
M(&5M<'1Y(&1I<F5C=&]R:65S#0H@("`@("`@("`@("`@("`@=6MS;W)T*"1D
M:7)T<F5E+"!A<G)A>2@D=&AI<RP@)U]S;W)T1&ER<R<I*3L-"B`@("`@("`@
M("`@("`@("!F;W)E86-H*"1D:7)T<F5E(&%S("1D:7(@/3X@)&YO='5S960I
M('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F%D9$9I;&5/<&5R871I
M;VXH)W)M9&ER)RP@87)R87DH)&1I<BDI.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/F-O;F9I9U-E="@G9&5F875L=%]C:&%N;F5L)RP@)'-A=F5C:&%N;F5L*3L-
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R96=I<W1R>2T^9&5L
M971E4&%C:V%G92@D<&%C:V%G92P@)&-H86YN96PI.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*"$D=&AI<RT^8V]M;6ET1FEL951R86YS86-T
M:6]N*"DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^<F]L;&)A8VM&:6QE
M5')A;G-A8W1I;VXH*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("`O+R!]?7T-"@T*("`@("`@("`D=&AI<RT^8V]N9FEG4V5T*"=D969A
M=6QT7V-H86YN96PG+"`D<V%V96-H86YN96PI.PT*("`@("`@("`O+R!296=I
M<W1E<B!T:&%T('1H92!P86-K86=E(&ES(&YO(&QO;F=E<B!I;G-T86QL960-
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F5G:7-T<GDM/F1E;&5T95!A8VMA
M9V4H)'!A8VMA9V4L("1C:&%N;F5L*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!3;W)T(&$@;&ES="!O9B!A<G)A>7,@;V8@87)R87DH9&]W;FQO861E
M9"!P86-K86=E9FEL96YA;64I(&)Y(&1E<&5N9&5N8WDN#0H@("`@("H-"B`@
M("`@*B!)="!A;'-O(')E;6]V97,@9'5P;&EC871E(&1E<&5N9&5N8VEE<PT*
M("`@("`J($!P87)A;2!A<G)A>2!A;B!A<G)A>2!O9B!014%27U!A8VMA9V5&
M:6QE7W9;,2\R72!O8FIE8W1S#0H@("`@("H@0')E='5R;B!A<G)A>7Q014%2
M7T5R<F]R(&%R<F%Y(&]F(&%R<F%Y*'!A8VMA9V5F:6QE;F%M92P@<&%C:V%G
M92YX;6P@8V]N=&5N=',I#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V]R=%!A
M8VMA9V5S1F]R56YI;G-T86QL*"8D<&%C:V%G97,I#0H@("`@>PT*("`@("`@
M("`D=&AI<RT^7V1E<&5N9&5N8WE$0B`]("9014%27T1E<&5N9&5N8WE$0CHZ
M<VEN9VQE=&]N*"1T:&ES+3YC;VYF:6<I.PT*("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D=&AI<RT^7V1E<&5N9&5N8WE$0BDI('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7V1E<&5N9&5N8WE$0CL-"B`@("`@("`@?0T*("`@
M("`@("!U<V]R="@D<&%C:V%G97,L(&%R<F%Y*"8D=&AI<RP@)U]S;W)T56YI
M;G-T86QL)RDI.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]S;W)T56YI;G-T
M86QL*"1A+"`D8BD-"B`@("![#0H@("`@("`@(&EF("@A)&$M/F=E=$1E<',H
M*2`F)B`A)&(M/F=E=$1E<',H*2D@>PT*("`@("`@("`@("`@<F5T=7)N(#`[
M("\O(&YE:71H97(@<&%C:V%G92!H87,@9&5P96YD96YC:65S+"!O<F1E<B!I
M<R!I;G-I9VYI9FEC86YT#0H@("`@("`@('T-"B`@("`@("`@:68@*"1A+3YG
M971$97!S*"D@)B8@(21B+3YG971$97!S*"DI('L-"B`@("`@("`@("`@(')E
M='5R;B`M,3L@+R\@)&$@;75S="!B92!I;G-T86QL960@869T97(@)&(@8F5C
M875S92`D82!H87,@9&5P96YD96YC:65S#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"$D82T^9V5T1&5P<R@I("8F("1B+3YG971$97!S*"DI('L-"B`@("`@
M("`@("`@(')E='5R;B`Q.R`O+R`D8B!M=7-T(&)E(&EN<W1A;&QE9"!A9G1E
M<B`D82!B96-A=7-E("1B(&AA<R!D97!E;F1E;F-I97,-"B`@("`@("`@?0T*
M("`@("`@("`O+R!B;W1H('!A8VMA9V5S(&AA=F4@9&5P96YD96YC:65S#0H@
M("`@("`@(&EF("@D=&AI<RT^7V1E<&5N9&5N8WE$0BT^9&5P96YD<T]N*"1A
M+"`D8BDI('L-"B`@("`@("`@("`@(')E='5R;B`M,3L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H)'1H:7,M/E]D97!E;F1E;F-Y1$(M/F1E<&5N9'-/;B@D
M8BP@)&$I*2![#0H@("`@("`@("`@("!R971U<FX@,3L-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@,#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O
M+R![>WL@7W-O<G1$:7)S*"D-"B`@("!F=6YC=&EO;B!?<V]R=$1I<G,H)&$L
M("1B*0T*("`@('L-"B`@("`@("`@:68@*'-T<FYA=&-M<"@D82P@)&(I(#T]
M("TQ*2!R971U<FX@,3L-"B`@("`@("`@:68@*'-T<FYA=&-M<"@D82P@)&(I
M(#T](#$I(')E='5R;B`M,3L-"B`@("`@("`@<F5T=7)N(#`[#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7V)U:6QD0V%L;&)A8VLH*0T*
M#0H@("`@9G5N8W1I;VX@7V)U:6QD0V%L;&)A8VLH)'=H870L("1D871A*0T*
M("`@('L-"B`@("`@("`@:68@*"@D=VAA="`]/2`G8VUD;W5T<'5T)R`F)B`D
M=&AI<RT^9&5B=6<@/B`Q*2!\?`T*("`@("`@("`@("`@*"1W:&%T(#T]("=O
M=71P=70G("8F("1T:&ES+3YD96)U9R`^(#`I*2![#0H@("`@("`@("`@("`D
M=&AI<RT^=6DM/F]U='!U=$1A=&$H<G1R:6TH)&1A=&$I+"`G8G5I;&0G*3L-
M"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O('U]?0T*?0T*#0HO+R![>WL@
M;60U7V9I;&4H*2!U=&EL:71Y(&9U;F-T:6]N#0II9B`H(69U;F-T:6]N7V5X
M:7-T<R@B;60U7V9I;&4B*2D@>PT*("`@(&9U;F-T:6]N(&UD-5]F:6QE*"1F
M:6QE;F%M92D@>PT*("`@("`@("`D9G`@/2!F;W!E;B@D9FEL96YA;64L(")R
M(BD[#0H@("`@("`@(&EF("@A)&9P*2!R971U<FX@;G5L;#L-"B`@("`@("`@
M:68@*&9U;F-T:6]N7V5X:7-T<R@G9FEL95]G971?8V]N=&5N=',G*2D@>PT*
M("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("`@("`D8V]N=&5N
M=',@/2!F:6QE7V=E=%]C;VYT96YT<R@D9FEL96YA;64I.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@)&-O;G1E;G1S(#T@9G)E860H)&9P+"!F
M:6QE<VEZ92@D9FEL96YA;64I*3L-"B`@("`@("`@("`@(&9C;&]S92@D9G`I
M.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!M9#4H)&-O;G1E;G1S*3L-
M"B`@("!]#0I]#0HO+R!]?7T-"@T*/SX`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]014%2+U!A8VMA9V5&:6QE+P``````````````````````
M```````````````````````````````````````````````P,#`P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<T,0`P,C$T-C0`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O4&%C:V%G949I;&4O
M1V5N97)A=&]R+P``````````````````````````````````````````````
M`````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-3$U-#,S-S0P`#`R,S0Q,0`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M4$5!4B]086-K86=E1FEL92]'96YE<F%T;W(O=C$N<&AP````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`Q-#4Q,S``,3`U,34T,S,W-#``,#(T-#4T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP#0HO*BH-"B`J
M('!A8VMA9V4N>&UL(&=E;F5R871I;VX@8VQA<W,L('!A8VMA9V4N>&UL('9E
M<G-I;VX@,2XP#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@
M*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R
M<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL
M86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W
M:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE
M(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O
M=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS
M94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E
M;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@
M4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N
M;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-
M"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D
M260Z('8Q+G!H<"QV(#$N-S`@,C`P-B\P,2\P-B`P-#HT-SHS-R!C96QL;V<@
M17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC
M92!296QE87-E(#$N-"XP83$-"B`J+PT*+RHJ#0H@*B!N965D960@9F]R(%!%
M05)?5D%,241!5$5?*B!C;VYS=&%N=',-"B`J+PT*<F5Q=6ER95]O;F-E("=0
M14%2+U9A;&ED871E+G!H<"<[#0IR97%U:7)E7V]N8V4@)U-Y<W1E;2YP:'`G
M.PT*<F5Q=6ER95]O;F-E("=014%2+U!A8VMA9V5&:6QE+W8R+G!H<"<[#0HO
M*BH-"B`J(%1H:7,@8VQA<W,@8V]N=F5R=',@82!014%27U!A8VMA9V5&:6QE
M7W8Q(&]B:F5C="!I;G1O(&%N>2!O=71P=70@9F]R;6%T+@T*("H-"B`J(%-U
M<'!O<G1E9"!O=71P=70@9F]R;6%T<R!I;F-L=61E(&%R<F%Y+"!834P@<W1R
M:6YG+"!A;F0@82!014%27U!A8VMA9V5&:6QE7W8R#0H@*B!O8FIE8W0L(&9O
M<B!C;VYV97)T:6YG('!A8VMA9V4N>&UL(#$N,"!I;G1O('!A8VMA9V4N>&UL
M(#(N,"!W:71H(&YO('-W96%T+@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@
M0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@
M/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H
M92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I
M;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P
M96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S
M<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S
M(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8Q#0I[#0H@("`@+RHJ#0H@
M("`@("H@0'9A<B!014%27U!A8VMA9V5&:6QE7W8Q#0H@("`@("HO#0H@("`@
M=F%R("1?<&%C:V%G969I;&4[#0H@("`@9G5N8W1I;VX@4$5!4E]086-K86=E
M1FEL95]'96YE<F%T;W)?=C$H)B1P86-K86=E9FEL92D-"B`@("![#0H@("`@
M("`@("1T:&ES+3Y?<&%C:V%G969I;&4@/2`F)'!A8VMA9V5F:6QE.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N(&=E=%!A8VMA9V5R5F5R<VEO;B@I#0H@("`@
M>PT*("`@("`@("!R971U<FX@)S$N-"XY)SL-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E<@T*("`@("`J($!P87)A;2!B
M;V]L(&EF('1R=64L(&$@+G1G>B!I<R!W<FET=&5N+"!O=&AE<G=I<V4@82`N
M=&%R(&ES('=R:71T96X-"B`@("`@*B!`<&%R86T@<W1R:6YG?&YU;&P@9&ER
M96-T;W)Y(&EN('=H:6-H('1O('-A=F4@=&AE("YT9WH-"B`@("`@*B!`<F5T
M=7)N('-T<FEN9WQ014%27T5R<F]R(&QO8V%T:6]N(&]F('!A8VMA9V4@;W(@
M97)R;W(@;V)J96-T#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=&]49WHH)B1P
M86-K86=E<BP@)&-O;7!R97-S(#T@=')U92P@)'=H97)E(#T@;G5L;"D-"B`@
M("![#0H@("`@("`@(')E<75I<F5?;VYC92`G07)C:&EV92]487(N<&AP)SL-
M"B`@("`@("`@:68@*"1W:&5R92`]/3T@;G5L;"D@>PT*("`@("`@("`@("`@
M:68@*"$H)'=H97)E(#T@4WES=&5M.CIM:W1E;7`H87)R87DH)RUD)RDI*2D@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=0
M14%27U!A8VMA9V5F:6QE7W8Q.CIT;U1G>CH@;6MT96UP(&9A:6QE9"<I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V5I9B`H(4!3>7-T96TZ.FUK
M1&ER*&%R<F%Y*"<M<"<L("1W:&5R92DI*2![#0H@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4$5!4E]086-K86=E9FEL95]V,3HZ=&]4
M9WHZ("(G("X@)'=H97)E("X@)R(@8V]U;&0G("X-"B`@("`@("`@("`@("`@
M("`G(&YO="!B92!C<F5A=&5D)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&9I;&5?97AI<W1S*"1W:&5R92`N($1)4D5#5$]265]315!!4D%43U(@+B`G
M<&%C:V%G92YX;6PG*2`F)@T*("`@("`@("`@("`@("`A:7-?9FEL92@D=VAE
M<F4@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)W!A8VMA9V4N>&UL)RDI('L-
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=014%27U!A
M8VMA9V5F:6QE7W8Q.CIT;U1G>CH@=6YA8FQE('1O('-A=F4@<&%C:V%G92YX
M;6P@87,G("X-"B`@("`@("`@("`@("`@("`G("(G("X@)'=H97)E("X@1$E2
M14-43U)97U-%4$%2051/4B`N("=P86-K86=E+GAM;"(G*3L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H(21T:&ES+3Y?<&%C:V%G969I;&4M/G9A;&ED871E
M*%!%05)?5D%,241!5$5?4$%#2T%'24Y'*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!%05)?4&%C:V%G969I;&5?=C$Z.G1O
M5&=Z.B!I;G9A;&ED('!A8VMA9V4@9FEL92<I.PT*("`@("`@("!]#0H@("`@
M("`@("1P:V=I;F9O(#T@)'1H:7,M/E]P86-K86=E9FEL92T^9V5T07)R87DH
M*3L-"B`@("`@("`@)&5X="`]("1C;VUP<F5S<R`_("<N=&=Z)R`Z("<N=&%R
M)SL-"B`@("`@("`@)'!K9W9E<B`]("1P:V=I;F9O6R=P86-K86=E)UT@+B`G
M+2<@+B`D<&MG:6YF;ULG=F5R<VEO;B==.PT*("`@("`@("`D9&5S=%]P86-K
M86=E(#T@9V5T8W=D*"D@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)'!K9W9E
M<B`N("1E>'0[#0H@("`@("`@(&EF("AF:6QE7V5X:7-T<RAG971C=V0H*2`N
M($1)4D5#5$]265]315!!4D%43U(@+B`D<&MG=F5R("X@)&5X="D@)B8-"B`@
M("`@("`@("`@("`@(6ES7V9I;&4H9V5T8W=D*"D@+B!$25)%0U1/4EE?4T50
M05)!5$]2("X@)'!K9W9E<B`N("1E>'0I*2![#0H@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4$5!4E]086-K86=E9FEL95]V,3HZ=&]4
M9WHZ(&-A;FYO="!C<F5A=&4@=&=Z(&9I;&4@(B<@+@T*("`@("`@("`@("`@
M("`@(&=E=&-W9"@I("X@1$E214-43U)97U-%4$%2051/4B`N("1P:V=V97(@
M+B`D97AT("X@)R(G*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'!K9V9I
M;&4@/2`D=&AI<RT^7W!A8VMA9V5F:6QE+3YG971086-K86=E1FEL92@I*2![
M#0H@("`@("`@("`@("`D<&MG9&ER(#T@9&ER;F%M92AR96%L<&%T:"@D<&MG
M9FEL92DI.PT*("`@("`@("`@("`@)'!K9V9I;&4@/2!B87-E;F%M92@D<&MG
M9FEL92D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G4$5!4E]086-K86=E9FEL95]V,3HZ=&]49WHZ
M('!A8VMA9V4@9FEL92!O8FIE8W0@;75S="`G("X-"B`@("`@("`@("`@("`@
M("`G8F4@8W)E871E9"!F<F]M(&$@<F5A;"!F:6QE)RD[#0H@("`@("`@('T-
M"B`@("`@("`@+R\@>WM[($-R96%T92!T:&4@<&%C:V%G92!F:6QE(&QI<W0-
M"B`@("`@("`@)&9I;&5L:7-T(#T@87)R87DH*3L-"B`@("`@("`@)&D@/2`P
M.PT*#0H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%C:V%G969I;&4M/F=E
M=$9I;&5L:7-T*"D@87,@)&9N86UE(#T^("1A='1S*2![#0H@("`@("`@("`@
M("`D9FEL92`]("1P:V=D:7(@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)&9N
M86UE.PT*("`@("`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D9FEL92DI('L-
M"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B1FEL
M92!D;V5S(&YO="!E>&ES=#H@)&9N86UE(BD[#0H@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("1F:6QE;&ES=%LD:2LK72`]("1F:6QE
M.PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&%T='-;)VUD-7-U;2==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5F:6QE
M+3YS971&:6QE071T<FEB=71E*"1F;F%M92P@)VUD-7-U;2<L(&UD-5]F:6QE
M*"1F:6QE*2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("1P86-K86=E<BT^;&]G*#(L(")!9&1I;F<@9FEL92`D9FYA;64B*3L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`O+R!]?7T-"B`@("`@
M("`@)'!A8VMA9V5X;6P@/2`D=&AI<RT^=&]086-K86=E1FEL92@D=VAE<F4L
M(%!%05)?5D%,241!5$5?4$%#2T%'24Y'+"`G<&%C:V%G92YX;6PG+"!T<G5E
M*3L-"B`@("`@("`@:68@*"1P86-K86=E>&UL*2![#0H@("`@("`@("`@("`D
M=&%R(#TF(&YE=R!!<F-H:79E7U1A<B@D9&5S=%]P86-K86=E+"`D8V]M<')E
M<W,I.PT*("`@("`@("`@("`@)'1A<BT^<V5T17)R;W)(86YD;&EN9RA014%2
M7T524D]27U)%5%523BD[("\O(%A86"!$;VXG="!P<FEN="!E<G)O<G,-"B`@
M("`@("`@("`@("\O("TM+2TM($-R96%T97,@=VET:"!T:&4@<&%C:V%G92YX
M;6P@9FEL90T*("`@("`@("`@("`@)&]K(#T@)'1A<BT^8W)E871E36]D:69Y
M*&%R<F%Y*"1P86-K86=E>&UL*2P@)R<L("1W:&5R92D[#0H@("`@("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D;VLI*2![#0H@("`@("`@("`@("`@("`@
M<F5T=7)N("1O:SL-"B`@("`@("`@("`@('T@96QS96EF("@A)&]K*2![#0H@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!%05)?
M4&%C:V%G969I;&5?=C$Z.G1O5&=Z.B!T87)B86QL(&-R96%T:6]N(&9A:6QE
M9"<I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@+R\@+2TM+2T@061D
M('1H92!C;VYT96YT(&]F('1H92!P86-K86=E#0H@("`@("`@("`@("!I9B`H
M(21T87(M/F%D9$UO9&EF>2@D9FEL96QI<W0L("1P:V=V97(L("1P:V=D:7(I
M*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)U!%05)?4&%C:V%G969I;&5?=C$Z.G1O5&=Z.B!T87)B86QL(&-R96%T:6]N
M(&9A:6QE9"<I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N
M("1D97-T7W!A8VMA9V4[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!`<&%R86T@<W1R:6YG?&YU;&P@9&ER96-T;W)Y('1O('!L86-E
M('1H92!P86-K86=E+GAM;"!I;BP@;W(@;G5L;"!F;W(@82!T96UP;W)A<GD@
M9&ER#0H@("`@("H@0'!A<F%M(&EN="!O;F4@;V8@=&AE(%!%05)?5D%,241!
M5$5?*B!C;VYS=&%N=',-"B`@("`@*B!`<&%R86T@<W1R:6YG(&YA;64@;V8@
M=&AE(&=E;F5R871E9"!F:6QE#0H@("`@("H@0'!A<F%M(&)O;VP@:68@=')U
M92P@=&AE;B!N;R!A;F%L>7-I<R!W:6QL(&)E('!E<F9O<FUE9"!O;B!R;VQE
M/2)P:'`B(&9I;&5S#0H@("`@("H@0')E='5R;B!S=')I;F=\4$5!4E]%<G)O
M<B!P871H('1O('1H92!C<F5A=&5D(&9I;&4@;VX@<W5C8V5S<PT*("`@("`J
M+PT*("`@(&9U;F-T:6]N('1O4&%C:V%G949I;&4H)'=H97)E(#T@;G5L;"P@
M)'-T871E(#T@4$5!4E]604Q)1$%415].3U)-04PL("1N86UE(#T@)W!A8VMA
M9V4N>&UL)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1N;V9I;&5C
M:&5C:VEN9R`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"$D=&AI<RT^
M7W!A8VMA9V5F:6QE+3YV86QI9&%T92@D<W1A=&4L("1N;V9I;&5C:&5C:VEN
M9RDI('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=0
M14%27U!A8VMA9V5F:6QE7W8Q.CIT;U!A8VMA9V5&:6QE.B!I;G9A;&ED('!A
M8VMA9V4N>&UL)RP-"B`@("`@("`@("`@("`@("!N=6QL+"!N=6QL+"!N=6QL
M+"`D=&AI<RT^7W!A8VMA9V5F:6QE+3YG971686QI9&%T:6]N5V%R;FEN9W,H
M*2D[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1W:&5R92`]/3T@;G5L;"D@
M>PT*("`@("`@("`@("`@:68@*"$H)'=H97)E(#T@4WES=&5M.CIM:W1E;7`H
M87)R87DH)RUD)RDI*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"=014%27U!A8VMA9V5F:6QE7W8Q.CIT;U!A8VMA9V5&
M:6QE.B!M:W1E;7`@9F%I;&5D)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T@96QS96EF("@A0%-Y<W1E;3HZ;6M$:7(H87)R87DH)RUP)RP@)'=H97)E
M*2DI('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=0
M14%27U!A8VMA9V5F:6QE7W8Q.CIT;U!A8VMA9V5&:6QE.B`B)R`N("1W:&5R
M92`N("<B(&-O=6QD)R`N#0H@("`@("`@("`@("`@("`@)R!N;W0@8F4@8W)E
M871E9"<I.PT*("`@("`@("!]#0H@("`@("`@("1N97=P:V=F:6QE(#T@)'=H
M97)E("X@1$E214-43U)97U-%4$%2051/4B`N("1N86UE.PT*("`@("`@("`D
M;G`@/2!`9F]P96XH)&YE=W!K9V9I;&4L("=W8B<I.PT*("`@("`@("!I9B`H
M(21N<"D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)U!%05)?4&%C:V%G969I;&5?=C$Z.G1O4&%C:V%G949I;&4Z('5N86)L92!T
M;R!S879E("<@+@T*("`@("`@("`@("`@("`@(B1N86UE(&%S("1N97=P:V=F
M:6QE(BD[#0H@("`@("`@('T-"B`@("`@("`@9G=R:71E*"1N<"P@)'1H:7,M
M/G1O6&UL*"1S=&%T92P@=')U92DI.PT*("`@("`@("!F8VQO<V4H)&YP*3L-
M"B`@("`@("`@<F5T=7)N("1N97=P:V=F:6QE.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J(&9I>"!B;W1H(%A-3"!E;F-O9&EN9R!T;R!B92!55$8X+"!A
M;F0@<F5P;&%C92!S=&%N9&%R9"!834P@96YT:71I97,@/"`^("(@)B`G#0H@
M("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=')I;F<-"B`@("`@*B!`
M<F5T=7)N('-T<FEN9PT*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(%]F:7A8;6Q%;F-O9&EN9R@D<W1R:6YG*0T*("`@
M('L-"B`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92AP:'!V97)S:6]N*"DL
M("<U+C`N,"<L("=L="<I*2![#0H@("`@("`@("`@("`D<W1R:6YG(#T@=71F
M.%]E;F-O9&4H)'-T<FEN9RD[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M('-T<G1R*"1S=')I;F<L(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)R8G("`]/B`G)F%M<#LG+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)SXG("`]/B`G
M)F=T.R<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G/"<@(#T^("<F;'0[)RP-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("<B)R`@/3X@)R9Q=6]T.R<L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G7"<G(#T^("<F
M87!O<SLG("DI.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%)E='5R;B!A
M;B!834P@9&]C=6UE;G0@8F%S960@;VX@=&AE('!A8VMA9V4@:6YF;R`H87,@
M<F5T=7)N960-"B`@("`@*B!B>2!T:&4@4$5!4E]#;VUM;VXZ.FEN9F]&<F]M
M*B!M971H;V1S*2X-"B`@("`@*@T*("`@("`J($!R971U<FX@<W1R:6YG(%A-
M3"!D871A#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=&]8;6PH)'-T871E(#T@
M4$5!4E]604Q)1$%415].3U)-04PL("1N;V9I;&5V86QI9&%T:6]N(#T@9F%L
M<V4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5F:6QE+3YS971$
M871E*&1A=&4H)UDM;2UD)RDI.PT*("`@("`@("!I9B`H(21T:&ES+3Y?<&%C
M:V%G969I;&4M/G9A;&ED871E*"1S=&%T92P@)&YO9FEL979A;&ED871I;VXI
M*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@
M("`@("`@)'!K9VEN9F\@/2`D=&AI<RT^7W!A8VMA9V5F:6QE+3YG971!<G)A
M>2@I.PT*("`@("`@("!S=&%T:6,@)&UA:6YT7VUA<"`](&%R<F%Y*`T*("`@
M("`@("`@("`@(FAA;F1L92(@/3X@(G5S97(B+`T*("`@("`@("`@("`@(FYA
M;64B(#T^(")N86UE(BP-"B`@("`@("`@("`@(")E;6%I;"(@/3X@(F5M86EL
M(BP-"B`@("`@("`@("`@(")R;VQE(B`]/B`B<F]L92(L#0H@("`@("`@("`@
M("`I.PT*("`@("`@("`D<F5T(#T@(CP_>&UL('9E<G-I;VX]7"(Q+C!<(B!E
M;F-O9&EN9SU<(E541BTX7"(@/SY<;B([#0H@("`@("`@("1R970@+CT@(CPA
M1$]#5%E012!P86-K86=E(%-94U1%32!<(FAT='`Z+R]P96%R+G!H<"YN970O
M9'1D+W!A8VMA9V4M,2XP7"(^7&XB.PT*("`@("`@("`D<F5T("X]("(\<&%C
M:V%G92!V97)S:6]N/5PB,2XP7"(@<&%C:V%G97)V97)S:6]N/5PB,2XT+CE<
M(CY<;B(@+@T*(B`\;F%M93XD<&MG:6YF;UMP86-K86=E73PO;F%M93XB.PT*
M("`@("`@("!I9B`H:7-S970H)'!K9VEN9F];)V5X=&5N9',G72DI('L-"B`@
M("`@("`@("`@("1R970@+CT@(EQN/&5X=&5N9',^)'!K9VEN9F];97AT96YD
M<UT\+V5X=&5N9',^(CL-"B`@("`@("`@?0T*("`@("`@("`D<F5T("X]#0H@
M(EQN(#QS=6UM87)Y/B(N)'1H:7,M/E]F:7A8;6Q%;F-O9&EN9R@D<&MG:6YF
M;ULG<W5M;6%R>2==*2XB/"]S=6UM87)Y/EQN(B`N#0HB(#QD97-C<FEP=&EO
M;CXB+G1R:6TH)'1H:7,M/E]F:7A8;6Q%;F-O9&EN9R@D<&MG:6YF;ULG9&5S
M8W)I<'1I;VXG72DI+B)<;B`\+V1E<V-R:7!T:6]N/EQN(B`N#0HB(#QM86EN
M=&%I;F5R<SY<;B([#0H@("`@("`@(&9O<F5A8V@@*"1P:V=I;F9O6R=M86EN
M=&%I;F5R<R==(&%S("1M86EN="D@>PT*("`@("`@("`@("`@)')E="`N/2`B
M("`\;6%I;G1A:6YE<CY<;B([#0H@("`@("`@("`@("!F;W)E86-H("@D;6%I
M;G1?;6%P(&%S("1I9'@@/3X@)&5L;2D@>PT*("`@("`@("`@("`@("`@("1R
M970@+CT@(B`@(#PD96QM/B([#0H@("`@("`@("`@("`@("`@)')E="`N/2`D
M=&AI<RT^7V9I>%AM;$5N8V]D:6YG*"1M86EN=%LD:61X72D[#0H@("`@("`@
M("`@("`@("`@)')E="`N/2`B/"\D96QM/EQN(CL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1R970@+CT@(B`@/"]M86EN=&%I;F5R/EQN(CL-"B`@
M("`@("`@?0T*("`@("`@("`D<F5T("X]("(@(#PO;6%I;G1A:6YE<G,^7&XB
M.PT*("`@("`@("`D<F5T("X]("1T:&ES+3Y?;6%K95)E;&5A<V58;6PH)'!K
M9VEN9F\L(&9A;'-E+"`D<W1A=&4I.PT*("`@("`@("!I9B`H:7-S970H)'!K
M9VEN9F];)V-H86YG96QO9R==*2`F)B!C;W5N="@D<&MG:6YF;ULG8VAA;F=E
M;&]G)UTI(#X@,"D@>PT*("`@("`@("`@("`@)')E="`N/2`B(#QC:&%N9V5L
M;V<^7&XB.PT*("`@("`@("`@("`@9F]R96%C:"`H)'!K9VEN9F];)V-H86YG
M96QO9R==(&%S("1O;&1R96QE87-E*2![#0H@("`@("`@("`@("`@("`@)')E
M="`N/2`D=&AI<RT^7VUA:V5296QE87-E6&UL*"1O;&1R96QE87-E+"!T<G5E
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1R970@+CT@(B`\+V-H
M86YG96QO9SY<;B([#0H@("`@("`@('T-"B`@("`@("`@)')E="`N/2`B/"]P
M86-K86=E/EQN(CL-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(%]M86ME4F5L96%S95AM;"@I#0H-"B`@
M("`O*BH-"B`@("`@*B!'96YE<F%T92!P87)T(&]F(&%N(%A-3"!D97-C<FEP
M=&EO;B!W:71H(')E;&5A<V4@:6YF;W)M871I;VXN#0H@("`@("H-"B`@("`@
M*B!`<&%R86T@87)R87D@("1P:V=I;F9O("`@(&%R<F%Y('=I=&@@<F5L96%S
M92!I;F9O<FUA=&EO;@T*("`@("`J($!P87)A;2!B;V]L("`@)&-H86YG96QO
M9R`@=VAE=&AE<B!T:&4@<F5S=6QT('=I;&P@8F4@:6X@82!C:&%N9V5L;V<@
M96QE;65N=`T*("`@("`J#0H@("`@("H@0')E='5R;B!S=')I;F<@6$U,(&1A
M=&$-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*
M("`@(&9U;F-T:6]N(%]M86ME4F5L96%S95AM;"@D<&MG:6YF;RP@)&-H86YG
M96QO9R`](&9A;'-E+"`D<W1A=&4@/2!014%27U9!3$E$051%7TY/4DU!3"D-
M"B`@("![#0H@("`@("`@("\O(%A86"!154]412!%3E1)5$E%4R!)3B!00T1!
M5$$L($]2($5-0D5$($E.($-$051!($),3T-+4R$A#0H@("`@("`@("1I;F1E
M;G0@/2`D8VAA;F=E;&]G(#\@(B`@(B`Z("(B.PT*("`@("`@("`D<F5T(#T@
M(B1I;F1E;G0@/')E;&5A<V4^7&XB.PT*("`@("`@("!I9B`H(65M<'1Y*"1P
M:V=I;F9O6R=V97)S:6]N)UTI*2![#0H@("`@("`@("`@("`D<F5T("X]("(D
M:6YD96YT("`\=F5R<VEO;CXD<&MG:6YF;UMV97)S:6]N73PO=F5R<VEO;CY<
M;B([#0H@("`@("`@('T-"B`@("`@("`@:68@*"%E;7!T>2@D<&MG:6YF;ULG
M<F5L96%S95]D871E)UTI*2![#0H@("`@("`@("`@("`D<F5T("X]("(D:6YD
M96YT("`\9&%T93XD<&MG:6YF;UMR96QE87-E7V1A=&5=/"]D871E/EQN(CL-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H(65M<'1Y*"1P:V=I;F9O6R=R96QE
M87-E7VQI8V5N<V4G72DI('L-"B`@("`@("`@("`@("1R970@+CT@(B1I;F1E
M;G0@(#QL:6-E;G-E/B1P:V=I;F9O6W)E;&5A<V5?;&EC96YS95T\+VQI8V5N
M<V4^7&XB.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A96UP='DH)'!K9VEN
M9F];)W)E;&5A<V5?<W1A=&4G72DI('L-"B`@("`@("`@("`@("1R970@+CT@
M(B1I;F1E;G0@(#QS=&%T93XD<&MG:6YF;UMR96QE87-E7W-T871E73PO<W1A
M=&4^7&XB.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A96UP='DH)'!K9VEN
M9F];)W)E;&5A<V5?;F]T97,G72DI('L-"B`@("`@("`@("`@("1R970@+CT@
M(B1I;F1E;G0@(#QN;W1E<SXB+G1R:6TH)'1H:7,M/E]F:7A8;6Q%;F-O9&EN
M9R@D<&MG:6YF;ULG<F5L96%S95]N;W1E<R==*2D-"B`@("`@("`@("`@("XB
M7&XD:6YD96YT("`\+VYO=&5S/EQN(CL-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H(65M<'1Y*"1P:V=I;F9O6R=R96QE87-E7W=A<FYI;F=S)UTI*2![#0H@
M("`@("`@("`@("`D<F5T("X]("(D:6YD96YT("`\=V%R;FEN9W,^(BXD=&AI
M<RT^7V9I>%AM;$5N8V]D:6YG*"1P:V=I;F9O6R=R96QE87-E7W=A<FYI;F=S
M)UTI+B(\+W=A<FYI;F=S/EQN(CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M:7-S970H)'!K9VEN9F];)W)E;&5A<V5?9&5P<R==*2`F)B!S:7IE;V8H)'!K
M9VEN9F];)W)E;&5A<V5?9&5P<R==*2`^(#`I('L-"B`@("`@("`@("`@("1R
M970@+CT@(B1I;F1E;G0@(#QD97!S/EQN(CL-"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1P:V=I;F9O6R=R96QE87-E7V1E<',G72!A<R`D9&5P*2![#0H@("`@
M("`@("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@(#QD97`@='EP93U<(B1D
M97!;='EP95U<(B!R96P]7"(D9&5P6W)E;%U<(B([#0H@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1D97!;)W9E<G-I;VXG72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)')E="`N/2`B('9E<G-I;VX]7"(D9&5P6W9E<G-I;VY=7"(B
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&1E<%LG;W!T:6]N86PG72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M)')E="`N/2`B(&]P=&EO;F%L/5PB)&1E<%MO<'1I;VYA;%U<(B([#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P
M6R=N86UE)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1R970@+CT@(CXD
M9&5P6VYA;65=/"]D97`^7&XB.PT*("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("1R970@+CT@(B\^7&XB.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1R970@
M+CT@(B1I;F1E;G0@(#PO9&5P<SY<;B([#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES<V5T*"1P:V=I;F9O6R=C;VYF:6=U<F5?;W!T:6]N<R==*2D@>PT*
M("`@("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@/&-O;F9I9W5R96]P=&EO
M;G,^7&XB.PT*("`@("`@("`@("`@9F]R96%C:"`H)'!K9VEN9F];)V-O;F9I
M9W5R95]O<'1I;VYS)UT@87,@)&,I('L-"B`@("`@("`@("`@("`@("`D<F5T
M("X]("(D:6YD96YT("`@/&-O;F9I9W5R96]P=&EO;B!N86UE/5PB(BX-"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]F:7A8;6Q%;F-O9&EN9R@D8ULG
M;F%M92==*2`N(")<(B([#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1C
M6R=D969A=6QT)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1R970@+CT@
M(B!D969A=6QT/5PB(B`N("1T:&ES+3Y?9FEX6&UL16YC;V1I;F<H)&-;)V1E
M9F%U;'0G72D@+B`B7"(B.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`D<F5T("X]("(@<')O;7!T/5PB(B`N("1T:&ES+3Y?9FEX6&UL
M16YC;V1I;F<H)&-;)W!R;VUP="==*2`N(")<(B([#0H@("`@("`@("`@("`@
M("`@)')E="`N/2`B+SY<;B([#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`D<F5T("X]("(D:6YD96YT("`\+V-O;F9I9W5R96]P=&EO;G,^7&XB.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D<&MG:6YF;ULG<')O=FED
M97,G72DI('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1P:V=I;F9O6R=P<F]V
M:61E<R==(&%S("1K97D@/3X@)'=H870I('L-"B`@("`@("`@("`@("`@("`D
M<F5T("X]("(D:6YD96YT("`\<')O=FED97,@='EP93U<(B1W:&%T6W1Y<&5=
M7"(@(CL-"B`@("`@("`@("`@("`@("`D<F5T("X](")N86UE/5PB)'=H871;
M;F%M95U<(B`B.PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=VAA=%LG
M97AT96YD<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<F5T("X](")E
M>'1E;F1S/5PB)'=H871;97AT96YD<UU<(B`B.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`D<F5T("X]("(O/EQN(CL-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'!K9VEN9F];
M)V9I;&5L:7-T)UTI*2![#0H@("`@("`@("`@("`D<F5T("X]("(D:6YD96YT
M("`\9FEL96QI<W0^7&XB.PT*("`@("`@("`@("`@:68@*"1S=&%T92!>(%!%
M05)?5D%,241!5$5?4$%#2T%'24Y'*2![#0H@("`@("`@("`@("`@("`@)')E
M="`N/2`D=&AI<RT^<F5C=7)S:79E6&UL1FEL96QI<W0H)'!K9VEN9F];)V9I
M;&5L:7-T)UTI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D<&MG:6YF;ULG9FEL96QI<W0G72!A<R`D9FEL92`]
M/B`D9F$I('L-"B`@("`@("`@("`@("`@("`@("`@0"1R970@+CT@(B1I;F1E
M;G0@("`\9FEL92!R;VQE/5PB)&9A6W)O;&5=7"(B.PT*("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&9A6R=B87-E:6YS=&%L;&1I<B==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)')E="`N/2`G(&)A<V5I;G-T86QL
M9&ER/2(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V9I>%AM;$5N8V]D:6YG*"1F85LG8F%S96EN<W1A;&QD:7(G72D@+B`G(B<[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1F85LG;60U<W5M)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5T("X]("(@;60U<W5M/5PB)&9A6VUD-7-U;5U<(B([#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1F85LG<&QA=&9O<FTG72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1R970@+CT@(B!P;&%T9F]R;3U<(B1F85MP;&%T9F]R;5U<(B([
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"%E;7!T>2@D9F%;)VEN<W1A;&PM87,G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1R970@+CT@)R!I;G-T86QL+6%S/2(G("X-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V9I>%AM;$5N8V]D:6YG
M*"1F85LG:6YS=&%L;"UA<R==*2`N("<B)SL-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`D<F5T("X]("<@;F%M93TB)R`N
M("1T:&ES+3Y?9FEX6&UL16YC;V1I;F<H)&9I;&4I("X@)R(G.PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H96UP='DH)&9A6R=R97!L86-E;65N=',G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R970@+CT@(B\^7&XB.PT*
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)')E="`N/2`B/EQN(CL-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1F85LG<F5P;&%C96UE;G1S)UT@87,@)'(I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5T("X]("(D:6YD96YT("`@
M(#QR97!L86-E(CL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E
M86-H("@D<B!A<R`D:R`]/B`D=BD@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<F5T("X]("(@)&L]7"(B("X@)'1H:7,M/E]F:7A8;6Q%
M;F-O9&EN9R@D=BD@+B<B)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E="`N/2`B+SY<
M;B([#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("!`)')E="`N/2`B)&EN9&5N="`@(#PO9FEL93Y<;B([#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D<F5T("X]("(D:6YD96YT("`\+V9I
M;&5L:7-T/EQN(CL-"B`@("`@("`@?0T*("`@("`@("`D<F5T("X]("(D:6YD
M96YT(#PO<F5L96%S93Y<;B([#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!A<G)A>0T*("`@("`J($!A
M8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<F5C=7)S
M:79E6&UL1FEL96QI<W0H)&QI<W0I#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M7V1I<G,@/2!A<G)A>2@I.PT*("`@("`@("!F;W)E86-H("@D;&ES="!A<R`D
M9FEL92`]/B`D871T<FEB=71E<RD@>PT*("`@("`@("`@("`@)'1H:7,M/E]A
M9&1$:7(H)'1H:7,M/E]D:7)S+"!E>'!L;V1E*"<O)RP@9&ER;F%M92@D9FEL
M92DI+"`D9FEL92P@)&%T=')I8G5T97,I.PT*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B`D=&AI<RT^7V9O<FUA=$1I<B@D=&AI<RT^7V1I<G,I.PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!A<G)A>0T*("`@("`J($!P
M87)A;2!A<G)A>0T*("`@("`J($!P87)A;2!S=')I;F=\;G5L;`T*("`@("`J
M($!P87)A;2!A<G)A>7QN=6QL#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@7V%D9$1I<B@F)&1I<G,L("1D:7(L("1F
M:6QE(#T@;G5L;"P@)&%T=')I8G5T97,@/2!N=6QL*0T*("`@('L-"B`@("`@
M("`@:68@*"1D:7(@/3T@87)R87DH*2!\?"`D9&ER(#T](&%R<F%Y*"<N)RDI
M('L-"B`@("`@("`@("`@("1D:7)S6R=F:6QE<R==6V)A<V5N86UE*"1F:6QE
M*5T@/2`D871T<FEB=71E<SL-"B`@("`@("`@("`@(')E='5R;CL-"B`@("`@
M("`@?0T*("`@("`@("`D8W5R9&ER(#T@87)R87E?<VAI9G0H)&1I<BD[#0H@
M("`@("`@(&EF("@A:7-S970H)&1I<G-;)V1I<G,G75LD8W5R9&ER72DI('L-
M"B`@("`@("`@("`@("1D:7)S6R=D:7)S)UU;)&-U<F1I<ET@/2!A<G)A>2@I
M.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?861D1&ER*"1D:7)S6R=D
M:7)S)UU;)&-U<F1I<ETL("1D:7(L("1F:6QE+"`D871T<FEB=71E<RD[#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&%R<F%Y#0H@("`@("H@
M0'!A<F%M('-T<FEN9PT*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B!`
M86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?9F]R;6%T
M1&ER*"1D:7)S+"`D:6YD96YT(#T@)R<L("1C=7)D:7(@/2`G)RD-"B`@("![
M#0H@("`@("`@("1R970@/2`G)SL-"B`@("`@("`@:68@*"%C;W5N="@D9&ER
M<RDI('L-"B`@("`@("`@("`@(')E='5R;B`G)SL-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H:7-S970H)&1I<G-;)V1I<G,G72DI('L-"B`@("`@("`@("`@
M('5K<V]R="@D9&ER<ULG9&ER<R==+"`G<W1R;F%T8V%S96-M<"<I.PT*("`@
M("`@("`@("`@9F]R96%C:"`H)&1I<G-;)V1I<G,G72!A<R`D9&ER(#T^("1C
M;VYT96YT<RD@>PT*("`@("`@("`@("`@("`@("1U<V5D:7(@/2`B)&-U<F1I
M<B\D9&ER(CL-"B`@("`@("`@("`@("`@("`D<F5T("X]("(D:6YD96YT("`@
M/&1I<B!N86UE/5PB)&1I<EPB/EQN(CL-"B`@("`@("`@("`@("`@("`D<F5T
M("X]("1T:&ES+3Y?9F]R;6%T1&ER*"1C;VYT96YT<RP@(B1I;F1E;G0@(BP@
M)'5S961I<BD[#0H@("`@("`@("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@
M(#PO9&ER/B`\(2TM("1U<V5D:7(@+2T^7&XB.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&ER<ULG9FEL97,G72DI
M('L-"B`@("`@("`@("`@('5K<V]R="@D9&ER<ULG9FEL97,G72P@)W-T<FYA
M=&-A<V5C;7`G*3L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1D:7)S6R=F:6QE
M<R==(&%S("1F:6QE(#T^("1A='1R:6)S*2![#0H@("`@("`@("`@("`@("`@
M)')E="`N/2`D=&AI<RT^7V9O<FUA=$9I;&4H)&9I;&4L("1A='1R:6)S+"`D
M:6YD96YT*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@
M<W1R:6YG#0H@("`@("H@0'!A<F%M(&%R<F%Y#0H@("`@("H@0'!A<F%M('-T
M<FEN9PT*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(%]F;W)M871&:6QE*"1F:6QE+"`D871T<FEB=71E<RP@)&EN9&5N
M="D-"B`@("![#0H@("`@("`@("1R970@/2`B)&EN9&5N="`@(#QF:6QE(')O
M;&4]7"(D871T<FEB=71E<UMR;VQE75PB(CL-"B`@("`@("`@:68@*&ES<V5T
M*"1A='1R:6)U=&5S6R=B87-E:6YS=&%L;&1I<B==*2D@>PT*("`@("`@("`@
M("`@)')E="`N/2`G(&)A<V5I;G-T86QL9&ER/2(G("X-"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V9I>%AM;$5N8V]D:6YG*"1A='1R:6)U=&5S6R=B87-E
M:6YS=&%L;&1I<B==*2`N("<B)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M:7-S970H)&%T=')I8G5T97-;)VUD-7-U;2==*2D@>PT*("`@("`@("`@("`@
M)')E="`N/2`B(&UD-7-U;3U<(B1A='1R:6)U=&5S6VUD-7-U;5U<(B([#0H@
M("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1A='1R:6)U=&5S6R=P;&%T
M9F]R;2==*2D@>PT*("`@("`@("`@("`@)')E="`N/2`B('!L871F;W)M/5PB
M)&%T=')I8G5T97-;<&QA=&9O<FU=7"(B.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("@A96UP='DH)&%T=')I8G5T97-;)VEN<W1A;&PM87,G72DI('L-"B`@
M("`@("`@("`@("1R970@+CT@)R!I;G-T86QL+6%S/2(G("X-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V9I>%AM;$5N8V]D:6YG*"1A='1R:6)U=&5S6R=I
M;G-T86QL+6%S)UTI("X@)R(G.PT*("`@("`@("!]#0H@("`@("`@("1R970@
M+CT@)R!N86UE/2(G("X@)'1H:7,M/E]F:7A8;6Q%;F-O9&EN9R@D9FEL92D@
M+B`G(B<[#0H@("`@("`@(&EF("AE;7!T>2@D871T<FEB=71E<ULG<F5P;&%C
M96UE;G1S)UTI*2![#0H@("`@("`@("`@("`D<F5T("X]("(O/EQN(CL-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1R970@+CT@(CY<;B([#0H@
M("`@("`@("`@("!F;W)E86-H("@D871T<FEB=71E<ULG<F5P;&%C96UE;G1S
M)UT@87,@)'(I('L-"B`@("`@("`@("`@("`@("`D<F5T("X]("(D:6YD96YT
M("`@(#QR97!L86-E(CL-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D<B!A
M<R`D:R`]/B`D=BD@>PT*("`@("`@("`@("`@("`@("`@("`D<F5T("X]("(@
M)&L]7"(B("X@)'1H:7,M/E]F:7A8;6Q%;F-O9&EN9R@D=BD@+B<B)SL-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)')E="`N/2`B+SY<
M;B([#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<F5T("X]("(D:6YD
M96YT("`@/"]F:6QE/EQN(CL-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M)')E=#L-"B`@("!]#0H-"B`@("`O+R![>WL@7W5N26YD96YT*"D-"@T*("`@
M("\J*@T*("`@("`J(%5N:6YD96YT(&=I=F5N('-T<FEN9R`H/RD-"B`@("`@
M*@T*("`@("`J($!P87)A;2!S=')I;F<@)'-T<B!4:&4@<W1R:6YG('1H870@
M:&%S('1O(&)E('5N:6YD96YT960N#0H@("`@("H@0')E='5R;B!S=')I;F<-
M"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!?=6Y);F1E;G0H)'-T<BD-"B`@("![#0H@("`@("`@("\O(')E;6]V92!L
M96%D:6YG(&YE=VQI;F5S#0H@("`@("`@("1S='(@/2!P<F5G7W)E<&QA8V4H
M)R]>6UQR7&Y=*R\G+"`G)RP@)'-T<BD[#0H@("`@("`@("\O(&9I;F0@=VAI
M=&5S<&%C92!A="!T:&4@8F5G:6YN:6YG(&]F('1H92!F:7)S="!L:6YE#0H@
M("`@("`@("1I;F1E;G1?;&5N(#T@<W1R<W!N*"1S='(L("(@7'0B*3L-"B`@
M("`@("`@)&EN9&5N="`]('-U8G-T<B@D<W1R+"`P+"`D:6YD96YT7VQE;BD[
M#0H@("`@("`@("1D871A(#T@)R<[#0H@("`@("`@("\O(')E;6]V92!T:&4@
M<V%M92!A;6]U;G0@;V8@=VAI=&5S<&%C92!F<F]M(&9O;&QO=VEN9R!L:6YE
M<PT*("`@("`@("!F;W)E86-H("AE>'!L;V1E*")<;B(L("1S='(I(&%S("1L
M:6YE*2![#0H@("`@("`@("`@("!I9B`H<W5B<W1R*"1L:6YE+"`P+"`D:6YD
M96YT7VQE;BD@/3T@)&EN9&5N="D@>PT*("`@("`@("`@("`@("`@("1D871A
M("X]('-U8G-T<B@D;&EN92P@)&EN9&5N=%]L96XI("X@(EQN(CL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&1A=&$[#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(&1E<&5N9&5N8VEE<U1O5C(H*0T*("`@('L-"B`@
M("`@("`@)&%R<B`](&%R<F%Y*"D[#0H@("`@("`@("1T:&ES+3Y?8V]N=F5R
M=$1E<&5N9&5N8VEE<S)?,"@D87)R*3L-"B`@("`@("`@<F5T=7)N("1A<G);
M)V1E<&5N9&5N8VEE<R==.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($-O
M;G9E<G0@82!P86-K86=E+GAM;"!V97)S:6]N(#$N,"!I;G1O('9E<G-I;VX@
M,BXP#0H@("`@("H-"B`@("`@*B!.;W1E('1H870@=&AI<R!D;V5S(&$@8F%S
M:6,@8V]N=F5R<VEO;BP@=&\@86QL;W<@;6]R92!A9'9A;F-E9`T*("`@("`J
M(&9E871U<F5S(&QI:V4@8G5N9&QE<R!A;F0@;75L=&EP;&4@<F5L96%S97,-
M"B`@("`@*B!`<&%R86T@<W1R:6YG('1H92!C;&%S<VYA;64@=&\@:6YS=&%N
M=&EA=&4@86YD(')E='5R;BX@(%1H:7,@;75S="!B90T*("`@("`J("`@("`@
M("`@("`@("`@4$5!4E]086-K86=E1FEL95]V,B!O<B!A(&1E<V-E;F1A;G0-
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B!I9B!T<G5E+"!O;FQY('9A;&ED+"!D
M971E<FUI;FES=&EC('!A8VMA9V4N>&UL(#$N,"!A<R!D969I;F5D(&)Y('1H
M90T*("`@("`J("`@("`@("`@("`@("`@('-T<FEC=&5S="!P87)A;65T97)S
M('=I;&P@8F4@8V]N=F5R=&5D#0H@("`@("H@0')E='5R;B!014%27U!A8VMA
M9V5&:6QE7W8R?%!%05)?17)R;W(-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F
M=&]6,B@D8VQA<W,@/2`G4$5!4E]086-K86=E1FEL95]V,B<L("1S=')I8W0@
M/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@D<W1R:6-T*2![#0H@("`@
M("`@("`@("!I9B`H(21T:&ES+3Y?<&%C:V%G969I;&4M/G9A;&ED871E*"DI
M('L-"B`@("`@("`@("`@("`@("`D82`](%!%05(Z.G)A:7-E17)R;W(H)VEN
M=F%L:60@<&%C:V%G92YX;6P@=F5R<VEO;B`Q+C`@8V%N;F]T(&)E(&-O;G9E
M<G1E9"<@+@T*("`@("`@("`@("`@("`@("`@("`G('1O('9E<G-I;VX@,BXP
M)RP@;G5L;"P@;G5L;"P@;G5L;"P-"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P86-K86=E9FEL92T^9V5T5F%L:61A=&EO;E=A<FYI;F=S*'1R=64I
M*3L-"B`@("`@("`@("`@("`@("!R971U<FX@)&$[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@)&%R<B`](&%R<F%Y*`T*("`@("`@("`@
M("`@)V%T=')I8G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G=F5R<VEO;B<@/3X@)S(N,"<L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=X;6QN<R<@/3X@)VAT='`Z+R]P96%R+G!H<"YN970O
M9'1D+W!A8VMA9V4M,BXP)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)WAM;&YS.G1A<VMS)R`]/B`G:'1T<#HO+W!E87(N<&AP+FYE="]D=&0O
M=&%S:W,M,2XP)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)WAM
M;&YS.GAS:2<@/3X@)VAT='`Z+R]W=W<N=S,N;W)G+S(P,#$O6$U,4V-H96UA
M+6EN<W1A;F-E)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)WAS
M:3IS8VAE;6%,;V-A=&EO;B<@/3X@(FAT='`Z+R]P96%R+G!H<"YN970O9'1D
M+W1A<VMS+3$N,%QN(B`N#0HB:'1T<#HO+W!E87(N<&AP+FYE="]D=&0O=&%S
M:W,M,2XP+GAS9%QN(B`N#0HB:'1T<#HO+W!E87(N<&AP+FYE="]D=&0O<&%C
M:V%G92TR+C!<;B(@+@T*)VAT='`Z+R]P96%R+G!H<"YN970O9'1D+W!A8VMA
M9V4M,BXP+GAS9"<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@*2P-"B`@
M("`@("`@("`@("=N86UE)R`]/B`D=&AI<RT^7W!A8VMA9V5F:6QE+3YG9710
M86-K86=E*"DL#0H@("`@("`@("`@("`G8VAA;FYE;"<@/3X@)W!E87(N<&AP
M+FYE="<L#0H@("`@("`@("D[#0H@("`@("`@("1A<G);)W-U;6UA<GDG72`]
M("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=%-U;6UA<GDH*3L-"B`@("`@("`@
M)&%R<ELG9&5S8W)I<'1I;VXG72`]("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E
M=$1E<V-R:7!T:6]N*"D[#0H@("`@("`@("1M86EN=&%I;F5R<R`]("1T:&ES
M+3Y?<&%C:V%G969I;&4M/F=E=$UA:6YT86EN97)S*"D[#0H@("`@("`@(&9O
M<F5A8V@@*"1M86EN=&%I;F5R<R!A<R`D;6%I;G1A:6YE<BD@>PT*("`@("`@
M("`@("`@:68@*"1M86EN=&%I;F5R6R=R;VQE)UT@(3T@)VQE860G*2![#0H@
M("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D;F5W(#T@87)R87DH#0H@("`@("`@("`@("`@("`@)VYA;64G
M(#T^("1M86EN=&%I;F5R6R=N86UE)UTL#0H@("`@("`@("`@("`@("`@)W5S
M97(G(#T^("1M86EN=&%I;F5R6R=H86YD;&4G72P-"B`@("`@("`@("`@("`@
M("`G96UA:6PG(#T^("1M86EN=&%I;F5R6R=E;6%I;"==+`T*("`@("`@("`@
M("`@("`@("=A8W1I=F4G(#T^("=Y97,G+`T*("`@("`@("`@("`@*3L-"B`@
M("`@("`@("`@("1A<G);)VQE860G75M=(#T@)&YE=SL-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H(6ES<V5T*"1A<G);)VQE860G72DI('L@+R\@<V]M92!P
M96]P;&4N+BX@>6]U(&MN;W<_#0H@("`@("`@("`@("`D87)R6R=L96%D)UT@
M/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`G;F%M92<@/3X@)W5N:VYO=VXG
M+`T*("`@("`@("`@("`@("`@("=U<V5R)R`]/B`G=6YK;F]W;B<L#0H@("`@
M("`@("`@("`@("`@)V5M86EL)R`]/B`G;F]L96%D;6%I;G1A:6YE<D!E>&%M
M<&QE+F-O;2<L#0H@("`@("`@("`@("`@("`@)V%C=&EV92<@/3X@)VYO)RP-
M"B`@("`@("`@("`@("D[#0H@("`@("`@('T-"B`@("`@("`@:68@*&-O=6YT
M*"1A<G);)VQE860G72D@/3T@,2D@>PT*("`@("`@("`@("`@)&%R<ELG;&5A
M9"==(#T@)&%R<ELG;&5A9"==6S!=.PT*("`@("`@("!]#0H@("`@("`@(&9O
M<F5A8V@@*"1M86EN=&%I;F5R<R!A<R`D;6%I;G1A:6YE<BD@>PT*("`@("`@
M("`@("`@:68@*"1M86EN=&%I;F5R6R=R;VQE)UT@/3T@)VQE860G*2![#0H@
M("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D;F5W(#T@87)R87DH#0H@("`@("`@("`@("`@("`@)VYA;64G
M(#T^("1M86EN=&%I;F5R6R=N86UE)UTL#0H@("`@("`@("`@("`@("`@)W5S
M97(G(#T^("1M86EN=&%I;F5R6R=H86YD;&4G72P-"B`@("`@("`@("`@("`@
M("`G96UA:6PG(#T^("1M86EN=&%I;F5R6R=E;6%I;"==+`T*("`@("`@("`@
M("`@("`@("=A8W1I=F4G(#T^("=Y97,G+`T*("`@("`@("`@("`@*3L-"B`@
M("`@("`@("`@("1A<G);)&UA:6YT86EN97);)W)O;&4G75U;72`]("1N97<[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1A<G);)V1E=F5L;W!E
M<B==*2`F)B!C;W5N="@D87)R6R=D979E;&]P97(G72D@/3T@,2D@>PT*("`@
M("`@("`@("`@)&%R<ELG9&5V96QO<&5R)UT@/2`D87)R6R=D979E;&]P97(G
M75LP73L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&%R<ELG8V]N
M=')I8G5T;W(G72D@)B8@8V]U;G0H)&%R<ELG8V]N=')I8G5T;W(G72D@/3T@
M,2D@>PT*("`@("`@("`@("`@)&%R<ELG8V]N=')I8G5T;W(G72`]("1A<G);
M)V-O;G1R:6)U=&]R)UU;,%T[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES
M<V5T*"1A<G);)VAE;'!E<B==*2`F)B!C;W5N="@D87)R6R=H96QP97(G72D@
M/3T@,2D@>PT*("`@("`@("`@("`@)&%R<ELG:&5L<&5R)UT@/2`D87)R6R=H
M96QP97(G75LP73L-"B`@("`@("`@?0T*("`@("`@("`D87)R6R=D871E)UT@
M/2`D=&AI<RT^7W!A8VMA9V5F:6QE+3YG971$871E*"D[#0H@("`@("`@("1A
M<G);)W9E<G-I;VXG72`]#0H@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`G<F5L96%S92<@/3X@)'1H:7,M/E]P86-K86=E9FEL92T^9V5T
M5F5R<VEO;B@I+`T*("`@("`@("`@("`@("`@("=A<&DG(#T^("1T:&ES+3Y?
M<&%C:V%G969I;&4M/F=E=%9E<G-I;VXH*2P-"B`@("`@("`@("`@("D[#0H@
M("`@("`@("1A<G);)W-T86)I;&ET>2==(#T-"B`@("`@("`@("`@(&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("=R96QE87-E)R`]/B`D=&AI<RT^7W!A8VMA
M9V5F:6QE+3YG9713=&%T92@I+`T*("`@("`@("`@("`@("`@("=A<&DG(#T^
M("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=%-T871E*"DL#0H@("`@("`@("`@
M("`I.PT*("`@("`@("`D;&EC96YS96UA<"`]#0H@("`@("`@("`@("!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`G<&AP)R`]/B`G:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4G+`T*("`@("`@("`@("`@("`@("=P:'`@;&EC96YS92<@
M/3X@)VAT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E)RP-"B`@("`@("`@("`@
M("`@("`G;&=P;"<@/3X@)VAT='`Z+R]W=W<N9VYU+F]R9R]C;W!Y;&5F="]L
M97-S97(N:'1M;"<L#0H@("`@("`@("`@("`@("`@)V)S9"<@/3X@)VAT='`Z
M+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP
M)RP-"B`@("`@("`@("`@("`@("`G8G-D('-T>6QE)R`]/B`G:'1T<#HO+W=W
M=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`G+`T*
M("`@("`@("`@("`@("`@("=B<V0M<W1Y;&4G(#T^("=H='1P.B\O=W=W+F]P
M96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"<L#0H@("`@
M("`@("`@("`@("`@)VUI="<@/3X@)VAT='`Z+R]W=W<N;W!E;G-O=7)C92YO
M<F<O;&EC96YS97,O;6ET+6QI8V5N<V4N<&AP)RP-"B`@("`@("`@("`@("`@
M("`G9W!L)R`]/B`G:'1T<#HO+W=W=RYG;G4N;W)G+V-O<'EL969T+V=P;"YH
M=&UL)RP-"B`@("`@("`@("`@("`@("`G87!A8VAE)R`]/B`G:'1T<#HO+W=W
M=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]A<&%C:&4R+C`N<&AP)PT*("`@
M("`@("`@("`@*3L-"B`@("`@("`@:68@*&ES<V5T*"1L:6-E;G-E;6%P6W-T
M<G1O;&]W97(H)'1H:7,M/E]P86-K86=E9FEL92T^9V5T3&EC96YS92@I*5TI
M*2![#0H@("`@("`@("`@("`D87)R6R=L:6-E;G-E)UT@/2!A<G)A>2@-"B`@
M("`@("`@("`@("`@("`G871T<FEB<R<@/3X@87)R87DH)W5R:2<@/3X-"B`@
M("`@("`@("`@("`@("`@("`@)&QI8V5N<V5M87!;<W1R=&]L;W=E<B@D=&AI
M<RT^7W!A8VMA9V5F:6QE+3YG971,:6-E;G-E*"DI72DL#0H@("`@("`@("`@
M("`@("`@)U]C;VYT96YT)R`]/B`D=&AI<RT^7W!A8VMA9V5F:6QE+3YG971,
M:6-E;G-E*"D-"B`@("`@("`@("`@("`@("`I.PT*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@+R\@9&]N)W0@=7-E(&)O9W5S('5R:0T*("`@("`@
M("`@("`@)&%R<ELG;&EC96YS92==(#T@)'1H:7,M/E]P86-K86=E9FEL92T^
M9V5T3&EC96YS92@I.PT*("`@("`@("!]#0H@("`@("`@("1A<G);)VYO=&5S
M)UT@/2`D=&AI<RT^7W!A8VMA9V5F:6QE+3YG971.;W1E<R@I.PT*("`@("`@
M("`D=&5M<"`](&%R<F%Y*"D[#0H@("`@("`@("1A<G);)V-O;G1E;G1S)UT@
M/2`D=&AI<RT^7V-O;G9E<G1&:6QE;&ES=#)?,"@D=&5M<"D[#0H@("`@("`@
M("1T:&ES+3Y?8V]N=F5R=$1E<&5N9&5N8VEE<S)?,"@D87)R*3L-"B`@("`@
M("`@)')E;&5A<V4@/2`H)'1H:7,M/E]P86-K86=E9FEL92T^9V5T0V]N9FEG
M=7)E3W!T:6]N<R@I('Q\("1T:&ES+3Y?:7-%>'1E;G-I;VXI(#\-"B`@("`@
M("`@("`@("=E>'1S<F-R96QE87-E)R`Z("=P:'!R96QE87-E)SL-"B`@("`@
M("`@:68@*"1R96QE87-E(#T]("=E>'1S<F-R96QE87-E)RD@>PT*("`@("`@
M("`@("`@)&%R<ELG8VAA;FYE;"==(#T@)W!E8VPN<&AP+FYE="<[#0H@("`@
M("`@("`@("`D87)R6R=P<F]V:61E<V5X=&5N<VEO;B==(#T@)&%R<ELG;F%M
M92==.R`O+R!A<W-U;7!T:6]N#0H@("`@("`@('T-"B`@("`@("`@)&%R<ELD
M<F5L96%S95T@/2!A<G)A>2@I.PT*("`@("`@("!I9B`H)'1H:7,M/E]P86-K
M86=E9FEL92T^9V5T0V]N9FEG=7)E3W!T:6]N<R@I*2![#0H@("`@("`@("`@
M("`D87)R6R1R96QE87-E75LG8V]N9FEG=7)E;W!T:6]N)UT@/2`D=&AI<RT^
M7W!A8VMA9V5F:6QE+3YG971#;VYF:6=U<F5/<'1I;VYS*"D[#0H@("`@("`@
M("`@("!F;W)E86-H("@D87)R6R1R96QE87-E75LG8V]N9FEG=7)E;W!T:6]N
M)UT@87,@)&D@/3X@)&]P="D@>PT*("`@("`@("`@("`@("`@("1A<G);)')E
M;&5A<V5=6R=C;VYF:6=U<F5O<'1I;VXG75LD:5T@/2!A<G)A>2@G871T<FEB
M<R<@/3X@)&]P="D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M8V]U;G0H)&%R<ELD<F5L96%S95U;)V-O;F9I9W5R96]P=&EO;B==*2`]/2`Q
M*2![#0H@("`@("`@("`@("`@("`@)&%R<ELD<F5L96%S95U;)V-O;F9I9W5R
M96]P=&EO;B==(#T@)&%R<ELD<F5L96%S95U;)V-O;F9I9W5R96]P=&EO;B==
M6S!=.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1T:&ES
M+3Y?8V]N=F5R=%)E;&5A<V4R7S`H)&%R<ELD<F5L96%S95TL("1T96UP*3L-
M"B`@("`@("`@:68@*"1R96QE87-E(#T]("=E>'1S<F-R96QE87-E)R`F)B!C
M;W5N="@D87)R6R1R96QE87-E72D@/B`Q*2![#0H@("`@("`@("`@("`O+R!M
M=6QT:7!L92!E>'1S<F-R96QE87-E('1A9W,@861D960@:6X@4$5!4B`Q+C0N
M,0T*("`@("`@("`@("`@)&%R<ELG9&5P96YD96YC:65S)UU;)W)E<75I<F5D
M)UU;)W!E87)I;G-T86QL97(G75LG;6EN)UT@/2`G,2XT+C$G.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@D8VP@/2`D=&AI<RT^7W!A8VMA9V5F:6QE+3YG
M971#:&%N9V5L;V<H*2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H)&-L(&%S
M("1R96QE87-E*2![#0H@("`@("`@("`@("`@("`@)')E;"`](&%R<F%Y*"D[
M#0H@("`@("`@("`@("`@("`@)')E;%LG=F5R<VEO;B==(#T-"B`@("`@("`@
M("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`G
M<F5L96%S92<@/3X@)')E;&5A<V5;)W9E<G-I;VXG72P-"B`@("`@("`@("`@
M("`@("`@("`@("`@("=A<&DG(#T^("1R96QE87-E6R=V97)S:6]N)UTL#0H@
M("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D<F5L96%S95LG<F5L96%S95]S=&%T92==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D<F5L96%S95LG<F5L96%S95]S=&%T92==(#T@)W-T86)L
M92<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1R96Q;
M)W-T86)I;&ET>2==(#T-"B`@("`@("`@("`@("`@("`@("`@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("`@("`G<F5L96%S92<@/3X@)')E;&5A<V5;
M)W)E;&5A<V5?<W1A=&4G72P-"B`@("`@("`@("`@("`@("`@("`@("`@("=A
M<&DG(#T^("1R96QE87-E6R=R96QE87-E7W-T871E)UTL#0H@("`@("`@("`@
M("`@("`@("`@("D[#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1R96QE
M87-E6R=R96QE87-E7V1A=&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M)')E;%LG9&%T92==(#T@)')E;&5A<V5;)W)E;&5A<V5?9&%T92==.PT*("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1R
M96Q;)V1A=&4G72`](&1A=&4H)UDM;2UD)RD[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<F5L96%S95LG<F5L96%S
M95]L:6-E;G-E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D;&EC96YS96UA<%MS=')T;VQO=V5R*"1R96QE87-E6R=R96QE87-E7VQI
M8V5N<V4G72E=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'5R:2`]
M("1L:6-E;G-E;6%P6W-T<G1O;&]W97(H)')E;&5A<V5;)W)E;&5A<V5?;&EC
M96YS92==*5T[#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D=7)I(#T@)VAT='`Z+R]W=W<N97AA;7!L
M92YC;VTG.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("1R96Q;)VQI8V5N<V4G72`](&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=A='1R:6)S)R`]/B!A<G)A>2@G=7)I)R`]/B`D
M=7)I*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G7V-O;G1E;G0G
M(#T^("1R96QE87-E6R=R96QE87-E7VQI8V5N<V4G70T*("`@("`@("`@("`@
M("`@("`@("`@("`@*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`D<F5L6R=L:6-E;G-E)UT@/2`D87)R6R=L:6-E
M;G-E)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)')E;&5A<V5;)W)E;&5A<V5?;F]T97,G72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@)')E;&5A<V5;)W)E;&5A<V5?;F]T97,G72`]("=N
M;R!R96QE87-E(&YO=&5S)SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@)')E;%LG;F]T97,G72`]("1R96QE87-E6R=R96QE87-E7VYO
M=&5S)UT[#0H@("`@("`@("`@("`@("`@)&%R<ELG8VAA;F=E;&]G)UU;)W)E
M;&5A<V4G75M=(#T@)')E;#L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("`D<F5T(#T@;F5W("1C;&%S<SL-"B`@("`@("`@)')E="T^<V5T
M0V]N9FEG*"1T:&ES+3Y?<&%C:V%G969I;&4M/E]C;VYF:6<I.PT*("`@("`@
M("`D<F5T+3YS971,;V=G97(H)'1H:7,M/E]P86-K86=E9FEL92T^7VQO9V=E
M<BD[#0H@("`@("`@("1R970M/F9R;VU!<G)A>2@D87)R*3L-"B`@("`@("`@
M<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M
M(&%R<F%Y#0H@("`@("H@0'!A<F%M(&)O;VP-"B`@("`@*B!`86-C97-S('!R
M:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?8V]N=F5R=$1E<&5N9&5N
M8VEE<S)?,"@F)')E;&5A<V4L("1I;G1E<FYA;"`](&9A;'-E*0T*("`@('L-
M"B`@("`@("`@)'!E87)D97`@/2!A<G)A>2@G<&5A<FEN<W1A;&QE<B<@/3X-
M"B`@("`@("`@("`@(&%R<F%Y*"=M:6XG(#T^("<Q+C0N,&(Q)RDI.R`O+R!T
M:&ES(&ES(&$@;&]T('-A9F5R#0H@("`@("`@("1R97%U:7)E9"`]("1O<'1I
M;VYA;"`](&%R<F%Y*"D[#0H@("`@("`@("1R96QE87-E6R=D97!E;F1E;F-I
M97,G72`](&%R<F%Y*"D[#0H@("`@("`@(&EF("@D=&AI<RT^7W!A8VMA9V5F
M:6QE+3YH87-$97!S*"DI('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3Y?<&%C:V%G969I;&4M/F=E=$1E<',H*2!A<R`D9&5P*2![#0H@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D9&5P6R=O<'1I;VYA;"==*2!\?"`D9&5P
M6R=O<'1I;VYA;"==(#T]("=N;R<I('L-"B`@("`@("`@("`@("`@("`@("`@
M)')E<75I<F5D6UT@/2`D9&5P.PT*("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("1O<'1I;VYA;%M=(#T@)&1E<#L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F
M;W)E86-H("AA<G)A>2@G<F5Q=6ER960G+"`G;W!T:6]N86PG*2!A<R`D87)R
M*2![#0H@("`@("`@("`@("`@("`@)&1E<',@/2!A<G)A>2@I.PT*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"0D87)R(&%S("1D97`I('L-"B`@("`@("`@
M("`@("`@("`@("`@+R\@;W)G86YI>F4@9&5P<R!B>2!D97!E;F1E;F-Y('1Y
M<&4@86YD(&YA;64-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M9&5P<ULD9&5P6R=T>7!E)UU=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)&1E<'-;)&1E<%LG='EP92==72`](&%R<F%Y*"D[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D
M97!;)VYA;64G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1D97!S
M6R1D97!;)W1Y<&4G75U;)&1E<%LG;F%M92==75M=(#T@)&1E<#L-"B`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1D97!S6R1D97!;)W1Y<&4G75U;72`]("1D97`[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@9&\@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<'-;
M)W!H<"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'!H<"`](&%R
M<F%Y*"D[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)&1E
M<'-;)W!H<"==*2`^(#$I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<&AP(#T@)'1H:7,M/E]P<F]C97-S4&AP1&5P<R@D9&5P<ULG<&AP)UTI
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!S6R=P:'`G75LP
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;&ES="@D
M:V5Y+"`D8FQA:"D@/2!E86-H("@D9&5P<ULG<&AP)UTI.R`O+R!S='5P:60@
M8G5G9WD@=F5R<VEO;G,-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&1E<'-;)W!H<"==(#T@87)R87DH)&)L86A;,%TI.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&AP(#T@)'1H:7,M/E]P<F]C97-S1&5P*"1D97!S6R=P:'`G75LP
M72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"$D<&AP*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.R`O+R!P
M;V]R(&UA;G,@=&AR;W<-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5L96%S95LG9&5P96YD96YC:65S)UU;)&%R<EU;)W!H<"==
M(#T@)'!H<#L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@('T@=VAI;&4@*&9A;'-E*3L-"B`@("`@("`@("`@("`@("!D;R![#0H@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P<ULG<&MG)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&MG(#T@87)R87DH*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1P:V<@/2`D=&AI<RT^7W!R;V-E<W--
M=6QT:7!L941E<'-.86UE*"1D97!S6R=P:V<G72D[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H(21P:V<I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL@+R\@<&]O<B!M86YS('1H<F]W#0H@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5L
M96%S95LG9&5P96YD96YC:65S)UU;)&%R<EU;)W!A8VMA9V4G72`]("1P:V<[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]('=H
M:6QE("AF86QS92D[#0H@("`@("`@("`@("`@("`@9&\@>PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&1E<'-;)V5X="==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'!K9R`](&%R<F%Y*"D[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D<&MG(#T@)'1H:7,M/E]P<F]C97-S375L=&EP;&5$
M97!S3F%M92@D9&5P<ULG97AT)UTI.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)')E;&5A<V5;)V1E<&5N9&5N8VEE<R==6R1A<G)=6R=E>'1E;G-I;VXG
M72`]("1P:V<[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!]('=H:6QE("AF86QS92D[#0H@("`@("`@("`@("`@("`@+R\@<VMI
M<"!S87!I("T@:70G<R!N;W0@<W5P<&]R=&5D('-O(&YO8F]D>2!W:6QL(&AA
M=F4@=7-E9"!I=`T*("`@("`@("`@("`@("`@("\O('-K:7`@;W,@+2!I="=S
M(&YO="!S=7!P;W)T960@:6X@,2XP#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1R96QE87-E6R=D97!E;F1E;F-I97,G
M75LG<F5Q=6ER960G72DI('L-"B`@("`@("`@("`@("1R96QE87-E6R=D97!E
M;F1E;F-I97,G75LG<F5Q=6ER960G72`]#0H@("`@("`@("`@("`@("`@87)R
M87E?;65R9V4H)'!E87)D97`L("1R96QE87-E6R=D97!E;F1E;F-I97,G75LG
M<F5Q=6ER960G72D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M<F5L96%S95LG9&5P96YD96YC:65S)UU;)W)E<75I<F5D)UT@/2`D<&5A<F1E
M<#L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES<V5T*"1R96QE87-E6R=D
M97!E;F1E;F-I97,G75LG<F5Q=6ER960G75LG<&AP)UTI*2![#0H@("`@("`@
M("`@("`D<F5L96%S95LG9&5P96YD96YC:65S)UU;)W)E<75I<F5D)UU;)W!H
M<"==(#T-"B`@("`@("`@("`@("`@("!A<G)A>2@G;6EN)R`]/B`G-"XP+C`G
M*3L-"B`@("`@("`@?0T*("`@("`@("`D;W)D97(@/2!A<G)A>2@I.PT*("`@
M("`@("`D8F5W;2`]("1R96QE87-E6R=D97!E;F1E;F-I97,G75LG<F5Q=6ER
M960G73L-"B`@("`@("`@)&]R9&5R6R=P:'`G72`]("1B97=M6R=P:'`G73L-
M"B`@("`@("`@)&]R9&5R6R=P96%R:6YS=&%L;&5R)UT@/2`D8F5W;5LG<&5A
M<FEN<W1A;&QE<B==.PT*("`@("`@("!I<W-E="@D8F5W;5LG<&%C:V%G92==
M*2`_("1O<F1E<ELG<&%C:V%G92==(#T@)&)E=VU;)W!A8VMA9V4G72`Z,#L-
M"B`@("`@("`@:7-S970H)&)E=VU;)V5X=&5N<VEO;B==*2`_("1O<F1E<ELG
M97AT96YS:6]N)UT@/2`D8F5W;5LG97AT96YS:6]N)UT@.C`[#0H@("`@("`@
M("1R96QE87-E6R=D97!E;F1E;F-I97,G75LG<F5Q=6ER960G72`]("1O<F1E
M<CL-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@87)R87D-"B`@
M("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?
M8V]N=F5R=$9I;&5L:7-T,E\P*"8D<&%C:V%G92D-"B`@("![#0H@("`@("`@
M("1R970@/2!A<G)A>2@G9&ER)R`]/@T*("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("=A='1R:6)S)R`]/B!A
M<G)A>2@G;F%M92<@/3X@)R\G*2P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("=F:6QE)R`]/B!A<G)A>2@I#0H@("`@("`@("`@("`@("`@("`@("`@("`I
M#0H@("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@("1P86-K86=E6R=P
M;&%T9F]R;2==(#T-"B`@("`@("`@)'!A8VMA9V5;)VEN<W1A;&PM87,G72`]
M(&%R<F%Y*"D[#0H@("`@("`@("1T:&ES+3Y?:7-%>'1E;G-I;VX@/2!F86QS
M93L-"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P86-K86=E9FEL92T^9V5T
M1FEL96QI<W0H*2!A<R`D;F%M92`]/B`D9FEL92D@>PT*("`@("`@("`@("`@
M)&9I;&5;)VYA;64G72`]("1N86UE.PT*("`@("`@("`@("`@:68@*&ES<V5T
M*"1F:6QE6R=R;VQE)UTI("8F("1F:6QE6R=R;VQE)UT@/3T@)W-R8R<I('L-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7VES17AT96YS:6]N(#T@=')U93L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D9FEL95LG
M<F5P;&%C96UE;G1S)UTI*2![#0H@("`@("`@("`@("`@("`@)')E<&P@/2`D
M9FEL95LG<F5P;&%C96UE;G1S)UT[#0H@("`@("`@("`@("`@("`@=6YS970H
M)&9I;&5;)W)E<&QA8V5M96YT<R==*3L-"B`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@=6YS970H)')E<&PI.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1F:6QE6R=I;G-T86QL+6%S)UTI
M*2![#0H@("`@("`@("`@("`@("`@)'!A8VMA9V5;)VEN<W1A;&PM87,G75LD
M;F%M95T@/2`D9FEL95LG:6YS=&%L;"UA<R==.PT*("`@("`@("`@("`@("`@
M('5N<V5T*"1F:6QE6R=I;G-T86QL+6%S)UTI.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*&ES<V5T*"1F:6QE6R=P;&%T9F]R;2==*2D@>PT*
M("`@("`@("`@("`@("`@("1P86-K86=E6R=P;&%T9F]R;2==6R1N86UE72`]
M("1F:6QE6R=P;&%T9F]R;2==.PT*("`@("`@("`@("`@("`@('5N<V5T*"1F
M:6QE6R=P;&%T9F]R;2==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("1F:6QE(#T@87)R87DH)V%T=')I8G,G(#T^("1F:6QE*3L-"B`@("`@("`@
M("`@(&EF("AI<W-E="@D<F5P;"DI('L-"B`@("`@("`@("`@("`@("!F;W)E
M86-H("@D<F5P;"!A<R`D<F5P;&%C92`I('L-"B`@("`@("`@("`@("`@("`@
M("`@)&9I;&5;)W1A<VMS.G)E<&QA8V4G75M=(#T@87)R87DH)V%T=')I8G,G
M(#T^("1R97!L86-E*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@:68@*&-O=6YT*"1R97!L*2`]/2`Q*2![#0H@("`@("`@("`@("`@
M("`@("`@("1F:6QE6R=T87-K<SIR97!L86-E)UT@/2`D9FEL95LG=&%S:W,Z
M<F5P;&%C92==6S!=.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("1R971;)V1I<B==6R=F:6QE)UU;72`]("1F:6QE
M.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("`J(%!O<W0M<')O8V5S<R!S<&5C:6%L(&9I;&5S('=I
M=&@@:6YS=&%L;"UA<R]P;&%T9F]R;2!A='1R:6)U=&5S(&%N9`T*("`@("`J
M(&UA:V4@=&AE(')E;&5A<V4@=&%G+@T*("`@("`J(`T*("`@("`J(%1H:7,@
M8V]M<&QE>"!M971H;V0@9F]L;&]W<R!T:&ES('=O<FLM9FQO=R!T;R!C<F5A
M=&4@=&AE(')E;&5A<V4@=&%G<SH-"B`@("`@*B`-"B`@("`@*B`\<')E/@T*
M("`@("`J("T@:68@86YY(&EN<W1A;&PM87,O<&QA=&9O<FT@97AI<W0L(&-R
M96%T92!A(&=E;F5R:6,@<F5L96%S92!A;F0@9FEL;"!I="!W:71H#0H@("`@
M("H@("!O(#QI;G-T86QL(&%S/2XN/B!T86=S(&9O<B`\9FEL92!N86UE/2XN
M+B!I;G-T86QL+6%S/2XN+CX-"B`@("`@*B`@(&\@/&EN<W1A;&P@87,]+BX^
M('1A9W,@9F]R(#QF:6QE(&YA;64]+BXN('!L871F;W)M/2$N+BX@:6YS=&%L
M;"UA<STN+CX-"B`@("`@*B`@(&\@/&EG;F]R93X@=&%G<R!F;W(@/&9I;&4@
M;F%M93TN+BX@<&QA=&9O<FT]+BXN/@T*("`@("`J("`@;R`\:6=N;W)E/B!T
M86=S(&9O<B`\9FEL92!N86UE/2XN+B!P;&%T9F]R;3TN+BX@:6YS=&%L;"UA
M<STN+CX-"B`@("`@*B`M(&-R96%T92!A(')E;&5A<V4@9F]R(&5A8V@@<&QA
M=&9O<FT@96YC;W5N=&5R960@86YD(&9I;&P@=VET:`T*("`@("`J("`@;R`\
M:6YS=&%L;"!A<RXN/B!T86=S(&9O<B`\9FEL92!N86UE/2XN+B!I;G-T86QL
M+6%S/2XN+CX-"B`@("`@*B`@(&\@/&EN<W1A;&P@87,N+CX@=&%G<R!F;W(@
M/&9I;&4@;F%M93TN+BX@<&QA=&9O<FT]=&AI<R!P;&%T9F]R;2!I;G-T86QL
M+6%S/2XN/@T*("`@("`J("`@;R`\:6YS=&%L;"!A<RXN/B!T86=S(&9O<B`\
M9FEL92!N86UE/2XN+B!P;&%T9F]R;3TA;W1H97(@<&QA=&9O<FT@:6YS=&%L
M;"UA<STN+CX-"B`@("`@*B`@(&\@/&EG;F]R93X@=&%G<R!F;W(@/&9I;&4@
M;F%M93TN+BX@<&QA=&9O<FT](71H:7,@<&QA=&9O<FT^#0H@("`@("H@("!O
M(#QI9VYO<F4^('1A9W,@9F]R(#QF:6QE(&YA;64]+BXN('!L871F;W)M/6]T
M:&5R('!L871F;W)M/@T*("`@("`J("`@;R`\:6=N;W)E/B!T86=S(&9O<B`\
M9FEL92!N86UE/2XN+B!P;&%T9F]R;3UO=&AE<B!P;&%T9F]R;2!I;G-T86QL
M+6%S/2XN/@T*("`@("`J("`@;R`\:6=N;W)E/B!T86=S(&9O<B`\9FEL92!N
M86UE/2XN+B!P;&%T9F]R;3TA=&AI<R!P;&%T9F]R;2!I;G-T86QL+6%S/2XN
M/@T*("`@("`J(#PO<')E/@T*("`@("`J(`T*("`@("`J($ET(&1O97,@=&AI
M<R!B>2!A8V-E<W-I;F<@=&AE("1P86-K86=E('!A<F%M971E<BP@=VAI8V@@
M8V]N=&%I;G,@86X@87)R87D@=VET:`T*("`@("`J(&EN9&EC97,Z#0H@("`@
M("H@#0H@("`@("H@("T@<&QA=&9O<FTZ(&UA<'!I;F<@;V8@9FEL92`]/B!/
M4R!T:&4@9FEL92!S:&]U;&0@8F4@:6YS=&%L;&5D(&]N#0H@("`@("H@("T@
M:6YS=&%L;"UA<SH@;6%P<&EN9R!O9B!F:6QE(#T^(&EN<W1A;&QE9"!N86UE
M#0H@("`@("H@("T@;W-M87`Z(&UA<'!I;F<@;V8@3U,@/3X@;&ES="!O9B!F
M:6QE<R!T:&%T('-H;W5L9"!B92!I;G-T86QL960-"B`@("`@*B`@("!O;B!T
M:&%T($]3#0H@("`@("H@("T@;F]T;W-M87`Z(&UA<'!I;F<@;V8@3U,@/3X@
M;&ES="!O9B!F:6QE<R!T:&%T('-H;W5L9"!N;W0@8F4-"B`@("`@*B`@("!I
M;G-T86QL960@;VX@=&AA="!/4PT*("`@("`J#0H@("`@("H@0'!A<F%M(&%R
M<F%Y#0H@("`@("H@0'!A<F%M(&%R<F%Y#0H@("`@("H@0&%C8V5S<R!P<FEV
M871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V-O;G9E<G1296QE87-E,E\P
M*"8D<F5L96%S92P@)'!A8VMA9V4I#0H@("`@>PT*("`@("`@("`O+RT@:68@
M86YY(&EN<W1A;&PM87,O<&QA=&9O<FT@97AI<W0L(&-R96%T92!A(&=E;F5R
M:6,@<F5L96%S92!A;F0@9FEL;"!I="!W:71H(`T*("`@("`@("!I9B`H8V]U
M;G0H)'!A8VMA9V5;)W!L871F;W)M)UTI('Q\(&-O=6YT*"1P86-K86=E6R=I
M;G-T86QL+6%S)UTI*2![#0H@("`@("`@("`@("`D9V5N97)I8R`](&%R<F%Y
M*"D[#0H@("`@("`@("`@("`D9V5N97)I8TEG;F]R92`](&%R<F%Y*"D[#0H@
M("`@("`@("`@("!F;W)E86-H("@D<&%C:V%G95LG:6YS=&%L;"UA<R==(&%S
M("1F:6QE(#T^("1A<RD@>PT*("`@("`@("`@("`@("`@("\O;R`\:6YS=&%L
M;"!A<STN+CX@=&%G<R!F;W(@/&9I;&4@;F%M93TN+BX@:6YS=&%L;"UA<STN
M+BX^#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<&%C:V%G95LG<&QA
M=&9O<FTG75LD9FEL95TI*2![#0H@("`@("`@("`@("`@("`@("`@("1G96YE
M<FEC6UT@/2`D9FEL93L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("\O;R`\:6YS
M=&%L;"!A<STN+CX@=&%G<R!F;W(@/&9I;&4@;F%M93TN+BX@<&QA=&9O<FT]
M(2XN+B!I;G-T86QL+6%S/2XN/@T*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D<&%C:V%G95LG<&QA=&9O<FTG75LD9FEL95TI("8F#0H@("`@("`@("`@
M("`@("`@("`@("`@)'!A8VMA9V5;)W!L871F;W)M)UU;)&9I;&5=>S!](#T]
M("<A)RD@>PT*("`@("`@("`@("`@("`@("`@("`D9V5N97)I8UM=(#T@)&9I
M;&4[#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`O+V\@/&EG;F]R93X@=&%G<R!F
M;W(@/&9I;&4@;F%M93TN+BX@<&QA=&9O<FT]+BXN(&EN<W1A;&PM87,]+BX^
M#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P86-K86=E6R=P;&%T9F]R
M;2==6R1F:6QE72D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`D<&%C:V%G
M95LG<&QA=&9O<FTG75LD9FEL95U[,'T@(3T@)R$G*2![#0H@("`@("`@("`@
M("`@("`@("`@("1G96YE<FEC26=N;W)E6UT@/2`D9FEL93L-"B`@("`@("`@
M("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)'!A8VMA9V5;)W!L
M871F;W)M)UT@87,@)&9I;&4@/3X@)'!L871F;W)M*2![#0H@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1P86-K86=E6R=I;G-T86QL+6%S)UU;)&9I;&5=
M*2D@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1P;&%T9F]R;7LP?2`A
M/2`G(2<I('L-"B`@("`@("`@("`@("`@("`@("`@+R]O(#QI9VYO<F4^('1A
M9W,@9F]R(#QF:6QE(&YA;64]+BXN('!L871F;W)M/2XN+CX-"B`@("`@("`@
M("`@("`@("`@("`@)&=E;F5R:6-)9VYO<F5;72`]("1F:6QE.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AC
M;W5N="@D<&%C:V%G95LG<&QA=&9O<FTG72DI('L-"B`@("`@("`@("`@("`@
M("`D;W-E<R`]("1N;W1P;&%T9F]R;2`]("1P;&%T9F]R;2`](&%R<F%Y*"D[
M#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!A8VMA9V5;)W!L871F;W)M
M)UT@87,@)&9I;&4@/3X@)&]S*2![#0H@("`@("`@("`@("`@("`@("`@("\O
M(&=E="!A(&QI<W0@;V8@;W-E<PT*("`@("`@("`@("`@("`@("`@("!I9B`H
M)&]S>S!](#T]("<A)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1O<V5S6W-U8G-T<B@D;W,L(#$I72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1O<V5S6W-U8G-T
M<B@D;W,L(#$I72`](&-O=6YT*"1O<V5S*3L-"B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D;W-E<ULD;W-=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@)&]S97-;)&]S72`](&-O=6YT*"1O<V5S*3L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`O+RT@8W)E871E(&$@<F5L96%S92!F;W(@96%C:"!P
M;&%T9F]R;2!E;F-O=6YT97)E9"!A;F0@9FEL;"!W:71H#0H@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)&]S97,@87,@)&]S(#T^("1R96QE87-E3G5M*2![
M#0H@("`@("`@("`@("`@("`@("`@("1R96QE87-E6R1R96QE87-E3G5M75LG
M:6YS=&%L;&-O;F1I=&EO;G,G75LG;W,G75LG;F%M92==(#T@)&]S.PT*("`@
M("`@("`@("`@("`@("`@("`D<F5L96%S95LD<F5L96%S94YU;5U;)V9I;&5L
M:7-T)UT@/2!A<G)A>2@G:6YS=&%L;"<@/3X@87)R87DH*2P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("=I9VYO<F4G(#T^(&%R<F%Y*"DI.PT*("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("@D<&%C:V%G95LG:6YS=&%L;"UA<R==
M(&%S("1F:6QE(#T^("1A<RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M+R]O(#QI;G-T86QL(&%S/2XN/B!T86=S(&9O<B`\9FEL92!N86UE/2XN+B!I
M;G-T86QL+6%S/2XN+CX-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)'!A8VMA9V5;)W!L871F;W)M)UU;)&9I;&5=*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1R96QE87-E6R1R96QE87-E3G5M75LG
M9FEL96QI<W0G75LG:6YS=&%L;"==6UT@/0T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=A='1R:6)S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@)&9I;&4L
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%S
M)R`]/B`D87,L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@+R]O
M(#QI;G-T86QL(&%S+BX^('1A9W,@9F]R#0H@("`@("`@("`@("`@("`@("`@
M("`@("`O+R`@/&9I;&4@;F%M93TN+BX@<&QA=&9O<FT]=&AI<R!P;&%T9F]R
M;2!I;G-T86QL+6%S/2XN/@T*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1P86-K86=E6R=P;&%T9F]R;2==6R1F:6QE72D@)B8-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=P;&%T9F]R;2==
M6R1F:6QE72`]/2`D;W,I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<F5L96%S95LD<F5L96%S94YU;5U;)V9I;&5L:7-T)UU;)VEN<W1A;&PG
M75M=(#T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G871T<FEB
M<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VYA;64G(#T^("1F:6QE+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=A<R<@/3X@)&%S+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@("\O;R`\:6YS=&%L;"!A<RXN/B!T86=S
M(&9O<@T*("`@("`@("`@("`@("`@("`@("`@("`@+R\@(#QF:6QE(&YA;64]
M+BXN('!L871F;W)M/2%O=&AE<B!P;&%T9F]R;2!I;G-T86QL+6%S/2XN/@T*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P86-K86=E6R=P
M;&%T9F]R;2==6R1F:6QE72D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P86-K86=E6R=P;&%T9F]R;2==6R1F:6QE72`A/2`B(21O<R(@
M)B8-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=P
M;&%T9F]R;2==6R1F:6QE77LP?2`]/2`G(2<I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<F5L96%S95LD<F5L96%S94YU;5U;)V9I;&5L:7-T
M)UU;)VEN<W1A;&PG75M=(#T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G871T<FEB<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^("1F:6QE+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A<R<@/3X@)&%S
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*2P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("\O;R`\:6=N;W)E
M/B!T86=S(&9O<@T*("`@("`@("`@("`@("`@("`@("`@("`@+R\@(#QF:6QE
M(&YA;64]+BXN('!L871F;W)M/2%T:&ES('!L871F;W)M(&EN<W1A;&PM87,]
M+BX^#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA
M9V5;)W!L871F;W)M)UU;)&9I;&5=*2`F)@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'!A8VMA9V5;)W!L871F;W)M)UU;)&9I;&5=(#T]("(A
M)&]S(BD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R96QE87-E
M6R1R96QE87-E3G5M75LG9FEL96QI<W0G75LG:6=N;W)E)UU;72`]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%T=')I8G,G(#T^(&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N
M86UE)R`]/B`D9FEL92P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("D[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("`O+V\@/&EG;F]R93X@=&%G<R!F;W(-"B`@("`@("`@("`@("`@("`@("`@
M("`@("\O("`\9FEL92!N86UE/2XN+B!P;&%T9F]R;3UO=&AE<B!P;&%T9F]R
M;2!I;G-T86QL+6%S/2XN/@T*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1P86-K86=E6R=P;&%T9F]R;2==6R1F:6QE72D@)B8-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=P;&%T9F]R;2==
M6R1F:6QE77LP?2`A/2`G(2<@)B8-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P86-K86=E6R=P;&%T9F]R;2==6R1F:6QE72`A/2`D;W,I('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5L96%S95LD<F5L96%S
M94YU;5U;)V9I;&5L:7-T)UU;)VEG;F]R92==6UT@/0T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=A='1R:6)S)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@
M)&9I;&4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1P86-K86=E6R=P;&%T9F]R;2==(&%S
M("1F:6QE(#T^("1P;&%T9F]R;2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1P86-K86=E6R=I;G-T86QL+6%S)UU;)&9I;&5=*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@+R]O(#QI9VYO<F4^('1A9W,@9F]R(#QF:6QE(&YA;64]+BXN('!L871F
M;W)M/2%T:&ES('!L871F;W)M/@T*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"1P;&%T9F]R;2`]/2`B(21O<R(I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<F5L96%S95LD<F5L96%S94YU;5U;)V9I;&5L:7-T)UU;
M)VEG;F]R92==6UT@/0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=A='1R:6)S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G;F%M92<@/3X@)&9I;&4L#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`I.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@+R]O(#QI9VYO<F4^('1A9W,@9F]R(#QF
M:6QE(&YA;64]+BXN('!L871F;W)M/6]T:&5R('!L871F;W)M/@T*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"1P;&%T9F]R;7LP?2`A/2`G(2<@)B8@
M)'!L871F;W)M("$]("1O<RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1R96QE87-E6R1R96QE87-E3G5M75LG9FEL96QI<W0G75LG:6=N;W)E
M)UU;72`]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%T=')I
M8G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=N86UE)R`]/B`D9FEL92P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"%C
M;W5N="@D<F5L96%S95LD<F5L96%S94YU;5U;)V9I;&5L:7-T)UU;)VEN<W1A
M;&PG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1R96QE
M87-E6R1R96QE87-E3G5M75LG9FEL96QI<W0G75LG:6YS=&%L;"==*3L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H
M(6-O=6YT*"1R96QE87-E6R1R96QE87-E3G5M75LG9FEL96QI<W0G75LG:6=N
M;W)E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D<F5L
M96%S95LD<F5L96%S94YU;5U;)V9I;&5L:7-T)UU;)VEG;F]R92==*3L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!I9B`H8V]U;G0H)&=E;F5R:6,I('Q\(&-O=6YT*"1G96YE
M<FEC26=N;W)E*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<F5L96%S95MC
M;W5N="@D;W-E<RE=(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*&-O=6YT*"1G96YE<FEC*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)&=E;F5R:6,@87,@)&9I;&4I('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;)VEN<W1A;&PM
M87,G75LD9FEL95TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1I;G-T86QL87,@/2`D<&%C:V%G95LG:6YS=&%L;"UA<R==6R1F:6QE
M73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YS=&%L;&%S(#T@)&9I
M;&4[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1R96QE87-E6V-O=6YT*"1O<V5S*5U;)V9I
M;&5L:7-T)UU;)VEN<W1A;&PG75M=(#T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G871T<FEB<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^("1F:6QE+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A<R<@
M/3X@)&EN<W1A;&QA<RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("D-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)&=E;F5R:6-)
M9VYO<F4I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M9V5N97)I8TEG;F]R92!A<R`D9FEL92D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1R96QE87-E6V-O=6YT*"1O<V5S*5U;)V9I;&5L:7-T)UU;
M)VEG;F]R92==6UT@/0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=A='1R:6)S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G;F%M92<@/3X@)&9I;&4L#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`I#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@+R\@8VQE86YU<`T*("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1R96QE87-E(&%S("1I(#T^("1R96PI('L-"B`@("`@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1R96Q;)V9I;&5L:7-T)UU;)VEN<W1A;&PG
M72D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`@("`@8V]U;G0H)')E;%LG
M9FEL96QI<W0G75LG:6YS=&%L;"==*2`]/2`Q*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D<F5L96%S95LD:5U;)V9I;&5L:7-T)UU;)VEN<W1A;&PG
M72`]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E;&5A<V5;)&E=
M6R=F:6QE;&ES="==6R=I;G-T86QL)UU;,%T[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1R96Q;)V9I
M;&5L:7-T)UU;)VEG;F]R92==*2`F)@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("!C;W5N="@D<F5L6R=F:6QE;&ES="==6R=I9VYO<F4G72D@/3T@,2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E;&5A<V5;)&E=6R=F:6QE
M;&ES="==6R=I9VYO<F4G72`]#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)')E;&5A<V5;)&E=6R=F:6QE;&ES="==6R=I9VYO<F4G75LP73L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!I9B`H8V]U;G0H)')E;&5A<V4I(#T](#$I('L-"B`@("`@
M("`@("`@("`@("`@("`@)')E;&5A<V4@/2`D<F5L96%S95LP73L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("\O(&YO('!L871F;W)M(&%T=',L(&)U="!S;VUE(&EN<W1A;&PM
M87,@871T<PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1P86-K86=E6R=I
M;G-T86QL+6%S)UT@87,@)&9I;&4@/3X@)'9A;'5E*2![#0H@("`@("`@("`@
M("`@("`@("`@("1R96QE87-E6R=F:6QE;&ES="==6R=I;G-T86QL)UU;72`]
M#0H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G871T<FEB<R<@/3X@87)R87DH#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B`D9FEL92P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%S)R`]/B`D=F%L=64-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`I#0H@("`@("`@("`@("`@
M("`@("`@("`@("`I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!I9B`H8V]U;G0H)')E;&5A<V5;)V9I;&5L:7-T)UU;)VEN<W1A;&PG
M72D@/3T@,2D@>PT*("`@("`@("`@("`@("`@("`@("`D<F5L96%S95LG9FEL
M96QI<W0G75LG:6YS=&%L;"==(#T@)')E;&5A<V5;)V9I;&5L:7-T)UU;)VEN
M<W1A;&PG75LP73L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@
M87)R87D-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("H@0&%C8V5S<R!P
M<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7W!R;V-E<W-$97`H)&1E
M<"D-"B`@("![#0H@("`@("`@(&EF("@D9&5P6R=T>7!E)UT@/3T@)W!H<"<I
M('L-"B`@("`@("`@("`@(&EF("@D9&5P6R=R96PG72`]/2`G:&%S)RD@>PT*
M("`@("`@("`@("`@("`@("\O(&-O;64@;VX@+2!E=F5R>6]N92!H87,@<&AP
M(0T*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("`D<&AP(#T@87)R87DH*3L-"B`@("`@
M("`@:68@*"1D97!;)W1Y<&4G72`A/2`G<&AP)RD@>PT*("`@("`@("`@("`@
M)'!H<%LG;F%M92==(#T@)&1E<%LG;F%M92==.PT*("`@("`@("`@("`@:68@
M*"1D97!;)W1Y<&4G72`]/2`G<&MG)RD@>PT*("`@("`@("`@("`@("`@("1P
M:'!;)V-H86YN96PG72`]("=P96%R+G!H<"YN970G.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@('-W:71C:"`H)&1E<%LG<F5L)UTI('L-
M"B`@("`@("`@("`@(&-A<V4@)V=T)R`Z#0H@("`@("`@("`@("`@("`@)'!H
M<%LG;6EN)UT@/2`D9&5P6R=V97)S:6]N)UT[#0H@("`@("`@("`@("`@("`@
M)'!H<%LG97AC;'5D92==(#T@)&1E<%LG=F5R<VEO;B==.PT*("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=G92<@.@T*("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)&1E<%LG=F5R<VEO;B==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H)&1E<%LG='EP92==(#T]("=P:'`G*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG;F%M92==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!;)W9E<G-I
M;VXG72`]("1D97!;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`D<&AP6R=M:6XG72`]("1D97!;)W9E<G-I;VXG
M73L-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G;'0G
M(#H-"B`@("`@("`@("`@("`@("`D<&AP6R=M87@G72`]("1D97!;)W9E<G-I
M;VXG73L-"B`@("`@("`@("`@("`@("`D<&AP6R=E>&-L=61E)UT@/2`D9&5P
M6R=V97)S:6]N)UT[#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@
M(&-A<V4@)VQE)R`Z#0H@("`@("`@("`@("`@("`@)'!H<%LG;6%X)UT@/2`D
M9&5P6R=V97)S:6]N)UT[#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@(&-A<V4@)V5Q)R`Z#0H@("`@("`@("`@("`@("`@)'!H<%LG;6EN)UT@
M/2`D9&5P6R=V97)S:6]N)UT[#0H@("`@("`@("`@("`@("`@)'!H<%LG;6%X
M)UT@/2`D9&5P6R=V97)S:6]N)UT[#0H@("`@("`@("`@("!B<F5A:SL-"B`@
M("`@("`@("`@(&-A<V4@)VYE)R`Z#0H@("`@("`@("`@("`@("`@)'!H<%LG
M97AC;'5D92==(#T@)&1E<%LG=F5R<VEO;B==.PT*("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@("`@("!C87-E("=N;W0G(#H-"B`@("`@("`@("`@("`@
M("`D<&AP6R=C;VYF;&EC=',G72`]("=Y97,G.PT*("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1P:'`[#0H@("`@?0T*
M#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&%R<F%Y#0H@("`@("H@0')E='5R
M;B!A<G)A>0T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]P<F]C97-S4&AP1&5P
M<R@D9&5P<RD-"B`@("![#0H@("`@("`@("1T97-T(#T@87)R87DH*3L-"B`@
M("`@("`@9F]R96%C:"`H)&1E<',@87,@)&1E<"D@>PT*("`@("`@("`@("`@
M)'1E<W1;72`]("1T:&ES+3Y?<')O8V5S<T1E<"@D9&5P*3L-"B`@("`@("`@
M?0T*("`@("`@("`D;6EN(#T@87)R87DH*3L-"B`@("`@("`@)&UA>"`](&%R
M<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1T97-T(&%S("1D97`I('L-"B`@
M("`@("`@("`@(&EF("@A)&1E<"D@>PT*("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1D
M97!;)VUI;B==*2D@>PT*("`@("`@("`@("`@("`@("1M:6Y;)&1E<%LG;6EN
M)UU=(#T@8V]U;G0H)&UI;BD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H:7-S970H)&1E<%LG;6%X)UTI*2![#0H@("`@("`@("`@("`@("`@
M)&UA>%LD9&5P6R=M87@G75T@/2!C;W5N="@D;6%X*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H8V]U;G0H)&UI;BD@/B`P*2![
M#0H@("`@("`@("`@("!U:W-O<G0H)&UI;BP@)W9E<G-I;VY?8V]M<&%R92<I
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("AC;W5N="@D;6%X*2`^(#`I('L-
M"B`@("`@("`@("`@('5K<V]R="@D;6%X+"`G=F5R<VEO;E]C;VUP87)E)RD[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&-O=6YT*"1M:6XI*2![#0H@("`@
M("`@("`@("`O+R!G970@=&AE(&AI9VAE<W0@;6EN:6UU;0T*("`@("`@("`@
M("`@)&UI;B`](&%R<F%Y7W!O<"@D82`](&%R<F%Y7V9L:7`H)&UI;BDI.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&UI;B`](&9A;'-E.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AC;W5N="@D;6%X*2D@>PT*("`@("`@
M("`@("`@+R\@9V5T('1H92!L;W=E<W0@;6%X:6UU;0T*("`@("`@("`@("`@
M)&UA>"`](&%R<F%Y7W-H:69T*"1A(#T@87)R87E?9FQI<"@D;6%X*2D[#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D;6%X(#T@9F%L<V4[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"1M:6XI('L-"B`@("`@("`@("`@("1P
M:'!;)VUI;B==(#T@)&UI;CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&UA
M>"D@>PT*("`@("`@("`@("`@)'!H<%LG;6%X)UT@/2`D;6%X.PT*("`@("`@
M("!]#0H@("`@("`@("1E>&-L=61E(#T@87)R87DH*3L-"B`@("`@("`@9F]R
M96%C:"`H)'1E<W0@87,@)&1E<"D@>PT*("`@("`@("`@("`@:68@*"%I<W-E
M="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN
M=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D97AC;'5D95M=(#T@
M)&1E<%LG97AC;'5D92==.PT*("`@("`@("!]#0H@("`@("`@(&EF("AC;W5N
M="@D97AC;'5D92DI('L-"B`@("`@("`@("`@("1P:'!;)V5X8VQU9&4G72`]
M("1E>&-L=61E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<&AP.PT*
M("`@('T-"@T*("`@("\J*@T*("`@("`J('!R;V-E<W,@;75L=&EP;&4@9&5P
M96YD96YC:65S('1H870@:&%V92!A(&YA;64L(&QI:V4@<&%C:V%G92!D97!S
M#0H@("`@("H@0'!A<F%M(&%R<F%Y#0H@("`@("H@0')E='5R;B!A<G)A>0T*
M("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N
M(%]P<F]C97-S375L=&EP;&5$97!S3F%M92@D9&5P<RD-"B`@("![#0H@("`@
M("`@("1T97-T<R`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1D97!S
M(&%S("1N86UE(#T^("1D97`I('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1D
M97`@87,@)&0I('L-"B`@("`@("`@("`@("`@("`D=&5S='-;)&YA;65=6UT@
M/2`D=&AI<RT^7W!R;V-E<W-$97`H)&0I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1T97-T<R!A<R`D;F%M92`]/B`D
M=&5S="D@>PT*("`@("`@("`@("`@)'!H<"`](&%R<F%Y*"D[#0H@("`@("`@
M("`@("`D;6EN(#T@87)R87DH*3L-"B`@("`@("`@("`@("1M87@@/2!A<G)A
M>2@I.PT*("`@("`@("`@("`@)'!H<%LG;F%M92==(#T@)&YA;64[#0H@("`@
M("`@("`@("!F;W)E86-H("@D=&5S="!A<R`D9&5P*2![#0H@("`@("`@("`@
M("`@("`@:68@*"$D9&5P*2![#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&1E<%LG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D<&AP6R=C:&%N;F5L)UT@/2`G<&5A<BYP:'`N;F5T)SL-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)V-O
M;F9L:6-T<R==*2`F)B`D9&5P6R=C;VYF;&EC=',G72`]/2`G>65S)RD@>PT*
M("`@("`@("`@("`@("`@("`@("`D<&AP6R=C;VYF;&EC=',G72`]("=Y97,G
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&1E<%LG;6EN)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1M:6Y;
M)&1E<%LG;6EN)UU=(#T@8V]U;G0H)&UI;BD[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=M87@G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)&UA>%LD9&5P6R=M87@G75T@/2!C;W5N
M="@D;6%X*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!I9B`H8V]U;G0H)&UI;BD@/B`P*2![#0H@("`@("`@("`@
M("`@("`@=6MS;W)T*"1M:6XL("=V97)S:6]N7V-O;7!A<F4G*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("AC;W5N="@D;6%X*2`^(#`I('L-
M"B`@("`@("`@("`@("`@("!U:W-O<G0H)&UA>"P@)W9E<G-I;VY?8V]M<&%R
M92<I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&-O=6YT*"1M
M:6XI*2![#0H@("`@("`@("`@("`@("`@+R\@9V5T('1H92!H:6=H97-T(&UI
M;FEM=6T-"B`@("`@("`@("`@("`@("`D;6EN(#T@87)R87E?<&]P*"1A(#T@
M87)R87E?9FQI<"@D;6EN*2D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("1M:6X@/2!F86QS93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("AC;W5N="@D;6%X*2D@>PT*("`@("`@("`@("`@("`@
M("\O(&=E="!T:&4@;&]W97-T(&UA>&EM=6T-"B`@("`@("`@("`@("`@("`D
M;6%X(#T@87)R87E?<VAI9G0H)&$@/2!A<G)A>5]F;&EP*"1M87@I*3L-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&UA>"`](&9A
M;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1M:6XI('L-
M"B`@("`@("`@("`@("`@("`D<&AP6R=M:6XG72`]("1M:6X[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!I9B`H)&UA>"D@>PT*("`@("`@("`@("`@
M("`@("1P:'!;)VUA>"==(#T@)&UA>#L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("1E>&-L=61E(#T@87)R87DH*3L-"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1T97-T(&%S("1D97`I('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1D97!;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("1E>&-L=61E6UT@/2`D9&5P6R=E>&-L=61E)UT[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!I9B`H8V]U;G0H)&5X8VQU9&4I*2![#0H@("`@("`@
M("`@("`@("`@)'!H<%LG97AC;'5D92==(#T@)&5X8VQU9&4[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`D<F5T6UT@/2`D<&AP.PT*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"GT-"C\^````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2
M+U!A8VMA9V5&:6QE+T=E;F5R871O<B]V,BYP:'``````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#$W,C`P,``Q,#4Q-30S,S<T,``P,C0T-3$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`-"B\J*@T*("H@<&%C
M:V%G92YX;6P@9V5N97)A=&EO;B!C;&%S<RP@<&%C:V%G92YX;6P@=F5R<VEO
M;B`R+C`-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)
M0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N
M(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@
M55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@
M($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0
M($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@
M=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-
M"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2
M#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^
M#0H@*B!`875T:&]R("`@("!3=&5P:&%N(%-C:&UI9'0@*&]R:6=I;F%L(%A-
M3%]397)I86QI>F5R(&-O9&4I#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@
M5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R
M<VEO;B`@("!#5E,Z("1)9#H@=C(N<&AP+'8@,2XS-"`R,#`V+S`S+S`R(#(P
M.C4P.C4Y(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@
M879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0HO*BH-"B`J
M(&9I;&4O9&ER(&UA;FEP=6QA=&EO;B!R;W5T:6YE<PT*("HO#0IR97%U:7)E
M7V]N8V4@)U-Y<W1E;2YP:'`G.PT*+RHJ#0H@*B!4:&ES(&-L87-S(&-O;G9E
M<G1S(&$@4$5!4E]086-K86=E1FEL95]V,B!O8FIE8W0@:6YT;R!A;GD@;W5T
M<'5T(&9O<FUA="X-"B`J#0H@*B!3=7!P;W)T960@;W5T<'5T(&9O<FUA=',@
M:6YC;'5D92!A<G)A>2P@6$U,('-T<FEN9R`H=7-I;F<@4RX@4V-H;6ED="=S
M#0H@*B!834Q?4V5R:6%L:7IE<BP@<VQI9VAT;'D@8W5S=&]M:7IE9"D-"B`J
M($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A
M=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!A
M=71H;W(@("`@(%-T97!H86X@4V-H;6ED="`H;W)I9VEN86P@6$U,7U-E<FEA
M;&EZ97(@8V]D92D-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0
M($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@
M(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A
M:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0IC;&%S<R!014%2
M7U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,@T*>PT*("`@+RHJ#0H@("`@*B!D
M969A=6QT(&]P=&EO;G,@9F]R('1H92!S97)I86QI>F%T:6]N#0H@("`@*B!`
M86-C97-S('!R:79A=&4-"B`@("`J($!V87(@87)R87D@)%]D969A=6QT3W!T
M:6]N<PT*("`@("HO#0H@("`@=F%R("1?9&5F875L=$]P=&EO;G,@/2!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`G:6YD96YT)R`@("`@("`@
M("`@("`]/B`G("<L("`@("`@("`@("`@("`@("`@("`O+R!S=')I;F<@=7-E
M9"!F;W(@:6YD96YT871I;VX-"B`@("`@("`@("`@("`@("`@("`@("`@("`G
M;&EN96)R96%K)R`@("`@("`@("`]/B`B7&XB+"`@("`@("`@("`@("`@("`@
M("\O('-T<FEN9R!U<V5D(&9O<B!N97=L:6YE<PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("=T>7!E2&EN=',G("`@("`@("`@(#T^(&9A;'-E+"`@("`@
M("`@("`@("`@("`@+R\@875T;VUA=&EC86QL>2!A9&0@='EP92!H:6X@871T
M<FEB=71E<PT*("`@("`@("`@("`@("`@("`@("`@("`@("=A9&1$96-L)R`@
M("`@("`@("`@(#T^('1R=64L("`@("`@("`@("`@("`@("`O+R!A9&0@86X@
M6$U,(&1E8VQA<F%T:6]N#0H@("`@("`@("`@("`@("`@("`@("`@("`@)V1E
M9F%U;'1486=.86UE)R`@("`@/3X@)UA-3%]397)I86QI>F5R7U1A9R<L("`O
M+R!T86<@=7-E9"!F;W(@:6YD97AE9"!A<G)A>7,@;W(@:6YV86QI9"!N86UE
M<PT*("`@("`@("`@("`@("`@("`@("`@("`@("=C;&%S<T%S5&%G3F%M92<@
M("`@(#T^(&9A;'-E+"`@("`@("`@("`@("`@("`@+R\@=7-E(&-L87-S;F%M
M92!F;W(@;V)J96-T<R!I;B!I;F1E>&5D(&%R<F%Y<PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("=K97E!='1R:6)U=&4G("`@("`@(#T^("=?;W)I9VEN
M86Q+97DG+"`@("`@("`@+R\@871T<FEB=71E('=H97)E(&]R:6=I;F%L(&ME
M>2!I<R!S=&]R960-"B`@("`@("`@("`@("`@("`@("`@("`@("`G='EP94%T
M=')I8G5T92<@("`@("`]/B`G7W1Y<&4G+"`@("`@("`@("`@("`@("\O(&%T
M=')I8G5T92!F;W(@='EP92`H;VYL>2!I9B!T>7!E2&EN=',@/3X@=')U92D-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`G8VQA<W-!='1R:6)U=&4G("`@
M("`]/B`G7V-L87-S)RP@("`@("`@("`@("`@("\O(&%T=')I8G5T92!F;W(@
M8VQA<W,@;V8@;V)J96-T<R`H;VYL>2!I9B!T>7!E2&EN=',@/3X@=')U92D-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`G<V-A;&%R07-!='1R:6)U=&5S
M)R`]/B!F86QS92P@("`@("`@("`@("`@("`@("\O('-C86QA<B!V86QU97,@
M*'-T<FEN9W,L(&EN=',L+BXI('=I;&P@8F4@<V5R:6%L:7IE9"!A<R!A='1R
M:6)U=&4-"B`@("`@("`@("`@("`@("`@("`@("`@("`G<')E<&5N9$%T=')I
M8G5T97,G("`]/B`G)RP@("`@("`@("`@("`@("`@("`@("\O('!R97!E;F0@
M<W1R:6YG(&9O<B!A='1R:6)U=&5S#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@)VEN9&5N=$%T=')I8G5T97,G("`@/3X@9F%L<V4L("`@("`@("`@("`@
M("`@("`O+R!I;F1E;G0@=&AE(&%T=')I8G5T97,L(&EF('-E="!T;R`G7V%U
M=&\G+"!I="!W:6QL(&EN9&5N="!A='1R:6)U=&5S('-O('1H97D@86QL('-T
M87)T(&%T('1H92!S86UE(&-O;'5M;@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("=M;V1E)R`@("`@("`@("`@("`@(#T^("=S:6UP;&5X;6PG+"`@("`@
M("`@("`@("`O+R!U<V4@)W-I;7!L97AM;"<@=&\@=7-E('!A<F5N="!N86UE
M(&%S('1A9VYA;64@:68@=')A;G-F;W)M:6YG(&%N(&EN9&5X960@87)R87D-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`G861D1&]C='EP92<@("`@("`@
M("`]/B!F86QS92P@("`@("`@("`@("`@("`@("\O(&%D9"!A(&1O8W1Y<&4@
M9&5C;&%R871I;VX-"B`@("`@("`@("`@("`@("`@("`@("`@("`G9&]C='EP
M92<@("`@("`@("`@("`]/B!N=6QL+"`@("`@("`@("`@("`@("`@("\O('-U
M<'!L>2!A('-T<FEN9R!O<B!A;B!A<G)A>2!W:71H(&ED(&%N9"!U<FD@*'M`
M<V5E(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7U!%05)?4&%C:V%G
M949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIG971$;V-T>7!E1&5C;&%R
M871I;VXH*7T-"B`@("`@("`@("`@("`@("`@("`@("`@("`G<F]O=$YA;64G
M("`@("`@("`@("`]/B`G<&%C:V%G92<L("`@("`@("`@("`@("`@("`@+R\@
M;F%M92!O9B!T:&4@<F]O="!T86<-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`G<F]O=$%T=')I8G5T97,G("`@("`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W9E<G-I;VXG(#T^("<R+C`G+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G>&UL;G,G(#T^("=H='1P.B\O<&5A
M<BYP:'`N;F5T+V1T9"]P86-K86=E+3(N,"<L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=X;6QN<SIT87-K<R<@/3X@)VAT='`Z+R]P96%R+G!H
M<"YN970O9'1D+W1A<VMS+3$N,"<L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=X;6QN<SIX<VDG(#T^("=H='1P.B\O=W=W+G<S+F]R9R\R,#`Q
M+UA-3%-C:&5M82UI;G-T86YC92<L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=X<VDZ<V-H96UA3&]C871I;VXG(#T^("=H='1P.B\O<&5A<BYP
M:'`N;F5T+V1T9"]T87-K<RTQ+C`-"FAT='`Z+R]P96%R+G!H<"YN970O9'1D
M+W1A<VMS+3$N,"YX<V0-"FAT='`Z+R]P96%R+G!H<"YN970O9'1D+W!A8VMA
M9V4M,BXP#0IH='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]P86-K86=E+3(N,"YX
M<V0G+`T*("`@("`@("`@("`@("`@("`@("`@("`@("DL("`@("`@("`@("`@
M("`@+R\@871T<FEB=71E<R!O9B!T:&4@<F]O="!T86<-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`G871T<FEB=71E<T%R<F%Y)R`@("`]/B`G871T<FEB
M<R<L("`@("`@("`@("`@("`@("`@+R\@86QL('9A;'5E<R!I;B!T:&ES(&ME
M>2!W:6QL(&)E('1R96%T960@87,@871T<FEB=71E<PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("=C;VYT96YT3F%M92<@("`@("`@(#T^("=?8V]N=&5N
M="<L("`@("`@("`@("`@("`@("`@("\O('1H:7,@=F%L=64@=VEL;"!B92!U
M<V5D(&1I<F5C=&QY(&%S(&-O;G1E;G0L(&EN<W1E860@;V8@8W)E871I;F<@
M82!N97<@=&%G+"!M87D@;VYL>2!B92!U<V5D(&EN(&-O;FIU8W1I;VX@=VET
M:"!A='1R:6)U=&5S07)R87D-"B`@("`@("`@("`@("`@("`@("`@("`@("`G
M8F5A=71I9GE&:6QE;&ES="<@("`]/B!F86QS92P-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`G96YC;V1I;F<G(#T^("=55$8M."<L#0H@("`@("`@("`@
M("`@("`@("`@("`@("`I.PT*#0H@("`O*BH-"B`@("`J(&]P=&EO;G,@9F]R
M('1H92!S97)I86QI>F%T:6]N#0H@("`@*B!`86-C97-S('!R:79A=&4-"B`@
M("`J($!V87(@87)R87D@)&]P=&EO;G,-"B`@("`J+PT*("`@('9A<B`D;W!T
M:6]N<R`](&%R<F%Y*"D[#0H-"B`@("\J*@T*("`@("H@8W5R<F5N="!T86<@
M9&5P=&@-"B`@("`J($!V87(@:6YT96=E<B`D7W1A9T1E<'1H#0H@("`@*B\-
M"B`@("!V87(@)%]T86=$97!T:"`](#`[#0H-"B`@("\J*@T*("`@("H@<V5R
M:6QI86QI>F5D(')E<')E<V5N=&%T:6]N(&]F('1H92!D871A#0H@("`@*B!`
M=F%R('-T<FEN9R`D7W-E<FEA;&EZ961$871A#0H@("`@*B\-"B`@("!V87(@
M)%]S97)I86QI>F5D1&%T82`](&YU;&P[#0H@("`@+RHJ#0H@("`@("H@0'9A
M<B!014%27U!A8VMA9V5&:6QE7W8R#0H@("`@("HO#0H@("`@=F%R("1?<&%C
M:V%G969I;&4[#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G
M949I;&5?=C(-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!014%27U!A8VMA9V5&
M:6QE7T=E;F5R871O<E]V,B@F)'!A8VMA9V5F:6QE*0T*("`@('L-"B`@("`@
M("`@)'1H:7,M/E]P86-K86=E9FEL92`]("8D<&%C:V%G969I;&4[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@0')E='5R;B!S=')I;F<-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!G971086-K86=E<E9E<G-I;VXH*0T*("`@('L-"B`@
M("`@("`@<F5T=7)N("<Q+C0N.2<[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@0'!A<F%M(%!%05)?4&%C:V%G97(-"B`@("`@*B!`<&%R86T@8F]O;"!G
M96YE<F%T92!A("YT9WH@;W(@82`N=&%R#0H@("`@("H@0'!A<F%M('-T<FEN
M9WQN=6QL('1E;7!O<F%R>2!D:7)E8W1O<GD@=&\@<&%C:V%G92!I;@T*("`@
M("`J+PT*("`@(&9U;F-T:6]N('1O5&=Z*"8D<&%C:V%G97(L("1C;VUP<F5S
M<R`]('1R=64L("1W:&5R92`](&YU;&PI#0H@("`@>PT*("`@("`@("`D82`]
M(&YU;&P[#0H@("`@("`@(')E='5R;B`D=&AI<RT^=&]49WHR*"1P86-K86=E
M<BP@)&$L("1C;VUP<F5S<RP@)'=H97)E*3L-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!086-K86=E('5P(&)O=&@@82!P86-K86=E+GAM;"!A;F0@<&%C
M:V%G93(N>&UL(&9O<B!T:&4@<V%M92!R96QE87-E#0H@("`@("H@0'!A<F%M
M(%!%05)?4&%C:V%G97(-"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL
M95]V,0T*("`@("`J($!P87)A;2!B;V]L(&=E;F5R871E(&$@+G1G>B!O<B!A
M("YT87(-"B`@("`@*B!`<&%R86T@<W1R:6YG?&YU;&P@=&5M<&]R87)Y(&1I
M<F5C=&]R>2!T;R!P86-K86=E(&EN#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M=&]49WHR*"8D<&%C:V%G97(L("8D<&8Q+"`D8V]M<')E<W,@/2!T<G5E+"`D
M=VAE<F4@/2!N=6QL*0T*("`@('L-"B`@("`@("`@<F5Q=6ER95]O;F-E("=!
M<F-H:79E+U1A<BYP:'`G.PT*("`@("`@("!I9B`H(21T:&ES+3Y?<&%C:V%G
M969I;&4M/FES17%U:79A;&5N="@D<&8Q*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!%05)?4&%C:V%G969I;&5?=C(Z.G1O
M5&=Z.B`B)R`N#0H@("`@("`@("`@("`@("`@8F%S96YA;64H)'!F,2T^9V5T
M4&%C:V%G949I;&4H*2D@+@T*("`@("`@("`@("`@("`@("<B(&ES(&YO="!E
M<75I=F%L96YT('1O("(G("X@8F%S96YA;64H)'1H:7,M/E]P86-K86=E9FEL
M92T^9V5T4&%C:V%G949I;&4H*2D-"B`@("`@("`@("`@("`@("`N("<B)RD[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"1W:&5R92`]/3T@;G5L;"D@>PT*
M("`@("`@("`@("`@:68@*"$H)'=H97)E(#T@4WES=&5M.CIM:W1E;7`H87)R
M87DH)RUD)RDI*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"=014%27U!A8VMA9V5F:6QE7W8R.CIT;U1G>CH@;6MT96UP
M(&9A:6QE9"<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V5I9B`H
M(4!3>7-T96TZ.FUK1&ER*&%R<F%Y*"<M<"<L("1W:&5R92DI*2![#0H@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4$5!4E]086-K86=E
M9FEL95]V,CHZ=&]49WHZ("(G("X@)'=H97)E("X@)R(@8V]U;&0G("X-"B`@
M("`@("`@("`@("`@("`G(&YO="!B92!C<F5A=&5D)RD[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*&9I;&5?97AI<W1S*"1W:&5R92`N($1)4D5#5$]265]3
M15!!4D%43U(@+B`G<&%C:V%G92YX;6PG*2`F)@T*("`@("`@("`@("`@("`A
M:7-?9FEL92@D=VAE<F4@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)W!A8VMA
M9V4N>&UL)RDI('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"=014%27U!A8VMA9V5F:6QE7W8R.CIT;U1G>CH@=6YA8FQE('1O('-A
M=F4@<&%C:V%G92YX;6P@87,G("X-"B`@("`@("`@("`@("`@("`G("(G("X@
M)'=H97)E("X@1$E214-43U)97U-%4$%2051/4B`N("=P86-K86=E+GAM;"(G
M*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21T:&ES+3Y?<&%C:V%G969I
M;&4M/G9A;&ED871E*%!%05)?5D%,241!5$5?4$%#2T%'24Y'*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!%05)?4&%C:V%G
M969I;&5?=C(Z.G1O5&=Z.B!I;G9A;&ED('!A8VMA9V4N>&UL)RD[#0H@("`@
M("`@('T-"B`@("`@("`@)&5X="`]("1C;VUP<F5S<R`_("<N=&=Z)R`Z("<N
M=&%R)SL-"B`@("`@("`@)'!K9W9E<B`]("1T:&ES+3Y?<&%C:V%G969I;&4M
M/F=E=%!A8VMA9V4H*2`N("<M)R`N("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E
M=%9E<G-I;VXH*3L-"B`@("`@("`@)&1E<W1?<&%C:V%G92`](&=E=&-W9"@I
M("X@1$E214-43U)97U-%4$%2051/4B`N("1P:V=V97(@+B`D97AT.PT*("`@
M("`@("!I9B`H9FEL95]E>&ES=',H9V5T8W=D*"D@+B!$25)%0U1/4EE?4T50
M05)!5$]2("X@)'!K9W9E<B`N("1E>'0I("8F#0H@("`@("`@("`@("`@("%I
M<U]F:6QE*&=E=&-W9"@I("X@1$E214-43U)97U-%4$%2051/4B`N("1P:V=V
M97(@+B`D97AT*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)U!%05)?4&%C:V%G969I;&5?=C(Z.G1O5&=Z.B!C86YN;W0@8W)E
M871E('1G>B!F:6QE("(G("X-"B`@("`@("`@("`@("`@("!G971C=V0H*2`N
M($1)4D5#5$]265]315!!4D%43U(@+B`D<&MG=F5R("X@)&5X="`N("<B)RD[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"1P:V=F:6QE(#T@)'1H:7,M/E]P
M86-K86=E9FEL92T^9V5T4&%C:V%G949I;&4H*2D@>PT*("`@("`@("`@("`@
M)'!K9V1I<B`](&1I<FYA;64H<F5A;'!A=&@H)'!K9V9I;&4I*3L-"B`@("`@
M("`@("`@("1P:V=F:6QE(#T@8F%S96YA;64H)'!K9V9I;&4I.PT*("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)U!%05)?4&%C:V%G969I;&5?=C(Z.G1O5&=Z.B!P86-K86=E(&9I;&4@
M;V)J96-T(&UU<W0@)R`N#0H@("`@("`@("`@("`@("`@)V)E(&-R96%T960@
M9G)O;2!A(')E86P@9FEL92<I.PT*("`@("`@("!]#0H@("`@("`@("\O('M[
M>R!#<F5A=&4@=&AE('!A8VMA9V4@9FEL92!L:7-T#0H@("`@("`@("1F:6QE
M;&ES="`](&%R<F%Y*"D[#0H@("`@("`@("1I(#T@,#L-"B`@("`@("`@)'1H
M:7,M/E]P86-K86=E9FEL92T^9FQA='1E;D9I;&5L:7-T*"D[#0H@("`@("`@
M("1C;VYT96YT<R`]("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=$-O;G1E;G1S
M*"D[#0H@("`@("`@(&EF("AI<W-E="@D8V]N=&5N='-;)V)U;F1L961P86-K
M86=E)UTI*2![("\O(&)U;F1L97,@;V8@<&%C:V%G97,-"B`@("`@("`@("`@
M("1C;VYT96YT<R`]("1C;VYT96YT<ULG8G5N9&QE9'!A8VMA9V4G73L-"B`@
M("`@("`@("`@(&EF("@A:7-S970H)&-O;G1E;G1S6S!=*2D@>PT*("`@("`@
M("`@("`@("`@("1C;VYT96YT<R`](&%R<F%Y*"1C;VYT96YT<RD[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D<&%C:V%G941I<B`]("1W:&5R93L-
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1C;VYT96YT<R!A<R`D:2`]/B`D<&%C
M:V%G92D@>PT*("`@("`@("`@("`@("`@("1F;F%M92`]("1P86-K86=E.PT*
M("`@("`@("`@("`@("`@("1F:6QE(#T@)'!K9V1I<B`N($1)4D5#5$]265]3
M15!!4D%43U(@+B`D9FYA;64[#0H@("`@("`@("`@("`@("`@:68@*"%F:6QE
M7V5X:7-T<R@D9FEL92DI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1P86-K86=E<BT^<F%I<V5%<G)O<B@B1FEL92!D;V5S(&YO="!E>&ES=#H@
M)&9N86UE(BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("1T9FEL92`]("1P86-K86=E1&ER("X@1$E214-43U)97U-%4$%2051/4B`N
M("1F;F%M93L-"B`@("`@("`@("`@("`@("!3>7-T96TZ.FUK9&ER*&%R<F%Y
M*"<M<"<L(&1I<FYA;64H)'1F:6QE*2DI.PT*("`@("`@("`@("`@("`@(&-O
M<'DH)&9I;&4L("1T9FEL92D[#0H@("`@("`@("`@("`@("`@)&9I;&5L:7-T
M6R1I*RM=(#T@)'1F:6QE.PT*("`@("`@("`@("`@("`@("1P86-K86=E<BT^
M;&]G*#(L(")!9&1I;F<@<&%C:V%G92`D9FYA;64B*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?2!E;'-E('L@+R\@;F]R;6%L('!A8VMA9V5S#0H@("`@
M("`@("`@("`D8V]N=&5N=',@/2`D8V]N=&5N='-;)V1I<B==6R=F:6QE)UT[
M#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1C;VYT96YT<ULP72DI('L-"B`@
M("`@("`@("`@("`@("`D8V]N=&5N=',@/2!A<G)A>2@D8V]N=&5N=',I.PT*
M("`@("`@("`@("`@?0T*("`@(`T*("`@("`@("`@("`@)'!A8VMA9V5$:7(@
M/2`D=VAE<F4[#0H@("`@("`@("`@("!F;W)E86-H("@D8V]N=&5N=',@87,@
M)&D@/3X@)&9I;&4I('L-"B`@("`@("`@("`@("`@("`D9FYA;64@/2`D9FEL
M95LG871T<FEB<R==6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@)&%T=',@
M/2`D9FEL95LG871T<FEB<R==.PT*("`@("`@("`@("`@("`@("1O<FEG(#T@
M)&9I;&4[#0H@("`@("`@("`@("`@("`@)&9I;&4@/2`D<&MG9&ER("X@1$E2
M14-43U)97U-%4$%2051/4B`N("1F;F%M93L-"B`@("`@("`@("`@("`@("!I
M9B`H(69I;&5?97AI<W1S*"1F:6QE*2D@>PT*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)'!A8VMA9V5R+3YR86ES945R<F]R*")&:6QE(&1O97,@;F]T
M(&5X:7-T.B`D9FYA;64B*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`D=&9I;&4@/2`D<&%C:V%G941I<B`N($1)
M4D5#5$]265]315!!4D%43U(@+B`D9FYA;64[#0H@("`@("`@("`@("`@("`@
M("`@('5N<V5T*"1O<FEG6R=A='1R:6)S)UTI.PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H8V]U;G0H)&]R:6<I*2![("\O(&9I;&4@=VET:"!T87-K<PT*
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@<G5N(&%N>2!P86-K86=E+71I
M;64@=&%S:W,-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AF=6YC=&EO
M;E]E>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D8V]N=&5N=',@/2!F:6QE7V=E=%]C;VYT96YT
M<R@D9FEL92D[#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F<"`](&9O<&5N*"1F:6QE
M+"`B<B(I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VYT96YT
M<R`]($!F<F5A9"@D9G`L(&9I;&5S:7IE*"1F:6QE*2D[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H
M("@D;W)I9R!A<R`D=&%G(#T^("1R87<I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&%G(#T@<W1R7W)E<&QA8V4H)'1H:7,M/E]P86-K86=E
M9FEL92T^9V5T5&%S:W-.<R@I("X@)SHG+"`G)RP@)'1A9RD[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1A<VL@/2`B4$5!4E]487-K7R1T86<B
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T87-K(#T@)FYE=R`D
M=&%S:R@D=&AI<RT^7W!A8VMA9V5F:6QE+3Y?8V]N9FEG+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5F:6QE+3Y?
M;&]G9V5R+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!014%2
M7U1!4TM?4$%#2T%'12D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1A<VLM/FEN:70H)')A=RP@)&%T=',L(&YU;&PI.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1R97,@/2`D=&%S:RT^<W1A<G1397-S:6]N*"1T
M:&ES+3Y?<&%C:V%G969I;&4L("1C;VYT96YT<RP@)'1F:6QE*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H(21R97,I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[("\O('-K:7`@=&AI
M<R!T87-K#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R97,I
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M<F5S.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D8V]N=&5N=',@/2`D<F5S.R`O+R!S879E
M(&-H86YG97,-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!3>7-T96TZ
M.FUK9&ER*&%R<F%Y*"<M<"<L(&1I<FYA;64H)'1F:6QE*2DI.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1W<"`](&9O<&5N*"1T9FEL92P@(G=B
M(BD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@9G=R:71E*"1W<"P@
M)&-O;G1E;G1S*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F8VQO
M<V4H)'=P*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H(69I;&5?
M97AI<W1S*"1T9FEL92DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(%-Y
M<W1E;3HZ;6MD:7(H87)R87DH)RUP)RP@9&ER;F%M92@D=&9I;&4I*2D[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!C;W!Y*"1F:6QE+"`D=&9I;&4I.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1F
M:6QE;&ES=%LD:2LK72`]("1T9FEL93L-"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P86-K86=E9FEL92T^<V5T1FEL94%T=')I8G5T92@D9FYA;64L
M("=M9#5S=6TG+"!M9#5?9FEL92@D=&9I;&4I+"`D:2`M(#$I.PT*("`@("`@
M("`@("`@("`@("`@("`D<&%C:V%G97(M/FQO9R@R+"`B061D:6YG(&9I;&4@
M)&9N86UE(BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@("`@("`O+R!]?7T-"B`@("`@("`@:68@*"1P
M9C$@(3T](&YU;&PI('L-"B`@("`@("`@("`@("1N86UE(#T@)W!A8VMA9V4R
M+GAM;"<[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D;F%M92`]
M("=P86-K86=E+GAM;"<[#0H@("`@("`@('T-"B`@("`@("`@)'!A8VMA9V5X
M;6P@/2`D=&AI<RT^=&]086-K86=E1FEL92@D=VAE<F4L(%!%05)?5D%,241!
M5$5?4$%#2T%'24Y'+"`D;F%M92D[#0H@("`@("`@(&EF("@D<&%C:V%G97AM
M;"D@>PT*("`@("`@("`@("`@)'1A<B`])B!N97<@07)C:&EV95]487(H)&1E
M<W1?<&%C:V%G92P@)&-O;7!R97-S*3L-"B`@("`@("`@("`@("1T87(M/G-E
M=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.R`O+R!86%@@1&]N
M)W0@<')I;G0@97)R;W)S#0H@("`@("`@("`@("`O+R`M+2TM+2!#<F5A=&5S
M('=I=&@@=&AE('!A8VMA9V4N>&UL(&9I;&4-"B`@("`@("`@("`@("1O:R`]
M("1T87(M/F-R96%T94UO9&EF>2AA<G)A>2@D<&%C:V%G97AM;"DL("<G+"`D
M=VAE<F4I.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&]K*2D@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B`D<&%C:V%G97(M/G)A:7-E17)R
M;W(H)&]K*3L-"B`@("`@("`@("`@('T@96QS96EF("@A)&]K*2![#0H@("`@
M("`@("`@("`@("`@<F5T=7)N("1P86-K86=E<BT^<F%I<V5%<G)O<B@G4$5!
M4E]086-K86=E9FEL95]V,CHZ=&]49WHH*3H@861D:6YG("<@+B`D;F%M92`N
M#0H@("`@("`@("`@("`@("`@("`@("<@9F%I;&5D)RD[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`O+R`M+2TM+2!!9&0@=&AE(&-O;G1E;G0@;V8@
M=&AE('!A8VMA9V4-"B`@("`@("`@("`@(&EF("@A)'1A<BT^861D36]D:69Y
M*"1F:6QE;&ES="P@)'!K9W9E<BP@)'=H97)E*2D@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B`D<&%C:V%G97(M/G)A:7-E17)R;W(H#0H@("`@("`@("`@
M("`@("`@("`@("=014%27U!A8VMA9V5F:6QE7W8R.CIT;U1G>B@I.B!T87)B
M86QL(&-R96%T:6]N(&9A:6QE9"<I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@+R\@861D('1H92!P86-K86=E+GAM;"!V97)S:6]N(#$N,`T*("`@
M("`@("`@("`@:68@*"1P9C$@(3T](&YU;&PI('L-"B`@("`@("`@("`@("`@
M("`D<&9G96X@/2`F)'!F,2T^9V5T1&5F875L=$=E;F5R871O<B@I.PT*("`@
M("`@("`@("`@("`@("1P86-K86=E>&UL,2`]("1P9F=E;BT^=&]086-K86=E
M1FEL92@D=VAE<F4L(%!%05)?5D%,241!5$5?4$%#2T%'24Y'+`T*("`@("`@
M("`@("`@("`@("`@("`G<&%C:V%G92YX;6PG+"!T<G5E*3L-"B`@("`@("`@
M("`@("`@("!I9B`H(21T87(M/F%D9$UO9&EF>2AA<G)A>2@D<&%C:V%G97AM
M;#$I+"`G)RP@)'=H97)E*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)'!A8VMA9V5R+3YR86ES945R<F]R*`T*("`@("`@("`@("`@("`@("`@
M("`@("`@)U!%05)?4&%C:V%G969I;&5?=C(Z.G1O5&=Z*"DZ(&%D9&EN9R!P
M86-K86=E+GAM;"!F86EL960G*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)&1E<W1?<&%C:V%G93L-
M"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T:6]N('1O4&%C:V%G949I
M;&4H)'=H97)E(#T@;G5L;"P@)'-T871E(#T@4$5!4E]604Q)1$%415].3U)-
M04PL("1N86UE(#T@)W!A8VMA9V4N>&UL)RD-"B`@("![#0H@("`@("`@(&EF
M("@A)'1H:7,M/E]P86-K86=E9FEL92T^=F%L:61A=&4H)'-T871E*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!%05)?4&%C
M:V%G969I;&5?=C(Z.G1O4&%C:V%G949I;&4Z(&EN=F%L:60@<&%C:V%G92YX
M;6PG+`T*("`@("`@("`@("`@("`@(&YU;&PL(&YU;&PL(&YU;&PL("1T:&ES
M+3Y?<&%C:V%G969I;&4M/F=E=%9A;&ED871I;VY787)N:6YG<R@I*3L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H)'=H97)E(#T]/2!N=6QL*2![#0H@("`@
M("`@("`@("!I9B`H(2@D=VAE<F4@/2!3>7-T96TZ.FUK=&5M<"AA<G)A>2@G
M+60G*2DI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)U!%05)?4&%C:V%G969I;&5?=C(Z.G1O4&%C:V%G949I;&4Z(&UK
M=&5M<"!F86EL960G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E
M:68@*"%`4WES=&5M.CIM:T1I<BAA<G)A>2@G+7`G+"`D=VAE<F4I*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!%05)?4&%C
M:V%G969I;&5?=C(Z.G1O4&%C:V%G949I;&4Z("(G("X@)'=H97)E("X@)R(@
M8V]U;&0G("X-"B`@("`@("`@("`@("`@("`G(&YO="!B92!C<F5A=&5D)RD[
M#0H@("`@("`@('T-"B`@("`@("`@)&YE=W!K9V9I;&4@/2`D=VAE<F4@+B!$
M25)%0U1/4EE?4T5005)!5$]2("X@)&YA;64[#0H@("`@("`@("1N<"`]($!F
M;W!E;B@D;F5W<&MG9FEL92P@)W=B)RD[#0H@("`@("`@(&EF("@A)&YP*2![
M#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4$5!4E]0
M86-K86=E9FEL95]V,CHZ=&]086-K86=E1FEL93H@=6YA8FQE('1O('-A=F4@
M)R`N#0H@("`@("`@("`@("`@("`B)&YA;64@87,@)&YE=W!K9V9I;&4B*3L-
M"B`@("`@("`@?0T*("`@("`@("!F=W)I=&4H)&YP+"`D=&AI<RT^=&]8;6PH
M)'-T871E*2D[#0H@("`@("`@(&9C;&]S92@D;G`I.PT*("`@("`@("!R971U
M<FX@)&YE=W!K9V9I;&4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@)G1O5C(H
M*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G969I;&4[
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4F5T=7)N(&%N(%A-3"!D;V-U
M;65N="!B87-E9"!O;B!T:&4@<&%C:V%G92!I;F9O("AA<R!R971U<FYE9`T*
M("`@("`J(&)Y('1H92!014%27T-O;6UO;CHZ:6YF;T9R;VTJ(&UE=&AO9',I
M+@T*("`@("`J#0H@("`@("H@0')E='5R;B!S=')I;F<@6$U,(&1A=&$-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!T;UAM;"@D<W1A=&4@/2!014%27U9!3$E$
M051%7TY/4DU!3"P@)&]P=&EO;G,@/2!A<G)A>2@I*0T*("`@('L-"B`@("`@
M("`@)'1H:7,M/E]P86-K86=E9FEL92T^<V5T1&%T92AD871E*"=9+6TM9"<I
M*3L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E9FEL92T^<V5T5&EM92AD871E
M*"=(.FDZ<R<I*3L-"B`@("`@("`@:68@*"$D=&AI<RT^7W!A8VMA9V5F:6QE
M+3YV86QI9&%T92@D<W1A=&4I*2![#0H@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES7V%R<F%Y*"1O<'1I;VYS
M*2D@>PT*("`@("`@("`@("`@)'1H:7,M/F]P=&EO;G,@/2!A<G)A>5]M97)G
M92@D=&AI<RT^7V1E9F%U;'1/<'1I;VYS+"`D;W!T:6]N<RD[#0H@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`D=&AI<RT^;W!T:6]N<R`]("1T:&ES
M+3Y?9&5F875L=$]P=&EO;G,[#0H@("`@("`@('T-"B`@("`@("`@)&%R<B`]
M("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=$%R<F%Y*"D[#0H@("`@("`@(&EF
M("AI<W-E="@D87)R6R=F:6QE;&ES="==*2D@>PT*("`@("`@("`@("`@=6YS
M970H)&%R<ELG9FEL96QI<W0G72D[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&ES<V5T*"1A<G);)U]L87-T=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@
M=6YS970H)&%R<ELG7VQA<W1V97)S:6]N)UTI.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("@D<W1A=&4@7B!014%27U9!3$E$051%7U!!0TM!1TE.1R`F)B`A
M:7-S970H)&%R<ELG8G5N9&QE)UTI*2![#0H@("`@("`@("`@("`D=7-E(#T@
M)'1H:7,M/E]R96-U<G-I=F58;6Q&:6QE;&ES="@D87)R6R=C;VYT96YT<R==
M6R=D:7(G75LG9FEL92==*3L-"B`@("`@("`@("`@('5N<V5T*"1A<G);)V-O
M;G1E;G1S)UU;)V1I<B==6R=F:6QE)UTI.PT*("`@("`@("`@("`@:68@*&ES
M<V5T*"1U<V5;)V1I<B==*2D@>PT*("`@("`@("`@("`@("`@("1A<G);)V-O
M;G1E;G1S)UU;)V1I<B==6R=D:7(G72`]("1U<V5;)V1I<B==.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1U<V5;)V9I;&4G72DI
M('L-"B`@("`@("`@("`@("`@("`D87)R6R=C;VYT96YT<R==6R=D:7(G75LG
M9FEL92==(#T@)'5S95LG9FEL92==.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@)'1H:7,M/F]P=&EO;G-;)V)E875T:69Y1FEL96QI<W0G72`]('1R
M=64[#0H@("`@("`@('T-"B`@("`@("`@)&%R<ELG871T<FEB<R==6R=P86-K
M86=E<G9E<G-I;VXG72`]("<Q+C0N.2<[#0H@("`@("`@(&EF("@D=&AI<RT^
M<V5R:6%L:7IE*"1A<G(L("1O<'1I;VYS*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<V5R:6%L:7IE9$1A=&$@+B`B7&XB.PT*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"@T*("`@(&9U;F-T
M:6]N(%]R96-U<G-I=F58;6Q&:6QE;&ES="@D;&ES="D-"B`@("![#0H@("`@
M("`@("1D:7)S(#T@87)R87DH*3L-"B`@("`@("`@:68@*&ES<V5T*"1L:7-T
M6R=A='1R:6)S)UTI*2![#0H@("`@("`@("`@("`D9FEL92`]("1L:7-T6R=A
M='1R:6)S)UU;)VYA;64G73L-"B`@("`@("`@("`@('5N<V5T*"1L:7-T6R=A
M='1R:6)S)UU;)VYA;64G72D[#0H@("`@("`@("`@("`D871T<FEB=71E<R`]
M("1L:7-T6R=A='1R:6)S)UT[#0H@("`@("`@("`@("`D=&AI<RT^7V%D9$1I
M<B@D9&ER<RP@97AP;&]D92@G+R<L(&1I<FYA;64H)&9I;&4I*2P@)&9I;&4L
M("1A='1R:6)U=&5S*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M(&9O<F5A8V@@*"1L:7-T(&%S("1A*2![#0H@("`@("`@("`@("`@("`@)&9I
M;&4@/2`D85LG871T<FEB<R==6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@
M)&%T=')I8G5T97,@/2`D85LG871T<FEB<R==.PT*("`@("`@("`@("`@("`@
M('5N<V5T*"1A6R=A='1R:6)S)UTI.PT*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?861D1&ER*"1D:7)S+"!E>'!L;V1E*"<O)RP@9&ER;F%M92@D9FEL92DI
M+"`D9FEL92P@)&%T=')I8G5T97,L("1A*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("`D=&AI<RT^7V9O<FUA=$1I<B@D9&ER<RD[#0H@
M("`@("`@("1T:&ES+3Y?9&5&;W)M870H)&1I<G,I.PT*("`@("`@("!R971U
M<FX@)&1I<G,[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7V%D9$1I<B@F)&1I
M<G,L("1D:7(L("1F:6QE(#T@;G5L;"P@)&%T=')I8G5T97,@/2!N=6QL+"`D
M=&%S:W,@/2!N=6QL*0T*("`@('L-"B`@("`@("`@:68@*"$D=&%S:W,I('L-
M"B`@("`@("`@("`@("1T87-K<R`](&%R<F%Y*"D[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"1D:7(@/3T@87)R87DH*2!\?"`D9&ER(#T](&%R<F%Y*"<N
M)RDI('L-"B`@("`@("`@("`@("1D:7)S6R=F:6QE)UU;8F%S96YA;64H)&9I
M;&4I72`]("1T87-K<SL-"B`@("`@("`@("`@("1A='1R:6)U=&5S6R=N86UE
M)UT@/2!B87-E;F%M92@D9FEL92D[#0H@("`@("`@("`@("`D9&ER<ULG9FEL
M92==6V)A<V5N86UE*"1F:6QE*5U;)V%T=')I8G,G72`]("1A='1R:6)U=&5S
M.PT*("`@("`@("`@("`@<F5T=7)N.PT*("`@("`@("!]#0H@("`@("`@("1C
M=7)D:7(@/2!A<G)A>5]S:&EF="@D9&ER*3L-"B`@("`@("`@:68@*"%I<W-E
M="@D9&ER<ULG9&ER)UU;)&-U<F1I<ETI*2![#0H@("`@("`@("`@("`D9&ER
M<ULG9&ER)UU;)&-U<F1I<ET@/2!A<G)A>2@I.PT*("`@("`@("!]#0H@("`@
M("`@("1T:&ES+3Y?861D1&ER*"1D:7)S6R=D:7(G75LD8W5R9&ER72P@)&1I
M<BP@)&9I;&4L("1A='1R:6)U=&5S+"`D=&%S:W,I.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N(%]F;W)M871$:7(H)B1D:7)S*0T*("`@('L-"B`@("`@("`@
M:68@*"%C;W5N="@D9&ER<RDI('L-"B`@("`@("`@("`@(')E='5R;B!A<G)A
M>2@I.PT*("`@("`@("!]#0H@("`@("`@("1N97=D:7)S(#T@87)R87DH*3L-
M"B`@("`@("`@:68@*&ES<V5T*"1D:7)S6R=D:7(G72DI('L-"B`@("`@("`@
M("`@("1N97=D:7)S6R=D:7(G72`]("1D:7)S6R=D:7(G73L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H:7-S970H)&1I<G-;)V9I;&4G72DI('L-"B`@("`@
M("`@("`@("1N97=D:7)S6R=F:6QE)UT@/2`D9&ER<ULG9FEL92==.PT*("`@
M("`@("!]#0H@("`@("`@("1D:7)S(#T@)&YE=V1I<G,[#0H@("`@("`@(&EF
M("AI<W-E="@D9&ER<ULG9&ER)UTI*2![#0H@("`@("`@("`@("!U:W-O<G0H
M)&1I<G-;)V1I<B==+"`G<W1R;F%T8V%S96-M<"<I.PT*("`@("`@("`@("`@
M9F]R96%C:"`H)&1I<G-;)V1I<B==(&%S("1D:7(@/3X@)&-O;G1E;G1S*2![
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]F;W)M871$:7(H)&1I<G-;)V1I
M<B==6R1D:7)=*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H:7-S970H)&1I<G-;)V9I;&4G72DI('L-"B`@("`@("`@("`@('5K
M<V]R="@D9&ER<ULG9FEL92==+"`G<W1R;F%T8V%S96-M<"<I.PT*("`@("`@
M("!].PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]D949O<FUA="@F)&1I<G,I
M#0H@("`@>PT*("`@("`@("!I9B`H(6-O=6YT*"1D:7)S*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N(&%R<F%Y*"D[#0H@("`@("`@('T-"B`@("`@("`@)&YE
M=V1I<G,@/2!A<G)A>2@I.PT*("`@("`@("!I9B`H:7-S970H)&1I<G-;)V1I
M<B==*2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H)&1I<G-;)V1I<B==(&%S
M("1D:7(@/3X@)&-O;G1E;G1S*2![#0H@("`@("`@("`@("`@("`@)&YE=V1I
M<B`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@)&YE=V1I<ELG871T<FEB
M<R==6R=N86UE)UT@/2`D9&ER.PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9&5&;W)M870H)&-O;G1E;G1S*3L-"B`@("`@("`@("`@("`@("!F;W)E86-H
M("@D8V]N=&5N=',@87,@)'1A9R`]/B`D=F%L*2![#0H@("`@("`@("`@("`@
M("`@("`@("1N97=D:7);)'1A9UT@/2`D=F%L.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`D;F5W9&ER<ULG9&ER)UU;72`]("1N97=D
M:7([#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H8V]U;G0H)&YE
M=V1I<G-;)V1I<B==*2`]/2`Q*2![#0H@("`@("`@("`@("`@("`@)&YE=V1I
M<G-;)V1I<B==(#T@)&YE=V1I<G-;)V1I<B==6S!=.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&ER<ULG9FEL92==
M*2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H)&1I<G-;)V9I;&4G72!A<R`D
M;F%M92`]/B`D9FEL92D@>PT*("`@("`@("`@("`@("`@("1N97=D:7)S6R=F
M:6QE)UU;72`]("1F:6QE.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*&-O=6YT*"1N97=D:7)S6R=F:6QE)UTI(#T](#$I('L-"B`@("`@("`@
M("`@("`@("`D;F5W9&ER<ULG9FEL92==(#T@)&YE=V1I<G-;)V9I;&4G75LP
M73L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D9&ER<R`]
M("1N97=D:7)S.PT*("`@('T-"@T*("`@("\J*@T*("`@("H@<F5S970@86QL
M(&]P=&EO;G,@=&\@9&5F875L="!O<'1I;VYS#0H@("`@*@T*("`@("H@0&%C
M8V5S<R`@('!U8FQI8PT*("`@("H@0'-E92`@("`@('-E=$]P=&EO;B@I+"!8
M34Q?56YS97)I86QI>F5R*"D-"B`@("`J+PT*("`@(&9U;F-T:6]N(')E<V5T
M3W!T:6]N<R@I#0H@("`@>PT*("`@("`@("`D=&AI<RT^;W!T:6]N<R`]("1T
M:&ES+3Y?9&5F875L=$]P=&EO;G,[#0H@("`@?0T*#0H@("`O*BH-"B`@("`J
M('-E="!A;B!O<'1I;VX-"B`@("`J#0H@("`@*B!9;W4@8V%N('5S92!T:&ES
M(&UE=&AO9"!I9B!Y;W4@9&\@;F]T('=A;G0@=&\@<V5T(&%L;"!O<'1I;VYS
M(&EN('1H92!C;VYS=')U8W1O<@T*("`@("H-"B`@("`J($!A8V-E<W,@("!P
M=6)L:6,-"B`@("`J($!S964@("`@("!R97-E=$]P=&EO;B@I+"!834Q?4V5R
M:6%L:7IE<B@I#0H@("`@*B\-"B`@("!F=6YC=&EO;B!S971/<'1I;VXH)&YA
M;64L("1V86QU92D-"B`@("![#0H@("`@("`@("1T:&ES+3YO<'1I;VYS6R1N
M86UE72`]("1V86QU93L-"B`@("!]#0H@("`@#0H@("`O*BH-"B`@("`J('-E
M=',@<V5V97)A;"!O<'1I;VYS(&%T(&]N8V4-"B`@("`J#0H@("`@*B!9;W4@
M8V%N('5S92!T:&ES(&UE=&AO9"!I9B!Y;W4@9&\@;F]T('=A;G0@=&\@<V5T
M(&%L;"!O<'1I;VYS(&EN('1H92!C;VYS=')U8W1O<@T*("`@("H-"B`@("`J
M($!A8V-E<W,@("!P=6)L:6,-"B`@("`J($!S964@("`@("!R97-E=$]P=&EO
M;B@I+"!834Q?56YS97)I86QI>F5R*"DL('-E=$]P=&EO;B@I#0H@("`@*B\-
M"B`@("!F=6YC=&EO;B!S971/<'1I;VYS*"1O<'1I;VYS*0T*("`@('L-"B`@
M("`@("`@)'1H:7,M/F]P=&EO;G,@/2!A<G)A>5]M97)G92@D=&AI<RT^;W!T
M:6]N<RP@)&]P=&EO;G,I.PT*("`@('T-"@T*("`@+RHJ#0H@("`@*B!S97)I
M86QI>F4@9&%T80T*("`@("H-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@
M("`J($!P87)A;2`@("!M:7AE9"`@("`D9&%T82!D871A('1O('-E<FEA;&EZ
M90T*("`@("H@0')E='5R;B`@(&)O;VQE86X@('1R=64@;VX@<W5C8V5S<RP@
M<&5A<B!E<G)O<B!O;B!F86EL=7)E#0H@("`@*B\-"B`@("!F=6YC=&EO;B!S
M97)I86QI>F4H)&1A=&$L("1O<'1I;VYS(#T@;G5L;"D-"B`@("![#0H@("`@
M("`@("\O(&EF(&]P=&EO;G,@:&%V92!B965N('-P96-I9FEE9"P@=7-E('1H
M96T@:6YS=&5A9`T*("`@("`@("`O+R!O9B!T:&4@<')E=FEO=7-L>2!D969I
M;F5D(&]N97,-"B`@("`@("`@:68@*&ES7V%R<F%Y*"1O<'1I;VYS*2D@>PT*
M("`@("`@("`@("`@)&]P=&EO;G-"86L@/2`D=&AI<RT^;W!T:6]N<SL-"B`@
M("`@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG;W9E<G)I9&5/<'1I;VYS
M)UTI("8F("1O<'1I;VYS6R=O=F5R<FED94]P=&EO;G,G72`]/2!T<G5E*2![
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/F]P=&EO;G,@/2!A<G)A>5]M97)G
M92@D=&AI<RT^7V1E9F%U;'1/<'1I;VYS+"`D;W!T:6]N<RD[#0H@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YO<'1I;VYS
M(#T@87)R87E?;65R9V4H)'1H:7,M/F]P=&EO;G,L("1O<'1I;VYS*3L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!E;'-E('L-"B`@("`@
M("`@("`@("1O<'1I;VYS0F%K(#T@;G5L;#L-"B`@("`@("`@?0T*("`@("`@
M("`-"B`@("`@("`@+R\@('-T87)T(&1E<'1H(&ES('IE<F\-"B`@("`@("`@
M)'1H:7,M/E]T86=$97!T:"`](#`[#0H-"B`@("`@("`@)'1H:7,M/E]S97)I
M86QI>F5D1&%T82`]("<G.PT*("`@("`@("`O+R!S97)I86QI>F4@86X@87)R
M87D-"B`@("`@("`@:68@*&ES7V%R<F%Y*"1D871A*2D@>PT*("`@("`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3YO<'1I;VYS6R=R;V]T3F%M92==*2D@>PT*
M("`@("`@("`@("`@("`@("1T86=.86UE(#T@)'1H:7,M/F]P=&EO;G-;)W)O
M;W1.86UE)UT[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("1T86=.86UE(#T@)V%R<F%Y)SL-"B`@("`@("`@("`@('T-"@T*("`@
M("`@("`@("`@)'1H:7,M/E]S97)I86QI>F5D1&%T82`N/2`D=&AI<RT^7W-E
M<FEA;&EZ94%R<F%Y*"1D871A+"`D=&%G3F%M92P@)'1H:7,M/F]P=&EO;G-;
M)W)O;W1!='1R:6)U=&5S)UTI.PT*("`@("`@("!]#0H@("`@("`@(`T*("`@
M("`@("`O+R!A9&0@9&]C='EP92!D96-L87)A=&EO;@T*("`@("`@("!I9B`H
M)'1H:7,M/F]P=&EO;G-;)V%D9$1O8W1Y<&4G72`]/3T@=')U92D@>PT*("`@
M("`@("`@("`@)'1H:7,M/E]S97)I86QI>F5D1&%T82`](%!%05)?4&%C:V%G
M949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIG971$;V-T>7!E1&5C;&%R
M871I;VXH)'1A9TYA;64L("1T:&ES+3YO<'1I;VYS6R=D;V-T>7!E)UTI#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)'1H:7,M/F]P
M=&EO;G-;)VQI;F5B<F5A:R==#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("X@)'1H:7,M/E]S97)I86QI>F5D1&%T83L-"B`@("`@("`@
M?0T*#0H@("`@("`@("\O("!B=6EL9"!X;6P@9&5C;&%R871I;VX-"B`@("`@
M("`@:68@*"1T:&ES+3YO<'1I;VYS6R=A9&1$96-L)UTI('L-"B`@("`@("`@
M("`@("1A='1S(#T@87)R87DH*3L-"B`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^;W!T:6]N<ULG96YC;V1I;F<G72D@*2![#0H@("`@("`@("`@("`@
M("`@)&5N8V]D:6YG(#T@)'1H:7,M/F]P=&EO;G-;)V5N8V]D:6YG)UT[#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1E;F-O9&EN
M9R`](&YU;&P[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^
M7W-E<FEA;&EZ961$871A(#T@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?
M=C)?6$U,7U5T:6PZ.F=E=%A-3$1E8VQA<F%T:6]N*"<Q+C`G+"`D96YC;V1I
M;F<I#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)'1H
M:7,M/F]P=&EO;G-;)VQI;F5B<F5A:R==#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("X@)'1H:7,M/E]S97)I86QI>F5D1&%T83L-"B`@
M("`@("`@?0T*("`@("`@("`-"B`@("`@("`@#0H)"6EF("@D;W!T:6]N<T)A
M:R`A/3T@;G5L;"D@>PT*"0D))'1H:7,M/F]P=&EO;G,@/2`D;W!T:6]N<T)A
M:SL-"@D)?0T*"0D-"B`@("`@("`@<F5T=7)N("!T<G5E.PT*("`@('T-"@T*
M("`@+RHJ#0H@("`@*B!G970@=&AE(')E<W5L="!O9B!T:&4@<V5R:6%L:7IA
M=&EO;@T*("`@("H-"B`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@*B!`<F5T
M=7)N('-T<FEN9R!S97)I86QI>F5D(%A-3`T*("`@("HO#0H@("`@9G5N8W1I
M;VX@9V5T4V5R:6%L:7IE9$1A=&$H*0T*("`@('L-"B`@("`@("`@:68@*"1T
M:&ES+3Y?<V5R:6%L:7IE9$1A=&$@/3T@;G5L;"`I('L-"B`@("`@("`@("`@
M(')E='5R;B`@)'1H:7,M/G)A:7-E17)R;W(H)TYO('-E<FEA;&EZ960@9&%T
M82!A=F%I;&%B;&4N(%5S92!834Q?4V5R:6%L:7IE<CHZ<V5R:6%L:7IE*"D@
M9FER<W0N)RP@6$U,7U-%4DE!3$E:15)?15)23U)?3D]?4T5224%,25I!5$E/
M3BD[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<V5R:6%L
M:7IE9$1A=&$[#0H@("`@?0T*("`@(`T*("`@+RHJ#0H@("`@*B!S97)I86QI
M>F4@86YY('9A;'5E#0H@("`@*@T*("`@("H@5&AI<R!M971H;V0@8VAE8VMS
M(&9O<B!T:&4@='EP92!O9B!T:&4@=F%L=64@86YD(&-A;&QS('1H92!A<'!R
M;W!R:6%T92!M971H;V0-"B`@("`J#0H@("`@*B!`86-C97-S('!R:79A=&4-
M"B`@("`J($!P87)A;2`@;6EX960@("`@("1V86QU90T*("`@("H@0'!A<F%M
M("!S=')I;F<@("`@)'1A9TYA;64-"B`@("`J($!P87)A;2`@87)R87D@("`@
M("1A='1R:6)U=&5S#0H@("`@*B!`<F5T=7)N('-T<FEN9PT*("`@("HO#0H@
M("`@9G5N8W1I;VX@7W-E<FEA;&EZ959A;'5E*"1V86QU92P@)'1A9TYA;64@
M/2!N=6QL+"`D871T<FEB=71E<R`](&%R<F%Y*"DI#0H@("`@>PT*("`@("`@
M("!I9B`H:7-?87)R87DH)'9A;'5E*2D@>PT*("`@("`@("`@("`@)'AM;"`]
M("1T:&ES+3Y?<V5R:6%L:7IE07)R87DH)'9A;'5E+"`D=&%G3F%M92P@)&%T
M=')I8G5T97,I.PT*("`@("`@("!](&5L<V5I9B`H:7-?;V)J96-T*"1V86QU
M92DI('L-"B`@("`@("`@("`@("1X;6P@/2`D=&AI<RT^7W-E<FEA;&EZ94]B
M:F5C="@D=F%L=64L("1T86=.86UE*3L-"B`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("1T86<@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W%N86UE)R`@("`@(#T^("1T86=.86UE+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`G871T<FEB=71E<R<@/3X@)&%T=')I8G5T97,L#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("=C;VYT96YT)R`@("`]/B`D=F%L
M=64-"B`@("`@("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("`D
M>&UL(#T@)'1H:7,M/E]C<F5A=&5834Q486<H)'1A9RD[#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N("1X;6P[#0H@("`@?0T*("`@(`T*("`@+RHJ#0H@
M("`@*B!S97)I86QI>F4@86X@87)R87D-"B`@("`J#0H@("`@*B!`86-C97-S
M("`@<')I=F%T90T*("`@("H@0'!A<F%M("`@(&%R<F%Y("`@)&%R<F%Y("`@
M("`@(&%R<F%Y('1O('-E<FEA;&EZ90T*("`@("H@0'!A<F%M("`@('-T<FEN
M9R`@)'1A9TYA;64@("`@(&YA;64@;V8@=&AE(')O;W0@=&%G#0H@("`@*B!`
M<&%R86T@("`@87)R87D@("`D871T<FEB=71E<R`@871T<FEB=71E<R!F;W(@
M=&AE(')O;W0@=&%G#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG("`D<W1R:6YG
M("`@("`@<V5R:6%L:7IE9"!D871A#0H@("`@*B!`=7-E<R`@("`@4$5!4E]0
M86-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.FES5F%L:61.86UE
M*"D@=&\@8VAE8VLL('=H971H97(@:V5Y(&AA<R!T;R!B92!S=6)S=&ET=71E
M9`T*("`@("HO#0H@("`@9G5N8W1I;VX@7W-E<FEA;&EZ94%R<F%Y*"8D87)R
M87DL("1T86=.86UE(#T@;G5L;"P@)&%T=')I8G5T97,@/2!A<G)A>2@I*0T*
M("`@('L-"B`@("`@("`@)%]C;VYT96YT(#T@;G5L;#L-"B`@("`@("`@#0H@
M("`@("`@("\J*@T*("`@("`@("`@*B!C:&5C:R!F;W(@<W!E8VEA;"!A='1R
M:6)U=&5S#0H@("`@("`@("`J+PT*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO
M;G-;)V%T=')I8G5T97-!<G)A>2==("$]/2!N=6QL*2![#0H@("`@("`@("`@
M("!I9B`H:7-S970H)&%R<F%Y6R1T:&ES+3YO<'1I;VYS6R=A='1R:6)U=&5S
M07)R87DG75TI*2![#0H@("`@("`@("`@("`@("`@)&%T=')I8G5T97,@/2`D
M87)R87E;)'1H:7,M/F]P=&EO;G-;)V%T=')I8G5T97-!<G)A>2==73L-"B`@
M("`@("`@("`@("`@("!U;G-E="@D87)R87E;)'1H:7,M/F]P=&EO;G-;)V%T
M=')I8G5T97-!<G)A>2==72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`O*BH-"B`@("`@("`@("`@("`J(&-H96-K(&9O<B!S<&5C:6%L(&-O;G1E
M;G0-"B`@("`@("`@("`@("`J+PT*("`@("`@("`@("`@:68@*"1T:&ES+3YO
M<'1I;VYS6R=C;VYT96YT3F%M92==("$]/2!N=6QL*2![#0H@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1A<G)A>5LD=&AI<RT^;W!T:6]N<ULG8V]N=&5N
M=$YA;64G75TI*2![#0H@("`@("`@("`@("`@("`@("`@("1?8V]N=&5N="`]
M("1A<G)A>5LD=&AI<RT^;W!T:6]N<ULG8V]N=&5N=$YA;64G75T[#0H@("`@
M("`@("`@("`@("`@("`@('5N<V5T*"1A<G)A>5LD=&AI<RT^;W!T:6]N<ULG
M8V]N=&5N=$YA;64G75TI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@("\J#0H@("`@("`@("H@:68@
M;6]D92!I<R!S970@=&\@<VEM<&QE6$U,+"!C:&5C:R!W:&5T:&5R#0H@("`@
M("`@("H@=&AE(&%R<F%Y(&ES(&%S<V]C:6%T:79E(&]R(&EN9&5X960-"B`@
M("`@("`@*B\-"B`@("`@("`@:68@*&ES7V%R<F%Y*"1A<G)A>2D@)B8@)'1H
M:7,M/F]P=&EO;G-;)VUO9&4G72`]/2`G<VEM<&QE>&UL)RD@>PT*("`@("`@
M("`@("`@)&EN9&5X960@/2!T<G5E.PT*("`@("`@("`@("`@:68@*"%C;W5N
M="@D87)R87DI*2![#0H@("`@("`@("`@("`@("`@)&EN9&5X960@/2!F86QS
M93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1A<G)A
M>2!A<R`D:V5Y(#T^("1V86PI('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES
M7VEN="@D:V5Y*2D@>PT*("`@("`@("`@("`@("`@("`@("`D:6YD97AE9"`]
M(&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@(&EF("@D
M:6YD97AE9"`F)B`D=&AI<RT^;W!T:6]N<ULG;6]D92==(#T]("=S:6UP;&5X
M;6PG*2![#0H@("`@("`@("`@("`@("`@)'-T<FEN9R`]("<G.PT*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1A<G)A>2!A<R`D:V5Y(#T^("1V86PI('L-
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=B96%U
M=&EF>49I;&5L:7-T)UT@)B8@)'1A9TYA;64@/3T@)V1I<B<I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]C=7)D:7(I
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)D
M:7(@/2`G)SL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1S879E9&ER(#T@)'1H:7,M/E]C=7)D:7([#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'9A;%LG871T<FEB
M<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D=F%L
M6R=A='1R:6)S)UU;)VYA;64G72`]/2`G+R<I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)D:7(@/2`G+R<[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?8W5R9&ER(#T]("<O
M)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]C=7)D:7(@/2`G)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V-U<F1I<B`N/2`G+R<@+B`D=F%L6R=A='1R:6)S)UU;)VYA;64G73L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@)'-T<FEN9R`N/2`D=&AI<RT^7W-E<FEA;&EZ959A;'5E
M*"`D=F%L+"`D=&%G3F%M92P@)&%T=')I8G5T97,I.PT*("`@("`@("`@("`@
M("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)V)E875T:69Y1FEL96QI<W0G
M72`F)B`D=&%G3F%M92`]/2`G9&ER)RD@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'-T<FEN9R`N/2`G(#PA+2T@)R`N("1T:&ES+3Y?8W5R9&ER("X@
M)R`M+3XG.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1S
M879E9&ER*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T
M*"1T:&ES+3Y?8W5R9&ER*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C
M=7)D:7(@/2`D<V%V961I<CL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`-
M"B`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`N/2`D=&AI<RT^;W!T:6]N
M<ULG;&EN96)R96%K)UT[#0H@("`@("`@(`D)"2\O"61O(&EN9&5N=&%T:6]N
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG:6YD
M96YT)UTA/3UN=6QL("8F("1T:&ES+3Y?=&%G1&5P=&@^,"D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'-T<FEN9R`N/2!S=')?<F5P96%T*"1T:&ES
M+3YO<'1I;VYS6R=I;F1E;G0G72P@)'1H:7,M/E]T86=$97!T:"D[#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@<F5T=7)N(')T<FEM*"1S=')I;F<I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(`T*"0EI9B`H)'1H:7,M/F]P=&EO;G-;
M)W-C86QA<D%S071T<FEB=71E<R==(#T]/2!T<G5E*2![#0H)("`@("`@("!F
M;W)E86-H("@D87)R87D@87,@)&ME>2`]/B`D=F%L=64I('L-"@D)"0EI9B`H
M:7-?<V-A;&%R*"1V86QU92D@)B8@*%!%05)?4&%C:V%G949I;&5?1V5N97)A
M=&]R7W8R7UA-3%]5=&EL.CII<U9A;&ED3F%M92@D:V5Y*2`]/3T@=')U92DI
M('L-"@D)"0D)=6YS970H)&%R<F%Y6R1K97E=*3L-"@D)"0D))&%T=')I8G5T
M97-;)'1H:7,M/F]P=&EO;G-;)W!R97!E;F1!='1R:6)U=&5S)UTN)&ME>5T@
M/2`D=F%L=64[#0H)"0D)?0T*"0D)?0T*"0E]#0H-"B`@("`@("`@+R\@8VAE
M8VL@9F]R(&5M<'1Y(&%R<F%Y(#T^(&-R96%T92!E;7!T>2!T86<-"B`@("`@
M("`@:68@*&5M<'1Y*"1A<G)A>2DI('L-"B`@("`@("`@("`@("1T86<@/2!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<6YA;64G("`@
M("`@/3X@)'1A9TYA;64L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V-O;G1E;G0G("`@(#T^("1?8V]N=&5N="P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G871T<FEB=71E<R<@/3X@)&%T=')I8G5T97,-"B`@("`@
M("`@("`@("`@("`@("`@("`@("D[#0H-"B`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("1T:&ES+3Y?=&%G1&5P=&@K*SL-"B`@("`@("`@("`@("1T
M;7`@/2`D=&AI<RT^;W!T:6]N<ULG;&EN96)R96%K)UT[#0H@("`@("`@("`@
M("!F;W)E86-H("@D87)R87D@87,@)&ME>2`]/B`D=F%L=64I('L-"B`@("`)
M"0DO+PED;R!I;F1E;G1A=&EO;@T*("`@("`@("`@("`@("`@(&EF("@D=&AI
M<RT^;W!T:6]N<ULG:6YD96YT)UTA/3UN=6QL("8F("1T:&ES+3Y?=&%G1&5P
M=&@^,"D@>PT*("`@("`@("`@("`@("`@("`@("`D=&UP("X]('-T<E]R97!E
M870H)'1H:7,M/F]P=&EO;G-;)VEN9&5N="==+"`D=&AI<RT^7W1A9T1E<'1H
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@#0H@("`@"0D)+R\)8V]P>2!K
M97D-"B`@("`)"0DD;W)I9TME>0D]"21K97D[#0H@("`@"0D)+R\):V5Y(&-A
M;FYO="!B92!U<V5D(&%S('1A9VYA;64@/3X@=7-E(&1E9F%U;'0@=&%G#0H@
M("`@("`@("`@("`@("`@)'9A;&ED(#T@4$5!4E]086-K86=E1FEL95]'96YE
M<F%T;W)?=C)?6$U,7U5T:6PZ.FES5F%L:61.86UE*"1K97DI.PT*("`@(`D@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1V86QI9"DI('L-"B`@("`)("`@
M("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=C;&%S<T%S5&%G3F%M92==
M("8F(&ES7V]B:F5C="@D=F%L=64I*2![#0H@("`@"2`@("`@("`@("`@("`@
M("`D:V5Y(#T@9V5T7V-L87-S*"1V86QU92D[#0H@("`@"2`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`)("`@("`@("`D:V5Y(#T@)'1H:7,M
M/F]P=&EO;G-;)V1E9F%U;'1486=.86UE)UT[#0H@("`@"2`@("`@("`@("`@
M('T-"B`@("`@("`@("`@"2`)?0T*("`@("`@("`@("`@("`@("1A='1S(#T@
M87)R87DH*3L-"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;
M)W1Y<&5(:6YT<R==(#T]/2!T<G5E*2![#0H@("`@("`@("`@("`@("`@("`@
M("1A='1S6R1T:&ES+3YO<'1I;VYS6R=T>7!E071T<FEB=71E)UU=(#T@9V5T
M='EP92@D=F%L=64I.PT*("`@(`D)"0EI9B`H)&ME>2`A/3T@)&]R:6=+97DI
M('L-"B`@("`)"0D)"21A='1S6R1T:&ES+3YO<'1I;VYS6R=K97E!='1R:6)U
M=&4G75T@/2`H<W1R:6YG*21O<FEG2V5Y.PT*("`@(`D)"0E]#0H@("`@#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^
M;W!T:6]N<ULG8F5A=71I9GE&:6QE;&ES="==("8F("1K97D@/3T@)V1I<B<I
M('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V-U
M<F1I<BDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R
M9&ER(#T@)R<[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@)'-A=F5D:7(@/2`D=&AI<RT^7V-U<F1I<CL-"B`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1V86QU95LG871T<FEB<R==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1V86QU95LG871T<FEB<R==
M6R=N86UE)UT@/3T@)R\G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]C=7)D:7(@/2`G+R<[#0H@("`@("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?8W5R9&ER("X]("<O)R`N("1V86QU95LG871T<FEB<R==6R=N86UE
M)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@("`@
M("!I9B`H:7-?<W1R:6YG*"1V86QU92D@)B8@)'9A;'5E("8F("@D=F%L=65[
M<W1R;&5N*"1V86QU92D@+2`Q?2`]/2`B7&XB*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`D=F%L=64@+CT@<W1R7W)E<&5A="@D=&AI<RT^;W!T:6]N<ULG
M:6YD96YT)UTL("1T:&ES+3Y?=&%G1&5P=&@I.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`D=&UP("X]("1T:&ES+3Y?8W)E871E6$U,
M5&%G*&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=Q;F%M92<@("`@("`]/B`D:V5Y+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=A='1R:6)U=&5S)R`]/B`D871T<RP-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8V]N=&5N="<@
M("`@/3X@)'9A;'5E("D-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*3L-"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M
M/F]P=&EO;G-;)V)E875T:69Y1FEL96QI<W0G72`F)B`D:V5Y(#T]("=D:7(G
M*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=F%L=65;)V%T
M=')I8G,G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T;7`@+CT@
M)R`\(2TM("<@+B`D=&AI<RT^7V-U<F1I<B`N("<@+2T^)SL-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D<V%V961I<BDI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^7V-U<F1I<BD[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R9&ER(#T@)'-A=F5D:7([
M#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'1M
M<"`N/2`D=&AI<RT^;W!T:6]N<ULG;&EN96)R96%K)UT[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`-"B`@("`@("`@("`@("1T:&ES+3Y?=&%G1&5P
M=&@M+3L-"B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG:6YD96YT
M)UTA/3UN=6QL("8F("1T:&ES+3Y?=&%G1&5P=&@^,"D@>PT*("`@("`@("`@
M("`@("`@("1T;7`@+CT@<W1R7W)E<&5A="@D=&AI<RT^;W!T:6]N<ULG:6YD
M96YT)UTL("1T:&ES+3Y?=&%G1&5P=&@I.PT*("`@("`@("`@("`@?0T*("`@
M(`T*("`@(`D):68@*'1R:6TH)'1M<"D@/3T]("<G*2![#0H@("`@"0D))'1M
M<"`](&YU;&P[#0H@("`@"0E]#0H@("`@"0D-"B`@("`@("`@("`@("1T86<@
M/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<6YA;64G
M("`@("`@/3X@)'1A9TYA;64L#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V-O;G1E;G0G("`@(#T^("1T;7`L#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V%T=')I8G5T97,G(#T^("1A='1R:6)U=&5S#0H@("`@("`@
M("`@("`@("`@("`@("`@("`I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M=&AI<RT^;W!T:6]N<ULG='EP94AI;G1S)UT@/3T]('1R=64I('L-"B`@("`@
M("`@("`@(&EF("@A:7-S970H)'1A9ULG871T<FEB=71E<R==6R1T:&ES+3YO
M<'1I;VYS6R=T>7!E071T<FEB=71E)UU=*2D@>PT*("`@("`@("`@("`@("`@
M("1T86=;)V%T=')I8G5T97,G75LD=&AI<RT^;W!T:6]N<ULG='EP94%T=')I
M8G5T92==72`]("=A<G)A>2<[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"@T*("`@("`@("`D<W1R:6YG(#T@)'1H:7,M/E]C<F5A=&5834Q486<H)'1A
M9RP@9F%L<V4I.PT*("`@("`@("!R971U<FX@)'-T<FEN9SL-"B`@("!]#0H@
M(`T*("`@+RHJ#0H@("`@*B!C<F5A=&4@82!T86<@9G)O;2!A;B!A<G)A>0T*
M("`@("H@=&AI<R!M971H;V0@87=A:71S(&%N(&%R<F%Y(&EN('1H92!F;VQL
M;W=I;F<@9F]R;6%T#0H@("`@*B!A<G)A>2@-"B`@("`J("`@("`@("=Q;F%M
M92<@("`@("`@(#T^("1T86=.86UE+`T*("`@("H@("`@("`@)V%T=')I8G5T
M97,G("`@/3X@87)R87DH*2P-"B`@("`J("`@("`@("=C;VYT96YT)R`@("`@
M(#T^("1C;VYT96YT+"`@("`@("\O(&]P=&EO;F%L#0H@("`@*B`@("`@("`G
M;F%M97-P86-E)R`@("`]/B`D;F%M97-P86-E("`@("`O+R!O<'1I;VYA;`T*
M("`@("H@("`@("`@)VYA;65S<&%C955R:2<@/3X@)&YA;65S<&%C955R:2`@
M+R\@;W!T:6]N86P-"B`@("`J("`@*0T*("`@("H-"B`@("`J($!A8V-E<W,@
M("!P<FEV871E#0H@("`@*B!`<&%R86T@("`@87)R87D@("`D=&%G('1A9R!D
M969I;FET:6]N#0H@("`@*B!`<&%R86T@("`@8F]O;&5A;B`D<F5P;&%C945N
M=&ET:65S('=H971H97(@=&\@<F5P;&%C92!834P@96YT:71I97,@:6X@8V]N
M=&5N="!O<B!N;W0-"B`@("`J($!R971U<FX@("!S=')I;F<@("1S=')I;F<@
M6$U,('1A9PT*("`@("HO#0H@("`@9G5N8W1I;VX@7V-R96%T95A-3%1A9R@@
M)'1A9RP@)')E<&QA8V5%;G1I=&EE<R`]('1R=64@*0T*("`@('L-"B`@("`@
M("`@:68@*"1T:&ES+3YO<'1I;VYS6R=I;F1E;G1!='1R:6)U=&5S)UT@(3T]
M(&9A;'-E*2![#0H@("`@("`@("`@("`D;75L=&EL:6YE(#T@=')U93L-"B`@
M("`@("`@("`@("1I;F1E;G0@("`@/2!S=')?<F5P96%T*"1T:&ES+3YO<'1I
M;VYS6R=I;F1E;G0G72P@)'1H:7,M/E]T86=$97!T:"D[#0H-"B`@("`@("`@
M("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG:6YD96YT071T<FEB=71E<R==(#T]
M("=?875T;R<I('L-"B`@("`@("`@("`@("`@("`D:6YD96YT("X]('-T<E]R
M97!E870H)R`G+"`H<W1R;&5N*"1T86=;)W%N86UE)UTI*S(I*3L-"@T*("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D:6YD96YT("X]
M("1T:&ES+3YO<'1I;VYS6R=I;F1E;G1!='1R:6)U=&5S)UT[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D;75L=&EL
M:6YE(#T@9F%L<V4[#0H@("`@("`@("`@("`D:6YD96YT("`@(#T@9F%L<V4[
M#0H@("`@("`@('T-"B`@("`-"B`@("`@("`@:68@*&ES7V%R<F%Y*"1T86=;
M)V-O;G1E;G0G72DI('L-"B`@("`@("`@("`@(&EF("AE;7!T>2@D=&%G6R=C
M;VYT96YT)UTI*2![#0H@("`@("`@("`@("`@("`@)'1A9ULG8V]N=&5N="==
M(#T@("`G)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E:68H:7-?
M<V-A;&%R*"1T86=;)V-O;G1E;G0G72D@)B8@*'-T<FEN9RDD=&%G6R=C;VYT
M96YT)UT@/3T@)R<I('L-"B`@("`@("`@("`@("1T86=;)V-O;G1E;G0G72`]
M("`@)R<[#0H@("`@("`@('T-"B`@("`-"B`@("`@("`@:68@*&ES7W-C86QA
M<B@D=&%G6R=C;VYT96YT)UTI('Q\(&ES7VYU;&PH)'1A9ULG8V]N=&5N="==
M*2D@>PT*("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=E;F-O9&EN
M9R==(#T]("=55$8M."<@)B8-"B`@("`@("`@("`@("`@("`@('9E<G-I;VY?
M8V]M<&%R92AP:'!V97)S:6]N*"DL("<U+C`N,"<L("=L="<I*2![#0H@("`@
M("`@("`@("`@("`@)&5N8V]D:6YG(#T@4$5!4E]086-K86=E1FEL95]'96YE
M<F%T;W)?=C)?6$U,7U5T:6Q?14Y4251)15-?551&.%]834P[#0H@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1E;F-O9&EN9R`](%!%
M05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL7T5.5$E42453
M7UA-3#L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T86<@/2!014%2
M7U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ8W)E871E5&%G
M1G)O;4%R<F%Y*"1T86<L("1R97!L86-E16YT:71I97,L("1M=6QT:6QI;F4L
M("1I;F1E;G0L("1T:&ES+3YO<'1I;VYS6R=L:6YE8G)E86LG72P@)&5N8V]D
M:6YG*3L-"B`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1T86=;)V-O;G1E
M;G0G72DI('L-"B`@("`@("`@("`@("1T86<@("`@/2`@("1T:&ES+3Y?<V5R
M:6%L:7IE07)R87DH)'1A9ULG8V]N=&5N="==+"`D=&%G6R=Q;F%M92==+"`D
M=&%G6R=A='1R:6)U=&5S)UTI.PT*("`@("`@("!](&5L<V5I9B`H:7-?;V)J
M96-T*"1T86=;)V-O;G1E;G0G72DI('L-"B`@("`@("`@("`@("1T86<@("`@
M/2`@("1T:&ES+3Y?<V5R:6%L:7IE3V)J96-T*"1T86=;)V-O;G1E;G0G72P@
M)'1A9ULG<6YA;64G72P@)'1A9ULG871T<FEB=71E<R==*3L-"B`@("`@("`@
M?2!E;'-E:68@*&ES7W)E<V]U<F-E*"1T86=;)V-O;G1E;G0G72DI('L-"B`@
M("`@("`@("`@('-E='1Y<&4H)'1A9ULG8V]N=&5N="==+"`G<W1R:6YG)RD[
M#0H@("`@("`@("`@("`D=&%G("`@(#T@("!014%27U!A8VMA9V5&:6QE7T=E
M;F5R871O<E]V,E]834Q?571I;#HZ8W)E871E5&%G1G)O;4%R<F%Y*"1T86<L
M("1R97!L86-E16YT:71I97,I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B`@)'1A9SL-"B`@("!]#0I]#0H-"B\O('=E;&PL(&ET)W,@;VYE('=A>2!T
M;R!D;R!T:&EN9W,@=VET:&]U="!E>'1R82!D97!S("XN+@T*+RH@=FEM.B!S
M970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30Z("HO#0HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@4$A0(%9E<G-I;VX@
M-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M#0HO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`R(%1H92!02%`@1W)O=7`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@
M("`@("!\#0HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G
M92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P-"B\O('P@
M879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\#0HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C
M;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P-
M"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P
M;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`T*+R\@?"!L:6-E;G-E
M0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L-"B\O('P@075T:&]R<SH@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P
M:'`M=&]O;',N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+PT*+R\@("`@)$ED.B!V,BYP
M:'`L=B`Q+C,T(#(P,#8O,#,O,#(@,C`Z-3`Z-3D@8V5L;&]G($5X<"`D#0H-
M"B\J*@T*("H@97)R;W(@8V]D92!F;W(@:6YV86QI9"!C:&%R<R!I;B!834P@
M;F%M90T*("HO#0ID969I;F4H(E!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R
M7W8R7UA-3%]5=&EL7T524D]27TE.5D%,241?0TA!4E,B+"`U,2D[#0H-"B\J
M*@T*("H@97)R;W(@8V]D92!F;W(@:6YV86QI9"!C:&%R<R!I;B!834P@;F%M
M90T*("HO#0ID969I;F4H(E!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R
M7UA-3%]5=&EL7T524D]27TE.5D%,241?4U1!4E0B+"`U,BD[#0H-"B\J*@T*
M("H@97)R;W(@8V]D92!F;W(@;F]N+7-C86QA<B!T86<@8V]N=&5N=`T*("HO
M#0ID969I;F4H(E!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5
M=&EL7T524D]27TY/3E]30T%,05)?0T].5$5.5"(L(#8P*3L-"B`@("`-"B\J
M*@T*("H@97)R;W(@8V]D92!F;W(@;6ES<VEN9R!T86<@;F%M90T*("HO#0ID
M969I;F4H(E!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL
M7T524D]27TY/7U1!1U].04U%(BP@-C$I.PT*("`@(`T*+RHJ#0H@*B!R97!L
M86-E(%A-3"!E;G1I=&EE<PT*("HO#0ID969I;F4H(E!%05)?4&%C:V%G949I
M;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL7U)%4$Q!0T5?14Y4251)15,B+"`Q
M*3L-"@T*+RHJ#0H@*B!E;6)E9&0@8V]N=&5N="!I;B!A($-$871A(%-E8W1I
M;VX-"B`J+PT*9&5F:6YE*")014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V
M,E]834Q?571I;%]#1$%405]314-424].(BP@,BD[#0H-"B\J*@T*("H@9&\@
M;F]T(')E<&QA8V4@96YT:71I=&5S#0H@*B\-"F1E9FEN92@B4$5!4E]086-K
M86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?14Y4251)15-?3D].12(L
M(#`I.PT*#0HO*BH-"B`J(')E<&QA8V4@86QL(%A-3"!E;G1I=&ET97,-"B`J
M(%1H:7,@<V5T=&EN9R!W:6QL(')E<&QA8V4@/"P@/BP@(BP@)R!A;F0@)@T*
M("HO#0ID969I;F4H(E!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-
M3%]5=&EL7T5.5$E424537UA-3"(L(#$I.PT*#0HO*BH-"B`J(')E<&QA8V4@
M;VYL>2!R97%U:7)E9"!834P@96YT:71I=&5S#0H@*B!4:&ES('-E='1I;F<@
M=VEL;"!R97!L86-E(#PL("(@86YD("8-"B`J+PT*9&5F:6YE*")014%27U!A
M8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;%]%3E1)5$E%4U]834Q?
M4D5154E2140B+"`R*3L-"@T*+RHJ#0H@*B!R97!L86-E($A434P@96YT:71I
M=&5S#0H@*B!`;&EN:R`@("!H='1P.B\O=W=W+G!H<"YN970O:'1M;&5N=&ET
M:65S#0H@*B\-"F1E9FEN92@B4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?
M=C)?6$U,7U5T:6Q?14Y4251)15-?2%1-3"(L(#,I.PT*#0HO*BH-"B`J(')E
M<&QA8V4@86QL(%A-3"!E;G1I=&ET97,L(&%N9"!E;F-O9&4@9G)O;2!)4T\M
M.#@U.2TQ('1O(%541BTX#0H@*B!4:&ES('-E='1I;F<@=VEL;"!R97!L86-E
M(#PL(#XL("(L("<@86YD("8-"B`J+PT*9&5F:6YE*")014%27U!A8VMA9V5&
M:6QE7T=E;F5R871O<E]V,E]834Q?571I;%]%3E1)5$E%4U]55$8X7UA-3"(L
M(#0I.PT*#0HO*BH-"B`J('5T:6QI='D@8VQA<W,@9F]R('=O<FMI;F<@=VET
M:"!834P@9&]C=6UE;G1S#0H@*B`-"B`J(&-U<W1O;6EZ960@=F5R<VEO;B!O
M9B!834Q?571I;"`P+C8N,`T*("H-"B`J($!C871E9V]R>2!834P-"B`J($!P
M86-K86=E("!014%2#0H@*B!`=F5R<VEO;B`@,"XV+C`-"B`J($!A=71H;W(@
M("!3=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"YN970^#0H@*B!`875T:&]R
M("`@1W)E9V]R>2!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("HO#0IC;&%S
M<R!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;"![#0H-
M"B`@("\J*@T*("`@("H@<F5T=7)N($%022!V97)S:6]N#0H@("`@*@T*("`@
M("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'-T871I8PT*("`@("H@0')E
M='5R;B`@('-T<FEN9R`@)'9E<G-I;VX@05!)('9E<G-I;VX-"B`@("`J+PT*
M("`@(&9U;F-T:6]N(&%P:59E<G-I;VXH*0T*("`@('L-"B`@("`@("`@<F5T
M=7)N("(P+C8B.PT*("`@('T-"@T*("`@+RHJ#0H@("`@*B!R97!L86-E(%A-
M3"!E;G1I=&EE<PT*("`@("H-"B`@("`J(%=I=&@@=&AE(&]P=&EO;F%L('-E
M8V]N9"!P87)A;65T97(L('EO=2!M87D@<V5L96-T+"!W:&EC:`T*("`@("H@
M96YT:71I97,@<VAO=6QD(&)E(')E<&QA8V5D+@T*("`@("H-"B`@("`J(#QC
M;V1E/@T*("`@("H@<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G.PT*("`@
M("H@#0H@("`@*B`O+R!R97!L86-E(%A-3"!E;G1I=&5S.@T*("`@("H@)'-T
M<FEN9R`](%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL
M.CIR97!L86-E16YT:71I97,H(E1H:7,@<W1R:6YG(&-O;G1A:6YS(#P@)B`^
M+B(I.PT*("`@("H@/"]C;V1E/@T*("`@("H-"B`@("`J($!A8V-E<W,@("!P
M=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P87)A;2`@("!S=')I;F<@
M('-T<FEN9R!W:&5R92!834P@<W!E8VEA;"!C:&%R<R!S:&]U;&0@8F4@<F5P
M;&%C960-"B`@("`J($!P87)A;2`@("!I;G1E9V5R('-E='1I;F<@9F]R(&5N
M=&ET:65S(&EN(&%T=')I8G5T92!V86QU97,@*&]N92!O9B!014%27U!A8VMA
M9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;%]%3E1)5$E%4U]834PL(%!%
M05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL7T5.5$E42453
M7UA-3%]215%525)%1"P@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?
M6$U,7U5T:6Q?14Y4251)15-?2%1-3"D-"B`@("`J($!R971U<FX@("!S=')I
M;F<@('-T<FEN9R!W:71H(')E<&QA8V5D(&-H87)S#0H@("`@*B\-"B`@("!F
M=6YC=&EO;B!R97!L86-E16YT:71I97,H)'-T<FEN9RP@)')E<&QA8V5%;G1I
M=&EE<R`](%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL
M7T5.5$E424537UA-3"D-"B`@("![#0H@("`@("`@('-W:71C:"`H)')E<&QA
M8V5%;G1I=&EE<RD@>PT*("`@("`@("`@("`@8V%S92!014%27U!A8VMA9V5&
M:6QE7T=E;F5R871O<E]V,E]834Q?571I;%]%3E1)5$E%4U]55$8X7UA-3#H-
M"B`@("`@("`@("`@("`@("!R971U<FX@<W1R='(H=71F.%]E;F-O9&4H)'-T
M<FEN9RDL87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G)B<@(#T^("<F86UP.R<L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G/B<@(#T^("<F9W0[)RP-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<\)R`@
M/3X@)R9L=#LG+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)R(G("`]/B`G)G%U;W0[)RP-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=<)R<@/3X@)R9A<&]S.R<@*2D[
M#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E(%!%
M05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL7T5.5$E42453
M7UA-3#H-"B`@("`@("`@("`@("`@("!R971U<FX@<W1R='(H)'-T<FEN9RQA
M<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("<F)R`@/3X@)R9A;7`[)RP-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("<^)R`@/3X@)R9G=#LG+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)SPG("`]/B`G)FQT
M.R<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G(B<@(#T^("<F<75O=#LG+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)UPG)R`]/B`G)F%P;W,[)R`I*3L-"B`@("`@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@4$5!4E]086-K
M86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?14Y4251)15-?6$U,7U)%
M455)4D5$.@T*("`@("`@("`@("`@("`@(')E='5R;B!S=')T<B@D<W1R:6YG
M+&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)R8G("`]/B`G)F%M<#LG+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)SPG("`]/B`G)FQT.R<L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G(B<@(#T^("<F
M<75O=#LG("DI.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@
M("`@8V%S92!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I
M;%]%3E1)5$E%4U](5$U,.@T*("`@("`@("`@("`@("`@(')E='5R;B!H=&UL
M<W!E8VEA;&-H87)S*"1S=')I;F<I.PT*("`@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<W1R:6YG.PT*("`@('T-
M"@T*("`@+RHJ#0H@("`@*B!B=6EL9"!A;B!X;6P@9&5C;&%R871I;VX-"B`@
M("`J#0H@("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?;VYC92`G6$U,+U5T
M:6PN<&AP)SL-"B`@("`J(`T*("`@("H@+R\@9V5T(&%N(%A-3"!D96-L87)A
M=&EO;CH-"B`@("`J("1X;6Q$96-L(#T@4$5!4E]086-K86=E1FEL95]'96YE
M<F%T;W)?=C)?6$U,7U5T:6PZ.F=E=%A-3$1E8VQA<F%T:6]N*"(Q+C`B+"`B
M551&+3@B+"!T<G5E*3L-"B`@("`J(#PO8V]D93X-"B`@("`J#0H@("`@*B!`
M86-C97-S("`@<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@("`@*B!`<&%R86T@
M("`@<W1R:6YG("`D=F5R<VEO;B`@("`@>&UL('9E<G-I;VX-"B`@("`J($!P
M87)A;2`@("!S=')I;F<@("1E;F-O9&EN9R`@("!C:&%R86-T97(@96YC;V1I
M;F<-"B`@("`J($!P87)A;2`@("!B;V]L96%N("1S=&%N9$%L;VYE("!D;V-U
M;65N="!I<R!S=&%N9&%L;VYE("AO<B!N;W0I#0H@("`@*B!`<F5T=7)N("`@
M<W1R:6YG("`D9&5C;"!X;6P@9&5C;&%R871I;VX-"B`@("`J($!U<V5S("`@
M("!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ871T
M<FEB=71E<U1O4W1R:6YG*"D@=&\@<V5R:6%L:7IE('1H92!A='1R:6)U=&5S
M(&]F('1H92!834P@9&5C;&%R871I;VX-"B`@("`J+PT*("`@(&9U;F-T:6]N
M(&=E=%A-3$1E8VQA<F%T:6]N*"1V97)S:6]N(#T@(C$N,"(L("1E;F-O9&EN
M9R`](&YU;&PL("1S=&%N9&%L;VYE(#T@;G5L;"D-"B`@("![#0H@("`@("`@
M("1A='1R:6)U=&5S(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(G9E<G-I;VXB(#T^("1V97)S:6]N+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@*3L-"B`@("`@("`@+R\@861D(&5N8V]D:6YG#0H@("`@
M("`@(&EF("@D96YC;V1I;F<@(3T](&YU;&PI('L-"B`@("`@("`@("`@("1A
M='1R:6)U=&5S6R)E;F-O9&EN9R)=(#T@)&5N8V]D:6YG.PT*("`@("`@("!]
M#0H@("`@("`@("\O(&%D9"!S=&%N9&%L;VYE+"!I9B!S<&5C:69I960-"B`@
M("`@("`@:68@*"1S=&%N9&%L;VYE("$]/2!N=6QL*2![#0H@("`@("`@("`@
M("`D871T<FEB=71E<ULB<W1A;F1A;&]N92)=(#T@)'-T86YD86QO;F4@/R`B
M>65S(B`Z(")N;R([#0H@("`@("`@('T-"B`@("`@("`@#0H@("`@("`@(')E
M='5R;B!S<')I;G1F*"(\/WAM;"5S/SXB+"!014%27U!A8VMA9V5&:6QE7T=E
M;F5R871O<E]V,E]834Q?571I;#HZ871T<FEB=71E<U1O4W1R:6YG*"1A='1R
M:6)U=&5S+"!F86QS92DI.PT*("`@('T-"@T*("`@+RHJ#0H@("`@*B!B=6EL
M9"!A(&1O8W5M96YT('1Y<&4@9&5C;&%R871I;VX-"B`@("`J#0H@("`@*B`\
M8V]D93X-"B`@("`J(')E<75I<F5?;VYC92`G6$U,+U5T:6PN<&AP)SL-"B`@
M("`J(`T*("`@("H@+R\@9V5T(&$@9&]C='EP92!D96-L87)A=&EO;CH-"B`@
M("`J("1X;6Q$96-L(#T@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?
M6$U,7U5T:6PZ.F=E=$1O8U1Y<&5$96-L87)A=&EO;B@B<F]O=%1A9R(L(FUY
M1&]C5'EP92YD=&0B*3L-"B`@("`J(#PO8V]D93X-"B`@("`J#0H@("`@*B!`
M86-C97-S("`@<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@("`@*B!`<&%R86T@
M("`@<W1R:6YG("`D<F]O="`@("`@("`@(&YA;64@;V8@=&AE(')O;W0@=&%G
M#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D=7)I("`@("`@("`@('5R:2!O
M9B!T:&4@9&]C='EP92!D969I;FET:6]N("AO<B!A<G)A>2!W:71H('5R:2!A
M;F0@<'5B;&EC(&ED*0T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&EN=&5R
M;F%L1'1D("!I;G1E<FYA;"!D=&0@96YT<FEE<R`@(`T*("`@("H@0')E='5R
M;B`@('-T<FEN9R`@)&1E8VP@("`@("`@("!D;V-T>7!E(&1E8VQA<F%T:6]N
M#0H@("`@*B!`<VEN8V4@("`@,"XR#0H@("`@*B\-"B`@("!F=6YC=&EO;B!G
M971$;V-4>7!E1&5C;&%R871I;VXH)')O;W0L("1U<FD@/2!N=6QL+"`D:6YT
M97)N86Q$=&0@/2!N=6QL*0T*("`@('L-"B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1U<FDI*2![#0H@("`@("`@("`@("`D<F5F(#T@<W!R:6YT9B@@)R!054),
M24,@(B5S(B`B)7,B)RP@)'5R:5LB:60B72P@)'5R:5LB=7)I(ET@*3L-"B`@
M("`@("`@?2!E;'-E:68@*"%E;7!T>2@D=7)I*2D@>PT*("`@("`@("`@("`@
M)')E9B`]('-P<FEN=&8H("<@4UE35$5-("(E<R(G+"`D=7)I("D[#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`D<F5F(#T@(B([#0H@("`@("`@
M('T-"@T*("`@("`@("!I9B`H96UP='DH)&EN=&5R;F%L1'1D*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N('-P<FEN=&8H(CPA1$]#5%E012`E<R5S/B(L("1R
M;V]T+"`D<F5F*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E
M='5R;B!S<')I;G1F*"(\(41/0U194$4@)7,E<R!;7&XE<UQN73XB+"`D<F]O
M="P@)')E9BP@)&EN=&5R;F%L1'1D*3L-"B`@("`@("`@?0T*("`@('T-"@T*
M("`@+RHJ#0H@("`@*B!C<F5A=&4@<W1R:6YG(')E<')E<V5N=&%T:6]N(&]F
M(&%N(&%T=')I8G5T92!L:7-T#0H@("`@*@T*("`@("H@/&-O9&4^#0H@("`@
M*B!R97%U:7)E7V]N8V4@)UA-3"]5=&EL+G!H<"<[#0H@("`@*B`-"B`@("`J
M("\O(&)U:6QD(&%N(&%T=')I8G5T92!S=')I;F<-"B`@("`J("1A='0@/2!A
M<G)A>2@-"B`@("`J("`@("`@("`@("`@("`B9F]O(B`@(#T^("`B8F%R(BP-
M"B`@("`J("`@("`@("`@("`@("`B87)G:"(@(#T^("`B=&]M871O(@T*("`@
M("H@("`@("`@("`@("`I.PT*("`@("H-"B`@("`J("1A='1,:7-T(#T@4$5!
M4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.F%T=')I8G5T
M97-4;U-T<FEN9R@D871T*3L@("`@#0H@("`@*B`\+V-O9&4^#0H@("`@*@T*
M("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'-T871I8PT*("`@("H@
M0'!A<F%M("`@(&%R<F%Y("`@("`@("`@)&%T=')I8G5T97,@("`@("`@(&%T
M=')I8G5T92!A<G)A>0T*("`@("H@0'!A<F%M("`@(&)O;VQE86Y\87)R87D@
M)'-O<G0@("`@("`@("`@("`@('-O<G0@871T<FEB=71E(&QI<W0@86QP:&%B
M971I8V%L;'DL(&UA>2!A;'-O(&)E(&%N(&%S<V]C(&%R<F%Y(&-O;G1A:6YI
M;F<@=&AE(&ME>7,@)W-O<G0G+"`G;75L=&EL:6YE)RP@)VEN9&5N="<L("=L
M:6YE8G)E86LG(&%N9"`G96YT:71I97,G#0H@("`@*B!`<&%R86T@("`@8F]O
M;&5A;B`@("`@("`D;75L=&EL:6YE("`@("`@("`@=7-E(&QI;F5B<F5A:W,L
M(&EF(&UO<F4@=&AA;B!O;F4@871T<FEB=71E(&ES(&=I=F5N#0H@("`@*B!`
M<&%R86T@("`@<W1R:6YG("`@("`@("`D:6YD96YT("`@("`@("`@("`@<W1R
M:6YG('5S960@9F]R(&EN9&5N=&%T:6]N(&]F(&UU;'1I;&EN92!A='1R:6)U
M=&5S#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@("`D;&EN96)R96%K
M("`@("`@("`@<W1R:6YG('5S960@9F]R(&QI;F5B<F5A:W,@;V8@;75L=&EL
M:6YE(&%T=')I8G5T97,-"B`@("`J($!P87)A;2`@("!I;G1E9V5R("`@("`@
M("1E;G1I=&EE<R`@("`@("`@("!S971T:6YG(&9O<B!E;G1I=&EE<R!I;B!A
M='1R:6)U=&4@=F%L=65S("AO;F4@;V8@4$5!4E]086-K86=E1FEL95]'96YE
M<F%T;W)?=C)?6$U,7U5T:6Q?14Y4251)15-?3D].12P@4$5!4E]086-K86=E
M1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?14Y4251)15-?6$U,+"!014%2
M7U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;%]%3E1)5$E%4U]8
M34Q?4D5154E2140L(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-
M3%]5=&EL7T5.5$E424537TA434PI#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R:6YG(')E<')E<V5N=&%T
M:6]N(&]F('1H92!A='1R:6)U=&5S#0H@("`@*B!`=7-E<R`@("`@4$5!4E]0
M86-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.G)E<&QA8V5%;G1I
M=&EE<R@I('1O(')E<&QA8V4@6$U,(&5N=&ET:65S(&EN(&%T=')I8G5T92!V
M86QU97,-"B`@("`J($!T;V1O("`@("!A;&QO=R!S;W)T(&%L<V\@=&\@8F4@
M86X@;W!T:6]N<R!A<G)A>0T*("`@("HO#0H@("`@9G5N8W1I;VX@871T<FEB
M=71E<U1O4W1R:6YG*"1A='1R:6)U=&5S+"`D<V]R="`]('1R=64L("1M=6QT
M:6QI;F4@/2!F86QS92P@)&EN9&5N="`]("<@("`@)RP@)&QI;F5B<F5A:R`]
M(")<;B(L("1E;G1I=&EE<R`](%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R
M7W8R7UA-3%]5=&EL7T5.5$E424537UA-3"D-"B`@("![#0H@("`@("`@("\J
M*@T*("`@("`@("`@*B!S96-O;F0@<&%R86UE=&5R(&UA>2!B92!A;B!A<G)A
M>0T*("`@("`@("`@*B\-"B`@("`@("`@:68@*&ES7V%R<F%Y*"1S;W)T*2D@
M>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1S;W)T6R=M=6QT:6QI;F4G72DI
M('L-"B`@("`@("`@("`@("`@("`D;75L=&EL:6YE(#T@)'-O<G1;)VUU;'1I
M;&EN92==.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T
M*"1S;W)T6R=I;F1E;G0G72DI('L-"B`@("`@("`@("`@("`@("`D:6YD96YT
M(#T@)'-O<G1;)VEN9&5N="==.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@:68@*&ES<V5T*"1S;W)T6R=L:6YE8G)E86LG72DI('L-"B`@("`@("`@
M("`@("`@("`D;75L=&EL:6YE(#T@)'-O<G1;)VQI;F5B<F5A:R==.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1S;W)T6R=E;G1I
M=&EE<R==*2D@>PT*("`@("`@("`@("`@("`@("1E;G1I=&EE<R`]("1S;W)T
M6R=E;G1I=&EE<R==.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@
M*&ES<V5T*"1S;W)T6R=S;W)T)UTI*2![#0H@("`@("`@("`@("`@("`@)'-O
M<G0@/2`D<V]R=%LG<V]R="==.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`D<V]R="`]('1R=64[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@)'-T<FEN9R`]("<G.PT*("`@("`@("!I9B`H
M:7-?87)R87DH)&%T=')I8G5T97,I("8F("%E;7!T>2@D871T<FEB=71E<RDI
M('L-"B`@("`@("`@("`@(&EF("@D<V]R="D@>PT*("`@("`@("`@("`@("`@
M(&MS;W)T*"1A='1R:6)U=&5S*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF*"`A)&UU;'1I;&EN92!\?"!C;W5N="@D871T<FEB=71E<RD@/3T@
M,2D@>PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1A='1R:6)U=&5S(&%S
M("1K97D@/3X@)'9A;'5E*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@D
M96YT:71I97,@(3T@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,
M7U5T:6Q?14Y4251)15-?3D].12D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)'9A;'5E(#T@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,
M7U5T:6PZ.G)E<&QA8V5%;G1I=&EE<R@D=F%L=64L("1E;G1I=&EE<RD[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)'-T
M<FEN9R`N/2`G("<N)&ME>2XG/2(G+B1V86QU92XG(B<[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`D9FER<W0@/2!T<G5E.PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1A
M='1R:6)U=&5S(&%S("1K97D@/3X@)'9A;'5E*2![#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@D96YT:71I97,@(3T@4$5!4E]086-K86=E1FEL95]'96YE
M<F%T;W)?=C)?6$U,7U5T:6Q?14Y4251)15-?3D].12D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)'9A;'5E(#T@4$5!4E]086-K86=E1FEL95]'96YE
M<F%T;W)?=C)?6$U,7U5T:6PZ.G)E<&QA8V5%;G1I=&EE<R@D=F%L=64L("1E
M;G1I=&EE<RD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@:68@*"1F:7)S="D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)'-T<FEN9R`N/2`B("(N)&ME>2XG/2(G+B1V86QU92XG(B<[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D9FER<W0@/2!F86QS93L-"B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1S=')I;F<@+CT@)&QI;F5B<F5A:RXD:6YD96YT+B1K97DN)STB)RXD=F%L
M=64N)R(G.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B`D<W1R:6YG.PT*("`@('T-"@T*("`@+RHJ#0H@("`@*B!C<F5A=&4@82!T
M86<-"B`@("`J#0H@("`@*B!4:&ES(&UE=&AO9"!W:6QL(&-A;&P@4$5!4E]0
M86-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.F-R96%T951A9T9R
M;VU!<G)A>2@I+"!W:&EC:`T*("`@("H@:7,@;6]R92!F;&5X:6)L92X-"B`@
M("`J#0H@("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?;VYC92`G6$U,+U5T
M:6PN<&AP)SL-"B`@("`J(`T*("`@("H@+R\@8W)E871E(&%N(%A-3"!T86<Z
M#0H@("`@*B`D=&%G(#T@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?
M6$U,7U5T:6PZ.F-R96%T951A9R@B;7E.<SIM>51A9R(L(&%R<F%Y*")F;V\B
M(#T^(")B87(B*2P@(E1H:7,@:7,@:6YS:61E('1H92!T86<B+"`B:'1T<#HO
M+W=W=RYW,V,N;W)G+VUY3G,C(BD[#0H@("`@*B`\+V-O9&4^#0H@("`@*@T*
M("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'-T871I8PT*("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@)'%N86UE("`@("`@("`@("`@('%U86QI9FEE
M9"!T86=N86UE("AI;F-L=61I;F<@;F%M97-P86-E*0T*("`@("H@0'!A<F%M
M("`@(&%R<F%Y("`@)&%T=')I8G5T97,@("`@("`@(&%R<F%Y(&-O;G1A:6YG
M(&%T=')I8G5T97,-"B`@("`J($!P87)A;2`@("!M:7AE9"`@("1C;VYT96YT
M#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D;F%M97-P86-E57)I("`@("`@
M55))(&]F('1H92!N86UE<W!A8V4-"B`@("`J($!P87)A;2`@("!I;G1E9V5R
M("1R97!L86-E16YT:71I97,@("!W:&5T:&5R('1O(')E<&QA8V4@6$U,('-P
M96-I86P@8VAA<G,@:6X@8V]N=&5N="P@96UB961D(&ET(&EN(&$@0T1A=&$@
M<V5C=&EO;B!O<B!N;VYE(&]F(&)O=&@-"B`@("`J($!P87)A;2`@("!B;V]L
M96%N("1M=6QT:6QI;F4@("`@("`@("!W:&5T:&5R('1O(&-R96%T92!A(&UU
M;'1I;&EN92!T86<@=VAE<F4@96%C:"!A='1R:6)U=&4@9V5T<R!W<FET=&5N
M('1O(&$@<VEN9VQE(&QI;F4-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1I
M;F1E;G0@("`@("`@("`@("!S=')I;F<@=7-E9"!T;R!I;F1E;G0@871T<FEB
M=71E<R`H7V%U=&\@:6YD96YT<R!A='1R:6)U=&5S('-O('1H97D@<W1A<G0@
M870@=&AE('-A;64@8V]L=6UN*0T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M)&QI;F5B<F5A:R`@("`@("`@('-T<FEN9R!U<V5D(&9O<B!L:6YE8G)E86MS
M#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D96YC;V1I;F<@("`@("`@("`@
M96YC;V1I;F<@=&AA="!S:&]U;&0@8F4@=7-E9"!T;R!T<F%N<VQA=&4@8V]N
M=&5N=`T*("`@("H@0')E='5R;B`@('-T<FEN9R`@)'-T<FEN9R`@("`@("`@
M("`@(%A-3"!T86<-"B`@("`J($!S964@("`@("!014%27U!A8VMA9V5&:6QE
M7T=E;F5R871O<E]V,E]834Q?571I;#HZ8W)E871E5&%G1G)O;4%R<F%Y*"D-
M"B`@("`J($!U<V5S("`@("!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V
M,E]834Q?571I;#HZ8W)E871E5&%G1G)O;4%R<F%Y*"D@=&\@8W)E871E('1H
M92!T86<-"B`@("`J+PT*("`@(&9U;F-T:6]N(&-R96%T951A9R@D<6YA;64L
M("1A='1R:6)U=&5S(#T@87)R87DH*2P@)&-O;G1E;G0@/2!N=6QL+"`D;F%M
M97-P86-E57)I(#T@;G5L;"P@)')E<&QA8V5%;G1I=&EE<R`](%!%05)?4&%C
M:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL7U)%4$Q!0T5?14Y4251)
M15,L("1M=6QT:6QI;F4@/2!F86QS92P@)&EN9&5N="`](")?875T;R(L("1L
M:6YE8G)E86L@/2`B7&XB+"`D96YC;V1I;F<@/2!014%27U!A8VMA9V5&:6QE
M7T=E;F5R871O<E]V,E]834Q?571I;%]%3E1)5$E%4U]834PI#0H@("`@>PT*
M("`@("`@("`D=&%G(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`B
M<6YA;64B("`@("`@/3X@)'%N86UE+`T*("`@("`@("`@("`@("`@("`@("`@
M(F%T=')I8G5T97,B(#T^("1A='1R:6)U=&5S#0H@("`@("`@("`@("`@("`@
M("`@("D[#0H-"B`@("`@("`@+R\@861D('1A9R!C;VYT96YT#0H@("`@("`@
M(&EF("@D8V]N=&5N="`A/3T@;G5L;"D@>PT*("`@("`@("`@("`@)'1A9ULB
M8V]N=&5N=")=(#T@)&-O;G1E;G0[#0H@("`@("`@('T-"B`@("`@("`@#0H@
M("`@("`@("\O(&%D9"!N86UE<W!A8V4@57)I#0H@("`@("`@(&EF("@D;F%M
M97-P86-E57)I("$]/2!N=6QL*2![#0H@("`@("`@("`@("`D=&%G6R)N86UE
M<W!A8V55<FDB72`]("1N86UE<W!A8V55<FD[#0H@("`@("`@('T-"@T*("`@
M("`@("!R971U<FX@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,
M7U5T:6PZ.F-R96%T951A9T9R;VU!<G)A>2@D=&%G+"`D<F5P;&%C945N=&ET
M:65S+"`D;75L=&EL:6YE+"`D:6YD96YT+"`D;&EN96)R96%K+"`D96YC;V1I
M;F<I.PT*("`@('T-"@T*("`@+RHJ#0H@("`@*B!C<F5A=&4@82!T86<@9G)O
M;2!A;B!A<G)A>0T*("`@("H@=&AI<R!M971H;V0@87=A:71S(&%N(&%R<F%Y
M(&EN('1H92!F;VQL;W=I;F<@9F]R;6%T#0H@("`@*B`\<')E/@T*("`@("H@
M87)R87DH#0H@("`@*B`@(G%N86UE(B`@("`@("`@/3X@)'%N86UE("`@("`@
M("`@+R\@<75A;&EF:65D(&YA;64@;V8@=&AE('1A9PT*("`@("H@(")N86UE
M<W!A8V4B("`@(#T^("1N86UE<W!A8V4@("`@("\O(&YA;65S<&%C92!P<F5F
M:7@@*&]P=&EO;F%L+"!I9B!Q;F%M92!I<R!S<&5C:69I960@;W(@;F\@;F%M
M97-P86-E*0T*("`@("H@(")L;V-A;'!A<G0B("`@(#T^("1L;V-A;'!A<G0L
M("`@("\O(&QO8V%L('!A<G0@;V8@=&AE('1A9VYA;64@*&]P=&EO;F%L+"!I
M9B!Q;F%M92!I<R!S<&5C:69I960I#0H@("`@*B`@(F%T=')I8G5T97,B("`@
M/3X@87)R87DH*2P@("`@("`@+R\@87)R87D@8V]N=&%I;FEN9R!A;&P@871T
M<FEB=71E<R`H;W!T:6]N86PI#0H@("`@*B`@(F-O;G1E;G0B("`@("`@/3X@
M)&-O;G1E;G0L("`@("`@+R\@=&%G(&-O;G1E;G0@*&]P=&EO;F%L*0T*("`@
M("H@(")N86UE<W!A8V55<FDB(#T^("1N86UE<W!A8V55<FD@("\O(&YA;65S
M<&%C955R:2!F;W(@=&AE(&=I=F5N(&YA;65S<&%C92`H;W!T:6]N86PI#0H@
M("`@*B`@("D-"B`@("`J(#PO<')E/@T*("`@("H-"B`@("`J(#QC;V1E/@T*
M("`@("H@<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G.PT*("`@("H@#0H@
M("`@*B`D=&%G(#T@87)R87DH#0H@("`@*B`@("`@("`@("`@(G%N86UE(B`@
M("`@("`@/3X@(F9O;SIB87(B+`T*("`@("H@("`@("`@("`@(")N86UE<W!A
M8V55<FDB(#T^(")H='1P.B\O9F]O+F-O;2(L#0H@("`@*B`@("`@("`@("`@
M(F%T=')I8G5T97,B("`@/3X@87)R87DH(")K97DB(#T^(")V86QU92(L(")A
M<F=H(B`]/B`B9G)U:70F=F5G971A8FQE(B`I+`T*("`@("H@("`@("`@("`@
M(")C;VYT96YT(B`@("`@(#T^(")))VT@:6YS:61E('1H92!T86<B+`T*("`@
M("H@("`@("`@("`@("`I.PT*("`@("H@+R\@8W)E871I;F<@82!T86<@=VET
M:"!Q=6%L:69I960@;F%M92!A;F0@;F%M97-P86-E57)I#0H@("`@*B`D<W1R
M:6YG(#T@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ
M.F-R96%T951A9T9R;VU!<G)A>2@D=&%G*3L-"B`@("`J(#PO8V]D93X-"B`@
M("`J#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@
M("`@*B!`<&%R86T@("`@87)R87D@("`D=&%G("`@("`@("`@("`@("`@=&%G
M(&1E9FEN:71I;VX-"B`@("`J($!P87)A;2`@("!I;G1E9V5R("1R97!L86-E
M16YT:71I97,@("!W:&5T:&5R('1O(')E<&QA8V4@6$U,('-P96-I86P@8VAA
M<G,@:6X@8V]N=&5N="P@96UB961D(&ET(&EN(&$@0T1A=&$@<V5C=&EO;B!O
M<B!N;VYE(&]F(&)O=&@-"B`@("`J($!P87)A;2`@("!B;V]L96%N("1M=6QT
M:6QI;F4@("`@("`@("!W:&5T:&5R('1O(&-R96%T92!A(&UU;'1I;&EN92!T
M86<@=VAE<F4@96%C:"!A='1R:6)U=&4@9V5T<R!W<FET=&5N('1O(&$@<VEN
M9VQE(&QI;F4-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1I;F1E;G0@("`@
M("`@("`@("!S=')I;F<@=7-E9"!T;R!I;F1E;G0@871T<FEB=71E<R`H7V%U
M=&\@:6YD96YT<R!A='1R:6)U=&5S('-O('1H97D@<W1A<G0@870@=&AE('-A
M;64@8V]L=6UN*0T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&QI;F5B<F5A
M:R`@("`@("`@('-T<FEN9R!U<V5D(&9O<B!L:6YE8G)E86MS#0H@("`@*B!`
M<F5T=7)N("`@<W1R:6YG("`D<W1R:6YG("`@("`@("`@("`@6$U,('1A9PT*
M("`@("H@0'-E92`@("`@(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R
M7UA-3%]5=&EL.CIC<F5A=&5486<H*0T*("`@("H@0'5S97,@("`@(%!%05)?
M4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIA='1R:6)U=&5S
M5&]3=')I;F<H*2!T;R!S97)I86QI>F4@=&AE(&%T=')I8G5T97,@;V8@=&AE
M('1A9PT*("`@("H@0'5S97,@("`@(%!%05)?4&%C:V%G949I;&5?1V5N97)A
M=&]R7W8R7UA-3%]5=&EL.CIS<&QI=%%U86QI9FEE9$YA;64H*2!T;R!G970@
M;&]C86P@<&%R="!A;F0@;F%M97-P86-E(&]F(&$@<75A;&EF:65D(&YA;64-
M"B`@("`J+PT*("`@(&9U;F-T:6]N(&-R96%T951A9T9R;VU!<G)A>2@D=&%G
M+"`D<F5P;&%C945N=&ET:65S(#T@4$5!4E]086-K86=E1FEL95]'96YE<F%T
M;W)?=C)?6$U,7U5T:6Q?4D503$%#15]%3E1)5$E%4RP@)&UU;'1I;&EN92`]
M(&9A;'-E+"`D:6YD96YT(#T@(E]A=71O(BP@)&QI;F5B<F5A:R`](")<;B(L
M("1E;F-O9&EN9R`](%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-
M3%]5=&EL7T5.5$E424537UA-3"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E
M="@D=&%G6R)C;VYT96YT(ETI("8F("%I<U]S8V%L87(H)'1A9ULB8V]N=&5N
M=")=*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05)?4&%C:V%G949I;&5?
M1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIR86ES945R<F]R*"`B4W5P<&QI960@
M;F]N+7-C86QA<B!V86QU92!A<R!T86<@8V]N=&5N="(L(%!%05)?4&%C:V%G
M949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL7T524D]27TY/3E]30T%,05)?
M0T].5$5.5"`I.PT*("`@("`@("!]#0H-"B`@("`@("`@:68@*"%I<W-E="@D
M=&%G6R=Q;F%M92==*2`F)B`A:7-S970H)'1A9ULG;&]C86Q087)T)UTI*2![
M#0H@("`@("`@("`@("!R971U<FX@4$5!4E]086-K86=E1FEL95]'96YE<F%T
M;W)?=C)?6$U,7U5T:6PZ.G)A:7-E17)R;W(H("=9;W4@;75S="!E:71H97(@
M<W5P<&QY(&$@<75A;&EF:65D(&YA;64@*'%N86UE*2!O<B!L;V-A;"!T86<@
M;F%M92`H;&]C86Q087)T*2XG+"!014%27U!A8VMA9V5&:6QE7T=E;F5R871O
M<E]V,E]834Q?571I;%]%4E)/4E].3U]404=?3D%-12`I.PT*("`@("`@("!]
M#0H-"B`@("`@("`@+R\@:68@;F\@871T<FEB=71E<R!H878@8F5E;B!S970L
M('5S92!E;7!T>2!A='1R:6)U=&5S#0H@("`@("`@(&EF("@A:7-S970H)'1A
M9ULB871T<FEB=71E<R)=*2!\?"`A:7-?87)R87DH)'1A9ULB871T<FEB=71E
M<R)=*2D@>PT*("`@("`@("`@("`@)'1A9ULB871T<FEB=71E<R)=(#T@87)R
M87DH*3L-"B`@("`@("`@?0T*("`@("`@("`-"B`@("`@("`@+R\@<75A;&EF
M:65D(&YA;64@:7,@;F]T(&=I=F5N#0H@("`@("`@(&EF("@A:7-S970H)'1A
M9ULB<6YA;64B72DI('L-"B`@("`@("`@("`@("\O(&-H96-K(&9O<B!N86UE
M<W!A8V4-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&%G6R)N86UE<W!A8V4B
M72D@)B8@(65M<'1Y*"1T86=;(FYA;65S<&%C92)=*2D@>PT*("`@("`@("`@
M("`@("`@("1T86=;(G%N86UE(ET@/2`D=&%G6R)N86UE<W!A8V4B72XB.B(N
M)'1A9ULB;&]C86Q087)T(ET[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("1T86=;(G%N86UE(ET@/2`D=&%G6R)L;V-A;%!A<G0B
M73L-"B`@("`@("`@("`@('T-"B`@("`@("`@+R\@;F%M97-P86-E(%5222!I
M<R!S970L(&)U="!N;R!N86UE<W!A8V4-"B`@("`@("`@?2!E;'-E:68@*&ES
M<V5T*"1T86=;(FYA;65S<&%C955R:2)=*2`F)B`A:7-S970H)'1A9ULB;F%M
M97-P86-E(ETI*2![#0H@("`@("`@("`@("`D<&%R=',@/2!014%27U!A8VMA
M9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ<W!L:711=6%L:69I961.
M86UE*"1T86=;(G%N86UE(ETI.PT*("`@("`@("`@("`@)'1A9ULB;&]C86Q0
M87)T(ET@/2`D<&%R='-;(FQO8V%L4&%R=")=.PT*("`@("`@("`@("`@:68@
M*&ES<V5T*"1P87)T<ULB;F%M97-P86-E(ETI*2![#0H@("`@("`@("`@("`@
M("`@)'1A9ULB;F%M97-P86-E(ET@/2`D<&%R='-;(FYA;65S<&%C92)=.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@:68@*&ES<V5T
M*"1T86=;(FYA;65S<&%C955R:2)=*2`F)B`A96UP='DH)'1A9ULB;F%M97-P
M86-E57)I(ETI*2![#0H@("`@("`@("`@("`O+R!I<R!A(&YA;65S<&%C92!G
M:79E;@T*("`@("`@("`@("`@:68@*&ES<V5T*"1T86=;(FYA;65S<&%C92)=
M*2`F)B`A96UP='DH)'1A9ULB;F%M97-P86-E(ETI*2![#0H@("`@("`@("`@
M("`@("`@)'1A9ULB871T<FEB=71E<R)=6R)X;6QN<SHB+B1T86=;(FYA;65S
M<&%C92)=72`]("1T86=;(FYA;65S<&%C955R:2)=.PT*("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`O+R!D969I;F4@=&AI<R!5<FD@
M87,@=&AE(&1E9F%U;'0@;F%M97-P86-E#0H@("`@("`@("`@("`@("`@)'1A
M9ULB871T<FEB=71E<R)=6R)X;6QN<R)=(#T@)'1A9ULB;F%M97-P86-E57)I
M(ET[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"@T*("`@("`@("`O+R!C
M:&5C:R!F;W(@;75L=&EL:6YE(&%T=')I8G5T97,-"B`@("`@("`@:68@*"1M
M=6QT:6QI;F4@/3T]('1R=64I('L-"B`@("`@("`@("`@(&EF("@D:6YD96YT
M(#T]/2`B7V%U=&\B*2![#0H@("`@("`@("`@("`@("`@)&EN9&5N="`]('-T
M<E]R97!E870H(B`B+"`H<W1R;&5N*"1T86=;(G%N86UE(ETI*S(I*3L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`-"B`@("`@("`@+R\@
M8W)E871E(&%T=')I8G5T92!L:7-T#0H@("`@("`@("1A='1,:7-T("`@(#T@
M("!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ871T
M<FEB=71E<U1O4W1R:6YG*"1T86=;(F%T=')I8G5T97,B72P@=')U92P@)&UU
M;'1I;&EN92P@)&EN9&5N="P@)&QI;F5B<F5A:R`I.PT*("`@("`@("!I9B`H
M(6ES<V5T*"1T86=;(F-O;G1E;G0B72D@?'P@*'-T<FEN9RDD=&%G6R)C;VYT
M96YT(ET@/3T@)R<I('L-"B`@("`@("`@("`@("1T86<@("`@/2`@('-P<FEN
M=&8H(CPE<R5S("\^(BP@)'1A9ULB<6YA;64B72P@)&%T=$QI<W0I.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@:68@*"1R97!L86-E16YT:71I
M97,@/3T@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?
M4D503$%#15]%3E1)5$E%4RD@>PT*("`@("`@("`@("`@("`@("1T86=;(F-O
M;G1E;G0B72`](%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5
M=&EL.CIR97!L86-E16YT:71I97,H)'1A9ULB8V]N=&5N=")=+"`D96YC;V1I
M;F<I.PT*("`@("`@("`@("`@?2!E;'-E:68@*"1R97!L86-E16YT:71I97,@
M/3T@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?0T1!
M5$%?4T5#5$E/3BD@>PT*("`@("`@("`@("`@("`@("1T86=;(F-O;G1E;G0B
M72`](%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIC
M<F5A=&5#1&%T85-E8W1I;VXH)'1A9ULB8V]N=&5N=")=*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("1T86<@("`@/2`@('-P<FEN=&8H(CPE<R5S
M/B5S/"\E<SXB+"`D=&%G6R)Q;F%M92)=+"`D871T3&ES="P@)'1A9ULB8V]N
M=&5N=")=+"`D=&%G6R)Q;F%M92)=("D[#0H@("`@("`@('T@("`@("`@(`T*
M("`@("`@("!R971U<FX@("1T86<[#0H@("`@?0T*#0H@("`O*BH-"B`@("`J
M(&-R96%T92!A('-T87)T(&5L96UE;G0-"B`@("`J#0H@("`@*B`\8V]D93X-
M"B`@("`J(')E<75I<F5?;VYC92`G6$U,+U5T:6PN<&AP)SL-"B`@("`J(`T*
M("`@("H@+R\@8W)E871E(&%N(%A-3"!S=&%R="!E;&5M96YT.@T*("`@("H@
M)'1A9R`](%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL
M.CIC<F5A=&53=&%R=$5L96UE;G0H(FUY3G,Z;7E486<B+"!A<G)A>2@B9F]O
M(B`]/B`B8F%R(BD@+")H='1P.B\O=W=W+G<S8RYO<F<O;7E.<R,B*3L-"B`@
M("`J(#PO8V]D93X-"B`@("`J#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@
M("`@*B!`<W1A=&EC#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D<6YA;64@
M("`@("`@("`@("`@<75A;&EF:65D('1A9VYA;64@*&EN8VQU9&EN9R!N86UE
M<W!A8V4I#0H@("`@*B!`<&%R86T@("`@87)R87D@("`D871T<FEB=71E<R`@
M("`@("`@87)R87D@8V]N=&%I;F<@871T<FEB=71E<PT*("`@("H@0'!A<F%M
M("`@('-T<FEN9R`@)&YA;65S<&%C955R:2`@("`@(%5222!O9B!T:&4@;F%M
M97-P86-E#0H@("`@*B!`<&%R86T@("`@8F]O;&5A;B`D;75L=&EL:6YE("`@
M("`@("`@=VAE=&AE<B!T;R!C<F5A=&4@82!M=6QT:6QI;F4@=&%G('=H97)E
M(&5A8V@@871T<FEB=71E(&=E=',@=W)I='1E;B!T;R!A('-I;F=L92!L:6YE
M#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D:6YD96YT("`@("`@("`@("`@
M<W1R:6YG('5S960@=&\@:6YD96YT(&%T=')I8G5T97,@*%]A=71O(&EN9&5N
M=',@871T<FEB=71E<R!S;R!T:&5Y('-T87)T(&%T('1H92!S86UE(&-O;'5M
M;BD-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1L:6YE8G)E86L@("`@("`@
M("!S=')I;F<@=7-E9"!F;W(@;&EN96)R96%K<PT*("`@("H@0')E='5R;B`@
M('-T<FEN9R`@)'-T<FEN9R`@("`@("`@("`@(%A-3"!S=&%R="!E;&5M96YT
M#0H@("`@*B!`<V5E("`@("`@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?
M=C)?6$U,7U5T:6PZ.F-R96%T945N9$5L96UE;G0H*2P@4$5!4E]086-K86=E
M1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.F-R96%T951A9R@I#0H@("`@
M*B\-"B`@("!F=6YC=&EO;B!C<F5A=&53=&%R=$5L96UE;G0H)'%N86UE+"`D
M871T<FEB=71E<R`](&%R<F%Y*"DL("1N86UE<W!A8V55<FD@/2!N=6QL+"`D
M;75L=&EL:6YE(#T@9F%L<V4L("1I;F1E;G0@/2`G7V%U=&\G+"`D;&EN96)R
M96%K(#T@(EQN(BD-"B`@("![#0H@("`@("`@("\O(&EF(&YO(&%T=')I8G5T
M97,@:&%V(&)E96X@<V5T+"!U<V4@96UP='D@871T<FEB=71E<PT*("`@("`@
M("!I9B`H(6ES<V5T*"1A='1R:6)U=&5S*2!\?"`A:7-?87)R87DH)&%T=')I
M8G5T97,I*2![#0H@("`@("`@("`@("`D871T<FEB=71E<R`](&%R<F%Y*"D[
M#0H@("`@("`@('T-"B`@("`@("`@#0H@("`@("`@(&EF("@D;F%M97-P86-E
M57)I("$](&YU;&PI('L-"B`@("`@("`@("`@("1P87)T<R`](%!%05)?4&%C
M:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIS<&QI=%%U86QI9FEE
M9$YA;64H)'%N86UE*3L-"B`@("`@("`@?0T*#0H@("`@("`@("\O(&-H96-K
M(&9O<B!M=6QT:6QI;F4@871T<FEB=71E<PT*("`@("`@("!I9B`H)&UU;'1I
M;&EN92`]/3T@=')U92D@>PT*("`@("`@("`@("`@:68@*"1I;F1E;G0@/3T]
M(")?875T;R(I('L-"B`@("`@("`@("`@("`@("`D:6YD96YT(#T@<W1R7W)E
M<&5A="@B("(L("AS=')L96XH)'%N86UE*2LR*2D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H)&YA;65S<&%C955R:2`A/2!N
M=6QL*2![#0H@("`@("`@("`@("`O+R!I<R!A(&YA;65S<&%C92!G:79E;@T*
M("`@("`@("`@("`@:68@*&ES<V5T*"1P87)T<ULB;F%M97-P86-E(ETI("8F
M("%E;7!T>2@D<&%R='-;(FYA;65S<&%C92)=*2D@>PT*("`@("`@("`@("`@
M("`@("1A='1R:6)U=&5S6R)X;6QN<SHB+B1P87)T<ULB;F%M97-P86-E(EU=
M(#T@)&YA;65S<&%C955R:3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@+R\@9&5F:6YE('1H:7,@57)I(&%S('1H92!D969A=6QT
M(&YA;65S<&%C90T*("`@("`@("`@("`@("`@("1A='1R:6)U=&5S6R)X;6QN
M<R)=(#T@)&YA;65S<&%C955R:3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*#0H@("`@("`@("\O(&-R96%T92!A='1R:6)U=&4@;&ES=`T*("`@("`@
M("`D871T3&ES="`@("`]("`@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?
M=C)?6$U,7U5T:6PZ.F%T=')I8G5T97-4;U-T<FEN9R@D871T<FEB=71E<RP@
M=')U92P@)&UU;'1I;&EN92P@)&EN9&5N="P@)&QI;F5B<F5A:RD[#0H@("`@
M("`@("1E;&5M96YT("`@(#T@("!S<')I;G1F*"(\)7,E<SXB+"`D<6YA;64L
M("1A='1,:7-T*3L-"B`@("`@("`@<F5T=7)N("`D96QE;65N=#L-"B`@("!]
M#0H-"B`@("\J*@T*("`@("H@8W)E871E(&%N(&5N9"!E;&5M96YT#0H@("`@
M*@T*("`@("H@/&-O9&4^#0H@("`@*B!R97%U:7)E7V]N8V4@)UA-3"]5=&EL
M+G!H<"<[#0H@("`@*B`-"B`@("`J("\O(&-R96%T92!A;B!834P@<W1A<G0@
M96QE;65N=#H-"B`@("`J("1T86<@/2!014%27U!A8VMA9V5&:6QE7T=E;F5R
M871O<E]V,E]834Q?571I;#HZ8W)E871E16YD16QE;65N="@B;7E.<SIM>51A
M9R(I.PT*("`@("H@/"]C;V1E/@T*("`@("H-"B`@("`J($!A8V-E<W,@("!P
M=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P87)A;2`@("!S=')I;F<@
M("1Q;F%M92`@("`@("`@("`@("!Q=6%L:69I960@=&%G;F%M92`H:6YC;'5D
M:6YG(&YA;65S<&%C92D-"B`@("`J($!R971U<FX@("!S=')I;F<@("1S=')I
M;F<@("`@("`@("`@("!834P@96YD(&5L96UE;G0-"B`@("`J($!S964@("`@
M("!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ8W)E
M871E4W1A<G1%;&5M96YT*"DL(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R
M7W8R7UA-3%]5=&EL.CIC<F5A=&5486<H*0T*("`@("HO#0H@("`@9G5N8W1I
M;VX@8W)E871E16YD16QE;65N="@D<6YA;64I#0H@("`@>PT*("`@("`@("`D
M96QE;65N="`@("`]("`@<W!R:6YT9B@B/"\E<SXB+"`D<6YA;64I.PT*("`@
M("`@("!R971U<FX@("1E;&5M96YT.PT*("`@('T-"B`@("`-"B`@("\J*@T*
M("`@("H@8W)E871E(&%N(%A-3"!C;VUM96YT#0H@("`@*@T*("`@("H@/&-O
M9&4^#0H@("`@*B!R97%U:7)E7V]N8V4@)UA-3"]5=&EL+G!H<"<[#0H@("`@
M*B`-"B`@("`J("\O(&-R96%T92!A;B!834P@<W1A<G0@96QE;65N=#H-"B`@
M("`J("1T86<@/2!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?
M571I;#HZ8W)E871E0V]M;65N="@B22!A;2!A(&-O;6UE;G0B*3L-"B`@("`J
M(#PO8V]D93X-"B`@("`J#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@
M*B!`<W1A=&EC#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D8V]N=&5N="`@
M("`@("`@("`@8V]N=&5N="!O9B!T:&4@8V]M;65N=`T*("`@("H@0')E='5R
M;B`@('-T<FEN9R`@)&-O;6UE;G0@("`@("`@("`@(%A-3"!C;VUM96YT#0H@
M("`@*B\-"B`@("!F=6YC=&EO;B!C<F5A=&5#;VUM96YT*"1C;VYT96YT*0T*
M("`@('L-"B`@("`@("`@)&-O;6UE;G0@("`@/2`@('-P<FEN=&8H(CPA+2T@
M)7,@+2T^(BP@)&-O;G1E;G0I.PT*("`@("`@("!R971U<FX@("1C;VUM96YT
M.PT*("`@('T-"B`@("`-"B`@("\J*@T*("`@("H@8W)E871E(&$@0T1A=&$@
M<V5C=&EO;@T*("`@("H-"B`@("`J(#QC;V1E/@T*("`@("H@<F5Q=6ER95]O
M;F-E("=834PO571I;"YP:'`G.PT*("`@("H@#0H@("`@*B`O+R!C<F5A=&4@
M82!#1&%T82!S96-T:6]N#0H@("`@*B`D=&%G(#T@4$5!4E]086-K86=E1FEL
M95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.F-R96%T94-$871A4V5C=&EO;B@B
M22!A;2!C;VYT96YT+B(I.PT*("`@("H@/"]C;V1E/@T*("`@("H-"B`@("`J
M($!A8V-E<W,@("!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P87)A
M;2`@("!S=')I;F<@("1D871A("`@("`@("`@("`@("!D871A(&]F('1H92!#
M1&%T82!S96-T:6]N#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG("`D<W1R:6YG
M("`@("`@("`@("`@0T1A=&$@<V5C=&EO;B!W:71H(&-O;G1E;G0-"B`@("`J
M+PT*("`@(&9U;F-T:6]N(&-R96%T94-$871A4V5C=&EO;B@D9&%T82D-"B`@
M("![#0H@("`@("`@(')E='5R;B`@<W!R:6YT9B@B/"%;0T1!5$%;)7-=73XB
M+"`D9&%T82D[#0H@("`@?0T*#0H@("`O*BH-"B`@("`J('-P;&ET('%U86QI
M9FEE9"!N86UE(&%N9"!R971U<FX@;F%M97-P86-E(&%N9"!L;V-A;"!P87)T
M#0H@("`@*@T*("`@("H@/&-O9&4^#0H@("`@*B!R97%U:7)E7V]N8V4@)UA-
M3"]5=&EL+G!H<"<[#0H@("`@*B`-"B`@("`J("\O('-P;&ET('%U86QI9FEE
M9"!T86<-"B`@("`J("1P87)T<R`](%!%05)?4&%C:V%G949I;&5?1V5N97)A
M=&]R7W8R7UA-3%]5=&EL.CIS<&QI=%%U86QI9FEE9$YA;64H(GAS;'0Z<W1Y
M;&5S:&5E="(I.PT*("`@("H@/"]C;V1E/@T*("`@("H@=&AE(')E='5R;F5D
M(&%R<F%Y('=I;&P@8V]N=&%I;B!T=V\@96QE;65N=',Z#0H@("`@*B`\<')E
M/@T*("`@("H@87)R87DH#0H@("`@*B`@("`@("`B;F%M97-P86-E(B`]/B`B
M>'-L="(L#0H@("`@*B`@("`@("`B;&]C86Q087)T(B`]/B`B<W1Y;&5S:&5E
M="(-"B`@("`J("`@("`@*3L-"B`@("`J(#PO<')E/@T*("`@("H-"B`@("`J
M($!A8V-E<W,@<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@("`@*B!`<&%R86T@
M('-T<FEN9R`@("`D<6YA;64@("`@("!Q=6%L:69I960@=&%G(&YA;64-"B`@
M("`J($!P87)A;2`@<W1R:6YG("`@("1D969A=6QT3G,@(&1E9F%U;'0@;F%M
M97-P86-E("AO<'1I;VYA;"D-"B`@("`J($!R971U<FX@87)R87D@("`@("1P
M87)T<R`@("`@(&%R<F%Y(&-O;G1A:6YI;F<@;F%M97-P86-E(&%N9"!L;V-A
M;"!P87)T#0H@("`@*B\-"B`@("!F=6YC=&EO;B!S<&QI=%%U86QI9FEE9$YA
M;64H)'%N86UE+"`D9&5F875L=$YS(#T@;G5L;"D-"B`@("![#0H@("`@("`@
M(&EF("AS=')S='(H)'%N86UE+"`G.B<I*2![#0H@("`@("`@("`@("`D=&UP
M(#T@97AP;&]D92@B.B(L("1Q;F%M92D[#0H@("`@("`@("`@("!R971U<FX@
M87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@(")N86UE<W!A8V4B
M(#T^("1T;7!;,%TL#0H@("`@("`@("`@("`@("`@("`@("`@("`@(")L;V-A
M;%!A<G0B(#T^("1T;7!;,5T-"B`@("`@("`@("`@("`@("`@("`@("`@("D[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("`@("`@(")N86UE<W!A8V4B(#T^("1D969A=6QT3G,L#0H@("`@
M("`@("`@("`@("`@("`@("`@(FQO8V%L4&%R="(@/3X@)'%N86UE#0H@("`@
M("`@("`@("`@("`@("`@("D[#0H@("`@?0T*#0H@("`O*BH-"B`@("`J(&-H
M96-K+"!W:&5T:&5R('-T<FEN9R!I<R!V86QI9"!834P@;F%M90T*("`@("H-
M"B`@("`J(#QP/EA-3"!N86UE<R!A<F4@=7-E9"!F;W(@=&%G;F%M92P@871T
M<FEB=71E(&YA;65S(&%N9"!V87)I;W5S#0H@("`@*B!O=&AE<BP@;&5S<V5R
M(&MN;W=N(&5N=&ET:65S+CPO<#X-"B`@("`J(#QP/D%N(%A-3"!N86UE(&UA
M>2!O;FQY(&-O;G-I<W0@;V8@86QP:&%N=6UE<FEC(&-H87)A8W1E<G,L#0H@
M("`@*B!D87-H97,L('5N9&5S8V]R97,@86YD('!E<FEO9',L(&%N9"!H87,@
M=&\@<W1A<G0@=VET:"!A(&QE='1E<@T*("`@("H@;W(@86X@=6YD97)S8V]R
M92X-"B`@("`J(#PO<#X-"B`@("`J#0H@("`@*B`\8V]D93X-"B`@("`J(')E
M<75I<F5?;VYC92`G6$U,+U5T:6PN<&AP)SL-"B`@("`J(`T*("`@("H@+R\@
M=F5R:69Y('1A9R!N86UE#0H@("`@*B`D<F5S=6QT(#T@4$5!4E]086-K86=E
M1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.FES5F%L:61.86UE*")I;G9A
M;&ED5&%G/R(I.PT*("`@("H@:68@*%!%05)?4&%C:V%G949I;&5?1V5N97)A
M=&]R7W8R7UA-3%]5=&EL.CII<T5R<F]R*"1R97-U;'0I*2![#0H@("`@*B`@
M("!P<FEN="`B26YV86QI9"!834P@;F%M93H@(B`N("1R97-U;'0M/F=E=$UE
M<W-A9V4H*3L-"B`@("`J('T-"B`@("`J(#PO8V]D93X-"B`@("`J#0H@("`@
M*B!`86-C97-S("!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P87)A
M;2`@('-T<FEN9R`@)'-T<FEN9R!S=')I;F<@=&AA="!S:&]U;&0@8F4@8VAE
M8VME9`T*("`@("H@0')E='5R;B`@;6EX960@("`D=F%L:60@('1R=64L(&EF
M('-T<FEN9R!I<R!A('9A;&ED(%A-3"!N86UE+"!014%2(&5R<F]R(&]T:&5R
M=VES90T*("`@("H@0'1O9&\@("`@<W5P<&]R="!F;W(@;W1H97(@8VAA<G-E
M=',-"B`@("`J+PT*("`@(&9U;F-T:6]N(&ES5F%L:61.86UE*"1S=')I;F<I
M#0H@("`@>PT*("`@("`@("`O+R!C:&5C:R!F;W(@:6YV86QI9"!C:&%R<PT*
M("`@("`@("!I9B`H(7!R96=?;6%T8V@H(B]>6ULZ86QN=6TZ75]<+2Y=)"\B
M+"`D<W1R:6YG>S!]*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05)?4&%C
M:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIR86ES945R<F]R*"`B
M6$U,(&YA;65S(&UA>2!O;FQY('-T87)T('=I=&@@;&5T=&5R(&]R('5N9&5R
M<V-O<F4B+"!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I
M;%]%4E)/4E])3E9!3$E$7U-405)4("D[#0H@("`@("`@('T-"B`@("`@("`@
M#0H@("`@("`@("\O(&-H96-K(&9O<B!I;G9A;&ED(&-H87)S#0H@("`@("`@
M(&EF("@A<')E9U]M871C:"@B+UXH6V$M>D$M6E]=*%MA+7I!+5HP+3E?7"U<
M+ETJ*3\Z*3];82UZ02U:7UTH6V$M>D$M6C`M.5]<+5PN72LI/R0O(BP@)'-T
M<FEN9RDI('L-"B`@("`@("`@("`@(')E='5R;B!014%27U!A8VMA9V5&:6QE
M7T=E;F5R871O<E]V,E]834Q?571I;#HZ<F%I<V5%<G)O<B@@(EA-3"!N86UE
M<R!M87D@;VYL>2!C;VYT86EN(&%L<&AA;G5M97)I8R!C:&%R<RP@<&5R:6]D
M+"!H>7!H96XL(&-O;&]N(&%N9"!U;F1E<G-C;W)E<R(L(%!%05)?4&%C:V%G
M949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL7T524D]27TE.5D%,241?0TA!
M4E,@*3L-"B`@("`@("`@('T-"B`@("`@("`@+R\@6$U,(&YA;64@:7,@=F%L
M:60-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`O*BH-"B`@
M("`J(')E<&QA8V5M96YT(&9O<B!014%27U!A8VMA9V5&:6QE7T=E;F5R871O
M<E]V,E]834Q?571I;#HZ<F%I<V5%<G)O<@T*("`@("H-"B`@("`J($%V;VED
M<R!T:&4@;F5C97-S:71Y('1O(&%L=V%Y<R!R97%U:7)E#0H@("`@*B!014%2
M+G!H<`T*("`@("H-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@("`J($!P
M87)A;2`@("!S=')I;F<@("`@("!E<G)O<B!M97-S86=E#0H@("`@*B!`<&%R
M86T@("`@:6YT96=E<B`@("`@97)R;W(@8V]D90T*("`@("H@0')E='5R;B`@
M(&]B:F5C="!014%27T5R<F]R#0H@("`@*B\-"B`@("!F=6YC=&EO;B!R86ES
M945R<F]R*"1M<V<L("1C;V1E*0T*("`@('L-"B`@("`@("`@<F5Q=6ER95]O
M;F-E("=014%2+G!H<"<[#0H@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"1M<V<L("1C;V1E*3L-"B`@("!]#0I]#0H_/BXO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]014%2+U!A8VMA9V5&:6QE+U!A<G-E<B\`````
M```````````````````````````````````````````````````````P,#`P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<T,``P
M,C(W,3<`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O4&%C:V%G
M949I;&4O4&%R<V5R+W8Q+G!H<```````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0Q
M-3<P`#$P-3$U-#,S-S0P`#`R,S<V-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`T*+RHJ#0H@*B!P86-K86=E+GAM
M;"!P87)S:6YG(&-L87-S+"!P86-K86=E+GAM;"!V97)S:6]N(#$N,`T*("H-
M"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H
M92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A
M;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P
M;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C
M871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H
M;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y
M<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC
M96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!V,2YP:'`L=B`Q
M+C(Q(#(P,#8O,#$O,#8@,#0Z-#<Z,S<@8V5L;&]G($5X<"`D#0H@*B!`;&EN
M:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@
M0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N
M,&$Q#0H@*B\-"B\J*@T*("H@<&%C:V%G92YX;6P@86)S=')A8W1I;VX@8VQA
M<W,-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+U!A8VMA9V5&:6QE+W8Q+G!H
M<"<[#0HO*BH-"B`J(%!A<G-E<B!F;W(@<&%C:V%G92YX;6P@=F5R<VEO;B`Q
M+C`-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-
M"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-
M"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`
M;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z($!0
M14%2+59%4D`-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@
M<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S(%!%05)?4&%C:V%G
M949I;&5?4&%R<V5R7W8Q#0I[#0H@("`@=F%R("1?<F5G:7-T<GD[#0H@("`@
M=F%R("1?8V]N9FEG.PT*("`@('9A<B`D7VQO9V=E<CL-"B`@("`O*BH-"B`@
M("`@*B!"0R!H86-K('1O(&%L;&]W(%!%05)?0V]M;6]N.CII;F9O1G)O;5-T
M<FEN9R@I('1O('-O<G0@;V8-"B`@("`@*B!W;W)K('=I=&@@=&AE('9E<G-I
M;VX@,BXP(&9O<FUA="`M('1H97)E)W,@;F\@9FEL96QI<W0@=&AO=6=H#0H@
M("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!F<F]M5C(H)'!A8VMA9V5F:6QE*0T*("`@('L-"B`@("`@
M("`@)&EN9F\@/2`D<&%C:V%G969I;&4M/F=E=$%R<F%Y*'1R=64I.PT*("`@
M("`@("`D<F5T(#T@;F5W(%!%05)?4&%C:V%G949I;&5?=C$[#0H@("`@("`@
M("1R970M/F9R;VU!<G)A>2@D:6YF;ULG;VQD)UTI.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N('-E=$-O;F9I9R@F)&,I#0H@("`@>PT*("`@("`@("`D=&AI
M<RT^7V-O;F9I9R`]("8D8SL-"B`@("`@("`@)'1H:7,M/E]R96=I<W1R>2`]
M("8D8RT^9V5T4F5G:7-T<GDH*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S
M971,;V=G97(H)B1L*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]L;V=G97(@
M/2`F)&P[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN
M9R!C;VYT96YT<R!O9B!P86-K86=E+GAM;"!F:6QE+"!V97)S:6]N(#$N,`T*
M("`@("`J($!R971U<FX@8F]O;"!S=6-C97-S(&]F('!A<G-I;F<-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!P87)S92@D9&%T82P@)&9I;&4L("1A<F-H:79E
M(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H(65X=&5N<VEO;E]L;V%D
M960H)WAM;"<I*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G0V%N;F]T(&-R96%T92!X;6P@<&%R<V5R(&9O<B!P87)S:6YG('!A
M8VMA9V4N>&UL+"!N;R!X;6P@97AT96YS:6]N)RD[#0H@("`@("`@('T-"B`@
M("`@("`@)'AP(#T@0'AM;%]P87)S97)?8W)E871E*"D[#0H@("`@("`@(&EF
M("@A)'AP*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G0V%N;F]T(&-R96%T92!X;6P@<&%R<V5R(&9O<B!P87)S:6YG('!A8VMA
M9V4N>&UL)RD[#0H@("`@("`@('T-"B`@("`@("`@>&UL7W-E=%]O8FIE8W0H
M)'AP+"`D=&AI<RD[#0H@("`@("`@('AM;%]S971?96QE;65N=%]H86YD;&5R
M*"1X<"P@)U]E;&5M96YT7W-T87)T7S%?,"<L("=?96QE;65N=%]E;F1?,5\P
M)RD[#0H@("`@("`@('AM;%]S971?8VAA<F%C=&5R7V1A=&%?:&%N9&QE<B@D
M>'`L("=?<&MG:6YF;U]C9&%T85\Q7S`G*3L-"B`@("`@("`@>&UL7W!A<G-E
M<E]S971?;W!T:6]N*"1X<"P@6$U,7T]05$E/3E]#05-%7T9/3$1)3D<L(&9A
M;'-E*3L-"@T*("`@("`@("`D=&AI<RT^96QE;65N=%]S=&%C:R`](&%R<F%Y
M*"D[#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2!A<G)A>2@G<')O
M=FED97,G(#T^(&%R<F%Y*"DI.PT*("`@("`@("`D=&AI<RT^8W5R<F5N=%]E
M;&5M96YT(#T@9F%L<V4[#0H@("`@("`@('5N<V5T*"1T:&ES+3YD:7)?:6YS
M=&%L;"D[#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V9I;&5L:7-T
M)UT@/2!A<G)A>2@I.PT*("`@("`@("`D=&AI<RT^9FEL96QI<W0@/28@)'1H
M:7,M/E]P86-K86=E26YF;ULG9FEL96QI<W0G73L-"B`@("`@("`@)'1H:7,M
M/F1I<E]N86UE<R`](&%R<F%Y*"D[#0H@("`@("`@("1T:&ES+3YI;E]C:&%N
M9V5L;V<@/2!F86QS93L-"B`@("`@("`@)'1H:7,M/F1?:2`](#`[#0H@("`@
M("`@("1T:&ES+3YC9&%T82`]("<G.PT*("`@("`@("`D=&AI<RT^7VES5F%L
M:60@/2!T<G5E.PT*#0H@("`@("`@(&EF("@A>&UL7W!A<G-E*"1X<"P@)&1A
M=&$L(#$I*2![#0H@("`@("`@("`@("`D8V]D92`]('AM;%]G971?97)R;W)?
M8V]D92@D>'`I.PT*("`@("`@("`@("`@)&QI;F4@/2!X;6Q?9V5T7V-U<G)E
M;G1?;&EN95]N=6UB97(H)'AP*3L-"B`@("`@("`@("`@('AM;%]P87)S97)?
M9G)E92@D>'`I.PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H<W!R:6YT9B@B6$U,(&5R<F]R.B`E<R!A="!L:6YE("5D(BP-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1S='(@/2!X;6Q?97)R;W)?<W1R:6YG
M*"1C;V1E*2P@)&QI;F4I+"`R*3L-"B`@("`@("`@?0T*#0H@("`@("`@('AM
M;%]P87)S97)?9G)E92@D>'`I.PT*#0H@("`@("`@("1P9B`](&YE=R!014%2
M7U!A8VMA9V5&:6QE7W8Q.PT*("`@("`@("`D<&8M/G-E=$-O;F9I9R@D=&AI
M<RT^7V-O;F9I9RD[#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VQO9V=E
M<BDI('L-"B`@("`@("`@("`@("1P9BT^<V5T3&]G9V5R*"1T:&ES+3Y?;&]G
M9V5R*3L-"B`@("`@("`@?0T*("`@("`@("`D<&8M/G-E=%!A8VMA9V5F:6QE
M*"1F:6QE+"`D87)C:&EV92D[#0H@("`@("`@("1P9BT^9G)O;4%R<F%Y*"1T
M:&ES+3Y?<&%C:V%G94EN9F\I.PT*("`@("`@("!R971U<FX@)'!F.PT*("`@
M('T-"B`@("`O+R![>WL@7W5N26YD96YT*"D-"@T*("`@("\J*@T*("`@("`J
M(%5N:6YD96YT(&=I=F5N('-T<FEN9PT*("`@("`J#0H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<W1R(%1H92!S=')I;F<@=&AA="!H87,@=&\@8F4@=6YI;F1E
M;G1E9"X-"B`@("`@*B!`<F5T=7)N('-T<FEN9PT*("`@("`J($!A8V-E<W,@
M<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]U;DEN9&5N="@D<W1R
M*0T*("`@('L-"B`@("`@("`@+R\@<F5M;W9E(&QE861I;F<@;F5W;&EN97,-
M"B`@("`@("`@)'-T<B`]('!R96=?<F5P;&%C92@G+UY;7')<;ETK+R<L("<G
M+"`D<W1R*3L-"B`@("`@("`@+R\@9FEN9"!W:&ET97-P86-E(&%T('1H92!B
M96=I;FYI;F<@;V8@=&AE(&9I<G-T(&QI;F4-"B`@("`@("`@)&EN9&5N=%]L
M96X@/2!S=')S<&XH)'-T<BP@(B!<="(I.PT*("`@("`@("`D:6YD96YT(#T@
M<W5B<W1R*"1S='(L(#`L("1I;F1E;G1?;&5N*3L-"B`@("`@("`@)&1A=&$@
M/2`G)SL-"B`@("`@("`@+R\@<F5M;W9E('1H92!S86UE(&%M;W5N="!O9B!W
M:&ET97-P86-E(&9R;VT@9F]L;&]W:6YG(&QI;F5S#0H@("`@("`@(&9O<F5A
M8V@@*&5X<&QO9&4H(EQN(BP@)'-T<BD@87,@)&QI;F4I('L-"B`@("`@("`@
M("`@(&EF("AS=6)S='(H)&QI;F4L(#`L("1I;F1E;G1?;&5N*2`]/2`D:6YD
M96YT*2![#0H@("`@("`@("`@("`@("`@)&1A=&$@+CT@<W5B<W1R*"1L:6YE
M+"`D:6YD96YT7VQE;BD@+B`B7&XB.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B`D9&%T83L-"B`@("!]#0H-"B`@("`O+R!3
M=7!P;W)T(&9O<B!P86-K86=E($141"!V,2XP.@T*("`@("\O('M[>R!?96QE
M;65N=%]S=&%R=%\Q7S`H*0T*#0H@("`@+RHJ#0H@("`@("H@6$U,('!A<G-E
M<B!C86QL8F%C:R!F;W(@96YD:6YG(&5L96UE;G1S+B`@57-E9"!F;W(@=F5R
M<VEO;B`Q+C`-"B`@("`@*B!P86-K86=E<RX-"B`@("`@*@T*("`@("`J($!P
M87)A;2!R97-O=7)C92`@)'AP("`@(%A-3"!P87)S97(@<F5S;W5R8V4-"B`@
M("`@*B!`<&%R86T@<W1R:6YG("`@("1N86UE("!N86UE(&]F(&5N9&EN9R!E
M;&5M96YT#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('9O:60-"B`@("`@*@T*
M("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N
M(%]E;&5M96YT7W-T87)T7S%?,"@D>'`L("1N86UE+"`D871T<FEB<RD-"B`@
M("![#0H@("`@("`@(&%R<F%Y7W!U<V@H)'1H:7,M/F5L96UE;G1?<W1A8VLL
M("1N86UE*3L-"B`@("`@("`@)'1H:7,M/F-U<G)E;G1?96QE;65N="`]("1N
M86UE.PT*("`@("`@("`D<W!O<R`]('-I>F5O9B@D=&AI<RT^96QE;65N=%]S
M=&%C:RD@+2`R.PT*("`@("`@("`D=&AI<RT^<')E=E]E;&5M96YT(#T@*"1S
M<&]S(#X](#`I(#\@)'1H:7,M/F5L96UE;G1?<W1A8VM;)'-P;W-=(#H@)R<[
M#0H@("`@("`@("1T:&ES+3YC=7)R96YT7V%T=')I8G5T97,@/2`D871T<FEB
M<SL-"B`@("`@("`@)'1H:7,M/F-D871A(#T@)R<[#0H@("`@("`@('-W:71C
M:"`H)&YA;64I('L-"B`@("`@("`@("`@(&-A<V4@)V1I<B<Z#0H@("`@("`@
M("`@("`@("`@:68@*"1T:&ES+3YI;E]C:&%N9V5L;V<I('L-"B`@("`@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=N86UE)RP@)&%T=')I
M8G,I("8F("1A='1R:6)S6R=N86UE)UT@(3T@)R\G*2![#0H@("`@("`@("`@
M("`@("`@("`@("1A='1R:6)S6R=N86UE)UT@/2!P<F5G7W)E<&QA8V4H87)R
M87DH)R%<7%Q<*R$G+"`G(2\K(2<I+"!A<G)A>2@G+R<L("<O)RDL#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D871T<FEB<ULG;F%M92==*3L-"B`@("`@
M("`@("`@("`@("`@("`@:68@*'-T<G)P;W,H)&%T=')I8G-;)VYA;64G72P@
M)R\G*2`]/2!S=')L96XH)&%T=')I8G-;)VYA;64G72D@+2`Q*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D871T<FEB<ULG;F%M92==(#T@<W5B<W1R
M*"1A='1R:6)S6R=N86UE)UTL(#`L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<W1R;&5N*"1A='1R:6)S6R=N86UE)UTI("T@,2D[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*'-T<G!O
M<R@D871T<FEB<ULG;F%M92==+"`G+R<I(#T]/2`P*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D871T<FEB<ULG;F%M92==(#T@<W5B<W1R*"1A='1R
M:6)S6R=N86UE)UTL(#$I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YD:7)?;F%M97-;72`]("1A='1R:6)S
M6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D871T<FEB<ULG8F%S96EN<W1A;&QD:7(G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/F1I<E]I;G-T86QL(#T@)&%T=')I
M8G-;)V)A<V5I;G-T86QL9&ER)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D871T<FEB<ULG<F]L92==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9&ER7W)O;&4@/2`D871T<FEB
M<ULG<F]L92==.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)V9I;&4G.@T*("`@("`@("`@
M("`@("`@(&EF("@D=&AI<RT^:6Y?8VAA;F=E;&]G*2![#0H@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&%T=')I8G-;)VYA;64G72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@)'!A=&@@/2`G)SL-"B`@("`@("`@("`@("`@("`@
M("`@:68@*&-O=6YT*"1T:&ES+3YD:7)?;F%M97,I*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^9&ER7VYA;65S(&%S("1D
M:7(I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%T:"`N/2`D
M9&ER("X@)R\G.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1P871H("X]
M('!R96=?<F5P;&%C92AA<G)A>2@G(5Q<7%PK(2<L("<A+RLA)RDL(&%R<F%Y
M*"<O)RP@)R\G*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("1A='1R:6)S
M6R=N86UE)UTI.PT*("`@("`@("`@("`@("`@("`@("!U;G-E="@D871T<FEB
M<ULG;F%M92==*3L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-U<G)E
M;G1?<&%T:"`]("1P871H.PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M9FEL96QI<W1;)'!A=&A=(#T@)&%T=')I8G,[#0H@("`@("`@("`@("`@("`@
M("`@("\O(%-E="!T:&4@8F%S96EN<W1A;&QD:7(@;VYL>2!I9B!T:&4@9FEL
M92!D;VXG="!H879E('1H:7,@871T<FEB#0H@("`@("`@("`@("`@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/F9I;&5L:7-T6R1P871H75LG8F%S96EN<W1A
M;&QD:7(G72D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1T
M:&ES+3YD:7)?:6YS=&%L;"DI#0H@("`@("`@("`@("`@("`@("`@('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YF:6QE;&ES=%LD<&%T:%U;
M)V)A<V5I;G-T86QL9&ER)UT@/2`D=&AI<RT^9&ER7VEN<W1A;&P[#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@+R\@4V5T
M('1H92!2;VQE#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/F9I;&5L:7-T6R1P871H75LG<F]L92==*2`F)B!I<W-E="@D=&AI<RT^
M9&ER7W)O;&4I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M9FEL96QI<W1;)'!A=&A=6R=R;VQE)UT@/2`D=&AI<RT^9&ER7W)O;&4[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=R97!L86-E
M)SH-"B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YI;E]C:&%N9V5L;V<I
M('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F9I;&5L:7-T6R1T:&ES
M+3YC=7)R96YT7W!A=&A=6R=R97!L86-E;65N=',G75M=(#T@)&%T=')I8G,[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("`@("`@8V%S92`G;6%I;G1A:6YE<G,G.@T*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)VUA:6YT86EN97)S)UT@/2!A<G)A
M>2@I.PT*("`@("`@("`@("`@("`@("1T:&ES+3YM7VD@/2`P.R`O+R!M86EN
M=&%I;F5R<R!A<G)A>2!I;F1E>`T*("`@("`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("`@("`@8V%S92`G;6%I;G1A:6YE<B<Z#0H@("`@("`@("`@("`@
M("`@+R\@8V]M<&%T:6)I;&ET>2!C:&5C:PT*("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG;6%I;G1A:6YE<G,G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG
M;6%I;G1A:6YE<G,G72`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YM7VD@/2`P.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=M86EN=&%I;F5R<R==6R1T
M:&ES+3YM7VE=(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M8W5R<F5N=%]M86EN=&%I;F5R(#TF("1T:&ES+3Y?<&%C:V%G94EN9F];)VUA
M:6YT86EN97)S)UU;)'1H:7,M/FU?:5T[#0H@("`@("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@("`@("!C87-E("=C:&%N9V5L;V<G.@T*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V-H86YG96QO9R==(#T@87)R
M87DH*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^8U]I(#T@,#L@+R\@8VAA
M;F=E;&]G(&%R<F%Y(&EN9&5X#0H@("`@("`@("`@("`@("`@)'1H:7,M/FEN
M7V-H86YG96QO9R`]('1R=64[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("!C87-E("=R96QE87-E)SH-"B`@("`@("`@("`@("`@("!I
M9B`H)'1H:7,M/FEN7V-H86YG96QO9RD@>PT*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N9V5L;V<G75LD=&AI<RT^8U]I
M72`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC=7)R
M96YT7W)E;&5A<V4@/2`F)'1H:7,M/E]P86-K86=E26YF;ULG8VAA;F=E;&]G
M)UU;)'1H:7,M/F-?:5T[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/F-U<G)E;G1?<F5L96%S92`]("8D
M=&AI<RT^7W!A8VMA9V5);F9O.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)V1E<',G.@T*
M("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/FEN7V-H86YG96QO9RD@>PT*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=R96QE
M87-E7V1E<',G72`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G9&5P)SH-
M"B`@("`@("`@("`@("`@("`O+R!D97!E;F1E;F-I97,@87)R87D@:6YD97@-
M"B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YI;E]C:&%N9V5L;V<I('L-
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F1?:2LK.PT*("`@("`@("`@
M("`@("`@("`@("!I<W-E="@D871T<FEB<ULG='EP92==*2`_("@D871T<FEB
M<ULG='EP92==(#T@<W1R=&]L;W=E<B@D871T<FEB<ULG='EP92==*2D@.B!F
M86QS93L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF
M;ULG<F5L96%S95]D97!S)UU;)'1H:7,M/F1?:5T@/2`D871T<FEB<SL-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@("`@("!C87-E("=C;VYF:6=U<F5O<'1I;VYS)SH-"B`@("`@("`@("`@
M("`@("!I9B`H(21T:&ES+3YI;E]C:&%N9V5L;V<I('L-"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG8V]N9FEG=7)E7V]P=&EO
M;G,G72`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G8V]N9FEG=7)E;W!T
M:6]N)SH-"B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YI;E]C:&%N9V5L
M;V<I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF
M;ULG8V]N9FEG=7)E7V]P=&EO;G,G75M=(#T@)&%T=')I8G,[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@
M("`@8V%S92`G<')O=FED97,G.@T*("`@("`@("`@("`@("`@(&EF("AE;7!T
M>2@D871T<FEB<ULG='EP92==*2!\?"!E;7!T>2@D871T<FEB<ULG;F%M92==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@)&%T=')I8G-;)V5X<&QI8VET)UT@
M/2!T<G5E.PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];
M)W!R;W9I9&5S)UU;(B1A='1R:6)S6W1Y<&5=.R1A='1R:6)S6VYA;65=(ET@
M/2`D871T<FEB<SL-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@(&-A<V4@)W!A8VMA9V4G(#H-"B`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&%T=')I8G-;)W9E<G-I;VXG72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P86-K86=E26YF;ULG>'-D=F5R<VEO;B==(#T@=')I;2@D
M871T<FEB<ULG=F5R<VEO;B==*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=X
M<V1V97)S:6]N)UT@/2`G,2XP)SL-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1A='1R:6)S6R=P86-K86=E<G9E<G-I
M;VXG72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E
M26YF;ULG<&%C:V%G97)V97)S:6]N)UT@/2`D871T<FEB<ULG<&%C:V%G97)V
M97)S:6]N)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&)R96%K.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(%]E;&5M96YT7V5N9%\Q7S`H*0T*#0H@("`@+RHJ#0H@("`@("H@
M6$U,('!A<G-E<B!C86QL8F%C:R!F;W(@96YD:6YG(&5L96UE;G1S+B`@57-E
M9"!F;W(@=F5R<VEO;B`Q+C`-"B`@("`@*B!P86-K86=E<RX-"B`@("`@*@T*
M("`@("`J($!P87)A;2!R97-O=7)C92`@)'AP("`@(%A-3"!P87)S97(@<F5S
M;W5R8V4-"B`@("`@*B!`<&%R86T@<W1R:6YG("`@("1N86UE("!N86UE(&]F
M(&5N9&EN9R!E;&5M96YT#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('9O:60-
M"B`@("`@*@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(%]E;&5M96YT7V5N9%\Q7S`H)'AP+"`D;F%M92D-"B`@("![
M#0H@("`@("`@("1D871A(#T@=')I;2@D=&AI<RT^8V1A=&$I.PT*("`@("`@
M("!S=VET8V@@*"1N86UE*2![#0H@("`@("`@("`@("!C87-E("=N86UE)SH-
M"B`@("`@("`@("`@("`@("!S=VET8V@@*"1T:&ES+3YP<F5V7V5L96UE;G0I
M('L-"B`@("`@("`@("`@("`@("`@("`@8V%S92`G<&%C:V%G92<Z#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=P86-K
M86=E)UT@/2`D9&%T83L-"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("`@("`@("`@("`@("!C87-E("=M86EN=&%I;F5R)SH-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC=7)R96YT7VUA:6YT86EN
M97);)VYA;64G72`]("1D871A.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@8V%S92`G97AT96YD<R<@.@T*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V5X=&5N9',G72`]("1D871A
M.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G
M<W5M;6%R>2<Z#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF
M;ULG<W5M;6%R>2==(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@8G)E86L[
M#0H@("`@("`@("`@("!C87-E("=D97-C<FEP=&EO;B<Z#0H@("`@("`@("`@
M("`@("`@)&1A=&$@/2`D=&AI<RT^7W5N26YD96YT*"1T:&ES+3YC9&%T82D[
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG9&5S8W)I
M<'1I;VXG72`]("1D871A.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@
M("`@("`@("`@8V%S92`G=7-E<B<Z#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/F-U<G)E;G1?;6%I;G1A:6YE<ELG:&%N9&QE)UT@/2`D9&%T83L-"B`@("`@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)V5M86EL)SH-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^8W5R<F5N=%]M86EN=&%I;F5R6R=E
M;6%I;"==(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@("`@("!C87-E("=R;VQE)SH-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M8W5R<F5N=%]M86EN=&%I;F5R6R=R;VQE)UT@/2`D9&%T83L-"B`@("`@("`@
M("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)W9E<G-I;VXG.@T*
M("`@("`@("`@("`@("`@("\O)&1A=&$@/2!E<F5G7W)E<&QA8V4@*"=;7F$M
M>D$M6C`M.2Y?7"U=)RP@)U\G+"`D9&%T82D[#0H@("`@("`@("`@("`@("`@
M:68@*"1T:&ES+3YI;E]C:&%N9V5L;V<I('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/F-U<G)E;G1?<F5L96%S95LG=F5R<VEO;B==(#T@)&1A=&$[
M#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P86-K86=E26YF;ULG=F5R<VEO;B==(#T@)&1A=&$[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@
M("`@("`@("`@8V%S92`G9&%T92<Z#0H@("`@("`@("`@("`@("`@:68@*"1T
M:&ES+3YI;E]C:&%N9V5L;V<I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/F-U<G)E;G1?<F5L96%S95LG<F5L96%S95]D871E)UT@/2`D9&%T83L-
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A8VMA9V5);F9O6R=R96QE87-E7V1A=&4G72`]("1D871A
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@(&-A<V4@)VYO=&5S)SH-"B`@("`@("`@("`@("`@("`O
M+R!T<GD@=&\@(F1E+6EN9&5N="(@<F5L96%S92!N;W1E<R!I;B!C87-E('-O
M;65O;F4-"B`@("`@("`@("`@("`@("`O+R!H87,@8F5E;B!O=F5R+6EN9&5N
M=&EN9R!T:&5I<B!X;6P@.RTI#0H@("`@("`@("`@("`@("`@)&1A=&$@/2`D
M=&AI<RT^7W5N26YD96YT*"1T:&ES+3YC9&%T82D[#0H@("`@("`@("`@("`@
M("`@:68@*"1T:&ES+3YI;E]C:&%N9V5L;V<I('L-"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/F-U<G)E;G1?<F5L96%S95LG<F5L96%S95]N;W1E<R==
M(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG<F5L96%S95]N;W1E
M<R==(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G=V%R;FEN9W,G.@T*("`@
M("`@("`@("`@("`@(&EF("@D=&AI<RT^:6Y?8VAA;F=E;&]G*2![#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YC=7)R96YT7W)E;&5A<V5;)W)E;&5A
M<V5?=V%R;FEN9W,G72`]("1D871A.PT*("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];
M)W)E;&5A<V5?=V%R;FEN9W,G72`]("1D871A.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@
M)W-T871E)SH-"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/FEN7V-H86YG
M96QO9RD@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8W5R<F5N=%]R
M96QE87-E6R=R96QE87-E7W-T871E)UT@/2`D9&%T83L-"B`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M8VMA9V5);F9O6R=R96QE87-E7W-T871E)UT@/2`D9&%T83L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@
M("!C87-E("=L:6-E;G-E)SH-"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M
M/FEN7V-H86YG96QO9RD@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M8W5R<F5N=%]R96QE87-E6R=R96QE87-E7VQI8V5N<V4G72`]("1D871A.PT*
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A<V5?;&EC96YS92==(#T@)&1A
M=&$[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("`@("`@8V%S92`G9&5P)SH-"B`@("`@("`@("`@("`@("!I
M9B`H)&1A=&$@)B8@(21T:&ES+3YI;E]C:&%N9V5L;V<I('L-"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG<F5L96%S95]D97!S
M)UU;)'1H:7,M/F1?:5U;)VYA;64G72`]("1D871A.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A
M<V4@)V1I<B<Z#0H@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YI;E]C:&%N
M9V5L;V<I('L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&%R<F%Y7W!O<"@D=&AI<RT^
M9&ER7VYA;65S*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@(&-A<V4@)V9I;&4G.@T*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^
M:6Y?8VAA;F=E;&]G*2![#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H)&1A=&$I
M('L-"B`@("`@("`@("`@("`@("`@("`@)'!A=&@@/2`G)SL-"B`@("`@("`@
M("`@("`@("`@("`@:68@*&-O=6YT*"1T:&ES+3YD:7)?;F%M97,I*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^9&ER7VYA
M;65S(&%S("1D:7(I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<&%T:"`N/2`D9&ER("X@)R\G.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("1P871H("X]("1D871A.PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M9FEL96QI<W1;)'!A=&A=(#T@)'1H:7,M/F-U<G)E;G1?871T<FEB=71E<SL-
M"B`@("`@("`@("`@("`@("`@("`@+R\@4V5T('1H92!B87-E:6YS=&%L;&1I
M<B!O;FQY(&EF('1H92!F:6QE(&1O;B=T(&AA=F4@=&AI<R!A='1R:6(-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^9FEL96QI<W1;
M)'!A=&A=6R=B87-E:6YS=&%L;&1I<B==*2`F)@T*("`@("`@("`@("`@("`@
M("`@("`@("`@:7-S970H)'1H:7,M/F1I<E]I;G-T86QL*2D-"B`@("`@("`@
M("`@("`@("`@("`@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/F9I;&5L:7-T6R1P871H75LG8F%S96EN<W1A;&QD:7(G72`]("1T:&ES+3YD
M:7)?:6YS=&%L;#L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`O+R!3970@=&AE(%)O;&4-"B`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^9FEL96QI<W1;)'!A=&A=6R=R;VQE)UTI
M("8F(&ES<V5T*"1T:&ES+3YD:7)?<F]L92DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YF:6QE;&ES=%LD<&%T:%U;)W)O;&4G72`]("1T
M:&ES+3YD:7)?<F]L93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@(&-A<V4@)VUA:6YT86EN97(G.@T*("`@("`@("`@("`@("`@(&EF("AE
M;7!T>2@D=&AI<RT^7W!A8VMA9V5);F9O6R=M86EN=&%I;F5R<R==6R1T:&ES
M+3YM7VE=6R=R;VQE)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%C:V%G94EN9F];)VUA:6YT86EN97)S)UU;)'1H:7,M/FU?:5U;)W)O
M;&4G72`]("=L96%D)SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/FU?:2LK.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("`@("`@8V%S92`G<F5L96%S92<Z#0H@("`@("`@("`@("`@("`@
M:68@*"1T:&ES+3YI;E]C:&%N9V5L;V<I('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/F-?:2LK.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)V-H86YG96QO9R<Z
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/FEN7V-H86YG96QO9R`](&9A;'-E
M.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!]#0H@("`@("`@
M(&%R<F%Y7W!O<"@D=&AI<RT^96QE;65N=%]S=&%C:RD[#0H@("`@("`@("1S
M<&]S(#T@<VEZ96]F*"1T:&ES+3YE;&5M96YT7W-T86-K*2`M(#$[#0H@("`@
M("`@("1T:&ES+3YC=7)R96YT7V5L96UE;G0@/2`H)'-P;W,@/B`P*2`_("1T
M:&ES+3YE;&5M96YT7W-T86-K6R1S<&]S72`Z("<G.PT*("`@("`@("`D=&AI
M<RT^8V1A=&$@/2`G)SL-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@7W!K9VEN9F]?8V1A=&%?,5\P*"D-"@T*("`@("\J*@T*("`@("`J(%A-
M3"!P87)S97(@8V%L;&)A8VL@9F]R(&-H87)A8W1E<B!D871A+B`@57-E9"!F
M;W(@=F5R<VEO;B`Q+C`-"B`@("`@*B!P86-K86=E<RX-"B`@("`@*@T*("`@
M("`J($!P87)A;2!R97-O=7)C92`@)'AP("`@(%A-3"!P87)S97(@<F5S;W5R
M8V4-"B`@("`@*B!`<&%R86T@<W1R:6YG("`@("1N86UE("!C:&%R86-T97(@
M9&%T80T*("`@("`J#0H@("`@("H@0')E='5R;B!V;VED#0H@("`@("H-"B`@
M("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?
M<&MG:6YF;U]C9&%T85\Q7S`H)'AP+"`D9&%T82D-"B`@("![#0H@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^8V1A=&$I*2![#0H@("`@("`@("`@("`D=&AI
M<RT^8V1A=&$@+CT@)&1A=&$[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O
M+R!]?7T-"GT-"C\^````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]0
M14%2+U!A8VMA9V5&:6QE+U!A<G-E<B]V,BYP:'``````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-C<W,``Q,#4Q-30S,S<T,``P,C,W-S$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`-"B\J*@T*("H@
M<&%C:V%G92YX;6P@<&%R<VEN9R!C;&%S<RP@<&%C:V%G92YX;6P@=F5R<VEO
M;B`R+C`-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)
M0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N
M(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@
M55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@
M($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0
M($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@
M=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-
M"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2
M#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^
M#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@
M=C(N<&AP+'8@,2XQ.2`R,#`V+S`Q+S(S(#$W.C,Y.C4R(&-E;&QO9R!%>'`@
M)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E
M;&5A<V4@,2XT+C!A,0T*("HO#0HO*BH-"B`J(&)A<V4@>&UL('!A<G-E<B!C
M;&%S<PT*("HO#0IR97%U:7)E7V]N8V4@)U!%05(O6$U,4&%R<V5R+G!H<"<[
M#0IR97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G949I;&4O=C(N<&AP)SL-"B\J
M*@T*("H@4&%R<V5R(&9O<B!P86-K86=E+GAM;"!V97)S:6]N(#(N,`T*("H@
M0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U
M=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@0%!%05(M5D52
M0`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!2
M96QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!4E]086-K86=E1FEL95]0
M87)S97)?=C(@97AT96YD<R!014%27UA-3%!A<G-E<@T*>PT*("`@('9A<B`D
M7V-O;F9I9SL-"B`@("!V87(@)%]L;V=G97([#0H@("`@=F%R("1?<F5G:7-T
M<GD[#0H-"B`@("!F=6YC=&EO;B!S971#;VYF:6<H)B1C*0T*("`@('L-"B`@
M("`@("`@)'1H:7,M/E]C;VYF:6<@/2`F)&,[#0H@("`@("`@("1T:&ES+3Y?
M<F5G:7-T<GD@/2`F)&,M/F=E=%)E9VES=')Y*"D[#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@<V5T3&]G9V5R*"8D;"D-"B`@("![#0H@("`@("`@("1T:&ES
M+3Y?;&]G9V5R(#T@)B1L.PT*("`@('T-"B`@("`O*BH-"B`@("`@*B!5;FEN
M9&5N="!G:79E;B!S=')I;F<-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I
M;F<@)'-T<B!4:&4@<W1R:6YG('1H870@:&%S('1O(&)E('5N:6YD96YT960N
M#0H@("`@("H@0')E='5R;B!S=')I;F<-"B`@("`@*B!`86-C97-S('!R:79A
M=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?=6Y);F1E;G0H)'-T<BD-"B`@
M("![#0H@("`@("`@("\O(')E;6]V92!L96%D:6YG(&YE=VQI;F5S#0H@("`@
M("`@("1S='(@/2!P<F5G7W)E<&QA8V4H)R]>6UQR7&Y=*R\G+"`G)RP@)'-T
M<BD[#0H@("`@("`@("\O(&9I;F0@=VAI=&5S<&%C92!A="!T:&4@8F5G:6YN
M:6YG(&]F('1H92!F:7)S="!L:6YE#0H@("`@("`@("1I;F1E;G1?;&5N(#T@
M<W1R<W!N*"1S='(L("(@7'0B*3L-"B`@("`@("`@)&EN9&5N="`]('-U8G-T
M<B@D<W1R+"`P+"`D:6YD96YT7VQE;BD[#0H@("`@("`@("1D871A(#T@)R<[
M#0H@("`@("`@("\O(')E;6]V92!T:&4@<V%M92!A;6]U;G0@;V8@=VAI=&5S
M<&%C92!F<F]M(&9O;&QO=VEN9R!L:6YE<PT*("`@("`@("!F;W)E86-H("AE
M>'!L;V1E*")<;B(L("1S='(I(&%S("1L:6YE*2![#0H@("`@("`@("`@("!I
M9B`H<W5B<W1R*"1L:6YE+"`P+"`D:6YD96YT7VQE;BD@/3T@)&EN9&5N="D@
M>PT*("`@("`@("`@("`@("`@("1D871A("X]('-U8G-T<B@D;&EN92P@)&EN
M9&5N=%]L96XI("X@(EQN(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@)&1A=&$[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@<&]S="UP<F]C97-S(&1A=&$-"B`@("`@*@T*("`@("`J($!P87)A;2!S
M=')I;F<@)&1A=&$-"B`@("`@*B!`<&%R86T@<W1R:6YG("1E;&5M96YT(&5L
M96UE;G0@;F%M90T*("`@("`J+PT*("`@(&9U;F-T:6]N('!O<W10<F]C97-S
M*"1D871A+"`D96QE;65N="D-"B`@("![#0H@("`@("`@(&EF("@D96QE;65N
M="`]/2`G;F]T97,G*2![#0H@("`@("`@("`@("!R971U<FX@=')I;2@D=&AI
M<RT^7W5N26YD96YT*"1D871A*2D[#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N('1R:6TH)&1A=&$I.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P
M87)A;2!S=')I;F<-"B`@("`@*B!`<&%R86T@<W1R:6YG(&9I;&4@;F%M92!O
M9B!T:&4@<&%C:V%G92YX;6P-"B`@("`@*B!`<&%R86T@<W1R:6YG?&9A;'-E
M(&YA;64@;V8@=&AE(&%R8VAI=F4@=&AI<R!P86-K86=E+GAM;"!C86UE(&9R
M;VTL(&EF(&%N>0T*("`@("`J($!P87)A;2!S=')I;F<@8VQA<W,@;F%M92!T
M;R!I;G-T86YT:6%T92!A;F0@<F5T=7)N+B`@5&AI<R!M=7-T(&)E(%!%05)?
M4&%C:V%G949I;&5?=C(@;W(-"B`@("`@*B`@("`@("`@("`@("`@(&$@<W5B
M8VQA<W,-"B`@("`@*B!`<F5T=7)N(%!%05)?4&%C:V%G949I;&5?=C(-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B`F<&%R<V4H)&1A=&$L("1F:6QE+"`D87)C
M:&EV92`](&9A;'-E+"`D8VQA<W,@/2`G4$5!4E]086-K86=E1FEL95]V,B<I
M#0H@("`@>PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R(#T@<&%R
M96YT.CIP87)S92@D9&%T82P@)&9I;&4I*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1E<G([#0H@("`@("`@('T-"B`@("`@("`@)')E="`](&YE=R`D8VQA
M<W,[#0H@("`@("`@("1R970M/G-E=$-O;F9I9R@D=&AI<RT^7V-O;F9I9RD[
M#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VQO9V=E<BDI('L-"B`@("`@
M("`@("`@("1R970M/G-E=$QO9V=E<B@D=&AI<RT^7VQO9V=E<BD[#0H@("`@
M("`@('T-"B`@("`@("`@)')E="T^9G)O;4%R<F%Y*"1T:&ES+3Y?=6YS97)I
M86QI>F5D1&%T82D[#0H@("`@("`@("1R970M/G-E=%!A8VMA9V5F:6QE*"1F
M:6QE+"`D87)C:&EV92D[#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-
M"GT-"C\^```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M4$5!4B]086-K86=E1FEL92]V,2YP:'``````````````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`Q-#4T-C8`,3`U,34T,S,W-#$`,#(R-30S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP#0HO*BH-"B`J
M(%!%05)?4&%C:V%G949I;&5?=C$L('!A8VMA9V4N>&UL('9E<G-I;VX@,2XP
M#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%
M.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@
M;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-
M"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T
M('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*
M("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@
M0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@
M0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(
M4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z('8Q+G!H
M<"QV(#$N-CD@,C`P-B\P,R\P,B`Q.#HQ-#HQ,R!C96QL;V<@17AP("0-"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2
M#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E
M(#$N-"XP83$-"B`J+PT*+RHJ#0H@*B!&;W(@97)R;W(@:&%N9&QI;F<-"B`J
M+PT*<F5Q=6ER95]O;F-E("=014%2+T5R<F]R4W1A8VLN<&AP)SL-"@T*+RHJ
M#0H@*B!%<G)O<B!C;V1E(&EF('!A<G-I;F<@:7,@871T96UP=&5D('=I=&@@
M;F\@>&UL(&5X=&5N<VEO;@T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)
M3$5?15)23U)?3D]?6$U,7T585"<L(#,I.PT*#0HO*BH-"B`J($5R<F]R(&-O
M9&4@:68@8W)E871I;F<@=&AE('AM;"!P87)S97(@<F5S;W5R8V4@9F%I;',-
M"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27T-!3E1?34%+
M15]005)315(G+"`T*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('5S960@9F]R
M(&%L;"!S87@@>&UL('!A<G-I;F<@97)R;W)S#0H@*B\-"F1E9FEN92@G4$5!
M4E]004-+04=%1DE,15]%4E)/4E]005)315)?15)23U(G+"`U*3L-"@T*+RHJ
M#0H@*B!%<G)O<B!C;V1E('5S960@=VAE;B!T:&5R92!I<R!N;R!N86UE#0H@
M*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E].3U].04U%)RP@
M-BD[#0H-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&$@<&%C:V%G92!N86UE
M(&ES(&YO="!V86QI9`T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?
M15)23U)?24Y604Q)1%].04U%)RP@-RD[#0H-"B\J*@T*("H@17)R;W(@8V]D
M92!U<V5D('=H96X@;F\@<W5M;6%R>2!I<R!P87)S960-"B`J+PT*9&5F:6YE
M*"=014%27U!!0TM!1T5&24Q%7T524D]27TY/7U-534U!4EDG+"`X*3L-"@T*
M+RHJ#0H@*B!%<G)O<B!C;V1E(&9O<B!S=6UM87)I97,@=&AA="!A<F4@;6]R
M92!T:&%N(#$@;&EN90T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?
M15)23U)?355,5$E,24Y%7U-534U!4EDG+"`Y*3L-"@T*+RHJ#0H@*B!%<G)O
M<B!C;V1E('5S960@=VAE;B!N;R!D97-C<FEP=&EO;B!I<R!P<F5S96YT#0H@
M*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]$15-#4DE0
M5$E/3B<L(#$P*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('5S960@=VAE;B!N
M;R!L:6-E;G-E(&ES('!R97-E;G0-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!
M1T5&24Q%7T524D]27TY/7TQ)0T5.4T4G+"`Q,2D[#0H-"B\J*@T*("H@17)R
M;W(@8V]D92!U<V5D('=H96X@82`\=F5R<VEO;CX@=F5R<VEO;B!N=6UB97(@
M:7,@;F]T('!R97-E;G0-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%
M7T524D]27TY/7U9%4E-)3TXG+"`Q,BD[#0H-"B\J*@T*("H@17)R;W(@8V]D
M92!U<V5D('=H96X@82`\=F5R<VEO;CX@=F5R<VEO;B!N=6UB97(@:7,@:6YV
M86QI9`T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?24Y6
M04Q)1%]615)324].)RP@,3,I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE
M;B!R96QE87-E('-T871E(&ES(&UI<W-I;F<-"B`J+PT*9&5F:6YE*"=014%2
M7U!!0TM!1T5&24Q%7T524D]27TY/7U-4051%)RP@,30I.PT*#0HO*BH-"B`J
M($5R<F]R(&-O9&4@=VAE;B!R96QE87-E('-T871E(&ES(&EN=F%L:60-"B`J
M+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27TE.5D%,241?4U1!
M5$4G+"`Q-2D[#0H-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(')E;&5A<V4@
M<W1A=&4@:7,@;6ES<VEN9PT*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)
M3$5?15)23U)?3D]?1$%412<L(#$V*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E
M('=H96X@<F5L96%S92!S=&%T92!I<R!I;G9A;&ED#0H@*B\-"F1E9FEN92@G
M4$5!4E]004-+04=%1DE,15]%4E)/4E])3E9!3$E$7T1!5$4G+"`Q-RD[#0H-
M"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&YO(')E;&5A<V4@;F]T97,@87)E
M(&9O=6YD#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E].
M3U].3U1%4R<L(#$X*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@;F\@
M;6%I;G1A:6YE<G,@87)E(&9O=6YD#0H@*B\-"F1E9FEN92@G4$5!4E]004-+
M04=%1DE,15]%4E)/4E].3U]-04E.5$%)3D524R<L(#$Y*3L-"@T*+RHJ#0H@
M*B!%<G)O<B!C;V1E('=H96X@82!M86EN=&%I;F5R(&AA<R!N;R!H86YD;&4-
M"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27TY/7TU!24Y4
M2$%.1$Q%)RP@,C`I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A(&UA
M:6YT86EN97(@:&%S(&YO(&AA;F1L90T*("HO#0ID969I;F4H)U!%05)?4$%#
M2T%'149)3$5?15)23U)?3D]?34%)3E123TQ%)RP@,C$I.PT*#0HO*BH-"B`J
M($5R<F]R(&-O9&4@=VAE;B!A(&UA:6YT86EN97(@:&%S(&YO(&YA;64-"B`J
M+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27TY/7TU!24Y43D%-
M12<L(#(R*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@82!M86EN=&%I
M;F5R(&AA<R!N;R!E;6%I;`T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)
M3$5?15)23U)?3D]?34%)3E1%34%)3"<L(#(S*3L-"@T*+RHJ#0H@*B!%<G)O
M<B!C;V1E('=H96X@82!M86EN=&%I;F5R(&AA<R!N;R!H86YD;&4-"B`J+PT*
M9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27TE.5D%,241?34%)3E12
M3TQ%)RP@,C0I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A(&1E<&5N
M9&5N8WD@:7,@;F]T(&$@4$A0(&1E<&5N9&5N8WDL(&)U="!H87,@;F\@;F%M
M90T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?3D]?1$50
M3D%-12<L(#(U*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@82!D97!E
M;F1E;F-Y(&AA<R!N;R!T>7!E("AP:V<L('!H<"P@971C+BD-"B`J+PT*9&5F
M:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27TY/7T1%4%194$4G+"`R-BD[
M#0H-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&$@9&5P96YD96YC>2!H87,@
M;F\@<F5L871I;VX@*&QT+"!G92P@:&%S+"!E=&,N*0T*("HO#0ID969I;F4H
M)U!%05)?4$%#2T%'149)3$5?15)23U)?3D]?1$504D5,)RP@,C<I.PT*#0HO
M*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A(&1E<&5N9&5N8WD@:7,@;F]T(&$@
M)VAA<R<@<F5L871I;VXL(&)U="!H87,@;F\@=F5R<VEO;@T*("HO#0ID969I
M;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?3D]?1$505D524TE/3B<L(#(X
M*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@82!D97!E;F1E;F-Y(&AA
M<R!A;B!I;G9A;&ED(')E;&%T:6]N#0H@*B\-"F1E9FEN92@G4$5!4E]004-+
M04=%1DE,15]%4E)/4E])3E9!3$E$7T1%4%)%3"<L(#(Y*3L-"@T*+RHJ#0H@
M*B!%<G)O<B!C;V1E('=H96X@82!D97!E;F1E;F-Y(&AA<R!A;B!I;G9A;&ED
M('1Y<&4-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27TE.
M5D%,241?1$505%E012<L(#,P*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H
M96X@82!D97!E;F1E;F-Y(&AA<R!A;B!I;G9A;&ED(&]P=&EO;F%L(&]P=&EO
M;@T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?24Y604Q)
M1%]$15!/4%1)3TY!3"<L(#,Q*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H
M96X@82!D97!E;F1E;F-Y(&ES(&$@<&MG(&1E<&5N9&5N8WDL(&%N9"!H87,@
M86X@:6YV86QI9"!P86-K86=E(&YA;64-"B`J+PT*9&5F:6YE*"=014%27U!!
M0TM!1T5&24Q%7T524D]27TE.5D%,241?1$503D%-12<L(#,R*3L-"@T*+RHJ
M#0H@*B!%<G)O<B!C;V1E('=H96X@82!D97!E;F1E;F-Y(&AA<R!A(&-H86YN
M96P](F9O;R(@871T<FEB=71E+"!A;F0@9F]O(&ES(&YO="!A(')E9VES=&5R
M960@8VAA;FYE;`T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?15)2
M3U)?54Y+3D]73E]$15!#2$%.3D5,)RP@,S,I.PT*#0HO*BH-"B`J($5R<F]R
M(&-O9&4@=VAE;B!R96P](FAA<R(@86YD('9E<G-I;VX@871T<FEB=71E(&ES
M('!R97-E;G0N#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/
M4E]$15!615)324].7TE'3D]2140G+"`S-"D[#0H-"B\J*@T*("H@17)R;W(@
M8V]D92!W:&5N('1Y<&4](G!H<"(@86YD(&1E<&5N9&5N8WD@;F%M92!I<R!P
M<F5S96YT#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E]$
M15!.04U%7TE'3D]2140G+"`S-2D[#0H-"B\J*@T*("H@17)R;W(@8V]D92!W
M:&5N(&$@8V]N9FEG=7)E(&]P=&EO;B!H87,@;F\@;F%M90T*("HO#0ID969I
M;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?3D]?0T].1DY!344G+"`S-BD[
M#0H-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&$@8V]N9FEG=7)E(&]P=&EO
M;B!H87,@;F\@;F%M90T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?
M15)23U)?3D]?0T].1E!23TU05"<L(#,W*3L-"@T*+RHJ#0H@*B!%<G)O<B!C
M;V1E('=H96X@82!F:6QE(&EN('1H92!F:6QE;&ES="!H87,@86X@:6YV86QI
M9"!R;VQE#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E])
M3E9!3$E$7T9)3$523TQ%)RP@,S@I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@
M=VAE;B!A(&9I;&4@:6X@=&AE(&9I;&5L:7-T(&AA<R!N;R!R;VQE#0H@*B\-
M"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]&24Q%4D],12<L
M(#,Y*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@86YA;'EZ:6YG(&$@
M<&AP('-O=7)C92!F:6QE('1H870@:&%S('!A<G-E(&5R<F]R<PT*("HO#0ID
M969I;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?24Y604Q)1%]02%!&24Q%
M)RP@-#`I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A;F%L>7II;F<@
M82!P:'`@<V]U<F-E(&9I;&4@<F5V96%L<R!A('-O=7)C92!E;&5M96YT#0H@
M*B!W:71H;W5T(&$@<&%C:V%G92!N86UE('!R969I>`T*("HO#0ID969I;F4H
M)U!%05)?4$%#2T%'149)3$5?15)23U)?3D]?4$Y!345?4%)%1DE8)RP@-#$I
M.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A;B!U;FMN;W=N(&-H86YN
M96P@:7,@<W!E8VEF:65D#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,
M15]%4E)/4E]53DM.3U=.7T-(04Y.14PG+"`T,BD[#0H-"B\J*@T*("H@17)R
M;W(@8V]D92!W:&5N(&YO(&9I;&5S(&%R92!F;W5N9"!I;B!T:&4@9FEL96QI
M<W0-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27TY/7T9)
M3$53)RP@-#,I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A(&9I;&4@
M:7,@;F]T('9A;&ED('!H<"!A8V-O<F1I;F<@=&\@7V%N86QY>F53;W5R8V5#
M;V1E*"D-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27TE.
M5D%,241?1DE,12<L(#0T*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@
M=&AE(&-H86YN96P@=F%L:61A=&]R(')E='5R;G,@86X@97)R;W(@;W(@=V%R
M;FEN9PT*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?0TA!
M3DY%3%9!3"<L(#0U*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@82!P
M:'`U('!A8VMA9V4@:7,@<&%C:V%G960@:6X@<&AP-"`H86YA;'ES:7,@9&]E
M<VXG="!W;W)K*0T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?15)2
M3U)?4$A0-2<L(#0V*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@82!F
M:6QE(&ES(&QI<W1E9"!I;B!P86-K86=E+GAM;"!B=70@9&]E<R!N;W0@97AI
M<W0-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27T9)3$5?
M3D]41D]53D0G+"`T-RD[#0H-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&$@
M/&1E<"!T>7!E/2)P:'`B(')E;#TB;F]T(BXN+B!I<R!E;F-O=6YT97)E9"`H
M=7-E(')E;#TB;F4B*0T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?
M4$A07TY/7TY/5"<L(#0X*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@
M82!P86-K86=E+GAM;"!C;VYT86EN<R!N;VXM25-/+3@X-3DM,2!C:&%R86-T
M97)S#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E].3TY?
M25-/7T-(05)3)RP@-#DI.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A
M(&1E<&5N9&5N8WD@:7,@;F]T(&$@)VAA<R<@<F5L871I;VXL(&)U="!H87,@
M;F\@=F5R<VEO;@T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?15)2
M3U)?3D]?1$504$A05D524TE/3B<L(#4P*3L-"@T*+RHJ#0H@*B!%<G)O<B!C
M;V1E('=H96X@82!P86-K86=E(&AA<R!N;R!L96%D(&1E=F5L;W!E<@T*("HO
M#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?3D]?3$5!1"<L(#4Q
M*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@82!F:6QE;F%M92!B96=I
M;G,@=VET:"`B+B(-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T52
M4D]27TE.5D%,241?1DE,14Y!344G+"`U,BD[#0HO*BH-"B`J('!A8VMA9V4N
M>&UL(&5N8V%P<W5L871O<@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A
M8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E
M;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!0
M2%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@
M("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S(%!%
M05)?4&%C:V%G949I;&5?=C$-"GL-"B`@("`O*BH-"B`@("`@*B!`86-C97-S
M('!R:79A=&4-"B`@("`@*B!`=F%R(%!%05)?17)R;W)3=&%C:PT*("`@("`J
M($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7W-T86-K.PT*
M#0H@("`@+RHJ#0H@("`@("H@02!R96=I<W1R>2!O8FIE8W0L('5S960@=&\@
M86-C97-S('1H92!P86-K86=E(&YA;64@=F%L:61A=&EO;B!R96=E>"!F;W(@
M;F]N+7-T86YD87)D(&-H86YN96QS#0H@("`@("H@0'9A<B!014%27U)E9VES
M=')Y#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R
M("1?<F5G:7-T<GD[#0H-"B`@("`O*BH-"B`@("`@*B!!;B!O8FIE8W0@=&AA
M="!C;VYT86EN<R!A(&QO9R!M971H;V0@=&AA="!M871C:&5S(%!%05)?0V]M
M;6]N.CIL;V<G<R!S:6=N871U<F4-"B`@("`@*B!`=F%R(&]B:F5C=`T*("`@
M("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7VQO9V=E
M<CL-"@T*("`@("\J*@T*("`@("`J(%!A<G-E9"!P86-K86=E(&EN9F]R;6%T
M:6]N#0H@("`@("H@0'9A<B!A<G)A>0T*("`@("`J($!A8V-E<W,@<')I=F%T
M90T*("`@("`J+PT*("`@('9A<B`D7W!A8VMA9V5);F9O.PT*#0H@("`@+RHJ
M#0H@("`@("H@<&%T:"!T;R!P86-K86=E+GAM;`T*("`@("`J($!V87(@<W1R
M:6YG#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R
M("1?<&%C:V%G949I;&4[#0H-"B`@("`O*BH-"B`@("`@*B!P871H('1O('!A
M8VMA9V4@+G1G>B!O<B!F86QS92!I9B!T:&ES(&ES(&$@;&]C86PO97AT<F%C
M=&5D('!A8VMA9V4N>&UL#0H@("`@("H@0'9A<B!S=')I;F<-"B`@("`@*B!`
M86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@)%]A<F-H:79E1FEL
M93L-"@T*("`@("\J*@T*("`@("`J($!V87(@:6YT#0H@("`@("H@0&%C8V5S
M<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?:7-686QI9"`](#`[#0H-
M"B`@("`O*BH-"B`@("`@*B!$971E<FUI;F5S('=H971H97(@=&AI<R!P86-K
M86=E9FEL92!W87,@:6YI=&EA;&EZ960@;VYL>2!W:71H('!A<G1I86P@<&%C
M:V%G92!I;F9O#0H@("`@("H-"B`@("`@*B!)9B!T:&ES('!A8VMA9V4@9FEL
M92!W87,@8V]N<W1R=6-T960@=FEA('!A<G-I;F<@4D535"P@:70@=VEL;"!O
M;FQY(&-O;G1A:6X-"B`@("`@*@T*("`@("`J("T@<&%C:V%G92!N86UE#0H@
M("`@("H@+2!C:&%N;F5L(&YA;64-"B`@("`@*B`M(&1E<&5N9&5N8VEE<R`-
M"B`@("`@*B!`=F%R(&)O;VQE86X-"B`@("`@*B!`86-C97-S('!R:79A=&4-
M"B`@("`@*B\-"B`@("!V87(@)%]I;F-O;7!L971E(#T@=')U93L-"@T*("`@
M("\J*@T*("`@("`J($!P87)A;2!B;V]L(&1E=&5R;6EN97,@=VAE=&AE<B!T
M;R!R971U<FX@82!014%27T5R<F]R(&]B:F5C="P@;W(@=7-E('1H92!014%2
M7T5R<F]R4W1A8VL-"B`@("`@*B!`<&%R86T@<W1R:6YG($YA;64@;V8@17)R
M;W(@4W1A8VL@8VQA<W,@=&\@=7-E+@T*("`@("`J+PT*("`@(&9U;F-T:6]N
M(%!%05)?4&%C:V%G949I;&5?=C$H*0T*("`@('L-"B`@("`@("`@)'1H:7,M
M/E]S=&%C:R`]("9N97<@4$5!4E]%<G)O<E-T86-K*"=014%27U!A8VMA9V5&
M:6QE7W8Q)RD[#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G-E=$5R<F]R365S
M<V%G951E;7!L871E*"1T:&ES+3Y?9V5T17)R;W)-97-S86=E*"DI.PT*("`@
M("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@('T-"@T*("`@(&9U;F-T
M:6]N(&EN<W1A;&Q":6YA<GDH)&EN<W1A;&QE<BD-"B`@("![#0H@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!I<T5X=&5N
M<VEO;B@D;F%M92D-"B`@("![#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("!]#0H-"B`@("!F=6YC=&EO;B!S971#;VYF:6<H)B1C;VYF:6<I#0H@("`@
M>PT*("`@("`@("`D=&AI<RT^7V-O;F9I9R`]("8D8V]N9FEG.PT*("`@("`@
M("`D=&AI<RT^7W)E9VES=')Y(#T@)B1C;VYF:6<M/F=E=%)E9VES=')Y*"D[
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T4F5Q=65S=&5D1W)O=7`H*0T*
M("`@('L-"B`@("`@("`@+R\@<&QA8V5H;VQD97(-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!&;W(@<V%V:6YG(&EN('1H92!R96=I<W1R>2X-"B`@("`@
M*@T*("`@("`J(%-E="!T:&4@;&%S="!V97)S:6]N('1H870@=V%S(&EN<W1A
M;&QE9`T*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!S971,87-T26YS=&%L;&5D5F5R<VEO;B@D=F5R<VEO;BD-"B`@("![
M#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)U]L87-T=F5R<VEO;B==
M(#T@)'9E<G-I;VX[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0')E='5R
M;B!S=')I;F=\9F%L<V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971,87-T
M26YS=&%L;&5D5F5R<VEO;B@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG7VQA<W1V97)S:6]N)UTI*2![#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG7VQA<W1V97)S
M:6]N)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N(&=E=$EN<W1A;&QE9$)I;F%R>2@I#0H@("`@
M>PT*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@;&ES=%!O<W1I;G-T86QL4V-R:7!T<R@I#0H@("`@>PT*("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@:6YI=%!O<W1I
M;G-T86QL4V-R:7!T<R@I#0H@("`@>PT*("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T3&]G9V5R*"8D;&]G9V5R*0T*
M("`@('L-"B`@("`@("`@:68@*"1L;V=G97(@)B8@*"%I<U]O8FIE8W0H)&QO
M9V=E<BD@?'P@(6UE=&AO9%]E>&ES=',H)&QO9V=E<BP@)VQO9R<I*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TQO9V=E<B!M
M=7-T(&)E(&-O;7!A=&EB;&4@=VET:"!014%27T-O;6UO;CHZ;&]G)RD[#0H@
M("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]L;V=G97(@/2`F)&QO9V=E<CL-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S971086-K86=E9FEL92@D9FEL92P@
M)&%R8VAI=F4@/2!F86QS92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<&%C
M:V%G949I;&4@/2`D9FEL93L-"B`@("`@("`@)'1H:7,M/E]A<F-H:79E1FEL
M92`]("1A<F-H:79E(#\@)&%R8VAI=F4@.B`D9FEL93L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!G971086-K86=E1FEL92@I#0H@("`@>PT*("`@("`@("!R
M971U<FX@:7-S970H)'1H:7,M/E]P86-K86=E1FEL92D@/R`D=&AI<RT^7W!A
M8VMA9V5&:6QE(#H@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T
M4&%C:V%G951Y<&4H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("=P:'`G.PT*
M("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$%R8VAI=F5&:6QE*"D-"B`@("![
M#0H@("`@("`@(')E='5R;B`D=&AI<RT^7V%R8VAI=F5&:6QE.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N('!A8VMA9V5);F9O*"1F:65L9"D-"B`@("![#0H@
M("`@("`@(&EF("@A:7-?<W1R:6YG*"1F:65L9"D@?'P@96UP='DH)&9I96QD
M*2!\?`T*("`@("`@("`@("`@(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];
M)&9I96QD72DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULD9FEE
M;&1=.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=$1I<G1R964H)'!A=&@I
M#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=D:7)T<F5E
M)UU;)'!A=&A=(#T@=')U93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971$
M:7)T<F5E*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A
M8VMA9V5);F9O6R=D:7)T<F5E)UTI("8F(&-O=6YT*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)V1I<G1R964G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7W!A8VMA9V5);F9O6R=D:7)T<F5E)UT[#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(')E<V5T
M1&ER=')E92@I#0H@("`@>PT*("`@("`@("!U;G-E="@D=&AI<RT^7W!A8VMA
M9V5);F9O6R=D:7)T<F5E)UTI.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&9R
M;VU!<G)A>2@D<&EN9F\I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7VEN8V]M
M<&QE=&4@/2!F86QS93L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]
M("1P:6YF;SL-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!I<TEN8V]M<&QE=&4H
M*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6YC;VUP;&5T93L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971#:&%N;F5L*"D-"B`@("![#0H@
M("`@("`@(')E='5R;B`G<&5A<BYP:'`N;F5T)SL-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!G9715<FDH*0T*("`@('L-"B`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=%1I;64H*0T*("`@('L-"B`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E
M=$5X=&5N9',H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)V5X=&5N9',G72DI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=E>'1E;F1S)UT[#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("`J($!R971U<FX@87)R87D-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!T;T%R
M<F%Y*"D-"B`@("![#0H@("`@("`@(&EF("@A)'1H:7,M/G9A;&ED871E*%!%
M05)?5D%,241!5$5?3D]234%,*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D=&AI<RT^9V5T07)R
M87DH*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971!<G)A>2@I#0H@("`@
M>PT*("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;SL-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!G971.86UE*"D-"B`@("![#0H@("`@("`@(')E
M='5R;B`D=&AI<RT^9V5T4&%C:V%G92@I.PT*("`@('T-"@T*("`@(&9U;F-T
M:6]N(&=E=%!A8VMA9V4H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3Y?<&%C:V%G94EN9F];)W!A8VMA9V4G72DI('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=P86-K86=E)UT[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J(%=!4DY)3D<@+2!D;VXG="!U<V4@=&AI<R!U;FQE<W,@>6]U
M(&MN;W<@=VAA="!Y;W4@87)E(&1O:6YG#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@<V5T4F%W4&%C:V%G92@D<&%C:V%G92D-"B`@("![#0H@("`@("`@("1T
M:&ES+3Y?<&%C:V%G94EN9F];)W!A8VMA9V4G72`]("1P86-K86=E.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N('-E=%!A8VMA9V4H)'!A8VMA9V4I#0H@("`@
M>PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=P86-K86=E)UT@/2`D
M<&%C:V%G93L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@9F%L<V4[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T5F5R<VEO;B@I#0H@("`@>PT*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG=F5R<VEO;B==
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];
M)W9E<G-I;VXG73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T5F5R<VEO;B@D=F5R<VEO;BD-
M"B`@("![#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)W9E<G-I;VXG
M72`]("1V97)S:6]N.PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2!F86QS
M93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!C;&5A<DUA:6YT86EN97)S*"D-
M"B`@("![#0H@("`@("`@('5N<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)VUA
M:6YT86EN97)S)UTI.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$UA:6YT
M86EN97)S*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A
M8VMA9V5);F9O6R=M86EN=&%I;F5R<R==*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)VUA:6YT86EN97)S)UT[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J($%D9',@82!N97<@;6%I;G1A:6YE<B`M(&YO(&-H96-K:6YG
M(&]F(&1U<&QI8V%T97,@:7,@<&5R9F]R;65D+"!U<V4-"B`@("`@*B!U<&1A
M=&5M86EN=&%I;F5R(&9O<B!T:&%T('!U<G!O<V4N#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@861D36%I;G1A:6YE<B@D<F]L92P@)&AA;F1L92P@)&YA;64L
M("1E;6%I;"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];
M)VUA:6YT86EN97)S)UU;72`]#0H@("`@("`@("`@("!A<G)A>2@G:&%N9&QE
M)R`]/B`D:&%N9&QE+"`G<F]L92<@/3X@)')O;&4L("=E;6%I;"<@/3X@)&5M
M86EL+"`G;F%M92<@/3X@)&YA;64I.PT*("`@("`@("`D=&AI<RT^7VES5F%L
M:60@/2!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!U<&1A=&5-86EN
M=&%I;F5R*"1R;VQE+"`D:&%N9&QE+"`D;F%M92P@)&5M86EL*0T*("`@('L-
M"B`@("`@("`@)&9O=6YD(#T@9F%L<V4[#0H@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG;6%I;G1A:6YE<G,G72D@?'P-"B`@("`@
M("`@("`@("`@(6ES7V%R<F%Y*"1T:&ES+3Y?<&%C:V%G94EN9F];)VUA:6YT
M86EN97)S)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/F%D9$UA
M:6YT86EN97(H)')O;&4L("1H86YD;&4L("1N86UE+"`D96UA:6PI.PT*("`@
M("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%C:V%G94EN9F];
M)VUA:6YT86EN97)S)UT@87,@)&D@/3X@)&UA:6YT86EN97(I('L-"B`@("`@
M("`@("`@(&EF("@D;6%I;G1A:6YE<ELG:&%N9&QE)UT@/3T@)&AA;F1L92D@
M>PT*("`@("`@("`@("`@("`@("1F;W5N9"`]("1I.PT*("`@("`@("`@("`@
M("`@(&)R96%K.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(&EF("@D9F]U;F0@(3T](&9A;'-E*2![#0H@("`@("`@("`@("!U;G-E="@D
M=&AI<RT^7W!A8VMA9V5);F9O6R=M86EN=&%I;F5R<R==6R1F;W5N9%TI.PT*
M("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG;6%I;G1A:6YE<G,G
M72`]#0H@("`@("`@("`@("`@("`@87)R87E?=F%L=65S*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)VUA:6YT86EN97)S)UTI.PT*("`@("`@("!]#0H@("`@("`@
M("1T:&ES+3YA9&1-86EN=&%I;F5R*"1R;VQE+"`D:&%N9&QE+"`D;F%M92P@
M)&5M86EL*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!D96QE=&5-86EN=&%I
M;F5R*"1H86YD;&4I#0H@("`@>PT*("`@("`@("`D9F]U;F0@/2!F86QS93L-
M"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P86-K86=E26YF;ULG;6%I;G1A
M:6YE<G,G72!A<R`D:2`]/B`D;6%I;G1A:6YE<BD@>PT*("`@("`@("`@("`@
M:68@*"1M86EN=&%I;F5R6R=H86YD;&4G72`]/2`D:&%N9&QE*2![#0H@("`@
M("`@("`@("`@("`@)&9O=6YD(#T@)&D[#0H@("`@("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1F
M;W5N9"`A/3T@9F%L<V4I('L-"B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)VUA:6YT86EN97)S)UU;)&9O=6YD72D[#0H@("`@("`@
M("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=M86EN=&%I;F5R<R==(#T-"B`@
M("`@("`@("`@("`@("!A<G)A>5]V86QU97,H)'1H:7,M/E]P86-K86=E26YF
M;ULG;6%I;G1A:6YE<G,G72D[#0H@("`@("`@("`@("!R971U<FX@=')U93L-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@9V5T4W1A=&4H*0T*("`@('L-"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A<V5?<W1A=&4G72DI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=R96QE
M87-E7W-T871E)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=%)A=U-T871E*"1S=&%T92D-
M"B`@("![#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A<V5?
M<W1A=&4G72`]("1S=&%T93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S9713
M=&%T92@D<W1A=&4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=R96QE87-E7W-T871E)UT@/2`D<W1A=&4[#0H@("`@("`@("1T:&ES
M+3Y?:7-686QI9"`](&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E
M=$1A=&4H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)W)E;&5A<V5?9&%T92==*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A<V5?9&%T92==.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!S971$871E*"1D871E*0T*("`@('L-"B`@("`@("`@)'1H:7,M
M/E]P86-K86=E26YF;ULG<F5L96%S95]D871E)UT@/2`D9&%T93L-"B`@("`@
M("`@)'1H:7,M/E]I<U9A;&ED(#T@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@9V5T3&EC96YS92@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG<F5L96%S95]L:6-E;G-E)UTI*2![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG<F5L96%S
M95]L:6-E;G-E)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=$QI8V5N<V4H)&1A=&4I#0H@
M("`@>PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=R96QE87-E7VQI
M8V5N<V4G72`]("1D871E.PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2!F
M86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G9713=6UM87)Y*"D-"B`@
M("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=S
M=6UM87)Y)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K
M86=E26YF;ULG<W5M;6%R>2==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S9713=6UM87)Y*"1S
M=6UM87)Y*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG
M<W5M;6%R>2==(#T@)'-U;6UA<GD[#0H@("`@("`@("1T:&ES+3Y?:7-686QI
M9"`](&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$1E<V-R:7!T
M:6]N*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA
M9V5);F9O6R=D97-C<FEP=&EO;B==*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<V-R:7!T:6]N)UT[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T
M:6]N('-E=$1E<V-R:7!T:6]N*"1D97-C*0T*("`@('L-"B`@("`@("`@)'1H
M:7,M/E]P86-K86=E26YF;ULG9&5S8W)I<'1I;VXG72`]("1D97-C.PT*("`@
M("`@("`D=&AI<RT^7VES5F%L:60@/2!F86QS93L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!G971.;W1E<R@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG<F5L96%S95]N;W1E<R==*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A<V5?
M;F]T97,G73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T3F]T97,H)&YO=&5S*0T*("`@('L-
M"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG<F5L96%S95]N;W1E<R==
M(#T@)&YO=&5S.PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2!F86QS93L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971$97!S*"D-"B`@("![#0H@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=R96QE87-E7V1E
M<',G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=R96QE87-E7V1E<',G73L-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4F5S970@9&5P
M96YD96YC:65S('!R:6]R('1O(&%D9&EN9R!N97<@;VYE<PT*("`@("`J+PT*
M("`@(&9U;F-T:6]N(&-L96%R1&5P<R@I#0H@("`@>PT*("`@("`@("!U;G-E
M="@D=&AI<RT^7W!A8VMA9V5);F9O6R=R96QE87-E7V1E<',G72D[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@861D4&AP1&5P*"1V97)S:6]N+"`D<F5L*0T*
M("`@('L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@9F%L<V4[#0H@("`@
M("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A<V5?9&5P<R==6UT@/0T*
M("`@("`@("`@("`@87)R87DH)W1Y<&4G(#T^("=P:'`G+`T*("`@("`@("`@
M("`@("`@("`@)W)E;"<@/3X@)')E;"P-"B`@("`@("`@("`@("`@("`@("=V
M97)S:6]N)R`]/B`D=F5R<VEO;BD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M861D4&%C:V%G941E<"@D;F%M92P@)'9E<G-I;VXL("1R96PL("1O<'1I;VYA
M;"`]("=N;R<I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2!F
M86QS93L-"B`@("`@("`@)&1E<"`]#0H@("`@("`@("`@("!A<G)A>2@G='EP
M92<@/3X@)W!K9R<L#0H@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@)&YA
M;64L#0H@("`@("`@("`@("`@("`@("`G<F5L)R`]/B`D<F5L+`T*("`@("`@
M("`@("`@("`@("`@)V]P=&EO;F%L)R`]/B`D;W!T:6]N86PI.PT*("`@("`@
M("!I9B`H)')E;"`A/2`G:&%S)R`F)B`D<F5L("$]("=N;W0G*2![#0H@("`@
M("`@("`@("`D9&5P6R=V97)S:6]N)UT@/2`D=F5R<VEO;CL-"B`@("`@("`@
M?0T*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=R96QE87-E7V1E<',G
M75M=(#T@)&1E<#L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!A9&1%>'1E;G-I
M;VY$97`H)&YA;64L("1V97)S:6]N+"`D<F5L+"`D;W!T:6]N86P@/2`G;F\G
M*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@9F%L<V4[#0H@
M("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A<V5?9&5P<R==6UT@
M/0T*("`@("`@("`@("`@87)R87DH)W1Y<&4G(#T^("=E>'0G+`T*("`@("`@
M("`@("`@("`@("`@)VYA;64G(#T^("1N86UE+`T*("`@("`@("`@("`@("`@
M("`@)W)E;"<@/3X@)')E;"P-"B`@("`@("`@("`@("`@("`@("=V97)S:6]N
M)R`]/B`D=F5R<VEO;BP-"B`@("`@("`@("`@("`@("`@("=O<'1I;VYA;"<@
M/3X@)&]P=&EO;F%L*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!705).
M24Y'("T@9&\@;F]T('5S92!T:&ES(&9U;F-T:6]N(&1I<F5C=&QY('5N;&5S
M<R!Y;W4@:VYO=R!W:&%T('EO=2=R92!D;VEN9PT*("`@("`J+PT*("`@(&9U
M;F-T:6]N('-E=$1E<',H)&1E<',I#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M7W!A8VMA9V5);F9O6R=R96QE87-E7V1E<',G72`]("1D97!S.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N(&AA<T1E<',H*0T*("`@('L-"B`@("`@("`@<F5T
M=7)N(&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A<V5?9&5P<R==
M*2`F)@T*("`@("`@("`@("`@8V]U;G0H)'1H:7,M/E]P86-K86=E26YF;ULG
M<F5L96%S95]D97!S)UTI.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$1E
M<&5N9&5N8WE'<F]U<"@D9W)O=7`I#0H@("`@>PT*("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@:7-#;VUP871I8FQE*"1P
M9BD-"B`@("![#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!I<U-U8G!A8VMA9V5/9B@D<"D-"B`@("![#0H@("`@("`@
M(')E='5R;B`D<"T^:7-3=6)P86-K86=E*"1T:&ES*3L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!I<U-U8G!A8VMA9V4H)'`I#0H@("`@>PT*("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9&5P96YD<T]N
M*"1P86-K86=E+"`D8VAA;FYE;"D-"B`@("![#0H@("`@("`@(&EF("AS=')T
M;VQO=V5R*"1C:&%N;F5L*2`A/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A
M*"1D97!S(#T@)'1H:7,M/F=E=$1E<',H*2DI('L-"B`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D9&5P
M<R!A<R`D9&5P*2![#0H@("`@("`@("`@("!I9B`H)&1E<%LG='EP92==("$]
M("=P:V<G*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!I9B`H<W1R=&]L;W=E<B@D9&5P6R=N86UE
M)UTI(#T]('-T<G1O;&]W97(H)'!A8VMA9V4I*2![#0H@("`@("`@("`@("`@
M("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E
M=$-O;F9I9W5R94]P=&EO;G,H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;F9I9W5R95]O<'1I;VYS)UTI*2![
M#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG8V]N
M9FEG=7)E7V]P=&EO;G,G73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@:&%S0V]N9FEG=7)E3W!T
M:6]N<R@I#0H@("`@>PT*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/E]P
M86-K86=E26YF;ULG8V]N9FEG=7)E7V]P=&EO;G,G72D@)B8-"B`@("`@("`@
M("`@(&-O=6YT*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;F9I9W5R95]O<'1I
M;VYS)UTI.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&%D9$-O;F9I9W5R94]P
M=&EO;B@D;F%M92P@)'!R;VUP="P@)&1E9F%U;'0@/2!F86QS92D-"B`@("![
M#0H@("`@("`@("1O(#T@87)R87DH)VYA;64G(#T^("1N86UE+"`G<')O;7!T
M)R`]/B`D<')O;7!T*3L-"B`@("`@("`@:68@*"1D969A=6QT("$]/2!F86QS
M92D@>PT*("`@("`@("`@("`@)&];)V1E9F%U;'0G72`]("1D969A=6QT.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E
M26YF;ULG8V]N9FEG=7)E7V]P=&EO;G,G72DI('L-"B`@("`@("`@("`@("1T
M:&ES+3Y?<&%C:V%G94EN9F];)V-O;F9I9W5R95]O<'1I;VYS)UT@/2!A<G)A
M>2@I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];
M)V-O;F9I9W5R95]O<'1I;VYS)UU;72`]("1O.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(&-L96%R0V]N9FEG=7)E3W!T:6]N<R@I#0H@("`@>PT*("`@("`@
M("!U;G-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYF:6=U<F5?;W!T:6]N
M<R==*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G9710<F]V:61E<R@I#0H@
M("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG
M<')O=FED97,G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A
M8VMA9V5);F9O6R=P<F]V:61E<R==.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!A9&1&:6QE*"1D
M:7(L("1F:6QE+"`D871T<G,I#0H@("`@>PT*("`@("`@("`D9&ER(#T@<')E
M9U]R97!L86-E*&%R<F%Y*"<A7%Q<7"LA)RP@)R$O*R$G*2P@87)R87DH)R\G
M+"`G+R<I+"`D9&ER*3L-"B`@("`@("`@:68@*"1D:7(@/3T@)R\G('Q\("1D
M:7(@/3T@)R<I('L-"B`@("`@("`@("`@("1D:7(@/2`G)SL-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("1D:7(@+CT@)R\G.PT*("`@("`@("!]
M#0H@("`@("`@("1F:6QE(#T@)&1I<B`N("1F:6QE.PT*("`@("`@("`D9FEL
M92`]('!R96=?<F5P;&%C92@G(5M<7"]=*R$G+"`G+R<L("1F:6QE*3L-"B`@
M("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG9FEL96QI<W0G75LD9FEL95T@
M/2`D871T<G,[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T26YS=&%L;&%T
M:6]N1FEL96QI<W0H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YG
M971&:6QE;&ES="@I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$9I;&5L
M:7-T*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA
M9V5);F9O6R=F:6QE;&ES="==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<&%C:V%G94EN9F];)V9I;&5L:7-T)UT[#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E
M=$9I;&5!='1R:6)U=&4H)&9I;&4L("1A='1R+"`D=F%L=64I#0H@("`@>PT*
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==6R1F:6QE
M75LD871T<ET@/2`D=F%L=64[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<F5S
M971&:6QE;&ES="@I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=F:6QE;&ES="==(#T@87)R87DH*3L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!S971);G-T86QL961!<R@D9FEL92P@)'!A=&@I#0H@("`@>PT*("`@
M("`@("!I9B`H)'!A=&@I('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7W!A8VMA9V5);F9O6R=F:6QE;&ES="==6R1F:6QE75LG:6YS=&%L;&5D7V%S
M)UT@/2`D<&%T:#L-"B`@("`@("`@?0T*("`@("`@("!U;G-E="@D=&AI<RT^
M7W!A8VMA9V5);F9O6R=F:6QE;&ES="==6R1F:6QE75LG:6YS=&%L;&5D7V%S
M)UTI.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&EN<W1A;&QE9$9I;&4H)&9I
M;&4L("1A='1S*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)V9I;&5L:7-T)UU;)&9I;&5=*2D@>PT*("`@("`@("`@
M("`@)'1H:7,M/E]P86-K86=E26YF;ULG9FEL96QI<W0G75LD9FEL95T@/0T*
M("`@("`@("`@("`@("`@(&%R<F%Y7VUE<F=E*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)V9I;&5L:7-T)UU;)&9I;&5=+"`D871T<RD[#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES
M="==6R1F:6QE72`]("1A='1S.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@9V5T0VAA;F=E;&]G*"D-"B`@("![#0H@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N9V5L;V<G72DI('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N9V5L
M;V<G73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@9V5T4&%C:V%G97AM;%9E<G-I;VXH*0T*("`@
M('L-"B`@("`@("`@<F5T=7)N("<Q+C`G.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("`J(%=R87!P97(@=&\@>T!L:6YK(%!%05)?17)R;W)3=&%C:SHZ9V5T
M17)R;W)S*"E]#0H@("`@("H@0'!A<F%M(&)O;VQE86X@9&5T97)M:6YE<R!W
M:&5T:&5R('1O('!U<F=E('1H92!E<G)O<B!S=&%C:R!A9G1E<B!R971R:65V
M:6YG#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&=E=%9A;&ED871I;VY787)N:6YG<R@D<'5R9V4@/2!T<G5E*0T*("`@
M('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<W1A8VLM/F=E=$5R<F]R<R@D
M<'5R9V4I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\J*@T*("`@("`J
M(%9A;&ED871I;VX@97)R;W(N("!!;'-O(&UA<FMS('1H92!O8FIE8W0@8V]N
M=&5N=',@87,@:6YV86QI9`T*("`@("`J($!P87)A;2!E<G)O<B!C;V1E#0H@
M("`@("H@0'!A<F%M(&%R<F%Y(&5R<F]R(&EN9F]R;6%T:6]N#0H@("`@("H@
M0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7W9A;&ED
M871E17)R;W(H)&-O9&4L("1P87)A;7,@/2!A<G)A>2@I*0T*("`@('L-"B`@
M("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"@D8V]D92P@)V5R<F]R)RP@)'!A
M<F%M<RP@9F%L<V4L(&9A;'-E+"!D96)U9U]B86-K=')A8V4H*2D[#0H@("`@
M("`@("1T:&ES+3Y?:7-686QI9"`](&9A;'-E.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J(%9A;&ED871I;VX@=V%R;FEN9RX@($1O97,@;F]T(&UA<FL@
M=&AE(&]B:F5C="!C;VYT96YT<R!I;G9A;&ED+@T*("`@("`J($!P87)A;2!E
M<G)O<B!C;V1E#0H@("`@("H@0'!A<F%M(&%R<F%Y(&5R<F]R(&EN9F]R;6%T
M:6]N#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@7W9A;&ED871E5V%R;FEN9R@D8V]D92P@)'!A<F%M<R`](&%R<F%Y
M*"DI#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*"1C;V1E
M+"`G=V%R;FEN9R<L("1P87)A;7,L(&9A;'-E+"!F86QS92P@9&5B=6=?8F%C
M:W1R86-E*"DI.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!I
M;G1E9V5R(&5R<F]R(&-O9&4-"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(%]G971%<G)O<DUE<W-A9V4H*0T*("`@
M('L-"B`@("`@("`@<F5T=7)N(&%R<F%Y*`T*("`@("`@("`@("`@("`@(%!%
M05)?4$%#2T%'149)3$5?15)23U)?3D]?3D%-12`]/@T*("`@("`@("`@("`@
M("`@("`@("`G36ES<VEN9R!086-K86=E($YA;64G+`T*("`@("`@("`@("`@
M("`@(%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?4U5-34%262`]/@T*("`@
M("`@("`@("`@("`@("`@("`G3F\@<W5M;6%R>2!F;W5N9"<L#0H@("`@("`@
M("`@("`@("`@4$5!4E]004-+04=%1DE,15]%4E)/4E]-54Q424Q)3D5?4U5-
M34%262`]/@T*("`@("`@("`@("`@("`@("`@("`G4W5M;6%R>2!S:&]U;&0@
M8F4@;VX@;VYE(&QI;F4G+`T*("`@("`@("`@("`@("`@(%!%05)?4$%#2T%'
M149)3$5?15)23U)?3D]?1$530U))4%1)3TX@/3X-"B`@("`@("`@("`@("`@
M("`@("`@)TUI<W-I;F<@9&5S8W)I<'1I;VXG+`T*("`@("`@("`@("`@("`@
M(%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?3$E#14Y312`]/@T*("`@("`@
M("`@("`@("`@("`@("`G36ES<VEN9R!L:6-E;G-E)RP-"B`@("`@("`@("`@
M("`@("!014%27U!!0TM!1T5&24Q%7T524D]27TY/7U9%4E-)3TX@/3X-"B`@
M("`@("`@("`@("`@("`@("`@)TYO(')E;&5A<V4@=F5R<VEO;B!F;W5N9"<L
M#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]3
M5$%412`]/@T*("`@("`@("`@("`@("`@("`@("`G3F\@<F5L96%S92!S=&%T
M92!F;W5N9"<L#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%1DE,15]%
M4E)/4E].3U]$051%(#T^#0H@("`@("`@("`@("`@("`@("`@("=.;R!R96QE
M87-E(&1A=&4@9F]U;F0G+`T*("`@("`@("`@("`@("`@(%!%05)?4$%#2T%'
M149)3$5?15)23U)?3D]?3D]415,@/3X-"B`@("`@("`@("`@("`@("`@("`@
M)TYO(')E;&5A<V4@;F]T97,@9F]U;F0G+`T*("`@("`@("`@("`@("`@(%!%
M05)?4$%#2T%'149)3$5?15)23U)?3D]?3$5!1"`]/@T*("`@("`@("`@("`@
M("`@("`@("`G4&%C:V%G92!M=7-T(&AA=F4@870@;&5A<W0@;VYE(&QE860@
M;6%I;G1A:6YE<B<L#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%1DE,
M15]%4E)/4E].3U]-04E.5$%)3D524R`]/@T*("`@("`@("`@("`@("`@("`@
M("`G3F\@;6%I;G1A:6YE<G,@9F]U;F0L(&%T(&QE87-T(&]N92!M=7-T(&)E
M(&1E9FEN960G+`T*("`@("`@("`@("`@("`@(%!%05)?4$%#2T%'149)3$5?
M15)23U)?3D]?34%)3E1(04Y$3$4@/3X-"B`@("`@("`@("`@("`@("`@("`@
M)TUA:6YT86EN97(@)6EN9&5X)2!H87,@;F\@:&%N9&QE("AU<V5R($E$(&%T
M(&-H86YN96P@<V5R=F5R*2<L#0H@("`@("`@("`@("`@("`@4$5!4E]004-+
M04=%1DE,15]%4E)/4E].3U]-04E.5%)/3$4@/3X-"B`@("`@("`@("`@("`@
M("`@("`@)TUA:6YT86EN97(@)6EN9&5X)2!H87,@;F\@<F]L92<L#0H@("`@
M("`@("`@("`@("`@4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]-04E.5$Y!
M344@/3X-"B`@("`@("`@("`@("`@("`@("`@)TUA:6YT86EN97(@)6EN9&5X
M)2!H87,@;F\@;F%M92<L#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%
M1DE,15]%4E)/4E].3U]-04E.5$5-04E,(#T^#0H@("`@("`@("`@("`@("`@
M("`@("=-86EN=&%I;F5R("5I;F1E>"4@:&%S(&YO(&5M86EL)RP-"B`@("`@
M("`@("`@("`@("!014%27U!!0TM!1T5&24Q%7T524D]27TY/7T1%4$Y!344@
M/3X-"B`@("`@("`@("`@("`@("`@("`@)T1E<&5N9&5N8WD@)6EN9&5X)2!I
M<R!N;W0@82!P:'`@9&5P96YD96YC>2P@86YD(&AA<R!N;R!N86UE)RP-"B`@
M("`@("`@("`@("`@("!014%27U!!0TM!1T5&24Q%7T524D]27TY/7T1%4%)%
M3"`]/@T*("`@("`@("`@("`@("`@("`@("`G1&5P96YD96YC>2`E:6YD97@E
M(&AA<R!N;R!R96QA=&EO;B`H<F5L*2<L#0H@("`@("`@("`@("`@("`@4$5!
M4E]004-+04=%1DE,15]%4E)/4E].3U]$15!465!%(#T^#0H@("`@("`@("`@
M("`@("`@("`@("=$97!E;F1E;F-Y("5I;F1E>"4@:&%S(&YO('1Y<&4G+`T*
M("`@("`@("`@("`@("`@(%!%05)?4$%#2T%'149)3$5?15)23U)?1$503D%-
M15])1TY/4D5$(#T^#0H@("`@("`@("`@("`@("`@("`@("=02%`@1&5P96YD
M96YC>2`E:6YD97@E(&AA<R!A(&YA;64@871T<FEB=71E(&]F("(E;F%M924B
M('=H:6-H('=I;&P@8F4G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("<@
M:6=N;W)E9"$G+`T*("`@("`@("`@("`@("`@(%!%05)?4$%#2T%'149)3$5?
M15)23U)?3D]?1$505D524TE/3B`]/@T*("`@("`@("`@("`@("`@("`@("`G
M1&5P96YD96YC>2`E:6YD97@E(&ES(&YO="!A(')E;#TB:&%S(B!O<B!R96P]
M(FYO="(@9&5P96YD96YC>2P@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`G86YD(&AA<R!N;R!V97)S:6]N)RP-"B`@("`@("`@("`@("`@("!014%2
M7U!!0TM!1T5&24Q%7T524D]27TY/7T1%4%!(4%9%4E-)3TX@/3X-"B`@("`@
M("`@("`@("`@("`@("`@)T1E<&5N9&5N8WD@)6EN9&5X)2!I<R!A('1Y<&4]
M(G!H<"(@9&5P96YD96YC>2P@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`G86YD(&AA<R!N;R!V97)S:6]N)RP-"B`@("`@("`@("`@("`@("!014%2
M7U!!0TM!1T5&24Q%7T524D]27T1%4%9%4E-)3TY?24=.3U)%1"`]/@T*("`@
M("`@("`@("`@("`@("`@("`G1&5P96YD96YC>2`E:6YD97@E(&ES(&$@<F5L
M/2(E<F5L)2(@9&5P96YD96YC>2P@=F5R<VEO;FEN9R!I<R!I9VYO<F5D)RP-
M"B`@("`@("`@("`@("`@("!014%27U!!0TM!1T5&24Q%7T524D]27TE.5D%,
M241?1$503U!424].04P@/3X-"B`@("`@("`@("`@("`@("`@("`@)T1E<&5N
M9&5N8WD@)6EN9&5X)2!H87,@:6YV86QI9"!O<'1I;VYA;"!V86QU92`B)6]P
M="4B+"!S:&]U;&0@8F4@>65S(&]R(&YO)RP-"B`@("`@("`@("`@("`@("!0
M14%27U!!0TM!1T5&24Q%7U!(4%].3U].3U0@/3X-"B`@("`@("`@("`@("`@
M("`@("`@)T1E<&5N9&5N8WD@)6EN9&5X)3H@<&AP(&1E<&5N9&5N8VEE<R!C
M86YN;W0@=7-E(")N;W0B(')E;"P@=7-E(")N92(G("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("<@=&\@97AC;'5D92!S<&5C:69I8R!V97)S:6]N<R<L
M#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]#
M3TY&3D%-12`]/@T*("`@("`@("`@("`@("`@("`@("`G0V]N9FEG=7)E($]P
M=&EO;B`E:6YD97@E(&AA<R!N;R!N86UE)RP-"B`@("`@("`@("`@("`@("!0
M14%27U!!0TM!1T5&24Q%7T524D]27TY/7T-/3D904D]-4%0@/3X-"B`@("`@
M("`@("`@("`@("`@("`@)T-O;F9I9W5R92!/<'1I;VX@)6EN9&5X)2!H87,@
M;F\@<')O;7!T)RP-"B`@("`@("`@("`@("`@("!014%27U!!0TM!1T5&24Q%
M7T524D]27TY/7T9)3$53(#T^#0H@("`@("`@("`@("`@("`@("`@("=.;R!F
M:6QE<R!I;B`\9FEL96QI<W0^('-E8W1I;VX@;V8@<&%C:V%G92YX;6PG+`T*
M("`@("`@("`@("`@("`@(%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?1DE,
M15)/3$4@/3X-"B`@("`@("`@("`@("`@("`@("`@)T9I;&4@(B5F:6QE)2(@
M:&%S(&YO(')O;&4L(&5X<&5C=&EN9R!O;F4@;V8@(B5R;VQE<R4B)RP-"B`@
M("`@("`@("`@("`@("!014%27U!!0TM!1T5&24Q%7T524D]27TE.5D%,241?
M1DE,15)/3$4@/3X-"B`@("`@("`@("`@("`@("`@("`@)T9I;&4@(B5F:6QE
M)2(@:&%S(&EN=F%L:60@<F]L92`B)7)O;&4E(BP@97AP96-T:6YG(&]N92!O
M9B`B)7)O;&5S)2(G+`T*("`@("`@("`@("`@("`@(%!%05)?4$%#2T%'149)
M3$5?15)23U)?24Y604Q)1%]&24Q%3D%-12`]/@T*("`@("`@("`@("`@("`@
M("`@("`G1FEL92`B)69I;&4E(B!C86YN;W0@<W1A<G0@=VET:"`B+B(L(&-A
M;FYO="!P86-K86=E(&]R(&EN<W1A;&PG+`T*("`@("`@("`@("`@("`@(%!%
M05)?4$%#2T%'149)3$5?15)23U)?24Y604Q)1%]02%!&24Q%(#T^#0H@("`@
M("`@("`@("`@("`@("`@("=087)S97(@97)R;W(Z(&EN=F%L:60@4$A0(&9O
M=6YD(&EN(&9I;&4@(B5F:6QE)2(G+`T*("`@("`@("`@("`@("`@(%!%05)?
M4$%#2T%'149)3$5?15)23U)?3D]?4$Y!345?4%)%1DE8(#T^#0H@("`@("`@
M("`@("`@("`@("`@("=I;B`E9FEL924Z("5T>7!E)2`B)6YA;64E(B!N;W0@
M<')E9FEX960@=VET:"!P86-K86=E(&YA;64@(B5P86-K86=E)2(G+`T*("`@
M("`@("`@("`@("`@(%!%05)?4$%#2T%'149)3$5?15)23U)?24Y604Q)1%]&
M24Q%(#T^#0H@("`@("`@("`@("`@("`@("`@("=087)S97(@97)R;W(Z(&EN
M=F%L:60@4$A0(&9I;&4@(B5F:6QE)2(G+`T*("`@("`@("`@("`@("`@(%!%
M05)?4$%#2T%'149)3$5?15)23U)?0TA!3DY%3%9!3"`]/@T*("`@("`@("`@
M("`@("`@("`@("`G0VAA;FYE;"!V86QI9&%T;W(@97)R;W(Z(&9I96QD("(E
M9FEE;&0E(B`M("5R96%S;VXE)RP-"B`@("`@("`@("`@("`@("!014%27U!!
M0TM!1T5&24Q%7T524D]27U!(4#4@/3X-"B`@("`@("`@("`@("`@("`@("`@
M)T5R<F]R+"!02%`U('1O:V5N(&5N8V]U;G1E<F5D(&EN("5F:6QE)2P@86YA
M;'ES:7,@<VAO=6QD(&)E(&EN(%!(4#4G+`T*("`@("`@("`@("`@("`@(%!%
M05)?4$%#2T%'149)3$5?15)23U)?1DE,15].3U1&3U5.1"`]/@T*("`@("`@
M("`@("`@("`@("`@("`G1FEL92`B)69I;&4E(B!I;B!P86-K86=E+GAM;"!D
M;V5S(&YO="!E>&ES="<L#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%
M1DE,15]%4E)/4E].3TY?25-/7T-(05)3(#T^#0H@("`@("`@("`@("`@("`@
M("`@("=086-K86=E+GAM;"!C;VYT86EN<R!N;VXM25-/+3@X-3DM,2!C:&%R
M86-T97)S+"!A;F0@;6%Y(&YO="!V86QI9&%T92<L#0H@("`@("`@("`@("`I
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%9A;&ED871E(%A-3"!P86-K
M86=E(&1E9FEN:71I;VX@9FEL92X-"B`@("`@*@T*("`@("`J($!A8V-E<W,@
M<'5B;&EC#0H@("`@("H@0')E='5R;B!B;V]L96%N#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@=F%L:61A=&4H)'-T871E(#T@4$5!4E]604Q)1$%415].3U)-
M04PL("1N;V9I;&5C:&5C:VEN9R`](&9A;'-E*0T*("`@('L-"B`@("`@("`@
M:68@*"@D=&AI<RT^7VES5F%L:60@)B`D<W1A=&4I(#T]("1S=&%T92D@>PT*
M("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@
M)'1H:7,M/E]I<U9A;&ED(#T@=')U93L-"B`@("`@("`@)&EN9F\@/2`D=&AI
M<RT^7W!A8VMA9V5);F9O.PT*("`@("`@("!I9B`H96UP='DH)&EN9F];)W!A
M8VMA9V4G72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O
M<BA014%27U!!0TM!1T5&24Q%7T524D]27TY/7TY!344I.PT*("`@("`@("`@
M("`@)'1H:7,M/E]P86-K86=E3F%M92`]("1P;B`]("=U;FMN;W=N)SL-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94YA
M;64@/2`D<&X@/2`D:6YF;ULG<&%C:V%G92==.PT*("`@("`@("!]#0H-"B`@
M("`@("`@:68@*&5M<'1Y*"1I;F9O6R=S=6UM87)Y)UTI*2![#0H@("`@("`@
M("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]004-+04=%1DE,15]%
M4E)/4E].3U]354U-05)9*3L-"B`@("`@("`@?2!E;'-E:68@*'-T<G!O<RAT
M<FEM*"1I;F9O6R=S=6UM87)Y)UTI+"`B7&XB*2`A/3T@9F%L<V4I('L-"B`@
M("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5787)N:6YG*%!%05)?4$%#2T%'
M149)3$5?15)23U)?355,5$E,24Y%7U-534U!4EDL#0H@("`@("`@("`@("`@
M("`@87)R87DH)W-U;6UA<GDG(#T^("1I;F9O6R=S=6UM87)Y)UTI*3L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H96UP='DH)&EN9F];)V1E<V-R:7!T:6]N
M)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!
M4E]004-+04=%1DE,15]%4E)/4E].3U]$15-#4DE05$E/3BD[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&5M<'1Y*"1I;F9O6R=R96QE87-E7VQI8V5N<V4G
M72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%2
M7U!!0TM!1T5&24Q%7T524D]27TY/7TQ)0T5.4T4I.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("AE;7!T>2@D:6YF;ULG=F5R<VEO;B==*2D@>PT*("`@("`@
M("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?4$%#2T%'149)3$5?
M15)23U)?3D]?5D524TE/3BD[#0H@("`@("`@('T-"B`@("`@("`@:68@*&5M
M<'1Y*"1I;F9O6R=R96QE87-E7W-T871E)UTI*2![#0H@("`@("`@("`@("`D
M=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]004-+04=%1DE,15]%4E)/4E].
M3U]35$%412D[#0H@("`@("`@('T-"B`@("`@("`@:68@*&5M<'1Y*"1I;F9O
M6R=R96QE87-E7V1A=&4G72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?=F%L
M:61A=&5%<G)O<BA014%27U!!0TM!1T5&24Q%7T524D]27TY/7T1!5$4I.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AE;7!T>2@D:6YF;ULG<F5L96%S95]N
M;W1E<R==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R
M*%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?3D]415,I.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AE;7!T>2@D:6YF;ULG;6%I;G1A:6YE<G,G72DI('L-
M"B`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27U!!0TM!
M1T5&24Q%7T524D]27TY/7TU!24Y404E.15)3*3L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1H87-L96%D(#T@9F%L<V4[#0H@("`@("`@("`@
M("`D:2`](#$[#0H@("`@("`@("`@("!F;W)E86-H("@D:6YF;ULG;6%I;G1A
M:6YE<G,G72!A<R`D;2D@>PT*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D
M;5LG:&%N9&QE)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M=F%L:61A=&5%<G)O<BA014%27U!!0TM!1T5&24Q%7T524D]27TY/7TU!24Y4
M2$%.1$Q%+`T*("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)VEN9&5X
M)R`]/B`D:2DI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!I9B`H96UP='DH)&U;)W)O;&4G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?4$%#2T%'149)3$5?15)2
M3U)?3D]?34%)3E123TQ%+`T*("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)VEN9&5X)R`]/B`D:2P@)W)O;&5S)R`]/B!014%27T-O;6UO;CHZ9V5T
M57-E<E)O;&5S*"DI*3L-"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&U;
M)W)O;&4G72`]/2`G;&5A9"<I('L-"B`@("`@("`@("`@("`@("`@("`@)&AA
M<VQE860@/2!T<G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!I9B`H96UP='DH)&U;)VYA;64G72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?4$%#2T%'149)3$5?
M15)23U)?3D]?34%)3E1.04U%+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)VEN9&5X)R`]/B`D:2DI.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!I9B`H96UP='DH)&U;)V5M86EL)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27U!!
M0TM!1T5&24Q%7T524D]27TY/7TU!24Y414U!24PL#0H@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@G:6YD97@G(#T^("1I*2D[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("1I*RL[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!I9B`H(21H87-L96%D*2![#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?4$%#2T%'149)3$5?15)2
M3U)?3D]?3$5!1"D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"%E;7!T>2@D:6YF;ULG<F5L96%S95]D97!S)UTI*2![#0H@("`@
M("`@("`@("`D:2`](#$[#0H@("`@("`@("`@("!F;W)E86-H("@D:6YF;ULG
M<F5L96%S95]D97!S)UT@87,@)&0I('L-"B`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1D6R=T>7!E)UTI('Q\(&5M<'1Y*"1D6R=T>7!E)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%2
M7U!!0TM!1T5&24Q%7T524D]27TY/7T1%4%194$4L#0H@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@G:6YD97@G(#T^("1I+"`G='EP97,G(#T^(%!%
M05)?0V]M;6]N.CIG971$97!E;F1E;F-Y5'EP97,H*2DI.PT*("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D9%LG<F5L)UTI('Q\(&5M<'1Y*"1D
M6R=R96PG72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI
M9&%T945R<F]R*%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?1$504D5,+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)VEN9&5X)R`]/B`D:2P@
M)W)E;',G(#T^(%!%05)?0V]M;6]N.CIG971$97!E;F1E;F-Y4F5L871I;VYS
M*"DI*3L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&1;)V]P
M=&EO;F%L)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:6Y?87)R
M87DH)&1;)V]P=&EO;F%L)UTL(&%R<F%Y*"=Y97,G+"`G;F\G*2DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA0
M14%27U!!0TM!1T5&24Q%7T524D]27TE.5D%,241?1$503U!424].04PL#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)VEN9&5X)R`]/B`D
M:2P@)V]P="<@/3X@)&1;)V]P=&EO;F%L)UTI*3L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I
M9B`H)&1;)W)E;"==("$]("=H87,G("8F("1D6R=R96PG72`A/2`G;F]T)R`F
M)B!E;7!T>2@D9%LG=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]004-+04=%1DE,15]%4E)/
M4E].3U]$15!615)324].+`T*("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)VEN9&5X)R`]/B`D:2DI.PT*("`@("`@("`@("`@("`@('T@96QS96EF
M("@H)&1;)W)E;"==(#T]("=H87,G('Q\("1D6R=R96PG72`]/2`G;F]T)RD@
M)B8@(65M<'1Y*"1D6R=V97)S:6]N)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?=F%L:61A=&5787)N:6YG*%!%05)?4$%#2T%'149)3$5?
M15)23U)?1$505D524TE/3E])1TY/4D5$+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH)VEN9&5X)R`]/B`D:2P@)W)E;"<@/3X@)&1;)W)E;"==
M*2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D
M9%LG='EP92==(#T]("=P:'`G("8F("%E;7!T>2@D9%LG;F%M92==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E5V%R;FEN9RA0
M14%27U!!0TM!1T5&24Q%7T524D]27T1%4$Y!345?24=.3U)%1"P-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=I;F1E>"<@/3X@)&DL("=N86UE
M)R`]/B`D9%LG;F%M92==*2D[#0H@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*"1D6R=T>7!E)UT@(3T@)W!H<"<@)B8@96UP='DH)&1;)VYA;64G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%
M05)?4$%#2T%'149)3$5?15)23U)?3D]?1$503D%-12P-"B`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"=I;F1E>"<@/3X@)&DI*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1D6R=T>7!E)UT@/3T@
M)W!H<"<@)B8@96UP='DH)&1;)W9E<G-I;VXG72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?4$%#2T%'149)
M3$5?15)23U)?3D]?1$504$A05D524TE/3BP-"B`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=I;F1E>"<@/3X@)&DI*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@:68@*"@D9%LG<F5L)UT@/3T@)VYO="<I
M("8F("@D9%LG='EP92==(#T]("=P:'`G*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]004-+04=%1DE,15]0
M2%!?3D]?3D]4+`T*("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)VEN
M9&5X)R`]/B`D:2DI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`D:2LK.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(&EF("@A96UP='DH)&EN9F];)V-O;F9I9W5R95]O<'1I;VYS)UTI*2![#0H@
M("`@("`@("`@("`D:2`](#$[#0H@("`@("`@("`@("!F;W)E86-H("@D:6YF
M;ULG8V]N9FEG=7)E7V]P=&EO;G,G72!A<R`D8RD@>PT*("`@("`@("`@("`@
M("`@(&EF("AE;7!T>2@D8ULG;F%M92==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]004-+04=%1DE,15]%
M4E)/4E].3U]#3TY&3D%-12P-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=I;F1E>"<@/3X@)&DI*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@:68@*&5M<'1Y*"1C6R=P<F]M<'0G72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?4$%#
M2T%'149)3$5?15)23U)?3D]?0T].1E!23TU05"P-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*"=I;F1E>"<@/3X@)&DI*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@)&DK*SL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H96UP='DH)&EN9F];)V9I;&5L:7-T
M)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!
M4E]004-+04=%1DE,15]%4E)/4E].3U]&24Q%4RD[#0H@("`@("`@("`@("`D
M97)R;W)S6UT@/2`G;F\@9FEL97,G.PT*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@9F]R96%C:"`H)&EN9F];)V9I;&5L:7-T)UT@87,@)&9I;&4@
M/3X@)&9A*2![#0H@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1F85LG<F]L
M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E
M17)R;W(H4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]&24Q%4D],12P-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=F:6QE)R`]/B`D9FEL92P@
M)W)O;&5S)R`]/B!014%27T-O;6UO;CHZ9V5T1FEL95)O;&5S*"DI*3L-"B`@
M("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*"%I;E]A<G)A>2@D9F%;)W)O;&4G72P@4$5!4E]#;VUM;VXZ
M.F=E=$9I;&52;VQE<R@I*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W9A;&ED871E17)R;W(H4$5!4E]004-+04=%1DE,15]%4E)/4E])3E9!
M3$E$7T9)3$523TQ%+`T*("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)V9I;&4G(#T^("1F:6QE+"`G<F]L92<@/3X@)&9A6R=R;VQE)UTL("=R;VQE
M<R<@/3X@4$5!4E]#;VUM;VXZ.F=E=$9I;&52;VQE<R@I*2D[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D9FEL97LP?2`]/2`G
M+B<@)B8@)&9I;&5[,7T@/3T@)R\G*2![#0H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27U!!0TM!1T5&24Q%7T524D]2
M7TE.5D%,241?1DE,14Y!344L#0H@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G9FEL92<@/3X@)&9I;&4I*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3Y?<F5G:7-T<GDI("8F("1T:&ES+3Y?:7-686QI9"D@>PT*("`@("`@
M("`@("`@)&-H86X@/2`D=&AI<RT^7W)E9VES=')Y+3YG971#:&%N;F5L*"=P
M96%R+G!H<"YN970G*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1C:&%N*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%
M<G)O<BA014%27U!!0TM!1T5&24Q%7T524D]27T-(04Y.14Q604PL("1C:&%N
M+3YG971-97-S86=E*"DI.PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7VES5F%L:60@/2`P.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M)'9A;&ED871O<B`]("1C:&%N+3YG971686QI9&%T:6]N3V)J96-T*"D[#0H@
M("`@("`@("`@("`D=F%L:61A=&]R+3YS971086-K86=E1FEL92@D=&AI<RD[
M#0H@("`@("`@("`@("`D=F%L:61A=&]R+3YV86QI9&%T92@D<W1A=&4I.PT*
M("`@("`@("`@("`@)&9A:6QU<F5S(#T@)'9A;&ED871O<BT^9V5T1F%I;'5R
M97,H*3L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1F86EL=7)E<ULG97)R;W)S
M)UT@87,@)&5R<F]R*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI
M9&%T945R<F]R*%!%05)?4$%#2T%'149)3$5?15)23U)?0TA!3DY%3%9!3"P@
M)&5R<F]R*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@
M*"1F86EL=7)E<ULG=V%R;FEN9W,G72!A<R`D=V%R;FEN9RD@>PT*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5787)N:6YG*%!%05)?4$%#2T%'
M149)3$5?15)23U)?0TA!3DY%3%9!3"P@)'=A<FYI;F<I.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@D=&AI<RT^7VES5F%L:60@
M)B8@)'-T871E(#T](%!%05)?5D%,241!5$5?4$%#2T%'24Y'("8F("$D;F]F
M:6QE8VAE8VMI;F<I('L-"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V%N86QY
M>F50:'!&:6QE<R@I*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]I<U9A
M;&ED(#T@=')U93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H)'1H:7,M/E]I<U9A;&ED*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]I<U9A;&ED(#T@)'-T871E.PT*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(%]A;F%L>7IE4&AP1FEL97,H*0T*("`@('L-"B`@("`@("`@:68@
M*"$D=&AI<RT^7VES5F%L:60I('L-"B`@("`@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C
M:V%G949I;&4I*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@('T-"B`@("`@("`@)&1I<E]P<F5F:7@@/2!D:7)N86UE*"1T:&ES+3Y?
M<&%C:V%G949I;&4I.PT*("`@("`@("`D8V]M;6]N(#T@;F5W(%!%05)?0V]M
M;6]N.PT*("`@("`@("`D;&]G(#T@:7-S970H)'1H:7,M/E]L;V=G97(I(#\@
M87)R87DH)B1T:&ES+3Y?;&]G9V5R+"`G;&]G)RD@.@T*("`@("`@("`@("`@
M87)R87DH)&-O;6UO;BP@)VQO9R<I.PT*("`@("`@("`D:6YF;R`]("1T:&ES
M+3YG971&:6QE;&ES="@I.PT*("`@("`@("!F;W)E86-H("@D:6YF;R!A<R`D
M9FEL92`]/B`D9F$I('L-"B`@("`@("`@("`@(&EF("@A9FEL95]E>&ES=',H
M)&1I<E]P<F5F:7@@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)&9I;&4I*2![
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?
M4$%#2T%'149)3$5?15)23U)?1DE,15].3U1&3U5.1"P-"B`@("`@("`@("`@
M("`@("`@("`@87)R87DH)V9I;&4G(#T^(')E86QP871H*"1D:7)?<')E9FEX
M*2`N($1)4D5#5$]265]315!!4D%43U(@+B`D9FEL92DI.PT*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*"1F85LG<F]L92==(#T]("=P:'`G("8F("1D:7)?<')E9FEX*2![#0H@
M("`@("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F-?87)R87DH)&QO9RP@87)R
M87DH,2P@(D%N86QY>FEN9R`D9FEL92(I*3L-"B`@("`@("`@("`@("`@("`D
M<W)C:6YF;R`]("1T:&ES+3Y?86YA;'EZ95-O=7)C94-O9&4H)&1I<E]P<F5F
M:7@@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)&9I;&4I.PT*("`@("`@("`@
M("`@("`@(&EF("@D<W)C:6YF;RD@>PT*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V)U:6QD4')O=FED97-!<G)A>2@D<W)C:6YF;RD[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M("1T:&ES+3Y?<&%C:V%G94YA;64@/2`D<&X@/2`D=&AI<RT^9V5T4&%C:V%G
M92@I.PT*("`@("`@("`D<&YL(#T@<W1R;&5N*"1P;BD[#0H@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=P<F]V:61E<R==*2D@>PT*
M("`@("`@("`@("`@9F]R96%C:"`H*&%R<F%Y*2`D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=P<F]V:61E<R==(&%S("1K97D@/3X@)'=H870I('L-"B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)'=H871;)V5X<&QI8VET)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("\O('-K:7`@8V]N9F]R;6%N8V4@8VAE8VMS(&EF
M('1H92!P<F]V:61E<R!E;G1R>2!I<PT*("`@("`@("`@("`@("`@("`@("`O
M+R!S<&5C:69I960@:6X@=&AE('!A8VMA9V4N>&UL(&9I;&4-"B`@("`@("`@
M("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@(&5X=')A8W0H)'=H870I.PT*("`@("`@("`@("`@("`@
M(&EF("@D='EP92`]/2`G8VQA<W,G*2![#0H@("`@("`@("`@("`@("`@("`@
M(&EF("@A<W1R;F-A<V5C;7`H)&YA;64L("1P;BP@)'!N;"DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&57
M87)N:6YG*%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?4$Y!345?4%)%1DE8
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I;&4G(#T^("1F
M:6QE+"`G='EP92<@/3X@)'1Y<&4L("=N86UE)R`]/B`D;F%M92P@)W!A8VMA
M9V4G(#T^("1P;BDI.PT*("`@("`@("`@("`@("`@('T@96QS96EF("@D='EP
M92`]/2`G9G5N8W1I;VXG*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AS
M=')S='(H)&YA;64L("<Z.B<I('Q\("%S=')N8V%S96-M<"@D;F%M92P@)'!N
M+"`D<&YL*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]V86QI9&%T95=A<FYI;F<H4$5!4E]004-+04=%1DE,15]%4E)/
M4E].3U]03D%-15]04D5&25@L#0H@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G9FEL92<@/3X@)&9I;&4L("=T>7!E)R`]/B`D='EP92P@)VYA;64G
M(#T^("1N86UE+"`G<&%C:V%G92<@/3X@)'!N*2D[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B`D=&AI<RT^7VES5F%L:60[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M1V5T('1H92!D969A=6QT('AM;"!G96YE<F%T;W(@;V)J96-T#0H@("`@("H-
M"B`@("`@*B!`<F5T=7)N(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8Q
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F=E=$1E9F%U;'1'96YE<F%T;W(H
M*0T*("`@('L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?4&%C
M:V%G949I;&5?1V5N97)A=&]R7W8Q)RDI('L-"B`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G4$5!4B]086-K86=E1FEL92]'96YE<F%T;W(O=C$N<&AP)SL-
M"B`@("`@("`@?0T*("`@("`@("`D82`]("9N97<@4$5!4E]086-K86=E1FEL
M95]'96YE<F%T;W)?=C$H)'1H:7,I.PT*("`@("`@("!R971U<FX@)&$[#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!C;VYT96YT<R!O9B!A
M(&9I;&4@;&ES=&5D('=I=&AI;B!T:&4@<&%C:V%G92YX;6P-"B`@("`@*B!`
M<&%R86T@<W1R:6YG#0H@("`@("H@0')E='5R;B!S=')I;F<-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!G971&:6QE0V]N=&5N=',H)&9I;&4I#0H@("`@>PT*
M("`@("`@("!I9B`H)'1H:7,M/E]A<F-H:79E1FEL92`]/2`D=&AI<RT^7W!A
M8VMA9V5&:6QE*2![("\O('5N<&%C:V5D#0H@("`@("`@("`@("`D9&ER(#T@
M9&ER;F%M92@D=&AI<RT^7W!A8VMA9V5&:6QE*3L-"B`@("`@("`@("`@("1F
M:6QE(#T@)&1I<B`N($1)4D5#5$]265]315!!4D%43U(@+B`D9FEL93L-"B`@
M("`@("`@("`@("1F:6QE(#T@<W1R7W)E<&QA8V4H87)R87DH)R\G+"`G7%PG
M*2P-"B`@("`@("`@("`@("`@("!A<G)A>2A$25)%0U1/4EE?4T5005)!5$]2
M+"!$25)%0U1/4EE?4T5005)!5$]2*2P@)&9I;&4I.PT*("`@("`@("`@("`@
M:68@*&9I;&5?97AI<W1S*"1F:6QE*2`F)B!I<U]R96%D86)L92@D9FEL92DI
M('L-"B`@("`@("`@("`@("`@("!R971U<FX@:6UP;&]D92@G)RP@9FEL92@D
M9FEL92DI.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>R`O+R!T
M9WH-"B`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=!<F-H:79E7U1A
M<B<I*2![#0H@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=!<F-H:79E
M+U1A<BYP:'`G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1A<B`]
M("9N97<@07)C:&EV95]487(H)'1H:7,M/E]A<F-H:79E1FEL92D[#0H@("`@
M("`@("`@("`D=&%R+3YP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%
M5%523BD[#0H@("`@("`@("`@("!I9B`H)&9I;&4@(3T@)W!A8VMA9V4N>&UL
M)R`F)B`D9FEL92`A/2`G<&%C:V%G93(N>&UL)RD@>PT*("`@("`@("`@("`@
M("`@("1F:6QE(#T@)'1H:7,M/F=E=%!A8VMA9V4H*2`N("<M)R`N("1T:&ES
M+3YG971697)S:6]N*"D@+B`G+R<@+B`D9FEL93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1F:6QE(#T@)'1A<BT^97AT<F%C=$EN4W1R:6YG*"1F
M:6QE*3L-"B`@("`@("`@("`@("1T87(M/G!O<$5R<F]R2&%N9&QI;F<H*3L-
M"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1F:6QE*2D@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#86YN;W0@
M;&]C871E(&9I;&4@)R1F:6QE)R!I;B!A<F-H:79E(BD[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!R971U<FX@)&9I;&4[#0H@("`@("`@('T-"B`@
M("!]#0H-"B`@("`O+R![>WL@86YA;'EZ95-O=7)C94-O9&4H*0T*("`@("\J
M*@T*("`@("`J($%N86QY>F4@=&AE('-O=7)C92!C;V1E(&]F('1H92!G:79E
M;B!02%`@9FEL90T*("`@("`J#0H@("`@("H@0'!A<F%M("!S=')I;F<@1FEL
M96YA;64@;V8@=&AE(%!(4"!F:6QE#0H@("`@("H@0')E='5R;B!M:7AE9`T*
M("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N
M(%]A;F%L>7IE4V]U<F-E0V]D92@D9FEL92D-"B`@("![#0H@("`@("`@(&EF
M("@A9G5N8W1I;VY?97AI<W1S*")T;VME;E]G971?86QL(BDI('L-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M(61E9FEN960H)U1?1$]#7T-/34U%3E0G*2D@>PT*("`@("`@("`@("`@9&5F
M:6YE*"=47T1/0U]#3TU-14Y4)RP@5%]#3TU-14Y4*3L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H(61E9FEN960H)U1?24Y415)&04-%)RDI('L-"B`@("`@
M("`@("`@(&1E9FEN92@G5%])3E1%4D9!0T4G+"`M,2D[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"%D969I;F5D*"=47TE-4$Q%345.5%,G*2D@>PT*("`@
M("`@("`@("`@9&5F:6YE*"=47TE-4$Q%345.5%,G+"`M,2D[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"$D9G`@/2!`9F]P96XH)&9I;&4L(")R(BDI('L-
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H9G5N8W1I;VY?97AI<W1S*"=F:6QE7V=E=%]C;VYT96YT<R<I*2![
M#0H@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@("`@("1C;VYT
M96YT<R`](&9I;&5?9V5T7V-O;G1E;G1S*"1F:6QE*3L-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("1C;VYT96YT<R`]($!F<F5A9"@D9G`L(&9I
M;&5S:7IE*"1F:6QE*2D[#0H@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@
M("`@("`@?0T*("`@("`@("`D=&]K96YS(#T@=&]K96Y?9V5T7V%L;"@D8V]N
M=&5N=',I.PT*+RH-"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F
M*"1T;VME;G,I.R`D:2LK*2![#0H@("`@("`@("`@("!`;&ES="@D=&]K96XL
M("1D871A*2`]("1T;VME;G-;)&E=.PT*("`@("`@("`@("`@:68@*&ES7W-T
M<FEN9R@D=&]K96XI*2![#0H@("`@("`@("`@("`@("`@=F%R7V1U;7`H)'1O
M:V5N*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M<')I;G0@=&]K96Y?;F%M92@D=&]K96XI("X@)R`G.PT*("`@("`@("`@("`@
M("`@('9A<E]D=6UP*')T<FEM*"1D871A*2D[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"BHO#0H@("`@("`@("1L;V]K7V9O<B`](#`[#0H@("`@("`@
M("1P87)E;E]L979E;"`](#`[#0H@("`@("`@("1B<F%C:V5T7VQE=F5L(#T@
M,#L-"B`@("`@("`@)&)R86-E7VQE=F5L(#T@,#L-"B`@("`@("`@)&QA<W1P
M:'!D;V,@/2`G)SL-"B`@("`@("`@)&-U<G)E;G1?8VQA<W,@/2`G)SL-"B`@
M("`@("`@)&-U<G)E;G1?:6YT97)F86-E(#T@)R<[#0H@("`@("`@("1C=7)R
M96YT7V-L87-S7VQE=F5L(#T@+3$[#0H@("`@("`@("1C=7)R96YT7V9U;F-T
M:6]N(#T@)R<[#0H@("`@("`@("1C=7)R96YT7V9U;F-T:6]N7VQE=F5L(#T@
M+3$[#0H@("`@("`@("1D96-L87)E9%]C;&%S<V5S(#T@87)R87DH*3L-"B`@
M("`@("`@)&1E8VQA<F5D7VEN=&5R9F%C97,@/2!A<G)A>2@I.PT*("`@("`@
M("`D9&5C;&%R961?9G5N8W1I;VYS(#T@87)R87DH*3L-"B`@("`@("`@)&1E
M8VQA<F5D7VUE=&AO9',@/2!A<G)A>2@I.PT*("`@("`@("`D=7-E9%]C;&%S
M<V5S(#T@87)R87DH*3L-"B`@("`@("`@)'5S961?9G5N8W1I;VYS(#T@87)R
M87DH*3L-"B`@("`@("`@)&5X=&5N9',@/2!A<G)A>2@I.PT*("`@("`@("`D
M:6UP;&5M96YT<R`](&%R<F%Y*"D[#0H@("`@("`@("1N;V1E<',@/2!A<G)A
M>2@I.PT*("`@("`@("`D:6YQ=6]T92`](&9A;'-E.PT*("`@("`@("`D:6YT
M97)F86-E(#T@9F%L<V4[#0H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I
M>F5O9B@D=&]K96YS*3L@)&DK*RD@>PT*("`@("`@("`@("`@:68@*&ES7V%R
M<F%Y*"1T;VME;G-;)&E=*2D@>PT*("`@("`@("`@("`@("`@(&QI<W0H)'1O
M:V5N+"`D9&%T82D@/2`D=&]K96YS6R1I73L-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@)'1O:V5N(#T@)'1O:V5N<ULD:5T[#0H@
M("`@("`@("`@("`@("`@)&1A=&$@/2`G)SL-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("@D:6YQ=6]T92D@>PT*("`@("`@("`@("`@("`@(&EF
M("@D=&]K96X@(3T@)R(G("8F("1T;VME;B`A/2!47T5.1%](15)%1$]#*2![
M#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1I;G%U;W1E(#T@
M9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@('-W:71C
M:"`H)'1O:V5N*2![#0H@("`@("`@("`@("`@("`@8V%S92!47U=(251%4U!!
M0T4@.@T*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@("`@("!C87-E("<[)SH-"B`@("`@("`@("`@("`@("`@("`@:68@*"1I
M;G1E<F9A8V4I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT
M7V9U;F-T:6]N(#T@)R<[#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R
M<F5N=%]F=6YC=&EO;E]L979E;"`]("TQ.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@
M("`@(&-A<V4@)R(G.@T*("`@("`@("`@("`@("`@(&-A<V4@5%]35$%25%](
M15)%1$]#.@T*("`@("`@("`@("`@("`@("`@("`D:6YQ=6]T92`]('1R=64[
M#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@
M(&-A<V4@5%]#55),65]/4$5..@T*("`@("`@("`@("`@("`@(&-A<V4@5%]$
M3TQ,05)?3U!%3E]#55),65]"4D%#15,Z#0H@("`@("`@("`@("`@("`@8V%S
M92`G>R<Z("1B<F%C95]L979E;"LK.R!C;VYT:6YU92`R.PT*("`@("`@("`@
M("`@("`@(&-A<V4@)WTG.@T*("`@("`@("`@("`@("`@("`@("`D8G)A8V5?
M;&5V96PM+3L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1C=7)R96YT7V-L
M87-S7VQE=F5L(#T]("1B<F%C95]L979E;"D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)&-U<G)E;G1?8VQA<W,@/2`G)SL-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1C=7)R96YT7V-L87-S7VQE=F5L(#T@+3$[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"1C=7)R
M96YT7V9U;F-T:6]N7VQE=F5L(#T]("1B<F%C95]L979E;"D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?9G5N8W1I;VX@/2`G)SL-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V9U;F-T:6]N7VQE=F5L
M(#T@+3$[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("!C87-E("=;)SH@
M)&)R86-K971?;&5V96PK*SL@8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@
M("!C87-E("==)SH@)&)R86-K971?;&5V96PM+3L@8V]N=&EN=64@,CL-"B`@
M("`@("`@("`@("`@("!C87-E("<H)SH@)'!A<F5N7VQE=F5L*RL[("`@8V]N
M=&EN=64@,CL-"B`@("`@("`@("`@("`@("!C87-E("<I)SH@)'!A<F5N7VQE
M=F5L+2T[("`@8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("!C87-E(%1?
M24Y415)&04-%.@T*("`@("`@("`@("`@("`@("`@("`D:6YT97)F86-E(#T@
M=')U93L-"B`@("`@("`@("`@("`@("!C87-E(%1?0TQ!4U,Z#0H@("`@("`@
M("`@("`@("`@("`@(&EF("@H)&-U<G)E;G1?8VQA<W-?;&5V96P@(3T@+3$I
M('Q\("@D8W5R<F5N=%]F=6YC=&EO;E]L979E;"`A/2`M,2DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%2
M7U!!0TM!1T5&24Q%7T524D]27TE.5D%,241?4$A01DE,12P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9FEL92<@/3X@)&9I;&4I*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&-A<V4@5%]&54Y#
M5$E/3CH-"B`@("`@("`@("`@("`@("!C87-E(%1?3D57.@T*("`@("`@("`@
M("`@("`@(&-A<V4@5%]%6%1%3D13.@T*("`@("`@("`@("`@("`@(&-A<V4@
M5%])35!,14U%3E13.@T*("`@("`@("`@("`@("`@("`@("`D;&]O:U]F;W(@
M/2`D=&]K96X[#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E(#([#0H@
M("`@("`@("`@("`@("`@8V%S92!47U-44DE.1SH-"B`@("`@("`@("`@("`@
M("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92AZ96YD7W9E<G-I;VXH*2P@)S(N
M,"<L("<\)RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI;E]A
M<G)A>2AS=')T;VQO=V5R*"1D871A*2P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@G<'5B;&EC)RP@)W!R:79A=&4G+"`G<')O=&5C=&5D
M)RP@)V%B<W1R86-T)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G:6YT97)F86-E)RP@)VEM<&QE;65N=',G+"`G=&AR;W<G*2`-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E5V%R;FEN9RA0
M14%27U!!0TM!1T5&24Q%7T524D]27U!(4#4L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"1F:6QE*2D[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1L;V]K7V9O<B`]/2!47T-,05-3*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]C;&%S<R`]("1D871A.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?8VQA<W-?;&5V96P@
M/2`D8G)A8V5?;&5V96P[#0H@("`@("`@("`@("`@("`@("`@("`@("`D9&5C
M;&%R961?8VQA<W-E<UM=(#T@)&-U<G)E;G1?8VQA<W,[#0H@("`@("`@("`@
M("`@("`@("`@('T@96QS96EF("@D;&]O:U]F;W(@/3T@5%])3E1%4D9!0T4I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7VEN=&5R9F%C
M92`]("1D871A.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?
M8VQA<W-?;&5V96P@/2`D8G)A8V5?;&5V96P[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D9&5C;&%R961?:6YT97)F86-E<UM=(#T@)&-U<G)E;G1?:6YT
M97)F86-E.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&QO;VM?
M9F]R(#T](%1?24U03$5-14Y44RD@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)&EM<&QE;65N='-;)&-U<G)E;G1?8VQA<W-=(#T@)&1A=&$[#0H@("`@
M("`@("`@("`@("`@("`@('T@96QS96EF("@D;&]O:U]F;W(@/3T@5%]%6%1%
M3D13*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D97AT96YD<ULD8W5R
M<F5N=%]C;&%S<UT@/2`D9&%T83L-"B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E:68@*"1L;V]K7V9O<B`]/2!47T953D-424].*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H)&-U<G)E;G1?8VQA<W,I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]F=6YC=&EO;B`]("(D8W5R
M<F5N=%]C;&%S<SHZ)&1A=&$B.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1D96-L87)E9%]M971H;V1S6R1C=7)R96YT7V-L87-S75M=(#T@)&1A
M=&$[#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&-U<G)E
M;G1?:6YT97)F86-E*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&-U<G)E;G1?9G5N8W1I;VX@/2`B)&-U<G)E;G1?:6YT97)F86-E.CHD9&%T
M82([#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E8VQA<F5D7VUE
M=&AO9'-;)&-U<G)E;G1?:6YT97)F86-E75M=(#T@)&1A=&$[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1C=7)R96YT7V9U;F-T:6]N(#T@)&1A=&$[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&1E8VQA<F5D7V9U;F-T:6]N<UM=(#T@
M)&-U<G)E;G1?9G5N8W1I;VX[#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]F=6YC=&EO;E]L
M979E;"`]("1B<F%C95]L979E;#L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1M(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*"1L;V]K7V9O<B`]/2!47TY%5RD@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)'5S961?8VQA<W-E<ULD9&%T85T@/2!T<G5E.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1L;V]K7V9O<B`](#`[
M#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@
M("`@("`@8V%S92!47U9!4DE!0DQ%.@T*("`@("`@("`@("`@("`@("`@("`D
M;&]O:U]F;W(@/2`P.PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU92`R
M.PT*("`@("`@("`@("`@("`@(&-A<V4@5%]$3T-?0T]-345.5#H-"B`@("`@
M("`@("`@("`@("!C87-E(%1?0T]-345.5#H-"B`@("`@("`@("`@("`@("`@
M("`@:68@*'!R96=?;6%T8V@H)R%>+UPJ7"I<<R$G+"`D9&%T82DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1L87-T<&AP9&]C(#T@)&1A=&$[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:%]A;&PH)R]`
M;F]D97!<<RLH7%,K*2\G+"`D;&%S='!H<&1O8RP@)&TI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&YO9&5P<R`](&%R<F%Y7VUE<F=E*"1N
M;V1E<',L("1M6S%=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU92`R.PT*("`@("`@("`@("`@("`@(&-A<V4@5%]$3U5"3$5?0T],3TXZ
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@A*"1T;VME;G-;)&D@+2`Q75LP
M72`]/2!47U=(251%4U!!0T4@?'P@)'1O:V5N<ULD:2`M(#%=6S!=(#T](%1?
M4U1224Y'*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V
M86QI9&%T945R<F]R*%!%05)?4$%#2T%'149)3$5?15)23U)?24Y604Q)1%]0
M2%!&24Q%+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=F
M:6QE)R`]/B`D9FEL92DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("1C;&%S<R`]("1T;VME;G-;)&D@+2`Q75LQ73L-"B`@("`@
M("`@("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H)&-L87-S*2`A/2`G<&%R
M96YT)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'5S961?8VQA<W-E
M<ULD8VQA<W-=(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("!C;VYT:6YU92`R.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(')E='5R;B!A<G)A>2@-"B`@("`@("`@("`@
M(")S;W5R8V5?9FEL92(@/3X@)&9I;&4L#0H@("`@("`@("`@("`B9&5C;&%R
M961?8VQA<W-E<R(@/3X@)&1E8VQA<F5D7V-L87-S97,L#0H@("`@("`@("`@
M("`B9&5C;&%R961?:6YT97)F86-E<R(@/3X@)&1E8VQA<F5D7VEN=&5R9F%C
M97,L#0H@("`@("`@("`@("`B9&5C;&%R961?;65T:&]D<R(@/3X@)&1E8VQA
M<F5D7VUE=&AO9',L#0H@("`@("`@("`@("`B9&5C;&%R961?9G5N8W1I;VYS
M(B`]/B`D9&5C;&%R961?9G5N8W1I;VYS+`T*("`@("`@("`@("`@(G5S961?
M8VQA<W-E<R(@/3X@87)R87E?9&EF9BAA<G)A>5]K97ES*"1U<V5D7V-L87-S
M97,I+"`D;F]D97!S*2P-"B`@("`@("`@("`@(")I;FAE<FET86YC92(@/3X@
M)&5X=&5N9',L#0H@("`@("`@("`@("`B:6UP;&5M96YT<R(@/3X@)&EM<&QE
M;65N=',L#0H@("`@("`@("`@("`I.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("`J($)U:6QD(&$@(G!R;W9I9&5S(B!A<G)A>2!F<F]M(&1A=&$@<F5T=7)N
M960@8GD-"B`@("`@*B!A;F%L>7IE4V]U<F-E0V]D92@I+B`@5&AE(&9O<FUA
M="!O9B!T:&4@8G5I;'0@87)R87D@:7,@;&EK90T*("`@("`J('1H:7,Z#0H@
M("`@("H-"B`@("`@*B`@87)R87DH#0H@("`@("H@("`@)V-L87-S.TUY0VQA
M<W,G(#T^("=A<G)A>2@G='EP92<@/3X@)V-L87-S)RP@)VYA;64G(#T^("=-
M>4-L87-S)RDL#0H@("`@("H@("`@+BXN#0H@("`@("H@("D-"B`@("`@*@T*
M("`@("`J#0H@("`@("H@0'!A<F%M(&%R<F%Y("1S<F-I;F9O(&%R<F%Y('=I
M=&@@:6YF;W)M871I;VX@86)O=70@82!S;W5R8V4@9FEL90T*("`@("`J(&%S
M(')E='5R;F5D(&)Y('1H92!A;F%L>7IE4V]U<F-E0V]D92@I(&UE=&AO9"X-
M"B`@("`@*@T*("`@("`J($!R971U<FX@=F]I9`T*("`@("`J#0H@("`@("H@
M0&%C8V5S<R!P<FEV871E#0H@("`@("H-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!?8G5I;&10<F]V:61E<T%R<F%Y*"1S<F-I;F9O*0T*("`@('L-"B`@("`@
M("`@:68@*"$D=&AI<RT^7VES5F%L:60I('L-"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D9FEL92`](&)A<V5N86UE
M*"1S<F-I;F9O6R=S;W5R8V5?9FEL92==*3L-"B`@("`@("`@)'!N(#T@)'1H
M:7,M/F=E=%!A8VMA9V4H*3L-"B`@("`@("`@)'!N;"`]('-T<FQE;B@D<&XI
M.PT*("`@("`@("!F;W)E86-H("@D<W)C:6YF;ULG9&5C;&%R961?8VQA<W-E
M<R==(&%S("1C;&%S<RD@>PT*("`@("`@("`@("`@)&ME>2`](")C;&%S<SLD
M8VQA<W,B.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)W!R;W9I9&5S)UU;)&ME>5TI*2![#0H@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^
M7W!A8VMA9V5);F9O6R=P<F]V:61E<R==6R1K97E=(#T-"B`@("`@("`@("`@
M("`@("!A<G)A>2@G9FEL92<]/B`D9FEL92P@)W1Y<&4G(#T^("=C;&%S<R<L
M("=N86UE)R`]/B`D8VQA<W,I.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1S
M<F-I;F9O6R=I;FAE<FET86YC92==6R1C;&%S<UTI*2![#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG<')O=FED97,G75LD:V5Y75LG
M97AT96YD<R==(#T-"B`@("`@("`@("`@("`@("`@("`@)'-R8VEN9F];)VEN
M:&5R:71A;F-E)UU;)&-L87-S73L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!F;W)E86-H("@D<W)C:6YF;ULG9&5C;&%R961?;65T:&]D
M<R==(&%S("1C;&%S<R`]/B`D;65T:&]D<RD@>PT*("`@("`@("`@("`@9F]R
M96%C:"`H)&UE=&AO9',@87,@)&UE=&AO9"D@>PT*("`@("`@("`@("`@("`@
M("1F=6YC=&EO;B`]("(D8VQA<W,Z.B1M971H;V0B.PT*("`@("`@("`@("`@
M("`@("1K97D@/2`B9G5N8W1I;VX[)&9U;F-T:6]N(CL-"B`@("`@("`@("`@
M("`@("!I9B`H)&UE=&AO9'LP?2`]/2`G7R<@?'P@(7-T<F-A<V5C;7`H)&UE
M=&AO9"P@)&-L87-S*2!\?`T*("`@("`@("`@("`@("`@("`@("!I<W-E="@D
M=&AI<RT^7W!A8VMA9V5);F9O6R=P<F]V:61E<R==6R1K97E=*2D@>PT*("`@
M("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG<')O=FED
M97,G75LD:V5Y72`]#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=F:6QE
M)ST^("1F:6QE+"`G='EP92<@/3X@)V9U;F-T:6]N)RP@)VYA;64G(#T^("1F
M=6YC=&EO;BD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"@T*("`@("`@
M("!F;W)E86-H("@D<W)C:6YF;ULG9&5C;&%R961?9G5N8W1I;VYS)UT@87,@
M)&9U;F-T:6]N*2![#0H@("`@("`@("`@("`D:V5Y(#T@(F9U;F-T:6]N.R1F
M=6YC=&EO;B([#0H@("`@("`@("`@("!I9B`H)&9U;F-T:6]N>S!](#T]("=?
M)R!\?"!I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=P<F]V:61E<R==6R1K
M97E=*2D@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@:68@*"%S=')S='(H)&9U;F-T:6]N+"`G.CHG
M*2`F)B!S=')N8V%S96-M<"@D9G5N8W1I;VXL("1P;BP@)'!N;"DI('L-"B`@
M("`@("`@("`@("`@("`D=V%R;FEN9W-;72`](")I;C$@(B`N("1F:6QE("X@
M(CH@9G5N8W1I;VX@7"(D9G5N8W1I;VY<(B!N;W0@<')E9FEX960@=VET:"!P
M86-K86=E(&YA;64@7"(D<&Y<(B([#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=P<F]V:61E<R==6R1K97E=(#T-
M"B`@("`@("`@("`@("`@("!A<G)A>2@G9FEL92<]/B`D9FEL92P@)W1Y<&4G
M(#T^("=F=6YC=&EO;B<L("=N86UE)R`]/B`D9G5N8W1I;VXI.PT*("`@("`@
M("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0I]#0H_/@T*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2
M+U!A8VMA9V5&:6QE+W8R+P``````````````````````````````````````
M```````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#4Q-30S,S<T,``P,C(P,3(`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+U!%05(O4&%C:V%G949I;&4O=C(O<G<N<&AP````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,38W-#$T`#$P-3$U-#,S-S0P`#`R,S$W
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`T*+RHJ#0H@*B!014%27U!A8VMA9V5&:6QE7W8R+"!P86-K86=E+GAM
M;"!V97)S:6]N(#(N,"P@<F5A9"]W<FET92!V97)S:6]N#0H@*@T*("H@4$A0
M('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L
M:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L
M9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R
M96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@
M=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*
M("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y
M("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@
M1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(')W+G!H<"QV(#$N,34@,C`P
M-B\P,2\R."`Q-SHS-3HQ,2!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@
M("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83@-"B`J
M+PT*+RHJ#0H@*B!&;W(@8F%S92!C;&%S<PT*("HO#0IR97%U:7)E7V]N8V4@
M)U!%05(O4&%C:V%G949I;&4O=C(N<&AP)SL-"B\J*@T*("H@0&-A=&5G;W)Y
M("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@
M1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN
M8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$X
M#0H@*B\-"F-L87-S(%!%05)?4&%C:V%G949I;&5?=C)?<G<@97AT96YD<R!0
M14%27U!A8VMA9V5&:6QE7W8R#0I[#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M
M('-T<FEN9R!%>'1E;G-I;VX@;F%M90T*("`@("`J($!R971U<FX@8F]O;"!S
M=6-C97-S(&]F(&]P97)A=&EO;@T*("`@("`J+PT*("`@(&9U;F-T:6]N('-E
M=%!R;W9I9&5S17AT96YS:6]N*"1E>'1E;G-I;VXI#0H@("`@>PT*("`@("`@
M("!I9B`H:6Y?87)R87DH)'1H:7,M/F=E=%!A8VMA9V54>7!E*"DL(&%R<F%Y
M*"=E>'1S<F,G+"`G97AT8FEN)RDI*2![#0H@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W!R;W9I9&5S97AT96YS:6]N)UTI
M*2![#0H@("`@("`@("`@("`@("`@+R\@96YS=7)E('1H870@=&AE(&-H86YN
M96P@=&%G(&ES('-E="!U<"!I;B!T:&4@<FEG:'0@;&]C871I;VX-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]I;G-E
M<G1"969O<F4H)'1H:7,M/E]P86-K86=E26YF;RP-"B`@("`@("`@("`@("`@
M("`@("`@87)R87DH)W5S97-R;VQE)RP@)W5S97-T87-K)RP@)W-R8W!A8VMA
M9V4G+"`G<W)C=7)I)RP@)W!H<')E;&5A<V4G+`T*("`@("`@("`@("`@("`@
M("`@("`G97AT<W)C<F5L96%S92<L("=E>'1B:6YR96QE87-E)RP@)V)U;F1L
M92<L("=C:&%N9V5L;V<G*2P-"B`@("`@("`@("`@("`@("`@("`@)&5X=&5N
M<VEO;BP@)W!R;W9I9&5S97AT96YS:6]N)RD[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=P<F]V:61E<V5X=&5N
M<VEO;B==(#T@)&5X=&5N<VEO;CL-"B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!S971086-K86=E*"1P86-K86=E*0T*("`@('L-"B`@
M("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7W!A8VMA9V5);F9O6R=A='1R:6)S)UTI*2![#0H@("`@("`@
M("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@87)R87E?;65R9V4H87)R87DH
M)V%T=')I8G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W9E<G-I;VXG(#T^("<R+C`G+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)WAM;&YS)R`]/B`G:'1T<#HO+W!E87(N<&AP
M+FYE="]D=&0O<&%C:V%G92TR+C`G+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)WAM;&YS.G1A<VMS)R`]/B`G:'1T<#HO+W!E87(N<&AP
M+FYE="]D=&0O=&%S:W,M,2XP)RP-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=X;6QN<SIX<VDG(#T^("=H='1P.B\O=W=W+G<S+F]R9R\R
M,#`Q+UA-3%-C:&5M82UI;G-T86YC92<L#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G>'-I.G-C:&5M84QO8V%T:6]N)R`]/B`G:'1T<#HO
M+W!E87(N<&AP+FYE="]D=&0O=&%S:W,M,2XP#0H@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]D=&0O=&%S:W,M,2XP+GAS9`T*("`@(&AT='`Z+R]P96%R+G!H
M<"YN970O9'1D+W!A8VMA9V4M,BXP#0H@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]D=&0O<&%C:V%G92TR+C`N>'-D)RP-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@*2DL("1T:&ES+3Y?<&%C:V%G94EN9F\I.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG;F%M
M92==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN
M9F\@/2!A<G)A>5]M97)G92AA<G)A>2@G;F%M92<@/3X@)'!A8VMA9V4I+`T*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\I.PT*("`@("`@
M("!]#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)VYA;64G72`]("1P
M86-K86=E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=%5R:2@D=7)I*0T*
M("`@('L-"B`@("`@("`@=6YS970H)'1H:7,M/E]P86-K86=E26YF;ULG8VAA
M;FYE;"==*3L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=U<FDG72DI('L-
M"B`@("`@("`@("`@("\O(&5N<W5R92!T:&%T('1H92!U<FD@=&%G(&ES('-E
M="!U<"!I;B!T:&4@<FEG:'0@;&]C871I;VX-"B`@("`@("`@("`@("1T:&ES
M+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^7VEN<V5R=$)E9F]R92@D=&AI<RT^
M7W!A8VMA9V5);F9O+"`-"B`@("`@("`@("`@("`@("!A<G)A>2@G97AT96YD
M<R<L("=S=6UM87)Y)RP@)V1E<V-R:7!T:6]N)RP@)VQE860G+`T*("`@("`@
M("`@("`@("`@("=D979E;&]P97(G+"`G8V]N=')I8G5T;W(G+"`G:&5L<&5R
M)RP@)V1A=&4G+"`G=&EM92<L("=V97)S:6]N)RP-"B`@("`@("`@("`@("`@
M("`G<W1A8FEL:71Y)RP@)VQI8V5N<V4G+"`G;F]T97,G+"`G8V]N=&5N=',G
M+"`G8V]M<&%T:6)L92<L#0H@("`@("`@("`@("`@("`@)V1E<&5N9&5N8VEE
M<R<L("=P<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L("=U<V5S=&%S
M:R<L("=S<F-P86-K86=E)RP@)W-R8W5R:2<L#0H@("`@("`@("`@("`@("`@
M)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L#0H@("`@("`@("`@("`@
M("`@)V5X=&)I;G)E;&5A<V4G+"`G8G5N9&QE)RP@)V-H86YG96QO9R<I+"`D
M=7)I+"`G=7)I)RD[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]P86-K
M86=E26YF;ULG=7)I)UT@/2`D=7)I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N
M('-E=$-H86YN96PH)&-H86YN96PI#0H@("`@>PT*("`@("`@("!U;G-E="@D
M=&AI<RT^7W!A8VMA9V5);F9O6R=U<FDG72D[#0H@("`@("`@("1T:&ES+3Y?
M:7-686QI9"`](#`[#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K
M86=E26YF;ULG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@+R\@96YS=7)E
M('1H870@=&AE(&-H86YN96P@=&%G(&ES('-E="!U<"!I;B!T:&4@<FEG:'0@
M;&]C871I;VX-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D
M=&AI<RT^7VEN<V5R=$)E9F]R92@D=&AI<RT^7W!A8VMA9V5);F9O+`T*("`@
M("`@("`@("`@("`@(&%R<F%Y*"=E>'1E;F1S)RP@)W-U;6UA<GDG+"`G9&5S
M8W)I<'1I;VXG+"`G;&5A9"<L#0H@("`@("`@("`@("`@("`@)V1E=F5L;W!E
M<B<L("=C;VYT<FEB=71O<B<L("=H96QP97(G+"`G9&%T92<L("=T:6UE)RP@
M)W9E<G-I;VXG+`T*("`@("`@("`@("`@("`@("=S=&%B:6QI='DG+"`G;&EC
M96YS92<L("=N;W1E<R<L("=C;VYT96YT<R<L("=C;VUP871I8FQE)RP-"B`@
M("`@("`@("`@("`@("`G9&5P96YD96YC:65S)RP@)W!R;W9I9&5S97AT96YS
M:6]N)RP@)W5S97-R;VQE)RP@)W5S97-T87-K)RP@)W-R8W!A8VMA9V4G+"`G
M<W)C=7)I)RP-"B`@("`@("`@("`@("`@("`G<&AP<F5L96%S92<L("=E>'1S
M<F-R96QE87-E)RP-"B`@("`@("`@("`@("`@("`G97AT8FEN<F5L96%S92<L
M("=B=6YD;&4G+"`G8VAA;F=E;&]G)RDL("1C:&%N;F5L+"`G8VAA;FYE;"<I
M.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V-H
M86YN96PG72`]("1C:&%N;F5L.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E
M=$5X=&5N9',H)&5X=&5N9',I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7VES
M5F%L:60@/2`P.PT*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)V5X=&5N9',G72DI('L-"B`@("`@("`@("`@("\O(&5N<W5R92!T
M:&%T('1H92!E>'1E;F1S('1A9R!I<R!S970@=7`@:6X@=&AE(')I9VAT(&QO
M8V%T:6]N#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H
M:7,M/E]I;G-E<G1"969O<F4H)'1H:7,M/E]P86-K86=E26YF;RP-"B`@("`@
M("`@("`@("`@("!A<G)A>2@G<W5M;6%R>2<L("=D97-C<FEP=&EO;B<L("=L
M96%D)RP-"B`@("`@("`@("`@("`@("`G9&5V96QO<&5R)RP@)V-O;G1R:6)U
M=&]R)RP@)VAE;'!E<B<L("=D871E)RP@)W1I;64G+"`G=F5R<VEO;B<L#0H@
M("`@("`@("`@("`@("`@)W-T86)I;&ET>2<L("=L:6-E;G-E)RP@)VYO=&5S
M)RP@)V-O;G1E;G1S)RP@)V-O;7!A=&EB;&4G+`T*("`@("`@("`@("`@("`@
M("=D97!E;F1E;F-I97,G+"`G<')O=FED97-E>'1E;G-I;VXG+"`G=7-E<W)O
M;&4G+"`G=7-E<W1A<VLG+"`G<W)C<&%C:V%G92<L("=S<F-U<FDG+`T*("`@
M("`@("`@("`@("`@("=P:'!R96QE87-E)RP@)V5X='-R8W)E;&5A<V4G+`T*
M("`@("`@("`@("`@("`@("=E>'1B:6YR96QE87-E)RP@)V)U;F1L92<L("=C
M:&%N9V5L;V<G*2P@)&5X=&5N9',L("=E>'1E;F1S)RD[#0H@("`@("`@('T-
M"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG97AT96YD<R==(#T@)&5X
M=&5N9',[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T4W5M;6%R>2@D<W5M
M;6%R>2D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<W5M;6%R
M>2==*2D@>PT*("`@("`@("`@("`@+R\@96YS=7)E('1H870@=&AE('-U;6UA
M<GD@=&%G(&ES('-E="!U<"!I;B!T:&4@<FEG:'0@;&]C871I;VX-"B`@("`@
M("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^7VEN<V5R=$)E
M9F]R92@D=&AI<RT^7W!A8VMA9V5);F9O+`T*("`@("`@("`@("`@("`@(&%R
M<F%Y*"=D97-C<FEP=&EO;B<L("=L96%D)RP-"B`@("`@("`@("`@("`@("`G
M9&5V96QO<&5R)RP@)V-O;G1R:6)U=&]R)RP@)VAE;'!E<B<L("=D871E)RP@
M)W1I;64G+"`G=F5R<VEO;B<L#0H@("`@("`@("`@("`@("`@)W-T86)I;&ET
M>2<L("=L:6-E;G-E)RP@)VYO=&5S)RP@)V-O;G1E;G1S)RP@)V-O;7!A=&EB
M;&4G+`T*("`@("`@("`@("`@("`@("=D97!E;F1E;F-I97,G+"`G<')O=FED
M97-E>'1E;G-I;VXG+"`G=7-E<W)O;&4G+"`G=7-E<W1A<VLG+"`G<W)C<&%C
M:V%G92<L("=S<F-U<FDG+`T*("`@("`@("`@("`@("`@("=P:'!R96QE87-E
M)RP@)V5X='-R8W)E;&5A<V4G+`T*("`@("`@("`@("`@("`@("=E>'1B:6YR
M96QE87-E)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P@)'-U;6UA<GDL("=S
M=6UM87)Y)RD[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]P86-K86=E
M26YF;ULG<W5M;6%R>2==(#T@)'-U;6UA<GD[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@<V5T1&5S8W)I<'1I;VXH)&1E<V,I#0H@("`@>PT*("`@("`@("`D
M=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)V1E<V-R:7!T:6]N)UTI*2![#0H@("`@("`@("`@
M("`O+R!E;G-U<F4@=&AA="!T:&4@9&5S8W)I<'1I;VX@=&%G(&ES('-E="!U
M<"!I;B!T:&4@<FEG:'0@;&]C871I;VX-"B`@("`@("`@("`@("1T:&ES+3Y?
M<&%C:V%G94EN9F\@/2`D=&AI<RT^7VEN<V5R=$)E9F]R92@D=&AI<RT^7W!A
M8VMA9V5);F9O+`T*("`@("`@("`@("`@("`@(&%R<F%Y*"=L96%D)RP-"B`@
M("`@("`@("`@("`@("`G9&5V96QO<&5R)RP@)V-O;G1R:6)U=&]R)RP@)VAE
M;'!E<B<L("=D871E)RP@)W1I;64G+"`G=F5R<VEO;B<L#0H@("`@("`@("`@
M("`@("`@)W-T86)I;&ET>2<L("=L:6-E;G-E)RP@)VYO=&5S)RP@)V-O;G1E
M;G1S)RP@)V-O;7!A=&EB;&4G+`T*("`@("`@("`@("`@("`@("=D97!E;F1E
M;F-I97,G+"`G<')O=FED97-E>'1E;G-I;VXG+"`G=7-E<W)O;&4G+"`G=7-E
M<W1A<VLG+"`G<W)C<&%C:V%G92<L("=S<F-U<FDG+`T*("`@("`@("`@("`@
M("`@("=P:'!R96QE87-E)RP@)V5X='-R8W)E;&5A<V4G+`T*("`@("`@("`@
M("`@("`@("=E>'1B:6YR96QE87-E)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G
M*2P@)&1E<V,L("=D97-C<FEP=&EO;B<I.PT*("`@("`@("!]#0H@("`@("`@
M("1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<V-R:7!T:6]N)UT@/2`D9&5S8SL-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!!9&1S(&$@;F5W(&UA:6YT86EN
M97(@+2!N;R!C:&5C:VEN9R!O9B!D=7!L:6-A=&5S(&ES('!E<F9O<FUE9"P@
M=7-E#0H@("`@("H@=7!D871E;6%I;G1A:6YE<B!F;W(@=&AA="!P=7)P;W-E
M+@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$UA:6YT86EN97(H)')O;&4L
M("1H86YD;&4L("1N86UE+"`D96UA:6PL("1A8W1I=F4@/2`G>65S)RD-"B`@
M("![#0H@("`@("`@(&EF("@A:6Y?87)R87DH)')O;&4L(&%R<F%Y*"=L96%D
M)RP@)V1E=F5L;W!E<B<L("=C;VYT<FEB=71O<B<L("=H96QP97(G*2DI('L-
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULD<F]L95TI*2![#0H@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)')O
M;&5=6S!=*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN
M9F];)')O;&5=(#T@87)R87DH)'1H:7,M/E]P86-K86=E26YF;ULD<F]L95TI
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E
M26YF;ULD<F]L95U;72`]#0H@("`@("`@("`@("`@("`@87)R87DH#0H@("`@
M("`@("`@("`@("`@("`@("=N86UE)R`]/B`D;F%M92P-"B`@("`@("`@("`@
M("`@("`@("`@)W5S97(G(#T^("1H86YD;&4L#0H@("`@("`@("`@("`@("`@
M("`@("=E;6%I;"<@/3X@)&5M86EL+`T*("`@("`@("`@("`@("`@("`@("`G
M86-T:79E)R`]/B`D86-T:79E+`T*("`@("`@("`@("`@("`@("D[#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`D=&5S=&%R<B`](&%R<F%Y*"=L
M96%D)RP-"B`@("`@("`@("`@("`@("`@("`@)V1E=F5L;W!E<B<L("=C;VYT
M<FEB=71O<B<L("=H96QP97(G+"`G9&%T92<L("=T:6UE)RP@)W9E<G-I;VXG
M+`T*("`@("`@("`@("`@("`@("`@("`G<W1A8FEL:71Y)RP@)VQI8V5N<V4G
M+"`G;F]T97,G+"`G8V]N=&5N=',G+"`G8V]M<&%T:6)L92<L#0H@("`@("`@
M("`@("`@("`@("`@("=D97!E;F1E;F-I97,G+"`G<')O=FED97-E>'1E;G-I
M;VXG+"`G=7-E<W)O;&4G+"`G=7-E<W1A<VLG+`T*("`@("`@("`@("`@("`@
M("`@("`G<W)C<&%C:V%G92<L("=S<F-U<FDG+"`G<&AP<F5L96%S92<L("=E
M>'1S<F-R96QE87-E)RP-"B`@("`@("`@("`@("`@("`@("`@)V5X=&)I;G)E
M;&5A<V4G+"`G8G5N9&QE)RP@)V-H86YG96QO9R<I.PT*("`@("`@("`@("`@
M9F]R96%C:"`H87)R87DH)VQE860G+"`G9&5V96QO<&5R)RP@)V-O;G1R:6)U
M=&]R)RP@)VAE;'!E<B<I(&%S("1T97-T<F]L92D@>PT*("`@("`@("`@("`@
M("`@(&%R<F%Y7W-H:69T*"1T97-T87)R*3L-"B`@("`@("`@("`@("`@("!I
M9B`H)')O;&4@/3T@)'1E<W1R;VQE*2![#0H@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULD<F]L
M95TI*2![#0H@("`@("`@("`@("`@("`@+R\@96YS=7)E('1H870@=&AE(&5X
M=&5N9',@=&%G(&ES('-E="!U<"!I;B!T:&4@<FEG:'0@;&]C871I;VX-"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]I
M;G-E<G1"969O<F4H)'1H:7,M/E]P86-K86=E26YF;RP@)'1E<W1A<G(L#0H@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"DL("1R;VQE*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)')O;&5=
M(#T-"B`@("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@
M("`@)VYA;64G(#T^("1N86UE+`T*("`@("`@("`@("`@("`@("`@("`G=7-E
M<B<@/3X@)&AA;F1L92P-"B`@("`@("`@("`@("`@("`@("`@)V5M86EL)R`]
M/B`D96UA:6PL#0H@("`@("`@("`@("`@("`@("`@("=A8W1I=F4G(#T^("1A
M8W1I=F4L#0H@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@?0T*("`@("`@
M("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@('T-"@T*("`@(&9U;F-T:6]N
M('5P9&%T94UA:6YT86EN97(H)&YE=W)O;&4L("1H86YD;&4L("1N86UE+"`D
M96UA:6PL("1A8W1I=F4@/2`G>65S)RD-"B`@("![#0H@("`@("`@("1F;W5N
M9"`](&9A;'-E.PT*("`@("`@("!F;W)E86-H("AA<G)A>2@G;&5A9"<L("=D
M979E;&]P97(G+"`G8V]N=')I8G5T;W(G+"`G:&5L<&5R)RD@87,@)')O;&4I
M('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF
M;ULD<F]L95TI*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D:6YF;R`]("1T:&ES+3Y?<&%C:V%G
M94EN9F];)')O;&5=.PT*("`@("`@("`@("`@:68@*"%I<W-E="@D:6YF;ULP
M72DI('L-"B`@("`@("`@("`@("`@("!I9B`H)&EN9F];)W5S97(G72`]/2`D
M:&%N9&QE*2![#0H@("`@("`@("`@("`@("`@("`@("1F;W5N9"`]('1R=64[
M#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O
M(&%S("1I(#T^("1M86EN=&%I;F5R*2![#0H@("`@("`@("`@("`@("`@:68@
M*"1M86EN=&%I;F5R6R=U<V5R)UT@/3T@)&AA;F1L92D@>PT*("`@("`@("`@
M("`@("`@("`@("`D9F]U;F0@/2`D:3L-"B`@("`@("`@("`@("`@("`@("`@
M8G)E86L@,CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"1F;W5N9"`]/3T@9F%L<V4I('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^861D36%I;G1A:6YE<B@D;F5W<F]L
M92P@)&AA;F1L92P@)&YA;64L("1E;6%I;"P@)&%C=&EV92D[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"1F;W5N9"`A/3T@9F%L<V4I('L-"B`@("`@("`@
M("`@(&EF("@D9F]U;F0@/3T]('1R=64I('L-"B`@("`@("`@("`@("`@("!U
M;G-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R1R;VQE72D[#0H@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)')O;&5=6R1F;W5N9%TI.PT*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%C:V%G94EN9F];)')O;&5=(#T@87)R87E?=F%L=65S*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)')O;&5=*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("`D=&AI<RT^861D36%I;G1A:6YE<B@D;F5W<F]L92P@
M)&AA;F1L92P@)&YA;64L("1E;6%I;"P@)&%C=&EV92D[#0H@("`@("`@("1T
M:&ES+3Y?:7-686QI9"`](#`[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9&5L
M971E36%I;G1A:6YE<B@D:&%N9&QE*0T*("`@('L-"B`@("`@("`@)&9O=6YD
M(#T@9F%L<V4[#0H@("`@("`@(&9O<F5A8V@@*&%R<F%Y*"=L96%D)RP@)V1E
M=F5L;W!E<B<L("=C;VYT<FEB=71O<B<L("=H96QP97(G*2!A<R`D<F]L92D@
M>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O
M6R1R;VQE72DI('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K
M86=E26YF;ULD<F]L95U;,%TI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P86-K86=E26YF;ULD<F]L95T@/2!A<G)A>2@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R1R;VQE72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E
M86-H("@D=&AI<RT^7W!A8VMA9V5);F9O6R1R;VQE72!A<R`D:2`]/B`D;6%I
M;G1A:6YE<BD@>PT*("`@("`@("`@("`@("`@(&EF("@D;6%I;G1A:6YE<ELG
M=7-E<B==(#T]("1H86YD;&4I('L-"B`@("`@("`@("`@("`@("`@("`@)&9O
M=6YD(#T@)&D[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D
M9F]U;F0@(3T](&9A;'-E*2![#0H@("`@("`@("`@("`@("`@=6YS970H)'1H
M:7,M/E]P86-K86=E26YF;ULD<F]L95U;)&9O=6YD72D[#0H@("`@("`@("`@
M("`@("`@:68@*"%C;W5N="@D=&AI<RT^7W!A8VMA9V5);F9O6R1R;VQE72D@
M)B8@)')O;&4@/3T@)VQE860G*2![#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&EF("@A8V]U;G0H)'1H:7,M/E]P86-K86=E26YF;ULD<F]L
M95TI*2![#0H@("`@("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)')O;&5=*3L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M('1R=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%C:V%G94EN9F];)')O;&5=(#T-"B`@("`@("`@("`@("`@("`@
M("`@87)R87E?=F%L=65S*"1T:&ES+3Y?<&%C:V%G94EN9F];)')O;&5=*3L-
M"B`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]P86-K86=E26YF
M;ULD<F]L95TI(#T](#$I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P86-K86=E26YF;ULD<F]L95T@/2`D=&AI<RT^7W!A8VMA9V5);F9O6R1R
M;VQE75LP73L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M8V]U;G0H)'1H:7,M/E]P86-K86=E26YF;ULD<F]L95TI(#T](#$I('L-"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R1R;VQE72`]("1T
M:&ES+3Y?<&%C:V%G94EN9F];)')O;&5=6S!=.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!S971296QE87-E5F5R<VEO;B@D=F5R<VEO;BD-"B`@("![
M#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=V97)S
M:6]N)UTI("8F#0H@("`@("`@("`@("`@(&ES<V5T*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)W9E<G-I;VXG75LG<F5L96%S92==*2D@>PT*("`@("`@("`@("`@
M=6YS970H)'1H:7,M/E]P86-K86=E26YF;ULG=F5R<VEO;B==6R=R96QE87-E
M)UTI.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@
M/2`D=&AI<RT^7VUE<F=E5&%G*"1T:&ES+3Y?<&%C:V%G94EN9F\L("1V97)S
M:6]N+"!A<G)A>2@-"B`@("`@("`@("`@("=V97)S:6]N)R`]/B!A<G)A>2@G
M<W1A8FEL:71Y)RP@)VQI8V5N<V4G+"`G;F]T97,G+"`G8V]N=&5N=',G+"`G
M8V]M<&%T:6)L92<L#0H@("`@("`@("`@("`@("`@)V1E<&5N9&5N8VEE<R<L
M("=P<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L("=U<V5S=&%S:R<L
M("=S<F-P86-K86=E)RP@)W-R8W5R:2<L#0H@("`@("`@("`@("`@("`@)W!H
M<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L#0H@("`@("`@("`@("`@("`@
M)V5X=&)I;G)E;&5A<V4G+"`G8G5N9&QE)RP@)V-H86YG96QO9R<I+`T*("`@
M("`@("`@("`@)W)E;&5A<V4G(#T^(&%R<F%Y*"=A<&DG*2DI.PT*("`@("`@
M("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@('T-"@T*("`@(&9U;F-T:6]N
M('-E=$%0259E<G-I;VXH)'9E<G-I;VXI#0H@("`@>PT*("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG=F5R<VEO;B==*2`F)@T*("`@
M("`@("`@("`@("!I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=V97)S:6]N
M)UU;)V%P:2==*2D@>PT*("`@("`@("`@("`@=6YS970H)'1H:7,M/E]P86-K
M86=E26YF;ULG=F5R<VEO;B==6R=A<&DG72D[#0H@("`@("`@('T-"B`@("`@
M("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?;65R9V5486<H)'1H
M:7,M/E]P86-K86=E26YF;RP@)'9E<G-I;VXL(&%R<F%Y*`T*("`@("`@("`@
M("`@)W9E<G-I;VXG(#T^(&%R<F%Y*"=S=&%B:6QI='DG+"`G;&EC96YS92<L
M("=N;W1E<R<L("=C;VYT96YT<R<L("=C;VUP871I8FQE)RP-"B`@("`@("`@
M("`@("`@("`G9&5P96YD96YC:65S)RP@)W!R;W9I9&5S97AT96YS:6]N)RP@
M)W5S97-R;VQE)RP@)W5S97-T87-K)RP@)W-R8W!A8VMA9V4G+"`G<W)C=7)I
M)RP-"B`@("`@("`@("`@("`@("`G<&AP<F5L96%S92<L("=E>'1S<F-R96QE
M87-E)RP-"B`@("`@("`@("`@("`@("`G97AT8FEN<F5L96%S92<L("=B=6YD
M;&4G+"`G8VAA;F=E;&]G)RDL#0H@("`@("`@("`@("`G87!I)R`]/B!A<G)A
M>2@I*2D[#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@?0T*
M#0H@("`@+RHJ#0H@("`@("H@<VYA<'-H;W1\9&5V96Q\86QP:&%\8F5T87QS
M=&%B;&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971296QE87-E4W1A8FEL
M:71Y*"1S=&%T92D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7W!A8VMA9V5);F9O6R=S=&%B:6QI='DG72D@)B8-"B`@("`@("`@("`@("`@
M:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<W1A8FEL:71Y)UU;)W)E;&5A
M<V4G72DI('L-"B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)W-T86)I;&ET>2==6R=R96QE87-E)UTI.PT*("`@("`@("!]#0H@("`@
M("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^7VUE<F=E5&%G*"1T
M:&ES+3Y?<&%C:V%G94EN9F\L("1S=&%T92P@87)R87DH#0H@("`@("`@("`@
M("`G<W1A8FEL:71Y)R`]/B!A<G)A>2@G;&EC96YS92<L("=N;W1E<R<L("=C
M;VYT96YT<R<L("=C;VUP871I8FQE)RP-"B`@("`@("`@("`@("`@("`G9&5P
M96YD96YC:65S)RP@)W!R;W9I9&5S97AT96YS:6]N)RP@)W5S97-R;VQE)RP@
M)W5S97-T87-K)RP@)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP-"B`@("`@("`@
M("`@("`@("`G<&AP<F5L96%S92<L("=E>'1S<F-R96QE87-E)RP-"B`@("`@
M("`@("`@("`@("`G97AT8FEN<F5L96%S92<L("=B=6YD;&4G+"`G8VAA;F=E
M;&]G)RDL#0H@("`@("`@("`@("`G<F5L96%S92<@/3X@87)R87DH)V%P:2<I
M*2D[#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@0'!A<F%M(&1E=F5L?&%L<&AA?&)E=&%\<W1A8FQE
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T05!)4W1A8FEL:71Y*"1S=&%T
M92D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=S=&%B:6QI='DG72D@)B8-"B`@("`@("`@("`@("`@:7-S970H)'1H
M:7,M/E]P86-K86=E26YF;ULG<W1A8FEL:71Y)UU;)V%P:2==*2D@>PT*("`@
M("`@("`@("`@=6YS970H)'1H:7,M/E]P86-K86=E26YF;ULG<W1A8FEL:71Y
M)UU;)V%P:2==*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W!A8VMA
M9V5);F9O(#T@)'1H:7,M/E]M97)G951A9R@D=&AI<RT^7W!A8VMA9V5);F9O
M+"`D<W1A=&4L(&%R<F%Y*`T*("`@("`@("`@("`@)W-T86)I;&ET>2<@/3X@
M87)R87DH)VQI8V5N<V4G+"`G;F]T97,G+"`G8V]N=&5N=',G+"`G8V]M<&%T
M:6)L92<L#0H@("`@("`@("`@("`@("`@)V1E<&5N9&5N8VEE<R<L("=P<F]V
M:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L("=U<V5S=&%S:R<L("=S<F-P
M86-K86=E)RP@)W-R8W5R:2<L#0H@("`@("`@("`@("`@("`@)W!H<')E;&5A
M<V4G+"`G97AT<W)C<F5L96%S92<L#0H@("`@("`@("`@("`@("`@)V5X=&)I
M;G)E;&5A<V4G+"`G8G5N9&QE)RP@)V-H86YG96QO9R<I+`T*("`@("`@("`@
M("`@)V%P:2<@/3X@87)R87DH*2DI.PT*("`@("`@("`D=&AI<RT^7VES5F%L
M:60@/2`P.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=$QI8V5N<V4H)&QI
M8V5N<V4L("1U<FD@/2!F86QS92P@)&9I;&5S;W5R8V4@/2!F86QS92D-"B`@
M("![#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG
M;&EC96YS92==*2D@>PT*("`@("`@("`@("`@+R\@96YS=7)E('1H870@=&AE
M(&QI8V5N<V4@=&%G(&ES('-E="!U<"!I;B!T:&4@<FEG:'0@;&]C871I;VX-
M"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^7VEN
M<V5R=$)E9F]R92@D=&AI<RT^7W!A8VMA9V5);F9O+`T*("`@("`@("`@("`@
M("`@(&%R<F%Y*"=N;W1E<R<L("=C;VYT96YT<R<L("=C;VUP871I8FQE)RP-
M"B`@("`@("`@("`@("`@("`G9&5P96YD96YC:65S)RP@)W!R;W9I9&5S97AT
M96YS:6]N)RP@)W5S97-R;VQE)RP@)W5S97-T87-K)RP@)W-R8W!A8VMA9V4G
M+"`G<W)C=7)I)RP-"B`@("`@("`@("`@("`@("`G<&AP<F5L96%S92<L("=E
M>'1S<F-R96QE87-E)RP-"B`@("`@("`@("`@("`@("`G97AT8FEN<F5L96%S
M92<L("=B=6YD;&4G+"`G8VAA;F=E;&]G)RDL(#`L("=L:6-E;G-E)RD[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"1U<FD@?'P@)&9I;&5S;W5R8V4I('L-
M"B`@("`@("`@("`@("1A='1R:6)S(#T@87)R87DH*3L-"B`@("`@("`@("`@
M(&EF("@D=7)I*2![#0H@("`@("`@("`@("`@("`@)&%T=')I8G-;)W5R:2==
M(#T@)'5R:3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1U<FD@/2!T
M<G5E.R`O+R!F;W(@=&5S="!B96QO=PT*("`@("`@("`@("`@:68@*"1F:6QE
M<V]U<F-E*2![#0H@("`@("`@("`@("`@("`@)&%T=')I8G-;)V9I;&5S;W5R
M8V4G72`]("1F:6QE<V]U<F-E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@("1L:6-E;G-E(#T@)'5R:2`_(&%R<F%Y*"=A='1R:6)S)R`]
M/B`D871T<FEB<RP@)U]C;VYT96YT)R`]/B`D;&EC96YS92D@.B`D;&EC96YS
M93L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG;&EC96YS92==(#T@
M)&QI8V5N<V4[#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@<V5T3F]T97,H)&YO=&5S*0T*("`@('L-"B`@
M("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7W!A8VMA9V5);F9O6R=N;W1E<R==*2D@>PT*("`@("`@("`@
M("`@+R\@96YS=7)E('1H870@=&AE(&YO=&5S('1A9R!I<R!S970@=7`@:6X@
M=&AE(')I9VAT(&QO8V%T:6]N#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA
M9V5);F9O(#T@)'1H:7,M/E]I;G-E<G1"969O<F4H)'1H:7,M/E]P86-K86=E
M26YF;RP-"B`@("`@("`@("`@("`@("!A<G)A>2@G8V]N=&5N=',G+"`G8V]M
M<&%T:6)L92<L#0H@("`@("`@("`@("`@("`@)V1E<&5N9&5N8VEE<R<L("=P
M<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L("=U<V5S=&%S:R<L("=S
M<F-P86-K86=E)RP@)W-R8W5R:2<L#0H@("`@("`@("`@("`@("`@)W!H<')E
M;&5A<V4G+"`G97AT<W)C<F5L96%S92<L#0H@("`@("`@("`@("`@("`@)V5X
M=&)I;G)E;&5A<V4G+"`G8G5N9&QE)RP@)V-H86YG96QO9R<I+"`D;F]T97,L
M("=N;W1E<R<I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G
M94EN9F];)VYO=&5S)UT@/2`D;F]T97,[#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@5&AI<R!I<R!O;FQY('5S960@870@:6YS=&%L;"UT:6UE+"!A9G1E
M<B!A;&P@<V5R:6%L:7IA=&EO;@T*("`@("`J(&ES(&]V97(N#0H@("`@("H@
M0'!A<F%M('-T<FEN9R!F:6QE(&YA;64-"B`@("`@*B!`<&%R86T@<W1R:6YG
M(&EN<W1A;&QE9"!P871H#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T26YS
M=&%L;&5D07,H)&9I;&4L("1P871H*0T*("`@('L-"B`@("`@("`@:68@*"1P
M871H*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF
M;ULG9FEL96QI<W0G75LD9FEL95U;)VEN<W1A;&QE9%]A<R==(#T@)'!A=&@[
M#0H@("`@("`@('T-"B`@("`@("`@=6YS970H)'1H:7,M/E]P86-K86=E26YF
M;ULG9FEL96QI<W0G75LD9FEL95U;)VEN<W1A;&QE9%]A<R==*3L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES(&ES(&]N;'D@=7-E9"!A="!I;G-T
M86QL+71I;64L(&%F=&5R(&%L;"!S97)I86QI>F%T:6]N#0H@("`@("H@:7,@
M;W9E<BX-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I;G-T86QL961&:6QE*"1F
M:6QE+"`D871T<RD-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7W!A8VMA9V5);F9O6R=F:6QE;&ES="==6R1F:6QE72DI('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V9I;&5L:7-T)UU;)&9I;&5=(#T-
M"B`@("`@("`@("`@("`@("!A<G)A>5]M97)G92@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=F:6QE;&ES="==6R1F:6QE72P@)&%T='-;)V%T=')I8G,G72D[#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=F:6QE;&ES="==6R1F:6QE72`]("1A='1S6R=A='1R:6)S)UT[#0H@
M("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!297-E="!T:&4@
M;&ES=&EN9R!O9B!P86-K86=E(&-O;G1E;G1S#0H@("`@("H@0'!A<F%M('-T
M<FEN9R!B87-E(&EN<W1A;&QA=&EO;B!D:7(@9F]R('1H92!W:&]L92!P86-K
M86=E+"!I9B!A;GD-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!C;&5A<D-O;G1E
M;G1S*"1B87-E:6YS=&%L;"`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)'1H
M:7,M/E]F:6QE<U9A;&ED(#T@9F%L<V4[#0H@("`@("`@("1T:&ES+3Y?:7-6
M86QI9"`](#`[#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E
M26YF;ULG8V]N=&5N=',G72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C
M:V%G94EN9F\@/2`D=&AI<RT^7VEN<V5R=$)E9F]R92@D=&AI<RT^7W!A8VMA
M9V5);F9O+`T*("`@("`@("`@("`@("`@(&%R<F%Y*"=C;VUP871I8FQE)RP-
M"B`@("`@("`@("`@("`@("`@("`@)V1E<&5N9&5N8VEE<R<L("=P<F]V:61E
M<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L("=U<V5S=&%S:R<L#0H@("`@("`@
M("`@("`@("`@("`@("=S<F-P86-K86=E)RP@)W-R8W5R:2<L("=P:'!R96QE
M87-E)RP@)V5X='-R8W)E;&5A<V4G+`T*("`@("`@("`@("`@("`@("`@("`G
M97AT8FEN<F5L96%S92<L("=B=6YD;&4G+"`G8VAA;F=E;&]G)RDL(&%R<F%Y
M*"DL("=C;VYT96YT<R<I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D=&AI
M<RT^9V5T4&%C:V%G951Y<&4H*2`A/2`G8G5N9&QE)RD@>PT*("`@("`@("`@
M("`@)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G72`](`T*("`@("`@
M("`@("`@("`@(&%R<F%Y*"=D:7(G(#T^(&%R<F%Y*"=A='1R:6)S)R`]/B!A
M<G)A>2@G;F%M92<@/3X@)R\G*2DI.PT*("`@("`@("`@("`@:68@*"1B87-E
M:6YS=&%L;"D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN
M9F];)V-O;G1E;G1S)UU;)V1I<B==6R=A='1R:6)S)UU;)V)A<V5I;G-T86QL
M9&ER)UT@/2`D8F%S96EN<W1A;&P[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG(')E
M;&%T:79E('!A=&@@;V8@=&AE(&)U;F1L960@<&%C:V%G92X-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!A9&1"=6YD;&5D4&%C:V%G92@D<&%T:"D-"B`@("![
M#0H@("`@("`@(&EF("@D=&AI<RT^9V5T4&%C:V%G951Y<&4H*2`A/2`G8G5N
M9&QE)RD@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]
M#0H@("`@("`@("1T:&ES+3Y?9FEL97-686QI9"`](&9A;'-E.PT*("`@("`@
M("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@("`D=&AI<RT^7W!A8VMA
M9V5);F9O(#T@)'1H:7,M/E]M97)G951A9R@D=&AI<RT^7W!A8VMA9V5);F9O
M+"`D<&%T:"P@87)R87DH#0H@("`@("`@("`@("`@("`@)V-O;G1E;G1S)R`]
M/B!A<G)A>2@G8V]M<&%T:6)L92<L("=D97!E;F1E;F-I97,G+"`G<')O=FED
M97-E>'1E;G-I;VXG+`T*("`@("`@("`@("`@("`@("=U<V5S<F]L92<L("=U
M<V5S=&%S:R<L("=S<F-P86-K86=E)RP@)W-R8W5R:2<L("=P:'!R96QE87-E
M)RP-"B`@("`@("`@("`@("`@("`G97AT<W)C<F5L96%S92<L("=E>'1B:6YR
M96QE87-E)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P-"B`@("`@("`@("`@
M("`@("`G8G5N9&QE9'!A8VMA9V4G(#T^(&%R<F%Y*"DI*3L-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG(&9I;&4@;F%M90T*("`@
M("`J($!P87)A;2!014%27U1A<VM?0V]M;6]N(&$@<F5A9"]W<FET92!T87-K
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D5&%S:U1O1FEL92@D9FEL96YA
M;64L("1T87-K*0T*("`@('L-"B`@("`@("`@:68@*"%M971H;V1?97AI<W1S
M*"1T87-K+"`G9V5T6&UL)RDI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6UE=&AO9%]E>&ES=',H)'1A
M<VLL("=G971.86UE)RDI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H(6UE=&AO9%]E>&ES=',H)'1A<VLL
M("=V86QI9&%T92<I*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"$D=&%S:RT^=F%L:61A=&4H*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG
M9&ER)UU;)V9I;&4G72DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^9V5T5&%S:W-.<R@I.R`O+R!D
M:7-C;W9E<B!T:&4@=&%S:W,@;F%M97-P86-E(&EF(&YO="!D;VYE(&%L<F5A
M9'D-"B`@("`@("`@)&9I;&5S(#T@)'1H:7,M/E]P86-K86=E26YF;ULG8V]N
M=&5N=',G75LG9&ER)UU;)V9I;&4G73L-"B`@("`@("`@:68@*"%I<W-E="@D
M9FEL97-;,%TI*2![#0H@("`@("`@("`@("`D9FEL97,@/2!A<G)A>2@D9FEL
M97,I.PT*("`@("`@("`@("`@)&EN9"`](&9A;'-E.PT*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@)&EN9"`]('1R=64[#0H@("`@("`@('T-"B`@
M("`@("`@9F]R96%C:"`H)&9I;&5S(&%S("1I(#T^("1F:6QE*2![#0H@("`@
M("`@("`@("!I9B`H:7-S970H)&9I;&5;)V%T=')I8G,G72DI('L-"B`@("`@
M("`@("`@("`@("!I9B`H)&9I;&5;)V%T=')I8G,G75LG;F%M92==(#T]("1F
M:6QE;F%M92D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)&EN9"D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)'0@/2!I<W-E="@D=&AI<RT^7W!A
M8VMA9V5);F9O6R=C;VYT96YT<R==6R=D:7(G75LG9FEL92==6R1I70T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@6R=A='1R:6)S)UU;)'1H:7,M
M/E]T87-K<TYS("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<Z
M)R`N("1T87-K+3YG971.86UE*"E=*2`_#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT<R==6R=D
M:7(G75LG9FEL92==6R1I70T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@6R=A='1R:6)S)UU;)'1H:7,M/E]T87-K<TYS("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("<Z)R`N("1T87-K+3YG971.86UE*"E=(#H@
M9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'0@)B8@(6ES
M<V5T*"1T6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UU;
M)&E=#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%LD=&AI<RT^
M7W1A<VMS3G,@+B`G.B<@+B`D=&%S:RT^9V5T3F%M92@I72`](&%R<F%Y*"1T
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I
M<B==6R=F:6QE)UU;)&E=6R1T:&ES+3Y?=&%S:W-.<R`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)SHG("X@)'1A<VLM/F=E=$YA;64H*5U;72`]
M("1T87-K+3YG9718;6PH*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T(#T@:7-S970H)'1H:7,M
M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G70T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@6R=A='1R:6)S)UU;)'1H:7,M
M/E]T87-K<TYS("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<Z
M)R`N("1T87-K+3YG971.86UE*"E=*2`_("1T:&ES+3Y?<&%C:V%G94EN9F];
M)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UT-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%LG871T<FEB<R==6R1T:&ES+3Y?=&%S:W-.<R`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G.B<@+B`D=&%S:RT^9V5T
M3F%M92@I72`Z(&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"1T("8F("%I<W-E="@D=%LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT<R==6R=D:7(G
M75LG9FEL92==#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%LD
M=&AI<RT^7W1A<VMS3G,@+B`G.B<@+B`D=&%S:RT^9V5T3F%M92@I72`](&%R
M<F%Y*"1T*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S
M)UU;)V1I<B==6R=F:6QE)UU;)'1H:7,M/E]T87-K<TYS("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G.B<@+B`D=&%S:RT^9V5T3F%M92@I75M=
M(#T@)'1A<VLM/F=E=%AM;"@I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T
M<FEN9R!P871H('1O('1H92!F:6QE#0H@("`@("H@0'!A<F%M('-T<FEN9R!F
M:6QE;F%M90T*("`@("`J($!P87)A;2!A<G)A>2!E>'1R82!A='1R:6)U=&5S
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D1FEL92@D9&ER+"`D9FEL92P@
M)&%T=')S*0T*("`@('L-"B`@("`@("`@:68@*"1T:&ES+3YG971086-K86=E
M5'EP92@I(#T]("=B=6YD;&4G*2![#0H@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]F:6QE<U9A;&ED(#T@
M9F%L<V4[#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@
M("1D:7(@/2!P<F5G7W)E<&QA8V4H87)R87DH)R%<7%Q<*R$G+"`G(2\K(2<I
M+"!A<G)A>2@G+R<L("<O)RDL("1D:7(I.PT*("`@("`@("!I9B`H)&1I<B`]
M/2`G+R<@?'P@)&1I<B`]/2`G)RD@>PT*("`@("`@("`@("`@)&1I<B`]("<G
M.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&1I<B`N/2`G+R<[
M#0H@("`@("`@('T-"B`@("`@("`@)&%T=')S6R=N86UE)UT@/2`D9&ER("X@
M)&9I;&4[#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF
M;ULG8V]N=&5N=',G72DI('L-"B`@("`@("`@("`@("\O(&5N<W5R92!T:&%T
M('1H92!C;VYT96YT<R!T86<@:7,@<V5T('5P#0H@("`@("`@("`@("`D=&AI
M<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]I;G-E<G1"969O<F4H)'1H:7,M
M/E]P86-K86=E26YF;RP-"B`@("`@("`@("`@("`@("!A<G)A>2@G8V]M<&%T
M:6)L92<L("=D97!E;F1E;F-I97,G+"`G<')O=FED97-E>'1E;G-I;VXG+"`G
M=7-E<W)O;&4G+"`G=7-E<W1A<VLG+`T*("`@("`@("`@("`@("`@("=S<F-P
M86-K86=E)RP@)W-R8W5R:2<L("=P:'!R96QE87-E)RP@)V5X='-R8W)E;&5A
M<V4G+`T*("`@("`@("`@("`@("`@("=E>'1B:6YR96QE87-E)RP@)V)U;F1L
M92<L("=C:&%N9V5L;V<G*2P@87)R87DH*2P@)V-O;G1E;G1S)RD[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];
M)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UTI*2![#0H@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I
M<B==6R=F:6QE)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G72`]#0H@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-O
M;G1E;G1S)UU;)V1I<B==6R=F:6QE)UTI.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER
M)UU;)V9I;&4G75M=6R=A='1R:6)S)UT@/2`D871T<G,[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT
M96YT<R==6R=D:7(G75LG9FEL92==6R=A='1R:6)S)UT@/2`D871T<G,[#0H@
M("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R
M:6YG($1E<&5N9&5N="!P86-K86=E(&YA;64-"B`@("`@*B!`<&%R86T@<W1R
M:6YG($1E<&5N9&5N="!P86-K86=E)W,@8VAA;FYE;"!N86UE#0H@("`@("H@
M0'!A<F%M('-T<FEN9R!M:6YI;75M('9E<G-I;VX@;V8@<W!E8VEF:65D('!A
M8VMA9V4@=&AA="!T:&ES(')E;&5A<V4@:7,@9W5A<F%N=&5E9"!T;R!B90T*
M("`@("`J("`@("`@("`@("`@("`@8V]M<&%T:6)L92!W:71H#0H@("`@("H@
M0'!A<F%M('-T<FEN9R!M87AI;75M('9E<G-I;VX@;V8@<W!E8VEF:65D('!A
M8VMA9V4@=&AA="!T:&ES(')E;&5A<V4@:7,@9W5A<F%N=&5E9"!T;R!B90T*
M("`@("`J("`@("`@("`@("`@("`@8V]M<&%T:6)L92!W:71H#0H@("`@("H@
M0'!A<F%M('-T<FEN9R!V97)S:6]N<R!O9B!S<&5C:69I960@<&%C:V%G92!T
M:&%T('1H:7,@<F5L96%S92!I<R!N;W0@8V]M<&%T:6)L92!W:71H#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@861D0V]M<&%T:6)L95!A8VMA9V4H)&YA;64L
M("1C:&%N;F5L+"`D;6EN+"`D;6%X+"`D97AC;'5D92`](&9A;'-E*0T*("`@
M('L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@)'-E
M="`](&%R<F%Y*`T*("`@("`@("`@("`@)VYA;64G(#T^("1N86UE+`T*("`@
M("`@("`@("`@)V-H86YN96PG(#T^("1C:&%N;F5L+`T*("`@("`@("`@("`@
M)VUI;B<@/3X@)&UI;BP-"B`@("`@("`@("`@("=M87@G(#T^("1M87@L#0H@
M("`@("`@("D[#0H@("`@("`@(&EF("@D97AC;'5D92D@>PT*("`@("`@("`@
M("`@)'-E=%LG97AC;'5D92==(#T@)&5X8VQU9&4[#0H@("`@("`@('T-"B`@
M("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@)'1H:7,M/E]P
M86-K86=E26YF;R`]("1T:&ES+3Y?;65R9V5486<H)'1H:7,M/E]P86-K86=E
M26YF;RP@)'-E="P@87)R87DH#0H@("`@("`@("`@("`@("`@)V-O;7!A=&EB
M;&4G(#T^(&%R<F%Y*"=D97!E;F1E;F-I97,G+"`G<')O=FED97-E>'1E;G-I
M;VXG+"`G=7-E<W)O;&4G+"`G=7-E<W1A<VLG+`T*("`@("`@("`@("`@("`@
M("`@("`G<W)C<&%C:V%G92<L("=S<F-U<FDG+"`G<&AP<F5L96%S92<L("=E
M>'1S<F-R96QE87-E)RP@)V5X=&)I;G)E;&5A<V4G+`T*("`@("`@("`@("`@
M("`@("`@("`G8G5N9&QE)RP@)V-H86YG96QO9R<I#0H@("`@("`@("`@("`I
M*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!296UO=F5S('1H92`\=7-E
M<W)O;&4^('1A9R!E;G1I<F5L>0T*("`@("`J+PT*("`@(&9U;F-T:6]N(')E
M<V5T57-E<W)O;&4H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)W5S97-R;VQE)UTI*2![#0H@("`@("`@("`@("!U
M;G-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=U<V5S<F]L92==*3L-"B`@("`@
M("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<-
M"B`@("`@*B!`<&%R86T@<W1R:6YG('!A8VMA9V4@;F%M92!O<B!U<FD-"B`@
M("`@*B!`<&%R86T@<W1R:6YG(&-H86YN96P@;F%M92!I9B!N;VXM=7)I#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@861D57-E<W)O;&4H)')O;&4L("1P86-K
M86=E3W)5<FDL("1C:&%N;F5L(#T@9F%L<V4I('L-"B`@("`@("`@)'-E="`]
M(&%R<F%Y*"=R;VQE)R`]/B`D<F]L92D[#0H@("`@("`@(&EF("@D8VAA;FYE
M;"D@>PT*("`@("`@("`@("`@)'-E=%LG<&%C:V%G92==(#T@)'!A8VMA9V5/
M<E5R:3L-"B`@("`@("`@("`@("1S971;)V-H86YN96PG72`]("1C:&%N;F5L
M.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'-E=%LG=7)I)UT@
M/2`D<&%C:V%G94]R57)I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?
M:7-686QI9"`](#`[#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D
M=&AI<RT^7VUE<F=E5&%G*"1T:&ES+3Y?<&%C:V%G94EN9F\L("1S970L(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("=U<V5S<F]L92<@/3X@87)R87DH)W5S
M97-T87-K)RP@)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP-"B`@("`@("`@("`@
M("`@("`@("`@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L("=E>'1B
M:6YR96QE87-E)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G*0T*("`@("`@("`@
M("`@*2D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4F5M;W9E<R!T:&4@
M/'5S97-T87-K/B!T86<@96YT:7)E;'D-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!R97-E=%5S97-T87-K*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7W!A8VMA9V5);F9O6R=U<V5S=&%S:R==*2D@>PT*("`@("`@("`@
M("`@=6YS970H)'1H:7,M/E]P86-K86=E26YF;ULG=7-E<W1A<VLG72D[#0H@
M("`@("`@('T-"B`@("!]#0H-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S
M=')I;F<-"B`@("`@*B!`<&%R86T@<W1R:6YG('!A8VMA9V4@;F%M92!O<B!U
M<FD-"B`@("`@*B!`<&%R86T@<W1R:6YG(&-H86YN96P@;F%M92!I9B!N;VXM
M=7)I#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D57-E<W1A<VLH)'1A<VLL
M("1P86-K86=E3W)5<FDL("1C:&%N;F5L(#T@9F%L<V4I('L-"B`@("`@("`@
M)'-E="`](&%R<F%Y*"=T87-K)R`]/B`D=&%S:RD[#0H@("`@("`@(&EF("@D
M8VAA;FYE;"D@>PT*("`@("`@("`@("`@)'-E=%LG<&%C:V%G92==(#T@)'!A
M8VMA9V5/<E5R:3L-"B`@("`@("`@("`@("1S971;)V-H86YN96PG72`]("1C
M:&%N;F5L.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'-E=%LG
M=7)I)UT@/2`D<&%C:V%G94]R57)I.PT*("`@("`@("!]#0H@("`@("`@("1T
M:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN
M9F\@/2`D=&AI<RT^7VUE<F=E5&%G*"1T:&ES+3Y?<&%C:V%G94EN9F\L("1S
M970L(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=U<V5S=&%S:R<@/3X@87)R
M87DH)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP-"B`@("`@("`@("`@("`@("`@
M("`@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L("=E>'1B:6YR96QE
M87-E)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G*0T*("`@("`@("`@("`@*2D[
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4F5M;W9E(&%L;"!C;VUP871I
M8FQE('1A9W,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!C;&5A<D-O;7!A=&EB
M;&4H*0T*("`@('L-"B`@("`@("`@=6YS970H)'1H:7,M/E]P86-K86=E26YF
M;ULG8V]M<&%T:6)L92==*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!2
M97-E="!D97!E;F1E;F-I97,@<')I;W(@=&\@861D:6YG(&YE=R!O;F5S#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@8VQE87)$97!S*"D-"B`@("![#0H@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC
M:65S)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@
M)'1H:7,M/E]M97)G951A9R@D=&AI<RT^7W!A8VMA9V5);F9O+"!A<G)A>2@I
M+`T*("`@("`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@
M("`G9&5P96YD96YC:65S)R`]/B!A<G)A>2@G<')O=FED97-E>'1E;G-I;VXG
M+"`G=7-E<W)O;&4G+"`G=7-E<W1A<VLG+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP@)W!H<')E;&5A<V4G+"`G
M97AT<W)C<F5L96%S92<L("=E>'1B:6YR96QE87-E)RP-"B`@("`@("`@("`@
M("`@("`@("`@("`@("=B=6YD;&4G+"`G8VAA;F=E;&]G)RDI*3L-"B`@("`@
M("`@?0T*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I
M97,G72`](&%R<F%Y*"D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A
M<F%M('-T<FEN9R!M:6YI;75M(%!(4"!V97)S:6]N(&%L;&]W960-"B`@("`@
M*B!`<&%R86T@<W1R:6YG(&UA>&EM=6T@4$A0('9E<G-I;VX@86QL;W=E9`T*
M("`@("`J($!P87)A;2!A<G)A>2`D97AC;'5D92!I;F-O;7!A=&EB;&4@4$A0
M('9E<G-I;VYS#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T4&AP1&5P*"1M
M:6XL("1M87@@/2!F86QS92P@)&5X8VQU9&4@/2!F86QS92D-"B`@("![#0H@
M("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@("1D97`@/0T*
M("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@)VUI;B<@/3X@
M)&UI;BP-"B`@("`@("`@("`@("D[#0H@("`@("`@(&EF("@D;6%X*2![#0H@
M("`@("`@("`@("`D9&5P6R=M87@G72`]("1M87@[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"1E>&-L=61E*2![#0H@("`@("`@("`@("!I9B`H8V]U;G0H
M)&5X8VQU9&4I(#T](#$I('L-"B`@("`@("`@("`@("`@("`D97AC;'5D92`]
M("1E>&-L=61E6S!=.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&1E
M<%LG97AC;'5D92==(#T@)&5X8VQU9&4[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE<R==
M6R=R97%U:7)E9"==6R=P:'`G72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?
M<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G=V%R;FEN9R<L(&%R<F%Y*"=D
M97`G(#T^#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E
M;F1E;F-I97,G75LG<F5Q=6ER960G75LG<&AP)UTI+`T*("`@("`@("`@("`@
M("`@("=W87)N:6YG.B!02%`@9&5P96YD96YC>2!A;')E861Y(&5X:7-T<RP@
M;W9E<G=R:71I;F<G*3L-"B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)V1E<&5N9&5N8VEE<R==6R=R97%U:7)E9"==6R=P:'`G72D[
M#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T
M:&ES+3Y?;65R9V5486<H)'1H:7,M/E]P86-K86=E26YF;RP@)&1E<"P-"B`@
M("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=D97!E;F1E;F-I
M97,G(#T^(&%R<F%Y*"=P<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L
M("=U<V5S=&%S:R<L#0H@("`@("`@("`@("`@("`@("`@("=S<F-P86-K86=E
M)RP@)W-R8W5R:2<L("=P:'!R96QE87-E)RP@)V5X='-R8W)E;&5A<V4G+"`G
M97AT8FEN<F5L96%S92<L#0H@("`@("`@("`@("`@("`@("`@("=B=6YD;&4G
M+"`G8VAA;F=E;&]G)RDL#0H@("`@("`@("`@("`@("`@)W)E<75I<F5D)R`]
M/B!A<G)A>2@G;W!T:6]N86PG+"`G9W)O=7`G*2P-"B`@("`@("`@("`@("`@
M("`G<&AP)R`]/B!A<G)A>2@G<&5A<FEN<W1A;&QE<B<L("=P86-K86=E)RP@
M)W-U8G!A8VMA9V4G+"`G97AT96YS:6]N)RP@)V]S)RP@)V%R8V@G*0T*("`@
M("`@("`@("`@*2D[#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<@;6EN:6UU;2!A;&QO=V5D
M(%!%05(@:6YS=&%L;&5R('9E<G-I;VX-"B`@("`@*B!`<&%R86T@<W1R:6YG
M(&UA>&EM=6T@86QL;W=E9"!014%2(&EN<W1A;&QE<B!V97)S:6]N#0H@("`@
M("H@0'!A<F%M('-T<FEN9R!R96-O;6UE;F1E9"!014%2(&EN<W1A;&QE<B!V
M97)S:6]N#0H@("`@("H@0'!A<F%M(&%R<F%Y(&EN8V]M<&%T:6)L92!V97)S
M:6]N(&]F('1H92!014%2(&EN<W1A;&QE<@T*("`@("`J+PT*("`@(&9U;F-T
M:6]N('-E=%!E87)I;G-T86QL97)$97`H)&UI;BP@)&UA>"`](&9A;'-E+"`D
M<F5C;VUM96YD960@/2!F86QS92P@)&5X8VQU9&4@/2!F86QS92D-"B`@("![
M#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@("1D97`@
M/0T*("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@)VUI;B<@
M/3X@)&UI;BP-"B`@("`@("`@("`@("D[#0H@("`@("`@(&EF("@D;6%X*2![
M#0H@("`@("`@("`@("`D9&5P6R=M87@G72`]("1M87@[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"1R96-O;6UE;F1E9"D@>PT*("`@("`@("`@("`@)&1E
M<%LG<F5C;VUM96YD960G72`]("1R96-O;6UE;F1E9#L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H)&5X8VQU9&4I('L-"B`@("`@("`@("`@(&EF("AC;W5N
M="@D97AC;'5D92D@/3T@,2D@>PT*("`@("`@("`@("`@("`@("1E>&-L=61E
M(#T@)&5X8VQU9&5;,%T[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D
M9&5P6R=E>&-L=61E)UT@/2`D97AC;'5D93L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S
M)UU;)W)E<75I<F5D)UU;)W!E87)I;G-T86QL97(G72DI('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G=V%R;FEN
M9R<L(&%R<F%Y*"=D97`G(#T^#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA
M9V5);F9O6R=D97!E;F1E;F-I97,G75LG<F5Q=6ER960G75LG<&5A<FEN<W1A
M;&QE<B==*2P-"B`@("`@("`@("`@("`@("`G=V%R;FEN9SH@4$5!4B!);G-T
M86QL97(@9&5P96YD96YC>2!A;')E861Y(&5X:7-T<RP@;W9E<G=R:71I;F<G
M*3L-"B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E
M<&5N9&5N8VEE<R==6R=R97%U:7)E9"==6R=P96%R:6YS=&%L;&5R)UTI.PT*
M("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI
M<RT^7VUE<F=E5&%G*"1T:&ES+3Y?<&%C:V%G94EN9F\L("1D97`L#0H@("`@
M("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`G9&5P96YD96YC:65S
M)R`]/B!A<G)A>2@G<')O=FED97-E>'1E;G-I;VXG+"`G=7-E<W)O;&4G+"`G
M=7-E<W1A<VLG+`T*("`@("`@("`@("`@("`@("`@("`G<W)C<&%C:V%G92<L
M("=S<F-U<FDG+"`G<&AP<F5L96%S92<L("=E>'1S<F-R96QE87-E)RP@)V5X
M=&)I;G)E;&5A<V4G+`T*("`@("`@("`@("`@("`@("`@("`G8G5N9&QE)RP@
M)V-H86YG96QO9R<I+`T*("`@("`@("`@("`@("`@("=R97%U:7)E9"<@/3X@
M87)R87DH)V]P=&EO;F%L)RP@)V=R;W5P)RDL#0H@("`@("`@("`@("`@("`@
M)W!E87)I;G-T86QL97(G(#T^(&%R<F%Y*"=P86-K86=E)RP@)W-U8G!A8VMA
M9V4G+"`G97AT96YS:6]N)RP@)V]S)RP@)V%R8V@G*0T*("`@("`@("`@("`@
M*2D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@36%R:R!A('!A8VMA9V4@
M87,@8V]N9FQI8W1I;F<@=VET:"!T:&ES('!A8VMA9V4-"B`@("`@*B!`<&%R
M86T@<W1R:6YG('!A8VMA9V4@;F%M90T*("`@("`J($!P87)A;2!S=')I;F<@
M<&%C:V%G92!C:&%N;F5L#0H@("`@("H@0'!A<F%M('-T<FEN9R!E>'1E;G-I
M;VX@=&AI<R!P86-K86=E('!R;W9I9&5S+"!I9B!A;GD-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!A9&1#;VYF;&EC=&EN9U!A8VMA9V5$97!7:71H0VAA;FYE
M;"@D;F%M92P@)&-H86YN96PL("1P<F]V:61E<V5X=&5N<VEO;B`](&9A;'-E
M*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@
M("`@)&1E<"`]#0H@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`G;F%M92<@/3X@)&YA;64L#0H@("`@("`@("`@("`@("`@)V-H86YN96PG
M(#T^("1C:&%N;F5L+`T*("`@("`@("`@("`@("`@("=C;VYF;&EC=',G(#T^
M("<G+`T*("`@("`@("`@("`@*3L-"B`@("`@("`@:68@*"1P<F]V:61E<V5X
M=&5N<VEO;BD@>PT*("`@("`@("`@("`@)&1E<%LG<')O=FED97-E>'1E;G-I
M;VXG72`]("1P<F]V:61E<V5X=&5N<VEO;CL-"B`@("`@("`@?0T*("`@("`@
M("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]M97)G951A9R@D=&AI
M<RT^7W!A8VMA9V5);F9O+"`D9&5P+`T*("`@("`@("`@("`@87)R87DH#0H@
M("`@("`@("`@("`@("`@)V1E<&5N9&5N8VEE<R<@/3X@87)R87DH)W!R;W9I
M9&5S97AT96YS:6]N)RP@)W5S97-R;VQE)RP@)W5S97-T87-K)RP-"B`@("`@
M("`@("`@("`@("`@("`@)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP@)W!H<')E
M;&5A<V4G+"`G97AT<W)C<F5L96%S92<L("=E>'1B:6YR96QE87-E)RP-"B`@
M("`@("`@("`@("`@("`@("`@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P-"B`@
M("`@("`@("`@("`@("`G<F5Q=6ER960G(#T^(&%R<F%Y*"=O<'1I;VYA;"<L
M("=G<F]U<"<I+`T*("`@("`@("`@("`@("`@("=P86-K86=E)R`]/B!A<G)A
M>2@G<W5B<&%C:V%G92<L("=E>'1E;G-I;VXG+"`G;W,G+"`G87)C:"<I#0H@
M("`@("`@("`@("`I*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!-87)K
M(&$@<&%C:V%G92!A<R!C;VYF;&EC=&EN9R!W:71H('1H:7,@<&%C:V%G90T*
M("`@("`J($!P87)A;2!S=')I;F<@<&%C:V%G92!N86UE#0H@("`@("H@0'!A
M<F%M('-T<FEN9R!P86-K86=E(&-H86YN96P-"B`@("`@*B!`<&%R86T@<W1R
M:6YG(&5X=&5N<VEO;B!T:&ES('!A8VMA9V4@<')O=FED97,L(&EF(&%N>0T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$-O;F9L:6-T:6YG4&%C:V%G941E
M<%=I=&A5<FDH)&YA;64L("1U<FDL("1P<F]V:61E<V5X=&5N<VEO;B`](&9A
M;'-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@
M("`@("`@)&1E<"`]#0H@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`G;F%M92<@/3X@)&YA;64L#0H@("`@("`@("`@("`@("`@)W5R:2<@
M/3X@)'5R:2P-"B`@("`@("`@("`@("`@("`G8V]N9FQI8W1S)R`]/B`G)RP-
M"B`@("`@("`@("`@("D[#0H@("`@("`@(&EF("@D<')O=FED97-E>'1E;G-I
M;VXI('L-"B`@("`@("`@("`@("1D97!;)W!R;W9I9&5S97AT96YS:6]N)UT@
M/2`D<')O=FED97-E>'1E;G-I;VX[#0H@("`@("`@('T-"B`@("`@("`@)'1H
M:7,M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?;65R9V5486<H)'1H:7,M/E]P
M86-K86=E26YF;RP@)&1E<"P-"B`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("=D97!E;F1E;F-I97,G(#T^(&%R<F%Y*"=P<F]V:61E<V5X
M=&5N<VEO;B<L("=U<V5S<F]L92<L("=U<V5S=&%S:R<L#0H@("`@("`@("`@
M("`@("`@("`@("=S<F-P86-K86=E)RP@)W-R8W5R:2<L("=P:'!R96QE87-E
M)RP@)V5X='-R8W)E;&5A<V4G+"`G97AT8FEN<F5L96%S92<L#0H@("`@("`@
M("`@("`@("`@("`@("=B=6YD;&4G+"`G8VAA;F=E;&]G)RDL#0H@("`@("`@
M("`@("`@("`@)W)E<75I<F5D)R`]/B!A<G)A>2@G;W!T:6]N86PG+"`G9W)O
M=7`G*2P-"B`@("`@("`@("`@("`@("`G<&%C:V%G92<@/3X@87)R87DH)W-U
M8G!A8VMA9V4G+"`G97AT96YS:6]N)RP@)V]S)RP@)V%R8V@G*0T*("`@("`@
M("`@("`@*2D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@861D1&5P96YD96YC
M>4=R;W5P*"1N86UE+"`D:&EN="D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?
M:7-686QI9"`](#`[#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D
M=&AI<RT^7VUE<F=E5&%G*"1T:&ES+3Y?<&%C:V%G94EN9F\L#0H@("`@("`@
M("`@("!A<G)A>2@G871T<FEB<R<@/3X@87)R87DH)VYA;64G(#T^("1N86UE
M+"`G:&EN="<@/3X@)&AI;G0I*2P-"B`@("`@("`@("`@(&%R<F%Y*`T*("`@
M("`@("`@("`@("`@("=D97!E;F1E;F-I97,G(#T^(&%R<F%Y*"=P<F]V:61E
M<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L("=U<V5S=&%S:R<L#0H@("`@("`@
M("`@("`@("`@("`@("=S<F-P86-K86=E)RP@)W-R8W5R:2<L("=P:'!R96QE
M87-E)RP@)V5X='-R8W)E;&5A<V4G+"`G97AT8FEN<F5L96%S92<L#0H@("`@
M("`@("`@("`@("`@("`@("=B=6YD;&4G+"`G8VAA;F=E;&]G)RDL#0H@("`@
M("`@("`@("`@("`@)V=R;W5P)R`]/B!A<G)A>2@I+`T*("`@("`@("`@("`@
M*2D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9R!P
M86-K86=E(&YA;64-"B`@("`@*B!`<&%R86T@<W1R:6YG?&9A;'-E(&-H86YN
M96P@;F%M92P@9F%L<V4@:68@=&AI<R!I<R!A('5R:0T*("`@("`J($!P87)A
M;2!S=')I;F=\9F%L<V4@=7)I(&YA;64L(&9A;'-E(&EF('1H:7,@:7,@82!C
M:&%N;F5L#0H@("`@("H@0'!A<F%M('-T<FEN9WQF86QS92!M:6YI;75M('9E
M<G-I;VX@<F5Q=6ER960-"B`@("`@*B!`<&%R86T@<W1R:6YG?&9A;'-E(&UA
M>&EM=6T@=F5R<VEO;B!A;&QO=V5D#0H@("`@("H@0'!A<F%M('-T<FEN9WQF
M86QS92!R96-O;6UE;F1E9"!I;G-T86QL871I;VX@=F5R<VEO;@T*("`@("`J
M($!P87)A;2!A<G)A>7QF86QS92!V97)S:6]N<R!T;R!E>&-L=61E(&9R;VT@
M:6YS=&%L;&%T:6]N#0H@("`@("H@0'!A<F%M('-T<FEN9R!E>'1E;G-I;VX@
M=&AI<R!P86-K86=E('!R;W9I9&5S+"!I9B!A;GD-"B`@("`@*B!`<&%R86T@
M8F]O;"!I9B!T<G5E+"!T96QL<R!T:&4@:6YS=&%L;&5R('1O(&EG;F]R92!T
M:&4@9&5F875L="!O<'1I;VYA;"!D97!E;F1E;F-Y(&=R;W5P#0H@("`@("H@
M("`@("`@("`@("`@=VAE;B!I;G-T86QL:6YG('1H:7,@<&%C:V%G90T*("`@
M("`J($!R971U<FX@87)R87D-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!?8V]N<W1R=6-T1&5P*"1N86UE+"`D8VAA
M;FYE;"P@)'5R:2P@)&UI;BP@)&UA>"P@)')E8V]M;65N9&5D+"`D97AC;'5D
M92P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<F]V:61E<V5X=&5N
M<VEO;B`](&9A;'-E+"`D;F]D969A=6QT(#T@9F%L<V4I#0H@("`@>PT*("`@
M("`@("`D9&5P(#T-"B`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("=N86UE)R`]/B`D;F%M92P-"B`@("`@("`@("`@("D[#0H@("`@("`@
M(&EF("@D8VAA;FYE;"D@>PT*("`@("`@("`@("`@)&1E<%LG8VAA;FYE;"==
M(#T@)&-H86YN96P[#0H@("`@("`@('T@96QS96EF("@D=7)I*2![#0H@("`@
M("`@("`@("`D9&5P6R=U<FDG72`]("1U<FD[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"1M:6XI('L-"B`@("`@("`@("`@("1D97!;)VUI;B==(#T@)&UI
M;CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&UA>"D@>PT*("`@("`@("`@
M("`@)&1E<%LG;6%X)UT@/2`D;6%X.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("@D<F5C;VUM96YD960I('L-"B`@("`@("`@("`@("1D97!;)W)E8V]M;65N
M9&5D)UT@/2`D<F5C;VUM96YD960[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"1E>&-L=61E*2![#0H@("`@("`@("`@("!I9B`H:7-?87)R87DH)&5X8VQU
M9&4I("8F(&-O=6YT*"1E>&-L=61E*2`]/2`Q*2![#0H@("`@("`@("`@("`@
M("`@)&5X8VQU9&4@/2`D97AC;'5D95LP73L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("1D97!;)V5X8VQU9&4G72`]("1E>&-L=61E.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@D;F]D969A=6QT*2![#0H@("`@("`@("`@("`D
M9&5P6R=N;V1E9F%U;'0G72`]("<G.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("@D<')O=FED97-E>'1E;G-I;VXI('L-"B`@("`@("`@("`@("1D97!;)W!R
M;W9I9&5S97AT96YS:6]N)UT@/2`D<')O=FED97-E>'1E;G-I;VX[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N("1D97`[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@0'!A<F%M('!A8VMA9V5\<W5B<&%C:V%G90T*("`@("`J($!P
M87)A;2!S=')I;F<@9W)O=7`@;F%M90T*("`@("`J($!P87)A;2!S=')I;F<@
M<&%C:V%G92!N86UE#0H@("`@("H@0'!A<F%M('-T<FEN9R!P86-K86=E(&-H
M86YN96P-"B`@("`@*B!`<&%R86T@<W1R:6YG(&UI;FEM=6T@=F5R<VEO;@T*
M("`@("`J($!P87)A;2!S=')I;F<@;6%X:6UU;2!V97)S:6]N#0H@("`@("H@
M0'!A<F%M('-T<FEN9R!R96-O;6UE;F1E9"!V97)S:6]N#0H@("`@("H@0'!A
M<F%M(&%R<F%Y?&9A;'-E(&]P=&EO;F%L(&5X8VQU9&5D('9E<G-I;VYS#0H@
M("`@("H@0'!A<F%M('-T<FEN9R!E>'1E;G-I;VX@=&AI<R!P86-K86=E('!R
M;W9I9&5S+"!I9B!A;GD-"B`@("`@*B!`<&%R86T@8F]O;"!I9B!T<G5E+"!T
M96QL<R!T:&4@:6YS=&%L;&5R('1O(&EG;F]R92!T:&4@9&5F875L="!O<'1I
M;VYA;"!D97!E;F1E;F-Y(&=R;W5P#0H@("`@("H@("`@("`@("`@("`@=VAE
M;B!I;G-T86QL:6YG('1H:7,@<&%C:V%G90T*("`@("`J($!R971U<FX@8F]O
M;"!F86QS92!I9B!T:&4@9&5P96YD96YC>2!G<F]U<"!H87,@;F]T(&)E96X@
M:6YI=&EA;&EZ960@=VET:`T*("`@("`J("`@("`@("`@("`@("![0&QI;FL@
M861D1&5P96YD96YC>4=R;W5P*"E]+"!O<B!A('-U8G!A8VMA9V4@:7,@861D
M960@=VET:`T*("`@("`J("`@("`@("`@("`@("!A('!R;W9I9&5S97AT96YS
M:6]N#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D1W)O=7!086-K86=E1&5P
M5VET:$-H86YN96PH)'1Y<&4L("1G<F]U<&YA;64L("1N86UE+"`D8VAA;FYE
M;"P@)&UI;B`](&9A;'-E+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D;6%X(#T@9F%L<V4L("1R96-O;6UE;F1E9"`](&9A;'-E
M+"`D97AC;'5D92`](&9A;'-E+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<')O=FED97-E>'1E;G-I;VX@/2!F86QS92P@)&YO
M9&5F875L="`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"1T>7!E(#T]
M("=S=6)P86-K86=E)R`F)B`D<')O=FED97-E>'1E;G-I;VXI('L-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L@+R\@<W5B<&%C:V%G97,@;75S="!B92!P
M:'`@<&%C:V%G97,-"B`@("`@("`@?0T*("`@("`@("`D9&5P(#T@)'1H:7,M
M/E]C;VYS=')U8W1$97`H)&YA;64L("1C:&%N;F5L+"!F86QS92P@)&UI;BP@
M)&UA>"P@)')E8V]M;65N9&5D+"`D97AC;'5D92P-"B`@("`@("`@("`@("1P
M<F]V:61E<V5X=&5N<VEO;BP@)&YO9&5F875L="D[#0H@("`@("`@(')E='5R
M;B`D=&AI<RT^7V%D9$=R;W5P1&5P96YD96YC>2@D='EP92P@)&1E<"P@)&=R
M;W5P;F%M92D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('!A
M8VMA9V5\<W5B<&%C:V%G90T*("`@("`J($!P87)A;2!S=')I;F<@9W)O=7`@
M;F%M90T*("`@("`J($!P87)A;2!S=')I;F<@<&%C:V%G92!N86UE#0H@("`@
M("H@0'!A<F%M('-T<FEN9R!P86-K86=E('5R:0T*("`@("`J($!P87)A;2!S
M=')I;F<@97AT96YS:6]N('1H:7,@<&%C:V%G92!P<F]V:61E<RP@:68@86YY
M#0H@("`@("H@0'!A<F%M(&)O;VP@:68@=')U92P@=&5L;',@=&AE(&EN<W1A
M;&QE<B!T;R!I9VYO<F4@=&AE(&1E9F%U;'0@;W!T:6]N86P@9&5P96YD96YC
M>2!G<F]U<`T*("`@("`J("`@("`@("`@("`@('=H96X@:6YS=&%L;&EN9R!T
M:&ES('!A8VMA9V4-"B`@("`@*B!`<F5T=7)N(&)O;VP@9F%L<V4@:68@=&AE
M(&1E<&5N9&5N8WD@9W)O=7`@:&%S(&YO="!B965N(&EN:71I86QI>F5D('=I
M=&@-"B`@("`@*B`@("`@("`@("`@("`@>T!L:6YK(&%D9$1E<&5N9&5N8WE'
M<F]U<"@I?0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$=R;W5P4&%C:V%G
M941E<%=I=&A54DDH)'1Y<&4L("1G<F]U<&YA;64L("1N86UE+"`D=7)I+"`D
M<')O=FED97-E>'1E;G-I;VX@/2!F86QS92P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1N;V1E9F%U;'0@/2!F86QS92D-"B`@
M("![#0H@("`@("`@(&EF("@D='EP92`]/2`G<W5B<&%C:V%G92<@)B8@)'!R
M;W9I9&5S97AT96YS:6]N*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[
M("\O('-U8G!A8VMA9V5S(&UU<W0@8F4@<&AP('!A8VMA9V5S#0H@("`@("`@
M('T-"B`@("`@("`@)&1E<"`]("1T:&ES+3Y?8V]N<W1R=6-T1&5P*"1N86UE
M+"!F86QS92P@)'5R:2P@9F%L<V4L(&9A;'-E+"!F86QS92P@9F%L<V4L#0H@
M("`@("`@("`@("`D<')O=FED97-E>'1E;G-I;VXL("1N;V1E9F%U;'0I.PT*
M("`@("`@("!R971U<FX@)'1H:7,M/E]A9&1'<F]U<$1E<&5N9&5N8WDH)'1Y
M<&4L("1D97`L("1G<F]U<&YA;64I.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("`J($!P87)A;2!S=')I;F<@9W)O=7`@;F%M92`H;75S="!B92!P<F4M97AI
M<W1I;F<I#0H@("`@("H@0'!A<F%M('-T<FEN9R!E>'1E;G-I;VX@;F%M90T*
M("`@("`J($!P87)A;2!S=')I;F<@;6EN:6UU;2!V97)S:6]N(&%L;&]W960-
M"B`@("`@*B!`<&%R86T@<W1R:6YG(&UA>&EM=6T@=F5R<VEO;B!A;&QO=V5D
M#0H@("`@("H@0'!A<F%M('-T<FEN9R!R96-O;6UE;F1E9"!V97)S:6]N#0H@
M("`@("H@0'!A<F%M(&%R<F%Y(&EN8V]M<&%T:6)L92!V97)S:6]N<PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N(&%D9$=R;W5P17AT96YS:6]N1&5P*"1G<F]U
M<&YA;64L("1N86UE+"`D;6EN(#T@9F%L<V4L("1M87@@/2!F86QS92P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E8V]M
M;65N9&5D(#T@9F%L<V4L("1E>&-L=61E(#T@9F%L<V4I#0H@("`@>PT*("`@
M("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@("`D9&5P(#T@)'1H
M:7,M/E]C;VYS=')U8W1$97`H)&YA;64L(&9A;'-E+"!F86QS92P@)&UI;BP@
M)&UA>"P@)')E8V]M;65N9&5D+"`D97AC;'5D92D[#0H@("`@("`@(')E='5R
M;B`D=&AI<RT^7V%D9$=R;W5P1&5P96YD96YC>2@G97AT96YS:6]N)RP@)&1E
M<"P@)&=R;W5P;F%M92D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A
M<F%M('!A8VMA9V5\<W5B<&%C:V%G97QE>'1E;G-I;VX-"B`@("`@*B!`<&%R
M86T@87)R87D@9&5P96YD96YC>2!C;VYT96YT<PT*("`@("`J($!P87)A;2!S
M=')I;F<@;F%M92!O9B!T:&4@9&5P96YD96YC>2!G<F]U<"!T;R!A9&0@=&AI
M<R!T;PT*("`@("`J($!R971U<FX@8F]O;&5A;@T*("`@("`J($!A8V-E<W,@
M<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]A9&1'<F]U<$1E<&5N
M9&5N8WDH)'1Y<&4L("1D97`L("1G<F]U<&YA;64I#0H@("`@>PT*("`@("`@
M("`D87)R(#T@87)R87DH)W-U8G!A8VMA9V4G+"`G97AT96YS:6]N)RD[#0H@
M("`@("`@(&EF("@D='EP92`A/2`G<&%C:V%G92<I('L-"B`@("`@("`@("`@
M(&%R<F%Y7W-H:69T*"1A<G(I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M='EP92`]/2`G97AT96YS:6]N)RD@>PT*("`@("`@("`@("`@87)R87E?<VAI
M9G0H)&%R<BD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I97,G75LG9W)O=7`G72DI('L-
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG
M9&5P96YD96YC:65S)UU;)V=R;W5P)UU;,%TI*2![#0H@("`@("`@("`@("`@
M("`@:68@*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE<R==6R=G
M<F]U<"==6R=A='1R:6)S)UU;)VYA;64G72`]/2`D9W)O=7!N86UE*2![#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N
M9&5N8VEE<R==6R=G<F]U<"==(#T@)'1H:7,M/E]M97)G951A9R@-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N
M9&5N8VEE<R==6R=G<F]U<"==+"`D9&5P+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1Y
M<&4@/3X@)&%R<@T*("`@("`@("`@("`@("`@("`@("`@("`@*2D[#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N
M9&5N8VEE<R==6R=G<F]U<"==(&%S("1I(#T^("1G<F]U<"D@>PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H)&=R;W5P6R=A='1R:6)S)UU;)VYA;64G72`]
M/2`D9W)O=7!N86UE*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE<R==6R=G<F]U<"==6R1I72`]("1T
M:&ES+3Y?;65R9V5486<H#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I97,G75LG9W)O=7`G75LD:5TL
M("1D97`L#0H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D='EP92`]/B`D87)R#0H@("`@("`@
M("`@("`@("`@("`@("`@("`I*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!`<&%R86T@;W!T:6]N86Q\<F5Q=6ER960-"B`@("`@*B!`<&%R86T@
M<W1R:6YG('!A8VMA9V4@;F%M90T*("`@("`J($!P87)A;2!S=')I;F<@<&%C
M:V%G92!C:&%N;F5L#0H@("`@("H@0'!A<F%M('-T<FEN9R!M:6YI;75M('9E
M<G-I;VX-"B`@("`@*B!`<&%R86T@<W1R:6YG(&UA>&EM=6T@=F5R<VEO;@T*
M("`@("`J($!P87)A;2!S=')I;F<@<F5C;VUM96YD960@=F5R<VEO;@T*("`@
M("`J($!P87)A;2!S=')I;F<@97AT96YS:6]N('1H:7,@<&%C:V%G92!P<F]V
M:61E<RP@:68@86YY#0H@("`@("H@0'!A<F%M(&)O;VP@:68@=')U92P@=&5L
M;',@=&AE(&EN<W1A;&QE<B!T;R!I9VYO<F4@=&AE(&1E9F%U;'0@;W!T:6]N
M86P@9&5P96YD96YC>2!G<F]U<`T*("`@("`J("`@("`@("`@("`@('=H96X@
M:6YS=&%L;&EN9R!T:&ES('!A8VMA9V4-"B`@("`@*B!`<&%R86T@87)R87E\
M9F%L<V4@;W!T:6]N86P@97AC;'5D960@=F5R<VEO;G,-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!A9&1086-K86=E1&5P5VET:$-H86YN96PH)'1Y<&4L("1N
M86UE+"`D8VAA;FYE;"P@)&UI;B`](&9A;'-E+"`D;6%X(#T@9F%L<V4L#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R96-O;6UE
M;F1E9"`](&9A;'-E+"`D97AC;'5D92`](&9A;'-E+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<')O=FED97-E>'1E;G-I;VX@
M/2!F86QS92P@)&YO9&5F875L="`](&9A;'-E*0T*("`@('L-"B`@("`@("`@
M)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@)&%R<B`](&%R<F%Y*"=O
M<'1I;VYA;"<L("=G<F]U<"<I.PT*("`@("`@("!I9B`H)'1Y<&4@(3T@)W)E
M<75I<F5D)RD@>PT*("`@("`@("`@("`@87)R87E?<VAI9G0H)&%R<BD[#0H@
M("`@("`@('T-"B`@("`@("`@)&1E<"`]("1T:&ES+3Y?8V]N<W1R=6-T1&5P
M*"1N86UE+"`D8VAA;FYE;"P@9F%L<V4L("1M:6XL("1M87@L("1R96-O;6UE
M;F1E9"P@)&5X8VQU9&4L#0H@("`@("`@("`@("`D<')O=FED97-E>'1E;G-I
M;VXL("1N;V1E9F%U;'0I.PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O
M(#T@)'1H:7,M/E]M97)G951A9R@D=&AI<RT^7W!A8VMA9V5);F9O+"`D9&5P
M+`T*("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@)V1E<&5N
M9&5N8VEE<R<@/3X@87)R87DH)W!R;W9I9&5S97AT96YS:6]N)RP@)W5S97-R
M;VQE)RP@)W5S97-T87-K)RP-"B`@("`@("`@("`@("`@("`@("`@)W-R8W!A
M8VMA9V4G+"`G<W)C=7)I)RP@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S
M92<L("=E>'1B:6YR96QE87-E)RP-"B`@("`@("`@("`@("`@("`@("`@)V)U
M;F1L92<L("=C:&%N9V5L;V<G*2P-"B`@("`@("`@("`@("`@("`D='EP92`]
M/B`D87)R+`T*("`@("`@("`@("`@("`@("=P86-K86=E)R`]/B!A<G)A>2@G
M<W5B<&%C:V%G92<L("=E>'1E;G-I;VXG+"`G;W,G+"`G87)C:"<I#0H@("`@
M("`@("`@("`I*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@
M;W!T:6]N86Q\<F5Q=6ER960-"B`@("`@*B!`<&%R86T@<W1R:6YG(&YA;64@
M;V8@=&AE('!A8VMA9V4-"B`@("`@*B!`<&%R86T@<W1R:6YG('5R:2!O9B!T
M:&4@<&%C:V%G90T*("`@("`J($!P87)A;2!S=')I;F<@97AT96YS:6]N('1H
M:7,@<&%C:V%G92!P<F]V:61E<RP@:68@86YY#0H@("`@("H@0'!A<F%M(&)O
M;VP@:68@=')U92P@=&5L;',@=&AE(&EN<W1A;&QE<B!T;R!I9VYO<F4@=&AE
M(&1E9F%U;'0@;W!T:6]N86P@9&5P96YD96YC>2!G<F]U<`T*("`@("`J("`@
M("`@("`@("`@('=H96X@:6YS=&%L;&EN9R!T:&ES('!A8VMA9V4-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!A9&1086-K86=E1&5P5VET:%5R:2@D='EP92P@
M)&YA;64L("1U<FDL("1P<F]V:61E<V5X=&5N<VEO;B`](&9A;'-E+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N;V1E9F%U;'0@/2!F
M86QS92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@
M("`@("`@("1A<G(@/2!A<G)A>2@G;W!T:6]N86PG+"`G9W)O=7`G*3L-"B`@
M("`@("`@:68@*"1T>7!E("$]("=R97%U:7)E9"<I('L-"B`@("`@("`@("`@
M(&%R<F%Y7W-H:69T*"1A<G(I.PT*("`@("`@("!]#0H@("`@("`@("1D97`@
M/2`D=&AI<RT^7V-O;G-T<G5C=$1E<"@D;F%M92P@9F%L<V4L("1U<FDL(&9A
M;'-E+"!F86QS92P@9F%L<V4L(&9A;'-E+`T*("`@("`@("`@("`@)'!R;W9I
M9&5S97AT96YS:6]N+"`D;F]D969A=6QT*3L-"B`@("`@("`@)'1H:7,M/E]P
M86-K86=E26YF;R`]("1T:&ES+3Y?;65R9V5486<H)'1H:7,M/E]P86-K86=E
M26YF;RP@)&1E<"P-"B`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("=D97!E;F1E;F-I97,G(#T^(&%R<F%Y*"=P<F]V:61E<V5X=&5N<VEO
M;B<L("=U<V5S<F]L92<L("=U<V5S=&%S:R<L#0H@("`@("`@("`@("`@("`@
M("`@("=S<F-P86-K86=E)RP@)W-R8W5R:2<L("=P:'!R96QE87-E)RP@)V5X
M='-R8W)E;&5A<V4G+"`G97AT8FEN<F5L96%S92<L#0H@("`@("`@("`@("`@
M("`@("`@("=B=6YD;&4G+"`G8VAA;F=E;&]G)RDL#0H@("`@("`@("`@("`@
M("`@)'1Y<&4@/3X@)&%R<BP-"B`@("`@("`@("`@("`@("`G<&%C:V%G92<@
M/3X@87)R87DH)W-U8G!A8VMA9V4G+"`G97AT96YS:6]N)RP@)V]S)RP@)V%R
M8V@G*0T*("`@("`@("`@("`@*2D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@0'!A<F%M(&]P=&EO;F%L?')E<75I<F5D(&]P=&EO;F%L+"!R97%U:7)E
M9`T*("`@("`J($!P87)A;2!S=')I;F<@<&%C:V%G92!N86UE#0H@("`@("H@
M0'!A<F%M('-T<FEN9R!P86-K86=E(&-H86YN96P-"B`@("`@*B!`<&%R86T@
M<W1R:6YG(&UI;FEM=6T@=F5R<VEO;@T*("`@("`J($!P87)A;2!S=')I;F<@
M;6%X:6UU;2!V97)S:6]N#0H@("`@("H@0'!A<F%M('-T<FEN9R!R96-O;6UE
M;F1E9"!V97)S:6]N#0H@("`@("H@0'!A<F%M(&%R<F%Y(&EN8V]M<&%T:6)L
M92!V97)S:6]N<PT*("`@("`J($!P87)A;2!B;V]L(&EF('1R=64L('1E;&QS
M('1H92!I;G-T86QL97(@=&\@:6=N;W)E('1H92!D969A=6QT(&]P=&EO;F%L
M(&1E<&5N9&5N8WD@9W)O=7`-"B`@("`@*B`@("`@("`@("`@("!W:&5N(&EN
M<W1A;&QI;F<@=&AI<R!P86-K86=E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M861D4W5B<&%C:V%G941E<%=I=&A#:&%N;F5L*"1T>7!E+"`D;F%M92P@)&-H
M86YN96PL("1M:6X@/2!F86QS92P@)&UA>"`](&9A;'-E+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5C;VUM96YD960@
M/2!F86QS92P@)&5X8VQU9&4@/2!F86QS92P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&YO9&5F875L="`](&9A;'-E*0T*
M("`@('L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@
M)&%R<B`](&%R<F%Y*"=O<'1I;VYA;"<L("=G<F]U<"<I.PT*("`@("`@("!I
M9B`H)'1Y<&4@(3T@)W)E<75I<F5D)RD@>PT*("`@("`@("`@("`@87)R87E?
M<VAI9G0H)&%R<BD[#0H@("`@("`@('T-"B`@("`@("`@)&1E<"`]("1T:&ES
M+3Y?8V]N<W1R=6-T1&5P*"1N86UE+"`D8VAA;FYE;"P@9F%L<V4L("1M:6XL
M("1M87@L("1R96-O;6UE;F1E9"P@)&5X8VQU9&4L#0H@("`@("`@("`@("`D
M;F]D969A=6QT*3L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T
M:&ES+3Y?;65R9V5486<H)'1H:7,M/E]P86-K86=E26YF;RP@)&1E<"P-"B`@
M("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=D97!E;F1E;F-I
M97,G(#T^(&%R<F%Y*"=P<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L
M("=U<V5S=&%S:R<L#0H@("`@("`@("`@("`@("`@("`@("=S<F-P86-K86=E
M)RP@)W-R8W5R:2<L("=P:'!R96QE87-E)RP@)V5X='-R8W)E;&5A<V4G+"`G
M97AT8FEN<F5L96%S92<L#0H@("`@("`@("`@("`@("`@("`@("=B=6YD;&4G
M+"`G8VAA;F=E;&]G)RDL#0H@("`@("`@("`@("`@("`@)'1Y<&4@/3X@)&%R
M<BP-"B`@("`@("`@("`@("`@("`G<W5B<&%C:V%G92<@/3X@87)R87DH)V5X
M=&5N<VEO;B<L("=O<R<L("=A<F-H)RD-"B`@("`@("`@("`@("DI.PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!O<'1I;VYA;'QR97%U:7)E
M9"!O<'1I;VYA;"P@<F5Q=6ER960-"B`@("`@*B!`<&%R86T@<W1R:6YG('!A
M8VMA9V4@;F%M90T*("`@("`J($!P87)A;2!S=')I;F<@<&%C:V%G92!U<FD@
M9F]R(&1O=VYL;V%D#0H@("`@("H@0'!A<F%M(&)O;VP@:68@=')U92P@=&5L
M;',@=&AE(&EN<W1A;&QE<B!T;R!I9VYO<F4@=&AE(&1E9F%U;'0@;W!T:6]N
M86P@9&5P96YD96YC>2!G<F]U<`T*("`@("`J("`@("`@("`@("`@('=H96X@
M:6YS=&%L;&EN9R!T:&ES('!A8VMA9V4-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!A9&13=6)P86-K86=E1&5P5VET:%5R:2@D='EP92P@)&YA;64L("1U<FDL
M("1N;V1E9F%U;'0@/2!F86QS92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?
M:7-686QI9"`](#`[#0H@("`@("`@("1A<G(@/2!A<G)A>2@G;W!T:6]N86PG
M+"`G9W)O=7`G*3L-"B`@("`@("`@:68@*"1T>7!E("$]("=R97%U:7)E9"<I
M('L-"B`@("`@("`@("`@(&%R<F%Y7W-H:69T*"1A<G(I.PT*("`@("`@("!]
M#0H@("`@("`@("1D97`@/2`D=&AI<RT^7V-O;G-T<G5C=$1E<"@D;F%M92P@
M9F%L<V4L("1U<FDL(&9A;'-E+"!F86QS92P@9F%L<V4L(&9A;'-E+"`D;F]D
M969A=6QT*3L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T:&ES
M+3Y?;65R9V5486<H)'1H:7,M/E]P86-K86=E26YF;RP@)&1E<"P-"B`@("`@
M("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=D97!E;F1E;F-I97,G
M(#T^(&%R<F%Y*"=P<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L("=U
M<V5S=&%S:R<L#0H@("`@("`@("`@("`@("`@("`@("=S<F-P86-K86=E)RP@
M)W-R8W5R:2<L("=P:'!R96QE87-E)RP@)V5X='-R8W)E;&5A<V4G+"`G97AT
M8FEN<F5L96%S92<L#0H@("`@("`@("`@("`@("`@("`@("=B=6YD;&4G+"`G
M8VAA;F=E;&]G)RDL#0H@("`@("`@("`@("`@("`@)'1Y<&4@/3X@)&%R<BP-
M"B`@("`@("`@("`@("`@("`G<W5B<&%C:V%G92<@/3X@87)R87DH)V5X=&5N
M<VEO;B<L("=O<R<L("=A<F-H)RD-"B`@("`@("`@("`@("DI.PT*("`@('T-
M"@T*("`@("\J*@T*("`@("`J($!P87)A;2!O<'1I;VYA;'QR97%U:7)E9"!O
M<'1I;VYA;"P@<F5Q=6ER960-"B`@("`@*B!`<&%R86T@<W1R:6YG(&5X=&5N
M<VEO;B!N86UE#0H@("`@("H@0'!A<F%M('-T<FEN9R!M:6YI;75M('9E<G-I
M;VX-"B`@("`@*B!`<&%R86T@<W1R:6YG(&UA>&EM=6T@=F5R<VEO;@T*("`@
M("`J($!P87)A;2!S=')I;F<@<F5C;VUM96YD960@=F5R<VEO;@T*("`@("`J
M($!P87)A;2!A<G)A>2!I;F-O;7!A=&EB;&4@=F5R<VEO;G,-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!A9&1%>'1E;G-I;VY$97`H)'1Y<&4L("1N86UE+"`D
M;6EN(#T@9F%L<V4L("1M87@@/2!F86QS92P@)')E8V]M;65N9&5D(#T@9F%L
M<V4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E>&-L=61E(#T@
M9F%L<V4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*
M("`@("`@("`D87)R(#T@87)R87DH)V]P=&EO;F%L)RP@)V=R;W5P)RD[#0H@
M("`@("`@(&EF("@D='EP92`A/2`G<F5Q=6ER960G*2![#0H@("`@("`@("`@
M("!A<G)A>5]S:&EF="@D87)R*3L-"B`@("`@("`@?0T*("`@("`@("`D9&5P
M(#T@)'1H:7,M/E]C;VYS=')U8W1$97`H)&YA;64L(&9A;'-E+"!F86QS92P@
M)&UI;BP@)&UA>"P@)')E8V]M;65N9&5D+"`D97AC;'5D92D[#0H@("`@("`@
M("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^7VUE<F=E5&%G*"1T:&ES
M+3Y?<&%C:V%G94EN9F\L("1D97`L#0H@("`@("`@("`@("!A<G)A>2@-"B`@
M("`@("`@("`@("`@("`G9&5P96YD96YC:65S)R`]/B!A<G)A>2@G<')O=FED
M97-E>'1E;G-I;VXG+"`G=7-E<W)O;&4G+"`G=7-E<W1A<VLG+`T*("`@("`@
M("`@("`@("`@("`@("`G<W)C<&%C:V%G92<L("=S<F-U<FDG+"`G<&AP<F5L
M96%S92<L("=E>'1S<F-R96QE87-E)RP@)V5X=&)I;G)E;&5A<V4G+`T*("`@
M("`@("`@("`@("`@("`@("`G8G5N9&QE)RP@)V-H86YG96QO9R<I+`T*("`@
M("`@("`@("`@("`@("1T>7!E(#T^("1A<G(L#0H@("`@("`@("`@("`@("`@
M)V5X=&5N<VEO;B<@/3X@87)R87DH)V]S)RP@)V%R8V@G*0T*("`@("`@("`@
M("`@*2D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN
M9R!/<&5R871I;F<@<WES=&5M(&YA;64-"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B!T<G5E(&EF('1H:7,@<&%C:V%G92!C86YN;W0@8F4@:6YS=&%L;&5D(&]N
M('1H:7,@3U,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&1/<T1E<"@D;F%M
M92P@)&-O;F9L:6-T<R`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M
M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@)&1E<"`](&%R<F%Y*"=N86UE)R`]
M/B`D;F%M92D[#0H@("`@("`@(&EF("@D8V]N9FQI8W1S*2![#0H@("`@("`@
M("`@("`D9&5P6R=C;VYF;&EC=',G72`]("<G.PT*("`@("`@("!]#0H@("`@
M("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^7VUE<F=E5&%G*"1T
M:&ES+3Y?<&%C:V%G94EN9F\L("1D97`L#0H@("`@("`@("`@("!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`G9&5P96YD96YC:65S)R`]/B!A<G)A>2@G<')O
M=FED97-E>'1E;G-I;VXG+"`G=7-E<W)O;&4G+"`G=7-E<W1A<VLG+`T*("`@
M("`@("`@("`@("`@("`@("`G<W)C<&%C:V%G92<L("=S<F-U<FDG+"`G<&AP
M<F5L96%S92<L("=E>'1S<F-R96QE87-E)RP@)V5X=&)I;G)E;&5A<V4G+`T*
M("`@("`@("`@("`@("`@("`@("`G8G5N9&QE)RP@)V-H86YG96QO9R<I+`T*
M("`@("`@("`@("`@("`@("=R97%U:7)E9"<@/3X@87)R87DH)V]P=&EO;F%L
M)RP@)V=R;W5P)RDL#0H@("`@("`@("`@("`@("`@)V]S)R`]/B!A<G)A>2@G
M87)C:"<I#0H@("`@("`@("`@("`I*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!`<&%R86T@<W1R:6YG($%R8VAI=&5C='5R92!M871C:&EN9R!P871T
M97)N#0H@("`@("H@0'!A<F%M(&)O;VQE86X@=')U92!I9B!T:&ES('!A8VMA
M9V4@8V%N;F]T(&)E(&EN<W1A;&QE9"!O;B!T:&ES(&%R8VAI=&5C='5R90T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$%R8VA$97`H)'!A='1E<FXL("1C
M;VYF;&EC=',@/2!F86QS92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?:7-6
M86QI9"`](#`[#0H@("`@("`@("1D97`@/2!A<G)A>2@G<&%T=&5R;B<@/3X@
M)'!A='1E<FXI.PT*("`@("`@("!I9B`H)&-O;F9L:6-T<RD@>PT*("`@("`@
M("`@("`@)&1E<%LG8V]N9FQI8W1S)UT@/2`G)SL-"B`@("`@("`@?0T*("`@
M("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]M97)G951A9R@D
M=&AI<RT^7W!A8VMA9V5);F9O+"`D9&5P+`T*("`@("`@("`@("`@87)R87DH
M#0H@("`@("`@("`@("`@("`@)V1E<&5N9&5N8VEE<R<@/3X@87)R87DH)W!R
M;W9I9&5S97AT96YS:6]N)RP@)W5S97-R;VQE)RP@)W5S97-T87-K)RP-"B`@
M("`@("`@("`@("`@("`@("`@)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP@)W!H
M<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L("=E>'1B:6YR96QE87-E)RP-
M"B`@("`@("`@("`@("`@("`@("`@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P-
M"B`@("`@("`@("`@("`@("`G<F5Q=6ER960G(#T^(&%R<F%Y*"=O<'1I;VYA
M;"<L("=G<F]U<"<I+`T*("`@("`@("`@("`@("`@("=A<F-H)R`]/B!A<G)A
M>2@I#0H@("`@("`@("`@("`I*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!3970@=&AE(&MI;F0@;V8@<&%C:V%G92P@86YD(&5R87-E(&%L;"!R96QE
M87-E('1A9W,-"B`@("`@*@T*("`@("`J("T@82!P:'`@<&%C:V%G92!I<R!A
M(%!%05(M<W1Y;&4@<&%C:V%G90T*("`@("`J("T@86X@97AT8FEN('!A8VMA
M9V4@:7,@82!014-,+7-T>6QE(&5X=&5N<VEO;B!B:6YA<GD-"B`@("`@*B`M
M(&%N(&5X='-R8R!P86-K86=E(&ES(&$@4$5#3"US='EL92!S;W5R8V4@9F]R
M(&$@8FEN87)Y#0H@("`@("H@+2!A(&)U;F1L92!P86-K86=E(&ES(&$@8V]L
M;&5C=&EO;B!O9B!O=&AE<B!P<F4M<&%C:V%G960@<&%C:V%G97,-"B`@("`@
M*B!`<&%R86T@<&AP?&5X=&)I;GQE>'1S<F-\8G5N9&QE#0H@("`@("H@0')E
M='5R;B!B;V]L('-U8V-E<W,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S9710
M86-K86=E5'EP92@D='EP92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?:7-6
M86QI9"`](#`[#0H@("`@("`@(&EF("@A:6Y?87)R87DH)'1Y<&4L(&%R<F%Y
M*"=P:'`G+"`G97AT8FEN)RP@)V5X='-R8R<L("=B=6YD;&4G*2DI('L-"B`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H)'1Y<&4@(3T@)V)U;F1L92<I('L-"B`@("`@("`@("`@("1T>7!E("X]
M("=R96QE87-E)SL-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("AA<G)A
M>2@G<&AP<F5L96%S92<L("=E>'1B:6YR96QE87-E)RP@)V5X='-R8W)E;&5A
M<V4G+"`G8G5N9&QE)RD@87,@)'1E<W0I('L-"B`@("`@("`@("`@('5N<V5T
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)'1E<W1=*3L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)'1Y<&5=*2D@
M>PT*("`@("`@("`@("`@+R\@96YS=7)E('1H870@=&AE(')E;&5A<V4@=&%G
M(&ES('-E="!U<`T*("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]
M("1T:&ES+3Y?:6YS97)T0F5F;W)E*"1T:&ES+3Y?<&%C:V%G94EN9F\L(&%R
M<F%Y*"=C:&%N9V5L;V<G*2P-"B`@("`@("`@("`@("`@("!A<G)A>2@I+"`D
M='EP92D[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF
M;ULD='EP95T@/2!A<G)A>2@I.PT*("`@("`@("!R971U<FX@=')U93L-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N(&)O;VP@=')U92!I9B!P
M86-K86=E('1Y<&4@:7,@<V5T('5P#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M861D4F5L96%S92@I#0H@("`@>PT*("`@("`@("!I9B`H)'1Y<&4@/2`D=&AI
M<RT^9V5T4&%C:V%G951Y<&4H*2D@>PT*("`@("`@("`@("`@:68@*"1T>7!E
M("$]("=B=6YD;&4G*2![#0H@("`@("`@("`@("`@("`@)'1Y<&4@+CT@)W)E
M;&5A<V4G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1H:7,M/E]P
M86-K86=E26YF;R`]("1T:&ES+3Y?;65R9V5486<H)'1H:7,M/E]P86-K86=E
M26YF;RP@87)R87DH*2P-"B`@("`@("`@("`@("`@("!A<G)A>2@D='EP92`]
M/B!A<G)A>2@G8VAA;F=E;&]G)RDI*3L-"B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(&-U<G)E;G0@<F5L96%S92!T
M86<@:6X@;W)D97(@=&\@861D('1O(&ET#0H@("`@("H@0'!A<F%M(&)O;VP@
M<F5T=7)N<R!O;FQY(')E;&5A<V5S('1H870@:&%V92!I;G-T86QL8V]N9&ET
M:6]N(&EF('1R=64-"B`@("`@*B!`<F5T=7)N(&%R<F%Y?&YU;&P-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B`F7V=E=$-U<G)E;G1296QE87-E*"1S=')I8W0@
M/2!T<G5E*0T*("`@('L-"B`@("`@("`@:68@*"1P(#T@)'1H:7,M/F=E=%!A
M8VMA9V54>7!E*"DI('L-"B`@("`@("`@("`@(&EF("@D<W1R:6-T*2![#0H@
M("`@("`@("`@("`@("`@:68@*"1P(#T]("=E>'1S<F,G*2![#0H@("`@("`@
M("`@("`@("`@("`@("1A(#T@;G5L;#L-"B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1A.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&EF("@D<"`A/2`G8G5N9&QE)RD@>PT*("`@("`@("`@
M("`@("`@("1P("X]("=R96QE87-E)SL-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R1P75LP72DI
M('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF
M;ULD<%U;8V]U;G0H)'1H:7,M/E]P86-K86=E26YF;ULD<%TI("T@,5T[#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7W!A8VMA9V5);F9O6R1P73L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("1A(#T@;G5L;#L-"B`@("`@("`@
M("`@(')E='5R;B`D83L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*
M("`@("`J($%D9"!A(&9I;&4@=&\@=&AE(&-U<G)E;G0@<F5L96%S92!T:&%T
M('-H;W5L9"!B92!I;G-T86QL960@=6YD97(@82!D:69F97)E;G0@;F%M90T*
M("`@("`J($!P87)A;2!S=')I;F<@/&-O;G1E;G1S/B!P871H('1O(&9I;&4-
M"B`@("`@*B!`<&%R86T@<W1R:6YG(&YA;64@=&AE(&9I;&4@<VAO=6QD(&)E
M(&EN<W1A;&QE9"!A<PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$EN<W1A
M;&Q!<R@D<&%T:"P@)&%S*0T*("`@('L-"B`@("`@("`@)'(@/2`F)'1H:7,M
M/E]G971#=7)R96YT4F5L96%S92@I.PT*("`@("`@("!I9B`H)'(@/3T](&YU
M;&PI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*
M("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@("`D<B`]("1T
M:&ES+3Y?;65R9V5486<H)'(L(&%R<F%Y*"=A='1R:6)S)R`]/B!A<G)A>2@G
M;F%M92<@/3X@)'!A=&@L("=A<R<@/3X@)&%S*2DL#0H@("`@("`@("`@("!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`G9FEL96QI<W0G(#T^(&%R<F%Y*"DL
M#0H@("`@("`@("`@("`@("`@)VEN<W1A;&PG(#T^(&%R<F%Y*"=I9VYO<F4G
M*0T*("`@("`@("`@("`@*2D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M061D(&$@9FEL92!T;R!T:&4@8W5R<F5N="!R96QE87-E('1H870@<VAO=6QD
M(&)E(&EG;F]R960-"B`@("`@*B!`<&%R86T@<W1R:6YG(#QC;VYT96YT<SX@
M<&%T:"!T;R!F:6QE#0H@("`@("H@0')E='5R;B!B;V]L('-U8V-E<W,@;V8@
M;W!E<F%T:6]N#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D26=N;W)E*"1P
M871H*0T*("`@('L-"B`@("`@("`@)'(@/2`F)'1H:7,M/E]G971#=7)R96YT
M4F5L96%S92@I.PT*("`@("`@("!I9B`H)'(@/3T](&YU;&PI('L-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D=&AI
M<RT^7VES5F%L:60@/2`P.PT*("`@("`@("`D<B`]("1T:&ES+3Y?;65R9V54
M86<H)'(L(&%R<F%Y*"=A='1R:6)S)R`]/B!A<G)A>2@G;F%M92<@/3X@)'!A
M=&@I*2P-"B`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=F
M:6QE;&ES="<@/3X@87)R87DH*2P-"B`@("`@("`@("`@("`@("`G:6=N;W)E
M)R`]/B!A<G)A>2@I#0H@("`@("`@("`@("`I*3L-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!!9&0@86X@97AT96YS:6]N(&)I;F%R>2!P86-K86=E(&9O
M<B!T:&ES(&5X=&5N<VEO;B!S;W5R8V4@8V]D92!R96QE87-E#0H@("`@("H-
M"B`@("`@*B!.;W1E('1H870@=&AE('!A8VMA9V4@;75S="!B92!F<F]M('1H
M92!S86UE(&-H86YN96P@87,@=&AE(&5X=&5N<VEO;B!S;W5R8V4@<&%C:V%G
M90T*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!A9&1":6YA<GEP86-K86=E*"1P86-K86=E*0T*("`@('L-"B`@("`@("`@
M:68@*"1T:&ES+3YG971086-K86=E5'EP92@I("$]("=E>'1S<F,G*2![#0H@
M("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@
M)'(@/2`F)'1H:7,M/E]G971#=7)R96YT4F5L96%S92AF86QS92D[#0H@("`@
M("`@(&EF("@D<B`]/3T@;G5L;"D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[
M#0H@("`@("`@("1R(#T@)'1H:7,M/E]M97)G951A9R@D<BP@)'!A8VMA9V4L
M#0H@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`G8FEN87)Y
M<&%C:V%G92<@/3X@87)R87DH)V9I;&5L:7-T)RDL#0H@("`@("`@("`@("`I
M*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!!9&0@82!C;VYF:6=U<F5O
M<'1I;VX@=&\@86X@97AT96YS:6]N('-O=7)C92!P86-K86=E#0H@("`@("H@
M0'!A<F%M('-T<FEN9PT*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B!`
M<&%R86T@<W1R:6YG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D0V]N9FEG
M=7)E3W!T:6]N*"1N86UE+"`D<')O;7!T+"`D9&5F875L="`](&YU;&PI#0H@
M("`@>PT*("`@("`@("!I9B`H)'1H:7,M/F=E=%!A8VMA9V54>7!E*"D@(3T@
M)V5X='-R8R<I('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@?0T*("`@("`@("`D<B`]("8D=&AI<RT^7V=E=$-U<G)E;G1296QE87-E
M*&9A;'-E*3L-"B`@("`@("`@:68@*"1R(#T]/2!N=6QL*2![#0H@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)&]P="`]
M(&%R<F%Y*"=A='1R:6)S)R`]/B!A<G)A>2@G;F%M92<@/3X@)&YA;64L("=P
M<F]M<'0G(#T^("1P<F]M<'0I*3L-"B`@("`@("`@:68@*"1D969A=6QT("$]
M/2!N=6QL*2![#0H@("`@("`@("`@("`D;W!T6R=D969A=6QT)UT@/2`D9&5F
M875L=#L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P
M.PT*("`@("`@("`D<B`]("1T:&ES+3Y?;65R9V5486<H)'(L("1O<'0L#0H@
M("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`G8V]N9FEG=7)E
M;W!T:6]N)R`]/B!A<G)A>2@G8FEN87)Y<&%C:V%G92<L("=F:6QE;&ES="<I
M+`T*("`@("`@("`@("`@*2D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M4V5T(&%N(&EN<W1A;&QA=&EO;B!C;VYD:71I;VX@8F%S960@;VX@<&AP('9E
M<G-I;VX@9F]R('1H92!C=7)R96YT(')E;&5A<V4@<V5T#0H@("`@("H@0'!A
M<F%M('-T<FEN9R!M:6YI;75M('9E<G-I;VX-"B`@("`@*B!`<&%R86T@<W1R
M:6YG(&UA>&EM=6T@=F5R<VEO;@T*("`@("`J($!P87)A;2!F86QS97QA<G)A
M>2!I;F-O;7!A=&EB;&4@=F5R<VEO;G,@;V8@4$A0#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@<V5T4&AP26YS=&%L;$-O;F1I=&EO;B@D;6EN+"`D;6%X+"`D
M97AC;'5D92`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)'(@/2`F)'1H:7,M
M/E]G971#=7)R96YT4F5L96%S92@I.PT*("`@("`@("!I9B`H)'(@/3T](&YU
M;&PI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*
M("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@("!I9B`H:7-S
M970H)');)VEN<W1A;&QC;VYD:71I;VYS)UU;)W!H<"==*2D@>PT*("`@("`@
M("`@("`@=6YS970H)');)VEN<W1A;&QC;VYD:71I;VYS)UU;)W!H<"==*3L-
M"B`@("`@("`@?0T*("`@("`@("`D9&5P(#T@87)R87DH)VUI;B<@/3X@)&UI
M;BP@)VUA>"<@/3X@)&UA>"D[#0H@("`@("`@(&EF("@D97AC;'5D92D@>PT*
M("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1E>&-L=61E*2`F)B!C;W5N="@D
M97AC;'5D92D@/3T@,2D@>PT*("`@("`@("`@("`@("`@("1E>&-L=61E(#T@
M)&5X8VQU9&5;,%T[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D9&5P
M6R=E>&-L=61E)UT@/2`D97AC;'5D93L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H)'1H:7,M/F=E=%!A8VMA9V54>7!E*"D@/3T@)V5X='-R8R<I('L-"B`@
M("`@("`@("`@("1R(#T@)'1H:7,M/E]M97)G951A9R@D<BP@)&1E<"P-"B`@
M("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)VEN
M<W1A;&QC;VYD:71I;VYS)R`]/B!A<G)A>2@G8V]N9FEG=7)E;W!T:6]N)RP@
M)V)I;F%R>7!A8VMA9V4G+`T*("`@("`@("`@("`@("`@("`@("`@("`@)V9I
M;&5L:7-T)RDL#0H@("`@("`@("`@("`@("`@("`@("=P:'`G(#T^(&%R<F%Y
M*"=E>'1E;G-I;VXG+"`G;W,G+"`G87)C:"<I#0H@("`@("`@("`@("`@("`@
M*2D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D<B`]("1T:&ES
M+3Y?;65R9V5486<H)'(L("1D97`L#0H@("`@("`@("`@("`@("`@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`@("=I;G-T86QL8V]N9&ET:6]N<R<@/3X@
M87)R87DH)V9I;&5L:7-T)RDL#0H@("`@("`@("`@("`@("`@("`@("=P:'`G
M(#T^(&%R<F%Y*"=E>'1E;G-I;VXG+"`G;W,G+"`G87)C:"<I#0H@("`@("`@
M("`@("`@("`@*2D[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!`<&%R86T@;W!T:6]N86Q\<F5Q=6ER960@;W!T:6]N86PL(')E<75I
M<F5D#0H@("`@("H@0'!A<F%M('-T<FEN9R!E>'1E;G-I;VX@;F%M90T*("`@
M("`J($!P87)A;2!S=')I;F<@;6EN:6UU;2!V97)S:6]N#0H@("`@("H@0'!A
M<F%M('-T<FEN9R!M87AI;75M('9E<G-I;VX-"B`@("`@*B!`<&%R86T@<W1R
M:6YG(')E8V]M;65N9&5D('9E<G-I;VX-"B`@("`@*B!`<&%R86T@87)R87D@
M:6YC;VUP871I8FQE('9E<G-I;VYS#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M861D17AT96YS:6]N26YS=&%L;$-O;F1I=&EO;B@D;F%M92P@)&UI;B`](&9A
M;'-E+"`D;6%X(#T@9F%L<V4L("1R96-O;6UE;F1E9"`](&9A;'-E+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5X8VQU
M9&4@/2!F86QS92D-"B`@("![#0H@("`@("`@("1R(#T@)B1T:&ES+3Y?9V5T
M0W5R<F5N=%)E;&5A<V4H*3L-"B`@("`@("`@:68@*"1R(#T]/2!N=6QL*2![
M#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@
M("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@)&1E<"`]("1T:&ES
M+3Y?8V]N<W1R=6-T1&5P*"1N86UE+"!F86QS92P@9F%L<V4L("1M:6XL("1M
M87@L("1R96-O;6UE;F1E9"P@)&5X8VQU9&4I.PT*("`@("`@("!I9B`H)'1H
M:7,M/F=E=%!A8VMA9V54>7!E*"D@/3T@)V5X='-R8R<I('L-"B`@("`@("`@
M("`@("1R(#T@)'1H:7,M/E]M97)G951A9R@D<BP@)&1E<"P-"B`@("`@("`@
M("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)VEN<W1A;&QC
M;VYD:71I;VYS)R`]/B!A<G)A>2@G8V]N9FEG=7)E;W!T:6]N)RP@)V)I;F%R
M>7!A8VMA9V4G+`T*("`@("`@("`@("`@("`@("`@("`@("`@)V9I;&5L:7-T
M)RDL#0H@("`@("`@("`@("`@("`@("`@("=E>'1E;G-I;VXG(#T^(&%R<F%Y
M*"=O<R<L("=A<F-H)RD-"B`@("`@("`@("`@("`@("`I*3L-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("1R(#T@)'1H:7,M/E]M97)G951A9R@D
M<BP@)&1E<"P-"B`@("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`@("`@)VEN<W1A;&QC;VYD:71I;VYS)R`]/B!A<G)A>2@G9FEL96QI
M<W0G*2P-"B`@("`@("`@("`@("`@("`@("`@)V5X=&5N<VEO;B<@/3X@87)R
M87DH)V]S)RP@)V%R8V@G*0T*("`@("`@("`@("`@("`@("DI.PT*("`@("`@
M("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4V5T(&%N(&EN<W1A;&QA
M=&EO;B!C;VYD:71I;VX@8F%S960@;VX@;W!E<F%T:6YG('-Y<W1E;2!F;W(@
M=&AE(&-U<G)E;G0@<F5L96%S92!S970-"B`@("`@*B!`<&%R86T@<W1R:6YG
M($]3(&YA;64-"B`@("`@*B!`<&%R86T@8F]O;"!W:&5T:&5R('1H:7,@3U,@
M:7,@:6YC;VUP871I8FQE('=I=&@@=&AE(&-U<G)E;G0@<F5L96%S90T*("`@
M("`J+PT*("`@(&9U;F-T:6]N('-E=$]S26YS=&%L;$-O;F1I=&EO;B@D;F%M
M92P@)&-O;F9L:6-T<R`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)'(@/2`F
M)'1H:7,M/E]G971#=7)R96YT4F5L96%S92@I.PT*("`@("`@("!I9B`H)'(@
M/3T](&YU;&PI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@?0T*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@("!I
M9B`H:7-S970H)');)VEN<W1A;&QC;VYD:71I;VYS)UU;)V]S)UTI*2![#0H@
M("`@("`@("`@("!U;G-E="@D<ELG:6YS=&%L;&-O;F1I=&EO;G,G75LG;W,G
M72D[#0H@("`@("`@('T-"B`@("`@("`@)&1E<"`](&%R<F%Y*"=N86UE)R`]
M/B`D;F%M92D[#0H@("`@("`@(&EF("@D8V]N9FQI8W1S*2![#0H@("`@("`@
M("`@("`D9&5P6R=C;VYF;&EC=',G72`]("<G.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("@D=&AI<RT^9V5T4&%C:V%G951Y<&4H*2`]/2`G97AT<W)C)RD@
M>PT*("`@("`@("`@("`@)'(@/2`D=&AI<RT^7VUE<F=E5&%G*"1R+"`D9&5P
M+`T*("`@("`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@
M("`G:6YS=&%L;&-O;F1I=&EO;G,G(#T^(&%R<F%Y*"=C;VYF:6=U<F5O<'1I
M;VXG+"`G8FEN87)Y<&%C:V%G92<L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`G9FEL96QI<W0G*2P-"B`@("`@("`@("`@("`@("`@("`@)V]S)R`]/B!A
M<G)A>2@G87)C:"<I#0H@("`@("`@("`@("`@("`@*2D[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`D<B`]("1T:&ES+3Y?;65R9V5486<H)'(L
M("1D97`L#0H@("`@("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`@("=I;G-T86QL8V]N9&ET:6]N<R<@/3X@87)R87DH)V9I;&5L:7-T
M)RDL#0H@("`@("`@("`@("`@("`@("`@("=O<R<@/3X@87)R87DH)V%R8V@G
M*0T*("`@("`@("`@("`@("`@("DI.PT*("`@("`@("!]#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@4V5T(&%N(&EN<W1A;&QA=&EO;B!C;VYD:71I;VX@
M8F%S960@;VX@87)C:&ET96-T=7)E(&9O<B!T:&4@8W5R<F5N="!R96QE87-E
M('-E=`T*("`@("`J($!P87)A;2!S=')I;F<@87)C:&ET96-T=7)E('!A='1E
M<FX-"B`@("`@*B!`<&%R86T@8F]O;"!W:&5T:&5R('1H:7,@87)C:"!I<R!I
M;F-O;7!A=&EB;&4@=VET:"!T:&4@8W5R<F5N="!R96QE87-E#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@<V5T07)C:$EN<W1A;&Q#;VYD:71I;VXH)'!A='1E
M<FXL("1C;VYF;&EC=',@/2!F86QS92D-"B`@("![#0H@("`@("`@("1R(#T@
M)B1T:&ES+3Y?9V5T0W5R<F5N=%)E;&5A<V4H*3L-"B`@("`@("`@:68@*"1R
M(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@('T-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@
M:68@*&ES<V5T*"1R6R=I;G-T86QL8V]N9&ET:6]N<R==6R=A<F-H)UTI*2![
M#0H@("`@("`@("`@("!U;G-E="@D<ELG:6YS=&%L;&-O;F1I=&EO;G,G75LG
M87)C:"==*3L-"B`@("`@("`@?0T*("`@("`@("`D9&5P(#T@87)R87DH)W!A
M='1E<FXG(#T^("1P871T97)N*3L-"B`@("`@("`@:68@*"1C;VYF;&EC=',I
M('L-"B`@("`@("`@("`@("1D97!;)V-O;F9L:6-T<R==(#T@)R<[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"1T:&ES+3YG971086-K86=E5'EP92@I(#T]
M("=E>'1S<F,G*2![#0H@("`@("`@("`@("`D<B`]("1T:&ES+3Y?;65R9V54
M86<H)'(L("1D97`L#0H@("`@("`@("`@("`@("`@87)R87DH#0H@("`@("`@
M("`@("`@("`@("`@("=I;G-T86QL8V]N9&ET:6]N<R<@/3X@87)R87DH)V-O
M;F9I9W5R96]P=&EO;B<L("=B:6YA<GEP86-K86=E)RP-"B`@("`@("`@("`@
M("`@("`@("`@("`@("=F:6QE;&ES="<I+`T*("`@("`@("`@("`@("`@("`@
M("`G87)C:"<@/3X@87)R87DH*0T*("`@("`@("`@("`@("`@("DI.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'(@/2`D=&AI<RT^7VUE<F=E
M5&%G*"1R+"`D9&5P+`T*("`@("`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("`@("`G:6YS=&%L;&-O;F1I=&EO;G,G(#T^(&%R<F%Y*"=F
M:6QE;&ES="<I+`T*("`@("`@("`@("`@("`@("`@("`G87)C:"<@/3X@87)R
M87DH*0T*("`@("`@("`@("`@("`@("DI.PT*("`@("`@("!]#0H@("`@?0T*
M#0H@("`@+RHJ#0H@("`@("H@1F]R(&5X=&5N<VEO;B!B:6YA<GD@<F5L96%S
M97,L('1H:7,@:7,@=7-E9"!T;R!S<&5C:69Y(&5I=&AE<B!T:&4-"B`@("`@
M*B!S=&%T:6,@55))('1O(&$@<V]U<F-E('!A8VMA9V4L(&]R('1H92!P86-K
M86=E(&YA;64@86YD(&-H86YN96P@;V8@=&AE(&5X='-R8PT*("`@("`J('!A
M8VMA9V4@:70@:7,@8F%S960@;VXN#0H@("`@("H@0'!A<F%M('-T<FEN9R!0
M86-K86=E(&YA;64L(&]R(&9U;&P@55))('1O('-O=7)C92!P86-K86=E("AE
M>'1S<F,@='EP92D-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S9713;W5R8V50
M86-K86=E*"1P86-K86=E3W)5<FDI#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M7VES5F%L:60@/2`P.PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K
M86=E26YF;ULG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]P
M86-K86=E26YF;R`]("1T:&ES+3Y?:6YS97)T0F5F;W)E*"1T:&ES+3Y?<&%C
M:V%G94EN9F\L(&%R<F%Y*"=P:'!R96QE87-E)RP-"B`@("`@("`@("`@("`@
M("`G97AT<W)C<F5L96%S92<L("=E>'1B:6YR96QE87-E)RP@)V)U;F1L92<L
M("=C:&%N9V5L;V<G*2P-"B`@("`@("`@("`@("`@("`D<&%C:V%G94]R57)I
M+"`G<W)C<&%C:V%G92<I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?:6YS97)T0F5F;W)E
M*"1T:&ES+3Y?<&%C:V%G94EN9F\L(&%R<F%Y*"=P:'!R96QE87-E)RP-"B`@
M("`@("`@("`@("`@("`G97AT<W)C<F5L96%S92<L("=E>'1B:6YR96QE87-E
M)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P@)'!A8VMA9V5/<E5R:2P@)W-R
M8W5R:2<I.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M1V5N97)A=&4@82!V86QI9"!C:&%N9V4@;&]G(&5N=')Y(&9R;VT@=&AE(&-U
M<G)E;G0@<&%C:V%G92YX;6P-"B`@("`@*B!`<&%R86T@<W1R:6YG?&9A;'-E
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5N97)A=&5#:&%N9V5,;V=%;G1R
M>2@D;F]T97,@/2!F86QS92D-"B`@("![#0H@("`@("`@(')E='5R;B!A<G)A
M>2@-"B`@("`@("`@("`@("=V97)S:6]N)R`]/B`-"B`@("`@("`@("`@("`@
M("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W)E;&5A<V4G(#T^("1T
M:&ES+3YG971697)S:6]N*"=R96QE87-E)RDL#0H@("`@("`@("`@("`@("`@
M("`@("=A<&DG(#T^("1T:&ES+3YG971697)S:6]N*"=A<&DG*2P-"B`@("`@
M("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("=S=&%B:6QI='DG(#T^
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/F=E=%-T86)I;&ET>2@I+`T*("`@
M("`@("`@("`@)V1A=&4G(#T^("1T:&ES+3YG971$871E*"DL#0H@("`@("`@
M("`@("`G;&EC96YS92<@/3X@)'1H:7,M/F=E=$QI8V5N<V4H=')U92DL#0H@
M("`@("`@("`@("`G;F]T97,G(#T^("1N;W1E<R`_("1N;W1E<R`Z("1T:&ES
M+3YG971.;W1E<R@I#0H@("`@("`@("`@("`I.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J($!P87)A;2!S=')I;F<@<F5L96%S92!V97)S:6]N('1O('-E
M="!C:&%N9V4@;&]G(&YO=&5S(&9O<@T*("`@("`J($!P87)A;2!A<G)A>2!O
M=71P=70@;V8@>T!L:6YK(&=E;F5R871E0VAA;F=E3&]G16YT<GDH*7T-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!S971#:&%N9V5L;V=%;G1R>2@D<F5L96%S
M979E<G-I;VXL("1C;VYT96YT<RD-"B`@("![#0H@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]P86-K86=E26YF;ULG8VAA;F=E;&]G)UTI*2![#0H@("`@
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N9V5L;V<G75LG<F5L
M96%S92==(#T@)&-O;G1E;G1S.PT*("`@("`@("`@("`@<F5T=7)N.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF
M;ULG8VAA;F=E;&]G)UU;)W)E;&5A<V4G75LP72DI('L-"B`@("`@("`@("`@
M(&EF("@D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N9V5L;V<G75LG<F5L96%S
M92==6R=V97)S:6]N)UU;)W)E;&5A<V4G72`]/2`D<F5L96%S979E<G-I;VXI
M('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N
M9V5L;V<G75LG<F5L96%S92==(#T@87)R87DH#0H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V-H86YG96QO9R==6R=R96QE87-E
M)UTI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N9V5L;V<G75LG<F5L96%S92==(#T@
M87)R87DH#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN
M9F];)V-H86YG96QO9R==6R=R96QE87-E)UTI.PT*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N9V5L;V<G75LG<F5L
M96%S92==6UT@/2`D8V]N=&5N=',[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@9F]R96%C:"@D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N
M9V5L;V<G75LG<F5L96%S92==(&%S("1I;F1E>"`]/B`D8VAA;F=E;&]G*2![
M#0H@("`@("`@("`@("!I9B`H:7-S970H)&-H86YG96QO9ULG=F5R<VEO;B==
M*2`F)@T*("`@("`@("`@("`@("`@("`@<W1R;F%T8V%S96-M<"@D8VAA;F=E
M;&]G6R=V97)S:6]N)UU;)W)E;&5A<V4G72P@)')E;&5A<V5V97)S:6]N*2`]
M/2`P*2![#0H@("`@("`@("`@("`@("`@)&-U<FQO9R`]("1I;F1E>#L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&-U
M<FQO9RDI('L-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V-H
M86YG96QO9R==6R=R96QE87-E)UU;)&-U<FQO9UT@/2`D8V]N=&5N=',[#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=C:&%N9V5L;V<G75LG<F5L96%S92==6UT@/2`D8V]N=&5N=',[#0H@
M("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!296UO=F4@=&AE
M(&-H86YG96QO9R!E;G1I<F5L>0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&-L
M96%R0VAA;F=E3&]G*"D-"B`@("![#0H@("`@("`@('5N<V5T*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)V-H86YG96QO9R==*3L-"B`@("!]#0I]#0H_/@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M4$5!4B]086-K86=E1FEL92]V,B]686QI9&%T;W(N<&AP````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`R,S8U-C<`,3`U,34T,S,W-#``,#(T-#<S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP#0HO+PT*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\(%!(4"!697)S:6]N
M(#4@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PT*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-"!4:&4@4$A0($=R;W5P
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I
M<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS92P@
M("`@("`@?`T*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA
M9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\#0HO+R!\
M(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@
M9F]L;&]W:6YG('5R;#H@("`@("`@("`@('P-"B\O('P@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`T*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\
M#0HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@
M<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P-"B\O('P@;&EC96YS
M94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E
M;'DN("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK#0HO+R!\($%U=&AO<CH@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N
M;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK#0HO+PT*+R\@)$ED.B!686QI9&%T;W(N<&AP+'8@,2XX
M-B`R,#`V+S`S+S`R(#$X.C$T.C$S(&-E;&QO9R!%>'`@)`T*+RHJ#0H@*B!0
M<FEV871E('9A;&ED871I;VX@8VQA<W,@=7-E9"!B>2!014%27U!A8VMA9V5&
M:6QE7W8R("T@9&\@;F]T('5S92!D:7)E8W1L>2P@:71S#0H@*B!S;VQE('!U
M<G!O<V4@:7,@=&\@<W!L:70@=7`@=&AE(%!%05(O4&%C:V%G949I;&4O=C(N
M<&AP(&9I;&4@=&\@;6%K92!I="!S;6%L;&5R#0H@*B!`875T:&]R($=R96<@
M0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!A8V-E<W,@<')I=F%T90T*
M("HO#0IC;&%S<R!014%27U!A8VMA9V5&:6QE7W8R7U9A;&ED871O<@T*>PT*
M("`@("\J*@T*("`@("`J($!V87(@87)R87D-"B`@("`@*B\-"B`@("!V87(@
M)%]P86-K86=E26YF;SL-"B`@("`O*BH-"B`@("`@*B!`=F%R(%!%05)?4&%C
M:V%G949I;&5?=C(-"B`@("`@*B\-"B`@("!V87(@)%]P9CL-"B`@("`O*BH-
M"B`@("`@*B!`=F%R(%!%05)?17)R;W)3=&%C:PT*("`@("`J+PT*("`@('9A
M<B`D7W-T86-K.PT*("`@("\J*@T*("`@("`J($!V87(@:6YT#0H@("`@("HO
M#0H@("`@=F%R("1?:7-686QI9"`](#`[#0H@("`@+RHJ#0H@("`@("H@0'9A
M<B!I;G0-"B`@("`@*B\-"B`@("!V87(@)%]F:6QE<U9A;&ED(#T@,#L-"B`@
M("`O*BH-"B`@("`@*B!`=F%R(&EN=`T*("`@("`J+PT*("`@('9A<B`D7V-U
M<E-T871E(#T@,#L-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@4$5!4E]086-K
M86=E1FEL95]V,@T*("`@("`J($!P87)A;2!I;G0-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!V86QI9&%T92@F)'!F+"`D<W1A=&4@/2!014%27U9!3$E$051%
M7TY/4DU!3"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<&8@/2`F)'!F.PT*
M("`@("`@("`D=&AI<RT^7V-U<E-T871E(#T@)'-T871E.PT*("`@("`@("`D
M=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]P9BT^9V5T07)R87DH*3L-
M"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@)'1H:7,M/E]P9BT^7VES5F%L
M:60[#0H@("`@("`@("1T:&ES+3Y?9FEL97-686QI9"`]("1T:&ES+3Y?<&8M
M/E]F:6QE<U9A;&ED.PT*("`@("`@("`D=&AI<RT^7W-T86-K(#T@)B1P9BT^
M7W-T86-K.PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YG971%<G)O<G,H=')U
M92D[#0H@("`@("`@(&EF("@H)'1H:7,M/E]I<U9A;&ED("8@)'-T871E*2`]
M/2`D<W1A=&4I('L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;RD@
M?'P@(6ES7V%R<F%Y*"1T:&ES+3Y?<&%C:V%G94EN9F\I*2![#0H@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=A='1R:6)S)UU;)W9E<G-I;VXG
M72D@?'P-"B`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG871T
M<FEB<R==6R=V97)S:6]N)UT@(3T@)S(N,"<I('L-"B`@("`@("`@("`@("1T
M:&ES+3Y?;F]086-K86=E5F5R<VEO;B@I.PT*("`@("`@("!]#0H@("`@("`@
M("1S=')U8W1U<F4@/0T*("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("=N
M86UE)RP-"B`@("`@("`@("`@("=C:&%N;F5L?'5R:2<L#0H@("`@("`@("`@
M("`G*F5X=&5N9',G+"`O+R!C86XG="!B92!M=6QT:7!L92P@8G5T('1H:7,@
M=V]R:W,@9FEN90T*("`@("`@("`@("`@)W-U;6UA<GDG+`T*("`@("`@("`@
M("`@)V1E<V-R:7!T:6]N)RP-"B`@("`@("`@("`@("<K;&5A9"<L("\O('1H
M97-E(&%L;"!N965D(&-O;G1E;G0@8VAE8VMS#0H@("`@("`@("`@("`G*F1E
M=F5L;W!E<B<L#0H@("`@("`@("`@("`G*F-O;G1R:6)U=&]R)RP-"B`@("`@
M("`@("`@("<J:&5L<&5R)RP-"B`@("`@("`@("`@("=D871E)RP-"B`@("`@
M("`@("`@("<J=&EM92<L#0H@("`@("`@("`@("`G=F5R<VEO;B<L#0H@("`@
M("`@("`@("`G<W1A8FEL:71Y)RP-"B`@("`@("`@("`@("=L:6-E;G-E+3X_
M=7)I+3X_9FEL97-O=7)C92<L#0H@("`@("`@("`@("`G;F]T97,G+`T*("`@
M("`@("`@("`@)V-O;G1E;G1S)RP@+R]S<&5C:6%L('9A;&ED871I;VX@;F5E
M9&5D#0H@("`@("`@("`@("`G*F-O;7!A=&EB;&4G+`T*("`@("`@("`@("`@
M)V1E<&5N9&5N8VEE<R<L("\O<W!E8VEA;"!V86QI9&%T:6]N(&YE961E9`T*
M("`@("`@("`@("`@)RIU<V5S<F]L92<L#0H@("`@("`@("`@("`G*G5S97-T
M87-K)RP@+R\@<F5S97)V92!T:&5S92!F;W(@,2XT+C!A,2!T;R!I;7!L96UE
M;G0-"B`@("`@("`@("`@("`@("`@("`@("`@("`O+R!T:&ES('=I;&P@86QL
M;W<@82!P86-K86=E+GAM;"!T;R!G<F%C969U;&QY('-A>2!I=`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("\O(&YE961S(&$@8V5R=&%I;B!P86-K86=E
M(&EN<W1A;&QE9"!I;B!O<F1E<B!T;R!I;7!L96UE;G0@82!R;VQE(&]R('1A
M<VL-"B`@("`@("`@("`@("<J<')O=FED97-E>'1E;G-I;VXG+`T*("`@("`@
M("`@("`@)RIS<F-P86-K86=E?"IS<F-U<FDG+`T*("`@("`@("`@("`@)RMP
M:'!R96QE87-E?"ME>'1S<F-R96QE87-E?"ME>'1B:6YR96QE87-E?&)U;F1L
M92<L("\O<W!E8VEA;"!V86QI9&%T:6]N(&YE961E9`T*("`@("`@("`@("`@
M)RIC:&%N9V5L;V<G+`T*("`@("`@("`I.PT*("`@("`@("`D=&5S="`]("1T
M:&ES+3Y?<&%C:V%G94EN9F\[#0H@("`@("`@("\O(&EG;F]R92!P;W-T+6EN
M<W1A;&QA=&EO;B!A<G)A>2!F:65L9',-"B`@("`@("`@:68@*&%R<F%Y7VME
M>5]E>&ES=',H)V9I;&5L:7-T)RP@)'1E<W0I*2![#0H@("`@("`@("`@("!U
M;G-E="@D=&5S=%LG9FEL96QI<W0G72D[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&%R<F%Y7VME>5]E>&ES=',H)U]L87-T;6]D:69I960G+"`D=&5S="DI
M('L-"B`@("`@("`@("`@('5N<V5T*"1T97-T6R=?;&%S=&UO9&EF:65D)UTI
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"<C
M8FEN87)Y<&%C:V%G92<L("1T97-T*2D@>PT*("`@("`@("`@("`@=6YS970H
M)'1E<W1;)R-B:6YA<GEP86-K86=E)UTI.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("AA<G)A>5]K97E?97AI<W1S*"=O;&0G+"`D=&5S="DI('L-"B`@("`@
M("`@("`@('5N<V5T*"1T97-T6R=O;&0G72D[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)U]L87-T=F5R<VEO;B<L("1T97-T
M*2D@>PT*("`@("`@("`@("`@=6YS970H)'1E<W1;)U]L87-T=F5R<VEO;B==
M*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21T:&ES+3Y?<W1U<&ED4V-H
M96UA5F%L:61A=&4H)'-T<G5C='5R92P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T97-T+"`G/'!A8VMA9V4^)RDI('L-
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H96UP='DH)'1H:7,M/E]P86-K86=E26YF;ULG;F%M92==*2D@>PT*
M("`@("`@("`@("`@)'1H:7,M/E]T86=#86YN;W1"945M<'1Y*"=N86UE)RD[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)W5R:2==*2D@>PT*("`@("`@("`@("`@)'1E<W0@/2`G=7)I)SL-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T97-T(#T@)V-H86YN
M96PG.PT*("`@("`@("!]#0H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A
M8VMA9V5);F9O6R1T97-T72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?=&%G
M0V%N;F]T0F5%;7!T>2@D=&5S="D[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&ES7V%R<F%Y*"1T:&ES+3Y?<&%C:V%G94EN9F];)VQI8V5N<V4G72D@)B8-
M"B`@("`@("`@("`@("`@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=L
M:6-E;G-E)UU;)U]C;VYT96YT)UTI('Q\#0H@("`@("`@("`@("`@(&5M<'1Y
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)VQI8V5N<V4G75LG7V-O;G1E;G0G72DI
M*2![#0H@("`@("`@("`@("`D=&AI<RT^7W1A9T-A;FYO=$)E16UP='DH)VQI
M8V5N<V4G*3L-"B`@("`@("`@?2!E;'-E:68@*&5M<'1Y*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)VQI8V5N<V4G72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?
M=&%G0V%N;F]T0F5%;7!T>2@G;&EC96YS92<I.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A8VMA9V5);F9O6R=S=6UM87)Y)UTI
M*2![#0H@("`@("`@("`@("`D=&AI<RT^7W1A9T-A;FYO=$)E16UP='DH)W-U
M;6UA<GDG*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H96UP='DH)'1H:7,M
M/E]P86-K86=E26YF;ULG9&5S8W)I<'1I;VXG72DI('L-"B`@("`@("`@("`@
M("1T:&ES+3Y?=&%G0V%N;F]T0F5%;7!T>2@G9&5S8W)I<'1I;VXG*3L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P86-K86=E26YF
M;ULG9&%T92==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]T86=#86YN;W1"
M945M<'1Y*"=D871E)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*&5M<'1Y
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)VYO=&5S)UTI*2![#0H@("`@("`@("`@
M("`D=&AI<RT^7W1A9T-A;FYO=$)E16UP='DH)VYO=&5S)RD[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W1I
M;64G72D@)B8@96UP='DH)'1H:7,M/E]P86-K86=E26YF;ULG=&EM92==*2D@
M>PT*("`@("`@("`@("`@)'1H:7,M/E]T86=#86YN;W1"945M<'1Y*"=T:6UE
M)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)V1E<&5N9&5N8VEE<R==*2D@>PT*("`@("`@("`@("`@)'1H
M:7,M/E]V86QI9&%T941E<&5N9&5N8VEE<R@I.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VUP871I8FQE
M)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E0V]M<&%T:6)L
M92@I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P
M86-K86=E26YF;ULG8G5N9&QE)UTI*2![#0H@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I<B==*2D@
M>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?9FEL96QI<W1-=7-T0V]N=&%I
M;D1I<B@G8V]N=&5N=',G*3L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG9FEL92==*2D@>PT*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9FEL96QI<W1#86YN;W1#;VYT86EN1FEL
M92@G8V]N=&5N=',G*3L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]V
M86QI9&%T94UA:6YT86EN97)S*"D[#0H@("`@("`@("1T:&ES+3Y?=F%L:61A
M=&53=&%B:6QI='E697)S:6]N*"D[#0H@("`@("`@("1F86EL(#T@9F%L<V4[
M#0H@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=U<V5S<F]L92<L("1T
M:&ES+3Y?<&%C:V%G94EN9F\I*2![#0H@("`@("`@("`@("`D<F]L97,@/2`D
M=&AI<RT^7W!A8VMA9V5);F9O6R=U<V5S<F]L92==.PT*("`@("`@("`@("`@
M:68@*"%I<U]A<G)A>2@D<F]L97,I('Q\("%I<W-E="@D<F]L97-;,%TI*2![
M#0H@("`@("`@("`@("`@("`@)')O;&5S(#T@87)R87DH)')O;&5S*3L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1R;VQE<R!A<R`D
M<F]L92D@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)')O;&5;)W)O
M;&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]U<V5S<F]L
M971A<VM-=7-T2&%V95)O;&5487-K*"=U<V5S<F]L92<L("=R;VQE)RD[#0H@
M("`@("`@("`@("`@("`@("`@("1F86EL(#T@=')U93L-"B`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1R;VQE6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1R;VQE6R=U<FDG72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W5S97-R;VQE=&%S:TUU<W1(879E0VAA
M;FYE;$]R57)I*"1R;VQE6R=R;VQE)UTL("=U<V5S<F]L92<I.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1F86EL(#T@=')U93L-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M:68@*"%I<W-E="@D<F]L95LG<&%C:V%G92==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]U<V5S<F]L971A<VM-=7-T2&%V95!A8VMA
M9V4H)')O;&5;)W)O;&4G72P@)W5S97-R;VQE)RD[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D9F%I;"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)W5S97-T87-K)RP@
M)'1H:7,M/E]P86-K86=E26YF;RDI('L-"B`@("`@("`@("`@("1R;VQE<R`]
M("1T:&ES+3Y?<&%C:V%G94EN9F];)W5S97-T87-K)UT[#0H@("`@("`@("`@
M("!I9B`H(6ES7V%R<F%Y*"1R;VQE<RD@?'P@(6ES<V5T*"1R;VQE<ULP72DI
M('L-"B`@("`@("`@("`@("`@("`D<F]L97,@/2!A<G)A>2@D<F]L97,I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)')O;&5S(&%S
M("1R;VQE*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<F]L95LG
M=&%S:R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W5S97-R
M;VQE=&%S:TUU<W1(879E4F]L951A<VLH)W5S97-T87-K)RP@)W1A<VLG*3L-
M"B`@("`@("`@("`@("`@("`@("`@)&9A:6P@/2!T<G5E.PT*("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)')O;&5;)V-H86YN96PG72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)')O;&5;)W5R:2==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?=7-E<W)O;&5T87-K375S=$AA=F5#
M:&%N;F5L3W)5<FDH)')O;&5;)W1A<VLG72P@)W5S97-T87-K)RD[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&9A:6P@/2!T<G5E.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!](&5L
M<V5I9B`H(6ES<V5T*"1R;VQE6R=P86-K86=E)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W5S97-R;VQE=&%S:TUU<W1(879E4&%C
M:V%G92@D<F]L95LG=&%S:R==+"`G=7-E<W1A<VLG*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1F86EL(#T@=')U93L-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H)&9A:6PI('L-"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W9A;&ED871E
M1FEL96QI<W0H*3L-"B`@("`@("`@)'1H:7,M/E]V86QI9&%T95)E;&5A<V4H
M*3L-"B`@("`@("`@:68@*"$D=&AI<RT^7W-T86-K+3YH87-%<G)O<G,H*2D@
M>PT*("`@("`@("`@("`@)&-H86X@/2`D=&AI<RT^7W!F+3Y?<F5G:7-T<GDM
M/F=E=$-H86YN96PH)'1H:7,M/E]P9BT^9V5T0VAA;FYE;"@I+"!T<G5E*3L-
M"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C:&%N*2D@>PT*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?=6YK;F]W;D-H86YN96PH)'1H:7,M/E]P
M9BT^9V5T0VAA;FYE;"@I*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@)'9A;'!A8VL@/2`D8VAA;BT^9V5T5F%L:61A=&EO;E!A
M8VMA9V4H*3L-"B`@("`@("`@("`@("`@("`O+R!F;W(@8VAA;FYE;"!V86QI
M9&%T;W(@<&%C:V%G97,L(&%L=V%Y<R!U<V4@=&AE(&1E9F%U;'0@4$5!4B!V
M86QI9&%T;W(N#0H@("`@("`@("`@("`@("`@+R\@;W1H97)W:7-E+"!T:&5Y
M(&-A;B=T(&)E(&EN<W1A;&QE9"!O<B!P86-K86=E9`T*("`@("`@("`@("`@
M("`@("1V86QI9&%T;W(@/2`D8VAA;BT^9V5T5F%L:61A=&EO;D]B:F5C="@D
M=&AI<RT^7W!F+3YG971086-K86=E*"DI.PT*("`@("`@("`@("`@("`@(&EF
M("@A)'9A;&ED871O<BD@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y7VUE<F=E*`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"=C:&%N;F5L)R`]/B`D8VAA;BT^9V5T3F%M
M92@I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P86-K
M86=E)R`]/B`D=&AI<RT^7W!F+3YG971086-K86=E*"DI+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'9A;'!A8VL-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("`@("`@("`@)W!A
M8VMA9V4@(B5C:&%N;F5L)2\E<&%C:V%G924B(&-A;FYO="!B92!P<F]P97)L
M>2!V86QI9&%T960@=VET:&]U="`G("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("=V86QI9&%T:6]N('!A8VMA9V4@(B5C:&%N;F5L)2\E;F%M924M)79E
M<G-I;VXE(B<I.PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@)'9A;&ED871O<BT^<V5T4&%C:V%G949I;&4H)'1H:7,M/E]P9BD[
M#0H@("`@("`@("`@("`@("`@)'9A;&ED871O<BT^=F%L:61A=&4H)'-T871E
M*3L-"B`@("`@("`@("`@("`@("`D9F%I;'5R97,@/2`D=F%L:61A=&]R+3YG
M971&86EL=7)E<R@I.PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1F86EL
M=7)E<ULG97)R;W)S)UT@87,@)&5R<F]R*2![#0H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G
M+"`D97)R;W(L#0H@("`@("`@("`@("`@("`@("`@("`@("`G0VAA;FYE;"!V
M86QI9&%T;W(@97)R;W(Z(&9I96QD("(E9FEE;&0E(B`M("5R96%S;VXE)RD[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1F86EL=7)E<ULG=V%R;FEN9W,G72!A<R`D=V%R;FEN9RD@>PT*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?
M7RP@)W=A<FYI;F<G+"`D=V%R;FEN9RP-"B`@("`@("`@("`@("`@("`@("`@
M("`@("=#:&%N;F5L('9A;&ED871O<B!W87)N:6YG.B!F:65L9"`B)69I96QD
M)2(@+2`E<F5A<V]N)2<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W!F+3Y?:7-686QI
M9"`]("1T:&ES+3Y?:7-686QI9"`]("$D=&AI<RT^7W-T86-K+3YH87-%<G)O
M<G,H)V5R<F]R)RD[#0H@("`@("`@(&EF("@D=&AI<RT^7VES5F%L:60@)B8@
M)'-T871E(#T](%!%05)?5D%,241!5$5?4$%#2T%'24Y'("8F("$D=&AI<RT^
M7V9I;&5S5F%L:60I('L-"B`@("`@("`@("`@(&EF("@D=&AI<RT^7W!F+3YG
M971086-K86=E5'EP92@I(#T]("=B=6YD;&4G*2![#0H@("`@("`@("`@("`@
M("`@:68@*"1T:&ES+3Y?86YA;'EZ94)U;F1L961086-K86=E<R@I*2![#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9FEL97-686QI9"`]("1T:&ES
M+3Y?<&8M/E]F:6QE<U9A;&ED(#T@=')U93L-"B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!F+3Y?:7-6
M86QI9"`]("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!I9B`H
M(21T:&ES+3Y?86YA;'EZ95!H<$9I;&5S*"DI('L-"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P9BT^7VES5F%L:60@/2`D=&AI<RT^7VES5F%L:60@
M/2`P.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9FEL97-686QI9"`]("1T:&ES+3Y?<&8M/E]F:6QE
M<U9A;&ED(#T@=')U93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES+3Y?:7-686QI9"D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&8M/E]I<U9A;&ED(#T@
M)'1H:7,M/E]I<U9A;&ED(#T@)'-T871E.PT*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B`D=&AI<RT^7W!F+3Y?:7-686QI9"`]("1T:&ES+3Y?:7-686QI
M9"`](#`[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7W-T=7!I9%-C:&5M859A
M;&ED871E*"1S=')U8W1U<F4L("1X;6PL("1R;V]T*0T*("`@('L-"B`@("`@
M("`@:68@*"%I<U]A<G)A>2@D>&UL*2D@>PT*("`@("`@("`@("`@)'AM;"`]
M(&%R<F%Y*"D[#0H@("`@("`@('T-"B`@("`@("`@)&ME>7,@/2!A<G)A>5]K
M97ES*"1X;6PI.PT*("`@("`@("!R97-E="@D:V5Y<RD[#0H@("`@("`@("1K
M97D@/2!C=7)R96YT*"1K97ES*3L-"B`@("`@("`@=VAI;&4@*"1K97D@/3T@
M)V%T=')I8G,G('Q\("1K97D@/3T@)U]C;VYT96YT<R<I('L-"B`@("`@("`@
M("`@("1K97D@/2!N97AT*"1K97ES*3L-"B`@("`@("`@?0T*("`@("`@("`D
M=6YF;W5N9'1A9W,@/2`D;W!T:6]N86QT86=S(#T@87)R87DH*3L-"B`@("`@
M("`@)')E="`]('1R=64[#0H@("`@("`@("1M:7-M871C:"`](&9A;'-E.PT*
M("`@("`@("!F;W)E86-H("@D<W1R=6-T=7)E(&%S("1S=')U8RD@>PT*("`@
M("`@("`@("`@:68@*"1K97DI('L-"B`@("`@("`@("`@("`@("`D=&%G(#T@
M)'AM;%LD:V5Y73L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T97-T
M(#T@)'1H:7,M/E]P<F]C97-S4W1R=6-T=7)E*"1S=')U8RD[#0H@("`@("`@
M("`@("!I9B`H:7-S970H)'1E<W1;)V-H;VEC97,G72DI('L-"B`@("`@("`@
M("`@("`@("`D;&]O<V4@/2!T<G5E.PT*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1T97-T6R=C:&]I8V5S)UT@87,@)&-H;VEC92D@>PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H)&ME>2`]/2`D8VAO:6-E6R=T86<G72D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)&ME>2`](&YE>'0H)&ME>7,I.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@=VAI;&4@*"1K97D@/3T@)V%T=')I8G,G
M('Q\("1K97D@/3T@)U]C;VYT96YT<R<I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D:V5Y(#T@;F5X="@D:V5Y<RD[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`D=6YF;W5N
M9'1A9W,@/2`D;W!T:6]N86QT86=S(#T@87)R87DH*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1M:7-M871C:"`](&9A;'-E.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"1K97D@)B8@)&ME>2`A/2`D8VAO:6-E6R=T86<G
M72`F)B!I<W-E="@D8VAO:6-E6R=M=6QT:7!L92==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1U;F9O=6YD=&%G<UM=(#T@)&-H;VEC95LG
M=&%G)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&]P=&EO;F%L
M=&%G<UM=(#T@)&-H;VEC95LG=&%G)UT[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"1K97DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&UI<VUA=&-H(#T@=')U93L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D<F5T("8]("1T:&ES+3Y?<')O8V5S<T%T
M=')I8G,H)&-H;VEC92P@)'1A9RP@)')O;W0I.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1U;F9O=6YD=&%G<UM=
M(#T@)&-H;VEC95LG=&%G)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M;6ES;6%T8V@@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&-H;VEC95LG;75L=&EP;&4G
M72D@?'P@)&-H;VEC95LG;75L=&EP;&4G72`A/2`G*B<I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1L;V]S92`](&9A;'-E.PT*("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&]P
M=&EO;F%L=&%G<UM=(#T@)&-H;VEC95LG=&%G)UT[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M:68@*"$D;&]O<V4I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I
M;G9A;&ED5&%G3W)D97(H)'5N9F]U;F1T86=S+"`D:V5Y+"`D<F]O="D[#0H@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M(&EF("@D:V5Y("$]("1T97-T6R=T86<G72D@>PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)'1E<W1;)VUU;'1I<&QE)UTI("8F("1T97-T6R=M
M=6QT:7!L92==("$]("<J)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)'5N9F]U;F1T86=S6UT@/2`D=&5S=%LG=&%G)UT[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7VEN=F%L:61486=/<F1E<B@D=6YF;W5N9'1A
M9W,L("1K97DL("1R;V]T*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D:V5Y*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&UI<VUA=&-H(#T@=')U93L-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1U
M;F9O=6YD=&%G<UM=(#T@)'1E<W1;)W1A9R==.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)&]P=&EO;F%L=&%G<UM=(#T@)'1E<W1;)W1A9R==.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)'1E<W1;)VUU;'1I<&QE)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7VEN=F%L:61486=/<F1E<B@D=6YF;W5N9'1A9W,L
M("1K97DL("1R;V]T*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`D=6YF;W5N9'1A9W,@/2`D;W!T:6]N86QT
M86=S(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("`@("`@)&UI<VUA=&-H
M(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("1K97D@/2!N97AT*"1K97ES*3L-"B`@("`@("`@("`@("`@("!W:&EL92`H
M)&ME>2`]/2`G871T<FEB<R<@?'P@)&ME>2`]/2`G7V-O;G1E;G1S)RD@>PT*
M("`@("`@("`@("`@("`@("`@("`D:V5Y(#T@;F5X="@D:V5Y<RD[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D:V5Y("8F("1K
M97D@(3T@)'1E<W1;)W1A9R==("8F(&ES<V5T*"1T97-T6R=M=6QT:7!L92==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=6YF;W5N9'1A9W-;72`]("1T
M97-T6R=T86<G73L-"B`@("`@("`@("`@("`@("`@("`@)&]P=&EO;F%L=&%G
M<UM=(#T@)'1E<W1;)W1A9R==.PT*("`@("`@("`@("`@("`@("`@("`D;6ES
M;6%T8V@@/2!T<G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`D<F5T("8]("1T:&ES+3Y?<')O8V5S<T%T=')I8G,H)'1E<W0L("1T
M86<L("1R;V]T*3L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21M:7-M871C:"`F
M)B!C;W5N="@D;W!T:6]N86QT86=S*2D@>PT*("`@("`@("`@("`@+R\@9&]N
M)W0@97)R;W(@;W5T(&]N(&%N>2!O<'1I;VYA;"!T86=S#0H@("`@("`@("`@
M("`D=6YF;W5N9'1A9W,@/2!A<G)A>5]D:69F*"1U;F9O=6YD=&%G<RP@)&]P
M=&EO;F%L=&%G<RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*&-O=6YT*"1U
M;F9O=6YD=&%G<RDI('L-"B`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI9%1A
M9T]R9&5R*"1U;F9O=6YD=&%G<RP@)&ME>2P@)')O;W0I.PT*("`@("`@("!]
M(&5L<V5I9B`H)&ME>2D@>PT*("`@("`@("`@("`@+R\@=6YK;F]W;B!T86=S
M#0H@("`@("`@("`@("`D=&AI<RT^7VEN=F%L:61486=/<F1E<B@G*FYO('1A
M9W,@86QL;W=E9"!H97)E*B<L("1K97DL("1R;V]T*3L-"B`@("`@("`@("`@
M('=H:6QE("@D:V5Y(#T@;F5X="@D:V5Y<RDI('L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7VEN=F%L:61486=/<F1E<B@G*FYO('1A9W,@86QL;W=E9"!H
M97)E*B<L("1K97DL("1R;V]T*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!?<')O8V5S<T%T=')I8G,H)&-H;VEC92P@)'1A9RP@)&-O;G1E>'0I#0H@
M("`@>PT*("`@("`@("!I9B`H:7-S970H)&-H;VEC95LG871T<FEB<R==*2D@
M>PT*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D=&%G*2D@>PT*("`@("`@
M("`@("`@("`@("1T86<@/2!A<G)A>2@D=&%G*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1T86=S(#T@)'1A9SL-"B`@("`@("`@("`@(&EF("@A
M:7-S970H)'1A9W-;,%TI*2![#0H@("`@("`@("`@("`@("`@)'1A9W,@/2!A
M<G)A>2@D=&%G<RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<F5T
M(#T@=')U93L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1T86=S(&%S("1I(#T^
M("1T86<I('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1T86<I
M('Q\("%I<W-E="@D=&%G6R=A='1R:6)S)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1C:&]I8V5;)V%T=')I8G,G72!A<R`D871T<FEB
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&%T=')I8GLP?2`A
M/2`G/R<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5T("8]
M("1T:&ES+3Y?=&%G2&%S3F]!='1R:6)S*"1C:&]I8V5;)W1A9R==+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]N=&5X="D[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64@,CL-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D8VAO
M:6-E6R=A='1R:6)S)UT@87,@)&%T=')I8BD@>PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H)&%T=')I8GLP?2`A/2`G/R<I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)'1A9ULG871T<FEB<R==6R1A='1R:6)=
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R970@)CT@)'1H
M:7,M/E]T86=-:7-S:6YG071T<FEB=71E*"1C:&]I8V5;)W1A9R==+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D871T<FEB+"`D8V]N=&5X
M="D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!R971U<FX@)')E=#L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@=')U93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?<')O8V5S<U-T
M<G5C='5R92@D:V5Y*0T*("`@('L-"B`@("`@("`@)')E="`](&%R<F%Y*"D[
M#0H@("`@("`@(&EF("AC;W5N="@D<&EE8V5S(#T@97AP;&]D92@G?"<L("1K
M97DI*2`^(#$I('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1P:65C97,@87,@
M)'!I96-E*2![#0H@("`@("`@("`@("`@("`@)')E=%LG8VAO:6-E<R==6UT@
M/2`D=&AI<RT^7W!R;V-E<W-3=')U8W1U<F4H)'!I96-E*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(')E='5R;B`D<F5T.PT*("`@("`@("!]#0H@
M("`@("`@("1M=6QT:2`]("1K97E[,'T[#0H@("`@("`@(&EF("@D;75L=&D@
M/3T@)RLG('Q\("1M=6QT:2`]/2`G*B<I('L-"B`@("`@("`@("`@("1R971;
M)VUU;'1I<&QE)UT@/2`D:V5Y>S!].PT*("`@("`@("`@("`@)&ME>2`]('-U
M8G-T<B@D:V5Y+"`Q*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H8V]U;G0H
M)&%T=')S(#T@97AP;&]D92@G+3XG+"`D:V5Y*2D@/B`Q*2![#0H@("`@("`@
M("`@("`D<F5T6R=T86<G72`](&%R<F%Y7W-H:69T*"1A='1R<RD[#0H@("`@
M("`@("`@("`D<F5T6R=A='1R:6)S)UT@/2`D871T<G,[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`D<F5T6R=T86<G72`]("1K97D[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@7W9A;&ED871E4W1A8FEL:71Y5F5R<VEO;B@I#0H@("`@>PT*("`@
M("`@("`D<W1R=6-T=7)E(#T@87)R87DH)W)E;&5A<V4G+"`G87!I)RD[#0H@
M("`@("`@("1A(#T@)'1H:7,M/E]S='5P:6138VAE;6%686QI9&%T92@D<W1R
M=6-T=7)E+"`D=&AI<RT^7W!A8VMA9V5);F9O6R=V97)S:6]N)UTL("<\=F5R
M<VEO;CXG*3L-"B`@("`@("`@)&$@)CT@)'1H:7,M/E]S='5P:6138VAE;6%6
M86QI9&%T92@D<W1R=6-T=7)E+"`D=&AI<RT^7W!A8VMA9V5);F9O6R=S=&%B
M:6QI='DG72P@)SQS=&%B:6QI='D^)RD[#0H@("`@("`@(&EF("@D82D@>PT*
M("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"<O7EQD*R@_.EPN7&0K*2HH
M/SI;82UZ02U:72M<9"HI/R0O)RP-"B`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%C:V%G94EN9F];)W9E<G-I;VXG75LG<F5L96%S92==*2D@>PT*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI9%9E<G-I;VXH)W)E;&5A<V4G
M+"`D=&AI<RT^7W!A8VMA9V5);F9O6R=V97)S:6]N)UU;)W)E;&5A<V4G72D[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H
M)R]>7&0K*#\Z7"Y<9"LI*B@_.EMA+7I!+5I=*UQD*BD_)"\G+`T*("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG=F5R<VEO;B==6R=A
M<&DG72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEN=F%L:61697)S
M:6]N*"=A<&DG+"`D=&AI<RT^7W!A8VMA9V5);F9O6R=V97)S:6]N)UU;)V%P
M:2==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:6Y?87)R
M87DH)'1H:7,M/E]P86-K86=E26YF;ULG<W1A8FEL:71Y)UU;)W)E;&5A<V4G
M72P-"B`@("`@("`@("`@("`@("`@(&%R<F%Y*"=S;F%P<VAO="<L("=D979E
M;"<L("=A;'!H82<L("=B971A)RP@)W-T86)L92<I*2D@>PT*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?:6YV86QI9%-T871E*"=R96QE87-E)RP@)'1H:7,M
M/E]P86-K86=E:6YF;ULG<W1A8FEL:71Y)UU;)W)E;&5A<V4G72D[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6EN7V%R<F%Y*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)W-T86)I;&ET>2==6R=A<&DG72P-"B`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=D979E;"<L("=A;'!H82<L("=B971A)RP@)W-T86)L
M92<I*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI9%-T871E
M*"=A<&DG+"`D=&AI<RT^7W!A8VMA9V5I;F9O6R=S=&%B:6QI='DG75LG87!I
M)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@7W9A;&ED871E36%I;G1A:6YE<G,H*0T*("`@('L-"B`@("`@
M("`@)'-T<G5C='5R92`]#0H@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`G;F%M92<L#0H@("`@("`@("`@("`@("`@)W5S97(G+`T*("`@
M("`@("`@("`@("`@("=E;6%I;"<L#0H@("`@("`@("`@("`@("`@)V%C=&EV
M92<L#0H@("`@("`@("`@("`I.PT*("`@("`@("!F;W)E86-H("AA<G)A>2@G
M;&5A9"<L("=D979E;&]P97(G+"`G8V]N=')I8G5T;W(G+"`G:&5L<&5R)RD@
M87,@)'1Y<&4I('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P
M86-K86=E26YF;ULD='EP95TI*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN
M=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]P86-K86=E26YF;ULD='EP95U;,%TI*2![#0H@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/E]P86-K86=E26YF;ULD='EP95T@87,@)&QE
M860I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S='5P:6138VAE
M;6%686QI9&%T92@D<W1R=6-T=7)E+"`D;&5A9"P@)SPG("X@)'1Y<&4@+B`G
M/B<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]S='5P:6138VAE;6%686QI9&%T
M92@D<W1R=6-T=7)E+"`D=&AI<RT^7W!A8VMA9V5);F9O6R1T>7!E72P-"B`@
M("`@("`@("`@("`@("`@("`@)SPG("X@)'1Y<&4@+B`G/B<I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7W9A
M;&ED871E4&AP1&5P*"1D97`L("1I;G-T86QL8V]N9&ET:6]N(#T@9F%L<V4I
M#0H@("`@>PT*("`@("`@("`D<W1R=6-T=7)E(#T@87)R87DH#0H@("`@("`@
M("`@("`G;6EN)RP-"B`@("`@("`@("`@("<J;6%X)RP-"B`@("`@("`@("`@
M("<J97AC;'5D92<L#0H@("`@("`@("D[#0H@("`@("`@("1T>7!E(#T@)&EN
M<W1A;&QC;VYD:71I;VX@/R`G/&EN<W1A;&QC;VYD:71I;VX^/'!H<#XG(#H@
M)SQD97!E;F1E;F-I97,^/')E<75I<F5D/CQP:'`^)SL-"B`@("`@("`@)'1H
M:7,M/E]S='5P:6138VAE;6%686QI9&%T92@D<W1R=6-T=7)E+"`D9&5P+"`D
M='EP92D[#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=M:6XG72DI('L-"B`@
M("`@("`@("`@(&EF("@A<')E9U]M871C:"@G+UY<9"LH/SI<+EQD*RDJ*#\Z
M6V$M>D$M6ETK7&0J*3\H/SHM6V$M>D$M6C`M.5TK*3\D+R<L#0H@("`@("`@
M("`@("`@("`@("`D9&5P6R=M:6XG72DI('L-"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7VEN=F%L:61697)S:6]N*"1T>7!E("X@)SQM:6X^)RP@)&1E<%LG
M;6EN)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF
M("AI<W-E="@D9&5P6R=M87@G72DI('L-"B`@("`@("`@("`@(&EF("@A<')E
M9U]M871C:"@G+UY<9"LH/SI<+EQD*RDJ*#\Z6V$M>D$M6ETK7&0J*3\H/SHM
M6V$M>D$M6C`M.5TK*3\D+R<L#0H@("`@("`@("`@("`@("`@("`D9&5P6R=M
M87@G72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEN=F%L:61697)S
M:6]N*"1T>7!E("X@)SQM87@^)RP@)&1E<%LG;6%X)UTI.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7W9A;&ED
M871E4&5A<FEN<W1A;&QE<D1E<"@D9&5P*0T*("`@('L-"B`@("`@("`@)'-T
M<G5C='5R92`](&%R<F%Y*`T*("`@("`@("`@("`@)VUI;B<L#0H@("`@("`@
M("`@("`G*FUA>"<L#0H@("`@("`@("`@("`G*G)E8V]M;65N9&5D)RP-"B`@
M("`@("`@("`@("<J97AC;'5D92<L#0H@("`@("`@("D[#0H@("`@("`@("1T
M:&ES+3Y?<W1U<&ED4V-H96UA5F%L:61A=&4H)'-T<G5C='5R92P@)&1E<"P@
M)SQD97!E;F1E;F-I97,^/')E<75I<F5D/CQP96%R:6YS=&%L;&5R/B<I.PT*
M("`@("`@("!I9B`H:7-S970H)&1E<%LG;6EN)UTI*2![#0H@("`@("`@("`@
M("!I9B`H(7!R96=?;6%T8V@H)R]>7&0K*#\Z7"Y<9"LI*B@_.EMA+7I!+5I=
M*UQD*BD_)"\G+`T*("`@("`@("`@("`@("`@("`@)&1E<%LG;6EN)UTI*2![
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]I;G9A;&ED5F5R<VEO;B@G/&1E
M<&5N9&5N8VEE<SX\<F5Q=6ER960^/'!E87)I;G-T86QL97(^/&UI;CXG+`T*
M("`@("`@("`@("`@("`@("`@("`D9&5P6R=M:6XG72D[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)VUA>"==
M*2D@>PT*("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"<O7EQD*R@_.EPN
M7&0K*2HH/SI;82UZ02U:72M<9"HI/R0O)RP-"B`@("`@("`@("`@("`@("`@
M("1D97!;)VUA>"==*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV
M86QI9%9E<G-I;VXH)SQD97!E;F1E;F-I97,^/')E<75I<F5D/CQP96%R:6YS
M=&%L;&5R/CQM87@^)RP-"B`@("`@("`@("`@("`@("`@("`@)&1E<%LG;6%X
M)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI
M<W-E="@D9&5P6R=R96-O;6UE;F1E9"==*2D@>PT*("`@("`@("`@("`@:68@
M*"%P<F5G7VUA=&-H*"<O7EQD*R@_.EPN7&0K*2HH/SI;82UZ02U:72M<9"HI
M/R0O)RP-"B`@("`@("`@("`@("`@("`@("1D97!;)W)E8V]M;65N9&5D)UTI
M*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]I;G9A;&ED5F5R<VEO;B@G
M/&1E<&5N9&5N8VEE<SX\<F5Q=6ER960^/'!E87)I;G-T86QL97(^/')E8V]M
M;65N9&5D/B<L#0H@("`@("`@("`@("`@("`@("`@("1D97!;)W)E8V]M;65N
M9&5D)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF
M("AI<W-E="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("!I9B`H
M(6ES7V%R<F%Y*"1D97!;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@("`@
M("`D9&5P6R=E>&-L=61E)UT@/2!A<G)A>2@D9&5P6R=E>&-L=61E)UTI.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)&1E<%LG97AC
M;'5D92==(&%S("1E>&-L=61E*2![#0H@("`@("`@("`@("`@("`@:68@*"%P
M<F5G7VUA=&-H*"<O7EQD*R@_.EPN7&0K*2HH/SI;82UZ02U:72M<9"HI/R0O
M)RP-"B`@("`@("`@("`@("`@("`@("`@("`D97AC;'5D92DI('L-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]I;G9A;&ED5F5R<VEO;B@G/&1E<&5N
M9&5N8VEE<SX\<F5Q=6ER960^/'!E87)I;G-T86QL97(^/&5X8VQU9&4^)RP-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1E>&-L=61E*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!?=F%L:61A=&5086-K86=E1&5P*"1D97`L("1G<F]U
M<"P@)'1Y<&4@/2`G/'!A8VMA9V4^)RD-"B`@("![#0H@("`@("`@(&EF("AI
M<W-E="@D9&5P6R=U<FDG72DI('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D
M9&5P6R=C;VYF;&EC=',G72DI('L-"B`@("`@("`@("`@("`@("`D<W1R=6-T
M=7)E(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=N86UE)RP-"B`@
M("`@("`@("`@("`@("`@("`@)W5R:2<L#0H@("`@("`@("`@("`@("`@("`@
M("=C;VYF;&EC=',G+`T*("`@("`@("`@("`@("`@("`@("`G*G!R;W9I9&5S
M97AT96YS:6]N)RP-"B`@("`@("`@("`@("`@("`I.PT*("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D<W1R=6-T=7)E(#T@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`@("=N86UE)RP-"B`@("`@("`@("`@("`@
M("`@("`@)W5R:2<L#0H@("`@("`@("`@("`@("`@("`@("<J<')O=FED97-E
M>'1E;G-I;VXG+`T*("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I9B`H:7-S970H)&1E
M<%LG8V]N9FQI8W1S)UTI*2![#0H@("`@("`@("`@("`@("`@)'-T<G5C='5R
M92`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G;F%M92<L#0H@("`@
M("`@("`@("`@("`@("`@("=C:&%N;F5L)RP-"B`@("`@("`@("`@("`@("`@
M("`@)RIM:6XG+`T*("`@("`@("`@("`@("`@("`@("`G*FUA>"<L#0H@("`@
M("`@("`@("`@("`@("`@("<J97AC;'5D92<L#0H@("`@("`@("`@("`@("`@
M("`@("=C;VYF;&EC=',G+`T*("`@("`@("`@("`@("`@("`@("`G*G!R;W9I
M9&5S97AT96YS:6]N)RP-"B`@("`@("`@("`@("`@("`I.PT*("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D<W1R=6-T=7)E(#T@87)R
M87DH#0H@("`@("`@("`@("`@("`@("`@("=N86UE)RP-"B`@("`@("`@("`@
M("`@("`@("`@)V-H86YN96PG+`T*("`@("`@("`@("`@("`@("`@("`G*FUI
M;B<L#0H@("`@("`@("`@("`@("`@("`@("<J;6%X)RP-"B`@("`@("`@("`@
M("`@("`@("`@)RIR96-O;6UE;F1E9"<L#0H@("`@("`@("`@("`@("`@("`@
M("<J97AC;'5D92<L#0H@("`@("`@("`@("`@("`@("`@("<J;F]D969A=6QT
M)RP-"B`@("`@("`@("`@("`@("`@("`@)RIP<F]V:61E<V5X=&5N<VEO;B<L
M#0H@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H:7-S970H)&1E<%LG;F%M92==*2D@>PT*("`@("`@
M("`@("`@)'1Y<&4@+CT@)SQN86UE/B<@+B`D9&5P6R=N86UE)UT@+B`G/"]N
M86UE/B<[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]S='5P:6138VAE
M;6%686QI9&%T92@D<W1R=6-T=7)E+"`D9&5P+"`G/&1E<&5N9&5N8VEE<SXG
M("X@)&=R;W5P("X@)'1Y<&4I.PT*("`@("`@("!I9B`H:7-S970H)&1E<%LG
M=7)I)UTI("8F("AI<W-E="@D9&5P6R=M:6XG72D@?'P@:7-S970H)&1E<%LG
M;6%X)UTI('Q\#0H@("`@("`@("`@("`@(&ES<V5T*"1D97!;)W)E8V]M;65N
M9&5D)UTI('Q\(&ES<V5T*"1D97!;)V5X8VQU9&4G72DI*2![#0H@("`@("`@
M("`@("`D=&AI<RT^7W5R:41E<'-#86YN;W1(879E5F5R<VEO;FEN9R@G/&1E
M<&5N9&5N8VEE<SXG("X@)&=R;W5P("X@)'1Y<&4I.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("AI<W-E="@D9&5P6R=C:&%N;F5L)UTI("8F('-T<G1O;&]W
M97(H)&1E<%LG8VAA;FYE;"==*2`]/2`G7U]U<FDG*2![#0H@("`@("`@("`@
M("`D=&AI<RT^7T1E<&-H86YN96Q#86YN;W1"955R:2@G/&1E<&5N9&5N8VEE
M<SXG("X@)&=R;W5P("X@)'1Y<&4I.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("AI<W-E="@D9&5P6R=M:6XG72DI('L-"B`@("`@("`@("`@(&EF("@A<')E
M9U]M871C:"@G+UY<9"LH/SI<+EQD*RDJ*#\Z6V$M>D$M6ETK7&0J*3\D+R<L
M#0H@("`@("`@("`@("`@("`@("`D9&5P6R=M:6XG72DI('L-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7VEN=F%L:61697)S:6]N*"<\9&5P96YD96YC:65S
M/B<@+B`D9W)O=7`@+B`D='EP92`N("<\;6EN/B<L("1D97!;)VUI;B==*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H
M)&1E<%LG;6%X)UTI*2![#0H@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H
M)R]>7&0K*#\Z7"Y<9"LI*B@_.EMA+7I!+5I=*UQD*BD_)"\G+`T*("`@("`@
M("`@("`@("`@("`@)&1E<%LG;6%X)UTI*2![#0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]I;G9A;&ED5F5R<VEO;B@G/&1E<&5N9&5N8VEE<SXG("X@)&=R
M;W5P("X@)'1Y<&4@+B`G/&UA>#XG+"`D9&5P6R=M87@G72D[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)W)E
M8V]M;65N9&5D)UTI*2![#0H@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H
M)R]>7&0K*#\Z7"Y<9"LI*B@_.EMA+7I!+5I=*UQD*BD_)"\G+`T*("`@("`@
M("`@("`@("`@("`@)&1E<%LG<F5C;VUM96YD960G72DI('L-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7VEN=F%L:61697)S:6]N*"<\9&5P96YD96YC:65S
M/B<@+B`D9W)O=7`@+B`D='EP92`N("<\<F5C;VUM96YD960^)RP-"B`@("`@
M("`@("`@("`@("`@("`@)&1E<%LG<F5C;VUM96YD960G72D[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)V5X
M8VQU9&4G72DI('L-"B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&1E<%LG
M97AC;'5D92==*2D@>PT*("`@("`@("`@("`@("`@("1D97!;)V5X8VQU9&4G
M72`](&%R<F%Y*"1D97!;)V5X8VQU9&4G72D[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!F;W)E86-H("@D9&5P6R=E>&-L=61E)UT@87,@)&5X8VQU
M9&4I('L-"B`@("`@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H)R]>7&0K
M*#\Z7"Y<9"LI*B@_.EMA+7I!+5I=*UQD*BD_)"\G+`T*("`@("`@("`@("`@
M("`@("`@("`@("1E>&-L=61E*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7VEN=F%L:61697)S:6]N*"<\9&5P96YD96YC:65S/B<@+B`D9W)O
M=7`@+B`D='EP92`N("<\97AC;'5D93XG+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@)&5X8VQU9&4I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T:6]N(%]V86QI
M9&%T95-U8G!A8VMA9V5$97`H)&1E<"P@)&=R;W5P*0T*("`@('L-"B`@("`@
M("`@)'1H:7,M/E]V86QI9&%T95!A8VMA9V5$97`H)&1E<"P@)&=R;W5P+"`G
M/'-U8G!A8VMA9V4^)RD[#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=P<F]V
M:61E<V5X=&5N<VEO;B==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]S=6)P
M86-K86=E0V%N;F]T4')O=FED945X=&5N<VEO;BA`)&1E<%LG;F%M92==*3L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&1E<%LG8V]N9FQI8W1S
M)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W-U8G!A8VMA9V5S0V%N;F]T
M0V]N9FQI8W0H0"1D97!;)VYA;64G72D[#0H@("`@("`@('T-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!?=F%L:61A=&5%>'1E;G-I;VY$97`H)&1E<"P@)&=R
M;W5P(#T@9F%L<V4L("1I;G-T86QL8V]N9&ET:6]N(#T@9F%L<V4I#0H@("`@
M>PT*("`@("`@("!I9B`H:7-S970H)&1E<%LG8V]N9FQI8W1S)UTI*2![#0H@
M("`@("`@("`@("`D<W1R=6-T=7)E(#T@87)R87DH#0H@("`@("`@("`@("`@
M("`@)VYA;64G+`T*("`@("`@("`@("`@("`@("<J;6EN)RP-"B`@("`@("`@
M("`@("`@("`G*FUA>"<L#0H@("`@("`@("`@("`@("`@)RIE>&-L=61E)RP-
M"B`@("`@("`@("`@("`@("`G8V]N9FQI8W1S)RP-"B`@("`@("`@("`@("D[
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D<W1R=6-T=7)E(#T@
M87)R87DH#0H@("`@("`@("`@("`@("`@)VYA;64G+`T*("`@("`@("`@("`@
M("`@("<J;6EN)RP-"B`@("`@("`@("`@("`@("`G*FUA>"<L#0H@("`@("`@
M("`@("`@("`@)RIR96-O;6UE;F1E9"<L#0H@("`@("`@("`@("`@("`@)RIE
M>&-L=61E)RP-"B`@("`@("`@("`@("D[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"1I;G-T86QL8V]N9&ET:6]N*2![#0H@("`@("`@("`@("`D='EP92`]
M("<\:6YS=&%L;&-O;F1I=&EO;CX\97AT96YS:6]N/B<[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`D='EP92`]("<\9&5P96YD96YC:65S/B<@
M+B`D9W)O=7`@+B`G/&5X=&5N<VEO;CXG.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("AI<W-E="@D9&5P6R=N86UE)UTI*2![#0H@("`@("`@("`@("`D='EP
M92`N/2`G/&YA;64^)R`N("1D97!;)VYA;64G72`N("<\+VYA;64^)SL-"B`@
M("`@("`@?0T*("`@("`@("`D=&AI<RT^7W-T=7!I9%-C:&5M859A;&ED871E
M*"1S=')U8W1U<F4L("1D97`L("1T>7!E*3L-"B`@("`@("`@:68@*&ES<V5T
M*"1D97!;)VUI;B==*2D@>PT*("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H
M*"<O7EQD*R@_.EPN7&0K*2HH/SI;82UZ02U:72M<9"HI/R0O)RP-"B`@("`@
M("`@("`@("`@("`@("1D97!;)VUI;B==*2D@>PT*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?:6YV86QI9%9E<G-I;VXH<W5B<W1R*"1T>7!E+"`Q*2`N("<\
M;6EN)RP@)&1E<%LG;6EN)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=M87@G72DI('L-"B`@("`@("`@
M("`@(&EF("@A<')E9U]M871C:"@G+UY<9"LH/SI<+EQD*RDJ*#\Z6V$M>D$M
M6ETK7&0J*3\D+R<L#0H@("`@("`@("`@("`@("`@("`D9&5P6R=M87@G72DI
M('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEN=F%L:61697)S:6]N*'-U
M8G-T<B@D='EP92P@,2D@+B`G/&UA>"<L("1D97!;)VUA>"==*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&1E<%LG
M<F5C;VUM96YD960G72DI('L-"B`@("`@("`@("`@(&EF("@A<')E9U]M871C
M:"@G+UY<9"LH/SI<+EQD*RDJ*#\Z6V$M>D$M6ETK7&0J*3\D+R<L#0H@("`@
M("`@("`@("`@("`@("`D9&5P6R=R96-O;6UE;F1E9"==*2D@>PT*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?:6YV86QI9%9E<G-I;VXH<W5B<W1R*"1T>7!E
M+"`Q*2`N("<\<F5C;VUM96YD960G+"`D9&5P6R=R96-O;6UE;F1E9"==*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H
M)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@("`@("`@:68@*"%I<U]A<G)A
M>2@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@)&1E<%LG
M97AC;'5D92==(#T@87)R87DH)&1E<%LG97AC;'5D92==*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1D97!;)V5X8VQU9&4G72!A
M<R`D97AC;'5D92D@>PT*("`@("`@("`@("`@("`@(&EF("@A<')E9U]M871C
M:"@G+UY<9"LH/SI<+EQD*RDJ*#\Z6V$M>D$M6ETK7&0J*3\D+R<L#0H@("`@
M("`@("`@("`@("`@("`@("`@)&5X8VQU9&4I*2![#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?:6YV86QI9%9E<G-I;VXH<W5B<W1R*"1T>7!E+"`Q
M*2`N("<\97AC;'5D92<L("1E>&-L=61E*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!?=F%L:61A=&5/<T1E<"@D9&5P+"`D:6YS=&%L;&-O;F1I=&EO;B`]
M(&9A;'-E*0T*("`@('L-"B`@("`@("`@)'-T<G5C='5R92`](&%R<F%Y*`T*
M("`@("`@("`@("`@)VYA;64G+`T*("`@("`@("`@("`@)RIC;VYF;&EC=',G
M+`T*("`@("`@("`I.PT*("`@("`@("`D='EP92`]("1I;G-T86QL8V]N9&ET
M:6]N(#\@)SQI;G-T86QL8V]N9&ET:6]N/CQO<SXG(#H@)SQD97!E;F1E;F-I
M97,^/')E<75I<F5D/CQO<SXG.PT*("`@("`@("!I9B`H)'1H:7,M/E]S='5P
M:6138VAE;6%686QI9&%T92@D<W1R=6-T=7)E+"`D9&5P+"`D='EP92DI('L-
M"B`@("`@("`@("`@(&EF("@D9&5P6R=N86UE)UT@/3T@)RHG*2![#0H@("`@
M("`@("`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)V-O;F9L:6-T<R<L
M("1D97`I*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8V%N;F]T
M0V]N9FQI8W17:71H06QL3W,H)'1Y<&4I.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T
M:6]N(%]V86QI9&%T94%R8VA$97`H)&1E<"P@)&EN<W1A;&QC;VYD:71I;VX@
M/2!F86QS92D-"B`@("![#0H@("`@("`@("1S=')U8W1U<F4@/2!A<G)A>2@-
M"B`@("`@("`@("`@("=P871T97)N)RP-"B`@("`@("`@("`@("<J8V]N9FQI
M8W1S)RP-"B`@("`@("`@*3L-"B`@("`@("`@)'1Y<&4@/2`D:6YS=&%L;&-O
M;F1I=&EO;B`_("<\:6YS=&%L;&-O;F1I=&EO;CX\87)C:#XG(#H@)SQD97!E
M;F1E;F-I97,^/')E<75I<F5D/CQA<F-H/B<[#0H@("`@("`@("1T:&ES+3Y?
M<W1U<&ED4V-H96UA5F%L:61A=&4H)'-T<G5C='5R92P@)&1E<"P@)'1Y<&4I
M.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]V86QI9&%T94EN<W1A;&Q#;VYD
M:71I;VYS*"1C;VYD+"`D<F5L96%S92D-"B`@("![#0H@("`@("`@("1S=')U
M8W1U<F4@/2!A<G)A>2@-"B`@("`@("`@("`@("<J<&AP)RP-"B`@("`@("`@
M("`@("<J97AT96YS:6]N)RP-"B`@("`@("`@("`@("<J;W,G+`T*("`@("`@
M("`@("`@)RIA<F-H)RP-"B`@("`@("`@*3L-"B`@("`@("`@:68@*"$D=&AI
M<RT^7W-T=7!I9%-C:&5M859A;&ED871E*"1S=')U8W1U<F4L#0H@("`@("`@
M("`@("`@("1C;VYD+"`D<F5L96%S92DI('L-"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("AA<G)A>2@G
M<&AP)RP@)V5X=&5N<VEO;B<L("=O<R<L("=A<F-H)RD@87,@)'1Y<&4I('L-
M"B`@("`@("`@("`@(&EF("AI<W-E="@D8V]N9%LD='EP95TI*2![#0H@("`@
M("`@("`@("`@("`@)&ET97(@/2`D8V]N9%LD='EP95T[#0H@("`@("`@("`@
M("`@("`@:68@*"%I<U]A<G)A>2@D:71E<BD@?'P@(6ES<V5T*"1I=&5R6S!=
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D:71E<B`](&%R<F%Y*"1I=&5R
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&ET97(@87,@)'!A8VMA9V4I('L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"1T>7!E(#T]("=E>'1E;G-I;VXG*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^>R)?=F%L:61A=&5[)'1Y<&5]1&5P(GTH)'!A8VMA
M9V4L(&9A;'-E+"!T<G5E*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y[(E]V86QI9&%T
M97LD='EP97U$97`B?2@D<&%C:V%G92P@=')U92D[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?=F%L:61A=&5$97!E
M;F1E;F-I97,H*0T*("`@('L-"B`@("`@("`@)'-T<G5C='5R92`](&%R<F%Y
M*`T*("`@("`@("`@("`@)W)E<75I<F5D)RP-"B`@("`@("`@("`@("<J;W!T
M:6]N86PG+`T*("`@("`@("`@("`@)RIG<F]U<"T^;F%M92T^:&EN="<-"B`@
M("`@("`@*3L-"B`@("`@("`@:68@*"$D=&AI<RT^7W-T=7!I9%-C:&5M859A
M;&ED871E*"1S=')U8W1U<F4L#0H@("`@("`@("`@("`@("1T:&ES+3Y?<&%C
M:V%G94EN9F];)V1E<&5N9&5N8VEE<R==+"`G/&1E<&5N9&5N8VEE<SXG*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@
M("`@(&9O<F5A8V@@*&%R<F%Y*"=R97%U:7)E9"<L("=O<'1I;VYA;"<I(&%S
M("1S:6UP;&5D97`I('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I97,G75LD<VEM<&QE9&5P72DI('L-
M"B`@("`@("`@("`@("`@("!I9B`H)'-I;7!L961E<"`]/2`G;W!T:6]N86PG
M*2![#0H@("`@("`@("`@("`@("`@("`@("1S=')U8W1U<F4@/2!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`@("`@("`@("<J<&%C:V%G92<L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`G*G-U8G!A8VMA9V4G+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@)RIE>'1E;G-I;VXG+`T*("`@("`@("`@("`@("`@("`@
M("`I.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@("1S=')U8W1U<F4@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@
M("`@("`@("=P:'`G+`T*("`@("`@("`@("`@("`@("`@("`@("`@)W!E87)I
M;G-T86QL97(G+`T*("`@("`@("`@("`@("`@("`@("`@("`@)RIP86-K86=E
M)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("<J<W5B<&%C:V%G92<L#0H@
M("`@("`@("`@("`@("`@("`@("`@("`G*F5X=&5N<VEO;B<L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`G*F]S)RP-"B`@("`@("`@("`@("`@("`@("`@
M("`@("<J87)C:"<L#0H@("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7W-T=7!I
M9%-C:&5M859A;&ED871E*"1S=')U8W1U<F4L#0H@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;)'-I
M;7!L961E<%TL#0H@("`@("`@("`@("`@("`@("`@("`@(CQD97!E;F1E;F-I
M97,^/"1S:6UP;&5D97`^(BDI('L-"B`@("`@("`@("`@("`@("`@("`@9F]R
M96%C:"`H87)R87DH)W!A8VMA9V4G+"`G<W5B<&%C:V%G92<L("=E>'1E;G-I
M;VXG*2!A<R`D='EP92D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE<R==6R1S
M:6UP;&5D97!=6R1T>7!E72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D:71E<B`]("1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE
M<R==6R1S:6UP;&5D97!=6R1T>7!E73L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1I=&5R6S!=*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D:71E<B`](&%R<F%Y*"1I=&5R*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)&ET97(@87,@)'!A8VMA9V4I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1T>7!E("$]("=E
M>'1E;G-I;VXG*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)'!A8VMA9V5;)W5R:2==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C
M:V%G95LG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7U5R;$]R0VAA;FYE;"@D='EP
M92P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P86-K86=E6R=N86UE)UTI.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<&%C:V%G95LG8VAA
M;FYE;"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7TYO0VAA;FYE;"@D='EP92P@)'!A8VMA9V5;
M)VYA;64G72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y[(E]V86QI9&%T97LD
M='EP97U$97`B?2@D<&%C:V%G92P@(CPD<VEM<&QE9&5P/B(I.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!I9B`H)'-I;7!L961E<"`]/2`G;W!T:6]N86PG*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("AA<G)A>2@G<&AP
M)RP@)W!E87)I;G-T86QL97(G+"`G;W,G+"`G87)C:"<I(&%S("1T>7!E*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P
M86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;)'-I;7!L961E<%U;)'1Y<&5=
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I=&5R(#T@)'1H
M:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;)'-I;7!L961E<%U;
M)'1Y<&5=.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)&ET97);,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1I=&5R(#T@87)R87DH)&ET97(I.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E
M86-H("@D:71E<B!A<R`D<&%C:V%G92D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^>R)?=F%L:61A=&5[)'1Y<&5]1&5P(GTH
M)'!A8VMA9V4I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG9&5P
M96YD96YC:65S)UU;)V=R;W5P)UTI*2![#0H@("`@("`@("`@("`D9W)O=7!S
M(#T@)'1H:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;)V=R;W5P
M)UT[#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1G<F]U<'-;,%TI*2![#0H@
M("`@("`@("`@("`@("`@)&=R;W5P<R`](&%R<F%Y*"1G<F]U<',I.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)'-T<G5C='5R92`](&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("<J<&%C:V%G92<L#0H@("`@("`@("`@("`@("`@
M)RIS=6)P86-K86=E)RP-"B`@("`@("`@("`@("`@("`G*F5X=&5N<VEO;B<L
M#0H@("`@("`@("`@("`I.PT*("`@("`@("`@("`@9F]R96%C:"`H)&=R;W5P
M<R!A<R`D9W)O=7`I('L-"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]S
M='5P:6138VAE;6%686QI9&%T92@D<W1R=6-T=7)E+"`D9W)O=7`L("<\9W)O
M=7`^)RDI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%014%27U9A;&ED
M871E.CIV86QI9$=R;W5P3F%M92@D9W)O=7!;)V%T=')I8G,G75LG;F%M92==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;G9A;&ED
M1&5P1W)O=7!.86UE*"1G<F]U<%LG871T<FEB<R==6R=N86UE)UTI.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*&%R<F%Y*"=P86-K86=E)RP@)W-U8G!A8VMA9V4G+"`G97AT96YS:6]N
M)RD@87,@)'1Y<&4I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D9W)O=7!;)'1Y<&5=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1I=&5R(#T@)&=R;W5P6R1T>7!E73L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1I=&5R6S!=*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D:71E<B`](&%R<F%Y*"1I=&5R
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&ET97(@87,@)'!A8VMA9V4I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1T>7!E
M("$]("=E>'1E;G-I;VXG*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;)W5R:2==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D<&%C:V%G95LG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7U5R;$]R0VAA;FYE
M;$=R;W5P*"1T>7!E+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!A8VMA9V5;)VYA;64G72P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1G<F]U
M<%LG;F%M92==*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)'!A8VMA9V5;)V-H86YN96PG72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E].;T-H86YN96Q'<F]U<"@D='EP92P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=N86UE
M)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9W)O=7!;)VYA;64G72D[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y[(E]V86QI9&%T97LD='EP97U$97`B?2@D<&%C:V%G92P@)SQG<F]U<"!N
M86UE/2(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1G<F]U<%LG871T<FEB<R==6R=N86UE)UT@+B`G(CXG*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!?=F%L:61A=&5#;VUP871I8FQE*"D-"B`@("![#0H@("`@("`@("1C
M;VUP870@/2`D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VUP871I8FQE)UT[#0H@
M("`@("`@(&EF("@A:7-S970H)&-O;7!A=%LP72DI('L-"B`@("`@("`@("`@
M("1C;VUP870@/2!A<G)A>2@D8V]M<&%T*3L-"B`@("`@("`@?0T*("`@("`@
M("`D<F5Q=6ER960@/2!A<G)A>2@G;F%M92<L("=C:&%N;F5L)RP@)VUI;B<L
M("=M87@G+"`G*F5X8VQU9&4G*3L-"B`@("`@("`@9F]R96%C:"`H)&-O;7!A
M="!A<R`D<&%C:V%G92D@>PT*("`@("`@("`@("`@)'1Y<&4@/2`G/&-O;7!A
M=&EB;&4^)SL-"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<&%C:V%G92D@
M)B8@87)R87E?:V5Y7V5X:7-T<R@G;F%M92<L("1P86-K86=E*2D@>PT*("`@
M("`@("`@("`@("`@("1T>7!E("X]("<\;F%M93XG("X@)'!A8VMA9V5;)VYA
M;64G72`N("<\+VYA;64^)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("1T:&ES+3Y?<W1U<&ED4V-H96UA5F%L:61A=&4H)')E<75I<F5D+"`D<&%C
M:V%G92P@)'1Y<&4I.PT*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1P86-K
M86=E*2`F)B!A<G)A>5]K97E?97AI<W1S*"=M:6XG+"`D<&%C:V%G92DI('L-
M"B`@("`@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H)R]>7&0K*#\Z7"Y<
M9"LI*B@_.EMA+7I!+5I=*UQD*BD_)"\G+`T*("`@("`@("`@("`@("`@("`@
M("`@("1P86-K86=E6R=M:6XG72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]I;G9A;&ED5F5R<VEO;BAS=6)S='(H)'1Y<&4L(#$I("X@)SQM
M:6XG+"`D<&%C:V%G95LG;6EN)UTI.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<&%C:V%G
M92D@)B8@87)R87E?:V5Y7V5X:7-T<R@G;6%X)RP@)'!A8VMA9V4I*2![#0H@
M("`@("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"<O7EQD*R@_.EPN7&0K
M*2HH/SI;82UZ02U:72M<9"HI/R0O)RP-"B`@("`@("`@("`@("`@("`@("`@
M("`D<&%C:V%G95LG;6%X)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?:6YV86QI9%9E<G-I;VXH<W5B<W1R*"1T>7!E+"`Q*2`N("<\;6%X
M)RP@)'!A8VMA9V5;)VUA>"==*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-?87)R87DH)'!A8VMA9V4I
M("8F(&%R<F%Y7VME>5]E>&ES=',H)V5X8VQU9&4G+"`D<&%C:V%G92DI('L-
M"B`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P86-K86=E6R=E>&-L
M=61E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=E>&-L
M=61E)UT@/2!A<G)A>2@D<&%C:V%G95LG97AC;'5D92==*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!A8VMA9V5;
M)V5X8VQU9&4G72!A<R`D97AC;'5D92D@>PT*("`@("`@("`@("`@("`@("`@
M("!I9B`H(7!R96=?;6%T8V@H)R]>7&0K*#\Z7"Y<9"LI*B@_.EMA+7I!+5I=
M*UQD*BD_)"\G+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`D97AC;'5D
M92DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI
M9%9E<G-I;VXH<W5B<W1R*"1T>7!E+"`Q*2`N("<\97AC;'5D92<L("1E>&-L
M=61E*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U
M;F-T:6]N(%]V86QI9&%T94)U;F1L92@D;&ES="D-"B`@("![#0H@("`@("`@
M(&EF("@A:7-?87)R87DH)&QI<W0I('Q\("%I<W-E="@D;&ES=%LG8G5N9&QE
M9'!A8VMA9V4G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7TYO
M0G5N9&QE9%!A8VMA9V5S*"D[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I
M<U]A<G)A>2@D;&ES=%LG8G5N9&QE9'!A8VMA9V4G72D@?'P@(6ES<V5T*"1L
M:7-T6R=B=6YD;&5D<&%C:V%G92==6S!=*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?071,96%S=#)"=6YD;&5D4&%C:V%G97,H*3L-"B`@("`@
M("`@?0T*("`@("`@("!F;W)E86-H("@D;&ES=%LG8G5N9&QE9'!A8VMA9V4G
M72!A<R`D<&%C:V%G92D@>PT*("`@("`@("`@("`@:68@*"%I<U]S=')I;F<H
M)'!A8VMA9V4I*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]B=6YD;&5D
M4&%C:V%G97--=7-T0F5&:6QE;F%M92@I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7W9A;&ED871E1FEL96QI
M<W0H)&QI<W0@/2!F86QS92P@)&%L;&]W:6=N;W)E(#T@9F%L<V4L("1D:7)S
M(#T@)R<I#0H@("`@>PT*("`@("`@("`D:7-C;VYT96YT<R`](&9A;'-E.PT*
M("`@("`@("!I9B`H(21L:7-T*2![#0H@("`@("`@("`@("`D:7-C;VYT96YT
M<R`]('1R=64[#0H@("`@("`@("`@("`D;&ES="`]("1T:&ES+3Y?<&%C:V%G
M94EN9F];)V-O;G1E;G1S)UT[#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]P86-K86=E26YF;ULG8G5N9&QE)UTI*2![#0H@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?=F%L:61A=&5"=6YD;&4H)&QI<W0I.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@D86QL;W=I9VYO
M<F4I('L-"B`@("`@("`@("`@("1S=')U8R`](&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("<J:6YS=&%L;"T^;F%M92T^87,G+`T*("`@("`@("`@("`@("`@
M("<J:6=N;W)E+3YN86UE)PT*("`@("`@("`@("`@*3L-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("1S=')U8R`](&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("<J9&ER+3YN86UE+3X_8F%S96EN<W1A;&QD:7(G+`T*("`@("`@
M("`@("`@("`@("<J9FEL92T^;F%M92T^<F]L92T^/V)A<V5I;G-T86QL9&ER
M+3X_;60U<W5M)PT*("`@("`@("`@("`@*3L-"B`@("`@("`@("`@(&EF("AI
M<W-E="@D;&ES=%LG9&ER)UTI("8F(&ES<V5T*"1L:7-T6R=F:6QE)UTI*2![
M#0H@("`@("`@("`@("`@("`@+R\@<W1A=F4@;V9F('9A;&ED871I;VX@97)R
M;W)S('=I=&AO=70@<F5Q=6ER:6YG(&$@<V5T(&]R9&5R+@T*("`@("`@("`@
M("`@("`@("1?;VQD(#T@)&QI<W0[#0H@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1L:7-T6R=A='1R:6)S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("1L:7-T(#T@87)R87DH)V%T=')I8G,G(#T^("1?;VQD6R=A='1R:6)S)UTI
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D;&ES=%LG
M9&ER)UT@/2`D7V]L9%LG9&ER)UT[#0H@("`@("`@("`@("`@("`@)&QI<W1;
M)V9I;&4G72`]("1?;VQD6R=F:6QE)UT[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D;&ES=%LG871T<FEB<R==*2!\
M?"`A:7-S970H)&QI<W1;)V%T=')I8G,G75LG;F%M92==*2D@>PT*("`@("`@
M("`@("`@)'5N:VYO=VX@/2`D86QL;W=I9VYO<F4@/R`G/&9I;&5L:7-T/B<@
M.B`G/&1I<B!N86UE/2(J=6YK;F]W;BHB/B<[#0H@("`@("`@("`@("`D9&ER
M;F%M92`]("1I<V-O;G1E;G1S(#\@)SQC;VYT96YT<SXG(#H@)'5N:VYO=VX[
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D9&ER;F%M92`]("<\
M9&ER(&YA;64](B<@+B`D;&ES=%LG871T<FEB<R==6R=N86UE)UT@+B`G(CXG
M.PT*("`@("`@("!]#0H@("`@("`@("1R97,@/2`D=&AI<RT^7W-T=7!I9%-C
M:&5M859A;&ED871E*"1S=')U8RP@)&QI<W0L("1D:7)N86UE*3L-"B`@("`@
M("`@:68@*"1A;&QO=VEG;F]R92`F)B`D<F5S*2![#0H@("`@("`@("`@("`D
M=&AI<RT^7W!F+3YG971&:6QE;&ES="@I.PT*("`@("`@("`@("`@)&9C;VYT
M96YT<R`]("1T:&ES+3Y?<&8M/F=E=$-O;G1E;G1S*"D[#0H@("`@("`@("`@
M("`D9FEL96QI<W0@/2!A<G)A>2@I.PT*("`@("`@("`@("`@:68@*"%I<W-E
M="@D9F-O;G1E;G1S6R=D:7(G75LG9FEL92==6S!=*2D@>PT*("`@("`@("`@
M("`@("`@("1F8V]N=&5N='-;)V1I<B==6R=F:6QE)UT@/2!A<G)A>2@D9F-O
M;G1E;G1S6R=D:7(G75LG9FEL92==*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1F8V]N=&5N='-;)V1I<B==6R=F:6QE)UT@87,@
M)&9I;&4I('L-"B`@("`@("`@("`@("`@("`D9FEL96QI<W1;)&9I;&5;)V%T
M=')I8G,G75LG;F%M92==72`]('1R=64[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!I9B`H:7-S970H)&QI<W1;)VEN<W1A;&PG72DI('L-"B`@("`@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1L:7-T6R=I;G-T86QL)UU;,%TI*2![
M#0H@("`@("`@("`@("`@("`@("`@("1L:7-T6R=I;G-T86QL)UT@/2!A<G)A
M>2@D;&ES=%LG:6YS=&%L;"==*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)&QI<W1;)VEN<W1A;&PG72!A<R`D9FEL
M92D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1F:6QE;&ES
M=%LD9FEL95LG871T<FEB<R==6R=N86UE)UU=*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]N;W1);D-O;G1E;G1S*"1F:6QE6R=A='1R
M:6)S)UU;)VYA;64G72P@)VEN<W1A;&PG*3L-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("AI<W-E="@D;&ES=%LG:6=N;W)E)UTI*2![#0H@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D;&ES=%LG:6=N;W)E)UU;,%TI*2![#0H@
M("`@("`@("`@("`@("`@("`@("1L:7-T6R=I9VYO<F4G72`](&%R<F%Y*"1L
M:7-T6R=I9VYO<F4G72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1L:7-T6R=I9VYO<F4G72!A<R`D9FEL92D@>PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1F:6QE;&ES=%LD9FEL
M95LG871T<FEB<R==6R=N86UE)UU=*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]N;W1);D-O;G1E;G1S*"1F:6QE6R=A='1R:6)S)UU;
M)VYA;64G72P@)VEG;F]R92<I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(&EF("@A)&%L;&]W:6=N;W)E("8F(&ES<V5T*"1L:7-T6R=F:6QE
M)UTI*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1L:7-T6R=F:6QE)UU;
M,%TI*2![#0H@("`@("`@("`@("`@("`@+R\@<VEN9VQE(&9I;&4-"B`@("`@
M("`@("`@("`@("`D;&ES=%LG9FEL92==(#T@87)R87DH)&QI<W1;)V9I;&4G
M72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E86-H("@D;&ES
M=%LG9FEL92==(&%S("1I(#T^("1F:6QE*0T*("`@("`@("`@("`@>PT*("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D9FEL95LG871T<FEB<R==*2`F)B!I
M<W-E="@D9FEL95LG871T<FEB<R==6R=N86UE)UTI("8F#0H@("`@("`@("`@
M("`@("`@("`@("`@)&9I;&5;)V%T=')I8G,G75LG;F%M92==>S!](#T]("<N
M)R`F)@T*("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&5;)V%T=')I8G,G
M75LG;F%M92==>S%](#T]("<O)RD@>PT*("`@("`@("`@("`@("`@("`@("`O
M+R!N86UE(&ES('-O;65T:&EN9R!L:6ME("(N+V1O8R]W:&%T979E<BYT>'0B
M#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI9$9I;&5.86UE
M*"1F:6QE6R=A='1R:6)S)UU;)VYA;64G72D[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9FEL95LG871T<FEB<R==
M*2`F)B!I<W-E="@D9FEL95LG871T<FEB<R==6R=R;VQE)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/E]V86QI9&%T95)O;&4H)&9I
M;&5;)V%T=')I8G,G75LG<F]L92==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W5S97-R;VQE
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')O;&5S(#T@
M)'1H:7,M/E]P86-K86=E26YF;ULG=7-E<W)O;&4G73L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1R;VQE<ULP72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')O;&5S(#T@87)R87DH
M)')O;&5S*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)')O;&5S(&%S("1R
M;VQE*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D
M<F]L95LG<F]L92==(#T@)&9I;&5;)V%T=')I8G,G75LG<F]L92==*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;7-G(#T@)U1H
M:7,@<&%C:V%G92!C;VYT86EN<R!R;VQE("(E<F]L924B(&%N9"!R97%U:7)E
M<R`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<&%C:V%G92`B)7!A8VMA9V4E(B!T;R!B92!U<V5D)SL-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<F]L95LG
M=7)I)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!A<F%M<R`](&%R<F%Y*"=R;VQE)R`]/B`D<F]L95LG<F]L92==
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<&%C:V%G92<@/3X@)')O;&5;)W5R:2==*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"=R
M;VQE)R`]/B`D<F]L95LG<F]L92==+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<&%C:V%G92<@/3X@)'1H:7,M/E]P
M9BT^7W)E9VES=')Y+3X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9RAA<G)A
M>2@G<&%C:V%G92<@/3X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1R;VQE6R=P86-K86=E)UTL("=C:&%N;F5L
M)R`]/B`D<F]L95LG8VAA;FYE;"==*2P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('1R=64I*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H)U]M
M=7-T26YS=&%L;%)O;&4G+"`G97)R;W(G+"`D<&%R86US+"`D;7-G*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI9$9I;&52
M;VQE*"1F:6QE6R=A='1R:6)S)UU;)VYA;64G72P-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&ER;F%M92P@)&9I;&5;)V%T=')I8G,G75LG<F]L
M92==*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1F:6QE6R=A='1R:6)S
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D<V%V92`]("1F:6QE6R=A
M='1R:6)S)UT[#0H@("`@("`@("`@("`@("`@:68@*"1D:7)S*2![#0H@("`@
M("`@("`@("`@("`@("`@("1S879E6R=N86UE)UT@/2`D9&ER<R`N("<O)R`N
M("1S879E6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@('5N<V5T*"1F:6QE6R=A='1R:6)S)UTI.PT*("`@("`@("`@("`@
M("`@(&EF("AC;W5N="@D9FEL92D@)B8@)'1H:7,M/E]C=7)3=&%T92`A/2!0
M14%27U9!3$E$051%7T1/5TY,3T%$24Y'*2![("\O(&AA<R!T87-K<PT*("`@
M("`@("`@("`@("`@("`@("!F;W)E86-H("@D9FEL92!A<R`D=&%S:R`]/B`D
M=F%L=64I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D=&%G0VQA
M<W,@/2`D=&AI<RT^7W!F+3YG971487-K*"1T87-K*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("@A:7-?87)R87DH)'9A;'5E*2!\?"`A
M:7-S970H)'9A;'5E6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=F%L=64@/2!A<G)A>2@D=F%L=64I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D=F%L=64@87,@)'8I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)')E="`](&-A;&Q?=7-E<E]F=6YC*&%R<F%Y*"1T
M86=#;&%S<RP@)W9A;&ED871E6&UL)RDL#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!F+"`D=BP@)'1H:7,M/E]P9BT^
M7V-O;F9I9RP@)'-A=F4I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-?87)R87DH)')E="DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI9%1A<VLH)'1A<VLL
M("1R970L($`D<V%V95LG;F%M92==*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)W5S97-T87-K)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1R;VQE<R`]("1T:&ES+3Y?<&%C:V%G94EN9F];)W5S97-T87-K
M)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)')O;&5S6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)')O;&5S(#T@87)R87DH)')O;&5S*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D<F]L97,@87,@)')O;&4I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D<F]L95LG=&%S
M:R==(#T@)'1A<VLI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D;7-G(#T@)U1H:7,@<&%C:V%G92!C;VYT86EN<R!T87-K
M("(E=&%S:R4B(&%N9"!R97%U:7)E<R`G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!A8VMA9V4@(B5P86-K86=E
M)2(@=&\@8F4@=7-E9"<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1R;VQE6R=U<FDG72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M
M<R`](&%R<F%Y*"=T87-K)R`]/B`D<F]L95LG=&%S:R==+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!A8VMA
M9V4G(#T^("1R;VQE6R=U<FDG72D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"=T
M87-K)R`]/B`D<F]L95LG=&%S:R==+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!A8VMA9V4G(#T^("1T:&ES
M+3Y?<&8M/E]R96=I<W1R>2T^#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!P87)S961086-K86=E3F%M951O4W1R
M:6YG*&%R<F%Y*"=P86-K86=E)R`]/@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R;VQE6R=P86-K86=E
M)UTL("=C:&%N;F5L)R`]/B`D<F]L95LG8VAA;FYE;"==*2P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T
M<G5E*2D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<W1A8VLM/G!U<V@H)U]M=7-T26YS=&%L;%1A<VLG+"`G97)R
M;W(G+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&%R86US+"`D;7-G*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W5N:VYO=VY487-K*"1T87-K
M+"`D<V%V95LG;F%M92==*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&QI
M<W1;)VEG;F]R92==*2D@>PT*("`@("`@("`@("`@:68@*"$D86QL;W=I9VYO
M<F4I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEG;F]R94YO=$%L;&]W
M960H)VEG;F]R92<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(&EF("AI<W-E="@D;&ES=%LG:6YS=&%L;"==*2D@>PT*("`@("`@("`@
M("`@:68@*"$D86QL;W=I9VYO<F4I('L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7VEG;F]R94YO=$%L;&]W960H)VEN<W1A;&PG*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&QI<W1;)V9I;&4G
M72DI('L-"B`@("`@("`@("`@(&EF("@D86QL;W=I9VYO<F4I('L-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7V9I;&5.;W1!;&QO=V5D*"=F:6QE)RD[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1L
M:7-T6R=D:7(G72DI('L-"B`@("`@("`@("`@(&EF("@D86QL;W=I9VYO<F4I
M('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V9I;&5.;W1!;&QO=V5D*"=D
M:7(G*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D;&ES=%LG9&ER)UU;,%TI*2![#0H@("`@("`@("`@("`@
M("`@("`@("1L:7-T6R=D:7(G72`](&%R<F%Y*"1L:7-T6R=D:7(G72D[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1L
M:7-T6R=D:7(G72!A<R`D9&ER*2![#0H@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D9&ER6R=A='1R:6)S)UTI("8F(&ES<V5T*"1D:7);)V%T=')I
M8G,G75LG;F%M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"1D:7);)V%T=')I8G,G75LG;F%M92==(#T]("<O)R!\?`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)V-O;G1E;G1S)UU;)V1I<B==6R=D:7(G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`O+R!A;'=A>7,@=7-E(&YO=&AI;F<@:68@=&AE
M(&9I;&5L:7-T(&AA<R!A;')E861Y(&)E96X@9FQA='1E;F5D#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&YE=V1I<G,@/2`G)SL-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T@96QS96EF("@D9&ER<R`]/2`G)RD@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1N97=D:7)S(#T@)&1I<ELG871T
M<FEB<R==6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N97=D:7)S(#T@
M)&1I<G,@+B`G+R<@+B`D9&ER6R=A='1R:6)S)UU;)VYA;64G73L-"B`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1N97=D:7)S(#T@)&1I
M<G,[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]V86QI9&%T949I;&5L:7-T*"1D:7(L("1A;&QO=VEG;F]R
M92P@)&YE=V1I<G,I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T:6]N(%]V86QI9&%T
M95)E;&5A<V4H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)W!H<')E;&5A<V4G72DI('L-"B`@("`@("`@("`@("1R
M96QE87-E(#T@)W!H<')E;&5A<V4G.PT*("`@("`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)W!R;W9I9&5S97AT96YS:6]N)UTI*2![
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]C86YN;W10<F]V:61E17AT96YS
M:6]N*"1R96QE87-E*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=S<F-P86-K86=E)UTI('Q\
M(&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W-R8W5R:2==*2D@>PT*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8V%N;F]T2&%V95-R8W!A8VMA9V4H)')E
M;&5A<V4I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)')E;&5A<V5S
M(#T@)'1H:7,M/E]P86-K86=E26YF;ULG<&AP<F5L96%S92==.PT*("`@("`@
M("`@("`@:68@*"%I<U]A<G)A>2@D<F5L96%S97,I*2![#0H@("`@("`@("`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1R96QE87-E<ULP72DI('L-"B`@("`@("`@("`@("`@
M("`D<F5L96%S97,@/2!A<G)A>2@D<F5L96%S97,I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@9F]R96%C:"`H)')E;&5A<V5S(&%S("1R96PI('L-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-T=7!I9%-C:&5M859A;&ED871E
M*&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G*FEN<W1A;&QC;VYD:71I
M;VYS)RP-"B`@("`@("`@("`@("`@("`@("`@)RIF:6QE;&ES="<L#0H@("`@
M("`@("`@("`@("`@*2P@)')E;"P@)SQP:'!R96QE87-E/B<I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7W!A8VMA9V5);F9O6R=E>'1S<F-R96QE87-E)UTI*2![#0H@("`@("`@("`@
M("`D<F5L96%S92`]("=E>'1S<F-R96QE87-E)SL-"B`@("`@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<')O=FED97-E>'1E;G-I
M;VXG72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VUU<W10<F]V:61E
M17AT96YS:6]N*"1R96QE87-E*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=S<F-P86-K86=E
M)UTI('Q\(&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W-R8W5R:2==*2D@
M>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V%N;F]T2&%V95-R8W!A8VMA
M9V4H)')E;&5A<V4I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)')E
M;&5A<V5S(#T@)'1H:7,M/E]P86-K86=E26YF;ULG97AT<W)C<F5L96%S92==
M.PT*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D<F5L96%S97,I*2![#0H@
M("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1R96QE87-E<ULP72DI('L-"B`@("`@
M("`@("`@("`@("`D<F5L96%S97,@/2!A<G)A>2@D<F5L96%S97,I.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)')E;&5A<V5S(&%S
M("1R96PI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-T=7!I9%-C:&5M
M859A;&ED871E*&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G*FEN<W1A
M;&QC;VYD:71I;VYS)RP-"B`@("`@("`@("`@("`@("`@("`@)RIC;VYF:6=U
M<F5O<'1I;VXM/FYA;64M/G!R;VUP="T^/V1E9F%U;'0G+`T*("`@("`@("`@
M("`@("`@("`@("`G*F)I;F%R>7!A8VMA9V4G+`T*("`@("`@("`@("`@("`@
M("`@("`G*F9I;&5L:7-T)RP-"B`@("`@("`@("`@("`@("`I+"`D<F5L+"`G
M/&5X='-R8W)E;&5A<V4^)RD[#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1R96Q;)V)I;F%R>7!A8VMA9V4G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<U]A<G)A>2@D<F5L6R=B:6YA<GEP86-K86=E)UTI('Q\("%I
M<W-E="@D<F5L6R=B:6YA<GEP86-K86=E)UU;,%TI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D<F5L6R=B:6YA<GEP86-K86=E)UT@/2!A<G)A>2@D
M<F5L6R=B:6YA<GEP86-K86=E)UTI.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R96Q;)V)I;F%R>7!A
M8VMA9V4G72!A<R`D8FEN*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES7W-T<FEN9R@D8FEN*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?8FEN87)Y4&%C:V%G94UU<W1"95!A8VMA9V5N86UE
M*"D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)V5X=&)I;G)E;&5A<V4G72DI('L-"B`@("`@("`@("`@("1R96QE87-E
M(#T@)V5X=&)I;G)E;&5A<V4G.PT*("`@("`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^7W!A8VMA9V5);F9O6R=P<F]V:61E<V5X=&5N<VEO;B==*2D@>PT*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?;75S=%!R;W9I9&5%>'1E;G-I;VXH
M)')E;&5A<V4I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-H86YN96PG72D@)B8-"B`@("`@
M("`@("`@("`@("`@("%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=S<F-P
M86-K86=E)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]M=7-T4W)C
M4&%C:V%G92@D<F5L96%S92D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG=7)I)UTI("8F("%I
M<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=S<F-U<FDG72DI('L-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7VUU<W13<F-U<FDH)')E;&5A<V4I.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)')E;&5A<V5S(#T@)'1H:7,M/E]P
M86-K86=E26YF;ULG97AT8FEN<F5L96%S92==.PT*("`@("`@("`@("`@:68@
M*"%I<U]A<G)A>2@D<F5L96%S97,I*2![#0H@("`@("`@("`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1R96QE87-E<ULP72DI('L-"B`@("`@("`@("`@("`@("`D<F5L96%S
M97,@/2!A<G)A>2@D<F5L96%S97,I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@9F]R96%C:"`H)')E;&5A<V5S(&%S("1R96PI('L-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7W-T=7!I9%-C:&5M859A;&ED871E*&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("`@("`G*FEN<W1A;&QC;VYD:71I;VYS)RP-"B`@
M("`@("`@("`@("`@("`@("`@)RIF:6QE;&ES="<L#0H@("`@("`@("`@("`@
M("`@*2P@)')E;"P@)SQE>'1B:6YR96QE87-E/B<I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA
M9V5);F9O6R=B=6YD;&4G72DI('L-"B`@("`@("`@("`@("1R96QE87-E(#T@
M)V)U;F1L92<[#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K
M86=E26YF;ULG<')O=FED97-E>'1E;G-I;VXG72DI('L-"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V-A;FYO=%!R;W9I9&5%>'1E;G-I;VXH)')E;&5A<V4I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)W-R8W!A8VMA9V4G72D@?'P@:7-S970H)'1H:7,M
M/E]P86-K86=E26YF;ULG<W)C=7)I)UTI*2![#0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]C86YN;W1(879E4W)C<&%C:V%G92@D<F5L96%S92D[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D<F5L96%S97,@/2`D=&AI<RT^7W!A
M8VMA9V5);F9O6R=B=6YD;&4G73L-"B`@("`@("`@("`@(&EF("@A:7-?87)R
M87DH)')E;&5A<V5S*2!\?"`A:7-S970H)')E;&5A<V5S6S!=*2D@>PT*("`@
M("`@("`@("`@("`@("1R96QE87-E<R`](&%R<F%Y*"1R96QE87-E<RD[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E86-H("@D<F5L96%S97,@
M87,@)')E;"D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1U<&ED4V-H
M96UA5F%L:61A=&4H87)R87DH#0H@("`@("`@("`@("`@("`@("`@("<J:6YS
M=&%L;&-O;F1I=&EO;G,G+`T*("`@("`@("`@("`@("`@("`@("`G*F9I;&5L
M:7-T)RP-"B`@("`@("`@("`@("`@("`I+"`D<F5L+"`G/&)U;F1L93XG*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D
M<F5L96%S97,@87,@)')E;"D@>PT*("`@("`@("`@("`@:68@*&ES7V%R<F%Y
M*"1R96PI("8F(&%R<F%Y7VME>5]E>&ES=',H)VEN<W1A;&QC;VYD:71I;VYS
M)RP@)')E;"DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E
M26YS=&%L;$-O;F1I=&EO;G,H)')E;%LG:6YS=&%L;&-O;F1I=&EO;G,G72P-
M"B`@("`@("`@("`@("`@("`@("`@(CPD<F5L96%S93X\:6YS=&%L;&-O;F1I
M=&EO;G,^(BD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-?
M87)R87DH)')E;"D@)B8@87)R87E?:V5Y7V5X:7-T<R@G9FEL96QI<W0G+"`D
M<F5L*2D@>PT*("`@("`@("`@("`@("`@(&EF("@D<F5L6R=F:6QE;&ES="==
M*2![#0H@("`@("`@("`@("`@("`@("`@(`T*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W9A;&ED871E1FEL96QI<W0H)')E;%LG9FEL96QI<W0G72P@
M=')U92D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@5&AI<R!I<R!H97)E
M('1O(&%L;&]W(')O;&4@97AT96YS:6]N('1H<F]U9V@@<&QU9VEN<PT*("`@
M("`J($!P87)A;2!S=')I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?=F%L
M:61A=&52;VQE*"1R;VQE*0T*("`@('L-"B`@("`@("`@<F5T=7)N(&EN7V%R
M<F%Y*"1R;VQE+"!014%27TEN<W1A;&QE<E]2;VQE.CIG971686QI9%)O;&5S
M*"1T:&ES+3Y?<&8M/F=E=%!A8VMA9V54>7!E*"DI*3L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!?:6YV86QI9%1A9T]R9&5R*"1O:W1A9W,L("1A8W1U86PL
M("1R;V]T*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?
M7T953D-424].7U\L("=E<G)O<B<L#0H@("`@("`@("`@("!A<G)A>2@G;VMT
M86=S)R`]/B`D;VMT86=S+"`G86-T=6%L)R`]/B`D86-T=6%L+"`G<F]O="<@
M/3X@)')O;W0I+`T*("`@("`@("`@("`@)TEN=F%L:60@=&%G(&]R9&5R(&EN
M("5R;V]T)2P@9F]U;F0@/"5A8W1U86PE/B!E>'!E8W1E9"!O;F4@;V8@(B5O
M:W1A9W,E(B<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]I9VYO<F5.;W1!
M;&QO=V5D*"1T>7!E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^
M<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=T>7!E)R`]/B`D
M='EP92DL#0H@("`@("`@("`@("`G/"5T>7!E)3X@:7,@;F]T(&%L;&]W960@
M:6YS:61E(&=L;V)A;"`\8V]N=&5N=',^+"!O;FQY(&EN<VED92`G("X-"B`@
M("`@("`@("`@("<\<&AP<F5L96%S93XO/&5X=&)I;G)E;&5A<V4^+"!U<V4@
M/&1I<CX@86YD(#QF:6QE/B!O;FQY)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@7V9I;&5.;W1!;&QO=V5D*"1T>7!E*0T*("`@('L-"B`@("`@("`@)'1H
M:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y
M*"=T>7!E)R`]/B`D='EP92DL#0H@("`@("`@("`@("`G/"5T>7!E)3X@:7,@
M;F]T(&%L;&]W960@:6YS:61E(')E;&5A<V4@/&9I;&5L:7-T/BP@;VYL>2!I
M;G-I9&4@)R`N#0H@("`@("`@("`@("`G/&-O;G1E;G1S/BP@=7-E(#QI9VYO
M<F4^(&%N9"`\:6YS=&%L;#X@;VYL>2<I.PT*("`@('T-"@T*("`@(&9U;F-T
M:6]N(%]T86=-:7-S:6YG071T<FEB=71E*"1T86<L("1A='1R+"`D8V]N=&5X
M="D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#
M5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G=&%G)R`]/B`D=&%G+`T*("`@("`@
M("`@("`@)V%T=')I8G5T92<@/3X@)&%T='(L("=C;VYT97AT)R`]/B`D8V]N
M=&5X="DL#0H@("`@("`@("`@("`G=&%G(#PE=&%G)3X@:6X@8V]N=&5X="`B
M)6-O;G1E>'0E(B!H87,@;F\@871T<FEB=71E("(E871T<FEB=71E)2(G*3L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?=&%G2&%S3F]!='1R:6)S*"1T86<L
M("1C;VYT97AT*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S
M:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=T86<G(#T^("1T86<L
M#0H@("`@("`@("`@("`G8V]N=&5X="<@/3X@)&-O;G1E>'0I+`T*("`@("`@
M("`@("`@)W1A9R`\)71A9R4^(&AA<R!N;R!A='1R:6)U=&5S(&EN(&-O;G1E
M>'0@(B5C;VYT97AT)2(G*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?:6YV
M86QI9$EN=&5R;F%L4W1R=6-T=7)E*"D-"B`@("![#0H@("`@("`@("1T:&ES
M+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97AC97!T:6]N)RP@87)R
M87DH*2P-"B`@("`@("`@("`@("=I;G1E<FYA;"!A<G)A>2!W87,@;F]T(&=E
M;F5R871E9"!B>2!C;VUP871I8FQE('!A<G-E<BP@;W(@97AT<F5M92!P87)S
M97(@97)R;W(L(&-A;FYO="!C;VYT:6YU92<I.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(%]I;G9A;&ED1FEL95)O;&4H)&9I;&4L("1D:7(L("1R;VQE*0T*
M("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].
M7U\L("=E<G)O<B<L(&%R<F%Y*`T*("`@("`@("`@("`@)V9I;&4G(#T^("1F
M:6QE+"`G9&ER)R`]/B`D9&ER+"`G<F]L92<@/3X@)')O;&4L#0H@("`@("`@
M("`@("`G<F]L97,G(#T^(%!%05)?26YS=&%L;&5R7U)O;&4Z.F=E=%9A;&ED
M4F]L97,H)'1H:7,M/E]P9BT^9V5T4&%C:V%G951Y<&4H*2DI+`T*("`@("`@
M("`@("`@)T9I;&4@(B5F:6QE)2(@:6X@9&ER96-T;W)Y("(E9&ER)2(@:&%S
M(&EN=F%L:60@<F]L92`B)7)O;&4E(BP@<VAO=6QD(&)E(&]N92!O9B`E<F]L
M97,E)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7VEN=F%L:61&:6QE3F%M
M92@D9FEL92P@)&1I<BD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM
M/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@-"B`@("`@("`@
M("`@("=F:6QE)R`]/B`D9FEL92DL#0H@("`@("`@("`@("`G1FEL92`B)69I
M;&4E(B!C86YN;W0@8F5G:6X@=VET:"`B+B(G*3L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!?9FEL96QI<W1#86YN;W1#;VYT86EN1FEL92@D9FEL96QI<W0I
M#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)
M3TY?7RP@)V5R<F]R)RP@87)R87DH)W1A9R<@/3X@)&9I;&5L:7-T*2P-"B`@
M("`@("`@("`@("<\)71A9R4^(&-A;B!O;FQY(&-O;G1A:6X@/&1I<CXL(&-O
M;G1A:6YS(#QF:6QE/BX@(%5S92`G("X-"B`@("`@("`@("`@("<\9&ER(&YA
M;64](B\B/B!A<R!T:&4@9FER<W0@9&ER(&5L96UE;G0G*3L-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!?9FEL96QI<W1-=7-T0V]N=&%I;D1I<B@D9FEL96QI
M<W0I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.
M0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)W1A9R<@/3X@)&9I;&5L:7-T*2P-
M"B`@("`@("`@("`@("<\)71A9R4^(&UU<W0@8V]N=&%I;B`\9&ER/BX@(%5S
M92`\9&ER(&YA;64](B\B/B!A<R!T:&4@)R`N#0H@("`@("`@("`@("`G9FER
M<W0@9&ER(&5L96UE;G0G*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?=&%G
M0V%N;F]T0F5%;7!T>2@D=&%G*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S
M=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=T86<G
M(#T^("1T86<I+`T*("`@("`@("`@("`@)SPE=&%G)3X@8V%N;F]T(&)E(&5M
M<'1Y("@\)71A9R4O/BDG*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?57)L
M3W)#:&%N;F5L*"1T>7!E+"`D;F%M92D-"B`@("![#0H@("`@("`@("1T:&ES
M+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G
M='EP92<@/3X@)'1Y<&4L#0H@("`@("`@("`@("`G;F%M92<@/3X@)&YA;64I
M+`T*("`@("`@("`@("`@)U)E<75I<F5D(&1E<&5N9&5N8WD@/"5T>7!E)3X@
M(B5N86UE)2(@8V%N(&AA=F4@96ET:&5R('5R;"!/4B`G("X-"B`@("`@("`@
M("`@("=C:&%N;F5L(&%T=')I8G5T97,L(&%N9"!N;W0@8F]T:"<I.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N(%].;T-H86YN96PH)'1Y<&4L("1N86UE*0T*
M("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].
M7U\L("=E<G)O<B<L(&%R<F%Y*"=T>7!E)R`]/B`D='EP92P-"B`@("`@("`@
M("`@("=N86UE)R`]/B`D;F%M92DL#0H@("`@("`@("`@("`G4F5Q=6ER960@
M9&5P96YD96YC>2`\)71Y<&4E/B`B)6YA;64E(B!M=7-T(&AA=F4@96ET:&5R
M('5R;"!/4B`G("X-"B`@("`@("`@("`@("=C:&%N;F5L(&%T=')I8G5T97,G
M*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?57)L3W)#:&%N;F5L1W)O=7`H
M)'1Y<&4L("1N86UE+"`D9W)O=7`I#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)W1Y
M<&4G(#T^("1T>7!E+`T*("`@("`@("`@("`@)VYA;64G(#T^("1N86UE+"`G
M9W)O=7`G(#T^("1G<F]U<"DL#0H@("`@("`@("`@("`G1W)O=7`@(B5G<F]U
M<"4B(&1E<&5N9&5N8WD@/"5T>7!E)3X@(B5N86UE)2(@8V%N(&AA=F4@96ET
M:&5R('5R;"!/4B`G("X-"B`@("`@("`@("`@("=C:&%N;F5L(&%T=')I8G5T
M97,L(&%N9"!N;W0@8F]T:"<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%].
M;T-H86YN96Q'<F]U<"@D='EP92P@)&YA;64L("1G<F]U<"D-"B`@("![#0H@
M("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R
M;W(G+"!A<G)A>2@G='EP92<@/3X@)'1Y<&4L#0H@("`@("`@("`@("`G;F%M
M92<@/3X@)&YA;64L("=G<F]U<"<@/3X@)&=R;W5P*2P-"B`@("`@("`@("`@
M("='<F]U<"`B)6=R;W5P)2(@9&5P96YD96YC>2`\)71Y<&4E/B`B)6YA;64E
M(B!M=7-T(&AA=F4@96ET:&5R('5R;"!/4B`G("X-"B`@("`@("`@("`@("=C
M:&%N;F5L(&%T=')I8G5T97,G*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?
M=6YK;F]W;D-H86YN96PH)&-H86YN96PI#0H@("`@>PT*("`@("`@("`D=&AI
M<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH
M)V-H86YN96PG(#T^("1C:&%N;F5L*2P-"B`@("`@("`@("`@("=5;FMN;W=N
M(&-H86YN96P@(B5C:&%N;F5L)2(G*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!?;F]086-K86=E5F5R<VEO;B@I#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH*2P-
M"B`@("`@("`@("`@("=P86-K86=E+GAM;"`\<&%C:V%G93X@=&%G(&AA<R!N
M;R!V97)S:6]N(&%T=')I8G5T92P@;W(@=F5R<VEO;B!I<R!N;W0@,BXP)RD[
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7TYO0G5N9&QE9%!A8VMA9V5S*"D-
M"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/
M3E]?+"`G97)R;W(G+"!A<G)A>2@I+`T*("`@("`@("`@("`@)TYO(#QB=6YD
M;&5D<&%C:V%G93X@=&%G('=A<R!F;W5N9"!I;B`\8V]N=&5N=',^+"!R97%U
M:7)E9"!F;W(@8G5N9&QE('!A8VMA9V5S)RD[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@7T%T3&5A<W0R0G5N9&QE9%!A8VMA9V5S*"D-"B`@("![#0H@("`@
M("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G
M+"!A<G)A>2@I+`T*("`@("`@("`@("`@)T%T(&QE87-T(#(@<&%C:V%G97,@
M;75S="!B92!B=6YD;&5D(&EN(&$@8G5N9&QE('!A8VMA9V4G*3L-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!?0VAA;FYE;$]R57)I*"1N86UE*0T*("`@('L-
M"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E
M<G)O<B<L(&%R<F%Y*"=N86UE)R`]/B`D;F%M92DL#0H@("`@("`@("`@("`G
M0G5N9&QE9"!P86-K86=E("(E;F%M924B(&-A;B!H879E(&5I=&AE<B!A('5R
M:2!O<B!A(&-H86YN96PL(&YO="!B;W1H)RD[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@7VYO0VAI;&1486<H)&-H:6QD+"`D=&%G*0T*("`@('L-"B`@("`@
M("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L
M(&%R<F%Y*"=C:&EL9"<@/3X@)&-H:6QD+"`G=&%G)R`]/B`D=&%G*2P-"B`@
M("`@("`@("`@("=486<@/"5T86<E/B!I<R!M:7-S:6YG(&-H:6QD('1A9R`\
M)6-H:6QD)3XG*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?:6YV86QI9%9E
M<G-I;VXH)'1Y<&4L("1V86QU92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?
M<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G='EP
M92<@/3X@)'1Y<&4L("=V86QU92<@/3X@)'9A;'5E*2P-"B`@("`@("`@("`@
M("=697)S:6]N('1Y<&4@/"5T>7!E)3X@:7,@;F]T(&$@=F%L:60@=F5R<VEO
M;B`H)79A;'5E)2DG*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?:6YV86QI
M9%-T871E*"1T>7!E+"`D=F%L=64I#0H@("`@>PT*("`@("`@("`D<W1A=&5S
M(#T@87)R87DH)W-T86)L92<L("=B971A)RP@)V%L<&AA)RP@)V1E=F5L)RD[
M#0H@("`@("`@(&EF("@D='EP92`A/2`G87!I)RD@>PT*("`@("`@("`@("`@
M)'-T871E<UM=(#T@)W-N87!S:&]T)SL-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H<W1R=&]L;W=E<B@D=F%L=64I(#T]("=R8R<I('L-"B`@("`@("`@("`@
M("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+`T*
M("`@("`@("`@("`@("`@(&%R<F%Y*"=V97)S:6]N)R`]/B`D=&AI<RT^7W!A
M8VMA9V5);F9O6R=V97)S:6]N)UU;)W)E;&5A<V4G72DL#0H@("`@("`@("`@
M("`@("`@)U)#(&ES(&YO="!A('-T871E+"!I="!I<R!A('9E<G-I;VX@<&]S
M=&9I>"P@=')Y("5V97)S:6]N)5)#,2P@<W1A8FEL:71Y(&)E=&$G*3L-"B`@
M("`@("`@?0T*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)
M3TY?7RP@)V5R<F]R)RP@87)R87DH)W1Y<&4G(#T^("1T>7!E+"`G=F%L=64G
M(#T^("1V86QU92P-"B`@("`@("`@("`@("=T>7!E<R<@/3X@)'-T871E<RDL
M#0H@("`@("`@("`@("`G4W1A8FEL:71Y('1Y<&4@/"5T>7!E)3X@:7,@;F]T
M(&$@=F%L:60@<W1A8FEL:71Y("@E=F%L=64E*2P@;75S="!B92!O;F4@;V8@
M)R`N#0H@("`@("`@("`@("`G)71Y<&5S)2<I.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(%]I;G9A;&ED5&%S:R@D=&%S:RP@)')E="P@)&9I;&4I#0H@("`@
M>PT*("`@("`@("!S=VET8V@@*"1R971;,%TI('L-"B`@("`@("`@("`@(&-A
M<V4@4$5!4E]405-+7T524D]27TU)4U-)3D=?05144DE"(#H-"B`@("`@("`@
M("`@("`@("`D:6YF;R`](&%R<F%Y*"=A='1R:6(G(#T^("1R971;,5TL("=T
M87-K)R`]/B`D=&%S:RP@)V9I;&4G(#T^("1F:6QE*3L-"B`@("`@("`@("`@
M("`@("`D;7-G(#T@)W1A<VL@/"5T87-K)3X@:7,@;6ES<VEN9R!A='1R:6)U
M=&4@(B5A='1R:6(E(B!I;B!F:6QE("5F:6QE)2<[#0H@("`@("`@("`@("!B
M<F5A:SL-"B`@("`@("`@("`@(&-A<V4@4$5!4E]405-+7T524D]27TY/0514
M4DE"4R`Z#0H@("`@("`@("`@("`@("`@)&EN9F\@/2!A<G)A>2@G=&%S:R<@
M/3X@)'1A<VLL("=F:6QE)R`]/B`D9FEL92D[#0H@("`@("`@("`@("`@("`@
M)&US9R`]("=T87-K(#PE=&%S:R4^(&AA<R!N;R!A='1R:6)U=&5S(&EN(&9I
M;&4@)69I;&4E)SL-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@
M8V%S92!014%27U1!4TM?15)23U)?5U)/3D=?05144DE"7U9!3%5%(#H-"B`@
M("`@("`@("`@("`@("`D:6YF;R`](&%R<F%Y*"=A='1R:6(G(#T^("1R971;
M,5TL("=V86QU97,G(#T^("1R971;,UTL#0H@("`@("`@("`@("`@("`@("`@
M("=W87,G(#T^("1R971;,ETL("=T87-K)R`]/B`D=&%S:RP@)V9I;&4G(#T^
M("1F:6QE*3L-"B`@("`@("`@("`@("`@("`D;7-G(#T@)W1A<VL@/"5T87-K
M)3X@871T<FEB=71E("(E871T<FEB)2(@:&%S('1H92!W<F]N9R!V86QU92`B
M)7=A<R4B("<N#0H@("`@("`@("`@("`@("`@("`@("=I;B!F:6QE("5F:6QE
M)2P@97AP96-T:6YG(&]N92!O9B`B)79A;'5E<R4B)SL-"B`@("`@("`@("`@
M(&)R96%K.PT*("`@("`@("`@("`@8V%S92!014%27U1!4TM?15)23U)?24Y6
M04Q)1"`Z#0H@("`@("`@("`@("`@("`@)&EN9F\@/2!A<G)A>2@G<F5A<V]N
M)R`]/B`D<F5T6S%=+"`G=&%S:R<@/3X@)'1A<VLL("=F:6QE)R`]/B`D9FEL
M92D[#0H@("`@("`@("`@("`@("`@)&US9R`]("=T87-K(#PE=&%S:R4^(&EN
M(&9I;&4@)69I;&4E(&ES(&EN=F%L:60@8F5C875S92!O9B`B)7)E87-O;B4B
M)SL-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!]#0H@("`@("`@("1T
M:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"`D:6YF
M;RP@)&US9RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7W5N:VYO=VY487-K
M*"1T87-K+"`D9FEL92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM
M/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G=&%S:R<@/3X@
M)'1A<VLL("=F:6QE)R`]/B`D9FEL92DL#0H@("`@("`@("`@("`G56YK;F]W
M;B!T87-K("(E=&%S:R4B('!A<W-E9"!I;B!F:6QE(#QF:6QE(&YA;64](B5F
M:6QE)2(^)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7W-U8G!A8VMA9V5#
M86YN;W10<F]V:61E17AT96YS:6]N*"1N86UE*0T*("`@('L-"B`@("`@("`@
M)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R
M<F%Y*"=N86UE)R`]/B`D;F%M92DL#0H@("`@("`@("`@("`G4W5B<&%C:V%G
M92!D97!E;F1E;F-Y("(E;F%M924B(&-A;FYO="!U<V4@/'!R;W9I9&5S97AT
M96YS:6]N/BP@)R`N#0H@("`@("`@("`@("`G;VYL>2!P86-K86=E(&1E<&5N
M9&5N8VEE<R!C86X@=7-E('1H:7,@=&%G)RD[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@7W-U8G!A8VMA9V5S0V%N;F]T0V]N9FQI8W0H)&YA;64I#0H@("`@
M>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@
M)V5R<F]R)RP@87)R87DH)VYA;64G(#T^("1N86UE*2P-"B`@("`@("`@("`@
M("=3=6)P86-K86=E(&1E<&5N9&5N8WD@(B5N86UE)2(@8V%N;F]T('5S92`\
M8V]N9FQI8W1S+SXL("<@+@T*("`@("`@("`@("`@)V]N;'D@<&%C:V%G92!D
M97!E;F1E;F-I97,@8V%N('5S92!T:&ES('1A9R<I.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N(%]C86YN;W10<F]V:61E17AT96YS:6]N*"1R96QE87-E*0T*
M("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].
M7U\L("=E<G)O<B<L(&%R<F%Y*"=R96QE87-E)R`]/B`D<F5L96%S92DL#0H@
M("`@("`@("`@("`G/"5R96QE87-E)3X@<&%C:V%G97,@8V%N;F]T('5S92`\
M<')O=FED97-E>'1E;G-I;VX^+"!O;FQY(&5X=&)I;G)E;&5A<V4@86YD(&5X
M='-R8W)E;&5A<V4@8V%N('!R;W9I9&4@82!02%`@97AT96YS:6]N)RD[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@7VUU<W10<F]V:61E17AT96YS:6]N*"1R
M96QE87-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?
M7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=R96QE87-E)R`]/B`D<F5L
M96%S92DL#0H@("`@("`@("`@("`G/"5R96QE87-E)3X@<&%C:V%G97,@;75S
M="!U<V4@/'!R;W9I9&5S97AT96YS:6]N/B!T;R!I;F1I8V%T92!W:&EC:"!0
M2%`@97AT96YS:6]N(&ES('!R;W9I9&5D)RD[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@7V-A;FYO=$AA=F53<F-P86-K86=E*"1R96QE87-E*0T*("`@('L-
M"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E
M<G)O<B<L(&%R<F%Y*"=R96QE87-E)R`]/B`D<F5L96%S92DL#0H@("`@("`@
M("`@("`G/"5R96QE87-E)3X@<&%C:V%G97,@8V%N;F]T('-P96-I9GD@82!S
M;W5R8V4@8V]D92!P86-K86=E+"!O;FQY(&5X=&5N<VEO;B!B:6YA<FEE<R!M
M87D@=7-E('1H92`\<W)C<&%C:V%G93X@=&%G)RD[#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@7VUU<W13<F-086-K86=E*"1R96QE87-E*0T*("`@('L-"B`@
M("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O
M<B<L(&%R<F%Y*"=R96QE87-E)R`]/B`D<F5L96%S92DL#0H@("`@("`@("`@
M("`G/&5X=&)I;G)E;&5A<V4^('!A8VMA9V5S(&UU<W0@<W!E8VEF>2!A('-O
M=7)C92!C;V1E('!A8VMA9V4@=VET:"`\<W)C<&%C:V%G93XG*3L-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!?;75S=%-R8W5R:2@D<F5L96%S92D-"B`@("![
M#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G
M97)R;W(G+"!A<G)A>2@G<F5L96%S92<@/3X@)')E;&5A<V4I+`T*("`@("`@
M("`@("`@)SQE>'1B:6YR96QE87-E/B!P86-K86=E<R!M=7-T('-P96-I9GD@
M82!S;W5R8V4@8V]D92!P86-K86=E('=I=&@@/'-R8W5R:3XG*3L-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!?=7)I1&5P<T-A;FYO=$AA=F5697)S:6]N:6YG
M*"1T>7!E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?
M7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=T>7!E)R`]/B`D='EP92DL
M#0H@("`@("`@("`@("`G)71Y<&4E.B!D97!E;F1E;F-I97,@=VET:"!A(#QU
M<FD^('1A9R!C86YN;W0@:&%V92!A;GD@=F5R<VEO;FEN9R!I;F9O<FUA=&EO
M;B<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]C;VYF;&EC=&EN9T1E<'-#
M86YN;W1(879E5F5R<VEO;FEN9R@D='EP92D-"B`@("![#0H@("`@("`@("1T
M:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A
M>2@G='EP92<@/3X@)'1Y<&4I+`T*("`@("`@("`@("`@)R5T>7!E)3H@8V]N
M9FQI8W1I;F<@9&5P96YD96YC:65S(&-A;FYO="!H879E('9E<G-I;VYI;F<@
M:6YF;RP@=7-E(#QE>&-L=61E/B!T;R`G("X-"B`@("`@("`@("`@("=E>&-L
M=61E('-P96-I9FEC('9E<G-I;VYS(&]F(&$@9&5P96YD96YC>2<I.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N(%]$97!C:&%N;F5L0V%N;F]T0F55<FDH)'1Y
M<&4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.
M0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)W1Y<&4G(#T^("1T>7!E*2P-"B`@
M("`@("`@("`@("<E='EP924Z(&-H86YN96P@8V%N;F]T(&)E(%]?=7)I+"!T
M:&ES(&ES(&$@<'-E=61O+6-H86YN96P@<F5S97)V960@9F]R('5R:2`G("X-
M"B`@("`@("`@("`@("=D97!E;F1E;F-I97,@;VYL>2<I.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N(%]B=6YD;&5D4&%C:V%G97--=7-T0F5&:6QE;F%M92@I
M#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)
M3TY?7RP@)V5R<F]R)RP@87)R87DH*2P-"B`@("`@("`@("`@("<\8G5N9&QE
M9'!A8VMA9V4^('1A9W,@;75S="!C;VYT86EN(&]N;'D@=&AE(&9I;&5N86UE
M(&]F(&$@<&%C:V%G92!R96QE87-E("<@+@T*("`@("`@("`@("`@)VEN('1H
M92!B=6YD;&4G*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?8FEN87)Y4&%C
M:V%G94UU<W1"95!A8VMA9V5N86UE*"D-"B`@("![#0H@("`@("`@("1T:&ES
M+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@I
M+`T*("`@("`@("`@("`@)SQB:6YA<GEP86-K86=E/B!T86=S(&UU<W0@8V]N
M=&%I;B!T:&4@;F%M92!O9B!A('!A8VMA9V4@=&AA="!I<R`G("X-"B`@("`@
M("`@("`@("=A(&-O;7!I;&5D('9E<G-I;VX@;V8@=&AI<R!E>'1S<F,@<&%C
M:V%G92<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]F:6QE3F]T1F]U;F0H
M)&9I;&4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?
M1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)V9I;&4G(#T^("1F:6QE*2P-
M"B`@("`@("`@("`@("=&:6QE("(E9FEL924B(&EN('!A8VMA9V4N>&UL(&1O
M97,@;F]T(&5X:7-T)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7VYO=$EN
M0V]N=&5N=',H)&9I;&4L("1T86<I#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)V9I
M;&4G(#T^("1F:6QE+"`G=&%G)R`]/B`D=&%G*2P-"B`@("`@("`@("`@("<\
M)71A9R4@;F%M93TB)69I;&4E(CX@:7,@:6YV86QI9"P@9FEL92!I<R!N;W0@
M:6X@/&-O;G1E;G1S/B<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]C86YN
M;W1686QI9&%T94YO4&%T:%-E="@I#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH*2P-
M"B`@("`@("`@("`@("=#86YN;W0@=F%L:61A=&4@9FEL97,L(&YO('!A=&@@
M=&\@<&%C:V%G92!F:6QE(&ES('-E="`H=7-E('-E=%!A8VMA9V5&:6QE*"DI
M)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7W5S97-R;VQE=&%S:TUU<W1(
M879E0VAA;FYE;$]R57)I*"1R;VQE+"`D=&%G*0T*("`@('L-"B`@("`@("`@
M)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R
M<F%Y*"=R;VQE)R`]/B`D<F]L92P@)W1A9R<@/3X@)'1A9RDL#0H@("`@("`@
M("`@("`G/"5T86<E/B!M=7-T(&-O;G1A:6X@96ET:&5R(#QU<FD^+"!O<B`\
M8VAA;FYE;#X@86YD(#QP86-K86=E/B<I.PT*("`@('T-"@T*("`@(&9U;F-T
M:6]N(%]U<V5S<F]L971A<VM-=7-T2&%V95!A8VMA9V4H)')O;&4L("1T86<I
M#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)
M3TY?7RP@)V5R<F]R)RP@87)R87DH)W)O;&4G(#T^("1R;VQE+"`G=&%G)R`]
M/B`D=&%G*2P-"B`@("`@("`@("`@("<\)71A9R4^(&UU<W0@8V]N=&%I;B`\
M<&%C:V%G93XG*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?=7-E<W)O;&5T
M87-K375S=$AA=F52;VQE5&%S:R@D=&%G+"`D='EP92D-"B`@("![#0H@("`@
M("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G
M+"!A<G)A>2@G=&%G)R`]/B`D=&%G+"`G='EP92<@/3X@)'1Y<&4I+`T*("`@
M("`@("`@("`@)SPE=&%G)3X@;75S="!C;VYT86EN(#PE='EP924^(&1E9FEN
M:6YG('1H92`E='EP924@=&\@8F4@=7-E9"<I.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(%]C86YN;W1#;VYF;&EC=%=I=&A!;&Q/<R@D='EP92D-"B`@("![
M#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G
M97)R;W(G+"!A<G)A>2@G=&%G)R`]/B`D=&%G*2P-"B`@("`@("`@("`@("<E
M=&%G)2!C86YN;W0@8V]N9FQI8W0@=VET:"!A;&P@3U-E<R<I.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N(%]I;G9A;&ED1&5P1W)O=7!.86UE*"1N86UE*0T*
M("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].
M7U\L("=E<G)O<B<L(&%R<F%Y*"=G<F]U<"<@/3X@)&YA;64I+`T*("`@("`@
M("`@("`@)TEN=F%L:60@9&5P96YD96YC>2!G<F]U<"!N86UE("(E;F%M924B
M)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7V%N86QY>F5"=6YD;&5D4&%C
M:V%G97,H*0T*("`@('L-"B`@("`@("`@:68@*"$D=&AI<RT^7VES5F%L:60I
M('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H(21T:&ES+3Y?<&8M/F=E=%!A8VMA9V54>7!E*"D@/3T@)V)U
M;F1L92<I('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&8M/E]P86-K86=E1FEL
M92DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*
M("`@("`@("`D9&ER7W!R969I>"`](&1I<FYA;64H)'1H:7,M/E]P9BT^7W!A
M8VMA9V5&:6QE*3L-"B`@("`@("`@)&QO9R`](&ES<V5T*"1T:&ES+3Y?<&8M
M/E]L;V=G97(I(#\@87)R87DH)B1T:&ES+3Y?<&8M/E]L;V=G97(L("=L;V<G
M*2`Z#0H@("`@("`@("`@("!A<G)A>2@G4$5!4E]#;VUM;VXG+"`G;&]G)RD[
M#0H@("`@("`@("1I;F9O(#T@)'1H:7,M/E]P9BT^9V5T0V]N=&5N=',H*3L-
M"B`@("`@("`@)&EN9F\@/2`D:6YF;ULG8G5N9&QE9'!A8VMA9V4G73L-"B`@
M("`@("`@:68@*"%I<U]A<G)A>2@D:6YF;RDI('L-"B`@("`@("`@("`@("1I
M;F9O(#T@87)R87DH)&EN9F\I.PT*("`@("`@("!]#0H@("`@("`@("1P:V<@
M/2`F;F5W(%!%05)?4&%C:V%G949I;&4H)'1H:7,M/E]P9BT^7V-O;F9I9RD[
M#0H@("`@("`@(&9O<F5A8V@@*"1I;F9O(&%S("1P86-K86=E*2![#0H@("`@
M("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1D:7)?<')E9FEX("X@1$E214-4
M3U)97U-%4$%2051/4B`N("1P86-K86=E*2D@>PT*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?9FEL94YO=$9O=6YD*"1D:7)?<')E9FEX("X@1$E214-43U)9
M7U-%4$%2051/4B`N("1P86-K86=E*3L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7VES5F%L:60@/2`P.PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F-?87)R
M87DH)&QO9RP@87)R87DH,2P@(D%N86QY>FEN9R!B=6YD;&5D('!A8VMA9V4@
M)'!A8VMA9V4B*2D[#0H@("`@("`@("`@("!014%2.CIP=7-H17)R;W)(86YD
M;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("`@("`D<F5T(#T@
M)'!K9RT^9G)O;4%N>49I;&4H)&1I<E]P<F5F:7@@+B!$25)%0U1/4EE?4T50
M05)!5$]2("X@)'!A8VMA9V4L#0H@("`@("`@("`@("`@("`@4$5!4E]604Q)
M1$%415].3U)-04PI.PT*("`@("`@("`@("`@4$5!4CHZ<&]P17)R;W)(86YD
M;&EN9R@I.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E="DI
M('L-"B`@("`@("`@("`@("`@("!C86QL7W5S97)?9G5N8U]A<G)A>2@D;&]G
M+"!A<G)A>2@P+"`B15)23U(Z('!A8VMA9V4@)'!A8VMA9V4@:7,@;F]T(&$@
M=F%L:60@(B`N#0H@("`@("`@("`@("`@("`@("`@("=P86-K86=E)RDI.PT*
M("`@("`@("`@("`@("`@("1I;F8@/2`D<F5T+3YG9715<V5R26YF;R@I.PT*
M("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D:6YF*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("@D:6YF(&%S("1E<G(I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&-A;&Q?=7-E<E]F=6YC7V%R<F%Y*"1L;V<L
M(&%R<F%Y*#$L("1E<G);)VUE<W-A9V4G72DI.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?86YA;'EZ
M95!H<$9I;&5S*"D-"B`@("![#0H@("`@("`@(&EF("@A)'1H:7,M/E]I<U9A
M;&ED*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!F+3Y?<&%C:V%G949I;&4I
M*2![#0H@("`@("`@("`@("`D=&AI<RT^7V-A;FYO=%9A;&ED871E3F]0871H
M4V5T*"D[#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-
M"B`@("`@("`@)&1I<E]P<F5F:7@@/2!D:7)N86UE*"1T:&ES+3Y?<&8M/E]P
M86-K86=E1FEL92D[#0H@("`@("`@("1C;VUM;VX@/2!N97<@4$5!4E]#;VUM
M;VX[#0H@("`@("`@("1L;V<@/2!I<W-E="@D=&AI<RT^7W!F+3Y?;&]G9V5R
M*2`_(&%R<F%Y*"8D=&AI<RT^7W!F+3Y?;&]G9V5R+"`G;&]G)RD@.@T*("`@
M("`@("`@("`@87)R87DH)B1C;VUM;VXL("=L;V<G*3L-"B`@("`@("`@)&EN
M9F\@/2`D=&AI<RT^7W!F+3YG971#;VYT96YT<R@I.PT*("`@("`@("`D:6YF
M;R`]("1I;F9O6R=D:7(G75LG9FEL92==.PT*("`@("`@("!I9B`H:7-S970H
M)&EN9F];)V%T=')I8G,G72DI('L-"B`@("`@("`@("`@("1I;F9O(#T@87)R
M87DH)&EN9F\I.PT*("`@("`@("!]#0H@("`@("`@("1P<F]V:61E<R`](&%R
M<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1I;F9O(&%S("1F82D@>PT*("`@
M("`@("`@("`@)&9A(#T@)&9A6R=A='1R:6)S)UT[#0H@("`@("`@("`@("`D
M9FEL92`]("1F85LG;F%M92==.PT*("`@("`@("`@("`@:68@*"%F:6QE7V5X
M:7-T<R@D9&ER7W!R969I>"`N($1)4D5#5$]265]315!!4D%43U(@+B`D9FEL
M92DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V9I;&5.;W1&;W5N9"@D
M9&ER7W!R969I>"`N($1)4D5#5$]265]315!!4D%43U(@+B`D9FEL92D[#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@
M("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&EF("AI;E]A<G)A>2@D9F%;)W)O;&4G72P@4$5!4E]);G-T86QL97)?4F]L
M93HZ9V5T4&AP4F]L97,H*2D@)B8@)&1I<E]P<F5F:7@I('L-"B`@("`@("`@
M("`@("`@("!C86QL7W5S97)?9G5N8U]A<G)A>2@D;&]G+"!A<G)A>2@Q+"`B
M06YA;'EZ:6YG("1F:6QE(BDI.PT*("`@("`@("`@("`@("`@("1S<F-I;F9O
M(#T@)'1H:7,M/F%N86QY>F53;W5R8V5#;V1E*"1D:7)?<')E9FEX("X@1$E2
M14-43U)97U-%4$%2051/4B`N("1F:6QE*3L-"B`@("`@("`@("`@("`@("!I
M9B`H)'-R8VEN9F\I('L-"B`@("`@("`@("`@("`@("`@("`@)'!R;W9I9&5S
M(#T@87)R87E?;65R9V4H)'!R;W9I9&5S+"`D=&AI<RT^7V)U:6QD4')O=FED
M97-!<G)A>2@D<W)C:6YF;RDI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W!A8VMA9V5.
M86UE(#T@)'!N(#T@)'1H:7,M/E]P9BT^9V5T4&%C:V%G92@I.PT*("`@("`@
M("`D<&YL(#T@<W1R;&5N*"1P;BD[#0H@("`@("`@(&9O<F5A8V@@*"1P<F]V
M:61E<R!A<R`D:V5Y(#T^("1W:&%T*2![#0H@("`@("`@("`@("!I9B`H:7-S
M970H)'=H871;)V5X<&QI8VET)UTI('Q\("$D=VAA="D@>PT*("`@("`@("`@
M("`@("`@("\O('-K:7`@8V]N9F]R;6%N8V4@8VAE8VMS(&EF('1H92!P<F]V
M:61E<R!E;G1R>2!I<PT*("`@("`@("`@("`@("`@("\O('-P96-I9FEE9"!I
M;B!T:&4@<&%C:V%G92YX;6P@9FEL90T*("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@97AT<F%C="@D=VAA
M="D[#0H@("`@("`@("`@("!I9B`H)'1Y<&4@/3T@)V-L87-S)RD@>PT*("`@
M("`@("`@("`@("`@(&EF("@A<W1R;F-A<V5C;7`H)&YA;64L("1P;BP@)'!N
M;"DI('L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U
M<V@H7U]&54Y#5$E/3E]?+"`G=V%R;FEN9R<L#0H@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"=F:6QE)R`]/B`D9FEL92P@)W1Y<&4G(#T^("1T>7!E+"`G
M;F%M92<@/3X@)&YA;64L("=P86-K86=E)R`]/B`D<&XI+`T*("`@("`@("`@
M("`@("`@("`@("`G:6X@)69I;&4E.B`E='EP924@(B5N86UE)2(@;F]T('!R
M969I>&5D('=I=&@@<&%C:V%G92!N86UE("(E<&%C:V%G924B)RD[#0H@("`@
M("`@("`@("!](&5L<V5I9B`H)'1Y<&4@/3T@)V9U;F-T:6]N)RD@>PT*("`@
M("`@("`@("`@("`@(&EF("AS=')S='(H)&YA;64L("<Z.B<I('Q\("%S=')N
M8V%S96-M<"@D;F%M92P@)'!N+"`D<&YL*2D@>PT*("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=W87)N
M:6YG)RP-"B`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I;&4G(#T^("1F
M:6QE+"`G='EP92<@/3X@)'1Y<&4L("=N86UE)R`]/B`D;F%M92P@)W!A8VMA
M9V4G(#T^("1P;BDL#0H@("`@("`@("`@("`@("`@("`@("=I;B`E9FEL924Z
M("5T>7!E)2`B)6YA;64E(B!N;W0@<')E9FEX960@=VET:"!P86-K86=E(&YA
M;64@(B5P86-K86=E)2(G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@)'1H:7,M/E]I<U9A;&ED.PT*("`@('T-"@T*("`@
M("\J*@T*("`@("`J($%N86QY>F4@=&AE('-O=7)C92!C;V1E(&]F('1H92!G
M:79E;B!02%`@9FEL90T*("`@("`J#0H@("`@("H@0'!A<F%M("!S=')I;F<@
M1FEL96YA;64@;V8@=&AE(%!(4"!F:6QE#0H@("`@("H@0'!A<F%M("!B;V]L
M96%N('=H971H97(@=&\@86YA;'EZ92`D9FEL92!A<R!T:&4@9FEL92!C;VYT
M96YT<PT*("`@("`J($!R971U<FX@;6EX960-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!A;F%L>7IE4V]U<F-E0V]D92@D9FEL92P@)'-T<FEN9R`](&9A;'-E
M*0T*("`@('L-"B`@("`@("`@:68@*"%F=6YC=&EO;E]E>&ES=',H(G1O:V5N
M7V=E=%]A;&PB*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S
M:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=F:6QE)R`]/B`D9FEL
M92DL#0H@("`@("`@("`@("`@("`@)U!A<G-E<B!E<G)O<CH@=&]K96Y?9V5T
M7V%L;"@I(&9U;F-T:6]N(&UU<W0@97AI<W0@=&\@86YA;'EZ92!S;W5R8V4@
M8V]D92<I.PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@A9&5F:6YE9"@G5%]$3T-?0T]-345.5"<I*2![#0H@
M("`@("`@("`@("!D969I;F4H)U1?1$]#7T-/34U%3E0G+"!47T-/34U%3E0I
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A9&5F:6YE9"@G5%])3E1%4D9!
M0T4G*2D@>PT*("`@("`@("`@("`@9&5F:6YE*"=47TE.5$521D%#12<L("TQ
M*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(61E9FEN960H)U1?24U03$5-
M14Y44R<I*2![#0H@("`@("`@("`@("!D969I;F4H)U1?24U03$5-14Y44R<L
M("TQ*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'-T<FEN9RD@>PT*("`@
M("`@("`@("`@)&-O;G1E;G1S(#T@)&9I;&4[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("!I9B`H(21F<"`]($!F;W!E;B@D9FEL92P@(G(B*2D@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T
M7V-O;G1E;G1S)RDI('L-"B`@("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L-
M"B`@("`@("`@("`@("`@("`D8V]N=&5N=',@/2!F:6QE7V=E=%]C;VYT96YT
M<R@D9FEL92D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("1C;VYT96YT<R`]($!F<F5A9"@D9G`L(&9I;&5S:7IE*"1F:6QE*2D[
M#0H@("`@("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@)'1O:V5N<R`]('1O:V5N7V=E=%]A;&PH
M)&-O;G1E;G1S*3L-"B\J#0H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I
M>F5O9B@D=&]K96YS*3L@)&DK*RD@>PT*("`@("`@("`@("`@0&QI<W0H)'1O
M:V5N+"`D9&%T82D@/2`D=&]K96YS6R1I73L-"B`@("`@("`@("`@(&EF("AI
M<U]S=')I;F<H)'1O:V5N*2D@>PT*("`@("`@("`@("`@("`@('9A<E]D=6UP
M*"1T;VME;BD[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@('!R:6YT('1O:V5N7VYA;64H)'1O:V5N*2`N("<@)SL-"B`@("`@("`@
M("`@("`@("!V87)?9'5M<"AR=')I;2@D9&%T82DI.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0HJ+PT*("`@("`@("`D;&]O:U]F;W(@/2`P.PT*("`@
M("`@("`D<&%R96Y?;&5V96P@/2`P.PT*("`@("`@("`D8G)A8VME=%]L979E
M;"`](#`[#0H@("`@("`@("1B<F%C95]L979E;"`](#`[#0H@("`@("`@("1L
M87-T<&AP9&]C(#T@)R<[#0H@("`@("`@("1C=7)R96YT7V-L87-S(#T@)R<[
M#0H@("`@("`@("1C=7)R96YT7VEN=&5R9F%C92`]("<G.PT*("`@("`@("`D
M8W5R<F5N=%]C;&%S<U]L979E;"`]("TQ.PT*("`@("`@("`D8W5R<F5N=%]F
M=6YC=&EO;B`]("<G.PT*("`@("`@("`D8W5R<F5N=%]F=6YC=&EO;E]L979E
M;"`]("TQ.PT*("`@("`@("`D9&5C;&%R961?8VQA<W-E<R`](&%R<F%Y*"D[
M#0H@("`@("`@("1D96-L87)E9%]I;G1E<F9A8V5S(#T@87)R87DH*3L-"B`@
M("`@("`@)&1E8VQA<F5D7V9U;F-T:6]N<R`](&%R<F%Y*"D[#0H@("`@("`@
M("1D96-L87)E9%]M971H;V1S(#T@87)R87DH*3L-"B`@("`@("`@)'5S961?
M8VQA<W-E<R`](&%R<F%Y*"D[#0H@("`@("`@("1U<V5D7V9U;F-T:6]N<R`]
M(&%R<F%Y*"D[#0H@("`@("`@("1E>'1E;F1S(#T@87)R87DH*3L-"B`@("`@
M("`@)&EM<&QE;65N=',@/2!A<G)A>2@I.PT*("`@("`@("`D;F]D97!S(#T@
M87)R87DH*3L-"B`@("`@("`@)&EN<75O=&4@/2!F86QS93L-"B`@("`@("`@
M)&EN=&5R9F%C92`](&9A;'-E.PT*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@
M/"!S:7IE;V8H)'1O:V5N<RD[("1I*RLI('L-"B`@("`@("`@("`@(&EF("AI
M<U]A<G)A>2@D=&]K96YS6R1I72DI('L-"B`@("`@("`@("`@("`@("!L:7-T
M*"1T;VME;BP@)&1A=&$I(#T@)'1O:V5N<ULD:5T[#0H@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("1T;VME;B`]("1T;VME;G-;)&E=
M.PT*("`@("`@("`@("`@("`@("1D871A(#T@)R<[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!I9B`H)&EN<75O=&4I('L-"B`@("`@("`@("`@("`@
M("!I9B`H)'1O:V5N("$]("<B)R`F)B`D=&]K96X@(3T@5%]%3D1?2$52141/
M0RD@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D:6YQ=6]T
M92`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!S
M=VET8V@@*"1T;VME;BD@>PT*("`@("`@("`@("`@("`@(&-A<V4@5%]72$E4
M15-004-%(#H-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@
M("`@("`@("`@("`@8V%S92`G.R<Z#0H@("`@("`@("`@("`@("`@("`@(&EF
M("@D:6YT97)F86-E*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R
M<F5N=%]F=6YC=&EO;B`]("<G.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)&-U<G)E;G1?9G5N8W1I;VY?;&5V96P@/2`M,3L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@("`@("!C87-E("<B)SH-"B`@("`@("`@("`@("`@("!C87-E(%1?4U1!
M4E1?2$52141/0SH-"B`@("`@("`@("`@("`@("`@("`@)&EN<75O=&4@/2!T
M<G5E.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@
M("`@("!C87-E(%1?0U523%E?3U!%3CH-"B`@("`@("`@("`@("`@("!C87-E
M(%1?1$],3$%27T]014Y?0U523%E?0E)!0T53.@T*("`@("`@("`@("`@("`@
M(&-A<V4@)WLG.B`D8G)A8V5?;&5V96PK*SL@8V]N=&EN=64@,CL-"B`@("`@
M("`@("`@("`@("!C87-E("=])SH-"B`@("`@("`@("`@("`@("`@("`@)&)R
M86-E7VQE=F5L+2T[#0H@("`@("`@("`@("`@("`@("`@(&EF("@D8W5R<F5N
M=%]C;&%S<U]L979E;"`]/2`D8G)A8V5?;&5V96PI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1C=7)R96YT7V-L87-S(#T@)R<[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D8W5R<F5N=%]C;&%S<U]L979E;"`]("TQ.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@D
M8W5R<F5N=%]F=6YC=&EO;E]L979E;"`]/2`D8G)A8V5?;&5V96PI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V9U;F-T:6]N(#T@)R<[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]F=6YC=&EO;E]L
M979E;"`]("TQ.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@("`@("`@8V%S92`G
M6R<Z("1B<F%C:V5T7VQE=F5L*RL[(&-O;G1I;G5E(#([#0H@("`@("`@("`@
M("`@("`@8V%S92`G72<Z("1B<F%C:V5T7VQE=F5L+2T[(&-O;G1I;G5E(#([
M#0H@("`@("`@("`@("`@("`@8V%S92`G*"<Z("1P87)E;E]L979E;"LK.R`@
M(&-O;G1I;G5E(#([#0H@("`@("`@("`@("`@("`@8V%S92`G*2<Z("1P87)E
M;E]L979E;"TM.R`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@("`@("`@8V%S
M92!47TE.5$521D%#13H-"B`@("`@("`@("`@("`@("`@("`@)&EN=&5R9F%C
M92`]('1R=64[#0H@("`@("`@("`@("`@("`@8V%S92!47T-,05-3.@T*("`@
M("`@("`@("`@("`@("`@("!I9B`H*"1C=7)R96YT7V-L87-S7VQE=F5L("$]
M("TQ*2!\?"`H)&-U<G)E;G1?9G5N8W1I;VY?;&5V96P@(3T@+3$I*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?
M1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)V9I;&4G(#T^("1F:6QE*2P-
M"B`@("`@("`@("`@("`@("`@("`@("`@("=087)S97(@97)R;W(Z(&EN=F%L
M:60@4$A0(&9O=6YD(&EN(&9I;&4@(B5F:6QE)2(G*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&-A<V4@5%]&54Y#5$E/3CH-"B`@("`@
M("`@("`@("`@("!C87-E(%1?3D57.@T*("`@("`@("`@("`@("`@(&-A<V4@
M5%]%6%1%3D13.@T*("`@("`@("`@("`@("`@(&-A<V4@5%])35!,14U%3E13
M.@T*("`@("`@("`@("`@("`@("`@("`D;&]O:U]F;W(@/2`D=&]K96X[#0H@
M("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@("`@
M("`@8V%S92!47U-44DE.1SH-"B`@("`@("`@("`@("`@("`@("`@:68@*'9E
M<G-I;VY?8V]M<&%R92AZ96YD7W9E<G-I;VXH*2P@)S(N,"<L("<\)RDI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI;E]A<G)A>2AS=')T;VQO
M=V5R*"1D871A*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G<'5B;&EC)RP@)W!R:79A=&4G+"`G<')O=&5C=&5D)RP@)V%B<W1R86-T
M)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:6YT97)F
M86-E)RP@)VEM<&QE;65N=',G+"`G=&AR;W<G*2`-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)W=A
M<FYI;F<G+"!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V9I;&4G(#T^("1F:6QE*2P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)T5R<F]R+"!02%`U('1O:V5N(&5N8V]U;G1E<F5D(&EN("5F
M:6QE)2PG("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R!A
M;F%L>7-I<R!S:&]U;&0@8F4@:6X@4$A0-2<I.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@D;&]O:U]F;W(@/3T@5%]#3$%34RD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?8VQA<W,@/2`D9&%T83L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V-L87-S7VQE=F5L(#T@
M)&)R86-E7VQE=F5L.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&1E8VQA
M<F5D7V-L87-S97-;72`]("1C=7)R96YT7V-L87-S.PT*("`@("`@("`@("`@
M("`@("`@("!](&5L<V5I9B`H)&QO;VM?9F]R(#T](%1?24Y415)&04-%*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]I;G1E<F9A8V4@
M/2`D9&%T83L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V-L
M87-S7VQE=F5L(#T@)&)R86-E7VQE=F5L.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)&1E8VQA<F5D7VEN=&5R9F%C97-;72`]("1C=7)R96YT7VEN=&5R
M9F%C93L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1L;V]K7V9O
M<B`]/2!47TE-4$Q%345.5%,I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1I;7!L96UE;G1S6R1C=7)R96YT7V-L87-S72`]("1D871A.PT*("`@("`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H)&QO;VM?9F]R(#T](%1?15A414Y$
M4RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&5X=&5N9'-;)&-U<G)E
M;G1?8VQA<W-=(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@("`@('T@96QS
M96EF("@D;&]O:U]F;W(@/3T@5%]&54Y#5$E/3BD@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"1C=7)R96YT7V-L87-S*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?9G5N8W1I;VX@/2`B)&-U<G)E
M;G1?8VQA<W,Z.B1D871A(CL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9&5C;&%R961?;65T:&]D<ULD8W5R<F5N=%]C;&%S<UU;72`]("1D871A
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1C=7)R96YT
M7VEN=&5R9F%C92D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C
M=7)R96YT7V9U;F-T:6]N(#T@(B1C=7)R96YT7VEN=&5R9F%C93HZ)&1A=&$B
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D96-L87)E9%]M971H
M;V1S6R1C=7)R96YT7VEN=&5R9F%C95U;72`]("1D871A.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D8W5R<F5N=%]F=6YC=&EO;B`]("1D871A.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1D96-L87)E9%]F=6YC=&EO;G-;72`]("1C
M=7)R96YT7V9U;F-T:6]N.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?9G5N8W1I;VY?;&5V
M96P@/2`D8G)A8V5?;&5V96P[#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M;2`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D
M;&]O:U]F;W(@/3T@5%].15<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1U<V5D7V-L87-S97-;)&1A=&%=(#T@=')U93L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D;&]O:U]F;W(@/2`P.PT*
M("`@("`@("`@("`@("`@("`@("!C;VYT:6YU92`R.PT*("`@("`@("`@("`@
M("`@(&-A<V4@5%]605))04),13H-"B`@("`@("`@("`@("`@("`@("`@)&QO
M;VM?9F]R(#T@,#L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64@,CL-
M"B`@("`@("`@("`@("`@("!C87-E(%1?1$]#7T-/34U%3E0Z#0H@("`@("`@
M("`@("`@("`@8V%S92!47T-/34U%3E0Z#0H@("`@("`@("`@("`@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"<A7B]<*EPJ7',A)RP@)&1A=&$I*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D;&%S='!H<&1O8R`]("1D871A.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8VA?86QL*"<O0&YO
M9&5P7',K*%Q3*RDO)RP@)&QA<W1P:'!D;V,L("1M*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1N;V1E<',@/2!A<G)A>5]M97)G92@D;F]D
M97!S+"`D;5LQ72D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN
M=64@,CL-"B`@("`@("`@("`@("`@("!C87-E(%1?1$]50DQ%7T-/3$]..@T*
M("`@("`@("`@("`@("`@("`@("!I9B`H(2@D=&]K96YS6R1I("T@,5U;,%T@
M/3T@5%]72$E415-004-%('Q\("1T;VME;G-;)&D@+2`Q75LP72`]/2!47U-4
M4DE.1RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1A
M8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G=V%R;FEN9R<L(&%R<F%Y*"=F:6QE
M)R`]/B`D9FEL92DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U!A
M<G-E<B!E<G)O<CH@:6YV86QI9"!02%`@9F]U;F0@:6X@9FEL92`B)69I;&4E
M(B<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1C
M;&%S<R`]("1T;VME;G-;)&D@+2`Q75LQ73L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*'-T<G1O;&]W97(H)&-L87-S*2`A/2`G<&%R96YT)RD@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)'5S961?8VQA<W-E<ULD8VQA<W-=(#T@
M=')U93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU92`R.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B!A<G)A>2@-"B`@("`@("`@("`@(")S;W5R8V5?9FEL
M92(@/3X@)&9I;&4L#0H@("`@("`@("`@("`B9&5C;&%R961?8VQA<W-E<R(@
M/3X@)&1E8VQA<F5D7V-L87-S97,L#0H@("`@("`@("`@("`B9&5C;&%R961?
M:6YT97)F86-E<R(@/3X@)&1E8VQA<F5D7VEN=&5R9F%C97,L#0H@("`@("`@
M("`@("`B9&5C;&%R961?;65T:&]D<R(@/3X@)&1E8VQA<F5D7VUE=&AO9',L
M#0H@("`@("`@("`@("`B9&5C;&%R961?9G5N8W1I;VYS(B`]/B`D9&5C;&%R
M961?9G5N8W1I;VYS+`T*("`@("`@("`@("`@(G5S961?8VQA<W-E<R(@/3X@
M87)R87E?9&EF9BAA<G)A>5]K97ES*"1U<V5D7V-L87-S97,I+"`D;F]D97!S
M*2P-"B`@("`@("`@("`@(")I;FAE<FET86YC92(@/3X@)&5X=&5N9',L#0H@
M("`@("`@("`@("`B:6UP;&5M96YT<R(@/3X@)&EM<&QE;65N=',L#0H@("`@
M("`@("`@("`I.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($)U:6QD(&$@
M(G!R;W9I9&5S(B!A<G)A>2!F<F]M(&1A=&$@<F5T=7)N960@8GD-"B`@("`@
M*B!A;F%L>7IE4V]U<F-E0V]D92@I+B`@5&AE(&9O<FUA="!O9B!T:&4@8G5I
M;'0@87)R87D@:7,@;&EK90T*("`@("`J('1H:7,Z#0H@("`@("H-"B`@("`@
M*B`@87)R87DH#0H@("`@("H@("`@)V-L87-S.TUY0VQA<W,G(#T^("=A<G)A
M>2@G='EP92<@/3X@)V-L87-S)RP@)VYA;64G(#T^("=->4-L87-S)RDL#0H@
M("`@("H@("`@+BXN#0H@("`@("H@("D-"B`@("`@*@T*("`@("`J#0H@("`@
M("H@0'!A<F%M(&%R<F%Y("1S<F-I;F9O(&%R<F%Y('=I=&@@:6YF;W)M871I
M;VX@86)O=70@82!S;W5R8V4@9FEL90T*("`@("`J(&%S(')E='5R;F5D(&)Y
M('1H92!A;F%L>7IE4V]U<F-E0V]D92@I(&UE=&AO9"X-"B`@("`@*@T*("`@
M("`J($!R971U<FX@=F]I9`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P<FEV
M871E#0H@("`@("H-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?8G5I;&10<F]V
M:61E<T%R<F%Y*"1S<F-I;F9O*0T*("`@('L-"B`@("`@("`@:68@*"$D=&AI
M<RT^7VES5F%L:60I('L-"B`@("`@("`@("`@(')E='5R;B!A<G)A>2@I.PT*
M("`@("`@("!]#0H@("`@("`@("1P<F]V:61E<W)E="`](&%R<F%Y*"D[#0H@
M("`@("`@("1F:6QE(#T@8F%S96YA;64H)'-R8VEN9F];)W-O=7)C95]F:6QE
M)UTI.PT*("`@("`@("`D<&X@/2`D=&AI<RT^7W!F+3YG971086-K86=E*"D[
M#0H@("`@("`@("1P;FP@/2!S=')L96XH)'!N*3L-"B`@("`@("`@9F]R96%C
M:"`H)'-R8VEN9F];)V1E8VQA<F5D7V-L87-S97,G72!A<R`D8VQA<W,I('L-
M"B`@("`@("`@("`@("1K97D@/2`B8VQA<W,[)&-L87-S(CL-"B`@("`@("`@
M("`@(&EF("AI<W-E="@D<')O=FED97-R971;)&ME>5TI*2![#0H@("`@("`@
M("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`D<')O=FED97-R971;)&ME>5T@/0T*("`@("`@("`@("`@("`@(&%R<F%Y
M*"=F:6QE)ST^("1F:6QE+"`G='EP92<@/3X@)V-L87-S)RP@)VYA;64G(#T^
M("1C;&%S<RD[#0H@("`@("`@("`@("!I9B`H:7-S970H)'-R8VEN9F];)VEN
M:&5R:71A;F-E)UU;)&-L87-S72DI('L-"B`@("`@("`@("`@("`@("`D<')O
M=FED97-R971;)&ME>5U;)V5X=&5N9',G72`]#0H@("`@("`@("`@("`@("`@
M("`@("1S<F-I;F9O6R=I;FAE<FET86YC92==6R1C;&%S<UT[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)'-R8VEN9F];
M)V1E8VQA<F5D7VUE=&AO9',G72!A<R`D8VQA<W,@/3X@)&UE=&AO9',I('L-
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1M971H;V1S(&%S("1M971H;V0I('L-
M"B`@("`@("`@("`@("`@("`D9G5N8W1I;VX@/2`B)&-L87-S.CHD;65T:&]D
M(CL-"B`@("`@("`@("`@("`@("`D:V5Y(#T@(F9U;F-T:6]N.R1F=6YC=&EO
M;B([#0H@("`@("`@("`@("`@("`@:68@*"1M971H;V1[,'T@/3T@)U\G('Q\
M("%S=')C87-E8VUP*"1M971H;V0L("1C;&%S<RD@?'P-"B`@("`@("`@("`@
M("`@("`@("`@:7-S970H)'!R;W9I9&5S<F5T6R1K97E=*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@)'!R;W9I9&5S<F5T6R1K97E=(#T-"B`@("`@("`@
M("`@("`@("`@("`@87)R87DH)V9I;&4G/3X@)&9I;&4L("=T>7!E)R`]/B`G
M9G5N8W1I;VXG+"`G;F%M92<@/3X@)&9U;F-T:6]N*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*#0H@("`@("`@(&9O<F5A8V@@*"1S<F-I;F9O6R=D
M96-L87)E9%]F=6YC=&EO;G,G72!A<R`D9G5N8W1I;VXI('L-"B`@("`@("`@
M("`@("1K97D@/2`B9G5N8W1I;VX[)&9U;F-T:6]N(CL-"B`@("`@("`@("`@
M(&EF("@D9G5N8W1I;VY[,'T@/3T@)U\G('Q\(&ES<V5T*"1P<F]V:61E<W)E
M=%LD:V5Y72DI('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("@A<W1R<W1R*"1F=6YC=&EO;BP@
M)SHZ)RD@)B8@<W1R;F-A<V5C;7`H)&9U;F-T:6]N+"`D<&XL("1P;FPI*2![
M#0H@("`@("`@("`@("`@("`@)'=A<FYI;F=S6UT@/2`B:6XQ("(@+B`D9FEL
M92`N("(Z(&9U;F-T:6]N(%PB)&9U;F-T:6]N7"(@;F]T('!R969I>&5D('=I
M=&@@<&%C:V%G92!N86UE(%PB)'!N7"(B.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)'!R;W9I9&5S<F5T6R1K97E=(#T-"B`@("`@("`@("`@("`@
M("!A<G)A>2@G9FEL92<]/B`D9FEL92P@)W1Y<&4G(#T^("=F=6YC=&EO;B<L
M("=N86UE)R`]/B`D9G5N8W1I;VXI.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B`D<')O=FED97-R970[#0H@("`@?0T*?0T*/SX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U!A8VMA9V5&:6QE+W8R+G!H<```
M```````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#(Q,3,P-``Q,#4Q-30S,S<T
M,``P,C(U,C0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`-"B\J*@T*("H@4$5!4E]086-K86=E1FEL95]V,BP@<&%C
M:V%G92YX;6P@=F5R<VEO;B`R+C`-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A
M;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B
M:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H
M870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y
M(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T
M86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T
M92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P
M>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`
M<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\
M8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE
M(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO
M;B`@("!#5E,Z("1)9#H@=C(N<&AP+'8@,2XQ,CDN,BXQ(#(P,#8O,#,O,C,@
M,#0Z,#<Z-3$@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL
M92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"B\J*@T*
M("H@1F]R(&5R<F]R(&AA;F1L:6YG#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!
M4B]%<G)O<E-T86-K+G!H<"<[#0HO*BH-"B`J($!C871E9V]R>2`@('!E87(-
M"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A
M=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P
M-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V
M97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@
M0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0IC
M;&%S<R!014%27U!A8VMA9V5&:6QE7W8R#0I[#0H-"B`@("`O*BH-"B`@("`@
M*B!087)S960@<&%C:V%G92!I;F9O<FUA=&EO;@T*("`@("`J($!V87(@87)R
M87D-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@
M)%]P86-K86=E26YF;R`](&%R<F%Y*"D[#0H-"B`@("`O*BH-"B`@("`@*B!P
M871H('1O('!A8VMA9V4@+G1G>B!O<B!F86QS92!I9B!T:&ES(&ES(&$@;&]C
M86PO97AT<F%C=&5D('!A8VMA9V4N>&UL#0H@("`@("H@0'9A<B!S=')I;F=\
M9F%L<V4-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V
M87(@)%]A<F-H:79E1FEL93L-"@T*("`@("\J*@T*("`@("`J('!A=&@@=&\@
M<&%C:V%G92`N>&UL(&]R(&9A;'-E(&EF('1H:7,@:7,@86X@86)S=')A8W0@
M<&%R<V5D+69R;VTM<W1R:6YG('AM;`T*("`@("`J($!V87(@<W1R:6YG?&9A
M;'-E#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R
M("1?<&%C:V%G949I;&4[#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES(&ES('5S
M960@8GD@9FEL92!A;F%L>7-I<R!R;W5T:6YE<R!T;R!L;V<@<')O9W)E<W,@
M:6YF;W)M871I;VX-"B`@("`@*B!`=F%R(%!%05)?0V]M;6]N#0H@("`@("H@
M0&%C8V5S<R!P<F]T96-T960-"B`@("`@*B\-"B`@("!V87(@)%]L;V=G97([
M#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES(&ES('-E="!T;R!T:&4@:&EG:&5S
M="!V86QI9&%T:6]N(&QE=F5L('1H870@:&%S(&)E96X@=F%L:61A=&5D#0H@
M("`@("H-"B`@("`@*B!)9B!T:&4@<&%C:V%G92YX;6P@:7,@:6YV86QI9"!O
M<B!U;FMN;W=N+"!T:&ES(&ES('-E="!T;R`P+B`@268-"B`@("`@*B!N;W)M
M86P@=F%L:61A=&EO;B!H87,@;V-C=7)R960L('1H:7,@:7,@<V5T('1O(%!%
M05)?5D%,241!5$5?3D]234%,+B`@268-"B`@("`@*B!D;W=N;&]A9&EN9R]I
M;G-T86QL871I;VX@=F%L:61A=&EO;B!H87,@;V-C=7)R960@:70@:7,@<V5T
M('1O(%!%05)?5D%,241!5$5?1$]73DQ/041)3D<-"B`@("`@*B!O<B!)3E-4
M04Q,24Y'+"!A;F0@<V\@;VX@=7`@=&\@4$5!4E]604Q)1$%415]004-+04=)
M3D<N("!4:&ES(&%L;&]W<R!V86QI9&%T:6]N#0H@("`@("H@(F-A8VAI;F<B
M('1O(&]C8W5R+"!W:&EC:"!I<R!P87)T:6-U;&%R;'D@:6UP;W)T86YT(&9O
M<B!P86-K86=E('9A;&ED871I;VXL('-O#0H@("`@("H@=&AA="!02%`@9FEL
M97,@87)E(&YO="!V86QI9&%T960@='=I8V4-"B`@("`@*B!`=F%R(&EN=`T*
M("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7VES
M5F%L:60@/2`P.PT*#0H@("`@+RHJ#0H@("`@("H@5')U92!I9B!T:&4@9FEL
M96QI<W0@:&%S(&)E96X@=F%L:61A=&5D#0H@("`@("H@0'!A<F%M(&)O;VP-
M"B`@("`@*B\-"B`@("!V87(@)%]F:6QE<U9A;&ED(#T@9F%L<V4[#0H-"B`@
M("`O*BH-"B`@("`@*B!`=F%R(%!%05)?4F5G:7-T<GD-"B`@("`@*B!`86-C
M97-S('!R;W1E8W1E9`T*("`@("`J+PT*("`@('9A<B`D7W)E9VES=')Y.PT*
M#0H@("`@+RHJ#0H@("`@("H@0'9A<B!014%27T-O;F9I9PT*("`@("`J($!A
M8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@=F%R("1?8V]N9FEG.PT*
M#0H@("`@+RHJ#0H@("`@("H@3W!T:6]N86P@1&5P96YD96YC>2!G<F]U<"!R
M97%U97-T960@9F]R(&EN<W1A;&QA=&EO;@T*("`@("`J($!V87(@<W1R:6YG
M#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?
M<F5Q=65S=&5D1W)O=7`@/2!F86QS93L-"@T*("`@("\J*@T*("`@("`J($!V
M87(@4$5!4E]%<G)O<E-T86-K#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-
M"B`@("`@*B\-"B`@("!V87(@)%]S=&%C:SL-"@T*("`@("\J*@T*("`@("`J
M($YA;65S<&%C92!P<F5F:7@@=7-E9"!F;W(@=&%S:W,@:6X@=&AI<R!P86-K
M86=E+GAM;"`M('5S92!T87-K<SH@=VAE;F5V97(@<&]S<VEB;&4-"B`@("`@
M*B\-"B`@("!V87(@)%]T87-K<TYS.PT*#0H@("`@+RHJ#0H@("`@("H@1&5T
M97)M:6YE<R!W:&5T:&5R('1H:7,@<&%C:V%G969I;&4@=V%S(&EN:71I86QI
M>F5D(&]N;'D@=VET:"!P87)T:6%L('!A8VMA9V4@:6YF;PT*("`@("`J#0H@
M("`@("H@268@=&AI<R!P86-K86=E(&9I;&4@=V%S(&-O;G-T<G5C=&5D('9I
M82!P87)S:6YG(%)%4U0L(&ET('=I;&P@;VYL>2!C;VYT86EN#0H@("`@("H-
M"B`@("`@*B`M('!A8VMA9V4@;F%M90T*("`@("`J("T@8VAA;FYE;"!N86UE
M#0H@("`@("H@+2!D97!E;F1E;F-I97,@#0H@("`@("H@0'9A<B!B;V]L96%N
M#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?
M:6YC;VUP;&5T92`]('1R=64[#0H-"B`@("`O*BH-"B`@("`@*B!`=F%R(%!%
M05)?4&%C:V%G949I;&5?=C)?5F%L:61A=&]R#0H@("`@("HO#0H@("`@=F%R
M("1?=C)686QI9&%T;W([#0H-"B`@("`O*BH-"B`@("`@*B!4:&4@8V]N<W1R
M=6-T;W(@;65R96QY('-E=',@=7`@=&AE('!R:79A=&4@97)R;W(@<W1A8VL-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!014%27U!A8VMA9V5&:6QE7W8R*"D-
M"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VL@/2!N97<@4$5!4E]%<G)O
M<E-T86-K*"=014%27U!A8VMA9V5&:6QE7W8R)RP@9F%L<V4L(&YU;&PI.PT*
M("`@("`@("`D=&AI<RT^7VES5F%L:60@/2!F86QS93L-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!4;R!M86ME('5N:70M=&5S=&EN9R!E87-I97(-"B`@
M("`@*B!`<&%R86T@4$5!4E]&<F]N=&5N9%\J#0H@("`@("H@0'!A<F%M(&%R
M<F%Y(&]P=&EO;G,-"B`@("`@*B!`<&%R86T@4$5!4E]#;VYF:6<-"B`@("`@
M*B!`<F5T=7)N(%!%05)?1&]W;FQO861E<@T*("`@("`J($!A8V-E<W,@<')O
M=&5C=&5D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F=E=%!%05)$;W=N;&]A
M9&5R*"8D:2P@)&\L("8D8RD-"B`@("![#0H@("`@("`@("1Z(#T@)FYE=R!0
M14%27T1O=VYL;V%D97(H)&DL("1O+"`D8RD[#0H@("`@("`@(')E='5R;B`D
M>CL-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!4;R!M86ME('5N:70M=&5S
M=&EN9R!E87-I97(-"B`@("`@*B!`<&%R86T@4$5!4E]#;VYF:6<-"B`@("`@
M*B!`<&%R86T@87)R87D@;W!T:6]N<PT*("`@("`J($!P87)A;2!A<G)A>2!P
M86-K86=E(&YA;64@87,@<F5T=7)N960@9G)O;2![0&QI;FL@4$5!4E]296=I
M<W1R>3HZ<&%R<V5086-K86=E3F%M92@I?0T*("`@("`J($!P87)A;2!I;G0@
M4$5!4E]604Q)1$%415\J(&-O;G-T86YT#0H@("`@("H@0')E='5R;B!014%2
M7T1E<&5N9&5N8WDR#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B`F9V5T4$5!4D1E<&5N9&5N8WDR*"8D8RP@)&\L
M("1P+"`D<R`](%!%05)?5D%,241!5$5?24Y35$%,3$E.1RD-"B`@("![#0H@
M("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T1E<&5N9&5N8WDR)RDI
M('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]$97!E;F1E;F-Y
M,BYP:'`G.PT*("`@("`@("!]#0H@("`@("`@("1Z(#T@)FYE=R!014%27T1E
M<&5N9&5N8WDR*"1C+"`D;RP@)'`L("1S*3L-"B`@("`@("`@<F5T=7)N("1Z
M.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$EN<W1A;&QE9$)I;F%R>2@I
M#0H@("`@>PT*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/E]P86-K86=E
M26YF;ULG(V)I;F%R>7!A8VMA9V4G72D@/R`D=&AI<RT^7W!A8VMA9V5);F9O
M6R<C8FEN87)Y<&%C:V%G92==(#H-"B`@("`@("`@("`@(&9A;'-E.PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J($EN<W1A;&QA=&EO;B!O9B!S;W5R8V4@
M<&%C:V%G92!H87,@9F%I;&5D+"!A='1E;7!T('1O(&1O=VYL;V%D(&%N9"!I
M;G-T86QL('1H90T*("`@("`J(&)I;F%R>2!V97)S:6]N(&]F('1H:7,@<&%C
M:V%G92X-"B`@("`@*B!`<&%R86T@4$5!4E]);G-T86QL97(-"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y?&9A;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@:6YS
M=&%L;$)I;F%R>2@F)&EN<W1A;&QE<BD-"B`@("![#0H@("`@("`@(&EF("@A
M3U-?5TE.1$]74RD@>PT*("`@("`@("`@("`@)&$@/2!F86QS93L-"B`@("`@
M("`@("`@(')E='5R;B`D83L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1H
M:7,M/F=E=%!A8VMA9V54>7!E*"D@/3T@)V5X='-R8R<I('L-"B`@("`@("`@
M("`@(&EF("@A:7-?87)R87DH)&EN<W1A;&QE<BT^9V5T26YS=&%L;%!A8VMA
M9V5S*"DI*2![#0H@("`@("`@("`@("`@("`@)&$@/2!F86QS93L-"B`@("`@
M("`@("`@("`@("!R971U<FX@)&$[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!F;W)E86-H("@D:6YS=&%L;&5R+3YG971);G-T86QL4&%C:V%G97,H
M*2!A<R`D<"D@>PT*("`@("`@("`@("`@("`@(&EF("@D<"T^:7-%>'1E;G-I
M;VXH)'1H:7,M/E]P86-K86=E26YF;ULG<')O=FED97-E>'1E;G-I;VXG72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1P+3YG971086-K86=E5'EP
M92@I("$]("=E>'1S<F,G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M82`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1A
M.R`O+R!T:&4@=7-E<B!P<F]B86)L>2!D;W=N;&]A9&5D(&ET('-E<&%R871E
M;'D-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7W!A8VMA9V5);F9O6R=E>'1S<F-R96QE87-E)UU;)V)I;F%R>7!A8VMA9V4G
M72DI('L-"B`@("`@("`@("`@("`@("`D:6YS=&%L;&5R+3YL;V<H,"P@)T%T
M=&5M<'1I;F<@=&\@9&]W;FQO860@8FEN87)Y('9E<G-I;VX@;V8@97AT96YS
M:6]N("(G("X-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E
M26YF;ULG<')O=FED97-E>'1E;G-I;VXG72`N("<B)RD[#0H@("`@("`@("`@
M("`@("`@)'!A<F%M<R`]("1T:&ES+3Y?<&%C:V%G94EN9F];)V5X='-R8W)E
M;&5A<V4G75LG8FEN87)Y<&%C:V%G92==.PT*("`@("`@("`@("`@("`@(&EF
M("@A:7-?87)R87DH)'!A<F%M<RD@?'P@(6ES<V5T*"1P87)A;7-;,%TI*2![
M#0H@("`@("`@("`@("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@D<&%R86US
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-H86YN96PG72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D:2`]/B`D<&%R
M86TI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;7-;)&E=(#T@
M87)R87DH)V-H86YN96PG(#T^("1T:&ES+3Y?<&%C:V%G94EN9F];)V-H86YN
M96PG72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&%C:V%G92<@
M/3X@)'!A<F%M+"`G=F5R<VEO;B<@/3X@)'1H:7,M/F=E=%9E<G-I;VXH*2D[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@)&1L(#T@)B1T:&ES+3YG971014%21&]W;FQO861E
M<B@D:6YS=&%L;&5R+3YU:2P@)&EN<W1A;&QE<BT^9V5T3W!T:6]N<R@I+`T*
M("`@("`@("`@("`@("`@("`@("`D:6YS=&%L;&5R+3YC;VYF:6<I.PT*("`@
M("`@("`@("`@("`@("1V97)B;W-E(#T@)&1L+3YC;VYF:6<M/F=E="@G=F5R
M8F]S92<I.PT*("`@("`@("`@("`@("`@("1D;"T^8V]N9FEG+3YS970H)W9E
M<F)O<V4G+"`M,2D[#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!A<F%M
M<R!A<R`D<&%R86TI('L-"B`@("`@("`@("`@("`@("`@("`@4$5!4CHZ<'5S
M:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`@
M("`@("`@("`@("`D<F5T(#T@)&1L+3YD;W=N;&]A9"AA<G)A>2@D<&%R86TI
M*3L-"B`@("`@("`@("`@("`@("`@("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN
M9R@I.PT*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)')E="D@
M)B8@8V]U;G0H)')E="DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("1D;"T^8V]N9FEG+3YS970H)W9E<F)O<V4G
M+"`D=F5R8F]S92D[#0H@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1R
M970I*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AC;W5N="@D<F5T*2`]
M/2`Q*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&8@/2`D<F5T6S!=
M+3YG971086-K86=E1FEL92@I.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M4$5!4CHZ<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&5R<B`]("1I;G-T86QL97(M/FEN
M<W1A;&PH)')E=%LP72D[#0H@("`@("`@("`@("`@("`@("`@("`@("!014%2
M.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-?87)R87DH)&5R<BDI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R<C8FEN87)Y<&%C:V%G92==
M(#T@)')E=%LP72T^9V5T4&%C:V%G92@I.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("\O(")I;G-T86QL(B!S96QF+"!S;R!A;&P@9&5P96YD96YC
M:65S('=I;&P@=V]R:R!T<F%N<W!A<F5N=&QY#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R>2T^861D4&%C:V%G93(H)'1H
M:7,I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;G-T86QL97(M
M/FQO9R@P+"`G1&]W;FQO860@86YD(&EN<W1A;&P@;V8@8FEN87)Y(&5X=&5N
M<VEO;B`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G8VAA
M;FYE;"<@/3X@)'!F+3YG971#:&%N;F5L*"DL#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<&%C:V%G92<@/3X@)'!F+3YG
M971086-K86=E*"DI+"!T<G5E*2`N("<B('-U8V-E<W-F=6PG*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D82`](&%R<F%Y*"1R971;,%TL("1E
M<G(I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D83L-
M"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1I;G-T86QL97(M/FQO9R@P+"`G1&]W;FQO860@86YD(&EN<W1A
M;&P@;V8@8FEN87)Y(&5X=&5N<VEO;B`B)R`N#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA
M;654;U-T<FEN9R@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"=C:&%N;F5L)R`]/B`D<&8M/F=E=$-H86YN96PH*2P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P86-K
M86=E)R`]/B`D<&8M/F=E=%!A8VMA9V4H*2DL('1R=64I("X@)R(@9F%I;&5D
M)RD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&$@/2!F86QS
M93L-"B`@("`@("`@<F5T=7)N("1A.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("`J($!R971U<FX@<W1R:6YG?&9A;'-E($5X=&5N<VEO;B!N86UE#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@9V5T4')O=FED97-%>'1E;G-I;VXH*0T*("`@
M('L-"B`@("`@("`@:68@*&EN7V%R<F%Y*"1T:&ES+3YG971086-K86=E5'EP
M92@I+"!A<G)A>2@G97AT<W)C)RP@)V5X=&)I;B<I*2D@>PT*("`@("`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W!R;W9I9&5S97AT
M96YS:6]N)UTI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<&%C:V%G94EN9F];)W!R;W9I9&5S97AT96YS:6]N)UT[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-
M"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<@17AT96YS:6]N(&YA
M;64-"B`@("`@*B!`<F5T=7)N(&)O;VP-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!I<T5X=&5N<VEO;B@D97AT96YS:6]N*0T*("`@('L-"B`@("`@("`@:68@
M*&EN7V%R<F%Y*"1T:&ES+3YG971086-K86=E5'EP92@I+"!A<G)A>2@G97AT
M<W)C)RP@)V5X=&)I;B<I*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<&%C:V%G94EN9F];)W!R;W9I9&5S97AT96YS:6]N)UT@/3T@)&5X=&5N
M<VEO;CL-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@5&5S=',@=VAE=&AE<B!E=F5R>2!P87)T
M(&]F('1H92!P86-K86=E+GAM;"`Q+C`@:7,@<F5P<F5S96YT960@:6X-"B`@
M("`@*B!T:&ES('!A8VMA9V4N>&UL(#(N,`T*("`@("`J($!P87)A;2!014%2
M7U!A8VMA9V5&:6QE7W8Q#0H@("`@("H@0')E='5R;B!B;V]L#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@:7-%<75I=F%L96YT*"1P9C$I#0H@("`@>PT*("`@
M("`@("!I9B`H(21P9C$I('L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@D=&AI<RT^9V5T4&%C:V%G951Y<&4H
M*2`]/2`G8G5N9&QE)RD@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/F=E=$5R<F]R<RAT
M<G5E*3L-"B`@("`@("`@:68@*"$D<&8Q+3YV86QI9&%T92A014%27U9!3$E$
M051%7TY/4DU!3"DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@?0T*("`@("`@("`D<&%S<R`]('1R=64[#0H@("`@("`@(&EF("@D
M<&8Q+3YG971086-K86=E*"D@(3T@)'1H:7,M/F=E=%!A8VMA9V4H*2D@>PT*
M("`@("`@("`@("`@)'1H:7,M/E]D:69F97)E;G1086-K86=E*"1P9C$M/F=E
M=%!A8VMA9V4H*2D[#0H@("`@("`@("`@("`D<&%S<R`](&9A;'-E.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("@D<&8Q+3YG971697)S:6]N*"D@(3T@)'1H
M:7,M/F=E=%9E<G-I;VXH*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]D:69F
M97)E;G1697)S:6]N*"1P9C$M/F=E=%9E<G-I;VXH*2D[#0H@("`@("`@("`@
M("`D<&%S<R`](&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("AT<FEM
M*"1P9C$M/F=E=%-U;6UA<GDH*2D@(3T@)'1H:7,M/F=E=%-U;6UA<GDH*2D@
M>PT*("`@("`@("`@("`@)'1H:7,M/E]D:69F97)E;G13=6UM87)Y*"1P9C$M
M/F=E=%-U;6UA<GDH*2D[#0H@("`@("`@("`@("`D<&%S<R`](&9A;'-E.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AP<F5G7W)E<&QA8V4H)R]<<RLO)RP@
M)R<L("1P9C$M/F=E=$1E<V-R:7!T:6]N*"DI("$]#0H@("`@("`@("`@("`@
M('!R96=?<F5P;&%C92@G+UQS*R\G+"`G)RP@)'1H:7,M/F=E=$1E<V-R:7!T
M:6]N*"DI*2![#0H@("`@("`@("`@("`D=&AI<RT^7V1I9F9E<F5N=$1E<V-R
M:7!T:6]N*"1P9C$M/F=E=$1E<V-R:7!T:6]N*"DI.PT*("`@("`@("`@("`@
M)'!A<W,@/2!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'!F,2T^
M9V5T4W1A=&4H*2`A/2`D=&AI<RT^9V5T4W1A=&4H*2D@>PT*("`@("`@("`@
M("`@)'1H:7,M/E]D:69F97)E;G13=&%T92@D<&8Q+3YG9713=&%T92@I*3L-
M"B`@("`@("`@("`@("1P87-S(#T@9F%L<V4[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"%S=')S='(H<')E9U]R97!L86-E*"<O7',K+R<L("<G+"`D=&AI
M<RT^9V5T3F]T97,H*2DL#0H@("`@("`@("`@("`@('!R96=?<F5P;&%C92@G
M+UQS*R\G+"`G)RP@)'!F,2T^9V5T3F]T97,H*2DI*2![#0H@("`@("`@("`@
M("`D=&AI<RT^7V1I9F9E<F5N=$YO=&5S*"1P9C$M/F=E=$YO=&5S*"DI.PT*
M("`@("`@("`@("`@)'!A<W,@/2!F86QS93L-"B`@("`@("`@?0T*("`@("`@
M("`D;7EM86EN=&%I;F5R<R`]("1T:&ES+3YG971-86EN=&%I;F5R<R@I.PT*
M("`@("`@("`D>6]U<FUA:6YT86EN97)S(#T@)'!F,2T^9V5T36%I;G1A:6YE
M<G,H*3L-"B`@("`@("`@9F]R("@D:3$@/2`P.R`D:3$@/"!C;W5N="@D>6]U
M<FUA:6YT86EN97)S*3L@)&DQ*RLI('L-"B`@("`@("`@("`@("1R97-E="`]
M(&9A;'-E.PT*("`@("`@("`@("`@9F]R("@D:3(@/2`P.R`D:3(@/"!C;W5N
M="@D;7EM86EN=&%I;F5R<RD[("1I,BLK*2![#0H@("`@("`@("`@("`@("`@
M:68@*"1M>6UA:6YT86EN97)S6R1I,EU;)VAA;F1L92==(#T]("1Y;W5R;6%I
M;G1A:6YE<G-;)&DQ75LG:&%N9&QE)UTI('L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*"1M>6UA:6YT86EN97)S6R1I,EU;)W)O;&4G72`A/2`D>6]U<FUA
M:6YT86EN97)S6R1I,5U;)W)O;&4G72D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]D:69F97)E;G12;VQE*"1M>6UA:6YT86EN97)S6R1I
M,EU;)VAA;F1L92==+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1Y
M;W5R;6%I;G1A:6YE<G-;)&DQ75LG<F]L92==+"`D;7EM86EN=&%I;F5R<ULD
M:3)=6R=R;VQE)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'!A<W,@
M/2!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("!I9B`H)&UY;6%I;G1A:6YE<G-;)&DR75LG96UA:6PG72`A/2`D
M>6]U<FUA:6YT86EN97)S6R1I,5U;)V5M86EL)UTI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9&EF9F5R96YT16UA:6PH)&UY;6%I;G1A
M:6YE<G-;)&DR75LG:&%N9&QE)UTL#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'EO=7)M86EN=&%I;F5R<ULD:3%=6R=E;6%I;"==+"`D;7EM86EN
M=&%I;F5R<ULD:3)=6R=E;6%I;"==*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1P87-S(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"1M>6UA:6YT86EN97)S6R1I,EU;)VYA
M;64G72`A/2`D>6]U<FUA:6YT86EN97)S6R1I,5U;)VYA;64G72D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D:69F97)E;G1.86UE*"1M
M>6UA:6YT86EN97)S6R1I,EU;)VAA;F1L92==+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1Y;W5R;6%I;G1A:6YE<G-;)&DQ75LG;F%M92==+"`D
M;7EM86EN=&%I;F5R<ULD:3)=6R=N86UE)UTI.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)'!A<W,@/2!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!U;G-E="@D;7EM86EN=&%I;F5R<ULD
M:3)=*3L-"B`@("`@("`@("`@("`@("`@("`@)&UY;6%I;G1A:6YE<G,@/2!A
M<G)A>5]V86QU97,H)&UY;6%I;G1A:6YE<G,I.PT*("`@("`@("`@("`@("`@
M("`@("!U;G-E="@D>6]U<FUA:6YT86EN97)S6R1I,5TI.PT*("`@("`@("`@
M("`@("`@("`@("`D>6]U<FUA:6YT86EN97)S(#T@87)R87E?=F%L=65S*"1Y
M;W5R;6%I;G1A:6YE<G,I.PT*("`@("`@("`@("`@("`@("`@("`D<F5S970@
M/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)')E
M<V5T*2![#0H@("`@("`@("`@("`@("`@)&DQ(#T@+3$[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]U;FUA=&-H961-86EN
M=&%I;F5R<R@D;7EM86EN=&%I;F5R<RP@)'EO=7)M86EN=&%I;F5R<RD[#0H@
M("`@("`@("1F:6QE;&ES="`]("1T:&ES+3YG971&:6QE;&ES="@I.PT*("`@
M("`@("!F;W)E86-H("@D<&8Q+3YG971&:6QE;&ES="@I(&%S("1F:6QE(#T^
M("1A='1S*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1F:6QE;&ES=%LD
M9FEL95TI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]M:7-S:6YG1FEL
M92@D9FEL92D[#0H@("`@("`@("`@("`@("`@)'!A<W,@/2!F86QS93L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'!A<W,[
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7V1I9F9E<F5N=%!A8VMA9V4H)'!A
M8VMA9V4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?
M1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)W!A8VMA9V4G(#T^("1P86-K
M86=E+`T*("`@("`@("`@("`@)W-E;&8G(#T^("1T:&ES+3YG971086-K86=E
M*"DI+`T*("`@("`@("`@("`@)W!A8VMA9V4N>&UL(#$N,"!P86-K86=E("(E
M<&%C:V%G924B(&1O97,@;F]T(&UA=&-H("(E<V5L9B4B)RD[#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@7V1I9F9E<F5N=%9E<G-I;VXH)'9E<G-I;VXI#0H@
M("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?
M7RP@)V5R<F]R)RP@87)R87DH)W9E<G-I;VXG(#T^("1V97)S:6]N+`T*("`@
M("`@("`@("`@)W-E;&8G(#T^("1T:&ES+3YG971697)S:6]N*"DI+`T*("`@
M("`@("`@("`@)W!A8VMA9V4N>&UL(#$N,"!V97)S:6]N("(E=F5R<VEO;B4B
M(&1O97,@;F]T(&UA=&-H("(E<V5L9B4B)RD[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@7V1I9F9E<F5N=%-T871E*"1S=&%T92D-"B`@("![#0H@("`@("`@
M("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A
M<G)A>2@G<W1A=&4G(#T^("1S=&%T92P-"B`@("`@("`@("`@("=S96QF)R`]
M/B`D=&AI<RT^9V5T4W1A=&4H*2DL#0H@("`@("`@("`@("`G<&%C:V%G92YX
M;6P@,2XP('-T871E("(E<W1A=&4E(B!D;V5S(&YO="!M871C:"`B)7-E;&8E
M(B<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]D:69F97)E;G12;VQE*"1H
M86YD;&4L("1R;VQE+"`D<V5L9G)O;&4I#0H@("`@>PT*("`@("`@("`D=&AI
M<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH
M)VAA;F1L92<@/3X@)&AA;F1L92P-"B`@("`@("`@("`@("=R;VQE)R`]/B`D
M<F]L92P@)W-E;&8G(#T^("1S96QF<F]L92DL#0H@("`@("`@("`@("`G<&%C
M:V%G92YX;6P@,2XP(&UA:6YT86EN97(@(B5H86YD;&4E(B!R;VQE("(E<F]L
M924B(&1O97,@;F]T(&UA=&-H("(E<V5L9B4B)RD[#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@7V1I9F9E<F5N=$5M86EL*"1H86YD;&4L("1E;6%I;"P@)'-E
M;&9E;6%I;"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H
M7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G:&%N9&QE)R`]/B`D:&%N
M9&QE+`T*("`@("`@("`@("`@)V5M86EL)R`]/B`D96UA:6PL("=S96QF)R`]
M/B`D<V5L9F5M86EL*2P-"B`@("`@("`@("`@("=P86-K86=E+GAM;"`Q+C`@
M;6%I;G1A:6YE<B`B)6AA;F1L924B(&5M86EL("(E96UA:6PE(B!D;V5S(&YO
M="!M871C:"`B)7-E;&8E(B<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]D
M:69F97)E;G1.86UE*"1H86YD;&4L("1N86UE+"`D<V5L9FYA;64I#0H@("`@
M>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@
M)V5R<F]R)RP@87)R87DH)VAA;F1L92<@/3X@)&AA;F1L92P-"B`@("`@("`@
M("`@("=N86UE)R`]/B`D;F%M92P@)W-E;&8G(#T^("1S96QF;F%M92DL#0H@
M("`@("`@("`@("`G<&%C:V%G92YX;6P@,2XP(&UA:6YT86EN97(@(B5H86YD
M;&4E(B!N86UE("(E;F%M924B(&1O97,@;F]T(&UA=&-H("(E<V5L9B4B)RD[
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7W5N;6%T8VAE9$UA:6YT86EN97)S
M*"1M>2P@)'EO=7)S*0T*("`@('L-"B`@("`@("`@:68@*"1M>2D@>PT*("`@
M("`@("`@("`@87)R87E?=V%L:R@D;7DL(&-R96%T95]F=6YC=&EO;B@G)B1I
M+"`D:R<L("<D:2`]("1I6R)H86YD;&4B73LG*2D[#0H@("`@("`@("`@("`D
M=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R
M87DH)VAA;F1L97,G(#T^("1M>2DL#0H@("`@("`@("`@("`@("`@)W!A8VMA
M9V4N>&UL(#(N,"!H87,@=6YM871C:&5D(&5X=')A(&UA:6YT86EN97)S("(E
M:&%N9&QE<R4B)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1Y;W5R<RD@
M>PT*("`@("`@("`@("`@87)R87E?=V%L:R@D>6]U<G,L(&-R96%T95]F=6YC
M=&EO;B@G)B1I+"`D:R<L("<D:2`]("1I6R)H86YD;&4B73LG*2D[#0H@("`@
M("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R
M<F]R)RP@87)R87DH)VAA;F1L97,G(#T^("1Y;W5R<RDL#0H@("`@("`@("`@
M("`@("`@)W!A8VMA9V4N>&UL(#$N,"!H87,@=6YM871C:&5D(&5X=')A(&UA
M:6YT86EN97)S("(E:&%N9&QE<R4B)RD[#0H@("`@("`@('T-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!?9&EF9F5R96YT3F]T97,H)&YO=&5S*0T*("`@('L-
M"B`@("`@("`@)'1R=6YC;F]T97,@/2!S=')L96XH)&YO=&5S*2`\(#(U(#\@
M)&YO=&5S(#H@<W5B<W1R*"1N;W1E<RP@,"P@,C0I("X@)RXN+B<[#0H@("`@
M("`@("1T<G5N8VUY;F]T97,@/2!S=')L96XH)'1H:7,M/F=E=$YO=&5S*"DI
M(#P@,C4@/R`D=&AI<RT^9V5T3F]T97,H*2`Z#0H@("`@("`@("`@("!S=6)S
M='(H)'1H:7,M/F=E=$YO=&5S*"DL(#`L(#(T*2`N("<N+BXG.PT*("`@("`@
M("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@
M87)R87DH)VYO=&5S)R`]/B`D=')U;F-N;W1E<RP-"B`@("`@("`@("`@("=S
M96QF)R`]/B`D=')U;F-M>6YO=&5S*2P-"B`@("`@("`@("`@("=P86-K86=E
M+GAM;"`Q+C`@<F5L96%S92!N;W1E<R`B)6YO=&5S)2(@9&\@;F]T(&UA=&-H
M("(E<V5L9B4B)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7V1I9F9E<F5N
M=%-U;6UA<GDH)'-U;6UA<GDI#0H@("`@>PT*("`@("`@("`D=')U;F-S=6UM
M87)Y(#T@<W1R;&5N*"1S=6UM87)Y*2`\(#(U(#\@)'-U;6UA<GD@.B!S=6)S
M='(H)'-U;6UA<GDL(#`L(#(T*2`N("<N+BXG.PT*("`@("`@("`D=')U;F-M
M>7-U;6UA<GD@/2!S=')L96XH)'1H:7,M/F=E='-U;6UA<GDH*2D@/"`R-2`_
M("1T:&ES+3YG9713=6UM87)Y*"D@.@T*("`@("`@("`@("`@<W5B<W1R*"1T
M:&ES+3YG971S=6UM87)Y*"DL(#`L(#(T*2`N("<N+BXG.PT*("`@("`@("`D
M=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R
M87DH)W-U;6UA<GDG(#T^("1T<G5N8W-U;6UA<GDL#0H@("`@("`@("`@("`G
M<V5L9B<@/3X@)'1R=6YC;7ES=6UM87)Y*2P-"B`@("`@("`@("`@("=P86-K
M86=E+GAM;"`Q+C`@<W5M;6%R>2`B)7-U;6UA<GDE(B!D;V5S(&YO="!M871C
M:"`B)7-E;&8E(B<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]D:69F97)E
M;G1$97-C<FEP=&EO;B@D9&5S8W)I<'1I;VXI#0H@("`@>PT*("`@("`@("`D
M=')U;F-D97-C<FEP=&EO;B`]('1R:6TH<W1R;&5N*"1D97-C<FEP=&EO;BD@
M/"`R-2`_("1D97-C<FEP=&EO;B`Z('-U8G-T<B@D9&5S8W)I<'1I;VXL(#`L
M(#(T*2`N("<N+BXG*3L-"B`@("`@("`@)'1R=6YC;7ED97-C<FEP=&EO;B`]
M('1R:6TH<W1R;&5N*"1T:&ES+3YG971$97-C<FEP=&EO;B@I*2`\(#(U(#\@
M)'1H:7,M/F=E=$1E<V-R:7!T:6]N*"D@.@T*("`@("`@("`@("`@<W5B<W1R
M*"1T:&ES+3YG971D97-C<FEP=&EO;B@I+"`P+"`R-"D@+B`G+BXN)RD[#0H@
M("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R
M;W(G+"!A<G)A>2@G9&5S8W)I<'1I;VXG(#T^("1T<G5N8V1E<V-R:7!T:6]N
M+`T*("`@("`@("`@("`@)W-E;&8G(#T^("1T<G5N8VUY9&5S8W)I<'1I;VXI
M+`T*("`@("`@("`@("`@)W!A8VMA9V4N>&UL(#$N,"!D97-C<FEP=&EO;B`B
M)61E<V-R:7!T:6]N)2(@9&]E<R!N;W0@;6%T8V@@(B5S96QF)2(G*3L-"B`@
M("!]#0H-"B`@("!F=6YC=&EO;B!?;6ES<VEN9T9I;&4H)&9I;&4I#0H@("`@
M>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@
M)V5R<F]R)RP@87)R87DH)V9I;&4G(#T^("1F:6QE*2P-"B`@("`@("`@("`@
M("=P86-K86=E+GAM;"`Q+C`@9FEL92`B)69I;&4E(B!I<R!N;W0@<')E<V5N
M="!I;B`\8V]N=&5N=',^)RD[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M5T%23DE.1R`M(&1O(&YO="!U<V4@=&AI<R!F=6YC=&EO;B!U;FQE<W,@>6]U
M(&MN;W<@=VAA="!Y;W4G<F4@9&]I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!S971287=3=&%T92@D<W1A=&4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M7W!A8VMA9V5);F9O6R=S=&%B:6QI='DG75LG<F5L96%S92==(#T@)'-T871E
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%=!4DY)3D<@+2!D;R!N;W0@
M=7-E('1H:7,@9G5N8W1I;VX@=6YL97-S('EO=2!K;F]W('=H870@>6]U)W)E
M(&1O:6YG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T4F%W0V]M<&%T:6)L
M92@D8V]M<&%T:6)L92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G
M94EN9F];)V-O;7!A=&EB;&4G72`]("1C;VUP871I8FQE.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("`J(%=!4DY)3D<@+2!D;R!N;W0@=7-E('1H:7,@9G5N
M8W1I;VX@=6YL97-S('EO=2!K;F]W('=H870@>6]U)W)E(&1O:6YG#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@<V5T4F%W4&%C:V%G92@D<&%C:V%G92D-"B`@
M("![#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)VYA;64G72`]("1P
M86-K86=E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%=!4DY)3D<@+2!D
M;R!N;W0@=7-E('1H:7,@9G5N8W1I;VX@=6YL97-S('EO=2!K;F]W('=H870@
M>6]U)W)E(&1O:6YG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T4F%W0VAA
M;FYE;"@D8VAA;FYE;"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G
M94EN9F];)V-H86YN96PG72`]("1C:&%N;F5L.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N('-E=%)E<75E<W1E9$=R;W5P*"1G<F]U<"D-"B`@("![#0H@("`@
M("`@("1T:&ES+3Y?<F5Q=65S=&5D1W)O=7`@/2`D9W)O=7`[#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@9V5T4F5Q=65S=&5D1W)O=7`H*0T*("`@('L-"B`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<F5Q=65S=&5D1W)O=7`I*2![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R97%U97-T961'<F]U<#L-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@1F]R('-A=FEN9R!I;B!T:&4@<F5G:7-T<GDN#0H@("`@
M("H-"B`@("`@*B!3970@=&AE(&QA<W0@=F5R<VEO;B!T:&%T('=A<R!I;G-T
M86QL960-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@<V5T3&%S=$EN<W1A;&QE9%9E<G-I;VXH)'9E<G-I;VXI#0H@("`@
M>PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=?;&%S='9E<G-I;VXG
M72`]("1V97)S:6]N.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!R971U
M<FX@<W1R:6YG?&9A;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T3&%S
M=$EN<W1A;&QE9%9E<G-I;VXH*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)U]L87-T=F5R<VEO;B==*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)U]L87-T=F5R
M<VEO;B==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!$971E<FUI;F5S('=H971H97(@=&AI
M<R!P86-K86=E+GAM;"!H87,@<&]S="UI;G-T86QL('-C<FEP=',@;W(@;F]T
M#0H@("`@("H@0')E='5R;B!A<G)A>7QF86QS90T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(&QI<W10;W-T:6YS=&%L;%-C<FEP=',H*0T*("`@('L-"B`@("`@
M("`@)&9I;&5L:7-T(#T@)'1H:7,M/F=E=$9I;&5L:7-T*"D[#0H@("`@("`@
M("1C;VYT96YT<R`]("1T:&ES+3YG971#;VYT96YT<R@I.PT*("`@("`@("`D
M8V]N=&5N=',@/2`D8V]N=&5N='-;)V1I<B==6R=F:6QE)UT[#0H@("`@("`@
M(&EF("@A:7-?87)R87DH)&-O;G1E;G1S*2!\?"`A:7-S970H)&-O;G1E;G1S
M6S!=*2D@>PT*("`@("`@("`@("`@)&-O;G1E;G1S(#T@87)R87DH)&-O;G1E
M;G1S*3L-"B`@("`@("`@?0T*("`@("`@("`D=&%S:V9I;&5S(#T@87)R87DH
M*3L-"B`@("`@("`@9F]R96%C:"`H)&-O;G1E;G1S(&%S("1F:6QE*2![#0H@
M("`@("`@("`@("`D871T<R`]("1F:6QE6R=A='1R:6)S)UT[#0H@("`@("`@
M("`@("!U;G-E="@D9FEL95LG871T<FEB<R==*3L-"B`@("`@("`@("`@(&EF
M("AC;W5N="@D9FEL92DI('L-"B`@("`@("`@("`@("`@("`D=&%S:V9I;&5S
M6R1A='1S6R=N86UE)UU=(#T@)&9I;&4[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@)&-O;6UO;B`](&YE=R!014%27T-O;6UO;CL-"B`@
M("`@("`@)&-O;6UO;BT^9&5B=6<@/2`D=&AI<RT^7V-O;F9I9RT^9V5T*"=V
M97)B;W-E)RD[#0H@("`@("`@("1T:&ES+3Y?<V-R:7!T<R`](&%R<F%Y*"D[
M#0H@("`@("`@("1R970@/2!A<G)A>2@I.PT*("`@("`@("!F;W)E86-H("@D
M=&%S:V9I;&5S(&%S("1N86UE(#T^("1T87-K<RD@>PT*("`@("`@("`@("`@
M:68@*"%I<W-E="@D9FEL96QI<W1;)&YA;65=*2D@>PT*("`@("`@("`@("`@
M("`@("\O(&EG;F]R960@9FEL97,@=VEL;"!N;W0@8F4@:6X@=&AE(&9I;&5L
M:7-T#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`D871T<R`]("1F:6QE;&ES=%LD;F%M95T[#0H@("`@
M("`@("`@("!F;W)E86-H("@D=&%S:W,@87,@)'1A9R`]/B`D<F%W*2![#0H@
M("`@("`@("`@("`@("`@)'1A<VL@/2`D=&AI<RT^9V5T5&%S:R@D=&%G*3L-
M"B`@("`@("`@("`@("`@("`D=&%S:R`]("9N97<@)'1A<VLH)'1H:7,M/E]C
M;VYF:6<L("1C;VUM;VXL(%!%05)?5$%32U])3E-404Q,*3L-"B`@("`@("`@
M("`@("`@("!I9B`H)'1A<VLM/FES4V-R:7!T*"DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)')E=%M=(#T@)&9I;&5L:7-T6R1N86UE75LG:6YS=&%L;&5D
M7V%S)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(&EF("AC;W5N="@D<F5T*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N("1R970[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($EN:71I86QI>F4@<&]S
M="UI;G-T86QL('-C<FEP=',@9F]R(')U;FYI;F<-"B`@("`@*@T*("`@("`J
M(%1H:7,@;65T:&]D(&-A;B!B92!U<V5D('1O(&1E=&5C="!P;W-T+6EN<W1A
M;&P@<V-R:7!T<RP@87,@=&AE(')E='5R;B!V86QU90T*("`@("`J(&EN9&EC
M871E<R!W:&5T:&5R(&%N>2!E>&ES=`T*("`@("`J($!R971U<FX@8F]O;`T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(&EN:710;W-T:6YS=&%L;%-C<FEP=',H
M*0T*("`@('L-"B`@("`@("`@)&9I;&5L:7-T(#T@)'1H:7,M/F=E=$9I;&5L
M:7-T*"D[#0H@("`@("`@("1C;VYT96YT<R`]("1T:&ES+3YG971#;VYT96YT
M<R@I.PT*("`@("`@("`D8V]N=&5N=',@/2`D8V]N=&5N='-;)V1I<B==6R=F
M:6QE)UT[#0H@("`@("`@(&EF("@A:7-?87)R87DH)&-O;G1E;G1S*2!\?"`A
M:7-S970H)&-O;G1E;G1S6S!=*2D@>PT*("`@("`@("`@("`@)&-O;G1E;G1S
M(#T@87)R87DH)&-O;G1E;G1S*3L-"B`@("`@("`@?0T*("`@("`@("`D=&%S
M:V9I;&5S(#T@87)R87DH*3L-"B`@("`@("`@9F]R96%C:"`H)&-O;G1E;G1S
M(&%S("1F:6QE*2![#0H@("`@("`@("`@("`D871T<R`]("1F:6QE6R=A='1R
M:6)S)UT[#0H@("`@("`@("`@("!U;G-E="@D9FEL95LG871T<FEB<R==*3L-
M"B`@("`@("`@("`@(&EF("AC;W5N="@D9FEL92DI('L-"B`@("`@("`@("`@
M("`@("`D=&%S:V9I;&5S6R1A='1S6R=N86UE)UU=(#T@)&9I;&4[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&-O;6UO;B`](&YE=R!0
M14%27T-O;6UO;CL-"B`@("`@("`@)&-O;6UO;BT^9&5B=6<@/2`D=&AI<RT^
M7V-O;F9I9RT^9V5T*"=V97)B;W-E)RD[#0H@("`@("`@("1T:&ES+3Y?<V-R
M:7!T<R`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1T87-K9FEL97,@
M87,@)&YA;64@/3X@)'1A<VMS*2![#0H@("`@("`@("`@("`D871T<R`]("1F
M:6QE;&ES=%LD;F%M95T[#0H@("`@("`@("`@("!F;W)E86-H("@D=&%S:W,@
M87,@)'1A9R`]/B`D<F%W*2![#0H@("`@("`@("`@("`@("`@)'1A<VMN86UE
M(#T@)'1H:7,M/F=E=%1A<VLH)'1A9RD[#0H@("`@("`@("`@("`@("`@)'1A
M<VL@/2`F;F5W("1T87-K;F%M92@D=&AI<RT^7V-O;F9I9RP@)&-O;6UO;BP@
M4$5!4E]405-+7TE.4U1!3$PI.PT*("`@("`@("`@("`@("`@(&EF("@A)'1A
M<VLM/FES4V-R:7!T*"DI('L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN
M=64[("\O('-C<FEP=',@87)E(&]N;'D@:&%N9&QE9"!A9G1E<B!I;G-T86QL
M871I;VX-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&QA
M<W1V97)S:6]N(#T@:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG7VQA<W1V
M97)S:6]N)UTI(#\-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K
M86=E26YF;ULG7VQA<W1V97)S:6]N)UT@.B!N=6QL.PT*("`@("`@("`@("`@
M("`@("1T87-K+3YI;FET*"1R87<L("1A='1S+"`D;&%S='9E<G-I;VXI.PT*
M("`@("`@("`@("`@("`@("1R97,@/2`D=&%S:RT^<W1A<G1397-S:6]N*"1T
M:&ES+"`D871T<ULG:6YS=&%L;&5D7V%S)UTI.PT*("`@("`@("`@("`@("`@
M(&EF("@A)')E<RD@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L@
M+R\@<VMI<"!T:&ES(&9I;&4-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<RDI('L-"B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1R97,[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("1A<W-I9VX@/2`F)'1A<VL[#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]S8W)I<'1S6UT@/2`F)&%S<VEG;CL-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]S
M8W)I<'1S*2D@>PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T
M:6]N(')U;E!O<W1I;G-T86QL4V-R:7!T<R@I#0H@("`@>PT*("`@("`@("!I
M9B`H)'1H:7,M/FEN:710;W-T:6YS=&%L;%-C<FEP=',H*2D@>PT*("`@("`@
M("`@("`@)'5I(#T@)E!%05)?1G)O;G1E;F0Z.G-I;F=L971O;B@I.PT*("`@
M("`@("`@("`@:68@*"1U:2D@>PT*("`@("`@("`@("`@("`@("1U:2T^<G5N
M4&]S=&EN<W1A;&Q38W)I<'1S*"1T:&ES+3Y?<V-R:7!T<RP@)'1H:7,I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H-"B`@("`O*BH-
M"B`@("`@*B!#;VYV97)T(&$@<F5C=7)S:79E('-E="!O9B`\9&ER/B!A;F0@
M/&9I;&4^('1A9W,@:6YT;R!A('-I;F=L92`\9&ER/B!T86<@=VET:`T*("`@
M("`J(#QF:6QE/B!T86=S+@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&9L871T
M96Y&:6QE;&ES="@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]P86-K86=E26YF;ULG8G5N9&QE)UTI*2![#0H@("`@("`@("`@("!R971U
M<FX[#0H@("`@("`@('T-"B`@("`@("`@)&9I;&5L:7-T(#T@87)R87DH*3L-
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E
M;G1S)UU;)V1I<B==6R=D:7(G72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?
M9V5T1FQA='1E;F5D1FEL96QI<W0H)&9I;&5L:7-T+"`D=&AI<RT^7W!A8VMA
M9V5);F9O6R=C;VYT96YT<R==6R=D:7(G72D[#0H@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1F:6QE;&ES=%LQ72DI('L-"B`@("`@("`@("`@("`@("`D9FEL
M96QI<W0@/2`D9FEL96QI<W1;,%T[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT<R==6R=D:7(G75LG
M9FEL92==(#T@)&9I;&5L:7-T.PT*("`@("`@("`@("`@=6YS970H)'1H:7,M
M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V1I<B==*3L-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("\O(&5L<V4@86QR96%D>2!F
M;&%T=&5N960@8G5T(&-H96-K(&9O<B!B87-E:6YS=&%L;&1I<B!P<F]P86=A
M=&EO;@T*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)V-O;G1E;G1S)UU;)V1I<B==6R=A='1R:6)S)UU;)V)A<V5I;G-T86QL
M9&ER)UTI*2![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UU;,%TI*2![
M#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UT@87,@)&D@/3X@)&9I
M;&4I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9FEL
M95LG871T<FEB<R==6R=B87-E:6YS=&%L;&1I<B==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G75LD:5U;)V%T
M=')I8G,G75LG8F%S96EN<W1A;&QD:7(G70T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#T@)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG
M9&ER)UU;)V%T=')I8G,G75LG8F%S96EN<W1A;&QD:7(G73L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF
M;ULG8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G75LG871T<FEB<R==6R=B87-E
M:6YS=&%L;&1I<B==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT<R==6R=D:7(G75LG9FEL92==6R=A
M='1R:6)S)UU;)V)A<V5I;G-T86QL9&ER)UT-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`]("1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;
M)V1I<B==6R=A='1R:6)S)UU;)V)A<V5I;G-T86QL9&ER)UT[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R
M86T@87)R87D@=&AE(&9I;F%L(&9L871T96YE9"!F:6QE(&QI<W0-"B`@("`@
M*B!`<&%R86T@87)R87D@=&AE(&-U<G)E;G0@9&ER96-T;W)Y(&)E:6YG('!R
M;V-E<W-E9`T*("`@("`J($!P87)A;2!S=')I;F=\9F%L<V4@86YY(')E8W5R
M<VEV96QY(&EN:&5R:71E9"!B865I;G-T86QL9&ER(&%T=')I8G5T90T*("`@
M("`J($!P87)A;2!S=')I;F<@<')I=F%T92!R96-U<G-I;VX@=F%R:6%B;&4-
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("H@0&%C8V5S<R!P<F]T96-T
M960-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?9V5T1FQA='1E;F5D1FEL96QI
M<W0H)B1F:6QE<RP@)&1I<BP@)&)A<V5I;G-T86QL(#T@9F%L<V4L("1P871H
M(#T@)R<I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)&1I<ELG871T<FEB
M<R==*2`F)B!I<W-E="@D9&ER6R=A='1R:6)S)UU;)V)A<V5I;G-T86QL9&ER
M)UTI*2![#0H@("`@("`@("`@("`D8F%S96EN<W1A;&P@/2`D9&ER6R=A='1R
M:6)S)UU;)V)A<V5I;G-T86QL9&ER)UT[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES<V5T*"1D:7);)V1I<B==*2D@>PT*("`@("`@("`@("`@:68@*"%I
M<W-E="@D9&ER6R=D:7(G75LP72DI('L-"B`@("`@("`@("`@("`@("`D9&ER
M6R=D:7(G72`](&%R<F%Y*"1D:7);)V1I<B==*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1D:7);)V1I<B==(&%S("1S=6)D:7(I
M('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1S=6)D:7);)V%T=')I
M8G,G72D@?'P@(6ES<V5T*"1S=6)D:7);)V%T=')I8G,G75LG;F%M92==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`D;F%M92`]("<J=6YK;F]W;BHG.PT*
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M("1N86UE(#T@)'-U8F1I<ELG871T<FEB<R==6R=N86UE)UT[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1N97=P871H(#T@96UP='DH
M)'!A=&@I(#\@)&YA;64@.@T*("`@("`@("`@("`@("`@("`@("`D<&%T:"`N
M("<O)R`N("1N86UE.PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T1FQA
M='1E;F5D1FEL96QI<W0H)&9I;&5S+"`D<W5B9&ER+`T*("`@("`@("`@("`@
M("`@("`@("`D8F%S96EN<W1A;&PL("1N97=P871H*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&1I<ELG9FEL92==
M*2D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D9&ER6R=F:6QE)UU;,%TI
M*2![#0H@("`@("`@("`@("`@("`@)&1I<ELG9FEL92==(#T@87)R87DH)&1I
M<ELG9FEL92==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1D:7);)V9I;&4G72!A<R`D9FEL92D@>PT*("`@("`@("`@("`@("`@
M("1A='1R<R`]("1F:6QE6R=A='1R:6)S)UT[#0H@("`@("`@("`@("`@("`@
M)&YA;64@/2`D871T<G-;)VYA;64G73L-"B`@("`@("`@("`@("`@("!I9B`H
M)&)A<V5I;G-T86QL("8F("%I<W-E="@D871T<G-;)V)A<V5I;G-T86QL9&ER
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1A='1R<ULG8F%S96EN<W1A
M;&QD:7(G72`]("1B87-E:6YS=&%L;#L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@)&%T=')S6R=N86UE)UT@/2!E;7!T>2@D<&%T:"D@
M/R`D;F%M92`Z("1P871H("X@)R\G("X@)&YA;64[#0H@("`@("`@("`@("`@
M("`@)&%T=')S6R=N86UE)UT@/2!P<F5G7W)E<&QA8V4H87)R87DH)R%<7%Q<
M*R$G+"`G(2\K(2<I+"!A<G)A>2@G+R<L("<O)RDL#0H@("`@("`@("`@("`@
M("`@("`@("1A='1R<ULG;F%M92==*3L-"B`@("`@("`@("`@("`@("`D9FEL
M95LG871T<FEB<R==(#T@)&%T=')S.PT*("`@("`@("`@("`@("`@("1F:6QE
M<UM=(#T@)&9I;&4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!S971#;VYF:6<H)B1C;VYF:6<I#0H@("`@>PT*
M("`@("`@("`D=&AI<RT^7V-O;F9I9R`]("8D8V]N9FEG.PT*("`@("`@("`D
M=&AI<RT^7W)E9VES=')Y(#T@)B1C;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T3&]G9V5R*"8D;&]G9V5R*0T*("`@
M('L-"B`@("`@("`@:68@*"%I<U]O8FIE8W0H)&QO9V=E<BD@?'P@(6UE=&AO
M9%]E>&ES=',H)&QO9V=E<BP@)VQO9R<I*2![#0H@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G3&]G9V5R(&UU<W0@8F4@8V]M<&%T:6)L
M92!W:71H(%!%05)?0V]M;6]N.CIL;V<G*3L-"B`@("`@("`@?0T*("`@("`@
M("`D=&AI<RT^7VQO9V=E<B`]("8D;&]G9V5R.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J(%=!4DY)3D<@+2!D;R!N;W0@=7-E('1H:7,@9G5N8W1I;VX@
M9&ER96-T;'D@=6YL97-S('EO=2!K;F]W('=H870@>6]U)W)E(&1O:6YG#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@<V5T1&5P<R@D9&5P<RD-"B`@("![#0H@
M("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE<R==(#T@
M)&1E<',[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T4&%C:V%G969I;&4H
M)&9I;&4L("1A<F-H:79E(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D=&AI
M<RT^7W!A8VMA9V5&:6QE(#T@)&9I;&4[#0H@("`@("`@("1T:&ES+3Y?87)C
M:&EV949I;&4@/2`D87)C:&EV92`_("1A<F-H:79E(#H@)&9I;&4[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@5W)A<'!E<B!T;R![0&QI;FL@4$5!4E]%
M<G)O<E-T86-K.CIG971%<G)O<G,H*7T-"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B!D971E<FUI;F5S('=H971H97(@=&\@<'5R9V4@=&AE(&5R<F]R('-T86-K
M(&%F=&5R(')E=')I979I;F<-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@9V5T5F%L:61A=&EO;E=A<FYI;F=S*"1P=7)G
M92`]('1R=64I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/E]S=&%C
M:RT^9V5T17)R;W)S*"1P=7)G92D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M9V5T4&%C:V%G949I;&4H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<&%C:V%G949I;&4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T07)C
M:&EV949I;&4H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?87)C
M:&EV949I;&4[#0H@("`@?0T*#0H-"B`@("`O*BH-"B`@("`@*B!$:7)E8W1L
M>2!S970@=&AE(&%R<F%Y('1H870@9&5F:6YE<R!T:&ES('!A8VMA9V5F:6QE
M#0H@("`@("H-"B`@("`@*B!705).24Y'.B!N;R!V86QI9&%T:6]N+B`@5&AI
M<R!S:&]U;&0@;VYL>2!B92!P97)F;W)M960@8GD@:6YT97)N86P@;65T:&]D
M<PT*("`@("`J(&EN<VED92!014%2(&]R(&)Y(&EN<'5T=&EN9R!A;B!A<G)A
M>2!S879E9"!F<F]M(&%N(&5X:7-T:6YG(%!%05)?4&%C:V%G949I;&5?=C(-
M"B`@("`@*B!`<&%R86T@87)R87D-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!F
M<F]M07)R87DH)'!I;F9O*0T*("`@('L-"B`@("`@("`@=6YS970H)'!I;F9O
M6R=O;&0G72D[#0H@("`@("`@('5N<V5T*"1P:6YF;ULG>'-D=F5R<VEO;B==
M*3L-"B`@("`@("`@)'1H:7,M/E]I;F-O;7!L971E(#T@9F%L<V4[#0H@("`@
M("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D<&EN9F\[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@:7-);F-O;7!L971E*"D-"B`@("![#0H@("`@("`@(')E
M='5R;B`D=&AI<RT^7VEN8V]M<&QE=&4[#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@0')E='5R;B!A<G)A>0T*("`@("`J+PT*("`@(&9U;F-T:6]N('1O
M07)R87DH)&9O<G)E9R`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"$D
M=&AI<RT^=F%L:61A=&4H4$5!4E]604Q)1$%415].3U)-04PI*2![#0H@("`@
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N("1T:&ES+3YG971!<G)A>2@D9F]R<F5G*3L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!G971!<G)A>2@D9F]R4F5G(#T@9F%L<V4I#0H@("`@>PT*("`@
M("`@("!I9B`H)&9O<E)E9RD@>PT*("`@("`@("`@("`@)&%R<B`]("1T:&ES
M+3Y?<&%C:V%G94EN9F\[#0H@("`@("`@("`@("`D87)R6R=O;&0G72`](&%R
M<F%Y*"D[#0H@("`@("`@("`@("`D87)R6R=O;&0G75LG=F5R<VEO;B==(#T@
M)'1H:7,M/F=E=%9E<G-I;VXH*3L-"B`@("`@("`@("`@("1A<G);)V]L9"==
M6R=R96QE87-E7V1A=&4G72`]("1T:&ES+3YG971$871E*"D[#0H@("`@("`@
M("`@("`D87)R6R=O;&0G75LG<F5L96%S95]S=&%T92==(#T@)'1H:7,M/F=E
M=%-T871E*"D[#0H@("`@("`@("`@("`D87)R6R=O;&0G75LG<F5L96%S95]L
M:6-E;G-E)UT@/2`D=&AI<RT^9V5T3&EC96YS92@I.PT*("`@("`@("`@("`@
M)&%R<ELG;VQD)UU;)W)E;&5A<V5?;F]T97,G72`]("1T:&ES+3YG971.;W1E
M<R@I.PT*("`@("`@("`@("`@)&%R<ELG;VQD)UU;)W)E;&5A<V5?9&5P<R==
M(#T@)'1H:7,M/F=E=$1E<',H*3L-"B`@("`@("`@("`@("1A<G);)V]L9"==
M6R=M86EN=&%I;F5R<R==(#T@)'1H:7,M/F=E=$UA:6YT86EN97)S*"D[#0H@
M("`@("`@("`@("`D87)R6R=X<V1V97)S:6]N)UT@/2`G,BXP)SL-"B`@("`@
M("`@("`@(')E='5R;B`D87)R.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@)&EN9F\@/2`D=&AI<RT^7W!A8VMA9V5);F9O.PT*("`@("`@("`@
M("`@=6YS970H)&EN9F];)V1I<G1R964G72D[#0H@("`@("`@("`@("!I9B`H
M:7-S970H)&EN9F];)U]L87-T=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@
M("`@('5N<V5T*"1I;F9O6R=?;&%S='9E<G-I;VXG72D[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)&EN9F];)R-B:6YA<GEP86-K
M86=E)UTI*2![#0H@("`@("`@("`@("`@("`@=6YS970H)&EN9F];)R-B:6YA
M<GEP86-K86=E)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T
M=7)N("1I;F9O.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M<&%C:V%G94EN9F\H)&9I96QD*0T*("`@('L-"B`@("`@("`@)&%R<B`]("1T
M:&ES+3YG971!<G)A>2AT<G5E*3L-"B`@("`@("`@:68@*"1F:65L9"`]/2`G
M<W1A=&4G*2![#0H@("`@("`@("`@("!R971U<FX@)&%R<ELG<W1A8FEL:71Y
M)UU;)W)E;&5A<V4G73L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&9I96QD
M(#T]("=A<&DM=F5R<VEO;B<I('L-"B`@("`@("`@("`@(')E='5R;B`D87)R
M6R=V97)S:6]N)UU;)V%P:2==.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M9FEE;&0@/3T@)V%P:2US=&%T92<I('L-"B`@("`@("`@("`@(')E='5R;B`D
M87)R6R=S=&%B:6QI='DG75LG87!I)UT[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES<V5T*"1A<G);)V]L9"==6R1F:65L9%TI*2![#0H@("`@("`@("`@
M("!I9B`H(6ES7W-T<FEN9R@D87)R6R=O;&0G75LD9FEE;&1=*2D@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B!N=6QL.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@<F5T=7)N("1A<G);)V]L9"==6R1F:65L9%T[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1A<G);)&9I96QD72DI('L-"B`@("`@
M("`@("`@(&EF("@A:7-?<W1R:6YG*"1A<G);)&9I96QD72DI('L-"B`@("`@
M("`@("`@("`@("!R971U<FX@;G5L;#L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(')E='5R;B`D87)R6R1F:65L9%T[#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N(&YU;&P[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T3F%M
M92@I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/F=E=%!A8VMA9V4H
M*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971086-K86=E*"D-"B`@("![
M#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=N86UE
M)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF
M;ULG;F%M92==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971#:&%N;F5L*"D-"B`@("![#0H@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=U<FDG72DI
M('L-"B`@("`@("`@("`@(')E='5R;B`G7U]U<FDG.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N;F5L
M)UTI*2![#0H@("`@("`@("`@("!R971U<FX@<W1R=&]L;W=E<B@D=&AI<RT^
M7W!A8VMA9V5);F9O6R=C:&%N;F5L)UTI.PT*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G9715<FDH
M*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)W5R:2==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C
M:V%G94EN9F];)W5R:2==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971%>'1E;F1S*"D-"B`@
M("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=E
M>'1E;F1S)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K
M86=E26YF;ULG97AT96YD<R==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G9713=6UM87)Y*"D-
M"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O
M6R=S=6UM87)Y)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P
M86-K86=E26YF;ULG<W5M;6%R>2==.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971$97-C<FEP
M=&EO;B@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K
M86=E26YF;ULG9&5S8W)I<'1I;VXG72DI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=D97-C<FEP=&EO;B==.PT*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!G971-86EN=&%I;F5R<R@D<F%W(#T@9F%L<V4I#0H@("`@>PT*("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)VQE860G72DI
M('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H)')A=RD@>PT*("`@("`@("`@("`@)')E="`](&%R<F%Y*"=L
M96%D)R`]/B`D=&AI<RT^7W!A8VMA9V5);F9O6R=L96%D)UTI.PT*("`@("`@
M("`@("`@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E=F5L;W!E<B==
M*2D@/PT*("`@("`@("`@("`@("`@("1R971;)V1E=F5L;W!E<B==(#T@)'1H
M:7,M/E]P86-K86=E26YF;ULG9&5V96QO<&5R)UT@.FYU;&P[#0H@("`@("`@
M("`@("`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=')I8G5T;W(G
M72DI(#\-"B`@("`@("`@("`@("`@("`D<F5T6R=C;VYT<FEB=71O<B==(#T@
M)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=')I8G5T;W(G72`Z;G5L;#L-"B`@
M("`@("`@("`@("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=H96QP97(G
M72DI(#\-"B`@("`@("`@("`@("`@("`D<F5T6R=H96QP97(G72`]("1T:&ES
M+3Y?<&%C:V%G94EN9F];)VAE;'!E<B==(#IN=6QL.PT*("`@("`@("`@("`@
M<F5T=7)N("1R970[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M<F5T(#T@87)R87DH*3L-"B`@("`@("`@("`@("1L96%D<R`](&ES<V5T*"1T
M:&ES+3Y?<&%C:V%G94EN9F];)VQE860G75LP72D@/R`D=&AI<RT^7W!A8VMA
M9V5);F9O6R=L96%D)UT@.@T*("`@("`@("`@("`@("`@(&%R<F%Y*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)VQE860G72D[#0H@("`@("`@("`@("!F;W)E86-H
M("@D;&5A9',@87,@)&QE860I('L-"B`@("`@("`@("`@("`@("`D<R`]("1L
M96%D.PT*("`@("`@("`@("`@("`@("1S6R=H86YD;&4G72`]("1S6R=U<V5R
M)UT[#0H@("`@("`@("`@("`@("`@=6YS970H)'-;)W5S97(G72D[#0H@("`@
M("`@("`@("`@("`@)'-;)W)O;&4G72`]("=L96%D)SL-"B`@("`@("`@("`@
M("`@("`D<F5T6UT@/2`D<SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=D979E;&]P97(G72DI
M('L-"B`@("`@("`@("`@("`@("`D;&5A9',@/2!I<W-E="@D=&AI<RT^7W!A
M8VMA9V5);F9O6R=D979E;&]P97(G75LP72D@/PT*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=D979E;&]P97(G72`Z#0H@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E
M=F5L;W!E<B==*3L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D;&5A9',@
M87,@)&UA:6YT86EN97(I('L-"B`@("`@("`@("`@("`@("`@("`@)',@/2`D
M;6%I;G1A:6YE<CL-"B`@("`@("`@("`@("`@("`@("`@)'-;)VAA;F1L92==
M(#T@)'-;)W5S97(G73L-"B`@("`@("`@("`@("`@("`@("`@=6YS970H)'-;
M)W5S97(G72D[#0H@("`@("`@("`@("`@("`@("`@("1S6R=R;VQE)UT@/2`G
M9&5V96QO<&5R)SL-"B`@("`@("`@("`@("`@("`@("`@)')E=%M=(#T@)',[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1R:6)U=&]R
M)UTI*2![#0H@("`@("`@("`@("`@("`@)&QE861S(#T@:7-S970H)'1H:7,M
M/E]P86-K86=E26YF;ULG8V]N=')I8G5T;W(G75LP72D@/PT*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT<FEB=71O<B==
M(#H-"B`@("`@("`@("`@("`@("`@("`@87)R87DH)'1H:7,M/E]P86-K86=E
M26YF;ULG8V]N=')I8G5T;W(G72D[#0H@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&QE861S(&%S("1M86EN=&%I;F5R*2![#0H@("`@("`@("`@("`@("`@
M("`@("1S(#T@)&UA:6YT86EN97([#0H@("`@("`@("`@("`@("`@("`@("1S
M6R=H86YD;&4G72`]("1S6R=U<V5R)UT[#0H@("`@("`@("`@("`@("`@("`@
M('5N<V5T*"1S6R=U<V5R)UTI.PT*("`@("`@("`@("`@("`@("`@("`D<ULG
M<F]L92==(#T@)V-O;G1R:6)U=&]R)SL-"B`@("`@("`@("`@("`@("`@("`@
M)')E=%M=(#T@)',[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];
M)VAE;'!E<B==*2D@>PT*("`@("`@("`@("`@("`@("1L96%D<R`](&ES<V5T
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)VAE;'!E<B==6S!=*2`_#0H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)VAE;'!E<B==(#H-
M"B`@("`@("`@("`@("`@("`@("`@87)R87DH)'1H:7,M/E]P86-K86=E26YF
M;ULG:&5L<&5R)UTI.PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1L96%D
M<R!A<R`D;6%I;G1A:6YE<BD@>PT*("`@("`@("`@("`@("`@("`@("`D<R`]
M("1M86EN=&%I;F5R.PT*("`@("`@("`@("`@("`@("`@("`D<ULG:&%N9&QE
M)UT@/2`D<ULG=7-E<B==.PT*("`@("`@("`@("`@("`@("`@("!U;G-E="@D
M<ULG=7-E<B==*3L-"B`@("`@("`@("`@("`@("`@("`@)'-;)W)O;&4G72`]
M("=H96QP97(G.PT*("`@("`@("`@("`@("`@("`@("`D<F5T6UT@/2`D<SL-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!R971U<FX@)')E=#L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T3&5A9',H*0T*("`@('L-
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)VQE860G
M72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O
M6R=L96%D)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$1E=F5L;W!E<G,H*0T*("`@('L-
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E=F5L
M;W!E<B==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G
M94EN9F];)V1E=F5L;W!E<B==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971#;VYT<FEB=71O
M<G,H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)V-O;G1R:6)U=&]R)UTI*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=')I8G5T;W(G73L-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@9V5T2&5L<&5R<R@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]P86-K86=E26YF;ULG:&5L<&5R)UTI*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG:&5L<&5R)UT[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T
M:6]N('-E=$1A=&4H)&1A=&4I#0H@("`@>PT*("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1A=&4G72DI('L-"B`@("`@("`@("`@
M("\O(&5N<W5R92!T:&%T('1H92!E>'1E;F1S('1A9R!I<R!S970@=7`@:6X@
M=&AE(')I9VAT(&QO8V%T:6]N#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA
M9V5);F9O(#T@)'1H:7,M/E]I;G-E<G1"969O<F4H)'1H:7,M/E]P86-K86=E
M26YF;RP-"B`@("`@("`@("`@("`@("!A<G)A>2@G=&EM92<L("=V97)S:6]N
M)RP-"B`@("`@("`@("`@("`@("`@("`@)W-T86)I;&ET>2<L("=L:6-E;G-E
M)RP@)VYO=&5S)RP@)V-O;G1E;G1S)RP@)V-O;7!A=&EB;&4G+`T*("`@("`@
M("`@("`@("`@("`@("`G9&5P96YD96YC:65S)RP@)W!R;W9I9&5S97AT96YS
M:6]N)RP@)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP-"B`@("`@("`@("`@("`@
M("`@("`@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L#0H@("`@("`@
M("`@("`@("`@("`@("=E>'1B:6YR96QE87-E)RP@)V)U;F1L92<L("=C:&%N
M9V5L;V<G*2P@87)R87DH*2P@)V1A=&4G*3L-"B`@("`@("`@?0T*("`@("`@
M("`D=&AI<RT^7W!A8VMA9V5);F9O6R=D871E)UT@/2`D9&%T93L-"B`@("`@
M("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!S9714:6UE*"1T:6UE*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]I<U9A
M;&ED(#T@,#L-"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=T:6UE)UTI*2![#0H@("`@("`@("`@("`O+R!E;G-U<F4@=&AA="!T
M:&4@=&EM92!T86<@:7,@<V5T('5P(&EN('1H92!R:6=H="!L;V-A=&EO;@T*
M("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?:6YS
M97)T0F5F;W)E*"1T:&ES+3Y?<&%C:V%G94EN9F\L#0H@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=V97)S:6]N)RP-"B`@("`@("`@("`@("`@("`@("`@
M)W-T86)I;&ET>2<L("=L:6-E;G-E)RP@)VYO=&5S)RP@)V-O;G1E;G1S)RP@
M)V-O;7!A=&EB;&4G+`T*("`@("`@("`@("`@("`@("`@("`G9&5P96YD96YC
M:65S)RP@)W!R;W9I9&5S97AT96YS:6]N)RP@)W-R8W!A8VMA9V4G+"`G<W)C
M=7)I)RP-"B`@("`@("`@("`@("`@("`@("`@)W!H<')E;&5A<V4G+"`G97AT
M<W)C<F5L96%S92<L#0H@("`@("`@("`@("`@("`@("`@("=E>'1B:6YR96QE
M87-E)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P@)'1I;64L("=T:6UE)RD[
M#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG=&EM
M92==(#T@)'1I;64[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T1&%T92@I
M#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF
M;ULG9&%T92==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C
M:V%G94EN9F];)V1A=&4G73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T5&EM92@I#0H@("`@
M>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG=&EM
M92==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN
M9F];)W1I;64G73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('!A8VMA9V5\87!I
M('9E<G-I;VX@8V%T96=O<GD@=&\@<F5T=7)N#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@9V5T5F5R<VEO;B@D:V5Y(#T@)W)E;&5A<V4G*0T*("`@('L-"B`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W9E<G-I;VXG
M75LD:V5Y72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA
M9V5);F9O6R=V97)S:6]N)UU;)&ME>5T[#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=%-T86)I
M;&ET>2@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K
M86=E26YF;ULG<W1A8FEL:71Y)UTI*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]P86-K86=E26YF;ULG<W1A8FEL:71Y)UT[#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N
M(&=E=%-T871E*"1K97D@/2`G<F5L96%S92<I#0H@("`@>PT*("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<W1A8FEL:71Y)UU;)&ME
M>5TI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF
M;ULG<W1A8FEL:71Y)UU;)&ME>5T[#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$QI8V5N<V4H
M)')A=R`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)VQI8V5N<V4G72DI('L-"B`@("`@("`@("`@(&EF
M("@D<F%W*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C
M:V%G94EN9F];)VQI8V5N<V4G73L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^7W!A8VMA9V5);F9O6R=L:6-E;G-E
M)UTI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G
M94EN9F];)VQI8V5N<V4G75LG7V-O;G1E;G0G73L-"B`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G
M94EN9F];)VQI8V5N<V4G73L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M9V5T3&EC96YS94QO8V%T:6]N*"D-"B`@("![#0H@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]P86-K86=E26YF;ULG;&EC96YS92==*2!\?"`A:7-?87)R
M87DH)'1H:7,M/E]P86-K86=E26YF;ULG;&EC96YS92==*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=L:6-E;G-E)UU;)V%T=')I8G,G73L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971.;W1E<R@I#0H@("`@>PT*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG;F]T97,G72DI
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=N
M;W1E<R==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!2971U<FX@=&AE(#QU<V5S<F]L93X@
M=&%G(&-O;G1E;G1S+"!I9B!A;GD-"B`@("`@*B!`<F5T=7)N(&%R<F%Y?&9A
M;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T57-E<W)O;&4H*0T*("`@
M('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W5S
M97-R;VQE)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K
M86=E26YF;ULG=7-E<W)O;&4G73L-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4F5T=7)N('1H
M92`\=7-E<W1A<VL^('1A9R!C;VYT96YT<RP@:68@86YY#0H@("`@("H@0')E
M='5R;B!A<G)A>7QF86QS90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%5S
M97-T87-K*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A
M8VMA9V5);F9O6R=U<V5S=&%S:R==*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<&%C:V%G94EN9F];)W5S97-T87-K)UT[#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("`J(%1H:7,@<VAO=6QD(&]N;'D@8F4@=7-E9"!T;R!R971R:65V92!F:6QE
M;F%M97,@86YD(&EN<W1A;&P@871T<FEB=71E<PT*("`@("`J+PT*("`@(&9U
M;F-T:6]N(&=E=$9I;&5L:7-T*"1P<F5S97)V92`](&9A;'-E*0T*("`@('L-
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V9I;&5L
M:7-T)UTI("8F("$D<')E<V5R=F4I('L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==.PT*("`@("`@("!]#0H@
M("`@("`@("1T:&ES+3YF;&%T=&5N1FEL96QI<W0H*3L-"B`@("`@("`@:68@
M*"1C;VYT96YT<R`]("1T:&ES+3YG971#;VYT96YT<R@I*2![#0H@("`@("`@
M("`@("`D<F5T(#T@87)R87DH*3L-"B`@("`@("`@("`@(&EF("@A:7-S970H
M)&-O;G1E;G1S6R=D:7(G75LG9FEL92==6S!=*2D@>PT*("`@("`@("`@("`@
M("`@("1C;VYT96YT<ULG9&ER)UU;)V9I;&4G72`](&%R<F%Y*"1C;VYT96YT
M<ULG9&ER)UU;)V9I;&4G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!F;W)E86-H("@D8V]N=&5N='-;)V1I<B==6R=F:6QE)UT@87,@)&9I;&4I
M('L-"B`@("`@("`@("`@("`@("`D;F%M92`]("1F:6QE6R=A='1R:6)S)UU;
M)VYA;64G73L-"B`@("`@("`@("`@("`@("!I9B`H(21P<F5S97)V92D@>PT*
M("`@("`@("`@("`@("`@("`@("`D9FEL92`]("1F:6QE6R=A='1R:6)S)UT[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1R971;)&YA
M;65=(#T@)&9I;&4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M(21P<F5S97)V92D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G
M94EN9F];)V9I;&5L:7-T)UT@/2`D<F5T.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@<F5T=7)N("1R970[#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%)E='5R;B!C
M;VYF:6=U<F4@;W!T:6]N<R!A<G)A>2P@:68@86YY#0H@("`@("H-"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y?&9A;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M9V5T0V]N9FEG=7)E3W!T:6]N<R@I#0H@("`@>PT*("`@("`@("!I9B`H)'1H
M:7,M/F=E=%!A8VMA9V54>7!E*"D@(3T@)V5X='-R8R<I('L-"B`@("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D<F5L96%S
M97,@/2`D=&AI<RT^9V5T4F5L96%S97,H*3L-"B`@("`@("`@:68@*&ES<V5T
M*"1R96QE87-E<ULP72DI('L-"B`@("`@("`@("`@("1R96QE87-E<R`]("1R
M96QE87-E6S!=.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D<F5L
M96%S97-;)V-O;F9I9W5R96]P=&EO;B==*2D@>PT*("`@("`@("`@("`@:68@
M*"%I<W-E="@D<F5L96%S97-;)V-O;F9I9W5R96]P=&EO;B==6S!=*2D@>PT*
M("`@("`@("`@("`@("`@("1R96QE87-E<ULG8V]N9FEG=7)E;W!T:6]N)UT@
M/2!A<G)A>2@D<F5L96%S97-;)V-O;F9I9W5R96]P=&EO;B==*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT
M*"1R96QE87-E<ULG8V]N9FEG=7)E;W!T:6]N)UTI.R`D:2LK*2![#0H@("`@
M("`@("`@("`@("`@)')E;&5A<V5S6R=C;VYF:6=U<F5O<'1I;VXG75LD:5T@
M/2`D<F5L96%S97-;)V-O;F9I9W5R96]P=&EO;B==6R1I75LG871T<FEB<R==
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N("1R96QE87-E
M<ULG8V]N9FEG=7)E;W!T:6]N)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%1H:7,@:7,@
M;VYL>2!U<V5D(&%T(&EN<W1A;&PM=&EM92P@869T97(@86QL('-E<FEA;&EZ
M871I;VX-"B`@("`@*B!I<R!O=F5R+@T*("`@("`J+PT*("`@(&9U;F-T:6]N
M(')E<V5T1FEL96QI<W0H*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]P86-K
M86=E26YF;ULG9FEL96QI<W0G72`](&%R<F%Y*"D[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@4F5T<FEE=F4@82!L:7-T(&]F(&9I;&5S('1H870@<VAO
M=6QD(&)E(&EN<W1A;&QE9"!O;B!T:&ES(&-O;7!U=&5R#0H@("`@("H@0')E
M='5R;B!A<G)A>0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$EN<W1A;&QA
M=&EO;D9I;&5L:7-T*"1F;W)F:6QE8VAE8VL@/2!F86QS92D-"B`@("![#0H@
M("`@("`@("1C;VYT96YT<R`]("1T:&ES+3YG971&:6QE;&ES="AT<G5E*3L-
M"B`@("`@("`@:68@*&ES<V5T*"1C;VYT96YT<ULG9&ER)UU;)V%T=')I8G,G
M75LG8F%S96EN<W1A;&QD:7(G72DI('L-"B`@("`@("`@("`@("1B87-E(#T@
M)&-O;G1E;G1S6R=D:7(G75LG871T<FEB<R==6R=B87-E:6YS=&%L;&1I<B==
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA
M9V5);F9O6R=B=6YD;&4G72DI('L-"B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*`T*("`@("`@("`@("`@("`@("=%>&-E<'1I;VXZ(&)U
M;F1L97,@<VAO=6QD(&)E(&AA;F1L960@:6X@9&]W;FQO860@8V]D92!O;FQY
M)RD[#0H@("`@("`@('T-"B`@("`@("`@)')E;&5A<V4@/2`D=&AI<RT^9V5T
M4F5L96%S97,H*3L-"B`@("`@("`@:68@*"1R96QE87-E*2![#0H@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1R96QE87-E6S!=*2D@>PT*("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)')E;&5A<V5;)VEN<W1A;&QC;VYD:71I;VYS)UTI
M("8F("%I<W-E="@D<F5L96%S95LG9FEL96QI<W0G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1F;W)F:6QE8VAE8VLI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9V5T1FEL96QI<W0H*3L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)&-O;G1E;G1S.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`D<F5L96%S92`](&%R<F%Y*"1R96QE87-E*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("1D97!C:&5C:V5R(#T@)B1T:&ES+3YG971014%2
M1&5P96YD96YC>3(H)'1H:7,M/E]C;VYF:6<L(&%R<F%Y*"DL#0H@("`@("`@
M("`@("`@("`@87)R87DH)V-H86YN96PG(#T^("1T:&ES+3YG971#:&%N;F5L
M*"DL("=P86-K86=E)R`]/B`D=&AI<RT^9V5T4&%C:V%G92@I*2P-"B`@("`@
M("`@("`@("`@("!014%27U9!3$E$051%7TE.4U1!3$Q)3D<I.PT*("`@("`@
M("`@("`@9F]R96%C:"`H)')E;&5A<V4@87,@)&EN<W1A;F-E*2![#0H@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1I;G-T86YC95LG:6YS=&%L;&-O;F1I
M=&EO;G,G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)&EN<W1A;&QC;VYD
M:71I;VYS(#T@)&EN<W1A;F-E6R=I;G-T86QL8V]N9&ET:6]N<R==.PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)&EN<W1A;&QC;VYD:71I
M;VYS*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@4$5!4CHZ<'5S:$5R
M<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)&EN<W1A;&QC;VYD:71I;VYS(&%S("1T
M>7!E(#T^("1C;VYD:71I;VYS*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D8V]N9&ET:6]N<ULP72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&-O;F1I=&EO;G,@/2!A<G)A>2@D
M8V]N9&ET:6]N<RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1C;VYD:71I
M;VYS(&%S("1C;VYD:71I;VXI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)')E="`]("1D97!C:&5C:V5R+3Y[(G9A;&ED871E>R1T>7!E
M?41E<&5N9&5N8WDB?2@D8V]N9&ET:6]N*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E="DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05(Z.G!O<$5R
M<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&-O;G1I;G5E(#,[("\O('-K:7`@=&AI<R!R96QE87-E#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG
M*"D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@+R\@=&AI<R!I<R!T:&4@<F5L96%S92!T;R!U
M<V4-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&EN<W1A;F-E6R=F:6QE
M;&ES="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`O+R!I9VYO<F4@9FEL
M97,-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I;G-T86YC95LG
M9FEL96QI<W0G75LG:6=N;W)E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D:6=N;W)E(#T@:7-S970H)&EN<W1A;F-E6R=F:6QE;&ES="==6R=I
M9VYO<F4G75LP72D@/PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I
M;G-T86YC95LG9FEL96QI<W0G75LG:6=N;W)E)UT@.@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"1I;G-T86YC95LG9FEL96QI<W0G75LG
M:6=N;W)E)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)&EG;F]R92!A<R`D:6<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!U;G-E="`H)&-O;G1E;G1S6R1I9ULG871T<FEB<R==6R=N86UE)UU=*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`O+R!I;G-T86QL(&9I;&5S(&%S
M('1H:7,@;F%M90T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&EN
M<W1A;F-E6R=F:6QE;&ES="==6R=I;G-T86QL)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D:6YS=&%L;&%S(#T@:7-S970H)&EN<W1A;F-E6R=F
M:6QE;&ES="==6R=I;G-T86QL)UU;,%TI(#\-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D:6YS=&%N8V5;)V9I;&5L:7-T)UU;)VEN<W1A;&PG72`Z
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)&EN<W1A;F-E
M6R=F:6QE;&ES="==6R=I;G-T86QL)UTI.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)&EN<W1A;&QA<R!A<R`D87,I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D8V]N=&5N='-;)&%S6R=A='1R:6)S)UU;
M)VYA;64G75U;)V%T=')I8G,G75LG:6YS=&%L;"UA<R==(#T-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&%S6R=A='1R:6)S)UU;)V%S)UT[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@
M*"1F;W)F:6QE8VAE8VLI('L-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&-O;G1E;G1S(&%S("1F:6QE(#T^("1A='1R<RD@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)&-O;G1E;G1S6R1F:6QE72`]("1A='1R<ULG871T
M<FEB<R==.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B`D8V]N=&5N=',[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T@96QS92![("\O('-I;7!L92!R96QE87-E
M("T@;F\@:6YS=&%L;&-O;F1I=&EO;G,@;W(@:6YS=&%L;"UA<PT*("`@("`@
M("`@("`@:68@*"1F;W)F:6QE8VAE8VLI('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/F=E=$9I;&5L:7-T*"D[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!R971U<FX@)&-O;G1E;G1S.PT*("`@("`@("!]#0H@("`@
M("`@("\O(&YO(')E;&5A<V5S(&UA=&-H960-"B`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)TYO(')E;&5A<V5S(&EN('!A8VMA9V4N>&UL(&UA
M=&-H960@=&AE(&5X:7-T:6YG(&]P97)A=&EN9R`G("X-"B`@("`@("`@("`@
M("=S>7-T96TL(&5X=&5N<VEO;G,@:6YS=&%L;&5D+"!O<B!A<F-H:71E8W1U
M<F4L(&-A;FYO="!I;G-T86QL)RD[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@5&AI<R!I<R!O;FQY('5S960@870@:6YS=&%L;"UT:6UE+"!A9G1E<B!A
M;&P@<V5R:6%L:7IA=&EO;@T*("`@("`J(&ES(&]V97(N#0H@("`@("H@0'!A
M<F%M('-T<FEN9R!F:6QE(&YA;64-"B`@("`@*B!`<&%R86T@<W1R:6YG(&EN
M<W1A;&QE9"!P871H#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T26YS=&%L
M;&5D07,H)&9I;&4L("1P871H*0T*("`@('L-"B`@("`@("`@:68@*"1P871H
M*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG
M9FEL96QI<W0G75LD9FEL95U;)VEN<W1A;&QE9%]A<R==(#T@)'!A=&@[#0H@
M("`@("`@('T-"B`@("`@("`@=6YS970H)'1H:7,M/E]P86-K86=E26YF;ULG
M9FEL96QI<W0G75LD9FEL95U;)VEN<W1A;&QE9%]A<R==*3L-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!G971);G-T86QL961,;V-A=&EO;B@D9FEL92D-"B`@
M("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=F
M:6QE;&ES="==6R1F:6QE75LG:6YS=&%L;&5D7V%S)UTI*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG9FEL96QI<W0G75LD
M9FEL95U;)VEN<W1A;&QE9%]A<R==.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES(&ES
M(&]N;'D@=7-E9"!A="!I;G-T86QL+71I;64L(&%F=&5R(&%L;"!S97)I86QI
M>F%T:6]N#0H@("`@("H@:7,@;W9E<BX-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!I;G-T86QL961&:6QE*"1F:6QE+"`D871T<RD-"B`@("![#0H@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==6R1F
M:6QE72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V9I
M;&5L:7-T)UU;)&9I;&5=(#T-"B`@("`@("`@("`@("`@("!A<G)A>5]M97)G
M92@D=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==6R1F:6QE72P@)&%T
M='-;)V%T=')I8G,G72D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==6R1F:6QE72`]("1A
M='1S6R=A='1R:6)S)UT[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!2971R:65V92!T:&4@8V]N=&5N=',@=&%G#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@9V5T0V]N=&5N=',H*0T*("`@('L-"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UTI*2![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N
M=',G73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9R!F=6QL('!A=&@@
M=&\@9FEL90T*("`@("`J($!P87)A;2!S=')I;F<@871T<FEB=71E(&YA;64-
M"B`@("`@*B!`<&%R86T@<W1R:6YG(&%T=')I8G5T92!V86QU90T*("`@("`J
M($!P87)A;2!I;G0@<FES:WD@8G5T(&9A<W0@+2!U<V4@=&AI<R!T;R!C:&]O
M<V4@82!F:6QE(&)A<V5D(&]N(&ET<R!P;W-I=&EO;B!I;B!T:&4@;&ES=`T*
M("`@("`J("`@("`@("`@("`@;V8@9FEL97,N("!);F1E>"!I<R!Z97)O+6)A
M<V5D(&QI:V4@4$A0(&%R<F%Y<RX-"B`@("`@*B!`<F5T=7)N(&)O;VP@<W5C
M8V5S<R!O9B!O<&5R871I;VX-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971&
M:6QE071T<FEB=71E*"1F:6QE;F%M92P@)&%T='(L("1V86QU92P@)&EN9&5X
M(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P
M.PT*("`@("`@("!I9B`H:6Y?87)R87DH)&%T='(L(&%R<F%Y*"=R;VQE)RP@
M)VYA;64G+"`G8F%S96EN<W1A;&QD:7(G*2DI('L-"B`@("`@("`@("`@("1T
M:&ES+3Y?9FEL97-686QI9"`](&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("@D:6YD97@@(3T](&9A;'-E("8F#0H@("`@("`@("`@("`@(&ES<V5T
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE
M)UU;)&EN9&5X75LG871T<FEB<R==*2D@>PT*("`@("`@("`@("`@)'1H:7,M
M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G75LD:6YD
M97A=6R=A='1R:6)S)UU;)&%T=')=(#T@)'9A;'5E.PT*("`@("`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT<R==6R=D:7(G75LG9FEL92==
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@
M("`@("`@("1F:6QE<R`]("1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S
M)UU;)V1I<B==6R=F:6QE)UT[#0H@("`@("`@(&EF("@A:7-S970H)&9I;&5S
M6S!=*2D@>PT*("`@("`@("`@("`@)&9I;&5S(#T@87)R87DH)&9I;&5S*3L-
M"B`@("`@("`@("`@("1I;F0@/2!F86QS93L-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("1I;F0@/2!T<G5E.PT*("`@("`@("!]#0H@("`@("`@
M(&9O<F5A8V@@*"1F:6QE<R!A<R`D:2`]/B`D9FEL92D@>PT*("`@("`@("`@
M("`@:68@*&ES<V5T*"1F:6QE6R=A='1R:6)S)UTI*2![#0H@("`@("`@("`@
M("`@("`@:68@*"1F:6QE6R=A='1R:6)S)UU;)VYA;64G72`]/2`D9FEL96YA
M;64I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1I;F0I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E
M;G1S)UU;)V1I<B==6R=F:6QE)UU;)&E=6R=A='1R:6)S)UU;)&%T=')=(#T@
M)'9A;'5E.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N
M=',G75LG9&ER)UU;)V9I;&4G75LG871T<FEB<R==6R1A='1R72`]("1V86QU
M93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N('-E=$1I<G1R964H)'!A=&@I#0H@("`@>PT*("`@
M("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=D:7)T<F5E)UU;)'!A=&A=(#T@
M=')U93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971$:7)T<F5E*"D-"B`@
M("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=D
M:7)T<F5E)UTI("8F(&-O=6YT*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1I<G1R
M964G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=D:7)T<F5E)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(')E<V5T1&ER=')E92@I#0H@
M("`@>PT*("`@("`@("!U;G-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=D:7)T
M<F5E)UTI.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($1E=&5R;6EN97,@
M=VAE=&AE<B!T:&ES('!A8VMA9V4@8VQA:6US(&ET(&ES(&-O;7!A=&EB;&4@
M=VET:"!T:&4@=F5R<VEO;B!O9@T*("`@("`J('1H92!P86-K86=E('1H870@
M:&%S(&$@<F5C;VUM96YD960@=F5R<VEO;B!D97!E;F1E;F-Y#0H@("`@("H@
M0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C)\4$5!4E]086-K86=E1FEL95]V
M,7Q014%27T1O=VYL;V%D97)?4&%C:V%G90T*("`@("`J($!R971U<FX@8F]O
M;&5A;@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&ES0V]M<&%T:6)L92@D<&8I
M#0H@("`@>PT*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)V-O;7!A=&EB;&4G72DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)V-H86YN96PG72DI('L-"B`@("`@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("`@("`@?0T*("`@("`@("`D;64@/2`D<&8M/F=E=%9E<G-I
M;VXH*3L-"B`@("`@("`@)&-O;7!A=&EB;&4@/2`D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=C;VUP871I8FQE)UT[#0H@("`@("`@(&EF("@A:7-S970H)&-O;7!A
M=&EB;&5;,%TI*2![#0H@("`@("`@("`@("`D8V]M<&%T:6)L92`](&%R<F%Y
M*"1C;VUP871I8FQE*3L-"B`@("`@("`@?0T*("`@("`@("`D9F]U;F0@/2!F
M86QS93L-"B`@("`@("`@9F]R96%C:"`H)&-O;7!A=&EB;&4@87,@)&EN9F\I
M('L-"B`@("`@("`@("`@(&EF("AS=')T;VQO=V5R*"1I;F9O6R=N86UE)UTI
M(#T]('-T<G1O;&]W97(H)'!F+3YG971086-K86=E*"DI*2![#0H@("`@("`@
M("`@("`@("`@:68@*'-T<G1O;&]W97(H)&EN9F];)V-H86YN96PG72D@/3T@
M<W1R=&]L;W=E<B@D<&8M/F=E=$-H86YN96PH*2DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)&9O=6YD(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(&EF("@A)&9O=6YD*2![#0H@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1I
M;F9O6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1I
M;F9O6R=E>&-L=61E)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@)&EN9F];
M)V5X8VQU9&4G72`](&%R<F%Y*"1I;F9O6R=E>&-L=61E)UTI.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)&EN9F];)V5X8VQU9&4G
M72!A<R`D97AC;'5D92D@>PT*("`@("`@("`@("`@("`@(&EF("AV97)S:6]N
M7V-O;7!A<F4H)&UE+"`D97AC;'5D92P@)ST])RDI('L-"B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H=F5R<VEO;E]C
M;VUP87)E*"1M92P@)&EN9F];)VUI;B==+"`G/CTG*2`F)B!V97)S:6]N7V-O
M;7!A<F4H)&UE+"`D:6YF;ULG;6%X)UTL("<\/2<I*2![#0H@("`@("`@("`@
M("!R971U<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0')E='5R;B!A<G)A>7QF
M86QS90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$-O;7!A=&EB;&4H*0T*
M("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];
M)V-O;7!A=&EB;&4G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7W!A8VMA9V5);F9O6R=C;VUP871I8FQE)UT[#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$1E
M<&5N9&5N8VEE<R@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UTI*2![#0H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UT[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N(&ES4W5B<&%C:V%G94]F*"1P*0T*("`@('L-"B`@("`@
M("`@<F5T=7)N("1P+3YI<U-U8G!A8VMA9V4H)'1H:7,I.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("`J($1E=&5R;6EN97,@=VAE=&AE<B!T:&4@<&%S<V5D
M(&EN('!A8VMA9V4@:7,@82!S=6)P86-K86=E(&]F('1H:7,@<&%C:V%G92X-
M"B`@("`@*@T*("`@("`J($YO('9E<G-I;VX@8VAE8VMI;F<@:7,@9&]N92P@
M;VYL>2!N86UE('9E<FEF:6-A=&EO;BX-"B`@("`@*B!`<&%R86T@4$5!4E]0
M86-K86=E1FEL95]V,7Q014%27U!A8VMA9V5&:6QE7W8R#0H@("`@("H@0')E
M='5R;B!B;V]L#0H@("`@("HO#0H@("`@9G5N8W1I;VX@:7-3=6)P86-K86=E
M*"1P*0T*("`@('L-"B`@("`@("`@)'-U8B`](&%R<F%Y*"D[#0H@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I97,G
M75LG<F5Q=6ER960G75LG<W5B<&%C:V%G92==*2D@>PT*("`@("`@("`@("`@
M)'-U8B`]("1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE<R==6R=R
M97%U:7)E9"==6R=S=6)P86-K86=E)UT[#0H@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1S=6);,%TI*2![#0H@("`@("`@("`@("`@("`@)'-U8B`](&%R<F%Y
M*"1S=6(I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I97,G75LG
M;W!T:6]N86PG75LG<W5B<&%C:V%G92==*2D@>PT*("`@("`@("`@("`@)'-U
M8C$@/2`D=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I97,G75LG;W!T
M:6]N86PG75LG<W5B<&%C:V%G92==.PT*("`@("`@("`@("`@:68@*"%I<W-E
M="@D<W5B,5LP72DI('L-"B`@("`@("`@("`@("`@("`D<W5B,2`](&%R<F%Y
M*"1S=6(Q*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1S=6(@/2!A
M<G)A>5]M97)G92@D<W5B+"`D<W5B,2D[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE<R==
M6R=G<F]U<"==*2D@>PT*("`@("`@("`@("`@)&=R;W5P(#T@)'1H:7,M/E]P
M86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;)V=R;W5P)UT[#0H@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1G<F]U<%LP72DI('L-"B`@("`@("`@("`@("`@
M("`D9W)O=7`@/2!A<G)A>2@D9W)O=7`I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@9F]R96%C:"`H)&=R;W5P(&%S("1D97!S*2![#0H@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1D97!S6R=S=6)P86-K86=E)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("1S=6(R(#T@)&1E<'-;)W-U8G!A8VMA9V4G
M73L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<W5B,ELP72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1S=6(R(#T@87)R87DH)'-U
M8C(I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("1S=6(@/2!A<G)A>5]M97)G92@D<W5B+"`D<W5B,BD[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(&9O<F5A8V@@*"1S=6(@87,@)&1E<"D@>PT*("`@("`@("`@("`@:68@*'-T
M<G1O;&]W97(H)&1E<%LG;F%M92==*2`]/2!S=')T;VQO=V5R*"1P+3YG9710
M86-K86=E*"DI*2![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;
M)V-H86YN96PG72DI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*'-T<G1O
M;&]W97(H)&1E<%LG8VAA;FYE;"==*2`]/2!S=')T;VQO=V5R*"1P+3YG971#
M:&%N;F5L*"DI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@
M=')U93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@(&EF("@D9&5P6R=U<FDG
M72`]/2`D<"T^9V5T55))*"DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!D97!E;F1S
M3VXH)'!A8VMA9V4L("1C:&%N;F5L*0T*("`@('L-"B`@("`@("`@:68@*"$H
M)&1E<',@/2`D=&AI<RT^9V5T1&5P96YD96YC:65S*"DI*2![#0H@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C
M:"`H87)R87DH)W!A8VMA9V4G+"`G<W5B<&%C:V%G92<I(&%S("1T>7!E*2![
M#0H@("`@("`@("`@("!F;W)E86-H("AA<G)A>2@G<F5Q=6ER960G+"`G;W!T
M:6]N86PG*2!A<R`D;F5E9&5D*2![#0H@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1D97!S6R1N965D961=6R1T>7!E72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D9&5P<ULD;F5E9&5D75LD='EP95U;,%TI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D9&5P<ULD;F5E9&5D75LD='EP
M95T@/2!A<G)A>2@D9&5P<ULD;F5E9&5D75LD='EP95TI.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1D
M97!S6R1N965D961=6R1T>7!E72!A<R`D9&5P*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D9&5P8VAA;FYE;"`](&ES<V5T*"1D97!;)V-H86YN96PG
M72D@/R`D9&5P6R=C:&%N;F5L)UT@.B`G7U]U<FDG.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H)&1E<%LG;F%M92==*2`]/2!S
M=')T;VQO=V5R*"1P86-K86=E*2`F)@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&1E<&-H86YN96P@/3T@)&-H86YN96PI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T@(`T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@
M*&ES<V5T*"1D97!S6R=G<F]U<"==*2D@>PT*("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)&1E<'-;)V=R;W5P)UU;,%TI*2![#0H@("`@("`@("`@("`@
M("`@("`@("1D97!;)V=R;W5P)UT@/2!A<G)A>2@D9&5P<ULG9W)O=7`G72D[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1D97!S6R=G<F]U<"==(&%S("1G<F]U<"D@>PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&=R;W5P6R1T>7!E72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&=R;W5P6R1T>7!E72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9W)O=7!;)'1Y<&5=(#T@
M87)R87DH)&=R;W5P6R1T>7!E72D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D9W)O=7!;
M)'1Y<&5=(&%S("1D97`I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9&5P8VAA;FYE;"`](&ES<V5T*"1D97!;)V-H86YN96PG72D@/R`D9&5P
M6R=C:&%N;F5L)UT@.B`G7U]U<FDG.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AS=')T;VQO=V5R*"1D97!;)VYA;64G72D@/3T@<W1R=&]L
M;W=E<B@D<&%C:V%G92D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9&5P8VAA;FYE;"`]/2`D8VAA;FYE;"D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]("`-"B`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!C;VYT
M96YT<R!O9B!A(&1E<&5N9&5N8WD@9W)O=7`-"B`@("`@*B!`<&%R86T@<W1R
M:6YG#0H@("`@("H@0')E='5R;B!A<G)A>7QF86QS90T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(&=E=$1E<&5N9&5N8WE'<F]U<"@D;F%M92D-"B`@("![#0H@
M("`@("`@("1N86UE(#T@<W1R=&]L;W=E<B@D;F%M92D[#0H@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;
M)V=R;W5P)UTI*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@('T-"B`@("`@("`@)&=R;W5P<R`]("1T:&ES+3Y?<&%C:V%G94EN9F];
M)V1E<&5N9&5N8VEE<R==6R=G<F]U<"==.PT*("`@("`@("!I9B`H(6ES<V5T
M*"1G<F]U<'-;,%TI*2![#0H@("`@("`@("`@("`D9W)O=7!S(#T@87)R87DH
M)&=R;W5P<RD[#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)&=R;W5P
M<R!A<R`D9W)O=7`I('L-"B`@("`@("`@("`@(&EF("AS=')T;VQO=V5R*"1G
M<F]U<%LG871T<FEB<R==6R=N86UE)UTI(#T]("1N86UE*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N("1G<F]U<#L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@4F5T<FEE=F4@82!P87)T:6%L('!A8VMA9V4N>&UL(#$N,"!R
M97!R97-E;G1A=&EO;B!O9B!D97!E;F1E;F-I97,-"B`@("`@*@T*("`@("`J
M(&$@=F5R>2!L:6UI=&5D(')E<')E<V5N=&%T:6]N(&]F(&1E<&5N9&5N8VEE
M<R!I<R!R971U<FYE9"!B>2!T:&ES(&UE=&AO9"X-"B`@("`@*B!4:&4@/&5X
M8VQU9&4^('1A9R!F;W(@97AC;'5D:6YG(&-E<G1A:6X@=F5R<VEO;G,@;V8@
M82!D97!E;F1E;F-Y(&ES#0H@("`@("H@8V]M<&QE=&5L>2!I9VYO<F5D+B`@
M26X@861D:71I;VXL(&1E<&5N9&5N8WD@9W)O=7!S(&%R92!I9VYO<F5D+"!W
M:71H('1H90T*("`@("`J(&%S<W5M<'1I;VX@=&AA="!A;&P@9&5P96YD96YC
M:65S(&EN(&1E<&5N9&5N8WD@9W)O=7!S(&%R92!A;'-O(&QI<W1E9"!I;@T*
M("`@("`J('1H92!O<'1I;VYA;"!G<F]U<"!T:&%T('=O<FL@=VET:"!A;&P@
M9&5P96YD96YC>2!G<F]U<',-"B`@("`@*B!`<&%R86T@8F]O;&5A;B!R971U
M<FX@<&%C:V%G92YX;6P@,BXP(#QD97!E;F1E;F-I97,^('1A9PT*("`@("`J
M($!R971U<FX@87)R87E\9F%L<V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G
M971$97!S*"1R87<@/2!F86QS92P@)&YO<&5A<FEN<W1A;&QE<B`](&9A;'-E
M*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)V1E<&5N9&5N8VEE<R==*2D@>PT*("`@("`@("`@("`@:68@*"1R87<I
M('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF
M;ULG9&5P96YD96YC:65S)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`D<F5T(#T@87)R87DH*3L-"B`@("`@("`@("`@("1M87`@/2!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`G<&AP)R`]/B`G<&AP)RP-"B`@("`@("`@("`@
M("`@("`G<&%C:V%G92<@/3X@)W!K9R<L#0H@("`@("`@("`@("`@("`@)W-U
M8G!A8VMA9V4G(#T^("=P:V<G+`T*("`@("`@("`@("`@("`@("=E>'1E;G-I
M;VXG(#T^("=E>'0G+`T*("`@("`@("`@("`@("`@("=O<R<@/3X@)V]S)RP-
M"B`@("`@("`@("`@("`@("`G<&5A<FEN<W1A;&QE<B<@/3X@)W!K9R<L#0H@
M("`@("`@("`@("`@("`@*3L-"B`@("`@("`@("`@(&9O<F5A8V@@*&%R<F%Y
M*"=R97%U:7)E9"<L("=O<'1I;VYA;"<I(&%S("1T>7!E*2![#0H@("`@("`@
M("`@("`@("`@)&]P=&EO;F%L(#T@*"1T>7!E(#T]("=O<'1I;VYA;"<I(#\@
M)WEE<R<@.B`G;F\G.PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;)'1Y<&5=*2D@>PT*
M("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P86-K86=E
M26YF;ULG9&5P96YD96YC:65S)UU;)'1Y<&5=(&%S("1D='EP92`]/B`D9&5P
M<RD@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)&1T>7!E(#T]("=P96%R
M:6YS=&%L;&5R)R`F)B`D;F]P96%R:6YS=&%L;&5R*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!S6S!=*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&1E<',@/2!A<G)A>2@D9&5P
M<RD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)&1E<',@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D;6%P6R1D='EP95TI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@;F\@<W5P<&]R="!F;W(@87)C:"!T
M>7!E#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H)&1T>7!E(#T]("=P96%R:6YS=&%L;&5R)RD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1D97!;)VYA;64G72`]("=014%2)SL-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P6R=C:&%N;F5L)UT@
M/2`G<&5A<BYP:'`N;F5T)SL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1S(#T@87)R87DH)W1Y<&4G(#T^
M("1M87!;)&1T>7!E72D[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&1E<%LG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1S6R=C:&%N;F5L)UT@/2`D9&5P6R=C:&%N;F5L)UT[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&1E<%LG=7)I)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'-;)W5R:2==(#T@)&1E<%LG=7)I)UT[#0H@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&1E<%LG;F%M92==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1S6R=N86UE)UT@/2`D9&5P6R=N86UE)UT[#0H@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&1E<%LG8V]N9FQI8W1S)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'-;)W)E;"==(#T@)VYO="<[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)&1E<%LG;6EN)UTI("8F#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(6ES<V5T*"1D97!;)VUA>"==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<ULG<F5L
M)UT@/2`G:&%S)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'-;)V]P=&EO;F%L)UT@/2`D;W!T:6]N86P[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1D97!;)VUI;B==*2`F)@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1D97!;
M)VUA>"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<ULG<F5L)UT@/2`G9V4G.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<S$@/2`D<SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)',Q6R=R96PG72`]("=L92<[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1S6R=V97)S:6]N)UT@/2`D9&5P6R=M:6XG73L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)',Q6R=V97)S:6]N)UT@/2`D
M9&5P6R=M87@G73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1D97!;)V-H86YN96PG72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1S,5LG8VAA;FYE;"==(#T@)&1E<%LG
M8VAA;FYE;"==.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D9'1Y<&4@
M(3T@)W!H<"<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1S6R=N86UE)UT@/2`D9&5P6R=N86UE)UT[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<S%;)VYA;64G72`]("1D97!;)VYA
M;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<ULG;W!T:6]N86PG72`]
M("1O<'1I;VYA;#L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)',Q6R=O<'1I;VYA;"==(#T@)&]P=&EO;F%L.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<F5T6UT@/2`D<S$[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1D97!;)VUI;B==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)&1E<%LG97AC;'5D92==*2`F)@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&5P6R=E>&-L=61E)UT@/3T@)&1E<%LG;6EN)UTI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S6R=R
M96PG72`]("=G="<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<ULG<F5L)UT@/2`G9V4G.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S
M6R=V97)S:6]N)UT@/2`D9&5P6R=M:6XG73L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'-;)V]P=&EO;F%L)UT@/2`D;W!T:6]N86P[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D9'1Y<&4@(3T@
M)W!H<"<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1S6R=N86UE)UT@/2`D9&5P6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H:7-S970H)&1E<%LG;6%X)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=E>&-L=61E
M)UTI("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D97!;)V5X8VQU9&4G72`]/2`D9&5P6R=M87@G72D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-;)W)E;"==(#T@)VQT)SL-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S6R=R96PG72`]
M("=L92<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-;)W9E<G-I;VXG72`]
M("1D97!;)VUA>"==.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<ULG;W!T:6]N86PG72`]("1O<'1I;VYA;#L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"1D='EP92`A/2`G<&AP)RD@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-;)VYA;64G72`]
M("1D97!;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1R
M971;72`]("1S.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&-O=6YT
M*"1R970I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1R970[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@('T-"@T*("`@("\J*@T*("`@("`J($!R971U<FX@<&AP?&5X='-R8WQE
M>'1B:6Y\8G5N9&QE?&9A;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T
M4&%C:V%G951Y<&4H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)W!H<')E;&5A<V4G72DI('L-"B`@("`@("`@("`@
M(')E='5R;B`G<&AP)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG97AT<W)C<F5L96%S92==*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("=E>'1S<F,G.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=E>'1B:6YR96QE87-E
M)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)V5X=&)I;B<[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V)U
M;F1L92==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("=B=6YD;&4G.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!`<F5T=7)N(&%R<F%Y?&9A;'-E#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@9V5T4F5L96%S97,H*0T*("`@('L-"B`@("`@("`@)'1Y<&4@
M/2`D=&AI<RT^9V5T4&%C:V%G951Y<&4H*3L-"B`@("`@("`@:68@*"1T>7!E
M("$]("=B=6YD;&4G*2![#0H@("`@("`@("`@("`D='EP92`N/2`G<F5L96%S
M92<[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES+3YG971086-K86=E
M5'EP92@I("8F(&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)'1Y<&5=*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)'1Y
M<&5=.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@9V5T0VAA;F=E;&]G*"D-"B`@("![#0H@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N9V5L;V<G72DI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N
M9V5L;V<G73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@:&%S1&5P<R@I#0H@("`@>PT*("`@("`@
M("!R971U<FX@:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC
M:65S)UTI.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=%!A8VMA9V5X;6Q6
M97)S:6]N*"D-"B`@("![#0H@("`@("`@(')E='5R;B`G,BXP)SL-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N(&%R<F%Y?&9A;'-E#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@9V5T4V]U<F-E4&%C:V%G92@I#0H@("`@>PT*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG97AT8FEN
M<F5L96%S92==*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"=C:&%N
M;F5L)R`]/B`D=&AI<RT^7W!A8VMA9V5);F9O6R=S<F-C:&%N;F5L)UTL#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@)W!A8VMA9V4G(#T^("1T:&ES+3Y?
M<&%C:V%G94EN9F];)W-R8W!A8VMA9V4G72D[#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$)U
M;F1L961086-K86=E<R@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]P86-K86=E26YF;ULG8G5N9&QE)UTI*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG8G5N9&QE
M9'!A8VMA9V4G73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T3&%S=$UO9&EF:65D*"D-"B`@
M("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=?
M;&%S=&UO9&EF:65D)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]P86-K86=E26YF;ULG7VQA<W1M;V1I9FEE9"==.PT*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!'970@=&AE(&-O;G1E;G1S(&]F(&$@9FEL92!L:7-T960@=VET:&EN('1H
M92!P86-K86=E+GAM;`T*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B!`
M<F5T=7)N('-T<FEN9PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$9I;&5#
M;VYT96YT<R@D9FEL92D-"B`@("![#0H@("`@("`@(&EF("@D=&AI<RT^7V%R
M8VAI=F5&:6QE(#T]("1T:&ES+3Y?<&%C:V%G949I;&4I('L@+R\@=6YP86-K
M960-"B`@("`@("`@("`@("1D:7(@/2!D:7)N86UE*"1T:&ES+3Y?<&%C:V%G
M949I;&4I.PT*("`@("`@("`@("`@)&9I;&4@/2`D9&ER("X@1$E214-43U)9
M7U-%4$%2051/4B`N("1F:6QE.PT*("`@("`@("`@("`@)&9I;&4@/2!S=')?
M<F5P;&%C92AA<G)A>2@G+R<L("=<7"<I+`T*("`@("`@("`@("`@("`@(&%R
M<F%Y*$1)4D5#5$]265]315!!4D%43U(L($1)4D5#5$]265]315!!4D%43U(I
M+"`D9FEL92D[#0H@("`@("`@("`@("!I9B`H9FEL95]E>&ES=',H)&9I;&4I
M("8F(&ES7W)E861A8FQE*"1F:6QE*2D@>PT*("`@("`@("`@("`@("`@(')E
M='5R;B!I;7!L;V1E*"<G+"!F:6QE*"1F:6QE*2D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T@96QS92![("\O('1G>@T*("`@("`@("`@("`@)'1A<B`]
M("9N97<@07)C:&EV95]487(H)'1H:7,M/E]A<F-H:79E1FEL92D[#0H@("`@
M("`@("`@("`D=&%R+3YP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%
M5%523BD[#0H@("`@("`@("`@("!I9B`H)&9I;&4@(3T@)W!A8VMA9V4N>&UL
M)R`F)B`D9FEL92`A/2`G<&%C:V%G93(N>&UL)RD@>PT*("`@("`@("`@("`@
M("`@("1F:6QE(#T@)'1H:7,M/F=E=%!A8VMA9V4H*2`N("<M)R`N("1T:&ES
M+3YG971697)S:6]N*"D@+B`G+R<@+B`D9FEL93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1F:6QE(#T@)'1A<BT^97AT<F%C=$EN4W1R:6YG*"1F
M:6QE*3L-"B`@("`@("`@("`@("1T87(M/G!O<$5R<F]R2&%N9&QI;F<H*3L-
M"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1F:6QE*2D@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#86YN;W0@
M;&]C871E(&9I;&4@)R1F:6QE)R!I;B!A<F-H:79E(BD[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!R971U<FX@)&9I;&4[#0H@("`@("`@('T-"B`@
M("!]#0H-"B`@("!F=6YC=&EO;B`F9V5T4E<H*0T*("`@('L-"B`@("`@("`@
M:68@*"%C;&%S<U]E>&ES=',H)U!%05)?4&%C:V%G949I;&5?=C)?<G<G*2D@
M>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+U!A8VMA9V5&:6QE
M+W8R+W)W+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@)&$@/2!N97<@4$5!
M4E]086-K86=E1FEL95]V,E]R=SL-"B`@("`@("`@9F]R96%C:"`H9V5T7V]B
M:F5C=%]V87)S*"1T:&ES*2!A<R`D;F%M92`]/B`D=6YU<V5D*2![#0H@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3XD;F%M92DI('L-"B`@("`@("`@
M("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&EF("@D;F%M92`]/2`G7V-O;F9I9R<@?'P@)&YA;64@/3T@)U]L;V=G97(G
M?'P@)&YA;64@/3T@)U]R96=I<W1R>2<@?'P-"B`@("`@("`@("`@("`@("`@
M("1N86UE(#T]("=?<W1A8VLG*2![#0H@("`@("`@("`@("`@("`@)&$M/B1N
M86UE(#T@)B1T:&ES+3XD;F%M93L-"B`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@)&$M/B1N86UE(#T@)'1H:7,M/B1N86UE.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D83L-"B`@
M("!]#0H-"B`@("!F=6YC=&EO;B`F9V5T1&5F875L=$=E;F5R871O<B@I#0H@
M("`@>PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]086-K86=E
M1FEL95]'96YE<F%T;W)?=C(G*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E("=014%2+U!A8VMA9V5&:6QE+T=E;F5R871O<B]V,BYP:'`G.PT*("`@
M("`@("!]#0H@("`@("`@("1A(#T@)FYE=R!014%27U!A8VMA9V5&:6QE7T=E
M;F5R871O<E]V,B@D=&AI<RD[#0H@("`@("`@(')E='5R;B`D83L-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!A;F%L>7IE4V]U<F-E0V]D92@D9FEL92P@)'-T
M<FEN9R`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7W8R5F%L:61A=&]R*2!\?`T*("`@("`@("`@("`@("`A:7-?82@D=&AI
M<RT^7W8R5F%L:61A=&]R+"`G4$5!4E]086-K86=E1FEL95]V,E]686QI9&%T
M;W(G*2D@>PT*("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?
M4&%C:V%G949I;&5?=C)?5F%L:61A=&]R)RDI('L-"B`@("`@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G949I;&4O=C(O5F%L:61A=&]R
M+G!H<"<[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^7W8R
M5F%L:61A=&]R(#T@;F5W(%!%05)?4&%C:V%G949I;&5?=C)?5F%L:61A=&]R
M.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D=&AI<RT^7W8R5F%L:61A
M=&]R+3YA;F%L>7IE4V]U<F-E0V]D92@D9FEL92P@)'-T<FEN9RD[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@=F%L:61A=&4H)'-T871E(#T@4$5!4E]604Q)
M1$%415].3U)-04PI#0H@("`@>PT*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?<&%C:V%G94EN9F\I('Q\("%I<U]A<G)A>2@D=&AI<RT^7W!A8VMA9V5)
M;F9O*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]V,E9A;&ED871O<BD@?'P-
M"B`@("`@("`@("`@("`@(6ES7V$H)'1H:7,M/E]V,E9A;&ED871O<BP@)U!%
M05)?4&%C:V%G949I;&5?=C)?5F%L:61A=&]R)RDI('L-"B`@("`@("`@("`@
M(&EF("@A8VQA<W-?97AI<W1S*"=014%27U!A8VMA9V5&:6QE7W8R7U9A;&ED
M871O<B<I*2![#0H@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2
M+U!A8VMA9V5&:6QE+W8R+U9A;&ED871O<BYP:'`G.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@)'1H:7,M/E]V,E9A;&ED871O<B`](&YE=R!014%2
M7U!A8VMA9V5&:6QE7W8R7U9A;&ED871O<CL-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG>'-D=F5R<VEO;B==
M*2D@>PT*("`@("`@("`@("`@=6YS970H)'1H:7,M/E]P86-K86=E26YF;ULG
M>'-D=F5R<VEO;B==*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1H
M:7,M/E]V,E9A;&ED871O<BT^=F%L:61A=&4H)'1H:7,L("1S=&%T92D[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T5&%S:W-.<R@I#0H@("`@>PT*("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?=&%S:W-.<RDI('L-"B`@("`@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=A='1R:6)S)UTI
M*2![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P86-K86=E
M26YF;ULG871T<FEB<R==(&%S("1N86UE(#T^("1V86QU92D@>PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H)'9A;'5E(#T]("=H='1P.B\O<&5A<BYP:'`N
M;F5T+V1T9"]T87-K<RTQ+C`G*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W1A<VMS3G,@/2!S=')?<F5P;&%C92@G>&UL;G,Z)RP@)R<L
M("1N86UE*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D=&AI<RT^7W1A
M<VMS3G,[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@1&5T97)M:6YE('=H
M971H97(@82!T87-K(&YA;64@:7,@82!V86QI9"!T87-K+B`@0W5S=&]M('1A
M<VMS(&UA>2!B92!D969I;F5D#0H@("`@("H@=7-I;F<@<W5B9&ER96-T;W)I
M97,@8GD@<'5T=&EN9R!A("(M(B!I;B!T:&4@;F%M92P@87,@:6X@/'1A<VMS
M.FUY8W5S=&]M+71A<VL^#0H@("`@("H-"B`@("`@*B!.;W1E('1H870@=&AI
M<R!M971H;V0@=VEL;"!A=71O+6QO860@=&AE('1A<VL@8VQA<W,@9FEL92!A
M;F0@=&5S="!F;W(@=&AE(&5X:7-T96YC90T*("`@("`J(&]F('1H92!N86UE
M('=I=&@@(BTB(')E<&QA8V5D(&)Y(")?(B!A<R!I;B!014%2+U1A<VLO;7EC
M=7-T;VTO=&%S:RYP:'`@;6%K97,@8VQA<W,-"B`@("`@*B!014%27U1A<VM?
M;7EC=7-T;VU?=&%S:PT*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971487-K
M*"1T87-K*0T*("`@('L-"B`@("`@("`@)'1H:7,M/F=E=%1A<VMS3G,H*3L-
M"B`@("`@("`@+R\@=')A;G-F;W)M(&%L;"`G+2<@=&\@)R\G(&%N9"`G=&%S
M:W,Z)R!T;R`G)R!S;R!T87-K<SIR97!L86-E(&)E8V]M97,@<F5P;&%C90T*
M("`@("`@("`D=&%S:R`]('-T<E]R97!L86-E*&%R<F%Y*"1T:&ES+3Y?=&%S
M:W-.<R`N("<Z)RP@)RTG*2P@87)R87DH)R<L("<@)RDL("1T87-K*3L-"B`@
M("`@("`@)'1A<VL@/2!S=')?<F5P;&%C92@G("<L("<O)RP@=6-W;W)D<R@D
M=&%S:RDI.PT*("`@("`@("`D<',@/2`H<W1R=&]L;W=E<BAS=6)S='(H4$A0
M7T]3+"`P+"`S*2D@/3T@)W=I;B<I(#\@)SLG(#H@)SHG.PT*("`@("`@("!F
M;W)E86-H("AE>'!L;V1E*"1P<RP@:6YI7V=E="@G:6YC;'5D95]P871H)RDI
M(&%S("1P871H*2![#0H@("`@("`@("`@("!I9B`H9FEL95]E>&ES=',H)'!A
M=&@@+B`B+U!%05(O5&%S:R\D=&%S:RYP:'`B*2D@>PT*("`@("`@("`@("`@
M("`@(&EN8VQU9&5?;VYC92`B4$5!4B]487-K+R1T87-K+G!H<"([#0H@("`@
M("`@("`@("`@("`@)'1A<VL@/2!S=')?<F5P;&%C92@G+R<L("=?)RP@)'1A
M<VLI.PT*("`@("`@("`@("`@("`@(&EF("AC;&%S<U]E>&ES=',H(E!%05)?
M5&%S:U\D=&%S:R(I*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`B
M4$5!4E]487-K7R1T87-K(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J($ME>2UF<FEE;F1L>2!A<G)A>5]S<&QI
M8V4-"B`@("`@*B!`<&%R86T@=&%G;F%M92!T;R!S<&QI8V4@82!V86QU92!I
M;B!B969O<F4-"B`@("`@*B!`<&%R86T@;6EX960@=&AE('9A;'5E('1O('-P
M;&EC92!I;@T*("`@("`J($!P87)A;2!S=')I;F<@=&AE(&YE=R!T86<@;F%M
M90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]K<W!L:6-E*"1A<G)A>2P@)&ME
M>2P@)'9A;'5E+"`D;F5W:V5Y*0T*("`@('L-"B`@("`@("`@)&]F9G-E="`]
M(&%R<F%Y7W-E87)C:"@D:V5Y+"!A<G)A>5]K97ES*"1A<G)A>2DI.PT*("`@
M("`@("`D869T97(@/2!A<G)A>5]S;&EC92@D87)R87DL("1O9F9S970I.PT*
M("`@("`@("`D8F5F;W)E(#T@87)R87E?<VQI8V4H)&%R<F%Y+"`P+"`D;V9F
M<V5T*3L-"B`@("`@("`@)&)E9F]R95LD;F5W:V5Y72`]("1V86QU93L-"B`@
M("`@("`@<F5T=7)N(&%R<F%Y7VUE<F=E*"1B969O<F4L("1A9G1E<BD[#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&%R<F%Y(&$@;&ES="!O
M9B!P;W-S:6)L92!K97ES+"!I;B!T:&4@;W)D97(@=&AE>2!M87D@;V-C=7(-
M"B`@("`@*B!`<&%R86T@;6EX960@8V]N=&5N=',@;V8@=&AE(&YE=R!P86-K
M86=E+GAM;"!T86<-"B`@("`@*B!`<&%R86T@<W1R:6YG('1A9R!N86UE#0H@
M("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M7VEN<V5R=$)E9F]R92@D87)R87DL("1K97ES+"`D8V]N=&5N=',L("1N97=K
M97DI#0H@("`@>PT*("`@("`@("!F;W)E86-H("@D:V5Y<R!A<R`D:V5Y*2![
M#0H@("`@("`@("`@("!I9B`H:7-S970H)&%R<F%Y6R1K97E=*2D@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B`D87)R87D@/2`D=&AI<RT^7VMS<&QI8V4H
M)&%R<F%Y+"`D:V5Y+"`D8V]N=&5N=',L("1N97=K97DI.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@("1A<G)A>5LD;F5W:V5Y72`]("1C
M;VYT96YT<SL-"B`@("`@("`@<F5T=7)N("1A<G)A>3L-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!`<&%R86T@<W5B<V5C=&EO;B!O9B![0&QI;FL@)%]P
M86-K86=E26YF;WT-"B`@("`@*B!`<&%R86T@87)R87E\<W1R:6YG('1A9R!C
M;VYT96YT<PT*("`@("`J($!P87)A;2!A<G)A>2!F;W)M870Z#0H@("`@("H@
M/'!R93X-"B`@("`@*B!A<G)A>2@-"B`@("`@*B`@('1A9VYA;64@/3X@87)R
M87DH;&ES="!O9B!T86<@;F%M97,@=&AA="!F;VQL;W<@=&AI<R!O;F4I+`T*
M("`@("`J("`@8VAI;&1T86=N86UE(#T^(&%R<F%Y*&QI<W0@;V8@8VAI;&0@
M=&%G(&YA;65S('1H870@9F]L;&]W('1H:7,@;VYE*2P-"B`@("`@*B`I#0H@
M("`@("H@/"]P<F4^#0H@("`@("H-"B`@("`@*B!4:&ES(&%L;&]W<R!C;VYS
M=')U8W1I;VX@;V8@;F5S=&5D('1A9W,-"B`@("`@*B!`86-C97-S('!R:79A
M=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?;65R9V5486<H)&UA;FEP+"`D
M8V]N=&5N=',L("1O<F1E<BD-"B`@("![#0H@("`@("`@(&EF("AC;W5N="@D
M;W)D97(I*2![#0H@("`@("`@("`@("!F;W)E86-H("@D;W)D97(@87,@)'1A
M9R`]/B`D8W5R;W)D97(I('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1M86YI<%LD=&%G72DI('L-"B`@("`@("`@("`@("`@("`@("`@+R\@96YS
M=7)E('1H870@=&AE('1A9R!I<R!S970@=7`-"B`@("`@("`@("`@("`@("`@
M("`@)&UA;FEP(#T@)'1H:7,M/E]I;G-E<G1"969O<F4H)&UA;FEP+"`D8W5R
M;W)D97(L(&%R<F%Y*"DL("1T86<I.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!I9B`H8V]U;G0H)&]R9&5R*2`^(#$I('L-"B`@("`@
M("`@("`@("`@("`@("`@)&UA;FEP6R1T86==(#T@)'1H:7,M/E]M97)G951A
M9R@D;6%N:7!;)'1A9UTL("1C;VYT96YT<RP@87)R87E?<VQI8V4H)&]R9&5R
M+"`Q*2D[#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D;6%N:7`[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@<F5T=7)N("1M86YI<#L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H:7-?87)R87DH)&UA;FEP6R1T86==*2`F)B`A96UP='DH
M)&UA;FEP6R1T86==*2`F)B!I<W-E="@D;6%N:7!;)'1A9UU;,%TI*2![#0H@
M("`@("`@("`@("`D;6%N:7!;)'1A9UU;72`]("1C;VYT96YT<SL-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@(&EF("@A8V]U;G0H)&UA;FEP6R1T
M86==*2D@>PT*("`@("`@("`@("`@("`@("1M86YI<%LD=&%G72`]("1C;VYT
M96YT<SL-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M)&UA;FEP6R1T86==(#T@87)R87DH)&UA;FEP6R1T86==*3L-"B`@("`@("`@
M("`@("`@("`D;6%N:7!;)'1A9UU;72`]("1C;VYT96YT<SL-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&UA;FEP.PT*("`@
M('T-"GT-"C\^#0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%
M05(O4&%C:V%G949I;&4N<&AP````````````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#,V-3<Q`#$P-3$U-#,S-S0Q`#`R,C(Q,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`T*+RHJ#0H@*B!0
M14%27U!A8VMA9V5&:6QE+"!P86-K86=E+GAM;"!P87)S:6YG('5T:6QI='D@
M8VQA<W,-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)
M0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N
M(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@
M55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@
M($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0
M($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@
M=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-
M"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2
M#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^
M#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@
M4&%C:V%G949I;&4N<&AP+'8@,2XS,R`R,#`V+S`R+S`Y(#(R.C,Y.C,R(&-E
M;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE
M('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0H-"B\J*@T*("H@;F5E9&5D
M(&9O<B!014%27U9!3$E$051%7RH@8V]N<W1A;G1S#0H@*B\-"G)E<75I<F5?
M;VYC92`G4$5!4B]686QI9&%T92YP:'`G.PT*+RHJ#0H@*B!%<G)O<B!C;V1E
M(&EF('1H92!P86-K86=E+GAM;"`\<&%C:V%G93X@=&%G(&1O97,@;F]T(&-O
M;G1A:6X@82!V86QI9"!V97)S:6]N#0H@*B\-"F1E9FEN92@G4$5!4E]004-+
M04=%1DE,15]%4E)/4E].3U]004-+04=%5D524TE/3B<L(#$I.PT*+RHJ#0H@
M*B!%<G)O<B!C;V1E(&EF('1H92!P86-K86=E+GAM;"`\<&%C:V%G93X@=&%G
M('9E<G-I;VX@:7,@;F]T('-U<'!O<G1E9"`H=F5R<VEO;B`Q+C`@86YD(#$N
M,2!A<F4@=&AE(&]N;'D@<W5P<&]R=&5D('9E<G-I;VYS+`T*("H@8W5R<F5N
M=&QY#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E])3E9!
M3$E$7U!!0TM!1T5615)324].)RP@,BD[#0HO*BH-"B`J($%B<W1R86-T:6]N
M(&9O<B!T:&4@<&%C:V%G92YX;6P@<&%C:V%G92!D97-C<FEP=&EO;B!F:6QE
M#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!
M4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T
M/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J
M($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@
M,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN
M8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S(%!%05)?4&%C:V%G949I
M;&4-"GL-"B`@("`O*BH-"B`@("`@*B!`=F%R(%!%05)?0V]N9FEG#0H@("`@
M("HO#0H@("`@=F%R("1?8V]N9FEG.PT*("`@('9A<B`D7V1E8G5G.PT*("`@
M("\J*@T*("`@("`J(%1E;7`@9&ER96-T;W)Y(&9O<B!U;F-O;7!R97-S:6YG
M('1G>B!F:6QE<RX-"B`@("`@*B!`=F%R('-T<FEN9WQF86QS90T*("`@("`J
M+PT*("`@('9A<B`D7W1M<&1I<CL-"B`@("!V87(@)%]L;V=G97(@/2!F86QS
M93L-"B`@("`O*BH-"B`@("`@*B!`=F%R(&)O;VQE86X-"B`@("`@*B\-"B`@
M("!V87(@)%]R87=2971U<FX@/2!F86QS93L-"@T*("`@("\J*@T*("`@("`J
M#0H@("`@("H@0'!A<F%M("`@4$5!4E]#;VYF:6<@)&-O;F9I9PT*("`@("`J
M($!P87)A;2`@(#\@("`D9&5B=6<-"B`@("`@*B!`<&%R86T@("!S=')I;F<@
M0'1M<&1I<B!/<'1I;VYA;"!T96UP;W)A<GD@9&ER96-T;W)Y(&9O<B!U;F-O
M;7!R97-S:6YG#0H@("`@("H@("`@("`@("`@9FEL97,-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!014%27U!A8VMA9V5&:6QE*"8D8V]N9FEG+"`D9&5B=6<@
M/2!F86QS92P@)'1M<&1I<B`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)'1H
M:7,M/E]C;VYF:6<@/2`D8V]N9FEG.PT*("`@("`@("`D=&AI<RT^7V1E8G5G
M(#T@)&1E8G5G.PT*("`@("`@("`D=&AI<RT^7W1M<&1I<B`]("1T;7!D:7([
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@5'5R;B!O9F8@=F%L:61A=&EO
M;B`M(')E='5R;B!A('!A<G-E9"!P86-K86=E+GAM;"!W:71H;W5T(&-H96-K
M:6YG(&ET#0H@("`@("H-"B`@("`@*B!4:&ES(&ES('5S960@8GD@=&AE('!A
M8VMA9V4M=F%L:61A=&4@8V]M;6%N9`T*("`@("`J+PT*("`@(&9U;F-T:6]N
M(')A=U)E='5R;B@I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W)A=U)E='5R
M;B`]('1R=64[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T3&]G9V5R*"8D
M;"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?;&]G9V5R(#T@)B1L.PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J($-R96%T92!A(%!%05)?4&%C:V%G949I
M;&5?4&%R<V5R7W8J(&]F(&$@9VEV96X@=F5R<VEO;BX-"B`@("`@*B!`<&%R
M86T@("!I;G0@)'9E<G-I;VX-"B`@("`@*B!`<F5T=7)N("!014%27U!A8VMA
M9V5&:6QE7U!A<G-E<E]V,7Q014%27U!A8VMA9V5&:6QE7U!A<G-E<E]V,0T*
M("`@("`J+PT*("`@(&9U;F-T:6]N("9P87)S97)&86-T;W)Y*"1V97)S:6]N
M*0T*("`@('L-"B`@("`@("`@:68@*"%I;E]A<G)A>2@D=F5R<VEO;GLP?2P@
M87)R87DH)S$G+"`G,B<I*2D@>PT*("`@("`@("`@("`@)&$@/2!F86QS93L-
M"B`@("`@("`@("`@(')E='5R;B`D83L-"B`@("`@("`@?0T*("`@("`@("!I
M;F-L=61E7V]N8V4@)U!%05(O4&%C:V%G949I;&4O4&%R<V5R+W8G("X@)'9E
M<G-I;VY[,'T@+B`G+G!H<"<[#0H@("`@("`@("1V97)S:6]N(#T@)'9E<G-I
M;VY[,'T[#0H@("`@("`@("1C;&%S<R`](")014%27U!A8VMA9V5&:6QE7U!A
M<G-E<E]V)'9E<G-I;VXB.PT*("`@("`@("`D82`](&YE=R`D8VQA<W,[#0H@
M("`@("`@(')E='5R;B`D83L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!&
M;W(@<VEM<&QE<B!U;FET+71E<W1I;F<-"B`@("`@*B!`<F5T=7)N('-T<FEN
M9PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$-L87-S4')E9FEX*"D-"B`@
M("![#0H@("`@("`@(')E='5R;B`G4$5!4E]086-K86=E1FEL95]V)SL-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!#<F5A=&4@82!014%27U!A8VMA9V5&
M:6QE7W8J(&]F(&$@9VEV96X@=F5R<VEO;BX-"B`@("`@*B!`<&%R86T@("!I
M;G0@)'9E<G-I;VX-"B`@("`@*B!`<F5T=7)N("!014%27U!A8VMA9V5&:6QE
M7W8Q?%!%05)?4&%C:V%G949I;&5?=C$-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B`F9F%C=&]R>2@D=F5R<VEO;BD-"B`@("![#0H@("`@("`@(&EF("@A:6Y?
M87)R87DH)'9E<G-I;VY[,'TL(&%R<F%Y*"<Q)RP@)S(G*2DI('L-"B`@("`@
M("`@("`@("1A(#T@9F%L<V4[#0H@("`@("`@("`@("!R971U<FX@)&$[#0H@
M("`@("`@('T-"B`@("`@("`@:6YC;'5D95]O;F-E("=014%2+U!A8VMA9V5&
M:6QE+W8G("X@)'9E<G-I;VY[,'T@+B`G+G!H<"<[#0H@("`@("`@("1V97)S
M:6]N(#T@)'9E<G-I;VY[,'T[#0H@("`@("`@("1C;&%S<R`]("1T:&ES+3YG
M971#;&%S<U!R969I>"@I("X@)'9E<G-I;VX[#0H@("`@("`@("1A(#T@;F5W
M("1C;&%S<SL-"B`@("`@("`@<F5T=7)N("1A.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J($-R96%T92!A(%!%05)?4&%C:V%G949I;&5?=BH@9G)O;2!I
M=',@=&]!<G)A>2@I(&UE=&AO9`T*("`@("`J#0H@("`@("H@5T%23DE.1SH@
M;F\@=F%L:61A=&EO;B!I<R!P97)F;W)M960L('1H92!A<G)A>2!I<R!A<W-U
M;65D('1O(&)E('9A;&ED+`T*("`@("`J(&%L=V%Y<R!P87)S92!F<F]M('AM
M;"!I9B!Y;W4@=V%N="!V86QI9&%T:6]N+@T*("`@("`J($!P87)A;2`@(&%R
M<F%Y("1A<G(-"B`@("`@*B!`<F5T=7)N(%!%05)?4&%C:V%G949I;&5-86YA
M9V5R7W8Q?%!%05)?4&%C:V%G949I;&5-86YA9V5R7W8R#0H@("`@("H@0'5S
M97,@("`@9F%C=&]R>2@I('1O(&-O;G-T<G5C="!T:&4@<F5T=7)N960@;V)J
M96-T+@T*("`@("`J+PT*("`@(&9U;F-T:6]N("9F<F]M07)R87DH)&%R<BD-
M"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D87)R6R=X<V1V97)S:6]N)UTI
M*2![#0H@("`@("`@("`@("`D;V)J(#T@)B1T:&ES+3YF86-T;W)Y*"1A<G);
M)WAS9'9E<G-I;VXG72D[#0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]L;V=G
M97(I('L-"B`@("`@("`@("`@("`@("`D;V)J+3YS971,;V=G97(H)'1H:7,M
M/E]L;V=G97(I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&]B:BT^
M<V5T0V]N9FEG*"1T:&ES+3Y?8V]N9FEG*3L-"B`@("`@("`@("`@("1O8FHM
M/F9R;VU!<G)A>2@D87)R*3L-"B`@("`@("`@("`@(')E='5R;B`D;V)J.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1A<G);
M)W!A8VMA9V4G75LG871T<FEB<R==6R=V97)S:6]N)UTI*2![#0H@("`@("`@
M("`@("`@("`@)&]B:B`]("8D=&AI<RT^9F%C=&]R>2@D87)R6R=P86-K86=E
M)UU;)V%T=')I8G,G75LG=F5R<VEO;B==*3L-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@)&]B:B`]("8D=&AI<RT^9F%C=&]R>2@G
M,2XP)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)'1H:7,M
M/E]L;V=G97(I('L-"B`@("`@("`@("`@("`@("`D;V)J+3YS971,;V=G97(H
M)'1H:7,M/E]L;V=G97(I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M)&]B:BT^<V5T0V]N9FEG*"1T:&ES+3Y?8V]N9FEG*3L-"B`@("`@("`@("`@
M("1O8FHM/F9R;VU!<G)A>2@D87)R*3L-"B`@("`@("`@("`@(')E='5R;B`D
M;V)J.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0W)E
M871E(&$@4$5!4E]086-K86=E1FEL95]V*B!F<F]M(&%N(%A-3"!S=')I;F<N
M#0H@("`@("H@0&%C8V5S<R`@<'5B;&EC#0H@("`@("H@0'!A<F%M("`@<W1R
M:6YG("1D871A(&-O;G1E;G1S(&]F('!A8VMA9V4N>&UL(&9I;&4-"B`@("`@
M*B!`<&%R86T@("!I;G0@)'-T871E('!A8VMA9V4@<W1A=&4@*&]N92!O9B!0
M14%27U9!3$E$051%7RH@8V]N<W1A;G1S*0T*("`@("`J($!P87)A;2`@('-T
M<FEN9R`D9FEL92!F=6QL('!A=&@@=&\@=&AE('!A8VMA9V4N>&UL(&9I;&4@
M*&%N9"!T:&4@9FEL97,-"B`@("`@*B`@("`@("`@("!I="!R969E<F5N8V5S
M*0T*("`@("`J($!P87)A;2`@('-T<FEN9R`D87)C:&EV92!O<'1I;VYA;"!N
M86UE(&]F('1H92!A<F-H:79E('1H870@=&AE(%A-3"!W87,-"B`@("`@*B`@
M("`@("`@("!E>'1R86-T960@9G)O;2P@:68@86YY#0H@("`@("H@0')E='5R
M;B`@4$5!4E]086-K86=E1FEL95]V,7Q014%27U!A8VMA9V5&:6QE7W8R#0H@
M("`@("H@0'5S97,@("`@<&%R<V5R1F%C=&]R>2@I('1O(&-O;G-T<G5C="!A
M('!A<G-E<B!T;R!L;V%D('1H92!P86-K86=E+@T*("`@("`J+PT*("`@(&9U
M;F-T:6]N("9F<F]M6&UL4W1R:6YG*"1D871A+"`D<W1A=&4L("1F:6QE+"`D
M87)C:&EV92`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*'!R96=?;6%T
M8V@H)R\\<&%C:V%G95M>/ETK=F5R<VEO;CTB*%LP+3E=*UPN6S`M.5TK*2(O
M)RP@)&1A=&$L("1P86-K86=E=F5R<VEO;BDI('L-"B`@("`@("`@("`@(&EF
M("@A:6Y?87)R87DH)'!A8VMA9V5V97)S:6]N6S%=+"!A<G)A>2@G,2XP)RP@
M)S(N,"<I*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*"=P86-K86=E+GAM;"!V97)S:6]N("(G("X@)'!A8VMA9V5V97)S
M:6]N6S%=("X-"B`@("`@("`@("`@("`@("`@("`@)R(@:7,@;F]T('-U<'!O
M<G1E9"P@;VYL>2`Q+C`@86YD(#(N,"!A<F4@<W5P<&]R=&5D+B<I.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)&]B:F5C="`]("8D=&AI<RT^<&%R
M<V5R1F%C=&]R>2@D<&%C:V%G979E<G-I;VY;,5TI.PT*("`@("`@("`@("`@
M:68@*"1T:&ES+3Y?;&]G9V5R*2![#0H@("`@("`@("`@("`@("`@)&]B:F5C
M="T^<V5T3&]G9V5R*"1T:&ES+3Y?;&]G9V5R*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1O8FIE8W0M/G-E=$-O;F9I9R@D=&AI<RT^7V-O;F9I
M9RD[#0H@("`@("`@("`@("`D<&8@/2`D;V)J96-T+3YP87)S92@D9&%T82P@
M)&9I;&4L("1A<F-H:79E*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1P9BDI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'!F.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1T:&ES+3Y?<F%W4F5T=7)N
M*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1P9CL-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF("@D<&8M/G9A;&ED871E*"1S=&%T92DI('L-
M"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]L;V=G97(I('L-"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1P9BT^9V5T5F%L:61A=&EO;E=A<FYI;F=S
M*&9A;'-E*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)'!F+3YG971686QI9&%T:6]N5V%R;FEN9W,H*2!A<R`D=V%R;FEN9RD@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;&]G9V5R+3YL
M;V<H,"P@)U=!4DY)3D<Z("<@+B`D=V%R;FEN9ULG;65S<V%G92==*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H;65T
M:&]D7V5X:7-T<R@D<&8L("=F;&%T=&5N1FEL96QI<W0G*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D<&8M/F9L871T96Y&:6QE;&ES="@I.R`O+R!F;W(@
M=C(-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N
M("1P9CL-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M:68@*"1T:&ES+3Y?8V]N9FEG+3YG970H)W9E<F)O<V4G*2`^(#`I('L-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?;&]G9V5R*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H)'!F+3YG971686QI9&%T:6]N5V%R
M;FEN9W,H9F%L<V4I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)'!F+3YG971686QI9&%T:6]N5V%R;FEN9W,H9F%L<V4I(&%S
M("1W87)N:6YG*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;&]G9V5R+3YL;V<H,"P@)T524D]2.B`G("X@)'=A<FYI;F=;
M)VUE<W-A9V4G72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1A(#T@
M4$5!4CHZ<F%I<V5%<G)O<B@G4&%R<VEN9R!O9B!P86-K86=E+GAM;"!F<F]M
M(&9I;&4@(B<@+B`D9FEL92`N("<B(&9A:6QE9"<L#0H@("`@("`@("`@("`@
M("`@("`@(#(L(&YU;&PL(&YU;&PL("1P9BT^9V5T5F%L:61A=&EO;E=A<FYI
M;F=S*"DI.PT*("`@("`@("`@("`@("`@(')E='5R;B`D83L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)R\\<&%C:V%G
M95M>/ETK=F5R<VEO;CTB*%M>(ETK*2(O)RP@)&1A=&$L("1P86-K86=E=F5R
M<VEO;BDI('L-"B`@("`@("`@("`@("1A(#T@4$5!4CHZ<F%I<V5%<G)O<B@G
M<&%C:V%G92YX;6P@9FEL92`B)R`N("1F:6QE("X-"B`@("`@("`@("`@("`@
M("`G(B!H87,@=6YS=7!P;W)T960@<&%C:V%G92YX;6P@/'!A8VMA9V4^('9E
M<G-I;VX@(B<@+B`D<&%C:V%G979E<G-I;VY;,5T@+B`G(B<I.PT*("`@("`@
M("`@("`@<F5T=7)N("1A.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?17)R;W)3=&%C:R<I*2![#0H@
M("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T5R<F]R4W1A8VLN
M<&AP)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(%!%05)?17)R;W)3
M=&%C:SHZ<W1A=&EC4'5S:"@G4$5!4E]086-K86=E1FEL92<L#0H@("`@("`@
M("`@("`@("`@4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]004-+04=%5D52
M4TE/3BP-"B`@("`@("`@("`@("`@("`G=V%R;FEN9R<L(&%R<F%Y*"=X;6PG
M(#T^("1D871A*2P@)W!A8VMA9V4N>&UL("(G("X@)&9I;&4@+@T*("`@("`@
M("`@("`@("`@("`@("`G(B!H87,@;F\@<&%C:V%G92YX;6P@/'!A8VMA9V4^
M('9E<G-I;VXG*3L-"B`@("`@("`@("`@("1O8FIE8W0@/2`F)'1H:7,M/G!A
M<G-E<D9A8W1O<GDH)S$N,"<I.PT*("`@("`@("`@("`@)&]B:F5C="T^<V5T
M0V]N9FEG*"1T:&ES+3Y?8V]N9FEG*3L-"B`@("`@("`@("`@("1P9B`]("1O
M8FIE8W0M/G!A<G-E*"1D871A+"`D9FEL92P@)&%R8VAI=F4I.PT*("`@("`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)'!F*2D@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B`D<&8[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H)'1H:7,M/E]R87=2971U<FXI('L-"B`@("`@("`@("`@("`@("!R971U
M<FX@)'!F.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1P9BT^
M=F%L:61A=&4H)'-T871E*2D@>PT*("`@("`@("`@("`@("`@(&EF("@D=&AI
M<RT^7VQO9V=E<BD@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)'!F+3YG
M971686QI9&%T:6]N5V%R;FEN9W,H9F%L<V4I*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D<&8M/F=E=%9A;&ED871I;VY787)N:6YG
M<R@I(&%S("1W87)N:6YG*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]L;V=G97(M/FQO9R@P+"`G5T%23DE.1SH@)R`N("1W87)N
M:6YG6R=M97-S86=E)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@(&EF("AM971H;V1?97AI<W1S*"1P9BP@)V9L871T96Y&
M:6QE;&ES="<I*2![#0H@("`@("`@("`@("`@("`@("`@("1P9BT^9FQA='1E
M;D9I;&5L:7-T*"D[("\O(&9O<B!V,@T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!R971U<FX@)'!F.PT*("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`D82`](%!%05(Z.G)A:7-E17)R;W(H)U!A
M<G-I;F<@;V8@<&%C:V%G92YX;6P@9G)O;2!F:6QE("(G("X@)&9I;&4@+B`G
M(B!F86EL960G+`T*("`@("`@("`@("`@("`@("`@("`R+"!N=6QL+"!N=6QL
M+"`D<&8M/F=E=%9A;&ED871I;VY787)N:6YG<R@I*3L-"B`@("`@("`@("`@
M("`@("!R971U<FX@)&$[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!296=I<W1E<B!A('1E;7!O<F%R>2!F
M:6QE(&]R(&1I<F5C=&]R>2X@(%=H96X@=&AE(&1E<W1R=6-T;W(@:7,-"B`@
M("`@*B!E>&5C=71E9"P@86QL(')E9VES=&5R960@=&5M<&]R87)Y(&9I;&5S
M(&%N9"!D:7)E8W1O<FEE<R!A<F4-"B`@("`@*B!R96UO=F5D+@T*("`@("`J
M#0H@("`@("H@0'!A<F%M('-T<FEN9R`@)&9I;&4@(&YA;64@;V8@9FEL92!O
M<B!D:7)E8W1O<GD-"B`@("`@*B!`<F5T=7)N("!V;VED#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@861D5&5M<$9I;&4H)&9I;&4I#0H@("`@>PT*("`@("`@
M("`D1TQ/0D%,4ULG7U!%05)?0V]M;6]N7W1E;7!F:6QE<R==6UT@/2`D9FEL
M93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!#<F5A=&4@82!014%27U!A
M8VMA9V5&:6QE7W8J(&9R;VT@82!C;VUP<F5S960@5&%R(&]R(%1G>B!F:6QE
M+@T*("`@("`J($!A8V-E<W,@('!U8FQI8PT*("`@("`J($!P87)A;2!S=')I
M;F<@8V]N=&5N=',@;V8@<&%C:V%G92YX;6P@9FEL90T*("`@("`J($!P87)A
M;2!I;G0@<&%C:V%G92!S=&%T92`H;VYE(&]F(%!%05)?5D%,241!5$5?*B!C
M;VYS=&%N=',I#0H@("`@("H@0')E='5R;B`@4$5!4E]086-K86=E1FEL95]V
M,7Q014%27U!A8VMA9V5&:6QE7W8R#0H@("`@("H@0'5S:6YG("`@07)C:&EV
M95]487(@=&\@97AT<F%C="!T:&4@9FEL97,-"B`@("`@*B!`=7-I;F<@("!F
M<F]M4&%C:V%G949I;&4H*2!T;R!L;V%D('1H92!P86-K86=E(&%F=&5R('1H
M92!P86-K86=E+GAM;`T*("`@("`J("`@("`@("`@(&9I;&4@:7,@97AT<F%C
M=&5D+@T*("`@("`J+PT*("`@(&9U;F-T:6]N("9F<F]M5&=Z1FEL92@D9FEL
M92P@)'-T871E*0T*("`@('L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H
M)T%R8VAI=F5?5&%R)RDI('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G
M07)C:&EV92]487(N<&AP)SL-"B`@("`@("`@?0T*("`@("`@("`D=&%R(#T@
M;F5W($%R8VAI=F5?5&%R*"1F:6QE*3L-"B`@("`@("`@:68@*"1T:&ES+3Y?
M9&5B=6<@/#T@,2D@>PT*("`@("`@("`@("`@)'1A<BT^<'5S:$5R<F]R2&%N
M9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("!]#0H@("`@("`@
M("1C;VYT96YT(#T@)'1A<BT^;&ES=$-O;G1E;G0H*3L-"B`@("`@("`@:68@
M*"1T:&ES+3Y?9&5B=6<@/#T@,2D@>PT*("`@("`@("`@("`@)'1A<BT^<&]P
M17)R;W)(86YD;&EN9R@I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-?
M87)R87DH)&-O;G1E;G0I*2![#0H@("`@("`@("`@("!I9B`H:7-?<W1R:6YG
M*"1F:6QE*2`F)B!S=')L96XH)&9I;&4@/"`R-34I("8F("%`:7-?9FEL92@D
M9FEL92DI('L-"B`@("`@("`@("`@("`@("`D<F5T(#T@4$5!4CHZ<F%I<V5%
M<G)O<B@B8V]U;&0@;F]T(&]P96X@9FEL92!<(B1F:6QE7"(B*3L-"B`@("`@
M("`@("`@("`@("!R971U<FX@)')E=#L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("1F:6QE(#T@<F5A;'!A=&@H)&9I;&4I.PT*("`@("`@("`@("`@
M)')E="`](%!%05(Z.G)A:7-E17)R;W(H(D-O=6QD(&YO="!G970@8V]N=&5N
M=',@;V8@<&%C:V%G92!<(B1F:6QE7"(B+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("<N($EN=F%L:60@=&=Z(&9I;&4N)RD[#0H@
M("`@("`@("`@("!R971U<FX@)')E=#L-"B`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@(&EF("@A8V]U;G0H)&-O;G1E;G0I("8F("%`:7-?9FEL92@D
M9FEL92DI('L-"B`@("`@("`@("`@("`@("`D<F5T(#T@4$5!4CHZ<F%I<V5%
M<G)O<B@B8V]U;&0@;F]T(&]P96X@9FEL92!<(B1F:6QE7"(B*3L-"B`@("`@
M("`@("`@("`@("!R971U<FX@)')E=#L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("`D>&UL(#T@;G5L;#L-"B`@("`@("`@)&]R:6=F:6QE
M(#T@)&9I;&4[#0H@("`@("`@(&9O<F5A8V@@*"1C;VYT96YT(&%S("1F:6QE
M*2![#0H@("`@("`@("`@("`D;F%M92`]("1F:6QE6R=F:6QE;F%M92==.PT*
M("`@("`@("`@("`@:68@*"1N86UE(#T]("=P86-K86=E,BYX;6PG*2![("\O
M(&%L;&]W(&$@+G1G>B!T;R!D:7-T<FEB=71E(&)O=&@@=F5R<VEO;G,-"B`@
M("`@("`@("`@("`@("`D>&UL(#T@)&YA;64[#0H@("`@("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)&YA;64@
M/3T@)W!A8VMA9V4N>&UL)RD@>PT*("`@("`@("`@("`@("`@("1X;6P@/2`D
M;F%M93L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@('T@
M96QS96EF("AE<F5G*"=P86-K86=E+GAM;"0G+"`D;F%M92P@)&UA=&-H*2D@
M>PT*("`@("`@("`@("`@("`@("1X;6P@/2`D;F%M93L-"B`@("`@("`@("`@
M("`@("!B<F5A:SL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H)'1H:7,M/E]T;7!D:7(I('L-"B`@("`@("`@("`@("1T;7!D:7(@
M/2`D=&AI<RT^7W1M<&1I<CL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("1T;7!D:7(@/2!3>7-T96TZ.FUK5&5M<"AA<G)A>2@G+60G+"`G<&5A
M<B<I*3L-"B`@("`@("`@("`@(%!%05)?4&%C:V%G949I;&4Z.F%D9%1E;7!&
M:6QE*"1T;7!D:7(I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A)'AM;"!\
M?"`A)'1A<BT^97AT<F%C=$QI<W0H87)R87DH)'AM;"DL("1T;7!D:7(I*2![
M#0H@("`@("`@("`@("`D<F5T(#T@4$5!4CHZ<F%I<V5%<G)O<B@G8V]U;&0@
M;F]T(&5X=')A8W0@=&AE('!A8VMA9V4N>&UL(&9I;&4@9G)O;2`B)R`N#0H@
M("`@("`@("`@("`@("`@)&]R:6=F:6QE("X@)R(G*3L-"B`@("`@("`@("`@
M(')E='5R;B`D<F5T.PT*("`@("`@("!]#0H@("`@("`@("1R970@/2`F4$5!
M4E]086-K86=E1FEL93HZ9G)O;5!A8VMA9V5&:6QE*"(D=&UP9&ER+R1X;6PB
M+"`D<W1A=&4L("1O<FEG9FEL92D[#0H@("`@("`@(')E='5R;B`D<F5T.PT*
M("`@('T-"@T*("`@("\J*@T*("`@("`J($-R96%T92!A(%!%05)?4&%C:V%G
M949I;&5?=BH@9G)O;2!A('!A8VMA9V4N>&UL(&9I;&4N#0H@("`@("H-"B`@
M("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!P87)A;2`@('-T<FEN9R`@
M)&1E<V-F:6QE("!N86UE(&]F('!A8VMA9V4@>&UL(&9I;&4-"B`@("`@*B!`
M<&%R86T@("!I;G0@("`@("1S=&%T92!P86-K86=E('-T871E("AO;F4@;V8@
M4$5!4E]604Q)1$%415\J(&-O;G-T86YT<RD-"B`@("`@*B!`<&%R86T@("!S
M=')I;F=\9F%L<V4@)&%R8VAI=F4@;F%M92!O9B!T:&4@87)C:&EV92!T:&ES
M('!A8VMA9V4N>&UL(&-A;64-"B`@("`@*B`@("`@("`@("!F<F]M+"!I9B!A
M;GD-"B`@("`@*B!`<F5T=7)N("!014%27U!A8VMA9V5&:6QE7W8Q?%!%05)?
M4&%C:V%G949I;&5?=C(-"B`@("`@*B!`=7-E<R`@("!014%27U!A8VMA9V5&
M:6QE.CIF<F]M6&UL4W1R:6YG('1O(&-R96%T92!T:&4@;VIE8W0@869T97(@
M=&AE#0H@("`@("H@("`@("`@("`@6$U,(&ES(&QO861E9"!F<F]M('1H92!P
M86-K86=E+GAM;"!F:6QE+@T*("`@("`J+PT*("`@(&9U;F-T:6]N("9F<F]M
M4&%C:V%G949I;&4H)&1E<V-F:6QE+"`D<W1A=&4L("1A<F-H:79E(#T@9F%L
M<V4I#0H@("`@>PT*("`@("`@("!I9B`H:7-?<W1R:6YG*"1D97-C9FEL92D@
M)B8@<W1R;&5N*"1D97-C9FEL92D@/"`R-34@)B8-"B`@("`@("`@("`@("`A
M0&ES7V9I;&4H)&1E<V-F:6QE*2!\?"`A:7-?<F5A9&%B;&4H)&1E<V-F:6QE
M*2!\?`T*("`@("`@("`@("`@("@A)&9P(#T@0&9O<&5N*"1D97-C9FEL92P@
M)W(G*2DI('L-"B`@("`@("`@("`@("1A(#T@4$5!4CHZ<F%I<V5%<G)O<B@B
M56YA8FQE('1O(&]P96X@)&1E<V-F:6QE(BD[#0H@("`@("`@("`@("!R971U
M<FX@)&$[#0H@("`@("`@('T-"@T*("`@("`@("`O+R!R96%D('1H92!W:&]L
M92!T:&EN9R!S;R!W92!O;FQY(&=E="!O;F4@8V1A=&$@8V%L;&)A8VL-"B`@
M("`@("`@+R\@9F]R(&5A8V@@8FQO8VL@;V8@8V1A=&$-"B`@("`@("`@:68@
M*&9U;F-T:6]N7V5X:7-T<R@G9FEL95]G971?8V]N=&5N=',G*2D@>PT*("`@
M("`@("`@("`@0&9C;&]S92@D9G`I.PT*("`@("`@("`@("`@)&1A=&$@/2!F
M:6QE7V=E=%]C;VYT96YT<R@D9&5S8V9I;&4I.PT*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@)&1A=&$@/2`G)SL-"B`@("`@("`@("`@('=H:6QE
M("@A9F5O9B@D9G`I*2![#0H@("`@("`@("`@("`@("`@)&1A=&$@+CT@0&9R
M96%D*"1F<"P@.#$Y,BD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F
M8VQO<V4H)&9P*3L-"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@)E!%05)?
M4&%C:V%G949I;&4Z.F9R;VU8;6Q3=')I;F<H)&1A=&$L("1S=&%T92P@)&1E
M<V-F:6QE+"`D87)C:&EV92D[#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@
M('T-"@T*#0H@("`@+RHJ#0H@("`@("H@0W)E871E(&$@4$5!4E]086-K86=E
M1FEL95]V*B!F<F]M(&$@+G1G>B!A<F-H:79E(&]R('!A8VMA9V4N>&UL(&9I
M;&4N#0H@("`@("H-"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!A8FQE('1O(&5X
M=')A8W0@:6YF;W)M871I;VX@86)O=70@82!P86-K86=E(&9R;VT@82`N=&=Z
M#0H@("`@("H@87)C:&EV92!O<B!F<F]M(&$@6$U,('!A8VMA9V4@9&5F:6YI
M=&EO;B!F:6QE+@T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@
M("`@*B!`<&%R86T@("!S=')I;F<@("1I;F9O(&9I;&4@;F%M90T*("`@("`J
M($!P87)A;2`@(&EN="`@("`@)'-T871E('!A8VMA9V4@<W1A=&4@*&]N92!O
M9B!014%27U9!3$E$051%7RH@8V]N<W1A;G1S*0T*("`@("`J($!R971U<FX@
M(%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]086-K86=E1FEL95]V,@T*("`@
M("`J($!U<V5S("`@(&9R;VU086-K86=E1FEL92@I(&EF('1H92!F:6QE(&%P
M<&5A<G,@=&\@8F4@6$U,#0H@("`@("H@0'5S97,@("`@9G)O;51G>D9I;&4H
M*2!T;R!L;V%D(&%L;"!N;VXM6$U,(&9I;&5S#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@)F9R;VU!;GE&:6QE*"1I;F9O+"`D<W1A=&4I#0H@("`@>PT*("`@
M("`@("`D9G`@/2!F86QS93L-"B`@("`@("`@:68@*&ES7W-T<FEN9R@D:6YF
M;RD@)B8@<W1R;&5N*"1I;F9O*2`\(#(U-2`F)@T*("`@("`@("`@("`@("AF
M:6QE7V5X:7-T<R@D:6YF;RD@?'P@*"1F<"`]($!F;W!E;B@D:6YF;RP@)W(G
M*2DI*2![#0H@("`@("`@("`@("!I9B`H)&9P*2![#0H@("`@("`@("`@("`@
M("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D
M=&UP(#T@<W5B<W1R*"1I;F9O+"`M-"D[#0H@("`@("`@("`@("!I9B`H)'1M
M<"`]/2`G+GAM;"<I('L-"B`@("`@("`@("`@("`@("`D:6YF;R`]("9014%2
M7U!A8VMA9V5&:6QE.CIF<F]M4&%C:V%G949I;&4H)&EN9F\L("1S=&%T92D[
M#0H@("`@("`@("`@("!](&5L<V5I9B`H)'1M<"`]/2`G+G1A<B<@?'P@)'1M
M<"`]/2`G+G1G>B<I('L-"B`@("`@("`@("`@("`@("`D:6YF;R`]("9014%2
M7U!A8VMA9V5&:6QE.CIF<F]M5&=Z1FEL92@D:6YF;RP@)'-T871E*3L-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&9P(#T@9F]P
M96XH)&EN9F\L(")R(BD[#0H@("`@("`@("`@("`@("`@)'1E<W0@/2!F<F5A
M9"@D9G`L(#4I.PT*("`@("`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@
M("`@("`@("`@("`@(&EF("@D=&5S="`]/2`B/#]X;6PB*2![#0H@("`@("`@
M("`@("`@("`@("`@("1I;F9O(#T@)E!%05)?4&%C:V%G949I;&4Z.F9R;VU0
M86-K86=E1FEL92@D:6YF;RP@)'-T871E*3L-"B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D:6YF;R`]("9014%27U!A
M8VMA9V5&:6QE.CIF<F]M5&=Z1FEL92@D:6YF;RP@)'-T871E*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`D:6YF;R`](%!%05(Z.G)A:7-E17)R;W(H(D-A;FYO
M="!O<&5N("<D:6YF;R<@9F]R('!A<G-I;F<B*3L-"B`@("`@("`@("`@(')E
M='5R;B`D:6YF;SL-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&EN9F\[
M#0H@("`@?0T*?0T*#0H_/@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]014%2+U!A8VMA9V5R+G!H<```````````````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`Q-S4U,P`Q,#4Q-30S,S<T,0`P,C$U-S(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`-"B\J*@T*
M("H@4$5!4E]086-K86=E<B!F;W(@9V5N97)A=&EN9R!R96QE87-E<PT*("H-
M"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H
M92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A
M;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P
M;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C
M871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H
M;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@
M("`@(%1O;6%S(%8N(%8N($-O>"`\8V]X0&ED96-N970N8V]M/@T*("H@0&%U
M=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%!A8VMA9V5R
M+G!H<"QV(#$N-C@@,C`P-B\P,2\P-B`P-#HT-SHS-B!C96QL;V<@17AP("0-
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]0
M14%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE
M87-E(#`N,0T*("HO#0H-"B\J*@T*("H@8F%S92!C;&%S<PT*("HO#0IR97%U
M:7)E7V]N8V4@)U!%05(O0V]M;6]N+G!H<"<[#0IR97%U:7)E7V]N8V4@)U!%
M05(O4&%C:V%G949I;&4N<&AP)SL-"G)E<75I<F5?;VYC92`G4WES=&5M+G!H
M<"<[#0H-"B\J*@T*("H@061M:6YI<W1R871I;VX@8VQA<W,@=7-E9"!T;R!M
M86ME(&$@4$5!4B!R96QE87-E('1A<F)A;&PN#0H@*@T*("H@0&-A=&5G;W)Y
M("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@
M1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN
M8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J
M+PT*8VQA<W,@4$5!4E]086-K86=E<B!E>'1E;F1S(%!%05)?0V]M;6]N#0I[
M#0H@("`@+RHJ#0H@("`@("H@0'9A<B!014%27U)E9VES=')Y#0H@("`@("HO
M#0H@("`@=F%R("1?<F5G:7-T<GD[#0H@("`@+R\@>WM[('!A8VMA9V4H*0T*
M#0H@("`@9G5N8W1I;VX@<&%C:V%G92@D<&MG9FEL92`](&YU;&PL("1C;VUP
M<F5S<R`]('1R=64L("1P:V<R(#T@;G5L;"D-"B`@("![#0H@("`@("`@("\O
M('M[>R!V86QI9&%T92!S=7!P;&EE9"!P86-K86=E+GAM;"!F:6QE#0H@("`@
M("`@(&EF("AE;7!T>2@D<&MG9FEL92DI('L-"B`@("`@("`@("`@("1P:V=F
M:6QE(#T@)W!A8VMA9V4N>&UL)SL-"B`@("`@("`@?0T*("`@("`@("!014%2
M.CIS=&%T:6-0=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[
M#0H@("`@("`@("1P:V<@/2`F;F5W(%!%05)?4&%C:V%G949I;&4H)'1H:7,M
M/F-O;F9I9RP@)'1H:7,M/F1E8G5G*3L-"B`@("`@("`@)'!F(#T@)B1P:V<M
M/F9R;VU086-K86=E1FEL92@D<&MG9FEL92P@4$5!4E]604Q)1$%415].3U)-
M04PI.PT*("`@("`@("`D;6%I;B`]("8D<&8[#0H@("`@("`@(%!%05(Z.G-T
M871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)'!F*2D@>PT*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1P9BT^
M9V5T57-E<DEN9F\H*2DI('L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D
M<&8M/F=E=%5S97));F9O*"D@87,@)&5R<F]R*2![#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YL;V<H,"P@)T5R<F]R.B`G("X@)&5R<F]R6R=M97-S
M86=E)UTI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("1T:&ES+3YL;V<H,"P@)'!F+3YG971-97-S86=E*"DI.PT*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")#86YN;W0@
M<&%C:V%G92P@97)R;W)S(&EN('!A8VMA9V4@9FEL92(I.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@9F]R96%C:"`H)'!F+3YG971686QI9&%T
M:6]N5V%R;FEN9W,H*2!A<R`D=V%R;FEN9RD@>PT*("`@("`@("`@("`@("`@
M("1T:&ES+3YL;V<H,2P@)U=A<FYI;F<Z("<@+B`D=V%R;FEN9ULG;65S<V%G
M92==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@("\O
M('U]?0T*("`@("`@("!I9B`H)'!K9S(I('L-"B`@("`@("`@("`@("1T:&ES
M+3YL;V<H,"P@)T%T=&5M<'1I;F<@=&\@<')O8V5S<R!T:&4@<V5C;VYD('!A
M8VMA9V4@9FEL92<I.PT*("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4'5S:$5R
M<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`@("`@
M)'!F,B`]("8D<&MG+3YF<F]M4&%C:V%G949I;&4H)'!K9S(L(%!%05)?5D%,
M241!5$5?3D]234%,*3L-"B`@("`@("`@("`@(%!%05(Z.G-T871I8U!O<$5R
M<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1P9C(I*2![#0H@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1P9C(M
M/F=E=%5S97));F9O*"DI*2![#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1P9C(M/F=E=%5S97));F9O*"D@87,@)&5R<F]R*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("=%<G)O<CH@)R`N("1E
M<G)O<ELG;65S<V%G92==*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L
M("1P9C(M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*")#86YN;W0@<&%C:V%G92P@97)R;W)S(&EN
M('-E8V]N9"!P86-K86=E(&9I;&4B*3L-"B`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!F,BT^9V5T5F%L:61A=&EO
M;E=A<FYI;F=S*"D@87,@)'=A<FYI;F<I('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/FQO9R@Q+"`G5V%R;FEN9SH@)R`N("1W87)N:6YG6R=M97-S
M86=E)UTI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("@D<&8R+3YG971086-K86=E>&UL5F5R<VEO;B@I(#T]
M("<R+C`G*2![#0H@("`@("`@("`@("`@("`@)&UA:6X@/2`F)'!F,CL-"B`@
M("`@("`@("`@("`@("`D;W1H97(@/2`F)'!F.PT*("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`D;6%I;B`]("8D<&8[#0H@("`@("`@
M("`@("`@("`@)&]T:&5R(#T@)B1P9C([#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!I9B`H)&UA:6XM/F=E=%!A8VMA9V5X;6Q697)S:6]N*"D@(3T@
M)S(N,"<I('L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G17)R;W(Z(&-A;FYO="!P86-K86=E('1W;R!P86-K86=E+GAM;"!V
M97)S:6]N(#$N,"P@8V%N("<@+@T*("`@("`@("`@("`@("`@("`@("`G;VYL
M>2!P86-K86=E('1O9V5T:&5R(&$@<&%C:V%G92YX;6P@,2XP(&%N9"!P86-K
M86=E+GAM;"`R+C`G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF
M("@D;W1H97(M/F=E=%!A8VMA9V5X;6Q697)S:6]N*"D@(3T@)S$N,"<I('L-
M"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G17)R
M;W(Z(&-A;FYO="!P86-K86=E('1W;R!P86-K86=E+GAM;"!V97)S:6]N(#(N
M,"P@8V%N("<@+@T*("`@("`@("`@("`@("`@("`@("`G;VYL>2!P86-K86=E
M('1O9V5T:&5R(&$@<&%C:V%G92YX;6P@,2XP(&%N9"!P86-K86=E+GAM;"`R
M+C`G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D;6%I
M;BT^<V5T3&]G9V5R*"1T:&ES*3L-"B`@("`@("`@:68@*"$D;6%I;BT^=F%L
M:61A=&4H4$5!4E]604Q)1$%415]004-+04=)3D<I*2![#0H@("`@("`@("`@
M("!F;W)E86-H("@D;6%I;BT^9V5T5F%L:61A=&EO;E=A<FYI;F=S*"D@87,@
M)'=A<FYI;F<I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("=%
M<G)O<CH@)R`N("1W87)N:6YG6R=M97-S86=E)UTI.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")#86YN
M;W0@<&%C:V%G92P@97)R;W)S(&EN('!A8VMA9V4B*3L-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1M86EN+3YG971686QI9&%T
M:6]N5V%R;FEN9W,H*2!A<R`D=V%R;FEN9RD@>PT*("`@("`@("`@("`@("`@
M("1T:&ES+3YL;V<H,2P@)U=A<FYI;F<Z("<@+B`D=V%R;FEN9ULG;65S<V%G
M92==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M)'!K9S(I('L-"B`@("`@("`@("`@("1O=&AE<BT^<V5T3&]G9V5R*"1T:&ES
M*3L-"B`@("`@("`@("`@("1A(#T@9F%L<V4[#0H@("`@("`@("`@("!I9B`H
M(21O=&AE<BT^=F%L:61A=&4H4$5!4E]604Q)1$%415].3U)-04PI('Q\("1A
M(#T@(21M86EN+3YI<T5Q=6EV86QE;G0H)&]T:&5R*2D@>PT*("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1O=&AE<BT^9V5T5F%L:61A=&EO;E=A<FYI;F=S
M*"D@87,@)'=A<FYI;F<I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/FQO9R@P+"`G17)R;W(Z("<@+B`D=V%R;FEN9ULG;65S<V%G92==*3L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&UA
M:6XM/F=E=%9A;&ED871I;VY787)N:6YG<R@I(&%S("1W87)N:6YG*2![#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@)T5R<F]R.B`G("X@
M)'=A<FYI;F=;)VUE<W-A9V4G72D[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@(&EF("@D82D@>PT*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)U1H92!T=V\@<&%C:V%G92YX;6P@
M9FEL97,@87)E(&YO="!E<75I=F%L96YT(2<I.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M(D-A;FYO="!P86-K86=E+"!E<G)O<G,@:6X@<&%C:V%G92(I.PT*("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D;W1H
M97(M/F=E=%9A;&ED871I;VY787)N:6YG<R@I(&%S("1W87)N:6YG*2![#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,2P@)U=A<FYI;F<Z("<@
M+B`D=V%R;FEN9ULG;65S<V%G92==*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`D9V5N(#T@)B1M86EN+3YG971$
M969A=6QT1V5N97)A=&]R*"D[#0H@("`@("`@("`@("`D=&=Z9FEL92`]("1G
M96XM/G1O5&=Z,B@D=&AI<RP@)&]T:&5R+"`D8V]M<')E<W,I.PT*("`@("`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)'1G>F9I;&4I*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N("1T9WIF:6QE.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)&1E<W1?<&%C:V%G92`](&)A<V5N86UE*"1T9WIF:6QE*3L-
M"B`@("`@("`@("`@("1P:V=D:7(@/2!D:7)N86UE*"1P:V=F:6QE*3L-"B`@
M("`-"B`@("`@("`@("`@("\O(%1!4B!T:&4@4&%C:V%G92`M+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM#0H@("`@("`@("`@
M("`D=&AI<RT^;&]G*#$L(")086-K86=E("1D97-T7W!A8VMA9V4@9&]N92(I
M.PT*("`@("`@("`@("`@:68@*&9I;&5?97AI<W1S*"(D<&MG9&ER+T-64R]2
M;V]T(BDI('L-"B`@("`@("`@("`@("`@("`D8W9S=F5R<VEO;B`]('!R96=?
M<F5P;&%C92@G+UM>82UZ,"TY72]I)RP@)U\G+"`D<&8M/F=E=%9E<G-I;VXH
M*2D[#0H@("`@("`@("`@("`@("`@)&-V<W1A9R`](")214Q%05-%7R1C=G-V
M97)S:6]N(CL-"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#$L("=486<@
M=&AE(')E;&5A<V5D(&-O9&4@=VET:"`B<&5A<B!C=G-T86<@)R`N#0H@("`@
M("`@("`@("`@("`@("`@("1M86EN+3YG971086-K86=E1FEL92@I("X@)R(G
M*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#$L("(H;W(@<V5T('1H
M92!#5E,@=&%G("1C=G-T86<@8GD@:&%N9"DB*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?2!E;'-E('L@+R\@=&AI<R!B<F%N8V@@:7,@97AE8W5T960@
M9F]R('-I;F=L92!P86-K86=E9FEL92!P86-K86=I;F<-"B`@("`@("`@("`@
M("1G96X@/2`F)'!F+3YG971$969A=6QT1V5N97)A=&]R*"D[#0H@("`@("`@
M("`@("`D=&=Z9FEL92`]("1G96XM/G1O5&=Z*"1T:&ES+"`D8V]M<')E<W,I
M.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'1G>F9I;&4I*2![
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`D=&=Z9FEL92T^9V5T
M365S<V%G92@I*3L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H(D-A;FYO="!P86-K86=E+"!E<G)O<G,@:6X@<&%C:V%G92(I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&1E<W1?<&%C:V%G92`]
M(&)A<V5N86UE*"1T9WIF:6QE*3L-"B`@("`@("`@("`@("1P:V=D:7(@/2!D
M:7)N86UE*"1P:V=F:6QE*3L-"B`@("`-"B`@("`@("`@("`@("\O(%1!4B!T
M:&4@4&%C:V%G92`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM#0H@("`@("`@("`@("`D=&AI<RT^;&]G*#$L(")086-K86=E
M("1D97-T7W!A8VMA9V4@9&]N92(I.PT*("`@("`@("`@("`@:68@*&9I;&5?
M97AI<W1S*"(D<&MG9&ER+T-64R]2;V]T(BDI('L-"B`@("`@("`@("`@("`@
M("`D8W9S=F5R<VEO;B`]('!R96=?<F5P;&%C92@G+UM>82UZ,"TY72]I)RP@
M)U\G+"`D<&8M/F=E=%9E<G-I;VXH*2D[#0H@("`@("`@("`@("`@("`@)&-V
M<W1A9R`](")214Q%05-%7R1C=G-V97)S:6]N(CL-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^;&]G*#$L(")486<@=&AE(')E;&5A<V5D(&-O9&4@=VET:"!@
M<&5A<B!C=G-T86<@)'!K9V9I;&4G(BD[#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/FQO9R@Q+"`B*&]R('-E="!T:&4@0U93('1A9R`D8W9S=&%G(&)Y(&AA
M;F0I(BD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N("1D97-T7W!A8VMA9V4[#0H@("`@?0T*#0H@("`@+R\@?7U]#0I]#0H-
M"B\O('M[>R!M9#5?9FEL92@I('5T:6QI='D@9G5N8W1I;VX-"FEF("@A9G5N
M8W1I;VY?97AI<W1S*"=M9#5?9FEL92<I*2![#0H@("`@9G5N8W1I;VX@;60U
M7V9I;&4H)&9I;&4I('L-"B`@("`@("`@:68@*"$D9F0@/2!`9F]P96XH)&9I
M;&4L("=R)RDI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=F:6QE7V=E=%]C
M;VYT96YT<R<I*2![#0H@("`@("`@("`@("!F8VQO<V4H)&9D*3L-"B`@("`@
M("`@("`@("1M9#4@/2!M9#4H9FEL95]G971?8V]N=&5N=',H)&9I;&4I*3L-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1M9#4@/2!M9#4H9G)E
M860H)&9D+"!F:6QE<VEZ92@D9FEL92DI*3L-"B`@("`@("`@("`@(&9C;&]S
M92@D9F0I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D;60U.PT*("`@
M('T-"GT-"B\O('U]?0T*#0H_/@T*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]296=I<W1R>2YP:'``````````
M````````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`R,38R,C``,3`U,34T,S,W
M-#$`,#(Q-C4U`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP#0HO*BH-"B`J(%!%05)?4F5G:7-T<GD-"B`J#0H@*B!0
M2%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U
M<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0
M(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R
M92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E
M#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N
M(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O
M<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@
M("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!4
M;VUA<R!6+B!6+B!#;W@@/&-O>$!I9&5C;F5T+F-O;3X-"B`J($!A=71H;W(@
M("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG
M:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS
M92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!296=I<W1R>2YP:'`L
M=B`Q+C$U,"XR+C(@,C`P-B\P,R\Q,2`P-#HQ-CHT."!C96QL;V<@17AP("0-
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]0
M14%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE
M87-E(#`N,0T*("HO#0H-"B\J*@T*("H@9F]R(%!%05)?17)R;W(-"B`J+PT*
M<F5Q=6ER95]O;F-E("=014%2+G!H<"<[#0IR97%U:7)E7V]N8V4@)U!%05(O
M1&5P96YD96YC>41"+G!H<"<[#0H-"F1E9FEN92@G4$5!4E]214=)4U1265]%
M4E)/4E],3T-+)RP@("`M,BD[#0ID969I;F4H)U!%05)?4D5'25-44EE?15)2
M3U)?1D]234%4)RP@+3,I.PT*9&5F:6YE*"=014%27U)%1TE35%)97T524D]2
M7T9)3$4G+"`@("TT*3L-"F1E9FEN92@G4$5!4E]214=)4U1265]%4E)/4E]#
M3TY&3$E#5"<L("TU*3L-"F1E9FEN92@G4$5!4E]214=)4U1265]%4E)/4E]#
M2$%.3D5,7T9)3$4G+"`M-BD[#0H-"B\J*@T*("H@061M:6YI<W1R871I;VX@
M8VQA<W,@=7-E9"!T;R!M86EN=&%I;B!T:&4@:6YS=&%L;&5D('!A8VMA9V4@
M9&%T86)A<V4N#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@
M("!014%2#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN
M970^#0H@*B!`875T:&]R("`@("!4;VUA<R!6+B!6+B!#;W@@/&-O>$!I9&5C
M;F5T+F-O;3X-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`
M<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R
M;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E
M;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N
M;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA
M8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0IC;&%S<R!014%27U)E
M9VES=')Y(&5X=&5N9',@4$5!4@T*>PT*("`@("\O('M[>R!P<F]P97)T:65S
M#0H-"B`@("`O*BH-"B`@("`@*B!&:6QE(&-O;G1A:6YI;F<@86QL(&-H86YN
M96P@:6YF;W)M871I;VXN#0H@("`@("H@0'9A<B!S=')I;F<-"B`@("`@*B\-
M"B`@("!V87(@)&-H86YN96QS(#T@)R<[#0H-"B`@("`O*BH@1&ER96-T;W)Y
M('=H97)E(')E9VES=')Y(&9I;&5S(&%R92!S=&]R960N#0H@("`@("H@0'9A
M<B!S=')I;F<-"B`@("`@*B\-"B`@("!V87(@)'-T871E9&ER(#T@)R<[#0H-
M"B`@("`O*BH@1FEL92!W:&5R92!T:&4@9FEL92!M87`@:7,@<W1O<F5D#0H@
M("`@("H@0'9A<B!S=')I;F<-"B`@("`@*B\-"B`@("!V87(@)&9I;&5M87`@
M/2`G)SL-"@T*("`@("\J*B!$:7)E8W1O<GD@=VAE<F4@<F5G:7-T<GD@9FEL
M97,@9F]R(&-H86YN96QS(&%R92!S=&]R960N#0H@("`@("H@0'9A<B!S=')I
M;F<-"B`@("`@*B\-"B`@("!V87(@)&-H86YN96QS9&ER(#T@)R<[#0H-"B`@
M("`O*BH@3F%M92!O9B!F:6QE('5S960@9F]R(&QO8VMI;F<@=&AE(')E9VES
M=')Y#0H@("`@("H@0'9A<B!S=')I;F<-"B`@("`@*B\-"B`@("!V87(@)&QO
M8VMF:6QE(#T@)R<[#0H-"B`@("`O*BH@1FEL92!D97-C<FEP=&]R('5S960@
M9'5R:6YG(&QO8VMI;F<-"B`@("`@*B!`=F%R(')E<V]U<F-E#0H@("`@("HO
M#0H@("`@=F%R("1L;V-K7V9P(#T@;G5L;#L-"@T*("`@("\J*B!-;V1E('5S
M960@9'5R:6YG(&QO8VMI;F<-"B`@("`@*B!`=F%R(&EN=`T*("`@("`J+PT*
M("`@('9A<B`D;&]C:U]M;V1E(#T@,#L@+R\@6%A8(%5.55-%1`T*#0H@("`@
M+RHJ($-A8VAE(&]F('!A8VMA9V4@:6YF;W)M871I;VXN("!3=')U8W1U<F4Z
M#0H@("`@("H@87)R87DH#0H@("`@("H@("`G<&%C:V%G92<@/3X@87)R87DH
M)VED)R`]/B`N+BX@*2P-"B`@("`@*B`@("XN+B`I#0H@("`@("H@0'9A<B!A
M<G)A>0T*("`@("`J+PT*("`@('9A<B`D<&MG:6YF;U]C86-H92`](&%R<F%Y
M*"D[#0H-"B`@("`O*BH@0V%C:&4@;V8@9FEL92!M87`N("!3=')U8W1U<F4Z
M#0H@("`@("H@87)R87DH("<O<&%T:"]T;R]F:6QE)R`]/B`G<&%C:V%G92<L
M("XN+B`I#0H@("`@("H@0'9A<B!A<G)A>0T*("`@("`J+PT*("`@('9A<B`D
M9FEL96UA<%]C86-H92`](&%R<F%Y*"D[#0H-"B`@("`O*BH-"B`@("`@*B!`
M=F%R(&9A;'-E?%!%05)?0VAA;FYE;$9I;&4-"B`@("`@*B\-"B`@("!V87(@
M)%]P96%R0VAA;FYE;#L-"@T*("`@("\J*@T*("`@("`J($!V87(@9F%L<V5\
M4$5!4E]#:&%N;F5L1FEL90T*("`@("`J+PT*("`@('9A<B`D7W!E8VQ#:&%N
M;F5L.PT*#0H@("`@+RHJ#0H@("`@("H@0'9A<B!014%27T1E<&5N9&5N8WE$
M0@T*("`@("`J+PT*("`@('9A<B`D7V1E<&5N9&5N8WE$0CL-"@T*("`@("\J
M*@T*("`@("`J($!V87(@4$5!4E]#;VYF:6<-"B`@("`@*B\-"B`@("!V87(@
M)%]C;VYF:6<[#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@8V]N<W1R=6-T
M;W(-"@T*("`@("\J*@T*("`@("`J(%!%05)?4F5G:7-T<GD@8V]N<W1R=6-T
M;W(N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("AO<'1I;VYA;"D@
M4$5!4B!I;G-T86QL(&1I<F5C=&]R>2`H9F]R("YP:'`@9FEL97,I#0H@("`@
M("H@0'!A<F%M(%!%05)?0VAA;FYE;$9I;&4@4$5!4E]#:&%N;F5L1FEL92!O
M8FIE8W0@<F5P<F5S96YT:6YG('1H92!014%2(&-H86YN96PL(&EF#0H@("`@
M("H@("`@("`@(&1E9F%U;'0@=F%L=65S(&%R92!N;W0@9&5S:7)E9"X@($]N
M;'D@=7-E9"!T:&4@=F5R>2!F:7)S="!T:6UE(&$@4$5!4@T*("`@("`J("`@
M("`@("!R97!O<VET;W)Y(&ES(&EN:71I86QI>F5D#0H@("`@("H@0'!A<F%M
M(%!%05)?0VAA;FYE;$9I;&4@4$5!4E]#:&%N;F5L1FEL92!O8FIE8W0@<F5P
M<F5S96YT:6YG('1H92!014-,(&-H86YN96PL(&EF#0H@("`@("H@("`@("`@
M(&1E9F%U;'0@=F%L=65S(&%R92!N;W0@9&5S:7)E9"X@($]N;'D@=7-E9"!T
M:&4@=F5R>2!F:7)S="!T:6UE(&$@4$5!4@T*("`@("`J("`@("`@("!R97!O
M<VET;W)Y(&ES(&EN:71I86QI>F5D#0H@("`@("H-"B`@("`@*B!`86-C97-S
M('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(%!%05)?4F5G:7-T<GDH
M)'!E87)?:6YS=&%L;%]D:7(@/2!014%27TE.4U1!3$Q?1$E2+"`D<&5A<E]C
M:&%N;F5L(#T@9F%L<V4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<&5C;%]C:&%N;F5L(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!P87)E;G0Z
M.E!%05(H*3L-"B`@("`@("`@)&1S(#T@1$E214-43U)97U-%4$%2051/4CL-
M"B`@("`@("`@)'1H:7,M/FEN<W1A;&Q?9&ER(#T@)'!E87)?:6YS=&%L;%]D
M:7([#0H@("`@("`@("1T:&ES+3YC:&%N;F5L<V1I<B`]("1P96%R7VEN<W1A
M;&Q?9&ER+B1D<RXG+F-H86YN96QS)SL-"B`@("`@("`@)'1H:7,M/G-T871E
M9&ER(#T@)'!E87)?:6YS=&%L;%]D:7(N)&1S+B<N<F5G:7-T<GDG.PT*("`@
M("`@("`D=&AI<RT^9FEL96UA<"`@/2`D<&5A<E]I;G-T86QL7V1I<BXD9',N
M)RYF:6QE;6%P)SL-"B`@("`@("`@)'1H:7,M/FQO8VMF:6QE(#T@)'!E87)?
M:6YS=&%L;%]D:7(N)&1S+B<N;&]C:R<[#0H@("`@("`@("1T:&ES+3Y?<&5A
M<D-H86YN96P@/2`D<&5A<E]C:&%N;F5L.PT*("`@("`@("`D=&AI<RT^7W!E
M8VQ#:&%N;F5L(#T@)'!E8VQ?8VAA;FYE;#L-"B`@("`@("`@)'1H:7,M/E]C
M;VYF:6<@/2!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!H87-7<FET
M94%C8V5S<R@I#0H@("`@>PT*("`@("`@("!I9B`H(4!F:6QE7V5X:7-T<R@D
M=&AI<RT^:6YS=&%L;%]D:7(I*2![#0H@("`@("`@("`@("`D9&ER(#T@)'1H
M:7,M/FEN<W1A;&Q?9&ER.PT*("`@("`@("`@("`@=VAI;&4@*"1D:7(@)B8@
M)&1I<B`A/2`G+B<I('L-"B`@("`@("`@("`@("`@("`D9&ER(#T@9&ER;F%M
M92@D9&ER*3L@+R\@8V0@+BX-"B`@("`@("`@("`@("`@("!I9B`H)&1I<B`A
M/2`G+B<@)B8@0&9I;&5?97AI<W1S*"1D:7(I*2![#0H@("`@("`@("`@("`@
M("`@("`@(&EF("A`:7-?=W)I=&5A8FQE*"1D:7(I*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@0&ES7W=R:71E86)L92@D=&AI
M<RT^:6YS=&%L;%]D:7(I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=$-O
M;F9I9R@F)&-O;F9I9RD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?8V]N9FEG
M(#T@)B1C;VYF:6<[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7VEN:71I86QI
M>F5#:&%N;F5L1&ER<R@I#0H@("`@>PT*("`@("`@("!S=&%T:6,@)')U;FYI
M;F<@/2!F86QS93L-"B`@("`@("`@:68@*"$D<G5N;FEN9RD@>PT*("`@("`@
M("`@("`@)')U;FYI;F<@/2!T<G5E.PT*("`@("`@("`@("`@)&1S(#T@1$E2
M14-43U)97U-%4$%2051/4CL-"B`@("`@("`@("`@(&EF("@A:7-?9&ER*"1T
M:&ES+3YC:&%N;F5L<V1I<BD@?'P-"B`@("`@("`@("`@("`@("`@("%F:6QE
M7V5X:7-T<R@D=&AI<RT^8VAA;FYE;'-D:7(@+B`D9',@+B`G<&5A<BYP:'`N
M;F5T+G)E9R<I('Q\#0H@("`@("`@("`@("`@("`@("`A9FEL95]E>&ES=',H
M)'1H:7,M/F-H86YN96QS9&ER("X@)&1S("X@)W!E8VPN<&AP+FYE="YR96<G
M*2!\?`T*("`@("`@("`@("`@("`@("`@(69I;&5?97AI<W1S*"1T:&ES+3YC
M:&%N;F5L<V1I<B`N("1D<R`N("=?7W5R:2YR96<G*2D@>PT*("`@("`@("`@
M("`@("`@(&EF("@A9FEL95]E>&ES=',H)'1H:7,M/F-H86YN96QS9&ER("X@
M)&1S("X@)W!E87(N<&AP+FYE="YR96<G*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D<&5A<E]C:&%N;F5L(#T@)'1H:7,M/E]P96%R0VAA;FYE;#L-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<U]A*"1P96%R7V-H86YN96PL("=0
M14%27T-H86YN96Q&:6QE)RD@?'P@(21P96%R7V-H86YN96PM/G9A;&ED871E
M*"DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A8VQA<W-?97AI
M<W1S*"=014%27T-H86YN96Q&:6QE)RDI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O0VAA;FYE;$9I;&4N<&AP
M)SL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1P96%R7V-H86YN96P@/2!N97<@4$5!4E]#:&%N;F5L1FEL
M93L-"B`@("`@("`@("`@("`@("`@("`@("`@("1P96%R7V-H86YN96PM/G-E
M=$YA;64H)W!E87(N<&AP+FYE="<I.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)'!E87)?8VAA;FYE;"T^<V5T06QI87,H)W!E87(G*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1P96%R7V-H86YN96PM/G-E=%-E<G9E<B@G<&5A
M<BYP:'`N;F5T)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&5A<E]C
M:&%N;F5L+3YS9713=6UM87)Y*"=02%`@17AT96YS:6]N(&%N9"!!<'!L:6-A
M=&EO;B!297!O<VET;W)Y)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M<&5A<E]C:&%N;F5L+3YS971$969A=6QT4$5!4E!R;W1O8V]L<R@I.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)'!E87)?8VAA;FYE;"T^<V5T0F%S9552
M3"@G4D535#$N,"<L("=H='1P.B\O<&5A<BYP:'`N;F5T+W)E<W0O)RD[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D<&5A<E]C:&%N;F5L+3YS971"87-E
M55),*"=215-4,2XQ)RP@)VAT='`Z+R]P96%R+G!H<"YN970O<F5S="\G*3L-
M"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1P96%R7V-H86YN96PM/G-E=$YA;64H)W!E87(N<&AP+FYE
M="<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'!E87)?8VAA;FYE;"T^
M<V5T06QI87,H)W!E87(G*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`D<&5A<E]C:&%N;F5L+3YV86QI9&%T92@I.PT*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9$-H86YN96PH)'!E87)?
M8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&EF("@A9FEL95]E>&ES=',H)'1H:7,M/F-H86YN96QS9&ER("X@)&1S("X@
M)W!E8VPN<&AP+FYE="YR96<G*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M<&5C;%]C:&%N;F5L(#T@)'1H:7,M/E]P96-L0VAA;FYE;#L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<U]A*"1P96-L7V-H86YN96PL("=014%27T-H
M86YN96Q&:6QE)RD@?'P@(21P96-L7V-H86YN96PM/G9A;&ED871E*"DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=0
M14%27T-H86YN96Q&:6QE)RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!R97%U:7)E7V]N8V4@)U!%05(O0VAA;FYE;$9I;&4N<&AP)SL-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1P96-L7V-H86YN96P@/2!N97<@4$5!4E]#:&%N;F5L1FEL93L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1P96-L7V-H86YN96PM/G-E=$YA;64H
M)W!E8VPN<&AP+FYE="<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'!E
M8VQ?8VAA;FYE;"T^<V5T06QI87,H)W!E8VPG*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1P96-L7V-H86YN96PM/G-E=%-E<G9E<B@G<&5C;"YP:'`N
M;F5T)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&5C;%]C:&%N;F5L
M+3YS9713=6UM87)Y*"=02%`@17AT96YS:6]N($-O;6UU;FET>2!,:6)R87)Y
M)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&5C;%]C:&%N;F5L+3YS
M971$969A=6QT4$5!4E!R;W1O8V]L<R@I.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'!E8VQ?8VAA;FYE;"T^<V5T0F%S95523"@G4D535#$N,"<L("=H
M='1P.B\O<&5C;"YP:'`N;F5T+W)E<W0O)RD[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D<&5C;%]C:&%N;F5L+3YS971"87-E55),*"=215-4,2XQ)RP@
M)VAT='`Z+R]P96-L+G!H<"YN970O<F5S="\G*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1P96-L7V-H86YN96PM/G-E=%9A;&ED871I;VY086-K86=E
M*"=014%27U9A;&ED871O<E]014-,)RP@)S$N,"<I.PT*("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'!E
M8VQ?8VAA;FYE;"T^<V5T3F%M92@G<&5C;"YP:'`N;F5T)RD[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D<&5C;%]C:&%N;F5L+3YS971!;&EA<R@G<&5C
M;"<I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("1P96-L7V-H86YN96PM/G9A;&ED871E*"D[#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?861D0VAA;FYE;"@D<&5C;%]C:&%N;F5L*3L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"%F:6QE7V5X
M:7-T<R@D=&AI<RT^8VAA;FYE;'-D:7(@+B`D9',@+B`G7U]U<FDN<F5G)RDI
M('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%
M05)?0VAA;FYE;$9I;&4G*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E("=014%2+T-H86YN96Q&:6QE+G!H<"<[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)'!R:79A=&4@
M/2!N97<@4$5!4E]#:&%N;F5L1FEL93L-"B`@("`@("`@("`@("`@("`@("`@
M)'!R:79A=&4M/G-E=$YA;64H)U]?=7)I)RD[#0H@("`@("`@("`@("`@("`@
M("`@("1P<FEV871E+3YA9&1&=6YC=&EO;B@G>&UL<G!C)RP@)S$N,"<L("<J
M*BHJ)RD[#0H@("`@("`@("`@("`@("`@("`@("1P<FEV871E+3YS9713=6UM
M87)Y*"=0<V5U9&\M8VAA;FYE;"!F;W(@<W1A=&EC('!A8VMA9V5S)RD[#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861D0VAA;FYE;"@D<')I=F%T
M92D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<F5B=6EL9$9I;&5-87`H*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("1R=6YN:6YG(#T@9F%L<V4[#0H@("`@("`@('T-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!?:6YI=&EA;&EZ941I<G,H*0T*("`@('L-"B`@("`@("`@
M)&1S(#T@1$E214-43U)97U-%4$%2051/4CL-"B`@("`@("`@+R\@6%A8($-O
M;7!A=&EB:6QI='D@8V]D92!S:&]U;&0@8F4@<F5M;W9E9"!I;B!T:&4@9G5T
M=7)E#0H@("`@("`@("\O(')E;F%M92!A;&P@<F5G:7-T<GD@9FEL97,@:68@
M86YY('1O(&QO=V5R8V%S90T*("`@("`@("!I9B`H(4]37U=)3D1/5U,@)B8@
M)&AA;F1L92`]($!O<&5N9&ER*"1T:&ES+3YS=&%T961I<BDI('L-"B`@("`@
M("`@("`@("1D97-T(#T@)'1H:7,M/G-T871E9&ER("X@)&1S.PT*("`@("`@
M("`@("`@=VAI;&4@*&9A;'-E("$]/2`H)&9I;&4@/2!R96%D9&ER*"1H86YD
M;&4I*2D@>PT*("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7BXJ
M6T$M6ETN*EPN<F5G)"\G+"`D9FEL92DI('L-"B`@("`@("`@("`@("`@("`@
M("`@<F5N86UE*"1D97-T("X@)&9I;&4L("1D97-T("X@<W1R=&]L;W=E<B@D
M9FEL92DI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&-L;W-E9&ER*"1H86YD;&4I.PT*("`@("`@("!]#0H@("`@
M("`@("1T:&ES+3Y?:6YI=&EA;&EZ94-H86YN96Q$:7)S*"D[#0H@("`@("`@
M(&EF("@A9FEL95]E>&ES=',H)'1H:7,M/F9I;&5M87`I*2![#0H@("`@("`@
M("`@("`D=&AI<RT^7W)E8G5I;&1&:6QE36%P*"D[#0H@("`@("`@('T-"B`@
M("`@("`@)'1H:7,M/E]I;FET:6%L:7IE1&5P1$(H*3L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!?:6YI=&EA;&EZ941E<$1"*"D-"B`@("![#0H@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/E]D97!E;F1E;F-Y1$(I*2![#0H@("`@("`@
M("`@("!S=&%T:6,@)&EN:71I86QI>FEN9R`](&9A;'-E.PT*("`@("`@("`@
M("`@:68@*"$D:6YI=&EA;&EZ:6YG*2![#0H@("`@("`@("`@("`@("`@)&EN
M:71I86QI>FEN9R`]('1R=64[#0H@("`@("`@("`@("`@("`@:68@*"$D=&AI
M<RT^7V-O;F9I9RD@>R`O+R!N979E<B!U<V5D/PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H3U-?5TE.1$]74RD@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)&9I;&4@/2`G<&5A<BYI;FDG.PT*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`G+G!E
M87)R8R<[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]C;VYF:6<@/2`F;F5W(%!%05)?0V]N9FEG*"1T:&ES
M+3YS=&%T961I<B`N($1)4D5#5$]265]315!!4D%43U(@+@T*("`@("`@("`@
M("`@("`@("`@("`@("`@)&9I;&4I.PT*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V-O;F9I9RT^<V5T4F5G:7-T<GDH)'1H:7,I.PT*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V-O;F9I9RT^<V5T*"=P:'!?9&ER)RP@)'1H
M:7,M/FEN<W1A;&Q?9&ER*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]D97!E;F1E;F-Y1$(@/2`F4$5!4E]$97!E;F1E
M;F-Y1$(Z.G-I;F=L971O;B@D=&AI<RT^7V-O;F9I9RD[#0H@("`@("`@("`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)'1H:7,M/E]D97!E;F1E;F-Y1$(I
M*2![#0H@("`@("`@("`@("`@("`@("`@("\O(&%T=&5M<'0@=&\@<F5C;W9E
M<B!B>2!R96UO=FEN9R!T:&4@9&5P(&1B#0H@("`@("`@("`@("`@("`@("`@
M($!U;FQI;FLH)'1H:7,M/E]C;VYF:6<M/F=E="@G<&AP7V1I<B<L(&YU;&PL
M("=P96%R+G!H<"YN970G*2`N#0H@("`@("`@("`@("`@("`@("`@("`@("!$
M25)%0U1/4EE?4T5005)!5$]2("X@)RYD97!D8B<I.PT*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V1E<&5N9&5N8WE$0B`]("9014%27T1E<&5N9&5N
M8WE$0CHZ<VEN9VQE=&]N*"1T:&ES+3Y?8V]N9FEG*3L-"B`@("`@("`@("`@
M("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'1H:7,M/E]D97!E;F1E;F-Y
M1$(I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!E8VAO("1T:&ES+3Y?
M9&5P96YD96YC>41"+3YG971-97-S86=E*"D[#0H@("`@("`@("`@("`@("`@
M("`@("`@("!D:64H)U5N<F5C;W9E<F%B;&4@97)R;W(G*3L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`D:6YI=&EA;&EZ:6YG(#T@9F%L<V4[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("!]#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&1E<W1R
M=6-T;W(-"@T*("`@("\J*@T*("`@("`J(%!%05)?4F5G:7-T<GD@9&5S=')U
M8W1O<BX@($UA:V5S('-U<F4@;F\@;&]C:W,@87)E(&9O<F=O='1E;BX-"B`@
M("`@*@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(%]014%27U)E9VES=')Y*"D-"B`@("![#0H@("`@("`@('!A<F5N
M=#HZ7U!%05(H*3L-"B`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1T:&ES+3YL
M;V-K7V9P*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]U;FQO8VLH*3L-"B`@
M("`@("`@?0T*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]A
M<W-E<G13=&%T941I<B@I#0H-"B`@("`O*BH-"B`@("`@*B!-86ME('-U<F4@
M=&AE(&1I<F5C=&]R>2!W:&5R92!W92!K965P(')E9VES=')Y(&9I;&5S(&5X
M:7-T<RX-"B`@("`@*@T*("`@("`J($!R971U<FX@8F]O;"!44E5%(&EF(&1I
M<F5C=&]R>2!E>&ES=',L($9!3%-%(&EF(&ET(&-O=6QD(&YO="!B90T*("`@
M("`J(&-R96%T960-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(%]A<W-E<G13=&%T941I<B@D8VAA;FYE
M;"`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"1C:&%N;F5L("8F("1T
M:&ES+3Y?9V5T0VAA;FYE;$9R;VU!;&EA<R@D8VAA;FYE;"D@(3T@)W!E87(N
M<&AP+FYE="<I('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V%S<V5R
M=$-H86YN96Q3=&%T941I<B@D8VAA;FYE;"D[#0H@("`@("`@('T-"B`@("`@
M("`@<W1A=&EC("1I;FET(#T@9F%L<V4[#0H@("`@("`@(&EF("@A0&ES7V1I
M<B@D=&AI<RT^<W1A=&5D:7(I*2![#0H@("`@("`@("`@("!I9B`H(21T:&ES
M+3YH87-7<FET94%C8V5S<R@I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E("=3>7-T96TN<&AP)SL-"B`@("`@("`@("`@(&EF("@A4WES=&5M.CIM
M:V1I<BAA<G)A>2@G+7`G+"`D=&AI<RT^<W1A=&5D:7(I*2D@>PT*("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8V]U;&0@;F]T
M(&-R96%T92!D:7)E8W1O<GD@)WLD=&AI<RT^<W1A=&5D:7)])R(I.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)&EN:70@/2!T<G5E.PT*("`@("`@
M("!]#0H@("`@("`@("1D<R`]($1)4D5#5$]265]315!!4D%43U([#0H@("`@
M("`@(&EF("@A0&ES7V1I<B@D=&AI<RT^8VAA;FYE;'-D:7(I('Q\#0H@("`@
M("`@("`@("`@("%F:6QE7V5X:7-T<R@D=&AI<RT^8VAA;FYE;'-D:7(@+B`D
M9',@+B`G<&5A<BYP:'`N;F5T+G)E9R<I('Q\#0H@("`@("`@("`@("`@("%F
M:6QE7V5X:7-T<R@D=&AI<RT^8VAA;FYE;'-D:7(@+B`D9',@+B`G<&5C;"YP
M:'`N;F5T+G)E9R<I('Q\#0H@("`@("`@("`@("`@("%F:6QE7V5X:7-T<R@D
M=&AI<RT^8VAA;FYE;'-D:7(@+B`D9',@+B`G7U]U<FDN<F5G)RDI('L-"B`@
M("`@("`@("`@("1I;FET(#T@=')U93L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H)&EN:70I('L-"B`@("`@("`@("`@('-T871I8R`D<G5N;FEN9R`](&9A
M;'-E.PT*("`@("`@("`@("`@:68@*"$D<G5N;FEN9RD@>PT*("`@("`@("`@
M("`@("`@("1R=6YN:6YG(#T@=')U93L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7VEN:71I86QI>F5$:7)S*"D[#0H@("`@("`@("`@("`@("`@)')U;FYI
M;F<@/2!F86QS93L-"B`@("`@("`@("`@("`@("`D:6YI="`](&9A;'-E.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M)'1H:7,M/E]I;FET:6%L:7IE1&5P1$(H*3L-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@7V%S<V5R=$-H86YN96Q3=&%T941I<B@I#0H-"B`@("`O*BH-"B`@("`@
M*B!-86ME('-U<F4@=&AE(&1I<F5C=&]R>2!W:&5R92!W92!K965P(')E9VES
M=')Y(&9I;&5S(&5X:7-T<R!F;W(@82!N;VXM<W1A;F1A<F0@8VAA;FYE;"X-
M"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@8VAA;FYE;"!N86UE#0H@
M("`@("H@0')E='5R;B!B;V]L(%12544@:68@9&ER96-T;W)Y(&5X:7-T<RP@
M1D%,4T4@:68@:70@8V]U;&0@;F]T(&)E#0H@("`@("H@8W)E871E9`T*("`@
M("`J#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@7V%S<V5R=$-H86YN96Q3=&%T941I<B@D8VAA;FYE;"D-"B`@("![
M#0H@("`@("`@("1D<R`]($1)4D5#5$]265]315!!4D%43U([#0H@("`@("`@
M(&EF("@A)&-H86YN96P@?'P@)'1H:7,M/E]G971#:&%N;F5L1G)O;4%L:6%S
M*"1C:&%N;F5L*2`]/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@("`@("`@
M:68@*"%F:6QE7V5X:7-T<R@D=&AI<RT^8VAA;FYE;'-D:7(@+B`D9',@+B`G
M<&5A<BYP:'`N;F5T+G)E9R<I*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/E]I;FET:6%L:7IE0VAA;FYE;$1I<G,H*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7V%S<V5R=%-T871E1&ER*"1C:&%N
M;F5L*3L-"B`@("`@("`@?0T*("`@("`@("`D8VAA;FYE;$1I<B`]("1T:&ES
M+3Y?8VAA;FYE;$1I<F5C=&]R>4YA;64H)&-H86YN96PI.PT*("`@("`@("!I
M9B`H(6ES7V1I<B@D=&AI<RT^8VAA;FYE;'-D:7(I('Q\#0H@("`@("`@("`@
M("`@("%F:6QE7V5X:7-T<R@D=&AI<RT^8VAA;FYE;'-D:7(@+B`D9',@+B`G
M<&5A<BYP:'`N;F5T+G)E9R<I*2![#0H@("`@("`@("`@("`D=&AI<RT^7VEN
M:71I86QI>F5#:&%N;F5L1&ER<R@I.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("@A0&ES7V1I<B@D8VAA;FYE;$1I<BDI('L-"B`@("`@("`@("`@(&EF("@A
M)'1H:7,M/FAA<U=R:71E06-C97-S*"DI('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)U-Y<W1E;2YP:'`G.PT*("`@("`@("`@("`@:68@*"%3>7-T
M96TZ.FUK9&ER*&%R<F%Y*"<M<"<L("1C:&%N;F5L1&ER*2DI('L-"B`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F-O=6QD(&YO
M="!C<F5A=&4@9&ER96-T;W)Y("<B("X@)&-H86YN96Q$:7(@+@T*("`@("`@
M("`@("`@("`@("`@("`B)R(I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!?87-S97)T0VAA;FYE;$1I<B@I#0H-"B`@("`O*BH-"B`@
M("`@*B!-86ME('-U<F4@=&AE(&1I<F5C=&]R>2!W:&5R92!W92!K965P(')E
M9VES=')Y(&9I;&5S(&9O<B!C:&%N;F5L<R!E>&ES=',-"B`@("`@*@T*("`@
M("`J($!R971U<FX@8F]O;"!44E5%(&EF(&1I<F5C=&]R>2!E>&ES=',L($9!
M3%-%(&EF(&ET(&-O=6QD(&YO="!B90T*("`@("`J(&-R96%T960-"B`@("`@
M*@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T
M:6]N(%]A<W-E<G1#:&%N;F5L1&ER*"D-"B`@("![#0H@("`@("`@(&EF("@A
M0&ES7V1I<B@D=&AI<RT^8VAA;FYE;'-D:7(I*2![#0H@("`@("`@("`@("!I
M9B`H(21T:&ES+3YH87-7<FET94%C8V5S<R@I*2![#0H@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E("=3>7-T96TN<&AP)SL-"B`@("`@("`@("`@(&EF("@A
M4WES=&5M.CIM:V1I<BAA<G)A>2@G+7`G+"`D=&AI<RT^8VAA;FYE;'-D:7(I
M*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B8V]U;&0@;F]T(&-R96%T92!D:7)E8W1O<GD@)WLD=&AI<RT^8VAA;FYE
M;'-D:7)])R(I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(&EF("@A0&ES7V1I<B@D=&AI<RT^8VAA;FYE;'-D:7(@+B!$25)%0U1/4EE?
M4T5005)!5$]2("X@)RYA;&EA<R<I*2![#0H@("`@("`@("`@("!I9B`H(21T
M:&ES+3YH87-7<FET94%C8V5S<R@I*2![#0H@("`@("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E("=3>7-T96TN<&AP)SL-"B`@("`@("`@("`@(&EF("@A4WES=&5M
M.CIM:V1I<BAA<G)A>2@G+7`G+"`D=&AI<RT^8VAA;FYE;'-D:7(@+B!$25)%
M0U1/4EE?4T5005)!5$]2("X@)RYA;&EA<R<I*2D@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8V]U;&0@;F]T(&-R96%T
M92!D:7)E8W1O<GD@)WLD=&AI<RT^8VAA;FYE;'-D:7)]+RYA;&EA<R<B*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@=')U
M93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7W!A8VMA9V5&
M:6QE3F%M92@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(&YA;64@;V8@
M=&AE(&9I;&4@=VAE<F4@9&%T82!F;W(@82!G:79E;B!P86-K86=E(&ES('-T
M;W)E9"X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@8VAA;FYE;"!N
M86UE+"!O<B!F86QS92!I9B!T:&ES(&ES(&$@4$5!4B!P86-K86=E#0H@("`@
M("H@0'!A<F%M('-T<FEN9R!P86-K86=E(&YA;64-"B`@("`@*@T*("`@("`J
M($!R971U<FX@<W1R:6YG(')E9VES=')Y(&9I;&4@;F%M90T*("`@("`J#0H@
M("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?
M<&%C:V%G949I;&5.86UE*"1P86-K86=E+"`D8VAA;FYE;"`](&9A;'-E*0T*
M("`@('L-"B`@("`@("`@:68@*"1C:&%N;F5L("8F("1T:&ES+3Y?9V5T0VAA
M;FYE;$9R;VU!;&EA<R@D8VAA;FYE;"D@(3T@)W!E87(N<&AP+FYE="<I('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V-H86YN96Q$:7)E8W1O<GE.
M86UE*"1C:&%N;F5L*2`N($1)4D5#5$]265]315!!4D%43U(@+@T*("`@("`@
M("`@("`@("`@('-T<G1O;&]W97(H)'!A8VMA9V4I("X@)RYR96<G.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B`D=&AI<RT^<W1A=&5D:7(@+B!$25)%
M0U1/4EE?4T5005)!5$]2("X@<W1R=&]L;W=E<B@D<&%C:V%G92D@+B`G+G)E
M9R<[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]C:&%N;F5L
M1FEL94YA;64H*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!N86UE(&]F
M('1H92!F:6QE('=H97)E(&1A=&$@9F]R(&$@9VEV96X@8VAA;FYE;"!I<R!S
M=&]R960N#0H@("`@("H@0'!A<F%M('-T<FEN9R!C:&%N;F5L(&YA;64-"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R!R96=I<W1R>2!F:6QE(&YA;64-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!?8VAA;FYE;$9I;&5.86UE*"1C:&%N;F5L+"`D
M;F]A;&EA<V5S(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H(21N;V%L
M:6%S97,I('L-"B`@("`@("`@("`@(&EF("A`9FEL95]E>&ES=',H)'1H:7,M
M/E]G971#:&%N;F5L06QI87-&:6QE3F%M92@D8VAA;FYE;"DI*2![#0H@("`@
M("`@("`@("`@("`@)&-H86YN96P@/2!I;7!L;V1E*"<G+"!F:6QE*"1T:&ES
M+3Y?9V5T0VAA;FYE;$%L:6%S1FEL94YA;64H)&-H86YN96PI*2D[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1T:&ES+3YC
M:&%N;F5L<V1I<B`N($1)4D5#5$]265]315!!4D%43U(@+B!S=')?<F5P;&%C
M92@G+R<L("=?)RP-"B`@("`@("`@("`@('-T<G1O;&]W97(H)&-H86YN96PI
M*2`N("<N<F5G)SL-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@
M9V5T0VAA;FYE;$%L:6%S1FEL94YA;64H*0T*#0H@("`@+RHJ#0H@("`@("H@
M0'!A<F%M('-T<FEN9PT*("`@("`J($!R971U<FX@<W1R:6YG#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@7V=E=$-H86YN96Q!;&EA<T9I;&5.86UE*"1A;&EA
M<RD-"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^8VAA;FYE;'-D:7(@
M+B!$25)%0U1/4EE?4T5005)!5$]2("X@)RYA;&EA<R<@+@T*("`@("`@("`@
M("`@("!$25)%0U1/4EE?4T5005)!5$]2("X@<W1R7W)E<&QA8V4H)R\G+"`G
M7R<L('-T<G1O;&]W97(H)&%L:6%S*2D@+B`G+G1X="<[#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(%]G971#:&%N;F5L1G)O;4%L:6%S*"D-
M"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@;F%M92!O9B!A(&-H86YN96P@
M9G)O;2!I=',@86QI87,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?9V5T0VAA
M;FYE;$9R;VU!;&EA<R@D8VAA;FYE;"D-"B`@("![#0H@("`@("`@(&EF("@A
M)'1H:7,M/E]C:&%N;F5L17AI<W1S*"1C:&%N;F5L*2D@>PT*("`@("`@("`@
M("`@:68@*"1C:&%N;F5L(#T]("=P96%R+G!H<"YN970G*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N("=P96%R+G!H<"YN970G.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*"1C:&%N;F5L(#T]("=P96-L+G!H<"YN970G
M*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("=P96-L+G!H<"YN970G.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1C:&%N;F5L(#T]("=?
M7W5R:2<I('L-"B`@("`@("`@("`@("`@("!R971U<FX@)U]?=7)I)SL-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@?0T*("`@("`@("`D8VAA;FYE;"`]('-T<G1O;&]W97(H)&-H86YN96PI
M.PT*("`@("`@("!I9B`H9FEL95]E>&ES=',H)'1H:7,M/E]G971#:&%N;F5L
M06QI87-&:6QE3F%M92@D8VAA;FYE;"DI*2![#0H@("`@("`@("`@("`O+R!T
M<F%N<VQA=&4@86X@86QI87,@=&\@86X@86-T=6%L(&-H86YN96P-"B`@("`@
M("`@("`@(')E='5R;B!I;7!L;V1E*"<G+"!F:6QE*"1T:&ES+3Y?9V5T0VAA
M;FYE;$%L:6%S1FEL94YA;64H)&-H86YN96PI*2D[#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("!R971U<FX@)&-H86YN96P[#0H@("`@("`@('T-
M"B`@("!]("`@(`T*("`@("\O('U]?0T*("`@("\O('M[>R!?9V5T0VAA;FYE
M;$9R;VU!;&EA<R@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(&%L:6%S
M(&]F(&$@8VAA;FYE;"!F<F]M(&ET<R!A;&EA<R!O<B!I=',@;F%M90T*("`@
M("`J+PT*("`@(&9U;F-T:6]N(%]G971!;&EA<R@D8VAA;FYE;"D-"B`@("![
M#0H@("`@("`@(&EF("@A)'1H:7,M/E]C:&%N;F5L17AI<W1S*"1C:&%N;F5L
M*2D@>PT*("`@("`@("`@("`@:68@*"1C:&%N;F5L(#T]("=P96%R+G!H<"YN
M970G*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("=P96%R)SL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("@D8VAA;FYE;"`]/2`G<&5C;"YP
M:'`N;F5T)RD@>PT*("`@("`@("`@("`@("`@(')E='5R;B`G<&5C;"<[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@('T-"B`@("`@("`@)&-H86YN96P@/2`D=&AI<RT^7V=E=$-H86YN96PH
M)&-H86YN96PI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VAA;FYE
M;"DI('L-"B`@("`@("`@("`@(')E='5R;B`D8VAA;FYE;#L-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@)&-H86YN96PM/F=E=$%L:6%S*"D[#0H@("`@
M?2`@("`-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7V-H86YN96Q$:7)E8W1O
M<GE.86UE*"D-"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@;F%M92!O9B!T
M:&4@9FEL92!W:&5R92!D871A(&9O<B!A(&=I=F5N('!A8VMA9V4@:7,@<W1O
M<F5D+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R!C:&%N;F5L(&YA
M;64L(&]R(&9A;'-E(&EF('1H:7,@:7,@82!014%2('!A8VMA9V4-"B`@("`@
M*B!`<&%R86T@<W1R:6YG('!A8VMA9V4@;F%M90T*("`@("`J#0H@("`@("H@
M0')E='5R;B!S=')I;F<@<F5G:7-T<GD@9FEL92!N86UE#0H@("`@("H-"B`@
M("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(%]C
M:&%N;F5L1&ER96-T;W)Y3F%M92@D8VAA;FYE;"D-"B`@("![#0H@("`@("`@
M(&EF("@A)&-H86YN96P@?'P@)'1H:7,M/E]G971#:&%N;F5L1G)O;4%L:6%S
M*"1C:&%N;F5L*2`]/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YS=&%T961I<CL-"B`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("1C:"`]("1T:&ES+3Y?9V5T0VAA;FYE;$9R;VU!;&EA<R@D
M8VAA;FYE;"D[#0H@("`@("`@("`@("!I9B`H(21C:"D@>PT*("`@("`@("`@
M("`@("`@("1C:"`]("1C:&%N;F5L.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YS=&%T961I<B`N($1)4D5#5$]265]315!!
M4D%43U(@+B!S=')T;VQO=V5R*"<N8VAA;FYE;"XG("X-"B`@("`@("`@("`@
M("`@("!S=')?<F5P;&%C92@G+R<L("=?)RP@)&-H*2D[#0H@("`@("`@('T-
M"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7V]P96Y086-K86=E
M1FEL92@I#0H-"B`@("!F=6YC=&EO;B!?;W!E;E!A8VMA9V5&:6QE*"1P86-K
M86=E+"`D;6]D92P@)&-H86YN96P@/2!F86QS92D-"B`@("![#0H@("`@("`@
M(&EF("@A)'1H:7,M/E]A<W-E<G13=&%T941I<B@D8VAA;FYE;"DI('L-"B`@
M("`@("`@("`@(')E='5R;B!N=6QL.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("@A:6Y?87)R87DH)&UO9&4L(&%R<F%Y*"=R)RP@)W)B)RDI("8F("$D=&AI
M<RT^:&%S5W)I=&5!8V-E<W,H*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&YU
M;&P[#0H@("`@("`@('T-"B`@("`@("`@)&9I;&4@/2`D=&AI<RT^7W!A8VMA
M9V5&:6QE3F%M92@D<&%C:V%G92P@)&-H86YN96PI.PT*("`@("`@("`D9G`@
M/2!`9F]P96XH)&9I;&4L("1M;V1E*3L-"B`@("`@("`@:68@*"$D9G`I('L-
M"B`@("`@("`@("`@(')E='5R;B!N=6QL.PT*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B`D9G`[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[
M(%]C;&]S95!A8VMA9V5&:6QE*"D-"@T*("`@(&9U;F-T:6]N(%]C;&]S95!A
M8VMA9V5&:6QE*"1F<"D-"B`@("![#0H@("`@("`@(&9C;&]S92@D9G`I.PT*
M("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!?;W!E;E!A8VMA9V5&
M:6QE*"D-"@T*("`@(&9U;F-T:6]N(%]O<&5N0VAA;FYE;$9I;&4H)&-H86YN
M96PL("1M;V1E*0T*("`@('L-"B`@("`@("`@:68@*"$D=&AI<RT^7V%S<V5R
M=$-H86YN96Q$:7(H*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&YU;&P[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"%I;E]A<G)A>2@D;6]D92P@87)R87DH
M)W(G+"`G<F(G*2D@)B8@(21T:&ES+3YH87-7<FET94%C8V5S<R@I*2![#0H@
M("`@("`@("`@("!R971U<FX@;G5L;#L-"B`@("`@("`@?0T*("`@("`@("`D
M9FEL92`]("1T:&ES+3Y?8VAA;FYE;$9I;&5.86UE*"1C:&%N;F5L*3L-"B`@
M("`@("`@)&9P(#T@0&9O<&5N*"1F:6QE+"`D;6]D92D[#0H@("`@("`@(&EF
M("@A)&9P*2![#0H@("`@("`@("`@("!R971U<FX@;G5L;#L-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@)&9P.PT*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!?8VQO<V5086-K86=E1FEL92@I#0H-"B`@("!F=6YC=&EO
M;B!?8VQO<V5#:&%N;F5L1FEL92@D9G`I#0H@("`@>PT*("`@("`@("!F8VQO
M<V4H)&9P*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7W)E
M8G5I;&1&:6QE36%P*"D-"@T*("`@(&9U;F-T:6]N(%]R96)U:6QD1FEL94UA
M<"@I#0H@("`@>PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E])
M;G-T86QL97)?4F]L92<I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)U!%05(O26YS=&%L;&5R+U)O;&4N<&AP)SL-"B`@("`@("`@?0T*("`@("`@
M("`D8VAA;FYE;',@/2`D=&AI<RT^7VQI<W1!;&Q086-K86=E<R@I.PT*("`@
M("`@("`D9FEL97,@/2!A<G)A>2@I.PT*("`@("`@("!F;W)E86-H("@D8VAA
M;FYE;',@87,@)&-H86YN96P@/3X@)'!A8VMA9V5S*2![#0H@("`@("`@("`@
M("!F;W)E86-H("@D<&%C:V%G97,@87,@)'!A8VMA9V4I('L-"B`@("`@("`@
M("`@("`@("`D=F5R<VEO;B`]("1T:&ES+3Y?<&%C:V%G94EN9F\H)'!A8VMA
M9V4L("=V97)S:6]N)RP@)&-H86YN96PI.PT*("`@("`@("`@("`@("`@("1F
M:6QE;&ES="`]("1T:&ES+3Y?<&%C:V%G94EN9F\H)'!A8VMA9V4L("=F:6QE
M;&ES="<L("1C:&%N;F5L*3L-"B`@("`@("`@("`@("`@("!I9B`H(6ES7V%R
M<F%Y*"1F:6QE;&ES="DI('L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN
M=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1F:6QE;&ES="!A<R`D;F%M92`]/B`D871T<G,I('L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1A='1R<ULG871T<FEB<R==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&%T=')S(#T@)&%T=')S6R=A='1R
M:6)S)UT[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@+R\@:70@:7,@<&]S<VEB;&4@9F]R(&-O;F9L:6-T:6YG('!A8VMA
M9V5S(&EN(&1I9F9E<F5N="!C:&%N;F5L<R!T;PT*("`@("`@("`@("`@("`@
M("`@("`O+R!C;VYF;&EC="!W:71H(&1A=&$@9FEL97,O9&]C(&9I;&5S#0H@
M("`@("`@("`@("`@("`@("`@(&EF("@D;F%M92`]/2`G9&ER=')E92<I('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M871T<G-;)W)O;&4G72D@)B8@(6EN7V%R<F%Y*"1A='1R<ULG<F]L92==+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("!014%27TEN<W1A;&QE<E]2;VQE
M.CIG971);G-T86QL86)L95)O;&5S*"DI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!T:&5S92!A<F4@;F]T(&EN<W1A;&QE9`T*("`@("`@("`@
M("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A='1R<ULG<F]L
M92==*2`F)B`A:6Y?87)R87DH)&%T=')S6R=R;VQE)UTL#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@(%!%05)?26YS=&%L;&5R7U)O;&4Z.F=E=$)A<V5I
M;G-T86QL4F]L97,H*2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1A
M='1R<ULG8F%S96EN<W1A;&QD:7(G72`]("1P86-K86=E.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M871T<G-;)V)A<V5I;G-T86QL9&ER)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D9FEL92`]("1A='1R<ULG8F%S96EN<W1A;&QD:7(G72Y$25)%
M0U1/4EE?4T5005)!5$]2+B1N86UE.PT*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D;F%M
M93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`D9FEL92`]('!R96=?<F5P;&%C92@G+%XO*RPG+"`G)RP@)&9I;&4I.PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H)&-H86YN96P@(3T@)W!E87(N<&AP
M+FYE="<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1F:6QE<ULD871T
M<G-;)W)O;&4G75U;)&9I;&5=(#T@87)R87DH<W1R=&]L;W=E<B@D8VAA;FYE
M;"DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R=&]L;W=E<B@D
M<&%C:V%G92DI.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)&9I;&5S6R1A='1R<ULG<F]L92==75LD
M9FEL95T@/2!S=')T;VQO=V5R*"1P86-K86=E*3L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("`D=&AI<RT^7V%S<V5R=%-T871E1&ER*"D[#0H@
M("`@("`@(&EF("@A)'1H:7,M/FAA<U=R:71E06-C97-S*"DI('L-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D9G`@
M/2!`9F]P96XH)'1H:7,M/F9I;&5M87`L("=W8B<I.PT*("`@("`@("!I9B`H
M(21F<"D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]
M#0H@("`@("`@("1T:&ES+3YF:6QE;6%P7V-A8VAE(#T@)&9I;&5S.PT*("`@
M("`@("!F=W)I=&4H)&9P+"!S97)I86QI>F4H)&9I;&5S*2D[#0H@("`@("`@
M(&9C;&]S92@D9G`I.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7W)E861&:6QE36%P*"D-"@T*("`@
M(&9U;F-T:6]N(%]R96%D1FEL94UA<"@I#0H@("`@>PT*("`@("`@("`D9G`@
M/2!`9F]P96XH)'1H:7,M/F9I;&5M87`L("=R)RD[#0H@("`@("`@(&EF("@A
M)&9P*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M)U!%05)?4F5G:7-T<GDZ(&-O=6QD(&YO="!O<&5N(&9I;&5M87`@(B<@+B`D
M=&AI<RT^9FEL96UA<"`N("<B)RP@4$5!4E]214=)4U1265]%4E)/4E]&24Q%
M+"!N=6QL+"!N=6QL+"`D<&AP7V5R<F]R;7-G*3L-"B`@("`@("`@?0T*("`@
M("`@("!C;&5A<G-T871C86-H92@I.PT*("`@("`@("`D<G0@/2!G971?;6%G
M:6-?<75O=&5S7W)U;G1I;64H*3L-"B`@("`@("`@<V5T7VUA9VEC7W%U;W1E
M<U]R=6YT:6UE*#`I.PT*("`@("`@("`D9G-I>F4@/2!F:6QE<VEZ92@D=&AI
M<RT^9FEL96UA<"D[#0H@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I
M;&5?9V5T7V-O;G1E;G1S)RDI('L-"B`@("`@("`@("`@(&9C;&]S92@D9G`I
M.PT*("`@("`@("`@("`@)&1A=&$@/2!F:6QE7V=E=%]C;VYT96YT<R@D=&AI
M<RT^9FEL96UA<"D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M9&%T82`](&9R96%D*"1F<"P@)&9S:7IE*3L-"B`@("`@("`@("`@(&9C;&]S
M92@D9G`I.PT*("`@("`@("!]#0H@("`@("`@('-E=%]M86=I8U]Q=6]T97-?
M<G5N=&EM92@D<G0I.PT*("`@("`@("`D=&UP(#T@=6YS97)I86QI>F4H)&1A
M=&$I.PT*("`@("`@("!I9B`H(21T;7`@)B8@)&9S:7IE(#X@-RD@>PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=014%27U)E9VES
M=')Y.B!I;G9A;&ED(&9I;&5M87`@9&%T82<L(%!%05)?4D5'25-44EE?15)2
M3U)?1D]234%4+"!N=6QL+"!N=6QL+"`D9&%T82D[#0H@("`@("`@('T-"B`@
M("`@("`@)'1H:7,M/F9I;&5M87!?8V%C:&4@/2`D=&UP.PT*("`@("`@("!R
M971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@
M7VQO8VLH*0T*#0H@("`@+RHJ#0H@("`@("H@3&]C:R!T:&4@<F5G:7-T<GDN
M#0H@("`@("H-"B`@("`@*B!`<&%R86T@:6YT96=E<B!L;V-K(&UO9&4L(&]N
M92!O9B!,3T-+7T58+"!,3T-+7U-((&]R($Q/0TM?54XN#0H@("`@("H@("`@
M("`@("`@("`@("`@4V5E(&9L;V-K(&UA;G5A;"!F;W(@;6]R92!I;F9O<FUA
M=&EO;BX-"B`@("`@*@T*("`@("`J($!R971U<FX@8F]O;"!44E5%(&]N('-U
M8V-E<W,L($9!3%-%(&EF(&QO8VMI;F<@9F%I;&5D+"!O<B!A#0H@("`@("H@
M("`@("`@("`@("`@(%!%05(@97)R;W(@:68@<V]M92!O=&AE<B!E<G)O<B!O
M8V-U<G,@*'-U8V@@87,@=&AE#0H@("`@("H@("`@("`@("`@("`@(&QO8VL@
M9FEL92!N;W0@8F5I;F<@=W)I=&%B;&4I+@T*("`@("`J#0H@("`@("H@0&%C
M8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7VQO8VLH)&UO
M9&4@/2!,3T-+7T58*0T*("`@('L-"B`@("`@("`@:68@*"%E<F5G:2@G5VEN
M9&]W<R`Y)RP@<&AP7W5N86UE*"DI*2![#0H@("`@("`@("`@("!I9B`H)&UO
M9&4@(3T@3$]#2U]53B`F)B!I<U]R97-O=7)C92@D=&AI<RT^;&]C:U]F<"DI
M('L-"B`@("`@("`@("`@("`@("`O+R!86%@@9&]E<R!N;W0@8VAE8VL@='EP
M92!O9B!L;V-K("A,3T-+7U-(+TQ/0TM?15@I#0H@("`@("`@("`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M(21T:&ES+3Y?87-S97)T4W1A=&5$:7(H*2D@>PT*("`@("`@("`@("`@("`@
M(&EF("@D;6]D92`]/2!,3T-+7T58*2![#0H@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G4F5G:7-T<GD@9&ER96-T;W)Y
M(&ES(&YO="!W<FET96%B;&4@8GD@=&AE(&-U<G)E;G0@=7-E<B<I.PT*("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1O<&5N7VUO9&4@/2`G=R<[#0H@("`@("`@("`@("`O
M+R!86%@@4&5O<&QE(')E<&]R=&5D('!R;V)L96US('=I=&@@3$]#2U]32"!A
M;F0@)W<G#0H@("`@("`@("`@("!I9B`H)&UO9&4@/3T]($Q/0TM?4T@@?'P@
M)&UO9&4@/3T]($Q/0TM?54XI('L-"B`@("`@("`@("`@("`@("!I9B`H0"%I
M<U]F:6QE*"1T:&ES+3YL;V-K9FEL92DI('L-"B`@("`@("`@("`@("`@("`@
M("`@=&]U8V@H)'1H:7,M/FQO8VMF:6QE*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)&]P96Y?;6]D92`]("=R)SL-"B`@("`@("`@
M("`@('T-"@T*("`@("`@("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^
M;&]C:U]F<"DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]C:U]F<"`]
M($!F;W!E;B@D=&AI<RT^;&]C:V9I;&4L("1O<&5N7VUO9&4I.PT*("`@("`@
M("`@("`@?0T*#0H@("`@("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1T:&ES
M+3YL;V-K7V9P*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@B8V]U;&0@;F]T(&-R96%T92!L;V-K(&9I;&4B("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*&ES<V5T
M*"1P:'!?97)R;W)M<V<I(#\@(CH@(B`N("1P:'!?97)R;W)M<V<@.B`B(BDI
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"$H:6YT*69L;V-K
M*"1T:&ES+3YL;V-K7V9P+"`D;6]D92DI('L-"B`@("`@("`@("`@("`@("!S
M=VET8V@@*"1M;V1E*2![#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@3$]#
M2U]32#H@)'-T<B`]("=S:&%R960G.R`@("!B<F5A:SL-"B`@("`@("`@("`@
M("`@("`@("`@8V%S92!,3T-+7T58.B`D<W1R(#T@)V5X8VQU<VEV92<[(&)R
M96%K.PT*("`@("`@("`@("`@("`@("`@("!C87-E($Q/0TM?54XZ("1S='(@
M/2`G=6YL;V-K)SL@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@(&1E
M9F%U;'0Z("`@("`@)'-T<B`]("=U;FMN;W=N)SL@("!B<F5A:SL-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*")C;W5L9"!N;W0@86-Q=6ER92`D<W1R(&QO8VL@*"1T:&ES
M+3YL;V-K9FEL92DB+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!014%27U)%1TE35%)97T524D]27TQ/0TLI.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!?=6YL;V-K*"D-"@T*("`@
M(&9U;F-T:6]N(%]U;FQO8VLH*0T*("`@('L-"B`@("`@("`@)')E="`]("1T
M:&ES+3Y?;&]C:RA,3T-+7U5.*3L-"B`@("`@("`@:68@*&ES7W)E<V]U<F-E
M*"1T:&ES+3YL;V-K7V9P*2D@>PT*("`@("`@("`@("`@9F-L;W-E*"1T:&ES
M+3YL;V-K7V9P*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^;&]C:U]F
M<"`](&YU;&P[#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!?<&%C:V%G945X:7-T<R@I#0H-"B`@("!F
M=6YC=&EO;B!?<&%C:V%G945X:7-T<R@D<&%C:V%G92P@)&-H86YN96P@/2!F
M86QS92D-"B`@("![#0H@("`@("`@(')E='5R;B!F:6QE7V5X:7-T<R@D=&AI
M<RT^7W!A8VMA9V5&:6QE3F%M92@D<&%C:V%G92P@)&-H86YN96PI*3L-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7V-H86YN96Q%>&ES=',H
M*0T*#0H@("`@+RHJ#0H@("`@("H@1&5T97)M:6YE('=H971H97(@82!C:&%N
M;F5L(&5X:7-T<R!I;B!T:&4@<F5G:7-T<GD-"B`@("`@*B!`<&%R86T@<W1R
M:6YG($-H86YN96P@;F%M90T*("`@("`J($!P87)A;2!B;V]L(&EF('1R=64L
M('1H96X@86QI87-E<R!W:6QL(&)E(&EG;F]R960-"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?8VAA;FYE;$5X:7-T
M<R@D8VAA;FYE;"P@)&YO86QI87-E<R`](&9A;'-E*0T*("`@('L-"B`@("`@
M("`@)&$@/2!F:6QE7V5X:7-T<R@D=&AI<RT^7V-H86YN96Q&:6QE3F%M92@D
M8VAA;FYE;"P@)&YO86QI87-E<RDI.PT*("`@("`@("!I9B`H(21A("8F("1C
M:&%N;F5L(#T]("=P96%R+G!H<"YN970G*2![#0H@("`@("`@("`@("!R971U
M<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21A("8F("1C:&%N
M;F5L(#T]("=P96-L+G!H<"YN970G*2![#0H@("`@("`@("`@("!R971U<FX@
M=')U93L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]A9&1#:&%N;F5L*"D-"@T*("`@
M("\J*@T*("`@("`J($!P87)A;2!014%27T-H86YN96Q&:6QE($-H86YN96P@
M;V)J96-T#0H@("`@("H@0'!A<F%M(&1O;F]T=7-E#0H@("`@("H@0'!A<F%M
M('-T<FEN9R!,87-T+4UO9&EF:65D($A45%`@=&%G(&9R;VT@<F5M;W1E(')E
M<75E<W0-"B`@("`@*B!`<F5T=7)N(&)O;VQE86Y\4$5!4E]%<G)O<B!4<G5E
M(&]N(&-R96%T:6]N+"!F86QS92!I9B!I="!A;')E861Y(&5X:7-T<PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N(%]A9&1#:&%N;F5L*"1C:&%N;F5L+"`D=7!D
M871E(#T@9F%L<V4L("1L87-T;6]D:69I960@/2!F86QS92D-"B`@("![#0H@
M("`@("`@(&EF("@A:7-?82@D8VAA;FYE;"P@)U!%05)?0VAA;FYE;$9I;&4G
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@A)&-H86YN96PM/G9A;&ED871E*"DI('L-"B`@("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H9FEL
M95]E>&ES=',H)'1H:7,M/E]C:&%N;F5L1FEL94YA;64H)&-H86YN96PM/F=E
M=$YA;64H*2DI*2![#0H@("`@("`@("`@("!I9B`H(21U<&1A=&4I('L-"B`@
M("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`D8VAE8VME<B`]("1T:&ES+3Y?9V5T0VAA;FYE;"@D8VAA
M;FYE;"T^9V5T3F%M92@I*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1C:&5C:V5R*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D8VAE
M8VME<CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D8VAA;FYE
M;"T^9V5T06QI87,H*2`A/2`D8VAE8VME<BT^9V5T06QI87,H*2D@>PT*("`@
M("`@("`@("`@("`@($!U;FQI;FLH)'1H:7,M/E]G971#:&%N;F5L06QI87-&
M:6QE3F%M92@D8VAE8VME<BT^9V5T06QI87,H*2DI.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@:68@*"1U<&1A=&4@
M)B8@(6EN7V%R<F%Y*"1C:&%N;F5L+3YG971.86UE*"DL(&%R<F%Y*"=P96%R
M+G!H<"YN970G+"`G<&5C;"YP:'`N;F5T)RDI*2![#0H@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@("1R970@/2`D=&AI<RT^7V%S<V5R=$-H86YN96Q$:7(H*3L-"B`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E="DI('L-"B`@("`@("`@("`@
M(')E='5R;B`D<F5T.PT*("`@("`@("!]#0H@("`@("`@("1R970@/2`D=&AI
M<RT^7V%S<V5R=$-H86YN96Q3=&%T941I<B@D8VAA;FYE;"T^9V5T3F%M92@I
M*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E="DI('L-"B`@("`@
M("`@("`@(')E='5R;B`D<F5T.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M8VAA;FYE;"T^9V5T06QI87,H*2`A/2`D8VAA;FYE;"T^9V5T3F%M92@I*2![
M#0H@("`@("`@("`@("!I9B`H9FEL95]E>&ES=',H)'1H:7,M/E]G971#:&%N
M;F5L06QI87-&:6QE3F%M92@D8VAA;FYE;"T^9V5T06QI87,H*2DI("8F#0H@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$-H86YN96Q&<F]M06QI87,H
M)&-H86YN96PM/F=E=$%L:6%S*"DI("$]("1C:&%N;F5L+3YG971.86UE*"DI
M('L-"B`@("`@("`@("`@("`@("`D8VAA;FYE;"T^<V5T06QI87,H)&-H86YN
M96PM/F=E=$YA;64H*2D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H(21T:&ES+3YH87-7<FET94%C8V5S<R@I*2![#0H@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M)&9P(#T@0&9O<&5N*"1T:&ES+3Y?9V5T0VAA;FYE;$%L:6%S1FEL94YA;64H
M)&-H86YN96PM/F=E=$%L:6%S*"DI+"`G=R<I.PT*("`@("`@("`@("`@:68@
M*"$D9G`I('L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!F=W)I=&4H)&9P+"`D8VAA;FYE;"T^
M9V5T3F%M92@I*3L-"B`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@A)'1H:7,M/FAA<U=R:71E06-C97-S*"DI('L-
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@
M("`D9G`@/2!`9F]P96XH)'1H:7,M/E]C:&%N;F5L1FEL94YA;64H)&-H86YN
M96PM/F=E=$YA;64H*2DL("=W8B<I.PT*("`@("`@("!I9B`H(21F<"D@>PT*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@
M("1I;F9O(#T@)&-H86YN96PM/G1O07)R87DH*3L-"B`@("`@("`@:68@*"1L
M87-T;6]D:69I960I('L-"B`@("`@("`@("`@("1I;F9O6R=?;&%S=&UO9&EF
M:65D)UT@/2`D;&%S=&UO9&EF:65D.PT*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@)&EN9F];)U]L87-T;6]D:69I960G72`](&1A=&4H)W(G*3L-
M"B`@("`@("`@?0T*("`@("`@("!F=W)I=&4H)&9P+"!S97)I86QI>F4H)&EN
M9F\I*3L-"B`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!?9&5L971E
M0VAA;FYE;"@I#0H-"B`@("`O*BH-"B`@("`@*B!$96QE=&EO;B!F86EL<R!I
M9B!T:&5R92!A<F4@86YY('!A8VMA9V5S(&EN<W1A;&QE9"!F<F]M('1H92!C
M:&%N;F5L#0H@("`@("H@0'!A<F%M('-T<FEN9WQ014%27T-H86YN96Q&:6QE
M(&-H86YN96P@;F%M90T*("`@("`J($!R971U<FX@8F]O;&5A;GQ014%27T5R
M<F]R(%1R=64@;VX@9&5L971I;VXL(&9A;'-E(&EF(&ET(&1O97-N)W0@97AI
M<W0-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?9&5L971E0VAA;FYE;"@D8VAA
M;FYE;"D-"B`@("![#0H@("`@("`@(&EF("@A:7-?<W1R:6YG*"1C:&%N;F5L
M*2D@>PT*("`@("`@("`@("`@:68@*&ES7V$H)&-H86YN96PL("=014%27T-H
M86YN96Q&:6QE)RDI('L-"B`@("`@("`@("`@("`@("!I9B`H(21C:&%N;F5L
M+3YV86QI9&%T92@I*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&-H
M86YN96P@/2`D8VAA;FYE;"T^9V5T3F%M92@I.PT*("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES+3Y?9V5T0VAA
M;FYE;$9R;VU!;&EA<R@D8VAA;FYE;"D@/3T@)U]?=7)I)RD@>PT*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M=&AI<RT^7V=E=$-H86YN96Q&<F]M06QI87,H)&-H86YN96PI(#T]("=P96-L
M+G!H<"YN970G*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"$D=&AI<RT^7V-H86YN96Q%>&ES=',H)&-H
M86YN96PI*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"$D8VAA;FYE;"!\?"`D=&AI<RT^7V=E=$-H86YN
M96Q&<F]M06QI87,H)&-H86YN96PI(#T]("=P96%R+G!H<"YN970G*2![#0H@
M("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@
M)&-H86YN96P@/2`D=&AI<RT^7V=E=$-H86YN96Q&<F]M06QI87,H)&-H86YN
M96PI.PT*("`@("`@("!I9B`H)&-H86YN96P@/3T@)W!E87(N<&AP+FYE="<I
M('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@
M("`@("`D=&5S="`]("1T:&ES+3Y?;&ES=$-H86YN96Q086-K86=E<R@D8VAA
M;FYE;"D[#0H@("`@("`@(&EF("AC;W5N="@D=&5S="DI('L-"B`@("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D=&5S="`]
M($!R;61I<B@D=&AI<RT^7V-H86YN96Q$:7)E8W1O<GE.86UE*"1C:&%N;F5L
M*2D[#0H@("`@("`@(&EF("@A)'1E<W0I('L-"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D9FEL92`]("1T:&ES+3Y?
M9V5T0VAA;FYE;$%L:6%S1FEL94YA;64H)'1H:7,M/E]G971!;&EA<R@D8VAA
M;FYE;"DI.PT*("`@("`@("!I9B`H0&9I;&5?97AI<W1S*"1F:6QE*2D@>PT*
M("`@("`@("`@("`@)'1E<W0@/2!`=6YL:6YK*"1F:6QE*3L-"B`@("`@("`@
M("`@(&EF("@A)'1E<W0I('L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&9I;&4@
M/2`D=&AI<RT^7V-H86YN96Q&:6QE3F%M92@D8VAA;FYE;"D[#0H@("`@("`@
M("1R970@/2!`=6YL:6YK*"1F:6QE*3L-"B`@("`@("`@<F5T=7)N("1R970[
M#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]I<T-H86YN96Q!
M;&EA<R@I#0H-"B`@("`O*BH-"B`@("`@*B!$971E<FUI;F4@=VAE=&AE<B!A
M(&-H86YN96P@97AI<W1S(&EN('1H92!R96=I<W1R>0T*("`@("`J($!P87)A
M;2!S=')I;F<@0VAA;FYE;"!!;&EA<PT*("`@("`J($!R971U<FX@8F]O;&5A
M;@T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]I<T-H86YN96Q!;&EA<R@D86QI
M87,I#0H@("`@>PT*("`@("`@("!R971U<FX@9FEL95]E>&ES=',H)'1H:7,M
M/E]G971#:&%N;F5L06QI87-&:6QE3F%M92@D86QI87,I*3L-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7W!A8VMA9V5);F9O*"D-"@T*("`@
M("\J*@T*("`@("`J($!P87)A;2!S=')I;F=\;G5L;`T*("`@("`J($!P87)A
M;2!S=')I;F=\;G5L;`T*("`@("`J($!P87)A;2!S=')I;F=\;G5L;`T*("`@
M("`J($!R971U<FX@87)R87E\;G5L;`T*("`@("`J($!A8V-E<W,@<')I=F%T
M90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]P86-K86=E26YF;R@D<&%C:V%G
M92`](&YU;&PL("1K97D@/2!N=6QL+"`D8VAA;FYE;"`]("=P96%R+G!H<"YN
M970G*0T*("`@('L-"B`@("`@("`@:68@*"1P86-K86=E(#T]/2!N=6QL*2![
M#0H@("`@("`@("`@("!I9B`H)&-H86YN96P@/3T](&YU;&PI('L-"B`@("`@
M("`@("`@("`@("`D8VAA;FYE;',@/2`D=&AI<RT^7VQI<W1#:&%N;F5L<R@I
M.PT*("`@("`@("`@("`@("`@("1R970@/2!A<G)A>2@I.PT*("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1C:&%N;F5L<R!A<R`D8VAA;FYE;"D@>PT*("`@
M("`@("`@("`@("`@("`@("`D8VAA;FYE;"`]('-T<G1O;&]W97(H)&-H86YN
M96PI.PT*("`@("`@("`@("`@("`@("`@("`D<F5T6R1C:&%N;F5L72`](&%R
M<F%Y*"D[#0H@("`@("`@("`@("`@("`@("`@("1P86-K86=E<R`]("1T:&ES
M+3Y?;&ES=%!A8VMA9V5S*"1C:&%N;F5L*3L-"B`@("`@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)'!A8VMA9V5S(&%S("1P86-K86=E*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D<F5T6R1C:&%N;F5L75M=(#T@)'1H:7,M/E]P
M86-K86=E26YF;R@D<&%C:V%G92P@;G5L;"P@)&-H86YN96PI.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(')E='5R;B`D<F5T.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@)'!S(#T@)'1H:7,M/E]L:7-T4&%C:V%G97,H)&-H86YN96PI.PT*("`@
M("`@("`@("`@:68@*"%C;W5N="@D<',I*2![#0H@("`@("`@("`@("`@("`@
M<F5T=7)N(&%R<F%Y*"D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R
M971U<FX@87)R87E?;6%P*&%R<F%Y*"8D=&AI<RP@)U]P86-K86=E26YF;R<I
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<',L(&%R<F%Y7V9I
M;&PH,"P@8V]U;G0H)'!S*2P@;G5L;"DL#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y7V9I;&PH,"P@8V]U;G0H)'!S*2P@)&-H86YN96PI
M*3L-"B`@("`@("`@?0T*("`@("`@("`D9G`@/2`D=&AI<RT^7V]P96Y086-K
M86=E1FEL92@D<&%C:V%G92P@)W(G+"`D8VAA;FYE;"D[#0H@("`@("`@(&EF
M("@D9G`@/3T](&YU;&PI('L-"B`@("`@("`@("`@(')E='5R;B!N=6QL.PT*
M("`@("`@("!]#0H@("`@("`@("1R="`](&=E=%]M86=I8U]Q=6]T97-?<G5N
M=&EM92@I.PT*("`@("`@("!S971?;6%G:6-?<75O=&5S7W)U;G1I;64H,"D[
M#0H@("`@("`@(&-L96%R<W1A=&-A8VAE*"D[#0H@("`@("`@(&EF("AF=6YC
M=&EO;E]E>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?8VQO<V5086-K86=E1FEL92@D9G`I.PT*("`@("`@("`@
M("`@)&1A=&$@/2!F:6QE7V=E=%]C;VYT96YT<R@D=&AI<RT^7W!A8VMA9V5&
M:6QE3F%M92@D<&%C:V%G92P@)&-H86YN96PI*3L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1D871A(#T@9G)E860H)&9P+"!F:6QE<VEZ92@D
M=&AI<RT^7W!A8VMA9V5&:6QE3F%M92@D<&%C:V%G92P@)&-H86YN96PI*2D[
M#0H@("`@("`@("`@("`D=&AI<RT^7V-L;W-E4&%C:V%G949I;&4H)&9P*3L-
M"B`@("`@("`@?0T*("`@("`@("!S971?;6%G:6-?<75O=&5S7W)U;G1I;64H
M)')T*3L-"B`@("`@("`@)&1A=&$@/2!U;G-E<FEA;&EZ92@D9&%T82D[#0H@
M("`@("`@(&EF("@D:V5Y(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!R971U
M<FX@)&1A=&$[#0H@("`@("`@('T-"B`@("`@("`@+R\@8V]M<&%T:6)I;&ET
M>2!F;W(@<&%C:V%G92YX;6P@=F5R<VEO;B`R+C`-"B`@("`@("`@:68@*&ES
M<V5T*"1D871A6R=O;&0G75LD:V5Y72DI('L-"B`@("`@("`@("`@(')E='5R
M;B`D9&%T85LG;VQD)UU;)&ME>5T[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&ES<V5T*"1D871A6R1K97E=*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1D
M871A6R1K97E=.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!N=6QL.PT*
M("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!?8VAA;FYE;$EN9F\H
M*0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9R!#:&%N;F5L(&YA
M;64-"B`@("`@*B!`<&%R86T@8F]O;"!W:&5T:&5R('1O('-T<FEC=&QY(')E
M=')I979E(&EN9F\@;V8@8VAA;FYE;',L(&YO="!J=7-T(&%L:6%S97,-"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y?&YU;&P-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!?8VAA;FYE;$EN9F\H)&-H86YN96PL("1N;V%L:6%S97,@/2!F86QS92D-
M"B`@("![#0H@("`@("`@(&EF("@A)'1H:7,M/E]C:&%N;F5L17AI<W1S*"1C
M:&%N;F5L+"`D;F]A;&EA<V5S*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&YU
M;&P[#0H@("`@("`@('T-"B`@("`@("`@)&9P(#T@)'1H:7,M/E]O<&5N0VAA
M;FYE;$9I;&4H)&-H86YN96PL("=R)RD[#0H@("`@("`@(&EF("@D9G`@/3T]
M(&YU;&PI('L-"B`@("`@("`@("`@(')E='5R;B!N=6QL.PT*("`@("`@("!]
M#0H@("`@("`@("1R="`](&=E=%]M86=I8U]Q=6]T97-?<G5N=&EM92@I.PT*
M("`@("`@("!S971?;6%G:6-?<75O=&5S7W)U;G1I;64H,"D[#0H@("`@("`@
M(&-L96%R<W1A=&-A8VAE*"D[#0H@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES
M=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L-"B`@("`@("`@("`@("1T:&ES
M+3Y?8VQO<V5#:&%N;F5L1FEL92@D9G`I.PT*("`@("`@("`@("`@)&1A=&$@
M/2!F:6QE7V=E=%]C;VYT96YT<R@D=&AI<RT^7V-H86YN96Q&:6QE3F%M92@D
M8VAA;FYE;"DI.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&1A
M=&$@/2!F<F5A9"@D9G`L(&9I;&5S:7IE*"1T:&ES+3Y?8VAA;FYE;$9I;&5.
M86UE*"1C:&%N;F5L*2DI.PT*("`@("`@("`@("`@)'1H:7,M/E]C;&]S94-H
M86YN96Q&:6QE*"1F<"D[#0H@("`@("`@('T-"B`@("`@("`@<V5T7VUA9VEC
M7W%U;W1E<U]R=6YT:6UE*"1R="D[#0H@("`@("`@("1D871A(#T@=6YS97)I
M86QI>F4H)&1A=&$I.PT*("`@("`@("!R971U<FX@)&1A=&$[#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]L:7-T0VAA;FYE;',H*0T*#0H@
M("`@9G5N8W1I;VX@7VQI<W1#:&%N;F5L<R@I#0H@("`@>PT*("`@("`@("`D
M8VAA;FYE;&QI<W0@/2!A<G)A>2@I.PT*("`@("`@("`D9'`@/2!`;W!E;F1I
M<B@D=&AI<RT^8VAA;FYE;'-D:7(I.PT*("`@("`@("!I9B`H(21D<"`@?'P@
M(4!I<U]D:7(H)'1H:7,M/F-H86YN96QS9&ER*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N(&%R<F%Y*"=P96%R+G!H<"YN970G+"`G<&5C;"YP:'`N;F5T)RP@
M)U]?=7)I)RD[#0H@("`@("`@('T-"B`@("`@("`@=VAI;&4@*"1E;G0@/2!R
M96%D9&ER*"1D<"DI('L-"B`@("`@("`@("`@(&EF("@D96YT>S!](#T]("<N
M)R!\?"!S=6)S='(H)&5N="P@+30I("$]("<N<F5G)RD@>PT*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*"1E;G0@/3T@)U]?=7)I+G)E9R<I('L-"B`@("`@("`@("`@("`@("`D
M8VAA;FYE;&QI<W1;72`]("=?7W5R:2<[#0H@("`@("`@("`@("`@("`@8V]N
M=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D8VAA;FYE;&QI
M<W1;72`]('-T<E]R97!L86-E*"=?)RP@)R\G+"!S=6)S='(H)&5N="P@,"P@
M+30I*3L-"B`@("`@("`@?0T*("`@("`@("!C;&]S961I<B@D9'`I.PT*("`@
M("`@("!I9B`H(6EN7V%R<F%Y*"=P96%R+G!H<"YN970G+"`D8VAA;FYE;&QI
M<W0I*2![#0H@("`@("`@("`@("`D8VAA;FYE;&QI<W1;72`]("=P96%R+G!H
M<"YN970G.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:6Y?87)R87DH)W!E
M8VPN<&AP+FYE="<L("1C:&%N;F5L;&ES="DI('L-"B`@("`@("`@("`@("1C
M:&%N;F5L;&ES=%M=(#T@)W!E8VPN<&AP+FYE="<[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"%I;E]A<G)A>2@G7U]U<FDG+"`D8VAA;FYE;&QI<W0I*2![
M#0H@("`@("`@("`@("`D8VAA;FYE;&QI<W1;72`]("=?7W5R:2<[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N("1C:&%N;F5L;&ES=#L-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7VQI<W1086-K86=E<R@I#0H-"B`@
M("!F=6YC=&EO;B!?;&ES=%!A8VMA9V5S*"1C:&%N;F5L(#T@9F%L<V4I#0H@
M("`@>PT*("`@("`@("!I9B`H)&-H86YN96P@)B8@)'1H:7,M/E]G971#:&%N
M;F5L1G)O;4%L:6%S*"1C:&%N;F5L*2`A/2`G<&5A<BYP:'`N;F5T)RD@>PT*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?;&ES=$-H86YN96Q086-K86=E
M<R@D8VAA;FYE;"D[#0H@("`@("`@('T-"B`@("`@("`@)'!K9VQI<W0@/2!A
M<G)A>2@I.PT*("`@("`@("`D9'`@/2!`;W!E;F1I<B@D=&AI<RT^<W1A=&5D
M:7(I.PT*("`@("`@("!I9B`H(21D<"D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1P:V=L:7-T.PT*("`@("`@("!]#0H@("`@("`@('=H:6QE("@D96YT(#T@
M<F5A9&1I<B@D9'`I*2![#0H@("`@("`@("`@("!I9B`H)&5N='LP?2`]/2`G
M+B<@?'P@<W5B<W1R*"1E;G0L("TT*2`A/2`G+G)E9R<I('L-"B`@("`@("`@
M("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("1P:V=L:7-T6UT@/2!S=6)S='(H)&5N="P@,"P@+30I.PT*("`@("`@("!]
M#0H@("`@("`@(&-L;W-E9&ER*"1D<"D[#0H@("`@("`@(')E='5R;B`D<&MG
M;&ES=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7VQI<W1#
M:&%N;F5L4&%C:V%G97,H*0T*#0H@("`@9G5N8W1I;VX@7VQI<W1#:&%N;F5L
M4&%C:V%G97,H)&-H86YN96PI#0H@("`@>PT*("`@("`@("`D<&MG;&ES="`]
M(&%R<F%Y*"D[#0H@("`@("`@("1D<"`]($!O<&5N9&ER*"1T:&ES+3Y?8VAA
M;FYE;$1I<F5C=&]R>4YA;64H)&-H86YN96PI*3L-"B`@("`@("`@:68@*"$D
M9'`I('L-"B`@("`@("`@("`@(')E='5R;B`D<&MG;&ES=#L-"B`@("`@("`@
M?0T*("`@("`@("!W:&EL92`H)&5N="`](')E861D:7(H)&1P*2D@>PT*("`@
M("`@("`@("`@:68@*"1E;G1[,'T@/3T@)RXG('Q\('-U8G-T<B@D96YT+"`M
M-"D@(3T@)RYR96<G*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`D<&MG;&ES=%M=(#T@<W5B<W1R
M*"1E;G0L(#`L("TT*3L-"B`@("`@("`@?0T*("`@("`@("!C;&]S961I<B@D
M9'`I.PT*("`@("`@("!R971U<FX@)'!K9VQI<W0[#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H@("`@#0H@("`@9G5N8W1I;VX@7VQI<W1!;&Q086-K86=E<R@I
M#0H@("`@>PT*("`@("`@("`D<F5T(#T@87)R87DH*3L-"B`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/E]L:7-T0VAA;FYE;',H*2!A<R`D8VAA;FYE;"D@>PT*
M("`@("`@("`@("`@)')E=%LD8VAA;FYE;%T@/2`D=&AI<RT^7VQI<W1086-K
M86=E<R@D8VAA;FYE;"D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R
M970[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@061D(&%N(&EN<W1A;&QE
M9"!P86-K86=E('1O('1H92!R96=I<W1R>0T*("`@("`J($!P87)A;2!S=')I
M;F<@<&%C:V%G92!N86UE#0H@("`@("H@0'!A<F%M(&%R<F%Y('!A8VMA9V4@
M:6YF;R`H<&%R<V5D(&)Y(%!%05)?0V]M;6]N.CII;F9O1G)O;2HH*2!M971H
M;V1S*0T*("`@("`J($!R971U<FX@8F]O;"!S=6-C97-S(&]F('-A=FEN9PT*
M("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N
M(%]A9&1086-K86=E*"1P86-K86=E+"`D:6YF;RD-"B`@("![#0H@("`@("`@
M(&EF("@D=&AI<RT^7W!A8VMA9V5%>&ES=',H)'!A8VMA9V4I*2![#0H@("`@
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)&9P
M(#T@)'1H:7,M/E]O<&5N4&%C:V%G949I;&4H)'!A8VMA9V4L("=W8B<I.PT*
M("`@("`@("!I9B`H)&9P(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)&EN9F];)U]L87-T;6]D
M:69I960G72`]('1I;64H*3L-"B`@("`@("`@9G=R:71E*"1F<"P@<V5R:6%L
M:7IE*"1I;F9O*2D[#0H@("`@("`@("1T:&ES+3Y?8VQO<V5086-K86=E1FEL
M92@D9G`I.PT*("`@("`@("!I9B`H:7-S970H)&EN9F];)V9I;&5L:7-T)UTI
M*2![#0H@("`@("`@("`@("`D=&AI<RT^7W)E8G5I;&1&:6QE36%P*"D[#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]0
M86-K86=E1FEL95]V,@T*("`@("`J($!R971U<FX@8F]O;`T*("`@("`J($!A
M8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]A9&1086-K
M86=E,B@D:6YF;RD-"B`@("![#0H@("`@("`@(&EF("@A)&EN9F\M/G9A;&ED
M871E*"DI('L-"B`@("`@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)U!%05)?
M0V]M;6]N)RDI('L-"B`@("`@("`@("`@("`@("`D=6D@/2!014%27T9R;VYT
M96YD.CIS:6YG;&5T;VXH*3L-"B`@("`@("`@("`@("`@("!I9B`H)'5I*2![
M#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O+3YG971686QI
M9&%T:6]N5V%R;FEN9W,H*2!A<R`D97)R*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D=6DM/FQO9R@R+"`D97)R6R=M97-S86=E)UTI.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@
M("`@("`@("1C:&%N;F5L(#T@)&EN9F\M/F=E=$-H86YN96PH*3L-"B`@("`@
M("`@)'!A8VMA9V4@/2`D:6YF;RT^9V5T4&%C:V%G92@I.PT*("`@("`@("`D
M<V%V92`]("1I;F9O.PT*("`@("`@("!I9B`H)'1H:7,M/E]P86-K86=E17AI
M<W1S*"1P86-K86=E+"`D8VAA;FYE;"DI('L-"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21T:&ES+3Y?8VAA
M;FYE;$5X:7-T<R@D8VAA;FYE;"P@=')U92DI('L-"B`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D:6YF;R`]("1I;F9O
M+3YT;T%R<F%Y*'1R=64I.PT*("`@("`@("!I9B`H(21I;F9O*2![#0H@("`@
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)&9P
M(#T@)'1H:7,M/E]O<&5N4&%C:V%G949I;&4H)'!A8VMA9V4L("=W8B<L("1C
M:&%N;F5L*3L-"B`@("`@("`@:68@*"1F<"`]/3T@;G5L;"D@>PT*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1I;F9O
M6R=?;&%S=&UO9&EF:65D)UT@/2!T:6UE*"D[#0H@("`@("`@(&9W<FET92@D
M9G`L('-E<FEA;&EZ92@D:6YF;RDI.PT*("`@("`@("`D=&AI<RT^7V-L;W-E
M4&%C:V%G949I;&4H)&9P*3L-"B`@("`@("`@)'1H:7,M/E]R96)U:6QD1FEL
M94UA<"@I.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG(%!A8VMA9V4@;F%M90T*("`@("`J
M($!P87)A;2!A<G)A>2!P87)S960@<&%C:V%G92YX;6P@,2XP#0H@("`@("H@
M0'!A<F%M(&)O;VP@=&AI<R!P87)A;65T97(@:7,@;VYL>2!H97)E(&9O<B!"
M0RX@($1O;B=T('5S92!I="X-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!?=7!D871E4&%C:V%G92@D<&%C:V%G92P@
M)&EN9F\L("1M97)G92`]('1R=64I#0H@("`@>PT*("`@("`@("`D;VQD:6YF
M;R`]("1T:&ES+3Y?<&%C:V%G94EN9F\H)'!A8VMA9V4I.PT*("`@("`@("!I
M9B`H96UP='DH)&]L9&EN9F\I*2![#0H@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@('T-"B`@("`@("`@)&9P(#T@)'1H:7,M/E]O<&5N4&%C
M:V%G949I;&4H)'!A8VMA9V4L("=W)RD[#0H@("`@("`@(&EF("@D9G`@/3T]
M(&YU;&PI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H:7-?;V)J96-T*"1I;F9O*2D@>PT*("`@("`@("`@
M("`@)&EN9F\@/2`D:6YF;RT^=&]!<G)A>2@I.PT*("`@("`@("!]#0H@("`@
M("`@("1I;F9O6R=?;&%S=&UO9&EF:65D)UT@/2!T:6UE*"D[#0H@("`@("`@
M("1N97=I;F9O(#T@)&EN9F\[#0H@("`@("`@(&EF("@D;65R9V4I('L-"B`@
M("`@("`@("`@("1I;F9O(#T@87)R87E?;65R9V4H)&]L9&EN9F\L("1I;F9O
M*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1D:69F(#T@)&EN
M9F\[#0H@("`@("`@('T-"B`@("`@("`@9G=R:71E*"1F<"P@<V5R:6%L:7IE
M*"1I;F9O*2D[#0H@("`@("`@("1T:&ES+3Y?8VQO<V5086-K86=E1FEL92@D
M9G`I.PT*("`@("`@("!I9B`H:7-S970H)&YE=VEN9F];)V9I;&5L:7-T)UTI
M*2![#0H@("`@("`@("`@("`D=&AI<RT^7W)E8G5I;&1&:6QE36%P*"D[#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]0
M86-K86=E1FEL95]V,@T*("`@("`J($!R971U<FX@8F]O;`T*("`@("`J($!A
M8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]U<&1A=&50
M86-K86=E,B@D:6YF;RD-"B`@("![#0H@("`@("`@(&EF("@A)'1H:7,M/E]P
M86-K86=E17AI<W1S*"1I;F9O+3YG971086-K86=E*"DL("1I;F9O+3YG971#
M:&%N;F5L*"DI*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@('T-"B`@("`@("`@)&9P(#T@)'1H:7,M/E]O<&5N4&%C:V%G949I;&4H
M)&EN9F\M/F=E=%!A8VMA9V4H*2P@)W<G+"`D:6YF;RT^9V5T0VAA;FYE;"@I
M*3L-"B`@("`@("`@:68@*"1F<"`]/3T@;G5L;"D@>PT*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1S879E(#T@)&EN
M9F\[#0H@("`@("`@("1I;F9O(#T@)'-A=F4M/F=E=$%R<F%Y*'1R=64I.PT*
M("`@("`@("`D:6YF;ULG7VQA<W1M;V1I9FEE9"==(#T@=&EM92@I.PT*("`@
M("`@("!F=W)I=&4H)&9P+"!S97)I86QI>F4H)&EN9F\I*3L-"B`@("`@("`@
M)'1H:7,M/E]C;&]S95!A8VMA9V5&:6QE*"1F<"D[#0H@("`@("`@("1T:&ES
M+3Y?<F5B=6EL9$9I;&5-87`H*3L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9R!086-K86=E
M(&YA;64-"B`@("`@*B!`<&%R86T@<W1R:6YG($-H86YN96P@;F%M90T*("`@
M("`J($!R971U<FX@4$5!4E]086-K86=E1FEL95]V,7Q014%27U!A8VMA9V5&
M:6QE7W8R?&YU;&P-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B`F7V=E=%!A8VMA9V4H)'!A8VMA9V4L("1C:&%N;F5L
M(#T@)W!E87(N<&AP+FYE="<I#0H@("`@>PT*("`@("`@("`D:6YF;R`]("1T
M:&ES+3Y?<&%C:V%G94EN9F\H)'!A8VMA9V4L(&YU;&PL("1C:&%N;F5L*3L-
M"B`@("`@("`@:68@*"1I;F9O(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!R
M971U<FX@)&EN9F\[#0H@("`@("`@('T-"B`@("`@("`@)&$@/2`D=&AI<RT^
M7V-O;F9I9SL-"B`@("`@("`@:68@*"$D82D@>PT*("`@("`@("`@("`@)'1H
M:7,M/E]C;VYF:6<@/2`F;F5W(%!%05)?0V]N9FEG.PT*("`@("`@("`@("`@
M)'1H:7,M/E]C;VYF:6<M/G-E="@G<&AP7V1I<B<L("1T:&ES+3YS=&%T961I
M<BD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%
M05)?4&%C:V%G949I;&4G*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E
M("=014%2+U!A8VMA9V5&:6QE+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@
M)'!K9R`]("9N97<@4$5!4E]086-K86=E1FEL92@D=&AI<RT^7V-O;F9I9RD[
M#0H@("`@("`@("1P9B`]("8D<&MG+3YF<F]M07)R87DH)&EN9F\I.PT*("`@
M("`@("!R971U<FX@)'!F.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P
M87)A;2!S=')I;F<@8VAA;FYE;"!N86UE#0H@("`@("H@0'!A<F%M(&)O;VP@
M=VAE=&AE<B!T;R!S=')I8W1L>2!R971R:65V92!C:&%N;F5L(&YA;65S#0H@
M("`@("H@0')E='5R;B!014%27T-H86YN96Q&:6QE?%!%05)?17)R;W(-"B`@
M("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F
M7V=E=$-H86YN96PH)&-H86YN96PL("1N;V%L:6%S97,@/2!F86QS92D-"B`@
M("![#0H@("`@("`@("1C:"`](&9A;'-E.PT*("`@("`@("!I9B`H)'1H:7,M
M/E]C:&%N;F5L17AI<W1S*"1C:&%N;F5L+"`D;F]A;&EA<V5S*2D@>PT*("`@
M("`@("`@("`@)&-H:6YF;R`]("1T:&ES+3Y?8VAA;FYE;$EN9F\H)&-H86YN
M96PL("1N;V%L:6%S97,I.PT*("`@("`@("`@("`@:68@*"1C:&EN9F\I('L-
M"B`@("`@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]#:&%N
M;F5L1FEL92<I*2![#0H@("`@("`@("`@("`@("`@("`@(')E<75I<F5?;VYC
M92`G4$5!4B]#:&%N;F5L1FEL92YP:'`G.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`D8V@@/2`F4$5!4E]#:&%N;F5L1FEL93HZ9G)O
M;4%R<F%Y5VET:$5R<F]R<R@D8VAI;F9O*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H)&-H*2![#0H@("`@("`@("`@("!I9B`H
M)&-H+3YV86QI9&%T92@I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1C
M:#L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1C:"T^
M9V5T17)R;W)S*'1R=64I(&%S("1E<G(I('L-"B`@("`@("`@("`@("`@("`D
M;65S<V%G92`]("1E<G);)VUE<W-A9V4G72`N(")<;B([#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`D8V@@/2!014%2.CIR86ES945R<F]R*"1M97-S
M86=E*3L-"B`@("`@("`@("`@(')E='5R;B`D8V@[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"1T:&ES+3Y?9V5T0VAA;FYE;$9R;VU!;&EA<R@D8VAA;FYE
M;"D@/3T@)W!E87(N<&AP+FYE="<I('L-"B`@("`@("`@("`@("\O('1H92!R
M96=I<W1R>2!I<R!N;W0@<')O<&5R;'D@<V5T('5P+"!S;R!U<V4@9&5F875L
M=',-"B`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T-H86YN
M96Q&:6QE)RDI('L-"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%
M05(O0VAA;FYE;$9I;&4N<&AP)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("1P96%R7V-H86YN96P@/2!N97<@4$5!4E]#:&%N;F5L1FEL93L-"B`@
M("`@("`@("`@("1P96%R7V-H86YN96PM/G-E=$YA;64H)W!E87(N<&AP+FYE
M="<I.PT*("`@("`@("`@("`@)'!E87)?8VAA;FYE;"T^<V5T06QI87,H)W!E
M87(G*3L-"B`@("`@("`@("`@("1P96%R7V-H86YN96PM/G-E=%-U;6UA<GDH
M)U!(4"!%>'1E;G-I;VX@86YD($%P<&QI8V%T:6]N(%)E<&]S:71O<GDG*3L-
M"B`@("`@("`@("`@("1P96%R7V-H86YN96PM/G-E=$1E9F%U;'1014%24')O
M=&]C;VQS*"D[#0H@("`@("`@("`@("`D<&5A<E]C:&%N;F5L+3YS971"87-E
M55),*"=215-4,2XP)RP@)VAT='`Z+R]P96%R+G!H<"YN970O<F5S="\G*3L-
M"B`@("`@("`@("`@("1P96%R7V-H86YN96PM/G-E=$)A<V554DPH)U)%4U0Q
M+C$G+"`G:'1T<#HO+W!E87(N<&AP+FYE="]R97-T+R<I.PT*("`@("`@("`@
M("`@<F5T=7)N("1P96%R7V-H86YN96P[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"1T:&ES+3Y?9V5T0VAA;FYE;$9R;VU!;&EA<R@D8VAA;FYE;"D@/3T@
M)W!E8VPN<&AP+FYE="<I('L-"B`@("`@("`@("`@("\O('1H92!R96=I<W1R
M>2!I<R!N;W0@<')O<&5R;'D@<V5T('5P+"!S;R!U<V4@9&5F875L=',-"B`@
M("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T-H86YN96Q&:6QE
M)RDI('L-"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O0VAA
M;FYE;$9I;&4N<&AP)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1P
M96%R7V-H86YN96P@/2!N97<@4$5!4E]#:&%N;F5L1FEL93L-"B`@("`@("`@
M("`@("1P96%R7V-H86YN96PM/G-E=$YA;64H)W!E8VPN<&AP+FYE="<I.PT*
M("`@("`@("`@("`@)'!E87)?8VAA;FYE;"T^<V5T06QI87,H)W!E8VPG*3L-
M"B`@("`@("`@("`@("1P96%R7V-H86YN96PM/G-E=%-U;6UA<GDH)U!(4"!%
M>'1E;G-I;VX@0V]M;75N:71Y($QI8G)A<GDG*3L-"B`@("`@("`@("`@("1P
M96%R7V-H86YN96PM/G-E=$1E9F%U;'1014%24')O=&]C;VQS*"D[#0H@("`@
M("`@("`@("`D<&5A<E]C:&%N;F5L+3YS971"87-E55),*"=215-4,2XP)RP@
M)VAT='`Z+R]P96-L+G!H<"YN970O<F5S="\G*3L-"B`@("`@("`@("`@("1P
M96%R7V-H86YN96PM/G-E=$)A<V554DPH)U)%4U0Q+C$G+"`G:'1T<#HO+W!E
M8VPN<&AP+FYE="]R97-T+R<I.PT*("`@("`@("`@("`@)'!E87)?8VAA;FYE
M;"T^<V5T5F%L:61A=&EO;E!A8VMA9V4H)U!%05)?5F%L:61A=&]R7U!%0TPG
M+"`G,2XP)RD[#0H@("`@("`@("`@("!R971U<FX@)'!E87)?8VAA;FYE;#L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1H:7,M/E]G971#:&%N;F5L1G)O
M;4%L:6%S*"1C:&%N;F5L*2`]/2`G7U]U<FDG*2![#0H@("`@("`@("`@("`O
M+R!T:&4@<F5G:7-T<GD@:7,@;F]T('!R;W!E<FQY('-E="!U<"P@<V\@=7-E
M(&1E9F%U;'1S#0H@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!
M4E]#:&%N;F5L1FEL92<I*2![#0H@("`@("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E("=014%2+T-H86YN96Q&:6QE+G!H<"<[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`D<')I=F%T92`](&YE=R!014%27T-H86YN96Q&:6QE.PT*
M("`@("`@("`@("`@)'!R:79A=&4M/G-E=$YA;64H)U]?=7)I)RD[#0H@("`@
M("`@("`@("`D<')I=F%T92T^861D1G5N8W1I;VXH)WAM;')P8R<L("<Q+C`G
M+"`G*BHJ*B<I.PT*("`@("`@("`@("`@)'!R:79A=&4M/G-E=%-U;6UA<GDH
M)U!S975D;RUC:&%N;F5L(&9O<B!S=&%T:6,@<&%C:V%G97,G*3L-"B`@("`@
M("`@("`@(')E='5R;B`D<')I=F%T93L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@)&-H.PT*("`@('T-"@T*("`@("\O('M[>R!P86-K86=E17AI<W1S
M*"D-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<@4&%C:V%G92!N
M86UE#0H@("`@("H@0'!A<F%M('-T<FEN9R!#:&%N;F5L(&YA;64-"B`@("`@
M*B!`<F5T=7)N(&)O;VP-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!P86-K86=E
M17AI<W1S*"1P86-K86=E+"`D8VAA;FYE;"`]("=P96%R+G!H<"YN970G*0T*
M("`@('L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4@/2`D=&AI<RT^
M7VQO8VLH3$]#2U]32"DI*2![#0H@("`@("`@("`@("!R971U<FX@)&4[#0H@
M("`@("`@('T-"B`@("`@("`@)')E="`]("1T:&ES+3Y?<&%C:V%G945X:7-T
M<R@D<&%C:V%G92P@)&-H86YN96PI.PT*("`@("`@("`D=&AI<RT^7W5N;&]C
M:R@I.PT*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"@T*("`@("\O('M[>R!C:&%N;F5L17AI<W1S*"D-"@T*("`@("\J*@T*
M("`@("`J($!P87)A;2!S=')I;F<@8VAA;FYE;"!N86UE#0H@("`@("H@0'!A
M<F%M(&)O;VP@:68@=')U92P@=&AE;B!A;&EA<V5S('=I;&P@8F4@:6=N;W)E
M9`T*("`@("`J($!R971U<FX@8F]O;`T*("`@("`J+PT*("`@(&9U;F-T:6]N
M(&-H86YN96Q%>&ES=',H)&-H86YN96PL("1N;V%L:6%S97,@/2!F86QS92D-
M"B`@("![#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E(#T@)'1H:7,M
M/E]L;V-K*$Q/0TM?4T@I*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E.PT*
M("`@("`@("!]#0H@("`@("`@("1R970@/2`D=&AI<RT^7V-H86YN96Q%>&ES
M=',H)&-H86YN96PL("1N;V%L:6%S97,I.PT*("`@("`@("`D=&AI<RT^7W5N
M;&]C:R@I.PT*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O
M+R!]?7T-"@T*("`@("\O('M[>R!I<T%L:6%S*"D-"@T*("`@("\J*@T*("`@
M("`J($1E=&5R;6EN97,@=VAE=&AE<B!T:&4@<&%R86UE=&5R(&ES(&%N(&%L
M:6%S(&]F(&$@8VAA;FYE;`T*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@
M*B!`<F5T=7)N(&)O;VP-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I<T%L:6%S
M*"1A;&EA<RD-"B`@("![#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E
M(#T@)'1H:7,M/E]L;V-K*$Q/0TM?4T@I*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1E.PT*("`@("`@("!]#0H@("`@("`@("1R970@/2`D=&AI<RT^7VES
M0VAA;FYE;$%L:6%S*"1A;&EA<RD[#0H@("`@("`@("1T:&ES+3Y?=6YL;V-K
M*"D[#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\O('U]
M?0T*("`@("\O('M[>R!P86-K86=E26YF;R@I#0H-"B`@("`O*BH-"B`@("`@
M*B!`<&%R86T@<W1R:6YG?&YU;&P-"B`@("`@*B!`<&%R86T@<W1R:6YG?&YU
M;&P-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@("`@("H@0')E='5R;B!A<G)A
M>7QN=6QL#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<&%C:V%G94EN9F\H)'!A
M8VMA9V4@/2!N=6QL+"`D:V5Y(#T@;G5L;"P@)&-H86YN96P@/2`G<&5A<BYP
M:'`N;F5T)RD-"B`@("![#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E
M(#T@)'1H:7,M/E]L;V-K*$Q/0TM?4T@I*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1E.PT*("`@("`@("!]#0H@("`@("`@("1R970@/2`D=&AI<RT^7W!A
M8VMA9V5);F9O*"1P86-K86=E+"`D:V5Y+"`D8VAA;FYE;"D[#0H@("`@("`@
M("1T:&ES+3Y?=6YL;V-K*"D[#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@
M('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!C:&%N;F5L26YF;R@I#0H-
M"B`@("`O*BH-"B`@("`@*B!2971R:65V92!A(')A=R!A<G)A>2!O9B!C:&%N
M;F5L(&1A=&$N#0H@("`@("H-"B`@("`@*B!$;R!N;W0@=7-E('1H:7,L(&EN
M<W1E860@=7-E('M`;&EN:R!G971#:&%N;F5L*"E](&9O<B!N;W)M86P-"B`@
M("`@*B!O<&5R871I;VYS+B`@07)R87D@<W1R=6-T=7)E(&ES('5N9&5F:6YE
M9"!I;B!T:&ES(&UE=&AO9`T*("`@("`J($!P87)A;2!S=')I;F<@8VAA;FYE
M;"!N86UE#0H@("`@("H@0'!A<F%M(&)O;VP@=VAE=&AE<B!T;R!S=')I8W1L
M>2!R971R:65V92!I;F9O<FUA=&EO;B!O;FQY(&]N(&YO;BUA;&EA<V5S#0H@
M("`@("H@0')E='5R;B!A<G)A>7QN=6QL?%!%05)?17)R;W(-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!C:&%N;F5L26YF;R@D8VAA;FYE;"`](&YU;&PL("1N
M;V%L:6%S97,@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1E(#T@)'1H:7,M/E]L;V-K*$Q/0TM?4T@I*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1E.PT*("`@("`@("!]#0H@("`@("`@("1R970@/2`D
M=&AI<RT^7V-H86YN96Q);F9O*"1C:&%N;F5L+"`D;F]A;&EA<V5S*3L-"B`@
M("`@("`@)'1H:7,M/E]U;FQO8VLH*3L-"B`@("`@("`@<F5T=7)N("1R970[
M#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R
M86T@<W1R:6YG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8VAA;FYE;$YA;64H
M)&-H86YN96PI#0H@("`@>PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M92`]("1T:&ES+3Y?;&]C:RA,3T-+7U-(*2DI('L-"B`@("`@("`@("`@(')E
M='5R;B`D93L-"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@)'1H:7,M/E]G
M971#:&%N;F5L1G)O;4%L:6%S*"1C:&%N;F5L*3L-"B`@("`@("`@)'1H:7,M
M/E]U;FQO8VLH*3L-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9PT*("`@("`J+PT*("`@(&9U
M;F-T:6]N(&-H86YN96Q!;&EA<R@D8VAA;FYE;"D-"B`@("![#0H@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1E(#T@)'1H:7,M/E]L;V-K*$Q/0TM?4T@I
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E.PT*("`@("`@("!]#0H@("`@
M("`@("1R970@/2`D=&AI<RT^7V=E=$%L:6%S*"1C:&%N;F5L*3L-"B`@("`@
M("`@)'1H:7,M/E]U;FQO8VLH*3L-"B`@("`@("`@<F5T=7)N("1R970[#0H@
M("`@?0T*("`@("\O('M[>R!L:7-T4&%C:V%G97,H*0T*#0H@("`@9G5N8W1I
M;VX@;&ES=%!A8VMA9V5S*"1C:&%N;F5L(#T@9F%L<V4I#0H@("`@>PT*("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1T:&ES+3Y?;&]C:RA,3T-+
M7U-(*2DI('L-"B`@("`@("`@("`@(')E='5R;B`D93L-"B`@("`@("`@?0T*
M("`@("`@("`D<F5T(#T@)'1H:7,M/E]L:7-T4&%C:V%G97,H)&-H86YN96PI
M.PT*("`@("`@("`D=&AI<RT^7W5N;&]C:R@I.PT*("`@("`@("!R971U<FX@
M)')E=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@;&ES=$%L
M;%!A8VMA9V5S*"D-"@T*("`@(&9U;F-T:6]N(&QI<W1!;&Q086-K86=E<R@I
M#0H@("`@>PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1T:&ES
M+3Y?;&]C:RA,3T-+7U-(*2DI('L-"B`@("`@("`@("`@(')E='5R;B`D93L-
M"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@)'1H:7,M/E]L:7-T06QL4&%C
M:V%G97,H*3L-"B`@("`@("`@)'1H:7,M/E]U;FQO8VLH*3L-"B`@("`@("`@
M<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[
M(&QI<W1#:&%N;F5L*"D-"@T*("`@(&9U;F-T:6]N(&QI<W1#:&%N;F5L<R@I
M#0H@("`@>PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1T:&ES
M+3Y?;&]C:RA,3T-+7U-(*2DI('L-"B`@("`@("`@("`@(')E='5R;B`D93L-
M"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@)'1H:7,M/E]L:7-T0VAA;FYE
M;',H*3L-"B`@("`@("`@)'1H:7,M/E]U;FQO8VLH*3L-"B`@("`@("`@<F5T
M=7)N("1R970[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&%D
M9%!A8VMA9V4H*0T*#0H@("`@+RHJ#0H@("`@("H@061D(&%N(&EN<W1A;&QE
M9"!P86-K86=E('1O('1H92!R96=I<W1R>0T*("`@("`J($!P87)A;2!S=')I
M;F=\4$5!4E]086-K86=E1FEL95]V,7Q014%27U!A8VMA9V5&:6QE7W8R('!A
M8VMA9V4@;F%M92!O<B!O8FIE8W0-"B`@("`@*B`@("`@("`@("`@("`@('1H
M870@=VEL;"!B92!P87-S960@=&\@>T!L:6YK(&%D9%!A8VMA9V4R*"E]#0H@
M("`@("H@0'!A<F%M(&%R<F%Y('!A8VMA9V4@:6YF;R`H<&%R<V5D(&)Y(%!%
M05)?0V]M;6]N.CII;F9O1G)O;2HH*2!M971H;V1S*0T*("`@("`J($!R971U
M<FX@8F]O;"!S=6-C97-S(&]F('-A=FEN9PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&%D9%!A8VMA9V4H)'!A8VMA9V4L("1I;F9O*0T*("`@('L-"B`@("`@
M("`@:68@*&ES7V]B:F5C="@D:6YF;RDI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^861D4&%C:V%G93(H)&EN9F\I.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1E(#T@)'1H:7,M/E]L;V-K*$Q/0TM?
M15@I*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E.PT*("`@("`@("!]#0H@
M("`@("`@("1R970@/2`D=&AI<RT^7V%D9%!A8VMA9V4H)'!A8VMA9V4L("1I
M;F9O*3L-"B`@("`@("`@)'1H:7,M/E]U;FQO8VLH*3L-"B`@("`@("`@:68@
M*"1R970I('L-"B`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%2
M7U!A8VMA9V5&:6QE7W8Q)RDI('L-"B`@("`@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)U!%05(O4&%C:V%G949I;&4O=C$N<&AP)SL-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("1P9B`](&YE=R!014%27U!A8VMA9V5&:6QE7W8Q
M.PT*("`@("`@("`@("`@)'!F+3YS971#;VYF:6<H)'1H:7,M/E]C;VYF:6<I
M.PT*("`@("`@("`@("`@)'!F+3YF<F]M07)R87DH)&EN9F\I.PT*("`@("`@
M("`@("`@)'1H:7,M/E]D97!E;F1E;F-Y1$(M/G5N:6YS=&%L;%!A8VMA9V4H
M)'!F*3L-"B`@("`@("`@("`@("1T:&ES+3Y?9&5P96YD96YC>41"+3YI;G-T
M86QL4&%C:V%G92@D<&8I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D
M<F5T.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!A9&1086-K
M86=E,B@I#0H-"B`@("!F=6YC=&EO;B!A9&1086-K86=E,B@D:6YF;RD-"B`@
M("![#0H@("`@("`@(&EF("@A:7-?;V)J96-T*"1I;F9O*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YA9&1086-K86=E*"1I;F9O6R=P86-K86=E
M)UTL("1I;F9O*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D92`]("1T:&ES+3Y?;&]C:RA,3T-+7T58*2DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D93L-"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@)'1H
M:7,M/E]A9&1086-K86=E,B@D:6YF;RD[#0H@("`@("`@("1T:&ES+3Y?=6YL
M;V-K*"D[#0H@("`@("`@(&EF("@D<F5T*2![#0H@("`@("`@("`@("`D=&AI
M<RT^7V1E<&5N9&5N8WE$0BT^=6YI;G-T86QL4&%C:V%G92@D:6YF;RD[#0H@
M("`@("`@("`@("`D=&AI<RT^7V1E<&5N9&5N8WE$0BT^:6YS=&%L;%!A8VMA
M9V4H)&EN9F\I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*
M("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!U<&1A=&5#:&%N;F5L
M*"D-"@T*("`@("\J*@T*("`@("`J($9O<B!F=71U<F4@97AP86YD:6)I;&ET
M>2!P=7)P;W-E<RP@<V5P87)A=&4@=&AI<PT*("`@("`J($!P87)A;2!014%2
M7T-H86YN96Q&:6QE#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=7!D871E0VAA
M;FYE;"@D8VAA;FYE;"P@)&QA<W1M;V1I9FEE9"`](&YU;&PI#0H@("`@>PT*
M("`@("`@("!I9B`H)&-H86YN96PM/F=E=$YA;64H*2`]/2`G7U]U<FDG*2![
M#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N("1T:&ES+3YA9&1#:&%N;F5L*"1C:&%N;F5L+"`D;&%S=&UO
M9&EF:65D+"!T<G5E*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@9&5L971E0VAA;FYE;"@I#0H-"B`@("`O*BH-"B`@("`@*B!$96QE=&EO
M;B!F86EL<R!I9B!T:&5R92!A<F4@86YY('!A8VMA9V5S(&EN<W1A;&QE9"!F
M<F]M('1H92!C:&%N;F5L#0H@("`@("H@0'!A<F%M('-T<FEN9WQ014%27T-H
M86YN96Q&:6QE(&-H86YN96P@;F%M90T*("`@("`J($!R971U<FX@8F]O;&5A
M;GQ014%27T5R<F]R(%1R=64@;VX@9&5L971I;VXL(&9A;'-E(&EF(&ET(&1O
M97-N)W0@97AI<W0-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!D96QE=&5#:&%N
M;F5L*"1C:&%N;F5L*0T*("`@('L-"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&4@/2`D=&AI<RT^7VQO8VLH3$]#2U]%6"DI*2![#0H@("`@("`@("`@
M("!R971U<FX@)&4[#0H@("`@("`@('T-"B`@("`@("`@)')E="`]("1T:&ES
M+3Y?9&5L971E0VAA;FYE;"@D8VAA;FYE;"D[#0H@("`@("`@("1T:&ES+3Y?
M=6YL;V-K*"D[#0H@("`@("`@(&EF("@D<F5T("8F(&ES7V$H)'1H:7,M/E]C
M;VYF:6<L("=014%27T-O;F9I9R<I*2![#0H@("`@("`@("`@("`D=&AI<RT^
M7V-O;F9I9RT^<V5T0VAA;FYE;',H)'1H:7,M/FQI<W1#:&%N;F5L<R@I*3L-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@861D0VAA;FYE;"@I#0H-"B`@("`O*BH-
M"B`@("`@*B!`<&%R86T@4$5!4E]#:&%N;F5L1FEL92!#:&%N;F5L(&]B:F5C
M=`T*("`@("`J($!P87)A;2!S=')I;F<@3&%S="U-;V1I9FEE9"!H96%D97(@
M9G)O;2!(5%10(&9O<B!C86-H:6YG#0H@("`@("H@0')E='5R;B!B;V]L96%N
M?%!%05)?17)R;W(@5')U92!O;B!C<F5A=&EO;BP@9F%L<V4@:68@:70@86QR
M96%D>2!E>&ES=',-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&1#:&%N;F5L
M*"1C:&%N;F5L+"`D;&%S=&UO9&EF:65D(#T@9F%L<V4L("1U<&1A=&4@/2!F
M86QS92D-"B`@("![#0H@("`@("`@(&EF("@A:7-?82@D8VAA;FYE;"P@)U!%
M05)?0VAA;FYE;$9I;&4G*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A)&-H86YN96PM/G9A;&ED871E
M*"DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1T:&ES+3Y?;&]C:RA,
M3T-+7T58*2DI('L-"B`@("`@("`@("`@(')E='5R;B`D93L-"B`@("`@("`@
M?0T*("`@("`@("`D<F5T(#T@)'1H:7,M/E]A9&1#:&%N;F5L*"1C:&%N;F5L
M+"`D=7!D871E+"`D;&%S=&UO9&EF:65D*3L-"B`@("`@("`@)'1H:7,M/E]U
M;FQO8VLH*3L-"B`@("`@("`@:68@*"$D=7!D871E("8F("1R970@)B8@:7-?
M82@D=&AI<RT^7V-O;F9I9RP@)U!%05)?0V]N9FEG)RDI('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?8V]N9FEG+3YS971#:&%N;F5L<R@D=&AI<RT^;&ES=$-H
M86YN96QS*"DI.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*
M("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!D96QE=&5086-K86=E
M*"D-"@T*("`@(&9U;F-T:6]N(&1E;&5T95!A8VMA9V4H)'!A8VMA9V4L("1C
M:&%N;F5L(#T@)W!E87(N<&AP+FYE="<I#0H@("`@>PT*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D92`]("1T:&ES+3Y?;&]C:RA,3T-+7T58*2DI('L-
M"B`@("`@("`@("`@(')E='5R;B`D93L-"B`@("`@("`@?0T*("`@("`@("`D
M9FEL92`]("1T:&ES+3Y?<&%C:V%G949I;&5.86UE*"1P86-K86=E+"`D8VAA
M;FYE;"D[#0H@("`@("`@("1R970@/2!`=6YL:6YK*"1F:6QE*3L-"B`@("`@
M("`@)'1H:7,M/E]R96)U:6QD1FEL94UA<"@I.PT*("`@("`@("`D=&AI<RT^
M7W5N;&]C:R@I.PT*("`@("`@("`D<"`](&%R<F%Y*"=C:&%N;F5L)R`]/B`D
M8VAA;FYE;"P@)W!A8VMA9V4G(#T^("1P86-K86=E*3L-"B`@("`@("`@)'1H
M:7,M/E]D97!E;F1E;F-Y1$(M/G5N:6YS=&%L;%!A8VMA9V4H)'`I.PT*("`@
M("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O
M+R![>WL@=7!D871E4&%C:V%G92@I#0H-"B`@("!F=6YC=&EO;B!U<&1A=&50
M86-K86=E*"1P86-K86=E+"`D:6YF;RP@)&UE<F=E(#T@=')U92D-"B`@("![
M#0H@("`@("`@(&EF("AI<U]O8FIE8W0H)&EN9F\I*2![#0H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G5P9&%T95!A8VMA9V4R*"1I;F9O+"`D;65R9V4I
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E(#T@
M)'1H:7,M/E]L;V-K*$Q/0TM?15@I*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1E.PT*("`@("`@("!]#0H@("`@("`@("1R970@/2`D=&AI<RT^7W5P9&%T
M95!A8VMA9V4H)'!A8VMA9V4L("1I;F9O+"`D;65R9V4I.PT*("`@("`@("`D
M=&AI<RT^7W5N;&]C:R@I.PT*("`@("`@("!I9B`H)')E="D@>PT*("`@("`@
M("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?4&%C:V%G949I;&5?=C$G
M*2D@>PT*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]086-K
M86=E1FEL92]V,2YP:'`G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M)'!F(#T@;F5W(%!%05)?4&%C:V%G949I;&5?=C$[#0H@("`@("`@("`@("`D
M<&8M/G-E=$-O;F9I9R@D=&AI<RT^7V-O;F9I9RD[#0H@("`@("`@("`@("`D
M<&8M/F9R;VU!<G)A>2@D=&AI<RT^<&%C:V%G94EN9F\H)'!A8VMA9V4I*3L-
M"B`@("`@("`@("`@("1T:&ES+3Y?9&5P96YD96YC>41"+3YU;FEN<W1A;&Q0
M86-K86=E*"1P9BD[#0H@("`@("`@("`@("`D=&AI<RT^7V1E<&5N9&5N8WE$
M0BT^:6YS=&%L;%!A8VMA9V4H)'!F*3L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@
M=7!D871E4&%C:V%G93(H*0T*#0H@("`@9G5N8W1I;VX@=7!D871E4&%C:V%G
M93(H)&EN9F\I#0H@("`@>PT*("`@("`@("!I9B`H(6ES7V]B:F5C="@D:6YF
M;RDI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=7!D871E4&%C:V%G
M92@D:6YF;ULG<&%C:V%G92==+"`D:6YF;RP@)&UE<F=E*3L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H(21I;F9O+3YV86QI9&%T92A014%27U9!3$E$051%
M7T1/5TY,3T%$24Y'*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E(#T@)'1H
M:7,M/E]L;V-K*$Q/0TM?15@I*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E
M.PT*("`@("`@("!]#0H@("`@("`@("1R970@/2`D=&AI<RT^7W5P9&%T95!A
M8VMA9V4R*"1I;F9O*3L-"B`@("`@("`@)'1H:7,M/E]U;FQO8VLH*3L-"B`@
M("`@("`@:68@*"1R970I('L-"B`@("`@("`@("`@("1T:&ES+3Y?9&5P96YD
M96YC>41"+3YU;FEN<W1A;&Q086-K86=E*"1I;F9O*3L-"B`@("`@("`@("`@
M("1T:&ES+3Y?9&5P96YD96YC>41"+3YI;G-T86QL4&%C:V%G92@D:6YF;RD[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=$-H86YN96PH*0T*("`@("\J*@T*
M("`@("`J($!P87)A;2!S=')I;F<@8VAA;FYE;"!N86UE#0H@("`@("H@0'!A
M<F%M(&)O;VP@=VAE=&AE<B!T;R!S=')I8W1L>2!R971U<FX@<F%W(&-H86YN
M96QS("AN;R!A;&EA<V5S*0T*("`@("`J($!R971U<FX@4$5!4E]#:&%N;F5L
M1FEL97Q014%27T5R<F]R#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F=E=$-H
M86YN96PH)&-H86YN96PL("1N;V%L:6%S97,@/2!F86QS92D-"B`@("![#0H@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E(#T@)'1H:7,M/E]L;V-K*$Q/
M0TM?4T@I*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E.PT*("`@("`@("!]
M#0H@("`@("`@("1R970@/2`F)'1H:7,M/E]G971#:&%N;F5L*"1C:&%N;F5L
M+"`D;F]A;&EA<V5S*3L-"B`@("`@("`@:68@*"$D<F5T*2![#0H@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G56YK;F]W;B!C:&%N;F5L
M.B`G("X@)&-H86YN96PI.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?
M=6YL;V-K*"D[#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!G971086-K86=E*"D-"B`@("`O*BH-"B`@
M("`@*B!`<&%R86T@<W1R:6YG('!A8VMA9V4@;F%M90T*("`@("`J($!P87)A
M;2!S=')I;F<@8VAA;FYE;"!N86UE#0H@("`@("H@0')E='5R;B!014%27U!A
M8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G949I;&5?=C)\;G5L;`T*("`@("`J
M+PT*("`@(&9U;F-T:6]N("9G971086-K86=E*"1P86-K86=E+"`D8VAA;FYE
M;"`]("=P96%R+G!H<"YN970G*0T*("`@('L-"B`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&4@/2`D=&AI<RT^7VQO8VLH3$]#2U]32"DI*2![#0H@("`@
M("`@("`@("!R971U<FX@)&4[#0H@("`@("`@('T-"B`@("`@("`@)'!F(#T@
M)B1T:&ES+3Y?9V5T4&%C:V%G92@D<&%C:V%G92P@)&-H86YN96PI.PT*("`@
M("`@("`D=&AI<RT^7W5N;&]C:R@I.PT*("`@("`@("!R971U<FX@)'!F.PT*
M("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@+RHJ#0H@("`@("H@1V5T(%!%
M05)?4&%C:V%G949I;&5?=ELQ+S)=(&]B:F5C=',@<F5P<F5S96YT:6YG('1H
M92!C;VYT96YT<R!O9@T*("`@("`J(&$@9&5P96YD96YC>2!G<F]U<"!T:&%T
M(&%R92!I;G-T86QL960N#0H@("`@("H-"B`@("`@*B!4:&ES(&ES('5S960@
M870@=6YI;G-T86QL+71I;64-"B`@("`@*B!`<&%R86T@87)R87D-"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y?&9A;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M9V5T26YS=&%L;&5D1W)O=7`H)&=R;W5P*0T*("`@('L-"B`@("`@("`@)')E
M="`](&%R<F%Y*"D[#0H@("`@("`@(&EF("AI<W-E="@D9W)O=7!;)W!A8VMA
M9V4G72DI('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&=R;W5P6R=P86-K
M86=E)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@)&=R;W5P6R=P86-K86=E
M)UT@/2!A<G)A>2@D9W)O=7!;)W!A8VMA9V4G72D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!F;W)E86-H("@D9W)O=7!;)W!A8VMA9V4G72!A<R`D
M<&%C:V%G92D@>PT*("`@("`@("`@("`@("`@("1D97!C:&%N;F5L(#T@:7-S
M970H)'!A8VMA9V5;)V-H86YN96PG72D@/R`D<&%C:V%G95LG8VAA;FYE;"==
M(#H@)U]?=7)I)SL-"B`@("`@("`@("`@("`@("`D<"`]("8D=&AI<RT^9V5T
M4&%C:V%G92@D<&%C:V%G95LG;F%M92==+"`D9&5P8VAA;FYE;"D[#0H@("`@
M("`@("`@("`@("`@:68@*"1P*2![#0H@("`@("`@("`@("`@("`@("`@("1S
M879E(#T@)B1P.PT*("`@("`@("`@("`@("`@("`@("`D<F5T6UT@/2`F)'-A
M=F4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(&EF("AI<W-E="@D9W)O=7!;)W-U8G!A8VMA9V4G72DI
M('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&=R;W5P6R=S=6)P86-K86=E
M)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@)&=R;W5P6R=S=6)P86-K86=E
M)UT@/2!A<G)A>2@D9W)O=7!;)W-U8G!A8VMA9V4G72D[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!F;W)E86-H("@D9W)O=7!;)W-U8G!A8VMA9V4G
M72!A<R`D<&%C:V%G92D@>PT*("`@("`@("`@("`@("`@("1D97!C:&%N;F5L
M(#T@:7-S970H)'!A8VMA9V5;)V-H86YN96PG72D@/R`D<&%C:V%G95LG8VAA
M;FYE;"==(#H@)U]?=7)I)SL-"B`@("`@("`@("`@("`@("`D<"`]("8D=&AI
M<RT^9V5T4&%C:V%G92@D<&%C:V%G95LG;F%M92==+"`D9&5P8VAA;FYE;"D[
M#0H@("`@("`@("`@("`@("`@:68@*"1P*2![#0H@("`@("`@("`@("`@("`@
M("`@("1S879E(#T@)B1P.PT*("`@("`@("`@("`@("`@("`@("`D<F5T6UT@
M/2`F)'-A=F4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(&EF("@A8V]U;G0H)')E="DI('L-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@)')E=#L-"B`@("!]#0H-"B`@("`O+R![>WL@9V5T0VAA;FYE;%9A;&ED
M871O<B@I#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9R!C:&%N;F5L
M(&YA;64-"B`@("`@*B!`<F5T=7)N(%!%05)?5F%L:61A=&5\9F%L<V4-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B`F9V5T0VAA;FYE;%9A;&ED871O<B@D8VAA
M;FYE;"D-"B`@("![#0H@("`@("`@("1C:&%N(#T@)'1H:7,M/F=E=$-H86YN
M96PH)&-H86YN96PI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VAA
M;BDI('L-"B`@("`@("`@("`@(')E='5R;B`D8VAA;CL-"B`@("`@("`@?0T*
M("`@("`@("`D=F%L(#T@)&-H86XM/F=E=%9A;&ED871I;VY/8FIE8W0H*3L-
M"B`@("`@("`@<F5T=7)N("1V86P[#0H@("`@?0T*("`@("\O('U]?0T*("`@
M("\O('M[>R!G971#:&%N;F5L<R@I#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M
M('-T<FEN9R!C:&%N;F5L(&YA;64-"B`@("`@*B!`<F5T=7)N(&%R<F%Y(&%N
M(&%R<F%Y(&]F(%!%05)?0VAA;FYE;$9I;&4@;V)J96-T<R!R97!R97-E;G1I
M;F<@979E<GD@:6YS=&%L;&5D(&-H86YN96P-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B`F9V5T0VAA;FYE;',H*0T*("`@('L-"B`@("`@("`@)')E="`](&%R
M<F%Y*"D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E(#T@)'1H:7,M
M/E]L;V-K*$Q/0TM?4T@I*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E.PT*
M("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?;&ES=$-H86YN
M96QS*"D@87,@)&-H86YN96PI('L-"B`@("`@("`@("`@("1E(#T@)B1T:&ES
M+3Y?9V5T0VAA;FYE;"@D8VAA;FYE;"D[#0H@("`@("`@("`@("!I9B`H(21E
M('Q\(%!%05(Z.FES17)R;W(H)&4I*2![#0H@("`@("`@("`@("`@("`@8V]N
M=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<F5T6UT@/2`D
M93L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W5N;&]C:R@I.PT*("`@
M("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O
M+R![>WL@8VAE8VM&:6QE36%P*"D-"@T*("`@("\J*@T*("`@("`J(%1E<W0@
M=VAE=&AE<B!A(&9I;&4@;W(@<V5T(&]F(&9I;&5S(&)E;&]N9W,@=&\@82!P
M86-K86=E+@T*("`@("`J#0H@("`@("H@268@86X@87)R87D@:7,@<&%S<V5D
M(&EN#0H@("`@("H@0'!A<F%M('-T<FEN9WQA<G)A>2!F:6QE('!A=&@L(&%B
M<V]L=71E(&]R(')E;&%T:79E('1O('1H92!P96%R#0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("!I;G-T86QL(&1I<@T*("`@("`J($!P87)A;2!S=')I
M;F=\87)R87D@;F%M92!O9B!014%2('!A8VMA9V4@;W(@87)R87DH)W!A8VMA
M9V4G(#T^(&YA;64L("=C:&%N;F5L)R`]/@T*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@8VAA;FYE;"D@;V8@82!P86-K86=E('1H870@=VEL;"!B92!I
M9VYO<F5D#0H@("`@("H@0'!A<F%M('-T<FEN9R!!4$D@=F5R<VEO;B`M(#$N
M,2!W:6QL(&5X8VQU9&4@86YY(&9I;&5S(&)E;&]N9VEN9R!T;R!A('!A8VMA
M9V4-"B`@("`@*B!`<&%R86T@87)R87D@<')I=F%T92!R96-U<G-I;VX@=F%R
M:6%B;&4-"B`@("`@*B!`<F5T=7)N(&%R<F%Y?&9A;'-E('=H:6-H('!A8VMA
M9V4@86YD(&-H86YN96P@=&AE(&9I;&4@8F5L;VYG<R!T;RP@;W(@86X@96UP
M='D-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@('-T<FEN9R!I9B!T:&4@
M9FEL92!D;V5S(&YO="!B96QO;F<@=&\@86X@:6YS=&%L;&5D('!A8VMA9V4L
M#0H@("`@("H@("`@("`@("`@("`@("`@("`@("!O<B!B96QO;F=S('1O('1H
M92!S96-O;F0@<&%R86UE=&5R)W,@<&%C:V%G90T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(&-H96-K1FEL94UA<"@D<&%T:"P@)'!A8VMA9V4@/2!F86QS92P@
M)&%P:2`]("<Q+C`G+"`D871T<G,@/2!F86QS92D-"B`@("![#0H@("`@("`@
M(&EF("AI<U]A<G)A>2@D<&%T:"DI('L-"B`@("`@("`@("`@('-T871I8R`D
M;F]T96UP='D[#0H@("`@("`@("`@("!I9B`H96UP='DH)&YO=&5M<'1Y*2D@
M>PT*("`@("`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27TEN
M<W1A;&QE<E]2;VQE)RDI('L-"B`@("`@("`@("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E("=014%2+TEN<W1A;&QE<B]2;VQE+G!H<"<[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("1N;W1E;7!T>2`](&-R96%T95]F
M=6YC=&EO;B@G)&$G+"=R971U<FX@(65M<'1Y*"1A*3LG*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("1P86-K86=E(#T@:7-?87)R87DH)'!A8VMA
M9V4I(#\@87)R87DH<W1R=&]L;W=E<B@D<&%C:V%G95LP72DL('-T<G1O;&]W
M97(H)'!A8VMA9V5;,5TI*0T*("`@("`@("`@("`@("`@(#H@<W1R=&]L;W=E
M<B@D<&%C:V%G92D[#0H@("`@("`@("`@("`D<&MG<R`](&%R<F%Y*"D[#0H@
M("`@("`@("`@("!F;W)E86-H("@D<&%T:"!A<R`D;F%M92`]/B`D871T<G,I
M('L-"B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)&%T=')S*2D@>PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%T=')S6R=I;G-T86QL
M+6%S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D;F%M92`]("1A
M='1R<ULG:6YS=&%L;"UA<R==.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@(&EF("@A:6Y?87)R87DH)&%T=')S6R=R;VQE
M)UTL(%!%05)?26YS=&%L;&5R7U)O;&4Z.F=E=$EN<W1A;&QA8FQE4F]L97,H
M*2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("\O('1H97-E(&%R92!N
M;W0@:6YS=&%L;&5D#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("!I9B`H(6EN7V%R<F%Y*"1A='1R<ULG<F]L92==+"!014%27TEN<W1A;&QE
M<E]2;VQE.CIG971"87-E:6YS=&%L;%)O;&5S*"DI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D871T<G-;)V)A<V5I;G-T86QL9&ER)UT@/2!I<U]A
M<G)A>2@D<&%C:V%G92D@/R`D<&%C:V%G95LQ72`Z("1P86-K86=E.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D871T<G-;)V)A<V5I;G-T86QL9&ER)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D;F%M92`]("1A='1R<ULG8F%S96EN<W1A;&QD:7(G
M72`N($1)4D5#5$]265]315!!4D%43U(@+B`D;F%M93L-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`D<&MG<ULD;F%M95T@/2`D=&AI<RT^8VAE8VM&:6QE36%P*"1N86UE+"`D
M<&%C:V%G92P@)&%P:2P@)&%T=')S*3L-"B`@("`@("`@("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D<&MG<ULD;F%M95TI*2![#0H@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D<&MG<ULD;F%M95T[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y7V9I
M;'1E<B@D<&MG<RP@)&YO=&5M<'1Y*3L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H96UP='DH)'1H:7,M/F9I;&5M87!?8V%C:&4I*2![#0H@("`@("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1T:&ES+3Y?;&]C:RA,3T-+7U-(
M*2DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)&4[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`D97)R(#T@)'1H:7,M/E]R96%D1FEL94UA<"@I
M.PT*("`@("`@("`@("`@)'1H:7,M/E]U;FQO8VLH*3L-"B`@("`@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1E<G(I*2![#0H@("`@("`@("`@("`@("`@
M<F5T=7)N("1E<G([#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"$D871T<G,I('L-"B`@("`@("`@("`@("1A='1R<R`](&%R<F%Y
M*"=R;VQE)R`]/B`G<&AP)RD[("\O(&%N>2!O;&0@8V%L;"!W;W5L9"!B92!F
M;W(@4$A0(')O;&4@;VYL>0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^9FEL96UA<%]C86-H95LD871T<G-;)W)O;&4G75U;)'!A=&A=
M*2D@>PT*("`@("`@("`@("`@:68@*"1A<&D@/CT@)S$N,2<@)B8@)'1H:7,M
M/F9I;&5M87!?8V%C:&5;)&%T=')S6R=R;VQE)UU=6R1P871H72`]/2`D<&%C
M:V%G92D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9FEL96UA<%]C
M86-H95LD871T<G-;)W)O;&4G75U;)'!A=&A=.PT*("`@("`@("!]#0H@("`@
M("`@("1L(#T@<W1R;&5N*"1T:&ES+3YI;G-T86QL7V1I<BD[#0H@("`@("`@
M(&EF("AS=6)S='(H)'!A=&@L(#`L("1L*2`]/2`D=&AI<RT^:6YS=&%L;%]D
M:7(I('L-"B`@("`@("`@("`@("1P871H(#T@<')E9U]R97!L86-E*"<A7B<N
M1$E214-43U)97U-%4$%2051/4BXG*R$G+"`G)RP@<W5B<W1R*"1P871H+"`D
M;"DI.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^9FEL
M96UA<%]C86-H95LD871T<G-;)W)O;&4G75U;)'!A=&A=*2D@>PT*("`@("`@
M("`@("`@:68@*"1A<&D@/CT@)S$N,2<@)B8@)'1H:7,M/F9I;&5M87!?8V%C
M:&5;)&%T=')S6R=R;VQE)UU=6R1P871H72`]/2`D<&%C:V%G92D@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^9FEL96UA<%]C86-H95LD871T<G-;
M)W)O;&4G75U;)'!A=&A=.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@87!I5F5R
M<VEO;B@I#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!E>'!E8W1E9"!!4$D@
M=F5R<VEO;BX@($-H86YN96QS($%022!I<R!V97)S:6]N(#$N,2P@87,@:70@
M:7,@8F%C:W=A<F1S#0H@("`@("H@8V]M<&%T:6)L92!W:71H(#$N,`T*("`@
M("`J($!R971U<FX@<W1R:6YG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@87!I
M5F5R<VEO;B@I#0H@("`@>PT*("`@("`@("!R971U<FX@)S$N,2<[#0H@("`@
M?0T*("`@("\O('U]?0T*#0H-"B`@("`O*BH-"B`@("`@*B!087)S92!A('!A
M8VMA9V4@;F%M92P@;W(@=F%L:61A=&4@82!P87)S960@<&%C:V%G92!N86UE
M(&%R<F%Y#0H@("`@("H@0'!A<F%M('-T<FEN9WQA<G)A>2!P87-S(&EN(&%N
M(&%R<F%Y(&]F(&9O<FUA=`T*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M87)R87DH#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@)W!A8VMA9V4G
M(#T^("=P;F%M92<L#0H@("`@("H@("`@("`@("`@("`@("`@("`@("!;)V-H
M86YN96PG(#T^("=C:&%N;F%M92<L70T*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@6R=V97)S:6]N)R`]/B`G=F5R<VEO;B<L70T*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@6R=S=&%T92<@/3X@)W-T871E)RQ=#0H@("`@("H@
M("`@("`@("`@("`@("`@("`@("!;)V=R;W5P)R`]/B`G9W)O=7!N86UE)UTI
M#0H@("`@("H@("`@("`@("`@("`@("`@("`@("!O<B!A('-T<FEN9R!O9B!F
M;W)M870-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(%MC:&%N;F5L.B\O
M75MC:&%N;F%M92]=<&YA;65;+79E<G-I;VY\+7-T871E75LO9W)O=7`]9W)O
M=7!N86UE70T*("`@("`J($!R971U<FX@87)R87E\4$5!4E]%<G)O<@T*("`@
M("`J+PT*("`@(&9U;F-T:6]N('!A<G-E4&%C:V%G94YA;64H)'!A<F%M+"`D
M9&5F875L=&-H86YN96P@/2`G<&5A<BYP:'`N;F5T)RD-"B`@("![#0H@("`@
M("`@("1S879E<&%R86T@/2`D<&%R86T[#0H@("`@("`@(&EF("AI<U]A<G)A
M>2@D<&%R86TI*2![#0H@("`@("`@("`@("`O+R!C;VYV97)T('1O('-T<FEN
M9R!F;W(@97)R;W(@;65S<V%G97,-"B`@("`@("`@("`@("1S879E<&%R86T@
M/2`D=&AI<RT^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@D<&%R86TI.PT*
M("`@("`@("`@("`@+R\@<')O8V5S<R!T:&4@87)R87D-"B`@("`@("`@("`@
M(&EF("@A:7-S970H)'!A<F%M6R=P86-K86=E)UTI*2![#0H@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)W!A<G-E4&%C:V%G94YA
M;64H*3H@87)R87D@)'!A<F%M("<@+@T*("`@("`@("`@("`@("`@("`@("`G
M;75S="!C;VYT86EN(&$@=F%L:60@<&%C:V%G92!N86UE(&EN(&EN9&5X(")P
M87)A;2(G+`T*("`@("`@("`@("`@("`@("`@("`G<&%C:V%G92<L(&YU;&PL
M(&YU;&PL("1P87)A;2D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1P87)A;5LG=7)I)UTI*2![#0H@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D<&%R86U;)V-H86YN96PG72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)'!A<F%M6R=C:&%N;F5L)UT@/2`D9&5F875L=&-H86YN96P[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`D<&%R86U;)V-H86YN96PG72`]("=?7W5R:2<[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M8V]M<&]N96YT<R`]($!P87)S95]U<FPH)'!A<F%M*3L-"B`@("`@("`@("`@
M(&EF("AI<W-E="@D8V]M<&]N96YT<ULG<V-H96UE)UTI*2![#0H@("`@("`@
M("`@("`@("`@:68@*"1C;VUP;VYE;G1S6R=S8VAE;64G72`]/2`G:'1T<"<I
M('L-"B`@("`@("`@("`@("`@("`@("`@+R\@=7)I('!A8VMA9V4-"B`@("`@
M("`@("`@("`@("`@("`@)'!A<F%M(#T@87)R87DH)W5R:2<@/3X@)'!A<F%M
M+"`G8VAA;FYE;"<@/3X@)U]?=7)I)RD[#0H@("`@("`@("`@("`@("`@?2!E
M;'-E:68H)&-O;7!O;F5N='-;)W-C:&5M92==("$]("=C:&%N;F5L)RD@>PT*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G
M<&%R<V5086-K86=E3F%M92@I.B!O;FQY(&-H86YN96PZ+R\@=7)I<R!M87D@
M)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G8F4@9&]W;FQO861E9"P@
M;F]T("(G("X@)'!A<F%M("X@)R(G+"`G:6YV86QI9"<L(&YU;&PL(&YU;&PL
M("1P87)A;2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*"%I<W-E="@D8V]M<&]N96YT<ULG<&%T:"==*2D@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=P
M87)S95!A8VMA9V5.86UE*"DZ(&%R<F%Y("1P87)A;2`G("X-"B`@("`@("`@
M("`@("`@("`@("`@)VUU<W0@8V]N=&%I;B!A('9A;&ED('!A8VMA9V4@;F%M
M92!I;B`B)R`N("1P87)A;2`N("<B)RP-"B`@("`@("`@("`@("`@("`@("`@
M)W!A8VMA9V4G+"!N=6QL+"!N=6QL+"`D<&%R86TI.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1C;VUP;VYE;G1S6R=H;W-T)UTI
M*2![#0H@("`@("`@("`@("`@("`@+R\@<F5M;W9E('1H92!L96%D:6YG("(O
M(@T*("`@("`@("`@("`@("`@("1C;VUP;VYE;G1S6R=P871H)UT@/2!S=6)S
M='(H)&-O;7!O;F5N='-;)W!A=&@G72P@,2D[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1C;VUP;VYE;G1S6R=S8VAE;64G72DI
M('L-"B`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1C;VUP;VYE;G1S6R=P
M871H)UTL("<O)RD@(3T](&9A;'-E*2![#0H@("`@("`@("`@("`@("`@("`@
M(&EF("@D8V]M<&]N96YT<ULG<&%T:"==>S!](#T]("<O)RD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)W!A
M<G-E4&%C:V%G94YA;64H*3H@=&AI<R!I<R!N;W0@)R`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V$@<&%C:V%G92!N86UE+"!I="!B96=I;G,@
M=VET:"`B+R(@:6X@(B<@+B`D<&%R86T@+B`G(B<L#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VEN=F%L:60G+"!N=6QL+"!N=6QL+"`D<&%R86TI
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("1P87)T<R`](&5X<&QO9&4H)R\G+"`D8V]M<&]N96YT<ULG<&%T:"==*3L-
M"B`@("`@("`@("`@("`@("`@("`@)&-O;7!O;F5N='-;)VAO<W0G72`](&%R
M<F%Y7W-H:69T*"1P87)T<RD[#0H@("`@("`@("`@("`@("`@("`@(&EF("AC
M;W5N="@D<&%R=',I(#X@,2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)&-O;7!O;F5N='-;)W!A=&@G72`](&%R<F%Y7W!O<"@D<&%R=',I.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)&-O;7!O;F5N='-;)VAO<W0G72`N/2`G
M+R<@+B!I;7!L;V1E*"<O)RP@)'!A<G1S*3L-"B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C;VUP;VYE
M;G1S6R=P871H)UT@/2!I;7!L;V1E*"<O)RP@)'!A<G1S*3L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@("1C;VUP;VYE;G1S6R=H;W-T)UT@/2`D9&5F875L
M=&-H86YN96P[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1C;VUP;VYE;G1S
M6R=P871H)UTL("<O)RDI('L-"B`@("`@("`@("`@("`@("`@("`@)'!A<G1S
M(#T@97AP;&]D92@G+R<L("1C;VUP;VYE;G1S6R=P871H)UTI.PT*("`@("`@
M("`@("`@("`@("`@("`D8V]M<&]N96YT<ULG<&%T:"==(#T@87)R87E?<&]P
M*"1P87)T<RD[#0H@("`@("`@("`@("`@("`@("`@("1C;VUP;VYE;G1S6R=H
M;W-T)UT@+CT@)R\G("X@:6UP;&]D92@G+R<L("1P87)T<RD[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("!I9B`H
M:7-?87)R87DH)'!A<F%M*2D@>PT*("`@("`@("`@("`@("`@("1P87)A;5LG
M<&%C:V%G92==(#T@)&-O;7!O;F5N='-;)W!A=&@G73L-"B`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@)'!A<F%M(#T@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("=P86-K86=E)R`]/B`D8V]M<&]N96YT<ULG
M<&%T:"==#0H@("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1C;VUP;VYE;G1S6R=H;W-T)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("1P87)A;5LG8VAA;FYE;"==(#T@)&-O;7!O;F5N='-;
M)VAO<W0G73L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!I9B`H:7-S970H)&-O;7!O;F5N='-;)V9R86=M96YT)UTI
M*2![#0H@("`@("`@("`@("`@("`@)'!A<F%M6R=G<F]U<"==(#T@)&-O;7!O
M;F5N='-;)V9R86=M96YT)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H:7-S970H)&-O;7!O;F5N='-;)W5S97(G72DI('L-"B`@("`@("`@
M("`@("`@("`D<&%R86U;)W5S97(G72`]("1C;VUP;VYE;G1S6R=U<V5R)UT[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)&-O;7!O
M;F5N='-;)W!A<W,G72DI('L-"B`@("`@("`@("`@("`@("`D<&%R86U;)W!A
M<W,G72`]("1C;VUP;VYE;G1S6R=P87-S)UT[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!I9B`H:7-S970H)&-O;7!O;F5N='-;)W%U97)Y)UTI*2![
M#0H@("`@("`@("`@("`@("`@<&%R<V5?<W1R*"1C;VUP;VYE;G1S6R=Q=65R
M>2==+"`D<&%R86U;)V]P=',G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`O+R!C:&5C:R!F;W(@97AT96YS:6]N#0H@("`@("`@("`@("`D<&%T
M:&EN9F\@/2!P871H:6YF;R@D<&%R86U;)W!A8VMA9V4G72D[#0H@("`@("`@
M("`@("!I9B`H:7-S970H)'!A=&AI;F9O6R=E>'1E;G-I;VXG72D@)B8-"B`@
M("`@("`@("`@("`@("`@(&EN7V%R<F%Y*'-T<G1O;&]W97(H)'!A=&AI;F9O
M6R=E>'1E;G-I;VXG72DL(&%R<F%Y*"=T9WHG+"`G=&%R)RDI*2![#0H@("`@
M("`@("`@("`@("`@)'!A<F%M6R=E>'1E;G-I;VXG72`]("1P871H:6YF;ULG
M97AT96YS:6]N)UT[#0H@("`@("`@("`@("`@("`@)'!A<F%M6R=P86-K86=E
M)UT@/2!S=6)S='(H)'!A=&AI;F9O6R=B87-E;F%M92==+"`P+`T*("`@("`@
M("`@("`@("`@("`@("!S=')L96XH)'!A=&AI;F9O6R=B87-E;F%M92==*2`M
M(#0I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@+R\@8VAE8VL@9F]R
M('9E<G-I;VX-"B`@("`@("`@("`@(&EF("AS=')P;W,H)'!A<F%M6R=P86-K
M86=E)UTL("<M)RDI('L-"B`@("`@("`@("`@("`@("`D=&5S="`](&5X<&QO
M9&4H)RTG+"`D<&%R86U;)W!A8VMA9V4G72D[#0H@("`@("`@("`@("`@("`@
M:68@*&-O=6YT*"1T97-T*2`A/2`R*2![#0H@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*"=P87)S95!A8VMA9V5.86UE*"DZ
M(&]N;'D@;VYE('9E<G-I;VXO<W1A=&4@)R`N#0H@("`@("`@("`@("`@("`@
M("`@("`@("`G9&5L:6UI=&5R("(M(B!I<R!A;&QO=V5D(&EN("(G("X@)'-A
M=F5P87)A;2`N("<B)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("=V97)S
M:6]N)RP@;G5L;"P@;G5L;"P@)'!A<F%M*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@;&ES="@D<&%R86U;)W!A8VMA9V4G72P@)'!A
M<F%M6R=V97)S:6]N)UTI(#T@)'1E<W0[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@+R\@=F%L:61A=&EO;@T*("`@("`@("`D:6YF;R`]
M("1T:&ES+3YC:&%N;F5L17AI<W1S*"1P87)A;5LG8VAA;FYE;"==*3L-"B`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\I*2![#0H@("`@("`@("`@
M("!R971U<FX@)&EN9F\[#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D:6YF
M;RD@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)W5N
M:VYO=VX@8VAA;FYE;"`B)R`N("1P87)A;5LG8VAA;FYE;"==("X-"B`@("`@
M("`@("`@("`@("`G(B!I;B`B)R`N("1S879E<&%R86T@+B`G(B<L("=C:&%N
M;F5L)RP@;G5L;"P@;G5L;"P@)'!A<F%M*3L-"B`@("`@("`@?0T*("`@("`@
M("`D8VAA;B`]("1T:&ES+3YG971#:&%N;F5L*"1P87)A;5LG8VAA;FYE;"==
M*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&-H86XI*2![#0H@("`@
M("`@("`@("!R971U<FX@)&-H86X[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"$D8VAA;BD@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H(D5X8V5P=&EO;CH@8V]R<G5P="!R96=I<W1R>2P@8V]U;&0@;F]T("(@
M+@T*("`@("`@("`@("`@("`@(")R971R:65V92!C:&%N;F5L("(@+B`D<&%R
M86U;)V-H86YN96PG72`N("(@:6YF;W)M871I;VXB+`T*("`@("`@("`@("`@
M("`@("=R96=I<W1R>2<L(&YU;&PL(&YU;&PL("1P87)A;2D[#0H@("`@("`@
M('T-"B`@("`@("`@)'!A<F%M6R=C:&%N;F5L)UT@/2`D8VAA;BT^9V5T3F%M
M92@I.PT*("`@("`@("`D=F%L:61A=&4@/2`D8VAA;BT^9V5T5F%L:61A=&EO
M;D]B:F5C="@I.PT*("`@("`@("`D=G!A8VMA9V4@/2`D8VAA;BT^9V5T5F%L
M:61A=&EO;E!A8VMA9V4H*3L-"B`@("`@("`@+R\@=F%L:61A=&4@<&%C:V%G
M92!N86UE#0H@("`@("`@(&EF("@A)'9A;&ED871E+3YV86QI9%!A8VMA9V5.
M86UE*"1P87)A;5LG<&%C:V%G92==+"`D=G!A8VMA9V5;)U]C;VYT96YT)UTI
M*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G<&%R
M<V5086-K86=E3F%M92@I.B!I;G9A;&ED('!A8VMA9V4@;F%M92`B)R`N#0H@
M("`@("`@("`@("`@("`@)'!A<F%M6R=P86-K86=E)UT@+B`G(B!I;B`B)R`N
M("1S879E<&%R86T@+B`G(B<L#0H@("`@("`@("`@("`@("`@)W!A8VMA9V4G
M+"!N=6QL+"!N=6QL+"`D<&%R86TI.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("AI<W-E="@D<&%R86U;)V=R;W5P)UTI*2![#0H@("`@("`@("`@("!I9B`H
M(5!%05)?5F%L:61A=&4Z.G9A;&ED1W)O=7!.86UE*"1P87)A;5LG9W)O=7`G
M72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G<&%R<V5086-K86=E3F%M92@I.B!D97!E;F1E;F-Y(&=R;W5P("(G("X@
M)'!A<F%M6R=G<F]U<"==("X-"B`@("`@("`@("`@("`@("`@("`@)R(@:7,@
M;F]T(&$@=F%L:60@9W)O=7`@;F%M92!I;B`B)R`N("1S879E<&%R86T@+B`G
M(B<L("=G<F]U<"<L(&YU;&PL(&YU;&PL#0H@("`@("`@("`@("`@("`@("`@
M("1P87)A;2D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES<V5T*"1P87)A;5LG<W1A=&4G72DI('L-"B`@("`@("`@("`@(&EF
M("@A:6Y?87)R87DH<W1R=&]L;W=E<B@D<&%R86U;)W-T871E)UTI+"`D=F%L
M:61A=&4M/F=E=%9A;&ED4W1A=&5S*"DI*2![#0H@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)W!A<G-E4&%C:V%G94YA;64H*3H@
M<W1A=&4@(B<@+B`D<&%R86U;)W-T871E)UT-"B`@("`@("`@("`@("`@("`@
M("`@+B`G(B!I<R!N;W0@82!V86QI9"!S=&%T92!I;B`B)R`N("1S879E<&%R
M86T@+B`G(B<L#0H@("`@("`@("`@("`@("`@("`@("=S=&%T92<L(&YU;&PL
M(&YU;&PL("1P87)A;2D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@:68@*&ES<V5T*"1P87)A;5LG=F5R<VEO;B==*2D@>PT*("`@("`@
M("`@("`@:68@*&ES<V5T*"1P87)A;5LG<W1A=&4G72DI('L-"B`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G<&%R<V5086-K86=E
M3F%M92@I.B!C86YN;W0@8V]N=&%I;B!B;W1H("<@+@T*("`@("`@("`@("`@
M("`@("`@("`G82!V97)S:6]N(&%N9"!A('-T86)I;&ET>2`H<W1A=&4I(&EN
M("(G("X@)'-A=F5P87)A;2`N("<B)RP-"B`@("`@("`@("`@("`@("`@("`@
M)W9E<G-I;VXO<W1A=&4G+"!N=6QL+"!N=6QL+"`D<&%R86TI.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@+R\@8VAE8VL@=VAE=&AE<B!V97)S:6]N
M(&ES(&%C='5A;&QY(&$@<W1A=&4-"B`@("`@("`@("`@(&EF("AI;E]A<G)A
M>2AS=')T;VQO=V5R*"1P87)A;5LG=F5R<VEO;B==*2P@)'9A;&ED871E+3YG
M971686QI9%-T871E<R@I*2D@>PT*("`@("`@("`@("`@("`@("1P87)A;5LG
M<W1A=&4G72`]('-T<G1O;&]W97(H)'!A<F%M6R=V97)S:6]N)UTI.PT*("`@
M("`@("`@("`@("`@('5N<V5T*"1P87)A;5LG=F5R<VEO;B==*3L-"B`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@:68@*"$D=F%L:61A
M=&4M/G9A;&ED5F5R<VEO;B@D<&%R86U;)W9E<G-I;VXG72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)W!A<G-E
M4&%C:V%G94YA;64H*3H@(B<@+B`D<&%R86U;)W9E<G-I;VXG72`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`G(B!I<R!N96ET:&5R(&$@=F%L:60@=F5R
M<VEO;B!N;W(@82!V86QI9"!S=&%T92!I;B`B)R`N#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D<V%V97!A<F%M("X@)R(G+"`G=F5R<VEO;B]S=&%T92<L
M(&YU;&PL(&YU;&PL("1P87)A;2D[#0H@("`@("`@("`@("`@("`@?2`@("`@
M("`@("`@("`@("`@("`@#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N("1P87)A;3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!`<&%R86T@87)R87D-"B`@("`@*B!`<F5T=7)N('-T<FEN9PT*("`@("`J
M+PT*("`@(&9U;F-T:6]N('!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H)'!A
M<G-E9"P@)&)R:65F(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H:7-?
M<W1R:6YG*"1P87)S960I*2![#0H@("`@("`@("`@("!R971U<FX@)'!A<G-E
M9#L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-?;V)J96-T*"1P87)S960I
M*2![#0H@("`@("`@("`@("`D<"`]("1P87)S960[#0H@("`@("`@("`@("`D
M<&%R<V5D(#T@87)R87DH#0H@("`@("`@("`@("`@("`@)W!A8VMA9V4G(#T^
M("1P+3YG971086-K86=E*"DL#0H@("`@("`@("`@("`@("`@)V-H86YN96PG
M(#T^("1P+3YG971#:&%N;F5L*"DL#0H@("`@("`@("`@("`@("`@)W9E<G-I
M;VXG(#T^("1P+3YG971697)S:6]N*"DL#0H@("`@("`@("`@("`I.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D<&%R<V5D6R=U<FDG72DI('L-
M"B`@("`@("`@("`@(')E='5R;B`D<&%R<V5D6R=U<FDG73L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H)&)R:65F*2![#0H@("`@("`@("`@("!I9B`H)&-H
M86YN96P@/2`D=&AI<RT^8VAA;FYE;$%L:6%S*"1P87)S961;)V-H86YN96PG
M72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)&-H86YN96P@+B`G+R<@
M+B`D<&%R<V5D6R=P86-K86=E)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@)'5P87-S(#T@)R<[#0H@("`@("`@(&EF("AI<W-E="@D
M<&%R<V5D6R=U<V5R)UTI*2![#0H@("`@("`@("`@("`D=7!A<W,@/2`D<&%R
M<V5D6R=U<V5R)UT[#0H@("`@("`@("`@("!I9B`H:7-S970H)'!A<G-E9%LG
M<&%S<R==*2D@>PT*("`@("`@("`@("`@("`@("1U<&%S<R`N/2`G.B<@+B`D
M<&%R<V5D6R=P87-S)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D
M=7!A<W,@/2`B)'5P87-S0"([#0H@("`@("`@('T-"B`@("`@("`@)')E="`]
M("=C:&%N;F5L.B\O)R`N("1U<&%S<R`N("1P87)S961;)V-H86YN96PG72`N
M("<O)R`N("1P87)S961;)W!A8VMA9V4G73L-"B`@("`@("`@:68@*&ES<V5T
M*"1P87)S961;)W9E<G-I;VXG72D@?'P@:7-S970H)'!A<G-E9%LG<W1A=&4G
M72DI('L-"B`@("`@("`@("`@("1R970@+CT@)RTG("X@0"1P87)S961;)W9E
M<G-I;VXG72`N($`D<&%R<V5D6R=S=&%T92==.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("AI<W-E="@D<&%R<V5D6R=E>'1E;G-I;VXG72DI('L-"B`@("`@
M("`@("`@("1R970@+CT@)RXG("X@)'!A<G-E9%LG97AT96YS:6]N)UT[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1P87)S961;)V]P=',G72DI
M('L-"B`@("`@("`@("`@("1R970@+CT@)S\G.PT*("`@("`@("`@("`@9F]R
M96%C:"`H)'!A<G-E9%LG;W!T<R==(&%S("1N86UE(#T^("1V86QU92D@>PT*
M("`@("`@("`@("`@("`@("1P87)S961;)V]P=',G75LD;F%M95T@/2`B)&YA
M;64])'9A;'5E(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1R970@
M+CT@:6UP;&]D92@G)B<L("1P87)S961;)V]P=',G72D[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*&ES<V5T*"1P87)S961;)V=R;W5P)UTI*2![#0H@("`@
M("`@("`@("`D<F5T("X]("<C)R`N("1P87)S961;)V=R;W5P)UT[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*?0T*#0H_/@T*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]2
M96UO=&4N<&AP````````````````````````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P-#4S-C,`,3`U,34T,S,W-#$`,#(Q,S$P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP#0HO*BH-"B`J(%!%05)?
M4F5M;W1E#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,
M24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO
M;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L
M92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG
M(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N
M("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(
M4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P
M:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN
M#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!
M4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*
M("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@
M(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%)E
M;6]T92YP:'`L=B`Q+C<V(#(P,#8O,#,O,#(@,3@Z,30Z,3,@8V5L;&]G($5X
M<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA
M9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@
M4F5L96%S92`P+C$-"B`J+PT*#0HO*BH-"B`J(&YE961E9"!F;W(@4$5!4E]%
M<G)O<@T*("HO#0IR97%U:7)E7V]N8V4@)U!%05(N<&AP)SL-"G)E<75I<F5?
M;VYC92`G4$5!4B]#;VYF:6<N<&AP)SL-"@T*+RHJ#0H@*B!4:&ES(&ES(&$@
M8VQA<W,@9F]R(&1O:6YG(')E;6]T92!O<&5R871I;VYS(&%G86EN<W0@=&AE
M(&-E;G1R86P-"B`J(%!%05(@9&%T86)A<V4N#0H@*@T*("H@0&YO9&5P(%A-
M3%]24$-?5F%L=64-"B`J($!N;V1E<"!834Q?4E!#7TUE<W-A9V4-"B`J($!N
M;V1E<"!834Q?4E!#7T-L:65N=`T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@
M0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@
M/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E
M;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!0
M2%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@
M("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*8VQA<W,@4$5!4E]2
M96UO=&4@97AT96YD<R!014%2#0I[#0H@("`@+R\@>WM[('!R;W!E<G1I97,-
M"@T*("`@('9A<B`D8V]N9FEG(#T@;G5L;#L-"B`@("!V87(@)&-A8VAE("`]
M(&YU;&P[#0H@("`@+RHJ#0H@("`@("H@0'9A<B!014%27U)E9VES=')Y#0H@
M("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?<F5G
M:7-T<GD[#0H-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!014%27U)E;6]T
M92AC;VYF:6=?;V)J96-T*0T*#0H@("`@9G5N8W1I;VX@4$5!4E]296UO=&4H
M)B1C;VYF:6<I#0H@("`@>PT*("`@("`@("`D=&AI<RT^4$5!4B@I.PT*("`@
M("`@("`D=&AI<RT^8V]N9FEG(#T@)B1C;VYF:6<[#0H@("`@("`@("1T:&ES
M+3Y?<F5G:7-T<GD@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-
M"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@<V5T4F5G:7-T<GDH
M*0T*("`@(`T*("`@(&9U;F-T:6]N('-E=%)E9VES=')Y*"8D<F5G*0T*("`@
M('L-"B`@("`@("`@)'1H:7,M/E]R96=I<W1R>2`]("8D<F5G.PT*("`@('T-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T0V%C:&4H*0T*#0H-"B`@("!F
M=6YC=&EO;B!G971#86-H92@D87)G<RD-"B`@("![#0H@("`@("`@("1I9"`@
M("`@("`](&UD-2AS97)I86QI>F4H)&%R9W,I*3L-"B`@("`@("`@)&-A8VAE
M9&ER(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=C86-H95]D:7(G*3L-"B`@("`@
M("`@)&9I;&5N86UE(#T@)&-A8VAE9&ER("X@1$E214-43U)97U-%4$%2051/
M4B`N("=X;6QR<&-?8V%C:&5?)R`N("1I9#L-"B`@("`@("`@:68@*"%F:6QE
M7V5X:7-T<R@D9FEL96YA;64I*2![#0H@("`@("`@("`@("!R971U<FX@;G5L
M;#L-"B`@("`@("`@?0T*#0H@("`@("`@("1F<"`](&9O<&5N*"1F:6QE;F%M
M92P@)W)B)RD[#0H@("`@("`@(&EF("@A)&9P*2![#0H@("`@("`@("`@("!R
M971U<FX@;G5L;#L-"B`@("`@("`@?0T*("`@("`@("!I9B`H9G5N8W1I;VY?
M97AI<W1S*"=F:6QE7V=E=%]C;VYT96YT<R<I*2![#0H@("`@("`@("`@("!F
M8VQO<V4H)&9P*3L-"B`@("`@("`@("`@("1C;VYT96YT(#T@9FEL95]G971?
M8V]N=&5N=',H)&9I;&5N86UE*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1C;VYT96YT("`](&9R96%D*"1F<"P@9FEL97-I>F4H)&9I;&5N
M86UE*2D[#0H@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@?0T*
M("`@("`@("`D<F5S=6QT("`@/2!A<G)A>2@-"B`@("`@("`@("`@("=A9V4G
M("`@("`@("`]/B!T:6UE*"D@+2!F:6QE;71I;64H)&9I;&5N86UE*2P-"B`@
M("`@("`@("`@("=L87-T0VAA;F=E)R`]/B!F:6QE;71I;64H)&9I;&5N86UE
M*2P-"B`@("`@("`@("`@("=C;VYT96YT)R`@("`]/B!U;G-E<FEA;&EZ92@D
M8V]N=&5N="DL#0H@("`@("`@("`@("`I.PT*("`@("`@("!R971U<FX@)')E
M<W5L=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!S879E
M0V%C:&4H*0T*#0H@("`@9G5N8W1I;VX@<V%V94-A8VAE*"1A<F=S+"`D9&%T
M82D-"B`@("![#0H@("`@("`@("1I9"`@("`@("`](&UD-2AS97)I86QI>F4H
M)&%R9W,I*3L-"B`@("`@("`@)&-A8VAE9&ER(#T@)'1H:7,M/F-O;F9I9RT^
M9V5T*"=C86-H95]D:7(G*3L-"B`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D
M8V%C:&5D:7(I*2![#0H@("`@("`@("`@("!3>7-T96TZ.FUK9&ER*&%R<F%Y
M*"<M<"<L("1C86-H961I<BDI.PT*("`@("`@("!]#0H@("`@("`@("1F:6QE
M;F%M92`]("1C86-H961I<BXG+WAM;')P8U]C86-H95\G+B1I9#L-"@T*("`@
M("`@("`D9G`@/2!`9F]P96XH)&9I;&5N86UE+"`B=V(B*3L-"B`@("`@("`@
M:68@*"1F<"D@>PT*("`@("`@("`@("`@9G=R:71E*"1F<"P@<V5R:6%L:7IE
M*"1D871A*2D[#0H@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@
M?0T*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&-L96%R0V%C
M:&4H*0T*#0H@("`@9G5N8W1I;VX@8VQE87)#86-H92@D;65T:&]D+"`D87)G
M<RD-"B`@("![#0H@("`@("`@(&%R<F%Y7W5N<VAI9G0H)&%R9W,L("1M971H
M;V0I.PT*("`@("`@("!A<G)A>5]U;G-H:69T*"1A<F=S+"`D=&AI<RT^8V]N
M9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I*3L@+R\@8V%C:&4@8GD@8VAA
M;FYE;`T*("`@("`@("`D:60@("`@("`@/2!M9#4H<V5R:6%L:7IE*"1A<F=S
M*2D[#0H@("`@("`@("1C86-H961I<B`]("1T:&ES+3YC;VYF:6<M/F=E="@G
M8V%C:&5?9&ER)RD[#0H@("`@("`@("1F:6QE;F%M92`]("1C86-H961I<BXG
M+WAM;')P8U]C86-H95\G+B1I9#L-"B`@("`@("`@:68@*&9I;&5?97AI<W1S
M*"1F:6QE;F%M92DI('L-"B`@("`@("`@("`@($!U;FQI;FLH)&9I;&5N86UE
M*3L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[
M>R!C86QL*&UE=&AO9"P@6V%R9W,N+BY=*0T*#0H@("`@9G5N8W1I;VX@8V%L
M;"@D;65T:&]D*0T*("`@('L-"B`@("`@("`@)%]A<F=S(#T@)&%R9W,@/2!F
M=6YC7V=E=%]A<F=S*"D[#0H-"B`@("`@("`@)'-E<G9E<E]C:&%N;F5L(#T@
M)'1H:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*3L-"B`@("`@
M("`@)&-H86YN96P@/2`D=&AI<RT^7W)E9VES=')Y+3YG971#:&%N;F5L*"1S
M97)V97)?8VAA;FYE;"D[#0H@("`@("`@(&EF("@A4$5!4CHZ:7-%<G)O<B@D
M8VAA;FYE;"DI('L-"B`@("`@("`@("`@("1M:7)R;W(@/2`D=&AI<RT^8V]N
M9FEG+3YG970H)W!R969E<G)E9%]M:7)R;W(G*3L-"B`@("`@("`@("`@(&EF
M("@D8VAA;FYE;"T^9V5T36ER<F]R*"1M:7)R;W(I*2![#0H@("`@("`@("`@
M("`@("`@:68@*"1C:&%N;F5L+3YS=7!P;W)T<R@G>&UL<G!C)RP@)&UE=&AO
M9"P@)&UI<G)O<BDI('L-"B`@("`@("`@("`@("`@("`@("`@)'-E<G9E<E]C
M:&%N;F5L(#T@)'-E<G9E<E]H;W-T(#T@)&UI<G)O<CL@+R\@=7-E('1H92!P
M<F5F97)R960@;6ER<F]R#0H@("`@("`@("`@("`@("`@("`@("1S97)V97)?
M<&]R="`]("1C:&%N;F5L+3YG9710;W)T*"1M:7)R;W(I.PT*("`@("`@("`@
M("`@("`@('T@96QS96EF("@A)&-H86YN96PM/G-U<'!O<G1S*"=X;6QR<&,G
M+"`D;65T:&]D*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H(D-H86YN96P@)'-E<G9E<E]C:&%N;F5L(&1O97,@
M;F]T("(@+@T*("`@("`@("`@("`@("`@("`@("`@("`@(G-U<'!O<G0@>&UL
M+7)P8R!M971H;V0@)&UE=&AO9"(I.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-S970H)'-E<G9E<E]H
M;W-T*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A)&-H86YN96PM/G-U<'!O
M<G1S*"=X;6QR<&,G+"`D;65T:&]D*2D@>PT*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D-H86YN96P@)'-E<G9E<E]C
M:&%N;F5L(&1O97,@;F]T('-U<'!O<G0@(B`N#0H@("`@("`@("`@("`@("`@
M("`@("`@("`B>&UL+7)P8R!M971H;V0@)&UE=&AO9"(I.PT*("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1S97)V97)?
M:&]S="`]("1S97)V97)?8VAA;FYE;#L-"B`@("`@("`@("`@("`@("`@("`@
M)'-E<G9E<E]P;W)T(#T@)&-H86YN96PM/F=E=%!O<G0H*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(E5N:VYO=VX@
M8VAA;FYE;"`G)'-E<G9E<E]C:&%N;F5L)R(I.PT*("`@("`@("!]#0H-"B`@
M("`@("`@87)R87E?=6YS:&EF="@D7V%R9W,L("1S97)V97)?8VAA;FYE;"D[
M("\O(&-A8VAE(&)Y(&-H86YN96P-"B`@("`@("`@)'1H:7,M/F-A8VAE(#T@
M)'1H:7,M/F=E=$-A8VAE*"1?87)G<RD[#0H@("`@("`@("1C86-H971T;"`]
M("1T:&ES+3YC;VYF:6<M/F=E="@G8V%C:&5?='1L)RD[#0H@("`@("`@("\O
M($EF(&-A8VAE(&ES(&YE=V5R('1H86X@)&-A8VAE='1L('-E8V]N9',L('=E
M('5S92!T:&4@8V%C:&4A#0H@("`@("`@(&EF("@D=&AI<RT^8V%C:&4@(3T]
M(&YU;&P@)B8@)'1H:7,M/F-A8VAE6R=A9V4G72`\("1C86-H971T;"D@>PT*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YC86-H95LG8V]N=&5N="==.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AE>'1E;G-I;VY?;&]A9&5D*")X;6QR
M<&,B*2D@>PT*("`@("`@("`@("`@)')E<W5L="`](&-A;&Q?=7-E<E]F=6YC
M7V%R<F%Y*&%R<F%Y*"8D=&AI<RP@)V-A;&Q?97!I)RDL("1A<F=S*3L-"B`@
M("`@("`@("`@(&EF("@A4$5!4CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PT*("`@
M("`@("`@("`@("`@("1T:&ES+3YS879E0V%C:&4H)%]A<F=S+"`D<F5S=6QT
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PT*("`@("`@("!](&5L<V5I9B`H(4!I;F-L=61E7V]N8V4@)UA-3"]24$,N
M<&AP)RD@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*")&;W(@=&AI<R!R96UO=&4@4$5!4B!O<&5R871I;VX@>6]U(&YE960@=&\@
M;&]A9"!T:&4@>&UL<G!C(&5X=&5N<VEO;B!O<B!I;G-T86QL(%A-3%]24$,B
M*3L-"B`@("`@("`@?0T*#0H@("`@("`@(&%R<F%Y7W-H:69T*"1A<F=S*3L-
M"B`@("`@("`@)'5S97)N86UE(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=U<V5R
M;F%M92<I.PT*("`@("`@("`D<&%S<W=O<F0@/2`D=&AI<RT^8V]N9FEG+3YG
M970H)W!A<W-W;W)D)RD[#0H@("`@("`@("1E87)G<R`](&%R<F%Y*"D[#0H@
M("`@("`@(&9O<F5A8V@H)&%R9W,@87,@)&%R9RD@>PT*("`@("`@("`@("`@
M)&5A<F=S6UT@/2`D=&AI<RT^7V5N8V]D92@D87)G*3L-"B`@("`@("`@?0T*
M("`@("`@("`D9B`](&YE=R!834Q?4E!#7TUE<W-A9V4H)&UE=&AO9"P@)&5A
M<F=S*3L-"B`@("`@("`@:68@*"1T:&ES+3YC86-H92`A/3T@;G5L;"D@>PT*
M("`@("`@("`@("`@)&UA>$%G92`]("<_;6%X06=E/2<N)'1H:7,M/F-A8VAE
M6R=L87-T0VAA;F=E)UT[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D;6%X06=E(#T@)R<[#0H@("`@("`@('T-"B`@("`@("`@)'!R;WAY7VAO
M<W0@/2`D<')O>'E?<&]R="`]("1P<F]X>5]U<V5R(#T@)'!R;WAY7W!A<W,@
M/2`G)SL-"B`@("`@("`@:68@*"1P<F]X>2`]('!A<G-E7W5R;"@D=&AI<RT^
M8V]N9FEG+3YG970H)VAT='!?<')O>'DG*2DI('L-"B`@("`@("`@("`@("1P
M<F]X>5]H;W-T(#T@0"1P<F]X>5LG:&]S="==.PT*("`@("`@("`@("`@:68@
M*&ES<V5T*"1P<F]X>5LG<V-H96UE)UTI("8F("1P<F]X>5LG<V-H96UE)UT@
M/3T@)VAT='!S)RD@>PT*("`@("`@("`@("`@("`@("1P<F]X>5]H;W-T(#T@
M)VAT='!S.B\O)R`N("1P<F]X>5]H;W-T.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)'!R;WAY7W!O<G0@/2!`)'!R;WAY6R=P;W)T)UT[#0H@("`@
M("`@("`@("`D<')O>'E?=7-E<B`]($!U<FQD96-O9&4H0"1P<F]X>5LG=7-E
M<B==*3L-"B`@("`@("`@("`@("1P<F]X>5]P87-S(#T@0'5R;&1E8V]D92A`
M)'!R;WAY6R=P87-S)UTI.PT*("`@("`@("!]#0H@("`@("`@("1S:&]S="`]
M("1S97)V97)?:&]S=#L-"B`@("`@("`@:68@*"1C:&%N;F5L+3YG97134TPH
M*2D@>PT*("`@("`@("`@("`@)'-H;W-T(#T@(FAT='!S.B\O)'-H;W-T(CL-
M"B`@("`@("`@?0T*("`@("`@("`D8R`](&YE=R!834Q?4E!#7T-L:65N="@G
M+R<@+B`D8VAA;FYE;"T^9V5T4&%T:"@G>&UL<G!C)RD-"B`@("`@("`@("`@
M("X@)&UA>$%G92P@)'-H;W-T+"`D<V5R=F5R7W!O<G0L("1P<F]X>5]H;W-T
M+"`D<')O>'E?<&]R="P-"B`@("`@("`@("`@("1P<F]X>5]U<V5R+"`D<')O
M>'E?<&%S<RD[#0H@("`@("`@(&EF("@D=7-E<FYA;64@)B8@)'!A<W-W;W)D
M*2![#0H@("`@("`@("`@("`D8RT^<V5T0W)E9&5N=&EA;',H)'5S97)N86UE
M+"`D<&%S<W=O<F0I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D=&AI<RT^
M8V]N9FEG+3YG970H)W9E<F)O<V4G*2`^/2`S*2![#0H@("`@("`@("`@("`D
M8RT^<V5T1&5B=6<H,2D[#0H@("`@("`@('T-"B`@("`@("`@)'(@/2`D8RT^
M<V5N9"@D9BD[#0H@("`@("`@(&EF("@A)'(I('L-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B6$U,7U)00R!S96YD(&9A:6QE9"(I
M.PT*("`@("`@("!]#0H@("`@("`@("1V(#T@)'(M/G9A;'5E*"D[#0H@("`@
M("`@(&EF("@D92`]("1R+3YF875L=$-O9&4H*2D@>PT*("`@("`@("`@("`@
M:68@*"1E(#T]("1'3$]"04Q36R=834Q?4E!#7V5R<B==6R=H='1P7V5R<F]R
M)UT@)B8@<W1R<W1R*"1R+3YF875L=%-T<FEN9R@I+"`G,S`T($YO="!-;V1I
M9FEE9"<I("$]/2!F86QS92D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^8V%C:&5;)V-O;G1E;G0G73L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<BT^9F%U;'13=')I
M;F<H*2P@)&4I.PT*("`@("`@("!]#0H-"B`@("`@("`@)')E<W5L="`](%A-
M3%]24$-?9&5C;V1E*"1V*3L-"B`@("`@("`@)'1H:7,M/G-A=F5#86-H92@D
M7V%R9W,L("1R97-U;'0I.PT*("`@("`@("!R971U<FX@)')E<W5L=#L-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!C86QL7V5P:2AM971H
M;V0L(%MA<F=S+BXN72D-"@T*("`@(&9U;F-T:6]N(&-A;&Q?97!I*"1M971H
M;V0I#0H@("`@>PT*("`@("`@("!D;R![#0H@("`@("`@("`@("!I9B`H97AT
M96YS:6]N7VQO861E9"@B>&UL<G!C(BDI('L-"B`@("`@("`@("`@("`@("!B
M<F5A:SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("A/4U]724Y$
M3U=3*2![#0H@("`@("`@("`@("`@("`@)&5X="`]("=D;&PG.PT*("`@("`@
M("`@("`@?2!E;'-E:68@*%!(4%]/4R`]/2`G2%`M55@G*2![#0H@("`@("`@
M("`@("`@("`@)&5X="`]("=S;"<[#0H@("`@("`@("`@("!](&5L<V5I9B`H
M4$A07T]3(#T]("=!25@G*2![#0H@("`@("`@("`@("`@("`@)&5X="`]("=A
M)SL-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&5X
M="`]("=S;R<[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D97AT(#T@
M3U-?5TE.1$]74R`_("=D;&PG(#H@)W-O)SL-"B`@("`@("`@("`@($!D;"@B
M>&UL<G!C+65P:2XD97AT(BD[#0H@("`@("`@("`@("!I9B`H97AT96YS:6]N
M7VQO861E9"@B>&UL<G!C(BDI('L-"B`@("`@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@($!D;"@B>&UL<G!C+B1E>'0B
M*3L-"B`@("`@("`@("`@(&EF("AE>'1E;G-I;VY?;&]A9&5D*")X;6QR<&,B
M*2D@>PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")U;F%B;&4@
M=&\@;&]A9"!X;6QR<&,@97AT96YS:6]N(BD[#0H@("`@("`@('T@=VAI;&4@
M*&9A;'-E*3L-"B`@("`@("`@)'-E<G9E<E]C:&%N;F5L(#T@)'1H:7,M/F-O
M;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*3L-"B`@("`@("`@)&-H86YN
M96P@/2`D=&AI<RT^7W)E9VES=')Y+3YG971#:&%N;F5L*"1S97)V97)?8VAA
M;FYE;"D[#0H@("`@("`@(&EF("@A4$5!4CHZ:7-%<G)O<B@D8VAA;FYE;"DI
M('L-"B`@("`@("`@("`@("1M:7)R;W(@/2`D=&AI<RT^8V]N9FEG+3YG970H
M)W!R969E<G)E9%]M:7)R;W(G*3L-"B`@("`@("`@("`@(&EF("@D8VAA;FYE
M;"T^9V5T36ER<F]R*"1M:7)R;W(I*2![#0H@("`@("`@("`@("`@("`@:68@
M*"1C:&%N;F5L+3YS=7!P;W)T<R@G>&UL<G!C)RP@)&UE=&AO9"P@)&UI<G)O
M<BDI('L-"B`@("`@("`@("`@("`@("`@("`@)'-E<G9E<E]C:&%N;F5L(#T@
M)'-E<G9E<E]H;W-T(#T@)&UI<G)O<CL@+R\@=7-E('1H92!P<F5F97)R960@
M;6ER<F]R#0H@("`@("`@("`@("`@("`@("`@("1S97)V97)?<&]R="`]("1C
M:&%N;F5L+3YG9710;W)T*"1M:7)R;W(I.PT*("`@("`@("`@("`@("`@('T@
M96QS96EF("@A)&-H86YN96PM/G-U<'!O<G1S*"=X;6QR<&,G+"`D;65T:&]D
M*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H(D-H86YN96P@)'-E<G9E<E]C:&%N;F5L(&1O97,@;F]T("(@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@(G-U<'!O<G0@>&UL+7)P8R!M971H
M;V0@)&UE=&AO9"(I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF("@A:7-S970H)'-E<G9E<E]H;W-T*2D@>PT*
M("`@("`@("`@("`@("`@(&EF("@A)&-H86YN96PM/G-U<'!O<G1S*"=X;6QR
M<&,G+"`D;65T:&]D*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H(D-H86YN96P@)'-E<G9E<E]C:&%N;F5L(&1O
M97,@;F]T('-U<'!O<G0@(B`N#0H@("`@("`@("`@("`@("`@("`@("`@("`B
M>&UL+7)P8R!M971H;V0@)&UE=&AO9"(I.PT*("`@("`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@("`@("1S97)V97)?:&]S="`]("1S
M97)V97)?8VAA;FYE;#L-"B`@("`@("`@("`@("`@("`@("`@)'-E<G9E<E]P
M;W)T(#T@)&-H86YN96PM/F=E=%!O<G0H*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(E5N:VYO=VX@8VAA;FYE;"`G
M)'-E<G9E<E]C:&%N;F5L)R(I.PT*("`@("`@("!]#0H@("`@("`@("1P87)A
M;7,@/2!F=6YC7V=E=%]A<F=S*"D[#0H@("`@("`@(&%R<F%Y7W-H:69T*"1P
M87)A;7,I.PT*("`@("`@("`D;65T:&]D(#T@<W1R7W)E<&QA8V4H(E\B+"`B
M+B(L("1M971H;V0I.PT*("`@("`@("`D<F5Q=65S="`]('AM;')P8U]E;F-O
M9&5?<F5Q=65S="@D;65T:&]D+"`D<&%R86US*3L-"B`@("`@("`@:68@*"1H
M='1P7W!R;WAY(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=H='1P7W!R;WAY)RDI
M('L-"B`@("`@("`@("`@("1P<F]X>2`]('!A<G-E7W5R;"@D:'1T<%]P<F]X
M>2D[#0H@("`@("`@("`@("`D<')O>'E?:&]S="`]("1P<F]X>5]P;W)T(#T@
M)'!R;WAY7W5S97(@/2`D<')O>'E?<&%S<R`]("<G.PT*("`@("`@("`@("`@
M)'!R;WAY7VAO<W0@/2!`)'!R;WAY6R=H;W-T)UT[#0H@("`@("`@("`@("!I
M9B`H:7-S970H)'!R;WAY6R=S8VAE;64G72D@)B8@)'!R;WAY6R=S8VAE;64G
M72`]/2`G:'1T<',G*2![#0H@("`@("`@("`@("`@("`@)'!R;WAY7VAO<W0@
M/2`G<W-L.B\O)R`N("1P<F]X>5]H;W-T.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)'!R;WAY7W!O<G0@/2!`)'!R;WAY6R=P;W)T)UT[#0H@("`@
M("`@("`@("`D<')O>'E?=7-E<B`]($!U<FQD96-O9&4H0"1P<F]X>5LG=7-E
M<B==*3L-"B`@("`@("`@("`@("1P<F]X>5]P87-S(#T@0'5R;&1E8V]D92A`
M)'!R;WAY6R=P87-S)UTI.PT*("`@("`@("`@("`@)&9P(#T@0&9S;V-K;W!E
M;B@D<')O>'E?:&]S="P@)'!R;WAY7W!O<G0I.PT*("`@("`@("`@("`@)'5S
M95]P<F]X>2`]('1R=64[#0H@("`@("`@("`@("!I9B`H)&-H86YN96PM/F=E
M=%-33"@I*2![#0H@("`@("`@("`@("`@("`@)'-E<G9E<E]H;W-T(#T@(FAT
M='!S.B\O)'-E<G9E<E]H;W-T(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("1U<V5?<')O>'D@/2!F86QS93L-"B`@
M("`@("`@("`@("1S<VP@/2`D8VAA;FYE;"T^9V5T4U-,*"D[#0H@("`@("`@
M("`@("`D9G`@/2!`9G-O8VMO<&5N*"@D<W-L(#\@)W-S;#HO+R<@.B`G)RD@
M+B`D<V5R=F5R7VAO<W0L("1S97)V97)?<&]R="D[#0H@("`@("`@("`@("!I
M9B`H(21F<"D@>PT*("`@("`@("`@("`@("`@("1S97)V97)?:&]S="`]("(D
M<W-L)'-E<G9E<E]H;W-T(CL@+R\@9F]R(&5R<F]R+7)E<&]R=&EN9PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@A)&9P("8F("1H
M='1P7W!R;WAY*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H(E!%05)?4F5M;W1E.CIC86QL.B!F<V]C:V]P96XH8"1P<F]X>5]H
M;W-T)RP@)'!R;WAY7W!O<G0I(&9A:6QE9"(I.PT*("`@("`@("!](&5L<V5I
M9B`H(21F<"D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*")014%27U)E;6]T93HZ8V%L;#H@9G-O8VMO<&5N*&`D<V5R=F5R7VAO
M<W0G+"`D<V5R=F5R7W!O<G0I(&9A:6QE9"(I.PT*("`@("`@("!]#0H@("`@
M("`@("1L96X@/2!S=')L96XH)')E<75E<W0I.PT*("`@("`@("`D<F5Q7VAE
M861E<G,@/2`B2&]S=#H@)'-E<G9E<E]H;W-T.B1S97)V97)?<&]R=%QR7&XB
M("X-"B`@("`@("`@("`@("`B0V]N=&5N="UT>7!E.B!T97AT+WAM;%QR7&XB
M("X-"B`@("`@("`@("`@("`B0V]N=&5N="UL96YG=&@Z("1L96Y<<EQN(CL-
M"B`@("`@("`@)'5S97)N86UE(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=U<V5R
M;F%M92<I.PT*("`@("`@("`D<&%S<W=O<F0@/2`D=&AI<RT^8V]N9FEG+3YG
M970H)W!A<W-W;W)D)RD[#0H@("`@("`@(&EF("@D=7-E<FYA;64@)B8@)'!A
M<W-W;W)D*2![#0H@("`@("`@("`@("`D<F5Q7VAE861E<G,@+CT@(D-O;VMI
M93H@4$5!4E]54T52/21U<V5R;F%M93L@4$5!4E]05STD<&%S<W=O<F1<<EQN
M(CL-"B`@("`@("`@("`@("1T;7`@/2!B87-E-C1?96YC;V1E*"(D=7-E<FYA
M;64Z)'!A<W-W;W)D(BD[#0H@("`@("`@("`@("`D<F5Q7VAE861E<G,@+CT@
M(D%U=&AO<FEZ871I;VXZ($)A<VEC("1T;7!<<EQN(CL-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H)'1H:7,M/F-A8VAE("$]/2!N=6QL*2![#0H@("`@("`@
M("`@("`D;6%X06=E(#T@)S]M87A!9V4])RXD=&AI<RT^8V%C:&5;)VQA<W1#
M:&%N9V4G73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1M87A!
M9V4@/2`G)SL-"B`@("`@("`@?0T*#0H@("`@("`@(&EF("@D=7-E7W!R;WAY
M("8F("1P<F]X>5]H;W-T("$]("<G("8F("1P<F]X>5]U<V5R("$]("<G*2![
M#0H@("`@("`@("`@("`D<F5Q7VAE861E<G,@+CT@)U!R;WAY+4%U=&AO<FEZ
M871I;VXZ($)A<VEC("<-"B`@("`@("`@("`@("`@("`N8F%S938T7V5N8V]D
M92@D<')O>'E?=7-E<BXG.B<N)'!R;WAY7W!A<W,I#0H@("`@("`@("`@("`@
M("`@+B)<<EQN(CL-"B`@("`@("`@?0T*#0H@("`@("`@(&EF("@D=&AI<RT^
M8V]N9FEG+3YG970H)W9E<F)O<V4G*2`^(#,I('L-"B`@("`@("`@("`@('!R
M:6YT(")834Q24$,@4D5154535"!(14%$15)3.EQN(CL-"B`@("`@("`@("`@
M('9A<E]D=6UP*"1R97%?:&5A9&5R<RD[#0H@("`@("`@("`@("!P<FEN="`B
M6$U,4E!#(%)%455%4U0@0D]$63I<;B([#0H@("`@("`@("`@("!V87)?9'5M
M<"@D<F5Q=65S="D[#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H)'5S95]P
M<F]X>2`F)B`D<')O>'E?:&]S="`A/2`G)RD@>PT*("`@("`@("`@("`@)'!O
M<W1?<W1R:6YG(#T@(E!/4U0@:'1T<#HO+R(N)'-E<G9E<E]H;W-T.PT*("`@
M("`@("`@("`@:68@*"1P<F]X>5]P;W)T(#X@)R<I('L-"B`@("`@("`@("`@
M("`@("`D<&]S=%]S=')I;F<@+CT@)SHG+B1S97)V97)?<&]R=#L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1P;W-T
M7W-T<FEN9R`](")03U-4("([#0H@("`@("`@('T-"@T*("`@("`@("`D<&%T
M:"`]("<O)R`N("1C:&%N;F5L+3YG9710871H*"=X;6QR<&,G*3L-"B`@("`@
M("`@9G=R:71E*"1F<"P@*"1P;W-T7W-T<FEN9R`N("1P871H("X@(B1M87A!
M9V4@2%144"\Q+C!<<EQN)')E<5]H96%D97)S7')<;B1R97%U97-T(BDI.PT*
M("`@("`@("`D<F5S<&]N<V4@/2`G)SL-"B`@("`@("`@)&QI;F4Q(#T@9F=E
M=',H)&9P+"`R,#0X*3L-"B`@("`@("`@:68@*"%P<F5G7VUA=&-H*"<A7DA4
M5%`O6S`M.5PN72L@*%QD*RD@*"XJ*2$G+"`D;&EN93$L("1M871C:&5S*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")014%2
M7U)E;6]T93H@:6YV86QI9"!(5%10(')E<W!O;G-E(&9R;VT@6$U,+5)00R!S
M97)V97(B*3L-"B`@("`@("`@?0T*("`@("`@("!S=VET8V@@*"1M871C:&5S
M6S%=*2![#0H@("`@("`@("`@("!C87-E("(R,#`B.B`O+R!/2PT*("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`B,S`T(CH@+R\@
M3F]T($UO9&EF:65D#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YC
M86-H95LG8V]N=&5N="==.PT*("`@("`@("`@("`@8V%S92`B-#`Q(CH@+R\@
M56YA=71H;W)I>F5D#0H@("`@("`@("`@("`@("`@:68@*"1U<V5R;F%M92`F
M)B`D<&%S<W=O<F0I('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*")014%27U)E;6]T92`H)'-E<G9E<E]H;W-T.B1S
M97)V97)?<&]R="D@(B`N#0H@("`@("`@("`@("`@("`@("`@("`@("`B.B!A
M=71H;W)I>F%T:6]N(&9A:6QE9"(L(#0P,2D[#0H@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*")014%27U)E;6]T92`H)'-E<G9E<E]H;W-T.B1S97)V97)?
M<&]R="D@(B`N#0H@("`@("`@("`@("`@("`@("`@("`@("`B.B!A=71H;W)I
M>F%T:6]N(')E<75I<F5D+"!P;&5A<V4@;&]G(&EN(&9I<G-T(BP@-#`Q*3L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!D969A=6QT.@T*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B4$5!4E]2
M96UO=&4@*"1S97)V97)?:&]S=#HD<V5R=F5R7W!O<G0I(#H@(B`N#0H@("`@
M("`@("`@("`@("`@("`@(")U;F5X<&5C=&5D($A45%`@<F5S<&]N<V4B+"`H
M:6YT*21M871C:&5S6S%=+"!N=6QL+"!N=6QL+`T*("`@("`@("`@("`@("`@
M("`@("`B)&UA=&-H97-;,5T@)&UA=&-H97-;,ETB*3L-"B`@("`@("`@?0T*
M("`@("`@("!W:&EL92`H=')I;2AF9V5T<R@D9G`L(#(P-#@I*2`A/2`G)RD[
M("\O('-K:7`@<F5S="!O9B!H96%D97)S#0H@("`@("`@('=H:6QE("@D8VAU
M;FL@/2!F<F5A9"@D9G`L(#$P,C0P*2D@>PT*("`@("`@("`@("`@)')E<W!O
M;G-E("X]("1C:'5N:SL-"B`@("`@("`@?0T*("`@("`@("!F8VQO<V4H)&9P
M*3L-"B`@("`@("`@:68@*"1T:&ES+3YC;VYF:6<M/F=E="@G=F5R8F]S92<I
M(#X@,RD@>PT*("`@("`@("`@("`@<')I;G0@(EA-3%)00R!215-03TY313I<
M;B([#0H@("`@("`@("`@("!V87)?9'5M<"@D<F5S<&]N<V4I.PT*("`@("`@
M("!]#0H@("`@("`@("1R970@/2!X;6QR<&-?9&5C;V1E*"1R97-P;VYS92D[
M#0H@("`@("`@(&EF("AI<U]A<G)A>2@D<F5T*2`F)B!I<W-E="@D<F5T6R=?
M7U!%05)?5%E015]?)UTI*2![#0H@("`@("`@("`@("!I9B`H)')E=%LG7U]0
M14%27U194$5?7R==(#T]("=E<G)O<B<I('L-"B`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)')E=%LG7U]014%27T-,05-37U\G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@)&-L87-S(#T@)')E=%LG7U]014%27T-,05-37U\G73L-
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@
M("`D8VQA<W,@/2`B4$5!4E]%<G)O<B([#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@(&EF("@D<F5T6R=C;V1E)UT@("`@(#T]/2`G)RD@
M)')E=%LG8V]D92==("`@("`](&YU;&P[#0H@("`@("`@("`@("`@("`@:68@
M*"1R971;)VUE<W-A9V4G72`@/3T]("<G*2`D<F5T6R=M97-S86=E)UT@(#T@
M;G5L;#L-"B`@("`@("`@("`@("`@("!I9B`H)')E=%LG=7-E<FEN9F\G72`]
M/3T@)R<I("1R971;)W5S97)I;F9O)UT@/2!N=6QL.PT*("`@("`@("`@("`@
M("`@(&EF("AS=')T;VQO=V5R*"1C;&%S<RD@/3T@)V1B7V5R<F]R)RD@>PT*
M("`@("`@("`@("`@("`@("`@("`D<F5T(#T@)'1H:7,M/G)A:7-E17)R;W(H
M4$5!4CHZ97)R;W)-97-S86=E*"1R971;)V-O9&4G72DL#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5T6R=C;V1E
M)UTL(&YU;&PL(&YU;&PL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<F5T6R=U<V5R:6YF;R==*3L-"B`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D<F5T(#T@
M)'1H:7,M/G)A:7-E17)R;W(H)')E=%LG;65S<V%G92==+"`D<F5T6R=C;V1E
M)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!N=6QL+"!N=6QL+"`D<F5T6R=U<V5R:6YF;R==*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS96EF("AI
M<U]A<G)A>2@D<F5T*2`F)B!S:7IE;V8H)')E="D@/3T@,2`F)B!I<W-E="@D
M<F5T6S!=*0T*("`@("`@("`@("`@("`@("`@)B8@:7-?87)R87DH)')E=%LP
M72D@)B8-"B`@("`@("`@("`@("`@("`@("%E;7!T>2@D<F5T6S!=6R=F875L
M=%-T<FEN9R==*2`F)@T*("`@("`@("`@("`@("`@("`@(65M<'1Y*"1R971;
M,%U;)V9A=6QT0V]D92==*2D@>PT*("`@("`@("`@("`@97AT<F%C="@D<F5T
M6S!=*3L-"B`@("`@("`@("`@("1F875L=%-T<FEN9R`](")834PM4E!#(%-E
M<G9E<B!&875L=#H@(B`N#0H@("`@("`@("`@("`@("`@('-T<E]R97!L86-E
M*")<;B(L("(@(BP@)&9A=6QT4W1R:6YG*3L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@D9F%U;'13=')I;F<L("1F875L=$-O9&4I
M.PT*("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH)')E="D@)B8@<VEZ96]F
M*"1R970I(#T](#(@)B8@(65M<'1Y*"1R971;)V9A=6QT4W1R:6YG)UTI("8F
M#0H@("`@("`@("`@("`@("%E;7!T>2@D<F5T6R=F875L=$-O9&4G72DI('L-
M"B`@("`@("`@("`@(&5X=')A8W0H)')E="D[#0H@("`@("`@("`@("`D9F%U
M;'13=')I;F<@/2`B6$U,+5)00R!397)V97(@1F%U;'0Z("(@+@T*("`@("`@
M("`@("`@("`@("!S=')?<F5P;&%C92@B7&XB+"`B("(L("1F875L=%-T<FEN
M9RD[#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&9A
M=6QT4W1R:6YG+"`D9F%U;'1#;V1E*3L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*("`@("\O('M[
M>R!?96YC;V1E#0H-"B`@("`O+R!A('-L:6=H=&QY(&5X=&5N9&5D('9E<G-I
M;VX@;V8@6$U,7U)00U]E;F-O9&4-"B`@("!F=6YC=&EO;B!?96YC;V1E*"1P
M:'!?=F%L*0T*("`@('L-"B`@("`@("`@9VQO8F%L("1834Q?4E!#7T)O;VQE
M86XL("1834Q?4E!#7TEN="P@)%A-3%]24$-?1&]U8FQE.PT*("`@("`@("!G
M;&]B86P@)%A-3%]24$-?4W1R:6YG+"`D6$U,7U)00U]!<G)A>2P@)%A-3%]2
M4$-?4W1R=6-T.PT*#0H@("`@("`@("1T>7!E(#T@9V5T='EP92@D<&AP7W9A
M;"D[#0H@("`@("`@("1X;6QR<&-V86P@/2!N97<@6$U,7U)00U]686QU93L-
M"@T*("`@("`@("!S=VET8V@H)'1Y<&4I('L-"B`@("`@("`@("`@(&-A<V4@
M(F%R<F%Y(CH-"B`@("`@("`@("`@("`@("!R97-E="@D<&AP7W9A;"D[#0H@
M("`@("`@("`@("`@("`@)&9I<G-T:V5Y(#T@:V5Y*"1P:'!?=F%L*3L-"B`@
M("`@("`@("`@("`@("!E;F0H)'!H<%]V86PI.PT*("`@("`@("`@("`@("`@
M("1L87-T:V5Y(#T@:V5Y*"1P:'!?=F%L*3L-"B`@("`@("`@("`@("`@("!R
M97-E="@D<&AP7W9A;"D[#0H@("`@("`@("`@("`@("`@:68@*"1F:7)S=&ME
M>2`]/3T@,"`F)B!I<U]I;G0H)&QA<W1K97DI("8F#0H@("`@("`@("`@("`@
M("`@("`@("@D;&%S=&ME>2`K(#$I(#T](&-O=6YT*"1P:'!?=F%L*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D:7-?8V]N=&EN=6]U<R`]('1R=64[#0H@
M("`@("`@("`@("`@("`@("`@(')E<V5T*"1P:'!?=F%L*3L-"B`@("`@("`@
M("`@("`@("`@("`@)'-I>F4@/2!C;W5N="@D<&AP7W9A;"D[#0H@("`@("`@
M("`@("`@("`@("`@(&9O<B`H)&5X<&5C="`](#`[("1E>'!E8W0@/"`D<VEZ
M93L@)&5X<&5C="LK+"!N97AT*"1P:'!?=F%L*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*&ME>2@D<&AP7W9A;"D@(3T]("1E>'!E8W0I('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:7-?8V]N=&EN=6]U<R`]
M(&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@D:7-?8V]N=&EN=6]U<RD@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5S970H)'!H<%]V86PI.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&%R<B`](&%R<F%Y*"D[#0H@("`@
M("`@("`@("`@("`@("`@("`@("!W:&EL92`H;&ES="@D:RP@)'8I(#T@96%C
M:"@D<&AP7W9A;"DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M87)R6R1K72`]("1T:&ES+3Y?96YC;V1E*"1V*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1X;6QR<&-V
M86PM/F%D9$%R<F%Y*"1A<G(I.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@+R\@9F%L;"!T:&]U9V@@:68@;F]T(&YU
M;65R:6-A;"!A;F0@8V]N=&EN=6]U<PT*("`@("`@("`@("`@8V%S92`B;V)J
M96-T(CH-"B`@("`@("`@("`@("`@("`D87)R(#T@87)R87DH*3L-"B`@("`@
M("`@("`@("`@("!W:&EL92`H;&ES="@D:RP@)'8I(#T@96%C:"@D<&AP7W9A
M;"DI('L-"B`@("`@("`@("`@("`@("`@("`@)&%R<ELD:UT@/2`D=&AI<RT^
M7V5N8V]D92@D=BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("1X;6QR<&-V86PM/F%D9%-T<G5C="@D87)R*3L-"B`@("`@("`@("`@
M("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@(FEN=&5G97(B.@T*("`@
M("`@("`@("`@("`@("1X;6QR<&-V86PM/F%D9%-C86QA<B@D<&AP7W9A;"P@
M)%A-3%]24$-?26YT*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@("`@(&-A<V4@(F1O=6)L92(Z#0H@("`@("`@("`@("`@("`@)'AM;')P
M8W9A;"T^861D4V-A;&%R*"1P:'!?=F%L+"`D6$U,7U)00U]$;W5B;&4I.PT*
M("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`B<W1R
M:6YG(CH-"B`@("`@("`@("`@(&-A<V4@(DY53$PB.@T*("`@("`@("`@("`@
M("`@("1X;6QR<&-V86PM/F%D9%-C86QA<B@D<&AP7W9A;"P@)%A-3%]24$-?
M4W1R:6YG*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@
M(&-A<V4@(F)O;VQE86XB.@T*("`@("`@("`@("`@("`@("1X;6QR<&-V86PM
M/F%D9%-C86QA<B@D<&AP7W9A;"P@)%A-3%]24$-?0F]O;&5A;BD[#0H@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E(")U;FMN;W=N
M('1Y<&4B.@T*("`@("`@("`@("`@9&5F875L=#H-"B`@("`@("`@("`@("`@
M("!R971U<FX@;G5L;#L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'AM
M;')P8W9A;#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*?0T*#0H_/@T*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]215-4+P``````````
M````````````````````````````````````````````````````````````
M````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U
M,34T,S,W-#``,#(P,3`U`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]0
M14%2+U)%4U0O,3`N<&AP````````````````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`V,3,P,@`Q,#4Q-30S,S<T,``P,C$P-#``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`-"B\J*@T*("H@
M4$5!4E]215-47S$P#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J
M#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@
M=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V
M86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L
M;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@
M=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T
M:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I
M871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@
M("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P
M:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O
M=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93
M.B`D260Z(#$P+G!H<"QV(#$N-#`@,C`P-B\P,2\P-B`P-#HT-SHS-R!C96QL
M;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S
M:6YC92!296QE87-E(#$N-"XP83$R#0H@*B\-"@T*+RHJ#0H@*B!&;W(@9&]W
M;FQO861I;F<@4D535"!X;6PO='AT(&9I;&5S#0H@*B\-"G)E<75I<F5?;VYC
M92`G4$5!4B]215-4+G!H<"<[#0H-"B\J*@T*("H@26UP;&5M96YT(%)%4U0@
M,2XP#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@
M4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N
M;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-
M"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S
M93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@
M<VEN8V4@4F5L96%S92`Q+C0N,&$Q,@T*("HO#0IC;&%S<R!014%27U)%4U1?
M,3`-"GL-"B`@("`O*BH-"B`@("`@*B!`=F%R(%!%05)?4D535`T*("`@("`J
M+PT*("`@('9A<B`D7W)E<W0[#0H@("`@9G5N8W1I;VX@4$5!4E]215-47S$P
M*"1C;VYF:6<L("1O<'1I;VYS(#T@87)R87DH*2D-"B`@("![#0H@("`@("`@
M("1T:&ES+3Y?<F5S="`]("9N97<@4$5!4E]215-4*"1C;VYF:6<L("1O<'1I
M;VYS*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971$;W=N;&]A9%523"@D
M8F%S92P@)'!A8VMA9V5I;F9O+"`D<')E9G-T871E+"`D:6YS=&%L;&5D*0T*
M("`@('L-"B`@("`@("`@)&-H86YN96P@/2`D<&%C:V%G96EN9F];)V-H86YN
M96PG73L-"B`@("`@("`@)'!A8VMA9V4@/2`D<&%C:V%G96EN9F];)W!A8VMA
M9V4G73L-"B`@("`@("`@)'-T871E<R`]("1T:&ES+3YB971T97)3=&%T97,H
M)'!R969S=&%T92P@=')U92D[#0H@("`@("`@(&EF("@A)'-T871E<RD@>PT*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)R(G("X@)'!R
M969S=&%T92`N("<B(&ES(&YO="!A('9A;&ED('-T871E)RD[#0H@("`@("`@
M('T-"B`@("`@("`@)'-T871E(#T@)'9E<G-I;VX@/2!N=6QL.PT*("`@("`@
M("!I9B`H:7-S970H)'!A8VMA9V5I;F9O6R=S=&%T92==*2D@>PT*("`@("`@
M("`@("`@)'-T871E(#T@)'!A8VMA9V5I;F9O6R=S=&%T92==.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("AI<W-E="@D<&%C:V%G96EN9F];)W9E<G-I;VXG
M72DI('L-"B`@("`@("`@("`@("1V97)S:6]N(#T@)'!A8VMA9V5I;F9O6R=V
M97)S:6]N)UT[#0H@("`@("`@('T-"B`@("`@("`@)&EN9F\@/2`D=&AI<RT^
M7W)E<W0M/G)E=')I979E1&%T82@D8F%S92`N("=R+R<@+B!S=')T;VQO=V5R
M*"1P86-K86=E*2`N("<O86QL<F5L96%S97,N>&UL)RD[#0H@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1I;F9O*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)TYO(')E;&5A<V5S(&%V86EL86)L92!F;W(@
M<&%C:V%G92`B)R`N#0H@("`@("`@("`@("`@("`@)&-H86YN96P@+B`G+R<@
M+B`D<&%C:V%G92`N("<B)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I
M<W-E="@D:6YF;ULG<B==*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("!]#0H@("`@("`@("1F;W5N9"`](&9A;'-E.PT*("`@("`@
M("`D<F5L96%S92`](&9A;'-E.PT*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1I
M;F9O6R=R)UTI('Q\("%I<W-E="@D:6YF;ULG<B==6S!=*2D@>PT*("`@("`@
M("`@("`@)&EN9F];)W(G72`](&%R<F%Y*"1I;F9O6R=R)UTI.PT*("`@("`@
M("!]#0H@("`@("`@(&9O<F5A8V@@*"1I;F9O6R=R)UT@87,@)')E;&5A<V4I
M('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]R97-T+3Y?;W!T
M:6]N<ULG9F]R8V4G72D@)B8@*"1I;G-T86QL960@)B8-"B`@("`@("`@("`@
M("`@("`@('9E<G-I;VY?8V]M<&%R92@D<F5L96%S95LG=B==+"`D:6YS=&%L
M;&5D+"`G/"<I*2D@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1S=&%T92DI('L-
M"B`@("`@("`@("`@("`@("!I9B`H)')E;&5A<V5;)W,G72`]/2`D<W1A=&4I
M('L-"B`@("`@("`@("`@("`@("`@("`@)&9O=6YD(#T@=')U93L-"B`@("`@
M("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1V97)S:6]N*2D@>PT*("`@("`@
M("`@("`@("`@(&EF("@D<F5L96%S95LG=B==(#T]("1V97)S:6]N*2![#0H@
M("`@("`@("`@("`@("`@("`@("1F;W5N9"`]('1R=64[#0H@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1R
M96QE87-E6R=S)UTL("1S=&%T97,I*2![#0H@("`@("`@("`@("`@("`@("`@
M("1F;W5N9"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@)'1H:7,M/E]R971U<FY$;W=N;&]A9%523"@D8F%S
M92P@)'!A8VMA9V4L("1R96QE87-E+"`D:6YF;RP@)&9O=6YD*3L-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!G971$97!$;W=N;&]A9%523"@D8F%S92P@)'AS
M9'9E<G-I;VXL("1D97!E;F1E;F-Y+"`D9&5P<&%C:V%G92P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<')E9G-T871E(#T@)W-T86)L92<L
M("1I;G-T86QL960@/2!F86QS92D-"B`@("![#0H@("`@("`@("1C:&%N;F5L
M(#T@)&1E<&5N9&5N8WE;)V-H86YN96PG73L-"B`@("`@("`@)'!A8VMA9V4@
M/2`D9&5P96YD96YC>5LG;F%M92==.PT*("`@("`@("`D<W1A=&5S(#T@)'1H
M:7,M/F)E='1E<E-T871E<R@D<')E9G-T871E+"!T<G5E*3L-"B`@("`@("`@
M:68@*"$D<W1A=&5S*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G(B<@+B`D<')E9G-T871E("X@)R(@:7,@;F]T(&$@=F%L:60@
M<W1A=&4G*3L-"B`@("`@("`@?0T*("`@("`@("`D<W1A=&4@/2`D=F5R<VEO
M;B`](&YU;&P[#0H@("`@("`@(&EF("AI<W-E="@D<&%C:V%G96EN9F];)W-T
M871E)UTI*2![#0H@("`@("`@("`@("`D<W1A=&4@/2`D<&%C:V%G96EN9F];
M)W-T871E)UT[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1P86-K
M86=E:6YF;ULG=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@)'9E<G-I;VX@
M/2`D<&%C:V%G96EN9F];)W9E<G-I;VXG73L-"B`@("`@("`@?0T*("`@("`@
M("`D:6YF;R`]("1T:&ES+3Y?<F5S="T^<F5T<FEE=F5$871A*"1B87-E("X@
M)W(O)R`N('-T<G1O;&]W97(H)'!A8VMA9V4I("X@)R]A;&QR96QE87-E<RYX
M;6PG*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\I*2![#0H@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4&%C:V%G92`B
M)R`N("1D97!P86-K86=E6R=C:&%N;F5L)UT@+B`G+R<@+B`D9&5P<&%C:V%G
M95LG<&%C:V%G92==#0H@("`@("`@("`@("`@("`@+B`G(B!D97!E;F1E;F-Y
M("(G("X@)&-H86YN96P@+B`G+R<@+B`D<&%C:V%G92`N("<B(&AA<R!N;R!R
M96QE87-E<R<I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-?87)R87DH
M)&EN9F\I('Q\("%I<W-E="@D:6YF;ULG<B==*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1E>&-L=61E(#T@
M87)R87DH*3L-"B`@("`@("`@)&UI;B`]("1M87@@/2`D<F5C;VUM96YD960@
M/2!F86QS93L-"B`@("`@("`@:68@*"1X<V1V97)S:6]N(#T]("<Q+C`G*2![
M#0H@("`@("`@("`@("`D<&EN9F];)W!A8VMA9V4G72`]("1D97!E;F1E;F-Y
M6R=N86UE)UT[#0H@("`@("`@("`@("`D<&EN9F];)V-H86YN96PG72`]("=P
M96%R+G!H<"YN970G.R`O+R!T:&ES(&ES(&%L=V%Y<R!T<G5E("T@9&]N)W0@
M8VAA;F=E('1H:7,-"B`@("`@("`@("`@('-W:71C:"`H)&1E<&5N9&5N8WE;
M)W)E;"==*2![#0H@("`@("`@("`@("`@("`@8V%S92`G9V4G(#H-"B`@("`@
M("`@("`@("`@("`@("`@)&UI;B`]("1D97!E;F1E;F-Y6R=V97)S:6]N)UT[
M#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@8V%S
M92`G9W0G(#H-"B`@("`@("`@("`@("`@("`@("`@)&UI;B`]("1D97!E;F1E
M;F-Y6R=V97)S:6]N)UT[#0H@("`@("`@("`@("`@("`@("`@("1E>&-L=61E
M(#T@87)R87DH)&1E<&5N9&5N8WE;)W9E<G-I;VXG72D[#0H@("`@("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@8V%S92`G97$G(#H-"B`@
M("`@("`@("`@("`@("`@("`@)')E8V]M;65N9&5D(#T@)&1E<&5N9&5N8WE;
M)W9E<G-I;VXG73L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@("`@("!C87-E("=L="<@.@T*("`@("`@("`@("`@("`@("`@("`D;6%X
M(#T@)&1E<&5N9&5N8WE;)W9E<G-I;VXG73L-"B`@("`@("`@("`@("`@("`@
M("`@)&5X8VQU9&4@/2!A<G)A>2@D9&5P96YD96YC>5LG=F5R<VEO;B==*3L-
M"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!C87-E
M("=L92<@.@T*("`@("`@("`@("`@("`@("`@("`D;6%X(#T@)&1E<&5N9&5N
M8WE;)W9E<G-I;VXG73L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@("`@("`@("!C87-E("=N92<@.@T*("`@("`@("`@("`@("`@("`@("`D
M97AC;'5D92`](&%R<F%Y*"1D97!E;F1E;F-Y6R=V97)S:6]N)UTI.PT*("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@)'!I;F9O6R=P86-K86=E)UT@/2`D9&5P
M96YD96YC>5LG;F%M92==.PT*("`@("`@("`@("`@)&UI;B`](&ES<V5T*"1D
M97!E;F1E;F-Y6R=M:6XG72D@/R`D9&5P96YD96YC>5LG;6EN)UT@.B!F86QS
M93L-"B`@("`@("`@("`@("1M87@@/2!I<W-E="@D9&5P96YD96YC>5LG;6%X
M)UTI(#\@)&1E<&5N9&5N8WE;)VUA>"==(#H@9F%L<V4[#0H@("`@("`@("`@
M("`D<F5C;VUM96YD960@/2!I<W-E="@D9&5P96YD96YC>5LG<F5C;VUM96YD
M960G72D@/PT*("`@("`@("`@("`@("`@("1D97!E;F1E;F-Y6R=R96-O;6UE
M;F1E9"==(#H@9F%L<V4[#0H@("`@("`@("`@("!I9B`H:7-S970H)&1E<&5N
M9&5N8WE;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1D97!E;F1E;F-Y6R=E>&-L=61E)UU;,%TI*2![#0H@("`@("`@("`@
M("`@("`@("`@("1E>&-L=61E(#T@87)R87DH)&1E<&5N9&5N8WE;)V5X8VQU
M9&4G72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@("1F;W5N9"`](&9A;'-E.PT*("`@("`@("`D<F5L
M96%S92`](&9A;'-E.PT*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1I;F9O6R=R
M)UTI('Q\("%I<W-E="@D:6YF;ULG<B==6S!=*2D@>PT*("`@("`@("`@("`@
M)&EN9F];)W(G72`](&%R<F%Y*"1I;F9O6R=R)UTI.PT*("`@("`@("!]#0H@
M("`@("`@(&9O<F5A8V@@*"1I;F9O6R=R)UT@87,@)')E;&5A<V4I('L-"B`@
M("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]R97-T+3Y?;W!T:6]N<ULG
M9F]R8V4G72D@)B8@*"1I;G-T86QL960@)B8-"B`@("`@("`@("`@("`@("`@
M('9E<G-I;VY?8V]M<&%R92@D<F5L96%S95LG=B==+"`D:6YS=&%L;&5D+"`G
M/"<I*2D@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1R96QE87-E6R=V)UTL
M("1E>&-L=61E*2D@>R`O+R!S:VEP(&5X8VQU9&5D('9E<G-I;VYS#0H@("`@
M("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`O+R!A;&QO=R!N97=E<B!R96QE87-E<R!T;R!S87D@(DDG;2!/2R!W
M:71H('1H92!D97!E;F1E;G0@<&%C:V%G92(-"B`@("`@("`@("`@(&EF("@D
M>'-D=F5R<VEO;B`]/2`G,BXP)R`F)B!I<W-E="@D<F5L96%S95LG8V\G72DI
M('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1R96QE87-E6R=C
M;R==*2!\?"`A:7-S970H)')E;&5A<V5;)V-O)UU;,%TI*2![#0H@("`@("`@
M("`@("`@("`@("`@("1R96QE87-E6R=C;R==(#T@87)R87DH)')E;&5A<V5;
M)V-O)UTI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D<F5L96%S95LG8V\G72!A<R`D96YT<GDI('L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1E;G1R>5LG>"==*2`F)B`A:7-?87)R
M87DH)&5N=')Y6R=X)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M96YT<GE;)W@G72`](&%R<F%Y*"1E;G1R>5LG>"==*3L-"B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*"%I<W-E="@D96YT<GE;)W@G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1E;G1R>5LG>"==(#T@87)R87DH*3L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I
M9B`H)&5N=')Y6R=C)UT@/3T@)&1E<'!A8VMA9V5;)V-H86YN96PG72`F)@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("!S=')T;VQO=V5R*"1E;G1R>5LG
M<"==*2`]/2!S=')T;VQO=V5R*"1D97!P86-K86=E6R=P86-K86=E)UTI("8F
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@('9E<G-I;VY?8V]M<&%R92@D
M9&5P<&%C:V%G95LG=F5R<VEO;B==+"`D96YT<GE;)VUI;B==+"`G/CTG*2`F
M)@T*("`@("`@("`@("`@("`@("`@("`@("`@("!V97)S:6]N7V-O;7!A<F4H
M)&1E<'!A8VMA9V5;)W9E<G-I;VXG72P@)&5N=')Y6R=M87@G72P@)SP])RD@
M)B8-"B`@("`@("`@("`@("`@("`@("`@("`@("`@(6EN7V%R<F%Y*"1R96QE
M87-E6R=V)UTL("1E;G1R>5LG>"==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)')E8V]M;65N9&5D(#T@)')E;&5A<V5;)W8G73L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@:68@*"1R96-O;6UE;F1E9"D@>PT*("`@("`@("`@("`@("`@(&EF("@D
M<F5L96%S95LG=B==("$]("1R96-O;6UE;F1E9"D@>R`O+R!I9B!W92!W86YT
M(&$@<W!E8VEF:6,-"B`@("`@("`@("`@("`@("`@("`@+R\@=F5R<VEO;BP@
M=&AE;B!S:VEP(&%L;"!O=&AE<G,-"B`@("`@("`@("`@("`@("`@("`@8V]N
M=&EN=64[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@:68@*"%I;E]A<G)A>2@D<F5L96%S95LG<R==+"`D<W1A=&5S
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@+R\@=&AE('-T86)I;&ET
M>2!I<R!T;V\@;&]W+"!B=70@=V4@;75S="!R971U<FX@=&AE#0H@("`@("`@
M("`@("`@("`@("`@("`@("`O+R!R96-O;6UE;F1E9"!V97)S:6]N(&EF('!O
M<W-I8FQE#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]R971U<FY$;W=N;&]A9%523"@D8F%S92P@)'!A8VMA9V4L("1R96QE87-E
M+"`D:6YF;RP@=')U92D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M)&UI;B`F)B!V97)S:6]N7V-O;7!A<F4H)')E;&5A<V5;)W8G72P@)&UI;BP@
M)VQT)RDI('L@+R\@<VMI<"!T;V\@;VQD('9E<G-I;VYS#0H@("`@("`@("`@
M("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H)&UA>"`F)B!V97)S:6]N7V-O;7!A<F4H)')E;&5A<V5;)W8G72P@)&UA
M>"P@)V=T)RDI('L@+R\@<VMI<"!T;V\@;F5W('9E<G-I;VYS#0H@("`@("`@
M("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H)&EN<W1A;&QE9"`F)B!V97)S:6]N7V-O;7!A<F4H)')E;&5A<V5;
M)W8G72P@)&EN<W1A;&QE9"P@)SPG*2D@>PT*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&EN7V%R
M<F%Y*"1R96QE87-E6R=S)UTL("1S=&%T97,I*2![("\O(&EF(&EN('1H92!P
M<F5F97)R960@<W1A=&4N+BX-"B`@("`@("`@("`@("`@("`D9F]U;F0@/2!T
M<G5E.R`O+R`N+BX@=&AE;B!U<V4@:70-"B`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M)'1H:7,M/E]R971U<FY$;W=N;&]A9%523"@D8F%S92P@)'!A8VMA9V4L("1R
M96QE87-E+"`D:6YF;RP@)&9O=6YD*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!?<F5T=7)N1&]W;FQO86154DPH)&)A<V4L("1P86-K86=E+"`D<F5L96%S
M92P@)&EN9F\L("1F;W5N9"D-"B`@("![#0H@("`@("`@(&EF("@A)&9O=6YD
M*2![#0H@("`@("`@("`@("`D<F5L96%S92`]("1I;F9O6R=R)UU;,%T[#0H@
M("`@("`@('T-"B`@("`@("`@)')E;&5A<V5I;F9O(#T@)'1H:7,M/E]R97-T
M+3YR971R:65V94-A8VAE1FER<W0H)&)A<V4@+B`G<B\G("X@<W1R=&]L;W=E
M<B@D<&%C:V%G92D@+B`G+R<@+B`-"B`@("`@("`@("`@("1R96QE87-E6R=V
M)UT@+B`G+GAM;"<I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5L
M96%S96EN9F\I*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G4&%C:V%G92`B)R`N("1P86-K86=E("X@)R(@5F5R<VEO;B`B)R`N
M("1R96QE87-E6R=V)UT@+@T*("`@("`@("`@("`@("`@("<B(&1O97,@;F]T
M(&AA=F4@4D535"!X;6P@879A:6QA8FQE)RD[#0H@("`@("`@('T-"B`@("`@
M("`@)'!A8VMA9V5X;6P@/2`D=&AI<RT^7W)E<W0M/G)E=')I979E0V%C:&5&
M:7)S="@D8F%S92`N("=R+R<@+B!S=')T;VQO=V5R*"1P86-K86=E*2`N("<O
M)R`N#0H@("`@("`@("`@("`G9&5P<RXG("X@)')E;&5A<V5;)W8G72`N("<N
M='AT)RP@9F%L<V4L('1R=64I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D<&%C:V%G97AM;"DI('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"=086-K86=E("(G("X@)'!A8VMA9V4@+B`G(B!697)S:6]N
M("(G("X@)')E;&5A<V5;)W8G72`N#0H@("`@("`@("`@("`@("`@)R(@9&]E
M<R!N;W0@:&%V92!215-4(&1E<&5N9&5N8WD@:6YF;W)M871I;VX@879A:6QA
M8FQE)RD[#0H@("`@("`@('T-"B`@("`@("`@)'!A8VMA9V5X;6P@/2!U;G-E
M<FEA;&EZ92@D<&%C:V%G97AM;"D[#0H@("`@("`@(&EF("@A)'!A8VMA9V5X
M;6PI('L-"B`@("`@("`@("`@("1P86-K86=E>&UL(#T@87)R87DH*3L-"B`@
M("`@("`@?0T*("`@("`@("`D86QL:6YF;R`]("1T:&ES+3Y?<F5S="T^<F5T
M<FEE=F5$871A*"1B87-E("X@)W(O)R`N('-T<G1O;&]W97(H)'!A8VMA9V4I
M("X-"B`@("`@("`@("`@("<O86QL<F5L96%S97,N>&UL)RD[#0H@("`@("`@
M(&EF("@A:7-?87)R87DH)&%L;&EN9F];)W(G72D@?'P@(6ES<V5T*"1A;&QI
M;F9O6R=R)UU;,%TI*2![#0H@("`@("`@("`@("`D86QL:6YF;ULG<B==(#T@
M87)R87DH)&%L;&EN9F];)W(G72D[#0H@("`@("`@('T-"B`@("`@("`@)&-O
M;7!A=&EB;&4@/2!F86QS93L-"B`@("`@("`@9F]R96%C:"`H)&%L;&EN9F];
M)W(G72!A<R`D<F5L96%S92D@>PT*("`@("`@("`@("`@:68@*"1R96QE87-E
M6R=V)UT@(3T@)')E;&5A<V5I;F9O6R=V)UTI('L-"B`@("`@("`@("`@("`@
M("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A
M:7-S970H)')E;&5A<V5;)V-O)UTI*2![#0H@("`@("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D8V]M<&%T:6)L92`]
M(&%R<F%Y*"D[#0H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1R96QE87-E
M6R=C;R==*2!\?"`A:7-S970H)')E;&5A<V5;)V-O)UU;,%TI*2![#0H@("`@
M("`@("`@("`@("`@)')E;&5A<V5;)V-O)UT@/2!A<G)A>2@D<F5L96%S95LG
M8V\G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E86-H("@D
M<F5L96%S95LG8V\G72!A<R`D96YT<GDI('L-"B`@("`@("`@("`@("`@("`D
M8V]M<"`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@)&-O;7!;)VYA;64G
M72`]("1E;G1R>5LG<"==.PT*("`@("`@("`@("`@("`@("1C;VUP6R=C:&%N
M;F5L)UT@/2`D96YT<GE;)V,G73L-"B`@("`@("`@("`@("`@("`D8V]M<%LG
M;6EN)UT@/2`D96YT<GE;)VUI;B==.PT*("`@("`@("`@("`@("`@("1C;VUP
M6R=M87@G72`]("1E;G1R>5LG;6%X)UT[#0H@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1E;G1R>5LG>"==*2`F)B`A:7-?87)R87DH)&5N=')Y6R=X)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("1C;VUP6R=E>&-L=61E)UT@/2`D
M96YT<GE;)W@G73L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@)&-O;7!A=&EB;&5;72`]("1C;VUP.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@:68@*&-O=6YT*"1C;VUP871I8FQE*2`]/2`Q*2![#0H@("`@
M("`@("`@("`@("`@)&-O;7!A=&EB;&4@/2`D8V]M<&%T:6)L95LP73L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@D9F]U;F0I('L-"B`@("`@("`@("`@(')E='5R;B`-"B`@
M("`@("`@("`@("`@("!A<G)A>2@G=F5R<VEO;B<@/3X@)')E;&5A<V5I;F9O
M6R=V)UTL#0H@("`@("`@("`@("`@("`@("`@("`@)VEN9F\G(#T^("1P86-K
M86=E>&UL+`T*("`@("`@("`@("`@("`@("`@("`@("=P86-K86=E)R`]/B`D
M<F5L96%S96EN9F];)W`G75LG7V-O;G1E;G0G72P-"B`@("`@("`@("`@("`@
M("`@("`@("`G<W1A8FEL:71Y)R`]/B`D<F5L96%S96EN9F];)W-T)UTL#0H@
M("`@("`@("`@("`@("`@("`@("`@)W5R;"<@/3X@)')E;&5A<V5I;F9O6R=G
M)UTL#0H@("`@("`@("`@("`@("`@("`@("`@)V-O;7!A=&EB;&4G(#T^("1C
M;VUP871I8FQE*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E
M='5R;@T*("`@("`@("`@("`@("`@(&%R<F%Y*"=V97)S:6]N)R`]/B`D<F5L
M96%S96EN9F];)W8G72P-"B`@("`@("`@("`@("`@("`@("`@("`G<&%C:V%G
M92<@/3X@)')E;&5A<V5I;F9O6R=P)UU;)U]C;VYT96YT)UTL#0H@("`@("`@
M("`@("`@("`@("`@("`@)W-T86)I;&ET>2<@/3X@)')E;&5A<V5I;F9O6R=S
M="==+`T*("`@("`@("`@("`@("`@("`@("`@("=I;F9O)R`]/B`D<&%C:V%G
M97AM;"P-"B`@("`@("`@("`@("`@("`@("`@("`G8V]M<&%T:6)L92<@/3X@
M)&-O;7!A=&EB;&4I.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@;&ES=%!A8VMA9V5S*"1B87-E*0T*("`@('L-"B`@("`@("`@)'!A8VMA
M9V5L:7-T(#T@)'1H:7,M/E]R97-T+3YR971R:65V941A=&$H)&)A<V4@+B`G
M<"]P86-K86=E<RYX;6PG*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)'!A8VMA9V5L:7-T*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1P86-K86=E
M;&ES=#L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P86-K
M86=E;&ES="D@?'P@(6ES<V5T*"1P86-K86=E;&ES=%LG<"==*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y*"D[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"%I<U]A<G)A>2@D<&%C:V%G96QI<W1;)W`G72DI('L-"B`@("`@("`@
M("`@("1P86-K86=E;&ES=%LG<"==(#T@87)R87DH)'!A8VMA9V5L:7-T6R=P
M)UTI.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<&%C:V%G96QI<W1;
M)W`G73L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!L:7-T06QL*"1B87-E+"`D
M9&]S=&%B;&4L("1B87-I8R`]('1R=64L("1S96%R8VAP86-K86=E(#T@9F%L
M<V4L("1S96%R8VAS=6UM87)Y(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D
M<&%C:V%G96QI<W0@/2`D=&AI<RT^7W)E<W0M/G)E=')I979E1&%T82@D8F%S
M92`N("=P+W!A8VMA9V5S+GAM;"<I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D<&%C:V%G96QI<W0I*2![#0H@("`@("`@("`@("!R971U<FX@)'!A
M8VMA9V5L:7-T.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D=&AI<RT^7W)E
M<W0M/F-O;F9I9RT^9V5T*"=V97)B;W-E)RD@/B`P*2![#0H@("`@("`@("`@
M("`D=6D@/2`F4$5!4E]&<F]N=&5N9#HZ<VEN9VQE=&]N*"D[#0H@("`@("`@
M("`@("`D=6DM/FQO9R@G4F5T<FEE=FEN9R!D871A+BXN,"4G+"!F86QS92D[
M#0H@("`@("`@('T-"B`@("`@("`@)')E="`](&%R<F%Y*"D[#0H@("`@("`@
M(&EF("@A:7-?87)R87DH)'!A8VMA9V5L:7-T*2!\?"`A:7-S970H)'!A8VMA
M9V5L:7-T6R=P)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)')E=#L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P86-K86=E;&ES=%LG
M<"==*2D@>PT*("`@("`@("`@("`@)'!A8VMA9V5L:7-T6R=P)UT@/2!A<G)A
M>2@D<&%C:V%G96QI<W1;)W`G72D[#0H@("`@("`@('T-"B`@("`@("`@4$5!
M4CHZ<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@
M("`@("`D;F5X="`]("XQ.PT*("`@("`@("!F;W)E86-H("@D<&%C:V%G96QI
M<W1;)W`G72!A<R`D<')O9W)E<W,@/3X@)'!A8VMA9V4I('L-"B`@("`@("`@
M("`@(&EF("@D=&AI<RT^7W)E<W0M/F-O;F9I9RT^9V5T*"=V97)B;W-E)RD@
M/B`P*2![#0H@("`@("`@("`@("`@("`@:68@*"1P<F]G<F5S<R`O(&-O=6YT
M*"1P86-K86=E;&ES=%LG<"==*2`^/2`D;F5X="D@>PT*("`@("`@("`@("`@
M("`@("`@("!I9B`H)&YE>'0@/3T@+C4I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1U:2T^;&]G*"<U,"4G+"!F86QS92D[#0H@("`@("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=6DM
M/FQO9R@G+B<L(&9A;'-E*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`D;F5X="`K/2`N,3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)&)A<VEC*2![
M("\O(')E;6]T92UL:7-T(&-O;6UA;F0-"B`@("`@("`@("`@("`@("!I9B`H
M)&1O<W1A8FQE*2![#0H@("`@("`@("`@("`@("`@("`@("1L871E<W0@/2`D
M=&AI<RT^7W)E<W0M/G)E=')I979E1&%T82@D8F%S92`N("=R+R<@+B!S=')T
M;VQO=V5R*"1P86-K86=E*2`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G
M+W-T86)L92YT>'0G*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`D;&%T97-T(#T@)'1H:7,M/E]R97-T+3YR971R
M:65V941A=&$H)&)A<V4@+B`G<B\G("X@<W1R=&]L;W=E<B@D<&%C:V%G92D@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@)R]L871E<W0N='AT)RD[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1L871E<W0I*2![#0H@("`@("`@("`@("`@("`@("`@("1L871E
M<W0@/2!F86QS93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@)&EN9F\@/2!A<G)A>2@G<W1A8FQE)R`]/B`D;&%T97-T*3L-"B`@("`@
M("`@("`@('T@96QS92![("\O(&QI<W0M86QL(&-O;6UA;F0-"B`@("`@("`@
M("`@("`@("`D:6YF(#T@)'1H:7,M/E]R97-T+3YR971R:65V941A=&$H)&)A
M<V4@+B`G<"\G("X@<W1R=&]L;W=E<B@D<&%C:V%G92D@+B`G+VEN9F\N>&UL
M)RD[#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&EN9BDI
M('L-"B`@("`@("`@("`@("`@("`@("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN
M9R@I.PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)&EN9CL-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1S96%R8VAP86-K
M86=E*2![#0H@("`@("`@("`@("`@("`@("`@("1F;W5N9"`]("@A96UP='DH
M)'-E87)C:'!A8VMA9V4I("8F('-T<FES='(H)'!A8VMA9V4L("1S96%R8VAP
M86-K86=E*2`A/3T@9F%L<V4I.PT*("`@("`@("`@("`@("`@("`@("!I9B`H
M(21F;W5N9"`F)B`A*&ES<V5T*"1S96%R8VAS=6UM87)Y*2`F)B`A96UP='DH
M)'-E87)C:'-U;6UA<GDI#0H@("`@("`@("`@("`@("`@("`@("`@("`F)B`H
M<W1R:7-T<B@D:6YF6R=S)UTL("1S96%R8VAS=6UM87)Y*2`A/3T@9F%L<V4-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!\?"!S=')I<W1R*"1I;F9;
M)V0G72P@)'-E87)C:'-U;6UA<GDI("$]/2!F86QS92DI*0T*("`@("`@("`@
M("`@("`@("`@("![#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M93L-"B`@("`@("`@("`@("`@("`@("`@?3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@)')E;&5A<V5S(#T@)'1H:7,M/E]R97-T+3YR
M971R:65V941A=&$H)&)A<V4@+B`G<B\G("X@<W1R=&]L;W=E<B@D<&%C:V%G
M92D@+@T*("`@("`@("`@("`@("`@("`@("`G+V%L;')E;&5A<V5S+GAM;"<I
M.PT*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R96QE87-E
M<RDI('L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)')E;&5A
M<V5S6R=R)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("1R96QE87-E
M<ULG<B==(#T@87)R87DH)')E;&5A<V5S6R=R)UTI.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!U;G-E="@D;&%T97-T*3L-"B`@("`@
M("`@("`@("`@("!U;G-E="@D=6YS=&%B;&4I.PT*("`@("`@("`@("`@("`@
M('5N<V5T*"1S=&%B;&4I.PT*("`@("`@("`@("`@("`@('5N<V5T*"1S=&%T
M92D[#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)')E;&5A<V5S6R=R)UT@
M87,@)')E;&5A<V4I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D;&%T97-T*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1D
M;W-T86)L92`F)B`D<F5L96%S95LG<R==(#T]("=S=&%B;&4G*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&QA=&5S="`]("1R96QE87-E6R=V
M)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T871E(#T@)W-T
M86)L92<[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H(21D;W-T86)L92D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1L871E<W0@/2`D<F5L96%S95LG=B==.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1S=&%T92`]("1R96QE87-E6R=S
M)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<W1A
M8FQE*2`F)B`D<F5L96%S95LG<R==(#T]("=S=&%B;&4G*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D<W1A8FQE(#T@)')E;&5A<V5;)W8G73L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'5N<W1A8FQE*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1U;G-T86)L92`]("1S
M=&%B;&4[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M=6YS=&%B;&4I("8F("1R96QE87-E6R=S)UT@(3T@)W-T86)L92<I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1L871E<W0@/2`D=6YS=&%B;&4@/2`D
M<F5L96%S95LG=B==.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'-T871E
M(#T@)')E;&5A<V5;)W,G73L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&QA=&5S="D@)B8@(6ES<V5T
M*"1S=&%T92DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1S=&%T92`]
M("1R96QE87-E6R=S)UT[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1L871E<W0I("8F(&ES<V5T*"1S
M=&%B;&4I("8F(&ES<V5T*"1U;G-T86)L92DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1D97!S(#T@87)R87DH
M*3L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1U;G-T86)L92DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)'5N<W1A8FQE(#T@9F%L<V4[#0H@("`@
M("`@("`@("`@("`@("`@("1S=&%T92`]("=S=&%B;&4G.PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)'-T86)L92DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1L871E<W0@/2`D=6YS=&%B;&4@/2`D<W1A8FQE.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@)&QA=&5S="`]("1U;G-T86)L93L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D;&%T97-T*2D@>PT*("`@("`@("`@("`@("`@("`@("`D;&%T97-T(#T@
M9F%L<V4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF
M("@D;&%T97-T*2![#0H@("`@("`@("`@("`@("`@("`@("1D(#T@)'1H:7,M
M/E]R97-T+3YR971R:65V94-A8VAE1FER<W0H)&)A<V4@+B`G<B\G("X@<W1R
M=&]L;W=E<B@D<&%C:V%G92D@+B`G+V1E<',N)R`N#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D;&%T97-T("X@)RYT>'0G*3L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*"%014%2.CII<T5R<F]R*"1D*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)&0@/2!U;G-E<FEA;&EZ92@D9"D[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H)&0I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&1;)W)E<75I<F5D)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=0
M14%27U!A8VMA9V5&:6QE7W8R)RDI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL
M92]V,BYP:'`G.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)'!F*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!F(#T@;F5W(%!%05)?4&%C:V%G949I;&5?=C([#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!F+3YS971$97!S*"1D*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1D97!S(#T@)'!F+3YG971$97!S*"D[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1D97!S(#T@)&0[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1T9&5P<R!A<R`D9&5P*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("@D9&5P6R=T>7!E)UT@(3T]("=P:V<G
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P<UM=(#T@)&1E<#L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<W1A8FQE
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<W1A8FQE(#T@)RUN+V$M)SL-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"$D<V5A
M<F-H<&%C:V%G92D@>PT*("`@("`@("`@("`@("`@("`@("`D:6YF;R`](&%R
M<F%Y*"=S=&%B;&4G(#T^("1L871E<W0L("=S=6UM87)Y)R`]/B`D:6YF6R=S
M)UTL("=D97-C<FEP=&EO;B<@/3X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1I;F9;)V0G72P@)V1E<',G(#T^("1D97!S+"`G8V%T96=O<GDG(#T^("1I
M;F9;)V-A)UU;)U]C;VYT96YT)UTL#0H@("`@("`@("`@("`@("`@("`@("`@
M("`G=6YS=&%B;&4G(#T^("1U;G-T86)L92P@)W-T871E)R`]/B`D<W1A=&4I
M.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("1I;F9O(#T@87)R87DH)W-T86)L92<@/3X@)'-T86)L92P@)W-U;6UA
M<GDG(#T^("1I;F9;)W,G72P@)V1E<V-R:7!T:6]N)R`]/@T*("`@("`@("`@
M("`@("`@("`@("`@("`@)&EN9ELG9"==+"`G9&5P<R<@/3X@)&1E<',L("=C
M871E9V]R>2<@/3X@)&EN9ELG8V$G75LG7V-O;G1E;G0G72P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("=U;G-T86)L92<@/3X@)'5N<W1A8FQE+"`G<W1A
M=&4G(#T^("1S=&%T92D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@)')E=%LD<&%C:V%G95T@/2`D:6YF;SL-"B`@
M("`@("`@?0T*("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@
M("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&QI
M<W1,871E<W15<&=R861E<R@D8F%S92P@)'-T871E+"`D:6YS=&%L;&5D+"`D
M8VAA;FYE;"P@)B1R96<I#0H@("`@>PT*("`@("`@("`D<&%C:V%G96QI<W0@
M/2`D=&AI<RT^7W)E<W0M/G)E=')I979E1&%T82@D8F%S92`N("=P+W!A8VMA
M9V5S+GAM;"<I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&%C:V%G
M96QI<W0I*2![#0H@("`@("`@("`@("!R971U<FX@)'!A8VMA9V5L:7-T.PT*
M("`@("`@("!]#0H@("`@("`@("1R970@/2!A<G)A>2@I.PT*("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1P86-K86=E;&ES="D@?'P@(6ES<V5T*"1P86-K86=E
M;&ES=%LG<"==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1R970[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D<&%C:V%G96QI<W1;)W`G
M72DI('L-"B`@("`@("`@("`@("1P86-K86=E;&ES=%LG<"==(#T@87)R87DH
M)'!A8VMA9V5L:7-T6R=P)UTI.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M<W1A=&4I('L-"B`@("`@("`@("`@("1S=&%T97,@/2`D=&AI<RT^8F5T=&5R
M4W1A=&5S*"1S=&%T92P@=')U92D[#0H@("`@("`@('T-"B`@("`@("`@9F]R
M96%C:"`H)'!A8VMA9V5L:7-T6R=P)UT@87,@)'!A8VMA9V4I('L-"B`@("`@
M("`@("`@(&EF("@A:7-S970H)&EN<W1A;&QE9%MS=')T;VQO=V5R*"1P86-K
M86=E*5TI*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`D:6YS=%]V97)S:6]N(#T@)')E9RT^<&%C
M:V%G94EN9F\H)'!A8VMA9V4L("=V97)S:6]N)RP@)&-H86YN96PI.PT*("`@
M("`@("`@("`@4$5!4CHZ<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]2
M15154DXI.PT*("`@("`@("`@("`@)&EN9F\@/2`D=&AI<RT^7W)E<W0M/G)E
M=')I979E1&%T82@D8F%S92`N("=R+R<@+B!S=')T;VQO=V5R*"1P86-K86=E
M*2`N#0H@("`@("`@("`@("`@("`@)R]A;&QR96QE87-E<RYX;6PG*3L-"B`@
M("`@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1I;F9O*2D@>PT*("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.R`O+R!N;R!R96UO=&4@<F5L96%S97,-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&EF("@A:7-S970H)&EN9F];)W(G72DI('L-
M"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("1F;W5N9"`](&9A;'-E.PT*("`@("`@("`@("`@)')E;&5A
M<V4@/2!F86QS93L-"B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&EN9F];
M)W(G72D@?'P@(6ES<V5T*"1I;F9O6R=R)UU;,%TI*2![#0H@("`@("`@("`@
M("`@("`@)&EN9F];)W(G72`](&%R<F%Y*"1I;F9O6R=R)UTI.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)&EN9F];)W(G72!A<R`D
M<F5L96%S92D@>PT*("`@("`@("`@("`@("`@(&EF("@D:6YS=%]V97)S:6]N
M("8F('9E<G-I;VY?8V]M<&%R92@D<F5L96%S95LG=B==+"`D:6YS=%]V97)S
M:6]N+"`G/#TG*2D@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1S=&%T
M92D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H:6Y?87)R87DH)')E;&5A
M<V5;)W,G72P@)'-T871E<RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1F;W5N9"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@("`@("1F;W5N9"`]('1R=64[#0H@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A)&9O=6YD*2![#0H@
M("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D<F5L:6YF;R`]("1T:&ES+3Y?<F5S="T^<F5T<FEE=F5#86-H
M949I<G-T*"1B87-E("X@)W(O)R`N('-T<G1O;&]W97(H)'!A8VMA9V4I("X@
M)R\G("X@#0H@("`@("`@("`@("`@("`@)')E;&5A<V5;)W8G72`N("<N>&UL
M)RD[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5L:6YF;RDI
M('L-"B`@("`@("`@("`@("`@("!R971U<FX@)')E;&EN9F\[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`D<F5T6R1P86-K86=E72`](&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("`@("`G=F5R<VEO;B<@/3X@)')E;&5A<V5;)W8G
M72P-"B`@("`@("`@("`@("`@("`@("`@)W-T871E)R`]/B`D<F5L96%S95LG
M<R==+`T*("`@("`@("`@("`@("`@("`@("`G9FEL97-I>F4G(#T^("1R96QI
M;F9O6R=F)UTL#0H@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@?0T*("`@
M("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!P86-K
M86=E26YF;R@D8F%S92P@)'!A8VMA9V4I#0H@("`@>PT*("`@("`@("!014%2
M.CIP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@
M("`@("1P:6YF;R`]("1T:&ES+3Y?<F5S="T^<F5T<FEE=F5$871A*"1B87-E
M("X@)W`O)R`N('-T<G1O;&]W97(H)'!A8VMA9V4I("X@)R]I;F9O+GAM;"<I
M.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&EN9F\I*2![#0H@("`@
M("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G56YK;F]W;B!P86-K86=E.B`B
M)R`N("1P86-K86=E("X@)R(@*$1E8G5G.B`G("X-"B`@("`@("`@("`@("`@
M("`D<&EN9F\M/F=E=$UE<W-A9V4H*2`N("<I)RD[#0H@("`@("`@('T-"B`@
M("`@("`@)')E;&5A<V5S(#T@87)R87DH*3L-"B`@("`@("`@)&%L;')E;&5A
M<V5S(#T@)'1H:7,M/E]R97-T+3YR971R:65V941A=&$H)&)A<V4@+B`G<B\G
M("X@<W1R=&]L;W=E<B@D<&%C:V%G92D@+@T*("`@("`@("`@("`@)R]A;&QR
M96QE87-E<RYX;6PG*3L-"B`@("`@("`@:68@*"%014%2.CII<T5R<F]R*"1A
M;&QR96QE87-E<RDI('L-"B`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S
M*"=014%27U!A8VMA9V5&:6QE7W8R)RDI('L-"B`@("`@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G949I;&4O=C(N<&AP)SL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&%L;')E;&5A
M<V5S6R=R)UTI*2![#0H@("`@("`@("`@("`@("`@)&%L;')E;&5A<V5S6R=R
M)UT@/2!A<G)A>2@D86QL<F5L96%S97-;)W(G72D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`D<&8@/2!N97<@4$5!4E]086-K86=E1FEL95]V,CL-
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1A;&QR96QE87-E<ULG<B==(&%S("1R
M96QE87-E*2![#0H@("`@("`@("`@("`@("`@)&1S(#T@)'1H:7,M/E]R97-T
M+3YR971R:65V94-A8VAE1FER<W0H)&)A<V4@+B`G<B\G("X@<W1R=&]L;W=E
M<B@D<&%C:V%G92D@+B`G+V1E<',N)R`N#0H@("`@("`@("`@("`@("`@("`@
M("1R96QE87-E6R=V)UT@+B`G+G1X="<I.PT*("`@("`@("`@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1D<RDI('L-"B`@("`@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&EF("@A:7-S970H)&QA=&5S="DI('L-"B`@("`@("`@("`@("`@("`@("`@
M)&QA=&5S="`]("1R96QE87-E6R=V)UT[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("1P9BT^<V5T1&5P<RAU;G-E<FEA;&EZ92@D9',I
M*3L-"B`@("`@("`@("`@("`@("`D9',@/2`D<&8M/F=E=$1E<',H*3L-"B`@
M("`@("`@("`@("`@("`D:6YF;R`]("1T:&ES+3Y?<F5S="T^<F5T<FEE=F5#
M86-H949I<G-T*"1B87-E("X@)W(O)R`N('-T<G1O;&]W97(H)'!A8VMA9V4I
M#0H@("`@("`@("`@("`@("`@("`@("X@)R\G("X@)')E;&5A<V5;)W8G72`N
M("<N>&UL)RD[#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&EN9F\I*2![#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D<F5L96%S97-;)')E
M;&5A<V5;)W8G75T@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)V1O
M;F5B>2<@/3X@)&EN9F];)VTG72P-"B`@("`@("`@("`@("`@("`@("`@)VQI
M8V5N<V4G(#T^("1I;F9O6R=L)UTL#0H@("`@("`@("`@("`@("`@("`@("=S
M=6UM87)Y)R`]/B`D:6YF;ULG<R==+`T*("`@("`@("`@("`@("`@("`@("`G
M9&5S8W)I<'1I;VXG(#T^("1I;F9O6R=D)UTL#0H@("`@("`@("`@("`@("`@
M("`@("=R96QE87-E9&%T92<@/3X@)&EN9F];)V1A)UTL#0H@("`@("`@("`@
M("`@("`@("`@("=R96QE87-E;F]T97,G(#T^("1I;F9O6R=N)UTL#0H@("`@
M("`@("`@("`@("`@("`@("=S=&%T92<@/3X@)')E;&5A<V5;)W,G72P-"B`@
M("`@("`@("`@("`@("`@("`@)V1E<',G(#T^("1D<R`_("1D<R`Z(&%R<F%Y
M*"DL#0H@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("1L871E<W0@/2`G)SL-"B`@("`@
M("`@?0T*("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@
M("`@(')E='5R;B!A<G)A>2@-"B`@("`@("`@("`@("=N86UE)R`]/B`D<&EN
M9F];)VXG72P-"B`@("`@("`@("`@("=C:&%N;F5L)R`]/B`D<&EN9F];)V,G
M72P-"B`@("`@("`@("`@("=C871E9V]R>2<@/3X@)'!I;F9O6R=C82==6R=?
M8V]N=&5N="==+`T*("`@("`@("`@("`@)W-T86)L92<@/3X@)&QA=&5S="P-
M"B`@("`@("`@("`@("=L:6-E;G-E)R`]/B`D<&EN9F];)VPG72P-"B`@("`@
M("`@("`@("=S=6UM87)Y)R`]/B`D<&EN9F];)W,G72P-"B`@("`@("`@("`@
M("=D97-C<FEP=&EO;B<@/3X@)'!I;F9O6R=D)UTL#0H@("`@("`@("`@("`G
M<F5L96%S97,G(#T^("1R96QE87-E<RP-"B`@("`@("`@("`@("D[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@4F5T=7)N(&%N(&%R<F%Y(&-O;G1A:6YI
M;F<@86QL(&]F('1H92!S=&%T97,@=&AA="!A<F4@;6]R92!S=&%B;&4@=&AA
M;@T*("`@("`J(&]R(&5Q=6%L('1O('1H92!P87-S960@:6X@<W1A=&4-"B`@
M("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@4F5L96%S92!S=&%T90T*("`@
M("`J($!P87)A;2!B;V]L96%N($1E=&5R;6EN97,@=VAE=&AE<B!T;R!I;F-L
M=61E("1S=&%T92!I;B!T:&4@;&ES=`T*("`@("`J($!R971U<FX@9F%L<V5\
M87)R87D@1F%L<V4@:68@)'-T871E(&ES(&YO="!A('9A;&ED(')E;&5A<V4@
M<W1A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!B971T97)3=&%T97,H)'-T
M871E+"`D:6YC;'5D92`](&9A;'-E*0T*("`@('L-"B`@("`@("`@<W1A=&EC
M("1S=&%T97,@/2!A<G)A>2@G<VYA<'-H;W0G+"`G9&5V96PG+"`G86QP:&$G
M+"`G8F5T82<L("=S=&%B;&4G*3L-"B`@("`@("`@)&D@/2!A<G)A>5]S96%R
M8V@H)'-T871E+"`D<W1A=&5S*3L-"B`@("`@("`@:68@*"1I(#T]/2!F86QS
M92D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@D:6YC;'5D92D@>PT*("`@("`@("`@("`@)&DM+3L-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@87)R87E?<VQI8V4H)'-T871E<RP@
M)&D@*R`Q*3L-"B`@("!]#0I]#0H_/@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]014%2+U)%4U0O,3$N<&AP````````````````````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-S0V-@`Q,#4Q-30S,S<T,``P,C$P-34`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`-"B\J*@T*("H@4$5!4E]215-47S$Q("T@:6UP;&5M96YT(&9A<W1E<B!L
M:7-T+6%L;"]R96UO=&4M;&ES="!C;VUM86YD#0H@*@T*("H@4$A0('9E<G-I
M;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE
M(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E
M#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E
M(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE
M('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N
M9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO
M=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A
M<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"
M96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR
M,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@
M0'9E<G-I;VX@("`@0U93.B`D260Z(#$Q+G!H<"QV(#$N-"`R,#`V+S`Q+S`V
M(#`T.C0W.C,W(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I
M;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C,-"B`J+PT*#0HO*BH-
M"B`J($9O<B!D;W=N;&]A9&EN9R!215-4('AM;"]T>'0@9FEL97,-"B`J+PT*
M<F5Q=6ER95]O;F-E("=014%2+U)%4U0N<&AP)SL-"@T*+RHJ#0H@*B!);7!L
M96UE;G0@4D535"`Q+C$-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`
M<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\
M8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE
M(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO
M;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S
M(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XS#0H@*B\-"F-L87-S(%!%
M05)?4D535%\Q,0T*>PT*("`@("\J*@T*("`@("`J($!V87(@4$5!4E]215-4
M#0H@("`@("HO#0H@("`@=F%R("1?<F5S=#L-"@T*("`@(&9U;F-T:6]N(%!%
M05)?4D535%\Q,2@D8V]N9FEG+"`D;W!T:6]N<R`](&%R<F%Y*"DI#0H@("`@
M>PT*("`@("`@("`D=&AI<RT^7W)E<W0@/2`F;F5W(%!%05)?4D535"@D8V]N
M9FEG+"`D;W!T:6]N<RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@;&ES=$%L
M;"@D8F%S92P@)&1O<W1A8FQE+"`D8F%S:6,@/2!T<G5E*0T*("`@('L-"B`@
M("`@("`@)&-A=&5G;W)Y;&ES="`]("1T:&ES+3Y?<F5S="T^<F5T<FEE=F5$
M871A*"1B87-E("X@)V,O8V%T96=O<FEE<RYX;6PG*3L-"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&-A=&5G;W)Y;&ES="DI('L-"B`@("`@("`@("`@
M(')E='5R;B`D8V%T96=O<GEL:7-T.PT*("`@("`@("!]#0H@("`@("`@("1R
M970@/2!A<G)A>2@I.PT*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1C871E9V]R
M>6QI<W1;)V,G72DI('L-"B`@("`@("`@("`@("1C871E9V]R>6QI<W1;)V,G
M72`](&%R<F%Y*"1C871E9V]R>6QI<W1;)V,G72D[#0H@("`@("`@('T-"B`@
M("`@("`@4$5!4CHZ<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]21515
M4DXI.PT*("`@("`@("!F;W)E86-H("@D8V%T96=O<GEL:7-T6R=C)UT@87,@
M)'!R;V=R97-S(#T^("1C871E9V]R>2D@>PT*("`@("`@("`@("`@)&-A=&5G
M;W)Y(#T@)&-A=&5G;W)Y6R=?8V]N=&5N="==.PT*("`@("`@("`@("`@)'!A
M8VMA9V5S:6YF;R`]("1T:&ES+3Y?<F5S="T^<F5T<FEE=F5$871A*"1B87-E
M("X-"B`@("`@("`@("`@("`@("`G8R\G("X@=7)L96YC;V1E*"1C871E9V]R
M>2D@+B`G+W!A8VMA9V5S:6YF;RYX;6PG*3L-"B`@("`@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1P86-K86=E<VEN9F\I*2![#0H@("`@("`@("`@("`@
M("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M(6ES7V%R<F%Y*"1P86-K86=E<VEN9F\I('Q\("%I<W-E="@D<&%C:V%G97-I
M;F9O6R=P:2==*2D@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D<&%C:V%G
M97-I;F9O6R=P:2==*2!\?"`A:7-S970H)'!A8VMA9V5S:6YF;ULG<&DG75LP
M72DI('L-"B`@("`@("`@("`@("`@("`D<&%C:V%G97-I;F9O6R=P:2==(#T@
M87)R87DH)'!A8VMA9V5S:6YF;ULG<&DG72D[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!F;W)E86-H("@D<&%C:V%G97-I;F9O6R=P:2==(&%S("1P
M86-K86=E:6YF;RD@>PT*("`@("`@("`@("`@("`@("1I;F9O(#T@)'!A8VMA
M9V5I;F9O6R=P)UT[#0H@("`@("`@("`@("`@("`@)'!A8VMA9V4@/2`D:6YF
M;ULG;B==.PT*("`@("`@("`@("`@("`@("1R96QE87-E<R`](&ES<V5T*"1P
M86-K86=E:6YF;ULG82==*2`_("1P86-K86=E:6YF;ULG82==(#H@9F%L<V4[
M#0H@("`@("`@("`@("`@("`@=6YS970H)&QA=&5S="D[#0H@("`@("`@("`@
M("`@("`@=6YS970H)'5N<W1A8FQE*3L-"B`@("`@("`@("`@("`@("!U;G-E
M="@D<W1A8FQE*3L-"B`@("`@("`@("`@("`@("!U;G-E="@D<W1A=&4I.PT*
M("`@("`@("`@("`@("`@(&EF("@D<F5L96%S97,I('L-"B`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D<F5L96%S97-;)W(G75LP72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1R96QE87-E<ULG<B==(#T@87)R87DH
M)')E;&5A<V5S6R=R)UTI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R96QE87-E<ULG<B==(&%S("1R
M96QE87-E*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1L871E<W0I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"1D;W-T86)L92`F)B`D<F5L96%S95LG<R==(#T]("=S=&%B;&4G*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1L871E<W0@/2`D<F5L
M96%S95LG=B==.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<W1A=&4@/2`G<W1A8FQE)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"$D9&]S=&%B
M;&4I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&QA=&5S
M="`]("1R96QE87-E6R=V)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1S=&%T92`]("1R96QE87-E6R=S)UT[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<W1A8FQE*2`F
M)B`D<F5L96%S95LG<R==(#T]("=S=&%B;&4G*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'-T86)L92`]("1R96QE87-E6R=V)UT[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=6YS=&%B;&4I
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1U;G-T86)L
M92`]("1S=&%B;&4[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D=6YS=&%B;&4I("8F("1R96QE87-E6R=S)UT@
M(3T@)W-T86)L92<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;&%T97-T(#T@)'5N<W1A8FQE(#T@)')E;&5A<V5;)W8G73L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<W1A=&4@/2`D<F5L96%S95LG<R==.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1L871E<W0I("8F("%I<W-E="@D<W1A=&4I*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T871E(#T@)')E;&5A
M<V5;)W,G73L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D;&%T97-T*2`F)B!I<W-E="@D
M<W1A8FQE*2`F)B!I<W-E="@D=6YS=&%B;&4I*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@:68@*"1B87-I8RD@>R`O+R!R96UO=&4M;&ES
M="!C;VUM86YD#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&QA
M=&5S="DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1L871E<W0@/2!F
M86QS93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`D<F5T6R1P86-K86=E72`](&%R<F%Y*"=S=&%B;&4G(#T^("1L871E
M<W0I.PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@+R\@;&ES="UA;&P@8V]M;6%N
M9`T*("`@("`@("`@("`@("`@("1D97!S(#T@87)R87DH*3L-"B`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1U;G-T86)L92DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)'5N<W1A8FQE(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@
M("`@("1S=&%T92`]("=S=&%B;&4G.PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)'-T86)L92DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1L871E<W0@/2`D=6YS=&%B;&4@/2`D<W1A8FQE.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@)&QA=&5S="`]("1U;G-T86)L93L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;&%T97-T*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`D;&%T97-T(#T@9F%L<V4[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D;&%T97-T*2![
M#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C:V%G96EN9F];
M)V1E<',G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?
M87)R87DH)'!A8VMA9V5I;F9O6R=D97!S)UTI('Q\#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`A:7-S970H)'!A8VMA9V5I;F9O6R=D97!S)UU;
M,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V5I
M;F9O6R=D97!S)UT@/2!A<G)A>2@D<&%C:V%G96EN9F];)V1E<',G72D[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@)&0@/2!F86QS93L-"B`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)'!A8VMA9V5I;F9O6R=D97!S)UT@87,@
M)&1E<"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1D97!;)W8G
M72`]/2`D;&%T97-T*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&0@/2!U;G-E<FEA;&EZ92@D9&5P6R=D)UTI.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@D9"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1D6R=R97%U:7)E9"==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27U!A8VMA9V5&
M:6QE7W8R)RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E("=014%2+U!A8VMA9V5&:6QE+W8R+G!H<"<[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)'!F*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<&8@/2!N97<@4$5!4E]086-K86=E1FEL95]V
M,CL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!F+3YS971$97!S*"1D*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&1E<',@/2`D<&8M/F=E=$1E<',H*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1D97!S(#T@)&0[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H
M("@D=&1E<',@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@D9&5P6R=T>7!E)UT@(3T]("=P:V<G*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9&5P<UM=(#T@)&1E<#L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1S=&%B;&4I*2![#0H@("`@("`@
M("`@("`@("`@("`@("1S=&%B;&4@/2`G+6XO82TG.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`D:6YF;R`](&%R<F%Y*"=S=&%B;&4G
M(#T^("1L871E<W0L("=S=6UM87)Y)R`]/B`D:6YF;ULG<R==+`T*("`@("`@
M("`@("`@("`@("`@("`G9&5S8W)I<'1I;VXG(#T^#0H@("`@("`@("`@("`@
M("`@("`@("1I;F9O6R=D)UTL("=D97!S)R`]/B`D9&5P<RP@)V-A=&5G;W)Y
M)R`]/B`D:6YF;ULG8V$G75LG7V-O;G1E;G0G72P-"B`@("`@("`@("`@("`@
M("`@("`@)W5N<W1A8FQE)R`]/B`D=6YS=&%B;&4L("=S=&%T92<@/3X@)'-T
M871E*3L-"B`@("`@("`@("`@("`@("`D<F5T6R1P86-K86=E72`]("1I;F9O
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(%!%05(Z.G!O
M<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@4F5T=7)N(&%N(&%R<F%Y(&-O;G1A:6YI
M;F<@86QL(&]F('1H92!S=&%T97,@=&AA="!A<F4@;6]R92!S=&%B;&4@=&AA
M;@T*("`@("`J(&]R(&5Q=6%L('1O('1H92!P87-S960@:6X@<W1A=&4-"B`@
M("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@4F5L96%S92!S=&%T90T*("`@
M("`J($!P87)A;2!B;V]L96%N($1E=&5R;6EN97,@=VAE=&AE<B!T;R!I;F-L
M=61E("1S=&%T92!I;B!T:&4@;&ES=`T*("`@("`J($!R971U<FX@9F%L<V5\
M87)R87D@1F%L<V4@:68@)'-T871E(&ES(&YO="!A('9A;&ED(')E;&5A<V4@
M<W1A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!B971T97)3=&%T97,H)'-T
M871E+"`D:6YC;'5D92`](&9A;'-E*0T*("`@('L-"B`@("`@("`@<W1A=&EC
M("1S=&%T97,@/2!A<G)A>2@G<VYA<'-H;W0G+"`G9&5V96PG+"`G86QP:&$G
M+"`G8F5T82<L("=S=&%B;&4G*3L-"B`@("`@("`@)&D@/2!A<G)A>5]S96%R
M8V@H)'-T871E+"`D<W1A=&5S*3L-"B`@("`@("`@:68@*"1I(#T]/2!F86QS
M92D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@D:6YC;'5D92D@>PT*("`@("`@("`@("`@)&DM+3L-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@87)R87E?<VQI8V4H)'-T871E<RP@
M)&D@*R`Q*3L-"B`@("!]#0I]#0H_/@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]215-4+G!H<```
M````````````````````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S4T-C$`
M,3`U,34T,S,W-#$`,#(P-C,P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP#0HO*BH-"B`J(%!%05)?4D535`T*("H-
M"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H
M92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A
M;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P
M;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C
M871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H
M;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y
M<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC
M96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!215-4+G!H<"QV
M(#$N,C`@,C`P-B\P,R\P,B`P,SHP.3HS,2!P86IO>64@17AP("0-"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@
M*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N
M-"XP83$-"B`J+PT*#0HO*BH-"B`J($9O<B!D;W=N;&]A9&EN9R!X;6P@9FEL
M97,-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+G!H<"<[#0IR97%U:7)E7V]N
M8V4@)U!%05(O6$U,4&%R<V5R+G!H<"<[#0H-"B\J*@T*("H@26YT96QL:6=E
M;G1L>2!R971R:65V92!D871A+"!F;VQL;W=I;F<@:'EP97)L:6YK<R!I9B!N
M96-E<W-A<GDL(&%N9"!R92UD:7)E8W1I;F<-"B`J(&%S('=E;&P-"B`J($!C
M871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H
M;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y
M<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC
M96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*
M("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@
M,2XT+C!A,0T*("HO#0IC;&%S<R!014%27U)%4U0-"GL-"B`@("!V87(@)&-O
M;F9I9SL-"B`@("!V87(@)%]O<'1I;VYS.PT*("`@(&9U;F-T:6]N(%!%05)?
M4D535"@F)&-O;F9I9RP@)&]P=&EO;G,@/2!A<G)A>2@I*0T*("`@('L-"B`@
M("`@("`@)'1H:7,M/F-O;F9I9R`]("8D8V]N9FEG.PT*("`@("`@("`D=&AI
M<RT^7V]P=&EO;G,@/2`D;W!T:6]N<SL-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!2971R:65V92!215-4(&1A=&$L(&)U="!A;'=A>7,@<F5T<FEE=F4@
M=&AE(&QO8V%L(&-A8VAE(&EF(&ET(&ES(&%V86EL86)L92X-"B`@("`@*@T*
M("`@("`J(%1H:7,@:7,@=7-E9G5L(&9O<B!E;&5M96YT<R!T:&%T('-H;W5L
M9"!N979E<B!C:&%N9V4L('-U8V@@87,@:6YF;W)M871I;VX@;VX@82!P87)T
M:6-U;&%R#0H@("`@("H@<F5L96%S90T*("`@("`J($!P87)A;2!S=')I;F<@
M9G5L;"!54DP@=&\@=&AI<R!R97-O=7)C90T*("`@("`J($!P87)A;2!A<G)A
M>7QF86QS92!C;VYT96YT<R!O9B!T:&4@86-C97!T+65N8V]D:6YG(&AE861E
M<@T*("`@("`J($!P87)A;2!B;V]L96%N("`@("!I9B!T<G5E+"!X;6P@=VEL
M;"!B92!R971U<FYE9"!A<R!A('-T<FEN9RP@;W1H97)W:7-E+"!X;6P@=VEL
M;"!B90T*("`@("`J("`@("`@("`@("`@("`@("`@("!P87)S960@=7-I;F<@
M4$5!4E]834Q087)S97(-"B`@("`@*B!`<F5T=7)N('-T<FEN9WQA<G)A>0T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(')E=')I979E0V%C:&5&:7)S="@D=7)L
M+"`D86-C97!T(#T@9F%L<V4L("1F;W)C97-T<FEN9R`](&9A;'-E*0T*("`@
M('L-"B`@("`@("`@)&-A8VAE9FEL92`]("1T:&ES+3YC;VYF:6<M/F=E="@G
M8V%C:&5?9&ER)RD@+B!$25)%0U1/4EE?4T5005)!5$]2("X-"B`@("`@("`@
M("`@(&UD-2@D=7)L*2`N("=R97-T+F-A8VAE9FEL92<[#0H@("`@("`@(&EF
M("A`9FEL95]E>&ES=',H)&-A8VAE9FEL92DI('L-"B`@("`@("`@("`@(')E
M='5R;B!U;G-E<FEA;&EZ92AI;7!L;V1E*"<G+"!F:6QE*"1C86-H969I;&4I
M*2D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1T:&ES+3YR971R:65V
M941A=&$H)'5R;"P@)&%C8V5P="P@)&9O<F-E<W1R:6YG*3L-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*B!2971R:65V92!A(')E;6]T92!215-4(')E<V]U
M<F-E#0H@("`@("H@0'!A<F%M('-T<FEN9R!F=6QL(%523"!T;R!T:&ES(')E
M<V]U<F-E#0H@("`@("H@0'!A<F%M(&%R<F%Y?&9A;'-E(&-O;G1E;G1S(&]F
M('1H92!A8V-E<'0M96YC;V1I;F<@:&5A9&5R#0H@("`@("H@0'!A<F%M(&)O
M;VQE86X@("`@(&EF('1R=64L('AM;"!W:6QL(&)E(')E='5R;F5D(&%S(&$@
M<W1R:6YG+"!O=&AE<G=I<V4L('AM;"!W:6QL(&)E#0H@("`@("H@("`@("`@
M("`@("`@("`@("`@('!A<G-E9"!U<VEN9R!014%27UA-3%!A<G-E<@T*("`@
M("`J($!R971U<FX@<W1R:6YG?&%R<F%Y#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@<F5T<FEE=F5$871A*"1U<FPL("1A8V-E<'0@/2!F86QS92P@)&9O<F-E
M<W1R:6YG(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D8V%C:&5)9"`]("1T
M:&ES+3YG971#86-H94ED*"1U<FPI.PT*("`@("`@("!I9B`H)')E="`]("1T
M:&ES+3YU<V5,;V-A;$-A8VAE*"1U<FPL("1C86-H94ED*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1R970[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7V]P=&EO;G-;)V]F9FQI;F4G72DI('L-"B`@("`@("`@
M("`@("1T<FEE9&1O=VYL;V%D(#T@=')U93L-"B`@("`@("`@("`@("1F:6QE
M(#T@)'1H:7,M/F1O=VYL;V%D2'1T<"@D=7)L+"`D8V%C:&5)9"`_("1C86-H
M94ED6R=L87-T0VAA;F=E)UT@.B!F86QS92P@)&%C8V5P="D[#0H@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`D=')I961D;W=N;&]A9"`](&9A;'-E
M.PT*("`@("`@("`@("`@)&9I;&4@/2!F86QS93L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D9FEL92DI('L-"B`@("`@("`@("`@
M(&EF("@D9FEL92T^9V5T0V]D92@I(#T]("TY,C<V*2![#0H@("`@("`@("`@
M("`@("`@)'1R:65D9&]W;FQO860@/2!F86QS93L-"B`@("`@("`@("`@("`@
M("`D9FEL92`](&9A;'-E.R`O+R!U<V4@;&]C86P@8V]P>2!I9B!A=F%I;&%B
M;&4@;VX@<V]C:V5T(&-O;FYE8W0@97)R;W(-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1F:6QE.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@A)&9I;&4I('L-"B`@("`@
M("`@("`@("1R970@/2`D=&AI<RT^9V5T0V%C:&4H)'5R;"D[#0H@("`@("`@
M("`@("!I9B`H(5!%05(Z.FES17)R;W(H)')E="D@)B8@)'1R:65D9&]W;FQO
M860I('L-"B`@("`@("`@("`@("`@("`O+R!R97-E="!T:&4@86=E(&]F('1H
M92!C86-H92!I9B!T:&4@<V5R=F5R('-A>7,@:70@=V%S('5N;6]D:69I960-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<V%V94-A8VAE*"1U<FPL("1R970L
M(&YU;&PL('1R=64L("1C86-H94ED*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(')E='5R;B`D<F5T.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI
M<U]A<G)A>2@D9FEL92DI('L-"B`@("`@("`@("`@("1H96%D97)S(#T@)&9I
M;&5;,ET[#0H@("`@("`@("`@("`D;&%S=&UO9&EF:65D(#T@)&9I;&5;,5T[
M#0H@("`@("`@("`@("`D8V]N=&5N="`]("1F:6QE6S!=.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@)&-O;G1E;G0@/2`D9FEL93L-"B`@("`@
M("`@("`@("1L87-T;6]D:69I960@/2!F86QS93L-"B`@("`@("`@("`@("1H
M96%D97)S(#T@87)R87DH*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&9O
M<F-E<W1R:6YG*2![#0H@("`@("`@("`@("`D=&AI<RT^<V%V94-A8VAE*"1U
M<FPL("1C;VYT96YT+"`D;&%S=&UO9&EF:65D+"!F86QS92P@)&-A8VAE260I
M.PT*("`@("`@("`@("`@<F5T=7)N("1C;VYT96YT.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("AI<W-E="@D:&5A9&5R<ULG8V]N=&5N="UT>7!E)UTI*2![
M#0H@("`@("`@("`@("!S=VET8V@@*"1H96%D97)S6R=C;VYT96YT+71Y<&4G
M72D@>PT*("`@("`@("`@("`@("`@(&-A<V4@)W1E>'0O>&UL)R`Z#0H@("`@
M("`@("`@("`@("`@8V%S92`G87!P;&EC871I;VXO>&UL)R`Z#0H@("`@("`@
M("`@("`@("`@("`@("1P87)S97(@/2!N97<@4$5!4E]834Q087)S97([#0H@
M("`@("`@("`@("`@("`@("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG*%!%
M05)?15)23U)?4D5455).*3L-"B`@("`@("`@("`@("`@("`@("`@)&5R<B`]
M("1P87)S97(M/G!A<G-E*"1C;VYT96YT*3L-"B`@("`@("`@("`@("`@("`@
M("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TEN=F%L:60@
M>&UL(&1O=VYL;V%D960@9G)O;2`B)R`N("1U<FP@+B`G(CH@)R`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&5R<BT^9V5T365S<V%G92@I*3L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D
M8V]N=&5N="`]("1P87)S97(M/F=E=$1A=&$H*3L-"B`@("`@("`@("`@("`@
M("!C87-E("=T97AT+VAT;6PG(#H-"B`@("`@("`@("`@("`@("!D969A=6QT
M(#H-"B`@("`@("`@("`@("`@("`@("`@+R\@=7-E(&ET(&%S(&$@<W1R:6YG
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`O+R!A<W-U;64@6$U,#0H@("`@("`@("`@("`D<&%R<V5R(#T@;F5W(%!%
M05)?6$U,4&%R<V5R.PT*("`@("`@("`@("`@)'!A<G-E<BT^<&%R<V4H)&-O
M;G1E;G0I.PT*("`@("`@("`@("`@)&-O;G1E;G0@/2`D<&%R<V5R+3YG971$
M871A*"D[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/G-A=F5#86-H92@D
M=7)L+"`D8V]N=&5N="P@)&QA<W1M;V1I9FEE9"P@9F%L<V4L("1C86-H94ED
M*3L-"B`@("`@("`@<F5T=7)N("1C;VYT96YT.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N('5S94QO8V%L0V%C:&4H)'5R;"P@)&-A8VAE:60@/2!N=6QL*0T*
M("`@('L-"B`@("`@("`@:68@*"1C86-H96ED(#T]/2!N=6QL*2![#0H@("`@
M("`@("`@("`D8V%C:&5I9&9I;&4@/2`D=&AI<RT^8V]N9FEG+3YG970H)V-A
M8VAE7V1I<B<I("X@1$E214-43U)97U-%4$%2051/4B`N#0H@("`@("`@("`@
M("`@("`@;60U*"1U<FPI("X@)W)E<W0N8V%C:&5I9"<[#0H@("`@("`@("`@
M("!I9B`H0&9I;&5?97AI<W1S*"1C86-H96ED9FEL92DI('L-"B`@("`@("`@
M("`@("`@("`D8V%C:&5I9"`]('5N<V5R:6%L:7IE*&EM<&QO9&4H)R<L(&9I
M;&4H)&-A8VAE:61F:6QE*2DI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@)&-A8VAE='1L(#T@)'1H:7,M/F-O;F9I9RT^
M9V5T*"=C86-H95]T=&PG*3L-"B`@("`@("`@+R\@268@8V%C:&4@:7,@;F5W
M97(@=&AA;B`D8V%C:&5T=&P@<V5C;VYD<RP@=V4@=7-E('1H92!C86-H92$-
M"B`@("`@("`@:68@*'1I;64H*2`M("1C86-H96ED6R=A9V4G72`\("1C86-H
M971T;"D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG971#86-H92@D
M=7)L*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@9V5T0V%C:&5)9"@D=7)L*0T*("`@('L-"B`@
M("`@("`@)&-A8VAE:61F:6QE(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=C86-H
M95]D:7(G*2`N($1)4D5#5$]265]315!!4D%43U(@+@T*("`@("`@("`@("`@
M;60U*"1U<FPI("X@)W)E<W0N8V%C:&5I9"<[#0H@("`@("`@(&EF("A`9FEL
M95]E>&ES=',H)&-A8VAE:61F:6QE*2D@>PT*("`@("`@("`@("`@)')E="`]
M('5N<V5R:6%L:7IE*&EM<&QO9&4H)R<L(&9I;&4H)&-A8VAE:61F:6QE*2DI
M.PT*("`@("`@("`@("`@<F5T=7)N("1R970[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!G971#86-H92@D=7)L*0T*("`@('L-"B`@("`@
M("`@)&-A8VAE9FEL92`]("1T:&ES+3YC;VYF:6<M/F=E="@G8V%C:&5?9&ER
M)RD@+B!$25)%0U1/4EE?4T5005)!5$]2("X-"B`@("`@("`@("`@(&UD-2@D
M=7)L*2`N("=R97-T+F-A8VAE9FEL92<[#0H@("`@("`@(&EF("A`9FEL95]E
M>&ES=',H)&-A8VAE9FEL92DI('L-"B`@("`@("`@("`@(')E='5R;B!U;G-E
M<FEA;&EZ92AI;7!L;V1E*"<G+"!F:6QE*"1C86-H969I;&4I*2D[#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G3F\@8V%C:&5D(&-O;G1E;G0@879A:6QA8FQE(&9O<B`B)R`N("1U
M<FP@+B`G(B<I.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@0'!A<F%M('-T<FEN9R!F=6QL(%523"!T;R!215-4(')E<V]U<F-E#0H@
M("`@("H@0'!A<F%M('-T<FEN9R!O<FEG:6YA;"!C;VYT96YT<R!O9B!T:&4@
M4D535"!R97-O=7)C90T*("`@("`J($!P87)A;2!A<G)A>2`@2%144"!,87-T
M+4UO9&EF:65D(&%N9"!%5&%G(&AE861E<G,-"B`@("`@*B!`<&%R86T@8F]O
M;"`@(&EF('1R=64L('1H96X@=&AE(&-A8VAE(&ED(&9I;&4@<VAO=6QD(&)E
M(')E9V5N97)A=&5D('1O#0H@("`@("H@("`@("`@("`@("`@("!T<FEG9V5R
M(&$@;F5W('1I;64M=&\M;&EV92!V86QU90T*("`@("`J+PT*("`@(&9U;F-T
M:6]N('-A=F5#86-H92@D=7)L+"`D8V]N=&5N=',L("1L87-T;6]D:69I960L
M("1N;V-H86YG92`](&9A;'-E+"`D8V%C:&5I9"`](&YU;&PI#0H@("`@>PT*
M("`@("`@("`D8V%C:&5I9&9I;&4@/2`D=&AI<RT^8V]N9FEG+3YG970H)V-A
M8VAE7V1I<B<I("X@1$E214-43U)97U-%4$%2051/4B`N#0H@("`@("`@("`@
M("!M9#4H)'5R;"D@+B`G<F5S="YC86-H96ED)SL-"B`@("`@("`@)&-A8VAE
M9FEL92`]("1T:&ES+3YC;VYF:6<M/F=E="@G8V%C:&5?9&ER)RD@+B!$25)%
M0U1/4EE?4T5005)!5$]2("X-"B`@("`@("`@("`@(&UD-2@D=7)L*2`N("=R
M97-T+F-A8VAE9FEL92<[#0H@("`@("`@(&EF("@D8V%C:&5I9"`]/3T@;G5L
M;"`F)B`D;F]C:&%N9V4I('L-"B`@("`@("`@("`@("1C86-H96ED(#T@=6YS
M97)I86QI>F4H:6UP;&]D92@G)RP@9FEL92@D8V%C:&5I9&9I;&4I*2D[#0H@
M("`@("`@('T-"@T*("`@("`@("`D9G`@/2!`9F]P96XH)&-A8VAE:61F:6QE
M+"`G=V(G*3L-"B`@("`@("`@:68@*"$D9G`I('L-"B`@("`@("`@("`@("1C
M86-H95]D:7(@/2`D=&AI<RT^8V]N9FEG+3YG970H)V-A8VAE7V1I<B<I.PT*
M("`@("`@("`@("`@:68@*"%I<U]D:7(H)&-A8VAE7V1I<BDI('L-"B`@("`@
M("`@("`@("`@("!3>7-T96TZ.FUK9&ER*&%R<F%Y*"<M<"<L("1C86-H95]D
M:7(I*3L-"B`@("`@("`@("`@("`@("`D9G`@/2!`9F]P96XH)&-A8VAE:61F
M:6QE+"`G=V(G*3L-"B`@("`@("`@("`@("`@("!I9B`H(21F<"D@>PT*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"@T*("`@
M("`@("!I9B`H)&YO8VAA;F=E*2![#0H@("`@("`@("`@("!F=W)I=&4H)&9P
M+"!S97)I86QI>F4H87)R87DH#0H@("`@("`@("`@("`@("`@)V%G92<@("`@
M("`@(#T^('1I;64H*2P-"B`@("`@("`@("`@("`@("`G;&%S=$-H86YG92<@
M/3X@)&-A8VAE:61;)VQA<W1#:&%N9V4G72P-"B`@("`@("`@("`@("`@("`I
M*2D[#0H@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@9G=R
M:71E*"1F<"P@<V5R:6%L:7IE*&%R<F%Y*`T*("`@("`@("`@("`@("`@("=A
M9V4G("`@("`@("`]/B!T:6UE*"DL#0H@("`@("`@("`@("`@("`@)VQA<W1#
M:&%N9V4G(#T^("1L87-T;6]D:69I960L#0H@("`@("`@("`@("`@("`@*2DI
M.PT*("`@("`@("!]#0H@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("`D
M9G`@/2!`9F]P96XH)&-A8VAE9FEL92P@)W=B)RD[#0H@("`@("`@(&EF("@A
M)&9P*2![#0H@("`@("`@("`@("!`=6YL:6YK*"1C86-H96ED9FEL92D[#0H@
M("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@
M9G=R:71E*"1F<"P@<V5R:6%L:7IE*"1C;VYT96YT<RDI.PT*("`@("`@("!F
M8VQO<V4H)&9P*3L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@169F:6-I96YT;'D@1&]W;FQO860@82!F:6QE('1H
M<F]U9V@@2%144"X@(%)E='5R;G,@9&]W;FQO861E9"!F:6QE(&%S(&$@<W1R
M:6YG(&EN+6UE;6]R>0T*("`@("`J(%1H:7,@:7,@8F5S="!U<V5D(&9O<B!S
M;6%L;"!F:6QE<PT*("`@("`J#0H@("`@("H@268@86X@2%144"!P<F]X>2!H
M87,@8F5E;B!C;VYF:6=U<F5D("AH='1P7W!R;WAY(%!%05)?0V]N9FEG#0H@
M("`@("H@<V5T=&EN9RDL('1H92!P<F]X>2!W:6QL(&)E('5S960N#0H@("`@
M("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=7)L("`@("`@('1H92!54DP@
M=&\@9&]W;FQO860-"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V%V95]D:7(@
M(&1I<F5C=&]R>2!T;R!S879E(&9I;&4@:6X-"B`@("`@*B!`<&%R86T@9F%L
M<V5\<W1R:6YG?&%R<F%Y("1L87-T;6]D:69I960@:&5A9&5R('9A;'5E<R!T
M;R!C:&5C:R!A9V%I;G-T(&9O<B!C86-H:6YG#0H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("!U<V4@9F%L<V4@=&\@<F5T=7)N('1H92!H96%D
M97(@=F%L=65S(&9R;VT@=&AI<R!D;W=N;&]A9`T*("`@("`J($!P87)A;2!F
M86QS97QA<G)A>2`D86-C97!T($%C8V5P="!H96%D97)S('1O('-E;F0-"B`@
M("`@*B!`<F5T=7)N('-T<FEN9WQA<G)A>2`@4F5T=7)N<R!T:&4@8V]N=&5N
M=',@;V8@=&AE(&1O=VYL;V%D960@9FEL92!O<B!A(%!%05(-"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@97)R;W(@;VX@9F%I;'5R92X@($EF('1H
M92!E<G)O<B!I<R!C875S960@8GD-"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@<V]C:V5T+7)E;&%T960@97)R;W)S+"!T:&4@97)R;W(@;V)J96-T
M('=I;&P-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:&%V92!T:&4@
M9G-O8VMO<&5N(&5R<F]R(&-O9&4@879A:6QA8FQE('1H<F]U9V@-"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@9V5T0V]D92@I+B`@268@8V%C:&EN
M9R!I<R!R97%U97-T960L('1H96X@<F5T=7)N('1H92!H96%D97(-"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@=F%L=65S+@T*("`@("`J#0H@("`@
M("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!D;W=N
M;&]A9$AT='`H)'5R;"P@)&QA<W1M;V1I9FEE9"`](&YU;&PL("1A8V-E<'0@
M/2!F86QS92D-"B`@("![#0H@("`@("`@("1I;F9O(#T@<&%R<V5?=7)L*"1U
M<FPI.PT*("`@("`@("!I9B`H(6ES<V5T*"1I;F9O6R=S8VAE;64G72D@?'P@
M(6EN7V%R<F%Y*"1I;F9O6R=S8VAE;64G72P@87)R87DH)VAT='`G+"`G:'1T
M<',G*2DI('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=#86YN;W0@9&]W;FQO860@;F]N+6AT='`@55),("(G("X@)'5R;"`N("<B
M)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D:6YF;ULG:&]S
M="==*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)T-A;FYO="!D;W=N;&]A9"!F<F]M(&YO;BU54DP@(B<@+B`D=7)L("X@)R(G
M*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1H;W-T(#T@)&EN
M9F];)VAO<W0G73L-"B`@("`@("`@("`@(&EF("@A87)R87E?:V5Y7V5X:7-T
M<R@G<&]R="<L("1I;F9O*2D@>PT*("`@("`@("`@("`@("`@("1I;F9O6R=P
M;W)T)UT@/2!N=6QL.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@
M*"%A<G)A>5]K97E?97AI<W1S*"=P871H)RP@)&EN9F\I*2![#0H@("`@("`@
M("`@("`@("`@)&EN9F];)W!A=&@G72`](&YU;&P[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`D<&]R="`]("1I;F9O6R=P;W)T)UT[#0H@("`@("`@
M("`@("`D<&%T:"`]("1I;F9O6R=P871H)UT[#0H@("`@("`@('T-"B`@("`@
M("`@)'!R;WAY7VAO<W0@/2`D<')O>'E?<&]R="`]("1P<F]X>5]U<V5R(#T@
M)'!R;WAY7W!A<W,@/2`G)SL-"B`@("`@("`@:68@*"1T:&ES+3YC;VYF:6<M
M/F=E="@G:'1T<%]P<F]X>2<I)B8@#0H@("`@("`@("`@("`@("1P<F]X>2`]
M('!A<G-E7W5R;"@D=&AI<RT^8V]N9FEG+3YG970H)VAT='!?<')O>'DG*2DI
M('L-"B`@("`@("`@("`@("1P<F]X>5]H;W-T(#T@0"1P<F]X>5LG:&]S="==
M.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1P<F]X>5LG<V-H96UE)UTI("8F
M("1P<F]X>5LG<V-H96UE)UT@/3T@)VAT='!S)RD@>PT*("`@("`@("`@("`@
M("`@("1P<F]X>5]H;W-T(#T@)W-S;#HO+R<@+B`D<')O>'E?:&]S=#L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("1P<F]X>5]P;W)T(#T@0"1P<F]X
M>5LG<&]R="==.PT*("`@("`@("`@("`@)'!R;WAY7W5S97(@/2!`)'!R;WAY
M6R=U<V5R)UT[#0H@("`@("`@("`@("`D<')O>'E?<&%S<R`]($`D<')O>'E;
M)W!A<W,G73L-"@T*("`@("`@("`@("`@:68@*"1P<F]X>5]P;W)T(#T]("<G
M*2![#0H@("`@("`@("`@("`@("`@)'!R;WAY7W!O<G0@/2`X,#@P.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AE;7!T>2@D<&]R
M="DI('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D:6YF;ULG<V-H96UE)UTI
M("8F("1I;F9O6R=S8VAE;64G72`]/2`G:'1T<',G*2![#0H@("`@("`@("`@
M("`@("`@)'!O<G0@/2`T-#,[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("1P;W)T(#T@.#`[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@268@*&ES<V5T*"1P<F]X>5LG:&]S="==*2D@>PT*
M("`@("`@("`@("`@)')E<75E<W0@/2`B1T54("1U<FP@2%144"\Q+C%<<EQN
M(CL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1R97%U97-T(#T@
M(D=%5"`D<&%T:"!(5%10+S$N,5QR7&XB.PT*("`@("`@("!]#0H-"B`@("`@
M("`@)&EF;6]D:69I961S:6YC92`]("<G.PT*("`@("`@("!I9B`H:7-?87)R
M87DH)&QA<W1M;V1I9FEE9"DI('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D
M;&%S=&UO9&EF:65D6R=,87-T+4UO9&EF:65D)UTI*2![#0H@("`@("`@("`@
M("`@("`@)&EF;6]D:69I961S:6YC92`]("=)9BU-;V1I9FEE9"U3:6YC93H@
M)R`N("1L87-T;6]D:69I961;)TQA<W0M36]D:69I960G72`N(")<<EQN(CL-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D;&%S=&UO
M9&EF:65D6R=%5&%G)UTI*2![#0H@("`@("`@("`@("`@("`@)&EF;6]D:69I
M961S:6YC92`N/2`B268M3F]N92U-871C:#H@)&QA<W1M;V1I9FEE9%M%5&%G
M75QR7&XB.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@)&EF;6]D:69I961S:6YC92`]("@D;&%S=&UO9&EF:65D(#\@
M(DEF+4UO9&EF:65D+5-I;F-E.B`D;&%S=&UO9&EF:65D7')<;B(@.B`G)RD[
M#0H@("`@("`@('T-"B`@("`@("`@)')E<75E<W0@+CT@(DAO<W0Z("1H;W-T
M.B1P;W)T7')<;B(@+B`D:69M;V1I9FEE9'-I;F-E("X-"B`@("`@("`@("`@
M(")5<V5R+4%G96YT.B!014%2+S$N-"XY+U!(4"\B("X@4$A07U9%4E-)3TX@
M+B`B7')<;B([#0H@("`@("`@("1U<V5R;F%M92`]("1T:&ES+3YC;VYF:6<M
M/F=E="@G=7-E<FYA;64G*3L-"B`@("`@("`@)'!A<W-W;W)D(#T@)'1H:7,M
M/F-O;F9I9RT^9V5T*"=P87-S=V]R9"<I.PT*("`@("`@("!I9B`H)'5S97)N
M86UE("8F("1P87-S=V]R9"D@>PT*("`@("`@("`@("`@)'1M<"`](&)A<V4V
M-%]E;F-O9&4H(B1U<V5R;F%M93HD<&%S<W=O<F0B*3L-"B`@("`@("`@("`@
M("1R97%U97-T("X](")!=71H;W)I>F%T:6]N.B!"87-I8R`D=&UP7')<;B([
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"1P<F]X>5]H;W-T("$]("<G("8F
M("1P<F]X>5]U<V5R("$]("<G*2![#0H@("`@("`@("`@("`D<F5Q=65S="`N
M/2`G4')O>'DM075T:&]R:7IA=&EO;CH@0F%S:6,@)R`N#0H@("`@("`@("`@
M("`@("`@8F%S938T7V5N8V]D92@D<')O>'E?=7-E<B`N("<Z)R`N("1P<F]X
M>5]P87-S*2`N(")<<EQN(CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&%C
M8V5P="D@>PT*("`@("`@("`@("`@)')E<75E<W0@+CT@)T%C8V5P=#H@)R`N
M(&EM<&QO9&4H)RP@)RP@)&%C8V5P="D@+B`B7')<;B([#0H@("`@("`@('T-
M"B`@("`@("`@)')E<75E<W0@+CT@(D-O;FYE8W1I;VXZ(&-L;W-E7')<;B([
M#0H@("`@("`@("1R97%U97-T("X](")<<EQN(CL-"B`@("`@("`@:68@*"1P
M<F]X>5]H;W-T("$]("<G*2![#0H@("`@("`@("`@("`D9G`@/2!`9G-O8VMO
M<&5N*"1P<F]X>5]H;W-T+"`D<')O>'E?<&]R="P@)&5R<FYO+"`D97)R<W1R
M+"`Q-2D[#0H@("`@("`@("`@("!I9B`H(21F<"D@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#;VYN96-T:6]N('1O(&`D
M<')O>'E?:&]S=#HD<')O>'E?<&]R="<@9F%I;&5D.B`D97)R<W1R(BP-"B`@
M("`@("`@("`@("`@("`@("`@+3DR-S8I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=S
M8VAE;64G72D@)B8@)&EN9F];)W-C:&5M92==(#T]("=H='1P<R<I('L-"B`@
M("`@("`@("`@("`@("`D:&]S="`]("=S<VPZ+R\G("X@)&AO<W0[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D9G`@/2!`9G-O8VMO<&5N*"1H;W-T
M+"`D<&]R="P@)&5R<FYO+"`D97)R<W1R*3L-"B`@("`@("`@("`@(&EF("@A
M)&9P*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H(D-O;FYE8W1I;VX@=&\@8"1H;W-T.B1P;W)T)R!F86EL960Z("1E<G)S
M='(B+"`D97)R;F\I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(&9W<FET92@D9G`L("1R97%U97-T*3L-"B`@("`@("`@)&AE861E<G,@
M/2!A<G)A>2@I.PT*("`@("`@("!W:&EL92`H=')I;2@D;&EN92`](&9G971S
M*"1F<"P@,3`R-"DI*2![#0H@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G
M+UXH6UXZ72LI.EQS*R@N*BE<<RHD+R<L("1L:6YE+"`D;6%T8VAE<RDI('L-
M"B`@("`@("`@("`@("`@("`D:&5A9&5R<UMS=')T;VQO=V5R*"1M871C:&5S
M6S%=*5T@/2!T<FEM*"1M871C:&5S6S)=*3L-"B`@("`@("`@("`@('T@96QS
M96EF("AP<F5G7VUA=&-H*"=\7DA45%`O,2Y;,#%=("A;,"TY77LS?2D@?"<L
M("1L:6YE+"`D;6%T8VAE<RDI('L-"B`@("`@("`@("`@("`@("!I9B`H)&UA
M=&-H97-;,5T@/3T@,S`T("8F("@D;&%S=&UO9&EF:65D('Q\("@D;&%S=&UO
M9&EF:65D(#T]/2!F86QS92DI*2![#0H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@:68@*"1M871C:&5S6S%=("$](#(P,"D@>PT*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B1FEL92!H='1P.B\O)&AO
M<W0Z)'!O<G0D<&%T:"!N;W0@=F%L:60@*')E8V5I=F5D.B`D;&EN92DB+"`H
M:6YT*2`D;6%T8VAE<ULQ72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D:&5A9&5R
M<ULG8V]N=&5N="UL96YG=&@G72DI('L-"B`@("`@("`@("`@("1L96YG=&@@
M/2`D:&5A9&5R<ULG8V]N=&5N="UL96YG=&@G73L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1L96YG=&@@/2`M,3L-"B`@("`@("`@?0T*("`@
M("`@("`D9&%T82`]("<G.PT*("`@("`@("!W:&EL92`H)&-H=6YK(#T@0&9R
M96%D*"1F<"P@.#$Y,BDI('L-"B`@("`@("`@("`@("1D871A("X]("1C:'5N
M:SL-"B`@("`@("`@?0T*("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@
M:68@*"1L87-T;6]D:69I960@/3T](&9A;'-E('Q\("1L87-T;6]D:69I960I
M('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D:&5A9&5R<ULG971A9R==*2D@
M>PT*("`@("`@("`@("`@("`@("1L87-T;6]D:69I960@/2!A<G)A>2@G151A
M9R<@/3X@)&AE861E<G-;)V5T86<G72D[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!I9B`H:7-S970H)&AE861E<G-;)VQA<W0M;6]D:69I960G72DI
M('L-"B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)&QA<W1M;V1I9FEE
M9"DI('L-"B`@("`@("`@("`@("`@("`@("`@)&QA<W1M;V1I9FEE9%LG3&%S
M="U-;V1I9FEE9"==(#T@)&AE861E<G-;)VQA<W0M;6]D:69I960G73L-"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D
M;&%S=&UO9&EF:65D(#T@)&AE861E<G-;)VQA<W0M;6]D:69I960G73L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R
M971U<FX@87)R87DH)&1A=&$L("1L87-T;6]D:69I960L("1H96%D97)S*3L-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&1A=&$[#0H@("`@?0T*?0T*
M/SX-"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]014%2+U)U;E1E<W0N<&AP````````````````
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`S-#4V,``Q,#4Q-30S,S<T,0`P
M,C$T-38`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`-"B\J*@T*("H@4$5!4E]2=6Y497-T#0H@*@T*("H@4$A0('9E
M<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F
M:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E
M;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@
M<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL
M('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@
M<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@5&]M
M87,@5BY6+D-O>"`\8V]X0&ED96-N970N8V]M/@T*("H@0&%U=&AO<B`@("`@
M1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%)U;E1E<W0N<&AP+'8@,2XR
M,"`R,#`V+S`R+S`S(#`R.C`X.C$Q(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S
M:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XS+C,-
M"B`J+PT*#0HO*BH-"B`J(&9O<B!E<G)O<B!H86YD;&EN9PT*("HO#0IR97%U
M:7)E7V]N8V4@)U!%05(N<&AP)SL-"G)E<75I<F5?;VYC92`G4$5!4B]#;VYF
M:6<N<&AP)SL-"@T*9&5F:6YE*"=$151!24Q%1"<L(#$I.PT*<'5T96YV*")0
M2%!?4$5!4E]254Y415-44STQ(BD[#0H-"B\J*@T*("H@4VEM<&QI9FEE9"!V
M97)S:6]N(&]F(%!(4"=S('1E<W0@<W5I=&4-"B`J#0H@*B!4<GD@:70@=VET
M:#H-"B`J#0H@*B`D('!H<"`M<B`G:6YC;'5D92`B+BXO4$5!4B]2=6Y497-T
M+G!H<"([("1T/6YE=R!014%27U)U;E1E<W0[("1O/21T+3YR=6XH(BXO<&5A
M<E]S>7-T96TN<&AP="(I.W!R:6YT7W(H)&\I.R<-"B`J#0H@*@T*("H@0&-A
M=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO
M<B`@("`@5&]M87,@5BY6+D-O>"`\8V]X0&ED96-N970N8V]M/@T*("H@0&%U
M=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2
M#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S
M92`Q+C,N,PT*("HO#0IC;&%S<R!014%27U)U;E1E<W0-"GL-"B`@("!V87(@
M)%]L;V=G97([#0H@("`@=F%R("1?;W!T:6]N<SL-"@T*("`@("\J*@T*("`@
M("`J($%N(&]B:F5C="!T:&%T('-U<'!O<G1S('1H92!014%27T-O;6UO;BT^
M;&]G*"D@<VEG;F%T=7)E+"!O<B!N=6QL#0H@("`@("H@0'!A<F%M(%!%05)?
M0V]M;6]N?&YU;&P-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!014%27U)U;E1E
M<W0H)&QO9V=E<B`](&YU;&PL("1O<'1I;VYS(#T@87)R87DH*2D-"B`@("![
M#0H@("`@("`@(&EF("AI<U]N=6QL*"1L;V=G97(I*2![#0H@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)U!%05(O0V]M;6]N+G!H<"<[#0H@("`@("`@("`@
M("`D;&]G9V5R(#T@;F5W(%!%05)?0V]M;6]N.PT*("`@("`@("!]#0H@("`@
M("`@("1T:&ES+3Y?;&]G9V5R(#T@)&QO9V=E<CL-"B`@("`@("`@)'1H:7,M
M/E]O<'1I;VYS(#T@)&]P=&EO;G,[#0H@("`@?0T*#0H@("`@+R\-"B`@("`O
M+R`@4G5N(&%N(&EN9&EV:61U86P@=&5S="!C87-E+@T*("`@("\O#0H-"B`@
M("!F=6YC=&EO;B!R=6XH)&9I;&4L("1I;FE?<V5T=&EN9W,@/2`G)RD-"B`@
M("![#0H@("`@("`@("1C=V0@/2!G971C=V0H*3L-"B`@("`@("`@)&-O;F8@
M/2`F4$5!4E]#;VYF:6<Z.G-I;F=L971O;B@I.PT*("`@("`@("`D<&AP(#T@
M)&-O;F8M/F=E="@G<&AP7V)I;B<I.PT*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]O<'1I;VYS6R=P:'!U;FET)UTI*2![#0H@("`@("`@("`@("`D8VUD
M(#T@(B1P:'`D:6YI7W-E='1I;F=S("UF("1F:6QE(CL-"B`@("`@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7VQO9V=E<BDI('L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7VQO9V=E<BT^;&]G*#(L("=2=6YN:6YG(&-O;6UA;F0@(B<@
M+B`D8VUD("X@)R(G*3L-"B`@("`@("`@("`@('T-"B`@("`-"B`@("`@("`@
M("`@("1S879E9&ER(#T@9V5T8W=D*"D[("\O(&EN(&-A<V4@=&AE('1E<W0@
M;6]V97,@=7,@87)O=6YD#0H@("`@("`@("`@("!C:&1I<BAD:7)N86UE*"1F
M:6QE*2D[#0H@("`@("`@("`@("!E8VAO(&`D8VUD8#L-"B`@("`@("`@("`@
M(&-H9&ER*"1S879E9&ER*3L-"B`@("`@("`@("`@(')E='5R;B`G4$%34T5$
M)SL@+R\@=V4@:&%V92!N;R!W87D@;V8@:VYO=VEN9R!T:&ES(&EN9F]R;6%T
M:6]N('-O(&%S<W5M92!P87-S:6YG#0H@("`@("`@('T-"B`@("`@("`@+R]V
M87)?9'5M<"@D<&AP*3ME>&ET.PT*("`@("`@("!G;&]B86P@)&QO9U]F;W)M
M870L("1I;F9O7W!A<F%M<RP@)&EN:5]O=F5R=W)I=&5S.PT*#0H@("`@("`@
M("1I;F9O7W!A<F%M<R`]("<G.PT*("`@("`@("`D;&]G7V9O<FUA="`]("=,
M14]$)SL-"@T*("`@("`@("`O+R!,;V%D('1H92!S96-T:6]N<R!O9B!T:&4@
M=&5S="!F:6QE+@T*("`@("`@("`D<V5C=&EO;E]T97AT(#T@87)R87DH#0H@
M("`@("`@("`@("`G5$535"<@("`@/3X@)RAU;FYA;65D('1E<W0I)RP-"B`@
M("`@("`@("`@("=32TE0248G("`]/B`G)RP-"B`@("`@("`@("`@("='150G
M("`@("`]/B`G)RP-"B`@("`@("`@("`@("=!4D=3)R`@("`]/B`G)RP-"B`@
M("`@("`@("`@("=#3$5!3B<@("`]/B`G)RP-"B`@("`@("`@*3L-"@T*("`@
M("`@("`D9FEL92`](')E86QP871H*"1F:6QE*3L-"B`@("`@("`@:68@*"%I
M<U]F:6QE*"1F:6QE*2!\?"`A)&9P(#T@9F]P96XH)&9I;&4L(")R(BDI('L-
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#86YN;W0@
M;W!E;B!T97-T(&9I;&4Z("1F:6QE(BD[#0H@("`@("`@('T-"@T*("`@("`@
M("`D<V5C=&EO;B`]("<G.PT*("`@("`@("!W:&EL92`H(69E;V8H)&9P*2D@
M>PT*("`@("`@("`@("`@)&QI;F4@/2!F9V5T<R@D9G`I.PT*#0H@("`@("`@
M("`@("`O+R!-871C:"!T:&4@8F5G:6YN:6YG(&]F(&$@<V5C=&EO;BX-"B`@
M("`@("`@("`@(&EF("AE<F5G*"=>+2TH6T$M6ETK*2TM)RPD;&EN92PD<BDI
M('L-"B`@("`@("`@("`@("`@("`D<V5C=&EO;B`]("1R6S%=.PT*("`@("`@
M("`@("`@("`@("1S96-T:6]N7W1E>'1;)'-E8W1I;VY=(#T@)R<[#0H@("`@
M("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!](&5L<V5I9B`H
M96UP='DH)'-E8W1I;VXI*2![#0H@("`@("`@("`@("`@("`@9F-L;W-E*"1F
M<"D[#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M(DEN=F%L:60@<V5C=&EO;G,@9F]R;6%T<R!I;B!T97-T(&9I;&4Z("1F:6QE
M(BD[#0H)"0E]#0H-"B`@("`@("`@("`@("\O($%D9"!T;R!T:&4@<V5C=&EO
M;B!T97AT+@T*("`@("`@("`@("`@)'-E8W1I;VY?=&5X=%LD<V5C=&EO;ET@
M+CT@)&QI;F4[#0H@("`@("`@('T-"B`@("`@("`@9F-L;W-E*"1F<"D[#0H-
M"B`@("`@("`@)'-H;W)T;F%M92`]('-T<E]R97!L86-E*"1C=V0@+B!$25)%
M0U1/4EE?4T5005)!5$]2+"`G)RP@)&9I;&4I.PT*("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?;W!T:6]N<ULG<VEM<&QE)UTI*2![#0H@("`@("`@("`@
M("`D=&5S=&5D(#T@=')I;2@D<V5C=&EO;E]T97AT6R=415-4)UTI("X@(ELD
M<VAO<G1N86UE72([#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M=&5S=&5D(#T@=')I;2@D<V5C=&EO;E]T97AT6R=415-4)UTI("X@)R`G.PT*
M("`@("`@("!]#0H-"B`@("`@("`@)'1M<"`](')E86QP871H*&1I<FYA;64H
M)&9I;&4I*3L-"B`@("`@("`@)'1M<%]S:VEP:68@/2`D=&UP("X@=6YI<6ED
M*"<O<&AP="XG*3L-"B`@("`@("`@)'1M<%]F:6QE("`@/2!E<F5G7W)E<&QA
M8V4H)UPN<&AP="0G+"<N<&AP)RPD9FEL92D[#0H@("`@("`@("1T;7!?<&]S
M="`@(#T@)'1M<"`N('5N:7%I9"@G+W!H<'0N)RD[#0H-"B`@("`@("`@0'5N
M;&EN:R@D=&UP7W-K:7!I9BD[#0H@("`@("`@($!U;FQI;FLH)'1M<%]F:6QE
M*3L-"B`@("`@("`@0'5N;&EN:R@D=&UP7W!O<W0I.PT*#0H@("`@("`@("\O
M('5N;&EN:R!O;&0@=&5S="!R97-U;'1S#0H@("`@("`@($!U;FQI;FLH97)E
M9U]R97!L86-E*"=<+G!H<'0D)RPG+F1I9F8G+"1F:6QE*2D[#0H@("`@("`@
M($!U;FQI;FLH97)E9U]R97!L86-E*"=<+G!H<'0D)RPG+FQO9R<L)&9I;&4I
M*3L-"B`@("`@("`@0'5N;&EN:RAE<F5G7W)E<&QA8V4H)UPN<&AP="0G+"<N
M97AP)RPD9FEL92DI.PT*("`@("`@("!`=6YL:6YK*&5R96=?<F5P;&%C92@G
M7"YP:'!T)"<L)RYO=70G+"1F:6QE*2D[#0H-"B`@("`@("`@+R\@0VAE8VL@
M:68@=&5S="!S:&]U;&0@8F4@<VMI<'!E9"X-"B`@("`@("`@)&EN9F\@/2`G
M)SL-"B`@("`@("`@)'=A<FX@/2!F86QS93L-"B`@("`@("`@:68@*&%R<F%Y
M7VME>5]E>&ES=',H)U-+25!)1B<L("1S96-T:6]N7W1E>'0I*2![#0H@("`@
M("`@("`@("!I9B`H=')I;2@D<V5C=&EO;E]T97AT6R=32TE0248G72DI('L-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<V%V95]T97AT*"1T;7!?<VMI<&EF
M+"`D<V5C=&EO;E]T97AT6R=32TE0248G72D[#0H@("`@("`@("`@("`@("`@
M+R\D97AT<F$@/2!S=6)S='(H4$A07T]3+"`P+"`S*2`A/3T@(E=)3B(@/PT*
M("`@("`@("`@("`@("`@("\O("`@(")U;G-E="!215%515-47TU%5$A/1#LB
M.B`B(CL-"@T*("`@("`@("`@("`@("`@("\O)&]U='!U="`](&`D97AT<F$@
M)'!H<"`D:6YF;U]P87)A;7,@+68@)'1M<%]S:VEP:69@.PT*("`@("`@("`@
M("`@("`@("1O=71P=70@/2!@)'!H<"`D:6YF;U]P87)A;7,@+68@)'1M<%]S
M:VEP:69@.PT*("`@("`@("`@("`@("`@('5N;&EN:R@D=&UP7W-K:7!I9BD[
M#0H@("`@("`@("`@("`@("`@:68@*&5R96=I*")><VMI<"(L('1R:6TH)&]U
M='!U="DI*2![#0H@("`@("`@("`@("`@("`@("`@("1S:VEP<F5A<V]N(#T@
M(E-+25`@)'1E<W1E9"([#0H@("`@("`@("`@("`@("`@("`@("1R96%S;VX@
M/2`H97)E9VDH(EYS:VEP6ULZ<W!A8V4Z75TJ*"XK*5PD(BP@=')I;2@D;W5T
M<'5T*2DI(#\@97)E9VE?<F5P;&%C92@B7G-K:7!;6SIS<&%C93I=72HH+BLI
M7"0B+"`B7%PQ(BP@=')I;2@D;W5T<'5T*2D@.B!&04Q313L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1R96%S;VXI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1S:VEP<F5A<V]N("X]("(@*')E87-O;CH@)')E87-O;BDB.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=Q=6EE="==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L;V=G97(M/FQO9R@P+"`D<VMI
M<')E87-O;BD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1O;&1?<&AP*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)'!H<"`]("1O;&1?<&AP.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`G4TM)4%!%1"<[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AE<F5G
M:2@B7FEN9F\B+"!T<FEM*"1O=71P=70I*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D<F5A<V]N(#T@*&5R96<H(EYI;F9O6ULZ<W!A8V4Z75TJ*"XK*5PD
M(BP@=')I;2@D;W5T<'5T*2DI(#\@97)E9U]R97!L86-E*")>:6YF;UM;.G-P
M86-E.EU=*B@N*RE<)"(L(")<7#$B+"!T<FEM*"1O=71P=70I*2`Z($9!3%-%
M.PT*("`@("`@("`@("`@("`@("`@("!I9B`H)')E87-O;BD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&EN9F\@/2`B("AI;F9O.B`D<F5A<V]N*2([
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@:68@*&5R96=I*")>=V%R;B(L('1R:6TH)&]U='!U
M="DI*2![#0H@("`@("`@("`@("`@("`@("`@("1R96%S;VX@/2`H97)E9R@B
M7G=A<FY;6SIS<&%C93I=72HH+BLI7"0B+"!T<FEM*"1O=71P=70I*2D@/R!E
M<F5G7W)E<&QA8V4H(EYW87)N6ULZ<W!A8V4Z75TJ*"XK*5PD(BP@(EQ<,2(L
M('1R:6TH)&]U='!U="DI(#H@1D%,4T4[#0H@("`@("`@("`@("`@("`@("`@
M(&EF("@D<F5A<V]N*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=V%R
M;B`]('1R=64[("\J(&]N;'D@:68@=&AE<F4@:7,@82!R96%S;VX@*B\-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1I;F9O(#T@(B`H=V%R;CH@)')E87-O
M;BDB.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@+R\@5V4G
M=F4@<V%T:7-F:65D('1H92!P<F5C;VYD:71I;VYS("T@<G5N('1H92!T97-T
M(0T*("`@("`@("`D=&AI<RT^<V%V95]T97AT*"1T;7!?9FEL92PD<V5C=&EO
M;E]T97AT6R=&24Q%)UTI.PT*#0H@("`@("`@("1A<F=S(#T@)'-E8W1I;VY?
M=&5X=%LG05)'4R==(#\@)R`M+2`G+B1S96-T:6]N7W1E>'1;)T%21U,G72`Z
M("<G.PT*#0H@("`@("`@("1C;60@/2`B)'!H<"1I;FE?<V5T=&EN9W,@+68@
M)'1M<%]F:6QE)&%R9W,@,CXF,2([#0H@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7VQO9V=E<BDI('L-"B`@("`@("`@("`@("1T:&ES+3Y?;&]G9V5R+3YL
M;V<H,BP@)U)U;FYI;F<@8V]M;6%N9"`B)R`N("1C;60@+B`G(B<I.PT*("`@
M("`@("!]#0H-"B`@("`@("`@)'-A=F5D:7(@/2!G971C=V0H*3L@+R\@:6X@
M8V%S92!T:&4@=&5S="!M;W9E<R!U<R!A<F]U;F0-"B`@("`@("`@:68@*&ES
M<V5T*"1S96-T:6]N7W1E>'1;)U)%5%523E,G72DI('L-"B`@("`@("`@("`@
M(&]B7W-T87)T*"D[#0H@("`@("`@("`@("!S>7-T96TH)&-M9"P@)')E='5R
M;E]V86QU92D[#0H@("`@("`@("`@("`D;W5T(#T@;V)?9V5T7V-O;G1E;G1S
M*"D[#0H@("`@("`@("`@("!O8E]E;F1?8VQE86XH*3L-"B`@("`@("`@("`@
M($!U;FQI;FLH)'1M<%]P;W-T*3L-"B`@("`@("`@("`@("1S96-T:6]N7W1E
M>'1;)U)%5%523E,G72`]("AI;G0I('1R:6TH)'-E8W1I;VY?=&5X=%LG4D54
M55).4R==*3L-"B`@("`@("`@("`@("1R971U<FYF86EL(#T@*"1R971U<FY?
M=F%L=64@(3T@)'-E8W1I;VY?=&5X=%LG4D5455).4R==*3L-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("1O=70@/2!@)&-M9&`[#0H@("`@("`@
M("`@("`D<F5T=7)N9F%I;"`](&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@
M(&-H9&ER*"1S879E9&ER*3L-"@T*("`@("`@("!I9B`H)'-E8W1I;VY?=&5X
M=%LG0TQ%04XG72D@>PT*("`@("`@("`@("`@+R\@<&5R9F]R;2!T97-T(&-L
M96%N=7`-"B`@("`@("`@("`@("1T:&ES+3YS879E7W1E>'0H)&-L96%N(#T@
M)'1M<"`N('5N:7%I9"@G+W!H<'0N)RDL("1S96-T:6]N7W1E>'1;)T-,14%.
M)UTI.PT*("`@("`@("`@("`@8"1P:'`@)&-L96%N8#L-"B`@("`@("`@("`@
M($!U;FQI;FLH)&-L96%N*3L-"B`@("`@("`@?0T*("`@("`@("`O+R!$;V5S
M('1H92!O=71P=70@;6%T8V@@=VAA="!I<R!E>'!E8W1E9#\-"B`@("`@("`@
M)&]U='!U="`]('1R:6TH)&]U="D[#0H@("`@("`@("1O=71P=70@/2!P<F5G
M7W)E<&QA8V4H)R]<<EQN+R<L(")<;B(L("1O=71P=70I.PT*#0H@("`@("`@
M(&EF("AI<W-E="@D<V5C=&EO;E]T97AT6R=%6%!%0U1&)UTI('Q\(&ES<V5T
M*"1S96-T:6]N7W1E>'1;)T584$5#5%)%1T58)UTI*2![#0H@("`@("`@("`@
M("!I9B`H:7-S970H)'-E8W1I;VY?=&5X=%LG15A014-41B==*2D@>PT*("`@
M("`@("`@("`@("`@("1W86YT960@/2!T<FEM*"1S96-T:6]N7W1E>'1;)T58
M4$5#5$8G72D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("1W86YT960@/2!T<FEM*"1S96-T:6]N7W1E>'1;)T584$5#5%)%1T58
M)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'=A;G1E9%]R92`]
M('!R96=?<F5P;&%C92@G+UQR7&XO)RPB7&XB+"1W86YT960I.PT*("`@("`@
M("`@("`@:68@*&ES<V5T*"1S96-T:6]N7W1E>'1;)T584$5#5$8G72DI('L-
M"B`@("`@("`@("`@("`@("`D=V%N=&5D7W)E(#T@<')E9U]Q=6]T92@D=V%N
M=&5D7W)E+"`G+R<I.PT*("`@("`@("`@("`@("`@("\O(%-T:6-K('1O(&)A
M<VEC<PT*("`@("`@("`@("`@("`@("1W86YT961?<F4@/2!S=')?<F5P;&%C
M92@B)7,B+"`B+BL_(BP@)'=A;G1E9%]R92D[("\O;F]T(&=R965D>0T*("`@
M("`@("`@("`@("`@("1W86YT961?<F4@/2!S=')?<F5P;&%C92@B)6DB+"`B
M6RM<+5T_6S`M.5TK(BP@)'=A;G1E9%]R92D[#0H@("`@("`@("`@("`@("`@
M)'=A;G1E9%]R92`]('-T<E]R97!L86-E*"(E9"(L(");,"TY72LB+"`D=V%N
M=&5D7W)E*3L-"B`@("`@("`@("`@("`@("`D=V%N=&5D7W)E(#T@<W1R7W)E
M<&QA8V4H(B5X(BP@(ELP+3EA+69!+49=*R(L("1W86YT961?<F4I.PT*("`@
M("`@("`@("`@("`@("1W86YT961?<F4@/2!S=')?<F5P;&%C92@B)68B+"`B
M6RM<+5T_7"X_6S`M.5TK7"X_6S`M.5TJ*$4M/ULP+3E=*RD_(BP@)'=A;G1E
M9%]R92D[#0H@("`@("`@("`@("`@("`@)'=A;G1E9%]R92`]('-T<E]R97!L
M86-E*"(E8R(L("(N(BP@)'=A;G1E9%]R92D[#0H@("`@("`@("`@("`@("`@
M+R\@)68@86QL;W=S('1W;R!P;VEN=',@(BTN,"XP(B!B=70@=&AA="!I<R!T
M:&4@8F5S="`J<VEM<&QE*B!E>'!R97-S:6]N#0H@("`@("`@("`@("!]#0H@
M("`@+RH@1$5"54<@64]54B!214=%6"!(15)%#0H@("`@("`@("`@("!V87)?
M9'5M<"@D=V%N=&5D7W)E*3L-"B`@("`@("`@("`@('!R:6YT*'-T<E]R97!E
M870H)STG+"`X,"D@+B`B7&XB*3L-"B`@("`@("`@("`@('9A<E]D=6UP*"1O
M=71P=70I.PT*("`@("HO#0H@("`@("`@("`@("!I9B`H(21R971U<FYF86EL
M("8F('!R96=?;6%T8V@H(B]>)'=A;G1E9%]R95PD+W,B+"`D;W5T<'5T*2D@
M>PT*("`@("`@("`@("`@("`@($!U;FQI;FLH)'1M<%]F:6QE*3L-"B`@("`@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG<75I970G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L;V=G97(M/FQO
M9R@P+"`B4$%34R`D=&5S=&5D)&EN9F\B*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1O;&1?<&AP*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D<&AP(#T@)&]L9%]P:'`[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B`G4$%34T5$)SL-"B`@
M("`@("`@("`@('T-"@T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M)'=A;G1E9"`]('1R:6TH)'-E8W1I;VY?=&5X=%LG15A014-4)UTI.PT*("`@
M("`@("`@("`@)'=A;G1E9"`]('!R96=?<F5P;&%C92@G+UQR7&XO)RPB7&XB
M+"1W86YT960I.PT*("`@("`@("`O+R!C;VUP87)E(&%N9"!L96%V92!O;B!S
M=6-C97-S#0H@("`@("`@("`@("`D;VL@/2`H,"`]/2!S=')C;7`H)&]U='!U
M="PD=V%N=&5D*2D[#0H@("`@("`@("`@("!I9B`H(21R971U<FYF86EL("8F
M("1O:RD@>PT*("`@("`@("`@("`@("`@($!U;FQI;FLH)'1M<%]F:6QE*3L-
M"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG
M<75I970G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L;V=G
M97(M/FQO9R@P+"`B4$%34R`D=&5S=&5D)&EN9F\B*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1O;&1?<&AP*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`D<&AP(#T@)&]L9%]P:'`[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B`G4$%34T5$
M)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@("\O(%1E
M<W0@9F%I;&5D('-O('=E(&YE960@=&\@<F5P;W)T(&1E=&%I;',N#0H@("`@
M("`@(&EF("@D=V%R;BD@>PT*("`@("`@("`@("`@)'1H:7,M/E]L;V=G97(M
M/FQO9R@P+"`B5T%23B`D=&5S=&5D)&EN9F\B*3L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1T:&ES+3Y?;&]G9V5R+3YL;V<H,"P@(D9!24P@
M)'1E<W1E9"1I;F9O(BD[#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H:7-S
M970H)'-E8W1I;VY?=&5X=%LG4D5455).4R==*2D@>PT*("`@("`@("`@("`@
M)$=,3T)!3%-;)U]?4$A07T9!24Q%1%]415-44U]?)UU;72`](&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B`D9FEL92P-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&5S=%]N86UE)R`]/B`D
M=&5S=&5D+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=O=71P=70G
M(#T^(&5R96=?<F5P;&%C92@G7"YP:'!T)"<L)RYL;V<G+"`D9FEL92DL#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1I9F8G("`@/3X@97)E9U]R
M97!L86-E*"=<+G!H<'0D)RPG+F1I9F8G+"`D9FEL92DL#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VEN9F\G("`@/3X@)&EN9F\L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W)E='5R;B<@/3X@)')E='5R;E]V86QU
M90T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`D1TQ/0D%,4ULG7U]02%!?1D%)3$5$7U1%
M4U137U\G75M=(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VYA;64G(#T^("1F:6QE+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=T97-T7VYA;64G(#T^("1T97-T960L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V]U='!U="<@/3X@97)E9U]R97!L86-E*"=<+G!H<'0D
M)RPG+FQO9R<L("1F:6QE*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G9&EF9B<@("`]/B!E<F5G7W)E<&QA8V4H)UPN<&AP="0G+"<N9&EF9B<L
M("1F:6QE*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:6YF;R<@
M("`]/B`D:6YF;RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PT*
M("`@("`@("!]#0H-"B`@("`@("`@+R\@=W)I=&4@+F5X<`T*("`@("`@("!I
M9B`H<W1R<&]S*"1L;V=?9F]R;6%T+"=%)RD@(3T]($9!3%-%*2![#0H@("`@
M("`@("`@("`D;&]G;F%M92`](&5R96=?<F5P;&%C92@G7"YP:'!T)"<L)RYE
M>'`G+"1F:6QE*3L-"B`@("`@("`@("`@(&EF("@A)&QO9R`](&9O<&5N*"1L
M;V=N86UE+"=W)RDI('L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@B0V%N;F]T(&-R96%T92!T97-T(&QO9R`M("1L;V=N86UE
M(BD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F=W)I=&4H)&QO9RPD
M=V%N=&5D*3L-"B`@("`@("`@("`@(&9C;&]S92@D;&]G*3L-"B`@("`@("`@
M?0T*#0H@("`@("`@("\O('=R:71E("YO=70-"B`@("`@("`@:68@*'-T<G!O
M<R@D;&]G7V9O<FUA="PG3R<I("$]/2!&04Q312D@>PT*("`@("`@("`@("`@
M)&QO9VYA;64@/2!E<F5G7W)E<&QA8V4H)UPN<&AP="0G+"<N;W5T)RPD9FEL
M92D[#0H@("`@("`@("`@("!I9B`H(21L;V<@/2!F;W!E;B@D;&]G;F%M92PG
M=R<I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H(D-A;FYO="!C<F5A=&4@=&5S="!L;V<@+2`D;&]G;F%M92(I.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@9G=R:71E*"1L;V<L)&]U='!U="D[
M#0H@("`@("`@("`@("!F8VQO<V4H)&QO9RD[#0H@("`@("`@('T-"@T*("`@
M("`@("`O+R!W<FET92`N9&EF9@T*("`@("`@("!I9B`H<W1R<&]S*"1L;V=?
M9F]R;6%T+"=$)RD@(3T]($9!3%-%*2![#0H@("`@("`@("`@("`D;&]G;F%M
M92`](&5R96=?<F5P;&%C92@G7"YP:'!T)"<L)RYD:69F)RPD9FEL92D[#0H@
M("`@("`@("`@("!I9B`H(21L;V<@/2!F;W!E;B@D;&]G;F%M92PG=R<I*2![
M#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-A
M;FYO="!C<F5A=&4@=&5S="!L;V<@+2`D;&]G;F%M92(I.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@9G=R:71E*"1L;V<L("1T:&ES+3YG96YE<F%T
M95]D:69F*"1W86YT960L("1O=71P=70L#0H@("`@("`@("`@("`@("`@:7-S
M970H)'-E8W1I;VY?=&5X=%LG4D5455).4R==*2`_(&%R<F%Y*'1R:6TH)'-E
M8W1I;VY?=&5X=%LG4D5455).4R==*2P-"B`@("`@("`@("`@("`@("`@("`@
M)')E='5R;E]V86QU92D@.B!N=6QL*2D[#0H@("`@("`@("`@("!F8VQO<V4H
M)&QO9RD[#0H@("`@("`@('T-"@T*("`@("`@("`O+R!W<FET92`N;&]G#0H@
M("`@("`@(&EF("AS=')P;W,H)&QO9U]F;W)M870L)TPG*2`A/3T@1D%,4T4I
M('L-"B`@("`@("`@("`@("1L;V=N86UE(#T@97)E9U]R97!L86-E*"=<+G!H
M<'0D)RPG+FQO9R<L)&9I;&4I.PT*("`@("`@("`@("`@:68@*"$D;&]G(#T@
M9F]P96XH)&QO9VYA;64L)W<G*2D@>PT*("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*")#86YN;W0@8W)E871E('1E<W0@;&]G("T@
M)&QO9VYA;64B*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9W<FET
M92@D;&]G+"(-"BTM+2T@15A014-4140@3U544%54#0HD=V%N=&5D#0HM+2TM
M($%#5%5!3"!/5510550-"B1O=71P=70-"BTM+2T@1D%)3$5$#0HB*3L-"B`@
M("`@("`@("`@(&EF("@D<F5T=7)N9F%I;"D@>PT*("`@("`@("`@("`@("`@
M(&9W<FET92@D;&]G+"(-"BTM+2T@15A014-4140@4D5455).#0HD<V5C=&EO
M;E]T97AT6U)%5%523E-=#0HM+2TM($%#5%5!3"!215154DX-"B1R971U<FY?
M=F%L=64-"B(I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F-L;W-E
M*"1L;V<I.PT*("`@("`@("`@("`@+R]E<G)O<E]R97!O<G0H)&9I;&4L)&QO
M9VYA;64L)'1E<W1E9"D[#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H:7-S
M970H)&]L9%]P:'`I*2![#0H@("`@("`@("`@("`D<&AP(#T@)&]L9%]P:'`[
M#0H@("`@("`@('T-"@T*("`@("`@("!R971U<FX@)'=A<FX@/R`G5T%23D5$
M)R`Z("=&04E,140G.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E;F5R871E
M7V1I9F8H)'=A;G1E9"P@)&]U='!U="P@)')E='5R;E]V86QU92D-"B`@("![
M#0H@("`@("`@("1W(#T@97AP;&]D92@B7&XB+"`D=V%N=&5D*3L-"B`@("`@
M("`@)&\@/2!E>'!L;V1E*")<;B(L("1O=71P=70I.PT*("`@("`@("`D=S$@
M/2!A<G)A>5]D:69F7V%S<V]C*"1W+"1O*3L-"B`@("`@("`@)&\Q(#T@87)R
M87E?9&EF9E]A<W-O8R@D;RPD=RD[#0H@("`@("`@("1W,B`](&%R<F%Y*"D[
M#0H@("`@("`@("1O,B`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@H)'<Q
M(&%S("1I9'@@/3X@)'9A;"D@)'<R6W-P<FEN=&8H(B4P,V0\(BPD:61X*5T@
M/2!S<')I;G1F*"(E,#-D+2`B+"`D:61X*S$I+B1V86P[#0H@("`@("`@(&9O
M<F5A8V@H)&\Q(&%S("1I9'@@/3X@)'9A;"D@)&\R6W-P<FEN=&8H(B4P,V0^
M(BPD:61X*5T@/2!S<')I;G1F*"(E,#-D*R`B+"`D:61X*S$I+B1V86P[#0H@
M("`@("`@("1D:69F(#T@87)R87E?;65R9V4H)'<R+"`D;S(I.PT*("`@("`@
M("!K<V]R="@D9&EF9BD[#0H@("`@("`@(&EF("@D<F5T=7)N7W9A;'5E*2![
M#0H@("`@("`@("`@("`D97AT<F$@/2`B(R-%6%!%0U1%1#H@)')E='5R;E]V
M86QU95LP75QR7&XC(U)%5%523D5$.B`D<F5T=7)N7W9A;'5E6S%=(CL-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1E>'1R82`]("<G.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B!I;7!L;V1E*")<<EQN(BP@)&1I9F8I
M("X@)&5X=')A.PT*("`@('T-"@T*("`@("\O#0H@("`@+R\@(%=R:71E('1H
M92!G:79E;B!T97AT('1O(&$@=&5M<&]R87)Y(&9I;&4L(&%N9"!R971U<FX@
M=&AE(&9I;&5N86UE+@T*("`@("\O#0H-"B`@("!F=6YC=&EO;B!S879E7W1E
M>'0H)&9I;&5N86UE+"`D=&5X="D-"B`@("![#0H@("`@("`@(&EF("@A)&9P
M(#T@9F]P96XH)&9I;&5N86UE+"`G=R<I*2![#0H@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@B0V%N;F]T(&]P96X@9FEL92`G(B`N("1F
M:6QE;F%M92`N("(G("AS879E7W1E>'0I(BD[#0H@("`@("`@('T-"B`@("`@
M("`@9G=R:71E*"1F<"PD=&5X="D[#0H@("`@("`@(&9C;&]S92@D9G`I.PT*
M("`@(&EF("@Q(#P@1$5404E,140I(&5C:&\@(@T*1DE,12`D9FEL96YA;64@
M>WM[#0HD=&5X=`T*?7U]#0HB.PT*("`@('T-"@T*?0T*/SX-"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U1A<VLO````
M````````````````````````````````````````````````````````````
M```````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#4Q-30S,S<T,``P,C`R,S(`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+U!%05(O5&%S:R]#;VUM;VXN<&AP````````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#$U,#$Q`#$P-3$U-#,S-S0P`#`R,C$W,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`T*+RHJ
M#0H@*B!014%27U1A<VM?0V]M;6]N+"!B87-E(&-L87-S(&9O<B!I;G-T86QL
M97(@=&%S:W,-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J
M($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S
M:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA
M8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I
M;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@
M4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E
M0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!0
M14%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN
M970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)
M9#H@0V]M;6]N+G!H<"QV(#$N,34@,C`P-B\P,2\P-B`P-#HT-SHS-R!C96QL
M;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S
M:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*+RHJ(T`K#0H@*B!%<G)O<B!C
M;V1E<R!F;W(@=&%S:R!V86QI9&%T:6]N(')O=71I;F5S#0H@*B\-"F1E9FEN
M92@G4$5!4E]405-+7T524D]27TY/05144DE"4R<L(#$I.PT*9&5F:6YE*"=0
M14%27U1!4TM?15)23U)?34E34TE.1U]!5%1224(G+"`R*3L-"F1E9FEN92@G
M4$5!4E]405-+7T524D]27U=23TY'7T%45%))0E]604Q512<L(#,I.PT*9&5F
M:6YE*"=014%27U1!4TM?15)23U)?24Y604Q)1"<L(#0I.PT*+RHJ(T`M*B\-
M"F1E9FEN92@G4$5!4E]405-+7U!!0TM!1T4G+"`Q*3L-"F1E9FEN92@G4$5!
M4E]405-+7TE.4U1!3$PG+"`R*3L-"F1E9FEN92@G4$5!4E]405-+7U!!0TM!
M1T5!3D1)3E-404Q,)RP@,RD[#0HO*BH-"B`J($$@=&%S:R!I<R!A;B!O<&5R
M871I;VX@=&AA="!M86YI<'5L871E<R!T:&4@8V]N=&5N=',@;V8@82!F:6QE
M+@T*("H-"B`J(%-I;7!L92!T87-K<R!O<&5R871E(&]N(#$@9FEL92X@($UU
M;'1I<&QE('1A<VMS(&%R92!E>&5C=71E9"!A9G1E<B!A;&P@9FEL97,@:&%V
M92!B965N#0H@*B!P<F]C97-S960@86YD(&EN<W1A;&QE9"P@86YD(&%R92!D
M97-I9VYE9"!T;R!O<&5R871E(&]N(&%L;"!F:6QE<R!C;VYT86EN:6YG('1H
M92!T87-K+@T*("H@5&AE(%!O<W0M:6YS=&%L;"!S8W)I<'0@=&%S:R!S:6UP
M;'D@=&%K97,@861V86YT86=E(&]F('1H92!F86-T('1H870@:70@=VEL;"!B
M92!R=6X-"B`J(&%F=&5R(&EN<W1A;&QA=&EO;BP@<F5P;&%C92!I<R!A('-I
M;7!L92!T87-K+@T*("H-"B`J($-O;6)I;FEN9R!T87-K<R!I<R!P;W-S:6)L
M92P@8G5T(&]R9&5R:6YG(&ES('-I9VYI9FEC86YT+@T*("H-"B`J(#QF:6QE
M(&YA;64](G1E<W0N<&AP(B!R;VQE/2)P:'`B/@T*("H@(#QT87-K<SIR97!L
M86-E(&9R;VT](D!D871A+61I<D`B('1O/2)D871A7V1I<B(@='EP93TB<&5A
M<BUC;VYF:6<B+SX-"B`J("`\=&%S:W,Z<&]S=&EN<W1A;&QS8W)I<'0O/@T*
M("H@/"]F:6QE/@T*("H-"B`J(%1H:7,@=VEL;"!F:7)S="!R97!L86-E(&%N
M>2!I;G-T86YC92!O9B!`9&%T82UD:7)`(&EN('1H92!T97-T+G!H<"!F:6QE
M#0H@*B!W:71H('1H92!P871H('1O('1H92!C=7)R96YT(&1A=&$@9&ER96-T
M;W)Y+B`@5&AE;BP@:70@=VEL;"!I;F-L=61E('1H90T*("H@=&5S="YP:'`@
M9FEL92!A;F0@<G5N('1H92!S8W)I<'0@:70@8V]N=&%I;G,@=&\@8V]N9FEG
M=7)E('1H92!P86-K86=E('!O<W0M:6YS=&%L;&%T:6]N+@T*("H@0&-A=&5G
M;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@
M("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H
M="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E
M(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK
M("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`
M<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N
M,&$Q#0H@*B!`86)S=')A8W0-"B`J+PT*8VQA<W,@4$5!4E]487-K7T-O;6UO
M;@T*>PT*("`@("\J*@T*("`@("`J(%9A;&ED('1Y<&5S(&9O<B!T:&ES('9E
M<G-I;VX@87)E("=S:6UP;&4G(&%N9"`G;75L=&EP;&4G#0H@("`@("H-"B`@
M("`@*B`M('-I;7!L92!T87-K<R!O<&5R871E(&]N('1H92!C;VYT96YT<R!O
M9B!A(&9I;&4@86YD('=R:71E(&]U="!C:&%N9V5S('1O(&1I<VL-"B`@("`@
M*B`M(&UU;'1I<&QE('1A<VMS(&]P97)A=&4@;VX@=&AE(&-O;G1E;G1S(&]F
M(&UA;GD@9FEL97,@86YD('=R:71E(&]U="!T:&4-"B`@("`@*B`@(&-H86YG
M97,@9&ER96-T;'D@=&\@9&ES:PT*("`@("`J#0H@("`@("H@0VAI;&0@=&%S
M:R!C;&%S<V5S(&UU<W0@;W9E<G)I9&4@=&AI<R!P<F]P97)T>2X-"B`@("`@
M*B!`86-C97-S('!R;W1E8W1E9`T*("`@("`J+PT*("`@('9A<B`D='EP92`]
M("=S:6UP;&4G.PT*("`@("\J*@T*("`@("`J($1E=&5R;6EN97,@=VAI8V@@
M:6YS=&%L;"!P:&%S92!T:&ES('1A<VL@:7,@97AE8W5T960@=6YD97(-"B`@
M("`@*B\-"B`@("!V87(@)'!H87-E(#T@4$5!4E]405-+7TE.4U1!3$P[#0H@
M("`@+RHJ#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-"B`@("`@*B\-"B`@
M("!V87(@)&-O;F9I9SL-"B`@("`O*BH-"B`@("`@*B!`86-C97-S('!R;W1E
M8W1E9`T*("`@("`J+PT*("`@('9A<B`D<F5G:7-T<GD[#0H@("`@+RHJ#0H@
M("`@("H@0&%C8V5S<R!P<F]T96-T960-"B`@("`@*B\-"B`@("!V87(@)&QO
M9V=E<CL-"B`@("`O*BH-"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`T*("`@
M("`J+PT*("`@('9A<B`D:6YS=&%L;'!H87-E.PT*("`@("\J*@T*("`@("`J
M($!P87)A;2!014%27T-O;F9I9PT*("`@("`J($!P87)A;2!014%27T-O;6UO
M;@T*("`@("`J+PT*("`@(&9U;F-T:6]N(%!%05)?5&%S:U]#;VUM;VXH)B1C
M;VYF:6<L("8D;&]G9V5R+"`D<&AA<V4I#0H@("`@>PT*("`@("`@("`D=&AI
M<RT^8V]N9FEG(#T@)B1C;VYF:6<[#0H@("`@("`@("1T:&ES+3YR96=I<W1R
M>2`]("8D8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("`D=&AI<RT^
M;&]G9V5R(#T@)B1L;V=G97([#0H@("`@("`@("1T:&ES+3YI;G-T86QL<&AA
M<V4@/2`D<&AA<V4[#0H@("`@("`@(&EF("@D=&AI<RT^='EP92`]/2`G;75L
M=&EP;&4G*2![#0H@("`@("`@("`@("`D1TQ/0D%,4ULG7U!%05)?5$%32U]0
M3U-424Y35$%.0T53)UU;9V5T7V-L87-S*"1T:&ES*5U;72`]("8D=&AI<SL-
M"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J(%9A;&ED871E
M('1H92!B87-I8R!C;VYT96YT<R!O9B!A('1A<VL@=&%G+@T*("`@("`J($!P
M87)A;2!014%27U!A8VMA9V5&:6QE7W8R#0H@("`@("H@0'!A<F%M(&%R<F%Y
M#0H@("`@("H@0'!A<F%M(%!%05)?0V]N9FEG#0H@("`@("H@0'!A<F%M(&%R
M<F%Y('1H92!E;G1I<F4@<&%R<V5D(#QF:6QE/B!T86<-"B`@("`@*B!`<F5T
M=7)N('1R=65\87)R87D@3VX@97)R;W(L(')E='5R;B!A;B!A<G)A>2!I;B!F
M;W)M870Z#0H@("`@("H@("`@87)R87DH4$5!4E]405-+7T524D]27S\_/ULL
M('!A<F%M,5U;+"!P87)A;3)=6RP@+BXN72D-"B`@("`@*@T*("`@("`J("`@
M($9O<B!014%27U1!4TM?15)23U)?34E34TE.1U]!5%1224(L('!A<W,@=&AE
M(&%T=')I8G5T92!N86UE(&EN#0H@("`@("H@("`@1F]R(%!%05)?5$%32U]%
M4E)/4E]74D].1U]!5%1224)?5D%,544L('!A<W,@=&AE(&%T=')I8G5T92!N
M86UE(&%N9"!A;B!A<G)A>0T*("`@("`J("`@(&]F(&QE9V%L('9A;'5E<R!I
M;@T*("`@("`J($!S=&%T:6,-"B`@("`@*B!`86)S=')A8W0-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!V86QI9%AM;"@D<&MG+"`D>&UL+"`F)&-O;F9I9RP@
M)&9I;&58;6PI#0H@("`@>PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($EN
M:71I86QI>F4@82!T87-K(&EN<W1A;F-E('=I=&@@=&AE('!A<F%M971E<G,-
M"B`@("`@*B!`<&%R86T@87)R87D@<F%W+"!P87)S960@>&UL#0H@("`@("H@
M0'!A<F%M(&%R<F%Y(&%T=')I8G5T97,@9G)O;2!T:&4@/&9I;&4^('1A9R!C
M;VYT86EN:6YG('1H:7,@=&%S:PT*("`@("`J($!P87)A;2!S=')I;F=\;G5L
M;"!L87-T(&EN<W1A;&QE9"!V97)S:6]N(&]F('1H:7,@<&%C:V%G90T*("`@
M("`J($!A8G-T<F%C=`T*("`@("`J+PT*("`@(&9U;F-T:6]N(&EN:70H)'AM
M;"P@)&9I;&5!='1R:6)U=&5S+"`D;&%S=%9E<G-I;VXI#0H@("`@>PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J($)E9VEN(&$@=&%S:R!P<F]C97-S:6YG
M('-E<W-I;VXN("!!;&P@;75L=&EP;&4@=&%S:W,@=VEL;"!B92!P<F]C97-S
M960@869T97(@96%C:"!F:6QE#0H@("`@("H@:&%S(&)E96X@<W5C8V5S<V9U
M;&QY(&EN<W1A;&QE9"P@86QL('-I;7!L92!T87-K<R!S:&]U;&0@<&5R9F]R
M;2!T:&5I<B!T87-K(&AE<F4@86YD#0H@("`@("H@<F5T=7)N(&%N>2!E<G)O
M<G,@=7-I;F<@=&AE(&-U<W1O;2!T:')O=T5R<F]R*"D@;65T:&]D('1O(&%L
M;&]W(&9O<G=A<F0@8V]M<&%T:6)I;&ET>0T*("`@("`J#0H@("`@("H@5&AI
M<R!M971H;V0@35535"!.3U0@=W)I=&4@;W5T(&%N>2!C:&%N9V5S('1O(&1I
M<VL-"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V,@T*("`@("`J
M($!P87)A;2!S=')I;F<@9FEL92!C;VYT96YT<PT*("`@("`J($!P87)A;2!S
M=')I;F<@=&AE(&5V96YT=6%L(&9I;F%L(&9I;&4@;&]C871I;VX@*&EN9F]R
M;6%T:6]N86P@;VYL>2D-"B`@("`@*B!`<F5T=7)N('-T<FEN9WQF86QS97Q0
M14%27T5R<F]R(&9A;'-E('1O('-K:7`@=&AI<R!F:6QE+"!014%27T5R<F]R
M('1O(&9A:6P-"B`@("`@*B`@("`@("`@("AU<V4@)'1H:7,M/G1H<F]W17)R
M;W(I+"!O=&AE<G=I<V4@<F5T=7)N('1H92!N97<@8V]N=&5N=',-"B`@("`@
M*B!`86)S=')A8W0-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S=&%R=%-E<W-I
M;VXH)'!K9RP@)&-O;G1E;G1S+"`D9&5S="D-"B`@("![#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@5&AI<R!M971H;V0@:7,@=7-E9"!T;R!P<F]C97-S
M(&5A8V@@;V8@=&AE('1A<VMS(&9O<B!A('!A<G1I8W5L87(@;75L=&EP;&4@
M8VQA<W,-"B`@("`@*B!T>7!E+B`@4VEM<&QE('1A<VMS(&YE960@;F]T(&EM
M<&QE;65N="!T:&ES(&UE=&AO9"X-"B`@("`@*B!`<&%R86T@87)R87D@86X@
M87)R87D@;V8@=&%S:W,-"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`T*("`@
M("`J($!S=&%T:6,-"B`@("`@*B!`86)S=')A8W0-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!R=6XH)'1A<VMS*0T*("`@('L-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!`<W1A=&EC#0H@("`@("H@0&9I;F%L#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@:&%S4&]S=&EN<W1A;&Q487-K<R@I#0H@("`@>PT*("`@("`@
M("!R971U<FX@:7-S970H)$=,3T)!3%-;)U]014%27U1!4TM?4$]35$E.4U1!
M3D-%4R==*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<W1A=&EC#0H@
M("`@("H@0&9I;F%L#0H@("`@("HO#0H@("`@(&9U;F-T:6]N(')U;E!O<W1I
M;G-T86QL5&%S:W,H*0T*("`@("![#0H@("`@("`@("!F;W)E86-H("@D1TQ/
M0D%,4ULG7U!%05)?5$%32U]03U-424Y35$%.0T53)UT@87,@)&-L87-S(#T^
M("1T87-K<RD@>PT*("`@("`@("`@("`@("1E<G(@/2!C86QL7W5S97)?9G5N
M8RAA<G)A>2@D8VQA<W,L("=R=6XG*2P-"B`@("`@("`@("`@("`@("`@("1'
M3$]"04Q36R=?4$5!4E]405-+7U!/4U1)3E-404Y#15,G75LD8VQA<W-=*3L-
M"B`@("`@("`@("`@("!I9B`H)&5R<BD@>PT*("`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4E]487-K7T-O;6UO;CHZ=&AR;W=%<G)O<B@D97)R*3L-"B`@
M("`@("`@("`@("!]#0H@("`@("`@("!]#0H@("`@("`@("!U;G-E="@D1TQ/
M0D%,4ULG7U!%05)?5$%32U]03U-424Y35$%.0T53)UTI.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("`J($1E=&5R;6EN97,@=VAE=&AE<B!A(')O;&4@:7,@
M82!S8W)I<'0-"B`@("`@*B!`<F5T=7)N(&)O;VP-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!I<U-C<FEP="@I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H
M:7,M/G1Y<&4@/3T@)W-C<FEP="<[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M=&AR;W=%<G)O<B@D;7-G+"`D8V]D92`]("TQ*0T*("`@('L-"B`@("`@("`@
M:6YC;'5D95]O;F-E("=014%2+G!H<"<[#0H@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"1M<V<L("1C;V1E*3L-"B`@("!]#0I]#0H_/@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O5&%S:R]0
M;W-T:6YS=&%L;'-C<FEP="\`````````````````````````````````````
M`````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-3$U-#,S-S0P`#`R,S<W,P`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O4$5!4B]487-K+U!O<W1I;G-T86QL<V-R:7!T+W)W+G!H<```````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,30S-34`,3`U,34T,S,W-#``,#(U,30T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP#0HO
M*BH-"B`J(#QT87-K<SIP;W-T:6YS=&%L;'-C<FEP=#X@+2!R96%D+W=R:71E
M('9E<G-I;VX-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J
M($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S
M:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA
M8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I
M;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@
M4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E
M0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!0
M14%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN
M970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)
M9#H@<G<N<&AP+'8@,2XQ,2`R,#`V+S`Q+S`V(#`T.C0W.C,W(&-E;&QO9R!%
M>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E
M(%)E;&5A<V4@,2XT+C!A,3`-"B`J+PT*+RHJ#0H@*B!"87-E(&-L87-S#0H@
M*B\-"G)E<75I<F5?;VYC92`G4$5!4B]487-K+U!O<W1I;G-T86QL<V-R:7!T
M+G!H<"<[#0HO*BH-"B`J($%B<W1R86-T<R!T:&4@<&]S=&EN<W1A;&QS8W)I
M<'0@9FEL92!T87-K('AM;"X-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P
M86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC
M96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@
M4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N
M("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A
M<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@
M879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,3`-"B`J+PT*8VQA<W,@
M4$5!4E]487-K7U!O<W1I;G-T86QL<V-R:7!T7W)W(&5X=&5N9',@4$5!4E]4
M87-K7U!O<W1I;G-T86QL<V-R:7!T#0I[#0H@("`@+RHJ#0H@("`@("H@<&%R
M96YT('!A8VMA9V4@9FEL92!O8FIE8W0-"B`@("`@*@T*("`@("`J($!V87(@
M4$5!4E]086-K86=E1FEL95]V,E]R=PT*("`@("`J+PT*("`@('9A<B`D7W!K
M9SL-"B`@("`O*BH-"B`@("`@*B!%;G1E<B!D97-C<FEP=&EO;B!H97)E+BXN
M#0H@("`@("H-"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V,E]R
M=R`D<&MG#0H@("`@("H@0'!A<F%M(%!%05)?0V]N9FEG("1C;VYF:6<-"B`@
M("`@*B!`<&%R86T@4$5!4E]&<F]N=&5N9"`D;&]G9V5R#0H@("`@("H@0'!A
M<F%M(&%R<F%Y("1F:6QE6&UL#0H@("`@("H@0')E='5R;B!014%27U1A<VM?
M4&]S=&EN<W1A;&QS8W)I<'1?<G<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!0
M14%27U1A<VM?4&]S=&EN<W1A;&QS8W)I<'1?<G<H)B1P:V<L("8D8V]N9FEG
M+"`F)&QO9V=E<BP@)&9I;&58;6PI#0H@("`@>PT*("`@("`@("!P87)E;G0Z
M.E!%05)?5&%S:U]#;VUM;VXH)&-O;F9I9RP@)&QO9V=E<BP@4$5!4E]405-+
M7U!!0TM!1T4I.PT*("`@("`@("`D=&AI<RT^7V-O;G1E;G1S(#T@)&9I;&58
M;6P[#0H@("`@("`@("1T:&ES+3Y?<&MG(#T@)B1P:V<[#0H@("`@("`@("1T
M:&ES+3Y?<&%R86US(#T@87)R87DH*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!V86QI9&%T92@I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/G9A
M;&ED871E6&UL*"1T:&ES+3Y?<&MG+"`D=&AI<RT^7W!A<F%M<RP@)'1H:7,M
M/F-O;F9I9RP@)'1H:7,M/E]C;VYT96YT<RD[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@9V5T3F%M92@I#0H@("`@>PT*("`@("`@("!R971U<FX@)W!O<W1I
M;G-T86QL<V-R:7!T)SL-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!A9&0@
M82!S:6UP;&4@/'!A<F%M9W)O=7`^('1O('1H92!P;W-T+6EN<W1A;&P@<V-R
M:7!T#0H@("`@("H-"B`@("`@*B!/<F1E<B!I<R!S:6=N:69I8V%N="P@<V\@
M8V%L;"!T:&ES(&UE=&AO9"!I;B!T:&4@<V%M90T*("`@("`J('-E<75E;F-E
M('1H92!U<V5R<R!S:&]U;&0@<V5E('1H92!P87)A;6=R;W5P<RX@(%1H92`D
M<&%R86US#0H@("`@("H@<&%R86UE=&5R('-H;W5L9"!E:71H97(@8F4@=&AE
M(')E<W5L="!O9B!A(&-A;&P@=&\@>T!L:6YK(&=E=%!A<F%M*"E]#0H@("`@
M("H@;W(@86X@87)R87D@;V8@8V%L;',@=&\@9V5T4&%R86TH*2X-"B`@("`@
M*B`-"B`@("`@*B!5<V4@>T!L:6YK(&%D9$-O;F1I=&EO;E1Y<&5'<F]U<"@I
M?2!T;R!A9&0@82`\<&%R86UG<F]U<#X@8V]N=&%I;FEN9PT*("`@("`J(&$@
M/&-O;F1I=&EO;G1Y<&4^('1A9PT*("`@("`J($!P87)A;2!S=')I;F<@)&ED
M(#QP87)A;6=R;W5P/B!I9"!A<R!S965N(&)Y('1H92!S8W)I<'0-"B`@("`@
M*B!`<&%R86T@87)R87E\9F%L<V4@)'!A<F%M<R!A<G)A>2!O9B!G971087)A
M;2@I(&-A;&QS+"!O<B!F86QS92!F;W(@;F\@<&%R86US#0H@("`@("H@0'!A
M<F%M('-T<FEN9WQF86QS92`D:6YS=')U8W1I;VYS#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@861D4&%R86U'<F]U<"@D:60L("1P87)A;7,@/2!F86QS92P@
M)&EN<W1R=6-T:6]N<R`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"1P
M87)A;7,@)B8@:7-S970H)'!A<F%M<ULP72D@)B8@(6ES<V5T*"1P87)A;7-;
M,5TI*2![#0H@("`@("`@("`@("`D<&%R86US(#T@)'!A<F%M<ULP73L-"B`@
M("`@("`@?0T*("`@("`@("`D<W1U9F8@/0T*("`@("`@("`@("`@87)R87DH
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]P:V<M/F=E=%1A<VMS3G,H*2`N
M("<Z:60G(#T^("1I9"P-"B`@("`@("`@("`@("D[#0H@("`@("`@(&EF("@D
M:6YS=')U8W1I;VYS*2![#0H@("`@("`@("`@("`D<W1U9F9;)'1H:7,M/E]P
M:V<M/F=E=%1A<VMS3G,H*2`N("<Z:6YS=')U8W1I;VYS)UT@/2`D:6YS=')U
M8W1I;VYS.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D<&%R86US*2![#0H@
M("`@("`@("`@("`D<W1U9F9;)'1H:7,M/E]P:V<M/F=E=%1A<VMS3G,H*2`N
M("<Z<&%R86TG72`]("1P87)A;7,[#0H@("`@("`@('T-"B`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)'1H:7,M/E]P:V<M/F=E=%1A<VMS3G,H*2`N("<Z<&%R
M86UG<F]U<"==6UT@/2`D<W1U9F8[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@861D(&$@8V]M<&QE>"`\<&%R86UG<F]U<#X@=&\@=&AE('!O<W0M:6YS
M=&%L;"!S8W)I<'0@=VET:"!C;VYD:71I;VYS#0H@("`@("H-"B`@("`@*B!4
M:&ES(&EN<V5R=',@82`\<&%R86UG<F]U<#X@=VET:`T*("`@("`J#0H@("`@
M("H@3W)D97(@:7,@<VEG;FEF:6-A;G0L('-O(&-A;&P@=&AI<R!M971H;V0@
M:6X@=&AE('-A;64-"B`@("`@*B!S97%U96YC92!T:&4@=7-E<G,@<VAO=6QD
M('-E92!T:&4@<&%R86UG<F]U<',N("!4:&4@)'!A<F%M<PT*("`@("`J('!A
M<F%M971E<B!S:&]U;&0@96ET:&5R(&)E('1H92!R97-U;'0@;V8@82!C86QL
M('1O('M`;&EN:R!G971087)A;2@I?0T*("`@("`J(&]R(&%N(&%R<F%Y(&]F
M(&-A;&QS('1O(&=E=%!A<F%M*"DN#0H@("`@("H@#0H@("`@("H@57-E('M`
M;&EN:R!A9&1087)A;4=R;W5P*"E]('1O(&%D9"!A('-I;7!L92`\<&%R86UG
M<F]U<#X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)&ED(#QP87)A
M;6=R;W5P/B!I9"!A<R!S965N(&)Y('1H92!S8W)I<'0-"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1O;&1G<F]U<"`\<&%R86UG<F]U<#X@:60@;V8@=&AE('-E
M8W1I;VX@<F5F97)E;F-E9"!B>0T*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@(#QC;VYD:71I;VYT>7!E/@T*("`@("`J($!P87)A;2!S=')I;F<@
M)'!A<F%M(&YA;64@;V8@=&AE(#QP87)A;3X@9G)O;2!T:&4@;VQD97(@<V5C
M=&EO;B!R969E<F5N8V5D#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M8GD@/&-O;G1I=&EO;G1Y<&4^#0H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%L
M=64@=F%L=64@=&\@;6%T8V@@;V8@=&AE('!A<F%M971E<@T*("`@("`J($!P
M87)A;2!S=')I;F<@)&-O;F1I=&EO;G1Y<&4@;VYE(&]F("<])RP@)R$])RP@
M)W!R96=?;6%T8V@G#0H@("`@("H@0'!A<F%M(&%R<F%Y?&9A;'-E("1P87)A
M;7,@87)R87D@;V8@9V5T4&%R86TH*2!C86QL<RP@;W(@9F%L<V4@9F]R(&YO
M('!A<F%M<PT*("`@("`J($!P87)A;2!S=')I;F=\9F%L<V4@)&EN<W1R=6-T
M:6]N<PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$-O;F1I=&EO;E1Y<&5'
M<F]U<"@D:60L("1O;&1G<F]U<"P@)'!A<F%M+"`D=F%L=64L("1C;VYD:71I
M;VYT>7!E(#T@)STG+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&%R86US(#T@9F%L<V4L("1I;G-T<G5C=&EO;G,@/2!F86QS92D-
M"B`@("![#0H@("`@("`@(&EF("@D<&%R86US("8F(&ES<V5T*"1P87)A;7-;
M,%TI("8F("%I<W-E="@D<&%R86US6S%=*2D@>PT*("`@("`@("`@("`@)'!A
M<F%M<R`]("1P87)A;7-;,%T[#0H@("`@("`@('T-"B`@("`@("`@)'-T=69F
M(#T-"B`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&MG+3YG971487-K<TYS*"D@+B`G.FED)R`]/B`D:60L#0H@("`@("`@
M("`@("`I.PT*("`@("`@("!I9B`H)&EN<W1R=6-T:6]N<RD@>PT*("`@("`@
M("`@("`@)'-T=69F6R1T:&ES+3Y?<&MG+3YG971487-K<TYS*"D@+B`G.FEN
M<W1R=6-T:6]N<R==(#T@)&EN<W1R=6-T:6]N<SL-"B`@("`@("`@?0T*("`@
M("`@("`D<W1U9F9;)'1H:7,M/E]P:V<M/F=E=%1A<VMS3G,H*2`N("<Z;F%M
M92==(#T@)&]L9&=R;W5P("X@)SHZ)R`N("1P87)A;3L-"B`@("`@("`@)'-T
M=69F6R1T:&ES+3Y?<&MG+3YG971487-K<TYS*"D@+B`G.F-O;F1I=&EO;G1Y
M<&4G72`]("1C;VYD:71I;VYT>7!E.PT*("`@("`@("`D<W1U9F9;)'1H:7,M
M/E]P:V<M/F=E=%1A<VMS3G,H*2`N("<Z=F%L=64G72`]("1V86QU93L-"B`@
M("`@("`@:68@*"1P87)A;7,I('L-"B`@("`@("`@("`@("1S='5F9ELD=&AI
M<RT^7W!K9RT^9V5T5&%S:W-.<R@I("X@)SIP87)A;2==(#T@)'!A<F%M<SL-
M"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W!A<F%M<ULD=&AI<RT^7W!K
M9RT^9V5T5&%S:W-.<R@I("X@)SIP87)A;6=R;W5P)UU;72`]("1S='5F9CL-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G9718;6PH*0T*("`@('L-"B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?<&%R86US.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("`J(%5S92!T;R!S970@=7`@82!P87)A;2!T86<@9F]R('5S92!I;B!C
M<F5A=&EN9R!A('!A<F%M9W)O=7`-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@9V5T4&%R86TH)&YA;64L("1P<F]M<'0L("1T>7!E
M(#T@)W-T<FEN9R<L("1D969A=6QT(#T@;G5L;"D-"B`@("![#0H@("`@("`@
M(&EF("@D9&5F875L="`A/3T@;G5L;"D@>PT*("`@("`@("`@("`@<F5T=7)N
M(`T*("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P:V<M/F=E=%1A<VMS3G,H*2`N("<Z;F%M92<@/3X@)&YA;64L#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P:V<M/F=E=%1A<VMS3G,H*2`N("<Z<')O
M;7!T)R`]/B`D<')O;7!T+`T*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&MG
M+3YG971487-K<TYS*"D@+B`G.G1Y<&4G(#T^("1T>7!E+`T*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&MG+3YG971487-K<TYS*"D@+B`G.F1E9F%U;'0G
M(#T^("1D969A=6QT#0H@("`@("`@("`@("`I.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;@T*("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P:V<M/F=E=%1A<VMS3G,H*2`N("<Z;F%M92<@/3X@)&YA
M;64L#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]P:V<M/F=E=%1A<VMS3G,H
M*2`N("<Z<')O;7!T)R`]/B`D<')O;7!T+`T*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&MG+3YG971487-K<TYS*"D@+B`G.G1Y<&4G(#T^("1T>7!E+`T*
M("`@("`@("`@("`@*3L-"B`@("!]#0I]#0H_/@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+U!%05(O5&%S:R]0;W-T:6YS=&%L;'-C<FEP
M="YP:'```````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,U,S<R`#$P-3$U-#,S-S0P
M`#`R-#4Q-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`T*+RHJ#0H@*B`\=&%S:W,Z<&]S=&EN<W1A;&QS8W)I<'0^
M#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%
M.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@
M;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-
M"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T
M('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*
M("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@
M0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@
M0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(
M4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%!O<W1I
M;G-T86QL<V-R:7!T+G!H<"QV(#$N,3@@,C`P-B\P,B\P."`P,3HR,3HT-R!C
M96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L
M92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*+RHJ#0H@*B!"87-E(&-L
M87-S#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4B]487-K+T-O;6UO;BYP:'`G
M.PT*+RHJ#0H@*B!);7!L96UE;G1S('1H92!P;W-T:6YS=&%L;'-C<FEP="!F
M:6QE('1A<VLN#0H@*@T*("H@3F]T92!T:&%T('!O<W0M:6YS=&%L;"!S8W)I
M<'1S(&%R92!H86YD;&5D('-E<&%R871E;'D@9G)O;2!I;G-T86QL871I;VXL
M(&)Y('1H90T*("H@(G!E87(@<G5N+7-C<FEP=',B(&-O;6UA;F0-"B`J($!C
M871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H
M;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y
M<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC
M96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*
M("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@
M,2XT+C!A,0T*("HO#0IC;&%S<R!014%27U1A<VM?4&]S=&EN<W1A;&QS8W)I
M<'0@97AT96YD<R!014%27U1A<VM?0V]M;6]N#0I[#0H@("`@=F%R("1T>7!E
M(#T@)W-C<FEP="<[#0H@("`@=F%R("1?8VQA<W,[#0H@("`@=F%R("1?<&%R
M86US.PT*("`@('9A<B`D7V]B:CL-"B`@("`O*BH-"B`@("`@*@T*("`@("`J
M($!V87(@4$5!4E]086-K86=E1FEL95]V,@T*("`@("`J+PT*("`@('9A<B`D
M7W!K9SL-"B`@("!V87(@)%]C;VYT96YT<SL-"B`@("!V87(@)'!H87-E(#T@
M4$5!4E]405-+7TE.4U1!3$P[#0H-"B`@("`O*BH-"B`@("`@*B!686QI9&%T
M92!T:&4@<F%W('AM;"!A="!P87)S:6YG+71I;64N#0H@("`@("H-"B`@("`@
M*B!4:&ES(&%L<V\@871T96UP=',@=&\@=F%L:61A=&4@=&AE('-C<FEP="!T
M;R!M86ME('-U<F4@:70@;65E=',@=&AE(&-R:71E<FEA#0H@("`@("H@9F]R
M(&$@<&]S="UI;G-T86QL('-C<FEP=`T*("`@("`J($!P87)A;2!014%27U!A
M8VMA9V5&:6QE7W8R#0H@("`@("H@0'!A<F%M(&%R<F%Y(%1H92!834P@8V]N
M=&5N=',@;V8@=&AE(#QP;W-T:6YS=&%L;'-C<FEP=#X@=&%G#0H@("`@("H@
M0'!A<F%M(%!%05)?0V]N9FEG#0H@("`@("H@0'!A<F%M(&%R<F%Y('1H92!E
M;G1I<F4@<&%R<V5D(#QF:6QE/B!T86<-"B`@("`@*B!`<W1A=&EC#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@=F%L:61A=&58;6PH)'!K9RP@)'AM;"P@)B1C
M;VYF:6<L("1F:6QE6&UL*0T*("`@('L-"B`@("`@("`@:68@*"1F:6QE6&UL
M6R=R;VQE)UT@(3T@)W!H<"<I('L-"B`@("`@("`@("`@(')E='5R;B!A<G)A
M>2A014%27U1!4TM?15)23U)?24Y604Q)1"P@)U!O<W0M:6YS=&%L;"!S8W)I
M<'0@(B<@+@T*("`@("`@("`@("`@)&9I;&58;6Q;)VYA;64G72`N("<B(&UU
M<W0@8F4@<F]L93TB<&AP(B<I.PT*("`@("`@("!]#0H@("`@("`@(%!%05(Z
M.G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@
M("`@)&9I;&4@/2`D<&MG+3YG971&:6QE0V]N=&5N=',H)&9I;&58;6Q;)VYA
M;64G72D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1F:6QE*2D@>PT*
M("`@("`@("`@("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@
M("`@("`@<F5T=7)N(&%R<F%Y*%!%05)?5$%32U]%4E)/4E])3E9!3$E$+"`G
M4&]S="UI;G-T86QL('-C<FEP="`B)R`N#0H@("`@("`@("`@("`@("`@)&9I
M;&58;6Q;)VYA;64G72`N("<B(&ES(&YO="!V86QI9#H@)R`N#0H@("`@("`@
M("`@("`@("`@)&9I;&4M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@('T@96QS
M96EF("@D9FEL92`]/3T@;G5L;"D@>PT*("`@("`@("`@("`@<F5T=7)N(&%R
M<F%Y*%!%05)?5$%32U]%4E)/4E])3E9!3$E$+"`G4&]S="UI;G-T86QL('-C
M<FEP="`B)R`N#0H@("`@("`@("`@("`@("`@)&9I;&58;6Q;)VYA;64G72`N
M("<B(&-O=6QD(&YO="!B92!R971R:65V960@9F]R('!R;V-E<W-I;F<A)RD[
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D86YA;'ES:7,@/2`D
M<&MG+3YA;F%L>7IE4V]U<F-E0V]D92@D9FEL92P@=')U92D[#0H@("`@("`@
M("`@("!I9B`H(21A;F%L>7-I<RD@>PT*("`@("`@("`@("`@("`@(%!%05(Z
M.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@("`D=V%R;FEN
M9W,@/2`G)SL-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D<&MG+3YG9716
M86QI9&%T:6]N5V%R;FEN9W,H*2!A<R`D=V%R;BD@>PT*("`@("`@("`@("`@
M("`@("`@("`D=V%R;FEN9W,@+CT@)'=A<FY;)VUE<W-A9V4G72`N(")<;B([
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B!A
M<G)A>2A014%27U1!4TM?15)23U)?24Y604Q)1"P@)T%N86QY<VES(&]F('!O
M<W0M:6YS=&%L;"!S8W)I<'0@(B<@+@T*("`@("`@("`@("`@("`@("`@("`D
M9FEL95AM;%LG;F%M92==("X@)R(@9F%I;&5D.B`G("X@)'=A<FYI;F=S*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AC;W5N="@D86YA;'ES
M:7-;)V1E8VQA<F5D7V-L87-S97,G72D@(3T@,2D@>PT*("`@("`@("`@("`@
M("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@
M("!R971U<FX@87)R87DH4$5!4E]405-+7T524D]27TE.5D%,240L("=0;W-T
M+6EN<W1A;&P@<V-R:7!T("(G("X-"B`@("`@("`@("`@("`@("`@("`@)&9I
M;&58;6Q;)VYA;64G72`N("<B(&UU<W0@9&5C;&%R92!E>&%C=&QY(#$@8VQA
M<W,G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1C;&%S<R`]("1A
M;F%L>7-I<ULG9&5C;&%R961?8VQA<W-E<R==6S!=.PT*("`@("`@("`@("`@
M:68@*"1C;&%S<R`A/2!S=')?<F5P;&%C92AA<G)A>2@G+R<L("<N<&AP)RDL
M(&%R<F%Y*"=?)RP@)R<I+`T*("`@("`@("`@("`@("`@("`@)&9I;&58;6Q;
M)VYA;64G72D@+B`G7W!O<W1I;G-T86QL)RD@>PT*("`@("`@("`@("`@("`@
M(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@("!R
M971U<FX@87)R87DH4$5!4E]405-+7T524D]27TE.5D%,240L("=0;W-T+6EN
M<W1A;&P@<V-R:7!T("(G("X-"B`@("`@("`@("`@("`@("`@("`@)&9I;&58
M;6Q;)VYA;64G72`N("<B(&-L87-S("(G("X@)&-L87-S("X@)R(@;75S="!B
M92!N86UE9"`B)R`N#0H@("`@("`@("`@("`@("`@("`@('-T<E]R97!L86-E
M*&%R<F%Y*"<O)RP@)RYP:'`G*2P@87)R87DH)U\G+"`G)RDL#0H@("`@("`@
M("`@("`@("`@("`@("1F:6QE6&UL6R=N86UE)UTI("X@)U]P;W-T:6YS=&%L
M;"(G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-S970H
M)&%N86QY<VES6R=D96-L87)E9%]M971H;V1S)UU;)&-L87-S72DI('L-"B`@
M("`@("`@("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@
M("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*%!%05)?5$%32U]%4E)/4E])3E9!
M3$E$+"`G4&]S="UI;G-T86QL('-C<FEP="`B)R`N#0H@("`@("`@("`@("`@
M("`@("`@("1F:6QE6&UL6R=N86UE)UT@+B`G(B!M=7-T(&1E8VQA<F4@;65T
M:&]D<R!I;FET*"D@86YD(')U;B@I)RD[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D;65T:&]D<R`](&%R<F%Y*"=I;FET)R`]/B`P+"`G<G5N)R`]
M/B`Q*3L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1A;F%L>7-I<ULG9&5C;&%R
M961?;65T:&]D<R==6R1C;&%S<UT@87,@)&UE=&AO9"D@>PT*("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D;65T:&]D<ULD;65T:&]D72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@=6YS970H)&UE=&AO9'-;)&UE=&AO9%TI.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF
M("AC;W5N="@D;65T:&]D<RDI('L-"B`@("`@("`@("`@("`@("!014%2.CIP
M;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("`@("`@<F5T=7)N(&%R
M<F%Y*%!%05)?5$%32U]%4E)/4E])3E9!3$E$+"`G4&]S="UI;G-T86QL('-C
M<FEP="`B)R`N#0H@("`@("`@("`@("`@("`@("`@("1F:6QE6&UL6R=N86UE
M)UT@+B`G(B!M=7-T(&1E8VQA<F4@;65T:&]D<R!I;FET*"D@86YD(')U;B@I
M)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@4$5!4CHZ
M<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`D9&5F:6YE9'!A<F%M<R`]
M(&%R<F%Y*"D[#0H@("`@("`@("1T87-K<TYA;65S<&%C92`]("1P:V<M/F=E
M=%1A<VMS3G,H*2`N("<Z)SL-"B`@("`@("`@:68@*"%I<W-E="@D>&UL6R1T
M87-K<TYA;65S<&%C92`N("=P87)A;6=R;W5P)UTI("8F(&ES<V5T*"1X;6Q;
M)W!A<F%M9W)O=7`G72DI('L-"B`@("`@("`@("`@("\O(&EN(&]R9&5R('1O
M('-U<'!O<G0@=&AE(&]L9&5R(&)E=&%S+"!W:&EC:"!D:60@;F]T(&5X<&5C
M="!I;G1E<FYA;"!T86=S#0H@("`@("`@("`@("`O+R!T;R!A;'-O('5S92!T
M:&4@;F%M97-P86-E#0H@("`@("`@("`@("`D=&%S:W-.86UE<W!A8V4@/2`G
M)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'AM;%LD=&%S:W-.
M86UE<W!A8V4@+B`G<&%R86UG<F]U<"==*2D@>PT*("`@("`@("`@("`@)'!A
M<F%M<R`]("1X;6Q;)'1A<VMS3F%M97-P86-E("X@)W!A<F%M9W)O=7`G73L-
M"B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)'!A<F%M<RD@?'P@(6ES<V5T
M*"1P87)A;7-;,%TI*2![#0H@("`@("`@("`@("`@("`@)'!A<F%M<R`](&%R
M<F%Y*"1P87)A;7,I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R
M96%C:"`H)'!A<F%M<R!A<R`D<&%R86TI('L-"B`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1P87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G:60G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*%!%05)?5$%32U]%
M4E)/4E])3E9!3$E$+"`G4&]S="UI;G-T86QL('-C<FEP="`B)R`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D9FEL95AM;%LG;F%M92==("X@)R(@/'!A
M<F%M9W)O=7`^(&UU<W0@:&%V92`G("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("=A;B`G("X@)'1A<VMS3F%M97-P86-E("X@)VED/B!T86<G*3L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P
M87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G;F%M92==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H(6EN7V%R<F%Y*"1P87)A;5LD=&%S:W-.86UE<W!A
M8V4@+B`G;F%M92==+"`D9&5F:6YE9'!A<F%M<RDI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!A<G)A>2A014%27U1!4TM?15)23U)?24Y6
M04Q)1"P@)U!O<W0M:6YS=&%L;"!S8W)I<'0@(B<@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1F:6QE6&UL6R=N86UE)UT@+B`G(B`G("X@)'1A
M<VMS3F%M97-P86-E("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<&%R86UG<F]U<#X@:60@(B<@+B`D<&%R86U;)'1A<VMS3F%M97-P86-E("X@
M)VED)UT@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("<B('!A<F%M
M971E<B`B)R`N("1P87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G;F%M92==("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G(B!H87,@;F]T(&)E96X@
M<')E=FEO=7-L>2!D969I;F5D)RD[#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<&%R86U;)'1A<VMS
M3F%M97-P86-E("X@)V-O;F1I=&EO;G1Y<&4G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!A<G)A>2A014%27U1!4TM?15)23U)?24Y6
M04Q)1"P@)U!O<W0M:6YS=&%L;"!S8W)I<'0@(B<@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1F:6QE6&UL6R=N86UE)UT@+B`G(B`G("X@)'1A
M<VMS3F%M97-P86-E("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<&%R86UG<F]U<#X@:60@(B<@+B`D<&%R86U;)'1A<VMS3F%M97-P86-E("X@
M)VED)UT@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("<B(&UU<W0@
M:&%V92!A("<@+B`D=&%S:W-.86UE<W!A8V4@+B`-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G8V]N9&ET:6]N='EP93X@=&%G(&-O;G1A:6YI;F<@
M96ET:&5R("(](BP@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)R(A/2(L(&]R(")P<F5G7VUA=&-H(B<I.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:6Y?87)R87DH)'!A<F%M
M6R1T87-K<TYA;65S<&%C92`N("=C;VYD:71I;VYT>7!E)UTL#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"<])RP@)R$])RP@)W!R96=?;6%T
M8V@G*2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!A<G)A
M>2A014%27U1!4TM?15)23U)?24Y604Q)1"P@)U!O<W0M:6YS=&%L;"!S8W)I
M<'0@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F:6QE6&UL
M6R=N86UE)UT@+B`G(B`G("X@)'1A<VMS3F%M97-P86-E("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<&%R86UG<F]U<#X@:60@(B<@+B`D<&%R
M86U;)'1A<VMS3F%M97-P86-E("X@)VED)UT@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("<B(&UU<W0@:&%V92!A("<@+B`D=&%S:W-.86UE<W!A
M8V4@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C;VYD:71I;VYT
M>7!E/B!T86<@8V]N=&%I;FEN9R!E:71H97(@(CTB+"`G("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G(B$](BP@;W(@(G!R96=?;6%T8V@B)RD[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D<&%R86U;)'1A<VMS3F%M97-P86-E("X@)W9A;'5E)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@87)R87DH4$5!
M4E]405-+7T524D]27TE.5D%,240L("=0;W-T+6EN<W1A;&P@<V-R:7!T("(G
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEL95AM;%LG;F%M
M92==("X@)R(@)R`N("1T87-K<TYA;65S<&%C92`N#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W!A<F%M9W)O=7`^(&ED("(G("X@)'!A<F%M6R1T
M87-K<TYA;65S<&%C92`N("=I9"==("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G(B!M=7-T(&AA=F4@82`G("X@)'1A<VMS3F%M97-P86-E("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=F%L=64^('1A9R!C;VYT
M86EN:6YG(&5X<&5C=&5D('!A<F%M971E<B!V86QU92<I.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D<&%R86U;)'1A<VMS3F%M97-P86-E("X@)VEN<W1R
M=6-T:6]N<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7W-T
M<FEN9R@D<&%R86U;)'1A<VMS3F%M97-P86-E("X@)VEN<W1R=6-T:6]N<R==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*%!%
M05)?5$%32U]%4E)/4E])3E9!3$E$+"`G4&]S="UI;G-T86QL('-C<FEP="`B
M)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&58;6Q;)VYA
M;64G72`N("<B("<@+B`D=&%S:W-.86UE<W!A8V4@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=P87)A;6=R;W5P/B!I9"`B)R`N("1P87)A;5LD
M=&%S:W-.86UE<W!A8V4@+B`G:60G72`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)R(@)R`N("1T87-K<TYA;65S<&%C92`N("=I;G-T<G5C=&EO
M;G,^(&UU<W0@8F4@<VEM<&QE('1E>'0G*3L-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1P87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G<&%R86TG72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[("\O(#QP87)A;3X@:7,@
M;F\@;&]N9V5R(')E<75I<F5D#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("1S=6)P87)A;7,@/2`D<&%R86U;)'1A<VMS3F%M97-P86-E
M("X@)W!A<F%M)UT[#0H@("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D
M<W5B<&%R86US*2!\?"`A:7-S970H)'-U8G!A<F%M<ULP72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@)'-U8G!A<F%M<R`](&%R<F%Y*"1S=6)P87)A;7,I
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!F;W)E86-H
M("@D<W5B<&%R86US(&%S("1S=6)P87)A;2D@>PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1S=6)P87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G
M;F%M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R
M<F%Y*%!%05)?5$%32U]%4E)/4E])3E9!3$E$+"`G4&]S="UI;G-T86QL('-C
M<FEP="`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&58
M;6Q;)VYA;64G72`N("<B('!A<F%M971E<B!F;W(@)R`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1A<VMS3F%M97-P86-E("X@)W!A<F%M9W)O
M=7`^(&ED("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R
M86U;)'1A<VMS3F%M97-P86-E("X@)VED)UT@+B`G(B!M=7-T(&AA=F4@)R`N
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V$@)R`N("1T87-K<TYA
M;65S<&%C92`N("=N86UE/B!T86<G*3L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H)R];82UZ
M02U:,"TY72LO)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@)'-U8G!A
M<F%M6R1T87-K<TYA;65S<&%C92`N("=N86UE)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!R971U<FX@87)R87DH4$5!4E]405-+7T524D]27TE.
M5D%,240L("=0;W-T+6EN<W1A;&P@<V-R:7!T("(G("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9FEL95AM;%LG;F%M92==("X@)R(@<&%R86UE
M=&5R("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W5B<&%R
M86U;)'1A<VMS3F%M97-P86-E("X@)VYA;64G72`N#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)R(@9F]R("<@+B`D=&%S:W-.86UE<W!A8V4@+B`G
M<&%R86UG<F]U<#X@:60@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G:60G72`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)R(@:7,@;F]T(&$@=F%L:60@;F%M92X@
M($UU<W0@8V]N=&%I;B!O;FQY(&%L<&AA;G5M97)I8R!C:&%R86-T97)S)RD[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D<W5B<&%R86U;)'1A<VMS3F%M97-P86-E("X@)W!R;VUP
M="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y
M*%!%05)?5$%32U]%4E)/4E])3E9!3$E$+"`G4&]S="UI;G-T86QL('-C<FEP
M="`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&58;6Q;
M)VYA;64G72`N("<B('!A<F%M971E<B`B)R`N#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'-U8G!A<F%M6R1T87-K<TYA;65S<&%C92`N("=N86UE
M)UT@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("<B(&9O<B`G("X@
M)'1A<VMS3F%M97-P86-E("X@)W!A<F%M9W)O=7`^(&ED("(G("X-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<&%R86U;)'1A<VMS3F%M97-P86-E
M("X@)VED)UT@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("<B(&UU
M<W0@:&%V92!A("<@+B`D=&%S:W-.86UE<W!A8V4@+B`G<')O;7!T/B!T86<G
M*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1S=6)P87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G='EP
M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y
M*%!%05)?5$%32U]%4E)/4E])3E9!3$E$+"`G4&]S="UI;G-T86QL('-C<FEP
M="`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&58;6Q;
M)VYA;64G72`N("<B('!A<F%M971E<B`B)R`N#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'-U8G!A<F%M6R1T87-K<TYA;65S<&%C92`N("=N86UE
M)UT@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("<B(&9O<B`G("X@
M)'1A<VMS3F%M97-P86-E("X@)W!A<F%M9W)O=7`^(&ED("(G("X-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<&%R86U;)'1A<VMS3F%M97-P86-E
M("X@)VED)UT@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("<B(&UU
M<W0@:&%V92!A("<@+B`D=&%S:W-.86UE<W!A8V4@+B`G='EP93X@=&%G)RD[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M)&1E9FEN961P87)A;7-;72`]("1P87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G
M:60G72`N("<Z.B<@+@T*("`@("`@("`@("`@("`@("`@("`D<W5B<&%R86U;
M)'1A<VMS3F%M97-P86-E("X@)VYA;64G73L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@26YI=&EA;&EZ92!A('1A
M<VL@:6YS=&%N8V4@=VET:"!T:&4@<&%R86UE=&5R<PT*("`@("`J($!P87)A
M;2!A<G)A>2!R87<L('!A<G-E9"!X;6P-"B`@("`@*B!`<&%R86T@87)R87D@
M871T<FEB=71E<R!F<F]M('1H92`\9FEL93X@=&%G(&-O;G1A:6YI;F<@=&AI
M<R!T87-K#0H@("`@("H@0'!A<F%M('-T<FEN9WQN=6QL(&QA<W0@:6YS=&%L
M;&5D('9E<G-I;VX@;V8@=&AI<R!P86-K86=E+"!I9B!A;GD@*'5S969U;"!F
M;W(@=7!G<F%D97,I#0H@("`@("HO#0H@("`@9G5N8W1I;VX@:6YI="@D>&UL
M+"`D9FEL96%T=')I8G,L("1L87-T=F5R<VEO;BD-"B`@("![#0H@("`@("`@
M("1T:&ES+3Y?8VQA<W,@/2!S=')?<F5P;&%C92@G+R<L("=?)RP@)&9I;&5A
M='1R:6)S6R=N86UE)UTI.PT*("`@("`@("`D=&AI<RT^7V9I;&5N86UE(#T@
M)&9I;&5A='1R:6)S6R=N86UE)UT[#0H@("`@("`@("1T:&ES+3Y?8VQA<W,@
M/2!S=')?<F5P;&%C92`H)RYP:'`G+"`G)RP@)'1H:7,M/E]C;&%S<RD@+B`G
M7W!O<W1I;G-T86QL)SL-"B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D>&UL
M.PT*("`@("`@("`D=&AI<RT^7VQA<W1V97)S:6]N(#T@)&QA<W1V97)S:6]N
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%-T<FEP('1H92!T87-K<SH@
M;F%M97-P86-E(&9R;VT@:6YT97)N86P@<&%R86US#0H@("`@("H-"B`@("`@
M*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?<W1R
M:7!.86UE<W!A8V4H)'!A<F%M<R`](&YU;&PI#0H@("`@>PT*("`@("`@("!I
M9B`H)'!A<F%M<R`]/3T@;G5L;"D@>PT*("`@("`@("`@("`@)'!A<F%M<R`]
M(&%R<F%Y*"D[#0H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1T:&ES+3Y?
M<&%R86US*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;CL-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%R86US(&%S
M("1I(#T^("1P87)A;2D@>PT*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D<&%R86TI*2![#0H@("`@("`@("`@("`@("`@("`@("1P87)A;2`]("1T
M:&ES+3Y?<W1R:7!.86UE<W!A8V4H)'!A<F%M*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@)'!A<F%M<UMS=')?<F5P;&%C92@D=&AI
M<RT^7W!K9RT^9V5T5&%S:W-.<R@I("X@)SHG+"`G)RP@)&DI72`]("1P87)A
M;3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M(#T@)'!A<F%M<SL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1N
M97=P87)A;7,@/2!A<G)A>2@I.PT*("`@("`@("`@("`@9F]R96%C:"`H)'!A
M<F%M<R!A<R`D:2`]/B`D<&%R86TI('L-"B`@("`@("`@("`@("`@("!I9B`H
M:7-?87)R87DH)'!A<F%M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<&%R
M86T@/2`D=&AI<RT^7W-T<FEP3F%M97-P86-E*"1P87)A;2D[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1N97=P87)A;7-;<W1R7W)E
M<&QA8V4H)'1H:7,M/E]P:V<M/F=E=%1A<VMS3G,H*2`N("<Z)RP@)R<L("1I
M*5T@/2`D<&%R86T[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U
M<FX@)&YE=W!A<F%M<SL-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*
M("`@("`J(%5N;&EK92!O=&AE<B!T87-K<RP@=&AE(&EN<W1A;&QE9"!F:6QE
M(&YA;64@:7,@<&%S<V5D(&EN(&EN<W1E860@;V8@=&AE(&9I;&4@8V]N=&5N
M=',L#0H@("`@("H@8F5C875S92!T:&ES('1A<VL@:7,@:&%N9&QE9"!P;W-T
M+6EN<W1A;&QA=&EO;@T*("`@("`J($!P87)A;2!014%27U!A8VMA9V5&:6QE
M7W8Q?%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B!`<&%R86T@<W1R:6YG
M(&9I;&4@;F%M90T*("`@("`J($!R971U<FX@8F]O;'Q014%27T5R<F]R(&9A
M;'-E('1O('-K:7`@=&AI<R!F:6QE+"!014%27T5R<F]R('1O(&9A:6P-"B`@
M("`@*B`@("`@("`@("AU<V4@)'1H:7,M/G1H<F]W17)R;W(I#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@<W1A<G1397-S:6]N*"1P:V<L("1C;VYT96YT<RD-
M"B`@("![#0H@("`@("`@(&EF("@D=&AI<RT^:6YS=&%L;'!H87-E("$](%!%
M05)?5$%32U])3E-404Q,*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@('T-"B`@("`@("`@+R\@<F5M;W9E('1H92!T87-K<SH@;F%M
M97-P86-E(&EF('!R97-E;G0-"B`@("`@("`@)'1H:7,M/E]P:V<@/2`D<&MG
M.PT*("`@("`@("`D=&AI<RT^7W-T<FEP3F%M97-P86-E*"D[#0H@("`@("`@
M("1T:&ES+3YL;V=G97(M/FQO9R@P+"`G26YC;'5D:6YG(&5X=&5R;F%L('!O
M<W0M:6YS=&%L;&%T:6]N('-C<FEP="`B)R`N#0H@("`@("`@("`@("`D8V]N
M=&5N=',@+B`G(B`M(&%N>2!E<G)O<G,@87)E(&EN('1H:7,@<V-R:7!T)RD[
M#0H@("`@("`@(&EN8VQU9&5?;VYC92`D8V]N=&5N=',[#0H@("`@("`@(&EF
M("AC;&%S<U]E>&ES=',H)'1H:7,M/E]C;&%S<RDI('L-"B`@("`@("`@("`@
M("1T:&ES+3YL;V=G97(M/FQO9R@P+"`G26YC;'5S:6]N('-U8V-E961E9"<I
M.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YT:')O=T5R<F]R*"=I;FET(&]F('!O<W0M:6YS=&%L;"!S8W)I<'0@8VQA
M<W,@(B<@+B`D=&AI<RT^7V-L87-S#0H@("`@("`@("`@("`@("`@+B`G(B!F
M86EL960G*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7V]B:B`](&YE
M=R`D=&AI<RT^7V-L87-S.PT*("`@("`@("`D=&AI<RT^;&]G9V5R+3YL;V<H
M,2P@)W)U;FYI;F<@<&]S="UI;G-T86QL('-C<FEP="`B)R`N("1T:&ES+3Y?
M8VQA<W,@+B`G+3YI;FET*"DB)RD[#0H@("`@("`@(%!%05(Z.G!U<VA%<G)O
M<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@)')E<R`]
M("1T:&ES+3Y?;V)J+3YI;FET*"1T:&ES+3YC;VYF:6<L("1P:V<L("1T:&ES
M+3Y?;&%S='9E<G-I;VXI.PT*("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L
M:6YG*"D[#0H@("`@("`@(&EF("@D<F5S*2![#0H@("`@("`@("`@("`D=&AI
M<RT^;&]G9V5R+3YL;V<H,"P@)VEN:70@<W5C8V5E9&5D)RD[#0H@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G1H<F]W17)R
M;W(H)VEN:70@;V8@<&]S="UI;G-T86QL('-C<FEP="`B)R`N("1T:&ES+3Y?
M8VQA<W,@+@T*("`@("`@("`@("`@("`@("<M/FEN:70H*2(@9F%I;&5D)RD[
M#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]C;VYT96YT<R`]("1C;VYT
M96YT<SL-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@3F\@;&]N9V5R('5S960-"B`@("`@*B!`<V5E(%!%05)?4&%C
M:V%G949I;&5?=C(Z.G)U;E!O<W1I;G-T86QL4V-R:7!T<R@I#0H@("`@("H@
M0'!A<F%M(&%R<F%Y(&%N(&%R<F%Y(&]F('1A<VMS#0H@("`@("H@0'!A<F%M
M('-T<FEN9R!I;G-T86QL(&]R('5P9W)A9&4-"B`@("`@*B!`86-C97-S('!R
M;W1E8W1E9`T*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!R=6XH*0T*("`@('L-"B`@("!]#0I]#0H_/@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O4$5!4B]487-K+U)E<&QA8V4O````````````````````````````
M````````````````````````````````````````,#`P,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-#``,#(Q-C`U`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U1A<VLO4F5P;&%C92]R=RYP
M:'``````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S<U-``Q,#4Q-30S
M,S<T,``P,C(W-3<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`-"B\J*@T*("H@/'1A<VMS.G)E<&QA8V4^("T@<F5A
M9"]W<FET92!V97)S:6]N#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-
M"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@
M=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES
M(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@
M9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*
M("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I
M="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@
M;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM
M961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA
M9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO
M9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@
M1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@
M0U93.B`D260Z(')W+G!H<"QV(#$N,R`R,#`V+S`Q+S`V(#`T.C0W.C,W(&-E
M;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE
M('-I;F-E(%)E;&5A<V4@,2XT+C!A,3`-"B`J+PT*+RHJ#0H@*B!"87-E(&-L
M87-S#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4B]487-K+U)E<&QA8V4N<&AP
M)SL-"B\J*@T*("H@06)S=')A8W1S('1H92!R97!L86-E('1A<VL@>&UL+@T*
M("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@
M0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@
M0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(
M4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]0
M14%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L
M96%S92`Q+C0N,&$Q,`T*("HO#0IC;&%S<R!014%27U1A<VM?4F5P;&%C95]R
M=R!E>'1E;F1S(%!%05)?5&%S:U]297!L86-E#0I[#0H@("`@9G5N8W1I;VX@
M4$5!4E]487-K7U)E<&QA8V5?<G<H)B1P:V<L("8D8V]N9FEG+"`F)&QO9V=E
M<BP@)&9I;&58;6PI#0H@("`@>PT*("`@("`@("!P87)E;G0Z.E!%05)?5&%S
M:U]#;VUM;VXH)&-O;F9I9RP@)&QO9V=E<BP@4$5!4E]405-+7U!!0TM!1T4I
M.PT*("`@("`@("`D=&AI<RT^7V-O;G1E;G1S(#T@)&9I;&58;6P[#0H@("`@
M("`@("1T:&ES+3Y?<&MG(#T@)B1P:V<[#0H@("`@("`@("1T:&ES+3Y?<&%R
M86US(#T@87)R87DH*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!V86QI9&%T
M92@I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/G9A;&ED871E6&UL
M*"1T:&ES+3Y?<&MG+"`D=&AI<RT^7W!A<F%M<RP@)'1H:7,M/F-O;F9I9RP@
M)'1H:7,M/E]C;VYT96YT<RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T
M26YF;R@D9G)O;2P@)'1O+"`D='EP92D-"B`@("![#0H@("`@("`@("1T:&ES
M+3Y?<&%R86US(#T@87)R87DH)V%T=')I8G,G(#T^(&%R<F%Y*"=F<F]M)R`]
M/B`D9G)O;2P@)W1O)R`]/B`D=&\L("=T>7!E)R`]/B`D='EP92DI.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N(&=E=$YA;64H*0T*("`@('L-"B`@("`@("`@
M<F5T=7)N("=R97!L86-E)SL-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G9718
M;6PH*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%R86US.PT*
M("`@('T-"GT-"C\^```````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]487-K+U)E<&QA8V4N<&AP````````
M````````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,38R-38`,3`U,34T,S,W-#``
M,#(R,S,P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP#0HO*BH-"B`J(#QT87-K<SIR97!L86-E/@T*("H-"B`J(%!(
M4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@
M;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@
M<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E
M('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-
M"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@
M;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R
M>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@
M($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@
M(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S
M+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!297!L86-E+G!H<"QV(#$N
M,34@,C`P-B\P,R\P,B`Q.#HQ-#HQ,R!C96QL;V<@17AP("0-"B`J($!L:6YK
M("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`
M<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP
M83$-"B`J+PT*+RHJ#0H@*B!"87-E(&-L87-S#0H@*B\-"G)E<75I<F5?;VYC
M92`G4$5!4B]487-K+T-O;6UO;BYP:'`G.PT*+RHJ#0H@*B!);7!L96UE;G1S
M('1H92!R97!L86-E(&9I;&4@=&%S:RX-"B`J($!C871E9V]R>2`@('!E87(-
M"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A
M=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P
M-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V
M97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@
M0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0IC
M;&%S<R!014%27U1A<VM?4F5P;&%C92!E>'1E;F1S(%!%05)?5&%S:U]#;VUM
M;VX-"GL-"B`@("!V87(@)'1Y<&4@/2`G<VEM<&QE)SL-"B`@("!V87(@)'!H
M87-E(#T@4$5!4E]405-+7U!!0TM!1T5!3D1)3E-404Q,.PT*("`@('9A<B`D
M7W)E<&QA8V5M96YT<SL-"@T*("`@("\J*@T*("`@("`J(%9A;&ED871E('1H
M92!R87<@>&UL(&%T('!A<G-I;F<M=&EM92X-"B`@("`@*B!`<&%R86T@4$5!
M4E]086-K86=E1FEL95]V,@T*("`@("`J($!P87)A;2!A<G)A>2!R87<L('!A
M<G-E9"!X;6P-"B`@("`@*B!`<&%R86T@4$5!4E]#;VYF:6<-"B`@("`@*B!`
M<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=F%L:61A=&58;6PH)'!K
M9RP@)'AM;"P@)B1C;VYF:6<L("1F:6QE6&UL*0T*("`@('L-"B`@("`@("`@
M:68@*"%I<W-E="@D>&UL6R=A='1R:6)S)UTI*2![#0H@("`@("`@("`@("!R
M971U<FX@87)R87DH4$5!4E]405-+7T524D]27TY/05144DE"4RD[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D>&UL6R=A='1R:6)S)UU;)W1Y
M<&4G72DI('L-"B`@("`@("`@("`@(')E='5R;B!A<G)A>2A014%27U1!4TM?
M15)23U)?34E34TE.1U]!5%1224(L("=T>7!E)RD[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"%I<W-E="@D>&UL6R=A='1R:6)S)UU;)W1O)UTI*2![#0H@
M("`@("`@("`@("!R971U<FX@87)R87DH4$5!4E]405-+7T524D]27TU)4U-)
M3D=?05144DE"+"`G=&\G*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES
M<V5T*"1X;6Q;)V%T=')I8G,G75LG9G)O;2==*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N(&%R<F%Y*%!%05)?5$%32U]%4E)/4E]-25-324Y'7T%45%))0BP@
M)V9R;VTG*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'AM;%LG871T<FEB
M<R==6R=T>7!E)UT@/3T@)W!E87(M8V]N9FEG)RD@>PT*("`@("`@("`@("`@
M:68@*"%I;E]A<G)A>2@D>&UL6R=A='1R:6)S)UU;)W1O)UTL("1C;VYF:6<M
M/F=E=$ME>7,H*2DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@87)R87DH
M4$5!4E]405-+7T524D]27U=23TY'7T%45%))0E]604Q512P@)W1O)RP@)'AM
M;%LG871T<FEB<R==6R=T;R==+`T*("`@("`@("`@("`@("`@("`@("`D8V]N
M9FEG+3YG971+97ES*"DI.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L
M<V5I9B`H)'AM;%LG871T<FEB<R==6R=T>7!E)UT@/3T@)W!H<"UC;VYS="<I
M('L-"B`@("`@("`@("`@(&EF("AD969I;F5D*"1X;6Q;)V%T=')I8G,G75LG
M=&\G72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y
M*%!%05)?5$%32U]%4E)/4E]74D].1U]!5%1224)?5D%,544L("=T;R<L("1X
M;6Q;)V%T=')I8G,G75LG=&\G72P-"B`@("`@("`@("`@("`@("`@("`@87)R
M87DH)W9A;&ED(%!(4"!C;VYS=&%N="<I*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?2!E;'-E:68@*"1X;6Q;)V%T=')I8G,G75LG='EP92==(#T]("=P
M86-K86=E+6EN9F\G*2![#0H@("`@("`@("`@("!I9B`H:6Y?87)R87DH)'AM
M;%LG871T<FEB<R==6R=T;R==+`T*("`@("`@("`@("`@("`@(&%R<F%Y*"=N
M86UE)RP@)W-U;6UA<GDG+"`G8VAA;FYE;"<L("=N;W1E<R<L("=E>'1E;F1S
M)RP@)V1E<V-R:7!T:6]N)RP-"B`@("`@("`@("`@("`@("`@("`@)W)E;&5A
M<V5?;F]T97,G+"`G;&EC96YS92<L("=R96QE87-E+6QI8V5N<V4G+"`G;&EC
M96YS92UU<FDG+`T*("`@("`@("`@("`@("`@("`@("`G=F5R<VEO;B<L("=A
M<&DM=F5R<VEO;B<L("=S=&%T92<L("=A<&DM<W1A=&4G+"`G<F5L96%S95]D
M871E)RP-"B`@("`@("`@("`@("`@("`@("`@)V1A=&4G+"`G=&EM92<I*2D@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R971U<FX@87)R87DH4$5!4E]4
M05-+7T524D]27U=23TY'7T%45%))0E]604Q512P@)W1O)RP@)'AM;%LG871T
M<FEB<R==6R=T;R==+`T*("`@("`@("`@("`@("`@("`@("!A<G)A>2@G;F%M
M92<L("=S=6UM87)Y)RP@)V-H86YN96PG+"`G;F]T97,G+"`G97AT96YD<R<L
M("=D97-C<FEP=&EO;B<L#0H@("`@("`@("`@("`@("`@("`@("=R96QE87-E
M7VYO=&5S)RP@)VQI8V5N<V4G+"`G<F5L96%S92UL:6-E;G-E)RP@)VQI8V5N
M<V4M=7)I)RP-"B`@("`@("`@("`@("`@("`@("`@)W9E<G-I;VXG+"`G87!I
M+79E<G-I;VXG+"`G<W1A=&4G+"`G87!I+7-T871E)RP@)W)E;&5A<V5?9&%T
M92<L#0H@("`@("`@("`@("`@("`@("`@("=D871E)RP@)W1I;64G*2D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!R
M971U<FX@87)R87DH4$5!4E]405-+7T524D]27U=23TY'7T%45%))0E]604Q5
M12P@)W1Y<&4G+"`D>&UL6R=A='1R:6)S)UU;)W1Y<&4G72P-"B`@("`@("`@
M("`@("`@("!A<G)A>2@G<&5A<BUC;VYF:6<G+"`G<&%C:V%G92UI;F9O)RP@
M)W!H<"UC;VYS="<I*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@=')U
M93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!);FET:6%L:7IE(&$@=&%S
M:R!I;G-T86YC92!W:71H('1H92!P87)A;65T97)S#0H@("`@("H@0'!A<F%M
M(&%R<F%Y(')A=RP@<&%R<V5D('AM;`T*("`@("`J($!P87)A;2!U;G5S960-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I;FET*"1X;6PL("1A='1R:6)S*0T*
M("`@('L-"B`@("`@("`@)'1H:7,M/E]R97!L86-E;65N=',@/2!I<W-E="@D
M>&UL6R=A='1R:6)S)UTI(#\@87)R87DH)'AM;"D@.B`D>&UL.PT*("`@('T-
M"@T*("`@("\J*@T*("`@("`J($1O(&$@<&%C:V%G92YX;6P@,2XP(')E<&QA
M8V5M96YT+"!W:71H(&%D9&ET:6]N86P@<&%C:V%G92UI;F9O(&9I96QD<R!A
M=F%I;&%B;&4-"B`@("`@*@T*("`@("`J(%-E92!V86QI9&%T95AM;"@I('-O
M=7)C92!F;W(@=&AE(&-O;7!L971E(&QI<W0@;V8@86QL;W=E9"!F:65L9',-
M"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V,7Q014%27U!A8VMA
M9V5&:6QE7W8R#0H@("`@("H@0'!A<F%M('-T<FEN9R!F:6QE(&-O;G1E;G1S
M#0H@("`@("H@0'!A<F%M('-T<FEN9R!T:&4@979E;G1U86P@9FEN86P@9FEL
M92!L;V-A=&EO;B`H:6YF;W)M871I;VYA;"!O;FQY*0T*("`@("`J($!R971U
M<FX@<W1R:6YG?&9A;'-E?%!%05)?17)R;W(@9F%L<V4@=&\@<VMI<"!T:&ES
M(&9I;&4L(%!%05)?17)R;W(@=&\@9F%I;`T*("`@("`J("`@("`@("`@*'5S
M92`D=&AI<RT^=&AR;W=%<G)O<BDL(&]T:&5R=VES92!R971U<FX@=&AE(&YE
M=R!C;VYT96YT<PT*("`@("`J+PT*("`@(&9U;F-T:6]N('-T87)T4V5S<VEO
M;B@D<&MG+"`D8V]N=&5N=',L("1D97-T*0T*("`@('L-"B`@("`@("`@)'-U
M8G-T7V9R;VT@/2`D<W5B<W1?=&\@/2!A<G)A>2@I.PT*("`@("`@("!F;W)E
M86-H("@D=&AI<RT^7W)E<&QA8V5M96YT<R!A<R`D82D@>PT*("`@("`@("`@
M("`@)&$@/2`D85LG871T<FEB<R==.PT*("`@("`@("`@("`@)'1O(#T@)R<[
M#0H@("`@("`@("`@("!I9B`H)&%;)W1Y<&4G72`]/2`G<&5A<BUC;VYF:6<G
M*2![#0H@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YI;G-T86QL<&AA<V4@
M/3T@4$5!4E]405-+7U!!0TM!1T4I('L-"B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!I9B`H)&%;)W1O)UT@/3T@)VUA<W1E<E]S97)V97(G*2![#0H@("`@
M("`@("`@("`@("`@("`@("1C:&%N(#T@)'1H:7,M/G)E9VES=')Y+3YG971#
M:&%N;F5L*"1P:V<M/F=E=$-H86YN96PH*2D[#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@A4$5!4CHZ:7-%<G)O<B@D8VAA;BDI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1T;R`]("1C:&%N+3YG971397)V97(H*3L-"B`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YL;V=G97(M/FQO9R@P+"`B)&1E<W0Z(&EN=F%L:60@<&5A
M<BUC;VYF:6<@<F5P;&%C96UE;G0Z("1A6W1O72(I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*"1T:&ES+3YC;VYF:6<M/FES1&5F:6YE9$QA>65R*"=F='`G
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@+R\@=')Y('1H92!R96UO
M=&4@8V]N9FEG(&9I;&4@9FER<W0-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1T;R`]("1T:&ES+3YC;VYF:6<M/F=E="@D85LG=&\G72P@)V9T<"<L("1P
M:V<M/F=E=$-H86YN96PH*2D[#0H@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-?;G5L;"@D=&\I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@=&AE;B!D969A=6QT('1O(&QO8V%L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1O(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"1A6R=T;R==
M+"!N=6QL+"`D<&MG+3YG971#:&%N;F5L*"DI.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1O(#T@)'1H:7,M/F-O;F9I9RT^9V5T
M*"1A6R=T;R==+"!N=6QL+"`D<&MG+3YG971#:&%N;F5L*"DI.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(&EF("AI<U]N=6QL*"1T;RDI('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/FQO9V=E<BT^;&]G*#`L("(D9&5S=#H@:6YV86QI9"!P96%R
M+6-O;F9I9R!R97!L86-E;65N=#H@)&%;=&]=(BD[#0H@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!](&5L<V5I9B`H)&%;)W1Y<&4G72`]/2`G<&AP+6-O;G-T)RD@
M>PT*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^:6YS=&%L;'!H87-E(#T]
M(%!%05)?5$%32U]004-+04=%*2![#0H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@:68@*&1E9FEN960H)&%;)W1O)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("1T;R`](&-O;G-T86YT*"1A6R=T;R==*3L-"B`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G9V5R
M+3YL;V<H,"P@(B1D97-T.B!I;G9A;&ED('!H<"UC;VYS="!R97!L86-E;65N
M=#H@)&%;=&]=(BD[#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@(&EF("@D="`]("1P:V<M/G!A8VMA9V5);F9O*"1A
M6R=T;R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&\@/2`D=#L-"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^;&]G9V5R+3YL;V<H,"P@(B1D97-T.B!I;G9A;&ED('!A8VMA9V4M
M:6YF;R!R97!L86-E;65N=#H@)&%;=&]=(BD[#0H@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES7VYU;&PH)'1O*2D@>PT*("`@
M("`@("`@("`@("`@("1S=6)S=%]F<F]M6UT@/2`D85LG9G)O;2==.PT*("`@
M("`@("`@("`@("`@("1S=6)S=%]T;UM=(#T@)'1O.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YL;V=G97(M/FQO9R@S+"`B
M9&]I;F<@(B`N('-I>F5O9B@D<W5B<W1?9G)O;2D@+@T*("`@("`@("`@("`@
M(B!S=6)S=&ET=71I;VXH<RD@9F]R("1D97-T(BD[#0H@("`@("`@(&EF("AS
M:7IE;V8H)'-U8G-T7V9R;VTI*2![#0H@("`@("`@("`@("`D8V]N=&5N=',@
M/2!S=')?<F5P;&%C92@D<W5B<W1?9G)O;2P@)'-U8G-T7W1O+"`D8V]N=&5N
M=',I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D8V]N=&5N=',[#0H@
M("`@?0T*?0T*/SX`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U1A<VLO56YI>&5O;"\`````````
M```````````````````````````````````````````````````````````P
M,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<T
M,``P,C$V-34`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O5&%S
M:R]5;FEX96]L+W)W+G!H<```````````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`S,S8W`#$P-3$U-#,S-S0P`#`R,S`R-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`T*+RHJ#0H@*B`\=&%S:W,Z
M=6YI>&5O;#X@+2!R96%D+W=R:71E('9E<G-I;VX-"B`J#0H@*B!02%`@=F5R
M<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I
M;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N
M<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B
M;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S
M96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P
M96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G
M($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW
M+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@
M*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@<G<N<&AP+'8@,2XT(#(P,#8O,#$O
M,#8@,#0Z-#<Z,S<@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@
M1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q,`T*("HO#0HO
M*BH-"B`J($)A<V4@8VQA<W,-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+U1A
M<VLO56YI>&5O;"YP:'`G.PT*+RHJ#0H@*B!!8G-T<F%C=',@=&AE('5N:7AE
M;VP@=&%S:R!X;6PN#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G
M92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G
M0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'
M<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!2
M96QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL
M86)L92!S:6YC92!296QE87-E(#$N-"XP83$P#0H@*B\-"F-L87-S(%!%05)?
M5&%S:U]5;FEX96]L7W)W(&5X=&5N9',@4$5!4E]487-K7U5N:7AE;VP-"GL-
M"B`@("!F=6YC=&EO;B!014%27U1A<VM?56YI>&5O;%]R=R@F)'!K9RP@)B1C
M;VYF:6<L("8D;&]G9V5R+"`D9FEL95AM;"D-"B`@("![#0H@("`@("`@('!A
M<F5N=#HZ4$5!4E]487-K7T-O;6UO;B@D8V]N9FEG+"`D;&]G9V5R+"!014%2
M7U1!4TM?4$%#2T%'12D[#0H@("`@("`@("1T:&ES+3Y?8V]N=&5N=',@/2`D
M9FEL95AM;#L-"B`@("`@("`@)'1H:7,M/E]P:V<@/2`F)'!K9SL-"B`@("`@
M("`@)'1H:7,M/E]P87)A;7,@/2!A<G)A>2@I.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N('9A;&ED871E*"D-"B`@("![#0H@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$YA;64H*0T*("`@('L-"B`@
M("`@("`@<F5T=7)N("=U;FEX96]L)SL-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!G9718;6PH*0T*("`@('L-"B`@("`@("`@<F5T=7)N("<G.PT*("`@('T-
M"GT-"C\^````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U1A<VLO56YI
M>&5O;"YP:'``````````````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3(R
M,0`Q,#4Q-30S,S<T,``P,C(S-C8`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`-"B\J*@T*("H@/'1A<VMS.G5N:7AE
M;VP^#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%
M3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S
M+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%52
M23H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)
M9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,
M:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H
M92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N
M;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@
M*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*
M("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@
M(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%5N
M:7AE;VPN<&AP+'8@,2XX(#(P,#8O,#$O,#8@,#0Z-#<Z,S<@8V5L;&]G($5X
M<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA
M9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@
M4F5L96%S92`Q+C0N,&$Q#0H@*B\-"B\J*@T*("H@0F%S92!C;&%S<PT*("HO
M#0IR97%U:7)E7V]N8V4@)U!%05(O5&%S:R]#;VUM;VXN<&AP)SL-"B\J*@T*
M("H@26UP;&5M96YT<R!T:&4@=6YI>"!L:6YE(&5N9&EN9W,@9FEL92!T87-K
M+@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*
M("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@
M(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT
M+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@
M4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S(%!%05)?5&%S:U]5;FEX96]L
M(&5X=&5N9',@4$5!4E]487-K7T-O;6UO;@T*>PT*("`@('9A<B`D='EP92`]
M("=S:6UP;&4G.PT*("`@('9A<B`D<&AA<V4@/2!014%27U1!4TM?4$%#2T%'
M13L-"B`@("!V87(@)%]R97!L86-E;65N=',[#0H-"B`@("`O*BH-"B`@("`@
M*B!686QI9&%T92!T:&4@<F%W('AM;"!A="!P87)S:6YG+71I;64N#0H@("`@
M("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B!`<&%R86T@
M87)R87D@<F%W+"!P87)S960@>&UL#0H@("`@("H@0'!A<F%M(%!%05)?0V]N
M9FEG#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N('9A
M;&ED871E6&UL*"1P:V<L("1X;6PL("8D8V]N9FEG+"`D9FEL95AM;"D-"B`@
M("![#0H@("`@("`@(&EF("@D>&UL("$]("<G*2![#0H@("`@("`@("`@("!R
M971U<FX@87)R87DH4$5!4E]405-+7T524D]27TE.5D%,240L("=N;R!A='1R
M:6)U=&5S(&%L;&]W960G*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!);FET:6%L:7IE(&$@
M=&%S:R!I;G-T86YC92!W:71H('1H92!P87)A;65T97)S#0H@("`@("H@0'!A
M<F%M(&%R<F%Y(')A=RP@<&%R<V5D('AM;`T*("`@("`J($!P87)A;2!U;G5S
M960-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I;FET*"1X;6PL("1A='1R:6)S
M*0T*("`@('L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!297!L86-E(&%L
M;"!L:6YE(&5N9&EN9W,@=VET:"!L:6YE(&5N9&EN9W,@8W5S=&]M:7IE9"!F
M;W(@=&AE(&-U<G)E;G0@3U,-"B`@("`@*@T*("`@("`J(%-E92!V86QI9&%T
M95AM;"@I('-O=7)C92!F;W(@=&AE(&-O;7!L971E(&QI<W0@;V8@86QL;W=E
M9"!F:65L9',-"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V,7Q0
M14%27U!A8VMA9V5&:6QE7W8R#0H@("`@("H@0'!A<F%M('-T<FEN9R!F:6QE
M(&-O;G1E;G1S#0H@("`@("H@0'!A<F%M('-T<FEN9R!T:&4@979E;G1U86P@
M9FEN86P@9FEL92!L;V-A=&EO;B`H:6YF;W)M871I;VYA;"!O;FQY*0T*("`@
M("`J($!R971U<FX@<W1R:6YG?&9A;'-E?%!%05)?17)R;W(@9F%L<V4@=&\@
M<VMI<"!T:&ES(&9I;&4L(%!%05)?17)R;W(@=&\@9F%I;`T*("`@("`J("`@
M("`@("`@*'5S92`D=&AI<RT^=&AR;W=%<G)O<BDL(&]T:&5R=VES92!R971U
M<FX@=&AE(&YE=R!C;VYT96YT<PT*("`@("`J+PT*("`@(&9U;F-T:6]N('-T
M87)T4V5S<VEO;B@D<&MG+"`D8V]N=&5N=',L("1D97-T*0T*("`@('L-"B`@
M("`@("`@)'1H:7,M/FQO9V=E<BT^;&]G*#,L(")R97!L86-I;F<@86QL(&QI
M;F4@96YD:6YG<R!W:71H(%Q<;B!I;B`D9&5S="(I.PT*("`@("`@("!R971U
M<FX@<')E9U]R97!L86-E*"(O7')<;GQ<;EQR?%QR?%QN+R(L(")<;B(L("1C
M;VYT96YT<RD[#0H@("`@?0T*?0T*/SX`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+U!%05(O5&%S:R]7:6YD;W=S96]L+P``````````
M`````````````````````````````````````````````````````#`P,#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S0P`#`R
M,C,V-``@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]487-K+U=I
M;F1O=W-E;VPO<G<N<&AP````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,T
M,30`,3`U,34T,S,W-#``,#(S-3(W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP#0HO*BH-"B`J(#QT87-K<SIW:6YD
M;W=S96]L/B`M(')E860O=W)I=&4@=F5R<VEO;@T*("H-"B`J(%!(4"!V97)S
M:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL
M92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS
M90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED
M92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV
M92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L
M92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E
M;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E
M87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@
M0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M
M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J
M($!V97)S:6]N("`@($-64SH@)$ED.B!R=RYP:'`L=B`Q+C0@,C`P-B\P,2\P
M-B`P-#HT-SHS-R!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&
M:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$P#0H@*B\-"B\J
M*@T*("H@0F%S92!C;&%S<PT*("HO#0IR97%U:7)E7V]N8V4@)U!%05(O5&%S
M:R]7:6YD;W=S96]L+G!H<"<[#0HO*BH-"B`J($%B<W1R86-T<R!T:&4@=VEN
M9&]W<V5O;"!T87-K('AM;"X-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P
M86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC
M96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@
M4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N
M("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A
M<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@
M879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,3`-"B`J+PT*8VQA<W,@
M4$5!4E]487-K7U=I;F1O=W-E;VQ?<G<@97AT96YD<R!014%27U1A<VM?5VEN
M9&]W<V5O;`T*>PT*("`@(&9U;F-T:6]N(%!%05)?5&%S:U]7:6YD;W=S96]L
M7W)W*"8D<&MG+"`F)&-O;F9I9RP@)B1L;V=G97(L("1F:6QE6&UL*0T*("`@
M('L-"B`@("`@("`@<&%R96YT.CI014%27U1A<VM?0V]M;6]N*"1C;VYF:6<L
M("1L;V=G97(L(%!%05)?5$%32U]004-+04=%*3L-"B`@("`@("`@)'1H:7,M
M/E]C;VYT96YT<R`]("1F:6QE6&UL.PT*("`@("`@("`D=&AI<RT^7W!K9R`]
M("8D<&MG.PT*("`@("`@("`D=&AI<RT^7W!A<F%M<R`](&%R<F%Y*"D[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@=F%L:61A=&4H*0T*("`@('L-"B`@("`@
M("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T3F%M
M92@I#0H@("`@>PT*("`@("`@("!R971U<FX@)W=I;F1O=W-E;VPG.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N(&=E=%AM;"@I#0H@("`@>PT*("`@("`@("!R
M971U<FX@)R<[#0H@("`@?0T*?0T*/SX`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O5&%S:R]7:6YD;W=S
M96]L+G!H<```````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U,C$U`#$P
M-3$U-#,S-S0P`#`R,S$P,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`T*+RHJ#0H@*B`\=&%S:W,Z=VEN9&]W<V5O
M;#X-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.
M4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N
M,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55))
M.@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF
M('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI
M8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE
M('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN
M970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J
M#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@
M*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@
M*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI
M8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@
M4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@5VEN
M9&]W<V5O;"YP:'`L=B`Q+C<@,C`P-B\P,2\P-B`P-#HT-SHS-R!C96QL;V<@
M17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC
M92!296QE87-E(#$N-"XP83$-"B`J+PT*+RHJ#0H@*B!"87-E(&-L87-S#0H@
M*B\-"G)E<75I<F5?;VYC92`G4$5!4B]487-K+T-O;6UO;BYP:'`G.PT*+RHJ
M#0H@*B!);7!L96UE;G1S('1H92!W:6YD;W=S(&QI;F4@96YD<VEN9W,@9FEL
M92!T87-K+@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@
M4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N
M;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-
M"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S
M93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@
M<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S(%!%05)?5&%S:U]7
M:6YD;W=S96]L(&5X=&5N9',@4$5!4E]487-K7T-O;6UO;@T*>PT*("`@('9A
M<B`D='EP92`]("=S:6UP;&4G.PT*("`@('9A<B`D<&AA<V4@/2!014%27U1!
M4TM?4$%#2T%'13L-"B`@("!V87(@)%]R97!L86-E;65N=',[#0H-"B`@("`O
M*BH-"B`@("`@*B!686QI9&%T92!T:&4@<F%W('AM;"!A="!P87)S:6YG+71I
M;64N#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@
M*B!`<&%R86T@87)R87D@<F%W+"!P87)S960@>&UL#0H@("`@("H@0'!A<F%M
M(%!%05)?0V]N9FEG#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U
M;F-T:6]N('9A;&ED871E6&UL*"1P:V<L("1X;6PL("8D8V]N9FEG+"`D9FEL
M95AM;"D-"B`@("![#0H@("`@("`@(&EF("@D>&UL("$]("<G*2![#0H@("`@
M("`@("`@("!R971U<FX@87)R87DH4$5!4E]405-+7T524D]27TE.5D%,240L
M("=N;R!A='1R:6)U=&5S(&%L;&]W960G*3L-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!);FET
M:6%L:7IE(&$@=&%S:R!I;G-T86YC92!W:71H('1H92!P87)A;65T97)S#0H@
M("`@("H@0'!A<F%M(&%R<F%Y(')A=RP@<&%R<V5D('AM;`T*("`@("`J($!P
M87)A;2!U;G5S960-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I;FET*"1X;6PL
M("1A='1R:6)S*0T*("`@('L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!2
M97!L86-E(&%L;"!L:6YE(&5N9&EN9W,@=VET:"!W:6YD;W=S(&QI;F4@96YD
M:6YG<PT*("`@("`J#0H@("`@("H@4V5E('9A;&ED871E6&UL*"D@<V]U<F-E
M(&9O<B!T:&4@8V]M<&QE=&4@;&ES="!O9B!A;&QO=V5D(&9I96QD<PT*("`@
M("`J($!P87)A;2!014%27U!A8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G949I
M;&5?=C(-"B`@("`@*B!`<&%R86T@<W1R:6YG(&9I;&4@8V]N=&5N=',-"B`@
M("`@*B!`<&%R86T@<W1R:6YG('1H92!E=F5N='5A;"!F:6YA;"!F:6QE(&QO
M8V%T:6]N("AI;F9O<FUA=&EO;F%L(&]N;'DI#0H@("`@("H@0')E='5R;B!S
M=')I;F=\9F%L<V5\4$5!4E]%<G)O<B!F86QS92!T;R!S:VEP('1H:7,@9FEL
M92P@4$5!4E]%<G)O<B!T;R!F86EL#0H@("`@("H@("`@("`@("`H=7-E("1T
M:&ES+3YT:')O=T5R<F]R*2P@;W1H97)W:7-E(')E='5R;B!T:&4@;F5W(&-O
M;G1E;G1S#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<W1A<G1397-S:6]N*"1P
M:V<L("1C;VYT96YT<RP@)&1E<W0I#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M;&]G9V5R+3YL;V<H,RP@(G)E<&QA8VEN9R!A;&P@;&EN92!E;F1I;F=S('=I
M=&@@7%QR7%QN(&EN("1D97-T(BD[#0H@("`@("`@(')E='5R;B!P<F5G7W)E
M<&QA8V4H(B]<<EQN?%QN7')\7')\7&XO(BP@(EQR7&XB+"`D8V]N=&5N=',I
M.PT*("`@('T-"GT-"C\^````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O4$5!4B]686QI9&%T92YP:'``````````````````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P-30V,3``,3`U,34T,S,W-#$`,#(Q-C`Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP#0HO*BH-"B`J(%!%05)?5F%L:61A=&4-"B`J#0H@*B!02%`@=F5R<VEO
M;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-
M"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M
M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@
M82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@
M=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD
M(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U
M(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R
M#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E
M879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P
M,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`
M=F5R<VEO;B`@("!#5E,Z("1)9#H@5F%L:61A=&4N<&AP+'8@,2XT-B`R,#`V
M+S`Q+S(S(#$W.C$V.C,U(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@
M:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@
M("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO
M#0HO*BHC0"L-"B`J($-O;G-T86YT<R!F;W(@:6YS=&%L;"!S=&%G90T*("HO
M#0ID969I;F4H)U!%05)?5D%,241!5$5?24Y35$%,3$E.1R<L(#$I.PT*9&5F
M:6YE*"=014%27U9!3$E$051%7U5.24Y35$%,3$E.1R<L(#(I.R`O+R!T:&ES
M(&ES(&YO="!B:70M;6%P<&5D(&QI:V4@=&AE(&]T:&5R<PT*9&5F:6YE*"=0
M14%27U9!3$E$051%7TY/4DU!3"<L(#,I.PT*9&5F:6YE*"=014%27U9!3$E$
M051%7T1/5TY,3T%$24Y')RP@-"D[("\O('1H:7,@:7,@;F]T(&)I="UM87!P
M960@;&EK92!T:&4@;W1H97)S#0ID969I;F4H)U!%05)?5D%,241!5$5?4$%#
M2T%'24Y')RP@-RD[#0HO*BHC0"TJ+PT*<F5Q=6ER95]O;F-E("=014%2+T-O
M;6UO;BYP:'`G.PT*<F5Q=6ER95]O;F-E("=014%2+U9A;&ED871O<B]014-,
M+G!H<"<[#0H-"B\J*@T*("H@5F%L:61A=&EO;B!C;&%S<R!F;W(@<&%C:V%G
M92YX;6P@+2!C:&%N;F5L+6QE=F5L(&%D=F%N8V5D('9A;&ED871I;VX-"B`J
M($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A
M=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C
M;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS
M92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@
M3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@
M*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!
M4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XT+C!A,0T*("HO#0IC;&%S<R!014%27U9A;&ED871E#0I[#0H@("`@
M=F%R("1P86-K86=E<F5G97@@/2!?4$5!4E]#3TU-3TY?4$%#2T%'15].04U%
M7U!214<[#0H@("`@+RHJ#0H@("`@("H@0'9A<B!014%27U!A8VMA9V5&:6QE
M7W8Q?%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B\-"B`@("!V87(@)%]P
M86-K86=E>&UL.PT*("`@("\J*@T*("`@("`J($!V87(@:6YT(&]N92!O9B!T
M:&4@4$5!4E]604Q)1$%415\J(&-O;G-T86YT<PT*("`@("`J+PT*("`@('9A
M<B`D7W-T871E(#T@4$5!4E]604Q)1$%415].3U)-04P[#0H@("`@+RHJ#0H@
M("`@("H@1F]R;6%T.B`H)V5R<F]R)R`]/B!A<G)A>2@G9FEE;&0G(#T^(&YA
M;64L("=R96%S;VXG(#T^(')E87-O;BDL("=W87)N:6YG)R`]/B!S86UE*0T*
M("`@("`J($!V87(@87)R87D-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@
M("`@*B\-"B`@("!V87(@)%]F86EL=7)E<R`](&%R<F%Y*"=E<G)O<B<@/3X@
M87)R87DH*2P@)W=A<FYI;F<G(#T^(&%R<F%Y*"DI.PT*#0H@("`@+RHJ#0H@
M("`@("H@3W9E<G)I9&4@=&AI<R!M971H;V0@=&\@:&%N9&QE('9A;&ED871I
M;VX@;V8@;F]R;6%L('!A8VMA9V4@;F%M97,-"B`@("`@*B!`<&%R86T@<W1R
M:6YG#0H@("`@("H@0')E='5R;B!B;V]L#0H@("`@("H@0&%C8V5S<R!P<F]T
M96-T960-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?=F%L:61086-K86=E3F%M
M92@D;F%M92D-"B`@("![#0H@("`@("`@(')E='5R;B`H8F]O;"D@<')E9U]M
M871C:"@G+UXG("X@)'1H:7,M/G!A8VMA9V5R96=E>"`N("<D+R<L("1N86UE
M*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG('!A
M8VMA9V4@;F%M92!T;R!V86QI9&%T90T*("`@("`J($!P87)A;2!S=')I;F<@
M;F%M92!O9B!C:&%N;F5L+7-P96-I9FEC('9A;&ED871I;VX@<&%C:V%G90T*
M("`@("`J($!F:6YA;`T*("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED4&%C
M:V%G94YA;64H)&YA;64L("1V86QI9&%T97!A8VMA9V5N86UE(#T@9F%L<V4I
M#0H@("`@>PT*("`@("`@("!I9B`H)'9A;&ED871E<&%C:V%G96YA;64I('L-
M"B`@("`@("`@("`@(&EF("AS=')T;VQO=V5R*"1N86UE*2`]/2!S=')T;VQO
M=V5R*"1V86QI9&%T97!A8VMA9V5N86UE*2D@>PT*("`@("`@("`@("`@("`@
M(')E='5R;B`H8F]O;"D@<')E9U]M871C:"@G+UY;82UZ02U:,"TY7UTK*#\Z
M7"Y;82UZ02U:,"TY7UTK*2HD+R<L("1N86UE*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/E]V86QI9%!A8VMA
M9V5.86UE*"1N86UE*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES
M('9A;&ED871E<R!A(&)U;F1L92!N86UE+"!A;F0@8G5N9&QE(&YA;65S(&UU
M<W0@8V]N9F]R;0T*("`@("`J('1O('1H92!014%2(&YA;6EN9R!C;VYV96YT
M:6]N+"!S;R!T:&4@;65T:&]D(&ES(&9I;F%L(&%N9"!S=&%T:6,N#0H@("`@
M("H@0'!A<F%M('-T<FEN9PT*("`@("`J($!F:6YA;`T*("`@("`J($!S=&%T
M:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9$=R;W5P3F%M92@D;F%M
M92D-"B`@("![#0H@("`@("`@(')E='5R;B`H8F]O;"D@<')E9U]M871C:"@G
M+UXG("X@7U!%05)?0T]-34].7U!!0TM!1T5?3D%-15]04D5'("X@)R0O)RP@
M)&YA;64I.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($1E=&5R;6EN92!W
M:&5T:&5R("1S=&%T92!R97!R97-E;G1S(&$@=F%L:60@<W1A8FEL:71Y(&QE
M=F5L#0H@("`@("H@0'!A<F%M('-T<FEN9PT*("`@("`J($!R971U<FX@8F]O
M;`T*("`@("`J($!S=&%T:6,-"B`@("`@*B!`9FEN86P-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!V86QI9%-T871E*"1S=&%T92D-"B`@("![#0H@("`@("`@
M(')E='5R;B!I;E]A<G)A>2@D<W1A=&4L(&%R<F%Y*"=S;F%P<VAO="<L("=D
M979E;"<L("=A;'!H82<L("=B971A)RP@)W-T86)L92<I*3L-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*B!'970@82!L:7-T(&]F('9A;&ED('-T86)I;&ET
M>2!L979E;',-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("H@0'-T871I
M8PT*("`@("`J($!F:6YA;`T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%9A
M;&ED4W1A=&5S*"D-"B`@("![#0H@("`@("`@(')E='5R;B!A<G)A>2@G<VYA
M<'-H;W0G+"`G9&5V96PG+"`G86QP:&$G+"`G8F5T82<L("=S=&%B;&4G*3L-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!$971E<FUI;F4@=VAE=&AE<B!A
M('9E<G-I;VX@:7,@82!P<F]P97)L>2!F;W)M871T960@=F5R<VEO;B!N=6UB
M97(@=&AA="!C86X@8F4@=7-E9`T*("`@("`J(&)Y('9E<G-I;VY?8V]M<&%R
M90T*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B!`<F5T=7)N(&)O;VP-
M"B`@("`@*B!`<W1A=&EC#0H@("`@("H@0&9I;F%L#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@=F%L:61697)S:6]N*"1V97(I#0H@("`@>PT*("`@("`@("!R
M971U<FX@*&)O;VPI('!R96=?;6%T8V@H4$5!4E]#3TU-3TY?4$%#2T%'15]6
M15)324].7U!214<L("1V97(I.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J
M($!P87)A;2!014%27U!A8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G949I;&5?
M=C(-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971086-K86=E1FEL92@F)'!F
M*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E>&UL(#T@)B1P9CL-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!?861D1F%I;'5R92@D9FEE;&0L("1R96%S
M;VXI#0H@("`@>PT*("`@("`@("`D=&AI<RT^7V9A:6QU<F5S6R=E<G)O<G,G
M75M=(#T@87)R87DH)V9I96QD)R`]/B`D9FEE;&0L("=R96%S;VXG(#T^("1R
M96%S;VXI.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!A8V-E<W,@<')I
M=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]A9&1787)N:6YG*"1F:65L
M9"P@)')E87-O;BD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?9F%I;'5R97-;
M)W=A<FYI;F=S)UU;72`](&%R<F%Y*"=F:65L9"<@/3X@)&9I96QD+"`G<F5A
M<V]N)R`]/B`D<F5A<V]N*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971&
M86EL=7)E<R@I#0H@("`@>PT*("`@("`@("`D9F%I;'5R97,@/2`D=&AI<RT^
M7V9A:6QU<F5S.PT*("`@("`@("`D=&AI<RT^7V9A:6QU<F5S(#T@87)R87DH
M)W=A<FYI;F=S)R`]/B!A<G)A>2@I+"`G97)R;W)S)R`]/B!A<G)A>2@I*3L-
M"B`@("`@("`@<F5T=7)N("1F86EL=7)E<SL-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!`<&%R86T@:6YT(&]N92!O9B!T:&4@4$5!4E]604Q)1$%415\J
M(&-O;G-T86YT<PT*("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED871E*"1S
M=&%T92`](&YU;&PI#0H@("`@>PT*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?<&%C:V%G97AM;"DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)'-T871E("$]/2!N=6QL*2![#0H@
M("`@("`@("`@("`D=&AI<RT^7W-T871E(#T@)'-T871E.PT*("`@("`@("!]
M#0H@("`@("`@("1T:&ES+3Y?9F%I;'5R97,@/2!A<G)A>2@G=V%R;FEN9W,G
M(#T^(&%R<F%Y*"DL("=E<G)O<G,G(#T^(&%R<F%Y*"DI.PT*("`@("`@("`D
M=&AI<RT^=F%L:61A=&5086-K86=E3F%M92@I.PT*("`@("`@("`D=&AI<RT^
M=F%L:61A=&5697)S:6]N*"D[#0H@("`@("`@("1T:&ES+3YV86QI9&%T94UA
M:6YT86EN97)S*"D[#0H@("`@("`@("1T:&ES+3YV86QI9&%T941A=&4H*3L-
M"B`@("`@("`@)'1H:7,M/G9A;&ED871E4W5M;6%R>2@I.PT*("`@("`@("`D
M=&AI<RT^=F%L:61A=&5$97-C<FEP=&EO;B@I.PT*("`@("`@("`D=&AI<RT^
M=F%L:61A=&5,:6-E;G-E*"D[#0H@("`@("`@("1T:&ES+3YV86QI9&%T94YO
M=&5S*"D[#0H@("`@("`@(&EF("@D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%!A
M8VMA9V5X;6Q697)S:6]N*"D@/3T@)S$N,"<I('L-"B`@("`@("`@("`@("1T
M:&ES+3YV86QI9&%T95-T871E*"D[#0H@("`@("`@("`@("`D=&AI<RT^=F%L
M:61A=&5&:6QE;&ES="@I.PT*("`@("`@("!](&5L<V5I9B`H)'1H:7,M/E]P
M86-K86=E>&UL+3YG971086-K86=E>&UL5F5R<VEO;B@I(#T]("<R+C`G*2![
M#0H@("`@("`@("`@("`D=&AI<RT^=F%L:61A=&54:6UE*"D[#0H@("`@("`@
M("`@("`D=&AI<RT^=F%L:61A=&53=&%B:6QI='DH*3L-"B`@("`@("`@("`@
M("1T:&ES+3YV86QI9&%T941E<',H*3L-"B`@("`@("`@("`@("1T:&ES+3YV
M86QI9&%T94UA:6Y&:6QE;&ES="@I.PT*("`@("`@("`@("`@)'1H:7,M/G9A
M;&ED871E4F5L96%S949I;&5L:7-T*"D[#0H@("`@("`@("`@("`O+R1T:&ES
M+3YV86QI9&%T94=L;V)A;%1A<VMS*"D[#0H@("`@("`@("`@("`D=&AI<RT^
M=F%L:61A=&5#:&%N9V5L;V<H*3L-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@(2@H8F]O;"D@8V]U;G0H)'1H:7,M/E]F86EL=7)E<ULG97)R;W)S)UTI
M*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`86-C97-S('!R;W1E8W1E
M9`T*("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED871E4&%C:V%G94YA;64H
M*0T*("`@('L-"B`@("`@("`@:68@*"1T:&ES+3Y?<W1A=&4@/3T@4$5!4E]6
M04Q)1$%415]004-+04=)3D<@?'P-"B`@("`@("`@("`@("`@)'1H:7,M/E]S
M=&%T92`]/2!014%27U9!3$E$051%7TY/4DU!3"D@>PT*("`@("`@("`@("`@
M:68@*"1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T4&%C:V%G97AM;%9E<G-I;VXH
M*2`]/2`G,BXP)R`F)@T*("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K
M86=E>&UL+3YG971%>'1E;F1S*"DI('L-"B`@("`@("`@("`@("`@("`D=F5R
M<VEO;B`]("1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T5F5R<VEO;B@I("X@)R<[
M#0H@("`@("`@("`@("`@("`@)&YA;64@/2`D=&AI<RT^7W!A8VMA9V5X;6PM
M/F=E=%!A8VMA9V4H*3L-"B`@("`@("`@("`@("`@("`D=&5S="`](&%R<F%Y
M7W-H:69T*"1A(#T@97AP;&]D92@G+B<L("1V97)S:6]N*2D[#0H@("`@("`@
M("`@("`@("`@:68@*"1T97-T(#T]("<P)RD@>PT*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@)'9L96X@/2!S=')L96XH)'1E<W0I.PT*("`@("`@("`@("`@
M("`@("1M86IV97(@/2!S=6)S='(H)&YA;64L('-T<FQE;B@D;F%M92D@+2`D
M=FQE;BD[#0H@("`@("`@("`@("`@("`@=VAI;&4@*"1M86IV97(@)B8@(6ES
M7VYU;65R:6,H)&UA:G9E<GLP?2DI('L-"B`@("`@("`@("`@("`@("`@("`@
M)&UA:G9E<B`]('-U8G-T<B@D;6%J=F5R+"`Q*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@:68@*"1M86IV97(@(3T@)'1E<W0I('L-
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1787)N:6YG*"=P86-K
M86=E)RP@(G!A8VMA9V4@)&YA;64@97AT96YD<R!P86-K86=E("(@+@T*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E>&UL+3YG971%
M>'1E;F1S*"D@+B`G(&%N9"!S;R!T:&4@;F%M92!S:&]U;&0@)R`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`G:&%V92!A('!O<W1F:7@@97%U86P@=&\@
M=&AE(&UA:F]R('9E<G-I;VX@;&EK92`B)R`N#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=$5X=&5N9',H*2`N("1T
M97-T("X@)R(G*3L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[
M#0H@("`@("`@("`@("`@("`@?2!E;'-E:68@*'-U8G-T<B@D;F%M92P@,"P@
M<W1R;&5N*"1N86UE*2`M("1V;&5N*2`A/0T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T17AT96YD<R@I*2![
M#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861D5V%R;FEN9R@G<&%C
M:V%G92<L(")P86-K86=E("1N86UE(&5X=&5N9',@<&%C:V%G92`B("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T
M17AT96YD<R@I("X@)R!A;F0@<V\@=&AE(&YA;64@;75S="`G("X-"B`@("`@
M("`@("`@("`@("`@("`@("`@("=B92!A;B!E>'1E;G-I;VX@;&EK92`B)R`N
M("1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T17AT96YD<R@I("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1T97-T("X@)R(G*3L-"B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@A)'1H:7,M/G9A;&ED
M4&%C:V%G94YA;64H)'1H:7,M/E]P86-K86=E>&UL+3YG971086-K86=E*"DI
M*2![#0H@("`@("`@("`@("`D=&AI<RT^7V%D9$9A:6QU<F4H)VYA;64G+"`G
M<&%C:V%G92!N86UE("(G("X-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M8VMA9V5X;6PM/F=E=%!A8VMA9V4H*2`N("<B(&ES(&EN=F%L:60G*3L-"B`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@('T-"@T*
M("`@("\J*@T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@=F%L:61A=&5697)S:6]N*"D-"B`@("![#0H@("`@("`@
M(&EF("@D=&AI<RT^7W-T871E("$](%!%05)?5D%,241!5$5?4$%#2T%'24Y'
M*2![#0H@("`@("`@("`@("!I9B`H(21T:&ES+3YV86QI9%9E<G-I;VXH)'1H
M:7,M/E]P86-K86=E>&UL+3YG971697)S:6]N*"DI*2![#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]A9&1&86EL=7)E*"=V97)S:6]N)RP-"B`@("`@("`@
M("`@("`@("`@("`@)TEN=F%L:60@=F5R<VEO;B!N=6UB97(@(B<@+B`D=&AI
M<RT^7W!A8VMA9V5X;6PM/F=E=%9E<G-I;VXH*2`N("<B)RD[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-
M"B`@("`@("`@)'9E<G-I;VX@/2`D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%9E
M<G-I;VXH*3L-"B`@("`@("`@)'9E<G-I;VYC;VUP;VYE;G1S(#T@97AP;&]D
M92@G+B<L("1V97)S:6]N*3L-"B`@("`@("`@:68@*&-O=6YT*"1V97)S:6]N
M8V]M<&]N96YT<RD@(3T@,RD@>PT*("`@("`@("`@("`@)'1H:7,M/E]A9&17
M87)N:6YG*"=V97)S:6]N)RP-"B`@("`@("`@("`@("`@("`G02!V97)S:6]N
M(&YU;6)E<B!S:&]U;&0@:&%V92`S(&1E8VEM86QS("AX+GDN>BDG*3L-"B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@("1N
M86UE(#T@)'1H:7,M/E]P86-K86=E>&UL+3YG971086-K86=E*"D[#0H@("`@
M("`@("\O('9E<G-I;VX@;75S="!B92!B87-E9"!U<&]N('-T871E#0H@("`@
M("`@('-W:71C:"`H)'1H:7,M/E]P86-K86=E>&UL+3YG9713=&%T92@I*2![
M#0H@("`@("`@("`@("!C87-E("=S;F%P<VAO="<@.@T*("`@("`@("`@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@8V%S92`G9&5V96PG(#H-
M"B`@("`@("`@("`@("`@("!I9B`H)'9E<G-I;VYC;VUP;VYE;G1S6S!=("X@
M)V$G(#T]("<P82<I('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D
M=F5R<VEO;F-O;7!O;F5N='-;,%T@/3T@,"D@>PT*("`@("`@("`@("`@("`@
M("`@("`D=F5R<VEO;F-O;7!O;F5N='-;,%T@/2`G,"<[#0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?861D5V%R;FEN9R@G=F5R<VEO;B<L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`G=F5R<VEO;B`B)R`N("1V97)S:6]N("X@
M)R(@<VAO=6QD(&)E("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@(&EM
M<&QO9&4H)RXG("PD=F5R<VEO;F-O;7!O;F5N=',I("X@)R(G*3L-"B`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V%D9%=A<FYI;F<H)W9E<G-I;VXG+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@)W!A8VMA9V5S('=I=&@@9&5V96P@<W1A8FEL:71Y(&UU<W0@8F4@
M/"!V97)S:6]N(#$N,"XP)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("!C87-E("=A;'!H82<@.@T*("`@("`@("`@("`@8V%S92`G
M8F5T82<@.@T*("`@("`@("`@("`@("`@("\O(&-H96-K(&9O<B!A('!A8VMA
M9V4@=&AA="!E>'1E;F1S(&$@<&%C:V%G92P-"B`@("`@("`@("`@("`@("`O
M+R!L:6ME($9O;R!A;F0@1F]O,@T*("`@("`@("`@("`@("`@(&EF("@D=&AI
M<RT^7W-T871E(#T](%!%05)?5D%,241!5$5?4$%#2T%'24Y'*2![#0H@("`@
M("`@("`@("`@("`@("`@(&EF("AS=6)S='(H)'9E<G-I;VYC;VUP;VYE;G1S
M6S)=+"`Q+"`R*2`]/2`G<F,G*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V%D9$9A:6QU<F4H)W9E<G-I;VXG+"`G4F5L96%S92!#86YD
M:61A=&4@=F5R<VEO;G,@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VUU<W0@:&%V92!C87!I=&%L(%)#+"!N;W0@;&]W97(M8V%S92!R8R<I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&EF("@A)'1H:7,M/E]P86-K86=E>&UL+3YG971%>'1E;F1S
M*"DI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1V97)S:6]N8V]M<&]N
M96YT<ULP72`]/2`G,2<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@D=F5R<VEO;F-O;7!O;F5N='-;,EU[,'T@/3T@)S`G*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"1V97)S:6]N8V]M<&]N96YT<ULR
M72`]/2`G,"<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+R\@=F5R<VEO;B`Q+BHN,#`P,`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V%D9%=A<FYI;F<H)W9E<G-I;VXG+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9E<G-I;VX@,2XG("X@
M)'9E<G-I;VYC;VUP;VYE;G1S6S%=("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G+C`@<')O8F%B;'D@<VAO=6QD(&YO="!B
M92!A;'!H82!O<B!B971A)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T@96QS96EF("AS=')L96XH)'9E<G-I;VYC;VUP;VYE;G1S6S)=*2`^
M(#$I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@=F5R
M<VEO;B`Q+BHN,%)#,2!O<B`Q+BHN,&)E=&$R-"!E=&,N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("\O('9E<G-I;VX@,2XJ+C`-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1787)N:6YG*"=V97)S
M:6]N)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V
M97)S:6]N(#$N)R`N("1V97)S:6]N8V]M<&]N96YT<ULQ72`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)RXP('!R;V)A8FQY
M('-H;W5L9"!N;W0@8F4@86QP:&$@;W(@8F5T82<I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M861D5V%R;FEN9R@G=F5R<VEO;B<L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=B=6=F:7@@=F5R<VEO;G,@*#$N,RYX('=H97)E('@@/B`P
M*2!P<F]B86)L>2!S:&]U;&0@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=N;W0@8F4@86QP:&$@;W(@8F5T82<I.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M)'9E<G-I;VYC;VUP;VYE;G1S6S!=("$]("<P)RD@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]A9&1787)N:6YG*"=V97)S:6]N)RP-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G;6%J;W(@=F5R<VEO;G,@9W)E
M871E<B!T:&%N(#$@87)E(&YO="!A;&QO=V5D(&9O<B!P86-K86=E<R`G("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=VET:&]U="!A;B`\97AT
M96YD<SX@=&%G(&]R(&%N(&ED96YT:6-A;"!P;W-T9FEX("AF;V\R('8R+C`N
M,"DG*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF
M("@D=F5R<VEO;F-O;7!O;F5N='-;,%T@+B`G82<@/3T@)S!A)RD@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"1V97)S:6]N
M8V]M<&]N96YT<ULP72`]/2`P*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D=F5R<VEO;F-O;7!O;F5N='-;,%T@/2`G,"<[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V%D9%=A<FYI;F<H)W9E<G-I;VXG+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=V97)S:6]N("(G("X@)'9E<G-I
M;VX@+B`G(B!S:&]U;&0@8F4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EM<&QO9&4H)RXG("PD=F5R<VEO;F-O;7!O;F5N=',I("X@)R(G
M*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@("`@("1V;&5N(#T@<W1R;&5N*"1V
M97)S:6]N8V]M<&]N96YT<ULP72`N("<G*3L-"B`@("`@("`@("`@("`@("`@
M("`@)&UA:G9E<B`]('-U8G-T<B@D;F%M92P@<W1R;&5N*"1N86UE*2`M("1V
M;&5N*3L-"B`@("`@("`@("`@("`@("`@("`@=VAI;&4@*"1M86IV97(@)B8@
M(6ES7VYU;65R:6,H)&UA:G9E<GLP?2DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1M86IV97(@/2!S=6)S='(H)&UA:G9E<BP@,2D[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"@D=F5R
M<VEO;F-O;7!O;F5N='-;,%T@(3T@,"D@)B8@)&UA:G9E<B`A/2`D=F5R<VEO
M;F-O;7!O;F5N='-;,%TI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?861D5V%R;FEN9R@G=F5R<VEO;B<L("=F:7)S="!V97)S:6]N(&YU
M;6)E<B`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9E<G-I
M;VYC;VUP;VYE;G1S6S!=("X@)R(@;75S="!M871C:"!T:&4@<&]S=&9I>"!O
M9B`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&%C:V%G92!N
M86UE("(G("X@)&YA;64@+B`G(B`H)R`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&UA:G9E<B`N("<I)RD[#0H@("`@("`@("`@("`@("`@("`@
M("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("!I9B`H)'9E<G-I;VYC;VUP;VYE;G1S6S!=(#T]
M("1M86IV97(I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D=F5R
M<VEO;F-O;7!O;F5N='-;,EU[,'T@/3T@)S`G*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"1V97)S:6]N8V]M<&]N96YT<ULR72`]/2`G
M,"<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@=F5R
M<VEO;B`R+BHN,#`P,`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V%D9%=A<FYI;F<H)W9E<G-I;VXG+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(G9E<G-I;VX@)&UA:G9E<BXB("X@
M)'9E<G-I;VYC;VUP;VYE;G1S6S%=("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G+C`@<')O8F%B;'D@<VAO=6QD(&YO="!B
M92!A;'!H82!O<B!B971A)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H<W1R;&5N*"1V97)S:6]N8V]M<&]N96YT<ULR72D@
M/B`Q*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O('9E
M<G-I;VX@,BXJ+C!20S$@;W(@,BXJ+C!B971A,C0@971C+@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`O+R!V97)S:6]N(#(N*BXP#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861D5V%R;FEN9R@G=F5R
M<VEO;B<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B
M=F5R<VEO;B`D;6%J=F5R+B(@+B`D=F5R<VEO;F-O;7!O;F5N='-;,5T@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<N,"!C
M86YN;W0@8F4@86QP:&$@;W(@8F5T82<I.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861D5V%R
M;FEN9R@G=F5R<VEO;B<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(")B=6=F:7@@=F5R<VEO;G,@*"1M86IV97(N>"YY('=H97)E('D@/B`P
M*2!S:&]U;&0@(B`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=N;W0@8F4@86QP:&$@;W(@8F5T82<I.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'9E<G-I;VYC
M;VUP;VYE;G1S6S!=("$]("<P)RD@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]A9&1787)N:6YG*"=V97)S:6]N)RP-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`B;VYL>2!V97)S:6]N<R`P+G@N>2!A;F0@)&UA
M:G9E<BYX+GD@87)E(&%L;&]W960@9F]R(&%L<&AA+V)E=&$@<F5L96%S97,B
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@D
M=F5R<VEO;F-O;7!O;F5N='-;,%T@+B`G82<@/3T@)S!A)RD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"1V97)S:6]N8V]M
M<&]N96YT<ULP72`]/2`P*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M=F5R<VEO;F-O;7!O;F5N='-;,%T@/2`G,"<[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V%D9%=A<FYI;F<H)W9E<G-I;VXG+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=V97)S:6]N("(G("X@)'9E<G-I;VX@
M+B`G(B!S:&]U;&0@8F4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EM<&QO9&4H)RXG("PD=F5R<VEO;F-O;7!O;F5N=',I("X@)R(G*3L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("`@("`@8V%S92`G<W1A8FQE)R`Z#0H@("`@("`@("`@("`@
M("`@:68@*"1V97)S:6]N8V]M<&]N96YT<ULP72`]/2`G,"<I('L-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1787)N:6YG*"=V97)S:6]N)RP@
M)W9E<G-I;VYS(&QE<W,@=&AA;B`Q+C`N,"!C86YN;W0@)R`N#0H@("`@("`@
M("`@("`@("`@("`@("=B92!S=&%B;&4G*3L-"B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(&EF("@A:7-?;G5M97)I8R@D=F5R<VEO;F-O;7!O;F5N='-;,ETI
M*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7&0K
M*')C?&%\86QP:&%\8GQB971A*5QD*B]I)RP-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'9E<G-I;VYC;VUP;VYE;G1S6S)=*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1787)N:6YG*"=V97)S:6]N)RP@
M)W9E<G-I;VX@(B<@+B`D=F5R<VEO;B`N("<B(&]R(&%N>2`G("X-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G4D,O8F5T82]A;'!H82!V97)S:6]N
M(&-A;FYO="!B92!S=&%B;&4G*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("\O(&-H96-K(&9O<B!A('!A
M8VMA9V4@=&AA="!E>'1E;F1S(&$@<&%C:V%G92P-"B`@("`@("`@("`@("`@
M("`O+R!L:6ME($9O;R!A;F0@1F]O,@T*("`@("`@("`@("`@("`@(&EF("@D
M=&AI<RT^7W!A8VMA9V5X;6PM/F=E=$5X=&5N9',H*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D=FQE;B`]('-T<FQE;B@D=F5R<VEO;F-O;7!O;F5N='-;
M,%T@+B`G)RD[#0H@("`@("`@("`@("`@("`@("`@("1M86IV97(@/2!S=6)S
M='(H)&YA;64L('-T<FQE;B@D;F%M92D@+2`D=FQE;BD[#0H@("`@("`@("`@
M("`@("`@("`@('=H:6QE("@D;6%J=F5R("8F("%I<U]N=6UE<FEC*"1M86IV
M97)[,'TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D;6%J=F5R(#T@
M<W5B<W1R*"1M86IV97(L(#$I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@(&EF("@H)'9E<G-I;VYC;VUP;VYE;G1S6S!=
M("$](#`I("8F("1M86IV97(@(3T@)'9E<G-I;VYC;VUP;VYE;G1S6S!=*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9%=A<FYI;F<H
M)W9E<G-I;VXG+"`G9FER<W0@=F5R<VEO;B!N=6UB97(@(B<@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1V97)S:6]N8V]M<&]N96YT<ULP72`N
M("<B(&UU<W0@;6%T8V@@=&AE('!O<W1F:7@@;V8@)R`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W!A8VMA9V4@;F%M92`B)R`N("1N86UE("X@
M)R(@*"<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M86IV97(@
M+B`G*2<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!](&5L
M<V5I9B`H)'9E<G-I;VYC;VUP;VYE;G1S6S!=(#X@,2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V%D9%=A<FYI;F<H)W9E<G-I;VXG+"`G;6%J
M;W(@=F5R<VEO;B!X(&EN('@N>2YZ(&UA>2!N;W0@8F4@9W)E871E<B!T:&%N
M("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)S$@9F]R(&%N>2!P86-K
M86=E('1H870@9&]E<R!N;W0@:&%V92!A;B`\97AT96YD<SX@=&%G)RD[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!D969A=6QT(#H-
M"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!B
M<F5A:SL-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J($!A
M8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=F%L:61A
M=&5-86EN=&%I;F5R<R@I#0H@("`@>PT*("`@("`@("`O+R!M86EN=&%I;F5R
M<R!C86X@;VYL>2!B92!T<G5L>2!V86QI9&%T960@<V5R=F5R+7-I9&4@9F]R
M(&UO<W0@8VAA;FYE;',-"B`@("`@("`@+R\@8G5T(&%L;&]W('1H:7,@8W5S
M=&]M:7IA=&EO;B!F;W(@=&AO<V4@=VAO('=I<V@@:70-"B`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0&%C8V5S<R!P
M<F]T96-T960-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9&%T941A=&4H
M*0T*("`@('L-"B`@("`@("`@:68@*"1T:&ES+3Y?<W1A=&4@/3T@4$5!4E]6
M04Q)1$%415].3U)-04P@?'P-"B`@("`@("`@("`@("`@)'1H:7,M/E]S=&%T
M92`]/2!014%27U9!3$E$051%7U!!0TM!1TE.1RD@>PT*("`@("`@("`@("`@
M:68@*"%P<F5G7VUA=&-H*"<O7&1<9%QD7&1<+5QD7&1<+5QD7&0O)RP-"B`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T1&%T92@I
M*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?861D1F%I;'5R92@G9&%T
M92<L("=I;G9A;&ED(')E;&5A<V4@9&%T92`B)R`N#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T1&%T92@I("X@)R(G*3L-
M"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!I9B`H<W1R=&]T:6UE*"1T:&ES+3Y?<&%C:V%G97AM
M;"T^9V5T1&%T92@I*2`]/2`M,2D@>PT*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?861D1F%I;'5R92@G9&%T92<L("=I;G9A;&ED(')E;&5A<V4@9&%T92`B
M)R`N#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G97AM;"T^
M9V5T1&%T92@I("X@)R(G*3L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]S
M=&%T92`]/2!014%27U9!3$E$051%7U!!0TM!1TE.1R`F)@T*("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P86-K86=E>&UL+3YG971$871E*"D@(3T@9&%T
M92@G62UM+60G*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?861D5V%R
M;FEN9R@G9&%T92<L("=296QE87-E($1A=&4@(B<@+@T*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=$1A=&4H*2`N("<B(&ES
M(&YO="!T;V1A>2<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!A
M8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=F%L:61A
M=&54:6UE*"D-"B`@("![#0H@("`@("`@(&EF("@A)'1H:7,M/E]P86-K86=E
M>&UL+3YG9714:6UE*"DI('L-"B`@("`@("`@("`@("\O(&1E9F%U;'0@;V8@
M;F\@=&EM92!V86QU92!S970-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*
M("`@("`@("!]#0H@("`@("`@("\O('!A8VMA9V5R(&%U=&]M871I8V%L;'D@
M<V5T<R!T:6UE+"!S;R!O;FQY('9A;&ED871E(&EF#0H@("`@("`@("\O('!E
M87(@=F%L:61A=&4@:7,@8V%L;&5D#0H@("`@("`@(&EF("@D=&AI<RT^7W-T
M871E(#T@4$5!4E]604Q)1$%415].3U)-04PI('L-"B`@("`@("`@("`@(&EF
M("@A<')E9U]M871C:"@G+UQD7&0Z7&1<9#I<9%QD+R<L#0H@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%1I;64H*2DI('L-"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V%D9$9A:6QU<F4H)W1I;64G+"`G:6YV
M86QI9"!R96QE87-E('1I;64@(B<@+@T*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%1I;64H*2`N("<B)RD[#0H@("`@("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@:68@*'-T<G1O=&EM92@D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%1I
M;64H*2D@/3T@+3$I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9$9A
M:6QU<F4H)W1I;64G+"`G:6YV86QI9"!R96QE87-E('1I;64@(B<@+@T*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%1I;64H
M*2`N("<B)RD[#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*
M("`@('T-"@T*("`@("\J*@T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@=F%L:61A=&53=&%T92@I#0H@("`@>PT*
M("`@("`@("`O+R!T:&ES(&ES('1H92!C;&]S97-T('1O(")F:6YA;"(@<&AP
M-"!C86X@9V5T#0H@("`@("`@(&EF("@A4$5!4E]686QI9&%T93HZ=F%L:613
M=&%T92@D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%-T871E*"DI*2![#0H@("`@
M("`@("`@("!I9B`H<W1R=&]L;W=E<B@D=&AI<RT^7W!A8VMA9V5X;6PM/F=E
M=%-T871E*"D@/3T@)W)C)RDI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M7V%D9$9A:6QU<F4H)W-T871E)RP@)U)#(&ES(&YO="!A('-T871E+"!I="!I
M<R!A('9E<G-I;VX@)R`N#0H@("`@("`@("`@("`@("`@("`@("=P;W-T9FEX
M+"!U<V4@)R`N("1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T5F5R<VEO;B@I("X@
M)U)#,2P@<W1A=&4@8F5T82<I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@)'1H:7,M/E]A9&1&86EL=7)E*"=S=&%T92<L("=I;G9A;&ED(')E;&5A
M<V4@<W1A=&4@(B<@+@T*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G
M97AM;"T^9V5T4W1A=&4H*2`N("<B+"!M=7-T(&)E(&]N92!O9CH@)R`N#0H@
M("`@("`@("`@("`@("`@:6UP;&]D92@G+"`G+"!014%27U9A;&ED871E.CIG
M971686QI9%-T871E<R@I*2D[#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!V86QI9&%T95-T86)I;&ET>2@I#0H@("`@>PT*("`@("`@
M("`D<F5T(#T@=')U93L-"B`@("`@("`@)'!A8VMA9V5S=&%B:6QI='D@/2`D
M=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%-T871E*"D[#0H@("`@("`@("1A<&ES
M=&%B:6QI='D@/2`D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%-T871E*"=A<&DG
M*3L-"B`@("`@("`@:68@*"%014%27U9A;&ED871E.CIV86QI9%-T871E*"1P
M86-K86=E<W1A8FEL:71Y*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]A9&1&
M86EL=7)E*"=S=&%T92<L("=I;G9A;&ED(')E;&5A<V4@<W1A8FEL:71Y("(G
M("X-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%-T
M871E*"D@+B`G(BP@;75S="!B92!O;F4@;V8Z("<@+@T*("`@("`@("`@("`@
M("`@(&EM<&QO9&4H)RP@)RP@4$5!4E]686QI9&%T93HZ9V5T5F%L:613=&%T
M97,H*2DI.PT*("`@("`@("`@("`@)')E="`](&9A;'-E.PT*("`@("`@("!]
M#0H@("`@("`@("1A<&ES=&%T97,@/2!014%27U9A;&ED871E.CIG971686QI
M9%-T871E<R@I.PT*("`@("`@("!A<G)A>5]S:&EF="@D87!I<W1A=&5S*3L@
M+R\@<VYA<'-H;W0@:7,@;F]T(&%L;&]W960-"B`@("`@("`@:68@*"%I;E]A
M<G)A>2@D87!I<W1A8FEL:71Y+"`D87!I<W1A=&5S*2D@>PT*("`@("`@("`@
M("`@)'1H:7,M/E]A9&1&86EL=7)E*"=S=&%T92<L("=I;G9A;&ED($%022!S
M=&%B:6QI='D@(B<@+@T*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G
M97AM;"T^9V5T4W1A=&4H)V%P:2<I("X@)R(L(&UU<W0@8F4@;VYE(&]F.B`G
M("X-"B`@("`@("`@("`@("`@("!I;7!L;V1E*"<L("<L("1A<&ES=&%T97,I
M*3L-"B`@("`@("`@("`@("1R970@/2!F86QS93L-"B`@("`@("`@?0T*("`@
M("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`
M86-C97-S('!R;W1E8W1E9`T*("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED
M871E4W5M;6%R>2@I#0H@("`@>PT*("`@("`@("!R971U<FX@=')U93L-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`T*("`@
M("`J+PT*("`@(&9U;F-T:6]N('9A;&ED871E1&5S8W)I<'1I;VXH*0T*("`@
M('L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@0&%C8V5S<R!P<F]T96-T960-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!V86QI9&%T94QI8V5N<V4H*0T*("`@('L-"B`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0&%C8V5S<R!P<F]T96-T
M960-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9&%T94YO=&5S*"D-"B`@
M("![#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("`J(&9O<B!P86-K86=E+GAM;"`R+C`@;VYL>2`M(&-H86YN96QS(&-A
M;B=T('5S92!P86-K86=E+GAM;"`Q+C`-"B`@("`@*B!`86-C97-S('!R;W1E
M8W1E9`T*("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED871E1&5P96YD96YC
M:65S*"D-"B`@("![#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("`J(&9O<B!P86-K86=E+GAM;"`Q+C`@;VYL>0T*("`@
M("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]V
M86QI9&%T949I;&5L:7-T*"D-"B`@("![#0H@("`@("`@(')E='5R;B!T<G5E
M.R`O+R!P;&%C96AO;&1E<B!F;W(@;F]W#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@9F]R('!A8VMA9V4N>&UL(#(N,"!O;FQY#0H@("`@("H@0&%C8V5S
M<R!P<F]T96-T960-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9&%T94UA
M:6Y&:6QE;&ES="@I#0H@("`@>PT*("`@("`@("!R971U<FX@=')U93L@+R\@
M<&QA8V5H;VQD97(@9F]R(&YO=PT*("`@('T-"@T*("`@("\J*@T*("`@("`J
M(&9O<B!P86-K86=E+GAM;"`R+C`@;VYL>0T*("`@("`J($!A8V-E<W,@<')O
M=&5C=&5D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=F%L:61A=&5296QE87-E
M1FEL96QI<W0H*0T*("`@('L-"B`@("`@("`@<F5T=7)N('1R=64[("\O('!L
M86-E:&]L9&5R(&9O<B!N;W<-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`
M86-C97-S('!R;W1E8W1E9`T*("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED
M871E0VAA;F=E;&]G*"D-"B`@("![#0H@("`@("`@(')E='5R;B!T<G5E.PT*
M("`@('T-"@T*("`@("\J*@T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@=F%L:61A=&5&:6QE;&ES="@I#0H@("`@
M>PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!`86-C97-S('!R;W1E8W1E9`T*("`@("`J+PT*("`@(&9U;F-T:6]N
M('9A;&ED871E1&5P<R@I#0H@("`@>PT*("`@("`@("!R971U<FX@=')U93L-
M"B`@("!]#0I]#0H_/@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U9A;&ED871O<B\`
M````````````````````````````````````````````````````````````
M```````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#4Q-30S,S<T,``P,C$R-34`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+U!%05(O5F%L:61A=&]R+U!%0TPN<&AP````````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`T,30S`#$P-3$U-#,S-S0P`#`R,C4Q,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`T*+RHJ#0H@
M*B!#:&%N;F5L(%9A;&ED871O<B!F;W(@=&AE('!E8VPN<&AP+FYE="!C:&%N
M;F5L#0H@*@T*("H@4$A0(#0@86YD(%!(4"`U#0H@*@T*("H@0&-A=&5G;W)Y
M("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@
M1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%!%0TPN<&AP+'8@,2XW(#(P
M,#8O,#(O,#,@,#(Z,#(Z,C(@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@
M("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E
M("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$U#0H@
M*B\-"B\J*@T*("H@5&AI<R!I<R!T:&4@<&%R96YT(&-L87-S(&9O<B!A;&P@
M=F%L:61A=&]R<PT*("HO#0IR97%U:7)E7V]N8V4@)U!%05(O5F%L:61A=&4N
M<&AP)SL-"B\J*@T*("H@0VAA;FYE;"!686QI9&%T;W(@9F]R('1H92!P96-L
M+G!H<"YN970@8VAA;FYE;`T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A
M8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E
M;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!0
M2%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@
M("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$U#0H@*B\-"F-L87-S(%!%
M05)?5F%L:61A=&]R7U!%0TP@97AT96YD<R!014%27U9A;&ED871E#0I[#0H@
M("`@9G5N8W1I;VX@=F%L:61A=&5697)S:6]N*"D-"B`@("![#0H@("`@("`@
M(&EF("@D=&AI<RT^7W-T871E(#T](%!%05)?5D%,241!5$5?4$%#2T%'24Y'
M*2![#0H@("`@("`@("`@("`D=F5R<VEO;B`]("1T:&ES+3Y?<&%C:V%G97AM
M;"T^9V5T5F5R<VEO;B@I.PT*("`@("`@("`@("`@)'9E<G-I;VYC;VUP;VYE
M;G1S(#T@97AP;&]D92@G+B<L("1V97)S:6]N*3L-"B`@("`@("`@("`@("1L
M87-T(#T@87)R87E?<&]P*"1V97)S:6]N8V]M<&]N96YT<RD[#0H@("`@("`@
M("`@("!I9B`H<W5B<W1R*"1L87-T+"`Q+"`R*2`]/2`G<F,G*2![#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/E]A9&1&86EL=7)E*"=V97)S:6]N)RP@)U)E
M;&5A<V4@0V%N9&ED871E('9E<G-I;VYS(&UU<W0@:&%V92`G("X-"B`@("`@
M("`@("`@("`@("`G=7!P97(M8V%S92!20RP@;F]T(&QO=V5R+6-A<V4@<F,G
M*3L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@=F%L:61A=&5086-K86=E3F%M92@I#0H@("`@>PT*
M("`@("`@("`D<F5T(#T@<&%R96YT.CIV86QI9&%T95!A8VMA9V5.86UE*"D[
M#0H@("`@("`@(&EF("@D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%!A8VMA9V54
M>7!E*"D@/3T@)V5X='-R8R<I('L-"B`@("`@("`@("`@(&EF("AS=')T;VQO
M=V5R*"1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T4&%C:V%G92@I*2`A/0T*("`@
M("`@("`@("`@("`@("`@<W1R=&]L;W=E<B@D=&AI<RT^7W!A8VMA9V5X;6PM
M/F=E=%!R;W9I9&5S17AT96YS:6]N*"DI*2![#0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]A9&1787)N:6YG*"=P<F]V:61E<V5X=&5N<VEO;B<L("=P86-K
M86=E(&YA;64@(B<@+@T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M8VMA9V5X;6PM/F=E=%!A8VMA9V4H*2`N("<B(&ES(&1I9F9E<F5N="!F<F]M
M(&5X=&5N<VEO;B!N86UE("(G("X-"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P86-K86=E>&UL+3YG9710<F]V:61E<T5X=&5N<VEO;B@I("X@)R(G
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M)')E=#L-"B`@("!]#0I]#0H_/@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+U!%05(O6$U,4&%R<V5R+G!H<```````````````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$W-#<Q`#$P-3$U-#,S-S0Q`#`R,38W
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`T*+RHJ#0H@*B!014%27T944`T*("H-"B`J(%!(4"!V97)S:6]N<R`T
M(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S
M=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@
M=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O
M<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O
M8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N
M;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J
M($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R
M(#QC96QL;V=`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@(%-T97!H86X@4V-H
M;6ED="`H;W)I9VEN86P@6$U,7U5N<V5R:6%L:7IE<B!C;V1E*0T*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%A-3%!A<G-E
M<BYP:'`L=B`Q+C$Q(#(P,#8O,#$O,#8@,#0Z-#<Z,S8@8V5L;&]G($5X<"`D
M#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L
M96%S92`Q+C0N,&$Q#0H@*B\-"@T*+RHJ#0H@*B!087)S97(@9F]R(&%N>2!X
M;6P@9FEL90T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@
M4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N
M;F5T/@T*("H@0&%U=&AO<B`@("`@4W1E<&AA;B!38VAM:61T("AO<FEG:6YA
M;"!834Q?56YS97)I86QI>F5R(&-O9&4I#0H@*B!`8V]P>7)I9VAT("`Q.3DW
M+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@
M*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@
M:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@
M("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J
M+PT*8VQA<W,@4$5!4E]834Q087)S97(-"GL-"B`@("`O*BH-"B`@("`@*B!U
M;G-E<FEL:6%L:7IE9"!D871A#0H@("`@("H@0'9A<B!S=')I;F<@)%]S97)I
M86QI>F5D1&%T80T*("`@("`J+PT*("`@('9A<B`D7W5N<V5R:6%L:7IE9$1A
M=&$@/2!N=6QL.PT*#0H@("`@+RHJ#0H@("`@("H@;F%M92!O9B!T:&4@<F]O
M="!T86<-"B`@("`@*B!`=F%R('-T<FEN9R`D7W)O;W0-"B`@("`@*B\-"B`@
M("!V87(@)%]R;V]T(#T@;G5L;#L-"@T*("`@("\J*@T*("`@("`J('-T86-K
M(&9O<B!A;&P@9&%T82!T:&%T(&ES(&9O=6YD#0H@("`@("H@0'9A<B!A<G)A
M>2`@("`D7V1A=&%3=&%C:PT*("`@("`J+PT*("`@('9A<B`D7V1A=&%3=&%C
M:R`@/2`@(&%R<F%Y*"D[#0H-"B`@("`O*BH-"B`@("`@*B!S=&%C:R!F;W(@
M86QL('9A;'5E<R!T:&%T(&%R92!G96YE<F%T960-"B`@("`@*B!`=F%R(&%R
M<F%Y("`@("1?=F%L4W1A8VL-"B`@("`@*B\-"B`@("!V87(@)%]V86Q3=&%C
M:R`@/2`@(&%R<F%Y*"D[#0H-"B`@("`O*BH-"B`@("`@*B!C=7)R96YT('1A
M9R!D97!T:`T*("`@("`J($!V87(@:6YT("`@("1?9&5P=&@-"B`@("`@*B\-
M"B`@("!V87(@)%]D97!T:"`](#`[#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T1&%T82@I#0H@
M("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/E]U;G-E<FEA;&EZ961$871A
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<@>&UL
M(&-O;G1E;G0-"B`@("`@*B!`<F5T=7)N('1R=65\4$5!4E]%<G)O<@T*("`@
M("`J+PT*("`@(&9U;F-T:6]N('!A<G-E*"1D871A*0T*("`@('L-"B`@("`@
M("`@:68@*"%E>'1E;G-I;VY?;&]A9&5D*"=X;6PG*2D@>PT*("`@("`@("`@
M("`@:6YC;'5D95]O;F-E("=014%2+G!H<"<[#0H@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@B6$U,($5X=&5N<VEO;B!N;W0@9F]U;F0B
M+"`Q*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W9A;%-T86-K(#T@
M87)R87DH*3L-"B`@("`@("`@)'1H:7,M/E]D871A4W1A8VL@/2!A<G)A>2@I
M.PT*("`@("`@("`D=&AI<RT^7V1E<'1H(#T@,#L-"@T*("`@("`@("!I9B`H
M=F5R<VEO;E]C;VUP87)E*'!H<'9E<G-I;VXH*2P@)S4N,"XP)RP@)VQT)RDI
M('L-"B`@("`@("`@("`@(&EF("AS=')P;W,H)&1A=&$L("=E;F-O9&EN9STB
M551&+3@B)RDI('L-"B`@("`@("`@("`@("`@("`D9&%T82`]('5T9CA?9&5C
M;V1E*"1D871A*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1X<"`]
M($!X;6Q?<&%R<V5R7V-R96%T92@G25-/+3@X-3DM,2<I.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@:68@*'-T<G!O<R@D9&%T82P@)V5N8V]D
M:6YG/2)55$8M."(G*2D@>PT*("`@("`@("`@("`@("`@("1X<"`]($!X;6Q?
M<&%R<V5R7V-R96%T92@G551&+3@G*3L-"B`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@)'AP(#T@0'AM;%]P87)S97)?8W)E871E*"=)
M4T\M.#@U.2TQ)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@>&UL7W!A<G-E<E]S971?;W!T:6]N*"1X<"P@6$U,7T]05$E/3E]#05-%
M7T9/3$1)3D<L(#`I.PT*("`@("`@("!X;6Q?<V5T7V]B:F5C="@D>'`L("1T
M:&ES*3L-"B`@("`@("`@>&UL7W-E=%]E;&5M96YT7VAA;F1L97(H)'AP+"`G
M<W1A<G1(86YD;&5R)RP@)V5N9$AA;F1L97(G*3L-"B`@("`@("`@>&UL7W-E
M=%]C:&%R86-T97)?9&%T85]H86YD;&5R*"1X<"P@)V-D871A2&%N9&QE<B<I
M.PT*("`@("`@("!I9B`H(7AM;%]P87)S92@D>'`L("1D871A*2D@>PT*("`@
M("`@("`@("`@)&US9R`]('AM;%]E<G)O<E]S=')I;F<H>&UL7V=E=%]E<G)O
M<E]C;V1E*"1X<"DI.PT*("`@("`@("`@("`@)&QI;F4@/2!X;6Q?9V5T7V-U
M<G)E;G1?;&EN95]N=6UB97(H)'AP*3L-"B`@("`@("`@("`@('AM;%]P87)S
M97)?9G)E92@D>'`I.PT*("`@("`@("`@("`@:6YC;'5D95]O;F-E("=014%2
M+G!H<"<[#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B
M6$U,($5R<F]R.B`G)&US9R<@;VX@;&EN92`G)&QI;F4G(BP@,BD[#0H@("`@
M("`@('T-"B`@("`@("`@>&UL7W!A<G-E<E]F<F5E*"1X<"D[#0H@("`@("`@
M(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%-T87)T
M(&5L96UE;G0@:&%N9&QE<B!F;W(@6$U,('!A<G-E<@T*("`@("`J#0H@("`@
M("H@0&%C8V5S<R!P<FEV871E#0H@("`@("H@0'!A<F%M("!O8FIE8W0@)'!A
M<G-E<B`@6$U,('!A<G-E<B!O8FIE8W0-"B`@("`@*B!`<&%R86T@('-T<FEN
M9R`D96QE;65N="!834P@96QE;65N=`T*("`@("`J($!P87)A;2`@87)R87D@
M("1A='1R:6)S(&%T=')I8G5T97,@;V8@6$U,('1A9PT*("`@("`J($!R971U
M<FX@=F]I9`T*("`@("`J+PT*("`@(&9U;F-T:6]N('-T87)T2&%N9&QE<B@D
M<&%R<V5R+"`D96QE;65N="P@)&%T=')I8G,I#0H@("`@>PT*("`@("`@("`D
M='EP92`]("=S=')I;F<G.PT*#0H@("`@("`@("1T:&ES+3Y?9&5P=&@K*SL-
M"B`@("`@("`@)'1H:7,M/E]D871A4W1A8VM;)'1H:7,M/E]D97!T:%T@/2!N
M=6QL.PT*#0H@("`@("`@("1V86P@/2!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@("=N86UE)R`@("`@("`@(#T^("1E;&5M96YT+`T*("`@("`@("`@
M("`@("`@("`@("`@)W9A;'5E)R`@("`@("`@/3X@;G5L;"P-"B`@("`@("`@
M("`@("`@("`@("`@("=T>7!E)R`@("`@("`@(#T^("1T>7!E+`T*("`@("`@
M("`@("`@("`@("`@("`@)V-H:6QD<F5N2V5Y<R<@/3X@87)R87DH*2P-"B`@
M("`@("`@("`@("`@("`@("`@("=A9V=R96=+97ES)R`@(#T^(&%R<F%Y*"D-
M"B`@("`@("`@("`@("`@("`@("`@*3L-"@T*("`@("`@("!I9B`H8V]U;G0H
M)&%T=')I8G,I(#X@,"D@>PT*("`@("`@("`@("`@)'9A;%LG8VAI;&1R96XG
M72`](&%R<F%Y*"D[#0H@("`@("`@("`@("`D=F%L6R=T>7!E)UT@/2`G87)R
M87DG.PT*#0H@("`@("`@("`@("`D=F%L6R=C:&EL9')E;B==6R=A='1R:6)S
M)UT@/2`D871T<FEB<SL-"@T*("`@("`@("!]#0H-"B`@("`@("`@87)R87E?
M<'5S:"@D=&AI<RT^7W9A;%-T86-K+"`D=F%L*3L-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!P;W-T+7!R;V-E<W,@9&%T80T*("`@("`J#0H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9&%T80T*("`@("`J($!P87)A;2!S=')I;F<@)&5L
M96UE;G0@96QE;65N="!N86UE#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<&]S
M=%!R;V-E<W,H)&1A=&$L("1E;&5M96YT*0T*("`@('L-"B`@("`@("`@<F5T
M=7)N('1R:6TH)&1A=&$I.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($5N
M9"!E;&5M96YT(&AA;F1L97(@9F]R(%A-3"!P87)S97(-"B`@("`@*@T*("`@
M("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J($!P87)A;2`@;V)J96-T(%A-
M3"!P87)S97(@;V)J96-T#0H@("`@("H@0'!A<F%M("!S=')I;F<-"B`@("`@
M*B!`<F5T=7)N('9O:60-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!E;F1(86YD
M;&5R*"1P87)S97(L("1E;&5M96YT*0T*("`@('L-"B`@("`@("`@)'9A;'5E
M(#T@87)R87E?<&]P*"1T:&ES+3Y?=F%L4W1A8VLI.PT*("`@("`@("`D9&%T
M82`@/2`D=&AI<RT^<&]S=%!R;V-E<W,H)'1H:7,M/E]D871A4W1A8VM;)'1H
M:7,M/E]D97!T:%TL("1E;&5M96YT*3L-"@T*("`@("`@("`O+R!A9&IU<W0@
M='EP92!O9B!T:&4@=F%L=64-"B`@("`@("`@<W=I=&-H*'-T<G1O;&]W97(H
M)'9A;'5E6R=T>7!E)UTI*2![#0H-"B`@("`@("`@("`@("\J#0H@("`@("`@
M("`@("`@*B!U;G-E<FEA;&EZ92!A;B!A<G)A>0T*("`@("`@("`@("`@("HO
M#0H@("`@("`@("`@("!C87-E("=A<G)A>2<Z#0H@("`@("`@("`@("`@("`@
M:68@*"1D871A("$]/2`G)RD@>PT*("`@("`@("`@("`@("`@("`@("`D=F%L
M=65;)V-H:6QD<F5N)UU;)U]C;VYT96YT)UT@/2`D9&%T83L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1V86QU95LG
M8VAI;&1R96XG72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E6R=V
M86QU92==(#T@)'9A;'5E6R=C:&EL9')E;B==.PT*("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1V86QU95LG=F%L=64G
M72`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&)R96%K.PT*#0H@("`@("`@("`@("`O*@T*("`@("`@("`@("`@("H@
M=6YS97)I86QI>F4@82!N=6QL('9A;'5E#0H@("`@("`@("`@("`@*B\-"B`@
M("`@("`@("`@(&-A<V4@)VYU;&PG.@T*("`@("`@("`@("`@("`@("1D871A
M(#T@;G5L;#L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"@T*("`@("`@("`@
M("`@+RH-"B`@("`@("`@("`@("`J('5N<V5R:6%L:7IE(&%N>2!S8V%L87(@
M=F%L=64-"B`@("`@("`@("`@("`J+PT*("`@("`@("`@("`@9&5F875L=#H-
M"B`@("`@("`@("`@("`@("!S971T>7!E*"1D871A+"`D=F%L=65;)W1Y<&4G
M72D[#0H@("`@("`@("`@("`@("`@)'9A;'5E6R=V86QU92==(#T@)&1A=&$[
M#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@('T-"B`@("`@("`@
M)'!A<F5N="`](&%R<F%Y7W!O<"@D=&AI<RT^7W9A;%-T86-K*3L-"B`@("`@
M("`@:68@*"1P87)E;G0@/3T](&YU;&PI('L-"B`@("`@("`@("`@("1T:&ES
M+3Y?=6YS97)I86QI>F5D1&%T82`]("8D=F%L=65;)W9A;'5E)UT[#0H@("`@
M("`@("`@("`D=&AI<RT^7W)O;W0@/2`F)'9A;'5E6R=N86UE)UT[#0H@("`@
M("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("\O('!A<F5N="!H87,@=&\@8F4@86X@87)R87D-"B`@("`@("`@
M("`@(&EF("@A:7-S970H)'!A<F5N=%LG8VAI;&1R96XG72D@?'P@(6ES7V%R
M<F%Y*"1P87)E;G1;)V-H:6QD<F5N)UTI*2![#0H@("`@("`@("`@("`@("`@
M)'!A<F5N=%LG8VAI;&1R96XG72`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@
M("`@:68@*"1P87)E;G1;)W1Y<&4G72`A/2`G87)R87DG*2![#0H@("`@("`@
M("`@("`@("`@("`@("1P87)E;G1;)W1Y<&4G72`]("=A<G)A>2<[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1V86QU95LG;F%M92==*2D@>PT*("`@("`@("`@("`@("`@
M("\O('1H97)E(&%L<F5A9'D@:&%S(&)E96X@82!T86<@=VET:"!T:&ES(&YA
M;64-"B`@("`@("`@("`@("`@("!I9B`H:6Y?87)R87DH)'9A;'5E6R=N86UE
M)UTL("1P87)E;G1;)V-H:6QD<F5N2V5Y<R==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`O+R!N;R!A9V=R96=A=&4@:&%S(&)E96X@8W)E871E9"!F;W(@
M=&AI<R!T86<-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I;E]A<G)A>2@D
M=F%L=65;)VYA;64G72P@)'!A<F5N=%LG86=G<F5G2V5Y<R==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P87)E;G1;)V-H:6QD
M<F5N)UU;)'9A;'5E6R=N86UE)UU=*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P87)E;G1;)V-H:6QD<F5N)UU;)'9A;'5E6R=N86UE)UU=
M(#T@87)R87DH)'!A<F5N=%LG8VAI;&1R96XG75LD=F%L=65;)VYA;64G75TI
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<&%R96YT6R=C:&EL9')E;B==6R1V86QU
M95LG;F%M92==72`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]P=7-H*"1P87)E
M;G1;)V%G9W)E9TME>7,G72P@)'9A;'5E6R=N86UE)UTI.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H
M)'!A<F5N=%LG8VAI;&1R96XG75LD=F%L=65;)VYA;64G75TL("1V86QU95LG
M=F%L=64G72D[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@)'!A<F5N=%LG8VAI;&1R96XG75LD=F%L=65;)VYA;64G
M75T@/2`F)'9A;'5E6R=V86QU92==.PT*("`@("`@("`@("`@("`@("`@("!A
M<G)A>5]P=7-H*"1P87)E;G1;)V-H:6QD<F5N2V5Y<R==+"`D=F%L=65;)VYA
M;64G72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("!A<G)A>5]P=7-H*"1P87)E;G1;)V-H:6QD
M<F5N)UTL)'9A;'5E6R=V86QU92==*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&%R<F%Y7W!U<V@H)'1H:7,M/E]V86Q3=&%C:RP@)'!A<F5N="D[
M#0H@("`@("`@('T-"@T*("`@("`@("`D=&AI<RT^7V1E<'1H+2T[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@2&%N9&QE<B!F;W(@8VAA<F%C=&5R(&1A
M=&$-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J($!P
M87)A;2`@;V)J96-T(%A-3"!P87)S97(@;V)J96-T#0H@("`@("H@0'!A<F%M
M("!S=')I;F<@0T1!5$$-"B`@("`@*B!`<F5T=7)N('9O:60-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!C9&%T84AA;F1L97(H)'!A<G-E<BP@)&-D871A*0T*
M("`@('L-"B`@("`@("`@)'1H:7,M/E]D871A4W1A8VM;)'1H:7,M/E]D97!T
M:%T@+CT@)&-D871A.PT*("`@('T-"GT-"C\^````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+G!H<```````
M````````````````````````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#$P-3`T
M-0`Q,#4Q-30S,S<T,P`P,C`P-3$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`-"B\J*@T*("H@4$5!4BP@=&AE(%!(
M4"!%>'1E;G-I;VX@86YD($%P<&QI8V%T:6]N(%)E<&]S:71O<GD-"B`J#0H@
M*B!014%2(&-L87-S(&%N9"!014%27T5R<F]R(&-L87-S#0H@*@T*("H@4$A0
M('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L
M:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L
M9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R
M96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@
M=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*
M("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y
M("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@
M4W1E<FQI;F<@2'5G:&5S(#QS=&5R;&EN9T!P:'`N;F5T/@T*("H@0&%U=&AO
M<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@
M("`@5&]M87,@5BY6+D-O>"`\8V]X0&ED96-N970N8V]M/@T*("H@0&%U=&AO
M<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER
M:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E
M;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%!%05(N<&AP+'8@
M,2XY."`R,#`V+S`Q+S(S(#`U.C,X.C`U(&-E;&QO9R!%>'`@)`T*("H@0&QI
M;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J
M($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ
M#0H@*B\-"@T*+RHJ(T`K#0H@*B!%4E)/4B!C;VYS=&%N=',-"B`J+PT*9&5F
M:6YE*"=014%27T524D]27U)%5%523B<L("`@("`Q*3L-"F1E9FEN92@G4$5!
M4E]%4E)/4E]04DE.5"<L("`@("`@,BD[#0ID969I;F4H)U!%05)?15)23U)?
M5%))1T=%4B<L("`@(#0I.PT*9&5F:6YE*"=014%27T524D]27T1)12<L("`@
M("`@("`X*3L-"F1E9FEN92@G4$5!4E]%4E)/4E]#04Q,0D%#2R<L("`Q-BD[
M#0HO*BH-"B`J(%=!4DY)3D<Z(&]B<V]L971E#0H@*B!`9&5P<F5C871E9`T*
M("HO#0ID969I;F4H)U!%05)?15)23U)?15A#15!424].)RP@,S(I.PT*+RHJ
M(T`M*B\-"F1E9FEN92@G4$5!4E]:13(G+"`H9G5N8W1I;VY?97AI<W1S*"=V
M97)S:6]N7V-O;7!A<F4G*2`F)@T*("`@("`@("`@("`@("`@("`@("!V97)S
M:6]N7V-O;7!A<F4H>F5N9%]V97)S:6]N*"DL("(R+61E=B(L(")G92(I*2D[
M#0H-"FEF("AS=6)S='(H4$A07T]3+"`P+"`S*2`]/2`G5TE.)RD@>PT*("`@
M(&1E9FEN92@G3U-?5TE.1$]74R<L('1R=64I.PT*("`@(&1E9FEN92@G3U-?
M54Y)6"<L("`@(&9A;'-E*3L-"B`@("!D969I;F4H)U!%05)?3U,G+"`@("`G
M5VEN9&]W<R<I.PT*?2!E;'-E('L-"B`@("!D969I;F4H)T]37U=)3D1/5U,G
M+"!F86QS92D[#0H@("`@9&5F:6YE*"=/4U]53DE8)RP@("`@=')U92D[#0H@
M("`@9&5F:6YE*"=014%27T]3)RP@("`@)U5N:7@G*3L@+R\@8FQA=&%N="!A
M<W-U;7!T:6]N#0I]#0H-"B\O(&EN<W1A;G0@8F%C:W=A<F1S(&-O;7!A=&EB
M:6QI='D-"FEF("@A9&5F:6YE9"@G4$%42%]315!!4D%43U(G*2D@>PT*("`@
M(&EF("A/4U]724Y$3U=3*2![#0H@("`@("`@(&1E9FEN92@G4$%42%]315!!
M4D%43U(G+"`G.R<I.PT*("`@('T@96QS92![#0H@("`@("`@(&1E9FEN92@G
M4$%42%]315!!4D%43U(G+"`G.B<I.PT*("`@('T-"GT-"@T*)$=,3T)!3%-;
M)U]014%27V1E9F%U;'1?97)R;W)?;6]D92==("`@("`](%!%05)?15)23U)?
M4D5455)..PT*)$=,3T)!3%-;)U]014%27V1E9F%U;'1?97)R;W)?;W!T:6]N
M<R==("`]($5?55-%4E].3U1)0T4[#0HD1TQ/0D%,4ULG7U!%05)?9&5S=')U
M8W1O<E]O8FIE8W1?;&ES="==(#T@87)R87DH*3L-"B1'3$]"04Q36R=?4$5!
M4E]S:'5T9&]W;E]F=6YC<R==("`@("`@("`@/2!A<G)A>2@I.PT*)$=,3T)!
M3%-;)U]014%27V5R<F]R7VAA;F1L97)?<W1A8VLG72`@("`](&%R<F%Y*"D[
M#0H-"D!I;FE?<V5T*"=T<F%C:U]E<G)O<G,G+"!T<G5E*3L-"@T*+RHJ#0H@
M*B!"87-E(&-L87-S(&9O<B!O=&AE<B!014%2(&-L87-S97,N("!0<F]V:61E
M<R!R=61I;65N=&%R>0T*("H@96UU;&%T:6]N(&]F(&1E<W1R=6-T;W)S+@T*
M("H-"B`J($EF('EO=2!W86YT(&$@9&5S=')U8W1O<B!I;B!Y;W5R(&-L87-S
M+"!I;FAE<FET(%!%05(@86YD(&UA:V4@80T*("H@9&5S=')U8W1O<B!M971H
M;V0@8V%L;&5D(%]Y;W5R8VQA<W-N86UE("AS86UE(&YA;64@87,@=&AE#0H@
M*B!C;VYS=')U8W1O<BP@8G5T('=I=&@@82`B7R(@<')E9FEX*2X@($%L<V\L
M(&EN('EO=7(@8V]N<W1R=6-T;W(@>6]U#0H@*B!H879E('1O(&-A;&P@=&AE
M(%!%05(@8V]N<W1R=6-T;W(Z("1T:&ES+3Y014%2*"D[+@T*("H@5&AE(&1E
M<W1R=6-T;W(@;65T:&]D('=I;&P@8F4@8V%L;&5D('=I=&AO=70@<&%R86UE
M=&5R<RX@($YO=&4@=&AA=`T*("H@870@:6X@<V]M92!305!)(&EM<&QE;65N
M=&%T:6]N<R`H<W5C:"!A<R!!<&%C:&4I+"!A;GD@;W5T<'5T(&1U<FEN9PT*
M("H@=&AE(')E<75E<W0@<VAU=&1O=VX@*&EN('=H:6-H(&1E<W1R=6-T;W)S
M(&%R92!C86QL960I('-E96US('1O(&)E#0H@*B!D:7-C87)D960N("!)9B!Y
M;W4@;F5E9"!T;R!G970@86YY(&1E8G5G(&EN9F]R;6%T:6]N(&9R;VT@>6]U
M<@T*("H@9&5S=')U8W1O<BP@=7-E(&5R<F]R7VQO9R@I+"!S>7-L;V<H*2!O
M<B!S;VUE=&AI;F<@<VEM:6QA<BX-"B`J#0H@*B!)35!/4E1!3E0A(%1O('5S
M92!T:&4@96UU;&%T960@9&5S=')U8W1O<G,@>6]U(&YE960@=&\@8W)E871E
M('1H90T*("H@;V)J96-T<R!B>2!R969E<F5N8V4Z("1O8FH@/28@;F5W(%!%
M05)?8VAI;&0[#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA
M9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P
M:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@5&]M87,@5BY6+B!#;W@@/&-O>$!I
M9&5C;F5T+F-O;3X-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL
M;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0
M($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@
M(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-E92`@("`@("`@4$5!4E]%<G)O
M<@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%!(4"`T
M+C`N,@T*("H@0&QI;FL@("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O;6%N
M=6%L+V5N+V-O<F4N<&5A<BYP:'`C8V]R92YP96%R+G!E87(-"B`J+PT*8VQA
M<W,@4$5!4@T*>PT*("`@("\O('M[>R!P<F]P97)T:65S#0H-"B`@("`O*BH-
M"B`@("`@*B!7:&5T:&5R('1O(&5N86)L92!I;G1E<FYA;"!D96)U9R!M97-S
M86=E<RX-"B`@("`@*@T*("`@("`J($!V87(@("`@(&)O;VP-"B`@("`@*B!`
M86-C97-S("!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?9&5B=6<@/2!F
M86QS93L-"@T*("`@("\J*@T*("`@("`J($1E9F%U;'0@97)R;W(@;6]D92!F
M;W(@=&AI<R!O8FIE8W0N#0H@("`@("H-"B`@("`@*B!`=F%R("`@("!I;G0-
M"B`@("`@*B!`86-C97-S("!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?
M9&5F875L=%]E<G)O<E]M;V1E(#T@;G5L;#L-"@T*("`@("\J*@T*("`@("`J
M($1E9F%U;'0@97)R;W(@;W!T:6]N<R!U<V5D(&9O<B!T:&ES(&]B:F5C="!W
M:&5N(&5R<F]R(&UO9&4-"B`@("`@*B!I<R!014%27T524D]27U1224='15(N
M#0H@("`@("H-"B`@("`@*B!`=F%R("`@("!I;G0-"B`@("`@*B!`86-C97-S
M("!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?9&5F875L=%]E<G)O<E]O
M<'1I;VYS(#T@;G5L;#L-"@T*("`@("\J*@T*("`@("`J($1E9F%U;'0@97)R
M;W(@:&%N9&QE<B`H8V%L;&)A8VLI(&9O<B!T:&ES(&]B:F5C="P@:68@97)R
M;W(@;6]D92!I<PT*("`@("`J(%!%05)?15)23U)?0T%,3$)!0TLN#0H@("`@
M("H-"B`@("`@*B!`=F%R("`@("!S=')I;F<-"B`@("`@*B!`86-C97-S("!P
M<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?9&5F875L=%]E<G)O<E]H86YD
M;&5R(#T@)R<[#0H-"B`@("`O*BH-"B`@("`@*B!7:&EC:"!C;&%S<R!T;R!U
M<V4@9F]R(&5R<F]R(&]B:F5C=',N#0H@("`@("H-"B`@("`@*B!`=F%R("`@
M("!S=')I;F<-"B`@("`@*B!`86-C97-S("!P<FEV871E#0H@("`@("HO#0H@
M("`@=F%R("1?97)R;W)?8VQA<W,@/2`G4$5!4E]%<G)O<B<[#0H-"B`@("`O
M*BH-"B`@("`@*B!!;B!A<G)A>2!O9B!E>'!E8W1E9"!E<G)O<G,N#0H@("`@
M("H-"B`@("`@*B!`=F%R("`@("!A<G)A>0T*("`@("`J($!A8V-E<W,@('!R
M:79A=&4-"B`@("`@*B\-"B`@("!V87(@)%]E>'!E8W1E9%]E<G)O<G,@/2!A
M<G)A>2@I.PT*#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@8V]N<W1R=6-T
M;W(-"@T*("`@("\J*@T*("`@("`J($-O;G-T<G5C=&]R+B`@4F5G:7-T97)S
M('1H:7,@;V)J96-T(&EN#0H@("`@("H@)%]014%27V1E<W1R=6-T;W)?;V)J
M96-T7VQI<W0@9F]R(&1E<W1R=6-T;W(@96UU;&%T:6]N(&EF(&$-"B`@("`@
M*B!D97-T<G5C=&]R(&]B:F5C="!E>&ES=',N#0H@("`@("H-"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1E<G)O<E]C;&%S<R`@*&]P=&EO;F%L*2!W:&EC:"!C
M;&%S<R!T;R!U<V4@9F]R#0H@("`@("H@("`@("`@(&5R<F]R(&]B:F5C=',L
M(&1E9F%U;'1S('1O(%!%05)?17)R;W(N#0H@("`@("H@0&%C8V5S<R!P=6)L
M:6,-"B`@("`@*B!`<F5T=7)N('9O:60-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!014%2*"1E<G)O<E]C;&%S<R`](&YU;&PI#0H@("`@>PT*("`@("`@("`D
M8VQA<W-N86UE(#T@<W1R=&]L;W=E<BAG971?8VQA<W,H)'1H:7,I*3L-"B`@
M("`@("`@:68@*"1T:&ES+3Y?9&5B=6<I('L-"B`@("`@("`@("`@('!R:6YT
M(")014%2(&-O;G-T<G5C=&]R(&-A;&QE9"P@8VQA<W,])&-L87-S;F%M95QN
M(CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&5R<F]R7V-L87-S("$]/2!N
M=6QL*2![#0H@("`@("`@("`@("`D=&AI<RT^7V5R<F]R7V-L87-S(#T@)&5R
M<F]R7V-L87-S.PT*("`@("`@("!]#0H@("`@("`@('=H:6QE("@D8VQA<W-N
M86UE("8F('-T<F-A<V5C;7`H)&-L87-S;F%M92P@(G!E87(B*2D@>PT*("`@
M("`@("`@("`@)&1E<W1R=6-T;W(@/2`B7R1C;&%S<VYA;64B.PT*("`@("`@
M("`@("`@:68@*&UE=&AO9%]E>&ES=',H)'1H:7,L("1D97-T<G5C=&]R*2D@
M>PT*("`@("`@("`@("`@("`@(&=L;V)A;"`D7U!%05)?9&5S=')U8W1O<E]O
M8FIE8W1?;&ES=#L-"B`@("`@("`@("`@("`@("`D7U!%05)?9&5S=')U8W1O
M<E]O8FIE8W1?;&ES=%M=(#T@)B1T:&ES.PT*("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)$=,3T)!3%-;)U]014%27U-(551$3U=.7U)%1TE35$52140G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@<F5G:7-T97)?<VAU=&1O=VY?
M9G5N8W1I;VXH(E]014%27V-A;&Q?9&5S=')U8W1O<G,B*3L-"B`@("`@("`@
M("`@("`@("`@("`@)$=,3T)!3%-;)U]014%27U-(551$3U=.7U)%1TE35$52
M140G72`]('1R=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&)R96%K.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`D8VQA<W-N86UE(#T@9V5T7W!A<F5N=%]C;&%S<R@D8VQA<W-N86UE
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O
M('U]?0T*("`@("\O('M[>R!D97-T<G5C=&]R#0H-"B`@("`O*BH-"B`@("`@
M*B!$97-T<G5C=&]R("AT:&4@96UU;&%T960@='EP92!O9BXN+BDN("!$;V5S
M(&YO=&AI;F<@<FEG:'0@;F]W+`T*("`@("`J(&)U="!I<R!I;F-L=61E9"!F
M;W(@9F]R=V%R9"!C;VUP871I8FEL:71Y+"!S;R!S=6)C;&%S<PT*("`@("`J
M(&1E<W1R=6-T;W)S('-H;W5L9"!A;'=A>7,@8V%L;"!I="X-"B`@("`@*@T*
M("`@("`J(%-E92!T:&4@;F]T92!I;B!T:&4@8VQA<W,@9&5S8VEP=&EO;B!A
M8F]U="!O=71P=70@9G)O;0T*("`@("`J(&1E<W1R=6-T;W)S+@T*("`@("`J
M#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`<F5T=7)N('9O:60-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?4$5!4B@I('L-"B`@("`@("`@:68@
M*"1T:&ES+3Y?9&5B=6<I('L-"B`@("`@("`@("`@('!R:6YT9B@B4$5!4B!D
M97-T<G5C=&]R(&-A;&QE9"P@8VQA<W,])7-<;B(L('-T<G1O;&]W97(H9V5T
M7V-L87-S*"1T:&ES*2DI.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(&=E=%-T871I8U!R;W!E<G1Y*"D-"@T*("`@("\J
M*@T*("`@("H@268@>6]U(&AA=F4@82!C;&%S<R!T:&%T)W,@;6]S=&QY+V5N
M=&ER96QY('-T871I8RP@86YD('EO=2!N965D('-T871I8PT*("`@("H@<')O
M<&5R=&EE<RP@>6]U(&-A;B!U<V4@=&AI<R!M971H;V0@=&\@<VEM=6QA=&4@
M=&AE;2X@16<N(&EN('EO=7(@;65T:&]D*',I#0H@("`@*B!D;R!T:&ES.B`D
M;7E687(@/2`F4$5!4CHZ9V5T4W1A=&EC4')O<&5R='DH)VUY8VQA<W,G+"`G
M;7E687(G*3L-"B`@("`J(%EO=2!-55-4('5S92!A(')E9F5R96YC92P@;W(@
M=&AE>2!W:6QL(&YO="!P97)S:7-T(0T*("`@("H-"B`@("`J($!A8V-E<W,@
M<'5B;&EC#0H@("`@*B!`<&%R86T@('-T<FEN9R`D8VQA<W,@(%1H92!C86QL
M:6YG(&-L87-S;F%M92P@=&\@<')E=F5N="!C;&%S:&5S#0H@("`@*B!`<&%R
M86T@('-T<FEN9R`D=F%R("`@(%1H92!V87)I86)L92!T;R!R971R:65V92X-
M"B`@("`J($!R971U<FX@;6EX960@("!!(')E9F5R96YC92!T;R!T:&4@=F%R
M:6%B;&4N($EF(&YO="!S970@:70@=VEL;"!B90T*("`@("H@("`@("`@("`@
M("`@("`@(&%U=&\@:6YI=&EA;&ES960@=&\@3E5,3"X-"B`@("`J+PT*("`@
M(&9U;F-T:6]N("9G9713=&%T:6-0<F]P97)T>2@D8VQA<W,L("1V87(I#0H@
M("`@>PT*("`@("`@("!S=&%T:6,@)'!R;W!E<G1I97,[#0H@("`@("`@(')E
M='5R;B`D<')O<&5R=&EE<ULD8VQA<W-=6R1V87)=.PT*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!R96=I<W1E<E-H=71D;W=N1G5N8R@I#0H-
M"B`@("`O*BH-"B`@("`J(%5S92!T:&ES(&9U;F-T:6]N('1O(')E9VES=&5R
M(&$@<VAU=&1O=VX@;65T:&]D(&9O<B!S=&%T:6,-"B`@("`J(&-L87-S97,N
M#0H@("`@*@T*("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`J($!P87)A;2`@
M;6EX960@)&9U;F,@(%1H92!F=6YC=&EO;B!N86UE("AO<B!A<G)A>2!O9B!C
M;&%S<R]M971H;V0I('1O(&-A;&P-"B`@("`J($!P87)A;2`@;6EX960@)&%R
M9W,@(%1H92!A<F=U;65N=',@=&\@<&%S<R!T;R!T:&4@9G5N8W1I;VX-"B`@
M("`J($!R971U<FX@=F]I9`T*("`@("HO#0H@("`@9G5N8W1I;VX@<F5G:7-T
M97)3:'5T9&]W;D9U;F,H)&9U;F,L("1A<F=S(#T@87)R87DH*2D-"B`@("![
M#0H@("`@("`@("\O(&EF('=E(&%R92!C86QL960@<W1A=&EC86QL>2P@=&AE
M<F4@:7,@82!P;W1E;G1I86P-"B`@("`@("`@+R\@=&AA="!N;R!S:'5T9&]W
M;B!F=6YC(&ES(')E9VES=&5R960N("!"=6<@(S8T-#4-"B`@("`@("`@:68@
M*"%I<W-E="@D1TQ/0D%,4ULG7U!%05)?4TA55$1/5TY?4D5'25-415)%1"==
M*2D@>PT*("`@("`@("`@("`@<F5G:7-T97)?<VAU=&1O=VY?9G5N8W1I;VXH
M(E]014%27V-A;&Q?9&5S=')U8W1O<G,B*3L-"B`@("`@("`@("`@("1'3$]"
M04Q36R=?4$5!4E]32%541$]73E]214=)4U1%4D5$)UT@/2!T<G5E.PT*("`@
M("`@("!]#0H@("`@("`@("1'3$]"04Q36R=?4$5!4E]S:'5T9&]W;E]F=6YC
M<R==6UT@/2!A<G)A>2@D9G5N8RP@)&%R9W,I.PT*("`@('T-"@T*("`@("\O
M('U]?0T*("`@("\O('M[>R!I<T5R<F]R*"D-"@T*("`@("\J*@T*("`@("`J
M(%1E;&P@=VAE=&AE<B!A('9A;'5E(&ES(&$@4$5!4B!E<G)O<BX-"B`@("`@
M*@T*("`@("`J($!P87)A;2`@(&UI>&5D("1D871A("`@=&AE('9A;'5E('1O
M('1E<W0-"B`@("`@*B!`<&%R86T@("!I;G0@("`D8V]D92`@(&EF("1D871A
M(&ES(&%N(&5R<F]R(&]B:F5C="P@<F5T=7)N('1R=64-"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@(&]N;'D@:68@)&-O9&4@:7,@82!S=')I;F<@
M86YD#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`D;V)J+3YG971-
M97-S86=E*"D@/3T@)&-O9&4@;W(-"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("1C;V1E(&ES(&%N(&EN=&5G97(@86YD("1O8FHM/F=E=$-O9&4H
M*2`]/2`D8V]D90T*("`@("`J($!A8V-E<W,@('!U8FQI8PT*("`@("`J($!R
M971U<FX@(&)O;VP@("`@=')U92!I9B!P87)A;65T97(@:7,@86X@97)R;W(-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I<T5R<F]R*"1D871A+"`D8V]D92`]
M(&YU;&PI#0H@("`@>PT*("`@("`@("!I9B`H:7-?82@D9&%T82P@)U!%05)?
M17)R;W(G*2D@>PT*("`@("`@("`@("`@:68@*&ES7VYU;&PH)&-O9&4I*2![
M#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]
M(&5L<V5I9B`H:7-?<W1R:6YG*"1C;V1E*2D@>PT*("`@("`@("`@("`@("`@
M(')E='5R;B`D9&%T82T^9V5T365S<V%G92@I(#T]("1C;V1E.PT*("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R971U<FX@)&1A=&$M
M/F=E=$-O9&4H*2`]/2`D8V]D93L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[('-E=$5R<F]R2&%N9&QI;F<H*0T*#0H@("`@+RHJ#0H@
M("`@("H@4V5T<R!H;W<@97)R;W)S(&=E;F5R871E9"!B>2!T:&ES(&]B:F5C
M="!S:&]U;&0@8F4@:&%N9&QE9"X-"B`@("`@*B!#86X@8F4@:6YV;VME9"!B
M;W1H(&EN(&]B:F5C=',@86YD('-T871I8V%L;'DN("!)9B!C86QL960-"B`@
M("`@*B!S=&%T:6-A;&QY+"!S971%<G)O<DAA;F1L:6YG('-E=',@=&AE(&1E
M9F%U;'0@8F5H879I;W5R(&9O<B!A;&P-"B`@("`@*B!014%2(&]B:F5C=',N
M("!)9B!C86QL960@:6X@86X@;V)J96-T+"!S971%<G)O<DAA;F1L:6YG('-E
M=',-"B`@("`@*B!T:&4@9&5F875L="!B96AA=FEO=7(@9F]R('1H870@;V)J
M96-T+@T*("`@("`J#0H@("`@("H@0'!A<F%M(&EN="`D;6]D90T*("`@("`J
M("`@("`@("!/;F4@;V8@4$5!4E]%4E)/4E]215154DXL(%!%05)?15)23U)?
M4%))3E0L#0H@("`@("H@("`@("`@(%!%05)?15)23U)?5%))1T=%4BP@4$5!
M4E]%4E)/4E]$244L#0H@("`@("H@("`@("`@(%!%05)?15)23U)?0T%,3$)!
M0TL@;W(@4$5!4E]%4E)/4E]%6$-%4%1)3TXN#0H@("`@("H-"B`@("`@*B!`
M<&%R86T@;6EX960@)&]P=&EO;G,-"B`@("`@*B`@("`@("`@5VAE;B`D;6]D
M92!I<R!014%27T524D]27U1224='15(L('1H:7,@:7,@=&AE(&5R<F]R(&QE
M=F5L("AO;F4-"B`@("`@*B`@("`@("`@;V8@15]54T527TY/5$E#12P@15]5
M4T527U=!4DY)3D<@;W(@15]54T527T524D]2*2X-"B`@("`@*@T*("`@("`J
M("`@("`@("!7:&5N("1M;V1E(&ES(%!%05)?15)23U)?0T%,3$)!0TLL('1H
M:7,@<&%R86UE=&5R(&ES(&5X<&5C=&5D#0H@("`@("H@("`@("`@('1O(&)E
M('1H92!C86QL8F%C:R!F=6YC=&EO;B!O<B!M971H;V0N("!!(&-A;&QB86-K
M#0H@("`@("H@("`@("`@(&9U;F-T:6]N(&ES(&$@<W1R:6YG('=I=&@@=&AE
M(&YA;64@;V8@=&AE(&9U;F-T:6]N+"!A#0H@("`@("H@("`@("`@(&-A;&QB
M86-K(&UE=&AO9"!I<R!A;B!A<G)A>2!O9B!T=V\@96QE;65N=',Z('1H92!E
M;&5M96YT#0H@("`@("H@("`@("`@(&%T(&EN9&5X(#`@:7,@=&AE(&]B:F5C
M="P@86YD('1H92!E;&5M96YT(&%T(&EN9&5X(#$@:7,-"B`@("`@*B`@("`@
M("`@=&AE(&YA;64@;V8@=&AE(&UE=&AO9"!T;R!C86QL(&EN('1H92!O8FIE
M8W0N#0H@("`@("H-"B`@("`@*B`@("`@("`@5VAE;B`D;6]D92!I<R!014%2
M7T524D]27U!224Y4(&]R(%!%05)?15)23U)?1$E%+"!T:&ES(&ES#0H@("`@
M("H@("`@("`@(&$@<')I;G1F(&9O<FUA="!S=')I;F<@=7-E9"!W:&5N('!R
M:6YT:6YG('1H92!E<G)O<@T*("`@("`J("`@("`@("!M97-S86=E+@T*("`@
M("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`<F5T=7)N('9O
M:60-"B`@("`@*B!`<V5E(%!%05)?15)23U)?4D5455).#0H@("`@("H@0'-E
M92!014%27T524D]27U!224Y4#0H@("`@("H@0'-E92!014%27T524D]27U12
M24='15(-"B`@("`@*B!`<V5E(%!%05)?15)23U)?1$E%#0H@("`@("H@0'-E
M92!014%27T524D]27T-!3$Q"04-+#0H@("`@("H@0'-E92!014%27T524D]2
M7T580T505$E/3@T*("`@("`J#0H@("`@("H@0'-I;F-E(%!(4"`T+C`N-0T*
M("`@("`J+PT*#0H@("`@9G5N8W1I;VX@<V5T17)R;W)(86YD;&EN9R@D;6]D
M92`](&YU;&PL("1O<'1I;VYS(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&EF
M("AI<W-E="@D=&AI<RD@)B8@:7-?82@D=&AI<RP@)U!%05(G*2D@>PT*("`@
M("`@("`@("`@)'-E=&UO9&4@("`@(#T@)B1T:&ES+3Y?9&5F875L=%]E<G)O
M<E]M;V1E.PT*("`@("`@("`@("`@)'-E=&]P=&EO;G,@(#T@)B1T:&ES+3Y?
M9&5F875L=%]E<G)O<E]O<'1I;VYS.PT*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@)'-E=&UO9&4@("`@(#T@)B1'3$]"04Q36R=?4$5!4E]D969A
M=6QT7V5R<F]R7VUO9&4G73L-"B`@("`@("`@("`@("1S971O<'1I;VYS("`]
M("8D1TQ/0D%,4ULG7U!%05)?9&5F875L=%]E<G)O<E]O<'1I;VYS)UT[#0H@
M("`@("`@('T-"@T*("`@("`@("!S=VET8V@@*"1M;V1E*2![#0H@("`@("`@
M("`@("!C87-E(%!%05)?15)23U)?15A#15!424]..@T*("`@("`@("`@("`@
M8V%S92!014%27T524D]27U)%5%523CH-"B`@("`@("`@("`@(&-A<V4@4$5!
M4E]%4E)/4E]04DE.5#H-"B`@("`@("`@("`@(&-A<V4@4$5!4E]%4E)/4E]4
M4DE'1T52.@T*("`@("`@("`@("`@8V%S92!014%27T524D]27T1)13H-"B`@
M("`@("`@("`@(&-A<V4@;G5L;#H-"B`@("`@("`@("`@("`@("`D<V5T;6]D
M92`]("1M;V1E.PT*("`@("`@("`@("`@("`@("1S971O<'1I;VYS(#T@)&]P
M=&EO;G,[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@
M(&-A<V4@4$5!4E]%4E)/4E]#04Q,0D%#2SH-"B`@("`@("`@("`@("`@("`D
M<V5T;6]D92`]("1M;V1E.PT*("`@("`@("`@("`@("`@("\O(&-L87-S+V]B
M:F5C="!M971H;V0@8V%L;&)A8VL-"B`@("`@("`@("`@("`@("!I9B`H:7-?
M8V%L;&%B;&4H)&]P=&EO;G,I*2![#0H@("`@("`@("`@("`@("`@("`@("1S
M971O<'1I;VYS(#T@)&]P=&EO;G,[#0H@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@=')I9V=E<E]E<G)O<B@B:6YV86QI
M9"!E<G)O<B!C86QL8F%C:R(L($5?55-%4E]705).24Y'*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@
M("`@(&1E9F%U;'0Z#0H@("`@("`@("`@("`@("`@=')I9V=E<E]E<G)O<B@B
M:6YV86QI9"!E<G)O<B!M;V1E(BP@15]54T527U=!4DY)3D<I.PT*("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(&5X<&5C=$5R<F]R*"D-"@T*("`@("\J*@T*("`@
M("`J(%1H:7,@;65T:&]D(&ES('5S960@=&\@=&5L;"!W:&EC:"!E<G)O<G,@
M>6]U(&5X<&5C="!T;R!G970N#0H@("`@("H@17AP96-T960@97)R;W)S(&%R
M92!A;'=A>7,@<F5T=7)N960@=VET:"!E<G)O<B!M;V1E#0H@("`@("H@4$5!
M4E]%4E)/4E]215154DXN("!%>'!E8W1E9"!E<G)O<B!C;V1E<R!A<F4@<W1O
M<F5D(&EN(&$@<W1A8VLL#0H@("`@("H@86YD('1H:7,@;65T:&]D('!U<VAE
M<R!A(&YE=R!E;&5M96YT(&]N=&\@:70N("!4:&4@;&ES="!O9@T*("`@("`J
M(&5X<&5C=&5D(&5R<F]R<R!A<F4@:6X@969F96-T('5N=&EL('1H97D@87)E
M('!O<'!E9"!O9F8@=&AE#0H@("`@("H@<W1A8VL@=VET:"!T:&4@<&]P17AP
M96-T*"D@;65T:&]D+@T*("`@("`J#0H@("`@("H@3F]T92!T:&%T('1H:7,@
M;65T:&]D(&-A;B!N;W0@8F4@8V%L;&5D('-T871I8V%L;'D-"B`@("`@*@T*
M("`@("`J($!P87)A;2!M:7AE9"`D8V]D92!A('-I;F=L92!E<G)O<B!C;V1E
M(&]R(&%N(&%R<F%Y(&]F(&5R<F]R(&-O9&5S('1O(&5X<&5C=`T*("`@("`J
M#0H@("`@("H@0')E='5R;B!I;G0@("`@('1H92!N97<@9&5P=&@@;V8@=&AE
M(")E>'!E8W1E9"!E<G)O<G,B('-T86-K#0H@("`@("H@0&%C8V5S<R!P=6)L
M:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!E>'!E8W1%<G)O<B@D8V]D92`]
M("<J)RD-"B`@("![#0H@("`@("`@(&EF("AI<U]A<G)A>2@D8V]D92DI('L-
M"B`@("`@("`@("`@(&%R<F%Y7W!U<V@H)'1H:7,M/E]E>'!E8W1E9%]E<G)O
M<G,L("1C;V1E*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(&%R
M<F%Y7W!U<V@H)'1H:7,M/E]E>'!E8W1E9%]E<G)O<G,L(&%R<F%Y*"1C;V1E
M*2D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('-I>F5O9B@D=&AI<RT^
M7V5X<&5C=&5D7V5R<F]R<RD[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[('!O<$5X<&5C="@I#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES(&UE
M=&AO9"!P;W!S(&]N92!E;&5M96YT(&]F9B!T:&4@97AP96-T960@97)R;W(@
M8V]D97,-"B`@("`@*B!S=&%C:RX-"B`@("`@*@T*("`@("`J($!R971U<FX@
M87)R87D@("!T:&4@;&ES="!O9B!E<G)O<B!C;V1E<R!T:&%T('=E<F4@<&]P
M<&5D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<&]P17AP96-T*"D-"B`@("![
M#0H@("`@("`@(')E='5R;B!A<G)A>5]P;W`H)'1H:7,M/E]E>'!E8W1E9%]E
M<G)O<G,I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!?8VAE
M8VM$96Q%>'!E8W0H*0T*#0H@("`@+RHJ#0H@("`@("H@5&AI<R!M971H;V0@
M8VAE8VMS('5N<V5T<R!A;B!E<G)O<B!C;V1E(&EF(&%V86EL86)L90T*("`@
M("`J#0H@("`@("H@0'!A<F%M(&UI>&5D(&5R<F]R(&-O9&4-"B`@("`@*B!`
M<F5T=7)N(&)O;VP@=')U92!I9B!T:&4@97)R;W(@8V]D92!W87,@=6YS970L
M(&9A;'-E(&]T:&5R=VES90T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@
M("`J($!S:6YC92!02%`@-"XS+C`-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?
M8VAE8VM$96Q%>'!E8W0H)&5R<F]R7V-O9&4I#0H@("`@>PT*("`@("`@("`D
M9&5L971E9"`](&9A;'-E.PT*#0H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?
M97AP96-T961?97)R;W)S($%3("1K97D@/3X@)&5R<F]R7V%R<F%Y*2![#0H@
M("`@("`@("`@("!I9B`H:6Y?87)R87DH)&5R<F]R7V-O9&4L("1E<G)O<E]A
M<G)A>2DI('L-"B`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^7V5X<&5C
M=&5D7V5R<F]R<ULD:V5Y75MA<G)A>5]S96%R8V@H)&5R<F]R7V-O9&4L("1E
M<G)O<E]A<G)A>2E=*3L-"B`@("`@("`@("`@("`@("`D9&5L971E9"`]('1R
M=64[#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@("\O(&-L96%N('5P
M(&5M<'1Y(&%R<F%Y<PT*("`@("`@("`@("`@:68@*#`@/3T@8V]U;G0H)'1H
M:7,M/E]E>'!E8W1E9%]E<G)O<G-;)&ME>5TI*2![#0H@("`@("`@("`@("`@
M("`@=6YS970H)'1H:7,M/E]E>'!E8W1E9%]E<G)O<G-;)&ME>5TI.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D9&5L971E
M9#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9&5L17AP96-T
M*"D-"@T*("`@("\J*@T*("`@("`J(%1H:7,@;65T:&]D(&1E;&5T97,@86QL
M(&]C8W5R96YC97,@;V8@=&AE('-P96-I9FEE9"!E;&5M96YT(&9R;VT-"B`@
M("`@*B!T:&4@97AP96-T960@97)R;W(@8V]D97,@<W1A8VLN#0H@("`@("H-
M"B`@("`@*B!`<&%R86T@(&UI>&5D("1E<G)O<E]C;V1E(&5R<F]R(&-O9&4@
M=&AA="!S:&]U;&0@8F4@9&5L971E9`T*("`@("`J($!R971U<FX@;6EX960@
M;&ES="!O9B!E<G)O<B!C;V1E<R!T:&%T('=E<F4@9&5L971E9"!O<B!E<G)O
M<@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0'-I;F-E(%!(4"`T
M+C,N,`T*("`@("`J+PT*("`@(&9U;F-T:6]N(&1E;$5X<&5C="@D97)R;W)?
M8V]D92D-"B`@("![#0H@("`@("`@("1D96QE=&5D(#T@9F%L<V4[#0H-"B`@
M("`@("`@:68@*"AI<U]A<G)A>2@D97)R;W)?8V]D92D@)B8@*#`@(3T@8V]U
M;G0H)&5R<F]R7V-O9&4I*2DI('L-"B`@("`@("`@("`@("\O("1E<G)O<E]C
M;V1E(&ES(&$@;F]N+65M<'1Y(&%R<F%Y(&AE<F4[#0H@("`@("`@("`@("`O
M+R!W92!W86QK('1H<F]U9V@@:70@=')Y:6YG('1O('5N<V5T(&%L;`T*("`@
M("`@("`@("`@+R\@=F%L=65S#0H@("`@("`@("`@("!F;W)E86-H*"1E<G)O
M<E]C;V1E(&%S("1K97D@/3X@)&5R<F]R*2![#0H@("`@("`@("`@("`@("`@
M:68@*"1T:&ES+3Y?8VAE8VM$96Q%>'!E8W0H)&5R<F]R*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D9&5L971E9"`]("!T<G5E.PT*("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1D96QE=&5D(#T@
M9F%L<V4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@<F5T=7)N("1D96QE=&5D(#\@=')U92`Z(%!%05(Z.G)A:7-E
M17)R;W(H(E1H92!E>'!E8W1E9"!E<G)O<B!Y;W4@<W5B;6ET=&5D(&1O97,@
M;F]T(&5X:7-T(BD[("\O($E-4%)/5D4@344-"B`@("`@("`@?2!E;'-E:68@
M*"%E;7!T>2@D97)R;W)?8V]D92DI('L-"B`@("`@("`@("`@("\O("1E<G)O
M<E]C;V1E(&-O;65S(&%L;VYE+"!T<GEI;F<@=&\@=6YS970@:70-"B`@("`@
M("`@("`@(&EF("@D=&AI<RT^7V-H96-K1&5L17AP96-T*"1E<G)O<E]C;V1E
M*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@B5&AE(&5X<&5C=&5D(&5R<F]R('EO=2!S=6)M:71T960@9&]E
M<R!N;W0@97AI<W0B*3L@+R\@24U04D]612!-10T*("`@("`@("`@("`@?0T*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@+R\@)&5R<F]R7V-O9&4@
M:7,@96UP='D-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*")4:&4@97AP96-T960@97)R;W(@>6]U('-U8FUI='1E9"!I<R!E;7!T>2(I
M.R`O+R!)35!23U9%($U%#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@<F%I<V5%<G)O<B@I#0H-"B`@("`O*BH-"B`@("`@
M*B!4:&ES(&UE=&AO9"!I<R!A('=R87!P97(@=&AA="!R971U<FYS(&%N(&EN
M<W1A;F-E(&]F('1H90T*("`@("`J(&-O;F9I9W5R960@97)R;W(@8VQA<W,@
M=VET:"!T:&ES(&]B:F5C="=S(&1E9F%U;'0@97)R;W(-"B`@("`@*B!H86YD
M;&EN9R!A<'!L:65D+B`@268@=&AE("1M;V1E(&%N9"`D;W!T:6]N<R!P87)A
M;65T97)S(&%R92!N;W0-"B`@("`@*B!S<&5C:69I960L('1H92!O8FIE8W0G
M<R!D969A=6QT<R!A<F4@=7-E9"X-"B`@("`@*@T*("`@("`J($!P87)A;2!M
M:7AE9"`D;65S<V%G92!A('1E>'0@97)R;W(@;65S<V%G92!O<B!A(%!%05(@
M97)R;W(@;V)J96-T#0H@("`@("H-"B`@("`@*B!`<&%R86T@:6YT("1C;V1E
M("`@("`@82!N=6UE<FEC(&5R<F]R(&-O9&4@*&ET(&ES('5P('1O('EO=7(@
M8VQA<W,-"B`@("`@*B`@("`@("`@("`@("`@("`@('1O(&1E9FEN92!T:&5S
M92!I9B!Y;W4@=V%N="!T;R!U<V4@8V]D97,I#0H@("`@("H-"B`@("`@*B!`
M<&%R86T@:6YT("1M;V1E("`@("`@3VYE(&]F(%!%05)?15)23U)?4D5455).
M+"!014%27T524D]27U!224Y4+`T*("`@("`J("`@("`@("`@("`@("`@("`@
M4$5!4E]%4E)/4E]44DE'1T52+"!014%27T524D]27T1)12P-"B`@("`@*B`@
M("`@("`@("`@("`@("`@(%!%05)?15)23U)?0T%,3$)!0TLL(%!%05)?15)2
M3U)?15A#15!424].+@T*("`@("`J#0H@("`@("H@0'!A<F%M(&UI>&5D("1O
M<'1I;VYS($EF("1M;V1E(&ES(%!%05)?15)23U)?5%))1T=%4BP@=&AI<R!P
M87)A;65T97(-"B`@("`@*B`@("`@("`@("`@("`@("`@('-P96-I9FEE<R!T
M:&4@4$A0+6EN=&5R;F%L(&5R<F]R(&QE=F5L("AO;F4@;V8-"B`@("`@*B`@
M("`@("`@("`@("`@("`@($5?55-%4E].3U1)0T4L($5?55-%4E]705).24Y'
M(&]R($5?55-%4E]%4E)/4BDN#0H@("`@("H@("`@("`@("`@("`@("`@("!)
M9B`D;6]D92!I<R!014%27T524D]27T-!3$Q"04-++"!T:&ES#0H@("`@("H@
M("`@("`@("`@("`@("`@("!P87)A;65T97(@<W!E8VEF:65S('1H92!C86QL
M8F%C:R!F=6YC=&EO;B!O<@T*("`@("`J("`@("`@("`@("`@("`@("`@;65T
M:&]D+B`@26X@;W1H97(@97)R;W(@;6]D97,@=&AI<R!P87)A;65T97(-"B`@
M("`@*B`@("`@("`@("`@("`@("`@(&ES(&EG;F]R960N#0H@("`@("H-"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1U<V5R:6YF;R!)9B!Y;W4@;F5E9"!T;R!P
M87-S(&%L;VYG(&9O<B!E>&%M<&QE(&1E8G5G#0H@("`@("H@("`@("`@("`@
M("`@("`@("!I;F9O<FUA=&EO;BP@=&AI<R!P87)A;65T97(@:7,@;65A;G0@
M9F]R('1H870N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1E<G)O
M<E]C;&%S<R!4:&4@<F5T=7)N960@97)R;W(@;V)J96-T('=I;&P@8F4-"B`@
M("`@*B`@("`@("`@("`@("`@("`@(&EN<W1A;G1I871E9"!F<F]M('1H:7,@
M8VQA<W,L(&EF('-P96-I9FEE9"X-"B`@("`@*@T*("`@("`J($!P87)A;2!B
M;V]L("1S:VEP;7-G($EF('1R=64L(')A:7-E17)R;W(@=VEL;"!O;FQY('!A
M<W,@97)R;W(@8V]D97,L#0H@("`@("H@("`@("`@("`@("`@("`@("!T:&4@
M97)R;W(@;65S<V%G92!P87)A;65T97(@=VEL;"!B92!D<F]P<&5D+@T*("`@
M("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`<F5T=7)N(&]B
M:F5C="`@(&$@4$5!4B!E<G)O<B!O8FIE8W0-"B`@("`@*B!`<V5E(%!%05(Z
M.G-E=$5R<F]R2&%N9&QI;F<-"B`@("`@*B!`<VEN8V4@4$A0(#0N,"XU#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@)G)A:7-E17)R;W(H)&UE<W-A9V4@/2!N
M=6QL+`T*("`@("`@("`@("`@("`@("`@("`@("`@("1C;V1E(#T@;G5L;"P-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`D;6]D92`](&YU;&PL#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@)&]P=&EO;G,@/2!N=6QL+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("1U<V5R:6YF;R`](&YU;&PL#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@)&5R<F]R7V-L87-S(#T@;G5L;"P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`D<VMI<&US9R`](&9A;'-E*0T*("`@('L-
M"B`@("`@("`@+R\@5&AE(&5R<F]R(&ES('EE="!A(%!%05(@97)R;W(@;V)J
M96-T#0H@("`@("`@(&EF("AI<U]O8FIE8W0H)&UE<W-A9V4I*2![#0H@("`@
M("`@("`@("`D8V]D92`@("`@("`@/2`D;65S<V%G92T^9V5T0V]D92@I.PT*
M("`@("`@("`@("`@)'5S97)I;F9O("`@(#T@)&UE<W-A9V4M/F=E=%5S97))
M;F9O*"D[#0H@("`@("`@("`@("`D97)R;W)?8VQA<W,@/2`D;65S<V%G92T^
M9V5T5'EP92@I.PT*("`@("`@("`@("`@)&UE<W-A9V4M/F5R<F]R7VUE<W-A
M9V5?<')E9FEX(#T@)R<[#0H@("`@("`@("`@("`D;65S<V%G92`@("`@/2`D
M;65S<V%G92T^9V5T365S<V%G92@I.PT*("`@("`@("!]#0H-"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES*2`F)B!I<W-E="@D=&AI<RT^7V5X<&5C=&5D7V5R
M<F]R<RD@)B8@<VEZ96]F*"1T:&ES+3Y?97AP96-T961?97)R;W)S*2`^(#`@
M)B8@<VEZ96]F*"1E>'`@/2!E;F0H)'1H:7,M/E]E>'!E8W1E9%]E<G)O<G,I
M*2D@>PT*("`@("`@("`@("`@:68@*"1E>'!;,%T@/3T@(BHB('Q\#0H@("`@
M("`@("`@("`@("`@*&ES7VEN="AR97-E="@D97AP*2D@)B8@:6Y?87)R87DH
M)&-O9&4L("1E>'`I*2!\?`T*("`@("`@("`@("`@("`@("AI<U]S=')I;F<H
M<F5S970H)&5X<"DI("8F(&EN7V%R<F%Y*"1M97-S86=E+"`D97AP*2DI('L-
M"B`@("`@("`@("`@("`@("`D;6]D92`](%!%05)?15)23U)?4D5455)..PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("\O($YO(&UO9&4@
M9VEV96XL('1R>2!G;&]B86P@;VYE<PT*("`@("`@("!I9B`H)&UO9&4@/3T]
M(&YU;&PI('L-"B`@("`@("`@("`@("\O($-L87-S(&5R<F]R(&AA;F1L97(-
M"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RD@)B8@:7-S970H)'1H:7,M
M/E]D969A=6QT7V5R<F]R7VUO9&4I*2![#0H@("`@("`@("`@("`@("`@)&UO
M9&4@("`@/2`D=&AI<RT^7V1E9F%U;'1?97)R;W)?;6]D93L-"B`@("`@("`@
M("`@("`@("`D;W!T:6]N<R`]("1T:&ES+3Y?9&5F875L=%]E<G)O<E]O<'1I
M;VYS.PT*("`@("`@("`@("`@+R\@1VQO8F%L(&5R<F]R(&AA;F1L97(-"B`@
M("`@("`@("`@('T@96QS96EF("AI<W-E="@D1TQ/0D%,4ULG7U!%05)?9&5F
M875L=%]E<G)O<E]M;V1E)UTI*2![#0H@("`@("`@("`@("`@("`@)&UO9&4@
M("`@/2`D1TQ/0D%,4ULG7U!%05)?9&5F875L=%]E<G)O<E]M;V1E)UT[#0H@
M("`@("`@("`@("`@("`@)&]P=&EO;G,@/2`D1TQ/0D%,4ULG7U!%05)?9&5F
M875L=%]E<G)O<E]O<'1I;VYS)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"@T*("`@("`@("!I9B`H)&5R<F]R7V-L87-S("$]/2!N=6QL*2![#0H@
M("`@("`@("`@("`D96,@/2`D97)R;W)?8VQA<W,[#0H@("`@("`@('T@96QS
M96EF("AI<W-E="@D=&AI<RD@)B8@:7-S970H)'1H:7,M/E]E<G)O<E]C;&%S
M<RDI('L-"B`@("`@("`@("`@("1E8R`]("1T:&ES+3Y?97)R;W)?8VQA<W,[
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D96,@/2`G4$5!4E]%
M<G)O<B<[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1S:VEP;7-G*2![#0H@
M("`@("`@("`@("`D82`]("9N97<@)&5C*"1C;V1E+"`D;6]D92P@)&]P=&EO
M;G,L("1U<V5R:6YF;RD[#0H@("`@("`@("`@("!R971U<FX@)&$[#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`D82`]("9N97<@)&5C*"1M97-S
M86=E+"`D8V]D92P@)&UO9&4L("1O<'1I;VYS+"`D=7-E<FEN9F\I.PT*("`@
M("`@("`@("`@<F5T=7)N("1A.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H@("`@+R\@>WM[('1H<F]W17)R;W(H*0T*#0H@("`@+RHJ#0H@
M("`@("H@4VEM<&QE<B!F;W)M(&]F(')A:7-E17)R;W(@=VET:"!F97=E<B!O
M<'1I;VYS+B`@26X@;6]S="!C87-E<PT*("`@("`J(&UE<W-A9V4L(&-O9&4@
M86YD('5S97)I;F9O(&%R92!E;F]U9V@N#0H@("`@("H-"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1M97-S86=E#0H@("`@("H-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B`F=&AR;W=%<G)O<B@D;65S<V%G92`](&YU;&PL#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@)&-O9&4@/2!N=6QL+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("1U<V5R:6YF;R`](&YU;&PI#0H@("`@>PT*("`@("`@("!I
M9B`H:7-S970H)'1H:7,I("8F(&ES7V$H)'1H:7,L("=014%2)RDI('L-"B`@
M("`@("`@("`@("1A(#T@)B1T:&ES+3YR86ES945R<F]R*"1M97-S86=E+"`D
M8V]D92P@;G5L;"P@;G5L;"P@)'5S97)I;F9O*3L-"B`@("`@("`@("`@(')E
M='5R;B`D83L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1A(#T@
M)E!%05(Z.G)A:7-E17)R;W(H)&UE<W-A9V4L("1C;V1E+"!N=6QL+"!N=6QL
M+"`D=7-E<FEN9F\I.PT*("`@("`@("`@("`@<F5T=7)N("1A.PT*("`@("`@
M("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@9G5N8W1I;VX@<W1A=&EC
M4'5S:$5R<F]R2&%N9&QI;F<H)&UO9&4L("1O<'1I;VYS(#T@;G5L;"D-"B`@
M("![#0H@("`@("`@("1S=&%C:R`]("8D1TQ/0D%,4ULG7U!%05)?97)R;W)?
M:&%N9&QE<E]S=&%C:R==.PT*("`@("`@("`D9&5F7VUO9&4@("`@/2`F)$=,
M3T)!3%-;)U]014%27V1E9F%U;'1?97)R;W)?;6]D92==.PT*("`@("`@("`D
M9&5F7V]P=&EO;G,@/2`F)$=,3T)!3%-;)U]014%27V1E9F%U;'1?97)R;W)?
M;W!T:6]N<R==.PT*("`@("`@("`D<W1A8VM;72`](&%R<F%Y*"1D969?;6]D
M92P@)&1E9E]O<'1I;VYS*3L-"B`@("`@("`@<W=I=&-H("@D;6]D92D@>PT*
M("`@("`@("`@("`@8V%S92!014%27T524D]27T580T505$E/3CH-"B`@("`@
M("`@("`@(&-A<V4@4$5!4E]%4E)/4E]215154DXZ#0H@("`@("`@("`@("!C
M87-E(%!%05)?15)23U)?4%))3E0Z#0H@("`@("`@("`@("!C87-E(%!%05)?
M15)23U)?5%))1T=%4CH-"B`@("`@("`@("`@(&-A<V4@4$5!4E]%4E)/4E]$
M244Z#0H@("`@("`@("`@("!C87-E(&YU;&PZ#0H@("`@("`@("`@("`@("`@
M)&1E9E]M;V1E(#T@)&UO9&4[#0H@("`@("`@("`@("`@("`@)&1E9E]O<'1I
M;VYS(#T@)&]P=&EO;G,[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@
M("`@("`@("`@(&-A<V4@4$5!4E]%4E)/4E]#04Q,0D%#2SH-"B`@("`@("`@
M("`@("`@("`D9&5F7VUO9&4@/2`D;6]D93L-"B`@("`@("`@("`@("`@("`O
M+R!C;&%S<R]O8FIE8W0@;65T:&]D(&-A;&QB86-K#0H@("`@("`@("`@("`@
M("`@:68@*&ES7V-A;&QA8FQE*"1O<'1I;VYS*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`D9&5F7V]P=&EO;G,@/2`D;W!T:6]N<SL-"B`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!T<FEG9V5R7V5R
M<F]R*")I;G9A;&ED(&5R<F]R(&-A;&QB86-K(BP@15]54T527U=!4DY)3D<I
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!B<F5A:SL-
M"@T*("`@("`@("`@("`@9&5F875L=#H-"B`@("`@("`@("`@("`@("!T<FEG
M9V5R7V5R<F]R*")I;G9A;&ED(&5R<F]R(&UO9&4B+"!%7U5315)?5T%23DE.
M1RD[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@('T-"B`@("`@
M("`@)'-T86-K6UT@/2!A<G)A>2@D;6]D92P@)&]P=&EO;G,I.PT*("`@("`@
M("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S=&%T:6-0
M;W!%<G)O<DAA;F1L:6YG*"D-"B`@("![#0H@("`@("`@("1S=&%C:R`]("8D
M1TQ/0D%,4ULG7U!%05)?97)R;W)?:&%N9&QE<E]S=&%C:R==.PT*("`@("`@
M("`D<V5T;6]D92`@("`@/2`F)$=,3T)!3%-;)U]014%27V1E9F%U;'1?97)R
M;W)?;6]D92==.PT*("`@("`@("`D<V5T;W!T:6]N<R`@/2`F)$=,3T)!3%-;
M)U]014%27V1E9F%U;'1?97)R;W)?;W!T:6]N<R==.PT*("`@("`@("!A<G)A
M>5]P;W`H)'-T86-K*3L-"B`@("`@("`@;&ES="@D;6]D92P@)&]P=&EO;G,I
M(#T@)'-T86-K6W-I>F5O9B@D<W1A8VLI("T@,5T[#0H@("`@("`@(&%R<F%Y
M7W!O<"@D<W1A8VLI.PT*("`@("`@("!S=VET8V@@*"1M;V1E*2![#0H@("`@
M("`@("`@("!C87-E(%!%05)?15)23U)?15A#15!424]..@T*("`@("`@("`@
M("`@8V%S92!014%27T524D]27U)%5%523CH-"B`@("`@("`@("`@(&-A<V4@
M4$5!4E]%4E)/4E]04DE.5#H-"B`@("`@("`@("`@(&-A<V4@4$5!4E]%4E)/
M4E]44DE'1T52.@T*("`@("`@("`@("`@8V%S92!014%27T524D]27T1)13H-
M"B`@("`@("`@("`@(&-A<V4@;G5L;#H-"B`@("`@("`@("`@("`@("`D<V5T
M;6]D92`]("1M;V1E.PT*("`@("`@("`@("`@("`@("1S971O<'1I;VYS(#T@
M)&]P=&EO;G,[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@
M("`@(&-A<V4@4$5!4E]%4E)/4E]#04Q,0D%#2SH-"B`@("`@("`@("`@("`@
M("`D<V5T;6]D92`]("1M;V1E.PT*("`@("`@("`@("`@("`@("\O(&-L87-S
M+V]B:F5C="!M971H;V0@8V%L;&)A8VL-"B`@("`@("`@("`@("`@("!I9B`H
M:7-?8V%L;&%B;&4H)&]P=&EO;G,I*2![#0H@("`@("`@("`@("`@("`@("`@
M("1S971O<'1I;VYS(#T@)&]P=&EO;G,[#0H@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@=')I9V=E<E]E<G)O<B@B:6YV
M86QI9"!E<G)O<B!C86QL8F%C:R(L($5?55-%4E]705).24Y'*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@
M("`@("`@(&1E9F%U;'0Z#0H@("`@("`@("`@("`@("`@=')I9V=E<E]E<G)O
M<B@B:6YV86QI9"!E<G)O<B!M;V1E(BP@15]54T527U=!4DY)3D<I.PT*("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@('T-"@T*("`@("\O('M[>R!P=7-H17)R;W)(86YD;&EN
M9R@I#0H-"B`@("`O*BH-"B`@("`@*B!0=7-H(&$@;F5W(&5R<F]R(&AA;F1L
M97(@;VX@=&]P(&]F('1H92!E<G)O<B!H86YD;&5R(&]P=&EO;G,@<W1A8VLN
M(%=I=&@@=&AI<PT*("`@("`J('EO=2!C86X@96%S:6QY(&]V97)R:61E('1H
M92!A8W1U86P@97)R;W(@:&%N9&QE<B!F;W(@<V]M92!C;V1E(&%N9"!R97-T
M;W)E#0H@("`@("H@:70@;&%T97(@=VET:"!P;W!%<G)O<DAA;F1L:6YG+@T*
M("`@("`J#0H@("`@("H@0'!A<F%M(&UI>&5D("1M;V1E("AS86UE(&%S('-E
M=$5R<F]R2&%N9&QI;F<I#0H@("`@("H@0'!A<F%M(&UI>&5D("1O<'1I;VYS
M("AS86UE(&%S('-E=$5R<F]R2&%N9&QI;F<I#0H@("`@("H-"B`@("`@*B!`
M<F5T=7)N(&)O;VP@06QW87ES('1R=64-"B`@("`@*@T*("`@("`J($!S964@
M4$5!4CHZ<V5T17)R;W)(86YD;&EN9PT*("`@("`J+PT*("`@(&9U;F-T:6]N
M('!U<VA%<G)O<DAA;F1L:6YG*"1M;V1E+"`D;W!T:6]N<R`](&YU;&PI#0H@
M("`@>PT*("`@("`@("`D<W1A8VL@/2`F)$=,3T)!3%-;)U]014%27V5R<F]R
M7VAA;F1L97)?<W1A8VLG73L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES*2`F
M)B!I<U]A*"1T:&ES+"`G4$5!4B<I*2![#0H@("`@("`@("`@("`D9&5F7VUO
M9&4@("`@/2`F)'1H:7,M/E]D969A=6QT7V5R<F]R7VUO9&4[#0H@("`@("`@
M("`@("`D9&5F7V]P=&EO;G,@/2`F)'1H:7,M/E]D969A=6QT7V5R<F]R7V]P
M=&EO;G,[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D9&5F7VUO
M9&4@("`@/2`F)$=,3T)!3%-;)U]014%27V1E9F%U;'1?97)R;W)?;6]D92==
M.PT*("`@("`@("`@("`@)&1E9E]O<'1I;VYS(#T@)B1'3$]"04Q36R=?4$5!
M4E]D969A=6QT7V5R<F]R7V]P=&EO;G,G73L-"B`@("`@("`@?0T*("`@("`@
M("`D<W1A8VM;72`](&%R<F%Y*"1D969?;6]D92P@)&1E9E]O<'1I;VYS*3L-
M"@T*("`@("`@("!I9B`H:7-S970H)'1H:7,I("8F(&ES7V$H)'1H:7,L("=0
M14%2)RDI('L-"B`@("`@("`@("`@("1T:&ES+3YS971%<G)O<DAA;F1L:6YG
M*"1M;V1E+"`D;W!T:6]N<RD[#0H@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("!014%2.CIS971%<G)O<DAA;F1L:6YG*"1M;V1E+"`D;W!T:6]N<RD[
M#0H@("`@("`@('T-"B`@("`@("`@)'-T86-K6UT@/2!A<G)A>2@D;6]D92P@
M)&]P=&EO;G,I.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@<&]P17)R;W)(86YD;&EN9R@I#0H-"B`@
M("`O*BH-"B`@("`J(%!O<"!T:&4@;&%S="!E<G)O<B!H86YD;&5R('5S960-
M"B`@("`J#0H@("`@*B!`<F5T=7)N(&)O;VP@06QW87ES('1R=64-"B`@("`J
M#0H@("`@*B!`<V5E(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG#0H@("`@*B\-
M"B`@("!F=6YC=&EO;B!P;W!%<G)O<DAA;F1L:6YG*"D-"B`@("![#0H@("`@
M("`@("1S=&%C:R`]("8D1TQ/0D%,4ULG7U!%05)?97)R;W)?:&%N9&QE<E]S
M=&%C:R==.PT*("`@("`@("!A<G)A>5]P;W`H)'-T86-K*3L-"B`@("`@("`@
M;&ES="@D;6]D92P@)&]P=&EO;G,I(#T@)'-T86-K6W-I>F5O9B@D<W1A8VLI
M("T@,5T[#0H@("`@("`@(&%R<F%Y7W!O<"@D<W1A8VLI.PT*("`@("`@("!I
M9B`H:7-S970H)'1H:7,I("8F(&ES7V$H)'1H:7,L("=014%2)RDI('L-"B`@
M("`@("`@("`@("1T:&ES+3YS971%<G)O<DAA;F1L:6YG*"1M;V1E+"`D;W!T
M:6]N<RD[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!014%2.CIS
M971%<G)O<DAA;F1L:6YG*"1M;V1E+"`D;W!T:6]N<RD[#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(&QO861%>'1E;G-I;VXH*0T*#0H@("`@+RHJ#0H@("`@*B!/
M4R!I;F1E<&5N9&%N="!02%`@97AT96YS:6]N(&QO860N(%)E;65M8F5R('1O
M('1A:V4@8V%R90T*("`@("H@;VX@=&AE(&-O<G)E8W0@97AT96YS:6]N(&YA
M;64@9F]R(&-A<V4@<V5N<VET:79E($]397,N#0H@("`@*@T*("`@("H@0'!A
M<F%M('-T<FEN9R`D97AT(%1H92!E>'1E;G-I;VX@;F%M90T*("`@("H@0')E
M='5R;B!B;V]L(%-U8V-E<W,@;W(@;F]T(&]N('1H92!D;"@I(&-A;&P-"B`@
M("`J+PT*("`@(&9U;F-T:6]N(&QO861%>'1E;G-I;VXH)&5X="D-"B`@("![
M#0H@("`@("`@(&EF("@A97AT96YS:6]N7VQO861E9"@D97AT*2D@>PT*("`@
M("`@("`@("`@+R\@:68@96ET:&5R(')E='5R;G,@=')U92!D;"@I('=I;&P@
M<')O9'5C92!A($9!5$%,(&5R<F]R+"!S=&]P('1H870-"B`@("`@("`@("`@
M(&EF("@H:6YI7V=E="@G96YA8FQE7V1L)RD@(3T@,2D@?'P@*&EN:5]G970H
M)W-A9F5?;6]D92<I(#T](#$I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*$]37U=)
M3D1/5U,I('L-"B`@("`@("`@("`@("`@("`D<W5F9FEX(#T@)RYD;&PG.PT*
M("`@("`@("`@("`@?2!E;'-E:68@*%!(4%]/4R`]/2`G2%`M55@G*2![#0H@
M("`@("`@("`@("`@("`@)'-U9F9I>"`]("<N<VPG.PT*("`@("`@("`@("`@
M?2!E;'-E:68@*%!(4%]/4R`]/2`G04E8)RD@>PT*("`@("`@("`@("`@("`@
M("1S=69F:7@@/2`G+F$G.PT*("`@("`@("`@("`@?2!E;'-E:68@*%!(4%]/
M4R`]/2`G3U-8)RD@>PT*("`@("`@("`@("`@("`@("1S=69F:7@@/2`G+F)U
M;F1L92<[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("1S=69F:7@@/2`G+G-O)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(')E='5R;B!`9&PH)W!H<%\G+B1E>'0N)'-U9F9I>"D@?'P@0&1L*"1E>'0N
M)'-U9F9I>"D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@?0T*#0H@("`@+R\@?7U]#0I]#0H-"B\O('M[>R!?4$5!4E]C86QL7V1E
M<W1R=6-T;W)S*"D-"@T*9G5N8W1I;VX@7U!%05)?8V%L;%]D97-T<G5C=&]R
M<R@I#0I[#0H@("`@9VQO8F%L("1?4$5!4E]D97-T<G5C=&]R7V]B:F5C=%]L
M:7-T.PT*("`@(&EF("AI<U]A<G)A>2@D7U!%05)?9&5S=')U8W1O<E]O8FIE
M8W1?;&ES="D@)B8-"B`@("`@("`@<VEZ96]F*"1?4$5!4E]D97-T<G5C=&]R
M7V]B:F5C=%]L:7-T*2D-"B`@("![#0H@("`@("`@(')E<V5T*"1?4$5!4E]D
M97-T<G5C=&]R7V]B:F5C=%]L:7-T*3L-"B`@("`@("`@:68@*$!014%2.CIG
M9713=&%T:6-0<F]P97)T>2@G4$5!4B<L("=D97-T<G5C=&QI9F\G*2D@>PT*
M("`@("`@("`@("`@)%]014%27V1E<W1R=6-T;W)?;V)J96-T7VQI<W0@/2!A
M<G)A>5]R979E<G-E*"1?4$5!4E]D97-T<G5C=&]R7V]B:F5C=%]L:7-T*3L-
M"B`@("`@("`@?0T*("`@("`@("!W:&EL92`H;&ES="@D:RP@)&]B:G)E9BD@
M/2!E86-H*"1?4$5!4E]D97-T<G5C=&]R7V]B:F5C=%]L:7-T*2D@>PT*("`@
M("`@("`@("`@)&-L87-S;F%M92`](&=E=%]C;&%S<R@D;V)J<F5F*3L-"B`@
M("`@("`@("`@('=H:6QE("@D8VQA<W-N86UE*2![#0H@("`@("`@("`@("`@
M("`@)&1E<W1R=6-T;W(@/2`B7R1C;&%S<VYA;64B.PT*("`@("`@("`@("`@
M("`@(&EF("AM971H;V1?97AI<W1S*"1O8FIR968L("1D97-T<G5C=&]R*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`D;V)J<F5F+3XD9&5S=')U8W1O<B@I
M.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D8VQA<W-N86UE(#T@
M9V5T7W!A<F5N=%]C;&%S<R@D8VQA<W-N86UE*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@+R\@16UP
M='D@=&AE(&]B:F5C="!L:7-T('1O(&5N<W5R92!T:&%T(&1E<W1R=6-T;W)S
M(&%R90T*("`@("`@("`O+R!N;W0@8V%L;&5D(&UO<F4@=&AA;B!O;F-E+@T*
M("`@("`@("`D7U!%05)?9&5S=')U8W1O<E]O8FIE8W1?;&ES="`](&%R<F%Y
M*"D[#0H@("`@?0T*#0H@("`@+R\@3F]W(&-A;&P@=&AE('-H=71D;W=N(&9U
M;F-T:6]N<PT*("`@(&EF("AI<U]A<G)A>2@D1TQ/0D%,4ULG7U!%05)?<VAU
M=&1O=VY?9G5N8W,G72D@04Y$("%E;7!T>2@D1TQ/0D%,4ULG7U!%05)?<VAU
M=&1O=VY?9G5N8W,G72DI('L-"B`@("`@("`@9F]R96%C:"`H)$=,3T)!3%-;
M)U]014%27W-H=71D;W=N7V9U;F-S)UT@87,@)'9A;'5E*2![#0H@("`@("`@
M("`@("!C86QL7W5S97)?9G5N8U]A<G)A>2@D=F%L=65;,%TL("1V86QU95LQ
M72D[#0H@("`@("`@('T-"B`@("!]#0I]#0H-"B\O('U]?0T*+RHJ#0H@*B!3
M=&%N9&%R9"!014%2(&5R<F]R(&-L87-S(&9O<B!02%`@-`T*("H-"B`J(%1H
M:7,@8VQA<W,@:7,@<W5P<V5R<V5D960@8GD@>T!L:6YK(%!%05)?17AC97!T
M:6]N?2!I;B!02%`@-0T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P
M86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS
M<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@(%1O;6%S(%8N5BX@0V]X(#QC
M;WA`:61E8VYE="YC;VT^#0H@*B!`875T:&]R("`@("!'<F5G;W)Y($)E879E
M<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@
M5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R
M<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]M86YU86PO96XO8V]R92YP96%R+G!E87(M97)R;W(N
M<&AP#0H@*B!`<V5E("`@("`@("!014%2.CIR86ES945R<F]R*"DL(%!%05(Z
M.G1H<F]W17)R;W(H*0T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE
M('-I;F-E(%!(4"`T+C`N,@T*("HO#0IC;&%S<R!014%27T5R<F]R#0I[#0H@
M("`@+R\@>WM[('!R;W!E<G1I97,-"@T*("`@('9A<B`D97)R;W)?;65S<V%G
M95]P<F5F:7@@/2`G)SL-"B`@("!V87(@)&UO9&4@("`@("`@("`@("`@("`@
M(#T@4$5!4E]%4E)/4E]215154DX[#0H@("`@=F%R("1L979E;"`@("`@("`@
M("`@("`@("`]($5?55-%4E].3U1)0T4[#0H@("`@=F%R("1C;V1E("`@("`@
M("`@("`@("`@("`]("TQ.PT*("`@('9A<B`D;65S<V%G92`@("`@("`@("`@
M("`@/2`G)SL-"B`@("!V87(@)'5S97)I;F9O("`@("`@("`@("`@(#T@)R<[
M#0H@("`@=F%R("1B86-K=')A8V4@("`@("`@("`@("`](&YU;&P[#0H-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@8V]N<W1R=6-T;W(-"@T*("`@("\J*@T*
M("`@("`J(%!%05)?17)R;W(@8V]N<W1R=6-T;W(-"B`@("`@*@T*("`@("`J
M($!P87)A;2!S=')I;F<@)&UE<W-A9V4@(&UE<W-A9V4-"B`@("`@*@T*("`@
M("`J($!P87)A;2!I;G0@)&-O9&4@("`@("AO<'1I;VYA;"D@97)R;W(@8V]D
M90T*("`@("`J#0H@("`@("H@0'!A<F%M(&EN="`D;6]D92`@("`@*&]P=&EO
M;F%L*2!E<G)O<B!M;V1E+"!O;F4@;V8Z(%!%05)?15)23U)?4D5455).+`T*
M("`@("`J(%!%05)?15)23U)?4%))3E0L(%!%05)?15)23U)?1$E%+"!014%2
M7T524D]27U1224='15(L#0H@("`@("H@4$5!4E]%4E)/4E]#04Q,0D%#2R!O
M<B!014%27T524D]27T580T505$E/3@T*("`@("`J#0H@("`@("H@0'!A<F%M
M(&UI>&5D("1O<'1I;VYS("`@*&]P=&EO;F%L*2!E<G)O<B!L979E;"P@7T]2
M7R!I;B!T:&4@8V%S92!O9@T*("`@("`J(%!%05)?15)23U)?0T%,3$)!0TLL
M('1H92!C86QL8F%C:R!F=6YC=&EO;B!O<B!O8FIE8W0O;65T:&]D#0H@("`@
M("H@='5P;&4N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R
M:6YF;R`H;W!T:6]N86PI(&%D9&ET:6]N86P@=7-E<B]D96)U9R!I;F9O#0H@
M("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@4$5!4E]%<G)O<B@D;65S<V%G92`]("=U;FMN;W=N
M(&5R<F]R)RP@)&-O9&4@/2!N=6QL+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@)&UO9&4@/2!N=6QL+"`D;W!T:6]N<R`](&YU;&PL("1U<V5R:6YF;R`]
M(&YU;&PI#0H@("`@>PT*("`@("`@("!I9B`H)&UO9&4@/3T](&YU;&PI('L-
M"B`@("`@("`@("`@("1M;V1E(#T@4$5!4E]%4E)/4E]215154DX[#0H@("`@
M("`@('T-"B`@("`@("`@)'1H:7,M/FUE<W-A9V4@("`]("1M97-S86=E.PT*
M("`@("`@("`D=&AI<RT^8V]D92`@("`@(#T@)&-O9&4[#0H@("`@("`@("1T
M:&ES+3YM;V1E("`@("`@/2`D;6]D93L-"B`@("`@("`@)'1H:7,M/G5S97)I
M;F9O("`]("1U<V5R:6YF;SL-"B`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T
M<R@B9&5B=6=?8F%C:W1R86-E(BDI('L-"B`@("`@("`@("`@(&EF("A`(5!%
M05(Z.F=E=%-T871I8U!R;W!E<G1Y*"=014%27T5R<F]R)RP@)W-K:7!T<F%C
M92<I*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/F)A8VMT<F%C92`](&1E
M8G5G7V)A8VMT<F%C92@I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(&EF("@D;6]D92`F(%!%05)?15)23U)?0T%,3$)!0TLI('L-"B`@
M("`@("`@("`@("1T:&ES+3YL979E;"`]($5?55-%4E].3U1)0T4[#0H@("`@
M("`@("`@("`D=&AI<RT^8V%L;&)A8VL@/2`D;W!T:6]N<SL-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@(&EF("@D;W!T:6]N<R`]/3T@;G5L;"D@
M>PT*("`@("`@("`@("`@("`@("1O<'1I;VYS(#T@15]54T527TY/5$E#13L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T:&ES+3YL979E;"`]("1O
M<'1I;VYS.PT*("`@("`@("`@("`@)'1H:7,M/F-A;&QB86-K(#T@;G5L;#L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1H:7,M/FUO9&4@)B!014%27T52
M4D]27U!224Y4*2![#0H@("`@("`@("`@("!I9B`H:7-?;G5L;"@D;W!T:6]N
M<RD@?'P@:7-?:6YT*"1O<'1I;VYS*2D@>PT*("`@("`@("`@("`@("`@("1F
M;W)M870@/2`B)7,B.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`D9F]R;6%T(#T@)&]P=&EO;G,[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!P<FEN=&8H)&9O<FUA="P@)'1H:7,M/F=E=$UE<W-A9V4H
M*2D[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES+3YM;V1E("8@4$5!
M4E]%4E)/4E]44DE'1T52*2![#0H@("`@("`@("`@("!T<FEG9V5R7V5R<F]R
M*"1T:&ES+3YG971-97-S86=E*"DL("1T:&ES+3YL979E;"D[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"1T:&ES+3YM;V1E("8@4$5!4E]%4E)/4E]$244I
M('L-"B`@("`@("`@("`@("1M<V<@/2`D=&AI<RT^9V5T365S<V%G92@I.PT*
M("`@("`@("`@("`@:68@*&ES7VYU;&PH)&]P=&EO;G,I('Q\(&ES7VEN="@D
M;W!T:6]N<RDI('L-"B`@("`@("`@("`@("`@("`D9F]R;6%T(#T@(B5S(CL-
M"B`@("`@("`@("`@("`@("!I9B`H<W5B<W1R*"1M<V<L("TQ*2`A/2`B7&XB
M*2![#0H@("`@("`@("`@("`@("`@("`@("1M<V<@+CT@(EQN(CL-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("1F;W)M870@/2`D;W!T:6]N<SL-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&1I92AS<')I;G1F*"1F;W)M870L("1M<V<I*3L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H)'1H:7,M/FUO9&4@)B!014%27T524D]27T-!
M3$Q"04-+*2![#0H@("`@("`@("`@("!I9B`H:7-?8V%L;&%B;&4H)'1H:7,M
M/F-A;&QB86-K*2D@>PT*("`@("`@("`@("`@("`@(&-A;&Q?=7-E<E]F=6YC
M*"1T:&ES+3YC86QL8F%C:RP@)'1H:7,I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(&EF("@D=&AI<RT^;6]D92`F(%!%05)?15)23U)?
M15A#15!424].*2![#0H@("`@("`@("`@("!T<FEG9V5R7V5R<F]R*")014%2
M7T524D]27T580T505$E/3B!I<R!O8G-O;&5T92P@=7-E(&-L87-S(%!%05)?
M17AC97!T:6]N(&9O<B!E>&-E<'1I;VYS(BP@15]54T527U=!4DY)3D<I.PT*
M("`@("`@("`@("`@979A;"@G)&4@/2!N97<@17AC97!T:6]N*"1T:&ES+3YM
M97-S86=E+"`D=&AI<RT^8V]D92D[=&AR;W<H)&4I.R<I.PT*("`@("`@("!]
M#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=$UO9&4H*0T*
M#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!E<G)O<B!M;V1E(&9R;VT@86X@
M97)R;W(@;V)J96-T+@T*("`@("`J#0H@("`@("H@0')E='5R;B!I;G0@97)R
M;W(@;6]D90T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@9V5T36]D92@I('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YM
M;V1E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G971#86QL
M8F%C:R@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(&-A;&QB86-K(&9U
M;F-T:6]N+VUE=&AO9"!F<F]M(&%N(&5R<F]R(&]B:F5C="X-"B`@("`@*@T*
M("`@("`J($!R971U<FX@;6EX960@8V%L;&)A8VL@9G5N8W1I;VX@;W(@;V)J
M96-T+VUE=&AO9"!A<G)A>0T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@9V5T0V%L;&)A8VLH*2![#0H@("`@("`@(')E
M='5R;B`D=&AI<RT^8V%L;&)A8VL[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(&=E=$UE<W-A9V4H*0T*#0H-"B`@("`O*BH-"B`@("`@*B!'
M970@=&AE(&5R<F]R(&UE<W-A9V4@9G)O;2!A;B!E<G)O<B!O8FIE8W0N#0H@
M("`@("H-"B`@("`@*B!`<F5T=7)N("!S=')I;F<@(&9U;&P@97)R;W(@;65S
M<V%G90T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@9V5T365S<V%G92@I#0H@("`@>PT*("`@("`@("!R971U<FX@*"1T
M:&ES+3YE<G)O<E]M97-S86=E7W!R969I>"`N("1T:&ES+3YM97-S86=E*3L-
M"B`@("!]#0H-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G971#;V1E*"D-
M"@T*("`@("\J*@T*("`@("`J($=E="!E<G)O<B!C;V1E(&9R;VT@86X@97)R
M;W(@;V)J96-T#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&EN="!E<G)O<B!C
M;V1E#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("`@9G5N
M8W1I;VX@9V5T0V]D92@I#0H@("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES
M+3YC;V1E.PT*("`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T
M5'EP92@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(&YA;64@;V8@=&AI
M<R!E<G)O<B]E>&-E<'1I;VXN#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R!E<G)O<B]E>&-E<'1I;VX@;F%M92`H='EP92D-"B`@("`@*B!`86-C
M97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0T*
M("`@('L-"B`@("`@("`@<F5T=7)N(&=E=%]C;&%S<R@D=&AI<RD[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=%5S97));F9O*"D-"@T*
M("`@("\J*@T*("`@("`J($=E="!A9&1I=&EO;F%L('5S97(M<W5P<&QI960@
M:6YF;W)M871I;VXN#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('-T<FEN9R!U
M<V5R+7-U<'!L:65D(&EN9F]R;6%T:6]N#0H@("`@("H@0&%C8V5S<R!P=6)L
M:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G9715<V5R26YF;R@I#0H@("`@
M>PT*("`@("`@("!R971U<FX@)'1H:7,M/G5S97)I;F9O.PT*("`@('T-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R!G971$96)U9TEN9F\H*0T*#0H@("`@
M+RHJ#0H@("`@("H@1V5T(&%D9&ET:6]N86P@9&5B=6<@:6YF;W)M871I;VX@
M<W5P<&QI960@8GD@=&AE(&%P<&QI8V%T:6]N+@T*("`@("`J#0H@("`@("H@
M0')E='5R;B!S=')I;F<@9&5B=6<@:6YF;W)M871I;VX-"B`@("`@*B!`86-C
M97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$1E8G5G26YF
M;R@I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/F=E=%5S97));F9O
M*"D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=$)A8VMT
M<F%C92@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(&-A;&P@8F%C:W1R
M86-E(&9R;VT@=VAE<F4@=&AE(&5R<F]R('=A<R!G96YE<F%T960N#0H@("`@
M("H@4W5P<&]R=&5D('=I=&@@4$A0(#0N,RXP(&]R(&YE=V5R+@T*("`@("`J
M#0H@("`@("H@0'!A<F%M(&EN="`D9G)A;64@*&]P=&EO;F%L*2!W:&%T(&9R
M86UE('1O(&9E=&-H#0H@("`@("H@0')E='5R;B!A<G)A>2!"86-K=')A8V4L
M(&]R($Y53$P@:68@;F]T(&%V86EL86)L92X-"B`@("`@*B!`86-C97-S('!U
M8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$)A8VMT<F%C92@D9G)A
M;64@/2!N=6QL*0T*("`@('L-"B`@("`@("`@:68@*&1E9FEN960H)U!%05)?
M24=.3U)%7T)!0TM44D%#12<I*2![#0H@("`@("`@("`@("!R971U<FX@;G5L
M;#L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&9R86UE(#T]/2!N=6QL*2![
M#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/F)A8VMT<F%C93L-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/F)A8VMT<F%C95LD9G)A;65=
M.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!A9&15<V5R26YF
M;R@I#0H-"B`@("!F=6YC=&EO;B!A9&15<V5R26YF;R@D:6YF;RD-"B`@("![
M#0H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^=7-E<FEN9F\I*2![#0H@("`@
M("`@("`@("`D=&AI<RT^=7-E<FEN9F\@/2`D:6YF;SL-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("1T:&ES+3YU<V5R:6YF;R`N/2`B("HJ("1I
M;F9O(CL-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O
M('M[>R!T;U-T<FEN9R@I#0H-"B`@("`O*BH-"B`@("`@*B!-86ME(&$@<W1R
M:6YG(')E<')E<V5N=&%T:6]N(&]F('1H:7,@;V)J96-T+@T*("`@("`J#0H@
M("`@("H@0')E='5R;B!S=')I;F<@82!S=')I;F<@=VET:"!A;B!O8FIE8W0@
M<W5M;6%R>0T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@=&]3=')I;F<H*2![#0H@("`@("`@("1M;V1E<R`](&%R<F%Y
M*"D[#0H@("`@("`@("1L979E;',@/2!A<G)A>2A%7U5315)?3D]424-%("`]
M/B`G;F]T:6-E)RP-"B`@("`@("`@("`@("`@("`@("`@("`@($5?55-%4E]7
M05).24Y'(#T^("=W87)N:6YG)RP-"B`@("`@("`@("`@("`@("`@("`@("`@
M($5?55-%4E]%4E)/4B`@(#T^("=E<G)O<B<I.PT*("`@("`@("!I9B`H)'1H
M:7,M/FUO9&4@)B!014%27T524D]27T-!3$Q"04-+*2![#0H@("`@("`@("`@
M("!I9B`H:7-?87)R87DH)'1H:7,M/F-A;&QB86-K*2D@>PT*("`@("`@("`@
M("`@("`@("1C86QL8F%C:R`]("AI<U]O8FIE8W0H)'1H:7,M/F-A;&QB86-K
M6S!=*2`_#0H@("`@("`@("`@("`@("`@("`@('-T<G1O;&]W97(H9V5T7V-L
M87-S*"1T:&ES+3YC86QL8F%C:ULP72DI(#H-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/F-A;&QB86-K6S!=*2`N("<Z.B<@+@T*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^8V%L;&)A8VM;,5T[#0H@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("1C86QL8F%C:R`]("1T:&ES+3YC86QL
M8F%C:SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B!S<')I
M;G1F*"=;)7,Z(&UE<W-A9V4](B5S(B!C;V1E/25D(&UO9&4]8V%L;&)A8VL@
M)RX-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("=C86QL8F%C:STE<R!P
M<F5F:7@](B5S(B!I;F9O/2(E<R)=)RP-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-T<G1O;&]W97(H9V5T7V-L87-S*"1T:&ES*2DL("1T:&ES+3YM
M97-S86=E+"`D=&AI<RT^8V]D92P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1C86QL8F%C:RP@)'1H:7,M/F5R<F]R7VUE<W-A9V5?<')E9FEX+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5S97)I;F9O*3L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1H:7,M/FUO9&4@)B!014%27T52
M4D]27U!224Y4*2![#0H@("`@("`@("`@("`D;6]D97-;72`]("=P<FEN="<[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES+3YM;V1E("8@4$5!4E]%
M4E)/4E]44DE'1T52*2![#0H@("`@("`@("`@("`D;6]D97-;72`]("=T<FEG
M9V5R)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1H:7,M/FUO9&4@)B!0
M14%27T524D]27T1)12D@>PT*("`@("`@("`@("`@)&UO9&5S6UT@/2`G9&EE
M)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1H:7,M/FUO9&4@)B!014%2
M7T524D]27U)%5%523BD@>PT*("`@("`@("`@("`@)&UO9&5S6UT@/2`G<F5T
M=7)N)SL-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@<W!R:6YT9B@G6R5S
M.B!M97-S86=E/2(E<R(@8V]D93TE9"!M;V1E/25S(&QE=F5L/25S("<N#0H@
M("`@("`@("`@("`@("`@("`@("`@("=P<F5F:7@](B5S(B!I;F9O/2(E<R)=
M)RP-"B`@("`@("`@("`@("`@("`@("`@("`@<W1R=&]L;W=E<BAG971?8VQA
M<W,H)'1H:7,I*2P@)'1H:7,M/FUE<W-A9V4L("1T:&ES+3YC;V1E+`T*("`@
M("`@("`@("`@("`@("`@("`@("!I;7!L;V1E*")\(BP@)&UO9&5S*2P@)&QE
M=F5L<ULD=&AI<RT^;&5V96Q=+`T*("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^97)R;W)?;65S<V%G95]P<F5F:7@L#0H@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YU<V5R:6YF;RD[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0I]#0H-"B\J#0H@*B!,;V-A;"!687)I86)L97,Z#0H@*B!M;V1E.B!P:'`-
M"B`J('1A8BUW:61T:#H@-`T*("H@8RUB87-I8RUO9F9S970Z(#0-"B`J($5N
M9#H-"B`J+PT*/SX-"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O<&5A<F-M9"YP:'``````````````
M````````````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S4V,3,`,3`U,34T
M,S,W-#,`,#(P-S0P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP#0HO+PT*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK#0HO+R!\(%!(4"!697)S:6]N(#4@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!#;W!Y<FEG:'0@*&,I
M(#$Y.3<M,C`P-"!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-
M"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@
M,RXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`T*+R\@?"!T:&%T(&ES
M(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y3
M12P@86YD(&ES("`@("`@("!\#0HO+R!\(&%V86EL86)L92!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG('5R;#H@("`@("`@
M("`@('P-"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!)
M9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N
M<V4@86YD(&%R92!U;F%B;&4@=&\@("!\#0HO+R!\(&]B=&%I;B!I="!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O
M("`@("`@("`@('P-"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`T*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\($%U=&AO<G,Z
M(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P-"B\O('P@("`@("`@("`@5&]M87,@5BY6+D-O
M>"`\8V]X0&ED96-N970N8V]M/B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O#0HO+R`D260Z('!E87)C;60N
M<&AP+'8@,2XS,R`R,#`V+S`Q+S`R(#$X.C`U.C4S(&-E;&QO9R!%>'`@)`T*
M#0IO8E]E;F1?8VQE86XH*3L-"FEF("@A9&5F:6YE9"@G4$5!4E]254Y465!%
M)RDI('L-"B`@("`O+R!T:&ES(&ES(&1E9FEN960@:6X@<&5C;&-M9"YP:'`@
M87,@)W!E8VPG#0H@("`@9&5F:6YE*"=014%27U)53E194$4G+"`G<&5A<B<I
M.PT*?0T*9&5F:6YE*"=014%27TE'3D]215]"04-+5%)!0T4G+"`Q*3L-"FEF
M("@A9G5N8W1I;VY?97AI<W1S*"=F:6QE7V=E=%]C;VYT96YT<R<I*2![#0H@
M("`@9G5N8W1I;VX@9FEL95]G971?8V]N=&5N=',H)&9I;&5N86UE*0T*("`@
M('L-"B`@("`@("`@)&9P(#T@9F]P96XH)&9I;&5N86UE+"`G<F(G*3L-"B`@
M("`@("`@)')E="`]("<G.PT*("`@("`@("!W:&EL92`H(69E;V8H)&9P*2D@
M>PT*("`@("`@("`@("`@)')E="`N/2!F<F5A9"@D9G`L(#@P.3(I.SL-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0I]#0HO*BH-
M"B`J($!N;V1E<"!'=&L-"B`J+PT*:68@*"<O=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B<@(3T@)T`G+B=I;F-L=61E7W!A=&@G+B=`)RD@>PT*("`@
M(&EN:5]S970H)VEN8VQU9&5?<&%T:"<L("<O=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B<I.PT*("`@("1R87<@/2!F86QS93L-"GT@96QS92![#0H@
M("`@+R\@=&AI<R!I<R!A(')A=RP@=6YI;G-T86QL960@<&5A<BP@96ET:&5R
M(&$@8W9S(&-H96-K;W5T+"!O<B!P:'`@9&ES=')O#0H@("`@)')A=R`]('1R
M=64[#0I]#0I`:6YI7W-E="@G86QL;W=?=7)L7V9O<&5N)RP@=')U92D[#0II
M9B`H(6EN:5]G970H)W-A9F5?;6]D92<I*2![#0H@("`@0'-E=%]T:6UE7VQI
M;6ET*#`I.PT*?0T*;V)?:6UP;&EC:71?9FQU<V@H=')U92D[#0I`:6YI7W-E
M="@G=')A8VM?97)R;W)S)RP@=')U92D[#0I`:6YI7W-E="@G:'1M;%]E<G)O
M<G,G+"!F86QS92D[#0I`:6YI7W-E="@G;6%G:6-?<75O=&5S7W)U;G1I;64G
M+"!F86QS92D[#0HD7U!%05)?4$A01$E2(#T@)R,D)5XF*B<[#0IS971?97)R
M;W)?:&%N9&QE<B@G97)R;W)?:&%N9&QE<B<I.PT*#0HD<&5A<E]P86-K86=E
M7W9E<G-I;VX@/2`B,2XT+CDB.PT*#0IR97%U:7)E7V]N8V4@)U!%05(N<&AP
M)SL-"G)E<75I<F5?;VYC92`G4$5!4B]&<F]N=&5N9"YP:'`G.PT*<F5Q=6ER
M95]O;F-E("=014%2+T-O;F9I9RYP:'`G.PT*<F5Q=6ER95]O;F-E("=014%2
M+T-O;6UA;F0N<&AP)SL-"G)E<75I<F5?;VYC92`G0V]N<V]L92]'971O<'0N
M<&AP)SL-"@T*#0I014%27T-O;6UA;F0Z.G-E=$9R;VYT96YD5'EP92@G0TQ)
M)RD[#0HD86QL7V-O;6UA;F1S(#T@4$5!4E]#;VUM86YD.CIG971#;VUM86YD
M<R@I.PT*#0HO+R!R96UO=F4@=&AI<R!N97AT('!A<G0@=VAE;B!W92!S=&]P
M('-U<'!O<G1I;F<@=&AA="!C<F%P+6%S<R!02%`@-"XR#0II9B`H(6ES<V5T
M*"1?4T525D526R=A<F=V)UTI("8F("%I<W-E="@D87)G=BD@)B8@(6ES<V5T
M*"1(5%107U-%4E9%4E]605)36R=A<F=V)UTI*2![#0H@("`@9&EE*"=%4E)/
M4CH@96ET:&5R('5S92!T:&4@0TQ)('!H<"!E>&5C=71A8FQE+"!O<B!S970@
M<F5G:7-T97)?87)G8U]A<F=V/4]N(&EN('!H<"YI;FDG*3L-"GT-"B1A<F=V
M(#T@0V]N<V]L95]'971O<'0Z.G)E86102%!!<F=V*"D[#0HO+R!F:7@@0T=)
M('-A<&D@;V1D:71Y("T@=&AE("TM(&EN('!E87(N8F%T+W!E87(@:7,@;F]T
M(')E;6]V960-"FEF("AP:'!?<V%P:5]N86UE*"D@(3T@)V-L:2<@)B8@:7-S
M970H)&%R9W9;,5TI("8F("1A<F=V6S%=(#T]("<M+2<I('L-"B`@("!U;G-E
M="@D87)G=ELQ72D[#0H@("`@)&%R9W8@/2!A<G)A>5]V86QU97,H)&%R9W8I
M.PT*?0T*)'!R;V=N86UE(#T@4$5!4E]254Y465!%.PT*:68@*&EN7V%R<F%Y
M*"=G971O<'0R)RP@9V5T7V-L87-S7VUE=&AO9',H)T-O;G-O;&5?1V5T;W!T
M)RDI*2![#0H@("`@87)R87E?<VAI9G0H)&%R9W8I.PT*("`@("1O<'1I;VYS
M(#T@0V]N<V]L95]'971O<'0Z.F=E=&]P=#(H)&%R9W8L(")C.D,Z9#I$.D=H
M/W-3<74Z=E8B*3L-"GT@96QS92![#0H@("`@)&]P=&EO;G,@/2!#;VYS;VQE
M7T=E=&]P=#HZ9V5T;W!T*"1A<F=V+"`B8SI#.F0Z1#I':#]S4W%U.G96(BD[
M#0I]#0II9B`H4$5!4CHZ:7-%<G)O<B@D;W!T:6]N<RDI('L-"B`@("!U<V%G
M92@D;W!T:6]N<RD[#0I]#0H-"B1O<'1S(#T@)&]P=&EO;G-;,%T[#0H-"B1F
M971Y<&4@/2`G0TQ))SL-"FEF("@D<')O9VYA;64@/3T@)V=P96%R)R!\?"`D
M<')O9VYA;64@/3T@)W!E87(M9W1K)RD@>PT*("`@("1F971Y<&4@/2`G1W1K
M)SL-"GT@96QS92![#0H@("`@9F]R96%C:"`H)&]P=',@87,@)&]P="D@>PT*
M("`@("`@("!I9B`H)&]P=%LP72`]/2`G1R<I('L-"B`@("`@("`@("`@("1F
M971Y<&4@/2`G1W1K)SL-"B`@("`@("`@?0T*("`@('T-"GT-"B\O0VAE8VL@
M:68@1W1K(&%N9"!02%`@/CT@-2XQ+C`-"FEF("@D9F5T>7!E(#T]("='=&LG
M("8F('9E<G-I;VY?8V]M<&%R92AP:'!V97)S:6]N*"DL("<U+C$N,"<L("<^
M/2<I*2![#0H@("`@)&9E='EP92`]("='=&LR)SL-"GT-"@T*)'!E87)?=7-E
M<E]C;VYF:6<@/2`G)SL-"B1P96%R7W-Y<W1E;5]C;VYF:6<@/2`G)SL-"B1S
M=&]R95]U<V5R7V-O;F9I9R`](&9A;'-E.PT*)'-T;W)E7W-Y<W1E;5]C;VYF
M:6<@/2!F86QS93L-"B1V97)B;W-E(#T@,3L-"@T*9F]R96%C:"`H)&]P=',@
M87,@)&]P="D@>PT*("`@('-W:71C:"`H)&]P=%LP72D@>PT*("`@("`@("!C
M87-E("=C)SH-"B`@("`@("`@("`@("1P96%R7W5S97)?8V]N9FEG(#T@)&]P
M=%LQ73L-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!C87-E("=#)SH-
M"B`@("`@("`@("`@("1P96%R7W-Y<W1E;5]C;VYF:6<@/2`D;W!T6S%=.PT*
M("`@("`@("`@("`@8G)E86L[#0H@("`@?0T*?0T*#0I014%27T-O;6UA;F0Z
M.G-E=$9R;VYT96YD5'EP92@D9F5T>7!E*3L-"B1U:2`]("9014%27T-O;6UA
M;F0Z.F=E=$9R;VYT96YD3V)J96-T*"D[#0HD8V]N9FEG(#T@)E!%05)?0V]N
M9FEG.CIS:6YG;&5T;VXH)'!E87)?=7-E<E]C;VYF:6<L("1P96%R7W-Y<W1E
M;5]C;VYF:6<I.PT*#0II9B`H4$5!4CHZ:7-%<G)O<B@D8V]N9FEG*2D@>PT*
M("`@("1?9FEL92`]("<G.PT*("`@(&EF("@D<&5A<E]U<V5R7V-O;F9I9R`A
M/3T@9F%L<V4I('L-"B`@("`@("`D7V9I;&4@+CT@)'!E87)?=7-E<E]C;VYF
M:6<[#0H@("`@?0T*("`@(&EF("@D<&5A<E]S>7-T96U?8V]N9FEG("$]/2!F
M86QS92D@>PT*("`@("`@("1?9FEL92`N/2`G+R<@+B`D<&5A<E]S>7-T96U?
M8V]N9FEG.PT*("`@('T-"B`@("!I9B`H)%]F:6QE(#T]("<O)RD@>PT*("`@
M("`@("`D7V9I;&4@/2`G5&AE(&1E9F%U;'0@8V]N9FEG(&9I;&4G.PT*("`@
M('T-"B`@("`D8V]N9FEG+3YG971-97-S86=E*"D[#0H@("`@)'5I+3YO=71P
M=71$871A*")%4E)/4CH@)%]F:6QE(&ES(&YO="!A('9A;&ED(&-O;F9I9R!F
M:6QE(&]R(&ES(&-O<G)U<'1E9"XB*3L-"B`@("`O+R!792!S=&]P+"!W92!H
M879E(&YO(&ED96$@=VAE<F4@=V4@87)E(#HI#0H@("`@97AI="@I.R`@("`-
M"GT-"@T*+R\@=&AI<R!I<R!U<V5D(&EN('1H92!E<G)O<B!H86YD;&5R('1O
M(')E=')I979E(&$@<F5L871I=F4@<&%T:`T*)%]014%27U!(4$1)4B`]("1C
M;VYF:6<M/F=E="@G<&AP7V1I<B<I.PT*)'5I+3YS971#;VYF:6<H)&-O;F9I
M9RD[#0I014%2.CIS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!
M0TLL(&%R<F%Y*"1U:2P@(F1I<W!L87E&871A;$5R<F]R(BDI.PT*:68@*&EN
M:5]G970H)W-A9F5?;6]D92<I*2![#0H@("`@)'5I+3YO=71P=71$871A*"=7
M05).24Y'.B!R=6YN:6YG(&EN('-A9F4@;6]D92!R97%U:7)E<R!T:&%T(&%L
M;"!F:6QE<R!C<F5A=&5D("<@+@T*("`@("`@("`G8F4@=&AE('-A;64@=6ED
M(&%S('1H92!C=7)R96YT('-C<FEP="X@(%!(4"!R97!O<G1S('1H:7,@<V-R
M:7!T(&ES('5I9#H@)R`N#0H@("`@("`@($!G971M>75I9"@I("X@)RP@86YD
M(&-U<G)E;G0@=7-E<B!I<SH@)R`N($!G971?8W5R<F5N=%]U<V5R*"DI.PT*
M?0T*#0HD=F5R8F]S92`]("1C;VYF:6<M/F=E="@B=F5R8F]S92(I.PT*)&-M
M9&]P=',@/2!A<G)A>2@I.PT*#0II9B`H)')A=RD@>PT*("`@(&EF("@A)&-O
M;F9I9RT^:7-$969I;F5D3&%Y97(H)W5S97(G*2`F)B`A)&-O;F9I9RT^:7-$
M969I;F5D3&%Y97(H)W-Y<W1E;2<I*2![#0H@("`@("`@("1F;W5N9"`](&9A
M;'-E.PT*("`@("`@("!F;W)E86-H("@D;W!T<R!A<R`D;W!T*2![#0H@("`@
M("`@("`@("!I9B`H)&]P=%LP72`]/2`G9"<@?'P@)&]P=%LP72`]/2`G1"<I
M('L-"B`@("`@("`@("`@("`@("`D9F]U;F0@/2!T<G5E.R`O+R!T:&4@=7-E
M<B!K;F]W<R!W:&%T('1H97D@87)E(&1O:6YG+"!A;F0@87)E('-E='1I;F<@
M8V]N9FEG('9A;'5E<PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(&EF("@A)&9O=6YD*2![#0H@("`@("`@("`@("`O+R!N;R!P<FEO<B!R
M=6YS+"!T<GD@=&\@:6YS=&%L;"!014%2#0H@("`@("`@("`@("!I9B`H<W1R
M<&]S*&1I<FYA;64H7U]&24Q%7U\I+"`G<V-R:7!T<R<I*2![#0H@("`@("`@
M("`@("`@("`@)'!A8VMA9V5X;6P@/2!D:7)N86UE*&1I<FYA;64H7U]&24Q%
M7U\I*2`N($1)4D5#5$]265]315!!4D%43U(@+B`G<&%C:V%G93(N>&UL)SL-
M"B`@("`@("`@("`@("`@("`D<&5A<F)A<V4@/2!D:7)N86UE*&1I<FYA;64H
M7U]&24Q%7U\I*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@)'!A8VMA9V5X;6P@/2!D:7)N86UE*%]?1DE,15]?*2`N($1)4D5#
M5$]265]315!!4D%43U(@+B`G<&%C:V%G93(N>&UL)SL-"B`@("`@("`@("`@
M("`@("`D<&5A<F)A<V4@/2!D:7)N86UE*%]?1DE,15]?*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D<&%C:V%G97AM
M;"DI('L-"B`@("`@("`@("`@("`@("`D;W!T:6]N<ULQ72`](&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("`@("`G:6YS=&%L;"<L#0H@("`@("`@("`@("`@
M("`@("`@("1P86-K86=E>&UL#0H@("`@("`@("`@("`@("`@*3L-"B`@("`@
M("`@("`@("`@("`D8V]N9FEG+3YS970H)W!H<%]D:7(G+"`D<&5A<F)A<V4@
M+B!$25)%0U1/4EE?4T5005)!5$]2("X@)W!H<"<I.PT*("`@("`@("`@("`@
M("`@("1C;VYF:6<M/G-E="@G9&%T85]D:7(G+"`D<&5A<F)A<V4@+B!$25)%
M0U1/4EE?4T5005)!5$]2("X@)V1A=&$G*3L-"B`@("`@("`@("`@("`@("`D
M8V]N9FEG+3YS970H)V1O8U]D:7(G+"`D<&5A<F)A<V4@+B!$25)%0U1/4EE?
M4T5005)!5$]2("X@)V1O8W,G*3L-"B`@("`@("`@("`@("`@("`D8V]N9FEG
M+3YS970H)W1E<W1?9&ER)RP@)'!E87)B87-E("X@1$E214-43U)97U-%4$%2
M051/4B`N("=T97-T<R<I.PT*("`@("`@("`@("`@("`@("1C;VYF:6<M/G-E
M="@G97AT7V1I<B<L("1P96%R8F%S92`N($1)4D5#5$]265]315!!4D%43U(@
M+B`G97AT96YS:6]N<R<I.PT*("`@("`@("`@("`@("`@("1C;VYF:6<M/G-E
M="@G8FEN7V1I<B<L("1P96%R8F%S92D[#0H@("`@("`@("`@("`@("`@)&-O
M;F9I9RT^;65R9V5#;VYF:6=&:6QE*"1P96%R8F%S92`N("=P96%R+FEN:2<L
M(&9A;'-E*3L-"B`@("`@("`@("`@("`@("`D8V]N9FEG+3YS=&]R92@I.PT*
M("`@("`@("`@("`@("`@("1C;VYF:6<M/G-E="@G875T;U]D:7-C;W9E<B<L
M(#$I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*?0T*9F]R
M96%C:"`H)&]P=',@87,@)&]P="D@>PT*("`@("1P87)A;2`]("%E;7!T>2@D
M;W!T6S%=*2`_("1O<'1;,5T@.B!T<G5E.PT*("`@('-W:71C:"`H)&]P=%LP
M72D@>PT*("`@("`@("!C87-E("=D)SH-"B`@("`@("`@("`@(&QI<W0H)&ME
M>2P@)'9A;'5E*2`](&5X<&QO9&4H)STG+"`D<&%R86TI.PT*("`@("`@("`@
M("`@)&-O;F9I9RT^<V5T*"1K97DL("1V86QU92P@)W5S97(G*3L-"B`@("`@
M("`@("`@(&)R96%K.PT*("`@("`@("!C87-E("=$)SH-"B`@("`@("`@("`@
M(&QI<W0H)&ME>2P@)'9A;'5E*2`](&5X<&QO9&4H)STG+"`D<&%R86TI.PT*
M("`@("`@("`@("`@)&-O;F9I9RT^<V5T*"1K97DL("1V86QU92P@)W-Y<W1E
M;2<I.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@(&-A<V4@)W,G.@T*
M("`@("`@("`@("`@)'-T;W)E7W5S97)?8V]N9FEG(#T@=')U93L-"B`@("`@
M("`@("`@(&)R96%K.PT*("`@("`@("!C87-E("=3)SH-"B`@("`@("`@("`@
M("1S=&]R95]S>7-T96U?8V]N9FEG(#T@=')U93L-"B`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("!C87-E("=U)SH-"B`@("`@("`@("`@("1C;VYF:6<M
M/G)E;6]V92@D<&%R86TL("=U<V5R)RD[#0H@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@8V%S92`G=B<Z#0H@("`@("`@("`@("`D8V]N9FEG+3YS970H
M)W9E<F)O<V4G+"`D8V]N9FEG+3YG970H)W9E<F)O<V4G*2`K(#$I.PT*("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@(&-A<V4@)W$G.@T*("`@("`@("`@
M("`@)&-O;F9I9RT^<V5T*"=V97)B;W-E)RP@)&-O;F9I9RT^9V5T*"=V97)B
M;W-E)RD@+2`Q*3L-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!C87-E
M("=6)SH-"B`@("`@("`@("`@('5S86=E*&YU;&PL("=V97)S:6]N)RD[#0H@
M("`@("`@(&-A<V4@)V,G.@T*("`@("`@("!C87-E("=#)SH-"B`@("`@("`@
M("`@(&)R96%K.PT*("`@("`@("!D969A=6QT.@T*("`@("`@("`@("`@+R\@
M86QL(&YO;B!P96%R('!A<F%M<R!G;V5S('1O('1H92!C;VUM86YD#0H@("`@
M("`@("`@("`D8VUD;W!T<ULD;W!T6S!=72`]("1P87)A;3L-"B`@("`@("`@
M("`@(&)R96%K.PT*("`@('T-"GT-"@T*:68@*"1S=&]R95]S>7-T96U?8V]N
M9FEG*2![#0H@("`@)&-O;F9I9RT^<W1O<F4H)W-Y<W1E;2<I.PT*?0T*#0II
M9B`H)'-T;W)E7W5S97)?8V]N9FEG*2![#0H@("`@)&-O;F9I9RT^<W1O<F4H
M)W5S97(G*3L-"GT-"@T*)&-O;6UA;F0@/2`H:7-S970H)&]P=&EO;G-;,5U;
M,%TI*2`_("1O<'1I;VYS6S%=6S!=(#H@;G5L;#L-"@T*:68@*&5M<'1Y*"1C
M;VUM86YD*2`F)B`H)'-T;W)E7W5S97)?8V]N9FEG('Q\("1S=&]R95]S>7-T
M96U?8V]N9FEG*2D@>PT*("`@(&5X:70[#0I]#0H-"FEF("@D9F5T>7!E(#T]
M("='=&LG('Q\("1F971Y<&4@/3T@)T=T:S(G*2![#0H@("`@:68@*"$D8V]N
M9FEG+3YV86QI9$-O;F9I9W5R871I;VXH*2D@>PT*("`@("`@("!014%2.CIR
M86ES945R<F]R*"=#4DE424-!3"!%4E)/4CH@;F\@97AI<W1I;F<@=F%L:60@
M8V]N9FEG=7)A=&EO;B!F:6QE<R!F;W5N9"!I;B!F:6QE<R`G("X-"B`@("`@
M("`@("`@("(G)'!E87)?=7-E<E]C;VYF:6<G(&]R("<D<&5A<E]S>7-T96U?
M8V]N9FEG)RP@<&QE87-E(&-O<'D@86X@97AI<W1I;F<@8V]N9FEG=7)A=&EO
M;B(@+@T*("`@("`@("`@("`@)V9I;&4@=&\@;VYE(&]F('1H97-E(&QO8V%T
M:6]N<RP@;W(@=7-E('1H92`M8R!A;F0@+7,@;W!T:6]N<R!T;R!C<F5A=&4@
M;VYE)RD[#0H@("`@?0T*("`@($=T:SHZ;6%I;B@I.PT*?2!E;'-E(&1O('L-
M"B`@("!I9B`H)&-O;6UA;F0@/3T@)VAE;'`G*2![#0H@("`@("`@('5S86=E
M*&YU;&PL($`D;W!T:6]N<ULQ75LQ72D[#0H@("`@?0T*("`@(&EF("@A)&-O
M;F9I9RT^=F%L:61#;VYF:6=U<F%T:6]N*"DI('L-"B`@("`@("`@4$5!4CHZ
M<F%I<V5%<G)O<B@G0U))5$E#04P@15)23U(Z(&YO(&5X:7-T:6YG('9A;&ED
M(&-O;F9I9W5R871I;VX@9FEL97,@9F]U;F0@:6X@9FEL97,@)R`N#0H@("`@
M("`@("`@("`B)R1P96%R7W5S97)?8V]N9FEG)R!O<B`G)'!E87)?<WES=&5M
M7V-O;F9I9R<L('!L96%S92!C;W!Y(&%N(&5X:7-T:6YG(&-O;F9I9W5R871I
M;VXB("X-"B`@("`@("`@("`@("=F:6QE('1O(&]N92!O9B!T:&5S92!L;V-A
M=&EO;G,L(&]R('5S92!T:&4@+6,@86YD("US(&]P=&EO;G,@=&\@8W)E871E
M(&]N92<I.PT*("`@('T-"@T*("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG
M*%!%05)?15)23U)?4D5455).*3L-"B`@("`D8VUD(#T@4$5!4E]#;VUM86YD
M.CIF86-T;W)Y*"1C;VUM86YD+"`D8V]N9FEG*3L-"B`@("!014%2.CIP;W!%
M<G)O<DAA;F1L:6YG*"D[#0H@("`@:68@*%!%05(Z.FES17)R;W(H)&-M9"DI
M('L-"B`@("`@("`@=7-A9V4H;G5L;"P@0"1O<'1I;VYS6S%=6S!=*3L-"B`@
M("!]#0H-"B`@("`D<VAO<G1?87)G<R`]("1L;VYG7V%R9W,@/2!N=6QL.PT*
M("`@(%!%05)?0V]M;6%N9#HZ9V5T1V5T;W!T07)G<R@D8V]M;6%N9"P@)'-H
M;W)T7V%R9W,L("1L;VYG7V%R9W,I.PT*("`@(&EF("AI;E]A<G)A>2@G9V5T
M;W!T,B<L(&=E=%]C;&%S<U]M971H;V1S*"=#;VYS;VQE7T=E=&]P="<I*2D@
M>PT*("`@("`@("!A<G)A>5]S:&EF="@D;W!T:6]N<ULQ72D[#0H@("`@("`@
M("1T;7`@/2!#;VYS;VQE7T=E=&]P=#HZ9V5T;W!T,B@D;W!T:6]N<ULQ72P@
M)'-H;W)T7V%R9W,L("1L;VYG7V%R9W,I.PT*("`@('T@96QS92![#0H@("`@
M("`@("1T;7`@/2!#;VYS;VQE7T=E=&]P=#HZ9V5T;W!T*"1O<'1I;VYS6S%=
M+"`D<VAO<G1?87)G<RP@)&QO;F=?87)G<RD[#0H@("`@?0T*("`@(&EF("A0
M14%2.CII<T5R<F]R*"1T;7`I*2![#0H@("`@("`@(&)R96%K.PT*("`@('T-
M"B`@("!L:7-T*"1T;7!O<'0L("1P87)A;7,I(#T@)'1M<#L-"B`@("`D;W!T
M<R`](&%R<F%Y*"D[#0H@("`@9F]R96%C:"`H)'1M<&]P="!A<R`D9F]O(#T^
M("1T;7`R*2![#0H@("`@("`@(&QI<W0H)&]P="P@)'9A;'5E*2`]("1T;7`R
M.PT*("`@("`@("!I9B`H)'9A;'5E(#T]/2!N=6QL*2![#0H@("`@("`@("`@
M("`D=F%L=64@/2!T<G5E.R`O+R!O<'1I;VYS('=I=&AO=70@87)G<PT*("`@
M("`@("!]#0H@("`@("`@(&EF("AS=')L96XH)&]P="D@/3T@,2D@>PT*("`@
M("`@("`@("`@)&-M9&]P=&EO;G,@/2`D8VUD+3YG971/<'1I;VYS*"1C;VUM
M86YD*3L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1C;61O<'1I;VYS(&%S("1O
M(#T^("1D*2![#0H@("`@("`@("`@("`@("`@:68@*$`D9%LG<VAO<G1O<'0G
M72`]/2`D;W!T*2![#0H@("`@("`@("`@("`@("`@("`@("1O<'1S6R1O72`]
M("1V86QU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I9B`H<W5B<W1R*"1O<'0L
M(#`L(#(I(#T]("<M+2<I('L-"B`@("`@("`@("`@("`@("`D;W!T<UMS=6)S
M='(H)&]P="P@,BE=(#T@)'9A;'5E.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@?0T*("`@("1O:R`]("1C;60M/G)U;B@D8V]M;6%N9"P@)&]P
M=',L("1P87)A;7,I.PT*("`@(&EF("@D;VL@/3T](&9A;'-E*2![#0H@("`@
M("`@(%!%05(Z.G)A:7-E17)R;W(H(G5N:VYO=VX@8V]M;6%N9"!@)&-O;6UA
M;F0G(BD[#0H@("`@?0T*("`@(&EF("A014%2.CII<T5R<F]R*"1O:RDI('L-
M"B`@("`@("`@4$5!4CHZ<V5T17)R;W)(86YD;&EN9RA014%27T524D]27T-!
M3$Q"04-++"!A<G)A>2@D=6DL(")D:7-P;&%Y1F%T86Q%<G)O<B(I*3L-"B`@
M("`@("`@4$5!4CHZ<F%I<V5%<G)O<B@D;VLI.PT*("`@('T-"GT@=VAI;&4@
M*&9A;'-E*3L-"@T*+R\@>WM[('5S86=E*"D-"@T*9G5N8W1I;VX@=7-A9V4H
M)&5R<F]R(#T@;G5L;"P@)&AE;'!S=6)J96-T(#T@;G5L;"D-"GL-"B`@("!G
M;&]B86P@)'!R;V=N86UE+"`D86QL7V-O;6UA;F1S.PT*("`@("1S=&1E<G(@
M/2!F;W!E;B@G<&AP.B\O<W1D97)R)RP@)W<G*3L-"B`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D97)R;W(I*2![#0H@("`@("`@(&9P=71S*"1S=&1E<G(L("1E
M<G)O<BT^9V5T365S<V%G92@I("X@(EQN(BD[#0H@("`@?2!E;'-E:68@*"1E
M<G)O<B`A/3T@;G5L;"D@>PT*("`@("`@("!F<'5T<R@D<W1D97)R+"`B)&5R
M<F]R7&XB*3L-"B`@("!]#0H@("`@:68@*"1H96QP<W5B:F5C="`A/2!N=6QL
M*2![#0H@("`@("`@("1P=70@/2!C;61(96QP*"1H96QP<W5B:F5C="D[#0H@
M("`@?2!E;'-E('L-"B`@("`@("`@)'!U="`]#0H@("`@("`@("`@("`B0V]M
M;6%N9',Z7&XB.PT*("`@("`@("`D;6%X;&5N(#T@;6%X*&%R<F%Y7VUA<"@B
M<W1R;&5N(BP@)&%L;%]C;VUM86YD<RDI.PT*("`@("`@("`D9F]R;6%T<W1R
M(#T@(B4M>R1M87AL96Y]<R`@)7-<;B([#0H@("`@("`@(&MS;W)T*"1A;&Q?
M8V]M;6%N9',I.PT*("`@("`@("!F;W)E86-H("@D86QL7V-O;6UA;F1S(&%S
M("1C;60@/3X@)&-L87-S*2![#0H@("`@("`@("`@("`D<'5T("X]('-P<FEN
M=&8H)&9O<FUA='-T<BP@)&-M9"P@4$5!4E]#;VUM86YD.CIG971$97-C<FEP
M=&EO;B@D8VUD*2D[#0H@("`@("`@('T-"B`@("`@("`@)'!U="`N/0T*("`@
M("`@("`@("`@(E5S86=E.B`D<')O9VYA;64@6V]P=&EO;G-=(&-O;6UA;F0@
M6V-O;6UA;F0M;W!T:6]N<UT@/'!A<F%M971E<G,^7&XB+@T*("`@("`@("`@
M("`@(E1Y<&4@7"(D<')O9VYA;64@:&5L<"!O<'1I;VYS7"(@=&\@;&ES="!A
M;&P@;W!T:6]N<RY<;B(N#0H@("`@("`@("`@("`B5'EP92!<(B1P<F]G;F%M
M92!H96QP('-H;W)T8W5T<UPB('1O(&QI<W0@86QL(&-O;6UA;F0@<VAO<G1C
M=71S+EQN(BX-"B`@("`@("`@("`@(")4>7!E(%PB)'!R;V=N86UE(&AE;'`@
M/&-O;6UA;F0^7"(@=&\@9V5T('1H92!H96QP(&9O<B!T:&4@<W!E8VEF:65D
M(&-O;6UA;F0N(CL-"B`@("!]#0H@("`@9G!U=',H)'-T9&5R<BP@(B1P=71<
M;B(I.PT*("`@(&9C;&]S92@D<W1D97)R*3L-"B`@("!E>&ET.PT*?0T*#0IF
M=6YC=&EO;B!C;61(96QP*"1C;VUM86YD*0T*>PT*("`@(&=L;V)A;"`D<')O
M9VYA;64L("1A;&Q?8V]M;6%N9',L("1C;VYF:6<[#0H@("`@:68@*"1C;VUM
M86YD(#T](")O<'1I;VYS(BD@>PT*("`@("`@("!R971U<FX-"B`@("`@("`@
M(D]P=&EO;G,Z7&XB+@T*("`@("`@("`B("`@("`M=B`@("`@("`@(&EN8W)E
M87-E('9E<F)O<VET>2!L979E;"`H9&5F875L="`Q*5QN(BX-"B`@("`@("`@
M(B`@("`@+7$@("`@("`@("!B92!Q=6EE="P@9&5C<F5A<V4@=F5R8F]S:71Y
M(&QE=F5L7&XB+@T*("`@("`@("`B("`@("`M8R!F:6QE("`@(&9I;F0@=7-E
M<B!C;VYF:6=U<F%T:6]N(&EN(&!F:6QE)UQN(BX-"B`@("`@("`@(B`@("`@
M+4,@9FEL92`@("!F:6YD('-Y<W1E;2!C;VYF:6=U<F%T:6]N(&EN(&!F:6QE
M)UQN(BX-"B`@("`@("`@(B`@("`@+60@9F]O/6)A<B!S970@=7-E<B!C;VYF
M:6<@=F%R:6%B;&4@8&9O;R<@=&\@8&)A<B=<;B(N#0H@("`@("`@("(@("`@
M("U$(&9O;SUB87(@<V5T('-Y<W1E;2!C;VYF:6<@=F%R:6%B;&4@8&9O;R<@
M=&\@8&)A<B=<;B(N#0H@("`@("`@("(@("`@("U'("`@("`@("`@<W1A<G0@
M:6X@9W)A<&AI8V%L("A'=&LI(&UO9&5<;B(N#0H@("`@("`@("(@("`@("US
M("`@("`@("`@<W1O<F4@=7-E<B!C;VYF:6=U<F%T:6]N7&XB+@T*("`@("`@
M("`B("`@("`M4R`@("`@("`@('-T;W)E('-Y<W1E;2!C;VYF:6=U<F%T:6]N
M7&XB+@T*("`@("`@("`B("`@("`M=2!F;V\@("`@('5N<V5T(&!F;V\G(&EN
M('1H92!U<V5R(&-O;F9I9W5R871I;VY<;B(N#0H@("`@("`@("(@("`@("UH
M+"`M/R`@("`@9&ES<&QA>2!H96QP+W5S86=E("AT:&ES(&UE<W-A9V4I7&XB
M+@T*("`@("`@("`B("`@("`M5B`@("`@("`@('9E<G-I;VX@:6YF;W)M871I
M;VY<;B([#0H@("`@?2!E;'-E:68@*"1C;VUM86YD(#T](")S:&]R=&-U=',B
M*2![#0H@("`@("`@("1S8R`](%!%05)?0V]M;6%N9#HZ9V5T4VAO<G1C=71S
M*"D[#0H@("`@("`@("1R970@/2`B4VAO<G1C=71S.EQN(CL-"B`@("`@("`@
M9F]R96%C:"`H)'-C(&%S("1S(#T^("1C*2![#0H@("`@("`@("`@("`D<F5T
M("X]('-P<FEN=&8H(B`@("`@)2TX<R`E<UQN(BP@)',L("1C*3L-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@)')E=#L-"@T*("`@('T@96QS96EF("@D
M8V]M;6%N9"`]/2`B=F5R<VEO;B(I('L-"B`@("`@("`@<F5T=7)N(")014%2
M(%9E<G-I;VXZ("(N)$=,3T)!3%-;)W!E87)?<&%C:V%G95]V97)S:6]N)UTN
M#0H@("`@("`@("`@("`@("`B7&Y02%`@5F5R<VEO;CH@(BYP:'!V97)S:6]N
M*"DN#0H@("`@("`@("`@("`@("`B7&Y:96YD($5N9VEN92!697)S:6]N.B`B
M+GIE;F1?=F5R<VEO;B@I+@T*("`@("`@("`@("`@("`@(EQN4G5N;FEN9R!O
M;CH@(BYP:'!?=6YA;64H*3L-"@T*("`@('T@96QS96EF("@D:&5L<"`](%!%
M05)?0V]M;6%N9#HZ9V5T2&5L<"@D8V]M;6%N9"DI('L-"B`@("`@("`@:68@
M*&ES7W-T<FEN9R@D:&5L<"DI('L-"B`@("`@("`@("`@(')E='5R;B`B)'!R
M;V=N86UE("1C;VUM86YD(%MO<'1I;VYS72`D:&5L<%QN(CL-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H)&AE;'!;,5T@/3T](&YU;&PI('L-"B`@("`@("`@
M("`@(')E='5R;B`B)'!R;V=N86UE("1C;VUM86YD("1H96QP6S!=(CL-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R;B`B)'!R;V=N86UE
M("1C;VUM86YD(%MO<'1I;VYS72`D:&5L<%LP75QN)&AE;'!;,5TB.PT*("`@
M("`@("!]#0H@("`@?0T*("`@(')E='5R;B`B0V]M;6%N9"`G)&-O;6UA;F0G
M(&ES(&YO="!V86QI9"P@=')Y("=P96%R(&AE;'`G(CL-"GT-"@T*+R\@?7U]
M#0H-"F9U;F-T:6]N(&5R<F]R7VAA;F1L97(H)&5R<FYO+"`D97)R;7-G+"`D
M9FEL92P@)&QI;F4L("1V87)S*2![#0H@("`@:68@*"AD969I;F5D*"=%7U-4
M4DE#5"<I("8F("1E<G)N;R`F($5?4U1224-4*2!\?"`A97)R;W)?<F5P;W)T
M:6YG*"DI('L-"B`@("`@("`@:68@*&1E9FEN960H)T5?4U1224-4)RD@)B8@
M)&5R<FYO("8@15]35%))0U0I('L-"B`@("`@("`@("`@(')E='5R;CL@+R\@
M15]35%))0U0-"B`@("`@("`@?0T*("`@("`@("!I9B`H)$=,3T)!3%-;)V-O
M;F9I9R==+3YG970H)W9E<F)O<V4G*2`\(#0I('L-"B`@("`@("`@("`@(')E
M='5R;CL@+R\@0'-I;&5N8V5D(&5R<F]R+"!S:&]W(&%L;"!I9B!D96)U9R!I
M<R!H:6=H(&5N;W5G:`T*("`@("`@("!]#0H@("`@?0T*("`@("1E<G)O<G1Y
M<&4@/2!A<G)A>2`H#0H@("`@("`@($5?15)23U(@("`]/B`@(D5R<F]R(BP-
M"B`@("`@("`@15]705).24Y'("`@/3X@(")787)N:6YG(BP-"B`@("`@("`@
M15]005)312`@(#T^("`B4&%R<VEN9R!%<G)O<B(L#0H@("`@("`@($5?3D]4
M24-%("`@/3X@(").;W1I8V4B+`T*("`@("`@("!%7T-/4D5?15)23U(@(#T^
M("`B0V]R92!%<G)O<B(L#0H@("`@("`@($5?0T]215]705).24Y'("`]/B`@
M(D-O<F4@5V%R;FEN9R(L#0H@("`@("`@($5?0T]-4$E,15]%4E)/4B`@/3X@
M(")#;VUP:6QE($5R<F]R(BP-"B`@("`@("`@15]#3TU024Q%7U=!4DY)3D<@
M/3X@(")#;VUP:6QE(%=A<FYI;F<B+`T*("`@("`@("!%7U5315)?15)23U(@
M/3X@(")5<V5R($5R<F]R(BP-"B`@("`@("`@15]54T527U=!4DY)3D<@/3X@
M(")5<V5R(%=A<FYI;F<B+`T*("`@("`@("!%7U5315)?3D]424-%(#T^("`B
M57-E<B!.;W1I8V4B#0H@("`@*3L-"B`@("`D<')E9FEX(#T@)&5R<F]R='EP
M95LD97)R;F]=.PT*("`@(&=L;V)A;"`D7U!%05)?4$A01$E2.PT*("`@(&EF
M("AS=')I<W1R*"1F:6QE+"`D7U!%05)?4$A01$E2*2D@>PT*("`@("`@("`D
M9FEL92`]('-U8G-T<B@D9FEL92P@<W1R;&5N*"1?4$5!4E]02%!$25(I("L@
M,2D[#0H@("`@?2!E;'-E('L-"B`@("`@("`@)&9I;&4@/2!B87-E;F%M92@D
M9FEL92D[#0H@("`@?0T*("`@('!R:6YT(")<;B1P<F5F:7@Z("1E<G)M<V<@
M:6X@)&9I;&4@;VX@;&EN92`D;&EN95QN(CL-"GT-"@T*#0HO*@T*("H@3&]C
M86P@=F%R:6%B;&5S.@T*("H@=&%B+7=I9'1H.B`T#0H@*B!C+6)A<VEC+6]F
M9G-E=#H@-`T*("H@:6YD96YT+71A8G,M;6]D93H@;FEL#0H@*B!M;V1E.B!P
M:'`-"B`J($5N9#H-"B`J+PT*+R\@=FEM-C`P.G-Y;CUP:'`-"@T*/SX-"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]P96%R8VUD+G!H<"YO<FEG````````````````````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`S-38Q-P`Q,#4Q-30S,S<T,P`P,C$W,#,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`-"B\O#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@
M4$A0(%9E<G-I;VX@-2`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK#0HO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`T(%1H
M92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!4:&ES('-O
M=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(
M4"!L:6-E;G-E+"`@("`@("!\#0HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H
M('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@
M("`@('P-"B\O('P@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M
M=V5B(&%T('1H92!F;VQL;W=I;F<@=7)L.B`@("`@("`@("`@?`T*+R\@?"!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N
M86)L92!T;R`@('P-"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`T*
M+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P
M>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@075T:&]R<SH@4W1I9R!"86MK96X@
M/'-S8D!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`T*+R\@?"`@("`@("`@("!4;VUA<R!6+E8N0V]X(#QC;WA`:61E8VYE
M="YC;VT^("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PT*+R\-"B\O("1)9#H@<&5A<F-M9"YP:'`L=B`Q+C,S(#(P
M,#8O,#$O,#(@,3@Z,#4Z-3,@8V5L;&]G($5X<"`D#0H-"F]B7V5N9%]C;&5A
M;B@I.PT*:68@*"%D969I;F5D*"=014%27U)53E194$4G*2D@>PT*("`@("\O
M('1H:7,@:7,@9&5F:6YE9"!I;B!P96-L8VUD+G!H<"!A<R`G<&5C;"<-"B`@
M("!D969I;F4H)U!%05)?4E5.5%E012<L("=P96%R)RD[#0I]#0ID969I;F4H
M)U!%05)?24=.3U)%7T)!0TM44D%#12<L(#$I.PT*:68@*"%F=6YC=&EO;E]E
M>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L-"B`@("!F=6YC=&EO;B!F
M:6QE7V=E=%]C;VYT96YT<R@D9FEL96YA;64I#0H@("`@>PT*("`@("`@("`D
M9G`@/2!F;W!E;B@D9FEL96YA;64L("=R8B<I.PT*("`@("`@("`D<F5T(#T@
M)R<[#0H@("`@("`@('=H:6QE("@A9F5O9B@D9G`I*2![#0H@("`@("`@("`@
M("`D<F5T("X](&9R96%D*"1F<"P@.#`Y,BD[.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B`D<F5T.PT*("`@('T-"GT-"B\J*@T*("H@0&YO9&5P($=T
M:PT*("HO#0II9B`H)R]H;VUE+VQU8V5R+W=O<FLO<&5A<B]S:&%R92]P:'`G
M("$]("=`)RXG:6YC;'5D95]P871H)RXG0"<I('L-"B`@("!I;FE?<V5T*"=I
M;F-L=61E7W!A=&@G+"`G+VAO;64O;'5C97(O=V]R:R]P96%R+W-H87)E+W!H
M<"<I.PT*("`@("1R87<@/2!F86QS93L-"GT@96QS92![#0H@("`@+R\@=&AI
M<R!I<R!A(')A=RP@=6YI;G-T86QL960@<&5A<BP@96ET:&5R(&$@8W9S(&-H
M96-K;W5T+"!O<B!P:'`@9&ES=')O#0H@("`@)')A=R`]('1R=64[#0I]#0I`
M:6YI7W-E="@G86QL;W=?=7)L7V9O<&5N)RP@=')U92D[#0II9B`H(6EN:5]G
M970H)W-A9F5?;6]D92<I*2![#0H@("`@0'-E=%]T:6UE7VQI;6ET*#`I.PT*
M?0T*;V)?:6UP;&EC:71?9FQU<V@H=')U92D[#0I`:6YI7W-E="@G=')A8VM?
M97)R;W)S)RP@=')U92D[#0I`:6YI7W-E="@G:'1M;%]E<G)O<G,G+"!F86QS
M92D[#0I`:6YI7W-E="@G;6%G:6-?<75O=&5S7W)U;G1I;64G+"!F86QS92D[
M#0HD7U!%05)?4$A01$E2(#T@)R,D)5XF*B<[#0IS971?97)R;W)?:&%N9&QE
M<B@G97)R;W)?:&%N9&QE<B<I.PT*#0HD<&5A<E]P86-K86=E7W9E<G-I;VX@
M/2`B,2XT+CDB.PT*#0IR97%U:7)E7V]N8V4@)U!%05(N<&AP)SL-"G)E<75I
M<F5?;VYC92`G4$5!4B]&<F]N=&5N9"YP:'`G.PT*<F5Q=6ER95]O;F-E("=0
M14%2+T-O;F9I9RYP:'`G.PT*<F5Q=6ER95]O;F-E("=014%2+T-O;6UA;F0N
M<&AP)SL-"G)E<75I<F5?;VYC92`G0V]N<V]L92]'971O<'0N<&AP)SL-"@T*
M#0I014%27T-O;6UA;F0Z.G-E=$9R;VYT96YD5'EP92@G0TQ))RD[#0HD86QL
M7V-O;6UA;F1S(#T@4$5!4E]#;VUM86YD.CIG971#;VUM86YD<R@I.PT*#0HO
M+R!R96UO=F4@=&AI<R!N97AT('!A<G0@=VAE;B!W92!S=&]P('-U<'!O<G1I
M;F<@=&AA="!C<F%P+6%S<R!02%`@-"XR#0II9B`H(6ES<V5T*"1?4T525D52
M6R=A<F=V)UTI("8F("%I<W-E="@D87)G=BD@)B8@(6ES<V5T*"1(5%107U-%
M4E9%4E]605)36R=A<F=V)UTI*2![#0H@("`@9&EE*"=%4E)/4CH@96ET:&5R
M('5S92!T:&4@0TQ)('!H<"!E>&5C=71A8FQE+"!O<B!S970@<F5G:7-T97)?
M87)G8U]A<F=V/4]N(&EN('!H<"YI;FDG*3L-"GT-"B1A<F=V(#T@0V]N<V]L
M95]'971O<'0Z.G)E86102%!!<F=V*"D[#0HO+R!F:7@@0T=)('-A<&D@;V1D
M:71Y("T@=&AE("TM(&EN('!E87(N8F%T+W!E87(@:7,@;F]T(')E;6]V960-
M"FEF("AP:'!?<V%P:5]N86UE*"D@(3T@)V-L:2<@)B8@:7-S970H)&%R9W9;
M,5TI("8F("1A<F=V6S%=(#T]("<M+2<I('L-"B`@("!U;G-E="@D87)G=ELQ
M72D[#0H@("`@)&%R9W8@/2!A<G)A>5]V86QU97,H)&%R9W8I.PT*?0T*)'!R
M;V=N86UE(#T@4$5!4E]254Y465!%.PT*:68@*&EN7V%R<F%Y*"=G971O<'0R
M)RP@9V5T7V-L87-S7VUE=&AO9',H)T-O;G-O;&5?1V5T;W!T)RDI*2![#0H@
M("`@87)R87E?<VAI9G0H)&%R9W8I.PT*("`@("1O<'1I;VYS(#T@0V]N<V]L
M95]'971O<'0Z.F=E=&]P=#(H)&%R9W8L(")C.D,Z9#I$.D=H/W-3<74Z=E8B
M*3L-"GT@96QS92![#0H@("`@)&]P=&EO;G,@/2!#;VYS;VQE7T=E=&]P=#HZ
M9V5T;W!T*"1A<F=V+"`B8SI#.F0Z1#I':#]S4W%U.G96(BD[#0I]#0II9B`H
M4$5!4CHZ:7-%<G)O<B@D;W!T:6]N<RDI('L-"B`@("!U<V%G92@D;W!T:6]N
M<RD[#0I]#0H-"B1O<'1S(#T@)&]P=&EO;G-;,%T[#0H-"B1F971Y<&4@/2`G
M0TQ))SL-"FEF("@D<')O9VYA;64@/3T@)V=P96%R)R!\?"`D<')O9VYA;64@
M/3T@)W!E87(M9W1K)RD@>PT*("`@("1F971Y<&4@/2`G1W1K)SL-"GT@96QS
M92![#0H@("`@9F]R96%C:"`H)&]P=',@87,@)&]P="D@>PT*("`@("`@("!I
M9B`H)&]P=%LP72`]/2`G1R<I('L-"B`@("`@("`@("`@("1F971Y<&4@/2`G
M1W1K)SL-"B`@("`@("`@?0T*("`@('T-"GT-"B\O0VAE8VL@:68@1W1K(&%N
M9"!02%`@/CT@-2XQ+C`-"FEF("@D9F5T>7!E(#T]("='=&LG("8F('9E<G-I
M;VY?8V]M<&%R92AP:'!V97)S:6]N*"DL("<U+C$N,"<L("<^/2<I*2![#0H@
M("`@)&9E='EP92`]("='=&LR)SL-"GT-"@T*)'!E87)?=7-E<E]C;VYF:6<@
M/2`G)SL-"B1P96%R7W-Y<W1E;5]C;VYF:6<@/2`G)SL-"B1S=&]R95]U<V5R
M7V-O;F9I9R`](&9A;'-E.PT*)'-T;W)E7W-Y<W1E;5]C;VYF:6<@/2!F86QS
M93L-"B1V97)B;W-E(#T@,3L-"@T*9F]R96%C:"`H)&]P=',@87,@)&]P="D@
M>PT*("`@('-W:71C:"`H)&]P=%LP72D@>PT*("`@("`@("!C87-E("=C)SH-
M"B`@("`@("`@("`@("1P96%R7W5S97)?8V]N9FEG(#T@)&]P=%LQ73L-"B`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("!C87-E("=#)SH-"B`@("`@("`@
M("`@("1P96%R7W-Y<W1E;5]C;VYF:6<@/2`D;W!T6S%=.PT*("`@("`@("`@
M("`@8G)E86L[#0H@("`@?0T*?0T*#0I014%27T-O;6UA;F0Z.G-E=$9R;VYT
M96YD5'EP92@D9F5T>7!E*3L-"B1U:2`]("9014%27T-O;6UA;F0Z.F=E=$9R
M;VYT96YD3V)J96-T*"D[#0HD8V]N9FEG(#T@)E!%05)?0V]N9FEG.CIS:6YG
M;&5T;VXH)'!E87)?=7-E<E]C;VYF:6<L("1P96%R7W-Y<W1E;5]C;VYF:6<I
M.PT*#0II9B`H4$5!4CHZ:7-%<G)O<B@D8V]N9FEG*2D@>PT*("`@("1?9FEL
M92`]("<G.PT*("`@(&EF("@D<&5A<E]U<V5R7V-O;F9I9R`A/3T@9F%L<V4I
M('L-"B`@("`@("`D7V9I;&4@+CT@)'!E87)?=7-E<E]C;VYF:6<[#0H@("`@
M?0T*("`@(&EF("@D<&5A<E]S>7-T96U?8V]N9FEG("$]/2!F86QS92D@>PT*
M("`@("`@("1?9FEL92`N/2`G+R<@+B`D<&5A<E]S>7-T96U?8V]N9FEG.PT*
M("`@('T-"B`@("!I9B`H)%]F:6QE(#T]("<O)RD@>PT*("`@("`@("`D7V9I
M;&4@/2`G5&AE(&1E9F%U;'0@8V]N9FEG(&9I;&4G.PT*("`@('T-"B`@("`D
M8V]N9FEG+3YG971-97-S86=E*"D[#0H@("`@)'5I+3YO=71P=71$871A*")%
M4E)/4CH@)%]F:6QE(&ES(&YO="!A('9A;&ED(&-O;F9I9R!F:6QE(&]R(&ES
M(&-O<G)U<'1E9"XB*3L-"B`@("`O+R!792!S=&]P+"!W92!H879E(&YO(&ED
M96$@=VAE<F4@=V4@87)E(#HI#0H@("`@97AI="@I.R`@("`-"GT-"@T*+R\@
M=&AI<R!I<R!U<V5D(&EN('1H92!E<G)O<B!H86YD;&5R('1O(')E=')I979E
M(&$@<F5L871I=F4@<&%T:`T*)%]014%27U!(4$1)4B`]("1C;VYF:6<M/F=E
M="@G<&AP7V1I<B<I.PT*)'5I+3YS971#;VYF:6<H)&-O;F9I9RD[#0I014%2
M.CIS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL(&%R<F%Y
M*"1U:2P@(F1I<W!L87E&871A;$5R<F]R(BDI.PT*:68@*&EN:5]G970H)W-A
M9F5?;6]D92<I*2![#0H@("`@)'5I+3YO=71P=71$871A*"=705).24Y'.B!R
M=6YN:6YG(&EN('-A9F4@;6]D92!R97%U:7)E<R!T:&%T(&%L;"!F:6QE<R!C
M<F5A=&5D("<@+@T*("`@("`@("`G8F4@=&AE('-A;64@=6ED(&%S('1H92!C
M=7)R96YT('-C<FEP="X@(%!(4"!R97!O<G1S('1H:7,@<V-R:7!T(&ES('5I
M9#H@)R`N#0H@("`@("`@($!G971M>75I9"@I("X@)RP@86YD(&-U<G)E;G0@
M=7-E<B!I<SH@)R`N($!G971?8W5R<F5N=%]U<V5R*"DI.PT*?0T*#0HD=F5R
M8F]S92`]("1C;VYF:6<M/F=E="@B=F5R8F]S92(I.PT*)&-M9&]P=',@/2!A
M<G)A>2@I.PT*#0II9B`H)')A=RD@>PT*("`@(&EF("@A)&-O;F9I9RT^:7-$
M969I;F5D3&%Y97(H)W5S97(G*2`F)B`A)&-O;F9I9RT^:7-$969I;F5D3&%Y
M97(H)W-Y<W1E;2<I*2![#0H@("`@("`@("1F;W5N9"`](&9A;'-E.PT*("`@
M("`@("!F;W)E86-H("@D;W!T<R!A<R`D;W!T*2![#0H@("`@("`@("`@("!I
M9B`H)&]P=%LP72`]/2`G9"<@?'P@)&]P=%LP72`]/2`G1"<I('L-"B`@("`@
M("`@("`@("`@("`D9F]U;F0@/2!T<G5E.R`O+R!T:&4@=7-E<B!K;F]W<R!W
M:&%T('1H97D@87)E(&1O:6YG+"!A;F0@87)E('-E='1I;F<@8V]N9FEG('9A
M;'5E<PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@A
M)&9O=6YD*2![#0H@("`@("`@("`@("`O+R!N;R!P<FEO<B!R=6YS+"!T<GD@
M=&\@:6YS=&%L;"!014%2#0H@("`@("`@("`@("!I9B`H<W1R<&]S*&1I<FYA
M;64H7U]&24Q%7U\I+"`G<V-R:7!T<R<I*2![#0H@("`@("`@("`@("`@("`@
M)'!A8VMA9V5X;6P@/2!D:7)N86UE*&1I<FYA;64H7U]&24Q%7U\I*2`N($1)
M4D5#5$]265]315!!4D%43U(@+B`G<&%C:V%G93(N>&UL)SL-"B`@("`@("`@
M("`@("`@("`D<&5A<F)A<V4@/2!D:7)N86UE*&1I<FYA;64H7U]&24Q%7U\I
M*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)'!A
M8VMA9V5X;6P@/2!D:7)N86UE*%]?1DE,15]?*2`N($1)4D5#5$]265]315!!
M4D%43U(@+B`G<&%C:V%G93(N>&UL)SL-"B`@("`@("`@("`@("`@("`D<&5A
M<F)A<V4@/2!D:7)N86UE*%]?1DE,15]?*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D<&%C:V%G97AM;"DI('L-"B`@
M("`@("`@("`@("`@("`D;W!T:6]N<ULQ72`](&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("`@("`G:6YS=&%L;"<L#0H@("`@("`@("`@("`@("`@("`@("1P
M86-K86=E>&UL#0H@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@("`@("`@
M("`D8V]N9FEG+3YS970H)W!H<%]D:7(G+"`D<&5A<F)A<V4@+B!$25)%0U1/
M4EE?4T5005)!5$]2("X@)W!H<"<I.PT*("`@("`@("`@("`@("`@("1C;VYF
M:6<M/G-E="@G9&%T85]D:7(G+"`D<&5A<F)A<V4@+B!$25)%0U1/4EE?4T50
M05)!5$]2("X@)V1A=&$G*3L-"B`@("`@("`@("`@("`@("`D8V]N9FEG+3YS
M970H)V1O8U]D:7(G+"`D<&5A<F)A<V4@+B!$25)%0U1/4EE?4T5005)!5$]2
M("X@)V1O8W,G*3L-"B`@("`@("`@("`@("`@("`D8V]N9FEG+3YS970H)W1E
M<W1?9&ER)RP@)'!E87)B87-E("X@1$E214-43U)97U-%4$%2051/4B`N("=T
M97-T<R<I.PT*("`@("`@("`@("`@("`@("1C;VYF:6<M/G-E="@G97AT7V1I
M<B<L("1P96%R8F%S92`N($1)4D5#5$]265]315!!4D%43U(@+B`G97AT96YS
M:6]N<R<I.PT*("`@("`@("`@("`@("`@("1C;VYF:6<M/G-E="@G8FEN7V1I
M<B<L("1P96%R8F%S92D[#0H@("`@("`@("`@("`@("`@)&-O;F9I9RT^;65R
M9V5#;VYF:6=&:6QE*"1P96%R8F%S92`N("=P96%R+FEN:2<L(&9A;'-E*3L-
M"B`@("`@("`@("`@("`@("`D8V]N9FEG+3YS=&]R92@I.PT*("`@("`@("`@
M("`@("`@("1C;VYF:6<M/G-E="@G875T;U]D:7-C;W9E<B<L(#$I.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*?0T*9F]R96%C:"`H)&]P
M=',@87,@)&]P="D@>PT*("`@("1P87)A;2`]("%E;7!T>2@D;W!T6S%=*2`_
M("1O<'1;,5T@.B!T<G5E.PT*("`@('-W:71C:"`H)&]P=%LP72D@>PT*("`@
M("`@("!C87-E("=D)SH-"B`@("`@("`@("`@(&QI<W0H)&ME>2P@)'9A;'5E
M*2`](&5X<&QO9&4H)STG+"`D<&%R86TI.PT*("`@("`@("`@("`@)&-O;F9I
M9RT^<V5T*"1K97DL("1V86QU92P@)W5S97(G*3L-"B`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("!C87-E("=$)SH-"B`@("`@("`@("`@(&QI<W0H)&ME
M>2P@)'9A;'5E*2`](&5X<&QO9&4H)STG+"`D<&%R86TI.PT*("`@("`@("`@
M("`@)&-O;F9I9RT^<V5T*"1K97DL("1V86QU92P@)W-Y<W1E;2<I.PT*("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@(&-A<V4@)W,G.@T*("`@("`@("`@
M("`@)'-T;W)E7W5S97)?8V]N9FEG(#T@=')U93L-"B`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("!C87-E("=3)SH-"B`@("`@("`@("`@("1S=&]R95]S
M>7-T96U?8V]N9FEG(#T@=')U93L-"B`@("`@("`@("`@(&)R96%K.PT*("`@
M("`@("!C87-E("=U)SH-"B`@("`@("`@("`@("1C;VYF:6<M/G)E;6]V92@D
M<&%R86TL("=U<V5R)RD[#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M8V%S92`G=B<Z#0H@("`@("`@("`@("`D8V]N9FEG+3YS970H)W9E<F)O<V4G
M+"`D8V]N9FEG+3YG970H)W9E<F)O<V4G*2`K(#$I.PT*("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@(&-A<V4@)W$G.@T*("`@("`@("`@("`@)&-O;F9I
M9RT^<V5T*"=V97)B;W-E)RP@)&-O;F9I9RT^9V5T*"=V97)B;W-E)RD@+2`Q
M*3L-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!C87-E("=6)SH-"B`@
M("`@("`@("`@('5S86=E*&YU;&PL("=V97)S:6]N)RD[#0H@("`@("`@(&-A
M<V4@)V,G.@T*("`@("`@("!C87-E("=#)SH-"B`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("!D969A=6QT.@T*("`@("`@("`@("`@+R\@86QL(&YO;B!P
M96%R('!A<F%M<R!G;V5S('1O('1H92!C;VUM86YD#0H@("`@("`@("`@("`D
M8VUD;W!T<ULD;W!T6S!=72`]("1P87)A;3L-"B`@("`@("`@("`@(&)R96%K
M.PT*("`@('T-"GT-"@T*:68@*"1S=&]R95]S>7-T96U?8V]N9FEG*2![#0H@
M("`@)&-O;F9I9RT^<W1O<F4H)W-Y<W1E;2<I.PT*?0T*#0II9B`H)'-T;W)E
M7W5S97)?8V]N9FEG*2![#0H@("`@)&-O;F9I9RT^<W1O<F4H)W5S97(G*3L-
M"GT-"@T*)&-O;6UA;F0@/2`H:7-S970H)&]P=&EO;G-;,5U;,%TI*2`_("1O
M<'1I;VYS6S%=6S!=(#H@;G5L;#L-"@T*:68@*&5M<'1Y*"1C;VUM86YD*2`F
M)B`H)'-T;W)E7W5S97)?8V]N9FEG('Q\("1S=&]R95]S>7-T96U?8V]N9FEG
M*2D@>PT*("`@(&5X:70[#0I]#0H-"FEF("@D9F5T>7!E(#T]("='=&LG('Q\
M("1F971Y<&4@/3T@)T=T:S(G*2![#0H@("`@:68@*"$D8V]N9FEG+3YV86QI
M9$-O;F9I9W5R871I;VXH*2D@>PT*("`@("`@("!014%2.CIR86ES945R<F]R
M*"=#4DE424-!3"!%4E)/4CH@;F\@97AI<W1I;F<@=F%L:60@8V]N9FEG=7)A
M=&EO;B!F:6QE<R!F;W5N9"!I;B!F:6QE<R`G("X-"B`@("`@("`@("`@("(G
M)'!E87)?=7-E<E]C;VYF:6<G(&]R("<D<&5A<E]S>7-T96U?8V]N9FEG)RP@
M<&QE87-E(&-O<'D@86X@97AI<W1I;F<@8V]N9FEG=7)A=&EO;B(@+@T*("`@
M("`@("`@("`@)V9I;&4@=&\@;VYE(&]F('1H97-E(&QO8V%T:6]N<RP@;W(@
M=7-E('1H92`M8R!A;F0@+7,@;W!T:6]N<R!T;R!C<F5A=&4@;VYE)RD[#0H@
M("`@?0T*("`@($=T:SHZ;6%I;B@I.PT*?2!E;'-E(&1O('L-"B`@("!I9B`H
M)&-O;6UA;F0@/3T@)VAE;'`G*2![#0H@("`@("`@('5S86=E*&YU;&PL($`D
M;W!T:6]N<ULQ75LQ72D[#0H@("`@?0T*("`@(&EF("@A)&-O;F9I9RT^=F%L
M:61#;VYF:6=U<F%T:6]N*"DI('L-"B`@("`@("`@4$5!4CHZ<F%I<V5%<G)O
M<B@G0U))5$E#04P@15)23U(Z(&YO(&5X:7-T:6YG('9A;&ED(&-O;F9I9W5R
M871I;VX@9FEL97,@9F]U;F0@:6X@9FEL97,@)R`N#0H@("`@("`@("`@("`B
M)R1P96%R7W5S97)?8V]N9FEG)R!O<B`G)'!E87)?<WES=&5M7V-O;F9I9R<L
M('!L96%S92!C;W!Y(&%N(&5X:7-T:6YG(&-O;F9I9W5R871I;VXB("X-"B`@
M("`@("`@("`@("=F:6QE('1O(&]N92!O9B!T:&5S92!L;V-A=&EO;G,L(&]R
M('5S92!T:&4@+6,@86YD("US(&]P=&EO;G,@=&\@8W)E871E(&]N92<I.PT*
M("`@('T-"@T*("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)2
M3U)?4D5455).*3L-"B`@("`D8VUD(#T@4$5!4E]#;VUM86YD.CIF86-T;W)Y
M*"1C;VUM86YD+"`D8V]N9FEG*3L-"B`@("!014%2.CIP;W!%<G)O<DAA;F1L
M:6YG*"D[#0H@("`@:68@*%!%05(Z.FES17)R;W(H)&-M9"DI('L-"B`@("`@
M("`@=7-A9V4H;G5L;"P@0"1O<'1I;VYS6S%=6S!=*3L-"B`@("!]#0H-"B`@
M("`D<VAO<G1?87)G<R`]("1L;VYG7V%R9W,@/2!N=6QL.PT*("`@(%!%05)?
M0V]M;6%N9#HZ9V5T1V5T;W!T07)G<R@D8V]M;6%N9"P@)'-H;W)T7V%R9W,L
M("1L;VYG7V%R9W,I.PT*("`@(&EF("AI;E]A<G)A>2@G9V5T;W!T,B<L(&=E
M=%]C;&%S<U]M971H;V1S*"=#;VYS;VQE7T=E=&]P="<I*2D@>PT*("`@("`@
M("!A<G)A>5]S:&EF="@D;W!T:6]N<ULQ72D[#0H@("`@("`@("1T;7`@/2!#
M;VYS;VQE7T=E=&]P=#HZ9V5T;W!T,B@D;W!T:6]N<ULQ72P@)'-H;W)T7V%R
M9W,L("1L;VYG7V%R9W,I.PT*("`@('T@96QS92![#0H@("`@("`@("1T;7`@
M/2!#;VYS;VQE7T=E=&]P=#HZ9V5T;W!T*"1O<'1I;VYS6S%=+"`D<VAO<G1?
M87)G<RP@)&QO;F=?87)G<RD[#0H@("`@?0T*("`@(&EF("A014%2.CII<T5R
M<F]R*"1T;7`I*2![#0H@("`@("`@(&)R96%K.PT*("`@('T-"B`@("!L:7-T
M*"1T;7!O<'0L("1P87)A;7,I(#T@)'1M<#L-"B`@("`D;W!T<R`](&%R<F%Y
M*"D[#0H@("`@9F]R96%C:"`H)'1M<&]P="!A<R`D9F]O(#T^("1T;7`R*2![
M#0H@("`@("`@(&QI<W0H)&]P="P@)'9A;'5E*2`]("1T;7`R.PT*("`@("`@
M("!I9B`H)'9A;'5E(#T]/2!N=6QL*2![#0H@("`@("`@("`@("`D=F%L=64@
M/2!T<G5E.R`O+R!O<'1I;VYS('=I=&AO=70@87)G<PT*("`@("`@("!]#0H@
M("`@("`@(&EF("AS=')L96XH)&]P="D@/3T@,2D@>PT*("`@("`@("`@("`@
M)&-M9&]P=&EO;G,@/2`D8VUD+3YG971/<'1I;VYS*"1C;VUM86YD*3L-"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1C;61O<'1I;VYS(&%S("1O(#T^("1D*2![
M#0H@("`@("`@("`@("`@("`@:68@*$`D9%LG<VAO<G1O<'0G72`]/2`D;W!T
M*2![#0H@("`@("`@("`@("`@("`@("`@("1O<'1S6R1O72`]("1V86QU93L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("!I9B`H<W5B<W1R*"1O<'0L(#`L(#(I(#T]
M("<M+2<I('L-"B`@("`@("`@("`@("`@("`D;W!T<UMS=6)S='(H)&]P="P@
M,BE=(#T@)'9A;'5E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M?0T*("`@("1O:R`]("1C;60M/G)U;B@D8V]M;6%N9"P@)&]P=',L("1P87)A
M;7,I.PT*("`@(&EF("@D;VL@/3T](&9A;'-E*2![#0H@("`@("`@(%!%05(Z
M.G)A:7-E17)R;W(H(G5N:VYO=VX@8V]M;6%N9"!@)&-O;6UA;F0G(BD[#0H@
M("`@?0T*("`@(&EF("A014%2.CII<T5R<F]R*"1O:RDI('L-"B`@("`@("`@
M4$5!4CHZ<V5T17)R;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"04-++"!A
M<G)A>2@D=6DL(")D:7-P;&%Y1F%T86Q%<G)O<B(I*3L-"B`@("`@("`@4$5!
M4CHZ<F%I<V5%<G)O<B@D;VLI.PT*("`@('T-"GT@=VAI;&4@*&9A;'-E*3L-
M"@T*+R\@>WM[('5S86=E*"D-"@T*9G5N8W1I;VX@=7-A9V4H)&5R<F]R(#T@
M;G5L;"P@)&AE;'!S=6)J96-T(#T@;G5L;"D-"GL-"B`@("!G;&]B86P@)'!R
M;V=N86UE+"`D86QL7V-O;6UA;F1S.PT*("`@("1S=&1E<G(@/2!F;W!E;B@G
M<&AP.B\O<W1D97)R)RP@)W<G*3L-"B`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M97)R;W(I*2![#0H@("`@("`@(&9P=71S*"1S=&1E<G(L("1E<G)O<BT^9V5T
M365S<V%G92@I("X@(EQN(BD[#0H@("`@?2!E;'-E:68@*"1E<G)O<B`A/3T@
M;G5L;"D@>PT*("`@("`@("!F<'5T<R@D<W1D97)R+"`B)&5R<F]R7&XB*3L-
M"B`@("!]#0H@("`@:68@*"1H96QP<W5B:F5C="`A/2!N=6QL*2![#0H@("`@
M("`@("1P=70@/2!C;61(96QP*"1H96QP<W5B:F5C="D[#0H@("`@?2!E;'-E
M('L-"B`@("`@("`@)'!U="`]#0H@("`@("`@("`@("`B0V]M;6%N9',Z7&XB
M.PT*("`@("`@("`D;6%X;&5N(#T@;6%X*&%R<F%Y7VUA<"@B<W1R;&5N(BP@
M)&%L;%]C;VUM86YD<RDI.PT*("`@("`@("`D9F]R;6%T<W1R(#T@(B4M>R1M
M87AL96Y]<R`@)7-<;B([#0H@("`@("`@(&MS;W)T*"1A;&Q?8V]M;6%N9',I
M.PT*("`@("`@("!F;W)E86-H("@D86QL7V-O;6UA;F1S(&%S("1C;60@/3X@
M)&-L87-S*2![#0H@("`@("`@("`@("`D<'5T("X]('-P<FEN=&8H)&9O<FUA
M='-T<BP@)&-M9"P@4$5!4E]#;VUM86YD.CIG971$97-C<FEP=&EO;B@D8VUD
M*2D[#0H@("`@("`@('T-"B`@("`@("`@)'!U="`N/0T*("`@("`@("`@("`@
M(E5S86=E.B`D<')O9VYA;64@6V]P=&EO;G-=(&-O;6UA;F0@6V-O;6UA;F0M
M;W!T:6]N<UT@/'!A<F%M971E<G,^7&XB+@T*("`@("`@("`@("`@(E1Y<&4@
M7"(D<')O9VYA;64@:&5L<"!O<'1I;VYS7"(@=&\@;&ES="!A;&P@;W!T:6]N
M<RY<;B(N#0H@("`@("`@("`@("`B5'EP92!<(B1P<F]G;F%M92!H96QP('-H
M;W)T8W5T<UPB('1O(&QI<W0@86QL(&-O;6UA;F0@<VAO<G1C=71S+EQN(BX-
M"B`@("`@("`@("`@(")4>7!E(%PB)'!R;V=N86UE(&AE;'`@/&-O;6UA;F0^
M7"(@=&\@9V5T('1H92!H96QP(&9O<B!T:&4@<W!E8VEF:65D(&-O;6UA;F0N
M(CL-"B`@("!]#0H@("`@9G!U=',H)'-T9&5R<BP@(B1P=71<;B(I.PT*("`@
M(&9C;&]S92@D<W1D97)R*3L-"B`@("!E>&ET.PT*?0T*#0IF=6YC=&EO;B!C
M;61(96QP*"1C;VUM86YD*0T*>PT*("`@(&=L;V)A;"`D<')O9VYA;64L("1A
M;&Q?8V]M;6%N9',L("1C;VYF:6<[#0H@("`@:68@*"1C;VUM86YD(#T](")O
M<'1I;VYS(BD@>PT*("`@("`@("!R971U<FX-"B`@("`@("`@(D]P=&EO;G,Z
M7&XB+@T*("`@("`@("`B("`@("`M=B`@("`@("`@(&EN8W)E87-E('9E<F)O
M<VET>2!L979E;"`H9&5F875L="`Q*5QN(BX-"B`@("`@("`@(B`@("`@+7$@
M("`@("`@("!B92!Q=6EE="P@9&5C<F5A<V4@=F5R8F]S:71Y(&QE=F5L7&XB
M+@T*("`@("`@("`B("`@("`M8R!F:6QE("`@(&9I;F0@=7-E<B!C;VYF:6=U
M<F%T:6]N(&EN(&!F:6QE)UQN(BX-"B`@("`@("`@(B`@("`@+4,@9FEL92`@
M("!F:6YD('-Y<W1E;2!C;VYF:6=U<F%T:6]N(&EN(&!F:6QE)UQN(BX-"B`@
M("`@("`@(B`@("`@+60@9F]O/6)A<B!S970@=7-E<B!C;VYF:6<@=F%R:6%B
M;&4@8&9O;R<@=&\@8&)A<B=<;B(N#0H@("`@("`@("(@("`@("U$(&9O;SUB
M87(@<V5T('-Y<W1E;2!C;VYF:6<@=F%R:6%B;&4@8&9O;R<@=&\@8&)A<B=<
M;B(N#0H@("`@("`@("(@("`@("U'("`@("`@("`@<W1A<G0@:6X@9W)A<&AI
M8V%L("A'=&LI(&UO9&5<;B(N#0H@("`@("`@("(@("`@("US("`@("`@("`@
M<W1O<F4@=7-E<B!C;VYF:6=U<F%T:6]N7&XB+@T*("`@("`@("`B("`@("`M
M4R`@("`@("`@('-T;W)E('-Y<W1E;2!C;VYF:6=U<F%T:6]N7&XB+@T*("`@
M("`@("`B("`@("`M=2!F;V\@("`@('5N<V5T(&!F;V\G(&EN('1H92!U<V5R
M(&-O;F9I9W5R871I;VY<;B(N#0H@("`@("`@("(@("`@("UH+"`M/R`@("`@
M9&ES<&QA>2!H96QP+W5S86=E("AT:&ES(&UE<W-A9V4I7&XB+@T*("`@("`@
M("`B("`@("`M5B`@("`@("`@('9E<G-I;VX@:6YF;W)M871I;VY<;B([#0H@
M("`@?2!E;'-E:68@*"1C;VUM86YD(#T](")S:&]R=&-U=',B*2![#0H@("`@
M("`@("1S8R`](%!%05)?0V]M;6%N9#HZ9V5T4VAO<G1C=71S*"D[#0H@("`@
M("`@("1R970@/2`B4VAO<G1C=71S.EQN(CL-"B`@("`@("`@9F]R96%C:"`H
M)'-C(&%S("1S(#T^("1C*2![#0H@("`@("`@("`@("`D<F5T("X]('-P<FEN
M=&8H(B`@("`@)2TX<R`E<UQN(BP@)',L("1C*3L-"B`@("`@("`@?0T*("`@
M("`@("!R971U<FX@)')E=#L-"@T*("`@('T@96QS96EF("@D8V]M;6%N9"`]
M/2`B=F5R<VEO;B(I('L-"B`@("`@("`@<F5T=7)N(")014%2(%9E<G-I;VXZ
M("(N)$=,3T)!3%-;)W!E87)?<&%C:V%G95]V97)S:6]N)UTN#0H@("`@("`@
M("`@("`@("`B7&Y02%`@5F5R<VEO;CH@(BYP:'!V97)S:6]N*"DN#0H@("`@
M("`@("`@("`@("`B7&Y:96YD($5N9VEN92!697)S:6]N.B`B+GIE;F1?=F5R
M<VEO;B@I+@T*("`@("`@("`@("`@("`@(EQN4G5N;FEN9R!O;CH@(BYP:'!?
M=6YA;64H*3L-"@T*("`@('T@96QS96EF("@D:&5L<"`](%!%05)?0V]M;6%N
M9#HZ9V5T2&5L<"@D8V]M;6%N9"DI('L-"B`@("`@("`@:68@*&ES7W-T<FEN
M9R@D:&5L<"DI('L-"B`@("`@("`@("`@(')E='5R;B`B)'!R;V=N86UE("1C
M;VUM86YD(%MO<'1I;VYS72`D:&5L<%QN(CL-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H)&AE;'!;,5T@/3T](&YU;&PI('L-"B`@("`@("`@("`@(')E='5R
M;B`B)'!R;V=N86UE("1C;VUM86YD("1H96QP6S!=(CL-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@(')E='5R;B`B)'!R;V=N86UE("1C;VUM86YD
M(%MO<'1I;VYS72`D:&5L<%LP75QN)&AE;'!;,5TB.PT*("`@("`@("!]#0H@
M("`@?0T*("`@(')E='5R;B`B0V]M;6%N9"`G)&-O;6UA;F0G(&ES(&YO="!V
M86QI9"P@=')Y("=P96%R(&AE;'`G(CL-"GT-"@T*+R\@?7U]#0H-"F9U;F-T
M:6]N(&5R<F]R7VAA;F1L97(H)&5R<FYO+"`D97)R;7-G+"`D9FEL92P@)&QI
M;F4L("1V87)S*2![#0H@("`@:68@*"AD969I;F5D*"=%7U-44DE#5"<I("8F
M("1E<G)N;R`F($5?4U1224-4*2!\?"`A97)R;W)?<F5P;W)T:6YG*"DI('L-
M"B`@("`@("`@:68@*&1E9FEN960H)T5?4U1224-4)RD@)B8@)&5R<FYO("8@
M15]35%))0U0I('L-"B`@("`@("`@("`@(')E='5R;CL@+R\@15]35%))0U0-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)$=,3T)!3%-;)V-O;F9I9R==+3YG
M970H)W9E<F)O<V4G*2`\(#0I('L-"B`@("`@("`@("`@(')E='5R;CL@+R\@
M0'-I;&5N8V5D(&5R<F]R+"!S:&]W(&%L;"!I9B!D96)U9R!I<R!H:6=H(&5N
M;W5G:`T*("`@("`@("!]#0H@("`@?0T*("`@("1E<G)O<G1Y<&4@/2!A<G)A
M>2`H#0H@("`@("`@($5?15)23U(@("`]/B`@(D5R<F]R(BP-"B`@("`@("`@
M15]705).24Y'("`@/3X@(")787)N:6YG(BP-"B`@("`@("`@15]005)312`@
M(#T^("`B4&%R<VEN9R!%<G)O<B(L#0H@("`@("`@($5?3D]424-%("`@/3X@
M(").;W1I8V4B+`T*("`@("`@("!%7T-/4D5?15)23U(@(#T^("`B0V]R92!%
M<G)O<B(L#0H@("`@("`@($5?0T]215]705).24Y'("`]/B`@(D-O<F4@5V%R
M;FEN9R(L#0H@("`@("`@($5?0T]-4$E,15]%4E)/4B`@/3X@(")#;VUP:6QE
M($5R<F]R(BP-"B`@("`@("`@15]#3TU024Q%7U=!4DY)3D<@/3X@(")#;VUP
M:6QE(%=A<FYI;F<B+`T*("`@("`@("!%7U5315)?15)23U(@/3X@(")5<V5R
M($5R<F]R(BP-"B`@("`@("`@15]54T527U=!4DY)3D<@/3X@(")5<V5R(%=A
M<FYI;F<B+`T*("`@("`@("!%7U5315)?3D]424-%(#T^("`B57-E<B!.;W1I
M8V4B#0H@("`@*3L-"B`@("`D<')E9FEX(#T@)&5R<F]R='EP95LD97)R;F]=
M.PT*("`@(&=L;V)A;"`D7U!%05)?4$A01$E2.PT*("`@(&EF("AS=')I<W1R
M*"1F:6QE+"`D7U!%05)?4$A01$E2*2D@>PT*("`@("`@("`D9FEL92`]('-U
M8G-T<B@D9FEL92P@<W1R;&5N*"1?4$5!4E]02%!$25(I("L@,2D[#0H@("`@
M?2!E;'-E('L-"B`@("`@("`@)&9I;&4@/2!B87-E;F%M92@D9FEL92D[#0H@
M("`@?0T*("`@('!R:6YT(")<;B1P<F5F:7@Z("1E<G)M<V<@:6X@)&9I;&4@
M;VX@;&EN92`D;&EN95QN(CL-"GT-"@T*#0HO*@T*("H@3&]C86P@=F%R:6%B
M;&5S.@T*("H@=&%B+7=I9'1H.B`T#0H@*B!C+6)A<VEC+6]F9G-E=#H@-`T*
M("H@:6YD96YT+71A8G,M;6]D93H@;FEL#0H@*B!M;V1E.B!P:'`-"B`J($5N
M9#H-"B`J+PT*+R\@=FEM-C`P.G-Y;CUP:'`-"@T*/SX-"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W!E
M8VQC;60N<&AP````````````````````````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`S-3(Q`#$P-3$U-#,S-S0S`#`R,#<R-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`T*+R\-"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!02%`@5F5R<VEO;B`U
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-
M"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#0@5&AE(%!(4"!'<F]U<"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@
M<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@
M("`@('P-"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E
M(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`T*+R\@?"!A
M=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O
M;&QO=VEN9R!U<FPZ("`@("`@("`@("!\#0HO+R!\(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0N("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P-"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O
M<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`T*
M+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L
M96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\#0HO+R!\(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+B`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PT*+R\@?"!!=71H;W)S.B!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\("`@
M("`@("`@(%1O;6%S(%8N5BY#;W@@/&-O>$!I9&5C;F5T+F-O;3X@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO
M+PT*+R\@)$ED.B!P96-L8VUD+G!H<"QV(#$N,2`R,#`U+S`R+S(Q(#`U.C,P
M.C4V(&-E;&QO9R!%>'`@)`T*#0HO*BH-"B`J($!N;V1E<"!'=&L-"B`J+PT*
M:68@*"<O=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B<@(3T@)T`G+B=I
M;F-L=61E7W!A=&@G+B=`)RD@>PT*("`@(&EN:5]S970H)VEN8VQU9&5?<&%T
M:"<L("<O=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B<I.PT*("`@("1R
M87<@/2!F86QS93L-"GT@96QS92![#0H@("`@+R\@=&AI<R!I<R!A(')A=RP@
M=6YI;G-T86QL960@<&5A<BP@96ET:&5R(&$@8W9S(&-H96-K;W5T+"!O<B!P
M:'`@9&ES=')O#0H@("`@)')A=R`]('1R=64[#0I]#0ID969I;F4H)U!%05)?
M4E5.5%E012<L("=P96-L)RD[#0IR97%U:7)E7V]N8V4@)W!E87)C;60N<&AP
M)SL-"B\J#0H@*B!,;V-A;"!V87)I86)L97,Z#0H@*B!T86(M=VED=&@Z(#0-
M"B`J(&,M8F%S:6,M;V9F<V5T.B`T#0H@*B!I;F1E;G0M=&%B<RUM;V1E.B!N
M:6P-"B`J(&UO9&4Z('!H<`T*("H@16YD.@T*("HO#0HO+R!V:6TV,#`Z<WEN
M/7!H<`T*#0H_/@T*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]P96-L8VUD
M+G!H<"YO<FEG````````````````````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,S4R-0`Q,#4Q-30S,S<T,P`P,C$V-S``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`-"B\O#0HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@4$A0(%9E<G-I;VX@-2`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\
M($-O<'ER:6=H="`H8RD@,3DY-RTR,#`T(%1H92!02%`@1W)O=7`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PT*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE
M8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\
M#0HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T
M:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P-"B\O('P@879A:6QA
M8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I
M;F<@=7)L.B`@("`@("`@("`@?`T*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\#0HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F
M('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P-"B\O('P@
M;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@
M<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`T*+R\@?"!L:6-E;G-E0'!H<"YN
M970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@
M("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-
M"B\O('P@075T:&]R<SH@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"`@("`@("`@
M("!4;VUA<R!6+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\#0HO+R!\("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\-"B\O
M("1)9#H@<&5C;&-M9"YP:'`L=B`Q+C$@,C`P-2\P,B\R,2`P-3HS,#HU-B!C
M96QL;V<@17AP("0-"@T*+RHJ#0H@*B!`;F]D97`@1W1K#0H@*B\-"FEF("@G
M+VAO;64O;'5C97(O=V]R:R]P96%R+W-H87)E+W!H<"<@(3T@)T`G+B=I;F-L
M=61E7W!A=&@G+B=`)RD@>PT*("`@(&EN:5]S970H)VEN8VQU9&5?<&%T:"<L
M("<O:&]M92]L=6-E<B]W;W)K+W!E87(O<VAA<F4O<&AP)RD[#0H@("`@)')A
M=R`](&9A;'-E.PT*?2!E;'-E('L-"B`@("`O+R!T:&ES(&ES(&$@<F%W+"!U
M;FEN<W1A;&QE9"!P96%R+"!E:71H97(@82!C=G,@8VAE8VMO=70L(&]R('!H
M<"!D:7-T<F\-"B`@("`D<F%W(#T@=')U93L-"GT-"F1E9FEN92@G4$5!4E]2
M54Y465!%)RP@)W!E8VPG*3L-"G)E<75I<F5?;VYC92`G<&5A<F-M9"YP:'`G
M.PT*+RH-"B`J($QO8V%L('9A<FEA8FQE<SH-"B`J('1A8BUW:61T:#H@-`T*
M("H@8RUB87-I8RUO9F9S970Z(#0-"B`J(&EN9&5N="UT86)S+6UO9&4Z(&YI
M;`T*("H@;6]D93H@<&AP#0H@*B!%;F0Z#0H@*B\-"B\O('9I;38P,#IS>6X]
M<&AP#0H-"C\^#0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$A056YI="\`````
M````````````````````````````````````````````````````````````
M````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`U,34T,S,W,S<`,#(P,#<V`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]02%!5;FET+T%S<V5R="YP:'``````````````````````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`R-S(S-``Q,#4Q-30S,S<S-P`P,C(P-C``(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RH@
M=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F
M='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!02%`@5F5R<VEO;B`T"B`J"B`J($-O
M<'ER:6=H="`H8RD@,C`P,BTR,#`U+"!396)A<W1I86X@0F5R9VUA;FX@/'-B
M0'-E8F%S=&EA;BUB97)G;6%N;BYD93XN"B`J($%L;"!R:6=H=',@<F5S97)V
M960N"B`J"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N
M9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M;V1I9FEC871I
M;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG
M(&-O;F1I=&EO;G,*("H@87)E(&UE=#H*("H*("H@("`J(%)E9&ES=')I8G5T
M:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P
M>7)I9VAT"B`J("`@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS
M(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J(`H@*B`@("H@4F5D
M:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H
M92!A8F]V92!C;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@=&AI<R!L:7-T(&]F
M(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;@H@
M*B`@("`@=&AE(&1O8W5M96YT871I;VX@86YD+V]R(&]T:&5R(&UA=&5R:6%L
M<R!P<F]V:61E9"!W:71H('1H90H@*B`@("`@9&ES=')I8G5T:6]N+@H@*@H@
M*B`@("H@3F5I=&AE<B!T:&4@;F%M92!O9B!396)A<W1I86X@0F5R9VUA;FX@
M;F]R('1H92!N86UE<R!O9B!H:7,*("H@("`@(&-O;G1R:6)U=&]R<R!M87D@
M8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C=',@9&5R:79E
M9`H@*B`@("`@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,@
M<')I;W(@=W)I='1E;B!P97)M:7-S:6]N+@H@*@H@*B!42$E3(%-/1E1705)%
M($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@0T].
M5%))0E543U)3"B`J(")!4R!)4R(@04Y$($%.62!%6%!215-3($]2($E-4$Q)
M140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4"B`J($Q)34E4140@
M5$\L(%1(12!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519
M($%.1"!&251.15-3"B`J($9/4B!!(%!!4E1)0U5,05(@4%524$]312!!4D4@
M1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%"B`J($-/4%E224=(
M5"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%($9/4B!!3ED@1$E2
M14-4+"!)3D1)4D5#5"P*("H@24Y#241%3E1!3"P@4U!%0TE!3"P@15A%35!,
M05)9+"!/4B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP*("H@
M0E54($Y/5"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!354)35$E4551%
M($=/3T13($]2(%-%4E9)0T53.PH@*B!,3U-3($]&(%5312P@1$%402P@3U(@
M4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)255!424].*2!(3U=%5D52"B`J
M($-!55-%1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(
M15(@24X@0T].5%)!0U0L(%-44DE#"B`J($Q)04))3$E462P@3U(@5$]25"`H
M24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E.
M"B`J($%.62!705D@3U54($]&(%1(12!54T4@3T8@5$A)4R!33T945T%212P@
M159%3B!)1B!!1%9)4T5$($]&(%1(10H@*B!03U-324))3$E462!/1B!354-(
M($1!34%'12X*("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@*B!`<&%C:V%G
M92`@("!02%!5;FET"B`J($!A=71H;W(@("`@(%-E8F%S=&EA;B!"97)G;6%N
M;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`8V]P>7)I9VAT("`R
M,#`R+3(P,#4@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R
M9VUA;FXN9&4^"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C
M92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@
M*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@07-S97)T+G!H<"QV(#$N,CD@,C`P
M-2\Q,2\Q,"`P.3HT-SHQ-"!S96)A<W1I86X@17AP("0*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!(4%5N:70*("H@0'-I
M;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C`N,`H@
M*B\*"B\J*@H@*B!!('-E="!O9B!A<W-E<G0@;65T:&]D<RX*("H*("H@0&-A
M=&5G;W)Y("`@5&5S=&EN9PH@*B!`<&%C:V%G92`@("!02%!5;FET"B`J($!A
M=71H;W(@("`@(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E
M<F=M86YN+F1E/@H@*B!`8V]P>7)I9VAT("`R,#`R+3(P,#4@4V5B87-T:6%N
M($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D
M+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@("!296QE
M87-E.B`Q+C,N,@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O4$A056YI=`H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B
M;&4@<VEN8V4@4F5L96%S92`Q+C`N,`H@*B\*8VQA<W,@4$A056YI=%]!<W-E
M<G0@>PH@("`@+RHJ"B`@("`@*B!`=F%R("`@(&)O;VQE86X*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]L;V]S96QY5'EP960@
M/2!&04Q313L*"B`@("`O*BH*("`@("`J($%S<V5R=',@=&AA="!A(&AA>7-T
M86-K(&-O;G1A:6YS(&$@;F5E9&QE+@H@("`@("H*("`@("`J($!P87)A;2`@
M;6EX960*("`@("`J($!P87)A;2`@;6EX960*("`@("`J($!P87)A;2`@<W1R
M:6YG"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-I;F-E("!-971H
M;V0@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XQ+C`*("`@("`J+PH@("`@
M9G5N8W1I;VX@87-S97)T0V]N=&%I;G,H)&YE961L92P@)&AA>7-T86-K+"`D
M;65S<V%G92`]("<G*2!["B`@("`@("`@:68@*&ES7W-T<FEN9R@D;F5E9&QE
M*2`F)B!I<U]S=')I;F<H)&AA>7-T86-K*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^87-S97)T5')U92AS=')P;W,H)&AA>7-T86-K+"`D;F5E9&QE*2`A/3T@
M1D%,4T4L("1M97-S86=E*3L*("`@("`@("!]"@H@("`@("`@(&5L<V4@:68@
M*&ES7V%R<F%Y*"1H87ES=&%C:RD@)B8@(6ES7V]B:F5C="@D;F5E9&QE*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^87-S97)T5')U92AI;E]A<G)A>2@D;F5E
M9&QE+"`D:&%Y<W1A8VLI+"`D;65S<V%G92D["B`@("`@("`@?0H*("`@("`@
M("!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/F9A:6PH)U5N<W5P<&]R=&5D
M('!A<F%M971E<B!P87-S960@=&\@87-S97)T0V]N=&%I;G,H*2XG*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!<W-E<G1S('1H870@82!H
M87ES=&%C:R!D;V5S(&YO="!C;VYT86EN(&$@;F5E9&QE+@H@("`@("H*("`@
M("`J($!P87)A;2`@;6EX960*("`@("`J($!P87)A;2`@;6EX960*("`@("`J
M($!P87)A;2`@<W1R:6YG"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@
M0'-I;F-E("!-971H;V0@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XQ+C`*
M("`@("`J+PH@("`@9G5N8W1I;VX@87-S97)T3F]T0V]N=&%I;G,H)&YE961L
M92P@)&AA>7-T86-K+"`D;65S<V%G92`]("<G*2!["B`@("`@("`@:68@*&ES
M7W-T<FEN9R@D;F5E9&QE*2`F)B!I<U]S=')I;F<H)&AA>7-T86-K*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^87-S97)T1F%L<V4H<W1R<&]S*"1H87ES=&%C
M:RP@)&YE961L92D@(3T]($9!3%-%+"`D;65S<V%G92D["B`@("`@("`@?0H*
M("`@("`@("!E;'-E(&EF("AI<U]A<G)A>2@D:&%Y<W1A8VLI("8F("%I<U]O
M8FIE8W0H)&YE961L92DI('L*("`@("`@("`@("`@)'1H:7,M/F%S<V5R=$9A
M;'-E*&EN7V%R<F%Y*"1N965D;&4L("1H87ES=&%C:RDL("1M97-S86=E*3L*
M("`@("`@("!]"@H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^
M9F%I;"@G56YS=7!P;W)T960@<&%R86UE=&5R('!A<W-E9"!T;R!A<W-E<G1.
M;W1#;VYT86EN<R@I+B<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($%S<V5R=',@=&AA="!T=V\@=F%R:6%B;&5S(&%R92!E<75A;"X*("`@
M("`J"B`@("`@*B!`<&%R86T@(&UI>&5D"B`@("`@*B!`<&%R86T@(&UI>&5D
M"B`@("`@*B!`<&%R86T@('-T<FEN9PH@("`@("H@0'!A<F%M("!M:7AE9`H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@87-S
M97)T17%U86QS*"1E>'!E8W1E9"P@)&%C='5A;"P@)&UE<W-A9V4@/2`G)RP@
M)&1E;'1A(#T@,"D@>PH@("`@("`@(&EF("@H:7-?87)R87DH)&%C='5A;"D@
M("8F(&ES7V%R<F%Y*"1E>'!E8W1E9"DI('Q\"B`@("`@("`@("`@("AI<U]O
M8FIE8W0H)&%C='5A;"D@)B8@:7-?;V)J96-T*"1E>'!E8W1E9"DI*2!["B`@
M("`@("`@("`@(&EF("AI<U]A<G)A>2@D86-T=6%L*2`F)B!I<U]A<G)A>2@D
M97AP96-T960I*2!["B`@("`@("`@("`@("`@("!K<V]R="@D86-T=6%L*3L*
M("`@("`@("`@("`@("`@(&MS;W)T*"1E>'!E8W1E9"D["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@(&EF("@D=&AI<RT^7VQO;W-E;'E4>7!E9"D@>PH@
M("`@("`@("`@("`@("`@)&%C='5A;"`@(#T@)'1H:7,M/E]C;VYV97)T5&]3
M=')I;F<H)&%C='5A;"D["B`@("`@("`@("`@("`@("`D97AP96-T960@/2`D
M=&AI<RT^7V-O;G9E<G14;U-T<FEN9R@D97AP96-T960I.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D86-T=6%L("`@/2!S97)I86QI>F4H)&%C='5A
M;"D["B`@("`@("`@("`@("1E>'!E8W1E9"`]('-E<FEA;&EZ92@D97AP96-T
M960I.PH*("`@("`@("`@("`@)&UE<W-A9V4@/2!S<')I;G1F*`H@("`@("`@
M("`@("`@("<E<V5X<&5C=&5D("5S+"!A8W1U86P@)7,G+`H*("`@("`@("`@
M("`@("`A96UP='DH)&UE<W-A9V4I(#\@)&UE<W-A9V4@+B`G("<@.B`G)RP*
M("`@("`@("`@("`@("`D97AP96-T960L"B`@("`@("`@("`@("`@)&%C='5A
M;`H@("`@("`@("`@("`I.PH*("`@("`@("`@("`@:68@*"1A8W1U86P@(3T]
M("1E>'!E8W1E9"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YF
M86EL*"1M97-S86=E*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@96QS96EF("AI<U]N=6UE<FEC*"1A8W1U86PI("8F(&ES7VYU;65R:6,H
M)&5X<&5C=&5D*2D@>PH@("`@("`@("`@("`D;65S<V%G92`]('-P<FEN=&8H
M"B`@("`@("`@("`@("`@)R5S97AP96-T960@)7,E<RP@86-T=6%L("5S)RP*
M"B`@("`@("`@("`@("`@(65M<'1Y*"1M97-S86=E*2`_("1M97-S86=E("X@
M)R`G(#H@)R<L"B`@("`@("`@("`@("`@)&5X<&5C=&5D+`H@("`@("`@("`@
M("`@("@D9&5L=&$@(3T@,"D@/R`H)RLO+2`G("X@)&1E;'1A*2`Z("<G+`H@
M("`@("`@("`@("`@("1A8W1U86P*("`@("`@("`@("`@*3L*"B`@("`@("`@
M("`@(&EF("@A*"1A8W1U86P@/CT@*"1E>'!E8W1E9"`M("1D96QT82D@)B8@
M)&%C='5A;"`\/2`H)&5X<&5C=&5D("L@)&1E;'1A*2DI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^9F%I;"@D;65S<V%G92D["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D
M;65S<V%G92`]('-P<FEN=&8H"B`@("`@("`@("`@("`@)R5S97AP96-T960@
M)7,L(&%C='5A;"`E<R<L"@H@("`@("`@("`@("`@("%E;7!T>2@D;65S<V%G
M92D@/R`D;65S<V%G92`N("<@)R`Z("<G+`H@("`@("`@("`@("`@("1E>'!E
M8W1E9"P*("`@("`@("`@("`@("`D86-T=6%L"B`@("`@("`@("`@("D["@H@
M("`@("`@("`@("!I9B`H)&%C='5A;"`A/3T@)&5X<&5C=&5D*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/F9A:6PH)&UE<W-A9V4I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@07-S
M97)T<R!T:&%T('1W;R!V87)I86)L97,@<F5F97)E;F-E('1H92!S86UE(&]B
M:F5C="X*("`@("`J(%1H:7,@<F5Q=6ER97,@=&AE(%IE;F0@16YG:6YE(#(@
M=&\@=V]R:RX*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C=`H@("`@("H@
M0'!A<F%M("!O8FIE8W0*("`@("`J($!P87)A;2`@<W1R:6YG"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0&1E<')E8V%T960*("`@("`J+PH@("`@
M9G5N8W1I;VX@87-S97)T4V%M92@D97AP96-T960L("1A8W1U86PL("1M97-S
M86=E(#T@)R<I('L*("`@("`@("!I9B`H(79E<G-I;VY?8V]M<&%R92AP:'!V
M97)S:6]N*"DL("<U+C`N,"<L("<^/2<I*2!["B`@("`@("`@("`@("1T:&ES
M+3YF86EL*"=A<W-E<G1386UE*"D@;VYL>2!W;W)K<R!W:71H(%!(4"`^/2`U
M+C`N,"XG*3L*("`@("`@("!]"@H@("`@("`@(&EF("@H:7-?;V)J96-T*"1E
M>'!E8W1E9"D@?'P@:7-?;G5L;"@D97AP96-T960I*2`F)@H@("`@("`@("`@
M("`H:7-?;V)J96-T*"1A8W1U86PI("`@?'P@:7-?;G5L;"@D86-T=6%L*2DI
M('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!S<')I;G1F*`H@("`@("`@("`@
M("`@("<E<V5X<&5C=&5D('1W;R!V87)I86)L97,@=&\@<F5F97)E;F-E('1H
M92!S86UE(&]B:F5C="<L"@H@("`@("`@("`@("`@("%E;7!T>2@D;65S<V%G
M92D@/R`D;65S<V%G92`N("<@)R`Z("<G"B`@("`@("`@("`@("D["@H@("`@
M("`@("`@("!I9B`H)&5X<&5C=&5D("$]/2`D86-T=6%L*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/F9A:6PH)&UE<W-A9V4I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/F9A
M:6PH)U5N<W5P<&]R=&5D('!A<F%M971E<B!P87-S960@=&\@87-S97)T4V%M
M92@I+B<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%S<V5R
M=',@=&AA="!T=V\@=F%R:6%B;&5S(&1O(&YO="!R969E<F5N8V4@=&AE('-A
M;64@;V)J96-T+@H@("`@("H@5&AI<R!R97%U:7)E<R!T:&4@6F5N9"!%;F=I
M;F4@,B!T;R!W;W)K+@H@("`@("H*("`@("`J($!P87)A;2`@;V)J96-T"B`@
M("`@*B!`<&%R86T@(&]B:F5C=`H@("`@("H@0'!A<F%M("!S=')I;F<*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`9&5P<F5C871E9`H@("`@("HO
M"B`@("!F=6YC=&EO;B!A<W-E<G1.;W1386UE*"1E>'!E8W1E9"P@)&%C='5A
M;"P@)&UE<W-A9V4@/2`G)RD@>PH@("`@("`@(&EF("@A=F5R<VEO;E]C;VUP
M87)E*'!H<'9E<G-I;VXH*2P@)S4N,"XP)RP@)SX])RDI('L*("`@("`@("`@
M("`@)'1H:7,M/F9A:6PH)V%S<V5R=$YO=%-A;64H*2!O;FQY('=O<FMS('=I
M=&@@4$A0(#X](#4N,"XP+B<I.PH@("`@("`@('T*"B`@("`@("`@:68@*"AI
M<U]O8FIE8W0H)&5X<&5C=&5D*2!\?"!I<U]N=6QL*"1E>'!E8W1E9"DI("8F
M"B`@("`@("`@("`@("AI<U]O8FIE8W0H)&%C='5A;"D@("!\?"!I<U]N=6QL
M*"1A8W1U86PI*2D@>PH@("`@("`@("`@("`D;65S<V%G92`]('-P<FEN=&8H
M"B`@("`@("`@("`@("`@)R5S97AP96-T960@='=O('9A<FEA8FQE<R!T;R!R
M969E<F5N8V4@9&EF9F5R96YT(&]B:F5C=',G+`H*("`@("`@("`@("`@("`A
M96UP='DH)&UE<W-A9V4I(#\@)&UE<W-A9V4@+B`G("<@.B`G)PH@("`@("`@
M("`@("`I.PH*("`@("`@("`@("`@:68@*"1E>'!E8W1E9"`]/3T@)&%C='5A
M;"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YF86EL*"1M97-S
M86=E*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1T:&ES+3YF86EL*"=5;G-U<'!O<G1E9"!P87)A;65T97(@<&%S<V5D
M('1O(&%S<V5R=$YO=%-A;64H*2XG*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!<W-E<G1S('1H870@82!V87)I86)L92!I<R!N;W0@3E5,
M3"X*("`@("`J"B`@("`@*B!`<&%R86T@(&UI>&5D"B`@("`@*B!`<&%R86T@
M('-T<FEN9PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@87-S97)T3F]T3G5L;"@D86-T=6%L+"`D;65S<V%G92`]("<G*2![
M"B`@("`@("`@)&UE<W-A9V4@/2!S<')I;G1F*`H@("`@("`@("`@)R5S97AP
M96-T960@3D]4($Y53$PL(&%C='5A;"!.54Q,)RP*"B`@("`@("`@("`A96UP
M='DH)&UE<W-A9V4I(#\@)&UE<W-A9V4@+B`G("<@.B`G)PH@("`@("`@("D[
M"@H@("`@("`@(&EF("AI<U]N=6QL*"1A8W1U86PI*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^9F%I;"@D;65S<V%G92D["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@07-S97)T<R!T:&%T(&$@=F%R:6%B;&4@:7,@
M3E5,3"X*("`@("`J"B`@("`@*B!`<&%R86T@(&UI>&5D"B`@("`@*B!`<&%R
M86T@('-T<FEN9PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@87-S97)T3G5L;"@D86-T=6%L+"`D;65S<V%G92`]("<G*2![
M"B`@("`@("`@)&UE<W-A9V4@/2!S<')I;G1F*`H@("`@("`@("`@)R5S97AP
M96-T960@3E5,3"P@86-T=6%L($Y/5"!.54Q,)RP*"B`@("`@("`@("`A96UP
M='DH)&UE<W-A9V4I(#\@)&UE<W-A9V4@+B`G("<@.B`G)PH@("`@("`@("D[
M"@H@("`@("`@(&EF("@A:7-?;G5L;"@D86-T=6%L*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/F9A:6PH)&UE<W-A9V4I.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($%S<V5R=',@=&AA="!A(&-O;F1I=&EO;B!I
M<R!T<G5E+@H@("`@("H*("`@("`J($!P87)A;2`@8F]O;&5A;@H@("`@("H@
M0'!A<F%M("!S=')I;F<*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%S<V5R=%1R=64H)&-O;F1I=&EO;BP@)&UE<W-A9V4@
M/2`G)RD@>PH@("`@("`@("1M97-S86=E(#T@<W!R:6YT9B@*("`@("`@("`@
M("<E<V5X<&5C=&5D(%12544L(&%C='5A;"!&04Q312<L"@H@("`@("`@("`@
M(65M<'1Y*"1M97-S86=E*2`_("1M97-S86=E("X@)R`G(#H@)R<*("`@("`@
M("`I.PH*("`@("`@("!I9B`H(21C;VYD:71I;VXI('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YF86EL*"1M97-S86=E*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!<W-E<G1S('1H870@82!C;VYD:71I;VX@:7,@
M9F%L<V4N"B`@("`@*@H@("`@("H@0'!A<F%M("!B;V]L96%N"B`@("`@*B!`
M<&%R86T@('-T<FEN9PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@87-S97)T1F%L<V4H)&-O;F1I=&EO;BP@)&UE<W-A9V4@
M/2`G)RD@>PH@("`@("`@("1M97-S86=E(#T@<W!R:6YT9B@*("`@("`@("`@
M("<E<V5X<&5C=&5D($9!3%-%+"!A8W1U86P@5%)512<L"@H@("`@("`@("`@
M(65M<'1Y*"1M97-S86=E*2`_("1M97-S86=E("X@)R`G(#H@)R<*("`@("`@
M("`I.PH*("`@("`@("!I9B`H)&-O;F1I=&EO;BD@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/F9A:6PH)&UE<W-A9V4I.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($%S<V5R=',@=&AA="!A('-T<FEN9R!M871C:&5S
M(&$@9VEV96X@<F5G=6QA<B!E>'!R97-S:6]N+@H@("`@("H*("`@("`J($!P
M87)A;2`@<W1R:6YG"B`@("`@*B!`<&%R86T@('-T<FEN9PH@("`@("H@0'!A
M<F%M("!S=')I;F<*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&%S<V5R=%)E9T5X<"@D<&%T=&5R;BP@)'-T<FEN9RP@)&UE
M<W-A9V4@/2`G)RD@>PH@("`@("`@("1M97-S86=E(#T@<W!R:6YT9B@*("`@
M("`@("`@("<E<R(E<R(@9&]E<R!N;W0@;6%T8V@@<&%T=&5R;B`B)7,B)RP*
M"B`@("`@("`@("`A96UP='DH)&UE<W-A9V4I(#\@)&UE<W-A9V4@+B`G("<@
M.B`G)RP*("`@("`@("`@("1S=')I;F<L"B`@("`@("`@("`D<&%T=&5R;@H@
M("`@("`@("D["@H@("`@("`@(&EF("@A<')E9U]M871C:"@D<&%T=&5R;BP@
M)'-T<FEN9RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YF86EL*"1M
M97-S86=E*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!<W-E
M<G1S('1H870@82!S=')I;F<@9&]E<R!N;W0@;6%T8V@@82!G:79E;B!R96=U
M;&%R(&5X<')E<W-I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<*
M("`@("`J($!P87)A;2`@<W1R:6YG"B`@("`@*B!`<&%R86T@('-T<FEN9PH@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S:6YC92`@365T:&]D(&%V
M86EL86)L92!S:6YC92!296QE87-E(#$N,2XP"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%S<V5R=$YO=%)E9T5X<"@D<&%T=&5R;BP@)'-T<FEN9RP@)&UE<W-A
M9V4@/2`G)RD@>PH@("`@("`@("1M97-S86=E(#T@<W!R:6YT9B@*("`@("`@
M("`@("<E<R(E<R(@;6%T8VAE<R!P871T97)N("(E<R(G+`H*("`@("`@("`@
M("%E;7!T>2@D;65S<V%G92D@/R`D;65S<V%G92`N("<@)R`Z("<G+`H@("`@
M("`@("`@)'-T<FEN9RP*("`@("`@("`@("1P871T97)N"B`@("`@("`@*3L*
M"B`@("`@("`@:68@*'!R96=?;6%T8V@H)'!A='1E<FXL("1S=')I;F<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9F%I;"@D;65S<V%G92D["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@07-S97)T<R!T:&%T(&$@
M=F%R:6%B;&4@:7,@;V8@82!G:79E;B!T>7!E+@H@("`@("H*("`@("`J($!P
M87)A;2`@<W1R:6YG("`@("`@("`@("1E>'!E8W1E9`H@("`@("H@0'!A<F%M
M("!M:7AE9"`@("`@("`@("`@)&%C='5A;`H@("`@("H@0'!A<F%M("!O<'1I
M;VYA;"!S=')I;F<@)&UE<W-A9V4*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%S<V5R=%1Y<&4H)&5X<&5C=&5D+"`D86-T
M=6%L+"`D;65S<V%G92`]("<G*2!["B`@("`@("`@<F5T=7)N("1T:&ES+3YA
M<W-E<G1%<75A;',H"B`@("`@("`@("`D97AP96-T960L"B`@("`@("`@("!G
M971T>7!E*"1A8W1U86PI+`H@("`@("`@("`@)&UE<W-A9V4*("`@("`@("`I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@82!V86QU92!T;R!A
M('-T<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@(&UI>&5D("`@)'9A;'5E
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V-O;G9E<G14;U-T<FEN9R@D=F%L=64I('L*("`@("`@("!F;W)E86-H("@D
M=F%L=64@87,@)&L@/3X@)'8I('L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y
M*"1V*2D@>PH@("`@("`@("`@("`@("`@)'9A;'5E6R1K72`]("1T:&ES+3Y?
M8V]N=F5R=%1O4W1R:6YG*"1V86QU95LD:UTI.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@<V5T='EP92@D=F%L=65;)&M=+"`G<W1R
M:6YG)RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D=F%L=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<&%R86T@(&)O;VQE
M86X@)&QO;W-E;'E4>7!E9`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T3&]O<V5L>51Y<&5D*"1L;V]S96QY5'EP960I
M('L*("`@("`@("!I9B`H:7-?8F]O;"@D;&]O<V5L>51Y<&5D*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7VQO;W-E;'E4>7!E9"`]("1L;V]S96QY5'EP960[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1F%I;',@82!T97-T
M('=I=&@@=&AE(&=I=F5N(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0'!A<F%M
M("!S=')I;F<*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B!`86)S
M=')A8W0*("`@("`J+PH@("`@9G5N8W1I;VX@9F%I;"@D;65S<V%G92`]("<G
M*2![("\J(&%B<W1R86-T("HO('T*?0H*+RH*("H@3&]C86P@=F%R:6%B;&5S
M.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z(#0*("H@8RUH
M86YG:6YG+6-O;6UE;G0M96YD97(M<#H@;FEL"B`J($5N9#H*("HO"C\^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!(4%5N:70O1U5)+P``````````
M````````````````````````````````````````````````````````````
M`````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,S-S,W`#`R,#4R,@`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$A0
M56YI="]'54DO1W1K+G!H<```````````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P-30S,C<`,3`U,34T,S,W,S<`,#(Q-S<S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J('9I;3H@<V5T
M(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P
M/30Z("HO"@HO*BH*("H@4$A0(%9E<G-I;VX@-`H@*@H@*B!#;W!Y<FEG:'0@
M*&,I(#(P,#(M,C`P-2P@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I
M86XM8F5R9VUA;FXN9&4^+@H@*B!!;&P@<FEG:'1S(')E<V5R=F5D+@H@*@H@
M*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y
M(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D:69I8V%T:6]N+"!A<F4@
M<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I
M;VYS"B`J(&%R92!M970Z"B`J"B`J("`@*B!2961I<W1R:6)U=&EO;G,@;V8@
M<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H=`H@
M*B`@("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE
M(&9O;&QO=VEN9R!D:7-C;&%I;65R+@H@*B`*("H@("`J(%)E9&ES=')I8G5T
M:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@
M8V]P>7)I9VAT"B`J("`@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I
M;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X*("H@("`@('1H
M92!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED
M960@=VET:"!T:&4*("H@("`@(&1I<W1R:6)U=&EO;BX*("H*("H@("`J($YE
M:71H97(@=&AE(&YA;64@;V8@4V5B87-T:6%N($)E<F=M86YN(&YO<B!T:&4@
M;F%M97,@;V8@:&ES"B`J("`@("!C;VYT<FEB=71O<G,@;6%Y(&)E('5S960@
M=&\@96YD;W)S92!O<B!P<F]M;W1E('!R;V1U8W1S(&1E<FEV960*("H@("`@
M(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T('-P96-I9FEC('!R:6]R('=R
M:71T96X@<&5R;6ES<VEO;BX*("H*("H@5$A)4R!33T945T%212!)4R!04D]6
M241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]2
M4PH@*B`B05,@25,B($%.1"!!3ED@15A04D534R!/4B!)35!,245$(%=!4E)!
M3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5`H@*B!,24U)5$5$(%1/+"!42$4@
M24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!3D0@1DE4
M3D534PH@*B!&3U(@02!005)424-53$%2(%!54E!/4T4@05)%($1)4T-,04E-
M140N($E.($Y/($5614Y4(%-(04Q,(%1(10H@*B!#3U!94DE'2%0@3U=.15(@
M3U(@0T].5%))0E543U)3($)%($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$
M25)%0U0L"B`J($E.0TE$14Y404PL(%-014-)04PL($5814U03$%262P@3U(@
M0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L"B`J($)55"!.3U0@
M3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/
M4B!315)624-%4SL*("H@3$]34R!/1B!54T4L($1!5$$L($]2(%!23T9)5%,[
M($]2($)54TE.15-3($E.5$524E505$E/3BD@2$]7159%4@H@*B!#0553140@
M04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E.($-/
M3E1204-4+"!35%))0PH@*B!,24%"24Q)5%DL($]2(%1/4E0@*$E.0TQ51$E.
M1R!.14=,24=%3D-%($]2($]42$525TE312D@05))4TE.1R!)3@H@*B!!3ED@
M5T%9($]55"!/1B!42$4@55-%($]&(%1(25,@4T]&5%=!4D4L($5614X@248@
M041625-%1"!/1B!42$4*("H@4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N
M"B`J"B`J($!C871E9V]R>2`@(%1E<W1I;F<*("H@0'!A8VMA9V4@("`@4$A0
M56YI=`H@*B!`875T:&]R("`@("!38V]T="!-871T;V-K<R`\<V-O='1`8W)I
M<W-C;W1T+F-O;3X*("H@0&-O<'ER:6=H="`@,C`P,BTR,#`U(%-E8F%S=&EA
M;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`;&EC
M96YS92`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S
M9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@0U93
M.B`D260Z($=T:RYP:'`L=B`Q+C8@,C`P-2\Q,2\Q,"`P.3HT-SHQ-2!S96)A
M<W1I86X@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+U!(4%5N:70*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B
M;&4@<VEN8V4@4F5L96%S92`Q+C(N,`H@*B\*"FEF("@A9G5N8W1I;VY?97AI
M<W1S*"=I<U]A)RDI('L*("`@(')E<75I<F5?;VYC92`G4$A0+T-O;7!A="]&
M=6YC=&EO;B]I<U]A+G!H<"<["GT*"B\J*@H@*B!'5$L@1U5)(&EN=&5R9F%C
M92!F;W(@4$A056YI="X*("H*("H@5&AI<R!C;&%S<R!I<R!A(%!(4"!P;W)T
M(&]F(&IU;FET+F%W='5I+G1E<W1R=6YN97(N($1O8W5M96YT871I;VX*("H@
M9F]R(&IU;FET+F%W='5I+G1E<W1R=6YN97(@8V%N(&)E(&9O=6YD(&%T"B`J
M(&AT='`Z+R]J=6YI="YS;W5R8V5F;W)G92YN970*("H*("H@1'5E('1O('1H
M92!L:6UI=&%T:6]N<R!O9B!02%`T(&%N9"!02%`M1W1K+"!T:&ES(&-L87-S
M(&-A;B!N;W0*("H@9'5P;&EC871E(&%L;"!O9B!T:&4@9G5N8W1I;VYA;&ET
M>2!O9B!T:&4@2E5N:70@1U5)+B!3;VUE(&]F('1H90H@*B!T:&EN9W,@=&AI
M<R!C;&%S<R!C86YN;W0@9&\@:6YC;'5D93H*("H@+2!296QO861I;F<@=&AE
M(&-L87-S(&9O<B!E86-H(')U;@H@*B`M(%-T;W!P:6YG('1H92!T97-T(&EN
M('!R;V=R97-S"B`J"B`J(%1O('5S92!S:6UP;'D@:6YT86YT:6%T92!T:&4@
M8VQA<W,@86YD(&-A;&P@;6%I;B@I"B`J("1G=&L@/28@;F5W(%!(4%5N:71?
M1U5)7T=T:SL*("H@)&=T:RT^;6%I;B@I.PH@*@H@*B!/;F-E('1H92!W:6YD
M;W<@:&%S(&9I;FES:&5D(&QO861I;F<L('EO=2!C86X@96YT97(@=&AE(&YA
M;64@;V8*("H@82!C;&%S<R!T:&%T(&AA<R!B965N(&QO861E9"`H:6YC;'5D
M92]R97%U:7)E('-O;64@=VAE<F4@:6X@>6]U<@H@*B!C;V1E+"!O<B!Y;W4@
M8V%N('!A<W,@=&AE(&YA;64@;V8@=&AE(&9I;&4@8V]N=&%I;FEN9R!T:&4@
M8VQA<W,N"B`J"B`J(%EO=2!C86X@86QS;R!L;V%D(&-L87-S97,@=7-I;F<@
M=&AE(%-E='5P1&5C;W)A=&]R(&-L87-S+@H@*B!R97%U:7)E7V]N8V4@)U!(
M4%5N:70O1U5)+U-E='5P1&5C;W)A=&]R+G!H<"<["B`J(')E<75I<F5?;VYC
M92`G4$A056YI="]'54DO1W1K+G!H<"<["B`J("1G=6D@/2!N97<@4$A056YI
M=%]'54E?4V5T=7!$96-O<F%T;W(H;F5W(%!(4%5N:71?1U5)7T=T:R@I*3L*
M("H@)&=U:2T^9V5T4W5I=&5S1G)O;41I<B@G+W!A=&@O=&\O=&5S="<L)RXJ
M7"YP:'`D)RQA<G)A>2@G:6YD97@N<&AP)RPG<W%L+G!H<"<I*3L*("H@)&=U
M:2T^<VAO=R@I.PH@*@H@*@H@*B!`8V%T96=O<GD@("!497-T:6YG"B`J($!P
M86-K86=E("`@(%!(4%5N:70*("H@0&%U=&AO<B`@("`@4V-O='0@36%T=&]C
M:W,@/'-C;W1T0&-R:7-S8V]T="YC;VT^"B`J($!C;W!Y<FEG:'0@(#(P,#(M
M,C`P-2!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N
M;BYD93X*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R
M9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V
M97)S:6]N("`@(%)E;&5A<V4Z(#$N,RXR"B`J($!L:6YK("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]02%!5;FET"B`J($!S:6YC92`@("`@
M($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N,BXP"B`J($!T;V1O
M("`@("`@($%L;&]W(&9I;&4@9')O<"X@*$=T:U]&:6QE1')O<"D*("HO"F-L
M87-S(%!(4%5N:71?1U5)7T=T:R!["@H@("`@+RHJ"B`@("`@*B!4:&4@;6%I
M;B!G=&L@=VEN9&]W"B`@("`@*B!`=F%R(&]B:F5C=`H@("`@("HO"B`@("!V
M87(@)&=U:3L*("`@("\J*@H@("`@("H@5&AE('1E>'0@96YT<GD@=&AA="!C
M;VYT86EN<R!T:&4@;F%M92!O9B!T:&4*("`@("`J(&9I;&4@=&AA="!H;VQD
M<R!T:&4@=&5S="AS*2]S=6ET92AS*2X*("`@("`J($!V87(@;V)J96-T"B`@
M("`@*B\*("`@('9A<B`D<W5I=&5&:65L9#L*("`@("\J*@H@("`@("H@5&AE
M(&QA8F5L('1H870@<VAO=W,@=&AE(&YU;6)E<B!O9B!T97-T<R!T:&%T"B`@
M("`@*B!W97)E(')U;BX*("`@("`J($!V87(@;V)J96-T"B`@("`@*B\*("`@
M('9A<B`D;G5M8F5R3V92=6YS.PH@("`@+RHJ"B`@("`@*B!4:&4@;&%B96P@
M=&AA="!S:&]W<R!T:&4@;G5M8F5R(&]F(&5R<F]R<R!T:&%T"B`@("`@*B!W
M97)E(&5N8V]U;G1E<F5D+@H@("`@("H@0'9A<B!O8FIE8W0*("`@("`J+PH@
M("`@=F%R("1N=6UB97)/9D5R<F]R<SL*("`@("\J*@H@("`@("H@5&AE(&QA
M8F5L('1H870@<VAO=W,@=&AE(&YU;6)E<B!O9B!F86EL=7)E<PH@("`@("H@
M=&AA="!W97)E(&5N8V]U;G1E<F5D+@H@("`@("H@0'9A<B!O8FIE8W0*("`@
M("`J+PH@("`@=F%R("1N=6UB97)/9D9A:6QU<F5S.PH@("`@+RHJ"B`@("`@
M*B!4:&4@;&%B96P@9F]R(')E<&]R=&EN9R!U<V5R(&UE<W-A9V5S+@H@("`@
M("H@0'9A<B!O8FIE8W0*("`@("`J+PH@("`@=F%R("1S=&%T=7-,:6YE.PH@
M("`@+RHJ"B`@("`@*B!4:&4@=&5X="!A<F5A(&9O<B!R97!O<G1I;F<@;65S
M<V%G97,@9G)O;2!S=6-C97-S9G5L"B`@("`@*B!T97-T(')U;G,N("AN;W0@
M;F5C97-S87)I;'D@<W5C8V5S<V9U;"!T97-T<RD*("`@("`J($!V87(@;V)J
M96-T"B`@("`@*B\*("`@('9A<B`D<F5P;W)T07)E83L*("`@("\J*@H@("`@
M("H@5&AE('1E>'0@87)E82!F;W(@<F5P;W)T:6YG(&5R<F]R<R!E;F-O=6YT
M97)E9"!W:&5N"B`@("`@*B!R=6YN:6YG('1E<W1S+@H@("`@("H@0'9A<B!O
M8FIE8W0*("`@("`J+PH@("`@=F%R("1D=6UP07)E83L*("`@("\J*@H@("`@
M("H@5&AE('!R;V=R97-S(&)A<B!I;F1I8V%T;W(N(%-H;W=S('1H92!P97)C
M96YT86=E(&]F"B`@("`@*B!P87-S960@=&5S=',N"B`@("`@*B!`=F%R(&]B
M:F5C=`H@("`@("HO"B`@("!V87(@)'!R;V=R97-S.PH@("`@+RHJ"B`@("`@
M*B!!(&-H96-K8F]X(&9O<B!T:&4@=7-E<B!T;R!I;F1I8V%T92!W:&5T:&5R
M(&]R(&YO="!T:&5Y"B`@("`@*B!W;W5L9"!L:6ME('1O('-E92!R97-U;'1S
M(&9R;VT@86QL('1E<W1S(&]R(&IU<W0@9F%I;'5R97,N"B`@("`@*B!`;V)J
M96-T"B`@("`@*B\*("`@('9A<B`D<VAO=U!A<W-E9#L*"B`@("`O*BH*("`@
M("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J(%1H92!C;VYS=')U8W1O
M<B!C:&5C:W,@9F]R('1H92!G=&L@97AT96YS:6]N(&%N9"!L;V%D<R!I=`H@
M("`@("H@:68@;F5E9&5D+B!4:&5N(&ET(&-R96%T97,@=&AE($=522X@5&AE
M($=522!I<R!N;W0@<VAO=VX*("`@("`J(&YO<B!I<R!T:&4@;6%I;B!G=&L@
M;&]O<"!S=&%R=&5D('5N=&EL(&UA:6XH*2!I<R!C86QL960N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2`@;F]N90H@("`@
M("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(%!(4%5N:71?
M1U5)7T=T:R@I"B`@("!["B`@("`@("`@+R\@0VAE8VL@9F]R('!H<"UG=&L@
M97AT96YS:6]N+@H@("`@("`@(&EF("@A97AT96YS:6]N7VQO861E9"@G9W1K
M)RDI('L*("`@("`@("`@("`@9&PH("=P:'!?9W1K+B<@+B!02%!?4TA,24)?
M4U5&1DE8*3L*("`@("`@("!]"@H@("`@("`@("\O($-R96%T92!T:&4@:6YT
M97)F86-E(&)U="!D;VXG="!S=&%R="!T:&4@;&]O<`H@("`@("`@("1T:&ES
M+3Y?8W)E871E54DH*3L*("`@('T*("`@("\J*@H@("`@("H@4W1A<G0@=&AE
M(&UA:6X@9W1K(&QO;W`N"B`@("`@*@H@("`@("H@;6%I;B@I(&9I<G-T('-E
M=',@=&AE(&1E9F%U;'0@<W1A=&4@;V8@=&AE('-H;W=087-S960*("`@("`J
M(&-H96-K(&)O>"X@3F5X="!A;&P@=VED9V5T<R!T:&%T(&%R92!P87)T(&]F
M('1H92!'54D*("`@("`J(&%R92!S:&]W;BX@1FEN86QL>2!T:&4@;6%I;B!G
M=&L@;&]O<"!I<R!S=&%R=&5D+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<&%R86T@(&)O;VQE86X@)'-H;W=087-S960*("`@("`J
M($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!M86EN*"1S:&]W
M4&%S<V5D(#T@=')U92D*("`@('L*("`@("`@("`D=&AI<RT^<VAO=U!A<W-E
M9"T^<V5T7V%C=&EV92@D<VAO=U!A<W-E9"D["B`@("`@("`@)'1H:7,M/F=U
M:2T^<VAO=U]A;&PH*3L*"B`@("`@("`@9W1K.CIM86EN*"D["B`@("!]"B`@
M("`O*BH*("`@("`J($-R96%T92!T:&4@=7-E<B!I;G1E<F9A8V4N"B`@("`@
M*@H@("`@("H@5&AE('5S97(@:6YT97)F86-E(&ES('!R971T>2!S:6UP;&4N
M($ET(&-O;G-I<W1S(&]F(&$*("`@("`J(&UE;G4L('1E>'0@96YT<GDL(')U
M;B!B=71T;VXL('-O;64@;&%B96QS+"!A('!R;V=R97-S"B`@("`@*B!I;F1I
M8V%T;W(L(&%N9"!A(&-O=7!L92!O9B!A<F5A<R!F;W(@;F]T:69I8V%T:6]N
M(&]F"B`@("`@*B!A;GD@;65S<V%G97,N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B!`<&%R86T@(&YO;F4*("`@("`J($!R971U<FX@
M=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!?8W)E871E54DH*0H@("`@>PH@
M("`@("`@("\O($-R96%T92!A('=I;F1O=RX*("`@("`@("`D=VEN9&]W(#TF
M(&YE=R!'=&M7:6YD;W<["B`@("`@("`@)'=I;F1O=RT^<V5T7W1I=&QE*"=0
M2%!5;FET($=T:R<I.PH@("`@("`@("1W:6YD;W<M/G-E=%]U<VEZ92@T,#`L
M("TQ*3L*"B`@("`@("`@+R\@0W)E871E('1H92!M86EN(&)O>"X*("`@("`@
M("`D;6%I;D)O>"`])B!N97<@1W1K5D)O>#L*("`@("`@("`D=VEN9&]W+3YA
M9&0H)&UA:6Y";W@I.PH*("`@("`@("`O+R!3=&%R="!W:71H('1H92!M96YU
M+@H@("`@("`@("1M86EN0F]X+3YP86-K7W-T87)T*"1T:&ES+3Y?8W)E871E
M365N=2@I*3L*"B`@("`@("`@+R\@5&AE;B!A9&0@=&AE('-U:71E(&9I96QD
M(&5N=')Y+@H@("`@("`@("1M86EN0F]X+3YP86-K7W-T87)T*"1T:&ES+3Y?
M8W)E871E4W5I=&5%;G1R>2@I*3L*"B`@("`@("`@+R\@5&AE;B!A9&0@=&AE
M(')E<&]R="!L86)E;',N"B`@("`@("`@)&UA:6Y";W@M/G!A8VM?<W1A<G0H
M)'1H:7,M/E]C<F5A=&5297!O<G1,86)E;',H*2D["@H@("`@("`@("\O($YE
M>'0@861D('1H92!P<F]G<F5S<R!B87(N"B`@("`@("`@)&UA:6Y";W@M/G!A
M8VM?<W1A<G0H)'1H:7,M/E]C<F5A=&50<F]G<F5S<T)A<B@I*3L*"B`@("`@
M("`@+R\@5&AE;B!A9&0@=&AE(')E<&]R="!A<F5A(&%N9"!T:&4@9'5M<"!A
M<F5A+@H@("`@("`@("1M86EN0F]X+3YP86-K7W-T87)T*"1T:&ES+3Y?8W)E
M871E4F5P;W)T07)E87,H*2D["@H@("`@("`@("\O($9I;FES:"!O9F8@=VET
M:"!T:&4@<W1A='5S(&QI;F4N"B`@("`@("`@)&UA:6Y";W@M/G!A8VM?<W1A
M<G0H)'1H:7,M/E]C<F5A=&53=&%T=7-,:6YE*"DI.PH*("`@("`@("`O+R!#
M;VYN96-T('1H92!D97-T<F]Y('-I9VYA;"X*("`@("`@("`D=VEN9&]W+3YC
M;VYN96-T7V]B:F5C="@G9&5S=')O>2<L(&%R<F%Y*"=G=&LG+"`G;6%I;E]Q
M=6ET)RDI.PH*("`@("`@("`O+R!!<W-I9VX@=&AE(&UE;6)E<BX*("`@("`@
M("`D=&AI<RT^9W5I(#TF("1W:6YD;W<["B`@("!]"B`@("`O*BH*("`@("`J
M($-R96%T92!T:&4@;65N=2X*("`@("`J"B`@("`@*B!4:&4@;65N=2!I<R!V
M97)Y('-I;7!L92X@270@86X@97AI="!M96YU(&ET96TL('=H:6-H(&5X:71S
M"B`@("`@*B!T:&4@87!P;&EC871I;VXL(&%N9"!A;B!A8F]U="!M96YU(&ET
M96TL('=H:6-H('-H;W=S('-O;64*("`@("`J(&)A<VEC(&EN9F]R;6%T:6]N
M(&%B;W5T('1H92!A<'!L:6-A=&EO;B!I='-E;&8N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@(&YO;F4*("`@("`J($!R
M971U<FX@)F]B:F5C="!4:&4@1W1K365N=4)A<@H@("`@("HO"B`@("!F=6YC
M=&EO;B`F7V-R96%T94UE;G4H*0H@("`@>PH@("`@("`@("\O($-R96%T92!T
M:&4@;65N=2!B87(N"B`@("`@("`@)&UE;G5"87(@/28@;F5W($=T:TUE;G5"
M87(["@H@("`@("`@("\O($-R96%T92!T:&4@;6%I;B`H;VYL>2D@;65N=2!I
M=&5M+@H@("`@("`@("1P:'!(96%D97(@/28@;F5W($=T:TUE;G5)=&5M*"=0
M2%!5;FET)RD["@H@("`@("`@("\O($%D9"!T:&4@;65N=2!I=&5M('1O('1H
M92!M96YU(&)A<BX*("`@("`@("`D;65N=4)A<BT^87!P96YD*"1P:'!(96%D
M97(I.PH*("`@("`@("`O+R!#<F5A=&4@=&AE(%!(4%5N:70@;65N=2X*("`@
M("`@("`D<&AP365N=2`])B!N97<@1W1K365N=3L*"B`@("`@("`@+R\@061D
M('1H92!M96YU(&ET96US"B`@("`@("`@)&%B;W5T(#TF(&YE=R!'=&M-96YU
M271E;2@G06)O=70N+BXG*3L*("`@("`@("`D86)O=70M/F-O;FYE8W0H)V%C
M=&EV871E)RP@87)R87DH)B1T:&ES+"`G86)O=70G*2D["B`@("`@("`@)'!H
M<$UE;G4M/F%P<&5N9"@D86)O=70I.PH*("`@("`@("`D97AI="`])B!N97<@
M1W1K365N=4ET96TH)T5X:70G*3L*("`@("`@("`D97AI="T^8V]N;F5C=%]O
M8FIE8W0H)V%C=&EV871E)RP@87)R87DH)V=T:R<L("=M86EN7W%U:70G*2D[
M"B`@("`@("`@)'!H<$UE;G4M/F%P<&5N9"@D97AI="D["@H@("`@("`@("\O
M($-O;7!L971E('1H92!M96YU+@H@("`@("`@("1P:'!(96%D97(M/G-E=%]S
M=6)M96YU*"1P:'!-96YU*3L*"B`@("`@("`@<F5T=7)N("1M96YU0F%R.PH@
M("`@?0H@("`@+RHJ"B`@("`@*B!#<F5A=&4@=&AE('-U:71E(&5N=')Y(&%N
M9"!R96QA=&5D('=I9&=E=',N"B`@("`@*@H@("`@("H@5&AE('-U:71E(&5N
M=')Y(&AA<R!S;VUE('-U<'!O<G1I;F<@8V]M<&]N96YT<R!S=6-H(&%S(&$*
M("`@("`J(&QA8F5L+"!T:&4@<VAO=R!P87-S960@8VAE8VL@8F]X(&%N9"!T
M:&4@<G5N(&)U='1O;BX@06QL"B`@("`@*B!O9B!T:&5S92!I=&5M<R!A<F4@
M<&%C:V5D(&EN=&\@='=O(&YE<W1E9"!B;WAE<RX*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2`@;F]N90H@("`@("H@0')E
M='5R;B`F;V)J96-T($$@8F]X('1H870@8V]N=&%I;G,@86QL(&]F('1H92!S
M=6ET92!E;G1R>2!P:65C97,N"B`@("`@*B\*("`@(&9U;F-T:6]N("9?8W)E
M871E4W5I=&5%;G1R>2@I"B`@("!["B`@("`@("`@+R\@0W)E871E('1H92!O
M=71E<FUO<W0@8F]X+@H@("`@("`@("1O=71E<D)O>"`@("`@("`@(#TF(&YE
M=R!'=&M60F]X.PH*("`@("`@("`O+R!#<F5A=&4@=&AE('-U:71E(&QA8F5L
M+"!B;W@L(&%N9"!F:65L9"X*("`@("`@("`D<W5I=&5,86)E;"`@("`@("`]
M)B!N97<@1W1K3&%B96PH)U1E<W0@8VQA<W,@;F%M93HG*3L*("`@("`@("`D
M<W5I=&5";W@@("`@("`@("`])B!N97<@1W1K2$)O>#L*("`@("`@("`D=&AI
M<RT^<W5I=&5&:65L9"`])B!N97<@1W1K16YT<GD["B`@("`@("`@)'1H:7,M
M/G-U:71E1FEE;&0M/G-E=%]T97AT*"1S=6ET94YA;64@(3T@3E5,3"`_("1S
M=6ET94YA;64@.B`G)RD["@H@("`@("`@("\O($-R96%T92!T:&4@8G5T=&]N
M('1H92!U<V5R('=I;&P@=7-E('1O('-T87)T('1H92!T97-T+@H@("`@("`@
M("1R=6Y"=71T;VX@/28@;F5W($=T:T)U='1O;B@G4G5N)RD["B`@("`@("`@
M)')U;D)U='1O;BT^8V]N;F5C=%]O8FIE8W0H)V-L:6-K960G+"!A<G)A>2@F
M)'1H:7,L("=R=6XG*2D["@H@("`@("`@("\O($-R96%T92!T:&4@8VAE8VL@
M8F]X('1H870@;&5T<R!T:&4@=7-E<B!S:&]W(&]N;'D@9F%I;'5R97,N"B`@
M("`@("`@)'1H:7,M/G-H;W=087-S960@/28@;F5W($=T:T-H96-K0G5T=&]N
M*"=3:&]W('!A<W-E9"!T97-T<R<I.PH*("`@("`@("`O+R!!9&0@=&AE(&-O
M;7!O;F5N=',@=&\@=&AE:7(@<F5S<&5C=&EV92!B;WAE<RX*("`@("`@("`D
M<W5I=&5,86)E;"T^<V5T7V%L:6=N;65N="@P+"`P*3L*("`@("`@("`D;W5T
M97)";W@M/G!A8VM?<W1A<G0H)'-U:71E3&%B96PI.PH@("`@("`@("1O=71E
M<D)O>"T^<&%C:U]S=&%R="@D<W5I=&5";W@I.PH@("`@("`@("1O=71E<D)O
M>"T^<&%C:U]S=&%R="@D=&AI<RT^<VAO=U!A<W-E9"D["@H@("`@("`@("1S
M=6ET94)O>"T^<&%C:U]S=&%R="@D=&AI<RT^<W5I=&5&:65L9"D["B`@("`@
M("`@)'-U:71E0F]X+3YP86-K7W-T87)T*"1R=6Y"=71T;VXI.PH*("`@("`@
M("!R971U<FX@)&]U=&5R0F]X.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E
M871E('1H92!L86)E;',@=&AA="!T96QL('1H92!U<V5R('=H870@:&%S(&AA
M<'!E;F5D+@H@("`@("H*("`@("`J(%1H97)E(&%R92!T:')E92!L86)E;',L
M(&]N92!E86-H(&9O<B!T;W1A;"!R=6YS+"!E<G)O<G,@86YD"B`@("`@*B!F
M86EL=7)E<RX@5&AE<F4@:7,@86QS;R!O;F4@;&%B96P@9F]R(&5A8V@@;V8@
M=&AE<V4@=&AA=`H@("`@("H@9&5S8W)I8F5S('=H870@=&AE(&QA8F5L(&ES
M+B!)="!C;W5L9"!B92!D;VYE('=I=&@@;VYE(&QA8F5L"B`@("`@*B!I;G-T
M96%D(&]F('1W;R!B=70@=&AA="!W;W5L9"!M86ME('5P9&%T97,@;75C:"!H
M87)D97(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`
M<&%R86T@(&YO;F4*("`@("`J($!R971U<FX@)F]B:F5C="!!(&)O>"!C;VYT
M86EN:6YG('1H92!L86)E;',N"B`@("`@*B\*("`@(&9U;F-T:6]N("9?8W)E
M871E4F5P;W)T3&%B96QS*"D*("`@('L*("`@("`@("`O+R!#<F5A=&4@82!B
M;W@@=&\@:&]L9"!E=F5R>71H:6YG+@H@("`@("`@("1L86)E;$)O>"`@("`@
M("`@(#TF(&YE=R!'=&M(0F]X.PH*("`@("`@("`O+R!#<F5A=&4@=&AE(&YO
M;BUU<&1A=&5D(&QA8F5L<RX*("`@("`@("`D;G5M8F5R3V92=6YS("`@("`]
M)B!N97<@1W1K3&%B96PH)U)U;G,Z)RD["B`@("`@("`@)&YU;6)E<D]F17)R
M;W)S("`@/28@;F5W($=T:TQA8F5L*"=%<G)O<G,Z)RD["B`@("`@("`@)&YU
M;6)E<D]F1F%I;'5R97,@/28@;F5W($=T:TQA8F5L*"=&86EL=7)E<SHG*3L*
M"B`@("`@("`@+R\@0W)E871E('1H92!L86)E;',@=&AA="!W:6QL(&)E('5P
M9&%T960N"B`@("`@("`@+R\@5&AE<V4@87)E(&%S<W-I9VYE9"!T;R!M96UB
M97)S('1O(&UA:V4@:70@96%S:65R('1O"B`@("`@("`@+R\@<V5T('1H96ER
M('9A;'5E<R!L871E<BX*("`@("`@("`D=&AI<RT^;G5M8F5R3V92=6YS("`@
M("`])B!N97<@1W1K3&%B96PH,"D["B`@("`@("`@)'1H:7,M/FYU;6)E<D]F
M17)R;W)S("`@/28@;F5W($=T:TQA8F5L*#`I.PH@("`@("`@("1T:&ES+3YN
M=6UB97)/9D9A:6QU<F5S(#TF(&YE=R!'=&M,86)E;"@P*3L*"B`@("`@("`@
M+R\@4&%C:R!E=F5R>71H:6YG(&EN+@H@("`@("`@("1L86)E;$)O>"T^<&%C
M:U]S=&%R="@D;G5M8F5R3V92=6YS*3L*("`@("`@("`D;&%B96Q";W@M/G!A
M8VM?<W1A<G0H)'1H:7,M/FYU;6)E<D]F4G5N<RD["B`@("`@("`@)&QA8F5L
M0F]X+3YP86-K7W-T87)T*"1N=6UB97)/9D5R<F]R<RD["B`@("`@("`@)&QA
M8F5L0F]X+3YP86-K7W-T87)T*"1T:&ES+3YN=6UB97)/9D5R<F]R<RD["B`@
M("`@("`@)&QA8F5L0F]X+3YP86-K7W-T87)T*"1N=6UB97)/9D9A:6QU<F5S
M*3L*("`@("`@("`D;&%B96Q";W@M/G!A8VM?<W1A<G0H)'1H:7,M/FYU;6)E
M<D]F1F%I;'5R97,I.PH*("`@("`@("!R971U<FX@)&QA8F5L0F]X.PH@("`@
M?0H*("`@("\J*@H@("`@("H@0W)E871E('1H92!S=6-C97-S+V9A:6QU<F4@
M:6YD:6-A=&]R+@H@("`@("H*("`@("`J($$@1W1K4')O9W)E<W-"87(@:7,@
M=7-E9"!T;R!V:7-U86QL>2!I;F1I8V%T92!H;W<@;6%N>0H@("`@("H@=&5S
M=',@=V5R92!S=6-C97-S9G5L(&-O;7!A<F5D('1O(&AO=R!M86YY('=E<F4@
M;F]T+B!4:&4*("`@("`J('!R;V=R97-S(&)A<B!S:&]W<R!T:&4@<&5R8V5N
M=&%G92!O9B!S=6-C97-S(&%N9"!W:6QL"B`@("`@*B!C:&%N9V4@9G)O;2!G
M<F5E;B!T;R!R960@:68@=&AE<F4@87)E(&%N>2!F86EL=7)E<RX*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2`@;F]N90H@
M("`@("H@0')E='5R;B`F;V)J96-T(%1H92!P<F]G<F5S<R!B87(*("`@("`J
M+PH@("`@9G5N8W1I;VX@)E]C<F5A=&50<F]G<F5S<T)A<B@I"B`@("!["B`@
M("`@("`@+R\@0W)E871E('1H92!P<F]G<F5S<R!B87(N"B`@("`@("`@)'1H
M:7,M/G!R;V=R97-S(#TF(&YE=R!'=&M0<F]G<F5S<T)A<BAN97<@1W1K061J
M=7-T;65N="@P+"`P+"`Q+"`N,2P@,2P@,"DI.PH*("`@("`@("`O+R!3970@
M=&AE('!R;V=R97-S(&)A<B!T;R!P<FEN="!T:&4@<&5R8V5N=&%G92X*("`@
M("`@("`D=&AI<RT^<')O9W)E<W,M/G-E=%]S:&]W7W1E>'0H=')U92D["@H@
M("`@("`@(')E='5R;B`D=&AI<RT^<')O9W)E<W,["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#<F5A=&4@=&AE(')E<&]R="!T97AT(&%R96%S+@H@("`@("H*
M("`@("`J(%1H92!R97!O<G0@87)E82!C;VYS:7-T<R!O9B!O;F4@=&5X="!A
M<F5A(&9O<B!F86EL=7)E<RP@;VYE"B`@("`@*B!T97AT(&%R96$@9F]R(&5R
M<F]R<R!A;F0@;VYE(&QA8F5L(&9O<B!I9&5N=&EF:6-A=&EO;B!P=7)P;W-E
M<RX*("`@("`J($%L;"!T:')E92!W:61G971S(&%R92!P86-K960@:6YT;R!A
M(&)O>"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P
M87)A;2`@;F]N90H@("`@("H@0')E='5R;B`F;V)J96-T(%1H92!B;W@@8V]N
M=&%I;FEN9R!T:&4@<F5P;W)T(&%R96%S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B`F7V-R96%T95)E<&]R=$%R96%S*"D*("`@('L*("`@("`@("`O+R!#<F5A
M=&4@=&AE(&-O;G1A:6YI;F<@8F]X+@H@("`@("`@("1R97!O<G1";W@@/28@
M;F5W($=T:U9";W@["@H@("`@("`@("\O($-R96%T92!T:&4@:61E;G1I9FEC
M871I;VX@;&%B96P*("`@("`@("`D<F5P;W)T3&%B96P@/28@;F5W($=T:TQA
M8F5L*"=%<G)O<G,@86YD($9A:6QU<F5S.B<I.PH@("`@("`@("1R97!O<G1,
M86)E;"T^<V5T7V%L:6=N;65N="@P+"`P*3L*"B`@("`@("`@+R\@0W)E871E
M('1H92!S8W)O;&QE9"!W:6YD;W=S(&9O<B!T:&4@=&5X="!A<F5A<RX*("`@
M("`@("`D<F5P;W)T4V-R;VQL(#TF(&YE=R!'=&M38W)O;&QE9%=I;F1O=SL*
M("`@("`@("`D9'5M<%-C<F]L;"`@(#TF(&YE=R!'=&M38W)O;&QE9%=I;F1O
M=SL*"B`@("`@("`@+R\@36%K92!T:&4@<V-R;VQL(&%R96%S(&)I9R!E;F]U
M9V@N"B`@("`@("`@)')E<&]R=%-C<F]L;"T^<V5T7W5S:7IE*"TQ+"`Q-3`I
M.PH@("`@("`@("1D=6UP4V-R;VQL+3YS971?=7-I>F4H+3$L(#$U,"D["@H@
M("`@("`@("\O($]N;'D@<VAO=R!T:&4@=F5R=&EC86P@<V-R;VQL(&)A<B!W
M:&5N(&YE961E9"X*("`@("`@("`O+R!.979E<B!S:&]W('1H92!H;W)I>F]N
M=&%L('-C<F]L;"!B87(N"B`@("`@("`@)')E<&]R=%-C<F]L;"T^<V5T7W!O
M;&EC>2A'5$M?4$],24-97TY%5D52+"!'5$M?4$],24-97T%55$]-051)0RD[
M"B`@("`@("`@)&1U;7!38W)O;&PM/G-E=%]P;VQI8WDH1U1+7U!/3$E#65].
M159%4BP@1U1+7U!/3$E#65]!551/34%424,I.PH*("`@("`@("`O+R!#<F5A
M=&4@=&AE('1E>'0@87)E87,N"B`@("`@("`@)'1H:7,M/G)E<&]R=$%R96$@
M/28@;F5W($=T:U1E>'0["B`@("`@("`@)'1H:7,M/F1U;7!!<F5A(#TF(&YE
M=R!'=&M497AT.PH*("`@("`@("`O+R!$;VXG="!L970@=V]R9',@9V5T(&)R
M;VME;BX*("`@("`@("`D=&AI<RT^<F5P;W)T07)E82T^<V5T7W=O<F1?=W)A
M<"AT<G5E*3L*("`@("`@("`D=&AI<RT^9'5M<$%R96$M/G-E=%]W;W)D7W=R
M87`H=')U92D["@H@("`@("`@("\O(%!A8VL@979E<GET:&EN9R!I;BX*("`@
M("`@("`D<F5P;W)T0F]X+3YP86-K7W-T87)T*"1R97!O<G1,86)E;"D["B`@
M("`@("`@)')E<&]R=%-C<F]L;"T^861D*"1T:&ES+3YR97!O<G1!<F5A*3L*
M("`@("`@("`D<F5P;W)T0F]X+3YP86-K7W-T87)T*"1R97!O<G138W)O;&PI
M.PH@("`@("`@("1D=6UP4V-R;VQL+3YA9&0H)'1H:7,M/F1U;7!!<F5A*3L*
M("`@("`@("`D<F5P;W)T0F]X+3YP86-K7W-T87)T*"1D=6UP4V-R;VQL*3L*
M"B`@("`@("`@<F5T=7)N("1R97!O<G1";W@["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#<F5A=&4@82!S=&%T=7,@;&%B96PN"B`@("`@*@H@("`@("H@02!S
M=&%T=7,@;&EN92!A="!T:&4@8F]T=&]M(&]F('1H92!A<'!L:6-A=&EO;B!I
M<R!U<V5D"B`@("`@*B!T;R!N;W1I9GD@=&AE('5S97(@;V8@;F]N+71E<W0@
M<F5L871E9"!M97-S86=E<R!S=6-H(&%S"B`@("`@*B!F86EL=7)E<R!L;V%D
M:6YG(&$@=&5S="!S=6ET92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J($!P87)A;2`@;F]N90H@("`@("H@0')E='5R;B`F;V)J96-T
M(%1H92!S=&%T=7,@;&%B96PN"B`@("`@*B\*("`@(&9U;F-T:6]N("9?8W)E
M871E4W1A='5S3&EN92@I"B`@("!["B`@("`@("`@+R\@0W)E871E('1H92!S
M=&%T=7,@;&%B96PN"B`@("`@("`@)'1H:7,M/G-T871U<TQI;F4@/28@;F5W
M($=T:TQA8F5L*"<G*3L*("`@("`@("`D=&AI<RT^<W1A='5S3&EN92T^<V5T
M7V%L:6=N;65N="@P+"`P*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3YS=&%T
M=7-,:6YE.PH@("`@?0H*("`@("\J*@H@("`@("H@4VAO=R!A('!O<'5P('=I
M=&@@:6YF;W)M871I;VX@86)O=70@=&AE(&%P<&QI8V%T:6]N+@H@("`@("H*
M("`@("`J(%1H92!P;W!U<"!S:&]U;&0@<VAO=R!I;F9O<FUA=&EO;B!A8F]U
M="!T:&4@=F5R<VEO;BP*("`@("`J('1H92!A=71H;W(L('1H92!L:6-E;G-E
M+"!W:&5R92!T;R!G970@=&AE(&QA=&5S=`H@("`@("H@=F5R<VEO;B!A;F0@
M82!S:&]R="!D97-C<FEP=&EO;BX*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H@0'!A<F%M("!N;VYE"B`@("`@*B!`<F5T=7)N('9O:60*
M("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("\O
M($-R96%T92!T:&4@;F5W('=I;F1O=RX*("`@("`@("`D86)O=70@/28@;F5W
M($=T:U=I;F1O=SL*("`@("`@("`D86)O=70M/G-E=%]T:71L92@G06)O=70@
M4$A056YI="!'54D@1W1K)RD["B`@("`@("`@)&%B;W5T+3YS971?=7-I>F4H
M,C4P+"`M,2D["@H@("`@("`@("\O(%!U="!T=V\@=F)O>&5S(&EN('1H92!H
M8F]X+@H@("`@("`@("1V0F]X(#TF(&YE=R!'=&M60F]X.PH@("`@("`@("1A
M8F]U="T^861D*"1V0F]X*3L*"B`@("`@("`@+R\@0W)E871E('1H92!L86)E
M;',N"B`@("`@("`@)'9E<G-I;VX@("`@(#TF(&YE=R!'=&M,86)E;"@B(%9E
M<G-I;VXZ(#$N,"(I.PH@("`@("`@("1L:6-E;G-E("`@("`])B!N97<@1W1K
M3&%B96PH(B!,:6-E;G-E.B!02%`@3&EC96YS92!V,RXP(BD["B`@("`@("`@
M)'=H97)E("`@("`@(#TF(&YE=R!'=&M,86)E;"@B($1O=VYL;V%D(&9R;VTZ
M(&AT='`Z+R]P96%R+G!H<"YN970O4$A056YI="\B*3L*("`@("`@("`D=6YI
M=$%U=&@@("`@/28@;F5W($=T:TQA8F5L*"(@4$A056YI="!!=71H;W(Z(%-E
M8F%S=&EA;B!"97)G;6%N(BD["B`@("`@("`@)&=T:T%U=&@@("`@(#TF(&YE
M=R!'=&M,86)E;"@B($=T:R!'54D@075T:&]R.B!38V]T="!-871T;V-K<R(I
M.PH*("`@("`@("`O+R!!;&EG;B!E=F5R>71H:6YG('1O('1H92!L969T"B`@
M("`@("`@)'=H97)E+3YS971?86QI9VYM96YT*#`L("XU*3L*("`@("`@("`D
M=F5R<VEO;BT^<V5T7V%L:6=N;65N="@P+"`N-2D["B`@("`@("`@)&QI8V5N
M<V4M/G-E=%]A;&EG;FUE;G0H,"P@+C4I.PH@("`@("`@("1G=&M!=71H+3YS
M971?86QI9VYM96YT*#`L("XU*3L*("`@("`@("`D=6YI=$%U=&@M/G-E=%]A
M;&EG;FUE;G0H,"P@+C4I.PH*("`@("`@("`O+R!086-K(&5V97)Y=&AI;F<@
M:6YT;R!T:&4@=D)O>#L*("`@("`@("`D=D)O>"T^<&%C:U]S=&%R="@D=F5R
M<VEO;BD["B`@("`@("`@)'9";W@M/G!A8VM?<W1A<G0H)&QI8V5N<V4I.PH@
M("`@("`@("1V0F]X+3YP86-K7W-T87)T*"1W:&5R92D["B`@("`@("`@)'9"
M;W@M/G!A8VM?<W1A<G0H)'5N:71!=71H*3L*("`@("`@("`D=D)O>"T^<&%C
M:U]S=&%R="@D9W1K075T:"D["@H@("`@("`@("\O($-O;FYE8W0@=&AE(&1E
M<W1R;WD@<VEG;F%L+@H@("`@("`@("1A8F]U="T^8V]N;F5C="@G9&5S=')O
M>2<L(&%R<F%Y*"=G=&LG+"`G=')U92<I*3L*"B`@("`@("`@+R\@4VAO=R!T
M:&4@9V]O9',N"B`@("`@("`@)&%B;W5T+3YS:&]W7V%L;"@I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@3&]A9"!T:&4@=&5S="!S=6ET92X*("`@("`J"B`@
M("`@*B!4:&ES(&UE=&AO9"!T<FEE<R!T;R!L;V%D('1E<W0@<W5I=&4@8F%S
M960@;VX@=&AE('5S97(*("`@("`J(&EN9F\N($EF('1H92!U<V5R('!A<W-E
M<R!T:&4@;F%M92!O9B!A('1E<W1S('-U:71E+"!I=`H@("`@("H@:7,@:6YS
M=&%N=&EA=&5D(&%N9"!A(&YE=R!O8FIE8W0@:7,@<F5T=7)N960N($EF('1H
M90H@("`@("H@=7-E<B!P87-S97,@82!F:6QE('1H870@8V]N=&%I;G,@82!T
M97-T('-U:71E+"!T:&4@8VQA<W,*("`@("`J(&ES(&EN<W1A;G1I871E9"!A
M;F0@82!N97<@;V)J96-T(&ES(')E='5R;F5D+B!)9B!T:&4@=7-E<@H@("`@
M("H@<&%S<V5S(&$@9FEL92!T:&%T(&-O;G1A:6YS(&$@=&5S="!C87-E+"!T
M:&4@=&5S="!C87-E(&ES"B`@("`@*B!P87-S960@=&\@82!N97<@=&5S="!S
M=6ET92!A;F0@=&AE(&YE=R!S=6ET92!O8FIE8W0@:7,*("`@("`J(')E='5R
M;F5D+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R
M86T@('-T<FEN9R`@5&AE(&9I;&4@=&AA="!C;VYT86EN<R!A('1E<W0@8V%S
M92]S=6ET92!O<B!T:&4@8VQA<W-N86UE+@H@("`@("H@0')E='5R;B`F;V)J
M96-T(%1H92!N97<@=&5S="!S=6ET92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M)FQO861497-T*"8D9FEL92D*("`@('L*("`@("`@("`O+R!#:&5C:R!T;R!S
M964@:68@82!C;&%S<R!N86UE('=A<R!G:79E;BX*("`@("`@("!I9B`H:7-?
M82@D9FEL92P@)U!(4%5N:71?5&5S=%-U:71E)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1F:6QE.PH@("`@("`@('T@96QS96EF("AC;&%S<U]E>&ES=',H
M)&9I;&4I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$A056YI="]4
M97-T4W5I=&4N<&AP)SL*("`@("`@("`@("`@<F5T=7)N(&YE=R!02%!5;FET
M7U1E<W13=6ET92@D9FEL92D["B`@("`@("`@?0H*("`@("`@("`O+R!#:&5C
M:R!T:&%T('1H92!F:6QE(&5X:7-T<RX*("`@("`@("!I9B`H(4!I<U]R96%D
M86)L92@D9FEL92DI('L*("`@("`@("`@("`@)'1H:7,M/E]S:&]W4W1A='5S
M*"=#86YN;W0@9FEN9"!F:6QE.B`G("X@)&9I;&4I.PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W-H;W=3
M=&%T=7,H)TQO861I;F<@=&5S="!S=6ET92XN+B<I.PH*("`@("`@("`O+R!)
M;G-T86YT:6%T92!T:&4@8VQA<W,N"B`@("`@("`@+R\@268@=&AE('!A=&@@
M:7,@+W!A=&@O=&\O=&5S="]497-T0VQA<W,N<&AP"B`@("`@("`@+R\@=&AE
M(&-L87-S(&YA;64@<VAO=6QD(&)E('1E<W1?5&5S=$-L87-S"B`@("`@("`@
M<F5Q=6ER95]O;F-E("1F:6QE.PH@("`@("`@("1C;&%S<TYA;64@/2!S=')?
M<F5P;&%C92A$25)%0U1/4EE?4T5005)!5$]2+"`G7R<L("1F:6QE*3L*("`@
M("`@("`D8VQA<W-.86UE(#T@<W5B<W1R*"1C;&%S<TYA;64L(#`L('-T<G!O
M<R@D8VQA<W-.86UE+"`G+B<I*3L*"B`@("`@("`@<F5Q=6ER95]O;F-E("=0
M2%!5;FET+U1E<W13=6ET92YP:'`G.PH@("`@("`@(')E='5R;B!N97<@4$A0
M56YI=%]497-T4W5I=&4H)&-L87-S3F%M92D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2=6X@=&AE('1E<W0@<W5I=&4N"B`@("`@*@H@("`@("H@5&AI<R!M
M971H;V0@<G5N<R!T:&4@=&5S="!S=6ET92!A;F0@=7!D871E<R!T:&4@;65S
M<V%G97,*("`@("`J(&9O<B!T:&4@=7-E<BX@5VAE;B!F:6YI<VAE9"!I="!C
M:&%N9V5S('1H92!S=&%T=7,@;&EN90H@("`@("H@=&\@)U1E<W0@0V]M<&QE
M=&4G"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A
M;2`@;F]N90H@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')U;E1E<W0H*0H@("`@>PH@("`@("`@("\O($YO=&EF>2!T:&4@=7-E
M<B!T:&%T('1H92!T97-T(&ES(')U;FYI;F<N"B`@("`@("`@)'1H:7,M/E]S
M:&]W4W1A='5S*"=2=6YN:6YG(%1E<W0N+BXG*3L*"B`@("`@("`@+R\@4G5N
M('1H92!T97-T+@H@("`@("`@("1R97-U;'0@/2!02%!5;FET.CIR=6XH)'1H
M:7,M/G-U:71E*3L*"B`@("`@("`@+R\@57!D871E('1H92!L86)E;',N"B`@
M("`@("`@)'1H:7,M/E]S971,86)E;%9A;'5E*"1T:&ES+3YN=6UB97)/9E)U
M;G,L("`@("`D<F5S=6QT+3YR=6Y#;W5N="@I*3L*("`@("`@("`D=&AI<RT^
M7W-E=$QA8F5L5F%L=64H)'1H:7,M/FYU;6)E<D]F17)R;W)S+"`@("1R97-U
M;'0M/F5R<F]R0V]U;G0H*2D["B`@("`@("`@)'1H:7,M/E]S971,86)E;%9A
M;'5E*"1T:&ES+3YN=6UB97)/9D9A:6QU<F5S+"`D<F5S=6QT+3YF86EL=7)E
M0V]U;G0H*2D["@H@("`@("`@("\O(%5P9&%T92!T:&4@<')O9W)E<W,@8F%R
M+@H@("`@("`@("1T:&ES+3Y?=7!D871E4')O9W)E<W,H)')E<W5L="T^<G5N
M0V]U;G0H*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97-U
M;'0M/F5R<F]R0V]U;G0H*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1R97-U;'0M/F9A:6QU<F5#;W5N="@I"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`I.PH*("`@("`@("`O+R!3:&]W('1H92!E<G)O<G,N
M"B`@("`@("`@)'1H:7,M/E]S:&]W1F%I;'5R97,H)')E<W5L="T^97)R;W)S
M*"DL("1T:&ES+3YD=6UP07)E82D["@H@("`@("`@("\O(%-H;W<@=&AE(&UE
M<W-A9V5S(&9R;VT@=&AE('1E<W1S+@H@("`@("`@(&EF("@D=&AI<RT^<VAO
M=U!A<W-E9"T^9V5T7V%C=&EV92@I*2!["B`@("`@("`@("`@("\O(%-H;W<@
M9F%I;'5R97,@86YD('-U8V-E<W,N"B`@("`@("`@("`@("1T:&ES+3Y?<VAO
M=T%L;"@D<F5S=6QT+"`D=&AI<RT^<F5P;W)T07)E82D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@+R\@4VAO=R!O;FQY(&9A:6QU<F5S+@H@("`@
M("`@("`@("`D=&AI<RT^7W-H;W=&86EL=7)E<R@D<F5S=6QT+3YF86EL=7)E
M<R@I+"`D=&AI<RT^<F5P;W)T07)E82D["B`@("`@("`@?0H*("`@("`@("`O
M+R!5<&1A=&4@=&AE('-T871U<R!M97-S86=E+@H@("`@("`@("1T:&ES+3Y?
M<VAO=U-T871U<R@G5&5S="!C;VUP;&5T92<I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4V5T('1H92!T97AT(&]F(&$@;&%B96PN"B`@("`@*@H@("`@("H@
M0VAA;F=E('1H92!T97AT(&]F(&$@9VEV96X@;&%B96PN"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@('=I9&=E="`@)B1L
M86)E;"!4:&4@;&%B96P@=VAO<V4@=F%L=64@:7,@=&\@8F4@8VAA;F=E9"X*
M("`@("`J($!P87)A;2`@<W1R:6YG("`D=F%L=64@(%1H92!N97<@=&5X="!O
M9B!T:&4@;&%B96PN"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W-E=$QA8F5L5F%L=64H)B1L86)E;"P@)'9A;'5E*0H@("`@
M>PH@("`@("`@("1L86)E;"T^<V5T7W1E>'0H)'9A;'5E*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%1H92!M86EN('=O<FL@;V8@=&AE(&%P<&QI8V%T:6]N
M+@H@("`@("H*("`@("`J($QO860@=&AE('1E<W0@<W5I=&4@86YD('1H96X@
M97AE8W5T92!T:&4@=&5S=',N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J($!P87)A;2`@;F]N90H@("`@("H@0')E='5R;B!V;VED"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')U;B@I"B`@("!["B`@("`@("`@+R\@3&]A
M9"!T:&4@=&5S="!S=6ET92X*("`@("`@("`D=&AI<RT^<W5I=&4@/28@)'1H
M:7,M/FQO861497-T*"1T:&ES+3YS=6ET949I96QD+3YG971?=&5X="@I*3L*
M"B`@("`@("`@+R\@0VAE8VL@=&\@;6%K92!S=7)E('1H92!S=6ET92!W87,@
M;&]A9&5D('!R;W!E<FQY+@H@("`@("`@(&EF("@A:7-?;V)J96-T*"1T:&ES
M+3YS=6ET92DI('L*("`@("`@("`@("`@+R\@4F%I<V4@86X@97)R;W(N"B`@
M("`@("`@("`@("1T:&ES+3Y?<VAO=U-T871U<R@G0V]U;&0@;F]T(&QO860@
M=&5S="!S=6ET92XG*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@+R\@4G5N('1H92!T97-T<RX*("`@("`@("`D=&AI
M<RT^<G5N5&5S="@I.PH@("`@?0H*("`@("\J*@H@("`@("H@57!D871E('1H
M92!S=&%T=7,@;65S<V%G92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J($!P87)A;2`@<W1R:6YG("`D<W1A='5S(%1H92!N97<@;65S
M<V%G92X*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO
M;B!?<VAO=U-T871U<R@D<W1A='5S*0H@("`@>PH@("`@("`@("1T:&ES+3YS
M=&%T=7-,:6YE+3YS971?=&5X="@D<W1A='5S*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($%L:6%S(&9O<B!M86EN*"D*("`@("`J"B`@("`@*B!`<V5E(&UA
M:6X*("`@("`J+PH@("`@9G5N8W1I;VX@<VAO=R@D<VAO=U!A<W-E9"`]('1R
M=64I"B`@("!["B`@("`@("`@)'1H:7,M/FUA:6XH)'-H;W=087-S960I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@061D(&$@<W5I=&4@=&\@=&AE('1E<W1S
M+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(')E<75I<F4@8GD@4V5T
M=7!$96-O<F%T;W(N($ET(&%D9',@80H@("`@("H@<W5I=&4@=&\@=&AE('1H
M92!C=7)R96YT('-E="!O9B!S=6ET97,N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J($!P87)A;2`@;V)J96-T("1T97-T4W5I=&4@5&AE
M('-U:71E('1O(&%D9"X*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@
M("!F=6YC=&EO;B!A9&13=6ET97,H)'1E<W13=6ET92D*("`@('L*("`@("`@
M("!I9B`H(6ES7V%R<F%Y*"1T97-T4W5I=&4I*2!["B`@("`@("`@("`@('-E
M='1Y<&4H)'1E<W13=6ET92P@)V%R<F%Y)RD["B`@("`@("`@?0H*("`@("`@
M("!F;W)E86-H("@D=&5S=%-U:71E(&%S("1S=6ET92D@>PH*("`@("`@("`@
M("`@:68@*&ES7V$H)'1H:7,M/G-U:71E+"`G4$A056YI=%]497-T4W5I=&4G
M*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-U:71E+3YA9&1497-T4W5I
M=&4H)'-U:71E+3YG971.86UE*"DI.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/G-U:71E(#TF("1T:&ES+3YL;V%D5&5S
M="@D<W5I=&4I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!3970@
M=&AE('-U:71E(&9I96QD+@H@("`@("`@("`@("`D=&5X="`]("1T:&ES+3YS
M=6ET949I96QD+3YG971?=&5X="@I.PH@("`@("`@("`@("!I9B`H96UP='DH
M)'1E>'0I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<W5I=&5&:65L9"T^
M<V5T7W1E>'0H)'1H:7,M/G-U:71E+3YG971.86UE*"DI.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4VAO=R!A;&P@
M=&5S="!M97-S86=E<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J($!P87)A;2`@;V)J96-T("!4:&4@5&5S=%)E<W5L="!F<F]M('1H
M92!T97-T('-U:71E+@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]S:&]W06QL*"8D<F5S=6QT*0H@("`@>PH@("`@("`@("\O
M($-L96%R('1H92!A<F5A(&9I<G-T+@H@("`@("`@("1T:&ES+3YR97!O<G1!
M<F5A+3YD96QE=&5?=&5X="@P+"`M,2D["B`@("`@("`@)'1H:7,M/G)E<&]R
M=$%R96$M/FEN<V5R=%]T97AT*"1R97-U;'0M/G1O4W1R:6YG*"DL(#`I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4VAO=R!F86EL=7)E+V5R<F]R(&UE<W-A
M9V5S(&EN('1H92!G:79E;B!T97AT(&%R96$N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@(&]B:F5C="`@)B1R97-U;'1S
M(%1H92!R97-U;'1S(&]F('1H92!T97-T+@H@("`@("H@0'!A<F%M("!W:61G
M970@("8D87)E82`@("!4:&4@87)E82!T;R!S:&]W('1H92!R97-U;'1S(&EN
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<VAO=T9A:6QU<F5S*"8D<F5S=6QT
M<RP@)B1A<F5A*0H@("`@>PH@("`@("`@("1A<F5A+3YD96QE=&5?=&5X="@P
M+"`M,2D["B`@("`@("`@9F]R96%C:"`H87)R87E?<F5V97)S92@D<F5S=6QT
M<RP@=')U92D@87,@)')E<W5L="D@>PH@("`@("`@("`@("`D87)E82T^:6YS
M97)T7W1E>'0H)')E<W5L="T^=&]3=')I;F<H*2P@,"D["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@57!D871E('1H92!P<F]G<F5S<R!I;F1I
M8V%T;W(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`
M<&%R86T@(&EN=&5G97(@)')U;G,*("`@("`J($!P87)A;2`@:6YT96=E<B`D
M97)R;W)S"B`@("`@*B!`<&%R86T@(&EN=&5G97(@)&9A:6QU<F5S"B`@("`@
M*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@7W5P9&%T95!R
M;V=R97-S*"1R=6YS+"`D97)R;W)S+"`D9F%I;'5R97,I"B`@("!["B`@("`@
M("`@)'!E<F-E;G1A9V4@/2`Q("T@*"@D97)R;W)S("L@)&9A:6QU<F5S*2`O
M("1R=6YS*3L*("`@("`@("`D=&AI<RT^<')O9W)E<W,M/G-E=%]P97)C96YT
M86=E*"1P97)C96YT86=E*3L*("`@('T*?0H*+RH*("H@3&]C86P@=F%R:6%B
M;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z(#0*("H@
M8RUH86YG:6YG+6-O;6UE;G0M96YD97(M<#H@;FEL"B`J($5N9#H*("HO"C\^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]02%!5;FET+T=522](5$U,+G!H<```````````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,3(Q-P`Q,#4Q-30S,S<S-P`P,C(P
M,#(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I
M9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!02%`@5F5R<VEO;B`T
M"B`J"B`J($-O<'ER:6=H="`H8RD@,C`P,BTR,#`U+"!396)A<W1I86X@0F5R
M9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93XN"B`J($%L;"!R:6=H
M=',@<F5S97)V960N"B`J"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@
M<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M
M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@
M9F]L;&]W:6YG(&-O;F1I=&EO;G,*("H@87)E(&UE=#H*("H*("H@("`J(%)E
M9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@
M86)O=F4@8V]P>7)I9VAT"B`J("`@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C
M;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J(`H@
M*B`@("H@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P
M<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@=&AI
M<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA
M:6UE<B!I;@H@*B`@("`@=&AE(&1O8W5M96YT871I;VX@86YD+V]R(&]T:&5R
M(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H90H@*B`@("`@9&ES=')I8G5T
M:6]N+@H@*@H@*B`@("H@3F5I=&AE<B!T:&4@;F%M92!O9B!396)A<W1I86X@
M0F5R9VUA;FX@;F]R('1H92!N86UE<R!O9B!H:7,*("H@("`@(&-O;G1R:6)U
M=&]R<R!M87D@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C
M=',@9&5R:79E9`H@*B`@("`@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@
M<W!E8VEF:6,@<')I;W(@=W)I='1E;B!P97)M:7-S:6]N+@H@*@H@*B!42$E3
M(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$52
M4R!!3D0@0T].5%))0E543U)3"B`J(")!4R!)4R(@04Y$($%.62!%6%!215-3
M($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4"B`J
M($Q)34E4140@5$\L(%1(12!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!
M3E1!0DE,2519($%.1"!&251.15-3"B`J($9/4B!!(%!!4E1)0U5,05(@4%52
M4$]312!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%"B`J
M($-/4%E224=(5"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%($9/
M4B!!3ED@1$E214-4+"!)3D1)4D5#5"P*("H@24Y#241%3E1!3"P@4U!%0TE!
M3"P@15A%35!,05)9+"!/4B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ5
M1$E.1RP*("H@0E54($Y/5"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!3
M54)35$E4551%($=/3T13($]2(%-%4E9)0T53.PH@*B!,3U-3($]&(%5312P@
M1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)255!424].*2!(
M3U=%5D52"B`J($-!55-%1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"24Q)
M5%DL(%=(151(15(@24X@0T].5%)!0U0L(%-44DE#"B`J($Q)04))3$E462P@
M3U(@5$]25"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!
M4DE324Y'($E."B`J($%.62!705D@3U54($]&(%1(12!54T4@3T8@5$A)4R!3
M3T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(10H@*B!03U-324))3$E4
M62!/1B!354-(($1!34%'12X*("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@
M*B!`<&%C:V%G92`@("!02%!5;FET"B`J($!A=71H;W(@("`@(%=O;&9R86T@
M2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^"B`J($!C;W!Y<FEG:'0@
M(#(P,#(M,C`P-2!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB
M97)G;6%N;BYD93X*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U
M<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E
M"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!(5$U,+G!H<"QV(#$N,3D@,C`P
M-2\Q,2\Q,"`P.3HT-SHQ-2!S96)A<W1I86X@17AP("0*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!(4%5N:70*("H@0'-I
M;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C`N,`H@
M*B\*"B\J*@H@*B!(5$U,($=522X*("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN
M9PH@*B!`<&%C:V%G92`@("!02%!5;FET"B`J($!A=71H;W(@("`@(%=O;&9R
M86T@2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^"B`J($!C;W!Y<FEG
M:'0@(#(P,#(M,C`P-2!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA
M;BUB97)G;6%N;BYD93X*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N
M<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E
M;G-E"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N,RXR"B`J($!L:6YK("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]02%!5;FET"B`J($!S
M:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N,"XP
M"B`J+PIC;&%S<R!02%!5;FET7T=525](5$U,"GL*("`@('9A<B`D7W-U:71E
M<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`J('1H92!C=7)R96YT(&EM<&QE
M;65N=&%T:6]N(&]F(%!(4%5N:70@:7,@9&5S:6=N960*("`@("H@=&AI<R!W
M87D@=&AA="!A9&1I;F<@82!S=6ET92!T;R!A;F]T:&5R('-U:71E(&]N;'D*
M("`@("H@9W)A8G,@86QL('1H92!T97-T<R!A;F0@861D<R!T:&5M('1O('1H
M92!S=6ET92P@<V\@>6]U"B`@("`J(&AA=F4@;F\@8VAA;F-E('1O(&9I;F0@
M;W5T('=H:6-H('1E<W0@9V]E<R!W:71H('=H:6-H('-U:71E"B`@("`J('1H
M97)E9F]R92!Y;W4@8V%N('-I;7!L>2!P87-S(&%N(&%R<F%Y(&]F('-U:71E
M<R!T;R!T:&ES(&-O;G-T<G5C=&]R(&AE<F4*("`@("H*("`@("H@0'!A<F%M
M("!A<G)A>2`@(%1H92!S=6ET97,@=&\@8F4@=&5S=&5D+B!)9B!N;W0@9VEV
M96XL('1H96X@>6]U(&UI9VAT"B`@("`J("`@("`@("`@("`@("`@("!B92!U
M<VEN9R!T:&4@4V5T=7!$96-O<F%T;W(L('=H:6-H(&1E=&5C=',@=&AE;2!A
M=71O;6%T:6-A;&QY"B`@("`J("`@("`@("`@("`@("`@("!W:&5N(&-A;&QI
M;F<@9V5T4W5I=&5S1G)O;41I<B@I"B`@("`J+PH@("`@9G5N8W1I;VX@4$A0
M56YI=%]'54E?2%1-3"@D<W5I=&5S(#T@87)R87DH*2D*("`@('L*("`@("`@
M("!I9B`H(6ES7V%R<F%Y*"1S=6ET97,I*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?<W5I=&5S(#T@87)R87DH)'-U:71E<RD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'1H:7,M/E]S=6ET97,@/2`D<W5I=&5S.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("H@061D('-U:71E<R!T;R!T:&4@1U5)
M"B`@("`J"B`@("`J($!P87)A;2`@;V)J96-T("!T:&ES('-H;W5L9"!B92!A
M;B!I;G-T86YC92!O9B!02%!5;FET7U1E<W13=6ET90H@("`@*B\*("`@(&9U
M;F-T:6]N(&%D9%-U:71E<R@D<W5I=&5S*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?<W5I=&5S(#T@87)R87E?;65R9V4H)'1H:7,M/E]S=6ET97,L)'-U:71E
M<RD["B`@("!]"@H@("`@+RHJ"B`@("`J('1H:7,@<')I;G1S('1H92!(5$U,
M(&-O9&4@<W1R86EG:'0@;W5T"B`@("`J"B`@("`J+PH@("`@9G5N8W1I;VX@
M<VAO=R@I"B`@("!["B`@("`@("`@)')E<75E<W0@("`@/2`D7U)%455%4U0[
M"B`@("`@("`@)'-H;W=087-S960@/2!&04Q313L*("`@("`@("`D<W5B;6ET
M=&5D("`]($`D<F5Q=65S=%LG<W5B;6ET=&5D)UT["@H@("`@("`@(&EF("@D
M<W5B;6ET=&5D*2!["B`@("`@("`@("`@("1S:&]W4&%S<V5D(#T@0"1R97%U
M97-T6R=S:&]W3TLG72`_(%12544@.B!&04Q313L*("`@("`@("!]"@H@("`@
M("`@("1S=6ET95)E<W5L=',@/2!A<G)A>2@I.PH*("`@("`@("!F;W)E86-H
M("@D=&AI<RT^7W-U:71E<R!A<R`D85-U:71E*2!["B`@("`@("`@("`@("1A
M4W5I=&5297-U;'0@/2!A<G)A>2@I.PH*("`@("`@("`@("`@+R\@<F5M;W9E
M('1H92!F:7)S="!D:7)E8W1O<GDG<R!N86UE(&9R;VT@=&AE('1E<W0M<W5I
M=&4@;F%M92P@<VEN8V4@:70*("`@("`@("`@("`@+R\@;6]S=&QY(&ES('-O
M;65T:&EN9R!L:6ME("=T97-T<R<@;W(@86QI:V4*("`@("`@("`@("`@)')E
M;6]V86)L95!R969I>"`](&5X<&QO9&4H)U\G+"1A4W5I=&4M/F=E=$YA;64H
M*2D["B`@("`@("`@("`@("1A4W5I=&5297-U;'1;)VYA;64G72`]('-T<E]R
M97!L86-E*"1R96UO=F%B;&50<F5F:7A;,%TN)U\G+"`G)RP@)&%3=6ET92T^
M9V5T3F%M92@I*3L*"B`@("`@("`@("`@(&EF("@D<W5B;6ET=&5D("8F(&ES
M<V5T*"1R97%U97-T6R1A4W5I=&5297-U;'1;)VYA;64G75TI*2!["B`@("`@
M("`@("`@("`@("`D<F5S=6QT(#T@4$A056YI=#HZ<G5N*"1A4W5I=&4I.PH*
M("`@("`@("`@("`@("`@("1A4W5I=&5297-U;'1;)V-O=6YT<R==6R=R=6XG
M72`]("1R97-U;'0M/G)U;D-O=6YT*"D["B`@("`@("`@("`@("`@("`D85-U
M:71E4F5S=6QT6R=C;W5N=',G75LG97)R;W(G72`]("1R97-U;'0M/F5R<F]R
M0V]U;G0H*3L*("`@("`@("`@("`@("`@("1A4W5I=&5297-U;'1;)V-O=6YT
M<R==6R=F86EL=7)E)UT@/2`D<F5S=6QT+3YF86EL=7)E0V]U;G0H*3L*"B`@
M("`@("`@("`@("`@("`D85-U:71E4F5S=6QT6R=R97-U;'1S)UT@/2`D=&AI
M<RT^7W!R97!A<F5297-U;'0H)')E<W5L="PD<VAO=U!A<W-E9"D["@H@("`@
M("`@("`@("`@("`@)'!E<B`](#$P,"\D<F5S=6QT+3YR=6Y#;W5N="@I.PH@
M("`@("`@("`@("`@("`@)&9A:6QE9"`]("@D<&5R*B1R97-U;'0M/F5R<F]R
M0V]U;G0H*2DK*"1P97(J)')E<W5L="T^9F%I;'5R94-O=6YT*"DI.PH@("`@
M("`@("`@("`@("`@)&%3=6ET95)E<W5L=%LG<&5R8V5N="==(#T@<F]U;F0H
M,3`P+21F86EL960L,BD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D85-U:71E4F5S=6QT6R=A9&1);F9O)UT@/2`G3D]4($5814-5
M5$5$)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'-U:71E4F5S=6QT
M<UM=(#T@)&%3=6ET95)E<W5L=#L*("`@("`@("!]"@H@("`@("`@("1F:6YA
M;%LG;F%M92==(#T@)T]615)!3$P@4D5354Q4)SL*("`@("`@("`D9FEN86Q;
M)V-O=6YT<R==(#T@87)R87DH*3L*("`@("`@("`D9FEN86Q;)W!E<F-E;G0G
M72`](#`["B`@("`@("`@)&YU;45X96-U=&5D5&5S=',@/2`P.PH*("`@("`@
M("!F;W)E86-H("@D<W5I=&5297-U;'1S(&%S("1A4W5I=&5297-U;'0I('L*
M("`@("`@("`@("`@:68@*'-I>F5O9BA`)&%3=6ET95)E<W5L=%LG8V]U;G1S
M)UTI*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D85-U:71E4F5S=6QT
M6R=C;W5N=',G72!A<R`D:V5Y/3XD84-O=6YT*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D9FEN86Q;)V-O=6YT<R==6R1K97E=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D9FEN86Q;)V-O=6YT<R==6R1K97E=
M(#T@,#L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M("`@("1F:6YA;%LG8V]U;G1S)UU;)&ME>5T@*ST@)&%#;W5N=#L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M:68@*&ES<V5T*"1F:6YA;%LG8V]U;G1S)UU;)W)U;B==*2D@>PH@("`@("`@
M("`@("`D<&5R(#T@,3`P+R1F:6YA;%LG8V]U;G1S)UU;)W)U;B==.PH@("`@
M("`@("`@("`D9F%I;&5D(#T@*"1P97(J)&9I;F%L6R=C;W5N=',G75LG97)R
M;W(G72DK*"1P97(J)&9I;F%L6R=C;W5N=',G75LG9F%I;'5R92==*3L*("`@
M("`@("`@("`@)&9I;F%L6R=P97)C96YT)UT@/2!R;W5N9"@Q,#`M)&9A:6QE
M9"PR*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9FEN86Q;)W!E
M<F-E;G0G72`](#`["B`@("`@("`@?0H*("`@("`@("!A<G)A>5]U;G-H:69T
M*"1S=6ET95)E<W5L=',L)&9I;F%L*3L*"B`@("`@("`@:6YC;'5D92`G4$A0
M56YI="]'54DO2%1-3"YT<&PG.PH@("`@?0H*("`@(&9U;F-T:6]N(%]P<F5P
M87)E4F5S=6QT*"1R97-U;'0L)'-H;W=087-S960I"B`@("!["B`@("`@("`@
M)')E="`](&%R<F%Y*"D["B`@("`@("`@)&9A:6QU<F5S(#T@)')E<W5L="T^
M9F%I;'5R97,H*3L*"B`@("`@("`@9F]R96%C:"@D9F%I;'5R97,@87,@)&%&
M86EL=7)E*2!["B`@("`@("`@("`@("1R971;)V9A:6QU<F5S)UU;72`]("1T
M:&ES+3Y?<')E<&%R949A:6QU<F4H)&%&86EL=7)E*3L*("`@("`@("!]"@H@
M("`@("`@("1E<G)O<G,@/2`D<F5S=6QT+3YE<G)O<G,H*3L*"B`@("`@("`@
M9F]R96%C:"@D97)R;W)S(&%S("1A17)R;W(I('L*("`@("`@("`@("`@)')E
M=%LG97)R;W)S)UU;72`]("1T:&ES+3Y?<')E<&%R945R<F]R<R@D845R<F]R
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D<VAO=U!A<W-E9"D@>PH@("`@
M("`@("`@("`D<&%S<V5D(#T@)')E<W5L="T^<&%S<V5D5&5S=',H*3L*"B`@
M("`@("`@("`@(&9O<F5A8V@H)'!A<W-E9"!A<R`D85!A<W-E9"D@>PH@("`@
M("`@("`@("`@("`@)')E=%LG<&%S<V5D)UU;72`]("1T:&ES+3Y?<')E<&%R
M95!A<W-E9%1E<W1S*"1A4&%S<V5D*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1R970["B`@("!]"@H@("`@9G5N8W1I;VX@
M7W!R97!A<F5&86EL=7)E*"1F86EL=7)E*0H@("`@>PH@("`@("`@("1T97-T
M(#T@)&9A:6QU<F4M/F9A:6QE9%1E<W0H*3L*("`@("`@("`D<F5T6R=T97-T
M3F%M92==(#T@)'1E<W0M/F=E=$YA;64H*3L*("`@("`@("`D97AC97!T:6]N
M(#T@)&9A:6QU<F4M/G1H<F]W;D5X8V5P=&EO;B@I.PH*("`@("`@("`O+R!A
M('-E<FEA;&EZ960@<W1R:6YG('-T87)T<R!W:71H(&$@)V-H87)A8W1E<CID
M96-I;6%L.GLG"B`@("`@("`@+R\@:68@<V\@=V4@=')Y('1O('5N<V5R:6%L
M:7IE(&ET"B`@("`@("`@+R\@=&AI<R!P:65C92!O9B!T:&4@<F5G=6QA<B!E
M>'!R97-S:6]N(&ES(&9O<B!D971E8W1I;F<@82!S97)I86QI>F5D"B`@("`@
M("`@+R\@='EP92!L:6ME("=A.C,Z)R!F;W(@86X@87)R87D@=VET:"!T:')E
M92!E;&5M96YT(&]R(&%N(&]B:F5C="!I+F4N("=/.C$R.B)C;&%S<R(Z,R<*
M("`@("`@("`D<V5R:6%L:7IE9"`]("<H7'<Z7&0K.B@_.B);7B)=*R(Z7&0K
M.BD_7'LN*EQ]*2<["@H@("`@("`@("\O(%-P86-E<R!M:6=H="!M86ME(&$@
M9&EF9BP@<V\@=V4@<VAA;&P@<VAO=R!T:&5M('!R;W!E<FQY("AS:6YC92!A
M"B`@("`@("`@+R\@=7-E<B!A9V5N="!I9VYO<F5S('1H96TI+@H@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"<O7B@N*BEE>'!E8W1E9"`G("X@)'-E<FEA;&EZ
M960@+B`G+"!A8W1U86P@)R`N("1S97)I86QI>F5D("X@)R0O<U4G+"`D97AC
M97!T:6]N+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@;V)?<W1A<G0H*3L*
M("`@("`@("`@("`@<')I;G1?<BAU;G-E<FEA;&EZ92@D;6%T8VAE<ULR72DI
M.PH@("`@("`@("`@("`D<F5T6R=E>'!E8W1E9"==(#T@:'1M;'-P96-I86QC
M:&%R<R@D;6%T8VAE<ULQ72D@+B`B/'!R93XB("X@:'1M;'-P96-I86QC:&%R
M<RAR=')I;2AO8E]G971?8V]N=&5N=',H*2DI("X@(CPO<')E/B(["B`@("`@
M("`@("`@("\O($EM<')O=F5D(&-O;7!A=&EB:6QI='DL(&]B7V-L96%N*"D@
M=V]U;&0@8F4@4$A0(#X](#0N,BXP(&]N;'DN"B`@("`@("`@("`@(&]B7V5N
M9%]C;&5A;B@I.PH*("`@("`@("`@("`@;V)?<W1A<G0H*3L*("`@("`@("`@
M("`@<')I;G1?<BAU;G-E<FEA;&EZ92@D;6%T8VAE<ULS72DI.PH@("`@("`@
M("`@("`D<F5T6R=A8W1U86PG72`](&AT;6QS<&5C:6%L8VAA<G,H)&UA=&-H
M97-;,5TI("X@(CQP<F4^(B`N(&AT;6QS<&5C:6%L8VAA<G,H<G1R:6TH;V)?
M9V5T7V-O;G1E;G1S*"DI*2`N("(\+W!R93XB.PH@("`@("`@("`@("!O8E]E
M;F1?8VQE86XH*3L*("`@("`@("!]"@H@("`@("`@(&5L<V4@:68@*'!R96=?
M;6%T8V@H)R]>*"XJ*65X<&5C=&5D("@N*BDL(&%C='5A;"`H+BHI)"]S52<L
M("1E>&-E<'1I;VXL("1M871C:&5S*2D@>PH@("`@("`@("`@("`D<F5T6R=E
M>'!E8W1E9"==(#T@;FPR8G(H<W1R7W)E<&QA8V4H(B`B+"`B)FYB<W`[(BP@
M:'1M;'-P96-I86QC:&%R<R@D;6%T8VAE<ULQ72`N("1M871C:&5S6S)=*2DI
M.PH@("`@("`@("`@("`D<F5T6R=A8W1U86PG72`](&YL,F)R*'-T<E]R97!L
M86-E*"(@(BP@(B9N8G-P.R(L(&AT;6QS<&5C:6%L8VAA<G,H)&UA=&-H97-;
M,5T@+B`D;6%T8VAE<ULS72DI*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D<F5T6R=M97-S86=E)UT@/2!N;#)B<BAS=')?<F5P;&%C92@B("(L
M("(F;F)S<#LB+"!H=&UL<W!E8VEA;&-H87)S*"1E>&-E<'1I;VXI*2D["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("!F=6YC
M=&EO;B!?<')E<&%R95!A<W-E9%1E<W1S*"1P87-S960I"B`@("!["B`@("`@
M("`@)')E=%LG=&5S=$YA;64G72`]("1P87-S960M/F=E=$YA;64H*3L*("`@
M("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("!F=6YC=&EO;B!?<')E<&%R
M945R<F]R*"1E<G)O<BD*("`@('L*("`@("`@("`D<F5T6R=T97-T3F%M92==
M(#T@)&5R<F]R+3YG971.86UE*"D["B`@("`@("`@)')E=%LG;65S<V%G92==
M(#T@)&5R<F]R+3YT;U-T<FEN9R@I.PH@("`@("`@(')E='5R;B`D<F5T.PH@
M("`@?0I]"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@
M-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!C+6AA;F=I;F<M8V]M;65N="UE
M;F1E<BUP.B!N:6P*("H@16YD.@H@*B\*/SX*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+U!(4%5N:70O1U5)+TA434PN='!L````
M````````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$U,#(S`#$P-3$U-#,S
M-S,W`#`R,C`Q,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\:'1M;#X*("`@(#QH96%D/@H@("`@("`@(#Q35%E,12!T>7!E
M/2)T97AT+V-S<R(^"@H@("`@("`@("`@("!B;V1Y+"!T9"!["B`@("`@("`@
M("`@("`@("!B86-K9W)O=6YD+6-O;&]R.B!L:6=H=&=R97D["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@('1A8FQE+F]U=&QI;F4L(&]U=&QI;F5&86EL
M=7)E('L*("`@("`@("`@("`@("`@(&)A8VMG<F]U;F0M8V]L;W(Z(&)L86-K
M.PH@("`@("`@("`@("`@("`@8F]R9&5R+7=I9'1H.B`Q<'@["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@('1D('L*("`@("`@("`@("`@("`@('!A9&1I
M;F<Z(#)P>#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@=&@@>PH@("`@
M("`@("`@("`@("`@=&5X="UA;&EG;CH@;&5F=#L*("`@("`@("`@("`@("`@
M(&-O;&]R.B!W:&ET93L*("`@("`@("`@("`@("`@(&)A8VMG<F]U;F0M8V]L
M;W(Z(&)L86-K.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`N<W5C8V5S
M<R!["B`@("`@("`@("`@("`@("!B86-K9W)O=6YD+6-O;&]R.B!L:6=H=&=R
M965N.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`N9F%I;'5R92!["B`@
M("`@("`@("`@("`@("!B86-K9W)O=6YD+6-O;&]R.B!O<F%N9V4["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@+FEN9F\@>PH@("`@("`@("`@("`@("`@
M<&%D9&EN9SH@,G!X.PH@("`@("`@("`@("`@("`@8V]L;W(Z(&]R86YG93L*
M("`@("`@("`@("`@?0H*("`@("`@("`\+U-464Q%/@H@("`@/"]H96%D/@H@
M("`@/&)O9'D^"B`@("`@("`@/&9O<FT@86-T:6]N/2(\/W!H<"!E8VAO("1?
M4T525D526R=02%!?4T5,1B==(#\^(B!M971H;V0](G!O<W0B(&YA;64](F]P
M=&EO;G-&;W)M(CX*("`@("`@("`@("`@/'1A8FQE(&%L:6=N/2)C96YT97(B
M(&-L87-S/2)O=71L:6YE(B!W:61T:#TB-S`E(CX*("`@("`@("`@("`@("`@
M(#QT<CX*("`@("`@("`@("`@("`@("`@("`\=&@@8V]L<W!A;CTB,3`B/@H@
M("`@("`@("`@("`@("`@("`@("`@("!/<'1I;VYS"B`@("`@("`@("`@("`@
M("`@("`@/"]T:#X*("`@("`@("`@("`@("`@(#PO='(^"B`@("`@("`@("`@
M("`@("`\='(^"B`@("`@("`@("`@("`@("`@("`@/'1D(&-O;'-P86X](C$P
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@/&EN<'5T('1Y<&4](F-H96-K
M8F]X(B!O;D-L:6-K/2)U;D-H96-K06QL*"DB(&YA;64](F%L;$-H96-K960B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`H=6XI8VAE8VL@86QL"B`@("`@
M("`@("`@("`@("`@("`@("`@("9N8G-P.R`F;F)S<#L*("`@("`@("`@("`@
M("`@("`@("`@("`@<VAO=R!/2R`\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA
M;64](G-H;W=/2R(@/#]P:'`@96-H;R!`)')E<75E<W1;)W-H;W=/2R==/R=C
M:&5C:V5D)SHG)S\^/@H@("`@("`@("`@("`@("`@("`@("`@("`F;F)S<#L@
M)FYB<W`["B`@("`@("`@("`@("`@("`@("`@("`@(#QI;G!U="!T>7!E/2)S
M=6)M:70B(&YA;64](G-U8FUI='1E9"(@=F%L=64](G)U;B!T97-T<R(^"B`@
M("`@("`@("`@("`@("`@("`@/"]T9#X*("`@("`@("`@("`@("`@(#PO='(^
M"@H@("`@("`@("`@("`@("`@/#]P:'`@9F]R96%C:"@D<W5I=&5297-U;'1S
M(&%S("1A4F5S=6QT*3H@/SX*("`@("`@("`@("`@("`@("`@("`\='(^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QT:"!C;VQS<&%N/2(Q,"(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\:6YP=70@='EP93TB8VAE8VMB;W@B
M(&YA;64](CP_<&AP(&5C:&\@)&%297-U;'1;)VYA;64G72`_/B(@/#]P:'`@
M96-H;R!`)')E<75E<W1;)&%297-U;'1;)VYA;64G75T_)V-H96-K960G.B<G
M(#\^/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/#]P:'`@96-H;R`D
M85)E<W5L=%LG;F%M92==(#\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`F;F)S<#L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#P_<&AP(&EF
M("AI<W-E="@D85)E<W5L=%LG861D26YF;R==*2DZ(#\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/&9O;G0@8VQA<W,](FEN9F\B/CP_<&AP
M(&5C:&\@0"1A4F5S=6QT6R=A9&1);F9O)UT@/SX\+V9O;G0^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\/W!H<"!E;F1I9B`_/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\+W1H/@H@("`@("`@("`@("`@("`@("`@(#PO='(^
M"@H@("`@("`@("`@("`@("`@("`@(#P_<&AP(&EF*$`D85)E<W5L=%LG<&5R
M8V5N="==*3H@/SX*("`@("`@("`@("`@("`@("`@("`@("`@/'1R/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'1D(&-O;'-P86X](C$P(B!N;W=R
M87`](FYO=W)A<"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'1A8FQE('-T>6QE/2)W:61T:#HQ,#`E.R!P861D:6YG.C)P>#LB(&-E;&QS
M<&%C:6YG/2(P(B!C96QL<W!A;CTB,"(@8V5L;'!A9&1I;F<](C`B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\='(^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\=&0@=VED=&@](CP_
M<&AP(&5C:&\@)&%297-U;'1;)W!E<F-E;G0G72`_/B4B(&-L87-S/2)S=6-C
M97-S(B!A;&EG;CTB8V5N=&5R(B!S='EL93TB<&%D9&EN9SHP.R(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/#]P:'`@
M96-H;R`D85)E<W5L=%LG<&5R8V5N="==/R1A4F5S=6QT6R=P97)C96YT)UTN
M)R4G.B<G(#\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+W1D/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'1D('=I9'1H/2(\/W!H<"!E8VAO(#$P,"TD85)E<W5L=%LG<&5R
M8V5N="==(#\^)2(@8VQA<W,](F9A:6QU<F4B(&%L:6=N/2)C96YT97(B('-T
M>6QE/2)P861D:6YG.C`[(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\/W!H<"!E8VAO("@Q,#`M)&%297-U;'1;)W!E
M<F-E;G0G72D_*#$P,"TD85)E<W5L=%LG<&5R8V5N="==+B<E)RDZ)R<@/SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO=&0^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO='(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]T86)L93X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO=&0^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#PO='(^"B`@("`@("`@("`@("`@("`@("`@/#]P:'`@96YD:68@
M/SX*"B`@("`@("`@("`@("`@("`@("`@/#]P:'`@:68H0"1A4F5S=6QT6R=C
M;W5N=',G72DZ(#\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QT<CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QT9"!C;VQS<&%N/2(Q,"(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/#]P:'`@9F]R96%C:"@D
M85)E<W5L=%LG8V]U;G1S)UT@87,@)&%#;W5N=#T^)'9A;'5E*3H@/SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/#]P:'`@96-H;R`D
M84-O=6YT(#\^<R`](#P_<&AP(&5C:&\@)'9A;'5E(#\^("9N8G-P.R`F;F)S
M<#L@)FYB<W`[("9N8G-P.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#P_<&AP(&5N9&9O<F5A8V@@/SX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO=&0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO='(^"B`@
M("`@("`@("`@("`@("`@("`@/#]P:'`@96YD:68@/SX*"B`@("`@("`@("`@
M("`@("`@("`@/#]P:'`@:68H:7-S970H)&%297-U;'1;)W)E<W5L=',G75LG
M9F%I;'5R97,G72D@)B8@<VEZ96]F*"1A4F5S=6QT6R=R97-U;'1S)UU;)V9A
M:6QU<F5S)UTI*0H@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H*"1A
M4F5S=6QT6R=R97-U;'1S)UU;)V9A:6QU<F5S)UT@87,@)&%&86EL=7)E*3H@
M/SX*("`@("`@("`@("`@("`@("`@("`@("`@/'1R/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'1D(&-L87-S/2)F86EL=7)E(CX\/W!H<"!E8VAO
M("1A1F%I;'5R95LG=&5S=$YA;64G72`_/CPO=&0^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\=&0@8VQA<W,](F9A:6QU<F4B/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#P_<&AP(&EF*&ES<V5T*"1A1F%I;'5R
M95LG;65S<V%G92==*2`F)B`D849A:6QU<F5;)VUE<W-A9V4G72DZ(#\^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#P_<&AP(&5C:&\@
M)&%&86EL=7)E6R=M97-S86=E)UT@/SX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\/W!H<"!E;'-E.B`_/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\=&%B;&4@8VQA<W,](F]U=&QI;F5&86EL=7)E
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QT
M<CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\=&0^97AP96-T960\+W1D/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QT9#X\/W!H<"!E8VAO("1A1F%I;'5R95LG
M97AP96-T960G72`_/CPO=&0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+W1R/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'1R/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QT9#YA8W1U86P\+W1D/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QT9#X\/W!H<"!E
M8VAO("1A1F%I;'5R95LG86-T=6%L)UT@/SX\+W1D/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]T<CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"]T86)L93X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\/W!H<"!E;F1I9B`_/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/"]T9#X*("`@("`@("`@("`@("`@("`@("`@
M("`@/"]T<CX*("`@("`@("`@("`@("`@("`@("`\/W!H<"!E;F1F;W)E86-H
M(#\^"@H@("`@("`@("`@("`@("`@("`@(#P_<&AP(&EF*&ES<V5T*"1A4F5S
M=6QT6R=R97-U;'1S)UU;)V5R<F]R<R==*2`F)B!S:7IE;V8H)&%297-U;'1;
M)W)E<W5L=',G75LG97)R;W)S)UTI*0H@("`@("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H*"1A4F5S=6QT6R=R97-U;'1S)UU;)V5R<F]R<R==(&%S("1A
M17)R;W(I.B`_/@H@("`@("`@("`@("`@("`@("`@("`@("`\='(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\=&0@8VQA<W,](F9A:6QU<F4B/CP_
M<&AP(&5C:&\@)&%%<G)O<ELG=&5S=$YA;64G72`_/CPO=&0^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\=&0@8VQA<W,](F9A:6QU<F4B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#P_<&AP(&5C:&\@)&%%<G)O
M<ELG;65S<V%G92==(#\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M+W1D/@H@("`@("`@("`@("`@("`@("`@("`@("`\+W1R/@H@("`@("`@("`@
M("`@("`@("`@(#P_<&AP(&5N9&9O<F5A8V@@/SX*"B`@("`@("`@("`@("`@
M("`@("`@/#]P:'`@:68H:7-S970H)&%297-U;'1;)W)E<W5L=',G75LG<&%S
M<V5D)UTI("8F('-I>F5O9B@D85)E<W5L=%LG<F5S=6QT<R==6R=P87-S960G
M72DI"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@H)&%297-U;'1;
M)W)E<W5L=',G75LG<&%S<V5D)UT@87,@)&%087-S960I.B`_/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\='(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\=&0@8VQA<W,](G-U8V-E<W,B/CP_<&AP(&5C:&\@)&%087-S961;
M)W1E<W1.86UE)UT@/SX\+W1D/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'1D(&-L87-S/2)S=6-C97-S(CX\8CY/2SPO8CX\+W1D/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\+W1R/@H@("`@("`@("`@("`@("`@("`@(#P_
M<&AP(&5N9&9O<F5A8V@@/SX*"B`@("`@("`@("`@("`@("`\/W!H<"!E;F1F
M;W)E86-H(#\^"B`@("`@("`@("`@(#PO=&%B;&4^"B`@("`@("`@/"]F;W)M
M/@H*("`@("`@("`\<V-R:7!T/@H@("`@("`@("`@("!V87(@86QL4W5I=&5.
M86UE<R`](&YE=R!!<G)A>2@I.PH@("`@("`@("`@("`\/W!H<"!F;W)E86-H
M*"1S=6ET95)E<W5L=',@87,@)&%297-U;'0I.B`_/@H@("`@("`@("`@("`@
M("`@86QL4W5I=&5.86UE<UMA;&Q3=6ET94YA;65S+FQE;F=T:%T@/2`B/#]P
M:'`@96-H;R`D85)E<W5L=%LG;F%M92==(#\^(CL*("`@("`@("`@("`@/#]P
M:'`@96YD9F]R96%C:"`_/@H@("`@("`@("`@("!F=6YC=&EO;B!U;D-H96-K
M06QL*"D*("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@7V-H96-K960@
M/2!D;V-U;65N="YO<'1I;VYS1F]R;2YA;&Q#:&5C:V5D+F-H96-K960["B`@
M("`@("`@("`@("`@("!F;W(@*&D],#MI/&%L;%-U:71E3F%M97,N;&5N9W1H
M.VDK*RD@>PH@("`@("`@("`@("`@("`@("`@(&1O8W5M96YT+F]P=&EO;G-&
M;W)M6V%L;%-U:71E3F%M97-;:5U=+F-H96-K960@/2!?8VAE8VME9#L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@(#PO<V-R:7!T
M/@H*("`@(#PO8F]D>3X*/"]H=&UL/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+U!(4%5N:70O1U5)+U-E='5P1&5C;W)A=&]R+G!H<```````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#$V-38Q`#$P-3$U-#,S-S,W`#`R-#(P-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S
M;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%!(4"!697)S:6]N(#0*("H*("H@
M0V]P>7)I9VAT("AC*2`R,#`R+3(P,#4L(%-E8F%S=&EA;B!"97)G;6%N;B`\
M<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/BX*("H@06QL(')I9VAT<R!R97-E
M<G9E9"X*("H*("H@4F5D:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@
M86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T"B`J(&UO9&EF:6-A
M=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I
M;F<@8V]N9&ET:6]N<PH@*B!A<F4@;65T.@H@*@H@*B`@("H@4F5D:7-T<FEB
M=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C
M;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO
M;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@"B`J("`@*B!2
M961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@
M=&AE(&%B;W9E(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T:&ES(&QI<W0@
M;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN
M"B`J("`@("!T:&4@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I
M86QS('!R;W9I9&5D('=I=&@@=&AE"B`J("`@("!D:7-T<FEB=71I;VXN"B`J
M"B`J("`@*B!.96ET:&5R('1H92!N86UE(&]F(%-E8F%S=&EA;B!"97)G;6%N
M;B!N;W(@=&AE(&YA;65S(&]F(&AI<PH@*B`@("`@8V]N=')I8G5T;W)S(&UA
M>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92!P<F]D=6-T<R!D97)I
M=F5D"B`J("`@("!F<F]M('1H:7,@<V]F='=A<F4@=VET:&]U="!S<&5C:69I
M8R!P<FEO<B!W<FET=&5N('!E<FUI<W-I;VXN"B`J"B`J(%1(25,@4T]&5%=!
M4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#
M3TY44DE"551/4E,*("H@(D%3($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U0
M3$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0*("H@3$E-251%
M1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)
M5%D@04Y$($9)5$Y%4U,*("H@1D]2($$@4$%25$E#54Q!4B!055)03U-%($%2
M12!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4*("H@0T]065))
M1TA4($]73D52($]2($-/3E1224)55$]24R!"12!,24%"3$4@1D]2($%.62!$
M25)%0U0L($E.1$E214-4+`H@*B!)3D-)1$5.5$%,+"!34$5#24%,+"!%6$5-
M4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+`H@
M*B!"550@3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&(%-50E-42515
M5$4@1T]/1%,@3U(@4T525DE#15,["B`J($Q/4U,@3T8@55-%+"!$051!+"!/
M4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI($A/5T5615(*
M("H@0T%54T5$($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)04))3$E462P@5TA%
M5$A%4B!)3B!#3TY44D%#5"P@4U1224,*("H@3$E!0DE,2519+"!/4B!43U)4
M("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@
M24X*("H@04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3(%-/1E1705)%
M+"!%5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,2519($]&(%-5
M0T@@1$%-04=%+@H@*@H@*B!`8V%T96=O<GD@("!497-T:6YG"B`J($!P86-K
M86=E("`@(%!(4%5N:70*("H@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE<VEN
M9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("H@0&-O<'ER:6=H="`@,C`P,BTR
M,#`U(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN
M+F1E/@H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G
M+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E
M<G-I;VX@("`@0U93.B`D260Z(%-E='5P1&5C;W)A=&]R+G!H<"QV(#$N,34@
M,C`P-2\Q,2\Q,"`P.3HT-SHQ-2!S96)A<W1I86X@17AP("0*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!(4%5N:70*("H@
M0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C`N
M,`H@*B\*"B\J*@H@*B!4:&ES(&1E8V]R871O<B!A8W1U86QL>2!J=7-T(&%D
M9',@=&AE(&9U;F-T:6]N86QI='D@=&\@<F5A9"!T:&4*("H@=&5S="US=6ET
M92!C;&%S<V5S(&9R;VT@82!G:79E;B!D:7)E8W1O<GD@86YD(&EN<W1A;F-I
M871E('1H96T*("H@875T;VUA=&EC86QL>2P@=7-E(&ET(&%S(&=I=F5N(&EN
M('1H92!E>&%M<&QE(&)E;&]W+@H@*@H@*B`\8V]D93X*("H@/#]P:'`*("H@
M)&=U:2`](&YE=R!02%!5;FET7T=525]3971U<$1E8V]R871O<BAN97<@4$A0
M56YI=%]'54E?2%1-3"@I*3L*("H@)&=U:2T^9V5T4W5I=&5S1G)O;41I<B@G
M+W!A=&@O=&\O9&ER+W1E<W1S)RPG+BI<+G!H<"0G+&%R<F%Y*"=I;F1E>"YP
M:'`G+"=S<6PN<&AP)RDI.PH@*B`D9W5I+3YS:&]W*"D["B`J(#\^"B`J(#PO
M8V]D93X*("H*("H@5&AE(&5X86UP;&4@8V%L;',@=&AI<R!C;&%S<R!A;F0@
M=&5L;',@:70@=&\Z"B`J"B`J("`@+2!F:6YD(&%L;"!F:6QE('5N9&5R('1H
M92!D:7)E8W1O<GD@+W!A=&@O=&\O9&ER+W1E<W1S"B`J("`@+2!F;W(@9FEL
M97,L('=H:6-H(&5N9"!W:71H("<N<&AP)R`H=&AI<R!I<R!A('!I96-E(&]F
M(&$@<F5G97AP+"!T:&%T)W,@=VAY('1H92`N(&ES(&5S8V%P960I"B`J("`@
M+2!A;F0@=&\@97AC;'5D92!T:&4@9FEL97,@)VEN9&5X+G!H<"<@86YD("=S
M<6PN<&AP)PH@*B`@("T@86YD(&EN8VQU9&4@86QL('1H92!F:6QE<R!T:&%T
M(&%R92!L969T(&EN('1H92!T97-T<RX*("H*("H@1VEV96X@=&AA="!T:&4@
M<&%T:"`H=&AE(&9I<G-T('!A<F%M971E<BD@96YD<R!W:71H("=T97-T<R<@
M:70@=VEL;"!B92!A<W-U;65D"B`J('1H870@=&AE(&-L87-S97,@87)E(&YA
M;65D('1E<W1S7RH@=VAE<F4@*B!I<R!T:&4@9&ER96-T;W)Y('!L=7,@=&AE
M(&9I;&5N86UE+`H@*B!A8V-O<F1I;F<@=&\@4$5!4B!S=&%N9&%R9',N"B`J
M"B`J(%-O('1H870Z"B`J"B`J("`@+2`G=&5S=$UE+G!H<"<@:6X@=&AE(&1I
M<B`G=&5S=',G(&)I;&P@8F4@87-S=6UE9"!T;R!C;VYT86EN(&$@8VQA<W,@
M=&5S='-?=&5S=$UE"B`J("`@+2`G+VUO<F5T97-T<R]A5&5S="YP:'`G('-H
M;W5L9"!C;VYT86EN(&$@8VQA<W,@)W1E<W1S7VUO<F5T97-T<U]A5&5S="<*
M("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@*B!`<&%C:V%G92`@("!02%!5
M;FET"B`J($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R86U`
M:W)I97-I;F<N9&4^"B`J($!C;W!Y<FEG:'0@(#(P,#(M,C`P-2!396)A<W1I
M86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&QI
M8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B
M<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@(%)E
M;&5A<V4Z(#$N,RXR"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]02%!5;FET"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL
M86)L92!S:6YC92!296QE87-E(#$N,"XP"B`J+PIC;&%S<R!02%!5;FET7T=5
M25]3971U<$1E8V]R871O<@I["B`@("`O*BH*("`@("H*("`@("H*("`@("HO
M"B`@("!F=6YC=&EO;B!02%!5;FET7T=525]3971U<$1E8V]R871O<B@F)&=U
M:2D*("`@('L*("`@("`@("`D=&AI<RT^7V=U:2`]("8D9W5I.PH@("`@?0H*
M("`@("\J*@H@("`@*B`@(&IU<W0@9F]R=V%R9&EN9R!T:&4@86-T:6]N('1O
M('1H92!D96-O<F%T960@8VQA<W,N"B`@("`J"B`@("`J+PH@("`@9G5N8W1I
M;VX@<VAO=R@D<VAO=U!A<W-E9#U44E5%*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?9W5I+3YS:&]W*"1S:&]W4&%S<V5D*3L*("`@('T*"B`@("`O*BH*("`@
M("H@4V5T=7`@=&5S="!S=6ET97,@=&AA="!C86X@8F4@9F]U;F0@:6X@=&AE
M(&=I=F5N(&1I<F5C=&]R>0H@("`@*B!5<VEN9R!T:&4@<V5C;VYD('!A<F%M
M971E<B!Y;W4@8V%N(&%L<V\@8VAO;W-E(&$@<W5B<V5T<R!O9B!T:&4@9FEL
M97,@9F]U;F0*("`@("H@:6X@=&AE(&=I=F5N(&1I<F5C=&]R>2X@22YE+B!O
M;FQY(&%L;"!T:&4@9FEL97,@=&AA="!C;VYT86EN("=?56YI=%1E<W1?)RP*
M("`@("H@:6X@;W)D97(@=&\@9&\@=&AI<R!S:6UP;'D@8V%L;"!I="!L:6ME
M('1H:7,Z"B`@("`J(#QC;V1E/F=E=%-U:71E<T9R;VU$:7(H)&1I<BPG+BI?
M56YI=%1E<W1?+BHG*3PO8V]D93XN"B`@("`J(%1H97)E('EO=2!C86X@86QR
M96%D>2!S964@=&AA="!T:&4@<&%T=&5R;B!I<R!B=6EL="!F;W(@=&AE('5S
M92!W:71H:6X@82!R96=U;&%R(&5X<')E<W-I;VXN"B`@("`J"B`@("`J($!P
M87)A;2`@<W1R:6YG("!T:&4@9&ER96-T;W)Y('=H97)E('1O('-E87)C:"!F
M;W(@=&5S="US=6ET92!F:6QE<PH@("`@*B!`<&%R86T@('-T<FEN9R`@=&AE
M('!A='1E<FX@*&$@<F5G97AP*2!B>2!W:&EC:"!T;R!F:6YD('1H92!F:6QE
M<PH@("`@*B!`<&%R86T@(&%R<F%Y("`@86X@87)R87D@;V8@9FEL92!N86UE
M<R!T:&%T('-H86QL(&)E(&5X8VQU9&5D"B`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T4W5I=&5S1G)O;41I<B@D9&ER+"`D9FEL96YA;650871T97)N(#T@)R<L
M("1E>&-L=61E(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H)&1I<GMS
M=')L96XH)&1I<BDM,7T@/3T@1$E214-43U)97U-%4$%2051/4BD@>PH@("`@
M("`@("`@("`D9&ER(#T@<W5B<W1R*"1D:7(L(#`L("TQ*3L*("`@("`@("!]
M"@H@("`@("`@("1F:6QE<R`]("1T:&ES+3Y?9V5T1FEL97,H<F5A;'!A=&@H
M)&1I<BDL("1F:6QE;F%M95!A='1E<FXL("1E>&-L=61E+"!R96%L<&%T:"@D
M9&ER("X@)R\N+B<I*3L*("`@("`@("!A<V]R="@D9FEL97,I.PH*("`@("`@
M("!F;W)E86-H("@D9FEL97,@87,@)&-L87-S3F%M92`]/B`D849I;&4I('L*
M("`@("`@("`@("`@:6YC;'5D95]O;F-E*"1A1FEL92D["@H@("`@("`@("`@
M("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<TYA;64I*2!["B`@("`@("`@("`@
M("`@("`D<W5I=&5S6UT@/28@;F5W(%!(4%5N:71?5&5S=%-U:71E*"1C;&%S
M<TYA;64I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M=')I9V=E<E]E<G)O<B@B)&-L87-S3F%M92!C;W5L9"!N;W0@8F4@9F]U;F0@
M:6X@)&1I<B1A1FEL92$B*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/E]G=6DM/F%D9%-U:71E<R@D<W5I=&5S*3L*("`@('T*
M"B`@("`O*BH*("`@("H@5&AI<R!M971H;V0@<V5A<F-H97,@<F5C=7)S:79E
M;'D@=&AR;W5G:"!T:&4@9&ER96-T;W)I97,*("`@("H@=&\@9FEN9"!A;&P@
M=&AE(&9I;&5S('1H870@<VAA;&P@8F4@861D960@=&\@=&AE(&)E('9I<VEB
M;&4N"B`@("`J"B`@("`J($!P87)A;2`@<W1R:6YG("!T:&4@<&%T:"!W:&5R
M92!F:6YD('1H92!F:6QE<PH@("`@*B!`<&%R86T@('-R=&EN9R`@=&AE('-T
M<FEN9R!P871T97)N(&)Y('=H:6-H('1O(&9I;F0@=&AE(&9I;&5S"B`@("`J
M($!P87)A;2`@<W1R:6YG("!T:&4@9FEL92!N86UE<R!T;R!B92!E>&-L=61E
M9`H@("`@*B!`<&%R86T@('-T<FEN9R`@=&AE(')O;W0@9&ER96-T;W)Y+"!W
M:&EC:"!S97)V97,@87,@=&AE('!R969I>"!T;R!T:&4@9G5L;'D@<75A;&EF
M:65D(&9I;&5N86UE"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@*B\*("`@
M(&9U;F-T:6]N(%]G971&:6QE<R@D9&ER+"`D9FEL96YA;650871T97)N+"`D
M97AC;'5D92P@)')O;W1$:7(I"B`@("!["B`@("`@("`@)&9I;&5S(#T@87)R
M87DH*3L*"B`@("`@("`@:68@*"1D<"`](&]P96YD:7(H)&1I<BDI('L*("`@
M("`@("`@("`@=VAI;&4@*$9!3%-%("$]/2`H)&9I;&4@/2!R96%D9&ER*"1D
M<"DI*2!["B`@("`@("`@("`@("`@("`D9FEL96YA;64@/2`D9&ER("X@1$E2
M14-43U)97U-%4$%2051/4B`N("1F:6QE.PH@("`@("`@("`@("`@("`@)&UA
M=&-H("`@(#T@5%)513L*"B`@("`@("`@("`@("`@("!I9B`H)&9I;&5N86UE
M4&%T=&5R;B`F)B`A<')E9U]M871C:"@B?B1F:6QE;F%M95!A='1E<FY^(BP@
M)&9I;&4I*2!["B`@("`@("`@("`@("`@("`@("`@)&UA=&-H(#T@1D%,4T4[
M"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*'-I>F5O
M9B@D97AC;'5D92DI('L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M97AC;'5D92!A<R`D845X8VQU9&4I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*'-T<G!O<R@D9FEL92P@)&%%>&-L=61E*2`A/3T@1D%,4T4I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M871C:"`]($9!3%-%.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*&ES7V9I;&4H)&9I;&5N
M86UE*2`F)B`D;6%T8V@I('L*("`@("`@("`@("`@("`@("`@("`D=&UP(#T@
M<W1R7W)E<&QA8V4H)')O;W1$:7(L("<G+"`D9FEL96YA;64I.PH*("`@("`@
M("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1T;7`L($1)4D5#5$]265]315!!
M4D%43U(I(#T]/2`P*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T;7`@
M/2!S=6)S='(H)'1M<"P@,2D["B`@("`@("`@("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1T;7`L("<O)RD@/3T](#`I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1M<"`]('-U8G-T<B@D=&UP
M+"`Q*3L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M("`@("1C;&%S<TYA;64@/2!S=')?<F5P;&%C92A$25)%0U1/4EE?4T5005)!
M5$]2+"`G7R<L("1T;7`I.PH@("`@("`@("`@("`@("`@("`@("1C;&%S<TYA
M;64@/2!B87-E;F%M92@D8VQA<W-.86UE+"`G+G!H<"<I.PH*("`@("`@("`@
M("`@("`@("`@("`D9FEL97-;)&-L87-S3F%M95T@/2`D9FEL96YA;64["B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*"1F:6QE("$]
M("<N)R`F)B`D9FEL92`A/2`G+BXG("8F(&ES7V1I<B@D9FEL96YA;64I*2![
M"B`@("`@("`@("`@("`@("`@("`@)&9I;&5S(#T@87)R87E?;65R9V4H)&9I
M;&5S+"`D=&AI<RT^7V=E=$9I;&5S*"1F:6QE;F%M92P@)&9I;&5N86UE4&%T
M=&5R;BP@)&5X8VQU9&4L("1R;V]T1&ER*2D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&-L;W-E9&ER*"1D<"D["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&9I;&5S.PH@("`@?0I]"@HO*@H@
M*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC
M+6]F9G-E=#H@-`H@*B!C+6AA;F=I;F<M8V]M;65N="UE;F1E<BUP.B!N:6P*
M("H@16YD.@H@*B\*/SX*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O4$A056YI="]297!E871E9%1E<W0N<&AP````````````````
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,3`V,C(`,3`U,34T,S,W,S<`,#(S,C`Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT
M('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@4$A0(%9E<G-I;VX@-`H@*@H@
M*B!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P-2P@4V5B87-T:6%N($)E<F=M86YN
M(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^+@H@*B!!;&P@<FEG:'1S(')E
M<V5R=F5D+@H@*@H@*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C
M92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D:69I
M8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO
M=VEN9R!C;VYD:71I;VYS"B`J(&%R92!M970Z"B`J"B`J("`@*B!2961I<W1R
M:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E
M(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET
M:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+@H@*B`*("H@("`J
M(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C
M92!T:&4@86)O=F4@8V]P>7)I9VAT"B`J("`@("!N;W1I8V4L('1H:7,@;&ES
M="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@
M:6X*("H@("`@('1H92!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E
M<FEA;',@<')O=FED960@=VET:"!T:&4*("H@("`@(&1I<W1R:6)U=&EO;BX*
M("H*("H@("`J($YE:71H97(@=&AE(&YA;64@;V8@4V5B87-T:6%N($)E<F=M
M86YN(&YO<B!T:&4@;F%M97,@;V8@:&ES"B`J("`@("!C;VYT<FEB=71O<G,@
M;6%Y(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E('!R;V1U8W1S(&1E
M<FEV960*("H@("`@(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T('-P96-I
M9FEC('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H*("H@5$A)4R!33T94
M5T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$
M($-/3E1224)55$]24PH@*B`B05,@25,B($%.1"!!3ED@15A04D534R!/4B!)
M35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5`H@*B!,24U)
M5$5$(%1/+"!42$4@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))
M3$E462!!3D0@1DE43D534PH@*B!&3U(@02!005)424-53$%2(%!54E!/4T4@
M05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(10H@*B!#3U!9
M4DE'2%0@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),12!&3U(@04Y9
M($1)4D5#5"P@24Y$25)%0U0L"B`J($E.0TE$14Y404PL(%-014-)04PL($58
M14U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L
M"B`J($)55"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)
M5%5412!'3T]$4R!/4B!315)624-%4SL*("H@3$]34R!/1B!54T4L($1!5$$L
M($]2(%!23T9)5%,[($]2($)54TE.15-3($E.5$524E505$E/3BD@2$]7159%
M4@H@*B!#0553140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!7
M2$542$52($E.($-/3E1204-4+"!35%))0PH@*B!,24%"24Q)5%DL($]2(%1/
M4E0@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D@05))4TE.
M1R!)3@H@*B!!3ED@5T%9($]55"!/1B!42$4@55-%($]&(%1(25,@4T]&5%=!
M4D4L($5614X@248@041625-%1"!/1B!42$4*("H@4$]34TE"24Q)5%D@3T8@
M4U5#2"!$04U!1T4N"B`J"B`J($!C871E9V]R>2`@(%1E<W1I;F<*("H@0'!A
M8VMA9V4@("`@4$A056YI=`H@*B!`875T:&]R("`@("!396)A<W1I86X@0F5R
M9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&-O<'ER:6=H
M="`@,C`P,BTR,#`U(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N
M+6)E<F=M86YN+F1E/@H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS
M;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N
M<V4*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%)E<&5A=&5D5&5S="YP:'`L
M=B`Q+C$S(#(P,#4O,3$O,3`@,#DZ-#<Z,30@<V5B87-T:6%N($5X<"`D"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]02%!5
M;FET"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XP+C`*("HO"@IR97%U:7)E7V]N8V4@)U!(4%5N:70O5&5S=$1E8V]R
M871O<BYP:'`G.PH*+RHJ"B`J($$@1&5C;W)A=&]R('1H870@<G5N<R!A('1E
M<W0@<F5P96%T961L>2X*("H*("H@2&5R92!I<R!A;B!E>&%M<&QE.@H@*@H@
M*B`\8V]D93X*("H@/#]P:'`*("H@<F5Q=6ER95]O;F-E("=02%!5;FET+G!H
M<"<["B`J(')E<75I<F5?;VYC92`G4$A056YI="]297!E871E9%1E<W0N<&AP
M)SL*("H*("H@8VQA<W,@36%T:%1E<W0@97AT96YD<R!02%!5;FET7U1E<W1#
M87-E('L*("H@("`@('9A<B`D9E9A;'5E,3L*("H@("`@('9A<B`D9E9A;'5E
M,CL*("H*("H@("`@(&9U;F-T:6]N($UA=&A497-T*"1N86UE*2!["B`J("`@
M("`@("`@)'1H:7,M/E!(4%5N:71?5&5S=$-A<V4H)&YA;64I.PH@*B`@("`@
M?0H@*@H@*B`@("`@9G5N8W1I;VX@<V5T57`H*2!["B`J("`@("`@("`@)'1H
M:7,M/F9686QU93$@/2`R.PH@*B`@("`@("`@("1T:&ES+3YF5F%L=64R(#T@
M,SL*("H@("`@('T*("H*("H@("`@(&9U;F-T:6]N('1E<W1!9&0H*2!["B`J
M("`@("`@("`@)'1H:7,M/F%S<V5R=%1R=64H)'1H:7,M/F9686QU93$@*R`D
M=&AI<RT^9E9A;'5E,B`]/2`U*3L*("H@("`@('T*("H@?0H@*@H@*B`D<W5I
M=&4@/2!N97<@4$A056YI=%]497-T4W5I=&4["B`J"B`J("1S=6ET92T^861D
M5&5S="@*("H@("!N97<@4$A056YI=%]297!E871E9%1E<W0H"B`J("`@("!N
M97<@36%T:%1E<W0H)W1E<W1!9&0G*2P*("H@("`@(#$P"B`J("`@*0H@*B`I
M.PH@*@H@*B`D<F5S=6QT(#T@4$A056YI=#HZ<G5N*"1S=6ET92D["B`J('!R
M:6YT("1R97-U;'0M/G1O4W1R:6YG*"D["B`J(#\^"B`J(#PO8V]D93X*("H*
M("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@*B!`<&%C:V%G92`@("!02%!5;FET
M"B`J($!A=71H;W(@("`@(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T
M:6%N+6)E<F=M86YN+F1E/@H@*B!`8V]P>7)I9VAT("`R,#`R+3(P,#4@4V5B
M87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J
M($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS
M97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@
M("!296QE87-E.B`Q+C,N,@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4$A056YI=`H@*B!`<VEN8V4@("`@("!#;&%S<R!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C`N,`H@*B\*8VQA<W,@4$A056YI
M=%]297!E871E9%1E<W0@97AT96YD<R!02%!5;FET7U1E<W1$96-O<F%T;W(@
M>PH@("`@+RHJ"B`@("`@*B!`=F%R("`@(&EN=&5G97(*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]T:6UE<U)E<&5A="`](#$[
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`
M<&%R86T@(&]B:F5C=`H@("`@("H@0'!A<F%M("!I;G1E9V5R"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!02%!5;FET7U)E
M<&5A=&5D5&5S="@F)'1E<W0L("1T:6UE<U)E<&5A="`](#$I('L*("`@("`@
M("`D=&AI<RT^4$A056YI=%]497-T1&5C;W)A=&]R*"1T97-T*3L*("`@("`@
M("`D=&AI<RT^7W1I;65S4F5P96%T(#T@)'1I;65S4F5P96%T.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0V]U;G1S('1H92!N=6UB97(@;V8@=&5S="!C87-E
M<R!T:&%T"B`@("`@*B!W:6QL(&)E(')U;B!B>2!T:&ES('1E<W0N"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G1E9V5R"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!C;W5N=%1E<W1#87-E<R@I('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]T:6UE<U)E<&5A="`J("1T:&ES+3Y?=&5S
M="T^8V]U;G1497-T0V%S97,H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)U
M;G,@=&AE(&1E8V]R871E9"!T97-T(&%N9"!C;VQL96-T<R!T:&4*("`@("`J
M(')E<W5L="!I;B!A(%1E<W1297-U;'0N"B`@("`@*@H@("`@("H@0'!A<F%M
M("!O8FIE8W0*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`86)S=')A
M8W0*("`@("`J+PH@("`@9G5N8W1I;VX@<G5N*"8D<F5S=6QT*2!["B`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@)'1H:7,M/E]T:6UE<U)E<&5A=#L@)&DK
M*RD@>PH@("`@("`@("`@("`D=&AI<RT^7W1E<W0M/G)U;B@D<F5S=6QT*3L*
M("`@("`@("!]"B`@("!]"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@
M=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J(&,M:&%N9VEN
M9RUC;VUM96YT+65N9&5R+7`Z(&YI;`H@*B!%;F0Z"B`J+PH_/@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]0
M2%!5;FET+U-K96QE=&]N+G!H<```````````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`S-#(P-0`Q,#4Q-30S,S<S-P`P,C(S-S<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RH@=FEM.B!S
M970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T
M;W`]-#H@*B\*"B\J*@H@*B!02%`@5F5R<VEO;B`T"B`J"B`J($-O<'ER:6=H
M="`H8RD@,C`P,BTR,#`U+"!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S
M=&EA;BUB97)G;6%N;BYD93XN"B`J($%L;"!R:6=H=',@<F5S97)V960N"B`J
M"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA
M<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M;V1I9FEC871I;VXL(&%R
M92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I
M=&EO;G,*("H@87)E(&UE=#H*("H*("H@("`J(%)E9&ES=')I8G5T:6]N<R!O
M9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT
M"B`J("`@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T
M:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J(`H@*B`@("H@4F5D:7-T<FEB
M=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V
M92!C;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I
M=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;@H@*B`@("`@
M=&AE(&1O8W5M96YT871I;VX@86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V
M:61E9"!W:71H('1H90H@*B`@("`@9&ES=')I8G5T:6]N+@H@*@H@*B`@("H@
M3F5I=&AE<B!T:&4@;F%M92!O9B!396)A<W1I86X@0F5R9VUA;FX@;F]R('1H
M92!N86UE<R!O9B!H:7,*("H@("`@(&-O;G1R:6)U=&]R<R!M87D@8F4@=7-E
M9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C=',@9&5R:79E9`H@*B`@
M("`@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I;W(@
M=W)I='1E;B!P97)M:7-S:6]N+@H@*@H@*B!42$E3(%-/1E1705)%($E3(%!2
M3U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@0T].5%))0E54
M3U)3"B`J(")!4R!)4R(@04Y$($%.62!%6%!215-3($]2($E-4$Q)140@5T%2
M4D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4"B`J($Q)34E4140@5$\L(%1(
M12!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519($%.1"!&
M251.15-3"B`J($9/4B!!(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!
M24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%"B`J($-/4%E224=(5"!/5TY%
M4B!/4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)
M3D1)4D5#5"P*("H@24Y#241%3E1!3"P@4U!%0TE!3"P@15A%35!,05)9+"!/
M4B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP*("H@0E54($Y/
M5"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!354)35$E4551%($=/3T13
M($]2(%-%4E9)0T53.PH@*B!,3U-3($]&(%5312P@1$%402P@3U(@4%)/1DE4
M4SL@3U(@0E5324Y%4U,@24Y415)255!424].*2!(3U=%5D52"B`J($-!55-%
M1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X@
M0T].5%)!0U0L(%-44DE#"B`J($Q)04))3$E462P@3U(@5$]25"`H24Y#3%5$
M24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E."B`J($%.
M62!705D@3U54($]&(%1(12!54T4@3T8@5$A)4R!33T945T%212P@159%3B!)
M1B!!1%9)4T5$($]&(%1(10H@*B!03U-324))3$E462!/1B!354-(($1!34%'
M12X*("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@*B!`<&%C:V%G92`@("!0
M2%!5;FET"B`J($!A=71H;W(@("`@(%-C;W1T($UA='1O8VMS(#QS8V]T=$!C
M<FES<V-O='0N8V]M/@H@*B!`8V]P>7)I9VAT("`R,#`R+3(P,#4@4V5B87-T
M:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O
M8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@("!#
M5E,Z("1)9#H@4VME;&5T;VXN<&AP+'8@,2XX(#(P,#4O,3$O,3`@,#DZ-#<Z
M,30@<V5B87-T:6%N($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]02%!5;FET"B`J($!S:6YC92`@("`@($9I;&4@
M879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XQ+C`*("HO"@HO*BH*("H@0VQA
M<W,@9F]R(&-R96%T:6YG(&$@4$A056YI=%]497-T0V%S92!S:V5L971O;B!F
M:6QE+@H@*@H@*B!4:&ES(&-L87-S('=I;&P@=&%K92!A(&-L87-S;F%M92!A
M<R!A('!A<F%M971E<B!O;B!C;VYS=')U8W1I;VX@86YD('=I;&P*("H@8W)E
M871E(&$@4$A0(&9I;&4@=&AA="!C;VYT86EN<R!T:&4@<VME;&5T;VX@;V8@
M82!02%!5;FET7U1E<W1#87-E"B`J('-U8F-L87-S+B!4:&4@=&5S="!C87-E
M('=I;&P@8V]N=&%I;B!A('1E<W0@9F]R96%C:"!M971H;V0@;V8@=&AE(&-L
M87-S+@H@*B!-971H;V1S(&]F('1H92!P87)E;G0@8VQA<W,@=VEL;"P@8GD@
M9&5F875L="P@8F4@97AC;'5D960@9G)O;2!T:&4@=&5S=`H@*B!C;&%S<RX@
M4&%S<VEN9R!A;F0@;W!T:6]N86P@8V]N<W1R=6-T:6]N('!A<F%M971E<B!W
M:6QL(&EN8VQU9&4@=&AE;2X*("H*("H@17AA;7!L90H@*@H@*B`@(#P_<&AP
M"B`J("`@<F5Q=6ER95]O;F-E("=02%!5;FET+U-K96QE=&]N+G!H<"<["B`J
M("`@)'!S(#T@;F5W(%!(4%5N:71?4VME;&5T;VXH)U!(4%5N:71?4VME;&5T
M;VXG+"`G4$A056YI="]3:V5L971O;BYP:'`G*3L*("H*("H@("`O+R!'96YE
M<F%T92!T:&4@=&5S="!C;&%S<RX*("H@("`O+R!$969A=6QT('-E='1I;F=S
M('=I;&P@;F]T(&EN8VQU9&4@86YY('!A<F5N="!C;&%S<R!M971H;V1S+"!B
M=70*("H@("`O+R!W:6QL(&EN8VQU9&4@<')I=F%T92!M971H;V1S+@H@*B`@
M("1P<RT^8W)E871E5&5S=$-L87-S*"D["B`J"B`J("`@+R\@5W)I=&4@=&AE
M(&YE=R!T97-T(&-L87-S('1O(&9I;&4N"B`J("`@+R\@0GD@9&5F875L="P@
M8V]D92!T;R!R=6X@=&AE('1E<W0@=VEL;"!B92!I;F-L=61E9"X*("H@("`D
M<',M/G=R:71E5&5S=$-L87-S*"D["B`J("`@/SX*("H*("H@3F]W(&]P96X@
M=&AE('-K96QE=&]N(&-L87-S(&%N9"!F:6QL(&EN('1H92!D971A:6QS+@H@
M*B!)9B!Y;W4@<G5N('1H92!T97-T(&%S(&ES+"!A;&P@=&5S=',@=VEL;"!F
M86EL(&%N9`H@*B!Y;W4@=VEL;"!S964@<&QE;G1Y(&]F('5N9&5F:6YE9"!C
M;VYS=&%N="!E<G)O<G,N"B`J"B`J($!C871E9V]R>2`@(%1E<W1I;F<*("H@
M0'!A8VMA9V4@("`@4$A056YI=`H@*B!`875T:&]R("`@("!38V]T="!-871T
M;V-K<R`\<V-O='1`8W)I<W-C;W1T+F-O;3X*("H@0&-O<'ER:6=H="`@,C`P
M,BTR,#`U(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M
M86YN+F1E/@H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N
M;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@
M0'9E<G-I;VX@("`@4F5L96%S93H@,2XS+C(*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!(4%5N:70*("H@0'-I;F-E("`@
M("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XQ+C`*("HO"F-L
M87-S(%!(4%5N:71?4VME;&5T;VX@>PH@("`@+RHJ"B`@("`@*B!0871H('1O
M('1H92!C;&%S<R!F:6QE('1O(&-R96%T92!A('-K96QE=&]N(&9O<BX*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D8VQA<W-0871H.PH*
M("`@("\J*@H@("`@("H@5&AE(&YA;64@;V8@=&AE(&-L87-S"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&-L87-S3F%M93L*"B`@("`O
M*BH*("`@("`J(%!A=&@@=&\@=&AE(&-O;F9I9W5R871I;VX@9FEL92!N965D
M960@8GD@8VQA<W,@=&\@=&5S="X*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D8V]N9FEG1FEL93L*"B`@("`O*BH*("`@("`J(%=H971H
M97(@;W(@;F]T('1O(&EN8VQU9&4@=&AE(&UE=&AO9',@;V8@=&AE('!A<F5N
M="!C;&%S<R!W:&5N('1E<W1I;F<N"B`@("`@*B!`=F%R(&)O;VQE86X*("`@
M("`J+PH@("`@=F%R("1I;F-L=61E4&%R96YT<SL*"B`@("`O*BH*("`@("`J
M(%=H971H97(@;W(@;F]T('1O('1E<W0@<')I=F%T92!M971H;V1S+@H@("`@
M("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D:6YC;'5D95!R:79A
M=&4["@H@("`@+RHJ"B`@("`@*B!4:&4@=&5S="!C;&%S<R!T:&%T('=I;&P@
M8F4@8W)E871E9"X*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D=&5S=$-L87-S.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N(%-E
M=',@=&AE(&-L87-S(&UE;6)E<G,@86YD(&-H96-K('1H870@=&AE(&-L87-S
M"B`@("`@*B!T;R!T97-T(&ES(&%C8V5S<VEB;&4N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2`@<W1R:6YG("`D8VQA<W-.
M86UE"B`@("`@*B!`<&%R86T@('-T<FEN9R`@)&-L87-S4&%T:`H@("`@("H@
M0'!A<F%M("!B;V]L96%N("1I;F-L=61E4&%R96YT<R!7:&5T97(@=&\@:6YC
M;'5D92!T:&4@<&%R96YT)W,@;65T:&]D<R!I;B!T:&4@=&5S="X*("`@("`J
M($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!02%!5;FET7U-K
M96QE=&]N*"1C;&%S<TYA;64L("1C;&%S<U!A=&@L("1I;F-L=61E4&%R96YT
M<R`]($9!3%-%+"`D:6YC;'5D95!R:79A=&4@/2!44E5%*2!["B`@("`@("`@
M+R\@4V5T('5P('1H92!M96UB97)S+@H@("`@("`@(&EF("A`:7-?<F5A9&%B
M;&4H)&-L87-S4&%T:"DI('L*("`@("`@("`@("`@)'1H:7,M/F-L87-S3F%M
M92`]("1C;&%S<TYA;64["B`@("`@("`@("`@("1T:&ES+3YC;&%S<U!A=&@@
M/2`D8VQA<W-0871H.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T
M:&ES+3Y?:&%N9&QE17)R;W)S*"1C;&%S<U!A=&@@+B`G(&ES(&YO="!R96%D
M86)L92X@0V%N;F]T(&-R96%T92!T97-T(&-L87-S+B<I.PH@("`@("`@('T*
M"B`@("`@("`@+R\@1&\@=V4@=V%N="!T;R!I;F-L=61E('!A<F5N="!M971H
M;V1S/PH@("`@("`@("1T:&ES+3YI;F-L=61E4&%R96YT<R`]("1I;F-L=61E
M4&%R96YT<SL*"B`@("`@("`@+R\@1&\@=V4@=V%N="!T;R!A;&QO=R!P<FEV
M871E(&UE=&AO9',_"B`@("`@("`@)'1H:7,M/FEN8VQU9&50<FEV871E(#T@
M)&EN8VQU9&50<FEV871E.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AE(&-L
M87-S('1O('1E<W0@;6%Y(')E<75I<F4@82!S<&5C:6%L(&-O;F9I9R!F:6QE
M(&)E9F]R92!I="!C86X@8F4*("`@("`J(&EN<W1A;G1I871E9"X@5&AI<R!M
M971H;V0@;&5T<R!Y;W4@<V5T('1H870@9FEL92X*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M("!S=')I;F<@)&-O;F9I9U!A
M=&@*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!S
M971#;VYF:6=&:6QE*"1C;VYF:6=&:6QE*2!["B`@("`@("`@+R\@0VAE8VL@
M=&AA="!T:&4@9FEL92!I<R!R96%D86)L90H@("`@("`@(&EF("A`:7-?<F5A
M9&%B;&4H)&-O;F9I9T9I;&4I*2!["B`@("`@("`@("`@("1T:&ES+3YC;VYF
M:6=&:6QE(#T@)&-O;F9I9T9I;&4["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'1H:7,M/E]H86YD;&5%<G)O<G,H)&-O;F9I9T9I;&4@+B`G(&ES
M(&YO="!R96%D86)L92X@0V%N;F]T(&-R96%T92!T97-T(&-L87-S+B<I.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!T:&4@8V]D
M92!T:&%T('=I;&P@8F4@=&AE('-K96QE=&]N(&]F('1H92!T97-T(&-A<V4N
M"B`@("`@*@H@("`@("H@5&AE('1E<W0@8V%S92!M=7-T(&AA=F4@82!C;'-S
M(&1E9FEN:71I;VXL(&]N92!V87(L(&$@8V]N<W1R=6-T;W(*("`@("`J('-E
M=%5P+"!T96%R1&]W;BP@86YD(&UE=&AO9',N($]P=&EO;F%L;'D@86YD(&)Y
M(&1E9F%U;'0@=&AE(&-O9&4*("`@("`J('1O(')U;B!T:&4@=&5S="!I<R!A
M9&1E9"!W:&5N('1H92!C;&%S<R!I<R!W<FET=&5N('1O(&9I;&4N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2`@;F]N90H@
M("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T
M951E<W1#;&%S<R@I('L*("`@("`@("`O+R!);G-T86YT:6%T92!T:&4@;V)J
M96-T+@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^8V]N9FEG1FEL92DI('L*
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("1T:&ES+3YC;VYF:6=&:6QE.PH@
M("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E("1T:&ES+3YC;&%S<U!A
M=&@["@H@("`@("`@("\O($=E="!T:&4@;65T:&]D<RX*("`@("`@("`D8VQA
M<W--971H;V1S(#T@9V5T7V-L87-S7VUE=&AO9',H)'1H:7,M/F-L87-S3F%M
M92D["@H@("`@("`@("\O(%)E;6]V92!T:&4@<&%R96YT(&UE=&AO9',@:68@
M;F5E9&5D+@H@("`@("`@(&EF("@A)'1H:7,M/FEN8VQU9&5087)E;G1S*2![
M"B`@("`@("`@("`@("1P87)E;G1-971H;V1S(#T@9V5T7V-L87-S7VUE=&AO
M9',H9V5T7W!A<F5N=%]C;&%S<R@D=&AI<RT^8VQA<W-.86UE*2D["@H@("`@
M("`@("`@("!I9B`H8V]U;G0H)'!A<F5N=$UE=&AO9',I*2!["B`@("`@("`@
M("`@("`@("`D8VQA<W--971H;V1S(#T@87)R87E?9&EF9B@D8VQA<W--971H
M;V1S+"`D<&%R96YT365T:&]D<RD["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("\O($-R96%T92!T:&4@8VQA<W,@9&5F:6YI=&EO;BP@8V]N
M<W1R=6-T;W(L('-E=%5P(&%N9"!T96%R1&]W;BX*("`@("`@("`D=&AI<RT^
M7V-R96%T941E9FEN:71I;VXH*3L*("`@("`@("`D=&AI<RT^7V-R96%T94-O
M;G-T<G5C=&]R*"D["B`@("`@("`@)'1H:7,M/E]C<F5A=&539715<%1E87)$
M;W=N*"D["@H@("`@("`@(&EF("AC;W5N="@D8VQA<W--971H;V1S*2D@>PH@
M("`@("`@("`@("`O+R!&;W)E86-H(&UE=&AO9"!C<F5A=&4@82!T97-T(&-A
M<V4N"B`@("`@("`@("`@(&9O<F5A8V@@*"1C;&%S<TUE=&AO9',@87,@)&UE
M=&AO9"D@>PH@("`@("`@("`@("`@("`@+R\@56YL97-S(&ET(&ES('1H92!C
M;VYS=')U8W1O<BX*("`@("`@("`@("`@("`@(&EF("AS=')C87-E8VUP*"1T
M:&ES+3YC;&%S<TYA;64L("1M971H;V0I("$]/2`P*2!["B`@("`@("`@("`@
M("`@("`@("\O($-H96-K(&9O<B!P<FEV871E(&UE=&AO9',N"B`@("`@("`@
M("`@("`@("`@(&EF("@A)'1H:7,M/FEN8VQU9&50<FEV871E("8F('-T<G!O
M<R@D;65T:&]D+"`G7R<I(#T]/2`P*2!["B`@("`@("`@("`@("`@("`@("`@
M("!C;VYT:6YU93L*("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?8W)E871E365T:&]D*"1M971H;V0I
M.PH@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($9I;FES(&]F9B!T:&4@
M8VQA<W,N"B`@("`@("`@)'1H:7,M/E]F:6YI<VA#;&%S<R@I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0W)E871E('1H92!C;&%S<R!D969I;FET:6]N+@H@
M("`@("H*("`@("`J(%1H92!D969I;FET:6]N(&-O;G-I<W0@;V8@82!H96%D
M97(@8V]M;65N="P@<F5Q=6ER92!S=&%T;65N=`H@("`@("H@9F]R(&=E='1I
M;F<@=&AE(%!(4%5N:70@9FEL92P@=&AE(&%C='5A;"!C;&%S<R!D969I;FET
M:6]N+`H@("`@("H@86YD('1H92!D969I;FET:6]N(&]F('1H92!C;&%S<R!M
M96UB97(@=F%R:6%B;&4N"B`@("`@*@H@("`@("H@06QL(&]F('1H92!C;V1E
M(&YE961E9"!F;W(@=&AE(&YE=R!C;&%S<R!I<R!S=&]R960@:6X@=&AE"B`@
M("`@*B!T97-T0VQA<W,@;65M8F5R+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H@0'!A<F%M("!N;VYE"B`@("`@*B!`<F5T=7)N('9O
M:60*("`@("`J+PH@("`@9G5N8W1I;VX@7V-R96%T941E9FEN:71I;VXH*2![
M"B`@("`@("`@+R\@0W)E871E(&AE861E<B!C;VUM96YT+@H@("`@("`@("1T
M:&ES+3YT97-T0VQA<W,@/0H@("`@("`@("`@(B\J*EQN(B`N"B`@("`@("`@
M("`B("H@4$A056YI="!T97-T(&-A<V4@9F]R("(@+B`D=&AI<RT^8VQA<W-.
M86UE("X@(EQN(B`N"B`@("`@("`@("`B("H@7&XB("X*("`@("`@("`@("(@
M*B!4:&4@;65T:&]D('-K96QE=&]N<R!B96QO=R!N965D('1O(&)E(&9I;&QE
M9"!I;B!W:71H(%QN(B`N"B`@("`@("`@("`B("H@<F5A;"!D871A('-O('1H
M870@=&AE('1E<W1S('=I;&P@<G5N(&-O<G)E8W1L>2X@4F5P;&%C92!<;B(@
M+@H@("`@("`@("`@(B`J(&%L;"!%6%!%0U1%1%]604P@86YD(%!!4D%-('-T
M<FEN9W,@=VET:"!R96%L(&1A=&$N(%QN(B`N"B`@("`@("`@("`B("H@7&XB
M("X*("`@("`@("`@("(@*B!#<F5A=&5D('=I=&@@4$A056YI=%]3:V5L971O
M;B!O;B`B("X@9&%T92@G62UM+60G*2`N(")<;B(@+@H@("`@("`@("`@(B`J
M+UQN(CL*"B`@("`@("`@+R\@061D('1H92!R97%U:7)E('-T871E;65N=',N
M"B`@("`@("`@)'1H:7,M/G1E<W1#;&%S<R`N/2`B<F5Q=6ER95]O;F-E("=0
M2%!5;FET+G!H<"<[7&XB.PH*("`@("`@("`O+R!!9&0@=&AE(&-L87-S(&1E
M9FEN:71I;VX@86YD('9A<FEA8FQE(&1E9FEN:71I;VXN"B`@("`@("`@)'1H
M:7,M/G1E<W1#;&%S<R`N/0H@("`@("`@("`@(F-L87-S("(@+B`D=&AI<RT^
M8VQA<W-.86UE("X@(E1E<W0@97AT96YD<R!02%!5;FET7U1E<W1#87-E('M<
M;EQN(B`N"B`@("`@("`@("`B("`@('9A<B!<)"(@+B`D=&AI<RT^8VQA<W-.
M86UE("X@(CM<;EQN(CL*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!T
M:&4@8VQA<W,@8V]N<W1R=6-T;W(N("A02%`T('-T>6QE*0H@("`@("H*("`@
M("`J(%1H92!C;VYS=')U8W1O<B!S:6UP;'D@8V%L;',@=&AE(%!(4%5N:71?
M5&5S=$-A<V4@;65T:&]D+@H@("`@("H@5&AI<R!C;V1E(&ES('1A:V5N(&9R
M;VT@=&AE(%!(4%5N:70@9&]C=6UE;G1A=&EO;BX*("`@("`J"B`@("`@*B!!
M;&P@;V8@=&AE(&-O9&4@;F5E9&5D(&9O<B!T:&4@;F5W(&-L87-S(&ES('-T
M;W)E9"!I;B!T:&4*("`@("`J('1E<W1#;&%S<R!M96UB97(N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@(&YO;F4*("`@
M("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!?8W)E871E
M0V]N<W1R=6-T;W(H*2!["B`@("`@("`@+R\@0W)E871E('1H92!T97-T(&-L
M87-S(&-O;G-T<G5C=&]R+@H@("`@("`@("1T:&ES+3YT97-T0VQA<W,N/0H@
M("`@("`@("`@(B`@("!F=6YC=&EO;B`B("X@)'1H:7,M/F-L87-S3F%M92`N
M(")497-T*%PD;F%M92E<;B(@+@H@("`@("`@("`@(B`@("![7&XB("X*("`@
M("`@("`@("(@("`@("`@(%PD=&AI<RT^4$A056YI=%]497-T0V%S92A<)&YA
M;64I.UQN(B`N"B`@("`@("`@("`B("`@('U<;EQN(CL*("`@('T*"B`@("`O
M*BH*("`@("`J($-R96%T92!S9715<"!A;F0@=&5A<D1O=VX@;65T:&]D<RX*
M("`@("`J"B`@("`@*B!4:&4@<V5T57`@;65T:&]D(&-R96%T97,@=&AE(&EN
M<W1A;F-E(&]F('1H92!O8FIE8W0@=&\@=&5S="X*("`@("`J(%1H92!T96%R
M1&]W;B!M971H;V0@<F5L96%S97,@=&AE(&EN<W1A;F-E+@H@("`@("H@5&AI
M<R!C;V1E(&ES('1A:V5N(&9R;VT@=&AE(%!(4%5N:70@9&]C=6UE;G1A=&EO
M;BX*("`@("`J"B`@("`@*B!!;&P@;V8@=&AE(&-O9&4@;F5E9&5D(&9O<B!T
M:&4@;F5W(&-L87-S(&ES('-T;W)E9"!I;B!T:&4*("`@("`J('1E<W1#;&%S
M<R!M96UB97(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*B!`<&%R86T@(&YO;F4*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@
M("!F=6YC=&EO;B!?8W)E871E4V5T57!496%R1&]W;B@I('L*("`@("`@("`O
M+R!#<F5A=&4@=&AE('-E=%5P(&UE=&AO9"X*("`@("`@("`D=&AI<RT^=&5S
M=$-L87-S("X]"B`@("`@("`@("`B("`@(&9U;F-T:6]N('-E=%5P*"E<;B(@
M+@H@("`@("`@("`@(B`@("![7&XB.PH*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/F-O;F9I9T9I;&4I*2!["B`@("`@("`@("`@("1T:&ES+3YT97-T0VQA
M<W,@+CT*("`@("`@("`@("`@(B`@("`@("`@<F5Q=6ER95]O;F-E("<B("X@
M)'1H:7,M/F-O;F9I9T9I;&4@+B`B)SM<;B(["B`@("`@("`@?0H*("`@("`@
M("`D=&AI<RT^=&5S=$-L87-S("X]"B`@("`@("`@("`B("`@("`@("!R97%U
M:7)E7V]N8V4@)R(@+B`D=&AI<RT^8VQA<W-0871H("X@(B<[7&XB("X*("`@
M("`@("`@("(@("`@("`@(%PD=&AI<RT^(B`N("1T:&ES+3YC;&%S<TYA;64@
M+B`B(#TF(&YE=R`B("X@)'1H:7,M/F-L87-S3F%M92`N("(H4$%204TI.UQN
M(B`N"B`@("`@("`@("`B("`@('U<;EQN(CL*"B`@("`@("`@+R\@0W)E871E
M('1H92!T96%R1&]W;B!M971H;V0N"B`@("`@("`@)'1H:7,M/G1E<W1#;&%S
M<R`N/0H@("`@("`@("`@(B`@("!F=6YC=&EO;B!T96%R1&]W;B@I7&XB("X*
M("`@("`@("`@("(@("`@>UQN(B`N"B`@("`@("`@("`B("`@("`@("!U;G-E
M="A<)'1H:7,M/B(@+B`D=&AI<RT^8VQA<W-.86UE("X@(BD[7&XB("X*("`@
M("`@("`@("(@("`@?5QN7&XB.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E
M871E(&$@8F%S:6,@<VME;&5T;VX@9F]R('1E<W0@;65T:&]D<RX*("`@("`J
M"B`@("`@*B!4:&ES(&-O9&4@:7,@=&%K96X@9G)O;2!T:&4@4$A056YI="!D
M;V-U;65N=&%T:6]N+@H@("`@("H*("`@("`J($%L;"!O9B!T:&4@8V]D92!N
M965D960@9F]R('1H92!N97<@8VQA<W,@:7,@<W1O<F5D(&EN('1H90H@("`@
M("H@=&5S=$-L87-S(&UE;6)E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J($!P87)A;2`@;F]N90H@("`@("H@0')E='5R;B!V;VED
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C<F5A=&5-971H;V0H)&UE=&AO9$YA
M;64I('L*("`@("`@("`O+R!#<F5A=&4@82!T97-T(&UE=&AO9"X*("`@("`@
M("`D=&AI<RT^=&5S=$-L87-S("X]"B`@("`@("`@("`B("`@(&9U;F-T:6]N
M('1E<W0B("X@)&UE=&AO9$YA;64@+B`B*"E<;B(@+@H@("`@("`@("`@(B`@
M("![7&XB("X*("`@("`@("`@("(@("`@("`@(%PD<F5S=6QT("`@/2!<)'1H
M:7,M/B(@+B`D=&AI<RT^8VQA<W-.86UE("X@(BT^(B`N("1M971H;V1.86UE
M("X@(BA005)!32D[7&XB("X*("`@("`@("`@("(@("`@("`@(%PD97AP96-T
M960@/2!%6%!%0U1%1%]604P[7&XB("X*("`@("`@("`@("(@("`@("`@(%PD
M=&AI<RT^87-S97)T17%U86QS*%PD97AP96-T960L(%PD<F5S=6QT*3M<;B(@
M+@H@("`@("`@("`@(B`@("!]7&Y<;B(["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!9&0@=&AE(&-L;W-I;F<@8G)A8V4@;F5E9&5D(&9O<B!A('!R;W!E<B!C
M;&%S<R!D969I;FET:6]N+@H@("`@("H*("`@("`J($%L;"!O9B!T:&4@8V]D
M92!N965D960@9F]R('1H92!N97<@8VQA<W,@:7,@<W1O<F5D(&EN('1H90H@
M("`@("H@=&5S=$-L87-S(&UE;6)E<BX*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J($!P87)A;2`@;F]N90H@("`@("H@0')E='5R;B!V
M;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(%]F:6YI<VA#;&%S<R@I('L*("`@
M("`@("`O+R!#;&]S92!O9F8@=&AE(&-L87-S+@H@("`@("`@("1T:&ES+3YT
M97-T0VQA<W,N/2`B?5QN(CL*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T
M92!T:&4@8V]D92!T:&%T('=I;&P@86-T=6%L;'D@<G5N('1H92!T97-T+@H@
M("`@("H*("`@("`J(%1H:7,@8V]D92!I<R!A9&1E9"!B>2!D969A=6QT('-O
M('1H870@=&AE('1E<W0@8V%N(&)E(')U;@H@("`@("H@:G5S="!B>2!R=6YN
M:6YG('1H92!F:6QE+B!4;R!H879E(&ET(&YO="!A9&1E9"!P87-S(&9A;'-E
M"B`@("`@*B!A<R!T:&4@<V5C;VYD('!A<F%M971E<B!T;R!T:&4@=W)I=&54
M97-T0VQA<W,@;65T:&]D+@H@("`@("H@5&AI<R!C;V1E(&ES('1A:V5N(&9R
M;VT@=&AE(%!(4%5N:70@9&]C=6UE;G1A=&EO;BX*("`@("`J"B`@("`@*B!!
M;&P@;V8@=&AE(&-O9&4@;F5E9&5D(&9O<B!T:&4@;F5W(&-L87-S(&ES('-T
M;W)E9"!I;B!T:&4*("`@("`J('1E<W1#;&%S<R!M96UB97(N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@(&YO;F4*("`@
M("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!?8W)E871E
M5&5S="@I('L*("`@("`@("`O+R!#<F5A=&4@82!C86QL('1O('1H92!T97-T
M+@H@("`@("`@("1T97-T(#T*("`@("`@("`@("(O+R!2=6YN:6YG('1H92!T
M97-T+EQN(B`N"B`@("`@("`@("`B7"1S=6ET92`@/2!N97<@4$A056YI=%]4
M97-T4W5I=&4H)R(@+B`D=&AI<RT^8VQA<W-.86UE("X@(E1E<W0G*3M<;B(@
M+@H@("`@("`@("`@(EPD<F5S=6QT(#T@4$A056YI=#HZ<G5N*%PD<W5I=&4I
M.UQN(B`N"B`@("`@("`@("`B96-H;R!<)')E<W5L="T^=&]3=')I;F<H*3M<
M;B(["@H@("`@("`@(')E='5R;B`D=&5S=#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%=R:71E('1H92!T97-T(&-L87-S('1O(&9I;&4N"B`@("`@*@H@("`@
M("H@5&AI<R!W:6QL('=R:71E('1H92!T97-T(&-L87-S(&-R96%T960@=7-I
M;F<@=&AE(&-R96%T951E<W1#;&%S<PH@("`@("H@;65T:&]D('1O(&$@9FEL
M92!C86QL960@/&-L87-S3F%M93Y497-T+G!H<"X@0GD@9&5F875L="!T:&4@
M9FEL90H@("`@("H@:7,@=W)I='1E;B!T;R!T:&4@8W5R<F5N="!D:7)E8W1O
M<GD@86YD('=I;&P@:&%V92!C;V1E('1O(')U;@H@("`@("H@=&AE('1E<W0@
M87!P96YD960@=&\@=&AE(&)O='1O;2!O9B!T:&4@9FEL92X*("`@("`J"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M("!S=')I;F<@("1D
M97-T:6YA=&EO;B!4:&4@9&ER96-T;W)Y('1O('=R:71E('1H92!F:6QE('1O
M+@H@("`@("H@0'!A<F%M("!B;V]L96%N("1A9&1497-T("`@("!7:&5T97(@
M=&\@861D('1H92!T97-T(')U;FYI;F<@8V]D92X*("`@("`J($!R971U<FX@
M=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET951E<W1#;&%S<R@D9&5S
M=&EN871I;VX@/2`G+B\G+"`D861D5&5S="`](%12544I('L*("`@("`@("`O
M+R!#:&5C:R!F;W(@<V]M971H:6YG('1O('=R:71E('1O(&9I;&4N"B`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^=&5S=$-L87-S*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7VAA;F1L945R<F]R<R@G3F]T:6YG('1O('=R:71E+B<L(%!(
M4%537U=!4DY)3D<I.PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*
M("`@("`@("`O+R!/<&5N('1H92!D97-T:6YA=&EO;B!F:6QE+@H@("`@("`@
M("1F<"`](&9O<&5N*"1D97-T:6YA=&EO;B`N("1T:&ES+3YC;&%S<TYA;64@
M+B`G5&5S="YP:'`G+"`G=R<I.PH@("`@("`@(&9W<FET92@D9G`L("(\/W!H
M<%QN(BD["@H@("`@("`@("\O(%=R:71E('1H92!T97-T(&-L87-S+@H@("`@
M("`@(&9W<FET92@D9G`L("1T:&ES+3YT97-T0VQA<W,I.PH*("`@("`@("`O
M+R!!9&0@=&AE(&-A;&P@=&\@=&5S="!T:&4@8VQA<W,@:6X@=&AE(&9I;&4@
M:68@=V4@=V5R92!A<VME9"!T;RX*("`@("`@("!I9B`H)&%D9%1E<W0I('L*
M("`@("`@("`@("`@9G=R:71E*"1F<"P@)'1H:7,M/E]C<F5A=&5497-T*"DI
M.PH@("`@("`@('T*"B`@("`@("`@+R\@0VQO<V4@=&AE(&9I;&4N"B`@("`@
M("`@9G=R:71E*"1F<"P@(C\^7&XB*3L*("`@("`@("!F8VQO<V4H)&9P*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($5R<F]R(&AA;F1L97(N"B`@("`@*@H@
M("`@("H@5&AI<R!M971H;V0@<VAO=6QD(&)E(')E=W)I='1E;B!T;R!U<V4@
M=&AE('!R969E<F5D(&5R<F]R"B`@("`@*B!H86YD;&EN9R!M971H;V0N("A0
M14%27T5R<F]R4W1A8VLI"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B!`<&%R86T@('-T<FEN9R`@)&UE<W-A9V4@5&AE(&5R<F]R(&UE
M<W-A9V4N"B`@("`@*B!`<&%R86T@(&EN=&5G97(@)'1Y<&4@("`@06X@:6YD
M:6-A=&EO;B!O9B!T:&4@<V5V97)I='D@;V8@=&AE(&5R<F]R+@H@("`@("H@
M0')E='5R;B!V;VED("`@("`@("`@("`@($-O9&4@;6%Y(&-A=7-E(%!(4"!T
M;R!E>&ET+@H@("`@("HO"B`@("!F=6YC=&EO;B!?:&%N9&QE17)R;W)S*"1M
M97-S86=E+"`D='EP92`]($5?55-%4E]%4E)/4BD@>PH@("`@("`@("\O($9O
M<B!N;W<@:G5S="!E8VAO('1H92!M97-S86=E+@H@("`@("`@(&5C:&\@)&UE
M<W-A9V4["@H@("`@("`@("\O($-H96-K('1O('-E92!I9B!W92!S:&]U;&0@
M<75I="X*("`@("`@("!I9B`H)'1Y<&4@/3T@15]54T527T524D]2*2!["B`@
M("`@("`@("`@(&5X:70["B`@("`@("`@?0H@("`@?0I]"@HO*@H@*B!,;V-A
M;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E
M=#H@-`H@*B!C+6AA;F=I;F<M8V]M;65N="UE;F1E<BUP.B!N:6P*("H@16YD
M.@H@*B\*/SX*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]02%!5;FET+U1E<W1#87-E+G!H<```````````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-C,Q,@`Q,#4Q-30S,S<S-P`P,C(S
M,C4`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I
M9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!02%`@5F5R<VEO;B`T
M"B`J"B`J($-O<'ER:6=H="`H8RD@,C`P,BTR,#`U+"!396)A<W1I86X@0F5R
M9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93XN"B`J($%L;"!R:6=H
M=',@<F5S97)V960N"B`J"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@
M<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M
M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@
M9F]L;&]W:6YG(&-O;F1I=&EO;G,*("H@87)E(&UE=#H*("H*("H@("`J(%)E
M9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@
M86)O=F4@8V]P>7)I9VAT"B`J("`@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C
M;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J(`H@
M*B`@("H@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P
M<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@=&AI
M<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA
M:6UE<B!I;@H@*B`@("`@=&AE(&1O8W5M96YT871I;VX@86YD+V]R(&]T:&5R
M(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H90H@*B`@("`@9&ES=')I8G5T
M:6]N+@H@*@H@*B`@("H@3F5I=&AE<B!T:&4@;F%M92!O9B!396)A<W1I86X@
M0F5R9VUA;FX@;F]R('1H92!N86UE<R!O9B!H:7,*("H@("`@(&-O;G1R:6)U
M=&]R<R!M87D@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C
M=',@9&5R:79E9`H@*B`@("`@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@
M<W!E8VEF:6,@<')I;W(@=W)I='1E;B!P97)M:7-S:6]N+@H@*@H@*B!42$E3
M(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$52
M4R!!3D0@0T].5%))0E543U)3"B`J(")!4R!)4R(@04Y$($%.62!%6%!215-3
M($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4"B`J
M($Q)34E4140@5$\L(%1(12!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!
M3E1!0DE,2519($%.1"!&251.15-3"B`J($9/4B!!(%!!4E1)0U5,05(@4%52
M4$]312!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%"B`J
M($-/4%E224=(5"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%($9/
M4B!!3ED@1$E214-4+"!)3D1)4D5#5"P*("H@24Y#241%3E1!3"P@4U!%0TE!
M3"P@15A%35!,05)9+"!/4B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ5
M1$E.1RP*("H@0E54($Y/5"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!3
M54)35$E4551%($=/3T13($]2(%-%4E9)0T53.PH@*B!,3U-3($]&(%5312P@
M1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)255!424].*2!(
M3U=%5D52"B`J($-!55-%1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"24Q)
M5%DL(%=(151(15(@24X@0T].5%)!0U0L(%-44DE#"B`J($Q)04))3$E462P@
M3U(@5$]25"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!
M4DE324Y'($E."B`J($%.62!705D@3U54($]&(%1(12!54T4@3T8@5$A)4R!3
M3T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(10H@*B!03U-324))3$E4
M62!/1B!354-(($1!34%'12X*("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@
M*B!`<&%C:V%G92`@("!02%!5;FET"B`J($!A=71H;W(@("`@(%-E8F%S=&EA
M;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`8V]P
M>7)I9VAT("`R,#`R+3(P,#4@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A
M<W1I86XM8F5R9VUA;FXN9&4^"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N
M;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@
M3&EC96YS90H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@5&5S=$-A<V4N<&AP
M+'8@,2XR,2`R,#`U+S$Q+S$P(#`Y.C0W.C$T('-E8F%S=&EA;B!%>'`@)`H@
M*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$A0
M56YI=`H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE
M87-E(#$N,"XP"B`J+PH*<F5Q=6ER95]O;F-E("=02%!5;FET+T%S<V5R="YP
M:'`G.PIR97%U:7)E7V]N8V4@)U!(4%5N:70O5&5S=%)E<W5L="YP:'`G.PH*
M+RHJ"B`J($$@5&5S=$-A<V4@9&5F:6YE<R!T:&4@9FEX='5R92!T;R!R=6X@
M;75L=&EP;&4@=&5S=',N"B`J"B`J(%1O(&1E9FEN92!A(%1E<W1#87-E"B`J
M"B`J("`@,2D@26UP;&5M96YT(&$@<W5B8VQA<W,@;V8@4$A056YI=%]497-T
M0V%S92X*("H@("`R*2!$969I;F4@:6YS=&%N8V4@=F%R:6%B;&5S('1H870@
M<W1O<F4@=&AE('-T871E(&]F('1H92!F:7AT=7)E+@H@*B`@(#,I($EN:71I
M86QI>F4@=&AE(&9I>'1U<F4@<W1A=&4@8GD@;W9E<G)I9&EN9R!S9715<"@I
M+@H@*B`@(#0I($-L96%N+75P(&%F=&5R(&$@=&5S="!B>2!O=F5R<FED:6YG
M('1E87)$;W=N*"DN"B`J"B`J($5A8V@@=&5S="!R=6YS(&EN(&ET<R!O=VX@
M9FEX='5R92!S;R!T:&5R92!C86X@8F4@;F\@<VED92!E9F9E8W1S"B`J(&%M
M;VYG('1E<W0@<G5N<RX*("H*("H@2&5R92!I<R!A;B!E>&%M<&QE.@H@*@H@
M*B`\8V]D93X*("H@/#]P:'`*("H@8VQA<W,@36%T:%1E<W0@97AT96YD<R!0
M2%!5;FET7U1E<W1#87-E('L*("H@("`@('9A<B`D9E9A;'5E,3L*("H@("`@
M('9A<B`D9E9A;'5E,CL*("H*("H@("`@(&9U;F-T:6]N($UA=&A497-T*"1N
M86UE*2!["B`J("`@("`@("`@)'1H:7,M/E!(4%5N:71?5&5S=$-A<V4H)&YA
M;64I.PH@*B`@("`@?0H@*@H@*B`@("`@9G5N8W1I;VX@<V5T57`H*2!["B`J
M("`@("`@("`@)'1H:7,M/F9686QU93$@/2`R.PH@*B`@("`@("`@("1T:&ES
M+3YF5F%L=64R(#T@,SL*("H@("`@('T*("H@?0H@*B`_/@H@*B`\+V-O9&4^
M"B`J"B`J($9O<B!E86-H('1E<W0@:6UP;&5M96YT(&$@;65T:&]D('=H:6-H
M(&EN=&5R86-T<R!W:71H('1H92!F:7AT=7)E+@H@*B!697)I9GD@=&AE(&5X
M<&5C=&5D(')E<W5L=',@=VET:"!A<W-E<G1I;VYS('-P96-I9FEE9"!B>2!C
M86QL:6YG"B`J(&%S<V5R="!W:71H(&$@8F]O;&5A;BX*("H*("H@/&-O9&4^
M"B`J(#P_<&AP"B`J(&9U;F-T:6]N('1E<W1087-S*"D@>PH@*B`@("`@)'1H
M:7,M/F%S<V5R=%1R=64H)'1H:7,M/F9686QU93$@*R`D=&AI<RT^9E9A;'5E
M,B`]/2`U*3L*("H@?0H@*B`_/@H@*B`\+V-O9&4^"B`J"B`J($!C871E9V]R
M>2`@(%1E<W1I;F<*("H@0'!A8VMA9V4@("`@4$A056YI=`H@*B!`875T:&]R
M("`@("!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N
M;BYD93X*("H@0&-O<'ER:6=H="`@,C`P,BTR,#`U(%-E8F%S=&EA;B!"97)G
M;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E
M;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@4F5L96%S93H@
M,2XS+C(*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+U!(4%5N:70*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I
M;F-E(%)E;&5A<V4@,2XP+C`*("HO"F-L87-S(%!(4%5N:71?5&5S=$-A<V4@
M97AT96YD<R!02%!5;FET7T%S<V5R="!["B`@("`O*BH*("`@("`J($!V87(@
M("`@8F]O;&5A;@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M('9A<B`D7V9A:6QE9"`]($9!3%-%.PH*("`@("\J*@H@("`@("H@5&AE(&YA
M;64@;V8@=&AE('1E<W0@8V%S92X*("`@("`J"B`@("`@*B!`=F%R("`@('-T
M<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D
M7VYA;64@/2`G)SL*"B`@("`O*BH*("`@("`J(%!(4%5N:71?5&5S=%)E<W5L
M="!O8FIE8W0*("`@("`J"B`@("`@*B!`=F%R("`@(&]B:F5C=`H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7W)E<W5L=#L*"B`@
M("`O*BH*("`@("`J($-O;G-T<G5C=',@82!T97-T(&-A<V4@=VET:"!T:&4@
M9VEV96X@;F%M92X*("`@("`J"B`@("`@*B!`<&%R86T@('-T<FEN9PH@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@4$A056YI
M=%]497-T0V%S92@D;F%M92`]($9!3%-%*2!["B`@("`@("`@:68@*"1N86UE
M("$]/2!&04Q312D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T3F%M92@D;F%M
M92D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0V]U;G1S('1H
M92!N=6UB97(@;V8@=&5S="!C87-E<R!E>&5C=71E9"!B>2!R=6XH5&5S=%)E
M<W5L="!R97-U;'0I+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@8V]U
M;G1497-T0V%S97,H*2!["B`@("`@("`@<F5T=7)N(#$["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'971S('1H92!N86UE(&]F(&$@5&5S=$-A<V4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$YA;64H*2!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?;F%M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)U;G,@
M=&AE('1E<W0@8V%S92!A;F0@8V]L;&5C=',@=&AE(')E<W5L=',@:6X@82!G
M:79E;B!497-T4F5S=6QT(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@
M(&]B:F5C=`H@("`@("H@0')E='5R;B!O8FIE8W0*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(')U;B@F)')E<W5L="D@>PH@
M("`@("`@("1T:&ES+3Y?<F5S=6QT(#T@)B1R97-U;'0["B`@("`@("`@)'1H
M:7,M/E]R97-U;'0M/G)U;B@D=&AI<RD["@H@("`@("`@(')E='5R;B`D=&AI
M<RT^7W)E<W5L=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)U;G,@=&AE(&)A
M<F4@=&5S="!S97%U96YC92X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!R=6Y"87)E*"D@>PH@("`@("`@("1T
M:&ES+3YS9715<"@I.PH@("`@("`@("1T:&ES+3YR=6Y497-T*"D["B`@("`@
M("`@)'1H:7,M/G1E87)$;W=N*"D["B`@("`@("`@)'1H:7,M/G!A<W,H*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($]V97)R:61E('1O(')U;B!T:&4@=&5S
M="!A;F0@87-S97)T(&ET<R!S=&%T92X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R;W1E8W1E9`H@("`@("HO"B`@("!F=6YC=&EO;B!R=6Y497-T*"D@>PH@
M("`@("`@(&-A;&Q?=7-E<E]F=6YC*`H@("`@("`@("`@87)R87DH"B`@("`@
M("`@("`@("8D=&AI<RP*("`@("`@("`@("`@)'1H:7,M/E]N86UE"B`@("`@
M("`@("`I"B`@("`@("`@*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@
M=&AE(&YA;64@;V8@82!497-T0V%S92X*("`@("`J"B`@("`@*B!`<&%R86T@
M('-T<FEN9PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T3F%M92@D;F%M92D@>PH@("`@("`@("1T:&ES+3Y?;F%M92`]
M("1N86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('-T<FEN
M9R!R97!R97-E;G1A=&EO;B!O9B!T:&4@=&5S="!C87-E+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!T;U-T<FEN9R@I('L*("`@("`@("!R971U<FX@
M)R<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@9&5F875L="!4
M97-T4F5S=6QT(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C
M=`H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J+PH@("`@9G5N8W1I
M;VX@)F-R96%T95)E<W5L="@I('L*("`@("`@("!R971U<FX@;F5W(%!(4%5N
M:71?5&5S=%)E<W5L=#L*("`@('T*"B`@("`O*BH*("`@("`J($9A:6QS(&$@
M=&5S="!W:71H('1H92!G:79E;B!M97-S86=E+@H@("`@("H*("`@("`J($!P
M87)A;2`@<W1R:6YG"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("HO
M"B`@("!F=6YC=&EO;B!F86EL*"1M97-S86=E(#T@)R<I('L*("`@("`@("!I
M9B`H9G5N8W1I;VY?97AI<W1S*"=D96)U9U]B86-K=')A8V4G*2D@>PH@("`@
M("`@("`@("`D=')A8V4@/2!D96)U9U]B86-K=')A8V4H*3L*"B`@("`@("`@
M("`@(&EF("AI<W-E="@D=')A8V5;)S$G75LG9FEL92==*2D@>PH@("`@("`@
M("`@("`@("`@)&UE<W-A9V4@/2!S<')I;G1F*`H@("`@("`@("`@("`@("`@
M("`B)7,@:6X@)7,Z)7,B+`H*("`@("`@("`@("`@("`@("`@)&UE<W-A9V4L
M"B`@("`@("`@("`@("`@("`@("1T<F%C95LG,2==6R=F:6QE)UTL"B`@("`@
M("`@("`@("`@("`@("1T<F%C95LG,2==6R=L:6YE)UT*("`@("`@("`@("`@
M("`@("D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3Y?<F5S=6QT+3YA9&1&86EL=7)E*"1T:&ES+"`D;65S<V%G92D["B`@("`@
M("`@)'1H:7,M/E]F86EL960@/2!44E5%.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4&%S<V5S(&$@=&5S="X*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E
M8W1E9`H@("`@("HO"B`@("!F=6YC=&EO;B!P87-S*"D@>PH@("`@("`@(&EF
M("@A)'1H:7,M/E]F86EL960I('L*("`@("`@("`@("`@)'1H:7,M/E]R97-U
M;'0M/F%D9%!A<W-E9%1E<W0H)'1H:7,I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E=',@=7`@=&AE(&9I>'1U<F4L(&9O<B!E>&%M<&QE
M+"!O<&5N(&$@;F5T=V]R:R!C;VYN96-T:6]N+@H@("`@("H@5&AI<R!M971H
M;V0@:7,@8V%L;&5D(&)E9F]R92!A('1E<W0@:7,@97AE8W5T960N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J($!A8G-T<F%C=`H@
M("`@("HO"B`@("!F=6YC=&EO;B!S9715<"@I('L@+RH@86)S=')A8W0@*B\@
M?0H*("`@("\J*@H@("`@("H@5&5A<G,@9&]W;B!T:&4@9FEX='5R92P@9F]R
M(&5X86UP;&4L(&-L;W-E(&$@;F5T=V]R:R!C;VYN96-T:6]N+@H@("`@("H@
M5&AI<R!M971H;V0@:7,@8V%L;&5D(&%F=&5R(&$@=&5S="!I<R!E>&5C=71E
M9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("H@0&%B
M<W1R86-T"B`@("`@*B\*("`@(&9U;F-T:6]N('1E87)$;W=N*"D@>R`O*B!A
M8G-T<F%C="`J+R!]"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B
M+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J(&,M:&%N9VEN9RUC
M;VUM96YT+65N9&5R+7`Z(&YI;`H@*B!%;F0Z"B`J+PH_/@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+U!(4%5N:70O5&5S=$1E8V]R871O<BYP:'``````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P-C8V`#$P-3$U-#,S-S,W`#`R
M,S0P,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T
M=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%!(4"!697)S:6]N
M(#0*("H*("H@0V]P>7)I9VAT("AC*2`R,#`R+3(P,#4L(%-E8F%S=&EA;B!"
M97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/BX*("H@06QL(')I
M9VAT<R!R97-E<G9E9"X*("H*("H@4F5D:7-T<FEB=71I;VX@86YD('5S92!I
M;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T"B`J
M(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H
M92!F;VQL;W=I;F<@8V]N9&ET:6]N<PH@*B!A<F4@;65T.@H@*@H@*B`@("H@
M4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H
M92!A8F]V92!C;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@=&AI<R!L:7-T(&]F
M(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@
M"B`J("`@*B!2961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R
M97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T
M:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C
M;&%I;65R(&EN"B`J("`@("!T:&4@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H
M97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE"B`J("`@("!D:7-T<FEB
M=71I;VXN"B`J"B`J("`@*B!.96ET:&5R('1H92!N86UE(&]F(%-E8F%S=&EA
M;B!"97)G;6%N;B!N;W(@=&AE(&YA;65S(&]F(&AI<PH@*B`@("`@8V]N=')I
M8G5T;W)S(&UA>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92!P<F]D
M=6-T<R!D97)I=F5D"B`J("`@("!F<F]M('1H:7,@<V]F='=A<F4@=VET:&]U
M="!S<&5C:69I8R!P<FEO<B!W<FET=&5N('!E<FUI<W-I;VXN"B`J"B`J(%1(
M25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$
M15)3($%.1"!#3TY44DE"551/4E,*("H@(D%3($E3(B!!3D0@04Y9($584%)%
M4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0*
M("H@3$E-251%1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#
M2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,*("H@1D]2($$@4$%25$E#54Q!4B!0
M55)03U-%($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4*
M("H@0T]065))1TA4($]73D52($]2($-/3E1224)55$]24R!"12!,24%"3$4@
M1D]2($%.62!$25)%0U0L($E.1$E214-4+`H@*B!)3D-)1$5.5$%,+"!34$5#
M24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#
M3%5$24Y'+`H@*B!"550@3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&
M(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,["B`J($Q/4U,@3T8@55-%
M+"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI
M($A/5T5615(*("H@0T%54T5$($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)04))
M3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@4U1224,*("H@3$E!0DE,2519
M+"!/4B!43U)4("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I
M($%225-)3D<@24X*("H@04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3
M(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,
M2519($]&(%-50T@@1$%-04=%+@H@*@H@*B!`8V%T96=O<GD@("!497-T:6YG
M"B`J($!P86-K86=E("`@(%!(4%5N:70*("H@0&%U=&AO<B`@("`@4V5B87-T
M:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J($!C
M;W!Y<FEG:'0@(#(P,#(M,C`P-2!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E
M8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W
M=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)3
M1"!,:6-E;G-E"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!497-T1&5C;W)A
M=&]R+G!H<"QV(#$N,3<@,C`P-2\Q,2\Q,"`P.3HT-SHQ-"!S96)A<W1I86X@
M17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+U!(4%5N:70*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN
M8V4@4F5L96%S92`Q+C`N,`H@*B\*"G)E<75I<F5?;VYC92`G4$A056YI="]4
M97-T0V%S92YP:'`G.PIR97%U:7)E7V]N8V4@)U!(4%5N:70O5&5S=%-U:71E
M+G!H<"<["@II9B`H(69U;F-T:6]N7V5X:7-T<R@G:7-?82<I*2!["B`@("!R
M97%U:7)E7V]N8V4@)U!(4"]#;VUP870O1G5N8W1I;VXO:7-?82YP:'`G.PI]
M"@HO*BH*("H@02!$96-O<F%T;W(@9F]R(%1E<W1S+@H@*@H@*B!5<V4@5&5S
M=$1E8V]R871O<B!A<R!T:&4@8F%S92!C;&%S<R!F;W(@9&5F:6YI;F<@;F5W
M"B`J('1E<W0@9&5C;W)A=&]R<RX@5&5S="!D96-O<F%T;W(@<W5B8VQA<W-E
M<R!C86X@8F4@:6YT<F]D=6-E9`H@*B!T;R!A9&0@8F5H879I;W5R(&)E9F]R
M92!O<B!A9G1E<B!A('1E<W0@:7,@<G5N+@H@*@H@*B!`8V%T96=O<GD@("!4
M97-T:6YG"B`J($!P86-K86=E("`@(%!(4%5N:70*("H@0&%U=&AO<B`@("`@
M4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^
M"B`J($!C;W!Y<FEG:'0@(#(P,#(M,C`P-2!396)A<W1I86X@0F5R9VUA;FX@
M/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP
M:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N,RXR
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]0
M2%!5;FET"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!2
M96QE87-E(#$N,"XP"B`J+PIC;&%S<R!02%!5;FET7U1E<W1$96-O<F%T;W(@
M>PH@("`@+RHJ"B`@("`@*B!4:&4@5&5S="!T;R!B92!D96-O<F%T960N"B`@
M("`@*@H@("`@("H@0'9A<B`@("!O8FIE8W0*("`@("`J($!A8V-E<W,@<')O
M=&5C=&5D"B`@("`@*B\*("`@('9A<B`D7W1E<W0@/2!.54Q,.PH*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M("!O
M8FIE8W0*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%!(4%5N:71?5&5S=$1E8V]R871O<B@F)'1E<W0I('L*("`@("`@("!I
M9B`H:7-?;V)J96-T*"1T97-T*2`F)@H@("`@("`@("`@("`H:7-?82@D=&5S
M="P@)U!(4%5N:71?5&5S=$-A<V4G*2!\?`H@("`@("`@("`@("`@:7-?82@D
M=&5S="P@)U!(4%5N:71?5&5S=%-U:71E)RDI*2!["@H@("`@("`@("`@("`D
M=&AI<RT^7W1E<W0@/2`F)'1E<W0["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4G5N<R!T:&4@=&5S="!A;F0@8V]L;&5C=',@=&AE"B`@("`@
M*B!R97-U;'0@:6X@82!497-T4F5S=6QT+@H@("`@("H*("`@("`J($!P87)A
M;2`@;V)J96-T"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!B87-I8U)U;B@F)')E<W5L="D@>PH@("`@("`@("1T:&ES+3Y?
M=&5S="T^<G5N*"1R97-U;'0I.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]U
M;G1S('1H92!N=6UB97(@;V8@=&5S="!C87-E<R!T:&%T"B`@("`@*B!W:6QL
M(&)E(')U;B!B>2!T:&ES('1E<W0N"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G1E9V5R"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!C;W5N=%1E<W1#87-E<R@I('L*("`@("`@("!R971U<FX@)'1H:7,M
M/E]T97-T+3YC;W5N=%1E<W1#87-E<R@I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@=&5S="!T;R!B92!R=6XN"B`@("`@*@H@("`@("H@
M0')E='5R;B!O8FIE8W0*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N("9G971497-T*"D@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7W1E<W0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2=6YS('1H92!D96-O
M<F%T960@=&5S="!A;F0@8V]L;&5C=',@=&AE"B`@("`@*B!R97-U;'0@:6X@
M82!497-T4F5S=6QT+@H@("`@("H*("`@("`J($!P87)A;2`@;V)J96-T"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0&%B<W1R86-T"B`@("`@*B\*
M("`@(&9U;F-T:6]N(')U;B@F)')E<W5L="D@>R`O*B!A8G-T<F%C="`J+R!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<W1R:6YG(')E<')E<V5N=&%T
M:6]N(&]F('1H92!T97-T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!T
M;U-T<FEN9R@I('L*("`@("`@("!R971U<FX@)'1H:7,M/E]T97-T+3YT;U-T
M<FEN9R@I.PH@("`@?0I]"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A
M8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!C+6AA;F=I;F<M
M8V]M;65N="UE;F1E<BUP.B!N:6P*("H@16YD.@H@*B\*/SX*````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O4$A056YI="]497-T1F%I;'5R92YP:'``````````````````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#<V,S(`,3`U,34T,S,W,S<`,#(S,#0V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O
M9G1T86)S=&]P/30Z("HO"@HO*BH*("H@4$A0(%9E<G-I;VX@-`H@*@H@*B!#
M;W!Y<FEG:'0@*&,I(#(P,#(M,C`P-2P@4V5B87-T:6%N($)E<F=M86YN(#QS
M8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^+@H@*B!!;&P@<FEG:'1S(')E<V5R
M=F5D+@H@*@H@*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A
M;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D:69I8V%T
M:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN
M9R!C;VYD:71I;VYS"B`J(&%R92!M970Z"B`J"B`J("`@*B!2961I<W1R:6)U
M=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O
M<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N
M<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+@H@*B`*("H@("`J(%)E
M9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T
M:&4@86)O=F4@8V]P>7)I9VAT"B`J("`@("!N;W1I8V4L('1H:7,@;&ES="!O
M9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X*
M("H@("`@('1H92!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA
M;',@<')O=FED960@=VET:"!T:&4*("H@("`@(&1I<W1R:6)U=&EO;BX*("H*
M("H@("`J($YE:71H97(@=&AE(&YA;64@;V8@4V5B87-T:6%N($)E<F=M86YN
M(&YO<B!T:&4@;F%M97,@;V8@:&ES"B`J("`@("!C;VYT<FEB=71O<G,@;6%Y
M(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E('!R;V1U8W1S(&1E<FEV
M960*("H@("`@(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T('-P96-I9FEC
M('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H*("H@5$A)4R!33T945T%2
M12!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/
M3E1224)55$]24PH@*B`B05,@25,B($%.1"!!3ED@15A04D534R!/4B!)35!,
M245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5`H@*B!,24U)5$5$
M(%1/+"!42$4@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E4
M62!!3D0@1DE43D534PH@*B!&3U(@02!005)424-53$%2(%!54E!/4T4@05)%
M($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(10H@*B!#3U!94DE'
M2%0@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),12!&3U(@04Y9($1)
M4D5#5"P@24Y$25)%0U0L"B`J($E.0TE$14Y404PL(%-014-)04PL($5814U0
M3$%262P@3U(@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L"B`J
M($)55"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)5%54
M12!'3T]$4R!/4B!315)624-%4SL*("H@3$]34R!/1B!54T4L($1!5$$L($]2
M(%!23T9)5%,[($]2($)54TE.15-3($E.5$524E505$E/3BD@2$]7159%4@H@
M*B!#0553140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!72$54
M2$52($E.($-/3E1204-4+"!35%))0PH@*B!,24%"24Q)5%DL($]2(%1/4E0@
M*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D@05))4TE.1R!)
M3@H@*B!!3ED@5T%9($]55"!/1B!42$4@55-%($]&(%1(25,@4T]&5%=!4D4L
M($5614X@248@041625-%1"!/1B!42$4*("H@4$]34TE"24Q)5%D@3T8@4U5#
M2"!$04U!1T4N"B`J"B`J($!C871E9V]R>2`@(%1E<W1I;F<*("H@0'!A8VMA
M9V4@("`@4$A056YI=`H@*B!`875T:&]R("`@("!396)A<W1I86X@0F5R9VUA
M;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&-O<'ER:6=H="`@
M,C`P,BTR,#`U(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E
M<F=M86YN+F1E/@H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS;W5R
M8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*
M("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%1E<W1&86EL=7)E+G!H<"QV(#$N
M,3,@,C`P-2\Q,2\Q,"`P.3HT-SHQ-"!S96)A<W1I86X@17AP("0*("H@0&QI
M;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!(4%5N:70*
M("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q
M+C`N,`H@*B\*"B\J*@H@*B!!(%1E<W1&86EL=7)E(&-O;&QE8W1S(&$@9F%I
M;&5D('1E<W0@=&]G971H97(@=VET:"!T:&4@8V%U9VAT(&5X8V5P=&EO;BX*
M("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@*B!`<&%C:V%G92`@("!02%!5
M;FET"B`J($!A=71H;W(@("`@(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B
M87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`8V]P>7)I9VAT("`R,#`R+3(P,#4@
M4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^
M"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC
M96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO
M;B`@("!296QE87-E.B`Q+C,N,@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A
M<BYP:'`N;F5T+W!A8VMA9V4O4$A056YI=`H@*B!`<VEN8V4@("`@("!#;&%S
M<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C`N,`H@*B\*8VQA<W,@4$A0
M56YI=%]497-T1F%I;'5R92!["B`@("`O*BH*("`@("`J($!V87(@("`@;V)J
M96-T"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?
M9F%I;&5D5&5S=#L*"B`@("`O*BH*("`@("`J($!V87(@("`@<W1R:6YG"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?=&AR;W=N
M17AC97!T:6]N.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(%1E<W1&
M86EL=7)E('=I=&@@=&AE(&=I=F5N('1E<W0@86YD(&5X8V5P=&EO;BX*("`@
M("`J"B`@("`@*B!`<&%R86T@(&]B:F5C=`H@("`@("H@0'!A<F%M("!S=')I
M;F<*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%!(4%5N:71?5&5S=$9A:6QU<F4H)B1F86EL961497-T+"`F)'1H<F]W;D5X
M8V5P=&EO;BD@>PH@("`@("`@("1T:&ES+3Y?9F%I;&5D5&5S="`@("`@(#T@
M)B1F86EL961497-T.PH@("`@("`@("1T:&ES+3Y?=&AR;W=N17AC97!T:6]N
M(#T@)B1T:')O=VY%>&-E<'1I;VX["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M971S('1H92!F86EL960@=&5S="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B
M:F5C=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@)F9A:6QE9%1E<W0H*2!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9F%I
M;&5D5&5S=#L*("`@('T*"B`@("`O*BH*("`@("`J($=E=',@=&AE('1H<F]W
M;B!E>&-E<'1I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N("9T:')O
M=VY%>&-E<'1I;VXH*2!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&AR;W=N
M17AC97!T:6]N.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('-H
M;W)T(&1E<V-R:7!T:6]N(&]F('1H92!F86EL=7)E+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!T;U-T<FEN9R@I('L*("`@("`@("!R971U<FX@<W!R
M:6YT9B@*("`@("`@("`@(")497-T0V%S92`E<RT^)7,H*2!F86EL960Z("5S
M7&XB+`H*("`@("`@("`@(&=E=%]C;&%S<R@D=&AI<RT^7V9A:6QE9%1E<W0I
M+`H@("`@("`@("`@)'1H:7,M/E]F86EL961497-T+3YG971.86UE*"DL"B`@
M("`@("`@("`D=&AI<RT^7W1H<F]W;D5X8V5P=&EO;@H@("`@("`@("D["B`@
M("!]"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T
M"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J(&,M:&%N9VEN9RUC;VUM96YT+65N
M9&5R+7`Z(&YI;`H@*B!%;F0Z"B`J+PH_/@H`````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$A056YI="]497-T3&ES=&5N97(N
M<&AP````````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3$P-C4`,3`U,34T
M,S,W,S<`,#(S,C,W`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P
M/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@4$A0
M(%9E<G-I;VX@-`H@*@H@*B!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P-2P@4V5B
M87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^+@H@
M*B!!;&P@<FEG:'1S(')E<V5R=F5D+@H@*@H@*B!2961I<W1R:6)U=&EO;B!A
M;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I
M=&AO=70*("H@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D
M('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS"B`J(&%R92!M970Z"B`J
M"B`J("`@*B!2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R
M971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T:&ES
M(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I
M;65R+@H@*B`*("H@("`J(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R
M;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT"B`J("`@("!N
M;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W
M:6YG(&1I<V-L86EM97(@:6X*("H@("`@('1H92!D;V-U;65N=&%T:6]N(&%N
M9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4*("H@("`@
M(&1I<W1R:6)U=&EO;BX*("H*("H@("`J($YE:71H97(@=&AE(&YA;64@;V8@
M4V5B87-T:6%N($)E<F=M86YN(&YO<B!T:&4@;F%M97,@;V8@:&ES"B`J("`@
M("!C;VYT<FEB=71O<G,@;6%Y(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M
M;W1E('!R;V1U8W1S(&1E<FEV960*("H@("`@(&9R;VT@=&AI<R!S;V9T=V%R
M92!W:71H;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*
M("H*("H@5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))
M1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]24PH@*B`B05,@25,B($%.1"!!
M3ED@15A04D534R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@
M0E54($Y/5`H@*B!,24U)5$5$(%1/+"!42$4@24U03$E%1"!705)204Y42453
M($]&($U%4D-(04Y404))3$E462!!3D0@1DE43D534PH@*B!&3U(@02!005)4
M24-53$%2(%!54E!/4T4@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(
M04Q,(%1(10H@*B!#3U!94DE'2%0@3U=.15(@3U(@0T].5%))0E543U)3($)%
M($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L"B`J($E.0TE$14Y4
M04PL(%-014-)04PL($5814U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!
M1T53("A)3D-,541)3D<L"B`J($)55"!.3U0@3$E-251%1"!43RP@4%)/0U52
M14U%3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL*("H@3$]3
M4R!/1B!54T4L($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3($E.5$52
M4E505$E/3BD@2$]7159%4@H@*B!#0553140@04Y$($].($%.62!42$5/4ED@
M3T8@3$E!0DE,2519+"!72$542$52($E.($-/3E1204-4+"!35%))0PH@*B!,
M24%"24Q)5%DL($]2(%1/4E0@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]4
M2$525TE312D@05))4TE.1R!)3@H@*B!!3ED@5T%9($]55"!/1B!42$4@55-%
M($]&(%1(25,@4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!42$4*("H@
M4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N"B`J"B`J($!C871E9V]R>2`@
M(%1E<W1I;F<*("H@0'!A8VMA9V4@("`@4$A056YI=`H@*B!`875T:&]R("`@
M("!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD
M93X*("H@0&-O<'ER:6=H="`@,C`P,BTR,#`U(%-E8F%S=&EA;B!"97)G;6%N
M;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E
M+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%1E
M<W1,:7-T96YE<BYP:'`L=B`Q+C$R(#(P,#4O,3$O,3`@,#DZ-#<Z,34@<V5B
M87-T:6%N($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]02%!5;FET"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA
M8FQE('-I;F-E(%)E;&5A<V4@,2XP+C`*("HO"@HO*BH*("H@02!,:7-T96YE
M<B!F;W(@=&5S="!P<F]G<F5S<RX*("H*("H@2&5R92!I<R!A;B!E>&%M<&QE
M.@H@*@H@*B`\8V]D93X*("H@/#]P:'`*("H@<F5Q=6ER95]O;F-E("=02%!5
M;FET+G!H<"<["B`J(')E<75I<F5?;VYC92`G4$A056YI="]497-T3&ES=&5N
M97(N<&AP)SL*("H*("H@8VQA<W,@36%T:%1E<W0@97AT96YD<R!02%!5;FET
M7U1E<W1#87-E('L*("H@("`@('9A<B`D9E9A;'5E,3L*("H@("`@('9A<B`D
M9E9A;'5E,CL*("H*("H@("`@(&9U;F-T:6]N($UA=&A497-T*"1N86UE*2![
M"B`J("`@("`@("`@)'1H:7,M/E!(4%5N:71?5&5S=$-A<V4H)&YA;64I.PH@
M*B`@("`@?0H@*@H@*B`@("`@9G5N8W1I;VX@<V5T57`H*2!["B`J("`@("`@
M("`@)'1H:7,M/F9686QU93$@/2`R.PH@*B`@("`@("`@("1T:&ES+3YF5F%L
M=64R(#T@,SL*("H@("`@('T*("H*("H@("`@(&9U;F-T:6]N('1E<W1!9&0H
M*2!["B`J("`@("`@("`@)'1H:7,M/F%S<V5R=%1R=64H)'1H:7,M/F9686QU
M93$@*R`D=&AI<RT^9E9A;'5E,B`]/2`T*3L*("H@("`@('T*("H@?0H@*@H@
M*B!C;&%S<R!->4QI<W1E;F5R(&5X=&5N9',@4$A056YI=%]497-T3&ES=&5N
M97(@>PH@*B`@("`@9G5N8W1I;VX@861D17)R;W(H)B1T97-T+"`F)'0I('L*
M("H@("`@("`@("!P<FEN="`B37E,:7-T96YE<CHZ861D17)R;W(H*2!C86QL
M960N7&XB.PH@*B`@("`@?0H@*@H@*B`@("`@9G5N8W1I;VX@861D1F%I;'5R
M92@F)'1E<W0L("8D="D@>PH@*B`@("`@("`@('!R:6YT(")->4QI<W1E;F5R
M.CIA9&1&86EL=7)E*"D@8V%L;&5D+EQN(CL*("H@("`@('T*("H*("H@("`@
M(&9U;F-T:6]N(&5N9%1E<W0H)B1T97-T*2!["B`J("`@("`@("`@<')I;G0@
M(DUY3&ES=&5N97(Z.F5N9%1E<W0H*2!C86QL960N7&XB.PH@*B`@("`@?0H@
M*@H@*B`@("`@9G5N8W1I;VX@<W1A<G1497-T*"8D=&5S="D@>PH@*B`@("`@
M("`@('!R:6YT(")->4QI<W1E;F5R.CIS=&%R=%1E<W0H*2!C86QL960N7&XB
M.PH@*B`@("`@?0H@*B!]"B`J"B`J("1S=6ET92`](&YE=R!02%!5;FET7U1E
M<W13=6ET93L*("H@)'-U:71E+3YA9&1497-T*&YE=R!-871H5&5S="@G=&5S
M=$%D9"<I*3L*("H*("H@)')E<W5L="`](&YE=R!02%!5;FET7U1E<W1297-U
M;'0["B`J("1R97-U;'0M/F%D9$QI<W1E;F5R*&YE=R!->4QI<W1E;F5R*3L*
M("H*("H@)'-U:71E+3YR=6XH)')E<W5L="D["B`J('!R:6YT("1R97-U;'0M
M/G1O4W1R:6YG*"D["B`J(#\^"B`J(#PO8V]D93X*("H*("H@0&-A=&5G;W)Y
M("`@5&5S=&EN9PH@*B!`<&%C:V%G92`@("!02%!5;FET"B`J($!A=71H;W(@
M("`@(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN
M+F1E/@H@*B!`8V]P>7)I9VAT("`R,#`R+3(P,#4@4V5B87-T:6%N($)E<F=M
M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J($!L:6-E;G-E("`@
M(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N
M<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q
M+C,N,@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA
M9V4O4$A056YI=`H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN
M8V4@4F5L96%S92`Q+C`N,`H@*B\*8VQA<W,@4$A056YI=%]497-T3&ES=&5N
M97(@>PH@("`@+RHJ"B`@("`@*B!!;B!E<G)O<B!O8V-U<G)E9"X*("`@("`J
M"B`@("`@*B!`<&%R86T@(&]B:F5C=`H@("`@("H@0'!A<F%M("!O8FIE8W0*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`86)S=')A8W0*("`@("`J
M+PH@("`@9G5N8W1I;VX@861D17)R;W(H)B1T97-T+"`F)'0I('L@+RIA8G-T
M<F%C="`J+R!]"@H@("`@+RHJ"B`@("`@*B!!(&9A:6QU<F4@;V-C=7)R960N
M"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0*("`@("`J($!P87)A;2`@
M;V)J96-T"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0&%B<W1R86-T
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$9A:6QU<F4H)B1T97-T+"`F)'0I
M('L@+RIA8G-T<F%C="`J+R!]"@H@("`@+RHJ"B`@("`@*B!!('1E<W0@96YD
M960N"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B!`86)S=')A8W0*("`@("`J+PH@("`@9G5N8W1I
M;VX@96YD5&5S="@F)'1E<W0I('L@+RIA8G-T<F%C="`J+R!]"@H@("`@+RHJ
M"B`@("`@*B!!('1E<W0@<W1A<G1E9"X*("`@("`J"B`@("`@*B!`<&%R86T@
M(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!A8G-T<F%C
M=`H@("`@("HO"B`@("!F=6YC=&EO;B!S=&%R=%1E<W0H)B1T97-T*2![("\J
M86)S=')A8W0@*B\@?0I]"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A
M8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!C+6AA;F=I;F<M
M8V]M;65N="UE;F1E<BUP.B!N:6P*("H@16YD.@H@*B\*/SX*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!(4%5N:70O5&5S=%)E
M<W5L="YP:'``````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(P-3(P
M`#$P-3$U-#,S-S,W`#`R,C<R-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@
M=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ
M"B`J(%!(4"!697)S:6]N(#0*("H*("H@0V]P>7)I9VAT("AC*2`R,#`R+3(P
M,#4L(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN
M+F1E/BX*("H@06QL(')I9VAT<R!R97-E<G9E9"X*("H*("H@4F5D:7-T<FEB
M=71I;VX@86YD('5S92!I;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET
M:"!O<B!W:71H;W5T"B`J(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P
M<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<PH@*B!A<F4@
M;65T.@H@*@H@*B`@("H@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E
M(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0*("H@("`@(&YO=&EC
M92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@
M9&ES8VQA:6UE<BX*("H@"B`J("`@*B!2961I<W1R:6)U=&EO;G,@:6X@8FEN
M87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H=`H@
M*B`@("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE
M(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN"B`J("`@("!T:&4@9&]C=6UE;G1A
M=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE
M"B`J("`@("!D:7-T<FEB=71I;VXN"B`J"B`J("`@*B!.96ET:&5R('1H92!N
M86UE(&]F(%-E8F%S=&EA;B!"97)G;6%N;B!N;W(@=&AE(&YA;65S(&]F(&AI
M<PH@*B`@("`@8V]N=')I8G5T;W)S(&UA>2!B92!U<V5D('1O(&5N9&]R<V4@
M;W(@<')O;6]T92!P<F]D=6-T<R!D97)I=F5D"B`J("`@("!F<F]M('1H:7,@
M<V]F='=A<F4@=VET:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N('!E<FUI
M<W-I;VXN"B`J"B`J(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%
M($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,*("H@(D%3($E3
M(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,
M541)3D<L($)55"!.3U0*("H@3$E-251%1"!43RP@5$A%($E-4$Q)140@5T%2
M4D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,*("H@1D]2
M($$@4$%25$E#54Q!4B!055)03U-%($%212!$25-#3$%)345$+B!)3B!.3R!%
M5D5.5"!32$%,3"!42$4*("H@0T]065))1TA4($]73D52($]2($-/3E1224)5
M5$]24R!"12!,24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+`H@*B!)
M3D-)1$5.5$%,+"!34$5#24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)
M04P@1$%-04=%4R`H24Y#3%5$24Y'+`H@*B!"550@3D]4($Q)34E4140@5$\L
M(%!23T-54D5-14Y4($]&(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[
M"B`J($Q/4U,@3T8@55-%+"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D53
M4R!)3E1%4E)54%1)3TXI($A/5T5615(*("H@0T%54T5$($%.1"!/3B!!3ED@
M5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@4U12
M24,*("H@3$E!0DE,2519+"!/4B!43U)4("A)3D-,541)3D<@3D5'3$E'14Y#
M12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X*("H@04Y9(%=!62!/550@3T8@
M5$A%(%5312!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@
M5$A%"B`J(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+@H@*@H@*B!`8V%T
M96=O<GD@("!497-T:6YG"B`J($!P86-K86=E("`@(%!(4%5N:70*("H@0&%U
M=&AO<B`@("`@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R
M9VUA;FXN9&4^"B`J($!C;W!Y<FEG:'0@(#(P,#(M,C`P-2!396)A<W1I86X@
M0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&QI8V5N
M<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M
M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@($-64SH@
M)$ED.B!497-T4F5S=6QT+G!H<"QV(#$N,3@@,C`P-2\Q,2\Q,"`P.3HT-SHQ
M-2!S96)A<W1I86X@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+U!(4%5N:70*("H@0'-I;F-E("`@("`@1FEL92!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C`N,`H@*B\*"G)E<75I<F5?;VYC
M92`G4$A056YI="]497-T1F%I;'5R92YP:'`G.PIR97%U:7)E7V]N8V4@)U!(
M4%5N:70O5&5S=$QI<W1E;F5R+G!H<"<["@II9B`H(69U;F-T:6]N7V5X:7-T
M<R@G:7-?82<I*2!["B`@("!R97%U:7)E7V]N8V4@)U!(4"]#;VUP870O1G5N
M8W1I;VXO:7-?82YP:'`G.PI]"@HO*BH*("H@02!497-T4F5S=6QT(&-O;&QE
M8W1S('1H92!R97-U;'1S(&]F(&5X96-U=&EN9R!A('1E<W0@8V%S92X*("H*
M("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@*B!`<&%C:V%G92`@("!02%!5;FET
M"B`J($!A=71H;W(@("`@(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T
M:6%N+6)E<F=M86YN+F1E/@H@*B!`8V]P>7)I9VAT("`R,#`R+3(P,#4@4V5B
M87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J
M($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS
M97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@
M("!296QE87-E.B`Q+C,N,@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4$A056YI=`H@*B!`<VEN8V4@("`@("!#;&%S<R!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C`N,`H@*B\*8VQA<W,@4$A056YI
M=%]497-T4F5S=6QT('L*("`@("\J*@H@("`@("H@0'9A<B`@("!A<G)A>0H@
M("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J+PH@("`@=F%R("1?97)R
M;W)S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($!V87(@("`@87)R87D*
M("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B\*("`@('9A<B`D7V9A
M:6QU<F5S(#T@87)R87DH*3L*"B`@("`@+RHJ"B`@("`@*B!`=F%R("`@(&%R
M<F%Y"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("HO"B`@("!V87(@
M)%]L:7-T96YE<G,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0'9A<B`@
M("!A<G)A>0H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J+PH@("`@
M=F%R("1?<&%S<V5D5&5S=',@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@
M0'9A<B`@("!I;G1E9V5R"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@
M("HO"B`@("!V87(@)%]R=6Y497-T<R`](#`["@H@("`@+RHJ"B`@("`@*B!`
M=F%R("`@(&)O;VQE86X*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!V87(@)%]S=&]P(#T@1D%,4T4["@H@("`@+RHJ"B`@("`@*B!!9&1S
M(&%N(&5R<F]R('1O('1H92!L:7-T(&]F(&5R<F]R<RX*("`@("`J(%1H92!P
M87-S960@:6X@97AC97!T:6]N(&-A=7-E9"!T:&4@97)R;W(N"B`@("`@*@H@
M("`@("H@0'!A<F%M("!O8FIE8W0*("`@("`J($!P87)A;2`@;V)J96-T"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!A9&1%
M<G)O<B@F)'1E<W0L("8D="D@>PH@("`@("`@("1T:&ES+3Y?97)R;W)S6UT@
M/2!N97<@4$A056YI=%]497-T1F%I;'5R92@D=&5S="P@)'0I.PH*("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'1H:7,M/E]L:7-T96YE<G,I
M.R`D:2LK*2!["B`@("`@("`@("`@("1T:&ES+3Y?;&ES=&5N97)S6R1I72T^
M861D17)R;W(H)'1E<W0L("1T*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!!9&1S(&$@9F%I;'5R92!T;R!T:&4@;&ES="!O9B!F86EL=7)E
M<RX*("`@("`J(%1H92!P87-S960@:6X@97AC97!T:6]N(&-A=7-E9"!T:&4@
M9F%I;'5R92X*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C=`H@("`@("H@
M0'!A<F%M("!O8FIE8W0*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%D9$9A:6QU<F4H)B1T97-T+"`F)'0I('L*("`@("`@
M("`D=&AI<RT^7V9A:6QU<F5S6UT@/2!N97<@4$A056YI=%]497-T1F%I;'5R
M92@D=&5S="P@)'0I.PH*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE
M;V8H)'1H:7,M/E]L:7-T96YE<G,I.R`D:2LK*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?;&ES=&5N97)S6R1I72T^861D1F%I;'5R92@D=&5S="P@)'0I.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E9VES=&5R<R!A(%1E
M<W1,:7-T96YE<BX*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C=`H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@861D3&ES
M=&5N97(H)B1L:7-T96YE<BD@>PH@("`@("`@(&EF("AI<U]O8FIE8W0H)&QI
M<W1E;F5R*2`F)@H@("`@("`@("`@("!I<U]A*"1L:7-T96YE<BP@)U!(4%5N
M:71?5&5S=$QI<W1E;F5R)RDI('L*("`@("`@("`@("`@)'1H:7,M/E]L:7-T
M96YE<G-;72`]("8D;&ES=&5N97(["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@061D<R!A('!A<W-E9"!T97-T('1O('1H92!L:7-T(&]F('!A
M<W-E9"!T97-T<RX*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C=`H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@861D4&%S
M<V5D5&5S="@F)'1E<W0I('L*("`@("`@("`D=&AI<RT^7W!A<W-E9%1E<W1S
M6UT@/2`F)'1E<W0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!);F9O<FUS('1H
M92!R97-U;'0@=&AA="!A('1E<W0@=V%S(&-O;7!L971E9"X*("`@("`J"B`@
M("`@*B!`<&%R86T@(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@96YD5&5S="@F)'1E<W0I('L*("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'1H:7,M/E]L:7-T96YE<G,I.R`D
M:2LK*2!["B`@("`@("`@("`@("1T:&ES+3Y?;&ES=&5N97)S6R1I72T^96YD
M5&5S="@D=&5S="D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M1V5T<R!T:&4@;G5M8F5R(&]F(&1E=&5C=&5D(&5R<F]R<RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN=&5G97(*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R0V]U;G0H*2!["B`@("`@("`@<F5T
M=7)N('-I>F5O9B@D=&AI<RT^7V5R<F]R<RD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS(&%N($5N=6UE<F%T:6]N(&9O<B!T:&4@97)R;W)S+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N("9E<G)O<G,H*2!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?97)R;W)S.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1V5T<R!T:&4@;G5M8F5R(&]F(&1E=&5C=&5D(&9A:6QU<F5S+@H@("`@("H*
M("`@("`J($!R971U<FX@:6YT96=E<@H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@9F%I;'5R94-O=6YT*"D@>PH@("`@("`@
M(')E='5R;B!S:7IE;V8H)'1H:7,M/E]F86EL=7)E<RD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&%N($5N=6UE<F%T:6]N(&9O<B!T:&4@9F%I
M;'5R97,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>0H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A:6QU<F5S*"D@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V9A:6QU<F5S.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!A;B!%;G5M97)A=&EO;B!F;W(@=&AE('!A
M<W-E9"!T97-T<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B`F<&%S<V5D
M5&5S=',H*2!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%S<V5D5&5S=',[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!5;G)E9VES=&5R<R!A(%1E<W1,:7-T
M96YE<BX*("`@("`J(%1H:7,@<F5Q=6ER97,@=&AE(%IE;F0@16YG:6YE(#(@
M*'1O('=O<FL@<')O<&5R;'DI+@H@("`@("H*("`@("`J($!P87)A;2`@;V)J
M96-T"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO
M;B!R96UO=F5,:7-T96YE<B@F)&QI<W1E;F5R*2!["B`@("`@("`@9F]R("@D
M:2`](#`[("1I(#P@<VEZ96]F*"1T:&ES+3Y?;&ES=&5N97)S*3L@)&DK*RD@
M>PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]L:7-T96YE<G-;)&E=(#T]/2`D
M;&ES=&5N97(I('L*("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?;&ES
M=&5N97)S6R1I72D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2=6YS(&$@5&5S=$-A<V4N"B`@("`@*@H@("`@("H@
M0'!A<F%M("!O8FIE8W0*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(')U;B@F)'1E<W0I('L*("`@("`@("`D=&AI<RT^<W1A
M<G1497-T*"1T97-T*3L*("`@("`@("`D=&AI<RT^7W)U;E1E<W1S*RL["B`@
M("`@("`@)'1E<W0M/G)U;D)A<F4H*3L*("`@("`@("`D=&AI<RT^96YD5&5S
M="@D=&5S="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!N=6UB
M97(@;V8@<G5N('1E<W1S+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E
M<@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@
M<G5N0V]U;G0H*2!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<G5N5&5S=',[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@=VAE=&AE<B!T:&4@=&5S
M="!R=6X@<VAO=6QD('-T;W`N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<VAO=6QD4W1O<"@I('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]S=&]P.PH@("`@?0H*("`@("\J*@H@("`@("H@
M26YF;W)M<R!T:&4@<F5S=6QT('1H870@82!T97-T('=I;&P@8F4@<W1A<G1E
M9"X*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C=`H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<W1A<G1497-T*"8D=&5S
M="D@>PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D=&AI<RT^
M7VQI<W1E;F5R<RD[("1I*RLI('L*("`@("`@("`@("`@)'1H:7,M/E]L:7-T
M96YE<G-;)&E=+3YS=&%R=%1E<W0H)'1E<W0I.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($UA<FMS('1H870@=&AE('1E<W0@<G5N('-H;W5L
M9"!S=&]P+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-T;W`H*2!["B`@("`@("`@)'1H:7,M/E]S=&]P(#T@
M5%)513L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!(5$U,(')E
M<')E<V5N=&%T:6]N(&]F('1H92!T97-T(')E<W5L="X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@=&](5$U,*"D@>PH@("`@("`@(')E='5R;B`G/'!R
M93XG("X@:'1M;'-P96-I86QC:&%R<R@D=&AI<RT^=&]3=')I;F<H*2D@+B`G
M/"]P<F4^)SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!T97AT
M(')E<')E<V5N=&%T:6]N(&]F('1H92!T97-T(')E<W5L="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@=&]3=')I;F<H*2!["B`@("`@("`@)')E<W5L
M="`]("<G.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!A<W-E9%1E<W1S
M(&%S("1P87-S961497-T*2!["B`@("`@("`@("`@("1R97-U;'0@+CT@<W!R
M:6YT9B@*("`@("`@("`@("`@("`B5&5S=$-A<V4@)7,M/B5S*"D@<&%S<V5D
M7&XB+`H*("`@("`@("`@("`@("!G971?8VQA<W,H)'!A<W-E9%1E<W0I+`H@
M("`@("`@("`@("`@("1P87-S961497-T+3YG971.86UE*"D*("`@("`@("`@
M("`@*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?9F%I
M;'5R97,@87,@)&9A:6QE9%1E<W0I('L*("`@("`@("`@("`@)')E<W5L="`N
M/2`D9F%I;&5D5&5S="T^=&]3=')I;F<H*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!W:&5T:&5R('1H92!E;G1I<F4@=&5S="!W87,@<W5C8V5S<V9U;"!O<B!N
M;W0N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!W87-3=6-C97-S9G5L
M*"D@>PH@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7V5R<F]R<RD@)B8@96UP
M='DH)'1H:7,M/E]F86EL=7)E<RDI('L*("`@("`@("`@("`@<F5T=7)N(%12
M544["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N($9!3%-%
M.PH@("`@("`@('T*("`@('T*?0H*+RH*("H@3&]C86P@=F%R:6%B;&5S.@H@
M*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z(#0*("H@8RUH86YG
M:6YG+6-O;6UE;G0M96YD97(M<#H@;FEL"B`J($5N9#H*("HO"C\^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+U!(4%5N:70O5&5S=%-U:71E+G!H<```
M````````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$U,C8T`#$P-3$U-#,S
M-S,W`#`R,C4U,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT
M('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%!(4"!6
M97)S:6]N(#0*("H*("H@0V]P>7)I9VAT("AC*2`R,#`R+3(P,#4L(%-E8F%S
M=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/BX*("H@
M06QL(')I9VAT<R!R97-E<G9E9"X*("H*("H@4F5D:7-T<FEB=71I;VX@86YD
M('5S92!I;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H
M;W5T"B`J(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T
M:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<PH@*B!A<F4@;65T.@H@*@H@
M*B`@("H@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T
M86EN('1H92!A8F]V92!C;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@=&AI<R!L
M:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE
M<BX*("H@"B`J("`@*B!2961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@
M;75S="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H=`H@*B`@("`@;F]T
M:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN
M9R!D:7-C;&%I;65R(&EN"B`J("`@("!T:&4@9&]C=6UE;G1A=&EO;B!A;F0O
M;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE"B`J("`@("!D
M:7-T<FEB=71I;VXN"B`J"B`J("`@*B!.96ET:&5R('1H92!N86UE(&]F(%-E
M8F%S=&EA;B!"97)G;6%N;B!N;W(@=&AE(&YA;65S(&]F(&AI<PH@*B`@("`@
M8V]N=')I8G5T;W)S(&UA>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T
M92!P<F]D=6-T<R!D97)I=F5D"B`J("`@("!F<F]M('1H:7,@<V]F='=A<F4@
M=VET:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N('!E<FUI<W-I;VXN"B`J
M"B`J(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(
M5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,*("H@(D%3($E3(B!!3D0@04Y9
M($584%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)5
M5"!.3U0*("H@3$E-251%1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%4R!/
M1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,*("H@1D]2($$@4$%25$E#
M54Q!4B!055)03U-%($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,
M3"!42$4*("H@0T]065))1TA4($]73D52($]2($-/3E1224)55$]24R!"12!,
M24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+`H@*B!)3D-)1$5.5$%,
M+"!34$5#24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%
M4R`H24Y#3%5$24Y'+`H@*B!"550@3D]4($Q)34E4140@5$\L(%!23T-54D5-
M14Y4($]&(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,["B`J($Q/4U,@
M3T8@55-%+"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)5
M4%1)3TXI($A/5T5615(*("H@0T%54T5$($%.1"!/3B!!3ED@5$A%3U)9($]&
M($Q)04))3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@4U1224,*("H@3$E!
M0DE,2519+"!/4B!43U)4("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%
M4E=)4T4I($%225-)3D<@24X*("H@04Y9(%=!62!/550@3T8@5$A%(%5312!/
M1B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/
M4U-)0DE,2519($]&(%-50T@@1$%-04=%+@H@*@H@*B!`8V%T96=O<GD@("!4
M97-T:6YG"B`J($!P86-K86=E("`@(%!(4%5N:70*("H@0&%U=&AO<B`@("`@
M4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^
M"B`J($!C;W!Y<FEG:'0@(#(P,#(M,C`P-2!396)A<W1I86X@0F5R9VUA;FX@
M/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP
M:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!497-T
M4W5I=&4N<&AP+'8@,2XQ-R`R,#`U+S$Q+S$P(#`Y.C0W.C$U('-E8F%S=&EA
M;B!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A
M8VMA9V4O4$A056YI=`H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S
M:6YC92!296QE87-E(#$N,"XP"B`J+PH*<F5Q=6ER95]O;F-E("=02%!5;FET
M+U1E<W1#87-E+G!H<"<["@HO*BH*("H@02!497-T4W5I=&4@:7,@82!#;VUP
M;W-I=&4@;V8@5&5S=',N($ET(')U;G,@82!C;VQL96-T:6]N(&]F('1E<W0@
M8V%S97,N"B`J"B`J($AE<F4@:7,@86X@97AA;7!L92!U<VEN9R!T:&4@9'EN
M86UI8R!T97-T(&1E9FEN:71I;VXN"B`J"B`J(#QC;V1E/@H@*B`\/W!H<`H@
M*B`D<W5I=&4@/2!N97<@4$A056YI=%]497-T4W5I=&4H*3L*("H@)'-U:71E
M+3YA9&1497-T*&YE=R!-871H5&5S="@G=&5S=%!A<W,G*2D["B`J(#\^"B`J
M(#PO8V]D93X*("H*("H@06QT97)N871I=F5L>2P@82!497-T4W5I=&4@8V%N
M(&5X=')A8W0@=&AE('1E<W1S('1O(&)E(')U;B!A=71O;6%T:6-A;&QY+@H@
M*B!4;R!D;R!S;R!Y;W4@<&%S<R!T:&4@8VQA<W-N86UE(&]F('EO=7(@5&5S
M=$-A<V4@8VQA<W,@=&\@=&AE(%1E<W13=6ET90H@*B!C;VYS=')U8W1O<BX*
M("H*("H@/&-O9&4^"B`J(#P_<&AP"B`J("1S=6ET92`](&YE=R!497-T4W5I
M=&4H)V-L87-S;F%M92<I.PH@*B`_/@H@*B`\+V-O9&4^"B`J"B`J(%1H:7,@
M8V]N<W1R=6-T;W(@8W)E871E<R!A('-U:71E('=I=&@@86QL('1H92!M971H
M;V1S('-T87)T:6YG('=I=&@*("H@(G1E<W0B('1H870@=&%K92!N;R!A<F=U
M;65N=',N"B`J"B`J($!C871E9V]R>2`@(%1E<W1I;F<*("H@0'!A8VMA9V4@
M("`@4$A056YI=`H@*B!`875T:&]R("`@("!396)A<W1I86X@0F5R9VUA;FX@
M/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&-O<'ER:6=H="`@,C`P
M,BTR,#`U(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M
M86YN+F1E/@H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N
M;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@
M0'9E<G-I;VX@("`@4F5L96%S93H@,2XS+C(*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!(4%5N:70*("H@0'-I;F-E("`@
M("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XP+C`*("HO"F-L
M87-S(%!(4%5N:71?5&5S=%-U:71E('L*("`@("\J*@H@("`@("H@5&AE(&YA
M;64@;V8@=&AE('1E<W0@<W5I=&4N"B`@("`@*@H@("`@("H@0'9A<B`@("!S
M=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@
M)%]N86UE(#T@)R<["@H@("`@+RHJ"B`@("`@*B!4:&4@=&5S=',@:6X@=&AE
M('1E<W0@<W5I=&4N"B`@("`@*@H@("`@("H@0'9A<B`@("!A<G)A>0H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7W1E<W1S(#T@
M87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!497-T4W5I
M=&4N"B`@("`@*@H@("`@("H@0'!A<F%M("!M:7AE9`H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@4$A056YI=%]497-T4W5I
M=&4H)'1E<W0@/2!&04Q312D@>PH@("`@("`@(&EF("@D=&5S="`A/3T@1D%,
M4T4I('L*("`@("`@("`@("`@)'1H:7,M/G-E=$YA;64H)'1E<W0I.PH@("`@
M("`@("`@("`D=&AI<RT^861D5&5S=%-U:71E*"1T97-T*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@=&5S="!T;R!T:&4@<W5I
M=&4N"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9%1E<W0H)B1T97-T
M*2!["B`@("`@("`@)'1H:7,M/E]T97-T<UM=(#T@)B1T97-T.PH@("`@?0H*
M("`@("\J*@H@("`@("H@061D<R!T:&4@=&5S=',@9G)O;2!T:&4@9VEV96X@
M8VQA<W,@=&\@=&AE('-U:71E+@H@("`@("H*("`@("`J($!P87)A;2`@<W1R
M:6YG"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO
M;B!A9&1497-T4W5I=&4H)'1E<W1#;&%S<RD@>PH@("`@("`@(&EF("AC;&%S
M<U]E>&ES=',H)'1E<W1#;&%S<RDI('L*("`@("`@("`@("`@)&UE=&AO9',@
M("`@("`@/2!G971?8VQA<W-?;65T:&]D<R@D=&5S=$-L87-S*3L*("`@("`@
M("`@("`@)'!A<F5N=$-L87-S97,@/2!A<G)A>2AS=')T;VQO=V5R*"1T97-T
M0VQA<W,I*3L*("`@("`@("`@("`@)'!A<F5N=$-L87-S("`@/2`D=&5S=$-L
M87-S.PH*("`@("`@("`@("`@=VAI;&4H:7-?<W1R:6YG*"1P87)E;G1#;&%S
M<R`](&=E=%]P87)E;G1?8VQA<W,H)'!A<F5N=$-L87-S*2DI('L*("`@("`@
M("`@("`@("`@("1P87)E;G1#;&%S<V5S6UT@/2`D<&%R96YT0VQA<W,["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(&9O<F5A8V@@*"1M971H;V1S(&%S
M("1M971H;V0I('L*("`@("`@("`@("`@("`@(&EF("AS=6)S='(H)&UE=&AO
M9"P@,"P@-"D@/3T@)W1E<W0G("8F"B`@("`@("`@("`@("`@("`@("`@(6EN
M7V%R<F%Y*"1M971H;V0L("1P87)E;G1#;&%S<V5S*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YA9&1497-T*&YE=R`D=&5S=$-L87-S*"1M971H
M;V0I*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($-O=6YT<R!T:&4@;G5M8F5R(&]F
M('1E<W0@8V%S97,@=&AA="!W:6QL(&)E(')U;B!B>2!T:&ES('1E<W0N"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!C;W5N=%1E<W1#87-E<R@I('L*
M("`@("`@("`D8V]U;G0@/2`P.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^
M7W1E<W1S(&%S("1T97-T*2!["B`@("`@("`@("`@("1C;W5N="`K/2`D=&5S
M="T^8V]U;G1497-T0V%S97,H*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D8V]U;G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!N
M86UE(&]F('1H92!S=6ET92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T3F%M92@I('L*("`@("`@("!R971U<FX@)'1H:7,M/E]N86UE.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4G5N<R!T:&4@=&5S=',@86YD(&-O;&QE8W1S
M('1H96ER(')E<W5L="!I;B!A(%1E<W1297-U;'0N"B`@("`@*@H@("`@("H@
M0'!A<F%M("!O8FIE8W0*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(')U;B@F)')E<W5L="D@>PH@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\('-I>F5O9B@D=&AI<RT^7W1E<W1S*2`F)B`A)')E<W5L="T^
M<VAO=6QD4W1O<"@I.R`D:2LK*2!["B`@("`@("`@("`@("1T:&ES+3Y?=&5S
M='-;)&E=+3YR=6XH)')E<W5L="D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4G5N<R!A('1E<W0N"B`@("`@*@H@("`@("H@0'!A<F%M("!O
M8FIE8W0*("`@("`J($!P87)A;2`@;V)J96-T"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!R=6Y497-T*"8D=&5S="P@)B1R
M97-U;'0I('L*("`@("`@("`D=&5S="T^<G5N*"1R97-U;'0I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4V5T<R!T:&4@;F%M92!O9B!T:&4@<W5I=&4N"B`@
M("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$YA;64H)&YA;64I('L*("`@
M("`@("`D=&AI<RT^7VYA;64@/2`D;F%M93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE('1E<W0@870@=&AE(&=I=F5N(&EN9&5X+@H@("`@
M("H*("`@("`J($!P87)A;2`@:6YT96=E<@H@("`@("H@0')E='5R;B!O8FIE
M8W0*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9T97-T070H)&EN9&5X*2!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M=&5S='-;)&EN9&5X72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M=&5S='-;)&EN9&5X73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@1D%,4T4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@;G5M8F5R(&]F('1E<W1S(&EN('1H:7,@<W5I=&4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!T97-T0V]U;G0H*2!["B`@("`@
M("`@<F5T=7)N('-I>F5O9B@D=&AI<RT^7W1E<W1S*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE('1E<W1S(&%S(&%N(&5N=6UE<F%T:6]N
M+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N("9T97-T<R@I('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]T97-T<SL*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@82!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@=&AE('1E<W0@
M<W5I=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('1O4W1R:6YG*"D@
M>PH@("`@("`@(')E='5R;B`G)SL*("`@('T*?0H*+RH*("H@3&]C86P@=F%R
M:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z(#0*
M("H@8RUH86YG:6YG+6-O;6UE;G0M96YD97(M<#H@;FEL"B`J($5N9#H*("HO
M"C\^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+U!(4%5N:70N<&AP````````````````````````````````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#$P,#$P`#$P-3$U-#,S-S0S`#`R,#4W-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S
M;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%!(4"!697)S:6]N(#0*("H*("H@
M0V]P>7)I9VAT("AC*2`R,#`R+3(P,#4L(%-E8F%S=&EA;B!"97)G;6%N;B`\
M<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/BX*("H@06QL(')I9VAT<R!R97-E
M<G9E9"X*("H*("H@4F5D:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@
M86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T"B`J(&UO9&EF:6-A
M=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I
M;F<@8V]N9&ET:6]N<PH@*B!A<F4@;65T.@H@*@H@*B`@("H@4F5D:7-T<FEB
M=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C
M;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO
M;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@"B`J("`@*B!2
M961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@
M=&AE(&%B;W9E(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T:&ES(&QI<W0@
M;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN
M"B`J("`@("!T:&4@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I
M86QS('!R;W9I9&5D('=I=&@@=&AE"B`J("`@("!D:7-T<FEB=71I;VXN"B`J
M"B`J("`@*B!.96ET:&5R('1H92!N86UE(&]F(%-E8F%S=&EA;B!"97)G;6%N
M;B!N;W(@=&AE(&YA;65S(&]F(&AI<PH@*B`@("`@8V]N=')I8G5T;W)S(&UA
M>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92!P<F]D=6-T<R!D97)I
M=F5D"B`J("`@("!F<F]M('1H:7,@<V]F='=A<F4@=VET:&]U="!S<&5C:69I
M8R!P<FEO<B!W<FET=&5N('!E<FUI<W-I;VXN"B`J"B`J(%1(25,@4T]&5%=!
M4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#
M3TY44DE"551/4E,*("H@(D%3($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U0
M3$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0*("H@3$E-251%
M1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)
M5%D@04Y$($9)5$Y%4U,*("H@1D]2($$@4$%25$E#54Q!4B!055)03U-%($%2
M12!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4*("H@0T]065))
M1TA4($]73D52($]2($-/3E1224)55$]24R!"12!,24%"3$4@1D]2($%.62!$
M25)%0U0L($E.1$E214-4+`H@*B!)3D-)1$5.5$%,+"!34$5#24%,+"!%6$5-
M4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+`H@
M*B!"550@3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&(%-50E-42515
M5$4@1T]/1%,@3U(@4T525DE#15,["B`J($Q/4U,@3T8@55-%+"!$051!+"!/
M4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI($A/5T5615(*
M("H@0T%54T5$($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)04))3$E462P@5TA%
M5$A%4B!)3B!#3TY44D%#5"P@4U1224,*("H@3$E!0DE,2519+"!/4B!43U)4
M("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@
M24X*("H@04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3(%-/1E1705)%
M+"!%5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,2519($]&(%-5
M0T@@1$%-04=%+@H@*@H@*B!`8V%T96=O<GD@("!497-T:6YG"B`J($!P86-K
M86=E("`@(%!(4%5N:70*("H@0&%U=&AO<B`@("`@4V5B87-T:6%N($)E<F=M
M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J($!C;W!Y<FEG:'0@
M(#(P,#(M,C`P-2!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB
M97)G;6%N;BYD93X*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U
M<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E
M"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!02%!5;FET+G!H<"QV(#$N,3<@
M,C`P-2\Q,2\Q,"`P.3HT-SHQ,2!S96)A<W1I86X@17AP("0*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!(4%5N:70*("H@
M0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C`N
M,`H@*B\*"G)E<75I<F5?;VYC92`G4$A056YI="]497-T0V%S92YP:'`G.PIR
M97%U:7)E7V]N8V4@)U!(4%5N:70O5&5S=%)E<W5L="YP:'`G.PIR97%U:7)E
M7V]N8V4@)U!(4%5N:70O5&5S=%-U:71E+G!H<"<["@HO*BH*("H@4$A056YI
M="!R=6YS(&$@5&5S=%-U:71E(&%N9"!R971U<FYS(&$@5&5S=%)E<W5L="!O
M8FIE8W0N"B`J"B`J($AE<F4@:7,@86X@97AA;7!L93H*("H*("H@/&-O9&4^
M"B`J(#P_<&AP"B`J(')E<75I<F5?;VYC92`G4$A056YI="YP:'`G.PH@*@H@
M*B!C;&%S<R!-871H5&5S="!E>'1E;F1S(%!(4%5N:71?5&5S=$-A<V4@>PH@
M*B`@("`@=F%R("1F5F%L=64Q.PH@*B`@("`@=F%R("1F5F%L=64R.PH@*@H@
M*B`@("`@9G5N8W1I;VX@36%T:%1E<W0H)&YA;64I('L*("H@("`@("`@)'1H
M:7,M/E!(4%5N:71?5&5S=$-A<V4H)&YA;64I.PH@*B`@("`@?0H@*@H@*B`@
M("`@9G5N8W1I;VX@<V5T57`H*2!["B`J("`@("`@("1T:&ES+3YF5F%L=64Q
M(#T@,CL*("H@("`@("`@)'1H:7,M/F9686QU93(@/2`S.PH@*B`@("`@?0H@
M*@H@*B`@("`@9G5N8W1I;VX@=&5S=$%D9"@I('L*("H@("`@("`@)'1H:7,M
M/F%S<V5R=%1R=64H)'1H:7,M/F9686QU93$@*R`D=&AI<RT^9E9A;'5E,B`]
M/2`U*3L*("H@("`@('T*("H@?0H@*@H@*B`D<W5I=&4@/2!N97<@4$A056YI
M=%]497-T4W5I=&4H*3L*("H@)'-U:71E+3YA9&1497-T*&YE=R!-871H5&5S
M="@G=&5S=$%D9"<I*3L*("H*("H@)')E<W5L="`](%!(4%5N:70Z.G)U;B@D
M<W5I=&4I.PH@*B!P<FEN="`D<F5S=6QT+3YT;TA434PH*3L*("H@/SX*("H@
M/"]C;V1E/@H@*@H@*B!!;'1E<FYA=&EV96QY+"!Y;W4@8V%N('!A<W,@82!C
M;&%S<R!N86UE('1O('1H92!02%!5;FET7U1E<W13=6ET92@I"B`J(&-O;G-T
M<G5C=&]R(&%N9"!L970@:70@875T;VUA=&EC86QL>2!A9&0@86QL(&UE=&AO
M9',@;V8@=&AA="!C;&%S<PH@*B!T:&%T('-T87)T('=I=&@@)W1E<W0G('1O
M('1H92!S=6ET93H*("H*("H@/&-O9&4^"B`J(#P_<&AP"B`J("1S=6ET92`@
M/2!N97<@4$A056YI=%]497-T4W5I=&4H)TUA=&A497-T)RD["B`J("1R97-U
M;'0@/2!02%!5;FET.CIR=6XH)'-U:71E*3L*("H@<')I;G0@)')E<W5L="T^
M=&](5$U,*"D["B`J(#\^"B`J(#PO8V]D93X*("H*("H@0&-A=&5G;W)Y("`@
M5&5S=&EN9PH@*B!`<&%C:V%G92`@("!02%!5;FET"B`J($!A=71H;W(@("`@
M(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E
M/@H@*B!`8V]P>7)I9VAT("`R,#`R+3(P,#4@4V5B87-T:6%N($)E<F=M86YN
M(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J($!L:6-E;G-E("`@(&AT
M='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N
M<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C,N
M,@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M4$A056YI=`H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@
M4F5L96%S92`Q+C`N,`H@*B\*8VQA<W,@4$A056YI="!["B`@("`O*BH*("`@
M("`J(%)U;G,@82!T97-T*'-U:71E*2X*("`@("`J"B`@("`@*B!`<&%R86T@
M(&UI>&5D"B`@("`@*B!`<F5T=7)N(%!(4%5N:71?5&5S=%)E<W5L=`H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@)G)U;B@F
M)'-U:71E*2!["B`@("`@("`@)')E<W5L="`](&YE=R!02%!5;FET7U1E<W12
M97-U;'0H*3L*("`@("`@("`D<W5I=&4M/G)U;B@D<F5S=6QT*3L*"B`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("!]"GT*"B\J"B`J($QO8V%L('9A<FEA
M8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J
M(&,M:&%N9VEN9RUC;VUM96YT+65N9&5R+7`Z(&YI;`H@*B!%;F0Z"B`J+PH_
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4V5R
M=FEC97,O````````````````````````````````````````````````````
M````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`U,34T,S,W,S0`,#(P,S8W`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]397)V:6-E<R]796%T:&5R+P``````````````````
M```````````````````````````````````````````````````P,#`P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<S-``P,C$W
M-C8`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-E<G9I8V5S+U=E871H
M97(O0V]M;6]N+G!H<```````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3$S,#`P
M`#$P-3$U-#,S-S,T`#`R,S<R,@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@
M=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT(&9O;&1M971H
M;V0];6%R:V5R.B`J+PH*+RHJ"B`J(%!%05(Z.E-E<G9I8V5S7U=E871H97)?
M0V]M;6]N"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J(#Q,24-%
M3E-%/@H@*B!#;W!Y<FEG:'0@*&,I(#(P,#4L($%L97AA;F1E<B!7:7)T>@H@
M*B!!;&P@<FEG:'1S(')E<V5R=F5D+@H@*@H@*B!2961I<W1R:6)U=&EO;B!A
M;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I
M=&AO=70*("H@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D
M('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS"B`J(&%R92!M970Z"B`J
M(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN
M('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O
M9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J
M(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D
M=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T:6-E+`H@*B`@('1H:7,@;&ES
M="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@
M:6X@=&AE(&1O8W5M96YT871I;VX*("H@("!A;F0O;W(@;W1H97(@;6%T97)I
M86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BX*("H@;R!.96ET
M:&5R('1H92!N86UE(&]F('1H92!S;V9T=V%R92!N;W(@=&AE(&YA;65S(&]F
M(&ET<R!C;VYT<FEB=71O<G,*("H@("!M87D@8F4@=7-E9"!T;R!E;F1O<G-E
M(&]R('!R;VUO=&4@<')O9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A
M<F4*("H@("!W:71H;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@<&5R;6ES
M<VEO;BX*("H*("H@5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@
M0T]065))1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]24R`B05,@25,B"B`J
M($%.1"!!3ED@15A04D534R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ5
M1$E.1RP@0E54($Y/5"!,24U)5$5$(%1/+"!42$4*("H@24U03$E%1"!705)2
M04Y42453($]&($U%4D-(04Y404))3$E462!!3D0@1DE43D534R!&3U(@02!0
M05)424-53$%2(%!54E!/4T4*("H@05)%($1)4T-,04E-140N($E.($Y/($56
M14Y4(%-(04Q,(%1(12!#3U!94DE'2%0@3U=.15(@3U(@0T].5%))0E543U)3
M($)%"B`J($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$
M14Y404PL(%-014-)04PL($5814U03$%262P@3U(*("H@0T].4T51545.5$E!
M3"!$04U!1T53("A)3D-,541)3D<L($)55"!.3U0@3$E-251%1"!43RP@4%)/
M0U5214U%3E0@3T8*("H@4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL@
M3$]34R!/1B!54T4L($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3"B`J
M($E.5$524E505$E/3BD@2$]7159%4B!#0553140@04Y$($].($%.62!42$5/
M4ED@3T8@3$E!0DE,2519+"!72$542$52($E."B`J($-/3E1204-4+"!35%))
M0U0@3$E!0DE,2519+"!/4B!43U)4("A)3D-,541)3D<@3D5'3$E'14Y#12!/
M4B!/5$A%4E=)4T4I"B`J($%225-)3D<@24X@04Y9(%=!62!/550@3T8@5$A%
M(%5312!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%
M"B`J(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+@H@*B`\+TQ)0T5.4T4^
M"B`J"B`J($!C871E9V]R>2`@("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@
M("`@(%-E<G9I8V5S7U=E871H97(*("H@0&%U=&AO<B`@("`@($%L97AA;F1E
M<B!7:7)T>B`\86QE>$!P8S1P+FYE=#X*("H@0&-O<'ER:6=H="`@(#(P,#4@
M06QE>&%N9&5R(%=I<G1Z"B`J($!L:6-E;G-E("`@("!H='1P.B\O=W=W+F]P
M96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI
M8V5N<V4*("H@0'9E<G-I;VX@("`@($-64SH@)$ED.B!#;VUM;VXN<&AP+'8@
M,2XU,2`R,#`U+S$Q+S$S(#(R.C(W.C,R(&5R=2!%>'`@)`H@*B!`;&EN:R`@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U-E<G9I8V5S7U=E
M871H97(*("H@0&9I;&5S;W5R8V4*("HO"@IR97%U:7)E7V]N8V4@(E-E<G9I
M8V5S+U=E871H97(N<&AP(CL*"B\O('M[>R!C;VYS=&%N=',*+R\@>WM[(&YA
M='5R86P@8V]N<W1A;G1S(&%N9"!M96%S=7)E<PID969I;F4H(E-%4E9)0T53
M7U=%051(15)?4D%$25537T5!4E1((BP@-C,W."XQ-2D["B\O('U]?0H*+R\@
M>WM[(&1E9F%U;'0@=F%L=65S(&9O<B!T:&4@<W5N+69U;F-T:6]N<PID969I
M;F4H(E-%4E9)0T537U=%051(15)?4U5.1E5.0U-?1$5&055,5%],051)5%5$
M12(L("`S,2XW-C8W*3L*9&5F:6YE*")315)624-%4U]714%42$527U-53D95
M3D-37T1%1D%53%1?3$].1TE4541%(BP@,S4N,C,S,RD["F1E9FEN92@B4T52
M5DE#15-?5T5!5$A%4E]354Y&54Y#4U]354Y225-%7UI%3DE42"(L("`@(#DP
M+C@S*3L*9&5F:6YE*")315)624-%4U]714%42$527U-53D953D-37U-53E-%
M5%]:14Y)5$@B+"`@("`@.3`N.#,I.PHO+R!]?7T*+R\@?7U]"@HO+R![>WL@
M8VQA<W,@4V5R=FEC97-?5V5A=&AE<E]#;VUM;VX*+RHJ"B`J(%!A<F5N="!C
M;&%S<R!F;W(@=V5A=&AE<BUS97)V:6-E<RX@1&5F:6YE<R!C;VUM;VX@9G5N
M8W1I;VYS(&9O<B!U;FET"B`J(&-O;G9E<G-I;VYS+"!C:&5C:W,@9F]R(&-A
M8VAE(&5N86)L:6YG(&%N9"!D;V5S(&]T:&5R(&UI<V-E;&QA;F5O=7,*("H@
M=&AI;F=S+@H@*@H@*B!`8V%T96=O<GD@("`@5V5B(%-E<G9I8V5S"B`J($!P
M86-K86=E("`@("!397)V:6-E<U]796%T:&5R"B`J($!A=71H;W(@("`@("!!
M;&5X86YD97(@5VER='H@/&%L97A`<&,T<"YN970^"B`J($!C;W!Y<FEG:'0@
M("`R,#`U($%L97AA;F1E<B!7:7)T>@H@*B!`;&EC96YS92`@("`@:'1T<#HO
M+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@
M($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@("!296QE87-E.B`Q+C0N,`H@
M*B!`;&EN:R`@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U-E
M<G9I8V5S7U=E871H97(*("HO"F-L87-S(%-E<G9I8V5S7U=E871H97)?0V]M
M;6]N('L*"B`@("`O+R![>WL@<')O<&5R=&EE<PH@("`@+RHJ"B`@("`@*B!&
M;W)M870@;V8@=&AE('5N:71S('!R;W9I9&5D("AS=&%N9&%R9"]M971R:6,O
M8W5S=&]M*0H@("`@("H*("`@("`J($!V87(@("`@('-T<FEN9R`@("`@("`@
M("`@("`@("`@("`@("`D7W5N:71S1F]R;6%T"B`@("`@*B!`86-C97-S("!P
M<FEV871E"B`@("`@*B\*("`@('9A<B`D7W5N:71S1F]R;6%T(#T@(G,B.PH*
M("`@("\J*@H@("`@("H@0W5S=&]M(&9O<FUA="!O9B!T:&4@=6YI=',*("`@
M("`J"B`@("`@*B!`=F%R("`@("!A<G)A>2`@("`@("`@("`@("`@("`@("`@
M("`@)%]C=7-T;VU5;FET<T9O<FUA=`H@("`@("H@0&%C8V5S<R`@<')I=F%T
M90H@("`@("HO"B`@("!V87(@)%]C=7-T;VU5;FET<T9O<FUA="`](&%R<F%Y
M*`H@("`@("`@(")T96UP(B`@(#T^(")F(BP*("`@("`@("`B=FES(B`@("`]
M/B`B<VTB+`H@("`@("`@(")H96EG:'0B(#T^(")F="(L"B`@("`@("`@(G=I
M;F0B("`@/3X@(FUP:"(L"B`@("`@("`@(G!R97,B("`@/3X@(FEN(BP*("`@
M("`@("`B<F%I;B(@("`]/B`B:6XB"B`@("`I.PH*("`@("\J*@H@("`@("H@
M3W!T:6]N<R!F;W(@2%144"!R97%U97-T<PH@("`@("H*("`@("`J($!V87(@
M("`@(&%R<F%Y("`@("`@("`@("`@("`@("`@("`@("`D7VAT='!/<'1I;VYS
M"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7VAT
M='!/<'1I;VYS(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($9O<FUA="!O
M9B!T:&4@=7-E9"!D871E<PH@("`@("H*("`@("`J($!V87(@("`@('-T<FEN
M9R`@("`@("`@("`@("`@("`@("`@("`D7V1A=&5&;W)M870*("`@("`J($!A
M8V-E<W,@('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?9&%T949O<FUA="`]
M(")M+V0O>2(["@H@("`@+RHJ"B`@("`@*B!&;W)M870@;V8@=&AE('5S960@
M=&EM97,*("`@("`J"B`@("`@*B!`=F%R("`@("!S=')I;F<@("`@("`@("`@
M("`@("`@("`@("`@)%]T:6UE1F]R;6%T"B`@("`@*B!`86-C97-S("!P<FEV
M871E"B`@("`@*B\*("`@('9A<B`D7W1I;65&;W)M870@/2`B1SII($$B.PH*
M("`@("\J*@H@("`@("H@3V)J96-T(&-O;G1A:6YI;F<@=&AE(&QO8V%T:6]N
M+61A=&$*("`@("`J"B`@("`@*B!`=F%R("`@("!O8FIE8W0@<W1D0VQA<W,@
M("`@("`@("`@("`@)%]L;V-A=&EO;@H@("`@("H@0&%C8V5S<R`@<')I=F%T
M90H@("`@("HO"B`@("!V87(@)%]L;V-A=&EO;CL*"B`@("`O*BH*("`@("`J
M($]B:F5C="!C;VYT86EN:6YG('1H92!W96%T:&5R+61A=&$*("`@("`J"B`@
M("`@*B!`=F%R("`@("!O8FIE8W0@<W1D0VQA<W,@("`@("`@("`@("`@)%]W
M96%T:&5R"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@('9A
M<B`D7W=E871H97(["@H@("`@+RHJ"B`@("`@*B!/8FIE8W0@8V]N=&%I;FEN
M9R!T:&4@9F]R96-A<W0M9&%T80H@("`@("H*("`@("`J($!V87(@("`@(&]B
M:F5C="!S=&1#;&%S<R`@("`@("`@("`@("`D7V9O<F5C87-T"B`@("`@*B!`
M86-C97-S("!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7V9O<F5C87-T.PH*
M("`@("\J*@H@("`@("H@0V%C:&4L(&-O;G1A:6YI;F<@=&AE(&1A=&$M;V)J
M96-T<PH@("`@("H*("`@("`J($!V87(@("`@(&]B:F5C="!#86-H92`@("`@
M("`@("`@("`@("`D7V-A8VAE"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@
M("`@*B\*("`@('9A<B`D7V-A8VAE.PH*("`@("\J*@H@("`@("H@4')O=FED
M97,@8VAE8VL@9F]R($-A8VAE"B`@("`@*@H@("`@("H@0'9A<B`@("`@8F]O
M;"`@("`@("`@("`@("`@("`@("`@("`@("1?8V%C:&5%;F%B;&5D"B`@("`@
M*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7V-A8VAE16YA
M8FQE9"`](&9A;'-E.PH@("`@+R\@?7U]"@H@("`@+R\@>WM[(&-O;G-T<G5C
M=&]R"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@
M0'!A<F%M("`@87)R87D@("`@("`@("`@("`@("`@("`@("`@("1O<'1I;VYS
M"B`@("`@*B!`<&%R86T@("!M:7AE9"`@("`@("`@("`@("`@("`@("`@("`@
M)&5R<F]R"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R"B`@("`@*B!`86-C
M97-S("!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%-E<G9I8V5S7U=E
M871H97)?0V]M;6]N*"1O<'1I;VYS+"`F)&5R<F]R*0H@("`@>PH@("`@("`@
M("\O(%-E="!S;VUE(&-O;G-T86YT<R!F;W(@=&AE(&-A<V4@=VAE;B!02%`T
M(&ES('5S960L(&%S('1H90H@("`@("`@("\O(&1A=&5?<W5N<V5T+W-U;G)I
M<V4@9G5N8W1I;VYS(&%R92!N;W0@:6UP;&5M96YT960@=&AE<F4*("`@("`@
M("!I9B`H(61E9FEN960H(E-53D953D-37U)%5%]424U%4U1!35`B*2D@>PH@
M("`@("`@("`@("!D969I;F4H(E-53D953D-37U)%5%]424U%4U1!35`B+"`P
M*3L*("`@("`@("`@("`@9&5F:6YE*")354Y&54Y#4U]2151?4U1224Y'(BP@
M("`@,2D["B`@("`@("`@("`@(&1E9FEN92@B4U5.1E5.0U-?4D547T1/54),
M12(L("`@(#(I.PH@("`@("`@('T*"B`@("`@("`@+R\@4V5T(&]P=&EO;G,@
M86-C;W)D:6YG;'D*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;(F-A8VAE
M5'EP92)=*2D@>PH@("`@("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;(F-A
M8VAE3W!T:6]N<R)=*2D@>PH@("`@("`@("`@("`@("`@)'-T871U<R`]("1T
M:&ES+3YS971#86-H92@D;W!T:6]N<ULB8V%C:&54>7!E(ETL("1O<'1I;VYS
M6R)C86-H94]P=&EO;G,B72D["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D<W1A='5S(#T@)'1H:7,M/G-E=$-A8VAE*"1O<'1I;VYS
M6R)C86-H951Y<&4B72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@("`@
M("`@("`@("`@("1E<G)O<B`]("1S=&%T=7,["B`@("`@("`@("`@("`@("!R
M971U<FX["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("AI
M<W-E="@D;W!T:6]N<ULB=6YI='-&;W)M870B72DI('L*("`@("`@("`@("`@
M:68@*&ES<V5T*"1O<'1I;VYS6R)C=7-T;VU5;FET<T9O<FUA=")=*2D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/G-E=%5N:71S1F]R;6%T*"1O<'1I;VYS
M6R)U;FET<T9O<FUA=")=+"`D;W!T:6]N<ULB8W5S=&]M56YI='-&;W)M870B
M72D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T56YI='-&;W)M870H)&]P=&EO;G-;(G5N:71S1F]R;6%T(ETI.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)&]P
M=&EO;G-;(FAT='!4:6UE;W5T(ETI*2!["B`@("`@("`@("`@("1T:&ES+3YS
M971(='1P5&EM96]U="@D;W!T:6]N<ULB:'1T<%1I;65O=70B72D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/G-E=$AT='!4:6UE;W5T
M*#8P*3L*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R)H
M='1P4')O>'DB72DI('L*("`@("`@("`@("`@)'-T871U<R`]("1T:&ES+3YS
M971(='1P4')O>'DH)&]P=&EO;G-;(FAT='!0<F]X>2)=*3L*("`@("`@("`@
M("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-T871U<RDI('L*
M("`@("`@("`@("`@("`@("1E<G)O<B`]("1S=&%T=7,["B`@("`@("`@("`@
M("`@("!R971U<FX["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(&EF("AI<W-E="@D;W!T:6]N<ULB9&%T949O<FUA=")=*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^<V5T1&%T951I;65&;W)M870H)&]P=&EO;G-;(F1A=&5&
M;W)M870B72P@(B(I.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)&]P
M=&EO;G-;(G1I;65&;W)M870B72DI('L*("`@("`@("`@("`@)'1H:7,M/G-E
M=$1A=&54:6UE1F]R;6%T*"(B+"`D;W!T:6]N<ULB=&EM949O<FUA=")=*3L*
M("`@("`@("!]"B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@<V5T0V%C
M:&4H*0H@("`@+RHJ"B`@("`@*B!%;F%B;&5S(&-A8VAI;F<@=&AE(&1A=&$L
M('5S86=E('-T<F]N9VQY(')E8V]M;65N9&5D"B`@("`@*@H@("`@("H@4F5Q
M=6ER97,@0V%C:&4@=&\@8F4@:6YS=&%L;&5D"B`@("`@*@H@("`@("H@0'!A
M<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1C86-H951Y<&4*
M("`@("`J($!P87)A;2`@(&%R<F%Y("`@("`@("`@("`@("`@("`@("`@("`D
M8V%C:&5/<'1I;VYS"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&)O;VP*
M("`@("`J($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?
M15)23U)?0T%#2$5?24Y)5%]&04E,140*("`@("`J($!A8V-E<W,@('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!S971#86-H92@D8V%C:&54>7!E(#T@
M(F9I;&4B+"`D8V%C:&5/<'1I;VYS(#T@87)R87DH*2D*("`@('L*("`@("`@
M("`O+R!4:&4@97)R;W(@:&%N9&QI;F<@:6X@0V%C:&4@:7,@82!B:70@8W)U
M;6UY("AR96%D.B!N;W0@97AI<W1E;G0I"B`@("`@("`@+R\@<V\@=V4@:&%V
M92!T;R!D;R!T:&%T(&]N(&]U<B!O=VXN+BX*("`@("`@("!`:6YC;'5D95]O
M;F-E(")#86-H92YP:'`B.PH@("`@("`@($`D8V%C:&4@/2!N97<@0V%C:&4H
M)&-A8VAE5'EP92P@)&-A8VAE3W!T:6]N<RD["B`@("`@("`@:68@*&ES7V]B
M:F5C="@D8V%C:&4I("8F("AS=')T;VQO=V5R*&=E=%]C;&%S<R@D8V%C:&4I
M*2`]/2`B8V%C:&4B('Q\(&ES7W-U8F-L87-S7V]F*"1C86-H92P@(F-A8VAE
M(BDI*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V%C:&4@("`@("`@(#T@)&-A
M8VAE.PH@("`@("`@("`@("`D=&AI<RT^7V-A8VAE16YA8FQE9"`]('1R=64[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]C86-H92`@
M("`@("`@/2!N=6QL.PH@("`@("`@("`@("`D=&AI<RT^7V-A8VAE16YA8FQE
M9"`](&9A;'-E.PH@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE
M<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]27T-!0TA%7TE.
M251?1D%)3$5$+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![
M>WL@<V5T56YI='-&;W)M870H*0H@("`@+RHJ"B`@("`@*B!#:&%N9V5S('1H
M92!R97!R97-E;G1A=&EO;B!O9B!T:&4@=6YI=',@*'-T86YD87)D+VUE=')I
M8RD*("`@("`J"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@
M("`@("`@("`@)'5N:71S1F]R;6%T"B`@("`@*B!`<&%R86T@("!A<G)A>2`@
M("`@("`@("`@("`@("`@("`@("`@)&-U<W1O;55N:71S1F]R;6%T"B`@("`@
M*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T56YI
M='-&;W)M870H)'5N:71S1F]R;6%T+"`D8W5S=&]M56YI='-&;W)M870@/2!A
M<G)A>2@I*0H@("`@>PH@("`@("`@('-T871I8R`D86-C97!T961&;W)M871S
M.PH@("`@("`@(&EF("@A:7-S970H)&%C8V5P=&5D1F]R;6%T<RDI('L*("`@
M("`@("`@("`@)&%C8V5P=&5D1F]R;6%T<R`](&%R<F%Y*`H@("`@("`@("`@
M("`@("`@(G1E;7`B("`@/3X@87)R87DH(F,B+"`B9B(I+`H@("`@("`@("`@
M("`@("`@(G9I<R(@("`@/3X@87)R87DH(FTB+"`B:VTB+"`B9G0B+"`B<VTB
M*2P*("`@("`@("`@("`@("`@(")H96EG:'0B(#T^(&%R<F%Y*")M(BP@(F9T
M(BDL"B`@("`@("`@("`@("`@("`B=VEN9"(@("`]/B!A<G)A>2@B;7!H(BP@
M(FMM:"(L(")K="(L(")M<',B+"`B9G!S(BP@(F)F="(I+`H@("`@("`@("`@
M("`@("`@(G!R97,B("`@/3X@87)R87DH(FEN(BP@(FAP82(L(")M8B(L(")M
M;2(L(")A=&TB*2P*("`@("`@("`@("`@("`@(")R86EN(B`@(#T^(&%R<F%Y
M*")I;B(L(")M;2(I"B`@("`@("`@("`@("D["B`@("`@("`@?0H*("`@("`@
M("!I9B`H<W1R;&5N*"1U;FET<T9O<FUA="D@)B8@:6Y?87)R87DH<W1R=&]L
M;W=E<B@D=6YI='-&;W)M871[,'TI+"!A<G)A>2@B8R(L(")M(BP@(G,B*2DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]U;FET<T9O<FUA="`]('-T<G1O;&]W
M97(H)'5N:71S1F]R;6%T>S!]*3L*("`@("`@("`@("`@:68@*"1T:&ES+3Y?
M=6YI='-&;W)M870@/3T@(F,B("8F(&ES7V%R<F%Y*"1C=7-T;VU5;FET<T9O
M<FUA="DI('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1C=7-T;VU5;FET
M<T9O<FUA="!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"1K97DL("1A8V-E<'1E9$9O<FUA
M=',I("8F(&EN7V%R<F%Y*"1V86QU92P@)&%C8V5P=&5D1F]R;6%T<ULD:V5Y
M72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7-T;VU5
M;FET<T9O<FUA=%LD:V5Y72`]("1V86QU93L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF("@D
M=&AI<RT^7W5N:71S1F]R;6%T(#T](")C(BD@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]U;FET<T9O<FUA="`](")S(CL*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!S971(='1P3W!T
M:6]N*"D*("`@("\J*@H@("`@("H@4V5T<R!A;B!O<'1I;VX@9F]R('5S86=E
M(&EN($A45%!?4F5Q=65S="!O8FIE8W1S"B`@("`@*@H@("`@("H@0'!A<F%M
M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1V87).86UE"B`@("`@
M*B!`<&%R86T@("!M:7AE9"`@("`@("`@("`@("`@("`@("`@("`@)'9A<E9A
M;'5E"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V5T2'1T<$]P=&EO;B@D=F%R3F%M92P@)'9A<E9A;'5E*0H@("`@>PH@
M("`@("`@(&EF("AI<U]S=')I;F<H)'9A<DYA;64I("8F("1V87).86UE("$]
M("(B("8F("%E;7!T>2@D=F%R5F%L=64I*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?:'1T<$]P=&EO;G-;)'9A<DYA;65=(#T@)'9A<E9A;'5E.PH@("`@("`@
M('T*("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!S971(='1P5&EM96]U
M="@I"B`@("`O*BH*("`@("`J(%-E=',@=&AE('1I;65O=70@:6X@<V5C;VYD
M<R!F;W(@2%144"!R97%U97-T<PH@("`@("H*("`@("`J($!P87)A;2`@(&EN
M="`@("`@("`@("`@("`@("`@("`@("`@("`D:'1T<%1I;65O=70*("`@("`J
M($!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S971(='1P
M5&EM96]U="@D:'1T<%1I;65O=70I"B`@("!["B`@("`@("`@:68@*&ES7VEN
M="@D:'1T<%1I;65O=70I*2!["B`@("`@("`@("`@("1T:&ES+3Y?:'1T<$]P
M=&EO;G-;(G1I;65O=70B72`]("1H='1P5&EM96]U=#L*("`@("`@("!]"B`@
M("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@<V5T2'1T<%!R;WAY*"D*("`@
M("\J*@H@("`@("H@4V5T<R!T:&4@<')O>'D@9F]R($A45%`@<F5Q=65S=',*
M("`@("`J"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@
M("`@("`@)&AT='!0<F]X>0H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=$AT='!0<F]X>2@D:'1T<%!R;WAY*0H@("`@
M>PH@("`@("`@(&EF("@H)'!R;WAY(#T@<&%R<V5?=7)L*"1H='1P4')O>'DI
M*2`A/3T@9F%L<V4@)B8@)'!R;WAY6R)S8VAE;64B72`]/2`B:'1T<"(I('L*
M("`@("`@("`@("`@:68@*&ES<V5T*"1P<F]X>5LB=7-E<B)=*2`F)B`D<')O
M>'E;(G5S97(B72`A/2`B(BD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]H
M='1P3W!T:6]N<ULB<')O>'E?=7-E<B)=(#T@)'!R;WAY6R)U<V5R(ET["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES<V5T*"1P<F]X>5LB<&%S
M<R)=*2`F)B`D<')O>'E;(G!A<W,B72`A/2`B(BD@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]H='1P3W!T:6]N<ULB<')O>'E?<&%S<R)=(#T@)'!R;WAY
M6R)P87-S(ET["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES<V5T
M*"1P<F]X>5LB:&]S=")=*2`F)B`D<')O>'E;(FAO<W0B72`A/2`B(BD@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]H='1P3W!T:6]N<ULB<')O>'E?:&]S
M=")=(#T@)'!R;WAY6R)H;W-T(ET["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*&ES<V5T*"1P<F]X>5LB<&]R=")=*2`F)B`D<')O>'E;(G!O<G0B
M72`A/2`B(BD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]H='1P3W!T:6]N
M<ULB<')O>'E?<&]R=")=(#T@)'!R;WAY6R)P;W)T(ET["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R
M<F]R*%-%4E9)0T537U=%051(15)?15)23U)?2%144%]04D]865])3E9!3$E$
M+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@('T*("`@("\O
M('U]?0H*("`@("\O('M[>R!G9715;FET<T9O<FUA="@I"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE('-E;&5C=&5D('5N:71S(&9O<FUA=`H@("`@("H*
M("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D
M=6YI='-&;W)M870*("`@("`J($!R971U<FX@(&%R<F%Y"B`@("`@*B!`86-C
M97-S("!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T56YI='-&;W)M
M870H)'5N:71S1F]R;6%T(#T@(B(I"B`@("!["B`@("`@("`@+R\@5&AI<R!I
M<R!C:&5A<"=O('-T=69F"B`@("`@("`@:68@*'-T<FQE;B@D=6YI='-&;W)M
M870I("8F(&EN7V%R<F%Y*'-T<G1O;&]W97(H)'5N:71S1F]R;6%T>S!]*2P@
M87)R87DH(F,B+"`B;2(L(")S(BDI*2!["B`@("`@("`@("`@("1U;FET<T9O
M<FUA="`]('-T<G1O;&]W97(H)'5N:71S1F]R;6%T>S!]*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D=6YI='-&;W)M870@/2`D=&AI<RT^7W5N
M:71S1F]R;6%T.PH@("`@("`@('T*"B`@("`@("`@)&,@/2`D=&AI<RT^7V-U
M<W1O;55N:71S1F]R;6%T.PH@("`@("`@("1M(#T@87)R87DH"B`@("`@("`@
M("`@(")T96UP(B`@(#T^(")C(BP*("`@("`@("`@("`@(G9I<R(@("`@/3X@
M(FMM(BP*("`@("`@("`@("`@(FAE:6=H="(@/3X@(FTB+`H@("`@("`@("`@
M("`B=VEN9"(@("`]/B`B:VUH(BP*("`@("`@("`@("`@(G!R97,B("`@/3X@
M(FUB(BP*("`@("`@("`@("`@(G)A:6XB("`@/3X@(FUM(@H@("`@("`@("D[
M"B`@("`@("`@)',@/2!A<G)A>2@*("`@("`@("`@("`@(G1E;7`B("`@/3X@
M(F8B+`H@("`@("`@("`@("`B=FES(B`@("`]/B`B<VTB+`H@("`@("`@("`@
M("`B:&5I9VAT(B`]/B`B9G0B+`H@("`@("`@("`@("`B=VEN9"(@("`]/B`B
M;7!H(BP*("`@("`@("`@("`@(G!R97,B("`@/3X@(FEN(BP*("`@("`@("`@
M("`@(G)A:6XB("`@/3X@(FEN(@H@("`@("`@("D["@H@("`@("`@(')E='5R
M;B`D>R1U;FET<T9O<FUA='T["B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![
M>WL@<V5T1&%T951I;65&;W)M870H*0H@("`@+RHJ"B`@("`@*B!#:&%N9V5S
M('1H92!R97!R97-E;G1A=&EO;B!O9B!T:6UE(&%N9"!D871E<R`H<V5E(&AT
M='`Z+R]W=W<N<&AP+FYE="]D871E*0H@("`@("H*("`@("`J($!P87)A;2`@
M('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D9&%T949O<FUA=`H@("`@
M("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1T:6UE
M1F]R;6%T"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T1&%T951I;65&;W)M870H)&1A=&5&;W)M870@/2`B(BP@)'1I
M;65&;W)M870@/2`B(BD*("`@('L*("`@("`@("!I9B`H<W1R;&5N*"1D871E
M1F]R;6%T*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V1A=&5&;W)M870@/2`D
M9&%T949O<FUA=#L*("`@("`@("!]"B`@("`@("`@:68@*'-T<FQE;B@D=&EM
M949O<FUA="DI('L*("`@("`@("`@("`@)'1H:7,M/E]T:6UE1F]R;6%T(#T@
M)'1I;65&;W)M870["B`@("`@("`@?0H@("`@?0H@("`@+R\@?7U]"@H@("`@
M+R\@>WM[(&-O;G9E<G1496UP97)A='5R92@I"B`@("`O*BH*("`@("`J($-O
M;G9E<G0@=&5M<&5R871U<F4@8F5T=V5E;B!F(&%N9"!C"B`@("`@*@H@("`@
M("H@0'!A<F%M("`@9FQO870@("`@("`@("`@("`@("`@("`@("`@("1T96UP
M97)A='5R90H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@
M("`@("`@("1F<F]M"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@
M("`@("`@("`@("`@)'1O"B`@("`@*B!`<F5T=7)N("!F;&]A=`H@("`@("H@
M0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;G9E<G14
M96UP97)A='5R92@D=&5M<&5R871U<F4L("1F<F]M+"`D=&\I"B`@("!["B`@
M("`@("`@)&9R;VT@/2!S=')T;VQO=V5R*"1F<F]M>S!]*3L*("`@("`@("`D
M=&\@("`]('-T<G1O;&]W97(H)'1O>S!]*3L*"B`@("`@("`@)')E<W5L="`]
M(&%R<F%Y*`H@("`@("`@("`@("`B9B(@/3X@87)R87DH"B`@("`@("`@("`@
M("`@("`B9B(@/3X@)'1E;7!E<F%T=7)E+"`@("`@("`@("`@(")C(B`]/B`H
M)'1E;7!E<F%T=7)E("T@,S(I("\@,2XX"B`@("`@("`@("`@("DL"B`@("`@
M("`@("`@(")C(B`]/B!A<G)A>2@*("`@("`@("`@("`@("`@(")F(B`]/B`Q
M+C@@*B`D=&5M<&5R871U<F4@*R`S,BP@(F,B(#T^("1T96UP97)A='5R90H@
M("`@("`@("`@("`I"B`@("`@("`@*3L*"B`@("`@("`@<F5T=7)N(')O=6YD
M*"1R97-U;'1;)&9R;VU=6R1T;UTL(#(I.PH@("`@?0H@("`@+R\@?7U]"@H@
M("`@+R\@>WM[(&-O;G9E<G13<&5E9"@I"B`@("`O*BH*("`@("`J($-O;G9E
M<G0@<W!E960@8F5T=V5E;B!M<&@L(&MM:"P@:W0L(&UP<RP@9G!S(&%N9"!B
M9G0*("`@("`J"B`@("`@*B!&=6YC=&EO;B!W:6QL(')E='5R;B`B9F%L<V4B
M('=H96X@=')Y:6YG('1O(&-O;G9E<G0@9G)O;0H@("`@("H@0F5A=69O<G0L
M(&%S(&ET(&ES(&$@<V-A;&4@86YD(&YO="!A('1R=64@;65A<W5R96UE;G0*
M("`@("`J"B`@("`@*B!`<&%R86T@("!F;&]A="`@("`@("`@("`@("`@("`@
M("`@("`@)'-P965D"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@
M("`@("`@("`@("`@)&9R;VT*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@
M("`@("`@("`@("`@("`@("`D=&\*("`@("`J($!R971U<FX@(&9L;V%T?&EN
M='QB;V]L"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!L:6YK("`@
M(&AT='`Z+R]W=W<N<W!C+FYO86$N9V]V+V9A<2]T;W)N861O+V)E875F;W)T
M+FAT;6P*("`@("`J+PH@("`@9G5N8W1I;VX@8V]N=F5R=%-P965D*"1S<&5E
M9"P@)&9R;VTL("1T;RD*("`@('L*("`@("`@("`D9G)O;2`]('-T<G1O;&]W
M97(H)&9R;VTI.PH@("`@("`@("1T;R`@(#T@<W1R=&]L;W=E<B@D=&\I.PH*
M("`@("`@("!S=&%T:6,@)&9A8W1O<CL*("`@("`@("!S=&%T:6,@)&)E875F
M;W)T.PH@("`@("`@(&EF("@A:7-S970H)&9A8W1O<BDI('L*("`@("`@("`@
M("`@)&9A8W1O<B`](&%R<F%Y*`H@("`@("`@("`@("`@("`@(FUP:"(@/3X@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@(FUP:"(@/3X@,2P@("`@("`@
M("`B:VUH(B`]/B`Q+C8P.3,T-"P@(FMT(B`]/B`P+C@V.#DW-C(L(")M<',B
M(#T^(#`N-#0W,#0L("`@(F9P<R(@/3X@,2XT-C8V-C8W"B`@("`@("`@("`@
M("`@("`I+`H@("`@("`@("`@("`@("`@(FMM:"(@/3X@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@(FUP:"(@/3X@,"XV,C$S-S$R+"`B:VUH(B`]/B`Q
M+"`@("`@("`@(FMT(B`]/B`P+C4S.3DU-C@L(")M<',B(#T^(#`N,C<W-S<W
M."P@(F9P<R(@/3X@,"XY,3$S-#0T"B`@("`@("`@("`@("`@("`I+`H@("`@
M("`@("`@("`@("`@(FMT(B`@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@(FUP:"(@/3X@,2XQ-3`W-SDT+"`B:VUH(B`]/B`Q+C@U,BP@("`@(FMT
M(B`]/B`Q+"`@("`@("`@(")M<',B(#T^(#`N-3$T-#0T-"P@(F9P<R(@/3X@
M,2XV.#<X,#DY"B`@("`@("`@("`@("`@("`I+`H@("`@("`@("`@("`@("`@
M(FUP<R(@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@(FUP:"(@/3X@
M,BXR,S8Y,S8S+"`B:VUH(B`]/B`S+C8L("`@("`@(FMT(B`]/B`Q+CDT,S@T
M-#4L(")M<',B(#T^(#$L("`@("`@("`@(F9P<R(@/3X@,RXR.#`X,SDY"B`@
M("`@("`@("`@("`@("`I+`H@("`@("`@("`@("`@("`@(F9P<R(@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@(FUP:"(@/3X@,"XV.#$X,3@R+"`B
M:VUH(B`]/B`Q+C`Y-S(X+"`@(FMT(B`]/B`P+C4Y,C0X,S@L(")M<',B(#T^
M(#`N,S`T."P@("`@(F9P<R(@/3X@,0H@("`@("`@("`@("`@("`@*0H@("`@
M("`@("`@("`I.PH*("`@("`@("`@("`@+R\@0F5A=69O<G0@<V-A;&4L(&UE
M87-U<F5M96YT<R!A<F4@:6X@:VYO=',*("`@("`@("`@("`@)&)E875F;W)T
M(#T@87)R87DH"B`@("`@("`@("`@("`@("`@(#$L("`@,RP@("`V+"`@,3`L
M"B`@("`@("`@("`@("`@("`@,38L("`R,2P@(#(W+"`@,S,L"B`@("`@("`@
M("`@("`@("`@-#`L("`T-RP@(#4U+"`@-C,*("`@("`@("`@("`@*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("@D9G)O;2`]/2`B8F9T(BD@>PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?2!E;'-E:68@*"1T;R`]/2`B
M8F9T(BD@>PH@("`@("`@("`@("`D<W!E960@/2!R;W5N9"@D<W!E960@*B`D
M9F%C=&]R6R1F<F]M75LB:W0B72P@,"D["B`@("`@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\('-I>F5O9B@D8F5A=69O<G0I.R`D:2LK*2!["B`@("`@("`@
M("`@("`@("!I9B`H)'-P965D(#P]("1B96%U9F]R=%LD:5TI('L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)&D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N('-I>F5O9B@D8F5A=69O
M<G0I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!R;W5N
M9"@D<W!E960@*B`D9F%C=&]R6R1F<F]M75LD=&]=+"`R*3L*("`@("`@("!]
M"B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@8V]N=F5R=%!R97-S=7)E
M*"D*("`@("\J*@H@("`@("H@0V]N=F5R="!P<F5S<W5R92!B971W965N(&EN
M+"!H<&$L(&UB+"!M;2!A;F0@871M"B`@("`@*@H@("`@("H@0'!A<F%M("`@
M9FQO870@("`@("`@("`@("`@("`@("`@("`@("1P<F5S<W5R90H@("`@("H@
M0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1F<F]M"B`@
M("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)'1O
M"B`@("`@*B!`<F5T=7)N("!F;&]A=`H@("`@("H@0&%C8V5S<R`@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;G9E<G10<F5S<W5R92@D<')E<W-U
M<F4L("1F<F]M+"`D=&\I"B`@("!["B`@("`@("`@)&9R;VT@/2!S=')T;VQO
M=V5R*"1F<F]M*3L*("`@("`@("`D=&\@("`]('-T<G1O;&]W97(H)'1O*3L*
M"B`@("`@("`@<W1A=&EC("1F86-T;W(["B`@("`@("`@:68@*"%I<W-E="@D
M9F%C=&]R*2D@>PH@("`@("`@("`@("`D9F%C=&]R(#T@87)R87DH"B`@("`@
M("`@("`@("`@("`B:6XB("`@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@(FEN(B`]/B`Q+"`@("`@("`@(")H<&$B(#T^(#,S+C@V,S@X-RP@(FUB
M(B`]/B`S,RXX-C,X.#<L(")M;2(@/3X@,C4N-"P@("`@("`B871M(B`]/B`P
M+C`S,S0R,3,*("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`B
M:'!A(B`@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@(FEN(B`]/B`P
M+C`R.34S+"`@(")H<&$B(#T^(#$L("`@("`@("`@(FUB(B`]/B`Q+"`@("`@
M("`@(")M;2(@/3X@,"XW-3`P-C$V+"`B871M(B`]/B`P+C`P,#DX-CD*("`@
M("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`B;6(B("`@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@(FEN(B`]/B`P+C`R.34S+"`@(")H
M<&$B(#T^(#$L("`@("`@("`@(FUB(B`]/B`Q+"`@("`@("`@(")M;2(@/3X@
M,"XW-3`P-C$V+"`B871M(B`]/B`P+C`P,#DX-CD*("`@("`@("`@("`@("`@
M("DL"B`@("`@("`@("`@("`@("`B;6TB("`@/3X@87)R87DH"B`@("`@("`@
M("`@("`@("`@("`@(FEN(B`]/B`P+C`S.3,W,#$L(")H<&$B(#T^(#$N,S,S
M,C(S.2P@(FUB(B`]/B`Q+C,S,S(R,SDL(")M;2(@/3X@,2P@("`@("`@("`B
M871M(B`]/B`P+C`P,3,Q-3@*("`@("`@("`@("`@("`@("DL"B`@("`@("`@
M("`@("`@("`B871M(B`@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M(FEN(B`]/B`R.2PY,C$R-3@L(")H<&$B(#T^(#$P,3,N,C4P,2P@(FUB(B`]
M/B`Q,#$S+C(U,#$L(")M;2(@/3X@-S4Y+CDY.3DU,BP@(F%T;2(@/3X@,0H@
M("`@("`@("`@("`@("`@*0H@("`@("`@("`@("`I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N(')O=6YD*"1P<F5S<W5R92`J("1F86-T;W);)&9R;VU=
M6R1T;UTL(#(I.PH@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&-O;G9E
M<G1$:7-T86YC92@I"B`@("`O*BH*("`@("`J($-O;G9E<G0@9&ES=&%N8V4@
M8F5T=V5E;B!K;2P@9G0@86YD('-M"B`@("`@*@H@("`@("H@0'!A<F%M("`@
M9FQO870@("`@("`@("`@("`@("`@("`@("`@("1D:7-T86YC90H@("`@("H@
M0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1F<F]M"B`@
M("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)'1O
M"B`@("`@*B!`<F5T=7)N("!F;&]A=`H@("`@("H@0&%C8V5S<R`@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;G9E<G1$:7-T86YC92@D9&ES=&%N
M8V4L("1F<F]M+"`D=&\I"B`@("!["B`@("`@("`@)'1O("`@/2!S=')T;VQO
M=V5R*"1T;RD["B`@("`@("`@)&9R;VT@/2!S=')T;VQO=V5R*"1F<F]M*3L*
M"B`@("`@("`@<W1A=&EC("1F86-T;W(["B`@("`@("`@:68@*"%I<W-E="@D
M9F%C=&]R*2D@>PH@("`@("`@("`@("`D9F%C=&]R(#T@87)R87DH"B`@("`@
M("`@("`@("`@("`B;2(@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M(FTB(#T^(#$L("`@("`@("`@("`@(FMM(B`]/B`Q,#`P+"`@("`@(")F="(@
M/3X@,RXR.#`X,SDX.34L(")S;2(@/3X@,"XP,#`V,C$S-CDY"B`@("`@("`@
M("`@("`@("`I+`H@("`@("`@("`@("`@("`@(FMM(B`]/B!A<G)A>2@*("`@
M("`@("`@("`@("`@("`@("`B;2(@/3X@,"XP,#$L("`@("`@("`B:VTB(#T^
M(#$L("`@("`@("`@(F9T(B`]/B`S,C@P+C@S.3@Y-2P@(G-M(B`]/B`P+C8R
M,3,V.3D*("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`B9G0B
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@(")M(B`]/B`P+C,P-#@L
M("`@("`@(")K;2(@/3X@,"XP,#`S,#0X+"`B9G0B(#T^(#$L("`@("`@("`@
M("`B<VTB(#T^(#`N,#`P,3@Y-`H@("`@("`@("`@("`@("`@*2P*("`@("`@
M("`@("`@("`@(")S;2(@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M(FTB(#T^(#`N,#`Q-C`Y,S0W,BP@(FMM(B`]/B`Q+C8P.3,T-S(L(")F="(@
M/3X@-3(X,"XP,3`V+"`@(")S;2(@/3X@,0H@("`@("`@("`@("`@("`@*0H@
M("`@("`@("`@("`I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(')O=6YD
M*"1D:7-T86YC92`J("1F86-T;W);)&9R;VU=6R1T;UTL(#(I.PH@("`@?0H@
M("`@+R\@?7U]"@H@("`@+R\@>WM[(&-A;&-U;&%T95=I;F1#:&EL;"@I"B`@
M("`O*BH*("`@("`J($-A;&-U;&%T92!W:6YD8VAI;&P@9G)O;2!T96UP97)A
M='5R92!A;F0@=VEN9'-P965D("AE;FAA;F-E9"!F;W)M=6QA*0H@("`@("H*
M("`@("`J(%1E;7!E<F%T=7)E(&AA<R!T;R!B92!E;G1E<F5D(&EN(&1E9R!&
M+"!S<&5E9"!I;B!M<&@A"B`@("`@*@H@("`@("H@0'!A<F%M("`@9FQO870@
M("`@("`@("`@("`@("`@("`@("`@("1T96UP97)A='5R90H@("`@("H@0'!A
M<F%M("`@9FQO870@("`@("`@("`@("`@("`@("`@("`@("1S<&5E9`H@("`@
M("H@0')E='5R;B`@9FQO870*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@
M("H@0&QI;FL@("`@:'1T<#HO+W=W=RYN=W,N;F]A82YG;W8O;VTO=VEN9&-H
M:6QL+PH@("`@("HO"B`@("!F=6YC=&EO;B!C86QC=6QA=&57:6YD0VAI;&PH
M)'1E;7!E<F%T=7)E+"`D<W!E960I"B`@("!["B`@("`@("`@<F5T=7)N(')O
M=6YD*#,U+C<T("L@,"XV,C$U("H@)'1E;7!E<F%T=7)E("T@,S4N-S4@*B!P
M;W<H)'-P965D+"`P+C$V*2`K(#`N-#(W-2`J("1T96UP97)A='5R92`J('!O
M=R@D<W!E960L(#`N,38I*3L*("`@('T*("`@("\O('U]?0H*("`@("\O('M[
M>R!C86QC=6QA=&5(=6UI9&ET>2@I"B`@("`O*BH*("`@("`J($-A;&-U;&%T
M92!H=6UI9&ET>2!F<F]M('1E;7!E<F%T=7)E(&%N9"!D97=P;VEN=`H@("`@
M("H@5&AI<R!I<R!O;FQY(&%N(&%P<')O>&EM871I;VXL('1H97)E(&ES(&YO
M(&5X86-T(&9O<FUU;&$L('1H:7,*("`@("`J(&]N92!H97)E(&ES(&-A;&QE
M9"!-86=N=7,M1F]R;75L80H@("`@("H*("`@("`J(%1E;7!E<F%T=7)E(&%N
M9"!D97=P;VEN="!H879E('1O(&)E(&5N=&5R960@:6X@9&5G($,A"B`@("`@
M*@H@("`@("H@0'!A<F%M("`@9FQO870@("`@("`@("`@("`@("`@("`@("`@
M("1T96UP97)A='5R90H@("`@("H@0'!A<F%M("`@9FQO870@("`@("`@("`@
M("`@("`@("`@("`@("1D97=0;VEN=`H@("`@("H@0')E='5R;B`@9FQO870*
M("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0&QI;FL@("`@:'1T<#HO
M+W=W=RYF87%S+F]R9R]F87%S+VUE=&5O<F]L;V=Y+W1E;7`M9&5W<&]I;G0O
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-A;&-U;&%T94AU;6ED:71Y*"1T96UP
M97)A='5R92P@)&1E=U!O:6YT*0H@("`@>PH@("`@("`@("\O($9I<G-T(&-A
M;&-U;&%T92!S871U<F%T:6]N('-T96%M('!R97-S=7)E(&9O<B!B;W1H('1E
M;7!E<F%T=7)E<PH@("`@("`@(&EF("@D=&5M<&5R871U<F4@/CT@,"D@>PH@
M("`@("`@("`@("`D82`](#<N-3L*("`@("`@("`@("`@)&(@/2`R,S<N,SL*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D82`](#<N-CL*("`@("`@
M("`@("`@)&(@/2`R-#`N-SL*("`@("`@("!]"B`@("`@("`@)'1E;7!34U`@
M/2`V+C$P-S@@*B!P;W<H,3`L("@D82`J("1T96UP97)A='5R92D@+R`H)&(@
M*R`D=&5M<&5R871U<F4I*3L*"B`@("`@("`@:68@*"1D97=0;VEN="`^/2`P
M*2!["B`@("`@("`@("`@("1A(#T@-RXU.PH@("`@("`@("`@("`D8B`](#(S
M-RXS.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1A(#T@-RXV.PH@
M("`@("`@("`@("`D8B`](#(T,"XW.PH@("`@("`@('T*("`@("`@("`D9&5W
M4U-0("`](#8N,3`W."`J('!O=R@Q,"P@*"1A("H@)&1E=U!O:6YT*2`O("@D
M8B`K("1D97=0;VEN="DI.PH*("`@("`@("!R971U<FX@<F]U;F0H,3`P("H@
M)&1E=U-34"`O("1T96UP4U-0+"`Q*3L*("`@('T*("`@("\O('U]?0H*("`@
M("\O('M[>R!C86QC=6QA=&5$97=0;VEN="@I"B`@("`O*BH*("`@("`J($-A
M;&-U;&%T92!D97=P;VEN="!F<F]M('1E;7!E<F%T=7)E(&%N9"!H=6UI9&ET
M>0H@("`@("H@5&AI<R!I<R!O;FQY(&%N(&%P<')O>&EM871I;VXL('1H97)E
M(&ES(&YO(&5X86-T(&9O<FUU;&$L('1H:7,*("`@("`J(&]N92!H97)E(&ES
M(&-A;&QE9"!-86=N=7,M1F]R;75L80H@("`@("H*("`@("`J(%1E;7!E<F%T
M=7)E(&AA<R!T;R!B92!E;G1E<F5D(&EN(&1E9R!#(0H@("`@("H*("`@("`J
M($!P87)A;2`@(&9L;V%T("`@("`@("`@("`@("`@("`@("`@("`D=&5M<&5R
M871U<F4*("`@("`J($!P87)A;2`@(&9L;V%T("`@("`@("`@("`@("`@("`@
M("`@("`D:'5M:61I='D*("`@("`J($!R971U<FX@(&9L;V%T"B`@("`@*B!`
M86-C97-S("!P=6)L:6,*("`@("`J($!L:6YK("`@(&AT='`Z+R]W=W<N9F%Q
M<RYO<F<O9F%Q<R]M971E;W)O;&]G>2]T96UP+61E=W!O:6YT+PH@("`@("HO
M"B`@("!F=6YC=&EO;B!C86QC=6QA=&5$97=0;VEN="@D=&5M<&5R871U<F4L
M("1H=6UI9&ET>2D*("`@('L*("`@("`@("!I9B`H)'1E;7!E<F%T=7)E(#X]
M(#`I('L*("`@("`@("`@("`@)&$@/2`W+C4["B`@("`@("`@("`@("1B(#T@
M,C,W+C,["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&$@/2`W+C8[
M"B`@("`@("`@("`@("1B(#T@,C0P+C<["B`@("`@("`@?0H*("`@("`@("`O
M+R!&:7)S="!C86QC=6QA=&4@<V%T=7)A=&EO;B!S=&5A;2!P<F5S<W5R92!F
M;W(@=&5M<&5R871U<F4*("`@("`@("`D4U-0(#T@-BXQ,#<X("H@<&]W*#$P
M+"`H)&$@*B`D=&5M<&5R871U<F4I("\@*"1B("L@)'1E;7!E<F%T=7)E*2D[
M"@H@("`@("`@("\O(%-T96%M('!R97-S=7)E"B`@("`@("`@)%-0("`]("1H
M=6UI9&ET>2`O(#$P,"`J("134U`["@H@("`@("`@("1V("`@/2!L;V<H)%-0
M("\@-BXQ,#<X+"`Q,"D["@H@("`@("`@(')E='5R;B!R;W5N9"@D8B`J("1V
M("\@*"1A("T@)'8I+"`Q*3L*("`@('T*("`@("\O('U]?0H*("`@("\O('M[
M>R!P;VQA<C)C87)T97-I86XH*0H@("`@+RHJ"B`@("`@*B!#;VYV97)T('!O
M;&%R(&-O;W)D:6YA=&5S('1O(&-A<G1E<VEA;B!C;V]R9&EN871E<PH@("`@
M("H*("`@("`J($!P87)A;2`@(&9L;V%T("`@("`@("`@("`@("`@("`@("`@
M("`D;&%T:71U9&4*("`@("`J($!P87)A;2`@(&9L;V%T("`@("`@("`@("`@
M("`@("`@("`@("`D;&]N9VET=61E"B`@("`@*B!`<F5T=7)N("!A<G)A>0H@
M("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('!O
M;&%R,F-A<G1E<VEA;B@D;&%T:71U9&4L("1L;VYG:71U9&4I"B`@("!["B`@
M("`@("`@)'1H971A(#T@9&5G,G)A9"@D;&%T:71U9&4I.PH@("`@("`@("1P
M:&D@("`](&1E9S)R860H)&QO;F=I='5D92D["@H@("`@("`@("1X(#T@4T52
M5DE#15-?5T5!5$A%4E]2041)55-?14%25$@@*B!C;W,H)'!H:2D@*B!C;W,H
M)'1H971A*3L*("`@("`@("`D>2`](%-%4E9)0T537U=%051(15)?4D%$2553
M7T5!4E1(("H@<VEN*"1P:&DI("H@8V]S*"1T:&5T82D["B`@("`@("`@)'H@
M/2!315)624-%4U]714%42$527U)!1$E54U]%05)42"`@("`@("`@("`@("`J
M('-I;B@D=&AE=&$I.PH*("`@("`@("!R971U<FX@87)R87DH)'@L("1Y+"`D
M>BD["B`@("!]"B`@("`O+R!]?7T*"@H@("`@+R\@>WM[(&-A;&-U;&%T95-U
M;E)I<V53970H*0H@("`@+RHJ"B`@("`@*B!#86QC=6QA=&5S('-U;G)I<V4@
M86YD('-U;G-E="!F;W(@82!L;V-A=&EO;@H@("`@("H*("`@("`J(%1H92!S
M=6X@<&]S:71I;VX@86QG;W)I=&AM('1A:V5N(&9R;VT@=&AE("=54R!.879A
M;"!/8G-E<G9A=&]R>2=S"B`@("`@*B!!;&UA;F%C(&9O<B!#;VUP=71E<G,G
M+"!I;7!L96UE;G1E9"!B>2!+96X@0FQO;VT@/&ME:V%B;&]O;5MA=%UU8V1A
M=FES6V1O=%UE9'4^"B`@("`@*B!F;W(@=&AE('IM86YI;2!P<F]J96-T+"!C
M;VYV97)T960@=&\@0R!B>2!-;W-H92!$;W)O;B`\;6]S9&]R;VY;871=;F5T
M=FES:6]N6V1O=%UN971;9&]T76EL/@H@("`@("H@86YD(&9I;F%L;'D@=&%K
M96X@9G)O;2!T:&4@4$A0-2!S;W5R8V5S(&%N9"!C;VYV97)T960@=&\@;F%T
M:79E(%!(4"!A<R!A('=R87!P97(N"B`@("`@*@H@("`@("H@5&AE(&1A=&4@
M:&%S('1O(&)E(&5N=&5R960@87,@82!T:6UE<W1A;7`A"B`@("`@*@H@("`@
M("H@0'!A<F%M("`@:6YT("`@("`@("`@("`@("`@("`@("`@("`@("1D871E
M"B`@("`@*B!`<&%R86T@("!I;G0@("`@("`@("`@("`@("`@("`@("`@("`@
M)')E=&9O<FUA=`H@("`@("H@0'!A<F%M("`@9FQO870@("`@("`@("`@("`@
M("`@("`@("`@("1L871I='5D90H@("`@("H@0'!A<F%M("`@9FQO870@("`@
M("`@("`@("`@("`@("`@("`@("1L;VYG:71U9&4*("`@("`J($!P87)A;2`@
M(&9L;V%T("`@("`@("`@("`@("`@("`@("`@("`D>F5N:71H"B`@("`@*B!`
M<&%R86T@("!F;&]A="`@("`@("`@("`@("`@("`@("`@("`@)&=M=%]O9F9S
M970*("`@("`J($!P87)A;2`@(&)O;VP@("`@("`@("`@("`@("`@("`@("`@
M("`D<W5N<FES90H@("`@("H@0')E='5R;B`@4$5!4E]%<G)O<GQM:7AE9`H@
M("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%
M4E)/4E]354Y&54Y#4U]$051%7TE.5D%,240*("`@("`J($!T:')O=W,@(%!%
M05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?4U5.1E5.0U-?4D54
M1D]235])3E9!3$E$"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI315)6
M24-%4U]714%42$527T524D]27U5.2TY/5TY?15)23U(*("`@("`J($!A8V-E
M<W,@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!C86QC=6QA=&53=6Y2
M:7-E4V5T*"1D871E+"`D<F5T9F]R;6%T(#T@;G5L;"P@)&QA=&ET=61E(#T@
M;G5L;"P@)&QO;F=I='5D92`](&YU;&PL("1Z96YI=&@@/2!N=6QL+"`D9VUT
M7V]F9G-E="`](&YU;&PL("1S=6YR:7-E(#T@=')U92D*("`@('L*("`@("`@
M("`O+R!$871E(&UU<W0@8F4@=&EM97-T86UP(&9O<B!N;W<*("`@("`@("!I
M9B`H(6ES7VEN="@D9&%T92DI('L*("`@("`@("`@("`@<F5T=7)N(%-E<G9I
M8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/
M4E]354Y&54Y#4U]$051%7TE.5D%,240L(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@?0H*("`@("`@("`O+R!#:&5C:R!F;W(@<')O<&5R(')E='5R
M;B!F;W)M870*("`@("`@("!I9B`H)')E=&9O<FUA="`]/3T@;G5L;"D@>PH@
M("`@("`@("`@("`D<F5T9F]R;6%T("`](%-53D953D-37U)%5%]35%))3D<[
M"B`@("`@("`@?2!E;'-E:68@*"%I;E]A<G)A>2@D<F5T9F]R;6%T+"!A<G)A
M>2A354Y&54Y#4U]2151?5$E-15-404U0+"!354Y&54Y#4U]2151?4U1224Y'
M+"!354Y&54Y#4U]2151?1$]50DQ%*2D@*2!["B`@("`@("`@("`@(')E='5R
M;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(
M15)?15)23U)?4U5.1E5.0U-?4D541D]235])3E9!3$E$+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@+R\@4V5T(&1E9F%U;'0@
M=F%L=65S(&9O<B!C;V]R9&EN871E<PH@("`@("`@(&EF("@D;&%T:71U9&4@
M/3T](&YU;&PI('L*("`@("`@("`@("`@)&QA=&ET=61E("`@/2!354Y&54Y#
M4U]$149!54Q47TQ!5$E4541%.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1L871I='5D92`@(#T@*&9L;V%T*2`D;&%T:71U9&4["B`@("`@("`@
M?0H@("`@("`@(&EF("@D;&]N9VET=61E(#T]/2!N=6QL*2!["B`@("`@("`@
M("`@("1L;VYG:71U9&4@(#T@4U5.1E5.0U-?1$5&055,5%],3TY'25151$4[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&QO;F=I='5D92`@/2`H
M9FQO870I("1L;VYG:71U9&4["B`@("`@("`@?0H@("`@("`@(&EF("@D>F5N
M:71H(#T]/2!N=6QL*2!["B`@("`@("`@("`@(&EF*"1S=6YR:7-E*2!["B`@
M("`@("`@("`@("`@("`D>F5N:71H(#T@4U5.1E5.0U-?4U5.4DE315]:14Y)
M5$@["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D>F5N
M:71H(#T@4U5.1E5.0U-?4U5.4T547UI%3DE42#L*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1Z96YI=&@@("`@(#T@*&9L
M;V%T*2`D>F5N:71H.PH@("`@("`@('T*"B`@("`@("`@+R\@1&5F875L="!V
M86QU92!F;W(@1TU4(&]F9G-E=`H@("`@("`@(&EF("@D9VUT7V]F9G-E="`]
M/3T@;G5L;"D@>PH@("`@("`@("`@("`D9VUT7V]F9G-E="`](&1A=&4H(EHB
M+"`D9&%T92D@+R`S-C`P.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1G;71?;V9F<V5T(#T@*&9L;V%T*2`D9VUT7V]F9G-E=#L*("`@("`@("!]
M"@H@("`@("`@("\O($EF('=E(&AA=F4@4$A0-2P@=&AE;B!A8W0@87,@=W)A
M<'!E<B!F;W(@=&AE(&%P<')O<')I871E(&9U;F-T:6]N<PH@("`@("`@(&EF
M("@D<W5N<FES92`F)B!F=6YC=&EO;E]E>&ES=',H(F1A=&5?<W5N<FES92(I
M*2!["B`@("`@("`@("`@(')E='5R;B!D871E7W-U;G)I<V4H)&1A=&4L("1R
M971F;W)M870L("1L871I='5D92P@)&QO;F=I='5D92P@)'IE;FET:"P@)&=M
M=%]O9F9S970I.PH@("`@("`@('T*("`@("`@("!I9B`H(21S=6YR:7-E("8F
M(&9U;F-T:6]N7V5X:7-T<R@B9&%T95]S=6YS970B*2D@>PH@("`@("`@("`@
M("!R971U<FX@9&%T95]S=6YS970H)&1A=&4L("1R971F;W)M870L("1L871I
M='5D92P@)&QO;F=I='5D92P@)'IE;FET:"P@)&=M=%]O9F9S970I.PH@("`@
M("`@('T*"B`@("`@("`@+R\@07!P87)E;G1L>2!W92!H879E(%!(4#0L('-O
M(&-A;&-U;&%T92!T:&4@;F5C8V5S<V%R>2!S=&5P<R!I;B!N871I=F4@4$A0
M"B`@("`@("`@+R\@4W1E<"`Q.B!&:7)S="!C86QC=6QA=&4@=&AE(&1A>2!O
M9B!T:&4@>65A<@H@("`@("`@("1.(#T@9&%T92@B>B(L("1D871E*2`K(#$[
M"@H@("`@("`@("\O(%-T97`@,CH@0V]N=F5R="!T:&4@;&]N9VET=61E('1O
M(&AO=7(@=F%L=64@86YD(&-A;&-U;&%T92!A;B!A<'!R;WAI;6%T92!T:6UE
M"B`@("`@("`@)&QN9TAO=7(@/2`D;&]N9VET=61E("\@,34["@H@("`@("`@
M("\O(%5S92`Q."!F;W(@<W5N<V5T(&EN<W1E860@;V8@-@H@("`@("`@(&EF
M("@D<W5N<FES92D@>PH@("`@("`@("`@("`O+R!3=6YR:7-E"B`@("`@("`@
M("`@("1T(#T@)$X@*R`H*#8@+2`D;&YG2&]U<BD@+R`R-"D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@+R\@4W5N<V5T"B`@("`@("`@("`@("1T
M(#T@)$X@*R`H*#$X("T@)&QN9TAO=7(I("\@,C0I.PH@("`@("`@('T*"B`@
M("`@("`@+R\@4W1E<"`S.B!#86QC=6QA=&4@=&AE('-U;B=S(&UE86X@86YO
M;6%L>0H@("`@("`@("1-(#T@*#`N.3@U-B`J("1T*2`M(#,N,C@Y.PH*("`@
M("`@("`O+R!3=&5P(#0Z($-A;&-U;&%T92!T:&4@<W5N)W,@=')U92!L;VYG
M:71U9&4*("`@("`@("`D3"`]("1-("L@*#$N.3$V("H@<VEN*&1E9S)R860H
M)$TI*2D@*R`H,"XP,C`@*B!S:6XH9&5G,G)A9"@R("H@)$TI*2D@*R`R.#(N
M-C,T.PH*("`@("`@("!W:&EL92`H)$P@/"`P*2!["B`@("`@("`@("`@("1,
M>"`]("1,("L@,S8P.PH@("`@("`@("`@("!A<W-E<G0H)$QX("$]("1,*3L@
M+R\@87-K:6YG=&AE9W5R=3H@<F5A;&QY(&YE961E9#\*("`@("`@("`@("`@
M)$P@/2`D3'@["B`@("`@("`@?0H*("`@("`@("!W:&EL92`H)$P@/CT@,S8P
M*2!["B`@("`@("`@("`@("1,>"`]("1,("T@,S8P.PH@("`@("`@("`@("!A
M<W-E<G0H)$QX("$]("1,*3L@+R\@87-K:6YG=&AE9W5R=3H@<F5A;&QY(&YE
M961E9#\*("`@("`@("`@("`@)$P@/2`D3'@["B`@("`@("`@?0H*("`@("`@
M("`O+R!3=&5P(#5A.B!#86QC=6QA=&4@=&AE('-U;B=S(')I9VAT(&%S8V5N
M<VEO;@H@("`@("`@("1202`](')A9#)D96<H871A;B@P+CDQ-S8T("H@=&%N
M*&1E9S)R860H)$PI*2DI.PH*("`@("`@("!W:&EL92`H)%)!(#P@,"D@>PH@
M("`@("`@("`@("`D4D%X(#T@)%)!("L@,S8P.PH@("`@("`@("`@("!A<W-E
M<G0H)%)!>"`A/2`D4D$I.R`O+R!A<VMI;F=T:&5G=7)U.B!R96%L;'D@;F5E
M9&5D/PH@("`@("`@("`@("`D4D$@/2`D4D%X.PH@("`@("`@('T*"B`@("`@
M("`@=VAI;&4@*"1202`^/2`S-C`I('L*("`@("`@("`@("`@)%)!>"`]("12
M02`M(#,V,#L*("`@("`@("`@("`@87-S97)T*"1207@@(3T@)%)!*3L@+R\@
M87-K:6YG=&AE9W5R=3H@<F5A;&QY(&YE961E9#\*("`@("`@("`@("`@)%)!
M(#T@)%)!>#L*("`@("`@("!]"@H@("`@("`@("\O(%-T97`@-6(Z(%)I9VAT
M(&%S8V5N<VEO;B!V86QU92!N965D<R!T;R!B92!I;B!T:&4@<V%M92!Q=6%D
M<F%N="!A<R!,"B`@("`@("`@)$QQ=6%D<F%N="`@/2!F;&]O<B@D3"`O(#DP
M*2`J(#DP.PH@("`@("`@("1207%U861R86YT(#T@9FQO;W(H)%)!("\@.3`I
M("H@.3`["@H@("`@("`@("1202`]("1202`K("@D3'%U861R86YT("T@)%)!
M<75A9')A;G0I.PH*("`@("`@("`O+R!3=&5P(#5C.B!2:6=H="!A<V-E;G-I
M;VX@=F%L=64@;F5E9',@=&\@8F4@8V]N=F5R=&5D(&EN=&\@:&]U<G,*("`@
M("`@("`D4D$@+ST@,34["@H@("`@("`@("\O(%-T97`@-CH@0V%L8W5L871E
M('1H92!S=6XG<R!D96-L:6YA=&EO;@H@("`@("`@("1S:6Y$96,@/2`P+C,Y
M-S@R("H@<VEN*&1E9S)R860H)$PI*3L*("`@("`@("`D8V]S1&5C(#T@8V]S
M*&%S:6XH)'-I;D1E8RDI.PH*("`@("`@("`O+R!3=&5P(#=A.B!#86QC=6QA
M=&4@=&AE('-U;B=S(&QO8V%L(&AO=7(@86YG;&4*("`@("`@("`D8V]S2"`]
M("AC;W,H9&5G,G)A9"@D>F5N:71H*2D@+2`H)'-I;D1E8R`J('-I;BAD96<R
M<F%D*"1L871I='5D92DI*2D@+R`H)&-O<T1E8R`J(&-O<RAD96<R<F%D*"1L
M871I='5D92DI*3L*"B`@("`@("`@+R\@6%A8.B!7:&%T)W,@=&AE('5S92!O
M9B!T:&ES(&)L;V-K+BX@/PH@("`@("`@("\O(&EF("AS=6YR:7-E("8F(&-O
M<T@@/B`Q('Q\("%S=6YR:7-E("8F(&-O<T@@/"`M,2D@>PH@("`@("`@("\O
M("`@("!T:')O=R!D;V5S;G1H87!P96XH*3L*("`@("`@("`O+R!]"@H@("`@
M("`@("\O(%-T97`@-V(Z($9I;FES:"!C86QC=6QA=&EN9R!((&%N9"!C;VYV
M97)T(&EN=&\@:&]U<G,*("`@("`@("!I9B`H)'-U;G)I<V4I('L*("`@("`@
M("`@("`@+R\@4W5N<FES90H@("`@("`@("`@("`D2"`](#,V,"`M(')A9#)D
M96<H86-O<R@D8V]S2"DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("\O(%-U;G-E=`H@("`@("`@("`@("`D2"`](')A9#)D96<H86-O<R@D8V]S
M2"DI.PH@("`@("`@('T*("`@("`@("`D2"`]("1(("\@,34["@H@("`@("`@
M("\O(%-T97`@.#H@0V%L8W5L871E(&QO8V%L(&UE86X@=&EM90H@("`@("`@
M("14(#T@)$@@*R`D4D$@+2`H,"XP-C4W,2`J("1T*2`M(#8N-C(R.PH*("`@
M("`@("`O+R!3=&5P(#DZ($-O;G9E<G0@=&\@551#"B`@("`@("`@)%54(#T@
M)%0@+2`D;&YG2&]U<CL*"B`@("`@("`@=VAI;&4@*"155"`\(#`I('L*("`@
M("`@("`@("`@)%54>"`]("155"`K(#(T.PH@("`@("`@("`@("!A<W-E<G0H
M)%54>"`A/2`D550I.R`O+R!A<VMI;F=T:&5G=7)U.B!R96%L;'D@;F5E9&5D
M/PH@("`@("`@("`@("`D550@/2`D551X.PH@("`@("`@('T*"B`@("`@("`@
M=VAI;&4@*"155"`^/2`R-"D@>PH@("`@("`@("`@("`D551X(#T@)%54("T@
M,C0["B`@("`@("`@("`@(&%S<V5R="@D551X("$]("155"D[("\O(&%S:VEN
M9W1H96=U<G4Z(')E86QL>2!N965D960_"B`@("`@("`@("`@("155"`]("15
M5'@["B`@("`@("`@?0H*("`@("`@("`D550@/2`D550@*R`D9VUT7V]F9G-E
M=#L*"B`@("`@("`@+R\@3F]W(&)R:6YG('1H92!R97-U;'0@:6YT;R!T:&4@
M8VAO<V5N(&9O<FUA="!A;F0@<F5T=7)N"B`@("`@("`@<W=I=&-H("@D<F5T
M9F]R;6%T*2!["B`@("`@("`@("`@(&-A<V4@4U5.1E5.0U-?4D547U1)3453
M5$%-4#H*("`@("`@("`@("`@("`@(')E='5R;B!F;&]O<B@D9&%T92`M("@D
M9&%T92`E("@R-"`J(#,V,#`I*2D@*R!F;&]O<B@V,"`J("155"D["B`@("`@
M("`@("`@(&-A<V4@4U5.1E5.0U-?4D547U-44DE.1SH*("`@("`@("`@("`@
M("`@("1.(#T@9FQO;W(H)%54*3L*("`@("`@("`@("`@("`@(')E='5R;B!S
M<')I;G1F*"(E,#)D.B4P,F0B+"`D3BP@9FQO;W(H-C`@*B`H)%54("T@)$XI
M*2D["B`@("`@("`@("`@(&-A<V4@4U5.1E5.0U-?4D547T1/54),13H*("`@
M("`@("`@("`@("`@(')E='5R;B`D550["B`@("`@("`@("`@(&1E9F%U;'0Z
M"B`@("`@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I
M<V5%<G)O<BA315)624-%4U]714%42$527T524D]27U5.2TY/5TY?15)23U(L
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@?0H@("`@+R\@
M?7U]"@H@("`@+R\@>WM[(&=E=%=E871H97))8V]N*"D*("`@("\J*@H@("`@
M("H@1V5T<R!A(&YU;6)E<B!C;W)R97-P;VYD:6YG('1O(&$@=V5A=&AE<B!I
M8V]N+@H@("`@("H*("`@("`J(%1H97-E(&YU;6)E<G,@:G5S="!H87!P96X@
M=&\@8V]R<F5S<&]N9"!W:71H('1H92!I8V]N<R!T:&%T('EO=2!G970@=VET
M:`H@("`@("H@=&AE('=E871H97(N8V]M(%-$2RP@8G5T(&]P96X@=F5R<VEO
M;G,@;V8@=&AE;2!H879E(&)E96X@8W)E871E9"X@26YP=70*("`@("`J(&UU
M<W0@8F4@:6X@<W1A;F1A<F0@=6YI=',N($9O<B!T:&4@:6-O;G,@=&AA="!I
M;F-L=61E(&1A>2]N:6=H="P@=V4@=7-E"B`@("`@*B!T:&4@<')E<V5N="!T
M:6UE(&%N9"!T:&4@<')O=FED960@;&%T+VQO;B!T;R!D971E<FUI;F4@:68@
M=&AE('-U;B!I<R!U<"X*("`@("`J($$@8V]M<&QE=&4@<V5T(&]F(&EC;VX@
M9&5S8W)I<'1I;VYS(&-A;B!B92!F;W5N9"!H97)E.@H@("`@("H@:'1T<#HO
M+W-R86YS:&%F="YW:6YC=7-T;VUI>F4N8V]M+T%R=&EC;&5S+F%S<'@_04E$
M/38P,38U)G4],`H@("`@("H*("`@("`J(%1H97)E(&%R92!A(&YU;6)E<B!O
M9B!I8V]N('-E=',@:&5R93H*("`@("`J(&AT='`Z+R]W=W<N9&5S:W1O<'-I
M9&5B87(N8V]M+V9O<G5M<R]I;F1E>"YP:'`_<VAO=W1O<&EC/3(T-#$F<W0]
M,`H@("`@("H@:'1T<#HO+W=W=RYD97-K=&]P<VED96)A<BYC;VTO9F]R=6US
M+VEN9&5X+G!H<#]S:&]W=&]P:6,].#$Y"B`@("`@*@H@("`@("H@0'!A<F%M
M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1C;VYD:71I;VX@("`@
M("!4:&4@8V]N9&ET:6]N+@H@("`@("H@0'!A<F%M("`@87)R87D@("`@("`@
M("`@("`@("`@("`@("`@("1C;&]U9',@("`@("`@("!4:&4@8VQO=61S(&%T
M('9A<FEO=7,@;&5V96QS+@H@("`@("H@0'!A<F%M("`@9FQO870@("`@("`@
M("`@("`@("`@("`@("`@("1W:6YD("`@("`@("`@("!7:6YD('-P965D(&EN
M(&UP:"X*("`@("`J($!P87)A;2`@(&9L;V%T("`@("`@("`@("`@("`@("`@
M("`@("`D=&5M<&5R871U<F4@("`@5&5M<&5R871U<F4@:6X@9&5G($8N"B`@
M("`@*B!`<&%R86T@("!F;&]A="`@("`@("`@("`@("`@("`@("`@("`@)&QA
M=&ET=61E("`@("`@(%!O:6YT(&QA=&ET=61E+@H@("`@("H@0'!A<F%M("`@
M9FQO870@("`@("`@("`@("`@("`@("`@("`@("1L;VYG:71U9&4@("`@("!0
M;VEN="!L;VYG:71U9&4N"B`@("`@*B!`875T:&]R("!3971H(%!R:6-E("`\
M<V5T:$!P<FEC97!A9V5S+F]R9SX*("`@("`J($!A8V-E<W,@('!U8FQI8PH@
M("`@("HO"B`@("!F=6YC=&EO;B!G971796%T:&5R26-O;B@D8V]N9&ET:6]N
M+"`D8VQO=61S(#T@87)R87DH*2P@)'=I;F0@/2`U+"`D=&5M<&5R871U<F4@
M/2`W,"P@)&QA=&ET=61E(#T@+3,V,"P@)&QO;F=I='5D92`]("TS-C`I"B`@
M("!["B`@("`@("`@+R\@4V5A<F-H(&9O<B!M871C:&5S('1H870@9&]N)W0@
M=7-E('1H92!T:6UE(&]F(&1A>0H@("`@("`@("1H86EL("`@("`]("AB;V]L
M*2!S=')I<W1R*"1C;VYD:71I;VXL(")H86EL(BD["B`@("`@("`@)&1U<W0@
M("`@(#T@*&)O;VPI('-T<FES='(H)&-O;F1I=&EO;BP@(F1U<W0B*2`@("`@
M?'P@*&)O;VPI('-T<FES='(H)&-O;F1I=&EO;BP@(G-A;F0B*3L*("`@("`@
M("`D<VUO:V4@("`@/2`H8F]O;"D@<W1R:7-T<B@D8V]N9&ET:6]N+"`B<VUO
M:V4B*2`@("!\?"`H8F]O;"D@<W1R:7-T<B@D8V]N9&ET:6]N+"`B=F]L8V%N
M:6,@87-H(BD["@H@("`@("`@("\O(%-L:6=H=&QY(&UO<F4@8V]M<&QE>"!M
M871C:&5S('1H870@;6EG:'0@;W(@;6EG:'0@;F]T('5S92!T:&4@=&EM92!O
M9B!D87D*("`@("`@("`D;F5A<B`@("`@/2`H8F]O;"D@<W1R:7-T<B@D8V]N
M9&ET:6]N+"`B=FEC:6YI='DB*2!\?"`H8F]O;"D@<W1R:7-T<B@D8V]N9&ET
M:6]N+"`B<F5C96YT(BD["B`@("`@("`@)&QI9VAT("`@(#T@*&)O;VPI('-T
M<FES='(H)&-O;F1I=&EO;BP@(FQI9VAT(BD["B`@("`@("`@)&AE879Y("`@
M(#T@*&)O;VPI('-T<FES='(H)&-O;F1I=&EO;BP@(FAE879Y(BD["B`@("`@
M("`@)&EC92`@("`@(#T@*&)O;VPI('-T<FES='(H)&-O;F1I=&EO;BP@(FEC
M92(I("`@("`@?'P@*&)O;VPI('-T<FES='(H)&-O;F1I=&EO;BP@(G!E;&QE
M=',B*3L*("`@("`@("`D<F%I;B`@("`@/2`H8F]O;"D@<W1R:7-T<B@D8V]N
M9&ET:6]N+"`B<F%I;B(I.PH@("`@("`@("1S;F]W("`@("`]("AB;V]L*2!S
M=')I<W1R*"1C;VYD:71I;VXL(")S;F]W(BD["B`@("`@("`@)&9O9R`@("`@
M(#T@*&)O;VPI('-T<FES='(H)&-O;F1I=&EO;BP@(F9O9R(I("`@("`@?'P@
M*&)O;VPI('-T<FES='(H)&-O;F1I=&EO;BP@(G-P<F%Y(BD@("`@("`@('Q\
M("AB;V]L*2!S=')I<W1R*"1C;VYD:71I;VXL(")M:7-T(BD["B`@("`@("`@
M)&AA>F4@("`@(#T@*&)O;VPI('-T<FES='(H)&-O;F1I=&EO;BP@(FAA>F4B
M*3L*("`@("`@("`D=',@("`@("`@/2`H8F]O;"D@<W1R:7-T<B@D8V]N9&ET
M:6]N+"`B=&AU;F1E<G-T;W)M(BD["B`@("`@("`@)&9R965Z:6YG(#T@*&)O
M;VPI('-T<FES='(H)&-O;F1I=&EO;BP@(F9R965Z:6YG(BD["B`@("`@("`@
M)'=I;F0@("`@(#T@*&)O;VPI('-T<FES='(H)&-O;F1I=&EO;BP@(G-Q=6%L
M;"(I("`@?'P@)'=I;F0@/B`R-3L*("`@("`@("`D;G-W("`@("`@/2`H8F]O
M;"D@<W1R:7-T<B@D8V]N9&ET:6]N+"`B;F\@<VEG;FEF:6-A;G0@=V5A=&AE
M<B(I.PH@("`@("`@("1H;W0@("`@("`]("1T96UP97)A='5R92`^(#DU.PH@
M("`@("`@("1F<FEG:60@("`]("1T96UP97)A='5R92`\(#4["@H*("`@("`@
M("!I9B`H)&AA:6PI('L*("`@("`@("`@("`@<F5T=7)N(#8[("`O+R!(86EL
M"B`@("`@("`@?0H@("`@("`@(&EF("@D9'5S="D@>PH@("`@("`@("`@("!R
M971U<FX@,3D[("\O($1U<W0*("`@("`@("!]"B`@("`@("`@:68@*"1S;6]K
M92D@>PH@("`@("`@("`@("!R971U<FX@,C([("\O(%-M;VME"B`@("`@("`@
M?0H*("`@("`@("`O+R!'970@<V]M92!O9B!T:&4@9&%N9V5R;W5S(&-O;F1I
M=&EO;G,@9FES=`H@("`@("`@(&EF("@D<F%I;B`F)B`D<VYO=R`F)B`H)&EC
M92!\?"`D9G)E97II;F<I*2!["B`@("`@("`@("`@(')E='5R;B`W.R`@+R\@
M26-Y+T-L;W5D<R!286EN+5-N;W<*("`@("`@("!]"B`@("`@("`@:68@*"@D
M=',@?'P@)')A:6XI("8F("@D:6-E('Q\("1F<F5E>FEN9RDI('L*("`@("`@
M("`@("`@<F5T=7)N(#$P.R`O+R!)8WDO4F%I;@H@("`@("`@('T*("`@("`@
M("!I9B`H*"1F;V<@?'P@)&AA>F4I("8F("@D:6-E('Q\("1F<F5E>FEN9RDI
M('L*("`@("`@("`@("`@<F5T=7)N(#@[("`O+R!)8WDO2&%Z92!286EN"B`@
M("`@("`@?0H@("`@("`@(&EF("@D<F%I;B`F)B`D<VYO=RD@>PH@("`@("`@
M("`@("!R971U<FX@-3L@("\O($-L;W5D>2]3;F]W+5)A:6X@36EX"B`@("`@
M("`@?0H@("`@("`@(&EF("@D9F]G("8F("1R86EN*2!["B`@("`@("`@("`@
M(')E='5R;B`Y.R`@+R\@2&%Z92]286EN"B`@("`@("`@?0H@("`@("`@(&EF
M("@D=VEN9"`F)B`D<F%I;BD@>PH@("`@("`@("`@("!R971U<FX@,3L@("\O
M(%=I;F0O4F%I;@H@("`@("`@('T*("`@("`@("!I9B`H)'=I;F0@)B8@)'-N
M;W<I('L*("`@("`@("`@("`@<F5T=7)N(#0S.R`O+R!7:6YD>2]3;F]W"B`@
M("`@("`@?0H@("`@("`@(&EF("@D<VYO=R`F)B`D;&EG:'0I('L*("`@("`@
M("`@("`@<F5T=7)N(#$S.R`O+R!&;'5R<FEE<PH@("`@("`@('T*("`@("`@
M("!I9B`H)&QI9VAT("8F("1R86EN*2!["B`@("`@("`@("`@(')E='5R;B`Q
M,3L@+R\@3&EG:'0@4F%I;@H@("`@("`@('T*"B`@("`@("`@+R\@1V5T('1H
M92!M87AI;75M(&-O=F5R86=E(&]F('1H92!C;&]U9',@870@86YY(&AE:6=H
M="X@1F]R(&UO<W0*("`@("`@("`O+R!P96]P;&4L(&]V97)C87-T(&%T(#$P
M,#!F="!I<R!T:&4@<V%M92!A<R!O=F5R8V%S="!A="`Q,#`P,&9T+@H@("`@
M("`@("\O"B`@("`@("`@+R\@,"`]/2!C;&5A<BP@,2`]/2!H87IE>2P@,B`]
M/2!P87)T;'D@8VQO=61Y+"`S(#T](&UO<W1L>2!C;&]U9'DL(#0@/3T@;W9E
M<F-A<W0*("`@("`@("`D8V]V97)A9V4@/2`P.PH@("`@("`@(&9O<F5A8V@@
M*"1C;&]U9',@87,@)&QA>65R*2!["B`@("`@("`@("`@(&EF("@D8V]V97)A
M9V4@/"`Q("8F('-T<FES='(H)&QA>65R6R)A;6]U;G0B72P@(F9E=R(I*2![
M"B`@("`@("`@("`@("`@("`D8V]V97)A9V4@/2`Q.PH@("`@("`@("`@("!]
M(&5L<V5I9B`H)&-O=F5R86=E(#P@,B`F)B!S=')I<W1R*"1L87EE<ELB86UO
M=6YT(ETL(")S8V%T=&5R960B*2D@>PH@("`@("`@("`@("`@("`@)&-O=F5R
M86=E(#T@,CL*("`@("`@("`@("`@?2!E;'-E:68@*"1C;W9E<F%G92`\(#,@
M)B8@*'-T<FES='(H)&QA>65R6R)A;6]U;G0B72P@(F)R;VME;B(I('Q\('-T
M<FES='(H)&QA>65R6R)A;6]U;G0B72P@(F-U;75L=7,B*2DI('L*("`@("`@
M("`@("`@("`@("1C;W9E<F%G92`](#,["B`@("`@("`@("`@('T@96QS96EF
M("@D8V]V97)A9V4@/"`T("8F('-T<FES='(H)&QA>65R6R)A;6]U;G0B72P@
M(F]V97)C87-T(BDI('L*("`@("`@("`@("`@("`@("1C;W9E<F%G92`](#0[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($-H96-K(&EF
M(&ET(&ES(&1A>2!O<B!N;W0N(#`@:7,@;FEG:'0L(#(@:7,@9&%Y+"!A;F0@
M,2!I<R!U;FMN;W=N"B`@("`@("`@+R\@;W(@='=I;&EG:'0@*'XH*WPM*3$@
M:&]U<B!O9B!S=6YR:7-E+W-U;G-E="DN($YO=&4@=&AA="!T=VEL:6=H="!I
M<VXG=`H@("`@("`@("\O(&%L=V%Y<R!A8V-U<F%T92!B96-A=7-E(&]F(&ES
M<W5E<R!W<F%P<&EN9R!A<F]U;F0@=&AE(#(T:'(@8VQO8VLN($]H('=E;&PN
M+BX*("`@("`@("!I9B`H)&QA=&ET=61E(#P@.3`@)B8@)&QA=&ET=61E(#X@
M+3DP("8F("1L;VYG:71U9&4@/"`Q.#`@)B8@)&QO;F=I='5D92`^("TQ.#`I
M('L*("`@("`@("`@("`@+R\@0V%L8W5L871E('-U;G)I<V4O<W5N<V5T(&%N
M9"!C=7)R96YT('1I;64@:6X@1TU4"B`@("`@("`@("`@("1S=6YR:7-E("`@
M/2`D=&AI<RT^8V%L8W5L871E4W5N4FES95-E="AG;6UK=&EM92@I+"!354Y&
M54Y#4U]2151?5$E-15-404U0+"`D;&%T:71U9&4L("1L;VYG:71U9&4L(%-%
M4E9)0T537U=%051(15)?4U5.1E5.0U-?4U5.4DE315]:14Y)5$@L(#`L('1R
M=64I.PH@("`@("`@("`@("`D<W5N<V5T("`@(#T@)'1H:7,M/F-A;&-U;&%T
M95-U;E)I<V53970H9VUM:W1I;64H*2P@4U5.1E5.0U-?4D547U1)34535$%-
M4"P@)&QA=&ET=61E+"`D;&]N9VET=61E+"!315)624-%4U]714%42$527U-5
M3D953D-37U-53E))4T5?6D5.251(+"`P+"!F86QS92D["B`@("`@("`@("`@
M("1T:6UE3V9$87D@/2!G;6UK=&EM92@I.PH*("`@("`@("`@("`@+R\@3F]W
M('1H870@=V4@:&%V92!T:&4@<W5N<FES92]S=6YS970@=&EM97,@86YD('1H
M92!C=7)R96YT('1I;64L"B`@("`@("`@("`@("\O('=E(&YE960@=&\@9FEG
M=7)E(&]U="!I9B!I="!I<R!D87DL(&YI9VAT+"!O<B!T=VEL:6=H="X@5W)A
M<'!I;F<*("`@("`@("`@("`@+R\@=&AE<V4@=&EM97,@87)O=6YD('1H92`R
M-&AR(&-L;V-K(&ES(&$@<&%I;BX*("`@("`@("`@("`@:68@*"1S=6YR:7-E
M(#P@)'-U;G-E="D@>PH@("`@("`@("`@("`@("`@:68@*"1T:6UE3V9$87D@
M/B`H)'-U;G)I<V4@*R`S-C`P*2`F)B`D=&EM94]F1&%Y(#P@*"1S=6YS970@
M+2`S-C`P*2D@>PH@("`@("`@("`@("`@("`@("`@("1I<T1A>2`](#(["B`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H)'1I;65/9D1A>2`^("@D<W5N<FES
M92`M(#,V,#`I("8F("1T:6UE3V9$87D@/"`H)'-U;G-E="`K(#,V,#`I*2![
M"B`@("`@("`@("`@("`@("`@("`@)&ES1&%Y(#T@,3L*("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&ES1&%Y(#T@,#L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@(&EF("@D=&EM94]F1&%Y(#P@*"1S=6YR:7-E("T@,S8P,"D@
M)B8@)'1I;65/9D1A>2`^("@D<W5N<V5T("L@,S8P,"DI('L*("`@("`@("`@
M("`@("`@("`@("`D:7-$87D@/2`P.PH@("`@("`@("`@("`@("`@?2!E;'-E
M:68@*"1T:6UE3V9$87D@/"`H)'-U;G)I<V4@*R`S-C`P*2`F)B`D=&EM94]F
M1&%Y(#X@*"1S=6YS970@+2`S-C`P*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1I<T1A>2`](#$["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1I<T1A>2`](#(["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!$
M969A=6QT('1O('1W:6QI9VAT(&)E8V%U<V4@:70@=&5N9',@=&\@:&%V92!N
M975T<F%L(&EC;VYS+@H@("`@("`@("`@("`D:7-$87D@/2`Q.PH@("`@("`@
M('T*"B`@("`@("`@+R\@1V5N97)A;"!P<F5C:7!I=&%T:6]N"B`@("`@("`@
M:68@*"1T<R`F)B`D;F5A<BD@>PH@("`@("`@("`@("!S=VET8V@@*"1I<T1A
M>2D@>PH@("`@("`@("`@("`@("`@8V%S92`P.@H@("`@("`@("`@("`@("`@
M8V%S92`Q.@H@("`@("`@("`@("`@("`@("`@(')E='5R;B`S.#L@+R\@3&EG
M:'1N:6YG"B`@("`@("`@("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N(#,W.R`O+R!,:6=H=&YI;F<O1&%Y"B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@:68@*"1T<RD@>PH@("`@("`@("`@("!S
M=VET8V@@*"1I<T1A>2D@>PH@("`@("`@("`@("`@("`@8V%S92`P.@H@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`T-SL@+R\@5&AU;F1E<G-T;W)M+TYI
M9VAT"B`@("`@("`@("`@("`@("!C87-E(#$Z"B`@("`@("`@("`@("`@("!C
M87-E(#(Z"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(#`[("`O+R!286EN
M+TQI9VAT;FEN9PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF
M("@D<VYO=RD@>PH@("`@("`@("`@("!S=VET8V@@*"1I<T1A>2D@>PH@("`@
M("`@("`@("`@("`@8V%S92`P.@H@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`T-CL@+R\@4VYO=R].:6=H=`H@("`@("`@("`@("`@("`@8V%S92`Q.@H@
M("`@("`@("`@("`@("`@8V%S92`R.@H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`T,3L@+R\@4VYO=PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(&EF("@D<F%I;BD@>PH@("`@("`@("`@("!S=VET8V@@*"1I<T1A>2D@
M>PH@("`@("`@("`@("`@("`@8V%S92`P.@H@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`T-3L@+R\@4F%I;B].:6=H=`H@("`@("`@("`@("`@("`@8V%S
M92`Q.@H@("`@("`@("`@("`@("`@("`@(')E='5R;B`T,#L@+R\@4F%I;@H@
M("`@("`@("`@("`@("`@8V%S92`R.@H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`S.3L@+R\@4F%I;B]$87D*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+R\@0VQO=60@8V]N9&ET:6]N<R!N96%R('1H92!G<F]U;F0*
M("`@("`@("!I9B`H)&9O9RD@>PH@("`@("`@("`@("!R971U<FX@,C`[("\O
M($9O9PH@("`@("`@('T*("`@("`@("!I9B`H)&AA>F4I('L*("`@("`@("`@
M("`@<F5T=7)N(#(Q.R`O+R!(87IE"B`@("`@("`@?0H*("`@("`@("`O+R!#
M;&]U9"!C;VYD:71I;VYS"B`@("`@("`@:68@*"1C;W9E<F%G92`]/2`T*2![
M"B`@("`@("`@("`@(')E='5R;B`R-CL@+R\@36]S=&QY($-L;W5D>0H@("`@
M("`@('T*("`@("`@("!I9B`H)&-O=F5R86=E(#T](#,I('L*("`@("`@("`@
M("`@<W=I=&-H("@D:7-$87DI('L*("`@("`@("`@("`@("`@(&-A<V4@,#H*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@,C<[("\O($UO<W1L>2!#;&]U
M9'DO3FEG:'0*("`@("`@("`@("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@,C8[("\O($UO<W1L>2!#;&]U9'D*("`@("`@("`@
M("`@("`@(&-A<V4@,CH*("`@("`@("`@("`@("`@("`@("!R971U<FX@,C@[
M("\O($UO<W1L>2!#;&]U9'DO1&%Y"B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@:68@*"1C;W9E<F%G92`]/2`R*2!["B`@("`@("`@("`@('-W
M:71C:"`H)&ES1&%Y*2!["B`@("`@("`@("`@("`@("!C87-E(#`Z"B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N(#(Y.R`O+R!087)T;'D@0VQO=61Y+TYI
M9VAT"B`@("`@("`@("`@("`@("!C87-E(#$Z"B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(#(V.R`O+R!-;W-T;'D@0VQO=61Y"B`@("`@("`@("`@("`@
M("!C87-E(#(Z"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(#,P.R`O+R!0
M87)T;'D@0VQO=61Y+T1A>0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(&EF("@D8V]V97)A9V4@/3T@,2D@>PH@("`@("`@("`@("!S=VET8V@@
M*"1I<T1A>2D@>PH@("`@("`@("`@("`@("`@8V%S92`P.@H@("`@("`@("`@
M("`@("`@8V%S92`Q.@H@("`@("`@("`@("`@("`@("`@(')E='5R;B`S,SL@
M+R\@2&%Z>2].:6=H=`H@("`@("`@("`@("`@("`@8V%S92`R.@H@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`S-#L@+R\@2&%Z>2]$87D*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@0V%T8V@M86QL<PH@("`@("`@
M(&EF("@D=VEN9"D@>PH@("`@("`@("`@("!R971U<FX@,C,[("\O(%=I;F0*
M("`@("`@("!]"B`@("`@("`@:68@*"1H;W0I('L*("`@("`@("`@("`@<F5T
M=7)N(#,V.R`O+R!(;W0A"B`@("`@("`@?0H@("`@("`@(&EF("@D9G)I9VED
M*2!["B`@("`@("`@("`@(')E='5R;B`R-3L@+R\@1G)I9VED"B`@("`@("`@
M?0H*("`@("`@("!I9B`H)&YS=RD@>PH@("`@("`@("`@("!S=VET8V@@*"1I
M<T1A>2D@>PH@("`@("`@("`@("`@("`@8V%S92`P.@H@("`@("`@("`@("`@
M("`@8V%S92`Q.@H@("`@("`@("`@("`@("`@("`@("\O(%5S92!N:6=H="!F
M;W(@='=I;&EG:'0@8F5C875S92!T:&4@;6]O;B!I<R!G96YE<F%L;'D*("`@
M("`@("`@("`@("`@("`@("`O+R!O=70@=&AE;BP@<V\@:70@=VEL;"!M871C
M:"!W:71H(&UO<W0@:6-O;B!S971S+@H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`S,3L@+R\@0VQE87(@3FEG:'0*("`@("`@("`@("`@("`@(&-A<V4@
M,CH*("`@("`@("`@("`@("`@("`@("!R971U<FX@,S([("\O($-L96%R($1A
M>0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@(FYA
M(CL*("`@('T*("`@("\O('U]?0I]"B\O('U]?0H_/@HN+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O4V5R=FEC97,O5V5A=&AE<B]%:G-E+G!H<```
M````````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#(U,3(`,3`U,34T,S,W,S0`
M,#(S,S<Q`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI
M9G1W:61T:#TT('-O9G1T86)S=&]P/30@9F]L9&UE=&AO9#UM87)K97(Z("HO
M"@HO*BH*("H@4$5!4CHZ4V5R=FEC97-?5V5A=&AE<E]%:G-E"B`J"B`J(%!(
M4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J(#Q,24-%3E-%/@H@*B!#;W!Y<FEG
M:'0@*&,I(#(P,#4L($%L97AA;F1E<B!7:7)T>@H@*B!!;&P@<FEG:'1S(')E
M<V5R=F5D+@H@*@H@*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C
M92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D:69I
M8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO
M=VEN9R!C;VYD:71I;VYS"B`J(&%R92!M970Z"B`J(&\@4F5D:7-T<FEB=71I
M;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y
M<FEG:'0@;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N
M9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J(&\@4F5D:7-T<FEB=71I
M;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C
M;W!Y<FEG:'0@;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS
M(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE(&1O8W5M96YT
M871I;VX*("H@("!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I
M=&@@=&AE(&1I<W1R:6)U=&EO;BX*("H@;R!.96ET:&5R('1H92!N86UE(&]F
M('1H92!S;V9T=V%R92!N;W(@=&AE(&YA;65S(&]F(&ET<R!C;VYT<FEB=71O
M<G,*("H@("!M87D@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O
M9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4*("H@("!W:71H;W5T
M('-P96-I9FEC('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H*("H@5$A)
M4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%
M4E,@04Y$($-/3E1224)55$]24R`B05,@25,B"B`J($%.1"!!3ED@15A04D53
M4R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"!,
M24U)5$5$(%1/+"!42$4*("H@24U03$E%1"!705)204Y42453($]&($U%4D-(
M04Y404))3$E462!!3D0@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/
M4T4*("H@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#
M3U!94DE'2%0@3U=.15(@3U(@0T].5%))0E543U)3($)%"B`J($Q)04),12!&
M3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL(%-014-)04PL
M($5814U03$%262P@3U(*("H@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,
M541)3D<L($)55"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8*("H@
M4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L($1!
M5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3"B`J($E.5$524E505$E/3BD@
M2$]7159%4B!#0553140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519
M+"!72$542$52($E."B`J($-/3E1204-4+"!35%))0U0@3$E!0DE,2519+"!/
M4B!43U)4("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I"B`J
M($%225-)3D<@24X@04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3(%-/
M1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,2519
M($]&(%-50T@@1$%-04=%+@H@*B`\+TQ)0T5.4T4^"B`J"B`J($!C871E9V]R
M>2`@("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@(%-E<G9I8V5S7U=E
M871H97(*("H@0&%U=&AO<B`@("`@($%L97AA;F1E<B!7:7)T>B`\86QE>$!P
M8S1P+FYE=#X*("H@0&-O<'ER:6=H="`@(#(P,#4@06QE>&%N9&5R(%=I<G1Z
M"B`J($!L:6-E;G-E("`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI
M8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I
M;VX@("`@($-64SH@)$ED.B!%:G-E+G!H<"QV(#$N,C,@,C`P-2\Q,2\Q,R`R
M,3HU-CHQ-B!E<G4@17AP("0*("H@0&QI;FL@("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]397)V:6-E<U]796%T:&5R"B`J($!L:6YK("`@
M("`@("!H='1P.B\O=W=W+F5J<V4N8V]M+W-E<G9I8V5S+W=E871H97)?>&UL
M7W=E8E]S97)V:6-E<RYH=&T*("H@0&5X86UP;&4@("`@(&5X86UP;&5S+V5J
M<V4M8F%S:6,N<&AP("`@("`@("`@("`@(&5J<V4M8F%S:6,N<&AP"B`J($!F
M:6QE<V]U<F-E"B`J+PH*<F5Q=6ER95]O;F-E(")397)V:6-E<R]796%T:&5R
M+T-O;6UO;BYP:'`B.PH*+R\@>WM[(&-L87-S(%-E<G9I8V5S7U=E871H97)?
M16IS90HO*BH*("H@5&AI<R!C;&%S<R!A8W1S(&%S(&%N(&EN=&5R9F%C92!T
M;R!T:&4@<V]A<"!S97)V:6-E(&]F($5*4T4N($ET(')E=')I979E<PH@*B!C
M=7)R96YT('=E871H97(@9&%T82!A;F0@9F]R96-A<W1S(&)A<V5D(&]N('!O
M<W1A;"!C;V1E<R`H6DE0*2X*("H*("H@0W5R<F5N=&QY('1H:7,@<V5R=FEC
M92!I<R!O;FQY(&%V86EL86)L92!F;W(@55,@=&5R<FET;W)Y+@H@*@H@*B!&
M;W(@82!W;W)K:6YG(&5X86UP;&4L('!L96%S92!T86ME(&$@;&]O:R!A=`H@
M*B`@("`@9&]C<R]397)V:6-E<U]796%T:&5R+V5X86UP;&5S+V5J<V4M8F%S
M:6,N<&AP"B`J"B`J($!C871E9V]R>2`@("!796(@4V5R=FEC97,*("H@0'!A
M8VMA9V4@("`@(%-E<G9I8V5S7U=E871H97(*("H@0&%U=&AO<B`@("`@($%L
M97AA;F1E<B!7:7)T>B`\86QE>$!P8S1P+FYE=#X*("H@0&-O<'ER:6=H="`@
M(#(P,#4@06QE>&%N9&5R(%=I<G1Z"B`J($!L:6-E;G-E("`@("!H='1P.B\O
M=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@
M0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@(%)E;&5A<V4Z(#$N-"XP"B`J
M($!L:6YK("`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4V5R
M=FEC97-?5V5A=&AE<@H@*B!`;&EN:R`@("`@("`@:'1T<#HO+W=W=RYE:G-E
M+F-O;2]S97)V:6-E<R]W96%T:&5R7WAM;%]W96)?<V5R=FEC97,N:'1M"B`J
M($!E>&%M<&QE("`@("!E>&%M<&QE<R]E:G-E+6)A<VEC+G!H<"`@("`@("`@
M("`@("!E:G-E+6)A<VEC+G!H<`H@*B\*8VQA<W,@4V5R=FEC97-?5V5A=&AE
M<E]%:G-E(&5X=&5N9',@4V5R=FEC97-?5V5A=&AE<E]#;VUM;VX@>PH*("`@
M("\O('M[>R!P<F]P97)T:65S"B`@("`O*BH*("`@("`J(%=31$P@;V)J96-T
M+"!P<F]V:61E9"!B>2!%2E-%"B`@("`@*@H@("`@("H@0'9A<B`@("`@;V)J
M96-T("`@("`@("`@("`@("`@("`@("`@("1?=W-D;`H@("`@("H@0&%C8V5S
M<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]W<V1L.PH*("`@("\J*@H@
M("`@("H@4T]!4"!O8FIE8W0@=&\@86-C97-S('=E871H97(@9&%T82P@<')O
M=FED960@8GD@14I310H@("`@("H*("`@("`J($!V87(@("`@(&]B:F5C="`@
M("`@("`@("`@("`@("`@("`@("`D7W=E871E<E-O87`*("`@("`J($!A8V-E
M<W,@('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?=V5A=&AE<E-O87`["B`@
M("`O+R!]?7T*"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!297%U:7)E<R!33T%0('1O
M(&)E(&EN<W1A;&QE9`H@("`@("H*("`@("`J($!P87)A;2`@(&%R<F%Y("`@
M("`@("`@("`@("`@("`@("`@("`D;W!T:6]N<PH@("`@("H@0'!A<F%M("`@
M;6EX960@("`@("`@("`@("`@("`@("`@("`@("1E<G)O<@H@("`@("H@0'1H
M<F]W<R`@4$5!4E]%<G)O<@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@
M("HO"B`@("!F=6YC=&EO;B!397)V:6-E<U]796%T:&5R7T5J<V4H)&]P=&EO
M;G,L("8D97)R;W(I"B`@("!["B`@("`@("`@)'!E<G)O<B`](&YU;&P["B`@
M("`@("`@)'1H:7,M/E-E<G9I8V5S7U=E871H97)?0V]M;6]N*"1O<'1I;VYS
M+"`D<&5R<F]R*3L*("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%
M<G)O<B@D<&5R<F]R*2D@>PH@("`@("`@("`@("`D97)R;W(@/2`D<&5R<F]R
M.PH@("`@("`@('T*("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!?8V]N
M;F5C=%-E<G9E<B@I"B`@("`O*BH*("`@("`J($-O;FYE8W1S('1O('1H92!3
M3T%0('-E<G9E<B!A;F0@<F5T<FEE=F5S('1H92!74T1,(&1A=&$*("`@("`J
M"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&)O;VP*("`@("`J($!T:')O
M=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?5U)/3D=?
M4T525D527T1!5$$*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V-O;FYE8W1397)V97(H*0H@("`@>PH@("`@("`@(&EN
M8VQU9&5?;VYC92`B4T]!4"]#;&EE;G0N<&AP(CL*("`@("`@("`D=&AI<RT^
M7W=S9&P@/2!N97<@4T]!4%]74T1,*")H='1P.B\O=W=W+F5J<V4N8V]M+U=E
M871H97)397)V:6-E+U-E<G9I8V4N87-M>#]74T1,(BP@)'1H:7,M/E]H='1P
M3W!T:6]N<RD["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?=W-D;"T^9F%U
M;'0I("8F(%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'1H:7,M/E]W<V1L
M+3YF875L="DI('L*("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H
M97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E]74D].1U]3
M15)615)?1$%402P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@
M("`@("`@(&5V86PH)'1H:7,M/E]W<V1L+3YG96YE<F%T94%L;%!R;WAI97,H
M*2D["B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H(E=E8E-E<G9I8V5?4V5R
M=FEC95]397)V:6-E4V]A<"(I*2!["B`@("`@("`@("`@(')E='5R;B!397)V
M:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)2
M3U)?5U)/3D=?4T525D527T1!5$$L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("`@("`@?0H@("`@("`@("1T:&ES+3Y?=V5A=&AE<E-O87`@/2`F;F5W(%=E
M8E-E<G9I8V5?4V5R=FEC95]397)V:6-E4V]A<#L*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@7V-H96-K3&]C
M871I;VY)1"@I"B`@("`O*BH*("`@("`J($-H96-K<R!T:&4@:60@9F]R('9A
M;&ED('9A;'5E<R!A;F0@=&AU<R!P<F5V96YT<R!S:6QL>2!R97%U97-T<R!T
M;R!%2E-%('-E<G9E<@H@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@
M("`@("`@("`@("`@("`@("`@("`D:60*("`@("`J($!R971U<FX@(%!%05)?
M17)R;W)\8F]O;`H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#
M15-?5T5!5$A%4E]%4E)/4E].3U],3T-!5$E/3@H@("`@("H@0'1H<F]W<R`@
M4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E])3E9!3$E$7TQ/
M0T%424]."B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]C:&5C:TQO8V%T:6]N240H)&ED*0H@("`@>PH@("`@("`@(&EF
M("AI<U]A<G)A>2@D:60I('Q\(&ES7V]B:F5C="@D:60I('Q\("%S=')L96XH
M)&ED*2D@>PH@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ
M<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]27TY/7TQ/0T%424].
M+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T@96QS96EF("@A8W1Y
M<&5?9&EG:70H)&ED*2!\?"`H<W1R;&5N*"1I9"D@(3T@-2DI('L*("`@("`@
M("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T52
M5DE#15-?5T5!5$A%4E]%4E)/4E])3E9!3$E$7TQ/0T%424].+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@<V5A<F-H3&]C871I;VXH
M*0H@("`@+RHJ"B`@("`@*B!%2E-%(&]F9F5R<R!N;R!S96%R8V@@9G5N8W1I
M;VX@=&\@9&%T92P@<V\@=&AI<R!F=6YC=&EO;B!I<R!D:7-A8FQE9"X*("`@
M("`J($UA>6)E('1H:7,@:7,@=&AE('!L86-E('1O(&EN=&5R9F%C92!T;R!S
M;VUE(&]N;&EN92!P;W-T8V]D92!S97)V:6-E+BXN"B`@("`@*@H@("`@("H@
M0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1L;V-A=&EO
M;@H@("`@("H@0'!A<F%M("`@8F]O;"`@("`@("`@("`@("`@("`@("`@("`@
M("1U<V5&:7)S=`H@("`@("H@0')E='5R;B`@8F]O;`H@("`@("H@0&%C8V5S
M<R`@<'5B;&EC"B`@("`@*B!`9&5P<F5C871E9`H@("`@("HO"B`@("!F=6YC
M=&EO;B!S96%R8VA,;V-A=&EO;B@D;&]C871I;VX@/2!N=6QL+"`D=7-E1FER
M<W0@/2!N=6QL*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*
M("`@("\O('U]?0H*("`@("\O('M[>R!S96%R8VA,;V-A=&EO;D)Y0V]U;G1R
M>2@I"B`@("`O*BH*("`@("`J($5*4T4@;V9F97)S(&YO('-E87)C:"!F=6YC
M=&EO;B!T;R!D871E+"!S;R!T:&ES(&9U;F-T:6]N(&ES(&1I<V%B;&5D+@H@
M("`@("H@36%Y8F4@=&AI<R!I<R!T:&4@<&QA8V4@=&\@:6YT97)F86-E('1O
M('-O;64@;VYL:6YE('!O<W1C;V1E('-E<G9I8V4N+BX*("`@("`J"B`@("`@
M*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)&-O=6YT
M<GD*("`@("`J($!R971U<FX@(&)O;VP*("`@("`J($!A8V-E<W,@('!U8FQI
M8PH@("`@("H@0&1E<')E8V%T960*("`@("`J+PH@("`@9G5N8W1I;VX@<V5A
M<F-H3&]C871I;VY">4-O=6YT<GDH)&-O=6YT<GD@/2!N=6QL*0H@("`@>PH@
M("`@("`@(')E='5R;B!F86QS93L*("`@('T*("`@("\O('U]?0H*("`@("\O
M('M[>R!G971,;V-A=&EO;B@I"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M(&1A=&$@9F]R('1H92!L;V-A=&EO;B!B96QO;F=I;F<@=&\@=&AE($E$"B`@
M("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@
M("`@("1I9`H@("`@("H@0')E='5R;B`@4$5!4E]%<G)O<GQA<G)A>0H@("`@
M("H@0'1H<F]W<R`@4$5!4E]%<G)O<@H@("`@("H@0&%C8V5S<R`@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$QO8V%T:6]N*"1I9"`]("(B*0H@
M("`@>PH@("`@("`@("1S=&%T=7,@/2`D=&AI<RT^7V-H96-K3&]C871I;VY)
M1"@D:60I.PH*("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O
M<B@D<W1A='5S*2D@>PH@("`@("`@("`@("!R971U<FX@)'-T871U<SL*("`@
M("`@("!]"@H@("`@("`@("1L;V-A=&EO;E)E='5R;B`](&%R<F%Y*"D["@H@
M("`@("`@(&EF("@D=&AI<RT^7V-A8VAE16YA8FQE9"`F)B`H)'=E871H97(@
M/2`D=&AI<RT^7V-A8VAE+3YG970H)&ED+"`B=V5A=&AE<B(I*2D@>PH@("`@
M("`@("`@("`O+R!'970@9&%T82!F<F]M(&-A8VAE"B`@("`@("`@("`@("1T
M:&ES+3Y?=V5A=&AE<B`]("1W96%T:&5R.PH@("`@("`@("`@("`D;&]C871I
M;VY2971U<FY;(F-A8VAE(ET@/2`B2$E4(CL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`O+R!#:&5C:RP@:68@=&AE('=E871H97)3;V%P+4]B:F5C
M="!I<R!P<F5S96YT+B!)9B!N;W0L(&-O;FYE8W0@=&\@=&AE(%-E<G9E<B!A
M;F0@<F5T<FEE=F4@=&AE(%=$4TP@9&%T80H@("`@("`@("`@("!I9B`H(21T
M:&ES+3Y?=V5A=&AE<E-O87`I('L*("`@("`@("`@("`@("`@("1S=&%T=7,@
M/2`D=&AI<RT^7V-O;FYE8W1397)V97(H*3L*("`@("`@("`@("`@("`@(&EF
M("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1S=&%T=7,["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1W96%T:&5R(#T@)'1H
M:7,M/E]W96%T:&5R4V]A<"T^9V5T5V5A=&AE<DEN9F\H)&ED*3L*"B`@("`@
M("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1W96%T:&5R
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1W96%T:&5R.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7W=E871H97(@/2`D=V5A=&AE
M<CL*"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V-A8VAE16YA8FQE9"D@>PH@
M("`@("`@("`@("`@("`@+R\@+BXN86YD(&-A8VAE(&ET"B`@("`@("`@("`@
M("`@("`D97AP:7)E(#T@8V]N<W1A;G0H(E-%4E9)0T537U=%051(15)?15A0
M25)%4U]714%42$52(BD["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-A8VAE
M+3YE>'13879E*"1I9"P@)'1H:7,M/E]W96%T:&5R+"`B(BP@)&5X<&ER92P@
M(G=E871H97(B*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;&]C871I
M;VY2971U<FY;(F-A8VAE(ET@/2`B34E34R(["B`@("`@("`@?0H@("`@("`@
M("1L;V-A=&EO;E)E='5R;ELB;F%M92)=(#T@)'1H:7,M/E]W96%T:&5R+3Y,
M;V-A=&EO;CL*"B`@("`@("`@<F5T=7)N("1L;V-A=&EO;E)E='5R;CL*("`@
M('T*("`@("\O('U]?0H*("`@("\O('M[>R!G971796%T:&5R*"D*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@=V5A=&AE<BUD871A(&9O<B!T:&4@<W5P
M<&QI960@;&]C871I;VX*("`@("`J"B`@("`@*B!`<&%R86T@("!S=')I;F<@
M("`@("`@("`@("`@("`@("`@("`@)&ED"B`@("`@*B!`<&%R86T@("!S=')I
M;F<@("`@("`@("`@("`@("`@("`@("`@)'5N:71S1F]R;6%T"B`@("`@*B!`
M<F5T=7)N("!014%27T5R<F]R?&%R<F%Y"B`@("`@*B!`=&AR;W=S("!014%2
M7T5R<F]R"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T5V5A=&AE<B@D:60@/2`B(BP@)'5N:71S1F]R;6%T(#T@(B(I
M"B`@("!["B`@("`@("`@)'-T871U<R`]("1T:&ES+3Y?8VAE8VM,;V-A=&EO
M;DE$*"1I9"D["@H@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R
M<F]R*"1S=&%T=7,I*2!["B`@("`@("`@("`@(')E='5R;B`D<W1A='5S.PH@
M("`@("`@('T*"B`@("`@("`@+R\@1V5T(&]T:&5R(&1A=&$*("`@("`@("`D
M=6YI=',@("`@/2`D=&AI<RT^9V5T56YI='-&;W)M870H)'5N:71S1F]R;6%T
M*3L*"B`@("`@("`@)'=E871H97)2971U<FX@/2!A<G)A>2@I.PH@("`@("`@
M(&EF("@D=&AI<RT^7V-A8VAE16YA8FQE9"`F)B`H)'=E871H97(@/2`D=&AI
M<RT^7V-A8VAE+3YG970H)&ED+"`B=V5A=&AE<B(I*2D@>PH@("`@("`@("`@
M("`O+R!386UE('!R;V-E9'5R92XN+@H@("`@("`@("`@("`D=&AI<RT^7W=E
M871H97(@/2`D=V5A=&AE<CL*("`@("`@("`@("`@)'=E871H97)2971U<FY;
M(F-A8VAE(ET@/2`B2$E4(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`O+R!#:&5C:RP@:68@=&AE('=E871H97)3;V%P+4]B:F5C="!I<R!P<F5S
M96YT+B!)9B!N;W0L(&-O;FYE8W0@=&\@=&AE(%-E<G9E<B!A;F0@<F5T<FEE
M=F4@=&AE(%=$4TP@9&%T80H@("`@("`@("`@("!I9B`H(21T:&ES+3Y?=V5A
M=&AE<E-O87`I('L*("`@("`@("`@("`@("`@("1S=&%T=7,@/2`D=&AI<RT^
M7V-O;FYE8W1397)V97(H*3L*("`@("`@("`@("`@("`@(&EF("A397)V:6-E
M<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1S=&%T=7,["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("\O("XN+F%S(&QA<W0@9G5N8W1I;VX*
M("`@("`@("`@("`@)'=E871H97(@/2`D=&AI<RT^7W=E871H97)3;V%P+3YG
M971796%T:&5R26YF;R@D:60I.PH*("`@("`@("`@("`@:68@*%-E<G9I8V5S
M7U=E871H97(Z.FES17)R;W(H)'=E871H97(I*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)'=E871H97(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1T:&ES+3Y?=V5A=&AE<B`]("1W96%T:&5R.PH*("`@("`@("`@("`@:68@
M*"1T:&ES+3Y?8V%C:&5%;F%B;&5D*2!["B`@("`@("`@("`@("`@("`O+R`N
M+BYA;F0@8V%C:&4@:70*("`@("`@("`@("`@("`@("1E>'!I<F4@/2!C;VYS
M=&%N="@B4T525DE#15-?5T5!5$A%4E]%6%!)4D537U=%051(15(B*3L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8V%C:&4M/F5X=%-A=F4H)&ED+"`D=&AI
M<RT^7W=E871H97(L("(B+"`D97AP:7)E+"`B=V5A=&AE<B(I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1W96%T:&5R4F5T=7)N6R)C86-H92)=(#T@
M(DU)4U,B.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<W-E="@D8V]M<&%S
M<RDI('L*("`@("`@("`@("`@+R\@665S+"!.3D4@86YD('1H92!L:6ME<R!A
M<F4@;75L=&EP;&5S(&]F(#(R+C4L(&)U="!A<R!T:&4@;W1H97(*("`@("`@
M("`@("`@+R\@<V5R=FEC97,@<F5T=7)N(&EN=&5G97)S(&9O<B!T:&ES('9A
M;'5E+"!T:&5S92!D:7)E8W1I;VYS(&%R90H@("`@("`@("`@("`O+R!R;W5N
M9&5D('5P"B`@("`@("`@("`@("1C;VUP87-S(#T@87)R87DH"B`@("`@("`@
M("`@("`@("`B;F]R=&@B("`@("`@("`@("`@(#T^(&%R<F%Y*").(BP@("`@
M(#`I+`H@("`@("`@("`@("`@("`@(FYO<G1H(&YO<G1H96%S="(@("`]/B!A
M<G)A>2@B3DY%(BP@(#(S*2P*("`@("`@("`@("`@("`@(")N;W)T:&5A<W0B
M("`@("`@("`@/3X@87)R87DH(DY%(BP@("`T-2DL"B`@("`@("`@("`@("`@
M("`B96%S="!N;W)T:&5A<W0B("`@(#T^(&%R<F%Y*")%3D4B+"`@-C@I+`H@
M("`@("`@("`@("`@("`@(F5A<W0B("`@("`@("`@("`@("`]/B!A<G)A>2@B
M12(L("`@(#DP*2P*("`@("`@("`@("`@("`@(")E87-T('-O=71H96%S="(@
M("`@/3X@87)R87DH(D5312(L(#$Q,RDL"B`@("`@("`@("`@("`@("`B<V]U
M=&AE87-T(B`@("`@("`@(#T^(&%R<F%Y*")312(L("`Q,S4I+`H@("`@("`@
M("`@("`@("`@(G-O=71H('-O=71H96%S="(@("`]/B!A<G)A>2@B4U-%(BP@
M,34X*2P*("`@("`@("`@("`@("`@(")S;W5T:"(@("`@("`@("`@("`@/3X@
M87)R87DH(E,B+"`@(#$X,"DL"B`@("`@("`@("`@("`@("`B<V]U=&@@<V]U
M=&AW97-T(B`@(#T^(&%R<F%Y*")34U<B+"`R,#,I+`H@("`@("`@("`@("`@
M("`@(G-O=71H=V5S="(@("`@("`@("`]/B!A<G)A>2@B4U<B+"`@,C(U*2P*
M("`@("`@("`@("`@("`@(")W97-T('-O=71H=V5S="(@("`@/3X@87)R87DH
M(E=35R(L(#(T."DL"B`@("`@("`@("`@("`@("`B=V5S="(@("`@("`@("`@
M("`@(#T^(&%R<F%Y*")7(BP@("`R-S`I+`H@("`@("`@("`@("`@("`@(G=E
M<W0@;F]R=&AW97-T(B`@("`]/B!A<G)A>2@B5TY7(BP@,CDS*2P*("`@("`@
M("`@("`@("`@(")N;W)T:'=E<W0B("`@("`@("`@/3X@87)R87DH(DY7(BP@
M(#,Q-2DL"B`@("`@("`@("`@("`@("`B;F]R=&@@;F]R=&AW97-T(B`@(#T^
M(&%R<F%Y*").3E<B+"`S,S@I"B`@("`@("`@("`@("D["B`@("`@("`@?0H*
M("`@("`@("`O+R!);FET:6%L:7IE('-O;64@87)R87ES"B`@("`@("`@)'5P
M9&%T92`@("`@("`@("`@("`](&%R<F%Y*"D["B`@("`@("`@)'1E;7!E<F%T
M=7)E("`@("`@("`](&%R<F%Y*"D["B`@("`@("`@)&9E;'1496UP97)A='5R
M92`@("`](&%R<F%Y*"D["B`@("`@("`@)'9I<VEB:6QI='D@("`@("`@("`]
M(&%R<F%Y*"D["B`@("`@("`@)'!R97-S=7)E("`@("`@("`@("`](&%R<F%Y
M*"D["B`@("`@("`@)&1E=U!O:6YT("`@("`@("`@("`](&%R<F%Y*"D["B`@
M("`@("`@)'5V26YD97@@("`@("`@("`@("`](&%R<F%Y*"D["B`@("`@("`@
M)'=I;F0@("`@("`@("`@("`@("`](&%R<F%Y*"D["@H@("`@("`@(&EF("AP
M<F5G7VUA=&-H*"(O*%QW*RD@*%QD*RDL("A<9"LI+"!A="`H7&0K.EQD*R!<
M=TTI(%M>7"A=*RA<*"A;7EPI72LI7"DI/R\B+"`D=&AI<RT^7W=E871H97(M
M/DQA<W15<&1A=&5D+"`D=7!D871E*2D@>PH@("`@("`@("`@("!I9B`H:7-S
M970H)'5P9&%T95LU72DI('L*("`@("`@("`@("`@("`@("1T:6UE<W1R:6YG
M(#T@)'5P9&%T95LV73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1T:6UE<W1R:6YG(#T@)'5P9&%T95LR72XB("(N)'5P9&%T95LQ
M72XB("(N)'5P9&%T95LS72XB("(N)'5P9&%T95LT72XB($535"(["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'=E871H97)2971U<FY;(G5P9&%T92)=
M("`@("`@("`@("`@/2!G;61A=&4H=')I;2@D=&AI<RT^7V1A=&5&;W)M870N
M(B`B+B1T:&ES+3Y?=&EM949O<FUA="DL('-T<G1O=&EM92@D=&EM97-T<FEN
M9RDI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1W96%T:&5R4F5T
M=7)N6R)U<&1A=&4B72`@("`@("`@("`@(#T@(B(["B`@("`@("`@?0H@("`@
M("`@("1W96%T:&5R4F5T=7)N6R)U<&1A=&5287<B72`@("`@("`@(#T@)'1H
M:7,M/E]W96%T:&5R+3Y,87-T57!D871E9#L*("`@("`@("`D=V5A=&AE<E)E
M='5R;ELB<W1A=&EO;B)=("`@("`@("`@("`]("1T:&ES+3Y?=V5A=&AE<BT^
M4F5P;W)T961!=#L*("`@("`@("`D=V5A=&AE<E)E='5R;ELB8V]N9&ET:6]N
M26-O;B)=("`@("`]("1T:&ES+3Y?=V5A=&AE<BT^26-O;DEN9&5X.PH@("`@
M("`@('!R96=?;6%T8V@H(B\H+3]<9"LI7$0K+R(L("1T:&ES+3Y?=V5A=&AE
M<BT^5&5M<')A='5R92P@)'1E;7!E<F%T=7)E*3L*("`@("`@("`D=V5A=&AE
M<E)E='5R;ELB=&5M<&5R871U<F4B72`@("`@("`]("1T:&ES+3YC;VYV97)T
M5&5M<&5R871U<F4H)'1E;7!E<F%T=7)E6S%=+"`B9B(L("1U;FET<ULB=&5M
M<")=*3L*("`@("`@("!P<F5G7VUA=&-H*"(O*"T_7&0K*5Q$*R\B+"`D=&AI
M<RT^7W=E871H97(M/D9E96QS3&EK92P@)&9E;'1496UP97)A='5R92D["B`@
M("`@("`@)'=E871H97)2971U<FY;(F9E;'1496UP97)A='5R92)=("`@/2`D
M=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E*"1F96QT5&5M<&5R871U<F5;,5TL
M(")F(BP@)'5N:71S6R)T96UP(ETI.PH@("`@("`@("1W96%T:&5R4F5T=7)N
M6R)C;VYD:71I;VXB72`@("`@("`@(#T@)'1H:7,M/E]W96%T:&5R+3Y&;W)E
M8V%S=#L*("`@("`@("!I9B`H<')E9U]M871C:"@B+RA;7&1<+ETK*5Q$*R\B
M+"`D=&AI<RT^7W=E871H97(M/E9I<VEB:6QI='DL("1V:7-I8FEL:71Y*2D@
M>PH@("`@("`@("`@("`D=V5A=&AE<E)E='5R;ELB=FES:6)I;&ET>2)=("`@
M(#T@)'1H:7,M/F-O;G9E<G1$:7-T86YC92@D=FES:6)I;&ET>5LQ72P@(G-M
M(BP@)'5N:71S6R)V:7,B72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'=E871H97)2971U<FY;(G9I<VEB:6QI='DB72`@("`]('1R:6TH)'1H
M:7,M/E]W96%T:&5R+3Y6:7-I8FEL:71Y*3L*("`@("`@("!]"B`@("`@("`@
M<')E9U]M871C:"@B+RA;7&1<+ETK*2!I;F-H97,@86YD("A<=RLI+R(L("1T
M:&ES+3Y?=V5A=&AE<BT^4')E<W-U<F4L("1P<F5S<W5R92D["B`@("`@("`@
M)'=E871H97)2971U<FY;(G!R97-S=7)E(ET@("`@("`@("`@/2`D=&AI<RT^
M8V]N=F5R=%!R97-S=7)E*"1P<F5S<W5R95LQ72P@(FEN(BP@)'5N:71S6R)P
M<F5S(ETI.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)P<F5S<W5R951R96YD
M(ET@("`@(#T@)'!R97-S=7)E6S)=.PH@("`@("`@('!R96=?;6%T8V@H(B\H
M+3]<9"LI7$0K+R(L("1T:&ES+3Y?=V5A=&AE<BT^1&5W4&]I;G0L("1D97=0
M;VEN="D["B`@("`@("`@)'=E871H97)2971U<FY;(F1E=U!O:6YT(ET@("`@
M("`@("`@/2`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E*"1D97=0;VEN=%LQ
M72P@(F8B+"`D=6YI='-;(G1E;7`B72D["B`@("`@("`@<')E9U]M871C:"@B
M+RA<9"LI("A<=RLI+R(L("1T:&ES+3Y?=V5A=&AE<BT^559);F1E>"P@)'5V
M26YD97@I.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)U=DEN9&5X(ET@("`@
M("`@("`@(#T@)'5V26YD97A;,5T["B`@("`@("`@)'=E871H97)2971U<FY;
M(G5V5&5X=")=("`@("`@("`@("`@/2`D=79);F1E>%LR73L*("`@("`@("`D
M=V5A=&AE<E)E='5R;ELB:'5M:61I='DB72`@("`@("`@("`]('-T<E]R97!L
M86-E*"(E(BP@(B(L("1T:&ES+3Y?=V5A=&AE<BT^2'5M:61I='DI.PH@("`@
M("`@(&EF("AP<F5G7VUA=&-H*"(O1G)O;2!T:&4@*%M<=UP@72LI(&%T("A;
M7&1<+ETK*2`H9W5S=&EN9R!T;R`H6UQD7"Y=*RD@*3]M<&@O(BP@)'1H:7,M
M/E]W96%T:&5R+3Y7:6YD+"`D=VEN9"DI('L*("`@("`@("`@("`@)'=E871H
M97)2971U<FY;(G=I;F0B72`@("`@("`@("`@("`@/2`D=&AI<RT^8V]N=F5R
M=%-P965D*"1W:6YD6S)=+"`B;7!H(BP@)'5N:71S6R)W:6YD(ETI.PH@("`@
M("`@("`@("!I9B`H:7-S970H)'=I;F1;-%TI*2!["B`@("`@("`@("`@("`@
M("`D=V5A=&AE<E)E='5R;ELB=VEN9$=U<W0B72`@("`@(#T@)'1H:7,M/F-O
M;G9E<G13<&5E9"@D=VEN9%LT72P@(FUP:"(L("1U;FET<ULB=VEN9")=*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D=V5A=&AE<E)E='5R;ELB=VEN
M9$1E9W)E97,B72`@("`@("`]("1C;VUP87-S6W-T<G1O;&]W97(H)'=I;F1;
M,5TI75LQ73L*("`@("`@("`@("`@)'=E871H97)2971U<FY;(G=I;F1$:7)E
M8W1I;VXB72`@("`@/2`D8V]M<&%S<UMS=')T;VQO=V5R*"1W:6YD6S%=*5U;
M,%T["B`@("`@("`@?2!E;'-E:68@*'-T<G1O;&]W97(H)'1H:7,M/E]W96%T
M:&5R+3Y7:6YD*2`]/2`B8V%L;2(I('L*("`@("`@("`@("`@)'=E871H97)2
M971U<FY;(G=I;F0B72`@("`@("`@("`](#`["B`@("`@("`@("`@("1W96%T
M:&5R4F5T=7)N6R)W:6YD1&5G<F5E<R)=("`@/2`P.PH@("`@("`@("`@("`D
M=V5A=&AE<E)E='5R;ELB=VEN9$1I<F5C=&EO;B)=(#T@(D-!3$TB.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1W96%T:&5R4F5T=7)N.PH@("`@?0H@
M("`@+R\@?7U]"@H@("`@+R\@>WM[(&=E=$9O<F5C87-T*"D*("`@("\J*@H@
M("`@("H@1V5T('1H92!F;W)E8V%S="!F;W(@=&AE(&YE>'0@9&%Y<PH@("`@
M("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@
M("`D:6YT"B`@("`@*B!`<&%R86T@("!I;G0@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1A>7,@("`@("`@("`@(%9A;'5E<R!B971W965N(#$@86YD(#D*
M("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D
M=6YI='-&;W)M870*("`@("`J($!R971U<FX@(%!%05)?17)R;W)\87)R87D*
M("`@("`J($!T:')O=W,@(%!%05)?17)R;W(*("`@("`J($!A8V-E<W,@('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971&;W)E8V%S="@D:60@/2`B
M(BP@)&1A>7,@/2`R+"`D=6YI='-&;W)M870@/2`B(BD*("`@('L*("`@("`@
M("`D<W1A='5S(#T@)'1H:7,M/E]C:&5C:TQO8V%T:6]N240H)&ED*3L*"B`@
M("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-T871U<RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1S=&%T=7,["B`@("`@("`@?0H@("`@
M("`@(&EF("@A:6Y?87)R87DH)&1A>7,L(')A;F=E*#$L(#DI*2D@>PH@("`@
M("`@("`@("`D9&%Y<R`](#(["B`@("`@("`@?0H*("`@("`@("`O+R!'970@
M;W1H97(@9&%T80H@("`@("`@("1U;FET<R`@("`]("1T:&ES+3YG9715;FET
M<T9O<FUA="@D=6YI='-&;W)M870I.PH*("`@("`@("`D9F]R96-A<W12971U
M<FX@/2!A<G)A>2@I.PH@("`@("`@(&EF("@D=&AI<RT^7V-A8VAE16YA8FQE
M9"`F)B`H)&9O<F5C87-T(#T@)'1H:7,M/E]C86-H92T^9V5T*"1I9"P@(F9O
M<F5C87-T(BDI*2!["B`@("`@("`@("`@("\O(%-A;64@<')O8V5D=7)E+BXN
M"B`@("`@("`@("`@("1T:&ES+3Y?9F]R96-A<W0@/2`D9F]R96-A<W0["B`@
M("`@("`@("`@("1F;W)E8V%S=%)E='5R;ELB8V%C:&4B72`](")(250B.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O($-H96-K+"!I9B!T:&4@
M=V5A=&AE<E-O87`M3V)J96-T(&ES('!R97-E;G0N($EF(&YO="P@8V]N;F5C
M="!T;R!T:&4@4V5R=F5R(&%N9"!R971R:65V92!T:&4@5T133"!D871A"B`@
M("`@("`@("`@(&EF("@A)'1H:7,M/E]W96%T:&5R4V]A<"D@>PH@("`@("`@
M("`@("`@("`@)'-T871U<R`]("1T:&ES+3Y?8V]N;F5C=%-E<G9E<B@I.PH@
M("`@("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H
M)'-T871U<RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'-T871U
M<SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+R\@+BXN87,@;&%S="!F=6YC=&EO;@H@("`@("`@("`@("`D9F]R96-A
M<W0@/2`D=&AI<RT^7W=E871H97)3;V%P+3Y'971.:6YE1&%Y1F]R96-A<W1)
M;F9O*"1I9"D["@H@("`@("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ
M:7-%<G)O<B@D9F]R96-A<W0I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)&9O<F5C87-T.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^
M7V9O<F5C87-T(#T@)&9O<F5C87-T.PH*("`@("`@("`@("`@:68@*"1T:&ES
M+3Y?8V%C:&5%;F%B;&5D*2!["B`@("`@("`@("`@("`@("`O+R`N+BYA;F0@
M8V%C:&4@:70*("`@("`@("`@("`@("`@("1E>'!I<F4@/2!C;VYS=&%N="@B
M4T525DE#15-?5T5!5$A%4E]%6%!)4D537T9/4D5#05-4(BD["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V-A8VAE+3YE>'13879E*"1I9"P@)'1H:7,M/E]F
M;W)E8V%S="P@(B(L("1E>'!I<F4L(")F;W)E8V%S="(I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1F;W)E8V%S=%)E='5R;ELB8V%C:&4B72`](")-
M25-3(CL*("`@("`@("!]"@H@("`@("`@("1F;W)E8V%S=%)E='5R;ELB9&%Y
M<R)=("`@/2!A<G)A>2@I.PH*("`@("`@("`O+R!);FET:6%L:7IE('-O;64@
M87)R87ES"B`@("`@("`@)'1E;7!E<F%T=7)E2&EG:"`@("`](&%R<F%Y*"D[
M"B`@("`@("`@)'1E;7!E<F%T=7)E3&]W("`@("`](&%R<F%Y*"D["@H@("`@
M("`@(&9O<B`H)&D@/2`Q.R`D:2`\/2`D9&%Y<SL@)&DK*RD@>PH@("`@("`@
M("`@("!P<F5G7VUA=&-H*"(O*"T_7&0K*5Q$*R\B+"`D=&AI<RT^7V9O<F5C
M87-T+3Y[(D1A>2(N)&E]+3Y(:6=H+"`D=&5M<&5R871U<F5(:6=H*3L*("`@
M("`@("`@("`@<')E9U]M871C:"@B+R@M/UQD*RE<1"LO(BP@)'1H:7,M/E]F
M;W)E8V%S="T^>R)$87DB+B1I?2T^3&]W+"`D=&5M<&5R871U<F5,;W<I.PH@
M("`@("`@("`@("`D9&%Y(#T@87)R87DH"B`@("`@("`@("`@("`@("`B=&5M
M<&5R='5R94AI9V@B(#T^("1T:&ES+3YC;VYV97)T5&5M<&5R871U<F4H)'1E
M;7!E<F%T=7)E2&EG:%LQ72P@(F8B+"`D=6YI='-;(G1E;7`B72DL"B`@("`@
M("`@("`@("`@("`B=&5M<&5R871U<F5,;W<B(#T^("1T:&ES+3YC;VYV97)T
M5&5M<&5R871U<F4H)'1E;7!E<F%T=7)E3&]W6S%=+"`B9B(L("1U;FET<ULB
M=&5M<")=*2P*("`@("`@("`@("`@("`@(")D87DB(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@(")C;VYD:71I;VXB("`@("`]/B`D=&AI<RT^7V9O
M<F5C87-T+3Y[(D1A>2(N)&E]+3Y&;W)E8V%S="P*("`@("`@("`@("`@("`@
M("`@("`B8V]N9&ET:6]N26-O;B(@/3X@)'1H:7,M/E]F;W)E8V%S="T^>R)$
M87DB+B1I?2T^26-O;DEN9&5X+`H@("`@("`@("`@("`@("`@("`@(")P<F5C
M:7!I=&%T:6]N(B`]/B!T<FEM*'-T<E]R97!L86-E*"(E(BP@(B(L("1T:&ES
M+3Y?9F]R96-A<W0M/GLB1&%Y(BXD:7TM/E!R96-I<$-H86YC92DI"B`@("`@
M("`@("`@("`@("`I"B`@("`@("`@("`@("D["@H@("`@("`@("`@("`D9F]R
M96-A<W12971U<FY;(F1A>7,B75M=(#T@)&1A>3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D9F]R96-A<W12971U<FX["B`@("!]"B`@("`O+R!]?7T*
M?0HO+R!]?7T*/SX*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M4V5R=FEC97,O5V5A=&AE<B]';&]B86QW96%T:&5R+G!H<```````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P-#8T-#``,3`U,34T,S,W,S0`,#(U,C8W`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J('9I;3H@
M<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S
M=&]P/30@9F]L9&UE=&AO9#UM87)K97(Z("HO"@HO*BH*("H@4$5!4CHZ4V5R
M=FEC97-?5V5A=&AE<E]';&]B86QW96%T:&5R"B`J"B`J(%!(4"!V97)S:6]N
M<R`T(&%N9"`U"B`J"B`J(#Q,24-%3E-%/@H@*B!#;W!Y<FEG:'0@*&,I(#(P
M,#4L($%L97AA;F1E<B!7:7)T>@H@*B!!;&P@<FEG:'1S(')E<V5R=F5D+@H@
M*@H@*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN
M87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D:69I8V%T:6]N+"!A
M<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD
M:71I;VYS"B`J(&%R92!M970Z"B`J(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O
M=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T
M:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L
M;&]W:6YG(&1I<V-L86EM97(N"B`J(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I
M;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@
M;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@
M9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE(&1O8W5M96YT871I;VX*("H@
M("!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I
M<W1R:6)U=&EO;BX*("H@;R!.96ET:&5R('1H92!N86UE(&]F('1H92!S;V9T
M=V%R92!N;W(@=&AE(&YA;65S(&]F(&ET<R!C;VYT<FEB=71O<G,*("H@("!M
M87D@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C=',@9&5R
M:79E9"!F<F]M('1H:7,@<V]F='=A<F4*("H@("!W:71H;W5T('-P96-I9FEC
M('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H*("H@5$A)4R!33T945T%2
M12!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/
M3E1224)55$]24R`B05,@25,B"B`J($%.1"!!3ED@15A04D534R!/4B!)35!,
M245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$(%1/
M+"!42$4*("H@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E4
M62!!3D0@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/4T4*("H@05)%
M($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'2%0@
M3U=.15(@3U(@0T].5%))0E543U)3($)%"B`J($Q)04),12!&3U(@04Y9($1)
M4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL(%-014-)04PL($5814U03$%2
M62P@3U(*("H@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L($)5
M5"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8*("H@4U5"4U1)5%54
M12!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L($1!5$$L($]2(%!2
M3T9)5%,[($]2($)54TE.15-3"B`J($E.5$524E505$E/3BD@2$]7159%4B!#
M0553140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52
M($E."B`J($-/3E1204-4+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4("A)
M3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I"B`J($%225-)3D<@
M24X@04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3(%-/1E1705)%+"!%
M5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,2519($]&(%-50T@@
M1$%-04=%+@H@*B`\+TQ)0T5.4T4^"B`J"B`J($!C871E9V]R>2`@("!796(@
M4V5R=FEC97,*("H@0'!A8VMA9V4@("`@(%-E<G9I8V5S7U=E871H97(*("H@
M0&%U=&AO<B`@("`@($%L97AA;F1E<B!7:7)T>B`\86QE>$!P8S1P+FYE=#X*
M("H@0&-O<'ER:6=H="`@(#(P,#4@06QE>&%N9&5R(%=I<G1Z"B`J($!L:6-E
M;G-E("`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S
M9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@($-6
M4SH@)$ED.B!';&]B86QW96%T:&5R+G!H<"QV(#$N,S0@,C`P-2\Q,2\Q,R`R
M,3HU-CHQ-B!E<G4@17AP("0*("H@0&QI;FL@("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]397)V:6-E<U]796%T:&5R"B`J($!L:6YK("`@
M("`@("!H='1P.B\O=W=W+F-A<&5S8VEE;F-E+F-O;2]W96)S97)V:6-E<R]G
M;&]B86QW96%T:&5R+VEN9&5X+G-H=&UL"B`J($!E>&%M<&QE("`@("!E>&%M
M<&QE<R]G;&]B86QW96%T:&5R+6)A<VEC+G!H<"`@("!G;&]B86QW96%T:&5R
M+6)A<VEC+G!H<`H@*B!`9FEL97-O=7)C90H@*B\*"G)E<75I<F5?;VYC92`B
M4V5R=FEC97,O5V5A=&AE<B]#;VUM;VXN<&AP(CL*"B\O('M[>R!C;&%S<R!3
M97)V:6-E<U]796%T:&5R7T=L;V)A;'=E871H97(*+RHJ"B`J(%1H:7,@8VQA
M<W,@86-T<R!A<R!A;B!I;G1E<F9A8V4@=&\@=&AE('-O87`@<V5R=FEC92!O
M9B!C87!E<V-I96YC92YC;VTN"B`J($ET('-E87)C:&5S(&9O<B!G:79E;B!L
M;V-A=&EO;G,@86YD(')E=')I979E<R!C=7)R96YT('=E871H97(@9&%T82X*
M("H*("H@1VQO8F%L5V5A=&AE<B!I<R!A(%-/05`@9G)O;G1E;F0@9F]R($U%
M5$%2(&1A=&$L('!R;W9I9&5D(&)Y($-A<&538VEE;F-E+@H@*B!)9B!Y;W4@
M=V%N="!T;R!U<V4@345405(L('EO=2!S:&]U;&0@=')Y('1H:7,@8VQA<W,@
M9FER<W0L(&%S(&ET(&ES(&UU8V@*("H@;6]R92!C;VUF;W)T86)L92`H86YD
M(&%L<V\@82!B:70@9F%S=&5R*2!T:&%N('1H92!N871I=F4@345405(M8VQA
M<W,*("H@<')O=FED960@8GD@=&AI<R!P86-K86=E+B!/;B!T:&4@;W1H97(@
M:&%N9"P@=&AI<R!S97)V:6-E('=O;B=T('-U<'!L>0H@*B!4049S+"!T:&4@
M9F]R96-A<W0@<WES=&5M(&%C8V]M<&%N>6EN9R!-151!4BP@<V\@>6]U(&AA
M=F4@=&\@;6%K90H@*B!T:&4@8V%L;"!H97)E+BXN"B`J"B`J($9O<B!A('=O
M<FMI;F<@97AA;7!L92P@<&QE87-E('1A:V4@82!L;V]K(&%T"B`J("`@("!D
M;V-S+U-E<G9I8V5S7U=E871H97(O97AA;7!L97,O9VQO8F%L=V5A=&AE<BUB
M87-I8RYP:'`*("H*("H*("H@0&-A=&5G;W)Y("`@(%=E8B!397)V:6-E<PH@
M*B!`<&%C:V%G92`@("`@4V5R=FEC97-?5V5A=&AE<@H@*B!`875T:&]R("`@
M("`@06QE>&%N9&5R(%=I<G1Z(#QA;&5X0'!C-'`N;F5T/@H@*B!`8V]P>7)I
M9VAT("`@,C`P-2!!;&5X86YD97(@5VER='H*("H@0&QI8V5N<V4@("`@(&AT
M='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N
M<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@("`@4F5L96%S93H@,2XT
M+C`*("H@0&QI;FL@("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]397)V:6-E<U]796%T:&5R"B`J($!L:6YK("`@("`@("!H='1P.B\O=W=W
M+F-A<&5S8VEE;F-E+F-O;2]W96)S97)V:6-E<R]G;&]B86QW96%T:&5R+VEN
M9&5X+G-H=&UL"B`J($!E>&%M<&QE("`@("!E>&%M<&QE<R]G;&]B86QW96%T
M:&5R+6)A<VEC+G!H<"`@("!G;&]B86QW96%T:&5R+6)A<VEC+G!H<`H@*B\*
M8VQA<W,@4V5R=FEC97-?5V5A=&AE<E]';&]B86QW96%T:&5R(&5X=&5N9',@
M4V5R=FEC97-?5V5A=&AE<E]#;VUM;VX@>PH*("`@("\O('M[>R!P<F]P97)T
M:65S"B`@("`O*BH*("`@("`J(%=31$P@;V)J96-T+"!P<F]V:61E9"!B>2!#
M87!E4V-I96YC90H@("`@("H*("`@("`J($!V87(@("`@(&]B:F5C="`@("`@
M("`@("`@("`@("`@("`@("`D7W=S9&P*("`@("`J($!A8V-E<W,@('!R:79A
M=&4*("`@("`J+PH@("`@=F%R("1?=W-D;#L*"B`@("`O*BH*("`@("`J(%-/
M05`@;V)J96-T('1O(&%C8V5S<R!S=&%T:6]N(&1A=&$L('!R;W9I9&5D(&)Y
M($-A<&538VEE;F-E"B`@("`@*@H@("`@("H@0'9A<B`@("`@;V)J96-T("`@
M("`@("`@("`@("`@("`@("`@("1?<W1A=&EO;E-O87`*("`@("`J($!A8V-E
M<W,@('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?<W1A=&EO;E-O87`["@H@
M("`@+RHJ"B`@("`@*B!33T%0(&]B:F5C="!T;R!A8V-E<W,@=V5A=&AE<B!D
M871A+"!P<F]V:61E9"!B>2!#87!E4V-I96YC90H@("`@("H*("`@("`J($!V
M87(@("`@("!O8FIE8W0@("`@("`@("`@("`@("`@("`@("`@)%]W96%T:&5R
M4V]A<`H@("`@("H@0&%C8V5S<R`@('!R:79A=&4*("`@("`J+PH@("`@=F%R
M("1?=V5A=&AE<E-O87`["B`@("`O+R!]?7T*"B`@("`O+R![>WL@8V]N<W1R
M=6-T;W(*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@
M*B!297%U:7)E<R!33T%0('1O(&)E(&EN<W1A;&QE9`H@("`@("H*("`@("`J
M($!P87)A;2`@(&%R<F%Y("`@("`@("`@("`@("`@("`@("`@("`D;W!T:6]N
M<PH@("`@("H@0'!A<F%M("`@;6EX960@("`@("`@("`@("`@("`@("`@("`@
M("1E<G)O<@H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<@H@("`@("H@0'1H
M<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]74D].
M1U]315)615)?1$%400H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO
M"B`@("!F=6YC=&EO;B!397)V:6-E<U]796%T:&5R7T=L;V)A;'=E871H97(H
M)&]P=&EO;G,L("8D97)R;W(I"B`@("!["B`@("`@("`@)'!E<G)O<B`](&YU
M;&P["B`@("`@("`@)'1H:7,M/E-E<G9I8V5S7U=E871H97)?0V]M;6]N*"1O
M<'1I;VYS+"`D<&5R<F]R*3L*("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE
M<CHZ:7-%<G)O<B@D<&5R<F]R*2D@>PH@("`@("`@("`@("`D97)R;W(@/2`D
M<&5R<F]R.PH@("`@("`@('T*("`@('T*("`@("\O('U]?0H*("`@("\O('M[
M>R!?8V]N;F5C=%-E<G9E<B@I"B`@("`O*BH*("`@("`J($-O;FYE8W1S('1O
M('1H92!33T%0('-E<G9E<B!A;F0@<F5T<FEE=F5S('1H92!74T1,(&1A=&$*
M("`@("`J"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&)O;VP*("`@("`J
M($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?
M5U)/3D=?4T525D527T1!5$$*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W1397)V97(H*0H@("`@>PH@("`@
M("`@(&EN8VQU9&5?;VYC92`B4T]!4"]#;&EE;G0N<&AP(CL*("`@("`@("`D
M=&AI<RT^7W=S9&P@/2!N97<@4T]!4%]74T1,*")H='1P.B\O;&EV92YC87!E
M<V-I96YC92YC;VTO=W-D;"]';&]B86Q796%T:&5R+G=S9&PB+"`D=&AI<RT^
M7VAT='!/<'1I;VYS*3L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]W<V1L
M+3YF875L="D@)B8@4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D=&AI<RT^
M7W=S9&PM/F9A=6QT*2D@>PH@("`@("`@("`@("`D97)R;W(@/2!397)V:6-E
M<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?
M5U)/3D=?4T525D527T1!5$$L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@(&5V86PH)'1H:7,M
M/E]W<V1L+3YG96YE<F%T94%L;%!R;WAI97,H*2D["B`@("`@("`@:68@*"%C
M;&%S<U]E>&ES=',H(E=E8E-E<G9I8V5?1VQO8F%L5V5A=&AE<E]3=&%T:6]N
M26YF;R(I('Q\("%C;&%S<U]E>&ES=',H(E=E8E-E<G9I8V5?1VQO8F%L5V5A
M=&AE<E]';&]B86Q796%T:&5R(BDI('L*("`@("`@("`@("`@)&5R<F]R(#T@
M4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$52
M7T524D]27U=23TY'7U-%4E9%4E]$051!+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^7W-T871I;VY3;V%P(#T@)FYE=R!796)397)V:6-E7T=L;V)A;%=E871H
M97)?4W1A=&EO;DEN9F\["B`@("`@("`@)'1H:7,M/E]W96%T:&5R4V]A<"`]
M("9N97<@5V5B4V5R=FEC95]';&]B86Q796%T:&5R7T=L;V)A;%=E871H97([
M"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H@("`@+R\@?7U]"@H@("`@
M+R\@>WM[(%]C:&5C:TQO8V%T:6]N240H*0H@("`@+RHJ"B`@("`@*B!#:&5C
M:W,@=&AE(&ED(&9O<B!V86QI9"!V86QU97,@86YD('1H=7,@<')E=F5N=',@
M<VEL;'D@<F5Q=65S=',@=&\*("`@("`J($=L;V)A;%=E871H97(@<V5R=F5R
M"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@
M("`@("`@("1I9`H@("`@("H@0')E='5R;B`@4$5!4E]%<G)O<GQB;V]L"B`@
M("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$527T52
M4D]27TY/7TQ/0T%424]."B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI3
M15)624-%4U]714%42$527T524D]27TE.5D%,241?3$]#051)3TX*("`@("`J
M($!A8V-E<W,@('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V-H96-K
M3&]C871I;VY)1"@D:60I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1I
M9"D@?'P@:7-?;V)J96-T*"1I9"D@?'P@(7-T<FQE;B@D:60I*2!["B`@("`@
M("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%
M4E9)0T537U=%051(15)?15)23U)?3D]?3$]#051)3TXL(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?<W1A=&EO;E-O
M87`M/FES5F%L:61#;V1E*"1I9"D@/3T](&9A;'-E*2!["B`@("`@("`@("`@
M(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T53
M7U=%051(15)?15)23U)?24Y604Q)1%],3T-!5$E/3BP@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[('-E87)C:$QO8V%T:6]N*"D*("`@
M("\J*@H@("`@("H@4V5A<F-H97,@241S(&9O<B!G:79E;B!L;V-A=&EO;BP@
M<F5T=7)N<R!A<G)A>2!O9B!P;W-S:6)L92!L;V-A=&EO;G,*("`@("`J(&]R
M('-I;F=L92!)1`H@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@
M("`@("`@("`@("`@("`@("`D;&]C871I;VX*("`@("`J($!P87)A;2`@(&)O
M;VP@("`@("`@("`@("`@("`@("`@("`@("`D=7-E1FER<W0@("`@("`@268@
M<V5T+"!F:7)S="!)1"!O9B!R97-U;'0M87)R87D@:7,@<F5T=7)N960*("`@
M("`J($!R971U<FX@(%!%05)?17)R;W)\87)R87E\<W1R:6YG"B`@("`@*B!`
M=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$527T524D]27U=2
M3TY'7U-%4E9%4E]$051!"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI3
M15)624-%4U]714%42$527T524D]27U5.2TY/5TY?3$]#051)3TX*("`@("`J
M($!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S96%R8VA,
M;V-A=&EO;B@D;&]C871I;VXL("1U<V5&:7)S="`](&9A;'-E*0H@("`@>PH@
M("`@("`@("\O($-H96-K+"!I9B!T:&4@<W1A=&EO;E-O87`M3V)J96-T(&ES
M('!R97-E;G0N($EF(&YO="P@8V]N;F5C="!T;R!T:&4@4V5R=F5R(&%N9"!R
M971R:65V92!T:&4@5T133"!D871A"B`@("`@("`@:68@*"$D=&AI<RT^7W-T
M871I;VY3;V%P*2!["B`@("`@("`@("`@("1S=&%T=7,@/2`D=&AI<RT^7V-O
M;FYE8W1397)V97(H*3L*("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H
M97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D<W1A='5S.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M+R!'970@<V5A<F-H(&1A=&$@9G)O;2!S97)V97(@86YD('5N<V5R:6%L:7IE
M"B`@("`@("`@)'-E87)C:"`]("1T:&ES+3Y?<W1A=&EO;E-O87`M/G-E87)C
M:$)Y3F%M92@D;&]C871I;VXI.PH*("`@("`@("!I9B`H4V5R=FEC97-?5V5A
M=&AE<CHZ:7-%<G)O<B@D<V5A<F-H*2D@>PH@("`@("`@("`@("!R971U<FX@
M4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$52
M7T524D]27U=23TY'7U-%4E9%4E]$051!+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@A:7-?87)R87DH
M)'-E87)C:"D@?'P@(7-I>F5O9B@D<V5A<F-H*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#
M15-?5T5!5$A%4E]%4E)/4E]53DM.3U=.7TQ/0T%424].+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@:68@*"$D=7-E1FER<W0@)B8@*'-I>F5O9B@D<V5A<F-H*2`^(#$I*2![
M"B`@("`@("`@("`@("`@("`@("`@)'-E87)C:%)E='5R;B`](&%R<F%Y*"D[
M"B`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F
M*"1S96%R8V@I.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1S
M96%R8VA2971U<FY;)'-E87)C:%LD:5TM/FEC86]=(#T@)'-E87)C:%LD:5TM
M/FYA;64N(BP@(BXD<V5A<F-H6R1I72T^8V]U;G1R>3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'5S949I<G-T
M('Q\("AS:7IE;V8H)'-E87)C:"D@/3T@,2DI('L*("`@("`@("`@("`@("`@
M("`@("`D<V5A<F-H4F5T=7)N(#T@)'-E87)C:%LP72T^:6-A;SL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1S96%R8VA2971U<FX["B`@("!]"B`@("`O+R!]?7T*"B`@("`O
M+R![>WL@<V5A<F-H3&]C871I;VY">4-O=6YT<GDH*0H@("`@+RHJ"B`@("`@
M*B!2971U<FYS($E$<R!W:71H(&QO8V%T:6]N+6YA;64@9F]R(&$@9VEV96X@
M8V]U;G1R>2!O<B!A;&P@879A:6QA8FQE"B`@("`@*B!C;W5N=')I97,L(&EF
M(&YO('9A;'5E('=A<R!G:79E;@H@("`@("H*("`@("`J($!P87)A;2`@('-T
M<FEN9R`@("`@("`@("`@("`@("`@("`@("`D8V]U;G1R>0H@("`@("H@0')E
M='5R;B`@4$5!4E]%<G)O<GQA<G)A>0H@("`@("H@0'1H<F]W<R`@4$5!4E]%
M<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]74D].1U]315)615)?1$%4
M00H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%
M4E]%4E)/4E]53DM.3U=.7TQ/0T%424]."B`@("`@*B!`86-C97-S("!P=6)L
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5A<F-H3&]C871I;VY">4-O=6YT
M<GDH)&-O=6YT<GD@/2`B(BD*("`@('L*("`@("`@("`O+R!2971U<FX@=&AE
M(&%V86EL86)L92!C;W5N=')I97,@87,@;F\@8V]U;G1R>2!W87,@9VEV96X*
M("`@("`@("!I9B`H(7-T<FQE;B@D8V]U;G1R>2DI('L*("`@("`@("`@("`@
M)&-O=6YT<FEE<R`]("1T:&ES+3Y?<W1A=&EO;E-O87`M/FQI<W1#;W5N=')I
M97,H*3L*("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R
M;W(H)&-O=6YT<FEE<RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!397)V
M:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)2
M3U)?5U)/3D=?4T525D527T1!5$$L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1C;W5N=')I97,["B`@
M("`@("`@?0H*("`@("`@("`O+R!#:&5C:RP@:68@=&AE('-T871I;VY3;V%P
M+4]B:F5C="!I<R!P<F5S96YT+B!)9B!N;W0L(&-O;FYE8W0@=&\@=&AE(%-E
M<G9E<B!A;F0@<F5T<FEE=F4@=&AE(%=$4TP@9&%T80H@("`@("`@(&EF("@A
M)'1H:7,M/E]S=&%T:6]N4V]A<"D@>PH@("`@("`@("`@("`D<W1A='5S(#T@
M)'1H:7,M/E]C;VYN96-T4V5R=F5R*"D["B`@("`@("`@("`@(&EF("A397)V
M:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)'-T871U<SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+R\@3F]W(&9O<B!T:&4@<F5A;"!S96%R8V@*("`@("`@("`D
M8V]U;G1R>4QO8W,@/2`D=&AI<RT^7W-T871I;VY3;V%P+3YS96%R8VA">4-O
M=6YT<GDH)&-O=6YT<GDI.PH@("`@("`@("\O($-H96-K(')E<W5L="!F;W(@
M=F%L:61I='D*("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O
M<B@D8V]U;G1R>4QO8W,I*2!["B`@("`@("`@("`@(')E='5R;B!397)V:6-E
M<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?
M5U)/3D=?4T525D527T1!5$$L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@?2!E;'-E:68@*"%I<U]A<G)A>2@D8V]U;G1R>4QO8W,I*2!["B`@("`@
M("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%
M4E9)0T537U=%051(15)?15)23U)?54Y+3D]73E],3T-!5$E/3BP@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("\O($-O;G-T<G5C
M="!T:&4@<F5S=6QT"B`@("`@("`@)&QO8V%T:6]N<R`](&%R<F%Y*"D["B`@
M("`@("`@9F]R96%C:"`H)&-O=6YT<GE,;V-S(&%S("1L;V-A=&EO;BD@>PH@
M("`@("`@("`@("`D;&]C871I;VYS6R1L;V-A=&EO;BT^:6-A;UT@/2`D;&]C
M871I;VXM/FYA;64N(BP@(BXD;&]C871I;VXM/F-O=6YT<GD["B`@("`@("`@
M?0H@("`@("`@(&%S;W)T*"1L;V-A=&EO;G,I.PH*("`@("`@("!R971U<FX@
M)&QO8V%T:6]N<SL*("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!G971,
M;V-A=&EO;B@I"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&1A=&$@9F]R
M('1H92!L;V-A=&EO;B!B96QO;F=I;F<@=&\@=&AE($E$"B`@("`@*@H@("`@
M("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1I9`H@
M("`@("H@0')E='5R;B`@4$5!4E]%<G)O<GQA<G)A>0H@("`@("H@0'1H<F]W
M<R`@4$5!4E]%<G)O<@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$QO8V%T:6]N*"1I9"`]("(B*0H@("`@>PH@("`@
M("`@("1S=&%T=7,@/2`D=&AI<RT^7V-H96-K3&]C871I;VY)1"@D:60I.PH*
M("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'-T871U<SL*("`@("`@("!]"@H@
M("`@("`@("1L;V-A=&EO;E)E='5R;B`](&%R<F%Y*"D["@H@("`@("`@(&EF
M("@D=&AI<RT^7V-A8VAE16YA8FQE9"`F)B`H)&QO8V%T:6]N(#T@)'1H:7,M
M/E]C86-H92T^9V5T*")'5RTB+B1I9"P@(FQO8V%T:6]N(BDI*2!["B`@("`@
M("`@("`@("\O($=E="!D871A(&9R;VT@8V%C:&4*("`@("`@("`@("`@)'1H
M:7,M/E]L;V-A=&EO;B`]("1L;V-A=&EO;CL*("`@("`@("`@("`@)&QO8V%T
M:6]N4F5T=7)N6R)C86-H92)=(#T@(DA)5"(["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@+R\@0VAE8VLL(&EF('1H92!S=&%T:6]N4V]A<"U/8FIE
M8W0@:7,@<')E<V5N="X@268@;F]T+"!C;VYN96-T('1O('1H92!397)V97(@
M86YD(')E=')I979E('1H92!71%-,(&1A=&$*("`@("`@("`@("`@:68@*"$D
M=&AI<RT^7W-T871I;VY3;V%P*2!["B`@("`@("`@("`@("`@("`D<W1A='5S
M(#T@)'1H:7,M/E]C;VYN96-T4V5R=F5R*"D["B`@("`@("`@("`@("`@("!I
M9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D<W1A='5S.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`D;&]C871I;VX@/2`D
M=&AI<RT^7W-T871I;VY3;V%P+3YG9713=&%T:6]N*"1I9"D["@H@("`@("`@
M("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D;&]C871I;VXI
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&QO8V%T:6]N.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7VQO8V%T:6]N(#T@)&QO8V%T
M:6]N.PH*("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%;F%B;&5D*2![
M"B`@("`@("`@("`@("`@("`O+R`N+BYA;F0@8V%C:&4@:70*("`@("`@("`@
M("`@("`@("1E>'!I<F4@/2!C;VYS=&%N="@B4T525DE#15-?5T5!5$A%4E]%
M6%!)4D537TQ/0T%424].(BD["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-A
M8VAE+3YE>'13879E*")'5RTB+B1I9"P@)'1H:7,M/E]L;V-A=&EO;BP@(B(L
M("1E>'!I<F4L(")L;V-A=&EO;B(I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1L;V-A=&EO;E)E='5R;ELB8V%C:&4B72`](")-25-3(CL*("`@("`@
M("!]"B`@("`@("`@:68@*'-T<FQE;B@D=&AI<RT^7VQO8V%T:6]N+3YR96=I
M;VXI("8F('-T<FQE;B@D=&AI<RT^7VQO8V%T:6]N+3YC;W5N=')Y*2D@>PH@
M("`@("`@("`@("`D;&]C;F%M92`]("1T:&ES+3Y?;&]C871I;VXM/FYA;64N
M(BP@(BXD=&AI<RT^7VQO8V%T:6]N+3YR96=I;VXN(BP@(BXD=&AI<RT^7VQO
M8V%T:6]N+3YC;W5N=')Y.PH@("`@("`@('T@96QS96EF("AS=')L96XH)'1H
M:7,M/E]L;V-A=&EO;BT^8V]U;G1R>2DI('L*("`@("`@("`@("`@)&QO8VYA
M;64@/2`D=&AI<RT^7VQO8V%T:6]N+3YN86UE+B(L("(N)'1H:7,M/E]L;V-A
M=&EO;BT^8V]U;G1R>3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M;&]C;F%M92`]("1T:&ES+3Y?;&]C871I;VXM/FYA;64["B`@("`@("`@?0H@
M("`@("`@("1L;V-A=&EO;E)E='5R;ELB;F%M92)=("`@("`@/2`D;&]C;F%M
M93L*("`@("`@("`D;&]C871I;VY2971U<FY;(FQA=&ET=61E(ET@(#T@)'1H
M:7,M/E]L;V-A=&EO;BT^;&%T:71U9&4["B`@("`@("`@)&QO8V%T:6]N4F5T
M=7)N6R)L;VYG:71U9&4B72`]("1T:&ES+3Y?;&]C871I;VXM/FQO;F=I='5D
M93L*("`@("`@("`D;&]C871I;VY2971U<FY;(G-U;G)I<V4B72`@(#T@9&%T
M92@D=&AI<RT^7W1I;65&;W)M870L("1T:&ES+3YC86QC=6QA=&53=6Y2:7-E
M4V5T*&=M;6MT:6UE*"DL(%-53D953D-37U)%5%]424U%4U1!35`L("1T:&ES
M+3Y?;&]C871I;VXM/FQA=&ET=61E+"`D=&AI<RT^7VQO8V%T:6]N+3YL;VYG
M:71U9&4L(%-%4E9)0T537U=%051(15)?4U5.1E5.0U-?4U5.4DE315]:14Y)
M5$@L(#`L('1R=64I*3L*("`@("`@("`D;&]C871I;VY2971U<FY;(G-U;G-E
M=")=("`@(#T@9&%T92@D=&AI<RT^7W1I;65&;W)M870L("1T:&ES+3YC86QC
M=6QA=&53=6Y2:7-E4V5T*&=M;6MT:6UE*"DL(%-53D953D-37U)%5%]424U%
M4U1!35`L("1T:&ES+3Y?;&]C871I;VXM/FQA=&ET=61E+"`D=&AI<RT^7VQO
M8V%T:6]N+3YL;VYG:71U9&4L(%-%4E9)0T537U=%051(15)?4U5.1E5.0U-?
M4U5.4T547UI%3DE42"P@(#`L(&9A;'-E*2D["B`@("`@("`@)&QO8V%T:6]N
M4F5T=7)N6R)E;&5V871I;VXB72`]("1T:&ES+3Y?;&]C871I;VXM/F5L979A
M=&EO;CL*"B`@("`@("`@<F5T=7)N("1L;V-A=&EO;E)E='5R;CL*("`@('T*
M("`@("\O('U]?0H*("`@("\O('M[>R!G971796%T:&5R*"D*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@=V5A=&AE<BUD871A(&9O<B!T:&4@<W5P<&QI
M960@;&]C871I;VX*("`@("`J"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@
M("`@("`@("`@("`@("`@("`@)&ED"B`@("`@*B!`<&%R86T@("!S=')I;F<@
M("`@("`@("`@("`@("`@("`@("`@)'5N:71S1F]R;6%T"B`@("`@*B!`<F5T
M=7)N("!014%27T5R<F]R?&%R<F%Y"B`@("`@*B!`=&AR;W=S("!014%27T5R
M<F]R"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T5V5A=&AE<B@D:60@/2`B(BP@)'5N:71S1F]R;6%T(#T@(B(I"B`@
M("!["B`@("`@("`@<W1A=&EC("1C;&]U9',["B`@("`@("`@:68@*"%I<W-E
M="@D8VQO=61S*2D@>PH@("`@("`@("`@("`D8VQO=61S("`@(#T@87)R87DH
M"B`@("`@("`@("`@("`@("`B<VMY(&-L96%R(BP*("`@("`@("`@("`@("`@
M(")F97<B+`H@("`@("`@("`@("`@("`@(G-C871T97)E9"(L"B`@("`@("`@
M("`@("`@("`B8G)O:V5N(BP*("`@("`@("`@("`@("`@(")O=F5R8V%S="(L
M"B`@("`@("`@("`@("D["B`@("`@("`@?0H*("`@("`@("`D<W1A='5S(#T@
M)'1H:7,M/E]C:&5C:TQO8V%T:6]N240H)&ED*3L*"B`@("`@("`@:68@*%-E
M<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1S=&%T=7,["B`@("`@("`@?0H*("`@("`@("`O+R!'970@
M;W1H97(@9&%T80H@("`@("`@("1U;FET<R`@("`]("1T:&ES+3YG9715;FET
M<T9O<FUA="@D=6YI='-&;W)M870I.PH*("`@("`@("`D=V5A=&AE<E)E='5R
M;B`](&%R<F%Y*"D["B`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%;F%B;&5D
M("8F("@D=V5A=&AE<B`]("1T:&ES+3Y?8V%C:&4M/F=E="@B1U<M(BXD:60L
M(")W96%T:&5R(BDI*2!["B`@("`@("`@("`@("\O(%-A;64@<')O8V5D=7)E
M+BXN"B`@("`@("`@("`@("1T:&ES+3Y?=V5A=&AE<B`]("1W96%T:&5R.PH@
M("`@("`@("`@("`D=V5A=&AE<E)E='5R;ELB8V%C:&4B72`](")(250B.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O($-H96-K+"!I9B!T:&4@
M=V5A=&AE<E-O87`M3V)J96-T(&ES('!R97-E;G0N($EF(&YO="P@8V]N;F5C
M="!T;R!T:&4@4V5R=F5R(&%N9"!R971R:65V92!T:&4@5T133"!D871A"B`@
M("`@("`@("`@(&EF("@A)'1H:7,M/E]W96%T:&5R4V]A<"D@>PH@("`@("`@
M("`@("`@("`@)'-T871U<R`]("1T:&ES+3Y?8V]N;F5C=%-E<G9E<B@I.PH@
M("`@("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H
M)'-T871U<RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'-T871U
M<SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+R\@+BXN87,@;&%S="!F=6YC=&EO;@H@("`@("`@("`@("`D=V5A=&AE
M<B`]("1T:&ES+3Y?=V5A=&AE<E-O87`M/F=E=%=E871H97)297!O<G0H)&ED
M*3L*"B`@("`@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R
M*"1W96%T:&5R*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1W96%T:&5R
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7W=E871H97(@
M/2`D=V5A=&AE<CL*"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V-A8VAE16YA
M8FQE9"D@>PH@("`@("`@("`@("`@("`@+R\@+BXN86YD(&-A8VAE(&ET"B`@
M("`@("`@("`@("`@("`D97AP:7)E(#T@8V]N<W1A;G0H(E-%4E9)0T537U=%
M051(15)?15A025)%4U]714%42$52(BD["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V-A8VAE+3YE>'13879E*")'5RTB+B1I9"P@)'1H:7,M/E]W96%T:&5R
M+"`B(BP@)&5X<&ER92P@(G=E871H97(B*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D=V5A=&AE<E)E='5R;ELB8V%C:&4B72`](")-25-3(CL*("`@
M("`@("!]"@H@("`@("`@("1U<&1A=&4@/2!T<FEM*'-T<E]R97!L86-E*&%R
M<F%Y*")4(BP@(EHB*2P@(B`B+"`D=&AI<RT^7W=E871H97(M/G1I;65S=&%M
M<"DI+B(@1TU4(CL*"B`@("`@("`@)'=E871H97)2971U<FY;(G5P9&%T92)=
M("`@("`@("`@("`@/2!G;61A=&4H=')I;2@D=&AI<RT^7V1A=&5&;W)M870N
M(B`B+B1T:&ES+3Y?=&EM949O<FUA="DL('-T<G1O=&EM92@D=7!D871E*2D[
M"B`@("`@("`@)'=E871H97)2971U<FY;(G5P9&%T95)A=R)=("`@("`@("`@
M/2`D=&AI<RT^7W=E871H97(M/G1I;65S=&%M<#L*("`@("`@("!I9B`H<W1R
M;&5N*"1T:&ES+3Y?=V5A=&AE<BT^<W1A=&EO;BT^<F5G:6]N*2`F)B!S=')L
M96XH)'1H:7,M/E]W96%T:&5R+3YS=&%T:6]N+3YC;W5N=')Y*2D@>PH@("`@
M("`@("`@("`D;&]C;F%M92`]("1T:&ES+3Y?=V5A=&AE<BT^<W1A=&EO;BT^
M;F%M92XB+"`B+B1T:&ES+3Y?=V5A=&AE<BT^<W1A=&EO;BT^<F5G:6]N+B(L
M("(N)'1H:7,M/E]W96%T:&5R+3YS=&%T:6]N+3YC;W5N=')Y.PH@("`@("`@
M('T@96QS96EF("AS=')L96XH)'1H:7,M/E]W96%T:&5R+3YS=&%T:6]N+3YC
M;W5N=')Y*2D@>PH@("`@("`@("`@("`D;&]C;F%M92`]("1T:&ES+3Y?=V5A
M=&AE<BT^<W1A=&EO;BT^;F%M92XB+"`B+B1T:&ES+3Y?=V5A=&AE<BT^<W1A
M=&EO;BT^8V]U;G1R>3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M;&]C;F%M92`]("1T:&ES+3Y?=V5A=&AE<BT^<W1A=&EO;BT^;F%M93L*("`@
M("`@("!]"B`@("`@("`@)'=E871H97)2971U<FY;(G-T871I;VXB72`@("`@
M("`@("`@/2`D;&]C;F%M93L*("`@("`@("`D=V5A=&AE<E)E='5R;ELB=VEN
M9")=("`@("`@("`@("`@("`]("1T:&ES+3YC;VYV97)T4W!E960H)'1H:7,M
M/E]W96%T:&5R+3YW:6YD+3YP<F5V86EL:6YG7W-P965D+"`B;7!S(BP@)'5N
M:71S6R)W:6YD(ETI.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)W:6YD1&5G
M<F5E<R)=("`@("`@(#T@)'1H:7,M/E]W96%T:&5R+3YW:6YD+3YP<F5V86EL
M:6YG7V1I<F5C=&EO;BT^9&5G<F5E<SL*("`@("`@("`D=V5A=&AE<E)E='5R
M;ELB=VEN9$1I<F5C=&EO;B)=("`@("`]("1T:&ES+3Y?=V5A=&AE<BT^=VEN
M9"T^<')E=F%I;&EN9U]D:7)E8W1I;VXM/F-O;7!A<W,["B`@("`@("`@:68@
M*"1T:&ES+3Y?=V5A=&AE<BT^=VEN9"T^<')E=F%I;&EN9U]S<&5E9"`A/2`D
M=&AI<RT^7W=E871H97(M/G=I;F0M/F=U<W1?<W!E960I('L*("`@("`@("`@
M("`@)'=E871H97)2971U<FY;(G=I;F1'=7-T(ET@("`@("`]("1T:&ES+3YC
M;VYV97)T4W!E960H)'1H:7,M/E]W96%T:&5R+3YW:6YD+3YG=7-T7W-P965D
M+"`B;7!S(BP@)'5N:71S6R)W:6YD(ETI.PH@("`@("`@('T*("`@("`@("!I
M9B`H)'1H:7,M/E]W96%T:&5R+3YW:6YD+3YV87)Y:6YG7V9R;VU?9&ER96-T
M:6]N("$]("(B("8F("1T:&ES+3Y?=V5A=&AE<BT^=VEN9"T^=F%R>6EN9U]T
M;U]D:7)E8W1I;VX@(3T@(B(I('L*("`@("`@("`@("`@)'=E871H97)2971U
M<FY;(G=I;F1687(B72`@("`@("`](&%R<F%Y("@*("`@("`@("`@("`@("`@
M(")F<F]M(B`]/B`D=&AI<RT^7W=E871H97(M/G=I;F0M/G9A<GEI;F=?9G)O
M;5]D:7)E8W1I;VXL"B`@("`@("`@("`@("`@("`B=&\B("`@/3X@)'1H:7,M
M/E]W96%T:&5R+3YW:6YD+3YV87)Y:6YG7W1O7V1I<F5C=&EO;@H@("`@("`@
M("`@("`I.PH@("`@("`@('T*"B`@("`@("`@)'=E871H97)2971U<FY;(G9I
M<VEB:6QI='DB72`@("`@("`@/2`D=&AI<RT^8V]N=F5R=$1I<W1A;F-E*"1T
M:&ES+3Y?=V5A=&AE<BT^=FES:6)I;&ET>2T^9&ES=&%N8V4@+R`Q,#`P+"`B
M:VTB+"`D=6YI='-;(G9I<R)=*3L*("`@("`@("`D=V5A=&AE<E)E='5R;ELB
M=FES475A;&EF:65R(ET@("`@("`]("1T:&ES+3Y?=V5A=&AE<BT^=FES:6)I
M;&ET>2T^<75A;&EF:65R.PH*("`@("`@("`D8V]N9&ET:6]N(#T@87)R87DH
M*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'1H:7,M/E]W
M96%T:&5R+3YP:&5N;VUE;F$I.R`D:2LK*2!["B`@("`@("`@("`@("1C;VYD
M:71I;VY;72`]("1T:&ES+3Y?=V5A=&AE<BT^<&AE;F]M96YA6R1I72T^<W1R
M:6YG.PH@("`@("`@('T*("`@("`@("`D=V5A=&AE<E)E='5R;ELB8V]N9&ET
M:6]N(ET@("`@("`@("`](&EM<&QO9&4H(BP@(BP@)&-O;F1I=&EO;BD["@H@
M("`@("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^7W=E871H97(M/G-K>2T^;&%Y
M97)S*2D@>PH@("`@("`@("`@("`D;&%Y97)S(#T@87)R87DH*3L*("`@("`@
M("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1T:&ES+3Y?=V5A=&AE
M<BT^<VMY+3YL87EE<G,I.R`D:2LK*2!["B`@("`@("`@("`@("`@("!I9B`H
M<W1R=&]U<'!E<B@D=&AI<RT^7W=E871H97(M/G-K>2T^;&%Y97)S6R1I72T^
M='EP92D@(3T@(D-,14%2(BD@>PH@("`@("`@("`@("`@("`@("`@("1L87EE
M<G-;)&E=("`@("`@("`@("`@(#T@87)R87DH*3L*("`@("`@("`@("`@("`@
M("`@("`D;&%Y97)S6R1I75LB86UO=6YT(ET@("`]("1C;&]U9'-;)'1H:7,M
M/E]W96%T:&5R+3YS:WDM/FQA>65R<ULD:5TM/F5X=&5N=%T["B`@("`@("`@
M("`@("`@("`@("`@)&QA>65R<ULD:5U;(FAE:6=H=")=("`@/2`D=&AI<RT^
M8V]N=F5R=$1I<W1A;F-E*"1T:&ES+3Y?=V5A=&AE<BT^<VMY+3YL87EE<G-;
M)&E=+3YA;'1I='5D92P@(FTB+"`D=6YI='-;(FAE:6=H=")=*3L*("`@("`@
M("`@("`@("`@("`@("!I9B`H<W1R=&]U<'!E<B@D=&AI<RT^7W=E871H97(M
M/G-K>2T^;&%Y97)S6R1I72T^='EP92D@(3T@(D-,3U5$(BD@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D;&%Y97)S6R1I75LB='EP92)=(#T@=6-W;W)D
M<RAS=')?<F5P;&%C92@B7R(L("(B+"`D=&AI<RT^7W=E871H97(M/G-K>2T^
M;&%Y97)S6R1I72T^='EP92DI.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M<VEZ96]F*"1L87EE<G,I*2!["B`@("`@("`@("`@("`@("`D=V5A=&AE<E)E
M='5R;ELB8VQO=61S(ET@("`@("`@(#T@)&QA>65R<SL*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@)'=E871H97)2971U<FY;(G1E;7!E<F%T
M=7)E(ET@("`@("`@/2`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E*"1T:&ES
M+3Y?=V5A=&AE<BT^=&5M<&5R871U<F4M/F%M8FEE;G0L(")C(BP@)'5N:71S
M6R)T96UP(ETI.PH@("`@("`@("1F96QT5&5M<&5R871U<F4@/2`D=&AI<RT^
M8V%L8W5L871E5VEN9$-H:6QL*"1T:&ES+3YC;VYV97)T5&5M<&5R871U<F4H
M)'=E871H97)2971U<FY;(G1E;7!E<F%T=7)E(ETL("1U;FET<ULB=&5M<")=
M+"`B9B(I+"`D=&AI<RT^8V]N=F5R=%-P965D*"1W96%T:&5R4F5T=7)N6R)W
M:6YD(ETL("1U;FET<ULB=VEN9")=+"`B;7!H(BDI.PH@("`@("`@("1W96%T
M:&5R4F5T=7)N6R)F96QT5&5M<&5R871U<F4B72`@(#T@)'1H:7,M/F-O;G9E
M<G1496UP97)A='5R92@D9F5L=%1E;7!E<F%T=7)E+"`B9B(L("1U;FET<ULB
M=&5M<")=*3L*("`@("`@("`D=V5A=&AE<E)E='5R;ELB9&5W4&]I;G0B72`@
M("`@("`@("`]("1T:&ES+3YC;VYV97)T5&5M<&5R871U<F4H)'1H:7,M/E]W
M96%T:&5R+3YT96UP97)A='5R92T^9&5W<&]I;G0L(")C(BP@)'5N:71S6R)T
M96UP(ETI.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)H=6UI9&ET>2)=("`@
M("`@("`@(#T@)'1H:7,M/E]W96%T:&5R+3YT96UP97)A='5R92T^<F5L871I
M=F5?:'5M:61I='D["B`@("`@("`@)'=E871H97)2971U<FY;(G!R97-S=7)E
M(ET@("`@("`@("`@/2`D=&AI<RT^8V]N=F5R=%!R97-S=7)E*"1T:&ES+3Y?
M=V5A=&AE<BT^<')E<W-U<F4M/F%L=&EM971E<BP@(FAP82(L("1U;FET<ULB
M<')E<R)=*3L*"B`@("`@("`@<F5T=7)N("1W96%T:&5R4F5T=7)N.PH@("`@
M?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&=E=$9O<F5C87-T*"D*("`@("\J
M*@H@("`@("H@1VQO8F%L5V5A=&AE<B!H87,@;F\@9F]R96-A<W0@<&5R('-E
M+"!S;R!T:&ES(&9U;F-T:6]N(&ES(&IU<W0@9F]R"B`@("`@*B!C;VUP871I
M8FEL:71Y('!U<G!O<V5S+@H@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN
M9R`@("`@("`@("`@("`@("`@("`@("`D:6YT"B`@("`@*B!`<&%R86T@("!I
M;G0@("`@("`@("`@("`@("`@("`@("`@("`@)&1A>7,*("`@("`J($!P87)A
M;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D=6YI='-&;W)M870*
M("`@("`J($!R971U<FX@(&)O;VP*("`@("`J($!A8V-E<W,@('!U8FQI8PH@
M("`@("H@0&1E<')E8V%T960*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1F]R
M96-A<W0H)&ED(#T@;G5L;"P@)&1A>7,@/2!N=6QL+"`D=6YI='-&;W)M870@
M/2!N=6QL*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*("`@
M("\O('U]?0I]"B\O('U]?0H_/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]397)V:6-E<R]796%T:&5R+TUE=&%R+G!H<```````````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#(U,C`R-``Q,#4Q-30S,S<S-``P,C,U-30`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RH@
M=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F
M='1A8G-T;W`]-"!F;VQD;65T:&]D/6UA<FME<CH@*B\*"B\J*@H@*B!014%2
M.CI397)V:6-E<U]796%T:&5R7TUE=&%R"B`J"B`J(%!(4"!V97)S:6]N<R`T
M(&%N9"`U"B`J"B`J(#Q,24-%3E-%/@H@*B!#;W!Y<FEG:'0@*&,I(#(P,#4L
M($%L97AA;F1E<B!7:7)T>@H@*B!!;&P@<FEG:'1S(')E<V5R=F5D+@H@*@H@
M*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y
M(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D:69I8V%T:6]N+"!A<F4@
M<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I
M;VYS"B`J(&%R92!M970Z"B`J(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C
M92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T:6-E
M+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W
M:6YG(&1I<V-L86EM97(N"B`J(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R
M>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T
M:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L
M;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE(&1O8W5M96YT871I;VX*("H@("!A
M;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R
M:6)U=&EO;BX*("H@;R!.96ET:&5R('1H92!N86UE(&]F('1H92!S;V9T=V%R
M92!N;W(@=&AE(&YA;65S(&]F(&ET<R!C;VYT<FEB=71O<G,*("H@("!M87D@
M8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C=',@9&5R:79E
M9"!F<F]M('1H:7,@<V]F='=A<F4*("H@("!W:71H;W5T('-P96-I9FEC('!R
M:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H*("H@5$A)4R!33T945T%212!)
M4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/3E12
M24)55$]24R`B05,@25,B"B`J($%.1"!!3ED@15A04D534R!/4B!)35!,245$
M(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$(%1/+"!4
M2$4*("H@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!
M3D0@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/4T4*("H@05)%($1)
M4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'2%0@3U=.
M15(@3U(@0T].5%))0E543U)3($)%"B`J($Q)04),12!&3U(@04Y9($1)4D5#
M5"P@24Y$25)%0U0L($E.0TE$14Y404PL(%-014-)04PL($5814U03$%262P@
M3U(*("H@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L($)55"!.
M3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8*("H@4U5"4U1)5%5412!'
M3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L($1!5$$L($]2(%!23T9)
M5%,[($]2($)54TE.15-3"B`J($E.5$524E505$E/3BD@2$]7159%4B!#0553
M140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E.
M"B`J($-/3E1204-4+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4("A)3D-,
M541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I"B`J($%225-)3D<@24X@
M04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3(%-/1E1705)%+"!%5D5.
M($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,2519($]&(%-50T@@1$%-
M04=%+@H@*B`\+TQ)0T5.4T4^"B`J"B`J($!C871E9V]R>2`@("!796(@4V5R
M=FEC97,*("H@0'!A8VMA9V4@("`@(%-E<G9I8V5S7U=E871H97(*("H@0&%U
M=&AO<B`@("`@($%L97AA;F1E<B!7:7)T>B`\86QE>$!P8S1P+FYE=#X*("H@
M0&-O<'ER:6=H="`@(#(P,#4@06QE>&%N9&5R(%=I<G1Z"B`J($!L:6-E;G-E
M("`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL
M:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@($-64SH@
M)$ED.B!-971A<BYP:'`L=B`Q+C@W(#(P,#8O,#,O,#@@,3(Z,SDZ,3@@97)U
M($5X<"`D"B`J($!L:6YK("`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A
M8VMA9V4O4V5R=FEC97-?5V5A=&AE<@H@*B!`;&EN:R`@("`@("`@:'1T<#HO
M+W=E871H97(N;F]A82YG;W8O=V5A=&AE<B]M971A<BYS:'1M;`H@*B!`;&EN
M:R`@("`@("`@:'1T<#HO+W=E871H97(N;F]A82YG;W8O=V5A=&AE<B]T868N
M<VAT;6P*("H@0&5X86UP;&4@("`@(&5X86UP;&5S+VUE=&%R+6)A<VEC+G!H
M<"`@("`@("`@("`@(&UE=&%R+6)A<VEC+G!H<`H@*B!`97AA;7!L92`@("`@
M97AA;7!L97,O;65T87(M97AT96YS:79E+G!H<"`@("`@("`@;65T87(M97AT
M96YS:79E+G!H<`H@*B!`9FEL97-O=7)C90H@*B\*"G)E<75I<F5?;VYC92`B
M4V5R=FEC97,O5V5A=&AE<B]#;VUM;VXN<&AP(CL*"G)E<75I<F5?;VYC92`B
M1$(N<&AP(CL*"B\O('M[>R!C;&%S<R!397)V:6-E<U]796%T:&5R7TUE=&%R
M"B\J*@H@*B!4:&ES(&-L87-S(&%C=',@87,@86X@:6YT97)F86-E('1O('1H
M92!-151!4B]4048@<V5R=FEC92!O9@H@*B!W96%T:&5R+FYO86$N9V]V+B!)
M="!S96%R8VAE<R!F;W(@;&]C871I;VYS(&=I=F5N(&EN($E#04\@;F]T871I
M;VX@86YD"B`J(')E=')I979E<R!T:&4@8W5R<F5N="!W96%T:&5R(&1A=&$N
M"B`J"B`J($]F(&-O=7)S92!T:&4@<&%R<VEN9R!O9B!T:&4@345405(M9&%T
M82!H87,@:71S(&QI;6ET871I;VYS+"!A<R!I=`H@*B!F;VQL;W=S('1H92!&
M961E<F%L($UE=&5O<F]L;V=I8V%L($AA;F1B;V]K($YO+C$@=VET:"!M;V1I
M9FEC871I;VYS('1O"B`J(&%C8V]M;V1A=&4@9F]R(&YO;BU54R!R97!O<G1S
M+"!S;R!I9B!T:&4@<F5P;W)T(&1E=FEA=&5S(&9R;VT@=&AE<V4*("H@<W1A
M;F1A<F1S+"!Y;W4@=V]N)W0@9V5T(&ET('!A<G-E9"!C;W)R96-T;'DN"B`J
M($%N>71H:6YG('1H870@:7,@;F]T('!A<G-E9"P@:7,@<V%V960@:6X@=&AE
M(")N;W!A<G-E(B!A<G)A>2UE;G1R>2P*("H@<F5T=7)N960@8GD@9V5T5V5A
M=&AE<B@I+"!S;R!Y;W4@8V%N(&1O('EO=7(@;W=N('!A<G-I;F<@869T97)W
M87)D<RX@5&AI<PH@*B!L:6UI=&%T:6]N(&ES('-P96-I9FEC86QL>2!G:79E
M;B!F;W(@<F5M87)K<RP@87,@=&AE(&-L87-S(&ES(&YO=`H@*B!P<F]C97-S
M:6YG(&5V97)Y=&AI;F<@;65N=&EO;F5D('1H97)E+"!B=70@>6]U('=I;&P@
M9V5T('1H92!M;W-T(&-O;6UO;@H@*B!F:65L9',@;&EK92!P<F5C:7!I=&%T
M:6]N(&%N9"!T96UP97)A='5R92UC:&%N9V5S+B!!9V%I;BP@979E<GET:&EN
M9R!N;W0*("H@<&%R<V5D+"!G;V5S(&EN=&\@(FYO<&%R<V4B+@H@*@H@*B!)
M9B!Y;W4@=&AI;FLL('-O;64@:6UP;W)T86YT(&9I96QD(&ES(&UI<W-I;F<@
M;W(@;F]T(&-O<G)E8W1L>2!P87)S960L"B`J('!L96%S92!F:6QE(&$@9F5A
M='5R92UR97%U97-T+V)U9W)E<&]R="!A="!H='1P.B\O<&5A<BYP:'`N;F5T
M+R!A;F0@8F4*("H@<W5R92!T;R!P<F]V:61E('1H92!-151!4B`H;W(@5$%&
M*2!R97!O<G0@=VET:"!A(%]D971A:6QE9%\@97AP;&%N871I;VXA"B`J"B`J
M($9O<B!W;W)K:6YG(&5X86UP;&5S+"!P;&5A<V4@=&%K92!A(&QO;VL@870*
M("H@("`@(&1O8W,O4V5R=FEC97-?5V5A=&AE<B]E>&%M<&QE<R]M971A<BUB
M87-I8RYP:'`*("H@("`@(&1O8W,O4V5R=FEC97-?5V5A=&AE<B]E>&%M<&QE
M<R]M971A<BUE>'1E;G-I=F4N<&AP"B`J"B`J"B`J($!C871E9V]R>2`@("!7
M96(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@(%-E<G9I8V5S7U=E871H97(*
M("H@0&%U=&AO<B`@("`@($%L97AA;F1E<B!7:7)T>B`\86QE>$!P8S1P+FYE
M=#X*("H@0&-O<'ER:6=H="`@(#(P,#4@06QE>&%N9&5R(%=I<G1Z"B`J($!L
M:6-E;G-E("`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S
M+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@
M(%)E;&5A<V4Z(#$N-"XP"B`J($!L:6YK("`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4V5R=FEC97-?5V5A=&AE<@H@*B!`;&EN:R`@("`@
M("`@:'1T<#HO+W=E871H97(N;F]A82YG;W8O=V5A=&AE<B]M971A<BYS:'1M
M;`H@*B!`;&EN:R`@("`@("`@:'1T<#HO+W=E871H97(N;F]A82YG;W8O=V5A
M=&AE<B]T868N<VAT;6P*("H@0&5X86UP;&4@("`@(&5X86UP;&5S+VUE=&%R
M+6)A<VEC+G!H<"`@("`@("`@("`@(&UE=&%R+6)A<VEC+G!H<`H@*B!`97AA
M;7!L92`@("`@97AA;7!L97,O;65T87(M97AT96YS:79E+G!H<"`@("`@("`@
M;65T87(M97AT96YS:79E+G!H<`H@*B\*8VQA<W,@4V5R=FEC97-?5V5A=&AE
M<E]-971A<B!E>'1E;F1S(%-E<G9I8V5S7U=E871H97)?0V]M;6]N"GL*("`@
M("\O('M[>R!P<F]P97)T:65S"B`@("`O*BH*("`@("`J($EN9F]R;6%T:6]N
M('1O(&%C8V5S<R!T:&4@;&]C871I;VX@1$(*("`@("`J"B`@("`@*B!`=F%R
M("`@("!O8FIE8W0@($1"("`@("`@("`@("`@("`@("`@)%]D8@H@("`@("H@
M0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]D8CL*"B`@("`O
M*BH*("`@("`J(%1H92!S;W5R8V4@345405(@=7-E<PH@("`@("H*("`@("`J
M($!V87(@("`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D7W-O=7)C
M94UE=&%R"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@('9A
M<B`D7W-O=7)C94UE=&%R.PH*("`@("\J*@H@("`@("H@5&AE('-O=7)C92!4
M048@=7-E<PH@("`@("H*("`@("`J($!V87(@("`@('-T<FEN9R`@("`@("`@
M("`@("`@("`@("`@("`D7W-O=7)C951A9@H@("`@("H@0&%C8V5S<R`@<')I
M=F%T90H@("`@("HO"B`@("!V87(@)%]S;W5R8V54868["@H@("`@+RHJ"B`@
M("`@*B!4:&ES('!A=&@@:7,@=7-E9"!T;R!F:6YD('1H92!-151!4B!D871A
M"B`@("`@*@H@("`@("H@0'9A<B`@("`@<W1R:6YG("`@("`@("`@("`@("`@
M("`@("`@("1?<V]U<F-E4&%T:$UE=&%R"B`@("`@*B!`86-C97-S("!P<FEV
M871E"B`@("`@*B\*("`@('9A<B`D7W-O=7)C95!A=&A-971A<CL*"B`@("`O
M*BH*("`@("`J(%1H:7,@<&%T:"!I<R!U<V5D('1O(&9I;F0@=&AE(%1!1B!D
M871A"B`@("`@*@H@("`@("H@0'9A<B`@("`@<W1R:6YG("`@("`@("`@("`@
M("`@("`@("`@("1?<V]U<F-E4&%T:%1A9@H@("`@("H@0&%C8V5S<R`@<')I
M=F%T90H@("`@("HO"B`@("!V87(@)%]S;W5R8V50871H5&%F.PH@("`@+R\@
M?7U]"@H@("`@+R\@>WM[(&-O;G-T<G5C=&]R"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0'!A<F%M("`@87)R87D@("`@("`@
M("`@("`@("`@("`@("`@("1O<'1I;VYS"B`@("`@*B!`<&%R86T@("!M:7AE
M9"`@("`@("`@("`@("`@("`@("`@("`@)&5R<F]R"B`@("`@*B!`=&AR;W=S
M("!014%27T5R<F]R"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%-E<G9I8V5S7U=E871H97)?365T87(H)&]P=&EO;G,L
M("8D97)R;W(I"B`@("!["B`@("`@("`@)'!E<G)O<B`](&YU;&P["B`@("`@
M("`@)'1H:7,M/E-E<G9I8V5S7U=E871H97)?0V]M;6]N*"1O<'1I;VYS+"`D
M<&5R<F]R*3L*("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O
M<B@D<&5R<F]R*2D@>PH@("`@("`@("`@("`D97)R;W(@/2`D<&5R<F]R.PH@
M("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`O+R!3970@
M;W!T:6]N<R!A8V-O<F1I;F=L>0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N
M<ULB9'-N(ETI*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULB
M9&)/<'1I;VYS(ETI*2!["B`@("`@("`@("`@("`@("`D<W1A='5S(#T@)'1H
M:7,M/G-E=$UE=&%R1$(H)&]P=&EO;G-;(F1S;B)=+"`D;W!T:6]N<ULB9&)/
M<'1I;VYS(ETI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)'-T871U<R`]("1T:&ES+3YS971-971A<D1"*"1O<'1I;VYS6R)D<VXB
M72D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*%-E<G9I
M8V5S7U=E871H97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@("`@("`@("`@
M)&5R<F]R(#T@)'-T871U<SL*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@
M('T*"B`@("`@("`@+R\@4V5T=&EN9R!T:&4@9&%T82!S;W5R8V5S(&9O<B!-
M151!4B!A;F0@5$%&("T@:&%V92!T;R!W871C:"!O=70@9F]R(&]L9&5R($%0
M22!U<V%G90H@("`@("`@(&EF("@H)'-O=7)C92`](&ES<V5T*"1O<'1I;VYS
M6R)S;W5R8V4B72DI('Q\(&ES<V5T*"1O<'1I;VYS6R)S;W5R8V5-971A<B)=
M*2D@>PH@("`@("`@("`@("`D<V]U<F-E365T87(@/2`D<V]U<F-E(#\@)&]P
M=&EO;G-;(G-O=7)C92)=(#H@)&]P=&EO;G-;(G-O=7)C94UE=&%R(ET["B`@
M("`@("`@("`@(&EF("@H)'-O=7)C95!A=&@@/2!I<W-E="@D;W!T:6]N<ULB
M<V]U<F-E4&%T:")=*2D@?'P@:7-S970H)&]P=&EO;G-;(G-O=7)C95!A=&A-
M971A<B)=*2D@>PH@("`@("`@("`@("`@("`@)'-O=7)C95!A=&A-971A<B`]
M("1S;W5R8V50871H(#\@)&]P=&EO;G-;(G-O=7)C95!A=&@B72`Z("1O<'1I
M;VYS6R)S;W5R8V50871H365T87(B73L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1S;W5R8V50871H365T87(@/2`B(CL*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S;W5R8V5-
M971A<B`](")H='1P(CL*("`@("`@("`@("`@)'-O=7)C95!A=&A-971A<B`]
M("(B.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;(G-O
M=7)C951A9B)=*2D@>PH@("`@("`@("`@("`D<V]U<F-E5&%F(#T@)&]P=&EO
M;G-;(G-O=7)C951A9B)=.PH@("`@("`@("`@("!I9B`H:7-S970H)&]P=&EO
M;ELB<V]U<F-E4&%T:%1A9B)=*2D@>PH@("`@("`@("`@("`@("`@)'-O=7)C
M95!A=&A4868@/2`D;W!T:6]N<ULB<V]U<F-E4&%T:%1A9B)=.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'-O=6-E4&%T:%1A9B`]
M("(B.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'-O=7)C951A9B`](")H='1P(CL*("`@("`@("`@("`@)'-O=7)C95!A
M=&A4868@/2`B(CL*("`@("`@("!]"B`@("`@("`@)'-T871U<R`]("1T:&ES
M+3YS971-971A<E-O=7)C92@D<V]U<F-E365T87(L("1S;W5R8V50871H365T
M87(L("1S;W5R8V54868L("1S;W5R8V50871H5&%F*3L*("`@("`@("!I9B`H
M4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@
M("`@("`D97)R;W(@/2`D<W1A='5S.PH@("`@("`@("`@("!R971U<FX["B`@
M("`@("`@?0H@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[('-E=$UE=&%R
M1$(H*0H@("`@+RHJ"B`@("`@*B!3971S('1H92!P87)A;65T97)S(&YE961E
M9"!F;W(@8V]N;F5C=&EN9R!T;R!T:&4@1$(L('=H97)E('1H90H@("`@("H@
M;&]C871I;VXM<V5A<F-H(&ES(&9E=&-H:6YG(&ET<R!D871A(&9R;VTN(%EO
M=2!N965D('1O(&)U:6QD(&$@1$(*("`@("`J('=I=&@@=&AE(&5X=&5R;F%L
M('1O;VP@8G5I;&1-971A<D1"(&9I<G-T+"!I="!F971C:&5S('1H92!L;V-A
M=&EO;G,*("`@("`J(&%N9"!A:7)P;W)T<R!F<F]M(&$@3D]!02UW96)S:71E
M+@H@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@
M("`@("`@("`D9'-N"B`@("`@*B!`<&%R86T@("!A<G)A>2`@("`@("`@("`@
M("`@("`@("`@("`@)&1B3W!T:6]N<PH@("`@("H@0')E='5R;B`@1$)?17)R
M;W)\8F]O;`H@("`@("H@0'1H<F]W<R`@1$)?17)R;W(*("`@("`J($!S964@
M("`@($1".CIP87)S94133@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=$UE=&%R1$(H)&1S;BP@)&1B3W!T:6]N<R`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@)&1S;FEN9F\@/2!$0CHZ<&%R<V5$
M4TXH)&1S;BD["B`@("`@("`@:68@*&ES7V%R<F%Y*"1D<VYI;F9O*2`F)B`A
M:7-S970H)&1S;FEN9F];(FUO9&4B72DI('L*("`@("`@("`@("`@)&1S;FEN
M9F];(FUO9&4B73T@,#8T-#L*("`@("`@("!]"@H@("`@("`@("\O($EN:71I
M86QI>F4@8V]N;F5C=&EO;B!T;R!$0B!A;F0@<W1O<F4@:6X@;V)J96-T(&EF
M('-U8V-E<W-F=6P*("`@("`@("`D9&(@/2`@1$(Z.F-O;FYE8W0H)&1S;FEN
M9F\L("1D8D]P=&EO;G,I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D9&(I
M*2!["B`@("`@("`@("`@(')E='5R;B`D9&(["B`@("`@("`@?0H@("`@("`@
M("1T:&ES+3Y?9&(@/2`D9&(["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[('-E=$UE=&%R4V]U<F-E*"D*("`@
M("\J*@H@("`@("H@4V5T<R!T:&4@<V]U<F-E+"!W:&5R92!T:&4@8VQA<W,@
M=')I97,@=&\@;&]C871E('1H92!-151!4B]4048@9&%T80H@("`@("H*("`@
M("`J(%-O=7)C92!C86X@8F4@:'1T<"P@9G1P(&]R(&9I;&4N"B`@("`@*B!!
M;'1E<FYA=&4@<V]U<F-E<&%T:',@8V%N(&)E('!R;W9I9&5D+@H@("`@("H*
M("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D
M<V]U<F-E365T87(*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@
M("`@("`@("`@("`D<V]U<F-E4&%T:$UE=&%R"B`@("`@*B!`<&%R86T@("!S
M=')I;F<@("`@("`@("`@("`@("`@("`@("`@)'-O=7)C951A9@H@("`@("H@
M0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1S;W5R8V50
M871H5&%F"B`@("`@*B!`<F5T=7)N("!014%27T524D]2?&)O;VP*("`@("`J
M($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?
M345405)?4T]54D-%7TE.5D%,240*("`@("`J($!A8V-E<W,@('!U8FQI8PH@
M("`@("HO"B`@("!F=6YC=&EO;B!S971-971A<E-O=7)C92@D<V]U<F-E365T
M87(L("1S;W5R8V50871H365T87(@/2`B(BP@)'-O=7)C951A9B`]("(B+"`D
M<V]U<F-E4&%T:%1A9B`]("(B*0H@("`@>PH@("`@("`@(&EF("AI;E]A<G)A
M>2@D<V]U<F-E365T87(L(&%R<F%Y*")H='1P(BP@(F9T<"(L(")F:6QE(BDI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V]U<F-E365T87(@/2`D<V]U<F-E
M365T87(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%-E
M<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%
M4E)/4E]-151!4E]33U520T5?24Y604Q)1"P@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("!]"@H@("`@("`@("\O($-H96-K(&9O<B!A('!R;W!E<B!-
M151!4B!S;W5R8V4@:68@<&%R86UE=&5R(&ES('-E="P@:68@;F]T('-E="!U
M<V4@9&5F875L=',*("`@("`@("!C;&5A<G-T871C86-H92@I.PH@("`@("`@
M(&EF("AS=')L96XH)'-O=7)C95!A=&A-971A<BDI('L*("`@("`@("`@("`@
M:68@*"@D=&AI<RT^7W-O=7)C94UE=&%R(#T](")F:6QE(B`F)B!I<U]D:7(H
M)'-O=7)C95!A=&A-971A<BDI('Q\("@D=&AI<RT^7W-O=7)C94UE=&%R("$]
M(")F:6QE(B`F)B!P87)S95]U<FPH)'-O=7)C95!A=&A-971A<BDI*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7W-O=7)C95!A=&A-971A<B`]("1S;W5R
M8V50871H365T87(["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)6
M24-%4U]714%42$527T524D]27TU%5$%27U-/55)#15])3E9!3$E$+"!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<W=I=&-H("@D<V]U<F-E365T87(I('L*("`@("`@
M("`@("`@("`@(&-A<V4@(FAT='`B.@H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<V]U<F-E4&%T:$UE=&%R(#T@(FAT='`Z+R]W96%T:&5R+FYO86$N
M9V]V+W!U8B]D871A+V]B<V5R=F%T:6]N<R]M971A<B]S=&%T:6]N<R(["B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E
M(")F='`B.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V]U<F-E4&%T
M:$UE=&%R(#T@(F9T<#HO+W=E871H97(N;F]A82YG;W8O9&%T82]O8G-E<G9A
M=&EO;G,O;65T87(O<W1A=&EO;G,B.PH@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@8V%S92`B9FEL92(Z"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]S;W5R8V50871H365T87(@/2`B+B(["B`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(&EF("AI;E]A<G)A>2@D<V]U<F-E5&%F+"!A<G)A>2@B:'1T
M<"(L(")F='`B+"`B9FEL92(I*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-O
M=7)C951A9B`]("1S;W5R8V54868["B`@("`@("`@?2!E;'-E:68@*"1S;W5R
M8V54868@(3T@(B(I('L*("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E
M871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E]-151!
M4E]33U520T5?24Y604Q)1"P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@
M("!]"@H@("`@("`@("\O($-H96-K(&9O<B!A('!R;W!E<B!4048@<V]U<F-E
M(&EF('!A<F%M971E<B!I<R!S970L(&EF(&YO="!S970@=7-E(&1E9F%U;'1S
M"B`@("`@("`@8VQE87)S=&%T8V%C:&4H*3L*("`@("`@("!I9B`H<W1R;&5N
M*"1S;W5R8V50871H5&%F*2D@>PH@("`@("`@("`@("!I9B`H*"1T:&ES+3Y?
M<V]U<F-E5&%F(#T](")F:6QE(B`F)B!I<U]D:7(H)'-O=7)C95!A=&A4868I
M*2!\?"`H)'1H:7,M/E]S;W5R8V54868@(3T@(F9I;&4B("8F('!A<G-E7W5R
M;"@D<V]U<F-E4&%T:%1A9BDI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W-O=7)C95!A=&A4868@/2`D<V]U<F-E4&%T:%1A9CL*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T
M:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?345405)?
M4T]54D-%7TE.5D%,240L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!S=VET8V@@*"1S
M;W5R8V54868I('L*("`@("`@("`@("`@("`@(&-A<V4@(FAT='`B.@H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<V]U<F-E4&%T:%1A9B`](")H='1P
M.B\O=V5A=&AE<BYN;V%A+F=O=B]P=6(O9&%T82]F;W)E8V%S=',O=&%F+W-T
M871I;VYS(CL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@(&-A<V4@(F9T<"(Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]S;W5R8V50871H5&%F(#T@(F9T<#HO+W=E871H97(N;F]A82YG;W8O9&%T
M82]F;W)E8V%S=',O=&%F+W-T871I;VYS(CL*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(F9I;&4B.@H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<V]U<F-E4&%T:%1A9B`]("(N(CL*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"B`@("`O+R!]?7T*"B`@
M("`O+R![>WL@7V-H96-K3&]C871I;VY)1"@I"B`@("`O*BH*("`@("`J($-H
M96-K<R!T:&4@:60@9F]R('9A;&ED('9A;'5E<R!A;F0@=&AU<R!P<F5V96YT
M<R!S:6QL>2!R97%U97-T<R!T;PH@("`@("H@345405(@<V5R=F5R"B`@("`@
M*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@
M("1I9`H@("`@("H@0')E='5R;B`@4$5!4E]%<G)O<GQB;V]L"B`@("`@*B!`
M=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$527T524D]27TY/
M7TQ/0T%424]."B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI315)624-%
M4U]714%42$527T524D]27TE.5D%,241?3$]#051)3TX*("`@("`J($!A8V-E
M<W,@('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V-H96-K3&]C871I
M;VY)1"@D:60I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1I9"D@?'P@
M:7-?;V)J96-T*"1I9"D@?'P@(7-T<FQE;B@D:60I*2!["B`@("`@("`@("`@
M(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T53
M7U=%051(15)?15)23U)?3D]?3$]#051)3TXL(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("`@("`@?2!E;'-E:68@*"%C='EP95]A;&YU;2@D:60I('Q\("AS
M=')L96XH)&ED*2`^(#0I*2!["B`@("`@("`@("`@(')E='5R;B!397)V:6-E
M<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?
M24Y604Q)1%],3T-!5$E/3BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H@("`@+R\@?7U]"@H@
M("`@+RHJ"B`@("`@*B!$;W=N;&]A9',@=&AE('=E871H97(M(&]R(&9O<F5C
M87-T+61A=&$@9F]R(&%N(&ED(&9R;VT@=&AE('-E<G9E<B!D97!E;F1A;G0@
M;VX@=&AE(&1A=&%T>7!E(&%N9"!R971U<FYS(&ET"B`@("`@*@H@("`@("H@
M0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1I9`H@("`@
M("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1D871A
M5'EP90H@("`@("H@0')E='5R;B`@4$5!4E]%<G)O<GQA<G)A>0H@("`@("H@
M0'1H<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]7
M4D].1U]315)615)?1$%400H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@
M("HO"B`@("`O+R![>WL@7W)E=')I979E4V5R=F5R1&%T82@I"B`@("!F=6YC
M=&EO;B!?<F5T<FEE=F5397)V97)$871A*"1I9"P@)&1A=&%4>7!E*2!["B`@
M("`@("`@<W=I=&-H*"1T:&ES+3Y[(E]S;W5R8V4B+G5C9FER<W0H)&1A=&%4
M>7!E*7TI('L*("`@("`@("`@("`@8V%S92`B9FEL92(Z"B`@("`@("`@("`@
M("`@("`O+R!&:6QE('-O=7)C92!I<R!U<V5D+"!G970@9FEL92!A;F0@<F5A
M9"!A<RUI<R!I;G1O(&$@<W1R:6YG"B`@("`@("`@("`@("`@("`D<V]U<F-E
M(#T@<F5A;'!A=&@H)'1H:7,M/GLB7W-O=7)C95!A=&@B+G5C9FER<W0H)&1A
M=&%4>7!E*7TN(B\B+B1I9"XB+E185"(I.PH@("`@("`@("`@("`@("`@)&1A
M=&$@/2!`9FEL95]G971?8V]N=&5N=',H)'-O=7)C92D["B`@("`@("`@("`@
M("`@("!I9B`H)&1A=&$@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#
M15-?5T5!5$A%4E]%4E)/4E]74D].1U]315)615)?1$%402P@7U]&24Q%7U\L
M(%]?3$E.15]?*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("!C87-E(")H='1P(CH*("`@("`@("`@("`@
M("`@("\O($A45%`@=7-E9"P@86-Q=6ER92!R97%U97-T(&]B:F5C="!A;F0@
M9F5T8V@@9&%T82!F<F]M('=E8G-E<G9E<BX@4F5T=7)N(&)O9'D@;V8@<F5P
M;'D*("`@("`@("`@("`@("`@(&EN8VQU9&5?;VYC92`B2%144"]297%U97-T
M+G!H<"(["@H@("`@("`@("`@("`@("`@)')E<75E<W0@/2`F;F5W($A45%!?
M4F5Q=65S="@D=&AI<RT^>R)?<V]U<F-E4&%T:"(N=6-F:7)S="@D9&%T851Y
M<&4I?2XB+R(N)&ED+B(N5%A4(BP@)'1H:7,M/E]H='1P3W!T:6]N<RD["B`@
M("`@("`@("`@("`@("`D<W1A='5S(#T@)')E<75E<W0M/G-E;F1297%U97-T
M*"D["B`@("`@("`@("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%
M<G)O<B@D<W1A='5S*2!\?"`H:6YT*2`D<F5Q=65S="T^9V5T4F5S<&]N<V5#
M;V1E*"D@/#X@,C`P*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%-E
M<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%
M4E)/4E]74D].1U]315)615)?1$%402P@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D9&%T82`]("1R
M97%U97-T+3YG971297-P;VYS94)O9'DH*3L*("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("!C87-E(")F='`B.@H@("`@("`@("`@("`@("`@
M+R\@1E10(&%S('-O=7)C92P@86-Q=6ER92!N96-C97-S87)Y(&]B:F5C="!F
M:7)S=`H@("`@("`@("`@("`@("`@:6YC;'5D95]O;F-E(").970O1E10+G!H
M<"(["@H@("`@("`@("`@("`@("`@+R\@4&%R<V4@<V]U<F-E('1O(&=E="!T
M:&4@<V5R=F5R(&1A=&$*("`@("`@("`@("`@("`@("1S97)V97(@/2!P87)S
M95]U<FPH)'1H:7,M/GLB7W-O=7)C95!A=&@B+G5C9FER<W0H)&1A=&%4>7!E
M*7TN(B\B+B1I9"XB+E185"(I.PH*("`@("`@("`@("`@("`@("\O($EF(&YE
M8V-E<W-A<GD@;W!T:6]N<R!A<F4@;F]T('-E="P@=7-E(&1E9F%U;'1S"B`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1S97)V97);(G!O<G0B72D@?'P@
M)'-E<G9E<ELB<&]R=")=(#T]("(B('Q\("1S97)V97);(G!O<G0B72`]/2`P
M*2!["B`@("`@("`@("`@("`@("`@("`@)'-E<G9E<ELB<&]R=")=(#T@,C$[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1S97)V97);(G5S97(B72D@?'P@)'-E<G9E<ELB=7-E<B)=(#T]("(B*2![
M"B`@("`@("`@("`@("`@("`@("`@)'-E<G9E<ELB=7-E<B)=(#T@(F9T<"([
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1S97)V97);(G!A<W,B72D@?'P@)'-E<G9E<ELB<&%S<R)=(#T]("(B*2![
M"B`@("`@("`@("`@("`@("`@("`@)'-E<G9E<ELB<&%S<R)=(#T@(F9T<$`B
M.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\O($EN<W1A
M;G1I871E(&]B:F5C="!A;F0@8V]N;F5C="!T;R!S97)V97(*("`@("`@("`@
M("`@("`@("1F='`@/2`F;F5W($YE=%]&5%`H)'-E<G9E<ELB:&]S=")=+"`D
M<V5R=F5R6R)P;W)T(ETL("1T:&ES+3Y?:'1T<$]P=&EO;G-;(G1I;65O=70B
M72D["B`@("`@("`@("`@("`@("`D<W1A='5S(#T@)&9T<"T^8V]N;F5C="@I
M.PH@("`@("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R
M;W(H)'-T871U<RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@4V5R
M=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$527T52
M4D]27U=23TY'7U-%4E9%4E]$051!+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\O($QO9VEN('1O
M('-E<G9E<BXN+@H@("`@("`@("`@("`@("`@)'-T871U<R`]("1F='`M/FQO
M9VEN*"1S97)V97);(G5S97(B72P@)'-E<G9E<ELB<&%S<R)=*3L*("`@("`@
M("`@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T
M=7,I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E
M871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E]74D].
M1U]315)615)?1$%402P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("`@("`O+R`N+BYA;F0@<F5T<FEE=F4@
M=&AE(&1A=&$@:6YT;R!A('1E;7!O<F%R>2!F:6QE"B`@("`@("`@("`@("`@
M("`D=&5M<&9I;&4@/2!T96UP;F%M*"(N+R(L(")397)V:6-E<U]796%T:&5R
M7TUE=&%R(BD["B`@("`@("`@("`@("`@("`D<W1A='5S(#T@)&9T<"T^9V5T
M*"1S97)V97);(G!A=&@B72P@)'1E;7!F:6QE+"!T<G5E+"!&5%!?05-#24DI
M.PH@("`@("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R
M;W(H)'-T871U<RDI('L*("`@("`@("`@("`@("`@("`@("!U;FQI;FLH)'1E
M;7!F:6QE*3L*("`@("`@("`@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?
M5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]27U=2
M3TY'7U-%4E9%4E]$051!+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\O($1I<V-O;FYE8W0@1E10
M('-E<G9E<BP@86YD(')E860@9&%T82!F<F]M('1E;7!O<F%R>2!F:6QE"B`@
M("`@("`@("`@("`@("`D9G1P+3YD:7-C;VYN96-T*"D["B`@("`@("`@("`@
M("`@("`D9&%T82`]($!F:6QE7V=E=%]C;VYT96YT<R@D=&5M<&9I;&4I.PH@
M("`@("`@("`@("`@("`@=6YL:6YK*"1T96UP9FEL92D["B`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@("\O(%-P;&ET(&1A=&$@
M:6YT;R!A;B!A<G)A>2!A;F0@<F5T=7)N"B`@("`@("`@<F5T=7)N('!R96=?
M<W!L:70H(B]<;GQ<<EQN?%QN7'(O(BP@)&1A=&$I.PH@("`@?0H@("`@+R\@
M?7U]"@H@("`@+R\@>WM[(%]P87)S95=E871H97)$871A*"D*("`@("\J*@H@
M("`@("H@4&%R<V5S('1H92!D871A(&%N9"!C86-H97,@:70*("`@("`J"B`@
M("`@*B!-151!4B!+4$E4(#`Y,3DU-5H@0T]2(#(R,#$U1S(U2U0@,R\T4TT@
M4C(X3"\R-C`P1E0@5%-202!/5D,P,3!#0@H@("`@("H@,3@O,38@03(Y.3(@
M4DU+(%-,4#`T-2!4,#$X,C`Q-3D*("`@("`J"B`@("`@*B!`<&%R86T@("!A
M<G)A>2`@("`@("`@("`@("`@("`@("`@("`@)&1A=&$*("`@("`J($!R971U
M<FX@(%!%05)?17)R;W)\87)R87D*("`@("`J($!T:')O=W,@(%!%05)?17)R
M;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?5U)/3D=?4T525D527T1!5$$*
M("`@("`J($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?
M15)23U)?54Y+3D]73E],3T-!5$E/3@H@("`@("H@0&%C8V5S<R`@<')I=F%T
M90H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5796%T:&5R1&%T82@D9&%T
M82D*("`@('L*("`@("`@("!S=&%T:6,@)&-O;7!A<W,["B`@("`@("`@<W1A
M=&EC("1C;&]U9',["B`@("`@("`@<W1A=&EC("1C;VYD:71I;VYS.PH@("`@
M("`@('-T871I8R`D<V5N<V]R<SL*("`@("`@("!I9B`H(6ES<V5T*"1C;VUP
M87-S*2D@>PH@("`@("`@("`@("`D8V]M<&%S<R`](&%R<F%Y*`H@("`@("`@
M("`@("`@("`@(DXB+"`B3DY%(BP@(DY%(BP@(D5.12(L"B`@("`@("`@("`@
M("`@("`B12(L(")%4T4B+"`B4T4B+"`B4U-%(BP*("`@("`@("`@("`@("`@
M(")3(BP@(E-35R(L(")35R(L(")74U<B+`H@("`@("`@("`@("`@("`@(E<B
M+"`B5TY7(BP@(DY7(BP@(DY.5R(*("`@("`@("`@("`@*3L*("`@("`@("`@
M("`@)&-L;W5D<R`@("`](&%R<F%Y*`H@("`@("`@("`@("`@("`@(G-K8R(@
M("`@("`@("`]/B`B<VMY(&-L96%R(BP*("`@("`@("`@("`@("`@(")N<V,B
M("`@("`@("`@/3X@(FYO('-I9VYI9FEC86YT(&-L;W5D(BP*("`@("`@("`@
M("`@("`@(")F97<B("`@("`@("`@/3X@(F9E=R(L"B`@("`@("`@("`@("`@
M("`B<V-T(B`@("`@("`@(#T^(")S8V%T=&5R960B+`H@("`@("`@("`@("`@
M("`@(F)K;B(@("`@("`@("`]/B`B8G)O:V5N(BP*("`@("`@("`@("`@("`@
M(")O=F,B("`@("`@("`@/3X@(F]V97)C87-T(BP*("`@("`@("`@("`@("`@
M(")V=B(@("`@("`@("`@/3X@(G9E<G1I8V%L('9I<VEB:6QI='DB+`H@("`@
M("`@("`@("`@("`@(G1C=2(@("`@("`@("`]/B`B5&]W97)I;F<@0W5M=6QU
M<R(L"B`@("`@("`@("`@("`@("`B8V(B("`@("`@("`@(#T^(")#=6UU;&]N
M:6UB=7,B+`H@("`@("`@("`@("`@("`@(F-L<B(@("`@("`@("`]/B`B8VQE
M87(@8F5L;W<@,3(L,#`P(&9T(@H@("`@("`@("`@("`I.PH@("`@("`@("`@
M("`D8V]N9&ET:6]N<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@(BLB("`@
M("`@("`@("`]/B`B:&5A=GDB+"`@("`@("`@(BTB("`@("`@("`@("`]/B`B
M;&EG:'0B+`H*("`@("`@("`@("`@("`@(")V8R(@("`@("`@("`@/3X@(G9I
M8VEN:71Y(BP@("`@(")R92(@("`@("`@("`@/3X@(G)E8V5N="(L"B`@("`@
M("`@("`@("`@("`B;G-W(B`@("`@("`@(#T^(")N;R!S:6=N:69I8V%N="!W
M96%T:&5R(BP*"B`@("`@("`@("`@("`@("`B;6DB("`@("`@("`@(#T^(")S
M:&%L;&]W(BP@("`@("`B8F,B("`@("`@("`@(#T^(")P871C:&5S(BP*("`@
M("`@("`@("`@("`@(")P<B(@("`@("`@("`@/3X@(G!A<G1I86PB+"`@("`@
M(")T<R(@("`@("`@("`@/3X@(G1H=6YD97)S=&]R;2(L"B`@("`@("`@("`@
M("`@("`B8FPB("`@("`@("`@(#T^(")B;&]W:6YG(BP@("`@("`B<V@B("`@
M("`@("`@(#T^(")S:&]W97)S(BP*("`@("`@("`@("`@("`@(")D<B(@("`@
M("`@("`@/3X@(FQO=R!D<FEF=&EN9R(L(")F>B(@("`@("`@("`@/3X@(F9R
M965Z:6YG(BP*"B`@("`@("`@("`@("`@("`B9'HB("`@("`@("`@(#T^(")D
M<FEZ>FQE(BP@("`@("`B<F$B("`@("`@("`@(#T^(")R86EN(BP*("`@("`@
M("`@("`@("`@(")S;B(@("`@("`@("`@/3X@(G-N;W<B+"`@("`@("`@(")S
M9R(@("`@("`@("`@/3X@(G-N;W<@9W)A:6YS(BP*("`@("`@("`@("`@("`@
M(")I8R(@("`@("`@("`@/3X@(FEC92!C<GES=&%L<R(L(")P92(@("`@("`@
M("`@/3X@(FEC92!P96QL971S(BP*("`@("`@("`@("`@("`@(")G<B(@("`@
M("`@("`@/3X@(FAA:6PB+"`@("`@("`@(")G<R(@("`@("`@("`@/3X@(G-M
M86QL(&AA:6PO<VYO=R!P96QL971S(BP*("`@("`@("`@("`@("`@(")U<"(@
M("`@("`@("`@/3X@(G5N:VYO=VX@<')E8VEP:71A=&EO;B(L"@H@("`@("`@
M("`@("`@("`@(F)R(B`@("`@("`@("`]/B`B;6ES="(L("`@("`@("`@(F9G
M(B`@("`@("`@("`]/B`B9F]G(BP*("`@("`@("`@("`@("`@(")F=2(@("`@
M("`@("`@/3X@(G-M;VME(BP@("`@("`@(")V82(@("`@("`@("`@/3X@(G9O
M;&-A;FEC(&%S:"(L"B`@("`@("`@("`@("`@("`B<V$B("`@("`@("`@(#T^
M(")S86YD(BP@("`@("`@("`B:'HB("`@("`@("`@(#T^(")H87IE(BP*("`@
M("`@("`@("`@("`@(")P>2(@("`@("`@("`@/3X@(G-P<F%Y(BP@("`@("`@
M(")D=2(@("`@("`@("`@/3X@(G=I9&5S<')E860@9'5S="(L"@H@("`@("`@
M("`@("`@("`@(G-Q(B`@("`@("`@("`]/B`B<W%U86QL(BP@("`@("`@(G-S
M(B`@("`@("`@("`]/B`B<V%N9'-T;W)M(BP*("`@("`@("`@("`@("`@(")D
M<R(@("`@("`@("`@/3X@(F1U<W1S=&]R;2(L("`@(")P;R(@("`@("`@("`@
M/3X@(G=E;&P@9&5V96QO<&5D(&1U<W0O<V%N9"!W:&ER;',B+`H@("`@("`@
M("`@("`@("`@(F9C(B`@("`@("`@("`]/B`B9G5N;F5L(&-L;W5D(BP*"B`@
M("`@("`@("`@("`@("`B*V9C(B`@("`@("`@(#T^(")T;W)N861O+W=A=&5R
M<W!O=70B"B`@("`@("`@("`@("D["B`@("`@("`@("`@("1S96YS;W)S(#T@
M87)R87DH"B`@("`@("`@("`@("`@("`B<G9R;F\B("`]/B`B4G5N=V%Y(%9I
M<W5A;"!286YG92!$971E8W1O<B!O9F9L:6YE(BP*("`@("`@("`@("`@("`@
M(")P=VEN;R(@(#T^(")0<F5S96YT(%=E871H97(@261E;G1I9FEE<B!O9F9L
M:6YE(BP*("`@("`@("`@("`@("`@(")P;F\B("`@(#T^(")4:7!P:6YG($)U
M8VME="!286EN($=A=6=E(&]F9FQI;F4B+`H@("`@("`@("`@("`@("`@(F9Z
M<F%N;R(@/3X@(D9R965Z:6YG(%)A:6X@4V5N<V]R(&]F9FQI;F4B+`H@("`@
M("`@("`@("`@("`@(G1S;F\B("`@/3X@(DQI9VAT;FEN9R!$971E8W1I;VX@
M4WES=&5M(&]F9FQI;F4B+`H@("`@("`@("`@("`@("`@(G9I<VYO(B`@/3X@
M(C)N9"!6:7-I8FEL:71Y(%-E;G-O<B!O9F9L:6YE(BP*("`@("`@("`@("`@
M("`@(")C:&EN;R(@(#T^("(R;F0@0V5I;&EN9R!(96EG:'0@26YD:6-A=&]R
M(&]F9FQI;F4B"B`@("`@("`@("`@("D["B`@("`@("`@?0H*("`@("`@("`D
M;65T87)#;V1E(#T@87)R87DH"B`@("`@("`@("`@(")R97!O<G0B("`@("`@
M/3X@(DU%5$%2?%-014-)(BP*("`@("`@("`@("`@(G-T871I;VXB("`@("`]
M/B`B7'=[-'TB+`H@("`@("`@("`@("`B=7!D871E(B`@("`@(#T^("(H7&1[
M,GTI/RA<9'LT?2E:(BP*("`@("`@("`@("`@(G1Y<&4B("`@("`@("`]/B`B
M05543WQ#3U(B+`H@("`@("`@("`@("`B=VEN9"(@("`@("`@(#T^("(H7&1[
M,WU\5D%2?%920BDH7&1[,BPS?2DH1RA<9'LR?2DI/RA<=WLR+#-]*2(L"B`@
M("`@("`@("`@(")W:6YD5F%R(B`@("`@/3X@(BA<9'LS?2E6*%QD>S-]*2(L
M"B`@("`@("`@("`@(")V:7-&<F%C(B`@("`@/3X@(BA<9'LQ?2DB+`H@("`@
M("`@("`@("`B=FES:6)I;&ET>2(@(#T^("(H7&1[-'TI?"@H37Q0*3\H*%QD
M>S$L,GU\*"A<9"D@*3\H7&0I7"\H7&0I*2A337Q+32DI*7PH0T%63TLI(BP*
M("`@("`@("`@("`@(G)U;G=A>2(@("`@("`]/B`B4BA<9'LR?2DH7'<I/UPO
M*%!\32D_*%QD>S1]*2A&5"D_*%8H4'Q-*3\H7&1[-'TI*$94*3\I/RA<=RD_
M(BP*("`@("`@("`@("`@(F-O;F1I=&EO;B(@("`]/B`B*"U\7"M\5D-\4D5\
M3E-7*3\H34E\0D-\4%)\5%-\0DQ\4TA\1%)\1EHI/R@H1%HI?"A202E\*%-.
M*7PH4T<I?"A)0RE\*%!,*7PH1U(I?"A'4RE\*%50*2DJ*$)2?$9'?$95?%9!
M?$15?%-!?$A:?%!9*3\H4$]\4U%\1D-\4U-\1%,I/R(L"B`@("`@("`@("`@
M(")C;&]U9',B("`@("`@/3X@(BA32T-\0TQ2?$Y30WPH*$9%5WQ30U1\0DM.
M?$]60WQ65BDH7&1[,WTI*%1#57Q#0BD_*2DB+`H@("`@("`@("`@("`B=&5M
M<&5R871U<F4B(#T^("(H32D_*%QD>S)]*5PO*"A-*3\H7&1[,GTI?%A8?%PO
M7"\I/R(L"B`@("`@("`@("`@(")P<F5S<W5R92(@("`@/3X@(BA!*2A<9'LT
M?2E\*%$I*%QD>S1]*2(L"B`@("`@("`@("`@(")T<F5N9"(@("`@("`@/3X@
M(DY/4TE'?%1%35!/?$)%0TU'(BP*("`@("`@("`@("`@(G)E;6%R:R(@("`@
M("`]/B`B4DU+(@H@("`@("`@("D["@H@("`@("`@("1R96UA<FMS(#T@87)R
M87DH"B`@("`@("`@("`@(")N;W-P96-I(B`@("`@/3X@(DY/4U!%0TDB+`H@
M("`@("`@("`@("`B875T;W-T871I;VXB(#T^(")!3R@Q?#(I(BP*("`@("`@
M("`@("`@(G!R97-S8VAG(B`@("`]/B`B4%)%4RA2?$8I4B(L"B`@("`@("`@
M("`@(")S96%P<F5S<W5R92(@/3X@(E-,4"A<9'LS?7Q.3RDB+`H@("`@("`@
M("`@("`B<')E8VEP(B`@("`@(#T^("(H4'PV?#<I*%QD>S1]?%PO>S1]*2(L
M"B`@("`@("`@("`@(")S;F]W9&5P=&@B("`@/3X@(C1<+RA<9'LS?2DB+`H@
M("`@("`@("`@("`B<VYO=V5Q=6EV(B`@(#T^("(Y,S,H7&1[,WTI(BP*("`@
M("`@("`@("`@(F-L;W5D='EP97,B("`]/B`B.%PO*%QD?%PO*2A<9'Q<+RDH
M7&1\7"\I(BP*("`@("`@("`@("`@(G-U;F1U<F%T:6]N(B`]/B`B.3@H7&1[
M,WTI(BP*("`@("`@("`@("`@(C%H=&5M<&1E=R(@("`]/B`B5"@P?#$I*%QD
M>S-]*2@H,'PQ*2A<9'LS?2DI/R(L"B`@("`@("`@("`@("(V:&UA>'1E;7`B
M("`@/3X@(C$H,'PQ*2A<9'LS?2DB+`H@("`@("`@("`@("`B-FAM:6YT96UP
M(B`@(#T^("(R*#!\,2DH7&1[,WTI(BP*("`@("`@("`@("`@(C(T:'1E;7`B
M("`@("`]/B`B-"@P?#$I*%QD>S-]*2@P?#$I*%QD>S-]*2(L"B`@("`@("`@
M("`@("(S:'!R97-S=&5N9"(@/3X@(C4H6S`M.%TI*%QD>S-]*2(L"B`@("`@
M("`@("`@(")S96YS;W)S(B`@("`@/3X@(E)64DY/?%!724Y/?%!.3WQ&6E)!
M3D]\5%-.3WQ625-.3WQ#2$E.3R(L"B`@("`@("`@("`@(")M86EN=&%I;B(@
M("`@/3X@(EM<)%TB"B`@("`@("`@*3L*"B`@("`@("`@:68@*%-%4E9)0T53
M7U=%051(15)?1$5"54<I('L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I
M(#P@<VEZ96]F*"1D871A*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@96-H
M;R`D9&%T85LD:5T["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M+R\@4W1A<G0@=VET:"!P87)S:6YG('1H92!F:7)S="!L:6YE(&9O<B!T:&4@
M;&%S="!U<&1A=&4*("`@("`@("`D=V5A=&AE<D1A=&$@/2!A<G)A>2@I.PH@
M("`@("`@("1W96%T:&5R1&%T85LB<W1A=&EO;B)=("`@/2`B(CL*("`@("`@
M("`D=V5A=&AE<D1A=&%;(F1A=&%287<B72`@(#T@:6UP;&]D92@B("(L("1D
M871A*3L*("`@("`@("`D=V5A=&AE<D1A=&%;(G5P9&%T92)=("`@(#T@<W1R
M=&]T:6UE*'1R:6TH)&1A=&%;,%TI+B(@1TU4(BD["B`@("`@("`@)'=E871H
M97)$871A6R)U<&1A=&5287<B72`]('1R:6TH)&1A=&%;,%TI.PH@("`@("`@
M("\O(&%N9"!P<F5P87)E('1H92!R97-T(&9O<B!S=&5P<&EN9R!T:')O=6=H
M"B`@("`@("`@87)R87E?<VAI9G0H)&1A=&$I.PH@("`@("`@("1M971A<B`]
M(&5X<&QO9&4H(B`B+"!P<F5G7W)E<&QA8V4H(B]<<WLR+'TO(BP@(B`B+"!I
M;7!L;V1E*"(@(BP@)&1A=&$I*2D["@H@("`@("`@("\O($%D9"!A(&9E=R!L
M;V-A;"!V87)I86)L97,@9F]R(&1A=&$@<')O8V5S<VEN9PH@("`@("`@("1T
M<F5N9$-O=6YT(#T@,#L@("`@("`@("`@("`@+R\@268@=V4@:&%V92!T<F5N
M9',L('=E(&YE960@=&AI<PH@("`@("`@("1P;VEN=&5R("`@(#TF("1W96%T
M:&5R1&%T83L@+R\@4&]I;G1E<B!T;R!T:&4@87)R87D@=V4@861D('1H92!D
M871A('1O"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1M971A
M<BD[("1I*RLI('L*("`@("`@("`@("`@+R\@0VAE8VL@9F]R('=H:71E<W!A
M8V4@86YD('-T97`@;&]O<"P@:68@;F]T:&EN9R=S('1H97)E"B`@("`@("`@
M("`@("1M971A<ELD:5T@/2!T<FEM*"1M971A<ELD:5TI.PH@("`@("`@("`@
M("!I9B`H(7-T<FQE;B@D;65T87);)&E=*2D@>PH@("`@("`@("`@("`@("`@
M8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("A315)6
M24-%4U]714%42$527T1%0E5'*2!["B`@("`@("`@("`@("`@("`D=&%B(#T@
M<W1R7W)E<&5A="@B7'0B+"`R("T@9FQO;W(H*'-T<FQE;B@D;65T87);)&E=
M*2`K(#(I("\@."DI.PH@("`@("`@("`@("`@("`@96-H;R`B7"(B+B1M971A
M<ELD:5TN(EPB(BXD=&%B+B(M/B`B.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`O+R!);FET:6%L:7IE('-O;64@87)R87ES"B`@("`@("`@("`@("1R
M97-U;'0@("`](&%R<F%Y*"D["B`@("`@("`@("`@("1R97-U;'161B`](&%R
M<F%Y*"D["B`@("`@("`@("`@("1L<F5S=6QT("`](&%R<F%Y*"D["@H@("`@
M("`@("`@("`D9F]U;F0@/2!F86QS93L*("`@("`@("`@("`@9F]R96%C:"`H
M)&UE=&%R0V]D92!A<R`D:V5Y(#T^("1R96=E>'`I('L*("`@("`@("`@("`@
M("`@("\O($-H96-K(&EF(&-U<G)E;G0@8V]D92!M871C:&5S(&-U<G)E;G0@
M;65T87(@<VYI<'!E=`H@("`@("`@("`@("`@("`@:68@*"@D9F]U;F0@/2!P
M<F5G7VUA=&-H*"(O7B(N)')E9V5X<"XB)"]I(BP@)&UE=&%R6R1I72P@)')E
M<W5L="DI(#T]('1R=64I('L*("`@("`@("`@("`@("`@("`@("!S=VET8V@@
M*"1K97DI('L*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B<W1A=&EO
M;B(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB<W1A
M=&EO;B)=(#T@)')E<W5L=%LP73L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('5N<V5T*"1M971A<D-O9&5;(G-T871I;VXB72D["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@
M("`@8V%S92`B=VEN9"(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!087)S92!W:6YD(&1A=&$L(&9I<G-T('1H92!S<&5E9"P@8V]N=F5R="!F
M<F]M(&MT('1O(&-H;W-E;B!U;FET"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&]I;G1E<ELB=VEN9")=(#T@)'1H:7,M/F-O;G9E<G13<&5E9"@D
M<F5S=6QT6S)=+"!S=')T;VQO=V5R*"1R97-U;'1;-5TI+"`B;7!H(BD["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)')E<W5L=%LQ72`]/2`B
M5D%2(B!\?"`D<F5S=6QT6S%=(#T](")64D(B*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@5F%R:6%B;&4@=VEN9',*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB=VEN9$1E9W)E97,B
M72`@(#T@(E9A<FEA8FQE(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&]I;G1E<ELB=VEN9$1I<F5C=&EO;B)=(#T@(E9A<FEA8FQE(CL*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@4V%V92!W:6YD(&1E9W)E92!A
M;F0@8V%L8R!D:7)E8W1I;VX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&]I;G1E<ELB=VEN9$1E9W)E97,B72`@(#T@:6YT=F%L*"1R97-U
M;'1;,5TI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN
M=&5R6R)W:6YD1&ER96-T:6]N(ET@/2`D8V]M<&%S<UMR;W5N9"@D<F5S=6QT
M6S%=("\@,C(N-2D@)2`Q-ET["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-?;G5M97)I
M8R@D<F5S=6QT6S1=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("\O(%=I;F0@=VET:"!G=7-T<RXN+@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P;VEN=&5R6R)W:6YD1W5S=")=(#T@)'1H:7,M/F-O
M;G9E<G13<&5E9"@D<F5S=6QT6S1=+"!S=')T;VQO=V5R*"1R97-U;'1;-5TI
M+"`B;7!H(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M("`@("`@("`@8V%S92`B=VEN9%9A<B(Z"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!/;F-E(&UO<F4@=VEN9"P@;F]W('9A<FEA8FEL:71Y(&%R
M;W5N9"!T:&4@8W5R<F5N="!W:6YD+61I<F5C=&EO;@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'!O:6YT97);(G=I;F1687)I86)I;&ET>2)=(#T@
M87)R87DH(F9R;VTB(#T^(&EN='9A;"@D<F5S=6QT6S%=*2P@(G1O(B`]/B!I
M;G1V86PH)')E<W5L=%LR72DI.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(G9I<T9R
M86,B.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@4&]S<VEB;&4@
M9G)A8W1I;VYA;"!V:7-I8FEL:71Y(&AE<F4N($-H96-K(&EF(&ET(&UA=&-H
M97,@=VET:"!T:&4@;F5X="!-151!4B!P:65C92!F;W(@=FES:6)I;&ET>0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;65T87);
M)&D@*R`Q72D@?'P@(7!R96=?;6%T8V@H(B]>(BXD;65T87)#;V1E6R)V:7-I
M8FEL:71Y(ETN(B0O:2(L("1R97-U;'1;,5TN(B`B+B1M971A<ELD:2`K(#%=
M+"`D<F5S=6QT5D8I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@3F\@;F5X="!-151!4B!P:65C92!A=F%I;&%B;&4@;W(@;F]T(&UA
M=&-H:6YG+B!-871C:"!A9V%I;G-T(&YE>'0@345405(@8V]D90H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1F;W5N9"`](&9A;'-E.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!-871C:"X@2&%N9"!O=F5R(')E<W5L="!A;F0@
M861V86YC92!-151!4@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("A315)624-%4U]714%42$527T1%0E5'*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&5C:&\@)&ME>2XB7&XB.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!E8VAO(")<(B(N)')E<W5L
M=%LQ72XB("(N)&UE=&%R6R1I("L@,5TN(EPB(BYS=')?<F5P96%T*")<="(L
M(#(@+2!F;&]O<B@H<W1R;&5N*"1R97-U;'1;,5TN(B`B+B1M971A<ELD:2`K
M(#%=*2`K(#(I("\@."DI+B(M/B`B.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M:V5Y(#T@(G9I<VEB:6QI='DB.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1R97-U;'0@/2`D<F5S=6QT5D8["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&DK*SL*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B=FES:6)I;&ET
M>2(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB=FES
M475A;&EF:65R(ET@/2`B050B.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*&ES7VYU;65R:6,H)')E<W5L=%LQ72D@)B8@*"1R97-U;'1;,5T@
M/3T@.3DY.2DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!5<'!E<B!L:6UI="!O9B!V:7-I8FEL:71Y(')A;F=E"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'9I<VEB:6QI='D@/2`D=&AI<RT^8V]N
M=F5R=$1I<W1A;F-E*#$P+"`B:VTB+"`B<VTB*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB=FES475A;&EF:65R(ET@/2`B
M0D593TY$(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF
M("AI<U]N=6UE<FEC*"1R97-U;'1;,5TI*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@-"UD:6=I="!V:7-I8FEL:71Y(&EN(&T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=FES:6)I;&ET>2`]("1T
M:&ES+3YC;VYV97)T1&ES=&%N8V4H*"1R97-U;'1;,5TO,3`P,"DL(")K;2(L
M(")S;2(I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*"%I<W-E="@D<F5S=6QT6S$Q72D@?'P@)')E<W5L=%LQ,5T@(3T@(D-!5D]+
M(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D<F5S
M=6QT6S-=(#T](")-(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&]I;G1E<ELB=FES475A;&EF:65R(ET@/2`B0D5,3U<B.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D<F5S
M=6QT6S-=(#T](")0(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&]I;G1E<ELB=FES475A;&EF:65R(ET@/2`B0D593TY$(CL*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES7VYU;65R:6,H)')E<W5L=%LU
M72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M=FES:6)I;&ET>2!A<R!O;F4O='=O+61I9VET(&YU;6)E<@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=FES:6)I;&ET>2`]("1T:&ES
M+3YC;VYV97)T1&ES=&%N8V4H)')E<W5L=%LU72P@)')E<W5L=%LQ,%TL(")S
M;2(I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O('1H92!Y
M+WH@<&%R="P@861D(&EF('=E(&AA9"!A('@@<&%R="`H<V5E('9I<VEB:6QI
M='DQ*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-?;G5M97)I8R@D<F5S=6QT6S==*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'9I<VEB:6QI='D@/2`D=&AI<RT^8V]N
M=F5R=$1I<W1A;F-E*"1R97-U;'1;-UT@*R`D<F5S=6QT6SA=("\@)')E<W5L
M=%LY72P@)')E<W5L=%LQ,%TL(")S;2(I.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'9I<VEB:6QI='D@/2`D=&AI<RT^8V]N
M=F5R=$1I<W1A;F-E*"1R97-U;'1;.%T@+R`D<F5S=6QT6SE=+"`D<F5S=6QT
M6S$P72P@(G-M(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)V:7-1=6%L:69I97(B72`]
M(")"15E/3D0B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V
M:7-I8FEL:71Y(#T@)'1H:7,M/F-O;G9E<G1$:7-T86YC92@Q,"P@(FMM(BP@
M(G-M(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT
M97);(F-L;W5D<R)=(#T@87)R87DH87)R87DH(F%M;W5N="(@/3X@(D-L96%R
M(&)E;&]W(BP@(FAE:6=H="(@/3X@-3`P,"DI.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P;VEN=&5R6R)C;VYD:71I;VXB72`](")N;R!S
M:6=N:69I8V%N="!W96%T:&5R(CL*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)V
M:7-I8FEL:71Y(ET@/2`D=FES:6)I;&ET>3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E
M(")C;VYD:71I;VXB.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M1FER<W0@<V]M92!B87-I8R!S971U<',*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)'!O:6YT97);(F-O;F1I=&EO;B)=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)C;VYD
M:71I;VXB72`]("(B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E:68@*'-T<FQE;B@D<&]I;G1E<ELB8V]N9&ET:6]N(ETI(#X@,"D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)C;VYD
M:71I;VXB72`N/2`B+"(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&EN7V%R<F%Y*'-T
M<G1O;&]W97(H)')E<W5L=%LP72DL("1C;VYD:71I;VYS*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("\O($9I<G-T('1R>2!M871C:&EN
M9R!T:&4@8V]M<&QE=&4@<W1R:6YG"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!O:6YT97);(F-O;F1I=&EO;B)=("X]("(@(BXD8V]N9&ET
M:6]N<UMS=')T;VQO=V5R*"1R97-U;'1;,%TI73L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@3F\@;'5C:RP@;6%T8V@@<&%R="!B>2!P87)T"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?<VAI9G0H)')E<W5L
M="D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<W5L="`]
M(&%R<F%Y7W5N:7%U92@D<F5S=6QT*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D<F5S=6QT(&%S("1C;VYD:71I;VXI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*'-T<FQE
M;B@D8V]N9&ET:6]N*2`^(#`I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P;VEN=&5R6R)C;VYD:71I;VXB72`N/2`B("(N
M)&-O;F1I=&EO;G-;<W1R=&]L;W=E<B@D8V]N9&ET:6]N*5T["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB8V]N
M9&ET:6]N(ET@/2!T<FEM*"1P;VEN=&5R6R)C;VYD:71I;VXB72D["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M("`@("`@("`@8V%S92`B8VQO=61S(CH*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)'!O:6YT97);(F-L;W5D<R)=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)C;&]U9',B
M72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*'-I>F5O9B@D<F5S=6QT
M*2`]/2`U*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M3VYL>2!A;6]U;G0@86YD(&AE:6=H=`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1C;&]U9"`](&%R<F%Y*")A;6]U;G0B(#T^("1C;&]U9'-;
M<W1R=&]L;W=E<B@D<F5S=6QT6S-=*5TL(")H96EG:'0B(#T^("@D<F5S=6QT
M6S1=*C$P,"DI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@96QS96EF("AS:7IE;V8H)')E<W5L
M="D@/3T@-BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O
M($%M;W5N="P@:&5I9VAT(&%N9"!T>7!E"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&-L;W5D(#T@87)R87DH(F%M;W5N="(@/3X@)&-L;W5D
M<UMS=')T;VQO=V5R*"1R97-U;'1;,UTI72P@(FAE:6=H="(@/3X@*"1R97-U
M;'1;-%TJ,3`P*2P@(G1Y<&4B(#T^("1C;&]U9'-;<W1R=&]L;W=E<B@D<F5S
M=6QT6S5=*5TI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@4TM#(&]R($-,4B!O<B!.4T,*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D8VQO=60@/2!A<G)A>2@B86UO
M=6YT(B`]/B`D8VQO=61S6W-T<G1O;&]W97(H)')E<W5L=%LP72E=*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P;VEN=&5R6R)C;&]U9',B75M=(#T@)&-L;W5D.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("`@("`@("`@(&-A<V4@(G1E;7!E<F%T=7)E(CH*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O(&YO<FUA;"!T96UP97)A='5R92!I;B!F:7)S="!P
M87)T"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!N96=A=&EV92!V
M86QU90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1R97-U;'1;
M,5T@/3T@(DTB*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)')E<W5L=%LR72`J/2`M,3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)T96UP
M97)A='5R92)=(#T@)'1H:7,M/F-O;G9E<G1496UP97)A='5R92@D<F5S=6QT
M6S)=+"`B8R(L(")F(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H<VEZ96]F*"1R97-U;'0I(#X@-"D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O('-A;64@9F]R(&1E=W!O:6YT"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"1R97-U;'1;-%T@/3T@(DTB*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97-U;'1;
M-5T@*CT@+3$["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)D97=0
M;VEN=")=(#T@)'1H:7,M/F-O;G9E<G1496UP97)A='5R92@D<F5S=6QT6S5=
M+"`B8R(L(")F(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!O:6YT97);(FAU;6ED:71Y(ET@/2`D=&AI<RT^8V%L8W5L871E2'5M:61I
M='DH)')E<W5L=%LR72P@)')E<W5L=%LU72D["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)'!O:6YT97);(G=I;F0B72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!.;W<@8V%L8W5L871E('=I;F1C:&EL;"!F<F]M
M('1E;7!E<F%T=7)E(&%N9"!W:6YD<W!E960*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<&]I;G1E<ELB9F5L=%1E;7!E<F%T=7)E(ET@/2`D
M=&AI<RT^8V%L8W5L871E5VEN9$-H:6QL*"1P;VEN=&5R6R)T96UP97)A='5R
M92)=+"`D<&]I;G1E<ELB=VEN9")=*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@("`@("`@("!C87-E(")P<F5S<W5R92(Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H)')E<W5L=%LQ72`]/2`B02(I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!0<F5S<W5R
M92!P<F]V:61E9"!I;B!I;F-H97,*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&]I;G1E<ELB<')E<W-U<F4B72`]("1R97-U;'1;,ET@+R`Q
M,#`["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)')E
M<W5L=%LS72`]/2`B42(I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`O+R`N+BX@:6X@:&5C=&]P87-C86P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<&]I;G1E<ELB<')E<W-U<F4B72`]("1T:&ES+3YC
M;VYV97)T4')E<W-U<F4H)')E<W5L=%LT72P@(FAP82(L(")I;B(I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@
M(G1R96YD(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(%=E(&UA
M>2!H879E(&$@=')E;F0@:&5R92XN+B!E>'1R86-T('1Y<&4@86YD('-E="!P
M;VEN=&5R(&]N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!C<F5A
M=&5D(&YE=R!A<G)A>0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D=V5A=&AE<D1A=&%;(G1R96YD(ETI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$871A6R)T<F5N9")=(#T@
M87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A
M=&AE<D1A=&%;(G1R96YD(EU;)'1R96YD0V]U;G1=(#T@87)R87DH*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P;VEN=&5R(#TF("1W96%T:&5R1&%T85LB=')E;F0B75LD
M=')E;F1#;W5N=%T["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=')E
M;F1#;W5N="LK.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT
M97);(G1Y<&4B72`]("1R97-U;'1;,%T["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!W:&EL92`H:7-S970H)&UE=&%R6R1I("L@,5TI("8F('!R96=?
M;6%T8V@H(B]>*$9-?%1,?$%4*2A<9'LR?2DH7&1[,GTI)"]I(BP@)&UE=&%R
M6R1I("L@,5TL("1L<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@D;')E<W5L=%LQ72`]/2`B1DTB*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)F<F]M(ET@
M/2`D;')E<W5L=%LR72XB.B(N)&QR97-U;'1;,UT["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1L<F5S=6QT6S%=(#T](")4
M3"(I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O
M:6YT97);(G1O(ET@/2`D;')E<W5L=%LR72XB.B(N)&QR97-U;'1;,UT["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(F%T(ET@
M/2`D;')E<W5L=%LR72XB.B(N)&QR97-U;'1;,UT["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("\O($%S('=E(&AA=F4@:G5S="!E>'1R86-T960@=&AE('1I;64@
M9F]R('1H:7,@=')E;F0*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!F<F]M(&]U<B!-151!4BP@:6YC<F5A<V4@9FEE;&0M8V]U;G1E<@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B<F5M
M87)K(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(%)E;6%R:R!P
M87)T(&)E9VEN<PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&UE=&%R
M0V]D92`]("1R96UA<FMS.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'=E871H97)$871A6R)R96UA<FLB72`](&%R<F%Y*"D["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@
M("`@8V%S92`B875T;W-T871I;VXB.@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@5VAI8V@@875T;W-T871I;VX@9&\@=V4@:&%V92!H97)E/PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1R97-U;'1;,5T@/3T@
M,"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R
M1&%T85LB<F5M87)K(EU;(F%U=&]S=&%T:6]N(ET@/2`B075T;VUA=&EC('=E
M871H97)S=&%T:6]N('<O;R!P<F5C:7!I=&%T:6]N(&1I<V-R:6UI;F%T;W(B
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G)E;6%R
M:R)=6R)A=71O<W1A=&EO;B)=(#T@(D%U=&]M871I8R!W96%T:&5R<W1A=&EO
M;B!W+R!P<F5C:7!I=&%T:6]N(&1I<V-R:6UI;F%T;W(B.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@=6YS970H)&UE=&%R0V]D95LB875T;W-T871I;VXB72D["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@
M("`@("`@8V%S92`B<')E<W-C:&<B.@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@1&5C;V1I;F<@9F]R(')A<&ED('!R97-S=7)E(&-H86YG97,*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AS=')T;VQO=V5R*"1R
M97-U;'1;,5TI(#T](")R(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1W96%T:&5R1&%T85LB<F5M87)K(EU;(G!R97-S8VAG(ET@/2`B
M4')E<W-U<F4@<FES:6YG(')A<&ED;'DB.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=V5A=&AE<D1A=&%;(G)E;6%R:R)=6R)P<F5S<V-H9R)=(#T@(E!R
M97-S=7)E(&9A;&QI;F<@<F%P:61L>2(["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D
M;65T87)#;V1E6R)P<F5S<V-H9R)=*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")S
M96%P<F5S<W5R92(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!0
M<F5S<W5R92!A="!S96$@;&5V96P@*&1E;&EV97)E9"!I;B!H<&$I"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!$96-O9&EN9R!I<R!A(&)I="!O
M8G-C=7)E(&%S(#DX,B!G971S(#DY."XR"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!W:&5R96%S(#$Q,R!B96-O;65S(#$Q,3,@+3X@;F\@<F5A
M;"!R=6QE(&AE<F4*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AS
M=')T;VQO=V5R*"1R97-U;'1;,5TI("$](")N;R(I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H)')E<W5L=%LQ72`^(#4P,"D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<')E<W,@/2`Y
M,#`@*R!R;W5N9"@D<F5S=6QT6S%=("\@,3`P+"`Q*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<')E<W,@/2`Q,#`P("L@)')E<W5L=%LQ
M73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$871A6R)R96UA<FLB
M75LB<V5A<')E<W-U<F4B72`]("1T:&ES+3YC;VYV97)T4')E<W-U<F4H)'!R
M97-S+"`B:'!A(BP@(FEN(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D;65T87)#
M;V1E6R)S96%P<F5S<W5R92)=*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")P<F5C
M:7`B.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@4')E8VEP:71A
M=&EO;B!I;B!I;F-H97,*("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T
M871I8R`D:&]U<G,["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1W96%T:&5R1&%T85LB<')E8VEP:71A=&EO;B)=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R1&%T85LB<')E
M8VEP:71A=&EO;B)=(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D:&]U<G,@/2!A<G)A>2@B4"(@/3X@(C$B+"`B-B(@/3X@
M(C,O-B(L("(W(B`]/B`B,C0B*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?;G5M
M97)I8R@D<F5S=6QT6S)=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P<F5C:7`@/2`B:6YD971E<FUI;F%B;&4B.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1R97-U;'1;,ET@/3T@(C`P
M,#`B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!R96-I
M<"`](")T<F%C96%B;&4B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?65L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<F5C
M:7`@/2`D<F5S=6QT6S)=("\@,3`P.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$
M871A6R)P<F5C:7!I=&%T:6]N(EU;72`](&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(")A;6]U;G0B(#T^("1P<F5C:7`L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(FAO=7)S(B`@/3X@)&AO=7)S
M6R1R97-U;'1;,5U="B`@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("`@("`@("`@(&-A<V4@(G-N;W=D97!T:"(Z"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!3;F]W(&1E<'1H(&EN(&EN8VAE<PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$871A6R)R96UA<FLB75LB
M<VYO=V1E<'1H(ET@/2`D<F5S=6QT6S%=.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@=6YS970H)&UE=&%R0V]D95LB<VYO=V1E<'1H(ETI.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("`@("`@("`@(&-A<V4@(G-N;W=E<75I=B(Z"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!386UE(&9O<B!E<75I=F%L96YT(&EN(%=A=&5R+BXN
M("AI;F-H97,I"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE
M<D1A=&%;(G)E;6%R:R)=6R)S;F]W97%U:78B72`]("1R97-U;'1;,5T@+R`Q
M,#L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1M971A<D-O
M9&5;(G-N;W=E<75I=B)=*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")C;&]U9'1Y
M<&5S(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($-L;W5D('1Y
M<&5S+"!H879E;B=T(&9O=6YD(&$@=V%Y(&9O<B!D96-E;G0@9&5C;V1I;F<@
M*'EE="D*("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1M971A
M<D-O9&5;(F-L;W5D='EP97,B72D["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B<W5N
M9'5R871I;VXB.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@1'5R
M871I;VX@;V8@<W5N<VAI;F4@*&EN(&UI;G5T97,I"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G)E;6%R:R)=6R)S=6YD=7)A
M=&EO;B)=(#T@(E1O=&%L(&UI;G5T97,@;V8@<W5N<VAI;F4Z("(N)')E<W5L
M=%LQ73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1M971A
M<D-O9&5;(G-U;F1U<F%T:6]N(ETI.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(C%H
M=&5M<&1E=R(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!496UP
M97)A='5R97,@:6X@=&AE(&QA<W0@:&]U<B!I;B!#"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H)')E<W5L=%LQ72`]/2`B,2(I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5S=6QT6S)=("H]("TQ.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'=E871H97)$871A6R)R96UA<FLB75LB,6AT96UP(ET@
M/2`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E*"1R97-U;'1;,ET@+R`Q,"P@
M(F,B+"`B9B(I.PH*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AS
M:7IE;V8H)')E<W5L="D@/B`S*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@<V%M92!F;W(@9&5W<&]I;G0*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)')E<W5L=%LT72`]/2`B,2(I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<W5L=%LU72`J
M/2`M,3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$871A6R)R96UA
M<FLB75LB,6AD97<B72`]("1T:&ES+3YC;VYV97)T5&5M<&5R871U<F4H)')E
M<W5L=%LU72`O(#$P+"`B8R(L(")F(BD["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D
M;65T87)#;V1E6R(Q:'1E;7!D97<B72D["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B
M-FAM87AT96UP(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($UA
M>"!T96UP97)A='5R92!I;B!T:&4@;&%S="`V(&AO=7)S(&EN($,*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT6S%=(#T]("(Q(BD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97-U;'1;,ET@
M*CT@+3$["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G)E;6%R:R)=6R(V
M:&UA>'1E;7`B72`]("1T:&ES+3YC;VYV97)T5&5M<&5R871U<F4H)')E<W5L
M=%LR72`O(#$P+"`B8R(L(")F(BD["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!U;G-E="@D;65T87)#;V1E6R(V:&UA>'1E;7`B72D["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@
M("`@("`@8V%S92`B-FAM:6YT96UP(CH*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("\O($UI;B!T96UP97)A='5R92!I;B!T:&4@;&%S="`V(&AO=7)S
M(&EN($,*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT
M6S%=(#T]("(Q(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1R97-U;'1;,ET@*CT@+3$["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;
M(G)E;6%R:R)=6R(V:&UI;G1E;7`B72`]("1T:&ES+3YC;VYV97)T5&5M<&5R
M871U<F4H)')E<W5L=%LR72`O(#$P+"`B8R(L(")F(BD["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!U;G-E="@D;65T87)#;V1E6R(V:&UI;G1E;7`B
M72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@("`@("`@("`@8V%S92`B,C1H=&5M<"(Z"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`O+R!-87@O36EN('1E;7!E<F%T=7)E<R!I;B!T
M:&4@;&%S="`R-"!H;W5R<R!I;B!#"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H)')E<W5L=%LQ72`]/2`B,2(I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<F5S=6QT6S)=("H]("TQ.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'=E871H97)$871A6R)R96UA<FLB75LB,C1H;6%X=&5M<")=(#T@)'1H
M:7,M/F-O;G9E<G1496UP97)A='5R92@D<F5S=6QT6S)=("\@,3`L(")C(BP@
M(F8B*3L*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)')E<W5L
M=%LS72`]/2`B,2(I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<F5S=6QT6S1=("H]("TQ.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$871A
M6R)R96UA<FLB75LB,C1H;6EN=&5M<")=(#T@)'1H:7,M/F-O;G9E<G1496UP
M97)A='5R92@D<F5S=6QT6S1=("\@,3`L(")C(BP@(F8B*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('5N<V5T*"1M971A<D-O9&5;(C(T:'1E;7`B
M72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@("`@("`@("`@8V%S92`B,VAP<F5S<W1E;F0B.@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@5V4@9&]N)W0@<V%V92!T:&4@<')E
M<W-U<F4@9'5R:6YG('1H92!D87DL('-O(&YO(&1E8V]D:6YG"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!P;W-S:6)L92P@<V]R<GD*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1M971A<D-O9&5;(C-H<')E
M<W-T96YD(ETI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(FYO<W!E8VDB.@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@3F\@8VAA;F=E(&1U<FEN9R!T
M:&4@;&%S="!H;W5R"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A
M=&AE<D1A=&%;(G)E;6%R:R)=6R)N;W-P96-I(ET@/2`B3F\@8VAA;F=E<R!I
M;B!W96%T:&5R(&-O;F1I=&EO;G,B.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=6YS970H)&UE=&%R0V]D95LB;F]S<&5C:2)=*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@
M("`@("!C87-E(")S96YS;W)S(CH*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("\O(%=E(&UA>2!H879E(&UU;'1I<&QE(&)R;VME;B!S96YS;W)S+"!S
M;R!D;R!N;W0@=6YS970*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)'=E871H97)$871A6R)R96UA<FLB75LB<V5N<V]R<R)=*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R1&%T
M85LB<F5M87)K(EU;(G-E;G-O<G,B72`](&%R<F%Y*"D["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=V5A=&AE<D1A=&%;(G)E;6%R:R)=6R)S96YS;W)S(EU;<W1R=&]L;W=E
M<B@D<F5S=6QT6S!=*5T@/2`D<V5N<V]R<UMS=')T;VQO=V5R*"1R97-U;'1;
M,%TI73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@("`@("!C87-E(")M86EN=&%I;B(Z"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G)E;6%R:R)=6R)M
M86EN=&%I;B)=(#T@(DUA:6YT86EN86YC92!N965D960B.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=6YS970H)&UE=&%R0V]D95LB;6%I;G1A:6XB
M72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("\O($1O(&YO=&AI;F<L(&IU<W0@<')E=F5N="!F=7)T:&5R
M(&UA=&-H:6YG"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D
M;65T87)#;V1E6R1K97E=*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!I9B`H)&9O=6YD("8F("%315)624-%4U]714%42$527T1%0E5'*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@("`@('T@96QS96EF("@D9F]U;F0@)B8@4T525DE#15-?5T5!5$A%4E]$
M14)51RD@>PH@("`@("`@("`@("`@("`@("`@("`@("!E8VAO("1K97DN(EQN
M(CL*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&EF("@A)&9O=6YD*2!["B`@("`@("`@("`@("`@("!I9B`H
M4T525DE#15-?5T5!5$A%4E]$14)51RD@>PH@("`@("`@("`@("`@("`@("`@
M(&5C:&\@(FXO85QN(CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)'=E871H97)$871A6R)N;W!A<G-E(ETI*2!["B`@
M("`@("`@("`@("`@("`@("`@)'=E871H97)$871A6R)N;W!A<G-E(ET@/2!A
M<G)A>2@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'=E
M871H97)$871A6R)N;W!A<G-E(EU;72`]("1M971A<ELD:5T["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D=V5A=&AE<D1A
M=&%;(FYO<&%R<V4B72DI('L*("`@("`@("`@("`@)'=E871H97)$871A6R)N
M;W!A<G-E(ET@/2!I;7!L;V1E*"(@(BP@("1W96%T:&5R1&%T85LB;F]P87)S
M92)=*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=V5A=&AE<D1A=&$[
M"B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@7W!A<G-E1F]R96-A<W1$
M871A*"D*("`@("\J*@H@("`@("H@4&%R<V5S('1H92!D871A(&%N9"!C86-H
M97,@:70*("`@("`J"B`@("`@*B!4048@2TQ'02`R-S$W,S1:(#(W,3@Q."`Q
M,3`P-TM4(%`V4TT@+5)!(%-#5#`R,"!"2TXR,#`*("`@("`J("`@("!&33(S
M,#`@,30P,#=+5"!0-E--(%-#5#`S,"!"2TXQ-3`*("`@("`J("`@("!&33`T
M,#`@5E)",#-+5"!0-E--(%-#5#`S-2!/5D,P.#`@4%)/0C,P(#`U,#D@4#93
M32`M4D$@0DM.,#,U"B`@("`@*B`@("`@1DTP.3`P(%920C`S2U0@-E--("U2
M02!"4B!30U0P,34@3U9#,#,U"B`@("`@*B`@("`@("`@(%1%35!/(#$R,34@
M-5--("U202!"4B!30U0P,#D@0DM.,#$U"B`@("`@*B`@("`@("`@($)%0TU'
M(#$U,3<@,38P,#=+5"!0-E--($Y35R!30U0P,34@0DM.,#<P"B`@("`@*@H@
M("`@("H@0'!A<F%M("`@87)R87D@("`@("`@("`@("`@("`@("`@("`@("1D
M871A"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&%R<F%Y"B`@("`@*B!`
M=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$527T524D]27U=2
M3TY'7U-%4E9%4E]$051!"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI3
M15)624-%4U]714%42$527T524D]27U5.2TY/5TY?3$]#051)3TX*("`@("`J
M($!A8V-E<W,@('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E
M1F]R96-A<W1$871A*"1D871A*0H@("`@>PH@("`@("`@('-T871I8R`D8V]M
M<&%S<SL*("`@("`@("!S=&%T:6,@)&-L;W5D<SL*("`@("`@("!S=&%T:6,@
M)&-O;F1I=&EO;G,["B`@("`@("`@<W1A=&EC("1S96YS;W)S.PH@("`@("`@
M(&EF("@A:7-S970H)&-O;7!A<W,I*2!["B`@("`@("`@("`@("1C;VUP87-S
M(#T@87)R87DH"B`@("`@("`@("`@("`@("`B3B(L(").3D4B+"`B3D4B+"`B
M14Y%(BP*("`@("`@("`@("`@("`@(")%(BP@(D5312(L(")312(L(")34T4B
M+`H@("`@("`@("`@("`@("`@(E,B+"`B4U-7(BP@(E-7(BP@(E=35R(L"B`@
M("`@("`@("`@("`@("`B5R(L(")73E<B+"`B3E<B+"`B3DY7(@H@("`@("`@
M("`@("`I.PH@("`@("`@("`@("`D8VQO=61S("`@(#T@87)R87DH"B`@("`@
M("`@("`@("`@("`B<VMC(B`@("`@("`@(#T^(")S:WD@8VQE87(B+`H@("`@
M("`@("`@("`@("`@(FYS8R(@("`@("`@("`]/B`B;F\@<VEG;FEF:6-A;G0@
M8VQO=60B+`H@("`@("`@("`@("`@("`@(F9E=R(@("`@("`@("`]/B`B9F5W
M(BP*("`@("`@("`@("`@("`@(")S8W0B("`@("`@("`@/3X@(G-C871T97)E
M9"(L"B`@("`@("`@("`@("`@("`B8FMN(B`@("`@("`@(#T^(")B<F]K96XB
M+`H@("`@("`@("`@("`@("`@(F]V8R(@("`@("`@("`]/B`B;W9E<F-A<W0B
M+`H@("`@("`@("`@("`@("`@(G9V(B`@("`@("`@("`]/B`B=F5R=&EC86P@
M=FES:6)I;&ET>2(L"B`@("`@("`@("`@("`@("`B=&-U(B`@("`@("`@(#T^
M(")4;W=E<FEN9R!#=6UU;'5S(BP*("`@("`@("`@("`@("`@(")C8B(@("`@
M("`@("`@/3X@(D-U;75L;VYI;6)U<R(L"B`@("`@("`@("`@("`@("`B8VQR
M(B`@("`@("`@(#T^(")C;&5A<B!B96QO=R`Q,BPP,#`@9G0B"B`@("`@("`@
M("`@("D["B`@("`@("`@("`@("1C;VYD:71I;VYS(#T@87)R87DH"B`@("`@
M("`@("`@("`@("`B*R(@("`@("`@("`@(#T^(")H96%V>2(L("`@("`@("`B
M+2(@("`@("`@("`@(#T^(")L:6=H="(L"@H@("`@("`@("`@("`@("`@(G9C
M(B`@("`@("`@("`]/B`B=FEC:6YI='DB+"`@("`@(G)E(B`@("`@("`@("`]
M/B`B<F5C96YT(BP*("`@("`@("`@("`@("`@(")N<W<B("`@("`@("`@/3X@
M(FYO('-I9VYI9FEC86YT('=E871H97(B+`H*("`@("`@("`@("`@("`@(")M
M:2(@("`@("`@("`@/3X@(G-H86QL;W<B+"`@("`@(")B8R(@("`@("`@("`@
M/3X@(G!A=&-H97,B+`H@("`@("`@("`@("`@("`@(G!R(B`@("`@("`@("`]
M/B`B<&%R=&EA;"(L("`@("`@(G1S(B`@("`@("`@("`]/B`B=&AU;F1E<G-T
M;W)M(BP*("`@("`@("`@("`@("`@(")B;"(@("`@("`@("`@/3X@(F)L;W=I
M;F<B+"`@("`@(")S:"(@("`@("`@("`@/3X@(G-H;W=E<G,B+`H@("`@("`@
M("`@("`@("`@(F1R(B`@("`@("`@("`]/B`B;&]W(&1R:69T:6YG(BP@(F9Z
M(B`@("`@("`@("`]/B`B9G)E97II;F<B+`H*("`@("`@("`@("`@("`@(")D
M>B(@("`@("`@("`@/3X@(F1R:7IZ;&4B+"`@("`@(")R82(@("`@("`@("`@
M/3X@(G)A:6XB+`H@("`@("`@("`@("`@("`@(G-N(B`@("`@("`@("`]/B`B
M<VYO=R(L("`@("`@("`@(G-G(B`@("`@("`@("`]/B`B<VYO=R!G<F%I;G,B
M+`H@("`@("`@("`@("`@("`@(FEC(B`@("`@("`@("`]/B`B:6-E(&-R>7-T
M86QS(BP@(G!E(B`@("`@("`@("`]/B`B:6-E('!E;&QE=',B+`H@("`@("`@
M("`@("`@("`@(F=R(B`@("`@("`@("`]/B`B:&%I;"(L("`@("`@("`@(F=S
M(B`@("`@("`@("`]/B`B<VUA;&P@:&%I;"]S;F]W('!E;&QE=',B+`H@("`@
M("`@("`@("`@("`@(G5P(B`@("`@("`@("`]/B`B=6YK;F]W;B!P<F5C:7!I
M=&%T:6]N(BP*"B`@("`@("`@("`@("`@("`B8G(B("`@("`@("`@(#T^(")M
M:7-T(BP@("`@("`@("`B9F<B("`@("`@("`@(#T^(")F;V<B+`H@("`@("`@
M("`@("`@("`@(F9U(B`@("`@("`@("`]/B`B<VUO:V4B+"`@("`@("`@(G9A
M(B`@("`@("`@("`]/B`B=F]L8V%N:6,@87-H(BP*("`@("`@("`@("`@("`@
M(")S82(@("`@("`@("`@/3X@(G-A;F0B+"`@("`@("`@(")H>B(@("`@("`@
M("`@/3X@(FAA>F4B+`H@("`@("`@("`@("`@("`@(G!Y(B`@("`@("`@("`]
M/B`B<W!R87DB+"`@("`@("`@(F1U(B`@("`@("`@("`]/B`B=VED97-P<F5A
M9"!D=7-T(BP*"B`@("`@("`@("`@("`@("`B<W$B("`@("`@("`@(#T^(")S
M<75A;&PB+"`@("`@("`B<W,B("`@("`@("`@(#T^(")S86YD<W1O<FTB+`H@
M("`@("`@("`@("`@("`@(F1S(B`@("`@("`@("`]/B`B9'5S='-T;W)M(BP@
M("`@(G!O(B`@("`@("`@("`]/B`B=V5L;"!D979E;&]P960@9'5S="]S86YD
M('=H:7)L<R(L"B`@("`@("`@("`@("`@("`B9F,B("`@("`@("`@(#T^(")F
M=6YN96P@8VQO=60B+`H*("`@("`@("`@("`@("`@("(K9F,B("`@("`@("`@
M/3X@(G1O<FYA9&\O=V%T97)S<&]U="(*("`@("`@("`@("`@*3L*("`@("`@
M("!]"@H@("`@("`@("1T869#;V1E(#T@87)R87DH"B`@("`@("`@("`@(")R
M97!O<G0B("`@("`@/3X@(E1!1GQ!340B+`H@("`@("`@("`@("`B<W1A=&EO
M;B(@("`@(#T^(")<=WLT?2(L"B`@("`@("`@("`@(")U<&1A=&4B("`@("`@
M/3X@(BA<9'LR?2D_*%QD>S1]*5HB+`H@("`@("`@("`@("`B=F%L:60B("`@
M("`@(#T^("(H7&1[,GTI*%QD>S)]*2A<9'LR?2DB+`H@("`@("`@("`@("`B
M=VEN9"(@("`@("`@(#T^("(H7&1[,WU\5D%2?%920BDH7&1[,BPS?2DH1RA<
M9'LR?2DI/RA<=WLR+#-]*2(L"B`@("`@("`@("`@(")V:7-&<F%C(B`@("`@
M/3X@(BA<9'LQ?2DB+`H@("`@("`@("`@("`B=FES:6)I;&ET>2(@(#T^("(H
M7&1[-'TI?"@H37Q0*3\H*%QD>S$L,GU\*"A<9"D@*3\H7&0I7"\H7&0I*2A3
M37Q+32DI*7PH0T%63TLI(BP*("`@("`@("`@("`@(F-O;F1I=&EO;B(@("`]
M/B`B*"U\7"M\5D-\4D5\3E-7*3\H34E\0D-\4%)\5%-\0DQ\4TA\1%)\1EHI
M/R@H1%HI?"A202E\*%-.*7PH4T<I?"A)0RE\*%!,*7PH1U(I?"A'4RE\*%50
M*2DJ*$)2?$9'?$95?%9!?$15?%-!?$A:?%!9*3\H4$]\4U%\1D-\4U-\1%,I
M/R(L"B`@("`@("`@("`@(")C;&]U9',B("`@("`@/3X@(BA32T-\0TQ2?$Y3
M0WPH*$9%5WQ30U1\0DM.?$]60WQ65BDH7&1[,WTI*%1#57Q#0BD_*2DB+`H@
M("`@("`@("`@("`B=VEN9'-H96%R(B`@(#T^(")74RA<9'LS?2E<+RA<9'LS
M?2DH7&1[,BPS?2DH7'=[,BPS?2DB+`H@("`@("`@("`@("`B=&5M<&UA>"(@
M("`@(#T^(")46"A<9'LR?2E<+RA<9'LR?2DH7'<I(BP*("`@("`@("`@("`@
M(G1E;7!M:6XB("`@("`]/B`B5$XH7&1[,GTI7"\H7&1[,GTI*%QW*2(L"B`@
M("`@("`@("`@(")T96UP;6%X;6EN(B`@/3X@(E18*%QD>S)]*5PO*%QD>S)]
M*2A<=RE43BA<9'LR?2E<+RA<9'LR?2DH7'<I(BP*("`@("`@("`@("`@(F9R
M;VTB("`@("`@("`]/B`B1DTH7&1[,GTI*%QD>S)]*3\B+`H@("`@("`@("`@
M("`B9FUC(B`@("`@("`@(#T^("(H4%)/0GQ"14--1WQ414U03RDH7&1[,GTI
M/R(*("`@("`@("`I.PH*("`@("`@("!I9B`H4T525DE#15-?5T5!5$A%4E]$
M14)51RD@>PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H
M)&1A=&$I.R`D:2LK*2!["B`@("`@("`@("`@("`@("!E8VAO("1D871A6R1I
M73L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`O+R!/:RP@=V4@
M:&%V92!C;W)R96-T(&1A=&$L('-T87)T('=I=&@@<&%R<VEN9R!T:&4@9FER
M<W0@;&EN92!F;W(@=&AE(&QA<W0@=7!D871E"B`@("`@("`@)&9O<F5C87-T
M1&%T82`](&%R<F%Y*"D["B`@("`@("`@)&9O<F5C87-T1&%T85LB<W1A=&EO
M;B)=("`@/2`B(CL*("`@("`@("`D9F]R96-A<W1$871A6R)D871A4F%W(ET@
M("`](&EM<&QO9&4H(B`B+"`D9&%T82D["B`@("`@("`@)&9O<F5C87-T1&%T
M85LB=7!D871E(ET@("`@/2!S=')T;W1I;64H=')I;2@D9&%T85LP72DN(B!'
M350B*3L*("`@("`@("`D9F]R96-A<W1$871A6R)U<&1A=&5287<B72`]('1R
M:6TH)&1A=&%;,%TI.PH@("`@("`@("\O(&%N9"!P<F5P87)E('1H92!R97-T
M(&9O<B!S=&5P<&EN9R!T:')O=6=H"B`@("`@("`@87)R87E?<VAI9G0H)&1A
M=&$I.PH@("`@("`@("1T868@/2!E>'!L;V1E*"(@(BP@<')E9U]R97!L86-E
M*"(O7'-[,BQ]+R(L("(@(BP@:6UP;&]D92@B("(L("1D871A*2DI.PH*("`@
M("`@("`O+R!!9&0@82!F97<@;&]C86P@=F%R:6%B;&5S(&9O<B!D871A('!R
M;V-E<W-I;F<*("`@("`@("`D9G)O;51I;64@/2`@(B([("`@("`@("`@("`@
M+R\@5&AE('1I;65P97)I;V0@=&AE(&1A=&$@9V5T<R!A9&1E9"!T;PH@("`@
M("`@("1F;6-#;W5N="`]("`P.R`@("`@("`@("`@("`O+R!)9B!W92!H879E
M($9-0W,@*$9O<F5C87-T($UE=&5O<F]L;V=I8V%L($-O;F1I=&EO;G,I+"!W
M92!N965D('1H:7,*("`@("`@("`D<&]I;G1E<B`@/28@)&9O<F5C87-T1&%T
M83L@+R\@4&]I;G1E<B!T;R!T:&4@87)R87D@=V4@861D('1H92!D871A('1O
M"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1T868I.R`D:2LK
M*2!["B`@("`@("`@("`@("\O($-H96-K(&9O<B!W:&ET97-P86-E(&%N9"!S
M=&5P(&QO;W`L(&EF(&YO=&AI;F<G<R!T:&5R90H@("`@("`@("`@("`D=&%F
M6R1I72`]('1R:6TH)'1A9ELD:5TI.PH@("`@("`@("`@("!I9B`H(7-T<FQE
M;B@D=&%F6R1I72DI('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!I9B`H4T525DE#15-?5T5!5$A%4E]$
M14)51RD@>PH@("`@("`@("`@("`@("`@)'1A8B`]('-T<E]R97!E870H(EQT
M(BP@,B`M(&9L;V]R*"AS=')L96XH)'1A9ELD:5TI("L@,BD@+R`X*2D["B`@
M("`@("`@("`@("`@("!E8VAO(")<(B(N)'1A9ELD:5TN(EPB(BXD=&%B+B(M
M/B`B.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!);FET:6%L:7IE
M('-O;64@87)R87ES"B`@("`@("`@("`@("1R97-U;'0@("`](&%R<F%Y*"D[
M"B`@("`@("`@("`@("1R97-U;'161B`](&%R<F%Y*"D["B`@("`@("`@("`@
M("1L<F5S=6QT("`](&%R<F%Y*"D["@H@("`@("`@("`@("`D9F]U;F0@/2!F
M86QS93L*("`@("`@("`@("`@9F]R96%C:"`H)'1A9D-O9&4@87,@)&ME>2`]
M/B`D<F5G97AP*2!["B`@("`@("`@("`@("`@("`O+R!#:&5C:R!I9B!C=7)R
M96YT(&-O9&4@;6%T8VAE<R!C=7)R96YT('1A9B!S;FEP<&5T"B`@("`@("`@
M("`@("`@("!I9B`H*"1F;W5N9"`]('!R96=?;6%T8V@H(B]>(BXD<F5G97AP
M+B(D+VDB+"`D=&%F6R1I72P@)')E<W5L="DI(#T]('1R=64I('L*("`@("`@
M("`@("`@("`@("`@("`D:6YS97)T(#T@87)R87DH*3L*("`@("`@("`@("`@
M("`@("`@("!S=VET8V@@*"1K97DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@8V%S92`B<W1A=&EO;B(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<&]I;G1E<ELB<W1A=&EO;B)=(#T@)')E<W5L=%LP73L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('5N<V5T*"1T869#;V1E6R)S=&%T:6]N(ETI
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("`@("`@("`@(&-A<V4@(G9A;&ED(CH*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P;VEN=&5R6R)V86QI9%)A=R)=(#T@)')E<W5L=%LP
M73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($=E;F5R871E<R!T
M:&4@=&EM97!E<FEO9"!T:&4@<F5P;W)T(&ES('9A;&ED(&9O<@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@;&ES="@D>65A<BP@)&UO;G1H+"`D9&%Y
M*2`](&5X<&QO9&4H(BTB+"!D871E*")9+6TM9"(L("1F;W)E8V%S=$1A=&%;
M(G5P9&%T92)=*2D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!$
M871E(&ES(&EN(&YE>'0@;6]N=&@*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@D<F5S=6QT6S%=(#P@)&1A>2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1M;VYT:"LK.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT
M97);(G9A;&ED1G)O;2)=(#T@9VUM:W1I;64H)')E<W5L=%LR72P@,"P@,"P@
M)&UO;G1H+"`D<F5S=6QT6S%=+"`D>65A<BD["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!686QI9"!T:6UE(&5N9',@;F5X="!D87D*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT6S)=(#X]("1R97-U
M;'1;,UTI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5S
M=6QT6S%=*RL["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB=F%L:614;R)=("`@
M/2!G;6UK=&EM92@D<F5S=6QT6S-=+"`P+"`P+"`D;6]N=&@L("1R97-U;'1;
M,5TL("1Y96%R*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T
M*"1T869#;V1E6R)V86QI9")=*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("\O($YO=R!T:&4@9W)O=7!S('=I;&P@<W1A<G0L('-O(&EN:71I86QI
M>F4@=&AE('1I;64@9W)O=7!S"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<&]I;G1E<ELB=&EM92)=(#T@87)R87DH*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1F<F]M5&EM92`]("1R97-U;'1;,ETN(CHP,"(["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB=&EM92)=6R1F
M<F]M5&EM95T@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@4V5T('!O:6YT97(@=&\@=&AE(&9I<G-T('1I;65P97)I;V0*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R(#TF("1P;VEN=&5R
M6R)T:6UE(EU;)&9R;VU4:6UE73L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")W:6YD
M(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(%!A<G-E('=I;F0@
M9&%T82P@9FER<W0@=&AE('-P965D+"!C;VYV97)T(&9R;VT@:W0@=&\@8VAO
M<V5N('5N:70*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R
M6R)W:6YD(ET@/2`D=&AI<RT^8V]N=F5R=%-P965D*"1R97-U;'1;,ETL('-T
M<G1O;&]W97(H)')E<W5L=%LU72DL(")M<&@B*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@D<F5S=6QT6S%=(#T](")605(B('Q\("1R97-U
M;'1;,5T@/3T@(E920B(I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!687)I86)L92!W:6YD<PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P;VEN=&5R6R)W:6YD1&5G<F5E<R)=("`@/2`B5F%R:6%B
M;&4B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R
M6R)W:6YD1&ER96-T:6]N(ET@/2`B5F%R:6%B;&4B.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!3879E('=I;F0@9&5G<F5E(&%N9"!C86QC(&1I<F5C
M=&EO;@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R
M6R)W:6YD1&5G<F5E<R)=("`@/2`D<F5S=6QT6S%=.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)W:6YD1&ER96-T:6]N(ET@
M/2`D8V]M<&%S<UMR;W5N9"@D<F5S=6QT6S%=("\@,C(N-2D@)2`Q-ET["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-?;G5M97)I8R@D<F5S=6QT6S1=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(%=I;F0@=VET:"!G=7-T
M<RXN+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R
M6R)W:6YD1W5S=")=(#T@)'1H:7,M/F-O;G9E<G13<&5E9"@D<F5S=6QT6S1=
M+"!S=')T;VQO=V5R*"1R97-U;'1;-5TI+"`B;7!H(BD["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)'!R;V)A8FEL:71Y*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P;VEN=&5R6R)W:6YD4')O8B)=(#T@)'!R;V)A
M8FEL:71Y.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T
M*"1P<F]B86)I;&ET>2D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@("`@("`@("`@8V%S92`B=FES1G)A8R(Z"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!0;W-S:6)L92!F<F%C=&EO;F%L('9I<VEB:6QI
M='D@:&5R92X@0VAE8VL@:68@:70@;6%T8VAE<R!W:71H('1H92!N97AT(%1!
M1B!P:65C92!F;W(@=FES:6)I;&ET>0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D=&%F6R1I("L@,5TI('Q\("%P<F5G7VUA=&-H
M*"(O7B(N)'1A9D-O9&5;(G9I<VEB:6QI='DB72XB)"]I(BP@)')E<W5L=%LQ
M72XB("(N)'1A9ELD:2`K(#%=+"`D<F5S=6QT5D8I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@3F\@;F5X="!4048@<&EE8V4@879A
M:6QA8FQE(&]R(&YO="!M871C:&EN9RX@36%T8V@@86=A:6YS="!N97AT(%1!
M1B!C;V1E"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O=6YD
M(#T@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($UA=&-H+B!(86YD(&]V
M97(@<F5S=6QT(&%N9"!A9'9A;F-E(%1!1@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("A315)624-%4U]714%42$527T1%0E5'*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&5C:&\@)&ME>2XB
M7&XB.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!E8VAO
M(")<(B(N)')E<W5L=%LQ72XB("(N)'1A9ELD:2`K(#%=+B)<(B(N<W1R7W)E
M<&5A="@B7'0B+"`R("T@9FQO;W(H*'-T<FQE;B@D<F5S=6QT6S%=+B(@(BXD
M=&%F6R1I("L@,5TI("L@,BD@+R`X*2DN(BT^("(["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1K97D@/2`B=FES:6)I;&ET>2(["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)')E<W5L="`]("1R97-U;'161CL*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")V
M:7-I8FEL:71Y(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN
M=&5R6R)V:7-1=6%L:69I97(B72`](")!5"(["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-?;G5M97)I8R@D<F5S=6QT6S%=*2`F)B`H)')E
M<W5L=%LQ72`]/2`Y.3DY*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("\O(%5P<&5R(&QI;6ET(&]F('9I<VEB:6QI='D@<F%N9V4*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=FES:6)I;&ET>2`]("1T
M:&ES+3YC;VYV97)T1&ES=&%N8V4H,3`L(")K;2(L(")S;2(I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)V:7-1=6%L:69I
M97(B72`](")"15E/3D0B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*&ES7VYU;65R:6,H)')E<W5L=%LQ72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`O+R`T+61I9VET('9I<VEB:6QI='D@
M:6X@;0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V:7-I8FEL
M:71Y(#T@)'1H:7,M/F-O;G9E<G1$:7-T86YC92@H)')E<W5L=%LQ72\Q,#`P
M*2P@(FMM(BP@(G-M(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M(&5L<V5I9B`H(6ES<V5T*"1R97-U;'1;,3%=*2!\?"`D<F5S=6QT6S$Q72`A
M/2`B0T%63TLB*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"1R97-U;'1;,UT@/3T@(DTB*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P;VEN=&5R6R)V:7-1=6%L:69I97(B72`](")"
M14Q/5R(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M:68@*"1R97-U;'1;,UT@/3T@(E`B*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P;VEN=&5R6R)V:7-1=6%L:69I97(B72`](")"
M15E/3D0B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-?;G5M97)I8R@D
M<F5S=6QT6S5=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!V:7-I8FEL:71Y(&%S(&]N92]T=V\M9&EG:70@;G5M8F5R"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V:7-I8FEL:71Y
M(#T@)'1H:7,M/F-O;G9E<G1$:7-T86YC92@D<F5S=6QT6S5=+"`D<F5S=6QT
M6S$P72P@(G-M(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+R\@=&AE('DO>B!P87)T+"!A9&0@:68@=V4@:&%D(&$@>"!P87)T("AS964@
M=FES:6)I;&ET>3$I"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("AI<U]N=6UE<FEC*"1R97-U;'1;-UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=FES:6)I;&ET>2`]("1T
M:&ES+3YC;VYV97)T1&ES=&%N8V4H)')E<W5L=%LW72`K("1R97-U;'1;.%T@
M+R`D<F5S=6QT6SE=+"`D<F5S=6QT6S$P72P@(G-M(BD["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=FES:6)I;&ET>2`]("1T
M:&ES+3YC;VYV97)T1&ES=&%N8V4H)')E<W5L=%LX72`O("1R97-U;'1;.5TL
M("1R97-U;'1;,3!=+"`B<VTB*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(G9I<U%U86QI
M9FEE<B)=(#T@(D)%64].1"(["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'9I<VEB:6QI='D@/2`D=&AI<RT^8V]N=F5R=$1I<W1A;F-E*#$P
M+"`B:VTB+"`B<VTB*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<&]I;G1E<ELB8VQO=61S(ET@/2!A<G)A>2AA<G)A>2@B86UO=6YT(B`]
M/B`B0VQE87(@8F5L;W<B+"`B:&5I9VAT(B`]/B`U,#`P*2D["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(F-O;F1I=&EO;B)=
M(#T@(FYO('-I9VYI9FEC86YT('=E871H97(B.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1P<F]B86)I;&ET>2DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<&]I;G1E<ELB=FES4')O8B)=(#T@)'!R;V)A8FEL:71Y
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1P<F]B
M86)I;&ET>2D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB=FES:6)I;&ET>2)=
M(#T@)'9I<VEB:6QI='D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B8V]N9&ET:6]N
M(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($9I<G-T('-O;64@
M8F%S:6,@<V5T=7!S"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1P;VEN=&5R6R)C;VYD:71I;VXB72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB8V]N9&ET:6]N(ET@/2`B
M(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AS=')L
M96XH)'!O:6YT97);(F-O;F1I=&EO;B)=*2`^(#`I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB8V]N9&ET:6]N(ET@+CT@
M(BPB.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI;E]A<G)A>2AS=')T;VQO=V5R*"1R
M97-U;'1;,%TI+"`D8V]N9&ET:6]N<RDI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!&:7)S="!T<GD@;6%T8VAI;F<@=&AE(&-O;7!L
M971E('-T<FEN9PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M;VEN=&5R6R)C;VYD:71I;VXB72`N/2`B("(N)&-O;F1I=&EO;G-;<W1R=&]L
M;W=E<B@D<F5S=6QT6S!=*5T["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O
M($YO(&QU8VLL(&UA=&-H('!A<G0@8GD@<&%R=`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y7W-H:69T*"1R97-U;'0I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1R97-U;'0@/2!A<G)A>5]U;FEQ
M=64H)')E<W5L="D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)')E<W5L="!A<R`D8V]N9&ET:6]N*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AS=')L96XH)&-O;F1I=&EO
M;BD@/B`P*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&]I;G1E<ELB8V]N9&ET:6]N(ET@+CT@(B`B+B1C;VYD:71I;VYS
M6W-T<G1O;&]W97(H)&-O;F1I=&EO;BE=.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(F-O;F1I=&EO;B)=(#T@
M=')I;2@D<&]I;G1E<ELB8V]N9&ET:6]N(ETI.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1P<F]B86)I;&ET>2DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB8V]N9&ET:6]N
M(ET@+CT@(B`H(BXD<')O8F%B:6QI='DN(B4@<')O8BXI(CL*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D<')O8F%B:6QI='DI.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A
M<V4@(F-L;W5D<R(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1P;VEN=&5R6R)C;&]U9',B72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB8VQO=61S(ET@/2!A<G)A>2@I
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("AS:7IE;V8H)')E<W5L="D@/3T@-2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($]N;'D@86UO=6YT
M(&%N9"!H96EG:'0*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M8VQO=60@/2!A<G)A>2@B86UO=6YT(B`]/B`D8VQO=61S6W-T<G1O;&]W97(H
M)')E<W5L=%LS72E=+"`B:&5I9VAT(B`]/B`H)')E<W5L=%LT72`J(#$P,"DI
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@96QS96EF("AS:7IE;V8H)')E<W5L="D@/3T@-BD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($%M;W5N="P@
M:&5I9VAT(&%N9"!T>7!E"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&-L;W5D(#T@87)R87DH(F%M;W5N="(@/3X@)&-L;W5D<UMS=')T;VQO
M=V5R*"1R97-U;'1;,UTI72P@(FAE:6=H="(@/3X@*"1R97-U;'1;-%T@*B`Q
M,#`I+"`B='EP92(@/3X@)&-L;W5D<UMS=')T;VQO=V5R*"1R97-U;'1;-5TI
M72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!32T,@;W(@0TQ2(&]R($Y30PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1C;&]U9"`](&%R<F%Y*")A;6]U;G0B(#T^
M("1C;&]U9'-;<W1R=&]L;W=E<B@D<F5S=6QT6S!=*5TI.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68H:7-S970H)'!R;V)A8FEL:71Y*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1C;&]U9%LB<')O8B)=(#T@)'!R;V)A8FEL:71Y
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1P<F]B
M86)I;&ET>2D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB8VQO=61S(EU;72`]
M("1C;&]U9#L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@("`@("`@("!C87-E(")W:6YD<VAE87(B.@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@4&%R<V4@=VEN9'-H96%R+"!I
M9B!A=F%I;&%B;&4*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN
M=&5R6R)W:6YD<VAE87(B72`@("`@("`@("`]("1T:&ES+3YC;VYV97)T4W!E
M960H)')E<W5L=%LS72P@<W1R=&]L;W=E<B@D<F5S=6QT6S1=*2P@(FUP:"(I
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(G=I;F1S
M:&5A<DAE:6=H=")=("`@(#T@)')E<W5L=%LQ72`J(#$P,#L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)W:6YD<VAE87)$96=R965S
M(ET@("`]("1R97-U;'1;,ET["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<&]I;G1E<ELB=VEN9'-H96%R1&ER96-T:6]N(ET@/2`D8V]M<&%S<UMR
M;W5N9"@D<F5S=6QT6S)=("\@,C(N-2D@)2`Q-ET["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@
M8V%S92`B=&5M<&UA>"(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9F]R96-A<W1$871A6R)T96UP97)A='5R94AI9V@B72`]("1T:&ES+3YC;VYV
M97)T5&5M<&5R871U<F4H)')E<W5L=%LQ72P@(F,B+"`B9B(I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@
M("`@("`@(&-A<V4@(G1E;7!M:6XB.@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@4&%R<V4@;6%X+VUI;B!T96UP97)A='5R90H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&9O<F5C87-T1&%T85LB=&5M<&5R871U<F5,
M;W<B72`@/2`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E*"1R97-U;'1;,5TL
M(")C(BP@(F8B*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")T96UP;6%X;6EN(CH*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S=$1A=&%;(G1E
M;7!E<F%T=7)E2&EG:")=(#T@)'1H:7,M/F-O;G9E<G1496UP97)A='5R92@D
M<F5S=6QT6S%=+"`B8R(L(")F(BD["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9F]R96-A<W1$871A6R)T96UP97)A='5R94QO=R)=("`]("1T:&ES
M+3YC;VYV97)T5&5M<&5R871U<F4H)')E<W5L=%LT72P@(F,B+"`B9B(I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("`@("`@("`@(&-A<V4@(F9R;VTB.@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@3F5X="!T:6UE<&5R:6]D(&ES(&-O;6EN9R!U<"P@<')E
M<&%R92!A<G)A>2!A;F0*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O
M('-E="!P;VEN=&5R(&%C8V]R9&EN9VQY"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H<VEZ96]F*"1R97-U;'0I(#X@,BD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("\O(%1H92!)0T%/('=A>0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1F<F]M5&EM92`]("1R97-U;'1;
M,5TN(CHB+B1R97-U;'1;,ET["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O
M(%1H92!!=7-T<F%L:6%N('=A>2`H2&5Y(&UA=&5S(2D*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9G)O;51I;64@/2`D<F5S=6QT6S%=+B(Z
M,#`B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&9O<F5C87-T1&%T85LB=&EM92)=6R1F<F]M
M5&EM95T@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&9M8T-O=6YT(#T@,#L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M;VEN=&5R(#TF("1F;W)E8V%S=$1A=&%;(G1I;64B75LD9G)O;51I;65=.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("`@("`@("`@(&-A<V4@(F9M8R(["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!497-T+"!I9B!T:&ES(&ES(&$@<')O8F%B:6QI='D@9F]R
M('1H92!N97AT($9-0PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*'!R96=?;6%T8V@H(B]>0D5#34=\5$5-4$\D+VDB+"`D=&%F6R1I("L@,5TL
M("1L<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("\O(%-E="!T>7!E('1O($)%0TU'(&]R(%1%35!/"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1Y<&4@/2`D;')E<W5L=%LP73L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!3970@<')O8F%B:6QI='D*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<')O8F%B:6QI='D@
M/2`D<F5S=6QT6S)=.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("\O($YO=R!E>'1R86-T('1I;64@9F]R('1H:7,@9W)O=7`*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!P<F5G7VUA=&-H*"(O7BA<9'LR?2DH
M7&1[,GTI)"]I(BP@)'1A9ELD:2`K(#)=+"`D;')E<W5L="D["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&9R;VT@/2`D;')E<W5L=%LQ72XB
M.C`P(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&\@("`]
M("1L<F5S=6QT6S)=+B(Z,#`B.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T;R`@(#T@*"1T;R`]/2`B,C0Z,#`B*2`_("(P,#HP,"(@.B`D
M=&\["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@07,@=V4@
M;F]W(&AA=F4@='EP92P@<')O8F%B:6QI='D@86YD('1I;64@9F]R('1H:7,@
M1DU#"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@9G)O;2!O
M=7(@5$%&+"!I;F-R96%S92!F:65L9"UC;W5N=&5R"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&D@*ST@,CL*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"(O7BA<9'LR?2DH7&1[
M,GTI)"]I(BP@)'1A9ELD:2`K(#%=+"`D;')E<W5L="DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!.;W)M86P@9W)O=7`L('-E="!T
M>7!E(&%N9"!U<V4@97AT<F%C=&5D('1I;64*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D='EP92`]("1R97-U;'1;,5T["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@0VAE8VL@9F]R(%!23T)D9`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<F5S=6QT
M6S)=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<')O8F%B:6QI='D@/2`D<F5S=6QT6S)=.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9G)O;2`]("1L<F5S=6QT6S%=+B(Z,#`B.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T;R`@(#T@)&QR97-U;'1;,ETN(CHP,"(["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1O("`@/2`H)'1O(#T]
M("(R-#HP,"(I(#\@(C`P.C`P(B`Z("1T;SL*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!386UE(&%S(&%B;W9E+"!W92!H879E(&$@=&EM
M92!F;W(@=&AI<R!&34,@9G)O;2!O=7(@5$%&+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("\O(&EN8W)E87-E(&9I96QD+6-O=6YT97(*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:2`K/2`Q.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`O+R!4:&ES(&ES(&5I=&AE<B!A(%!23T)D9"!O
M<B!A(&UA;&9O<FUE9"!4048*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)')E<W5L=%LR72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!R;V)A8FEL:71Y(#T@)')E<W5L=%LR
M73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@2&%N9&QE('1H92!&34,L(&=E;F5R871E(&YE8V-E<W-A<GD@
M87)R87D@:68@:70G<R!T:&4@9FER<W0N+BX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D='EP92DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1F;W)E8V%S=$1A=&%;(G1I
M;64B75LD9G)O;51I;65=6R)F;6,B72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&9O<F5C87-T1&%T85LB=&EM92)=6R1F<F]M
M5&EM95U;(F9M8R)=(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&9O<F5C87-T1&%T85LB=&EM92)=6R1F<F]M5&EM95U;(F9M8R)=6R1F;6-#
M;W5N=%T@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("\O("XN+F%N9"!S970@<&]I;G1E<BX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<&]I;G1E<B`])B`D9F]R96-A<W1$871A6R)T:6UE
M(EU;)&9R;VU4:6UE75LB9FUC(EU;)&9M8T-O=6YT73L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9FUC0V]U;G0K*SL*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!);G-E<G0@9&%T80H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)T>7!E(ET@/2`D='EP
M93L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB
M9G)O;2)=(#T@)&9R;VT["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'!O:6YT97);(G1O(ET@("`]("1T;SL*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!U;G-E="@D='EP92P@)&9R;VTL("1T;RD["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P<F]B86)I
M;&ET>2DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!O:6YT97);(G!R;V)A8FEL:71Y(ET@/2`D<')O8F%B:6QI='D["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1P<F]B86)I
M;&ET>2D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&1E9F%U
M;'0Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!$;R!N;W1H:6YG
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*"1F;W5N9"`F
M)B`A4T525DE#15-?5T5!5$A%4E]$14)51RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M)&9O=6YD("8F(%-%4E9)0T537U=%051(15)?1$5"54<I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@96-H;R`D:V5Y+B)<;B(["B`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(21F
M;W5N9"D@>PH@("`@("`@("`@("`@("`@:68@*%-%4E9)0T537U=%051(15)?
M1$5"54<I('L*("`@("`@("`@("`@("`@("`@("!E8VAO(")N+V%<;B(["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1F
M;W)E8V%S=$1A=&%;(FYO<&%R<V4B72DI('L*("`@("`@("`@("`@("`@("`@
M("`D9F]R96-A<W1$871A6R)N;W!A<G-E(ET@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&9O<F5C87-T1&%T85LB;F]P
M87)S92)=6UT@/2`D=&%F6R1I73L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@:68@*&ES<V5T*"1F;W)E8V%S=$1A=&%;(FYO<&%R<V4B72DI
M('L*("`@("`@("`@("`@)&9O<F5C87-T1&%T85LB;F]P87)S92)=(#T@:6UP
M;&]D92@B("(L("`D9F]R96-A<W1$871A6R)N;W!A<G-E(ETI.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1F;W)E8V%S=$1A=&$["B`@("!]"B`@("`O
M+R!]?7T*"B`@("`O+R![>WL@7V-O;G9E<G12971U<FXH*0H@("`@+RHJ"B`@
M("`@*B!#;VYV97)T<R!T:&4@9&%T82!I;B!T:&4@<F5T=7)N(&%R<F%Y('1O
M('1H92!D97-I<F5D('5N:71S(&%N9"]O<@H@("`@("H@;W5T<'5T(&9O<FUA
M="X*("`@("`J"B`@("`@*B!`<&%R86T@("!A<G)A>2`@("`@("`@("`@("`@
M("`@("`@("`@)'1A<F=E=`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@
M("`@("`@("`@("`@("`@("1U;FET<PH@("`@("H@0'!A<F%M("`@<W1R:6YG
M("`@("`@("`@("`@("`@("`@("`@("1L;V-A=&EO;@H@("`@("H@0&%C8V5S
M<R`@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N=F5R=%)E='5R
M;B@F)'1A<F=E="P@)'5N:71S+"`D;&]C871I;VXI"B`@("!["B`@("`@("`@
M:68@*&ES7V%R<F%Y*"1T87)G970I*2!["B`@("`@("`@("`@(&9O<F5A8V@@
M*"1T87)G970@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("!I
M9B`H:7-?87)R87DH)'9A;"DI('L*("`@("`@("`@("`@("`@("`@("`O+R!!
M;F]T:&5R(&%R<F%Y(&1E=&5C=&5D+"!S;R!R96-U<G-E(&EN=&\@:70@=&\@
M8V]N=F5R="!T:&4@=6YI=',*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V-O;G9E<G12971U<FXH)'1A<F=E=%LD:V5Y72P@)'5N:71S+"`D;&]C871I
M;VXI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("!S=VET8V@@*"1K97DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M8V%S92`B<W1A=&EO;B(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;F5W5F%L(#T@)&QO8V%T:6]N6R)N86UE(ET["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S
M92`B=7!D871E(CH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B=F%L
M:61&<F]M(CH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B=F%L:614
M;R(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F5W5F%L(#T@9VUD
M871E*'1R:6TH)'1H:7,M/E]D871E1F]R;6%T+B(@(BXD=&AI<RT^7W1I;65&
M;W)M870I+"`D=F%L*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")W:6YD(CH*("`@
M("`@("`@("`@("`@("`@("`@("`@8V%S92`B=VEN9$=U<W0B.@H@("`@("`@
M("`@("`@("`@("`@("`@("!C87-E(")W:6YD<VAE87(B.@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&YE=U9A;"`]("1T:&ES+3YC;VYV97)T4W!E
M960H)'9A;"P@(FUP:"(L("1U;FET<ULB=VEN9")=*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@
M("!C87-E(")V:7-I8FEL:71Y(CH*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1N97=686P@/2`D=&AI<RT^8V]N=F5R=$1I<W1A;F-E*"1V86PL(")S
M;2(L("1U;FET<ULB=FES(ETI.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(FAE:6=H
M="(Z"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(G=I;F1S:&5A<DAE
M:6=H="(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F5W5F%L(#T@
M)'1H:7,M/F-O;G9E<G1$:7-T86YC92@D=F%L+"`B9G0B+"`D=6YI='-;(FAE
M:6=H=")=*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@("`@("`@("!C87-E(")T96UP97)A='5R92(Z"B`@
M("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(G1E;7!E<F%T=7)E2&EG:"(Z
M"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(G1E;7!E<F%T=7)E3&]W
M(CH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B9&5W4&]I;G0B.@H@
M("`@("`@("`@("`@("`@("`@("`@("!C87-E(")F96QT5&5M<&5R871U<F4B
M.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`]("1T:&ES
M+3YC;VYV97)T5&5M<&5R871U<F4H)'9A;"P@(F8B+"`D=6YI='-;(G1E;7`B
M72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@("`@("`@("`@8V%S92`B<')E<W-U<F4B.@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&YE=U9A;"`]("1T:&ES+3YC;VYV97)T4')E
M<W-U<F4H)'9A;"P@(FEN(BP@)'5N:71S6R)P<F5S(ETI.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@
M("`@(&-A<V4@(F%M;W5N="(Z"B`@("`@("`@("`@("`@("`@("`@("`@(&-A
M<V4@(G-N;W=D97!T:"(Z"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@
M(G-N;W=E<75I=B(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-?;G5M97)I8R@D=F%L*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1N97=686P@/2`D=&AI<RT^8V]N=F5R=%!R97-S=7)E*"1V86PL
M(")I;B(L("1U;FET<ULB<F%I;B)=*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&YE=U9A;"`]("1V86P["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@("`@("`@("`@8V%S92`B<V5A<')E<W-U<F4B.@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`]("1T:&ES+3YC;VYV97)T
M4')E<W-U<F4H)'9A;"P@(FEN(BP@)'5N:71S6R)P<F5S(ETI.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@
M("`@("`@(&-A<V4@(C%H=&5M<"(Z"B`@("`@("`@("`@("`@("`@("`@("`@
M(&-A<V4@(C%H9&5W(CH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B
M-FAM87AT96UP(CH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B-FAM
M:6YT96UP(CH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B,C1H;6%X
M=&5M<"(Z"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(C(T:&UI;G1E
M;7`B.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`]("1T
M:&ES+3YC;VYV97)T5&5M<&5R871U<F4H)'9A;"P@(F8B+"`D=6YI='-;(G1E
M;7`B72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&-O;G1I;G5E(#(["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("1T87)G971;)&ME>5T@/2`D;F5W5F%L
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[('-E87)C:$QO8V%T:6]N*"D*
M("`@("\J*@H@("`@("H@4V5A<F-H97,@241S(&9O<B!G:79E;B!L;V-A=&EO
M;BP@<F5T=7)N<R!A<G)A>2!O9B!P;W-S:6)L92!L;V-A=&EO;G,*("`@("`J
M(&]R('-I;F=L92!)1`H@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN9WQA
M<G)A>2`@("`@("`@("`@("`@("`D;&]C871I;VX*("`@("`J($!P87)A;2`@
M(&)O;VP@("`@("`@("`@("`@("`@("`@("`@("`D=7-E1FER<W0@("`@("`@
M268@<V5T+"!F:7)S="!)1"!O9B!R97-U;'0M87)R87D@:7,@<F5T=7)N960*
M("`@("`J($!R971U<FX@(%!%05)?17)R;W)\87)R87E\<W1R:6YG"B`@("`@
M*B!`=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$527T524D]2
M7U5.2TY/5TY?3$]#051)3TX*("`@("`J($!T:')O=W,@(%!%05)?17)R;W(Z
M.E-%4E9)0T537U=%051(15)?15)23U)?1$)?3D]47T-/3DY%0U1%1`H@("`@
M("H@0'1H<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/
M4E])3E9!3$E$7TQ/0T%424]."B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5A<F-H3&]C871I;VXH)&QO8V%T:6]N+"`D
M=7-E1FER<W0@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?9&(I('Q\("%$0CHZ:7-#;VYN96-T:6]N*"1T:&ES+3Y?9&(I*2![
M"B`@("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R
M<F]R*%-%4E9)0T537U=%051(15)?15)23U)?1$)?3D]47T-/3DY%0U1%1"P@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI
M<U]S=')I;F<H)&QO8V%T:6]N*2D@>PH@("`@("`@("`@("`O+R!4<GD@=&\@
M<&%R="!S96%R8V@@<W1R:6YG(&EN(&YA;64L('-T871E(&%N9"!C;W5N=')Y
M('!A<G0*("`@("`@("`@("`@+R\@86YD(&)U:6QD('=H97)E(&-L875S92!F
M<F]M(&ET(&9O<B!T:&4@<V5L96-T"B`@("`@("`@("`@("1L;V-A=&EO;B`]
M(&5X<&QO9&4H(BPB+"`D;&]C871I;VXI.PH*("`@("`@("`@("`@+R\@5')I
M;2P@8V%P<RUL;W<@86YD('%U;W1E('1H92!S=')I;F=S"B`@("`@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D;&]C871I;VXI.R`D:2LK*2![
M"B`@("`@("`@("`@("`@("`D;&]C871I;VY;)&E=(#T@)'1H:7,M/E]D8BT^
M<75O=&4H(B4B+G-T<G1O;&]W97(H=')I;2@D;&]C871I;VY;)&E=*2DN(B4B
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*'-I>F5O9B@D;&]C
M871I;VXI(#T](#$I('L*("`@("`@("`@("`@("`@("1W:&5R92`@/2`B3$]7
M15(H;F%M92D@3$E+12`B+B1L;V-A=&EO;ELP73L*("`@("`@("`@("`@?2!E
M;'-E:68@*'-I>F5O9B@D;&]C871I;VXI(#T](#(I('L*("`@("`@("`@("`@
M("`@("1W:&5R92`@/2`B3$]715(H;F%M92D@3$E+12`B+B1L;V-A=&EO;ELP
M73L*("`@("`@("`@("`@("`@("1W:&5R92`N/2`B($%.1"!,3U=%4BAC;W5N
M=')Y*2!,24M%("(N)&QO8V%T:6]N6S%=.PH@("`@("`@("`@("!](&5L<V5I
M9B`H<VEZ96]F*"1L;V-A=&EO;BD@/3T@,RD@>PH@("`@("`@("`@("`@("`@
M)'=H97)E("`]("),3U=%4BAN86UE*2!,24M%("(N)&QO8V%T:6]N6S!=.PH@
M("`@("`@("`@("`@("`@)'=H97)E("X]("(@04Y$($Q/5T52*'-T871E*2!,
M24M%("(N)&QO8V%T:6]N6S%=.PH@("`@("`@("`@("`@("`@)'=H97)E("X]
M("(@04Y$($Q/5T52*&-O=6YT<GDI($Q)2T4@(BXD;&]C871I;VY;,ET["B`@
M("`@("`@("`@('T@96QS96EF("AS:7IE;V8H)&QO8V%T:6]N*2`]/2`T*2![
M"B`@("`@("`@("`@("`@("`D=VAE<F4@(#T@(DQ/5T52*&YA;64I($Q)2T4@
M(BYS=6)S='(H)&QO8V%T:6]N6S!=+"`P+"`M,BDN(BP@(BYS=6)S='(H)&QO
M8V%T:6]N6S%=+"`R*3L*("`@("`@("`@("`@("`@("1W:&5R92`N/2`B($%.
M1"!,3U=%4BAS=&%T92D@3$E+12`B+B1L;V-A=&EO;ELR73L*("`@("`@("`@
M("`@("`@("1W:&5R92`N/2`B($%.1"!,3U=%4BAC;W5N=')Y*2!,24M%("(N
M)&QO8V%T:6]N6S-=.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!#
M<F5A=&4@<V5L96-T+"!L;V-A=&EO;G,@=VET:"!)0T%/(&9I<G-T"B`@("`@
M("`@("`@("1S96QE8W0@/2`B4T5,14-4(&EC86\L(&YA;64L('-T871E+"!C
M;W5N=')Y+"!L871I='5D92P@;&]N9VET=61E("(N"B`@("`@("`@("`@("`@
M("`@("`@("`B1E)/32!M971A<DQO8V%T:6]N<R`B+@H@("`@("`@("`@("`@
M("`@("`@("`@(E=(15)%("(N)'=H97)E+B(@(BX*("`@("`@("`@("`@("`@
M("`@("`@(")/4D1%4B!"62!I8V%O($1%4T,B.PH@("`@("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'-E;&5C="D["B`@("`@("`@("`@
M("\O($-H96-K(')E<W5L="!F;W(@=F%L:61I='D*("`@("`@("`@("`@:68@
M*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("`@("`@?2!E;'-E:68@*'-T<G1O;&]W97(H
M9V5T7V-L87-S*"1R97-U;'0I*2`A/2`B9&)?<F5S=6QT(B!\?"`D<F5S=6QT
M+3YN=6U2;W=S*"D@/3T@,"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%-E
M<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%
M4E)/4E]53DM.3U=.7TQ/0T%424].+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!297-U;'0@:7,@=F%L:60L
M('-T87)T('!R97!A<FEN9R!T:&4@<F5T=7)N"B`@("`@("`@("`@("1I8V%O
M(#T@87)R87DH*3L*("`@("`@("`@("`@=VAI;&4@*"@D<F]W(#T@)')E<W5L
M="T^9F5T8VA2;W<H1$)?1D540TA-3T1%7T%34T]#*2D@(3T@;G5L;"D@>PH@
M("`@("`@("`@("`@("`@)&QO8VEC86\@/2`D<F]W6R)I8V%O(ET["B`@("`@
M("`@("`@("`@("`O+R!&:7)S="!T:&4@;F%M92!O9B!T:&4@;&]C871I;VX*
M("`@("`@("`@("`@("`@(&EF("@A<W1R;&5N*"1R;W=;(G-T871E(ETI*2![
M"B`@("`@("`@("`@("`@("`@("`@)&QO8VYA;64@/2`D<F]W6R)N86UE(ETN
M(BP@(BXD<F]W6R)C;W5N=')Y(ET["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1L;V-N86UE(#T@)')O=ULB;F%M92)=
M+B(L("(N)')O=ULB<W1A=&4B72XB+"`B+B1R;W=;(F-O=6YT<GDB73L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@D;&]C:6-A;R`A
M/2`B+2TM+2(I('L*("`@("`@("`@("`@("`@("`@("`O+R!792!H879E(&$@
M;&]C871I;VX@=VET:"!)0T%/"B`@("`@("`@("`@("`@("`@("`@)&EC86];
M)&QO8VEC86]=(#T@)&QO8VYA;64["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("\O($YO($E#04\L('1R>2!F:6YD:6YG
M('1H92!N96%R97-T(&%I<G!O<G0*("`@("`@("`@("`@("`@("`@("`D;&]C
M:6-A;R`]("1T:&ES+3YS96%R8VA!:7)P;W)T*"1R;W=;(FQA=&ET=61E(ETL
M("1R;W=;(FQO;F=I='5D92)=*3L*("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1I8V%O6R1L;V-I8V%O72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&EC86];)&QO8VEC86]=(#T@)&QO8VYA;64["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@("`@("\O($]N;'D@;VYE(')E<W5L=#\@4F5T=7)N(&%S('-T<FEN
M9PH@("`@("`@("`@("!I9B`H<VEZ96]F*"1I8V%O*2`]/2`Q('Q\("1U<V5&
M:7)S="D@>PH@("`@("`@("`@("`@("`@)&EC86\@/2!K97DH)&EC86\I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1L;V-A
M=&EO;BDI('L*("`@("`@("`@("`@+R\@3&]C871I;VX@=V%S('!R;W9I9&5D
M(&%S(&-O;W)D:6YA=&5S+"!S96%R8V@@;F5A<F5S="!A:7)P;W)T"B`@("`@
M("`@("`@("1I8V%O(#T@)'1H:7,M/G-E87)C:$%I<G!O<G0H)&QO8V%T:6]N
M6S!=+"`D;&]C871I;VY;,5TI.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)
M0T537U=%051(15)?15)23U)?24Y604Q)1%],3T-!5$E/3BP@7U]&24Q%7U\L
M(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6-A;SL*
M("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!S96%R8VA,;V-A=&EO;D)Y
M0V]U;G1R>2@I"B`@("`O*BH*("`@("`J(%)E='5R;G,@241S('=I=&@@;&]C
M871I;VXM;F%M92!F;W(@82!G:79E;B!C;W5N=')Y(&]R(&%L;"!A=F%I;&%B
M;&4*("`@("`J(&-O=6YT<FEE<RP@:68@;F\@=F%L=64@=V%S(&=I=F5N"B`@
M("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@
M("`@("1C;W5N=')Y"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&%R<F%Y
M"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$52
M7T524D]27U5.2TY/5TY?3$]#051)3TX*("`@("`J($!T:')O=W,@(%!%05)?
M17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?1$)?3D]47T-/3DY%0U1%
M1`H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%
M4E]%4E)/4E]74D].1U]315)615)?1$%400H@("`@("H@0&%C8V5S<R`@<'5B
M;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-E87)C:$QO8V%T:6]N0GE#;W5N
M=')Y*"1C;W5N=')Y(#T@(B(I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^7V1B*2!\?"`A1$(Z.FES0V]N;F5C=&EO;B@D=&AI<RT^7V1B*2D@
M>PH@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%
M<G)O<BA315)624-%4U]714%42$527T524D]27T1"7TY/5%]#3TY.14-4140L
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`O+R!2
M971U<FX@=&AE(&%V86EL86)L92!C;W5N=')I97,@87,@;F\@8V]U;G1R>2!W
M87,@9VEV96X*("`@("`@("!I9B`H(7-T<FQE;B@D8V]U;G1R>2DI('L*("`@
M("`@("`@("`@)'-E;&5C="`](")314Q%0U0@1$E35$E.0U0H8V]U;G1R>2D@
M(BX*("`@("`@("`@("`@("`@("`@("`@(")&4D]-(&UE=&%R06ER<&]R=',@
M(BX*("`@("`@("`@("`@("`@("`@("`@(")/4D1%4B!"62!C;W5N=')Y($%3
M0R(["B`@("`@("`@("`@("1C;W5N=')I97,@/2`D=&AI<RT^7V1B+3YG971#
M;VPH)'-E;&5C="D["@H@("`@("`@("`@("`O+R!!<R`D8V]U;G1R:65S(&ES
M(&5I=&AE<B!A;B!E<G)O<B!O<B!T:&4@=')U92!R97-U;'0L"B`@("`@("`@
M("`@("\O('=E(&-A;B!J=7-T(')E='5R;B!I=`H@("`@("`@("`@("!R971U
M<FX@)&-O=6YT<FEE<SL*("`@("`@("!]"@H@("`@("`@("\O($YO=R!F;W(@
M=&AE(')E86P@<V5A<F-H"B`@("`@("`@)'-E;&5C="`](")314Q%0U0@:6-A
M;RP@;F%M92P@<W1A=&4L(&-O=6YT<GD@(BX*("`@("`@("`@("`@("`@("`@
M(D923TT@;65T87)!:7)P;W)T<R`B+@H@("`@("`@("`@("`@("`@("`B5TA%
M4D4@3$]715(H8V]U;G1R>2D@3$E+12`G)2(N<W1R=&]L;W=E<BAT<FEM*"1C
M;W5N=')Y*2DN(B4G("(N"B`@("`@("`@("`@("`@("`@(")/4D1%4B!"62!N
M86UE($%30R(["B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y
M*"1S96QE8W0I.PH@("`@("`@("\O($-H96-K(')E<W5L="!F;W(@=F%L:61I
M='D*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?2!E;'-E:68@*'-T<G1O
M;&]W97(H9V5T7V-L87-S*"1R97-U;'0I*2`A/2`B9&)?<F5S=6QT(B!\?"`D
M<F5S=6QT+3YN=6U2;W=S*"D@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@
M4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$52
M7T524D]27U5.2TY/5TY?3$]#051)3TXL(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@?0H*("`@("`@("`O+R!#;VYS=')U8W0@=&AE(')E<W5L=`H@
M("`@("`@("1L;V-A=&EO;G,@/2!A<G)A>2@I.PH@("`@("`@('=H:6QE("@H
M)')O=R`]("1R97-U;'0M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]!4U-/0RDI
M("$](&YU;&PI('L*("`@("`@("`@("`@)&QO8VEC86\@/2`D<F]W6R)I8V%O
M(ET["B`@("`@("`@("`@(&EF("@D;&]C:6-A;R`A/2`B+2TM+2(I('L*("`@
M("`@("`@("`@("`@("\O($9I<G-T('1H92!N86UE(&]F('1H92!L;V-A=&EO
M;@H@("`@("`@("`@("`@("`@:68@*"%S=')L96XH)')O=ULB<W1A=&4B72DI
M('L*("`@("`@("`@("`@("`@("`@("`D;&]C;F%M92`]("1R;W=;(FYA;64B
M72XB+"`B+B1R;W=;(F-O=6YT<GDB73L*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)&QO8VYA;64@/2`D<F]W6R)N86UE
M(ETN(BP@(BXD<F]W6R)S=&%T92)=+B(L("(N)')O=ULB8V]U;G1R>2)=.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&QO8V%T:6]N<ULD
M;&]C:6-A;UT@/2`D;&]C;F%M93L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1L;V-A=&EO;G,["B`@("!]"B`@("`O+R!]?7T*
M"B`@("`O+R![>WL@<V5A<F-H06ER<&]R="@I"B`@("`O*BH*("`@("`J(%-E
M87)C:&5S('1H92!N96%R97-T(&%I<G!O<G0H<RD@9F]R(&=I=F5N(&-O;W)D
M:6YA=&5S+"!R971U<FYS(&%R<F%Y"B`@("`@*B!O9B!)1',@;W(@<VEN9VQE
M($E$"B`@("`@*@H@("`@("H@0'!A<F%M("`@9FQO870@("`@("`@("`@("`@
M("`@("`@("`@("1L871I='5D90H@("`@("H@0'!A<F%M("`@9FQO870@("`@
M("`@("`@("`@("`@("`@("`@("1L;VYG:71U9&4*("`@("`J($!P87)A;2`@
M(&EN="`@("`@("`@("`@("`@("`@("`@("`@("`D;G5M4F5S=6QT<PH@("`@
M("H@0')E='5R;B`@4$5!4E]%<G)O<GQA<G)A>7QS=')I;F<*("`@("`J($!T
M:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?54Y+
M3D]73E],3T-!5$E/3@H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<CHZ4T52
M5DE#15-?5T5!5$A%4E]%4E)/4E]$0E].3U1?0T].3D5#5$5$"B`@("`@*B!`
M=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$527T524D]27TE.
M5D%,241?3$]#051)3TX*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!S96%R8VA!:7)P;W)T*"1L871I='5D92P@)&QO;F=I
M='5D92P@)&YU;5)E<W5L=',@/2`Q*0H@("`@>PH@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]D8BD@?'P@(41".CII<T-O;FYE8W1I;VXH)'1H:7,M/E]D
M8BDI('L*("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A
M:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E]$0E].3U1?0T].3D5#
M5$5$+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@("`@("!I
M9B`H(6ES7VYU;65R:6,H)&QA=&ET=61E*2!\?"`A:7-?;G5M97)I8R@D;&]N
M9VET=61E*2D@>PH@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE
M<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]27TE.5D%,241?
M3$]#051)3TXL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@
M("`@("`O+R!'970@86QL(&%I<G!O<G1S"B`@("`@("`@)'-E;&5C="`](")3
M14Q%0U0@:6-A;RP@>"P@>2P@>B!&4D]-(&UE=&%R06ER<&]R=',B.PH@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<V5L96-T*3L*("`@
M("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@?2!E;'-E:68@*'-T<G1O;&]W97(H
M9V5T7V-L87-S*"1R97-U;'0I*2`A/2`B9&)?<F5S=6QT(B!\?"`D<F5S=6QT
M+3YN=6U2;W=S*"D@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@4V5R=FEC
M97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]2
M7U5.2TY/5TY?3$]#051)3TXL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@?0H*("`@("`@("`O+R!297-U;'0@:7,@=F%L:60L('-T87)T('-E87)C
M:`H@("`@("`@("\O($EN:71I86QI>F4@=F%L=65S"B`@("`@("`@)&UI;E]D
M:7-T(#T@;G5L;#L*("`@("`@("`D<75E<GD@("`@/2`D=&AI<RT^<&]L87(R
M8V%R=&5S:6%N*"1L871I='5D92P@)&QO;F=I='5D92D["B`@("`@("`@)'-E
M87)C:"`@(#T@87)R87DH(F1I<W0B(#T^(&%R<F%Y*"DL(")I8V%O(B`]/B!A
M<G)A>2@I*3L*("`@("`@("!W:&EL92`H*"1R;W<@/2`D<F5S=6QT+3YF971C
M:%)O=RA$0E]&151#2$U/1$5?05-33T,I*2`A/2!N=6QL*2!["B`@("`@("`@
M("`@("1I8V%O(#T@)')O=ULB:6-A;R)=.PH@("`@("`@("`@("`D86ER("`]
M(&%R<F%Y*"1R;W=;(G@B72P@)')O=ULB>2)=+"`D<F]W6R)Z(ETI.PH*("`@
M("`@("`@("`@)&1I<W0@/2`P.PH@("`@("`@("`@("`D9"`](#`["B`@("`@
M("`@("`@("\O($-A;&-U;&%T92!D:7-T86YC92!O9B!Q=65R>2!A;F0@8W5R
M<F5N="!A:7)P;W)T"B`@("`@("`@("`@("\O(&)R96%K(&]F9BP@:68@9&ES
M=&%N8V4@:7,@;&%R9V5R('1H86X@8W5R<F5N="`D;6EN7V1I<W0*("`@("`@
M("`@("`@9F]R*"1D.R`D9"`\('-I>F5O9B@D86ER*3L@)&0K*RD@>PH@("`@
M("`@("`@("`@("`@)'0@/2`D86ER6R1D72`M("1Q=65R>5LD9%T["B`@("`@
M("`@("`@("`@("`D9&ES="`K/2!P;W<H)'0L(#(I.PH@("`@("`@("`@("`@
M("`@:68@*"1M:6Y?9&ES="`A/2!N=6QL("8F("1D:7-T(#X@)&UI;E]D:7-T
M*2!["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D9"`^/2!S:7IE
M;V8H)&%I<BDI('L*("`@("`@("`@("`@("`@("\O($]K+"!C=7)R96YT(&%I
M<G!O<G0@:7,@;VYE(&]F('1H92!N96%R97(@;&]C871I;VYS"B`@("`@("`@
M("`@("`@("`O+R!A9&0@=&\@<F5S=6QT+6%R<F%Y"B`@("`@("`@("`@("`@
M("`D<V5A<F-H6R)D:7-T(EU;72`]("1D:7-T.PH@("`@("`@("`@("`@("`@
M)'-E87)C:%LB:6-A;R)=6UT@/2`D:6-A;SL*("`@("`@("`@("`@("`@("\O
M(%-O<G0@87)R87D@9F]R(&1I<W1A;F-E"B`@("`@("`@("`@("`@("!A<G)A
M>5]M=6QT:7-O<G0H)'-E87)C:%LB9&ES=")=+"!33U)47TY5345224,L(%-/
M4E1?05-#+"`D<V5A<F-H6R)I8V%O(ETL(%-/4E1?4U1224Y'+"!33U)47T%3
M0RD["B`@("`@("`@("`@("`@("`O+R!)9B!A<G)A>2!I<R!L87)G97(@=&AE
M;B!D97-I<F5D(')E<W5L=',L(&-H;W`@;V9F(&QA<W0@;VYE"B`@("`@("`@
M("`@("`@("!I9B`H<VEZ96]F*"1S96%R8VA;(F1I<W0B72D@/B`D;G5M4F5S
M=6QT<RD@>PH@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!O<"@D<V5A<F-H
M6R)D:7-T(ETI.PH@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!O<"@D<V5A
M<F-H6R)I8V%O(ETI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)&UI;E]D:7-T(#T@;6%X*"1S96%R8VA;(F1I<W0B72D["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"1N=6U297-U;'1S(#T](#$I
M('L*("`@("`@("`@("`@+R\@3VYL>2!O;F4@<F5S=6QT('=A;G1E9"P@<F5T
M=7)N(&%S('-T<FEN9PH@("`@("`@("`@("!R971U<FX@)'-E87)C:%LB:6-A
M;R)=6S!=.PH@("`@("`@('T@96QS96EF("@D;G5M4F5S=6QT<R`^(#$I('L*
M("`@("`@("`@("`@+R\@4F5T=7)N(&9O=6YD(&QO8V%T:6]N<PH@("`@("`@
M("`@("!R971U<FX@)'-E87)C:%LB:6-A;R)=.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R
M<F]R*%-%4E9)0T537U=%051(15)?15)23U)?54Y+3D]73E],3T-!5$E/3BP@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("!]"B`@("`O+R!]
M?7T*"B`@("`O+R![>WL@9V5T3&]C871I;VXH*0H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!D871A(&9O<B!T:&4@;&]C871I;VX@8F5L;VYG:6YG('1O
M('1H92!)1`H@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@
M("`@("`@("`@("`@("`D:60*("`@("`J($!R971U<FX@(%!%05)?17)R;W)\
M87)R87D*("`@("`J($!T:')O=W,@(%!%05)?17)R;W(*("`@("`J($!A8V-E
M<W,@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971,;V-A=&EO;B@D
M:60@/2`B(BD*("`@('L*("`@("`@("`D<W1A='5S(#T@)'1H:7,M/E]C:&5C
M:TQO8V%T:6]N240H)&ED*3L*"B`@("`@("`@:68@*%-E<G9I8V5S7U=E871H
M97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@("`@("`@("`@<F5T=7)N("1S
M=&%T=7,["B`@("`@("`@?0H*("`@("`@("`D;&]C871I;VY2971U<FX@/2!A
M<G)A>2@I.PH*("`@("`@("!I9B`H)'1H:7,M/E]C86-H945N86)L960@)B8@
M*"1L;V-A=&EO;B`]("1T:&ES+3Y?8V%C:&4M/F=E="@B345405(M(BXD:60L
M(")L;V-A=&EO;B(I*2D@>PH@("`@("`@("`@("`O+R!'<F%B('-T=69F(&9R
M;VT@8V%C:&4*("`@("`@("`@("`@)'1H:7,M/E]L;V-A=&EO;B`]("1L;V-A
M=&EO;CL*("`@("`@("`@("`@)&QO8V%T:6]N4F5T=7)N6R)C86-H92)=(#T@
M(DA)5"(["B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3Y?9&(I("8F
M($1".CII<T-O;FYE8W1I;VXH)'1H:7,M/E]D8BDI('L*("`@("`@("`@("`@
M+R\@1V5T(&1A=&$@9G)O;2!$0@H@("`@("`@("`@("`D<V5L96-T(#T@(E-%
M3$5#5"!I8V%O+"!N86UE+"!S=&%T92P@8V]U;G1R>2P@;&%T:71U9&4L(&QO
M;F=I='5D92P@96QE=F%T:6]N("(N"B`@("`@("`@("`@("`@("`@("`@("`B
M1E)/32!M971A<D%I<G!O<G1S(%=(15)%(&EC86\])R(N)&ED+B(G(CL*("`@
M("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1S96QE8W0I
M.PH*("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?2!E
M;'-E:68@*'-T<G1O;&]W97(H9V5T7V-L87-S*"1R97-U;'0I*2`A/2`B9&)?
M<F5S=6QT(B!\?"`D<F5S=6QT+3YN=6U2;W=S*"D@/3T@,"D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H
M4T525DE#15-?5T5!5$A%4E]%4E)/4E]53DM.3U=.7TQ/0T%424].+"!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("\O
M(%)E<W5L="!I<R!O:RP@<'5T('1H:6YG<R!I;G1O(&]B:F5C=`H@("`@("`@
M("`@("`D=&AI<RT^7VQO8V%T:6]N(#T@)')E<W5L="T^9F5T8VA2;W<H1$)?
M1D540TA-3T1%7T%34T]#*3L*"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V-A
M8VAE16YA8FQE9"D@>PH@("`@("`@("`@("`@("`@+R\@+BXN86YD(&-A8VAE
M(&ET"B`@("`@("`@("`@("`@("`D97AP:7)E(#T@8V]N<W1A;G0H(E-%4E9)
M0T537U=%051(15)?15A025)%4U],3T-!5$E/3B(I.PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]C86-H92T^97AT4V%V92@B345405(M(BXD:60L("1T:&ES
M+3Y?;&]C871I;VXL("(B+"`D97AP:7)E+"`B;&]C871I;VXB*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)&QO8V%T:6]N4F5T=7)N6R)C86-H92)=
M(#T@(DU)4U,B.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES
M+3Y?;&]C871I;VX@/2!A<G)A>2@*("`@("`@("`@("`@("`@(")N86UE(B`@
M("`@(#T^("1I9"P*("`@("`@("`@("`@("`@(")S=&%T92(@("`@(#T^("(B
M+`H@("`@("`@("`@("`@("`@(F-O=6YT<GDB("`@/3X@(B(L"B`@("`@("`@
M("`@("`@("`B;&%T:71U9&4B("`]/B`B(BP*("`@("`@("`@("`@("`@(")L
M;VYG:71U9&4B(#T^("(B+`H@("`@("`@("`@("`@("`@(F5L979A=&EO;B(@
M/3X@(B(*("`@("`@("`@("`@*3L*("`@("`@("!]"B`@("`@("`@+R\@4W1U
M9F8@;F%M92US=')I;F<@=&]G971H97(*("`@("`@("!I9B`H<W1R;&5N*"1T
M:&ES+3Y?;&]C871I;VY;(G-T871E(ETI("8F('-T<FQE;B@D=&AI<RT^7VQO
M8V%T:6]N6R)C;W5N=')Y(ETI*2!["B`@("`@("`@("`@("1L;V-N86UE(#T@
M)'1H:7,M/E]L;V-A=&EO;ELB;F%M92)=+B(L("(N)'1H:7,M/E]L;V-A=&EO
M;ELB<W1A=&4B72XB+"`B+B1T:&ES+3Y?;&]C871I;VY;(F-O=6YT<GDB73L*
M("`@("`@("!](&5L<V5I9B`H<W1R;&5N*"1T:&ES+3Y?;&]C871I;VY;(F-O
M=6YT<GDB72DI('L*("`@("`@("`@("`@)&QO8VYA;64@/2`D=&AI<RT^7VQO
M8V%T:6]N6R)N86UE(ETN(BP@(BXD=&AI<RT^7VQO8V%T:6]N6R)C;W5N=')Y
M(ET["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&QO8VYA;64@/2`D
M=&AI<RT^7VQO8V%T:6]N6R)N86UE(ET["B`@("`@("`@?0H@("`@("`@("1L
M;V-A=&EO;E)E='5R;ELB;F%M92)=("`@("`@/2`D;&]C;F%M93L*("`@("`@
M("`D;&]C871I;VY2971U<FY;(FQA=&ET=61E(ET@(#T@)'1H:7,M/E]L;V-A
M=&EO;ELB;&%T:71U9&4B73L*("`@("`@("`D;&]C871I;VY2971U<FY;(FQO
M;F=I='5D92)=(#T@)'1H:7,M/E]L;V-A=&EO;ELB;&]N9VET=61E(ET["B`@
M("`@("`@)&QO8V%T:6]N4F5T=7)N6R)S=6YR:7-E(ET@("`](&1A=&4H)'1H
M:7,M/E]T:6UE1F]R;6%T+"`D=&AI<RT^8V%L8W5L871E4W5N4FES95-E="AG
M;6UK=&EM92@I+"!354Y&54Y#4U]2151?5$E-15-404U0+"`D=&AI<RT^7VQO
M8V%T:6]N6R)L871I='5D92)=+"`D=&AI<RT^7VQO8V%T:6]N6R)L;VYG:71U
M9&4B72P@4T525DE#15-?5T5!5$A%4E]354Y&54Y#4U]354Y225-%7UI%3DE4
M2"P@,"P@=')U92DI.PH@("`@("`@("1L;V-A=&EO;E)E='5R;ELB<W5N<V5T
M(ET@("`@/2!D871E*"1T:&ES+3Y?=&EM949O<FUA="P@)'1H:7,M/F-A;&-U
M;&%T95-U;E)I<V53970H9VUM:W1I;64H*2P@4U5.1E5.0U-?4D547U1)3453
M5$%-4"P@)'1H:7,M/E]L;V-A=&EO;ELB;&%T:71U9&4B72P@)'1H:7,M/E]L
M;V-A=&EO;ELB;&]N9VET=61E(ETL(%-%4E9)0T537U=%051(15)?4U5.1E5.
M0U-?4U5.4T547UI%3DE42"P@(#`L(&9A;'-E*2D["B`@("`@("`@)&QO8V%T
M:6]N4F5T=7)N6R)E;&5V871I;VXB72`]("1T:&ES+3Y?;&]C871I;VY;(F5L
M979A=&EO;B)=.PH*("`@("`@("!R971U<FX@)&QO8V%T:6]N4F5T=7)N.PH@
M("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&=E=%=E871H97(H*0H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!W96%T:&5R+61A=&$@9F]R('1H92!S
M=7!P;&EE9"!L;V-A=&EO;@H@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN
M9R`@("`@("`@("`@("`@("`@("`@("`D:60*("`@("`J($!P87)A;2`@('-T
M<FEN9R`@("`@("`@("`@("`@("`@("`@("`D=6YI='-&;W)M870*("`@("`J
M($!R971U<FX@(%!(4%]%<G)O<GQA<G)A>0H@("`@("H@0'1H<F]W<R`@4$A0
M7T5R<F]R"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T5V5A=&AE<B@D:60@/2`B(BP@)'5N:71S1F]R;6%T(#T@(B(I
M"B`@("!["B`@("`@("`@)&ED("`@("`]('-T<G1O=7!P97(H)&ED*3L*("`@
M("`@("`D<W1A='5S(#T@)'1H:7,M/E]C:&5C:TQO8V%T:6]N240H)&ED*3L*
M"B`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-T871U
M<RDI('L*("`@("`@("`@("`@<F5T=7)N("1S=&%T=7,["B`@("`@("`@?0H*
M("`@("`@("`O+R!'970@;W1H97(@9&%T80H@("`@("`@("1U;FET<R`@("`]
M("1T:&ES+3YG9715;FET<T9O<FUA="@D=6YI='-&;W)M870I.PH@("`@("`@
M("1L;V-A=&EO;B`]("1T:&ES+3YG971,;V-A=&EO;B@D:60I.PH*("`@("`@
M("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D;&]C871I;VXI*2![
M"B`@("`@("`@("`@(')E='5R;B`D;&]C871I;VX["B`@("`@("`@?0H*("`@
M("`@("!I9B`H)'1H:7,M/E]C86-H945N86)L960@)B8@*"1W96%T:&5R(#T@
M)'1H:7,M/E]C86-H92T^9V5T*")-151!4BTB+B1I9"P@(G=E871H97(B*2DI
M('L*("`@("`@("`@("`@+R\@5V5E+BXN(&ET('=A<R!C86-H960L(&QE="=S
M(&AA=F4@:70N+BX*("`@("`@("`@("`@)'=E871H97)2971U<FX@(#T@)'=E
M871H97(["B`@("`@("`@("`@("1T:&ES+3Y?=V5A=&AE<B`]("1W96%T:&5R
M4F5T=7)N.PH@("`@("`@("`@("`D=V5A=&AE<E)E='5R;ELB8V%C:&4B72`]
M(")(250B.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O($1O=VYL
M;V%D('=E871H97(*("`@("`@("`@("`@)'=E871H97)$871A(#T@)'1H:7,M
M/E]R971R:65V95-E<G9E<D1A=&$H)&ED+"`B;65T87(B*3L*("`@("`@("`@
M("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'=E871H97)$871A
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1W96%T:&5R1&%T83L*("`@
M("`@("`@("`@?2!E;'-E:68@*"%I<U]A<G)A>2@D=V5A=&AE<D1A=&$I('Q\
M('-I>F5O9B@D=V5A=&AE<D1A=&$I(#P@,BD@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?
M5T5!5$A%4E]%4E)/4E]74D].1U]315)615)?1$%402P@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@4&%R<V4@
M=V5A=&AE<@H@("`@("`@("`@("`D=V5A=&AE<E)E='5R;B`@/2`D=&AI<RT^
M7W!A<G-E5V5A=&AE<D1A=&$H)'=E871H97)$871A*3L*"B`@("`@("`@("`@
M(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1W96%T:&5R4F5T=7)N
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1W96%T:&5R4F5T=7)N.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!!9&0@86X@:6-O;B!F;W(@
M=&AE(&-U<G)E;G0@8V]N9&ET:6]N<PH@("`@("`@("`@("`O+R!$971E<FUI
M;F4@:68@8V5R=&%I;B!V86QU97,@87)E('-E="P@:68@;F]T('5S92!D969A
M=6QT<PH@("`@("`@("`@("`D8V]N9&ET:6]N("`@/2!I<W-E="@D=V5A=&AE
M<E)E='5R;ELB8V]N9&ET:6]N(ETI("`@/R`D=V5A=&AE<E)E='5R;ELB8V]N
M9&ET:6]N(ET@("`Z(").;R!3:6=N:69I8V%N="!796%T:&5R(CL*("`@("`@
M("`@("`@)&-L;W5D<R`@("`@(#T@:7-S970H)'=E871H97)2971U<FY;(F-L
M;W5D<R)=*2`@("`@(#\@)'=E871H97)2971U<FY;(F-L;W5D<R)=("`@("`@
M.B`@("`@("`@("`@("`@("`@(&%R<F%Y*"D["B`@("`@("`@("`@("1W:6YD
M("`@("`@("`](&ES<V5T*"1W96%T:&5R4F5T=7)N6R)W:6YD(ETI("`@("`@
M("`_("1W96%T:&5R4F5T=7)N6R)W:6YD(ET@("`@("`@(#H@("`@("`@("`@
M("`@("`@("`@("`@("`U.R`*("`@("`@("`@("`@)'1E;7!E<F%T=7)E(#T@
M:7-S970H)'=E871H97)2971U<FY;(G1E;7!E<F%T=7)E(ETI(#\@)'=E871H
M97)2971U<FY;(G1E;7!E<F%T=7)E(ET@.B`@("`@("`@("`@("`@("`@("`@
M("`@-S`[(`H@("`@("`@("`@("`D;&%T:71U9&4@("`@/2!I<W-E="@D;&]C
M871I;VY;(FQA=&ET=61E(ETI("`@("`@("`@/R`D;&]C871I;VY;(FQA=&ET
M=61E(ET@("`@("`@("`Z("`@("`@("`@("`@("`@("`@("`@+3,V,#L*("`@
M("`@("`@("`@)&QO;F=I='5D92`@(#T@:7-S970H)&QO8V%T:6]N6R)L;VYG
M:71U9&4B72D@("`@("`@(#\@)&QO8V%T:6]N6R)L;VYG:71U9&4B72`@("`@
M("`@.B`@("`@("`@("`@("`@("`@("`@("TS-C`["B`@("`@("`@("`@(`H@
M("`@("`@("`@("`O+R!'970@=&AE(&EC;VX*("`@("`@("`@("`@)'=E871H
M97)2971U<FY;(F-O;F1I=&EO;DEC;VXB72`]("1T:&ES+3YG971796%T:&5R
M26-O;B@D8V]N9&ET:6]N+"`D8VQO=61S+"`D=VEN9"P@)'1E;7!E<F%T=7)E
M+"`D;&%T:71U9&4L("1L;VYG:71U9&4I.PH*("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?8V%C:&5%;F%B;&5D*2!["B`@("`@("`@("`@("`@("`O+R!#86-H
M92!W96%T:&5R"B`@("`@("`@("`@("`@("`D97AP:7)E(#T@8V]N<W1A;G0H
M(E-%4E9)0T537U=%051(15)?15A025)%4U]714%42$52(BD["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V-A8VAE+3YE>'13879E*")-151!4BTB+B1I9"P@
M)'=E871H97)2971U<FXL("1U;FET<T9O<FUA="P@)&5X<&ER92P@(G=E871H
M97(B*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7W=E871H
M97(@/2`D=V5A=&AE<E)E='5R;CL*("`@("`@("`@("`@)'=E871H97)2971U
M<FY;(F-A8VAE(ET@/2`B34E34R(["B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^7V-O;G9E<G12971U<FXH)'=E871H97)2971U<FXL("1U;FET<RP@)&QO
M8V%T:6]N*3L*"B`@("`@("`@<F5T=7)N("1W96%T:&5R4F5T=7)N.PH@("`@
M?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&=E=$9O<F5C87-T*"D*("`@("\J
M*@H@("`@("H@345405(@<')O=FED97,@;F\@9F]R96-A<W0@<&5R('-E+"!W
M92!U<V4@=&AE(%1!1B!R97!O<G1S('1O(&=E;F5R871E"B`@("`@*B!A(&9O
M<F5C87-T(&9O<B!T:&4@86YN;W5N8V5D('1I;65P97)I;V0*("`@("`J"B`@
M("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)&ED
M"B`@("`@*B!`<&%R86T@("!I;G0@("`@("`@("`@("`@("`@("`@("`@("`@
M)&1A>7,@("`@("`@("`@($EG;F]R960L(&YO="!A<'!L:6-A8FQE"B`@("`@
M*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)'5N:71S
M1F]R;6%T"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&%R<F%Y"B`@("`@
M*B!`=&AR;W=S("!014%27T5R<F]R"B`@("`@*B!`86-C97-S("!P=6)L:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1F]R96-A<W0H)&ED(#T@(B(L("1D
M87ES(#T@;G5L;"P@)'5N:71S1F]R;6%T(#T@(B(I"B`@("!["B`@("`@("`@
M)&ED("`@("`]('-T<G1O=7!P97(H)&ED*3L*("`@("`@("`D<W1A='5S(#T@
M)'1H:7,M/E]C:&5C:TQO8V%T:6]N240H)&ED*3L*"B`@("`@("`@:68@*%-E
M<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1S=&%T=7,["B`@("`@("`@?0H*("`@("`@("`O+R!'970@
M;W1H97(@9&%T80H@("`@("`@("1U;FET<R`@("`]("1T:&ES+3YG9715;FET
M<T9O<FUA="@D=6YI='-&;W)M870I.PH@("`@("`@("1L;V-A=&EO;B`]("1T
M:&ES+3YG971,;V-A=&EO;B@D:60I.PH*("`@("`@("!I9B`H4V5R=FEC97-?
M5V5A=&AE<CHZ:7-%<G)O<B@D;&]C871I;VXI*2!["B`@("`@("`@("`@(')E
M='5R;B`D;&]C871I;VX["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M
M/E]C86-H945N86)L960@)B8@*"1F;W)E8V%S="`]("1T:&ES+3Y?8V%C:&4M
M/F=E="@B345405(M(BXD:60L(")F;W)E8V%S="(I*2D@>PH@("`@("`@("`@
M("`O+R!7964N+BX@:70@=V%S(&-A8VAE9"P@;&5T)W,@:&%V92!I="XN+@H@
M("`@("`@("`@("`D9F]R96-A<W12971U<FX@(#T@)&9O<F5C87-T.PH@("`@
M("`@("`@("`D=&AI<RT^7V9O<F5C87-T(#T@)&9O<F5C87-T4F5T=7)N.PH@
M("`@("`@("`@("`D9F]R96-A<W12971U<FY;(F-A8VAE(ET@/2`B2$E4(CL*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!$;W=N;&]A9"!F;W)E
M8V%S=`H@("`@("`@("`@("`D9F]R96-A<W1$871A(#T@)'1H:7,M/E]R971R
M:65V95-E<G9E<D1A=&$H)&ED+"`B=&%F(BD["B`@("`@("`@("`@(&EF("A3
M97)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1F;W)E8V%S=$1A=&$I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)&9O<F5C87-T1&%T83L*("`@("`@("`@
M("`@?2!E;'-E:68@*"%I<U]A<G)A>2@D9F]R96-A<W1$871A*2!\?"!S:7IE
M;V8H)&9O<F5C87-T1&%T82D@/"`R*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%4
M2$527T524D]27U=23TY'7U-%4E9%4E]$051!+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!087)S92!F;W)E
M8V%S=`H@("`@("`@("`@("`D9F]R96-A<W12971U<FX@(#T@)'1H:7,M/E]P
M87)S949O<F5C87-T1&%T82@D9F]R96-A<W1$871A*3L*"B`@("`@("`@("`@
M(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1F;W)E8V%S=%)E='5R
M;BDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D9F]R96-A<W12971U<FX[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%
M;F%B;&5D*2!["B`@("`@("`@("`@("`@("`O+R!#86-H92!W96%T:&5R"B`@
M("`@("`@("`@("`@("`D97AP:7)E(#T@8V]N<W1A;G0H(E-%4E9)0T537U=%
M051(15)?15A025)%4U]&3U)%0T%35"(I.PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]C86-H92T^97AT4V%V92@B345405(M(BXD:60L("1F;W)E8V%S=%)E
M='5R;BP@)'5N:71S1F]R;6%T+"`D97AP:7)E+"`B9F]R96-A<W0B*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V9O<F5C87-T(#T@)&9O
M<F5C87-T4F5T=7)N.PH@("`@("`@("`@("`D9F]R96-A<W12971U<FY;(F-A
M8VAE(ET@/2`B34E34R(["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-O
M;G9E<G12971U<FXH)&9O<F5C87-T4F5T=7)N+"`D=6YI=',L("1L;V-A=&EO
M;BD["@H@("`@("`@(')E='5R;B`D9F]R96-A<W12971U<FX["B`@("!]"B`@
M("`O+R!]?7T*?0HO+R!]?7T*/SX*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+U-E<G9I8V5S+U=E871H97(O5V5A=&AE<F1O=&-O;2YP:'``````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#8S,#$P`#$P-3$U-#,S-S,T`#`R-3,P-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*B!V
M:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T
M=&%B<W1O<#TT(&9O;&1M971H;V0];6%R:V5R.B`J+PH*+RHJ"B`J(%!%05(Z
M.E-E<G9I8V5S7U=E871H97)?5V5A=&AE<F1O=&-O;0H@*@H@*B!02%`@=F5R
M<VEO;G,@-"!A;F0@-0H@*@H@*B`\3$E#14Y313X*("H@0V]P>7)I9VAT("AC
M*2`R,#`U+"!!;&5X86YD97(@5VER='H*("H@06QL(')I9VAT<R!R97-E<G9E
M9"X*("H*("H@4F5D:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@86YD
M(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T"B`J(&UO9&EF:6-A=&EO
M;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@
M8V]N9&ET:6]N<PH@*B!A<F4@;65T.@H@*B!O(%)E9&ES=')I8G5T:6]N<R!O
M9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT
M(&YO=&EC92P*("H@("!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE
M(&9O;&QO=VEN9R!D:7-C;&%I;65R+@H@*B!O(%)E9&ES=')I8G5T:6]N<R!I
M;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I
M9VAT(&YO=&EC92P*("H@("!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@
M=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN('1H92!D;V-U;65N=&%T:6]N
M"B`J("`@86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H
M92!D:7-T<FEB=71I;VXN"B`J(&\@3F5I=&AE<B!T:&4@;F%M92!O9B!T:&4@
M<V]F='=A<F4@;F]R('1H92!N86UE<R!O9B!I=',@8V]N=')I8G5T;W)S"B`J
M("`@;6%Y(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E('!R;V1U8W1S
M(&1E<FEV960@9G)O;2!T:&ES('-O9G1W87)E"B`J("`@=VET:&]U="!S<&5C
M:69I8R!P<FEO<B!W<FET=&5N('!E<FUI<W-I;VXN"B`J"B`J(%1(25,@4T]&
M5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.
M1"!#3TY44DE"551/4E,@(D%3($E3(@H@*B!!3D0@04Y9($584%)%4U,@3U(@
M24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0@3$E-251%
M1"!43RP@5$A%"B`J($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"
M24Q)5%D@04Y$($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%"B`J
M($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@0T]065))
M1TA4($]73D52($]2($-/3E1224)55$]24R!"10H@*B!,24%"3$4@1D]2($%.
M62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!34$5#24%,+"!%6$5-
M4$Q!4EDL($]2"B`J($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'
M+"!"550@3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&"B`J(%-50E-4
M25155$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%+"!$051!+"!/
M4B!04D]&2513.R!/4B!"55-)3D534PH@*B!)3E1%4E)54%1)3TXI($A/5T56
M15(@0T%54T5$($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)04))3$E462P@5TA%
M5$A%4B!)3@H@*B!#3TY44D%#5"P@4U1224-4($Q)04))3$E462P@3U(@5$]2
M5"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*0H@*B!!4DE3
M24Y'($E.($%.62!705D@3U54($]&(%1(12!54T4@3T8@5$A)4R!33T945T%2
M12P@159%3B!)1B!!1%9)4T5$($]&(%1(10H@*B!03U-324))3$E462!/1B!3
M54-(($1!34%'12X*("H@/"],24-%3E-%/@H@*@H@*B!`8V%T96=O<GD@("`@
M5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@("!397)V:6-E<U]796%T:&5R
M"B`J($!A=71H;W(@("`@("!!;&5X86YD97(@5VER='H@/&%L97A`<&,T<"YN
M970^"B`J($!C;W!Y<FEG:'0@("`R,#`U($%L97AA;F1E<B!7:7)T>@H@*B!`
M;&EC96YS92`@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E
M<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@
M("!#5E,Z("1)9#H@5V5A=&AE<F1O=&-O;2YP:'`L=B`Q+C4X(#(P,#4O,3$O
M,3<@,#@Z,3DZ-#(@97)U($5X<"`D"B`J($!L:6YK("`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O4V5R=FEC97-?5V5A=&AE<@H@*B!`;&EN
M:R`@("`@("`@:'1T<#HO+W=W=RYW96%T:&5R+F-O;2]S97)V:6-E<R]X;6QO
M87`N:'1M;`H@*B!`97AA;7!L92`@("`@97AA;7!L97,O=V5A=&AE<BYC;VTM
M8F%S:6,N<&AP("`@("`@=V5A=&AE<BYC;VTM8F%S:6,N<&AP"B`J($!E>&%M
M<&QE("`@("!E>&%M<&QE<R]W96%T:&5R+F-O;2UE>'1E;G-I=F4N<&AP("!W
M96%T:&5R+F-O;2UE>'1E;G-I=F4N<&AP"B`J($!F:6QE<V]U<F-E"B`J+PH*
M<F5Q=6ER95]O;F-E(")397)V:6-E<R]796%T:&5R+T-O;6UO;BYP:'`B.PH*
M+R\@>WM[(&-L87-S(%-E<G9I8V5S7U=E871H97)?5V5A=&AE<F1O=&-O;0HO
M*BH*("H@5&AI<R!C;&%S<R!A8W1S(&%S(&%N(&EN=&5R9F%C92!T;R!T:&4@
M>&UL('-E<G9I8V4@;V8@=V5A=&AE<BYC;VTN($ET"B`J('-E87)C:&5S(&9O
M<B!G:79E;B!L;V-A=&EO;G,@86YD(')E=')I979E<R!C=7)R96YT('=E871H
M97(@9&%T82!A<R!W96QL"B`J(&%S(&9O<F5C87-T(&9O<B!U<"!T;R`Q,"!D
M87ES+@H@*@H@*B!&;W(@=7-I;F<@=&AE('=E871H97(N8V]M('AM;"US97)V
M:6-E('!L96%S92!V:7-I=`H@*B`@("`@:'1T<#HO+W=W=RYW96%T:&5R+F-O
M;2]S97)V:6-E<R]X;6QO87`N:'1M;`H@*B!A;F0@9F]L;&]W('1H92!L:6YK
M('1O('-I9VX@=7`L(&ET)W,@9G)E92$@66]U('=I;&P@<F5C96EV92!A;B!E
M;6%I;`H@*B!W:&5R92!T;R!D;W=N;&]A9"!T:&4@4T1+('=I=&@@=&AE(&YE
M961E9"!I;6%G97,@86YD(&=U:61E;&EN97,@:&]W('1O"B`J('!U8FQI<V@@
M;&EV92!D871A(&9R;VT@=V5A=&AE<BYC;VTN(%5N9F]R='5N871E;'D@=&AE
M(&=U:61E;&EN97,@87)E(&$*("H@8FET(&AA<G-H+"!T:&%T)W,@=VAY('1H
M97)E)W,@;F\@86-T=6%L(&1A=&$M<F5P<F5S96YT871I;VX@:6X@=&AI<PH@
M*B!C;&%S<RP@:G5S="!T:&4@<F%W(&1A=&$N($%L<V\@=V5A=&AE<BYC;VT@
M9&5M86YD<R!A8W1I=F4@8V%C:&EN9RP@<V\@22=D"B`J('-T<F]N9VQY(')E
M8V]M;65N9"!E;F%B;&EN9R!T:&4@8V%C:&EN9R!I;7!L96UE;G1E9"!I;B!T
M:&ES(&-L87-S+B!)=`H@*B!O8F5Y<R!T;R!T:&4@=&EM97,@87,@=W)I='1E
M;B!D;W=N(&EN('1H92!G=6ED96QI;F5S+@H@*@H@*B!&;W(@=V]R:VEN9R!E
M>&%M<&QE<RP@<&QE87-E('1A:V4@82!L;V]K(&%T"B`J("`@("!D;V-S+U-E
M<G9I8V5S7U=E871H97(O97AA;7!L97,O=V5A=&AE<BYC;VTM8F%S:6,N<&AP
M"B`J("`@("!D;V-S+U-E<G9I8V5S7U=E871H97(O97AA;7!L97,O=V5A=&AE
M<BYC;VTM97AT96YS:79E+G!H<`H@*@H@*B!`8V%T96=O<GD@("`@5V5B(%-E
M<G9I8V5S"B`J($!P86-K86=E("`@("!397)V:6-E<U]796%T:&5R"B`J($!A
M=71H;W(@("`@("!!;&5X86YD97(@5VER='H@/&%L97A`<&,T<"YN970^"B`J
M($!C;W!Y<FEG:'0@("`R,#`U($%L97AA;F1E<B!7:7)T>@H@*B!`;&EC96YS
M92`@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M
M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@("!296QE
M87-E.B`Q+C0N,`H@*B!`;&EN:R`@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+U-E<G9I8V5S7U=E871H97(*("H@0&QI;FL@("`@("`@(&AT
M='`Z+R]W=W<N=V5A=&AE<BYC;VTO<V5R=FEC97,O>&UL;V%P+FAT;6P*("H@
M0&5X86UP;&4@("`@(&5X86UP;&5S+W=E871H97(N8V]M+6)A<VEC+G!H<"`@
M("`@('=E871H97(N8V]M+6)A<VEC+G!H<`H@*B!`97AA;7!L92`@("`@97AA
M;7!L97,O=V5A=&AE<BYC;VTM97AT96YS:79E+G!H<"`@=V5A=&AE<BYC;VTM
M97AT96YS:79E+G!H<`H@*B\*8VQA<W,@4V5R=FEC97-?5V5A=&AE<E]796%T
M:&5R9&]T8V]M(&5X=&5N9',@4V5R=FEC97-?5V5A=&AE<E]#;VUM;VX@>PH*
M("`@("\O('M[>R!P<F]P97)T:65S"B`@("`O*BH*("`@("`J(%!A<G1N97(M
M240@870@=V5A=&AE<BYC;VT*("`@("`J"B`@("`@*B!`=F%R("`@("!S=')I
M;F<@("`@("`@("`@("`@("`@("`@("`@)%]P87)T;F5R240*("`@("`J($!A
M8V-E<W,@('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?<&%R=&YE<DE$(#T@
M(B(["@H@("`@+RHJ"B`@("`@*B!,:6-E;G-E(&ME>2!A="!W96%T:&5R+F-O
M;0H@("`@("H*("`@("`J($!V87(@("`@('-T<FEN9R`@("`@("`@("`@("`@
M("`@("`@("`D7VQI8V5N<V5+97D*("`@("`J($!A8V-E<W,@('!R:79A=&4*
M("`@("`J+PH@("`@=F%R("1?;&EC96YS94ME>2`]("(B.PH*("`@("\J*@H@
M("`@("H@4W=I=&-H('1O('1O9V=L92!P<F4M9F5T8VAI;F<@;V8@9&%T82!I
M;B!O;F4@<VEN9VQE(')E<75E<W0*("`@("`J"B`@("`@*B!`=F%R("`@("!B
M;V]L("`@("`@("`@("`@("`@("`@("`@("`@)%]P<F5&971C:`H@("`@("H@
M0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("`@=F%R("1?<')E1F5T8V@@
M/2!F86QS93L*"B`@("`O*BH*("`@("`J($]B:F5C="!C;VYT86EN:6YG('1H
M92!P<F]M;W1I;VYA;"!L:6YK<RUD871A"B`@("`@*@H@("`@("H@0'9A<B`@
M("`@;V)J96-T('-T9$-L87-S("`@("`@("`@("`@("1?;&EN:W,*("`@("`J
M($!A8V-E<W,@('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?;&EN:W,["@H@
M("`@+RHJ"B`@("`@*B!834Q?56YS97)I86QI>F5R+"!U<V5D(&9O<B!P<F]C
M97-S:6YG('1H92!X;6P*("`@("`J"B`@("`@*B!`=F%R("`@("!O8FIE8W0@
M6$U,7U5N<V5R:6%L:7IE<B`@("`@)%]U;G-E<FEA;&EZ97(*("`@("`J($!A
M8V-E<W,@('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?=6YS97)I86QI>F5R
M.PH@("`@+R\@?7U]"@H@("`@+R\@>WM[(&-O;G-T<G5C=&]R"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@4F5Q=6ER97,@6$U,
M7U-E<FEA;&EZ97(@=&\@8F4@:6YS=&%L;&5D"B`@("`@*@H@("`@("H@0'!A
M<F%M("`@87)R87D@("`@("`@("`@("`@("`@("`@("`@("1O<'1I;VYS"B`@
M("`@*B!`<&%R86T@("!M:7AE9"`@("`@("`@("`@("`@("`@("`@("`@)&5R
M<F]R"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R"B`@("`@*B!`86-C97-S
M("!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%-E<G9I8V5S7U=E871H
M97)?5V5A=&AE<F1O=&-O;2@D;W!T:6]N<RP@)B1E<G)O<BD*("`@('L*("`@
M("`@("`D<&5R<F]R(#T@;G5L;#L*("`@("`@("`D=&AI<RT^4V5R=FEC97-?
M5V5A=&AE<E]#;VUM;VXH)&]P=&EO;G,L("1P97)R;W(I.PH@("`@("`@(&EF
M("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1P97)R;W(I*2!["B`@("`@
M("`@("`@("1E<G)O<B`]("1P97)R;W(["B`@("`@("`@("`@(')E='5R;CL*
M("`@("`@("!]"@H@("`@("`@("\O(%-E="!O<'1I;VYS(&%C8V]R9&EN9VQY
M"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R)P87)T;F5R240B72DI('L*
M("`@("`@("`@("`@)'1H:7,M/G-E=$%C8V]U;G1$871A*"1O<'1I;VYS6R)P
M87)T;F5R240B72D["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D;W!T
M:6]N<ULB;&EC96YS94ME>2)=*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T
M06-C;W5N=$1A=&$H(B(L("1O<'1I;VYS6R)L:6-E;G-E2V5Y(ETI.PH@("`@
M("`@('T*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;(G!R949E=&-H(ETI
M*2!["B`@("`@("`@("`@("1T:&ES+3YE;F%B;&50<F5&971C:"@D;W!T:6]N
M<ULB<')E1F5T8V@B72D["B`@("`@("`@?0H*("`@("`@("!I;F-L=61E7V]N
M8V4@(EA-3"]5;G-E<FEA;&EZ97(N<&AP(CL*("`@("`@("`D=6YS97)I86QI
M>F5R(#T@)FYE=R!834Q?56YS97)I86QI>F5R*&%R<F%Y*")C;VUP;&5X5'EP
M92(@/3X@(F]B:F5C="(L(")K97E!='1R:6)U=&4B(#T^(")T>7!E(BDI.PH@
M("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1U;G-E<FEA
M;&EZ97(I*2!["B`@("`@("`@("`@("1E<G)O<B`]("1U;G-E<FEA;&EZ97([
M"B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=&AI<RT^7W5N<V5R:6%L:7IE<B`]("1U;G-E<FEA;&EZ97(["B`@
M("`@("`@?0H*("`@("`@("`O+R!#86XG="!A8W%U:7)E(&%N(&]B:F5C="!H
M97)E+"!H87,@=&\@8F4@8VQE86X@;VX@979E<GD@<F5Q=65S=`H@("`@("`@
M(&EN8VQU9&5?;VYC92`B2%144"]297%U97-T+G!H<"(["B`@("!]"B`@("`O
M+R!]?7T*"B`@("`O+R![>WL@<V5T06-C;W5N=$1A=&$H*0H@("`@+RHJ"B`@
M("`@*B!3971S('1H92!N96-C97-S87)Y(&%C8V]U;G0M:6YF;W)M871I;VX@
M9F]R('=E871H97(N8V]M+"!Y;W4G;&P*("`@("`J(')E8V5I=F4@=&AE;2!A
M9G1E<B!R96=I<W1E<FEN9R!F;W(@=&AE(%A-3"US=')E86T*("`@("`J"B`@
M("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)'!A
M<G1N97))1`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@
M("`@("`@("1L:6-E;G-E2V5Y"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T06-C;W5N=$1A=&$H)'!A<G1N97))1"P@
M)&QI8V5N<V5+97DI"B`@("!["B`@("`@("`@:68@*'-T<FQE;B@D<&%R=&YE
M<DE$*2`F)B!C='EP95]D:6=I="@D<&%R=&YE<DE$*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7W!A<G1N97))1"`@/2`D<&%R=&YE<DE$.PH@("`@("`@('T*
M("`@("`@("!I9B`H<W1R;&5N*"1L:6-E;G-E2V5Y*2`F)B!C='EP95]A;&YU
M;2@D;&EC96YS94ME>2DI('L*("`@("`@("`@("`@)'1H:7,M/E]L:6-E;G-E
M2V5Y(#T@)&QI8V5N<V5+97D["B`@("`@("`@?0H@("`@?0H@("`@+R\@?7U]
M"@H@("`@+R\@>WM[(&5N86)L95!R949E=&-H*"D*("`@("\J*@H@("`@("H@
M16YA8FQE<R!P<F4M9F5T8VAI;F<@;V8@9&%T82!I;B!O;F4@<VEN9VQE(')E
M<75E<W0*("`@("`J"B`@("`@*B!`<&%R86T@("!B;V]L("`@("`@("`@("`@
M("`@("`@("`@("`@)'!R949E=&-H"B`@("`@*B!`86-C97-S("!P=6)L:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@96YA8FQE4')E1F5T8V@H)'!R949E=&-H
M*0H@("`@>PH@("`@("`@(&EF("@D<')E1F5T8V@@/3T@=')U92D@>PH@("`@
M("`@("`@("`D=&AI<RT^7W!R949E=&-H(#T@=')U93L*("`@("`@("!]"B`@
M("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@7V-H96-K3&]C871I;VY)1"@I
M"B`@("`O*BH*("`@("`J($-H96-K<R!T:&4@:60@9F]R('9A;&ED('9A;'5E
M<R!A;F0@=&AU<R!P<F5V96YT<R!S:6QL>2!R97%U97-T<R!T;PH@("`@("H@
M=V5A=&AE<BYC;VT@<V5R=F5R"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R
M:6YG("`@("`@("`@("`@("`@("`@("`@("1I9`H@("`@("H@0')E='5R;B`@
M4$5!4E]%<G)O<GQB;V]L"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI3
M15)624-%4U]714%42$527T524D]27TY/7TQ/0T%424]."B`@("`@*B!`=&AR
M;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$527T524D]27TE.5D%,
M241?3$]#051)3TX*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V-H96-K3&]C871I;VY)1"@D:60I"B`@("!["B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1I9"D@?'P@:7-?;V)J96-T*"1I9"D@?'P@(7-T
M<FQE;B@D:60I*2!["B`@("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T
M:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?3D]?3$]#
M051)3TXL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?2!E;'-E:68@
M*"%C='EP95]A;&YU;2@D:60I('Q\("AS=')L96XH)&ED*2`^(#@I*2!["B`@
M("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R
M*%-%4E9)0T537U=%051(15)?15)23U)?24Y604Q)1%],3T-!5$E/3BP@7U]&
M24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(%]P87)S95=E871H
M97)$871A*"D*("`@("\J*@H@("`@("H@1F5T8VAE<R!T:&4@9&%T82!B87-E
M9"!O;B!T:&4@<F5Q=65S=&5D('1Y<&4@86YD(&-A8VAE<R!I=`H@("`@("H*
M("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D
M:60*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@
M("`D<F5Q5'EP90H@("`@("H@0')E='5R;B`@4$5!4E]%<G)O<GQB;V]L"B`@
M("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$527T52
M4D]27U=23TY'7U-%4E9%4E]$051!"B`@("`@*B!`=&AR;W=S("!014%27T5R
M<F]R"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]P87)S95=E871H97)$871A*"1I9"P@)')E<51Y<&4I"B`@("!["B`@
M("`@("`@:68@*"1T:&ES+3Y?<')E1F5T8V@I('L*("`@("`@("`@("`@)')E
M<51Y<&4@/2`B86QL(CL*("`@("`@("!]"@H@("`@("`@("1U<FP@/2`B:'1T
M<#HO+WAO87`N=V5A=&AE<BYC;VTO=V5A=&AE<B]L;V-A;"\B+B1I9"XB/W!R
M;V0]>&]A<"9P87(](BXD=&AI<RT^7W!A<G1N97))1"XB)FME>3TB+B1T:&ES
M+3Y?;&EC96YS94ME>3L*"B`@("`@("`@<W=I=&-H("@D<F5Q5'EP92D@>PH@
M("`@("`@("`@("!C87-E(")L:6YK<R(Z"B`@("`@("`@("`@("`@("`D=7)L
M("X]("(F;&EN:SUX;V%P(CL*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("!C87-E(")W96%T:&5R(CH*("`@("`@("`@("`@("`@("1U<FP@
M+CT@(B9C8STJ)G5N:70]<R(["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@8V%S92`B9F]R96-A<W0B.@H@("`@("`@("`@("`@("`@)'5R
M;"`N/2`B)F1A>68],3`F=6YI=#US(CL*("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("!C87-E(")A;&PB.@H@("`@("`@("`@("`@("`@)'5R
M;"`N/2`B)FQI;FL]>&]A<"9C8STJ)F1A>68],3`F=6YI=#US(CL*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@+R\@1V5T(&1A
M=&$@9G)O;2!54DPN+BX*("`@("`@("`D<F5Q=65S="`]("9N97<@2%144%]2
M97%U97-T*"1U<FPL("1T:&ES+3Y?:'1T<$]P=&EO;G,I.PH@("`@("`@("1S
M=&%T=7,@/2`D<F5Q=65S="T^<V5N9%)E<75E<W0H*3L*("`@("`@("!I9B`H
M4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2!\?"`H:6YT*2`D
M<F5Q=65S="T^9V5T4F5S<&]N<V5#;V1E*"D@/#X@,C`P*2!["B`@("`@("`@
M("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)
M0T537U=%051(15)?15)23U)?5U)/3D=?4T525D527T1!5$$L(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@("`@("1D871A(#T@)')E<75E
M<W0M/F=E=%)E<W!O;G-E0F]D>2@I.PH*("`@("`@("`O+R`N+BYA;F0@=6YS
M97)I86QI>F4*("`@("`@("`D<W1A='5S(#T@)'1H:7,M/E]U;G-E<FEA;&EZ
M97(M/G5N<V5R:6%L:7IE*"1D871A*3L*"B`@("`@("`@:68@*%-E<G9I8V5S
M7U=E871H97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@("`@("`@("`@<F5T
M=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!
M5$A%4E]%4E)/4E]74D].1U]315)615)?1$%402P@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F]O="`]("1T
M:&ES+3Y?=6YS97)I86QI>F5R+3YG9712;V]T3F%M92@I.PH@("`@("`@("`@
M("`D9&%T82`]("1T:&ES+3Y?=6YS97)I86QI>F5R+3YG9715;G-E<FEA;&EZ
M961$871A*"D["@H@("`@("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ
M:7-%<G)O<B@D<F]O="D@?'P@)')O;W0@/3T@(DA434PB*2!["B`@("`@("`@
M("`@("`@("`O+R!3;VUE=&AI;F<@=W)O;F<@:&5R92P@;6%Y8F4@;F]T(%A-
M3"!R971R:65V960N+BX*("`@("`@("`@("`@("`@(')E='5R;B!397)V:6-E
M<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?
M5U)/3D=?4T525D527T1!5$$L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@("`@('T@96QS96EF("@D<F]O="`]/2`B97)R;W(B*2!["B`@("`@("`@
M("`@("`@("`O+R!792!G;W0@86X@97)R;W(@8F%C:R!F<F]M('=E871H97(N
M8V]M"B`@("`@("`@("`@("`@("`D97)R;F\@(#T@:V5Y*&=E=%]O8FIE8W1?
M=F%R<R@D9&%T82DI.PH@("`@("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S
M7U=E871H97(Z.G)A:7-E17)R;W(H)&5R<FYO+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@
M5F%L:60@9&%T82P@;&5T<R!G970@<W1A<G1E9`H@("`@("`@("`@("`@("`@
M+R\@3&]O<"!T:')O=6=H('1H92!D:69F97)E;G0@<W5B+7!A<G1S(&]F('1H
M92!D871A(&9R;R!P<F]C97-S:6YG"B`@("`@("`@("`@("`@("!F;W)E86-H
M("AG971?;V)J96-T7W9A<G,H)&1A=&$I(&%S("1K97D@/3X@)'9A;"D@>PH@
M("`@("`@("`@("`@("`@("`@('-W:71C:"`H)&ME>2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!C87-E(")H96%D(CH*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E(#(["B`@("`@("`@("`@("`@("`@("`@("`@
M(&-A<V4@(G!R;6\B.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A
M<FYA;64@(#T@(FQI;FMS(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")L;V,B.@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64@(#T@(FQO8V%T
M:6]N(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@("`@("!C87-E(")C8R(Z"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=F%R;F%M92`@/2`B=V5A=&AE<B(["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@
M("`@("`@8V%S92`B9&%Y9B(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=F%R;F%M92`@/2`B9F]R96-A<W0B.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("\O(%-A=F4@9&%T82!I;B!O8FIE8W0*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^>R)?(BXD=F%R;F%M97T@/2`D=F%L.PH@("`@
M("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7V-A8VAE16YA8FQE9"D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`O+R`N+BYA;F0@8V%C:&4@:68@<&]S
M<VEB;&4*("`@("`@("`@("`@("`@("`@("`@("`@)&5X<&ER92`](&-O;G-T
M86YT*")315)624-%4U]714%42$527T584$E215-?(BYS=')T;W5P<&5R*"1V
M87)N86UE*2D["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8V%C
M:&4M/F5X=%-A=F4H)&ED+"`D=F%L+"`B(BP@)&5X<&ER92P@)'9A<FYA;64I
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@<V5A<F-H3&]C871I;VXH*0H@
M("`@+RHJ"B`@("`@*B!396%R8VAE<R!)1',@9F]R(&=I=F5N(&QO8V%T:6]N
M+"!R971U<FYS(&%R<F%Y(&]F('!O<W-I8FQE(&QO8V%T:6]N<PH@("`@("H@
M;W(@<VEN9VQE($E$"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@
M("`@("`@("`@("`@("`@("`@("1L;V-A=&EO;@H@("`@("H@0'!A<F%M("`@
M8F]O;"`@("`@("`@("`@("`@("`@("`@("`@("1U<V5&:7)S="`@("`@("!)
M9B!S970L(&9I<G-T($E$(&]F(')E<W5L="UA<G)A>2!I<R!R971U<FYE9`H@
M("`@("H@0')E='5R;B`@4$5!4E]%<G)O<GQA<G)A>7QS=')I;F<*("`@("`J
M($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?
M5U)/3D=?4T525D527T1!5$$*("`@("`J($!T:')O=W,@(%!%05)?17)R;W(Z
M.E-%4E9)0T537U=%051(15)?15)23U)?54Y+3D]73E],3T-!5$E/3@H@("`@
M("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-E87)C
M:$QO8V%T:6]N*"1L;V-A=&EO;BP@)'5S949I<G-T(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@)&QO8V%T:6]N(#T@=')I;2@D;&]C871I;VXI.PH@("`@("`@
M("1L;V-,;W<@("`]('-T<G1O;&]W97(H)&QO8V%T:6]N*3L*("`@("`@("`*
M("`@("`@("`O+R!#:&5C:R!O;B!C86-H960@9&%T83H@340U+6AA<V@@;V8@
M;&]C871I;VX@:&%S('1O(&)E(&-O<G)E8W0@86YD('1H92!U<V5R9&%T82!H
M87,@=&\@8F4@=&AE('-A;64@87,@=&AE(&=I=F5N(&QO8V%T:6]N(`H@("`@
M("`@(&EF("@D=&AI<RT^7V-A8VAE16YA8FQE9"`F)B`D;&]C3&]W(#T]("1T
M:&ES+3Y?8V%C:&4M/F=E=%5S97)$871A*&UD-2@D;&]C3&]W*2P@(G-E87)C
M:"(I*2!["B`@("`@("`@("`@("1S96%R8V@@/2`D=&AI<RT^7V-A8VAE+3YG
M970H;60U*"1L;V-,;W<I+"`B<V5A<F-H(BD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@+R\@1V5T('-E87)C:"!D871A(&9R;VT@<V5R=F5R(&%N
M9"!U;G-E<FEA;&EZ90H@("`@("`@("`@("`D<F5Q=65S="`]("9N97<@2%14
M4%]297%U97-T*")H='1P.B\O>&]A<"YW96%T:&5R+F-O;2]S96%R8V@O<V5A
M<F-H/W=H97)E/2(N=7)L96YC;V1E*"1L;V-A=&EO;BDL("1T:&ES+3Y?:'1T
M<$]P=&EO;G,I.PH@("`@("`@("`@("`D<W1A='5S(#T@)')E<75E<W0M/G-E
M;F1297%U97-T*"D["B`@("`@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R
M.CII<T5R<F]R*"1S=&%T=7,I('Q\("AI;G0I("1R97%U97-T+3YG971297-P
M;VYS94-O9&4H*2`\/B`R,#`I('L*("`@("`@("`@("`@("`@(')E='5R;B!3
M97)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?
M15)23U)?5U)/3D=?4T525D527T1!5$$L(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&1A=&$@/2`D<F5Q=65S="T^
M9V5T4F5S<&]N<V5";V1Y*"D["B`@("`*("`@("`@("`@("`@+R\@+BXN86YD
M('5N<V5R:6%L:7IE"B`@("`@("`@("`@("1S=&%T=7,@/2`D=&AI<RT^7W5N
M<V5R:6%L:7IE<BT^=6YS97)I86QI>F4H)&1A=&$L(&9A;'-E+"!A<G)A>2@B
M;W9E<G)I9&5/<'1I;VYS(B`]/B!T<G5E+"`B8V]M<&QE>%1Y<&4B(#T^(")A
M<G)A>2(L(")K97E!='1R:6)U=&4B(#T^(")I9"(I*3L*("`@(`H@("`@("`@
M("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A
M:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E]74D].1U]315)615)?
M1$%402P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@?0H@("`@
M"B`@("`@("`@("`@("1R;V]T(#T@)'1H:7,M/E]U;G-E<FEA;&EZ97(M/F=E
M=%)O;W1.86UE*"D["B`@("`@("`@("`@("1S96%R8V@@/2`D=&AI<RT^7W5N
M<V5R:6%L:7IE<BT^9V5T56YS97)I86QI>F5D1&%T82@I.PH@("`@"B`@("`@
M("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S96%R8V@I
M('Q\("1R;V]T(#T](")(5$U,(BD@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%
M4E]%4E)/4E]74D].1U]315)615)?1$%402P@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("`@("`@?2!E;'-E:68@*"%I<U]A<G)A>2@D<V5A<F-H*2!\
M?"`A<VEZ96]F*"1S96%R8V@I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$52
M7T524D]27U5.2TY/5TY?3$]#051)3TXL(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V-A8VAE
M16YA8FQE9"D@>PH@("`@("`@("`@("`@("`@+R\@+BXN86YD(&-A8VAE(&EF
M('!O<W-I8FQE"B`@("`@("`@("`@("`@("`D97AP:7)E(#T@8V]N<W1A;G0H
M(E-%4E9)0T537U=%051(15)?15A025)%4U]314%20T@B*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?8V%C:&4M/F5X=%-A=F4H;60U*"1L;V-,;W<I+"`D
M<V5A<F-H+"`D;&]C3&]W+"`D97AP:7)E+"`B<V5A<F-H(BD["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A)'5S949I<G-T("8F("AS
M:7IE;V8H)'-E87)C:"D@/B`Q*2D@>PH@("`@("`@("`@("`D<V5A<F-H4F5T
M=7)N(#T@)'-E87)C:#L*("`@("`@("!](&5L<V5I9B`H)'5S949I<G-T('Q\
M("AS:7IE;V8H)'-E87)C:"D@/3T@,2DI('L*("`@("`@("`@("`@)'-E87)C
M:%)E='5R;B`](&ME>2@D<V5A<F-H*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D<V5A<F-H4F5T=7)N.PH@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@
M>WM[('-E87)C:$QO8V%T:6]N0GE#;W5N=')Y*"D*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!O;FQY(&9A;'-E+"!A<R!W96%T:&5R+F-O;2!O9F9E<G,@;F\@
M8V]U;G1R>2!L:7-T:6YG('9I80H@("`@("H@:71S(%A-3"!S97)V:6-E<PH@
M("`@("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@
M("`@("`D8V]U;G1R>0H@("`@("H@0')E='5R;B`@8F]O;`H@("`@("H@0&%C
M8V5S<R`@<'5B;&EC"B`@("`@*B!`9&5P<F5C871E9`H@("`@("HO"B`@("!F
M=6YC=&EO;B!S96%R8VA,;V-A=&EO;D)Y0V]U;G1R>2@D8V]U;G1R>2`]("(B
M*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*("`@("\O('U]
M?0H*("`@("\O('M[>R!G971,:6YK<R@I"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE(&1A=&$@9F]R('1H92!P<F]M;W1I;VYA;"!L:6YK<R!B96QO;F=I
M;F<@=&\@=&AE($E$"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@
M("`@("`@("`@("`@("`@("`@("1I9`H@("`@("H@0')E='5R;B`@4$5!4E]%
M<G)O<GQA<G)A>0H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<@H@("`@("H@
M0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$QI;FMS
M*"1I9"`]("(B*0H@("`@>PH@("`@("`@("1S=&%T=7,@/2`D=&AI<RT^7V-H
M96-K3&]C871I;VY)1"@D:60I.PH*("`@("`@("!I9B`H4V5R=FEC97-?5V5A
M=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'-T871U<SL*("`@("`@("!]"@H@("`@("`@("1L:6YK<U)E='5R;B`](&%R
M<F%Y*"D["@H@("`@("`@(&EF("@D=&AI<RT^7V-A8VAE16YA8FQE9"`F)B`H
M)&QI;FMS(#T@)'1H:7,M/E]C86-H92T^9V5T*"1I9"P@(FQI;FMS(BDI*2![
M"B`@("`@("`@("`@("\O($=E="!D871A(&9R;VT@8V%C:&4*("`@("`@("`@
M("`@)'1H:7,M/E]L:6YK<R`]("1L:6YK<SL*("`@("`@("`@("`@)&QI;FMS
M4F5T=7)N6R)C86-H92)=(#T@(DA)5"(["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@+R\@4V%M92!A<R!I;B!T:&4@9G5N8W1I;VX@86)O=F4N+BX*
M("`@("`@("`@("`@)'-T871U<R`]("1T:&ES+3Y?<&%R<V5796%T:&5R1&%T
M82@D:60L(")L:6YK<R(I.PH*("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E
M871H97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D<W1A='5S.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1L:6YK
M<U)E='5R;ELB8V%C:&4B72`](")-25-3(CL*("`@("`@("!]"@H@("`@("`@
M("1L:6YK<U)E='5R;ELB<')O;6\B72`](&%R<F%Y*"D["B`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@<VEZ96]F*"1T:&ES+3Y?;&EN:W,M/FQI;FLI.R`D
M:2LK*2!["B`@("`@("`@("`@("1L:6YK<U)E='5R;ELB<')O;6\B75LD:5T@
M/2!A<G)A>2@I.PH@("`@("`@("`@("`D;&EN:W-2971U<FY;(G!R;VUO(EU;
M)&E=6R)T:71L92)=(#T@)'1H:7,M/E]L:6YK<RT^;&EN:ULD:5TM/G0["B`@
M("`@("`@("`@("\O($(P<FME9"!R97-P;VYS92`H<F5T=7)N960@:7,@)G!A
M<CUX;V%P+"!S:&]U;&0@8F4@)G!R;V0]>&]A<"DL(&9I>"!I=`H@("`@("`@
M("`@("`D;&EN:W-2971U<FY;(G!R;VUO(EU;)&E=6R)L:6YK(ET@(#T@<W1R
M7W)E<&QA8V4H(G!A<CTB+"`B<')O9#TB+"`D=&AI<RT^7VQI;FMS+3YL:6YK
M6R1I72T^;"D["B`@("`@("`@("`@("1L:6YK<U)E='5R;ELB<')O;6\B75LD
M:5U;(FQI;FLB72`N/2`B)G!A<CTB+B1T:&ES+3Y?<&%R=&YE<DE$.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1L:6YK<U)E='5R;CL*("`@('T*("`@
M("\O('U]?0H*("`@("\O('M[>R!G971,;V-A=&EO;B@I"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE(&1A=&$@9F]R('1H92!L;V-A=&EO;B!B96QO;F=I
M;F<@=&\@=&AE($E$"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@
M("`@("`@("`@("`@("`@("`@("1I9`H@("`@("H@0')E='5R;B`@4$5!4E]%
M<G)O<GQA<G)A>0H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<@H@("`@("H@
M0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$QO8V%T
M:6]N*"1I9"`]("(B*0H@("`@>PH@("`@("`@("1S=&%T=7,@/2`D=&AI<RT^
M7V-H96-K3&]C871I;VY)1"@D:60I.PH*("`@("`@("!I9B`H4V5R=FEC97-?
M5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'-T871U<SL*("`@("`@("!]"@H@("`@("`@("1L;V-A=&EO;E)E='5R
M;B`](&%R<F%Y*"D["@H@("`@("`@(&EF("@D=&AI<RT^7V-A8VAE16YA8FQE
M9"`F)B`H)&QO8V%T:6]N(#T@)'1H:7,M/E]C86-H92T^9V5T*"1I9"P@(FQO
M8V%T:6]N(BDI*2!["B`@("`@("`@("`@("\O($=E="!D871A(&9R;VT@8V%C
M:&4*("`@("`@("`@("`@)'1H:7,M/E]L;V-A=&EO;B`]("1L;V-A=&EO;CL*
M("`@("`@("`@("`@)&QO8V%T:6]N4F5T=7)N6R)C86-H92)=(#T@(DA)5"([
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@4V%M92!A<R!I;B!T
M:&4@9G5N8W1I;VX@86)O=F4N+BX*("`@("`@("`@("`@)'-T871U<R`]("1T
M:&ES+3Y?<&%R<V5796%T:&5R1&%T82@D:60L(")L;V-A=&EO;B(I.PH*("`@
M("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-T871U
M<RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<W1A='5S.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1L;V-A=&EO;E)E='5R;ELB8V%C:&4B72`]
M(")-25-3(CL*("`@("`@("!]"@H@("`@("`@("1L;V-A=&EO;E)E='5R;ELB
M;F%M92)=("`@("`@/2`D=&AI<RT^7VQO8V%T:6]N+3YD;F%M.PH@("`@("`@
M("1L;V-A=&EO;E)E='5R;ELB=&EM92)=("`@("`@/2!D871E*"1T:&ES+3Y?
M=&EM949O<FUA="P@<W1R=&]T:6UE*"1T:&ES+3Y?;&]C871I;VXM/G1M*2D[
M"B`@("`@("`@)&QO8V%T:6]N4F5T=7)N6R)L871I='5D92)=("`]("1T:&ES
M+3Y?;&]C871I;VXM/FQA=#L*("`@("`@("`D;&]C871I;VY2971U<FY;(FQO
M;F=I='5D92)=(#T@)'1H:7,M/E]L;V-A=&EO;BT^;&]N.PH@("`@("`@("1L
M;V-A=&EO;E)E='5R;ELB<W5N<FES92)=("`@/2!D871E*"1T:&ES+3Y?=&EM
M949O<FUA="P@<W1R=&]T:6UE*"1T:&ES+3Y?;&]C871I;VXM/G-U;G(I*3L*
M("`@("`@("`D;&]C871I;VY2971U<FY;(G-U;G-E=")=("`@(#T@9&%T92@D
M=&AI<RT^7W1I;65&;W)M870L('-T<G1O=&EM92@D=&AI<RT^7VQO8V%T:6]N
M+3YS=6YS*2D["B`@("`@("`@)&QO8V%T:6]N4F5T=7)N6R)T:6UE>F]N92)=
M("`]("1T:&ES+3Y?;&]C871I;VXM/GIO;F4["@H@("`@("`@(')E='5R;B`D
M;&]C871I;VY2971U<FX["B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@
M9V5T5V5A=&AE<B@I"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('=E871H
M97(M9&%T82!F;W(@=&AE('-U<'!L:65D(&QO8V%T:6]N"B`@("`@*@H@("`@
M("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1I9`H@
M("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1U
M;FET<T9O<FUA=`H@("`@("H@0')E='5R;B`@4$5!4E]%<G)O<GQA<G)A>0H@
M("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<@H@("`@("H@0&%C8V5S<R`@<'5B
M;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%=E871H97(H)&ED(#T@(B(L
M("1U;FET<T9O<FUA="`]("(B*0H@("`@>PH@("`@("`@("1S=&%T=7,@/2`D
M=&AI<RT^7V-H96-K3&]C871I;VY)1"@D:60I.PH*("`@("`@("!I9B`H4V5R
M=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'-T871U<SL*("`@("`@("!]"@H@("`@("`@("\O($=E="!O
M=&AE<B!D871A"B`@("`@("`@)'5N:71S("`@(#T@)'1H:7,M/F=E=%5N:71S
M1F]R;6%T*"1U;FET<T9O<FUA="D["@H@("`@("`@("1W96%T:&5R4F5T=7)N
M(#T@87)R87DH*3L*"B`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%;F%B;&5D
M("8F("@D=V5A=&AE<B`]("1T:&ES+3Y?8V%C:&4M/F=E="@D:60L(")W96%T
M:&5R(BDI*2!["B`@("`@("`@("`@("\O(%-A;64@<')O8V5D=7)E+BXN"B`@
M("`@("`@("`@("1T:&ES+3Y?=V5A=&AE<B`]("1W96%T:&5R.PH@("`@("`@
M("`@("`D=V5A=&AE<E)E='5R;ELB8V%C:&4B72`](")(250B.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("\O("XN+F%S(&QA<W0@9G5N8W1I;VX*
M("`@("`@("`@("`@)'-T871U<R`]("1T:&ES+3Y?<&%R<V5796%T:&5R1&%T
M82@D:60L(")W96%T:&5R(BD["@H@("`@("`@("`@("!I9B`H4V5R=FEC97-?
M5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1S=&%T=7,["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'=E
M871H97)2971U<FY;(F-A8VAE(ET@/2`B34E34R(["B`@("`@("`@?0H*("`@
M("`@("`O+R!3;VUE(&5X<&QA;F%T:6]N(&9O<B!T:&4@;F5X="!T=V\@;&EN
M97,Z"B`@("`@("`@+R\@=V5A=&AE<BYC;VT@:7-N)W0@86QW87ES('-U<'!L
M>6EN9R!T:&4@=&EM97IO;F4@:6X@=&AE('5P9&%T92!S=')I;F<L(&)U=`H@
M("`@("`@("\O('5S97,@(DQO8V%L(%1I;64B(&%S(')E9F5R96YC92P@=VAI
M8V@@:7,@:6UH;R!U='1E<FQY('-T=7!I9"P@8F5C875S92!I="=S"B`@("`@
M("`@+R\@:6YC;VYS:7-T96YT+B!796QL+"!W:&%T($D@9&\@:&5R92!I<R!C
M:&5C:R!F;W(@=&AI<R!S=')I;F<@86YD(&EF($D@8V%N"B`@("`@("`@+R\@
M9FEN9"!I="P@22!C86QC=6QA=&4@=&AE(&1I9F9E<F5N8V4@8F5T=V5E;B!T
M:&4@=&EM97IO;F4@870@=&AE(&QO8V%T:6]N"B`@("`@("`@+R\@86YD('1H
M:7,@8V]M<'5T97)S('1I;65Z;VYE+B!4:&ES(&%M;W5N="!O9B!S96-O;F1S
M(&ES('1H96X@<W5B=')A8W1E9"!F<F]M"B`@("`@("`@+R\@=&AE('1I;64@
M=&AE('5P9&%T92US=')I;F<@:&%S(&1E;&EV97)E9"X*("`@("`@("`D=7!D
M871E("`@/2!S=')?<F5P;&%C92@B3&]C86P@5&EM92(L("(B+"`D=&AI<RT^
M7W=E871H97(M/FQS=7`I.PH@("`@("`@("1A9&IU<W146B`]("@D=7!D871E
M(#T]("1T:&ES+3Y?=V5A=&AE<BT^;'-U<"D@/R`P(#H@)'1H:7,M/E]L;V-A
M=&EO;BT^>F]N92`J(#,V,#`@+2!D871E*"):(BD["B`@("`@("`@)'=E871H
M97)2971U<FY;(G5P9&%T92)=("`@("`@("`@("`@/2!G;61A=&4H=')I;2@D
M=&AI<RT^7V1A=&5&;W)M870N(B`B+B1T:&ES+3Y?=&EM949O<FUA="DL('-T
M<G1O=&EM92@D=7!D871E*2`M("1A9&IU<W146BD["B`@("`@("`@)'=E871H
M97)2971U<FY;(G5P9&%T95)A=R)=("`@("`@("`@/2`D=&AI<RT^7W=E871H
M97(M/FQS=7`["B`@("`@("`@)'=E871H97)2971U<FY;(G-T871I;VXB72`@
M("`@("`@("`@/2`D=&AI<RT^7W=E871H97(M/F]B<W0["B`@("`@("`@)'=E
M871H97)2971U<FY;(G1E;7!E<F%T=7)E(ET@("`@("`@/2`D=&AI<RT^8V]N
M=F5R=%1E;7!E<F%T=7)E*"1T:&ES+3Y?=V5A=&AE<BT^=&UP+"`B9B(L("1U
M;FET<ULB=&5M<")=*3L*("`@("`@("`D=V5A=&AE<E)E='5R;ELB9F5L=%1E
M;7!E<F%T=7)E(ET@("`]("1T:&ES+3YC;VYV97)T5&5M<&5R871U<F4H)'1H
M:7,M/E]W96%T:&5R+3YF;&EK+"`B9B(L("1U;FET<ULB=&5M<")=*3L*("`@
M("`@("`D=V5A=&AE<E)E='5R;ELB8V]N9&ET:6]N(ET@("`@("`@("`]("1T
M:&ES+3Y?=V5A=&AE<BT^=#L*("`@("`@("`D=V5A=&AE<E)E='5R;ELB8V]N
M9&ET:6]N26-O;B)=("`@("`]("1T:&ES+3Y?=V5A=&AE<BT^:6-O;CL*("`@
M("`@("`D=V5A=&AE<E)E='5R;ELB<')E<W-U<F4B72`@("`@("`@("`]("1T
M:&ES+3YC;VYV97)T4')E<W-U<F4H)'1H:7,M/E]W96%T:&5R+3YB87(M/G(L
M(")I;B(L("1U;FET<ULB<')E<R)=*3L*("`@("`@("`D=V5A=&AE<E)E='5R
M;ELB<')E<W-U<F54<F5N9")=("`@("`]("1T:&ES+3Y?=V5A=&AE<BT^8F%R
M+3YD.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)W:6YD(ET@("`@("`@("`@
M("`@(#T@)'1H:7,M/F-O;G9E<G13<&5E9"@D=&AI<RT^7W=E871H97(M/G=I
M;F0M/G,L(")M<&@B+"`D=6YI='-;(G=I;F0B72D["B`@("`@("`@)'=E871H
M97)2971U<FY;(G=I;F1'=7-T(ET@("`@("`@("`@/2`D=&AI<RT^8V]N=F5R
M=%-P965D*"1T:&ES+3Y?=V5A=&AE<BT^=VEN9"T^9W5S="P@(FUP:"(L("1U
M;FET<ULB=VEN9")=*3L*("`@("`@("`D=V5A=&AE<E)E='5R;ELB=VEN9$1E
M9W)E97,B72`@("`@("`]("1T:&ES+3Y?=V5A=&AE<BT^=VEN9"T^9#L*("`@
M("`@("`D=V5A=&AE<E)E='5R;ELB=VEN9$1I<F5C=&EO;B)=("`@("`]("1T
M:&ES+3Y?=V5A=&AE<BT^=VEN9"T^=#L*("`@("`@("`D=V5A=&AE<E)E='5R
M;ELB:'5M:61I='DB72`@("`@("`@("`]("1T:&ES+3Y?=V5A=&AE<BT^:&UI
M9#L*("`@("`@("!I9B`H:7-?;G5M97)I8R@D=&AI<RT^7W=E871H97(M/G9I
M<RDI('L*("`@("`@("`@("`@)'=E871H97)2971U<FY;(G9I<VEB:6QI='DB
M72`@("`]("1T:&ES+3YC;VYV97)T1&ES=&%N8V4H)'1H:7,M/E]W96%T:&5R
M+3YV:7,L(")S;2(L("1U;FET<ULB=FES(ETI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1W96%T:&5R4F5T=7)N6R)V:7-I8FEL:71Y(ET@("`@
M/2`D=&AI<RT^7W=E871H97(M/G9I<SL*("`@("`@("!]"B`@("`@("`@)'=E
M871H97)2971U<FY;(G5V26YD97@B72`@("`@("`@("`@/2`D=&AI<RT^7W=E
M871H97(M/G5V+3YI.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)U=E1E>'0B
M72`@("`@("`@("`@(#T@)'1H:7,M/E]W96%T:&5R+3YU=BT^=#L*("`@("`@
M("`D=V5A=&AE<E)E='5R;ELB9&5W4&]I;G0B72`@("`@("`@("`]("1T:&ES
M+3YC;VYV97)T5&5M<&5R871U<F4H)'1H:7,M/E]W96%T:&5R+3YD97=P+"`B
M9B(L("1U;FET<ULB=&5M<")=*3L*"B`@("`@("`@<F5T=7)N("1W96%T:&5R
M4F5T=7)N.PH@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&=E=$9O<F5C
M87-T*"D*("`@("\J*@H@("`@("H@1V5T('1H92!F;W)E8V%S="!F;W(@=&AE
M(&YE>'0@9&%Y<PH@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@
M("`@("`@("`@("`@("`@("`D:60*("`@("`J($!P87)A;2`@(&EN="`@("`@
M("`@("`@("`@("`@("`@("`@("`D9&%Y<R`@("`@("`@("`@5F%L=65S(&)E
M='=E96X@,2!A;F0@,3`*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@
M("`@("`@("`@("`@("`D=6YI='-&;W)M870*("`@("`J($!R971U<FX@(%!%
M05)?17)R;W)\87)R87D*("`@("`J($!T:')O=W,@(%!%05)?17)R;W(*("`@
M("`J($!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971&
M;W)E8V%S="@D:60@/2`B(BP@)&1A>7,@/2`R+"`D=6YI='-&;W)M870@/2`B
M(BD*("`@('L*("`@("`@("`D<W1A='5S(#T@)'1H:7,M/E]C:&5C:TQO8V%T
M:6]N240H)&ED*3L*"B`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES
M17)R;W(H)'-T871U<RDI('L*("`@("`@("`@("`@<F5T=7)N("1S=&%T=7,[
M"B`@("`@("`@?0H@("`@("`@(&EF("@A:6Y?87)R87DH)&1A>7,L(')A;F=E
M*#$L(#$P*2DI('L*("`@("`@("`@("`@)&1A>7,@/2`R.PH@("`@("`@('T*
M"B`@("`@("`@+R\@1V5T(&]T:&5R(&1A=&$*("`@("`@("`D=6YI=',@("`@
M/2`D=&AI<RT^9V5T56YI='-&;W)M870H)'5N:71S1F]R;6%T*3L*"B`@("`@
M("`@)&9O<F5C87-T4F5T=7)N(#T@87)R87DH*3L*"B`@("`@("`@:68@*"1T
M:&ES+3Y?8V%C:&5%;F%B;&5D("8F("@D9F]R96-A<W0@/2`D=&AI<RT^7V-A
M8VAE+3YG970H)&ED+"`B9F]R96-A<W0B*2DI('L*("`@("`@("`@("`@+R\@
M16YC;W)E+BXN"B`@("`@("`@("`@("1T:&ES+3Y?9F]R96-A<W0@/2`D9F]R
M96-A<W0["B`@("`@("`@("`@("1F;W)E8V%S=%)E='5R;ELB8V%C:&4B72`]
M(")(250B.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O("XN+@H@
M("`@("`@("`@("`D<W1A='5S(#T@)'1H:7,M/E]P87)S95=E871H97)$871A
M*"1I9"P@(F9O<F5C87-T(BD["@H@("`@("`@("`@("!I9B`H4V5R=FEC97-?
M5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1S=&%T=7,["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&9O
M<F5C87-T4F5T=7)N6R)C86-H92)=(#T@(DU)4U,B.PH@("`@("`@('T*"B`@
M("`@("`@+R\@4V]M92!E>'!L86YA=&EO;B!F;W(@=&AE(&YE>'0@='=O(&QI
M;F5S.B`H<V%M92!A<R!A8F]V92D*("`@("`@("`O+R!W96%T:&5R+F-O;2!I
M<VXG="!A;'=A>7,@<W5P<&QY:6YG('1H92!T:6UE>F]N92!I;B!T:&4@=7!D
M871E('-T<FEN9RP@8G5T"B`@("`@("`@+R\@=7-E<R`B3&]C86P@5&EM92(@
M87,@<F5F97)E;F-E+"!W:&EC:"!I<R!I;6AO('5T=&5R;'D@<W1U<&ED+"!B
M96-A=7-E(&ET)W,*("`@("`@("`O+R!I;F-O;G-I<W1E;G0N(%=E;&PL('=H
M870@22!D;R!H97)E(&ES(&-H96-K(&9O<B!T:&ES('-T<FEN9R!A;F0@:68@
M22!C86X*("`@("`@("`O+R!F:6YD(&ET+"!)(&-A;&-U;&%T92!T:&4@9&EF
M9F5R96YC92!B971W965N('1H92!T:6UE>F]N92!A="!T:&4@;&]C871I;VX*
M("`@("`@("`O+R!A;F0@=&AI<R!C;VUP=71E<G,@=&EM97IO;F4N(%1H:7,@
M86UO=6YT(&]F('-E8V]N9',@:7,@=&AE;B!S=6)T<F%C=&5D(&9R;VT*("`@
M("`@("`O+R!T:&4@=&EM92!T:&4@=7!D871E+7-T<FEN9R!H87,@9&5L:79E
M<F5D+@H@("`@("`@("1U<&1A=&4@("`]('-T<E]R97!L86-E*"),;V-A;"!4
M:6UE(BP@(B(L("1T:&ES+3Y?9F]R96-A<W0M/FQS=7`I.PH@("`@("`@("1A
M9&IU<W146B`]("@D=7!D871E(#T]("1T:&ES+3Y?9F]R96-A<W0M/FQS=7`I
M(#\@,"`Z("1T:&ES+3Y?;&]C871I;VXM/GIO;F4@*B`S-C`P("T@9&%T92@B
M6B(I.PH@("`@("`@("1F;W)E8V%S=%)E='5R;ELB=7!D871E(ET@("`@/2!G
M;61A=&4H)'1H:7,M/E]D871E1F]R;6%T+B(@(BXD=&AI<RT^7W1I;65&;W)M
M870L('-T<G1O=&EM92@D=7!D871E*2`M("1A9&IU<W146BD["B`@("`@("`@
M)&9O<F5C87-T4F5T=7)N6R)U<&1A=&5287<B72`]("1T:&ES+3Y?9F]R96-A
M<W0M/FQS=7`["B`@("`@("`@)&9O<F5C87-T4F5T=7)N6R)D87ES(ET@("`@
M("`](&%R<F%Y*"D["@H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1D87ES
M.R`D:2LK*2!["B`@("`@("`@("`@("1D87D@/2!A<G)A>2@*("`@("`@("`@
M("`@("`@(")T96UP97)A='5R94AI9V@B(#T^("1T:&ES+3YC;VYV97)T5&5M
M<&5R871U<F4H)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^:&DL(")F(BP@
M)'5N:71S6R)T96UP(ETI+`H@("`@("`@("`@("`@("`@(G1E;7!E<F%T=7)E
M3&]W(B`@/3X@)'1H:7,M/F-O;G9E<G1496UP97)A='5R92@D=&AI<RT^7V9O
M<F5C87-T+3YD87E;)&E=+3YL;W<L(")F(BP@)'5N:71S6R)T96UP(ETI+`H@
M("`@("`@("`@("`@("`@(G-U;G)I<V4B("`@("`@("`@/3X@9&%T92@D=&AI
M<RT^7W1I;65&;W)M870L('-T<G1O=&EM92@D=&AI<RT^7V9O<F5C87-T+3YD
M87E;)&E=+3YS=6YR*2DL"B`@("`@("`@("`@("`@("`B<W5N<V5T(B`@("`@
M("`@("`]/B!D871E*"1T:&ES+3Y?=&EM949O<FUA="P@<W1R=&]T:6UE*"1T
M:&ES+3Y?9F]R96-A<W0M/F1A>5LD:5TM/G-U;G,I*2P*("`@("`@("`@("`@
M("`@(")D87DB(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@(")C;VYD
M:71I;VXB("`@("`]/B`D=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=+3YP87)T
M6S!=+3YT+`H@("`@("`@("`@("`@("`@("`@(")C;VYD:71I;VY)8V]N(B`]
M/B`D=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=+3YP87)T6S!=+3YI8V]N+`H@
M("`@("`@("`@("`@("`@("`@(")W:6YD(B`@("`@("`@("`]/B`D=&AI<RT^
M8V]N=F5R=%-P965D*"1T:&ES+3Y?9F]R96-A<W0M/F1A>5LD:5TM/G!A<G1;
M,%TM/G=I;F0M/G,L(")M<&@B+"`D=6YI='-;(G=I;F0B72DL"B`@("`@("`@
M("`@("`@("`@("`@(G=I;F1'=7-T(B`@("`@(#T^("1T:&ES+3YC;VYV97)T
M4W!E960H)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^<&%R=%LP72T^=VEN
M9"T^9W5S="P@(FUP:"(L("1U;FET<ULB=VEN9")=*2P*("`@("`@("`@("`@
M("`@("`@("`B=VEN9$1E9W)E97,B("`@/3X@)'1H:7,M/E]F;W)E8V%S="T^
M9&%Y6R1I72T^<&%R=%LP72T^=VEN9"T^9"P*("`@("`@("`@("`@("`@("`@
M("`B=VEN9$1I<F5C=&EO;B(@/3X@)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I
M72T^<&%R=%LP72T^=VEN9"T^="P*("`@("`@("`@("`@("`@("`@("`B<')E
M8VEP:71A=&EO;B(@/3X@)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^<&%R
M=%LP72T^<'!C<"P*("`@("`@("`@("`@("`@("`@("`B:'5M:61I='DB("`@
M("`@/3X@)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^<&%R=%LP72T^:&UI
M9`H@("`@("`@("`@("`@("`@*2P*("`@("`@("`@("`@("`@(")N:6=H="(@
M/3X@87)R87D@*`H@("`@("`@("`@("`@("`@("`@(")C;VYD:71I;VXB("`@
M("`]/B`D=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=+3YP87)T6S%=+3YT+`H@
M("`@("`@("`@("`@("`@("`@(")C;VYD:71I;VY)8V]N(B`]/B`D=&AI<RT^
M7V9O<F5C87-T+3YD87E;)&E=+3YP87)T6S%=+3YI8V]N+`H@("`@("`@("`@
M("`@("`@("`@(")W:6YD(B`@("`@("`@("`]/B`D=&AI<RT^8V]N=F5R=%-P
M965D*"1T:&ES+3Y?9F]R96-A<W0M/F1A>5LD:5TM/G!A<G1;,5TM/G=I;F0M
M/G,L(")M<&@B+"`D=6YI='-;(G=I;F0B72DL"B`@("`@("`@("`@("`@("`@
M("`@(G=I;F1'=7-T(B`@("`@(#T^("1T:&ES+3YC;VYV97)T4W!E960H)'1H
M:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^<&%R=%LQ72T^=VEN9"T^9W5S="P@
M(FUP:"(L("1U;FET<ULB=VEN9")=*2P*("`@("`@("`@("`@("`@("`@("`B
M=VEN9$1E9W)E97,B("`@/3X@)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^
M<&%R=%LQ72T^=VEN9"T^9"P*("`@("`@("`@("`@("`@("`@("`B=VEN9$1I
M<F5C=&EO;B(@/3X@)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^<&%R=%LQ
M72T^=VEN9"T^="P*("`@("`@("`@("`@("`@("`@("`B<')E8VEP:71A=&EO
M;B(@/3X@)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^<&%R=%LQ72T^<'!C
M<"P*("`@("`@("`@("`@("`@("`@("`B:'5M:61I='DB("`@("`@/3X@)'1H
M:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^<&%R=%LQ72T^:&UI9`H@("`@("`@
M("`@("`@("`@*0H@("`@("`@("`@("`I.PH*("`@("`@("`@("`@)&9O<F5C
M87-T4F5T=7)N6R)D87ES(EU;72`]("1D87D["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&9O<F5C87-T4F5T=7)N.PH@("`@?0H@("`@+R\@?7U]"GT*
M+R\@?7U]"C\^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]397)V:6-E<R]796%T:&5R+G!H<```````````````````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`R-C`V,@`Q,#4Q-30S,S<S-``P,C(U,#4`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RH@
M=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F
M='1A8G-T;W`]-"!F;VQD;65T:&]D/6UA<FME<CH@*B\*"B\J*@H@*B!014%2
M.CI397)V:6-E<U]796%T:&5R"B`J"B`J(%-E<G9I8V5S7U=E871H97(@<V5A
M<F-H97,@9F]R(&=I=F5N(&QO8V%T:6]N<R!A;F0@<F5T<FEE=F5S(&-U<G)E
M;G0*("H@=V5A=&AE<B!D871A(&%N9"P@9&5P96YD86YT(&]N('1H92!U<V5D
M('-E<G9I8V4L(&%L<V\@9F]R96-A<W1S+B!5<"!T;PH@*B!N;W<L(%-/05`@
M<V5R=FEC97,@9G)O;2!#87!E4V-I96YC92!A;F0@14I312P@6$U,(&9R;VT@
M=V5A=&AE<BYC;VT@86YD"B`J($U%5$%2+U1!1B!F<F]M(&YO86$N9V]V(&%R
M92!S=7!P;W)T960L(&9U<G1H97(@<V5R=FEC97,@=VEL;"!G970*("H@:6YC
M;'5D960L(&EF('1H97D@8F5C;VUE(&%V86EL86)L92!A;F0@87)E('!R;W!E
M<FQY(&1O8W5M96YT960N"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J
M"B`J(#Q,24-%3E-%/@H@*B!#;W!Y<FEG:'0@*&,I(#(P,#4L($%L97AA;F1E
M<B!7:7)T>@H@*B!!;&P@<FEG:'1S(')E<V5R=F5D+@H@*@H@*B!2961I<W1R
M:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W
M:71H(&]R('=I=&AO=70*("H@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D
M('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS"B`J(&%R
M92!M970Z"B`J(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU
M<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T:6-E+`H@*B`@('1H
M:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L
M86EM97(N"B`J(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU
M<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T:6-E+`H@*B`@
M('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I
M<V-L86EM97(@:6X@=&AE(&1O8W5M96YT871I;VX*("H@("!A;F0O;W(@;W1H
M97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BX*
M("H@;R!.96ET:&5R('1H92!N86UE(&]F('1H92!S;V9T=V%R92!N;W(@=&AE
M(&YA;65S(&]F(&ET<R!C;VYT<FEB=71O<G,*("H@("!M87D@8F4@=7-E9"!T
M;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C=',@9&5R:79E9"!F<F]M('1H
M:7,@<V]F='=A<F4*("H@("!W:71H;W5T('-P96-I9FEC('!R:6]R('=R:71T
M96X@<&5R;6ES<VEO;BX*("H*("H@5$A)4R!33T945T%212!)4R!04D]6241%
M1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]24R`B
M05,@25,B"B`J($%.1"!!3ED@15A04D534R!/4B!)35!,245$(%=!4E)!3E1)
M15,L($E.0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$(%1/+"!42$4*("H@24U0
M3$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!3D0@1DE43D53
M4R!&3U(@02!005)424-53$%2(%!54E!/4T4*("H@05)%($1)4T-,04E-140N
M($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'2%0@3U=.15(@3U(@0T].
M5%))0E543U)3($)%"B`J($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%
M0U0L($E.0TE$14Y404PL(%-014-)04PL($5814U03$%262P@3U(*("H@0T].
M4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L($)55"!.3U0@3$E-251%
M1"!43RP@4%)/0U5214U%3E0@3T8*("H@4U5"4U1)5%5412!'3T]$4R!/4B!3
M15)624-%4SL@3$]34R!/1B!54T4L($1!5$$L($]2(%!23T9)5%,[($]2($)5
M4TE.15-3"B`J($E.5$524E505$E/3BD@2$]7159%4B!#0553140@04Y$($].
M($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E."B`J($-/3E12
M04-4+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4("A)3D-,541)3D<@3D5'
M3$E'14Y#12!/4B!/5$A%4E=)4T4I"B`J($%225-)3D<@24X@04Y9(%=!62!/
M550@3T8@5$A%(%5312!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3
M140@3T8@5$A%"B`J(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+@H@*B`\
M+TQ)0T5.4T4^"B`J"B`J($!C871E9V]R>2`@("!796(@4V5R=FEC97,*("H@
M0'!A8VMA9V4@("`@(%-E<G9I8V5S7U=E871H97(*("H@0&%U=&AO<B`@("`@
M($%L97AA;F1E<B!7:7)T>B`\86QE>$!P8S1P+FYE=#X*("H@0&-O<'ER:6=H
M="`@(#(P,#4@06QE>&%N9&5R(%=I<G1Z"B`J($!L:6-E;G-E("`@("!H='1P
M.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H
M<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@($-64SH@)$ED.B!796%T
M:&5R+G!H<"QV(#$N-#,@,C`P-2\Q,2\Q-B`Q,CHT.#HS-"!E<G4@17AP("0*
M("H@0&QI;FL@("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]3
M97)V:6-E<U]796%T:&5R"B`J($!F:6QE<V]U<F-E"B`J+PH*+R\@>WM[(&-O
M;G-T86YT<PHO+R![>WL@8V%C:&4@=&EM97,*9&5F:6YE*")315)624-%4U]7
M14%42$527T584$E215-?54Y)5%,B+"`@("`@("`@.3`P*3L@+R\@,35-"F1E
M9FEN92@B4T525DE#15-?5T5!5$A%4E]%6%!)4D537TQ/0T%424].(BP@("`T
M,S(P,"D[("\O(#$R2`ID969I;F4H(E-%4E9)0T537U=%051(15)?15A025)%
M4U]714%42$52(BP@("`@(#$X,#`I.R`O+R`S,$T*9&5F:6YE*")315)624-%
M4U]714%42$527T584$E215-?1D]214-!4U0B+"`@("`W,C`P*3L@+R\@(#)(
M"F1E9FEN92@B4T525DE#15-?5T5!5$A%4E]%6%!)4D537TQ)3DM3(BP@("`@
M("`T,S(P,"D[("\O(#$R2`ID969I;F4H(E-%4E9)0T537U=%051(15)?15A0
M25)%4U]314%20T@B+"`@(#(T,3DR,#`I.R`O+R`R.$0*+R\@?7U]"@HO+R![
M>WL@97)R;W(@8V]D97,*9&5F:6YE*")315)624-%4U]714%42$527T524D]2
M7U-%4E9)0T5?3D]47T9/54Y$(BP@("`@("`@(#$P*3L*9&5F:6YE*")315)6
M24-%4U]714%42$527T524D]27U5.2TY/5TY?3$]#051)3TXB+"`@("`@("`@
M(#$Q*3L*9&5F:6YE*")315)624-%4U]714%42$527T524D]27U=23TY'7U-%
M4E9%4E]$051!(BP@("`@("`@(#$R*3L*9&5F:6YE*")315)624-%4U]714%4
M2$527T524D]27T-!0TA%7TE.251?1D%)3$5$(BP@("`@("`@(#$S*3L*9&5F
M:6YE*")315)624-%4U]714%42$527T524D]27T1"7TY/5%]#3TY.14-4140B
M+"`@("`@("`@(#$T*3L*9&5F:6YE*")315)624-%4U]714%42$527T524D]2
M7TA45%!?4%)/6%E?24Y604Q)1"(L("`@("`@(#$U*3L*9&5F:6YE*")315)6
M24-%4U]714%42$527T524D]27U-53D953D-37T1!5$5?24Y604Q)1"(L("`@
M(#$V*3L*9&5F:6YE*")315)624-%4U]714%42$527T524D]27U-53D953D-3
M7U)%5$9/4DU?24Y604Q)1"(L(#$W*3L*9&5F:6YE*")315)624-%4U]714%4
M2$527T524D]27TU%5$%27U-/55)#15])3E9!3$E$(BP@("`@(#$X*3L*+R\@
M?7U]"@HO+R![>WL@97)R;W(@8V]D97,@9&5F:6YE9"!B>2!W96%T:&5R+F-O
M;0ID969I;F4H(E-%4E9)0T537U=%051(15)?15)23U)?54Y+3D]73E]%4E)/
M4B(L("`@("`@("`@("`@,"D["F1E9FEN92@B4T525DE#15-?5T5!5$A%4E]%
M4E)/4E].3U],3T-!5$E/3B(L("`@("`@("`@("`@("`Q*3L*9&5F:6YE*")3
M15)624-%4U]714%42$527T524D]27TE.5D%,241?3$]#051)3TXB+"`@("`@
M("`@(#(I.PID969I;F4H(E-%4E9)0T537U=%051(15)?15)23U)?24Y604Q)
M1%]005)43D527TE$(BP@("`@(#$P,"D["F1E9FEN92@B4T525DE#15-?5T5!
M5$A%4E]%4E)/4E])3E9!3$E$7U!23T150U1?0T]$12(L("`@,3`Q*3L*9&5F
M:6YE*")315)624-%4U]714%42$527T524D]27TE.5D%,241?3$E#14Y315]+
M15DB+"`@("`Q,#(I.PHO+R!]?7T*+R\@?7U]"@HO+R![>WL@8VQA<W,@4V5R
M=FEC97-?5V5A=&AE<@HO*BH*("H@5&AI<R!C;&%S<R!A8W1S(&%S(&%N(&EN
M=&5R9F%C92!T;R!V87)I;W5S(&]N;&EN92!W96%T:&5R+7-E<G9I8V5S+@H@
M*@H@*B!`8V%T96=O<GD@("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@
M("!397)V:6-E<U]796%T:&5R"B`J($!A=71H;W(@("`@("!!;&5X86YD97(@
M5VER='H@/&%L97A`<&,T<"YN970^"B`J($!C;W!Y<FEG:'0@("`R,#`U($%L
M97AA;F1E<B!7:7)T>@H@*B!`;&EC96YS92`@("`@:'1T<#HO+W=W=RYO<&5N
M<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E
M;G-E"B`J($!V97)S:6]N("`@("!296QE87-E.B`Q+C0N,`H@*B!`;&EN:R`@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U-E<G9I8V5S7U=E
M871H97(*("HO"F-L87-S(%-E<G9I8V5S7U=E871H97(@>PH*("`@("\O('M[
M>R`F<V5R=FEC92@I"B`@("`O*BH*("`@("`J($9A8W1O<GD@9F]R(&-R96%T
M:6YG('1H92!S97)V:6-E<RUO8FIE8W1S"B`@("`@*@H@("`@("H@57-A8FQE
M(&ME>7,@9F]R('1H92!O<'1I;VYS(&%R<F%Y(&%R93H*("`@("`J(&\@9&5B
M=6<@("`@("`@("`@("`@(&5N86)L97,@9&5B=6=G:6YG(&]U='!U=`H@("`@
M("H@+2TM($-O;6UO;B!/<'1I;VYS"B`@("`@*B!O(&-A8VAE5'EP92`@("`@
M("`@("!D969I;F5S('=H870@='EP92!O9B!C86-H92!T;R!U<V4*("`@("`J
M(&\@8V%C:&5/<'1I;VYS("`@("`@('!A<W-E<R!C86-H92!O<'1I;VYS"B`@
M("`@*B!O('5N:71S1F]R;6%T("`@("`@("!U<V4@*%53*2US=&%N9&%R9"P@
M;65T<FEC(&]R(&-U<W1O;2!U;FET<PH@("`@("H@;R!C=7-T;VU5;FET<T9O
M<FUA="`@9&5F:6YE<R!T:&4@8W5S=&]M:7IE9"!U;FET<R!F;W)M870*("`@
M("`J(&\@:'1T<%1I;65O=70@("`@("`@('-E=',@=&EM96]U="!F;W(@2%14
M4"!R97%U97-T<PH@("`@("H@;R!H='1P4')O>'D@("`@("`@("`@<V5T<R!P
M<F]X>2!F;W(@2%144"!R97%U97-T<RP@<&QE87-E('5S92!T:&4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@(&YO=&%T:6]N(&AT='`Z+R];=7-E<ELZ
M<&%S<UU`76AO<W1;.G!O<G1="B`@("`@*B!O(&1A=&5&;W)M870@("`@("`@
M("!S=')I;F<@=&\@=7-E(&9O<B!D871E(&]U='!U=`H@("`@("H@;R!T:6UE
M1F]R;6%T("`@("`@("`@<W1R:6YG('1O('5S92!F;W(@=&EM92!O=71P=70*
M("`@("`J("TM+2!%2E-%($]P=&EO;G,*("`@("`J(&\@;F]N90H@("`@("H@
M+2TM($=L;V)A;%=E871H97(@3W!T:6]N<PH@("`@("H@;R!N;VYE"B`@("`@
M*B`M+2T@345405(O5$%&($]P=&EO;G,*("`@("`J(&\@9'-N("`@("`@("`@
M("`@("`@(%-T<FEN9R!F;W(@9&5F:6YI;F<@=&AE($1"(&-O;FYE8W1I;VX*
M("`@("`J(&\@9&)/<'1I;VYS("`@("`@("`@('!A<W-E<R!$0B!O<'1I;VYS
M"B`@("`@*B!O('-O=7)C94UE=&%R("`@("`@("!H='1P+"!F='`@;W(@9FEL
M92`M('1Y<&4@;V8@9&%T82US;W5R8V4@9F]R($U%5$%2"B`@("`@*B!O('-O
M=7)C95!A=&A-971A<B`@("!W:&5R92!T;R!L;V]K(&9O<B!T:&4@<V]U<F-E
M+"!54DD@;W(@9FEL97!A=&@L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("!O9B!-151!4B!I;F9O<FUA=&EO;@H@("`@("H@;R!S;W5R8V54868@("`@
M("`@("`@:'1T<"P@9G1P(&]R(&9I;&4@+2!T>7!E(&]F(&1A=&$M<V]U<F-E
M(&9O<B!4048*("`@("`J(&\@<V]U<F-E4&%T:%1A9B`@("`@('=H97)E('1O
M(&QO;VL@9F]R('1H92!S;W5R8V4L(%5222!O<B!F:6QE<&%T:"P*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@(&]F(%1!1B!I;F9O<FUA=&EO;@H@("`@
M("H@+2TM('=E871H97(N8V]M($]P=&EO;G,*("`@("`J(&\@<&%R=&YE<DE$
M("`@("`@("`@(%EO=2=L;"!R96-E:79E('1H97-E(&ME>7,@869T97(@<F5G
M:7-T97)I;F<*("`@("`J(&\@;&EC96YS94ME>2`@("`@("`@('=I=&@@=&AE
M('=E871H97(N8V]M(%A-3"US97)V:6-E"B`@("`@*B!O('!R949E=&-H("`@
M("`@("`@("!%;F%B;&5S('!R92UF971C:&EN9R!O9B!D871A(&EN(&]N92!S
M:6YG;&4@<F5Q=65S=`H@("`@("H*("`@("`J($!P87)A;2`@("!S=')I;F<@
M("`@("`@("`@("`@("`@("`@("`D<V5R=FEC90H@("`@("H@0'!A<F%M("`@
M(&%R<F%Y("`@("`@("`@("`@("`@("`@("`@("1O<'1I;VYS"B`@("`@*B!`
M<F5T=7)N("`@4$5!4E]%<G)O<GQO8FIE8W0*("`@("`J($!T:')O=W,@("!0
M14%27T5R<F]R"B`@("`@*B!`=&AR;W=S("`@4$5!4E]%<G)O<CHZ4T525DE#
M15-?5T5!5$A%4E]%4E)/4E]315)624-%7TY/5%]&3U5.1`H@("`@("H@0&%C
M8V5S<R`@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B`F<V5R=FEC92@D
M<V5R=FEC92P@)&]P=&EO;G,@/2!N=6QL*0H@("`@>PH@("`@("`@("1S97)V
M:6-E(#T@=6-F:7)S="AS=')T;VQO=V5R*"1S97)V:6-E*2D["B`@("`@("`@
M)&-L87-S;F%M92`](")397)V:6-E<U]796%T:&5R7R(N)'-E<G9I8V4["@H@
M("`@("`@("\O($-H96-K(&9O<B!D96)U9V=I;F<M;6]D92!A;F0@<V5T('-T
M=69F(&%C8V]R9&EN9VQY"B`@("`@("`@:68@*&ES7V%R<F%Y*"1O<'1I;VYS
M*2`F)B!I<W-E="@D;W!T:6]N<ULB9&5B=6<B72D@)B8@)&]P=&EO;G-;(F1E
M8G5G(ET@/CT@,BD@>PH@("`@("`@("`@("!I9B`H(61E9FEN960H(E-%4E9)
M0T537U=%051(15)?1$5"54<B*2D@>PH@("`@("`@("`@("`@("`@9&5F:6YE
M*")315)624-%4U]714%42$527T1%0E5'(BP@=')U92D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:6YC;'5D95]O;F-E*")397)V:6-E<R]796%T:&5R
M+R(N)'-E<G9I8V4N(BYP:'`B*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!I9B`H(61E9FEN960H(E-%4E9)0T537U=%051(15)?1$5"54<B*2D@
M>PH@("`@("`@("`@("`@("`@9&5F:6YE*")315)624-%4U]714%42$527T1%
M0E5'(BP@9F%L<V4I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@($!I;F-L
M=61E7V]N8V4H(E-E<G9I8V5S+U=E871H97(O(BXD<V5R=FEC92XB+G!H<"(I
M.PH@("`@("`@('T*"B`@("`@("`@+R\@3F\@<W5C:"!S97)V:6-E+BXN(&)A
M:6P@;W5T"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)&-L87-S;F%M92DI
M('L*("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E
M17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E]315)624-%7TY/5%]&3U5.
M1"P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("\O
M($-R96%T92!S97)V:6-E(&%N9"!R971U<FX*("`@("`@("`D97)R;W(@/2!N
M=6QL.PH@("`@("`@($`D;V)J(#T@)FYE=R`D8VQA<W-N86UE*"1O<'1I;VYS
M+"`D97)R;W(I.PH*("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%
M<G)O<B@D97)R;W(I*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1O8FH["B`@("`@
M("`@?0H@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&%P:59E<G-I;VXH
M*0H@("`@+RHJ"B`@("`@*B!&;W(@>6]U<B!C;VYV96YI96YC92P@=VAE;B!)
M(&-O;64@=7`@=VET:"!C:&%N9V5S(&EN('1H92!!4$DN+BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N("!S=')I;F<*("`@("`J($!A8V-E<W,@('!U8FQI8PH@
M("`@("HO"B`@("!F=6YC=&EO;B!A<&E697)S:6]N*"D*("`@('L*("`@("`@
M("!R971U<FX@(C$N-"(["B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@
M7V5R<F]R365S<V%G92@I"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&UE
M<W-A9V4@9F]R(&$@8V5R=&%I;B!E<G)O<B!C;V1E"B`@("`@*@H@("`@("H@
M0'!A<F%M("`@4$5!4E]%<G)O<GQI;G0@("`@("`@("`@("`@("1V86QU90H@
M("`@("H@0')E='5R;B`@<W1R:6YG"B`@("`@*B!`86-C97-S("!P<FEV871E
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]E<G)O<DUE<W-A9V4H)'9A;'5E*0H@
M("`@>PH@("`@("`@('-T871I8R`D97)R;W)-97-S86=E<SL*("`@("`@("!I
M9B`H(6ES<V5T*"1E<G)O<DUE<W-A9V5S*2D@>PH@("`@("`@("`@("`D97)R
M;W)-97-S86=E<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@4T525DE#15-?
M5T5!5$A%4E]%4E)/4E]315)624-%7TY/5%]&3U5.1"`@("`@("`@(#T^(")2
M97%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(BP*("`@("`@
M("`@("`@("`@(%-%4E9)0T537U=%051(15)?15)23U)?54Y+3D]73E],3T-!
M5$E/3B`@("`@("`@("`]/B`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB
M+`H@("`@("`@("`@("`@("`@4T525DE#15-?5T5!5$A%4E]%4E)/4E]74D].
M1U]315)615)?1$%402`@("`@("`@(#T^(")397)V97(@9&%T82!W<F]N9R!O
M<B!N;W0@879A:6QA8FQE+B(L"B`@("`@("`@("`@("`@("!315)624-%4U]7
M14%42$527T524D]27T-!0TA%7TE.251?1D%)3$5$("`@("`@("`@/3X@(D-A
M8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(BP*("`@("`@("`@("`@("`@
M(%-%4E9)0T537U=%051(15)?15)23U)?1$)?3D]47T-/3DY%0U1%1"`@("`@
M("`@("`]/B`B365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(L"B`@("`@("`@
M("`@("`@("!315)624-%4U]714%42$527T524D]27TA45%!?4%)/6%E?24Y6
M04Q)1"`@("`@("`@/3X@(E1H92!G:79E;B!P<F]X>2!I<R!N;W0@=F%L:60L
M('!L96%S92!U<V4@=&AE(&YO=&%T:6]N(&AT='`Z+R];=7-E<ELZ<&%S<UU`
M76AO<W1;.G!O<G1=+B(L"B`@("`@("`@("`@("`@("!315)624-%4U]714%4
M2$527T524D]27U-53D953D-37T1!5$5?24Y604Q)1"`@("`@/3X@(E1H92!D
M871E('EO=2=V92!P<F]V:61E9"!F;W(@8V%L8W5L871I;VX@;V8@<W5N<FES
M92]S=6YS970@:7,@;F]T(&$@=&EM97-T86UP+B(L"B`@("`@("`@("`@("`@
M("!315)624-%4U]714%42$527T524D]27U-53D953D-37U)%5$9/4DU?24Y6
M04Q)1"`@/3X@(E1H92!R971U<FX@9F]R;6%T('EO=2=V92!P<F]V:61E9"!F
M;W(@8V%L8W5L871I;VX@;V8@<W5N<FES92]S=6YS970@:7,@;F]T('9A;&ED
M+B(L"B`@("`@("`@("`@("`@("!315)624-%4U]714%42$527T524D]27TU%
M5$%27U-/55)#15])3E9!3$E$("`@("`@/3X@(E1H92!-151!4B]4048@<V]U
M<F-E('EO=2=V92!P<F]V:61E9"!H87,@86X@:6YV86QI9"!T>7!E(&]R('!A
M=&@N(BP*("`@("`@("`@("`@("`@(%-%4E9)0T537U=%051(15)?15)23U)?
M54Y+3D]73E]%4E)/4B`@("`@("`@("`@("`]/B`B06X@=6YK;F]W;B!E<G)O
M<B!H87,@;V-C=7)E9"XB+`H@("`@("`@("`@("`@("`@4T525DE#15-?5T5!
M5$A%4E]%4E)/4E].3U],3T-!5$E/3B`@("`@("`@("`@("`@(#T^(").;R!L
M;V-A=&EO;B!P<F]V:61E9"XB+`H@("`@("`@("`@("`@("`@4T525DE#15-?
M5T5!5$A%4E]%4E)/4E])3E9!3$E$7TQ/0T%424].("`@("`@("`@(#T^("))
M;G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(L"B`@("`@("`@("`@("`@("!3
M15)624-%4U]714%42$527T524D]27TE.5D%,241?4$%25$Y%4E])1"`@("`@
M("`@/3X@(DEN=F%L:60@<&%R=&YE<B!I9"XB+`H@("`@("`@("`@("`@("`@
M4T525DE#15-?5T5!5$A%4E]%4E)/4E])3E9!3$E$7U!23T150U1?0T]$12`@
M("`@(#T^("));G9A;&ED('!R;V1U8W0@8V]D92XB+`H@("`@("`@("`@("`@
M("`@4T525DE#15-?5T5!5$A%4E]%4E)/4E])3E9!3$E$7TQ)0T5.4T5?2T59
M("`@("`@(#T^("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*("`@("`@("`@("`@
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII
M<T5R<F]R*"1V86QU92DI('L*("`@("`@("`@("`@)'9A;'5E(#T@)'9A;'5E
M+3YG971#;V1E*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@:7-S970H
M)&5R<F]R365S<V%G97-;)'9A;'5E72D@/R`D97)R;W)-97-S86=E<ULD=F%L
M=65=(#H@)&5R<F]R365S<V%G97-;4T525DE#15-?5T5!5$A%4E]%4E)/4E]5
M3DM.3U=.7T524D]273L*("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!I
M<T5R<F]R*"D*("`@("\J*@H@("`@("H@0VAE8VMS(&9O<B!A;B!E<G)O<B!O
M8FIE8W0L('-A;64@87,@:6X@4$5!4@H@("`@("H*("`@("`J($!P87)A;2`@
M(%!%05)?17)R;W)\;6EX960@("`@("`@("`@("`D=F%L=64*("`@("`J($!R
M971U<FX@(&)O;VP*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!I<T5R<F]R*"1V86QU92D*("`@('L*("`@("`@("!R971U
M<FX@*&ES7V]B:F5C="@D=F%L=64I("8F("AS=')T;VQO=V5R*&=E=%]C;&%S
M<R@D=F%L=64I*2`]/2`B<&5A<E]E<G)O<B(@?'P@:7-?<W5B8VQA<W-?;V8H
M)'9A;'5E+"`B<&5A<E]E<G)O<B(I*2D["B`@("!]"B`@("`O+R!]?7T*"B`@
M("`O+R![>WL@)G)A:7-E17)R;W(H*0H@("`@+RHJ"B`@("`@*B!#<F5A=&5S
M(&5R<F]R+"!S86UE(&%S(&EN(%!%05(@=VET:"!A(&-U<W1O;6EZ960@9FQA
M=F]R"B`@("`@*@H@("`@("H@0'!A<F%M("`@:6YT("`@("`@("`@("`@("`@
M("`@("`@("`@("1C;V1E"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@
M("`@("`@("`@("`@("`@)&9I;&4*("`@("`J($!P87)A;2`@(&EN="`@("`@
M("`@("`@("`@("`@("`@("`@("`D;&EN90H@("`@("H@0')E='5R;B`@4$5!
M4E]%<G)O<@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!F
M=6YC=&EO;B`F<F%I<V5%<G)O<B@D8V]D92`](%-%4E9)0T537U=%051(15)?
M15)23U)?54Y+3D]73E]%4E)/4BP@)&9I;&4@/2`B(BP@)&QI;F4@/2`P*0H@
M("`@>PH@("`@("`@("\O(%1H:7,@<VAO=6QD(&EM<')O=F4@=&AE('!E<F9O
M<FUA;F-E(&]F('1H92!S8W)I<'0L(&%S(%!%05(@:7,@;VYL>2!I;F-L=61E
M9"P@=VAE;@H@("`@("`@("\O(')E86QL>2!N965D960N"B`@("`@("`@:6YC
M;'5D95]O;F-E(")014%2+G!H<"(["@H@("`@("`@("1M97-S86=E(#T@(E-E
M<G9I8V5S7U=E871H97(B.PH@("`@("`@(&EF("@D9FEL92`A/2`B(B`F)B`D
M;&EN92`^(#`I('L*("`@("`@("`@("`@)&UE<W-A9V4@+CT@(B`H(BYB87-E
M;F%M92@D9FEL92DN(CHB+B1L:6YE+B(I(CL*("`@("`@("!]"B`@("`@("`@
M)&UE<W-A9V4@+CT@(CH@(BY397)V:6-E<U]796%T:&5R.CI?97)R;W)-97-S
M86=E*"1C;V1E*3L*"B`@("`@("`@)&5R<F]R(#T@4$5!4CHZ<F%I<V5%<G)O
M<B@D;65S<V%G92P@)&-O9&4L(%!%05)?15)23U)?4D5455).+"!%7U5315)?
M3D]424-%+"`B4V5R=FEC97-?5V5A=&AE<E]%<G)O<B(L(&YU;&PL(&9A;'-E
M*3L*("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@?0H@("`@+R\@?7U]"GT*
M+R\@?7U]"C\^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]33T%0+P``````````````````````````````````````````
M```````````````````````````````````````````P,#`P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<S-P`P,3<S-3$`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-/05`O0F%S92YP:'``````````
M````````````````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3(R,3,S`#$P-3$U
M-#,S-S,W`#`R,#<S-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@5&AI<R!F:6QE(&QO861S(&%L;"!R
M97%U:7)E9"!L:6)R87)I97,L(&1E9FEN97,@8V]N<W1A;G1S('5S960@86-R
M;W-S('1H90H@*B!33T%0('!A8VMA9V4L(&%N9"!D969I;F5S('1H92!B87-E
M(&-L87-S97,@=&AA="!M;W-T(&]T:&5R(&-L87-S97,@;V8@=&AI<PH@*B!P
M86-K86=E(&5X=&5N9"X*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*
M("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E
M<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L"B`J('1H870@:7,@8G5N
M9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A
M;F0@:7,@879A:6QA8FQE(&%T"B`J('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M
M=V5B(&%T(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L
M:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I=`H@*B!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O(&QI
M8V5N<V5`<&AP+FYE="!S;R!W92!C86X*("H@;6%I;"!Y;W4@82!C;W!Y(&EM
M;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!796(@4V5R=FEC97,*("H@
M0'!A8VMA9V4@("`@4T]!4`H@*B!`875T:&]R("`@("!$:65T<FEC:"!!>6%L
M82`\9&EE=')I8VA`9V%N>#0N8V]M/B!/<FEG:6YA;"!!=71H;W(*("H@0&%U
M=&AO<B`@("`@4VAA;F4@0V%R879E;R`\4VAA;F5`0V%R879E;RYC;VT^("`@
M4&]R="!T;R!014%2(&%N9"!M;W)E"B`J($!A=71H;W(@("`@($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/B`@($UA:6YT96YA;F-E"B`J($!A
M=71H;W(@("`@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^("`@("`@
M($UA:6YT96YA;F-E"B`J($!C;W!Y<FEG:'0@(#(P,#,M,C`P-2!4:&4@4$A0
M($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S)?,#(N='AT("!02%`@3&EC96YS92`R+C`R"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]33T%0"B`J+PH*+RHJ"B`J
M(%-/05!?3T)*14-47U-44E5#5"!M86ME<R!014%2.CI33T%0('5S92!O8FIE
M8W1S(&9O<B!33T%0('-T<G5C='5R97,@<F%T:&5R"B`J('1H86X@87)R87ES
M+B`@5&AI<R!H87,@8F5E;B!D;VYE('1O('!R;W9I9&4@82!C;&]S97(@;6%T
M8V@@=&\@<&AP+7-O87`N("!)9@H@*B!T:&4@;VQD(&)E:&%V:6]U<B!I<R!N
M965D960L('-E="!T;R!F86QS92X@(%1H92!O;&0@8F5H879I;W5R(&ES"B`J
M(&1E<')E8V%T960N"B`J"B`J($!G;&]B86P@8F]O;"`D1TQ/0D%,4ULG4T]!
M4%]/0DI%0U1?4U1254-4)UT*("HO"B1'3$]"04Q36R=33T%07T]"2D5#5%]3
M5%)50U0G72`]('1R=64["@HO*BH*("H@4T]!4%]205=?0T].5D525"!M86ME
M<R!014%2.CI33T%0(&%T=&5M<'0@=&\@9&5T97)M:6YE('=H870@4T]!4"!T
M>7!E(&$@4$A0"B`J('-T<FEN9R!#3U5,1"!B92X@(%1H:7,@;6%Y(')E<W5L
M="!I;B!S;&EG:'1L>2!B971T97(@:6YT97)O<&5R86)I;&ET>2!W:&5N"B`J
M('EO=2!A<F4@;F]T('5S:6YG(%=31$PL(&%N9"!A<F4@8F5I;F<@;&%Z>2!A
M;F0@;F]T('5S:6YG(%-/05!?5F%L=64@=&\*("H@9&5F:6YE('1Y<&5S(&9O
M<B!Y;W5R('9A;'5E<RX*("H*("H@0&=L;V)A;"!B;V]L("1'3$]"04Q36R=3
M3T%07U)!5U]#3TY615)4)UT*("HO"B1'3$]"04Q36R=33T%07U)!5U]#3TY6
M15)4)UT@/2!F86QS93L*"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PIR97%U
M:7)E7V]N8V4@)U-/05`O5'EP92]D871E5&EM92YP:'`G.PIR97%U:7)E7V]N
M8V4@)U-/05`O5'EP92]H97A":6YA<GDN<&AP)SL*"B\O(&]P=&EO;F%L(&9E
M871U<F5S"B1'3$]"04Q36R=33T%07V]P=&EO;G,G72`](&%R<F%Y*"D["@I`
M:6YC;'5D95]O;F-E("=-86EL+VUI;65087)T+G!H<"<["D!I;F-L=61E7V]N
M8V4@)TUA:6PO;6EM941E8V]D92YP:'`G.PII9B`H8VQA<W-?97AI<W1S*"=-
M86EL7VUI;65087)T)RDI('L*("`@("1'3$]"04Q36R=33T%07V]P=&EO;G,G
M75LG36EM92==(#T@,3L*("`@(&1E9FEN92@G34%)3%]-24U%4$%25%]#4DQ&
M)RP@(EQR7&XB*3L*?0H*0&EN8VQU9&5?;VYC92`G3F5T+T1)344N<&AP)SL*
M:68@*&-L87-S7V5X:7-T<R@G3F5T7T1)345?365S<V%G92<I*2!["B`@("`D
M1TQ/0D%,4ULG4T]!4%]O<'1I;VYS)UU;)T1)344G72`](#$["GT*"B\J*@H@
M*B!%;F%B;&4@9&5B=6=G:6YG(&EN9F]R;6%T:6]N/PH@*@H@*B!`9VQO8F%L
M(&)O;VP@)$=,3T)!3%-;)U-/05!?1$5"54<G70H@*B!`;F%M92`D4T]!4%]$
M14)51PH@*B\*)$=,3T)!3%-;)U-/05!?1$5"54<G72`](&9A;'-E.PH*:68@
M*"%F=6YC=&EO;E]E>&ES=',H)W9E<G-I;VY?8V]M<&%R92<I('Q\"B`@("!V
M97)S:6]N7V-O;7!A<F4H<&AP=F5R<VEO;B@I+"`G-"XQ)RP@)SPG*2D@>PH@
M("`@9&EE*")R97%U:7)E<R!02%`@-"XQ(&]R(&AI9VAE<EQN(BD["GT*:68@
M*'9E<G-I;VY?8V]M<&%R92AP:'!V97)S:6]N*"DL("<T+C$G+"`G/CTG*2`F
M)@H@("`@=F5R<VEO;E]C;VUP87)E*'!H<'9E<G-I;VXH*2P@)S0N,B<L("<\
M)RDI('L*("`@(&1E9FEN92@G1DQ/050G+"`G9&]U8FQE)RD["GT@96QS92![
M"B`@("!D969I;F4H)T9,3T%4)RP@)V9L;V%T)RD["GT*"FEF("@A9&5F:6YE
M9"@G24Y&)RDI('L*("`@(&1E9FEN92@G24Y&)RP@,2XX93,P-RD["GT*:68@
M*"%D969I;F5D*"=.04XG*2D@>PH@("`@9&5F:6YE*"=.04XG+"`P+C`I.PI]
M"@ID969I;F4H)U-/05!?3$E"4D%265]615)324].)RP@)S`N."XP4D,T)RD[
M"F1E9FEN92@G4T]!4%],24)205)97TY!344G+"`@("`G4$5!4BU33T%0(#`N
M."XP4D,T+61E=F5L)RD["@HO+R!3970@<V-H96UA('9E<G-I;VXN"F1E9FEN
M92@G4T]!4%]834Q?4T-(14U!7U9%4E-)3TXG+"`@)VAT='`Z+R]W=W<N=S,N
M;W)G+S(P,#$O6$U,4V-H96UA)RD["F1E9FEN92@G4T]!4%]834Q?4T-(14U!
M7TE.4U1!3D-%)RP@)VAT='`Z+R]W=W<N=S,N;W)G+S(P,#$O6$U,4V-H96UA
M+6EN<W1A;F-E)RD["F1E9FEN92@G4T]!4%]834Q?4T-(14U!7S$Y.3DG+"`@
M("`@)VAT='`Z+R]W=W<N=S,N;W)G+S$Y.3DO6$U,4V-H96UA)RD["F1E9FEN
M92@G4T]!4%]30TA%34$G+"`@("`@("`@("`@("`@)VAT='`Z+R]S8VAE;6%S
M+GAM;'-O87`N;W)G+W=S9&PO<V]A<"\G*3L*9&5F:6YE*"=33T%07U-#2$5-
M05]%3D-/1$E.1R<L("`@("`G:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O
M<V]A<"]E;F-O9&EN9R\G*3L*9&5F:6YE*"=33T%07T5.5D5,3U`G+"`@("`@
M("`@("`@("`G:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O<V]A<"]E;G9E
M;&]P92\G*3L*"F1E9FEN92@G4T-(14U!7T1)4T-/)RP@("`@("`@("`@("`@
M)VAT='`Z+R]S8VAE;6%S+GAM;'-O87`N;W)G+V1I<V-O+R<I.PID969I;F4H
M)U-#2$5-05]$25-#3U]30TPG+"`@("`@("`@("=H='1P.B\O<V-H96UA<RYX
M;6QS;V%P+F]R9R]D:7-C;R]S8VPO)RD["@ID969I;F4H)U-#2$5-05]33T%0
M)RP@("`@("`@("`@("`@("=H='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]W
M<V1L+W-O87`O)RD["F1E9FEN92@G4T-(14U!7U-/05!?2%144"<L("`@("`@
M("`@)VAT='`Z+R]S8VAE;6%S+GAM;'-O87`N;W)G+W-O87`O:'1T<"<I.PID
M969I;F4H)U-#2$5-05]74T1,7TA45%`G+"`@("`@("`@("=H='1P.B\O<V-H
M96UA<RYX;6QS;V%P+F]R9R]W<V1L+VAT='`O)RD["F1E9FEN92@G4T-(14U!
M7TU)344G+"`@("`@("`@("`@("`@)VAT='`Z+R]S8VAE;6%S+GAM;'-O87`N
M;W)G+W=S9&PO;6EM92\G*3L*9&5F:6YE*"=30TA%34%?5U-$3"<L("`@("`@
M("`@("`@("`G:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O=W-D;"\G*3L*
M9&5F:6YE*"=30TA%34%?1$E-12<L("`@("`@("`@("`@("`G:'1T<#HO+W-C
M:&5M87,N>&UL<V]A<"YO<F<O=W,O,C`P,B\P-"]D:6UE+W=S9&PO)RD["F1E
M9FEN92@G4T-(14U!7T-/3E1%3E0G+"`@("`@("`@("`@)VAT='`Z+R]S8VAE
M;6%S+GAM;'-O87`N;W)G+W=S+S(P,#(O,#0O8V]N=&5N="UT>7!E+R<I.PID
M969I;F4H)U-#2$5-05]2148G+"`@("`@("`@("`@("`@("=H='1P.B\O<V-H
M96UA<RYX;6QS;V%P+F]R9R]W<R\R,#`R+S`T+W)E9F5R96YC92\G*3L*"F1E
M9FEN92@G4T]!4%]$149!54Q47T5.0T]$24Y')RP@("=55$8M."<I.PH*:68@
M*"%F=6YC=&EO;E]E>&ES=',H)VES7V$G*2D@>PH@("`@9G5N8W1I;VX@:7-?
M82@F)&]B:F5C="P@)&-L87-S7VYA;64I"B`@("!["B`@("`@("`@:68@*'-T
M<G1O;&]W97(H9V5T7V-L87-S*"1O8FIE8W0I*2`]/2`D8VQA<W-?;F%M92D@
M>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N(&ES7W-U8F-L87-S7V]F*"1O8FIE8W0L("1C;&%S<U]N86UE*3L*
M("`@('T*?0H*:68@*"%C;&%S<U]E>&ES=',H)W-T9$-L87-S)RDI('L*("`@
M("\J(%!(4#4@9&]E<VXG="!D969I;F4@=&AI<S\@*B\*("`@(&-L87-S('-T
M9$-L87-S('L*("`@("`@("!F=6YC=&EO;B!?7V-O;G-T<G5C=&]R*"D@>WT*
M("`@('T*?0H*8VQA<W,@4T]!4%]"87-E7T]B:F5C="!E>'1E;F1S(%!%05(*
M>PH@("`@+RHJ"B`@("`@*B!3=&]R92!D96)U9V=I;F<@:6YF;W)M871I;VX@
M:6X@)%]D96)U9U]D871A/PH@("`@("H*("`@("`J($!S964@)&1E8G5G7V1A
M=&$L(%-/05!?0F%S90H@("`@("H@0'9A<B!B;V]L96%N("1?9&5B=6=?9FQA
M9PH@("`@("HO"B`@("!V87(@)%]D96)U9U]F;&%G(#T@9F%L<V4["@H@("`@
M+RHJ"B`@("`@*B!3=')I;F<@8V]N=&%I;FEN9R!D96)U9V=I;F<@:6YF;W)M
M871I;VX@:68@)%]D96)U9U]F;&%G(&ES('1R=64N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J($!S964@)&1E8G5G7V9L86<L(%-/05!?
M0F%S90H@("`@("H@0'9A<B!S=')I;F<@)%]D96)U9U]D871A"B`@("`@*B\*
M("`@('9A<B`D7V1E8G5G7V1A=&$@/2`G)SL*"B`@("`O*BH*("`@("`J(%-U
M<'!O<G1E9"!E;F-O9&EN9W,L(&QI;6ET960@8GD@6$U,(&5X=&5N<VEO;BX*
M("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y("1?96YC;V1I;F=S"B`@("`@*B\*
M("`@('9A<B`D7V5N8V]D:6YG<R`](&%R<F%Y*"=)4T\M.#@U.2TQ)RP@)U53
M+4%30TE))RP@)U541BTX)RD["@H@("`@+RHJ"B`@("`@*B!&875L="!C;V1E
M+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG("1?;7EF875L=&-O9&4*("`@
M("`J+PH@("`@=F%R("1?;7EF875L=&-O9&4@/2`G)SL*"B`@("`O*BH*("`@
M("`J(%)E8V5N="!014%27T5R<F]R(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M=F%R(%!%05)?17)R;W(@)&9A=6QT"B`@("`@*B\*("`@('9A<B`D9F%U;'0@
M/2!N=6QL.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@
M("`@("H@0'-E92`D9&5B=6=?9&%T82P@7V1E8G5G*"D*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1F875L=&-O9&4@($5R<F]R(&-O9&4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%-/05!?0F%S95]/8FIE8W0H)&9A=6QT8V]D92`]
M("=#;&EE;G0G*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;7EF875L=&-O9&4@
M/2`D9F%U;'1C;V1E.PH@("`@("`@("1T:&ES+3Y?9&5B=6=?9FQA9R`]("1'
M3$]"04Q36R=33T%07T1%0E5')UT["B`@("`@("`@<&%R96YT.CI014%2*"=3
M3T%07T9A=6QT)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!286ES97,@82!3
M3T%0(&5R<F]R+@H@("`@("H*("`@("`J(%!L96%S92!R969E<B!T;R!T:&4@
M4T]!4"!D969I;FET:6]N(&9O<B!A;B!I;7!R97-S:6]N(&]F('=H870@82!C
M97)T86EN"B`@("`@*B!P87)A;65T97(@<W1A;F1S(&9O<BX*("`@("`J"B`@
M("`@*B!5<V4@)&1E8G5G7V9L86<@=&\@<W1O<F4@97)R;W)S('1O('1H92!M
M96UB97(@=F%R:6%B;&4@)&1E8G5G7V1A=&$*("`@("`J"B`@("`@*B!`<V5E
M("1D96)U9U]F;&%G+"`D9&5B=6=?9&%T82P@4T]!4%]&875L=`H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F=\;V)J96-T("1S='(@($5R<F]R(&UE<W-A
M9V4@;W(@;V)J96-T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&5T86EL("`@
M("`@1&5T86EL960@97)R;W(@;65S<V%G92X*("`@("`J($!P87)A;2!S=')I
M;F<@)&%C=&]R55))"B`@("`@*B!`<&%R86T@;6EX960@)&-O9&4*("`@("`J
M($!P87)A;2!M:7AE9"`D;6]D90H@("`@("H@0'!A<F%M(&UI>&5D("1O<'1I
M;VYS"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<VMI<&US9PH@("`@("HO"B`@
M("!F=6YC=&EO;B`F7W)A:7-E4V]A<$9A=6QT*"1S='(L("1D971A:6P@/2`G
M)RP@)&%C=&]R55))(#T@)R<L("1C;V1E(#T@;G5L;"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&UO9&4@/2!N=6QL+"`D;W!T:6]N<R`](&YU
M;&PL("1S:VEP;7-G(#T@9F%L<V4I"B`@("!["B`@("`@("`@+R\@4&%S<R!T
M:')O=6=H('!R979I;W5S(&9A=6QT<RX*("`@("`@("`D:7-?:6YS=&%N8V4@
M/2!I<W-E="@D=&AI<RD["B`@("`@("`@:68@*&ES7V]B:F5C="@D<W1R*2D@
M>PH@("`@("`@("`@("`D9F%U;'0@/28@)'-T<CL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!I9B`H(21C;V1E*2!["B`@("`@("`@("`@("`@("`D
M8V]D92`]("1I<U]I;G-T86YC92`_("1T:&ES+3Y?;7EF875L=&-O9&4@.B`G
M0VQI96YT)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D9F%U;'0@/28@
M;F5W(%-/05!?1F%U;'0H)'-T<BP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1C;V1E+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&%C=&]R55))+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&1E=&%I;"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1M;V1E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&]P=&EO;G,I.PH@("`@("`@('T*("`@("`@("!I
M9B`H)&ES7VEN<W1A;F-E*2!["B`@("`@("`@("`@("1T:&ES+3YF875L="`]
M)B`D9F%U;'0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&9A=6QT.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]?:7-F875L="@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3YF875L="`A/2!N=6QL.PH@("`@?0H*("`@(&9U;F-T
M:6]N("9?7V=E=&9A=6QT*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/F9A=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A('-T<FEN9R!T
M;R!T:&4@9&5B=6<@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1S=')I;F<@($1E8G5G9VEN9R!M97-S86=E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?9&5B=6<H)'-T<FEN9RD*("`@('L*("`@("`@("!I9B`H)'1H:7,M
M/E]D96)U9U]F;&%G*2!["B`@("`@("`@("`@("1T:&ES+3Y?9&5B=6=?9&%T
M82`N/2!G971?8VQA<W,H)'1H:7,I("X@)SH@)R`N"B`@("`@("`@("`@("`@
M("!S=')?<F5P;&%C92@G/B<L("(^7')<;B(L("1S=')I;F<I("X@(EQN(CL*
M("`@("`@("!]"B`@("!]"@I]"@HO*BH*("H@0V]M;6]N(&)A<V4@8VQA<W,@
M;V8@86QL(%-/05`@8VQA<W-E<RX*("H*("H@0&%C8V5S<R`@('!U8FQI8PH@
M*B!`<&%C:V%G92`@4T]!4`H@*B!`875T:&]R("`@4VAA;F4@0V%R879E;R`\
M<VAA;F5`<&AP+FYE=#X@0V]N=F5R<VEO;B!T;R!014%2(&%N9"!U<&1A=&5S
M"B`J+PIC;&%S<R!33T%07T)A<V4@97AT96YD<R!33T%07T)A<V5?3V)J96-T
M"GL*("`@('9A<B`D7UA-3%-C:&5M82`](&%R<F%Y*"=H='1P.B\O=W=W+G<S
M+F]R9R\R,#`Q+UA-3%-C:&5M82<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]834Q38VAE;6$G*3L*("`@
M('9A<B`D7UA-3%-C:&5M859E<G-I;VX@/2`G:'1T<#HO+W=W=RYW,RYO<F<O
M,C`P,2]834Q38VAE;6$G.PH*("`@("\O(&QO860@='EP97,@:6YT;R!T>7!E
M;6%P(&%R<F%Y"B`@("!V87(@)%]T>7!E;6%P(#T@87)R87DH"B`@("`@("`@
M)VAT='`Z+R]W=W<N=S,N;W)G+S(P,#$O6$U,4V-H96UA)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@)W-T<FEN9R<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@
M("=B;V]L96%N)R`]/B`G8F]O;&5A;B<L"B`@("`@("`@("`@("=F;&]A="<@
M/3X@1DQ/050L"B`@("`@("`@("`@("=D;W5B;&4G(#T^($9,3T%4+`H@("`@
M("`@("`@("`G9&5C:6UA;"<@/3X@1DQ/050L"B`@("`@("`@("`@("=D=7)A
M=&EO;B<@/3X@)VEN=&5G97(G+`H@("`@("`@("`@("`G9&%T951I;64G(#T^
M("=S=')I;F<G+`H@("`@("`@("`@("`G=&EM92<@/3X@)W-T<FEN9R<L"B`@
M("`@("`@("`@("=D871E)R`]/B`G<W1R:6YG)RP*("`@("`@("`@("`@)V=9
M96%R36]N=&@G(#T^("=I;G1E9V5R)RP*("`@("`@("`@("`@)V=996%R)R`]
M/B`G:6YT96=E<B<L"B`@("`@("`@("`@("=G36]N=&A$87DG(#T^("=I;G1E
M9V5R)RP*("`@("`@("`@("`@)V=$87DG(#T^("=I;G1E9V5R)RP*("`@("`@
M("`@("`@)V=-;VYT:"<@/3X@)VEN=&5G97(G+`H@("`@("`@("`@("`G:&5X
M0FEN87)Y)R`]/B`G<W1R:6YG)RP*("`@("`@("`@("`@)V)A<V4V-$)I;F%R
M>2<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("\O(&1E<FEV960@9&%T871Y
M<&5S"B`@("`@("`@("`@("=N;W)M86QI>F5D4W1R:6YG)R`]/B`G<W1R:6YG
M)RP*("`@("`@("`@("`@)W1O:V5N)R`]/B`G<W1R:6YG)RP*("`@("`@("`@
M("`@)VQA;F=U86=E)R`]/B`G<W1R:6YG)RP*("`@("`@("`@("`@)TY-5$]+
M14XG(#T^("=S=')I;F<G+`H@("`@("`@("`@("`G3DU43TM%3E,G(#T^("=S
M=')I;F<G+`H@("`@("`@("`@("`G3F%M92<@/3X@)W-T<FEN9R<L"B`@("`@
M("`@("`@("=.0TYA;64G(#T^("=S=')I;F<G+`H@("`@("`@("`@("`G240G
M(#T^("=S=')I;F<G+`H@("`@("`@("`@("`G2412148G(#T^("=S=')I;F<G
M+`H@("`@("`@("`@("`G24121493)R`]/B`G<W1R:6YG)RP*("`@("`@("`@
M("`@)T5.5$E462<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=%3E1)5$E%
M4R<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=I;G1E9V5R)R`]/B`G:6YT
M96=E<B<L"B`@("`@("`@("`@("=N;VY0;W-I=&EV94EN=&5G97(G(#T^("=I
M;G1E9V5R)RP*("`@("`@("`@("`@)VYE9V%T:79E26YT96=E<B<@/3X@)VEN
M=&5G97(G+`H@("`@("`@("`@("`G;&]N9R<@/3X@)VEN=&5G97(G+`H@("`@
M("`@("`@("`G:6YT)R`]/B`G:6YT96=E<B<L"B`@("`@("`@("`@("=S:&]R
M="<@/3X@)VEN=&5G97(G+`H@("`@("`@("`@("`G8GET92<@/3X@)W-T<FEN
M9R<L"B`@("`@("`@("`@("=N;VY.96=A=&EV94EN=&5G97(G(#T^("=I;G1E
M9V5R)RP*("`@("`@("`@("`@)W5N<VEG;F5D3&]N9R<@/3X@)VEN=&5G97(G
M+`H@("`@("`@("`@("`G=6YS:6=N961);G0G(#T^("=I;G1E9V5R)RP*("`@
M("`@("`@("`@)W5N<VEG;F5D4VAO<G0G(#T^("=I;G1E9V5R)RP*("`@("`@
M("`@("`@)W5N<VEG;F5D0GET92<@/3X@)VEN=&5G97(G+`H@("`@("`@("`@
M("`G<&]S:71I=F5);G1E9V5R)R`@/3X@)VEN=&5G97(G+`H@("`@("`@("`@
M("`G86YY5'EP92<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=A;GE54DDG
M(#T^("=S=')I;F<G+`H@("`@("`@("`@("`G44YA;64G(#T^("=S=')I;F<G
M"B`@("`@("`@*2P*("`@("`@("`G:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]8
M34Q38VAE;6$G(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:30G(#T^("=I;G1E
M9V5R)RP*("`@("`@("`@("`@)VEN="<@/3X@)VEN=&5G97(G+`H@("`@("`@
M("`@("`G8F]O;&5A;B<@/3X@)V)O;VQE86XG+`H@("`@("`@("`@("`G<W1R
M:6YG)R`]/B`G<W1R:6YG)RP*("`@("`@("`@("`@)V1O=6)L92<@/3X@1DQ/
M050L"B`@("`@("`@("`@("=F;&]A="<@/3X@1DQ/050L"B`@("`@("`@("`@
M("=D871E5&EM92<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=T:6UE26YS
M=&%N="<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=B87-E-C1":6YA<GDG
M(#T^("=S=')I;F<G+`H@("`@("`@("`@("`G8F%S938T)R`]/B`G<W1R:6YG
M)RP*("`@("`@("`@("`@)W5R+71Y<&4G(#T^("=S=')I;F<G"B`@("`@("`@
M*2P*("`@("`@("`G:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O<V]A<"]E
M;F-O9&EN9R\G(#T^(&%R<F%Y*`H@("`@("`@("`@("`G8F%S938T)R`]/B`G
M<W1R:6YG)RP*("`@("`@("`@("`@)V%R<F%Y)R`]/B`G87)R87DG+`H@("`@
M("`@("`@("`G07)R87DG(#T^("=A<G)A>2<L"B`@("`@("`@("`@("=3=')U
M8W0G(#T^("=A<G)A>2<I"B`@("`I.PH*("`@("\J*@H@("`@("H@1&5F875L
M="!C;&%S<R!N86UE('1O('5S92!F;W(@9&5C;V1E9"!R97-P;VYS92!O8FIE
M8W1S+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG("1?9&5F875L=$]B:F5C
M=$-L87-S;F%M90H@("`@("HO"B`@("!V87(@)%]D969A=6QT3V)J96-T0VQA
M<W-N86UE(#T@)W-T9$-L87-S)SL*"B`@("`O+R!,;V%D(&YA;65S<&%C92!5
M4DES(&EN=&\@86X@87)R87D@;V8@55))(#T^('!R969I>"X*("`@('9A<B`D
M7VYA;65S<&%C97,["B`@("!V87(@)%]N86UE<W!A8V4["@H@("`@=F%R("1?
M>&UL16YT:71I97,@/2!A<G)A>2@G)B<@/3X@)R9A;7`[)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)SPG(#T^("<F;'0[)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)SXG(#T^("<F9W0[)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(B<B(#T^("<F87!O<SLG+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G(B<@/3X@)R9Q=6]T.R<I.PH*("`@
M('9A<B`D7V1O8V]N=F5R<VEO;B`](&9A;'-E.PH*("`@('9A<B`D7U]A='1A
M8VAM96YT<R`](&%R<F%Y*"D["@H@("`@=F%R("1?=W-D;"`](&YU;&P["@H@
M("`@+RHJ"B`@("`@*B!4<G5E(&EF('=E('5S92!S96-T:6]N(#4@96YC;V1I
M;F<L(&]R(&9A;'-E(&EF('1H:7,@:7,@;&ET97)A;"X*("`@("`J"B`@("`@
M*B!`=F%R(&)O;VQE86X@)%]S96-T:6]N-0H@("`@("HO"B`@("!V87(@)%]S
M96-T:6]N-2`]('1R=64["@H@("`@+R\@2&%N9&QE('1Y<&4@=&\@8VQA<W,@
M;6%P<&EN9RX*("`@('9A<B`D7V%U=&]?=')A;G-L871I;VX@/2!F86QS93L*
M("`@('9A<B`D7W1Y<&5?=')A;G-L871I;VX@/2!A<G)A>2@I.PH*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'-E92`D9&5B
M=6=?9&%T82P@7V1E8G5G*"D*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1F875L=&-O9&4@($5R<F]R(&-O9&4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%-/05!?0F%S92@D9F%U;'1C;V1E(#T@)T-L:65N="<I"B`@("!["B`@("`@
M("`@<&%R96YT.CI33T%07T)A<V5?3V)J96-T*"1F875L=&-O9&4I.PH@("`@
M("`@("1T:&ES+3Y?<F5S971.86UE<W!A8V5S*"D["B`@("!]"@H@("`@9G5N
M8W1I;VX@7W)E<V5T3F%M97-P86-E<R@I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]N86UE<W!A8V5S(#T@87)R87DH"B`@("`@("`@("`@("=H='1P.B\O<V-H
M96UA<RYX;6QS;V%P+F]R9R]S;V%P+V5N=F5L;W!E+R<@/3X@)U-/05`M14Y6
M)RP*("`@("`@("`@("`@)VAT='`Z+R]W=W<N=S,N;W)G+S(P,#$O6$U,4V-H
M96UA)R`]/B`G>'-D)RP*("`@("`@("`@("`@)VAT='`Z+R]W=W<N=S,N;W)G
M+S(P,#$O6$U,4V-H96UA+6EN<W1A;F-E)R`]/B`G>'-I)RP*("`@("`@("`@
M("`@)VAT='`Z+R]S8VAE;6%S+GAM;'-O87`N;W)G+W-O87`O96YC;V1I;F<O
M)R`]/B`G4T]!4"U%3D,G*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@
M=&AE('-C:&5M82!V97)S:6]N('5S960@:6X@=&AE(%-/05`@;65S<V%G92X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!S964@)%]8
M34Q38VAE;6$*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S8VAE;6%6
M97)S:6]N("!4:&4@<V-H96UA('9E<G-I;VXN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]S97138VAE;6%697)S:6]N*"1S8VAE;6%697)S:6]N*0H@("`@>PH@
M("`@("`@(&EF("@A:6Y?87)R87DH)'-C:&5M859E<G-I;VXL("1T:&ES+3Y?
M6$U,4V-H96UA*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES
M95-O87!&875L="@B=6YS=7!O<G1E9"!834Q38VAE;6$@)'-C:&5M859E<G-I
M;VXB*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]834Q38VAE;6%697)S
M:6]N(#T@)'-C:&5M859E<G-I;VX["B`@("`@("`@)'1M<$Y3(#T@87)R87E?
M9FQI<"@D=&AI<RT^7VYA;65S<&%C97,I.PH@("`@("`@("1T;7!.4ULG>'-D
M)UT@/2`D=&AI<RT^7UA-3%-C:&5M859E<G-I;VX["B`@("`@("`@)'1M<$Y3
M6R=X<VDG72`]("1T:&ES+3Y?6$U,4V-H96UA5F5R<VEO;B`N("<M:6YS=&%N
M8V4G.PH@("`@("`@("1T:&ES+3Y?;F%M97-P86-E<R`](&%R<F%Y7V9L:7`H
M)'1M<$Y3*3L*("`@('T*"B`@("!F=6YC=&EO;B!?9V5T3F%M97-P86-E4')E
M9FEX*"1N<RD*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]N86UE<W!A8V4@
M)B8@)&YS(#T]("1T:&ES+3Y?;F%M97-P86-E*2!["B`@("`@("`@("`@(')E
M='5R;B`G)SL*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M;F%M97-P86-E<ULD;G-=*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]N86UE<W!A8V5S6R1N<UT["B`@("`@("`@?0H@("`@("`@("1P<F5F:7@@
M/2`G;G,G("X@8V]U;G0H)'1H:7,M/E]N86UE<W!A8V5S*3L*("`@("`@("`D
M=&AI<RT^7VYA;65S<&%C97-;)&YS72`]("1P<F5F:7@["B`@("`@("`@<F5T
M=7)N("1P<F5F:7@["B`@("!]"@H@("`@9G5N8W1I;VX@7V=E=$YA;65S<&%C
M949O<E!R969I>"@D<')E9FEX*0H@("`@>PH@("`@("`@("1F;&EP<&5D(#T@
M87)R87E?9FQI<"@D=&AI<RT^7VYA;65S<&%C97,I.PH@("`@("`@(&EF("AI
M<W-E="@D9FQI<'!E9%LD<')E9FEX72DI('L*("`@("`@("`@("`@<F5T=7)N
M("1F;&EP<&5D6R1P<F5F:7A=.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M;G5L;#L*("`@('T*"B`@("!F=6YC=&EO;B!?:7-3;V%P5F%L=64H)B1V86QU
M92D*("`@('L*("`@("`@("!R971U<FX@:7-?82@D=F%L=64L("=33T%07U9A
M;'5E)RD["B`@("!]"@H@("`@9G5N8W1I;VX@7W-E<FEA;&EZ959A;'5E*"8D
M=F%L=64L("1N86UE(#T@)R<L("1T>7!E(#T@9F%L<V4L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&5L3F%M97-P86-E(#T@;G5L;"P@)'1Y<&5.
M86UE<W!A8V4@/2!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1O<'1I;VYS(#T@87)R87DH*2P@)&%T=')I8G5T97,@/2!A<G)A>2@I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A<G1Y<&4@/2`G)RD*("`@
M('L*("`@("`@("`D;F%M97-P86-E<R`](&%R<F%Y*"D["B`@("`@("`@)&%R
M<F%Y5'EP92`]("1A<G)A>5]D97!T:"`]("1X;6QO=71?=F%L=64@/2!N=6QL
M.PH@("`@("`@("1T>7!E4')E9FEX(#T@)&5L4')E9FEX(#T@)'AM;&]U=%]O
M9F9S970@/2`D>&UL;W5T7V%R<F%Y5'EP92`]("<G.PH@("`@("`@("1X;6QO
M=71?='EP92`]("1X;6QN<R`]("1P='EP92`]("1A<G)A>5]T>7!E7VYS(#T@
M)R<["@H@("`@("`@(&EF("@A)&YA;64@?'P@:7-?;G5M97)I8R@D;F%M92DI
M('L*("`@("`@("`@("`@)&YA;64@/2`G:71E;2<["B`@("`@("`@?0H*("`@
M("`@("!I9B`H)'1H:7,M/E]W<V1L*2!["B`@("`@("`@("`@(&QI<W0H)'!T
M>7!E+"`D87)R87E4>7!E+"`D87)R87E?='EP95]N<RP@)&%R<F%Y7V1E<'1H
M*0H@("`@("`@("`@("`@("`@/2`D=&AI<RT^7W=S9&PM/F=E=%-C:&5M851Y
M<&4H)'1Y<&4L("1N86UE+"`D='EP94YA;65S<&%C92D["B`@("`@("`@?0H*
M("`@("`@("!I9B`H(21A<G)A>51Y<&4I('L*("`@("`@("`@("`@)&%R<F%Y
M5'EP92`]("1A<G1Y<&4["B`@("`@("`@?0H@("`@("`@(&EF("@A)'!T>7!E
M*2!["B`@("`@("`@("`@("1P='EP92`]("1T:&ES+3Y?9V5T5'EP92@D=F%L
M=64I.PH@("`@("`@('T*("`@("`@("!I9B`H(21T>7!E*2!["B`@("`@("`@
M("`@("1T>7!E(#T@)'!T>7!E.PH@("`@("`@('T*"B`@("`@("`@:68@*'-T
M<F-A<V5C;7`H)'!T>7!E+"`G4W1R=6-T)RD@/3T@,"!\?`H@("`@("`@("`@
M("!S=')C87-E8VUP*"1T>7!E+"`G4W1R=6-T)RD@/3T@,"D@>PH@("`@("`@
M("`@("`O+R!3=')U8W0*("`@("`@("`@("`@)'9A<G,@/2!N=6QL.PH@("`@
M("`@("`@("!I9B`H:7-?;V)J96-T*"1V86QU92DI('L*("`@("`@("`@("`@
M("`@("1V87)S(#T@9V5T7V]B:F5C=%]V87)S*"1V86QU92D["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=F%R<R`]("8D=F%L=64[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1V87)S
M*2D@>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D=F%R
M<RD@87,@)&LI('L*("`@("`@("`@("`@("`@("`@("`O+R!(:61E('!R:79A
M=&4@=F%R<RX*("`@("`@("`@("`@("`@("`@("!I9B`H)&M;,%T@/3T@)U\G
M*2!C;VYT:6YU93L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?;V)J96-T
M*"1V87)S6R1K72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES
M7V$H)'9A<G-;)&M=+"`G4T]!4%]686QU92<I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D>&UL;W5T7W9A;'5E("X]("1V87)S6R1K72T^<V5R
M:6%L:7IE*"1T:&ES*3L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(%A86"!G970@=&AE
M(&UE;6)E<G,@86YD('-E<FEA;&EZ92!T:&5M(&EN<W1E860*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O(&-O;G9E<G1I;F<@=&\@86X@87)R87D@
M:7,@;6]R92!O=F5R:&5A9"!T:&%N('=E"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!S:&]U;&0@<F5A;&QY(&1O+@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'AM;&]U=%]V86QU92`N/2`D=&AI<RT^7W-E<FEA;&EZ
M959A;'5E*&=E=%]O8FIE8W1?=F%R<R@D=F%R<ULD:UTI+"`D:RP@9F%L<V4L
M("1T:&ES+3Y?<V5C=&EO;C4@/R!N=6QL(#H@)&5L3F%M97-P86-E*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1X;6QO=71?=F%L=64@
M+CT@)'1H:7,M/E]S97)I86QI>F5686QU92@D=F%R<ULD:UTL("1K+"!F86QS
M92P@)'1H:7,M/E]S96-T:6]N-2`_(&YU;&P@.B`D96Q.86UE<W!A8V4I.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS96EF("AS=')C87-E8VUP*"1P='EP92P@
M)T%R<F%Y)RD@/3T@,"!\?`H@("`@("`@("`@("`@("`@("!S=')C87-E8VUP
M*"1T>7!E+"`G07)R87DG*2`]/2`P*2!["B`@("`@("`@("`@("\O($%R<F%Y
M+@H@("`@("`@("`@("`D='EP94YA;65S<&%C92`](%-/05!?4T-(14U!7T5.
M0T]$24Y'.PH@("`@("`@("`@("`D;W)I9U]T>7!E(#T@)'1Y<&4["B`@("`@
M("`@("`@("1T>7!E(#T@)T%R<F%Y)SL*("`@("`@("`@("`@)&YU;71Y<&5S
M(#T@,#L*("`@("`@("`@("`@+R\@6%A8('1H:7,@=VEL;"!B92!S;&]W(&]N
M(&QA<F=E<B!A<G)A>7,N("!"87-I8V%L;'DL(&ET(&9L871T96YS"B`@("`@
M("`@("`@("\O(&%R<F%Y<R!T;R!A;&QO=R!U<R!T;R!S97)I86QI>F4@;75L
M=&DM9&EM96YS:6]N86P@87)R87ES+B`@5V4*("`@("`@("`@("`@+R\@;VYL
M>2!D;R!T:&ES(&EF(&%R<F%Y5'EP92!I<R!S970L('=H:6-H('=I;&P@='EP
M:6-A;&QY(&]N;'D*("`@("`@("`@("`@+R\@:&%P<&5N(&EF('=E(&%R92!U
M<VEN9R!74T1,"B`@("`@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG9FQA
M='1E;B==*2!\?`H@("`@("`@("`@("`@("`@*"1A<G)A>51Y<&4@)B8*("`@
M("`@("`@("`@("`@("`H<W1R8VAR*"1A<G)A>51Y<&4L("<L)RD@?'P@<W1R
M<W1R*"1A<G)A>51Y<&4L("==6R<I*2DI('L*("`@("`@("`@("`@("`@("1N
M=6UT>7!E<R`]("1T:&ES+3Y?;75L=&E!<G)A>51Y<&4H)'9A;'5E+"`D87)R
M87E4>7!E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D87)?<VEZ92P@)'AM;&]U=%]V86QU92D["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1A<G)A>5]T>7!E(#T@)&%R<F%Y7W1Y
M<&5?<')E9FEX(#T@)R<["B`@("`@("`@("`@(&EF("@D;G5M='EP97,@(3T@
M,2D@>PH@("`@("`@("`@("`@("`@)&%R<F%Y5'EP95%.86UE(#TF(&YE=R!1
M3F%M92@D87)R87E4>7!E*3L*("`@("`@("`@("`@("`@("1A<G)A>51Y<&4@
M/2`D87)R87E4>7!E44YA;64M/FYA;64["B`@("`@("`@("`@("`@("`D87)R
M87E?='EP97,@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@)&%R<F%Y7W9A
M;"`](&YU;&P["@H@("`@("`@("`@("`@("`@+R\@4V5R:6%L:7IE(&5A8V@@
M87)R87D@96QE;65N="X*("`@("`@("`@("`@("`@("1A<E]S:7IE(#T@8V]U
M;G0H)'9A;'5E*3L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V86QU92!A
M<R`D87)R87E?=F%L*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES
M+3Y?:7-3;V%P5F%L=64H)&%R<F%Y7W9A;"DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&%R<F%Y7W1Y<&4@/2`D87)R87E?=F%L+3YT>7!E.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D87)R87E?='EP97-;)&%R<F%Y7W1Y<&5=
M(#T@,3L*("`@("`@("`@("`@("`@("`@("`@("`@)&%R<F%Y7W1Y<&5?;G,@
M/2`D87)R87E?=F%L+3YT>7!E7VYA;65S<&%C93L*("`@("`@("`@("`@("`@
M("`@("`@("`@)'AM;&]U=%]V86QU92`N/2`D=&AI<RT^7W-E<FEA;&EZ959A
M;'5E*"1A<G)A>5]V86PL("1A<G)A>5]V86PM/FYA;64L("1A<G)A>5]T>7!E
M+"`D87)R87E?='EP95]N<RD["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&%R<F%Y7W1Y<&4@/2`D=&AI
M<RT^7V=E=%1Y<&4H)&%R<F%Y7W9A;"D["B`@("`@("`@("`@("`@("`@("`@
M("`@("1A<G)A>5]T>7!E<ULD87)R87E?='EP95T@/2`Q.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D>&UL;W5T7W9A;'5E("X]("1T:&ES+3Y?<V5R:6%L
M:7IE5F%L=64H)&%R<F%Y7W9A;"P@)VET96TG+"`D87)R87E?='EP92P@)'1H
M:7,M/E]S96-T:6]N-2`_(&YU;&P@.B`D96Q.86UE<W!A8V4I.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("`@("`D>&UL;W5T7V]F9G-E="`]("<@4T]!4"U%3D,Z;V9F<V5T/2);,%TB
M)SL*("`@("`@("`@("`@("`@(&EF("@A)&%R<F%Y5'EP92D@>PH@("`@("`@
M("`@("`@("`@("`@("1N=6UT>7!E<R`](&-O=6YT*"1A<G)A>5]T>7!E<RD[
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1N=6UT>7!E<R`]/2`Q*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1A<G)A>51Y<&4@/2`D87)R87E?='EP
M93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M+R\@57-I;F<@86YY5'EP92!I<R!M;W)E(&EN=&5R;W!E<F%B;&4N"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1A<G)A>5]T>7!E(#T]("=3=')U8W0G*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1A<G)A>5]T>7!E(#T@)R<["B`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1A<G)A>5]T>7!E(#T]("=!
M<G)A>2<I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&%R<F%Y5'EP92`]
M("=A;GE4>7!E)SL*("`@("`@("`@("`@("`@("`@("`@("`@)&%R<F%Y7W1Y
M<&5?<')E9FEX(#T@)WAS9"<["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"$D87)R87E4>7!E*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D87)R87E4>7!E(#T@)&%R
M<F%Y7W1Y<&4["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*"$D87)R87E4>7!E('Q\("1N=6UT>7!E<R`^(#$I
M('L*("`@("`@("`@("`@("`@("\O(%-H;W5L9"!R969E<F5N8V4@=VAA="!S
M8VAE;6$@=V4G<F4@=7-I;F<N"B`@("`@("`@("`@("`@("`D87)R87E4>7!E
M(#T@)WAS9#IA;GE4>7!E)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@(&EF("@D87)R87E?='EP95]N<RD@>PH@("`@("`@("`@("`@
M("`@("`@("1A<G)A>5]T>7!E7W!R969I>"`]("1T:&ES+3Y?9V5T3F%M97-P
M86-E4')E9FEX*"1A<G)A>5]T>7!E7VYS*3L*("`@("`@("`@("`@("`@('T@
M96QS96EF("AI<W-E="@D=&AI<RT^7W1Y<&5M87!;)'1H:7,M/E]834Q38VAE
M;6%697)S:6]N75LD87)R87E4>7!E72DI('L*("`@("`@("`@("`@("`@("`@
M("`D87)R87E?='EP95]P<F5F:7@@/2`D=&AI<RT^7VYA;65S<&%C97-;)'1H
M:7,M/E]834Q38VAE;6%697)S:6]N73L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&EF("@D87)R87E?='EP95]P<F5F:7@I('L*("`@("`@
M("`@("`@("`@("`@("`D87)R87E4>7!E(#T@)&%R<F%Y7W1Y<&5?<')E9FEX
M("X@)SHG("X@)&%R<F%Y5'EP93L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)'AM;&]U=%]A<G)A>51Y<&4@/2`G(%-/
M05`M14Y#.F%R<F%Y5'EP93TB)R`N("1A<G)A>51Y<&4["B`@("`@("`@("`@
M(&EF("@D87)R87E?9&5P=&@@(3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@
M9F]R("@D:2`](#`[("1I(#P@)&%R<F%Y7V1E<'1H.R`D:2LK*2!["B`@("`@
M("`@("`@("`@("`@("`@)'AM;&]U=%]A<G)A>51Y<&4@+CT@)UM=)SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D>&UL
M;W5T7V%R<F%Y5'EP92`N/2`B6R1A<E]S:7IE75PB(CL*("`@("`@("!](&5L
M<V5I9B`H)'1H:7,M/E]I<U-O87!686QU92@D=F%L=64I*2!["B`@("`@("`@
M("`@("1X;6QO=71?=F%L=64@/28@)'9A;'5E+3YS97)I86QI>F4H)'1H:7,I
M.PH@("`@("`@('T@96QS96EF("@D='EP92`]/2`G<W1R:6YG)RD@>PH@("`@
M("`@("`@("`D>&UL;W5T7W9A;'5E(#T@:'1M;'-P96-I86QC:&%R<R@D=F%L
M=64I.PH@("`@("`@('T@96QS96EF("@D='EP92`]/2`G<F%W<W1R:6YG)RD@
M>PH@("`@("`@("`@("`D>&UL;W5T7W9A;'5E(#TF("1V86QU93L*("`@("`@
M("!](&5L<V5I9B`H)'1Y<&4@/3T@)V)O;VQE86XG*2!["B`@("`@("`@("`@
M("1X;6QO=71?=F%L=64@/2`D=F%L=64@/R`G=')U92<@.B`G9F%L<V4G.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1X;6QO=71?=F%L=64@/28@
M)'9A;'5E.PH@("`@("`@('T*"B`@("`@("`@+R\@061D(&YA;65S<&%C97,N
M"B`@("`@("`@:68@*"1E;$YA;65S<&%C92D@>PH@("`@("`@("`@("`D96Q0
M<F5F:7@@/2`D=&AI<RT^7V=E=$YA;65S<&%C95!R969I>"@D96Q.86UE<W!A
M8V4I.PH@("`@("`@("`@("!I9B`H)&5L4')E9FEX*2!["B`@("`@("`@("`@
M("`@("`D>&UL;W5T7VYA;64@/2`B)&5L4')E9FEX.B1N86UE(CL*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1X;6QO=71?;F%M92`]
M("1N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'AM;&]U=%]N86UE(#T@)&YA;64["B`@("`@("`@?0H*("`@("`@
M("!I9B`H)'1Y<&5.86UE<W!A8V4I('L*("`@("`@("`@("`@)'1Y<&50<F5F
M:7@@/2`D=&AI<RT^7V=E=$YA;65S<&%C95!R969I>"@D='EP94YA;65S<&%C
M92D["B`@("`@("`@("`@(&EF("@D='EP95!R969I>"D@>PH@("`@("`@("`@
M("`@("`@)'AM;&]U=%]T>7!E(#T@(B1T>7!E4')E9FEX.B1T>7!E(CL*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1X;6QO=71?='EP
M92`]("1T>7!E.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*"1T
M>7!E("8F"B`@("`@("`@("`@("`@("`@(&ES<V5T*"1T:&ES+3Y?='EP96UA
M<%LD=&AI<RT^7UA-3%-C:&5M859E<G-I;VY=6R1T>7!E72DI('L*("`@("`@
M("`@("`@)'1Y<&50<F5F:7@@/2`D=&AI<RT^7VYA;65S<&%C97-;)'1H:7,M
M/E]834Q38VAE;6%697)S:6]N73L*("`@("`@("`@("`@:68@*"1T>7!E4')E
M9FEX*2!["B`@("`@("`@("`@("`@("`D>&UL;W5T7W1Y<&4@/2`B)'1Y<&50
M<F5F:7@Z)'1Y<&4B.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)'AM;&]U=%]T>7!E(#T@)'1Y<&4["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("\O($AA;F1L92!A9&1I=&EO;F%L(&%T=')I8G5T
M97,N"B`@("`@("`@)'AM;%]A='1R(#T@)R<["B`@("`@("`@:68@*&-O=6YT
M*"1A='1R:6)U=&5S*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D871T<FEB
M=71E<R!A<R`D:R`]/B`D=BD@>PH@("`@("`@("`@("`@("`@)&MQ;B`])B!N
M97<@44YA;64H)&LI.PH@("`@("`@("`@("`@("`@)'9Q;B`])B!N97<@44YA
M;64H)'8I.PH@("`@("`@("`@("`@("`@)'AM;%]A='1R("X]("<@)R`N("1K
M<6XM/F9Q;B@I("X@)STB)R`N("1V<6XM/F9Q;B@I("X@)R(G.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!3=&]R92!T:&4@871T86-H
M;65N="!F;W(@;6EM92!E;F-O9&EN9RX*("`@("`@("!I9B`H:7-S970H)&]P
M=&EO;G-;)V%T=&%C:&UE;G0G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]?
M871T86-H;65N='-;72`]("1O<'1I;VYS6R=A='1A8VAM96YT)UT["B`@("`@
M("`@?0H*("`@("`@("!I9B`H)'1H:7,M/E]S96-T:6]N-2D@>PH@("`@("`@
M("`@("!I9B`H)'AM;&]U=%]T>7!E*2!["B`@("`@("`@("`@("`@("`D>&UL
M;W5T7W1Y<&4@/2`B('AS:3IT>7!E/5PB)'AM;&]U=%]T>7!E7"(B.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<U]N=6QL*"1X;6QO=71?=F%L
M=64I*2!["B`@("`@("`@("`@("`@("`D>&UL(#T@(EQR7&X\)'AM;&]U=%]N
M86UE)'AM;&]U=%]T>7!E)'AM;&YS)'AM;&]U=%]A<G)A>51Y<&4B("X*("`@
M("`@("`@("`@("`@("`@("`B)'AM;%]A='1R('AS:3IN:6P]7")T<G5E7"(O
M/B(["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D>&UL
M(#T@(EQR7&X\)'AM;&]U=%]N86UE)'AM;&]U=%]T>7!E)'AM;&YS)'AM;&]U
M=%]A<G)A>51Y<&4B("X*("`@("`@("`@("`@("`@("`@("`B)'AM;&]U=%]O
M9F9S970D>&UL7V%T='(^)'AM;&]U=%]V86QU93PO)'AM;&]U=%]N86UE/B([
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I
M9B`H:7-?;G5L;"@D>&UL;W5T7W9A;'5E*2D@>PH@("`@("`@("`@("`@("`@
M)'AM;"`](")<<EQN/"1X;6QO=71?;F%M921X;6QN<R1X;6Q?871T<B\^(CL*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1X;6P@/2`B
M7')<;CPD>&UL;W5T7VYA;64D>&UL;G,D>&UL7V%T='(^(B`N"B`@("`@("`@
M("`@("`@("`@("`@)'AM;&]U=%]V86QU92`N("(\+R1X;6QO=71?;F%M93XB
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'AM
M;#L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G1S(&$@4$A0('1Y<&4@
M=&\@82!33T%0('1Y<&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU92`@5&AE('9A
M;'5E('1O(&EN<W!E8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!V86QU92=S(%-/05`@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V=E=%1Y<&4H)B1V86QU92D*("`@('L*("`@("`@("!G;&]B86P@)%-/05!?
M3T)*14-47U-44E5#5"P@)%-/05!?4D%77T-/3E9%4E0["@H@("`@("`@("1T
M>7!E(#T@9V5T='EP92@D=F%L=64I.PH@("`@("`@('-W:71C:"`H)'1Y<&4I
M('L*("`@("`@("!C87-E("=O8FIE8W0G.@H@("`@("`@("`@("!I9B`H:7-?
M82@D=F%L=64L("=S;V%P7W9A;'5E)RDI('L*("`@("`@("`@("`@("`@("1T
M>7!E(#T@)'9A;'5E+3YT>7!E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)'1Y<&4@/2`G4W1R=6-T)SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G87)R87DG.@H@("`@
M("`@("`@("`O+R!(87-H97,@87)E(&%L=V%Y<R!H86YD;&5D(&%S('-T<G5C
M=',N"B`@("`@("`@("`@(&EF("@D=&AI<RT^7VES2&%S:"@D=F%L=64I*2![
M"B`@("`@("`@("`@("`@("`D='EP92`]("=3=')U8W0G.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&%R7W-I>F4@/2!C;W5N="@D
M=F%L=64I.PH@("`@("`@("`@("`@("`@<F5S970H)'9A;'5E*3L*("`@("`@
M("`@("`@("`@("1K97DQ(#T@:V5Y*"1V86QU92D["B`@("`@("`@("`@("`@
M("!I9B`H)&%R7W-I>F4@/B`P("8F(&ES7V$H)&ME>3$L("=33T%07U9A;'5E
M)RDI('L*("`@("`@("`@("`@("`@("`@("`O+R!&25A-13H@9F]R(&YO;BUW
M<V1L('-T<G5C=',@=&AA="!A<F4@86QL('1H92!S86UE('1Y<&4*("`@("`@
M("`@("`@("`@("`@("`D:V5Y,B`](&ME>2@D=F%L=64I.PH@("`@("`@("`@
M("`@("`@("`@(&EF("@D87)?<VEZ92`^(#$@)B8*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]I<U-O87!686QU92@D:V5Y,2D@)B8*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I<U-O87!686QU92@D:V5Y,BD@
M)B8*("`@("`@("`@("`@("`@("`@("`@("`@)&ME>3$M/FYA;64@(3T@)&ME
M>3(M/FYA;64I('L*("`@("`@("`@("`@("`@("`@("`@("`@+R\@5&AI<R!I
M<R!A('-T<G5C="P@;F]T(&%N(&%R<F%Y+@H@("`@("`@("`@("`@("`@("`@
M("`@("`D='EP92`]("=3=')U8W0G.PH@("`@("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1T>7!E(#T@)T%R<F%Y
M)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("1T>7!E(#T@)T%R<F%Y)SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@8V%S92`G:6YT96=E<B<Z"B`@("`@("`@8V%S92`G;&]N
M9R<Z"B`@("`@("`@("`@("1T>7!E(#T@)VEN="<["B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E("=B;V]L96%N)SH*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&-A<V4@)V1O=6)L92<Z"B`@("`@("`@("`@("\O(&1O
M=6)L92!I<R!D97!R96-A=&5D(&EN(%!(4"`T+C(@86YD(&QA=&5R+@H@("`@
M("`@("`@("`D='EP92`]("=F;&]A="<["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!C87-E("=N=6QL)SH*("`@("`@("`@("`@)'1Y<&4@/2`G)SL*
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)W-T<FEN9R<Z"B`@
M("`@("`@("`@(&EF("@D4T]!4%]205=?0T].5D525"D@>PH@("`@("`@("`@
M("`@("`@:68@*&ES7VYU;65R:6,H)'9A;'5E*2D@>PH@("`@("`@("`@("`@
M("`@("`@(&EF("AS=')S='(H)'9A;'5E+"`G+B<I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1T>7!E(#T@)V9L;V%T)SL*("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D='EP92`]
M("=I;G0G.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@*%-/05!?5'EP95]H
M97A":6YA<GDZ.FES7VAE>&)I;B@D=F%L=64I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1T>7!E(#T@)VAE>$)I;F%R>2<["B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?:7-"87-E-C0H)'9A;'5E*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1Y<&4@/2`G8F%S938T0FEN87)Y)SL*("`@("`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1D="`])B!N97<@4T]!4%]4>7!E7V1A=&54:6UE*"1V86QU92D["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&1T+3YT;U5N:7AT:6UE
M*"D@(3T@+3$I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M='EP92`]("=D871E5&EM92<["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T>7!E.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]M=6QT:4%R<F%Y5'EP92@F)'9A;'5E+"`F)'1Y<&4L
M("8D<VEZ92P@)B1X;6PI"B`@("!["B`@("`@("`@)'-Z(#T@8V]U;G0H)'9A
M;'5E*3L*("`@("`@("!I9B`H:7-?87)R87DH)'9A;'5E*2D@>PH@("`@("`@
M("`@("`O+R!3965M<R!W92!H879E(&$@;75L=&D@9&EM96YS:6]N86P@87)R
M87DL(&9I9W5R92!I="!O=70@:68@=V4*("`@("`@("`@("`@+R\@9&\N"B`@
M("`@("`@("`@("1C(#T@8V]U;G0H)'9A;'5E*3L*("`@("`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@)&,[("1I*RLI('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?;75L=&E!<G)A>51Y<&4H)'9A;'5E6R1I72P@)'1Y<&4L("1S:7IE
M+"`D>&UL*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1S:7IE
M*2!["B`@("`@("`@("`@("`@("`D<VEZ92`]("1S>BX@)RPG("X@)'-I>F4[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<VEZ92`]
M("1S>CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<F5T=7)N(#$["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*&ES7V]B:F5C="@D=F%L
M=64I*2!["B`@("`@("`@("`@("`@("`D='EP92`]("1V86QU92T^='EP93L*
M("`@("`@("`@("`@("`@("1X;6P@+CT@)'9A;'5E+3YS97)I86QI>F4H)'1H
M:7,I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1Y
M<&4@/2`D=&AI<RT^7V=E=%1Y<&4H)'9A;'5E*3L*("`@("`@("`@("`@("`@
M("1X;6P@+CT@)'1H:7,M/E]S97)I86QI>F5686QU92@D=F%L=64L("=I=&5M
M)RP@)'1Y<&4I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1S
M:7IE(#T@;G5L;#L*"B`@("`@("`@<F5T=7)N(#$["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('=H971H97(@82!S=')I;F<@:7,@8F%S938T(&5N
M8V]D960@9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU
M92`@5&AE('-T<FEN9R!T;R!C:&5C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%1R=64@:68@=&AE('-P96-I9FEE9"!V86QU92!S965M<R!T
M;R!B92!B87-E-C0@96YC;V1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7VES
M0F%S938T*"8D=F%L=64I"B`@("!["B`@("`@("`@)&P@/2!S=')L96XH)'9A
M;'5E*3L*("`@("`@("!I9B`H)&PI('L*("`@("`@("`@("`@<F5T=7)N("1V
M86QU95LD;"`M(#%=(#T]("<])R`F)@H@("`@("`@("`@("`@("`@<')E9U]M
M871C:"@G+UM!+5IA+7H]7"]<*UTK+R<L("1V86QU92D["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=VAE=&AE<B!A('1Y<&4@:7,@82!B87-E-C0@='EP92X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("!!('1Y<&4@;F%M92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE('1Y<&4@
M;F%M92!I<R!A(&)A<V4V-"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M:7-"87-E-C14>7!E*"1T>7!E*0H@("`@>PH@("`@("`@(')E='5R;B`D='EP
M92`]/2`G8F%S938T)R!\?"`D='EP92`]/2`G8F%S938T0FEN87)Y)SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=VAE=&AE<B!A;B!A<G)A>2!I
M<R!A(&AA<V@N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1A("!!;B!A
M<G)A>2!T;R!C:&5C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@:68@=&AE('-P96-I9FEE9"!A<G)A>2!I<R!A(&AA<V@N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]I<TAA<V@H)B1A*0H@("`@>PH@("`@("`@("\O
M($D@<F5A;&QY(&1I<VQI:V4@:&%V:6YG('1O(&QO;W`@=&AR;W5G:"!T:&ES
M(&EN(%!(4"!C;V1E+"!R96%L;'D*("`@("`@("`O+R!L87)G92!A<G)A>7,@
M=VEL;"!B92!S;&]W+B`@5V4@;F5E9"!A($,@9G5N8W1I;VX@=&\@9&\@=&AI
M<RX*("`@("`@("`D;F%M97,@/2!A<G)A>2@I.PH@("`@("`@("1I="`](#`[
M"B`@("`@("`@9F]R96%C:"`H)&$@87,@)&L@/3X@)'8I('L*("`@("`@("`@
M("`@+R\@0VAE8VMI;F<@=&AE('1Y<&4@:7,@9F%S=&5R('1H86X@<F5G97AP
M+@H@("`@("`@("`@("`D="`](&=E='1Y<&4H)&LI.PH@("`@("`@("`@("!I
M9B`H)'0@(3T@)VEN=&5G97(G*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?:7-3;V%P5F%L
M=64H)'8I*2!["B`@("`@("`@("`@("`@("`D;F%M97-;)'8M/FYA;65=(#T@
M,3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`O+R!)9B!S;VUE;VYE(&AA
M<R!A(&QA<F=E(&AA<V@@=&AE>2!S:&]U;&0@<F5A;&QY(&)E(&1E9FEN:6YG
M('1H90H@("`@("`@("`@("`O+R!T>7!E+@H@("`@("`@("`@("!I9B`H)&ET
M*RL@/B`Q,"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!C;W5N="@D;F%M
M97,I/C$["B`@("!]"@H@("`@9G5N8W1I;VX@)E]U;E]H=&UL96YT:71I97,H
M)'-T<FEN9RD*("`@('L*("`@("`@("`D=')A;G-?=&)L(#T@9V5T7VAT;6Q?
M=')A;G-L871I;VY?=&%B;&4H2%1-3%]%3E1)5$E%4RD["B`@("`@("`@)'1R
M86YS7W1B;"`](&%R<F%Y7V9L:7`H)'1R86YS7W1B;"D["B`@("`@("`@<F5T
M=7)N('-T<G1R*"1S=')I;F<L("1T<F%N<U]T8FPI.PH@("`@?0H*("`@(&9U
M;F-T:6]N("9?9&5C;V1E*"8D<V]A<'9A;"D*("`@('L*("`@("`@("!G;&]B
M86P@)%-/05!?3T)*14-47U-44E5#5#L*"B`@("`@("`@:68@*"$D=&AI<RT^
M7VES4V]A<%9A;'5E*"1S;V%P=F%L*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'-O87!V86P["B`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1S;V%P=F%L
M+3YV86QU92DI('L*("`@("`@("`@("`@:68@*"133T%07T]"2D5#5%]35%)5
M0U0@)B8@)'-O87!V86PM/G1Y<&4@(3T@)T%R<F%Y)RD@>PH@("`@("`@("`@
M("`@("`@)&-L87-S;F%M92`]("1T:&ES+3Y?9&5F875L=$]B:F5C=$-L87-S
M;F%M93L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W1Y<&5?
M=')A;G-L871I;VY;)'-O87!V86PM/G1Q;BT^9G%N*"E=*2D@>PH@("`@("`@
M("`@("`@("`@("`@("\O(%1H:7,@=VEL;"!F;W)C92!A;B!E<G)O<B!I;B!0
M2%`@:68@=&AE(&-L87-S(&1O97,@;F]T"B`@("`@("`@("`@("`@("`@("`@
M+R\@97AI<W0N"B`@("`@("`@("`@("`@("`@("`@)&-L87-S;F%M92`]("1T
M:&ES+3Y?='EP95]T<F%N<VQA=&EO;ELD<V]A<'9A;"T^='%N+3YF<6XH*5T[
M"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)'1H:7,M/E]T>7!E
M7W1R86YS;&%T:6]N6R1S;V%P=F%L+3YT>7!E72DI('L*("`@("`@("`@("`@
M("`@("`@("`O+R!4:&ES('=I;&P@9F]R8V4@86X@97)R;W(@:6X@4$A0(&EF
M('1H92!C;&%S<R!D;V5S(&YO=`H@("`@("`@("`@("`@("`@("`@("\O(&5X
M:7-T+@H@("`@("`@("`@("`@("`@("`@("1C;&%S<VYA;64@/2`D=&AI<RT^
M7W1Y<&5?=')A;G-L871I;VY;)'-O87!V86PM/G1Y<&5=.PH@("`@("`@("`@
M("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?875T;U]T<F%N<VQA=&EO;BD@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)'-O87!V86PM
M/G1Y<&4I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1C;&%S<VYA;64@
M/2`D<V]A<'9A;"T^='EP93L*("`@("`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H)'1H:7,M/E]W<V1L*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T
M(#T@)'1H:7,M/E]W<V1L+3YG971#;VUP;&5X5'EP94YA;65&;W)%;&5M96YT
M*"1S;V%P=F%L+3YN86UE+"`D<V]A<'9A;"T^;F%M97-P86-E*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"1T("8F(&-L87-S7V5X:7-T<R@D="DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;&%S<VYA;64@/2`D
M=#L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1R971U
M<FX@/28@;F5W("1C;&%S<VYA;64["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D<F5T=7)N(#T@87)R87DH*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@)&-O=6YT97(@/2`Q.PH@("`@("`@("`@("`D:7-S
M=')U8W0@/2`A)%-/05!?3T)*14-47U-44E5#5"!\?"`A:7-?87)R87DH)')E
M='5R;BD["B`@("`@("`@("`@(&9O<F5A8V@@*"1S;V%P=F%L+3YV86QU92!A
M<R`D:71E;2D@>PH@("`@("`@("`@("`@("`@:68@*&ES7V]B:F5C="@D<F5T
M=7)N*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7W=S9&PI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@+R\@1V5T('1H:7,@8VAI;&0G
M<R!74T1,(&EN9F]R;6%T:6]N+@H@("`@("`@("`@("`@("`@("`@("`@("`O
M+R`O)'-O87!V86PM/FYS+R1S;V%P=F%L+3YT>7!E+R1I=&5M+3YN<R\D:71E
M;2T^;F%M90H@("`@("`@("`@("`@("`@("`@("`@("`D8VAI;&1?='EP92`]
M("1T:&ES+3Y?=W-D;"T^9V5T0V]M<&QE>%1Y<&5#:&EL9%1Y<&4H"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<V]A<'9A;"T^;F%M97-P86-E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-O87!V86PM/FYA;64L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D:71E;2T^;F%M97-P86-E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&ET96TM/FYA;64I.PH@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H)&-H:6QD7W1Y<&4I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1I=&5M+3YT>7!E(#T@)&-H:6QD7W1Y
M<&4["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*"$D:7-S=')U8W0@?'P@
M)&ET96TM/G1Y<&4@/3T@)T%R<F%Y)RD@>PH@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)')E='5R;BT^>R1I=&5M+3YN86UE?2D@)B8*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&ES7V]B:F5C="@D<F5T=7)N+3Y[
M)&ET96TM/FYA;65]*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)')E='5R;BT^>R1I=&5M+3YN86UE?2`])B`D=&AI<RT^7V1E8V]D92@D:71E
M;2D["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D
M<F5T=7)N+3Y[)&ET96TM/FYA;65]*2`F)@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:7-?87)R87DH)')E='5R;BT^>R1I=&5M+3YN86UE
M?2DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R971U<FXM/GLD
M:71E;2T^;F%M97U;72`])B`D=&AI<RT^7V1E8V]D92@D:71E;2D["B`@("`@
M("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D<F5T=7)N
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E='5R;EM=(#TF
M("1T:&ES+3Y?9&5C;V1E*"1I=&5M*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R971U
M<FXM/GLD:71E;2T^;F%M97T@/28@)'1H:7,M/E]D96-O9&4H)&ET96TI.PH@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*&ES<V5T*"1R971U<FXM/GLD:71E;2T^;F%M97TI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1I<W-T<G5C="`](&9A;'-E.PH@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H8V]U;G0H9V5T7V]B:F5C=%]V87)S
M*"1R971U<FXI*2`]/2`Q*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9"`])B`D=&AI<RT^7V1E8V]D92@D:71E;2D["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<F5T=7)N(#T@87)R87DH)')E='5R;BT^>R1I=&5M
M+3YN86UE?2P@)&0I.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&0@/28@)'1H:7,M/E]D
M96-O9&4H)&ET96TI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E
M='5R;BT^>R1I=&5M+3YN86UE?2`](&%R<F%Y*"1R971U<FXM/GLD:71E;2T^
M;F%M97TL("1D*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1R971U<FXM/GLD:71E;2T^;F%M97T@/28@)'1H:7,M/E]D96-O9&4H)&ET
M96TI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`O+R!3970@=&AE(&%T=')I8G5T97,@87,@;65M8F5R<R!I;B!T:&4@8VQA
M<W,N"B`@("`@("`@("`@("`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H)')E
M='5R;BP@)U]?<V5T7V%T=')I8G5T92<I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1S;V%P=F%L+3YA='1R:6)U=&5S(&%S("1K97D@
M/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C86QL
M7W5S97)?9G5N8U]A<G)A>2AA<G)A>2@F)')E='5R;BP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=?
M7W-E=%]A='1R:6)U=&4G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1K97DL("1V86QU92DI.PH@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H)'-O87!V86PM/F%R<F%Y5'EP92`F)B`D=&AI<RT^7VES4V]A<%9A
M;'5E*"1I=&5M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'1H
M:7,M/E]I<T)A<V4V-%1Y<&4H)&ET96TM/G1Y<&4I("8F"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`A)'1H:7,M/E]I<T)A<V4V-%1Y<&4H)'-O87!V
M86PM/F%R<F%Y5'EP92DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("\O($1E8V]D92!T:&4@=F%L=64@:68@=V4G<F4@;&]S:6YG('1H92!B87-E
M-C0*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O('1Y<&4@:6YF;W)M
M871I;VXN"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:71E;2T^=F%L
M=64@/2!B87-E-C1?9&5C;V1E*"1I=&5M+3YV86QU92D["B`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&ET96TM
M/G1Y<&4@/2`D<V]A<'9A;"T^87)R87E4>7!E.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H(21I<W-T<G5C="D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D<F5T=7)N6UT@/28@)'1H:7,M/E]D
M96-O9&4H)&ET96TI.PH@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI
M<W-E="@D<F5T=7)N6R1I=&5M+3YN86UE72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&ES<W1R=6-T(#T@9F%L<V4["B`@("`@("`@("`@("`@("`@
M("`@("`@("1D(#TF("1T:&ES+3Y?9&5C;V1E*"1I=&5M*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@)')E='5R;B`](&%R<F%Y*"1R971U<FY;)&ET96TM
M/FYA;65=+"`D9"D["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)')E='5R;ELD:71E;2T^;F%M95T@/28@
M)'1H:7,M/E]D96-O9&4H)&ET96TI.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M<F5T=7)N("1R971U<FX["B`@("`@("`@?0H*("`@("`@("!I9B`H)'-O87!V
M86PM/G1Y<&4@/3T@)V)O;VQE86XG*2!["B`@("`@("`@("`@(&EF("@D<V]A
M<'9A;"T^=F%L=64@(3T@)S`G("8F"B`@("`@("`@("`@("`@("!S=')C87-E
M8VUP*"1S;V%P=F%L+3YV86QU92P@)V9A;'-E)RD@(3T@,"D@>PH@("`@("`@
M("`@("`@("`@)'-O87!V86PM/G9A;'5E(#T@=')U93L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1S;V%P=F%L+3YV86QU92`](&9A
M;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*"1S;V%P=F%L
M+3YT>7!E("8F"B`@("`@("`@("`@("`@("`@(&ES<V5T*"1T:&ES+3Y?='EP
M96UA<%M33T%07UA-3%]30TA%34%?5D524TE/3EU;)'-O87!V86PM/G1Y<&5=
M*2D@>PH@("`@("`@("`@("`O+R!)9B!W92!C86XL('-E="!V87)I86)L92!T
M>7!E+@H@("`@("`@("`@("!S971T>7!E*"1S;V%P=F%L+3YV86QU92P*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W1Y<&5M87!;4T]!4%]834Q?4T-(
M14U!7U9%4E-)3TY=6R1S;V%P=F%L+3YT>7!E72D["B`@("`@("`@?0H*("`@
M("`@("!I9B`H)'1H:7,M/E]I<T)A<V4V-%1Y<&4H)'-O87!V86PM/G1Y<&4I
M*2!["B`@("`@("`@("`@(')E='5R;B!B87-E-C1?9&5C;V1E*"1S;V%P=F%L
M+3YV86QU92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M("1S;V%P=F%L+3YV86QU93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#<F5A=&5S('1H92!33T%0(&5N=F5L;W!E('=I=&@@=&AE(%-/05`@
M96YV96QO<"!D871A+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;0H@("`@("H@0'!A<F%M(&%R<F%Y("1H96%D
M97)S"B`@("`@*B!`<&%R86T@<W1R:6YG("1E;F-O9&EN9PH@("`@("H@0'!A
M<F%M(&%R<F%Y("1O<'1I;VYS"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<*("`@("`J+PH@("`@9G5N8W1I;VX@)E]M86ME16YV96QO<&4H)B1M971H
M;V0L("8D:&5A9&5R<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E
M;F-O9&EN9R`](%-/05!?1$5&055,5%]%3D-/1$E.1RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1O<'1I;VYS(#T@87)R87DH*2D*("`@('L*("`@
M("`@("`D<VUS9R`]("1H96%D97)?>&UL(#T@)&YS7W-T<FEN9R`]("<G.PH*
M("`@("`@("!I9B`H)&AE861E<G,I('L*("`@("`@("`@("`@)&,@/2!C;W5N
M="@D:&5A9&5R<RD["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C
M.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D:&5A9&5R7WAM;"`N/2`D:&5A
M9&5R<ULD:5TM/G-E<FEA;&EZ92@D=&AI<RD["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&AE861E<E]X;6P@/2`B/%-/05`M14Y6.DAE861E<CY<<EQN
M)&AE861E<E]X;6Q<<EQN/"]33T%0+45.5CI(96%D97(^7')<;B(["B`@("`@
M("`@?0H*("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=I;G!U="==*2!\
M?"`D;W!T:6]N<ULG:6YP=70G72`]/2`G<&%R<V4G*2!["B`@("`@("`@("`@
M(&EF("AI<U]A<G)A>2@D;65T:&]D*2D@>PH@("`@("`@("`@("`@("`@)&,@
M/2!C;W5N="@D;65T:&]D*3L*("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\("1C.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@)'-M<V<@
M+CT@)&UE=&AO9%LD:5TM/G-E<FEA;&EZ92@D=&AI<RD["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M<VUS9R`])B`D;65T:&]D+3YS97)I86QI>F4H)'1H:7,I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-M<V<@/28@)&UE
M=&AO9#L*("`@("`@("!]"B`@("`@("`@)&)O9'D@/2`B/%-/05`M14Y6.D)O
M9'D^7')<;B(@+B`D<VUS9R`N(")<<EQN/"]33T%0+45.5CI";V1Y/EQR7&XB
M.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VYA;65S<&%C97,@87,@)&L@
M/3X@)'8I('L*("`@("`@("`@("`@)&YS7W-T<FEN9R`N/2`B('AM;&YS.B1V
M/5PB)&M<(EQR7&XB.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/E]N
M86UE<W!A8V4I('L*("`@("`@("`@("`@)&YS7W-T<FEN9R`N/2`B('AM;&YS
M/5PB>R1T:&ES+3Y?;F%M97-P86-E?5PB7')<;B(["B`@("`@("`@?0H*("`@
M("`@("`O*B!)9B`G=7-E)R`]/2`G;&ET97)A;"<L('=E(&1O(&YO="!P=70@
M:6X@=&AE(&5N8V]D:6YG4W1Y;&4N("!4:&ES(&ES"B`@("`@("`@("H@9&5N
M;W1E9"!B>2`D=&AI<RT^7W-E8W1I;VXU(&)E:6YG(&9A;'-E+B`@)W5S92<@
M8V%N(&)E(&1E9FEN960@870@80H@("`@("`@("`J(&UO<F4@9W)A;G5L87(@
M;&5V96P@=&AA;B!W92!A<F4@9&5A;&EN9R!W:71H(&AE<F4L('-O('1H:7,@
M9&]E<R!N;W0*("`@("`@("`@*B!W;W)K(&9O<B!A;&P@<V5R=FEC97,N("HO
M"B`@("`@("`@)'AM;"`]("(\/WAM;"!V97)S:6]N/5PB,2XP7"(@96YC;V1I
M;F<]7"(D96YC;V1I;F=<(C\^7')<;EQR7&XB+@H@("`@("`@("`@("`B/%-/
M05`M14Y6.D5N=F5L;W!E("1N<U]S=')I;F<B+@H@("`@("`@("`@("`H)'1H
M:7,M/E]S96-T:6]N-2`_("<@4T]!4"U%3E8Z96YC;V1I;F=3='EL93TB)R`N
M(%-/05!?4T-(14U!7T5.0T]$24Y'("X@)R(G(#H@)R<I+@H@("`@("`@("`@
M("`B/EQR7&XB+@H@("`@("`@("`@("`B)&AE861E<E]X;6PD8F]D>3PO4T]!
M4"U%3E8Z16YV96QO<&4^7')<;B(["@H@("`@("`@(')E='5R;B`D>&UL.PH@
M("`@?0H*("`@(&9U;F-T:6]N("9?;6%K94UI;65-97-S86=E*"8D>&UL+"`D
M96YC;V1I;F<@/2!33T%07T1%1D%53%1?14Y#3T1)3D<I"B`@("!["B`@("`@
M("`@9VQO8F%L("133T%07V]P=&EO;G,["@H@("`@("`@(&EF("@A:7-S970H
M)%-/05!?;W!T:6]N<ULG36EM92==*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]R86ES95-O87!&875L="@G36EM92!I<R!N;W0@:6YS=&%L;&5D
M)RD["B`@("`@("`@?0H*("`@("`@("`O+R!%;F-O9&4@86YY(&%T=&%C:&UE
M;G1S+@H@("`@("`@("\O(%-E92!H='1P.B\O=W=W+G<S+F]R9R]44B]33T%0
M+6%T=&%C:&UE;G1S"B`@("`@("`@+R\@3F]W('=E(&AA=F4@=&\@;6EM92!E
M;F-O9&4@=&AE(&UE<W-A9V4N"B`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"=C
M;VYT96YT7W1Y<&4G(#T^("=M=6QT:7!A<G0O<F5L871E9#L@='EP93UT97AT
M+WAM;"<I.PH@("`@("`@("1M<V<@/28@;F5W($UA:6Q?;6EM95!A<G0H)R<L
M("1P87)A;7,I.PH*("`@("`@("`O+R!!9&0@=&AE('AM;"!P87)T+@H@("`@
M("`@("1P87)A;7-;)V-O;G1E;G1?='EP92==(#T@)W1E>'0O>&UL)SL*("`@
M("`@("`D<&%R86US6R=C:&%R<V5T)UT@/2`D96YC;V1I;F<["B`@("`@("`@
M)'!A<F%M<ULG96YC;V1I;F<G72`]("=B87-E-C0G.PH@("`@("`@("1M<V<M
M/F%D9%-U8E!A<G0H)'AM;"P@)'!A<F%M<RD["@H@("`@("`@("\O($%D9"!T
M:&4@871T86-H96UE;G1S"B`@("`@("`@)&,@/2!C;W5N="@D=&AI<RT^7U]A
M='1A8VAM96YT<RD["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&,[("1I
M*RLI('L*("`@("`@("`@("`@)&%T=&%C:&UE;G0@/28@)'1H:7,M/E]?871T
M86-H;65N='-;)&E=.PH@("`@("`@("`@("`D;7-G+3YA9&13=6)087)T*"1A
M='1A8VAM96YT6R=B;V1Y)UTL("1A='1A8VAM96YT*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D;7-G+3YE;F-O9&4H*3L*("`@('T*"B`@("`O+R!4
M3T1/.B!T:&ES(&YE961S('1O(&)E('5S960@9G)O;2!T:&4@5')A;G-P;W)T
M('-Y<W1E;2X*("`@(&9U;F-T:6]N("9?;6%K941)345-97-S86=E*"8D>&UL
M*0H@("`@>PH@("`@("`@(&=L;V)A;"`D4T]!4%]O<'1I;VYS.PH*("`@("`@
M("!I9B`H(6ES<V5T*"133T%07V]P=&EO;G-;)T1)344G72DI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)T1)344@:7,@
M;F]T(&EN<W1A;&QE9"<I.PH@("`@("`@('T*"B`@("`@("`@+R\@16YC;V1E
M(&%N>2!A='1A8VAM96YT<RX*("`@("`@("`O+R!3964@:'1T<#HO+W-E87)C
M:"YI971F+F]R9R]I;G1E<FYE="UD<F%F=',O9')A9G0M;FEE;'-E;BUD:6UE
M+7-O87`M,#`N='AT"B`@("`@("`@+R\@3F]W('=E(&AA=F4@=&\@1$E-12!E
M;F-O9&4@=&AE(&UE<W-A9V4*("`@("`@("`D9&EM92`])B!N97<@3F5T7T1)
M345?365S<V%G92@I.PH@("`@("`@("1M<V<@/28@)&1I;64M/F5N8V]D941A
M=&$H)'AM;"P@4T]!4%]%3E9%3$]0+"!N=6QL+"!.151?1$E-15]465!%7U52
M22D["@H@("`@("`@("\O($%D9"!T:&4@871T86-H;65N=',N"B`@("`@("`@
M)&,@/2!C;W5N="@D=&AI<RT^7U]A='1A8VAM96YT<RD["B`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@)&,[("1I*RLI('L*("`@("`@("`@("`@)&%T=&%C
M:&UE;G0@/28@)'1H:7,M/E]?871T86-H;65N='-;)&E=.PH@("`@("`@("`@
M("`D;7-G("X]("1D:6UE+3YE;F-O9&5$871A*"1A='1A8VAM96YT6R=B;V1Y
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%T
M=&%C:&UE;G1;)V-O;G1E;G1?='EP92==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1A='1A8VAM96YT6R=C:60G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!.151?1$E-15]465!%
M7TU%1$E!*3L*("`@("`@("!]"B`@("`@("`@)&US9R`N/2`D9&EM92T^96YD
M365S<V%G92@I.PH*("`@("`@("!R971U<FX@)&US9SL*("`@('T*"B`@("!F
M=6YC=&EO;B!?9&5C;V1E36EM94UE<W-A9V4H)B1D871A+"`F)&AE861E<G,L
M("8D871T86-H;65N=',I"B`@("!["B`@("`@("`@9VQO8F%L("133T%07V]P
M=&EO;G,["@H@("`@("`@(&EF("@A:7-S970H)%-/05!?;W!T:6]N<ULG36EM
M92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=-
M:6UE(%5N<W5P<&]R=&5D+"!I;G-T86QL(%!%05(Z.DUA:6PZ.DUI;64G+"`G
M)RP@)R<L("=397)V97(G*3L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@
M('T*"B`@("`@("`@)'!A<F%M<ULG:6YC;'5D95]B;V1I97,G72`]('1R=64[
M"B`@("`@("`@)'!A<F%M<ULG9&5C;V1E7V)O9&EE<R==("`]('1R=64["B`@
M("`@("`@)'!A<F%M<ULG9&5C;V1E7VAE861E<G,G72`]('1R=64["@H@("`@
M("`@("\O($QA;64@=&AI;F<@=&\@:&%V92!T;R!D;R!F;W(@9&5C;V1I;F<N
M"B`@("`@("`@)&1E8V]D97(@/28@;F5W($UA:6Q?;6EM941E8V]D92@D9&%T
M82D["B`@("`@("`@)'-T<G5C='5R92`]("1D96-O9&5R+3YD96-O9&4H)'!A
M<F%M<RD["@H@("`@("`@(&EF("AI<W-E="@D<W1R=6-T=7)E+3YB;V1Y*2D@
M>PH@("`@("`@("`@("`D9&%T82`]("1S=')U8W1U<F4M/F)O9'D["B`@("`@
M("`@("`@("1H96%D97)S(#T@)'-T<G5C='5R92T^:&5A9&5R<SL*"B`@("`@
M("`@("`@(')E='5R;CL*("`@("`@("!](&5L<V5I9B`H:7-S970H)'-T<G5C
M='5R92T^<&%R=',I*2!["B`@("`@("`@("`@("1D871A(#T@)'-T<G5C='5R
M92T^<&%R='-;,%TM/F)O9'D["B`@("`@("`@("`@("1H96%D97)S(#T@87)R
M87E?;65R9V4H)'-T<G5C='5R92T^:&5A9&5R<RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<W1R=6-T=7)E+3YP87)T<ULP72T^:&5A
M9&5R<RD["B`@("`@("`@("`@(&EF("AC;W5N="@D<W1R=6-T=7)E+3YP87)T
M<RD@/B`Q*2!["B`@("`@("`@("`@("`@("`D;6EM95]P87)T<R`](&%R<F%Y
M7W-P;&EC92@D<W1R=6-T=7)E+3YP87)T<RPQ*3L*("`@("`@("`@("`@("`@
M("\O(%!R97!A<F4@=&AE('!A<G1S(&9O<B!T:&4@4T]!4"!P87)S97(N"@H@
M("`@("`@("`@("`@("`@)&,@/2!C;W5N="@D;6EM95]P87)T<RD["B`@("`@
M("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8SL@)&DK*RD@>PH@("`@
M("`@("`@("`@("`@("`@("1P(#TF("1M:6UE7W!A<G1S6R1I73L*("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)'`M/FAE861E<G-;)V-O;G1E;G0M
M;&]C871I;VXG72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@+R\@5$]$
M3SH@;6]D:69Y(&QO8V%T:6]N('!E<B!3=T$@;F]T92!S96-T:6]N(#,*("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@:'1T<#HO+W=W=RYW,RYO<F<O5%(O
M4T]!4"UA='1A8VAM96YT<PH@("`@("`@("`@("`@("`@("`@("`@("`D871T
M86-H;65N='-;)'`M/FAE861E<G-;)V-O;G1E;G0M;&]C871I;VXG75T@/2`D
M<"T^8F]D>3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D8VED(#T@)V-I9#HG("X@<W5B<W1R*"1P+3YH
M96%D97)S6R=C;VYT96YT+6ED)UTL(#$L("TR*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&%T=&%C:&UE;G1S6R1C:61=(#T@)'`M/F)O9'D["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D
M=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=-:6UE('!A<G-I;F<@97)R;W(G+"`G
M)RP@)R<L("=397)V97(G*3L*("`@('T*"B`@("!F=6YC=&EO;B!?9&5C;V1E
M1$E-14UE<W-A9V4H)B1D871A+"`F)&AE861E<G,L("8D871T86-H;65N=',I
M"B`@("!["B`@("`@("`@9VQO8F%L("133T%07V]P=&EO;G,["@H@("`@("`@
M(&EF("@A:7-S970H)%-/05!?;W!T:6]N<ULG1$E-12==*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=$24U%(%5N<W5P<&]R=&5D
M+"!I;G-T86QL(%!%05(Z.DYE=#HZ1$E-12<L("<G+"`G)RP@)U-E<G9E<B<I
M.PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`O+R!4
M:&ES(%-(3U5,1"!B92!M;W9E9"!T;R!T:&4@=')A;G-P;W)T(&QA>65R+"!E
M+F<N(%!(4"!I='-E;&8@<VAO=6QD"B`@("`@("`@+R\@:&%N9&QE('!A<G-I
M;F<@1$E-12`[*0H@("`@("`@("1D:6UE(#TF(&YE=R!.971?1$E-15]-97-S
M86=E*"D["B`@("`@("`@)&5R<B`]("1D:6UE+3YD96-O9&5$871A*"1D871A
M*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=&86EL960@=&\@9&5C;V1E
M('1H92!$24U%(&UE<W-A9V4A)RP@)R<L("<G+"`G4V5R=F5R)RD["B`@("`@
M("`@("`@(')E='5R;CL*("`@("`@("!]"B`@("`@("`@:68@*'-T<F-A<V5C
M;7`H)&1I;64M/G!A<G1S6S!=6R=T>7!E)UTL(%-/05!?14Y614Q/4"D@(3T@
M,"D@>PH@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=$24U%
M(')E8V]R9"`Q(&ES(&YO="!A(%-/05`@96YV96QO<"$G+"`G)RP@)R<L("=3
M97)V97(G*3L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@
M("`@)&1A=&$@/2`D9&EM92T^<&%R='-;,%U;)V1A=&$G73L*("`@("`@("`O
M+R!&86ME(&ET(&9O<B!N;W<N"B`@("`@("`@)&AE861E<G-;)V-O;G1E;G0M
M='EP92==(#T@)W1E>'0O>&UL)SL*("`@("`@("`D8R`](&-O=6YT*"1D:6UE
M+3YP87)T<RD["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&,[("1I*RLI
M('L*("`@("`@("`@("`@)'!A<G0@/28@)&1I;64M/G!A<G1S6R1I73L*("`@
M("`@("`@("`@+R\@5V4@;F5E9"!T;R!H86YD;&4@55)))W,@8F5T=&5R+@H@
M("`@("`@("`@("`D:60@/2!S=')N8VUP*"1P87)T6R=I9"==+"`G8VED.B<L
M(#0I"B`@("`@("`@("`@("`@("`_("=C:60Z)R`N("1P87)T6R=I9"=="B`@
M("`@("`@("`@("`@("`Z("1P87)T6R=I9"==.PH@("`@("`@("`@("`D871T
M86-H;65N='-;)&ED72`]("1P87)T6R=D871A)UT["B`@("`@("`@?0H@("`@
M?0H*("`@(&9U;F-T:6]N(%]?<V5T7W1Y<&5?=')A;G-L871I;VXH)'1Y<&4L
M("1C;&%S<R`](&YU;&PI"B`@("!["B`@("`@("`@)'1Q(#TF(&YE=R!13F%M
M92@D='EP92D["B`@("`@("`@:68@*"$D8VQA<W,I('L*("`@("`@("`@("`@
M)&-L87-S(#T@)'1Q+3YN86UE.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^
M7W1Y<&5?=')A;G-L871I;VY;)'1Y<&5=/21C;&%S<SL*("`@('T*"GT*"B\J
M*@H@*B!#;&%S<R!U<V5D('1O(&AA;F1L92!13D%-12!V86QU97,@:6X@6$U,
M+@H@*@H@*B!`86-C97-S("`@<'5B;&EC"B`J($!P86-K86=E("!33T%0"B`J
M($!A=71H;W(@("!3:&%N92!#87)A=F5O(#QS:&%N94!P:'`N;F5T/B!#;VYV
M97)S:6]N('1O(%!%05(@86YD('5P9&%T97,*("HO"F-L87-S(%%.86UE"GL*
M("`@('9A<B`D;F%M92`]("<G.PH@("`@=F%R("1N<R`]("<G.PH@("`@=F%R
M("1N86UE<W!A8V4])R<["@H@("`@9G5N8W1I;VX@44YA;64H)&YA;64L("1N
M86UE<W!A8V4@/2`G)RD*("`@('L*("`@("`@("!I9B`H)&YA;64@)B8@)&YA
M;65;,%T@/3T@)WLG*2!["B`@("`@("`@("`@('!R96=?;6%T8V@H)R]<>R@N
M*C\I7'TH+BHI+R<L("1N86UE+"`D;2D["B`@("`@("`@("`@("1T:&ES+3YN
M86UE(#T@)&U;,ET["B`@("`@("`@("`@("1T:&ES+3YN86UE<W!A8V4@/2`D
M;5LQ73L*("`@("`@("!](&5L<V5I9B`H<W5B<W1R7V-O=6YT*"1N86UE+"`G
M.B<I(#T](#$I('L*("`@("`@("`@("`@)',@/2!E>'!L;V1E*"<Z)RP@)&YA
M;64I.PH@("`@("`@("`@("`D<R`](&%R<F%Y7W)E=F5R<V4H)',I.PH@("`@
M("`@("`@("`D=&AI<RT^;F%M92`]("1S6S!=.PH@("`@("`@("`@("`D=&AI
M<RT^;G,@/2`D<ULQ73L*("`@("`@("`@("`@)'1H:7,M/FYA;65S<&%C92`]
M("1N86UE<W!A8V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H
M:7,M/FYA;64@/2`D;F%M93L*("`@("`@("`@("`@)'1H:7,M/FYA;65S<&%C
M92`]("1N86UE<W!A8V4["B`@("`@("`@?0H*("`@("`@("`O+R!!(&QI='1L
M92!M;W)E(&UA9VEC('1H86X@<VAO=6QD(&)E(&EN(&$@<6YA;64N"B`@("`@
M("`@)'`@/2!S=')P;W,H)'1H:7,M/FYA;64L("=;)RD["B`@("`@("`@:68@
M*"1P*2!["B`@("`@("`@("`@("\O(%1/1$\Z($YE960@=&\@<F4M97AA;6EN
M92!T:&ES(&QO9VEC(&QA=&5R+@H@("`@("`@("`@("`O+R!#:&]P(&]F9B!;
M72X*("`@("`@("`@("`@)'1H:7,M/F%R<F%Y4VEZ92`](&5X<&QO9&4H)RPG
M+"!S=6)S='(H)'1H:7,M/FYA;64L("1P("L@,2P@+21P("T@,BDI.PH@("`@
M("`@("`@("`D=&AI<RT^87)R87E);F9O(#T@<W5B<W1R*"1T:&ES+3YN86UE
M+"`D<"D["B`@("`@("`@("`@("1T:&ES+3YN86UE(#T@<W5B<W1R*"1T:&ES
M+3YN86UE+"`P+"`D<"D["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N
M(&9Q;B@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YN86UE<W!A8V4I('L*
M("`@("`@("`@("`@<F5T=7)N("=[)R`N("1T:&ES+3YN86UE<W!A8V4@+B`G
M?2<@+B`D=&AI<RT^;F%M93L*("`@("`@("!](&5L<V5I9B`H)'1H:7,M/FYS
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;G,@+B`G.B<@+B`D=&AI
M<RT^;F%M93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YN86UE
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+U-/05`O0VQI96YT+G!H<```````````````````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#8Q,#<Q`#$P-3$U-#,S-S,W`#`R,3,P
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@5&AI<R!F:6QE(&-O;G1A:6YS('1H92!C;V1E(&9O<B!T
M:&4@4T]!4"!C;&EE;G0N"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J
M"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V
M97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+`H@*B!T:&%T(&ES(&)U
M;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@
M86YD(&ES(&%V86EL86)L92!A=`H@*B!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8B!A="!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@
M;&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70*("H@=&AR;W5G
M:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R!L
M:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N"B`J(&UA:6P@>6]U(&$@8V]P>2!I
M;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@5V5B(%-E<G9I8V5S"B`J
M($!P86-K86=E("`@(%-/05`*("H@0&%U=&AO<B`@("`@1&EE=')I8V@@07EA
M;&$@/&1I971R:6-H0&=A;G@T+F-O;3X@3W)I9VEN86P@075T:&]R"B`J($!A
M=71H;W(@("`@(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@
M(%!O<G0@=&\@4$5!4B!A;F0@;6]R90H@*B!`875T:&]R("`@("!#:'5C:R!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX@("!-86EN=&5N86YC90H@*B!`
M875T:&]R("`@("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/B`@("`@
M("!-86EN=&5N86YC90H@*B!`8V]P>7)I9VAT("`R,#`S+3(P,#4@5&AE(%!(
M4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\R7S`R+G1X="`@4$A0($QI8V5N<V4@,BXP,@H@*B!`;&EN:R`@("`@
M("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4T]!4`H@*B\*"G)E<75I
M<F5?;VYC92`G4T]!4"]686QU92YP:'`G.PIR97%U:7)E7V]N8V4@)U-/05`O
M0F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)U-/05`O5')A;G-P;W)T+G!H<"<[
M"G)E<75I<F5?;VYC92`G4T]!4"]74T1,+G!H<"<["G)E<75I<F5?;VYC92`G
M4T]!4"]&875L="YP:'`G.PIR97%U:7)E7V]N8V4@)U-/05`O4&%R<V5R+G!H
M<"<["@HO+R!!<FYA=60Z('1H92!F;VQL;W=I;F<@8V]D92!W87,@=&%K96X@
M9G)O;2!$871A3V)J96-T(&%N9"!A9&%P=&5D('1O('-U:70*"B\O('1H:7,@
M=VEL;"!B92!H;W)R:69I8V%L;'D@<VQO=R$A(2$*+R\@3D]413H@3W9E<FQO
M860@4T5'1D%53%13($].(%!(4#0@*R!:96YD($]P=&EM:7IE<@HO+R!T:&5S
M92!T=V\@87)E($)#+T9#(&AA;F1L97)S(&9O<B!C86QL(&EN(%!(4#0O-0H*
M:68@*"%C;&%S<U]E>&ES=',H)U-/05!?0VQI96YT7T]V97)L;V%D)RDI('L*
M("`@(&EF("AS=6)S='(H<&AP=F5R<VEO;B@I+"`P+"`Q*2`]/2`U*2!["B`@
M("`@("`@8VQA<W,@4T]!4%]#;&EE;G1?3W9E<FQO860@97AT96YD<R!33T%0
M7T)A<V4@>PH@("`@("`@("`@("!F=6YC=&EO;B!?7V-A;&PH)&UE=&AO9"P@
M)&%R9W,I"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@("1R971U<FX@
M/2!N=6QL.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C86QL*"1M971H;V0L
M("1A<F=S+"`D<F5T=7)N*3L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5T
M=7)N.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@
M("`@("!I9B`H(69U;F-T:6]N7V5X:7-T<R@G8VQO;F4G*2D@>PH@("`@("`@
M("`@("!E=F%L*"=F=6YC=&EO;B!C;&]N92@D="D@>R!R971U<FX@)'0[('TG
M*3L*("`@("`@("!]"B`@("`@("`@979A;"@G"B`@("`@("`@("`@(&-L87-S
M(%-/05!?0VQI96YT7T]V97)L;V%D(&5X=&5N9',@4T]!4%]"87-E('L*("`@
M("`@("`@("`@("`@(&9U;F-T:6]N(%]?8V%L;"@D;65T:&]D+"`D87)G<RP@
M)B1R971U<FXI"B`@("`@("`@("`@("`@("!["B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?8V%L;"@D;65T:&]D+"`D87)G<RP@)')E='5R
M;BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('TG*3L*("`@('T*
M?0H*+RHJ"B`J(%-/05`@0VQI96YT($-L87-S"B`J"B`J(%1H:7,@8VQA<W,@
M:7,@=&AE(&UA:6X@:6YT97)F86-E(&9O<B!M86MI;F<@<V]A<"!R97%U97-T
M<RX*("H*("H@8F%S:6,@=7-A9V4Z/&-O9&4^"B`J("`@)'-O87!C;&EE;G0@
M/2!N97<@4T]!4%]#;&EE;G0H('-T<FEN9R!P871H(%L@+"!B;V]L96%N('=S
M9&Q=("D["B`J("`@96-H;R`D<V]A<&-L:65N="T^8V%L;"@@<W1R:6YG(&UE
M=&AO9&YA;64@6R`L(&%R<F%Y('!A<F%M971E<G-=("D["B`J(#PO8V]D93X*
M("H*("H@3W)I9VEN86QL>2!B87-E9"!O;B!33T%0>#0@8GD@1&EE=')I8V@@
M07EA;&$*("H@:'1T<#HO+V1I971R:6-H+F=A;G@T+F-O;2]S;V%P>#0*("H*
M("H@0&%C8V5S<R`@('!U8FQI8PH@*B!`<&%C:V%G92`@4T]!4`H@*B!`875T
M:&]R("`@4VAA;F4@0V%R879E;R`\<VAA;F5`<&AP+FYE=#X@0V]N=F5R<VEO
M;B!T;R!014%2(&%N9"!U<&1A=&5S"B`J($!A=71H;W(@("!3=&EG($)A:VME
M;B`\<W-B0&9A<W0N;F\^($-O;G9E<G-I;VX@=&\@4$5!4@H@*B!`875T:&]R
M("`@1&EE=')I8V@@07EA;&$@/&1I971R:6-H0&=A;G@T+F-O;3X@3W)I9VEN
M86P@075T:&]R"B`J+PIC;&%S<R!33T%07T-L:65N="!E>'1E;F1S(%-/05!?
M0VQI96YT7T]V97)L;V%D"GL*("`@("\J*@H@("`@("H@0V]M;75N:6-A=&EO
M;B!E;F1P;VEN="X*("`@("`J"B`@("`@*B!#=7)R96YT;'D@=&AE(&9O;&QO
M=VEN9R!T<F%N<W!O<G0@9F]R;6%T<R!A<F4@<W5P<&]R=&5D.@H@("`@("H@
M("T@2%144`H@("`@("H@("T@4TU44`H@("`@("H*("`@("`J($5X86UP;&4@
M96YD<&]I;G1S.@H@("`@("H@("!H='1P.B\O=W=W+F5X86UP;&4N8V]M+W-O
M87`O<V5R=F5R+G!H<`H@("`@("H@("!H='1P<SHO+W=W=RYE>&%M<&QE+F-O
M;2]S;V%P+W-E<G9E<BYP:'`*("`@("`J("`@;6%I;'1O.G-O87!`97AA;7!L
M92YC;VT*("`@("`J"B`@("`@*B!`<V5E("!33T%07T-L:65N="@I"B`@("`@
M*B!`=F%R("1?96YD<&]I;G0@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V5N
M9'!O:6YT(#T@)R<["@H@("`@+RHJ"B`@("`@*B!4:&4@4T]!4"!03U)4(&YA
M;64@=&AA="!I<R!U<V5D(&)Y('1H92!C;&EE;G0N"B`@("`@*@H@("`@("H@
M0'9A<B`D7W!O<G1.86UE('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]P;W)T
M3F%M92`]("<G.PH*("`@("\J*@H@("`@("H@16YD<&]I;G0@='EP92!E+F<N
M("=W9'-L)RX*("`@("`J"B`@("`@*B!`=F%R("1?7V5N9'!O:6YT5'EP92!S
M=')I;F<*("`@("`J+PH@("`@=F%R("1?7V5N9'!O:6YT5'EP92`]("<G.PH*
M("`@("\J*@H@("`@("H@5&AE(')E8V5I=F5D('AM;"X*("`@("`J"B`@("`@
M*B!`=F%R("1X;6P@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D>&UL.PH*("`@
M("\J*@H@("`@("H@5&AE(&]U=&=O:6YG(&%N9"!I;F-O;6EN9R!D871A('-T
M<F5A;2!F;W(@9&5B=6=G:6YG+@H@("`@("H*("`@("`J($!V87(@)'=I<F4@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D=VER93L*("`@('9A<B`D7U]L87-T
M7W)E<75E<W0@/2!N=6QL.PH@("`@=F%R("1?7VQA<W1?<F5S<&]N<V4@/2!N
M=6QL.PH*("`@("\J*@H@("`@("H@3W!T:6]N<RX*("`@("`J"B`@("`@*B!`
M=F%R("1?7V]P=&EO;G,@87)R87D*("`@("`J+PH@("`@=F%R("1?7V]P=&EO
M;G,@/2!A<G)A>2@G=')A8V4G/3XP*3L*"B`@("`O*BH*("`@("`J(%1H92!C
M:&%R86-T97(@96YC;V1I;F<@=7-E9"!F;W(@6$U,('!A<G-E<BP@971C+@H@
M("`@("H*("`@("`J($!V87(@)%]E;F-O9&EN9R!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1?96YC;V1I;F<@/2!33T%07T1%1D%53%1?14Y#3T1)3D<["@H@
M("`@+RHJ"B`@("`@*B!4:&4@87)R87D@;V8@4T]!4%](96%D97)S('1H870@
M=V4@87)E('-E;F1I;F<N"B`@("`@*@H@("`@("H@0'9A<B`D:&5A9&5R<T]U
M="!A<G)A>0H@("`@("HO"B`@("!V87(@)&AE861E<G-/=70@/2!N=6QL.PH*
M("`@("\J*@H@("`@("H@5&AE(&AE861E<G,@=V4@<F5C:65V960@8F%C:R!I
M;B!T:&4@<F5S<&]N<V4N"B`@("`@*@H@("`@("H@0'9A<B`D:&5A9&5R<TEN
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D:&5A9&5R<TEN(#T@;G5L;#L*"B`@
M("`O*BH*("`@("`J($]P=&EO;G,@9F]R('1H92!(5%107U)E<75E<W0@8VQA
M<W,@*'-E92!(5%10+U)E<75E<W0N<&AP*2X*("`@("`J"B`@("`@*B!`=F%R
M("1?7W!R;WAY7W!A<F%M<R!A<G)A>0H@("`@("HO"B`@("!V87(@)%]?<')O
M>'E?<&%R86US(#T@87)R87DH*3L*"B`@("!V87(@)%]S;V%P7W1R86YS<&]R
M="`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&5N9'!O:6YT("`@("!!;B!54DPN"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D=W-D;"`@("`@("`@5VAE=&AE<B!T:&4@96YD<&]I;G0@:7,@82!7
M4T1,(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P;W)T3F%M90H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P<F]X>5]P87)A;7,@($]P=&EO;G,@9F]R('1H
M92!(5%107U)E<75E<W0@8VQA<W,@*'-E90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@($A45%`O4F5Q=65S="YP:'`I"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%-/05!?0VQI96YT*"1E;F1P;VEN="P@)'=S9&P@/2!F86QS
M92P@)'!O<G1.86UE(#T@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`D<')O>'E?<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!P87)E
M;G0Z.E-/05!?0F%S92@G0VQI96YT)RD["@H@("`@("`@("1T:&ES+3Y?96YD
M<&]I;G0@/2`D96YD<&]I;G0["B`@("`@("`@)'1H:7,M/E]P;W)T3F%M92`]
M("1P;W)T3F%M93L*("`@("`@("`D=&AI<RT^7U]P<F]X>5]P87)A;7,@/2`D
M<')O>'E?<&%R86US.PH*("`@("`@("`O+R!4:&ES(&AA8VL@<VAO=6QD('!E
M<FAA<',@8F4@<F5M;W9E9"!A<R!I="!M:6=H="!C875S92!U;F5X<&5C=&5D
M"B`@("`@("`@+R\@8F5H879I;W5R+@H@("`@("`@("1W<V1L(#T@)'=S9&P*
M("`@("`@("`@("`@/R`D=W-D;`H@("`@("`@("`@("`Z('-T<G1O;&]W97(H
M<W5B<W1R*"1E;F1P;VEN="P@+30I*2`]/2`G=W-D;"<["@H@("`@("`@("\O
M(&UA:V4@=F%L=65S"B`@("`@("`@:68@*"1W<V1L*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?7V5N9'!O:6YT5'EP92`]("=W<V1L)SL*("`@("`@("`@("`@
M+R\@:6YS=&%N=&EA=&4@=W-D;"!C;&%S<PH@("`@("`@("`@("`D=&AI<RT^
M7W=S9&P@/28@;F5W(%-/05!?5U-$3"@D=&AI<RT^7V5N9'!O:6YT+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7U]P<F]X>5]P87)A;7,I.PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]W<V1L
M+3YF875L="D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&
M875L="@D=&AI<RT^7W=S9&PM/F9A=6QT*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?<F5S970H*0H@("`@>PH@("`@
M("`@("1T:&ES+3YX;6P@/2!N=6QL.PH@("`@("`@("1T:&ES+3YW:7)E(#T@
M;G5L;#L*("`@("`@("`D=&AI<RT^7U]L87-T7W)E<75E<W0@/2!N=6QL.PH@
M("`@("`@("1T:&ES+3Y?7VQA<W1?<F5S<&]N<V4@/2!N=6QL.PH@("`@("`@
M("1T:&ES+3YH96%D97)S26X@/2!N=6QL.PH@("`@("`@("1T:&ES+3YH96%D
M97)S3W5T(#T@;G5L;#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE
M(&-H87)A8W1E<B!E;F-O9&EN9RX*("`@("`J"B`@("`@*B!,:6UI=&5D('1O
M("=55$8M."<L("=54U]!4T-)22<@86YD("=)4T\M.#@U.2TQ)RX*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@96YC;V1I;F<*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!3
M3T%07T9A=6QT(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971%
M;F-O9&EN9R@D96YC;V1I;F<I"B`@("!["B`@("`@("`@:68@*&EN7V%R<F%Y
M*"1E;F-O9&EN9RP@)'1H:7,M/E]E;F-O9&EN9W,I*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?96YC;V1I;F<@/2`D96YC;V1I;F<["B`@("`@("`@("`@(')E
M='5R;CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53
M;V%P1F%U;'0H)TEN=F%L:60@16YC;V1I;F<G*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($%D9',@82!H96%D97(@=&\@=&AE(&5N=F5L;W!E+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0'!A<F%M(%-/
M05!?2&5A9&5R("1S;V%P7W9A;'5E("!!(%-/05!?2&5A9&5R(&]R(&%N(&%R
M<F%Y('=I=&@@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&5L96UE;G1S("=N86UE)RP@)VYA;65S<&%C92<L"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M=7-T=6YD97)S=&%N
M9"<L(&%N9"`G86-T;W(G('1O('-E;F0*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87,@82!H96%D97(N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%D9$AE861E<B@F)'-O87!?=F%L=64I"B`@("!["B`@("`@("`@
M+R\@061D(&$@;F5W(&AE861E<B!T;R!T:&4@;65S<V%G92X*("`@("`@("!I
M9B`H:7-?82@D<V]A<%]V86QU92P@)U-/05!?2&5A9&5R)RDI('L*("`@("`@
M("`@("`@)'1H:7,M/FAE861E<G-/=71;72`])B`D<V]A<%]V86QU93L*("`@
M("`@("!](&5L<V5I9B`H:7-?87)R87DH)'-O87!?=F%L=64I*2!["B`@("`@
M("`@("`@("\O(&YA;64L('9A;'5E+"!N86UE<W!A8V4L(&UU<W1U;F1E<G-T
M86YD+"!A8W1O<@H@("`@("`@("`@("`D=&AI<RT^:&5A9&5R<T]U=%M=(#TF
M(&YE=R!33T%07TAE861E<B@D<V]A<%]V86QU95LP72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;G5L;"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'-O87!?=F%L=65;,5TL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S;V%P7W9A;'5E6S)=+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<V]A<%]V86QU95LS72D[.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)TEN=F%L:60@<&%R86UE
M=&5R('!R;W9I9&5D('1O(&%D9$AE861E<B@I+B`@375S="!B92!A;B!A<G)A
M>2!O<B!A(%-/05!?2&5A9&5R+B<I.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($-A;&QS(&$@;65T:&]D(&]N('1H92!33T%0(&5N9'!O:6YT
M+@H@("`@("H*("`@("`J(%1H92!N86UE<W!A8V4@<&%R86UE=&5R(&ES(&]V
M97)L;V%D960@=&\@86-C97!T(&%N(&%R<F%Y(&]F(&]P=&EO;G,*("`@("`J
M('1H870@8V%N(&-O;G1A:6X@9&%T82!N96-E<W-A<GD@9F]R('9A<FEO=7,@
M=')A;G-P;W)T<R!I9B!I="!I<R!U<V5D(&%S"B`@("`@*B!A;B!A<G)A>2P@
M:70@34%9(&-O;G1A:6X@82!N86UE<W!A8V4@=F%L=64@86YD(&$@<V]A<&%C
M=&EO;B!V86QU92X@($EF"B`@("`@*B!I="!I<R!O=F5R;&]A9&5D+"!T:&4@
M<V]A<&%C=&EO;B!P87)A;65T97(@:7,@:6=N;W)E9"!A;F0@35535"!B90H@
M("`@("H@<&QA8V5D(&EN('1H92!O<'1I;VYS(&%R<F%Y+B`@5&AI<R!I<R!D
M;VYE('1O('!R;W9I9&4@8F%C:W=A<F1S"B`@("`@*B!C;VUP871I8FEL:71Y
M('=I=&@@8W5R<F5N="!C;&EE;G1S+"!B=70@;6%Y(&)E(')E;6]V960@:6X@
M=&AE(&9U='5R92X*("`@("`J(%1H92!C=7)R96YT;'D@<W5P<&]R=&5D('9A
M;'5E<R!A<F4Z/'!R93X*("`@("`J("`@;F%M97-P86-E"B`@("`@*B`@('-O
M87!A8W1I;VX*("`@("`J("`@=&EM96]U="`H2%144"!S;V-K970@=&EM96]U
M="D*("`@("`J("`@=')A;G-F97(M96YC;V1I;F<@*%--5%`L($-O;G1E;G0M
M5')A;G-F97(M16YC;V1I;F<Z(&AE861E<BD*("`@("`J("`@9G)O;2`H4TU4
M4"P@1G)O;3H@:&5A9&5R*0H@("`@("H@("!S=6)J96-T("A33510+"!3=6)J
M96-T.B!H96%D97(I"B`@("`@*B`@(&AE861E<G,@*%--5%`L(&AA<V@@;V8@
M97AT<F$@4TU44"!H96%D97)S*0H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1M971H;V0@("`@("`@("`@(%1H92!M971H;V0@=&\@8V%L;"X*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86US("`@("`@("`@("`@5&AE(&UE=&AO9"!P
M87)A;65T97)S+@H@("`@("H@0'!A<F%M('-T<FEN9WQA<G)A>2`D;F%M97-P
M86-E("!.86UE<W!A8V4@;W(@:&%S:"!W:71H(&]P=&EO;G,N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1S;V%P06-T:6]N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5&AE(&UE=&AO9"!R97-U;'0@;W(@82!33T%07T9A=6QT(&]N
M(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F8V%L;"@D;65T:&]D+"`F
M)'!A<F%M<RP@)&YA;65S<&%C92`](&9A;'-E+"`D<V]A<$%C=&EO;B`](&9A
M;'-E*0H@("`@>PH@("`@("`@("1T:&ES+3YH96%D97)S26X@/2!N=6QL.PH@
M("`@("`@("1T:&ES+3Y?7VQA<W1?<F5Q=65S="`](&YU;&P["B`@("`@("`@
M)'1H:7,M/E]?;&%S=%]R97-P;VYS92`](&YU;&P["B`@("`@("`@)'1H:7,M
M/G=I<F4@/2!N=6QL.PH@("`@("`@("1T:&ES+3YX;6P@/2!N=6QL.PH*("`@
M("`@("`D<V]A<%]D871A(#TF("1T:&ES+3Y?7V=E;F5R871E*"1M971H;V0L
M("1P87)A;7,L("1N86UE<W!A8V4L("1S;V%P06-T:6]N*3L*("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D<V]A<%]D871A*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@D<V]A<%]D871A*3L*("`@
M("`@("!]"@H@("`@("`@("\O(%]?9V5N97)A=&4H*2!M87D@:&%V92!C:&%N
M9V5D('1H92!E;F1P;VEN="!I9B!T:&4@5U-$3"!H87,@;6]R90H@("`@("`@
M("\O('1H86X@;VYE('-E<G9I8V4L('-O('=E(&YE960@=&\@<V5E(&EF('=E
M(&YE960@=&\@9V5N97)A=&4@82!N97<*("`@("`@("`O+R!T<F%N<W!O<G0@
M=&\@:&]O:R!T;R!A(&1I9F9E<F5N="!54DDN("!3:6YC92!T:&4@=')A;G-P
M;W)T('!R;W1O8V]L"B`@("`@("`@+R\@8V%N(&%L<V\@8VAA;F=E+"!W92!N
M965D('1O(&=E="!A;B!E;G1I<F5L>2!N97<@;V)J96-T+B`@5&AI<R!C;W5L
M9`H@("`@("`@("\O('!R;V)A8FQY(&)E(&]P=&EM:7IE9"X*("`@("`@("!I
M9B`H(21T:&ES+3Y?<V]A<%]T<F%N<W!O<G0@?'P*("`@("`@("`@("`@)'1H
M:7,M/E]E;F1P;VEN="`A/2`D=&AI<RT^7W-O87!?=')A;G-P;W)T+3YU<FPI
M('L*("`@("`@("`@("`@)'1H:7,M/E]S;V%P7W1R86YS<&]R="`])B!33T%0
M7U1R86YS<&]R=#HZ9V5T5')A;G-P;W)T*"1T:&ES+3Y?96YD<&]I;G0I.PH@
M("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D=&AI<RT^7W-O87!?=')A
M;G-P;W)T*2D@>PH@("`@("`@("`@("`@("`@)&9A=6QT(#TF("1T:&ES+3Y?
M<V]A<%]T<F%N<W!O<G0["B`@("`@("`@("`@("`@("`D=&AI<RT^7W-O87!?
M=')A;G-P;W)T(#T@;G5L;#L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7W)A:7-E4V]A<$9A=6QT*"1F875L="D["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@)'1H:7,M/E]S;V%P7W1R86YS<&]R="T^96YC;V1I
M;F<@/2`D=&AI<RT^7V5N8V]D:6YG.PH*("`@("`@("`O+R!396YD('1H92!M
M97-S86=E+@H@("`@("`@("1T<F%N<W!O<G1?;W!T:6]N<R`](&%R<F%Y7VUE
M<F=E7W)E8W5R<VEV92@D=&AI<RT^7U]P<F]X>5]P87)A;7,L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?7V]P=&EO;G,I.PH@("`@("`@("1T:&ES+3YX;6P@/28@)'1H:7,M
M/E]S;V%P7W1R86YS<&]R="T^<V5N9"@D<V]A<%]D871A+"`D=')A;G-P;W)T
M7V]P=&EO;G,I.PH*("`@("`@("`O+R!3879E('1H92!W:7)E(&EN9F]R;6%T
M:6]N(&9O<B!D96)U9V=I;F<N"B`@("`@("`@:68@*"1T:&ES+3Y?7V]P=&EO
M;G-;)W1R86-E)UT@/B`P*2!["B`@("`@("`@("`@("1T:&ES+3Y?7VQA<W1?
M<F5Q=65S="`])B`D=&AI<RT^7W-O87!?=')A;G-P;W)T+3YO=71G;VEN9U]P
M87EL;V%D.PH@("`@("`@("`@("`D=&AI<RT^7U]L87-T7W)E<W!O;G-E(#TF
M("1T:&ES+3Y?<V]A<%]T<F%N<W!O<G0M/FEN8V]M:6YG7W!A>6QO860["B`@
M("`@("`@("`@("1T:&ES+3YW:7)E(#TF("1T:&ES+3Y?7V=E=%]W:7)E*"D[
M"B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^7W-O87!?=')A;G-P;W)T
M+3YF875L="D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O
M87!&875L="@D=&AI<RT^>&UL*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3Y?7V%T=&%C:&UE;G1S(#TF("1T:&ES+3Y?<V]A<%]T<F%N<W!O<G0M/F%T
M=&%C:&UE;G1S.PH@("`@("`@("1T:&ES+3Y?7W)E<W5L=%]E;F-O9&EN9R`]
M("1T:&ES+3Y?<V]A<%]T<F%N<W!O<G0M/G)E<W5L=%]E;F-O9&EN9SL*"B`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?7V]P=&EO;G-;)W)E<W5L="==*2`F
M)@H@("`@("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R=R97-U;'0G72`A/2`G
M<&%R<V4G*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^>&UL.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?7W!A<G-E*"1T:&ES+3YX
M;6PL("1T:&ES+3Y?7W)E<W5L=%]E;F-O9&EN9RP@)'1H:7,M/E]?871T86-H
M;65N=',I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!A;B!O<'1I;VX@
M=&\@=7-E('=I=&@@=&AE('1R86YS<&]R="!L87EE<G,N"B`@("`@*@H@("`@
M("H@1F]R(&5X86UP;&4Z"B`@("`@*B`\8V]D93X*("`@("`J("1S;V%P8VQI
M96YT+3YS971/<'0H)V-U<FPG+"!#55),3U!47U9%4D)/4T4L(#$I"B`@("`@
M*B`\+V-O9&4^"B`@("`@*B!T;R!P87-S(&$@<W!E8VEF:6,@;W!T:6]N('1O
M(&-U<FP@:68@=7-I;F<@86X@4U-,(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1C871E9V]R>2`@0V%T96=O<GD@=&\@=VAI8V@@=&AE(&]P=&EO;B!A<'!L
M:65S(&]R(&]P=&EO;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M(&YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1O<'1I;VX@("`@06X@;W!T
M:6]N(&YA;64@:68@)&-A=&5G;W)Y(&ES(&$@8V%T96=O<GD@;F%M92P*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("!A;B!O<'1I;VX@=F%L=64@
M:68@)&-A=&5G;W)Y(&ES(&%N(&]P=&EO;B!N86UE+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=F%L=64@("`@($%N(&]P=&EO;B!V86QU92!I9B`D8V%T96=O
M<GD@:7,@82!C871E9V]R>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@(&YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$]P="@D8V%T96=O
M<GDL("1O<'1I;VXL("1V86QU92`](&YU;&PI"B`@("!["B`@("`@("`@:68@
M*"%I<U]N=6QL*"1V86QU92DI('L*("`@("`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^7U]O<'1I;VYS6R1C871E9V]R>5TI*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7U]O<'1I;VYS6R1C871E9V]R>5T@/2!A<G)A>2@I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)&-A=&5G
M;W)Y75LD;W!T:6]N72`]("1V86QU93L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R1C871E9V]R>5T@/2`D;W!T:6]N
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-A;&P@;65T:&]D
M('-U<'!O<G1I;F<@=&AE(&]V97)L;V%D(&5X=&5N<VEO;BX*("`@("`J"B`@
M("`@*B!)9B!T:&4@;W9E<FQO860@97AT96YS:6]N(&ES(&QO861E9"P@>6]U
M(&-A;B!C86QL('1H92!C;&EE;G0@8VQA<W,@=VET:`H@("`@("H@82!S;V%P
M(&UE=&AO9"!N86UE.@H@("`@("H@/&-O9&4^"B`@("`@*B`D<V]A<"`](&YE
M=R!33T%07T-L:65N="@N+BXN*3L*("`@("`J("1V86QU92`]("1S;V%P+3YG
M9713=&]C:U%U;W1E*"=-4T94)RD["B`@("`@*B`\+V-O9&4^"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1M971H;V0@("`@("`@(%1H92!M971H;V0@=&\@8V%L;"X*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86US("`@("`@("`@5&AE(&UE=&AO9"!P87)A
M;65T97)S+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5T=7)N7W9A;'5E("!7
M:6QL(&=E="!T:&4@;65T:&]D)W,@<F5T=7)N('9A;'5E"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%S<VEG;F5D+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@06QW87ES('1R=64N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]C86QL*"1M971H;V0L("1P87)A;7,L("8D<F5T=7)N7W9A
M;'5E*0H@("`@>PH@("`@("`@("\O($]V97)L;V%D:6YG(&QO=V5R8V%S97,@
M=&AE(&UE=&AO9"!N86UE+"!W92!N965D('1O(&QO;VL@:6YT;R!T:&4*("`@
M("`@("`O+R!W<V1L(&%N9"!T<GD@=&\@9FEN9"!T:&4@8V]R<F5C="!M971H
M;V0@;F%M92!T;R!G970@=&AE(&-O<G)E8W0*("`@("`@("`O+R!C87-E(&9O
M<B!T:&4@8V%L;"X*("`@("`@("!I9B`H)'1H:7,M/E]W<V1L*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?=W-D;"T^;6%T8VA-971H;V0H)&UE=&AO9"D["B`@
M("`@("`@?0H*("`@("`@("`D<F5T=7)N7W9A;'5E(#TF("1T:&ES+3YC86QL
M*"1M971H;V0L("1P87)A;7,I.PH*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("!F=6YC=&EO;B`F7U]G971L87-T<F5Q=65S="@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?7VQA<W1?<F5Q=65S=#L*("`@('T*"B`@
M("!F=6YC=&EO;B`F7U]G971L87-T<F5S<&]N<V4H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7U]L87-T7W)E<W!O;G-E.PH@("`@?0H*("`@(&9U
M;F-T:6]N(%]?=7-E*"1U<V4I"B`@("!["B`@("`@("`@)'1H:7,M/E]?;W!T
M:6]N<ULG=7-E)UT@/2`D=7-E.PH@("`@?0H*("`@(&9U;F-T:6]N(%]?<W1Y
M;&4H)'-T>6QE*0H@("`@>PH@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)W-T
M>6QE)UT@/2`D<W1Y;&4["B`@("!]"@H@("`@9G5N8W1I;VX@7U]T<F%C92@D
M;&5V96PI"B`@("!["B`@("`@("`@)'1H:7,M/E]?;W!T:6]N<ULG=')A8V4G
M72`]("1L979E;#L*("`@('T*"B`@("!F=6YC=&EO;B`F7U]G96YE<F%T92@D
M;65T:&]D+"`F)'!A<F%M<RP@)&YA;65S<&%C92`](&9A;'-E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@)'-O87!!8W1I;VX@/2!F86QS92D*("`@('L*
M("`@("`@("`D=&AI<RT^9F%U;'0@/2!N=6QL.PH@("`@("`@("1T:&ES+3Y?
M7V]P=&EO;G-;)VEN<'5T)UT])W!A<G-E)SL*("`@("`@("`D=&AI<RT^7U]O
M<'1I;VYS6R=R97-U;'0G73TG<&%R<V4G.PH@("`@("`@("1T:&ES+3Y?7V]P
M=&EO;G-;)W!A<F%M971E<G,G72`](&9A;'-E.PH*("`@("`@("!I9B`H)'!A
M<F%M<R`F)B!G971T>7!E*"1P87)A;7,I("$]("=A<G)A>2<I('L*("`@("`@
M("`@("`@)'!A<F%M<R`](&%R<F%Y*"1P87)A;7,I.PH@("`@("`@('T*"B`@
M("`@("`@:68@*&=E='1Y<&4H)&YA;65S<&%C92D@/3T@)V%R<F%Y)RD@>PH@
M("`@("`@("`@("!F;W)E86-H("@D;F%M97-P86-E(&%S("1O<'1N86UE(#T^
M("1O<'0I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;<W1R
M=&]L;W=E<B@D;W!T;F%M92E=(#T@)&]P=#L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]?;W!T:6]N<ULG;F%M97-P86-E
M)UTI*2!["B`@("`@("`@("`@("`@("`D;F%M97-P86-E(#T@)'1H:7,M/E]?
M;W!T:6]N<ULG;F%M97-P86-E)UT["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D;F%M97-P86-E(#T@9F%L<V4["B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!792=L;"!P;&%C
M92`D<V]A<$%C=&EO;B!I;G1O(&]U<B!A<G)A>2!F;W(@=7-A9V4@:6X@=&AE
M"B`@("`@("`@("`@("\O('1R86YS<&]R="X*("`@("`@("`@("`@)'1H:7,M
M/E]?;W!T:6]N<ULG<V]A<&%C=&EO;B==(#T@)'-O87!!8W1I;VX["B`@("`@
M("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)VYA;65S<&%C92==(#T@)&YA;65S
M<&%C93L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^7U]E;F1P;VEN
M=%1Y<&4@/3T@)W=S9&PG*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5T4V-H
M96UA5F5R<VEO;B@D=&AI<RT^7W=S9&PM/GAS9"D["@H@("`@("`@("`@("`O
M+R!'970@<&]R="!N86UE+@H@("`@("`@("`@("!I9B`H(21T:&ES+3Y?<&]R
M=$YA;64I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&]R=$YA;64@/2`D
M=&AI<RT^7W=S9&PM/F=E=%!O<G1.86UE*"1M971H;V0I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1T:&ES+3Y?<&]R
M=$YA;64I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES
M95-O87!&875L="@D=&AI<RT^7W!O<G1.86UE*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@+R\@1V5T(&5N9'!O:6YT+@H@("`@("`@("`@("`D=&AI
M<RT^7V5N9'!O:6YT(#T@)'1H:7,M/E]W<V1L+3YG971%;F1P;VEN="@D=&AI
M<RT^7W!O<G1.86UE*3L*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)'1H:7,M/E]E;F1P;VEN="DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"1T:&ES+3Y?96YD<&]I;G0I.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O+R!'970@;W!E<F%T:6]N(&1A=&$N
M"B`@("`@("`@("`@("1O<$1A=&$@/2`D=&AI<RT^7W=S9&PM/F=E=$]P97)A
M=&EO;D1A=&$H)'1H:7,M/E]P;W)T3F%M92P@)&UE=&AO9"D["@H@("`@("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D;W!$871A*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)&]P1&%T82D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&YA;65S<&%C92`]("1O<$1A
M=&%;)VYA;65S<&%C92==.PH@("`@("`@("`@("`D=&AI<RT^7U]O<'1I;VYS
M6R=S='EL92==(#T@)&]P1&%T85LG<W1Y;&4G73L*("`@("`@("`@("`@)'1H
M:7,M/E]?;W!T:6]N<ULG=7-E)UT@/2`D;W!$871A6R=I;G!U="==6R=U<V4G
M73L*("`@("`@("`@("`@)'1H:7,M/E]?;W!T:6]N<ULG<V]A<&%C=&EO;B==
M(#T@)&]P1&%T85LG<V]A<$%C=&EO;B==.PH*("`@("`@("`@("`@+R\@4V5T
M(&EN<'5T('!A<F%M971E<G,N"B`@("`@("`@("`@(&EF("@D=&AI<RT^7U]O
M<'1I;VYS6R=I;G!U="==(#T]("=P87)S92<I('L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?7V]P=&EO;G-;)W!A<F%M971E<G,G72`]("1O<$1A=&%;)W!A
M<F%M971E<G,G73L*("`@("`@("`@("`@("`@("1N<&%R86US(#T@87)R87DH
M*3L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D;W!$871A6R=I;G!U="==
M6R=P87)T<R==*2`F)@H@("`@("`@("`@("`@("`@("`@(&-O=6YT*"1O<$1A
M=&%;)VEN<'5T)UU;)W!A<G1S)UTI*2!["B`@("`@("`@("`@("`@("`@("`@
M)&D@/2`P.PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1O<$1A=&%;
M)VEN<'5T)UU;)W!A<G1S)UT@87,@)&YA;64@/3X@)'!A<G0I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'AM;&YS(#T@)R<["B`@("`@("`@("`@("`@
M("`@("`@("`@("1A='1R<R`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@
M("`@("`@("\O($ES('1H92!N86UE(&$@8V]M<&QE>"!T>7!E/PH@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A<G1;)V5L96UE;G0G72DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1X;6QN<R`]("1T:&ES
M+3Y?=W-D;"T^;F%M97-P86-E<ULD<&%R=%LG;F%M97-P86-E)UU=.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'!A<G0@/2`D=&AI<RT^7W=S9&PM
M/F5L96UE;G1S6R1P87)T6R=N86UE<W!A8V4G75U;)'!A<G1;)W1Y<&4G75T[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F%M92`]("1P87)T6R=N
M86UE)UT["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;)&YA;65=*2!\?`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]W<V1L+3YG971$871A
M2&%N9&QE<B@D;F%M92P@)'!A<G1;)VYA;65S<&%C92==*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&YP87)A;7-;)&YA;65=(#TF("1P87)A
M;7-;)&YA;65=.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@5V4@;F]W(&9O<F-E(&%N
M(&%S<V]C:6%T:79E(&%R<F%Y(&9O<@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@<&%R86UE=&5R<R!I9B!U<VEN9R!74T1,+@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U
M;'0H(E1H92!N86UE9"!P87)A;65T97(@)&YA;64@:7,@;F]T(&EN('1H92!C
M86QL('!A<F%M971E<G,N(BD["B`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&=E='1Y<&4H)&YP87)A;7-;
M)&YA;65=*2`A/2`G;V)J96-T)R!\?`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(6ES7V$H)&YP87)A;7-;)&YA;65=+"`G4T]!4%]686QU92<I*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!4>7!E(&ES(&QI:V5L
M>2!A('%N86UE+"!S<&QI="!I="!A<&%R="P@86YD(&=E=`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@=&AE('1Y<&4@;F%M97-P86-E(&9R;VT@
M5U-$3"X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1Q;F%M92`])B!N
M97<@44YA;64H)'!A<G1;)W1Y<&4G72D["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H)'%N86UE+3YN<RD@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T>7!E7VYA;65S<&%C92`]("1T:&ES+3Y?=W-D;"T^
M;F%M97-P86-E<ULD<6YA;64M/FYS73L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS96EF("AI<W-E="@D<&%R=%LG;F%M97-P86-E)UTI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1Y<&5?;F%M97-P
M86-E(#T@)'1H:7,M/E]W<V1L+3YN86UE<W!A8V5S6R1P87)T6R=N86UE<W!A
M8V4G75T["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T>7!E7VYA;65S<&%C
M92`](&YU;&P["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<6YA;64M/FYA;65S<&%C92`]("1T
M>7!E7VYA;65S<&%C93L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M>7!E(#T@)'%N86UE+3YN86UE.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'!Q;F%M92`]("1N86UE.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"1X;6QN<RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P<6YA;64@/2`G>R<@+B`D>&UL;G,@+B`G?2<@+B`D;F%M93L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1N<&%R86US6R1N86UE72`])B!N97<@4T]!4%]686QU92@D
M<'%N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1Q;F%M92T^9G%N*"DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&YP87)A;7-;)&YA;65=+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1A='1R<RD["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!74T1,(&9I>'5P<R!T;R!T
M:&4@4T]!4"!V86QU92X*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1P87)A;7,@/28@)&YP87)A;7,["B`@("`@("`@("`@("`@("!U
M;G-E="@D;G!A<F%M<RD["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=&AI<RT^7W-E=%-C:&5M859E<G-I;VXH4T]!4%]8
M34Q?4T-(14U!7U9%4E-)3TXI.PH@("`@("`@('T*"B`@("`@("`@+R\@4V5R
M:6%L:7IE('1H92!M97-S86=E+@H@("`@("`@("1T:&ES+3Y?<V5C=&EO;C4@
M/2`H:7-S970H)'1H:7,M/E]?;W!T:6]N<ULG=7-E)UTI("8F"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R=U<V4G72`]
M/2`G;&ET97)A;"<I.PH*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?7V]P
M=&EO;G-;)W-T>6QE)UTI('Q\"B`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO
M;G-;)W-T>6QE)UT@/3T@)W)P8R<I('L*("`@("`@("`@("`@)'1H:7,M/E]?
M;W!T:6]N<ULG<W1Y;&4G72`]("=R<&,G.PH@("`@("`@("`@("`D=&AI<RT^
M9&]C<&%R86US(#T@=')U93L*("`@("`@("`@("`@)&UQ;F%M92`])B!N97<@
M44YA;64H)&UE=&AO9"P@)&YA;65S<&%C92D["B`@("`@("`@("`@("1M971H
M;V1686QU92`])B!N97<@4T]!4%]686QU92@D;7%N86UE+3YF<6XH*2P@)U-T
M<G5C="<L("1P87)A;7,I.PH@("`@("`@("`@("`D<V]A<%]M<V<@/28@)'1H
M:7,M/E]M86ME16YV96QO<&4H)&UE=&AO9%9A;'5E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FAE861E
M<G-/=70L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V5N8V]D:6YG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]?;W!T:6]N<RD[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"$D<&%R86US*2![
M"B`@("`@("`@("`@("`@("`D;7%N86UE(#TF(&YE=R!13F%M92@D;65T:&]D
M+"`D;F%M97-P86-E*3L*("`@("`@("`@("`@("`@("1M>6YU;&P@/2!N=6QL
M.PH@("`@("`@("`@("`@("`@)'!A<F%M<R`])B!N97<@4T]!4%]686QU92@D
M;7%N86UE+3YF<6XH*2P@)U-T<G5C="<L("1M>6YU;&PI.PH@("`@("`@("`@
M("!](&5L<V5I9B`H)'1H:7,M/E]?;W!T:6]N<ULG:6YP=70G72`]/2`G<&%R
M<V4G*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)'!A<F%M<RDI
M('L*("`@("`@("`@("`@("`@("`@("`D;G!A<F%M<R`](&%R<F%Y*"D["B`@
M("`@("`@("`@("`@("`@("`@)&ME>7,@/2!A<G)A>5]K97ES*"1P87)A;7,I
M.PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1K97ES(&%S("1K*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AG971T>7!E*"1P87)A;7-;
M)&M=*2`A/2`G;V)J96-T)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&YP87)A;7-;72`])B!N97<@4T]!4%]686QU92@D:RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P87)A;7-;)&M=*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1N<&%R86US6UT@/28@)'!A<F%M<ULD:UT["B`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@)'!A<F%M<R`])B`D;G!A<F%M<SL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7U]O<'1I;VYS6R=P
M87)A;65T97)S)UTI('L*("`@("`@("`@("`@("`@("`@("`D;7%N86UE(#TF
M(&YE=R!13F%M92@D;65T:&]D+"`D;F%M97-P86-E*3L*("`@("`@("`@("`@
M("`@("`@("`D<&%R86US(#TF(&YE=R!33T%07U9A;'5E*"1M<6YA;64M/F9Q
M;B@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)U-T<G5C="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<&%R86US*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D<V]A<%]M<V<@/28@)'1H:7,M
M/E]M86ME16YV96QO<&4H)'!A<F%M<RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YH96%D97)S3W5T+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]E;F-O9&EN9RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G,I.PH@("`@("`@
M('T*("`@("`@("!U;G-E="@D=&AI<RT^:&5A9&5R<T]U="D["@H@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1S;V%P7VUS9RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)'-O87!?;7-G*3L*("`@
M("`@("!]"@H@("`@("`@("\O($AA;F1L92!-24U%(&]R($1)344@96YC;V1I
M;F<N"B`@("`@("`@+R\@5$]$3SH@1$E-12!E;F-O9&EN9R!S:&]U;&0@;6]V
M92!T;R!T:&4@=')A;G-P;W)T+"!D;R!I="!H97)E(&9O<@H@("`@("`@("\O
M(&YO=R!A;F0@9F]R(&5A<V4@;V8@9V5T=&EN9R!I="!D;VYE+@H@("`@("`@
M(&EF("AC;W5N="@D=&AI<RT^7U]A='1A8VAM96YT<RDI('L*("`@("`@("`@
M("`@:68@*"AI<W-E="@D=&AI<RT^7U]O<'1I;VYS6R=A='1A8VAM96YT<R==
M*2`F)@H@("`@("`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)V%T=&%C
M:&UE;G1S)UT@/3T@)TUI;64G*2!\?`H@("`@("`@("`@("`@("`@:7-S970H
M)'1H:7,M/E]?;W!T:6]N<ULG36EM92==*2D@>PH@("`@("`@("`@("`@("`@
M)'-O87!?;7-G(#TF("1T:&ES+3Y?;6%K94UI;65-97-S86=E*"1S;V%P7VUS
M9RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V5N8V]D:6YG*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("\O(&1E9F%U;'0@:7,@9&EM90H@("`@
M("`@("`@("`@("`@)'-O87!?;7-G(#TF("1T:&ES+3Y?;6%K941)345-97-S
M86=E*"1S;V%P7VUS9RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V5N8V]D:6YG*3L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)VAE861E<G,G75LG0V]N
M=&5N="U4>7!E)UT@/2`G87!P;&EC871I;VXO9&EM92<["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'-O87!?;7-G*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U
M;'0H)'-O87!?;7-G*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@+R\@26YS=&%N=&EA=&4@8VQI96YT+@H@("`@("`@(&EF("AI<U]A<G)A
M>2@D<V]A<%]M<V<I*2!["B`@("`@("`@("`@("1S;V%P7V1A=&$@/28@)'-O
M87!?;7-G6R=B;V1Y)UT["B`@("`@("`@("`@(&EF("AC;W5N="@D<V]A<%]M
M<V=;)VAE861E<G,G72DI('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7U]O<'1I;VYS6R=H96%D97)S)UTI*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]?;W!T:6]N<ULG:&5A9&5R<R==(#T@87)R87E?;65R
M9V4H)'1H:7,M/E]?;W!T:6]N<ULG:&5A9&5R<R==+"`D<V]A<%]M<V=;)VAE
M861E<G,G72D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)VAE861E<G,G72`]("1S;V%P
M7VUS9ULG:&5A9&5R<R==.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-O87!?9&%T82`]
M)B`D<V]A<%]M<V<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'-O87!?
M9&%T83L*("`@('T*"B`@("!F=6YC=&EO;B`F7U]P87)S92@F)')E<W!O;G-E
M+"`D96YC;V1I;F<L("8D871T86-H;65N=',I"B`@("!["B`@("`@("`@+R\@
M4&%R<V4@=&AE(')E<W!O;G-E+@H@("`@("`@("1R97-P;VYS92`])B!N97<@
M4T]!4%]087)S97(H)')E<W!O;G-E+"`D96YC;V1I;F<L("1A='1A8VAM96YT
M<RD["B`@("`@("`@:68@*"1R97-P;VYS92T^9F%U;'0I('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)')E<W!O;G-E+3YF
M875L="D["B`@("`@("`@?0H*("`@("`@("`O+R!2971U<FX@87)R87D@;V8@
M<&%R86UE=&5R<RX*("`@("`@("`D<F5T=7)N(#TF("1R97-P;VYS92T^9V5T
M4F5S<&]N<V4H*3L*("`@("`@("`D:&5A9&5R<R`])B`D<F5S<&]N<V4M/F=E
M=$AE861E<G,H*3L*("`@("`@("!I9B`H)&AE861E<G,I('L*("`@("`@("`@
M("`@)'1H:7,M/FAE861E<G-);B`])B`D=&AI<RT^7U]D96-O9&5297-P;VYS
M92@D:&5A9&5R<RP@9F%L<V4I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?7V1E8V]D95)E<W!O;G-E*"1R971U<FXI.PH@("`@?0H*("`@
M(&9U;F-T:6]N("9?7V1E8V]D95)E<W!O;G-E*"8D<F5S<&]N<V4L("1S:&EF
M="`]('1R=64I"B`@("!["B`@("`@("`@:68@*"$D<F5S<&]N<V4I('L*("`@
M("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H*("`@("`@("`O+R!#
M:&5C:R!F;W(@=F%L:60@<F5S<&]N<V4N"B`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)')E<W!O;G-E*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]R86ES95-O87!&875L="@D<F5S<&]N<V4I.PH@("`@("`@('T@96QS96EF
M("@A:7-?82@D<F5S<&]N<V4L("=S;V%P7W9A;'5E)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(D1I9&XG="!G970@
M4T]!4%]686QU92!O8FIE8W0@8F%C:R!F<F]M(&-L:65N="(I.PH@("`@("`@
M('T*"B`@("`@("`@+R\@1&5C;V1E('1O(&YA=&EV92!P:'`@9&%T871Y<&4N
M"B`@("`@("`@)')E='5R;D%R<F%Y(#TF("1T:&ES+3Y?9&5C;V1E*"1R97-P
M;VYS92D["@H@("`@("`@("\O($9A=6QT/PH@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1R971U<FY!<G)A>2DI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<F%I<V53;V%P1F%U;'0H)')E='5R;D%R<F%Y*3L*("`@("`@("!]
M"@H@("`@("`@(&EF("AI<U]O8FIE8W0H)')E='5R;D%R<F%Y*2`F)@H@("`@
M("`@("`@("!S=')C87-E8VUP*&=E=%]C;&%S<R@D<F5T=7)N07)R87DI+"`G
M<W1D0VQA<W,G*2`]/2`P*2!["B`@("`@("`@("`@("1R971U<FY!<G)A>2`]
M(&=E=%]O8FIE8W1?=F%R<R@D<F5T=7)N07)R87DI.PH@("`@("`@('T*("`@
M("`@("!I9B`H:7-?87)R87DH)')E='5R;D%R<F%Y*2D@>PH@("`@("`@("`@
M("!I9B`H:7-S970H)')E='5R;D%R<F%Y6R=F875L=&-O9&4G72D@?'P*("`@
M("`@("`@("`@("`@(&ES<V5T*"1R971U<FY!<G)A>5LG4T]!4"U%3E8Z9F%U
M;'1C;V1E)UTI*2!["B`@("`@("`@("`@("`@("`D9F%U;'1C;V1E(#T@)&9A
M=6QT<W1R:6YG(#T@)&9A=6QT9&5T86EL(#T@)&9A=6QT86-T;W(@/2`G)SL*
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R971U<FY!<G)A>2!A<R`D:R`]
M/B`D=BD@>PH@("`@("`@("`@("`@("`@("`@(&EF("AS=')I<W1R*"1K+"`G
M9F%U;'1C;V1E)RDI("1F875L=&-O9&4@/2`D=CL*("`@("`@("`@("`@("`@
M("`@("!I9B`H<W1R:7-T<B@D:RP@)V9A=6QT<W1R:6YG)RDI("1F875L='-T
M<FEN9R`]("1V.PH@("`@("`@("`@("`@("`@("`@(&EF("AS=')I<W1R*"1K
M+"`G9&5T86EL)RDI("1F875L=&1E=&%I;"`]("1V.PH@("`@("`@("`@("`@
M("`@("`@(&EF("AS=')I<W1R*"1K+"`G9F%U;'1A8W1O<B<I*2`D9F%U;'1A
M8W1O<B`]("1V.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)&9A=6QT<W1R:6YG+"`D
M9F%U;'1D971A:6PL("1F875L=&%C=&]R+"`D9F%U;'1C;V1E*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`O+R!2971U<FX@87)R87D@;V8@<F5T=7)N
M('9A;'5E<RX*("`@("`@("`@("`@:68@*"1S:&EF="`F)B!C;W5N="@D<F5T
M=7)N07)R87DI(#T](#$I('L*("`@("`@("`@("`@("`@(')E='5R;B!A<G)A
M>5]S:&EF="@D<F5T=7)N07)R87DI.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(')E='5R;B`D<F5T=7)N07)R87D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D<F5T=7)N07)R87D["B`@("!]"@H@("`@9G5N8W1I;VX@7U]G971?
M=VER92@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?7V]P=&EO;G-;)W1R
M86-E)UT@/B`P("8F"B`@("`@("`@("`@("@D=&AI<RT^7U]L87-T7W)E<75E
M<W0@?'P@)'1H:7,M/E]?;&%S=%]R97-P;VYS92DI('L*("`@("`@("`@("`@
M<F5T=7)N(")/551'3TE.1SI<;EQN(B`N"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7U]L87-T7W)E<75E<W0@+@H@("`@("`@("`@("`@("`@(EQN7&Y)3D-/
M34E.1UQN7&XB("X*("`@("`@("`@("`@("`@('!R96=?<F5P;&%C92@B+SX\
M+R(L(CY<<EQN/"(L("1T:&ES+3Y?7VQA<W1?<F5S<&]N<V4I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-/05`O1&ES8V\N<&AP````````
M````````````````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,V,30T`#$P-3$U
M-#,S-S,W`#`R,3$S,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@5&AI<R!F:6QE(&-O;G1A:6YS('1H
M92!C;V1E(&9O<B!T:&4@1$E30T\@<V5R=F5R+"!P<F]V:61I;F<@1$E33R!A
M;F0@5U-$3`H@*B!S97)V:6-E<RX*("H*("H@4$A0('9E<G-I;VYS(#0@86YD
M(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T
M('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L"B`J('1H870@
M:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%
M3E-%+"!A;F0@:7,@879A:6QA8FQE(&%T"B`J('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N
M='AT+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE
M(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I=`H@*B!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E
M('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X*("H@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!796(@4V5R=FEC
M97,*("H@0'!A8VMA9V4@("`@4T]!4`H@*B!`875T:&]R("`@("!$;6ET<FD@
M5FEN;V=R861O=B`\9&EM:71R:4!V:6YO9W)A9&]V+F1E/@H@*B!`875T:&]R
M("`@("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U
M=&AO<B`@("`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0&-O
M<'ER:6=H="`@,C`P,RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@
M("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0@(%!(4"!,
M:6-E;G-E(#(N,#(*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+U-/05`*("HO"@IR97%U:7)E7V]N8V4@)U-/05`O0F%S92YP
M:'`G.PH*8VQA<W,@4T]!4%]$25-#3U]397)V97(@97AT96YD<R!33T%07T)A
M<V5?3V)J96-T('L*"B`@("!V87(@)&YA;65S<&%C97,@("`@(#T@87)R87DH
M4T-(14U!7U=31$P@/3X@)W=S9&PG+"!30TA%34%?4T]!4"`]/B`G<V]A<"<I
M.PH@("`@=F%R("1I;7!O<G1?;G,@("`@("`](&%R<F%Y*"D["B`@("!V87(@
M)'=S9&P@("`@("`@("`@(#T@)R<["B`@("!V87(@)&1I<V-O("`@("`@("`@
M(#T@)R<["B`@("!V87(@)%]W<V1L("`@("`@("`@(#T@87)R87DH*3L*("`@
M('9A<B`D7V1I<V-O("`@("`@("`@/2!A<G)A>2@I.PH@("`@=F%R("1?<V5R
M=FEC95]N86UE("`]("<G.PH@("`@=F%R("1?<V5R=FEC95]N<R`@("`]("<G
M.PH@("`@=F%R("1?<V5R=FEC95]D97-C("`]("<G.PH@("`@=F%R("1?<&]R
M=&YA;64@("`@("`]("<G.PH@("`@=F%R("1?8FEN9&EN9VYA;64@("`]("<G
M.PH@("`@=F%R("1S;V%P7W-E<G9E<B`@("`]($Y53$P["@H*("`@(&9U;F-T
M:6]N(%-/05!?1$E30T]?4V5R=F5R*"1S;V%P7W-E<G9E<BP@)'-E<G9I8V5?
M;F%M92P@)'-E<G9I8V5?9&5S8R`]("<G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&EM<&]R=%]N<R`](&YU;&PI"B`@("!["B`@("`@("`@
M<&%R96YT.CI33T%07T)A<V5?3V)J96-T*"=397)V97(G*3L*"B`@("`@("`@
M:68@*"`A:7-?;V)J96-T*"1S;V%P7W-E<G9E<BD*("`@("`@("`@("`@?'P@
M(6=E=%]C;&%S<R@D<V]A<%]S97)V97(I(#T]("=S;V%P7W-E<G9E<B<I(')E
M='5R;CL*"B`@("`@("`@)'1H:7,M/E]S97)V:6-E7VYA;64@/2`D<V5R=FEC
M95]N86UE.PH@("`@("`@("1T:&ES+3Y?<V5R=FEC95]N<R`](")U<FXZ)'-E
M<G9I8V5?;F%M92(["B`@("`@("`@)'1H:7,M/E]S97)V:6-E7V1E<V,@/2`D
M<V5R=FEC95]D97-C.PH@("`@("`@("1T:&ES+3YI;7!O<G1?;G,@/2!I<W-E
M="@D:6UP;W)T7VYS*2`_("1I;7!O<G1?;G,@.B`D=&AI<RT^:6UP;W)T7VYS
M.PH@("`@("`@("1T:&ES+3YS;V%P7W-E<G9E<B`]("1S;V%P7W-E<G9E<CL*
M("`@("`@("`D=&AI<RT^:&]S="`](&ES<V5T*"1?4T525D526R=(5%107TA/
M4U0G72D@/R`D7U-%4E9%4ELG2%144%](3U-4)UT@.B`G;&]C86QH;W-T)SL*
M("`@('T*"B`@("!F=6YC=&EO;B!G971$25-#3R@I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]G96YE<F%T95]$25-#3R@I.PH@("`@("`@(')E='5R;B`D=&AI
M<RT^9&ES8V\["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T5U-$3"@I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]G96YE<F%T95]74T1,*"D["B`@("`@("`@<F5T
M=7)N("1T:&ES+3YW<V1L.PH@("`@?0H*("`@(&9U;F-T:6]N(%]G96YE<F%T
M95]$25-#3R@I"B`@("!["B`@("`@("`@+R\@1$E30T\*("`@("`@("`D=&AI
M<RT^7V1I<V-O6R=D:7-C;SID:7-C;W9E<GDG75LG871T<B==6R=X;6QN<SID
M:7-C;R==(#T@4T-(14U!7T1)4T-/.PH@("`@("`@("1T:&ES+3Y?9&ES8V];
M)V1I<V-O.F1I<V-O=F5R>2==6R=A='1R)UU;)WAM;&YS.G-C;"==(#T@4T-(
M14U!7T1)4T-/7U-#3#L*("`@("`@("`D=&AI<RT^7V1I<V-O6R=D:7-C;SID
M:7-C;W9E<GDG75LG<V-L.F-O;G1R86-T4F5F)UU;)V%T='(G75LG<F5F)UT@
M/0H@("`@("`@("`@("`H87)R87E?:V5Y7V5X:7-T<R@G2%144%,G+"`D7U-%
M4E9%4BD@)B8@)%]315)615);)TA45%!3)UT@/3T@)V]N)RD*("`@("`@("`@
M("`@/R`G:'1T<',Z+R\G("X@)'1H:7,M/FAO<W0@+B`D7U-%4E9%4ELG4$A0
M7U-%3$8G72`N("<_=W-D;"<*("`@("`@("`@("`@.B`G:'1T<#HO+R<@("X@
M)'1H:7,M/FAO<W0@+B`D7U-%4E9%4ELG4$A07U-%3$8G72`N("<_=W-D;"<[
M"@H@("`@("`@("\O(&=E;F5R871E(&1I<V-O('AM;`H@("`@("`@("1T:&ES
M+3Y?9V5N97)A=&5?1$E30T]?6$U,*"1T:&ES+3Y?9&ES8V\I.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]G96YE<F%T95]74T1,*"D*("`@('L*("`@("`@("`O
M+R!74T1,"B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3YS;V%P7W-E<G9E
M<BT^7VYA;65S<&%C97,I*2!["B`@("`@("`@("`@("\O(&YE960@=&\@9V5T
M.B!T>7!E;G,L('AS9"`F(%-/05`M14Y#"B`@("`@("`@("`@("1F;&EP<&5D
M(#T@87)R87E?9FQI<"@D=&AI<RT^<V]A<%]S97)V97(M/E]N86UE<W!A8V5S
M*3L*("`@("`@("`@("`@)'1H:7,M/FYA;65S<&%C97-;)'1H:7,M/E]S97)V
M:6-E7VYS72`]("=T;G,G.PH@("`@("`@("`@("`D=&AI<RT^;F%M97-P86-E
M<ULD9FQI<'!E9%LG>'-D)UU=(#T@)WAS9"<["B`@("`@("`@("`@("1T:&ES
M+3YN86UE<W!A8V5S6R1F;&EP<&5D6R=33T%0+45.0R==72`]("=33T%0+45.
M0R<["B`@("`@("`@?0H*("`@("`@("`O+R!$149)3DE424].4PH@("`@("`@
M("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G75LG871T<B==6R=N86UE)UT@
M/2`D=&AI<RT^7W-E<G9I8V5?;F%M93L*("`@("`@("`D=&AI<RT^7W=S9&Q;
M)V1E9FEN:71I;VYS)UU;)V%T='(G75LG=&%R9V5T3F%M97-P86-E)UT@/2`D
M=&AI<RT^7W-E<G9I8V5?;G,["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/FYA
M;65S<&%C97,@87,@)&YS(#T^("1P<F5F:7@I('L*("`@("`@("`@("`@)'1H
M:7,M/E]W<V1L6R=D969I;FET:6]N<R==6R=A='1R)UU;)WAM;&YS.B<@+B`D
M<')E9FEX72`]("1N<SL*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]W<V1L
M6R=D969I;FET:6]N<R==6R=A='1R)UU;)WAM;&YS)UT@/2!30TA%34%?5U-$
M3#L*"B`@("`@("`@+R\@26UP;W)T(&YA;65S<&%C97,N(%-E96US('1O(&YO
M="!W;W)K('EE=#H@=W-D;"YE>&4@9F]M("Y.150@8V%N)W0*("`@("`@("`O
M+R!H86YD;&4@:6UP;W)T960@8V]M<&QE=&4@=W-D;"UD969I;FET:6]N<RX*
M("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/FEM<&]R=%]N<RDI('L*("`@("`@
M("`@("`@)&D@/2`P.PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^:6UP
M;W)T7VYS(&%S("1?;G,@/3X@)%]L;V-A=&EO;BD@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]W<V1L6R=D969I;FET:6]N<R==6R=I;7!O<G0G75LD:5U;
M)V%T='(G75LG;&]C871I;VXG72`]("1?;&]C871I;VX["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W=S9&Q;)V1E9FEN:71I;VYS)UU;)VEM<&]R="==6R1I
M75LG871T<B==6R=N86UE<W!A8V4G72`]("1?;G,["B`@("`@("`@("`@("`@
M("`D:2LK.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1T:&ES
M+3Y?=W-D;%LG9&5F:6YI=&EO;G,G75LG='EP97,G75LG871T<B==6R=X;6QN
M<R==/2=H='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]W<V1L+R<["B`@("`@
M("`@)'1H:7,M/E]W<V1L6R=D969I;FET:6]N<R==6R=T>7!E<R==6R=S8VAE
M;6$G73UA<G)A>2@I.PH*("`@("`@("`O+R!0;&%C96AO;&1E<B!F;W(@;65S
M<V%G97,*("`@("`@("`D=&AI<RT^7W=S9&Q;)V1E9FEN:71I;VYS)UU;)VUE
M<W-A9V4G72`](&%R<F%Y*"D["@H@("`@("`@("\O(%!/4E1465!%+4Y!344*
M("`@("`@("`D=&AI<RT^7W!O<G1N86UE(#T@)'1H:7,M/E]S97)V:6-E7VYA
M;64@+B`G4&]R="<["B`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I;FET:6]N
M<R==6R=P;W)T5'EP92==6R=A='1R)UU;)VYA;64G72`]("1T:&ES+3Y?<&]R
M=&YA;64["@H@("`@("`@("\O($))3D1)3D<M3D%-10H@("`@("`@("1T:&ES
M+3Y?8FEN9&EN9VYA;64@/2`D=&AI<RT^7W-E<G9I8V5?;F%M92`N("=":6YD
M:6YG)SL*("`@("`@("`D=&AI<RT^7W=S9&Q;)V1E9FEN:71I;VYS)UU;)V)I
M;F1I;F<G75LG871T<B==6R=N86UE)UT@/2`D=&AI<RT^7V)I;F1I;F=N86UE
M.PH@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G75LG8FEN9&EN
M9R==6R=A='1R)UU;)W1Y<&4G72`]("=T;G,Z)R`N("1T:&ES+3Y?<&]R=&YA
M;64["B`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I;FET:6]N<R==6R=B:6YD
M:6YG)UU;)W-O87`Z8FEN9&EN9R==6R=A='1R)UU;)W-T>6QE)UT@/2`G<G!C
M)SL*("`@("`@("`D=&AI<RT^7W=S9&Q;)V1E9FEN:71I;VYS)UU;)V)I;F1I
M;F<G75LG<V]A<#IB:6YD:6YG)UU;)V%T='(G75LG=')A;G-P;W)T)UT@/2!3
M0TA%34%?4T]!4%](5%10.PH*("`@("`@("`O+R!315)624-%"B`@("`@("`@
M)'1H:7,M/E]W<V1L6R=D969I;FET:6]N<R==6R=S97)V:6-E)UU;)V%T='(G
M75LG;F%M92==(#T@)'1H:7,M/E]S97)V:6-E7VYA;64@+B`G4V5R=FEC92<[
M"B`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I;FET:6]N<R==6R=S97)V:6-E
M)UU;)V1O8W5M96YT871I;VXG75LG871T<B==(#T@)R<["B`@("`@("`@)'1H
M:7,M/E]W<V1L6R=D969I;FET:6]N<R==6R=S97)V:6-E)UU;)V1O8W5M96YT
M871I;VXG72`](&AT;6QE;G1I=&EE<R@D=&AI<RT^7W-E<G9I8V5?9&5S8RD[
M"B`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I;FET:6]N<R==6R=S97)V:6-E
M)UU;)W!O<G0G75LG871T<B==6R=N86UE)UT@/2`D=&AI<RT^7W!O<G1N86UE
M.PH@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G75LG<V5R=FEC
M92==6R=P;W)T)UU;)V%T='(G75LG8FEN9&EN9R==(#T@)W1N<SHG("X@)'1H
M:7,M/E]B:6YD:6YG;F%M93L*("`@("`@("`D=&AI<RT^7W=S9&Q;)V1E9FEN
M:71I;VYS)UU;)W-E<G9I8V4G75LG<&]R="==6R=S;V%P.F%D9')E<W,G75LG
M871T<B==6R=L;V-A=&EO;B==(#T*("`@("`@("`@("`@*&%R<F%Y7VME>5]E
M>&ES=',H)TA45%!3)RP@)%]315)615(I("8F("1?4T525D526R=(5%104R==
M(#T]("=O;B<I"B`@("`@("`@("`@(#\@)VAT='!S.B\O)R`N("1T:&ES+3YH
M;W-T("X@)%]315)615);)U!(4%]314Q&)UT*("`@("`@("`@("`@.B`G:'1T
M<#HO+R<@("X@)'1H:7,M/FAO<W0@+B`D7U-%4E9%4ELG4$A07U-%3$8G73L*
M"B`@("`@("`@+R\*("`@("`@("`D9&ES<&%T8VA?:V5Y<R`](&%R<F%Y7VME
M>7,H)'1H:7,M/G-O87!?<V5R=F5R+3YD:7-P871C:%]O8FIE8W1S*3L*("`@
M("`@("`D9&,@/2!C;W5N="@D9&ES<&%T8VA?:V5Y<RD["B`@("`@("`@9F]R
M("@D9&D@/2`P.R`D9&D@/"`D9&,[("1D:2LK*2!["B`@("`@("`@("`@("1N
M86UE<W!A8V4@/2`D9&ES<&%T8VA?:V5Y<ULD9&E=.PH@("`@("`@("`@("`D
M;F%M97-P86-E7V]B:F5C=',@/28@)'1H:7,M/G-O87!?<V5R=F5R+3YD:7-P
M871C:%]O8FIE8W1S6R1N86UE<W!A8V5=.PH@("`@("`@("`@("`D;V,@/2!C
M;W5N="@D;F%M97-P86-E7V]B:F5C=',I.PH@("`@("`@("`@("!F;W(@*"1O
M:2`](#`[("1O:2`\("1O8SL@)&]I*RLI('L*("`@("`@("`@("`@("`@("1O
M8FIE8W0@/2`D;F%M97-P86-E7V]B:F5C='-;)&]I73L*("`@("`@("`@("`@
M("`@("\O('1Y<&5S(&1E9FEN:71I;VYS"B`@("`@("`@("`@("`@("`D=&AI
M<RT^861D4V-H96UA1G)O;4UA<"@D;V)J96-T+3Y?7W1Y<&5D968I.PH@("`@
M("`@("`@("`@("`@+R\@34534T%'15,*("`@("`@("`@("`@("`@("1T:&ES
M+3YA9&1-971H;V1S1G)O;4UA<"@D;V)J96-T+3Y?7V1I<W!A=&-H7VUA<"P@
M)&YA;65S<&%C92P@9V5T7V-L87-S*"1O8FIE8W0I*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)'-E<G9E<BT^9&ES<&%T
M8VA?;6%P*2D@>PH@("`@("`@("`@("`D=&AI<RT^861D365T:&]D<T9R;VU-
M87`H)'-E<G9E<BT^9&ES<&%T8VA?;6%P+"`D;F%M97-P86-E*3L*("`@("`@
M("!]"@H@("`@("`@("\O(&=E;F5R871E('=S9&P*("`@("`@("`D=&AI<RT^
M7V=E;F5R871E7U=31$Q?6$U,*"D["B`@("!]"@H@("`@9G5N8W1I;VX@)E]G
M97138VAE;6$H)&YA;65S<&%C92D*("`@('L*("`@("`@("`O+R!30TA%34$*
M("`@("`@("`D8R`](&-O=6YT*"1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G
M75LG='EP97,G75LG<V-H96UA)UTI.PH@("`@("`@(&9O<B@D:2`](#`[("1I
M(#P@)&,[("1I*RLI('L*("`@("`@("`@("`@:68@*"1T:&ES+3Y?=W-D;%LG
M9&5F:6YI=&EO;G,G75LG='EP97,G75LG<V-H96UA)UU;)&E=6R=A='1R)UU;
M)W1A<F=E=$YA;65S<&%C92==(#T]("1N86UE<W!A8V4I('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7W=S9&Q;)V1E9FEN:71I;VYS)UU;)W1Y
M<&5S)UU;)W-C:&5M82==6R1I73L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+R\@9&]N)W0@:&%V92!T:&ES(&YA;65S<&%C90H@("`@("`@
M("1S8VAE;6$@/2!A<G)A>2@I.PH@("`@("`@("1S8VAE;6%;)V%T='(G72`]
M(&%R<F%Y*"D["B`@("`@("`@)'-C:&5M85LG8V]M<&QE>%1Y<&4G72`](&%R
M<F%Y*"D["B`@("`@("`@)'-C:&5M85LG871T<B==6R=X;6QN<R==(#T@87)R
M87E?<V5A<F-H*"=X<V0G+"1T:&ES+3YN86UE<W!A8V5S*3L*("`@("`@("`D
M<V-H96UA6R=A='1R)UU;)W1A<F=E=$YA;65S<&%C92==(#T@)&YA;65S<&%C
M93L*("`@("`@("`D=&AI<RT^7W=S9&Q;)V1E9FEN:71I;VYS)UU;)W1Y<&5S
M)UU;)W-C:&5M82==6UT@/28@)'-C:&5M83L*"B`@("`@("`@<F5T=7)N("1S
M8VAE;6$["B`@("!]"@H@("`@9G5N8W1I;VX@861D4V-H96UA1G)O;4UA<"@F
M)&UA<"D*("`@('L*("`@("`@("!I9B`H(21M87`I('L*("`@("`@("`@("`@
M<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)&UA<"!A<R`D
M7W1Y<&5?;F%M92`]/B`D7W1Y<&5?9&5F*2!["B`@("`@("`@("`@(&QI<W0H
M)'1Y<&5N<RPD='EP92D@/2`D=&AI<RT^7V=E=%1Y<&5.<R@D7W1Y<&5?;F%M
M92D["B`@("`@("`@("`@(&EF("@D='EP96YS(#T]("=X<V0G*2!["B`@("`@
M("`@("`@("`@("`O+R!C86YN;W0@861D('1O('AS9"P@;&5T<R!U<V4@;65T
M:&]D7VYA;65S<&%C90H@("`@("`@("`@("`@("`@)'1Y<&5N<R`]("=T;G,G
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1S8VAE;6$@/28@)'1H:7,M
M/E]G97138VAE;6$H87)R87E?<V5A<F-H*"1T>7!E;G,L("1T:&ES+3YN86UE
M<W!A8V5S*2D["B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]I9D-O;7!L97A4
M>7!E17AI<W1S*"1S8VAE;6%;)V-O;7!L97A4>7!E)UTL("1T>7!E*2D@>PH@
M("`@("`@("`@("`@("`@)&-T>7!E(#TF("1S8VAE;6%;)V-O;7!L97A4>7!E
M)UU;73L*("`@("`@("`@("`@("`@("1C='EP95LG871T<B==6R=N86UE)UT@
M/2`D='EP93L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1?='EP95]D968@
M87,@)%]V87)N86UE(#T^("1?=F%R='EP92D@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("@A:7-?:6YT*"1?=F%R;F%M92DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@;&ES="@D7W9A<G1Y<&5N<RPD7W9A<G1Y<&4I(#T@)'1H:7,M
M/E]G9714>7!E3G,H)%]V87)T>7!E*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&-T>7!E6R=A;&PG75LG871T<B==(#T@)R<["B`@("`@("`@("`@("`@
M("`@("`@("`@("1E;"`])B`D8W1Y<&5;)V%L;"==6R=E;&5M96YT)UU;73L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&5L6R=A='1R)UU;)VYA;64G72`]
M("1?=F%R;F%M93L*("`@("`@("`@("`@("`@("`@("`@("`@)&5L6R=A='1R
M)UU;)W1Y<&4G72`]("1?=F%R='EP96YS("X@)SHG("X@)%]V87)T>7!E.PH@
M("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1C='EP95LG8V]M<&QE>$-O;G1E;G0G75LG871T<B==(#T@)R<[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1C='EP95LG8V]M<&QE>$-O;G1E
M;G0G75LG<F5S=')I8W1I;VXG75LG871T<B==6R=B87-E)UT@/2`G4T]!4"U%
M3D,Z07)R87DG.PH@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M7W9A<G1Y<&4@87,@)&%R<F%Y7W9A<B`]/B`D87)R87E?='EP92D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@;&ES="@D7W9A<G1Y<&5N<RP@)%]V
M87)T>7!E*2`]("1T:&ES+3Y?9V5T5'EP94YS*"1A<G)A>5]T>7!E*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1C='EP95LG8V]M<&QE>$-O;G1E
M;G0G75LG<F5S=')I8W1I;VXG75LG871T<FEB=71E)UU;)V%T='(G75LG<F5F
M)UT@/2`G4T]!4"U%3D,Z87)R87E4>7!E)SL*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1C='EP95LG8V]M<&QE>$-O;G1E;G0G75LG<F5S=')I8W1I
M;VXG75LG871T<FEB=71E)UU;)V%T='(G75LG=W-D;#IA<G)A>51Y<&4G72`]
M("1?=F%R='EP96YS("X@)SHG("X@)%]V87)T>7!E("X@)UM=)SL*("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M"B`@("!F=6YC=&EO;B!A9&1-971H;V1S1G)O;4UA<"@F)&UA<"P@)&YA;65S
M<&%C92P@)&-L87-S;F%M92`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"$D
M;6%P*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@
M(&9O<F5A8V@@*"1M87`@87,@)&UE=&AO9%]N86UE(#T^("1M971H;V1?='EP
M97,I('L*("`@("`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)VYA;65S
M<&%C92<L("1M971H;V1?='EP97,I*2!["B`@("`@("`@("`@("`@("`D;65T
M:&]D7VYA;65S<&%C92`]("1M971H;V1?='EP97-;)VYA;65S<&%C92==.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&UE=&AO9%]N
M86UE<W!A8V4@/2`D;F%M97-P86-E.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("\O($E.4%54"B`@("`@("`@("`@(&EF("AI<W-E="@D;65T:&]D7W1Y
M<&5S6R=I;B==*2`F)B!I<U]A<G)A>2@D;65T:&]D7W1Y<&5S6R=I;B==*2D@
M>PH@("`@("`@("`@("`@("`@)&EN<'5T7VUE<W-A9V4@/28@)'1H:7,M/E]W
M<V1L6R=D969I;FET:6]N<R==6R=M97-S86=E)UU;73L*("`@("`@("`@("`@
M("`@("1I;G!U=%]M97-S86=E6R=A='1R)UU;)VYA;64G72`]("1M971H;V1?
M;F%M92`N("=297%U97-T)SL*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1M
M971H;V1?='EP97-;)VEN)UT@87,@)&YA;64@/3X@)'1Y<&4I('L*("`@("`@
M("`@("`@("`@("`@("!L:7-T*"1T>7!E;G,L("1T>7!E*2`]("1T:&ES+3Y?
M9V5T5'EP94YS*"1T>7!E*3L*("`@("`@("`@("`@("`@("`@("`D<&%R="`]
M)B`D:6YP=71?;65S<V%G95LG<&%R="==6UT["B`@("`@("`@("`@("`@("`@
M("`@)'!A<G1;)V%T='(G75LG;F%M92==(#T@)&YA;64["B`@("`@("`@("`@
M("`@("`@("`@)'!A<G1;)V%T='(G75LG='EP92==(#T@)'1Y<&5N<R`N("<Z
M)R`N("1T>7!E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`O+R!/5510550*("`@("`@("`@("`@:68@*&ES<V5T*"1M
M971H;V1?='EP97-;)V]U="==*2`F)B!I<U]A<G)A>2@D;65T:&]D7W1Y<&5S
M6R=O=70G72DI('L*("`@("`@("`@("`@("`@("1O=71P=71?;65S<V%G92`]
M)B`D=&AI<RT^7W=S9&Q;)V1E9FEN:71I;VYS)UU;)VUE<W-A9V4G75M=.PH@
M("`@("`@("`@("`@("`@)&]U='!U=%]M97-S86=E6R=A='1R)UU;)VYA;64G
M72`]("1M971H;V1?;F%M92`N("=297-P;VYS92<["B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D;65T:&]D7W1Y<&5S6R=O=70G72!A<R`D;F%M92`]/B`D
M='EP92D@>PH@("`@("`@("`@("`@("`@("`@(&QI<W0H)'1Y<&5N<RP@)'1Y
M<&4I(#T@)'1H:7,M/E]G9714>7!E3G,H)'1Y<&4I.PH@("`@("`@("`@("`@
M("`@("`@("1P87)T(#TF("1O=71P=71?;65S<V%G95LG<&%R="==6UT["B`@
M("`@("`@("`@("`@("`@("`@)'!A<G1;)V%T='(G75LG;F%M92==(#T@)&YA
M;64["B`@("`@("`@("`@("`@("`@("`@)'!A<G1;)V%T='(G75LG='EP92==
M(#T@)'1Y<&5N<R`N("<Z)R`N("1T>7!E.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!03U)45%E015,*("`@("`@
M("`@("`@)&]P97)A=&EO;B`])B`D=&AI<RT^7W=S9&Q;)V1E9FEN:71I;VYS
M)UU;)W!O<G14>7!E)UU;)V]P97)A=&EO;B==6UT["B`@("`@("`@("`@("1O
M<&5R871I;VY;)V%T='(G75LG;F%M92==(#T@)&UE=&AO9%]N86UE.PH*("`@
M("`@("`@("`@+R\@24Y0550*("`@("`@("`@("`@)&]P97)A=&EO;ELG:6YP
M=70G75LG871T<B==6R=M97-S86=E)UT@/2`G=&YS.B<*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("X@)&EN<'5T7VUE<W-A9V5;)V%T='(G75LG;F%M
M92==.PH*("`@("`@("`@("`@+R\@3U544%54"B`@("`@("`@("`@("1O<&5R
M871I;VY;)V]U='!U="==6R=A='1R)UU;)VUE<W-A9V4G72`]("=T;G,Z)PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D;W5T<'5T7VUE<W-A9V5;
M)V%T='(G75LG;F%M92==.PH*("`@("`@("`@("`@+R\@0DE.1$E.1PH@("`@
M("`@("`@("`D8FEN9&EN9R`])B`D=&AI<RT^7W=S9&Q;)V1E9FEN:71I;VYS
M)UU;)V)I;F1I;F<G75LG;W!E<F%T:6]N)UU;73L*("`@("`@("`@("`@)&)I
M;F1I;F=;)V%T='(G75LG;F%M92==(#T@)&UE=&AO9%]N86UE.PH@("`@("`@
M("`@("`D86-T:6]N(#T@)&UE=&AO9%]N86UE<W!A8V4@+B`G(R<@+B`H)&-L
M87-S;F%M92`_("1C;&%S<VYA;64@+B`G(R<@.B`G)RD@+B`D;65T:&]D7VYA
M;64["B`@("`@("`@("`@("1B:6YD:6YG6R=S;V%P.F]P97)A=&EO;B==6R=A
M='1R)UU;)W-O87!!8W1I;VXG72`]("1A8W1I;VX["@H@("`@("`@("`@("`O
M+R!)3E!55`H@("`@("`@("`@("`D8FEN9&EN9ULG:6YP=70G75LG871T<B==
M(#T@)R<["B`@("`@("`@("`@("1B:6YD:6YG6R=I;G!U="==6R=S;V%P.F)O
M9'DG75LG871T<B==6R=U<V4G72`]("=E;F-O9&5D)SL*("`@("`@("`@("`@
M)&)I;F1I;F=;)VEN<'5T)UU;)W-O87`Z8F]D>2==6R=A='1R)UU;)VYA;65S
M<&%C92==(#T@)&UE=&AO9%]N86UE<W!A8V4["B`@("`@("`@("`@("1B:6YD
M:6YG6R=I;G!U="==6R=S;V%P.F)O9'DG75LG871T<B==6R=E;F-O9&EN9U-T
M>6QE)UT@/2!33T%07U-#2$5-05]%3D-/1$E.1SL*"B`@("`@("`@("`@("\O
M($]55%!55`H@("`@("`@("`@("`D8FEN9&EN9ULG;W5T<'5T)UU;)V%T='(G
M72`]("<G.PH@("`@("`@("`@("`D8FEN9&EN9ULG;W5T<'5T)UU;)W-O87`Z
M8F]D>2==6R=A='1R)UU;)W5S92==(#T@)V5N8V]D960G.PH@("`@("`@("`@
M("`D8FEN9&EN9ULG;W5T<'5T)UU;)W-O87`Z8F]D>2==6R=A='1R)UU;)VYA
M;65S<&%C92==(#T@)&UE=&AO9%]N86UE<W!A8V4["B`@("`@("`@("`@("1B
M:6YD:6YG6R=O=71P=70G75LG<V]A<#IB;V1Y)UU;)V%T='(G75LG96YC;V1I
M;F=3='EL92==(#T@4T]!4%]30TA%34%?14Y#3T1)3D<["B`@("`@("`@?0H@
M("`@?0H*("`@(&9U;F-T:6]N(%]G96YE<F%T95]$25-#3U]834PH)&1I<V-O
M7V%R<F%Y*0H@("`@>PH@("`@("`@("1D:7-C;R`]("<\/WAM;"!V97)S:6]N
M/2(Q+C`B/SXG.PH@("`@("`@(&9O<F5A8V@@*"1D:7-C;U]A<G)A>2!A<R`D
M:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@)&1I<V-O("X]("1T:&ES+3Y?
M87)R87E4;TYO9&4H)&ME>2PD=F%L*3L*("`@("`@("!]"B`@("`@("`@)'1H
M:7,M/F1I<V-O(#T@)&1I<V-O.PH@("`@?0H*("`@(&9U;F-T:6]N(%]G96YE
M<F%T95]74T1,7UA-3"@I"B`@("!["B`@("`@("`@)'=S9&P@/2`G/#]X;6P@
M=F5R<VEO;CTB,2XP(C\^)SL*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W=S
M9&P@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("1W<V1L("X]("1T
M:&ES+3Y?87)R87E4;TYO9&4H)&ME>2P@)'9A;"D["B`@("`@("`@?0H@("`@
M("`@("1T:&ES+3YW<V1L(#T@)'=S9&P["B`@("!]"@H@("`@9G5N8W1I;VX@
M7V%R<F%Y5&].;V1E*"1N;V1E7VYA;64@/2`G)RP@)&%R<F%Y*0H@("`@>PH@
M("`@("`@("1R971U<FX@/2`G)SL*("`@("`@("!I9B`H:7-?87)R87DH)&%R
M<F%Y*2D@>PH@("`@("`@("`@("`O+R!W92!H879E(&$@;F]D92!I9B!T:&5R
M92=S(&ME>2`G871T<B<*("`@("`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES
M=',H)V%T='(G+"1A<G)A>2DI('L*("`@("`@("`@("`@("`@("1R971U<FX@
M+CT@(CPD;F]D95]N86UE(CL*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D87)R87E;)V%T='(G72DI('L*("`@("`@("`@("`@("`@("`@("!F;W)E
M86-H("@D87)R87E;)V%T='(G72!A<R`D871T<E]N86UE(#T^("1A='1R7W9A
M;'5E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1R971U<FX@+CT@(B`D
M871T<E]N86UE/5PB)&%T=')?=F%L=65<(B(["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\O('5N
M<V5T("=A='1R)R!A;F0@<')O8V5E9"!O=&AE<B!C:&EL9',N+BX*("`@("`@
M("`@("`@("`@('5N<V5T*"1A<G)A>5LG871T<B==*3L*"B`@("`@("`@("`@
M("`@("!I9B`H8V]U;G0H)&%R<F%Y*2`^(#`I('L*("`@("`@("`@("`@("`@
M("`@("`D:2`](#`["B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&%R
M<F%Y(&%S("1C:&EL9%]N;V1E7VYA;64@/3X@)&-H:6QD7VYO9&5?=F%L=64I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)')E='5R;B`N/2`D:2`]/2`P
M(#\@(CY<;B(@.B`G)SL*("`@("`@("`@("`@("`@("`@("`@("`@)')E='5R
M;B`N/2`D=&AI<RT^7V%R<F%Y5&].;V1E*"1C:&EL9%]N;V1E7VYA;64L)&-H
M:6QD7VYO9&5?=F%L=64I.PH@("`@("`@("`@("`@("`@("`@("`@("`D:2LK
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D
M<F5T=7)N("X]("(\+R1N;V1E7VYA;64^7&XB.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<F5T=7)N("X]("(@+SY<
M;B(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`O+R!W92!H879E(&YO("=A='1R)R!K97D@:6X@87)R
M87D@+2!S;R!I="=S(&QI<W0@;V8@;F]D97,@=VET:`H@("`@("`@("`@("`@
M("`@+R\@=&AE('-A;64@;F%M92`N+BX*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1A<G)A>2!A<R`D8VAI;&1?;F]D95]N86UE(#T^("1C:&EL9%]N;V1E
M7W9A;'5E*2!["B`@("`@("`@("`@("`@("`@("`@)')E='5R;B`N/2`D=&AI
M<RT^7V%R<F%Y5&].;V1E*"1N;V1E7VYA;64L)&-H:6QD7VYO9&5?=F%L=64I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@+R\@)&%R<F%Y(&ES(&YO="!A;B!A<G)A>0H@
M("`@("`@("`@("!I9B`H)&%R<F%Y("$])R<I('L*("`@("`@("`@("`@("`@
M("\O(&%N9"!I=',@;F]T(&5M<'1Y"B`@("`@("`@("`@("`@("`D<F5T=7)N
M("X]("(\)&YO9&5?;F%M93XD87)R87D\+R1N;V1E7VYA;64^7&XB.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@86YD(&ET<R!E
M;7!T>2XN+@H@("`@("`@("`@("`@("`@)')E='5R;B`N/2`B/"1N;V1E7VYA
M;64@+SY<;B(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1R971U<FX["B`@("!]"@H@("`@9G5N8W1I;VX@7V=E=%1Y<&5.<R@D
M='EP92D*("`@('L*("`@("`@("!P<F5G7VUA=&-H7V%L;"@B)UQ[*"XJ*5Q]
M)W-M(BP@)'1Y<&4L("1M*3L*("`@("`@("!I9B`H:7-S970H)&U;,5U;,%TI
M("8F("1M6S%=6S!=("$]("<G*2!["B`@("`@("`@("`@(&EF("@A87)R87E?
M:V5Y7V5X:7-T<R@D;5LQ75LP72PD=&AI<RT^;F%M97-P86-E<RDI('L*("`@
M("`@("`@("`@("`@("1N<U]P<F5F(#T@)VYS)R`N(&-O=6YT*"1T:&ES+3YN
M86UE<W!A8V5S*3L*("`@("`@("`@("`@("`@("1T:&ES+3YN86UE<W!A8V5S
M6R1M6S%=6S!=72`]("1N<U]P<F5F.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]W<V1L6R=D969I;FET:6]N<R==6R=A='1R)UU;)WAM;&YS.B<@+B`D;G-?
M<')E9ET@/2`D;5LQ75LP73L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M='EP96YS(#T@)'1H:7,M/FYA;65S<&%C97-;)&U;,5U;,%U=.PH@("`@("`@
M("`@("`D='EP92`](&5R96=?<F5P;&%C92@D;5LP75LP72PG)RPD='EP92D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1Y<&5N<R`]("=X<V0G
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@87)R87DH)'1Y<&5N<RPD='EP
M92D["B`@("!]"@H@("`@9G5N8W1I;VX@7VEF0V]M<&QE>%1Y<&5%>&ES=',H
M)'1Y<&5S07)R87DL("1T>7!E7VYA;64I"B`@("!["B`@("`@("`@:68@*&ES
M7V%R<F%Y*"1T>7!E<T%R<F%Y*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D
M='EP97-!<G)A>2!A<R`D:6YD97@@/3X@)'1Y<&5?9&%T82D@>PH@("`@("`@
M("`@("`@("`@:68@*"1T>7!E<T%R<F%Y6R1I;F1E>%U;)V%T='(G75LG;F%M
M92==(#T]("1T>7!E7VYA;64I('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]33T%0+T9A=6QT+G!H<```
M````````````````````````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,#`U,@`Q
M,#4Q-30S,S<S-P`P,C$Q,S,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J(%1H:7,@9FEL92!C;VYT86EN
M<R!T:&4@4T]!4%]&875L="!C;&%S<RP@=7-E9"!F;W(@86QL(&5R<F]R(&]B
M:F5C=',@:6X@=&AI<PH@*B!P86-K86=E+@H@*@H@*B!02%`@=F5R<VEO;G,@
M-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U
M8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P*("H@
M=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE
M($Q)0T5.4T4L(&%N9"!I<R!A=F%I;&%B;&4@870*("H@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(@870@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,E\P,BYT>'0N("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O
M9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET
M"B`J('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A
M(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;@H@*B!M86EL('EO
M=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@(%=E8B!3
M97)V:6-E<PH@*B!`<&%C:V%G92`@("!33T%0"B`J($!A=71H;W(@("`@($1I
M971R:6-H($%Y86QA(#QD:65T<FEC:$!G86YX-"YC;VT^($]R:6=I;F%L($%U
M=&AO<@H@*B!`875T:&]R("`@("!3:&%N92!#87)A=F5O(#Q3:&%N94!#87)A
M=F5O+F-O;3X@("!0;W)T('1O(%!%05(@86YD(&UO<F4*("H@0&%U=&AO<B`@
M("`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^("`@36%I;G1E
M;F%N8V4*("H@0&%U=&AO<B`@("`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E
M+F]R9SX@("`@("`@36%I;G1E;F%N8V4*("H@0&-O<'ER:6=H="`@,C`P,RTR
M,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0@(%!(4"!,:6-E;G-E(#(N,#(*("H@
M0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U-/05`*
M("HO"@IR97%U:7)E7V]N8V4H)U!%05(N<&AP)RD["@HO*BH*("H@4T]!4%]&
M875L=`H@*B!014%2.CI%<G)O<B!W<F%P<&5R('5S960@=&\@;6%T8V@@4T]!
M4"!&875L=',@=&\@4$5!4B!%<G)O<G,*("H*("H@0'!A8VMA9V4@(%-/05`*
M("H@0&%C8V5S<R`@('!U8FQI8PH@*B!`875T:&]R("`@4VAA;F4@0V%R879E
M;R`\4VAA;F5`0V%R879E;RYC;VT^("`@4&]R="!T;R!014%2(&%N9"!M;W)E
M"B`J($!A=71H;W(@("!$:65T<FEC:"!!>6%L82`\9&EE=')I8VA`9V%N>#0N
M8V]M/B!/<FEG:6YA;"!!=71H;W(*("HO"F-L87-S(%-/05!?1F%U;'0@97AT
M96YD<R!014%27T5R<F]R"GL*("`@(`H@("`@+RHJ"B`@("`@*B!#;VYS=')U
M8W1O<@H@("`@("H@"B`@("`@*B!`<&%R86T@("`@<W1R:6YG("!M97-S86=E
M('-T<FEN9R!F;W(@9F%U;'0*("`@("`J($!P87)A;2`@("!M:7AE9"`@('1H
M92!F875L=&-O9&4*("`@("`J($!P87)A;2`@("!M:7AE9"`@('-E92!014%2
M.CI%4E)/4B`*("`@("`J($!P87)A;2`@("!M:7AE9"`@('-E92!014%2.CI%
M4E)/4B`*("`@("`J($!P87)A;2`@("!A<G)A>2`@('1H92!U<V5R:6YF;R!A
M<G)A>2!I<R!U<V5D('1O('!A<W,@:6X@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("!33T%0(&%C=&]R(&%N9"!D971A:6P@9F]R('1H92!F875L=`H@
M("`@("HO"B`@("!F=6YC=&EO;B!33T%07T9A=6QT*"1F875L='-T<FEN9R`]
M("=U;FMN;W=N(&5R<F]R)RP@)&9A=6QT8V]D92`]("=#;&EE;G0G+"`D9F%U
M;'1A8W1O<CU.54Q,+"`D9&5T86EL/4Y53$PL("1M;V1E(#T@;G5L;"P@)&]P
M=&EO;G,@/2!N=6QL*0H@("`@>PH@("`@("`@('!A<F5N=#HZ4$5!4E]%<G)O
M<B@D9F%U;'1S=')I;F<L("1F875L=&-O9&4L("1M;V1E+"`D;W!T:6]N<RP@
M)&1E=&%I;"D["B`@("`@("`@:68@*"1F875L=&%C=&]R*2`D=&AI<RT^97)R
M;W)?;65S<V%G95]P<F5F:7@@/2`D9F%U;'1A8W1O<CL*("`@('T*("`@(`H@
M("`@+RHJ"B`@("`@*B!M97-S86=E"B`@("`@*@H@("`@("H@<F5T=7)N<R!A
M(%-/05!?365S<V%G92!C;&%S<R!T:&%T(&-A;B!B92!S96YT(&%S(&$@<V5R
M=F5R(')E<W!O;G-E"B`@("`@*@H@("`@("H@0')E='5R;B!33T%07TUE<W-A
M9V4@"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO
M;B!M97-S86=E*"D*("`@('L*("`@("`@("`D;7-G(#TF(&YE=R!33T%07T)A
M<V4H*3L*("`@("`@("`D<&%R86US(#T@87)R87DH*3L*("`@("`@("`D<&%R
M86US6UT@/28@;F5W(%-/05!?5F%L=64H)V9A=6QT8V]D92<L("=13F%M92<L
M("=33T%0+45.5CHG+B1T:&ES+3YC;V1E*3L*("`@("`@("`D<&%R86US6UT@
M/28@;F5W(%-/05!?5F%L=64H)V9A=6QT<W1R:6YG)RP@)W-T<FEN9R<L("1T
M:&ES+3YM97-S86=E*3L*("`@("`@("`D<&%R86US6UT@/28@;F5W(%-/05!?
M5F%L=64H)V9A=6QT86-T;W(G+"`G86YY55)))RP@)'1H:7,M/F5R<F]R7VUE
M<W-A9V5?<')E9FEX*3L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F)A8VMT
M<F%C92DI('L*("`@("`@("`@("`@)'!A<F%M<UM=(#TF(&YE=R!33T%07U9A
M;'5E*"=D971A:6PG+"`G<W1R:6YG)RP@)'1H:7,M/F)A8VMT<F%C92D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'!A<F%M<UM=(#TF(&YE=R!3
M3T%07U9A;'5E*"=D971A:6PG+"`G<W1R:6YG)RP@)'1H:7,M/G5S97)I;F9O
M*3L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@)&UE=&AO9%9A;'5E(#TF
M(&YE=R!33T%07U9A;'5E*"=[)RY33T%07T5.5D5,3U`N)WU&875L="<L("=3
M=')U8W0G+"`D<&%R86US*3L*("`@("`@("`D:&5A9&5R<R`]($Y53$P["B`@
M("`@("`@<F5T=7)N("1M<V<M/E]M86ME16YV96QO<&4H)&UE=&AO9%9A;'5E
M+"`D:&5A9&5R<RD["B`@("!]"B`@("`*("`@("\J*@H@("`@("H@9V5T1F%U
M;'0*("`@("`J"B`@("`@*B!R971U<FYS(&$@<VEM<&QE(&YA=&EV92!P:'`@
M87)R87D@8V]N=&%I;FEN9R!T:&4@9F%U;'0@9&%T80H@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!G971&875L="@I"B`@("!["B`@("`@("`@9VQO8F%L
M("133T%07T]"2D5#5%]35%)50U0["B`@("`@("`@:68@*"133T%07T]"2D5#
M5%]35%)50U0I('L*("`@("`@("`@("`@)&9A=6QT(#TF(&YE=R!S=&1#;&%S
M<R@I.PH@("`@("`@("`@("`D9F%U;'0M/F9A=6QT8V]D92`]("1T:&ES+3YC
M;V1E.PH@("`@("`@("`@("`D9F%U;'0M/F9A=6QT<W1R:6YG(#T@)'1H:7,M
M/FUE<W-A9V4["B`@("`@("`@("`@("1F875L="T^9F%U;'1A8W1O<B`]("1T
M:&ES+3YE<G)O<E]M97-S86=E7W!R969I>#L*("`@("`@("`@("`@)&9A=6QT
M+3YD971A:6P@/2`D=&AI<RT^=7-E<FEN9F\["B`@("`@("`@("`@(')E='5R
M;B`D9F%U;'0["B`@("`@("`@?0H@("`@("`@(')E='5R;B!A<G)A>2@*("`@
M("`@("`@("`@("`@("=F875L=&-O9&4G(#T^("1T:&ES+3YC;V1E+`H@("`@
M("`@("`@("`@("`@)V9A=6QT<W1R:6YG)R`]/B`D=&AI<RT^;65S<V%G92P*
M("`@("`@("`@("`@("`@("=F875L=&%C=&]R)R`]/B`D=&AI<RT^97)R;W)?
M;65S<V%G95]P<F5F:7@L"B`@("`@("`@("`@("`@("`G9&5T86EL)R`]/B`D
M=&AI<RT^=7-E<FEN9F\*("`@("`@("`@("`@*3L*("`@('T*("`@(`H@("`@
M+RHJ"B`@("`@*B!G971!8W1O<@H@("`@("H*("`@("`J(')E='5R;G,@=&AE
M(%-/05`@86-T;W(@9F]R('1H92!F875L=`H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG(`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T06-T;W(H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^97)R;W)?;65S<V%G95]P<F5F:7@["B`@("!]"B`@("`*("`@("\J*@H@
M("`@("H@9V5T1&5T86EL"B`@("`@*@H@("`@("H@<F5T=7)N<R!T:&4@9F%U
M;'0@9&5T86EL"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971$971A
M:6PH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^=7-E<FEN9F\["B`@
M("!]"B`@("`*?0H_/@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+U-/05`O4&%R<V5R+G!H<```````````````
M`````````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0V,#4P`#$P-3$U-#,S-S,W
M`#`R,3,R,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@5&AI<R!F:6QE(&-O;G1A:6YS('1H92!C;V1E
M(&9O<B!T:&4@4T]!4"!M97-S86=E('!A<G-E<BX*("H*("H@4$A0('9E<G-I
M;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I
M<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L
M"B`J('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@
M9FEL92!,24-%3E-%+"!A;F0@:7,@879A:6QA8FQE(&%T"B`J('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S)?,#(N='AT+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!A(&-O
M<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I
M;B!I=`H@*B!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E
M;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X*("H@;6%I
M;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!7
M96(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@4T]!4`H@*B!`875T:&]R("`@
M("!$:65T<FEC:"!!>6%L82`\9&EE=')I8VA`9V%N>#0N8V]M/B!/<FEG:6YA
M;"!!=71H;W(*("H@0&%U=&AO<B`@("`@4VAA;F4@0V%R879E;R`\4VAA;F5`
M0V%R879E;RYC;VT^("`@4&]R="!T;R!014%2(&%N9"!M;W)E"B`J($!A=71H
M;W(@("`@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/B`@($UA
M:6YT96YA;F-E"B`J($!A=71H;W(@("`@($IA;B!38VAN96ED97(@/&IA;D!H
M;W)D92YO<F<^("`@("`@($UA:6YT96YA;F-E"B`J($!C;W!Y<FEG:'0@(#(P
M,#,M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT("!02%`@3&EC96YS92`R+C`R
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]3
M3T%0"B`J+PH*<F5Q=6ER95]O;F-E("=33T%0+T)A<V4N<&AP)SL*<F5Q=6ER
M95]O;F-E("=33T%0+U9A;'5E+G!H<"<["@HO*BH*("H@4T]!4"!087)S97(*
M("H*("H@5&AI<R!C;&%S<R!I<R!U<V5D(&)Y(%-/05`Z.DUE<W-A9V4@86YD
M(%-/05`Z.E-E<G9E<B!T;R!P87)S92!S;V%P"B`J('!A8VME=',N($]R:6=I
M;F%L;'D@8F%S960@;VX@4T]!4'@T(&)Y($1I971R:6-H($%Y86QA"B`J(&AT
M='`Z+R]D:65T<FEC:"YG86YX-"YC;VTO<V]A<'@T"B`J"B`J($!A8V-E<W,@
M<'5B;&EC"B`J($!P86-K86=E(%-/05`*("H@0&%U=&AO<B!3:&%N92!#87)A
M=F5O(#QS:&%N94!P:'`N;F5T/B!#;VYV97)S:6]N('1O(%!%05(@86YD('5P
M9&%T97,*("H@0&%U=&AO<B!$:65T<FEC:"!!>6%L82`\9&EE=')I8VA`9V%N
M>#0N8V]M/B!/<FEG:6YA;"!!=71H;W(*("HO"F-L87-S(%-/05!?4&%R<V5R
M(&5X=&5N9',@4T]!4%]"87-E"GL*("`@('9A<B`D<W1A='5S(#T@)R<["B`@
M("!V87(@)'!O<VET:6]N(#T@,#L*("`@('9A<B`D<&]S7W-T870@/2`P.PH@
M("`@=F%R("1D97!T:"`](#`["B`@("!V87(@)&1E9F%U;'1?;F%M97-P86-E
M(#T@)R<["B`@("!V87(@)&UE<W-A9V4@/2!A<G)A>2@I.PH@("`@=F%R("1D
M97!T:%]A<G)A>2`](&%R<F%Y*"D["B`@("!V87(@)'!R979I;W5S7V5L96UE
M;G0@/2`G)SL*("`@('9A<B`D<V]A<')E<W!O;G-E(#T@;G5L;#L*("`@('9A
M<B`D<V]A<&AE861E<G,@/2!N=6QL.PH@("`@=F%R("1P87)E;G0@/2`P.PH@
M("`@=F%R("1R;V]T7W-T<G5C=%]N86UE(#T@87)R87DH*3L*("`@('9A<B`D
M:&5A9&5R7W-T<G5C=%]N86UE(#T@87)R87DH*3L*("`@('9A<B`D8W5R96YT
M7W)O;W1?<W1R=6-T7VYA;64@/2`G)SL*("`@('9A<B`D96YT:71I97,@/2!A
M<G)A>2`H("<F)R`]/B`G)F%M<#LG+"`G/"<@/3X@)R9L=#LG+"`G/B<@/3X@
M)R9G=#LG+"`B)R(@/3X@)R9A<&]S.R<L("<B)R`]/B`G)G%U;W0[)R`I.PH@
M("`@=F%R("1R;V]T7W-T<G5C="`](&%R<F%Y*"D["B`@("!V87(@)&AE861E
M<E]S=')U8W0@/2!A<G)A>2@I.PH@("`@=F%R("1C=7)E;G1?<F]O=%]S=')U
M8W0@/2`P.PH@("`@=F%R("1R969E<F5N8V5S(#T@87)R87DH*3L*("`@('9A
M<B`D;F5E9%]R969E<F5N8V5S(#T@87)R87DH*3L*("`@('9A<B`D6$U,4V-H
M96UA5F5R<VEO;CL*("`@('9A<B`D8F]D>41E<'1H.R`O+R!U<V5D('1O(&AA
M;F1L92!N;VXM<F]O="!E;&5M96YT<R!B969O<F4@<F]O="!B;V1Y(&5L96UE
M;G0*"B`@("`O*BH*("`@("`J(%-/05!?4&%R<V5R(&-O;G-T<G5C=&]R"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!X;6P@8V]N=&5N=`H@("`@("H@
M0'!A<F%M('-T<FEN9R!X;6P@8VAA<F%C=&5R(&5N8V]D:6YG+"!D969A=6QT
M<R!T;R`G551&+3@G"B`@("`@*B\*("`@(&9U;F-T:6]N(%-/05!?4&%R<V5R
M*"8D>&UL+"`D96YC;V1I;F<@/2!33T%07T1%1D%53%1?14Y#3T1)3D<L("1A
M='1A8VAM96YT<R`](&YU;&PI"B`@("!["B`@("`@("`@<&%R96YT.CI33T%0
M7T)A<V4H)U!A<G-E<B<I.PH@("`@("`@("1T:&ES+3Y?<V5T4V-H96UA5F5R
M<VEO;BA33T%07UA-3%]30TA%34%?5D524TE/3BD["@H@("`@("`@("1T:&ES
M+3YA='1A8VAM96YT<R`]("1A='1A8VAM96YT<SL*"B`@("`@("`@+R\@0VAE
M8VL@=&AE('AM;"!T86<@9F]R(&5N8V]D:6YG+@H@("`@("`@(&EF("AP<F5G
M7VUA=&-H*"<O/%P_>&UL6UX^72ME;F-O9&EN9UQS*C\]7',J/RA<)RA;7EPG
M72HI7"=\(BA;7B)=*BDB*5M>/ETJ/UM</UT^+R<L("1X;6PL("1M*2D@>PH@
M("`@("`@("`@("`D96YC;V1I;F<@/2!S=')T;W5P<&5R*"1M6S)=(#\@)&U;
M,ET@.B`D;5LS72D["B`@("`@("`@?0H*("`@("`@("`O+R!$971E<FUI;F5S
M('=H97)E(&EN('1H92!M97-S86=E('=E(&%R90H@("`@("`@("\O("AE;G9E
M;&]P92QH96%D97(L8F]D>2QM971H;V0I+B!#:&5C:R!W:&5T:&5R(&-O;G1E
M;G0@:&%S"B`@("`@("`@+R\@8F5E;B!R96%D+@H@("`@("`@(&EF("@A96UP
M='DH)'AM;"DI('L*("`@("`@("`@("`@+R\@4')E<&%R92!T:&4@>&UL('!A
M<G-E<BX*("`@("`@("`@("`@)'!A<G-E<B`]('AM;%]P87)S97)?8W)E871E
M*"1E;F-O9&EN9RD["B`@("`@("`@("`@('AM;%]P87)S97)?<V5T7V]P=&EO
M;B@D<&%R<V5R+"!834Q?3U!424].7T-!4T5?1D],1$E.1RP@,"D["B`@("`@
M("`@("`@('AM;%]S971?;V)J96-T*"1P87)S97(L("1T:&ES*3L*("`@("`@
M("`@("`@>&UL7W-E=%]E;&5M96YT7VAA;F1L97(H)'!A<G-E<BP@)W-T87)T
M16QE;65N="<L("=E;F1%;&5M96YT)RD["B`@("`@("`@("`@('AM;%]S971?
M8VAA<F%C=&5R7V1A=&%?:&%N9&QE<B@D<&%R<V5R+"`G8VAA<F%C=&5R1&%T
M82<I.PH*("`@("`@("`@("`@+R\@4V]M92!L86UE('-O87`@:6UP;&5M96YT
M871I;VYS(&%D9"!N=6QL(&)Y=&5S(&%T('1H90H@("`@("`@("`@("`O+R!E
M;F0@;V8@=&AE('-O87`@<W1R96%M+"!A;F0@97AP870@8VAO86MS(&]N('1H
M870N"B`@("`@("`@("`@(&EF("@D>&UL6W-T<FQE;B@D>&UL*2`M(#%=(#T]
M(#`I('L*("`@("`@("`@("`@("`@("1X;6P@/2!T<FEM*"1X;6PI.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O+R!087)S92!T:&4@6$U,(&9I;&4N
M"B`@("`@("`@("`@(&EF("@A>&UL7W!A<G-E*"1P87)S97(L("1X;6PL('1R
M=64I*2!["B`@("`@("`@("`@("`@("`D97)R(#T@<W!R:6YT9B@G6$U,(&5R
M<F]R(&]N(&QI;F4@)60@8V]L("5D(&)Y=&4@)60@)7,G+`H@("`@("`@("`@
M("`@("`@("`@('AM;%]G971?8W5R<F5N=%]L:6YE7VYU;6)E<B@D<&%R<V5R
M*2P*("`@("`@("`@("`@("`@("`@("!X;6Q?9V5T7V-U<G)E;G1?8V]L=6UN
M7VYU;6)E<B@D<&%R<V5R*2P*("`@("`@("`@("`@("`@("`@("!X;6Q?9V5T
M7V-U<G)E;G1?8GET95]I;F1E>"@D<&%R<V5R*2P*("`@("`@("`@("`@("`@
M("`@("!X;6Q?97)R;W)?<W1R:6YG*'AM;%]G971?97)R;W)?8V]D92@D<&%R
M<V5R*2DI.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L
M="@D97)R+&AT;6QS<&5C:6%L8VAA<G,H)'AM;"DI.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@('AM;%]P87)S97)?9G)E92@D<&%R<V5R*3L*("`@("`@
M("!]"B`@("!]"@H*("`@("\J*@H@("`@("H@9&]M=6QT:0H@("`@("H@<F5C
M=7)S92!T;R!B=6EL9"!A(&UU;'1I+61I;2!A<G)A>2P@=7-E9"!B>2!B=6EL
M9%)E<W!O;G-E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&1O;75L=&DH)&0L("8D87(L("8D<BP@)B1V+"`D
M860],"D*("`@('L*("`@("`@("!I9B`H)&0I('L*("`@("`@("`@("`@)'1H
M:7,M/F1O;75L=&DH)&0M,2P@)&%R+"`D<ELD87);)&%D75TL("1V+"`D860K
M,2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'(@/2`D=CL*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!B=6EL9%)E<W!O;G-E"B`@
M("`@*B!L;V]P('1H<F]U9V@@;7-G+"!B=6EL9&EN9R!R97-P;VYS92!S=')U
M8W1U<F5S"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="!P;W-I=&EO;@H@("`@
M("H@0')E='5R;B!33T%07U9A;'5E"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@9G5N8W1I;VX@)F)U:6QD4F5S<&]N<V4H)'!O<RD*("`@
M('L*("`@("`@("`D<F5S<&]N<V4@/2!N=6QL.PH*("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V-H:6QD<F5N)UTI*2!["B`@("`@
M("`@("`@("1C:&EL9')E;B`](&5X<&QO9&4H)WPG+"`D=&AI<RT^;65S<V%G
M95LD<&]S75LG8VAI;&1R96XG72D["@H@("`@("`@("`@("!F;W)E86-H("@D
M8VAI;&1R96X@87,@)&,@/3X@)&-H:6QD7W!O<RD@>PH@("`@("`@("`@("`@
M("`@:68@*"1T:&ES+3YM97-S86=E6R1C:&EL9%]P;W-=6R=T>7!E)UT@(3T@
M;G5L;"D@>PH@("`@("`@("`@("`@("`@("`@("1R97-P;VYS95M=(#TF("1T
M:&ES+3YB=6EL9%)E<W!O;G-E*"1C:&EL9%]P;W,I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AA<G)A>5]K97E?
M97AI<W1S*"=A<G)A>5-I>F4G+"`D=&AI<RT^;65S<V%G95LD<&]S72DI('L*
M("`@("`@("`@("`@("`@("1A<F1E<'1H(#T@8V]U;G0H)'1H:7,M/FUE<W-A
M9V5;)'!O<UU;)V%R<F%Y4VEZ92==*3L*("`@("`@("`@("`@("`@(&EF("@D
M87)D97!T:"`^(#$I('L*("`@("`@("`@("`@("`@("`@("`D87(@/2!A<G)A
M>5]P860H87)R87DH*2P@)&%R9&5P=&@L(#`I.PH@("`@("`@("`@("`@("`@
M("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=A<G)A>4]F9G-E="<L("1T:&ES
M+3YM97-S86=E6R1P;W-=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"`D87)D97!T:#L@)&DK*RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&%R6R1I72`K/2`D=&AI<RT^;65S<V%G95LD
M<&]S75LG87)R87E/9F9S970G75LD:5T["B`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@)&5L8R`](&-O=6YT*"1R97-P;VYS92D["B`@("`@("`@("`@("`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@)&5L8SL@)&DK*RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!R96-U<G-E('1O(&)U:6QD(&$@;75L=&DM9&EM
M96YS:6]N86P@87)R87D*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/F1O;75L=&DH)&%R9&5P=&@L("1A<BP@)&YE=W)E<W`L("1R97-P;VYS95LD
M:5TI.PH*("`@("`@("`@("`@("`@("`@("`@("`@+R\@:6YC<F5M96YT(&]U
M<B!A<G)A>2!P;VEN=&5R<PH@("`@("`@("`@("`@("`@("`@("`@("`D860@
M/2`D87)D97!T:"`M(#$["B`@("`@("`@("`@("`@("`@("`@("`@("1A<ELD
M861=*RL["B`@("`@("`@("`@("`@("`@("`@("`@('=H:6QE("@D860@/B`P
M("8F("1A<ELD861=(#X]("1T:&ES+3YM97-S86=E6R1P;W-=6R=A<G)A>5-I
M>F4G75LD861=*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D87);
M)&%D72`](#`["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D860M+3L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A<ELD861=*RL["B`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@)')E<W!O;G-E(#T@)&YE=W)E<W`["B`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)'1H:7,M/FUE<W-A9V5;)'!O
M<UU;)V%R<F%Y3V9F<V5T)UTI("8F"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V%R<F%Y3V9F<V5T)UU;,%T@/B`P
M*2!["B`@("`@("`@("`@("`@("`@("`@+R\@8VAE8VL@9F]R('!A9&1I;F<*
M("`@("`@("`@("`@("`@("`@("`D<&%D(#T@)'1H:7,M/FUE<W-A9V5;)'!O
M<UU;)V%R<F%Y3V9F<V5T)UU;,%T@*R!C;W5N="@D<F5S<&]N<V4I("H@+3$[
M"B`@("`@("`@("`@("`@("`@("`@)')E<W!O;G-E(#T@87)R87E?<&%D*"1R
M97-P;VYS92P@)'!A9"P@;G5L;"D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($)U:6QD(&%T=')I8G5T
M97,N"B`@("`@("`@)&%T=')S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H
M("@D=&AI<RT^;65S<V%G95LD<&]S75LG871T<G,G72!A<R`D871N(#T^("1A
M='8I('L*("`@("`@("`@("`@:68@*"%S=')S='(H)&%T;BP@)WAM;&YS)RD@
M)B8*("`@("`@("`@("`@("`@("%S=')P;W,H)&%T;BP@)SHG*2D@>PH@("`@
M("`@("`@("`@("`@)&%T=')S6R1A=&Y=(#T@)&%T=CL*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@+R\@061D(&-U<G)E;G0@;F]D92=S('9A
M;'5E+@H@("`@("`@(&EF("@D<F5S<&]N<V4I('L*("`@("`@("`@("`@)&YQ
M;B`])B!N97<@46YA;64H)'1H:7,M/FUE<W-A9V5;)'!O<UU;)VYA;64G72P@
M)'1H:7,M/FUE<W-A9V5;)'!O<UU;)VYA;65S<&%C92==*3L*("`@("`@("`@
M("`@)'1Q;B`])B!N97<@46YA;64H)'1H:7,M/FUE<W-A9V5;)'!O<UU;)W1Y
M<&4G72P@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)W1Y<&5?;F%M97-P86-E)UTI
M.PH@("`@("`@("`@("`D<F5S<&]N<V4@/28@;F5W(%-/05!?5F%L=64H)&YQ
M;BT^9G%N*"DL("1T<6XM/F9Q;B@I+"`D<F5S<&]N<V4L("1A='1R<RD["B`@
M("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^;65S<V%G95LD<&]S75LG87)R
M87E4>7!E)UTI*2!["B`@("`@("`@("`@("`@("`D<F5S<&]N<V4M/F%R<F%Y
M5'EP92`]("1T:&ES+3YM97-S86=E6R1P;W-=6R=A<G)A>51Y<&4G73L*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1N<6X@
M/28@;F5W(%%N86UE*"1T:&ES+3YM97-S86=E6R1P;W-=6R=N86UE)UTL("1T
M:&ES+3YM97-S86=E6R1P;W-=6R=N86UE<W!A8V4G72D["B`@("`@("`@("`@
M("1T<6X@/28@;F5W(%%N86UE*"1T:&ES+3YM97-S86=E6R1P;W-=6R=T>7!E
M)UTL("1T:&ES+3YM97-S86=E6R1P;W-=6R=T>7!E7VYA;65S<&%C92==*3L*
M("`@("`@("`@("`@)')E<W!O;G-E(#TF(&YE=R!33T%07U9A;'5E*"1N<6XM
M/F9Q;B@I+"`D='%N+3YF<6XH*2P@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V-D
M871A)UTL("1A='1R<RD["B`@("`@("`@?0H*("`@("`@("`O+R!H86YD;&4@
M:&5A9&5R(&%T=')I8G5T92!T:&%T('=E(&YE960*("`@("`@("!I9B`H87)R
M87E?:V5Y7V5X:7-T<R@G86-T;W(G+"`D=&AI<RT^;65S<V%G95LD<&]S72DI
M('L*("`@("`@("`@("`@)')E<W!O;G-E+3YA8W1O<B`]("1T:&ES+3YM97-S
M86=E6R1P;W-=6R=A8W1O<B==.PH@("`@("`@('T*("`@("`@("!I9B`H87)R
M87E?:V5Y7V5X:7-T<R@G;75S=%5N9&5R<W1A;F0G+"`D=&AI<RT^;65S<V%G
M95LD<&]S72DI('L*("`@("`@("`@("`@)')E<W!O;G-E+3YM=7-T=6YD97)S
M=&%N9"`]("1T:&ES+3YM97-S86=E6R1P;W-=6R=M=7-T56YD97)S=&%N9"==
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')E<W!O;G-E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@<W1A<G1%;&5M96YT"B`@("`@*B!S=&%R="UE;&5M
M96YT(&AA;F1L97(@=7-E9"!W:71H('AM;"!P87)S97(*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@<W1A<G1%
M;&5M96YT*"1P87)S97(L("1N86UE+"`D871T<G,I"B`@("!["B`@("`@("`@
M+R\@<&]S:71I;VX@:6X@82!T;W1A;"!N=6UB97(@;V8@96QE;65N=',L('-T
M87)T:6YG(&9R;VT@,`H@("`@("`@("\O('5P9&%T92!C;&%S<R!L979E;"!P
M;W,*("`@("`@("`D<&]S(#T@)'1H:7,M/G!O<VET:6]N*RL["@H@("`@("`@
M("\O(&%N9"!S970@;6EN90H@("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=
M(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG='EP
M92==(#T@)R<["B`@("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)W1Y<&5?
M;F%M97-P86-E)UT@/2`G)SL*("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S
M75LG8V1A=&$G72`]("<G.PH@("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=
M6R=P;W,G72`]("1P;W,["B`@("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;
M)VED)UT@/2`G)SL*"B`@("`@("`@+R\@<&%R96YT+V-H:6QD+V1E<'1H(&1E
M=&5R;6EN871I;VYS"@H@("`@("`@("\O(&1E<'1H(#T@:&]W(&UA;GD@;&5V
M96QS(')E;6]V960@9G)O;2!R;V]T/PH@("`@("`@("\O('-E="!M:6YE(&%S
M(&-U<G)E;G0@9VQO8F%L(&1E<'1H(&%N9"!I;F-R96UE;G0@9VQO8F%L(&1E
M<'1H('9A;'5E"B`@("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V1E<'1H
M)UT@/2`D=&AI<RT^9&5P=&@K*SL*"B`@("`@("`@+R\@96QS92!A9&0@<V5L
M9B!A<R!C:&EL9"!T;R!W:&]E=F5R('1H92!C=7)R96YT('!A<F5N="!I<PH@
M("`@("`@(&EF("@D<&]S("$](#`I('L*("`@("`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3YM97-S86=E6R1T:&ES+3YP87)E;G1=6R=C:&EL9')E;B==*2D*
M("`@("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1T:&ES+3YP87)E;G1=
M6R=C:&EL9')E;B==("X](")\)'!O<R(["B`@("`@("`@("`@(&5L<V4*("`@
M("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1T:&ES+3YP87)E;G1=6R=C
M:&EL9')E;B==(#T@)'!O<SL*("`@("`@("!]"@H@("`@("`@("\O('-E="!M
M>2!P87)E;G0*("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG<&%R96YT
M)UT@/2`D=&AI<RT^<&%R96YT.PH*("`@("`@("`O+R!S970@<V5L9B!A<R!C
M=7)R96YT('9A;'5E(&9O<B!T:&ES(&1E<'1H"B`@("`@("`@)'1H:7,M/F1E
M<'1H7V%R<F%Y6R1T:&ES+3YD97!T:%T@/2`D<&]S.PH@("`@("`@("\O('-E
M="!S96QF(&%S(&-U<G)E;G0@<&%R96YT"B`@("`@("`@)'1H:7,M/G!A<F5N
M="`]("1P;W,["B`@("`@("`@)'%N86UE(#TF(&YE=R!13F%M92@D;F%M92D[
M"B`@("`@("`@+R\@<V5T('-T871U<PH@("`@("`@(&EF("AS=')C87-E8VUP
M*"=E;G9E;&]P92<L("1Q;F%M92T^;F%M92D@/3T@,"D@>PH@("`@("`@("`@
M("`D=&AI<RT^<W1A='5S(#T@)V5N=F5L;W!E)SL*("`@("`@("!](&5L<V5I
M9B`H<W1R8V%S96-M<"@G:&5A9&5R)RP@)'%N86UE+3YN86UE*2`]/2`P*2![
M"B`@("`@("`@("`@("1T:&ES+3YS=&%T=7,@/2`G:&5A9&5R)SL*("`@("`@
M("`@("`@)'1H:7,M/FAE861E<E]S=')U8W1?;F%M95M=(#T@)'1H:7,M/F-U
M<F5N=%]R;V]T7W-T<G5C=%]N86UE(#T@)'%N86UE+3YN86UE.PH@("`@("`@
M("`@("`D=&AI<RT^:&5A9&5R7W-T<G5C=%M=(#T@)'1H:7,M/F-U<F5N=%]R
M;V]T7W-T<G5C="`]("1P;W,["B`@("`@("`@("`@("1T:&ES+3YM97-S86=E
M6R1P;W-=6R=T>7!E)UT@/2`G4W1R=6-T)SL*("`@("`@("!](&5L<V5I9B`H
M<W1R8V%S96-M<"@G8F]D>2<L("1Q;F%M92T^;F%M92D@/3T@,"D@>PH@("`@
M("`@("`@("`D=&AI<RT^<W1A='5S(#T@)V)O9'DG.PH@("`@("`@("`@("`D
M=&AI<RT^8F]D>41E<'1H(#T@)'1H:7,M/F1E<'1H.PH*("`@("`@("`O+R!3
M970@;65T:&]D"B`@("`@("`@?2!E;'-E:68@*"1T:&ES+3YS=&%T=7,@/3T@
M)V)O9'DG*2!["B`@("`@("`@("`@("\O($ES('1H:7,@96QE;65N="!A;&QO
M=V5D('1O(&)E(&$@<F]O=#\*("`@("`@("`@("`@+R\@6%A8('1H:7,@;F5E
M9',@=&\@8F4@;W!T:6UI>F5D+"!W92!L;V]P('1H<F]U9V@@871T<G,@='=I
M8V4@;F]W+@H@("`@("`@("`@("`D8V%N7W)O;W0@/2`D=&AI<RT^9&5P=&@@
M/3T@)'1H:7,M/F)O9'E$97!T:"`K(#$["B`@("`@("`@("`@(&EF("@D8V%N
M7W)O;W0I('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1A='1R<R!A<R`D
M:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AS=')I
M<W1R*"1K97DL("<Z<F]O="<I("8F("$D=F%L=64I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&-A;E]R;V]T(#T@1D%,4T4["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!I9B`H)&-A;E]R;V]T*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^<W1A='5S(#T@)VUE=&AO9"<["B`@("`@("`@("`@("`@("`D=&AI<RT^
M<F]O=%]S=')U8W1?;F%M95M=(#T@)'1H:7,M/F-U<F5N=%]R;V]T7W-T<G5C
M=%]N86UE(#T@)'%N86UE+3YN86UE.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/G)O;W1?<W1R=6-T6UT@/2`D=&AI<RT^8W5R96YT7W)O;W1?<W1R=6-T(#T@
M)'!O<SL*("`@("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=T
M>7!E)UT@/2`G4W1R=6-T)SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@+R\@4V5T(&UY('-T871U<RX*("`@("`@("`D=&AI<RT^;65S<V%G
M95LD<&]S75LG<W1A='5S)UT@/2`D=&AI<RT^<W1A='5S.PH*("`@("`@("`O
M+R!3970@;F%M92X*("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG;F%M
M92==(#T@:'1M;'-P96-I86QC:&%R<R@D<6YA;64M/FYA;64I.PH*("`@("`@
M("`O+R!3970@871T<FEB=71E<RX*("`@("`@("`D=&AI<RT^;65S<V%G95LD
M<&]S75LG871T<G,G72`]("1A='1R<SL*"B`@("`@("`@+R\@3&]O<"!T:')O
M=6=H(&%T=')I8G5T97,L(&QO9V=I;F<@;G,@86YD('1Y<&4@9&5C;&%R871I
M;VYS+@H@("`@("`@(&9O<F5A8V@@*"1A='1R<R!A<R`D:V5Y(#T^("1V86QU
M92D@>PH@("`@("`@("`@("`O+R!)9B!N<R!D96-L87)A=&EO;G,L(&%D9"!T
M;R!C;&%S<R!L979E;"!A<G)A>2!O9B!V86QI9`H@("`@("`@("`@("`O+R!N
M86UE<W!A8V5S+@H@("`@("`@("`@("`D:W%N(#TF(&YE=R!13F%M92@D:V5Y
M*3L*("`@("`@("`@("`@:68@*"1K<6XM/FYS(#T]("=X;6QN<R<I('L*("`@
M("`@("`@("`@("`@("1P<F5F:7@@/2`D:W%N+3YN86UE.PH*("`@("`@("`@
M("`@("`@(&EF("AI;E]A<G)A>2@D=F%L=64L("1T:&ES+3Y?6$U,4V-H96UA
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T4V-H96UA5F5R
M<VEO;B@D=F%L=64I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?;F%M97-P86-E<ULD=F%L=65=(#T@)'!R969I>#L*"B`@
M("`@("`@("`@("\O(%-E="!M971H;V0@;F%M97-P86-E+@H@("`@("`@("`@
M("!](&5L<V5I9B`H)&ME>2`]/2`G>&UL;G,G*2!["B`@("`@("`@("`@("`@
M("`D<6YA;64M/FYS(#T@)'1H:7,M/E]G971.86UE<W!A8V50<F5F:7@H)'9A
M;'5E*3L*("`@("`@("`@("`@("`@("1Q;F%M92T^;F%M97-P86-E(#T@)'9A
M;'5E.PH@("`@("`@("`@("!](&5L<V5I9B`H)&MQ;BT^;F%M92`]/2`G86-T
M;W(G*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG
M86-T;W(G72`]("1V86QU93L*("`@("`@("`@("`@?2!E;'-E:68@*"1K<6XM
M/FYA;64@/3T@)VUU<W15;F1E<G-T86YD)RD@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/FUE<W-A9V5;)'!O<UU;)VUU<W15;F1E<G-T86YD)UT@/2`D=F%L
M=64["@H@("`@("`@("`@("`O+R!)9B!I="=S(&$@='EP92!D96-L87)A=&EO
M;BP@<V5T('1Y<&4N"B`@("`@("`@("`@('T@96QS96EF("@D:W%N+3YN86UE
M(#T]("=T>7!E)RD@>PH@("`@("`@("`@("`@("`@)'9Q;B`])B!N97<@44YA
M;64H)'9A;'5E*3L*("`@("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1P
M;W-=6R=T>7!E)UT@/2`D=G%N+3YN86UE.PH@("`@("`@("`@("`@("`@)'1H
M:7,M/FUE<W-A9V5;)'!O<UU;)W1Y<&5?;F%M97-P86-E)UT@/2`D=&AI<RT^
M7V=E=$YA;65S<&%C949O<E!R969I>"@D=G%N+3YN<RD["B`@("`@("`@("`@
M("`@("`O+R!3:&]U;&0@9&\@<V]M971H:6YG(&AE<F4@=VET:"!T:&4@;F%M
M97-P86-E(&]F"B`@("`@("`@("`@("`@("`O+R!S<&5C:69I960@='EP93\*
M"B`@("`@("`@("`@('T@96QS96EF("@D:W%N+3YN86UE(#T]("=A<G)A>51Y
M<&4G*2!["B`@("`@("`@("`@("`@("`D=G%N(#TF(&YE=R!13F%M92@D=F%L
M=64I.PH@("`@("`@("`@("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)W1Y
M<&4G72`]("=!<G)A>2<["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'9Q
M;BT^87)R87E3:7IE*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM
M97-S86=E6R1P;W-=6R=A<G)A>5-I>F4G72`]("1V<6XM/F%R<F%Y4VEZ93L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3YM97-S
M86=E6R1P;W-=6R=A<G)A>51Y<&4G72`]("1V<6XM/FYA;64["@H@("`@("`@
M("`@("!](&5L<V5I9B`H)&MQ;BT^;F%M92`]/2`G;V9F<V5T)RD@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V%R<F%Y3V9F<V5T
M)UT@/2!S<&QI="@G+"<L('-U8G-T<B@D=F%L=64L(#$L('-T<FQE;B@D=F%L
M=64I("T@,BDI.PH*("`@("`@("`@("`@?2!E;'-E:68@*"1K<6XM/FYA;64@
M/3T@)VED)RD@>PH@("`@("`@("`@("`@("`@+R\@4V%V92!I9"!T;R!R969E
M<F5N8V4@87)R87DN"B`@("`@("`@("`@("`@("`D=&AI<RT^<F5F97)E;F-E
M<ULD=F%L=65=(#T@)'!O<SL*("`@("`@("`@("`@("`@("1T:&ES+3YM97-S
M86=E6R1P;W-=6R=I9"==(#T@)'9A;'5E.PH*("`@("`@("`@("`@?2!E;'-E
M:68@*"1K<6XM/FYA;64@/3T@)VAR968G*2!["B`@("`@("`@("`@("`@("!I
M9B`H)'9A;'5E6S!=(#T]("<C)RD@>PH@("`@("`@("`@("`@("`@("`@("1R
M968@/2!S=6)S='(H)'9A;'5E+"`Q*3L*("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/G)E9F5R96YC97-;)')E9ETI*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("\O(&-D871A+"!T>7!E+"!I;G9A;"X*("`@("`@
M("`@("`@("`@("`@("`@("`@)')E9E]P;W,@/2`D=&AI<RT^<F5F97)E;F-E
M<ULD<F5F73L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUE<W-A
M9V5;)'!O<UU;)V-H:6QD<F5N)UT@/2`F)'1H:7,M/FUE<W-A9V5;)')E9E]P
M;W-=6R=C:&EL9')E;B==.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^;65S<V%G95LD<&]S75LG8V1A=&$G72`]("8D=&AI<RT^;65S<V%G95LD
M<F5F7W!O<UU;)V-D871A)UT["B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YM97-S86=E6R1P;W-=6R=T>7!E)UT@/2`F)'1H:7,M/FUE<W-A9V5;
M)')E9E]P;W-=6R=T>7!E)UT["B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YM97-S86=E6R1P;W-=6R=A<G)A>5-I>F4G72`]("8D=&AI<RT^;65S
M<V%G95LD<F5F7W!O<UU;)V%R<F%Y4VEZ92==.PH@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG87)R87E4>7!E)UT@/2`F
M)'1H:7,M/FUE<W-A9V5;)')E9E]P;W-=6R=A<G)A>51Y<&4G73L*("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!2979E<G-E(')E9F5R96YC92P@<W1O<F4@:6X@)VYE960@<F5F97)E
M;F-E)RX*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^;F5E9%]R969E<F5N8V5S6R1R969=*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/FYE961?<F5F97)E;F-E<ULD<F5F72`](&%R
M<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/FYE961?<F5F97)E;F-E<ULD<F5F75M=(#T@
M)'!O<SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M(&5L<V5I9B`H:7-S970H)'1H:7,M/F%T=&%C:&UE;G1S6R1V86QU95TI*2![
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V-D
M871A)UT@/2`D=&AI<RT^871T86-H;65N='-;)'9A;'5E73L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`O+R!3
M964@:68@;F%M97-P86-E(&ES(&1E9FEN960@:6X@=&%G+@H@("`@("`@(&EF
M("AA<G)A>5]K97E?97AI<W1S*"=X;6QN<SHG("X@)'%N86UE+3YN<RP@)&%T
M=')S*2D@>PH@("`@("`@("`@("`D;F%M97-P86-E(#T@)&%T=')S6R=X;6QN
M<SHG("X@)'%N86UE+3YN<UT["B`@("`@("`@?2!E;'-E:68@*"1Q;F%M92T^
M;G,@)B8@(21Q;F%M92T^;F%M97-P86-E*2!["B`@("`@("`@("`@("1N86UE
M<W!A8V4@/2`D=&AI<RT^7V=E=$YA;65S<&%C949O<E!R969I>"@D<6YA;64M
M/FYS*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!'970@;F%M
M97-P86-E+@H@("`@("`@("`@("`D;F%M97-P86-E(#T@)'%N86UE+3YN86UE
M<W!A8V4@/R`D<6YA;64M/FYA;65S<&%C92`Z("1T:&ES+3YD969A=6QT7VYA
M;65S<&%C93L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O
M<UU;)VYA;65S<&%C92==(#T@)&YA;65S<&%C93L*("`@("`@("`D=&AI<RT^
M9&5F875L=%]N86UE<W!A8V4@/2`D;F%M97-P86-E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@96YD16QE;65N=`H@("`@("H@96YD+65L96UE;G0@:&%N9&QE
M<B!U<V5D('=I=&@@>&UL('!A<G-E<@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!E;F1%;&5M96YT*"1P87)S
M97(L("1N86UE*0H@("`@>PH@("`@("`@("\O(%!O<VET:6]N(&]F(&-U<G)E
M;G0@96QE;65N="!I<R!E<75A;"!T;R!T:&4@;&%S="!V86QU92!L969T"B`@
M("`@("`@+R\@:6X@9&5P=&A?87)R87D@9F]R(&UY(&1E<'1H+@H@("`@("`@
M("1P;W,@/2`D=&AI<RT^9&5P=&A?87)R87E;)'1H:7,M/F1E<'1H73L*"B`@
M("`@("`@+R\@0G)I;F<@9&5P=&@@9&]W;B!A(&YO=&-H+@H@("`@("`@("1T
M:&ES+3YD97!T:"TM.PH@("`@("`@("1Q;F%M92`])B!N97<@44YA;64H)&YA
M;64I.PH*("`@("`@("`O+R!'970@='EP92!I9B!N;W0@97AP;&EC:71L>2!D
M96-L87)E9"!I;B!A;B!X<VDZ='EP92!A='1R:6)U=&4N"B`@("`@("`@+R\@
M6%A8(&-H96-K(&]N(&EN=&5G<F%T:6YG('=S9&P@=F%L:61A=&EO;B!H97)E
M"B`@("`@("`@:68@*"1T:&ES+3YM97-S86=E6R1P;W-=6R=T>7!E)UT@/3T@
M)R<I('L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YM97-S86=E6R1P
M;W-=6R=C:&EL9')E;B==*2D@>PH@("`@("`@("`@("`@("`@+RH@=&AI<R!I
M<R!S;&]W+"!N965D('1O(&QO;VL@870@<V]M92!F87-T97(@;65T:&]D"B`@
M("`@("`@("`@("`@("`D8VAI;&1R96X@/2!E>'!L;V1E*"=\)RP@)'1H:7,M
M/FUE<W-A9V5;)'!O<UU;)V-H:6QD<F5N)UTI.PH@("`@("`@("`@("`@("`@
M:68@*&-O=6YT*"1C:&EL9')E;BD@/B`R("8F"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/FUE<W-A9V5;)&-H:6QD<F5N6S%=75LG;F%M92==(#T]("1T
M:&ES+3YM97-S86=E6R1C:&EL9')E;ELR75U;)VYA;64G72D@>PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=T>7!E)UT@/2`G
M07)R87DG.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG='EP92==(#T@)U-T<G5C
M="<["B`@("`@("`@("`@("`@("!]*B\*("`@("`@("`@("`@("`@("1T:&ES
M+3YM97-S86=E6R1P;W-=6R=T>7!E)UT@/2`G4W1R=6-T)SL*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1P87)E;G0@/2`D=&AI<RT^
M;65S<V%G95LD<&]S75LG<&%R96YT)UT["B`@("`@("`@("`@("`@("!I9B`H
M)'1H:7,M/FUE<W-A9V5;)'!A<F5N=%U;)W1Y<&4G72`]/2`G07)R87DG("8F
M"B`@("`@("`@("`@("`@("`@(&%R<F%Y7VME>5]E>&ES=',H)V%R<F%Y5'EP
M92<L("1T:&ES+3YM97-S86=E6R1P87)E;G1=*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=T>7!E)UT@/2`D=&AI<RT^
M;65S<V%G95LD<&%R96YT75LG87)R87E4>7!E)UT["B`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM97-S86=E
M6R1P;W-=6R=T>7!E)UT@/2`G<W1R:6YG)SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@268@=&%G('=E
M(&%R92!C=7)R96YT;'D@8VQO<VEN9R!I<R!T:&4@;65T:&]D('=R87!P97(N
M"B`@("`@("`@:68@*"1P;W,@/3T@)'1H:7,M/F-U<F5N=%]R;V]T7W-T<G5C
M="D@>PH@("`@("`@("`@("`D=&AI<RT^<W1A='5S(#T@)V)O9'DG.PH@("`@
M("`@('T@96QS96EF("@D<6YA;64M/FYA;64@/3T@)T)O9'DG('Q\("1Q;F%M
M92T^;F%M92`]/2`G2&5A9&5R)RD@>PH@("`@("`@("`@("`D=&AI<RT^<W1A
M='5S(#T@)V5N=F5L;W!E)SL*("`@("`@("!]"@H@("`@("`@("\O(%-E="!P
M87)E;G0@8F%C:R!T;R!M>2!P87)E;G0N"B`@("`@("`@)'1H:7,M/G!A<F5N
M="`]("1T:&ES+3YM97-S86=E6R1P;W-=6R=P87)E;G0G73L*"B`@("`@("`@
M+R\@2&%N9&QE(&%N>2!R979E<G-E(')E9F5R96YC97,@;F]W+@H@("`@("`@
M("1I9')E9B`]("1T:&ES+3YM97-S86=E6R1P;W-=6R=I9"==.PH*("`@("`@
M("!I9B`H)&ED<F5F("$]("<G("8F(&%R<F%Y7VME>5]E>&ES=',H)&ED<F5F
M+"`D=&AI<RT^;F5E9%]R969E<F5N8V5S*2D@>PH@("`@("`@("`@("!F;W)E
M86-H("@D=&AI<RT^;F5E9%]R969E<F5N8V5S6R1I9')E9ET@87,@)')E9E]P
M;W,I('L*("`@("`@("`@("`@("`@("\O(%A86"!I<R!T:&ES('-T=69F('1H
M97)E(&%L<F5A9'D_"B`@("`@("`@("`@("`@("`D=&AI<RT^;65S<V%G95LD
M<F5F7W!O<UU;)V-H:6QD<F5N)UT@/2`F)'1H:7,M/FUE<W-A9V5;)'!O<UU;
M)V-H:6QD<F5N)UT["B`@("`@("`@("`@("`@("`D=&AI<RT^;65S<V%G95LD
M<F5F7W!O<UU;)V-D871A)UT@/2`F)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V-D
M871A)UT["B`@("`@("`@("`@("`@("`D=&AI<RT^;65S<V%G95LD<F5F7W!O
M<UU;)W1Y<&4G72`]("8D=&AI<RT^;65S<V%G95LD<&]S75LG='EP92==.PH@
M("`@("`@("`@("`@("`@)'1H:7,M/FUE<W-A9V5;)')E9E]P;W-=6R=A<G)A
M>5-I>F4G72`]("8D=&AI<RT^;65S<V%G95LD<&]S75LG87)R87E3:7IE)UT[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^;65S<V%G95LD<F5F7W!O<UU;)V%R
M<F%Y5'EP92==(#T@)B1T:&ES+3YM97-S86=E6R1P;W-=6R=A<G)A>51Y<&4G
M73L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(&-H87)A8W1E<D1A=&$*("`@("`J(&5L96UE;G0@8V]N=&5N="!H86YD
M;&5R('5S960@=VET:"!X;6P@<&%R<V5R"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(&-H87)A8W1E<D1A=&$H
M)'!A<G-E<BP@)&1A=&$I"B`@("!["B`@("`@("`@)'!O<R`]("1T:&ES+3YD
M97!T:%]A<G)A>5LD=&AI<RT^9&5P=&A=.PH@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^;65S<V%G95LD<&]S75LG8V1A=&$G72DI('L*("`@("`@("`@("`@
M)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V-D871A)UT@+CT@)&1A=&$["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;
M)V-D871A)UT@/2`D9&%T83L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!G971297-P;VYS90H@("`@("H*("`@("`J(')E='5R;G,@86X@87)R
M87D@;V8@<F5S<&]N<V5S"B`@("`@*B!A9G1E<B!P87)S:6YG(&$@<V]A<"!M
M97-S86=E+"!U<V4@=&AI<R!T;R!G970@=&AE(')E<W!O;G-E"B`@("`@*@H@
M("`@("H@0')E='5R;B`@(&%R<F%Y"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("HO"B`@("!F=6YC=&EO;B`F9V5T4F5S<&]N<V4H*0H@("`@>PH@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^<F]O=%]S=')U8W1;,%TI("8F"B`@("`@
M("`@("`@("1T:&ES+3YR;V]T7W-T<G5C=%LP72D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/F)U:6QD4F5S<&]N<V4H)'1H:7,M/G)O;W1?<W1R=6-T
M6S!=*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53
M;V%P1F%U;'0H(F-O=6QD;B=T(&)U:6QD(')E<W!O;G-E(BD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!G971(96%D97)S"B`@("`@*@H@("`@("H@<F5T=7)N
M<R!A;B!A<G)A>2!O9B!H96%D97(@<F5S<&]N<V5S"B`@("`@*B!A9G1E<B!P
M87)S:6YG(&$@<V]A<"!M97-S86=E+"!U<V4@=&AI<R!T;R!G970@=&AE(')E
M<W!O;G-E"B`@("`@*@H@("`@("H@0')E='5R;B`@(&%R<F%Y"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T2&5A9&5R
M<R@I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YH96%D97)?<W1R
M=6-T6S!=*2`F)@H@("`@("`@("`@("`D=&AI<RT^:&5A9&5R7W-T<G5C=%LP
M72D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F)U:6QD4F5S<&]N<V4H
M)'1H:7,M/FAE861E<E]S=')U8W1;,%TI.PH@("`@("`@('T*"B`@("`@("`@
M+R\@5V4@9&]N)W0@9F%U;'0@:68@=&AE<F4@87)E(&YO(&AE861E<G,@=&AA
M="!C86X@8F4@:&%N9&QE9`H@("`@("`@("\O(&)Y('1H92!A<'`@:68@;F5C
M97-S87)Y+@H@("`@("`@(')E='5R;B!N=6QL.PH@("`@?0H*("`@("\J*@H@
M("`@("H@9&5C;V1E16YT:71I97,*("`@("`J"B`@("`@*B!R96UO=F5S(&5N
M=&ET:65S(&9R;VT@=&5X=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<*
M("`@("`J($!R971U<FX@("!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!F=6YC=&EO;B!D96-O9&5%;G1I=&EE<R@D=&5X="D*
M("`@('L*("`@("`@("`D=')A;G-?=&)L(#T@87)R87E?9FQI<"@D=&AI<RT^
M96YT:71I97,I.PH@("`@("`@(')E='5R;B!S=')T<B@D=&5X="P@)'1R86YS
M7W1B;"D["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!4"]397)V97(O````````````
M````````````````````````````````````````````````````````````
M````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T
M,S,W,S<`,#(P-C$W`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]33T%0
M+U-E<G9E<B]%;6%I;"YP:'``````````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`Q-C4Q-P`Q,#4Q-30S,S<S-P`P,C(S-S$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H:7,@
M9FEL92!C;VYT86EN<R!T:&4@8V]D92!F;W(@=&AE(&5M86EL(%-/05`@<V5R
M=F5R+@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%
M.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R
M(&]F('1H92!02%`@;&EC96YS92P*("H@=&AA="!I<R!B=6YD;&5D('=I=&@@
M=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R!A=F%I
M;&%B;&4@870*("H@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD
M(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET"B`J('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N
M;F5T('-O('=E(&-A;@H@*B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN
M"B`J"B`J($!C871E9V]R>2`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@
M("!33T%0"B`J($!A=71H;W(@("`@(%-H86YE($-A<F%V96\@/%-H86YE0$-A
M<F%V96\N8V]M/B`@(%!O<G0@=&\@4$5!4B!A;F0@;6]R90H@*B!`8V]P>7)I
M9VAT("`R,#`S+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="`@4$A0($QI8V5N
M<V4@,BXP,@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A
M8VMA9V4O4T]!4`H@*B\*"G)E<75I<F5?;VYC92`G4T]!4"]397)V97(N<&AP
M)SL*<F5Q=6ER95]O;F-E("=33T%0+T-L:65N="YP:'`G.PIR97%U:7)E7V]N
M8V4@)U-/05`O5')A;G-P;W)T+G!H<"<["G)E<75I<F5?;VYC92`G36%I;"]M
M:6UE1&5C;V1E+G!H<"<["@HO*BH*("H@4T]!4"!397)V97(@0VQA<W,@=&AA
M="!I;7!L96UE;G1S(&%N(&5M86EL(%-/05`@<V5R=F5R+@H@*B!H='1P.B\O
M=W=W+G!O8VME='-O87`N8V]M+W-P96-S+W-M='!B:6YD:6YG+PH@*@H@*B!4
M:&ES(&-L87-S(&]V97)R:61E<R!T:&4@9&5F875L="!(5%10('-E<G9E<BP@
M<')O=FED:6YG('1H92!A8FEL:71Y('1O"B`J('!A<G-E(&%N(&5M86EL(&UE
M<W-A9V4@86YD(&5X96-U=&4@4T]!4"!C86QL<RX@(%1H:7,@8VQA<W,@1$]%
M4R!.3U0@<&]P('1H90H@*B!M97-S86=E.R!T:&4@;65S<V%G92P@8V]M<&QE
M=&4@=VET:"!H96%D97)S+"!M=7-T(&)E('!A<W-E9"!I;B!A<R!A"B`J('!A
M<F%M971E<B!T;R!T:&4@<V5R=FEC92!F=6YC=&EO;B!C86QL+@H@*@H@*B!`
M86-C97-S("`@<'5B;&EC"B`J($!P86-K86=E("!33T%0"B`J($!A=71H;W(@
M("!3:&%N92!#87)A=F5O(#QS:&%N94!P:'`N;F5T/@H@*B\*8VQA<W,@4T]!
M4%]397)V97)?16UA:6P@97AT96YD<R!33T%07U-E<G9E<B!["@H@("`@=F%R
M("1H96%D97)S(#T@87)R87DH*3L*"B`@("!F=6YC=&EO;B!33T%07U-E<G9E
M<E]%;6%I;"@D<V5N9%]R97-P;VYS92`]('1R=64I"B`@("!["B`@("`@("`@
M<&%R96YT.CI33T%07U-E<G9E<B@I.PH@("`@("`@("1T:&ES+3YS96YD7W)E
M<W!O;G-E(#T@)'-E;F1?<F5S<&]N<V4["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!296UO=F5S($A45%`@:&5A9&5R<R!F<F]M(')E<W!O;G-E+@H@("`@("H*
M("`@("`J(%1/1$\Z('5S92!014%2(&5M86EL(&-L87-S97,*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5%;6%I;"@F)&1A=&$I"B`@("![
M"B`@("`@("`@:68@*'!R96=?;6%T8V@H(B]>*"XJ/RE<<C]<;EQR/UQN*"XJ
M*2]S(BP@)&1A=&$L("1M871C:"DI('L*"B`@("`@("`@("`@(&EF("AP<F5G
M7VUA=&-H7V%L;"@G+UXH+BH_*3I<<RLH+BHI)"]M)RP@)&UA=&-H6S%=+"`D
M;6%T8VAE<RDI('L*("`@("`@("`@("`@("`@("1H8R`](&-O=6YT*"1M871C
M:&5S6S!=*3L*("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1H
M8SL@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YH96%D97)S
M6W-T<G1O;&]W97(H)&UA=&-H97-;,5U;)&E=*5T@/2!T<FEM*"1M871C:&5S
M6S)=6R1I72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@(&EF("@A<W1R:7-T<B@D=&AI<RT^:&5A9&5R<ULG8V]N=&5N
M="UT>7!E)UTL("=T97AT+WAM;"<I*2!["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]R86ES95-O87!&875L="@G26YV86QI9"!#;VYT96YT(%1Y<&4G
M+"`G)RP@)R<L("=#;&EE;G0G*3L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("AS=')C
M87-E8VUP*"1T:&ES+3YH96%D97)S6R=C;VYT96YT+71R86YS9F5R+65N8V]D
M:6YG)UTL("=B87-E-C0G*3T],"D@>PH@("`@("`@("`@("`@("`@+RH@56YF
M;VQD(&QI;F5S+B`J+PH@("`@("`@("`@("`@("`@)&5N8W1E>'0@/2!P<F5G
M7W)E<&QA8V4H(B];7')\7&Y=+R(L("<G+"`D;6%T8VA;,ETI.PH@("`@("`@
M("`@("`@("`@)&1A=&$@/2!B87-E-C1?9&5C;V1E*"1E;F-T97AT*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1D871A(#T@)&UA
M=&-H6S)=.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!)9B!N;R!C
M;VYT96YT+"!R971U<FX@9F%L<V4N("HO"B`@("`@("`@("`@(')E='5R;B!S
M=')L96XH)'1H:7,M/G)E<75E<W0I(#X@,#L*("`@("`@("!]"@H@("`@("`@
M("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)TEN=F%L:60@16UA:6P@1F]R;6%T
M)RP@)R<L("<G+"`G0VQI96YT)RD["@H@("`@("`@(')E='5R;B!F86QS93L*
M("`@('T*"B`@("!F=6YC=&EO;B!C;&EE;G0H)B1D871A*0H@("`@>PH@("`@
M("`@("1A='1A8VAM96YT<R`](&%R<F%Y*"D["@H@("`@("`@("\J($EF(&YE
M:71H97(@;6%T8VAE<RP@=V4G;&P@:G5S="!T<GD@:70@86YY=V%Y+B`J+PH@
M("`@("`@(&EF("AS=')I<W1R*"1D871A+"`G0V]N=&5N="U4>7!E.B!A<'!L
M:6-A=&EO;B]D:6UE)RDI('L*("`@("`@("`@("`@)'1H:7,M/E]D96-O9&5$
M24U%365S<V%G92@D9&%T82P@)'1H:7,M/FAE861E<G,L("1A='1A8VAM96YT
M<RD["B`@("`@("`@("`@("1U<V5%;F-O9&EN9R`]("=$24U%)SL*("`@("`@
M("!](&5L<V5I9B`H<W1R:7-T<B@D9&%T82P@)TU)344M5F5R<VEO;CHG*2D@
M>PH@("`@("`@("`@("`O*B!4:&ES(&ES(&$@;6EM92!M97-S86=E+"!L970G
M<R!D96-O9&4@:70N("HO"B`@("`@("`@("`@("1T:&ES+3Y?9&5C;V1E36EM
M94UE<W-A9V4H)&1A=&$L("1T:&ES+3YH96%D97)S+"`D871T86-H;65N=',I
M.PH@("`@("`@("`@("`D=7-E16YC;V1I;F<@/2`G36EM92<["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@+RH@5&AE(&]L9"!F86QL8F%C:RP@8G5T
M(&1E8V]D94UI;65-97-S86=E(&AA;F1L97,@=&AI;F=S(&9I;F4N("HO"B`@
M("`@("`@("`@("1T:&ES+3Y?<&%R<V5%;6%I;"@D9&%T82D["B`@("`@("`@
M?0H*("`@("`@("`O*B!'970@=&AE(&-H87)A8W1E<B!E;F-O9&EN9R!O9B!T
M:&4@:6YC;VUI;F<@<F5Q=65S="!T<F5A="!I;F-O;6EN9PH@("`@("`@("`J
M(&1A=&$@87,@551&+3@@:68@;F\@96YC;V1I;F<@<V5T+B`J+PH@("`@("`@
M(&EF("@A)'1H:7,M/G-O87!F875L="`F)@H@("`@("`@("`@("`A)'1H:7,M
M/E]G971#;VYT96YT16YC;V1I;F<H)'1H:7,M/FAE861E<G-;)V-O;G1E;G0M
M='EP92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^>&UL7V5N8V]D:6YG(#T@
M4T]!4%]$149!54Q47T5.0T]$24Y'.PH@("`@("`@("`@("`O*B!!;B!E;F-O
M9&EN9R!W92!D;VXG="!U;F1E<G-T86YD+"!R971U<FX@82!F875L="X@*B\*
M("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@G56YS=7!P;W)T
M960@96YC;V1I;F<L('5S92!O;F4@;V8@25-/+3@X-3DM,2P@55,M05-#24DL
M(%541BTX)RP@)R<L("<G+"`G4V5R=F5R)RD["B`@("`@("`@?0H*("`@("`@
M("!I9B`H)'1H:7,M/G-O87!F875L="D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G-O87!F875L="T^9V5T1F%U;'0H*3L*("`@("`@("!]"@H@("`@
M("`@("1C;&EE;G0@/28@;F5W(%-/05!?0VQI96YT*&YU;&PI.PH*("`@("`@
M("!R971U<FX@)&-L:65N="T^7U]P87)S92@D9&%T82P@)'1H:7,M/GAM;%]E
M;F-O9&EN9RP@)'1H:7,M/F%T=&%C:&UE;G1S*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!S97)V:6-E*"8D9&%T82P@)&5N9'!O:6YT(#T@)R<L("1S96YD7W)E
M<W!O;G-E(#T@=')U92P*("`@("`@("`@("`@("`@("`@("`@)&1U;7`@/2!F
M86QS92D*("`@('L*("`@("`@("`D=&AI<RT^96YD<&]I;G0@/2`D96YD<&]I
M;G0["B`@("`@("`@)&%T=&%C:&UE;G1S(#T@87)R87DH*3L*("`@("`@("`D
M:&5A9&5R<R`](&%R<F%Y*"D["@H@("`@("`@("\J($EF(&YE:71H97(@;6%T
M8VAE<RP@=V4G;&P@:G5S="!T<GD@:70@86YY=V%Y+B`J+PH@("`@("`@(&EF
M("AS=')I<W1R*"1D871A+"`G0V]N=&5N="U4>7!E.B!A<'!L:6-A=&EO;B]D
M:6UE)RDI('L*("`@("`@("`@("`@)'1H:7,M/E]D96-O9&5$24U%365S<V%G
M92@D9&%T82P@)'1H:7,M/FAE861E<G,L("1A='1A8VAM96YT<RD["B`@("`@
M("`@("`@("1U<V5%;F-O9&EN9R`]("=$24U%)SL*("`@("`@("!](&5L<V5I
M9B`H<W1R:7-T<B@D9&%T82P@)TU)344M5F5R<VEO;CHG*2D@>PH@("`@("`@
M("`@("`O*B!4:&ES(&ES(&$@;6EM92!M97-S86=E+"!L970G<R!D96-O9&4@
M:70N("HO"B`@("`@("`@("`@("1T:&ES+3Y?9&5C;V1E36EM94UE<W-A9V4H
M)&1A=&$L("1T:&ES+3YH96%D97)S+"`D871T86-H;65N=',I.PH@("`@("`@
M("`@("`D=7-E16YC;V1I;F<@/2`G36EM92<["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@+RH@5&AE(&]L9"!F86QL8F%C:RP@8G5T(&1E8V]D94UI
M;65-97-S86=E(&AA;F1L97,@=&AI;F=S(&9I;F4N("HO"B`@("`@("`@("`@
M("1T:&ES+3Y?<&%R<V5%;6%I;"@D9&%T82D["B`@("`@("`@?0H*("`@("`@
M("`O*B!'970@=&AE(&-H87)A8W1E<B!E;F-O9&EN9R!O9B!T:&4@:6YC;VUI
M;F<@<F5Q=65S="!T<F5A="!I;F-O;6EN9PH@("`@("`@("`J(&1A=&$@87,@
M551&+3@@:68@;F\@96YC;V1I;F<@<V5T+B`J+PH@("`@("`@(&EF("@A)')E
M<W!O;G-E("8F"B`@("`@("`@("`@("$D=&AI<RT^7V=E=$-O;G1E;G1%;F-O
M9&EN9R@D=&AI<RT^:&5A9&5R<ULG8V]N=&5N="UT>7!E)UTI*2!["B`@("`@
M("`@("`@("1T:&ES+3YX;6Q?96YC;V1I;F<@/2!33T%07T1%1D%53%1?14Y#
M3T1)3D<["B`@("`@("`@("`@("\J($%N(&5N8V]D:6YG('=E(&1O;B=T('5N
M9&5R<W1A;F0L(')E='5R;B!A(&9A=6QT+B`J+PH@("`@("`@("`@("`D=&AI
M<RT^7W)A:7-E4V]A<$9A=6QT*"=5;G-U<'!O<G1E9"!E;F-O9&EN9RP@=7-E
M(&]N92!O9B!)4T\M.#@U.2TQ+"!54RU!4T-)22P@551&+3@G+"`G)RP@)R<L
M("=397)V97(G*3L*("`@("`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/F=E
M=$9A=6QT365S<V%G92@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES
M+3YS;V%P9F%U;'0I('L*("`@("`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M
M/G-O87!F875L="T^;65S<V%G92@I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1S;V%P7VUS9R`]("1T:&ES+3YP87)S95)E<75E<W0H)&1A=&$L
M)&%T=&%C:&UE;G1S*3L*"B`@("`@("`@("`@("\J($AA;F1L92!-:6UE(&]R
M($1)344@96YC;V1I;F<N("HO"B`@("`@("`@("`@("\J(%1/1$\Z($1)344@
M16YC;V1I;F<@<VAO=6QD(&UO=F4@=&\@=&AE('1R86YS<&]R="P@9&\@:70@
M:&5R90H@("`@("`@("`@("`@*B!F;W(@;F]W(&%N9"!F;W(@96%S92!O9B!G
M971T:6YG(&ET(&1O;F4N("HO"B`@("`@("`@("`@(&EF("AC;W5N="@D=&AI
M<RT^7U]A='1A8VAM96YT<RDI('L*("`@("`@("`@("`@("`@(&EF("@D=7-E
M16YC;V1I;F<@/3T@)TUI;64G*2!["B`@("`@("`@("`@("`@("`@("`@)'-O
M87!?;7-G(#T@)'1H:7,M/E]M86ME36EM94UE<W-A9V4H)'-O87!?;7-G*3L*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M+RH@1&5F875L="!I<R!$24U%+B`J+PH@("`@("`@("`@("`@("`@("`@("1S
M;V%P7VUS9R`]("1T:&ES+3Y?;6%K941)345-97-S86=E*"1S;V%P7VUS9RD[
M"B`@("`@("`@("`@("`@("`@("`@)&AE861E<ELG0V]N=&5N="U4>7!E)UT@
M/2`G87!P;&EC871I;VXO9&EM92<["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<V]A<%]M<V<I*2!["B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES95-O87!&875L
M="@D<V]A<%]M<V<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!I9B`H:7-?87)R87DH)'-O87!?;7-G*2D@>PH@("`@
M("`@("`@("`@("`@)')E<W!O;G-E(#T@)'-O87!?;7-G6R=B;V1Y)UT["B`@
M("`@("`@("`@("`@("!I9B`H8V]U;G0H)'-O87!?;7-G6R=H96%D97)S)UTI
M*2!["B`@("`@("`@("`@("`@("`@("`@)&AE861E<G,@/2`D<V]A<%]M<V=;
M)VAE861E<G,G73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1R97-P;VYS92`]("1S;V%P7VUS9SL*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3YS
M96YD7W)E<W!O;G-E*2!["B`@("`@("`@("`@(&EF("@D9'5M<"D@>PH@("`@
M("`@("`@("`@("`@<')I;G0@)')E<W!O;G-E.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)&9R;VT@/2!A<G)A>5]K97E?97AI<W1S
M*"=R97!L>2UT;R<L("1T:&ES+3YH96%D97)S*2`_("1T:&ES+3YH96%D97)S
M6R=R97!L>2UT;R==(#H@)'1H:7,M/FAE861E<G-;)V9R;VTG73L*"B`@("`@
M("`@("`@("`@("`D<V]A<%]T<F%N<W!O<G0@/28@4T]!4%]4<F%N<W!O<G0Z
M.F=E=%1R86YS<&]R="@G;6%I;'1O.B<@+B`D9G)O;2P@)'1H:7,M/G)E<W!O
M;G-E7V5N8V]D:6YG*3L*("`@("`@("`@("`@("`@("1F<F]M(#T@)'1H:7,M
M/F5N9'!O:6YT(#\@)'1H:7,M/F5N9'!O:6YT(#H@)'1H:7,M/FAE861E<G-;
M)W1O)UT["B`@("`@("`@("`@("`@("`D:&5A9&5R<ULG26XM4F5P;'DM5&\G
M72`]("1T:&ES+3YH96%D97)S6R=M97-S86=E+6ED)UT["B`@("`@("`@("`@
M("`@("`D;W!T:6]N<R`](&%R<F%Y*"=F<F]M)R`]/B`D9G)O;2P@)W-U8FIE
M8W0G(#T^("1T:&ES+3YH96%D97)S6R=S=6)J96-T)UTL("=H96%D97)S)R`]
M/B`D:&5A9&5R<RD["B`@("`@("`@("`@("`@("`D<V]A<%]T<F%N<W!O<G0M
M/G-E;F0H)')E<W!O;G-E+"`D;W!T:6]N<RD["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-/
M05`O4V5R=F5R+T5M86EL7T=A=&5W87DN<&AP````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#$R-34V`#$P-3$U-#,S-S,W`#`R-#`U,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@5&AI
M<R!F:6QE(&-O;G1A:6YS('1H92!C;V1E(&9O<B!T:&4@96UA:6PM2%144"!3
M3T%0(&=A=&5W87D@<V5R=F5R+@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@
M-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@
M=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P*("H@=&AA="!I
M<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.
M4T4L(&%N9"!I<R!A=F%I;&%B;&4@870*("H@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT
M>'0N("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@
M4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET"B`J('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@
M=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;@H@*B!M86EL('EO=2!A(&-O
M<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@(%=E8B!397)V:6-E
M<PH@*B!`<&%C:V%G92`@("!33T%0"B`J($!A=71H;W(@("`@(%-H86YE($-A
M<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@(%!O<G0@=&\@4$5!4B!A;F0@
M;6]R90H@*B!`8V]P>7)I9VAT("`R,#`S+3(P,#4@5&AE(%!(4"!'<F]U<`H@
M*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R
M+G1X="`@4$A0($QI8V5N<V4@,BXP,@H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O4T]!4`H@*B\*"G)E<75I<F5?;VYC92`G
M4T]!4"]397)V97(O16UA:6PN<&AP)SL*<F5Q=6ER95]O;F-E("=33T%0+U1R
M86YS<&]R="YP:'`G.PH*+RHJ"B`J(%-/05`@4V5R=F5R($-L87-S('1H870@
M:6UP;&5M96YT<R!A;B!E;6%I;"!33T%0('-E<G9E<BX*("H@:'1T<#HO+W=W
M=RYP;V-K971S;V%P+F-O;2]S<&5C<R]S;71P8FEN9&EN9R\*("H*("H@5&AI
M<R!C;&%S<R!O=F5R<FED97,@=&AE(&1E9F%U;'0@2%144"!S97)V97(L('!R
M;W9I9&EN9R!T:&4@86)I;&ET>2!T;PH@*B!P87)S92!A;B!E;6%I;"!M97-S
M86=E(&%N9"!E>&5C=71E('-O87`@8V%L;',N("!4:&ES(&-L87-S($1/15,@
M3D]4('!O<"!T:&4*("H@;65S<V%G93L@=&AE(&UE<W-A9V4L(&-O;7!L971E
M('=I=&@@:&5A9&5R<RP@;75S="!B92!P87-S960@:6X@87,@80H@*B!P87)A
M;65T97(@=&\@=&AE('-E<G9I8V4@9G5N8W1I;VX@8V%L;"X*("H*("H@5&AI
M<R!C;&%S<R!C86QL<R!A('!R;W9I9&5D($A45%`@4T]!4"!S97)V97(L(&9O
M<G=A<F1I;F<@=&AE(&5M86EL(')E<75E<W0L"B`J('1H96X@<V5N9&EN9R!T
M:&4@2%144"!R97-P;VYS92!O=70@87,@86X@96UA:6PN"B`J"B`J($!A8V-E
M<W,@("!P=6)L:6,*("H@0'!A8VMA9V4@(%-/05`*("H@0&%U=&AO<B`@(%-H
M86YE($-A<F%V96\@/'-H86YE0'!H<"YN970^"B`J+PIC;&%S<R!33T%07U-E
M<G9E<E]%;6%I;%]'871E=V%Y(&5X=&5N9',@4T]!4%]397)V97)?16UA:6P@
M>PH*("`@('9A<B`D9V%T97=A>2`](&YU;&P["B`@("!V87(@)&1U;7`@/2!F
M86QS93L*"B`@("!F=6YC=&EO;B!33T%07U-E<G9E<E]%;6%I;%]'871E=V%Y
M*"1G871E=V%Y(#T@)R<L("1S96YD7W)E<W!O;G-E(#T@=')U92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1U;7`@/2!F86QS
M92D*("`@('L*("`@("`@("!P87)E;G0Z.E-/05!?4V5R=F5R*"D["B`@("`@
M("`@)'1H:7,M/G-E;F1?<F5S<&]N<V4@/2`D<V5N9%]R97-P;VYS93L*("`@
M("`@("`D=&AI<RT^9V%T97=A>2`]("1G871E=V%Y.PH@("`@("`@("1T:&ES
M+3YD=6UP(#T@)&1U;7`["B`@("!]"@H@("`@9G5N8W1I;VX@<V5R=FEC92@F
M)&1A=&$L("1G871E=V%Y(#T@)R<L("1E;F1P;VEN="`]("<G+`H@("`@("`@
M("`@("`@("`@("`@("`D<V5N9%]R97-P;VYS92`]('1R=64L("1D=6UP(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M/F5N9'!O:6YT(#T@)&5N9'!O
M:6YT.PH@("`@("`@("1R97-P;VYS92`]("<G.PH@("`@("`@("1U<V5%;F-O
M9&EN9R`]("=-:6UE)SL*("`@("`@("`D;W!T:6]N<R`](&%R<F%Y*"D["B`@
M("`@("`@:68@*"$D9V%T97=A>2D@>PH@("`@("`@("`@("`D9V%T97=A>2`]
M("1T:&ES+3YG871E=V%Y.PH@("`@("`@('T*"B`@("`@("`@+RH@5V4@:&%V
M92!A(&9U;&P@<V5T(&]F(&AE861E<G,L(&YE960@=&\@9FEN9"!T:&4@9FER
M<W0@8FQA;FL*("`@("`@("`@*B!L:6YE+B`J+PH@("`@("`@("1T:&ES+3Y?
M<&%R<V5%;6%I;"@D9&%T82D["B`@("`@("`@:68@*"1T:&ES+3YF875L="D@
M>PH@("`@("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^9F%U;'0M/FUE<W-A
M9V4H*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YH96%D97)S6R=C
M;VYT96YT+71Y<&4G72`]/2`G87!P;&EC871I;VXO9&EM92<I"B`@("`@("`@
M("`@("1U<V5%;F-O9&EN9R`]("=$24U%)SL*"B`@("`@("`@+RH@0V%L;"!T
M:&4@2%144"!397)V97(N("HO"B`@("`@("`@:68@*"$D<F5S<&]N<V4I('L*
M("`@("`@("`@("`@)'-O87!?=')A;G-P;W)T(#TF(%-/05!?5')A;G-P;W)T
M.CIG9714<F%N<W!O<G0H)&=A=&5W87DL("1T:&ES+3YX;6Q?96YC;V1I;F<I
M.PH@("`@("`@("`@("!I9B`H)'-O87!?=')A;G-P;W)T+3YF875L="D@>PH@
M("`@("`@("`@("`@("`@)')E<W!O;G-E(#T@)'-O87!?=')A;G-P;W)T+3YF
M875L="T^;65S<V%G92@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`O*B!396YD('1H92!M97-S86=E+B`J+PH@("`@("`@(&EF("@A)')E
M<W!O;G-E*2!["B`@("`@("`@("`@("1O<'1I;VYS6R=S;V%P86-T:6]N)UT@
M/2`D=&AI<RT^:&5A9&5R<ULG<V]A<&%C=&EO;B==.PH@("`@("`@("`@("`D
M;W!T:6]N<ULG:&5A9&5R<R==6R=#;VYT96YT+51Y<&4G72`]("1T:&ES+3YH
M96%D97)S6R=C;VYT96YT+71Y<&4G73L*"B`@("`@("`@("`@("1R97-P;VYS
M92`]("1S;V%P7W1R86YS<&]R="T^<V5N9"@D9&%T82P@)&]P=&EO;G,I.PH@
M("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/FAE861E<G-;)VUI;64M=F5R
M<VEO;B==*2D*("`@("`@("`@("`@("`@("1O<'1I;VYS6R=H96%D97)S)UU;
M)TU)344M5F5R<VEO;B==(#T@)'1H:7,M/FAE861E<G-;)VUI;64M=F5R<VEO
M;B==.PH*("`@("`@("`@("`@:68@*"1S;V%P7W1R86YS<&]R="T^9F%U;'0I
M('L*("`@("`@("`@("`@("`@("1R97-P;VYS92`]("1S;V%P7W1R86YS<&]R
M="T^9F%U;'0M/FUE<W-A9V4H*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1S;V%P7W1R86YS<&]R="T^=')A;G-P
M;W)T+3YA='1A8VAM96YT<R!A<R`D8VED(#T^("1B;V1Y*2!["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F%T=&%C:&UE;G1S6UT@/2!A<G)A>2@G8F]D
M>2<@/3X@)&)O9'DL("=C:60G(#T^("1C:60L("=E;F-O9&EN9R<@/3X@)V)A
M<V4V-"<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@
M*&-O=6YT*"1T:&ES+3Y?7V%T=&%C:&UE;G1S*2D@>PH@("`@("`@("`@("`@
M("`@("`@(&EF("@D=7-E16YC;V1I;F<@/3T@)TUI;64G*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1S;V%P7VUS9R`]("1T:&ES+3Y?;6%K94UI;65-
M97-S86=E*"1R97-P;VYS92D["B`@("`@("`@("`@("`@("`@("`@("`@("1O
M<'1I;VYS6R=H96%D97)S)UU;)TU)344M5F5R<VEO;B==(#T@)S$N,"<["B`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`@("`@+RH@1&5F875L="!I<R!$24U%+B`J+PH@("`@("`@("`@("`@("`@
M("`@("`@("`D<V]A<%]M<V<@/2`D=&AI<RT^7VUA:V5$24U%365S<V%G92@D
M<F5S<&]N<V4I.PH@("`@("`@("`@("`@("`@("`@("`@("`D;W!T:6]N<ULG
M:&5A9&5R<R==6R=#;VYT96YT+51Y<&4G72`]("=A<'!L:6-A=&EO;B]D:6UE
M)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)'-O87!?;7-G*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@D<V]A
M<%]M<V<I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-?87)R87DH)'-O87!?;7-G*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D<F5S<&]N<V4@/2`D<V]A<%]M<V=;)V)O9'DG73L*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1S;V%P7VUS9ULG:&5A
M9&5R<R==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1O<'1I;VYS6R=H96%D97)S)UTI*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&]P=&EO;G-;)VAE861E<G,G72`](&%R<F%Y7VUE
M<F=E*"1O<'1I;VYS6R=H96%D97)S)UTL("1S;V%P7VUS9ULG:&5A9&5R<R==
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&]P=&EO;G-;)VAE861E<G,G
M72`]("1S;V%P7VUS9ULG:&5A9&5R<R==.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/G-E;F1?<F5S<&]N<V4I
M('L*("`@("`@("`@("`@:68@*"1T:&ES+3YD=6UP('Q\("1D=6UP*2!["B`@
M("`@("`@("`@("`@("!P<FEN="`D<F5S<&]N<V4["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D9G)O;2`](&%R<F%Y7VME>5]E>&ES
M=',H)W)E<&QY+71O)RP@)'1H:7,M/FAE861E<G,I(#\@)'1H:7,M/FAE861E
M<G-;)W)E<&QY+71O)UT@.B`D=&AI<RT^:&5A9&5R<ULG9G)O;2==.PH*("`@
M("`@("`@("`@("`@("1S;V%P7W1R86YS<&]R="`])B!33T%07U1R86YS<&]R
M=#HZ9V5T5')A;G-P;W)T*"=M86EL=&\Z)R`N("1F<F]M+"`D=&AI<RT^<F5S
M<&]N<V5?96YC;V1I;F<I.PH@("`@("`@("`@("`@("`@)&9R;VT@/2`D=&AI
M<RT^96YD<&]I;G0@/R`D=&AI<RT^96YD<&]I;G0@.B`D=&AI<RT^:&5A9&5R
M<ULG=&\G73L*("`@("`@("`@("`@("`@("1H96%D97)S(#T@87)R87DH)TEN
M+5)E<&QY+51O)R`]/B`D=&AI<RT^:&5A9&5R<ULG;65S<V%G92UI9"==*3L*
M("`@("`@("`@("`@("`@("1O<'1I;VYS(#T@87)R87DH)V9R;VTG(#T^("1F
M<F]M+"`G<W5B:F5C="<]/B`D=&AI<RT^:&5A9&5R<ULG<W5B:F5C="==+"`G
M:&5A9&5R<R<@/3X@)&AE861E<G,I.PH@("`@("`@("`@("`@("`@)'-O87!?
M=')A;G-P;W)T+3YS96YD*"1R97-P;VYS92P@)&]P=&EO;G,I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@?0I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+U-/05`O4V5R=F5R+U1#4"YP:'``````
M````````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-S$U`#$P-3$U-#,S
M-S,W`#`R,3<V-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&AI<R!F:6QE(&-O;G1A:6YS('1H92!C
M;V1E(&9O<B!T:&4@5$-0(%-/05`@<V5R=F5R+@H@*@H@*B!02%`@=F5R<VEO
M;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P*
M("H@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F
M:6QE($Q)0T5.4T4L(&%N9"!I<R!A=F%I;&%B;&4@870*("H@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,E\P,BYT>'0N("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E(&$@8V]P
M>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN
M(&ET"B`J('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N
M9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;@H@*B!M86EL
M('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@(%=E
M8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("!33T%0"B`J($!A=71H;W(@("`@
M(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@(%!O<G0@=&\@
M4$5!4B!A;F0@;6]R90H@*B!`8V]P>7)I9VAT("`R,#`S+3(P,#4@5&AE(%!(
M4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\R7S`R+G1X="`@4$A0($QI8V5N<V4@,BXP,@H@*B!`;&EN:R`@("`@
M("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4T]!4`H@*B\*"G)E<75I
M<F5?;VYC92`G4T]!4"]397)V97(N<&AP)SL*"B\J*@H@*B!33T%0(%-E<G9E
M<B!#;&%S<R!T:&%T(&EM<&QE;65N=',@82!40U`@4T]!4"!397)V97(N"B`J
M(&AT='`Z+R]W=W<N<&]C:V5T<V]A<"YC;VTO<W!E8W,O<VUT<&)I;F1I;F<O
M"B`J"B`J(%1H:7,@8VQA<W,@;W9E<G)I9&5S('1H92!D969A=6QT($A45%`@
M<V5R=F5R+"!P<F]V:61I;F<@=&AE(&%B:6QI='D@=&\*("H@86-C97!T('-O
M8VME="!C;VYN96-T:6]N<R!A;F0@97AE8W5T92!33T%0(&-A;&QS+@H@*@H@
M*B!43T1/.@H@*B`@('5S92!.971?4V]C:V5T"B`J("`@:6UP;&5M96YT('-O
M;64@<V5C=7)I='D@<V-H96UE"B`J("`@:6UP;&5M96YT('-U<'!O<G0@9F]R
M(&%T=&%C:&UE;G1S"B`J"B`J($!A8V-E<W,@("!P=6)L:6,*("H@0'!A8VMA
M9V4@(%-/05`*("H@0&%U=&AO<B`@(%-H86YE($-A<F%V96\@/'-H86YE0'!H
M<"YN970^"B`J+PIC;&%S<R!33T%07U-E<G9E<E]40U`@97AT96YD<R!33T%0
M7U-E<G9E<B!["@H@("`@=F%R("1H96%D97)S(#T@87)R87DH*3L*("`@('9A
M<B`D;&]C86QA9&1R.PH@("`@=F%R("1P;W)T.PH@("`@=F%R("1L:7-T96X[
M"B`@("!V87(@)')E=7-E.PH*("`@(&9U;F-T:6]N(%-/05!?4V5R=F5R7U1#
M4"@D;&]C86QA9&1R(#T@)S$R-RXP+C`N,2<L("1P;W)T(#T@,3`P,#`L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&QI<W1E;B`](#4L("1R975S
M92`]('1R=64I"B`@("!["B`@("`@("`@<&%R96YT.CI33T%07U-E<G9E<B@I
M.PH@("`@("`@("1T:&ES+3YL;V-A;&%D9'(@/2`D;&]C86QA9&1R.PH@("`@
M("`@("1T:&ES+3YP;W)T(#T@)'!O<G0["B`@("`@("`@)'1H:7,M/FQI<W1E
M;B`]("1L:7-T96X["B`@("`@("`@)'1H:7,M/G)E=7-E(#T@)')E=7-E.PH@
M("`@?0H*("`@(&9U;F-T:6]N(')U;B@I"B`@("!["B`@("`@("`@:68@*"@D
M<V]C:R`]('-O8VME=%]C<F5A=&4H049?24Y%5"P@4T]#2U]35%)%04TL(#`I
M*2`\(#`I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P
M1F%U;'0H)W-O8VME=%]C<F5A=&4H*2!F86EL960N(%)E87-O;CH@)R`N('-O
M8VME=%]S=')E<G)O<B@D<V]C:RDI.PH@("`@("`@('T*("`@("`@("!I9B`H
M)'1H:7,M/G)E=7-E("8F"B`@("`@("`@("`@("%`<V]C:V5T7W-E=&]P="@D
M<V]C:RP@4T],7U-/0TM%5"P@4T]?4D554T5!1$12+"`Q*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@G<V]C:V5T7W-E
M=&]P="@I(&9A:6QE9"X@4F5A<V]N.B`G("X@<V]C:V5T7W-T<F5R<F]R*'-O
M8VME=%]L87-T7V5R<F]R*"1S;V-K*2DI.PH@("`@("`@('T*("`@("`@("!I
M9B`H*"1R970@/2!S;V-K971?8FEN9"@D<V]C:RP@)'1H:7,M/FQO8V%L861D
M<BP@)'1H:7,M/G!O<G0I*2`\(#`I('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<F%I<V53;V%P1F%U;'0H)W-O8VME=%]B:6YD*"D@9F%I;&5D+B!2
M96%S;VXZ("<@+B!S;V-K971?<W1R97)R;W(H)')E="DI.PH@("`@("`@('T*
M("`@("`@("!I9B`H*"1R970@/2!S;V-K971?;&ES=&5N*"1S;V-K+"`D=&AI
M<RT^;&ES=&5N*2D@/"`P*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7W)A:7-E4V]A<$9A=6QT*"=S;V-K971?;&ES=&5N*"D@9F%I;&5D+B!296%S
M;VXZ("<@+B!S;V-K971?<W1R97)R;W(H)')E="DI.PH@("`@("`@('T*"B`@
M("`@("`@=VAI;&4@*'1R=64I('L*("`@("`@("`@("`@)&1A=&$@/2!N=6QL
M.PH@("`@("`@("`@("!I9B`H*"1M<V=S;V-K(#T@<V]C:V5T7V%C8V5P="@D
M<V]C:RDI(#P@,"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O
M87!&875L="@G<V]C:V5T7V%C8V5P="@I(&9A:6QE9"X@4F5A<V]N.B`G("X@
M<V]C:V5T7W-T<F5R<F]R*"1M<V=S;V-K*2D["B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!W:&EL92`H)&)U9B`]
M('-O8VME=%]R96%D*"1M<V=S;V-K+"`X,3DR*2D@>PH@("`@("`@("`@("`@
M("`@:68@*"$D8G5F(#T@=')I;2@D8G5F*2D@>PH@("`@("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)&1A=&$@+CT@)&)U9CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M:68@*"1D871A*2!["B`@("`@("`@("`@("`@("`D<F5S<&]N<V4@/2`D=&AI
M<RT^<V5R=FEC92@D9&%T82D["B`@("`@("`@("`@("`@("`O*B!7<FET92!T
M;R!T:&4@<V]C:V5T+B`J+PH@("`@("`@("`@("`@("`@:68@*"%S;V-K971?
M=W)I=&4H)&US9W-O8VLL("1R97-P;VYS92P@<W1R;&5N*"1R97-P;VYS92DI
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53
M;V%P1F%U;'0H)T5R<F]R('-E;F1I;F<@<F5S<&]N<V4@9&%T82!R96%S;VX@
M)R`N('-O8VME=%]S=')E<G)O<B@I*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@<V]C:V5T7V-L;W-E("@D;7-G<V]C
M:RD["B`@("`@("`@?0H*("`@("`@("!S;V-K971?8VQO<V4@*"1S;V-K*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!S97)V:6-E*"8D9&%T82D*("`@('L*("`@
M("`@("`O*B!43T1/.B!W92!N965D('1O(&AA;F1L92!A='1A8VAM96YT<R!S
M;VUE:&]W+B`J+PH@("`@("`@(')E='5R;B`D=&AI<RT^<&%R<V5297%U97-T
M*"1D871A+"`D871T86-H;65N=',I.PH@("`@?0I]"@``````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]33T%0+U-E<G9E<BYP:'``````````
M````````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`W,#<S,P`Q,#4Q-30S
M,S<S-P`P,C$S-#(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J(%1H:7,@9FEL92!C;VYT86EN<R!T:&4@
M8V]D92!F;W(@=&AE(%-/05`@<V5R=F5R+@H@*@H@*B!02%`@=F5R<VEO;G,@
M-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U
M8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P*("H@
M=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE
M($Q)0T5.4T4L(&%N9"!I<R!A=F%I;&%B;&4@870*("H@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(@870@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,E\P,BYT>'0N("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O
M9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET
M"B`J('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A
M(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;@H@*B!M86EL('EO
M=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@(%=E8B!3
M97)V:6-E<PH@*B!`<&%C:V%G92`@("!33T%0"B`J($!A=71H;W(@("`@($1I
M971R:6-H($%Y86QA(#QD:65T<FEC:$!G86YX-"YC;VT^($]R:6=I;F%L($%U
M=&AO<@H@*B!`875T:&]R("`@("!3:&%N92!#87)A=F5O(#Q3:&%N94!#87)A
M=F5O+F-O;3X@("!0;W)T('1O(%!%05(@86YD(&UO<F4*("H@0&%U=&AO<B`@
M("`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^("`@36%I;G1E
M;F%N8V4*("H@0&%U=&AO<B`@("`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E
M+F]R9SX@("`@("`@36%I;G1E;F%N8V4*("H@0&-O<'ER:6=H="`@,C`P,RTR
M,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0@(%!(4"!,:6-E;G-E(#(N,#(*("H@
M0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U-/05`*
M("HO"@IR97%U:7)E7V]N8V4@)U-/05`O0F%S92YP:'`G.PIR97%U:7)E7V]N
M8V4@)U-/05`O1F%U;'0N<&AP)SL*<F5Q=6ER95]O;F-E("=33T%0+U!A<G-E
M<BYP:'`G.PIR97%U:7)E7V]N8V4@)U-/05`O5F%L=64N<&AP)SL*<F5Q=6ER
M95]O;F-E("=33T%0+U=31$PN<&AP)SL*"B\J*@H@*B!33T%0(%-E<G9E<B!#
M;&%S<PH@*@H@*B!/<FEG:6YA;'D@8F%S960@;VX@4T]!4'@T(&)Y($1I971R
M:6-H($%Y86QA"B`J(&AT='`Z+R]D:65T<FEC:"YG86YX-"YC;VTO<V]A<'@T
M"B`J"B`J($!A8V-E<W,@("!P=6)L:6,*("H@0'!A8VMA9V4@(%-/05`*("H@
M0&%U=&AO<B`@(%-H86YE($-A<F%V96\@/'-H86YE0'!H<"YN970^($-O;G9E
M<G-I;VX@=&\@4$5!4B!A;F0@=7!D871E<PH@*B!`875T:&]R("`@1&EE=')I
M8V@@07EA;&$@/&1I971R:6-H0&=A;G@T+F-O;3X@3W)I9VEN86P@075T:&]R
M"B`J+PIC;&%S<R!33T%07U-E<G9E<B!E>'1E;F1S(%-/05!?0F%S90I["B`@
M("`O*BH*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D9&ES<&%T8VA?;6%P(#T@87)R87DH*3L@+R\@8W)E871E(&5M<'1Y(&1I
M<W!A=&-H(&UA<`H@("`@=F%R("1D:7-P871C:%]O8FIE8W1S(#T@87)R87DH
M*3L*("`@('9A<B`D<V]A<&]B:F5C="`](&YU;&P["B`@("!V87(@)&-A;&Q?
M;65T:&]D;F%M92`](&YU;&P["B`@("!V87(@)&-A;&Q(86YD;&5R(#T@;G5L
M;#L*("`@('9A<B`D8V%L;%9A;&ED871I;VX@/2!T<G5E.PH*("`@("\J*@H@
M("`@("H@02!L:7-T(&]F(&AE861E<G,@=&AA="!A<F4@9V]I;F<@=&\@8F4@
M<V5N="!B86-K('1O('1H92!C;&EE;G0N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)&AE861E<G,@/2!A<G)A>2@I.PH*("`@
M("\J*@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D<F5Q=65S="`]("<G.PH*("`@("\J*@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG("!834PM16YC;V1I;F<*("`@("`J+PH@("`@=F%R("1X;6Q?96YC
M;V1I;F<@/2!33T%07T1%1D%53%1?14Y#3T1)3D<["B`@("!V87(@)')E<W!O
M;G-E7V5N8V]D:6YG(#T@)U541BTX)SL*"B`@("!V87(@)')E<W5L="`]("=S
M=6-C97-S9G5L)SL@+R\@9F]R(&QO9V=I;F<@:6YT97)O<"!R97-U;'1S('1O
M(&1B"@H@("`@=F%R("1E;F1P;VEN="`]("<G.R`O+R!T:&4@=7)I('1O($U%
M(0H*("`@('9A<B`D<V5R=FEC92`]("<G.R`O+W-O87!A8W1I;VX@:&5A9&5R
M"B`@("!V87(@)&UE=&AO9%]N86UE<W!A8V4@/2!N=6QL.PH@("`@=F%R("1?
M7V]P=&EO;G,@/2!A<G)A>2@G=7-E)R`]/B`G96YC;V1E9"<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=S='EL92<@/3X@)W)P8R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=P87)A;65T97)S)R`]/B`P*3L*"B`@("!F
M=6YC=&EO;B!33T%07U-E<G9E<B@D;W!T:6]N<R`](&YU;&PI"B`@("!["B`@
M("`@("`@:6YI7W-E="@G=')A8VM?97)R;W)S)RP@,2D["B`@("`@("`@<&%R
M96YT.CI33T%07T)A<V4H)U-E<G9E<B<I.PH*("`@("`@("!I9B`H:7-?87)R
M87DH)&]P=&EO;G,I*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D;W!T:6]N
M<ULG=7-E)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7U]O<'1I;VYS
M6R=U<V4G72`]("1O<'1I;VYS6R=U<V4G73L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W-T>6QE)UTI*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R=S='EL92==(#T@)&]P=&EO
M;G-;)W-T>6QE)UT["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES
M<V5T*"1O<'1I;VYS6R=P87)A;65T97)S)UTI*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7U]O<'1I;VYS6R=P87)A;65T97)S)UT@/2`D;W!T:6]N<ULG
M<&%R86UE=&5R<R==.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@
M("\O(&%S<W5M92!W92!E;F-O9&4@=VET:"!S96-T:6]N(#4*("`@("`@("`D
M=&AI<RT^7W-E8W1I;VXU(#T@=')U93L*("`@("`@("!I9B`H)'1H:7,M/E]?
M;W!T:6]N<ULG=7-E)UT]/2=L:71E<F%L)RD@>PH@("`@("`@("`@("`D=&AI
M<RT^7W-E8W1I;VXU(#T@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@17)R;W(@:&%N9&QE<B!F;W(@97)R;W)S('1H870@:&%P<&5N
M(&EN('!R;WAI960@;65T:&]D<RX*("`@("`J"B`@("`@*B!4;R!A;'=A>7,@
M<F5T=7)N(&$@=F%L:60@4T]!4"!R97-P;VYS92!E=F5N(&]N(&5R<F]R<R!T
M:&%T(&1O;B=T(&AA<'!E;@H@("`@("H@:6X@=&AI<R!C;V1E+"!T:&4@97)R
M;W)S(&%R92!C871C:&5D+"!T<F%N<V9O<FUE9"!T;R!A(%-/05`@9F%U;'0@
M86YD"B`@("`@*B!I;6UE9&EA=&5L>2!S96YT('1O('1H92!C;&EE;G0N"B`@
M("`@*@H@("`@("H@0'-E92!H='1P.B\O=W=W+G!H<"YN970O<V5T7V5R<F]R
M7VAA;F1L97(*("`@("`J+PH@("`@9G5N8W1I;VX@7V5R<F]R2&%N9&QE<B@D
M97)R;F\L("1E<G)M<V<L("1F:6QE;F%M92P@)&QI;F5N=6TL("1V87)S*0H@
M("`@>PH@("`@("`@("\J(%1H92!E<G)O<B!H86YD;&5R('-H;W5L9"!I9VYO
M<F4@)S`G(&5R<F]R<RP@96<N(&AI9&1E;B!B>2!`("T@<V5E"B`@("`@("`@
M("H@=&AE('-E=%]E<G)O<E]H86YD;&5R(&UA;G5A;"!P86=E+B`H=&AA;FMS
M('1O($%L86X@2VYO=VQE<RDN("HO"B`@("`@("`@:68@*"$D97)R;F\@?'P@
M)&5R<FYO(#T]($5?3D]424-%*2!["B`@("`@("`@("`@(')E='5R;CL*("`@
M("`@("!]"@H@("`@("`@("1T:&ES+3YF875L="`])B!N97<@4T]!4%]&875L
M="@D97)R;7-G+"`G4V5R=F5R)RP@)U!(4"<L(")%<G)N;SH@)&5R<FYO7&Y&
M:6QE;F%M93H@)&9I;&5N86UE7&Y,:6YE;F\Z("1L:6YE;G5M7&XB*3L*"B`@
M("`@("`@)'1H:7,M/E]S96YD4F5S<&]N<V4H*3L*("`@("`@("!E>&ET.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]G971#;VYT96YT16YC;V1I;F<H)&-O;G1E
M;G1?='EP92D*("`@('L*("`@("`@("`O*B!'970@=&AE(&-H87)A8W1E<B!E
M;F-O9&EN9R!O9B!T:&4@:6YC;VUI;F<@<F5Q=65S="!T<F5A="!I;F-O;6EN
M9PH@("`@("`@("`J(&1A=&$@87,@551&+3@@:68@;F\@96YC;V1I;F<@<V5T
M+B`J+PH@("`@("`@("1T:&ES+3YX;6Q?96YC;V1I;F<@/2`G551&+3@G.PH@
M("`@("`@(&EF("AS=')P;W,H)&-O;G1E;G1?='EP92P@)STG*2D@>PH@("`@
M("`@("`@("`D96YC(#T@<W1R=&]U<'!E<BAS=')?<F5P;&%C92@G(B<L("<G
M+"!S=6)S='(H<W1R<W1R*"1C;VYT96YT7W1Y<&4L("<])RDL(#$I*2D["B`@
M("`@("`@("`@(&EF("@A:6Y?87)R87DH)&5N8RP@)'1H:7,M/E]E;F-O9&EN
M9W,I*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)'1H:7,M/GAM;%]E;F-O9&EN9R`]("1E;F,[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"@H@("`@
M+RHJ"B`@("`@*B!087)S97,@<F5Q=65S="!A;F0@<&]S=',@<F5S<&]N<V4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E<G9I8V4H)&1A=&$L("1E;F1P;VEN
M="`]("<G+"`D=&5S="`](&9A;'-E*0H@("`@>PH@("`@("`@("1R97-P;VYS
M92`](&YU;&P["B`@("`@("`@)&%T=&%C:&UE;G1S(#T@87)R87DH*3L*("`@
M("`@("`D=7-E16YC;V1I;F<@/2`G1$E-12<["@H@("`@("`@("\J($9I9W5R
M92!O=70@;W5R(&5N9'!O:6YT+B`J+PH@("`@("`@("1T:&ES+3YE;F1P;VEN
M="`]("1E;F1P;VEN=#L*("`@("`@("!I9B`H(21T97-T("8F("$D=&AI<RT^
M96YD<&]I;G0I('L*("`@("`@("`@("`@+RH@5V4G;&P@=')Y('1O(&)U:6QD
M(&]U<B!E;F1P;VEN="X@*B\*("`@("`@("`@("`@)'1H:7,M/F5N9'!O:6YT
M(#T@)VAT='`Z+R\G("X@)%]315)615);)U-%4E9%4E].04U%)UT["B`@("`@
M("`@("`@(&EF("@D7U-%4E9%4ELG4T525D527U!/4E0G72D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/F5N9'!O:6YT("X]("<Z)R`N("1?4T525D526R=3
M15)615)?4$]25"==.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES
M+3YE;F1P;VEN="`N/2`D7U-%4E9%4ELG4T-225!47TY!344G73L*("`@("`@
M("!]"@H@("`@("`@("\J($=E="!T:&4@8VAA<F%C=&5R(&5N8V]D:6YG(&]F
M('1H92!I;F-O;6EN9R!R97%U97-T('1R96%T(&EN8V]M:6YG"B`@("`@("`@
M("H@9&%T82!A<R!55$8M."!I9B!N;R!E;F-O9&EN9R!S970N("HO"B`@("`@
M("`@:68@*&ES<V5T*"1?4T525D526R=#3TY414Y47U194$4G72DI('L*("`@
M("`@("`@("`@:68@*'-T<F-A<V5C;7`H)%]315)615);)T-/3E1%3E1?5%E0
M12==+"`G87!P;&EC871I;VXO9&EM92<I(#T](#`I('L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9&5C;V1E1$E-14UE<W-A9V4H)&1A=&$L("1H96%D97)S
M+"`D871T86-H;65N=',I.PH@("`@("`@("`@("`@("`@)'5S945N8V]D:6YG
M(#T@)T1)344G.PH@("`@("`@("`@("!](&5L<V5I9B`H<W1R:7-T<B@D7U-%
M4E9%4ELG0T].5$5.5%]465!%)UTL("=M=6QT:7!A<G0O<F5L871E9"<I*2![
M"B`@("`@("`@("`@("`@("`O*B!4:&ES(&ES(&$@;6EM92!M97-S86=E+"!L
M970G<R!D96-O9&4@:70N("HO"B`@("`@("`@("`@("`@("`D9&%T82`]("=#
M;VYT96YT+51Y<&4Z("<@+@H@("`@("`@("`@("`@("`@("`@('-T<FEP<VQA
M<VAE<R@D7U-%4E9%4ELG0T].5$5.5%]465!%)UTI("X*("`@("`@("`@("`@
M("`@("`@("`B7')<;EQR7&XB("X@)&1A=&$["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V1E8V]D94UI;65-97-S86=E*"1D871A+"`D:&5A9&5R<RP@)&%T
M=&%C:&UE;G1S*3L*("`@("`@("`@("`@("`@("1U<V5%;F-O9&EN9R`]("=-
M:6UE)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1H
M96%D97)S6R=C;VYT96YT+71Y<&4G72DI('L*("`@("`@("`@("`@("`@("1H
M96%D97)S6R=C;VYT96YT+71Y<&4G72`]('-T<FEP<VQA<VAE<R@D7U-%4E9%
M4ELG0T].5$5.5%]465!%)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("@A)'1H:7,M/F9A=6QT("8F"B`@("`@("`@("`@("`@("`A)'1H:7,M
M/E]G971#;VYT96YT16YC;V1I;F<H)&AE861E<G-;)V-O;G1E;G0M='EP92==
M*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/GAM;%]E;F-O9&EN9R`](%-/
M05!?1$5&055,5%]%3D-/1$E.1SL*("`@("`@("`@("`@("`@("\J($9O=6YD
M(&5N8V]D:6YG('=E(&1O;B=T('5N9&5R<W1A;F0[(')E='5R;B!A(&9A=6QT
M+B`J+PH@("`@("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@G
M56YS=7!P;W)T960@96YC;V1I;F<L('5S92!O;F4@;V8@25-/+3@X-3DM,2P@
M55,M05-#24DL(%541BTX)RP@)R<L("<G+"`G4V5R=F5R)RD["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("\J($EF('1H:7,@:7,@;F]T(&$@
M4$]35"!W:71H($-O;G1E;G0M5'EP92!T97AT+WAM;"P@=')Y('1O(')E='5R
M;B!A"B`@("`@("`@("H@5U-$3"!F:6QE+B`J+PH@("`@("`@(&EF("@A)'1H
M:7,M/F9A=6QT("8F("$D=&5S="`F)@H@("`@("`@("`@("`H)%]315)615);
M)U)%455%4U1?34542$]$)UT@(3T@)U!/4U0G('Q\"B`@("`@("`@("`@("!S
M=')N8VUP*"1H96%D97)S6R=C;VYT96YT+71Y<&4G72P@)W1E>'0O>&UL)RP@
M."D@(3T@,"DI('L*("`@("`@("`@("`@+RH@5&AI<R!I<R!N;W0@<&]S<VEB
M;'D@82!V86QI9"!33T%0(')E<75E<W0L('1R>2!T;R!R971U<FX@82!74T1,
M"B`@("`@("`@("`@("`J(&9I;&4N("HO"B`@("`@("`@("`@("1T:&ES+3Y?
M<F%I<V53;V%P1F%U;'0H)TEN=F%L:60@4T]!4"!R97%U97-T+"!M=7-T(&)E
M(%!/4U0@=VET:"!C;VYT96YT+71Y<&4Z('1E>'0O>&UL+"!G;W0Z("<@+B`H
M:7-S970H)&AE861E<G-;)V-O;G1E;G0M='EP92==*2`_("1H96%D97)S6R=C
M;VYT96YT+71Y<&4G72`Z("=.;W1H:6YG(2<I+"`G)RP@)R<L("=397)V97(G
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A)'1H:7,M/F9A=6QT*2!["B`@
M("`@("`@("`@("\J("1R97-P;VYS92!I<R!A(%-/05!?37-G(&]B:F5C="X@
M*B\*("`@("`@("`@("`@)'-O87!?;7-G(#T@)'1H:7,M/G!A<G-E4F5Q=65S
M="@D9&%T82P@)&%T=&%C:&UE;G1S*3L*"B`@("`@("`@("`@("\J($AA;F1L
M92!-:6UE(&]R($1)344@96YC;V1I;F<N("HO"B`@("`@("`@("`@("\J(%1/
M1$\Z($1)344@9&5C;V1I;F<@<VAO=6QD(&UO=F4@=&\@=&AE('1R86YS<&]R
M="P@9&\@:70@:&5R90H@("`@("`@("`@("`@*B!F;W(@;F]W(&%N9"!F;W(@
M96%S92!O9B!G971T:6YG(&ET(&1O;F4N("HO"B`@("`@("`@("`@(&EF("AC
M;W5N="@D=&AI<RT^7U]A='1A8VAM96YT<RDI('L*("`@("`@("`@("`@("`@
M(&EF("@D=7-E16YC;V1I;F<@/3T@)TUI;64G*2!["B`@("`@("`@("`@("`@
M("`@("`@)'-O87!?;7-G(#T@)'1H:7,M/E]M86ME36EM94UE<W-A9V4H)'-O
M87!?;7-G*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@+R\@9&5F875L="!I<R!D:6UE"B`@("`@("`@("`@("`@("`@
M("`@)'-O87!?;7-G(#T@)'1H:7,M/E]M86ME1$E-14UE<W-A9V4H)'-O87!?
M;7-G*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^:&5A9&5R<ULG0V]N
M=&5N="U4>7!E)UT@/2`G87!P;&EC871I;VXO9&EM92<["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<V]A
M<%]M<V<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES95-O87!&875L="@D<V]A<%]M<V<I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H:7-?87)R87DH)'-O87!?
M;7-G*2D@>PH@("`@("`@("`@("`@("`@)')E<W!O;G-E(#T@)'-O87!?;7-G
M6R=B;V1Y)UT["B`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)'-O87!?;7-G
M6R=H96%D97)S)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FAE
M861E<G,@/2`D<V]A<%]M<V=;)VAE861E<G,G73L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R97-P
M;VYS92`]("1S;V%P7VUS9SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/E]S96YD4F5S<&]N<V4H)')E<W!O;G-E*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%-E;F1S('1H92!F:6YA;"!(5%10(')E<W!O;G-E
M('1O('1H92!C;&EE;G0L(&EN8VQU9&EN9R!T:&4@2%144"!H96%D97(*("`@
M("`J(&%N9"!T:&4@2%144"!B;V1Y+@H@("`@("H*("`@("`J($EF(&%N(&5R
M<F]R(&AA<'!E;F5D+"!I="!R971U<FYS(&$@4T]!4"!F875L="!I;G-T96%D
M(&]F('1H92!R97-P;VYS90H@("`@("H@8F]D>2X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1R97-P;VYS92`@5&AE(')E<W!O;G-E(&)O9'DN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]S96YD4F5S<&]N<V4H)')E<W!O;G-E(#T@
M)R<I"B`@("!["B`@("`@("`@+RH@36%K92!D:7-T:6YC=&EO;B!B971W965N
M('1H92!D:69F97)E;G0@4T%027,L(')U;FYI;F<@4$A0(&%S($-'22!O<@H@
M("`@("`@("`J(&%S(&$@;6]D=6QE+B`J+PH@("`@("`@(&EF("AS=')I<W1R
M*'!H<%]S87!I7VYA;64H*2P@)V-G:2<I(#T]/2`P*2!["B`@("`@("`@("`@
M("1H9')S7W1Y<&4@/2`G4W1A='5S.B<["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&AD<G-?='EP92`]("=(5%10+S$N,2<["B`@("`@("`@?0H*
M("`@("`@("!I9B`H)'1H:7,M/F9A=6QT*2!["B`@("`@("`@("`@("1H9')S
M(#T@(B1H9')S7W1Y<&4@-3`P(%-O87`@1F%U;'1<<EQN(CL*("`@("`@("`@
M("`@)')E<W!O;G-E(#T@)'1H:7,M/F9A=6QT+3YM97-S86=E*"D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&AD<G,@/2`B)&AD<G-?='EP92`R
M,#`@3TM<<EQN(CL*("`@("`@("!]"B`@("`@("`@:&5A9&5R*"1H9')S*3L*
M"B`@("`@("`@)'1H:7,M/FAE861E<G-;)U-E<G9E<B==(#T@4T]!4%],24)2
M05)97TY!344["B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^:&5A9&5R<ULG
M0V]N=&5N="U4>7!E)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YH96%D97)S
M6R=#;VYT96YT+51Y<&4G72`]("=T97AT+WAM;#L@8VAA<G-E=#TG("X*("`@
M("`@("`@("`@("`@("1T:&ES+3YR97-P;VYS95]E;F-O9&EN9SL*("`@("`@
M("!]"B`@("`@("`@)'1H:7,M/FAE861E<G-;)T-O;G1E;G0M3&5N9W1H)UT@
M/2!S=')L96XH)')E<W!O;G-E*3L*"B`@("`@("`@9F]R96%C:"`H)'1H:7,M
M/FAE861E<G,@87,@)&L@/3X@)'8I('L*("`@("`@("`@("`@:&5A9&5R*"(D
M:SH@)'8B*3L*("`@("`@("`@("`@)&AD<G,@+CT@(B1K.B`D=EQR7&XB.PH@
M("`@("`@('T*"B`@("`@("`@)'1H:7,M/G)E<W!O;G-E(#T@)&AD<G,@+B`B
M7')<;B(@+B`D<F5S<&]N<V4["B`@("`@("`@<')I;G0@)')E<W!O;G-E.PH@
M("`@?0H*("`@(&9U;F-T:6]N("9C86QL365T:&]D*"1M971H;V1N86UE+"`F
M)&%R9W,I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YC86QL2&%N9&QE<BD@
M>PH@("`@("`@("`@("!R971U<FX@0&-A;&Q?=7-E<E]F=6YC7V%R<F%Y*"1T
M:&ES+3YC86QL2&%N9&QE<BP@87)R87DH)&UE=&AO9&YA;64L("1A<F=S*2D[
M"B`@("`@("`@?0H*("`@("`@("!S971?97)R;W)?:&%N9&QE<BAA<G)A>2@D
M=&AI<RP@)U]E<G)O<DAA;F1L97(G*2D["@H@("`@("`@(&EF("@D87)G<RD@
M>PH@("`@("`@("`@("`O*B!#86QL(&UE=&AO9"!W:71H('!A<F%M971E<G,N
M("HO"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^<V]A<&]B:F5C="D@
M)B8@:7-?;V)J96-T*"1T:&ES+3YS;V%P;V)J96-T*2D@>PH@("`@("`@("`@
M("`@("`@)')E="`]($!C86QL7W5S97)?9G5N8U]A<G)A>2AA<G)A>2@F)'1H
M:7,M/G-O87!O8FIE8W0L("1M971H;V1N86UE*2P@)&%R9W,I.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E="`]($!C86QL7W5S
M97)?9G5N8U]A<G)A>2@D;65T:&]D;F%M92P@)&%R9W,I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@0V%L;"!M971H
M;V0@=VET:&]U<B!P87)A;65T97)S+B`J+PH@("`@("`@("`@("!I9B`H:7-?
M;V)J96-T*"1T:&ES+3YS;V%P;V)J96-T*2D@>PH@("`@("`@("`@("`@("`@
M)')E="`]($!C86QL7W5S97)?9G5N8RAA<G)A>2@F)'1H:7,M/G-O87!O8FIE
M8W0L("1M971H;V1N86UE*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D<F5T(#T@0&-A;&Q?=7-E<E]F=6YC*"1M971H;V1N86UE
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5S=&]R95]E
M<G)O<E]H86YD;&5R*"D["@H@("`@("`@(')E='5R;B`D<F5T.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0W)E871E<R!33T%07U9A;'5E(&]B:F5C="!W:71H
M(')E='5R;B!V86QU97,@9G)O;2!M971H;V0N"B`@("`@*B!5<V5S(&UE=&AO
M9"!S:6=N871U<F4@=&\@9&5T97)M:6YE('1Y<&4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&)U:6QD4F5S=6QT*"8D;65T:&]D7W)E<W!O;G-E+"`F)')E='5R
M;E]T>7!E+`H@("`@("`@("`@("`@("`@("`@("`@("`@)')E='5R;E]N86UE
M(#T@)W)E='5R;B<L("1N86UE<W!A8V4@/2`G)RD*("`@('L*("`@("`@("!I
M9B`H:7-?82@D;65T:&]D7W)E<W!O;G-E+"`G4T]!4%]686QU92<I*2!["B`@
M("`@("`@("`@("1R971U<FY?=F%L(#T@87)R87DH)&UE=&AO9%]R97-P;VYS
M92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y
M*"1R971U<FY?='EP92D@)B8@:7-?87)R87DH)&UE=&AO9%]R97-P;VYS92DI
M('L*("`@("`@("`@("`@("`@("1I(#T@,#L*"B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D<F5T=7)N7W1Y<&4@87,@)&ME>2`]/B`D='EP92D@>PH@("`@
M("`@("`@("`@("`@("`@(&EF("AI<U]N=6UE<FEC*"1K97DI*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1K97D@/2`G:71E;2<["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A*"1M971H
M;V1?<F5S<&]N<V5;)&E=+"=S;V%P7W9A;'5E)RDI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)')E='5R;E]V86Q;72`]("1M971H;V1?<F5S<&]N<V5;
M)&DK*UT["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)'%N(#TF(&YE=R!13F%M92@D:V5Y+"`D;F%M97-P
M86-E*3L*("`@("`@("`@("`@("`@("`@("`@("`@)')E='5R;E]V86Q;72`]
M)B!N97<@4T]!4%]686QU92@D<6XM/F9Q;B@I+"`D='EP92P@)&UE=&AO9%]R
M97-P;VYS95LD:2LK72D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@:68@*&ES7V%R<F%Y*"1R971U<FY?='EP92DI('L*("`@("`@("`@("`@
M("`@("`@("`D:V5Y<R`](&%R<F%Y7VME>7,H)')E='5R;E]T>7!E*3L*("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES7VYU;65R:6,H)&ME>7-;,%TI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1R971U<FY?;F%M92`]("1K97ES
M6S!=.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`D=F%L=65S(#T@87)R87E?=F%L=65S*"1R971U<FY?='EP92D["B`@("`@
M("`@("`@("`@("`@("`@)')E='5R;E]T>7!E(#T@)'9A;'5E<ULP73L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1Q;B`])B!N97<@44YA
M;64H)')E='5R;E]N86UE+"`D;F%M97-P86-E*3L*("`@("`@("`@("`@("`@
M("1R971U<FY?=F%L(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("1R971U
M<FY?=F%L6UT@/28@;F5W(%-/05!?5F%L=64H)'%N+3YF<6XH*2P@)')E='5R
M;E]T>7!E+"`D;65T:&]D7W)E<W!O;G-E*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("!R971U<FX@)')E='5R;E]V86P["B`@("!]"@H@("`@
M9G5N8W1I;VX@<&%R<V5297%U97-T*"1D871A(#T@)R<L("1A='1A8VAM96YT
M<R`](&YU;&PI"B`@("!["B`@("`@("`@+RH@4&%R<V4@<F5S<&]N<V4L(&=E
M="!33T%07U!A<G-E<B!O8FIE8W0N("HO"B`@("`@("`@)'!A<G-E<B`])B!N
M97<@4T]!4%]087)S97(H)&1A=&$L("1T:&ES+3YX;6Q?96YC;V1I;F<L("1A
M='1A8VAM96YT<RD["B`@("`@("`@+RH@268@9F%U;'0@;V-C=7)R960@9'5R
M:6YG(&UE<W-A9V4@<&%R<VEN9RX@*B\*("`@("`@("!I9B`H)'!A<G-E<BT^
M9F%U;'0I('L*("`@("`@("`@("`@)'1H:7,M/F9A=6QT(#T@)'!A<G-E<BT^
M9F%U;'0["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*"B`@
M("`@("`@+RH@2&%N9&QE(&UE<W-A9V4@:&5A9&5R<RX@*B\*("`@("`@("`D
M<F5Q=65S=%]H96%D97)S(#T@)'!A<G-E<BT^9V5T2&5A9&5R<R@I.PH@("`@
M("`@("1H96%D97)?<F5S=6QT<R`](&%R<F%Y*"D["@H@("`@("`@(&EF("@D
M<F5Q=65S=%]H96%D97)S*2!["B`@("`@("`@("`@(&EF("@A:7-?82@D<F5Q
M=65S=%]H96%D97)S+"`G4T]!4%]686QU92<I*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=087)S97(@9&ED(&YO="!R971U
M<FX@4T]!4%]686QU92!O8FIE8W0Z("<@+B`D<F5Q=65S=%]H96%D97)S+"`G
M)RP@)R<L("=397)V97(G*3L*("`@("`@("`@("`@("`@(')E='5R;B!N=6QL
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D<F5Q=65S=%]H96%D
M97)S+3YV86QU92D@>PH@("`@("`@("`@("`@("`@+RH@2&%N9&QE(&AE861E
M<G,@;F]W+B`J+PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)')E<75E<W1?
M:&5A9&5R<RT^=F%L=64@87,@)&AE861E<E]V86PI('L*("`@("`@("`@("`@
M("`@("`@("`D9E]E>&ES=',@/2`D=&AI<RT^=F%L:61A=&5-971H;V0H)&AE
M861E<E]V86PM/FYA;64L("1H96%D97)?=F%L+3YN86UE<W!A8V4I.PH*("`@
M("`@("`@("`@("`@("`@("`O*B!43T1/.B!T:&ES(&1O97,@;F]T('1A:V4@
M:6YT;R!A8V-O=6YT(&UE<W-A9V4@<F]U=&EN9PH@("`@("`@("`@("`@("`@
M("`@("`J('EE="X@*B\*("`@("`@("`@("`@("`@("`@("`D;7EA8W1O<B`]
M("$D:&5A9&5R7W9A;"T^86-T;W(@?'P*("`@("`@("`@("`@("`@("`@("`@
M("`@)&AE861E<E]V86PM/F%C=&]R(#T]("=H='1P.B\O<V-H96UA<RYX;6QS
M;V%P+F]R9R]S;V%P+V%C=&]R+VYE>'0G('Q\"B`@("`@("`@("`@("`@("`@
M("`@("`@("1H96%D97)?=F%L+3YA8W1O<B`]/2`D=&AI<RT^96YD<&]I;G0[
M"@H@("`@("`@("`@("`@("`@("`@(&EF("@A)&9?97AI<W1S("8F("1H96%D
M97)?=F%L+3YM=7-T=6YD97)S=&%N9"`F)B`D;7EA8W1O<BD@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=)(&1O
M;EPG="!U;F1E<G-T86YD(&AE861E<B`G("X@)&AE861E<E]V86PM/FYA;64L
M("<G+"`G)RP@)TUU<W15;F1E<G-T86YD)RD["B`@("`@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("`@("`@+RH@5V4@;VYL>2!H86YD;&4@=&AE(&AE861E
M<B!I9B!I="=S(&9O<B!U<RX@*B\*("`@("`@("`@("`@("`@("`@("`D:7-O
M:R`]("1F7V5X:7-T<R`F)B`D;7EA8W1O<CL*"B`@("`@("`@("`@("`@("`@
M("`@:68@*"1I<V]K*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\J($-A
M;&P@;W5R(&AE861E<B!N;W<A("HO"B`@("`@("`@("`@("`@("`@("`@("`@
M("1H96%D97)?;65T:&]D(#T@)&AE861E<E]V86PM/FYA;64["B`@("`@("`@
M("`@("`@("`@("`@("`@("1H96%D97)?9&%T82`](&%R<F%Y*"1T:&ES+3Y?
M9&5C;V1E*"1H96%D97)?=F%L*2D["B`@("`@("`@("`@("`@("`@("`@("`@
M("\J($EF('1H97)E(&%R92!P87)A;65T97)S('1O('!A<W,N("HO"B`@("`@
M("`@("`@("`@("`@("`@("`@("1H<B`])B`D=&AI<RT^8V%L;$UE=&AO9"@D
M:&5A9&5R7VUE=&AO9"P@)&AE861E<E]D871A*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&AE861E<E]R97-U;'1S6UT@/2!A<G)A>5]S:&EF="@D=&AI
M<RT^8G5I;&1297-U;'0H)&AR+"`D=&AI<RT^<F5T=7)N7W1Y<&4L("1H96%D
M97)?;65T:&]D+"`D:&5A9&5R7W9A;"T^;F%M97-P86-E*2D["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O*B!(86YD;&4@=&AE(&UE=&AO9"!C86QL
M+B`J+PH@("`@("`@("\J($5V86QU871E(&UE<W-A9V4L(&=E='1I;F<@8F%C
M:R!A(%-/05!?5F%L=64@;V)J96-T+B`J+PH@("`@("`@("1T:&ES+3YC86QL
M7VUE=&AO9&YA;64@/2`D=&AI<RT^;65T:&]D;F%M92`]("1P87)S97(M/G)O
M;W1?<W1R=6-T7VYA;65;,%T["@H@("`@("`@("\J($9I9W5R92!O=70@=&AE
M(&UE=&AO9"!N86UE<W!A8V4N("HO"B`@("`@("`@)'1H:7,M/FUE=&AO9%]N
M86UE<W!A8V4@/2`D<&%R<V5R+3YM97-S86=E6R1P87)S97(M/G)O;W1?<W1R
M=6-T6S!=75LG;F%M97-P86-E)UT["@H@("`@("`@(&EF("@D=&AI<RT^7W=S
M9&PI('L*("`@("`@("`@("`@)'1H:7,M/E]S97138VAE;6%697)S:6]N*"1T
M:&ES+3Y?=W-D;"T^>'-D*3L*("`@("`@("`@("`@)&1A=&%(86YD;&5R(#T@
M)'1H:7,M/E]W<V1L+3YG971$871A2&%N9&QE<B@D=&AI<RT^;65T:&]D;F%M
M92P@)'1H:7,M/FUE=&AO9%]N86UE<W!A8V4I.PH@("`@("`@("`@("!I9B`H
M)&1A=&%(86YD;&5R*0H@("`@("`@("`@("`@("`@)'1H:7,M/F-A;&Q?;65T
M:&]D;F%M92`]("1T:&ES+3YM971H;V1N86UE(#T@)&1A=&%(86YD;&5R.PH*
M("`@("`@("`@("`@)'1H:7,M/E]P;W)T3F%M92`]("1T:&ES+3Y?=W-D;"T^
M9V5T4&]R=$YA;64H)'1H:7,M/FUE=&AO9&YA;64I.PH@("`@("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D=&AI<RT^7W!O<G1.86UE*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)'1H:7,M
M/E]P;W)T3F%M92D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&]P1&%T
M82`]("1T:&ES+3Y?=W-D;"T^9V5T3W!E<F%T:6]N1&%T82@D=&AI<RT^7W!O
M<G1.86UE+"`D=&AI<RT^;65T:&]D;F%M92D["B`@("`@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1O<$1A=&$I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]R86ES95-O87!&875L="@D;W!$871A*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R=S='EL92==(#T@
M)&]P1&%T85LG<W1Y;&4G73L*("`@("`@("`@("`@)'1H:7,M/E]?;W!T:6]N
M<ULG=7-E)UT@/2`D;W!$871A6R=O=71P=70G75LG=7-E)UT["B`@("`@("`@
M("`@("1T:&ES+3Y?7V]P=&EO;G-;)W!A<F%M971E<G,G72`]("1O<$1A=&%;
M)W!A<F%M971E<G,G73L*("`@("`@("!]"@H@("`@("`@("\J($1O97,@;65T
M:&]D(&5X:7-T/R`J+PH@("`@("`@(&EF("@A)'1H:7,M/FUE=&AO9&YA;64@
M?'P*("`@("`@("`@("`@(21T:&ES+3YV86QI9&%T94UE=&AO9"@D=&AI<RT^
M;65T:&]D;F%M92P@)'1H:7,M/FUE=&AO9%]N86UE<W!A8V4I*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)VUE=&AO9"`B)R`N("1T
M:&ES+3YM971H;V1?;F%M97-P86-E("X@)'1H:7,M/FUE=&AO9&YA;64@+B`G
M(B!N;W0@9&5F:6YE9"!I;B!S97)V:6-E)RP@)R<L("<G+"`G4V5R=F5R)RD[
M"B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"$D<F5Q=65S=%]V86P@/2`D<&%R<V5R+3YG971297-P;VYS92@I*2![
M"B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*("`@("`@("!I
M9B`H(6ES7V$H)')E<75E<W1?=F%L+"`G4T]!4%]686QU92<I*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)U!A<G-E<B!D:60@;F]T
M(')E='5R;B!33T%07U9A;'5E(&]B:F5C=#H@)R`N("1R97%U97-T7W9A;"P@
M)R<L("<G+"`G4V5R=F5R)RD["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@
M("`@("`@('T*"B`@("`@("`@+RH@5F5R:69Y('1H870@4T]!4%]686QU92!O
M8FIE8W1S(&EN(')E<75E<W0@;6%T8V@@=&AE(&UE=&AO9',*("`@("`@("`@
M*B!S:6=N871U<F4N("HO"B`@("`@("`@:68@*"$D=&AI<RT^=F5R:69Y365T
M:&]D*"1R97%U97-T7W9A;"DI('L*("`@("`@("`@("`@+RH@=F5R:69Y365T
M:&]D*"D@8W)E871E<R!T:&4@9F%U;'0N("HO"B`@("`@("`@("`@(')E='5R
M;B!N=6QL.PH@("`@("`@('T*"B`@("`@("`@+RH@3F5E9"!T;R!S970@<W!E
M8VEA;"!E<G)O<B!D971E8W1I;VX@:6YS:61E('1H92!V86QU92!C;&%S<R!T
M;PH@("`@("`@("`J(&1I9F9E<F5N=&EA=&4@8F5T=V5E;B!N;R!P87)A;7,@
M<&%S<V5D+"!A;F0@86X@97)R;W(@9&5C;V1I;F<N("HO"B`@("`@("`@)')E
M<75E<W1?9&%T82`]("1T:&ES+3Y?7V1E8V]D95)E<75E<W0H)')E<75E<W1?
M=F%L*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5Q=65S=%]D871A
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L
M="@D<F5Q=65S=%]D871A*3L*("`@("`@("!]"B`@("`@("`@)&UE=&AO9%]R
M97-P;VYS92`])B`D=&AI<RT^8V%L;$UE=&AO9"@D=&AI<RT^8V%L;%]M971H
M;V1N86UE+"`D<F5Q=65S=%]D871A*3L*"B`@("`@("`@:68@*"1T:&ES+3Y?
M7V]P=&EO;G-;)W!A<F%M971E<G,G72!\?`H@("`@("`@("`@("`A)&UE=&AO
M9%]R97-P;VYS92!\?`H@("`@("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R=S
M='EL92==/3TG<G!C)RD@>PH@("`@("`@("`@("`O*B!'970@=&AE(&UE=&AO
M9"!R97-U;'0N("HO"B`@("`@("`@("`@(&EF("AI<U]N=6QL*"1M971H;V1?
M<F5S<&]N<V4I*2!["B`@("`@("`@("`@("`@("`D<F5T=7)N7W9A;"`](&YU
M;&P["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<F5T
M=7)N7W9A;"`]("1T:&ES+3YB=6EL9%)E<W5L="@D;65T:&]D7W)E<W!O;G-E
M+"`D=&AI<RT^<F5T=7)N7W1Y<&4I.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D<6X@/28@;F5W(%%.86UE*"1T:&ES+3YM971H;V1N86UE("X@)U)E
M<W!O;G-E)RP@)'1H:7,M/FUE=&AO9%]N86UE<W!A8V4I.PH@("`@("`@("`@
M("`D;65T:&]D5F%L=64@/28@;F5W(%-/05!?5F%L=64H)'%N+3YF<6XH*2P@
M)U-T<G5C="<L("1R971U<FY?=F%L*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D;65T:&]D5F%L=64@/28@)&UE=&AO9%]R97-P;VYS93L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;6%K945N=F5L;W!E*"1M
M971H;V1686QU92P@)&AE861E<E]R97-U;'1S+"`D=&AI<RT^<F5S<&]N<V5?
M96YC;V1I;F<I.PH@("`@?0H*("`@(&9U;F-T:6]N("9?7V1E8V]D95)E<75E
M<W0H)')E<75E<W0L("1S:&EF="`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF
M("@A)')E<75E<W0I('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@
M("`@?0H*("`@("`@("`O*B!#:&5C:R!F;W(@=F%L:60@<F5S<&]N<V4N("HO
M"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<75E<W0I*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"1R97%U97-T
M*3L*("`@("`@("!](&5L<V4@:68@*"%I<U]A*"1R97%U97-T+"`G4T]!4%]6
M86QU92<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A
M<$9A=6QT*"=);G9A;&ED(&1A=&$@:6X@<V5R=F5R.CI?7V1E8V]D95)E<75E
M<W0G*3L*("`@("`@("!]"@H@("`@("`@("\J($1E8V]D92!T;R!N871I=F4@
M<&AP(&1A=&%T>7!E+B`J+PH@("`@("`@("1R97%U97-T07)R87D@/2`D=&AI
M<RT^7V1E8V]D92@D<F5Q=65S="D["B`@("`@("`@+RH@1F%U;'0_("HO"B`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<75E<W1!<G)A>2DI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)')E<75E
M<W1!<G)A>2D["B`@("`@("`@?0H@("`@("`@(&EF("AI<U]O8FIE8W0H)')E
M<75E<W1!<G)A>2D@)B8*("`@("`@("`@("`@9V5T7V-L87-S*"1R97%U97-T
M07)R87DI(#T]("=S=&1#;&%S<R<I('L*("`@("`@("`@("`@)')E<75E<W1!
M<G)A>2`](&=E=%]O8FIE8W1?=F%R<R@D<F5Q=65S=$%R<F%Y*3L*("`@("`@
M("!](&5L<V5I9B`H)'1H:7,M/E]?;W!T:6]N<ULG<W1Y;&4G72`]/2`G9&]C
M=6UE;G0G*2!["B`@("`@("`@("`@("1R97%U97-T07)R87D@/2!A<G)A>2@D
M<F5Q=65S=$%R<F%Y*3L*("`@("`@("!]"B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1R97%U97-T07)R87DI*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D<F5Q
M=65S=$%R<F%Y6R=F875L=&-O9&4G72D@?'P*("`@("`@("`@("`@("`@(&ES
M<V5T*"1R97%U97-T07)R87E;)U-/05`M14Y6.F9A=6QT8V]D92==*2D@>PH@
M("`@("`@("`@("`@("`@)&9A=6QT8V]D92`]("1F875L='-T<FEN9R`]("1F
M875L=&1E=&%I;"`]("1F875L=&%C=&]R(#T@)R<["B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D<F5Q=65S=$%R<F%Y(&%S("1K(#T^("1V*2!["B`@("`@
M("`@("`@("`@("`@("`@:68@*'-T<FES='(H)&LL("=F875L=&-O9&4G*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D9F%U;'1C;V1E(#T@)'8["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF("AS
M=')I<W1R*"1K+"`G9F%U;'1S=')I;F<G*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D9F%U;'1S=')I;F<@/2`D=CL*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@:68@*'-T<FES='(H)&LL("=D971A
M:6PG*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9F%U;'1D971A:6P@
M/2`D=CL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@:68@*'-T<FES='(H)&LL("=F875L=&%C=&]R)RDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&9A=6QT86-T;W(@/2`D=CL*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@D9F%U;'1S=')I;F<L("1F
M875L=&1E=&%I;"P@)&9A=6QT86-T;W(L("1F875L=&-O9&4I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("\J(%)E='5R;B!A<G)A>2!O9B!R971U<FX@
M=F%L=65S+B`J+PH@("`@("`@("`@("!I9B`H)'-H:69T("8F(&-O=6YT*"1R
M97%U97-T07)R87DI(#T](#$I('L*("`@("`@("`@("`@("`@(')E='5R;B!A
M<G)A>5]S:&EF="@D<F5Q=65S=$%R<F%Y*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!R971U<FX@)')E<75E<W1!<G)A>3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1R97%U97-T07)R87D["B`@("!]"@H@("`@9G5N8W1I;VX@
M=F5R:69Y365T:&]D*"1R97%U97-T*0H@("`@>PH@("`@("`@(&EF("@A)'1H
M:7,M/F-A;&Q686QI9&%T:6]N*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@("`@('T*"B`@("`@("`@)'!A<F%M<R`]("1R97%U97-T+3YV86QU
M93L*"B`@("`@("`@+RH@1V5T('1H92!D:7-P871C:"!M87`@:68@;VYE(&5X
M:7-T<RX@*B\*("`@("`@("`D;6%P(#T@;G5L;#L*("`@("`@("!I9B`H87)R
M87E?:V5Y7V5X:7-T<R@D=&AI<RT^;65T:&]D;F%M92P@)'1H:7,M/F1I<W!A
M=&-H7VUA<"DI('L*("`@("`@("`@("`@)&UA<"`]("1T:&ES+3YD:7-P871C
M:%]M87!;)'1H:7,M/FUE=&AO9&YA;65=.PH@("`@("`@('T@96QS96EF("AI
M<W-E="@D=&AI<RT^<V]A<&]B:F5C="DI('L*("`@("`@("`@("`@:68@*&UE
M=&AO9%]E>&ES=',H)'1H:7,M/G-O87!O8FIE8W0L("=?7V1I<W!A=&-H)RDI
M('L*("`@("`@("`@("`@("`@("1M87`@/2`D=&AI<RT^<V]A<&]B:F5C="T^
M7U]D:7-P871C:"@D=&AI<RT^;65T:&]D;F%M92D["B`@("`@("`@("`@('T@
M96QS96EF("AM971H;V1?97AI<W1S*"1T:&ES+3YS;V%P;V)J96-T+"`D=&AI
M<RT^;65T:&]D;F%M92DI('L*("`@("`@("`@("`@("`@("\J($YO(&UA<"P@
M86QL('!U8FQI8R!F=6YC=&EO;G,@87)E(%-/05`@9G5N8W1I;VYS+B`J+PH@
M("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@:68@*"$D;6%P*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?<F%I<V53;V%P1F%U;'0H)U-/05`@<F5Q=65S="!S<&5C:69I960@86X@
M=6YH86YD;&5D(&UE=&AO9"`B)R`N("1T:&ES+3YM971H;V1N86UE("X@)R(G
M+"`G)RP@)R<L("=#;&EE;G0G*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@+RH@268@=V4@86QI87-E9"!T:&4@4T]!
M4"!M971H;V0@;F%M92!T;R!A(%!(4"!F=6YC=&EO;BP@8VAA;F=E"B`@("`@
M("`@("H@8V%L;%]M971H;V1N86UE('-O('=E(&1O('1H92!R:6=H="!T:&EN
M9RX@*B\*("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@G86QI87,G+"`D
M;6%P*2`F)B`A96UP='DH)&UA<%LG86QI87,G72DI('L*("`@("`@("`@("`@
M)'1H:7,M/F-A;&Q?;65T:&]D;F%M92`]("1M87!;)V%L:6%S)UT["B`@("`@
M("`@?0H*("`@("`@("`O*B!)9B!T:&5R92!A<F4@:6YP=70@<&%R86UE=&5R
M<R!R97%U:7)E9"X@*B\*("`@("`@("!I9B`H)'-I9R`]("1M87!;)VEN)UTI
M('L*("`@("`@("`@("`@)'1H:7,M/FEN<'5T7W9A;'5E(#T@8V]U;G0H)'-I
M9RD["B`@("`@("`@("`@("1T:&ES+3YR971U<FY?='EP92`](&ES7V%R<F%Y
M*"1M87!;)V]U="==*2`_("1M87!;)V]U="==(#H@9F%L<V4["B`@("`@("`@
M("`@(&EF("AI<U]A<G)A>2@D<&%R86US*2D@>PH@("`@("`@("`@("`@("`@
M+RH@5F%L:61A=&4@=&AE(&YU;6)E<B!O9B!P87)A;65T97)S+B`J+PH@("`@
M("`@("`@("`@("`@:68@*&-O=6YT*"1P87)A;7,I(#T](&-O=6YT*"1S:6<I
M*2!["B`@("`@("`@("`@("`@("`@("`@+RH@36%K92!A<G)A>2!O9B!P87)A
M;2!T>7!E<RX@*B\*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D<&%R
M86US(&%S("1P87)A;2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<%M=
M(#T@<W1R=&]L;W=E<B@D<&%R86TM/G1Y<&4I.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`D<VEG7W0@/2!A<G)A>5]V86QU
M97,H)'-I9RD["B`@("`@("`@("`@("`@("`@("`@+RH@5F%L:61A=&4@96%C
M:"!P87)A;2=S('1Y<&4N("HO"B`@("`@("`@("`@("`@("`@("`@9F]R("@D
M:2`](#`[("1I(#P@8V]U;G0H)'`I.R`D:2LK*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("\J($EF(%-/05`@='EP97,@9&\@;F]T(&UA=&-H+"!I="=S
M('-T:6QL(&9I;F4@:68@=&AE"B`@("`@("`@("`@("`@("`@("`@("`@("`J
M(&UA<'!E9"!P:'`@='EP97,@;6%T8V@@=&AI<R!A;&QO=W,@=7-I;F<@<&QA
M:6X@4$A0"B`@("`@("`@("`@("`@("`@("`@("`@("`J('9A<FEA8FQE<R!T
M;R!W;W)K("AI+F4N('-T=69F(&QI:V4@1&5C:6UA;"!W;W5L9`H@("`@("`@
M("`@("`@("`@("`@("`@("`@*B!F86EL(&]T:&5R=VES92DN(%=E(&-O;G-I
M9&5R('1H:7,@;VYL>2!E<G)O<B!I9B!T:&4*("`@("`@("`@("`@("`@("`@
M("`@("`@("H@='EP97,@97AI<W0@:6X@;W5R('1Y<&4@;6%P<RP@86YD('1H
M97D@9&EF9F5R+B`J+PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H<W1R
M8V%S96-M<"@D<VEG7W1;)&E=+"`D<%LD:5TI("$](#`@)B8*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&ES<V5T*"1T:&ES+3Y?='EP96UA<%M33T%0
M7UA-3%]30TA%34%?5D524TE/3EU;)'-I9U]T6R1I75TI("8F"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!S=')C87-E8VUP*"1T:&ES+3Y?='EP96UA
M<%M33T%07UA-3%]30TA%34%?5D524TE/3EU;)'-I9U]T6R1I75TL("1T:&ES
M+3Y?='EP96UA<%M33T%07UA-3%]30TA%34%?5D524TE/3EU;)'!;)&E=72D@
M(3T@,"D@>PH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;2`]
M("1P87)A;7-;)&E=.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]R86ES95-O87!&875L="@B4T]!4"!R97%U97-T(&-O;G1A:6YE9"!M
M:7-M871C:&EN9R!P87)A;65T97)S(&]F(&YA;64@)'!A<F%M+3YN86UE(&AA
M9"!T>7!E(%M[)'!;)&E=?5TL('=H:6-H(&1I9"!N;W0@;6%T8V@@<VEG;F%T
M=7)E)W,@='EP93H@6WLD<VEG7W1;)&E=?5TL(&UA=&-H960_("(@+B`H<W1R
M8V%S96-M<"@D<VEG7W1;)&E=+"`D<%LD:5TI*2P@)R<L("<G+"`G0VQI96YT
M)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("\J(%=R;VYG
M(&YU;6)E<B!O9B!P87)A;7,N("HO"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]R86ES95-O87!&875L="@G4T]!4"!R97%U97-T(&-O;G1A:6YE9"!I
M;F-O<G)E8W0@;G5M8F5R(&]F('!A<F%M971E<G,N(&UE=&AO9"`B)R`N("1T
M:&ES+3YM971H;V1N86UE("X@)R(@<F5Q=6ER960@)R`N(&-O=6YT*"1S:6<I
M("X@)R!A;F0@<F5Q=65S="!P<F]V:61E9"`G("X@8V]U;G0H)'!A<F%M<RDL
M("<G+"`G)RP@)T-L:65N="<I.PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("\J($YO('!A<F%M<RX@*B\*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)U-/05`@<F5Q=65S="!C
M;VYT86EN960@:6YC;W)R96-T(&YU;6)E<B!O9B!P87)A;65T97)S+B!M971H
M;V0@(B<@+B`D=&AI<RT^;65T:&]D;F%M92`N("<B(')E<75I<F5S("<@+B!C
M;W5N="@D<VEG*2`N("<@<&%R86UE=&5R<RP@86YD(')E<75E<W0@<')O=FED
M960@;F]N92XG+"`G)RP@)R<L("=#;&EE;G0G*3L*("`@("`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@+RH@5V4G;&P@=')Y(&ET(&%N>7=A>2X@*B\*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!V86QI9&%T94UE=&AO9"@D;65T
M:&]D;F%M92P@)&YA;65S<&%C92`](&YU;&PI"B`@("!["B`@("`@("`@=6YS
M970H)'1H:7,M/G-O87!O8FIE8W0I.PH*("`@("`@("!I9B`H(21T:&ES+3YC
M86QL5F%L:61A=&EO;BD@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("!]"@H@("`@("`@("\J($YO(%-/05`@86-C97-S('1O('!R:79A=&4@
M9G5N8W1I;VYS+B`J+PH@("`@("`@(&EF("@D;65T:&]D;F%M95LP72`]/2`G
M7R<I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@+RH@:68@:70G<R!I;B!O=7(@9G5N8W1I;VX@;&ES="P@;VL@*B\*
M("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@D;65T:&]D;F%M92P@)'1H
M:7,M/F1I<W!A=&-H7VUA<"D@)B8*("`@("`@("`@("`@*"$D;F%M97-P86-E
M('Q\"B`@("`@("`@("`@("`A87)R87E?:V5Y7V5X:7-T<R@G;F%M97-P86-E
M)RP@)'1H:7,M/F1I<W!A=&-H7VUA<%LD;65T:&]D;F%M95TI('Q\"B`@("`@
M("`@("`@("`D;F%M97-P86-E(#T]("1T:&ES+3YD:7-P871C:%]M87!;)&UE
M=&AO9&YA;65=6R=N86UE<W!A8V4G72DI('L*("`@("`@("`@("`@:68@*&%R
M<F%Y7VME>5]E>&ES=',H)VYA;65S<&%C92<L("1T:&ES+3YD:7-P871C:%]M
M87!;)&UE=&AO9&YA;65=*2D*("`@("`@("`@("`@("`@("1T:&ES+3YM971H
M;V1?;F%M97-P86-E(#T@)'1H:7,M/F1I<W!A=&-H7VUA<%LD;65T:&]D;F%M
M95U;)VYA;65S<&%C92==.PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("!]"@H@("`@("`@("\J(&EF(&ET)W,@:6X@86X@;V)J96-T+"!I="=S
M(&]K("HO"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YD:7-P871C:%]O8FIE
M8W1S6R1N86UE<W!A8V5=*2D@>PH@("`@("`@("`@("`D8R`](&-O=6YT*"1T
M:&ES+3YD:7-P871C:%]O8FIE8W1S6R1N86UE<W!A8V5=*3L*("`@("`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@)&,[("1I*RLI('L*("`@("`@("`@("`@
M("`@("1O8FH@/28@)'1H:7,M/F1I<W!A=&-H7V]B:F5C='-;)&YA;65S<&%C
M95U;)&E=.PH@("`@("`@("`@("`@("`@+RH@268@=V4@:&%V92!A(&1I<W!A
M=&-H(&UA<"P@86YD('1H92!F=6YC=&EO;B!I<R!N;W0@:6X@=&AE"B`@("`@
M("`@("`@("`@("`@*B!D:7-P871C:"!M87`L('1H96X@:70@:7,@;F]T(&-A
M;&QA8FQE(2`J+PH@("`@("`@("`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H
M)&]B:BP@)U]?9&ES<&%T8V@G*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF
M("@D;V)J+3Y?7V1I<W!A=&-H*"1M971H;V1N86UE*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^;65T:&]D7VYA;65S<&%C92`]("1N86UE
M<W!A8V4["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS;V%P;V)J
M96-T(#TF("1O8FH["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@
M96QS96EF("AM971H;V1?97AI<W1S*"1O8FHL("1M971H;V1N86UE*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YM971H;V1?;F%M97-P86-E(#T@
M)&YA;65S<&%C93L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V]A<&]B
M:F5C="`])B`D;V)J.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@9G5N8W1I;VX@861D
M3V)J96-T36%P*"8D;V)J+"`D;F%M97-P86-E(#T@;G5L;"P@)'-E<G9I8V5?
M;F%M92`]("=$969A=6QT)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<V5R=FEC95]D97-C(#T@)R<I"B`@("!["B`@("`@("`@:68@*"$D;F%M97-P
M86-E*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D;V)J+3YN86UE<W!A8V4I
M*2!["B`@("`@("`@("`@("`@("`O+R!86%@@82!B:70@;V8@8F%C:W=A<F1S
M(&-O;7!A=&EB:6QI='D*("`@("`@("`@("`@("`@("1N86UE<W!A8V4@/2`D
M;V)J+3YN86UE<W!A8V4["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=.;R!N86UE<W!A8V4@
M<')O=FED960@9F]R(&-L87-S(2<L("<G+"`G)RP@)U-E<G9E<B<I.PH@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/F1I<W!A=&-H7V]B:F5C
M='-;)&YA;65S<&%C95TI*2!["B`@("`@("`@("`@("1T:&ES+3YD:7-P871C
M:%]O8FIE8W1S6R1N86UE<W!A8V5=(#T@87)R87DH*3L*("`@("`@("!]"B`@
M("`@("`@)'1H:7,M/F1I<W!A=&-H7V]B:F5C='-;)&YA;65S<&%C95U;72`]
M)B`D;V)J.PH*("`@("`@("`O+R!#<F5A=&4@:6YT97)N86P@5U-$3"!S=')U
M8W1U<F5S(&9O<B!O8FIE8W0*"B`@("`@("`@+R\@6%A8($)E8V%U<V4@<V]M
M92!I;G1E<FYA;"!W;W)K:6YG<R!O9B!014%2.CI33T%0(&1E8VED92!W:&5T
M:&5R('1O"B`@("`@("`@+R\@9&\@8V5R=&%I;B!T:&EN9W,@8GD@=&AE('!R
M97-E;F-E(&]R(&%B<V5N8V4@;V8@7W=S9&PL('=E('-H;W5L9`H@("`@("`@
M("\O(&]N;'D@8W)E871E(&$@7W=S9&P@<W1R=6-T=7)E(&EF('=E(&MN;W<@
M=V4@8V%N(&9I;&P@:70[(&EF"B`@("`@("`@+R\@7U]D:7-P871C:%]M87`@
M;W(@7U]T>7!E9&5F(&9O<B!T:&4@;V)J96-T(&ES(&UI<W-I;F<L('=E('-H
M;W5L9`H@("`@("`@("\O(&%V;VED(&-R96%T:6YG(&ET+B!,871E<BP@=VAE
M;B!W92!A<F4@=7-I;F<@4$A0(#4@:6YT<F]S<&5C=&EO;BP@=V4*("`@("`@
M("`O+R!W:6QL(&)E(&%B;&4@=&\@;6%K92!T:&4@9&%T82!F;W(@86QL(&]B
M:F5C=',@=VET:&]U="!A;GD@97AT<F$*("`@("`@("`O+R!I;F9O<FUA=&EO
M;B!F<F]M('1H92!D979E;&]P97)S+"!A;F0@=&AI<R!C;VYD:71I;VX@<VAO
M=6QD(&)E"B`@("`@("`@+R\@9')O<'!E9"X*"B`@("`@("`@+R\@6%A8($MN
M;W=N(&ES<W5E.B!I9B!I;7!O<G1E9"!74T1,("AB:6YD5U-$3"D@;W(@86YO
M=&AE<B!74T1,('-O=7)C90H@("`@("`@("\O(&ES('5S960@=&\@861D(%]W
M<V1L('-T<G5C='5R92!I;F9O<FUA=&EO;BP@=&AE;B!A9&1/8FIE8W174T1,
M(&ES"B`@("`@("`@+R\@=7-E9"P@=&AE<F4@:7,@82!H:6=H('!O<W-I8FEL
M:71Y(&]F(%]W<V1L(&1A=&$@8V]R<G5P=&EO;CL*("`@("`@("`O+R!T:&5R
M969O<F4@>6]U('-H;W5L9"!A=F]I9"!U<VEN9R!?7V1I<W!A=&-H7VUA<"]?
M7W1Y<&5D968*("`@("`@("`O+R!D969I;FET:6]N<R!!3D0@;W1H97(@5U-$
M3"!D871A('-O=7)C97,@:6X@=&AE('-A;64@<V5R=FEC92X@5V4*("`@("`@
M("`O+R!E>&-L=61E(&-L87-S97,@=&AA="!D;VXG="!H879E(%]?='EP961E
M9G,@=&\@86QL;W<@97AT97)N86P@5U-$3`H@("`@("`@("\O(&9I;&5S('1O
M(&)E('5S960@=VET:"!C;&%S<V5S('=I=&@@;F\@:6YT97)N86P@='EP92!D
M969I;FET:6]N<PH@("`@("`@("\O("AT:&4@='EP97,@87)E(&1E9FEN960@
M:6X@=&AE(%=31$P@9FEL92DN(%=H96X@861D3V)J96-T5U-$3"!I<PH@("`@
M("`@("\O(')E9F%C=&]R960@=&\@;F]T(&-A=7-E(&-O<G)U<'1I;VXL('1H
M:7,@<F5S=')I8W1I;VX@8V%N(&)E"B`@("`@("`@+R\@<F5L87AE9"X*"B`@
M("`@("`@+R\@26X@<W5M;6%R>2P@:68@>6]U(&%D9"!A;B!O8FIE8W0@=VET
M:"!B;W1H(&$@9&ES<&%T8V@@;6%P(&%N9"!T>7!E"B`@("`@("`@+R\@9&5F
M:6YI=&EO;G,L('1H96X@<')E=FEO=7,@5U-$3"!F:6QE(&]P97)A=&EO;B!A
M;F0@='EP92!D969I;FET:6]N<PH@("`@("`@("\O('=I;&P@8F4@;W9E<G=R
M:71T96XN"B`@("`@("`@:68@*&ES<V5T*"1O8FHM/E]?9&ES<&%T8VA?;6%P
M*2`F)B!I<W-E="@D;V)J+3Y?7W1Y<&5D968I*2!["B`@("`@("`@("`@("1T
M:&ES+3YA9&1/8FIE8W174T1,*"1O8FHL("1N86UE<W!A8V4L("1S97)V:6-E
M7VYA;64L("1S97)V:6-E7V1E<V,I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@;65T:&]D
M('1O('1H92!D:7-P871C:"!M87`N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D
M9%1O36%P*"1M971H;V1N86UE+"`D:6XL("1O=70L("1N86UE<W!A8V4@/2!N
M=6QL+"`D86QI87,@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A9G5N8W1I
M;VY?97AI<W1S*"1M971H;V1N86UE*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7W)A:7-E4V]A<$9A=6QT*"=%<G)O<B!M87!P:6YG(&9U;F-T:6]N)RP@)R<L
M("<G+"`G4V5R=F5R)RD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@("1T:&ES+3YD:7-P871C:%]M87!;)&UE=&AO9&YA
M;65=6R=I;B==(#T@)&EN.PH@("`@("`@("1T:&ES+3YD:7-P871C:%]M87!;
M)&UE=&AO9&YA;65=6R=O=70G72`]("1O=70["B`@("`@("`@)'1H:7,M/F1I
M<W!A=&-H7VUA<%LD;65T:&]D;F%M95U;)V%L:6%S)UT@/2`D86QI87,["B`@
M("`@("`@:68@*"1N86UE<W!A8V4I('L*("`@("`@("`@("`@)'1H:7,M/F1I
M<W!A=&-H7VUA<%LD;65T:&]D;F%M95U;)VYA;65S<&%C92==(#T@)&YA;65S
M<&%C93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@(&9U;F-T:6]N('-E=$-A;&Q(86YD;&5R*"1C86QL2&%N9&QE<BP@)'9A
M;&ED871I;VX@/2!T<G5E*0H@("`@>PH@("`@("`@("1T:&ES+3YC86QL2&%N
M9&QE<B`]("1C86QL2&%N9&QE<CL*("`@("`@("`D=&AI<RT^8V%L;%9A;&ED
M871I;VX@/2`D=F%L:61A=&EO;CL*("`@('T*"B`@("`O*BH*("`@("`J($!D
M97!R96-A=&5D('5S92!B:6YD5U-$3"!F<F]M(&YO=R!O;@H@("`@("HO"B`@
M("!F=6YC=&EO;B!B:6YD*"1W<V1L7W5R;"D*("`@('L*("`@("`@("`D=&AI
M<RT^8FEN9%=31$PH)'=S9&Q?=7)L*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($!P87)A;2`@<W1R:6YG(&$@=7)L('1O(&$@5U-$3"!R97-O=7)C90H@("`@
M("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(&)I;F174T1,
M*"1W<V1L7W5R;"D*("`@('L*("`@("`@("`O*B!);G-T86YT:6%T92!74T1,
M(&-L87-S+B`J+PH@("`@("`@("1T:&ES+3Y?=W-D;"`])B!N97<@4T]!4%]7
M4T1,*"1W<V1L7W5R;"D["B`@("`@("`@:68@*"1T:&ES+3Y?=W-D;"T^9F%U
M;'0I('L*("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@D=&AI
M<RT^7W=S9&PM/F9A=6QT*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@861D3V)J
M96-T5U-$3"@F)'=S9&Q?;V)J+"`D=&%R9V5T3F%M97-P86-E+"`D<V5R=FEC
M95]N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`D<V5R=FEC95]D
M97-C(#T@)R<I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W=S
M9&PI*2!["B`@("`@("`@("`@("1T:&ES+3Y?=W-D;"`])B!N97<@4T]!4%]7
M4T1,.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]W<V1L+3YP87)S94]B
M:F5C="@D=W-D;%]O8FHL("1T87)G971.86UE<W!A8V4L("1S97)V:6-E7VYA
M;64L("1S97)V:6-E7V1E<V,I.PH*("`@("`@("!I9B`H)'1H:7,M/E]W<V1L
M+3YF875L="D@>PH@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT
M*"1T:&ES+3Y?=W-D;"T^9F%U;'0I.PH@("`@("`@('T*("`@('T*?0H`````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+U-/05`O=&]O;',O````````````````````
M`````````````````````````````````````````````````````````#`P
M,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S,W
M`#`R,#4Q,0`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!4"]T;V]L
M<R]G96YP<F]X>2YP:'``````````````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`V,C,`,3`U,34T,S,W,S<`,#(S,#<V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"F5R<F]R7W)E<&]R=&EN9RA%
M7T%,3"D["G)E<75I<F5?;VYC92`G4T]!4"]74T1,+G!H<"<["@HO*BH*("H@
M9V5N<')O>'D*("H*("H@82!C;VUM86YD(&QI;F4@=&]O;"!F;W(@9V5N97)A
M=&EN9R!33T%0('!R;WAI97,@9G)O;2!74T1,(&9I;&5S"B`J"B`J(&=E;G!R
M;WAY+G!H<"!H='1P.B\O<VET92]F;V\N=W-D;"`^(&9O;RYP:'`*("H*("HO
M"@IF=6YC=&EO;B!D;U]W<V1L*"1U<FDI('L*("`@("1W<V1L(#TF(&YE=R!3
M3T%07U=31$PH)'5R:2D["B`@("!P<FEN="`D=W-D;"T^9V5N97)A=&5!;&Q0
M<F]X:65S*"D["GT*96-H;R`B/#]P:'!<;EQN<F5Q=6ER95]O;F-E("=33T%0
M+T-L:65N="YP:'`G.UQN7&XB.PID;U]W<V1L*"1?4T525D526R=A<F=V)UU;
M,5TI.PIE8VAO(")<;C\^(CL*/SX`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-/05`O5')A;G-P;W)T+P``````
M````````````````````````````````````````````````````````````
M`````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,S-S,W`#`R,3,T-0`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!
M4"]4<F%N<W!O<G0O2%144"YP:'``````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P-#<T,S$`,3`U,34T,S,W,S<`,#(R-C0V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!4:&ES
M(&9I;&4@8V]N=&%I;G,@=&AE(&-O9&4@9F]R(&$@2%144"!T<F%N<W!O<G0@
M;&%Y97(N"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.
M4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N
M,#(@;V8@=&AE(%!(4"!L:6-E;G-E+`H@*B!T:&%T(&ES(&)U;F1L960@=VET
M:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES(&%V
M86EL86)L92!A=`H@*B!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A
M;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70*("H@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N"B`J(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X*("H*("H@0&-A=&5G;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E
M("`@(%-/05`*("H@0&%U=&AO<B`@("`@4VAA;F4@0V%R879E;R`\4VAA;F5`
M0V%R879E;RYC;VT^"B`J($!C;W!Y<FEG:'0@(#(P,#,M,C`P-2!4:&4@4$A0
M($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S)?,#(N='AT("!02%`@3&EC96YS92`R+C`R"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]33T%0"B`J+PH*+RHJ"B`J
M($A45%`@5')A;G-P;W)T(&-L87-S"B`J"B`J($!P86-K86=E("!33T%0"B`J
M($!C871E9V]R>2!796)?4V5R=FEC97,*("HO"@HO*BH*("H@3F5E9&5D($-L
M87-S97,*("HO"G)E<75I<F5?;VYC92`G4T]!4"]"87-E+G!H<"<["@HO*BH*
M("H@($A45%`@5')A;G-P;W)T(&9O<B!33T%0"B`J"B`J($!A8V-E<W,@<'5B
M;&EC"B`J($!P86-K86=E(%-/05`*("H@0&%U=&AO<B!3:&%N92!#87)A=F5O
M(#QS:&%N94!P:'`N;F5T/@H@*B\*8VQA<W,@4T]!4%]4<F%N<W!O<G1?2%14
M4"!E>'1E;F1S(%-/05!?0F%S90I["@H@("`@+RHJ"B`@("`@*B!"87-I8R!!
M=71H('-T<FEN9PH@("`@("H*("`@("`J($!V87(@(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D:&5A9&5R<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#
M;V]K:65S"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)&-O;VMI97,["@H@("`@+RHJ"B`@("`@*@H@("`@("H@0'9A<B`@:6YT
M(&-O;FYE8W1I;VX@=&EM96]U="!I;B!S96-O;F1S("T@,"`](&YO;F4*("`@
M("`J+PH@("`@=F%R("1T:6UE;W5T(#T@-#L*"B`@("`O*BH*("`@("`J($%R
M<F%Y(&-O;G1A:6YI;F<@=7)L<&%R=',@+2!P87)S95]U<FPH*0H@("`@("H*
M("`@("`J($!V87(@(&UI>&5D"B`@("`@*B\*("`@('9A<B`D=7)L<&%R=',@
M/2!.54Q,.PH*("`@("\J*@H@("`@("H@0V]N;F5C=&EO;B!E;F1P;VEN="`M
M(%523`H@("`@("H*("`@("`J($!V87(@('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)'5R;"`]("<G.PH*("`@("\J*@H@("`@("H@26YC;VUI;F<@<&%Y;&]A
M9`H@("`@("H*("`@("`J($!V87(@('-T<FEN9PH@("`@("HO"B`@("!V87(@
M)&EN8V]M:6YG7W!A>6QO860@/2`G)SL*"B`@("`O*BH*("`@("`J($A45%`M
M4F5Q=65S="!5<V5R+4%G96YT"B`@("`@*@H@("`@("H@0'9A<B`@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D7W5S97)!9V5N="`](%-/05!?3$E"4D%265].
M04U%.PH*("`@("\J*@H@("`@("H@2%144"!%;F-O9&EN9PH@("`@("H*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D96YC;V1I;F<@/2!3
M3T%07T1%1D%53%1?14Y#3T1)3D<["@H@("`@+RHJ"B`@("`@*B!(5%10+5)E
M<W!O;G-E($-O;G1E;G0M5'EP92!E;F-O9&EN9PH@("`@("H*("`@("`J('=E
M(&%S<W5M92!55$8M."!I9B!N;R!E;F-O9&EN9R!I<R!S970*("`@("`J($!V
M87(@('-T<FEN9PH@("`@("HO"B`@("!V87(@)')E<W5L=%]E;F-O9&EN9R`]
M("=55$8M."<["@H@("`@+RHJ"B`@("`@*B!(5%10+5)E<W!O;G-E($-O;G1E
M;G0M5'EP90H@("`@("HO"B`@("!V87(@)')E<W5L=%]C;VYT96YT7W1Y<&4[
M"@H@("`@=F%R("1R97-U;'1?:&5A9&5R<R`](&%R<F%Y*"D["@H@("`@=F%R
M("1R97-U;'1?8V]O:VEE<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!3
M3T%07U1R86YS<&]R=%](5%10($-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D55),("`@(&AT='`@=7)L('1O('-O87`@96YD<&]I
M;G0*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M
M("!S=')I;F<@)%5220H@("`@("H@0'!A<F%M("!S=')I;F<@)&5N8V]D:6YG
M("!E;F-O9&EN9R!T;R!U<V4*("`@("`J+PH@("`@9G5N8W1I;VX@4T]!4%]4
M<F%N<W!O<G1?2%144"@D55),+"`D96YC;V1I;F<@/2!33T%07T1%1D%53%1?
M14Y#3T1)3D<I"B`@("!["B`@("`@("`@<&%R96YT.CI33T%07T)A<V4H)TA4
M5%`G*3L*("`@("`@("`D=&AI<RT^=7)L<&%R=',@/2!`<&%R<V5?=7)L*"15
M4DPI.PH@("`@("`@("1T:&ES+3YU<FP@/2`D55),.PH@("`@("`@("1T:&ES
M+3YE;F-O9&EN9R`]("1E;F-O9&EN9SL*("`@('T*"B`@("`O*BH*("`@("`J
M('-E;F0@86YD(')E8V5I=F4@<V]A<"!D871A"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R!O=71G;VEN9R!P;W-T(&1A=&$*("`@("`J($!P87)A;2!A
M<G)A>2`@;W!T:6]N<PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG?&9A
M=6QT(')E<W!O;G-E"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B`F<V5N9"@F)&US9RP@)&]P=&EO;G,@/2!N=6QL*0H@("`@
M>PH@("`@("`@(&EF("@A)'1H:7,M/E]V86QI9&%T955R;"@I*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^9F%U;'0["B`@("`@("`@?0H*("`@("`@
M("!I9B`H:7-S970H)&]P=&EO;G-;)W1I;65O=70G72DI"B`@("`@("`@("`@
M("1T:&ES+3YT:6UE;W5T(#T@*&EN="DD;W!T:6]N<ULG=&EM96]U="==.PH*
M("`@("`@("!I9B`H<W1R8V%S96-M<"@D=&AI<RT^=7)L<&%R='-;)W-C:&5M
M92==+"`G2%144"<I(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<V5N9$A45%`H)&US9RP@)&]P=&EO;G,I.PH@("`@("`@('T@96QS92!I
M9B`H<W1R8V%S96-M<"@D=&AI<RT^=7)L<&%R='-;)W-C:&5M92==+"`G2%14
M4%,G*2`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W-E;F1(
M5%104R@D;7-G+"`D;W!T:6]N<RD["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'1H:7,M/E]R86ES95-O87!&875L="@G26YV86QI9"!U<FP@<V-H96UE
M("<N)'1H:7,M/G5R;"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!S970@9&%T
M82!F;W(@:'1T<"!A=71H96YT:6-A=&EO;@H@("`@("H@8W)E871E<R!!=71H
M;W)I>F%T:6]N(&AE861E<@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'5S97)N86UE("`@=7-E<FYA;64*("`@("`J($!P87)A;2!S=')I;F<@)'!A
M<W-W;W)D("`@<F5S<&]N<V4@9&%T82P@;6EN=7,@:'1T<"!H96%D97)S"B`@
M("`@*@H@("`@("H@0')E='5R;B!N;VYE"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!S971#<F5D96YT:6%L<R@D=7-E<FYA
M;64L("1P87-S=V]R9"D*("`@('L*("`@("`@("`D=&AI<RT^:&5A9&5R<ULG
M075T:&]R:7IA=&EO;B==(#T@)T)A<VEC("<@+B!B87-E-C1?96YC;V1E*"1U
M<V5R;F%M92`N("<Z)R`N("1P87-S=V]R9"D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!9&0@82!C;V]K:64*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("H@0'!A<F%M("!S=')I;F<@("1N86UE("`@8V]O:VEE(&YA;64*
M("`@("`J($!P87)A;2`@;6EX960@("`D=F%L=64@(&-O;VMI92!V86QU90H@
M("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$-O
M;VMI92@D;F%M92P@)'9A;'5E*0H@("`@>PH@("`@("`@("1T:&ES+3YC;V]K
M:65S6R1N86UE73TD=F%L=64["B`@("!]"@H@("`@+R\@<')I=F%T92!M971H
M;V1S"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T97,@=&AE(&-O<G)E8W0@:&5A
M9&5R<R!F;W(@=&AE(&-O;VMI97,*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO
M;B!?9V5N0V]O:VEE2&5A9&5R*"D*("`@('L*("`@("`@("!F;W)E86-H("@D
M=&AI<RT^8V]O:VEE<R!A<R`D;F%M93T^)'9A;'5E*2!["B`@("`@("`@("`@
M("1C;V]K:65S(#T@*&ES<V5T*"1C;V]K:65S*2`_("1C;V]K:65S+B`G.R`G
M(#H@)R<I("X*("`@("`@("`@("`@("`@("`@("`@("`@=7)L96YC;V1E*"1N
M86UE*2`N("<])R`N('5R;&5N8V]D92@D=F%L=64I.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)&-O;VMI97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!V
M86QI9&%T92!U<FP@9&%T82!P87-S960@=&\@8V]N<W1R=6-T;W(*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!R971U<FX@8F]O;&5A
M;@H@("`@("HO"B`@("!F=6YC=&EO;B!?=F%L:61A=&55<FPH*0H@("`@>PH@
M("`@("`@(&EF("@@(2!I<U]A<G)A>2@D=&AI<RT^=7)L<&%R=',I("D@>PH@
M("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")5;F%B;&4@=&\@
M<&%R<V4@55),("(@+B`D=&AI<RT^=7)L*3L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YU
M<FQP87)T<ULG:&]S="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W)A:7-E
M4V]A<$9A=6QT*").;R!H;W-T(&EN(%523"`B("X@)'1H:7,M/G5R;"D["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^=7)L<&%R='-;)W!O<G0G72DI('L*"B`@("`@("`@
M("`@(&EF("AS=')C87-E8VUP*"1T:&ES+3YU<FQP87)T<ULG<V-H96UE)UTL
M("=(5%10)RD@/3T@,"D*("`@("`@("`@("`@("`@("1T:&ES+3YU<FQP87)T
M<ULG<&]R="==(#T@.#`["B`@("`@("`@("`@(&5L<V4@:68@*'-T<F-A<V5C
M;7`H)'1H:7,M/G5R;'!A<G1S6R=S8VAE;64G72P@)TA45%!3)RD@/3T@,"D*
M("`@("`@("`@("`@("`@("1T:&ES+3YU<FQP87)T<ULG<&]R="==(#T@-#0S
M.PH*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YU<FQP87)T
M<ULG=7-E<B==*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T0W)E9&5N=&EA
M;',H=7)L9&5C;V1E*"1T:&ES+3YU<FQP87)T<ULG=7-E<B==*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=7)L9&5C;V1E*"1T:&ES
M+3YU<FQP87)T<ULG<&%S<R==*2D["B`@("`@("`@?0H@("`@("`@(&EF("@A
M:7-S970H)'1H:7,M/G5R;'!A<G1S6R=P871H)UTI('Q\("$D=&AI<RT^=7)L
M<&%R='-;)W!A=&@G72D*("`@("`@("`@("`@)'1H:7,M/G5R;'!A<G1S6R=P
M871H)UT@/2`G+R<["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!&:6YD<R!O=70@=VAA="!I<R!T:&4@96YC;V1I;F<N"B`@
M("`@*@H@("`@("H@4V5T<R!T:&4@;V)J96-T('!R;W!E<G1Y(&%C8V]R9&EN
M9VQY+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A
M<F%M("!A<G)A>2`D:&5A9&5R<R`@:&5A9&5R<PH@("`@("H@0')E='5R;B!V
M;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S945N8V]D:6YG*"1H96%D
M97)S*0H@("`@>PH@("`@("`@("1H(#T@<W1R:7-T<B@D:&5A9&5R<RP@)T-O
M;G1E;G0M5'EP92<I.PH@("`@("`@('!R96=?;6%T8VA?86QL*"<O7D-O;G1E
M;G0M5'EP93I<<RHH+BHI)"]I;2<L("1H+"`D8W0L(%!214=?4T547T]21$52
M*3L*("`@("`@("`D;B`](&-O=6YT*"1C="D["B`@("`@("`@)&-T(#T@)&-T
M6R1N("T@,5T["B`@("`@("`@)'1H:7,M/G)E<W5L=%]C;VYT96YT7W1Y<&4@
M/2!S=')?<F5P;&%C92@B7'(B+"`G)RP@)&-T6S%=*3L*("`@("`@("!I9B`H
M<')E9U]M871C:"@G+R@N*C\I*#\Z.UQS/V-H87)S970]*2@N*BDO:2<L("1T
M:&ES+3YR97-U;'1?8V]N=&5N=%]T>7!E+"`D;2DI('L*("`@("`@("`@("`@
M+R\@<W1R:7`@=&AE('-T<FEN9R!O9B!<<@H@("`@("`@("`@("`D=&AI<RT^
M<F5S=6QT7V-O;G1E;G1?='EP92`]("1M6S%=.PH@("`@("`@("`@("!I9B`H
M8V]U;G0H)&TI(#X@,BD@>PH@("`@("`@("`@("`@("`@)&5N8R`]('-T<G1O
M=7!P97(H<W1R7W)E<&QA8V4H)R(G+"`G)RP@)&U;,ETI*3L*("`@("`@("`@
M("`@("`@(&EF("AI;E]A<G)A>2@D96YC+"`D=&AI<RT^7V5N8V]D:6YG<RDI
M('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<F5S=6QT7V5N8V]D:6YG
M(#T@)&5N8SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("`O+R!D96%L('=I=&@@8G)O:V5N('-E<G9E<G,@=&AA
M="!D;VXG="!S970@8V]N=&5N="!T>7!E(&]N(&9A=6QT<PH@("`@("`@(&EF
M("@A)'1H:7,M/G)E<W5L=%]C;VYT96YT7W1Y<&4I("1T:&ES+3YR97-U;'1?
M8V]N=&5N=%]T>7!E(#T@)W1E>'0O>&UL)SL*("`@('T*"B`@("`O*BH*("`@
M("`J(%!A<G-E<R!T:&4@:&5A9&5R<PH@("`@("H*("`@("`J($!P87)A;2`@
M87)R87D@)&AE861E<G,@=&AE(&AE861E<G,*("`@("`J($!R971U<FX@=F]I
M9`H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5(96%D97)S*"1H96%D97)S
M*0H@("`@>PH@("`@("`@("\J(&QA<F=E;'D@8F]R<F]W960@9G)O;2!(5%10
M7U)E<75E<W0@*B\*("`@("`@("`D=&AI<RT^<F5S=6QT7VAE861E<G,@/2!A
M<G)A>2@I.PH@("`@("`@("1H96%D97)S(#T@<W!L:70H(EQR/UQN(BP@)&AE
M861E<G,I.PH@("`@("`@(&9O<F5A8V@@*"1H96%D97)S(&%S("1V86QU92D@
M>PH@("`@("`@("`@("!I9B`H<W1R<&]S*"1V86QU92PG.B<I(#T]/2!F86QS
M92D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G)E<W5L=%]H96%D97)S6S!=
M/21V86QU93L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&QI<W0H)&YA;64L)'9A;'5E*2`]('-P;&ET*"<Z
M)RPD=F%L=64I.PH@("`@("`@("`@("`D:&5A9&5R;F%M92`]('-T<G1O;&]W
M97(H)&YA;64I.PH@("`@("`@("`@("`D:&5A9&5R=F%L=64@/2!T<FEM*"1V
M86QU92D["B`@("`@("`@("`@("1T:&ES+3YR97-U;'1?:&5A9&5R<ULD:&5A
M9&5R;F%M95T])&AE861E<G9A;'5E.PH*("`@("`@("`@("`@:68@*"1H96%D
M97)N86UE(#T]("=S970M8V]O:VEE)RD@>PH@("`@("`@("`@("`@("`@+R\@
M4&%R<V4@82!3971#;V]K:64@:&5A9&5R('1O(&9I;&P@7V-O;VMI97,@87)R
M87D*("`@("`@("`@("`@("`@("1C;V]K:64@/2!A<G)A>2@*("`@("`@("`@
M("`@("`@("`@("`G97AP:7)E<R<@/3X@;G5L;"P*("`@("`@("`@("`@("`@
M("`@("`G9&]M86EN)R`@/3X@)'1H:7,M/G5R;'!A<G1S6R=H;W-T)UTL"B`@
M("`@("`@("`@("`@("`@("`@)W!A=&@G("`@(#T^(&YU;&PL"B`@("`@("`@
M("`@("`@("`@("`@)W-E8W5R92<@(#T^(&9A;'-E"B`@("`@("`@("`@("`@
M("`I.PH*("`@("`@("`@("`@("`@("\O($]N;'D@82!N86UE/79A;'5E('!A
M:7(*("`@("`@("`@("`@("`@(&EF("@A<W1R<&]S*"1H96%D97)V86QU92P@
M)SLG*2D@>PH@("`@("`@("`@("`@("`@("`@(&QI<W0H)&-O;VMI95LG;F%M
M92==+"`D8V]O:VEE6R=V86QU92==*2`](&%R<F%Y7VUA<"@G=')I;2<L(&5X
M<&QO9&4H)STG+"`D:&5A9&5R=F%L=64I*3L*("`@("`@("`@("`@("`@("`@
M("`D8V]O:VEE6R=N86UE)UT@(#T@=7)L9&5C;V1E*"1C;V]K:65;)VYA;64G
M72D["B`@("`@("`@("`@("`@("`@("`@)&-O;VMI95LG=F%L=64G72`]('5R
M;&1E8V]D92@D8V]O:VEE6R=V86QU92==*3L*"B`@("`@("`@("`@("`@("`O
M+R!3;VUE(&]P=&EO;F%L('!A<F%M971E<G,@87)E('-U<'!L:65D"B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1E;&5M
M96YT<R`](&5X<&QO9&4H)SLG+"`D:&5A9&5R=F%L=64I.PH@("`@("`@("`@
M("`@("`@("`@(&QI<W0H)&-O;VMI95LG;F%M92==+"`D8V]O:VEE6R=V86QU
M92==*2`](&%R<F%Y7VUA<"@G=')I;2<L(&5X<&QO9&4H)STG+"`D96QE;65N
M='-;,%TI*3L*("`@("`@("`@("`@("`@("`@("`D8V]O:VEE6R=N86UE)UT@
M(#T@=7)L9&5C;V1E*"1C;V]K:65;)VYA;64G72D["B`@("`@("`@("`@("`@
M("`@("`@)&-O;VMI95LG=F%L=64G72`]('5R;&1E8V]D92@D8V]O:VEE6R=V
M86QU92==*3L*"B`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`](#$[("1I
M(#P@8V]U;G0H)&5L96UE;G1S*3LD:2LK*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@(&QI<W0@*"1E;$YA;64L("1E;%9A;'5E*2`](&%R<F%Y7VUA<"@G
M=')I;2<L(&5X<&QO9&4H)STG+"`D96QE;65N='-;)&E=*2D["B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@G<V5C=7)E)R`]/2`D96Q.86UE*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]O:VEE6R=S96-U<F4G72`]
M('1R=64["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@G97AP
M:7)E<R<@/3T@)&5L3F%M92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&-O;VMI95LG97AP:7)E<R==(#T@<W1R7W)E<&QA8V4H)R(G+"`G)RP@
M)&5L5F%L=64I.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M)W!A=&@G(#T]("1E;$YA;64@3U(@)V1O;6%I;B<@/3T@)&5L3F%M92D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;VMI95LD96Q.86UE72`]
M('5R;&1E8V]D92@D96Q686QU92D["B`@("`@("`@("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]O:VEE
M6R1E;$YA;65=(#T@)&5L5F%L=64["B`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D=&AI<RT^<F5S=6QT7V-O;VMI97-;72`]("1C;V]K
M:64["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!296UO=F4@:'1T<"!H96%D97)S(&9R;VT@<F5S<&]N<V4*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5297-P;VYS92@I"B`@("![
M"B`@("`@("`@:68@*'!R96=?;6%T8V@H(B]>*"XJ/RE<<C]<;EQR/UQN*"XJ
M*2]S(BP@)'1H:7,M/FEN8V]M:6YG7W!A>6QO860L("1M871C:"DI('L*("`@
M("`@("`@("`@(R1T:&ES+3YR97-P;VYS92`]('!R96=?<F5P;&%C92@B+UM<
M<GQ<;ETO(BP@)R<L("1M871C:%LR72D["B`@("`@("`@("`@("1T:&ES+3YR
M97-P;VYS92`])B`D;6%T8VA;,ET["B`@("`@("`@("`@("\O(&9I;F0@=&AE
M(')E<W!O;G-E(&5R<F]R+"!S;VUE('-E<G9E<G,@<F5S<&]N<V4@=VET:"`U
M,#`@9F]R('-O87`@9F%U;'1S"B`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5(
M96%D97)S*"1M871C:%LQ72D["@H@("`@("`@("`@("!L:7-T*"1P<F]T;V-O
M;"P@)&-O9&4L("1M<V<I(#T@<W-C86YF*"1T:&ES+3YR97-U;'1?:&5A9&5R
M<ULP72P@)R5S("5S("5S)RD["B`@("`@("`@("`@('5N<V5T*"1T:&ES+3YR
M97-U;'1?:&5A9&5R<ULP72D["@H@("`@("`@("`@("!S=VET8V@H)&-O9&4I
M('L*("`@("`@("`@("`@("`@(&-A<V4@,3`P.B`O+R!#;VYT:6YU90H@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/FEN8V]M:6YG7W!A>6QO860@/2`D;6%T
M8VA;,ET["B`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P87)S
M95)E<W!O;G-E*"D["B`@("`@("`@("`@("`@("!C87-E(#0P,#H*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")(5%10(%)E
M<W!O;G-E("1C;V1E($)A9"!297%U97-T(BD["B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@8V%S92`T,#$Z"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]R86ES95-O87!&875L="@B2%144"!297-P;VYS92`D8V]D92!!
M=71H96YT:6-A=&EO;B!&86EL960B*3L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("!C87-E(#0P,SH*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W)A:7-E4V]A<$9A=6QT*")(5%10(%)E<W!O;G-E("1C;V1E($9O<F)I
M9&1E;B(I.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@
M-#`T.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U
M;'0H(DA45%`@4F5S<&]N<V4@)&-O9&4@3F]T($9O=6YD(BD["B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`T,#<Z"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@B2%144"!297-P;VYS
M92`D8V]D92!0<F]X>2!!=71H96YT:6-A=&EO;B!297%U:7)E9"(I.PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@-#`X.@H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(DA45%`@4F5S
M<&]N<V4@)&-O9&4@4F5Q=65S="!4:6UE;W5T(BD["B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@8V%S92`T,3`Z"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]R86ES95-O87!&875L="@B2%144"!297-P;VYS92`D8V]D
M92!';VYE(BD["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@9&5F
M875L=#H*("`@("`@("`@("`@("`@("`@("!I9B`H)&-O9&4@/CT@-#`P("8F
M("1C;V1E(#P@-3`P*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<F%I<V53;V%P1F%U;'0H(DA45%`@4F5S<&]N<V4@)&-O9&4@3F]T($9O
M=6YD+"!397)V97(@;65S<V%G93H@)&US9R(I.PH@("`@("`@("`@("`@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7W!A<G-E16YC;V1I
M;F<H)&UA=&-H6S%=*3L*"B`@("`@("`@("`@(&EF("@D=&AI<RT^<F5S=6QT
M7V-O;G1E;G1?='EP92`]/2`G87!P;&EC871I;VXO9&EM92<I('L*("`@("`@
M("`@("`@("`@("\O(%A86"!Q=6EC:R!H86-K(&EN<V5R=&EO;B!O9B!$24U%
M"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D=&AI<RT^7V1E
M8V]D941)345-97-S86=E*"1T:&ES+3YR97-P;VYS92PD=&AI<RT^:&5A9&5R
M<RPD=&AI<RT^871T86-H;65N=',I*2D@>PH@("`@("`@("`@("`@("`@("`@
M("\O(%]D96-O9&5$24U%365S<V%G92!A;')E861Y(')A:7-E9"`D=&AI<RT^
M9F%U;'0*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^<F5S=6QT7V-O
M;G1E;G1?='EP92`]("1T:&ES+3YH96%D97)S6R=C;VYT96YT+71Y<&4G73L*
M("`@("`@("`@("`@?2!E;'-E(&EF("AS=')I<W1R*"1T:&ES+3YR97-U;'1?
M8V]N=&5N=%]T>7!E+"=M=6QT:7!A<G0O<F5L871E9"<I*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^<F5S<&]N<V4@/2`D=&AI<RT^:6YC;VUI;F=?<&%Y
M;&]A9#L*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1T:&ES
M+3Y?9&5C;V1E36EM94UE<W-A9V4H)'1H:7,M/G)E<W!O;G-E+"1T:&ES+3YH
M96%D97)S+"1T:&ES+3YA='1A8VAM96YT<RDI*2!["B`@("`@("`@("`@("`@
M("`@("`@+R\@7V1E8V]D94UI;65-97-S86=E(&%L<F5A9'D@<F%I<V5D("1T
M:&ES+3YF875L=`H@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E(&EF("@D=&AI
M<RT^<F5S=6QT7V-O;G1E;G1?='EP92`A/2`G=&5X="]X;6PG*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"1T:&ES+3YR97-P
M;VYS92D["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@+R\@:68@;F\@8V]N=&5N="P@<F5T=7)N(&9A
M;'-E"B`@("`@("`@("`@(')E='5R;B!S=')L96XH)'1H:7,M/G)E<W!O;G-E
M*2`^(#`["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U
M;'0H)TEN=F%L:60@2%144"!297-P;VYS92<I.PH@("`@("`@(')E='5R;B!F
M86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!H='1P(')E<75E
M<W0L(&EN8VQU9&EN9R!H96%D97)S+"!F;W(@;W5T9V]I;F<@<F5Q=65S=`H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("`F)&US9R`@(&]U=&=O:6YG
M(%-/05`@<&%C:V%G90H@("`@("H@0'!A<F%M("1O<'1I;VYS"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R!O=71G;VEN9U]P87EL;V%D"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@)E]G971297%U97-T*"8D
M;7-G+"`D;W!T:6]N<RD*("`@('L*("`@("`@("`D86-T:6]N(#T@:7-S970H
M)&]P=&EO;G-;)W-O87!A8W1I;VXG72D_)&]P=&EO;G-;)W-O87!A8W1I;VXG
M73HG)SL*("`@("`@("`D9G5L;'!A=&@@/2`D=&AI<RT^=7)L<&%R='-;)W!A
M=&@G72X*("`@("`@("`@("`@("`@("`@("`@("`@*&ES<V5T*"1T:&ES+3YU
M<FQP87)T<ULG<75E<GDG72D_)S\G+B1T:&ES+3YU<FQP87)T<ULG<75E<GDG
M73HG)RDN"B`@("`@("`@("`@("`@("`@("`@("`@("AI<W-E="@D=&AI<RT^
M=7)L<&%R='-;)V9R86=M96YT)UTI/R<C)RXD=&AI<RT^=7)L<&%R='-;)V9R
M86=M96YT)UTZ)R<I.PH*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W!R
M;WAY7VAO<W0G72DI('L*("`@("`@("`@("`@)&9U;&QP871H(#T@)VAT='`Z
M+R\G("X@)'1H:7,M/G5R;'!A<G1S6R=H;W-T)UT@+B`G.B<@+B`D=&AI<RT^
M=7)L<&%R='-;)W!O<G0G72`N("1F=6QL<&%T:#L*("`@("`@("!]"@H@("`@
M("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<')O>'E?=7-E<B==*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^:&5A9&5R<ULG4')O>'DM075T:&]R:7IA=&EO;B==
M(#T@)T)A<VEC("<@+B!B87-E-C1?96YC;V1E*"1O<'1I;VYS6R=P<F]X>5]U
M<V5R)UTN(CHB+B1O<'1I;VYS6R=P<F]X>5]P87-S)UTI.PH@("`@("`@('T*
M"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=U<V5R)UTI*2!["B`@("`@
M("`@("`@("1T:&ES+3YS971#<F5D96YT:6%L<R@D;W!T:6]N<ULG=7-E<B==
M+"`D;W!T:6]N<ULG<&%S<R==*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3YH96%D97)S6R=5<V5R+4%G96YT)UT@/2`D=&AI<RT^7W5S97)!9V5N=#L*
M("`@("`@("`D=&AI<RT^:&5A9&5R<ULG2&]S="==(#T@)'1H:7,M/G5R;'!A
M<G1S6R=H;W-T)UT["B`@("`@("`@)'1H:7,M/FAE861E<G-;)T-O;G1E;G0M
M5'EP92==(#T@(G1E>'0O>&UL.R!C:&%R<V5T/21T:&ES+3YE;F-O9&EN9R([
M"B`@("`@("`@)'1H:7,M/FAE861E<G-;)T-O;G1E;G0M3&5N9W1H)UT@/2!S
M=')L96XH)&US9RD["B`@("`@("`@)'1H:7,M/FAE861E<G-;)U-/05!!8W1I
M;VXG72`](")<(B1A8W1I;VY<(B(["B`@("`@("`@:68@*&ES<V5T*"1O<'1I
M;VYS6R=H96%D97)S)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YH96%D97)S
M(#T@87)R87E?;65R9V4H)'1H:7,M/FAE861E<G,L("1O<'1I;VYS6R=H96%D
M97)S)UTI.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/F-O;VMI97,@/2!A
M<G)A>2@I.PH@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)VYO8V]O:VEE
M<R==*2!\?"`A)&]P=&EO;G-;)VYO8V]O:VEE<R==*2!["B`@("`@("`@("`@
M("\O(&%D9"!T:&4@8V]O:VEE<R!W92!G;W0@9G)O;2!T:&4@;&%S="!R97%U
M97-T"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^<F5S=6QT7V-O;VMI
M97,I*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^<F5S=6QT
M7V-O;VMI97,@87,@)&-O;VMI92D@>PH@("`@("`@("`@("`@("`@("`@(&EF
M("@D8V]O:VEE6R=D;VUA:6XG72`]/2`D=&AI<RT^=7)L<&%R='-;)VAO<W0G
M72D*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-O;VMI97-;)&-O
M;VMI95LG;F%M92==73TD8V]O:VEE6R=V86QU92==.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("\O(&%D9"!C
M;V]K:65S('1H92!U<V5R('=A;G1S('1O('-E=`H@("`@("`@(&EF("AI<W-E
M="@D;W!T:6]N<ULG8V]O:VEE<R==*2D@>PH@("`@("`@("`@("!F;W)E86-H
M("@D;W!T:6]N<ULG8V]O:VEE<R==(&%S("1C;V]K:64I('L*("`@("`@("`@
M("`@("`@(&EF("@D8V]O:VEE6R=D;VUA:6XG72`]/2`D=&AI<RT^=7)L<&%R
M='-;)VAO<W0G72D*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V]O:VEE
M<ULD8V]O:VEE6R=N86UE)UU=/21C;V]K:65;)W9A;'5E)UT["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@:68@*&-O=6YT*"1T:&ES+3YC;V]K
M:65S*2D@>PH@("`@("`@("`@("`D=&AI<RT^:&5A9&5R<ULG0V]O:VEE)UT@
M/2`D=&AI<RT^7V=E;D-O;VMI94AE861E<B@I.PH@("`@("`@('T*("`@("`@
M("`D:&5A9&5R<R`]("<G.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YH96%D
M97)S(&%S("1K(#T^("1V*2!["B`@("`@("`@("`@("1H96%D97)S("X]("(D
M:SH@)'9<<EQN(CL*("`@("`@("!]"B`@("`@("`@)'1H:7,M/F]U=&=O:6YG
M7W!A>6QO860@/0H@("`@("`@("`@("`@("`@(E!/4U0@)&9U;&QP871H($A4
M5%`O,2XP7')<;B(N"B`@("`@("`@("`@("`@("`D:&5A9&5R<RXB7')<;B(N
M"B`@("`@("`@("`@("`@("`D;7-G.PH@("`@("`@(')E='5R;B`D=&AI<RT^
M;W5T9V]I;F=?<&%Y;&]A9#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E;F0@
M;W5T9V]I;F<@<F5Q=65S="P@86YD(')E860O<&%R<V4@<F5S<&]N<V4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`F)&US9R`@(&]U=&=O:6YG(%-/
M05`@<&%C:V%G90H@("`@("H@0'!A<F%M('-T<FEN9R`@)&%C=&EO;B`@(%-/
M05`@06-T:6]N"B`@("`@*B!`<F5T=7)N('-T<FEN9R`F)')E<W!O;G-E("`@
M<F5S<&]N<V4@9&%T82P@;6EN=7,@:'1T<"!H96%D97)S"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@)E]S96YD2%144"@F
M)&US9RP@)&]P=&EO;G,I"B`@("!["B`@("`@("`@)'1H:7,M/FEN8V]M:6YG
M7W!A>6QO860@/2`G)SL*("`@("`@("`D=&AI<RT^7V=E=%)E<75E<W0H)&US
M9RP@)&]P=&EO;G,I.PH@("`@("`@("1H;W-T(#T@)'1H:7,M/G5R;'!A<G1S
M6R=H;W-T)UT["B`@("`@("`@)'!O<G0@/2`D=&AI<RT^=7)L<&%R='-;)W!O
M<G0G73L*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W!R;WAY7VAO<W0G
M72DI('L*("`@("`@("`@("`@)&AO<W0@/2`D;W!T:6]N<ULG<')O>'E?:&]S
M="==.PH@("`@("`@("`@("`D<&]R="`](&ES<V5T*"1O<'1I;VYS6R=P<F]X
M>5]P;W)T)UTI(#\@)&]P=&EO;G-;)W!R;WAY7W!O<G0G72`Z(#@P.#`["B`@
M("`@("`@?0H@("`@("`@("\O('-E;F0*("`@("`@("!I9B`H)'1H:7,M/G1I
M;65O=70@/B`P*2!["B`@("`@("`@("`@("1F<"`]($!F<V]C:V]P96XH)&AO
M<W0L("1P;W)T+"`D=&AI<RT^97)R;F\L("1T:&ES+3YE<G)M<V<L("1T:&ES
M+3YT:6UE;W5T*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9G`@
M/2!`9G-O8VMO<&5N*"1H;W-T+"`D<&]R="P@)'1H:7,M/F5R<FYO+"`D=&AI
M<RT^97)R;7-G*3L*("`@("`@("!]"B`@("`@("`@:68@*"$D9G`I('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(D-O;FYE
M8W0@17)R;W(@=&\@)&AO<W0Z)'!O<G0B*3L*("`@("`@("!]"B`@("`@("`@
M:68@*"1T:&ES+3YT:6UE;W5T(#X@,"D@>PH@("`@("`@("`@("`O+R!S;VUE
M(&)U:6QD<R!O9B!P:'`@9&\@;F]T('-U<'!O<G0@=&AI<RP@<VEL96YC90H@
M("`@("`@("`@("`O+R!T:&4@=V%R;FEN9PH@("`@("`@("`@("!`<V]C:V5T
M7W-E=%]T:6UE;W5T*"1F<"P@)'1H:7,M/G1I;65O=70I.PH@("`@("`@('T*
M("`@("`@("!I9B`H(69P=71S*"1F<"P@)'1H:7,M/F]U=&=O:6YG7W!A>6QO
M860L('-T<FQE;B@D=&AI<RT^;W5T9V]I;F=?<&%Y;&]A9"DI*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")%<G)O<B!0
M3U-4:6YG($1A=&$@=&\@)&AO<W0B*3L*("`@("`@("!]"@H@("`@("`@("\O
M(&=E="!R97!O;G-E"B`@("`@("`@+R\@6%A8('1I;64@8V]N<W5M97(*("`@
M("`@("!D;R!["B`@("`@("`@("`@("1D871A(#T@9G)E860H)&9P+"`T,#DV
M*3L*("`@("`@("`@("`@)%]T;7!?<W1A='5S(#T@<V]C:V5T7V=E=%]S=&%T
M=7,H)&9P*3L*("`@("`@("`@("`@:68@*"1?=&UP7W-T871U<ULG=&EM961?
M;W5T)UTI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E
M4V]A<$9A=6QT*")4:6UE9"!O=70@<F5A9"!F<F]M("1H;W-T(BD["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^:6YC;VUI
M;F=?<&%Y;&]A9"`N/2`D9&%T83L*("`@("`@("`@("`@?0H@("`@("`@('T@
M=VAI;&4@*"$D7W1M<%]S=&%T=7-;)V5O9B==*3L*"B`@("`@("`@9F-L;W-E
M*"1F<"D["@H@("`@("`@(&EF("@A)'1H:7,M/E]P87)S95)E<W!O;G-E*"DI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YF875L=#L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YR97-P;VYS93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E;F0@;W5T9V]I;F<@<F5Q=65S="P@86YD(')E860O<&%R
M<V4@<F5S<&]N<V4L('9I82!(5%104PH@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@("8D;7-G("`@;W5T9V]I;F<@4T]!4"!P86-K86=E"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D86-T:6]N("`@4T]!4"!!8W1I;VX*("`@("`J($!R
M971U<FX@<W1R:6YG("8D<F5S<&]N<V4@("!R97-P;VYS92!D871A+"!M:6YU
M<R!H='1P(&AE861E<G,*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!F=6YC=&EO;B`F7W-E;F1(5%104R@F)&US9RP@)&]P=&EO;G,I"B`@
M("!["B`@("`@("`@+RH@3D]412!4:&ES(&9U;F-T:6]N('5S97,@=&AE($-5
M4DP@9G5N8W1I;VYS"B`@("`@("`@("H@(%EO=7(@<&AP(&UU<W0@8F4@8V]M
M<&EL960@=VET:"!#55),"B`@("`@("`@("HO"B`@("`@("`@:68@*"%E>'1E
M;G-I;VY?;&]A9&5D*"=C=7)L)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<F%I<V53;V%P1F%U;'0H)T-54DP@17AT96YS:6]N(&ES(')E<75I
M<F5D(&9O<B!(5%104R<I.PH@("`@("`@('T*"B`@("`@("`@)&-H(#T@8W5R
M;%]I;FET*"D["@H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<')O>'E?
M:&]S="==*2D@>PH@("`@("`@("`@("`O+R`D;W!T:6]N<ULG:'1T<%]P<F]X
M>2==(#T]("=H;W-T;F%M93IP;W)T)PH@("`@("`@("`@("`D:&]S="`]("1O
M<'1I;VYS6R=P<F]X>5]H;W-T)UT["B`@("`@("`@("`@("1P;W)T(#T@:7-S
M970H)&]P=&EO;G-;)W!R;WAY7W!O<G0G72D@/R`D;W!T:6]N<ULG<')O>'E?
M<&]R="==(#H@.#`X,#L*("`@("`@("`@("`@8W5R;%]S971O<'0H)&-H+"!#
M55),3U!47U!23UA9+"`D:&]S="`N("(Z(B`N("1P;W)T*3L*("`@("`@("!]
M"@H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<')O>'E?=7-E<B==*2D@
M>PH@("`@("`@("`@("`O+R`D;W!T:6]N<ULG:'1T<%]P<F]X>5]U<V5R<'<G
M72`]/2`G=7-E<FYA;64Z<&%S<W=O<F0G"B`@("`@("`@("`@(&-U<FQ?<V5T
M;W!T*"1C:"P@0U523$]05%]04D]8655315)05T0L("1O<'1I;VYS6R=P<F]X
M>5]U<V5R)UT@+B`G.B<@+B`D;W!T:6]N<ULG<')O>'E?<&%S<R==*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG=7-E<B==*2D@
M>PH@("`@("`@("`@("!C=7)L7W-E=&]P="@D8V@L($-54DQ/4%1?55-%4E!7
M1"P@)&]P=&EO;G-;)W5S97(G72`N("<Z)R`N("1O<'1I;VYS6R=P87-S)UTI
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]A
M<&%C=&EO;B==*2D@>PH@("`@("`@("`@("`D;W!T:6]N<ULG<V]A<&%C=&EO
M;B==(#T@)R<["B`@("`@("`@?0H@("`@("`@(&-U<FQ?<V5T;W!T*"1C:"P@
M0U523$]05%](5%102$5!1$52("P@("`@87)R87DH)T-O;G1E;G0M5'EP93H@
M=&5X="]X;6P[8VAA<G-E=#TG("X@)'1H:7,M/F5N8V]D:6YG+"`G4T]!4$%C
M=&EO;CH@(B<N)&]P=&EO;G-;)W-O87!A8W1I;VXG72XG(B<I*3L*("`@("`@
M("!C=7)L7W-E=&]P="@D8V@L($-54DQ/4%1?55-%4D%'14Y4("P@("`@("1T
M:&ES+3Y?=7-E<D%G96YT*3L*"B`@("`@("`@:68@*"1T:&ES+3YT:6UE;W5T
M*2!["B`@("`@("`@("`@(&-U<FQ?<V5T;W!T*"1C:"P@0U523$]05%]424U%
M3U54+"`D=&AI<RT^=&EM96]U="D[("\O=&EM97,@;W5T(&%F=&5R(#1S"B`@
M("`@("`@?0H*("`@("`@("!C=7)L7W-E=&]P="@D8V@L($-54DQ/4%1?4$]3
M5$9)14Q$4RP@("`@("`@)&US9RD["B`@("`@("`@8W5R;%]S971O<'0H)&-H
M+"!#55),3U!47U523"P@("`@("`@("`@("`@("1T:&ES+3YU<FPI.PH@("`@
M("`@(&-U<FQ?<V5T;W!T*"1C:"P@0U523$]05%]03U-4+"`@("`@("`@("`@
M("`Q*3L*("`@("`@("!C=7)L7W-E=&]P="@D8V@L($-54DQ/4%1?1D%)3$].
M15)23U(L("`@("`@,"D["B`@("`@("`@8W5R;%]S971O<'0H)&-H+"!#55),
M3U!47T9/3$Q/5TQ/0T%424].+"`@(#$I.PH@("`@("`@(&-U<FQ?<V5T;W!T
M*"1C:"P@0U523$]05%]215154DY44D%.4T9%4BP@("`Q*3L*("`@("`@("!C
M=7)L7W-E=&]P="@D8V@L($-54DQ/4%1?2$5!1$52+"`@("`@("`@("`@,2D[
M"B`@("`@("`@:68@*&1E9FEN960H)T-54DQ/4%1?2%144%]615)324].)RDI
M('L*("`@("`@("`@("`@8W5R;%]S971O<'0H)&-H+"!#55),3U!47TA45%!?
M5D524TE/3BP@,2D["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)&]P
M=&EO;G-;)V-U<FPG72DI('L*("`@("`@("`@("`@9F]R96%C:"`H)&]P=&EO
M;G-;)V-U<FPG72!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@
M(&-U<FQ?<V5T;W!T*"1C:"P@)&ME>2P@)'9A;"D["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("\O(%-A=F4@=&AE(&]U=&=O:6YG(%A-3"X@
M5&AI<R!D;V5S;B=T('%U:71E(&UA=&-H(%]S96YD2%144`H@("`@("`@("\O
M(&%S($-54DP@9V5N97)A=&5S('1H92!H96%D97)S+"!B=70@:&%V:6YG('1H
M92!834P@:7,*("`@("`@("`O+R!U<W5A;&QY('1H92!M;W-T(&EM<&]R=&%N
M="!P87)T(&9O<B!T<F%C:6YG+V1E8G5G9VEN9RX*("`@("`@("`D=&AI<RT^
M;W5T9V]I;F=?<&%Y;&]A9"`]("1M<V<["@H@("`@("`@("1T:&ES+3YI;F-O
M;6EN9U]P87EL;V%D(#T@8W5R;%]E>&5C*"1C:"D["B`@("`@("`@:68@*"$D
M=&AI<RT^:6YC;VUI;F=?<&%Y;&]A9"D@>PH@("`@("`@("`@("`D;2`]("=C
M=7)L7V5X96,@97)R;W(@)R`N(&-U<FQ?97)R;F\H)&-H*2`N("<@)R`N(&-U
M<FQ?97)R;W(H)&-H*3L*("`@("`@("`@("`@8W5R;%]C;&]S92@D8V@I.PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@D;2D[
M"B`@("`@("`@?0H@("`@("`@(&-U<FQ?8VQO<V4H)&-H*3L*"B`@("`@("`@
M:68@*"$D=&AI<RT^7W!A<G-E4F5S<&]N<V4H*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/F9A=6QT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1T:&ES+3YR97-P;VYS93L*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+U-/05`O5')A;G-P;W)T+U--5%`N<&AP````
M`````````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$V,S(T`#$P-3$U-#,S-S,W
M`#`R,C8T-P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@5&AI<R!F:6QE(&-O;G1A:6YS('1H92!C;V1E
M(&9O<B!A;B!33510('1R86YS<&]R="!L87EE<BX*("H*("H@5&AI<R!C;V1E
M(&ES('-T:6QL(&$@<F]U9V@@86YD('5N=&5S=&5D(&1R869T+@H@*B!43T1/
M.@H@*B`@<W=I=&-H('1O('!E87(@;6%I;"!S='5F9@H@*B`@<VUT<"!A=71H
M96YT:6-A=&EO;@H@*B`@<VUT<"!S<VP@<W5P<&]R=`H@*B`@86)I;&ET>2!T
M;R!D969I;F4@<VUT<"!O<'1I;VYS("AE;F-O9&EN9RP@9G)O;2P@971C+BD*
M("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T
M:&4@4$A0(&QI8V5N<V4L"B`J('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@
M<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@879A:6QA8FQE
M(&%T"B`J('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@
M=6YA8FQE('1O(&]B=&%I;B!I=`H@*B!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S
M;R!W92!C86X*("H@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@
M*B!`8V%T96=O<GD@("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@4T]!
M4`H@*B!`875T:&]R("`@("!3:&%N92!#87)A=F5O(#Q3:&%N94!#87)A=F5O
M+F-O;3X*("H@0&-O<'ER:6=H="`@,C`P,RTR,#`U(%1H92!02%`@1W)O=7`*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P
M,BYT>'0@(%!(4"!,:6-E;G-E(#(N,#(*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+U-/05`*("HO"@IR97%U:7)E7V]N8V4@
M)U-/05`O0F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TUA:6PO<VUT<"YP:'`G
M.PH*+RHJ"B`J("!33510(%1R86YS<&]R="!F;W(@4T]!4`H@*@H@*B!I;7!L
M96UE;G1S(%-/05`M4TU44"!A<R!D969I;F5D(&%T"B`J(&AT='`Z+R]W=W<N
M<&]C:V5T<V]A<"YC;VTO<W!E8W,O<VUT<&)I;F1I;F<O"B`J"B`J(%1/1$\Z
M('5S92!014%2('-M='`@86YD($UI;64@8VQA<W-E<PH@*@H@*B!`86-C97-S
M('!U8FQI8PH@*B!`<&%C:V%G92!33T%0"B`J($!A=71H;W(@4VAA;F4@0V%R
M879E;R`\<VAA;F5`<&AP+FYE=#X*("HO"F-L87-S(%-/05!?5')A;G-P;W)T
M7U--5%`@97AT96YD<R!33T%07T)A<V4*>PH*("`@('9A<B`D8W)E9&5N=&EA
M;',@/2`G)SL*("`@('9A<B`D=&EM96]U="`](#0[("\O(&-O;FYE8W0@=&EM
M96]U=`H@("`@=F%R("1U<FQP87)T<R`]($Y53$P["B`@("!V87(@)'5R;"`]
M("<G.PH@("`@=F%R("1I;F-O;6EN9U]P87EL;V%D(#T@)R<["B`@("!V87(@
M)%]U<V5R06=E;G0@/2!33T%07TQ)0E)!4EE?3D%-13L*("`@('9A<B`D96YC
M;V1I;F<@/2!33T%07T1%1D%53%1?14Y#3T1)3D<["B`@("!V87(@)&AO<W0@
M/2`G,3(W+C`N,"XQ)SL*("`@('9A<B`D<&]R="`](#(U.PH@("`@=F%R("1A
M=71H(#T@3E5,3#L*("`@("\J*@H@("`@*B!33T%07U1R86YS<&]R=%]33510
M($-O;G-T<G5C=&]R"B`@("`J"B`@("`J($!P87)A;2!S=')I;F<@)%523"`@
M("!M86EL=&\Z861D<F5S<PH@("`@*@H@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@*B\*("`@(&9U;F-T:6]N(%-/05!?5')A;G-P;W)T7U--5%`H)%523"P@
M)&5N8V]D:6YG/2=54RU!4T-)22<I"B`@("!["B`@("`@("`@<&%R96YT.CI3
M3T%07T)A<V4H)U--5%`G*3L*("`@("`@("`D=&AI<RT^96YC;V1I;F<@/2`D
M96YC;V1I;F<["B`@("`@("`@)'1H:7,M/G5R;'!A<G1S(#T@0'!A<G-E7W5R
M;"@D55),*3L*("`@("`@("`D=&AI<RT^=7)L(#T@)%523#L*("`@('T*"B`@
M("`O*BH*("`@("H@<V5N9"!A;F0@<F5C96EV92!S;V%P(&1A=&$*("`@("H*
M("`@("H@0'!A<F%M('-T<FEN9R`F)&US9R`@("`@("!O=71G;VEN9R!P;W-T
M(&1A=&$*("`@("H@0'!A<F%M('-T<FEN9R`D86-T:6]N("`@("`@4T]!4"!!
M8W1I;VX@:&5A9&5R(&1A=&$*("`@("H@0'!A<F%M(&EN="`D=&EM96]U="`@
M<V]C:V5T('1I;65O=70L(&1E9F%U;'0@,"!O<B!O9F8*("`@("H*("`@("H@
M0')E='5R;B!S=')I;F<@)B1R97-P;VYS92`@(')E<W!O;G-E(&1A=&$L(&UI
M;G5S(&AT='`@:&5A9&5R<PH@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B\*
M("`@(&9U;F-T:6]N('-E;F0H)B1M<V<L("`O*F%R<F%Y*B\@)&]P=&EO;G,@
M/2!.54Q,*0H@("`@>PH@("`@("`@("1T:&ES+3YI;F-O;6EN9U]P87EL;V%D
M(#T@)R<["B`@("`@("`@)'1H:7,M/F]U=&=O:6YG7W!A>6QO860@/2`F)&US
M9SL*("`@("`@("!I9B`H(21T:&ES+3Y?=F%L:61A=&55<FPH*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/F9A=6QT.PH@("`@("`@('T*("`@("`@
M("!I9B`H(21O<'1I;VYS('Q\("%A<G)A>5]K97E?97AI<W1S*"=F<F]M)RPD
M;W!T:6]N<RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53
M;V%P1F%U;'0H(DYO($923TT@861D<F5S<R!T;R!S96YD(&UE<W-A9V4@=VET
M:"(I.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=H
M;W-T)UTI*2`D=&AI<RT^:&]S="`]("1O<'1I;VYS6R=H;W-T)UT["B`@("`@
M("`@:68@*&ES<V5T*"1O<'1I;VYS6R=P;W)T)UTI*2`D=&AI<RT^<&]R="`]
M("1O<'1I;VYS6R=P;W)T)UT["B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS
M6R=A=71H)UTI*2`D=&AI<RT^875T:"`]("1O<'1I;VYS6R=A=71H)UT["B`@
M("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=U<V5R;F%M92==*2D@)'1H:7,M
M/G5S97)N86UE(#T@)&]P=&EO;G-;)W5S97)N86UE)UT["B`@("`@("`@:68@
M*&ES<V5T*"1O<'1I;VYS6R=P87-S=V]R9"==*2D@)'1H:7,M/G!A<W-W;W)D
M(#T@)&]P=&EO;G-;)W!A<W-W;W)D)UT["@H@("`@("`@("1H96%D97)S(#T@
M87)R87DH*3L*("`@("`@("`D:&5A9&5R<ULG1G)O;2==(#T@)&]P=&EO;G-;
M)V9R;VTG73L*("`@("`@("`D:&5A9&5R<ULG6"U-86EL97(G72`]("1T:&ES
M+3Y?=7-E<D%G96YT.PH@("`@("`@("1H96%D97)S6R=-24U%+59E<G-I;VXG
M72`]("<Q+C`G.PH@("`@("`@("1H96%D97)S6R=-97-S86=E+4E$)UT@/2!M
M9#4H=&EM92@I*2XG+G-O87!`)RXD=&AI<RT^:&]S=#L*("`@("`@("`D:&5A
M9&5R<ULG5&\G72`]("1T:&ES+3YU<FQP87)T<ULG<&%T:"==.PH@("`@("`@
M(&EF("AA<G)A>5]K97E?97AI<W1S*"=S;V%P86-T:6]N)RP@)&]P=&EO;G,I
M*2!["B`@("`@("`@("`@("1H96%D97)S6R=3;V%P86-T:6]N)UT@/2`B7")[
M)&]P=&EO;G-;)W-O87!A8W1I;VXG77U<(B(["B`@("`@("`@?0H*("`@("`@
M("!I9B`H:7-S970H)&]P=&EO;G-;)VAE861E<G,G72DI"B`@("`@("`@("`@
M("1H96%D97)S(#T@87)R87E?;65R9V4H)&AE861E<G,L("1O<'1I;VYS6R=H
M96%D97)S)UTI.PH*("`@("`@("`O+R!I9B!T:&4@8V]N=&5N="!T>7!E(&ES
M(&%L<F5A9'D@<V5T+"!W92!A<W-U;64@=&AA="!-:6UE(&5N8V]D:6YG"B`@
M("`@("`@+R\@:7,@86QR96%D>2!D;VYE"B`@("`@("`@:68@*&ES<V5T*"1H
M96%D97)S6R=#;VYT96YT+51Y<&4G72DI('L*("`@("`@("`@("`@)&]U="`]
M("1M<V<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@9&\@82!S
M:6UP;&4@:6YL:6YE($UI;64@96YC;V1I;F<*("`@("`@("`@("`@)&AE861E
M<G-;)T-O;G1E;G0M1&ES<&]S:71I;VXG72`]("=I;FQI;F4G.PH@("`@("`@
M("`@("`D:&5A9&5R<ULG0V]N=&5N="U4>7!E)UT@/2`B=&5X="]X;6P[(&-H
M87)S970]7"(D=&AI<RT^96YC;V1I;F=<(B(["B`@("`@("`@("`@(&EF("AA
M<G)A>5]K97E?97AI<W1S*"=T<F%N<V9E<BUE;F-O9&EN9R<L("1O<'1I;VYS
M*2D@>PH@("`@("`@("`@("`@("`@:68@*'-T<F-A<V5C;7`H)&]P=&EO;G-;
M)W1R86YS9F5R+65N8V]D:6YG)UTL)W%U;W1E9"UP<FEN=&%B;&4G*3T],"D@
M>PH@("`@("`@("`@("`@("`@("`@("1H96%D97)S6R=#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG)UT@/2`D;W!T:6]N<ULG=')A;G-F97(M96YC;V1I;F<G
M73L*("`@("`@("`@("`@("`@("`@("`D;W5T(#T@)B1M<V<["B`@("`@("`@
M("`@("`@("!](&5L<V4@:68@*'-T<F-A<V5C;7`H)&]P=&EO;G-;)W1R86YS
M9F5R+65N8V]D:6YG)UTL)V)A<V4V-"<I/3TP*2!["B`@("`@("`@("`@("`@
M("`@("`@)&AE861E<G-;)T-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<G72`]
M("=B87-E-C0G.PH@("`@("`@("`@("`@("`@("`@("1O=70@/2!C:'5N:U]S
M<&QI="AB87-E-C1?96YC;V1E*"1M<V<I+#<V+")<;B(I.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]R86ES95-O87!&875L="@B26YV86QI9"!4<F%N<V9E<B!%;F-O9&EN
M9SH@>R1O<'1I;VYS6R=T<F%N<V9E<BUE;F-O9&EN9R==?2(I.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@+R\@9&5F875L="!T;R!B87-E-C0*("`@("`@("`@("`@("`@("1H96%D
M97)S6R=#;VYT96YT+51R86YS9F5R+45N8V]D:6YG)UT@/2`G8F%S938T)SL*
M("`@("`@("`@("`@("`@("1O=70@/2!C:'5N:U]S<&QI="AB87-E-C1?96YC
M;V1E*"1M<V<I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M)&AE861E<G-;)U-U8FIE8W0G72`](&%R<F%Y7VME>5]E>&ES=',H)W-U8FIE
M8W0G+"`D;W!T:6]N<RD@/R`D;W!T:6]N<ULG<W5B:F5C="==(#H@)U-/05`@
M365S<V%G92<["@H@("`@("`@(&9O<F5A8V@@*"1H96%D97)S(&%S("1K97D@
M/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1H96%D97)?=&5X="`N/2`B)&ME
M>3H@)'9A;'5E7&XB.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^;W5T9V]I
M;F=?<&%Y;&]A9"`]("1H96%D97)?=&5X="XB7')<;B(N)'1H:7,M/F]U=&=O
M:6YG7W!A>6QO860["B`@("`@("`@(R!W92!W86YT('1O(')E='5R;B!A('!R
M;W!E<B!834P@;65S<V%G90H*("`@("`@("`D;6%I;&5R7W!A<F%M<R`](&%R
M<F%Y*`H@("`@("`@("`@("`G:&]S="<@/3X@)'1H:7,M/FAO<W0L"B`@("`@
M("`@("`@("=P;W)T)R`]/B`D=&AI<RT^<&]R="P*("`@("`@("`@("`@)W5S
M97)N86UE)R`]/B`D=&AI<RT^=7-E<FYA;64L"B`@("`@("`@("`@("=P87-S
M=V]R9"<@/3X@)'1H:7,M/G!A<W-W;W)D+`H@("`@("`@("`@("`G875T:"<@
M/3X@)'1H:7,M/F%U=&@*("`@("`@("`I.PH@("`@("`@("1M86EL97(@/28@
M;F5W($UA:6Q?<VUT<"@D;6%I;&5R7W!A<F%M<RD["B`@("`@("`@)')E<W5L
M="`]("1M86EL97(M/G-E;F0H)'1H:7,M/G5R;'!A<G1S6R=P871H)UTL("1H
M96%D97)S+"`D;W5T*3L*("`@("`@("`C)')E<W5L="`](&UA:6PH)'1H:7,M
M/G5R;'!A<G1S6R=P871H)UTL("1H96%D97)S6R=3=6)J96-T)UTL("1O=70L
M("1H96%D97)?=&5X="D["@H@("`@("`@(&EF("@A4$5!4CHZ:7-%<G)O<B@D
M<F5S=6QT*2D@>PH@("`@("`@("`@("`D=F%L(#TF(&YE=R!33T%07U9A;'5E
M*"=-97-S86=E+4E$)RPG<W1R:6YG)RPD:&5A9&5R<ULG365S<V%G92U)1"==
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<W9A;%M=(#TF(&YE
M=R!33T%07U9A;'5E*"=F875L=&-O9&4G+"=13F%M92<L)U-/05`M14Y6.D-L
M:65N="<I.PH@("`@("`@("`@("`D<W9A;%M=(#TF(&YE=R!33T%07U9A;'5E
M*"=F875L='-T<FEN9R<L)W-T<FEN9R<L(F-O=6QD;B=T('-E;F0@4TU44"!M
M97-S86=E('1O('LD=&AI<RT^=7)L<&%R='-;)W!A=&@G77TB*3L*("`@("`@
M("`@("`@)'9A;"`])B!N97<@4T]!4%]686QU92@G1F%U;'0G+"=3=')U8W0G
M+"1S=F%L*3L*("`@("`@("!]"@H@("`@("`@("1M<6YA;64@/28@;F5W(%%.
M86UE*"1M971H;V0L("1N86UE<W!A8V4I.PH@("`@("`@("1M971H;V1686QU
M92`])B!N97<@4T]!4%]686QU92@G4F5S<&]N<V4G+"`G4W1R=6-T)RP@87)R
M87DH)'9A;"DI.PH*("`@("`@("`D=&AI<RT^:6YC;VUI;F=?<&%Y;&]A9"`]
M)B`D=&AI<RT^7VUA:V5%;G9E;&]P92@D;65T:&]D5F%L=64L("1T:&ES+3YH
M96%D97)S+"`D=&AI<RT^96YC;V1I;F<I.PH*("`@("`@("!R971U<FX@)'1H
M:7,M/FEN8V]M:6YG7W!A>6QO860["B`@("!]"@H@("`@+RHJ"B`@("`J('-E
M="!D871A(&9O<B!H='1P(&%U=&AE;G1I8V%T:6]N"B`@("`J(&-R96%T97,@
M075T:&]R:7IA=&EO;B!H96%D97(*("`@("H*("`@("H@0'!A<F%M('-T<FEN
M9R`D=7-E<FYA;64@("!U<V5R;F%M90H@("`@*B!`<&%R86T@<W1R:6YG("1P
M87-S=V]R9"`@(')E<W!O;G-E(&1A=&$L(&UI;G5S(&AT='`@:&5A9&5R<PH@
M("`@*@H@("`@*B!`<F5T=7)N(&YO;F4*("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("HO"B`@("!F=6YC=&EO;B!S971#<F5D96YT:6%L<R@D=7-E<FYA;64L
M("1P87-S=V]R9"D*("`@('L*("`@("`@("`D=&AI<RT^=7-E<FYA;64@/2`D
M=7-E<FYA;64["B`@("`@("`@)'1H:7,M/G!A<W-W;W)D(#T@)'!A<W-W;W)D
M.PH@("`@?0H*("`@("\O('!R:79A=&4@;65M8F5R<PH*("`@("\J*@H@("`@
M*B!V86QI9&%T92!U<FP@9&%T82!P87-S960@=&\@8V]N<W1R=6-T;W(*("`@
M("H*("`@("H@0')E='5R;B!B;V]L96%N"B`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@*B\*("`@(&9U;F-T:6]N(%]V86QI9&%T955R;"@I"B`@("!["B`@
M("`@("`@:68@*"`A(&ES7V%R<F%Y*"1T:&ES+3YU<FQP87)T<RD@*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(E5N86)L92!T;R!P
M87)S92!54DP@)'5R;"(I.PH@("`@("`@("`@("!R971U<FX@1D%,4T4["B`@
M("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/G5R;'!A<G1S6R=S
M8VAE;64G72D@?'P*("`@("`@("`@("`@<W1R8V%S96-M<"@D=&AI<RT^=7)L
M<&%R='-;)W-C:&5M92==+"`G;6%I;'1O)RD@(3T@,"D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@B56YA8FQE('1O('!A<G-E
M(%523"`D=7)L(BD["B`@("`@("`@("`@("`@("!R971U<FX@1D%,4T4["B`@
M("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/G5R;'!A<G1S6R=P
M871H)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H
M(E5N86)L92!T;R!P87)S92!54DP@)'5R;"(I.PH@("`@("`@("`@("!R971U
M<FX@1D%,4T4["B`@("`@("`@?0H@("`@("`@(')E='5R;B!44E5%.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!4"]4<F%N<W!O<G0O5$-0+G!H<```
M````````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`V-#<`,3`U,34T,S,W
M,S<`,#(R-3$T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&ES(&9I;&4@8V]N=&%I;G,@=&AE(&-O
M9&4@9F]R(&$@5$-0('1R86YS<&]R="!L87EE<BX*("H*("H@4$A0('9E<G-I
M;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I
M<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L
M"B`J('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@
M9FEL92!,24-%3E-%+"!A;F0@:7,@879A:6QA8FQE(&%T"B`J('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S)?,#(N='AT+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!A(&-O
M<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I
M;B!I=`H@*B!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E
M;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X*("H@;6%I
M;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!7
M96(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@4T]!4`H@*B!`875T:&]R("`@
M("!3:&%N92!(86YN82`\:6]R9'E?871?:6]R9'E?9&]T7V-O;3X*("H@0&-O
M<'ER:6=H="`@,C`P,RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@
M("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0@(%!(4"!,
M:6-E;G-E(#(N,#(*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+U-/05`*("HO"@IR97%U:7)E7V]N8V4@)U-/05`O0F%S92YP
M:'`G.PH*+RHJ"B`J(%1#4"!T<F%N<W!O<G0@9F]R(%-/05`N"B`J"B`J($!T
M;V1O("`@('5S92!.971?4V]C:V5T.R!I;7!L96UE;G0@<V]M92!S96-U<FET
M>2!S8VAE;64[(&EM<&QE;65N="!S=7!P;W)T"B`J("`@("`@("`@(&9O<B!A
M='1A8VAM96YT<PH@*B!`86-C97-S("!P=6)L:6,*("H@0'!A8VMA9V4@4T]!
M4`H@*B!`875T:&]R("!3:&%N92!(86YN82`\:6]R9'E?871?:6]R9'E?9&]T
M7V-O;3X*("HO"F-L87-S(%-/05!?5')A;G-P;W)T7U1#4"!E>'1E;F1S(%-/
M05!?0F%S95]/8FIE8W0*>PH*("`@('9A<B`D:&5A9&5R<R`](&%R<F%Y*"D[
M"B`@("!V87(@)'5R;'!A<G1S(#T@3E5,3#L*("`@('9A<B`D=7)L(#T@)R<[
M"B`@("!V87(@)&EN8V]M:6YG7W!A>6QO860@/2`G)SL*("`@('9A<B`D7W5S
M97)!9V5N="`](%-/05!?3$E"4D%265].04U%.PH@("`@=F%R("1E;F-O9&EN
M9R`](%-/05!?1$5&055,5%]%3D-/1$E.1SL*("`@('9A<B`D<F5S=6QT7V5N
M8V]D:6YG(#T@)U541BTX)SL*("`@('9A<B`D<F5S=6QT7V-O;G1E;G1?='EP
M93L*"B`@("`O*BH*("`@("`J('-O8VME=`H@("`@("HO"B`@("!V87(@)'-O
M8VME="`]("<G.PH*("`@("\J*@H@("`@("H@4T]!4%]4<F%N<W!O<G1?5$-0
M($-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D55),
M("`@(&AT='`@=7)L('1O('-O87`@96YD<&]I;G0*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!33T%07U1R86YS
M<&]R=%]40U`H)%523"P@)&5N8V]D:6YG(#T@4T]!4%]$149!54Q47T5.0T]$
M24Y'*0H@("`@>PH@("`@("`@('!A<F5N=#HZ4T]!4%]"87-E7T]B:F5C="@G
M5$-0)RD["B`@("`@("`@)'1H:7,M/G5R;'!A<G1S(#T@0'!A<G-E7W5R;"@D
M55),*3L*("`@("`@("`D=&AI<RT^=7)L(#T@)%523#L*("`@("`@("`D=&AI
M<RT^96YC;V1I;F<@/2`D96YC;V1I;F<["B`@("!]"@H@("`@9G5N8W1I;VX@
M7W-O8VME=%]P:6YG*"D*("`@('L*("`@("`@("`O+R!86%@@:&]W(&1O('=E
M(')E<W1A<G0@869T97(@<V]C:V5T7W-H=71D;W=N/PH@("`@("`@("\O:68@
M*"$D=&AI<RT^<V]C:V5T*2!["B`@("`@("`@("`@(",@8W)E871E('-O8VME
M="!R97-O=7)C90H@("`@("`@("`@("`D=&AI<RT^<V]C:V5T(#T@0'-O8VME
M=%]C<F5A=&4H049?24Y%5"P@4T]#2U]35%)%04TL(%-/3%]40U`I.PH@("`@
M("`@("`@("!I9B`H)'1H:7,M/G-O8VME="`\(#`I(')E='5R;B`P.PH*("`@
M("`@("`@("`@(R!C;VYN96-T"B`@("`@("`@("`@("1R97-U;'0@/2!S;V-K
M971?8V]N;F5C="@D=&AI<RT^<V]C:V5T+"`D=&AI<RT^=7)L<&%R='-;)VAO
M<W0G72P@)'1H:7,M/G5R;'!A<G1S6R=P;W)T)UTI.PH@("`@("`@("`@("!I
M9B`H)')E<W5L="`\(#`I(')E='5R;B`P.PH@("`@("`@("\O?0H@("`@("`@
M(')E='5R;B`Q.PH@("`@?0H*("`@("\J*@H@("`@("H@<V5N9"!A;F0@<F5C
M96EV92!S;V%P(&1A=&$*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("8D
M;7-G("`@("`@(&]U=&=O:6YG('!O<W0@9&%T80H@("`@("H@0'!A<F%M('-T
M<FEN9R`D86-T:6]N("`@("`@4T]!4"!!8W1I;VX@:&5A9&5R(&1A=&$*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9WQF875L="!R97-P;VYS90H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@)G-E;F0H
M)B1M<V<L("1O<'1I;VYS(#T@3E5,3"D*("`@('L*("`@("`@("`D=&AI<RT^
M:6YC;VUI;F=?<&%Y;&]A9"`]("<G.PH@("`@("`@("1T:&ES+3YO=71G;VEN
M9U]P87EL;V%D(#T@)B1M<V<["B`@("`@("`@:68@*"$D=&AI<RT^7W9A;&ED
M871E57)L*"DI(')E='5R;B`D=&AI<RT^9F%U;'0["@H@("`@("`@("\O(&-H
M96-K(&9O<B!40U`@<V-H96UE"B`@("`@("`@:68@*'-T<F-A<V5C;7`H)'1H
M:7,M/G5R;'!A<G1S6R=S8VAE;64G72P@)U1#4"<I(#T](#`I('L*("`@("`@
M("`@("`@+R\@8VAE8VL@8V]N;F5C=&EO;@H@("`@("`@("`@("!I9B`H(21T
M:&ES+3Y?<V]C:V5T7W!I;F<H*2D*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=E<G)O<B!O;B`G+B1T:&ES+3YU<FPN
M)R!R96%S;VX@)RYS;V-K971?<W1R97)R;W(H<V]C:V5T7VQA<W1?97)R;W(H
M)'1H:7,M/G-O8VME="DI*3L*"B`@("`@("`@("`@("\O('=R:71E('1O('1H
M92!S;V-K970*("`@("`@("`@("`@:68@*"%`<V]C:V5T7W=R:71E*"1T:&ES
M+3YS;V-K970L("1T:&ES+3YO=71G;VEN9U]P87EL;V%D+"!S=')L96XH)'1H
M:7,M/F]U=&=O:6YG7W!A>6QO860I*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)T5R<F]R('-E;F1I;F<@9&%T
M82!T;R`G+B1T:&ES+3YU<FPN)R!R96%S;VX@)RYS;V-K971?<W1R97)R;W(H
M<V]C:V5T7VQA<W1?97)R;W(H)'1H:7,M/G-O8VME="DI*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@+R\@<VAU=&1O=VX@=W)I=&EN9PH@("`@("`@
M("`@("!I9B@A<V]C:V5T7W-H=71D;W=N*"1T:&ES+3YS;V-K970L(#$I*0H@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H
M(F-A;B=T(&-H86YG92!S;V-K970@;6]D92!T;R!R96%D+B(I.PH*("`@("`@
M("`@("`@+R\@<F5A9"!E=F5R>71H:6YG('=E(&-A;BX*("`@("`@("`@("`@
M=VAI;&4H)&)U9B`]($!S;V-K971?<F5A9"@D=&AI<RT^<V]C:V5T+"`Q,#(T
M+"!02%!?0DE.05)97U)%040I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M:6YC;VUI;F=?<&%Y;&]A9"`N/2`D8G5F.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`O+R!R971U<FX@<&%Y;&]A9"!O<B!D:64*("`@("`@("`@("`@
M:68@*"1T:&ES+3YI;F-O;6EN9U]P87EL;V%D*0H@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YI;F-O;6EN9U]P87EL;V%D.PH*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(D5R<F]R(')E=F5I=FEN
M9R!D871A(&9R;VT@(BXD=&AI<RT^=7)L*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=);G9A;&ED('5R;"!S
M8VAE;64@)RXD=&AI<RT^=7)L*3L*("`@('T*"B`@("`O*BH*("`@("`J('9A
M;&ED871E('5R;"!D871A('!A<W-E9"!T;R!C;VYS=')U8W1O<@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]V86QI9&%T955R;"@I"B`@("!["B`@
M("`@("`@:68@*"`A(&ES7V%R<F%Y*"1T:&ES+3YU<FQP87)T<RD@*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(E5N86)L92!T;R!P
M87)S92!54DP@)'5R;"(I.PH@("`@("`@("`@("!R971U<FX@1D%,4T4["B`@
M("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/G5R;'!A<G1S6R=H
M;W-T)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H
M(DYO(&AO<W0@:6X@55),("1U<FPB*3L*("`@("`@("`@("`@<F5T=7)N($9!
M3%-%.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YU<FQP
M87)T<ULG<&%T:"==*2!\?"`A)'1H:7,M/G5R;'!A<G1S6R=P871H)UTI"B`@
M("`@("`@("`@("1T:&ES+3YU<FQP87)T<ULG<&%T:"==(#T@)R\G.PH@("`@
M("`@(')E='5R;B!44E5%.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]33T%0+U1R86YS<&]R="YP:'``````````````````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#4S,``Q,#4Q-30S,S<S-P`P,C(P-C``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%1H:7,@9FEL92!C;VYT86EN<R!T:&4@8V]D92!F;W(@86X@
M86)S=')A8W0@=')A;G-P;W)T(&QA>65R+@H@*@H@*B!02%`@=F5R<VEO;G,@
M-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U
M8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P*("H@
M=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE
M($Q)0T5.4T4L(&%N9"!I<R!A=F%I;&%B;&4@870*("H@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(@870@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,E\P,BYT>'0N("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O
M9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET
M"B`J('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A
M(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;@H@*B!M86EL('EO
M=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@(%=E8B!3
M97)V:6-E<PH@*B!`<&%C:V%G92`@("!33T%0"B`J($!A=71H;W(@("`@($1I
M971R:6-H($%Y86QA(#QD:65T<FEC:$!G86YX-"YC;VT^"B`J($!A=71H;W(@
M("`@(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/@H@*B!`8V]P
M>7)I9VAT("`R,#`S+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="`@4$A0($QI
M8V5N<V4@,BXP,@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O4T]!4`H@*B\*"G)E<75I<F5?;VYC92`G4T]!4"]"87-E+G!H
M<"<["@HO*BH*("H@4T]!4"!4<F%N<W!O<G0@3&%Y97(*("H*("H@5&AI<R!L
M87EE<B!C86X@=7-E(&1I9F9E<F5N="!P<F]T;V-O;',@9&5P96YD86YT(&]N
M('1H92!E;F1P;VEN="!U<FP@<')O=FED960*("H@;F\@:VYO=VQE9V4@;V8@
M=&AE(%-/05`@<')O=&]C;VP@:7,@879A:6QA8FQE(&%T('1H:7,@;&5V96P*
M("H@;F\@:VYO=VQE9V4@;V8@=&AE('1R86YS<&]R="!P<F]T;V-O;',@:7,@
M879A:6QA8FQE(&%T('1H:7,@;&5V96P*("H*("H@0&%C8V5S<R`@('!U8FQI
M8PH@*B!`<&%C:V%G92`@4T]!4`H@*B!`875T:&]R("`@4VAA;F4@0V%R879E
M;R`\<VAA;F5`<&AP+FYE=#X*("HO"F-L87-S(%-/05!?5')A;G-P;W)T"GL*
M("`@(&9U;F-T:6]N("9G9714<F%N<W!O<G0H)'5R;"P@)&5N8V]D:6YG(#T@
M4T]!4%]$149!54Q47T5.0T]$24Y'*0H@("`@>PH@("`@("`@("1U<FQP87)T
M<R`]($!P87)S95]U<FPH)'5R;"D["@H@("`@("`@(&EF("@A)'5R;'!A<G1S
M6R=S8VAE;64G72D@>PH@("`@("`@("`@("!R971U<FX@4T]!4%]"87-E7T]B
M:F5C=#HZ7W)A:7-E4V]A<$9A=6QT*"));G9A;&ED('1R86YS<&]R="!54DDZ
M("1U<FPB*3L*("`@("`@("!]"@H@("`@("`@(&EF("AS=')C87-E8VUP*"1U
M<FQP87)T<ULG<V-H96UE)UTL("=M86EL=&\G*2`]/2`P*2!["B`@("`@("`@
M("`@("1T<F%N<W!O<G1?='EP92`]("=33510)SL*("`@("`@("!](&5L<V5I
M9B`H<W1R8V%S96-M<"@D=7)L<&%R='-;)W-C:&5M92==+"`G:'1T<',G*2`]
M/2`P*2!["B`@("`@("`@("`@("1T<F%N<W!O<G1?='EP92`]("=(5%10)SL*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!H86YD;&4@;W1H97(@
M=')A;G-P;W)T('1Y<&5S("HO"B`@("`@("`@("`@("1T<F%N<W!O<G1?='EP
M92`]('-T<G1O=7!P97(H)'5R;'!A<G1S6R=S8VAE;64G72D["B`@("`@("`@
M?0H@("`@("`@("1T<F%N<W!O<G1?:6YC;'5D92`]("=33T%0+U1R86YS<&]R
M="\G("X@)'1R86YS<&]R=%]T>7!E("X@)RYP:'`G.PH@("`@("`@("1R97,@
M/2!`:6YC;'5D95]O;F-E*"1T<F%N<W!O<G1?:6YC;'5D92D["B`@("`@("`@
M:68@*"$D<F5S("8F("%I;E]A<G)A>2@D=')A;G-P;W)T7VEN8VQU9&4L(&=E
M=%]I;F-L=61E9%]F:6QE<R@I*2D@>PH@("`@("`@("`@("!R971U<FX@4T]!
M4%]"87-E7T]B:F5C=#HZ7W)A:7-E4V]A<$9A=6QT*").;R!4<F%N<W!O<G0@
M9F]R('LD=7)L<&%R='-;)W-C:&5M92==?2(I.PH@("`@("`@('T*("`@("`@
M("`D=')A;G-P;W)T7V-L87-S(#T@(E-/05!?5')A;G-P;W)T7R1T<F%N<W!O
M<G1?='EP92(["B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)'1R86YS<&]R
M=%]C;&%S<RDI('L*("`@("`@("`@("`@<F5T=7)N(%-/05!?0F%S95]/8FIE
M8W0Z.E]R86ES95-O87!&875L="@B3F\@5')A;G-P;W)T(&-L87-S("1T<F%N
M<W!O<G1?8VQA<W,B*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T(#TF
M(&YE=R`D=')A;G-P;W)T7V-L87-S*"1U<FPL("1E;F-O9&EN9RD["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]33T%0+U1Y<&4O````````````````
M````````````````````````````````````````````````````````````
M```P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,S<S-P`P,C`R-S(`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-/05`O
M5'EP92]D871E5&EM92YP:'``````````````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#$R-30P`#$P-3$U-#,S-S,W`#`R,C4T,0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO+PHO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O
M<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O
M('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\
M('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL
M92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@
M;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T
M92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A
M;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S
M.B!3:&%N92!#87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X@("!0;W)T('1O
M(%!%05(@86YD(&UO<F4@("!\"B\O('P@075T:&]R<SH@1&EE=')I8V@@07EA
M;&$@/&1I971R:6-H0&=A;G@T+F-O;3X@3W)I9VEN86P@075T:&]R("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED
M.B!D871E5&EM92YP:'`L=B`Q+C<@,C`P-2\P,R\Q,"`R,SHQ-CHS.2!Y=6YO
M<V@@17AP("0*+R\*8VQA<W,@4T]!4%]4>7!E7V1A=&54:6UE"GL*("`@('9A
M<B`D97)E9U]I<V\X-C`Q(#T@)R@M/ULP+3E=>S1]*2TH6S`M.5U[,GTI+2A;
M,"TY77LR?2E4*%LP+3E=>S)]*3HH6S`M.5U[,GTI.BA;,"TY77LR?2DH7"Y;
M,"TY72HI/RA:?%LK7"U=6S`M.5U[-'U\6RM<+5U;,"TY77LR?3I;,"TY77LR
M?2D_)SL*("`@("`@("`C(B@M/ULP+3E=>S1]*2TB+B`@+R\@8V5N='5R:65S
M("8@>65A<G,@0T-962T*("`@("`@("`C(BA;,"TY77LR?2DM(BX@("\O(&UO
M;G1H<R!-32T*("`@("`@("`C(BA;,"TY77LR?2DB+B`@("`O+R!D87ES($1$
M"B`@("`@("`@(R)4(BX@("`@("`@("`@("`@("`@("`@("\O('-E<&%R871O
M<B!4"B`@("`@("`@(R(H6S`M.5U[,GTI.B(N("`O+R!H;W5R<R!H:#H*("`@
M("`@("`C(BA;,"TY77LR?2DZ(BX@("\O(&UI;G5T97,@;6TZ"B`@("`@("`@
M(R(H6S`M.5U[,GTI*%PN6S`M.5TJ*3\B+B`O+R!S96-O;F1S('-S+G-S+BXN
M"B`@("`@("`@(R(H6GQ;*UPM75LP+3E=>S1]?%LK7"U=6S`M.5U[,GTZ6S`M
M.5U[,GTI/R([("\O(%H@=&\@:6YD:6-A=&4@551#+"`M+RM(2#I-33I34RY3
M4RXN+B!F;W(@;&]C86P@='HG<PH@("`@("`@(",@:68@;F\@.'1H(')E9R`H
M6BD@87-S=6UE<R!55$,*("`@('9A<B`D=&EM97-T86UP(#T@+3$["B`@("`*
M("`@(&9U;F-T:6]N(%-/05!?5'EP95]D871E5&EM92@D9&%T92`]("TQ*0H@
M("`@>PH@("`@("`@(&EF("@D9&%T92`]/2`M,2D@)&1A=&4@/2!T:6UE*"D[
M"@H@("`@("`@(&EF("AG971T>7!E*"1D871E*2`]/2`G:6YT96=E<B<I('L*
M("`@("`@("`@("`@)'1H:7,M/G1I;65S=&%M<"`]("1D871E.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YT:6UE<W1A;7`@/2`D=&AI
M<RT^=&]5;FEX=&EM92@D9&%T92D["B`@("`@("`@?0H@("`@?0H@("`@"B`@
M("!F=6YC=&EO;B!T;U-/05`H)&1A=&4@/2!.54Q,*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^=&]55$,H)&1A=&4I.PH@("`@?0H@("`@"B`@("!F
M=6YC=&EO;B!T;U-T<FEN9R@D=&EM97-T86UP(#T@,"D*("`@('L*("`@("`@
M("!I9B`H(21T:6UE<W1A;7`I("1T:6UE<W1A;7`@/2`D=&AI<RT^=&EM97-T
M86UP.PH@("`@("`@(&EF("@D=&EM97-T86UP(#P@,"D@<F5T=7)N(#`["@H@
M("`@("`@(')E='5R;B!D871E*"=9+6TM9%Q42#II.G-/)RPD=&EM97-T86UP
M*3L*("`@('T*("`@(`H@("`@9G5N8W1I;VX@7W-P;&ET*"1D871E<W1R*0H@
M("`@>PH@("`@("`@(&EF("@A)&1A=&5S='(I"B`@("`@("`@("`@("1D871E
M<W1R(#T@)'1H:7,M/G1O4W1R:6YG*"D["B`@("`@("`@96QS92!I9B`H9V5T
M='EP92@D9&%T97-T<BD@/3T@)VEN=&5G97(G*0H@("`@("`@("`@("`D9&%T
M97-T<B`]("1T:&ES+3YT;U-T<FEN9R@D9&%T97-T<BD["B`@("`@("`@("`@
M(`H@("`@("`@(&EF("AE<F5G*"1T:&ES+3YE<F5G7VES;S@V,#$L)&1A=&5S
M='(L)')E9W,I*2!["B`@("`@("`@("`@(&EF("@D<F5G<ULX72`A/2`G)R`F
M)B`D<F5G<ULX72`A/2`G6B<I('L*("`@("`@("`@("`@("`@("1O<"`]('-U
M8G-T<B@D<F5G<ULX72PP+#$I.PH@("`@("`@("`@("`@("`@)&@@/2!S=6)S
M='(H)')E9W-;.%TL,2PR*3L*("`@("`@("`@("`@("`@(&EF("AS=')S='(H
M)')E9W-;.%TL)SHG*2D@>PH@("`@("`@("`@("`@("`@("`@("1M(#T@<W5B
M<W1R*"1R96=S6SA=+#0L,BD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("1M(#T@<W5B<W1R*"1R96=S6SA=+#,L,BD[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H)&]P(#T]
M("<K)RD@>PH@("`@("`@("`@("`@("`@("`@("1R96=S6S1=(#T@)')E9W-;
M-%T@+2`D:#L*("`@("`@("`@("`@("`@("`@("!I9B`H)')E9W-;-%T@/"`P
M*2`D<F5G<ULT72`K/2`R-#L*("`@("`@("`@("`@("`@("`@("`D<F5G<ULU
M72`]("1R96=S6S5=("T@)&T["B`@("`@("`@("`@("`@("`@("`@:68@*"1R
M96=S6S5=(#P@,"D@)')E9W-;-5T@*ST@-C`["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1R96=S6S1=(#T@)')E9W-;
M-%T@*R`D:#L*("`@("`@("`@("`@("`@("`@("!I9B`H)')E9W-;-%T@/B`R
M,RD@)')E9W-;-%T@+3T@,C0["B`@("`@("`@("`@("`@("`@("`@)')E9W-;
M-5T@/2`D<F5G<ULU72`K("1M.PH@("`@("`@("`@("`@("`@("`@(&EF("@D
M<F5G<ULU72`^(#4Y*2`D<F5G<ULU72`M/2`V,#L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)')E9W,["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B!&04Q313L*("`@('T*("`@(`H@("`@
M9G5N8W1I;VX@=&]55$,H)&1A=&5S='(@/2!.54Q,*0H@("`@>PH@("`@("`@
M("1R96=S(#T@)'1H:7,M/E]S<&QI="@D9&%T97-T<BD["@H@("`@("`@(&EF
M("@D<F5G<RD@>PH@("`@("`@("`@("!R971U<FX@<W!R:6YT9B@G)3`T9"TE
M,#)D+24P,F14)3`R9#HE,#)D.B4P,F1:)RPD<F5G<ULQ72PD<F5G<ULR72PD
M<F5G<ULS72PD<F5G<ULT72PD<F5G<ULU72PD<F5G<ULV72D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)R<["B`@("!]"@H@("`@9G5N8W1I;VX@=&]5
M;FEX=&EM92@D9&%T97-T<B`]($Y53$PI"B`@("!["B`@("`@("`@)')E9W,@
M/2`D=&AI<RT^7W-P;&ET*"1D871E<W1R*3L*("`@("`@("!I9B`H)')E9W,I
M('L*("`@("`@("`@("`@<F5T=7)N('-T<G1O=&EM92@B)')E9W-;,5TM)')E
M9W-;,ETM)')E9W-;,UT@)')E9W-;-%TZ)')E9W-;-5TZ)')E9W-;-EU:(BD[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`M,3L*("`@('T*"B`@("!F=6YC
M=&EO;B!C;VUP87)E*"1D871E,2P@)&1A=&4R(#T@3E5,3"D*("`@('L*("`@
M("`@("!I9B`H)&1A=&4R(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1D871E
M,B`]("1D871E,3L*("`@("`@("`@("`@)&1A=&4Q(#T@)'1H:7,M/G1I;65S
M=&%M<#L*("`@("`@("!]"B`@("`@("`@:68@*"%I<U]N=6UE<FEC*"1D871E
M,2DI"B`@("`@("`@("`@("1D871E,2`]("1T:&ES+3YT;U5N:7AT:6UE*"1D
M871E,2D["B`@("`@("`@:68@*"%I<U]N=6UE<FEC*"1D871E,BDI"B`@("`@
M("`@("`@("1D871E,B`]("1T:&ES+3YT;U5N:7AT:6UE*"1D871E,BD["B`@
M("`@("`@:68@*"1D871E,2`A/2`M,2`F)B`D9&%T93(@(3T@+3$I(')E='5R
M;B`D9&%T93$@+2`D9&%T93(["B`@("`@("`@<F5T=7)N("TQ.PH@("`@?0H@
M("`@"B`@("!F=6YC=&EO;B!?=&5S="@D;W)I9R`]("<R,#`Q+3`T+3(U5#`Y
M.C,Q.C0Q+3`W,#`G*0H@("`@>PH@("`@("`@("1U=&,@/2`D=&AI<RT^=&]5
M5$,H)&]R:6<I.PH@("`@("`@("1T<S$@/2`D=&AI<RT^=&]5;FEX=&EM92@D
M;W)I9RD["B`@("`@("`@)'1S,B`]("1T:&ES+3YT;U5N:7AT:6UE*"1U=&,I
M.PH@("`@("`@("1B,2`]("1T:&ES+3YT;U-T<FEN9R@D=',Q*3L*("`@("`@
M("`D8C(@/2`D=&AI<RT^=&]3=')I;F<H)'1S,BD["B`@("`@("`@<')I;G0@
M(F]R:6<Z("1O<FEG7&XB.PH@("`@("`@('!R:6YT(")O<FEG('1O551#.B`D
M=71C7&XB.PH@("`@("`@('!R:6YT(")O<FEG('1S.B`D=',Q7&XB.PH@("`@
M("`@('!R:6YT(")U=&,@=',Z("1T<S)<;B(["B`@("`@("`@<')I;G0@(F]R
M:6<@=',@8F%C:SH@)&(Q7&XB.PH@("`@("`@('!R:6YT(")U=&,@=',@8F%C
M:SH@)&(R7&XB.PH@("`@("`@(&EF("@D8C$@(3T@)&]R:6<@?'P@)&(R("$]
M("1O<FEG*2!["B`@("`@("`@("`@(&5C:&\@(D5R<F]R(&EN(&ES;S@V,#$@
M8V]N=F5R<VEO;G-<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M96-H;R`B9&%T951I;64@3TM<;B(["B`@("`@("`@?0H@("`@?0I]"@HC('1H
M97-E('-H;W5L9"!A;&P@;6%T8V@*(R1D(#T@;F5W(%-/05!?5'EP95]D871E
M5&EM92@I.PHC96-H;R`D9"T^8V]M<&%R92@B,C`P,2TP-"TR-50R,#HS,3HT
M,5HB+"(R,#`Q+3`T+3(U5#(P.C,Q.C0Q6B(I+B)<;B(["B-E8VAO("1D+3YC
M;VUP87)E*"(R,#`Q+3`T+3(U5#(P.C,Q.C0Q6B(L(C(P,#$M,#0M,C54,3(Z
M,S$Z-#$M,#@P,"(I+B)<;B(["B-E8VAO("1D+3YC;VUP87)E*"(R,#`Q+3`T
M+3(U5#(P.C,Q.C0Q6B(L(C(P,#$M,#0M,C54,3(Z,S$Z-#$M,#@Z,#`B*2XB
M7&XB.PH*/SX`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+U-/05`O5'EP92]D=7)A=&EO;BYP:'``````
M`````````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$S-#`V`#$P-3$U-#,S-S,W
M`#`R,C8S-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*@IH='1P.B\O=W=W+G<S+F]R9R]44B]X;6QS8VAE;6$M
M,B\*"EM$969I;FET:6]N.ET@("!D=7)A=&EO;B!R97!R97-E;G1S(&$@9'5R
M871I;VX@;V8@=&EM92X@5&AE('9A;'5E('-P86-E(&]F"F1U<F%T:6]N(&ES
M(&$@<VEX+61I;65N<VEO;F%L('-P86-E('=H97)E('1H92!C;V]R9&EN871E
M<R!D97-I9VYA=&4@=&AE"D=R96=O<FEA;B!Y96%R+"!M;VYT:"P@9&%Y+"!H
M;W5R+"!M:6YU=&4L(&%N9"!S96-O;F0@8V]M<&]N96YT<PID969I;F5D(&EN
M("`U+C4N,RXR(&]F(%M)4T\@.#8P,5TL(')E<W!E8W1I=F5L>2X@5&AE<V4@
M8V]M<&]N96YT<R!A<F4*;W)D97)E9"!I;B!T:&5I<B!S:6=N:69I8V%N8V4@
M8GD@=&AE:7(@;W)D97(@;V8@87!P96%R86YC92!I+F4N(&%S('EE87(L"FUO
M;G1H+"!D87DL(&AO=7(L(&UI;G5T92P@86YD('-E8V]N9"X@"@HS+C(N-BXQ
M($QE>&EC86P@<F5P<F5S96YT871I;VX*5&AE(&QE>&EC86P@<F5P<F5S96YT
M871I;VX@9F]R(&1U<F%T:6]N(&ES('1H92!;25-/(#@V,#%=(&5X=&5N9&5D
M"F9O<FUA="!0;EEN($UN1%1N2"!N36Y3+"!W:&5R92!N62!R97!R97-E;G1S
M('1H92!N=6UB97(@;V8*>65A<G,L(&Y-('1H92!N=6UB97(@;V8@;6]N=&AS
M+"!N1"!T:&4@;G5M8F5R(&]F(&1A>7,L("=4)R!I<R!T:&4*9&%T92]T:6UE
M('-E<&%R871O<BP@;D@@=&AE(&YU;6)E<B!O9B!H;W5R<RP@;DT@=&AE(&YU
M;6)E<B!O9@IM:6YU=&5S(&%N9"!N4R!T:&4@;G5M8F5R(&]F('-E8V]N9',N
M(%1H92!N=6UB97(@;V8@<V5C;VYD<PIC86X@:6YC;'5D92!D96-I;6%L(&1I
M9VET<R!T;R!A<F)I=')A<GD@<')E8VES:6]N+@H*5&AE('9A;'5E<R!O9B!T
M:&4@665A<BP@36]N=&@L($1A>2P@2&]U<B!A;F0@36EN=71E<R!C;VUP;VYE
M;G1S"F%R92!N;W0@<F5S=')I8W1E9"!B=70@86QL;W<@86X@87)B:71R87)Y
M(&EN=&5G97(N(%-I;6EL87)L>2P@=&AE"G9A;'5E(&]F('1H92!396-O;F1S
M(&-O;7!O;F5N="!A;&QO=W,@86X@87)B:71R87)Y(&1E8VEM86PN"E1H=7,L
M('1H92!L97AI8V%L(')E<')E<V5N=&%T:6]N(&]F(&1U<F%T:6]N(&1O97,@
M;F]T(&9O;&QO=R!T:&4*86QT97)N871I=F4@9F]R;6%T(&]F("`U+C4N,RXR
M+C$@;V8@6TE33R`X-C`Q72X*"D%N(&]P=&EO;F%L('!R96-E9&EN9R!M:6YU
M<R!S:6=N("@G+2<I(&ES(&%L;&]W960L('1O(&EN9&EC871E(&$*;F5G871I
M=F4@9'5R871I;VXN($EF('1H92!S:6=N(&ES(&]M:71T960@82!P;W-I=&EV
M92!D=7)A=&EO;B!I<PII;F1I8V%T960N(%-E92!A;'-O($E33R`X-C`Q($1A
M=&4@86YD(%1I;64@1F]R;6%T<R`H1"DN(`H*1F]R(&5X86UP;&4L('1O(&EN
M9&EC871E(&$@9'5R871I;VX@;V8@,2!Y96%R+"`R(&UO;G1H<RP@,R!D87ES
M+`HQ,"!H;W5R<RP@86YD(#,P(&UI;G5T97,L(&]N92!W;W5L9"!W<FET93H@
M4#%9,DTS1%0Q,$@S,$TN"D]N92!C;W5L9"!A;'-O(&EN9&EC871E(&$@9'5R
M871I;VX@;V8@;6EN=7,@,3(P(&1A>7,@87,Z("U0,3(P1"X@"@I2961U8V5D
M('!R96-I<VEO;B!A;F0@=')U;F-A=&5D(')E<')E<V5N=&%T:6]N<R!O9B!T
M:&ES(&9O<FUA=`IA<F4@86QL;W=E9"!P<F]V:61E9"!T:&5Y(&-O;F9O<FT@
M=&\@=&AE(&9O;&QO=VEN9SH@"@I)9B!T:&4@;G5M8F5R(&]F('EE87)S+"!M
M;VYT:',L(&1A>7,L(&AO=7)S+"!M:6YU=&5S+"!O<B!S96-O;F1S"FEN(&%N
M>2!E>'!R97-S:6]N(&5Q=6%L<R!Z97)O+"!T:&4@;G5M8F5R(&%N9"!I=',@
M8V]R<F5S<&]N9&EN9PID97-I9VYA=&]R("IM87DJ(&)E(&]M:71T960N($AO
M=V5V97(L(&%T(&QE87-T(&]N92!N=6UB97(@86YD"FET<R!D97-I9VYA=&]R
M("IM=7-T*B!B92!P<F5S96YT+B`*5&AE('-E8V]N9',@<&%R="`J;6%Y*B!H
M879E(&$@9&5C:6UA;"!F<F%C=&EO;BX@"E1H92!D97-I9VYA=&]R("=4)R!S
M:&%L;"!B92!A8G-E;G0@:68@86QL(&]F('1H92!T:6UE(&ET96US(&%R92!A
M8G-E;G0N"E1H92!D97-I9VYA=&]R("=0)R!M=7-T(&%L=V%Y<R!B92!P<F5S
M96YT+B`*1F]R(&5X86UP;&4L(%`Q,S0W62P@4#$S-#=-(&%N9"!0,5DR350R
M2"!A<F4@86QL(&%L;&]W960[(%`P63$S-#=-"F%N9"!0,%DQ,S0W33!$(&%R
M92!A;&QO=V5D+B!0+3$S-#=-(&ES(&YO="!A;&QO=V5D(&%L=&AO=6=H("U0
M,3,T-TT*:7,@86QL;W=E9"X@4#%9,DU4(&ES(&YO="!A;&QO=V5D+B`*"BHO
M"@HO*B!T:&ES(&ES(&]N;'D@86X@87!R;WAI;6%T:6]N(&]F(&1U<F%T:6]N
M+"!M;W)E('=O<FL@<W1I;&P@=&\@9&\N"B`@('-E92!A8F]V92!S8VAE;6$@
M=7)L(&9O<B!M;W)E(&EN9F\@;VX@9'5R871I;VX*("`@"B`@(%1/1$\Z(&9I
M9W5R92!O=70@8F5S="!A<')O>&EM871I;VX@9F]R('EE87(@86YD(&UO;G1H
M(&-O;G9E<G-I;VX@=&\@<V5C;VYD<PHJ+PH@("`*)&5R96=?9'5R871I;VX@
M/2`G*"TI/U`H6S`M.5TK62D_*%LP+3E=*TTI/RA;,"TY72M$*3]4/RA;,"TY
M72M(*3\H6S`M.5TK32D_*%LP+3E=*U,I/R<["F-L87-S(%-/05!?5'EP95]D
M=7)A=&EO;@I["B`@("`O+R!F;W)M870@4&Y9;DUN1%1N2&Y-;E,*("`@(&9U
M;F-T:6]N('5N:7A?=&]?9'5R871I;VXH)'-E8V]N9',I('L*("`@("`@("!R
M971U<FX@4T]!4%]4>7!E7V1U<F%T:6]N.CIG971D=7)A=&EO;B@D<V5C;VYD
M<RD["B`@("!]"B`@("`*("`@(&9U;F-T:6]N(&UO9"@D82P@)&(L("8D9"P@
M)B1R*2!["B`@("`@("`@)&0@/2!F;&]O<B@@)&$@+R`D8B`I.PH@("`@("`@
M("1R(#T@)&$@)2`D8CL*("`@('T*("`@(`H@("`@9G5N8W1I;VX@9V5T9'5R
M871I;VXH)'-E8V]N9',I('L*("`@("`@("`D;F5G(#T@)R<["B`@("`@("`@
M:68@*"1S96-O;F1S(#P@,"D@>PH@("`@("`@("`@("`D;F5G(#T@)RTG.PH@
M("`@("`@("`@("`D<V5C;VYD<R`]("1S96-O;F1S("H@+3$["B`@("`@("`@
M?0H@("`@("`@(`H@("`@("`@("1?;6D@/2`V,#L*("`@("`@("`D7V@@/2`D
M7VUI("H@-C`["B`@("`@("`@)%]D(#T@)%]H("H@,C0["B`@("`@("`@+R\@
M6%A8(&AO=R!D;R!W92!P<F]P97)L>2!H86YD;&4@;6]N=&@@86YD('EE87(@
M=F%L=65S/PH@("`@("`@("1?;2`]("1?9"`J(#,P.PH@("`@("`@("1?>2`]
M("1?9"`J(#,V-3L*"B`@("`@("`@4T]!4%]4>7!E7V1U<F%T:6]N.CIM;V0H
M)'-E8V]N9',L("1?>2P@)'DL("1S96-O;F1S*3L*("`@("`@("!33T%07U1Y
M<&5?9'5R871I;VXZ.FUO9"@D<V5C;VYD<RP@)%]M+"`D;2P@)'-E8V]N9',I
M.PH@("`@("`@(%-/05!?5'EP95]D=7)A=&EO;CHZ;6]D*"1S96-O;F1S+"`D
M7V0L("1D+"`D<V5C;VYD<RD["B`@("`@("`@4T]!4%]4>7!E7V1U<F%T:6]N
M.CIM;V0H)'-E8V]N9',L("1?:"P@)&@L("1S96-O;F1S*3L*("`@("`@("!3
M3T%07U1Y<&5?9'5R871I;VXZ.FUO9"@D<V5C;VYD<RP@)%]M:2P@)&UI+"`D
M<RD["B`@("`@("`@"B`@("`@("`@)&1U<F%T:6]N(#T@)&YE9RXG4"<["B`@
M("`@("`@:68@*"1Y*2`D9'5R871I;VX@+CT@)'DN)UDG.PH@("`@("`@(&EF
M("@D;2D@)&1U<F%T:6]N("X]("1M+B=-)SL*("`@("`@("!I9B`H)&0I("1D
M=7)A=&EO;B`N/2`D9"XG1"<["B`@("`@("`@:68@*"1H('Q\("1M:2!\?"`D
M<RD@)&1U<F%T:6]N("X])U0G.PH@("`@("`@(&EF("@D:"D@)&1U<F%T:6]N
M("X]("1H+B=()SL*("`@("`@("!I9B`H)&UI*2`D9'5R871I;VX@+CT@)&UI
M+B=-)SL*("`@("`@("!I9B`H)',I("1D=7)A=&EO;B`N/2`D<RXG4R<["B`@
M("`@("`@:68@*"1D=7)A=&EO;B`]/2`G4"<@?'P@)&1U<F%T:6]N(#T]("<M
M4"<I("1D=7)A=&EO;B`]("=05#!3)SL*("`@("`@("!R971U<FX@)&1U<F%T
M:6]N.PH@("`@?0H@("`@"B`@("!F=6YC=&EO;B!M:V1U<F%T:6]N*"1N+"`D
M62P@)$UO+"`D1"P@)$@L("1-:2P@)%,I('L*("`@("`@("`D7VUI(#T@-C`[
M"B`@("`@("`@)%]H(#T@)%]M:2`J(#8P.PH@("`@("`@("1?9"`]("1?:"`J
M(#(T.PH@("`@("`@("\O(%A86"!H;W<@9&\@=V4@<')O<&5R;'D@:&%N9&QE
M(&UO;G1H(&%N9"!Y96%R('9A;'5E<S\*("`@("`@("`D7VT@/2`D7V0@*B`S
M,#L*("`@("`@("`D7WD@/2`D7V0@*B`S-C4["B`@("`@("`@"B`@("`@("`@
M)'-E8R`]("19("H@)%]Y("L@)$UO("H@)%]M("L@)$0@*B`D7V0@*R`D2"`J
M("1?:"`K("1-:2`J("1?;6D@*R`D4SL*("`@("`@("!I9B`H)&X@/3T@)RTG
M*2`D<V5C(#T@)'-E8R`J("TQ.PH@("`@("`@(')E='5R;B`D<V5C.PH@("`@
M?0H@("`@"B`@("!F=6YC=&EO;B!D=7)A=&EO;E]T;U]U;FEX*"1D=7)A=&EO
M;BD@>PH@("`@("`@(&=L;V)A;"`D97)E9U]D=7)A=&EO;CL*("`@("`@("!I
M9B`H97)E9R@D97)E9U]D=7)A=&EO;BPD9'5R871I;VXL)')E9W,I*2!["B`@
M("`@("`@("`@(')E='5R;B!33T%07U1Y<&5?9'5R871I;VXZ.FUK9'5R871I
M;VXH)')E9W-;,5TL("1R96=S6S)=+"`D<F5G<ULS72P@)')E9W-;-%TL("1R
M96=S6S5=+"`D<F5G<ULV72P@)')E9W-;-UTI.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@1D%,4T4["B`@("!]"B`@("`*("`@(&9U;F-T:6]N(&ES7V1U
M<F%T:6]N*"1D=7)A=&EO;BD@>PH@("`@("`@(&=L;V)A;"`D97)E9U]D=7)A
M=&EO;CL*("`@("`@("!R971U<FX@97)E9R@D97)E9U]D=7)A=&EO;BPD9'5R
M871I;VXL)')E9W,I.PH@("`@?0H@("`@"B`@("!F=6YC=&EO;B!?=&5S="@D
M=&EM92D@>PH@("`@("`@(&EF("A33T%07U1Y<&5?9'5R871I;VXZ.FES7V1U
M<F%T:6]N*"1T:6UE*2D@>PH@("`@("`@("`@("`D="`](%-/05!?5'EP95]D
M=7)A=&EO;CHZ9'5R871I;VY?=&]?=6YI>"@D=&EM92D["B`@("`@("`@("`@
M(&5C:&\@(D1U<F%T:6]N.B`D=&EM92!I<R`B+B1T+B(@<V5C;VYD<UQN(CL*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D="`](%-/05!?5'EP95]D
M=7)A=&EO;CHZ=6YI>%]T;U]D=7)A=&EO;B@D=&EM92D["B`@("`@("`@("`@
M(&5C:&\@(E-E8V]N9',Z("1T:6UE(&ES("(N)'0N(B!D=7)A=&EO;EQN(CL*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T.PH@("`@?0H@("`@"B`@("!F
M=6YC=&EO;B!A9&0H)&0Q+"`D9#(I('L*("`@("`@("`D<S$@/2!33T%07U1Y
M<&5?9'5R871I;VXZ.F1U<F%T:6]N7W1O7W5N:7@H)&0Q*3L*("`@("`@("`D
M<S(@/2!33T%07U1Y<&5?9'5R871I;VXZ.F1U<F%T:6]N7W1O7W5N:7@H)&0R
M*3L*("`@("`@("!R971U<FX@4T]!4%]4>7!E7V1U<F%T:6]N.CIU;FEX7W1O
M7V1U<F%T:6]N*"1S,2`K("1S,BD["B`@("!]"B`@("`*("`@(&9U;F-T:6]N
M('-U8G1R86-T*"1D,2P@)&0R*2!["B`@("`@("`@)',Q(#T@4T]!4%]4>7!E
M7V1U<F%T:6]N.CID=7)A=&EO;E]T;U]U;FEX*"1D,2D["B`@("`@("`@)',R
M(#T@4T]!4%]4>7!E7V1U<F%T:6]N.CID=7)A=&EO;E]T;U]U;FEX*"1D,BD[
M"B`@("`@("`@<F5T=7)N(%-/05!?5'EP95]D=7)A=&EO;CHZ=6YI>%]T;U]D
M=7)A=&EO;B@D<S$@+2`D<S(I.PH@("`@?0H*?0H*+RH@=&5S=',@*B\*"B1T
M(#T@4T]!4%]4>7!E7V1U<F%T:6]N.CI?=&5S="@G4#%9,DTS1%0Q,$@S,$TG
M*3L*4T]!4%]4>7!E7V1U<F%T:6]N.CI?=&5S="@D="D["B1T(#T@4T]!4%]4
M>7!E7V1U<F%T:6]N.CI?=&5S="@G+5`Q,C!$)RD["E-/05!?5'EP95]D=7)A
M=&EO;CHZ7W1E<W0H)'0I.PH*+R\@9'5R871I;VX@<VEN8V4@,3DW,`HD="`]
M(%-/05!?5'EP95]D=7)A=&EO;CHZ7W1E<W0H=&EM92@I*3L*4T]!4%]4>7!E
M7V1U<F%T:6]N.CI?=&5S="@D="D["@IP<FEN="`B061D('-H;W5L9"!B92!0
M5#!3.B`B+E-/05!?5'EP95]D=7)A=&EO;CHZ861D*"<M4#$R,$0G+"=0-$TG
M*2XB7&XB.PIP<FEN="`B4W5B=')A8W0@<VAO=6QD(&)E(%!4,%,Z("(N4T]!
M4%]4>7!E7V1U<F%T:6]N.CIS=6)T<F%C="@G4#$R,$0G+"=0-$TG*2XB7&XB
M.PH_/@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O4T]!4"]4>7!E+VAE>$)I;F%R>2YP:'``````````
M````````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,U,3(`,3`U,34T,S,W,S<`,#(R
M-S,U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE
M(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@
M;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI
M<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@
M?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV
M92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E
M;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA
M=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%-H86YE($-A<F%V96\@/%-H86YE0$-A
M<F%V96\N8V]M/B`@(%!O<G0@=&\@4$5!4B!A;F0@;6]R92`@('P*+R\@?"!!
M=71H;W)S.B!$:65T<FEC:"!!>6%L82`\9&EE=')I8VA`9V%N>#0N8V]M/B!/
M<FEG:6YA;"!!=71H;W(@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+PHO+R`D260Z(&AE>$)I;F%R>2YP:'`L=B`Q+C8@,C`P
M-2\P,R\Q,"`R,SHQ-CHS.2!Y=6YO<V@@17AP("0*+R\*8VQA<W,@4T]!4%]4
M>7!E7VAE>$)I;F%R>0I["B`@("!F=6YC=&EO;B!T;U]B:6XH)'9A;'5E*0H@
M("`@>PH@("`@("`@("1L96X@/2!S=')L96XH)'9A;'5E*3L*("`@("`@("!R
M971U<FX@<&%C:R@G2"<@+B`D;&5N+"`D=F%L=64I.PH@("`@?0H@("`@9G5N
M8W1I;VX@=&]?:&5X*"1V86QU92D*("`@('L*("`@("`@("!R971U<FX@8FEN
M,FAE>"@D=F%L=64I.PH@("`@?0H@("`@9G5N8W1I;VX@:7-?:&5X8FEN*"1V
M86QU92D*("`@('L*("`@("`@("`C(&9I<G-T('-E92!I9B!T:&5R92!A<F4@
M86YY(&EN=F%L:60@8VAA<G,*("`@("`@("`D;"`]('-T<FQE;B@D=F%L=64I
M.PH*("`@("`@("!I9B`H)&P@/"`Q('Q\('-T<G-P;B@D=F%L=64L("<P,3(S
M-#4V-S@Y04)#1$5&86)C9&5F)RD@(3T@)&PI(')E='5R;B!&04Q313L*"B`@
M("`@("`@)&)I;B`](%-/05!?5'EP95]H97A":6YA<GDZ.G1O7V)I;B@D=F%L
M=64I.PH@("`@("`@("1H97@@/2!33T%07U1Y<&5?:&5X0FEN87)Y.CIT;U]H
M97@H)&)I;BD["B`@("`@("`@<F5T=7)N('-T<F-A<V5C;7`H)'9A;'5E+"`D
M:&5X*2`]/2`P.PH@("`@?0I]"@H_/@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+U-/05`O5F%L=64N<&AP````````````````````````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#$U,38P`#$P-3$U-#,S-S,W`#`R,3$T,0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@5&AI<R!F:6QE(&-O;G1A:6YS('1H92!C;V1E(&9O<B!C;VYV
M97)T:6YG('9A;'5E<R!B971W965N(%-/05`@86YD(%!(4"X*("H*("H@4$A0
M('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@
M9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI
M8V5N<V4L"B`J('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I
M;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@879A:6QA8FQE(&%T"B`J('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S)?,#(N='AT+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M(&]B=&%I;B!I=`H@*B!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE
M87-E('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X*
M("H@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O
M<GD@("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@4T]!4`H@*B!`875T
M:&]R("`@("!$:65T<FEC:"!!>6%L82`\9&EE=')I8VA`9V%N>#0N8V]M/B!/
M<FEG:6YA;"!!=71H;W(*("H@0&%U=&AO<B`@("`@4VAA;F4@0V%R879E;R`\
M4VAA;F5`0V%R879E;RYC;VT^("`@4&]R="!T;R!014%2(&%N9"!M;W)E"B`J
M($!A=71H;W(@("`@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/B`@($UA:6YT96YA;F-E"B`J($!A=71H;W(@("`@($IA;B!38VAN96ED97(@
M/&IA;D!H;W)D92YO<F<^("`@("`@($UA:6YT96YA;F-E"B`J($!C;W!Y<FEG
M:'0@(#(P,#,M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT("!02%`@3&EC96YS
M92`R+C`R"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]33T%0"B`J+PH*<F5Q=6ER95]O;F-E("=33T%0+T)A<V4N<&AP)SL*
M"B\J*@H@*B!33T%0.CI686QU90H@*@H@*B!4:&ES(&-L87-S(&-O;G9E<G1S
M('9A;'5E<R!B971W965N(%!(4"!A;F0@4T]!4"X*("H*("H@3W)I9VEN86QL
M>2!B87-E9"!O;B!33T%0>#0@8GD@1&EE=')I8V@@07EA;&$*("H@:'1T<#HO
M+V1I971R:6-H+F=A;G@T+F-O;2]S;V%P>#0*("H*("H@0&%C8V5S<R!P=6)L
M:6,*("H@0'!A8VMA9V4@4T]!4`H@*B!`875T:&]R(%-H86YE($-A<F%V96\@
M/'-H86YE0'!H<"YN970^($-O;G9E<G-I;VX@=&\@4$5!4B!A;F0@=7!D871E
M<PH@*B!`875T:&]R($1I971R:6-H($%Y86QA(#QD:65T<FEC:$!G86YX-"YC
M;VT^($]R:6=I;F%L($%U=&AO<@H@*B\*8VQA<W,@4T]!4%]686QU90I["B`@
M("`O*BH*("`@("`J"B`@("`@*@H@("`@("H@0'9A<B`@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D=F%L=64@/2!N=6QL.PH*("`@("\J*@H@("`@("H*("`@
M("`J($!V87(@('-T<FEN9PH@("`@("HO"B`@("!V87(@)&YA;64@/2`G)SL*
M"B`@("`O*BH*("`@("`J"B`@("`@*B!`=F%R("!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1T>7!E(#T@)R<["@H@("`@+RHJ"B`@("`@*B!.86UE<W!A8V4*
M("`@("`J"B`@("`@*B!`=F%R("!S=')I;F<*("`@("`J+PH@("`@=F%R("1N
M86UE<W!A8V4@/2`G)SL*("`@('9A<B`D='EP95]N86UE<W!A8V4@/2`G)SL*
M"B`@("!V87(@)&%T=')I8G5T97,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D87)R87E4
M>7!E(#T@)R<["@H@("`@=F%R("1O<'1I;VYS(#T@87)R87DH*3L*"B`@("!V
M87(@)&YQ;CL*("`@('9A<B`D='%N.PH*("`@("\J*@H@("`@("H@0V]N<W1R
M=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@
M("`@;F%M92!O9B!T:&4@<V]A<"UV86QU92![;F%M97-P86-E?6YA;64*("`@
M("`J($!P87)A;2!M:7AE9"`@)'1Y<&4@("`@("`@('-O87`@=F%L=64@>VYA
M;65S<&%C97UT>7!E+"!I9B!N;W0@<V5T(&%N(&%U=&]M871I8PH@("`@("H@
M0'!A<F%M(&UI>&5D("`D=F%L=64@("`@("`@=F%L=64@=&\@<V5T"B`@("`@
M*B!`<&%R86T@87)R87D@("1A='1R:6)U=&5S("`H;W!T:6]N86PI($%T=')I
M8G5T97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%-/05!?5F%L=64H)&YA;64@
M/2`G)RP@)'1Y<&4@/2!F86QS92P@)'9A;'5E(#T@;G5L;"P@)&%T=')I8G5T
M97,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("\O($1E=&5C="!T>7!E(&EF
M(&YO="!P87-S960N"B`@("`@("`@)'1H:7,M/FYQ;B`])B!N97<@44YA;64H
M)&YA;64I.PH@("`@("`@("1T:&ES+3YN86UE(#T@)'1H:7,M/FYQ;BT^;F%M
M93L*("`@("`@("`D=&AI<RT^;F%M97-P86-E(#T@)'1H:7,M/FYQ;BT^;F%M
M97-P86-E.PH@("`@("`@("1T:&ES+3YT<6X@/28@;F5W(%%.86UE*"1T>7!E
M*3L*("`@("`@("`D=&AI<RT^='EP92`]("1T:&ES+3YT<6XM/FYA;64["B`@
M("`@("`@)'1H:7,M/G1Y<&5?<')E9FEX(#T@)'1H:7,M/G1Q;BT^;G,["B`@
M("`@("`@)'1H:7,M/G1Y<&5?;F%M97-P86-E(#T@)'1H:7,M/G1Q;BT^;F%M
M97-P86-E.PH@("`@("`@("1T:&ES+3YV86QU92`])B`D=F%L=64["B`@("`@
M("`@)'1H:7,M/F%T=')I8G5T97,@/2`D871T<FEB=71E<SL*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E<FEA;&EZ92X*("`@("`J"B`@("`@*B!`<&%R86T@
M4T]!4%]"87-E("8D<V5R:6%L:7IE<B`@02!33T%07T)A<V4@:6YS=&%N8V4@
M;W(@<W5B8VQA<W,@=&\@<V5R:6%L:7IE('=I=&@N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%A-3"!R97!R97-E;G1A=&EO;B!O9B`D=&AI<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@)G-E<FEA;&EZ92@F)'-E<FEA;&EZ97(I
M"B`@("!["B`@("`@("`@<F5T=7)N("1S97)I86QI>F5R+3Y?<V5R:6%L:7IE
M5F%L=64H)'1H:7,M/G9A;'5E+"`D=&AI<RT^;F%M92P@)'1H:7,M/G1Y<&4L
M("1T:&ES+3YN86UE<W!A8V4L("1T:&ES+3YT>7!E7VYA;65S<&%C92P@)'1H
M:7,M/F]P=&EO;G,L("1T:&ES+3YA='1R:6)U=&5S+"`D=&AI<RT^87)R87E4
M>7!E*3L*("`@('T*"GT*"B\J*@H@*B!33T%0.CI(96%D97(*("H*("H@5&AI
M<R!C;&%S<R!C;VYV97)T<R!V86QU97,@8F5T=V5E;B!02%`@86YD(%-/05`N
M($ET(&ES(&$@<VEM<&QE"B`J('=R87!P97(@87)O=6YD(%-/05!?5F%L=64L
M(&%D9&EN9R!S=7!P;W)T(&9O<B!33T%0(&%C=&]R(&%N9`H@*B!M=7-T=6YD
M97)S=&%N9"!P87)A;65T97)S+@H@*@H@*B!/<FEG:6YA;&QY(&)A<V5D(&]N
M(%-/05!X-"!B>2!$:65T<FEC:"!!>6%L80H@*B!H='1P.B\O9&EE=')I8V@N
M9V%N>#0N8V]M+W-O87!X-`H@*@H@*B!`86-C97-S('!U8FQI8PH@*B!`<&%C
M:V%G92!33T%0"B`J($!A=71H;W(@4VAA;F4@0V%R879E;R`\<VAA;F5`<&AP
M+FYE=#X@0V]N=F5R<VEO;B!T;R!014%2(&%N9"!U<&1A=&5S"B`J($!A=71H
M;W(@1&EE=')I8V@@07EA;&$@/&1I971R:6-H0&=A;G@T+F-O;3X@3W)I9VEN
M86P@075T:&]R"B`J+PIC;&%S<R!33T%07TAE861E<B!E>'1E;F1S(%-/05!?
M5F%L=64*>PH@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@("1N86UE("`@("`@("`@("`@;F%M92!O9B!T
M:&4@<V]A<"UV86QU92![;F%M97-P86-E?6YA;64*("`@("`J($!P87)A;2!M
M:7AE9"`@("1T>7!E("`@("`@("`@("`@<V]A<"!V86QU92![;F%M97-P86-E
M?71Y<&4L(&EF(&YO="!S970@86X@875T;VUA=&EC"B`@("`@*B!`<&%R86T@
M;6EX960@("`D=F%L=64@("`@("`@("`@('9A;'5E('1O('-E=`H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&UU<W1U;F1E<G-T86YD("!:97)O(&]R(&]N92X*
M("`@("`J($!P87)A;2!M:7AE9"`@("1A='1R:6)U=&5S("`@("`@*&]P=&EO
M;F%L*2!!='1R:6)U=&5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!33T%07TAE
M861E<B@D;F%M92`]("<G+"`D='EP92P@)'9A;'5E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)&UU<W1U;F1E<G-T86YD(#T@,"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("1A='1R:6)U=&5S(#T@87)R87DH*2D*("`@('L*("`@
M("`@("!I9B`H(6ES7V%R<F%Y*"1A='1R:6)U=&5S*2D@>PH@("`@("`@("`@
M("`D86-T;W(@/2`D871T<FEB=71E<SL*("`@("`@("`@("`@)&%T=')I8G5T
M97,@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@<&%R96YT.CI33T%0
M7U9A;'5E*"1N86UE+"`D='EP92P@)'9A;'5E+"`D871T<FEB=71E<RD["@H@
M("`@("`@(&EF("AI<W-E="@D86-T;W(I*2!["B`@("`@("`@("`@("1T:&ES
M+3YA='1R:6)U=&5S6R=33T%0+45.5CIA8W1O<B==(#T@)&%C=&]R.PH@("`@
M("`@('T@96QS96EF("@A:7-S970H)'1H:7,M/F%T=')I8G5T97-;)U-/05`M
M14Y6.F%C=&]R)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YA='1R:6)U=&5S
M6R=33T%0+45.5CIA8W1O<B==(#T@)VAT='`Z+R]S8VAE;6%S+GAM;'-O87`N
M;W)G+W-O87`O86-T;W(O;F5X="<["B`@("`@("`@?0H@("`@("`@("1T:&ES
M+3YA='1R:6)U=&5S6R=33T%0+45.5CIM=7-T56YD97)S=&%N9"==(#T@*&EN
M="DD;75S='5N9&5R<W1A;F0["B`@("!]"@I]"@HO*BH*("H@4T]!4#HZ071T
M86-H;65N=`H@*B!T:&ES(&-L87-S(&-O;G9E<G1S('9A;'5E<R!B971W965N
M(%!(4"!A;F0@4T]!4`H@*B!I="!H86YD;&5S($UI;64@871T86-H96UE;G1S
M('!E<B!7,T,@3F]T92!O;B!3;V%P($%T=&%C:&5M96YT<R!A=`H@*B!H='1P
M.B\O=W=W+G<S+F]R9R]44B]33T%0+6%T=&%C:&UE;G1S"B`J"B`J"B`J($!A
M8V-E<W,@<'5B;&EC"B`J($!P86-K86=E(%-/05`*("H@0&%U=&AO<B!3:&%N
M92!#87)A=F5O(#QS:&%N94!P:'`N;F5T/B!#;VYV97)S:6]N('1O(%!%05(@
M86YD('5P9&%T97,*("HO"F-L87-S(%-/05!?071T86-H;65N="!E>'1E;F1S
M(%-/05!?5F%L=64*>PH@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@
M("H*("`@("`J($!P87)A;2`@("!S=')I;F<@(&YA;64@;V8@=&AE('-O87`M
M=F%L=64@/'9A;'5E7VYA;64^"B`@("`@*B!`<&%R86T@("`@;6EX960@("!S
M;V%P(&AE861E<B!V86QU90H@("`@("H@0'!A<F%M("`@('-T<FEN9R!N86UE
M<W!A8V4*("`@("`J+PH@("`@9G5N8W1I;VX@4T]!4%]!='1A8VAM96YT*"1N
M86UE(#T@)R<L("1T>7!E(#T@)V%P<&QI8V%T:6]N+V]C=&5T+7-T<F5A;2<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&5N86UE+"`D9FEL
M92`](&YU;&PI"B`@("!["B`@("`@("`@9VQO8F%L("133T%07V]P=&EO;G,[
M"B`@("`@("`@:68@*"%I<W-E="@D4T]!4%]O<'1I;VYS6R=-:6UE)UTI*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=-86EL7VUI
M;64@:7,@;F]T(&EN<W1A;&QE9"P@=6YA8FQE('1O('-U<'!O<G0@4T]!4"!!
M='1A8VAE;65N=',G*3L*("`@("`@("!]"B`@("`@("`@<&%R96YT.CI33T%0
M7U9A;'5E*"1N86UE+"!N=6QL+"!N=6QL*3L*"B`@("`@("`@)&9I;&5D871A
M(#T@*"1F:6QE(#T]/2!N=6QL*2`_("1T:&ES+3Y?9FEL93)S='(H)&9I;&5N
M86UE*2`Z("1F:6QE.PH@("`@("`@("1F:6QE;F%M92`](&)A<V5N86UE*"1F
M:6QE;F%M92D["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&9I;&5D871A
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&9I;&5D871A.PH@("`@("`@('T*
M"B`@("`@("`@)&-I9"`](&UD-2AU;FEQ:60H=&EM92@I*2D["@H@("`@("`@
M("1T:&ES+3YA='1R:6)U=&5S6R=H<F5F)UT@/2`G8VED.B<N)&-I9#L*"B`@
M("`@("`@)'1H:7,M/F]P=&EO;G-;)V%T=&%C:&UE;G0G72`](&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=B;V1Y)R`@("`@/3X@
M)&9I;&5D871A+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D
M:7-P;W-I=&EO;B<@("`@(#T^("1F:6QE;F%M92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G8V]N=&5N=%]T>7!E)R`@(#T^("1T>7!E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=E;F-O9&EN9R<@/3X@
M)V)A<V4V-"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-I
M9"<@/3X@)&-I9`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-O;G1E;G1S(&]F
M('1H92!G:79E;B!F:6QE(&YA;64@87,@<W1R:6YG"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1F:6QE7VYA;64*("`@("`J($!R971U<FX@<W1R:6YG"B`@("`@
M*B!`86-C97,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B`F7V9I;&4R
M<W1R*"1F:6QE7VYA;64I"B`@("!["B`@("`@("`@:68@*"%I<U]R96%D86)L
M92@D9FEL95]N86UE*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G1FEL92!I<R!N;W0@<F5A9&%B;&4@)R`N("1F:6QE7VYA;64I
M.PH@("`@("`@('T*("`@("`@("!I9B`H(21F9"`](&9O<&5N*"1F:6QE7VYA
M;64L("=R8B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"=#;W5L9"!N;W0@;W!E;B`G("X@)&9I;&5?;F%M92D["B`@("`@("`@
M?0H@("`@("`@("1C;VYT(#T@9G)E860H)&9D+"!F:6QE<VEZ92@D9FEL95]N
M86UE*2D["B`@("`@("`@9F-L;W-E*"1F9"D["B`@("`@("`@<F5T=7)N("1C
M;VYT.PH@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-/05`O
M5U-$3"YP:'``````````````````````````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,C0W,C8P`#$P-3$U-#,S-S,W`#`R,#8T-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@5&AI<R!F
M:6QE(&-O;G1A:6YS('1H92!C;V1E(&9O<B!D96%L:6YG('=I=&@@5U-$3"!A
M8V-E<W,@86YD('-E<G9I8V5S+@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@
M-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@
M=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P*("H@=&AA="!I
M<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.
M4T4L(&%N9"!I<R!A=F%I;&%B;&4@870*("H@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT
M>'0N("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@
M4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET"B`J('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@
M=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;@H@*B!M86EL('EO=2!A(&-O
M<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@(%=E8B!397)V:6-E
M<PH@*B!`<&%C:V%G92`@("!33T%0"B`J($!A=71H;W(@("`@($1I971R:6-H
M($%Y86QA(#QD:65T<FEC:$!G86YX-"YC;VT^($]R:6=I;F%L($%U=&AO<@H@
M*B!`875T:&]R("`@("!3:&%N92!#87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O
M;3X@("!0;W)T('1O(%!%05(@86YD(&UO<F4*("H@0&%U=&AO<B`@("`@0VAU
M8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^("`@36%I;G1E;F%N8V4*
M("H@0&%U=&AO<B`@("`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX@
M("`@("`@36%I;G1E;F%N8V4*("H@0&-O<'ER:6=H="`@,C`P,RTR,#`U(%1H
M92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,E\P,BYT>'0@(%!(4"!,:6-E;G-E(#(N,#(*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U-/05`*("HO"@IR
M97%U:7)E7V]N8V4@)U-/05`O0F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)U-/
M05`O1F%U;'0N<&AP)SL*<F5Q=6ER95]O;F-E("=(5%10+U)E<75E<W0N<&AP
M)SL*"F1E9FEN92@G5U-$3%]#04-(15]-05A?04=%)RP@-#,R,#`I.PID969I
M;F4H)U=31$Q?0T%#2$5?55-%)RP@("`@(#`I.R`O+R!S970@=&\@>F5R;R!T
M;R!T=7)N(&]F9B!C86-H:6YG"@HO*BH*("H@5&AI<R!C;&%S<R!P87)S97,@
M5U-$3"!F:6QE<RP@86YD(&-A;B!B92!U<V5D(&)Y(%-/05`Z.D-L:65N="!T
M;PH@*B!P<F]P97)L>2!R96=I<W1E<B!S;V%P('9A;'5E<R!F;W(@<V5R=FEC
M97,N"B`J"B`J($]R:6=I;F%L;'D@8F%S960@;VX@4T]!4'@T(&)Y($1I971R
M:6-H($%Y86QA"B`J(&AT='`Z+R]D:65T<FEC:"YG86YX-"YC;VTO<V]A<'@T
M"B`J"B`J(%1/1$\Z"B`J("`@861D('=S9&P@8V%C:&EN9PH@*B`@(')E9F%C
M=&]R(&YA;65S<&%C92!H86YD;&EN9R`H)&YA;65S<&%C92\D;G,I"B`J("`@
M:6UP;&5M96YT($E$3"!T>7!E('-Y;G1A>"!D96-L87)A=&EO;B!S;R!W92!C
M86X@9V5N97)A=&4@5U-$3`H@*@H@*B!`86-C97-S('!U8FQI8PH@*B!`<&%C
M:V%G92!33T%0"B`J($!A=71H;W(@4VAA;F4@0V%R879E;R`\<VAA;F5`<&AP
M+FYE=#X@0V]N=F5R<VEO;B!T;R!014%2(&%N9"!U<&1A=&5S"B`J($!A=71H
M;W(@1&EE=')I8V@@07EA;&$@/&1I971R:6-H0&=A;G@T+F-O;3X@3W)I9VEN
M86P@075T:&]R"B`J+PIC;&%S<R!33T%07U=31$P@97AT96YD<R!33T%07T)A
M<V4*>PH@("`@=F%R("1T;G,@/2!N=6QL.PH@("`@=F%R("1D969I;FET:6]N
M(#T@87)R87DH*3L*("`@('9A<B`D;F%M97-P86-E<R`](&%R<F%Y*"D["B`@
M("!V87(@)&YS(#T@87)R87DH*3L*("`@('9A<B`D>'-D(#T@4T]!4%]834Q?
M4T-(14U!7U9%4E-)3TX["B`@("!V87(@)&-O;7!L97A4>7!E<R`](&%R<F%Y
M*"D["B`@("!V87(@)&5L96UE;G1S(#T@87)R87DH*3L*("`@('9A<B`D;65S
M<V%G97,@/2!A<G)A>2@I.PH@("`@=F%R("1P;W)T5'EP97,@/2!A<G)A>2@I
M.PH@("`@=F%R("1B:6YD:6YG<R`](&%R<F%Y*"D["B`@("!V87(@)&EM<&]R
M=',@/2!A<G)A>2@I.PH@("`@=F%R("1S97)V:6-E<R`](&%R<F%Y*"D["B`@
M("!V87(@)'-E<G9I8V4@/2`G)SL*("`@('9A<B`D=7)I(#T@)R<["B`@("!V
M87(@)&1O8W,@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%!R;WAY('!A<F%M
M971E<G,*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D<')O>'D@/2!N=6QL.PH*("`@('9A<B`D=')A8V4@/2`P.PH*("`@("\J
M*@H@("`@("H@57-E(%=31$P@8V%C:&4*("`@("`J"B`@("`@*B!`=F%R(&)O
M;VQE86X*("`@("`J+PH@("`@=F%R("1C86-H955S92`](&YU;&P["@H@("`@
M+RHJ"B`@("`@*B!#86-H92!M87@@;&EF971I;64@*&EN('-E8V]N9',I"B`@
M("`@*@H@("`@("H@0'9A<B!I;G0*("`@("`J+PH@("`@=F%R("1C86-H94UA
M>$%G92`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!#;&%S<R!T;R!U<V4@9F]R
M(%=31$P@<&%R<VEN9RX@0V%N(&)E(&]V97)R:61D96X@9F]R('-P96-I86P*
M("`@("`J(&-A<V5S+"!S=6)C;&%S<V5S+"!E=&,N"B`@("`@*B!`=F%R('-T
M<FEN9R`D=W-D;%!A<G-E<D-L87-S"B`@("`@*B\*("`@('9A<B`D=W-D;%!A
M<G-E<D-L87-S(#T@)U-/05!?5U-$3%]087)S97(G.PH*("`@("\J*@H@("`@
M("H@4T]!4%]74T1,(&-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@("1W<V1L7W5R:2`@("`@55),('1O(%=31$P@9FEL92X*("`@
M("`J($!P87)A;2!A<G)A>2`@("1P<F]X>2`@("`@("`@0V]N=&%I;G,@;W!T
M:6]N<R!F;W(@2%144%]297%U97-T(&-L87-S("AS964@2%144"]297%U97-T
M+G!H<"DN"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8V%C:&55<V4@("`@(%5S
M92!74T1,(&-A8VAI;F<N($1E9F%U;'1S('1O(&9A;'-E+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&-A8VAE36%X06=E("!#86-H92!M87@@;&EF971I;64@
M*&EN('-E8V]N9',I+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&1O8W,@("`@
M("`@("!087)S92!D;V-U;65N=&%T:6]N(&EN('1H92!74T1,/R!$969A=6QT
M<R!T;R!F86QS92X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!33T%07U=31$PH)'=S9&Q?=7)I("`@(#T@9F%L
M<V4L"B`@("`@("`@("`@("`@("`@("`@("`@)'!R;WAY("`@("`@(#T@87)R
M87DH*2P*("`@("`@("`@("`@("`@("`@("`@("`D8V%C:&55<V4@("`@/2!7
M4T1,7T-!0TA%7U5312P*("`@("`@("`@("`@("`@("`@("`@("`D8V%C:&5-
M87A!9V4@/2!74T1,7T-!0TA%7TU!6%]!1T4L"B`@("`@("`@("`@("`@("`@
M("`@("`@)&1O8W,@("`@("`@(#T@9F%L<V4I"B`@("!["B`@("`@("`@<&%R
M96YT.CI33T%07T)A<V4H)U=31$PG*3L*("`@("`@("`D=&AI<RT^=7)I("`@
M("`@("`@/2`D=W-D;%]U<FD["B`@("`@("`@)'1H:7,M/G!R;WAY("`@("`@
M(#T@)'!R;WAY.PH@("`@("`@("1T:&ES+3YC86-H955S92`@("`]("1C86-H
M955S93L*("`@("`@("`D=&AI<RT^8V%C:&5-87A!9V4@/2`D8V%C:&5-87A!
M9V4["B`@("`@("`@)'1H:7,M/F1O8W,@("`@("`@(#T@)&1O8W,["@H@("`@
M("`@(&EF("@D=W-D;%]U<FDI('L*("`@("`@("`@("`@)'1H:7,M/G!A<G-E
M55),*"1W<V1L7W5R:2D["B`@("`@("`@("`@(')E<V5T*"1T:&ES+3YS97)V
M:6-E<RD["B`@("`@("`@("`@("1T:&ES+3YS97)V:6-E(#T@:V5Y*"1T:&ES
M+3YS97)V:6-E<RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('-E
M=%]S97)V:6-E*"1S97)V:6-E*0H@("`@>PH@("`@("`@(&EF("AA<G)A>5]K
M97E?97AI<W1S*"1S97)V:6-E+"`D=&AI<RT^<V5R=FEC97,I*2!["B`@("`@
M("`@("`@("1T:&ES+3YS97)V:6-E(#T@)'-E<G9I8V4["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@0&1E<')E8V%T960@=7-E('!A<G-E55),
M(&EN<W1E860*("`@("`J+PH@("`@9G5N8W1I;VX@<&%R<V4H)'=S9&Q?=7)I
M+"`D<')O>'D@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3YP87)S
M95523"@D=W-D;%]U<FDL("1P<F]X>2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!&:6QL('1H92!74T1,(&%R<F%Y('1R964@=VET:"!D871A(&9R;VT@82!7
M4T1,(&9I;&4*("`@("`J"B`@("`@*B!`<&%R86T@('-T<FEN9PH@("`@("H@
M0'!A<F%M("!A<G)A>2`@<')O>'D@<F5L871E9"!P87)A;65T97)S"B`@("`@
M*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@<&%R<V554DPH
M)'=S9&Q?=7)I+"`D<')O>'D@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1P
M87)S97(@/28@;F5W("1T:&ES+3YW<V1L4&%R<V5R0VQA<W,H)'=S9&Q?=7)I
M+"`D=&AI<RP@)'1H:7,M/F1O8W,I.PH*("`@("`@("!I9B`H)'!A<G-E<BT^
M9F%U;'0I('L*("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@D
M<&%R<V5R+3YF875L="D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@1FEL;"!T:&4@5U-$3"!A<G)A>2!T<F5E('=I=&@@9&%T82!F<F]M(&]N
M92!O<B!M;W)E(%!(4"!C;&%S<R!O8FIE8W1S"B`@("`@*@H@("`@("H@0'!A
M<F%M("!M:7AE9"`@)'=S9&Q?;V)J($%N(&]B:F5C="!O<B!A<G)A>2!O9B!O
M8FIE8W1S('1O(&%D9"!T;R!T:&4@:6YT97)N86P@5U-$3"!T<F5E"B`@("`@
M*B!`<&%R86T@('-T<FEN9R`@)'-E<G9I8V5?;F%M92!.86UE(&]F('1H92!7
M4T1,(#QS97)V:6-E/@H@("`@("H@0'!A<F%M("!S=')I;F<@("1S97)V:6-E
M7V1E<V,@3W!T:6]N86P@9&5S8W)I<'1I;VX@;V8@=&AE(%=31$P@/'-E<G9I
M8V4^"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@
M<&%R<V5/8FIE8W0H)B1W<V1L7V]B:BP@)'1A<F=E=$YA;65S<&%C92P@)'-E
M<G9I8V5?;F%M92P@)'-E<G9I8V5?9&5S8R`]("<G*0H@("`@>PH@("`@("`@
M("1P87)S97(@/28@;F5W(%-/05!?5U-$3%]/8FIE8W1087)S97(H)'=S9&Q?
M;V)J+"`D=&AI<RP@)'1A<F=E=$YA;65S<&%C92P@)'-E<G9I8V5?;F%M92P@
M)'-E<G9I8V5?9&5S8RD["@H@("`@("`@("!I9B`H)'!A<G-E<BT^9F%U;'0I
M('L*("`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)'!A<G-E
M<BT^9F%U;'0I.PH@("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M16YD<&]I;G0H)'!O<G1.86UE*0H@("`@>PH@("`@("`@(')E='5R;B`H:7-S
M970H)'1H:7,M/G-E<G9I8V5S6R1T:&ES+3YS97)V:6-E75LG<&]R=',G75LD
M<&]R=$YA;65=6R=A9&1R97-S)UU;)VQO8V%T:6]N)UTI*0H@("`@("`@("`@
M("`@("`@/R`D=&AI<RT^<V5R=FEC97-;)'1H:7,M/G-E<G9I8V5=6R=P;W)T
M<R==6R1P;W)T3F%M95U;)V%D9')E<W,G75LG;&]C871I;VXG70H@("`@("`@
M("`@("`@("`@.B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")N;R!E;F1P;VEN
M="!F;W(@<&]R="!F;W(@)'!O<G1.86UE(BP@)'1H:7,M/G5R:2D["B`@("!]
M"@H@("`@9G5N8W1I;VX@7V=E=%!O<G1.86UE*"1O<&5R871I;VXL("1S97)V
M:6-E*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^<V5R=FEC97-;
M)'-E<G9I8V5=6R=P;W)T<R==*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D
M=&AI<RT^<V5R=FEC97-;)'-E<G9I8V5=6R=P;W)T<R==(&%S("1P;W)T(#T^
M("1P;W)T071T<G,I('L*("`@("`@("`@("`@("`@("1T>7!E(#T@)'1H:7,M
M/G-E<G9I8V5S6R1S97)V:6-E75LG<&]R=',G75LD<&]R=%U;)W1Y<&4G73L*
M("`@("`@("`@("`@("`@(&EF("@D='EP92`]/2`G<V]A<"<@)B8*("`@("`@
M("`@("`@("`@("`@("!I<W-E="@D=&AI<RT^8FEN9&EN9W-;)'!O<G1!='1R
M<ULG8FEN9&EN9R==75LG;W!E<F%T:6]N<R==6R1O<&5R871I;VY=*2D@>PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`D<&]R=#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@
M;G5L;#L*("`@('T*"B`@("`O*BH*("`@("`J(&9I;F0@=&AE(&YA;64@;V8@
M=&AE(&9I<G-T('!O<G0@=&AA="!C;VYT86EN<R!A;B!O<&5R871I;VX@;V8*
M("`@("`J(&YA;64@)&]P97)A=&EO;BX@(&%L=V%Y<R!R971U<FYS(&$@=&AE
M('-O87`@<&]R=$YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!O<G1.
M86UE*"1O<&5R871I;VXL("1S97)V:6-E(#T@;G5L;"D*("`@('L*("`@("`@
M("!I9B`H(21S97)V:6-E*2`D<V5R=FEC92`]("1T:&ES+3YS97)V:6-E.PH@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^<V5R=FEC97-;)'-E<G9I8V5=6R=P
M;W)T<R==*2D@>PH@("`@("`@("`@("`D<&]R=$YA;64@/2`D=&AI<RT^7V=E
M=%!O<G1.86UE*"1O<&5R871I;VXL("1S97)V:6-E*3L*("`@("`@("`@("`@
M:68@*"1P;W)T3F%M92D@<F5T=7)N("1P;W)T3F%M93L*("`@("`@("!]"B`@
M("`@("`@+R\@5')Y(&%N>2!S97)V:6-E(&EN('1H92!74T1,+@H@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3YS97)V:6-E<R!A<R`D<V5R=FEC94YA;64@/3X@
M)'-E<G9I8V4I('L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YS97)V
M:6-E<ULD<V5R=FEC94YA;65=6R=P;W)T<R==*2D@>PH@("`@("`@("`@("`@
M("`@)'!O<G1.86UE(#T@)'1H:7,M/E]G9710;W)T3F%M92@D;W!E<F%T:6]N
M+"`D<V5R=FEC94YA;64I.PH@("`@("`@("`@("`@("`@:68@*"1P;W)T3F%M
M92D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS97)V:6-E(#T@)'-E
M<G9I8V5.86UE.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<&]R=$YA
M;64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(FYO(&]P
M97)A=&EO;B`D;W!E<F%T:6]N(&EN('=S9&PB+"`D=&AI<RT^=7)I*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!G971/<&5R871I;VY$871A*"1P;W)T3F%M92P@
M)&]P97)A=&EO;BD*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/G-E
M<G9I8V5S6R1T:&ES+3YS97)V:6-E75LG<&]R=',G75LD<&]R=$YA;65=6R=B
M:6YD:6YG)UTI"B`@("`@("`@("`@("8F("1B:6YD:6YG(#T@)'1H:7,M/G-E
M<G9I8V5S6R1T:&ES+3YS97)V:6-E75LG<&]R=',G75LD<&]R=$YA;65=6R=B
M:6YD:6YG)UTI('L*("`@("`@("`@("`@+R\@9V5T(&]P97)A=&EO;B!D871A
M(&9R;VT@8FEN9&EN9PH@("`@("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M
M/F)I;F1I;F=S6R1B:6YD:6YG75LG;W!E<F%T:6]N<R==6R1O<&5R871I;VY=
M*2D@>PH@("`@("`@("`@("`@("`@)&]P1&%T82`]("1T:&ES+3YB:6YD:6YG
M<ULD8FEN9&EN9UU;)V]P97)A=&EO;G,G75LD;W!E<F%T:6]N73L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`O+R!G970@;W!E<F%T:6]N(&1A=&$@9G)O
M;2!P;W)T='EP90H@("`@("`@("`@("`D<&]R=%1Y<&4@/2`D=&AI<RT^8FEN
M9&EN9W-;)&)I;F1I;F==6R=T>7!E)UT["B`@("`@("`@("`@(&EF("@A)'!O
M<G14>7!E*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES
M95-O87!&875L="@B;F\@<&]R="!T>7!E(&9O<B!B:6YD:6YG("1B:6YD:6YG
M(&EN('=S9&P@(B`N("1T:&ES+3YU<FDI.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^<&]R=%1Y<&5S6R1P;W)T5'EP
M95U;)&]P97)A=&EO;ETI*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/G!O<G14>7!E<ULD<&]R=%1Y<&5=6R1O<&5R871I;VY=6R=P87)A
M;65T97)/<F1E<B==*2D*("`@("`@("`@("`@("`@("`@("`D;W!$871A6R=P
M87)A;65T97)/<F1E<B==(#T@)'1H:7,M/G!O<G14>7!E<ULD<&]R=%1Y<&5=
M6R1O<&5R871I;VY=6R=P87)A;65T97)/<F1E<B==.PH@("`@("`@("`@("`@
M("`@)&]P1&%T85LG:6YP=70G72`](&%R<F%Y7VUE<F=E*"1O<$1A=&%;)VEN
M<'5T)UTL("1T:&ES+3YP;W)T5'EP97-;)'!O<G14>7!E75LD;W!E<F%T:6]N
M75LG:6YP=70G72D["B`@("`@("`@("`@("`@("`D;W!$871A6R=O=71P=70G
M72`](&%R<F%Y7VUE<F=E*"1O<$1A=&%;)V]U='!U="==+"`D=&AI<RT^<&]R
M=%1Y<&5S6R1P;W)T5'EP95U;)&]P97)A=&EO;EU;)V]U='!U="==*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(21O<$1A=&$I"B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@B;F\@;W!E
M<F%T:6]N("1O<&5R871I;VX@9F]R('!O<G0@)'!O<G1.86UE+"!I;B!W<V1L
M(BP@)'1H:7,M/G5R:2D["B`@("`@("`@("`@("1O<$1A=&%;)W!A<F%M971E
M<G,G72`](&9A;'-E.PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/F)I
M;F1I;F=S6R1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O<G1S
M)UU;)'!O<G1.86UE75LG8FEN9&EN9R==75LG;W!E<F%T:6]N<R==6R1O<&5R
M871I;VY=6R=I;G!U="==6R=N86UE<W!A8V4G72DI"B`@("`@("`@("`@("`@
M("`D;W!$871A6R=N86UE<W!A8V4G72`]("1T:&ES+3YB:6YD:6YG<ULD=&AI
M<RT^<V5R=FEC97-;)'1H:7,M/G-E<G9I8V5=6R=P;W)T<R==6R1P;W)T3F%M
M95U;)V)I;F1I;F<G75U;)V]P97)A=&EO;G,G75LD;W!E<F%T:6]N75LG:6YP
M=70G75LG;F%M97-P86-E)UT["B`@("`@("`@("`@("\O(&UE<W-A9V4@9&%T
M82!F<F]M(&UE<W-A9V5S"B`@("`@("`@("`@("1I;G!U=$US9R`]("1O<$1A
M=&%;)VEN<'5T)UU;)VUE<W-A9V4G73L*("`@("`@("`@("`@:68@*&ES7V%R
M<F%Y*"1T:&ES+3YM97-S86=E<ULD:6YP=71-<V==*2D@>PH@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/FUE<W-A9V5S6R1I;G!U=$US9UT@87,@
M)'!N86UE(#T^("1P871T<G,I('L*("`@("`@("`@("`@("`@("`@("!I9B`H
M)&]P1&%T85LG<W1Y;&4G72`]/2`G9&]C=6UE;G0G("8F("1O<$1A=&%;)VEN
M<'5T)UU;)W5S92==(#T]("=L:71E<F%L)PH@("`@("`@("`@("`@("`@("`@
M("`@("`F)B`D<&YA;64@/3T@)W!A<F%M971E<G,G*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1O<$1A=&%;)W!A<F%M971E<G,G72`]('1R=64["B`@
M("`@("`@("`@("`@("`@("`@("`@("1O<$1A=&%;)VYA;65S<&%C92==(#T@
M)'1H:7,M/FYA;65S<&%C97-;)'!A='1R<ULG;F%M97-P86-E)UU=.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D96P@/2`D=&AI<RT^96QE;65N='-;)'!A
M='1R<ULG;F%M97-P86-E)UU=6R1P871T<G-;)W1Y<&4G75T["B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D96Q;)V5L96UE;G1S)UTI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D96Q;)V5L
M96UE;G1S)UT@87,@)&5L;F%M92`]/B`D96QA='1R<RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1O<$1A=&%;)VEN<'5T)UU;)W!A<G1S
M)UU;)&5L;F%M95T@/2`D96QA='1R<SL*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1O
M<$1A=&%;)VEN<'5T)UU;)W!A<G1S)UU;)'!N86UE72`]("1P871T<G,["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1O=71P=71-<V<@/2`D;W!$871A6R=O=71P
M=70G75LG;65S<V%G92==.PH@("`@("`@("`@("!I9B`H:7-?87)R87DH)'1H
M:7,M/FUE<W-A9V5S6R1O=71P=71-<V==*2D@>PH@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/FUE<W-A9V5S6R1O=71P=71-<V==(&%S("1P;F%M
M92`]/B`D<&%T=')S*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1O<$1A
M=&%;)W-T>6QE)UT@/3T@)V1O8W5M96YT)R`F)B`D;W!$871A6R=O=71P=70G
M75LG=7-E)UT@/3T@)VQI=&5R86PG"B`@("`@("`@("`@("`@("`@("`@("`@
M("8F("1P;F%M92`]/2`G<&%R86UE=&5R<R<I('L*"B`@("`@("`@("`@("`@
M("`@("`@("`@("1E;"`]("1T:&ES+3YE;&5M96YT<ULD<&%T=')S6R=N86UE
M<W!A8V4G75U;)'!A='1R<ULG='EP92==73L*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1E;%LG96QE;65N=',G72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1E;%LG96QE;65N=',G72!A
M<R`D96QN86UE(#T^("1E;&%T=')S*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&]P1&%T85LG;W5T<'5T)UU;)W!A<G1S)UU;)&5L;F%M
M95T@/2`D96QA='1R<SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1O<$1A=&%;)V]U
M='!U="==6R=P87)T<R==6R1P;F%M95T@/2`D<&%T=')S.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!R971U<FX@)&]P1&%T83L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(FYO(&)I;F1I;F<@9F]R
M('!O<G0@)'!O<G1.86UE(&EN('=S9&PB+"`D=&AI<RT^=7)I*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!M871C:$UE=&AO9"@F)&]P97)A=&EO;BD*("`@('L*
M("`@("`@("`O+R!/=F5R;&]A9&EN9R!L;W=E<F-A<V5S(&9U;F-T:6]N(&YA
M;65S(#HH"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/G-E<G9I8V5S6R1T:&ES
M+3YS97)V:6-E75LG<&]R=',G72!A<R`D<&]R="`]/B`D<&]R=$%T=')S*2![
M"B`@("`@("`@("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H)'1H:7,M/F)I;F1I
M;F=S6R1P;W)T071T<G-;)V)I;F1I;F<G75U;)V]P97)A=&EO;G,G72D@87,@
M)&]P*2!["B`@("`@("`@("`@("`@("!I9B`H<W1R8V%S96-M<"@D;W`L("1O
M<&5R871I;VXI(#T](#`I('L*("`@("`@("`@("`@("`@("`@("`D;W!E<F%T
M:6]N(#T@)&]P.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@9V5T1&%T84AA;F1L97(*
M("`@("`J"B`@("`@*B!':79E;B!A(&1A=&%T>7!E+"!W:&%T(&9U;F-T:6]N
M(&AA;F1L97,@=&AE('!R;V-E<W-I;F<_"B`@("`@*B!T:&ES(&ES('5S960@
M9F]R(&1O8R]L:71E<F%L(')E<75E<W1S('=H97)E('=E(')E8V5I=F4*("`@
M("`J(&$@9&%T871Y<&4L(&%N9"!W92!N965D('1O('!A<W,@:70@=&\@82!M
M971H;V0@:6X@;W5T"B`@("`@*B!S97)V97(@8VQA<W,*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG(&1A=&%T>7!E"B`@("`@*B!`<&%R86T@<W1R:6YG
M(&YA;65S<&%C90H@("`@("H@0')E='5R;G,@<W1R:6YG(&UE=&AO9&YA;64*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$1A=&%(86YD;&5R*"1D871A='EP92P@)&YA;65S<&%C92D*("`@('L*("`@
M("`@("`O+R!S964@:68@=V4@:&%V92!A;B!E;&5M96YT(&)Y('1H:7,@;F%M
M90H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^;F%M97-P86-E<ULD;F%M97-P
M86-E72DI"B`@("`@("`@("`@("1N86UE<W!A8V4@/2`D=&AI<RT^;F%M97-P
M86-E<ULD;F%M97-P86-E73L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/FYS
M6R1N86UE<W!A8V5=*2D@>PH@("`@("`@("`@("`D;G-P(#T@)'1H:7,M/FYS
M6R1N86UE<W!A8V5=.PH@("`@("`@("`@("`O+VEF("@A:7-S970H)'1H:7,M
M/F5L96UE;G1S6R1N<W!=*2D*("`@("`@("`@("`@+R\@("`@)&YS<"`]("1T
M:&ES+3YN86UE<W!A8V5S6R1N<W!=.PH@("`@("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/F5L96UE;G1S6R1N<W!=6R1D871A='EP95TI*2!["B`@("`@("`@
M("`@("`@("`D8VAE8VMM97-S86=E<R`](&%R<F%Y*"D["B`@("`@("`@("`@
M("`@("`O+R!F:6YD('=H870@;65S<V%G97,@=7-E('1H:7,@9&%T871Y<&4*
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YM97-S86=E<R!A<R`D
M;65S<V%G96YA;64@/3X@)&UE<W-A9V4I('L*("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D;65S<V%G92!A<R`D<&%R=&YA;64@/3X@)'!A<G0I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1P87)T6R=T>7!E)UT@/3T@
M)&1A=&%T>7!E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8VAE
M8VMM97-S86=E<UM=(#T@)&UE<W-A9V5N86UE.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`O+R!F:6YD('1H92!O<&5R871I;VX@=&AA="!U<V5S('1H
M:7,@;65S<V%G90H@("`@("`@("`@("`@("`@)&1A=&%(86YD;&5R(#T@;G5L
M;#L*("`@("`@("`@("`@("`@(&9O<F5A8V@H)'1H:7,M/G!O<G14>7!E<R!A
M<R`D<&]R=&YA;64@/3X@)'!O<G1T>7!E*2!["B`@("`@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)'!O<G1T>7!E(&%S("1O<&YA;64@/3X@)&]P:6YF;RD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D8VAE8VMM97-S
M86=E<R!A<R`D;65S<V%G96YA;64I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@D;W!I;F9O6R=I;G!U="==6R=M97-S86=E)UT@/3T@)&UE
M<W-A9V5N86UE*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1O<&YA;64["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M4V]A<$%C=&EO;B@D<&]R=$YA;64L("1O<&5R871I;VXI"B`@("!["B`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3YB:6YD:6YG<ULD=&AI<RT^<V5R=FEC97-;
M)'1H:7,M/G-E<G9I8V5=6R=P;W)T<R==6R1P;W)T3F%M95U;)V)I;F1I;F<G
M75U;)V]P97)A=&EO;G,G75LD;W!E<F%T:6]N75LG<V]A<$%C=&EO;B==*2`F
M)@H@("`@("`@("`@("`D<V]A<$%C=&EO;B`]("1T:&ES+3YB:6YD:6YG<ULD
M=&AI<RT^<V5R=FEC97-;)'1H:7,M/G-E<G9I8V5=6R=P;W)T<R==6R1P;W)T
M3F%M95U;)V)I;F1I;F<G75U;)V]P97)A=&EO;G,G75LD;W!E<F%T:6]N75LG
M<V]A<$%C=&EO;B==*2!["B`@("`@("`@("`@(')E='5R;B`D<V]A<$%C=&EO
M;CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=$YA;65S<&%C92@D<&]R=$YA;64L("1O<&5R871I;VXI
M"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YB:6YD:6YG<ULD=&AI
M<RT^<V5R=FEC97-;)'1H:7,M/G-E<G9I8V5=6R=P;W)T<R==6R1P;W)T3F%M
M95U;)V)I;F1I;F<G75TI("8F"B`@("`@("`@("`@(&ES<V5T*"1T:&ES+3YB
M:6YD:6YG<ULD=&AI<RT^<V5R=FEC97-;)'1H:7,M/G-E<G9I8V5=6R=P;W)T
M<R==6R1P;W)T3F%M95U;)V)I;F1I;F<G75U;)V]P97)A=&EO;G,G75LD;W!E
M<F%T:6]N75LG:6YP=70G75LG;F%M97-P86-E)UTI("8F"B`@("`@("`@("`@
M("1N86UE<W!A8V4@/2`D=&AI<RT^8FEN9&EN9W-;)'1H:7,M/G-E<G9I8V5S
M6R1T:&ES+3YS97)V:6-E75LG<&]R=',G75LD<&]R=$YA;65=6R=B:6YD:6YG
M)UU=6R=O<&5R871I;VYS)UU;)&]P97)A=&EO;EU;)VEN<'5T)UU;)VYA;65S
M<&%C92==*2!["B`@("`@("`@("`@(')E='5R;B`D;F%M97-P86-E.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@9G5N8W1I
M;VX@9V5T3F%M97-P86-E071T<FEB=71E3F%M92@D;F%M97-P86-E*0H@("`@
M>PH@("`@("`@("\J($EF(&ET(&1O97-N)W0@97AI<W0@870@9FER<W0L(&9L
M:7`@=&AE(&%R<F%Y(&%N9"!C:&5C:PH@("`@("`@("`J(&%G86EN+B`J+PH@
M("`@("`@(&EF("AE;7!T>2@D=&AI<RT^;G-;)&YA;65S<&%C95TI*2!["B`@
M("`@("`@("`@("1T:&ES+3YN<R`](&%R<F%Y7V9L:7`H)'1H:7,M/FYA;65S
M<&%C97,I.PH@("`@("`@('T*("`@("`@("`O*B!)9B!I="!D;V5S;B=T(&5X
M:7-T(&YO=RP@861D(&ET+B`J+PH@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^
M;G-;)&YA;65S<&%C95TI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M861D3F%M97-P86-E*"1N86UE<W!A8V4I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1T:&ES+3YN<ULD;F%M97-P86-E73L*("`@('T*"B`@("!F=6YC
M=&EO;B!A9&1.86UE<W!A8V4H)&YA;65S<&%C92D*("`@('L*("`@("`@("!I
M9B`H(65M<'1Y*"1T:&ES+3YN<ULD;F%M97-P86-E72DI('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YN<ULD;F%M97-P86-E73L*("`@("`@("!]"@H@
M("`@("`@("1N(#T@8V]U;G0H)'1H:7,M/FYS*3L*("`@("`@("`D871T<B`]
M("=N<R<@+B`D;CL*("`@("`@("`D=&AI<RT^;F%M97-P86-E<ULG;G,G("X@
M)&Y=(#T@)&YA;65S<&%C93L*("`@("`@("`D=&AI<RT^;G-;)&YA;65S<&%C
M95T@/2`D871T<CL*("`@("`@("!R971U<FX@)&%T='(["B`@("!]"@H@("`@
M9G5N8W1I;VX@7W9A;&ED871E4W1R:6YG*"1S=')I;F<I"B`@("!["B`@("`@
M("`@+R\@6%A8('1H:7,@<VAO=6QD(&)E(&1O;F4@<V]O;F5R(&]R(&QA=&5R
M"B`@("`@("`@+R\@<F5T=7)N('1R=64["B`@("`@("`@<F5T=7)N('!R96=?
M;6%T8V@H(B]>6UQW7SHC7"]=*R0O(BP@)'-T<FEN9RD["B`@("!]"@H@("`@
M9G5N8W1I;VX@7V%D9$%R9R@F)&%R9W,L("8D87)G87)R87DL("1A<F=N86UE
M*0H@("`@>PH@("`@("`@(&EF("@D87)G<RD@>PH@("`@("`@("`@("`D87)G
M<R`N/2`G+"`G.PH@("`@("`@('T*("`@("`@("`D87)G<R`N/2`B7"0B("X@
M)&%R9VYA;64["B`@("`@("`@:68@*"$D=&AI<RT^7W9A;&ED871E4W1R:6YG
M*"1A<F=N86UE*2D@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@
M("!]"B`@("`@("`@:68@*"1A<F=A<G)A>2D@>PH@("`@("`@("`@("`D87)G
M87)R87D@+CT@)RP@)SL*("`@("`@("!]"B`@("`@("`@)&%R9V%R<F%Y("X]
M("(G)&%R9VYA;64G(#T^(%PD(B`N("1A<F=N86UE.PH@("`@?0H*("`@(&9U
M;F-T:6]N(%]E;&5M96YT07)G*"8D87)G<RP@)B1A<F=A<G)A>2P@)B1?87)G
M='EP92P@)%]A<F=N86UE*0H@("`@>PH@("`@("`@("1C;VUM96YT<R`]("<G
M.PH@("`@("`@("1E;"`]("1T:&ES+3YE;&5M96YT<ULD7V%R9W1Y<&5;)VYA
M;65S<&%C92==75LD7V%R9W1Y<&5;)W1Y<&4G75T["B`@("`@("`@)'1N<R`]
M(&ES<V5T*"1T:&ES+3YN<ULD96Q;)VYA;65S<&%C92==72D@/R`D=&AI<RT^
M;G-;)&5L6R=N86UE<W!A8V4G75T@.B`D7V%R9W1Y<&5;)VYA;65S<&%C92==
M.PH*("`@("`@("!I9B`H(65M<'1Y*"1E;%LG8V]M<&QE>"==*2!\?"`H:7-S
M970H)&5L6R=T>7!E)UTI("8F(&ES<V5T*"1T:&ES+3YC;VUP;&5X5'EP97-;
M)'1N<UU;)&5L6R=T>7!E)UU=*2DI('L*("`@("`@("`@("`@+R\@5&AE(&5L
M96UE;G0@:7,@82!C;VUP;&5X('1Y<&4N"B`@("`@("`@("`@("1C;VUM96YT
M<R`N/2`B("`@("`@("`O+R![)%]A<F=T>7!E6R=T>7!E)UU](&ES(&$@0V]M
M<&QE>%1Y<&4L(')E9F5R('1O('1H92!74T1,(&9O<B!M;W)E(&EN9F\N7&XB
M.PH@("`@("`@("`@("`D871T<FYA;64@/2`B>R1?87)G='EP95LG='EP92==
M?5]A='1R(CL*("`@("`@("`@("`@:68@*&ES<V5T*"1E;%LG='EP92==*2`F
M)B!I<W-E="@D=&AI<RT^8V]M<&QE>%1Y<&5S6R1T;G-=6R1E;%LG='EP92==
M75LG871T<FEB=71E)UTI*2!["B`@("`@("`@("`@("`@("`D8V]M;65N=',@
M+CT@(B`@("`@("`@+R\@>R1?87)G='EP95LG='EP92==?2!M87D@<F5Q=6ER
M92!A='1R:6)U=&5S+"!R969E<B!T;R!T:&4@5U-$3"!F;W(@;6]R92!I;F9O
M+EQN(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D8V]M;65N=',@+CT@
M(B`@("`@("`@7"1[)&%T=')N86UE?5LG>&UL;G,G72`]("=[)'1H:7,M/FYA
M;65S<&%C97-;)%]A<F=T>7!E6R=N86UE<W!A8V4G75U])SM<;B(["B`@("`@
M("`@("`@("1C;VUM96YT<R`N/2`B("`@("`@("!<)'LD7V%R9W1Y<&5;)W1Y
M<&4G77T@/28@;F5W(%-/05!?5F%L=64H)WLD7V%R9W1Y<&5;)W1Y<&4G77TG
M+"!F86QS92P@7"1[)%]A<F=T>7!E6R=T>7!E)UU]+"!<)"1A='1R;F%M92D[
M7&XB.PH@("`@("`@("`@("`D=&AI<RT^7V%D9$%R9R@D87)G<RP@)&%R9V%R
M<F%Y+"`D7V%R9W1Y<&5;)W1Y<&4G72D["B`@("`@("`@("`@(&EF("AI<W-E
M="@D96Q;)W1Y<&4G72D@)B8@:7-S970H)'1H:7,M/F-O;7!L97A4>7!E<ULD
M=&YS75LD96Q;)W1Y<&4G75U;)V%T=')I8G5T92==*2D@>PH@("`@("`@("`@
M("`@("`@:68@*"1A<F=S*2!["B`@("`@("`@("`@("`@("`@("`@)&%R9W,@
M+CT@)RP@)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1A
M<F=S("X]("<D)R`N("1A='1R;F%M93L*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS96EF("AI<W-E="@D96Q;)V5L96UE;G1S)UTI*2!["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1E;%LG96QE;65N=',G72!A<R`D96YA;64@/3X@)&5L
M96UE;G0I('L*("`@("`@("`@("`@("`@("1C;VUM96YT<R`N/2`B("`@("`@
M("!<)"1E;F%M92`])B!N97<@4T]!4%]686QU92@G>WLD=&AI<RT^;F%M97-P
M86-E<ULD96QE;65N=%LG;F%M97-P86-E)UU=?7TD96YA;64G+"`G(B`N"B`@
M("`@("`@("`@("`@("`@("`@*&ES<V5T*"1E;&5M96YT6R=T>7!E)UTI(#\@
M)&5L96UE;G1;)W1Y<&4G72`Z(&9A;'-E*2`N("(G+"!<)"1E;F%M92D[7&XB
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1!<F<H)&%R9W,L("1A<F=A
M<G)A>2P@)&5N86UE*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1C;VUM96YT<R`N/2`B("`@("`@("!<)"1?87)G;F%M
M92`])B!N97<@4T]!4%]686QU92@G>WLD=&AI<RT^;F%M97-P86-E<ULD=&YS
M77U])%]A<F=N86UE)RP@)WLD96Q;)W1Y<&4G77TG+"!<)"1?87)G;F%M92D[
M7&XB.PH@("`@("`@("`@("`D=&AI<RT^7V%D9$%R9R@D87)G<RP@)&%R9V%R
M<F%Y+"`D7V%R9VYA;64I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C
M;VUM96YT<SL*("`@('T*"B`@("!F=6YC=&EO;B!?8V]M<&QE>%1Y<&5!<F<H
M)B1A<F=S+"`F)&%R9V%R<F%Y+"`F)%]A<F=T>7!E+"`D7V%R9VYA;64I"B`@
M("!["B`@("`@("`@)&-O;6UE;G1S(#T@)R<["B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3YC;VUP;&5X5'EP97-;)%]A<F=T>7!E6R=N86UE<W!A8V4G75U;
M)%]A<F=T>7!E6R=T>7!E)UU=*2D@>PH@("`@("`@("`@("`D8V]M;65N=',@
M(#T@(B`@("`@("`@+R\@)%]A<F=N86UE(&ES(&$@0V]M<&QE>%1Y<&4@>R1?
M87)G='EP95LG='EP92==?2Q<;B(["B`@("`@("`@("`@("1C;VUM96YT<R`N
M/2`B("`@("`@("`O+R!R969E<B!T;R!W<V1L(&9O<B!M;W)E(&EN9F]<;B([
M"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^8V]M<&QE>%1Y<&5S6R1?
M87)G='EP95LG;F%M97-P86-E)UU=6R1?87)G='EP95LG='EP92==75LG871T
M<FEB=71E)UTI*2!["B`@("`@("`@("`@("`@("`D8V]M;65N=',@+CT@(B`@
M("`@("`@+R\@)%]A<F=N86UE(&UA>2!R97%U:7)E(&%T=')I8G5T97,L(')E
M9F5R('1O('=S9&P@9F]R(&UO<F4@:6YF;UQN(CL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D=W)A<&YA;64@/2`G>R<@+B`D=&AI<RT^;F%M97-P86-E
M<ULD7V%R9W1Y<&5;)VYA;65S<&%C92==72XG?2<@+B`D7V%R9W1Y<&5;)W1Y
M<&4G73L*("`@("`@("`@("`@)&-O;6UE;G1S("X]("(@("`@("`@(%PD)%]A
M<F=N86UE(#TF(&YE=R!33T%07U9A;'5E*"<D7V%R9VYA;64G+"`G)'=R87!N
M86UE)RP@7"0D7V%R9VYA;64I.UQN(CL*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3Y?861D07)G*"1A<F=S+"`D87)G87)R87DL("1?87)G;F%M92D["B`@
M("`@("`@<F5T=7)N("1C;VUM96YT<SL*("`@('T*"B`@("`O*BH*("`@("`J
M($=E;F5R871E<R!S='5B(&-O9&4@9G)O;2!T:&4@5U-$3"!T:&%T(&-A;B!B
M92!S879E9"!T;R!A(&9I;&4*("`@("`J(&]R(&5V86PG9"!I;G1O(&5X:7-T
M96YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5N97)A=&50<F]X>4-O9&4H
M)'!O<G0@/2`G)RP@)&-L87-S;F%M93TG)RD*("`@('L*("`@("`@("`D;75L
M=&EP;W)T(#T@8V]U;G0H)'1H:7,M/G-E<G9I8V5S6R1T:&ES+3YS97)V:6-E
M75LG<&]R=',G72D@/B`Q.PH@("`@("`@(&EF("@A)'!O<G0I('L*("`@("`@
M("`@("`@<F5S970H)'1H:7,M/G-E<G9I8V5S6R1T:&ES+3YS97)V:6-E75LG
M<&]R=',G72D["B`@("`@("`@("`@("1P;W)T(#T@8W5R<F5N="@D=&AI<RT^
M<V5R=FEC97-;)'1H:7,M/G-E<G9I8V5=6R=P;W)T<R==*3L*("`@("`@("!]
M"B`@("`@("`@+R\@6%A8(&-U<G)E;G1L>2!D;R!N;W0@<W5P<&]R="!(5%10
M('!O<G1S"B`@("`@("`@:68@*"1P;W)T6R=T>7!E)UT@(3T@)W-O87`G*2![
M"B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*"B`@("`@("`@
M+R\@6%A8(&-U<G)E;G10;W)T(&ES($)!1`H@("`@("`@("1C;&EE;G1U<FP@
M/2`D<&]R=%LG861D<F5S<R==6R=L;V-A=&EO;B==.PH@("`@("`@(&EF("@A
M)&-L87-S;F%M92D@>PH@("`@("`@("`@("!I9B`H)&UU;'1I<&]R="!\?"`D
M<&]R="D@>PH@("`@("`@("`@("`@("`@)&-L87-S;F%M92`]("=796)397)V
M:6-E7R<@+B`D=&AI<RT^<V5R=FEC92`N("=?)R`N("1P;W)T6R=N86UE)UT[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D8VQA<W-N
M86UE(#T@)U=E8E-E<G9I8V5?)R`N("1T:&ES+3YS97)V:6-E.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1C;&%S<VYA;64@/2!P<F5G7W)E<&QA8V4H
M)R];("Y<+5PH7"E=*R\G+"`G7R<L("1C;&%S<VYA;64I.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"$D=&AI<RT^7W9A;&ED871E4W1R:6YG*"1C;&%S<VYA
M;64I*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*"B`@
M("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3YP<F]X>2D@)B8@8V]U;G0H)'1H
M:7,M/G!R;WAY*2D@>PH@("`@("`@("`@("`D8VQA<W,@/2`B8VQA<W,@)&-L
M87-S;F%M92!E>'1E;F1S(%-/05!?0VQI96YT7&Y[7&XB("X*("`@("`@("`@
M("`@(B`@("!F=6YC=&EO;B`D8VQA<W-N86UE*%PD<&%T:"`]("<D8VQI96YT
M=7)L)RE<;B`@("![7&XB("X*("`@("`@("`@("`@(B`@("`@("`@7"1T:&ES
M+3Y33T%07T-L:65N="A<)'!A=&@L(#`L(#`L7&XB("X*("`@("`@("`@("`@
M)R`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"<["@H@("`@("`@
M("`@("!F;W)E86-H("@D=&AI<RT^<')O>'D@87,@)&ME>2`]/B`D=F%L*2![
M"B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)'9A;"DI('L*("`@("`@
M("`@("`@("`@("`@("`D8VQA<W,@+CT@(B<D:V5Y)R`]/B!A<G)A>2@B.PH@
M("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V86P@87,@)&ME>3(@/3X@
M)'9A;#(I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&-L87-S("X]("(G
M)&ME>3(G(#T^("<D=F%L,B<L("(["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("1C;&%S<R`N/2`G*2<["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1C;&%S<R`N/2`B
M)R1K97DG(#T^("<D=F%L)RP@(CL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D8VQA<W,@+CT@(BDI.UQN("`@('U<;B([
M"B`@("`@("`@("`@("1C;&%S<R`]('-T<E]R97!L86-E*"<L("DI)RP@)RDI
M)RP@)&-L87-S*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8VQA
M<W,@/2`B8VQA<W,@)&-L87-S;F%M92!E>'1E;F1S(%-/05!?0VQI96YT7&Y[
M7&XB("X*("`@("`@("`@("`@(B`@("!F=6YC=&EO;B`D8VQA<W-N86UE*%PD
M<&%T:"`]("<D8VQI96YT=7)L)RE<;B`@("![7&XB("X*("`@("`@("`@("`@
M(B`@("`@("`@7"1T:&ES+3Y33T%07T-L:65N="A<)'!A=&@L(#`I.UQN(B`N
M"B`@("`@("`@("`@("(@("`@?5QN(CL*("`@("`@("!]"@H@("`@("`@("\O
M(&=E="!T:&4@8FEN9&EN9RP@9G)O;2!T:&%T(&=E="!T:&4@<&]R="!T>7!E
M"B`@("`@("`@)'!R:6UA<GE":6YD:6YG(#T@)'!O<G1;)V)I;F1I;F<G73L@
M+R\D=&AI<RT^<V5R=FEC97-;)'1H:7,M/G-E<G9I8V5=6R=P;W)T<R==6R1P
M;W)T6R=N86UE)UU=6R)B:6YD:6YG(ET["B`@("`@("`@)'!R:6UA<GE":6YD
M:6YG(#T@<')E9U]R97!L86-E*"(O7B@N*CHI+R(L("<G+"`D<')I;6%R>4)I
M;F1I;F<I.PH@("`@("`@("1P;W)T5'EP92`]("1T:&ES+3YB:6YD:6YG<ULD
M<')I;6%R>4)I;F1I;F==6R=T>7!E)UT["B`@("`@("`@)'!O<G14>7!E(#T@
M<')E9U]R97!L86-E*"(O7B@N*CHI+R(L("<G+"`D<&]R=%1Y<&4I.PH@("`@
M("`@("1S='EL92`]("1T:&ES+3YB:6YD:6YG<ULD<')I;6%R>4)I;F1I;F==
M6R=S='EL92==.PH*("`@("`@("`O+R!86%@@8W5R<F5N=%!O<G14>7!E(&ES
M($)!1`H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YP;W)T5'EP97-;)'!O<G14
M>7!E72!A<R`D;W!N86UE(#T^("1O<&5R871I;VXI('L*("`@("`@("`@("`@
M)'-O87!A8W1I;VX@/2!I<W-E="@D=&AI<RT^8FEN9&EN9W-;)'!R:6UA<GE"
M:6YD:6YG75LG;W!E<F%T:6]N<R==6R1O<&YA;65=6R=S;V%P06-T:6]N)UTI
M(#\*("`@("`@("`@("`@("`@("1T:&ES+3YB:6YD:6YG<ULD<')I;6%R>4)I
M;F1I;F==6R=O<&5R871I;VYS)UU;)&]P;F%M95U;)W-O87!!8W1I;VXG72`Z
M"B`@("`@("`@("`@("`@("!N=6QL.PH@("`@("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/F)I;F1I;F=S6R1P<FEM87)Y0FEN9&EN9UU;)V]P97)A=&EO;G,G
M75LD;W!N86UE75LG<W1Y;&4G72DI('L*("`@("`@("`@("`@("`@("1O<'-T
M>6QE(#T@)'1H:7,M/F)I;F1I;F=S6R1P<FEM87)Y0FEN9&EN9UU;)V]P97)A
M=&EO;G,G75LD;W!N86UE75LG<W1Y;&4G73L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1O<'-T>6QE(#T@)'-T>6QE.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1U<V4@/2`D=&AI<RT^8FEN9&EN9W-;)'!R
M:6UA<GE":6YD:6YG75LG;W!E<F%T:6]N<R==6R1O<&YA;65=6R=I;G!U="==
M6R=U<V4G73L*("`@("`@("`@("`@:68@*"1U<V4@/3T@)V5N8V]D960G*2![
M"B`@("`@("`@("`@("`@("`D;F%M97-P86-E(#T@)'1H:7,M/F)I;F1I;F=S
M6R1P<FEM87)Y0FEN9&EN9UU;)V]P97)A=&EO;G,G75LD;W!N86UE75LG:6YP
M=70G75LG;F%M97-P86-E)UT["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D8FEN9&EN9U1Y<&4@/2`D=&AI<RT^8FEN9&EN9W-;)'!R
M:6UA<GE":6YD:6YG75LG='EP92==.PH@("`@("`@("`@("`@("`@)&YS(#T@
M)'1H:7,M/G!O<G14>7!E<ULD8FEN9&EN9U1Y<&5=6R1O<&YA;65=6R=I;G!U
M="==6R=N86UE<W!A8V4G73L*("`@("`@("`@("`@("`@("1N86UE<W!A8V4@
M/2`D=&AI<RT^;F%M97-P86-E<ULD;G-=.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D87)G<R`]("<G.PH@("`@("`@("`@("`D87)G87)R87D@/2`G
M)SL*("`@("`@("`@("`@)&-O;6UE;G1S(#T@)R<["B`@("`@("`@("`@("1W
M<F%P<&5R<R`]("<G.PH@("`@("`@("`@("!F;W)E86-H("@D;W!E<F%T:6]N
M6R=I;G!U="==(&%S("1A<F=N86UE(#T^("1A<F=T>7!E*2!["B`@("`@("`@
M("`@("`@("!I9B`H)&%R9VYA;64@/3T@)VUE<W-A9V4G*2!["B`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/FUE<W-A9V5S6R1A<F=T>7!E
M72!A<R`D7V%R9VYA;64@/3X@)%]A<F=T>7!E*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@D;W!S='EL92`]/2`G9&]C=6UE;G0G("8F("1U<V4@
M/3T@)VQI=&5R86PG("8F"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M7V%R9W1Y<&5;)VYA;64G72`]/2`G<&%R86UE=&5R<R<I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O(%1H92!T>7!E(&]R(&5L96UE;G0@<F5F
M97)E9"!T;R!I<R!U<V5D"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!F;W(@<&%R86UE=&5R<RX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1E;&%T=')S(#T@;G5L;#L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1E;&5M96YT(#T@)%]A<F=T>7!E6R=E;&5M96YT)UT["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D96P@/2`D=&AI<RT^96QE;65N='-;)%]A<F=T
M>7!E6R=N86UE<W!A8V4G75U;)%]A<F=T>7!E6R=T>7!E)UU=.PH*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D96Q;)V-O;7!L97@G72D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE<W!A8V4@/2`D
M=&AI<RT^;F%M97-P86-E<ULD7V%R9W1Y<&5;)VYA;65S<&%C92==73L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!86%@@;F5E9"!T;R!W
M<F%P('1H92!P87)A;65T97)S(&EN"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@82!S;V%P7W9A;'5E+@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1E;%LG96QE;65N=',G72DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D96Q;)V5L96UE;G1S)UT@87,@)&5L;F%M
M92`]/B`D96QA='1R<RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!)<R!T:&4@96QE;65N="!A(&-O;7!L97@@='EP93\*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3YC;VUP;&5X5'EP97-;)&5L871T<G-;)VYA;65S<&%C92==75LD96QN
M86UE72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1C;VUM96YT<R`N/2`D=&AI<RT^7V-O;7!L97A4>7!E07)G*"1A<F=S
M+"`D87)G87)R87DL("1?87)G='EP92P@)%]A<F=N86UE*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861D07)G
M*"1A<F=S+"`D87)G87)R87DL("1E;&YA;64I.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1E;%LG8V]M<&QE>"==("8F
M("1A<F=A<G)A>2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1W<F%P;F%M92`]("=[)R`N("1T:&ES+3YN86UE<W!A8V5S6R1?87)G='EP
M95LG;F%M97-P86-E)UU=+B=])R`N("1E;%LG;F%M92==.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1C;VUM96YT<R`N/2`B("`@("`@("!<
M)'LD96Q;)VYA;64G77T@/28@;F5W(%-/05!?5F%L=64H)R1W<F%P;F%M92<L
M(&9A;'-E+"!<)'8@/2!A<G)A>2@D87)G87)R87DI*3M<;B(["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&%R9V%R<F%Y(#T@(B=[)&5L6R=N
M86UE)UU])R`]/B!<)'LD96Q;)VYA;64G77TB.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1?87)G
M='EP95LG96QE;65N="==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("\O($5L96UE;G0@87)G=6UE;G0N"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&-O;6UE;G1S("X]("1T:&ES+3Y?96QE;65N=$%R
M9R@D87)G<RP@)&%R9V%R<F%Y+"`D7V%R9W1Y<&4L("1?87)G='EP95LG='EP
M92==*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@0V]M<&QE>"!T>7!E
M(&%R9W5M96YT+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C
M;VUM96YT<R`N/2`D=&AI<RT^7V-O;7!L97A4>7!E07)G*"1A<F=S+"`D87)G
M87)R87DL("1?87)G='EP92P@)%]A<F=N86UE*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@+R\@5F%L:61A=&4@96YT<FEE<RX*"B`@("`@
M("`@("`@("\O($]P97)A=&EO;B!N86UE<R!A<F4@9G5N8W1I;VX@;F%M97,L
M('-O('1R>2!T;R!M86ME('-U<F4*("`@("`@("`@("`@+R\@:70G<R!L96=A
M;"X@5&AI<R!C;W5L9"!P;W1E;G1I86QL>2!C875S92!C;VQL:7-I;VYS+`H@
M("`@("`@("`@("`O+R!B=70@;&5T)W,@=')Y('1O(&UA:V4@979E<GET:&EN
M9R!C86QL86)L92!A;F0@<V5E(&AO=PH@("`@("`@("`@("`O+R!M86YY('!R
M;V)L96US('1H870@8V%U<V5S+@H@("`@("`@("`@("`D;W!N86UE7W!H<"`]
M('!R96=?<F5P;&%C92@G+UL@+EPM7"A<*5TK+R<L("=?)RP@)&]P;F%M92D[
M"B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]V86QI9&%T95-T<FEN9R@D;W!N
M86UE7W!H<"DI('L*("`@("`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&%R9V%R<F%Y*2!["B`@("`@
M("`@("`@("`@("`D87)G87)R87D@/2`B87)R87DH)&%R9V%R<F%Y*2(["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D87)G87)R87D@
M/2`G;G5L;"<["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1C;&%S<R`N
M/2`B("`@(&9U;F-T:6]N("8D;W!N86UE7W!H<"@D87)G<RE<;B`@("![7&XD
M8V]M;65N=',D=W)A<'!E<G,B("X*("`@("`@("`@("`@("`@("(@("`@("`@
M(')E='5R;B!<)'1H:7,M/F-A;&PH)R1O<&YA;64G+%QN(B`N"B`@("`@("`@
M("`@("`@("`B("`@("`@("`@("`@("`@("`@("`@("`@("`@7"1V(#T@)&%R
M9V%R<F%Y+%QN(B`N"B`@("`@("`@("`@("`@("`B("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)VYA;65S<&%C92<@/3X@)R1N86UE<W!A8V4G
M+%QN(B`N"B`@("`@("`@("`@("`@("`B("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W-O87!A8W1I;VXG(#T^("<D<V]A<&%C=&EO;B<L7&XB
M("X*("`@("`@("`@("`@("`@("(@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<W1Y;&4G(#T^("<D;W!S='EL92<L7&XB("X*("`@("`@("`@
M("`@("`@("(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=7-E
M)R`]/B`G)'5S92<B("X*("`@("`@("`@("`@("`@("@D=&AI<RT^=')A8V4_
M(BQ<;B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T<F%C92<@
M/3X@,2(@.B`G)RD@+B`B*2D[7&XB("X*("`@("`@("`@("`@("`@("(@("`@
M?5QN(CL*("`@("`@("!]"@H@("`@("`@("1C;&%S<R`N/2`B?5QN(CL*("`@
M("`@("!R971U<FX@)&-L87-S.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E;F5R
M871E06QL4')O>&EE<R@I"B`@("!["B`@("`@("`@)'!R;WAY8V]D92`]("<G
M.PH@("`@("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H)'1H:7,M/G-E<G9I8V5S
M6R1T:&ES+3YS97)V:6-E75LG<&]R=',G72D@87,@)&ME>2D@>PH@("`@("`@
M("`@("`D<&]R="`])B`D=&AI<RT^<V5R=FEC97-;)'1H:7,M/G-E<G9I8V5=
M6R=P;W)T<R==6R1K97E=.PH@("`@("`@("`@("`D<')O>'EC;V1E("X]("1T
M:&ES+3YG96YE<F%T95!R;WAY0V]D92@D<&]R="D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D<')O>'EC;V1E.PH@("`@?0H*("`@(&9U;F-T:6]N("9G
M9710<F]X>2@D<&]R="`]("<G+"`D;F%M92`]("<G*0H@("`@>PH@("`@("`@
M("1M=6QT:7!O<G0@/2!C;W5N="@D=&AI<RT^<V5R=FEC97-;)'1H:7,M/G-E
M<G9I8V5=6R=P;W)T<R==*2`^(#$["@H@("`@("`@(&EF("@A)'!O<G0I('L*
M("`@("`@("`@("`@<F5S970H)'1H:7,M/G-E<G9I8V5S6R1T:&ES+3YS97)V
M:6-E75LG<&]R=',G72D["B`@("`@("`@("`@("1P;W)T(#T@8W5R<F5N="@D
M=&AI<RT^<V5R=FEC97-;)'1H:7,M/G-E<G9I8V5=6R=P;W)T<R==*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("@D;75L=&EP;W)T('Q\("1P;W)T*2!["B`@
M("`@("`@("`@("1C;&%S<VYA;64@/2`G5V5B4V5R=FEC95\G("X@)'1H:7,M
M/G-E<G9I8V4@+B`G7R<@+B`D<&]R=%LG;F%M92==.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1C;&%S<VYA;64@/2`G5V5B4V5R=FEC95\G("X@
M)'1H:7,M/G-E<G9I8V4["B`@("`@("`@?0H*("`@("`@("!I9B`H)&YA;64I
M('L*("`@("`@("`@("`@)&-L87-S;F%M92`]("1N86UE("X@)U\G("X@)&-L
M87-S;F%M93L*("`@("`@("!]"@H@("`@("`@("1C;&%S<VYA;64@/2!P<F5G
M7W)E<&QA8V4H)R];("Y<+5PH7"E=*R\G+"`G7R<L("1C;&%S<VYA;64I.PH@
M("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"1C;&%S<VYA;64I*2!["B`@("`@
M("`@("`@("1P<F]X>2`]("1T:&ES+3YG96YE<F%T95!R;WAY0V]D92@D<&]R
M="P@)&-L87-S;F%M92D["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4T]!
M4"]#;&EE;G0N<&AP)SL*("`@("`@("`@("`@979A;"@D<')O>'DI.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N(&YE=R`D8VQA<W-N86UE.PH@("`@?0H*
M("`@(&9U;F-T:6]N("9?9V5T0V]M<&QE>%1Y<&5&;W)%;&5M96YT*"1N86UE
M+"`D;F%M97-P86-E*0H@("`@>PH@("`@("`@("1T(#T@;G5L;#L*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/FYS6R1N86UE<W!A8V5=*2`F)@H@("`@("`@
M("`@("!I<W-E="@D=&AI<RT^96QE;65N='-;)'1H:7,M/FYS6R1N86UE<W!A
M8V5=75LD;F%M95U;)W1Y<&4G72DI('L*"B`@("`@("`@("`@("1T>7!E(#T@
M)'1H:7,M/F5L96UE;G1S6R1T:&ES+3YN<ULD;F%M97-P86-E75U;)&YA;65=
M6R=T>7!E)UT["B`@("`@("`@("`@("1N<R`]("1T:&ES+3YE;&5M96YT<ULD
M=&AI<RT^;G-;)&YA;65S<&%C95U=6R1N86UE75LG;F%M97-P86-E)UT["@H@
M("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/F-O;7!L97A4>7!E<ULD;G-=
M6R1T>7!E72DI('L*("`@("`@("`@("`@("`@("1T(#T@)'1H:7,M/F-O;7!L
M97A4>7!E<ULD;G-=6R1T>7!E73L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("!R971U<FX@)'0["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T0V]M
M<&QE>%1Y<&5.86UE1F]R16QE;65N="@D;F%M92P@)&YA;65S<&%C92D*("`@
M('L*("`@("`@("`D="`]("1T:&ES+3Y?9V5T0V]M<&QE>%1Y<&5&;W)%;&5M
M96YT*"1N86UE+"`D;F%M97-P86-E*3L*("`@("`@("!I9B`H)'0I('L*("`@
M("`@("`@("`@<F5T=7)N("1T6R=N86UE)UT["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B!N=6QL.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$-O;7!L97A4
M>7!E0VAI;&14>7!E*"1N<RP@)&YA;64L("1C:&EL9%]N<RP@)&-H:6QD7VYA
M;64I"B`@("!["B`@("`@("`@+R\@:7,@=&AE('1Y<&4@86X@96QE;65N=#\*
M("`@("`@("`D="`]("1T:&ES+3Y?9V5T0V]M<&QE>%1Y<&5&;W)%;&5M96YT
M*"1N86UE+"`D;G,I.PH@("`@("`@(&EF("@D="D@>PH@("`@("`@("`@("`O
M+R!N;RP@9V5T(&ET(&9R;VT@8V]M<&QE>"!T>7!E<R!D:7)E8W1L>0H@("`@
M("`@("`@("!I9B`H:7-S970H)'1;)V5L96UE;G1S)UU;)&-H:6QD7VYA;65=
M6R=T>7!E)UTI*0H@("`@("`@("`@("`@("`@<F5T=7)N("1T6R=E;&5M96YT
M<R==6R1C:&EL9%]N86UE75LG='EP92==.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@;G5L;#L*("`@('T*"B`@("!F=6YC=&EO;B!G97138VAE;6%4>7!E
M*"1T>7!E+"`D;F%M92P@)'1Y<&5?;F%M97-P86-E*0H@("`@>PH@("`@("`@
M("\O('-E92!I9B!I="=S(&$@8V]M<&QE>"!T>7!E('-O('=E(&-A;B!D96%L
M('!R;W!E<FQY('=I=&@*("`@("`@("`O+R!33T%014Y#.F%R<F%Y5'EP92X*
M("`@("`@("!I9B`H)&YA;64@)B8@)'1Y<&4I('L*("`@("`@("`@("`@+R\@
M6%A8(%1/1$\Z"B`@("`@("`@("`@("\O(&QO;VL@=7`@=&AE(&YA;64@:6X@
M=&AE('=S9&P@86YD('9A;&ED871E('1H92!T>7!E+@H@("`@("`@("`@("!F
M;W)E86-H("@D=&AI<RT^8V]M<&QE>%1Y<&5S(&%S("1N<R`]/B`D='EP97,I
M('L*("`@("`@("`@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"1T>7!E
M+"`D='EP97,I*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&%R<F%Y7VME
M>5]E>&ES=',H)W1Y<&4G+"`D='EP97-;)'1Y<&5=*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!L:7-T*"1A<G)A>71Y<&5?;G,L("1A<G)A>71Y<&4L
M("1A<G)A>5]D97!T:"D@/2!I<W-E="@D='EP97-;)'1Y<&5=6R=A<G)A>51Y
M<&4G72D_"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E
M=$1E97!E<W1!<G)A>51Y<&4H)'1Y<&5S6R1T>7!E75LG;F%M97-P86-E)UTL
M("1T>7!E<ULD='EP95U;)V%R<F%Y5'EP92==*0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B!A<G)A>2@D=&AI<RT^;F%M97-P86-E<ULD='EP97-;
M)'1Y<&5=6R=N86UE<W!A8V4G75TL(&YU;&PL(#`I.PH@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX@87)R87DH)'1Y<&5S6R1T>7!E75LG='EP92==
M+"`D87)R87ET>7!E+"`D87)R87ET>7!E7VYS+"`D87)R87E?9&5P=&@I.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H
M87)R87E?:V5Y7V5X:7-T<R@G87)R87E4>7!E)RP@)'1Y<&5S6R1T>7!E72DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@;&ES="@D87)R87ET>7!E7VYS
M+"`D87)R87ET>7!E+"`D87)R87E?9&5P=&@I(#T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9V5T1&5E<&5S=$%R<F%Y5'EP92@D='EP
M97-;)'1Y<&5=6R=N86UE<W!A8V4G72P@)'1Y<&5S6R1T>7!E75LG87)R87E4
M>7!E)UTI.PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@87)R87DH
M)T%R<F%Y)RP@)&%R<F%Y='EP92P@)&%R<F%Y='EP95]N<RP@)&%R<F%Y7V1E
M<'1H*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)V5L96UE;G1S)RP@)'1Y<&5S6R1T
M>7!E72D@)B8*("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?:V5Y7V5X
M:7-T<R@D;F%M92P@)'1Y<&5S6R1T>7!E75LG96QE;65N=',G72DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1Y<&4@/2`D='EP97-;)'1Y<&5=6R=E
M;&5M96YT<R==6R=T>7!E)UT["B`@("`@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!A<G)A>2@D='EP92P@;G5L;"P@)'1H:7,M/FYA;65S<&%C97-;)'1Y
M<&5S6R1T>7!E75LG;F%M97-P86-E)UU=+"!N=6QL*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@:68@*"1T>7!E("8F("1T>7!E7VYA;65S<&%C92D@
M>PH@("`@("`@("`@("`D87)R87E4>7!E(#T@;G5L;#L*("`@("`@("`@("`@
M+R\@6%A8(%1/1$\Z"B`@("`@("`@("`@("\O('1H:7,@8V]D92!C=7)R96YT
M;'D@:&%N9&QE<R!O;FQY(&]N92!W87D@;V8@96YC;V1I;F<@87)R87D@='EP
M97,@:6X@=W-D;`H@("`@("`@("`@("`O+R!N965D('1O(&1O(&$@9V5N97)A
M;&EZ960@9G5N8W1I;VX@=&\@9FEG=7)E(&]U="!C;VUP;&5X('1Y<&5S"B`@
M("`@("`@("`@("1P(#T@)'1H:7,M/FYS6R1T>7!E7VYA;65S<&%C95T["B`@
M("`@("`@("`@(&EF("@D<"`F)@H@("`@("`@("`@("`@("`@87)R87E?:V5Y
M7V5X:7-T<R@D<"P@)'1H:7,M/F-O;7!L97A4>7!E<RD@)B8*("`@("`@("`@
M("`@("`@(&%R<F%Y7VME>5]E>&ES=',H)'1Y<&4L("1T:&ES+3YC;VUP;&5X
M5'EP97-;)'!=*2D@>PH@("`@("`@("`@("`@("`@:68@*"1A<G)A>51Y<&4@
M/2`D=&AI<RT^8V]M<&QE>%1Y<&5S6R1P75LD='EP95U;)V%R<F%Y5'EP92==
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1Y<&4@/2`G07)R87DG.PH@("`@
M("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3YC;VUP;&5X5'EP97-;)'!=
M6R1T>7!E75LG;W)D97(G73T])W-E<75E;F-E)R`F)@H@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y7VME>5]E>&ES=',H)V5L96UE;G1S)RP@)'1H
M:7,M/F-O;7!L97A4>7!E<ULD<%U;)'1Y<&5=*2D@>PH@("`@("`@("`@("`@
M("`@("`@(')E<V5T*"1T:&ES+3YC;VUP;&5X5'EP97-;)'!=6R1T>7!E75LG
M96QE;65N=',G72D["B`@("`@("`@("`@("`@("`@("`@+R\@87-S=6UE(&%N
M(&%R<F%Y"B`@("`@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1T:&ES+3YC
M;VUP;&5X5'EP97-;)'!=6R1T>7!E75LG96QE;65N=',G72D@/3T@,2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D87)G(#T@8W5R<F5N="@D=&AI<RT^
M8V]M<&QE>%1Y<&5S6R1P75LD='EP95U;)V5L96UE;G1S)UTI.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D87)R87E4>7!E(#T@)&%R9ULG='EP92==.PH@
M("`@("`@("`@("`@("`@("`@("`@("`D='EP92`]("=!<G)A>2<["B`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/F-O;7!L97A4>7!E<ULD<%U;)'1Y<&5=6R=E
M;&5M96YT<R==(&%S("1E;&5M96YT*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H)&5L96UE;G1;)VYA;64G72`]/2`D='EP92D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A<G)A>51Y<&4@/2`D96QE
M;65N=%LG='EP92==.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T>7!E(#T@)&5L96UE;G1;)W1Y<&4G73L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)'1Y<&4@/2`G4W1R=6-T)SL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2@D='EP92P@)&%R
M<F%Y5'EP92P@)'1Y<&5?;F%M97-P86-E+"!N=6QL*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!R971U<FX@87)R87DH;G5L;"P@;G5L;"P@
M;G5L;"P@;G5L;"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296-U<G-E('1H
M<F]U9V@@=&AE(%=31$P@<W1R=6-T=7)E(&QO;VMI;F<@9F]R('1H92!I;FYE
M<FUO<W0*("`@("`J(&%R<F%Y('1Y<&4@;V8@;75L=&DM9&EM96YS:6]N86P@
M87)R87ES+@H@("`@("H*("`@("`J(%1A:V5S(&$@;F%M97-P86-E('!R969I
M>"!A;F0@82!T>7!E+"!W:&EC:"!C86X@8F4@:6X@=&AE(&9O<FT*("`@("`J
M("=T>7!E)R!O<B`G='EP95M=)RP@86YD(')E='5R;G,@=&AE(&9U;&P@;F%M
M97-P86-E(%5222P@=&AE"B`@("`@*B!T>7!E(&]F('1H92!M;W-T(&1E97!L
M>2!N97-T960@87)R87D@='EP92!F;W5N9"P@86YD('1H92!N=6UB97(*("`@
M("`J(&]F(&QE=F5L<R!O9B!N97-T:6YG+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H@0')E='5R;B!M:7AE9"!A<G)A>2!O<B!N;W1H
M:6YG"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971$965P97-T07)R87E4>7!E
M*"1N<U!R969I>"P@)&%R<F%Y5'EP92D*("`@('L*("`@("`@("!S=&%T:6,@
M)'1R86EL(#T@87)R87DH*3L*"B`@("`@("`@)&%R<F%Y5'EP92`](&5R96=?
M<F5P;&%C92@G7%M<720G+"`G)RP@)&%R<F%Y5'EP92D["@H@("`@("`@("\O
M(%!R;W1E8W0@86=A:6YS="!C:7)C=6QA<B!R969E<F5N8V5S"B`@("`@("`@
M+R\@6%A8(%=E(')E86QL>2!N965D('1O(')E;6]V92!T<F%I;"!F<F]M('1H
M:7,@86QT;V=E=&AE<B`H:70G<R!V97)Y(&EN969F:6-I96YT(&%N9`H@("`@
M("`@("\O(&EN('1H92!W<F]N9R!P;&%C92$I(&%N9"!P=70@8VER8W5L87(@
M<F5F97)E;F-E(&-H96-K:6YG(&EN('=H96X@=&AE(%=31$P@:6YF;PH@("`@
M("`@("\O(&ES(&=E;F5R871E9"!I;B!T:&4@9FER<W0@<&QA8V4*("`@("`@
M("!I9B`H87)R87E?<V5A<F-H*"1N<U!R969I>"`N("<Z)R`N("1A<G)A>51Y
M<&4L("1T<F%I;"DI('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*&YU;&PL
M(&YU;&PL("UC;W5N="@D=')A:6PI*3L*("`@("`@("!]"@H@("`@("`@(&EF
M("AA<G)A>5]K97E?97AI<W1S*"1N<U!R969I>"P@)'1H:7,M/F-O;7!L97A4
M>7!E<RD@)B8*("`@("`@("`@("`@87)R87E?:V5Y7V5X:7-T<R@D87)R87E4
M>7!E+"`D=&AI<RT^8V]M<&QE>%1Y<&5S6R1N<U!R969I>%TI("8F"B`@("`@
M("`@("`@(&%R<F%Y7VME>5]E>&ES=',H)V%R<F%Y5'EP92<L("1T:&ES+3YC
M;VUP;&5X5'EP97-;)&YS4')E9FEX75LD87)R87E4>7!E72DI('L*("`@("`@
M("`@("`@)'1R86EL6UT@/2`D;G-0<F5F:7@@+B`G.B<@+B`D87)R87E4>7!E
M.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]G971$965P97-T07)R
M87E4>7!E*"1T:&ES+3YC;VUP;&5X5'EP97-;)&YS4')E9FEX75LD87)R87E4
M>7!E75LG;F%M97-P86-E)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-O;7!L97A4>7!E<ULD
M;G-0<F5F:7A=6R1A<G)A>51Y<&5=6R=A<G)A>51Y<&4G72D["B`@("`@("`@
M("`@(')E='5R;B!A<G)A>2@D<F5S=6QT6S!=+"`D<F5S=6QT6S%=+"`D<F5S
M=6QT6S)=("L@,2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B!A<G)A>2@D
M=&AI<RT^;F%M97-P86-E<ULD;G-0<F5F:7A=+"`D87)R87E4>7!E+"`P*3L*
M("`@('T*"GT*"F-L87-S(%-/05!?5U-$3%]#86-H92!E>'1E;F1S(%-/05!?
M0F%S90I["B`@("`O+R!#86-H92!S971T:6YG<PH*("`@("\J*@H@("`@("H@
M57-E(%=31$P@8V%C:&4*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@
M("`J+PH@("`@=F%R("1?8V%C:&55<V4@/2!N=6QL.PH*("`@("\J*@H@("`@
M("H@0V%C:&4@;6%X(&QI9F5T:6UE("AI;B!S96-O;F1S*0H@("`@("H*("`@
M("`J($!V87(@:6YT"B`@("`@*B\*("`@('9A<B`D7V-A8VAE36%X06=E(#T@
M;G5L;#L*"B`@("`O*BH*("`@("`J(%-/05!?5U-$3%]#86-H92!C;VYS=')U
M8W1O<@H@("`@("H*("`@("`J($!P87)A;2`@8F]O;&5A;B!U<V4@8V%C:&EN
M9PH@("`@("H@0'!A<F%M("!I;G0@("`@(&-A8VAE(&UA>"!L:69E=&EM92`H
M:6X@<V5C;VYD<RD*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%-/05!?5U-$3%]#86-H92@D8V%C:&55<V4@/2!74T1,7T-!
M0TA%7U5312P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V%C:&5-
M87A!9V4@/2!74T1,7T-!0TA%7TU!6%]!1T4I"B`@("!["B`@("`@("`@<&%R
M96YT.CI33T%07T)A<V4H)U=31$Q#04-(12<I.PH@("`@("`@("1T:&ES+3Y?
M8V%C:&55<V4@/2`D8V%C:&55<V4["B`@("`@("`@)'1H:7,M/E]C86-H94UA
M>$%G92`]("1C86-H94UA>$%G93L*("`@('T*"B`@("`O*BH*("`@("`J(%]C
M86-H941I<@H@("`@("H@<F5T=7)N('1H92!P871H('1O('1H92!C86-H92P@
M:68@:70@9&]E<VXG="!E>&ES="P@;6%K92!I=`H@("`@("HO"B`@("!F=6YC
M=&EO;B!?8V%C:&5$:7(H*0H@("`@>PH@("`@("`@("1D:7(@/2!G971E;G8H
M(E=31$Q#04-(12(I.PH@("`@("`@(&EF("@A)&1I<BD@)&1I<B`]("(@+B]W
M<V1L8V%C:&4B.PH@("`@("`@($!M:V1I<B@D9&ER+"`P-S`P*3L*("`@("`@
M("!R971U<FX@)&1I<CL*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E
M<R!A(&9I;&4@9G)O;2!C86-H92!I9B!I="!E>&ES=',L(&]T:&5R=VES92!R
M971R96EV92!F<F]M(&YE="P*("`@("`J(&%D9"!T;R!C86-H92P@86YD(')E
M='5R;B!F<F]M(&-A8VAE+@H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG
M("`@55),('1O(%=31$P*("`@("`J($!P87)A;2`@87)R87D@("`@<')O>'D@
M<&%R86UE=&5R<PH@("`@("H@0'!A<F%M("!I;G0@("`@("!E>'!E8W1E9"!-
M1#4@;V8@5U-$3"!54DP*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@9&%T80H@("`@("HO"B`@("!F=6YC=&EO;B!G970H
M)'=S9&Q?9FYA;64L("1P<F]X>5]P87)A;7,@/2!A<G)A>2@I+"`D8V%C:&4@
M/2`P*0H@("`@>PH@("`@("`@("1C86-H96YA;64@/2`D;60U7W=S9&P@/2`D
M9FEL95]D871A(#T@)R<["B`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&55<V4I
M('L*("`@("`@("`@("`@+R\@5')Y('1O(')E=')I979E(%=31$P@9G)O;2!C
M86-H90H@("`@("`@("`@("`D8V%C:&5N86UE(#T@4T]!4%]74T1,7T-A8VAE
M.CI?8V%C:&5$:7(H*2`N("<O)R`N(&UD-2@D=W-D;%]F;F%M92DN("<@+G=S
M9&PG.PH@("`@("`@("`@("!I9B`H9FEL95]E>&ES=',H)&-A8VAE;F%M92DI
M('L*("`@("`@("`@("`@("`@("1W9B`](&9O<&5N*"1C86-H96YA;64L("=R
M8B<I.PH@("`@("`@("`@("`@("`@:68@*"1W9BD@>PH@("`@("`@("`@("`@
M("`@("`@("\O(%)E861I;F<@8V%C:&5D(&9I;&4*("`@("`@("`@("`@("`@
M("`@("`D9FEL95]D871A(#T@9G)E860H)'=F+"!F:6QE<VEZ92@D8V%C:&5N
M86UE*2D["B`@("`@("`@("`@("`@("`@("`@)&UD-5]W<V1L(#T@;60U*"1F
M:6QE7V1A=&$I.PH@("`@("`@("`@("`@("`@("`@(&9C;&]S92@D=V8I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1C86-H92D@
M>PH@("`@("`@("`@("`@("`@("`@(&EF("@D8V%C:&4@(3T@)&UD-5]W<V1L
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A
M:7-E4V]A<$9A=6QT*"=74T1,($-H96-K<W5M(&5R<F]R(2<L("1W<V1L7V9N
M86UE*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1F:2`]('-T870H)&-A8VAE
M;F%M92D["B`@("`@("`@("`@("`@("`@("`@)&-A8VAE7VUT:6UE(#T@)&9I
M6SA=.PH@("`@("`@("`@("`@("`@("`@("\O<')I;G0@8V%C:&5?;71I;64L
M('1I;64H*0H@("`@("`@("`@("`@("`@("`@(&EF("@D8V%C:&5?;71I;64@
M*R`D=&AI<RT^7V-A8VAE36%X06=E(#P@=&EM92@I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("\O(&5X<&ER960*("`@("`@("`@("`@("`@("`@("`@
M("`@)&UD-5]W<V1L(#T@)R<[("\O(')E9F5T8V@*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(&EF("@A)&UD-5]W<V1L*2!["B`@("`@("`@("`@("\O
M($YO="!C86-H960@;W(@;F]T('5S:6YG(&-A8VAE+B!2971R:65V92!74T1,
M(&9R;VT@55),"@H@("`@("`@("`@("`O+R!I<R!I="!A(&QO8V%L(&9I;&4_
M"B`@("`@("`@("`@("\O('1H:7,@<V5C=&EO;B!S:&]U;&0@8F4@<F5P;&%C
M92!B>2!C=7)L(&%T('-O;64@<&]I;G0*("`@("`@("`@("`@:68@*"%P<F5G
M7VUA=&-H*"<O7BAH='1P<S]\9FEL92DZ7"]<+R\G+"`D=W-D;%]F;F%M92DI
M('L*("`@("`@("`@("`@("`@(&EF("@A9FEL95]E>&ES=',H)'=S9&Q?9FYA
M;64I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I
M<V53;V%P1F%U;'0H(E5N86)L92!T;R!R96%D(&QO8V%L(%=31$P@)'=S9&Q?
M9FYA;64B+"`D=W-D;%]F;F%M92D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=F:6QE7V=E=%]C;VYT
M96YT<R<I*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&5?9&%T82`](&9I
M;&5?9V5T7V-O;G1E;G1S*"1W<V1L7V9N86UE*3L*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&9I;&5?9&%T82`](&EM
M<&QO9&4H)R<L9FEL92@D=W-D;%]F;F%M92DI.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'5R:2`]
M(&5X<&QO9&4H)S\G+"`D=W-D;%]F;F%M92D["B`@("`@("`@("`@("`@("`D
M<G$@/28@;F5W($A45%!?4F5Q=65S="@D=7)I6S!=+"`D<')O>'E?<&%R86US
M*3L*("`@("`@("`@("`@("`@("\O('1H92!U<V5R(&%G96YT($A45%!?4F5Q
M=65S="!U<V5S(&9O=6QS('1H:6YG<R!U<`H@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1U<FE;,5TI*2!["B`@("`@("`@("`@("`@("`@("`@)')Q+3YA
M9&1287=1=65R>5-T<FEN9R@D=7)I6S%=*3L*("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!R;WAY7W!A<F%M<ULG<')O
M>'E?:&]S="==*2`F)@H@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1P<F]X
M>5]P87)A;7-;)W!R;WAY7W!O<G0G72D@)B8*("`@("`@("`@("`@("`@("`@
M("!I<W-E="@D<')O>'E?<&%R86US6R=P<F]X>5]U<V5R)UTI("8F"B`@("`@
M("`@("`@("`@("`@("`@:7-S970H)'!R;WAY7W!A<F%M<ULG<')O>'E?<&%S
M<R==*2D@>PH@("`@("`@("`@("`@("`@("`@("1R<2T^<V5T4')O>'DH)'!R
M;WAY7W!A<F%M<ULG<')O>'E?:&]S="==+"`D<')O>'E?<&%R86US6R=P<F]X
M>5]P;W)T)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<')O>'E?<&%R86US6R=P<F]X>5]U<V5R)UTL("1P<F]X>5]P87)A;7-;)W!R
M;WAY7W!A<W,G72D["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H
M)'!R;WAY7W!A<F%M<ULG<')O>'E?:&]S="==*2`F)@H@("`@("`@("`@("`@
M("`@("`@("`@("`@(&ES<V5T*"1P<F]X>5]P87)A;7-;)W!R;WAY7W!O<G0G
M72DI('L*("`@("`@("`@("`@("`@("`@("`D<G$M/G-E=%!R;WAY*"1P<F]X
M>5]P87)A;7-;)W!R;WAY7VAO<W0G72P@)'!R;WAY7W!A<F%M<ULG<')O>'E?
M<&]R="==*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D
M<F5S=6QT(#T@)')Q+3YS96YD4F5Q=65S="@I.PH@("`@("`@("`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@B56YA8FQE('1O
M(')E=')I979E(%=31$P@)'=S9&Q?9FYA;64L(B`N("1R<2T^9V5T4F5S<&]N
M<V5#;V1E*"DL("1W<V1L7V9N86UE*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1F:6QE7V1A=&$@/2`D<G$M/F=E=%)E<W!O;G-E0F]D
M>2@I.PH@("`@("`@("`@("`@("`@:68@*"$D9FEL95]D871A*2!["B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H
M(E5N86)L92!T;R!R971R:65V92!74T1,("1W<V1L7V9N86UE+"!N;R!H='1P
M(&)O9'DB+"`D=W-D;%]F;F%M92D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1M9#5?=W-D;"`](&UD-2@D9FEL95]D
M871A*3L*"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V-A8VAE57-E*2!["B`@
M("`@("`@("`@("`@("`D9G`@/2!F;W!E;B@D8V%C:&5N86UE+"`B=V(B*3L*
M("`@("`@("`@("`@("`@(&9W<FET92@D9G`L("1F:6QE7V1A=&$I.PH@("`@
M("`@("`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&55<V4@)B8@)&-A8VAE("8F
M("1C86-H92`A/2`D;60U7W=S9&PI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<F%I<V53;V%P1F%U;'0H(E=31$P@0VAE8VMS=6T@97)R;W(A(BP@
M)'=S9&Q?9FYA;64I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&9I;&5?
M9&%T83L*("`@('T*"GT*"F-L87-S(%-/05!?5U-$3%]087)S97(@97AT96YD
M<R!33T%07T)A<V4*>PH*("`@("\J*@H@("`@("H@1&5F:6YE(&EN=&5R;F%L
M(&%R<F%Y<R!O9B!B:6YD:6YG<RP@<&]R=',L(&]P97)A=&EO;G,L"B`@("`@
M*B!M97-S86=E<RP@971C+@H@("`@("HO"B`@("!V87(@)&-U<G)E;G1-97-S
M86=E.PH@("`@=F%R("1C=7)R96YT3W!E<F%T:6]N.PH@("`@=F%R("1C=7)R
M96YT4&]R=%1Y<&4["B`@("!V87(@)&-U<G)E;G1":6YD:6YG.PH@("`@=F%R
M("1C=7)R96YT4&]R=#L*"B`@("`O*BH*("`@("`J(%!A<G-E<B!V87)S+@H@
M("`@("HO"B`@("!V87(@)&-A8VAE.PH*("`@('9A<B`D=&YS(#T@;G5L;#L*
M("`@('9A<B`D<V]A<&YS(#T@87)R87DH)W-O87`G*3L*("`@('9A<B`D=7)I
M(#T@)R<["B`@("!V87(@)'=S9&P@/2!N=6QL.PH*("`@('9A<B`D<W1A='5S
M(#T@)R<["B`@("!V87(@)&5L96UE;G1?<W1A8VL@/2!A<G)A>2@I.PH@("`@
M=F%R("1P87)E;G1%;&5M96YT(#T@)R<["@H@("`@=F%R("1S8VAE;6$@/2`G
M)SL*("`@('9A<B`D<V-H96UA4W1A='5S(#T@)R<["B`@("!V87(@)'-C:&5M
M85]S=&%C:R`](&%R<F%Y*"D["B`@("!V87(@)&-U<G)E;G1#;VUP;&5X5'EP
M93L*("`@('9A<B`D<V-H96UA7V5L96UE;G1?<W1A8VL@/2!A<G)A>2@I.PH@
M("`@=F%R("1C=7)R96YT16QE;65N=#L*"B`@("`O*BH*("`@("`J(&-O;G-T
M<G5C=&]R"B`@("`@*B\*("`@(&9U;F-T:6]N(%-/05!?5U-$3%]087)S97(H
M)'5R:2P@)B1W<V1L+"`D9&]C<R`](&9A;'-E*0H@("`@>PH@("`@("`@('!A
M<F5N=#HZ4T]!4%]"87-E*"=74T1,4$%24T52)RD["B`@("`@("`@)'1H:7,M
M/F-A8VAE(#TF(&YE=R!33T%07U=31$Q?0V%C:&4H)'=S9&PM/F-A8VAE57-E
M+"`D=W-D;"T^8V%C:&5-87A!9V4I.PH@("`@("`@("1T:&ES+3YU<FD@/2`D
M=7)I.PH@("`@("`@("1T:&ES+3YW<V1L(#T@)B1W<V1L.PH@("`@("`@("1T
M:&ES+3YD;V-S(#T@)&1O8W,["B`@("`@("`@)'1H:7,M/G!A<G-E*"1U<FDI
M.PH@("`@?0H*("`@(&9U;F-T:6]N('!A<G-E*"1U<FDI"B`@("!["B`@("`@
M("`@+R\@0VAE8VL@=VAE=&AE<B!C;VYT96YT(&AA<R!B965N(')E860N"B`@
M("`@("`@)&9D(#T@)'1H:7,M/F-A8VAE+3YG970H)'5R:2P@)'1H:7,M/G=S
M9&PM/G!R;WAY*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D9F0I*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"1F
M9"D["B`@("`@("`@?0H*("`@("`@("`O+R!#<F5A=&4@86X@6$U,('!A<G-E
M<BX*("`@("`@("`D<&%R<V5R(#T@>&UL7W!A<G-E<E]C<F5A=&4H*3L*("`@
M("`@("!X;6Q?<&%R<V5R7W-E=%]O<'1I;VXH)'!A<G-E<BP@6$U,7T]05$E/
M3E]#05-%7T9/3$1)3D<L(#`I.PH@("`@("`@('AM;%]S971?;V)J96-T*"1P
M87)S97(L("1T:&ES*3L*("`@("`@("!X;6Q?<V5T7V5L96UE;G1?:&%N9&QE
M<B@D<&%R<V5R+"`G<W1A<G1%;&5M96YT)RP@)V5N9$5L96UE;G0G*3L*("`@
M("`@("!I9B`H)'1H:7,M/F1O8W,I('L*("`@("`@("`@("`@>&UL7W-E=%]C
M:&%R86-T97)?9&%T85]H86YD;&5R*"1P87)S97(L("=C:&%R86-T97)$871A
M)RD["B`@("`@("`@?0H*("`@("`@("!I9B`H(7AM;%]P87)S92@D<&%R<V5R
M+"`D9F0L('1R=64I*2!["B`@("`@("`@("`@("1D971A:6P@/2!S<')I;G1F
M*"=834P@97)R;W(@;VX@;&EN92`E9#H@)7,G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!X;6Q?9V5T7V-U<G)E;G1?;&EN95]N=6UB97(H)'!A
M<G-E<BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('AM;%]E<G)O
M<E]S=')I;F<H>&UL7V=E=%]E<G)O<E]C;V1E*"1P87)S97(I*2D["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")5;F%B;&4@
M=&\@<&%R<V4@5U-$3"!F:6QE("1U<FE<;B1D971A:6PB*3L*("`@("`@("!]
M"B`@("`@("`@>&UL7W!A<G-E<E]F<F5E*"1P87)S97(I.PH@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@<W1A<G0M96QE;65N
M="!H86YD;&5R"B`@("`@*B\*("`@(&9U;F-T:6]N('-T87)T16QE;65N="@D
M<&%R<V5R+"`D;F%M92P@)&%T=')S*0H@("`@>PH@("`@("`@("\O($=E="!E
M;&5M96YT('!R969I>"X*("`@("`@("`D<6YA;64@/28@;F5W(%%.86UE*"1N
M86UE*3L*("`@("`@("!I9B`H)'%N86UE+3YN<RD@>PH@("`@("`@("`@("`D
M;G,@/2`D<6YA;64M/FYS.PH@("`@("`@("`@("!I9B`H)&YS("8F("@H(21T
M:&ES+3YT;G,@)B8@<W1R8V%S96-M<"@D<6YA;64M/FYA;64L("=D969I;FET
M:6]N<R<I(#T](#`I('Q\("1N<R`]/2`D=&AI<RT^=&YS*2D@>PH@("`@("`@
M("`@("`@("`@)&YA;64@/2`D<6YA;64M/FYA;64["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@)'1H:7,M/F-U<G)E;G1486<@/2`D<6YA;64M
M/FYA;64["B`@("`@("`@)'1H:7,M/G!A<F5N=$5L96UE;G0@/2`G)SL*("`@
M("`@("`D<W1A8VM?<VEZ92`](&-O=6YT*"1T:&ES+3YE;&5M96YT7W-T86-K
M*3L*("`@("`@("!I9B`H)'-T86-K7W-I>F4I('L*("`@("`@("`@("`@)'1H
M:7,M/G!A<F5N=$5L96UE;G0@/2`D=&AI<RT^96QE;65N=%]S=&%C:ULD<W1A
M8VM?<VEZ92`M(#%=.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^96QE;65N
M=%]S=&%C:UM=(#T@)'1H:7,M/F-U<G)E;G1486<["@H@("`@("`@("\O($9I
M;F0@<W1A='5S+"!R96=I<W1E<B!D871A+@H@("`@("`@('-W:71C:"`H)'1H
M:7,M/G-T871U<RD@>PH@("`@("`@(&-A<V4@)W1Y<&5S)SH*("`@("`@("`@
M("`@+R\@<V5C="`R+C(@=W-D;#IT>7!E<PH@("`@("`@("`@("`O+R!C:&EL
M9')E;CH@>'-D.G-C:&5M80H@("`@("`@("`@("`D<&%R96YT7W1A9R`]("<G
M.PH@("`@("`@("`@("`D<W1A8VM?<VEZ92`](&-O=6YT*"1T:&ES+3YS8VAE
M;6%?<W1A8VLI.PH@("`@("`@("`@("!I9B`H)'-T86-K7W-I>F4I('L*("`@
M("`@("`@("`@("`@("1P87)E;G1?=&%G(#T@)'1H:7,M/G-C:&5M85]S=&%C
M:ULD<W1A8VM?<VEZ92`M(#%=.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!S=VET8V@@*"1Q;F%M92T^;F%M92D@>PH@("`@("`@("`@("!C87-E("=S
M8VAE;6$G.@H@("`@("`@("`@("`@("`@+R\@3F\@<&%R96YT('-H;W5L9"!B
M92!I;B!T:&4@<W1A8VLN"B`@("`@("`@("`@("`@("!I9B`H(21P87)E;G1?
M=&%G('Q\("1P87)E;G1?=&%G(#T]("=T>7!E<R<I('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@G=&%R9V5T3F%M97-P86-E
M)RP@)&%T=')S*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M<V-H96UA(#T@)'1H:7,M/G=S9&PM/F=E=$YA;65S<&%C94%T=')I8G5T94YA
M;64H)&%T=')S6R=T87)G971.86UE<W!A8V4G72D["B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G-C:&5M82`]("1T:&ES+3YW<V1L+3YG971.86UE<W!A8V5!='1R:6)U=&5.
M86UE*"1T:&ES+3YW<V1L+3YT;G,I.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S
M6R1T:&ES+3YS8VAE;6%=(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^=W-D;"T^96QE;65N='-;)'1H:7,M/G-C:&5M85T@/2!A<G)A
M>2@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("!C87-E("=C;VUP;&5X5'EP92<Z"B`@("`@("`@("`@
M("`@("!I9B`H)'!A<F5N=%]T86<@/3T@)W-C:&5M82<I('L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E(#T@)&%T=')S
M6R=N86UE)UT["B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D871T
M<G-;)VYA;65S<&%C92==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M871T<G-;)VYA;65S<&%C92==(#T@)'1H:7,M/G-C:&5M83L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM
M/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O
M;7!L97A4>7!E72`]("1A='1R<SL*("`@("`@("`@("`@("`@("`@("!I9B`H
M87)R87E?:V5Y7V5X:7-T<R@G8F%S92<L("1A='1R<RDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)'%N(#TF(&YE=R!13F%M92@D871T<G-;)V)A<V4G
M72D["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YC;VUP
M;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E;G1#;VUP;&5X
M5'EP95U;)W1Y<&4G72`]("1Q;BT^;F%M93L*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA
M75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E75LG;F%M97-P86-E)UT@/2`D
M<6XM/FYS.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H
M:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP95U;)W1Y<&4G
M72`]("=3=')U8W0G.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<V-H96UA4W1A='5S(#T@)V-O;7!L97A4>7!E
M)SL*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G=S9&PM/F5L96UE;G1S6R1T:&ES+3YS8VAE;6%=6R1T:&ES
M+3YC=7)R96YT16QE;65N=%U;)V-O;7!L97@G72`]('1R=64["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&-A<V4@)V5L96UE;G0G.@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A
M='1R<ULG='EP92==*2D@>PH@("`@("`@("`@("`@("`@("`@("1Q;B`])B!N
M97<@44YA;64H)&%T=')S6R=T>7!E)UTI.PH@("`@("`@("`@("`@("`@("`@
M("1A='1R<ULG='EP92==(#T@)'%N+3YN86UE.PH@("`@("`@("`@("`@("`@
M("`@(&EF("@D<6XM/FYS("8F(&%R<F%Y7VME>5]E>&ES=',H)'%N+3YN<RP@
M)'1H:7,M/G=S9&PM/FYA;65S<&%C97,I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1A='1R<ULG;F%M97-P86-E)UT@/2`D<6XM/FYS.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("`@("`D<&%R96YT16QE;65N="`]("<G.PH@("`@("`@("`@("`@("`@)'-T
M86-K7W-I>F4@/2!C;W5N="@D=&AI<RT^<V-H96UA7V5L96UE;G1?<W1A8VLI
M.PH@("`@("`@("`@("`@("`@:68@*"1S=&%C:U]S:7IE(#X@,"D@>PH@("`@
M("`@("`@("`@("`@("`@("1P87)E;G1%;&5M96YT(#T@)'1H:7,M/G-C:&5M
M85]E;&5M96YT7W-T86-K6R1S=&%C:U]S:7IE("T@,5T["B`@("`@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A='1R<ULG<F5F
M)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)'%N(#TF(&YE=R!13F%M92@D
M871T<G-;)W)E9B==*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8W5R
M<F5N=$5L96UE;G0@/2`D<6XM/FYA;64["B`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC=7)R96YT16QE;65N
M="`]("1A='1R<ULG;F%M92==.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@)'1H:7,M/G-C:&5M85]E;&5M96YT7W-T86-K6UT@/2`D=&AI
M<RT^8W5R<F5N=$5L96UE;G0["B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1A='1R<ULG;F%M97-P86-E)UTI*2!["B`@("`@("`@("`@("`@("`@("`@
M)&%T=')S6R=N86UE<W!A8V4G72`]("1T:&ES+3YS8VAE;6$["B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*"1P87)E;G1?=&%G(#T]
M("=S8VAE;6$G*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM
M/F5L96UE;G1S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT16QE;65N
M=%T@/2`D871T<G,["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM
M/F5L96UE;G1S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT16QE;65N
M=%U;)V-O;7!L97@G72`](&9A;'-E.PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YS8VAE;6%3=&%T=7,@/2`G96QE;65N="<["B`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP92D@>PH@("`@
M("`@("`@("`@("`@("`@("\O('=E)W)E(&EN<VED92!A(&-O;7!L97A4>7!E
M"B`@("`@("`@("`@("`@("`@("`@:68@*"AI<W-E="@D=&AI<RT^=W-D;"T^
M8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M
M<&QE>%1Y<&5=6R=O<F1E<B==*2`F)@H@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD
M=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E75LG;W)D97(G72`]/2`G<V5Q=65N
M8V4G*0H@("`@("`@("`@("`@("`@("`@("`@("`F)B`D=&AI<RT^=W-D;"T^
M8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M
M<&QE>%1Y<&5=6R=T>7!E)UT@/3T@)T%R<F%Y)RD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS
M8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R=A<G)A>51Y<&4G
M72`](&ES<V5T*"1A='1R<ULG='EP92==*2`_("1A='1R<ULG='EP92==(#H@
M;G5L;#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD
M=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E75LG96QE;65N=',G75LD=&AI<RT^
M8W5R<F5N=$5L96UE;G1=(#T@)&%T=')S.PH@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^96QE;65N
M='-;)'1H:7,M/G-C:&5M85U;)'!A<F5N=$5L96UE;G1=6R=E;&5M96YT<R==
M6R1T:&ES+3YC=7)R96YT16QE;65N=%T@/2`D871T<G,["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A
M<V4@)V-O;7!L97A#;VYT96YT)SH*("`@("`@("`@("`@8V%S92`G<VEM<&QE
M0V]N=&5N="<Z"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&-A<V4@)V5X=&5N<VEO;B<Z"B`@("`@("`@("`@(&-A<V4@)W)E<W1R:6-T
M:6]N)SH*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^<V-H96UA4W1A='5S
M(#T]("=C;VUP;&5X5'EP92<I('L*("`@("`@("`@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1A='1R<ULG8F%S92==*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D<6X@/28@;F5W(%%.86UE*"1A='1R<ULG8F%S92==*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD
M=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E75LG='EP
M92==(#T@)'%N+3YN86UE.PH*("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M5'EP97,@=&AA="!E>'1E;F0@9G)O;2!O=&AE<B!T>7!E<R!A<F5N)W0*("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@*F]F*B!T:&]S92!T>7!E<RX@4F5F
M;&5C="!T:&ES(&)Y(&1E;F]T:6YG"B`@("`@("`@("`@("`@("`@("`@("`@
M("\O('=H:6-H('1Y<&4@=&AE>2!E>'1E;F0N($DG;2!L96%V:6YG('1H90H@
M("`@("`@("`@("`@("`@("`@("`@("`O+R`G='EP92<@<V5T=&EN9R!H97)E
M('-I;F-E($DG;2!N;W0@<W5R92!W:&%T"B`@("`@("`@("`@("`@("`@("`@
M("`@("\O(')E;6]V:6YG(&ET(&UI9VAT(&)R96%K(&%T('1H92!M;VUE;G0N
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D<6YA;64M/FYA;64@/3T@
M)V5X=&5N<VEO;B<I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M
M/F-U<G)E;G1#;VUP;&5X5'EP95U;)V5X=&5N9',G72`]("1Q;BT^;F%M93L*
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L
M+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E;G1#
M;VUP;&5X5'EP95U;)W1Y<&4G72`]("=3=')U8W0G.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@8V%S92`G<V5Q=65N8V4G.@H@("`@("`@("`@
M("`@("`@:68@*"1T:&ES+3YS8VAE;6%3=&%T=7,@/3T@)V-O;7!L97A4>7!E
M)RD@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YC;VUP;&5X
M5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP
M95U;)V]R9&5R)UT@/2`D<6YA;64M/FYA;64["B`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES
M+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R=T>7!E)UTI
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YC;VUP
M;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E;G1#;VUP;&5X
M5'EP95U;)W1Y<&4G72`]("=!<G)A>2<["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("!C87-E("=A;&PG.@H@("`@("`@("`@("`@("`@)'1H:7,M
M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R
M<F5N=$-O;7!L97A4>7!E75LG;W)D97(G72`]("1Q;F%M92T^;F%M93L*("`@
M("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/G=S9&PM/F-O;7!L97A4
M>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E
M75LG='EP92==*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L
M+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E;G1#
M;VUP;&5X5'EP95U;)W1Y<&4G72`]("=3=')U8W0G.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E
M("=C:&]I8V4G.@H@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F-O;7!L
M97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4
M>7!E75LG;W)D97(G72`]("1Q;F%M92T^;F%M93L*("`@("`@("`@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^
M<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E75LG='EP92==*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YC;VUP;&5X5'EP
M97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP95U;
M)W1Y<&4G72`]("=!<G)A>2<["B`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!C87-E("=A='1R:6)U=&4G.@H@("`@("`@("`@("`@("`@:68@*"1T
M:&ES+3YS8VAE;6%3=&%T=7,@/3T@)V-O;7!L97A4>7!E)RD@>PH@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D871T<G-;)VYA;64G72DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E
M<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E75LG
M871T<FEB=71E)UU;)&%T=')S6R=N86UE)UU=(#T@)&%T=')S.PH@("`@("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D871T<G-;)W)E9B==*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'$@/28@;F5W(%%.86UE*"1A='1R<ULG<F5F)UTI.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&%T=')S(&%S
M("1K(#T^("1V*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"1K("$]("=R968G("8F('-T<G-T<B@D:RP@)'$M/FYA;64I*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V<2`])B!N97<@
M44YA;64H)'8I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H)'$M/FYA;64@/3T@)V%R<F%Y5'EP92<I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YC;VUP
M;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E;G1#;VUP;&5X
M5'EP95U;)'$M/FYA;65=(#T@)'9Q+3YN86UE+B`D=G$M/F%R<F%Y26YF;SL*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U
M<G)E;G1#;VUP;&5X5'EP95U;)W1Y<&4G72`]("=!<G)A>2<["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^
M8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M
M<&QE>%1Y<&5=6R=N86UE<W!A8V4G72`]("1V<2T^;G,["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^8V]M
M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M<&QE
M>%1Y<&5=6R1Q+3YN86UE72`]("1V<2T^;F%M93L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^<V-H96UA7W-T86-K6UT@
M/2`D<6YA;64M/FYA;64["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C
M87-E("=M97-S86=E)SH*("`@("`@("`@("`@+R\@<V5C="`R+C,@=W-D;#IM
M97-S86=E(&-H:6QD('=S9&PZ<&%R=`H@("`@("`@("`@("!S=VET8V@@*"1Q
M;F%M92T^;F%M92D@>PH@("`@("`@("`@("!C87-E("=P87)T)SH*("`@("`@
M("`@("`@("`@("1Q;B`](&YU;&P["B`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&%T=')S6R=T>7!E)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)'%N
M(#TF(&YE=R!13F%M92@D871T<G-;)W1Y<&4G72D["B`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H:7-S970H)&%T=')S6R=E;&5M96YT)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@)'%N(#TF(&YE=R!13F%M92@D871T<G-;)V5L96UE
M;G0G72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H
M)'%N*2!["B`@("`@("`@("`@("`@("`@("`@)&%T=')S6R=T>7!E)UT@/2`D
M<6XM/FYA;64["B`@("`@("`@("`@("`@("`@("`@)&%T=')S6R=N86UE<W!A
M8V4G72`]("1Q;BT^;G,["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`D=&AI<RT^=W-D;"T^;65S<V%G97-;)'1H:7,M/F-U<G)E;G1-97-S
M86=E75LD871T<G-;)VYA;64G75T@/2`D871T<G,["B`@("`@("`@("`@("`@
M("`O+R!E<G)O<B!I;B!W<V1L"@H@("`@("`@("`@("!C87-E("=D;V-U;65N
M=&%T:6]N)SH*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M9&5F875L=#H*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=P;W)T5'EP92<Z
M"B`@("`@("`@("`@("\O('-E8W0@,BXT"B`@("`@("`@("`@('-W:71C:"`H
M)'%N86UE+3YN86UE*2!["B`@("`@("`@("`@(&-A<V4@)V]P97)A=&EO;B<Z
M"B`@("`@("`@("`@("`@("`O+R!A='1R:6)U=&5S.B!N86UE"B`@("`@("`@
M("`@("`@("`O+R!C:&EL9')E;CH@=W-D;#II;G!U="!W<V1L.F]U='!U="!W
M<V1L.F9A=6QT"B`@("`@("`@("`@("`@("`D=&AI<RT^8W5R<F5N=$]P97)A
M=&EO;B`]("1A='1R<ULG;F%M92==.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/G=S9&PM/G!O<G14>7!E<ULD=&AI<RT^8W5R<F5N=%!O<G14>7!E75LD=&AI
M<RT^8W5R<F5N=$]P97)A=&EO;ET@/2`D871T<G,["B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VEN<'5T)SH*("`@("`@("`@
M("`@8V%S92`G;W5T<'5T)SH*("`@("`@("`@("`@8V%S92`G9F%U;'0G.@H@
M("`@("`@("`@("`@("`@+R\@=W-D;#II;G!U="!W<V1L.F]U='!U="!W<V1L
M.F9A=6QT"B`@("`@("`@("`@("`@("`O+R!A='1R:6)U=&5S.B!N86UE(&UE
M<W-A9V4@<&%R86UE=&5R3W)D97(H;W!T:6]N86PI"B`@("`@("`@("`@("`@
M("!I9B`H)'1H:7,M/F-U<G)E;G1/<&5R871I;VXI('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/G=S9&PM/G!O<G14>7!E<ULD=&AI
M<RT^8W5R<F5N=%!O<G14>7!E75LD=&AI<RT^8W5R<F5N=$]P97)A=&EO;EU;
M)&YA;65=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D
M;"T^<&]R=%1Y<&5S6R1T:&ES+3YC=7)R96YT4&]R=%1Y<&5=6R1T:&ES+3YC
M=7)R96YT3W!E<F%T:6]N75LD;F%M95T@/2!A<G)A>5]M97)G92@D=&AI<RT^
M=W-D;"T^<&]R=%1Y<&5S6R1T:&ES+3YC=7)R96YT4&]R=%1Y<&5=6R1T:&ES
M+3YC=7)R96YT3W!E<F%T:6]N75LD;F%M95TL("1A='1R<RD["B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/G=S9&PM/G!O<G14>7!E<ULD=&AI<RT^8W5R<F5N=%!O<G14>7!E
M75LD=&AI<RT^8W5R<F5N=$]P97)A=&EO;EU;)&YA;65=(#T@)&%T=')S.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H
M87)R87E?:V5Y7V5X:7-T<R@G;65S<V%G92<L("1A='1R<RDI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'%N(#TF(&YE=R!13F%M92@D871T<G-;)VUE
M<W-A9V4G72D["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L
M+3YP;W)T5'EP97-;)'1H:7,M/F-U<G)E;G10;W)T5'EP95U;)'1H:7,M/F-U
M<G)E;G1/<&5R871I;VY=6R1N86UE75LG;65S<V%G92==(#T@)'%N+3YN86UE
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^<&]R=%1Y
M<&5S6R1T:&ES+3YC=7)R96YT4&]R=%1Y<&5=6R1T:&ES+3YC=7)R96YT3W!E
M<F%T:6]N75LD;F%M95U;)VYA;65S<&%C92==(#T@)'%N+3YN<SL*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V1O8W5M96YT871I;VXG
M.@H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!D969A=6QT
M.@H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)V)I;F1I;F<G.@H@("`@("`@
M("`@("`D;G,@/2`D<6YA;64M/FYS(#\@)'1H:7,M/G=S9&PM/FYA;65S<&%C
M97-;)'%N86UE+3YN<UT@.B!30TA%34%?5U-$3#L*("`@("`@("`@("`@<W=I
M=&-H("@D;G,I('L*("`@("`@("`@("`@8V%S92!30TA%34%?4T]!4#H*("`@
M("`@("`@("`@("`@("\O('1H:7,@9&5A;',@=VET:"!W<V1L('-E8W1I;VX@
M,R!S;V%P(&)I;F1I;F<*("`@("`@("`@("`@("`@('-W:71C:"`H)'%N86UE
M+3YN86UE*2!["B`@("`@("`@("`@("`@("!C87-E("=B:6YD:6YG)SH*("`@
M("`@("`@("`@("`@("`@("`O+R!S96-T(#,N,PH@("`@("`@("`@("`@("`@
M("`@("\O('-O87`Z8FEN9&EN9RP@871T<FEB=71E<SH@=')A;G-P;W)T*')E
M<75I<F5D*2P@<W1Y;&4H;W!T:6]N86PL(&1E9F%U;'0@/2!D;V-U;65N="D*
M("`@("`@("`@("`@("`@("`@("`O+R!I9B!S='EL92!I<R!M:7-S:6YG+"!I
M="!I<R!A<W-U;65D('1O(&)E("=D;V-U;65N="<*("`@("`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1A='1R<ULG<W1Y;&4G72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&%T=')S6R=S='EL92==(#T@)V1O8W5M96YT)SL*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G=S9&PM/F)I;F1I;F=S6R1T:&ES+3YC=7)R96YT0FEN9&EN9UT@/2!A
M<G)A>5]M97)G92@D=&AI<RT^=W-D;"T^8FEN9&EN9W-;)'1H:7,M/F-U<G)E
M;G1":6YD:6YG72P@)&%T=')S*3L*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@("`@("!C87-E("=O<&5R871I;VXG.@H@("`@("`@
M("`@("`@("`@("`@("\O('-E8W0@,RXT"B`@("`@("`@("`@("`@("`@("`@
M+R\@<V]A<#IO<&5R871I;VXL(&%T=')I8G5T97,Z('-O87!!8W1I;VXH<F5Q
M=6ER960I+"!S='EL92AO<'1I;VYA;"P@9&5F875L="`]('-O87`Z8FEN9&EN
M9SIS='EL92D*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1A='1R
M<ULG<W1Y;&4G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&%T=')S
M6R=S='EL92==(#T@)'1H:7,M/G=S9&PM/F)I;F1I;F=S6R1T:&ES+3YC=7)R
M96YT0FEN9&EN9UU;)W-T>6QE)UT["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^=W-D;"T^8FEN
M9&EN9W-;)'1H:7,M/F-U<G)E;G1":6YD:6YG75LG;W!E<F%T:6]N<R==6R1T
M:&ES+3YC=7)R96YT3W!E<F%T:6]N72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G=S9&PM/F)I;F1I;F=S6R1T:&ES+3YC=7)R96YT0FEN
M9&EN9UU;)V]P97)A=&EO;G,G75LD=&AI<RT^8W5R<F5N=$]P97)A=&EO;ET@
M/2!A<G)A>5]M97)G92@D=&AI<RT^=W-D;"T^8FEN9&EN9W-;)'1H:7,M/F-U
M<G)E;G1":6YD:6YG75LG;W!E<F%T:6]N<R==6R1T:&ES+3YC=7)R96YT3W!E
M<F%T:6]N72P@)&%T=')S*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^8FEN9&EN
M9W-;)'1H:7,M/F-U<G)E;G1":6YD:6YG75LG;W!E<F%T:6]N<R==6R1T:&ES
M+3YC=7)R96YT3W!E<F%T:6]N72`]("1A='1R<SL*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("`@("`@8V%S92`G8F]D>2<Z"B`@("`@("`@("`@("`@("`@("`@+R\@<V5C
M="`S+C4*("`@("`@("`@("`@("`@("`@("`O+R!S;V%P.F)O9'D@871T<FEB
M=71E<SH*("`@("`@("`@("`@("`@("`@("`O+R!P87)T("T@;W!T:6]N86PN
M("!L:7-T960@<&%R=',@;75S="!A<'!E87(@:6X@8F]D>2P@;6ES<VEN9R!M
M96%N<R!A;&P@<&%R=',@87!P96%R(&EN(&)O9'D*("`@("`@("`@("`@("`@
M("`@("`O+R!U<V4@+2!R97%U:7)E9"X@96YC;V1E9'QL:71E<F%L"B`@("`@
M("`@("`@("`@("`@("`@+R\@96YC;V1I;F=3='EL92`M(&]P=&EO;F%L+B`@
M<W!A8V4@<V5P97)A=&5D(&QI<W0@;V8@96YC;V1I;F=S("AU<FDG<RD*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^8FEN9&EN9W-;)'1H:7,M
M/F-U<G)E;G1":6YD:6YG70H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!;)V]P97)A=&EO;G,G75LD=&AI<RT^8W5R<F5N=$]P97)A=&EO
M;EU;)'1H:7,M/F]P4W1A='5S72`]("1A='1R<SL*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=F875L="<Z"B`@
M("`@("`@("`@("`@("`@("`@+R\@<V5C="`S+C8*("`@("`@("`@("`@("`@
M("`@("`O+R!S;V%P.F9A=6QT(&%T=')I8G5T97,Z(&YA;64@=7-E("!E;F-O
M9&EN9U-T>6QE(&YA;65S<&%C90H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YW<V1L+3YB:6YD:6YG<ULD=&AI<RT^8W5R<F5N=$)I;F1I;F=="B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%LG;W!E<F%T:6]N<R==
M6R1T:&ES+3YC=7)R96YT3W!E<F%T:6]N75LD=&AI<RT^;W!3=&%T=7-=(#T@
M)&%T=')S.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@("`@(&-A<V4@)VAE861E<B<Z"B`@("`@("`@("`@("`@("`@("`@+R\@
M<V5C="`S+C<*("`@("`@("`@("`@("`@("`@("`O+R!S;V%P.FAE861E<B!A
M='1R:6)U=&5S.B!M97-S86=E('!A<G0@=7-E(&5N8V]D:6YG4W1Y;&4@;F%M
M97-P86-E"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F)I;F1I
M;F=S6R1T:&ES+3YC=7)R96YT0FEN9&EN9UT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@6R=O<&5R871I;VYS)UU;)'1H:7,M/F-U<G)E
M;G1/<&5R871I;VY=6R1T:&ES+3YO<%-T871U<UU;)VAE861E<G,G75M=(#T@
M)&%T=')S.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@("`@(&-A<V4@)VAE861E<F9A=6QT)SH*("`@("`@("`@("`@("`@("`@
M("`O+R!S96-T(#,N-PH@("`@("`@("`@("`@("`@("`@("\O('-O87`Z:&5A
M9&5R(&%T=')I8G5T97,Z(&UE<W-A9V4@<&%R="!U<V4@96YC;V1I;F=3='EL
M92!N86UE<W!A8V4*("`@("`@("`@("`@("`@("`@("`D:&5A9&5R(#T@8V]U
M;G0H)'1H:7,M/G=S9&PM/F)I;F1I;F=S6R1T:&ES+3YC=7)R96YT0FEN9&EN
M9UT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6R=O<&5R
M871I;VYS)UU;)'1H:7,M/F-U<G)E;G1/<&5R871I;VY=6R1T:&ES+3YO<%-T
M871U<UU;)VAE861E<G,G72DM,3L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^=W-D;"T^8FEN9&EN9W-;)'1H:7,M/F-U<G)E;G1":6YD:6YG70H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!;)V]P97)A=&EO;G,G
M75LD=&AI<RT^8W5R<F5N=$]P97)A=&EO;EU;)'1H:7,M/F]P4W1A='5S75LG
M:&5A9&5R<R==6R1H96%D97)=6R=F875L="==(#T@)&%T=')S.PH@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)V1O
M8W5M96YT871I;VXG.@H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@+R\@
M97)R;W(A("!N;W0@82!V86QI9"!E;&5M96YT(&EN<VED92!B:6YD:6YG"B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@4T-(14U!
M7U=31$PZ"B`@("`@("`@("`@("`@("`O+R!86%@@=F5R:69Y(&-O<G)E8W0@
M;F%M97-P86-E"B`@("`@("`@("`@("`@("`O+R!F;W(@;F]W+"!D969A=6QT
M(&ES('1H92`G=W-D;"<@;F%M97-P86-E"B`@("`@("`@("`@("`@("`O+R!O
M=&AE<B!P;W-S:6)L92!N86UE<W!A8V5S(&EN8VQU9&4@<VUT<"P@:'1T<"P@
M971C+B!F;W(@86QT97)N871E(&)I;F1I;F=S"B`@("`@("`@("`@("`@("!S
M=VET8V@@*"1Q;F%M92T^;F%M92D@>PH@("`@("`@("`@("`@("`@8V%S92`G
M;W!E<F%T:6]N)SH*("`@("`@("`@("`@("`@("`@("`O+R!S96-T(#(N-0H@
M("`@("`@("`@("`@("`@("`@("\O('=S9&PZ;W!E<F%T:6]N(&%T=')I8G5T
M97,Z(&YA;64*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8W5R<F5N=$]P
M97)A=&EO;B`]("1A='1R<ULG;F%M92==.PH@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)V]U='!U="<Z"B`@("`@
M("`@("`@("`@("!C87-E("=I;G!U="<Z"B`@("`@("`@("`@("`@("!C87-E
M("=F875L="<Z"B`@("`@("`@("`@("`@("`@("`@+R\@<V5C="`R+C4*("`@
M("`@("`@("`@("`@("`@("`O+R!W<V1L.FEN<'5T(&%T=')I8G5T97,Z(&YA
M;64*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;W!3=&%T=7,@/2`D<6YA
M;64M/FYA;64["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("`@("`@8V%S92`G9&]C=6UE;G1A=&EO;B<Z"B`@("`@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92!30TA%34%?5U-$
M3%](5%10.@H@("`@("`@("`@("`@("`@<W=I=&-H("@D<6YA;64M/FYA;64I
M('L*("`@("`@("`@("`@("`@(&-A<V4@)V)I;F1I;F<G.@H@("`@("`@("`@
M("`@("`@("`@("\O('-E8W0@-"XT"B`@("`@("`@("`@("`@("`@("`@+R\@
M:'1T<#IB:6YD:6YG(&%T=')I8G5T97,Z('9E<F(*("`@("`@("`@("`@("`@
M("`@("`O+R!P87)E;G0Z('=S9&PZ8FEN9&EN9PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YW<V1L+3YB:6YD:6YG<ULD=&AI<RT^8W5R<F5N=$)I;F1I
M;F==(#T@87)R87E?;65R9V4H)'1H:7,M/G=S9&PM/F)I;F1I;F=S6R1T:&ES
M+3YC=7)R96YT0FEN9&EN9UTL("1A='1R<RD["B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G;W!E<F%T:6]N)SH*
M("`@("`@("`@("`@("`@("`@("`O+R!S96-T(#0N-0H@("`@("`@("`@("`@
M("`@("`@("\O(&AT='`Z;W!E<F%T:6]N(&%T=')I8G5T97,Z(&QO8V%T:6]N
M"B`@("`@("`@("`@("`@("`@("`@+R\@<&%R96YT.B!W<V1L.F]P97)A=&EO
M;@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YB:6YD:6YG<ULD
M=&AI<RT^8W5R<F5N=$)I;F1I;F==6R=O<&5R871I;VYS)UT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!;)'1H:7,M/F-U<G)E;G1/<&5R871I;VY=(#T@)&%T=')S.PH@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)W5R
M;$5N8V]D960G.@H@("`@("`@("`@("`@("`@("`@("\O('-E8W0@-"XV"B`@
M("`@("`@("`@("`@("`@("`@+R\@:'1T<#IU<FQ%;F-O9&5D(&%T=')I8G5T
M97,Z(&QO8V%T:6]N"B`@("`@("`@("`@("`@("`@("`@+R\@<&%R96YT.B!W
M<V1L.FEN<'5T('=S9&PZ;W5T<'5T(&5T8RX*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^=W-D;"T^8FEN9&EN9W-;)'1H:7,M/F-U<G)E;G1":6YD:6YG
M75LG;W!E<F%T:6]N<R==6R1T:&ES+3YO<%-T871U<UT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!;
M)'1H:7,M/F-U<G)E;G1/<&5R871I;VY=6R=U<FDG72`]("=U<FQ%;F-O9&5D
M)SL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@
M("!C87-E("=U<FQ297!L86-E;65N="<Z"B`@("`@("`@("`@("`@("`@("`@
M+R\@<V5C="`T+C<*("`@("`@("`@("`@("`@("`@("`O+R!H='1P.G5R;%)E
M<&QA8V5M96YT(&%T=')I8G5T97,Z(&QO8V%T:6]N"B`@("`@("`@("`@("`@
M("`@("`@+R\@<&%R96YT.B!W<V1L.FEN<'5T('=S9&PZ;W5T<'5T(&5T8RX*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^8FEN9&EN9W-;)'1H
M:7,M/F-U<G)E;G1":6YD:6YG75LG;W!E<F%T:6]N<R==6R1T:&ES+3YO<%-T
M871U<UT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!;)'1H:7,M/F-U<G)E;G1/<&5R871I;VY=6R=U
M<FDG72`]("=U<FQ297!L86-E;65N="<["B`@("`@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G9&]C=6UE;G1A=&EO;B<Z
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@
M9&5F875L=#H*("`@("`@("`@("`@("`@("`@("`O+R!E<G)O<@H@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@8V%S92!30TA%34%?34E-13H*("`@("`@("`@("`@("`@("\O('-E
M8W0@-0H@("`@("`@("`@("`@("`@+R\@86QL(&UI;64@<&%R=',@87)E(&-H
M:6QD<F5N(&]F('=S9&PZ:6YP=70L('=S9&PZ;W5T<'5T+"!E=&,N"B`@("`@
M("`@("`@("`@("`O+R!U;G-U<&]R=&5D(&%S(&]F('EE=`H@("`@("`@("`@
M("`@("`@<W=I=&-H("@D<6YA;64M/FYA;64I('L*("`@("`@("`@("`@("`@
M(&-A<V4@)V-O;G1E;G0G.@H@("`@("`@("`@("`@("`@("`@("\O('-E8W0@
M-2XS(&UI;64Z8V]N=&5N=`H@("`@("`@("`@("`@("`@("`@("\O(#QM:6UE
M.F-O;G1E;G0@<&%R=#TB;FUT;VME;B(_('1Y<&4](G-T<FEN9R(_+SX*("`@
M("`@("`@("`@("`@("`@("`O+R!P87)T(&%T=')I8G5T92!O;FQY(')E<75I
M<F5D(&EF(&-O;G1E;G0@:7,@8VAI;&0@;V8@;75L=&EP87)T(')E;&%T960L
M"B`@("`@("`@("`@("`@("`@("`@+R\@("`@("`@(&ET(&-O;G1A:6YS('1H
M92!N86UE(&]F('1H92!P87)T"B`@("`@("`@("`@("`@("`@("`@+R\@='EP
M92!A='1R:6)U=&4@8V]N=&%I;G,@=&AE(&UI;64@='EP90H@("`@("`@("`@
M("`@("`@8V%S92`G;75L=&EP87)T4F5L871E9"<Z"B`@("`@("`@("`@("`@
M("`@("`@+R\@<V5C="`U+C0@;6EM93IM=6QT:7!A<G1296QA=&5D"B`@("`@
M("`@("`@("`@("!C87-E("=P87)T)SH*("`@("`@("`@("`@("`@(&-A<V4@
M)VUI;658;6PG.@H@("`@("`@("`@("`@("`@("`@("\O('-E8W0@-2XV(&UI
M;64Z;6EM95AM;`H@("`@("`@("`@("`@("`@("`@("\O(#QM:6UE.FUI;658
M;6P@<&%R=#TB;FUT;VME;B(_+SX*("`@("`@("`@("`@("`@("`@("`O+PH@
M("`@("`@("`@("`@("`@8V%S92`G9&]C=6UE;G1A=&EO;B<Z"B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@9&5F875L=#H*
M("`@("`@("`@("`@("`@("`@("`O+R!E<G)O<@H@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@8V%S
M92!30TA%34%?1$E-13H*("`@("`@("`@("`@("`@("\O($1)344@:7,@9&5F
M:6YE9"!I;CH*("`@("`@("`@("`@("`@("\O(&AT='`Z+R]G;W1D;W1N970N
M8V]M+W1E86TO>&UL7W=S<W!E8W,O9&EM92]74T1,+45X=&5N<VEO;BUF;W(M
M1$E-12YH=&T*("`@("`@("`@("`@("`@("\O(&%L;"!$24U%('!A<G1S(&%R
M92!C:&EL9')E;B!O9B!W<V1L.FEN<'5T+"!W<V1L.F]U='!U="P@971C+@H@
M("`@("`@("`@("`@("`@+R\@=6YS=7!O<G1E9"!A<R!O9B!Y970*("`@("`@
M("`@("`@("`@('-W:71C:"`H)'%N86UE+3YN86UE*2!["B`@("`@("`@("`@
M("`@("!C87-E("=M97-S86=E)SH*("`@("`@("`@("`@("`@("`@("`O+R!S
M96-T(#0N,2!D:6UE.FUE<W-A9V4*("`@("`@("`@("`@("`@("`@("`O+R!A
M<'!E87)S(&EN(&)I;F1I;F<@<V5C=&EO;@H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YW<V1L+3YB:6YD:6YG<ULD=&AI<RT^8W5R<F5N=$)I;F1I;F==
M6R=D:6UE)UT@/2`D871T<G,["B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@(&1E9F%U
M;'0Z"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G<V5R=FEC92<Z"B`@("`@
M("`@("`@("1N<R`]("1Q;F%M92T^;G,@/R`D=&AI<RT^=W-D;"T^;F%M97-P
M86-E<ULD<6YA;64M/FYS72`Z(%-#2$5-05]74T1,.PH*("`@("`@("`@("`@
M<W=I=&-H("@D<6YA;64M/FYA;64I('L*("`@("`@("`@("`@8V%S92`G<&]R
M="<Z"B`@("`@("`@("`@("`@("`O+R!S96-T(#(N-B!W<V1L.G!O<G0@871T
M<FEB=71E<SH@;F%M92!B:6YD:6YG"B`@("`@("`@("`@("`@("`D=&AI<RT^
M8W5R<F5N=%!O<G0@/2`D871T<G-;)VYA;64G73L*("`@("`@("`@("`@("`@
M("1T:&ES+3YW<V1L+3YS97)V:6-E<ULD=&AI<RT^8W5R<F5N=%-E<G9I8V5=
M6R=P;W)T<R==6R1T:&ES+3YC=7)R96YT4&]R=%T@/2`D871T<G,["B`@("`@
M("`@("`@("`@("`O+R!86%@@:&%C:R!T;R!D96%L('=I=&@@8FEN9&EN9R!N
M86UE<W!A8V5S"B`@("`@("`@("`@("`@("`D<6X@/28@;F5W(%%.86UE*"1A
M='1R<ULG8FEN9&EN9R==*3L*("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L
M+3YS97)V:6-E<ULD=&AI<RT^8W5R<F5N=%-E<G9I8V5=6R=P;W)T<R==6R1T
M:&ES+3YC=7)R96YT4&]R=%U;)V)I;F1I;F<G72`]("1Q;BT^;F%M93L*("`@
M("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YS97)V:6-E<ULD=&AI<RT^8W5R
M<F5N=%-E<G9I8V5=6R=P;W)T<R==6R1T:&ES+3YC=7)R96YT4&]R=%U;)VYA
M;65S<&%C92==(#T@)'%N+3YN<SL*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@8V%S92`G861D<F5S<R<Z"B`@("`@("`@("`@("`@("`D
M=&AI<RT^=W-D;"T^<V5R=FEC97-;)'1H:7,M/F-U<G)E;G1397)V:6-E75LG
M<&]R=',G75LD=&AI<RT^8W5R<F5N=%!O<G1=6R=A9&1R97-S)UT@/2`D871T
M<G,["B`@("`@("`@("`@("`@("`O+R!W:&%T(%194$4@;V8@<&]R="!I<R!I
M=#\@(%-/05`@;W(@2%144#\*("`@("`@("`@("`@("`@("1N<R`]("1Q;F%M
M92T^;G,@/R`D=&AI<RT^=W-D;"T^;F%M97-P86-E<ULD<6YA;64M/FYS72`Z
M(%-#2$5-05]74T1,.PH@("`@("`@("`@("`@("`@<W=I=&-H("@D;G,I('L*
M("`@("`@("`@("`@("`@(&-A<V4@4T-(14U!7U=31$Q?2%144#H*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^<V5R=FEC97-;)'1H:7,M/F-U
M<G)E;G1397)V:6-E75LG<&]R=',G75LD=&AI<RT^8W5R<F5N=%!O<G1=6R=T
M>7!E)UT])VAT='`G.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@("`@(&-A<V4@4T-(14U!7U-/05`Z"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G=S9&PM/G-E<G9I8V5S6R1T:&ES+3YC=7)R96YT4V5R
M=FEC95U;)W!O<G1S)UU;)'1H:7,M/F-U<G)E;G10;W)T75LG='EP92==/2=S
M;V%P)SL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@("`@("\O(%-H;W5L9&XG
M="!H87!P96XL('=E)VQL(&%S<W5M92!33T%0+@H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YW<V1L+3YS97)V:6-E<ULD=&AI<RT^8W5R<F5N=%-E<G9I
M8V5=6R=P;W)T<R==6R1T:&ES+3YC=7)R96YT4&]R=%U;)W1Y<&4G73TG<V]A
M<"<["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("!C87-E("=D;V-U;65N=&%T:6]N)SH*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`O+R!4;W`@;&5V96P@96QE;65N=',@9F]U;F0@=6YD97(@=W-D;#ID969I
M;FET:6]N<RX*("`@("`@("!S=VET8V@@*"1Q;F%M92T^;F%M92D@>PH@("`@
M("`@(&-A<V4@)VEM<&]R="<Z"B`@("`@("`@("`@("\O('-E8W0@,BXQ+C$@
M=W-D;#II;7!O<G0@871T<FEB=71E<SH@;F%M97-P86-E(&QO8V%T:6]N"B`@
M("`@("`@("`@(&EF("@H:7-S970H)&%T=')S6R=L;V-A=&EO;B==*2!\?"!I
M<W-E="@D871T<G-;)W-C:&5M84QO8V%T:6]N)UTI*2`F)@H@("`@("`@("`@
M("`@("`@(6ES<V5T*"1T:&ES+3YW<V1L+3YI;7!O<G1S6R1A='1R<ULG;F%M
M97-P86-E)UU=*2D@>PH@("`@("`@("`@("`@("`@)'5R:2`](&ES<V5T*"1A
M='1R<ULG;&]C871I;VXG72D@/R`D871T<G-;)VQO8V%T:6]N)UT@.B`D871T
M<G-;)W-C:&5M84QO8V%T:6]N)UT["B`@("`@("`@("`@("`@("`D;&]C871I
M;VX@/2!`<&%R<V5?=7)L*"1U<FDI.PH@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D;&]C871I;VY;)W-C:&5M92==*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1B87-E(#T@0'!A<G-E7W5R;"@D=&AI<RT^=7)I*3L*("`@("`@("`@
M("`@("`@("`@("`D=7)I(#T@)'1H:7,M/FUE<F=E57)L*"1B87-E+"`D=7)I
M*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D=&AI<RT^
M=W-D;"T^:6UP;W)T<ULD871T<G-;)VYA;65S<&%C92==72`]("1A='1R<SL*
M("`@("`@("`@("`@("`@("1I;7!O<G1?<&%R<V5R7V-L87-S(#T@9V5T7V-L
M87-S*"1T:&ES*3L*("`@("`@("`@("`@("`@("1I;7!O<G1?<&%R<V5R(#TF
M(&YE=R`D:6UP;W)T7W!A<G-E<E]C;&%S<R@D=7)I+"`D=&AI<RT^=W-D;"P@
M)'1H:7,M/F1O8W,I.PH@("`@("`@("`@("`@("`@:68@*"1I;7!O<G1?<&%R
M<V5R+3YF875L="D@>PH@("`@("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES
M+3YW<V1L+3YI;7!O<G1S6R1A='1R<ULG;F%M97-P86-E)UU=*3L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`D=&AI<RT^8W5R<F5N=$EM<&]R="`]("1A='1R
M<ULG;F%M97-P86-E)UT["B`@("`@("`@("`@('T*("`@("`@("`@("`@+R\@
M0V]N=&EN=64@;VX@=&\@=&AE("=T>7!E<R<@8V%S92`M(&QA8VL@;V8@8G)E
M86L[(&ES"B`@("`@("`@("`@("\O(&EN=&5N=&EO;F%L+@H*("`@("`@("!C
M87-E("=T>7!E<R<Z"B`@("`@("`@("`@("\O('-E8W0@,BXR('=S9&PZ='EP
M97,*("`@("`@("`@("`@)'1H:7,M/G-T871U<R`]("=T>7!E<R<["B`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=S8VAE;6$G.@H@("`@("`@
M("`@("`O+R!792!C86X@:&ET('1H:7,@870@=&AE('1O<"!L979E;"!I9B!W
M92=V92!B965N(&%S:V5D('1O"B`@("`@("`@("`@("\O(&EM<&]R="!A;B!8
M4T0@9FEL92X*("`@("`@("`@("`@:68@*"%E;7!T>2@D871T<G-;)W1A<F=E
M=$YA;65S<&%C92==*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-C:&5M
M82`]("1T:&ES+3YW<V1L+3YG971.86UE<W!A8V5!='1R:6)U=&5.86UE*"1A
M='1R<ULG=&%R9V5T3F%M97-P86-E)UTI.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-C:&5M82`]("1T:&ES+3YW<V1L
M+3YG971.86UE<W!A8V5!='1R:6)U=&5.86UE*"1T:&ES+3YW<V1L+3YT;G,I
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3YW<V1L+3YC;VUP
M;&5X5'EP97-;)'1H:7,M/G-C:&5M85T@/2!A<G)A>2@I.PH@("`@("`@("`@
M("`D=&AI<RT^=W-D;"T^96QE;65N='-;)'1H:7,M/G-C:&5M85T@/2!A<G)A
M>2@I.PH@("`@("`@("`@("`D=&AI<RT^<V-H96UA7W-T86-K6UT@/2`D<6YA
M;64M/FYA;64["B`@("`@("`@("`@("1T:&ES+3YS=&%T=7,@/2`G='EP97,G
M.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G;65S<V%G92<Z
M"B`@("`@("`@("`@("\O('-E8W0@,BXS('=S9&PZ;65S<V%G92!A='1R:6)U
M=&5S.B!N86UE(&-H:6QD<F5N.G=S9&PZ<&%R=`H@("`@("`@("`@("`D=&AI
M<RT^<W1A='5S(#T@)VUE<W-A9V4G.PH@("`@("`@("`@("!I9B`H:7-S970H
M)&%T=')S6R=N86UE)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^8W5R
M<F5N=$UE<W-A9V4@/2`D871T<G-;)VYA;64G73L*("`@("`@("`@("`@("`@
M("1T:&ES+3YW<V1L+3YM97-S86=E<ULD=&AI<RT^8W5R<F5N=$UE<W-A9V5=
M(#T@87)R87DH*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@8V%S92`G<&]R=%1Y<&4G.@H@("`@("`@("`@("`O+R!S96-T
M(#(N-"!W<V1L.G!O<G14>7!E"B`@("`@("`@("`@("\O(&%T=')I8G5T97,Z
M(&YA;64*("`@("`@("`@("`@+R\@8VAI;&1R96XZ('=S9&PZ;W!E<F%T:6]N
M"B`@("`@("`@("`@("1T:&ES+3YS=&%T=7,@/2`G<&]R=%1Y<&4G.PH@("`@
M("`@("`@("`D=&AI<RT^8W5R<F5N=%!O<G14>7!E(#T@)&%T=')S6R=N86UE
M)UT["B`@("`@("`@("`@("1T:&ES+3YW<V1L+3YP;W)T5'EP97-;)'1H:7,M
M/F-U<G)E;G10;W)T5'EP95T@/2!A<G)A>2@I.PH@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@8V%S92`G8FEN9&EN9R<Z"B`@("`@("`@("`@("\O('-E
M8W0@,BXU('=S9&PZ8FEN9&EN9R!A='1R:6)U=&5S.B!N86UE('1Y<&4*("`@
M("`@("`@("`@+R\@8VAI;&1R96XZ('=S9&PZ;W!E<F%T:6]N('-O87`Z8FEN
M9&EN9R!H='1P.F)I;F1I;F<*("`@("`@("`@("`@:68@*"1Q;F%M92T^;G,@
M)B8@)'%N86UE+3YN<R`A/2`D=&AI<RT^=&YS*2!["B`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^<W1A
M='5S(#T@)V)I;F1I;F<G.PH@("`@("`@("`@("`D=&AI<RT^8W5R<F5N=$)I
M;F1I;F<@/2`D871T<G-;)VYA;64G73L*("`@("`@("`@("`@)'%N(#TF(&YE
M=R!13F%M92@D871T<G-;)W1Y<&4G72D["B`@("`@("`@("`@("1T:&ES+3YW
M<V1L+3YB:6YD:6YG<ULD=&AI<RT^8W5R<F5N=$)I;F1I;F==6R=T>7!E)UT@
M/2`D<6XM/FYA;64["B`@("`@("`@("`@("1T:&ES+3YW<V1L+3YB:6YD:6YG
M<ULD=&AI<RT^8W5R<F5N=$)I;F1I;F==6R=N86UE<W!A8V4G72`]("1Q;BT^
M;G,["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=S97)V:6-E
M)SH*("`@("`@("`@("`@+R\@<V5C="`R+C<@=W-D;#IS97)V:6-E(&%T=')I
M8G5T97,Z(&YA;64@8VAI;&1R96XZ('!O<G1S"B`@("`@("`@("`@("1T:&ES
M+3YC=7)R96YT4V5R=FEC92`]("1A='1R<ULG;F%M92==.PH@("`@("`@("`@
M("`D=&AI<RT^=W-D;"T^<V5R=FEC97-;)'1H:7,M/F-U<G)E;G1397)V:6-E
M75LG<&]R=',G72`](&%R<F%Y*"D["B`@("`@("`@("`@("1T:&ES+3YS=&%T
M=7,@/2`G<V5R=FEC92<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C
M87-E("=D969I;FET:6]N<R<Z"B`@("`@("`@("`@("\O('-E8R`R+C$@=W-D
M;#ID969I;FET:6]N<PH@("`@("`@("`@("`O+R!A='1R:6)U=&5S.B!N86UE
M('1A<F=E=$YA;65S<&%C92!X;6QN<SHJ"B`@("`@("`@("`@("\O(&-H:6QD
M<F5N.B!W<V1L.FEM<&]R="!W<V1L.G1Y<&5S('=S9&PZ;65S<V%G92!W<V1L
M.G!O<G14>7!E('=S9&PZ8FEN9&EN9R!W<V1L.G-E<G9I8V4*("`@("`@("`@
M("`@)'1H:7,M/G=S9&PM/F1E9FEN:71I;VX@/2`D871T<G,["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1A='1R<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@
M("`@("`@("`@("`@:68@*'-T<G-T<B@D:V5Y+"`G>&UL;G,Z)RD@(3T](&9A
M;'-E*2!["B`@("`@("`@("`@("`@("`@("`@)'%N(#TF(&YE=R!13F%M92@D
M:V5Y*3L*("`@("`@("`@("`@("`@("`@("`O+R!86%@@;F5E9"!T;R!R969A
M8W1O<B!N<R!H86YD;&EN9RX*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M=W-D;"T^;F%M97-P86-E<ULD<6XM/FYA;65=(#T@)'9A;'5E.PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YN<ULD=F%L=65=(#T@)'%N+3YN
M86UE.PH@("`@("`@("`@("`@("`@("`@(&EF("@D:V5Y(#T]("=T87)G971.
M86UE<W!A8V4G('Q\"B`@("`@("`@("`@("`@("`@("`@("`@('-T<F-A<V5C
M;7`H)'9A;'5E+%-/05!?4T-(14U!*2`]/2`P*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YS;V%P;G-;72`]("1Q;BT^;F%M93L*("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H:6Y?87)R87DH)'9A;'5E+"`D=&AI<RT^7UA-3%-C:&5M82DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YX<V0@
M/2`D=F%L=64["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*&ES<V5T*"1N<RD@)B8@)&YS*2!["B`@("`@("`@
M("`@("`@("`D;F%M97-P86-E(#T@)WAM;&YS.B<@+B`D;G,["B`@("`@("`@
M("`@("`@("!I9B`H(21T:&ES+3YW<V1L+3YD969I;FET:6]N6R1N86UE<W!A
M8V5=*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I
M<V53;V%P1F%U;'0H(G!A<G-E(&5R<F]R+"!N;R!N86UE<W!A8V4@9F]R("1N
M86UE<W!A8V4B+"`D=&AI<RT^=7)I*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1T:&ES+3YT;G,@/2`D;G,["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@96YD+65L96UE;G0@:&%N9&QE<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@96YD16QE;65N="@D<&%R<V5R+"`D;F%M92D*("`@('L*("`@("`@("`D
M<W1A8VMS:7IE(#T@8V]U;G0H)'1H:7,M/F5L96UE;G1?<W1A8VLI.PH@("`@
M("`@(&EF("@D<W1A8VMS:7IE*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^
M96QE;65N=%]S=&%C:ULD<W1A8VMS:7IE("T@,5T@/3T@)V1E9FEN:71I;VYS
M)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-T871U<R`]("<G.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&%R<F%Y7W!O<"@D=&AI<RT^96QE;65N
M=%]S=&%C:RD["B`@("`@("`@?0H*("`@("`@("!I9B`H<W1R:7-T<B@D;F%M
M92P@)W-C:&5M82<I*2!["B`@("`@("`@("`@(&%R<F%Y7W!O<"@D=&AI<RT^
M<V-H96UA7W-T86-K*3L*("`@("`@("`@("`@)'1H:7,M/G-C:&5M82`]("<G
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3YS8VAE;6$I('L*("`@
M("`@("`@("`@87)R87E?<&]P*"1T:&ES+3YS8VAE;6%?<W1A8VLI.PH@("`@
M("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/G-C:&5M85]S=&%C:RD@/#T@,2D@
M>PH@("`@("`@("`@("`@("`@+RH@0V]R<F5C="!T:&4@='EP92!F;W(@<V5Q
M=65N8V5S('=I=&@@;75L=&EP;&4*("`@("`@("`@("`@("`@("`J(&5L96UE
M;G1S+B`J+PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YC=7)R
M96YT0V]M<&QE>%1Y<&4I("8F(&ES<V5T*"1T:&ES+3YW<V1L+3YC;VUP;&5X
M5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP
M95U;)W1Y<&4G72D*("`@("`@("`@("`@("`@("`@("`F)B`D=&AI<RT^=W-D
M;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT
M0V]M<&QE>%1Y<&5=6R=T>7!E)UT@/3T@)T%R<F%Y)PH@("`@("`@("`@("`@
M("`@("`@("8F(&%R<F%Y7VME>5]E>&ES=',H)V5L96UE;G1S)RP@)'1H:7,M
M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R
M<F5N=$-O;7!L97A4>7!E72D*("`@("`@("`@("`@("`@("`@("`F)B!C;W5N
M="@D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T
M:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R=E;&5M96YT<R==*2`^(#$I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F-O;7!L97A4
M>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E
M75LG='EP92==(#T@)U-T<G5C="<["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("`@("`@:68@*'-T<FES='(H)&YA;64L("=C;VUP
M;&5X5'EP92<I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^8W5R<F5N=$-O
M;7!L97A4>7!E(#T@)R<["B`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)'1H
M:7,M/G-C:&5M85]E;&5M96YT7W-T86-K*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YC=7)R96YT16QE;65N="`](&%R<F%Y7W!O<"@D=&AI<RT^
M<V-H96UA7V5L96UE;G1?<W1A8VLI.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8W5R<F5N=$5L96UE;G0@
M/2`G)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E:68@
M*'-T<FES='(H)&YA;64L("=E;&5M96YT)RDI('L*("`@("`@("`@("`@("`@
M(&EF("AC;W5N="@D=&AI<RT^<V-H96UA7V5L96UE;G1?<W1A8VLI*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/F-U<G)E;G1%;&5M96YT(#T@87)R
M87E?<&]P*"1T:&ES+3YS8VAE;6%?96QE;65N=%]S=&%C:RD["B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC
M=7)R96YT16QE;65N="`]("<G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@16QE;65N
M="!C;VYT96YT(&AA;F1L97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-H87)A
M8W1E<D1A=&$H)'!A<G-E<BP@)&1A=&$I"B`@("!["B`@("`@("`@+R\@4W1O
M<F4@=&AE(&1O8W5M96YT871I;VX@:6X@=&AE(%=31$P@9FEL92X*("`@("`@
M("!I9B`H)'1H:7,M/F-U<G)E;G1486<@/3T@)V1O8W5M96YT871I;VXG*2![
M"B`@("`@("`@("`@("1D871A(#T@=')I;2AP<F5G7W)E<&QA8V4H)R]<<RLO
M)RP@)R`G+"`D9&%T82DI.PH@("`@("`@("`@("!I9B`H(7-T<FQE;B@D9&%T
M82DI('L*("`@("`@("`@("`@("`@(')E='5R;CL*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@<W=I=&-H("@D=&AI<RT^<W1A='5S*2!["B`@("`@("`@
M("`@(&-A<V4@)W-E<G9I8V4G.@H@("`@("`@("`@("`@("`@)'!T<B`])B`D
M=&AI<RT^=W-D;"T^<V5R=FEC97-;)'1H:7,M/F-U<G)E;G1397)V:6-E73L*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G<&]R
M=%1Y<&4G.@H@("`@("`@("`@("`@("`@)'!T<B`])B`D=&AI<RT^=W-D;"T^
M<&]R=%1Y<&5S6R1T:&ES+3YC=7)R96YT4&]R=%1Y<&5=6R1T:&ES+3YC=7)R
M96YT3W!E<F%T:6]N73L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@8V%S92`G8FEN9&EN9R<Z"B`@("`@("`@("`@("`@("`D<'1R(#TF
M("1T:&ES+3YW<V1L+3YB:6YD:6YG<ULD=&AI<RT^8W5R<F5N=$)I;F1I;F==
M.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=M
M97-S86=E)SH*("`@("`@("`@("`@("`@("1P='(@/28@)'1H:7,M/G=S9&PM
M/FUE<W-A9V5S6R1T:&ES+3YC=7)R96YT365S<V%G95T["B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V]P97)A=&EO;B<Z"B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)W1Y<&5S
M)SH*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^8W5R<F5N=$-O
M;7!L97A4>7!E*2`F)@H@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1T:&ES
M+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U
M<G)E;G1#;VUP;&5X5'EP95TI*2!["B`@("`@("`@("`@("`@("`@("`@:68@
M*"1T:&ES+3YC=7)R96YT16QE;65N="D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D<'1R(#TF("1T:&ES+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M
M/G-C:&5M85U;)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP95U;)V5L96UE;G1S
M)UU;)'1H:7,M/F-U<G)E;G1%;&5M96YT73L*("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<'1R(#TF("1T
M:&ES+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M
M/F-U<G)E;G1#;VUP;&5X5'EP95T["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@(&EF("AI<W-E="@D<'1R*2D@>PH@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D<'1R6R=D;V-U;65N=&%T:6]N)UTI
M*2!["B`@("`@("`@("`@("`@("`@("`@)'!T<ELG9&]C=6UE;G1A=&EO;B==
M(#T@)R<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1P=');)V1O8W5M96YT871I;VXG72`N/2`G("<["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`D<'1R6R=D;V-U;65N=&%T:6]N
M)UT@+CT@)&1A=&$["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B`D<&%R<V5D(&ES(&%N(&%R<F%Y(')E='5R;F5D(&)Y
M('!A<G-E7W5R;"@I+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("HO"B`@("!F=6YC=&EO;B!M97)G955R;"@D<&%R<V5D+"`D<&%T:"D*
M("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P87)S960I*2!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1U<FD@
M/2`G)SL*("`@("`@("!I9B`H(65M<'1Y*"1P87)S961;)W-C:&5M92==*2D@
M>PH@("`@("`@("`@("`D<V5P(#T@*'-T<G1O;&]W97(H)'!A<G-E9%LG<V-H
M96UE)UTI(#T]("=M86EL=&\G(#\@)SHG(#H@)SHO+R<I.PH@("`@("`@("`@
M("`D=7)I(#T@)'!A<G-E9%LG<V-H96UE)UT@+B`D<V5P.PH@("`@("`@('T*
M"B`@("`@("`@:68@*&ES<V5T*"1P87)S961;)W!A<W,G72DI('L*("`@("`@
M("`@("`@)'5R:2`N/2`B)'!A<G-E9%MU<V5R73HD<&%R<V5D6W!A<W-=0"([
M"B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1P87)S961;)W5S97(G72DI('L*
M("`@("`@("`@("`@)'5R:2`N/2`B)'!A<G-E9%MU<V5R74`B.PH@("`@("`@
M('T*"B`@("`@("`@:68@*&ES<V5T*"1P87)S961;)VAO<W0G72DI('L*("`@
M("`@("`@("`@)'5R:2`N/2`D<&%R<V5D6R=H;W-T)UT["B`@("`@("`@?0H@
M("`@("`@(&EF("AI<W-E="@D<&%R<V5D6R=P;W)T)UTI*2!["B`@("`@("`@
M("`@("1U<FD@+CT@(CHD<&%R<V5D6W!O<G1=(CL*("`@("`@("!]"B`@("`@
M("`@:68@*"1P871H6S!=("$]("<O)R`F)B!I<W-E="@D<&%R<V5D6R=P871H
M)UTI*2!["B`@("`@("`@("`@(&EF("@D<&%R<V5D6R=P871H)UU;<W1R;&5N
M*"1P87)S961;)W!A=&@G72D@+2`Q72`A/2`G+R<I('L*("`@("`@("`@("`@
M("`@("1P871H(#T@9&ER;F%M92@D<&%R<V5D6R=P871H)UTI("X@)R\G("X@
M)'!A=&@["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M<&%T:"`]("1P87)S961;)W!A=&@G72`N("1P871H.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1P871H(#T@)'1H:7,M/E]N;W)M86QI>F4H)'!A=&@I
M.PH@("`@("`@('T*("`@("`@("`D<V5P(#T@)'!A=&A;,%T@/3T@)R\G(#\@
M)R<@.B`G+R<["B`@("`@("`@)'5R:2`N/2`D<V5P("X@)'!A=&@["@H@("`@
M("`@(')E='5R;B`D=7)I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]N;W)M86QI
M>F4H)'!A=&A?<W1R*0H@("`@>PH@("`@("`@("1P=V0@/2`G)SL*("`@("`@
M("`D<W1R07)R(#T@<')E9U]S<&QI="@G+RA<+RDO)RP@)'!A=&A?<W1R+"`M
M,2P@4%)%1U]34$Q)5%].3U]%35!462D["B`@("`@("`@)'!W9$%R<B`]("<G
M.PH@("`@("`@("1J(#T@,#L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C
M;W5N="@D<W1R07)R*3L@)&DK*RD@>PH@("`@("`@("`@("!I9B`H)'-T<D%R
M<ELD:5T@(3T@)R`N+B<I('L*("`@("`@("`@("`@("`@(&EF("@D<W1R07)R
M6R1I72`A/2`G("XG*2!["B`@("`@("`@("`@("`@("`@("`@)'!W9$%R<ELD
M:ET@/2`D<W1R07)R6R1I73L*("`@("`@("`@("`@("`@("`@("`D:BLK.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@87)R87E?<&]P*"1P=V1!<G(I.PH@("`@("`@("`@("`@("`@
M)&HM+3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D<%-T<B`]
M(&EM<&QO9&4H)R\G+"`D<'=D07)R*3L*("`@("`@("`D<'=D(#T@*'-T<FQE
M;B@D<%-T<BD@/B`P*2`_("@G+R<@+B`D<%-T<BD@.B`G+R<["B`@("`@("`@
M<F5T=7)N("1P=V0["B`@("!]"@I]"@HO*BH*("H@4&%R<V5S('1H92!T>7!E
M<R!A;F0@;65T:&]D<R!U<V5D(&EN('=E8B!S97)V:6-E(&]B:F5C=',@:6YT
M;R!T:&4@:6YT97)N86P*("H@9&%T82!S=')U8W1U<F5S('5S960@8GD@4T]!
M4%]74T1,+@H@*@H@*B!!<W-U;65S('1H92!33T%07U=31$P@8VQA<W,@:7,@
M=6YP;W!U;&%T960@=&\@<W1A<G0@=VET:"X*("H*("H@0&%U=&AO<B!#:')I
M<R!#;V4@/&EN9F]`:6YT96QL:6=E;G1S=')E86UI;F<N8V]M/@H@*B\*8VQA
M<W,@4T]!4%]74T1,7T]B:F5C=%!A<G-E<B!E>'1E;F1S(%-/05!?0F%S90I[
M"B`@("`O*BH*("`@("`J(%1A<F=E="!N86UE<W!A8V4@9F]R('1H92!74T1,
M(&1O8W5M96YT('=I;&P@:&%V92!T:&4@9F]L;&]W:6YG"B`@("`@*B!P<F5F
M:7@N"B`@("`@*B\*("`@('9A<B`D=&YS4')E9FEX(#T@)W1N<R<["@H@("`@
M+RHJ"B`@("`@*B!2969E<F5N8V4@=&\@=&AE(%-/05!?5U-$3"!O8FIE8W0@
M=&\@<&]P=6QA=&4N"B`@("`@*B\*("`@('9A<B`D=W-D;"`](&YU;&P["@H@
M("`@+RHJ($-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0'!A<F%M("`D;V)J
M96-T<R!2969E<F5N8V4@=&\@=&AE(&]B:F5C="!O<B!A<G)A>2!O9B!O8FIE
M8W1S('1O('!A<G-E"B`@("`@*B!`<&%R86T@("1W<V1L(%)E9F5R96YC92!T
M;R!T:&4@4T]!4%]74T1,(&]B:F5C="!T;R!P;W!U;&%T90H@("`@("H@0'!A
M<F%M("`D=&%R9V5T3F%M97-P86-E(%1H92!T87)G970@;F%M97-P86-E(&]F
M('-C:&5M82!T>7!E<R!E=&,N"B`@("`@*B!`<&%R86T@("1S97)V:6-E7VYA
M;64@3F%M92!O9B!T:&4@5U-$3"`\<V5R=FEC93X*("`@("`J($!P87)A;2`@
M)'-E<G9I8V5?9&5S8R!/<'1I;VYA;"!D97-C<FEP=&EO;B!O9B!T:&4@5U-$
M3"`\<V5R=FEC93X*("`@("`J+PH@("`@9G5N8W1I;VX@4T]!4%]74T1,7T]B
M:F5C=%!A<G-E<B@F)&]B:F5C=',L("8D=W-D;"P@)'1A<F=E=$YA;65S<&%C
M92P@)'-E<G9I8V5?;F%M92P@)'-E<G9I8V5?9&5S8R`]("<G*0H@("`@>PH@
M("`@("`@('!A<F5N=#HZ4T]!4%]"87-E*"=74T1,3T)*14-44$%24T52)RD[
M"@H@("`@("`@("1T:&ES+3YW<V1L(#T@)B1W<V1L.PH*("`@("`@("`O+R!3
M970@=7`@=&AE(%-/05!?5U-$3"!O8FIE8W0*("`@("`@("`D=&AI<RT^7VEN
M:71I86QI<V4H)'-E<G9I8V5?;F%M92D["@H@("`@("`@("\O(%!A<G-E(&5A
M8V@@=V5B('-E<G9I8V4@;V)J96-T"B`@("`@("`@)'=S9&Q?<F5F(#T@*&ES
M7V%R<F%Y*"1O8FIE8W1S*3\@)&]B:F5C=',@.B!A<G)A>2@F)&]B:F5C=',I
M*3L*"B`@("`@("`@9F]R96%C:"`H)'=S9&Q?<F5F(&%S("1R969?:71E;2D@
M>PH@("`@("`@("`@("!I9B`H(6ES7V]B:F5C="@D<F5F7VET96TI*0H@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)TEN
M=F%L:60@=V5B('-E<G9I8V4@;V)J96-T('!A<W-E9"!T;R!O8FIE8W0@<&%R
M<V5R)RP@)W5R;CHG("X@9V5T7V-L87-S*"1O8FIE8W0I*3L*"B`@("`@("`@
M("`@(&EF("@D=&AI<RT^7W!A<G-E*"1R969?:71E;2P@)'1A<F=E=$YA;65S
M<&%C92P@)'-E<G9I8V5?;F%M92D@(3T@=')U92D*("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@+R\@0G5I;&0@8FEN9&EN9W,@
M9G)O;2!A8G-T<F%C="!D871A+@H@("`@("`@(&EF("@D=&AI<RT^9F%U;'0@
M/3T@;G5L;"D@>PH@("`@("`@("`@("`D=&AI<RT^7V=E;F5R871E0FEN9&EN
M9W-!;F1397)V:6-E<R@D=&%R9V5T3F%M97-P86-E+"`D<V5R=FEC95]N86UE
M+"`D<V5R=FEC95]D97-C*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!);FET:6%L:7-E('1H92!33T%07U=31$P@=')E92`H9&5S=')U8W1I
M=F4I+@H@("`@("H*("`@("`J($EF('1H92!O8FIE8W0@:&%S(&%L<F5A9'D@
M8F5E;B!I;FET:6%L:7-E9"P@=&AE(&]N;'D@969F96-T"B`@("`@*B!W:6QL
M(&)E('1O(&-H86YG92!T:&4@=&YS(&YA;65S<&%C92!T;R!T:&4@;F5W('-E
M<G9I8V4@;F%M92X*("`@("`J"B`@("`@*B!`<&%R86T@("1S97)V:6-E7VYA
M;64@3F%M92!O9B!T:&4@5U-$3"`\<V5R=FEC93X*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?:6YI=&EA;&ES92@D<V5R
M=FEC95]N86UE*0H@("`@>PH@("`@("`@("\O(%-E="!U<"!T:&4@8F%S:6,@
M;F%M97-P86-E<R!T:&%T(&%L;"!74T1,(&1E9FEN:71I;VYS('5S92X*("`@
M("`@("`D=&AI<RT^=W-D;"T^;F%M97-P86-E<ULG=W-D;"==(#T@4T-(14U!
M7U=31$P[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!74T1,(&QA;F=U86=E"B`@("`@("`@)'1H:7,M/G=S9&PM/FYA;65S<&%C
M97-;)W-O87`G72`](%-#2$5-05]33T%0.R`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@5U-$3"!33T%0(&)I;F1I;F=S"B`@("`@
M("`@)'1H:7,M/G=S9&PM/FYA;65S<&%C97-;)'1H:7,M/G1N<U!R969I>%T@
M/2`G=7)N.B<@+B`D<V5R=FEC95]N86UE.R`@("`@("`@("`@("`@("`@+R\@
M5&%R9V5T(&YA;65S<&%C90H@("`@("`@("1T:&ES+3YW<V1L+3YN86UE<W!A
M8V5S6R=X<V0G72`](&%R<F%Y7W-E87)C:"@G>'-D)RP@)'1H:7,M/E]N86UE
M<W!A8V5S*3L@("`@("`@("`@("\O(%A-3"!38VAE;6$*("`@("`@("`D=&AI
M<RT^=W-D;"T^;F%M97-P86-E<ULG4T]!4"U%3D,G72`](&%R<F%Y7W-E87)C
M:"@G4T]!4"U%3D,G+"`D=&AI<RT^7VYA;65S<&%C97,I.R`O+R!33T%0('1Y
M<&5S"@H@("`@("`@("\O(%A86"!2969A8W1O<B`D;F%M97-P86-E+R1N<R!F
M;W(@4VAA;F4@.BTI"B`@("`@("`@=6YS970H)'1H:7,M/G=S9&PM/FYS6R=U
M<FXZ)R`N("1S97)V:6-E7VYA;65=*3L*("`@("`@("`D=&AI<RT^=W-D;"T^
M;G,@*ST@87)R87E?9FQI<"@D=&AI<RT^=W-D;"T^;F%M97-P86-E<RD["@H@
M("`@("`@("\O($EM<&]R=',@87)E(&YO="!I;7!L96UE;G1E9"!I;B!74T1,
M(&=E;F5R871I;VX@9G)O;2!C;&%S<V5S+@H@("`@("`@("\O("HJ*B`\=W-D
M;#II;7!O<G0^("HJ*@H@("`@?0H*("`@("\J*@H@("`@("H@4&%R<V5R("T@
M=&%K97,@82!S:6YG;&4@;V)J96-T('1O(&%D9"!T;R!T<F5E"B`@("`@*B`H
M;F]N+61E<W1R=6-T:79E*2X*("`@("`J"B`@("`@*B!`<&%R86T@("1O8FIE
M8W0@4F5F97)E;F-E('1O('1H92!O8FIE8W0@=&\@<&%R<V4*("`@("`J($!P
M87)A;2`@)'-E<G9I8V5?;F%M92!.86UE(&]F('1H92!74T1,(#QS97)V:6-E
M/@H@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@
M7W!A<G-E*"8D;V)J96-T+"`D<V-H96UA3F%M97-P86-E+"`D<V5R=FEC95]N
M86UE*0H@("`@>PH@("`@("`@("\O($-R96%T92!N86UE<W!A8V4@<')E9FEX
M(&9O<B!T:&4@<V-H96UA"B`@("`@("`@+R\@6%A8(&YO="!V97)Y(&5L96=A
M;G0@.BTH"@H@("`@("`@(&QI<W0H)'-C:%!R969I>"P@)&9O;RD@/2`D=&AI
M<RT^7V=E=%1Y<&5.<R@G>R<@+B`D<V-H96UA3F%M97-P86-E+B=])RD["B`@
M("`@("`@=6YS970H)&9O;RD["@H@("`@("`@("\O(%!A<G-E(&%L;"!T:&4@
M='EP97,@9&5F:6YE9"!B>2!T:&4@;V)J96-T(&EN('=H871E=F5R"B`@("`@
M("`@+R\@<V-H96UA(&QA;F=U86=E('=E(&%R92!U<VEN9R`H8W5R<F5N=&QY
M(%]?='EP961E9B!A<G)A>7,I"B`@("`@("`@+R\@*BHJ(#QW<V1L.G1Y<&5S
M/B`J*BH*"B`@("`@("`@9F]R96%C:"`H)&]B:F5C="T^7U]T>7!E9&5F(&%S
M("1T>7!E3F%M92`]/B`D='EP959A;'5E*2!["B`@("`@("`@("`@("\O($=E
M="]C<F5A=&4@;F%M97-P86-E(&1E9FEN:71I;VX*"B`@("`@("`@("`@(&QI
M<W0H)&YS4')E9FEX+"`D='EP94YA;64I(#T@)'1H:7,M/E]G9714>7!E3G,H
M)'1Y<&5.86UE*3L*"B`@("`@("`@("`@("\O($-R96%T92!T>7!E(&1E9FEN
M:71I;VX*"B`@("`@("`@("`@("1T:&ES+3YW<V1L+3YC;VUP;&5X5'EP97-;
M)'-C:%!R969I>%U;)'1Y<&5.86UE72`](&%R<F%Y*"=N86UE)R`]/B`D='EP
M94YA;64I.PH@("`@("`@("`@("`D=&AI<U1Y<&4@/28@)'1H:7,M/G=S9&PM
M/F-O;7!L97A4>7!E<ULD<V-H4')E9FEX75LD='EP94YA;65=.PH*("`@("`@
M("`@("`@+R\@06-C;W)D:6YG('1O($1M:71R:2=S(&1O8W5M96YT871I;VXL
M(%]?='EP961E9B!C;VUE<R!I;B!T=V\*("`@("`@("`@("`@+R\@9FQA=F]R
M<SH*("`@("`@("`@("`@+R\@07)R87D@/2!A<G)A>2AA<G)A>2@B:71E;2(@
M/3X@(G9A;'5E(BDI"B`@("`@("`@("`@("\O(%-T<G5C="`](&%R<F%Y*")I
M=&5M,2(@/3X@(G9A;'5E,2(L(")I=&5M,B(@/3X@(G9A;'5E,B(L("XN+BD*
M"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D='EP959A;'5E*2D@>PH@("`@
M("`@("`@("`@("`@<F5S970H)'1Y<&5686QU92D["B`@("`@("`@("`@("`@
M("!I9B`H:7-?87)R87DH8W5R<F5N="@D='EP959A;'5E*2D@)B8@8V]U;G0H
M)'1Y<&5686QU92D@/3T@,0H@("`@("`@("`@("`@("`@("`@("8F(&-O=6YT
M*&-U<G)E;G0H)'1Y<&5686QU92DI(#T](#$I('L*("`@("`@("`@("`@("`@
M("`@("`O+R!)="=S(&%N(&%R<F%Y"@H@("`@("`@("`@("`@("`@("`@("1T
M:&ES5'EP95LG='EP92==(#T@)T%R<F%Y)SL*("`@("`@("`@("`@("`@("`@
M("!R97-E="AC=7)R96YT*"1T>7!E5F%L=64I*3L*("`@("`@("`@("`@("`@
M("`@("!L:7-T*"1N<U!R969I>"P@)'1Y<&5.86UE*2`]("1T:&ES+3Y?9V5T
M5'EP94YS*&-U<G)E;G0H8W5R<F5N="@D='EP959A;'5E*2DI.PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES5'EP95LG;F%M97-P86-E)UT@/2`D;G-0<F5F
M:7@["B`@("`@("`@("`@("`@("`@("`@)'1H:7-4>7!E6R=A<G)A>51Y<&4G
M72`]("1T>7!E3F%M92`N("=;72<["B`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H(6ES7V%R<F%Y*&-U<G)E;G0H)'1Y<&5686QU92DI*2!["B`@("`@("`@
M("`@("`@("`@("`@+R\@270G<R!A('-T<G5C=`H*("`@("`@("`@("`@("`@
M("`@("`D=&AI<U1Y<&5;)W1Y<&4G72`]("=3=')U8W0G.PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES5'EP95LG;W)D97(G72`]("=A;&PG.PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES5'EP95LG;F%M97-P86-E)UT@/2`D;G-0<F5F
M:7@["B`@("`@("`@("`@("`@("`@("`@)'1H:7-4>7!E6R=E;&5M96YT<R==
M(#T@87)R87DH*3L*"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1Y
M<&5686QU92!A<R`D96QE;65N=$YA;64@/3X@)&5L96UE;G14>7!E*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@(&QI<W0H)&YS4')E9FEX+"`D='EP94YA
M;64I(#T@)'1H:7,M/E]G9714>7!E3G,H)&5L96UE;G14>7!E*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7-4>7!E6R=E;&5M96YT<R==6R1E;&5M
M96YT3F%M95U;)VYA;64G72`]("1E;&5M96YT3F%M93L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7-4>7!E6R=E;&5M96YT<R==6R1E;&5M96YT3F%M
M95U;)W1Y<&4G72`]("1T>7!E3F%M93L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7-4>7!E6R=E;&5M96YT<R==6R1E;&5M96YT3F%M95U;)VYA;65S
M<&%C92==(#T@)&YS4')E9FEX.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@+R\@
M270G<R!E<G)O;F5O=7,*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]R86ES95-O87!&875L="@B5&AE('1Y<&4@9&5F:6YI=&EO;B!F;W(@
M)&YS4')E9FEX.B1T>7!E3F%M92!I<R!I;G9A;&ED+B(L("=U<FXZ)R`N(&=E
M=%]C;&%S<R@D;V)J96-T*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O+R!)="=S(&5R<F]N96]U
M<PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U
M;'0H(E1H92!T>7!E(&1E9FEN:71I;VX@9F]R("1N<U!R969I>#HD='EP94YA
M;64@:7,@:6YV86QI9"XB+"`G=7)N.B<@+B!G971?8VQA<W,H)&]B:F5C="DI
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!#<F5A=&4@
M86X@96UP='D@96QE;65N="!A<G)A>2!W:71H('1H92!T87)G970@;F%M97-P
M86-E"B`@("`@("`@+R\@<')E9FEX+"!T;R!M871C:"!T:&4@<F5S=6QT<R!O
M9B!74T1,('!A<G-I;F<N"@H@("`@("`@("1T:&ES+3YW<V1L+3YE;&5M96YT
M<ULD<V-H4')E9FEX72`](&%R<F%Y*"D["@H@("`@("`@("\O(%!O<'5L871E
M('1R964@=VET:"!M97-S86=E(&EN9F]R;6%T:6]N"B`@("`@("`@+R\@*BHJ
M(#QW<V1L.FUE<W-A9V4^("HJ*@H*("`@("`@("!F;W)E86-H("@D;V)J96-T
M+3Y?7V1I<W!A=&-H7VUA<"!A<R`D;W!E<F%T:6]N3F%M92`]/B`D;65S<V%G
M97,I('L*("`@("`@("`@("`@9F]R96%C:"`H)&UE<W-A9V5S(&%S("1M97-S
M86=E5'EP92`]/B`D;65S<V%G95!A<G1S*2!["B`@("`@("`@("`@("`@("!U
M;G-E="@D=&AI<TUE<W-A9V4I.PH*("`@("`@("`@("`@("`@('-W:71C:"`H
M)&UE<W-A9V54>7!E*2!["B`@("`@("`@("`@("`@("!C87-E("=I;B<Z"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/FUE<W-A9V5S6R1O<&5R
M871I;VY.86UE("X@)U)E<75E<W0G72`](&%R<F%Y*"D["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7--97-S86=E(#TF("1T:&ES+3YW<V1L+3YM97-S86=E
M<ULD;W!E<F%T:6]N3F%M92`N("=297%U97-T)UT["B`@("`@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G;W5T)SH*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^;65S<V%G97-;)&]P97)A
M=&EO;DYA;64@+B`G4F5S<&]N<V4G72`](&%R<F%Y*"D["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7--97-S86=E(#TF("1T:&ES+3YW<V1L+3YM97-S86=E
M<ULD;W!E<F%T:6]N3F%M92`N("=297-P;VYS92==.PH@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)V%L:6%S)SH*
M("`@("`@("`@("`@("`@("`@("`O+R!$;R!N;W1H:6YG"B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@9&5F875L=#H*("`@
M("`@("`@("`@("`@("`@("`O+R!%<G)O<B!C;VYD:71I;VX*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)'1H:7--97-S86=E*2D@>PH@("`@("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1M97-S86=E4&%R=',@87,@)'!A<G1.86UE
M(#T^("1P87)T5'EP92D@>PH@("`@("`@("`@("`@("`@("`@("`@("!L:7-T
M("@D;G-0<F5F:7@L("1T>7!E3F%M92D@/2`D=&AI<RT^7V=E=%1Y<&5.<R@D
M<&%R=%1Y<&4I.PH*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7--97-S
M86=E6R1P87)T3F%M95T@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=N86UE)R`]/B`D<&%R=$YA;64L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G='EP92<@/3X@)'1Y<&5.86UE+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VYA;65S<&%C92<@/3X@)&YS4')E9FEX"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+R\@4&]P=6QA=&4@=')E92!W:71H('!O<G14>7!E(&EN9F]R
M;6%T:6]N"B`@("`@("`@+R\@6%A8($-U<G)E;G0@:6UP;&5M96YT871I;VX@
M;VYL>2!S=7!P;W)T<R!O;F4@<&]R=%1Y<&4@=&AA=`H@("`@("`@("\O(&5N
M8V]M<&%S<V5S(&%L;"!O9B!T:&4@;W!E<F%T:6]N<R!A=F%I;&%B;&4N"B`@
M("`@("`@+R\@*BHJ(#QW<V1L.G!O<G14>7!E/B`J*BH*"B`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^=W-D;"T^<&]R=%1Y<&5S6R1S97)V:6-E7VYA;64@
M+B`G4&]R="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^=W-D;"T^<&]R=%1Y
M<&5S6R1S97)V:6-E7VYA;64@+B`G4&]R="==(#T@87)R87DH*3L*("`@("`@
M("!]"B`@("`@("`@)'1H:7-0;W)T5'EP92`])B`D=&AI<RT^=W-D;"T^<&]R
M=%1Y<&5S6R1S97)V:6-E7VYA;64@+B`G4&]R="==.PH*("`@("`@("!F;W)E
M86-H("@D;V)J96-T+3Y?7V1I<W!A=&-H7VUA<"!A<R`D;W!E<F%T:6]N3F%M
M92`]/B`D;65S<V%G97,I('L*("`@("`@("`@("`@)'1H:7-0;W)T5'EP95LD
M;W!E<F%T:6]N3F%M95T@/2!A<G)A>2@G;F%M92<@/3X@)&]P97)A=&EO;DYA
M;64I.PH*("`@("`@("`@("`@9F]R96%C:"`H)&UE<W-A9V5S(&%S("1M97-S
M86=E5'EP92`]/B`D;65S<V%G95!A<G1S*2!["B`@("`@("`@("`@("`@("!S
M=VET8V@@*"1M97-S86=E5'EP92D@>PH@("`@("`@("`@("`@("`@8V%S92`G
M:6XG.@H@("`@("`@("`@("`@("`@("`@("1T:&ES4&]R=%1Y<&5;)&]P97)A
M=&EO;DYA;65=6R=I;G!U="==(#T@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@("`@("=M97-S86=E)R`]/B`D;W!E<F%T:6]N3F%M92`N("=297%U97-T
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@)VYA;65S<&%C92<@/3X@)'1H
M:7,M/G1N<U!R969I>"D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("`@("`@8V%S92`G;W5T)SH*("`@("`@("`@("`@("`@("`@
M("`D=&AI<U!O<G14>7!E6R1O<&5R871I;VY.86UE75LG;W5T<'5T)UT@/2!A
M<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)VUE<W-A9V4G(#T^("1O
M<&5R871I;VY.86UE("X@)U)E<W!O;G-E)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@)VYA;65S<&%C92<@/3X@)'1H:7,M/G1N<U!R969I>"D["B`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@5&%K92!A;&P@=&AE(&%B<W1R86-T(%=31$P@
M9&%T82!A;F0@8G5I;&0@8V]N8W)E=&4@8FEN9&EN9W,@86YD"B`@("`@*B!S
M97)V:6-E<R`H9&5S=')U8W1I=F4I+@H@("`@("H*("`@("`J(%A86"!#=7)R
M96YT(&EM<&QE;65N=&%T:6]N(&1I<V-A<F1S("1S97)V:6-E7V1E<V,N"B`@
M("`@*@H@("`@("H@0'!A<F%M("`D<V-H96UA3F%M97-P86-E($YA;65S<&%C
M92!F;W(@='EP97,@971C+@H@("`@("H@0'!A<F%M("`D<V5R=FEC95]N86UE
M($YA;64@;V8@=&AE(%=31$P@/'-E<G9I8V4^"B`@("`@*B!`<&%R86T@("1S
M97)V:6-E7V1E<V,@3W!T:6]N86P@9&5S8W)I<'1I;VX@;V8@=&AE(%=31$P@
M/'-E<G9I8V4^"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V=E;F5R871E0FEN9&EN9W-!;F1397)V:6-E<R@D<V-H96UA
M3F%M97-P86-E+"`D<V5R=FEC95]N86UE+"`D<V5R=FEC95]D97-C(#T@)R<I
M"B`@("!["B`@("`@("`@+R\@4&]P=6QA=&4@=')E92!W:71H(&)I;F1I;F=S
M(&EN9F]R;6%T:6]N"B`@("`@("`@+R\@6%A8($-U<G)E;G0@:6UP;&5M96YT
M871I;VX@;VYL>2!S=7!P;W)T<R!O;F4@8FEN9&EN9R!T:&%T"B`@("`@("`@
M+R\@;6%T8VAE<R!T:&4@<VEN9VQE('!O<G14>7!E(&%N9"!A;&P@;V8@:71S
M(&]P97)A=&EO;G,N"B`@("`@("`@+R\@6%A8($ES('1H:7,@=&AE(&-O<G)E
M8W0@=7-E(&]F("1S8VAE;6%.86UE<W!A8V4@:&5R93\*("`@("`@("`O+R`J
M*BH@/'=S9&PZ8FEN9&EN9SX@*BHJ"@H@("`@("`@("1T:&ES+3YW<V1L+3YB
M:6YD:6YG<ULD<V5R=FEC95]N86UE("X@)T)I;F1I;F<G72`](&%R<F%Y*`H@
M("`@("`@("`@("`@("`@)W1Y<&4G(#T^("1S97)V:6-E7VYA;64@+B`G4&]R
M="<L"B`@("`@("`@("`@("`@("`G;F%M97-P86-E)R`]/B`D=&AI<RT^=&YS
M4')E9FEX+`H@("`@("`@("`@("`@("`@)W-T>6QE)R`]/B`G<G!C)RP*("`@
M("`@("`@("`@("`@("=T<F%N<W!O<G0G(#T^(%-#2$5-05]33T%07TA45%`L
M"B`@("`@("`@("`@("`@("`G;W!E<F%T:6]N<R<@/3X@87)R87DH*2D["B`@
M("`@("`@)'1H:7-":6YD:6YG(#TF("1T:&ES+3YW<V1L+3YB:6YD:6YG<ULD
M<V5R=FEC95]N86UE("X@)T)I;F1I;F<G73L*"B`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/G=S9&PM/G!O<G14>7!E<ULD<V5R=FEC95]N86UE("X@)U!O<G0G
M72!A<R`D;W!E<F%T:6]N3F%M92`]/B`D;W!E<F%T:6]N1&%T82D@>PH@("`@
M("`@("`@("`D=&AI<T)I;F1I;F=;)V]P97)A=&EO;G,G75LD;W!E<F%T:6]N
M3F%M95T@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=S;V%P06-T:6]N)R`]
M/B`D<V-H96UA3F%M97-P86-E("X@)R,G("X@)&]P97)A=&EO;DYA;64L"B`@
M("`@("`@("`@("`@("`G<W1Y;&4G(#T^("1T:&ES0FEN9&EN9ULG<W1Y;&4G
M72D["@H@("`@("`@("`@("!F;W)E86-H("AA<G)A>2@G:6YP=70G+"`G;W5T
M<'5T)RD@87,@)&UE<W-A9V54>7!E*0H@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1O<&5R871I;VY$871A6R1M97-S86=E5'EP95TI*2!["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7-":6YD:6YG6R=O<&5R871I;VYS)UU;)&]P97)A
M=&EO;DYA;65=6R1M97-S86=E5'EP95T@/2!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=U<V4G(#T^("=E;F-O9&5D)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=N86UE<W!A8V4G(#T^("1S8VAE;6%.86UE
M<W!A8V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G96YC;V1I;F=3
M='EL92<@/3X@4T]!4%]30TA%34%?14Y#3T1)3D<I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@4&]P=6QA=&4@=')E92!W:71H
M('-E<G9I8V4@:6YF;W)M871I;VX*("`@("`@("`O+R!86%@@0W5R<F5N="!I
M;7!L96UE;G1A=&EO;B!S=7!P;W)T<R!O;F4@<V5R=FEC92!W:&EC:"!G<F]U
M<',*("`@("`@("`O+R!A;&P@;V8@=&AE('!O<G1S('1O9V5T:&5R+"!O;F4@
M<&]R="!P97(@8FEN9&EN9PH@("`@("`@("\O(%A86"!7:&%T(&%B;W5T(&AT
M='!S/PH@("`@("`@("\O("HJ*B`\=W-D;#IS97)V:6-E/B`J*BH*"B`@("`@
M("`@)'1H:7,M/G=S9&PM/G-E<G9I8V5S6R1S97)V:6-E7VYA;64@+B`G4V5R
M=FEC92==(#T@87)R87DH)W!O<G1S)R`]/B!A<G)A>2@I*3L*("`@("`@("`D
M=&AI<U-E<G9I8V4@/28@)'1H:7,M/G=S9&PM/G-E<G9I8V5S6R1S97)V:6-E
M7VYA;64@+B`G4V5R=FEC92==6R=P;W)T<R==.PH*("`@("`@("!F;W)E86-H
M("@D=&AI<RT^=W-D;"T^8FEN9&EN9W,@87,@)&)I;F1I;F=.86UE(#T^("1B
M:6YD:6YG1&%T82D@>PH@("`@("`@("`@("`D=&AI<U-E<G9I8V5;)&)I;F1I
M;F=$871A6R=T>7!E)UU=(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M)VYA;64G(#T^("1B:6YD:6YG1&%T85LG='EP92==+`H@("`@("`@("`@("`@
M("`@("`@("=B:6YD:6YG)R`]/B`D8FEN9&EN9TYA;64L"B`@("`@("`@("`@
M("`@("`@("`@)VYA;65S<&%C92<@/3X@)'1H:7,M/G1N<U!R969I>"P*("`@
M("`@("`@("`@("`@("`@("`G861D<F5S<R<@/3X@87)R87DH)VQO8V%T:6]N
M)R`]/@H@("`@("`@("`@("`@("`@("`@("`@("`G:'1T<#HO+R<@+B`D7U-%
M4E9%4ELG4T525D527TY!344G72`N("1?4T525D526R=02%!?4T5,1B==("X*
M("`@("`@("`@("`@("`@("`@("`@("`@*&ES<V5T*"1?4T525D526R=15452
M65]35%))3D<G72D@/R`G/R<@+B`D7U-%4E9%4ELG455%4EE?4U1224Y')UT@
M.B`G)RDI+`H@("`@("`@("`@("`@("`@("`@("=T>7!E)R`]/B`G<V]A<"<I
M.PH@("`@("`@('T*"B`@("`@("`@+R\@4V5T('-E<G9I8V4*("`@("`@("`D
M=&AI<RT^=W-D;"T^<V5T7W-E<G9I8V4H)'-E<G9I8V5?;F%M92`N("=397)V
M:6-E)RD["B`@("`@("`@)'1H:7,M/G=S9&PM/G5R:2`]("1T:&ES+3YW<V1L
M+3YN86UE<W!A8V5S6R1T:&ES+3YT;G-0<F5F:7A=.PH*("`@("`@("`O+R!#
M<F5A=&4@5U-$3"!D969I;FET:6]N"B`@("`@("`@+R\@*BHJ(#QW<V1L.F1E
M9FEN:71I;VYS/B`J*BH*"B`@("`@("`@)'1H:7,M/G=S9&PM/F1E9FEN:71I
M;VX@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=N86UE)R`]/B`D<V5R=FEC
M95]N86UE+`H@("`@("`@("`@("`@("`@)W1A<F=E=$YA;65S<&%C92<@/3X@
M)'1H:7,M/G=S9&PM/FYA;65S<&%C97-;)'1H:7,M/G1N<U!R969I>%TL"B`@
M("`@("`@("`@("`@("`G>&UL;G,G(#T^(%-#2$5-05]74T1,*3L*"B`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/G=S9&PM/FYA;65S<&%C97,@87,@)&YS4')E
M9FEX(#T^("1N86UE<W!A8V4I('L*("`@("`@("`@("`@)'1H:7,M/G=S9&PM
M/F1E9FEN:71I;VY;)WAM;&YS.B<@+B`D;G-0<F5F:7A=(#T@)&YA;65S<&%C
M93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&9U;F-T
M:6]N(&ES(&%D87!T960@9G)O;2!$;6ET<FD@5B=S(&EM<&QE;65N=&%T:6]N
M(&]F"B`@("`@*B!$25-#3R]74T1,(&=E;F5R871I;VXN($ET('-E<&%R871E
M<R!N86UE<W!A8V4@9G)O;2!T>7!E(&YA;64@:6X*("`@("`J(&$@7U]T>7!E
M9&5F(&ME>2!A;F0@8W)E871E<R!A(&YE=R!N86UE<W!A8V4@96YT<GD@:6X@
M=&AE(%=31$P*("`@("`J('-T<G5C='5R92!I9B!T:&4@;F%M97-P86-E(&AA
M<R!N;W0@8F5E;B!U<V5D(&)E9F]R92X@5&AE"B`@("`@*B!N86UE<W!A8V4@
M<')E9FEX(&%N9"!T>7!E(&YA;64@87)E(')E='5R;F5D+B!)9B!N;R!N86UE
M<W!A8V4@:7,*("`@("`J('-P96-I9FEE9"P@>'-D(&ES(&%S<W5M960N"B`@
M("`@*@H@("`@("H@5V4@=VEL;"!N;W0@;F5E9"!T:&ES(&9U;F-T:6]N(&%N
M>6UO<F4@;VYC92!?7W1Y<&5D968@:7,*("`@("`J(&5L:6UI;F%T960N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]G9714>7!E3G,H)'1Y<&4I"B`@("!["B`@
M("`@("`@<')E9U]M871C:%]A;&PH(B=<>R@N*BE<?2=S;2(L("1T>7!E+"`D
M;2D["B`@("`@("`@:68@*&ES<V5T*"1M6S%=6S!=*2`F)B`D;5LQ75LP72`A
M/2`G)RD@>PH@("`@("`@("`@("!I9B`H(6%R<F%Y7VME>5]E>&ES=',H)&U;
M,5U;,%TL("1T:&ES+3YW<V1L+3YN<RDI('L*("`@("`@("`@("`@("`@("1N
M<U]P<F5F(#T@)VYS)R`N(&-O=6YT*"1T:&ES+3YW<V1L+3YN86UE<W!A8V5S
M*3L*("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YN<ULD;5LQ75LP75T@
M/2`D;G-?<')E9CL*("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YN86UE
M<W!A8V5S6R1N<U]P<F5F72`]("1M6S%=6S!=.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1T>7!E;G,@/2`D=&AI<RT^=W-D;"T^;G-;)&U;,5U;,%U=
M.PH@("`@("`@("`@("`D='EP92`](&5R96=?<F5P;&%C92@D;5LP75LP72P@
M)R<L("1T>7!E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D='EP
M96YS(#T@)WAS9"<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@87)R87DH
M)'1Y<&5N<RP@)'1Y<&4I.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4WES=&5M+G!H<```
M````````````````````````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-#8W
M-C0`,3`U,34T,S,W-#,`,#(P-C(R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP#0HO*BH-"B`J($9I;&4O1&ER96-T
M;W)Y(&UA;FEP=6QA=&EO;@T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U
M#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T
M('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I
M<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE
M(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-
M"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@
M:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O
M(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM
M;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K
M86=E("`@(%-Y<W1E;0T*("H@0&%U=&AO<B`@("`@5&]M87,@5BY6+D-O>"`\
M8V]X0&ED96-N970N8V]M/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H
M92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I
M;VX@("`@0U93.B`D260Z(%-Y<W1E;2YP:'`L=B`Q+C4S(#(P,#8O,#$O,#8@
M,#0Z-#<Z,S8@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL
M92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*#0HO*BH-"B`J
M(&)A<V4@8VQA<W,-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+G!H<"<[#0IR
M97%U:7)E7V]N8V4@)T-O;G-O;&4O1V5T;W!T+G!H<"<[#0H-"B1'3$]"04Q3
M6R=?4WES=&5M7W1E;7!?9FEL97,G72`](&%R<F%Y*"D[#0H-"B\J*@T**B!3
M>7-T96T@;V9F97)S(&-R;W-S('!L871T9F]R;2!C;VUP871I8FQE('-Y<W1E
M;2!F=6YC=&EO;G,-"BH-"BH@4W1A=&EC(&9U;F-T:6]N<R!F;W(@9&EF9F5R
M96YT(&]P97)A=&EO;G,N(%-H;W5L9"!W;W)K('5N9&5R#0HJ(%5N:7@@86YD
M(%=I;F1O=W,N(%1H92!N86UE<R!A;F0@=7-A9V4@:&%S(&)E96X@=&%K96X@
M9G)O;2!I=',@<F5S<&5C=&EV96QY#0HJ($=.52!C;VUM86YD<RX@5&AE(&9U
M;F-T:6]N<R!W:6QL(')E='5R;B`H8F]O;"D@9F%L<V4@;VX@97)R;W(@86YD
M('=I;&P-"BH@=')I9V=E<B!T:&4@97)R;W(@=VET:"!T:&4@4$A0('1R:6=G
M97)?97)R;W(H*2!F=6YC=&EO;B`H>6]U(&-A;B!S:6QE;F-E#0HJ('1H92!E
M<G)O<B!B>2!P<F5F:7AI;F<@82`G0"<@<VEG;B!A9G1E<B!T:&4@9G5N8W1I
M;VX@8V%L;"DN#0HJ#0HJ($1O8W5M96YT871I;VX@;VX@=&AI<R!C;&%S<R!Y
M;W4@8V%N(&9I;F0@:6XZ#0HJ(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L
M+PT**@T**B!%>&%M<&QE('5S86=E.@T**B!I9B`H(4!3>7-T96TZ.G)M*"<M
M<B!F:6QE,2!D:7(Q)RDI('L-"BH@("`@<')I;G0@(F-O=6QD(&YO="!D96QE
M=&4@9FEL93$@;W(@9&ER,2([#0HJ('T-"BH-"BH@26X@8V%S92!Y;W4@;F5E
M9"!T;R!T;R!P87-S(&9I;&4@;F%M97,@=VET:"!S<&%C97,L#0HJ('!A<W,@
M=&AE('!A<F%M<R!A<R!A;B!A<G)A>3H-"BH-"BH@4WES=&5M.CIR;2AA<G)A
M>2@G+7(G+"`D9FEL93$L("1D:7(Q*2D[#0HJ#0HJ($!C871E9V]R>2`@('!E
M87(-"BH@0'!A8VMA9V4@("`@4WES=&5M#0HJ($!A=71H;W(@("`@(%1O;6%S
M(%8N5BX@0V]X(#QC;WA`:61E8VYE="YC;VT^#0HJ($!C;W!Y<FEG:'0@(#$Y
M.3<M,C`P-B!4:&4@4$A0($=R;W5P#0HJ($!L:6-E;G-E("`@(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*
M*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T**B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T**B!`<VEN8V4@("`@
M("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"BHO#0IC;&%S
M<R!3>7-T96T-"GL-"B`@("`O*BH-"B`@("`J(')E='5R;G,@=&AE(&-O;6UA
M;F1L:6YE(&%R9W5M96YT<R!O9B!A(&9U;F-T:6]N#0H@("`@*@T*("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@)&%R9W8@("`@("`@("`@('1H92!C;VUM86YD
M;&EN90T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)'-H;W)T7V]P=&EO;G,@
M('1H92!A;&QO=V5D(&]P=&EO;B!S:&]R="UT86=S#0H@("`@*B!`<&%R86T@
M("`@<W1R:6YG("`D;&]N9U]O<'1I;VYS("`@=&AE(&%L;&]W960@;W!T:6]N
M(&QO;F<M=&%G<PT*("`@("H@0')E='5R;B`@(&%R<F%Y("`@=&AE(&=I=F5N
M(&]P=&EO;G,@86YD('1H97)E('9A;'5E<PT*("`@("H@0&%C8V5S<R!P<FEV
M871E#0H@("`@*B\-"B`@("!F=6YC=&EO;B!?<&%R<V5!<F=S*"1A<F=V+"`D
M<VAO<G1?;W!T:6]N<RP@)&QO;F=?;W!T:6]N<R`](&YU;&PI#0H@("`@>PT*
M("`@("`@("!I9B`H(6ES7V%R<F%Y*"1A<F=V*2`F)B`D87)G=B`A/3T@;G5L
M;"D@>PT*("`@("`@("`@("`@)&%R9W8@/2!P<F5G7W-P;&ET*"<O7',K+R<L
M("1A<F=V+"`M,2P@4%)%1U]34$Q)5%].3U]%35!462D[#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N($-O;G-O;&5?1V5T;W!T.CIG971O<'0R*"1A<F=V
M+"`D<VAO<G1?;W!T:6]N<RD[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@*B!/
M=71P=70@97)R;W)S('=I=&@@4$A0('1R:6=G97)?97)R;W(H*2X@66]U(&-A
M;B!S:6QE;F-E('1H92!E<G)O<G,-"B`@("`J('=I=&@@<')E9FEX:6YG(&$@
M(D`B('-I9VX@=&\@=&AE(&9U;F-T:6]N(&-A;&PZ($!3>7-T96TZ.FUK9&ER
M*"XN*3L-"B`@("`J#0H@("`@*B!`<&%R86T@;6EX960@)&5R<F]R(&$@4$5!
M4B!E<G)O<B!O<B!A('-T<FEN9R!W:71H('1H92!E<G)O<B!M97-S86=E#0H@
M("`@*B!`<F5T=7)N(&)O;VP@9F%L<V4-"B`@("`J($!A8V-E<W,@<')I=F%T
M90T*("`@("HO#0H@("`@9G5N8W1I;VX@<F%I<V5%<G)O<B@D97)R;W(I#0H@
M("`@>PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(I*2![#0H@
M("`@("`@("`@("`D97)R;W(@/2`D97)R;W(M/F=E=$UE<W-A9V4H*3L-"B`@
M("`@("`@?0T*("`@("`@("!T<FEG9V5R7V5R<F]R*"1E<G)O<BP@15]54T52
M7U=!4DY)3D<I.PT*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@*B!#<F5A=&5S(&$@;F5S=&5D(&%R<F%Y(')E<')E<V5N
M=&EN9R!T:&4@<W1R=6-T=7)E(&]F(&$@9&ER96-T;W)Y#0H@("`@*@T*("`@
M("H@4WES=&5M.CI?9&ER5&]3=')U8W0H)V1I<C$G+"`P*2`]/@T*("`@("H@
M("!!<G)A>0T*("`@("H@("`@*`T*("`@("H@("`@6V1I<G-=(#T^($%R<F%Y
M#0H@("`@*B`@("`@("`@*`T*("`@("H@("`@("`@("`@("!;,%T@/3X@9&ER
M,0T*("`@("H@("`@("`@("D-"B`@("`J#0H@("`@*B`@("!;9FEL97-=(#T^
M($%R<F%Y#0H@("`@*B`@("`@("`@*`T*("`@("H@("`@("`@("`@("!;,%T@
M/3X@9&ER,2]F:6QE,@T*("`@("H@("`@("`@("`@("!;,5T@/3X@9&ER,2]F
M:6QE,PT*("`@("H@("`@("`@("D-"B`@("`J("`@("D-"B`@("`J($!P87)A
M;2`@("!S=')I;F<@("1S4&%T:"`@("`@($YA;64@;V8@=&AE(&1I<F5C=&]R
M>0T*("`@("H@0'!A<F%M("`@(&EN=&5G97(@)&UA>&EN<W0@("`@;6%X+B!D
M965P(&]F('1H92!L;V]K=7`-"B`@("`J($!P87)A;2`@("!I;G1E9V5R("1A
M:W1I;G-T("`@('-T87)T:6YG(&1E97`@;V8@=&AE(&QO;VMU<`T*("`@("H@
M0')E='5R;B`@(&%R<F%Y("`@=&AE('-T<G5C='5R92!O9B!T:&4@9&ER#0H@
M("`@*B!`86-C97-S("`@<')I=F%T90T*("`@("HO#0H-"B`@("!F=6YC=&EO
M;B!?9&ER5&]3=')U8W0H)'-0871H+"`D;6%X:6YS="P@)&%K=&EN<W0@/2`P
M*0T*("`@('L-"B`@("`@("`@)'-T<G5C="`](&%R<F%Y*"=D:7)S)R`]/B!A
M<G)A>2@I+"`G9FEL97,G(#T^(&%R<F%Y*"DI.PT*("`@("`@("!I9B`H*"1D
M:7(@/2!`;W!E;F1I<B@D<U!A=&@I*2`]/3T@9F%L<V4I('L-"B`@("`@("`@
M("`@(%-Y<W1E;3HZ<F%I<V5%<G)O<B@B0V]U;&0@;F]T(&]P96X@9&ER("1S
M4&%T:"(I.PT*("`@("`@("`@("`@<F5T=7)N("1S=')U8W0[("\O(%A86"!C
M;W5L9"!N;W0@;W!E;B!E<G)O<@T*("`@("`@("!]#0H@("`@("`@("1S=')U
M8W1;)V1I<G,G75M=(#T@)'-0871H(#T@<F5A;'!A=&@H)'-0871H*3L@+R\@
M6%A8(&1O;B=T(&%D9"!I9B`G+B<@;W(@)RXN)R`_#0H@("`@("`@("1L:7-T
M(#T@87)R87DH*3L-"B`@("`@("`@=VAI;&4@*&9A;'-E("$]/2`H)&9I;&4@
M/2!R96%D9&ER*"1D:7(I*2D@>PT*("`@("`@("`@("`@:68@*"1F:6QE("$]
M("<N)R`F)B`D9FEL92`A/2`G+BXG*2![#0H@("`@("`@("`@("`@("`@)&QI
M<W1;72`]("1F:6QE.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(&-L;W-E9&ER*"1D:7(I.PT*("`@("`@("!S;W)T*"1L:7-T*3L-"B`@
M("`@("`@:68@*"1A:W1I;G-T(#P@)&UA>&EN<W0@?'P@)&UA>&EN<W0@/3T@
M,"D@>PT*("`@("`@("`@("`@9F]R96%C:"@D;&ES="!A<R`D=F%L*2![#0H@
M("`@("`@("`@("`@("`@)'!A=&@@/2`D<U!A=&@@+B!$25)%0U1/4EE?4T50
M05)!5$]2("X@)'9A;#L-"B`@("`@("`@("`@("`@("!I9B`H:7-?9&ER*"1P
M871H*2`F)B`A:7-?;&EN:R@D<&%T:"DI('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1M<"`](%-Y<W1E;3HZ7V1I<E1O4W1R=6-T*"1P871H+"`D;6%X:6YS
M="P@)&%K=&EN<W0K,2D[#0H@("`@("`@("`@("`@("`@("`@("1S=')U8W0@
M/2!A<G)A>5]M97)G95]R96-U<G-I=F4H)'1M<"P@)'-T<G5C="D[#0H@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)'-T
M<G5C=%LG9FEL97,G75M=(#T@)'!A=&@[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<W1R
M=6-T.PT*("`@('T-"@T*("`@("\J*@T*("`@("H@0W)E871E<R!A(&YE<W1E
M9"!A<G)A>2!R97!R97-E;G1I;F<@=&AE('-T<G5C='5R92!O9B!A(&1I<F5C
M=&]R>2!A;F0@9FEL97,-"B`@("`J#0H@("`@*B!`<&%R86T@("`@87)R87D@
M)&9I;&5S($%R<F%Y(&QI<W1I;F<@9FEL97,@86YD(&1I<G,-"B`@("`J($!R
M971U<FX@("!A<G)A>0T*("`@("H@0'-E92!3>7-T96TZ.E]D:7)4;U-T<G5C
M="@I#0H@("`@*B\-"B`@("!F=6YC=&EO;B!?;75L=&EP;&54;U-T<G5C="@D
M9FEL97,I#0H@("`@>PT*("`@("`@("`D<W1R=6-T(#T@87)R87DH)V1I<G,G
M(#T^(&%R<F%Y*"DL("=F:6QE<R<@/3X@87)R87DH*2D[#0H@("`@("`@('-E
M='1Y<&4H)&9I;&5S+"`G87)R87DG*3L-"B`@("`@("`@9F]R96%C:"`H)&9I
M;&5S(&%S("1F:6QE*2![#0H@("`@("`@("`@("!I9B`H:7-?9&ER*"1F:6QE
M*2`F)B`A:7-?;&EN:R@D9FEL92DI('L-"B`@("`@("`@("`@("`@("`D=&UP
M(#T@4WES=&5M.CI?9&ER5&]3=')U8W0H)&9I;&4L(#`I.PT*("`@("`@("`@
M("`@("`@("1S=')U8W0@/2!A<G)A>5]M97)G95]R96-U<G-I=F4H)'1M<"P@
M)'-T<G5C="D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("1S=')U8W1;)V9I;&5S)UU;72`]("1F:6QE.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<W1R=6-T.PT*("`@('T-
M"@T*("`@("\J*@T*("`@("H@5&AE(')M(&-O;6UA;F0@9F]R(')E;6]V:6YG
M(&9I;&5S+@T*("`@("H@4W5P<&]R=',@;75L=&EP;&4@9FEL97,@86YD(&1I
M<G,@86YD(&%L<V\@<F5C=7)S:79E(&1E;&5T97,-"B`@("`J#0H@("`@*B!`
M<&%R86T@("`@<W1R:6YG("`D87)G<R`@('1H92!A<F=U;65N=',@9F]R(')M
M#0H@("`@*B!`<F5T=7)N("`@;6EX960@("!014%27T5R<F]R(&]R('1R=64@
M9F]R('-U8V-E<W,-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@("`J+PT*
M("`@(&9U;F-T:6]N(')M*"1A<F=S*0T*("`@('L-"B`@("`@("`@)&]P=',@
M/2!3>7-T96TZ.E]P87)S94%R9W,H)&%R9W,L("=R9B<I.R`O+R`B9B(@9&\@
M;F]T:&EN9R!B=70@;&EK92!I="`Z+2D-"B`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)&]P=',I*2![#0H@("`@("`@("`@("!R971U<FX@4WES=&5M.CIR
M86ES945R<F]R*"1O<'1S*3L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H
M*"1O<'1S6S!=(&%S("1O<'0I('L-"B`@("`@("`@("`@(&EF("@D;W!T6S!=
M(#T]("=R)RD@>PT*("`@("`@("`@("`@("`@("1D;U]R96-U<G-I=F4@/2!T
M<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1R970@
M/2!T<G5E.PT*("`@("`@("!I9B`H:7-S970H)&1O7W)E8W5R<VEV92DI('L-
M"B`@("`@("`@("`@("1S=')U8W0@/2!3>7-T96TZ.E]M=6QT:7!L951O4W1R
M=6-T*"1O<'1S6S%=*3L-"B`@("`@("`@("`@(&9O<F5A8V@H)'-T<G5C=%LG
M9FEL97,G72!A<R`D9FEL92D@>PT*("`@("`@("`@("`@("`@(&EF("@A0'5N
M;&EN:R@D9FEL92DI('L-"B`@("`@("`@("`@("`@("`@("`@)')E="`](&9A
M;'-E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&9O<F5A8V@H)'-T<G5C=%LG9&ER<R==(&%S("1D:7(I('L-"B`@
M("`@("`@("`@("`@("!I9B`H(4!R;61I<B@D9&ER*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D<F5T(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M9F]R96%C:"`H)&]P='-;,5T@87,@)&9I;&4I('L-"B`@("`@("`@("`@("`@
M("`D9&5L971E(#T@*&ES7V1I<B@D9FEL92DI(#\@)W)M9&ER)R`Z("=U;FQI
M;FLG.PT*("`@("`@("`@("`@("`@(&EF("@A0"1D96QE=&4H)&9I;&4I*2![
M#0H@("`@("`@("`@("`@("`@("`@("1R970@/2!F86QS93L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@*B!-86ME(&1I
M<F5C=&]R:65S+@T*("`@("H-"B`@("`J(%1H92`M<"!O<'1I;VX@=VEL;"!C
M<F5A=&4@<&%R96YT(&1I<F5C=&]R:65S#0H@("`@*B!`<&%R86T@("`@<W1R
M:6YG("`D87)G<R`@("!T:&4@;F%M92!O9B!T:&4@9&ER96-T;W(H>7QI97,I
M('1O(&-R96%T90T*("`@("H@0')E='5R;B`@(&)O;VP@("`@5')U92!F;W(@
M<W5C8V5S<PT*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("HO#0H@("`@
M9G5N8W1I;VX@;6M$:7(H)&%R9W,I#0H@("`@>PT*("`@("`@("`D;W!T<R`]
M(%-Y<W1E;3HZ7W!A<G-E07)G<R@D87)G<RP@)W!M.B<I.PT*("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D;W!T<RDI('L-"B`@("`@("`@("`@(')E='5R
M;B!3>7-T96TZ.G)A:7-E17)R;W(H)&]P=',I.PT*("`@("`@("!]#0H@("`@
M("`@("1M;V1E(#T@,#<W-SL@+R\@9&5F875L="!M;V1E#0H@("`@("`@(&9O
M<F5A8V@H)&]P='-;,%T@87,@)&]P="D@>PT*("`@("`@("`@("`@:68@*"1O
M<'1;,%T@/3T@)W`G*2![#0H@("`@("`@("`@("`@("`@)&-R96%T95]P87)E
M;G1S(#T@=')U93L-"B`@("`@("`@("`@('T@96QS96EF*"1O<'1;,%T@/3T@
M)VTG*2![#0H@("`@("`@("`@("`@("`@+R\@:68@=&AE(&UO9&4@:7,@8VQE
M87)L>2!A;B!O8W1A;"!N=6UB97(@*'-T87)T<R!W:71H(#`I#0H@("`@("`@
M("`@("`@("`@+R\@8V]N=F5R="!I="!T;R!D96-I;6%L#0H@("`@("`@("`@
M("`@("`@:68@*'-T<FQE;B@D;W!T6S%=*2`F)B`D;W!T6S%=>S!](#T]("<P
M)RD@>PT*("`@("`@("`@("`@("`@("`@("`D;W!T6S%=(#T@;V-T9&5C*"1O
M<'1;,5TI.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@("\O(&-O;G9E<G0@=&\@:6YT#0H@("`@("`@("`@("`@("`@
M("`@("1O<'1;,5T@*ST@,#L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@)&UO9&4@/2`D;W!T6S%=.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@("1R970@/2!T<G5E.PT*("`@("`@("!I9B`H:7-S
M970H)&-R96%T95]P87)E;G1S*2D@>PT*("`@("`@("`@("`@9F]R96%C:"@D
M;W!T<ULQ72!A<R`D9&ER*2![#0H@("`@("`@("`@("`@("`@)&1I<G-T86-K
M(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("!W:&EL92`H(4!I<U]D:7(H
M)&1I<BD@)B8@)&1I<B`A/2!$25)%0U1/4EE?4T5005)!5$]2*2![#0H@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y7W5N<VAI9G0H)&1I<G-T86-K+"`D9&ER
M*3L-"B`@("`@("`@("`@("`@("`@("`@)&1I<B`](&1I<FYA;64H)&1I<BD[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('=H:6QE("@D
M;F5W9&ER(#T@87)R87E?<VAI9G0H)&1I<G-T86-K*2D@>PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H(6ES7W=R:71E86)L92AD:7)N86UE*"1N97=D:7(I
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E="`](&9A;'-E.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"%M:V1I<B@D;F5W
M9&ER+"`D;6]D92DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R970@
M/2!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@(&9O<F5A8V@H)&]P='-;,5T@87,@)&1I<BD@>PT*("`@("`@("`@
M("`@("`@(&EF("@A0&ES7V1I<B@D9&ER*2`F)B`A;6MD:7(H)&1I<BP@)&UO
M9&4I*2![#0H@("`@("`@("`@("`@("`@("`@("1R970@/2!F86QS93L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@*B!#
M;VYC871E;F%T92!F:6QE<PT*("`@("H-"B`@("`J(%5S86=E.@T*("`@("H@
M,2D@)'9A<B`](%-Y<W1E;3HZ8V%T*"=S86UP;&4N='AT('1E<W0N='AT)RD[
M#0H@("`@*B`R*2!3>7-T96TZ.F-A="@G<V%M<&QE+G1X="!T97-T+G1X="`^
M(&9I;F%L+G1X="<I.PT*("`@("H@,RD@4WES=&5M.CIC870H)W-A;7!L92YT
M>'0@=&5S="YT>'0@/CX@9FEN86PN='AT)RD[#0H@("`@*@T*("`@("H@3F]T
M93H@87,@=&AE(&-L87-S('5S92!F;W!E;BP@=7)L<R!S:&]U;&0@=V]R:R!A
M;'-O("AT97-T('1H870I#0H@("`@*@T*("`@("H@0'!A<F%M("`@('-T<FEN
M9R`@)&%R9W,@("!T:&4@87)G=6UE;G1S#0H@("`@*B!`<F5T=7)N("`@8F]O
M;&5A;B!T<G5E(&]N('-U8V-E<W,-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-
M"B`@("`J+PT*("`@(&9U;F-T:6]N("9C870H)&%R9W,I#0H@("`@>PT*("`@
M("`@("`D<F5T(#T@;G5L;#L-"B`@("`@("`@)&9I;&5S(#T@87)R87DH*3L-
M"B`@("`@("`@:68@*"%I<U]A<G)A>2@D87)G<RDI('L-"B`@("`@("`@("`@
M("1A<F=S(#T@<')E9U]S<&QI="@G+UQS*R\G+"`D87)G<RP@+3$L(%!214=?
M4U!,251?3D]?14U05%DI.PT*("`@("`@("!]#0H@("`@("`@(&9O<B@D:3TP
M.R`D:2`\(&-O=6YT*"1A<F=S*3L@)&DK*RD@>PT*("`@("`@("`@("`@:68@
M*"1A<F=S6R1I72`]/2`G/B<I('L-"B`@("`@("`@("`@("`@("`D;6]D92`]
M("=W8B<[#0H@("`@("`@("`@("`@("`@)&]U='!U=&9I;&4@/2`D87)G<ULD
M:2LQ73L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@('T@
M96QS96EF("@D87)G<ULD:5T@/3T@)SX^)RD@>PT*("`@("`@("`@("`@("`@
M("1M;V1E(#T@)V%B*R<[#0H@("`@("`@("`@("`@("`@)&]U='!U=&9I;&4@
M/2`D87)G<ULD:2LQ73L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&9I;&5S6UT@/2`D
M87)G<ULD:5T[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES<V5T*"1M;V1E*2D@>PT*("`@("`@("`@("`@:68@*"$D;W5T<'5T
M9F0@/2!F;W!E;B@D;W5T<'5T9FEL92P@)&UO9&4I*2![#0H@("`@("`@("`@
M("`@("`@)&5R<B`](%-Y<W1E;3HZ<F%I<V5%<G)O<B@B0V]U;&0@;F]T(&]P
M96X@)&]U='!U=&9I;&4B*3L-"B`@("`@("`@("`@("`@("!R971U<FX@)&5R
M<CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1R970@/2!T<G5E.PT*
M("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1F:6QE<R!A<R`D9FEL92D@
M>PT*("`@("`@("`@("`@:68@*"$D9F0@/2!F;W!E;B@D9FEL92P@)W(G*2D@
M>PT*("`@("`@("`@("`@("`@(%-Y<W1E;3HZ<F%I<V5%<G)O<B@B0V]U;&0@
M;F]T(&]P96X@)&9I;&4B*3L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@('=H:6QE("@D8V]N="`](&9R
M96%D*"1F9"P@,C`T."DI('L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)&]U='!U=&9D*2D@>PT*("`@("`@("`@("`@("`@("`@("!F=W)I=&4H)&]U
M='!U=&9D+"`D8V]N="D[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@)')E="`N/2`D8V]N=#L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F8VQO<V4H)&9D
M*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H0&ES7W)E<V]U<F-E*"1O=71P
M=71F9"DI('L-"B`@("`@("`@("`@(&9C;&]S92@D;W5T<'5T9F0I.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("H@0W)E871E<R!T96UP;W)A<GD@9FEL97,@;W(@9&ER96-T;W)I
M97,N(%1H:7,@9G5N8W1I;VX@=VEL;"!R96UO=F4-"B`@("`J('1H92!C<F5A
M=&5D(&9I;&5S('=H96X@=&AE('-C<FEP=',@9FEN:7-H(&ET<R!E>&5C=71I
M;VXN#0H@("`@*@T*("`@("H@57-A9V4Z#0H@("`@*B`@(#$I("1T96UP9FEL
M92`](%-Y<W1E;3HZ;6MT96UP*")P<F5F:7@B*3L-"B`@("`J("`@,BD@)'1E
M;7!D:7(@(#T@4WES=&5M.CIM:W1E;7`H(BUD('!R969I>"(I.PT*("`@("H@
M("`S*2`D=&5M<&9I;&4@/2!3>7-T96TZ.FUK=&5M<"@I.PT*("`@("H@("`T
M*2`D=&5M<&9I;&4@/2!3>7-T96TZ.FUK=&5M<"@B+70@+W9A<B]T;7`@<')E
M9FEX(BD[#0H@("`@*@T*("`@("H@<')E9FEX("T^(%1H92!S=')I;F<@=&AA
M="!W:6QL(&)E('!R97!E;F1E9"!T;R!T:&4@=&5M<"!N86UE#0H@("`@*B`@
M("`@("`@("`@*&1E9F%U;'1S('1O(")T;7`B*2X-"B`@("`J("UD("`@("`M
M/B!!('1E;7!O<F%R>2!D:7(@=VEL;"!B92!C<F5A=&5D(&EN<W1E860@;V8@
M82!F:6QE+@T*("`@("H@+70@("`@("T^(%1H92!T87)G970@9&ER('=H97)E
M('1H92!T96UP;W)A<GD@*&9I;&5\9&ER*2!W:6QL(&)E(&-R96%T960N($EF
M#0H@("`@*B`@("`@("`@("`@=&AI<R!P87)A;2!I<R!M:7-S:6YG(&)Y(&1E
M9F%U;'0@=&AE(&5N=B!V87)S(%1-4"!O;B!7:6YD;W=S(&]R#0H@("`@*B`@
M("`@("`@("`@5$U01$E2(&EN(%5N:7@@=VEL;"!B92!U<V5D+B!)9B!T:&5S
M92!V87)S(&%R92!A;'-O(&UI<W-I;F<-"B`@("`J("`@("`@("`@("!C.EQW
M:6YD;W=S7'1E;7`@;W(@+W1M<"!W:6QL(&)E('5S960N#0H@("`@*@T*("`@
M("H@0'!A<F%M("`@<W1R:6YG("`D87)G<R`@5&AE(&%R9W5M96YT<PT*("`@
M("H@0')E='5R;B`@;6EX960@("!T:&4@9G5L;"!P871H(&]F('1H92!C<F5A
M=&5D("AF:6QE?&1I<BD@;W(@9F%L<V4-"B`@("`J($!S964@4WES=&5M.CIT
M;7!D:7(H*0T*("`@("H@0&%C8V5S<R`@<'5B;&EC#0H@("`@*B\-"B`@("!F
M=6YC=&EO;B!M:W1E;7`H)&%R9W,@/2!N=6QL*0T*("`@('L-"B`@("`@("`@
M<W1A=&EC("1F:7)S=%]T:6UE(#T@=')U93L-"B`@("`@("`@)&]P=',@/2!3
M>7-T96TZ.E]P87)S94%R9W,H)&%R9W,L("=T.F0G*3L-"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&]P=',I*2![#0H@("`@("`@("`@("!R971U<FX@
M4WES=&5M.CIR86ES945R<F]R*"1O<'1S*3L-"B`@("`@("`@?0T*("`@("`@
M("!F;W)E86-H*"1O<'1S6S!=(&%S("1O<'0I('L-"B`@("`@("`@("`@(&EF
M*"1O<'1;,%T@/3T@)V0G*2![#0H@("`@("`@("`@("`@("`@)'1M<%]I<U]D
M:7(@/2!T<G5E.PT*("`@("`@("`@("`@?2!E;'-E:68H)&]P=%LP72`]/2`G
M="<I('L-"B`@("`@("`@("`@("`@("`D=&UP9&ER(#T@)&]P=%LQ73L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D<')E9FEX(#T@*&ES
M<V5T*"1O<'1S6S%=6S!=*2D@/R`D;W!T<ULQ75LP72`Z("=T;7`G.PT*("`@
M("`@("!I9B`H(6ES<V5T*"1T;7!D:7(I*2![#0H@("`@("`@("`@("`D=&UP
M9&ER(#T@4WES=&5M.CIT;7!D:7(H*3L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H(5-Y<W1E;3HZ;6M$:7(H87)R87DH)RUP)RP@)'1M<&1I<BDI*2![#0H@
M("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@
M)'1M<"`]('1E;7!N86TH)'1M<&1I<BP@)'!R969I>"D[#0H@("`@("`@(&EF
M("AI<W-E="@D=&UP7VES7V1I<BDI('L-"B`@("`@("`@("`@('5N;&EN:R@D
M=&UP*3L@+R\@8F4@8V%R969U;"!P;W-S:6)L92!R86-E(&-O;F1I=&EO;B!H
M97)E#0H@("`@("`@("`@("!I9B`H(6UK9&ER*"1T;7`L(#`W,#`I*2![#0H@
M("`@("`@("`@("`@("`@<F5T=7)N(%-Y<W1E;3HZ<F%I<V5%<G)O<B@B56YA
M8FQE('1O(&-R96%T92!T96UP;W)A<GD@9&ER96-T;W)Y("1T;7!D:7(B*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D1TQ/0D%,4ULG
M7U-Y<W1E;5]T96UP7V9I;&5S)UU;72`]("1T;7`[#0H@("`@("`@(&EF("@D
M9FER<W1?=&EM92D@>PT*("`@("`@("`@("`@4$5!4CHZ<F5G:7-T97)3:'5T
M9&]W;D9U;F,H87)R87DH)U-Y<W1E;2<L("=?<F5M;W9E5&UP1FEL97,G*2D[
M#0H@("`@("`@("`@("`D9FER<W1?=&EM92`](&9A;'-E.PT*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B`D=&UP.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("H@4F5M;W9E('1E;7!O<F%R>2!F:6QE<R!C<F5A=&5D(&UY(&UK5&5M<"X@
M5&AI<R!F=6YC=&EO;B!I<R!E>&5C=71E9`T*("`@("H@870@<V-R:7!T('-H
M=71D;W=N('1I;64-"B`@("`J#0H@("`@*B!`86-C97-S('!R:79A=&4-"B`@
M("`J+PT*("`@(&9U;F-T:6]N(%]R96UO=F54;7!&:6QE<R@I#0H@("`@>PT*
M("`@("`@("!I9B`H8V]U;G0H)$=,3T)!3%-;)U]3>7-T96U?=&5M<%]F:6QE
M<R==*2D@>PT*("`@("`@("`@("`@)&1E;&5T92`]("1'3$]"04Q36R=?4WES
M=&5M7W1E;7!?9FEL97,G73L-"B`@("`@("`@("`@(&%R<F%Y7W5N<VAI9G0H
M)&1E;&5T92P@)RUR)RD[#0H@("`@("`@("`@("!3>7-T96TZ.G)M*"1D96QE
M=&4I.PT*("`@("`@("`@("`@)$=,3T)!3%-;)U]3>7-T96U?=&5M<%]F:6QE
M<R==(#T@87)R87DH*3L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*
M("`@("H@1V5T('1H92!P871H(&]F('1H92!T96UP;W)A;"!D:7)E8W1O<GD@
M<V5T(&EN('1H92!S>7-T96T-"B`@("`J(&)Y(&QO;VMI;F<@:6X@:71S(&5N
M=FER;VYM96YT<R!V87)I86)L97,N#0H@("`@*B!.;W1E.B!P:'`N:6YI+7)E
M8V]M;65N9&5D(')E;6]V97,@=&AE(")%(B!F<F]M('1H92!V87)I86)L97-?
M;W)D97(@<V5T=&EN9RP-"B`@("`J(&UA:VEN9R!U;F%V86EB;&4@=&AE("1?
M14Y6(&%R<F%Y+"!T:&%T(',@=VAY('=E(&1O('1E<W1S('=I=&@@7T5.5@T*
M("`@("H-"B`@("`J($!R971U<FX@<W1R:6YG(%1H92!T96UP;W)A;"!D:7)E
M8W1O<GD@;VX@=&AE('-Y<W1E;0T*("`@("HO#0H@("`@9G5N8W1I;VX@=&UP
M9&ER*"D-"B`@("![#0H@("`@("`@(&EF("A/4U]724Y$3U=3*2![#0H@("`@
M("`@("`@("!I9B`H)'9A<B`](&ES<V5T*"1?14Y66R=414U0)UTI(#\@)%]%
M3E9;)U1%35`G72`Z(&=E=&5N=B@G5$5-4"<I*2![#0H@("`@("`@("`@("`@
M("`@<F5T=7)N("1V87([#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H)'9A<B`](&ES<V5T*"1?14Y66R=435`G72D@/R`D7T5.5ELG5$U0)UT@
M.B!G971E;G8H)U1-4"<I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1V
M87([#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)'9A<B`](&ES
M<V5T*"1?14Y66R=W:6YD:7(G72D@/R`D7T5.5ELG=VEN9&ER)UT@.B!G971E
M;G8H)W=I;F1I<B<I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1V87([
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@9V5T96YV*"=3
M>7-T96U2;V]T)RD@+B`G7'1E;7`G.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("@D=F%R(#T@:7-S970H)%]%3E9;)U1-4$1)4B==*2`_("1?14Y66R=435!$
M25(G72`Z(&=E=&5N=B@G5$U01$E2)RDI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=F%R.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`G+W1M<"<[#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@*B!4:&4@(G=H:6-H(B!C;VUM86YD("AS
M:&]W('1H92!F=6QL('!A=&@@;V8@82!C;VUM86YD*0T*("`@("H-"B`@("`J
M($!P87)A;2!S=')I;F<@)'!R;V=R86T@5&AE(&-O;6UA;F0@=&\@<V5A<F-H
M(&9O<@T*("`@("H@0'!A<F%M(&UI>&5D("`D9F%L;&)A8VL@5F%L=64@=&\@
M<F5T=7)N(&EF("1P<F]G<F%M(&ES(&YO="!F;W5N9`T*("`@("H-"B`@("`J
M($!R971U<FX@;6EX960@02!S=')I;F<@=VET:"!T:&4@9G5L;"!P871H(&]R
M(&9A;'-E(&EF(&YO="!F;W5N9`T*("`@("H@0&%U=&AO<B!3=&EG($)A:VME
M;B`\<W-B0'!H<"YN970^#0H@("`@*B\-"B`@("!F=6YC=&EO;B!W:&EC:"@D
M<')O9W)A;2P@)&9A;&QB86-K(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`O
M+R!E;F9O<F-E($%020T*("`@("`@("!I9B`H(6ES7W-T<FEN9R@D<')O9W)A
M;2D@?'P@)R<@/3T@)'!R;V=R86TI('L-"B`@("`@("`@("`@(')E='5R;B`D
M9F%L;&)A8VL[#0H@("`@("`@('T-"@T*("`@("`@("`O+R!A=F%I;&%B;&4@
M<VEN8V4@-"XS+C!20S(-"B`@("`@("`@:68@*&1E9FEN960H)U!!5$A?4T50
M05)!5$]2)RDI('L-"B`@("`@("`@("`@("1P871H7V1E;&EM(#T@4$%42%]3
M15!!4D%43U([#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D<&%T
M:%]D96QI;2`]($]37U=)3D1/5U,@/R`G.R<@.B`G.B<[#0H@("`@("`@('T-
M"B`@("`@("`@+R\@9G5L;"!P871H(&=I=F5N#0H@("`@("`@(&EF("AB87-E
M;F%M92@D<')O9W)A;2D@(3T@)'!R;V=R86TI('L-"B`@("`@("`@("`@("1P
M871H7V5L96UE;G1S6UT@/2!D:7)N86UE*"1P<F]G<F%M*3L-"B`@("`@("`@
M("`@("1P<F]G<F%M(#T@8F%S96YA;64H)'!R;V=R86TI.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@+R\@2&]N;W(@<V%F92!M;V1E#0H@("`@
M("`@("`@("!I9B`H(6EN:5]G970H)W-A9F5?;6]D92<I('Q\("$D<&%T:"`]
M(&EN:5]G970H)W-A9F5?;6]D95]E>&5C7V1I<B<I*2![#0H@("`@("`@("`@
M("`@("`@)'!A=&@@/2!G971E;G8H)U!!5$@G*3L-"B`@("`@("`@("`@("`@
M("!I9B`H(21P871H*2![#0H@("`@("`@("`@("`@("`@("`@("1P871H(#T@
M9V5T96YV*"=0871H)RD[("\O('-O;64@3U-E<R!A<F4@:G5S="!S='5P:60@
M96YO=6=H('1O(&1O('1H:7,-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`D<&%T:%]E;&5M96YT<R`](&5X<&QO9&4H
M)'!A=&A?9&5L:6TL("1P871H*3L-"B`@("`@("`@?0T*#0H@("`@("`@(&EF
M("A/4U]724Y$3U=3*2![#0H@("`@("`@("`@("`D97AE7W-U9F9I>&5S(#T@
M9V5T96YV*"=0051(15A4)RD-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/R!E>'!L;V1E*"1P871H7V1E;&EM+"!G971E;G8H)U!!5$A%6%0G
M*2D-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B!A<G)A>2@G
M+F5X92<L)RYB870G+"<N8VUD)RPG+F-O;2<I.PT*("`@("`@("`@("`@+R\@
M86QL;W<@<&%S<VEN9R!A(&-O;6UA;F0N97AE('!A<F%M#0H@("`@("`@("`@
M("!I9B`H<W1R<&]S*"1P<F]G<F%M+"`G+B<I("$]/2!F86QS92D@>PT*("`@
M("`@("`@("`@("`@(&%R<F%Y7W5N<VAI9G0H)&5X95]S=69F:7AE<RP@)R<I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@+R\@:7-?97AE8W5T86)L
M92@I(&ES(&YO="!A=F%I;&%B;&4@;VX@=VEN9&]W<R!F;W(@4$A0-`T*("`@
M("`@("`@("`@)'!E87)?:7-?97AE8W5T86)L92`]("AF=6YC=&EO;E]E>&ES
M=',H)VES7V5X96-U=&%B;&4G*2D@/R`G:7-?97AE8W5T86)L92<@.B`G:7-?
M9FEL92<[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D97AE7W-U
M9F9I>&5S(#T@87)R87DH)R<I.PT*("`@("`@("`@("`@)'!E87)?:7-?97AE
M8W5T86)L92`]("=I<U]E>&5C=71A8FQE)SL-"B`@("`@("`@?0T*#0H@("`@
M("`@(&9O<F5A8V@@*"1E>&5?<W5F9FEX97,@87,@)'-U9F8I('L-"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1P871H7V5L96UE;G1S(&%S("1D:7(I('L-"B`@
M("`@("`@("`@("`@("`D9FEL92`]("1D:7(@+B!$25)%0U1/4EE?4T5005)!
M5$]2("X@)'!R;V=R86T@+B`D<W5F9CL-"B`@("`@("`@("`@("`@("!I9B`H
M)'!E87)?:7-?97AE8W5T86)L92@D9FEL92DI('L-"B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1F:6QE.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&9A;&QB86-K
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("H@5&AE(")F:6YD(B!C;VUM86YD
M#0H@("`@*@T*("`@("H@57-A9V4Z#0H@("`@*@T*("`@("H@4WES=&5M.CIF
M:6YD*"1D:7(I.PT*("`@("H@4WES=&5M.CIF:6YD*"(D9&ER("UT>7!E(&0B
M*3L-"B`@("`J(%-Y<W1E;3HZ9FEN9"@B)&1I<B`M='EP92!F(BD[#0H@("`@
M*B!3>7-T96TZ.F9I;F0H(B1D:7(@+6YA;64@*BYP:'`B*3L-"B`@("`J(%-Y
M<W1E;3HZ9FEN9"@B)&1I<B`M;F%M92`J+G!H<"`M;F%M92`J+FAT;2HB*3L-
M"B`@("`J(%-Y<W1E;3HZ9FEN9"@B)&1I<B`M;6%X9&5P=&@@,2(I.PT*("`@
M("H-"B`@("`J(%!A<F%M<R!I;7!L;65N=&5D.@T*("`@("H@)&1I<B`@("`@
M("`@("`@("T^(%-T87)T('1H92!S96%R8V@@870@=&AI<R!D:7)E8W1O<GD-
M"B`@("`J("UT>7!E(&0@("`@("`@("`M/B!R971U<FX@;VYL>2!D:7)E8W1O
M<FEE<PT*("`@("H@+71Y<&4@9B`@("`@("`@("T^(')E='5R;B!O;FQY(&9I
M;&5S#0H@("`@*B`M;6%X9&5P=&@@/&X^("`@+3X@;6%X(&1E<'1H(&]F(')E
M8W5R<VEO;@T*("`@("H@+6YA;64@/'!A='1E<FX^("T^('-E87)C:"!P871T
M97)N("AB87-H('-T>6QE*2X@375L=&EP;&4@+6YA;64@<&%R86T@86QL;W=E
M9`T*("`@("H-"B`@("`J($!P87)A;2`@;6EX960@16ET:&5R(&%R<F%Y(&]R
M('-T<FEN9R!W:71H('1H92!C;VUM86YD(&QI;F4-"B`@("`J($!R971U<FX@
M87)R87D@07)R87D@;V8@9F]U;F0@9FEL97,-"B`@("`J#0H@("`@*B\-"B`@
M("!F=6YC=&EO;B!F:6YD*"1A<F=S*0T*("`@('L-"B`@("`@("`@:68@*"%I
M<U]A<G)A>2@D87)G<RDI('L-"B`@("`@("`@("`@("1A<F=S(#T@<')E9U]S
M<&QI="@G+UQS*R\G+"`D87)G<RP@+3$L(%!214=?4U!,251?3D]?14U05%DI
M.PT*("`@("`@("!]#0H@("`@("`@("1D:7(@/2!A<G)A>5]S:&EF="@D87)G
M<RD[#0H@("`@("`@("1P871T97)N<R`](&%R<F%Y*"D[#0H@("`@("`@("1D
M97!T:"`](#`[#0H@("`@("`@("1D;U]F:6QE<R`]("1D;U]D:7)S(#T@=')U
M93L-"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)&%R9W,I.R`D
M:2LK*2![#0H@("`@("`@("`@("!S=VET8V@@*"1A<F=S6R1I72D@>PT*("`@
M("`@("`@("`@("`@(&-A<V4@)RUT>7!E)SH-"B`@("`@("`@("`@("`@("`@
M("`@:68@*&EN7V%R<F%Y*"1A<F=S6R1I*S%=+"!A<G)A>2@G9"<L("=F)RDI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&%R9W-;)&DK,5T@
M/3T@)V0G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1O7V9I
M;&5S(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D;U]D:7)S(#T@9F%L
M<V4[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)&DK*SL-"B`@("`@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@8V%S92`G+6YA
M;64G.@T*("`@("`@("`@("`@("`@("`@("!I9B`H3U-?5TE.1$]74RD@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1A<F=S6R1I*S%=>S!](#T]
M("=<7"<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!P<F5P
M96YD(&1R:79E#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%R9W-;
M)&DK,5T@/2!A9&1S;&%S:&5S*'-U8G-T<BAG971C=V0H*2P@,"P@,BD@+B`D
M87)G<ULD:2`K(#%=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@("\O(&5S8V%P92!P871H('-E<&%R871O
M<G,@=&\@879O:60@4$-212!P<F]B;&5M<PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)&%R9W-;)&DK,5T@/2!S=')?<F5P;&%C92@G7%PG+"`G7%Q<7"<L
M("1A<F=S6R1I*S%=*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`D<&%T=&5R;G-;72`]("(H(B`N('!R96=?<F5P;&%C
M92AA<G)A>2@G+UPN+R<L("<O7"HO)RDL#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=<+B<L
M("<N*B<L("DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1A<F=S6R1I*S%=*0T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`N("(I(CL-"B`@("`@("`@("`@
M("`@("`@("`@)&DK*SL-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("`@("`@8V%S92`G+6UA>&1E<'1H)SH-"B`@("`@("`@("`@
M("`@("`@("`@)&1E<'1H(#T@)&%R9W-;)&DK,5T[#0H@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@("1P871H(#T@4WES=&5M.CI?9&ER5&]3=')U8W0H)&1I<BP@)&1E<'1H
M*3L-"B`@("`@("`@:68@*"1D;U]F:6QE<R`F)B`D9&]?9&ER<RD@>PT*("`@
M("`@("`@("`@)&9I;&5S(#T@87)R87E?;65R9V4H)'!A=&A;)V9I;&5S)UTL
M("1P871H6R=D:7)S)UTI.PT*("`@("`@("!](&5L<V5I9B`H)&1O7V1I<G,I
M('L-"B`@("`@("`@("`@("1F:6QE<R`]("1P871H6R=D:7)S)UT[#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`D9FEL97,@/2`D<&%T:%LG9FEL
M97,G73L-"B`@("`@("`@?0T*("`@("`@("!I9B`H8V]U;G0H)'!A='1E<FYS
M*2D@>PT*("`@("`@("`@("`@)'!A='1E<FYS(#T@:6UP;&]D92@G?"<L("1P
M871T97)N<RD[#0H@("`@("`@("`@("`D<F5T(#T@87)R87DH*3L-"B`@("`@
M("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1F:6QE<RD[("1I*RLI
M('L-"B`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@B(UXD<&%T=&5R
M;G-<)",B+"`D9FEL97-;)&E=*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M<F5T6UT@/2`D9FEL97-;)&E=.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D<F5T.PT*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B`D9FEL97,[#0H@("`@?0T*?0T*/SX-"@``````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R\`
M````````````````````````````````````````````````````````````
M```````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#4Q-30S,S<T,@`P,3<W-#4`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+W1E<W1S+T1A=&4O````````````````````````````````
M`````````````````````````````````````````````#`P,#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S0R`#`R,#8R,@`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R\`
M````````````````````````````````````````````````````````````
M````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U
M,34T,S,W-#(`,#(Q-S8T`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T
M97-T<R]$871E+W1E<W1S+V)U9S8W-"YP:'``````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C,W-``Q,#4Q-30S,S<T,@`P,C,U,C$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*<F5Q=6ER95]O
M;F-E("=$871E+G!H<"<["B1E<G)O<B`](&9A;'-E.PHD9&%T97,@/2!A<G)A
M>2`H"B`@("!A<G)A>2@@87)R87DH,C`P,RPS+#$W*2PG,C`P,S`S,C,G+"<R
M,#`S,#,Q-R<L)S(P,#,P,S(T)RPG,C`P,S`S,3`G*2P*("`@(&%R<F%Y*"!A
M<G)A>2@R,#`S+#,L,C`I+"<R,#`S,#,R,R<L)S(P,#,P,S$W)RPG,C`P,S`S
M,C0G+"<R,#`S,#,Q,"<I+`H@("`@87)R87DH(&%R<F%Y*#(P,#,L,RPR,RDL
M)S(P,#,P,S(S)RPG,C`P,S`S,3<G+"<R,#`S,#,R-"<L)S(P,#,P,S$P)RD*
M*3L*9F]R96%C:"`H)&1A=&5S(&%S("1D*2!["B`@("`D9&%T92`]("1D6S!=
M.PH@("`@)')E<R`]($1A=&5?0V%L8SHZ96YD3V97965K*"1D871E6S)=+"1D
M871E6S%=+"1D871E6S!=*3L*("`@(&EF("@D<F5S(3TD9%LQ72D@>PH@("`@
M("`@(&5C:&\@(D)U9R`V-S0@96]W.B`B("X@)&1A=&5;,%TN)&1A=&5;,5TN
M)&1A=&5;,ETN(B!F86EL961<;B(["B`@("`@("`@)&5R<F]R(#T@=')U93L*
M("`@('T*?0H*9F]R96%C:"`H)&1A=&5S(&%S("1D*2!["B`@("`D9&%T92`]
M("1D6S!=.PH@("`@)')E<R`]($1A=&5?0V%L8SHZ8F5G:6Y/9E=E96LH)&1A
M=&5;,ETL)&1A=&5;,5TL)&1A=&5;,%TI.PH@("`@:68@*"1R97,A/21D6S)=
M*2!["B`@("`@("`@96-H;R`B0G5G(#8W-"!B;W<Z("(@+B`D9&%T95LP72XD
M9&%T95LQ72XD9&%T95LR72XB(&9A:6QE9%QN(CL*("`@("`@("`D97)R;W(@
M/2!T<G5E.PH@("`@?0I]"@H*9F]R96%C:"`H)&1A=&5S(&%S("1D*2!["B`@
M("`D9&%T92`]("1D6S!=.PH@("`@)')E<R`]($1A=&5?0V%L8SHZ8F5G:6Y/
M9DYE>'17965K*"1D871E6S)=+"1D871E6S%=+"1D871E6S!=*3L*("`@(&EF
M("@D<F5S(3TD9%LS72D@>PH@("`@("`@(&5C:&\@(D)U9R`V-S0@8F]N=SH@
M(B`N("1D871E6S!=+B1D871E6S%=+B1D871E6S)=+B(@9F%I;&5D7&XB.PH@
M("`@("`@("1E<G)O<B`]('1R=64["B`@("!]"GT*"@IF;W)E86-H("@D9&%T
M97,@87,@)&0I('L*("`@("1D871E(#T@)&1;,%T["B`@("`D<F5S(#T@1&%T
M95]#86QC.CIB96=I;D]F4')E=E=E96LH)&1A=&5;,ETL)&1A=&5;,5TL)&1A
M=&5;,%TI.PH@("`@:68@*"1R97,A/21D6S1=*2!["B`@("`@("`@96-H;R`B
M0G5G(#8W-"!B;W!W.B`B("X@)&1A=&5;,%TN)&1A=&5;,5TN)&1A=&5;,ETN
M(B!F86EL961<;B(["B`@("`@("`@)&5R<F]R(#T@=')U93L*("`@('T*?0H*
M:68@*"$D97)R;W(I('L*("`@(&5C:&\@(D)U9R`V-S0Z($]+7&XB.PI]"@H_
M/@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1A=&4O=&5S=',O8G5G-S(W
M7S$N<&AP````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#8P`#$P-3$U-#,S
M-S0R`#`R,S<S,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*@H@*B!497-T<R!F;W(@=V5E:W-);DUO;G1H+"!F
M96)R=6%R>2!W:71H(#0@=V5E:W,*("H@36]N9&%Y(&%S(#%S="!D87D@;V8@
M=V5E:PH@*B\*9&5F:6YE*"=$051%7T-!3$-?0D5'24Y?5T5%2T1!62<L(#$I
M.PIR97%U:7)E7V]N8V4@(D1A=&4O0V%L8RYP:'`B.PH*+RHJ"B`J(%1E<W0@
M9&%T97,@9G)O;2`Q.3<P('1O(#(P,CD*("H@1&%T82!F<F]M.B!H='1P.B\O
M=W=W+FUE<FQY;BYD96UO;BYC;RYU:R]W:VYO=&5S="YT>'0*("H@3W1H97)S
M('5S969U;&P@9&%T87,@879A:6QA8FQE(&9R;VTZ"B`J(&AT='`Z+R]W=W<N
M;65R;'EN+F1E;6]N+F-O+G5K+R-D870*("HO"B1D871A<&%T:"`](&1I<FYA
M;64H(%]?1DE,15]?*3L*"B1F86EL961?=&5S=%]D871A("`@/2!F86QS93L*
M)&1A=&5S("`@/2!F:6QE*"1D871A<&%T:"`N("<O=V5E:W-I;FUO;G1H7S1?
M;6]N9&%Y+G1X="<I.PHD8VYT("`@("`]('-I>F5O9B@D9&%T97,I.PHD=F%L
M:61S(#T@87)R87DH*3L*9F]R*"`D:3TP.R1I/"1C;G0[)&DK*R`I>PH@("`@
M)'!A<G1S("`@("`@/2!E>'!L;V1E*"<O)RPD9&%T97-;)&E=*3L*("`@("1V
M86QI9'-;)'!A<G1S6S!=72`](&%R<F%Y*"1P87)T<ULQ73T^*&EN="ES=')?
M<F5P;&%C92@B7&XB+"<G+"1P87)T<ULR72DI.PI]"G5N<V5T*"1D871E<RD[
M"F9O<F5A8V@H)'9A;&ED<R!A<R`D>65A<B`]/B`D;6]N=&AS*7L*("`@(&9O
M<F5A8V@@*"1M;VYT:',@87,@)&UO;G1H/3XD=F%L:61?=V5E:W,I('L*("`@
M("`@("`D8V%L8U]W965K<R`]($1A=&5?0V%L8SHZ=V5E:W-);DUO;G1H*"1M
M;VYT:"PD>65A<BD["B`@("`@("`@:68H)&-A;&-?=V5E:W,A/21V86QI9%]W
M965K<RE["B`@("`@("`@("`@("1F86EL961?=&5S=%]D871A("`@/2!T<G5E
M.PH@("`@("`@("`@("!E8VAO(")"=6<@(S<R-RP@<&%S<R`Q.B`D>65A<B\D
M;6]N=&@@9F%I;&5D+B!%>'!E8W0Z)'9A;&ED7W=E96MS($=O=#HD8V%L8U]W
M965K<UQN(CL*("`@("`@("!]"B`@("!]"GT*:68@*"$D9F%I;&5D7W1E<W1?
M9&%T82D@>PH)96-H;R`B0G5G(",W,C<L('!A<W,@,3H@3TM<;B(["GT*/SX*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M=&5S=',O1&%T92]T97-T<R]B=6<W,C=?,BYP:'``````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#(P-C``,3`U,34T,S,W-#(`,#(S-S,Q`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J"B`J(%1E
M<W1S(&9O<B!W965K<TEN36]N=&@L(&9E8G)U87)Y('=I=&@@-"!W965K<PH@
M*B!3=6YD87D@87,@,7-T(&1A>2!O9B!W965K"B`J+PID969I;F4H)T1!5$5?
M0T%,0U]"14=)3E]7145+1$%9)RP@,"D["G)E<75I<F5?;VYC92`B1&%T92]#
M86QC+G!H<"(["@HO*BH*("H@5&5S="!D871E<R!F<F]M(#$Y-S`@=&\@,C`R
M.0H@*B!$871A(&9R;VTZ(&AT='`Z+R]W=W<N;65R;'EN+F1E;6]N+F-O+G5K
M+W=K;F]T97-T+G1X=`H@*B!/=&AE<G,@=7-E9G5L;"!D871A<R!A=F%I;&%B
M;&4@9G)O;3H*("H@:'1T<#HO+W=W=RYM97)L>6XN9&5M;VXN8V\N=6LO(V1A
M=`H@*B\*)&1A=&%P871H(#T@9&ER;F%M92@@7U]&24Q%7U\I.PH*)&9A:6QE
M9%]T97-T7V1A=&$@("`](&9A;'-E.PHD9&%T97,@("`](&9I;&4H)&1A=&%P
M871H("X@)R]W965K<VEN;6]N=&A?-%]S=6YD87DN='AT)RD["B1C;G0@("`@
M(#T@<VEZ96]F*"1D871E<RD["B1V86QI9',@/2!A<G)A>2@I.PIF;W(H("1I
M/3`[)&D\)&-N=#LD:2LK("E["B`@("`D<&%R=',@("`@("`](&5X<&QO9&4H
M)R\G+"1D871E<ULD:5TI.PH@("`@)'9A;&ED<ULD<&%R='-;,%U=(#T@87)R
M87DH)'!A<G1S6S%=/3XH:6YT*7-T<E]R97!L86-E*")<;B(L)R<L)'!A<G1S
M6S)=*2D["GT*=6YS970H)&1A=&5S*3L*9F]R96%C:"@D=F%L:61S(&%S("1Y
M96%R(#T^("1M;VYT:',I>PH@("`@9F]R96%C:"`H)&UO;G1H<R!A<R`D;6]N
M=&@]/B1V86QI9%]W965K<RD@>PH@("`@("`@("1C86QC7W=E96MS(#T@1&%T
M95]#86QC.CIW965K<TEN36]N=&@H)&UO;G1H+"1Y96%R*3L*("`@("`@("!I
M9B@D8V%L8U]W965K<R$])'9A;&ED7W=E96MS*7L*("`@("`@("`@("`@)&9A
M:6QE9%]T97-T7V1A=&$@("`]('1R=64["B`@("`@("`@("`@(&5C:&\@(D)U
M9R`C-S(W+"!P87-S(#,Z("1Y96%R+R1M;VYT:"!F86EL960N($5X<&5C=#HD
M=F%L:61?=V5E:W,@1V]T.B1C86QC7W=E96MS7&XB.PH@("`@("`@('T*("`@
M('T*?0II9B`H(21F86EL961?=&5S=%]D871A*2!["@EE8VAO(")"=6<@(S<R
M-RP@<&%S<R`R.B!/2UQN(CL*?0H_/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+V)U9S<R
M-U\S+G!H<```````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`U,``Q,#4Q-30S
M,S<T,@`P,C,W,S$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RH*("H@5&5S=',@9F]R('=E96MS26Y-;VYT:"P@
M(G)A;F1O;2(*("H@4W5N9&%Y(&%S(#%S="!D87D@;V8@=V5E:PH@*B\*9&5F
M:6YE*"=$051%7T-!3$-?0D5'24Y?5T5%2T1!62<L(#`I.PIR97%U:7)E7V]N
M8V4@(D1A=&4O0V%L8RYP:'`B.PH*+RHJ"B`J(%1E<W0@9&%T97,@9G)O;2`Q
M.3<P('1O(#(P,CD*("H@1&%T82!F<F]M.B!H='1P.B\O=W=W+FUE<FQY;BYD
M96UO;BYC;RYU:R]W:VYO=&5S="YT>'0*("H@3W1H97)S('5S969U;&P@9&%T
M87,@879A:6QA8FQE(&9R;VTZ"B`J(&AT='`Z+R]W=W<N;65R;'EN+F1E;6]N
M+F-O+G5K+R-D870*("HO"B1D871A<&%T:"`](&1I<FYA;64H(%]?1DE,15]?
M*3L*"B1F86EL961?=&5S=%]D871A("`@/2!F86QS93L*)&1A=&5S("`@/2!F
M:6QE*"1D871A<&%T:"`N("<O=V5E:W-I;FUO;G1H7W)D;5]S=6YD87DN='AT
M)RD["B1C;G0@("`@(#T@<VEZ96]F*"1D871E<RD["B1V86QI9',@/2!A<G)A
M>2@I.PIF;W(H("1I/3`[)&D\)&-N=#LD:2LK("E["B`@("`D<&%R=',@("`@
M("`](&5X<&QO9&4H)R\G+"1D871E<ULD:5TI.PH@("`@)'9A;&ED<ULD<&%R
M='-;,%U=(#T@87)R87DH)'!A<G1S6S%=/3XH:6YT*7-T<E]R97!L86-E*")<
M;B(L)R<L)'!A<G1S6S)=*2D["GT*=6YS970H)&1A=&5S*3L*9F]R96%C:"@D
M=F%L:61S(&%S("1Y96%R(#T^("1M;VYT:',I>PH@("`@9F]R96%C:"`H)&UO
M;G1H<R!A<R`D;6]N=&@]/B1V86QI9%]W965K<RD@>PH@("`@("`@("1C86QC
M7W=E96MS(#T@1&%T95]#86QC.CIW965K<TEN36]N=&@H)&UO;G1H+"1Y96%R
M*3L*("`@("`@("!I9B@D8V%L8U]W965K<R$])'9A;&ED7W=E96MS*7L*("`@
M("`@("`@("`@)&9A:6QE9%]T97-T7V1A=&$@("`]('1R=64["B`@("`@("`@
M("`@(&5C:&\@(D)U9R`C-S(W+"!P87-S(#,Z("1Y96%R+R1M;VYT:"!F86EL
M960N($5X<&5C=#HD=F%L:61?=V5E:W,@1V]T.B1C86QC7W=E96MS7&XB.PH@
M("`@("`@('T*("`@('T*?0II9B`H(21F86EL961?=&5S=%]D871A*2!["B`@
M("!E8VAO(")"=6<@(S<R-RP@<&%S<R`S.B!/2UQN(CL*?0H_/@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+W1E<W1S+T1A=&4O=&5S=',O8G5G-S(W7S0N<&AP````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,#0W`#$P-3$U-#,S-S0R`#`R,S<T,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*@H@*B!4
M97-T<R!F;W(@=V5E:W-);DUO;G1H+"`B<F%N9&]M(@H@*B!-;VYD87D@87,@
M,7-T(&1A>2!O9B!W965K"B`J+PID969I;F4H)T1!5$5?0T%,0U]"14=)3E]7
M145+1$%9)RP@,2D["G)E<75I<F5?;VYC92`B1&%T92]#86QC+G!H<"(["@HO
M*BH*("H@5&5S="!D871E<R!F<F]M(#$Y-S`@=&\@,C`R.0H@*B!$871A(&9R
M;VTZ(&AT='`Z+R]W=W<N;65R;'EN+F1E;6]N+F-O+G5K+W=K;F]T97-T+G1X
M=`H@*B!/=&AE<G,@=7-E9G5L;"!D871A<R!A=F%I;&%B;&4@9G)O;3H*("H@
M:'1T<#HO+W=W=RYM97)L>6XN9&5M;VXN8V\N=6LO(V1A=`H@*B\*)&1A=&%P
M871H(#T@9&ER;F%M92@@7U]&24Q%7U\I.PH*)&9A:6QE9%]T97-T7V1A=&$@
M("`](&9A;'-E.PHD9&%T97,@("`](&9I;&4H)&1A=&%P871H("X@)R]W965K
M<VEN;6]N=&A?<F1M7VUO;F1A>2YT>'0G*3L*)&-N="`@("`@/2!S:7IE;V8H
M)&1A=&5S*3L*)'9A;&ED<R`](&%R<F%Y*"D["F9O<B@@)&D],#LD:3PD8VYT
M.R1I*RL@*7L*("`@("1P87)T<R`@("`@(#T@97AP;&]D92@G+R<L)&1A=&5S
M6R1I72D["B`@("`D=F%L:61S6R1P87)T<ULP75T@/2!A<G)A>2@D<&%R='-;
M,5T]/BAI;G0I<W1R7W)E<&QA8V4H(EQN(BPG)RPD<&%R='-;,ETI*3L*?0IU
M;G-E="@D9&%T97,I.PIF;W)E86-H*"1V86QI9',@87,@)'EE87(@/3X@)&UO
M;G1H<RE["B`@("!F;W)E86-H("@D;6]N=&AS(&%S("1M;VYT:#T^)'9A;&ED
M7W=E96MS*2!["B`@("`@("`@)&-A;&-?=V5E:W,@/2!$871E7T-A;&,Z.G=E
M96MS26Y-;VYT:"@D;6]N=&@L)'EE87(I.PH@("`@("`@(&EF*"1C86QC7W=E
M96MS(3TD=F%L:61?=V5E:W,I>PH@("`@("`@("`@("`D9F%I;&5D7W1E<W1?
M9&%T82`@(#T@=')U93L*("`@("`@("`@("`@96-H;R`B0G5G(#<R-RP@<&%S
M<R`T.B`D>65A<B\D;6]N=&@@9F%I;&5D+B!%>'!E8W0Z)'9A;&ED7W=E96MS
M($=O=#HD8V%L8U]W965K<UQN(CL*("`@("`@("!]"B`@("!]"GT*:68@*"$D
M9F%I;&5D7W1E<W1?9&%T82D@>PH@("`@96-H;R`B0G5G(",W,C<L('!A<W,@
M-#H@3TM<;B(["GT*/SX*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]B=6<Y
M-C<N<&AP````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`V,34`,3`U,34T
M,S,W-#(`,#(S-3(R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"G)E<75I<F5?;VYC92`G1&%T92YP:'`G.PHD7T1!
M5$5?5$E-15I/3D5?1$5&055,5"`]("=086-I9FEC+T-H871H86TG.PHD='H@
M/2!$871E7U1I;65:;VYE.CIG971$969A=6QT*"D["FEF("@D='HM/FED(3TD
M7T1!5$5?5$E-15I/3D5?1$5&055,5"`F)B`D='HM/FED(3TG4&%C:69I8R]#
M:&%T:&%M)RD@>PH@("`@96-H;R`B<V5T1&5F875L="!&86EL961<;B(["GT*
M1&%T95]4:6UE6F]N93HZ<V5T1&5F875L="@G0U-4)RD["B1D969A=6QT(#T@
M)T535"<["B1T>B`]($1A=&5?5&EM95IO;F4Z.F=E=$1E9F%U;'0H*3L*:68@
M*"1T>BT^:60A/21?1$%415]424U%6D].15]$149!54Q4("8F("1T>BT^:60A
M/2=%4U0G*2!["B`@("!E8VAO(")S971$969A=6QT($9A:6QE9%QN(CL*?0H_
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+W1E<W1S+T1A=&4O=&5S=',O8V%L8RYP:'``````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#0T-#8V`#$P-3$U-#,S-S0R`#`R,S0Q
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED
M=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PHO+PHO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-2!$86YI
M96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!T:&4@3F5W($)31"!L:6-E;G-E+"!4:&%T
M(&ES(&)U;F1L960@('P*+R\@?"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@
M9FEL92!,24-%3E-%+"!A;F0@:7,@879A:6QA8FQE('1H<F]U9V@@("`@("!\
M"B\O('P@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W
M=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("`@
M("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E
M(&$@8V]P>2!O9B!T:&4@;F5W($)31&QI8V5N<V4@86YD(&%R92!U;F%B;&4@
M("!\"B\O('P@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M
M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@?`HO+R!\('!E87(M
M9&5V0&QI<W1S+G!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I
M;6UE9&EA=&5L>2X@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@075T:&]R.B!$86YI96P@0V]N=FES<V]R(#QD86YI96QC
M0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+RHJ"B`J(%1E<W1S(&9O<B!T:&4@
M1&%T95]#86QC(&-L87-S"B`J"B`J($%N>2!I;F1I=FED=6%L('1E<W1S('1H
M870@9F%I;"!W:6QL(&AA=F4@=&AE:7(@;F%M92P@97AP96-T960@<F5S=6QT
M"B`J(&%N9"!A8W1U86P@<F5S=6QT('!R:6YT960@;W5T+B`@4V\@<V5E:6YG
M(&YO(&]U='!U="!W:&5N(&5X96-U=&EN9PH@*B!T:&ES(&9I;&4@:7,@82!G
M;V]D('1H:6YG+@H@*@H@*B!#86X@8F4@<G5N('9I82!#3$D@;W(@82!W96(@
M<V5R=F5R+@H@*@H@*B!4:&ES('1E<W0@<V5N<V5S('=H971H97(@:70@:7,@
M9G)O;2!A;B!I;G-T86QL871I;VX@;V8@4$5!4CHZ1&%T92!O<B!I9@H@*B!I
M="=S(&9R;VT@0U93(&]R(&$@+G1A<B!F:6QE+B`@268@:70G<R!A;B!I;G-T
M86QL960@=F5R<VEO;BP@=7-E('1H90H@*B!I;G-T86QL960@=F5R<VEO;B!O
M9B!$871E7T-A;&,N("!/=&AE<G=I<V4L('5S92!T:&4@;&]C86P@9&5V96QO
M<&UE;G0*("H@8V]P>2!O9B!$871E7T-A;&,N"B`J"B`J($!C871E9V]R>2`@
M($1A=&4@86YD(%1I;64*("H@0'!A8VMA9V4@("`@1&%T90H@*B!`875T:&]R
M("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C
M;W!Y<FEG:'0@(#(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS
M90H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@8V%L8RYP:'`L=B`Q+C@@,C`P
M-2\Q,2\Q-2`P,#HQ-CHT,"!P86IO>64@17AP("0*("H@0&QI;FL@("`@("`@
M:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1A=&4*("H@0'-I;F-E("`@
M("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C4*("HO"@II9B`H
M)R]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R)R`A/2`G0"<N)VEN8VQU
M9&5?<&%T:"<N)T`G*2!["B`@("!I;FE?<V5T*"=I;F-L=61E7W!A=&@G+"!I
M;FE?9V5T*"=I;F-L=61E7W!A=&@G*0H@("`@("`@("`@("`N(%!!5$A?4T50
M05)!5$]2("X@)RXG"B`@("`I.PI](&5L<V4@>PH@("`@:6YI7W-E="@G:6YC
M;'5D95]P871H)RP@<F5A;'!A=&@H9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN
M+R<I"B`@("`@("`@("`@("X@4$%42%]315!!4D%43U(@+B`G+B<@+B!0051(
M7U-%4$%2051/4@H@("`@("`@("`@("`N(&EN:5]G970H)VEN8VQU9&5?<&%T
M:"<I"B`@("`I.PI]"@HO*BH*("H@1V5T('1H92!N965D960@8VQA<W,*("HO
M"G)E<75I<F5?;VYC92`G1&%T92]#86QC+G!H<"<["@HO*BH*("H@0V]M<&%R
M92!T:&4@=&5S="!R97-U;'0@=&\@=&AE(&5X<&5C=&5D(')E<W5L=`H@*@H@
M*B!)9B!T:&4@=&5S="!F86EL<RP@96-H;R!O=70@=&AE(')E<W5L=',N"B`J
M"B`J($!P87)A;2!M:7AE9"`@)&5X<&5C="`@("`@=&AE('-C86QA<B!O<B!A
M<G)A>2!Y;W4@97AP96-T(&9R;VT@=&AE('1E<W0*("H@0'!A<F%M(&UI>&5D
M("`D86-T=6%L("`@("!T:&4@<V-A;&%R(&]R(&%R<F%Y(')E<W5L=',@9G)O
M;2!T:&4@=&5S=`H@*B!`<&%R86T@<W1R:6YG("1T97-T7VYA;64@('1H92!N
M86UE(&]F('1H92!T97-T"B`J"B`J($!R971U<FX@=F]I9`H@*B\*9G5N8W1I
M;VX@8V]M<&%R92@D97AP96-T+"`D86-T=6%L+"`D=&5S=%]N86UE*2!["B`@
M("!I9B`H:7-?87)R87DH)&5X<&5C="DI('L*("`@("`@("!I9B`H8V]U;G0H
M87)R87E?9&EF9B@D86-T=6%L+"`D97AP96-T*2DI('L*("`@("`@("`@("`@
M96-H;R`B)'1E<W1?;F%M92!F86EL960N("!%>'!E8W0Z7&XB.PH@("`@("`@
M("`@("!P<FEN=%]R*"1E>'!E8W0I.PH@("`@("`@("`@("!E8VAO(")!8W1U
M86PZ7&XB.PH@("`@("`@("`@("!P<FEN=%]R*"1A8W1U86PI.PH@("`@("`@
M('T*("`@('T@96QS92!["B`@("`@("`@:68@*"1E>'!E8W0@(3T@)&%C='5A
M;"D@>PH@("`@("`@("`@("!E8VAO("(D=&5S=%]N86UE(&9A:6QE9"X@($5X
M<&5C=#H@)&5X<&5C="X@($%C='5A;#H@)&%C='5A;%QN(CL*("`@("`@("!]
M"B`@("!]"GT*"FEF("AP:'!?<V%P:5]N86UE*"D@(3T@)V-L:2<I('L*("`@
M(&5C:&\@(CQP<F4^7&XB.PI]"@H*8V]M<&%R92@G,C`P,#$Q,C(G+"!$871E
M7T-A;&,Z.F1A=&5&;W)M870H,C(L(#$Q+"`R,#`P+"`G)5DE;25D)RDL("=D
M871E1F]R;6%T)RD["F-O;7!A<F4H)S(P,#`Q,3(R)RP@1&%T95]#86QC.CID
M871E1F]R;6%T*"<R,B<L("<Q,2<L("<R,#`P)RP@)R59)6TE9"<I+"`G9&%T
M949O<FUA="!S='(G*3L*"F-O;7!A<F4H)S(P,#$G+"!$871E7T-A;&,Z.F1E
M9F%U;'1#96YT=7)Y*"<Q)RDL("=D969A=6QT0V5N='5R>2`Q('-T<B<I.PIC
M;VUP87)E*"<R,#`Q)RP@1&%T95]#86QC.CID969A=6QT0V5N='5R>2@Q*2P@
M)V1E9F%U;'1#96YT=7)Y(#$G*3L*8V]M<&%R92@G,3DV,"<L($1A=&5?0V%L
M8SHZ9&5F875L=$-E;G1U<GDH-C`I+"`G9&5F875L=$-E;G1U<GD@,B<I.PIC
M;VUP87)E*"<R,#$P)RP@1&%T95]#86QC.CID969A=6QT0V5N='5R>2@Q,"DL
M("=D969A=6QT0V5N='5R>2`S)RD["@IC;VUP87)E*#(T-3$X-S$L($1A=&5?
M0V%L8SHZ9&%T951O1&%Y<R@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G9&%T951O
M1&%Y<R!S='(G*3L*8V]M<&%R92@R-#4Q.#<Q+"!$871E7T-A;&,Z.F1A=&54
M;T1A>7,H,C(L(#$Q+"`R,#`P*2P@)V1A=&54;T1A>7,G*3L*8V]M<&%R92@G
M,C`P,#$Q,C(G+"!$871E7T-A;&,Z.F1A>7-4;T1A=&4H,C0U,3@W,2DL("=D
M87ES5&]$871E)RD["@IC;VUP87)E*"<R,#`P+30W+3,G+"!$871E7T-A;&,Z
M.F=R96=O<FEA;E1O25-/*"<R,B<L("<Q,2<L("<R,#`P)RDL("=G<F5G;W)I
M86Y4;TE33R!S='(G*3L*8V]M<&%R92@G,C`P,"TT-RTS)RP@1&%T95]#86QC
M.CIG<F5G;W)I86Y4;TE33R@R,BP@,3$L(#(P,#`I+"`G9W)E9V]R:6%N5&])
M4T\G*3L*8V]M<&%R92@R-#4Q-S$V+C4V-S8W+"!$871E7T-A;&,Z.F1A=&53
M96%S;VXH)U-534U%4E-/3%-424-%)RP@,C`P,"DL("=D871E4V5A<V]N)RD[
M"@IC;VUP87)E*&1A=&4H)UEM9"<I+"!$871E7T-A;&,Z.F1A=&5.;W<H*2P@
M)V1A=&5.;W<G*3L*8V]M<&%R92AD871E*"=9)RDL($1A=&5?0V%L8SHZ9V5T
M665A<B@I+"`G9V5T665A<B<I.PIC;VUP87)E*&1A=&4H)VTG*2P@1&%T95]#
M86QC.CIG971-;VYT:"@I+"`G9V5T36]N=&@G*3L*8V]M<&%R92AD871E*"=D
M)RDL($1A=&5?0V%L8SHZ9V5T1&%Y*"DL("=G971$87DG*3L*"F-O;7!A<F4H
M,S(W+"!$871E7T-A;&,Z.FIU;&EA;D1A=&4H,C(L(#$Q+"`R,#`P*2P@)VIU
M;&EA;D1A=&4G*3L*8V]M<&%R92@G3F]V96UB97(G+"!$871E7T-A;&,Z.F=E
M=$UO;G1H1G5L;&YA;64H,3$I+"`G9V5T36]N=&A&=6QL;F%M92<I.PIC;VUP
M87)E*"=.;W8G+"!$871E7T-A;&,Z.F=E=$UO;G1H06)B<FYA;64H,3$I+"`G
M9V5T36]N=&A!8F)R;F%M92<I.PIC;VUP87)E*"=3871U<F1A>2<L($1A=&5?
M0V%L8SHZ9V5T5V5E:V1A>49U;&QN86UE*#$L(#$L(#(P,#4I+"`G9V5T5V5E
M:V1A>49U;&QN86UE)RD["F-O;7!A<F4H)U-A="<L($1A=&5?0V%L8SHZ9V5T
M5V5E:V1A>4%B8G)N86UE*#$L(#$L(#(P,#4I+"`G9V5T5V5E:V1A>4%B8G)N
M86UE)RD["F-O;7!A<F4H,3$L($1A=&5?0V%L8SHZ9V5T36]N=&A&<F]M1G5L
M;$YA;64H)TYO=F5M8F5R)RDL("=G971-;VYT:$9R;VU&=6QL3F%M92<I.PH*
M8V]M<&%R92@S,C<L($1A=&5?0V%L8SHZ:G5L:6%N1&%T92@G,C(G+"`G,3$G
M+"`G,C`P,"<I+"`G:G5L:6%N1&%T92!S='(G*3L*8V]M<&%R92@G3F]V96UB
M97(G+"!$871E7T-A;&,Z.F=E=$UO;G1H1G5L;&YA;64H)S$Q)RDL("=G971-
M;VYT:$9U;&QN86UE('-T<B<I.PIC;VUP87)E*"=.;W8G+"!$871E7T-A;&,Z
M.F=E=$UO;G1H06)B<FYA;64H)S$Q)RDL("=G971-;VYT:$%B8G)N86UE('-T
M<B<I.PIC;VUP87)E*"=3871U<F1A>2<L($1A=&5?0V%L8SHZ9V5T5V5E:V1A
M>49U;&QN86UE*"<P,2<L("<P,2<L("<R,#`U)RDL("=G9717965K9&%Y1G5L
M;&YA;64@<W1R)RD["F-O;7!A<F4H)U-A="<L($1A=&5?0V%L8SHZ9V5T5V5E
M:V1A>4%B8G)N86UE*"<P,2<L("<P,2<L("<R,#`U)RDL("=G9717965K9&%Y
M06)B<FYA;64@<W1R)RD["@HD97AP(#T@87)R87DH"B`@("`G2F%N=6%R>2<L
M"B`@("`G1F5B<G5A<GDG+`H@("`@)TUA<F-H)RP*("`@("=!<')I;"<L"B`@
M("`G36%Y)RP*("`@("=*=6YE)RP*("`@("=*=6QY)RP*("`@("=!=6=U<W0G
M+`H@("`@)U-E<'1E;6)E<B<L"B`@("`G3V-T;V)E<B<L"B`@("`G3F]V96UB
M97(G+`H@("`@)T1E8V5M8F5R)PHI.PIC;VUP87)E*"1E>'`L($1A=&5?0V%L
M8SHZ9V5T36]N=&A.86UE<R@I+"`G9V5T36]N=&A.86UE<R<I.PH*)&5X<"`]
M(&%R<F%Y*`H@("`@)TUO;F1A>2<L"B`@("`G5'5E<V1A>2<L"B`@("`G5V5D
M;F5S9&%Y)RP*("`@("=4:'5R<V1A>2<L"B`@("`G1G)I9&%Y)RP*("`@("=3
M871U<F1A>2<L"B`@("`G4W5N9&%Y)PHI.PIC;VUP87)E*"1E>'`L($1A=&5?
M0V%L8SHZ9V5T5V5E:T1A>7,H*2P@)V=E=%=E96M$87ES)RD["@IC;VUP87)E
M*#,L($1A=&5?0V%L8SHZ9&%Y3V97965K*#(R+"`Q,2P@,C`P,"DL("=D87E/
M9E=E96LG*3L*8V]M<&%R92@T-RP@1&%T95]#86QC.CIW965K3V9996%R*#(R
M+"`Q,2P@,C`P,"DL("=W965K3V9996%R)RD["F-O;7!A<F4H-"P@1&%T95]#
M86QC.CIQ=6%R=&5R3V9996%R*#(R+"`Q,2P@,C`P,"DL("=Q=6%R=&5R3V99
M96%R)RD["@IC;VUP87)E*#,L($1A=&5?0V%L8SHZ9&%Y3V97965K*"<R,B<L
M("<Q,2<L("<R,#`P)RDL("=D87E/9E=E96L@<W1R)RD["F-O;7!A<F4H-#<L
M($1A=&5?0V%L8SHZ=V5E:T]F665A<B@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G
M=V5E:T]F665A<B!S='(G*3L*8V]M<&%R92@T+"!$871E7T-A;&,Z.G%U87)T
M97)/9EEE87(H)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)W%U87)T97)/9EEE87(@
M<W1R)RD["@IC;VUP87)E*#(X+"!$871E7T-A;&,Z.F1A>7-);DUO;G1H*#(L
M(#$Y,#`I+"`G9&%Y<TEN36]N=&@@,2<I.PIC;VUP87)E*#(Y+"!$871E7T-A
M;&,Z.F1A>7-);DUO;G1H*#(L(#$Y.38I+"`G9&%Y<TEN36]N=&@@,B<I.PIC
M;VUP87)E*#(Y+"!$871E7T-A;&,Z.F1A>7-);DUO;G1H*#(L(#(P,#`I+"`G
M9&%Y<TEN36]N=&@@,R<I.PIC;VUP87)E*#(X+"!$871E7T-A;&,Z.F1A>7-)
M;DUO;G1H*#(L(#(P,#$I+"`G9&%Y<TEN36]N=&@@-"<I.PIC;VUP87)E*#,P
M+"!$871E7T-A;&,Z.F1A>7-);DUO;G1H*#$Q+"`R,#`P*2P@)V1A>7-);DUO
M;G1H(#4G*3L*"F-O;7!A<F4H,C@L($1A=&5?0V%L8SHZ9&%Y<TEN36]N=&@H
M)S`R)RP@,3DP,"DL("=D87ES26Y-;VYT:"`Q('-T<B<I.PIC;VUP87)E*#(Y
M+"!$871E7T-A;&,Z.F1A>7-);DUO;G1H*"<P,B<L(#$Y.38I+"`G9&%Y<TEN
M36]N=&@@,B!S='(G*3L*8V]M<&%R92@R.2P@1&%T95]#86QC.CID87ES26Y-
M;VYT:"@G,#(G+"`R,#`P*2P@)V1A>7-);DUO;G1H(#,@<W1R)RD["F-O;7!A
M<F4H,C@L($1A=&5?0V%L8SHZ9&%Y<TEN36]N=&@H)S`R)RP@,C`P,2DL("=D
M87ES26Y-;VYT:"`T('-T<B<I.PIC;VUP87)E*#,P+"!$871E7T-A;&,Z.F1A
M>7-);DUO;G1H*"<Q,2<L("<R,#`P)RDL("=D87ES26Y-;VYT:"`U('-T<B<I
M.PH*8V]M<&%R92@U+"!$871E7T-A;&,Z.G=E96MS26Y-;VYT:"@Q,2P@,C`P
M,"DL("=W965K<TEN36]N=&@G*3L*8V]M<&%R92@U+"!$871E7T-A;&,Z.G=E
M96MS26Y-;VYT:"@G,3$G+"`G,C`P,"<I+"`G=V5E:W-);DUO;G1H('-T<B<I
M.PH*"B1E>'`@/2!A<G)A>2@*("`@("<Q.3`P,#(R-B<L"B`@("`G,3DP,#`R
M,C<G+`H@("`@)S$Y,#`P,C(X)RP*("`@("<Q.3`P,#,P,2<L"B`@("`G,3DP
M,#`S,#(G+`H@("`@)S$Y,#`P,S`S)RP*("`@("<Q.3`P,#,P-"<L"BD["F-O
M;7!A<F4H)&5X<"P@1&%T95]#86QC.CIG971#86QE;F1A<E=E96LH,C<L(#(L
M(#$Y,#`I+"`G9V5T0V%L96YD87)7965K(#$G*3L*"B1E>'`@/2!A<G)A>2@*
M("`@("<R,#`P,#(R."<L"B`@("`G,C`P,#`R,CDG+`H@("`@)S(P,#`P,S`Q
M)RP*("`@("<R,#`P,#,P,B<L"B`@("`G,C`P,#`S,#,G+`H@("`@)S(P,#`P
M,S`T)RP*("`@("<R,#`P,#,P-2<L"BD["F-O;7!A<F4H)&5X<"P@1&%T95]#
M86QC.CIG971#86QE;F1A<E=E96LH,C@L(#(L(#(P,#`I+"`G9V5T0V%L96YD
M87)7965K(#(G*3L*"B1E>'`@/2!A<G)A>2@*("`@("<R,#`P,3$R-R<L"B`@
M("`G,C`P,#$Q,C@G+`H@("`@)S(P,#`Q,3(Y)RP*("`@("<R,#`P,3$S,"<L
M"B`@("`G,C`P,#$R,#$G+`H@("`@)S(P,#`Q,C`R)RP*("`@("<R,#`P,3(P
M,R<**3L*8V]M<&%R92@D97AP+"!$871E7T-A;&,Z.F=E=$-A;&5N9&%R5V5E
M:R@R-RP@,3$L(#(P,#`I+"`G9V5T0V%L96YD87)7965K(#,G*3L*8V]M<&%R
M92@D97AP+"!$871E7T-A;&,Z.F=E=$-A;&5N9&%R5V5E:R@G,C<G+"`G,3$G
M+"`G,C`P,"<I+"`G9V5T0V%L96YD87)7965K(#,@<W1R)RD["@HD97AP(#T@
M87)R87DH"B`@("!A<G)A>2@*("`@("`@("`G,C`P,#$P,S`G+`H@("`@("`@
M("<R,#`P,3`S,2<L"B`@("`@("`@)S(P,#`Q,3`Q)RP*("`@("`@("`G,C`P
M,#$Q,#(G+`H@("`@("`@("<R,#`P,3$P,R<L"B`@("`@("`@)S(P,#`Q,3`T
M)RP*("`@("DL"B`@("!A<G)A>2@*("`@("`@("`G,C`P,#$Q,#4G+`H@("`@
M("`@("<R,#`P,3$P-B<L"B`@("`@("`@)S(P,#`Q,3`W)RP*("`@("`@("`G
M,C`P,#$Q,#@G+`H@("`@("`@("<R,#`P,3$P.2<L"B`@("`@("`@)S(P,#`Q
M,3$P)RP*("`@("`@("`G,C`P,#$Q,3$G+`H@("`@*2P*("`@(&%R<F%Y*`H@
M("`@("`@("<R,#`P,3$Q,B<L"B`@("`@("`@)S(P,#`Q,3$S)RP*("`@("`@
M("`G,C`P,#$Q,30G+`H@("`@("`@("<R,#`P,3$Q-2<L"B`@("`@("`@)S(P
M,#`Q,3$V)RP*("`@("`@("`G,C`P,#$Q,3<G+`H@("`@("`@("<R,#`P,3$Q
M."<L"B`@("`I+`H@("`@87)R87DH"B`@("`@("`@)S(P,#`Q,3$Y)RP*("`@
M("`@("`G,C`P,#$Q,C$G+`H@("`@("`@("<R,#`P,3$R,B<L"B`@("`@("`@
M)S(P,#`Q,3(S)RP*("`@("`@("`G,C`P,#$Q,C0G+`H@("`@("`@("<R,#`P
M,3$R-2<L"B`@("`@("`@)S(P,#`Q,3(V)RP*("`@("DL"B`@("!A<G)A>2@*
M("`@("`@("`G,C`P,#$Q,C<G+`H@("`@("`@("<R,#`P,3$R."<L"B`@("`@
M("`@)S(P,#`Q,3(Y)RP*("`@("`@("`G,C`P,#$Q,S`G+`H@("`@("`@("<R
M,#`P,3(P,2<L"B`@("`@("`@)S(P,#`Q,C`R)RP*("`@("`@("`G,C`P,#$R
M,#,G"B`@("`I"BD["F-O;7!A<F4H)&5X<"P@1&%T95]#86QC.CIG971#86QE
M;F1A<DUO;G1H*#$Q+"`R,#`P*2P@)V=E=$-A;&5N9&%R36]N=&@G*3L*8V]M
M<&%R92@D97AP+"!$871E7T-A;&,Z.F=E=$-A;&5N9&%R36]N=&@H)S$Q)RP@
M)S(P,#`G*2P@)V=E=$-A;&5N9&%R36]N=&@@<W1R)RD["@HO+R!)(&1O;B=T
M(&9E96P@;&EK92!D96%L:6YG('=I=&@@=&AI<R!R:6=H="!N;W<N+BX*+R]C
M;VUP87)E*"<G+"!$871E7T-A;&,Z.F=E=$-A;&5N9&%R665A<B@R,#`P*2P@
M)V=E=$-A;&5N9&%R665A<B<I.PH*8V]M<&%R92@G,C`P,#$Q,C$G+"!$871E
M7T-A;&,Z.G!R979$87DH,C(L(#$Q+"`R,#`P*2P@)W!R979$87DG*3L*8V]M
M<&%R92@G,C`P,#$Q,C,G+"!$871E7T-A;&,Z.FYE>'1$87DH,C(L(#$Q+"`R
M,#`P*2P@)VYE>'1$87DG*3L*8V]M<&%R92@G,C`P,#$Q,C$G+"!$871E7T-A
M;&,Z.G!R979$87DH,C(L(#$Q+"`R,#`P*2P@)W!R979$87D@<W1R)RD["F-O
M;7!A<F4H)S(P,#`Q,3(S)RP@1&%T95]#86QC.CIN97AT1&%Y*"<R,B<L("<Q
M,2<L("<R,#`P)RDL("=N97AT1&%Y('-T<B<I.PH*8V]M<&%R92@G,C`P,#$Q
M,3<G+"!$871E7T-A;&,Z.G!R9797965K9&%Y*"<Q.2<L("<Q,2<L("<R,#`P
M)RDL("=P<F5V5V5E:V1A>2`Q('-T<B<I.PIC;VUP87)E*"<R,#`P,3$Q-R<L
M($1A=&5?0V%L8SHZ<')E=E=E96MD87DH,3DL(#$Q+"`R,#`P*2P@)W!R9797
M965K9&%Y(#$G*3L*8V]M<&%R92@G,C`P,#$Q,C$G+"!$871E7T-A;&,Z.G!R
M9797965K9&%Y*#(R+"`Q,2P@,C`P,"DL("=P<F5V5V5E:V1A>2`R)RD["F-O
M;7!A<F4H)S(P,#`Q,3(S)RP@1&%T95]#86QC.CIN97AT5V5E:V1A>2@R,BP@
M,3$L(#(P,#`I+"`G;F5X=%=E96MD87D@,2<I.PIC;VUP87)E*"<R,#`P,3$R
M-R<L($1A=&5?0V%L8SHZ;F5X=%=E96MD87DH,C0L(#$Q+"`R,#`P*2P@)VYE
M>'17965K9&%Y(#(G*3L*8V]M<&%R92@G,C`P,#$Q,C<G+"!$871E7T-A;&,Z
M.FYE>'17965K9&%Y*"<R-"<L("<Q,2<L("<R,#`P)RDL("=N97AT5V5E:V1A
M>2`R('-T<B<I.PH*8V]M<&%R92@G,C`P,#$Q,C$G+"!$871E7T-A;&,Z.G!R
M979$87E/9E=E96LH)S(G+"`G,C(G+"`G,3$G+"`G,C`P,"<I+"`G<')E=D1A
M>4]F5V5E:R`Q('-T<B<I.PIC;VUP87)E*"<R,#`P,3$R,2<L($1A=&5?0V%L
M8SHZ<')E=D1A>4]F5V5E:R@R+"`R,BP@,3$L(#(P,#`I+"`G<')E=D1A>4]F
M5V5E:R`Q)RD["F-O;7!A<F4H)S(P,#`Q,3$U)RP@1&%T95]#86QC.CIP<F5V
M1&%Y3V97965K*#,L(#(R+"`Q,2P@,C`P,"DL("=P<F5V1&%Y3V97965K(#(G
M*3L*8V]M<&%R92@G,C`P,#$Q,C(G+"!$871E7T-A;&,Z.G!R979$87E/9E=E
M96LH,RP@,C(L(#$Q+"`R,#`P+"`G)5DE;25D)RP@=')U92DL("=P<F5V1&%Y
M3V97965K(#,G*3L*8V]M<&%R92@G,C`P,#$Q,C(G+"!$871E7T-A;&,Z.FYE
M>'1$87E/9E=E96LH,RP@,C(L(#$Q+"`R,#`P+"`G)5DE;25D)RP@=')U92DL
M("=N97AT1&%Y3V97965K(#$G*3L*8V]M<&%R92@G,C`P,#$Q,CDG+"!$871E
M7T-A;&,Z.FYE>'1$87E/9E=E96LH,RP@,C(L(#$Q+"`R,#`P*2P@)VYE>'1$
M87E/9E=E96L@,B<I.PIC;VUP87)E*"<R,#`P,3$R,R<L($1A=&5?0V%L8SHZ
M;F5X=$1A>4]F5V5E:R@T+"`R,BP@,3$L(#(P,#`I+"`G;F5X=$1A>4]F5V5E
M:R`S)RD["F-O;7!A<F4H)S(P,#`Q,3(S)RP@1&%T95]#86QC.CIN97AT1&%Y
M3V97965K*"<T)RP@)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)VYE>'1$87E/9E=E
M96L@,R!S='(G*3L*"F-O;7!A<F4H)S(P,#`Q,3(Q)RP@1&%T95]#86QC.CIP
M<F5V1&%Y3V97965K3VY/<D)E9F]R92@G,B<L("<R,B<L("<Q,2<L("<R,#`P
M)RDL("=P<F5V1&%Y3V97965K3VY/<D)E9F]R92`Q('-T<B<I.PIC;VUP87)E
M*"<R,#`P,3$R,2<L($1A=&5?0V%L8SHZ<')E=D1A>4]F5V5E:T]N3W)"969O
M<F4H,BP@,C(L(#$Q+"`R,#`P*2P@)W!R979$87E/9E=E96M/;D]R0F5F;W)E
M(#$G*3L*8V]M<&%R92@G,C`P,#$Q,C(G+"!$871E7T-A;&,Z.G!R979$87E/
M9E=E96M/;D]R0F5F;W)E*#,L(#(R+"`Q,2P@,C`P,"DL("=P<F5V1&%Y3V97
M965K3VY/<D)E9F]R92`R)RD["F-O;7!A<F4H)S(P,#`Q,3(R)RP@1&%T95]#
M86QC.CIN97AT1&%Y3V97965K3VY/<D%F=&5R*#,L(#(R+"`Q,2P@,C`P,"DL
M("=N97AT1&%Y3V97965K3VY/<D%F=&5R(#$G*3L*8V]M<&%R92@G,C`P,#$Q
M,C,G+"!$871E7T-A;&,Z.FYE>'1$87E/9E=E96M/;D]R069T97(H-"P@,C(L
M(#$Q+"`R,#`P*2P@)VYE>'1$87E/9E=E96M/;D]R069T97(@,B<I.PIC;VUP
M87)E*"<R,#`P,3$R,R<L($1A=&5?0V%L8SHZ;F5X=$1A>4]F5V5E:T]N3W)!
M9G1E<B@G-"<L("<R,B<L("<Q,2<L("<R,#`P)RDL("=N97AT1&%Y3V97965K
M3VY/<D%F=&5R(#(@<W1R)RD["@IC;VUP87)E*"<R,#`P,3$R,"<L($1A=&5?
M0V%L8SHZ8F5G:6Y/9E=E96LH)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)V)E9VEN
M3V97965K('-T<B<I.PIC;VUP87)E*"<R,#`P,3$R,"<L($1A=&5?0V%L8SHZ
M8F5G:6Y/9E=E96LH,C(L(#$Q+"`R,#`P*2P@)V)E9VEN3V97965K)RD["F-O
M;7!A<F4H)S(P,#`Q,3(V)RP@1&%T95]#86QC.CIE;F1/9E=E96LH,C(L(#$Q
M+"`R,#`P*2P@)V5N9$]F5V5E:R<I.PIC;VUP87)E*"<R,#`P,3$R-B<L($1A
M=&5?0V%L8SHZ96YD3V97965K*"<R,B<L("<Q,2<L("<R,#`P)RDL("=E;F1/
M9E=E96L@<W1R)RD["@IC;VUP87)E*"<R,#`P,3$Q,R<L($1A=&5?0V%L8SHZ
M8F5G:6Y/9E!R9797965K*#(R+"`Q,2P@,C`P,"DL("=B96=I;D]F4')E=E=E
M96LG*3L*8V]M<&%R92@G,C`P,#$Q,C<G+"!$871E7T-A;&,Z.F)E9VEN3V9.
M97AT5V5E:R@R,BP@,3$L(#(P,#`I+"`G8F5G:6Y/9DYE>'17965K)RD["F-O
M;7!A<F4H)S(P,#`Q,3$S)RP@1&%T95]#86QC.CIB96=I;D]F4')E=E=E96LH
M)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)V)E9VEN3V90<F5V5V5E:R!S='(G*3L*
M8V]M<&%R92@G,C`P,#$Q,C<G+"!$871E7T-A;&,Z.F)E9VEN3V9.97AT5V5E
M:R@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G8F5G:6Y/9DYE>'17965K('-T<B<I
M.PH*8V]M<&%R92@G,C`P,#$Q,#$G+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT
M:"@Q,2P@,C`P,"DL("=B96=I;D]F36]N=&@G*3L*8V]M<&%R92@G,C`P,#$Q
M,#$G+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT:"@G,3$G+"`G,C`P,"<I+"`G
M8F5G:6Y/9DUO;G1H('-T<B<I.PH*8V]M<&%R92@G,C`P,#$P,#$G+"!$871E
M7T-A;&,Z.F)E9VEN3V90<F5V36]N=&@H,C(L(#$Q+"`R,#`P*2P@)V)E9VEN
M3V90<F5V36]N=&@G*3L*8V]M<&%R92@G,C`P,#$P,S$G+"!$871E7T-A;&,Z
M.F5N9$]F4')E=DUO;G1H*#(R+"`Q,2P@,C`P,"DL("=E;F1/9E!R979-;VYT
M:"<I.PIC;VUP87)E*"<R,#`P,3`P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9E!R
M979-;VYT:"@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G8F5G:6Y/9E!R979-;VYT
M:"!S='(G*3L*8V]M<&%R92@G,C`P,#$P,S$G+"!$871E7T-A;&,Z.F5N9$]F
M4')E=DUO;G1H*"<R,B<L("<Q,2<L("<R,#`P)RDL("=E;F1/9E!R979-;VYT
M:"!S='(G*3L*"F-O;7!A<F4H)S(P,#`Q,C`Q)RP@1&%T95]#86QC.CIB96=I
M;D]F3F5X=$UO;G1H*#(R+"`Q,2P@,C`P,"DL("=B96=I;D]F3F5X=$UO;G1H
M)RD["F-O;7!A<F4H)S(P,#`Q,C,Q)RP@1&%T95]#86QC.CIE;F1/9DYE>'1-
M;VYT:"@R,BP@,3$L(#(P,#`I+"`G96YD3V9.97AT36]N=&@G*3L*8V]M<&%R
M92@G,C`P,#$R,#$G+"!$871E7T-A;&,Z.F)E9VEN3V9.97AT36]N=&@H)S(R
M)RP@)S$Q)RP@)S(P,#`G*2P@)V)E9VEN3V9.97AT36]N=&@@<W1R)RD["F-O
M;7!A<F4H)S(P,#`Q,C,Q)RP@1&%T95]#86QC.CIE;F1/9DYE>'1-;VYT:"@G
M,C(G+"`G,3$G+"`G,C`P,"<I+"`G96YD3V9.97AT36]N=&@@<W1R)RD["@IC
M;VUP87)E*"<Q.3DY,3`P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO;G1H0GE3
M<&%N*"TQ,RP@,3$L(#(P,#`I+"`G8F5G:6Y/9DUO;G1H0GE3<&%N(#$G*3L*
M8V]M<&%R92@G,C`P,#$P,#$G+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT:$)Y
M4W!A;B@M,2P@,3$L(#(P,#`I+"`G8F5G:6Y/9DUO;G1H0GE3<&%N(#(G*3L*
M8V]M<&%R92@G,C`P,#$Q,#$G+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT:$)Y
M4W!A;B@P+"`Q,2P@,C`P,"DL("=B96=I;D]F36]N=&A">5-P86X@,R<I.PIC
M;VUP87)E*"<R,#`P,3(P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO;G1H0GE3
M<&%N*#$L(#$Q+"`R,#`P*2P@)V)E9VEN3V9-;VYT:$)Y4W!A;B`T)RD["F-O
M;7!A<F4H)S(P,#$Q,C`Q)RP@1&%T95]#86QC.CIB96=I;D]F36]N=&A">5-P
M86XH,3,L(#$Q+"`R,#`P*2P@)V)E9VEN3V9-;VYT:$)Y4W!A;B`U)RD["@IC
M;VUP87)E*"<Q.3DY,#$P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO;G1H0GE3
M<&%N*"<M,3,G+"`G,#(G+"`G,C`P,"<I+"`G8F5G:6Y/9DUO;G1H0GE3<&%N
M(#8@<W1R)RD["F-O;7!A<F4H)S$Y.3DP,3`Q)RP@1&%T95]#86QC.CIB96=I
M;D]F36]N=&A">5-P86XH+3$S+"`R+"`R,#`P*2P@)V)E9VEN3V9-;VYT:$)Y
M4W!A;B`V)RD["F-O;7!A<F4H)S(P,#`P,3`Q)RP@1&%T95]#86QC.CIB96=I
M;D]F36]N=&A">5-P86XH+3$L(#(L(#(P,#`I+"`G8F5G:6Y/9DUO;G1H0GE3
M<&%N(#<G*3L*8V]M<&%R92@G,C`P,#`R,#$G+"!$871E7T-A;&,Z.F)E9VEN
M3V9-;VYT:$)Y4W!A;B@P+"`R+"`R,#`P*2P@)V)E9VEN3V9-;VYT:$)Y4W!A
M;B`X)RD["F-O;7!A<F4H)S(P,#`P,S`Q)RP@1&%T95]#86QC.CIB96=I;D]F
M36]N=&A">5-P86XH,2P@,BP@,C`P,"DL("=B96=I;D]F36]N=&A">5-P86X@
M.2<I.PIC;VUP87)E*"<R,#`Q,#,P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO
M;G1H0GE3<&%N*#$S+"`R+"`R,#`P*2P@)V)E9VEN3V9-;VYT:$)Y4W!A;B`Q
M,"<I.PIC;VUP87)E*"<R,#`Q,#,P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO
M;G1H0GE3<&%N*"<Q,R<L("<P,B<L("<R,#`P)RDL("=B96=I;D]F36]N=&A"
M>5-P86X@,3`@<W1R)RD["@IC;VUP87)E*"<Q.3DY,3`S,2<L($1A=&5?0V%L
M8SHZ96YD3V9-;VYT:$)Y4W!A;B@M,3,L(#$Q+"`R,#`P*2P@)V5N9$]F36]N
M=&A">5-P86X@,2<I.PIC;VUP87)E*"<R,#`P,3`S,2<L($1A=&5?0V%L8SHZ
M96YD3V9-;VYT:$)Y4W!A;B@M,2P@,3$L(#(P,#`I+"`G96YD3V9-;VYT:$)Y
M4W!A;B`R)RD["F-O;7!A<F4H)S(P,#`Q,3,P)RP@1&%T95]#86QC.CIE;F1/
M9DUO;G1H0GE3<&%N*#`L(#$Q+"`R,#`P*2P@)V5N9$]F36]N=&A">5-P86X@
M,R<I.PIC;VUP87)E*"<R,#`P,3(S,2<L($1A=&5?0V%L8SHZ96YD3V9-;VYT
M:$)Y4W!A;B@Q+"`Q,2P@,C`P,"DL("=E;F1/9DUO;G1H0GE3<&%N(#0G*3L*
M8V]M<&%R92@G,C`P,3$R,S$G+"!$871E7T-A;&,Z.F5N9$]F36]N=&A">5-P
M86XH,3,L(#$Q+"`R,#`P*2P@)V5N9$]F36]N=&A">5-P86X@-2<I.PH*8V]M
M<&%R92@G,3DY.3`Q,S$G+"!$871E7T-A;&,Z.F5N9$]F36]N=&A">5-P86XH
M)RTQ,R<L("<P,B<L("<R,#`P)RDL("=E;F1/9DUO;G1H0GE3<&%N(#8@<W1R
M)RD["F-O;7!A<F4H)S$Y.3DP,3,Q)RP@1&%T95]#86QC.CIE;F1/9DUO;G1H
M0GE3<&%N*"TQ,RP@,BP@,C`P,"DL("=E;F1/9DUO;G1H0GE3<&%N(#8G*3L*
M8V]M<&%R92@G,C`P,#`Q,S$G+"!$871E7T-A;&,Z.F5N9$]F36]N=&A">5-P
M86XH+3$L(#(L(#(P,#`I+"`G96YD3V9-;VYT:$)Y4W!A;B`W)RD["F-O;7!A
M<F4H)S(P,#`P,C(Y)RP@1&%T95]#86QC.CIE;F1/9DUO;G1H0GE3<&%N*#`L
M(#(L(#(P,#`I+"`G96YD3V9-;VYT:$)Y4W!A;B`X)RD["F-O;7!A<F4H)S(P
M,#`P,S,Q)RP@1&%T95]#86QC.CIE;F1/9DUO;G1H0GE3<&%N*#$L(#(L(#(P
M,#`I+"`G96YD3V9-;VYT:$)Y4W!A;B`Y)RD["F-O;7!A<F4H)S(P,#$P,S,Q
M)RP@1&%T95]#86QC.CIE;F1/9DUO;G1H0GE3<&%N*#$S+"`R+"`R,#`P*2P@
M)V5N9$]F36]N=&A">5-P86X@,3`G*3L*8V]M<&%R92@G,C`P,3`S,S$G+"!$
M871E7T-A;&,Z.F5N9$]F36]N=&A">5-P86XH)S$S)RP@)S`R)RP@)S(P,#`G
M*2P@)V5N9$]F36]N=&A">5-P86X@,3`@<W1R)RD["@IC;VUP87)E*#,L($1A
M=&5?0V%L8SHZ9FER<W1/9DUO;G1H5V5E:V1A>2@Q,2P@,C`P,"DL("=F:7)S
M=$]F36]N=&A7965K9&%Y)RD["F-O;7!A<F4H,RP@1&%T95]#86QC.CIF:7)S
M=$]F36]N=&A7965K9&%Y*"<Q,2<L("<R,#`P)RDL("=F:7)S=$]F36]N=&A7
M965K9&%Y('-T<B<I.PH*8V]M<&%R92@G,C`P-3`Q,#$G+"!$871E7T-A;&,Z
M.DY7965K9&%Y3V9-;VYT:"@Q+"`V+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-
M;VYT:"`Q-C$G*3L*8V]M<&%R92@G,C`P-3`Q,#(G+"!$871E7T-A;&,Z.DY7
M965K9&%Y3V9-;VYT:"@Q+"`P+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT
M:"`Q,#$G*3L*8V]M<&%R92@G,C`P-3`Q,#,G+"!$871E7T-A;&,Z.DY7965K
M9&%Y3V9-;VYT:"@Q+"`Q+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"`Q
M,3$G*3L*8V]M<&%R92@G,C`P-3`Q,#0G+"!$871E7T-A;&,Z.DY7965K9&%Y
M3V9-;VYT:"@Q+"`R+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"`Q,C$G
M*3L*8V]M<&%R92@G,C`P-3`Q,#4G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-
M;VYT:"@Q+"`S+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"`Q,S$G*3L*
M8V]M<&%R92@G,C`P-3`Q,#8G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT
M:"@Q+"`T+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"`Q-#$G*3L*8V]M
M<&%R92@G,C`P-3`Q,#<G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@Q
M+"`U+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"`Q-3$G*3L*"F-O;7!A
M<F4H)S(P,#4P,3`X)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)S(G
M+"`G-B<L("<P,2<L("<R,#`U)RDL("=.5V5E:V1A>4]F36]N=&@@,C8Q)RD[
M"F-O;7!A<F4H)S(P,#4P,3`Y)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N
M=&@H)S(G+"`G,"<L("<P,2<L("<R,#`U)RDL("=.5V5E:V1A>4]F36]N=&@@
M,C`Q)RD["F-O;7!A<F4H)S(P,#4P,3$P)RP@1&%T95]#86QC.CI.5V5E:V1A
M>4]F36]N=&@H)S(G+"`G,2<L("<P,2<L("<R,#`U)RDL("=.5V5E:V1A>4]F
M36]N=&@@,C$Q)RD["F-O;7!A<F4H)S(P,#4P,3$Q)RP@1&%T95]#86QC.CI.
M5V5E:V1A>4]F36]N=&@H)S(G+"`G,B<L("<P,2<L("<R,#`U)RDL("=.5V5E
M:V1A>4]F36]N=&@@,C(Q)RD["F-O;7!A<F4H)S(P,#4P,3$R)RP@1&%T95]#
M86QC.CI.5V5E:V1A>4]F36]N=&@H)S(G+"`G,R<L("<P,2<L("<R,#`U)RDL
M("=.5V5E:V1A>4]F36]N=&@@,C,Q)RD["F-O;7!A<F4H)S(P,#4P,3$S)RP@
M1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)S(G+"`G-"<L("<P,2<L("<R
M,#`U)RDL("=.5V5E:V1A>4]F36]N=&@@,C0Q)RD["F-O;7!A<F4H)S(P,#4P
M,3$T)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)S(G+"`G-2<L("<P
M,2<L("<R,#`U)RDL("=.5V5E:V1A>4]F36]N=&@@,C4Q)RD["@IC;VUP87)E
M*"<R,#`U,#$S,2<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"=L87-T
M)RP@,2P@,2P@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@;#$Q)RD["F-O;7!A
M<F4H)S(P,#4P,3,P)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)VQA
M<W0G+"`P+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"!L,#$G*3L*8V]M
M<&%R92@G,C`P-3`Q,CDG+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G
M;&%S="<L(#8L(#$L(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(&PV,2<I.PIC
M;VUP87)E*"<R,#`U,#$R."<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H
M*"=L87-T)RP@-2P@,2P@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@;#4Q)RD[
M"F-O;7!A<F4H)S(P,#4P,3(W)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N
M=&@H)VQA<W0G+"`T+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"!L-#$G
M*3L*8V]M<&%R92@G,C`P-3`Q,C8G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-
M;VYT:"@G;&%S="<L(#,L(#$L(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(&PS
M,2<I.PIC;VUP87)E*"<R,#`U,#$R-2<L($1A=&5?0V%L8SHZ3E=E96MD87E/
M9DUO;G1H*"=L87-T)RP@,BP@,2P@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@
M;#(Q)RD["@IC;VUP87)E*"<R,#`U,#,S,2<L($1A=&5?0V%L8SHZ3E=E96MD
M87E/9DUO;G1H*"=L87-T)RP@-"P@,RP@,C`P-2DL("=.5V5E:V1A>4]F36]N
M=&@@;#0S)RD["F-O;7!A<F4H)S(P,#4P,S,P)RP@1&%T95]#86QC.CI.5V5E
M:V1A>4]F36]N=&@H)VQA<W0G+"`S+"`S+"`R,#`U*2P@)TY7965K9&%Y3V9-
M;VYT:"!L,S,G*3L*8V]M<&%R92@G,C`P-3`S,CDG+"!$871E7T-A;&,Z.DY7
M965K9&%Y3V9-;VYT:"@G;&%S="<L(#(L(#,L(#(P,#4I+"`G3E=E96MD87E/
M9DUO;G1H(&PR,R<I.PIC;VUP87)E*"<R,#`U,#,R."<L($1A=&5?0V%L8SHZ
M3E=E96MD87E/9DUO;G1H*"=L87-T)RP@,2P@,RP@,C`P-2DL("=.5V5E:V1A
M>4]F36]N=&@@;#$S)RD["F-O;7!A<F4H)S(P,#4P,S(W)RP@1&%T95]#86QC
M.CI.5V5E:V1A>4]F36]N=&@H)VQA<W0G+"`P+"`S+"`R,#`U*2P@)TY7965K
M9&%Y3V9-;VYT:"!L,#,G*3L*8V]M<&%R92@G,C`P-3`S,C8G+"!$871E7T-A
M;&,Z.DY7965K9&%Y3V9-;VYT:"@G;&%S="<L(#8L(#,L(#(P,#4I+"`G3E=E
M96MD87E/9DUO;G1H(&PV,R<I.PIC;VUP87)E*"<R,#`U,#,R-2<L($1A=&5?
M0V%L8SHZ3E=E96MD87E/9DUO;G1H*"=L87-T)RP@-2P@,RP@,C`P-2DL("=.
M5V5E:V1A>4]F36]N=&@@;#4S)RD["@H*8V]M<&%R92AF86QS92P@1&%T95]#
M86QC.CII<U9A;&ED1&%T92@R.2P@,BP@,3DP,"DL("=I<U9A;&ED1&%T92`Q
M)RD["F-O;7!A<F4H=')U92P@1&%T95]#86QC.CII<U9A;&ED1&%T92@R.2P@
M,BP@,C`P,"DL("=I<U9A;&ED1&%T92`R)RD["F-O;7!A<F4H=')U92P@1&%T
M95]#86QC.CII<U9A;&ED1&%T92@G,CDG+"`G,#(G+"`G,C`P,"<I+"`G:7-6
M86QI9$1A=&4@,B!S='(G*3L*"F-O;7!A<F4H9F%L<V4L($1A=&5?0V%L8SHZ
M:7-,96%P665A<B@Q.3`P*2P@)VES3&5A<%EE87(@,2<I.PIC;VUP87)E*'1R
M=64L($1A=&5?0V%L8SHZ:7-,96%P665A<B@Q.3DV*2P@)VES3&5A<%EE87(@
M,B<I.PIC;VUP87)E*'1R=64L($1A=&5?0V%L8SHZ:7-,96%P665A<B@R,#`P
M*2P@)VES3&5A<%EE87(@,R<I.PIC;VUP87)E*&9A;'-E+"!$871E7T-A;&,Z
M.FES3&5A<%EE87(H,C`P,2DL("=I<TQE87!996%R(#0G*3L*8V]M<&%R92AF
M86QS92P@1&%T95]#86QC.CII<TQE87!996%R*"<R,#`Q)RDL("=I<TQE87!9
M96%R(#0@<W1R)RD["@IC;VUP87)E*&9A;'-E+"!$871E7T-A;&,Z.FES1G5T
M=7)E1&%T92@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G:7-&=71U<F5$871E(#$@
M<W1R)RD["F-O;7!A<F4H9F%L<V4L($1A=&5?0V%L8SHZ:7-&=71U<F5$871E
M*#(R+"`Q,2P@,C`P,"DL("=I<T9U='5R941A=&4@,2<I.PIC;VUP87)E*'1R
M=64L($1A=&5?0V%L8SHZ:7-&=71U<F5$871E*#(R+"`Q,2P@9&%T92@G62<I
M("L@,2DL("=I<T9U='5R941A=&4@,B<I.PH*8V]M<&%R92AF86QS92P@1&%T
M95]#86QC.CII<U!A<W1$871E*#(R+"`Q,2P@9&%T92@G62<I("L@,2DL("=I
M<U!A<W1$871E(#$G*3L*8V]M<&%R92AT<G5E+"!$871E7T-A;&,Z.FES4&%S
M=$1A=&4H,C(L(#$Q+"`R,#`P*2P@)VES4&%S=$1A=&4@,B<I.PIC;VUP87)E
M*'1R=64L($1A=&5?0V%L8SHZ:7-087-T1&%T92@G,C(G+"`G,3$G+"`G,C`P
M,"<I+"`G:7-087-T1&%T92`R('-T<B<I.PH*8V]M<&%R92@Q,"P@1&%T95]#
M86QC.CID871E1&EF9B@R,BP@,3$L(#(P,#`L(#$R+"`Q,2P@,C`P,"DL("=D
M871E1&EF9B`Q)RD["F-O;7!A<F4H,3`L($1A=&5?0V%L8SHZ9&%T941I9F8H
M,3(L(#$Q+"`R,#`P+"`R,BP@,3$L(#(P,#`I+"`G9&%T941I9F8@,B<I.PIC
M;VUP87)E*#8Q+"!$871E7T-A;&,Z.F1A=&5$:69F*#(R+"`Q,2P@,C`P,"P@
M,C(L(#$L(#(P,#$I+"`G9&%T941I9F8@,R<I.PIC;VUP87)E*#8Q+"!$871E
M7T-A;&,Z.F1A=&5$:69F*"<R,B<L("<Q,2<L("<R,#`P)RP@)S(R)RP@)S`Q
M)RP@)S(P,#$G*2P@)V1A=&5$:69F(#,@<W1R)RD["@IC;VUP87)E*"TQ+"!$
M871E7T-A;&,Z.F-O;7!A<F5$871E<R@Q,BP@,3$L(#(P,#`L(#(R+"`Q,2P@
M,C`P,"DL("=C;VUP87)E1&%T97,@,2<I.PIC;VUP87)E*#`L($1A=&5?0V%L
M8SHZ8V]M<&%R941A=&5S*#(R+"`Q,2P@,C`P,"P@,C(L(#$Q+"`R,#`P*2P@
M)V-O;7!A<F5$871E<R`R)RD["F-O;7!A<F4H,2P@1&%T95]#86QC.CIC;VUP
M87)E1&%T97,H,C(L(#$Q+"`R,#`P+"`Q,BP@,3$L(#(P,#`I+"`G8V]M<&%R
M941A=&5S(#,G*3L*8V]M<&%R92@Q+"!$871E7T-A;&,Z.F-O;7!A<F5$871E
M<R@G,C(G+"`G,3$G+"`G,C`P,"<L("<Q,B<L("<Q,2<L("<R,#`P)RDL("=C
M;VUP87)E1&%T97,@,R!S='(G*3L*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S
M+V-A;&,N<&AP+F]R:6<`````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`T-#0W,``Q
M,#4Q-30S,S<T,@`P,C0S-#<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A
M8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*+R\*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC
M*2`Q.3DW+3(P,#4@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T
M/B`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=&AE($YE=R!"
M4T0@;&EC96YS92P@5&AA="!I<R!B=6YD;&5D("!\"B\O('P@=VET:"!T:&ES
M('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES(&%V86EL86)L
M92!T:')O=6=H("`@("`@?`HO+R!\('1H92!W;W)L9"UW:61E+7=E8B!A="`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S
M9"UL:6-E;G-E+G!H<"`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(&YE=R!"4T1L:6-E;G-E
M(&%N9"!A<F4@=6YA8FQE("`@?`HO+R!\('1O(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@
M("`@('P*+R\@?"!P96%R+61E=D!L:7-T<RYP:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@1&%N:65L($-O
M;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\J*@H@
M*B!497-T<R!F;W(@=&AE($1A=&5?0V%L8R!C;&%S<PH@*@H@*B!!;GD@:6YD
M:79I9'5A;"!T97-T<R!T:&%T(&9A:6P@=VEL;"!H879E('1H96ER(&YA;64L
M(&5X<&5C=&5D(')E<W5L=`H@*B!A;F0@86-T=6%L(')E<W5L="!P<FEN=&5D
M(&]U="X@(%-O('-E96EN9R!N;R!O=71P=70@=VAE;B!E>&5C=71I;F<*("H@
M=&AI<R!F:6QE(&ES(&$@9V]O9"!T:&EN9RX*("H*("H@0V%N(&)E(')U;B!V
M:6$@0TQ)(&]R(&$@=V5B('-E<G9E<BX*("H*("H@5&AI<R!T97-T('-E;G-E
M<R!W:&5T:&5R(&ET(&ES(&9R;VT@86X@:6YS=&%L;&%T:6]N(&]F(%!%05(Z
M.D1A=&4@;W(@:68*("H@:70G<R!F<F]M($-64R!O<B!A("YT87(@9FEL92X@
M($EF(&ET)W,@86X@:6YS=&%L;&5D('9E<G-I;VXL('5S92!T:&4*("H@:6YS
M=&%L;&5D('9E<G-I;VX@;V8@1&%T95]#86QC+B`@3W1H97)W:7-E+"!U<V4@
M=&AE(&QO8V%L(&1E=F5L;W!M96YT"B`J(&-O<'D@;V8@1&%T95]#86QC+@H@
M*@H@*B!`8V%T96=O<GD@("!$871E(&%N9"!4:6UE"B`J($!P86-K86=E("`@
M($1A=&4*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L
M8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`R,#`U(%1H92!02%`@1W)O=7`*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(&-A
M;&,N<&AP+'8@,2XX(#(P,#4O,3$O,34@,#`Z,38Z-#`@<&%J;WEE($5X<"`D
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$
M871E"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XU"B`J+PH*:68@*"<O:&]M92]L=6-E<B]W;W)K+W!E87(O<VAA<F4O
M<&AP)R`A/2`G0"<N)VEN8VQU9&5?<&%T:"<N)T`G*2!["B`@("!I;FE?<V5T
M*"=I;F-L=61E7W!A=&@G+"!I;FE?9V5T*"=I;F-L=61E7W!A=&@G*0H@("`@
M("`@("`@("`N(%!!5$A?4T5005)!5$]2("X@)RXG"B`@("`I.PI](&5L<V4@
M>PH@("`@:6YI7W-E="@G:6YC;'5D95]P871H)RP@<F5A;'!A=&@H9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+RXN+R<I"B`@("`@("`@("`@("X@4$%42%]315!!
M4D%43U(@+B`G+B<@+B!0051(7U-%4$%2051/4@H@("`@("`@("`@("`N(&EN
M:5]G970H)VEN8VQU9&5?<&%T:"<I"B`@("`I.PI]"@HO*BH*("H@1V5T('1H
M92!N965D960@8VQA<W,*("HO"G)E<75I<F5?;VYC92`G1&%T92]#86QC+G!H
M<"<["@HO*BH*("H@0V]M<&%R92!T:&4@=&5S="!R97-U;'0@=&\@=&AE(&5X
M<&5C=&5D(')E<W5L=`H@*@H@*B!)9B!T:&4@=&5S="!F86EL<RP@96-H;R!O
M=70@=&AE(')E<W5L=',N"B`J"B`J($!P87)A;2!M:7AE9"`@)&5X<&5C="`@
M("`@=&AE('-C86QA<B!O<B!A<G)A>2!Y;W4@97AP96-T(&9R;VT@=&AE('1E
M<W0*("H@0'!A<F%M(&UI>&5D("`D86-T=6%L("`@("!T:&4@<V-A;&%R(&]R
M(&%R<F%Y(')E<W5L=',@9G)O;2!T:&4@=&5S=`H@*B!`<&%R86T@<W1R:6YG
M("1T97-T7VYA;64@('1H92!N86UE(&]F('1H92!T97-T"B`J"B`J($!R971U
M<FX@=F]I9`H@*B\*9G5N8W1I;VX@8V]M<&%R92@D97AP96-T+"`D86-T=6%L
M+"`D=&5S=%]N86UE*2!["B`@("!I9B`H:7-?87)R87DH)&5X<&5C="DI('L*
M("`@("`@("!I9B`H8V]U;G0H87)R87E?9&EF9B@D86-T=6%L+"`D97AP96-T
M*2DI('L*("`@("`@("`@("`@96-H;R`B)'1E<W1?;F%M92!F86EL960N("!%
M>'!E8W0Z7&XB.PH@("`@("`@("`@("!P<FEN=%]R*"1E>'!E8W0I.PH@("`@
M("`@("`@("!E8VAO(")!8W1U86PZ7&XB.PH@("`@("`@("`@("!P<FEN=%]R
M*"1A8W1U86PI.PH@("`@("`@('T*("`@('T@96QS92!["B`@("`@("`@:68@
M*"1E>'!E8W0@(3T@)&%C='5A;"D@>PH@("`@("`@("`@("!E8VAO("(D=&5S
M=%]N86UE(&9A:6QE9"X@($5X<&5C=#H@)&5X<&5C="X@($%C='5A;#H@)&%C
M='5A;%QN(CL*("`@("`@("!]"B`@("!]"GT*"FEF("AP:'!?<V%P:5]N86UE
M*"D@(3T@)V-L:2<I('L*("`@(&5C:&\@(CQP<F4^7&XB.PI]"@H*8V]M<&%R
M92@G,C`P,#$Q,C(G+"!$871E7T-A;&,Z.F1A=&5&;W)M870H,C(L(#$Q+"`R
M,#`P+"`G)5DE;25D)RDL("=D871E1F]R;6%T)RD["F-O;7!A<F4H)S(P,#`Q
M,3(R)RP@1&%T95]#86QC.CID871E1F]R;6%T*"<R,B<L("<Q,2<L("<R,#`P
M)RP@)R59)6TE9"<I+"`G9&%T949O<FUA="!S='(G*3L*"F-O;7!A<F4H)S(P
M,#$G+"!$871E7T-A;&,Z.F1E9F%U;'1#96YT=7)Y*"<Q)RDL("=D969A=6QT
M0V5N='5R>2`Q('-T<B<I.PIC;VUP87)E*"<R,#`Q)RP@1&%T95]#86QC.CID
M969A=6QT0V5N='5R>2@Q*2P@)V1E9F%U;'1#96YT=7)Y(#$G*3L*8V]M<&%R
M92@G,3DV,"<L($1A=&5?0V%L8SHZ9&5F875L=$-E;G1U<GDH-C`I+"`G9&5F
M875L=$-E;G1U<GD@,B<I.PIC;VUP87)E*"<R,#$P)RP@1&%T95]#86QC.CID
M969A=6QT0V5N='5R>2@Q,"DL("=D969A=6QT0V5N='5R>2`S)RD["@IC;VUP
M87)E*#(T-3$X-S$L($1A=&5?0V%L8SHZ9&%T951O1&%Y<R@G,C(G+"`G,3$G
M+"`G,C`P,"<I+"`G9&%T951O1&%Y<R!S='(G*3L*8V]M<&%R92@R-#4Q.#<Q
M+"!$871E7T-A;&,Z.F1A=&54;T1A>7,H,C(L(#$Q+"`R,#`P*2P@)V1A=&54
M;T1A>7,G*3L*8V]M<&%R92@G,C`P,#$Q,C(G+"!$871E7T-A;&,Z.F1A>7-4
M;T1A=&4H,C0U,3@W,2DL("=D87ES5&]$871E)RD["@IC;VUP87)E*"<R,#`P
M+30W+3,G+"!$871E7T-A;&,Z.F=R96=O<FEA;E1O25-/*"<R,B<L("<Q,2<L
M("<R,#`P)RDL("=G<F5G;W)I86Y4;TE33R!S='(G*3L*8V]M<&%R92@G,C`P
M,"TT-RTS)RP@1&%T95]#86QC.CIG<F5G;W)I86Y4;TE33R@R,BP@,3$L(#(P
M,#`I+"`G9W)E9V]R:6%N5&])4T\G*3L*8V]M<&%R92@R-#4Q-S$V+C4V-S8W
M+"!$871E7T-A;&,Z.F1A=&5396%S;VXH)U-534U%4E-/3%-424-%)RP@,C`P
M,"DL("=D871E4V5A<V]N)RD["@IC;VUP87)E*&1A=&4H)UEM9"<I+"!$871E
M7T-A;&,Z.F1A=&5.;W<H*2P@)V1A=&5.;W<G*3L*8V]M<&%R92AD871E*"=9
M)RDL($1A=&5?0V%L8SHZ9V5T665A<B@I+"`G9V5T665A<B<I.PIC;VUP87)E
M*&1A=&4H)VTG*2P@1&%T95]#86QC.CIG971-;VYT:"@I+"`G9V5T36]N=&@G
M*3L*8V]M<&%R92AD871E*"=D)RDL($1A=&5?0V%L8SHZ9V5T1&%Y*"DL("=G
M971$87DG*3L*"F-O;7!A<F4H,S(W+"!$871E7T-A;&,Z.FIU;&EA;D1A=&4H
M,C(L(#$Q+"`R,#`P*2P@)VIU;&EA;D1A=&4G*3L*8V]M<&%R92@G3F]V96UB
M97(G+"!$871E7T-A;&,Z.F=E=$UO;G1H1G5L;&YA;64H,3$I+"`G9V5T36]N
M=&A&=6QL;F%M92<I.PIC;VUP87)E*"=.;W8G+"!$871E7T-A;&,Z.F=E=$UO
M;G1H06)B<FYA;64H,3$I+"`G9V5T36]N=&A!8F)R;F%M92<I.PIC;VUP87)E
M*"=3871U<F1A>2<L($1A=&5?0V%L8SHZ9V5T5V5E:V1A>49U;&QN86UE*#$L
M(#$L(#(P,#4I+"`G9V5T5V5E:V1A>49U;&QN86UE)RD["F-O;7!A<F4H)U-A
M="<L($1A=&5?0V%L8SHZ9V5T5V5E:V1A>4%B8G)N86UE*#$L(#$L(#(P,#4I
M+"`G9V5T5V5E:V1A>4%B8G)N86UE)RD["F-O;7!A<F4H,3$L($1A=&5?0V%L
M8SHZ9V5T36]N=&A&<F]M1G5L;$YA;64H)TYO=F5M8F5R)RDL("=G971-;VYT
M:$9R;VU&=6QL3F%M92<I.PH*8V]M<&%R92@S,C<L($1A=&5?0V%L8SHZ:G5L
M:6%N1&%T92@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G:G5L:6%N1&%T92!S='(G
M*3L*8V]M<&%R92@G3F]V96UB97(G+"!$871E7T-A;&,Z.F=E=$UO;G1H1G5L
M;&YA;64H)S$Q)RDL("=G971-;VYT:$9U;&QN86UE('-T<B<I.PIC;VUP87)E
M*"=.;W8G+"!$871E7T-A;&,Z.F=E=$UO;G1H06)B<FYA;64H)S$Q)RDL("=G
M971-;VYT:$%B8G)N86UE('-T<B<I.PIC;VUP87)E*"=3871U<F1A>2<L($1A
M=&5?0V%L8SHZ9V5T5V5E:V1A>49U;&QN86UE*"<P,2<L("<P,2<L("<R,#`U
M)RDL("=G9717965K9&%Y1G5L;&YA;64@<W1R)RD["F-O;7!A<F4H)U-A="<L
M($1A=&5?0V%L8SHZ9V5T5V5E:V1A>4%B8G)N86UE*"<P,2<L("<P,2<L("<R
M,#`U)RDL("=G9717965K9&%Y06)B<FYA;64@<W1R)RD["@HD97AP(#T@87)R
M87DH"B`@("`G2F%N=6%R>2<L"B`@("`G1F5B<G5A<GDG+`H@("`@)TUA<F-H
M)RP*("`@("=!<')I;"<L"B`@("`G36%Y)RP*("`@("=*=6YE)RP*("`@("=*
M=6QY)RP*("`@("=!=6=U<W0G+`H@("`@)U-E<'1E;6)E<B<L"B`@("`G3V-T
M;V)E<B<L"B`@("`G3F]V96UB97(G+`H@("`@)T1E8V5M8F5R)PHI.PIC;VUP
M87)E*"1E>'`L($1A=&5?0V%L8SHZ9V5T36]N=&A.86UE<R@I+"`G9V5T36]N
M=&A.86UE<R<I.PH*)&5X<"`](&%R<F%Y*`H@("`@)TUO;F1A>2<L"B`@("`G
M5'5E<V1A>2<L"B`@("`G5V5D;F5S9&%Y)RP*("`@("=4:'5R<V1A>2<L"B`@
M("`G1G)I9&%Y)RP*("`@("=3871U<F1A>2<L"B`@("`G4W5N9&%Y)PHI.PIC
M;VUP87)E*"1E>'`L($1A=&5?0V%L8SHZ9V5T5V5E:T1A>7,H*2P@)V=E=%=E
M96M$87ES)RD["@IC;VUP87)E*#,L($1A=&5?0V%L8SHZ9&%Y3V97965K*#(R
M+"`Q,2P@,C`P,"DL("=D87E/9E=E96LG*3L*8V]M<&%R92@T-RP@1&%T95]#
M86QC.CIW965K3V9996%R*#(R+"`Q,2P@,C`P,"DL("=W965K3V9996%R)RD[
M"F-O;7!A<F4H-"P@1&%T95]#86QC.CIQ=6%R=&5R3V9996%R*#(R+"`Q,2P@
M,C`P,"DL("=Q=6%R=&5R3V9996%R)RD["@IC;VUP87)E*#,L($1A=&5?0V%L
M8SHZ9&%Y3V97965K*"<R,B<L("<Q,2<L("<R,#`P)RDL("=D87E/9E=E96L@
M<W1R)RD["F-O;7!A<F4H-#<L($1A=&5?0V%L8SHZ=V5E:T]F665A<B@G,C(G
M+"`G,3$G+"`G,C`P,"<I+"`G=V5E:T]F665A<B!S='(G*3L*8V]M<&%R92@T
M+"!$871E7T-A;&,Z.G%U87)T97)/9EEE87(H)S(R)RP@)S$Q)RP@)S(P,#`G
M*2P@)W%U87)T97)/9EEE87(@<W1R)RD["@IC;VUP87)E*#(X+"!$871E7T-A
M;&,Z.F1A>7-);DUO;G1H*#(L(#$Y,#`I+"`G9&%Y<TEN36]N=&@@,2<I.PIC
M;VUP87)E*#(Y+"!$871E7T-A;&,Z.F1A>7-);DUO;G1H*#(L(#$Y.38I+"`G
M9&%Y<TEN36]N=&@@,B<I.PIC;VUP87)E*#(Y+"!$871E7T-A;&,Z.F1A>7-)
M;DUO;G1H*#(L(#(P,#`I+"`G9&%Y<TEN36]N=&@@,R<I.PIC;VUP87)E*#(X
M+"!$871E7T-A;&,Z.F1A>7-);DUO;G1H*#(L(#(P,#$I+"`G9&%Y<TEN36]N
M=&@@-"<I.PIC;VUP87)E*#,P+"!$871E7T-A;&,Z.F1A>7-);DUO;G1H*#$Q
M+"`R,#`P*2P@)V1A>7-);DUO;G1H(#4G*3L*"F-O;7!A<F4H,C@L($1A=&5?
M0V%L8SHZ9&%Y<TEN36]N=&@H)S`R)RP@,3DP,"DL("=D87ES26Y-;VYT:"`Q
M('-T<B<I.PIC;VUP87)E*#(Y+"!$871E7T-A;&,Z.F1A>7-);DUO;G1H*"<P
M,B<L(#$Y.38I+"`G9&%Y<TEN36]N=&@@,B!S='(G*3L*8V]M<&%R92@R.2P@
M1&%T95]#86QC.CID87ES26Y-;VYT:"@G,#(G+"`R,#`P*2P@)V1A>7-);DUO
M;G1H(#,@<W1R)RD["F-O;7!A<F4H,C@L($1A=&5?0V%L8SHZ9&%Y<TEN36]N
M=&@H)S`R)RP@,C`P,2DL("=D87ES26Y-;VYT:"`T('-T<B<I.PIC;VUP87)E
M*#,P+"!$871E7T-A;&,Z.F1A>7-);DUO;G1H*"<Q,2<L("<R,#`P)RDL("=D
M87ES26Y-;VYT:"`U('-T<B<I.PH*8V]M<&%R92@U+"!$871E7T-A;&,Z.G=E
M96MS26Y-;VYT:"@Q,2P@,C`P,"DL("=W965K<TEN36]N=&@G*3L*8V]M<&%R
M92@U+"!$871E7T-A;&,Z.G=E96MS26Y-;VYT:"@G,3$G+"`G,C`P,"<I+"`G
M=V5E:W-);DUO;G1H('-T<B<I.PH*"B1E>'`@/2!A<G)A>2@*("`@("<Q.3`P
M,#(R-B<L"B`@("`G,3DP,#`R,C<G+`H@("`@)S$Y,#`P,C(X)RP*("`@("<Q
M.3`P,#,P,2<L"B`@("`G,3DP,#`S,#(G+`H@("`@)S$Y,#`P,S`S)RP*("`@
M("<Q.3`P,#,P-"<L"BD["F-O;7!A<F4H)&5X<"P@1&%T95]#86QC.CIG971#
M86QE;F1A<E=E96LH,C<L(#(L(#$Y,#`I+"`G9V5T0V%L96YD87)7965K(#$G
M*3L*"B1E>'`@/2!A<G)A>2@*("`@("<R,#`P,#(R."<L"B`@("`G,C`P,#`R
M,CDG+`H@("`@)S(P,#`P,S`Q)RP*("`@("<R,#`P,#,P,B<L"B`@("`G,C`P
M,#`S,#,G+`H@("`@)S(P,#`P,S`T)RP*("`@("<R,#`P,#,P-2<L"BD["F-O
M;7!A<F4H)&5X<"P@1&%T95]#86QC.CIG971#86QE;F1A<E=E96LH,C@L(#(L
M(#(P,#`I+"`G9V5T0V%L96YD87)7965K(#(G*3L*"B1E>'`@/2!A<G)A>2@*
M("`@("<R,#`P,3$R-R<L"B`@("`G,C`P,#$Q,C@G+`H@("`@)S(P,#`Q,3(Y
M)RP*("`@("<R,#`P,3$S,"<L"B`@("`G,C`P,#$R,#$G+`H@("`@)S(P,#`Q
M,C`R)RP*("`@("<R,#`P,3(P,R<**3L*8V]M<&%R92@D97AP+"!$871E7T-A
M;&,Z.F=E=$-A;&5N9&%R5V5E:R@R-RP@,3$L(#(P,#`I+"`G9V5T0V%L96YD
M87)7965K(#,G*3L*8V]M<&%R92@D97AP+"!$871E7T-A;&,Z.F=E=$-A;&5N
M9&%R5V5E:R@G,C<G+"`G,3$G+"`G,C`P,"<I+"`G9V5T0V%L96YD87)7965K
M(#,@<W1R)RD["@HD97AP(#T@87)R87DH"B`@("!A<G)A>2@*("`@("`@("`G
M,C`P,#$P,S`G+`H@("`@("`@("<R,#`P,3`S,2<L"B`@("`@("`@)S(P,#`Q
M,3`Q)RP*("`@("`@("`G,C`P,#$Q,#(G+`H@("`@("`@("<R,#`P,3$P,R<L
M"B`@("`@("`@)S(P,#`Q,3`T)RP*("`@("DL"B`@("!A<G)A>2@*("`@("`@
M("`G,C`P,#$Q,#4G+`H@("`@("`@("<R,#`P,3$P-B<L"B`@("`@("`@)S(P
M,#`Q,3`W)RP*("`@("`@("`G,C`P,#$Q,#@G+`H@("`@("`@("<R,#`P,3$P
M.2<L"B`@("`@("`@)S(P,#`Q,3$P)RP*("`@("`@("`G,C`P,#$Q,3$G+`H@
M("`@*2P*("`@(&%R<F%Y*`H@("`@("`@("<R,#`P,3$Q,B<L"B`@("`@("`@
M)S(P,#`Q,3$S)RP*("`@("`@("`G,C`P,#$Q,30G+`H@("`@("`@("<R,#`P
M,3$Q-2<L"B`@("`@("`@)S(P,#`Q,3$V)RP*("`@("`@("`G,C`P,#$Q,3<G
M+`H@("`@("`@("<R,#`P,3$Q."<L"B`@("`I+`H@("`@87)R87DH"B`@("`@
M("`@)S(P,#`Q,3$Y)RP*("`@("`@("`G,C`P,#$Q,C$G+`H@("`@("`@("<R
M,#`P,3$R,B<L"B`@("`@("`@)S(P,#`Q,3(S)RP*("`@("`@("`G,C`P,#$Q
M,C0G+`H@("`@("`@("<R,#`P,3$R-2<L"B`@("`@("`@)S(P,#`Q,3(V)RP*
M("`@("DL"B`@("!A<G)A>2@*("`@("`@("`G,C`P,#$Q,C<G+`H@("`@("`@
M("<R,#`P,3$R."<L"B`@("`@("`@)S(P,#`Q,3(Y)RP*("`@("`@("`G,C`P
M,#$Q,S`G+`H@("`@("`@("<R,#`P,3(P,2<L"B`@("`@("`@)S(P,#`Q,C`R
M)RP*("`@("`@("`G,C`P,#$R,#,G"B`@("`I"BD["F-O;7!A<F4H)&5X<"P@
M1&%T95]#86QC.CIG971#86QE;F1A<DUO;G1H*#$Q+"`R,#`P*2P@)V=E=$-A
M;&5N9&%R36]N=&@G*3L*8V]M<&%R92@D97AP+"!$871E7T-A;&,Z.F=E=$-A
M;&5N9&%R36]N=&@H)S$Q)RP@)S(P,#`G*2P@)V=E=$-A;&5N9&%R36]N=&@@
M<W1R)RD["@HO+R!)(&1O;B=T(&9E96P@;&EK92!D96%L:6YG('=I=&@@=&AI
M<R!R:6=H="!N;W<N+BX*+R]C;VUP87)E*"<G+"!$871E7T-A;&,Z.F=E=$-A
M;&5N9&%R665A<B@R,#`P*2P@)V=E=$-A;&5N9&%R665A<B<I.PH*8V]M<&%R
M92@G,C`P,#$Q,C$G+"!$871E7T-A;&,Z.G!R979$87DH,C(L(#$Q+"`R,#`P
M*2P@)W!R979$87DG*3L*8V]M<&%R92@G,C`P,#$Q,C,G+"!$871E7T-A;&,Z
M.FYE>'1$87DH,C(L(#$Q+"`R,#`P*2P@)VYE>'1$87DG*3L*8V]M<&%R92@G
M,C`P,#$Q,C$G+"!$871E7T-A;&,Z.G!R979$87DH,C(L(#$Q+"`R,#`P*2P@
M)W!R979$87D@<W1R)RD["F-O;7!A<F4H)S(P,#`Q,3(S)RP@1&%T95]#86QC
M.CIN97AT1&%Y*"<R,B<L("<Q,2<L("<R,#`P)RDL("=N97AT1&%Y('-T<B<I
M.PH*8V]M<&%R92@G,C`P,#$Q,3<G+"!$871E7T-A;&,Z.G!R9797965K9&%Y
M*"<Q.2<L("<Q,2<L("<R,#`P)RDL("=P<F5V5V5E:V1A>2`Q('-T<B<I.PIC
M;VUP87)E*"<R,#`P,3$Q-R<L($1A=&5?0V%L8SHZ<')E=E=E96MD87DH,3DL
M(#$Q+"`R,#`P*2P@)W!R9797965K9&%Y(#$G*3L*8V]M<&%R92@G,C`P,#$Q
M,C$G+"!$871E7T-A;&,Z.G!R9797965K9&%Y*#(R+"`Q,2P@,C`P,"DL("=P
M<F5V5V5E:V1A>2`R)RD["F-O;7!A<F4H)S(P,#`Q,3(S)RP@1&%T95]#86QC
M.CIN97AT5V5E:V1A>2@R,BP@,3$L(#(P,#`I+"`G;F5X=%=E96MD87D@,2<I
M.PIC;VUP87)E*"<R,#`P,3$R-R<L($1A=&5?0V%L8SHZ;F5X=%=E96MD87DH
M,C0L(#$Q+"`R,#`P*2P@)VYE>'17965K9&%Y(#(G*3L*8V]M<&%R92@G,C`P
M,#$Q,C<G+"!$871E7T-A;&,Z.FYE>'17965K9&%Y*"<R-"<L("<Q,2<L("<R
M,#`P)RDL("=N97AT5V5E:V1A>2`R('-T<B<I.PH*8V]M<&%R92@G,C`P,#$Q
M,C$G+"!$871E7T-A;&,Z.G!R979$87E/9E=E96LH)S(G+"`G,C(G+"`G,3$G
M+"`G,C`P,"<I+"`G<')E=D1A>4]F5V5E:R`Q('-T<B<I.PIC;VUP87)E*"<R
M,#`P,3$R,2<L($1A=&5?0V%L8SHZ<')E=D1A>4]F5V5E:R@R+"`R,BP@,3$L
M(#(P,#`I+"`G<')E=D1A>4]F5V5E:R`Q)RD["F-O;7!A<F4H)S(P,#`Q,3$U
M)RP@1&%T95]#86QC.CIP<F5V1&%Y3V97965K*#,L(#(R+"`Q,2P@,C`P,"DL
M("=P<F5V1&%Y3V97965K(#(G*3L*8V]M<&%R92@G,C`P,#$Q,C(G+"!$871E
M7T-A;&,Z.G!R979$87E/9E=E96LH,RP@,C(L(#$Q+"`R,#`P+"`G)5DE;25D
M)RP@=')U92DL("=P<F5V1&%Y3V97965K(#,G*3L*8V]M<&%R92@G,C`P,#$Q
M,C(G+"!$871E7T-A;&,Z.FYE>'1$87E/9E=E96LH,RP@,C(L(#$Q+"`R,#`P
M+"`G)5DE;25D)RP@=')U92DL("=N97AT1&%Y3V97965K(#$G*3L*8V]M<&%R
M92@G,C`P,#$Q,CDG+"!$871E7T-A;&,Z.FYE>'1$87E/9E=E96LH,RP@,C(L
M(#$Q+"`R,#`P*2P@)VYE>'1$87E/9E=E96L@,B<I.PIC;VUP87)E*"<R,#`P
M,3$R,R<L($1A=&5?0V%L8SHZ;F5X=$1A>4]F5V5E:R@T+"`R,BP@,3$L(#(P
M,#`I+"`G;F5X=$1A>4]F5V5E:R`S)RD["F-O;7!A<F4H)S(P,#`Q,3(S)RP@
M1&%T95]#86QC.CIN97AT1&%Y3V97965K*"<T)RP@)S(R)RP@)S$Q)RP@)S(P
M,#`G*2P@)VYE>'1$87E/9E=E96L@,R!S='(G*3L*"F-O;7!A<F4H)S(P,#`Q
M,3(Q)RP@1&%T95]#86QC.CIP<F5V1&%Y3V97965K3VY/<D)E9F]R92@G,B<L
M("<R,B<L("<Q,2<L("<R,#`P)RDL("=P<F5V1&%Y3V97965K3VY/<D)E9F]R
M92`Q('-T<B<I.PIC;VUP87)E*"<R,#`P,3$R,2<L($1A=&5?0V%L8SHZ<')E
M=D1A>4]F5V5E:T]N3W)"969O<F4H,BP@,C(L(#$Q+"`R,#`P*2P@)W!R979$
M87E/9E=E96M/;D]R0F5F;W)E(#$G*3L*8V]M<&%R92@G,C`P,#$Q,C(G+"!$
M871E7T-A;&,Z.G!R979$87E/9E=E96M/;D]R0F5F;W)E*#,L(#(R+"`Q,2P@
M,C`P,"DL("=P<F5V1&%Y3V97965K3VY/<D)E9F]R92`R)RD["F-O;7!A<F4H
M)S(P,#`Q,3(R)RP@1&%T95]#86QC.CIN97AT1&%Y3V97965K3VY/<D%F=&5R
M*#,L(#(R+"`Q,2P@,C`P,"DL("=N97AT1&%Y3V97965K3VY/<D%F=&5R(#$G
M*3L*8V]M<&%R92@G,C`P,#$Q,C,G+"!$871E7T-A;&,Z.FYE>'1$87E/9E=E
M96M/;D]R069T97(H-"P@,C(L(#$Q+"`R,#`P*2P@)VYE>'1$87E/9E=E96M/
M;D]R069T97(@,B<I.PIC;VUP87)E*"<R,#`P,3$R,R<L($1A=&5?0V%L8SHZ
M;F5X=$1A>4]F5V5E:T]N3W)!9G1E<B@G-"<L("<R,B<L("<Q,2<L("<R,#`P
M)RDL("=N97AT1&%Y3V97965K3VY/<D%F=&5R(#(@<W1R)RD["@IC;VUP87)E
M*"<R,#`P,3$R,"<L($1A=&5?0V%L8SHZ8F5G:6Y/9E=E96LH)S(R)RP@)S$Q
M)RP@)S(P,#`G*2P@)V)E9VEN3V97965K('-T<B<I.PIC;VUP87)E*"<R,#`P
M,3$R,"<L($1A=&5?0V%L8SHZ8F5G:6Y/9E=E96LH,C(L(#$Q+"`R,#`P*2P@
M)V)E9VEN3V97965K)RD["F-O;7!A<F4H)S(P,#`Q,3(V)RP@1&%T95]#86QC
M.CIE;F1/9E=E96LH,C(L(#$Q+"`R,#`P*2P@)V5N9$]F5V5E:R<I.PIC;VUP
M87)E*"<R,#`P,3$R-B<L($1A=&5?0V%L8SHZ96YD3V97965K*"<R,B<L("<Q
M,2<L("<R,#`P)RDL("=E;F1/9E=E96L@<W1R)RD["@IC;VUP87)E*"<R,#`P
M,3$Q,R<L($1A=&5?0V%L8SHZ8F5G:6Y/9E!R9797965K*#(R+"`Q,2P@,C`P
M,"DL("=B96=I;D]F4')E=E=E96LG*3L*8V]M<&%R92@G,C`P,#$Q,C<G+"!$
M871E7T-A;&,Z.F)E9VEN3V9.97AT5V5E:R@R,BP@,3$L(#(P,#`I+"`G8F5G
M:6Y/9DYE>'17965K)RD["F-O;7!A<F4H)S(P,#`Q,3$S)RP@1&%T95]#86QC
M.CIB96=I;D]F4')E=E=E96LH)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)V)E9VEN
M3V90<F5V5V5E:R!S='(G*3L*8V]M<&%R92@G,C`P,#$Q,C<G+"!$871E7T-A
M;&,Z.F)E9VEN3V9.97AT5V5E:R@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G8F5G
M:6Y/9DYE>'17965K('-T<B<I.PH*8V]M<&%R92@G,C`P,#$Q,#$G+"!$871E
M7T-A;&,Z.F)E9VEN3V9-;VYT:"@Q,2P@,C`P,"DL("=B96=I;D]F36]N=&@G
M*3L*8V]M<&%R92@G,C`P,#$Q,#$G+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT
M:"@G,3$G+"`G,C`P,"<I+"`G8F5G:6Y/9DUO;G1H('-T<B<I.PH*8V]M<&%R
M92@G,C`P,#$P,#$G+"!$871E7T-A;&,Z.F)E9VEN3V90<F5V36]N=&@H,C(L
M(#$Q+"`R,#`P*2P@)V)E9VEN3V90<F5V36]N=&@G*3L*8V]M<&%R92@G,C`P
M,#$P,S$G+"!$871E7T-A;&,Z.F5N9$]F4')E=DUO;G1H*#(R+"`Q,2P@,C`P
M,"DL("=E;F1/9E!R979-;VYT:"<I.PIC;VUP87)E*"<R,#`P,3`P,2<L($1A
M=&5?0V%L8SHZ8F5G:6Y/9E!R979-;VYT:"@G,C(G+"`G,3$G+"`G,C`P,"<I
M+"`G8F5G:6Y/9E!R979-;VYT:"!S='(G*3L*8V]M<&%R92@G,C`P,#$P,S$G
M+"!$871E7T-A;&,Z.F5N9$]F4')E=DUO;G1H*"<R,B<L("<Q,2<L("<R,#`P
M)RDL("=E;F1/9E!R979-;VYT:"!S='(G*3L*"F-O;7!A<F4H)S(P,#`Q,C`Q
M)RP@1&%T95]#86QC.CIB96=I;D]F3F5X=$UO;G1H*#(R+"`Q,2P@,C`P,"DL
M("=B96=I;D]F3F5X=$UO;G1H)RD["F-O;7!A<F4H)S(P,#`Q,C,Q)RP@1&%T
M95]#86QC.CIE;F1/9DYE>'1-;VYT:"@R,BP@,3$L(#(P,#`I+"`G96YD3V9.
M97AT36]N=&@G*3L*8V]M<&%R92@G,C`P,#$R,#$G+"!$871E7T-A;&,Z.F)E
M9VEN3V9.97AT36]N=&@H)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)V)E9VEN3V9.
M97AT36]N=&@@<W1R)RD["F-O;7!A<F4H)S(P,#`Q,C,Q)RP@1&%T95]#86QC
M.CIE;F1/9DYE>'1-;VYT:"@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G96YD3V9.
M97AT36]N=&@@<W1R)RD["@IC;VUP87)E*"<Q.3DY,3`P,2<L($1A=&5?0V%L
M8SHZ8F5G:6Y/9DUO;G1H0GE3<&%N*"TQ,RP@,3$L(#(P,#`I+"`G8F5G:6Y/
M9DUO;G1H0GE3<&%N(#$G*3L*8V]M<&%R92@G,C`P,#$P,#$G+"!$871E7T-A
M;&,Z.F)E9VEN3V9-;VYT:$)Y4W!A;B@M,2P@,3$L(#(P,#`I+"`G8F5G:6Y/
M9DUO;G1H0GE3<&%N(#(G*3L*8V]M<&%R92@G,C`P,#$Q,#$G+"!$871E7T-A
M;&,Z.F)E9VEN3V9-;VYT:$)Y4W!A;B@P+"`Q,2P@,C`P,"DL("=B96=I;D]F
M36]N=&A">5-P86X@,R<I.PIC;VUP87)E*"<R,#`P,3(P,2<L($1A=&5?0V%L
M8SHZ8F5G:6Y/9DUO;G1H0GE3<&%N*#$L(#$Q+"`R,#`P*2P@)V)E9VEN3V9-
M;VYT:$)Y4W!A;B`T)RD["F-O;7!A<F4H)S(P,#$Q,C`Q)RP@1&%T95]#86QC
M.CIB96=I;D]F36]N=&A">5-P86XH,3,L(#$Q+"`R,#`P*2P@)V)E9VEN3V9-
M;VYT:$)Y4W!A;B`U)RD["@IC;VUP87)E*"<Q.3DY,#$P,2<L($1A=&5?0V%L
M8SHZ8F5G:6Y/9DUO;G1H0GE3<&%N*"<M,3,G+"`G,#(G+"`G,C`P,"<I+"`G
M8F5G:6Y/9DUO;G1H0GE3<&%N(#8@<W1R)RD["F-O;7!A<F4H)S$Y.3DP,3`Q
M)RP@1&%T95]#86QC.CIB96=I;D]F36]N=&A">5-P86XH+3$S+"`R+"`R,#`P
M*2P@)V)E9VEN3V9-;VYT:$)Y4W!A;B`V)RD["F-O;7!A<F4H)S(P,#`P,3`Q
M)RP@1&%T95]#86QC.CIB96=I;D]F36]N=&A">5-P86XH+3$L(#(L(#(P,#`I
M+"`G8F5G:6Y/9DUO;G1H0GE3<&%N(#<G*3L*8V]M<&%R92@G,C`P,#`R,#$G
M+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT:$)Y4W!A;B@P+"`R+"`R,#`P*2P@
M)V)E9VEN3V9-;VYT:$)Y4W!A;B`X)RD["F-O;7!A<F4H)S(P,#`P,S`Q)RP@
M1&%T95]#86QC.CIB96=I;D]F36]N=&A">5-P86XH,2P@,BP@,C`P,"DL("=B
M96=I;D]F36]N=&A">5-P86X@.2<I.PIC;VUP87)E*"<R,#`Q,#,P,2<L($1A
M=&5?0V%L8SHZ8F5G:6Y/9DUO;G1H0GE3<&%N*#$S+"`R+"`R,#`P*2P@)V)E
M9VEN3V9-;VYT:$)Y4W!A;B`Q,"<I.PIC;VUP87)E*"<R,#`Q,#,P,2<L($1A
M=&5?0V%L8SHZ8F5G:6Y/9DUO;G1H0GE3<&%N*"<Q,R<L("<P,B<L("<R,#`P
M)RDL("=B96=I;D]F36]N=&A">5-P86X@,3`@<W1R)RD["@IC;VUP87)E*"<Q
M.3DY,3`S,2<L($1A=&5?0V%L8SHZ96YD3V9-;VYT:$)Y4W!A;B@M,3,L(#$Q
M+"`R,#`P*2P@)V5N9$]F36]N=&A">5-P86X@,2<I.PIC;VUP87)E*"<R,#`P
M,3`S,2<L($1A=&5?0V%L8SHZ96YD3V9-;VYT:$)Y4W!A;B@M,2P@,3$L(#(P
M,#`I+"`G96YD3V9-;VYT:$)Y4W!A;B`R)RD["F-O;7!A<F4H)S(P,#`Q,3,P
M)RP@1&%T95]#86QC.CIE;F1/9DUO;G1H0GE3<&%N*#`L(#$Q+"`R,#`P*2P@
M)V5N9$]F36]N=&A">5-P86X@,R<I.PIC;VUP87)E*"<R,#`P,3(S,2<L($1A
M=&5?0V%L8SHZ96YD3V9-;VYT:$)Y4W!A;B@Q+"`Q,2P@,C`P,"DL("=E;F1/
M9DUO;G1H0GE3<&%N(#0G*3L*8V]M<&%R92@G,C`P,3$R,S$G+"!$871E7T-A
M;&,Z.F5N9$]F36]N=&A">5-P86XH,3,L(#$Q+"`R,#`P*2P@)V5N9$]F36]N
M=&A">5-P86X@-2<I.PH*8V]M<&%R92@G,3DY.3`Q,S$G+"!$871E7T-A;&,Z
M.F5N9$]F36]N=&A">5-P86XH)RTQ,R<L("<P,B<L("<R,#`P)RDL("=E;F1/
M9DUO;G1H0GE3<&%N(#8@<W1R)RD["F-O;7!A<F4H)S$Y.3DP,3,Q)RP@1&%T
M95]#86QC.CIE;F1/9DUO;G1H0GE3<&%N*"TQ,RP@,BP@,C`P,"DL("=E;F1/
M9DUO;G1H0GE3<&%N(#8G*3L*8V]M<&%R92@G,C`P,#`Q,S$G+"!$871E7T-A
M;&,Z.F5N9$]F36]N=&A">5-P86XH+3$L(#(L(#(P,#`I+"`G96YD3V9-;VYT
M:$)Y4W!A;B`W)RD["F-O;7!A<F4H)S(P,#`P,C(Y)RP@1&%T95]#86QC.CIE
M;F1/9DUO;G1H0GE3<&%N*#`L(#(L(#(P,#`I+"`G96YD3V9-;VYT:$)Y4W!A
M;B`X)RD["F-O;7!A<F4H)S(P,#`P,S,Q)RP@1&%T95]#86QC.CIE;F1/9DUO
M;G1H0GE3<&%N*#$L(#(L(#(P,#`I+"`G96YD3V9-;VYT:$)Y4W!A;B`Y)RD[
M"F-O;7!A<F4H)S(P,#$P,S,Q)RP@1&%T95]#86QC.CIE;F1/9DUO;G1H0GE3
M<&%N*#$S+"`R+"`R,#`P*2P@)V5N9$]F36]N=&A">5-P86X@,3`G*3L*8V]M
M<&%R92@G,C`P,3`S,S$G+"!$871E7T-A;&,Z.F5N9$]F36]N=&A">5-P86XH
M)S$S)RP@)S`R)RP@)S(P,#`G*2P@)V5N9$]F36]N=&A">5-P86X@,3`@<W1R
M)RD["@IC;VUP87)E*#,L($1A=&5?0V%L8SHZ9FER<W1/9DUO;G1H5V5E:V1A
M>2@Q,2P@,C`P,"DL("=F:7)S=$]F36]N=&A7965K9&%Y)RD["F-O;7!A<F4H
M,RP@1&%T95]#86QC.CIF:7)S=$]F36]N=&A7965K9&%Y*"<Q,2<L("<R,#`P
M)RDL("=F:7)S=$]F36]N=&A7965K9&%Y('-T<B<I.PH*8V]M<&%R92@G,C`P
M-3`Q,#$G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@Q+"`V+"`Q+"`R
M,#`U*2P@)TY7965K9&%Y3V9-;VYT:"`Q-C$G*3L*8V]M<&%R92@G,C`P-3`Q
M,#(G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@Q+"`P+"`Q+"`R,#`U
M*2P@)TY7965K9&%Y3V9-;VYT:"`Q,#$G*3L*8V]M<&%R92@G,C`P-3`Q,#,G
M+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@Q+"`Q+"`Q+"`R,#`U*2P@
M)TY7965K9&%Y3V9-;VYT:"`Q,3$G*3L*8V]M<&%R92@G,C`P-3`Q,#0G+"!$
M871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@Q+"`R+"`Q+"`R,#`U*2P@)TY7
M965K9&%Y3V9-;VYT:"`Q,C$G*3L*8V]M<&%R92@G,C`P-3`Q,#4G+"!$871E
M7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@Q+"`S+"`Q+"`R,#`U*2P@)TY7965K
M9&%Y3V9-;VYT:"`Q,S$G*3L*8V]M<&%R92@G,C`P-3`Q,#8G+"!$871E7T-A
M;&,Z.DY7965K9&%Y3V9-;VYT:"@Q+"`T+"`Q+"`R,#`U*2P@)TY7965K9&%Y
M3V9-;VYT:"`Q-#$G*3L*8V]M<&%R92@G,C`P-3`Q,#<G+"!$871E7T-A;&,Z
M.DY7965K9&%Y3V9-;VYT:"@Q+"`U+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-
M;VYT:"`Q-3$G*3L*"F-O;7!A<F4H)S(P,#4P,3`X)RP@1&%T95]#86QC.CI.
M5V5E:V1A>4]F36]N=&@H)S(G+"`G-B<L("<P,2<L("<R,#`U)RDL("=.5V5E
M:V1A>4]F36]N=&@@,C8Q)RD["F-O;7!A<F4H)S(P,#4P,3`Y)RP@1&%T95]#
M86QC.CI.5V5E:V1A>4]F36]N=&@H)S(G+"`G,"<L("<P,2<L("<R,#`U)RDL
M("=.5V5E:V1A>4]F36]N=&@@,C`Q)RD["F-O;7!A<F4H)S(P,#4P,3$P)RP@
M1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)S(G+"`G,2<L("<P,2<L("<R
M,#`U)RDL("=.5V5E:V1A>4]F36]N=&@@,C$Q)RD["F-O;7!A<F4H)S(P,#4P
M,3$Q)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)S(G+"`G,B<L("<P
M,2<L("<R,#`U)RDL("=.5V5E:V1A>4]F36]N=&@@,C(Q)RD["F-O;7!A<F4H
M)S(P,#4P,3$R)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)S(G+"`G
M,R<L("<P,2<L("<R,#`U)RDL("=.5V5E:V1A>4]F36]N=&@@,C,Q)RD["F-O
M;7!A<F4H)S(P,#4P,3$S)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H
M)S(G+"`G-"<L("<P,2<L("<R,#`U)RDL("=.5V5E:V1A>4]F36]N=&@@,C0Q
M)RD["F-O;7!A<F4H)S(P,#4P,3$T)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F
M36]N=&@H)S(G+"`G-2<L("<P,2<L("<R,#`U)RDL("=.5V5E:V1A>4]F36]N
M=&@@,C4Q)RD["@IC;VUP87)E*"<R,#`U,#$S,2<L($1A=&5?0V%L8SHZ3E=E
M96MD87E/9DUO;G1H*"=L87-T)RP@,2P@,2P@,C`P-2DL("=.5V5E:V1A>4]F
M36]N=&@@;#$Q)RD["F-O;7!A<F4H)S(P,#4P,3,P)RP@1&%T95]#86QC.CI.
M5V5E:V1A>4]F36]N=&@H)VQA<W0G+"`P+"`Q+"`R,#`U*2P@)TY7965K9&%Y
M3V9-;VYT:"!L,#$G*3L*8V]M<&%R92@G,C`P-3`Q,CDG+"!$871E7T-A;&,Z
M.DY7965K9&%Y3V9-;VYT:"@G;&%S="<L(#8L(#$L(#(P,#4I+"`G3E=E96MD
M87E/9DUO;G1H(&PV,2<I.PIC;VUP87)E*"<R,#`U,#$R."<L($1A=&5?0V%L
M8SHZ3E=E96MD87E/9DUO;G1H*"=L87-T)RP@-2P@,2P@,C`P-2DL("=.5V5E
M:V1A>4]F36]N=&@@;#4Q)RD["F-O;7!A<F4H)S(P,#4P,3(W)RP@1&%T95]#
M86QC.CI.5V5E:V1A>4]F36]N=&@H)VQA<W0G+"`T+"`Q+"`R,#`U*2P@)TY7
M965K9&%Y3V9-;VYT:"!L-#$G*3L*8V]M<&%R92@G,C`P-3`Q,C8G+"!$871E
M7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G;&%S="<L(#,L(#$L(#(P,#4I+"`G
M3E=E96MD87E/9DUO;G1H(&PS,2<I.PIC;VUP87)E*"<R,#`U,#$R-2<L($1A
M=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"=L87-T)RP@,BP@,2P@,C`P-2DL
M("=.5V5E:V1A>4]F36]N=&@@;#(Q)RD["@IC;VUP87)E*"<R,#`U,#,S,2<L
M($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"=L87-T)RP@-"P@,RP@,C`P
M-2DL("=.5V5E:V1A>4]F36]N=&@@;#0S)RD["F-O;7!A<F4H)S(P,#4P,S,P
M)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)VQA<W0G+"`S+"`S+"`R
M,#`U*2P@)TY7965K9&%Y3V9-;VYT:"!L,S,G*3L*8V]M<&%R92@G,C`P-3`S
M,CDG+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G;&%S="<L(#(L(#,L
M(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(&PR,R<I.PIC;VUP87)E*"<R,#`U
M,#,R."<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"=L87-T)RP@,2P@
M,RP@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@;#$S)RD["F-O;7!A<F4H)S(P
M,#4P,S(W)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)VQA<W0G+"`P
M+"`S+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"!L,#,G*3L*8V]M<&%R92@G
M,C`P-3`S,C8G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G;&%S="<L
M(#8L(#,L(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(&PV,R<I.PIC;VUP87)E
M*"<R,#`U,#,R-2<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"=L87-T
M)RP@-2P@,RP@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@;#4S)RD["@H*8V]M
M<&%R92AF86QS92P@1&%T95]#86QC.CII<U9A;&ED1&%T92@R.2P@,BP@,3DP
M,"DL("=I<U9A;&ED1&%T92`Q)RD["F-O;7!A<F4H=')U92P@1&%T95]#86QC
M.CII<U9A;&ED1&%T92@R.2P@,BP@,C`P,"DL("=I<U9A;&ED1&%T92`R)RD[
M"F-O;7!A<F4H=')U92P@1&%T95]#86QC.CII<U9A;&ED1&%T92@G,CDG+"`G
M,#(G+"`G,C`P,"<I+"`G:7-686QI9$1A=&4@,B!S='(G*3L*"F-O;7!A<F4H
M9F%L<V4L($1A=&5?0V%L8SHZ:7-,96%P665A<B@Q.3`P*2P@)VES3&5A<%EE
M87(@,2<I.PIC;VUP87)E*'1R=64L($1A=&5?0V%L8SHZ:7-,96%P665A<B@Q
M.3DV*2P@)VES3&5A<%EE87(@,B<I.PIC;VUP87)E*'1R=64L($1A=&5?0V%L
M8SHZ:7-,96%P665A<B@R,#`P*2P@)VES3&5A<%EE87(@,R<I.PIC;VUP87)E
M*&9A;'-E+"!$871E7T-A;&,Z.FES3&5A<%EE87(H,C`P,2DL("=I<TQE87!9
M96%R(#0G*3L*8V]M<&%R92AF86QS92P@1&%T95]#86QC.CII<TQE87!996%R
M*"<R,#`Q)RDL("=I<TQE87!996%R(#0@<W1R)RD["@IC;VUP87)E*&9A;'-E
M+"!$871E7T-A;&,Z.FES1G5T=7)E1&%T92@G,C(G+"`G,3$G+"`G,C`P,"<I
M+"`G:7-&=71U<F5$871E(#$@<W1R)RD["F-O;7!A<F4H9F%L<V4L($1A=&5?
M0V%L8SHZ:7-&=71U<F5$871E*#(R+"`Q,2P@,C`P,"DL("=I<T9U='5R941A
M=&4@,2<I.PIC;VUP87)E*'1R=64L($1A=&5?0V%L8SHZ:7-&=71U<F5$871E
M*#(R+"`Q,2P@9&%T92@G62<I("L@,2DL("=I<T9U='5R941A=&4@,B<I.PH*
M8V]M<&%R92AF86QS92P@1&%T95]#86QC.CII<U!A<W1$871E*#(R+"`Q,2P@
M9&%T92@G62<I("L@,2DL("=I<U!A<W1$871E(#$G*3L*8V]M<&%R92AT<G5E
M+"!$871E7T-A;&,Z.FES4&%S=$1A=&4H,C(L(#$Q+"`R,#`P*2P@)VES4&%S
M=$1A=&4@,B<I.PIC;VUP87)E*'1R=64L($1A=&5?0V%L8SHZ:7-087-T1&%T
M92@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G:7-087-T1&%T92`R('-T<B<I.PH*
M8V]M<&%R92@Q,"P@1&%T95]#86QC.CID871E1&EF9B@R,BP@,3$L(#(P,#`L
M(#$R+"`Q,2P@,C`P,"DL("=D871E1&EF9B`Q)RD["F-O;7!A<F4H,3`L($1A
M=&5?0V%L8SHZ9&%T941I9F8H,3(L(#$Q+"`R,#`P+"`R,BP@,3$L(#(P,#`I
M+"`G9&%T941I9F8@,B<I.PIC;VUP87)E*#8Q+"!$871E7T-A;&,Z.F1A=&5$
M:69F*#(R+"`Q,2P@,C`P,"P@,C(L(#$L(#(P,#$I+"`G9&%T941I9F8@,R<I
M.PIC;VUP87)E*#8Q+"!$871E7T-A;&,Z.F1A=&5$:69F*"<R,B<L("<Q,2<L
M("<R,#`P)RP@)S(R)RP@)S`Q)RP@)S(P,#$G*2P@)V1A=&5$:69F(#,@<W1R
M)RD["@IC;VUP87)E*"TQ+"!$871E7T-A;&,Z.F-O;7!A<F5$871E<R@Q,BP@
M,3$L(#(P,#`L(#(R+"`Q,2P@,C`P,"DL("=C;VUP87)E1&%T97,@,2<I.PIC
M;VUP87)E*#`L($1A=&5?0V%L8SHZ8V]M<&%R941A=&5S*#(R+"`Q,2P@,C`P
M,"P@,C(L(#$Q+"`R,#`P*2P@)V-O;7!A<F5$871E<R`R)RD["F-O;7!A<F4H
M,2P@1&%T95]#86QC.CIC;VUP87)E1&%T97,H,C(L(#$Q+"`R,#`P+"`Q,BP@
M,3$L(#(P,#`I+"`G8V]M<&%R941A=&5S(#,G*3L*8V]M<&%R92@Q+"!$871E
M7T-A;&,Z.F-O;7!A<F5$871E<R@G,C(G+"`G,3$G+"`G,C`P,"<L("<Q,B<L
M("<Q,2<L("<R,#`P)RDL("=C;VUP87)E1&%T97,@,R!S='(G*3L*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M=&5S=',O1&%T92]T97-T<R]T97-T7V-A;&,N<&AP````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#(T,C0`,3`U,34T,S,W-#(`,#(T-#0P`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"G)E<75I<F5?
M;VYC92`B1&%T92]#86QC+G!H<"(["@HO*BH*("H@5&5S="!D871E<R!F<F]M
M(#$Y-S`@=&\@,C`R.0H@*B!$871A(&9R;VTZ(&AT='`Z+R]W=W<N;65R;'EN
M+F1E;6]N+F-O+G5K+W=K;F]T97-T+G1X=`H@*B!/=&AE<G,@=7-E9G5L;"!D
M871A<R!A=F%I;&%B;&4@9G)O;3H*("H@:'1T<#HO+W=W=RYM97)L>6XN9&5M
M;VXN8V\N=6LO(V1A=`H@*B\*)&9A:6QE9%]T97-T7V1A=&$@("`](&9A;'-E
M.PHD=VMN;R`@(#T@9FEL92@G=VMN;W1E<W0N='AT)RD["B1C;G0@("`@/2!S
M:7IE;V8H)'=K;F\I.PIF;W(H("1I/3`[)&D\)&-N=#LD:2LK("E["B`@("`D
M<&%R=',@("`@("`](&5X<&QO9&4H)SHG+"1W:VYO6R1I72D["B`@("`D=V5E
M:W-N;ULD<&%R='-;,%U=(#T@<W1R7W)E<&QA8V4H(EQN(BPG)RPD<&%R='-;
M,5TI.PI]"G5N<V5T*"1W:VYO*3L*9F]R96%C:"@D=V5E:W-N;R!A<R`D9&%T
M93T^)&ES;RE["B`@("`D>65A<B`@("`@("`]('-U8G-T<B@D9&%T92PP+#0I
M.PH@("`@)&UO;G1H("`@("`@/2!S=6)S='(H)&1A=&4L-"PR*3L*("`@("1D
M87D@("`@("`@(#T@<W5B<W1R*"1D871E+#8I.PH@("`@)&ES;SDV,#$@/2!$
M871E7T-A;&,Z.F=R96=O<FEA;E1O25-/*"1D87DL)&UO;G1H+"1Y96%R*3L*
M("`@(&EF*"1I<V\Y-C`Q(3TD:7-O*7L*("`@("`@("`D9F%I;&5D7W1E<W1?
M9&%T82`@(#T@=')U93L*("`@("`@("!E8VAO("1D871E("X@)R@G("X@)&ES
M;R`N("<I(#T^)R`N("1Y96%R+B<M)RXD;6]N=&@N)RTG+B1D87D@+B<]/B<@
M+B`D:7-O.38P,2`N("(@.B!F86EL961<;B(["B`@("!]"GT*"B\J*@H@*B!"
M=6=S(",Q.3<X.`H@*B\*)&9A:6QE9%]T97-T7S$Y-S@X("`](&9A;'-E.PHD
M<&%S<S$@(#T@,CT]1&%T95]#86QC.CIW965K3V9996%R*#4L,2PQ.3DX*3]T
M<G5E.F9A;'-E.PHD<&%S<S(@(#T@,CT]1&%T95]#86QC.CIW965K3V9996%R
M*#8L,2PQ.3DX*3]T<G5E.F9A;'-E.PHD<&%S<S,@(#T@,CT]1&%T95]#86QC
M.CIW965K3V9996%R*#4L,2PR,#`T*3]T<G5E.F9A;'-E.PHD<&%S<S0@(#T@
M,CT]1&%T95]#86QC.CIW965K3V9996%R*#8L,2PR,#`T*3]T<G5E.F9A;'-E
M.PII9B@@(2@D<&%S<S$@)B8@)'!A<W,R("8F("1P87-S,R`F)B`D<&%S<S0I
M("E["B`@("`D9F%I;&5D7W1E<W1?,3DW.#@@("`]('1R=64["GT*"FEF*"1F
M86EL961?=&5S=%\Q.3<X."!\?"`D9F%I;&5D7W1E<W1?9&%T82E["B`@("!E
M8VAO(")"=6<@(S$Y-S@X.B!F86EL961<;B(["GT@96QS92!["B`@("!E8VAO
M(")"=6<@(S$Y-S@X.B!/2UQN(CL*?0H_/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+W1E<W1?
M9&%T95]M971H;V1S7W-P86XN<&AP````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3(S-P`Q,#4Q-30S
M,S<T,@`P,C<R,C0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]
M-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*+R\*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW
M+3(P,#4@($QE86YD<F\@3'5C87)E;&QA("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4
M:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=&AE($YE=R!"4T0@;&EC
M96YS92P@5&AA="!I<R!B=6YD;&5D("!\"B\O('P@=VET:"!T:&ES('!A8VMA
M9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES(&%V86EL86)L92!T:')O
M=6=H("`@("`@?`HO+R!\('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M?"!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E
M;G-E+G!H<"`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N
M;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(&YE=R!"4T1L:6-E;G-E(&%N9"!A
M<F4@=6YA8FQE("`@?`HO+R!\('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@('P*
M+R\@?"!P96%R+61E=D!L:7-T<RYP:'`N;F5T('-O('=E(&-A;B!M86EL('EO
M=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("!\"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@3&5A;F1R;R!,=6-A<F5L
M;&$@/&QL=6-A>$!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@
M=&5S=%]D871E7VUE=&AO9'-?<W!A;BYP:'`L=B`Q+C(@,C`P-2\Q,2\Q-2`P
M,#HQ-CHT,"!P86IO>64@17AP("0*+R\*"@IR97%U:7)E7V]N8V4@)T1A=&4N
M<&AP)SL*<F5Q=6ER95]O;F-E("=$871E+U-P86XN<&AP)SL*"B1D871E(#T@
M;F5W($1A=&4H*3L*)'1M<"`](&YE=R!$871E*"1D871E*3L*"G!R:6YT9B@B
M06-T=6%L(&1A=&4Z("5S7&XB+"`D9&%T92T^9V5T1&%T92A$051%7T9/4DU!
M5%])4T\I*3L*"B1T;7`M/F-O<'DH)&1A=&4I.PHD=&UP+3YS=6)T<F%C=%-P
M86XH;F5W($1A=&5?4W!A;B@G,#HP,#HP,#HP-2<I*3L*<')I;G1F*")3=6)T
M<F%C=&EN9R`U('-E8V]N9',Z("5S7&XB+"`D=&UP+3YG971$871E*$1!5$5?
M1D]234%47TE33RDI.PH*)'1M<"T^8V]P>2@D9&%T92D["B1T;7`M/G-U8G1R
M86-T4W!A;BAN97<@1&%T95]3<&%N*"<P.C`P.C(P.C`P)RDI.PIP<FEN=&8H
M(E-U8G1R86-T:6YG(#(P(&UI;G5T97,Z("5S7&XB+"`D=&UP+3YG971$871E
M*$1!5$5?1D]234%47TE33RDI.PH*)'1M<"T^8V]P>2@D9&%T92D["B1T;7`M
M/G-U8G1R86-T4W!A;BAN97<@1&%T95]3<&%N*"<P.C$P.C`P.C`P)RDI.PIP
M<FEN=&8H(E-U8G1R86-T:6YG(#$P(&AO=7)S.B`E<UQN(BP@)'1M<"T^9V5T
M1&%T92A$051%7T9/4DU!5%])4T\I*3L*"B1T;7`M/F-O<'DH)&1A=&4I.PHD
M=&UP+3YS=6)T<F%C=%-P86XH;F5W($1A=&5?4W!A;B@G,SHP,#HP,#HP,"<I
M*3L*<')I;G1F*")3=6)T<F%C=&EN9R`S(&1A>7,Z("5S7&XB+"`D=&UP+3YG
M971$871E*$1!5$5?1D]234%47TE33RDI.PH*)'1M<"T^8V]P>2@D9&%T92D[
M"B1T;7`M/G-U8G1R86-T4W!A;BAN97<@1&%T95]3<&%N*"<S.C$P.C(P.C`U
M)RDI.PIP<FEN=&8H(E-U8G1R86-T:6YG(#,@9&%Y<RP@,3`@:&]U<G,L(#(P
M(&UI;G5T97,@86YD(#4@<V5C;VYD<SH@)7-<;B(L("1T;7`M/F=E=$1A=&4H
M1$%415]&3U)-051?25-/*2D["@HD=&UP+3YC;W!Y*"1D871E*3L*)'1M<"T^
M861D4W!A;BAN97<@1&%T95]3<&%N*"<P.C`P.C`P.C`U)RDI.PIP<FEN=&8H
M(D%D9&EN9R`U('-E8V]N9',Z("5S7&XB+"`D=&UP+3YG971$871E*$1!5$5?
M1D]234%47TE33RDI.PH*)'1M<"T^8V]P>2@D9&%T92D["B1T;7`M/F%D9%-P
M86XH;F5W($1A=&5?4W!A;B@G,#HP,#HR,#HP,"<I*3L*<')I;G1F*")!9&1I
M;F<@,C`@;6EN=71E<SH@)7-<;B(L("1T;7`M/F=E=$1A=&4H1$%415]&3U)-
M051?25-/*2D["@HD=&UP+3YC;W!Y*"1D871E*3L*)'1M<"T^861D4W!A;BAN
M97<@1&%T95]3<&%N*"<P.C$P.C`P.C`P)RDI.PIP<FEN=&8H(D%D9&EN9R`Q
M,"!H;W5R<SH@)7-<;B(L("1T;7`M/F=E=$1A=&4H1$%415]&3U)-051?25-/
M*2D["@HD=&UP+3YC;W!Y*"1D871E*3L*)'1M<"T^861D4W!A;BAN97<@1&%T
M95]3<&%N*"<S.C`P.C`P.C`P)RDI.PIP<FEN=&8H(D%D9&EN9R`S(&1A>7,Z
M("5S7&XB+"`D=&UP+3YG971$871E*$1!5$5?1D]234%47TE33RDI.PH*)'1M
M<"T^8V]P>2@D9&%T92D["B1T;7`M/F%D9%-P86XH;F5W($1A=&5?4W!A;B@G
M,SHQ,#HR,#HP-2<I*3L*<')I;G1F*")!9&1I;F<@,R!D87ES+"`Q,"!H;W5R
M<RP@,C`@;6EN=71E<R!A;F0@-2!S96-O;F1S.B`E<UQN(BP@)'1M<"T^9V5T
M1&%T92A$051%7T9/4DU!5%])4T\I*3L*"C\^"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+W1E<W1S+T1A=&4O=&5S=',O=&5S='5N:70N<&AP````````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R-S0S`#$P-3$U-#,S-S0R`#`R-#,V,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-#H@
M*B\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0('9E
M<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-2`@36%R<VAA;&P@
M4F]C:"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!T:&4@3F5W($)31"!L:6-E;G-E+"!4:&%T(&ES(&)U
M;F1L960@('P*+R\@?"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,
M24-%3E-%+"!A;F0@:7,@879A:6QA8FQE('1H<F]U9V@@("`@("!\"B\O('P@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N;W!E
M;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("`@("`@("`@
M("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P
M>2!O9B!T:&4@;F5W($)31&QI8V5N<V4@86YD(&%R92!U;F%B;&4@("!\"B\O
M('P@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P
M;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@?`HO+R!\('!E87(M9&5V0&QI
M<W1S+G!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA
M=&5L>2X@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@075T:&]R<SH@36%R<VAA;&P@4F]C:"`\;7)O8VA`<&AP+FYE=#X@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!T97-T=6YI="YP:'`L=B`Q
M+C(@,C`P-2\Q,2\Q-2`P,#HQ-CHT,"!P86IO>64@17AP("0*"B\J*@H@*B!$
M:7-P;&%Y<R!A;&P@=&5S="!C87-E<R!O;B!T:&4@<V%M92!P86=E"B`J"B`J
M($!P86-K86=E($1A=&4*("H@0&%U=&AO<B!-87)S:&%L;"!2;V-H(#QM<F]C
M:$!P:'`N;F5T/@H@*B\*"@IE8VAO("(\<')E/B(["G)E<75I<F5?;VYC92`G
M4$A056YI="YP:'`G.PIR97%U:7)E7V]N8V4@)W1E<W1U;FET7V1A=&4N<&AP
M)SL*<F5Q=6ER95]O;F-E("=T97-T=6YI=%]D871E7W-P86XN<&AP)SL*96-H
M;R`B/"]P<F4^(CL*/SX*```````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T
M<R]T97-T=6YI=%]D871E+G!H<```````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C`P-30`
M,3`U,34T,S,W-#(`,#(U,S4R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\O('9I;3H@<V5T(&5X<&%N9'1A8B!T
M86)S=&]P/30@<V]F='1A8G-T;W`]-"!S:&EF='=I9'1H/30Z"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@36%R<VAA;&P@4F]C:"`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@
M=&\@=&AE($YE=R!"4T0@;&EC96YS92P@5&AA="!I<R!B=6YD;&5D("!\"B\O
M('P@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD
M(&ES(&%V86EL86)L92!T:')O=6=H("`@("`@?`HO+R!\('1H92!W;W)L9"UW
M:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G
M+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@("`@("`@("`@("`@("`@("!\
M"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(&YE
M=R!"4T1L:6-E;G-E(&%N9"!A<F4@=6YA8FQE("`@?`HO+R!\('1O(&]B=&%I
M;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@
M82!N;W1E('1O("`@("`@('P*+R\@?"!P96%R+61E=D!L:7-T<RYP:'`N;F5T
M('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO
M<CH@36%R<VAA;&P@4F]C:"`\;7)O8VA`<&AP+FYE=#X@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O"B\O("1)9#H@=&5S='5N:71?9&%T92YP:'`L=B`Q+C,@,C`P
M-2\Q,2\Q-2`P,#HQ-CHT,"!P86IO>64@17AP("0*+R\*"G)E<75I<F5?;VYC
M92`G1&%T92YP:'`G.PIR97%U:7)E7V]N8V4@)U!(4%5N:70N<&AP)SL*"F-L
M87-S(&UY1&%T92!E>'1E;F1S($1A=&4@>PH@("`@9G5N8W1I;VX@;7E$871E
M*"1D871E*0H@("`@>PH@("`@("`@("1T:&ES+3Y$871E*"1D871E*3L*("`@
M('T*?0H*+RHJ"B`J(%1E<W0@8V%S92!F;W(@1&%T90H@*@H@*B!`<&%C:V%G
M92!$871E"B`J($!A=71H;W(@36%R<VAA;&P@4F]C:"`\;7)O8VA`<&AP+FYE
M=#X*("HO"F-L87-S($1A=&5?5&5S="!E>'1E;F1S(%!(4%5N:71?5&5S=$-A
M<V4@>PH*("`@('9A<B`D=&EM93L*"B`@("!F=6YC=&EO;B!$871E7U1E<W0H
M)&YA;64I"B`@("!["B`@("`@("`@)'1H:7,M/E!(4%5N:71?5&5S=$-A<V4H
M)&YA;64I.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=%5P*"D*("`@('L*("`@
M("`@("`D=&AI<RT^=&EM92`](&YE=R!$871E*"(R,#`S+3$P+3`T(#$T.C`S
M.C(T(BD["B`@("!]"@H@("`@9G5N8W1I;VX@=&5A<D1O=VXH*0H@("`@>PH@
M("`@("`@('5N<V5T*"1T:&ES+3YT:6UE*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!T97-T1&%T94YU;&PH*0H@("`@>PH@("`@("`@("1T:6UE(#T@;F5W($1A
M=&4H*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*`H@("`@("`@("`@
M("!D871E*"=9+6TM9"!(.FDZ<R<I+`H@("`@("`@("`@("!S<')I;G1F*"<E
M,#1D+24P,F0M)3`R9"`E,#)D.B4P,F0Z)3`R9"<L"B`@("`@("`@("`@("`@
M("`D=&EM92T^>65A<BP@)'1I;64M/FUO;G1H+"`D=&EM92T^9&%Y+`H@("`@
M("`@("`@("`@("`@)'1I;64M/FAO=7(L("1T:6UE+3YM:6YU=&4L("1T:6UE
M+3YS96-O;F0I"B`@("`@("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T
M06)S=')A8W1I;VXH*0H@("`@>PH@("`@("`@("1D(#T@;F5W($1A=&4H*3L*
M("`@("`@("`D;7D@/2!N97<@;7E$871E*"1D*3L*("`@("`@("`D=&AI<RT^
M87-S97)T17%U86QS*"1D+3YG971$871E*"DL)&UY+3YG971$871E*"DI.PH@
M("`@?0H*("`@(&9U;F-T:6]N('1E<W1$871E0V]P>2@I"B`@("!["B`@("`@
M("`@)'1E;7`@/2!N97<@1&%T92@D=&AI<RT^=&EM92D["B`@("`@("`@)'1H
M:7,M/F%S<V5R=$5Q=6%L<R@D=&5M<"P@)'1H:7,M/G1I;64I.PH@("`@?0H*
M("`@(&9U;F-T:6]N('1E<W1$871E25-/*"D*("`@('L*("`@("`@("`D=&5M
M<"`](&YE=R!$871E*"(R,#`S+3$P+3`T(#$T.C`S.C(T(BD["B`@("`@("`@
M)'1H:7,M/F%S<V5R=$5Q=6%L<R@*("`@("`@("`@("`@)S(P,#,M,3`M,#0@
M,30Z,#,Z,C0G+`H@("`@("`@("`@("!S<')I;G1F*"<E,#1D+24P,F0M)3`R
M9"`E,#)D.B4P,F0Z)3`R9"<L"B`@("`@("`@("`@("`@("`D=&5M<"T^>65A
M<BP@)'1E;7`M/FUO;G1H+"`D=&5M<"T^9&%Y+`H@("`@("`@("`@("`@("`@
M)'1E;7`M/FAO=7(L("1T96UP+3YM:6YU=&4L("1T96UP+3YS96-O;F0I"B`@
M("`@("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T1&%T94E33T)A<VEC
M*"D*("`@('L*("`@("`@("`D=&5M<"`](&YE=R!$871E*"(R,#`S,3`P-%0Q
M-#`S,C0B*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*`H@("`@("`@
M("`@("`G,C`P,RTQ,"TP-"`Q-#HP,SHR-"<L"B`@("`@("`@("`@('-P<FEN
M=&8H)R4P-&0M)3`R9"TE,#)D("4P,F0Z)3`R9#HE,#)D)RP*("`@("`@("`@
M("`@("`@("1T96UP+3YY96%R+"`D=&5M<"T^;6]N=&@L("1T96UP+3YD87DL
M"B`@("`@("`@("`@("`@("`D=&5M<"T^:&]U<BP@)'1E;7`M/FUI;G5T92P@
M)'1E;7`M/G-E8V]N9"D*("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N
M('1E<W1$871E25-/17AT96YD960H*0H@("`@>PH@("`@("`@("1T96UP(#T@
M;F5W($1A=&4H(C(P,#,M,3`M,#14,30Z,#,Z,C0B*3L*("`@("`@("`D=&AI
M<RT^87-S97)T17%U86QS*`H@("`@("`@("`@("`G,C`P,RTQ,"TP-"`Q-#HP
M,SHR-"<L"B`@("`@("`@("`@('-P<FEN=&8H)R4P-&0M)3`R9"TE,#)D("4P
M,F0Z)3`R9#HE,#)D)RP*("`@("`@("`@("`@("`@("1T96UP+3YY96%R+"`D
M=&5M<"T^;6]N=&@L("1T96UP+3YD87DL"B`@("`@("`@("`@("`@("`D=&5M
M<"T^:&]U<BP@)'1E;7`M/FUI;G5T92P@)'1E;7`M/G-E8V]N9"D*("`@("`@
M("`I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W1$871E25-/5&EM97-T86UP
M*"D*("`@('L*("`@("`@("`D=&5M<"`](&YE=R!$871E*"(R,#`S,3`P-#$T
M,#,R-"(I.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H"B`@("`@("`@
M("`@("<R,#`S+3$P+3`T(#$T.C`S.C(T)RP*("`@("`@("`@("`@<W!R:6YT
M9B@G)3`T9"TE,#)D+24P,F0@)3`R9#HE,#)D.B4P,F0G+`H@("`@("`@("`@
M("`@("`@)'1E;7`M/GEE87(L("1T96UP+3YM;VYT:"P@)'1E;7`M/F1A>2P*
M("`@("`@("`@("`@("`@("1T96UP+3YH;W5R+"`D=&5M<"T^;6EN=71E+"`D
M=&5M<"T^<V5C;VYD*0H@("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@
M=&5S=$1A=&55;FEX=&EM92@I"B`@("!["B`@("`@("`@)'1E;7`@/2!N97<@
M1&%T92AS=')T;W1I;64H(C(P,#,M,3`M,#0@,30Z,#,Z,C0B*2D["B`@("`@
M("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@*("`@("`@("`@("`@)S(P,#,M,3`M
M,#0@,30Z,#,Z,C0G+`H@("`@("`@("`@("!S<')I;G1F*"<E,#1D+24P,F0M
M)3`R9"`E,#)D.B4P,F0Z)3`R9"<L"B`@("`@("`@("`@("`@("`D=&5M<"T^
M>65A<BP@)'1E;7`M/FUO;G1H+"`D=&5M<"T^9&%Y+`H@("`@("`@("`@("`@
M("`@)'1E;7`M/FAO=7(L("1T96UP+3YM:6YU=&4L("1T96UP+3YS96-O;F0I
M"B`@("`@("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T4V5T1&%T94E3
M3R@I"B`@("!["B`@("`@("`@)'1H:7,M/G1I;64M/G-E=$1A=&4H(C(P,#,M
M,3`M,#0@,30Z,#,Z,C0B*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS
M*`H@("`@("`@("`@("`G,C`P,RTQ,"TP-"`Q-#HP,SHR-"<L"B`@("`@("`@
M("`@('-P<FEN=&8H)R4P-&0M)3`R9"TE,#)D("4P,F0Z)3`R9#HE,#)D)RP*
M("`@("`@("`@("`@("`@("1T:&ES+3YT:6UE+3YY96%R+"`D=&AI<RT^=&EM
M92T^;6]N=&@L("1T:&ES+3YT:6UE+3YD87DL"B`@("`@("`@("`@("`@("`D
M=&AI<RT^=&EM92T^:&]U<BP@)'1H:7,M/G1I;64M/FUI;G5T92P@)'1H:7,M
M/G1I;64M/G-E8V]N9"D*("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N
M('1E<W13971$871E25-/0F%S:6,H*0H@("`@>PH@("`@("`@("1T:&ES+3YT
M:6UE+3YS971$871E*"(R,#`S,3`P-%0Q-#`S,C0B*3L*("`@("`@("`D=&AI
M<RT^87-S97)T17%U86QS*`H@("`@("`@("`@("`G,C`P,RTQ,"TP-"`Q-#HP
M,SHR-"<L"B`@("`@("`@("`@('-P<FEN=&8H)R4P-&0M)3`R9"TE,#)D("4P
M,F0Z)3`R9#HE,#)D)RP*("`@("`@("`@("`@("`@("1T:&ES+3YT:6UE+3YY
M96%R+"`D=&AI<RT^=&EM92T^;6]N=&@L("1T:&ES+3YT:6UE+3YD87DL"B`@
M("`@("`@("`@("`@("`D=&AI<RT^=&EM92T^:&]U<BP@)'1H:7,M/G1I;64M
M/FUI;G5T92P@)'1H:7,M/G1I;64M/G-E8V]N9"D*("`@("`@("`I.PH@("`@
M?0H*("`@(&9U;F-T:6]N('1E<W13971$871E25-/17AT96YD960H*0H@("`@
M>PH@("`@("`@("1T:&ES+3YT:6UE+3YS971$871E*"(R,#`S+3$P+3`T5#$T
M.C`S.C(T(BD["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@*("`@("`@
M("`@("`@)S(P,#,M,3`M,#0@,30Z,#,Z,C0G+`H@("`@("`@("`@("!S<')I
M;G1F*"<E,#1D+24P,F0M)3`R9"`E,#)D.B4P,F0Z)3`R9"<L"B`@("`@("`@
M("`@("`@("`D=&AI<RT^=&EM92T^>65A<BP@)'1H:7,M/G1I;64M/FUO;G1H
M+"`D=&AI<RT^=&EM92T^9&%Y+`H@("`@("`@("`@("`@("`@)'1H:7,M/G1I
M;64M/FAO=7(L("1T:&ES+3YT:6UE+3YM:6YU=&4L("1T:&ES+3YT:6UE+3YS
M96-O;F0I"B`@("`@("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T4V5T
M1&%T951I;65S=&%M<"@I"B`@("!["B`@("`@("`@)'1H:7,M/G1I;64M/G-E
M=$1A=&4H(C(P,#,Q,#`T,30P,S(T(BD["B`@("`@("`@)'1H:7,M/F%S<V5R
M=$5Q=6%L<R@*("`@("`@("`@("`@)S(P,#,M,3`M,#0@,30Z,#,Z,C0G+`H@
M("`@("`@("`@("!S<')I;G1F*"<E,#1D+24P,F0M)3`R9"`E,#)D.B4P,F0Z
M)3`R9"<L"B`@("`@("`@("`@("`@("`D=&AI<RT^=&EM92T^>65A<BP@)'1H
M:7,M/G1I;64M/FUO;G1H+"`D=&AI<RT^=&EM92T^9&%Y+`H@("`@("`@("`@
M("`@("`@)'1H:7,M/G1I;64M/FAO=7(L("1T:&ES+3YT:6UE+3YM:6YU=&4L
M("1T:&ES+3YT:6UE+3YS96-O;F0I"B`@("`@("`@*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!T97-T4V5T1&%T955N:7AT:6UE*"D*("`@('L*("`@("`@("`D
M=&AI<RT^=&EM92T^<V5T1&%T92AS=')T;W1I;64H(C(P,#,M,3`M,#0@,30Z
M,#,Z,C0B*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@*("`@("`@
M("`@("`@)S(P,#,M,3`M,#0@,30Z,#,Z,C0G+`H@("`@("`@("`@("!S<')I
M;G1F*"<E,#1D+24P,F0M)3`R9"`E,#)D.B4P,F0Z)3`R9"<L"B`@("`@("`@
M("`@("`@("`D=&AI<RT^=&EM92T^>65A<BP@)'1H:7,M/G1I;64M/FUO;G1H
M+"`D=&AI<RT^=&EM92T^9&%Y+`H@("`@("`@("`@("`@("`@)'1H:7,M/G1I
M;64M/FAO=7(L("1T:&ES+3YT:6UE+3YM:6YU=&4L("1T:&ES+3YT:6UE+3YS
M96-O;F0I"B`@("`@("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T1V5T
M1&%T94E33R@I"B`@("!["B`@("`@("`@)&1A=&4@/2`D=&AI<RT^=&EM92T^
M9V5T1&%T92A$051%7T9/4DU!5%])4T\I.PH@("`@("`@("1T:&ES+3YA<W-E
M<G1%<75A;',H)S(P,#,M,3`M,#0@,30Z,#,Z,C0G+"`D9&%T92D["B`@("!]
M"@H@("`@9G5N8W1I;VX@=&5S=$=E=$1A=&5)4T]"87-I8R@I"B`@("!["B`@
M("`@("`@)&1A=&4@/2`D=&AI<RT^=&EM92T^9V5T1&%T92A$051%7T9/4DU!
M5%])4T]?0D%324,I.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)S(P
M,#,Q,#`T5#$T,#,R-%HG+"`D9&%T92D["B`@("!]"@H@("`@9G5N8W1I;VX@
M=&5S=$=E=$1A=&5)4T]%>'1E;F1E9"@I"B`@("!["B`@("`@("`@)&1A=&4@
M/2`D=&AI<RT^=&EM92T^9V5T1&%T92A$051%7T9/4DU!5%])4T]?15A414Y$
M140I.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)S(P,#,M,3`M,#14
M,30Z,#,Z,C1:)RP@)&1A=&4I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W1'
M971$871E5&EM97-T86UP*"D*("`@('L*("`@("`@("`D9&%T92`]("1T:&ES
M+3YT:6UE+3YG971$871E*$1!5$5?1D]234%47U1)34535$%-4"D["B`@("`@
M("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@G,C`P,S$P,#0Q-#`S,C0G+"`D9&%T
M92D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=$=E=$1A=&55;FEX=&EM92@I
M"B`@("!["B`@("`@("`@)&1A=&4@/2`D=&AI<RT^=&EM92T^9V5T1&%T92A$
M051%7T9/4DU!5%]53DE85$E-12D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q
M=6%L<RAS=')T;W1I;64H)S(P,#,M,3`M,#0@,30Z,#,Z,C0G*2P@)&1A=&4I
M.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W1&;W)M870H*0H@("`@>PH@("`@
M("`@("1C;V1E<R`](&%R<F%Y*`H@("`@("`@("`@("`G82<@/3X@)U-A="<L
M"B`@("`@("`@("`@("=!)R`]/B`G4V%T=7)D87DG+`H@("`@("`@("`@("`G
M8B<@/3X@)T]C="<L"B`@("`@("`@("`@("=")R`]/B`G3V-T;V)E<B<L"B`@
M("`@("`@("`@("=#)R`]/B`G,C`G+`H@("`@("`@("`@("`G9"<@/3X@)S`T
M)RP*("`@("`@("`@("`@)T0G(#T^("<Q,"\P-"\R,#`S)RP*("`@("`@("`@
M("`@)V4G(#T^("<T)RP*("`@("`@("`@("`@)T@G(#T^("<Q-"<L"B`@("`@
M("`@("`@("=))R`]/B`G,#(G+`H@("`@("`@("`@("`G:B<@/3X@)S(W-R<L
M"B`@("`@("`@("`@("=M)R`]/B`G,3`G+`H@("`@("`@("`@("`G32<@/3X@
M)S`S)RP*("`@("`@("`@("`@)VXG(#T^(")<;B(L"B`@("`@("`@("`@("=/
M)R`]/B`G*S`P.C`P)RP*("`@("`@("`@("`@)V\G(#T^("<K,#`Z,#`G+`H@
M("`@("`@("`@("`G<"<@/3X@)W!M)RP*("`@("`@("`@("`@)U`G(#T^("=0
M32<L"B`@("`@("`@("`@("=R)R`]/B`G,#(Z,#,Z,C0@4$TG+`H@("`@("`@
M("`@("`G4B<@/3X@)S$T.C`S)RP*("`@("`@("`@("`@)U,G(#T^("<R-"<L
M"B`@("`@("`@("`@("=T)R`]/B`B7'0B+`H@("`@("`@("`@("`G5"<@/3X@
M)S$T.C`S.C(T)RP*("`@("`@("`@("`@)W<G(#T^("<V)RP*("`@("`@("`@
M("`@)U4G(#T^("<T,"<L"B`@("`@("`@("`@("=Y)R`]/B`G,#,G+`H@("`@
M("`@("`@("`G62<@/3X@)S(P,#,G+`H@("`@("`@("`@("`G)2<@/3X@)R4G
M"B`@("`@("`@*3L*"B`@("`@("`@9F]R96%C:"`H)&-O9&5S(&%S("1C;V1E
M(#T^("1E>'!E8W1E9"D@>PH@("`@("`@("`@("`D=&AI<RT^87-S97)T17%U
M86QS*`H@("`@("`@("`@("`@("`@(B1C;V1E.B`D97AP96-T960B+"`D=&AI
M<RT^=&EM92T^9F]R;6%T*"(D8V]D93H@)21C;V1E(BD*("`@("`@("`@("`@
M*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=%1O551#8GE/
M9F9S970H*0H@("`@>PH@("`@("`@("1T:&ES+3YT:6UE+3YS97146F)Y240H
M)T535"<I.PH@("`@("`@("1T:&ES+3YT:6UE+3YT;U540R@I.PH@("`@("`@
M("1T96UP(#T@;F5W($1A=&4H(C(P,#,M,3`M,#0@,30Z,#,Z,C0B*3L*("`@
M("`@("`D=&5M<"T^=&]55$-B>4]F9G-E="@B+3`U.C`P(BD["@H@("`@("`@
M("1T:&ES+3YA<W-E<G1%<75A;',H)'1E;7`L("1T:&ES+3YT:6UE*3L*("`@
M('T*"GT*"B\O(')U;G,@=&AE('1E<W1S"B1S=6ET92`](&YE=R!02%!5;FET
M7U1E<W13=6ET92@B1&%T95]497-T(BD["B1R97-U;'0@/2!02%!5;FET.CIR
M=6XH)'-U:71E*3L*+R\@<')I;G1S('1H92!T97-T<PIE8VAO("1R97-U;'0M
M/G1O4W1R:6YG*"D["@H_/@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]T97-T=6YI
M=%]D871E7W-P86XN<&AP````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3(W-S4`,3`U,34T,S,W
M-#(`,#(V-#`V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@
M<VAI9G1W:61T:#TT.B`J+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR
M,#`S($QE86YD<F\@3'5C87)E;&QA("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('1H92!.97<@0E-$(&QI8V5N
M<V4L(%1H870@:7,@8G5N9&QE9"`@?`HO+R!\('=I=&@@=&AI<R!P86-K86=E
M(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R!A=F%I;&%B;&4@=&AR;W5G
M:"`@("`@('P*+R\@?"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS
M92YP:'`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F('1H92!N97<@0E-$;&EC96YS92!A;F0@87)E
M('5N86)L92`@('P*+R\@?"!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("!\"B\O
M('P@<&5A<BUD979`;&ES=',N<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W(Z($QE86YD<F\@3'5C87)E;&QA
M(#QL;'5C87A`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z('1E
M<W1U;FET7V1A=&5?<W!A;BYP:'`L=B`Q+C0@,C`P-2\Q,2\Q-2`P,#HQ-CHT
M,"!P86IO>64@17AP("0*+R\*"G)E<75I<F5?;VYC92`G1&%T92YP:'`G.PIR
M97%U:7)E7V]N8V4@)T1A=&4O4W!A;BYP:'`G.PIR97%U:7)E7V]N8V4@)U!(
M4%5N:70N<&AP)SL*"B\J*@H@*B!497-T(&-A<V4@9F]R($1A=&5?4W!A;@H@
M*@H@*B!`<&%C:V%G92!$871E"B`J($!A=71H;W(@3&5A;F1R;R!,=6-A<F5L
M;&$@/&QL=6-A>$!P:'`N;F5T/@H@*B\*8VQA<W,@1&%T95]3<&%N5&5S="!E
M>'1E;F1S(%!(4%5N:71?5&5S=$-A<V4@>PH*("`@('9A<B`D=&EM93L*"B`@
M("!F=6YC=&EO;B!$871E7U-P86Y497-T*"1N86UE*2!["B`@("`@("`@)'1H
M:7,M/E!(4%5N:71?5&5S=$-A<V4H)&YA;64I.PH@("`@?0H*("`@(&9U;F-T
M:6]N('-E=%5P*"D@>PH@("`@("`@("1T:&ES+3YT:6UE(#T@;F5W($1A=&5?
M4W!A;B@Y-S4S,2D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5A<D1O=VXH*2![
M"B`@("`@("`@=6YS970H)'1H:7,M/G1I;64I.PH@("`@?0H*("`@(&9U;F-T
M:6]N('1E<W13971&<F]M07)R87DH*2!["B`@("`@("`@)'1H:7,M/G1I;64M
M/G-E=$9R;VU!<G)A>2AA<G)A>2@U+"`T."XU+"`R."XU+"`S,2DI.PH@("`@
M("`@("1T:&ES+3YA<W-E<G1%<75A;',H"B`@("`@("`@("`@("<W.C`Z-3DZ
M,2<L"B`@("`@("`@("`@('-P<FEN=&8H)R5D.B5D.B5D.B5D)RP@)'1H:7,M
M/G1I;64M/F1A>2P@)'1H:7,M/G1I;64M/FAO=7(L"B`@("`@("`@("`@("`@
M("`D=&AI<RT^=&EM92T^;6EN=71E+"`D=&AI<RT^=&EM92T^<V5C;VYD*0H@
M("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=%-E=$9R;VU3=')I
M;F<H*2!["B`@("`@("`@)'1H:7,M/G1I;64M/G-E=$9R;VU3=')I;F<H)S4Z
M,#`Z-3DZ,S$G*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*`H@("`@
M("`@("`@("`G-3HP.C4Y.C,Q)RP*("`@("`@("`@("`@<W!R:6YT9B@G)60Z
M)60Z)60Z)60G+"`D=&AI<RT^=&EM92T^9&%Y+"`D=&AI<RT^=&EM92T^:&]U
M<BP*("`@("`@("`@("`@("`@("1T:&ES+3YT:6UE+3YM:6YU=&4L("1T:&ES
M+3YT:6UE+3YS96-O;F0I"B`@("`@("`@*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!T97-T4V5T1G)O;5-E8V]N9',H*2!["B`@("`@("`@)'1H:7,M/G1I;64M
M/G-E=$9R;VU396-O;F1S*#0S-#,T-"D["B`@("`@("`@)'1H:7,M/F%S<V5R
M=$5Q=6%L<R@*("`@("`@("`@("`@)S4Z,#HS.3HT)RP*("`@("`@("`@("`@
M<W!R:6YT9B@G)60Z)60Z)60Z)60G+"`D=&AI<RT^=&EM92T^9&%Y+"`D=&AI
M<RT^=&EM92T^:&]U<BP*("`@("`@("`@("`@("`@("1T:&ES+3YT:6UE+3YM
M:6YU=&4L("1T:&ES+3YT:6UE+3YS96-O;F0I"B`@("`@("`@*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!T97-T4V5T1G)O;4UI;G5T97,H*2!["B`@("`@("`@
M)'1H:7,M/G1I;64M/G-E=$9R;VU-:6YU=&5S*#<X-C`N,#$V-C8V-C8V-BD[
M"B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@*("`@("`@("`@("`@)S4Z
M,3$Z,#HQ)RP*("`@("`@("`@("`@<W!R:6YT9B@G)60Z)60Z)60Z)60G+"`D
M=&AI<RT^=&EM92T^9&%Y+"`D=&AI<RT^=&EM92T^:&]U<BP*("`@("`@("`@
M("`@("`@("1T:&ES+3YT:6UE+3YM:6YU=&4L("1T:&ES+3YT:6UE+3YS96-O
M;F0I"B`@("`@("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T4V5T1G)O
M;4AO=7)S*"D@>PH@("`@("`@("1T:&ES+3YT:6UE+3YS971&<F]M2&]U<G,H
M-3`N,3(S-#4I.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H"B`@("`@
M("`@("`@("<R.C(Z-SHR-"<L"B`@("`@("`@("`@('-P<FEN=&8H)R5D.B5D
M.B5D.B5D)RP@)'1H:7,M/G1I;64M/F1A>2P@)'1H:7,M/G1I;64M/FAO=7(L
M"B`@("`@("`@("`@("`@("`D=&AI<RT^=&EM92T^;6EN=71E+"`D=&AI<RT^
M=&EM92T^<V5C;VYD*0H@("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@
M=&5S=%-E=$9R;VU$87ES*"D@>PH@("`@("`@("1T:&ES+3YT:6UE+3YS971&
M<F]M1&%Y<RAP:2@I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*`H@
M("`@("`@("`@("`G,SHS.C(S.C4T)RP*("`@("`@("`@("`@<W!R:6YT9B@G
M)60Z)60Z)60Z)60G+"`D=&AI<RT^=&EM92T^9&%Y+"`D=&AI<RT^=&EM92T^
M:&]U<BP*("`@("`@("`@("`@("`@("1T:&ES+3YT:6UE+3YM:6YU=&4L("1T
M:&ES+3YT:6UE+3YS96-O;F0I"B`@("`@("`@*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!T97-T4V5T1G)O;41A=&5$:69F*"D@>PH@("`@("`@("1T:&ES+3YT
M:6UE+3YS971&<F]M1&%T941I9F8H"B`@("`@("`@("`@(&YE=R!$871E*"<R
M,#`T+3`S+3$P(#`Q.C$U.C4Y)RDL"B`@("`@("`@("`@(&YE=R!$871E*"<R
M,#`S+3`S+3$P(#`P.C$P.C4P)RD*("`@("`@("`I.PH@("`@("`@("1T:&ES
M+3YA<W-E<G1%<75A;',H"B`@("`@("`@("`@("<S-C8Z,3HU.CDG+`H@("`@
M("`@("`@("!S<')I;G1F*"<E9#HE9#HE9#HE9"<L("1T:&ES+3YT:6UE+3YD
M87DL("1T:&ES+3YT:6UE+3YH;W5R+`H@("`@("`@("`@("`@("`@)'1H:7,M
M/G1I;64M/FUI;G5T92P@)'1H:7,M/G1I;64M/G-E8V]N9"D*("`@("`@("`I
M.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W1#;W!Y*"D@>PH@("`@("`@("1T
M:6UE(#T@;F5W($1A=&5?4W!A;B@I.PH@("`@("`@("1T:6UE+3YC;W!Y*"1T
M:&ES+3YT:6UE*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*`H@("`@
M("`@("`@("!S<')I;G1F*"<E9#HE9#HE9#HE9"<L("1T:&ES+3YT:6UE+3YD
M87DL("1T:&ES+3YT:6UE+3YH;W5R+`H@("`@("`@("`@("`@("`@)'1H:7,M
M/G1I;64M/FUI;G5T92P@)'1H:7,M/G1I;64M/G-E8V]N9"DL"B`@("`@("`@
M("`@('-P<FEN=&8H)R5D.B5D.B5D.B5D)RP@)'1I;64M/F1A>2P@)'1I;64M
M/FAO=7(L"B`@("`@("`@("`@("`@("`D=&EM92T^;6EN=71E+"`D=&EM92T^
M<V5C;VYD*0H@("`@("`@("D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=$9O
M<FUA="@I('L*("`@("`@("`D8V]D97,@/2!A<G)A>2@*("`@("`@("`@("`@
M)T,G(#T^("<Q+"`P,SHP-3HS,2<L"B`@("`@("`@("`@("=D)R`]/B`G,2XQ
M,C@X,S$P,3@U,3@U)RP*("`@("`@("`@("`@)T0G(#T^("<Q)RP*("`@("`@
M("`@("`@)V4G(#T^("<R-RXP.3$Y-#0T-#0T-#0G+`H@("`@("`@("`@("`G
M9B<@/3X@)S$V,C4N-3$V-C8V-C8V-R<L"B`@("`@("`@("`@("=G)R`]/B`G
M.3<U,S$G+`H@("`@("`@("`@("`G:"<@/3X@)S,G+`H@("`@("`@("`@("`G
M2"<@/3X@)S`S)RP*("`@("`@("`@("`@)VDG(#T^("<S)RP*("`@("`@("`@
M("`@)TDG(#T^("<P,R<L"B`@("`@("`@("`@("=M)R`]/B`G-2<L"B`@("`@
M("`@("`@("=-)R`]/B`G,#4G+`H@("`@("`@("`@("`G;B<@/3X@(EQN(BP*
M("`@("`@("`@("`@)W`G(#T^("=A;2<L"B`@("`@("`@("`@("=0)R`]/B`G
M04TG+`H@("`@("`@("`@("`G<B<@/3X@)S`S.C`U.C,Q(&%M)RP*("`@("`@
M("`@("`@)U(G(#T^("<P,SHP-2<L"B`@("`@("`@("`@("=S)R`]/B`G,S$G
M+`H@("`@("`@("`@("`G4R<@/3X@)S,Q)RP*("`@("`@("`@("`@)W0G(#T^
M(")<="(L"B`@("`@("`@("`@("=4)R`]/B`G,#,Z,#4Z,S$G+`H@("`@("`@
M("`@("`G)2<@/3X@)R4G+`H@("`@("`@("D["B`@("`@("`@9F]R96%C:"`H
M)&-O9&5S(&%S("1C;V1E(#T^("1E>'!E8W1E9"D@>PH@("`@("`@("`@("`D
M=&AI<RT^87-S97)T17%U86QS*`H@("`@("`@("`@("`@("`@(B1C;V1E.B`D
M97AP96-T960B+"`D=&AI<RT^=&EM92T^9F]R;6%T*"(D8V]D93H@)21C;V1E
M(BD*("`@("`@("`@("`@*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I
M;VX@=&5S=$%D9"@I('L*("`@("`@("`D=&AI<RT^=&EM92T^861D*&YE=R!$
M871E7U-P86XH-C`P,"DI.PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^=&EM
M92T^=&]396-O;F1S*"D["B`@("`@("`@)&5X<&5C=&5D(#T@,3`S-3,Q.PH@
M("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)&5X<&5C=&5D+"`D<F5S=6QT
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T4W5B=')A8W0H*2!["B`@("`@
M("`@)'1H:7,M/G1I;64M/G-U8G1R86-T*&YE=R!$871E7U-P86XH-C`P,"DI
M.PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^=&EM92T^=&]396-O;F1S*"D[
M"B`@("`@("`@)&5X<&5C=&5D(#T@.3$U,S$["B`@("`@("`@)'1H:7,M/F%S
M<V5R=$5Q=6%L<R@D97AP96-T960L("1R97-U;'0I.PH@("`@?0H*?0H*+R\@
M<G5N<R!T:&4@=&5S=',*)'-U:71E(#T@;F5W(%!(4%5N:71?5&5S=%-U:71E
M*")$871E7U-P86Y497-T(BD["B1R97-U;'0@/2!02%!5;FET.CIR=6XH)'-U
M:71E*3L*+R\@<')I;G1S('1H92!T97-T<PIE8VAO("1R97-U;'0M/G1O4W1R
M:6YG*"D["@H_/@H````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M=&5S=',O1&%T92]T97-T<R]W965K<VEN;6]N=&A?-%]M;VYD87DN='AT````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`R-C0`,3`U,34T,S,W-#(`,#(W,#,T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#$Y.3DO,B\T"C(P,3`O
M,B\T"C(P,C$O,B\T"C(P,C<O,B\T"C$Y,S<O,B\T"C$Y-#,O,B\T"C$X,#(O
M,B\T"C$X,3,O,B\T"C$X,3DO,B\T"C$X,S`O,B\T"C$X-#$O,B\T"C$X-#<O
M,B\T"C$X-3@O,B\T"C$X-CDO,B\T"C$X-S4O,B\T"C$X.#8O,B\T"C$X.3<O
M,B\T"C$Y,#DO,B\T"C$Y,34O,B\T"C$Y,C8O,B\T"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1A=&4O
M=&5S=',O=V5E:W-I;FUO;G1H7S1?<W5N9&%Y+G1X=```````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,C8T`#$P-3$U-#,S-S0R`#`R-S`U,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````R,#`Y+S(O-`HR,#$U+S(O-`HR,#(V+S(O
M-`HR,#,W+S(O-`HQ.3,Q+S(O-`HQ.30R+S(O-`HQ.#`Q+S(O-`HQ.#`W+S(O
M-`HQ.#$X+S(O-`HQ.#(Y+S(O-`HQ.#,U+S(O-`HQ.#0V+S(O-`HQ.#4W+S(O
M-`HQ.#8S+S(O-`HQ.#<T+S(O-`HQ.#@U+S(O-`HQ.#DQ+S(O-`HQ.3`S+S(O
M-`HQ.3$T+S(O-`HQ.3(U+S(O-`H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+W=E96MS
M:6YM;VYT:%]R9&U?;6]N9&%Y+G1X=```````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S(Q-@`Q,#4Q-30S
M,S<T,@`P,C<T-3<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````,3DY.2\X+S8*,C`P,"\Q,"\V"C(P,#$O,3(O-@HR,#`R+S$R
M+S8*,C`P,R\V+S8*,C`P-"\X+S8*,C`P-2\Q,"\V"C(P,#8O,3`O-@HR,#`W
M+S$R+S8*,C`P."\V+S8*,C`P.2\Q,2\V"C(P,3`O."\V"C(P,3$O,3`O-@HR
M,#$R+S$R+S8*,C`Q,R\Q,B\V"C(P,30O-B\V"C(P,34O,3$O-@HR,#$V+S$P
M+S8*,C`Q-R\Q,"\V"C(P,3@O,3(O-@HR,#$Y+S$R+S8*,C`R,"\Q,2\V"C(P
M,C$O."\V"C(P,C(O,3`O-@HR,#(S+S$P+S8*,C`R-"\Q,B\V"C(P,C4O-B\V
M"C(P,C8O,3$O-@HR,#(W+S@O-@HR,#(X+S$P+S8*,C`R.2\Q,B\V"C(P,S`O
M,3(O-@HR,#,Q+S8O-@HR,#,R+S@O-@HR,#,S+S$P+S8*,C`S-"\Q,"\V"C(P
M,S4O,3(O-@HR,#,V+S8O-@HR,#,W+S$Q+S8*,3DS,"\V+S8*,3DS,2\Q,2\V
M"C$Y,S(O,3`O-@HQ.3,S+S$P+S8*,3DS-"\Q,B\V"C$Y,S4O,3(O-@HQ.3,V
M+S$Q+S8*,3DS-R\X+S8*,3DS."\Q,"\V"C$Y,SDO,3`O-@HQ.30P+S$R+S8*
M,3DT,2\V+S8*,3DT,B\Q,2\V"C$Y-#,O."\V"C$Y-#0O,3`O-@HQ.30U+S$R
M+S8*,3DT-B\Q,B\V"C$Y-#<O-B\V"C$Y-#@O."\V"C$Y-#DO,3`O-@HQ.#`P
M+S8O-@HQ.#`Q+S$Q+S8*,3@P,B\X+S8*,3@P,R\Q,"\V"C$X,#0O,3(O-@HQ
M.#`U+S$R+S8*,3@P-B\V+S8*,3@P-R\Q,2\V"C$X,#@O,3`O-@HQ.#`Y+S$P
M+S8*,3@Q,"\Q,B\V"C$X,3$O,3(O-@HQ.#$R+S$Q+S8*,3@Q,R\X+S8*,3@Q
M-"\Q,"\V"C$X,34O,3`O-@HQ.#$V+S$R+S8*,3@Q-R\V+S8*,3@Q."\Q,2\V
M"C$X,3DO."\V"C$X,C`O,3`O-@HQ.#(Q+S$R+S8*,3@R,B\Q,B\V"C$X,C,O
M-B\V"C$X,C0O."\V"C$X,C4O,3`O-@HQ.#(V+S$P+S8*,3@R-R\Q,B\V"C$X
M,C@O-B\V"C$X,CDO,3$O-@HQ.#,P+S@O-@HQ.#,Q+S$P+S8*,3@S,B\Q,B\V
M"C$X,S,O,3(O-@HQ.#,T+S8O-@HQ.#,U+S$Q+S8*,3@S-B\Q,"\V"C$X,S<O
M,3`O-@HQ.#,X+S$R+S8*,3@S.2\Q,B\V"C$X-#`O,3$O-@HQ.#0Q+S@O-@HQ
M.#0R+S$P+S8*,3@T,R\Q,"\V"C$X-#0O,3(O-@HQ.#0U+S8O-@HQ.#0V+S$Q
M+S8*,3@T-R\X+S8*,3@T."\Q,"\V"C$X-#DO,3(O-@HQ.#4P+S$R+S8*,3@U
M,2\V+S8*,3@U,B\X+S8*,3@U,R\Q,"\V"C$X-30O,3`O-@HQ.#4U+S$R+S8*
M,3@U-B\V+S8*,3@U-R\Q,2\V"C$X-3@O."\V"C$X-3DO,3`O-@HQ.#8P+S$R
M+S8*,3@V,2\Q,B\V"C$X-C(O-B\V"C$X-C,O,3$O-@HQ.#8T+S$P+S8*,3@V
M-2\Q,"\V"C$X-C8O,3(O-@HQ.#8W+S$R+S8*,3@V."\Q,2\V"C$X-CDO."\V
M"C$X-S`O,3`O-@HQ.#<Q+S$P+S8*,3@W,B\Q,B\V"C$X-S,O-B\V"C$X-S0O
M,3$O-@HQ.#<U+S@O-@HQ.#<V+S$P+S8*,3@W-R\Q,B\V"C$X-S@O,3(O-@HQ
M.#<Y+S8O-@HQ.#@P+S@O-@HQ.#@Q+S$P+S8*,3@X,B\Q,"\V"C$X.#,O,3(O
M-@HQ.#@T+S8O-@HQ.#@U+S$Q+S8*,3@X-B\X+S8*,3@X-R\Q,"\V"C$X.#@O
M,3(O-@HQ.#@Y+S$R+S8*,3@Y,"\V+S8*,3@Y,2\Q,2\V"C$X.3(O,3`O-@HQ
M.#DS+S$P+S8*,3@Y-"\Q,B\V"C$X.34O,3(O-@HQ.#DV+S$Q+S8*,3@Y-R\X
M+S8*,3@Y."\Q,"\V"C$X.3DO,3`O-@HQ.3`P+S$R+S8*,3DP,2\Q,B\V"C$Y
M,#(O-B\V"C$Y,#,O,3$O-@HQ.3`T+S$P+S8*,3DP-2\Q,"\V"C$Y,#8O,3(O
M-@HQ.3`W+S$R+S8*,3DP."\Q,2\V"C$Y,#DO."\V"C$Y,3`O,3`O-@HQ.3$Q
M+S$P+S8*,3DQ,B\Q,B\V"C$Y,3,O-B\V"C$Y,30O,3$O-@HQ.3$U+S@O-@HQ
M.3$V+S$P+S8*,3DQ-R\Q,B\V"C$Y,3@O,3(O-@HQ.3$Y+S8O-@HQ.3(P+S@O
M-@HQ.3(Q+S$P+S8*,3DR,B\Q,"\V"C$Y,C,O,3(O-@HQ.3(T+S8O-@HQ.3(U
M+S$Q+S8*,3DR-B\X+S8*,3DR-R\Q,"\V"C$Y,C@O,3(O-@HQ.3(Y+S$R+S8*
M,3DY.2\Q,B\U"C(P,#`O,3(O-0HR,#`Q+S$Q+S4*,C`P,B\Q,2\U"C(P,#,O
M,3(O-0HR,#`T+S$R+S4*,C`P-2\Q,B\U"C(P,#8O,3(O-0HR,#`W+S$Q+S4*
M,C`P."\Q,B\U"C(P,#DO,3(O-0HR,#$P+S$R+S4*,C`Q,2\Q,B\U"C(P,3(O
M,3$O-0HR,#$S+S$Q+S4*,C`Q-"\Q,B\U"C(P,34O,3(O-0HR,#$V+S$R+S4*
M,C`Q-R\Q,B\U"C(P,3@O,3$O-0HR,#$Y+S$Q+S4*,C`R,"\Q,B\U"C(P,C$O
M,3(O-0HR,#(R+S$R+S4*,C`R,R\Q,B\U"C(P,C0O,3$O-0HR,#(U+S$R+S4*
M,C`R-B\Q,B\U"C(P,C<O,3(O-0HR,#(X+S$R+S4*,C`R.2\Q,2\U"C(P,S`O
M,3$O-0HR,#,Q+S$R+S4*,C`S,B\Q,B\U"C(P,S,O,3(O-0HR,#,T+S$R+S4*
M,C`S-2\Q,2\U"C(P,S8O,3(O-0HR,#,W+S$R+S4*,3DS,"\Q,B\U"C$Y,S$O
M,3(O-0HQ.3,R+S$R+S4*,3DS,R\Q,B\U"C$Y,S0O,3$O-0HQ.3,U+S$Q+S4*
M,3DS-B\Q,B\U"C$Y,S<O,3(O-0HQ.3,X+S$R+S4*,3DS.2\Q,B\U"C$Y-#`O
M,3$O-0HQ.30Q+S$R+S4*,3DT,B\Q,B\U"C$Y-#,O,3(O-0HQ.30T+S$R+S4*
M,3DT-2\Q,2\U"C$Y-#8O,3$O-0HQ.30W+S$R+S4*,3DT."\Q,B\U"C$Y-#DO
M,3(O-0HQ.#`P+S$R+S4*,3@P,2\Q,B\U"C$X,#(O,3(O-0HQ.#`S+S$R+S4*
M,3@P-"\Q,2\U"C$X,#4O,3$O-0HQ.#`V+S$R+S4*,3@P-R\Q,B\U"C$X,#@O
M,3(O-0HQ.#`Y+S$R+S4*,3@Q,"\Q,2\U"C$X,3$O,3$O-0HQ.#$R+S$R+S4*
M,3@Q,R\Q,B\U"C$X,30O,3(O-0HQ.#$U+S$R+S4*,3@Q-B\Q,2\U"C$X,3<O
M,3(O-0HQ.#$X+S$R+S4*,3@Q.2\Q,B\U"C$X,C`O,3(O-0HQ.#(Q+S$Q+S4*
M,3@R,B\Q,2\U"C$X,C,O,3(O-0HQ.#(T+S$R+S4*,3@R-2\Q,B\U"C$X,C8O
M,3(O-0HQ.#(W+S$Q+S4*,3@R."\Q,B\U"C$X,CDO,3(O-0HQ.#,P+S$R+S4*
M,3@S,2\Q,B\U"C$X,S(O,3$O-0HQ.#,S+S$Q+S4*,3@S-"\Q,B\U"C$X,S4O
M,3(O-0HQ.#,V+S$R+S4*,3@S-R\Q,B\U"C$X,S@O,3$O-0HQ.#,Y+S$Q+S4*
M,3@T,"\Q,B\U"C$X-#$O,3(O-0HQ.#0R+S$R+S4*,3@T,R\Q,B\U"C$X-#0O
M,3$O-0HQ.#0U+S$R+S4*,3@T-B\Q,B\U"C$X-#<O,3(O-0HQ.#0X+S$R+S4*
M,3@T.2\Q,2\U"C$X-3`O,3$O-0HQ.#4Q+S$R+S4*,3@U,B\Q,B\U"C$X-3,O
M,3(O-0HQ.#4T+S$R+S4*,3@U-2\Q,2\U"C$X-38O,3(O-0HQ.#4W+S$R+S4*
M,3@U."\Q,B\U"C$X-3DO,3(O-0HQ.#8P+S$Q+S4*,3@V,2\Q,2\U"C$X-C(O
M,3(O-0HQ.#8S+S$R+S4*,3@V-"\Q,B\U"C$X-C4O,3(O-0HQ.#8V+S$Q+S4*
M,3@V-R\Q,2\U"C$X-C@O,3(O-0HQ.#8Y+S$R+S4*,3@W,"\Q,B\U"C$X-S$O
M,3(O-0HQ.#<R+S$Q+S4*,3@W,R\Q,B\U"C$X-S0O,3(O-0HQ.#<U+S$R+S4*
M,3@W-B\Q,B\U"C$X-S<O,3$O-0HQ.#<X+S$Q+S4*,3@W.2\Q,B\U"C$X.#`O
M,3(O-0HQ.#@Q+S$R+S4*,3@X,B\Q,B\U"C$X.#,O,3$O-0HQ.#@T+S$R+S4*
M,3@X-2\Q,B\U"C$X.#8O,3(O-0HQ.#@W+S$R+S4*,3@X."\Q,2\U"C$X.#DO
M,3$O-0HQ.#DP+S$R+S4*,3@Y,2\Q,B\U"C$X.3(O,3(O-0HQ.#DS+S$R+S4*
M,3@Y-"\Q,2\U"C$X.34O,3$O-0HQ.#DV+S$R+S4*,3@Y-R\Q,B\U"C$X.3@O
M,3(O-0HQ.#DY+S$R+S4*,3DP,"\Q,2\U"C$Y,#$O,3$O-0HQ.3`R+S$R+S4*
M,3DP,R\Q,B\U"C$Y,#0O,3(O-0HQ.3`U+S$R+S4*,3DP-B\Q,2\U"C$Y,#<O
M,3$O-0HQ.3`X+S$R+S4*,3DP.2\Q,B\U"C$Y,3`O,3(O-0HQ.3$Q+S$R+S4*
M,3DQ,B\Q,2\U"C$Y,3,O,3(O-0HQ.3$T+S$R+S4*,3DQ-2\Q,B\U"C$Y,38O
M,3(O-0HQ.3$W+S$Q+S4*,3DQ."\Q,2\U"C$Y,3DO,3(O-0HQ.3(P+S$R+S4*
M,3DR,2\Q,B\U"C$Y,C(O,3(O-0HQ.3(S+S$Q+S4*,3DR-"\Q,B\U"C$Y,C4O
M,3(O-0HQ.3(V+S$R+S4*,3DR-R\Q,B\U"C$Y,C@O,3$O-0HQ.3(Y+S$Q+S4*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T
M<R]$871E+W1E<W1S+W=E96MS:6YM;VYT:%]R9&U?<W5N9&%Y+G1X=```````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-S(Q-@`Q,#4Q-30S,S<T,@`P,C<T-S,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````,3DY.2\Q,B\U"C(P,#`O,3$O
M-0HR,#`Q+S$Q+S4*,C`P,B\Q,B\U"C(P,#,O,3(O-0HR,#`T+S$R+S4*,C`P
M-2\Q,B\U"C(P,#8O,3$O-0HR,#`W+S$Q+S4*,C`P."\Q,B\U"C(P,#DO,3(O
M-0HR,#$P+S$R+S4*,C`Q,2\Q,B\U"C(P,3(O,3$O-0HR,#$S+S$R+S4*,C`Q
M-"\Q,B\U"C(P,34O,3(O-0HR,#$V+S$R+S4*,C`Q-R\Q,2\U"C(P,3@O,3$O
M-0HR,#$Y+S$R+S4*,C`R,"\Q,B\U"C(P,C$O,3(O-0HR,#(R+S$R+S4*,C`R
M,R\Q,2\U"C(P,C0O,3(O-0HR,#(U+S$R+S4*,C`R-B\Q,B\U"C(P,C<O,3(O
M-0HR,#(X+S$Q+S4*,C`R.2\Q,2\U"C(P,S`O,3(O-0HR,#,Q+S$R+S4*,C`S
M,B\Q,B\U"C(P,S,O,3(O-0HR,#,T+S$Q+S4*,C`S-2\Q,2\U"C(P,S8O,3(O
M-0HR,#,W+S$R+S4*,3DS,"\Q,B\U"C$Y,S$O,3(O-0HQ.3,R+S$R+S4*,3DS
M,R\Q,2\U"C$Y,S0O,3$O-0HQ.3,U+S$R+S4*,3DS-B\Q,B\U"C$Y,S<O,3(O
M-0HQ.3,X+S$R+S4*,3DS.2\Q,2\U"C$Y-#`O,3(O-0HQ.30Q+S$R+S4*,3DT
M,B\Q,B\U"C$Y-#,O,3(O-0HQ.30T+S$Q+S4*,3DT-2\Q,2\U"C$Y-#8O,3(O
M-0HQ.30W+S$R+S4*,3DT."\Q,B\U"C$Y-#DO,3(O-0HQ.#`P+S$R+S4*,3@P
M,2\Q,B\U"C$X,#(O,3(O-0HQ.#`S+S$R+S4*,3@P-"\Q,2\U"C$X,#4O,3(O
M-0HQ.#`V+S$R+S4*,3@P-R\Q,B\U"C$X,#@O,3(O-0HQ.#`Y+S$Q+S4*,3@Q
M,"\Q,2\U"C$X,3$O,3(O-0HQ.#$R+S$R+S4*,3@Q,R\Q,B\U"C$X,30O,3(O
M-0HQ.#$U+S$Q+S4*,3@Q-B\Q,B\U"C$X,3<O,3(O-0HQ.#$X+S$R+S4*,3@Q
M.2\Q,B\U"C$X,C`O,3$O-0HQ.#(Q+S$Q+S4*,3@R,B\Q,B\U"C$X,C,O,3(O
M-0HQ.#(T+S$R+S4*,3@R-2\Q,B\U"C$X,C8O,3$O-0HQ.#(W+S$Q+S4*,3@R
M."\Q,B\U"C$X,CDO,3(O-0HQ.#,P+S$R+S4*,3@S,2\Q,B\U"C$X,S(O,3$O
M-0HQ.#,S+S$R+S4*,3@S-"\Q,B\U"C$X,S4O,3(O-0HQ.#,V+S$R+S4*,3@S
M-R\Q,2\U"C$X,S@O,3$O-0HQ.#,Y+S$R+S4*,3@T,"\Q,B\U"C$X-#$O,3(O
M-0HQ.#0R+S$R+S4*,3@T,R\Q,2\U"C$X-#0O,3(O-0HQ.#0U+S$R+S4*,3@T
M-B\Q,B\U"C$X-#<O,3(O-0HQ.#0X+S$Q+S4*,3@T.2\Q,2\U"C$X-3`O,3(O
M-0HQ.#4Q+S$R+S4*,3@U,B\Q,B\U"C$X-3,O,3(O-0HQ.#4T+S$Q+S4*,3@U
M-2\Q,2\U"C$X-38O,3(O-0HQ.#4W+S$R+S4*,3@U."\Q,B\U"C$X-3DO,3(O
M-0HQ.#8P+S$Q+S4*,3@V,2\Q,B\U"C$X-C(O,3(O-0HQ.#8S+S$R+S4*,3@V
M-"\Q,B\U"C$X-C4O,3$O-0HQ.#8V+S$Q+S4*,3@V-R\Q,B\U"C$X-C@O,3(O
M-0HQ.#8Y+S$R+S4*,3@W,"\Q,B\U"C$X-S$O,3$O-0HQ.#<R+S$R+S4*,3@W
M,R\Q,B\U"C$X-S0O,3(O-0HQ.#<U+S$R+S4*,3@W-B\Q,2\U"C$X-S<O,3$O
M-0HQ.#<X+S$R+S4*,3@W.2\Q,B\U"C$X.#`O,3(O-0HQ.#@Q+S$R+S4*,3@X
M,B\Q,2\U"C$X.#,O,3$O-0HQ.#@T+S$R+S4*,3@X-2\Q,B\U"C$X.#8O,3(O
M-0HQ.#@W+S$R+S4*,3@X."\Q,2\U"C$X.#DO,3(O-0HQ.#DP+S$R+S4*,3@Y
M,2\Q,B\U"C$X.3(O,3(O-0HQ.#DS+S$Q+S4*,3@Y-"\Q,2\U"C$X.34O,3(O
M-0HQ.#DV+S$R+S4*,3@Y-R\Q,B\U"C$X.3@O,3(O-0HQ.#DY+S$Q+S4*,3DP
M,"\Q,2\U"C$Y,#$O,3(O-0HQ.3`R+S$R+S4*,3DP,R\Q,B\U"C$Y,#0O,3(O
M-0HQ.3`U+S$Q+S4*,3DP-B\Q,2\U"C$Y,#<O,3(O-0HQ.3`X+S$R+S4*,3DP
M.2\Q,B\U"C$Y,3`O,3(O-0HQ.3$Q+S$Q+S4*,3DQ,B\Q,B\U"C$Y,3,O,3(O
M-0HQ.3$T+S$R+S4*,3DQ-2\Q,B\U"C$Y,38O,3$O-0HQ.3$W+S$Q+S4*,3DQ
M."\Q,B\U"C$Y,3DO,3(O-0HQ.3(P+S$R+S4*,3DR,2\Q,B\U"C$Y,C(O,3$O
M-0HQ.3(S+S$Q+S4*,3DR-"\Q,B\U"C$Y,C4O,3(O-0HQ.3(V+S$R+S4*,3DR
M-R\Q,B\U"C$Y,C@O,3$O-0HQ.3(Y+S$R+S4*,3DY.2\Q,"\V"C(P,#`O,3(O
M-@HR,#`Q+S$R+S8*,C`P,B\V+S8*,C`P,R\Q,2\V"C(P,#0O,3`O-@HR,#`U
M+S$P+S8*,C`P-B\Q,B\V"C(P,#<O,3(O-@HR,#`X+S$Q+S8*,C`P.2\X+S8*
M,C`Q,"\Q,"\V"C(P,3$O,3`O-@HR,#$R+S$R+S8*,C`Q,R\V+S8*,C`Q-"\Q
M,2\V"C(P,34O."\V"C(P,38O,3`O-@HR,#$W+S$R+S8*,C`Q."\Q,B\V"C(P
M,3DO-B\V"C(P,C`O."\V"C(P,C$O,3`O-@HR,#(R+S$P+S8*,C`R,R\Q,B\V
M"C(P,C0O-B\V"C(P,C4O,3$O-@HR,#(V+S@O-@HR,#(W+S$P+S8*,C`R."\Q
M,B\V"C(P,CDO,3(O-@HR,#,P+S8O-@HR,#,Q+S$Q+S8*,C`S,B\Q,"\V"C(P
M,S,O,3`O-@HR,#,T+S$R+S8*,C`S-2\Q,B\V"C(P,S8O,3$O-@HR,#,W+S@O
M-@HQ.3,P+S$Q+S8*,3DS,2\X+S8*,3DS,B\Q,"\V"C$Y,S,O,3(O-@HQ.3,T
M+S$R+S8*,3DS-2\V+S8*,3DS-B\X+S8*,3DS-R\Q,"\V"C$Y,S@O,3`O-@HQ
M.3,Y+S$R+S8*,3DT,"\V+S8*,3DT,2\Q,2\V"C$Y-#(O."\V"C$Y-#,O,3`O
M-@HQ.30T+S$R+S8*,3DT-2\Q,B\V"C$Y-#8O-B\V"C$Y-#<O,3$O-@HQ.30X
M+S$P+S8*,3DT.2\Q,"\V"C$X,#`O,3$O-@HQ.#`Q+S@O-@HQ.#`R+S$P+S8*
M,3@P,R\Q,"\V"C$X,#0O,3(O-@HQ.#`U+S8O-@HQ.#`V+S$Q+S8*,3@P-R\X
M+S8*,3@P."\Q,"\V"C$X,#DO,3(O-@HQ.#$P+S$R+S8*,3@Q,2\V+S8*,3@Q
M,B\X+S8*,3@Q,R\Q,"\V"C$X,30O,3`O-@HQ.#$U+S$R+S8*,3@Q-B\V+S8*
M,3@Q-R\Q,2\V"C$X,3@O."\V"C$X,3DO,3`O-@HQ.#(P+S$R+S8*,3@R,2\Q
M,B\V"C$X,C(O-B\V"C$X,C,O,3$O-@HQ.#(T+S$P+S8*,3@R-2\Q,"\V"C$X
M,C8O,3(O-@HQ.#(W+S$R+S8*,3@R."\Q,2\V"C$X,CDO."\V"C$X,S`O,3`O
M-@HQ.#,Q+S$P+S8*,3@S,B\Q,B\V"C$X,S,O-B\V"C$X,S0O,3$O-@HQ.#,U
M+S@O-@HQ.#,V+S$P+S8*,3@S-R\Q,B\V"C$X,S@O,3(O-@HQ.#,Y+S8O-@HQ
M.#0P+S@O-@HQ.#0Q+S$P+S8*,3@T,B\Q,"\V"C$X-#,O,3(O-@HQ.#0T+S8O
M-@HQ.#0U+S$Q+S8*,3@T-B\X+S8*,3@T-R\Q,"\V"C$X-#@O,3(O-@HQ.#0Y
M+S$R+S8*,3@U,"\V+S8*,3@U,2\Q,2\V"C$X-3(O,3`O-@HQ.#4S+S$P+S8*
M,3@U-"\Q,B\V"C$X-34O,3(O-@HQ.#4V+S$Q+S8*,3@U-R\X+S8*,3@U."\Q
M,"\V"C$X-3DO,3`O-@HQ.#8P+S$R+S8*,3@V,2\V+S8*,3@V,B\Q,2\V"C$X
M-C,O."\V"C$X-C0O,3`O-@HQ.#8U+S$R+S8*,3@V-B\Q,B\V"C$X-C<O-B\V
M"C$X-C@O."\V"C$X-CDO,3`O-@HQ.#<P+S$P+S8*,3@W,2\Q,B\V"C$X-S(O
M-B\V"C$X-S,O,3$O-@HQ.#<T+S@O-@HQ.#<U+S$P+S8*,3@W-B\Q,B\V"C$X
M-S<O,3(O-@HQ.#<X+S8O-@HQ.#<Y+S$Q+S8*,3@X,"\Q,"\V"C$X.#$O,3`O
M-@HQ.#@R+S$R+S8*,3@X,R\Q,B\V"C$X.#0O,3$O-@HQ.#@U+S@O-@HQ.#@V
M+S$P+S8*,3@X-R\Q,"\V"C$X.#@O,3(O-@HQ.#@Y+S8O-@HQ.#DP+S$Q+S8*
M,3@Y,2\X+S8*,3@Y,B\Q,"\V"C$X.3,O,3(O-@HQ.#DT+S$R+S8*,3@Y-2\V
M+S8*,3@Y-B\X+S8*,3@Y-R\Q,"\V"C$X.3@O,3`O-@HQ.#DY+S$R+S8*,3DP
M,"\Q,B\V"C$Y,#$O-B\V"C$Y,#(O,3$O-@HQ.3`S+S@O-@HQ.3`T+S$P+S8*
M,3DP-2\Q,B\V"C$Y,#8O,3(O-@HQ.3`W+S8O-@HQ.3`X+S@O-@HQ.3`Y+S$P
M+S8*,3DQ,"\Q,"\V"C$Y,3$O,3(O-@HQ.3$R+S8O-@HQ.3$S+S$Q+S8*,3DQ
M-"\X+S8*,3DQ-2\Q,"\V"C$Y,38O,3(O-@HQ.3$W+S$R+S8*,3DQ."\V+S8*
M,3DQ.2\Q,2\V"C$Y,C`O,3`O-@HQ.3(Q+S$P+S8*,3DR,B\Q,B\V"C$Y,C,O
M,3(O-@HQ.3(T+S$Q+S8*,3DR-2\X+S8*,3DR-B\Q,"\V"C$Y,C<O,3`O-@HQ
M.3(X+S$R+S8*,3DR.2\V+S8*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+W=K;F]T97-T+G1X=```
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,#<P-``Q,#4Q-30S,S<T,@`P,C0T
M,#8`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M,3DY.3$R,C<Z,3DY.2TU,BTQ"C$Y.3DQ,C(X.C$Y.3DM-3(M,@HQ.3DY,3(R
M.3HQ.3DY+34R+3,*,3DY.3$R,S`Z,3DY.2TU,BTT"C$Y.3DQ,C,Q.C$Y.3DM
M-3(M-0HR,#`P,#$P,3HQ.3DY+34R+38*,C`P,#`Q,#(Z,3DY.2TU,BTW"C(P
M,#`P,3`S.C(P,#`M,#$M,0HR,#`P,#$P-#HR,#`P+3`Q+3(*,C`P,#`Q,#4Z
M,C`P,"TP,2TS"C(P,#`P,3`V.C(P,#`M,#$M-`HR,#`P,#$P-SHR,#`P+3`Q
M+34*,C`P,#`Q,#@Z,C`P,"TP,2TV"C(P,#`P,3`Y.C(P,#`M,#$M-PHR,#`P
M,3(R-3HR,#`P+34R+3$*,C`P,#$R,C8Z,C`P,"TU,BTR"C(P,#`Q,C(W.C(P
M,#`M-3(M,PHR,#`P,3(R.#HR,#`P+34R+30*,C`P,#$R,CDZ,C`P,"TU,BTU
M"C(P,#`Q,C,P.C(P,#`M-3(M-@HR,#`P,3(S,3HR,#`P+34R+3<*,C`P,3`Q
M,#$Z,C`P,2TP,2TQ"C(P,#$P,3`R.C(P,#$M,#$M,@HR,#`Q,#$P,SHR,#`Q
M+3`Q+3,*,C`P,3`Q,#0Z,C`P,2TP,2TT"C(P,#$P,3`U.C(P,#$M,#$M-0HR
M,#`Q,#$P-CHR,#`Q+3`Q+38*,C`P,3`Q,#<Z,C`P,2TP,2TW"C(P,#$Q,C(T
M.C(P,#$M-3(M,0HR,#`Q,3(R-3HR,#`Q+34R+3(*,C`P,3$R,C8Z,C`P,2TU
M,BTS"C(P,#$Q,C(W.C(P,#$M-3(M-`HR,#`Q,3(R.#HR,#`Q+34R+34*,C`P
M,3$R,CDZ,C`P,2TU,BTV"C(P,#$Q,C,P.C(P,#$M-3(M-PHR,#`Q,3(S,3HR
M,#`R+3`Q+3$*,C`P,C`Q,#$Z,C`P,BTP,2TR"C(P,#(P,3`R.C(P,#(M,#$M
M,PHR,#`R,#$P,SHR,#`R+3`Q+30*,C`P,C`Q,#0Z,C`P,BTP,2TU"C(P,#(P
M,3`U.C(P,#(M,#$M-@HR,#`R,#$P-CHR,#`R+3`Q+3<*,C`P,C$R,C,Z,C`P
M,BTU,BTQ"C(P,#(Q,C(T.C(P,#(M-3(M,@HR,#`R,3(R-3HR,#`R+34R+3,*
M,C`P,C$R,C8Z,C`P,BTU,BTT"C(P,#(Q,C(W.C(P,#(M-3(M-0HR,#`R,3(R
M.#HR,#`R+34R+38*,C`P,C$R,CDZ,C`P,BTU,BTW"C(P,#(Q,C,P.C(P,#,M
M,#$M,0HR,#`R,3(S,3HR,#`S+3`Q+3(*,C`P,S`Q,#$Z,C`P,RTP,2TS"C(P
M,#,P,3`R.C(P,#,M,#$M-`HR,#`S,#$P,SHR,#`S+3`Q+34*,C`P,S`Q,#0Z
M,C`P,RTP,2TV"C(P,#,P,3`U.C(P,#,M,#$M-PHR,#`S,3(R,CHR,#`S+34R
M+3$*,C`P,S$R,C,Z,C`P,RTU,BTR"C(P,#,Q,C(T.C(P,#,M-3(M,PHR,#`S
M,3(R-3HR,#`S+34R+30*,C`P,S$R,C8Z,C`P,RTU,BTU"C(P,#,Q,C(W.C(P
M,#,M-3(M-@HR,#`S,3(R.#HR,#`S+34R+3<*,C`P,S$R,CDZ,C`P-"TP,2TQ
M"C(P,#,Q,C,P.C(P,#0M,#$M,@HR,#`S,3(S,3HR,#`T+3`Q+3,*,C`P-#`Q
M,#$Z,C`P-"TP,2TT"C(P,#0P,3`R.C(P,#0M,#$M-0HR,#`T,#$P,SHR,#`T
M+3`Q+38*,C`P-#`Q,#0Z,C`P-"TP,2TW"C(P,#0Q,C(P.C(P,#0M-3(M,0HR
M,#`T,3(R,3HR,#`T+34R+3(*,C`P-#$R,C(Z,C`P-"TU,BTS"C(P,#0Q,C(S
M.C(P,#0M-3(M-`HR,#`T,3(R-#HR,#`T+34R+34*,C`P-#$R,C4Z,C`P-"TU
M,BTV"C(P,#0Q,C(V.C(P,#0M-3(M-PHR,#`T,3(R-SHR,#`T+34S+3$*,C`P
M-#$R,C@Z,C`P-"TU,RTR"C(P,#0Q,C(Y.C(P,#0M-3,M,PHR,#`T,3(S,#HR
M,#`T+34S+30*,C`P-#$R,S$Z,C`P-"TU,RTU"C(P,#4P,3`Q.C(P,#0M-3,M
M-@HR,#`U,#$P,CHR,#`T+34S+3<*,C`P-3`Q,#,Z,C`P-2TP,2TQ"C(P,#4P
M,3`T.C(P,#4M,#$M,@HR,#`U,#$P-3HR,#`U+3`Q+3,*,C`P-3`Q,#8Z,C`P
M-2TP,2TT"C(P,#4P,3`W.C(P,#4M,#$M-0HR,#`U,#$P.#HR,#`U+3`Q+38*
M,C`P-3`Q,#DZ,C`P-2TP,2TW"C(P,#4Q,C(V.C(P,#4M-3(M,0HR,#`U,3(R
M-SHR,#`U+34R+3(*,C`P-3$R,C@Z,C`P-2TU,BTS"C(P,#4Q,C(Y.C(P,#4M
M-3(M-`HR,#`U,3(S,#HR,#`U+34R+34*,C`P-3$R,S$Z,C`P-2TU,BTV"C(P
M,#8P,3`Q.C(P,#4M-3(M-PHR,#`V,#$P,CHR,#`V+3`Q+3$*,C`P-C`Q,#,Z
M,C`P-BTP,2TR"C(P,#8P,3`T.C(P,#8M,#$M,PHR,#`V,#$P-3HR,#`V+3`Q
M+30*,C`P-C`Q,#8Z,C`P-BTP,2TU"C(P,#8P,3`W.C(P,#8M,#$M-@HR,#`V
M,#$P.#HR,#`V+3`Q+3<*,C`P-C$R,C4Z,C`P-BTU,BTQ"C(P,#8Q,C(V.C(P
M,#8M-3(M,@HR,#`V,3(R-SHR,#`V+34R+3,*,C`P-C$R,C@Z,C`P-BTU,BTT
M"C(P,#8Q,C(Y.C(P,#8M-3(M-0HR,#`V,3(S,#HR,#`V+34R+38*,C`P-C$R
M,S$Z,C`P-BTU,BTW"C(P,#<P,3`Q.C(P,#<M,#$M,0HR,#`W,#$P,CHR,#`W
M+3`Q+3(*,C`P-S`Q,#,Z,C`P-RTP,2TS"C(P,#<P,3`T.C(P,#<M,#$M-`HR
M,#`W,#$P-3HR,#`W+3`Q+34*,C`P-S`Q,#8Z,C`P-RTP,2TV"C(P,#<P,3`W
M.C(P,#<M,#$M-PHR,#`W,3(R-#HR,#`W+34R+3$*,C`P-S$R,C4Z,C`P-RTU
M,BTR"C(P,#<Q,C(V.C(P,#<M-3(M,PHR,#`W,3(R-SHR,#`W+34R+30*,C`P
M-S$R,C@Z,C`P-RTU,BTU"C(P,#<Q,C(Y.C(P,#<M-3(M-@HR,#`W,3(S,#HR
M,#`W+34R+3<*,C`P-S$R,S$Z,C`P."TP,2TQ"C(P,#@P,3`Q.C(P,#@M,#$M
M,@HR,#`X,#$P,CHR,#`X+3`Q+3,*,C`P.#`Q,#,Z,C`P."TP,2TT"C(P,#@P
M,3`T.C(P,#@M,#$M-0HR,#`X,#$P-3HR,#`X+3`Q+38*,C`P.#`Q,#8Z,C`P
M."TP,2TW"C(P,#@Q,C(R.C(P,#@M-3(M,0HR,#`X,3(R,SHR,#`X+34R+3(*
M,C`P.#$R,C0Z,C`P."TU,BTS"C(P,#@Q,C(U.C(P,#@M-3(M-`HR,#`X,3(R
M-CHR,#`X+34R+34*,C`P.#$R,C<Z,C`P."TU,BTV"C(P,#@Q,C(X.C(P,#@M
M-3(M-PHR,#`X,3(R.3HR,#`Y+3`Q+3$*,C`P.#$R,S`Z,C`P.2TP,2TR"C(P
M,#@Q,C,Q.C(P,#DM,#$M,PHR,#`Y,#$P,3HR,#`Y+3`Q+30*,C`P.3`Q,#(Z
M,C`P.2TP,2TU"C(P,#DP,3`S.C(P,#DM,#$M-@HR,#`Y,#$P-#HR,#`Y+3`Q
M+3<*,C`P.3$R,C$Z,C`P.2TU,BTQ"C(P,#DQ,C(R.C(P,#DM-3(M,@HR,#`Y
M,3(R,SHR,#`Y+34R+3,*,C`P.3$R,C0Z,C`P.2TU,BTT"C(P,#DQ,C(U.C(P
M,#DM-3(M-0HR,#`Y,3(R-CHR,#`Y+34R+38*,C`P.3$R,C<Z,C`P.2TU,BTW
M"C(P,#DQ,C(X.C(P,#DM-3,M,0HR,#`Y,3(R.3HR,#`Y+34S+3(*,C`P.3$R
M,S`Z,C`P.2TU,RTS"C(P,#DQ,C,Q.C(P,#DM-3,M-`HR,#$P,#$P,3HR,#`Y
M+34S+34*,C`Q,#`Q,#(Z,C`P.2TU,RTV"C(P,3`P,3`S.C(P,#DM-3,M-PHR
M,#$P,#$P-#HR,#$P+3`Q+3$*,C`Q,#`Q,#4Z,C`Q,"TP,2TR"C(P,3`P,3`V
M.C(P,3`M,#$M,PHR,#$P,#$P-SHR,#$P+3`Q+30*,C`Q,#`Q,#@Z,C`Q,"TP
M,2TU"C(P,3`P,3`Y.C(P,3`M,#$M-@HR,#$P,#$Q,#HR,#$P+3`Q+3<*,C`Q
M,#$R,C<Z,C`Q,"TU,BTQ"C(P,3`Q,C(X.C(P,3`M-3(M,@HR,#$P,3(R.3HR
M,#$P+34R+3,*,C`Q,#$R,S`Z,C`Q,"TU,BTT"C(P,3`Q,C,Q.C(P,3`M-3(M
M-0HR,#$Q,#$P,3HR,#$P+34R+38*,C`Q,3`Q,#(Z,C`Q,"TU,BTW"C(P,3$P
M,3`S.C(P,3$M,#$M,0HR,#$Q,#$P-#HR,#$Q+3`Q+3(*,C`Q,3`Q,#4Z,C`Q
M,2TP,2TS"C(P,3$P,3`V.C(P,3$M,#$M-`HR,#$Q,#$P-SHR,#$Q+3`Q+34*
M,C`Q,3`Q,#@Z,C`Q,2TP,2TV"C(P,3$P,3`Y.C(P,3$M,#$M-PHR,#$Q,3(R
M-CHR,#$Q+34R+3$*,C`Q,3$R,C<Z,C`Q,2TU,BTR"C(P,3$Q,C(X.C(P,3$M
M-3(M,PHR,#$Q,3(R.3HR,#$Q+34R+30*,C`Q,3$R,S`Z,C`Q,2TU,BTU"C(P
M,3$Q,C,Q.C(P,3$M-3(M-@HR,#$R,#$P,3HR,#$Q+34R+3<*,C`Q,C`Q,#(Z
M,C`Q,BTP,2TQ"C(P,3(P,3`S.C(P,3(M,#$M,@HR,#$R,#$P-#HR,#$R+3`Q
M+3,*,C`Q,C`Q,#4Z,C`Q,BTP,2TT"C(P,3(P,3`V.C(P,3(M,#$M-0HR,#$R
M,#$P-SHR,#$R+3`Q+38*,C`Q,C`Q,#@Z,C`Q,BTP,2TW"C(P,3(Q,C(T.C(P
M,3(M-3(M,0HR,#$R,3(R-3HR,#$R+34R+3(*,C`Q,C$R,C8Z,C`Q,BTU,BTS
M"C(P,3(Q,C(W.C(P,3(M-3(M-`HR,#$R,3(R.#HR,#$R+34R+34*,C`Q,C$R
M,CDZ,C`Q,BTU,BTV"C(P,3(Q,C,P.C(P,3(M-3(M-PHR,#$R,3(S,3HR,#$S
M+3`Q+3$*,C`Q,S`Q,#$Z,C`Q,RTP,2TR"C(P,3,P,3`R.C(P,3,M,#$M,PHR
M,#$S,#$P,SHR,#$S+3`Q+30*,C`Q,S`Q,#0Z,C`Q,RTP,2TU"C(P,3,P,3`U
M.C(P,3,M,#$M-@HR,#$S,#$P-CHR,#$S+3`Q+3<*,C`Q,S$R,C,Z,C`Q,RTU
M,BTQ"C(P,3,Q,C(T.C(P,3,M-3(M,@HR,#$S,3(R-3HR,#$S+34R+3,*,C`Q
M,S$R,C8Z,C`Q,RTU,BTT"C(P,3,Q,C(W.C(P,3,M-3(M-0HR,#$S,3(R.#HR
M,#$S+34R+38*,C`Q,S$R,CDZ,C`Q,RTU,BTW"C(P,3,Q,C,P.C(P,30M,#$M
M,0HR,#$S,3(S,3HR,#$T+3`Q+3(*,C`Q-#`Q,#$Z,C`Q-"TP,2TS"C(P,30P
M,3`R.C(P,30M,#$M-`HR,#$T,#$P,SHR,#$T+3`Q+34*,C`Q-#`Q,#0Z,C`Q
M-"TP,2TV"C(P,30P,3`U.C(P,30M,#$M-PHR,#$T,3(R,CHR,#$T+34R+3$*
M,C`Q-#$R,C,Z,C`Q-"TU,BTR"C(P,30Q,C(T.C(P,30M-3(M,PHR,#$T,3(R
M-3HR,#$T+34R+30*,C`Q-#$R,C8Z,C`Q-"TU,BTU"C(P,30Q,C(W.C(P,30M
M-3(M-@HR,#$T,3(R.#HR,#$T+34R+3<*,C`Q-#$R,CDZ,C`Q-2TP,2TQ"C(P
M,30Q,C,P.C(P,34M,#$M,@HR,#$T,3(S,3HR,#$U+3`Q+3,*,C`Q-3`Q,#$Z
M,C`Q-2TP,2TT"C(P,34P,3`R.C(P,34M,#$M-0HR,#$U,#$P,SHR,#$U+3`Q
M+38*,C`Q-3`Q,#0Z,C`Q-2TP,2TW"C(P,34Q,C(Q.C(P,34M-3(M,0HR,#$U
M,3(R,CHR,#$U+34R+3(*,C`Q-3$R,C,Z,C`Q-2TU,BTS"C(P,34Q,C(T.C(P
M,34M-3(M-`HR,#$U,3(R-3HR,#$U+34R+34*,C`Q-3$R,C8Z,C`Q-2TU,BTV
M"C(P,34Q,C(W.C(P,34M-3(M-PHR,#$U,3(R.#HR,#$U+34S+3$*,C`Q-3$R
M,CDZ,C`Q-2TU,RTR"C(P,34Q,C,P.C(P,34M-3,M,PHR,#$U,3(S,3HR,#$U
M+34S+30*,C`Q-C`Q,#$Z,C`Q-2TU,RTU"C(P,38P,3`R.C(P,34M-3,M-@HR
M,#$V,#$P,SHR,#$U+34S+3<*,C`Q-C`Q,#0Z,C`Q-BTP,2TQ"C(P,38P,3`U
M.C(P,38M,#$M,@HR,#$V,#$P-CHR,#$V+3`Q+3,*,C`Q-C`Q,#<Z,C`Q-BTP
M,2TT"C(P,38P,3`X.C(P,38M,#$M-0HR,#$V,#$P.3HR,#$V+3`Q+38*,C`Q
M-C`Q,3`Z,C`Q-BTP,2TW"C(P,38Q,C(V.C(P,38M-3(M,0HR,#$V,3(R-SHR
M,#$V+34R+3(*,C`Q-C$R,C@Z,C`Q-BTU,BTS"C(P,38Q,C(Y.C(P,38M-3(M
M-`HR,#$V,3(S,#HR,#$V+34R+34*,C`Q-C$R,S$Z,C`Q-BTU,BTV"C(P,3<P
M,3`Q.C(P,38M-3(M-PHR,#$W,#$P,CHR,#$W+3`Q+3$*,C`Q-S`Q,#,Z,C`Q
M-RTP,2TR"C(P,3<P,3`T.C(P,3<M,#$M,PHR,#$W,#$P-3HR,#$W+3`Q+30*
M,C`Q-S`Q,#8Z,C`Q-RTP,2TU"C(P,3<P,3`W.C(P,3<M,#$M-@HR,#$W,#$P
M.#HR,#$W+3`Q+3<*,C`Q-S$R,C4Z,C`Q-RTU,BTQ"C(P,3<Q,C(V.C(P,3<M
M-3(M,@HR,#$W,3(R-SHR,#$W+34R+3,*,C`Q-S$R,C@Z,C`Q-RTU,BTT"C(P
M,3<Q,C(Y.C(P,3<M-3(M-0HR,#$W,3(S,#HR,#$W+34R+38*,C`Q-S$R,S$Z
M,C`Q-RTU,BTW"C(P,3@P,3`Q.C(P,3@M,#$M,0HR,#$X,#$P,CHR,#$X+3`Q
M+3(*,C`Q.#`Q,#,Z,C`Q."TP,2TS"C(P,3@P,3`T.C(P,3@M,#$M-`HR,#$X
M,#$P-3HR,#$X+3`Q+34*,C`Q.#`Q,#8Z,C`Q."TP,2TV"C(P,3@P,3`W.C(P
M,3@M,#$M-PHR,#$X,3(R-#HR,#$X+34R+3$*,C`Q.#$R,C4Z,C`Q."TU,BTR
M"C(P,3@Q,C(V.C(P,3@M-3(M,PHR,#$X,3(R-SHR,#$X+34R+30*,C`Q.#$R
M,C@Z,C`Q."TU,BTU"C(P,3@Q,C(Y.C(P,3@M-3(M-@HR,#$X,3(S,#HR,#$X
M+34R+3<*,C`Q.#$R,S$Z,C`Q.2TP,2TQ"C(P,3DP,3`Q.C(P,3DM,#$M,@HR
M,#$Y,#$P,CHR,#$Y+3`Q+3,*,C`Q.3`Q,#,Z,C`Q.2TP,2TT"C(P,3DP,3`T
M.C(P,3DM,#$M-0HR,#$Y,#$P-3HR,#$Y+3`Q+38*,C`Q.3`Q,#8Z,C`Q.2TP
M,2TW"C(P,3DQ,C(S.C(P,3DM-3(M,0HR,#$Y,3(R-#HR,#$Y+34R+3(*,C`Q
M.3$R,C4Z,C`Q.2TU,BTS"C(P,3DQ,C(V.C(P,3DM-3(M-`HR,#$Y,3(R-SHR
M,#$Y+34R+34*,C`Q.3$R,C@Z,C`Q.2TU,BTV"C(P,3DQ,C(Y.C(P,3DM-3(M
M-PHR,#$Y,3(S,#HR,#(P+3`Q+3$*,C`Q.3$R,S$Z,C`R,"TP,2TR"C(P,C`P
M,3`Q.C(P,C`M,#$M,PHR,#(P,#$P,CHR,#(P+3`Q+30*,C`R,#`Q,#,Z,C`R
M,"TP,2TU"C(P,C`P,3`T.C(P,C`M,#$M-@HR,#(P,#$P-3HR,#(P+3`Q+3<*
M,C`R,#$R,C$Z,C`R,"TU,BTQ"C(P,C`Q,C(R.C(P,C`M-3(M,@HR,#(P,3(R
M,SHR,#(P+34R+3,*,C`R,#$R,C0Z,C`R,"TU,BTT"C(P,C`Q,C(U.C(P,C`M
M-3(M-0HR,#(P,3(R-CHR,#(P+34R+38*,C`R,#$R,C<Z,C`R,"TU,BTW"C(P
M,C`Q,C(X.C(P,C`M-3,M,0HR,#(P,3(R.3HR,#(P+34S+3(*,C`R,#$R,S`Z
M,C`R,"TU,RTS"C(P,C`Q,C,Q.C(P,C`M-3,M-`HR,#(Q,#$P,3HR,#(P+34S
M+34*,C`R,3`Q,#(Z,C`R,"TU,RTV"C(P,C$P,3`S.C(P,C`M-3,M-PHR,#(Q
M,#$P-#HR,#(Q+3`Q+3$*,C`R,3`Q,#4Z,C`R,2TP,2TR"C(P,C$P,3`V.C(P
M,C$M,#$M,PHR,#(Q,#$P-SHR,#(Q+3`Q+30*,C`R,3`Q,#@Z,C`R,2TP,2TU
M"C(P,C$P,3`Y.C(P,C$M,#$M-@HR,#(Q,#$Q,#HR,#(Q+3`Q+3<*,C`R,3$R
M,C<Z,C`R,2TU,BTQ"C(P,C$Q,C(X.C(P,C$M-3(M,@HR,#(Q,3(R.3HR,#(Q
M+34R+3,*,C`R,3$R,S`Z,C`R,2TU,BTT"C(P,C$Q,C,Q.C(P,C$M-3(M-0HR
M,#(R,#$P,3HR,#(Q+34R+38*,C`R,C`Q,#(Z,C`R,2TU,BTW"C(P,C(P,3`S
M.C(P,C(M,#$M,0HR,#(R,#$P-#HR,#(R+3`Q+3(*,C`R,C`Q,#4Z,C`R,BTP
M,2TS"C(P,C(P,3`V.C(P,C(M,#$M-`HR,#(R,#$P-SHR,#(R+3`Q+34*,C`R
M,C`Q,#@Z,C`R,BTP,2TV"C(P,C(P,3`Y.C(P,C(M,#$M-PHR,#(R,3(R-CHR
M,#(R+34R+3$*,C`R,C$R,C<Z,C`R,BTU,BTR"C(P,C(Q,C(X.C(P,C(M-3(M
M,PHR,#(R,3(R.3HR,#(R+34R+30*,C`R,C$R,S`Z,C`R,BTU,BTU"C(P,C(Q
M,C,Q.C(P,C(M-3(M-@HR,#(S,#$P,3HR,#(R+34R+3<*,C`R,S`Q,#(Z,C`R
M,RTP,2TQ"C(P,C,P,3`S.C(P,C,M,#$M,@HR,#(S,#$P-#HR,#(S+3`Q+3,*
M,C`R,S`Q,#4Z,C`R,RTP,2TT"C(P,C,P,3`V.C(P,C,M,#$M-0HR,#(S,#$P
M-SHR,#(S+3`Q+38*,C`R,S`Q,#@Z,C`R,RTP,2TW"C(P,C,Q,C(U.C(P,C,M
M-3(M,0HR,#(S,3(R-CHR,#(S+34R+3(*,C`R,S$R,C<Z,C`R,RTU,BTS"C(P
M,C,Q,C(X.C(P,C,M-3(M-`HR,#(S,3(R.3HR,#(S+34R+34*,C`R,S$R,S`Z
M,C`R,RTU,BTV"C(P,C,Q,C,Q.C(P,C,M-3(M-PHR,#(T,#$P,3HR,#(T+3`Q
M+3$*,C`R-#`Q,#(Z,C`R-"TP,2TR"C(P,C0P,3`S.C(P,C0M,#$M,PHR,#(T
M,#$P-#HR,#(T+3`Q+30*,C`R-#`Q,#4Z,C`R-"TP,2TU"C(P,C0P,3`V.C(P
M,C0M,#$M-@HR,#(T,#$P-SHR,#(T+3`Q+3<*,C`R-#$R,C,Z,C`R-"TU,BTQ
M"C(P,C0Q,C(T.C(P,C0M-3(M,@HR,#(T,3(R-3HR,#(T+34R+3,*,C`R-#$R
M,C8Z,C`R-"TU,BTT"C(P,C0Q,C(W.C(P,C0M-3(M-0HR,#(T,3(R.#HR,#(T
M+34R+38*,C`R-#$R,CDZ,C`R-"TU,BTW"C(P,C0Q,C,P.C(P,C4M,#$M,0HR
M,#(T,3(S,3HR,#(U+3`Q+3(*,C`R-3`Q,#$Z,C`R-2TP,2TS"C(P,C4P,3`R
M.C(P,C4M,#$M-`HR,#(U,#$P,SHR,#(U+3`Q+34*,C`R-3`Q,#0Z,C`R-2TP
M,2TV"C(P,C4P,3`U.C(P,C4M,#$M-PHR,#(U,3(R,CHR,#(U+34R+3$*,C`R
M-3$R,C,Z,C`R-2TU,BTR"C(P,C4Q,C(T.C(P,C4M-3(M,PHR,#(U,3(R-3HR
M,#(U+34R+30*,C`R-3$R,C8Z,C`R-2TU,BTU"C(P,C4Q,C(W.C(P,C4M-3(M
M-@HR,#(U,3(R.#HR,#(U+34R+3<*,C`R-3$R,CDZ,C`R-BTP,2TQ"C(P,C4Q
M,C,P.C(P,C8M,#$M,@HR,#(U,3(S,3HR,#(V+3`Q+3,*,C`R-C`Q,#$Z,C`R
M-BTP,2TT"C(P,C8P,3`R.C(P,C8M,#$M-0HR,#(V,#$P,SHR,#(V+3`Q+38*
M,C`R-C`Q,#0Z,C`R-BTP,2TW"C(P,C8Q,C(Q.C(P,C8M-3(M,0HR,#(V,3(R
M,CHR,#(V+34R+3(*,C`R-C$R,C,Z,C`R-BTU,BTS"C(P,C8Q,C(T.C(P,C8M
M-3(M-`HR,#(V,3(R-3HR,#(V+34R+34*,C`R-C$R,C8Z,C`R-BTU,BTV"C(P
M,C8Q,C(W.C(P,C8M-3(M-PHR,#(V,3(R.#HR,#(V+34S+3$*,C`R-C$R,CDZ
M,C`R-BTU,RTR"C(P,C8Q,C,P.C(P,C8M-3,M,PHR,#(V,3(S,3HR,#(V+34S
M+30*,C`R-S`Q,#$Z,C`R-BTU,RTU"C(P,C<P,3`R.C(P,C8M-3,M-@HR,#(W
M,#$P,SHR,#(V+34S+3<*,C`R-S`Q,#0Z,C`R-RTP,2TQ"C(P,C<P,3`U.C(P
M,C<M,#$M,@HR,#(W,#$P-CHR,#(W+3`Q+3,*,C`R-S`Q,#<Z,C`R-RTP,2TT
M"C(P,C<P,3`X.C(P,C<M,#$M-0HR,#(W,#$P.3HR,#(W+3`Q+38*,C`R-S`Q
M,3`Z,C`R-RTP,2TW"C(P,C<Q,C(W.C(P,C<M-3(M,0HR,#(W,3(R.#HR,#(W
M+34R+3(*,C`R-S$R,CDZ,C`R-RTU,BTS"C(P,C<Q,C,P.C(P,C<M-3(M-`HR
M,#(W,3(S,3HR,#(W+34R+34*,C`R.#`Q,#$Z,C`R-RTU,BTV"C(P,C@P,3`R
M.C(P,C<M-3(M-PHR,#(X,#$P,SHR,#(X+3`Q+3$*,C`R.#`Q,#0Z,C`R."TP
M,2TR"C(P,C@P,3`U.C(P,C@M,#$M,PHR,#(X,#$P-CHR,#(X+3`Q+30*,C`R
M.#`Q,#<Z,C`R."TP,2TU"C(P,C@P,3`X.C(P,C@M,#$M-@HR,#(X,#$P.3HR
M,#(X+3`Q+3<*,C`R.#$R,C4Z,C`R."TU,BTQ"C(P,C@Q,C(V.C(P,C@M-3(M
M,@HR,#(X,3(R-SHR,#(X+34R+3,*,C`R.#$R,C@Z,C`R."TU,BTT"C(P,C@Q
M,C(Y.C(P,C@M-3(M-0HR,#(X,3(S,#HR,#(X+34R+38*,C`R.#$R,S$Z,C`R
M."TU,BTW"C(P,CDP,3`Q.C(P,CDM,#$M,0HR,#(Y,#$P,CHR,#(Y+3`Q+3(*
M,C`R.3`Q,#,Z,C`R.2TP,2TS"C(P,CDP,3`T.C(P,CDM,#$M-`HR,#(Y,#$P
M-3HR,#(Y+3`Q+34*,C`R.3`Q,#8Z,C`R.2TP,2TV"C(P,CDP,3`W.C(P,CDM
M,#$M-P``````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]$0B\`````````````````````````````````````````
M```````````````````````````````````````P,#`P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<T,0`P,C`R,S$`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+P``````````
M````````````````````````````````````````````````````````````
M`#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S
M-S0R`#`R,3,W-``@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O
M1$(O=&5S=',O9&)?97)R;W(N<&AP=```````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#8Q-#<`,3`U,34T,S,W-#(`,#(T,#<W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"TM5$535"TM"D1".CI$0E]%<G)O
M<@HM+5-+25!)1BTM"CP_<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I*3L@
M<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\/W!H
M<"`O+R`M*BT@0RLK("TJ+0IR97%U:7)E7V]N8V4@)RXO:6YC;'5D92YI;F,G
M.PIR97%U:7)E7V]N8V4@)T1"+G!H<"<["@IF=6YC=&EO;B!T97-T7V5R<F]R
M7VAA;F1L97(H)&5R<FYO+"`D97)R;7-G+"`D9FEL92P@)&QI;F4L("1V87)S
M*2!["B`@("!I9B`H9&5F:6YE9"@G15]35%))0U0G*2D@>PH@("`@("`@(&EF
M("@D97)R;F\@)B!%7U-44DE#5`H@("`@("`@("`@("`F)B`H97)R;W)?<F5P
M;W)T:6YG*"D@)B!%7U-44DE#5"D@(3T@15]35%))0U0I('L*("`@("`@("`@
M("`@+R\@26=N;W)E($5?4U1224-4(&YO=&EC97,@=6YL97-S('1H97D@:&%V
M92!B965N('1U<FYE9"!O;@H@("`@("`@("`@("!R971U<FX["B`@("`@("`@
M?0H@("`@?2!E;'-E('L*("`@("`@("!D969I;F4H)T5?4U1224-4)RP@,C`T
M."D["B`@("!]"B`@("`D97)R;W)T>7!E(#T@87)R87D@*`H@("`@("`@($5?
M15)23U(@/3X@)T5R<F]R)RP*("`@("`@("!%7U=!4DY)3D<@/3X@)U=A<FYI
M;F<G+`H@("`@("`@($5?4$%24T4@/3X@)U!A<G-I;F<@17)R;W(G+`H@("`@
M("`@($5?3D]424-%(#T^("=.;W1I8V4G+`H@("`@("`@($5?0T]215]%4E)/
M4B`]/B`G0V]R92!%<G)O<B<L"B`@("`@("`@15]#3U)%7U=!4DY)3D<@/3X@
M)T-O<F4@5V%R;FEN9R<L"B`@("`@("`@15]#3TU024Q%7T524D]2(#T^("=#
M;VUP:6QE($5R<F]R)RP*("`@("`@("!%7T-/35!)3$5?5T%23DE.1R`]/B`G
M0V]M<&EL92!787)N:6YG)RP*("`@("`@("!%7U5315)?15)23U(@/3X@)U5S
M97(@17)R;W(G+`H@("`@("`@($5?55-%4E]705).24Y'(#T^("=5<V5R(%=A
M<FYI;F<G+`H@("`@("`@($5?55-%4E].3U1)0T4@/3X@)U5S97(@3F]T:6-E
M)RP*("`@("`@("!%7U-44DE#5"`]/B`G4W1R:6-T($YO=&EC92<L"B`@("`I
M.PH@("`@)'!R969I>"`]("1E<G)O<G1Y<&5;)&5R<FYO73L*("`@('!R:6YT
M(")<;B1P<F5F:7@Z("1E<G)M<V<@:6X@(B`N(&)A<V5N86UE*"1F:6QE*2`N
M("(@;VX@;&EN92!86%A<;B(["GT*"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D[
M"G-E=%]E<G)O<E]H86YD;&5R*"=T97-T7V5R<F]R7VAA;F1L97(G*3L*"G!R
M:6YT(")T97-T:6YG(&1I9F9E<F5N="!E<G)O<B!C;V1E<RXN+EQN(CL*)&4@
M/2!N97<@1$)?17)R;W(H*3L@<')I;G0@<W1R=&]L;W=E<B@D92T^=&]3=')I
M;F<H*2DN(EQN(CL*)&4@/2!N97<@1$)?17)R;W(H(G1E<W0@97)R;W(B*3L@
M<')I;G0@<W1R=&]L;W=E<B@D92T^=&]3=')I;F<H*2DN(EQN(CL*)&4@/2!N
M97<@1$)?17)R;W(H1$)?3TLI.R!P<FEN="!S=')T;VQO=V5R*"1E+3YT;U-T
M<FEN9R@I*2XB7&XB.PHD92`](&YE=R!$0E]%<G)O<BA$0E]%4E)/4BD[('!R
M:6YT('-T<G1O;&]W97(H)&4M/G1O4W1R:6YG*"DI+B)<;B(["B1E(#T@;F5W
M($1"7T5R<F]R*$1"7T524D]27U-93E1!6"D[('!R:6YT('-T<G1O;&]W97(H
M)&4M/G1O4W1R:6YG*"DI+B)<;B(["B1E(#T@;F5W($1"7T5R<F]R*$1"7T52
M4D]27T1)5EI%4D\I.R!P<FEN="!S=')T;VQO=V5R*"1E+3YT;U-T<FEN9R@I
M*2XB7&XB.PH*<')I;G0@(G1E<W1I;F<@9&EF9F5R96YT(&5R<F]R(&UO9&5S
M+BXN7&XB.PHD92`](&YE=R!$0E]%<G)O<BA$0E]%4E)/4BP@4$5!4E]%4E)/
M4E]04DE.5"D[('!R:6YT('-T<G1O;&]W97(H)&4M/G1O4W1R:6YG*"DI+B)<
M;B(["B1E(#T@;F5W($1"7T5R<F]R*$1"7T524D]27U-93E1!6"P@4$5!4E]%
M4E)/4E]44DE'1T52*3L*"G!R:6YT(")T97-T:6YG(&1I9F9E<F5N="!E<G)O
M<B!S97)V97)I=&EE<RXN+EQN(CL*)&4@/2!N97<@1$)?17)R;W(H1$)?15)2
M3U)?4UE.5$%8+"!014%27T524D]27U1224='15(L($5?55-%4E].3U1)0T4I
M.PHD92`](&YE=R!$0E]%<G)O<BA$0E]%4E)/4E]364Y405@L(%!%05)?15)2
M3U)?5%))1T=%4BP@15]54T527U=!4DY)3D<I.PHD92`](&YE=R!$0E]%<G)O
M<BA$0E]%4E)/4E]364Y405@L(%!%05)?15)23U)?5%))1T=%4BP@15]54T52
M7T524D]2*3L*"C\^"BTM1T54+2T*+2U03U-4+2T*+2U%6%!%0U0M+0IT97-T
M:6YG(&1I9F9E<F5N="!E<G)O<B!C;V1E<RXN+@I;9&)?97)R;W(Z(&UE<W-A
M9V4](F1B(&5R<F]R.B!U;FMN;W=N(&5R<F]R(B!C;V1E/2TQ(&UO9&4]<F5T
M=7)N(&QE=F5L/6YO=&EC92!P<F5F:7@](B(@:6YF;STB(ET*6V1B7V5R<F]R
M.B!M97-S86=E/2)D8B!E<G)O<CH@=&5S="!E<G)O<B(@8V]D93TM,2!M;V1E
M/7)E='5R;B!L979E;#UN;W1I8V4@<')E9FEX/2(B(&EN9F\](B)="EMD8E]E
M<G)O<CH@;65S<V%G93TB9&(@97)R;W(Z(&YO(&5R<F]R(B!C;V1E/3$@;6]D
M93UR971U<FX@;&5V96P];F]T:6-E('!R969I>#TB(B!I;F9O/2(B70I;9&)?
M97)R;W(Z(&UE<W-A9V4](F1B(&5R<F]R.B!U;FMN;W=N(&5R<F]R(B!C;V1E
M/2TQ(&UO9&4]<F5T=7)N(&QE=F5L/6YO=&EC92!P<F5F:7@](B(@:6YF;STB
M(ET*6V1B7V5R<F]R.B!M97-S86=E/2)D8B!E<G)O<CH@<WEN=&%X(&5R<F]R
M(B!C;V1E/2TR(&UO9&4]<F5T=7)N(&QE=F5L/6YO=&EC92!P<F5F:7@](B(@
M:6YF;STB(ET*6V1B7V5R<F]R.B!M97-S86=E/2)D8B!E<G)O<CH@9&EV:7-I
M;VX@8GD@>F5R;R(@8V]D93TM,3,@;6]D93UR971U<FX@;&5V96P];F]T:6-E
M('!R969I>#TB(B!I;F9O/2(B70IT97-T:6YG(&1I9F9E<F5N="!E<G)O<B!M
M;V1E<RXN+@I$0B!%<G)O<CH@=6YK;F]W;B!E<G)O<EMD8E]E<G)O<CH@;65S
M<V%G93TB9&(@97)R;W(Z('5N:VYO=VX@97)R;W(B(&-O9&4]+3$@;6]D93UP
M<FEN="!L979E;#UN;W1I8V4@<')E9FEX/2(B(&EN9F\](B)="@I5<V5R($YO
M=&EC93H@1$(@17)R;W(Z('-Y;G1A>"!E<G)O<B!I;B!014%2+G!H<"!O;B!L
M:6YE(%A86`IT97-T:6YG(&1I9F9E<F5N="!E<G)O<B!S97)V97)I=&EE<RXN
M+@H*57-E<B!.;W1I8V4Z($1"($5R<F]R.B!S>6YT87@@97)R;W(@:6X@4$5!
M4BYP:'`@;VX@;&EN92!86%@*"E5S97(@5V%R;FEN9SH@1$(@17)R;W(Z('-Y
M;G1A>"!E<G)O<B!I;B!014%2+G!H<"!O;B!L:6YE(%A86`H*57-E<B!%<G)O
M<CH@1$(@17)R;W(Z('-Y;G1A>"!E<G)O<B!I;B!014%2+G!H<"!O;B!L:6YE
M(%A86`H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S
M+T1"+W1E<W1S+V1B7V5R<F]R,BYP:'!T````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`V,C,V`#$P-3$U-#,S-S0Q`#`R-#$U-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````M+51%4U0M+0I$0CHZ17)R;W(@
M,@HM+5-+25!)1BTM"CP_<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I*3L@
M<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\/W!H
M<`IR97%U:7)E7V]N8V4@)RXO:6YC;'5D92YI;F,G.PIR97%U:7)E7V]N8V4@
M)T1"+G!H<"<["@IE<G)O<E]R97!O<G1I;F<H15]!3$PI.PH*9G5N8W1I;VX@
M;7EF=6YC*"8D;V)J*2!["B`@("!P<FEN="`G;7EF=6YC(&AE<F4L(&]B:CTG
M"B`@("`@("`@("`N('-T<G1O;&]W97(H)&]B:BT^=&]3=')I;F<H*2D@+B`B
M7&XB.PI]"F9U;F-T:6]N(&UY9G5N8S(H)B1O8FHI('L*("`@('!R:6YT("=M
M>69U;F,R(&AE<F4L(&]B:CTG"B`@("`@("`@("`N('-T<G1O;&]W97(H)&]B
M:BT^=&]3=')I;F<H*2D@+B`B7&XB.PI]"F-L87-S(&UY8VQA<W,@>PH@("`@
M9G5N8W1I;VX@;7EF=6YC*"8D;V)J*2!["B`@("`@("`@<')I;G0@)VUY8VQA
M<W,Z.FUY9G5N8R!H97)E+"!O8FH])PH@("`@("`@("`@+B!S=')T;VQO=V5R
M*"1O8FHM/G1O4W1R:6YG*"DI("X@(EQN(CL*("`@('T*?0IF=6YC=&EO;B!T
M97-T7V5R<F]R7VAA;F1L97(H)&5R<FYO+"`D97)R;7-G+"`D9FEL92P@)&QI
M;F4L("1V87)S*2!["B`@("!I9B`H9&5F:6YE9"@G15]35%))0U0G*2D@>PH@
M("`@("`@(&EF("@D97)R;F\@)B!%7U-44DE#5`H@("`@("`@("`@("`F)B`H
M97)R;W)?<F5P;W)T:6YG*"D@)B!%7U-44DE#5"D@(3T@15]35%))0U0I('L*
M("`@("`@("`@("`@+R\@26=N;W)E($5?4U1224-4(&YO=&EC97,@=6YL97-S
M('1H97D@:&%V92!B965N('1U<FYE9"!O;@H@("`@("`@("`@("!R971U<FX[
M"B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("!D969I;F4H)T5?4U12
M24-4)RP@,C`T."D["B`@("!]"B`@("`D97)R;W)T>7!E(#T@87)R87D@*`H@
M("`@("`@($5?15)23U(@/3X@)T5R<F]R)RP*("`@("`@("!%7U=!4DY)3D<@
M/3X@)U=A<FYI;F<G+`H@("`@("`@($5?4$%24T4@/3X@)U!A<G-I;F<@17)R
M;W(G+`H@("`@("`@($5?3D]424-%(#T^("=.;W1I8V4G+`H@("`@("`@($5?
M0T]215]%4E)/4B`]/B`G0V]R92!%<G)O<B<L"B`@("`@("`@15]#3U)%7U=!
M4DY)3D<@/3X@)T-O<F4@5V%R;FEN9R<L"B`@("`@("`@15]#3TU024Q%7T52
M4D]2(#T^("=#;VUP:6QE($5R<F]R)RP*("`@("`@("!%7T-/35!)3$5?5T%2
M3DE.1R`]/B`G0V]M<&EL92!787)N:6YG)RP*("`@("`@("!%7U5315)?15)2
M3U(@/3X@)U5S97(@17)R;W(G+`H@("`@("`@($5?55-%4E]705).24Y'(#T^
M("=5<V5R(%=A<FYI;F<G+`H@("`@("`@($5?55-%4E].3U1)0T4@/3X@)U5S
M97(@3F]T:6-E)RP*("`@("`@("!%7U-44DE#5"`]/B`G4W1R:6-T($YO=&EC
M92<L"B`@("`I.PH@("`@)'!R969I>"`]("1E<G)O<G1Y<&5;)&5R<FYO73L*
M("`@('!R:6YT('-T<G1O;&]W97(H(B1P<F5F:7@Z("1E<G)M<V<@:6X@(B`N
M(&)A<V5N86UE*"1F:6QE*0H@("`@("`@("`@("`@("`@("`@("`N("(@;VX@
M;&EN92!86%A<;B(I.PI]"@HD;V)J(#T@;F5W(&UY8VQA<W,["@HD9&)H(#T@
M1$(Z.F9A8W1O<GDH(FUY<W%L(BD["@IP<FEN="`B9&5F875L=#H@(CL*)&4@
M/2`D9&)H+3YR86ES945R<F]R*")R971U<FX@=&5S=&EN9R!E<G)O<B(I.PIP
M<FEN="!S=')T;VQO=V5R*"1E+3YT;U-T<FEN9R@I*2`N(")<;B(["@IP<FEN
M="`B9VQO8F%L(&1E9F%U;'0Z("(["E!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H
M4$5!4E]%4E)/4E]#04Q,0D%#2RP@(FUY9G5N8S(B*3L*)&4@/2`D9&)H+3YR
M86ES945R<F]R*")G;&]B86P@9&5F875L="!T97-T(BD["@HD9&)H+3YS971%
M<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4%))3E0I.PIP<FEN="`B;6]D93UP
M<FEN=#H@(CL*)&4@/2`D9&)H+3YR86ES945R<F]R*")P<FEN="!T97-T:6YG
M(&5R<F]R(BD["G!R:6YT(")<;B(["@HD9&)H+3YS971%<G)O<DAA;F1L:6YG
M*%!%05)?15)23U)?0T%,3$)!0TLL(")M>69U;F,B*3L*<')I;G0@(FUO9&4]
M9G5N8W1I;VX@8V%L;&)A8VLZ("(["B1E(#T@)&1B:"T^<F%I<V5%<G)O<B@B
M9G5N8W1I;VX@8V%L;&)A8VL@=&5S=&EN9R!E<G)O<B(I.PH*)&1B:"T^<V5T
M17)R;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"04-++"!A<G)A>2@D;V)J
M+"`B;7EF=6YC(BDI.PIP<FEN="`B;6]D93UO8FIE8W0@8V%L;&)A8VLZ("([
M"B1E(#T@)&1B:"T^<F%I<V5%<G)O<B@B;V)J96-T(&-A;&QB86-K('1E<W1I
M;F<@97)R;W(B*3L*"G-E=%]E<G)O<E]H86YD;&5R*")T97-T7V5R<F]R7VAA
M;F1L97(B*3L*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U12
M24='15(I.PIP<FEN="`B;6]D93UT<FEG9V5R.B`B.PHD92`]("1D8F@M/G)A
M:7-E17)R;W(H(G1R:6=G97(@=&5S=&EN9R!E<G)O<B(I.PH*/SX*+2U%6%!%
M0U0M+0ID969A=6QT.B!;9&)?97)R;W(Z(&UE<W-A9V4](F1B(&5R<F]R.B!R
M971U<FX@=&5S=&EN9R!E<G)O<B(@8V]D93TM,2!M;V1E/7)E='5R;B!L979E
M;#UN;W1I8V4@<')E9FEX/2(B(&EN9F\](B!;9&(@97)R;W(Z('5N:VYO=VX@
M97)R;W)=(ET*9VQO8F%L(&1E9F%U;'0Z(&UY9G5N8S(@:&5R92P@;V)J/5MD
M8E]E<G)O<CH@;65S<V%G93TB9&(@97)R;W(Z(&=L;V)A;"!D969A=6QT('1E
M<W0B(&-O9&4]+3$@;6]D93UC86QL8F%C:R!C86QL8F%C:SUM>69U;F,R('!R
M969I>#TB(B!I;F9O/2(@6V1B(&5R<F]R.B!U;FMN;W=N(&5R<F]R72)="FUO
M9&4]<')I;G0Z($1"($5R<F]R.B!P<FEN="!T97-T:6YG(&5R<F]R"FUO9&4]
M9G5N8W1I;VX@8V%L;&)A8VLZ(&UY9G5N8R!H97)E+"!O8FH]6V1B7V5R<F]R
M.B!M97-S86=E/2)D8B!E<G)O<CH@9G5N8W1I;VX@8V%L;&)A8VL@=&5S=&EN
M9R!E<G)O<B(@8V]D93TM,2!M;V1E/6-A;&QB86-K(&-A;&QB86-K/6UY9G5N
M8R!P<F5F:7@](B(@:6YF;STB(%MD8B!E<G)O<CH@=6YK;F]W;B!E<G)O<ETB
M70IM;V1E/6]B:F5C="!C86QL8F%C:SH@;7EC;&%S<SHZ;7EF=6YC(&AE<F4L
M(&]B:CU;9&)?97)R;W(Z(&UE<W-A9V4](F1B(&5R<F]R.B!O8FIE8W0@8V%L
M;&)A8VL@=&5S=&EN9R!E<G)O<B(@8V]D93TM,2!M;V1E/6-A;&QB86-K(&-A
M;&QB86-K/6UY8VQA<W,Z.FUY9G5N8R!P<F5F:7@](B(@:6YF;STB(%MD8B!E
M<G)O<CH@=6YK;F]W;B!E<G)O<ETB70IM;V1E/71R:6=G97(Z('5S97(@;F]T
M:6-E.B!D8B!E<G)O<CH@=')I9V=E<B!T97-T:6YG(&5R<F]R(&EN('!E87(N
M<&AP(&]N(&QI;F4@>'AX"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T
M<R]$0B]T97-T<R]D8E]F86-T;W)Y+G!H<'0`````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C<Q,0`Q,#4Q-30S,S<T,0`P,C0T,#4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+2U415-4+2T*1$(Z.F9A8W1O
M<GD*+2U32TE0248M+0H\/W!H<"!C:&1I<BAD:7)N86UE*%]?1DE,15]?*2D[
M(')E<75I<F5?;VYC92`G+B]S:VEP:68N:6YC)SL@/SX*+2U&24Q%+2T*/#]P
M:'`@+R\@+2HM($,K*R`M*BT*<F5Q=6ER95]O;F-E("<N+VEN8VQU9&4N:6YC
M)SL*<F5Q=6ER95]O;F-E("=$0BYP:'`G.PH*)&)A8VME;F1S(#T@87)R87DH
M"B`@("`G9&)A<V4G+`H@("`@)V9B<W%L)RP*("`@("=I8F%S92<L"B`@("`G
M:69X)RP*("`@("=M<W%L)RP*("`@("=M<W-Q;"<L"B`@("`G;7ES<6PG+`H@
M("`@)VUY<W%L:2<L"B`@("`G;V-I."<L"B`@("`G;V1B8R<L"B`@("`G<&=S
M<6PG+`H@("`@)W-Q;&ET92<L"B`@("`G<WEB87-E)RP**3L*"F9O<F5A8V@@
M*"1B86-K96YD<R!A<R`D;F%M92D@>PH@("`@)&]B:B`]($1".CIF86-T;W)Y
M*"1N86UE*3L*"B`@("!P<FEN="`B=&5S=&EN9R`D;F%M93H@(CL*("`@(&EF
M("A$0CHZ:7-%<G)O<B@D;V)J*2D@>PH)("`@('!R:6YT("=E<G)O<CH@)R`N
M("1O8FHM/F=E=$UE<W-A9V4H*2`N(")<;B(["B`@("!](&5L<V4@>PH)("`@
M('!R:6YT("=O8FIE8W0Z("<@+B`D;V)J+3YT;U-T<FEN9R@I("X@(EQN(CL*
M("`@('T*?0H*/SX*+2U'150M+0HM+5!/4U0M+0HM+4584$5#5"TM"G1E<W1I
M;F<@9&)A<V4Z(&]B:F5C=#H@9&)?9&)A<V4Z("AP:'!T>7!E/61B87-E+"!D
M8G-Y;G1A>#UD8F%S92D*=&5S=&EN9R!F8G-Q;#H@;V)J96-T.B!D8E]F8G-Q
M;#H@*'!H<'1Y<&4]9F)S<6PL(&1B<WEN=&%X/69B<W%L*0IT97-T:6YG(&EB
M87-E.B!O8FIE8W0Z(&1B7VEB87-E.B`H<&AP='EP93UI8F%S92P@9&)S>6YT
M87@]:6)A<V4I"G1E<W1I;F<@:69X.B!O8FIE8W0Z(&1B7VEF>#H@*'!H<'1Y
M<&4]:69X+"!D8G-Y;G1A>#UI9G@I"G1E<W1I;F<@;7-Q;#H@;V)J96-T.B!D
M8E]M<W%L.B`H<&AP='EP93UM<W%L+"!D8G-Y;G1A>#UM<W%L*0IT97-T:6YG
M(&US<W%L.B!O8FIE8W0Z(&1B7VUS<W%L.B`H<&AP='EP93UM<W-Q;"P@9&)S
M>6YT87@];7-S<6PI"G1E<W1I;F<@;7ES<6PZ(&]B:F5C=#H@9&)?;7ES<6PZ
M("AP:'!T>7!E/6UY<W%L+"!D8G-Y;G1A>#UM>7-Q;"D*=&5S=&EN9R!M>7-Q
M;&DZ(&]B:F5C=#H@9&)?;7ES<6QI.B`H<&AP='EP93UM>7-Q;&DL(&1B<WEN
M=&%X/6UY<W%L:2D*=&5S=&EN9R!O8VDX.B!O8FIE8W0Z(&1B7V]C:3@Z("AP
M:'!T>7!E/6]C:3@L(&1B<WEN=&%X/6]C:3@I"G1E<W1I;F<@;V1B8SH@;V)J
M96-T.B!D8E]O9&)C.B`H<&AP='EP93UO9&)C+"!D8G-Y;G1A>#US<6PY,BD*
M=&5S=&EN9R!P9W-Q;#H@;V)J96-T.B!D8E]P9W-Q;#H@*'!H<'1Y<&4]<&=S
M<6PL(&1B<WEN=&%X/7!G<W%L*0IT97-T:6YG('-Q;&ET93H@;V)J96-T.B!D
M8E]S<6QI=&4Z("AP:'!T>7!E/7-Q;&ET92P@9&)S>6YT87@]<W%L:71E*0IT
M97-T:6YG('-Y8F%S93H@;V)J96-T.B!D8E]S>6)A<V4Z("AP:'!T>7!E/7-Y
M8F%S92P@9&)S>6YT87@]<WEB87-E*0H`````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1B7VES;6%N:7`N
M<&AP=````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,C0W`#$P-3$U-#,S-S0Q
M`#`R-#0P,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````M+51%4U0M+0I$0CHZ:7--86YI<`HM+5-+25!)1BTM"CP_<&AP(&-H
M9&ER*&1I<FYA;64H7U]&24Q%7U\I*3L@<F5Q=6ER95]O;F-E("<N+W-K:7!I
M9BYI;F,G.R`_/@HM+49)3$4M+0H\/W!H<"`O+R`M*BT@0RLK("TJ+0IR97%U
M:7)E7V]N8V4@)RXO:6YC;'5D92YI;F,G.PIR97%U:7)E7V]N8V4@)T1"+G!H
M<"<["@IF=6YC=&EO;B!T97-T*"1Q=65R>2D@>PH@("`@<')I;G1F*"(E<R`Z
M("5D7&XB+"!P<F5G7W)E<&QA8V4H)R]<<RLN*B\G+"`G)RP@)'%U97)Y*2P*
M("`@("`@("`@("!$0CHZ:7--86YI<"@D<75E<GDI*3L*?0H*<')I;G0@(G1E
M<W1I;F<@1$(Z.FES36%N:7`N+BY<;B(["@IT97-T*")314Q%0U0@*B!&4D]-
M('1A8FQE(BD["G1E<W0H(E-E;&5C="`J(&9R;VT@=&%B;&4B*3L*=&5S="@B
M<V5L96-T("H@1G)O;2!T86)L92(I.PIT97-T*")S16Q%0W0@*B!F<D]M('1A
M8FQE(BD["G1E<W0H(E-%3$5#5"!$25-424Y#5"!N86UE($923TT@=&%B;&4B
M*3L*=&5S="@B55!$051%('1A8FQE(%-%5"!F;V\@/2`G8F%R)R(I.PIT97-T
M*")$14Q%5$4@1E)/32!T86)L92(I.PIT97-T*")D96QE=&4@9G)O;2!T86)L
M92!W:&5R92!I9"!I<R!N=6QL(BD["G1E<W0H(F-R96%T92!T86)L92`H:60@
M:6YT96=E<BP@;F%M92!V87)C:&%R*#$P,"DI(BD["G1E<W0H(D-214%412!3
M15%514Y#12!F;V\B*3L*=&5S="@B7")#4D5!5$4@4%)/0T5$55)%(&9O;UPB
M(BD["G1E<W0H(D=204Y4(%-%3$5#5"!/3B!T86)L92!43R!U<V5R(BD["G1E
M<W0H(E)%5D]+12!314Q%0U0@3TX@=&%B;&4@1E)/32!U<V5R(BD["G1E<W0H
M(E-(3U<@3U!424].4R(I.PIT97-T*")$4D]0(%1!0DQ%(&9O;R(I.PIT97-T
M*")!3%1%4B!404),12!F;V\@041$($-/3%5-3B`H8F%R($E.5$5'15(I(BD[
M"G1E<W0H(B`@4T5,14-4("H@1E)/32!T86)L92(I.PIT97-T*"(@($1%3$54
M12!&4D]-('1A8FQE(BD["C\^"BTM1T54+2T*+2U03U-4+2T*+2U%6%!%0U0M
M+0IT97-T:6YG($1".CII<TUA;FEP+BXN"E-%3$5#5"`Z(#`*4V5L96-T(#H@
M,`IS96QE8W0@.B`P"G-%;$5#="`Z(#`*4T5,14-4(#H@,`I54$1!5$4@.B`Q
M"D1%3$5412`Z(#$*9&5L971E(#H@,0IC<F5A=&4@.B`Q"D-214%412`Z(#$*
M(D-214%412`Z(#$*1U)!3E0@.B`Q"E)%5D]+12`Z(#$*4TA/5R`Z(#`*1%)/
M4"`Z(#$*04Q415(@.B`Q"B`Z(#`*(#H@,0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S
M=',O1$(O=&5S=',O9&)?<&%R<V5D<VXN<&AP=```````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,C,Q-C4`,3`U,34T,S,W-#(`,#(T-38T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"TM5$535"TM"D1".CIP87)S
M94133@HM+5-+25!)1BTM"CP_<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I
M*3L@<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\
M/W!H<"`O+R`M*BT@0RLK("TJ+0IR97%U:7)E7V]N8V4@)RXO:6YC;'5D92YI
M;F,G.PIR97%U:7)E7V]N8V4@)T1"+G!H<"<["@IF=6YC=&EO;B!T97-T*"1D
M<VXI('L*("`@(&5C:&\@(D133CH@)&1S;EQN(CL*("`@('!R:6YT7W(H1$(Z
M.G!A<G-E1%-.*"1D<VXI*3L*?0H*9G5N8W1I;VX@=&5S=$%R<F%Y*"1D<VXI
M('L*("`@(&5C:&\@(D133CH@87)R87E<;B(["B`@("!P<FEN=%]R*$1".CIP
M87)S94133B@D9'-N*2D["GT*"G!R:6YT(")T97-T:6YG($1".CIP87)S9413
M3BXN+EQN7&XB.PH*=&5S="@B;7ES<6PB*3L*=&5S="@B;V1B8RAM<W-Q;"DB
M*3L*=&5S="@G;V1B8RAD8C(I.B\O=7-E<CIP87-S=V]R9$`O9&%T86)A<V4G
M*3L*=&5S="@G;V1B8RAA8V-E<W,I.B\O+V1A=&%B87-E)RD["G1E<W0H)V]D
M8F,Z+R]A9&UI;D`O9&%T87-O=7)C94YA;64G*3L*=&5S="@B;7ES<6PZ+R]L
M;V-A;&AO<W0B*3L*=&5S="@B;7ES<6PZ+R]R96UO=&4N:&]S="YC;VTO9&(B
M*3L*=&5S="@B;V-I.#HO+W-Y<W1E;3IM86YA9V5R0"(I.PIT97-T*")O8VDX
M.B\O=7-E<CIP87-S0'1N<RUN86UE(BD["G1E<W0H(F]D8F,H<V]L:60I.B\O
M9F]O.F)A<D!T8W`K;&]C86QH;W-T*S$S,3,B*3L@("\O(&1E<')E8V%T960*
M=&5S="@B<&=S<6PZ+R]U<V5R0'5N:7@K;&]C86QH;W-T+W!E87(B*3L@("`@
M("`@("`@+R\@9&5P<F5C871E9`IT97-T*")I8F%S93HO+W5S97(E-#!D;VUA
M:6XZ<&%S<W=O<F1`:&]S="(I.PIT97-T*")I8F%S93HO+W5S97)`9&]M86EN
M.G!A<W-`=V]R9$`O9&%T86)A<V4B*3L@("`O+R!A;'-O('-U<'!O<G1E9`IT
M97-T*")I9G@Z+R]U<V5R0&1O;6%I;CIP87-S0'=O<F1`:&]S="YC;VTO+W5S
M<B]D8B]G96YE<F%L+F1B(BD["G1E<W0H)VEF>#HO+W)E;6]T92YH;W-T+F-O
M;2]C.EQW:6YD;W=S7&UY+F1B)RD["G1E<W0H)V]C:3@Z+R]32$]/5$]55#HJ
M*BHJ*BI`*$1%4T-225!424]./2A!1$1215-37TQ)4U0]*$%$1%)%4U,]*%!2
M3U1/0T],/51#4"DH2$]35#TQ.3(N,38X+C$P,2XQ-C$I*%!/4E0],34R,2DI
M*2A#3TY.14-47T1!5$$]*%-%4E9)0T5?3D%-13U425,I*2DG*3L*"B\O(&YE
M=R!F;W)M871S"G1E<W0H(F]D8F,H<V]L:60I.B\O9F]O.F)A<D!L;V-A;&AO
M<W0Z,3,Q,R(I.PIT97-T*")P9W-Q;#HO+W5S97)`=6YI>"@I+W!E87(B*3L*
M=&5S="@B;7ES<6PZ+R]U<V5R0'5N:7@H+W!A=&@O=&\O<V]C:V5T*2]P96%R
M(BD["G1E<W0H(G!G<W%L.B\O=7-E<D!T8W`H*2]P96%R(BD["G1E<W0H(G!G
M<W%L.B\O=7-E<D!T8W`H<V]M96AO<W0I+W!E87(B*3L*=&5S="@B<&=S<6PZ
M+R]U<V5R.G!A<W-`=V]R9$!T8W`H<V]M96AO<W0Z-S<W-RDO<&5A<B(I.PH*
M+R\@<W!E8VEA;"!B86-K96YD(&]P=&EO;G,*=&5S="@G:6)A<V4Z+R]U<V5R
M.G!A<W-`;&]C86QH;W-T+R]V87(O;&EB+V1B87-E+F1B9C]R;VQE/69O;R<I
M.PIT97-T*"=D8F%S93HO+T`O/W)O;&4]9F]O)F1I86QE8W0]8F%R)RD["G1E
M<W0H)W-Q;&ET93HO+R\O=6YI>"]P871H+W1O+V1A=&%B87-E/V]P=&EO;CUV
M86QU929A;F]T:&5R;W!T:6]N/6%N;W1H97)V86QU92<I.PIT97-T*"=S<6QI
M=&4Z+R\O8SHO=VEN+W!A=&@O=&\O9&%T86)A<V4_;W!T:6]N/79A;'5E)RD[
M"@HO+R!S;VUE(&5X86UP;&5S(&9R;VT@;6%N=6%L"G1E<W0H)VUY<W%L.B\O
M=7-E<FYA;65`:&]S='-P96,G*3L*=&5S="@G;7ES<6PZ+R]H;W-T<W!E8R]D
M871A8F%S92<I.PIT97-T*"=M>7-Q;#HO+VAO<W1S<&5C)RD["G1E<W0H)VUY
M<W%L.B\O+V1A=&%B87-E)RD["@HO+R!A<G)A>2!T97-T<PHD87)R87D@/2!A
M<G)A>2@*("`@("=P:'!T>7!E)R`@/3X@)VUY<W%L)RP*("`@("=H;W-T<W!E
M8R<@/3X@)V9O;V)A<B<L"BD["G1E<W1!<G)A>2@D87)R87DI.PH*/SX*+2U'
M150M+0HM+5!/4U0M+0HM+4584$5#5"TM"G1E<W1I;F<@1$(Z.G!A<G-E1%-.
M+BXN"@I$4TXZ(&UY<W%L"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!M>7-Q
M;`H@("`@6V1B<WEN=&%X72`]/B!M>7-Q;`H@("`@6W5S97)N86UE72`]/B`*
M("`@(%MP87-S=V]R9%T@/3X@"B`@("!;<')O=&]C;VQ=(#T^(`H@("`@6VAO
M<W1S<&5C72`]/B`*("`@(%MP;W)T72`]/B`*("`@(%MS;V-K971=(#T^(`H@
M("`@6V1A=&%B87-E72`]/B`**0I$4TXZ(&]D8F,H;7-S<6PI"D%R<F%Y"B@*
M("`@(%MP:'!T>7!E72`]/B!O9&)C"B`@("!;9&)S>6YT87A=(#T^(&US<W%L
M"B`@("!;=7-E<FYA;65=(#T^(`H@("`@6W!A<W-W;W)D72`]/B`*("`@(%MP
M<F]T;V-O;%T@/3X@"B`@("!;:&]S='-P96-=(#T^(`H@("`@6W!O<G1=(#T^
M(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^(`HI"D133CH@
M;V1B8RAD8C(I.B\O=7-E<CIP87-S=V]R9$`O9&%T86)A<V4*07)R87D**`H@
M("`@6W!H<'1Y<&5=(#T^(&]D8F,*("`@(%MD8G-Y;G1A>%T@/3X@9&(R"B`@
M("!;=7-E<FYA;65=(#T^('5S97(*("`@(%MP87-S=V]R9%T@/3X@<&%S<W=O
M<F0*("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P96-=(#T^(`H@
M("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=
M(#T^(&1A=&%B87-E"BD*1%-..B!O9&)C*&%C8V5S<RDZ+R\O9&%T86)A<V4*
M07)R87D**`H@("`@6W!H<'1Y<&5=(#T^(&]D8F,*("`@(%MD8G-Y;G1A>%T@
M/3X@86-C97-S"B`@("!;=7-E<FYA;65=(#T^(`H@("`@6W!A<W-W;W)D72`]
M/B`*("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P96-=(#T^(`H@
M("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=
M(#T^(&1A=&%B87-E"BD*1%-..B!O9&)C.B\O861M:6Y`+V1A=&%S;W5R8V5.
M86UE"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!O9&)C"B`@("!;9&)S>6YT
M87A=(#T^(&]D8F,*("`@(%MU<V5R;F%M95T@/3X@861M:6X*("`@(%MP87-S
M=V]R9%T@/3X@"B`@("!;<')O=&]C;VQ=(#T^('1C<`H@("`@6VAO<W1S<&5C
M72`]/B`*("`@(%MP;W)T72`]/B`*("`@(%MS;V-K971=(#T^(`H@("`@6V1A
M=&%B87-E72`]/B!D871A<V]U<F-E3F%M90HI"D133CH@;7ES<6PZ+R]L;V-A
M;&AO<W0*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^(&UY<W%L"B`@("!;9&)S
M>6YT87A=(#T^(&UY<W%L"B`@("!;=7-E<FYA;65=(#T^(`H@("`@6W!A<W-W
M;W)D72`]/B`*("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P96-=
M(#T^(&QO8V%L:&]S=`H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@
M"B`@("!;9&%T86)A<V5=(#T^(`HI"D133CH@;7ES<6PZ+R]R96UO=&4N:&]S
M="YC;VTO9&(*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^(&UY<W%L"B`@("!;
M9&)S>6YT87A=(#T^(&UY<W%L"B`@("!;=7-E<FYA;65=(#T^(`H@("`@6W!A
M<W-W;W)D72`]/B`*("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P
M96-=(#T^(')E;6]T92YH;W-T+F-O;0H@("`@6W!O<G1=(#T^(`H@("`@6W-O
M8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^(&1B"BD*1%-..B!O8VDX.B\O
M<WES=&5M.FUA;F%G97)`"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!O8VDX
M"B`@("!;9&)S>6YT87A=(#T^(&]C:3@*("`@(%MU<V5R;F%M95T@/3X@<WES
M=&5M"B`@("!;<&%S<W=O<F1=(#T^(&UA;F%G97(*("`@(%MP<F]T;V-O;%T@
M/3X@=&-P"B`@("!;:&]S='-P96-=(#T^(`H@("`@6W!O<G1=(#T^(`H@("`@
M6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^(`HI"D133CH@;V-I.#HO
M+W5S97(Z<&%S<T!T;G,M;F%M90I!<G)A>0HH"B`@("!;<&AP='EP95T@/3X@
M;V-I.`H@("`@6V1B<WEN=&%X72`]/B!O8VDX"B`@("!;=7-E<FYA;65=(#T^
M('5S97(*("`@(%MP87-S=V]R9%T@/3X@<&%S<PH@("`@6W!R;W1O8V]L72`]
M/B!T8W`*("`@(%MH;W-T<W!E8UT@/3X@=&YS+6YA;64*("`@(%MP;W)T72`]
M/B`*("`@(%MS;V-K971=(#T^(`H@("`@6V1A=&%B87-E72`]/B`**0I$4TXZ
M(&]D8F,H<V]L:60I.B\O9F]O.F)A<D!T8W`K;&]C86QH;W-T*S$S,3,*07)R
M87D**`H@("`@6W!H<'1Y<&5=(#T^(&]D8F,*("`@(%MD8G-Y;G1A>%T@/3X@
M<V]L:60*("`@(%MU<V5R;F%M95T@/3X@9F]O"B`@("!;<&%S<W=O<F1=(#T^
M(&)A<@H@("`@6W!R;W1O8V]L72`]/B!T8W`*("`@(%MH;W-T<W!E8UT@/3X@
M;&]C86QH;W-T*S$S,3,*("`@(%MP;W)T72`]/B`*("`@(%MS;V-K971=(#T^
M(`H@("`@6V1A=&%B87-E72`]/B`**0I$4TXZ('!G<W%L.B\O=7-E<D!U;FEX
M*VQO8V%L:&]S="]P96%R"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!P9W-Q
M;`H@("`@6V1B<WEN=&%X72`]/B!P9W-Q;`H@("`@6W5S97)N86UE72`]/B!U
M<V5R"B`@("!;<&%S<W=O<F1=(#T^(`H@("`@6W!R;W1O8V]L72`]/B!U;FEX
M"B`@("!;:&]S='-P96-=(#T^(`H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME
M=%T@/3X@;&]C86QH;W-T"B`@("!;9&%T86)A<V5=(#T^('!E87(**0I$4TXZ
M(&EB87-E.B\O=7-E<B4T,&1O;6%I;CIP87-S=V]R9$!H;W-T"D%R<F%Y"B@*
M("`@(%MP:'!T>7!E72`]/B!I8F%S90H@("`@6V1B<WEN=&%X72`]/B!I8F%S
M90H@("`@6W5S97)N86UE72`]/B!U<V5R0&1O;6%I;@H@("`@6W!A<W-W;W)D
M72`]/B!P87-S=V]R9`H@("`@6W!R;W1O8V]L72`]/B!T8W`*("`@(%MH;W-T
M<W!E8UT@/3X@:&]S=`H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@
M"B`@("!;9&%T86)A<V5=(#T^(`HI"D133CH@:6)A<V4Z+R]U<V5R0&1O;6%I
M;CIP87-S0'=O<F1`+V1A=&%B87-E"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]
M/B!I8F%S90H@("`@6V1B<WEN=&%X72`]/B!I8F%S90H@("`@6W5S97)N86UE
M72`]/B!U<V5R0&1O;6%I;@H@("`@6W!A<W-W;W)D72`]/B!P87-S0'=O<F0*
M("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P96-=(#T^(`H@("`@
M6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^
M(&1A=&%B87-E"BD*1%-..B!I9G@Z+R]U<V5R0&1O;6%I;CIP87-S0'=O<F1`
M:&]S="YC;VTO+W5S<B]D8B]G96YE<F%L+F1B"D%R<F%Y"B@*("`@(%MP:'!T
M>7!E72`]/B!I9G@*("`@(%MD8G-Y;G1A>%T@/3X@:69X"B`@("!;=7-E<FYA
M;65=(#T^('5S97)`9&]M86EN"B`@("!;<&%S<W=O<F1=(#T^('!A<W-`=V]R
M9`H@("`@6W!R;W1O8V]L72`]/B!T8W`*("`@(%MH;W-T<W!E8UT@/3X@:&]S
M="YC;VT*("`@(%MP;W)T72`]/B`*("`@(%MS;V-K971=(#T^(`H@("`@6V1A
M=&%B87-E72`]/B`O=7-R+V1B+V=E;F5R86PN9&(**0I$4TXZ(&EF>#HO+W)E
M;6]T92YH;W-T+F-O;2]C.EQW:6YD;W=S7&UY+F1B"D%R<F%Y"B@*("`@(%MP
M:'!T>7!E72`]/B!I9G@*("`@(%MD8G-Y;G1A>%T@/3X@:69X"B`@("!;=7-E
M<FYA;65=(#T^(`H@("`@6W!A<W-W;W)D72`]/B`*("`@(%MP<F]T;V-O;%T@
M/3X@=&-P"B`@("!;:&]S='-P96-=(#T^(')E;6]T92YH;W-T+F-O;0H@("`@
M6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^
M(&,Z7'=I;F1O=W-<;7DN9&(**0I$4TXZ(&]C:3@Z+R]32$]/5$]55#HJ*BHJ
M*BI`*$1%4T-225!424]./2A!1$1215-37TQ)4U0]*$%$1%)%4U,]*%!23U1/
M0T],/51#4"DH2$]35#TQ.3(N,38X+C$P,2XQ-C$I*%!/4E0],34R,2DI*2A#
M3TY.14-47T1!5$$]*%-%4E9)0T5?3D%-13U425,I*2D*07)R87D**`H@("`@
M6W!H<'1Y<&5=(#T^(&]C:3@*("`@(%MD8G-Y;G1A>%T@/3X@;V-I.`H@("`@
M6W5S97)N86UE72`]/B!32$]/5$]55`H@("`@6W!A<W-W;W)D72`]/B`J*BHJ
M*BH*("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P96-=(#T^("A$
M15-#4DE05$E/3CTH041$4D534U],25-4/2A!1$1215-3/2A04D]43T-/3#U4
M0U`I*$A/4U0],3DR+C$V."XQ,#$N,38Q*2A03U)4/3$U,C$I*2DH0T].3D5#
M5%]$051!/2A315)624-%7TY!344]5$E3*2DI"B`@("!;<&]R=%T@/3X@"B`@
M("!;<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@/3X@"BD*1%-..B!O9&)C
M*'-O;&ED*3HO+V9O;SIB87)`;&]C86QH;W-T.C$S,3,*07)R87D**`H@("`@
M6W!H<'1Y<&5=(#T^(&]D8F,*("`@(%MD8G-Y;G1A>%T@/3X@<V]L:60*("`@
M(%MU<V5R;F%M95T@/3X@9F]O"B`@("!;<&%S<W=O<F1=(#T^(&)A<@H@("`@
M6W!R;W1O8V]L72`]/B!T8W`*("`@(%MH;W-T<W!E8UT@/3X@;&]C86QH;W-T
M"B`@("!;<&]R=%T@/3X@,3,Q,PH@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T
M86)A<V5=(#T^(`HI"D133CH@<&=S<6PZ+R]U<V5R0'5N:7@H*2]P96%R"D%R
M<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!P9W-Q;`H@("`@6V1B<WEN=&%X72`]
M/B!P9W-Q;`H@("`@6W5S97)N86UE72`]/B!U<V5R"B`@("!;<&%S<W=O<F1=
M(#T^(`H@("`@6W!R;W1O8V]L72`]/B!U;FEX"B`@("!;:&]S='-P96-=(#T^
M(`H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A
M<V5=(#T^('!E87(**0I$4TXZ(&UY<W%L.B\O=7-E<D!U;FEX*"]P871H+W1O
M+W-O8VME="DO<&5A<@I!<G)A>0HH"B`@("!;<&AP='EP95T@/3X@;7ES<6P*
M("`@(%MD8G-Y;G1A>%T@/3X@;7ES<6P*("`@(%MU<V5R;F%M95T@/3X@=7-E
M<@H@("`@6W!A<W-W;W)D72`]/B`*("`@(%MP<F]T;V-O;%T@/3X@=6YI>`H@
M("`@6VAO<W1S<&5C72`]/B`*("`@(%MP;W)T72`]/B`*("`@(%MS;V-K971=
M(#T^("]P871H+W1O+W-O8VME=`H@("`@6V1A=&%B87-E72`]/B!P96%R"BD*
M1%-..B!P9W-Q;#HO+W5S97)`=&-P*"DO<&5A<@I!<G)A>0HH"B`@("!;<&AP
M='EP95T@/3X@<&=S<6P*("`@(%MD8G-Y;G1A>%T@/3X@<&=S<6P*("`@(%MU
M<V5R;F%M95T@/3X@=7-E<@H@("`@6W!A<W-W;W)D72`]/B`*("`@(%MP<F]T
M;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P96-=(#T^(`H@("`@6W!O<G1=(#T^
M(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^('!E87(**0I$
M4TXZ('!G<W%L.B\O=7-E<D!T8W`H<V]M96AO<W0I+W!E87(*07)R87D**`H@
M("`@6W!H<'1Y<&5=(#T^('!G<W%L"B`@("!;9&)S>6YT87A=(#T^('!G<W%L
M"B`@("!;=7-E<FYA;65=(#T^('5S97(*("`@(%MP87-S=V]R9%T@/3X@"B`@
M("!;<')O=&]C;VQ=(#T^('1C<`H@("`@6VAO<W1S<&5C72`]/B!S;VUE:&]S
M=`H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A
M<V5=(#T^('!E87(**0I$4TXZ('!G<W%L.B\O=7-E<CIP87-S0'=O<F1`=&-P
M*'-O;65H;W-T.C<W-S<I+W!E87(*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^
M('!G<W%L"B`@("!;9&)S>6YT87A=(#T^('!G<W%L"B`@("!;=7-E<FYA;65=
M(#T^('5S97(*("`@(%MP87-S=V]R9%T@/3X@<&%S<T!W;W)D"B`@("!;<')O
M=&]C;VQ=(#T^('1C<`H@("`@6VAO<W1S<&5C72`]/B!S;VUE:&]S=`H@("`@
M6W!O<G1=(#T^(#<W-S<*("`@(%MS;V-K971=(#T^(`H@("`@6V1A=&%B87-E
M72`]/B!P96%R"BD*1%-..B!I8F%S93HO+W5S97(Z<&%S<T!L;V-A;&AO<W0O
M+W9A<B]L:6(O9&)A<V4N9&)F/W)O;&4]9F]O"D%R<F%Y"B@*("`@(%MP:'!T
M>7!E72`]/B!I8F%S90H@("`@6V1B<WEN=&%X72`]/B!I8F%S90H@("`@6W5S
M97)N86UE72`]/B!U<V5R"B`@("!;<&%S<W=O<F1=(#T^('!A<W,*("`@(%MP
M<F]T;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P96-=(#T^(&QO8V%L:&]S=`H@
M("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=
M(#T^("]V87(O;&EB+V1B87-E+F1B9@H@("`@6W)O;&5=(#T^(&9O;PHI"D13
M3CH@9&)A<V4Z+R]`+S]R;VQE/69O;R9D:6%L96-T/6)A<@I!<G)A>0HH"B`@
M("!;<&AP='EP95T@/3X@9&)A<V4*("`@(%MD8G-Y;G1A>%T@/3X@9&)A<V4*
M("`@(%MU<V5R;F%M95T@/3X@"B`@("!;<&%S<W=O<F1=(#T^(`H@("`@6W!R
M;W1O8V]L72`]/B!T8W`*("`@(%MH;W-T<W!E8UT@/3X@"B`@("!;<&]R=%T@
M/3X@"B`@("!;<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@/3X@"B`@("!;
M<F]L95T@/3X@9F]O"B`@("!;9&EA;&5C=%T@/3X@8F%R"BD*1%-..B!S<6QI
M=&4Z+R\O+W5N:7@O<&%T:"]T;R]D871A8F%S93]O<'1I;VX]=F%L=64F86YO
M=&AE<F]P=&EO;CUA;F]T:&5R=F%L=64*07)R87D**`H@("`@6W!H<'1Y<&5=
M(#T^('-Q;&ET90H@("`@6V1B<WEN=&%X72`]/B!S<6QI=&4*("`@(%MU<V5R
M;F%M95T@/3X@"B`@("!;<&%S<W=O<F1=(#T^(`H@("`@6W!R;W1O8V]L72`]
M/B!T8W`*("`@(%MH;W-T<W!E8UT@/3X@"B`@("!;<&]R=%T@/3X@"B`@("!;
M<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@/3X@+W5N:7@O<&%T:"]T;R]D
M871A8F%S90H@("`@6V]P=&EO;ET@/3X@=F%L=64*("`@(%MA;F]T:&5R;W!T
M:6]N72`]/B!A;F]T:&5R=F%L=64**0I$4TXZ('-Q;&ET93HO+R]C.B]W:6XO
M<&%T:"]T;R]D871A8F%S93]O<'1I;VX]=F%L=64*07)R87D**`H@("`@6W!H
M<'1Y<&5=(#T^('-Q;&ET90H@("`@6V1B<WEN=&%X72`]/B!S<6QI=&4*("`@
M(%MU<V5R;F%M95T@/3X@"B`@("!;<&%S<W=O<F1=(#T^(`H@("`@6W!R;W1O
M8V]L72`]/B!T8W`*("`@(%MH;W-T<W!E8UT@/3X@"B`@("!;<&]R=%T@/3X@
M"B`@("!;<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@/3X@8SHO=VEN+W!A
M=&@O=&\O9&%T86)A<V4*("`@(%MO<'1I;VY=(#T^('9A;'5E"BD*1%-..B!M
M>7-Q;#HO+W5S97)N86UE0&AO<W1S<&5C"D%R<F%Y"B@*("`@(%MP:'!T>7!E
M72`]/B!M>7-Q;`H@("`@6V1B<WEN=&%X72`]/B!M>7-Q;`H@("`@6W5S97)N
M86UE72`]/B!U<V5R;F%M90H@("`@6W!A<W-W;W)D72`]/B`*("`@(%MP<F]T
M;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P96-=(#T^(&AO<W1S<&5C"B`@("!;
M<&]R=%T@/3X@"B`@("!;<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@/3X@
M"BD*1%-..B!M>7-Q;#HO+VAO<W1S<&5C+V1A=&%B87-E"D%R<F%Y"B@*("`@
M(%MP:'!T>7!E72`]/B!M>7-Q;`H@("`@6V1B<WEN=&%X72`]/B!M>7-Q;`H@
M("`@6W5S97)N86UE72`]/B`*("`@(%MP87-S=V]R9%T@/3X@"B`@("!;<')O
M=&]C;VQ=(#T^('1C<`H@("`@6VAO<W1S<&5C72`]/B!H;W-T<W!E8PH@("`@
M6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^
M(&1A=&%B87-E"BD*1%-..B!M>7-Q;#HO+VAO<W1S<&5C"D%R<F%Y"B@*("`@
M(%MP:'!T>7!E72`]/B!M>7-Q;`H@("`@6V1B<WEN=&%X72`]/B!M>7-Q;`H@
M("`@6W5S97)N86UE72`]/B`*("`@(%MP87-S=V]R9%T@/3X@"B`@("!;<')O
M=&]C;VQ=(#T^('1C<`H@("`@6VAO<W1S<&5C72`]/B!H;W-T<W!E8PH@("`@
M6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^
M(`HI"D133CH@;7ES<6PZ+R\O9&%T86)A<V4*07)R87D**`H@("`@6W!H<'1Y
M<&5=(#T^(&UY<W%L"B`@("!;9&)S>6YT87A=(#T^(&UY<W%L"B`@("!;=7-E
M<FYA;65=(#T^(`H@("`@6W!A<W-W;W)D72`]/B`*("`@(%MP<F]T;V-O;%T@
M/3X@=&-P"B`@("!;:&]S='-P96-=(#T^(`H@("`@6W!O<G1=(#T^(`H@("`@
M6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^(&1A=&%B87-E"BD*1%-.
M.B!A<G)A>0I!<G)A>0HH"B`@("!;<&AP='EP95T@/3X@;7ES<6P*("`@(%MD
M8G-Y;G1A>%T@/3X@;7ES<6P*("`@(%MU<V5R;F%M95T@/3X@"B`@("!;<&%S
M<W=O<F1=(#T^(`H@("`@6W!R;W1O8V]L72`]/B`*("`@(%MH;W-T<W!E8UT@
M/3X@9F]O8F%R"B`@("!;<&]R=%T@/3X@"B`@("!;<V]C:V5T72`]/B`*("`@
M(%MD871A8F%S95T@/3X@"BD*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O
M1$(O=&5S=',O9')I=F5R+P``````````````````````````````````````
M````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`U,34T,S,W-#$`,#(R-C8V`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O,#%C;VYN96-T+G!H
M<'0````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S(U-``Q,#4Q-30S,S<T,0`P,C4S-C$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+2U4
M15-4+2T*1$)?9')I=F5R.CIC;VYN96-T"BTM24Y)+2T*97)R;W)?<F5P;W)T
M:6YG(#T@,C`T-PHM+5-+25!)1BTM"CP_<&AP(&-H9&ER*&1I<FYA;64H7U]&
M24Q%7U\I*3L@<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G.R`_/@HM+49)
M3$4M+0H\/W!H<`IR97%U:7)E7V]N8V4@)RXO8V]N;F5C="YI;F,G.PH*+RHJ
M"B`J($1E=&5R;6EN92!I9B!T:&4@9&%T86)A<V4@8V]N;F5C=&EO;B!M871C
M:&5S('=H870G<R!E>'!E8W1E9`H@*@H@*B!`<&%R86T@;V)J96-T("1D8F@@
M("!T:&4@4$5!4B!$0B!O8FIE8W0*("H@0'!A<F%M('-T<FEN9R`D;F%M92`@
M=&AE(&YA;64@;V8@=&AE(&-U<G)E;G0@=&5S=`H@*@H@*B!`<F5T=7)N('9O
M:60*("HO"F9U;F-T:6]N(&-H96-K7V1B:"@D9&)H+"`D;F%M92D@>PH@("`@
M:68@*$1".CII<T5R<F]R*"1D8F@I*2!["B`@("`@("`@9&EE*"=C;VYN96-T
M+FEN8SH@)R`N("1D8F@M/G1O4W1R:6YG*"DI.PH@("`@?0H@("`@:68@*&ES
M7V]B:F5C="@D9&)H*2D@>PH@("`@("`@('!R:6YT("(D;F%M92!I<R!A;B!O
M8FIE8W1<;B(["B`@("!]"B`@("!S=VET8V@@*"1D8F@M/G!H<'1Y<&4I('L*
M("`@("`@("!C87-E("=D8F%S92<Z"B`@("`@("`@("`@(&EF("AI<U]I;G0H
M)&1B:"T^8V]N;F5C=&EO;BDI('L*("`@("`@("`@("`@("`@('!R:6YT("(D
M;F%M92!I<R!C;VYN96-T961<;B(["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("!P<FEN="`B)&YA;64@3D]4(&-O;FYE8W1E9%QN(CL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!C87-E
M("=M>7-Q;&DG.@H@("`@("`@("`@("!I9B`H:7-?82@D9&)H+3YC;VYN96-T
M:6]N+"`G;7ES<6QI)RDI('L*("`@("`@("`@("`@("`@('!R:6YT("(D;F%M
M92!I<R!C;VYN96-T961<;B(["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("!P<FEN="`B)&YA;64@3D]4(&-O;FYE8W1E9%QN(CL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!D969A=6QT
M.@H@("`@("`@("`@("!I9B`H9V5T='EP92@D9&)H+3YC;VYN96-T:6]N*2`]
M/2`G<F5S;W5R8V4G*2!["B`@("`@("`@("`@("`@("!P<FEN="`B)&YA;64@
M:7,@8V]N;F5C=&5D7&XB.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@<')I;G0@(B1N86UE($Y/5"!C;VYN96-T961<;B(["B`@("`@
M("`@("`@('T*("`@('T*?0H*"F-H96-K7V1B:"@D9&)H+"`G)&1B:"<I.PH*
M"B1T97-T7V%R<F%Y7V1S;B`]($1".CIP87)S94133B@D9'-N*3L*9F]R96%C
M:"`H)'1E<W1?87)R87E?9'-N(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("!I
M9B`H)'9A;'5E(#T]/2!F86QS92D@>PH@("`@("`@('5N<V5T*"1T97-T7V%R
M<F%Y7V1S;ELD:V5Y72D["B`@("!]"GT*"B1D8FAA(#TF($1".CIC;VYN96-T
M*"1T97-T7V%R<F%Y7V1S;BP@)&]P=&EO;G,I.PIC:&5C:U]D8F@H)&1B:&$L
M("<D9&)H82<I.PH*"B1T;7`@(#T@<V5R:6%L:7IE*"1D8FAA*3L*)&1B:'4@
M/2!U;G-E<FEA;&EZ92@D=&UP*3L*8VAE8VM?9&)H*"1D8FAU+"`G)&1B:'4G
M*3L*"C\^"BTM15A014-4+2T*)&1B:"!I<R!A;B!O8FIE8W0*)&1B:"!I<R!C
M;VYN96-T960*)&1B:&$@:7,@86X@;V)J96-T"B1D8FAA(&ES(&-O;FYE8W1E
M9`HD9&)H=2!I<R!A;B!O8FIE8W0*)&1B:'4@:7,@8V]N;F5C=&5D"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+S`R9F5T8V@N<&AP=```````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(Q-C``,3`U,34T,S,W-#$`,#(U,#$U`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"TM5$535"TM
M"D1"7V1R:79E<CHZ9F5T8V@*+2U)3DDM+0IE<G)O<E]R97!O<G1I;F<@/2`R
M,#0W"BTM4TM)4$E&+2T*/#]P:'`@8VAD:7(H9&ER;F%M92A?7T9)3$5?7RDI
M.R!R97%U:7)E7V]N8V4@)RXO<VMI<&EF+FEN8R<[(#\^"BTM1DE,12TM"CP_
M<&AP"G)E<75I<F5?;VYC92`G+B]M:W1A8FQE+FEN8R<["G)E<75I<F5?;VYC
M92`G+BXO9F5T8VAM;V1E<RYI;F,G.PH_/@HM+4584$5#5"TM"G1E<W1I;F<@
M9F5T8VAR;W<Z"G)O=R`Q.B`T,BP@8FEN9RP@5&AI<R!I<R!A('1E<W0L(#$Y
M.3DM,3$M,C$*<F]W(#(Z(#$L(&]N92P@3VYE+"`R,#`Q+3`R+3$V"G)O=R`S
M.B`R+"!T=V\L(%1W;RP@,C`P,2TP,BTQ-0IR;W<@-#H@,RP@=&AR964L(%1H
M<F5E+"`R,#`Q+3`R+3$T"G)O=R`U.B!.54Q,"G1E<W1I;F<@9F5T8VAM;V1E
M<SH@9F5T8VAR;W<@9&5F875L="!D969A=6QT+"!P;W)T86)I;&ET>2!M;V1E
M($1"7U!/4E1!0DE,25197T%,3"!>($1"7U!/4E1!0DE,25197U)44DE-"C`@
M,2`R(#,*;W5T<'5T(&UA=&-H960@97AP96-T960@9F]R;6%T"G1E<W1I;F<@
M9F5T8VAM;V1E<SH@9F5T8VAI;G1O(&1E9F%U;'0@9&5F875L=`HP(#$@,B`S
M"C0R(&)I;F<@5&AI<R!I<R!A('1E<W0@,3DY.2TQ,2TR,0IT97-T:6YG(&9E
M=&-H;6]D97,Z(&9E=&-H<F]W(&]R9&5R960@9&5F875L=`HP(#$@,B`S"G1E
M<W1I;F<@9F5T8VAM;V1E<SH@9F5T8VAR;W<@87-S;V,@9&5F875L=`IA(&(@
M8R!D"G1E<W1I;F<@9F5T8VAM;V1E<SH@9F5T8VAR;W<@;W)D97)E9"!D969A
M=6QT('=I=&@@87-S;V,@<W!E8VEF:65D"F$@8B!C(&0*=&5S=&EN9R!F971C
M:&UO9&5S.B!F971C:')O=R!A<W-O8R!D969A=6QT('=I=&@@;W)D97)E9"!S
M<&5C:69I960*,"`Q(#(@,PIT97-T:6YG(&9E=&-H;6]D97,Z(&9E=&-H:6YT
M;R!O<F1E<F5D(&1E9F%U;'0*,"`Q(#(@,PIT97-T:6YG(&9E=&-H;6]D97,Z
M(&9E=&-H:6YT;R!A<W-O8R!D969A=6QT"F$@8B!C(&0*=&5S=&EN9R!F971C
M:&UO9&5S.B!F971C:&EN=&\@;W)D97)E9"!D969A=6QT('=I=&@@87-S;V,@
M<W!E8VEF:65D"F$@8B!C(&0*=&5S=&EN9R!F971C:&UO9&5S.B!F971C:&EN
M=&\@87-S;V,@9&5F875L="!W:71H(&]R9&5R960@<W!E8VEF:65D"C`@,2`R
M(#,*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D
M<FEV97(O,#-S:6UP;&5Q=65R>2YP:'!T````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,U-P`Q
M,#4Q-30S,S<T,0`P,C8S,3(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+2U415-4+2T*1$)?9')I=F5R.CIS:6UP;&51=65R
M>0HM+4E.22TM"F5R<F]R7W)E<&]R=&EN9R`](#(P-#<*+2U32TE0248M+0H\
M/W!H<"!C:&1I<BAD:7)N86UE*%]?1DE,15]?*2D[(')E<75I<F5?;VYC92`G
M+B]S:VEP:68N:6YC)SL@/SX*+2U&24Q%+2T*/#]P:'`*<F5Q=6ER95]O;F-E
M("<N+VUK=&%B;&4N:6YC)SL*<F5Q=6ER95]O;F-E("<N+B]S:6UP;&5Q=65R
M>2YI;F,G.PH_/@HM+4584$5#5"TM"G!A<W-E9`H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+S`T;G5M
M8V]L<RYP:'!T````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S-3``,3`U,34T,S,W-#$`
M,#(U-#`U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"TM5$535"TM"D1"7V1R:79E<CHZ;G5M0V]L<PHM+4E.22TM"F5R<F]R
M7W)E<&]R=&EN9R`](#(P-#<*+2U32TE0248M+0H\/W!H<"!C:&1I<BAD:7)N
M86UE*%]?1DE,15]?*2D[(')E<75I<F5?;VYC92`G+B]S:VEP:68N:6YC)SL@
M/SX*+2U&24Q%+2T*/#]P:'`*<F5Q=6ER95]O;F-E("<N+VUK=&%B;&4N:6YC
M)SL*<F5Q=6ER95]O;F-E("<N+B]N=6UC;VQS+FEN8R<["C\^"BTM15A014-4
M+2T*,0HR"C,*-`H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\P-7-E<75E;F-E<RYP:'!T
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`Q,#$W`#$P-3$U-#,S-S0Q`#`R-3<R,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````M+51%4U0M
M+0I$0E]D<FEV97(Z.G-E<75E;F-E<PHM+4E.22TM"F5R<F]R7W)E<&]R=&EN
M9R`](#(P-#<*+2U32TE0248M+0H\/W!H<`IE<G)O<E]R97!O<G1I;F<H15]!
M3$PI.PIC:&1I<BAD:7)N86UE*%]?1DE,15]?*2D["G)E<75I<F5?;VYC92`G
M+B]S:VEP:68N:6YC)SL*)'1A8FQE26YF;R`]("1D8BT^9')O<%-E<75E;F-E
M*"=A:FMD<VQF86IO:6IK861I92<I.PII9B`H1$(Z.FES17)R;W(H)'1A8FQE
M26YF;RD@)B8@)'1A8FQE26YF;RT^8V]D92`]/2!$0E]%4E)/4E].3U1?0T%0
M04),12D@>PH@("`@9&EE*")S:VEP("1T86)L94EN9F\M/FUE<W-A9V4B*3L*
M?0H_/@HM+49)3$4M+0H\/W!H<`IR97%U:7)E7V]N8V4@)RXO8V]N;F5C="YI
M;F,G.PIR97%U:7)E7V]N8V4@)RXN+W-E<75E;F-E<RYI;F,G.PH_/@HM+458
M4$5#5"TM"F%N(&5R<F]R(&ES('1H92!P<F]P97(@<F5S<&]N<V4@:&5R90IA
M;B!E<G)O<B!C;W5G:'0@8GD@=&AE(&5R<F]R(&AA;F1L97(@:7,@9V]O9`IA
M/3$*8CTR"F(M83TQ"F,],0ID/3$*93TQ"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\P-G!R97!E>&5C
M+G!H<'0``````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S<U`#$P-3$U-#,S-S0Q`#`R-34U
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````M
M+51%4U0M+0I$0E]D<FEV97(Z.G!R97!A<F4O97AE8W5T90HM+4E.22TM"F5R
M<F]R7W)E<&]R=&EN9R`](#(P-#<*+2U32TE0248M+0H\/W!H<"!C:&1I<BAD
M:7)N86UE*%]?1DE,15]?*2D[(')E<75I<F5?;VYC92`G+B]S:VEP:68N:6YC
M)SL@/SX*+2U&24Q%+2T*/#]P:'`*<F5Q=6ER95]O;F-E("<N+VUK=&%B;&4N
M:6YC)SL*<F5Q=6ER95]O;F-E("<N+B]P<F5P97AE+FEN8R<["C\^"BTM15A0
M14-4+2T*+2TM+2TM+2TM+2TM,2TM+2TM+2TM+2TM+0IS=&@Q+'-T:#(L<W1H
M,RQS=&@T(&-R96%T960*<W1H,3H@/R!A<R!P87)A;2P@<&%S<VEN9R!A<R!A
M<G)A>2XN+B!S=&@Q(&5X96-U=&5D"G-T:#(Z("$@86YD(#\@87,@<&%R86US
M+"!P87-S:6YG(&%S(&%R<F%Y+BXN('-T:#(@97AE8W5T960*<W1H,SH@/RP@
M(2!A;F0@)B!A<R!P87)A;7,L('!A<W-I;F<@87,@87)R87DN+BX@<W1H,R!E
M>&5C=71E9`IS=&@T.B!N;R!P87)A;7,N+BX@<W1H-"!E>&5C=71E9`IR97-U
M;'1S.@I\-S(@+2!A("T@("T@?`I\-S(@+2!D:7)E8W0@+2`@+2!\"GPW,B`M
M(&ET)W,@9V]O9"`M(&]P87%U92!P;&%C96AO;&1E<B=S('1E<W0@+2!\"GPW
M,B`M('1H870G<R!R:6=H="`M("`M('P*"BTM+2TM+2TM+2TM+3(M+2TM+2TM
M+2TM+2T*<F5S=6QT<SH*?#<R("T@<V5T,2`M(&]P87%U92!P;&%C96AO;&1E
M<B=S('1E<W0@+2`Q,C,T+34V+3<X?`I\-S(@+2!S970R("T@;W!A<75E('!L
M86-E:&]L9&5R)W,@=&5S="`M('P*?#<R("T@<V5T,R`M(&]P87%U92!P;&%C
M96AO;&1E<B=S('1E<W0@+2!\"@HM+2TM+2TM+2TM+2TS+2TM+2TM+2TM+2TM
M"E12544*1D%,4T4*"BTM+2TM+2TM+2TM+30M+2TM+2TM+2TM+2T*?#<R("T@
M<V5T,2`M(&]P87%U92!P;&%C96AO;&1E<B=S('1E<W0@+2`Q,C,T+34V+3<X
M?`I\-S(@+2!S970R("T@;W!A<75E('!L86-E:&]L9&5R)W,@=&5S="`M('P*
M?#<R("T@<V5T,R`M(&]P87%U92!P;&%C96AO;&1E<B=S('1E<W0@+2!\"GY^
M"GY^"GPW,B`M('-E=#$@+2!O<&%Q=64@<&QA8V5H;VQD97(G<R!T97-T("T@
M,3(S-"TU-BTW.'P*?GX*?#<R("T@<V5T,2`M(&]P87%U92!P;&%C96AO;&1E
M<B=S('1E<W0@+2`Q,C,T+34V+3<X?`I\-S(@+2!S970R("T@;W!A<75E('!L
M86-E:&]L9&5R)W,@=&5S="`M('P*?#<R("T@<V5T,R`M(&]P87%U92!P;&%C
M96AO;&1E<B=S('1E<W0@+2!\"GY^"@HM+2TM+2TM+2TM+2TU+2TM+2TM+2TM
M+2TM"FEN<V5R=#H@;VMA>0IA(#T@,3$L(&(@/2!T:')E92P@9"`](&=O="!E
M>'!E8W1E9"!O=71C;VUE"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O
M=&5S=',O9')I=F5R+S`X869F96-T961R;W=S+G!H<'0`````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#(W-S(`,3`U,34T,S,W-#$`,#(V-#$W`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"TM5$535"TM"D1"7V1R:79E<CHZ869F
M96-T9612;W=S"BTM24Y)+2T*97)R;W)?<F5P;W)T:6YG(#T@,C`T-PHM+5-+
M25!)1BTM"CP_<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I*3L@<F5Q=6ER
M95]O;F-E("<N+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\/W!H<`IR97%U
M:7)E7V]N8V4@)RXO;6MT86)L92YI;F,G.PH*+RHJ"B`J($QO8V%L(&5R<F]R
M(&-A;&QB86-K(&AA;F1L97(N"B`J"B`J($1R;W!S('1H92!P:'!T97-T('1A
M8FQE+"!P<FEN=',@;W5T(&%N(&5R<F]R(&UE<W-A9V4@86YD(&MI;&QS('1H
M90H@*B!P<F]C97-S+@H@*@H@*B!`<&%R86T@;V)J96-T("`D;R`@4$5!4B!E
M<G)O<B!O8FIE8W0@875T;VUA=&EC86QL>2!P87-S960@=&\@=&AI<R!M971H
M;V0*("H@0')E='5R;B!V;VED"B`J($!S964@4$5!4CHZ<V5T17)R;W)(86YD
M;&EN9R@I"B`J+PIF=6YC=&EO;B!P92@D;RD@>PH@("`@9VQO8F%L("1D8F@[
M"@H@("`@)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%52
M3BD["B`@("!D<F]P7W1A8FQE*"1D8F@L("=P:'!T97-T)RD["@H@("`@9&EE
M*"1O+3YT;U-T<FEN9R@I*3L*?0H*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA0
M14%27T524D]27T-!3$Q"04-++"`G<&4G*3L*"@HO+R!#;&5A;B!T86)L90HD
M9&)H+3YQ=65R>2@B1$5,151%($923TT@<&AP=&5S="(I.PH*+R\@069F96-T
M960@<F]W<R!B>2!)3E-%4E0@<W1A=&5M96YT"B1D8F@M/G%U97)Y*"))3E-%
M4E0@24Y43R!P:'!T97-T("AA+&(I(%9!3%5%4R@Q+"`G=&5S="<I(BD["B1D
M8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T("AA+&(I(%9!3%5%4R@R
M+"`G=&5S="<I(BD["G!R:6YT9B@B)60@869T97(@:6YS97)T7&XB+"`D9&)H
M+3YA9F9E8W1E9%)O=W,H*2D["@HO+R!!9F9E8W1E9"!R;W=S(&)Y(%-%3$5#
M5"!S=&%T96UE;G0*)&1B:"T^<75E<GDH(E-%3$5#5"`J($923TT@<&AP=&5S
M="(I.PIP<FEN=&8H(B5D(&%F=&5R('-E;&5C=%QN(BP@)&1B:"T^869F96-T
M9612;W=S*"DI.PHD9&)H+3YQ=65R>2@B1$5,151%($923TT@<&AP=&5S="!7
M2$5212!B(#T@)W1E<W0G(BD["G!R:6YT9B@B)60@869T97(@9&5L971E7&XB
M+"`D9&)H+3YA9F9E8W1E9%)O=W,H*2D["@HO+R!!9F9E8W1E9"!R;W=S(&)Y
M($1%3$5412!S=&%T96UE;G0*)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!H
M<'1E<W0@*&$L8BD@5D%,5453*#$L("=T97-T)RDB*3L*)&1B:"T^<75E<GDH
M(DE.4T525"!)3E1/('!H<'1E<W0@*&$L8BD@5D%,5453*#(L("=T97-T)RDB
M*3L*)&1B:"T^<75E<GDH(D1%3$5412!&4D]-('!H<'1E<W0B*3L*<')I;G1F
M*"(E9"!A9G1E<B!D96QE=&4@86QL7&XB+"`D9&)H+3YA9F9E8W1E9%)O=W,H
M*2D["@H*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%52
M3BD["F1R;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G*3L*"C\^"BTM15A014-4
M+2T*,2!A9G1E<B!I;G-E<G0*,"!A9G1E<B!S96QE8W0*,B!A9G1E<B!D96QE
M=&4*,B!A9G1E<B!D96QE=&4@86QL"@```````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O,#EN=6UR;W=S
M+G!H<'0````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`Q,@`Q,#4Q-30S,S<T,0`P,C4T
M-#``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+2U415-4+2T*1$)?9')I=F5R.CIN=6U2;W=S"BTM24Y)+2T*97)R;W)?<F5P
M;W)T:6YG(#T@,C`T-PHM+5-+25!)1BTM"CP_<&AP(&-H9&ER*&1I<FYA;64H
M7U]&24Q%7U\I*3L@<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G.R`_/@HM
M+49)3$4M+0H\/W!H<`IR97%U:7)E7V]N8V4@)RXO;6MT86)L92YI;F,G.PIR
M97%U:7)E7V]N8V4@)RXN+VYU;7)O=W,N:6YC)SL*/SX*+2U%6%!%0U0M+0HH
M=V%N="`Q*2!G;W0@,2!F<F]M(&9I<G-T"BAW86YT(#(I(&=O="`R(&9R;VT@
M,`HH=V%N="`S*2!G;W0@,R!F<F]M(#$**'=A;G0@-"D@9V]T(#0@9G)O;2`R
M"BAW86YT(#4I(&=O="`U(&9R;VT@,PHH=V%N="`V*2!G;W0@-B!F<F]M(#0*
M*'=A;G0@-2D@9V]T(#4@9G)O;2`^(#`@*'!A<W-I;F<@<&%R86US('1O('%U
M97)Y*0HH=V%N="`T*2!G;W0@-"!F<F]M(#P@-"`H9&]I;F<@<')E<&%R92]E
M>&5C=71E*0HH=V%N="`R*2!G;W0@,B!F<F]M(#4@86YD(#8@;F]T(&1E;&5T
M960**'=A;G0@,"D@9V]T(#`@9G)O;2`\(#`*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O,3!E
M<G)O<FUA<"YP:'!T```````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S8S,P`Q,#4Q-30S,S<T
M,0`P,C4U-C``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+2U415-4+2T*1$)?9')I=F5R.CIE<G)O<B!M87!P:6YG"BTM24Y)
M+2T*97)R;W)?<F5P;W)T:6YG(#T@,C`T-PHM+5-+25!)1BTM"CP_<&AP(&-H
M9&ER*&1I<FYA;64H7U]&24Q%7U\I*3L@<F5Q=6ER95]O;F-E("<N+W-K:7!I
M9BYI;F,G.R`_/@HM+49)3$4M+0H\/W!H<`IR97%U:7)E7V]N8V4@)RXO;6MT
M86)L92YI;F,G.PIR97%U:7)E7V]N8V4@)RXN+V5R<F]R<RYI;F,G.PH_/@HM
M+4584$5#5"TM"D1"7T524D]27TY/4U5#2%1!0DQ%(&9O<B!S96QE8W0Z("!M
M871C:&5S(&5X<&5C=&5D(&]U=&-O;64*1$)?15)23U)?3D]354-(5$%"3$4@
M9F]R(&1R;W`Z("!M871C:&5S(&5X<&5C=&5D(&]U=&-O;64*1$)?15)23U)?
M3D]47T9/54Y$(&9O<B!D<F]P(&EN9&5X.B`@;6%T8VAE<R!E>'!E8W1E9"!O
M=71C;VUE"D1"7T524D]27T%,4D5!1%E?15A)4U13(&9O<B!C<F5A=&4@=&%B
M;&4Z("!M871C:&5S(&5X<&5C=&5D(&]U=&-O;64*1$)?15)23U)?04Q214%$
M65]%6$E35%,@9F]R(&-R96%T92!I;F1E>#H@(&UA=&-H97,@97AP96-T960@
M;W5T8V]M90I$0E]%4E)/4E]#3TY35%)!24Y4(&9O<B!P<FEM87)Y(&ME>2!I
M;G-E<G0@9'5P;&EC871E.B`@;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"
M7T524D]27T-/3E-44D%)3E0@9F]R('!R:6UA<GD@:V5Y('5P9&%T92!D=7!L
M:6-A=&4Z("!M871C:&5S(&5X<&5C=&5D(&]U=&-O;64*1$)?15)23U)?0T].
M4U1204E.5"!F;W(@=6YI<75E(&ME>2!I;G-E<G0@9'5P;&EC871E.B`@;6%T
M8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"7T524D]27T-/3E-44D%)3E0@9F]R
M('5N:7%U92!K97D@=7!D871E(&1U<&QI8V%T93H@(&UA=&-H97,@97AP96-T
M960@;W5T8V]M90I$0E]%4E)/4E]#3TY35%)!24Y4(&9O<B!F;W)E:6=N(&ME
M>2!O;B!I;G-E<G0Z("!M871C:&5S(&5X<&5C=&5D(&]U=&-O;64*1$)?15)2
M3U)?0T].4U1204E.5"!F;W(@9F]R96EG;B!K97D@;VX@9&5L971E.B`@;6%T
M8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"7T524D]27T-/3E-44D%)3E1?3D]4
M7TY53$P@;VX@:6YS97)T.B`@;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"
M7T524D]27T-/3E-44D%)3E1?3D]47TY53$P@;VX@=7!D871E.B`@;6%T8VAE
M<R!E>'!E8W1E9"!O=71C;VUE"D1"7T524D]27TY/4U5#2$9)14Q$(&IO:6YI
M;F<@3TX@8F]G=7,@8V]L=6UN.B`@;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE
M"D1"7T524D]27TY/4U5#2$9)14Q$(&IO:6YI;F<@55-)3D<@8F]G=7,@8V]L
M=6UN.B`@;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"7T524D]27T1)5EI%
M4D\Z("!M871C:&5S(&5X<&5C=&5D(&]U=&-O;64*1$)?15)23U)?24Y604Q)
M1%].54U"15(@<'5T=&EN9R!C:&%R<R!I;B!)3E0@8V]L=6UN.B`@;6%T8VAE
M<R!E>'!E8W1E9"!O=71C;VUE"D1"7T524D]27TE.5D%,241?3E5-0D52('!U
M='1I;F<@9FQO870@:6X@24Y4(&-O;'5M;CH@(&UA=&-H97,@97AP96-T960@
M;W5T8V]M90I$0E]%4E)/4E])3E9!3$E$7TY534)%4B!P=71T:6YG(&5X8V5S
M<VEV92!I;G0@:6X@24Y4(&-O;'5M;CH@(&UA=&-H97,@97AP96-T960@;W5T
M8V]M90I$0E]%4E)/4E])3E9!3$E$7TY534)%4B!P=71T:6YG(&EN="!I;B!#
M2$%2(&-O;'5M;CH@(&UA=&-H97,@97AP96-T960@;W5T8V]M90I$0E]%4E)/
M4E].3U-50TA&245,1#H@(&UA=&-H97,@97AP96-T960@;W5T8V]M90I$0E]%
M4E)/4E]364Y405@Z("!M871C:&5S(&5X<&5C=&5D(&]U=&-O;64*1$)?15)2
M3U)?5D%,545?0T]53E1?3TY?4D]7.B`@;6%T8VAE<R!E>'!E8W1E9"!O=71C
M;VUE"D1"7T524D]27TE.5D%,240@;VX@0TA!4B!C;VQU;6X@9&%T82!T;V\@
M;&]N9SH@(&UA=&-H97,@97AP96-T960@;W5T8V]M90I$0E]%4E)/4E])3E9!
M3$E$(&]N(%9!4D-(05(@8V]L=6UN(&1A=&$@=&]O(&QO;F<Z("!M871C:&5S
M(&5X<&5C=&5D(&]U=&-O;64*````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+S$Q=')A;G-A
M8W1I;VYS+G!H<'0`````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$T,34`,3`U,34T,S,W-#$`,#(V
M-#,V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"TM5$535"TM"D1"7V1R:79E<CHZ=')A;G-A8W1I;VX@=&5S=`HM+4E.22TM
M"F5R<F]R7W)E<&]R=&EN9R`](#(P-#<*+2U32TE0248M+0H\/W!H<`IC:&1I
M<BAD:7)N86UE*%]?1DE,15]?*2D[(')E<75I<F5?;VYC92`G+B]S:VEP:68N
M:6YC)SL*:68@*"$D9&(M/F9E871U<F5S6R=T<F%N<V%C=&EO;G,G72D@>PH@
M("`@9&EE*"=S:VEP('1H:7,@9')I=F5R(&1O97,@;F]T('-U<'!O<G0@=')A
M;G-A8W1I;VYS)RD["GT*/SX*+2U&24Q%+2T*/#]P:'`*)&YE961I;FYO9&(@
M/2!T<G5E.PIR97%U:7)E7V]N8V4@)RXO;6MT86)L92YI;F,G.PIR97%U:7)E
M7V]N8V4@)RXN+W1R86YS86-T:6]N<RYI;F,G.PH_/@HM+4584$5#5"TM"C$I
M(&%F=&5R(&%U=&]C;VUM:70Z(&)I;F<@;VYE+B`@;W!S/6]K"C(I(&)E9F]R
M92!C;VUM:70Z(&)I;F<@;VYE('1W;R!T:')E92X@(&]P<SUO:PHS*2!A9G1E
M<B!C;VUM:70Z(&)I;F<@;VYE('1W;R!T:')E92X@(&]P<SUO:PHT*2!B969O
M<F4@<F]L;&)A8VLZ(&)I;F<@;VYE('1W;R!T:')E92!F;W5R(&9I=F4N("!O
M<',];VL*-2D@869T97(@<F]L;&)A8VLZ(&)I;F<@;VYE('1W;R!T:')E92X@
M(&]P<SUO:PHV*2!B969O<F4@875T;V-O;6UI="MR;VQL8F%C:SH@8FEN9R!O
M;F4@='=O('1H<F5E('-I>"!S979E;BX@(&]P<SUO:PHW*2!A9G1E<B!A=71O
M8V]M;6ET*W)O;&QB86-K.B!B:6YG(&]N92!T=V\@=&AR964@<VEX('-E=F5N
M+B`@;W!S/6]K"C@I('1E<W1I;F<@=&AA="!S96QE8W0@9&]E<VXG="!D:7-T
M=7)B92!O<&-O=6YT.B!O:PH`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+S$S
M;&EM:70N<&AP=```````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-C(`,3`U,34T,S,W
M-#$`,#(U,#0U`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"TM5$535"TM"D1"7V1R:79E<CHZ<F]W(&QI;6ET"BTM24Y)+2T*
M97)R;W)?<F5P;W)T:6YG(#T@,C`T-PHM+5-+25!)1BTM"CP_<&AP(&-H9&ER
M*&1I<FYA;64H7U]&24Q%7U\I*3L@<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI
M;F,G.R`_/@HM+49)3$4M+0H\/W!H<`IR97%U:7)E7V]N8V4@)RXO8V]N;F5C
M="YI;F,G.PIR97%U:7)E7V]N8V4@)RXO9')O<'1A8FQE+FEN8R<["G)E<75I
M<F5?;VYC92`G+BXO;&EM:70N:6YC)SL*/SX*+2U%6%!%0U0M+0H]/3T]/3T]
M($9R;VTZ(#`@?'P@3G5M8F5R(&]F(')O=W,@=&\@9F5T8V@Z(#$P(#T]/3T]
M/3T*,2XM(')E<W5L="`P"C(N+2!R97-U;'0@,0HS+BT@<F5S=6QT(#(*-"XM
M(')E<W5L="`S"C4N+2!R97-U;'0@-`HV+BT@<F5S=6QT(#4*-RXM(')E<W5L
M="`V"C@N+2!R97-U;'0@-PHY+BT@<F5S=6QT(#@*,3`N+2!R97-U;'0@.0H]
M/3T]/3T]($9R;VTZ(#$P('Q\($YU;6)E<B!O9B!R;W=S('1O(&9E=&-H.B`Q
M,"`]/3T]/3T]"C$Q+BT@<F5S=6QT(#$P"C$R+BT@<F5S=6QT(#$Q"C$S+BT@
M<F5S=6QT(#$R"C$T+BT@<F5S=6QT(#$S"C$U+BT@<F5S=6QT(#$T"C$V+BT@
M<F5S=6QT(#$U"C$W+BT@<F5S=6QT(#$V"C$X+BT@<F5S=6QT(#$W"C$Y+BT@
M<F5S=6QT(#$X"C(P+BT@<F5S=6QT(#$Y"CT]/3T]/3T@1G)O;3H@,C`@?'P@
M3G5M8F5R(&]F(')O=W,@=&\@9F5T8V@Z(#$P(#T]/3T]/3T*,C$N+2!R97-U
M;'0@,C`*,C(N+2!R97-U;'0@,C$*,C,N+2!R97-U;'0@,C(*,C0N+2!R97-U
M;'0@,C,*,C4N+2!R97-U;'0@,C0*,C8N+2!R97-U;'0@,C4*,C<N+2!R97-U
M;'0@,C8*,C@N+2!R97-U;'0@,C<*,CDN+2!R97-U;'0@,C@*,S`N+2!R97-U
M;'0@,CD*/3T]/3T]/2!&<F]M.B`S,"!\?"!.=6UB97(@;V8@<F]W<R!T;R!F
M971C:#H@,3`@/3T]/3T]/0HS,2XM(')E<W5L="`S,`HS,BXM(')E<W5L="`S
M,0HS,RXM(')E<W5L="`S,@H]/3T]/3T](%!A<W-I;F<@)'!A<F%M<R!\?"!&
M<F]M.B`Q,2!\?"!.=6UB97(@;V8@<F]W<R!T;R!F971C:#H@,R`]/3T]/3T]
M"C$R+BT@<F5S=6QT(#$Q"C$S+BT@<F5S=6QT(#$R"C$T+BT@<F5S=6QT(#$S
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T
M97-T<R]$0B]T97-T<R]D<FEV97(O,31F971C:&UO9&5?;V)J96-T+G!H<'0`
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,3(Q-P`Q,#4Q-30S,S<T,0`P,C<R,34`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+2U415-4+2T*1$)?9')I
M=F5R.CIF971C:&UO9&4@;V)J96-T"BTM24Y)+2T*97)R;W)?<F5P;W)T:6YG
M(#T@,C`T-PHM+5-+25!)1BTM"CP_<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%
M7U\I*3L@<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M
M+0H\/W!H<`IR97%U:7)E7V]N8V4@)RXO;6MT86)L92YI;F,G.PIR97%U:7)E
M7V]N8V4@)RXN+V9E=&-H;6]D95]O8FIE8W0N:6YC)SL*/SX*+2U%6%!%0U0M
M+0HM+2T@9F5T8V@@=VET:"!P87)A;2!$0E]&151#2$U/1$5?3T)*14-4("TM
M+0IS=&1C;&%S<R`M/B!A(&(@8R!D"G-T9&-L87-S("T^(&$@8B!C(&0*+2TM
M(&9E=&-H('=I=&@@9&5F875L="!F971C:&UO9&4@1$)?1D540TA-3T1%7T]"
M2D5#5"`M+2T*<W1D8VQA<W,@+3X@82!B(&,@9`IS=&1C;&%S<R`M/B!A(&(@
M8R!D"BTM+2!F971C:"!W:71H(&1E9F%U;'0@9F5T8VAM;V1E($1"7T9%5$-(
M34]$15]/0DI%0U0@86YD(&-L87-S($1"7W)O=R`M+2T*9&)?<F]W("T^(&$@
M8B!C(&0*9&)?<F]W("T^(&$@8B!C(&0*+2TM(&9E=&-H('=I=&@@9&5F875L
M="!F971C:&UO9&4@1$)?1D540TA-3T1%7T]"2D5#5"!W:71H(&YO(&-L87-S
M('1H96X@1$)?<F]W("TM+0IS=&1C;&%S<R`M/B!A(&(@8R!D"F1B7W)O=R`M
M/B!A(&(@8R!D"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O,35Q=6]T92YP:'!T````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`Q,S8P,0`Q,#4Q-30S,S<T,0`P,C4P-C<`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+2U415-4+2T*
M1$)?9')I=F5R.CIQ=6]T90HM+4E.22TM"F5R<F]R7W)E<&]R=&EN9R`](#(P
M-#<*+2U32TE0248M+0H\/W!H<"!C:&1I<BAD:7)N86UE*%]?1DE,15]?*2D[
M(')E<75I<F5?;VYC92`G+B]S:VEP:68N:6YC)SL@/SX*+2U&24Q%+2T*/#]P
M:'`*<F5Q=6ER95]O;F-E("<N+V-O;FYE8W0N:6YC)SL*<F5Q=6ER95]O;F-E
M("<N+V1R;W!T86)L92YI;F,G.PH*"B\J*@H@*B!,;V-A;"!E<G)O<B!C86QL
M8F%C:R!H86YD;&5R+@H@*@H@*B!$<F]P<R!T:&4@<&AP=&5S="!T86)L92P@
M<')I;G1S(&]U="!A;B!E<G)O<B!M97-S86=E(&%N9"!K:6QL<R!T:&4*("H@
M<')O8V5S<RX*("H*("H@0'!A<F%M(&]B:F5C="`@)&\@(%!%05(@97)R;W(@
M;V)J96-T(&%U=&]M871I8V%L;'D@<&%S<V5D('1O('1H:7,@;65T:&]D"B`J
M($!R971U<FX@=F]I9`H@*B!`<V5E(%!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H
M*0H@*B\*9G5N8W1I;VX@<&4H)&\I('L*("`@(&=L;V)A;"`D9&)H.PH*("`@
M("1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PH@
M("`@9')O<%]T86)L92@D9&)H+"`G<&5A<G%U;W1E)RD["@H@("`@9&EE*"1O
M+3YT;U-T<FEN9R@I*3L*?0H*+R\@1$)-4R!B;V]L96%N(&-O;'5M;B!T>7!E
M('-I;75L871I;VXN+BX*)&)O;VQE86Y?8V]L7W1Y<&4@/2!A<G)A>2@*("`@
M("=D8F%S92<@(#T^("=,;V=I8V%L)RP*("`@("=F8G-Q;"<@(#T^("="3T],
M14%.)RP*("`@("=I8F%S92<@(#T^("=334%,3$E.5"<L"B`@("`G:69X)R`@
M("`]/B`G4TU!3$Q)3E0G+`H@("`@)VUS<6PG("`@/3X@)TE.5$5'15(G+`H@
M("`@)VUS<W%L)R`@/3X@)T))5"<L"B`@("`G;7ES<6PG("`]/B`G5$E.64E.
M5"@Q*2<L"B`@("`G;7ES<6QI)R`]/B`G5$E.64E.5"@Q*2<L"B`@("`G;V-I
M."<@("`]/B`G3E5-0D52*#$I)RP*("`@("=O9&)C)R`@(#T^("=334%,3$E.
M5"<L"B`@("`G<&=S<6PG("`]/B`G0D]/3$5!3B<L"B`@("`G<W%L:71E)R`]
M/B`G24Y414=%4B<L"B`@("`G<WEB87-E)R`]/B`G5$E.64E.5"<L"BD["@HO
M+R!A9&IU<W0@=&AI;F=S(&9O<B!S<&5C:69I8R!$0DU3)W,*"FEF("@D9&)H
M+3YP:'!T>7!E(#T]("=O9&)C)RD@>PH@("`@:68@*"1D8F@M/F1B<WEN=&%X
M(#T]("=O9&)C)RD@>PH@("`@("`@("1T>7!E(#T@)&1B:"T^<&AP='EP93L*
M("`@('T@96QS92!["B`@("`@("`@)'1Y<&4@/2`D9&)H+3YD8G-Y;G1A>#L*
M("`@('T*?2!E;'-E('L*("`@("1T>7!E(#T@)&1B:"T^<&AP='EP93L*?0H*
M<W=I=&-H("@D='EP92D@>PH@("`@8V%S92`G86-C97-S)SH*("`@("`@("`D
M9&5C:6UA;"`]("=324Y'3$4G.PH@("`@("`@("1N=6QL(#T@)R<["B`@("`@
M("`@)&-H<B`@/2`G5D%20TA!4B@X*2<["B`@("`@("`@)&ED96YT:69I97(@
M/2`G<5QU="`B9&YT)SL*("`@("`@("!B<F5A:SL*("`@(&-A<V4@)V1B,B<Z
M"B`@("!C87-E("=I8F%S92<Z"B`@("`@("`@)&1E8VEM86P@/2`G1$5#24U!
M3"@S+#$I)SL*("`@("`@("`D;G5L;"`]("<G.PH@("`@("`@("1C:'(@(#T@
M)U9!4D-(05(H."DG.PH@("`@("`@("1I9&5N=&EF:65R(#T@)W%<=71=(")D
M;EMT)SL*("`@("`@("!B<F5A:SL*("`@(&-A<V4@)VEF>"<Z"B`@("`@("`@
M+R\@9&]I;F<@=&AI<R!F;W(@:69X('1O(&ME97`@8V5R=&%I;B!V97)S:6]N
M<R!H87!P>0H@("`@("`@("1D96-I;6%L(#T@)T1%0TE-04PH,RPQ*2<["B`@
M("`@("`@)&YU;&P@/2`G)SL*("`@("`@("`D8VAR("`]("=#2$%2*#@I)SL*
M("`@("`@("`D:61E;G1I9FEE<B`]("<G.PH@("`@("`@(&)R96%K.PH@("`@
M8V%S92`G;7-Q;"<Z"B`@("`@("`@)&1E8VEM86P@/2`G4D5!3"<["B`@("`@
M("`@)&YU;&P@/2`G)SL*("`@("`@("`D8VAR("`]("=#2$%2*#@I)SL*("`@
M("`@("`D:61E;G1I9FEE<B`]("<G.PH@("`@("`@(&)R96%K.PH@("`@8V%S
M92`G9F)S<6PG.@H@("`@8V%S92`G;V-I."<Z"B`@("`@("`@)&1E8VEM86P@
M/2`G1$5#24U!3"@S+#$I)SL*("`@("`@("`D;G5L;"`]("<G.PH@("`@("`@
M("1C:'(@(#T@)U9!4D-(05(H."DG.PH@("`@("`@("1I9&5N=&EF:65R(#T@
M)W%<=71=(&1N6W0G.PH@("`@("`@(&)R96%K.PH@("`@9&5F875L=#H*("`@
M("`@("`D9&5C:6UA;"`]("=$14-)34%,*#,L,2DG.PH@("`@("`@("1N=6QL
M(#T@)TY53$PG.PH@("`@("`@("1C:'(@(#T@)U9!4D-(05(H."DG.PH@("`@
M("`@("1I9&5N=&EF:65R(#T@)W%<=71=(")D;EMT)SL*?0H*)&1B:"T^<V5T
M17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["F1R;W!?=&%B;&4H
M)&1B:"P@)W!E87)Q=6]T92<I.PH*"FEF("@D:61E;G1I9FEE<BD@>PH@("`@
M<W=I=&-H("@D9&)H+3YP:'!T>7!E*2!["B`@("`@("`@8V%S92`G<WEB87-E
M)SH*("`@("`@("`@("`@)')E<R`]("1D8F@M/G%U97)Y*"=S970@<75O=&5D
M7VED96YT:69I97(@;VXG*3L*("`@("`@("`@("`@:68@*$1".CII<T5R<F]R
M*"1R97,I("D@>PH@("`@("`@("`@("`@("`@<&4H)')E<RD["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@9&5F875L=#H*("`@
M('T*("`@("1C<F5A=&4@/2`D9&)H+3YQ=65R>2@B"B`@("`@("`@0U)%051%
M(%1!0DQ%('!E87)Q=6]T92`H"B`@("`@("`@("!N("1D96-I;6%L("1N=6QL
M+`H@("`@("`@("`@<R`D8VAR("1N=6QL+`H@("`@("`@("`@(B`N("1D8F@M
M/G%U;W1E261E;G1I9FEE<B@D:61E;G1I9FEE<BD@+B`B("1D96-I;6%L("1N
M=6QL+`H@("`@("`@("`@8B![)&)O;VQE86Y?8V]L7W1Y<&5;)&1B:"T^<&AP
M='EP95U]("1N=6QL"B`@("`@("`@*0H@("`@(BD["@H@("`@:68@*$1".CII
M<T5R<F]R*"1C<F5A=&4I("D@>PH@("`@("`@('!E*"1C<F5A=&4I.PH@("`@
M?0H*("`@("1I;F9O(#T@)&1B:"T^=&%B;&5);F9O*"=P96%R<75O=&4G*3L*
M("`@(&EF("A$0CHZ:7-%<G)O<B@D:6YF;RD@*2!["B`@("`@("`@:68@*"1I
M;F9O+3YC;V1E(#T]($1"7T524D]27TY/5%]#05!!0DQ%*2!["B`@("`@("`@
M("`@('!R:6YT(")';W0@;W5T8V]M92!E>'!E8W1E9"!F<F]M(&1E;&EM:71E
M9"!I9&5N=&EF:65R+EQN(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!P<FEN="`B=&%B;&5);F9O*"D@9F%I;&5D+EQN(CL*("`@("`@("!]"B`@
M("!](&5L<V4@>PH@("`@("`@(&EF("@D:61E;G1I9FEE<B`]/2`D:6YF;ULR
M75LG;F%M92==*2!["B`@("`@("`@("`@('!R:6YT(")';W0@;W5T8V]M92!E
M>'!E8W1E9"!F<F]M(&1E;&EM:71E9"!I9&5N=&EF:65R+EQN(CL*("`@("`@
M("`@("`@+R\@<')I;G0@(D-/3%5-3B!.04U%($E3.B![)&EN9F];,EU;)VYA
M;64G77U<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<')I;G0@
M(D5X<&5C=&5D(&-O;'5M;B!N86UE.B`G)&ED96YT:69I97(G("XN+B`B.PH@
M("`@("`@("`@("!P<FEN="`B06-T=6%L(&-O;'5M;B!N86UE.B`G>R1I;F9O
M6S)=6R=N86UE)UU])UQN(CL*("`@("`@("!]"B`@("!]"@I](&5L<V4@>PH@
M("`@)&1B:"T^<75E<GDH(@H@("`@("`@($-214%412!404),12!P96%R<75O
M=&4@*`H@("`@("`@("`@;B`D9&5C:6UA;"`D;G5L;"P*("`@("`@("`@(',@
M)&-H<B`D;G5L;"P*("`@("`@("`@('!L86EN:61E;G1I9FEE<B`D9&5C:6UA
M;"`D;G5L;"P*("`@("`@("`@(&(@>R1B;V]L96%N7V-O;%]T>7!E6R1D8F@M
M/G!H<'1Y<&5=?2`D;G5L;`H@("`@("`@("D*("`@("(I.PH@("`@<')I;G0@
M(D=O="!O=71C;VUE(&5X<&5C=&5D(&9R;VT@9&5L:6UI=&5D(&ED96YT:69I
M97(N7&XB.PI]"@H*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]2
M7T-!3$Q"04-++"`G<&4G*3L*"@HD<W1R:6YG<R`](&%R<F%Y*`H@("`@(B<B
M+`H@("`@(EPB(BP*("`@(")<7"(L"B`@("`B)2(L"B`@("`B7R(L"B`@("`B
M)R<B+`H@("`@(EPB7"(B+`H@("`@(EQ<7%PB+`H@("`@(EQ<)UQ<)R(L"B`@
M("`B7%Q<(EQ<7"(B"BD["@HD;G5M<R`](&%R<F%Y*`H@("`@,3(N,RP*("`@
M(#$U+`HI.PH*)&)O;VQS(#T@87)R87DH"B`@("!44E5%+`H@("`@1D%,4T4L
M"BD["@H*96-H;R`B4W1R:6YG(&5S8V%P92!T97-T.B`B.PIF;W)E86-H("@D
M<W1R:6YG<R!A<R`D<RD@>PH@("`@)'%U;W1E9"`]("1D8F@M/G%U;W1E4VUA
M<G0H)',I.PH@("`@)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!E87)Q=6]T
M92`H<RD@5D%,5453("@D<75O=&5D*2(I.PI]"B1D:69F(#T@87)R87E?9&EF
M9B@D<W1R:6YG<RP@)')E<R`]("1D8F@M/F=E=$-O;"@B4T5,14-4(',@1E)/
M32!P96%R<75O=&4B*2D["FEF("AC;W5N="@D9&EF9BD@/B`P*2!["B`@("!E
M8VAO(")&04E,(CL*("`@('!R:6YT7W(H)'-T<FEN9W,I.PH@("`@<')I;G1?
M<B@D<F5S*3L*?2!E;'-E('L*("`@(&5C:&\@(D]+(CL*?0H*)&1B:"T^<75E
M<GDH(D1%3$5412!&4D]-('!E87)Q=6]T92(I.PH*"F5C:&\@(EQN3G5M8F5R
M(&5S8V%P92!T97-T.B`B.PIF;W)E86-H("@D;G5M<R!A<R`D;BD@>PH@("`@
M)'%U;W1E9"`]("1D8F@M/G%U;W1E4VUA<G0H)&XI.PH@("`@)&1B:"T^<75E
M<GDH(DE.4T525"!)3E1/('!E87)Q=6]T92`H;BD@5D%,5453("@D<75O=&5D
M*2(I.PI]"@HD9&EF9B`](&%R<F%Y*"D["B1R97,@/28@)&1B:"T^9V5T0V]L
M*"=314Q%0U0@;B!&4D]-('!E87)Q=6]T92!/4D1%4B!"62!N)RD["F9O<F5A
M8V@@*"1N=6US(&%S("1K97D@/3X@)'9A;"D@>PH@("`@:68@*"1V86P@(3T@
M)')E<ULD:V5Y72D@>PH@("`@("`@("1D:69F6UT@/2`B)'9A;"`A/2![)')E
M<ULD:V5Y77TB.PH@("`@?0I]"@II9B`H8V]U;G0H)&1I9F8I(#X@,"D@>PH@
M("`@96-H;R`B1D%)3%QN(CL*("`@('!R:6YT7W(H)&1I9F8I.PI](&5L<V4@
M>PH@("`@96-H;R`G3TLG.PI]"@HD9&)H+3YQ=65R>2@G1$5,151%($923TT@
M<&5A<G%U;W1E)RD["@H*96-H;R`B7&Y";V]L96%N(&5S8V%P92!T97-T.B`B
M.PHD:2`](#$["F9O<F5A8V@@*"1B;V]L<R!A<R`D8BD@>PH@("`@)'%U;W1E
M9"`]("1D8F@M/G%U;W1E4VUA<G0H)&(I.PH@("`@)&1B:"T^<75E<GDH(DE.
M4T525"!)3E1/('!E87)Q=6]T92`H;BP@8BD@5D%,5453("@D:2P@)'%U;W1E
M9"DB*3L*("`@("1I*RL["GT*"B1D:69F(#T@87)R87DH*3L*)')E<R`])B`D
M9&)H+3YG971#;VPH)U-%3$5#5"!B+"!N($923TT@<&5A<G%U;W1E($]21$52
M($)9(&XG*3L*9F]R96%C:"`H)&)O;VQS(&%S("1K97D@/3X@)'9A;"D@>PH@
M("`@:68@*"1V86P@/3T]('1R=64I('L*("`@("`@("!I9B`H)')E<ULD:V5Y
M72`]/2`Q('Q\("1R97-;)&ME>5T@/3T@=')U92!\?`H@("`@("`@("`@("!S
M=6)S='(H<W1R=&]L;W=E<B@D<F5S6R1K97E=*2P@,"P@,2D@/3T@)W0G*0H@
M("`@("`@('L*("`@("`@("`@("`@+R\@9V]O9`H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1D:69F6UT@/2`B:6XZ=')U92`A/2!O=70Z>R1R97-;
M)&ME>5U](CL*("`@("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@(&EF("@D
M<F5S6R1K97E=(#T](#`@?'P@)')E<ULD:V5Y72`]/2!F86QS92!\?`H@("`@
M("`@("`@("!S=6)S='(H<W1R=&]L;W=E<B@D<F5S6R1K97E=*2P@,"P@,2D@
M/3T@)V8G*0H@("`@("`@('L*("`@("`@("`@("`@+R\@9V]O9`H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1D:69F6UT@/2`B:6XZ9F%L<V4@(3T@
M;W5T.GLD<F5S6R1K97E=?2(["B`@("`@("`@?0H@("`@?0I]"@II9B`H8V]U
M;G0H)&1I9F8I(#X@,"D@>PH@("`@96-H;R`B1D%)3%QN(CL*("`@('!R:6YT
M7W(H)&1I9F8I.PI](&5L<V4@>PH@("`@96-H;R`B3TM<;B(["GT*"@HD9&)H
M+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*9')O<%]T
M86)L92@D9&)H+"`G<&5A<G%U;W1E)RD["@H_/@HM+4584$5#5"TM"D=O="!O
M=71C;VUE(&5X<&5C=&5D(&9R;VT@9&5L:6UI=&5D(&ED96YT:69I97(N"E-T
M<FEN9R!E<V-A<&4@=&5S=#H@3TL*3G5M8F5R(&5S8V%P92!T97-T.B!/2PI"
M;V]L96%N(&5S8V%P92!T97-T.B!/2PH`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\Q-G1A8FQE:6YF;RYP:'!T````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,3`V-C(S`#$P-3$U-#,S-S0Q`#`R-3<P-0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````M+51%4U0M+0I$0E]D
M<FEV97(Z.G1A8FQE26YF;PHM+4E.22TM"F5R<F]R7W)E<&]R=&EN9R`](#(P
M-#<*+2U32TE0248M+0H\/W!H<`H*+RHJ"B`J($-A;&QS('1A8FQE26YF;R@I
M(&EN('9A<FEO=7,@=V%Y<R!A;F0@8VAE8VMS('1O('-E92!T:&%T('1H92!O
M=71P=70*("H@;6%T8VAE<R!W:&%T)W,@97AP96-T960N"B`J"B`J(%1H97-E
M('1E<W1S(&%C8V]U;G0@9F]R(&5A8V@@1$)-4R!U<VEN9R!D:69F97)E;G0@
M8V]L=6UN('1Y<&5S(&%N9`H@*B!R97!O<G1I;F<@8F%C:R!D:69F97)E;G0@
M:6YF;W)M871I;VXN("!4:&5S92!D:69F97)E;F-E<R!A<F4@86-C;W5N=&5D
M"B`J(&9O<B!I;B!T:&4@/'9A<CXD<75I<FMS/"]V87(^(&%R<F%Y+"!W:&EC
M:"!H87,@=&AE(&9O;&QO=VEN9R!F;W)M870Z"B`J"B`J(#QP<F4^"B`J("=D
M<FEV97(G(#T^(&%R<F%Y*`H@*B`@("`@)V-L;V(G(#T^($1"35,G<R!C;VQU
M;6X@='EP92!F;W(@8W)E871I;F<@0TQ/0B!F:65L9',*("H@("`@("=D871E
M)R`]/B!$0DU3)W,@8V]L=6UN('1Y<&4@9F]R(&-R96%T:6YG($1!5$4@9FEE
M;&1S"B`J("`@("`G9&%T96QI=&5R86PG(#T^(%1H92!344P@:V5Y=V]R9"!N
M96-E<W-A<GD@9F]R(&1E9FEN:6YG(&1A=&5S"B`J("`@("`G9FEN9'-?=&%B
M;&4G(#T^($-A;B!T:&ES($1"35,@9&5T97)M:6YE('1A8FQE(&YA;65S(&9R
M;VT@<75E<FEE<S\*("H@("`@("=S:7IE7V9R;VU?=&%B;&4G(#T^($1O97,@
M=&AI<R!$0DU3(&MN;W<@=&AE(&-O;'5M;B!S:7IE('9I82!T86)L92!N86UE
M/PH@*B`@("`@)VAA;F1L97-?<F5S=6QT<R<@/3X@0V%N('1H92!$0DU3(&=E
M="!I;F9O(&9R;VT@<75E<GD@<F5S=6QT<S\*("H@("`@("=C;VUM86YD<R<@
M/3X@87)R87DH"B`J("`@("`@("`@17AT<F$@8V]M;6%N9',@=&\@8F4@<&%S
M<V5D('1O(%!(4"=S(&5V86PH*2!F=6YC=&EO;@H@*B`@("`@*0H@*B`@("`@
M,"`]/B!A<G)A>2@*("H@("`@("`@("`O+R`@26YF;R!E>'!E8W1E9"!T;R!B
M92!R97!O<G1E9"!F;W(@<&AP=&5S=%]F:RYA"B`J("`@("`@("`@+R\@("A)
M3E1%1T52($Y/5"!.54Q,*2`H54Y)455%($M%62!W:71H(&0I"B`J("`@("`@
M("`@)W1Y<&4G(#T^($-O;'5M;B!T>7!E(')E<&]R=&5D(&)Y('1H92!$0DU3
M"B`J("`@("`@("`@)VQE;B<@/3X@0V]L=6UN('-I>F4@<F5P;W)T960@8GD@
M=&AE($1"35,*("H@("`@("`@("`G9FQA9W,G(#T^($9L86=S(')E<&]R=&5D
M(&)Y('1H92!$0DU3"B`J("`@("`I"B`J("`@("`Q(#T^(&%R<F%Y*"D@($EN
M9F\@97AP96-T960@=&\@8F4@<F5P;W)T960@9F]R('!H<'1E<W1?9FLN9FL*
M("H@("`@("`@("`@("`@("`@("`@*$E.5$5'15(@3D]4($Y53$PI("A04DE-
M05)9($M%62D*("H@("`@(#(@/3X@87)R87DH*2`@26YF;R!E>'!E8W1E9"!T
M;R!B92!R97!O<G1E9"!F;W(@<&AP=&5S=%]F:RYC"B`J("`@("`@("`@("`@
M("`@("`@("A#3$]"+T-(05(O5D%20TA!4B!.54Q,*0H@*B`@("`@,R`]/B!A
M<G)A>2@I("!);F9O(&5X<&5C=&5D('1O(&)E(')E<&]R=&5D(&9O<B!P:'!T
M97-T7V9K+F0*("H@("`@("`@("`@("`@("`@("`@*$1!5$4@3D]4($Y53$PI
M("A53DE1544@2T59('=I=&@@82D*("H@("`@(#0@/3X@87)R87DH*2`@26YF
M;R!E>'!E8W1E9"!T;R!B92!R97!O<G1E9"!F;W(@<&AP=&5S=%]F:RYE"B`J
M("`@("`@("`@("`@("`@("`@("A#2$%2*#(I($1%1D%53%0@)R!E)R!.3U0@
M3E5,3"D*("H@("`@(#4@/3X@87)R87DH*2`@26YF;R!E>'!E8W1E9"!T;R!B
M92!R97!O<G1E9"!F;W(@<&AP=&5S=%]F:RYF"B`J("`@("`@("`@("`@("`@
M("`@("A$14-)34%,*#(L,2D@3E5,3"D*("H@("`@(#D@/3X@87)R87DH*2`@
M26YF;R!E>'!E8W1E9"!T;R!B92!R97!O<G1E9"!F;W(@<&AP=&5S="YD"B`J
M("`@("`@("`@("`@("`@("`@("A605)#2$%2*#(P*2!.54Q,*0H@*B`I"B`J
M(#PO<')E/@H@*@H@*B!`8V%T96=O<GD@1&%T86)A<V4*("H@0'!A8VMA9V4@
M($1""B`J($!V97)S:6]N("`D260Z(#$V=&%B;&5I;F9O+G!H<'0L=B`Q+C,R
M(#(P,#4O,#(O,30@,3<Z,#0Z,3<@9&%N:65L8R!%>'`@)`H@*B!`875T:&]R
M("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!A;F%L>7-I<V%N9'-O;'5T
M:6]N<RYC;VT^"B`J($!S964@("`@("!$0E]C;VUM;VXZ.G1A8FQE26YF;R@I
M"B`J+PH*97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*8VAD:7(H9&ER;F%M92A?
M7T9)3$5?7RDI.PIR97%U:7)E7V]N8V4@)RXO<VMI<&EF+FEN8R<["B1T86)L
M94EN9F\@/2`D9&(M/G1A8FQE26YF;R@G86IK9'-L9F%J;VEJ:V%D:64G*3L*
M:68@*$1".CII<T5R<F]R*"1T86)L94EN9F\I("8F("1T86)L94EN9F\M/F-O
M9&4@/3T@1$)?15)23U)?3D]47T-!4$%"3$4I('L*("`@(&1I92@B<VMI<"`D
M=&%B;&5);F9O+3YM97-S86=E(BD["GT*"C\^"BTM1DE,12TM"CP_<&AP"@HO
M+R`@)$ED.B`Q-G1A8FQE:6YF;RYP:'!T+'8@,2XS,B`R,#`U+S`R+S$T(#$W
M.C`T.C$W(&1A;FEE;&,@17AP("0*"B\J*@H@*B!#;VYN96-T('1O('1H92!D
M871A8F%S92!A;F0@;6%K92!T:&4@<&AP=&5S="!T86)L92X*("HO"G)E<75I
M<F5?;VYC92`G+B]M:W1A8FQE+FEN8R<["@HO*BH*("H@3&]C86P@97)R;W(@
M8V%L;&)A8VL@:&%N9&QE<BX*("H*("H@26X@9V5N97)A;"P@:70@<')I;G1S
M(&]U="!A;B!E<G)O<B!M97-S86=E(&%N9"!K:6QL<R!T:&4@<')O8V5S<RX*
M("H@0G5T('-O;64@97)R;W)S(&%R92!E>'!E8W1E9"!A;F0@86QL;W=E9"!T
M;R!E>&ES="X*("H*("H@0'!A<F%M(&]B:F5C="`@)&\@(%!%05(@97)R;W(@
M;V)J96-T(&%U=&]M871I8V%L;'D@<&%S<V5D('1O('1H:7,@;65T:&]D"B`J
M($!R971U<FX@=F]I9`H@*B!`<V5E(%!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H
M*0H@*B\*9G5N8W1I;VX@<&4H)&\I>PH@("`@9VQO8F%L("1D8F@L("1Q=6ER
M:W,["@H@("`@:68@*"1O+3YG971-97-S86=E*"D@/3T@(D1"($5R<F]R.B!C
M86XG="!D:7-T:6YG=6ES:"!D=7!L:6-A=&4@9FEE;&0@;F%M97,B*2!["B`@
M("`@("`@<')I;G0@(DY/5$E#13H@)&1B:"T^<&AP='EP92!C86XG="!D:7-T
M:6YG=6ES:"!D=7!L:6-A=&4@9FEE;&0@;F%M97,B.PH@("`@("`@(')E='5R
M;CL*("`@('T*"B`@("!I9B`H)&\M/F=E=$-O9&4H*2`]/2!$0E]%4E)/4E].
M3U1?0T%004),12`F)@H@("`@("`@("$D<75I<FMS6R1D8F@M/G!H<'1Y<&4@
M+B`G.B<@+B`D9&)H+3YD8G-Y;G1A>%U;)VAA;F1L97-?<F5S=6QT<R==*0H@
M("`@>PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("`D9&)H+3YS971%<G)O
M<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*("`@(&1R;W!?=&%B;&4H
M)&1B:"P@)W!H<'1E<W0G*3L*("`@(&1R;W!?=&%B;&4H)&1B:"P@)W!H<'1E
M<W1?9FLG*3L*"B`@("!D:64H)&\M/G1O4W1R:6YG*"DI.PI]"@HO*BH*("H@
M3&]O<"!T:')O=6=H(&%N(&%R<F%Y(')E='5R;F5D(&9R;VT@=&%B;&5);F9O
M*"DL(&-O;7!A<F4@=&AE(&%C='5A;`H@*B!C;VYT96YT<R!T;R!T:&4@97AP
M96-T960@8V]N=&5N=',N("!)9B!T:&4@86-T=6%L(')E<W5L=',@;6%T8V@@
M=&AE"B`J(&5X<&5C=&%T:6]N<RP@<V%Y('-O+B`@268@;F]T+"!S87D@<V\@
M86YD('-H;W<@=&AE(&EN9F]R;6%T:6]N+@H@*@H@*B!`<&%R86T@87)R87D@
M("`D87)R87D@("`@('1H92!A<G)A>2!T;R!B92!E>&%M:6YE9`H@*B!`<&%R
M86T@<W1R:6YG("`D97AP96-T960@('1H92!E>'!E8W1E9"!C;VYT96YT<R!O
M9B!T:&4@87)R87D*("H@0'!A<F%M('-T<FEN9R`@)&9I96QD("`@("!F:65L
M9"!I;F1E>"!N=6UB97(@;V8@)'%U<FEK<R!A;F0@=&%B;&4*("H@0'!A<F%M
M(&)O;VQE86X@)'%U97)Y("`@("!T<G5E(&EF(&%R<F%Y(&ES(&9R;VT@82!Q
M=65R>2!O<B!F86QS92!I9B!A<G)A>0H@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&ES('1A8FQE26YF;R@I"B`J($!R971U<FX@=F]I9`H@*B\*9G5N
M8W1I;VX@97AA;6EN94%R<F%Y1&%T82@D87)R87DL("1E>'!E8W1E9"P@)&9I
M96QD(#T@9F%L<V4L("1Q=65R>2`]('1R=64I('L*("`@(&=L;V)A;"`D9&)H
M+"`D<75I<FMS.PH*("`@("1Q=6ER:U]K97D@/2`D9&)H+3YP:'!T>7!E("X@
M)SHG("X@)&1B:"T^9&)S>6YT87@["@H@("`@:68@*$1".CII<T5R<F]R*"1A
M<G)A>2D@)B8@)&%R<F%Y+3YG971#;V1E*"D@/3T@1$)?15)23U)?3D]47T-!
M4$%"3$4I('L*("`@("`@("!P<FEN="`B;6%T8VAE9"!E>'!E8W1E9"!R97-U
M;'1<;B(["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&EF("@A:7-?87)R
M87DH)&%R<F%Y*2D@>PH@("`@("`@('!R:6YT(")4:&ES($1-0E,@9&ED;B=T
M('!R;V1U8V4@<')O<&5R(')E<W5L='-<;B(["B`@("`@("`@<F5T=7)N.PH@
M("`@?0H*("`@(&EF("AI<U]I;G0H)&9I96QD*2D@>PH@("`@("`@("1A<G)A
M>2`]("1A<G)A>5LD9FEE;&1=.PH@("`@?0H*("`@("1A8W1U86P@/2`G)SL*
M("`@(&9O<F5A8V@@*"1A<G)A>2!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@
M("`@(&EF("@D9FEE;&0@(3T](&9A;'-E("8F"B`@("`@("`@("`@(&ES<V5T
M*"1Q=6ER:W-;)'%U:7)K7VME>5U;)&9I96QD75LD:V5Y72DI"B`@("`@("`@
M>PH@("`@("`@("`@("!I9B`H)&ME>2`]/2`G9FQA9W,G("8F("1V86QU92`]
M/2`G)R`F)B`D<75E<GD@)B8*("`@("`@("`@("`@("`@("$D<75I<FMS6R1Q
M=6ER:U]K97E=6R=F:6YD<U]T86)L92==*0H@("`@("`@("`@("!["B`@("`@
M("`@("`@("`@("`D86-T=6%L("X]("(D:V5Y("XN+B!M871C:&5D(&5X<&5C
M=&5D('9A;'5E7&XB.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@:68@*"1Q=6ER:W-;)'%U:7)K7VME>5U;)&9I96QD75LD:V5Y72`]
M/2`D=F%L=64I('L*("`@("`@("`@("`@("`@("`@("`D86-T=6%L("X]("(D
M:V5Y("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E7&XB.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H)'9A;'5E
M(#T](#`*("`@("`@("`@("`@("`@("`@("`@("`@)B8@(21Q=6ER:W-;)'%U
M:7)K7VME>5U;)W-I>F5?9G)O;5]T86)L92==*0H@("`@("`@("`@("`@("`@
M("`@('L*("`@("`@("`@("`@("`@("`@("`@("`@)&%C='5A;"`N/2`B)&ME
M>2`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU95QN(CL*("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D86-T
M=6%L("X]("(D:V5Y("XN+B!W87,@)R1V86QU92<@8G5T('=E(&5X<&5C=&5D
M("(["B`@("`@("`@("`@("`@("`@("`@("`@("1A8W1U86P@+CT@(B=[)'%U
M:7)K<ULD<75I<FM?:V5Y75LD9FEE;&1=6R1K97E=?2=<;B(["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"1K97D@/3T@)W1A
M8FQE)RD@>PH@("`@("`@("`@("`@("`@:68@*"1F:65L9"`\/2`U*2!["B`@
M("`@("`@("`@("`@("`@("`@:68@*"1V86QU92`]/2`G<&AP=&5S=%]F:R<I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&%C='5A;"`N/2`B)&ME>2`N
M+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU95QN(CL*("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'9A
M;'5E(#T]("<G("8F("1Q=65R>2`F)@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(21Q=6ER:W-;)'%U:7)K7VME>5U;)V9I;F1S7W1A8FQE)UTI"B`@
M("`@("`@("`@("`@("`@("`@("`@('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1A8W1U86P@+CT@(B1K97D@+BXN(&UA=&-H960@97AP96-T960@
M=F%L=65<;B(["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D86-T=6%L("X]("(D:V5Y("XN
M+B!W87,@)R1V86QU92<@8G5T('=E(&5X<&5C=&5D("=P:'!T97-T7V9K)UQN
M(CL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@:68@*"1V86QU92`]/2`G<&AP=&5S="<I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&%C='5A;"`N/2`B)&ME>2`N+BX@;6%T8VAE9"!E>'!E
M8W1E9"!V86QU95QN(CL*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'9A;'5E(#T]("<G("8F("1Q
M=65R>2`F)@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(21Q=6ER:W-;
M)'%U:7)K7VME>5U;)V9I;F1S7W1A8FQE)UTI"B`@("`@("`@("`@("`@("`@
M("`@("`@('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A8W1U86P@
M+CT@(B1K97D@+BXN(&UA=&-H960@97AP96-T960@=F%L=65<;B(["B`@("`@
M("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D86-T=6%L("X]("(D:V5Y("XN+B!W87,@)R1V86QU92<@
M8G5T('=E(&5X<&5C=&5D("=P:'!T97-T7V9K)UQN(CL*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1A8W1U86P@+CT@(B1K97D@/3X@)'9A;'5E7&XB.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@?0H@("`@:68@*"1A8W1U86P@/3T@)&5X<&5C=&5D
M*2!["B`@("`@("`@<')I;G0@(FUA=&-H960@97AP96-T960@<F5S=6QT7&XB
M.PH@("`@?2!E;'-E('L*("`@("`@("!P<FEN="`B1$E$3B=4(&UA=&-H(&5X
M<&5C=&5D('9A;'5E<RXN+EQN(CL*("`@("`@("!P<FEN="`B?GY^?GY^?GY<
M;D5X<&5C=&5D.EQN)&5X<&5C=&5D7&XB.PH@("`@("`@('!R:6YT(")^?GY^
M7&Y!8W1U86PZ7&XD86-T=6%L7&Y^?GY^?GY^?EQN7&XB.PH@("`@?0I]"@HO
M*BH*("H@3&]O<"!T:')O=6=H(&%N(&%R<F%Y(&]F('1A8FQE(&EN9F\@9&%T
M82!A;F0@<F5T=7)N('1H92!R97-U;'1S+@H@*@H@*B!`<&%R86T@87)R87D@
M("1A<G)A>2`@=&AE(&%R<F%Y('1O(&)E(&5X86UI;F5D"B`J($!R971U<FX@
M<W1R:6YG"B`J+PIF=6YC=&EO;B!R971U<FY!<G)A>41A=&$H)&%R<F%Y*2![
M"B`@("!G;&]B86P@)&1B:"P@)'%U:7)K<SL*"B`@("`D<75I<FM?:V5Y(#T@
M)&1B:"T^<&AP='EP92`N("<Z)R`N("1D8F@M/F1B<WEN=&%X.PH*("`@(&EF
M("@A)'%U:7)K<ULD<75I<FM?:V5Y75LG:&%N9&QE<U]R97-U;'1S)UTI('L*
M("`@("`@("!R971U<FX@(EQN(CL*("`@('T*"B`@("`D;W5T(#T@)R<["B`@
M("!F;W)E86-H("@D87)R87D@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@
M("`D;W5T("X]("(D:V5Y(#T^("1V86QU95QN(CL*("`@('T*("`@(')E='5R
M;B`D;W5T.PI]"@H*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]2
M7T-!3$Q"04-++"`G<&4G*3L*"@HD<75I<FMS(#T@87)R87DH"B`@("`G9F)S
M<6PZ9F)S<6PG(#T^(&%R<F%Y*`H@("`@("`@("=C;&]B)R`]/B`G0TA!4B@R
M.2DG+`H@("`@("`@("=D871E)R`]/B`G1$%412<L"B`@("`@("`@)V1A=&5L
M:71E<F%L)R`]/B`G($1!5$4@)RP*("`@("`@("`G9FEN9'-?=&%B;&4G(#T^
M(&9A;'-E+`H@("`@("`@("=S:7IE7V9R;VU?=&%B;&4G(#T^(&9A;'-E+`H@
M("`@("`@("=H86YD;&5S7W)E<W5L=',G(#T^('1R=64L"B`@("`@("`@)V-O
M;6UA;F1S)R`]/B!A<G)A>2@*("`@("`@("`I+`H@("`@("`@(#`@/3X@87)R
M87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G24Y414=%4B<L"B`@("`@("`@
M("`@("=L96XG(#T^(#`L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@
M("`@("`@*2P*("`@("`@("`Q(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP
M92<@/3X@)TE.5$5'15(G+`H@("`@("`@("`@("`G;&5N)R`]/B`P+`H@("`@
M("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"<L"B`@("`@("`@*2P*("`@
M("`@("`R(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)T-(05)!
M0U1%4B<L"B`@("`@("`@("`@("=L96XG(#T^(#(Y+`H@("`@("`@("`@("`G
M9FQA9W,G(#T^("<G+`H@("`@("`@("DL"B`@("`@("`@,R`]/B!A<G)A>2@*
M("`@("`@("`@("`@)W1Y<&4G(#T^("=$051%)RP*("`@("`@("`@("`@)VQE
M;B<@/3X@,"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I
M+`H@("`@("`@(#0@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G
M0TA!4D%#5$52)RP*("`@("`@("`@("`@)VQE;B<@/3X@,BP*("`@("`@("`@
M("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@("`@(#4@/3X@87)R
M87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G1$5#24U!3"<L"B`@("`@("`@
M("`@("=L96XG(#T^(#`L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@
M("`@("`@*2P*("`@("`@("`Y(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP
M92<@/3X@)T-(05)!0U1%4B<L"B`@("`@("`@("`@("=L96XG(#T^(#(P+`H@
M("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@("DL"B`@("`I+`H*
M("`@("=I8F%S93II8F%S92<@/3X@87)R87DH"B`@("`@("`@)V-L;V(G(#T^
M("=605)#2$%2*#4P*2<L"B`@("`@("`@)V1A=&4G(#T^("=$051%)RP*("`@
M("`@("`G9&%T96QI=&5R86PG(#T^("<G+`H@("`@("`@("=F:6YD<U]T86)L
M92<@/3X@9F%L<V4L"B`@("`@("`@)W-I>F5?9G)O;5]T86)L92<@/3X@9F%L
M<V4L"B`@("`@("`@)VAA;F1L97-?<F5S=6QT<R<@/3X@=')U92P*("`@("`@
M("`G8V]M;6%N9',G(#T^(&%R<F%Y*`H@("`@("`@("DL"B`@("`@("`@,"`]
M/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=)3E1%1T52)RP*("`@
M("`@("`@("`@)VQE;B<@/3X@-"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G
M=6YI<75E7VME>2!N;W1?;G5L;"<L"B`@("`@("`@*2P*("`@("`@("`Q(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)TE.5$5'15(G+`H@("`@
M("`@("`@("`G;&5N)R`]/B`T+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=P
M<FEM87)Y7VME>2!N;W1?;G5L;"<L"B`@("`@("`@*2P*("`@("`@("`R(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)U9!4D-(05(G+`H@("`@
M("`@("`@("`G;&5N)R`]/B`U,"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G
M)RP*("`@("`@("`I+`H@("`@("`@(#,@/3X@87)R87DH"B`@("`@("`@("`@
M("=T>7!E)R`]/B`G1$%412<L"B`@("`@("`@("`@("=L96XG(#T^(#0L"B`@
M("`@("`@("`@("=F;&%G<R<@/3X@)W5N:7%U95]K97D@;F]T7VYU;&PG+`H@
M("`@("`@("DL"B`@("`@("`@-"`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y
M<&4G(#T^("=#2$%2)RP*("`@("`@("`@("`@)VQE;B<@/3X@,BP*("`@("`@
M("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&P@9&5F875L="<L"B`@("`@("`@
M*2P*("`@("`@("`U(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@
M)TY5345224,H.2PQ*2<L"B`@("`@("`@("`@("=L96XG(#T^(#0L"B`@("`@
M("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`Y(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)U9!4D-(05(G+`H@("`@
M("`@("`@("`G;&5N)R`]/B`R,"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G
M)RP*("`@("`@("`I+`H@("`@*2P*"B`@("`G:6)A<V4Z9FER96)I<F0G(#T^
M(&%R<F%Y*`H@("`@("`@("=C;&]B)R`]/B`G5D%20TA!4B@U,"DG+`H@("`@
M("`@("=D871E)R`]/B`G1$%412<L"B`@("`@("`@)V1A=&5L:71E<F%L)R`]
M/B`G)RP*("`@("`@("`G9FEN9'-?=&%B;&4G(#T^(&9A;'-E+`H@("`@("`@
M("=S:7IE7V9R;VU?=&%B;&4G(#T^(&9A;'-E+`H@("`@("`@("=H86YD;&5S
M7W)E<W5L=',G(#T^('1R=64L"B`@("`@("`@)V-O;6UA;F1S)R`]/B!A<G)A
M>2@*("`@("`@("`I+`H@("`@("`@(#`@/3X@87)R87DH"B`@("`@("`@("`@
M("=T>7!E)R`]/B`G24Y414=%4B<L"B`@("`@("`@("`@("=L96XG(#T^(#0L
M"B`@("`@("`@("`@("=F;&%G<R<@/3X@)W5N:7%U95]K97D@;F]T7VYU;&PG
M+`H@("`@("`@("DL"B`@("`@("`@,2`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=)3E1%1T52)RP*("`@("`@("`@("`@)VQE;B<@/3X@-"P*
M("`@("`@("`@("`@)V9L86=S)R`]/B`G<')I;6%R>5]K97D@;F]T7VYU;&PG
M+`H@("`@("`@("DL"B`@("`@("`@,B`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=605)#2$%2)RP*("`@("`@("`@("`@)VQE;B<@/3X@-3`L
M"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@
M("`S(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)T1!5$4G+`H@
M("`@("`@("`@("`G;&5N)R`]/B`T+`H@("`@("`@("`@("`G9FQA9W,G(#T^
M("=U;FEQ=65?:V5Y(&YO=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#0@
M/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G0TA!4B<L"B`@("`@
M("`@("`@("=L96XG(#T^(#(L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO
M=%]N=6QL(&1E9F%U;'0G+`H@("`@("`@("DL"B`@("`@("`@-2`]/B!A<G)A
M>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=.54U%4DE#*#DL,2DG+`H@("`@
M("`@("`@("`G;&5N)R`]/B`T+`H@("`@("`@("`@("`G9FQA9W,G(#T^("<G
M+`H@("`@("`@("DL"B`@("`@("`@.2`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=605)#2$%2)RP*("`@("`@("`@("`@)VQE;B<@/3X@,C`L
M"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("DL
M"@H@("`@)VEF>#II9G@G(#T^(&%R<F%Y*`H@("`@("`@("=C;&]B)R`]/B`G
M0TA!4B@R.2DG+`H@("`@("`@("=D871E)R`]/B`G0TA!4B@Q,"DG+`H@("`@
M("`@("=D871E;&ET97)A;"<@/3X@)R<L"B`@("`@("`@)V9I;F1S7W1A8FQE
M)R`]/B!F86QS92P*("`@("`@("`G<VEZ95]F<F]M7W1A8FQE)R`]/B!F86QS
M92P*("`@("`@("`G:&%N9&QE<U]R97-U;'1S)R`]/B!T<G5E+`H@("`@("`@
M("=C;VUM86YD<R<@/3X@87)R87DH"B`@("`@("`@*2P*("`@("`@("`P(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)U-13$E.5"<L"B`@("`@
M("`@("`@("=L96XG(#T^(#0L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO
M=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#$@/3X@87)R87DH"B`@("`@
M("`@("`@("=T>7!E)R`]/B`G4U%,24Y4)RP*("`@("`@("`@("`@)VQE;B<@
M/3X@-"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@
M("`@("DL"B`@("`@("`@,B`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G
M(#T^("=344Q#2$%2)RP*("`@("`@("`@("`@)VQE;B<@/3X@,CDL"B`@("`@
M("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`S(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)U-13$-(05(G+`H@("`@
M("`@("`@("`G;&5N)R`]/B`Q,"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G
M;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@-"`]/B!A<G)A>2@*("`@
M("`@("`@("`@)W1Y<&4G(#T^("=344Q#2$%2)RP*("`@("`@("`@("`@)VQE
M;B<@/3X@,BP*("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@
M("`@("`@("DL"B`@("`@("`@-2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y
M<&4G(#T^("=344Q$14-)34%,)RP*("`@("`@("`@("`@)VQE;B<@/3X@-3$S
M+`H@("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@("DL"B`@("`@
M("`@.2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=344Q#2$%2
M)RP*("`@("`@("`@("`@)VQE;B<@/3X@,C`L"B`@("`@("`@("`@("=F;&%G
M<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("DL"@H@("`@)VUS<6PZ;7-Q;"<@
M/3X@87)R87DH"B`@("`@("`@)V-L;V(G(#T^("=415A4*#(U-2DG+`H@("`@
M("`@("=D871E)R`]/B`G0TA!4B@Q,"DG+`H@("`@("`@("=D871E;&ET97)A
M;"<@/3X@)R<L"B`@("`@("`@)V9I;F1S7W1A8FQE)R`]/B!T<G5E+`H@("`@
M("`@("=S:7IE7V9R;VU?=&%B;&4G(#T^('1R=64L"B`@("`@("`@)VAA;F1L
M97-?<F5S=6QT<R<@/3X@=')U92P*("`@("`@("`G8V]M;6%N9',G(#T^(&%R
M<F%Y*`H@("`@("`@("DL"B`@("`@("`@,"`]/B!A<G)A>2@*("`@("`@("`@
M("`@)W1Y<&4G(#T^("=I;G0G+`H@("`@("`@("`@("`G;&5N)R`]/B`T+`H@
M("`@("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"<L"B`@("`@("`@*2P*
M("`@("`@("`Q(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)VEN
M="<L"B`@("`@("`@("`@("=L96XG(#T^(#0L"B`@("`@("`@("`@("\O(&9O
M<B!S;VUE(')E87-O;BP@=&AE('5N:7%U92!P<F]P97)T>2!A;'=A>7,@8V]N
M=&%I;G,@,`H@("`@("`@("`@("`O+R`G9FQA9W,G(#T^("=U;FEQ=65?:V5Y
M(&YO=%]N=6QL)RP*("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG
M+`H@("`@("`@("DL"B`@("`@("`@,B`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=T97AT)RP*("`@("`@("`@("`@)VQE;B<@/3X@,C4U+`H@
M("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@("DL"B`@("`@("`@
M,R`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=C:&%R)RP*("`@
M("`@("`@("`@)VQE;B<@/3X@,3`L"B`@("`@("`@("`@("=F;&%G<R<@/3X@
M)VYO=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#0@/3X@87)R87DH"B`@
M("`@("`@("`@("=T>7!E)R`]/B`G8VAA<B<L"B`@("`@("`@("`@("=L96XG
M(#T^(#(L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL)RP*("`@
M("`@("`I+`H@("`@("`@(#4@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E
M)R`]/B`G<F5A;"<L"B`@("`@("`@("`@("=L96XG(#T^(#@L"B`@("`@("`@
M("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`Y(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)V-H87(G+`H@("`@("`@("`@
M("`G;&5N)R`]/B`R,"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@
M("`@("`I+`H@("`@*2P*"B`@("`G;7-S<6PZ;7-S<6PG(#T^(&%R<F%Y*`H@
M("`@("`@("=C;&]B)R`]/B`G5$585"<L"B`@("`@("`@)V1A=&4G(#T^("=3
M34%,3$1!5$5424U%)RP*("`@("`@("`G9&%T96QI=&5R86PG(#T^("<G+`H@
M("`@("`@("=F:6YD<U]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@)W-I>F5?
M9G)O;5]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@)VAA;F1L97-?<F5S=6QT
M<R<@/3X@=')U92P*("`@("`@("`G8V]M;6%N9',G(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`G:6YI7W-E="@B;7-S<6PN9&%T971I;65C;VYV97)T(BP@(D]F
M9B(I.R<L"B`@("`@("`@("`@("<D9&)H+3YQ=65R>2@B4T54($1!5$5&3U)-
M050@>6UD(BD[)RP*("`@("`@("`I+`H@("`@("`@(#`@/3X@87)R87DH"B`@
M("`@("`@("`@("=T>7!E)R`]/B`G:6YT)RP*("`@("`@("`@("`@)VQE;B<@
M/3X@-"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G;75L=&EP;&5?:V5Y('5N
M:7%U95]K97D@;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@,2`]/B!A
M<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=I;G0G+`H@("`@("`@("`@
M("`G;&5N)R`]/B`T+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=P<FEM87)Y
M7VME>2!N;W1?;G5L;"<L"B`@("`@("`@*2P*("`@("`@("`R(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`G='EP92<@/3X@)W1E>'0G+`H@("`@("`@("`@("`G
M;&5N)R`]/B`T,#DV+`H@("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@
M("`@("DL"B`@("`@("`@,R`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G
M(#T^("=D871E=&EM92<L"B`@("`@("`@("`@("=L96XG(#T^(#0L"B`@("`@
M("`@("`@("=F;&%G<R<@/3X@)VUU;'1I<&QE7VME>2!U;FEQ=65?:V5Y(&YO
M=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#0@/3X@87)R87DH"B`@("`@
M("`@("`@("=T>7!E)R`]/B`G8VAA<B<L"B`@("`@("`@("`@("=L96XG(#T^
M(#(L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL)RP*("`@("`@
M("`I+`H@("`@("`@(#4@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]
M/B`G<F5A;"<L"B`@("`@("`@("`@("=L96XG(#T^(#$Y+`H@("`@("`@("`@
M("`G9FQA9W,G(#T^("<G+`H@("`@("`@("DL"B`@("`@("`@.2`]/B!A<G)A
M>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=C:&%R)RP*("`@("`@("`@("`@
M)VQE;B<@/3X@,C`L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@
M("`@*2P*("`@("DL"@H@("`@)VUY<W%L.FUY<W%L)R`]/B!A<G)A>2@*("`@
M("`@("`G8VQO8B<@/3X@)U1%6%0G+`H@("`@("`@("=D871E)R`]/B`G1$%4
M12<L"B`@("`@("`@)V1A=&5L:71E<F%L)R`]/B`G)RP*("`@("`@("`G9FEN
M9'-?=&%B;&4G(#T^('1R=64L"B`@("`@("`@)W-I>F5?9G)O;5]T86)L92<@
M/3X@=')U92P*("`@("`@("`G:&%N9&QE<U]R97-U;'1S)R`]/B!T<G5E+`H@
M("`@("`@("=C;VUM86YD<R<@/3X@87)R87DH"B`@("`@("`@*2P*("`@("`@
M("`P(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)VEN="<L"B`@
M("`@("`@("`@("=L96XG(#T^(#$Q+`H@("`@("`@("`@("`G9FQA9W,G(#T^
M("=N;W1?;G5L;"!M=6QT:7!L95]K97DG+`H@("`@("`@("DL"B`@("`@("`@
M,2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=I;G0G+`H@("`@
M("`@("`@("`G;&5N)R`]/B`Q,2P*("`@("`@("`@("`@)V9L86=S)R`]/B`G
M;F]T7VYU;&P@<')I;6%R>5]K97DG+`H@("`@("`@("DL"B`@("`@("`@,B`]
M/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=B;&]B)RP*("`@("`@
M("`@("`@)VQE;B<@/3X@-C4U,S4L"B`@("`@("`@("`@("=F;&%G<R<@/3X@
M)V)L;V(G+`H@("`@("`@("DL"B`@("`@("`@,R`]/B!A<G)A>2@*("`@("`@
M("`@("`@)W1Y<&4G(#T^("=D871E)RP*("`@("`@("`@("`@)VQE;B<@/3X@
M,3`L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL(&UU;'1I<&QE
M7VME>2<L"B`@("`@("`@*2P*("`@("`@("`T(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`G='EP92<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=L96XG(#T^
M(#(L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL)RP*("`@("`@
M("`I+`H@("`@("`@(#4@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]
M/B`G<F5A;"<L"B`@("`@("`@("`@("=L96XG(#T^(#0L"B`@("`@("`@("`@
M("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`Y(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`G='EP92<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@
M("=L96XG(#T^(#(P+`H@("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@
M("`@("DL"B`@("`I+`H*("`@("=M>7-Q;&DZ;7ES<6QI)R`]/B!A<G)A>2@*
M("`@("`@("`G8VQO8B<@/3X@)U1%6%0G+`H@("`@("`@("=D871E)R`]/B`G
M1$%412<L"B`@("`@("`@)V1A=&5L:71E<F%L)R`]/B`G)RP*("`@("`@("`G
M9FEN9'-?=&%B;&4G(#T^('1R=64L"B`@("`@("`@)W-I>F5?9G)O;5]T86)L
M92<@/3X@9F%L<V4L"B`@("`@("`@)VAA;F1L97-?<F5S=6QT<R<@/3X@=')U
M92P*("`@("`@("`G8V]M;6%N9',G(#T^(&%R<F%Y*`H@("`@("`@("DL"B`@
M("`@("`@,"`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=I;G0G
M+`H@("`@("`@("`@("`G;&5N)R`]/B`R+`H@("`@("`@("`@("`G9FQA9W,G
M(#T^("=N;W1?;G5L;"!M=6QT:7!L95]K97D@9W)O=7!?8GDG+`H@("`@("`@
M("DL"B`@("`@("`@,2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^
M("=I;G0G+`H@("`@("`@("`@("`G;&5N)R`]/B`P+`H@("`@("`@("`@("`G
M9FQA9W,G(#T^("=N;W1?;G5L;"!P<FEM87)Y7VME>2!G<F]U<%]B>2<L"B`@
M("`@("`@*2P*("`@("`@("`R(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP
M92<@/3X@)V)L;V(G+`H@("`@("`@("`@("`G;&5N)R`]/B`P+`H@("`@("`@
M("`@("`G9FQA9W,G(#T^("=B;&]B)RP*("`@("`@("`I+`H@("`@("`@(#,@
M/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G9&%T92<L"B`@("`@
M("`@("`@("=L96XG(#T^(#$P+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=N
M;W1?;G5L;"!M=6QT:7!L95]K97DG+`H@("`@("`@("DL"B`@("`@("`@-"`]
M/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=C:&%R)RP*("`@("`@
M("`@("`@)VQE;B<@/3X@,"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T
M7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@-2`]/B!A<G)A>2@*("`@("`@
M("`@("`@)W1Y<&4G(#T^("=D96-I;6%L)RP*("`@("`@("`@("`@)VQE;B<@
M/3X@,"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G9W)O=7!?8GDG+`H@("`@
M("`@("DL"B`@("`@("`@.2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G
M(#T^("=V87)C:&%R)RP*("`@("`@("`@("`@)VQE;B<@/3X@,3`L"B`@("`@
M("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("DL"@H@("`@
M)V]C:3@Z;V-I."<@/3X@87)R87DH"B`@("`@("`@)V-L;V(G(#T^("=#3$]"
M)RP*("`@("`@("`G9&%T92<@/3X@)T1!5$4G+`H@("`@("`@("=D871E;&ET
M97)A;"<@/3X@)R<L"B`@("`@("`@)V9I;F1S7W1A8FQE)R`]/B!F86QS92P*
M("`@("`@("`G<VEZ95]F<F]M7W1A8FQE)R`]/B!F86QS92P*("`@("`@("`G
M:&%N9&QE<U]R97-U;'1S)R`]/B!T<G5E+`H@("`@("`@("=C;VUM86YD<R<@
M/3X@87)R87DH"B`@("`@("`@("`@("<D9&)H+3YQ=65R>2@B04Q415(@4T53
M4TE/3B!3150@3DQ37T1!5$5?1D]234%4(#T@7"=965E9+4U-+41$7"<B*3LG
M+`H@("`@("`@("DL"B`@("`@("`@,"`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=.54U"15(G+`H@("`@("`@("`@("`G;&5N)R`]/B`R,BP*
M("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL
M"B`@("`@("`@,2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=.
M54U"15(G+`H@("`@("`@("`@("`G;&5N)R`]/B`R,BP*("`@("`@("`@("`@
M)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@,B`]
M/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=#3$]")RP*("`@("`@
M("`@("`@)VQE;B<@/3X@-#`P,"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G
M)RP*("`@("`@("`I+`H@("`@("`@(#,@/3X@87)R87DH"B`@("`@("`@("`@
M("=T>7!E)R`]/B`G1$%412<L"B`@("`@("`@("`@("=L96XG(#T^(#<L"B`@
M("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL)RP*("`@("`@("`I+`H@
M("`@("`@(#0@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G0TA!
M4B<L"B`@("`@("`@("`@("=L96XG(#T^(#(L"B`@("`@("`@("`@("=F;&%G
M<R<@/3X@)VYO=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#4@/3X@87)R
M87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G3E5-0D52)RP*("`@("`@("`@
M("`@)VQE;B<@/3X@,C(L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@
M("`@("`@*2P*("`@("`@("`Y(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP
M92<@/3X@)U9!4D-(05(G+`H@("`@("`@("`@("`G;&5N)R`]/B`R,"P*("`@
M("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@*2P*"B`@
M("`G;V1B8SIA8V-E<W,G(#T^(&%R<F%Y*`H@("`@("`@("=C;&]B)R`]/B`G
M5$585"<L"B`@("`@("`@)V1A=&4G(#T^("=$051%5$E-12<L"B`@("`@("`@
M)V1A=&5L:71E<F%L)R`]/B`G)RP*("`@("`@("`G9FEN9'-?=&%B;&4G(#T^
M(&9A;'-E+`H@("`@("`@("=S:7IE7V9R;VU?=&%B;&4G(#T^(&9A;'-E+`H@
M("`@("`@("=H86YD;&5S7W)E<W5L=',G(#T^('1R=64L"B`@("`@("`@)V-O
M;6UA;F1S)R`]/B!A<G)A>2@*("`@("`@("`I+`H@("`@("`@(#`@/3X@87)R
M87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G24Y414=%4B<L"B`@("`@("`@
M("`@("=L96XG(#T^(#$P+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=N;W1?
M;G5L;"<L"B`@("`@("`@*2P*("`@("`@("`Q(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`G='EP92<@/3X@)TE.5$5'15(G+`H@("`@("`@("`@("`G;&5N)R`]
M/B`Q,"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@
M("`@("DL"B`@("`@("`@,B`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G
M(#T^("=,3TY'0TA!4B<L"B`@("`@("`@("`@("=L96XG(#T^(#(U-2P*("`@
M("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@("`@(#,@
M/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G1$%4151)344G+`H@
M("`@("`@("`@("`G;&5N)R`]/B`Q.2P*("`@("`@("`@("`@)V9L86=S)R`]
M/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@-"`]/B!A<G)A>2@*
M("`@("`@("`@("`@)W1Y<&4G(#T^("=605)#2$%2)RP*("`@("`@("`@("`@
M)VQE;B<@/3X@,BP*("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG
M+`H@("`@("`@("DL"B`@("`@("`@-2`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=$14-)34%,)RP*("`@("`@("`@("`@)VQE;B<@/3X@,34L
M"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@
M("`Y(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)U9!4D-(05(G
M+`H@("`@("`@("`@("`G;&5N)R`]/B`R,"P*("`@("`@("`@("`@)V9L86=S
M)R`]/B`G)RP*("`@("`@("`I+`H@("`@*2P*"B`@("`G;V1B8SID8C(G(#T^
M(&%R<F%Y*`H@("`@("`@("=C;&]B)R`]/B`G0TQ/0B<L"B`@("`@("`@)V1A
M=&4G(#T^("=$051%)RP*("`@("`@("`G9&%T96QI=&5R86PG(#T^("<G+`H@
M("`@("`@("=F:6YD<U]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@)W-I>F5?
M9G)O;5]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@)VAA;F1L97-?<F5S=6QT
M<R<@/3X@=')U92P*("`@("`@("`G8V]M;6%N9',G(#T^(&%R<F%Y*`H@("`@
M("`@("DL"B`@("`@("`@,"`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G
M(#T^("=)3E1%1T52)RP*("`@("`@("`@("`@)VQE;B<@/3X@,3`L"B`@("`@
M("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL)RP*("`@("`@("`I+`H@("`@
M("`@(#$@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G24Y414=%
M4B<L"B`@("`@("`@("`@("=L96XG(#T^(#$P+`H@("`@("`@("`@("`G9FQA
M9W,G(#T^("=N;W1?;G5L;"<L"B`@("`@("`@*2P*("`@("`@("`R(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)T-,3T(G+`H@("`@("`@("`@
M("`G;&5N)R`]/B`Q,#0X-3<V+`H@("`@("`@("`@("`G9FQA9W,G(#T^("<G
M+`H@("`@("`@("DL"B`@("`@("`@,R`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=$051%)RP*("`@("`@("`@("`@)VQE;B<@/3X@,3`L"B`@
M("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL)RP*("`@("`@("`I+`H@
M("`@("`@(#0@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G0TA!
M4B<L"B`@("`@("`@("`@("=L96XG(#T^(#(L"B`@("`@("`@("`@("=F;&%G
M<R<@/3X@)VYO=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#4@/3X@87)R
M87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G1$5#24U!3"<L"B`@("`@("`@
M("`@("=L96XG(#T^(#(L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@
M("`@("`@*2P*("`@("`@("`Y(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP
M92<@/3X@)U9!4D-(05(G+`H@("`@("`@("`@("`G;&5N)R`]/B`R,"P*("`@
M("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@*2P*"B`@
M("`G<&=S<6PZ<&=S<6PG(#T^(&%R<F%Y*`H@("`@("`@("=C;&]B)R`]/B`G
M5$585"<L"B`@("`@("`@)V1A=&4G(#T^("=$051%)RP*("`@("`@("`G9&%T
M96QI=&5R86PG(#T^("<G+`H@("`@("`@("=F:6YD<U]T86)L92<@/3X@9F%L
M<V4L"B`@("`@("`@)W-I>F5?9G)O;5]T86)L92<@/3X@9F%L<V4L"B`@("`@
M("`@)VAA;F1L97-?<F5S=6QT<R<@/3X@=')U92P*("`@("`@("`G8V]M;6%N
M9',G(#T^(&%R<F%Y*`H@("`@("`@("`@("`G)&1B:"T^<75E<GDH(E-%5"!$
M051%4U193$4@/2!)4T\B*3LG+`H@("`@("`@("DL"B`@("`@("`@,"`]/B!A
M<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=I;G0T)RP*("`@("`@("`@
M("`@)VQE;B<@/3X@-"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU
M;&P@=6YI<75E7VME>2!M=6QT:7!L95]K97DG+`H@("`@("`@("DL"B`@("`@
M("`@,2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=I;G0T)RP*
M("`@("`@("`@("`@)VQE;B<@/3X@-"P*("`@("`@("`@("`@)V9L86=S)R`]
M/B`G;F]T7VYU;&P@<')I;6%R>5]K97DG+`H@("`@("`@("DL"B`@("`@("`@
M,B`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=T97AT)RP*("`@
M("`@("`@("`@)VQE;B<@/3X@+3$L"B`@("`@("`@("`@("=F;&%G<R<@/3X@
M)R<L"B`@("`@("`@*2P*("`@("`@("`S(#T^(&%R<F%Y*`H@("`@("`@("`@
M("`G='EP92<@/3X@)V1A=&4G+`H@("`@("`@("`@("`G;&5N)R`]/B`T+`H@
M("`@("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"!U;FEQ=65?:V5Y(&UU
M;'1I<&QE7VME>2<L"B`@("`@("`@*2P*("`@("`@("`T(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`G='EP92<@/3X@)V)P8VAA<B<L"B`@("`@("`@("`@("=L
M96XG(#T^("TQ+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"!D
M969A=6QT7R4R,&4G+`H@("`@("`@("DL"B`@("`@("`@-2`]/B!A<G)A>2@*
M("`@("`@("`@("`@)W1Y<&4G(#T^("=N=6UE<FEC)RP*("`@("`@("`@("`@
M)VQE;B<@/3X@+3$L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@
M("`@*2P*("`@("`@("`Y(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@
M/3X@)W9A<F-H87(G+`H@("`@("`@("`@("`G;&5N)R`]/B`M,2P*("`@("`@
M("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@*2P*"B`@("`G
M<W%L:71E.G-Q;&ET92<@/3X@87)R87DH"B`@("`@("`@)V-L;V(G(#T^("=#
M3$]")RP*("`@("`@("`G9&%T92<@/3X@)T1!5$4G+`H@("`@("`@("=D871E
M;&ET97)A;"<@/3X@)R<L"B`@("`@("`@)V9I;F1S7W1A8FQE)R`]/B!F86QS
M92P*("`@("`@("`G<VEZ95]F<F]M7W1A8FQE)R`]/B!F86QS92P*("`@("`@
M("`G:&%N9&QE<U]R97-U;'1S)R`]/B!F86QS92P*("`@("`@("`G8V]M;6%N
M9',G(#T^(&%R<F%Y*`H@("`@("`@("DL"B`@("`@("`@,"`]/B!A<G)A>2@*
M("`@("`@("`@("`@)W1Y<&4G(#T^("=)3E1%1T52)RP*("`@("`@("`@("`@
M)VQE;B<@/3X@,"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG
M+`H@("`@("`@("DL"B`@("`@("`@,2`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=)3E1%1T52)RP*("`@("`@("`@("`@)VQE;B<@/3X@,"P*
M("`@("`@("`@("`@)V9L86=S)R`]/B`G<')I;6%R>5]K97D@;F]T7VYU;&PG
M+`H@("`@("`@("DL"B`@("`@("`@,B`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=#3$]")RP*("`@("`@("`@("`@)VQE;B<@/3X@,"P*("`@
M("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@("`@(#,@
M/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G1$%412<L"B`@("`@
M("`@("`@("=L96XG(#T^(#`L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO
M=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#0@/3X@87)R87DH"B`@("`@
M("`@("`@("=T>7!E)R`]/B`G0TA!4B<L"B`@("`@("`@("`@("=L96XG(#T^
M(#(L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL(&1E9F%U;'1?
M)3(P92<L"B`@("`@("`@*2P*("`@("`@("`U(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`G='EP92<@/3X@)T1%0TE-04PG+`H@("`@("`@("`@("`G;&5N)R`]
M/B`R+`H@("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@("DL"B`@
M("`@("`@.2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=605)#
M2$%2)RP*("`@("`@("`@("`@)VQE;B<@/3X@,C`L"B`@("`@("`@("`@("=F
M;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("DL"@H@("`@)W-Y8F%S93IS
M>6)A<V4G(#T^(&%R<F%Y*`H@("`@("`@("=C;&]B)R`]/B`G5$585"<L"B`@
M("`@("`@)V1A=&4G(#T^("=334%,3$1!5$5424U%)RP*("`@("`@("`G9&%T
M96QI=&5R86PG(#T^("<G+`H@("`@("`@("=F:6YD<U]T86)L92<@/3X@9F%L
M<V4L"B`@("`@("`@)W-I>F5?9G)O;5]T86)L92<@/3X@9F%L<V4L"B`@("`@
M("`@)VAA;F1L97-?<F5S=6QT<R<@/3X@=')U92P*("`@("`@("`G8V]M;6%N
M9',G(#T^(&%R<F%Y*`H@("`@("`@("`@("`G)&1B:"T^<75E<GDH(E-%5"!$
M051%1D]234%4('EM9"(I.R<L"B`@("`@("`@*2P*("`@("`@("`P(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)VEN="<L"B`@("`@("`@("`@
M("=L96XG(#T^(#$Q+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=M=6QT:7!L
M95]K97D@=6YI<75E7VME>2<L"B`@("`@("`@*2P*("`@("`@("`Q(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)VEN="<L"B`@("`@("`@("`@
M("=L96XG(#T^(#$Q+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=U;FEQ=65?
M:V5Y)RP*("`@("`@("`I+`H@("`@("`@(#(@/3X@87)R87DH"B`@("`@("`@
M("`@("=T>7!E)R`]/B`G<W1R:6YG)RP*("`@("`@("`@("`@)VQE;B<@/3X@
M,S(W-C@L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*
M("`@("`@("`S(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)V1A
M=&5T:6UE)RP*("`@("`@("`@("`@)VQE;B<@/3X@,CDL"B`@("`@("`@("`@
M("=F;&%G<R<@/3X@)VUU;'1I<&QE7VME>2!U;FEQ=65?:V5Y)RP*("`@("`@
M("`I+`H@("`@("`@(#0@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]
M/B`G<W1R:6YG)RP*("`@("`@("`@("`@)VQE;B<@/3X@,BP*("`@("`@("`@
M("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@("`@(#4@/3X@87)R
M87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G<F5A;"<L"B`@("`@("`@("`@
M("=L96XG(#T^(#0L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@
M("`@*2P*("`@("`@("`Y(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@
M/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=L96XG(#T^(#(P+`H@("`@("`@
M("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@("DL"B`@("`I+`HI.PH*"B1Q
M=6ER:U]K97D@/2`D9&)H+3YP:'!T>7!E("X@)SHG("X@)&1B:"T^9&)S>6YT
M87@["@II9B`H(6ES<V5T*"1Q=6ER:W-;)'%U:7)K7VME>5TI*2!["B`@("!D
M:64H(E1H:7,@=&5S="!D;V5S(&YO="!Y970@<W5P<&]R="`D<75I<FM?:V5Y
M(BD["GT*"FEF("AC;W5N="@D<75I<FMS6R1Q=6ER:U]K97E=6R=C;VUM86YD
M<R==*2D@>PH@("`@9F]R96%C:"`H)'%U:7)K<ULD<75I<FM?:V5Y75LG8V]M
M;6%N9',G72!A<R`D=F%L=64I('L*("`@("`@("!E=F%L*"1V86QU92D["B`@
M("!]"GT*"@HD9&)H+3YQ=65R>2@G1$5,151%($923TT@<&AP=&5S="<I.PHD
M9&)H+3YQ=65R>2@B24Y315)4($E.5$\@<&AP=&5S="!604Q515,@*#$L("=O
M;F4G+"`G3VYE)RP@)S(P,#$M,#(M,38G*2(I.PHD9&)H+3YQ=65R>2@B24Y3
M15)4($E.5$\@<&AP=&5S="!604Q515,@*#(L("=T=V\G+"`G5'=O)RP@)S(P
M,#$M,#(M,34G*2(I.PHD9&)H+3YQ=65R>2@B24Y315)4($E.5$\@<&AP=&5S
M="!604Q515,@*#,L("=T:')E92<L("=4:')E92<L("<R,#`Q+3`R+3$T)RDB
M*3L*"@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).
M*3L*9')O<%]T86)L92@D9&)H+"`G<&AP=&5S=%]F:R<I.PHD9&)H+3YS971%
M<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL("=P92<I.PH*"FEF
M("@D<75I<FM?:V5Y(#T]("=O9&)C.F%C8V5S<R<I('L*("`@("1D969A=6QT
M7V4@/2`G)SL*("`@("1D96-I;6%L("`@/2`G3E5-15))0R<["GT@96QS96EF
M("@D<75I<FM?:V5Y(#T]("=M<W%L.FUS<6PG*2!["B`@("`D9&5F875L=%]E
M(#T@)R<["B`@("`D9&5C:6UA;"`@(#T@)U)%04PG.PI](&5L<V4@>PH@("`@
M)&1E9F%U;'1?92`](")$149!54Q4("<@92<B.PH@("`@)&1E8VEM86P@("`]
M("=$14-)34%,*#(L,2DG.PI]"@HO+R`D;G5L;"!I<R!S970@:6X@;6MT86)L
M92YI;F,*"G-W:71C:"`H)&1B:"T^<&AP='EP92D@>PH@("`@8V%S92`G;7-Q
M;"<Z"B`@("`@("`@)&1B:"T^<75E<GDH(@H@("`@("`@("`@("!#4D5!5$4@
M5$%"3$4@<&AP=&5S=%]F:R`H"B`@("`@("`@("`@("`@("!A($E.5$5'15(@
M3D]4($Y53$PL"B`@("`@("`@("`@("`@("!F:R!)3E1%1T52($Y/5"!.54Q,
M+`H@("`@("`@("`@("`@("`@8R![)'%U:7)K<ULD<75I<FM?:V5Y75LG8VQO
M8B==?2`D;G5L;"P*("`@("`@("`@("`@("`@(&0@>R1Q=6ER:W-;)'%U:7)K
M7VME>5U;)V1A=&4G77T@3D]4($Y53$PL"B`@("`@("`@("`@("`@("!E($-(
M05(H,BD@)&1E9F%U;'1?92!.3U0@3E5,3"P*("`@("`@("`@("`@("`@(&8@
M)&1E8VEM86P@)&YU;&P*("`@("`@("`@("`@*0H@("`@("`@("(I.PH@("`@
M("`@("1D8F@M/G%U97)Y*"=#4D5!5$4@54Y)455%($E.1$58(&9K<&L@3TX@
M<&AP=&5S=%]F:R`H9FLI)RD["B`@("`@("`@)&1B:"T^<75E<GDH)T-214%4
M12!53DE1544@24Y$15@@9FMU:R!/3B!P:'!T97-T7V9K("AA+"!D*2<I.PH@
M("`@("`@(&)R96%K.PH@("`@9&5F875L=#H*("`@("`@("`D9&)H+3YQ=65R
M>2@B"B`@("`@("`@("`@($-214%412!404),12!P:'!T97-T7V9K("@*("`@
M("`@("`@("`@("`@(&$@24Y414=%4B!.3U0@3E5,3"P*("`@("`@("`@("`@
M("`@(&9K($E.5$5'15(@3D]4($Y53$PL"B`@("`@("`@("`@("`@("!C('LD
M<75I<FMS6R1Q=6ER:U]K97E=6R=C;&]B)UU]("1N=6QL+`H@("`@("`@("`@
M("`@("`@9"![)'%U:7)K<ULD<75I<FM?:V5Y75LG9&%T92==?2!.3U0@3E5,
M3"P*("`@("`@("`@("`@("`@(&4@0TA!4B@R*2`D9&5F875L=%]E($Y/5"!.
M54Q,+`H@("`@("`@("`@("`@("`@9B`D9&5C:6UA;"`D;G5L;"P*("`@("`@
M("`@("`@("`@(%!224U!4ED@2T59("AF:RDL"B`@("`@("`@("`@("`@("!5
M3DE1544@*&$L(&0I"B`@("`@("`@("`@("D*("`@("`@("`B*3L*?0H*)&1B
M:"T^<75E<GDH(D-214%412!)3D1%6"!T:&5D:61X($].('!H<'1E<W1?9FL@
M*&0I(BD["B1D8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T7V9K(%9!
M3%5%4R`H,3`L(#$L("=/;F4G+"(*("`@("`@("`@("`@+B`D<75I<FMS6R1Q
M=6ER:U]K97E=6R=D871E;&ET97)A;"==("X@(B<R,#`Q+3`R+3$V)RP@("=C
M,2<L(#$N,2DB*3L*)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!H<'1E<W1?
M9FL@5D%,5453("@R,"P@,BP@)U1W;R<L(@H@("`@("`@("`@("`N("1Q=6ER
M:W-;)'%U:7)K7VME>5U;)V1A=&5L:71E<F%L)UT@+B`B)S(P,#$M,#(M,34G
M+"`G8S(G+"`R+C(I(BD["B1D8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T
M97-T7V9K(%9!3%5%4R`H,S`L(#,L("=4:')E92<L(@H@("`@("`@("`@("`N
M("1Q=6ER:W-;)'%U:7)K7VME>5U;)V1A=&5L:71E<F%L)UT@+B`B)S(P,#$M
M,#(M,30G+"`G8S,G+"`S+C,I(BD["@IF=6YC=&EO;B`F<G5N475E<GDH*2![
M"B`@("!G;&]B86P@)&1B:"P@)')E<W5L=&]B:CL*"B`@("`D<75I<FM?:V5Y
M(#T@)&1B:"T^<&AP='EP92`N("<Z)R`N("1D8F@M/F1B<WEN=&%X.PH*("`@
M('-W:71C:"`H)'%U:7)K7VME>2D@>PH@("`@("`@(&-A<V4@)V]D8F,Z9&(R
M)SH*("`@("`@("`@("`@+R\@8V%N)W0@97AT<F%C="!B;&]B)W,@=&AI<R!W
M87D@<V\@;6%K92!A(&9A:V4@8V]L=6UN"B`@("`@("`@("`@("1Q=65R>2`]
M(")314Q%0U0@<&AP=&5S=%]F:RYA+"!P:'!T97-T7V9K+F9K+"`G=&5M<'AY
M>B<@05,@8RPB"B`@("`@("`@("`@("`@("`@("`N("<@<&AP=&5S=%]F:RYD
M+"!P:'!T97-T7V9K+F4L('!H<'1E<W1?9FLN9BPG"B`@("`@("`@("`@("`@
M("`@("`N("<@<&AP=&5S="YA+"!P:'!T97-T+F(L('!H<'1E<W0N8RP@<&AP
M=&5S="YD)PH@("`@("`@("`@("`@("`@("`@+B`G($923TT@<&AP=&5S=%]F
M:RP@<&AP=&5S="<*("`@("`@("`@("`@("`@("`@("X@)R!72$5212!P:'!T
M97-T+F$@/2!P:'!T97-T7V9K+F9K)SL*("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@8V%S92`G;7-Q;#IM<W%L)SH*("`@("`@("`@("`@)'%U97)Y(#T@
M)U-%3$5#5"!P:'!T97-T7V9K+F$L('!H<'1E<W1?9FLN9FLL('!H<'1E<W1?
M9FLN8RPG"B`@("`@("`@("`@("`@("`@("`N("<@<&AP=&5S=%]F:RYD+"!P
M:'!T97-T7V9K+F4L('!H<'1E<W1?9FLN9BPG"B`@("`@("`@("`@("`@("`@
M("`N("<@<&AP=&5S="YA+"!P:'!T97-T+F(L('!H<'1E<W0N8RP@<&AP=&5S
M="YD)PH@("`@("`@("`@("`@("`@("`@+B`G($923TT@<&AP=&5S=%]F:RP@
M<&AP=&5S="<*("`@("`@("`@("`@("`@("`@("X@)R!72$5212!P:'!T97-T
M+F$@/2!P:'!T97-T7V9K+F9K)SL*("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@9&5F875L=#H*("`@("`@("`@("`@)'%U97)Y(#T@)U-%3$5#5"!P:'!T
M97-T7V9K+F$L('!H<'1E<W1?9FLN9FLL('!H<'1E<W1?9FLN8RPG"B`@("`@
M("`@("`@("`@("`@("`N("<@<&AP=&5S=%]F:RYD+"!P:'!T97-T7V9K+F4L
M('!H<'1E<W1?9FLN9BPG"B`@("`@("`@("`@("`@("`@("`N("<@<&AP=&5S
M="YA+"!P:'!T97-T+F(L('!H<'1E<W0N8RP@<&AP=&5S="YD)PH@("`@("`@
M("`@("`@("`@("`@+B`G($923TT@<&AP=&5S=%]F:RP@<&AP=&5S="<*("`@
M("`@("`@("`@("`@("`@("X@)R!72$5212!P:'!T97-T+F$@/2!P:'!T97-T
M7V9K+F9K)SL*("`@('T*("`@("1R97-U;'1O8FH@/28@)&1B:"T^<75E<GDH
M)'%U97)Y*3L*("`@(')E='5R;B`D<F5S=6QT;V)J.PI]"@H*)&5X<&5C=&5D
M,#$@/2`G=&%B;&4@+BXN(&UA=&-H960@97AP96-T960@=F%L=64*;F%M92`]
M/B!A"G1Y<&4@+BXN(&UA=&-H960@97AP96-T960@=F%L=64*;&5N("XN+B!M
M871C:&5D(&5X<&5C=&5D('9A;'5E"F9L86=S("XN+B!M871C:&5D(&5X<&5C
M=&5D('9A;'5E"B<["@HD97AP96-T960P,B`]("=T86)L92`N+BX@;6%T8VAE
M9"!E>'!E8W1E9"!V86QU90IN86UE(#T^(&9K"G1Y<&4@+BXN(&UA=&-H960@
M97AP96-T960@=F%L=64*;&5N("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E
M"F9L86=S("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"B<["@HD97AP96-T
M960P,R`]("=T86)L92`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90IN86UE
M(#T^(&,*='EP92`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90IL96X@+BXN
M(&UA=&-H960@97AP96-T960@=F%L=64*9FQA9W,@+BXN(&UA=&-H960@97AP
M96-T960@=F%L=64*)SL*"B1E>'!E8W1E9#`T(#T@)W1A8FQE("XN+B!M871C
M:&5D(&5X<&5C=&5D('9A;'5E"FYA;64@/3X@9`IT>7!E("XN+B!M871C:&5D
M(&5X<&5C=&5D('9A;'5E"FQE;B`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU
M90IF;&%G<R`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90HG.PH*)&5X<&5C
M=&5D,#4@/2`G=&%B;&4@+BXN(&UA=&-H960@97AP96-T960@=F%L=64*;F%M
M92`]/B!E"G1Y<&4@+BXN(&UA=&-H960@97AP96-T960@=F%L=64*;&5N("XN
M+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"F9L86=S("XN+B!M871C:&5D(&5X
M<&5C=&5D('9A;'5E"B<["@HD97AP96-T960P-B`]("=T86)L92`N+BX@;6%T
M8VAE9"!E>'!E8W1E9"!V86QU90IN86UE(#T^(&8*='EP92`N+BX@;6%T8VAE
M9"!E>'!E8W1E9"!V86QU90IL96X@+BXN(&UA=&-H960@97AP96-T960@=F%L
M=64*9FQA9W,@+BXN(&UA=&-H960@97AP96-T960@=F%L=64*)SL*"B1E>'!E
M8W1E9#$P(#T@)W1A8FQE("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"FYA
M;64@/3X@9`IT>7!E("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"FQE;B`N
M+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90IF;&%G<R`N+BX@;6%T8VAE9"!E
M>'!E8W1E9"!V86QU90HG.PH*"@IP<FEN="`B7&X]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3U<;B(["G!R:6YT(")087-S:6YG
M(')E<W5L="!/0DI%0U0@=&\@;65T:&]D(&EN($1"7SQT>7!E/BY<;B(["G!R
M:6YT(")/=71P=70@/2!D969A=6QT+EQN(CL*<')I;G0@(BTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+5QN(CL*)')E<W5L=&]B
M:B`])B!R=6Y1=65R>2@I.PHD87)R87D@/2`D9&)H+3YT86)L94EN9F\H)')E
M<W5L=&]B:BD["@IP<FEN="`B7&YC;VQU;6X@,#I<;B(["F5X86UI;F5!<G)A
M>41A=&$H)&%R<F%Y+"`D97AP96-T960P,2P@,"D["@IP<FEN="`B7&YC;VQU
M;6X@.3I<;B(["F5X86UI;F5!<G)A>41A=&$H)&%R<F%Y+"`D97AP96-T960Q
M,"P@.2D["@H*<')I;G0@(EQN/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]7&XB.PIP<FEN="`B4&%S<VEN9R!R97-U;'0@240@
M=&\@;65T:&]D(&EN($1"7SQT>7!E/BY<;B(["G!R:6YT(")/=71P=70@/2!$
M0E]404),14E.1D]?3U)$15(N7&XB.PIP<FEN="`B+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM7&XB.PHD<F5S=6QT;V)J(#TF
M(')U;E%U97)Y*"D["B1A<G)A>2`]("1D8F@M/G1A8FQE26YF;R@D<F5S=6QT
M;V)J+3YR97-U;'0L($1"7U1!0DQ%24Y&3U]/4D1%4BD["@IP<FEN="`B7&YC
M;VQU;6X@,#I<;B(["F5X86UI;F5!<G)A>41A=&$H)&%R<F%Y+"`D97AP96-T
M960P,2P@,"D["@IP<FEN="`B7&YC;VQU;6X@,SI<;B(["F5X86UI;F5!<G)A
M>41A=&$H)&%R<F%Y+"`D97AP96-T960P-"P@,RD["@IP<FEN="`B7&YN=6U?
M9FEE;&1S.B`B.PII9B`H)'%U:7)K<ULD<75I<FM?:V5Y75LG:&%N9&QE<U]R
M97-U;'1S)UT@)B8@)&%R<F%Y6R=N=6U?9FEE;&1S)UT@/3T@,3`I('L*("`@
M('!R:6YT(")M871C:&5D(&5X<&5C=&5D(')E<W5L=%QN(CL*?2!E;'-E:68@
M*$1".CII<T5R<F]R*"1A<G)A>2D@)B8@)&%R<F%Y+3YG971#;V1E*"D@/3T@
M1$)?15)23U)?3D]47T-!4$%"3$4I('L*("`@('!R:6YT(")M871C:&5D(&5X
M<&5C=&5D(')E<W5L=%QN(CL*?2!E;'-E('L*("`@('!R:6YT(")4:&ES($1-
M0E,@9&ED;B=T('!R;V1U8V4@<')O<&5R(')E<W5L='-<;B(["GT*"G!R:6YT
M(")<;F]R9&5R.EQN(CL*:68@*"1Q=6ER:W-;)'%U:7)K7VME>5U;)VAA;F1L
M97-?<F5S=6QT<R==("8F(&ES7V%R<F%Y*"1A<G)A>5LG;W)D97(G72DI('L*
M("`@("1E>'!E8W1E9"`]("=A(#T^(#8*8B`]/B`W"F,@/3X@.`ID(#T^(#D*
M92`]/B`T"F8@/3X@-0IF:R`]/B`Q"B<["B`@("!K<V]R="@D87)R87E;)V]R
M9&5R)UTI.PH@("`@97AA;6EN94%R<F%Y1&%T82@D87)R87E;)V]R9&5R)UTL
M("1E>'!E8W1E9"D["GT@96QS96EF("A$0CHZ:7-%<G)O<B@D87)R87DI("8F
M("1A<G)A>2T^9V5T0V]D92@I(#T]($1"7T524D]27TY/5%]#05!!0DQ%*2![
M"B`@("!P<FEN="`B;6%T8VAE9"!E>'!E8W1E9"!R97-U;'1<;B(["GT@96QS
M92!["B`@("!P<FEN="`B5&AI<R!$34)3(&1I9&XG="!P<F]D=6-E('!R;W!E
M<B!R97-U;'1S7&XB.PI]"@H*"G!R:6YT(")<;CT]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/5QN(CL*<')I;G0@(E!A<W-I;F<@
M1$)?5$%"3$5)3D9/7T]21$525$%"3$4@=&\@;65T:&]D(&EN($1"7W)E<W5L
M="Y<;B(["G!R:6YT(")/=71P=70@/2!$0E]404),14E.1D]?3U)$15)404),
M12Y<;B(["G!R:6YT("(M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2U<;B(["B1R97-U;'1O8FH@/28@<G5N475E<GDH*3L*)&%R
M<F%Y(#T@)')E<W5L=&]B:BT^=&%B;&5);F9O*$1"7U1!0DQ%24Y&3U]/4D1%
M4E1!0DQ%*3L*+R\@1G)E92!T:&ES('1O(&ME97`@:6YT97)B87-E(&AA<'!Y
M+@HD<F5S=6QT;V)J+3YF<F5E*"D["@IP<FEN="`B7&YC;VQU;6X@,#I<;B([
M"F5X86UI;F5!<G)A>41A=&$H)&%R<F%Y+"`D97AP96-T960P,2P@,"D["@IP
M<FEN="`B7&YC;VQU;6X@,SI<;B(["F5X86UI;F5!<G)A>41A=&$H)&%R<F%Y
M+"`D97AP96-T960P-"P@,RD["@IP<FEN="`B7&YN=6U?9FEE;&1S.B`B.PII
M9B`H)'%U:7)K<ULD<75I<FM?:V5Y75LG:&%N9&QE<U]R97-U;'1S)UT@)B8@
M)&%R<F%Y6R=N=6U?9FEE;&1S)UT@/3T@,3`I('L*("`@('!R:6YT(")M871C
M:&5D(&5X<&5C=&5D(')E<W5L=%QN(CL*?2!E;'-E:68@*$1".CII<T5R<F]R
M*"1A<G)A>2D@)B8@)&%R<F%Y+3YG971#;V1E*"D@/3T@1$)?15)23U)?3D]4
M7T-!4$%"3$4I('L*("`@('!R:6YT(")M871C:&5D(&5X<&5C=&5D(')E<W5L
M=%QN(CL*?2!E;'-E('L*("`@('!R:6YT(")4:&ES($1-0E,@9&ED;B=T('!R
M;V1U8V4@<')O<&5R(')E<W5L='-<;B(["GT*"@IP<FEN="`G;W)D97)T86)L
M95MP:'!T97-T73H@)SL*)&5X<&5C=&5D(#T@)V$@/3X@-@IB(#T^(#<*8R`]
M/B`X"F0@/3X@.0HG.PII9B`H)'%U:7)K<ULD<75I<FM?:V5Y75LG:&%N9&QE
M<U]R97-U;'1S)UT*("`@("8F(&ES<V5T*"1A<G)A>5LG;W)D97)T86)L92==
M6R=P:'!T97-T)UTI*2!["B`@("`D86-T=6%L(#T@<F5T=7)N07)R87E$871A
M*"1A<G)A>5LG;W)D97)T86)L92==6R=P:'!T97-T)UTI.PI](&5L<V4@>PH@
M("`@)&%C='5A;"`]("<G.PI]"FEF("@D86-T=6%L(#T]("1E>'!E8W1E9"D@
M>PH@("`@<')I;G0@(FUA=&-H960@97AP96-T960@<F5S=6QT7&XB.PI](&5L
M<V4@>PH@("`@:68@*"@D<75I<FMS6R1Q=6ER:U]K97E=6R=F:6YD<U]T86)L
M92==(#T]/2!F86QS92`*("`@("`@("!\?"!$0CHZ:7-%<G)O<B@D87)R87DI
M("8F("1A<G)A>2T^9V5T0V]D92@I(#T]($1"7T524D]27TY/5%]#05!!0DQ%
M*0H@("`@("`@("8F("1A8W1U86P@/3T@)R<I('L*("`@("`@("!P<FEN="`B
M;6%T8VAE9"!E>'!E8W1E9"!R97-U;'1<;B(["B`@("!](&5L<V4@>PH@("`@
M("`@('!R:6YT(")$241.)U0@;6%T8V@@97AP96-T960@=F%L=65S+BXN7&XB
M.PH@("`@("`@('!R:6YT(")^?GY^?GY^?EQN17AP96-T960Z7&XD97AP96-T
M961<;B(["B`@("`@("`@<')I;G0@(GY^?GY<;D%C='5A;#I<;B1A8W1U86Q<
M;GY^?GY^?GY^7&Y<;B(["B`@("!]"GT*"@IP<FEN="`G;W)D97)T86)L95MP
M:'!T97-T7V9K73H@)SL*)&5X<&5C=&5D(#T@)V$@/3X@,`IF:R`]/B`Q"F,@
M/3X@,@ID(#T^(#,*92`]/B`T"F8@/3X@-0HG.PII9B`H)'%U:7)K<ULD<75I
M<FM?:V5Y75LG:&%N9&QE<U]R97-U;'1S)UT*("`@("8F(&ES<V5T*"1A<G)A
M>5LG;W)D97)T86)L92==6R=P:'!T97-T7V9K)UTI*2!["B`@("`D86-T=6%L
M(#T@<F5T=7)N07)R87E$871A*"1A<G)A>5LG;W)D97)T86)L92==6R=P:'!T
M97-T7V9K)UTI.PI](&5L<V4@>PH@("`@)&%C='5A;"`]("<G.PI]"FEF("@D
M86-T=6%L(#T]("1E>'!E8W1E9"D@>PH@("`@<')I;G0@(FUA=&-H960@97AP
M96-T960@<F5S=6QT7&XB.PI](&5L<V4@>PH@("`@:68@*"@D<75I<FMS6R1Q
M=6ER:U]K97E=6R=F:6YD<U]T86)L92==(#T]/2!F86QS92`*("`@("`@("!\
M?"!$0CHZ:7-%<G)O<B@D87)R87DI("8F("1A<G)A>2T^9V5T0V]D92@I(#T]
M($1"7T524D]27TY/5%]#05!!0DQ%*0H@("`@("`@("8F("1A8W1U86P@/3T@
M)R<I('L*("`@("`@("!P<FEN="`B;6%T8VAE9"!E>'!E8W1E9"!R97-U;'1<
M;B(["B`@("!](&5L<V4@>PH@("`@("`@('!R:6YT(")$241.)U0@;6%T8V@@
M97AP96-T960@=F%L=65S+BXN7&XB.PH@("`@("`@('!R:6YT(")^?GY^?GY^
M?EQN17AP96-T960Z7&XD97AP96-T961<;B(["B`@("`@("`@<')I;G0@(GY^
M?GY<;D%C='5A;#I<;B1A8W1U86Q<;GY^?GY^?GY^7&Y<;B(["B`@("!]"GT*
M"@IP<FEN="`B7&X]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3U<;B(["G!R:6YT(")087-S:6YG(%1!0DQ%($Y!344@)W!H<'1E
M<W1?9FLG('1O(&UE=&AO9"!I;B!$0E\\9')I=F5R/BY<;B(["G!R:6YT(")/
M=71P=70@/2!D969A=6QT+EQN(CL*<')I;G0@(BTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+5QN(CL*)&%R<F%Y(#T@)&1B:"T^
M=&%B;&5);F9O*"=P:'!T97-T7V9K)RD["@IP<FEN="`B7&YC;VQU;6X@,#I<
M;B(["F5X86UI;F5!<G)A>41A=&$H)&%R<F%Y+"`D97AP96-T960P,2P@,"P@
M9F%L<V4I.PH*<')I;G0@(EQN8V]L=6UN(#$Z7&XB.PIE>&%M:6YE07)R87E$
M871A*"1A<G)A>2P@)&5X<&5C=&5D,#(L(#$L(&9A;'-E*3L*"G!R:6YT(")<
M;F-O;'5M;B`R.EQN(CL*97AA;6EN94%R<F%Y1&%T82@D87)R87DL("1E>'!E
M8W1E9#`S+"`R+"!F86QS92D["@IP<FEN="`B7&YC;VQU;6X@,SI<;B(["F5X
M86UI;F5!<G)A>41A=&$H)&%R<F%Y+"`D97AP96-T960P-"P@,RP@9F%L<V4I
M.PH*<')I;G0@(EQN8V]L=6UN(#0Z7&XB.PIE>&%M:6YE07)R87E$871A*"1A
M<G)A>2P@)&5X<&5C=&5D,#4L(#0L(&9A;'-E*3L*"G!R:6YT(")<;F-O;'5M
M;B`U.EQN(CL*97AA;6EN94%R<F%Y1&%T82@D87)R87DL("1E>'!E8W1E9#`V
M+"`U+"!F86QS92D["@H*<')I;G0@(EQN/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]7&XB.PIP<FEN="`B4&%S<VEN9R!404),
M12!.04U%("=P:'!T97-T7V9K)R!T;R!M971H;V0@:6X@1$)?/&1R:79E<CXN
M7&XB.PIP<FEN="`B3W5T<'5T(#T@1$)?5$%"3$5)3D9/7T953$PN7&XB.PIP
M<FEN="`B+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM7&XB.PHD87)R87D@/2`D9&)H+3YT86)L94EN9F\H)W!H<'1E<W1?9FLG
M+"!$0E]404),14E.1D]?1E5,3"D["@IP<FEN="`B7&YC;VQU;6X@,#I<;B([
M"F5X86UI;F5!<G)A>41A=&$H)&%R<F%Y+"`D97AP96-T960P,2P@,"P@9F%L
M<V4I.PH*<')I;G0@(EQN;W)D97(Z7&XB.PHD97AP96-T(#TG82`]/B`P"F9K
M(#T^(#$*8R`]/B`R"F0@/3X@,PIE(#T^(#0*9B`]/B`U"B<["F5X86UI;F5!
M<G)A>41A=&$H)&%R<F%Y6R=O<F1E<B==+"`D97AP96-T+"!F86QS92P@9F%L
M<V4I.PH*<')I;G0@(EQN;W)D97)T86)L95MP:'!T97-T7V9K73I<;B(["B1E
M>'!E8W0@/2=A(#T^(#`*9FL@/3X@,0IC(#T^(#(*9"`]/B`S"F4@/3X@-`IF
M(#T^(#4*)SL*97AA;6EN94%R<F%Y1&%T82@D87)R87E;)V]R9&5R=&%B;&4G
M75LG<&AP=&5S=%]F:R==+"`D97AP96-T*3L*"@H*<')I;G0@(EQN/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]7&XB.PIP<FEN
M="`B4&%S<VEN9R!404),12!.04U%("=P:'!T97-T7V9K)R!T;R!M971H;V0@
M:6X@1$)?/&1R:79E<CX@04=!24XN7&XB.PIP<FEN="`B3W5T<'5T(#T@1$)?
M5$%"3$5)3D9/7T953$PL(&QO=V5R8V%S:6YG('1U<FYE9"!O9F8N7&XB.PIP
M<FEN="`B+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM7&XB.PHD9&)H+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]2
M5$%"24Q)5%E?04Q,(%X@1$)?4$]25$%"24Q)5%E?3$]715)#05-%*3L*)&%R
M<F%Y(#T@)&1B:"T^=&%B;&5);F9O*"=P:'!T97-T7V9K)RP@1$)?5$%"3$5)
M3D9/7T953$PI.PH*+R\@=&5S=&EN9R!N;VXM;&]W97)C87-I;F<@86)O=F4@
M=&\@96YS=7)E('!R;V=R86T@9&]E<VXG="!D:64N"B\O(&QO=V5R8V%S92!T
M:&4@;F%M97,@:&5R92!T;R!E;G-U<F4@=&5S="!U;FEF;W)M:71Y+@HD87)R
M87E;,%U;)W1A8FQE)UT@/2!S=')T;VQO=V5R*"1A<G)A>5LP75LG=&%B;&4G
M72D["B1A<G)A>5LP75LG;F%M92==(#T@<W1R=&]L;W=E<B@D87)R87E;,%U;
M)VYA;64G72D["@IP<FEN="`B7&YC;VQU;6X@,#I<;B(["F5X86UI;F5!<G)A
M>41A=&$H)&%R<F%Y+"`P+"!F86QS92D["@H*)&1B:"T^<V5T17)R;W)(86YD
M;&EN9RA014%27T524D]27U)%5%523BD["F1R;W!?=&%B;&4H)&1B:"P@)W!H
M<'1E<W0G*3L*9')O<%]T86)L92@D9&)H+"`G<&AP=&5S=%]F:R<I.PH*/SX*
M+2U%6%!%0U0M+0H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T*4&%S<VEN9R!R97-U;'0@3T)*14-4('1O(&UE=&AO9"!I;B!$
M0E\\='EP93XN"D]U='!U="`](&1E9F%U;'0N"BTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H*8V]L=6UN(#`Z"FUA=&-H960@
M97AP96-T960@<F5S=6QT"@IC;VQU;6X@.3H*;6%T8VAE9"!E>'!E8W1E9"!R
M97-U;'0*"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/0I087-S:6YG(')E<W5L="!)1"!T;R!M971H;V0@:6X@1$)?/'1Y<&4^
M+@I/=71P=70@/2!$0E]404),14E.1D]?3U)$15(N"BTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H*8V]L=6UN(#`Z"FUA=&-H
M960@97AP96-T960@<F5S=6QT"@IC;VQU;6X@,SH*;6%T8VAE9"!E>'!E8W1E
M9"!R97-U;'0*"FYU;5]F:65L9',Z(&UA=&-H960@97AP96-T960@<F5S=6QT
M"@IO<F1E<CH*;6%T8VAE9"!E>'!E8W1E9"!R97-U;'0*"CT]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0I087-S:6YG($1"7U1!
M0DQ%24Y&3U]/4D1%4E1!0DQ%('1O(&UE=&AO9"!I;B!$0E]R97-U;'0N"D]U
M='!U="`]($1"7U1!0DQ%24Y&3U]/4D1%4E1!0DQ%+@HM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*"F-O;'5M;B`P.@IM871C
M:&5D(&5X<&5C=&5D(')E<W5L=`H*8V]L=6UN(#,Z"FUA=&-H960@97AP96-T
M960@<F5S=6QT"@IN=6U?9FEE;&1S.B!M871C:&5D(&5X<&5C=&5D(')E<W5L
M=`IO<F1E<G1A8FQE6W!H<'1E<W1=.B!M871C:&5D(&5X<&5C=&5D(')E<W5L
M=`IO<F1E<G1A8FQE6W!H<'1E<W1?9FM=.B!M871C:&5D(&5X<&5C=&5D(')E
M<W5L=`H*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]"E!A<W-I;F<@5$%"3$4@3D%-12`G<&AP=&5S=%]F:R<@=&\@;65T:&]D
M(&EN($1"7SQD<FEV97(^+@I/=71P=70@/2!D969A=6QT+@HM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*"F-O;'5M;B`P.@IM
M871C:&5D(&5X<&5C=&5D(')E<W5L=`H*8V]L=6UN(#$Z"FUA=&-H960@97AP
M96-T960@<F5S=6QT"@IC;VQU;6X@,CH*;6%T8VAE9"!E>'!E8W1E9"!R97-U
M;'0*"F-O;'5M;B`S.@IM871C:&5D(&5X<&5C=&5D(')E<W5L=`H*8V]L=6UN
M(#0Z"FUA=&-H960@97AP96-T960@<F5S=6QT"@IC;VQU;6X@-3H*;6%T8VAE
M9"!E>'!E8W1E9"!R97-U;'0*"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/0I087-S:6YG(%1!0DQ%($Y!344@)W!H<'1E<W1?
M9FLG('1O(&UE=&AO9"!I;B!$0E\\9')I=F5R/BX*3W5T<'5T(#T@1$)?5$%"
M3$5)3D9/7T953$PN"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+0H*8V]L=6UN(#`Z"FUA=&-H960@97AP96-T960@<F5S=6QT
M"@IO<F1E<CH*;6%T8VAE9"!E>'!E8W1E9"!R97-U;'0*"F]R9&5R=&%B;&5;
M<&AP=&5S=%]F:UTZ"FUA=&-H960@97AP96-T960@<F5S=6QT"@H]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*4&%S<VEN9R!4
M04),12!.04U%("=P:'!T97-T7V9K)R!T;R!M971H;V0@:6X@1$)?/&1R:79E
M<CX@04=!24XN"D]U='!U="`]($1"7U1!0DQ%24Y&3U]&54Q,+"!L;W=E<F-A
M<VEN9R!T=7)N960@;V9F+@HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2T*"F-O;'5M;B`P.@IM871C:&5D(&5X<&5C=&5D(')E
M<W5L=`H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\Q-W%U97)Y+G!H<'0`
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`W,S,T`#$P-3$U-#,S-S0Q`#`R-3$P-P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````M+51%
M4U0M+0I$0E]D<FEV97(Z.G%U97)Y"BTM24Y)+2T*97)R;W)?<F5P;W)T:6YG
M(#T@,C`T-PHM+5-+25!)1BTM"CP_<&AP"@HO*BH*("H@0V%L;',@=&AE('%U
M97)Y*"D@;65T:&]D(&EN('9A<FEO=7,@=V%Y<R!A9V%I;G-T(&%N>2!$0DU3
M+@H@*@H@*B!`<V5E("`@("`@1$)?8V]M;6]N.CIQ=65R>2@I"B`J(`H@*B!`
M<&%C:V%G92`@1$(*("H@0'9E<G-I;VX@("1)9#H@,3=Q=65R>2YP:'!T+'8@
M,2XQ,R`R,#`U+S`R+S$V(#$S.C4T.C4R(&1A;FEE;&,@17AP("0*("H@0&-A
M=&5G;W)Y($1A=&%B87-E"B`J($!A=71H;W(@("!$86YI96P@0V]N=FES<V]R
M(#QD86YI96QC0&%N86QY<VES86YD<V]L=71I;VYS+F-O;3X*("H@0&EN=&5R
M;F%L"B`J+PH*8VAD:7(H9&ER;F%M92A?7T9)3$5?7RDI.PIR97%U:7)E7V]N
M8V4@)RXO<VMI<&EF+FEN8R<["@H_/@HM+49)3$4M+0H\/W!H<`H*+R\@)$ED
M.B`Q-W%U97)Y+G!H<'0L=B`Q+C$S(#(P,#4O,#(O,38@,3,Z-30Z-3(@9&%N
M:65L8R!%>'`@)`H*+RHJ"B`J($-O;FYE8W0@=&\@=&AE(&1A=&%B87-E(&%N
M9"!M86ME('1H92!P:'!T97-T('1A8FQE+@H@*B\*<F5Q=6ER95]O;F-E("<N
M+VUK=&%B;&4N:6YC)SL*"@HO*BH*("H@3&]C86P@97)R;W(@8V%L;&)A8VL@
M:&%N9&QE<BX*("H*("H@1')O<',@=&AE('!H<'1E<W0@=&%B;&4L('!R:6YT
M<R!O=70@86X@97)R;W(@;65S<V%G92!A;F0@:VEL;',@=&AE"B`J('!R;V-E
M<W,N"B`J"B`J($!P87)A;2!O8FIE8W0@("1O("!014%2(&5R<F]R(&]B:F5C
M="!A=71O;6%T:6-A;&QY('!A<W-E9"!T;R!T:&ES(&UE=&AO9`H@*B!`<F5T
M=7)N('9O:60*("H@0'-E92!014%2.CIS971%<G)O<DAA;F1L:6YG*"D*("HO
M"F9U;F-T:6]N('!E*"1O*2!["B`@("!G;&]B86P@)&1B:#L*"B`@("`D9&)H
M+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*("`@(&1R
M;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G*3L*"B`@("!D:64H)&\M/G1O4W1R
M:6YG*"DI.PI]"@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M0T%,3$)!0TLL("=P92<I.PH*"B1D8F@M/G-E=$9E=&-H36]D92A$0E]&151#
M2$U/1$5?05-33T,I.PH*"B1R97,@/28@)&1B:"T^<75E<GDH)T1%3$5412!&
M4D]-('!H<'1E<W0@5TA%4D4@82`](#$W)RD["G!R:6YT("<Q*2!D96QE=&4Z
M("<@+B`H)')E<R`]/3T@1$)?3TL@/R`G;VMA>2<@.B`G97)R;W(G*2`N(")<
M;B(["@HD<F5S(#TF("1D8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T
M("AA+"!B+"!C*2!604Q515,@*#$W+"`G;VYE)RP@)T]N92<I(BD["G!R:6YT
M("<R*2!I;G-E<G0Z("<@+B`H)')E<R`]/3T@1$)?3TL@/R`G;VMA>2<@.B`G
M97)R;W(G*2`N(")<;B(["@HD<F5S(#TF("1D8F@M/G%U97)Y*"=)3E-%4E0@
M24Y43R!P:'!T97-T("AA+"!B+"!C*2!604Q515,@*#\L(#\L(#\I)RP@87)R
M87DH,3<L("=T=V\G+"`G5'=O)RDI.PIP<FEN="`G,RD@:6YS97)T.B`G("X@
M*"1R97,@/3T]($1"7T]+(#\@)V]K87DG(#H@)V5R<F]R)RD@+B`B7&XB.PH*
M"B1R97,@/28@)&1B:"T^<75E<GDH)U-%3$5#5"!A+"!B($923TT@<&AP=&5S
M="!72$5212!A(#T@,3<G*3L*)')O=R`]("1R97,M/F9E=&-H4F]W*"D["G!R
M:6YT("(T*2!A(#T@>R1R;W=;)V$G77TL(&(@/2![)')O=ULG8B==?5QN(CL*
M)')E<RT^9G)E92@I.R`@+R\@:V5E<"!F8G-Q;"!H87!P>2X*"B1R97,@/28@
M)&1B:"T^<75E<GDH)U-%3$5#5"!A+"!B($923TT@<&AP=&5S="!72$5212!C
M(#T@/R<L(&%R<F%Y*"=4=V\G*2D["B1R;W<@/2`D<F5S+3YF971C:%)O=R@I
M.PIP<FEN="`B-2D@82`]('LD<F]W6R=A)UU]+"!B(#T@>R1R;W=;)V(G77U<
M;B(["@H*)&%R<F%Y(#T@87)R87DH"B`@("`G9F]O)R`]/B`Q,2P*("`@("=B
M87(G(#T^("=T:')E92<L"B`@("`G8F%Z)R`]/B!N=6QL+`HI.PHD<F5S(#TF
M("1D8F@M/G%U97)Y*"=)3E-%4E0@24Y43R!P:'!T97-T("AA+"!B+"!D*2!6
M04Q515,@*#\L(#\L(#\I)RP@)&%R<F%Y*3L*<')I;G0@)S8I(&EN<V5R=#H@
M)R`N("@D<F5S(#T]/2!$0E]/2R`_("=O:V%Y)R`Z("=E<G)O<B<I("X@(EQN
M(CL*"B1R97,@/28@)&1B:"T^<75E<GDH)U-%3$5#5"!A+"!B+"!D($923TT@
M<&AP=&5S="!72$5212!A(#T@/R<L(#$Q*3L*)')O=R`]("1R97,M/F9E=&-H
M4F]W*"D["G!R:6YT("(W*2!A(#T@>R1R;W=;)V$G77TL(&(@/2![)')O=ULG
M8B==?2P@9"`]("(["FEF("@D9&)H+3YP:'!T>7!E(#T]("=M<W%L)RD@>PH@
M("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)V0G+"`D<F]W*2D@>PH@("`@("`@
M("1T>7!E(#T@9V5T='EP92@D<F]W6R=D)UTI.PH@("`@("`@(&EF("@D='EP
M92`]/2`G3E5,3"<@?'P@)')O=ULG9"==(#T]("<G*2!["B`@("`@("`@("`@
M('!R:6YT(")G;W0@97AP96-T960@=F%L=65<;B(["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<')I;G0@(D524CH@97AP96-T960@9"=S('1Y<&4@
M=&\@8F4@3E5,3"!B=70@:70G<R`D='EP92!A;F0@=&AE('9A;'5E(&ES("([
M"B`@("`@("`@("`@('!R:6YT("1R;W=;)V0G72`N(")<;B(["B`@("`@("`@
M?0H@("`@?2!E;'-E('L*("`@("`@("`O+R!H='1P.B\O8G5G<RYP:'`N;F5T
M+S]I9#TS,3DV,`H@("`@("`@('!R:6YT(")0<FEO<B!T;R!02%`@-"XS+C$Q
M(&]R(#4N,"XT+"!02%`G<R!M<W%L(&5X=&5N<VEO;B!S:6QE;G1L>2(*("`@
M("`@("`@("`@("`N("(@9')O<'!E9"!C;VQU;6YS('=I=&@@;G5L;"!V86QU
M97,N(%EO=2!N965D('1O('5P9W)A9&4N7&XB.PH@("`@?0I](&5L<V4@>PH@
M("`@)'1Y<&4@/2!G971T>7!E*"1R;W=;)V0G72D["B`@("!I9B`H)'1Y<&4@
M/3T@)TY53$PG('Q\("1R;W=;)V0G72`]/2`G)RD@>PH@("`@("`@('!R:6YT
M(")G;W0@97AP96-T960@=F%L=65<;B(["B`@("!](&5L<V4@>PH@("`@("`@
M('!R:6YT(")%4E(Z(&5X<&5C=&5D(&0G<R!T>7!E('1O(&)E($Y53$P@8G5T
M(&ET)W,@)'1Y<&4@86YD('1H92!V86QU92!I<R`B.PH@("`@("`@('!R:6YT
M("1R;W=;)V0G72`N(")<;B(["B`@("!]"GT*"@HD<F5S(#TF("1D8F@M/G%U
M97)Y*"=$14Q%5$4@1E)/32!P:'!T97-T(%=(15)%(&$@/2`_)RP@87)R87DH
M,3<I*3L*<')I;G0@)S@I(&1E;&5T93H@)R`N("@D<F5S(#T]/2!$0E]/2R`_
M("=O:V%Y)R`Z("=E<G)O<B<I("X@(EQN(CL*"B1R97,@/28@)&1B:"T^<75E
M<GDH)T1%3$5412!&4D]-('!H<'1E<W0@5TA%4D4@82`](#\G+"!A<G)A>2@P
M*2D["G!R:6YT("<Y*2!D96QE=&4@=VET:"!A<G)A>2@P*2!A<R!P87)A;3H@
M)R`N("@D<F5S(#T]/2!$0E]/2R`_("=O:V%Y)R`Z("=E<G)O<B<I("X@(EQN
M(CL*"B1R97,@/28@)&1B:"T^<75E<GDH)T1%3$5412!&4D]-('!H<'1E<W0@
M5TA%4D4@82`](#\G+"`P*3L*<')I;G0@)S$P*2!D96QE=&4@=VET:"`P(&%S
M('!A<F%M.B`G("X@*"1R97,@/3T]($1"7T]+(#\@)V]K87DG(#H@)V5R<F]R
M)RD@+B`B7&XB.PH*"B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/
M4E]215154DXI.PID<F]P7W1A8FQE*"1D8F@L("=P:'!T97-T)RD["@H_/@HM
M+4584$5#5"TM"C$I(&1E;&5T93H@;VMA>0HR*2!I;G-E<G0Z(&]K87D*,RD@
M:6YS97)T.B!O:V%Y"C0I(&$@/2`Q-RP@8B`](&]N90HU*2!A(#T@,3<L(&(@
M/2!T=V\*-BD@:6YS97)T.B!O:V%Y"C<I(&$@/2`Q,2P@8B`]('1H<F5E+"!D
M(#T@9V]T(&5X<&5C=&5D('9A;'5E"C@I(&1E;&5T93H@;VMA>0HY*2!D96QE
M=&4@=VET:"!A<G)A>2@P*2!A<R!P87)A;3H@;VMA>0HQ,"D@9&5L971E('=I
M=&@@,"!A<R!P87)A;3H@;VMA>0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R
M:79E<B\Q.&=E="YP:'!T````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,V-#`U`#$P
M-3$U-#,S-S0Q`#`R-#4R,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````M+51%4U0M+0I$0E]D<FEV97(Z.F=E=`HM+4E.22TM
M"F5R<F]R7W)E<&]R=&EN9R`](#(P-#<*+2U32TE0248M+0H\/W!H<`H*+RHJ
M"B`J($-A;&QS('1H92!G970J*"D@;65T:&]D<R!I;B!V87)I;W5S('=A>7,@
M86=A:6YS="!A;GD@1$)-4RX*("H*("H@0'-E92!$0E]#;VUM;VXZ.F=E=$%L
M;"@I+"!$0E]#;VUM;VXZ.F=E=$%S<V]C*"DL($1"7T-O;6UO;CHZ9V5T0V]L
M*"D*("H@("`@("!$0E]#;VUM;VXZ.F=E=$QI<W1/9B@I+"!$0E]#;VUM;VXZ
M.F=E=$]N92@I+"!$0E]#;VUM;VXZ.F=E=%)O=R@I"B`J"B`J($!P86-K86=E
M("!$0@H@*B!`=F5R<VEO;B`@)$ED.B`Q.&=E="YP:'!T+'8@,2XY(#(P,#4O
M,#(O,30@,C,Z-#<Z-30@9&%N:65L8R!%>'`@)`H@*B!`8V%T96=O<GD@1&%T
M86)A<V4*("H@0&%U=&AO<B`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`
M86YA;'ES:7-A;F1S;VQU=&EO;G,N8V]M/@H@*B!`:6YT97)N86P*("HO"@IC
M:&1I<BAD:7)N86UE*%]?1DE,15]?*2D["G)E<75I<F5?;VYC92`G+B]S:VEP
M:68N:6YC)SL*"C\^"BTM1DE,12TM"CP_<&AP"@HO+R`D260Z(#$X9V5T+G!H
M<'0L=B`Q+CD@,C`P-2\P,B\Q-"`R,SHT-SHU-"!D86YI96QC($5X<"`D"@HO
M*BH*("H@0V]N;F5C="!T;R!T:&4@9&%T86)A<V4@86YD(&UA:V4@=&AE(#QK
M8F0^<&AP=&5S=#PO:V)D/B!T86)L92X*("HO"G)E<75I<F5?;VYC92`G+B]M
M:W1A8FQE+FEN8R<["@H*+RHJ"B`J($QO8V%L(&5R<F]R(&-A;&QB86-K(&AA
M;F1L97(N"B`J"B`J($1R;W!S('1H92!P:'!T97-T('1A8FQE+"!P<FEN=',@
M;W5T(&%N(&5R<F]R(&UE<W-A9V4@86YD(&MI;&QS('1H90H@*B!P<F]C97-S
M+@H@*@H@*B!`<&%R86T@;V)J96-T("`D;R`@4$5!4B!E<G)O<B!O8FIE8W0@
M875T;VUA=&EC86QL>2!P87-S960@=&\@=&AI<R!M971H;V0*("H@0')E='5R
M;B!V;VED"B`J($!S964@4$5!4CHZ<V5T17)R;W)(86YD;&EN9R@I"B`J+PIF
M=6YC=&EO;B!P92@D;RE["B`@("!G;&]B86P@)&1B:#L*"B`@("`D9&)H+3YS
M971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*("`@(&1R;W!?
M=&%B;&4H)&1B:"P@)W!H<'1E<W0G*3L*"B`@("!D:64H)&\M/G1O4W1R:6YG
M*"DI.PI]"@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,
M3$)!0TLL("=P92<I.PH*"B1D8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T
M97-T(%9!3%5%4R`H,BP@)W1W;R<L("=4=V\G+"`G,C`P,BTP,BTR,B<I(BD[
M"B1D8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T(%9!3%5%4R`H-#(L
M("=T:')E92<L("=4:')E92<L("<R,#`S+3`S+3(S)RDB*3L*"@IP<FEN="`B
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]7&XB.PIP<FEN="`G=&5S=&EN9R!G971/;F4Z("<["B1R970@/28@
M)&1B:"T^9V5T3VYE*")314Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%4D4@8R`]
M("=4=V\G(BD["G!R:6YT7W(H)')E="D["G!R:6YT(")<;B(["@IP<FEN="`G
M=&5S=&EN9R!G971/;F4@=VET:"!S=')I;F<@<&%R86US.B`G.PHD<F5T(#TF
M("1D8F@M/F=E=$]N92@G4T5,14-4("H@1E)/32!P:'!T97-T(%=(15)%(&,@
M/2`_)RP@)U1H<F5E)RD["G!R:6YT7W(H)')E="D["G!R:6YT(")<;B(["@IP
M<FEN="`G=&5S=&EN9R!G971/;F4@=VET:"!A<G)A>2!P87)A;7,Z("<["B1R
M970@/28@)&1B:"T^9V5T3VYE*"=314Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%
M4D4@8R`](#\G+"!A<G)A>2@G5'=O)RDI.PIP<FEN=%]R*"1R970I.PIP<FEN
M="`B7&XB.PH*<')I;G0@(EQN/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]7&XB.PIP<FEN="`B=&5S=&EN9R!G
M9712;W<Z7&XB.PHD<F5T(#TF("1D8F@M/F=E=%)O=R@B4T5,14-4("H@1E)/
M32!P:'!T97-T(%=(15)%(&,@/2`G5'=O)R(I.PIP<FEN=%]R*"1R970I.PH*
M<')I;G0@(G1E<W1I;F<@9V5T4F]W('=I=&@@;G5L;"!P87)A;7,L($1"7T9%
M5$-(34]$15]/4D1%4D5$.EQN(CL*)')E="`])B`D9&)H+3YG9712;W<H(E-%
M3$5#5"`J($923TT@<&AP=&5S="!72$5212!C(#T@)U1W;R<B+`H@("`@("`@
M(&YU;&PL($1"7T9%5$-(34]$15]/4D1%4D5$*3L*<')I;G1?<B@D<F5T*3L*
M"B\O(%1(25,@1$]%4TXG5"!73U)+($1512!43R!"04-+5T%21%,@0T]-4$%4
M24))3$E462!#4D%0"B\O('!R:6YT(")T97-T:6YG(&=E=%)O=R!W:71H('-T
M<FEN9R!P87)A;7,L($1"7T9%5$-(34]$15]/4D1%4D5$.EQN(CL*+R\@)')E
M="`])B`D9&)H+3YG9712;W<H)U-%3$5#5"`J($923TT@<&AP=&5S="!72$52
M12!C(#T@/R<L"B\O("`@("`@("`@)U1W;R<L($1"7T9%5$-(34]$15]/4D1%
M4D5$*3L*+R\@<')I;G1?<B@D<F5T*3L*+R\*+R\@=&5S=&EN9R!G9712;W<@
M=VET:"!S=')I;F<@<&%R86US+"!$0E]&151#2$U/1$5?3U)$15)%1#H*+R\@
M07)R87D*+R\@*`HO+R`@("`@6S!=(#T^(#(*+R\@("`@(%LQ72`]/B!T=V\*
M+R\@("`@(%LR72`]/B!4=V\*+R\@("`@(%LS72`]/B`R,#`R+3`R+3(R"B\O
M("D*"B`@('!R:6YT(")T97-T:6YG(&=E=%)O=R!W:71H(%)%5D524T5$(&%R
M9W,Z($1"7T9%5$-(34]$15]!4U-/0RP@87)R87D@<&%R86US.EQN(CL*("`@
M)')E="`])B`D9&)H+3YG9712;W<H)U-%3$5#5"`J($923TT@<&AP=&5S="!7
M2$5212!C(#T@/R<L"B`@("`@("`@("`@1$)?1D540TA-3T1%7T%34T]#+"!A
M<G)A>2@G5'=O)RDI.PH@("!P<FEN=%]R*"1R970I.PH@("`*("`@<')I;G0@
M(G1E<W1I;F<@9V5T4F]W('=I=&@@4D5615)3140@87)G<SH@1$)?1D540TA-
M3T1%7T%34T]#.EQN(CL*("`@)')E="`])B`D9&)H+3YG9712;W<H(E-%3$5#
M5"`J($923TT@<&AP=&5S="!72$5212!C(#T@)U1W;R<B+`H@("`@("`@("`@
M($1"7T9%5$-(34]$15]!4U-/0RD["B`@('!R:6YT7W(H)')E="D["@IP<FEN
M="`B=&5S=&EN9R!G9712;W<@=VET:"!A<G)A>2!P87)A;7,L($1"7T9%5$-(
M34]$15]!4U-/0SI<;B(["B1R970@/28@)&1B:"T^9V5T4F]W*"=314Q%0U0@
M*B!&4D]-('!H<'1E<W0@5TA%4D4@8R`](#\G+`H@("`@("`@(&%R<F%Y*"=4
M=V\G*2P@1$)?1D540TA-3T1%7T%34T]#*3L*<')I;G1?<B@D<F5T*3L*"G!R
M:6YT(")T97-T:6YG(&=E=%)O=R!W:71H(&%R<F%Y('!A<F%M<RP@1$)?1D54
M0TA-3T1%7T]"2D5#5#I<;B(["B1R970@/28@)&1B:"T^9V5T4F]W*"=314Q%
M0U0@*B!&4D]-('!H<'1E<W0@5TA%4D4@8R`](#\G+`H@("`@("`@(&%R<F%Y
M*"=4=V\G*2P@1$)?1D540TA-3T1%7T]"2D5#5"D["G!R:6YT7W(H)')E="D[
M"@H*<')I;G0@(EQN/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]7&XB.PIP<FEN="`B=&5S=&EN9R!G971#;VPZ
M7&XB.PHD<F5T(#TF("1D8F@M/F=E=$-O;"@B4T5,14-4("H@1E)/32!P:'!T
M97-T($]21$52($)9(&(B*3L*<')I;G1?<B@D<F5T*3L*"G!R:6YT(")T97-T
M:6YG(&=E=$-O;"!O;B!Q=65R>2!W:71H(&YO(')E8V]R9',Z7&XB.PHD<F5T
M(#TF("1D8F@M/F=E=$-O;"@G4T5,14-4("H@1E)/32!P:'!T97-T(%=(15)%
M(&$@/B`R,#`G*3L*<')I;G1?<B@D<F5T*3L*"G!R:6YT(")T97-T:6YG(&=E
M=$-O;"!W:71H(&EN=F%L:60@8V]L=6UN(&ED.EQN(CL*)&1B:"T^<V5T17)R
M;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["B1R970@/28@)&1B:"T^
M9V5T0V]L*"=314Q%0U0@8B!&4D]-('!H<'1E<W0@3U)$15(@0ED@8B<L(#$I
M.PII9B`H1$(Z.FES17)R;W(H)')E="DI('L*("`@(&5C:&\@)')E="T^9V5T
M365S<V%G92@I("X@(EQN(CL*?2!E;'-E('L*("`@('!R:6YT("(^/B!3:&]U
M;&0@:&%V92!P<F]D=6-E9"`G;F\@<W5C:"!F:65L9"<@97)R;W)<;B(["GT*
M)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"04-++"`G
M<&4G*3L*"G!R:6YT(")T97-T:6YG(&=E=$-O;"!W:71H(#$@8V]L.EQN(CL*
M)')E="`])B`D9&)H+3YG971#;VPH(E-%3$5#5"`J($923TT@<&AP=&5S="!/
M4D1%4B!"62!B(BP@,2D["G!R:6YT7W(H)')E="D["@IP<FEN="`B=&5S=&EN
M9R!G971#;VP@=VET:"!B(&-O;#I<;B(["B1R970@/28@)&1B:"T^9V5T0V]L
M*")314Q%0U0@*B!&4D]-('!H<'1E<W0@3U)$15(@0ED@8B(L("=B)RD["G!R
M:6YT7W(H)')E="D["@IP<FEN="`B=&5S=&EN9R!G971#;VP@=VET:"!B(&-O
M;"P@<V-A;&%R('!A<F%M<SI<;B(["B1R970@/28@)&1B:"T^9V5T0V]L*")3
M14Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%4D4@82`\(#\@3U)$15(@0ED@8B(L
M"B`@("`@("`@)V(G+"`Q,#`I.PIP<FEN=%]R*"1R970I.PH*<')I;G0@(G1E
M<W1I;F<@9V5T0V]L('=I=&@@8B!C;VPL(&%R<F%Y('!A<F%M<SI<;B(["B1R
M970@/28@)&1B:"T^9V5T0V]L*")314Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%
M4D4@82`\(#\@3U)$15(@0ED@8B(L"B`@("`@("`@)V(G+"!A<G)A>2@Q,#`I
M*3L*<')I;G1?<B@D<F5T*3L*"@IP<FEN="`B7&X]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3U<;B(["G!R:6YT
M(")T97-T:6YG(&=E=$%S<V]C.EQN(CL*)')E="`])B`D9&)H+3YG971!<W-O
M8R@G4T5,14-4(&$L(&(L(&,@1E)/32!P:'!T97-T(%=(15)%(&$@/"`Q,#`@
M3U)$15(@0ED@8B<I.PIP<FEN=%]R*"1R970I.PH*<')I;G0@(G1E<W1I;F<@
M9V5T07-S;V,@=VET:"!F86QS92!F;W)C92P@;G5L;"!P87)A;7,L($1"7T9%
M5$-(34]$15]/4D1%4D5$.EQN(CL*)')E="`])B`D9&)H+3YG971!<W-O8R@B
M4T5,14-4(&$L(&(L(&,@1E)/32!P:'!T97-T(%=(15)%(&$@/"`Q,#`@3U)$
M15(@0ED@8B(L"B`@("`@("`@("`@("`@("`@("`@("`@(&9A;'-E+"!N=6QL
M+"!$0E]&151#2$U/1$5?3U)$15)%1"D["G!R:6YT7W(H)')E="D["@IP<FEN
M="`B=&5S=&EN9R!G971!<W-O8R!W:71H(&9A;'-E(&9O<F-E+"!S8V%L87(@
M<&%R86US+"!$0E]&151#2$U/1$5?05-33T,Z7&XB.PHD<F5T(#TF("1D8F@M
M/F=E=$%S<V]C*"=314Q%0U0@82P@8BP@8R!&4D]-('!H<'1E<W0@5TA%4D4@
M82`\(#\@3U)$15(@0ED@8B<L"B`@("`@("`@("`@("`@("`@("`@("`@(&9A
M;'-E+"`Q,#`L($1"7T9%5$-(34]$15]!4U-/0RD["G!R:6YT7W(H)')E="D[
M"@IP<FEN="`B=&5S=&EN9R!G971!<W-O8R!W:71H('1W;R!C;VQS+"!F86QS
M92!F;W)C92P@<V-A;&%R('!A<F%M<RP@1$)?1D540TA-3T1%7T%34T]#.EQN
M(CL*)')E="`])B`D9&)H+3YG971!<W-O8R@G4T5,14-4(&$L(&(@1E)/32!P
M:'!T97-T(%=(15)%(&$@/"`_($]21$52($)9(&(G+`H@("`@("`@("`@("`@
M("`@("`@("`@("!F86QS92P@,3`P+"!$0E]&151#2$U/1$5?05-33T,I.PIP
M<FEN=%]R*"1R970I.PH*<')I;G0@(G1E<W1I;F<@9V5T07-S;V,@=VET:"!T
M=V\@8V]L<RP@=')U92!F;W)C92P@<V-A;&%R('!A<F%M<RP@1$)?1D540TA-
M3T1%7T%34T]#.EQN(CL*)')E="`])B`D9&)H+3YG971!<W-O8R@G4T5,14-4
M(&$L(&(@1E)/32!P:'!T97-T(%=(15)%(&$@/"`_($]21$52($)9(&(G+`H@
M("`@("`@("`@("`@("`@("`@("`@("!T<G5E+"`Q,#`L($1"7T9%5$-(34]$
M15]!4U-/0RD["G!R:6YT7W(H)')E="D["@IP<FEN="`B=&5S=&EN9R!G971!
M<W-O8R!W:71H(&9A;'-E(&9O<F-E+"!S8V%L87(@<&%R86US+"!$0E]&151#
M2$U/1$5?05-33T,L('1R=64@9W)O=7`Z7&XB.PHD<F5T(#TF("1D8F@M/F=E
M=$%S<V]C*"=314Q%0U0@82P@8BP@8R!&4D]-('!H<'1E<W0@5TA%4D4@82`\
M(#\@3U)$15(@0ED@8B<L"B`@("`@("`@("`@("`@("`@("`@("`@(&9A;'-E
M+"`Q,#`L($1"7T9%5$-(34]$15]!4U-/0RP@=')U92D["G!R:6YT7W(H)')E
M="D["@IP<FEN="`B=&5S=&EN9R!G971!<W-O8R!W:71H(&9A;'-E(&9O<F-E
M+"!A<G)A>2!P87)A;7,L($1"7T9%5$-(34]$15]/0DI%0U0Z7&XB.PHD<F5T
M(#TF("1D8F@M/F=E=$%S<V]C*"=314Q%0U0@82P@8BP@8R!&4D]-('!H<'1E
M<W0@5TA%4D4@82`\(#\@3U)$15(@0ED@8B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@(&9A;'-E+"!A<G)A>2@Q,#`I+"!$0E]&151#2$U/1$5?3T)*14-4
M*3L*<')I;G1?<B@D<F5T*3L*"G!R:6YT(")T97-T:6YG(&=E=$%S<V]C('=I
M=&@@=')U92!F;W)C92P@87)R87D@<&%R86US+"!$0E]&151#2$U/1$5?3T)*
M14-4+"!T<G5E(&=R;W5P.EQN(CL*)')E="`])B`D9&)H+3YG971!<W-O8R@G
M4T5,14-4(&$L(&(L(&,@1E)/32!P:'!T97-T(%=(15)%(&$@/"`_($]21$52
M($)9(&(G+`H@("`@("`@("`@("`@("`@("`@("`@("!F86QS92P@87)R87DH
M,3`P*2P@1$)?1D540TA-3T1%7T]"2D5#5"P@=')U92D["G!R:6YT7W(H)')E
M="D["@H*<')I;G0@(EQN/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]7&XB.PIP<FEN="`B=&5S=&EN9R!G971!
M;&PZ7&XB.PHD<F5T(#TF("1D8F@M/F=E=$%L;"@B4T5,14-4("H@1E)/32!P
M:'!T97-T(%=(15)%(&,@/2`G5'=O)R!/4B!C(#T@)U1H<F5E)R(I.PIP<FEN
M=%]R*"1R970I.PH*<')I;G0@(G1E<W1I;F<@9V5T06QL('=I=&@@;G5L;"!P
M87)A;7,L($1"7T9%5$-(34]$15]/4D1%4D5$.EQN(CL*)')E="`])B`D9&)H
M+3YG971!;&PH(E-%3$5#5"`J($923TT@<&AP=&5S="!72$5212!C(#T@)U1W
M;R<@3U(@8R`]("=4:')E92<B+`H@("`@("`@(&YU;&PL($1"7T9%5$-(34]$
M15]/4D1%4D5$*3L*<')I;G1?<B@D<F5T*3L*"B\O(%1(25,@1$]%4TXG5"!7
M3U)+($1512!43R!"04-+5T%21%,@0T]-4$%424))3$E462!#4D%0"B\O('!R
M:6YT(")T97-T:6YG(&=E=$%L;"!W:71H('-T<FEN9R!P87)A;7,L($1"7T9%
M5$-(34]$15]/4D1%4D5$.EQN(CL*+R\@)')E="`])B`D9&)H+3YG971!;&PH
M)U-%3$5#5"`J($923TT@<&AP=&5S="!72$5212!C(#T@/R<L"B\O("`@("`@
M("`@)U1W;R<L($1"7T9%5$-(34]$15]/4D1%4D5$*3L*+R\@<')I;G1?<B@D
M<F5T*3L*+R\*+R\@=&5S=&EN9R!G971!;&P@=VET:"!S=')I;F<@<&%R86US
M+"!$0E]&151#2$U/1$5?3U)$15)%1#H*+R\@07)R87D*+R\@*`HO+R`@("`@
M6S!=(#T^(#(*+R\@("`@(%LQ72`]/B!T=V\*+R\@("`@(%LR72`]/B!4=V\*
M+R\@("`@(%LS72`]/B`R,#`R+3`R+3(R"B\O("D*"B`@('!R:6YT(")T97-T
M:6YG(&=E=$%L;"!W:71H(%)%5D524T5$(&%R9W,Z($1"7T9%5$-(34]$15]!
M4U-/0RP@87)R87D@<&%R86US.EQN(CL*("`@)')E="`])B`D9&)H+3YG971!
M;&PH)U-%3$5#5"`J($923TT@<&AP=&5S="!72$5212!C(#T@/R!/4B!C(#T@
M/R!/4D1%4B!"62!C)RP*("`@("`@("`@("!$0E]&151#2$U/1$5?05-33T,L
M(&%R<F%Y*"=4=V\G+"`G5&AR964G*2D["B`@('!R:6YT7W(H)')E="D["B`@
M(`H@("!P<FEN="`B=&5S=&EN9R!G971!;&P@=VET:"!2159%4E-%1"!A<F=S
M.B!$0E]&151#2$U/1$5?05-33T,Z7&XB.PH@("`D<F5T(#TF("1D8F@M/F=E
M=$%L;"@B4T5,14-4("H@1E)/32!P:'!T97-T(%=(15)%(&,@/2`G5'=O)R!/
M4B!C(#T@)U1H<F5E)R(L"B`@("`@("`@("`@1$)?1D540TA-3T1%7T%34T]#
M*3L*("`@<')I;G1?<B@D<F5T*3L*"G!R:6YT(")T97-T:6YG(&=E=$%L;"!W
M:71H(&%R<F%Y('!A<F%M<RP@1$)?1D540TA-3T1%7T%34T]#.EQN(CL*)')E
M="`])B`D9&)H+3YG971!;&PH)U-%3$5#5"`J($923TT@<&AP=&5S="!72$52
M12!C(#T@/R!/4B!C(#T@/R!/4D1%4B!"62!C)RP*("`@("`@("!A<G)A>2@G
M5'=O)RP@)U1H<F5E)RDL($1"7T9%5$-(34]$15]!4U-/0RD["G!R:6YT7W(H
M)')E="D["@IP<FEN="`B=&5S=&EN9R!G971!;&P@=VET:"!A<G)A>2!P87)A
M;7,L($1"7T9%5$-(34]$15]/0DI%0U0Z7&XB.PHD<F5T(#TF("1D8F@M/F=E
M=$%L;"@G4T5,14-4("H@1E)/32!P:'!T97-T(%=(15)%(&,@/2`_($]2(&,@
M/2`_($]21$52($)9(&,G+`H@("`@("`@(&%R<F%Y*"=4=V\G+"`G5&AR964G
M*2P@1$)?1D540TA-3T1%7T]"2D5#5"D["G!R:6YT7W(H)')E="D["@H*<')I
M;G0@(EQN/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]7&XB.PIP<FEN="`G=&5S=&EN9R!G971/;F4@=VET:"!N
M=6QL('9A;'5E(&EN(&-O;'5M;CH@)SL*)&1B:"T^<75E<GDH(DE.4T525"!)
M3E1/('!H<'1E<W0@5D%,5453("@Y+"`G;FEN92<L("<G+"!.54Q,*2(I.PHD
M<F5T(#TF("1D8F@M/F=E=$]N92@G4T5,14-4(&0@1E)/32!P:'!T97-T(%=(
M15)%(&$@/2`Y)RD["FEF("@D<F5T(#T]/2`G)RD@>PH@("`@<')I;G0@(FUA
M=&-H97,@97AP96-T960@<F5S=6QT7&XB.PI](&5L<V4@>PH@("`@:68@*"1D
M8F@M/G!H<'1Y<&4@/3T@)VUS<6PG*2!["B`@("`@("`@:68@*&=E='1Y<&4H
M)')E="D@/3T@)TY53$PG*2!["B`@("`@("`@("`@("\O(&US<6P@9&]E<VXG
M="!E=F5N(')E='5R;B!T:&4@8V]L=6UN+B`@2F]Y(2`Z*0H@("`@("`@("`@
M("`O+R!H='1P.B\O8G5G<RYP:'`N;F5T+S]I9#TS,3DV,`H@("`@("`@("`@
M("!P<FEN="`B;6%T8VAE<R!E>'!E8W1E9"!R97-U;'1<;B(["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<')I;G0@(E=/5RP@;5-13"!N;W<@<F5T
M=7)N<R!C;VQU;6YS('1H870@:&%V92!.54Q,4R!I;B!T:&5M7&XB.PH@("`@
M("`@('T*("`@('T@96QS92!["B`@("`@("`@<')I;G0@)W1Y<&4])R`N(&=E
M='1Y<&4H)')E="D@+B`B+"!V86QU93TD<F5T7&XB.PH@("`@?0I]"@IP<FEN
M="`G=&5S=&EN9R!G971/;F4@=VET:"!E;7!T>2!S=')I;F<@:6X@8V]L=6UN
M.B`G.PHD<F5T(#TF("1D8F@M/F=E=$]N92@G4T5,14-4(&,@1E)/32!P:'!T
M97-T(%=(15)%(&$@/2`Y)RD["FEF("@D<F5T(#T]/2`G)RD@>PH@("`@<')I
M;G0@(F5M<'1Y('-T<FEN9UQN(CL*?2!E;'-E('L*("`@('!R:6YT("=T>7!E
M/2<@+B!G971T>7!E*"1R970I("X@(BP@=F%L=64])')E=%QN(CL*?0H*"G!R
M:6YT(")<;CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/5QN(CL*"@ID<F]P7W1A8FQE*"1D8F@L("=P:'!T97-T
M)RD["@H*/SX*+2U%6%!%0U0M+0H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*=&5S=&EN9R!G971/;F4Z(#(*
M=&5S=&EN9R!G971/;F4@=VET:"!S=')I;F<@<&%R86US.B`T,@IT97-T:6YG
M(&=E=$]N92!W:71H(&%R<F%Y('!A<F%M<SH@,@H*/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"G1E<W1I;F<@
M9V5T4F]W.@I!<G)A>0HH"B`@("!;,%T@/3X@,@H@("`@6S%=(#T^('1W;PH@
M("`@6S)=(#T^(%1W;PH@("`@6S-=(#T^(#(P,#(M,#(M,C(**0IT97-T:6YG
M(&=E=%)O=R!W:71H(&YU;&P@<&%R86US+"!$0E]&151#2$U/1$5?3U)$15)%
M1#H*07)R87D**`H@("`@6S!=(#T^(#(*("`@(%LQ72`]/B!T=V\*("`@(%LR
M72`]/B!4=V\*("`@(%LS72`]/B`R,#`R+3`R+3(R"BD*=&5S=&EN9R!G9712
M;W<@=VET:"!2159%4E-%1"!A<F=S.B!$0E]&151#2$U/1$5?05-33T,L(&%R
M<F%Y('!A<F%M<SH*07)R87D**`H@("`@6V%=(#T^(#(*("`@(%MB72`]/B!T
M=V\*("`@(%MC72`]/B!4=V\*("`@(%MD72`]/B`R,#`R+3`R+3(R"BD*=&5S
M=&EN9R!G9712;W<@=VET:"!2159%4E-%1"!A<F=S.B!$0E]&151#2$U/1$5?
M05-33T,Z"D%R<F%Y"B@*("`@(%MA72`]/B`R"B`@("!;8ET@/3X@='=O"B`@
M("!;8UT@/3X@5'=O"B`@("!;9%T@/3X@,C`P,BTP,BTR,@HI"G1E<W1I;F<@
M9V5T4F]W('=I=&@@87)R87D@<&%R86US+"!$0E]&151#2$U/1$5?05-33T,Z
M"D%R<F%Y"B@*("`@(%MA72`]/B`R"B`@("!;8ET@/3X@='=O"B`@("!;8UT@
M/3X@5'=O"B`@("!;9%T@/3X@,C`P,BTP,BTR,@HI"G1E<W1I;F<@9V5T4F]W
M('=I=&@@87)R87D@<&%R86US+"!$0E]&151#2$U/1$5?3T)*14-4.@IS=&1#
M;&%S<R!/8FIE8W0**`H@("`@6V%=(#T^(#(*("`@(%MB72`]/B!T=V\*("`@
M(%MC72`]/B!4=V\*("`@(%MD72`]/B`R,#`R+3`R+3(R"BD*"CT]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0IT
M97-T:6YG(&=E=$-O;#H*07)R87D**`H@("`@6S!=(#T^(#0R"B`@("!;,5T@
M/3X@-#(*("`@(%LR72`]/B`R"BD*=&5S=&EN9R!G971#;VP@;VX@<75E<GD@
M=VET:"!N;R!R96-O<F1S.@I!<G)A>0HH"BD*=&5S=&EN9R!G971#;VP@=VET
M:"!I;G9A;&ED(&-O;'5M;B!I9#H*1$(@17)R;W(Z(&YO('-U8V@@9FEE;&0*
M=&5S=&EN9R!G971#;VP@=VET:"`Q(&-O;#H*07)R87D**`H@("`@6S!=(#T^
M(&)I;F<*("`@(%LQ72`]/B!T:')E90H@("`@6S)=(#T^('1W;PHI"G1E<W1I
M;F<@9V5T0V]L('=I=&@@8B!C;VPZ"D%R<F%Y"B@*("`@(%LP72`]/B!B:6YG
M"B`@("!;,5T@/3X@=&AR964*("`@(%LR72`]/B!T=V\**0IT97-T:6YG(&=E
M=$-O;"!W:71H(&(@8V]L+"!S8V%L87(@<&%R86US.@I!<G)A>0HH"B`@("!;
M,%T@/3X@8FEN9PH@("`@6S%=(#T^('1H<F5E"B`@("!;,ET@/3X@='=O"BD*
M=&5S=&EN9R!G971#;VP@=VET:"!B(&-O;"P@87)R87D@<&%R86US.@I!<G)A
M>0HH"B`@("!;,%T@/3X@8FEN9PH@("`@6S%=(#T^('1H<F5E"B`@("!;,ET@
M/3X@='=O"BD*"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/0IT97-T:6YG(&=E=$%S<V]C.@I!<G)A>0HH"B`@
M("!;-#)=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;,%T@/3X@
M=&AR964*("`@("`@("`@("`@6S%=(#T^(%1H<F5E"B`@("`@("`@*0H*("`@
M(%LR72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@("`@6S!=(#T^('1W
M;PH@("`@("`@("`@("!;,5T@/3X@5'=O"B`@("`@("`@*0H**0IT97-T:6YG
M(&=E=$%S<V]C('=I=&@@9F%L<V4@9F]R8V4L(&YU;&P@<&%R86US+"!$0E]&
M151#2$U/1$5?3U)$15)%1#H*07)R87D**`H@("`@6S0R72`]/B!!<G)A>0H@
M("`@("`@("@*("`@("`@("`@("`@6S!=(#T^('1H<F5E"B`@("`@("`@("`@
M(%LQ72`]/B!4:')E90H@("`@("`@("D*"B`@("!;,ET@/3X@07)R87D*("`@
M("`@("`H"B`@("`@("`@("`@(%LP72`]/B!T=V\*("`@("`@("`@("`@6S%=
M(#T^(%1W;PH@("`@("`@("D*"BD*=&5S=&EN9R!G971!<W-O8R!W:71H(&9A
M;'-E(&9O<F-E+"!S8V%L87(@<&%R86US+"!$0E]&151#2$U/1$5?05-33T,Z
M"D%R<F%Y"B@*("`@(%LT,ET@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@
M("`@(%MB72`]/B!T:')E90H@("`@("`@("`@("!;8UT@/3X@5&AR964*("`@
M("`@("`I"@H@("`@6S)=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@
M("!;8ET@/3X@='=O"B`@("`@("`@("`@(%MC72`]/B!4=V\*("`@("`@("`I
M"@HI"G1E<W1I;F<@9V5T07-S;V,@=VET:"!T=V\@8V]L<RP@9F%L<V4@9F]R
M8V4L('-C86QA<B!P87)A;7,L($1"7T9%5$-(34]$15]!4U-/0SH*07)R87D*
M*`H@("`@6S0R72`]/B!T:')E90H@("`@6S)=(#T^('1W;PHI"G1E<W1I;F<@
M9V5T07-S;V,@=VET:"!T=V\@8V]L<RP@=')U92!F;W)C92P@<V-A;&%R('!A
M<F%M<RP@1$)?1D540TA-3T1%7T%34T]#.@I!<G)A>0HH"B`@("!;-#)=(#T^
M($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;8ET@/3X@=&AR964*("`@
M("`@("`I"@H@("`@6S)=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@
M("!;8ET@/3X@='=O"B`@("`@("`@*0H**0IT97-T:6YG(&=E=$%S<V]C('=I
M=&@@9F%L<V4@9F]R8V4L('-C86QA<B!P87)A;7,L($1"7T9%5$-(34]$15]!
M4U-/0RP@=')U92!G<F]U<#H*07)R87D**`H@("`@6S0R72`]/B!!<G)A>0H@
M("`@("`@("@*("`@("`@("`@("`@6S!=(#T^($%R<F%Y"B`@("`@("`@("`@
M("`@("`H"B`@("`@("`@("`@("`@("`@("`@6V)=(#T^(&)I;F<*("`@("`@
M("`@("`@("`@("`@("!;8UT@/3X@5&AI<R!I<R!A('1E<W0*("`@("`@("`@
M("`@("`@("D*"B`@("`@("`@("`@(%LQ72`]/B!!<G)A>0H@("`@("`@("`@
M("`@("`@*`H@("`@("`@("`@("`@("`@("`@(%MB72`]/B!T:')E90H@("`@
M("`@("`@("`@("`@("`@(%MC72`]/B!4:')E90H@("`@("`@("`@("`@("`@
M*0H*("`@("`@("`I"@H@("`@6S)=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@
M("`@("`@("!;,%T@/3X@07)R87D*("`@("`@("`@("`@("`@("@*("`@("`@
M("`@("`@("`@("`@("!;8ET@/3X@='=O"B`@("`@("`@("`@("`@("`@("`@
M6V-=(#T^(%1W;PH@("`@("`@("`@("`@("`@*0H*("`@("`@("`I"@HI"G1E
M<W1I;F<@9V5T07-S;V,@=VET:"!F86QS92!F;W)C92P@87)R87D@<&%R86US
M+"!$0E]&151#2$U/1$5?3T)*14-4.@I!<G)A>0HH"B`@("!;-#)=(#T^('-T
M9$-L87-S($]B:F5C=`H@("`@("`@("@*("`@("`@("`@("`@6V%=(#T^(#0R
M"B`@("`@("`@("`@(%MB72`]/B!T:')E90H@("`@("`@("`@("!;8UT@/3X@
M5&AR964*("`@("`@("`I"@H@("`@6S)=(#T^('-T9$-L87-S($]B:F5C=`H@
M("`@("`@("@*("`@("`@("`@("`@6V%=(#T^(#(*("`@("`@("`@("`@6V)=
M(#T^('1W;PH@("`@("`@("`@("!;8UT@/3X@5'=O"B`@("`@("`@*0H**0IT
M97-T:6YG(&=E=$%S<V]C('=I=&@@=')U92!F;W)C92P@87)R87D@<&%R86US
M+"!$0E]&151#2$U/1$5?3T)*14-4+"!T<G5E(&=R;W5P.@I!<G)A>0HH"B`@
M("!;-#)=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;,%T@/3X@
M<W1D0VQA<W,@3V)J96-T"B`@("`@("`@("`@("`@("`H"B`@("`@("`@("`@
M("`@("`@("`@6V%=(#T^(#0R"B`@("`@("`@("`@("`@("`@("`@6V)=(#T^
M(&)I;F<*("`@("`@("`@("`@("`@("`@("!;8UT@/3X@5&AI<R!I<R!A('1E
M<W0*("`@("`@("`@("`@("`@("D*"B`@("`@("`@("`@(%LQ72`]/B!S=&1#
M;&%S<R!/8FIE8W0*("`@("`@("`@("`@("`@("@*("`@("`@("`@("`@("`@
M("`@("!;85T@/3X@-#(*("`@("`@("`@("`@("`@("`@("!;8ET@/3X@=&AR
M964*("`@("`@("`@("`@("`@("`@("!;8UT@/3X@5&AR964*("`@("`@("`@
M("`@("`@("D*"B`@("`@("`@*0H*("`@(%LR72`]/B!!<G)A>0H@("`@("`@
M("@*("`@("`@("`@("`@6S!=(#T^('-T9$-L87-S($]B:F5C=`H@("`@("`@
M("`@("`@("`@*`H@("`@("`@("`@("`@("`@("`@(%MA72`]/B`R"B`@("`@
M("`@("`@("`@("`@("`@6V)=(#T^('1W;PH@("`@("`@("`@("`@("`@("`@
M(%MC72`]/B!4=V\*("`@("`@("`@("`@("`@("D*"B`@("`@("`@*0H**0H*
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]"G1E<W1I;F<@9V5T06QL.@I!<G)A>0HH"B`@("!;,%T@/3X@07)R
M87D*("`@("`@("`H"B`@("`@("`@("`@(%LP72`]/B`R"B`@("`@("`@("`@
M(%LQ72`]/B!T=V\*("`@("`@("`@("`@6S)=(#T^(%1W;PH@("`@("`@("`@
M("!;,UT@/3X@,C`P,BTP,BTR,@H@("`@("`@("D*"B`@("!;,5T@/3X@07)R
M87D*("`@("`@("`H"B`@("`@("`@("`@(%LP72`]/B`T,@H@("`@("`@("`@
M("!;,5T@/3X@=&AR964*("`@("`@("`@("`@6S)=(#T^(%1H<F5E"B`@("`@
M("`@("`@(%LS72`]/B`R,#`S+3`S+3(S"B`@("`@("`@*0H**0IT97-T:6YG
M(&=E=$%L;"!W:71H(&YU;&P@<&%R86US+"!$0E]&151#2$U/1$5?3U)$15)%
M1#H*07)R87D**`H@("`@6S!=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@
M("`@("!;,%T@/3X@,@H@("`@("`@("`@("!;,5T@/3X@='=O"B`@("`@("`@
M("`@(%LR72`]/B!4=V\*("`@("`@("`@("`@6S-=(#T^(#(P,#(M,#(M,C(*
M("`@("`@("`I"@H@("`@6S%=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@
M("`@("!;,%T@/3X@-#(*("`@("`@("`@("`@6S%=(#T^('1H<F5E"B`@("`@
M("`@("`@(%LR72`]/B!4:')E90H@("`@("`@("`@("!;,UT@/3X@,C`P,RTP
M,RTR,PH@("`@("`@("D*"BD*=&5S=&EN9R!G971!;&P@=VET:"!2159%4E-%
M1"!A<F=S.B!$0E]&151#2$U/1$5?05-33T,L(&%R<F%Y('!A<F%M<SH*07)R
M87D**`H@("`@6S!=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;
M85T@/3X@-#(*("`@("`@("`@("`@6V)=(#T^('1H<F5E"B`@("`@("`@("`@
M(%MC72`]/B!4:')E90H@("`@("`@("`@("!;9%T@/3X@,C`P,RTP,RTR,PH@
M("`@("`@("D*"B`@("!;,5T@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@
M("`@(%MA72`]/B`R"B`@("`@("`@("`@(%MB72`]/B!T=V\*("`@("`@("`@
M("`@6V-=(#T^(%1W;PH@("`@("`@("`@("!;9%T@/3X@,C`P,BTP,BTR,@H@
M("`@("`@("D*"BD*=&5S=&EN9R!G971!;&P@=VET:"!2159%4E-%1"!A<F=S
M.B!$0E]&151#2$U/1$5?05-33T,Z"D%R<F%Y"B@*("`@(%LP72`]/B!!<G)A
M>0H@("`@("`@("@*("`@("`@("`@("`@6V%=(#T^(#(*("`@("`@("`@("`@
M6V)=(#T^('1W;PH@("`@("`@("`@("!;8UT@/3X@5'=O"B`@("`@("`@("`@
M(%MD72`]/B`R,#`R+3`R+3(R"B`@("`@("`@*0H*("`@(%LQ72`]/B!!<G)A
M>0H@("`@("`@("@*("`@("`@("`@("`@6V%=(#T^(#0R"B`@("`@("`@("`@
M(%MB72`]/B!T:')E90H@("`@("`@("`@("!;8UT@/3X@5&AR964*("`@("`@
M("`@("`@6V1=(#T^(#(P,#,M,#,M,C,*("`@("`@("`I"@HI"G1E<W1I;F<@
M9V5T06QL('=I=&@@87)R87D@<&%R86US+"!$0E]&151#2$U/1$5?05-33T,Z
M"D%R<F%Y"B@*("`@(%LP72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@
M("`@6V%=(#T^(#0R"B`@("`@("`@("`@(%MB72`]/B!T:')E90H@("`@("`@
M("`@("!;8UT@/3X@5&AR964*("`@("`@("`@("`@6V1=(#T^(#(P,#,M,#,M
M,C,*("`@("`@("`I"@H@("`@6S%=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@
M("`@("`@("!;85T@/3X@,@H@("`@("`@("`@("!;8ET@/3X@='=O"B`@("`@
M("`@("`@(%MC72`]/B!4=V\*("`@("`@("`@("`@6V1=(#T^(#(P,#(M,#(M
M,C(*("`@("`@("`I"@HI"G1E<W1I;F<@9V5T06QL('=I=&@@87)R87D@<&%R
M86US+"!$0E]&151#2$U/1$5?3T)*14-4.@I!<G)A>0HH"B`@("!;,%T@/3X@
M<W1D0VQA<W,@3V)J96-T"B`@("`@("`@*`H@("`@("`@("`@("!;85T@/3X@
M-#(*("`@("`@("`@("`@6V)=(#T^('1H<F5E"B`@("`@("`@("`@(%MC72`]
M/B!4:')E90H@("`@("`@("`@("!;9%T@/3X@,C`P,RTP,RTR,PH@("`@("`@
M("D*"B`@("!;,5T@/3X@<W1D0VQA<W,@3V)J96-T"B`@("`@("`@*`H@("`@
M("`@("`@("!;85T@/3X@,@H@("`@("`@("`@("!;8ET@/3X@='=O"B`@("`@
M("`@("`@(%MC72`]/B!4=V\*("`@("`@("`@("`@6V1=(#T^(#(P,#(M,#(M
M,C(*("`@("`@("`I"@HI"@H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*=&5S=&EN9R!G971/;F4@=VET:"!N
M=6QL('9A;'5E(&EN(&-O;'5M;CH@;6%T8VAE<R!E>'!E8W1E9"!R97-U;'0*
M=&5S=&EN9R!G971/;F4@=VET:"!E;7!T>2!S=')I;F<@:6X@8V]L=6UN.B!E
M;7!T>2!S=')I;F<*"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T
M<R]D<FEV97(O,3EG971L:7-T;V8N<&AP=```````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-C$W
M,@`Q,#4Q-30S,S<T,0`P,C4W-#0`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+2U415-4+2T*1$)?9')I=F5R.CIG971,:7-T
M3V8*+2U)3DDM+0IE<G)O<E]R97!O<G1I;F<@/2`R,#0W"BTM4TM)4$E&+2T*
M/#]P:'`@8VAD:7(H9&ER;F%M92A?7T9)3$5?7RDI.R!R97%U:7)E7V]N8V4@
M)RXO<VMI<&EF+FEN8R<[(#\^"BTM1DE,12TM"CP_<&AP"@IR97%U:7)E7V]N
M8V4@)RXO;6MT86)L92YI;F,G.PH*+RH*("H@06X@87)R87D@=VET:"!K97ES
M(&-O;G1A:6YI;F<@=&AE("1T>7!E('1O(&)E('!A<W-E9"!T;R!T:&4@9V5T
M3&ES=$]F*"D*("H@;65T:&]D+B`@5&AE('9A;'5E<R!O9B!T:&4@;6%I;B!A
M<G)A>2!A<F4@82!S=6(M87)R87D@=&AA="!H87,@:V5Y<PH@*B!L:7-T:6YG
M('1H92!P:'!T>7!E(&%N9"!D8G-Y;G1A>"!O9B!E86-H(&1R:79E<B!A;F0@
M=F%L=65S(&]F('1H90H@*B!R97-U;'0@97AP96-T960@9G)O;2!T:&4@8V]M
M8FEN871I;VX@;V8@86QL('1H97-E(&9A8W1O<G,N"B`J+PHD=&5S=',@/2!A
M<G)A>2@*("`@("=T86)L97,G(#T^(&%R<F%Y*`H@("`@("`@("=D8F%S93ID
M8F%S92<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)V9B<W%L
M.F9B<W%L)R`]/B`G87)R87DG+`H@("`@("`@("=I8F%S93II8F%S92<@/3X@
M)V%R<F%Y)RP*("`@("`@("`G:6)A<V4Z9FER96)I<F0G(#T^("=A<G)A>2<L
M"B`@("`@("`@)VEF>#II9G@G(#T^("=A<G)A>2<L"B`@("`@("`@)VUS<6PZ
M;7-Q;"<@/3X@)V%R<F%Y)RP*("`@("`@("`G;7-S<6PZ;7-S<6PG(#T^("=A
M<G)A>2<L"B`@("`@("`@)VUY<W%L.FUY<W%L)R`]/B`G87)R87DG+`H@("`@
M("`@("=M>7-Q;&DZ;7ES<6QI)R`]/B`G87)R87DG+`H@("`@("`@("=O8VDX
M.F]C:3@G(#T^("=A<G)A>2<L"B`@("`@("`@)V]D8F,Z86-C97-S)R`]/B`G
M87)R87DG+`H@("`@("`@("=O9&)C.F1B,B<@/3X@)V%R<F%Y)RP*("`@("`@
M("`G<&=S<6PZ<&=S<6PG(#T^("=A<G)A>2<L"B`@("`@("`@)W-Q;&ET93IS
M<6QI=&4G(#T^("=A<G)A>2<L"B`@("`@("`@)W-Y8F%S93IS>6)A<V4G(#T^
M("=A<G)A>2<L"B`@("`I+`H@("`@)W9I97=S)R`]/B!A<G)A>2@*("`@("`@
M("`G9&)A<V4Z9&)A<V4G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@
M("`@("=F8G-Q;#IF8G-Q;"<@/3X@)V%R<F%Y)RP*("`@("`@("`G:6)A<V4Z
M:6)A<V4G(#T^("=A<G)A>2<L"B`@("`@("`@)VEB87-E.F9I<F5B:7)D)R`]
M/B`G87)R87DG+`H@("`@("`@("=I9G@Z:69X)R`]/B!$0E]%4E)/4E]53E-5
M4%!/4E1%1"P*("`@("`@("`G;7-Q;#IM<W%L)R`]/B!$0E]%4E)/4E]53E-5
M4%!/4E1%1"P*("`@("`@("`G;7-S<6PZ;7-S<6PG(#T^("=A<G)A>2<L"B`@
M("`@("`@)VUY<W%L.FUY<W%L)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*
M("`@("`@("`G;7ES<6QI.FUY<W%L:2<@/3X@1$)?15)23U)?54Y355!03U)4
M140L"B`@("`@("`@)V]C:3@Z;V-I."<@/3X@1$)?15)23U)?54Y355!03U)4
M140L"B`@("`@("`@)V]D8F,Z86-C97-S)R`]/B`G87)R87DG+`H@("`@("`@
M("=O9&)C.F1B,B<@/3X@)V%R<F%Y)RP*("`@("`@("`G<&=S<6PZ<&=S<6PG
M(#T^("=A<G)A>2<L"B`@("`@("`@)W-Q;&ET93IS<6QI=&4G(#T^($1"7T52
M4D]27U5.4U504$]25$5$+`H@("`@("`@("=S>6)A<V4Z<WEB87-E)R`]/B`G
M87)R87DG+`H@("`@*2P*("`@("=U<V5R<R<@/3X@87)R87DH"B`@("`@("`@
M)V1B87-E.F1B87-E)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@
M("`G9F)S<6PZ9F)S<6PG(#T^("=A<G)A>2<L"B`@("`@("`@)VEB87-E.FEB
M87-E)R`]/B`G87)R87DG+`H@("`@("`@("=I8F%S93IF:7)E8FER9"<@/3X@
M)V%R<F%Y)RP*("`@("`@("`G:69X.FEF>"<@/3X@1$)?15)23U)?54Y355!0
M3U)4140L"B`@("`@("`@)VUS<6PZ;7-Q;"<@/3X@1$)?15)23U)?54Y355!0
M3U)4140L"B`@("`@("`@)VUS<W%L.FUS<W%L)R`]/B!$0E]%4E)/4E]53E-5
M4%!/4E1%1"P*("`@("`@("`G;7ES<6PZ;7ES<6PG(#T^($1"7T524D]27T%#
M0T534U]624],051)3TXL"B`@("`@("`@)VUY<W%L:3IM>7-Q;&DG(#T^($1"
M7T524D]27T%#0T534U]624],051)3TXL"B`@("`@("`@)V]C:3@Z;V-I."<@
M/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)V]D8F,Z86-C97-S
M)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;V1B8SID8C(G
M(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=P9W-Q;#IP9W-Q
M;"<@/3X@)V%R<F%Y)RP*("`@("`@("`G<W%L:71E.G-Q;&ET92<@/3X@1$)?
M15)23U)?54Y355!03U)4140L"B`@("`@("`@)W-Y8F%S93IS>6)A<V4G(#T^
M($1"7T524D]27U5.4U504$]25$5$+`H@("`@*2P*("`@("=D871A8F%S97,G
M(#T^(&%R<F%Y*`H@("`@("`@("=D8F%S93ID8F%S92<@/3X@1$)?15)23U)?
M54Y355!03U)4140L"B`@("`@("`@)V9B<W%L.F9B<W%L)R`]/B!$0E]%4E)/
M4E]53E-54%!/4E1%1"P*("`@("`@("`G:6)A<V4Z:6)A<V4G(#T^($1"7T52
M4D]27U5.4U504$]25$5$+`H@("`@("`@("=I8F%S93IF:7)E8FER9"<@/3X@
M1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)VEF>#II9G@G(#T^($1"
M7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=M<W%L.FUS<6PG(#T^("=A
M<G)A>2<L"B`@("`@("`@)VUS<W%L.FUS<W%L)R`]/B!$0E]%4E)/4E]53E-5
M4%!/4E1%1"P*("`@("`@("`G;7ES<6PZ;7ES<6PG(#T^("=A<G)A>2<L"B`@
M("`@("`@)VUY<W%L:3IM>7-Q;&DG(#T^("=A<G)A>2<L"B`@("`@("`@)V]C
M:3@Z;V-I."<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)V]D
M8F,Z86-C97-S)R`]/B`G87)R87DG+`H@("`@("`@("=O9&)C.F1B,B<@/3X@
M)V%R<F%Y)RP*("`@("`@("`G<&=S<6PZ<&=S<6PG(#T^("=A<G)A>2<L"B`@
M("`@("`@)W-Q;&ET93IS<6QI=&4G(#T^($1"7T524D]27U5.4U504$]25$5$
M+`H@("`@("`@("=S>6)A<V4Z<WEB87-E)R`]/B!$0E]%4E)/4E]53E-54%!/
M4E1%1"P*("`@("DL"B`@("`G9G5N8W1I;VYS)R`]/B!A<G)A>2@*("`@("`@
M("`G9&)A<V4Z9&)A<V4G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@
M("`@("=F8G-Q;#IF8G-Q;"<@/3X@)V%R<F%Y)RP*("`@("`@("`G:6)A<V4Z
M:6)A<V4G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=I8F%S
M93IF:7)E8FER9"<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@
M)VEF>#II9G@G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=M
M<W%L.FUS<6PG(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=M
M<W-Q;#IM<W-Q;"<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@
M)VUY<W%L.FUY<W%L)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@
M("`G;7ES<6QI.FUY<W%L:2<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@
M("`@("`@)V]C:3@Z;V-I."<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@
M("`@("`@)V]D8F,Z86-C97-S)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*
M("`@("`@("`G;V1B8SID8C(G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@
M("`@("`@("=P9W-Q;#IP9W-Q;"<@/3X@)V%R<F%Y)RP*("`@("`@("`G<W%L
M:71E.G-Q;&ET92<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@
M)W-Y8F%S93IS>6)A<V4G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@
M*2P*("`@("=P<F]C961U<F5S)R`]/B!A<G)A>2@*("`@("`@("`G9&)A<V4Z
M9&)A<V4G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=F8G-Q
M;#IF8G-Q;"<@/3X@)V%R<F%Y)RP*("`@("`@("`G:6)A<V4Z:6)A<V4G(#T^
M($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=I8F%S93IF:7)E8FER
M9"<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)VEF>#II9G@G
M(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=M<W%L.FUS<6PG
M(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=M<W-Q;#IM<W-Q
M;"<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)VUY<W%L.FUY
M<W%L)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;7ES<6QI
M.FUY<W%L:2<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)V]C
M:3@Z;V-I."<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)V]D
M8F,Z86-C97-S)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G
M;V1B8SID8C(G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=P
M9W-Q;#IP9W-Q;"<@/3X@)V%R<F%Y)RP*("`@("`@("`G<W%L:71E.G-Q;&ET
M92<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)W-Y8F%S93IS
M>6)A<V4G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@*2P*("`@("=S
M8VAE;6$N=&%B;&5S)R`]/B!A<G)A>2@*("`@("`@("`G9&)A<V4Z9&)A<V4G
M(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=F8G-Q;#IF8G-Q
M;"<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)VEB87-E.FEB
M87-E)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G:6)A<V4Z
M9FER96)I<F0G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=I
M9G@Z:69X)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;7-Q
M;#IM<W%L)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;7-S
M<6PZ;7-S<6PG(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=M
M>7-Q;#IM>7-Q;"<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@
M)VUY<W%L:3IM>7-Q;&DG(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@
M("`@("=O8VDX.F]C:3@G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@
M("`@("=O9&)C.F%C8V5S<R<@/3X@)V%R<F%Y)RP*("`@("`@("`G;V1B8SID
M8C(G(#T^("=A<G)A>2<L"B`@("`@("`@)W!G<W%L.G!G<W%L)R`]/B`G87)R
M87DG+`H@("`@("`@("=S<6QI=&4Z<W%L:71E)R`]/B!$0E]%4E)/4E]53E-5
M4%!/4E1%1"P*("`@("`@("`G<WEB87-E.G-Y8F%S92<@/3X@1$)?15)23U)?
M54Y355!03U)4140L"B`@("`I+`H@("`@)W-Y;F]N>6US)R`]/B!A<G)A>2@*
M("`@("`@("`G9&)A<V4Z9&)A<V4G(#T^($1"7T524D]27U5.4U504$]25$5$
M+`H@("`@("`@("=F8G-Q;#IF8G-Q;"<@/3X@1$)?15)23U)?54Y355!03U)4
M140L"B`@("`@("`@)VEB87-E.FEB87-E)R`]/B!$0E]%4E)/4E]53E-54%!/
M4E1%1"P*("`@("`@("`G:6)A<V4Z9FER96)I<F0G(#T^($1"7T524D]27U5.
M4U504$]25$5$+`H@("`@("`@("=I9G@Z:69X)R`]/B!$0E]%4E)/4E]53E-5
M4%!/4E1%1"P*("`@("`@("`G;7-Q;#IM<W%L)R`]/B!$0E]%4E)/4E]53E-5
M4%!/4E1%1"P*("`@("`@("`G;7-S<6PZ;7-S<6PG(#T^($1"7T524D]27U5.
M4U504$]25$5$+`H@("`@("`@("=M>7-Q;#IM>7-Q;"<@/3X@1$)?15)23U)?
M54Y355!03U)4140L"B`@("`@("`@)VUY<W%L:3IM>7-Q;&DG(#T^($1"7T52
M4D]27U5.4U504$]25$5$+`H@("`@("`@("=O8VDX.F]C:3@G(#T^("=A<G)A
M>2<L"B`@("`@("`@)V]D8F,Z86-C97-S)R`]/B!$0E]%4E)/4E]53E-54%!/
M4E1%1"P*("`@("`@("`G;V1B8SID8C(G(#T^($1"7T524D]27U5.4U504$]2
M5$5$+`H@("`@("`@("=P9W-Q;#IP9W-Q;"<@/3X@1$)?15)23U)?54Y355!0
M3U)4140L"B`@("`@("`@)W-Q;&ET93IS<6QI=&4G(#T^($1"7T524D]27U5.
M4U504$]25$5$+`H@("`@("`@("=S>6)A<V4Z<WEB87-E)R`]/B!$0E]%4E)/
M4E]53E-54%!/4E1%1"P*("`@("DL"BD["@HO*BH*("H@1&5T97)M:6YE(&EF
M('1H92!O=71P=70@9G)O;2!T:&4@9')I=F5R(&UA=&-H97,@=VAA="!W92!E
M>'!E8W0*("H*("H@268@=&AI;F=S(&%R92!A<R!W92!E>'!E8W0L(&YO=&AI
M;F<@:7,@<')I;G1E9"!O=70N"B`J"B`J($EF('1H:6YG<R!G;R!W<F]N9RP@
M<')I;G0@(E5.15A014-4140@3U540T]-12(@86YD(&1I<W!L87D*("H@=VAA
M="!H87!P96YE9"X*("H*("H@0'!A<F%M(&UI>&5D("`D<F5S=6QT("`@('1H
M92!R97-U;'0@9G)O;2!G971,:7-T3V8*("H@0'!A<F%M(&UI>&5D("`D97AP
M96-T960@('1H92!E>'!E8W1E9"!R97-U;'0*("H@0'!A<F%M('-T<FEN9R`D
M;F%M92`@("`@('1H92!N86UE(&]F('1H92!C=7)R96YT('1E<W0*("H*("H@
M0')E='5R;B!V;VED"B`J+PIF=6YC=&EO;B!C:&5C:U]O=71P=70H)')E<W5L
M="P@)&5X<&5C=&5D+"`D;F%M92D@>PH@("`@:68@*&ES7V]B:F5C="@D<F5S
M=6QT*2D@>PH@("`@("`@(&EF("@D<F5S=6QT+3YG971#;V1E*"D@(3T]("1E
M>'!E8W1E9"D@>PH@("`@("`@("`@("!E8VAO(")53D584$5#5$5$($]55$-/
M344@1D]2("1N86UE+BXN7&XB.PH@("`@("`@("`@("!E8VAO("1R97-U;'0M
M/F=E=$1E8G5G26YF;R@I("X@(EQN(CL*("`@("`@("!]"B`@("!](&5L<V4@
M>PH@("`@("`@("1T>7!E(#T@9V5T='EP92@D<F5S=6QT*3L*("`@("`@("!I
M9B`H)'1Y<&4@(3T@)&5X<&5C=&5D*2!["B`@("`@("`@("`@(&EF("@D97AP
M96-T960@/3T]($1"7T524D]27T%#0T534U]624],051)3TX*("`@("`@("`@
M("`@("`@("8F("1T>7!E(#T]("=A<G)A>2<I"B`@("`@("`@("`@('L*("`@
M("`@("`@("`@("`@("\O(%1H:7,@=7-E<B!H87,@86-C97-S('1O('1H92!M
M>7-Q;"!T86)L92X*("`@("`@("`@("`@("`@("\O($YO="!A('!R;V)L96T*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&5C:&\@(E5.
M15A014-4140@3U540T]-12!&3U(@)&YA;64N+BY<;B(["B`@("`@("`@("`@
M("`@("!E8VAO("(@($5X<&5C=&5D.B`D97AP96-T961<;B(["B`@("`@("`@
M("`@("`@("!E8VAO("<@(%)E<W5L=#H@)SL*("`@("`@("`@("`@("`@('!R
M:6YT7W(H)')E<W5L="D["B`@("`@("`@("`@("`@("!E8VAO(")<;B(["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]"GT*"@HD9&)H+3YS971%<G)O
M<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*9F]R96%C:"`H)'1E<W1S
M(&%S("1T97-T(#T^("1D8FUS*2!["B`@("!C:&5C:U]O=71P=70H)&1B:"T^
M9V5T3&ES=$]F*"1T97-T*2P*("`@("`@("`@("`@("`@("`D9&)M<ULD9&)H
M+3YP:'!T>7!E("X@)SHG("X@)&1B:"T^9&)S>6YT87A=+`H@("`@("`@("`@
M("`@("`@("1T97-T*3L*?0H*"F1R;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G
M*3L*"C\^"BTM15A014-4+2T*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E
M<W1S+V1R:79E<B]C;VYN96-T+FEN8P``````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R
M-#`P`#$P-3$U-#,S-S0Q`#`R-3`P-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`H*+RHJ"B`J($-O;FYE8W1S('1O
M('1H92!D871A8F%S90H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@
M*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R
M<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA
M8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I
M;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(
M4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*
M("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*
M("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N
M;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@
M*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@)$ED.B!C;VYN
M96-T+FEN8RQV(#$N,3(@,C`P-2\P,B\P,B`P,#HT,#HR,R!D86YI96QC($5X
M<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]$0@H@*B\*"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["@HO+R!3971T:6YG
M(&]F("1O<'1I;VYS(&%N9"!R97%U:7)I;F<@1$(@87)E(&1O;F4@:6X@<V5T
M=7`N:6YC"@HO*BH*("H@17-T86)L:7-H('1H92!I;F-L=61E7W!A=&@L($13
M3B=S(&%N9"!C;VYN96-T:6]N("1O<'1I;VYS"B`J+PIR97%U:7)E7V]N8V4@
M)RXO<V5T=7`N:6YC)SL*"FEF("AE;7!T>2@D9'-N<RDI('L*("`@(&1I92@G
M070@;&5A<W0@;VYE(&5L96UE;G0@;V8@)&1S;G,@;75S="!B92!D969I;F5D
M(&EN('-E='5P+FEN8R<I.PI]"@IL:7-T*"1D8FUS+"`D9'-N*2`](&5A8V@H
M)&1S;G,I.PH*:68@*"1D8FUS(#T]("=M<W-Q;"<I('L*("`@(&EN:5]S970H
M)VUS<W%L+G1E>'1L:6UI="<L(#0P.38I.PH@("`@:6YI7W-E="@G;7-S<6PN
M=&5X='-I>F4G+"`T,#DV*3L*?0H*)&1B:"`])B!$0CHZ8V]N;F5C="@D9'-N
M+"`D;W!T:6]N<RD["FEF("A$0CHZ:7-%<G)O<B@D9&)H*2D@>PH@("`@9&EE
M*"=C;VYN96-T+FEN8SH@)R`N("1D8F@M/G1O4W1R:6YG*"DI.PI]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+VUK=&%B;&4N:6YC
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`Q-C0`,3`U,34T,S,W-#$`,#(U,#`R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@HO*BH*("H@0W)E871E<R!T:&4@/&MB9#YP:'!T97-T/"]K8F0^('1A
M8FQE"B`J"B`J(%1R:65S('1O(&1R;W`@=&AE('1A8FQE(&9I<G-T+"!I;B!C
M87-E(&ET(&%L<F5A9'D@97AI<W1S+@H@*@H@*B`\<')E/@H@*B!#4D5!5$4@
M5$%"3$4@<&AP=&5S="`H"B`J("`@82!)3E1%1T52($Y53$PL"B`J("`@8B!#
M2$%2*#0P*2!$149!54Q4("=D968G($Y/5"!.54Q,+`H@*B`@(&,@5D%20TA!
M4B@R-34I($Y53$PL"B`J("`@9"!605)#2$%2*#(P*2!.54Q,*0H@*B`\+W!R
M93X*("H*("H@3F5E9"`\:V)D/DY/5"!.54Q,/"]K8F0^(&]N(#QK8F0^8CPO
M:V)D/B!T;R!T97-T"B`J(#QK8F0^1$)?4$]25$%"24Q)5%E?4E1224T\+VMB
M9#XN("!-4R!344P@86YD(%-Y8F%S92!T<FEM(&]U='!U="!F<F]M"B`J(#QK
M8F0^5D%20TA!4CPO:V)D/BP@8G5T(&YO="!O;B`\:V)D/D-(05(\+VMB9#XN
M"B`J"B`J($YE960@/&MB9#Y$149!54Q4/"]K8F0^('9A;'5E(&]N(#QK8F0^
M8CPO:V)D/B!B96-A=7-E($]R86-L92!C;VYS:61E<G,*("H@86X@96UP='D@
M<W1R:6YG('1O(&)E(#QK8F0^3E5,3#PO:V)D/BX*("H*("H@26X@3W)A8VQE
M+"!W:&5N('5S:6YG('!L86-E:&]L9&5R<R!I;B`\:V)D/E=(15)%/"]K8F0^
M(&-L875S97,@;VX@"B`J(#QK8F0^0TA!4CPO:V)D/B!C;VQU;6YS+"!T:&4@
M8V]L=6UN(&UU<W0@:&%V92`\:V)D/E)44DE-*"D\+VMB9#X@<G5N(&]N"B`J
M('1H92!C;VQU;6XZ"B`J(#QS86UP/@H@*B`@("!314Q%0U0@*B!&4D]-('!H
M<'1E<W0@5TA%4D4@4E1224TH8BD@/2`_"B`J(#PO<V%M<#X*("H*("H@4$A0
M('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@
M9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC
M96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L
M92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N
M9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO
M=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@($1A=&%B
M87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@($1A;FEE;"!#
M;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY
M-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J
M($!V97)S:6]N("`@("1)9#H@;6MT86)L92YI;F,L=B`Q+C$Y(#(P,#4O,#(O
M,30@,C,Z,S,Z,C`@9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"@HO*BH*("H@17-T86)L
M:7-H97,@=&AE($1"(&]B:F5C="!A;F0@8V]N;F5C=',@=&\@=&AE(&1A=&%B
M87-E"B`J+PIR97%U:7)E7V]N8V4@)RXO8V]N;F5C="YI;F,G.PH*+RHJ"B`J
M($=E="!T:&4@9')O<%]T86)L92@I(&9U;F-T:6]N"B`J+PIR97%U:7)E7V]N
M8V4@)RXO9')O<'1A8FQE+FEN8R<["@HO*BH*("H@5&AE(&5R<F]R(&AA;F1L
M97(@9F]R('1H92!D<F]P('1A8FQE('!R;V-E9'5R90H@*@H@*B!0<FEN=',@
M;W5T(&%N(&5R<F]R(&UE<W-A9V4@86YD(&1I97,N"B`J+PIF=6YC=&EO;B!D
M96)U9U]D:64H)&\I>PH@("`@9&EE*"1O+3YT;U-T<FEN9R@I*3L*?0H*"B1D
M8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PID<F]P
M7W1A8FQE*"1D8F@L("=P:'!T97-T)RD["@HO+R1D8F@M/G-E=$5R<F]R2&%N
M9&QI;F<H4$5!4E]%4E)/4E]44DE'1T52*3L*)&1B:"T^<V5T17)R;W)(86YD
M;&EN9RA014%27T524D]27T-!3$Q"04-++"`G9&5B=6=?9&EE)RD["@II9B`H
M)&1B:"T^<&AP='EP92`]/2`G;V1B8R<I('L*("`@(&EF("@D9&)H+3YD8G-Y
M;G1A>"`]/2`G;V1B8R<I('L*("`@("`@("`D='EP92`]("1D8F@M/G!H<'1Y
M<&4["B`@("!](&5L<V4@>PH@("`@("`@("1T>7!E(#T@)&1B:"T^9&)S>6YT
M87@["B`@("!]"GT@96QS92!["B`@("`D='EP92`]("1D8F@M/G!H<'1Y<&4[
M"GT*"@IS=VET8V@@*"1T>7!E*2!["B`@("!C87-E("=A8V-E<W,G.@H@("`@
M("`@("1N=6QL(#T@)TY53$PG.PH@("`@("`@("1C:')C(#T@)U9!4D-(05(H
M,C4U*2<["B`@("`@("`@)&-H<F0@/2`G5D%20TA!4B@R,"DG.PH@("`@("`@
M("1D969A=6QT(#T@)R<["B`@("`@("`@)'1A8FQE='EP92`]("<G.PH@("`@
M("`@(&)R96%K.PH@("`@8V%S92`G9&(R)SH*("`@(&-A<V4@)VEB87-E)SH*
M("`@("`@("`D;G5L;"`]("<G.PH@("`@("`@("1C:')C(#T@)U9!4D-(05(H
M,C4U*2<["B`@("`@("`@)&-H<F0@/2`G5D%20TA!4B@R,"DG.PH@("`@("`@
M("1D969A=6QT(#T@(D1%1D%53%0@)V1E9B<@3D]4($Y53$PB.PH@("`@("`@
M("1T86)L971Y<&4@/2`G)SL*("`@("`@("!B<F5A:SL*("`@(&-A<V4@)V9B
M<W%L)SH*("`@("`@("`D;G5L;"`]("<G.PH@("`@("`@("1C:')C(#T@)T-(
M05(H,C4U*2<["B`@("`@("`@)&-H<F0@/2`G0TA!4B@R,"DG.PH@("`@("`@
M("1D969A=6QT(#T@(D1%1D%53%0@)V1E9B<@3D]4($Y53$PB.PH@("`@("`@
M("1D871E7VQI=&5R86P@/2`G($1!5$4@)SL*("`@("`@("`D=&%B;&5T>7!E
M(#T@)R<["B`@("`@("`@8G)E86L["B`@("!C87-E("=I9G@G.@H@("`@("`@
M("\O(&1O:6YG('1H:7,@9F]R(&EF>"!T;R!K965P(&-E<G1A:6X@=F5R<VEO
M;G,@:&%P<'D*("`@("`@("`D;G5L;"`]("<G.PH@("`@("`@("1C:')C(#T@
M)T-(05(H,C4U*2<["B`@("`@("`@)&-H<F0@/2`G0TA!4B@R,"DG.PH@("`@
M("`@("1D969A=6QT(#T@(D1%1D%53%0@)V1E9B<@3D]4($Y53$PB.PH@("`@
M("`@("1T86)L971Y<&4@/2`G)SL*("`@("`@("!B<F5A:SL*("`@(&-A<V4@
M)VUS<6PG.@H@("`@("`@("1N=6QL(#T@)R<["B`@("`@("`@)&-H<F,@/2`G
M0TA!4B@R-34I)SL*("`@("`@("`D8VAR9"`]("=#2$%2*#(P*2<["B`@("`@
M("`@)&1E9F%U;'0@/2`G)SL*("`@("`@("`D=&%B;&5T>7!E(#T@)R<["B`@
M("`@("`@8G)E86L["B`@("!C87-E("=M>7-Q;"<Z"B`@("!C87-E("=M>7-Q
M;&DG.@H@("`@("`@("1N=6QL(#T@)TY53$PG.PH@("`@("`@("1C:')C(#T@
M)U9!4D-(05(H,C4U*2<["B`@("`@("`@)&-H<F0@/2`G5D%20TA!4B@R,"DG
M.PH@("`@("`@("1D969A=6QT(#T@(D1%1D%53%0@)V1E9B<@3D]4($Y53$PB
M.PH@("`@("`@(&EF("@A96UP='DH)&YE961I;FYO9&(I*2!["B`@("`@("`@
M("`@("1T86)L971Y<&4@/2`G5%E013U)3DY/1$(G.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1T86)L971Y<&4@/2`G)SL*("`@("`@("!]"B`@
M("`@("`@8G)E86L["B`@("!D969A=6QT.@H@("`@("`@("1N=6QL(#T@)TY5
M3$PG.PH@("`@("`@("1C:')C(#T@)U9!4D-(05(H,C4U*2<["B`@("`@("`@
M)&-H<F0@/2`G5D%20TA!4B@R,"DG.PH@("`@("`@("1D969A=6QT(#T@(D1%
M1D%53%0@)V1E9B<@3D]4($Y53$PB.PH@("`@("`@("1T86)L971Y<&4@/2`G
M)SL*?0H*<W=I=&-H("@D9&)H+3YP:'!T>7!E*2!["B`@("!C87-E("=D8F%S
M92<Z"B`@("`@("`@+R\@9FEL92!E>&ES=',@;W(@=V%S(&-R96%T960@:6X@
M1$)?9&)A<V4Z.F-O;FYE8W0H*0H@("`@("`@(&)R96%K.PH@("`@9&5F875L
M=#H*("`@("`@("`D=&5S=%]M:W1A8FQE7W%U97)Y(#T@(@H@("`@("`@("`@
M("!#4D5!5$4@5$%"3$4@<&AP=&5S="`H"B`@("`@("`@("`@("`@82!)3E1%
M1T52("1N=6QL+`H@("`@("`@("`@("`@(&(@0TA!4B@T,"D@)&1E9F%U;'0L
M"B`@("`@("`@("`@("`@8R`D8VAR8R`D;G5L;"P*("`@("`@("`@("`@("!D
M("1C:')D("1N=6QL*2`D=&%B;&5T>7!E"B`@("`@("`@(CL*?0H*"B1D8F@M
M/G%U97)Y*"1T97-T7VUK=&%B;&5?<75E<GDI.PHD9&)H+3YQ=65R>2@B24Y3
M15)4($E.5$\@<&AP=&5S="!604Q515,H-#(L("=B:6YG)RP@)U1H:7,@:7,@
M82!T97-T)RP@)S$Y.3DM,3$M,C$G*2(I.PH*)&1B:"T^<V5T17)R;W)(86YD
M;&EN9RA014%27T524D]27U)%5%523BD["@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]T97-T<R]$0B]T97-T<R]D<FEV97(O;75L=&EC;VYN96-T+G!H<```````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P-3$P-P`Q,#4Q-30S,S<T,0`P,C8Q,#8`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"B\J*@H@
M*B!497-T<R!T:&4@=F%R:6]U<R!W87ES($1")W,@8V]N;F5C="@I(&9U;F-T
M:6]N(&]P97)A=&5S"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J
M($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S
M:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B
M;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN
M9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N
M("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0
M($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@
M=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP
M+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@
M*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@
M*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN
M970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J
M($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("`D260Z(&UU;'1I
M8V]N;F5C="YP:'`L=B`Q+C(@,C`P-2\P,B\P,R`P-3HT.3HT-2!D86YI96QC
M($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]$0@H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!2
M96QE87-E(#$N-RXP"B`J+PH*+RHJ"B`J($5S=&%B;&ES:"!T:&4@:6YC;'5D
M95]P871H+"!$4TXG<R!A;F0@8V]N;F5C=&EO;B`D;W!T:6]N<PH@*B\*<F5Q
M=6ER95]O;F-E("<N+W-E='5P+FEN8R<["@IF;W)E86-H("@D9'-N<R!A<R`D
M9&)M<R`]/B`D9'-N*2!["B`@("!E8VAO("(]/3T]/3T]/2`D9&)M<R`]/3T]
M/3T]/5QN(CL*("`@("1O<'1I;VYS6R=P97)S:7-T96YT)UT@/2!F86QS93L*
M("`@("1D8F@@/28@1$(Z.F-O;FYE8W0H)&1S;BP@)&]P=&EO;G,I.PH@("`@
M:68@*$1".CII<T5R<F]R*"1D8F@I*2!["B`@("`@("`@96-H;R`G4%)/0DQ%
M33H@)R`N("1D8F@M/F=E=%5S97));F9O*"D@+B`B7&XB.PH@("`@("`@(&-O
M;G1I;G5E.PH@("`@?0H*("`@(&EF("@D9&)H+3YP<F]V:61E<R@G;F5W7VQI
M;FLG*0H@("`@("`@("8F('9E<G-I;VY?8V]M<&%R92AP:'!V97)S:6]N*"DL
M("1D8F@M/G!R;W9I9&5S*"=N97=?;&EN:R<I+"`G/CTG*2D*("`@('L*("`@
M("`@("`D<')O8G,@/2!F86QS93L*("`@("`@("`D9'-N(#T@1$(Z.G!A<G-E
M1%-.*"1D<VXI.PH@("`@("`@("1D<VY;)VYE=U]L:6YK)UT@/2!T<G5E.PH@
M("`@("`@("1D8F@@/28@1$(Z.F-O;FYE8W0H)&1S;BP@)&]P=&EO;G,I.PH@
M("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D9&)H*2D@>PH@("`@("`@("`@("!E
M8VAO("=.15<@3$E.2R!04D]"3$5-.B`G("X@)&1B:"T^9V5T57-E<DEN9F\H
M*2`N(")<;B(["B`@("`@("`@("`@("1P<F]B<R`]('1R=64["B`@("`@("`@
M?0H*("`@("`@("!I9B`H)&1B:"T^<')O=FED97,H)W!C;VYN96-T)RDI('L*
M("`@("`@("`@("`@)&]P=&EO;G-;)W!E<G-I<W1E;G0G72`]('1R=64["B`@
M("`@("`@("`@("1D8F@M/F1I<V-O;FYE8W0H*3L*("`@("`@("`@("`@)&1B
M:"`])B!$0CHZ8V]N;F5C="@D9'-N+"`D;W!T:6]N<RD["B`@("`@("`@("`@
M(&EF("A$0CHZ:7-%<G)O<B@D9&)H*2D@>PH@("`@("`@("`@("`@("`@96-H
M;R`G4$524TE35"!.15=#3TX@4%)/0DQ%33H@)R`N("1D8F@M/F=E=%5S97))
M;F9O*"D@+B`B7&XB.PH@("`@("`@("`@("`@("`@)'!R;V)S(#T@=')U93L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@=6YS970H)&1S;ELG;F5W7VQI
M;FLG72D["B`@("`@("`@("`@("1D8F@M/F1I<V-O;FYE8W0H*3L*("`@("`@
M("`@("`@)&1B:"`])B!$0CHZ8V]N;F5C="@D9'-N+"`D;W!T:6]N<RD["B`@
M("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D9&)H*2D@>PH@("`@("`@("`@
M("`@("`@96-H;R`G4$524TE35"!/3$1#3TX@4%)/0DQ%33H@)R`N("1D8F@M
M/F=E=%5S97));F9O*"D@+B`B7&XB.PH@("`@("`@("`@("`@("`@)'!R;V)S
M(#T@=')U93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H
M)'!R;V)S*2!["B`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@('T*("`@
M("`@("`D9&)H+3YD:7-C;VYN96-T*"D["@H@("`@?2!E;'-E:68@*"1D8F@M
M/G!R;W9I9&5S*"=P8V]N;F5C="<I*2!["B`@("`@("`@)&]P=&EO;G-;)W!E
M<G-I<W1E;G0G72`]('1R=64["B`@("`@("`@)&1B:"T^9&ES8V]N;F5C="@I
M.PH@("`@("`@("1D8F@@/28@1$(Z.F-O;FYE8W0H)&1S;BP@)&]P=&EO;G,I
M.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D9&)H*2D@>PH@("`@("`@("`@
M("!E8VAO("=015)325-4(%!23T),14TZ("<@+B`D9&)H+3YG9715<V5R26YF
M;R@I("X@(EQN(CL*("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@?0H@
M("`@("`@("1D8F@M/F1I<V-O;FYE8W0H*3L*("`@('T*("`@(&5C:&\@(D=/
M3T1<;B(["GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S
M+V1R:79E<B]R=6XN8W9S````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-C8P
M`#$P-3$U-#,S-S0Q`#`R-#(Q,@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````C(2`O8FEN+W-H"@HC("1)9#H@<G5N+F-V<RQV
M(#$N,B`R,#`T+S`R+S(P(#$X.C4W.C4R(&1A;FEE;&,@17AP("0*"B,@=G9V
M=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V
M=G8*(R!014%2($1"(%1%4U0@4U1!4E1%4@HC"B,@("!4;R!R=6X@86QL('1E
M<W1S.B`@+B]R=6X*(R`@(%1O(')U;B!O;F4@=&5S=#H@("`N+W)U;B`\=&5S
M="!F:6QE(&YA;64^"B,@("!%>&%M<&QE.B`@("`@("`@("`@+B]R=6X@9&)?
M<&%R<V5D<VXN<&AP=`HC"B,@0F5F;W)E(')U;FYI;F<@=&AE('1E<W1S('EO
M=2!M=7-T(&%D:G5S="!T:&4*(R!F;VQL;W=I;F<@=&AR964@=F%R:6%B;&5S
M.@H*(R`@(%1H92!F=6QL('!A=&@@=&\@>6]U<B!02%`@9&ER96-T;W)Y.@H@
M("`@1$)?5$535%]02%!?4$%42#UC.B]P<F]G<F%^,2]P:'`*"B,@("!4:&4@
M;F%M92!O9B!Y;W5R(%!(4"!#3$D@97AE8W5T86)L90HC("`@*&5X86UP;&5S
M('!H<"YE>&4L('!H<"UC;&DN97AE+"!C;&DO<&AP+F5X92DZ"B`@("!$0E]4
M15-47U!(4%]#3$D]<&AP+F5X90H*(R`@(%1H92!F=6QL('!A=&@@=&\@=&AE
M('!R97-E;G0@9&ER96-T;W)Y"B,@("`H;F]T('5S:6YG("105T0@9'5E('1O
M($-Y9W=I;BDZ"B`@("!$0E]415-47T1)4CUD.B]P96%R=&5S="]P96%R+T1"
M+W1E<W1S+V1R:79E<@H*(R!>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>
M7EY>7EY>7EY>7EY>7EY>7EY>7EY>7@H*"@I415-47U!(4%]%6$5#551!0DQ%
M/21$0E]415-47U!(4%]0051(+R1$0E]415-47U!(4%]#3$D*97AP;W)T(%1%
M4U1?4$A07T5814-55$%"3$4*"FEF(%L@)",@+6=T(#`@70IT:&5N"B`@("!T
M97-T/20Q"F5L<V4*("`@('1E<W0]*BYP:'!T"F9I"@HD5$535%]02%!?15A%
M0U5404),12`D1$)?5$535%]02%!?4$%42"]R=6XM=&5S=',N<&AP("1$0E]4
M15-47T1)4B\D>W1E<W1]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"
M+W1E<W1S+V1R:79E<B]S971U<"YI;F,N8W9S````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`W-38P`#$P-3$U-#,S-S0Q`#`R-3,R,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`H*+RHJ"B`J($5S=&%B;&ES
M:&5S('1H92!I;F-L=61E7W!A=&@L($133B=S(&%N9"!C;VYN96-T:6]N("1O
M<'1I;VYS"B`J"B`J($EF('1H:7,@9FEL92!I<R!N86UE9"`B<V5T=7`N:6YC
M+F-V<RPB(&ET(&ES('1H92!O<FEG:6YA;"!O;F4@9G)O;2!#5E,N"B`J(%!L
M96%S92!D;R!T:&4@9F]L;&]W:6YG.@H@*B`@(#$I($UA:V4@82!C;W!Y(&]F
M('1H:7,@9FEL92!N86UE9"`B<V5T=7`N:6YC(BX*("H@("`R*2!4:&5N+"!I
M;B!T:&4@8V]P>2P@961I="!T:&4@)&1S;G,@87)R87D@87,@87!P<F]P<FEA
M=&4@9F]R('EO=7(*("H@("`@("!E;G9I<F]N;65N="X*("H@("`S*2!!="!L
M96%S="!O;F4@96QE;65N="!O9B!T:&4@)&1S;G,@87)R87D@;F5E9',@=&\@
M8F4@=6YC;VUM96YT960N"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J
M"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V
M97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I
M;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO
M=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@
M4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$
M0@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H
M<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P
M"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("`D260Z('-E
M='5P+FEN8RYC=G,L=B`Q+C8@,C`P-2\P,B\Q-"`R,SHS,SHR,"!D86YI96QC
M($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]$0@H@*B\*"FEF("@A9&5F:6YE9"@G4$%42%]315!!4D%43U(G*2D@
M>PH@("`@:68@*'-T<FES='(H4$A07T]3+"`G5TE.)RDI('L*("`@("`@("`O
M*BH*("`@("`@("`@*B!4:&4@<W1R:6YG('5S960@=&\@9&5L:6UI="!E;&5M
M96YT<R!O9B!T:&4@<&%T:"X*("`@("`@("`@*B\*("`@("`@("!D969I;F4H
M)U!!5$A?4T5005)!5$]2)RP@)SLG*3L*("`@('T@96QS92!["B`@("`@("`@
M+RHJ"B`@("`@("`@("H@5&AE('-T<FEN9R!U<V5D('1O(&1E;&EM:70@96QE
M;65N=',@;V8@=&AE('!A=&@N"B`@("`@("`@("HO"B`@("`@("`@9&5F:6YE
M*"=0051(7U-%4$%2051/4B<L("<Z)RD["B`@("!]"GT*"B\J"B`J($EF('1H
M92!P871H('1O('EO=7(@4$5!4B!I;G-T86QL871I;VX@:7,@9F]U;F0@:6X@
M=&AE(&QE9G0@:&%N9`H@*B!P;W)T:6]N(&]F('1H92!I9B@I(&5X<')E<W-I
M;VX@8F5L;W<L('1H870@;65A;G,@=&AI<R!F:6QE(&AA<PH@*B!C;VUE(&9R
M;VT@=&AE(%!%05(@:6YS=&%L;&5R+B`@5&AE<F5F;W)E+"!L970G<R!U<V4@
M=&AE"B`J(&EN<W1A;&QE9"!V97)S:6]N(&]F($1"+"!W:&EC:"!S:&]U;&0@
M8F4@9F]U;F0@=FEA('1H90H@*B!C;VUP=71E<B=S(&1E9F%U;'0@:6YC;'5D
M95]P871H+B`@061D("<N)R!T;R!T:&4@:6YC;'5D95]P871H"B`J('1O(&5N
M<W5R92`G+B<@:7,@:6X@=&AE<F4N"B`J(`H@*B!)9B!T:&4@<&%T:"!H87,@
M;F]T(&)E96X@<W5B<W1I='5T960@:6X@=&AE(&EF*"D@97AP<F5S<VEO;BP*
M("H@=&AI<R!F:6QE(&AA<R!L:6ME;'D@8V]M92!F<F]M(&$@0U93(&-H96-K
M;W5T(&]R(&$@+G1A<B!F:6QE+@H@*B!4:&5R969O<F4L('=E)VQL(&%S<W5M
M92!T:&4@=&5S=',@<VAO=6QD('5S92!T:&4@=F5R<VEO;B!O9@H@*B!$0B!T
M:&%T(&AA<R!C;VUE(&9R;VT@=&AE<F4@87,@=V5L;"X*("HO"FEF("@G+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(G("$]("=`)RXG:6YC;'5D95]P
M871H)RXG0"<I('L*("`@(&EN:5]S970H)VEN8VQU9&5?<&%T:"<L(&EN:5]G
M970H)VEN8VQU9&5?<&%T:"<I"B`@("`@("`@("`@("X@4$%42%]315!!4D%4
M3U(@+B`G+B<*("`@("D["GT@96QS92!["B`@("!I;FE?<V5T*"=I;F-L=61E
M7W!A=&@G+"!R96%L<&%T:"AD:7)N86UE*%]?1DE,15]?*2`N("<O+BXO+BXG
M*0H@("`@("`@("`@("`N(%!!5$A?4T5005)!5$]2("X@)RXG("X@4$%42%]3
M15!!4D%43U(*("`@("`@("`@("`@+B!I;FE?9V5T*"=I;F-L=61E7W!A=&@G
M*0H@("`@*3L*?0H*+RHJ"B`J($=R86(@=&AE(%!%05(@1$(@8VQA<W-E<RX*
M("HO"G)E<75I<F5?;VYC92`G1$(N<&AP)SL*"B\O($]P=&EO;G,@=7-E9"!W
M:&5N(&-O;FYE8W1I;F<*)&]P=&EO;G,@/2!A<G)A>2@*("`@("\O)V]P=&EM
M:7IE)R`]/B`G<&]R=&%B:6QI='DG+`H@("`@)W!O<G1A8FEL:71Y)R`]/B!$
M0E]03U)404))3$E465]!3$PL"B`@("`G9&5B=6<G(#T^(#(L"BD["@HD9&)A
M<V5D<VX@/2!A<G)A>2@*("`@("=P:'!T>7!E)R`@/3X@)V1B87-E)RP*("`@
M("=D871A8F%S92<@/3X@)R]P871H+V%N9"]N86UE+V]F+V1B87-E+V9I;&4G
M+`H@("`@)VUO9&4G("`@("`]/B`R+`H@("`@)V9I96QD<R<@("`]/B!A<G)A
M>2@*("`@("`@("!A<G)A>2@G82<L("=.)RP@-2P@,"DL"B`@("`@("`@87)R
M87DH)V(G+"`G0R<L(#0P*2P*("`@("`@("!A<G)A>2@G8R<L("=#)RP@,C4U
M*2P*("`@("`@("!A<G)A>2@G9"<L("=#)RP@,C`I+`H@("`@*2P**3L*"B\J
M"B`J(%5N8V]M;65N="!A="!L96%S="!O;F4@;V8@=&AE(&9O;&QO=VEN9R!E
M;&5M96YT<RX*("H@5VAE;B!R=6YN:6YG('1H92`N<&AP="!T97-T<RP@=&AE
M(&9I<G-T('5N8V]M;65N=&5D(&5L96UE;G0@:7,@=7-E9"X*("H@5VAE;B!R
M=6YN:6YG('1H92!M=6QT:6-O;FYE8W0N<&AP('1E<W0L(&%L;"!U;F-O;6UE
M;G1E9"!E;&5M96YT<R!A<F4@=7-E9"X*("HO"B1D<VYS(#T@87)R87DH"B`@
M("`O+R`G9&)A<V4G("`@(#T^("1D8F%S961S;BP*("`@("\O("=F8G-Q;"<@
M("`@/3X@)V9B<W%L.B\O7W-Y<W1E;3I`+V1B)RP*("`@("\O("=F:7)E8FER
M9"<@/3X@)VEB87-E*&9I<F5B:7)D*3HO+U-94T1"03IM87-T97)K97E`+R]O
M<'0O:6YT97)B87-E+V5X86UP;&5S+V5M<&QO>65E+F=D8C]D:6%L96-T/3,G
M+`H@("`@+R\@)VEF>"<@("`@("`]/B`G:69X.B\O=7-E<CIP=T!L;V-A;&AO
M<W0O9&(G+`H@("`@+R\@)VUS<6PG("`@("`]/B`G;7-Q;#HO+R]D8B<L"@H@
M("`@+R\@270G<R!A9'9I<V%B;&4@=&\@=7-E(&]N;'D@;VYE(&]F('1H92!F
M;VQL;W=I;F<@870@82!T:6UE.@H@("`@+R\@)VUS<W%L)R`@("`]/B`G;7-S
M<6PZ+R]S84!S;VUE:&]S="]P=6)S)RP*("`@("\O("=S>6)A<V4G("`@/3X@
M)W-Y8F%S93HO+W-A0'-O;65H;W-T+W!U8G,G+`H*("`@("\O("=M>7-Q;"<@
M("`@/3X@)VUY<W%L.B\O<F]O=$!L;V-A;&AO<W0O=&5S="<L"B`@("`O+R`G
M;7ES<6QI)R`@(#T^("=M>7-Q;&DZ+R]R;V]T0&QO8V%L:&]S="]T97-T)RP*
M("`@("\O("=O8VDX)R`@("`@/3X@)V]C:3@Z+R]S>7-T96TZ;6%N86=E<D`G
M+`H@("`@+R\@)V%C8V5S<R<@("`]/B`G;V1B8RAA8V-E<W,I.B\O861M:6Y`
M+U-Y<W1E;41S;DYA;64G+`H@("`@+R\@)V1B,B<@("`@("`]/B`G;V1B8RAD
M8C(I.B\O9&(R:6YS=#$Z6%A86$`O4T%-4$Q%)RP*("`@("\O("=P9W-Q;"<@
M("`@/3X@)W!G<W%L.B\O<&]S=&=R97-`;&]C86QH;W-T+W1E<W0G+`H@("`@
M+R\@)W-Q;&ET92<@("`]/B`G<W%L:71E.B\O9'5M;7DZ0&QO8V%L:&]S="\G
M("X@9V5T8W=D*"D@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)W1E<W0N9&(_
M;6]D93TP-C0T)RP**3L*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B]S971U<"YI;F,N8W9S
M+F]R:6<``````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`W-38R`#$P-3$U-#,S-S0Q`#`R-C(V-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`H*+RHJ"B`J($5S=&%B;&ES:&5S('1H92!I;F-L=61E7W!A=&@L($133B=S
M(&%N9"!C;VYN96-T:6]N("1O<'1I;VYS"B`J"B`J($EF('1H:7,@9FEL92!I
M<R!N86UE9"`B<V5T=7`N:6YC+F-V<RPB(&ET(&ES('1H92!O<FEG:6YA;"!O
M;F4@9G)O;2!#5E,N"B`J(%!L96%S92!D;R!T:&4@9F]L;&]W:6YG.@H@*B`@
M(#$I($UA:V4@82!C;W!Y(&]F('1H:7,@9FEL92!N86UE9"`B<V5T=7`N:6YC
M(BX*("H@("`R*2!4:&5N+"!I;B!T:&4@8V]P>2P@961I="!T:&4@)&1S;G,@
M87)R87D@87,@87!P<F]P<FEA=&4@9F]R('EO=7(*("H@("`@("!E;G9I<F]N
M;65N="X*("H@("`S*2!!="!L96%S="!O;F4@96QE;65N="!O9B!T:&4@)&1S
M;G,@87)R87D@;F5E9',@=&\@8F4@=6YC;VUM96YT960N"B`J"B`J(%!(4"!V
M97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I
M;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N
M<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED
M92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E
M(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@
M=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@
M82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S
M90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!$86YI96P@0V]N
M=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M
M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`
M=F5R<VEO;B`@("`D260Z('-E='5P+FEN8RYC=G,L=B`Q+C8@,C`P-2\P,B\Q
M-"`R,SHS,SHR,"!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*"FEF("@A9&5F:6YE9"@G
M4$%42%]315!!4D%43U(G*2D@>PH@("`@:68@*'-T<FES='(H4$A07T]3+"`G
M5TE.)RDI('L*("`@("`@("`O*BH*("`@("`@("`@*B!4:&4@<W1R:6YG('5S
M960@=&\@9&5L:6UI="!E;&5M96YT<R!O9B!T:&4@<&%T:"X*("`@("`@("`@
M*B\*("`@("`@("!D969I;F4H)U!!5$A?4T5005)!5$]2)RP@)SLG*3L*("`@
M('T@96QS92!["B`@("`@("`@+RHJ"B`@("`@("`@("H@5&AE('-T<FEN9R!U
M<V5D('1O(&1E;&EM:70@96QE;65N=',@;V8@=&AE('!A=&@N"B`@("`@("`@
M("HO"B`@("`@("`@9&5F:6YE*"=0051(7U-%4$%2051/4B<L("<Z)RD["B`@
M("!]"GT*"B\J"B`J($EF('1H92!P871H('1O('EO=7(@4$5!4B!I;G-T86QL
M871I;VX@:7,@9F]U;F0@:6X@=&AE(&QE9G0@:&%N9`H@*B!P;W)T:6]N(&]F
M('1H92!I9B@I(&5X<')E<W-I;VX@8F5L;W<L('1H870@;65A;G,@=&AI<R!F
M:6QE(&AA<PH@*B!C;VUE(&9R;VT@=&AE(%!%05(@:6YS=&%L;&5R+B`@5&AE
M<F5F;W)E+"!L970G<R!U<V4@=&AE"B`J(&EN<W1A;&QE9"!V97)S:6]N(&]F
M($1"+"!W:&EC:"!S:&]U;&0@8F4@9F]U;F0@=FEA('1H90H@*B!C;VUP=71E
M<B=S(&1E9F%U;'0@:6YC;'5D95]P871H+B`@061D("<N)R!T;R!T:&4@:6YC
M;'5D95]P871H"B`J('1O(&5N<W5R92`G+B<@:7,@:6X@=&AE<F4N"B`J(`H@
M*B!)9B!T:&4@<&%T:"!H87,@;F]T(&)E96X@<W5B<W1I='5T960@:6X@=&AE
M(&EF*"D@97AP<F5S<VEO;BP*("H@=&AI<R!F:6QE(&AA<R!L:6ME;'D@8V]M
M92!F<F]M(&$@0U93(&-H96-K;W5T(&]R(&$@+G1A<B!F:6QE+@H@*B!4:&5R
M969O<F4L('=E)VQL(&%S<W5M92!T:&4@=&5S=',@<VAO=6QD('5S92!T:&4@
M=F5R<VEO;B!O9@H@*B!$0B!T:&%T(&AA<R!C;VUE(&9R;VT@=&AE<F4@87,@
M=V5L;"X*("HO"FEF("@G+VAO;64O;'5C97(O=V]R:R]P96%R+W-H87)E+W!H
M<"<@(3T@)T`G+B=I;F-L=61E7W!A=&@G+B=`)RD@>PH@("`@:6YI7W-E="@G
M:6YC;'5D95]P871H)RP@:6YI7V=E="@G:6YC;'5D95]P871H)RD*("`@("`@
M("`@("`@+B!0051(7U-%4$%2051/4B`N("<N)PH@("`@*3L*?2!E;'-E('L*
M("`@(&EN:5]S970H)VEN8VQU9&5?<&%T:"<L(')E86QP871H*&1I<FYA;64H
M7U]&24Q%7U\I("X@)R\N+B\N+B<I"B`@("`@("`@("`@("X@4$%42%]315!!
M4D%43U(@+B`G+B<@+B!0051(7U-%4$%2051/4@H@("`@("`@("`@("`N(&EN
M:5]G970H)VEN8VQU9&5?<&%T:"<I"B`@("`I.PI]"@HO*BH*("H@1W)A8B!T
M:&4@4$5!4B!$0B!C;&%S<V5S+@H@*B\*<F5Q=6ER95]O;F-E("=$0BYP:'`G
M.PH*+R\@3W!T:6]N<R!U<V5D('=H96X@8V]N;F5C=&EN9PHD;W!T:6]N<R`]
M(&%R<F%Y*`H@("`@+R\G;W!T:6UI>F4G(#T^("=P;W)T86)I;&ET>2<L"B`@
M("`G<&]R=&%B:6QI='DG(#T^($1"7U!/4E1!0DE,25197T%,3"P*("`@("=D
M96)U9R<@/3X@,BP**3L*"B1D8F%S961S;B`](&%R<F%Y*`H@("`@)W!H<'1Y
M<&4G("`]/B`G9&)A<V4G+`H@("`@)V1A=&%B87-E)R`]/B`G+W!A=&@O86YD
M+VYA;64O;V8O9&)A<V4O9FEL92<L"B`@("`G;6]D92<@("`@(#T^(#(L"B`@
M("`G9FEE;&1S)R`@(#T^(&%R<F%Y*`H@("`@("`@(&%R<F%Y*"=A)RP@)TXG
M+"`U+"`P*2P*("`@("`@("!A<G)A>2@G8B<L("=#)RP@-#`I+`H@("`@("`@
M(&%R<F%Y*"=C)RP@)T,G+"`R-34I+`H@("`@("`@(&%R<F%Y*"=D)RP@)T,G
M+"`R,"DL"B`@("`I+`HI.PH*+RH*("H@56YC;VUM96YT(&%T(&QE87-T(&]N
M92!O9B!T:&4@9F]L;&]W:6YG(&5L96UE;G1S+@H@*B!7:&5N(')U;FYI;F<@
M=&AE("YP:'!T('1E<W1S+"!T:&4@9FER<W0@=6YC;VUM96YT960@96QE;65N
M="!I<R!U<V5D+@H@*B!7:&5N(')U;FYI;F<@=&AE(&UU;'1I8V]N;F5C="YP
M:'`@=&5S="P@86QL('5N8V]M;65N=&5D(&5L96UE;G1S(&%R92!U<V5D+@H@
M*B\*)&1S;G,@/2!A<G)A>2@*("`@("\O("=D8F%S92<@("`@/3X@)&1B87-E
M9'-N+`H@("`@+R\@)V9B<W%L)R`@("`]/B`G9F)S<6PZ+R]?<WES=&5M.D`O
M9&(G+`H@("`@+R\@)V9I<F5B:7)D)R`]/B`G:6)A<V4H9FER96)I<F0I.B\O
M4UE31$)!.FUA<W1E<FME>4`O+V]P="]I;G1E<F)A<V4O97AA;7!L97,O96UP
M;&]Y964N9V1B/V1I86QE8W0],R<L"B`@("`O+R`G:69X)R`@("`@(#T^("=I
M9G@Z+R]U<V5R.G!W0&QO8V%L:&]S="]D8B<L"B`@("`O+R`G;7-Q;"<@("`@
M(#T^("=M<W%L.B\O+V1B)RP*"B`@("`O+R!)="=S(&%D=FES86)L92!T;R!U
M<V4@;VYL>2!O;F4@;V8@=&AE(&9O;&QO=VEN9R!A="!A('1I;64Z"B`@("`O
M+R`G;7-S<6PG("`@(#T^("=M<W-Q;#HO+W-A0'-O;65H;W-T+W!U8G,G+`H@
M("`@+R\@)W-Y8F%S92<@("`]/B`G<WEB87-E.B\O<V%`<V]M96AO<W0O<'5B
M<R<L"@H@("`@+R\@)VUY<W%L)R`@("`]/B`G;7ES<6PZ+R]R;V]T0&QO8V%L
M:&]S="]T97-T)RP*("`@("\O("=M>7-Q;&DG("`@/3X@)VUY<W%L:3HO+W)O
M;W1`;&]C86QH;W-T+W1E<W0G+`H@("`@+R\@)V]C:3@G("`@("`]/B`G;V-I
M.#HO+W-Y<W1E;3IM86YA9V5R0"<L"B`@("`O+R`G86-C97-S)R`@(#T^("=O
M9&)C*&%C8V5S<RDZ+R]A9&UI;D`O4WES=&5M1'-N3F%M92<L"B`@("`O+R`G
M9&(R)R`@("`@(#T^("=O9&)C*&1B,BDZ+R]D8C)I;G-T,3I86%A80"]304U0
M3$4G+`H@("`@+R\@)W!G<W%L)R`@("`]/B`G<&=S<6PZ+R]P;W-T9W)E<T!L
M;V-A;&AO<W0O=&5S="<L"B`@("`O+R`G<W%L:71E)R`@(#T^("=S<6QI=&4Z
M+R]D=6UM>3I`;&]C86QH;W-T+R<@+B!G971C=V0H*2`N($1)4D5#5$]265]3
M15!!4D%43U(@+B`G=&5S="YD8C]M;V1E/3`V-#0G+`HI.PH`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R
M:79E<B]S:VEP:68N:6YC````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,3(V`#$P
M-3$U-#,S-S0Q`#`R-#8T-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*+RHJ"B`J($$@=&5S="!T;R!M86ME('-U
M<F4@=&AE(&1A=&%B87-E(&-A;B!B92!C;VYN96-T960@=&\*("H*("H@4$A0
M('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@
M9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC
M96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L
M92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N
M9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO
M=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@($1A=&%B
M87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@($1A;FEE;"!#
M;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY
M-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J
M($!V97)S:6]N("`@("1)9#H@<VMI<&EF+FEN8RQV(#$N-R`R,#`U+S`R+S`R
M(#`P.C0P.C(S(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*+RHJ"B`J($5S=&%B;&ES
M:"!T:&4@:6YC;'5D95]P871H+"!$4TXG<R!A;F0@8V]N;F5C=&EO;B`D;W!T
M:6]N<PH@*B\*<F5Q=6ER95]O;F-E("<N+W-E='5P+FEN8R<["@II9B`H96UP
M='DH)&1S;G,I*2!["B`@("!D:64H)W-K:7`@070@;&5A<W0@;VYE(&5L96UE
M;G0@;V8@)&1S;G,@;75S="!B92!D969I;F5D(&EN('-E='5P+FEN8R<I.PI]
M"@IL:7-T*"1D8FUS+"`D9'-N*2`](&5A8V@H)&1S;G,I.PH*)&1B:"`])B!$
M0CHZ8V]N;F5C="@D9'-N+"`D;W!T:6]N<RD["FEF("A$0CHZ:7-%<G)O<B@D
M9&)H*2D@>PH@("`@9&EE*"=S:VEP("<@+B`D9&)H+3YM97-S86=E*3L*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O=&5S=',O1$(O=&5S=',O97)R;W)S+FEN8P``````````````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,S,V,30`,3`U,34T,S,W-#$`,#(S-#$Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@HO
M*BH*("H@5&5S=',@=&AE(&1R:79E<G,G(&5R<F]R(&UA<'!I;F<*("H*("H@
M17AE8W5T960@8GD@9')I=F5R+S$P97)R;W)M87`N<&AP=`H@*@H@*B!02%`@
M=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F
M:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E
M;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV
M92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE
M('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90H@*B!S96YD
M(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U
M(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A
M<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@1&%N:65L($-O
M;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW
M+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@
M0'9E<G-I;VX@("`@)$ED.B!E<G)O<G,N:6YC+'8@,2XS-2`R,#`U+S`R+S(X
M(#`R.C`R.C0Q(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*+RHJ"B`J($1E=&5R;6EN
M92!I9B!T:&4@97)R;W(@9G)O;2!T:&4@9')I=F5R(&UA=&-H97,@=&AE(&5R
M<F]R('=E(&5X<&5C=`H@*@H@*B!)9B!T:&EN9W,@87)E(&%S('=E(&5X<&5C
M="P@<')I;G0@;W5T(")M871C:&5S(&5X<&5C=&5D(&]U=&-O;64B"B`J"B`J
M($EF('1H:6YG<R!G;R!W<F]N9RP@<')I;G0@(E5.15A014-4140@3U540T]-
M12(@86YD(&1I<W!L87D@=&AE"B`J(&5R<F]R)W,@:6YF;W)M871I;VXN"B`J
M"B`J($!P87)A;2!O8FIE8W0@("1E("`@("`@("`@("`@("`@("!T:&4@1$)?
M17)R;W(@;V)J96-T(&9R;VT@=&AE('%U97)Y"B`J($!P87)A;2!I;G0@("`@
M("1E>'!E8W1E9%]D8E]C;V1E("!T:&4@1$)?15)23U(J(&-O;G-T86YT('1O
M(&5X<&5C=`H@*B!`<&%R86T@8F]O;&5A;B`D<VAO=6QD7V)E7V5R<F]R("`@
M9&]E<R!T:&4@1$)-4R!C;VYS:61E<B!T:&ES(&%N(&5R<F]R/PH@*@H@*B!`
M<F5T=7)N('9O:60*("HO"F9U;F-T:6]N(&-H96-K7V5R<F]R*"1E+"`D97AP
M96-T961?9&)?8V]D92P@)'-H;W5L9%]B95]E<G)O<B`]('1R=64I('L*("`@
M(&EF("@D<VAO=6QD7V)E7V5R<F]R*2!["B`@("`@("`@:68@*$1".CII<T5R
M<F]R*"1E*2D@>PH@("`@("`@("`@("!I9B`H)&4M/F=E=$-O9&4H*2`]/2`D
M97AP96-T961?9&)?8V]D92D@>PH@("`@("`@("`@("`@("`@<')I;G0@(FUA
M=&-H97,@97AP96-T960@;W5T8V]M95QN(CL*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@('!R:6YT(")53D584$5#5$5$($]55$-/344N
M+BY<;B(["B`@("`@("`@("`@("`@("!P<FEN="`G("`@(%!%05(Z.D1"(&5R
M<F]R8V]D93H@)R`N("1E+3YG971#;V1E*"D@+B`B7&XB.PH@("`@("`@("`@
M("`@("`@<')I;G0@)R`@("`G("X@)&4M/F=E=%5S97));F9O*"D@+B`B7&XB
M.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<')I;G0@(EQN("`@(%5.15A014-4140@3U540T]-12XN+B!E>'!E8W1E9"!E
M<G)O<B!B=70@:70@=V%S;B=T7&XB.PH@("`@("`@('T*("`@('T@96QS92![
M"B`@("`@("`@:68@*$1".CII<T5R<F]R*"1E*2D@>PH@("`@("`@("`@("!P
M<FEN="`B54Y%6%!%0U1%1"!/551#3TU%+BXN(&1I9&XG="!E>'!E8W0@97)R
M;W(@8G5T(&ET('=A<UQN(CL*("`@("`@("`@("`@<')I;G0@)R`@("!014%2
M.CI$0B!E<G)O<F-O9&4Z("<@+B`D92T^9V5T0V]D92@I("X@(EQN(CL*("`@
M("`@("`@("`@<')I;G0@)R`@("`G("X@)&4M/F=E=%5S97));F9O*"D@+B`B
M7&XB.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('!R:6YT(")M871C
M:&5S(&5X<&5C=&5D(&]U=&-O;65<;B(["B`@("`@("`@?0H@("`@?0I]"@HO
M*BH*("H@3&]C86P@97)R;W(@8V%L;&)A8VL@:&%N9&QE<@H@*B`*("H@0'!A
M<F%M(&]B:F5C="`@)&\@(%!%05(@97)R;W(@;V)J96-T(&%U=&]M871I8V%L
M;'D@<&%S<V5D('1O('1H:7,@;65T:&]D"B`J($!R971U<FX@=F]I9`H@*B!`
M<V5E(%!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H*0H@*B\*9G5N8W1I;VX@<&4H
M)&\I('L*("`@('!R:6YT(")<;BTM+2TM+2TM+2TM+2TM+5QN(CL*("`@('!R
M:6YT(")(879I;F<@<')O8FQE;7,@8W)E871I;F<@82!T86)L92!F;W(@=&5S
M=&EN9RXN+EQN(CL*("`@('!R:6YT("1O+3YG971$96)U9TEN9F\H*2`N(")<
M;B(["B`@("!P<FEN="`B+2TM+2TM+2TM+2TM+2TM7&XB.PI]"@H*)&1B:"T^
M<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["@H*<')I;G0@
M)T1"7T524D]27TY/4U5#2%1!0DQ%(&9O<B!S96QE8W0Z("`G.PHD<F5S(#T@
M)&1B:"T^<75E<GDH)U-%3$5#5"`J($923TT@=&%B;&54:&%T<T)O9W5S)RD[
M"F-H96-K7V5R<F]R*"1R97,L($1"7T524D]27TY/4U5#2%1!0DQ%*3L*"G!R
M:6YT("=$0E]%4E)/4E].3U-50TA404),12!F;W(@9')O<#H@("<["B1R97,@
M/2!D<F]P7W1A8FQE*"1D8F@L("=T86)L951H871S0F]G=7,G*3L*8VAE8VM?
M97)R;W(H)')E<RP@1$)?15)23U)?3D]354-(5$%"3$4I.PH*<')I;G0@)T1"
M7T524D]27TY/5%]&3U5.1"!F;W(@9')O<"!I;F1E>#H@("<["G-W:71C:"`H
M)&1B:"T^<&AP='EP92`N("<Z)R`N("1D8F@M/F1B<WEN=&%X*2!["B`@("!C
M87-E("=F8G-Q;#IF8G-Q;"<Z"B`@("!C87-E("=I8F%S93IF:7)E8FER9"<Z
M"B`@("!C87-E("=I8F%S93II8F%S92<Z"B`@("!C87-E("=I9G@Z:69X)SH*
M("`@(&-A<V4@)V]D8F,Z9&(R)SH*("`@(&-A<V4@)V]C:3@Z;V-I."<Z"B`@
M("!C87-E("=P9W-Q;#IP9W-Q;"<Z"B`@("!C87-E("=S<6QI=&4Z<W%L:71E
M)SH*("`@("`@("`D<F5S(#T@)&1B:"T^<75E<GDH)T123U`@24Y$15@@9F%K
M96EN9&5X)RD["B`@("`@("`@8G)E86L["B`@("!C87-E("=M<W-Q;#IM<W-Q
M;"<Z"B`@("!C87-E("=S>6)A<V4Z<WEB87-E)SH*("`@("`@("`D<F5S(#T@
M)&1B:"T^<75E<GDH)T123U`@24Y$15@@<&AP=&5S="YF86ME:6YD97@G*3L*
M("`@("`@("!B<F5A:SL*("`@(&-A<V4@)VUS<6PZ;7-Q;"<Z"B`@("`@("`@
M)')E<R`]("1D8F@M/G%U97)Y*"=$4D]0($E.1$58(&9A:V5I;F1E>"!&4D]-
M('!H<'1E<W0G*3L*("`@("`@("!B<F5A:SL*("`@(&1E9F%U;'0Z"B`@("`@
M("`@)')E<R`]("1D8F@M/G%U97)Y*"=$4D]0($E.1$58(&9A:V5I;F1E>"!/
M3B!P:'!T97-T)RD["GT*8VAE8VM?97)R;W(H)')E<RP@1$)?15)23U)?3D]4
M7T9/54Y$*3L*"@IP<FEN="`G1$)?15)23U)?04Q214%$65]%6$E35%,@9F]R
M(&-R96%T92!T86)L93H@("<["B1R97,@/2`D9&)H+3YQ=65R>2@D=&5S=%]M
M:W1A8FQE7W%U97)Y*3L*8VAE8VM?97)R;W(H)')E<RP@1$)?15)23U)?04Q2
M14%$65]%6$E35%,I.PH*<')I;G0@)T1"7T524D]27T%,4D5!1%E?15A)4U13
M(&9O<B!C<F5A=&4@:6YD97@Z("`G.PHD<F5S(#T@9')O<%]T86)L92@D9&)H
M+"`G82<I.PHD9&)H+3YP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27T-!
M3$Q"04-++"`G<&4G*3L*)')E<R`]("1D8F@M/G%U97)Y*"=#4D5!5$4@5$%"
M3$4@82`H82!)3E1%1T52*2<I.PHD9&)H+3YP;W!%<G)O<DAA;F1L:6YG*"D[
M"B1R97,@/2`D9&)H+3YQ=65R>2@G0U)%051%($E.1$58(&%A7VED>"!/3B!A
M("AA*2<I.PHD<F5S(#T@)&1B:"T^<75E<GDH)T-214%412!)3D1%6"!A85]I
M9'@@3TX@82`H82DG*3L*<W=I=&-H("@D9&)H+3YP:'!T>7!E*2!["B`@("!C
M87-E("=F8G-Q;"<Z"B`@("`@("`@+R\@1G)O;G1"87-E(&1O97-N)W0@87-S
M:6=N(&$@<W!E8VEF:6,@8V]D92!F;W(@=&AI<R!Y970N"B`@("`@("`@8VAE
M8VM?97)R;W(H)')E<RP@1$)?15)23U)?04Q214%$65]%6$E35%,L(&9A;'-E
M*3L*("`@("`@("!B<F5A:SL*("`@(&1E9F%U;'0Z"B`@("`@("`@8VAE8VM?
M97)R;W(H)')E<RP@1$)?15)23U)?04Q214%$65]%6$E35%,I.PI]"B1R97,@
M/2!D<F]P7W1A8FQE*"1D8F@L("=A)RD["@H*<')I;G0@)T1"7T524D]27T-/
M3E-44D%)3E0@9F]R('!R:6UA<GD@:V5Y(&EN<V5R="!D=7!L:6-A=&4Z("`G
M.PHD<F5S(#T@9')O<%]T86)L92@D9&)H+"`G82<I.PHD9&)H+3YP=7-H17)R
M;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"04-++"`G<&4G*3L*<W=I=&-H
M("@D9&)H+3YP:'!T>7!E*2!["B`@("!C87-E("=M<W%L)SH*("`@("`@("`D
M<F5S(#T@)&1B:"T^<75E<GDH)T-214%412!404),12!A("AA($E.5$5'15(@
M3D]4($Y53$PI)RD["B`@("`@("`@)')E<R`]("1D8F@M/G%U97)Y*"=#4D5!
M5$4@54Y)455%($E.1$58(&%P:R!/3B!A("AA*2<I.PH@("`@("`@(&)R96%K
M.PH@("`@9&5F875L=#H*("`@("`@("`D<F5S(#T@)&1B:"T^<75E<GDH)T-2
M14%412!404),12!A("AA($E.5$5'15(@3D]4($Y53$PL(%!224U!4ED@2T59
M("AA*2DG*3L*?0HD9&)H+3YP;W!%<G)O<DAA;F1L:6YG*"D["B1R97,@/2`D
M9&)H+3YQ=65R>2@G24Y315)4($E.5$\@82!604Q515,@*#$I)RD["B1R97,@
M/2`D9&)H+3YQ=65R>2@G24Y315)4($E.5$\@82!604Q515,@*#$I)RD["F-H
M96-K7V5R<F]R*"1R97,L($1"7T524D]27T-/3E-44D%)3E0I.PH*"G!R:6YT
M("=$0E]%4E)/4E]#3TY35%)!24Y4(&9O<B!P<FEM87)Y(&ME>2!U<&1A=&4@
M9'5P;&EC871E.B`@)SL*)')E<R`]("1D8F@M/G%U97)Y*"=)3E-%4E0@24Y4
M3R!A(%9!3%5%4R`H,BDG*3L*)')E<R`]("1D8F@M/G%U97)Y*"=54$1!5$4@
M82!3150@83TQ(%=(15)%(&$],B<I.PIC:&5C:U]E<G)O<B@D<F5S+"!$0E]%
M4E)/4E]#3TY35%)!24Y4*3L*"@IP<FEN="`G1$)?15)23U)?0T].4U1204E.
M5"!F;W(@=6YI<75E(&ME>2!I;G-E<G0@9'5P;&EC871E.B`@)SL*)')E<R`]
M(&1R;W!?=&%B;&4H)&1B:"P@)V$G*3L*)&1B:"T^<'5S:$5R<F]R2&%N9&QI
M;F<H4$5!4E]%4E)/4E]#04Q,0D%#2RP@)W!E)RD["G-W:71C:"`H)&1B:"T^
M<&AP='EP92D@>PH@("`@8V%S92`G;7-Q;"<Z"B`@("`@("`@)')E<R`]("1D
M8F@M/G%U97)Y*"=#4D5!5$4@5$%"3$4@82`H82!)3E1%1T52($Y/5"!.54Q,
M*2<I.PH@("`@("`@("1R97,@/2`D9&)H+3YQ=65R>2@G0U)%051%(%5.25%5
M12!)3D1%6"!A=6L@3TX@82`H82DG*3L*("`@("`@("!B<F5A:SL*("`@(&1E
M9F%U;'0Z"B`@("`@("`@)')E<R`]("1D8F@M/G%U97)Y*"=#4D5!5$4@5$%"
M3$4@82`H82!)3E1%1T52($Y/5"!.54Q,+"!53DE1544@*&$I*2<I.PI]"B1D
M8F@M/G!O<$5R<F]R2&%N9&QI;F<H*3L*)')E<R`]("1D8F@M/G%U97)Y*"=)
M3E-%4E0@24Y43R!A(%9!3%5%4R`H,2DG*3L*)')E<R`]("1D8F@M/G%U97)Y
M*"=)3E-%4E0@24Y43R!A(%9!3%5%4R`H,2DG*3L*8VAE8VM?97)R;W(H)')E
M<RP@1$)?15)23U)?0T].4U1204E.5"D["@H*<')I;G0@)T1"7T524D]27T-/
M3E-44D%)3E0@9F]R('5N:7%U92!K97D@=7!D871E(&1U<&QI8V%T93H@("<[
M"B1R97,@/2`D9&)H+3YQ=65R>2@G24Y315)4($E.5$\@82!604Q515,@*#(I
M)RD["B1R97,@/2`D9&)H+3YQ=65R>2@G55!$051%(&$@4T54(&$],2!72$52
M12!A/3(G*3L*8VAE8VM?97)R;W(H)')E<RP@1$)?15)23U)?0T].4U1204E.
M5"D["@H*<')I;G0@)T1"7T524D]27T-/3E-44D%)3E0@9F]R(&9O<F5I9VX@
M:V5Y(&]N(&EN<V5R=#H@("<["B1R97,@/2!D<F]P7W1A8FQE*"1D8F@L("=B
M)RD["B1R97,@/2!D<F]P7W1A8FQE*"1D8F@L("=A)RD["B1D8F@M/G!U<VA%
M<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL("=P92<I.PIS=VET
M8V@@*"1D8F@M/G!H<'1Y<&4I('L*("`@(&-A<V4@)VUY<W%L)SH*("`@(&-A
M<V4@)VUY<W%L:2<Z"B`@("`@("`@)')E<R`]("1D8F@M/G%U97)Y*"=#4D5!
M5$4@5$%"3$4@82`H82!)3E0@3D]4($Y53$PL("<*("`@("`@("`@("`@("`@
M("`@("`N("=04DE-05)9($M%62`H82DI("<*("`@("`@("`@("`@("`@("`@
M("`N("=465!%/4E.3D]$0B<I.PH@("`@("`@("1R97,@/2`D9&)H+3YQ=65R
M>2@G0U)%051%(%1!0DQ%(&(@*&(@24Y4+"`G"B`@("`@("`@("`@("`@("`@
M("`@+B`G24Y$15@@<&%R7VEN9"`H8BDL("<*("`@("`@("`@("`@("`@("`@
M("`N("=&3U)%24=.($M%62`H8BD@4D5&15)%3D-%4R!A("AA*2D@)PH@("`@
M("`@("`@("`@("`@("`@("X@)U194$4]24Y.3T1")RD["B`@("`@("`@)&1B
M:"T^<&]P17)R;W)(86YD;&EN9R@I.PH@("`@("`@(&)R96%K.PH*("`@(&-A
M<V4@)VUS<6PG.@H@("`@("`@("\O(&US<6P@9&]E<R!N;W0@<W5P<&]R="!F
M;W)E:6=N(&ME>7,*("`@("`@("`D<F5S(#T@)&1B:"T^<75E<GDH)T-214%4
M12!404),12!A("AA($E.5$5'15(@3D]4($Y53$PI)RD["B`@("`@("`@)')E
M<R`]("1D8F@M/G%U97)Y*"=#4D5!5$4@54Y)455%($E.1$58(&%U:R!/3B!A
M("AA*2<I.PH@("`@("`@("1D8F@M/G!O<$5R<F]R2&%N9&QI;F<H*3L*("`@
M("`@("`D<F5S(#T@)&1B:"T^<75E<GDH)T-214%412!404),12!B("AB($E.
M5$5'15(@4D5&15)%3D-%4R!A("AA*2DG*3L*("`@("`@("!I9B`H1$(Z.FES
M17)R;W(H)')E<RDI('L*("`@("`@("`@("`@<')I;G0@(FUA=&-H97,@97AP
M96-T960@;W5T8V]M95QN(CL*("`@("`@("`@("`@<')I;G0@(D1"7T524D]2
M7T-/3E-44D%)3E0@9F]R(&9O<F5I9VX@:V5Y(&]N(&1E;&5T93H@(&UA=&-H
M97,@97AP96-T960@;W5T8V]M95QN(CL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!P<FEN="`B5T]7+"!I="!S965M<R!M4U%,(&YO=R!S=7!P;W)T
M<R!R969E<F5N8V5S7&XB.PH@("`@("`@("`@("!P<FEN="`B5T]7+"!I="!S
M965M<R!M4U%,(&YO=R!S=7!P;W)T<R!R969E<F5N8V5S7&XB.PH@("`@("`@
M('T*("`@("`@("!B<F5A:SL*"B`@("!D969A=6QT.@H@("`@("`@("1R97,@
M/2`D9&)H+3YQ=65R>2@G0U)%051%(%1!0DQ%(&$@*&$@24Y414=%4B!.3U0@
M3E5,3"P@4%))34%262!+15D@*&$I*2<I.PH@("`@("`@("1R97,@/2`D9&)H
M+3YQ=65R>2@G0U)%051%(%1!0DQ%(&(@*&(@24Y414=%4B!2149%4D5.0T53
M(&$@*&$I*2<I.PH@("`@("`@("1D8F@M/G!O<$5R<F]R2&%N9&QI;F<H*3L*
M?0H*:68@*"1D8F@M/G!H<'1Y<&4@(3T@)VUS<6PG*2!["B`@("`D<F5S(#T@
M)&1B:"T^<75E<GDH)TE.4T525"!)3E1/(&$@*&$I('9A;'5E<R`H,2DG*3L*
M("`@("1R97,@/2`D9&)H+3YQ=65R>2@G24Y315)4($E.5$\@8B`H8BD@=F%L
M=65S("@R*2<I.PH@("`@<W=I=&-H("@D9&)H+3YP:'!T>7!E*2!["B`@("`@
M("`@8V%S92`G<W%L:71E)SH*("`@("`@("`@("`@8VAE8VM?97)R;W(H)')E
M<RP@1$)?15)23U)?0T].4U1204E.5"P@9F%L<V4I.PH@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!C:&5C:U]E<G)O
M<B@D<F5S+"!$0E]%4E)/4E]#3TY35%)!24Y4*3L*("`@('T@("`*"B`@("!P
M<FEN="`G1$)?15)23U)?0T].4U1204E.5"!F;W(@9F]R96EG;B!K97D@;VX@
M9&5L971E.B`@)SL*("`@("1R97,@/2`D9&)H+3YQ=65R>2@G24Y315)4($E.
M5$\@8B`H8BD@=F%L=65S("@Q*2<I.PH@("`@)')E<R`]("1D8F@M/G%U97)Y
M*"=$14Q%5$4@1E)/32!A(%=(15)%(&$@/2`Q)RD["B`@("!S=VET8V@@*"1D
M8F@M/G!H<'1Y<&4I('L*("`@("`@("!C87-E("=S<6QI=&4G.@H@("`@("`@
M("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E]#3TY35%)!24Y4+"!F
M86QS92D["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&1E9F%U;'0Z"B`@
M("`@("`@("`@(&-H96-K7V5R<F]R*"1R97,L($1"7T524D]27T-/3E-44D%)
M3E0I.PH@("`@?0I]"@H*<')I;G0@)T1"7T524D]27T-/3E-44D%)3E1?3D]4
M7TY53$P@;VX@:6YS97)T.B`@)SL*)')E<R`](&1R;W!?=&%B;&4H)&1B:"P@
M)W!E87)T97-T;G5L;"<I.PHD9&)H+3YP=7-H17)R;W)(86YD;&EN9RA014%2
M7T524D]27T-!3$Q"04-++"`G<&4G*3L*)')E<R`]("1D8F@M/G%U97)Y*"=#
M4D5!5$4@5$%"3$4@<&5A<G1E<W1N=6QL("AA($-(05(H,RD@3D]4($Y53$PI
M)RD["B1D8F@M/G!O<$5R<F]R2&%N9&QI;F<H*3L*)')E<R`]("1D8F@M/G%U
M97)Y*"=)3E-%4E0@24Y43R!P96%R=&5S=&YU;&P@5D%,5453("A.54Q,*2<I
M.PIC:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E]#3TY35%)!24Y47TY/5%].
M54Q,*3L*"@IP<FEN="`G1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3"!O
M;B!U<&1A=&4Z("`G.PHD<F5S(#T@)&1B:"T^<75E<GDH(DE.4T525"!)3E1/
M('!E87)T97-T;G5L;"!604Q515,@*"=O;F4G*2(I.PHD<F5S(#T@)&1B:"T^
M<75E<GDH(E501$%412!P96%R=&5S=&YU;&P@4T54(&$@/2!.54Q,(%=(15)%
M(&$@/2`G;VYE)R(I.PIS=VET8V@@*"1D8F@M/G!H<'1Y<&4I('L*("`@(&-A
M<V4@)VUY<W%L)SH*("`@(&-A<V4@)VUY<W%L:2<Z"B`@("`@("`@8VAE8VM?
M97)R;W(H)')E<RP@1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3"P@9F%L
M<V4I.PH@("`@("`@(&)R96%K.PH@("`@9&5F875L=#H*("`@("`@("!C:&5C
M:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E]#3TY35%)!24Y47TY/5%].54Q,*3L*
M?0H*"G!R:6YT("=$0E]%4E)/4E].3U-50TA&245,1"!J;VEN:6YG($].(&)O
M9W5S(&-O;'5M;CH@("<["B1R97,@/2`D9&)H+3YQ=65R>2@G4T5,14-4("H@
M1E)/32!P:'!T97-T($I/24X@82!/3B`H<&AP=&5S="YA(#T@82YB*2<I.PIS
M=VET8V@@*"1D8F@M/G!H<'1Y<&4@+B`G.B<@+B`D9&)H+3YD8G-Y;G1A>"D@
M>PH@("`@8V%S92`G;7-Q;#IM<W%L)SH*("`@(&-A<V4@)V]D8F,Z86-C97-S
M)SH*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E]364Y405@I
M.PH@("`@("`@(&)R96%K.PH@("`@9&5F875L=#H*("`@("`@("!C:&5C:U]E
M<G)O<B@D<F5S+"!$0E]%4E)/4E].3U-50TA&245,1"D["GT*"@IP<FEN="`G
M1$)?15)23U)?3D]354-(1DE%3$0@:F]I;FEN9R!54TE.1R!B;V=U<R!C;VQU
M;6XZ("`G.PHD<F5S(#T@)&1B:"T^<75E<GDH)U-%3$5#5"`J($923TT@<&AP
M=&5S="!*3TE.(&$@55-)3D<@*&(I)RD["G-W:71C:"`H)&1B:"T^<&AP='EP
M92`N("<Z)R`N("1D8F@M/F1B<WEN=&%X*2!["B`@("!C87-E("=I8F%S93II
M8F%S92<Z"B`@("!C87-E("=I8F%S93IF:7)E8FER9"<Z"B`@("!C87-E("=M
M<W%L.FUS<6PG.@H@("`@8V%S92`G;V1B8SIA8V-E<W,G.@H@("`@8V%S92`G
M;V1B8SID8C(G.@H@("`@8V%S92`G<WEB87-E.G-Y8F%S92<Z"B`@("`@("`@
M8VAE8VM?97)R;W(H)')E<RP@1$)?15)23U)?4UE.5$%8*3L*("`@("`@("!B
M<F5A:SL*("`@(&1E9F%U;'0Z"B`@("`@("`@8VAE8VM?97)R;W(H)')E<RP@
M1$)?15)23U)?3D]354-(1DE%3$0I.PI]"@H*<')I;G0@)T1"7T524D]27T1)
M5EI%4D\Z("`G.PHO+R!);G1E<F)A<V4@9&5T96-T<R!T:&4@97)R;W(@;VX@
M9F5T8VAI;F<*)')E<R`]("1D8F@M/F=E=$%L;"@G4T5,14-4(#`O,"!&4D]-
M('!H<'1E<W0G*3L*<W=I=&-H("@D9&)H+3YP:'!T>7!E*2!["B`@("!C87-E
M("=O9&)C)SH*("`@("`@("!S=VET8V@@*"1D8F@M/F1B<WEN=&%X*2!["B`@
M("`@("`@("`@(&-A<V4@)V%C8V5S<R<Z"B`@("`@("`@("`@("`@("!C:&5C
M:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E]$259:15)/+"!F86QS92D["B`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G9&(R)SH*("`@
M("`@("`@("`@("`@(&-H96-K7V5R<F]R*"1R97,L($1"7T524D]27T1)5EI%
M4D\I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@("`@
M(&)R96%K.PH@("`@8V%S92`G:6)A<V4G.@H@("`@8V%S92`G:69X)SH*("`@
M(&-A<V4@)V9B<W%L)SH*("`@(&-A<V4@)VUS<W%L)SH*("`@(&-A<V4@)VUY
M<W%L)SH*("`@(&-A<V4@)VUY<W%L:2<Z"B`@("!C87-E("=S<6QI=&4G.@H@
M("`@8V%S92`G<WEB87-E)SH*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$
M0E]%4E)/4E]$259:15)/+"!F86QS92D["B`@("`@("`@8G)E86L["B`@("!C
M87-E("=M<W%L)SH*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/
M4E]364Y405@I.PH@("`@("`@(&)R96%K.PH@("`@9&5F875L=#H*("`@("`@
M("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E]$259:15)/*3L*?0H*"G!R
M:6YT("=$0E]%4E)/4E])3E9!3$E$7TY534)%4B!P=71T:6YG(&-H87)S(&EN
M($E.5"!C;VQU;6XZ("`G.PHD<F5S(#T@)&1B:"T^<75E<GDH(E501$%412!P
M:'!T97-T(%-%5"!A(#T@)V%B8R<@5TA%4D4@82`](#0R(BD["G-W:71C:"`H
M)&1B:"T^<&AP='EP92D@>PH@("`@8V%S92`G;7ES<6PG.@H@("`@8V%S92`G
M;7ES<6QI)SH*("`@(&-A<V4@)W-Q;&ET92<Z"B`@("`@("`@8VAE8VM?97)R
M;W(H)')E<RP@1$)?15)23U)?24Y604Q)1%].54U"15(L(&9A;'-E*3L*("`@
M("`@("!B<F5A:SL*("`@(&1E9F%U;'0Z"B`@("`@("`@8VAE8VM?97)R;W(H
M)')E<RP@1$)?15)23U)?24Y604Q)1%].54U"15(I.PI]"@H*<')I;G0@)T1"
M7T524D]27TE.5D%,241?3E5-0D52('!U='1I;F<@9FQO870@:6X@24Y4(&-O
M;'5M;CH@("<["B1R97,@/2`D9&)H+3YQ=65R>2@B55!$051%('!H<'1E<W0@
M4T54(&$@/2`X+CD@5TA%4D4@82`](#0R(BD["G-W:71C:"`H)&1B:"T^<&AP
M='EP92D@>PH@("`@8V%S92`G9F)S<6PG.@H@("`@8V%S92`G:6)A<V4G.@H@
M("`@8V%S92`G:69X)SH*("`@(&-A<V4@)VUS<W%L)SH*("`@(&-A<V4@)VUY
M<W%L)SH*("`@(&-A<V4@)VUY<W%L:2<Z"B`@("!C87-E("=O8VDX)SH*("`@
M(&-A<V4@)V]D8F,G.@H@("`@8V%S92`G<&=S<6PG.@H@("`@8V%S92`G<W%L
M:71E)SH*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E])3E9!
M3$E$7TY534)%4BP@9F%L<V4I.PH@("`@("`@(&)R96%K.PH@("`@9&5F875L
M=#H*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E])3E9!3$E$
M7TY534)%4BD["GT*"@IP<FEN="`G1$)?15)23U)?24Y604Q)1%].54U"15(@
M<'5T=&EN9R!E>&-E<W-I=F4@:6YT(&EN($E.5"!C;VQU;6XZ("`G.PHD<F5S
M(#T@)&1B:"T^<75E<GDH(E501$%412!P:'!T97-T(%-%5"!A(#T@,3@T-#8W
M-#0P-S,W,#DU-3$V,38@5TA%4D4@82`](#0R(BD["G-W:71C:"`H)&1B:"T^
M<&AP='EP92`N("<Z)R`N("1D8F@M/F1B<WEN=&%X*2!["B`@("!C87-E("=I
M8F%S93II8F%S92<Z"B`@("!C87-E("=I8F%S93IF:7)E8FER9"<Z"B`@("`@
M("`@8VAE8VM?97)R;W(H)')E<RP@1$)?15)23U)?4UE.5$%8*3L*("`@("`@
M("!B<F5A:SL*("`@(&-A<V4@)V9B<W%L.F9B<W%L)SH*("`@(&-A<V4@)VUS
M<6PZ;7-Q;"<Z"B`@("!C87-E("=M<W-Q;#IM<W-Q;"<Z"B`@("!C87-E("=M
M>7-Q;#IM>7-Q;"<Z"B`@("!C87-E("=M>7-Q;&DZ;7ES<6QI)SH*("`@(&-A
M<V4@)V]C:3@Z;V-I."<Z"B`@("!C87-E("=O9&)C.F%C8V5S<R<Z"B`@("!C
M87-E("=S<6QI=&4Z<W%L:71E)SH*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S
M+"!$0E]%4E)/4E])3E9!3$E$7TY534)%4BP@9F%L<V4I.PH@("`@("`@(&)R
M96%K.PH@("`@9&5F875L=#H*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$
M0E]%4E)/4E])3E9!3$E$7TY534)%4BD["GT*"@IP<FEN="`G1$)?15)23U)?
M24Y604Q)1%].54U"15(@<'5T=&EN9R!I;G0@:6X@0TA!4B!C;VQU;6XZ("`G
M.PHD<F5S(#T@)&1B:"T^<75E<GDH(E501$%412!P:'!T97-T(%-%5"!B(#T@
M."!72$5212!A(#T@-#(B*3L*<W=I=&-H("@D9&)H+3YP:'!T>7!E("X@)SHG
M("X@)&1B:"T^9&)S>6YT87@I('L*("`@(&-A<V4@)VEB87-E.FEB87-E)SH*
M("`@(&-A<V4@)VEB87-E.F9I<F5B:7)D)SH*("`@(&-A<V4@)VEF>#II9G@G
M.@H@("`@8V%S92`G;7-S<6PZ;7-S<6PG.@H@("`@8V%S92`G;7ES<6PZ;7ES
M<6PG.@H@("`@8V%S92`G;7ES<6QI.FUY<W%L:2<Z"B`@("!C87-E("=O8VDX
M.F]C:3@G.@H@("`@8V%S92`G;V1B8SIA8V-E<W,G.@H@("`@8V%S92`G<&=S
M<6PZ<&=S<6PG.@H@("`@8V%S92`G<W%L:71E.G-Q;&ET92<Z"B`@("`@("`@
M8VAE8VM?97)R;W(H)')E<RP@1$)?15)23U)?24Y604Q)1%].54U"15(L(&9A
M;'-E*3L*("`@("`@("!B<F5A:SL*("`@(&1E9F%U;'0Z"B`@("`@("`@8VAE
M8VM?97)R;W(H)')E<RP@1$)?15)23U)?24Y604Q)1%].54U"15(I.PI]"@H*
M<')I;G0@)T1"7T524D]27TY/4U5#2$9)14Q$.B`@)SL*)')E<R`]("1D8F@M
M/G%U97)Y*"=314Q%0U0@92!&4D]-('!H<'1E<W0G*3L*8VAE8VM?97)R;W(H
M)')E<RP@1$)?15)23U)?3D]354-(1DE%3$0I.PH*"G!R:6YT("=$0E]%4E)/
M4E]364Y405@Z("`G.PHD<F5S(#T@)&1B:"T^<75E<GDH)T-214%412<I.PIC
M:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E]364Y405@I.PH*"G!R:6YT("=$
M0E]%4E)/4E]604Q515]#3U5.5%]/3E]23U<Z("`G.PHD<F5S(#T@)&1B:"T^
M<75E<GDH)TE.4T525"!)3E1/('!H<'1E<W0@*&$I(%9!3%5%4R`H-C<X+"`R
M*2<I.PIS=VET8V@@*"1D8F@M/G!H<'1Y<&4I('L*("`@(&-A<V4@)VUS<6PG
M.@H@("`@("`@(&-H96-K7V5R<F]R*"1R97,L($1"7T524D]27U9!3%5%7T-/
M54Y47T].7U)/5RP@9F%L<V4I.PH@("`@("`@(&)R96%K.PH@("`@9&5F875L
M=#H*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E]604Q515]#
M3U5.5%]/3E]23U<I.PI]"@H*<')I;G0@)T1"7T524D]27TE.5D%,240@;VX@
M0TA!4B!C;VQU;6X@9&%T82!T;V\@;&]N9SH@("<["B1R97,@/2`D9&)H+3YQ
M=65R>2@B24Y315)4($E.5$\@<&AP=&5S="`H8BD@5D%,5453("@G,3(S-#4V
M-S@Y+C$R,S0U-C<X.2XQ,C,T-38W.#DN,3(S-#4V-S@Y+C$G*2(I.PIS=VET
M8V@@*"1D8F@M/G!H<'1Y<&4@+B`G.B<@+B`D9&)H+3YD8G-Y;G1A>"D@>PH@
M("`@8V%S92`G;7-Q;#IM<W%L)SH*("`@(&-A<V4@)VUS<W%L.FUS<W%L)SH*
M("`@(&-A<V4@)VUY<W%L.FUY<W%L)SH*("`@(&-A<V4@)VUY<W%L:3IM>7-Q
M;&DG.@H@("`@8V%S92`G;V1B8SIA8V-E<W,G.@H@("`@8V%S92`G<W%L:71E
M.G-Q;&ET92<Z"B`@("!C87-E("=S>6)A<V4Z<WEB87-E)SH*("`@("`@("!C
M:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E])3E9!3$E$+"!F86QS92D["B`@
M("`@("`@8G)E86L["B`@("!C87-E("=F8G-Q;#IF8G-Q;"<Z"B`@("`@("`@
M8VAE8VM?97)R;W(H)')E<RP@1$)?15)23U)?5%)53D-!5$5$*3L*("`@("`@
M("!B<F5A:SL*("`@(&1E9F%U;'0Z"B`@("`@("`@8VAE8VM?97)R;W(H)')E
M<RP@1$)?15)23U)?24Y604Q)1"D["GT*"@IP<FEN="`G1$)?15)23U)?24Y6
M04Q)1"!O;B!605)#2$%2(&-O;'5M;B!D871A('1O;R!L;VYG.B`@)SL*)')E
M<R`]("1D8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T("AD*2!604Q5
M15,@*"<Q,C,T-38W.#DN,3(S-#4V-S@Y+C$G*2(I.PIS=VET8V@@*"1D8F@M
M/G!H<'1Y<&4@+B`G.B<@+B`D9&)H+3YD8G-Y;G1A>"D@>PH@("`@8V%S92`G
M;7-Q;#IM<W%L)SH*("`@(&-A<V4@)VUS<W%L.FUS<W%L)SH*("`@(&-A<V4@
M)VUY<W%L.FUY<W%L)SH*("`@(&-A<V4@)VUY<W%L:3IM>7-Q;&DG.@H@("`@
M8V%S92`G;V1B8SIA8V-E<W,G.@H@("`@8V%S92`G<W%L:71E.G-Q;&ET92<Z
M"B`@("!C87-E("=S>6)A<V4Z<WEB87-E)SH*("`@("`@("!C:&5C:U]E<G)O
M<B@D<F5S+"!$0E]%4E)/4E])3E9!3$E$+"!F86QS92D["B`@("`@("`@8G)E
M86L["B`@("!C87-E("=F8G-Q;#IF8G-Q;"<Z"B`@("`@("`@8VAE8VM?97)R
M;W(H)')E<RP@1$)?15)23U)?5%)53D-!5$5$*3L*("`@("`@("!B<F5A:SL*
M("`@(&1E9F%U;'0Z"B`@("`@("`@8VAE8VM?97)R;W(H)')E<RP@1$)?15)2
M3U)?24Y604Q)1"D["GT*"@H*9')O<%]T86)L92@D9&)H+"`G<&AP=&5S="<I
M.PID<F]P7W1A8FQE*"1D8F@L("=B)RD["F1R;W!?=&%B;&4H)&1B:"P@)V$G
M*3L*9')O<%]T86)L92@D9&)H+"`G<&5A<G1E<W1N=6QL)RD["@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+W1E<W1S+T1"+W1E<W1S+V9E=&-H;6]D95]O8FIE8W0N:6YC````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`V,C(W`#$P-3$U-#,S-S0R`#`R-3,V,@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`H*+RHJ
M"B`J(%1E<W1S('1H92!D<FEV97)S)R!O8FIE8W0@9F5T8V@@;6]D92!P<F]C
M961U<F5S"B`J"B`J($5X96-U=&5D(&)Y(&1R:79E<B\Q-&9E=&-H;6]D95]O
M8FIE8W0N<&AP=`H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,
M24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO
M;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@
M55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@
M268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,
M:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H
M92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN
M970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*
M("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@
M0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T
M/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`
M;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@)$ED.B!F971C:&UO
M9&5?;V)J96-T+FEN8RQV(#$N,3$@,C`P-2\P,B\P,R`P-3HT.3HT-"!D86YI
M96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]$0@H@*B\*"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["@HO*BH*
M("H@3&]C86P@97)R;W(@8V%L;&)A8VL@:&%N9&QE<@H@*@H@*B!$<F]P<R!T
M:&4@<&AP=&5S="!T86)L92P@<')I;G1S(&]U="!A;B!E<G)O<B!M97-S86=E
M(&%N9"!K:6QL<R!T:&4*("H@<')O8V5S<RX*("H*("H@0'!A<F%M(&]B:F5C
M="`@)&\@(%!%05(@97)R;W(@;V)J96-T(&%U=&]M871I8V%L;'D@<&%S<V5D
M('1O('1H:7,@;65T:&]D"B`J($!R971U<FX@=F]I9`H@*B!`<V5E(%!%05(Z
M.G-E=$5R<F]R2&%N9&QI;F<H*0H@*B\*9G5N8W1I;VX@<&4H)&\I('L*("`@
M(&=L;V)A;"`D9&)H.PH*("`@("1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!
M4E]%4E)/4E]215154DXI.PH@("`@9')O<%]T86)L92@D9&)H+"`G<&AP=&5S
M="<I.PH*("`@(&1I92@D;RT^=&]3=')I;F<H*2D["GT*"B\J*@H@*B!0<FEN
M="!O=70@=&AE(&]B:F5C=`H@*B\*9G5N8W1I;VX@<')I;G1?;V)J*"8D;V)J
M*2!["B`@("!I9B`H(6ES7V]B:F5C="@D;V)J*2D@>PH@("`@("`@(&5C:&\@
M(D524D]2.B!N;R!O8FIE8W0A7&XB.PH@("`@?2!E;'-E('L*("`@("`@("!E
M8VAO('-T<G1O;&]W97(H9V5T7V-L87-S*"1O8FHI*2`N("<@+3X@)R`N(&EM
M<&QO9&4H)R`G+"!A<G)A>5]K97ES*"AA<G)A>2DD;V)J*2D@+B`B7&XB.PH@
M("`@?0I]"@H*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27T-!
M3$Q"04-++"`G<&4G*3L*"F5C:&\@(BTM+2!F971C:"!W:71H('!A<F%M($1"
M7T9%5$-(34]$15]/0DI%0U0@+2TM7&XB.PHD<W1H(#T@)&1B:"T^<75E<GDH
M(E-%3$5#5"`J($923TT@<&AP=&5S="(I.PHD<F]W(#T@)'-T:"T^9F5T8VA2
M;W<H1$)?1D540TA-3T1%7T]"2D5#5"D["G!R:6YT7V]B:B@D<F]W*3L*)'-T
M:"T^9G)E92@I.R`@+R\@:V5E<"!F8G-Q;"!H87!P>2X*"B1S=&@@/2`D9&)H
M+3YQ=65R>2@B4T5,14-4("H@1E)/32!P:'!T97-T(BD["B1S=&@M/F9E=&-H
M26YT;R@D<F]W+"!$0E]&151#2$U/1$5?3T)*14-4*3L*<')I;G1?;V)J*"1R
M;W<I.PHD<W1H+3YF<F5E*"D[("`O+R!K965P(&9B<W%L(&AA<'!Y+@H*96-H
M;R`B+2TM(&9E=&-H('=I=&@@9&5F875L="!F971C:&UO9&4@1$)?1D540TA-
M3T1%7T]"2D5#5"`M+2U<;B(["B1D8F@M/G-E=$9E=&-H36]D92A$0E]&151#
M2$U/1$5?3T)*14-4*3L*)'-T:"`]("1D8F@M/G%U97)Y*")314Q%0U0@*B!&
M4D]-('!H<'1E<W0B*3L*)')O=R`]("1S=&@M/F9E=&-H4F]W*"D["G!R:6YT
M7V]B:B@D<F]W*3L*)'-T:"T^9G)E92@I.R`@+R\@:V5E<"!F8G-Q;"!H87!P
M>2X*"B1S=&@@/2`D9&)H+3YQ=65R>2@B4T5,14-4("H@1E)/32!P:'!T97-T
M(BD["B1S=&@M/F9E=&-H26YT;R@D<F]W*3L*<')I;G1?;V)J*"1R;W<I.PHD
M<W1H+3YF<F5E*"D[("`O+R!K965P(&9B<W%L(&AA<'!Y+@H*96-H;R`B+2TM
M(&9E=&-H('=I=&@@9&5F875L="!F971C:&UO9&4@1$)?1D540TA-3T1%7T]"
M2D5#5"!A;F0@8VQA<W,@1$)?<F]W("TM+5QN(CL*)&1B:"T^<V5T1F5T8VA-
M;V1E*$1"7T9%5$-(34]$15]/0DI%0U0L("=$0E]R;W<G*3L*)'-T:"`]("1D
M8F@M/G%U97)Y*")314Q%0U0@*B!&4D]-('!H<'1E<W0B*3L*)')O=R`]("1S
M=&@M/F9E=&-H4F]W*"D["G!R:6YT7V]B:B@D<F]W*3L*)'-T:"T^9G)E92@I
M.R`@+R\@:V5E<"!F8G-Q;"!H87!P>2X*"B1S=&@@/2`D9&)H+3YQ=65R>2@B
M4T5,14-4("H@1E)/32!P:'!T97-T(BD["B1S=&@M/F9E=&-H26YT;R@D<F]W
M*3L*<')I;G1?;V)J*"1R;W<I.PHD<W1H+3YF<F5E*"D[("`O+R!K965P(&9B
M<W%L(&AA<'!Y+@H*96-H;R`B+2TM(&9E=&-H('=I=&@@9&5F875L="!F971C
M:&UO9&4@1$)?1D540TA-3T1%7T]"2D5#5"!W:71H(&YO(&-L87-S('1H96X@
M1$)?<F]W("TM+5QN(CL*)&1B:"T^<V5T1F5T8VA-;V1E*$1"7T9%5$-(34]$
M15]/0DI%0U0I.PHD<W1H(#T@)&1B:"T^<75E<GDH)U-%3$5#5"`J($923TT@
M<&AP=&5S="<I.PHD<F]W(#T@)'-T:"T^9F5T8VA2;W<H*3L*<')I;G1?;V)J
M*"1R;W<I.PHD<W1H+3YF<F5E*"D[("`O+R!K965P(&9B<W%L(&AA<'!Y+@H*
M)&1B:"T^<V5T1F5T8VA-;V1E*$1"7T9%5$-(34]$15]/0DI%0U0L("=$0E]R
M;W<G*3L*)'-T:"`]("1D8F@M/G%U97)Y*"=314Q%0U0@*B!&4D]-('!H<'1E
M<W0G*3L*)')O=R`]("1S=&@M/F9E=&-H4F]W*"D["G!R:6YT7V]B:B@D<F]W
M*3L*"B1S=&@M/F9R964H*3L@("\O(&ME97`@9F)S<6P@:&%P<'DN"B`@("`@
M("`@("`@("`@("\O(&ME97`@:6)A<V4@:&%P<'DZ(&-A;B=T(&1R;W`@=&)L
M('1H870@:&%S(')E<W5L=',@;W!E;B!A9V%I;G-T(&ET+@H*)&1B:"T^<V5T
M17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["F1R;W!?=&%B;&4H
M)&1B:"P@)W!H<'1E<W0G*3L*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]$0B]T97-T<R]F971C:&UO9&5S+FEN8P``````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`Q,S,V,@`Q,#4Q-30S,S<T,@`P,C0R,34`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*"B\J
M*@H@*B!497-T<R!T:&4@9')I=F5R<R<@=F%R:6]U<R!F971C:"!M971H;V1S
M"B`J"B`J($5X96-U=&5D(&)Y(&1R:79E<B\P,F9E=&-H+G!H<'0*("H*("H@
M4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@
M;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L
M9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E
M8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N
M86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@
M<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL
M('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@($1A
M=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@($1A;FEE
M;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP
M"B`J($!V97)S:6]N("`@("1)9#H@9F5T8VAM;V1E<RYI;F,L=B`Q+C$Q(#(P
M,#4O,#(O,30@,3<Z,#0Z,30@9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@
M("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"@HO*BH*("H@
M3&]C86P@97)R;W(@8V%L;&)A8VL@:&%N9&QE<@H@*@H@*B!$<F]P<R!T:&4@
M<&AP=&5S="!T86)L92P@<')I;G1S(&]U="!A;B!E<G)O<B!M97-S86=E(&%N
M9"!K:6QL<R!T:&4*("H@<')O8V5S<RX*("H*("H@0'!A<F%M(&]B:F5C="`@
M)&\@(%!%05(@97)R;W(@;V)J96-T(&%U=&]M871I8V%L;'D@<&%S<V5D('1O
M('1H:7,@;65T:&]D"B`J($!R971U<FX@=F]I9`H@*B!`<V5E(%!%05(Z.G-E
M=$5R<F]R2&%N9&QI;F<H*0H@*B\*9G5N8W1I;VX@<&4H)&\I('L*("`@(&=L
M;V)A;"`D9&)H.PH*("`@("1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%
M4E)/4E]215154DXI.PH@("`@9')O<%]T86)L92@D9&)H+"`G<&AP=&5S="<I
M.PH*("`@(&1I92@D;RT^=&]3=')I;F<H*2D["GT*"B1D8F@M/G-E=$5R<F]R
M2&%N9&QI;F<H4$5!4E]%4E)/4E]#04Q,0D%#2RP@)W!E)RD["B1D8F@M/G-E
M=$]P=&EO;B@G875T;V9R964G+"!T<G5E*3L*"B1D8F@M/G%U97)Y*"))3E-%
M4E0@24Y43R!P:'!T97-T(%9!3%5%4R`H,2P@)V]N92<L("=/;F4G+"`G,C`P
M,2TP,BTQ-B<I(BD["B1D8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T
M(%9!3%5%4R`H,BP@)W1W;R<L("=4=V\G+"`G,C`P,2TP,BTQ-2<I(BD["B1D
M8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T(%9!3%5%4R`H,RP@)W1H
M<F5E)RP@)U1H<F5E)RP@)S(P,#$M,#(M,30G*2(I.PH*<')I;G0@(G1E<W1I
M;F<@9F5T8VAR;W<Z7&XB.PHD<W1H(#T@)&1B:"T^<75E<GDH(E-%3$5#5"`J
M($923TT@<&AP=&5S="(I.PIF;W(@*"1I(#T@,3L@)&D@/#T@-3L@)&DK*RD@
M>PH@("`@<')I;G0@(G)O=R`D:3H@(CL*("`@("1R;W<@/2`D<W1H+3YF971C
M:%)O=R@I.PH@("`@:68@*$1".CII<T5R<F]R*"1R;W<I*2!["B`@("`@("`@
M<')I;G0@)')O=RT^=&]3=')I;F<H*2`N(")<;B(["B`@("`@("`@8V]N=&EN
M=64["B`@("!]"B`@("!I9B`H:7-?87)R87DH)')O=RDI('L*("`@("`@("!P
M<FEN="!I;7!L;V1E*"<L("<L("1R;W<I("X@(EQN(CL*("`@('T@96QS92![
M"B`@("`@("`@=F%R7V1U;7`H)')O=RD["B`@("!]"GT*)'-T:"T^9G)E92@I
M.R`@+R\@:V5E<"!F8G-Q;"!H87!P>2X*"B1D8F@M/G%U97)Y*"=$14Q%5$4@
M1E)/32!P:'!T97-T(%=(15)%(&$@/#X@-#(G*3L*"@IP<FEN="`B=&5S=&EN
M9R!F971C:&UO9&5S.B!F971C:')O=R!D969A=6QT(&1E9F%U;'0L('!O<G1A
M8FEL:71Y(&UO9&4@1$)?4$]25$%"24Q)5%E?04Q,(%X@1$)?4$]25$%"24Q)
M5%E?4E1224U<;B(["B1D8F@M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$
M0E]03U)404))3$E465]!3$P@7B!$0E]03U)404))3$E465]25%))32D["B1S
M=&@@/2`D9&)H+3YQ=65R>2@B4T5,14-4("H@1E)/32!P:'!T97-T(BD["B1R
M;W<@/2`D<W1H+3YF971C:%)O=R@I.PIP<FEN="!I;7!L;V1E*"(@(BP@87)R
M87E?:V5Y<R@D<F]W*2DN(EQN(CL*)&%C='5A;"`](&EM<&QO9&4H)R`G+"!A
M<G)A>5]V86QU97,H)')O=RDI.PIS=VET8V@@*"1D8F@M/G!H<'1Y<&4I('L*
M("`@(&-A<V4@)V9B<W%L)SH*("`@(&-A<V4@)VUS<6PG.@H@("`@8V%S92`G
M;7ES<6PG.@H@("`@8V%S92`G;7ES<6QI)SH*("`@(&-A<V4@)W-Q;&ET92<Z
M"B`@("`@("`@)&5X<&5C=&5D(#T@)S0R(&)I;F<@5&AI<R!I<R!A('1E<W0@
M,3DY.2TQ,2TR,2<["B`@("`@("`@8G)E86L["B`@("!C87-E("=I9G@G.@H@
M("`@("`@("1E>'!E8W1E9"`]("<T,B!B:6YG("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%1H:7,@:7,@82!T97-T("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Q.3DY+3$Q+3(Q("`@("`@("`@("<["B`@("`@("`@8G)E86L["B`@
M("!D969A=6QT.@H@("`@("`@("1E>'!E8W1E9"`]("<T,B!B:6YG("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%1H:7,@:7,@82!T97-T
M(#$Y.3DM,3$M,C$G.PI]"FEF("@D86-T=6%L(#T]("1E>'!E8W1E9"D@>PH@
M("`@96-H;R`B;W5T<'5T(&UA=&-H960@97AP96-T960@9F]R;6%T7&XB.PI]
M(&5L<V4@>PH@("`@96-H;R`B1$E$3B=4($U!5$-((2`@17AP96-T960@;W5T
M<'5T.B`G)&5X<&5C=&5D)RX@($%C='5A;"!O=71P=70Z("<D86-T=6%L)RY<
M;B(["GT*)'-T:"T^9G)E92@I.R`@+R\@:V5E<"!F8G-Q;"!H87!P>2X*"G!R
M:6YT(")T97-T:6YG(&9E=&-H;6]D97,Z(&9E=&-H:6YT;R!D969A=6QT(&1E
M9F%U;'1<;B(["B1D8F@M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]0
M3U)404))3$E465]!3$PI.PHD<W1H(#T@)&1B:"T^<75E<GDH(E-%3$5#5"`J
M($923TT@<&AP=&5S="(I.PHD<F]W(#T@87)R87DH*3L*)'-T:"T^9F5T8VA)
M;G1O*"1R;W<I.PIP<FEN="!I;7!L;V1E*"(@(BP@87)R87E?:V5Y<R@D<F]W
M*2DN(EQN(CL*<')I;G0@:6UP;&]D92@G("<L(&%R<F%Y7W9A;'5E<R@D<F]W
M*2DN(EQN(CL*)'-T:"T^9G)E92@I.R`@+R\@:V5E<"!F8G-Q;"!H87!P>2X*
M"G!R:6YT(")T97-T:6YG(&9E=&-H;6]D97,Z(&9E=&-H<F]W(&]R9&5R960@
M9&5F875L=%QN(CL*)&1B:"T^<V5T1F5T8VA-;V1E*$1"7T9%5$-(34]$15]/
M4D1%4D5$*3L*)'-T:"`]("1D8F@M/G%U97)Y*")314Q%0U0@*B!&4D]-('!H
M<'1E<W0B*3L*)')O=R`]("1S=&@M/F9E=&-H4F]W*"D["G!R:6YT(&EM<&QO
M9&4H(B`B+"!A<G)A>5]K97ES*"1R;W<I*2XB7&XB.PHD<W1H+3YF<F5E*"D[
M("`O+R!K965P(&9B<W%L(&AA<'!Y+@H*<')I;G0@(G1E<W1I;F<@9F5T8VAM
M;V1E<SH@9F5T8VAR;W<@87-S;V,@9&5F875L=%QN(CL*)&1B:"T^<V5T1F5T
M8VA-;V1E*$1"7T9%5$-(34]$15]!4U-/0RD["B1S=&@@/2`D9&)H+3YQ=65R
M>2@B4T5,14-4("H@1E)/32!P:'!T97-T(BD["B1R;W<@/2`D<W1H+3YF971C
M:%)O=R@I.PIP<FEN="!I;7!L;V1E*"(@(BP@87)R87E?:V5Y<R@D<F]W*2DN
M(EQN(CL*)'-T:"T^9G)E92@I.R`@+R\@:V5E<"!F8G-Q;"!H87!P>2X*"G!R
M:6YT(")T97-T:6YG(&9E=&-H;6]D97,Z(&9E=&-H<F]W(&]R9&5R960@9&5F
M875L="!W:71H(&%S<V]C('-P96-I9FEE9%QN(CL*)&1B:"T^<V5T1F5T8VA-
M;V1E*$1"7T9%5$-(34]$15]/4D1%4D5$*3L*)'-T:"`]("1D8F@M/G%U97)Y
M*")314Q%0U0@*B!&4D]-('!H<'1E<W0B*3L*)')O=R`]("1S=&@M/F9E=&-H
M4F]W*$1"7T9%5$-(34]$15]!4U-/0RD["G!R:6YT(&EM<&QO9&4H(B`B+"!A
M<G)A>5]K97ES*"1R;W<I*2XB7&XB.PHD<W1H+3YF<F5E*"D[("`O+R!K965P
M(&9B<W%L(&AA<'!Y+@H*<')I;G0@(G1E<W1I;F<@9F5T8VAM;V1E<SH@9F5T
M8VAR;W<@87-S;V,@9&5F875L="!W:71H(&]R9&5R960@<W!E8VEF:65D7&XB
M.PHD9&)H+3YS971&971C:$UO9&4H1$)?1D540TA-3T1%7T%34T]#*3L*)'-T
M:"`]("1D8F@M/G%U97)Y*")314Q%0U0@*B!&4D]-('!H<'1E<W0B*3L*)')O
M=R`]("1S=&@M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]/4D1%4D5$*3L*<')I
M;G0@:6UP;&]D92@B("(L(&%R<F%Y7VME>7,H)')O=RDI+B)<;B(["B1S=&@M
M/F9R964H*3L@("\O(&ME97`@9F)S<6P@:&%P<'DN"@IP<FEN="`B=&5S=&EN
M9R!F971C:&UO9&5S.B!F971C:&EN=&\@;W)D97)E9"!D969A=6QT7&XB.PHD
M9&)H+3YS971&971C:$UO9&4H1$)?1D540TA-3T1%7T]21$52140I.PHD<W1H
M(#T@)&1B:"T^<75E<GDH(E-%3$5#5"`J($923TT@<&AP=&5S="(I.PHD<F]W
M(#T@87)R87DH*3L*)'-T:"T^9F5T8VA);G1O*"1R;W<I.PIP<FEN="!I;7!L
M;V1E*"(@(BP@87)R87E?:V5Y<R@D<F]W*2DN(EQN(CL*)'-T:"T^9G)E92@I
M.R`@+R\@:V5E<"!F8G-Q;"!H87!P>2X*"G!R:6YT(")T97-T:6YG(&9E=&-H
M;6]D97,Z(&9E=&-H:6YT;R!A<W-O8R!D969A=6QT7&XB.PHD9&)H+3YS971&
M971C:$UO9&4H1$)?1D540TA-3T1%7T%34T]#*3L*)'-T:"`]("1D8F@M/G%U
M97)Y*")314Q%0U0@*B!&4D]-('!H<'1E<W0B*3L*)')O=R`](&%R<F%Y*"D[
M"B1S=&@M/F9E=&-H26YT;R@D<F]W*3L*<')I;G0@:6UP;&]D92@B("(L(&%R
M<F%Y7VME>7,H)')O=RDI+B)<;B(["B1S=&@M/F9R964H*3L@("\O(&ME97`@
M9F)S<6P@:&%P<'DN"@IP<FEN="`B=&5S=&EN9R!F971C:&UO9&5S.B!F971C
M:&EN=&\@;W)D97)E9"!D969A=6QT('=I=&@@87-S;V,@<W!E8VEF:65D7&XB
M.PHD9&)H+3YS971&971C:$UO9&4H1$)?1D540TA-3T1%7T]21$52140I.PHD
M<W1H(#T@)&1B:"T^<75E<GDH(E-%3$5#5"`J($923TT@<&AP=&5S="(I.PHD
M<F]W(#T@87)R87DH*3L*)'-T:"T^9F5T8VA);G1O*"1R;W<L($1"7T9%5$-(
M34]$15]!4U-/0RD["G!R:6YT(&EM<&QO9&4H(B`B+"!A<G)A>5]K97ES*"1R
M;W<I*2XB7&XB.PHD<W1H+3YF<F5E*"D[("`O+R!K965P(&9B<W%L(&AA<'!Y
M+@H*<')I;G0@(G1E<W1I;F<@9F5T8VAM;V1E<SH@9F5T8VAI;G1O(&%S<V]C
M(&1E9F%U;'0@=VET:"!O<F1E<F5D('-P96-I9FEE9%QN(CL*)&1B:"T^<V5T
M1F5T8VA-;V1E*$1"7T9%5$-(34]$15]!4U-/0RD["B1S=&@@/2`D9&)H+3YQ
M=65R>2@B4T5,14-4("H@1E)/32!P:'!T97-T(BD["B1R;W<@/2!A<G)A>2@I
M.PHD<W1H+3YF971C:$EN=&\H)')O=RP@1$)?1D540TA-3T1%7T]21$52140I
M.PIP<FEN="!I;7!L;V1E*"(@(BP@87)R87E?:V5Y<R@D<F]W*2DN(EQN(CL*
M"B1S=&@M/F9R964H*3L@("\O(&ME97`@9F)S<6P@:&%P<'DN"B`@("`@("`@
M("`@("`@("\O(&ME97`@:6)A<V4@:&%P<'DZ(&-A;B=T(&1R;W`@=&)L('1H
M870@:&%S(')E<W5L=',@;W!E;B!A9V%I;G-T(&ET+@H*)&1B:"T^<V5T17)R
M;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["F1R;W!?=&%B;&4H)&1B
M:"P@)W!H<'1E<W0G*3L*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+W1E<W1S+T1"+W1E<W1S+VEN8VQU9&4N:6YC````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`T,#4R`#$P-3$U-#,S-S0R`#`R,S4Q,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`H*+RHJ"B`J
M(%-E=',@=&AE(&EN8VQU9&5?<&%T:"P@97)R;W)?<F5P;W)T:6YG(&%N9"!0
M051(7U-%4$%2051/4B!F;W(@=&5S=',*("H@:6X@=&AE($1"+W1E<W1S(&1I
M<F5C=&]R>0H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%
M3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S
M+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55))
M.@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@
M0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U
M=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@
M*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC
M96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!0
M2%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@)$ED.B!I;F-L=61E+FEN
M8RQV(#$N-2`R,#`U+S`R+S`S(#`U.C0Y.C0T(&1A;FEE;&,@17AP("0*("H@
M0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J
M+PH*97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*"FEF("@A9&5F:6YE9"@G4$%4
M2%]315!!4D%43U(G*2D@>PH@("`@:68@*'-T<FES='(H4$A07T]3+"`G5TE.
M)RDI('L*("`@("`@("`O*BH*("`@("`@("`@*B!$969I;F4@=&AE('!A=&@@
M<V5P87)A=&]R(&9O<B!W:6YD;W=S"B`@("`@("`@("HO"B`@("`@("`@9&5F
M:6YE*"=0051(7U-%4$%2051/4B<L("<[)RD["B`@("!](&5L<V4@>PH@("`@
M("`@("\J*@H@("`@("`@("`J($1E9FEN92!T:&4@<&%T:"!S97!A<F%T;W(@
M9F]R(&]T:&5R('-Y<W1E;7,*("`@("`@("`@*B\*("`@("`@("!D969I;F4H
M)U!!5$A?4T5005)!5$]2)RP@)SHG*3L*("`@('T*?0H*+RH*("H@268@=&AE
M('!A=&@@=&\@>6]U<B!014%2(&EN<W1A;&QA=&EO;B!I<R!F;W5N9"!I;B!T
M:&4@;&5F="!H86YD"B`J('!O<G1I;VX@;V8@=&AE(&EF*"D@97AP<F5S<VEO
M;B!B96QO=RP@=&AA="!M96%N<R!T:&ES(&9I;&4@:&%S"B`J(&-O;64@9G)O
M;2!T:&4@4$5!4B!I;G-T86QL97(N("!4:&5R969O<F4L(&QE="=S('5S92!T
M:&4*("H@:6YS=&%L;&5D('9E<G-I;VX@;V8@1$(L('=H:6-H('-H;W5L9"!B
M92!F;W5N9"!V:6$@=&AE"B`J(&-O;7!U=&5R)W,@9&5F875L="!I;F-L=61E
M7W!A=&@N("!!9&0@)RXG('1O('1H92!I;F-L=61E7W!A=&@*("H@=&\@96YS
M=7)E("<N)R!I<R!I;B!T:&5R92X*("H@"B`J($EF('1H92!P871H(&AA<R!N
M;W0@8F5E;B!S=6)S=&ET=71E9"!I;B!T:&4@:68H*2!E>'!R97-S:6]N+`H@
M*B!T:&ES(&9I;&4@:&%S(&QI:V5L>2!C;VUE(&9R;VT@82!#5E,@8VAE8VMO
M=70@;W(@82`N=&%R(&9I;&4N"B`J(%1H97)E9F]R92P@=V4G;&P@87-S=6UE
M('1H92!T97-T<R!S:&]U;&0@=7-E('1H92!V97)S:6]N(&]F"B`J($1"('1H
M870@:&%S(&-O;64@9G)O;2!T:&5R92!A<R!W96QL+@H@*B\*:68@*"<O=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B<@(3T@)T`G+B=I;F-L=61E7W!A
M=&@G+B=`)RD@>PH@("`@:6YI7W-E="@G:6YC;'5D95]P871H)RP@:6YI7V=E
M="@G:6YC;'5D95]P871H)RD*("`@("`@("`@("`@+B!0051(7U-%4$%2051/
M4B`N("<N)PH@("`@*3L*?2!E;'-E('L*("`@(&EN:5]S970H)VEN8VQU9&5?
M<&%T:"<L(')E86QP871H*&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I"B`@
M("`@("`@("`@("X@4$%42%]315!!4D%43U(@+B`G+B<@+B!0051(7U-%4$%2
M051/4@H@("`@("`@("`@("`N(&EN:5]G970H)VEN8VQU9&5?<&%T:"<I"B`@
M("`I.PI]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+VEN8VQU9&4N:6YC+F]R:6<`
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T,#4T`#$P-3$U-#,S-S0R`#`R-#0U
M-``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*+RHJ"B`J(%-E=',@=&AE(&EN8VQU9&5?<&%T:"P@97)R;W)?<F5P
M;W)T:6YG(&%N9"!0051(7U-%4$%2051/4B!F;W(@=&5S=',*("H@:6X@=&AE
M($1"+W1E<W1S(&1I<F5C=&]R>0H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@
M-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@
M=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@
M879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F
M;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@
M=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T
M:')O=6=H('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E
M;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA
M=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@
M("`@1$(*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L
M8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'
M<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@)$ED
M.B!I;F-L=61E+FEN8RQV(#$N-2`R,#`U+S`R+S`S(#`U.C0Y.C0T(&1A;FEE
M;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+T1""B`J+PH*97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*"FEF("@A
M9&5F:6YE9"@G4$%42%]315!!4D%43U(G*2D@>PH@("`@:68@*'-T<FES='(H
M4$A07T]3+"`G5TE.)RDI('L*("`@("`@("`O*BH*("`@("`@("`@*B!$969I
M;F4@=&AE('!A=&@@<V5P87)A=&]R(&9O<B!W:6YD;W=S"B`@("`@("`@("HO
M"B`@("`@("`@9&5F:6YE*"=0051(7U-%4$%2051/4B<L("<[)RD["B`@("!]
M(&5L<V4@>PH@("`@("`@("\J*@H@("`@("`@("`J($1E9FEN92!T:&4@<&%T
M:"!S97!A<F%T;W(@9F]R(&]T:&5R('-Y<W1E;7,*("`@("`@("`@*B\*("`@
M("`@("!D969I;F4H)U!!5$A?4T5005)!5$]2)RP@)SHG*3L*("`@('T*?0H*
M+RH*("H@268@=&AE('!A=&@@=&\@>6]U<B!014%2(&EN<W1A;&QA=&EO;B!I
M<R!F;W5N9"!I;B!T:&4@;&5F="!H86YD"B`J('!O<G1I;VX@;V8@=&AE(&EF
M*"D@97AP<F5S<VEO;B!B96QO=RP@=&AA="!M96%N<R!T:&ES(&9I;&4@:&%S
M"B`J(&-O;64@9G)O;2!T:&4@4$5!4B!I;G-T86QL97(N("!4:&5R969O<F4L
M(&QE="=S('5S92!T:&4*("H@:6YS=&%L;&5D('9E<G-I;VX@;V8@1$(L('=H
M:6-H('-H;W5L9"!B92!F;W5N9"!V:6$@=&AE"B`J(&-O;7!U=&5R)W,@9&5F
M875L="!I;F-L=61E7W!A=&@N("!!9&0@)RXG('1O('1H92!I;F-L=61E7W!A
M=&@*("H@=&\@96YS=7)E("<N)R!I<R!I;B!T:&5R92X*("H@"B`J($EF('1H
M92!P871H(&AA<R!N;W0@8F5E;B!S=6)S=&ET=71E9"!I;B!T:&4@:68H*2!E
M>'!R97-S:6]N+`H@*B!T:&ES(&9I;&4@:&%S(&QI:V5L>2!C;VUE(&9R;VT@
M82!#5E,@8VAE8VMO=70@;W(@82`N=&%R(&9I;&4N"B`J(%1H97)E9F]R92P@
M=V4G;&P@87-S=6UE('1H92!T97-T<R!S:&]U;&0@=7-E('1H92!V97)S:6]N
M(&]F"B`J($1"('1H870@:&%S(&-O;64@9G)O;2!T:&5R92!A<R!W96QL+@H@
M*B\*:68@*"<O:&]M92]L=6-E<B]W;W)K+W!E87(O<VAA<F4O<&AP)R`A/2`G
M0"<N)VEN8VQU9&5?<&%T:"<N)T`G*2!["B`@("!I;FE?<V5T*"=I;F-L=61E
M7W!A=&@G+"!I;FE?9V5T*"=I;F-L=61E7W!A=&@G*0H@("`@("`@("`@("`N
M(%!!5$A?4T5005)!5$]2("X@)RXG"B`@("`I.PI](&5L<V4@>PH@("`@:6YI
M7W-E="@G:6YC;'5D95]P871H)RP@<F5A;'!A=&@H9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+RXN)RD*("`@("`@("`@("`@+B!0051(7U-%4$%2051/4B`N("<N
M)R`N(%!!5$A?4T5005)!5$]2"B`@("`@("`@("`@("X@:6YI7V=E="@G:6YC
M;'5D95]P871H)RD*("`@("D["GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+VQI;6ET
M+FEN8P``````````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T-C(R`#$P-3$U
M-#,S-S0R`#`R,S(Q,0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`H*+RHJ"B`J(%1E<W1S('1H92!D<FEV97)S)R!L
M:6UI=%%U97)Y*"D@;65T:&]D"B`J"B`J($5X96-U=&5D(&)Y(&1R:79E<B\Q
M,VQI;6ET+G!H<'0*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@
M3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I
M;VX@,RXP(&]F('1H92!02%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L
M92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG
M(%5223H*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@
M($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@
M3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T
M:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N
M;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J
M"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J
M($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE
M=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@("1)9#H@;&EM:70N
M:6YC+'8@,2XQ,2`R,#`U+S`R+S`S(#`U.C0Y.C0T(&1A;FEE;&,@17AP("0*
M("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1"
M"B`J+PH*97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*"B\J*@H@*B!,;V-A;"!E
M<G)O<B!C86QL8F%C:R!H86YD;&5R"B`J"B`J($1R;W!S('1H92!P:'!T97-T
M('1A8FQE+"!P<FEN=',@;W5T(&%N(&5R<F]R(&UE<W-A9V4@86YD(&MI;&QS
M('1H90H@*B!P<F]C97-S+@H@*@H@*B!`<&%R86T@;V)J96-T("`D;R`@4$5!
M4B!E<G)O<B!O8FIE8W0@875T;VUA=&EC86QL>2!P87-S960@=&\@=&AI<R!M
M971H;V0*("H@0')E='5R;B!V;VED"B`J($!S964@4$5!4CHZ<V5T17)R;W)(
M86YD;&EN9R@I"B`J+PIF=6YC=&EO;B!P92@D;RD@>PH@("`@9VQO8F%L("1D
M8F@["@H@("`@)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U)%
M5%523BD["B`@("!D<F]P7W1A8FQE*"1D8F@L("=P:'!T97-T)RD["@H@("`@
M9&EE*"1O+3YT;U-T<FEN9R@I*3L*?0H*"B1D8F@M/G-E=$5R<F]R2&%N9&QI
M;F<H4$5!4E]%4E)/4E]215154DXI.PID<F]P7W1A8FQE*"1D8F@L("=P:'!?
M;&EM:70G*3L*"B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]#
M04Q,0D%#2RP@)W!E)RD["@HD9&)H+3YQ=65R>2@G0U)%051%(%1!0DQ%('!H
M<%]L:6UI="`H82!#2$%2*#(P*2DG*3L*"@HD9G)O;2`@("`](#`["B1C;W5N
M="`@(#T@,3`["B1N=6UR;W=S(#T@,S`["@IF;W(@*"1I/3`[("1I/#TD;G5M
M<F]W<RLR.R`D:2LK*2!["B`@("`D9&)H+3YQ=65R>2@B24Y315)4($E.5$\@
M<&AP7VQI;6ET(%9!3%5%4R@G<F5S=6QT("1I)RDB*3L*?0IF;W(@*"1I(#T@
M,#L@)&D@/#T@,SL@)&DK*RD@>PH@("`@)&9R;VT@/2`Q,"`J("1I.PH@("`@
M)')E<R`]("1D8F@M/FQI;6ET475E<GDH(G-E;&5C="`J(&9R;VT@<&AP7VQI
M;6ET(BP@)&9R;VTL("1C;W5N="D["B`@("!E8VAO("(]/3T]/3T]($9R;VTZ
M("1F<F]M('Q\($YU;6)E<B!O9B!R;W=S('1O(&9E=&-H.B`D8V]U;G0@/3T]
M/3T]/5QN(CL*("`@('=H:6QE("@D<F]W(#T@)')E<RT^9F5T8VA2;W<H1$)?
M1D540TA-3T1%7T%34T]#*2D@>PH@("`@("`@(&5C:&\@)')E<RT^9V5T4F]W
M0V]U;G1E<B@I("X@)RXM("<@+B`D<F]W6R=A)UT@+B`B7&XB.PH@("`@?0H@
M("`@)')E<RT^9G)E92@I.R`@+R\@:V5E<"!F8G-Q;"!H87!P>2X*?0H*"B1F
M<F]M("`](#$Q.PHD8V]U;G0@/2`S.PH*96-H;R`B/3T]/3T]/2!087-S:6YG
M(%PD<&%R86US('Q\($9R;VTZ("1F<F]M('Q\($YU;6)E<B!O9B!R;W=S('1O
M(&9E=&-H.B`D8V]U;G0@/3T]/3T]/5QN(CL*)')E<R`]("1D8F@M/FQI;6ET
M475E<GDH)U-%3$5#5"`J($923TT@<&AP7VQI;6ET(%=(15)%(&$@/"`_)RP@
M)&9R;VTL("1C;W5N="P@87)R87DH)W)E<W5L="`Y.2<I*3L*=VAI;&4@*"1R
M;W<@/2`D<F5S+3YF971C:%)O=RA$0E]&151#2$U/1$5?05-33T,I*2!["B`@
M("!E8VAO("1R97,M/F=E=%)O=T-O=6YT97(H*2`N("<N+2`G("X@)')O=ULG
M82==("X@(EQN(CL*?0H*)')E<RT^9G)E92@I.R`@+R\@:V5E<"!F8G-Q;"!H
M87!P>2X*("`@("`@("`@("`@("`@+R\@:V5E<"!I8F%S92!H87!P>3H@8V%N
M)W0@9')O<"!T8FP@=&AA="!H87,@<F5S=6QT<R!O<&5N(&%G86EN<W0@:70N
M"@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*
M9')O<%]T86)L92@D9&)H+"`G<&AP7VQI;6ET)RD["@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"
M+W1E<W1S+VYU;6-O;',N:6YC````````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`S-3$S`#$P-3$U-#,S-S0R`#`R,S4U,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`H*+RHJ"B`J(%1E<W1S('1H
M92!D<FEV97)S)R!N=6U#;VQS*"D@;65T:&]D"B`J"B`J($5X96-U=&5D(&)Y
M(&1R:79E<B\P-&YU;6-O;',N<&AP=`H@*@H@*B!02%`@=F5R<VEO;G,@-"!A
M;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE
M8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@
M:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H
M92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*
M("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I
M="!T:')O=6=H('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L
M:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE
M9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA
M9V4@("`@1$(*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N
M:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(
M4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@
M)$ED.B!N=6UC;VQS+FEN8RQV(#$N-R`R,#`U+S`R+S`S(#`U.C0Y.C0T(&1A
M;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+T1""B`J+PH*+RHJ"B`J($QO8V%L(&5R<F]R(&-A;&QB86-K
M(&AA;F1L97(*("H*("H@1')O<',@=&AE('!H<'1E<W0@=&%B;&4L('!R:6YT
M<R!O=70@86X@97)R;W(@;65S<V%G92!A;F0@:VEL;',@=&AE"B`J('!R;V-E
M<W,N"B`J"B`J($!P87)A;2!O8FIE8W0@("1O("!014%2(&5R<F]R(&]B:F5C
M="!A=71O;6%T:6-A;&QY('!A<W-E9"!T;R!T:&ES(&UE=&AO9`H@*B!`<F5T
M=7)N('9O:60*("H@0'-E92!014%2.CIS971%<G)O<DAA;F1L:6YG*"D*("HO
M"F9U;F-T:6]N('!E*"1O*2!["B`@("!G;&]B86P@)&1B:#L*"B`@("`D9&)H
M+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*("`@(&1R
M;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G*3L*"B`@("!D:64H)&\M/G1O4W1R
M:6YG*"DI.PI]"@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M0T%,3$)!0TLL("=P92<I.PH*"B1S=&@@/2`D9&)H+3YQ=65R>2@B4T5,14-4
M(&$@1E)/32!P:'!T97-T(BD["G!R:6YT9B@B)61<;B(L("1S=&@M/FYU;4-O
M;',H*2D["B1S=&@@/2`D9&)H+3YQ=65R>2@B4T5,14-4(&$L8B!&4D]-('!H
M<'1E<W0B*3L*<')I;G1F*"(E9%QN(BP@)'-T:"T^;G5M0V]L<R@I*3L*)'-T
M:"`]("1D8F@M/G%U97)Y*")314Q%0U0@82QB+&,@1E)/32!P:'!T97-T(BD[
M"G!R:6YT9B@B)61<;B(L("1S=&@M/FYU;4-O;',H*2D["B1S=&@@/2`D9&)H
M+3YQ=65R>2@B4T5,14-4("H@1E)/32!P:'!T97-T(BD["G!R:6YT9B@B)61<
M;B(L("1S=&@M/FYU;4-O;',H*2D["@H*<W=I=&-H("@D9&)H+3YP:'!T>7!E
M*2!["B`@("!C87-E("=I8F%S92<Z"B`@("`@("`@+RH*("`@("`@("`@*B!)
M;G1E<F)A<V4@9&]E<VXG="!A;&QO=R!D<F]P<&EN9R!T86)L97,@=&AA="!H
M879E(')E<W5L=`H@("`@("`@("`J('-E=',@<W1I;&P@;W!E;BX*("`@("`@
M("`@*B\*("`@("`@("`D9&)H+3YF<F5E4F5S=6QT*"1S=&@M/G)E<W5L="D[
M"B`@("`@("`@8G)E86L["GT*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%2
M7T524D]27U)%5%523BD["F1R;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G*3L*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T
M<R]N=6UR;W=S+FEN8P``````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C(S
M-@`Q,#4Q-30S,S<T,@`P,C,V,3``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"B\J*@H@*B!497-T<R!T:&4@9')I
M=F5R<R<@;G5M4F]W<R@I(&UE=&AO9`H@*@H@*B!%>&5C=71E9"!B>2!D<FEV
M97(O,#EN=6UR;W=S+G!H<'0*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*
M("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O
M('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90H@*B!T:&%T(&ES(&%V
M86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L
M;&]W:6YG(%5223H*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H
M92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR
M;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS
M94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E
M;'DN"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@
M($1""B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`
M<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O
M=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@("1)9#H@
M;G5M<F]W<RYI;F,L=B`Q+C$R(#(P,#4O,#(O,#D@,#<Z,#<Z,C0@9&%N:65L
M8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A
M8VMA9V4O1$(*("HO"@HO*BH*("H@3&]C86P@97)R;W(@8V%L;&)A8VL@:&%N
M9&QE<@H@*@H@*B!$<F]P<R!T:&4@<&AP=&5S="!T86)L92P@<')I;G1S(&]U
M="!A;B!E<G)O<B!M97-S86=E(&%N9"!K:6QL<R!T:&4*("H@<')O8V5S<RX*
M("H*("H@0'!A<F%M(&]B:F5C="`@)&\@(%!%05(@97)R;W(@;V)J96-T(&%U
M=&]M871I8V%L;'D@<&%S<V5D('1O('1H:7,@;65T:&]D"B`J($!R971U<FX@
M=F]I9`H@*B!`<V5E(%!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H*0H@*B\*9G5N
M8W1I;VX@<&4H)&\I('L*("`@(&=L;V)A;"`D9&)H.PH*("`@("1D8F@M/G-E
M=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PH@("`@9')O<%]T
M86)L92@D9&)H+"`G<&AP=&5S="<I.PH*("`@('!R:6YT(")<;BTM+2TM+2TM
M+2TM+5QN(CL*("`@(&EF("@D;RT^9V5T0V]D92@I(#T]($1"7T524D]27TY/
M5%]#05!!0DQ%*2!["B`@("`@("`@<')I;G0@(E1H:7,@1$)-4R!D;V5S(&YO
M="!S=7!P;W)T(&YU;5)O=W,H*2XB.PH@("`@?2!E;'-E:68@*"1O+3YG971#
M;V1E*"D@/3T@1$)?15)23U)?34E334%40T@I('L*("`@("`@("!P<FEN="`B
M36ES;6%T8V@@8F5T=V5E;B!T:&4@;G5M8F5R(&]F('!L86-E:&]L9&5R<R!A
M;F0@<&%R86UE=&5R<RY<;B(["B`@("`@("`@9F]R96%C:"`H)&\M/F)A8VMT
M<F%C92!A<R`D:71E;2`]/B`D9&5T86EL*2!["B`@("`@("`@("`@(&EF("@D
M9&5T86EL6R=F=6YC=&EO;B==(#T]("=Q=65R>2<I('L*("`@("`@("`@("`@
M("`@(&5C:&\@)U%515)9.B`G("X@)&1E=&%I;%LG87)G<R==6S!=("X@(EQN
M(CL*("`@("`@("`@("`@("`@(&5C:&\@(E!!4D%-151%4E,Z7&XB.PH@("`@
M("`@("`@("`@("`@<')I;G1?<B@D9&5T86EL6R=A<F=S)UU;,5TI.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("!P<FEN
M="`D;RT^9V5T1&5B=6=);F9O*"D@+B`B7&XB.PH@("`@?0H@("`@97AI=#L*
M?0H*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"04-+
M+"`G<&4G*3L*"@HD<F5S(#T@)&1B:"T^<75E<GDH(E-%3$5#5"!A($923TT@
M<&AP=&5S="(I.PII9B`H(41".CII<T5R<F]R*"1R;W=S(#T@)')E<RT^;G5M
M4F]W<R@I*2D@>PH@("`@<')I;G0@(BAW86YT(#$I(&=O="`D<F]W<R!F<F]M
M(&9I<G-T7&XB.PI](&5L<V4@>PH@("`@<')I;G0@(EQN(CL*?0IF;W(@*"1I
M(#T@,#L@)&D@/"`U.R`D:2LK*2!["B`@("`D9&)H+3YQ=65R>2@B24Y315)4
M($E.5$\@<&AP=&5S="`H82D@5D%,5453("@D:2DB*3L*("`@("1R97,@/2`D
M9&)H+3YQ=65R>2@B4T5,14-4(&$@1E)/32!P:'!T97-T(BD["B`@("!I9B`H
M(41".CII<T5R<F]R*"1R;W=S(#T@)')E<RT^;G5M4F]W<R@I*2D@>PH@("`@
M("`@('!R:6YT("<H=V%N="`G("X@*"1I("L@,BD@+B`B*2!G;W0@)')O=W,@
M9G)O;2`D:5QN(CL*("`@('T@96QS92!["B`@("`@("`@<')I;G0@(EQN(CL*
M("`@('T*?0H*)')E<R`]("1D8F@M/G%U97)Y*"=314Q%0U0@82!&4D]-('!H
M<'1E<W0@5TA%4D4@82`^(#\G+"`P*3L*:68@*"%$0CHZ:7-%<G)O<B@D<F]W
M<R`]("1R97,M/FYU;5)O=W,H*2DI('L*("`@('!R:6YT("(H=V%N="`U*2!G
M;W0@)')O=W,@9G)O;2`^(#`@*'!A<W-I;F<@<&%R86US('1O('%U97)Y*5QN
M(CL*?2!E;'-E('L*("`@('!R:6YT(")<;B(["GT*"B1S=&@@/2`D9&)H+3YP
M<F5P87)E*"=314Q%0U0@82!&4D]-('!H<'1E<W0@5TA%4D4@82`\(#\G*3L*
M)')E<R`]("1D8F@M/F5X96-U=&4H)'-T:"P@87)R87DH-"DI.PII9B`H(41"
M.CII<T5R<F]R*"1R;W=S(#T@)')E<RT^;G5M4F]W<R@I*2D@>PH@("`@<')I
M;G0@(BAW86YT(#0I(&=O="`D<F]W<R!F<F]M(#P@-"`H9&]I;F<@<')E<&%R
M92]E>&5C=71E*5QN(CL*?2!E;'-E('L*("`@('!R:6YT(")<;B(["GT*"B1D
M8F@M/G%U97)Y*")$14Q%5$4@1E)/32!P:'!T97-T(%=(15)%(&$@/"`T(BD[
M"B1R97,@/2`D9&)H+3YQ=65R>2@B4T5,14-4(&$@1E)/32!P:'!T97-T(BD[
M"FEF("@A1$(Z.FES17)R;W(H)')O=W,@/2`D<F5S+3YN=6U2;W=S*"DI*2![
M"B`@("!P<FEN="`B*'=A;G0@,BD@9V]T("1R;W=S(&9R;VT@-2!A;F0@-B!N
M;W0@9&5L971E9%QN(CL*?2!E;'-E('L*("`@('!R:6YT(")<;B(["GT*)')E
M<R`]("1D8F@M/G%U97)Y*")314Q%0U0@82!&4D]-('!H<'1E<W0@=VAE<F4@
M82`\(#`B*3L*:68@*"%$0CHZ:7-%<G)O<B@D<F]W<R`]("1R97,M/FYU;5)O
M=W,H*2DI('L*("`@('!R:6YT("(H=V%N="`P*2!G;W0@)')O=W,@9G)O;2`\
M(#!<;B(["GT@96QS92!["B`@("!P<FEN="`B7&XB.PI]"@H*)')E<RT^9G)E
M92@I.R`@+R\@:V5E<"!I8F%S92!H87!P>0HD9&)H+3YS971%<G)O<DAA;F1L
M:6YG*%!%05)?15)23U)?4D5455).*3L*9')O<%]T86)L92@D9&)H+"`G<&AP
M=&5S="<I.PH`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S
M=',O<')E<&5X92YI;F,`````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,30W
M,C0`,3`U,34T,S,W-#(`,#(S-30W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"@HO*BH*("H@5&5S=',@=&AE(&1R
M:79E<G,G('!R97!A<F4@86YD(&5X96-U=&4@;65T:&]D<PH@*@H@*B!%>&5C
M=71E9"!B>2!D<FEV97(O,#9P<F5P97AE8RYP:'!T"B`J"B`J(%!(4"!V97)S
M:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*
M("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@
M;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N
M;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@
M*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES
M<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P
M-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R
M<VEO;B`@("`D260Z('!R97!E>&4N:6YC+'8@,2XR-2`R,#`U+S`R+S$V(#$S
M.C4T.C4Q(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*)'1M<&9I;&4@/2!T96UP;F%M
M*"(O=&UP(BP@(G!H<'1M<"(I.PIR96=I<W1E<E]S:'5T9&]W;E]F=6YC=&EO
M;B@B;7E?<VAU=&1O=VXB*3L*)&9P(#T@9F]P96XH)'1M<&9I;&4L(")W(BD[
M"B1F:6QE9&%T82`](")O<&%Q=64@<&QA8V5H;VQD97(G<R!T97-T(CL*9G=R
M:71E*"1F<"P@)&9I;&5D871A*3L*9F-L;W-E*"1F<"D["@H*+RHJ"B`J($QO
M8V%L(&5R<F]R(&-A;&QB86-K(&AA;F1L97(*("H*("H@4')I;G1S(&]U="!A
M;B!E<G)O<B!M97-S86=E(&%N9"!K:6QL<R!T:&4@<')O8V5S<RX*("H*("H@
M0'!A<F%M(&]B:F5C="`@)&\@(%!%05(@97)R;W(@;V)J96-T(&%U=&]M871I
M8V%L;'D@<&%S<V5D('1O('1H:7,@;65T:&]D"B`J($!R971U<FX@=F]I9`H@
M*B!`<V5E(%!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H*0H@*B\*9G5N8W1I;VX@
M<&4H)&\I('L*("`@('!R:6YT(")<;B(@+B`D;RT^=&]3=')I;F<H*3L*("`@
M(&5X:70["GT*"B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]#
M04Q,0D%#2RP@)W!E)RD["@H*+R\@,2D@375L=&EP;&4@<')E<&%R92]E>&5C
M($E.4T525"!Q=65R:65S"F5C:&\@(BTM+2TM+2TM+2TM+3$M+2TM+2TM+2TM
M+2U<;B(["@HD<W1H,2`]("1D8F@M/G!R97!A<F4H(DE.4T525"!)3E1/('!H
M<'1E<W0@*&$L(&(I(%9!3%5%4R`H/RP@)V$G*2(I.PHD<W1H,B`]("1D8F@M
M/G!R97!A<F4H(DE.4T525"!)3E1/('!H<'1E<W0@*&$L8BD@5D%,5453("@A
M+#\I(BD["B1S=&@S(#T@)&1B:"T^<')E<&%R92@B24Y315)4($E.5$\@<&AP
M=&5S="`H82QB+&,I(%9!3%5%4R`H/RPA+"8I(BD["B1S=&@T(#T@)&1B:"T^
M<')E<&%R92@B24Y315)4($E.5$\@<&AP=&5S="`H82P@8BD@5D%,5453("@W
M,BP@)V1I<F5C="<I(BD["G!R:6YT(")S=&@Q+'-T:#(L<W1H,RQS=&@T(&-R
M96%T961<;B(["G!R:6YT("=S=&@Q.B`_(&%S('!A<F%M+"!P87-S:6YG(&%S
M(&%R<F%Y+BXN("<["FEF("@H)')E<R`]("1D8F@M/F5X96-U=&4H)'-T:#$L
M(&%R<F%Y*#<R*2DI(#T]/2!$0E]/2RD@>PH@("`@<')I;G0@(G-T:#$@97AE
M8W5T961<;B(["GT@96QS92!["B`@("!P<FEN="`B<W1H,2!F86EL961<;B([
M"GT*"G!R:6YT("=S=&@R.B`A(&%N9"`_(&%S('!A<F%M<RP@<&%S<VEN9R!A
M<R!A<G)A>2XN+B`G.PII9B`H*"1R97,@/2`D9&)H+3YE>&5C=71E*"1S=&@R
M+"!A<G)A>2@W,BP@(G1H870G<R!R:6=H="(I*2D@/3T]($1"7T]+*2!["B`@
M("!P<FEN="`B<W1H,B!E>&5C=71E9%QN(CL*?2!E;'-E('L*("`@('!R:6YT
M(")S=&@R(&9A:6QE9%QN(CL*?0H*<')I;G0@)W-T:#,Z(#\L("$@86YD("8@
M87,@<&%R86US+"!P87-S:6YG(&%S(&%R<F%Y+BXN("<["G-W:71C:"`H)&1B
M:"T^<&AP='EP92D@>PH@("`@8V%S92`G;7-Q;"<Z"B`@("`@("`@)')E<R`]
M("1D8F@M/F5X96-U=&4H)'-T:#,L(&%R<F%Y*#<R+"`B)VET7%PG<R!G;V]D
M)R(L("1T;7!F:6QE*2D["B`@("`@("`@8G)E86L["B`@("!D969A=6QT.@H@
M("`@("`@("1R97,@/2`D9&)H+3YE>&5C=71E*"1S=&@S+"!A<G)A>2@W,BP@
M(B=I="<G<R!G;V]D)R(L("1T;7!F:6QE*2D["GT*:68@*"1R97,@/3T]($1"
M7T]+*2!["B`@("!P<FEN="`B<W1H,R!E>&5C=71E9%QN(CL*?2!E;'-E('L*
M("`@('!R:6YT(")S=&@S(&9A:6QE9%QN(CL*?0H*<')I;G0@)W-T:#0Z(&YO
M('!A<F%M<RXN+B`G.PII9B`H*"1R97,@/2`D9&)H+3YE>&5C=71E*"1S=&@T
M*2D@/3T]($1"7T]+*2!["B`@("!P<FEN="`B<W1H-"!E>&5C=71E9%QN(CL*
M?2!E;'-E('L*("`@('!R:6YT(")S=&@T(&9A:6QE9%QN(CL*?0IP<FEN=%]R
M97-U;'1S*"D["@H*+R\@,BD@3VYE('!R97!A<F5D+"!M=6QT:7!L92!T:6UE
M(&5X96-U=&5D"F5C:&\@(EQN+2TM+2TM+2TM+2TM,BTM+2TM+2TM+2TM+5QN
M(CL*"B1D8F@M/G%U97)Y*"=$14Q%5$4@1E)/32!P:'!T97-T)RD["B1S=&@@
M/2`D9&)H+3YP<F5P87)E*"=)3E-%4E0@24Y43R!P:'!T97-T("AA+"!B+"!C
M+"!D*2!604Q515,@*#\L(#\L("8L(#\I)RD["B1D871A(#T@87)R87DH"B`@
M("`P(#T^(&%R<F%Y*#<R+"`G<V5T,2<L("1T;7!F:6QE+"`G,3(S-"TU-BTW
M."<I+`H@("`@,2`]/B!A<G)A>2@W,BP@)W-E=#(G+"`D=&UP9FEL92P@;G5L
M;"DL"B`@("`R(#T^(&%R<F%Y*#<R+"`G<V5T,R<L("1T;7!F:6QE+"!N=6QL
M*0HI.PHD<F5S(#T@)&1B:"T^97AE8W5T94UU;'1I<&QE*"1S=&@L("1D871A
M*3L*<')I;G1?<F5S=6QT<R@I.PH*"B\O(#,I(&9R9650<F5P87)E9"@I('1E
M<W0*96-H;R`B7&XM+2TM+2TM+2TM+2TS+2TM+2TM+2TM+2TM7&XB.PH*:68@
M*"1D8F@M/F9R9650<F5P87)E9"@D<W1H*2D@>PH@("`@96-H;R`G5%)512<[
M"GT@96QS92!["B`@("!E8VAO("=&04Q312<["GT*96-H;R`B7&XB.PII9B`H
M)&1B:"T^9G)E95!R97!A<F5D*#8V-BDI('L*("`@(&5C:&\@)U12544G.PI]
M(&5L<V4@>PH@("`@96-H;R`G1D%,4T4G.PI]"F5C:&\@(EQN(CL*"@HO+R`T
M*2!314Q%0U1S('1E<W1S"F5C:&\@(EQN+2TM+2TM+2TM+2TM-"TM+2TM+2TM
M+2TM+5QN(CL*)'-T:#$@/2`D9&)H+3YP<F5P87)E*")314Q%0U0@*B!&4D]-
M('!H<'1E<W0@5TA%4D4@82`](#\@3U)$15(@0ED@8B(I.PIP<FEN=%\T*"1S
M=&@Q+"`W,BD["G!R:6YT7S0H)'-T:#$L(#<Q*3L*)'-T:#(@/2`D9&)H+3YP
M<F5P87)E*")314Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%4D4@9"`](#\@3U)$
M15(@0ED@8B(I.PIP<FEN=%\T*"1S=&@R+"`G,3(S-"TU-BTW."<I.PHD<W1H
M,R`]("1D8F@M/G!R97!A<F4H(E-%3$5#5"`J($923TT@<&AP=&5S="!72$52
M12!C(#T@)B!/4D1%4B!"62!B(BD["G!R:6YT7S0H)'-T:#,L("1T;7!F:6QE
M*3L*"@HO+R`U*2!!4U-/0TE!5$E612!!4E)!62!Q=65R:65S"F5C:&\@(EQN
M+2TM+2TM+2TM+2TM-2TM+2TM+2TM+2TM+5QN(CL*"B1S=&@U(#T@)&1B:"T^
M<')E<&%R92@G24Y315)4($E.5$\@<&AP=&5S="`H82P@8BP@9"D@5D%,5453
M("@_+"`_+"`_*2<I.PHD87)R87D@/2!A<G)A>2@*("`@("=F;V\G(#T^(#$Q
M+`H@("`@)V)A<B<@/3X@)W1H<F5E)RP*("`@("=B87HG(#T^(&YU;&PL"BD[
M"B1R97,@/2`D9&)H+3YE>&5C=71E*"1S=&@U+"`D87)R87DI.PIP<FEN="`G
M:6YS97)T.B`G("X@*"1R97,@/3T]($1"7T]+(#\@)V]K87DG(#H@)V5R<F]R
M)RD@+B`B7&XB.PH*)'-T:#8@/2`D9&)H+3YP<F5P87)E*"=314Q%0U0@82P@
M8BP@9"!&4D]-('!H<'1E<W0@5TA%4D4@82`](#\G*3L*)')E<R`]("1D8F@M
M/F5X96-U=&4H)'-T:#8L(&%R<F%Y*#$Q*2D["B1R;W<@/2`D<F5S+3YF971C
M:%)O=RA$0E]&151#2$U/1$5?05-33T,I.PIP<FEN="`B82`]('LD<F]W6R=A
M)UU]+"!B(#T@>R1R;W=;)V(G77TL(&0@/2`B.PII9B`H)&1B:"T^<&AP='EP
M92`]/2`G;7-Q;"<I('L*("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=D)RP@
M)')O=RDI('L*("`@("`@("`D='EP92`](&=E='1Y<&4H)')O=ULG9"==*3L*
M("`@("`@("!I9B`H)'1Y<&4@/3T@)TY53$PG('Q\("1R;W=;)V0G72`]/2`G
M)RD@>PH@("`@("`@("`@("!P<FEN="`B9V]T(&5X<&5C=&5D(&]U=&-O;65<
M;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1Y<&4@/2!G971T
M>7!E*"1R;W=;)V0G72D["B`@("`@("`@("`@('!R:6YT(")53BUE>'!E8W1E
M9"!O=71C;VUE.B`D='EP95QN(CL*("`@("`@("!]"B`@("!](&5L<V4@>PH@
M("`@("`@("\O(&AT='`Z+R]B=6=S+G!H<"YN970O/VED/3,Q.38P"B`@("`@
M("`@<')I;G0@(E!R:6]R('1O(%!(4"`T+C,N,3$@;W(@-2XP+C0L(%!(4"=S
M(&US<6P@97AT96YS:6]N('-I;&5N=&QY(@H@("`@("`@("`@("`@("X@(B!D
M<F]P<&5D(&-O;'5M;G,@=VET:"!N=6QL('9A;'5E<RX@66]U(&YE960@=&\@
M=7!G<F%D92Y<;B(["B`@("!]"GT@96QS92!["B`@("`D='EP92`](&=E='1Y
M<&4H)')O=ULG9"==*3L*("`@(&EF("@D='EP92`]/2`G<W1R:6YG)RD@>PH@
M("`@("`@('!R:6YT(")G;W0@97AP96-T960@;W5T8V]M95QN(CL*("`@('T@
M96QS92!["B`@("`@("`@<')I;G0@(E5.+65X<&5C=&5D(&]U=&-O;64Z("1T
M>7!E7&XB.PH@("`@?0I]"@HO*BH*("H@075T;VUA=&EC86QL>2!F<F5E('1H
M92!P<F5P87)E9"!S=&%T96UE;G1S(&%N9"!R97-U;'1S('=H96X@=&AE('-C
M<FEP=`H@*B!T97)M:6YA=&5S"B`J"B`J($!R971U<FX@=F]I9`H@*B\*9G5N
M8W1I;VX@;7E?<VAU=&1O=VXH*2!["B`@("!G;&]B86P@)'1M<&9I;&4L("1D
M8F@L("1S=&@Q+"`D<W1H,BP@)'-T:#,L("1S=&@T+"`D<W1H-2P@)'-T:#8L
M("1R97,["@H@("`@<W=I=&-H("@D9&)H+3YP:'!T>7!E*2!["B`@("`@("`@
M8V%S92`G:6)A<V4G.@H@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!)
M;G1E<F)A<V4@9&]E<VXG="!A;&QO=R!D<F]P<&EN9R!T86)L97,@=&AA="!H
M879E(')E<W5L=`H@("`@("`@("`@("`@*B!S971S('-T:6QL(&]P96XN"B`@
M("`@("`@("`@("`J+PH@("`@("`@("`@("`D9&)H+3YF<F5E4')E<&%R960H
M)'-T:#$I.PH@("`@("`@("`@("`D9&)H+3YF<F5E4')E<&%R960H)'-T:#(I
M.PH@("`@("`@("`@("`D9&)H+3YF<F5E4')E<&%R960H)'-T:#,I.PH@("`@
M("`@("`@("`D9&)H+3YF<F5E4')E<&%R960H)'-T:#0I.PH@("`@("`@("`@
M("`D9&)H+3YF<F5E4')E<&%R960H)'-T:#4I.PH@("`@("`@("`@("`D9&)H
M+3YF<F5E4')E<&%R960H)'-T:#8I.PH@("`@("`@("`@("`D9&)H+3YF<F5E
M4F5S=6QT*"1R97,M/G)E<W5L="D["B`@("`@("`@("`@(&)R96%K.PH@("`@
M?0H*("`@("1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]21515
M4DXI.PH@("`@9')O<%]T86)L92@D9&)H+"`G<&AP=&5S="<I.PH*("`@('5N
M;&EN:R@D=&UP9FEL92D["GT*"B\J*@H@*B!0<FEN="!O=70@=&AE(&1A=&$@
M:6X@=&5S="!T86)L90H@*@H@*B!`<F5T=7)N('9O:60*("HO"F9U;F-T:6]N
M('!R:6YT7W)E<W5L=',H*2!["B`@("!G;&]B86P@)&1B:#L*("`@('!R:6YT
M(")R97-U;'1S.EQN(CL*("`@("1R97,@/2`D9&)H+3YQ=65R>2@B4T5,14-4
M("H@1E)/32!P:'!T97-T(%=(15)%(&$@/2`W,B!/4D1%4B!"62!B(BD["B`@
M("`D:2`](#`["B`@("!W:&EL92`H)')O=R`]("1R97,M/F9E=&-H4F]W*$1"
M7T9%5$-(34]$15]/4D1%4D5$*2D@>PH@("`@("`@('!R:6YT("=\)R`N(&EM
M<&QO9&4H(B`M("(L("1R;W<I("X@(GQ<;B(["B`@("`@("`@)&DK*SL*("`@
M('T*("`@(&EF("@A)&DI('L*("`@("`@("!P<FEN="`B5&AE(')E8V]R9',@
M=V5R92!N;W0@9F]U;F0N("!$:60@=&AE>2!G970@:6YS97)T960_7&XB.PH@
M("`@?0I]"@HO*BH*("H@17AE8W5T92!T:&4@<')E<&%R960@<W1A=&5M96YT
M(&%N9"!P<FEN="!O=70@=&AE(&1A=&$@:6X@=&AE(')E<W5L=`H@*@H@*B!`
M<&%R86T@<F5S;W5R8V4@("`@("1S=&@@("!T:&4@<W1A=&5M96YT(&AA;F1L
M92!T;R!P<F]C97-S"B`J($!P87)A;2!S=')I;F=\87)R87D@)&)I;F0@('1H
M92!D871A('1H870@=VEL;"!R97!L86-E('1H92!P;&%C96AO;&1E<G,*("H*
M("H@0')E='5R;B!V;VED"B`J+PIF=6YC=&EO;B!P<FEN=%\T*"1S=&@L("1B
M:6YD*2!["B`@("!G;&]B86P@)&1B:#L*("`@("1R97,@/2`D9&)H+3YE>&5C
M=71E*"1S=&@L("1B:6YD*3L*("`@('=H:6QE("@D<F]W(#T@)')E<RT^9F5T
M8VA2;W<H1$)?1D540TA-3T1%7T]21$52140I*2!["B`@("`@("`@<')I;G0@
M)WPG("X@:6UP;&]D92@B("T@(BP@)')O=RD@+B`B?%QN(CL*("`@('T*("`@
M(&5C:&\@(GY^7&XB.PI]"@``````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+W1E<W1S+T1"+W1E<W1S+W)U;BYC=G,`````````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`Q-C4Q`#$P-3$U-#,S-S0R`#`R,C<R,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````C(2`O8FEN+W-H"@HC
M("1)9#H@<G5N+F-V<RQV(#$N,R`R,#`T+S`R+S(P(#$X.C4W.C4Q(&1A;FEE
M;&,@17AP("0*"B,@=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V
M=G9V=G9V=G9V=G9V=G9V=G8*(R!014%2($1"(%1%4U0@4U1!4E1%4@HC"B,@
M("!4;R!R=6X@86QL('1E<W1S.B`@+B]R=6X*(R`@(%1O(')U;B!O;F4@=&5S
M=#H@("`N+W)U;B`\=&5S="!F:6QE(&YA;64^"B,@("!%>&%M<&QE.B`@("`@
M("`@("`@+B]R=6X@9&)?<&%R<V5D<VXN<&AP=`HC"B,@0F5F;W)E(')U;FYI
M;F<@=&AE('1E<W1S('EO=2!M=7-T(&%D:G5S="!T:&4*(R!F;VQL;W=I;F<@
M=&AR964@=F%R:6%B;&5S.@H*(R`@(%1H92!F=6QL('!A=&@@=&\@>6]U<B!0
M2%`@9&ER96-T;W)Y.@H@("`@1$)?5$535%]02%!?4$%42#UC.B]P<F]G<F%^
M,2]P:'`*"B,@("!4:&4@;F%M92!O9B!Y;W5R(%!(4"!#3$D@97AE8W5T86)L
M90HC("`@*&5X86UP;&5S('!H<"YE>&4L('!H<"UC;&DN97AE+"!C;&DO<&AP
M+F5X92DZ"B`@("!$0E]415-47U!(4%]#3$D]<&AP+F5X90H*(R`@(%1H92!F
M=6QL('!A=&@@=&\@=&AE('!R97-E;G0@9&ER96-T;W)Y"B,@("`H;F]T('5S
M:6YG("105T0@9'5E('1O($-Y9W=I;BDZ"B`@("!$0E]415-47T1)4CUD.B]P
M96%R=&5S="]P96%R+T1"+W1E<W1S"@HC(%Y>7EY>7EY>7EY>7EY>7EY>7EY>
M7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>"@H*"E1%4U1?4$A07T58
M14-55$%"3$4])$1"7U1%4U1?4$A07U!!5$@O)$1"7U1%4U1?4$A07T-,20IE
M>'!O<G0@5$535%]02%!?15A%0U5404),10H*:68@6R`D(R`M9W0@,"!="G1H
M96X*("`@('1E<W0])#$*96QS90H@("`@=&5S=#TJ+G!H<'0*9FD*"B1415-4
M7U!(4%]%6$5#551!0DQ%("1$0E]415-47U!(4%]0051(+W)U;BUT97-T<RYP
M:'`@)$1"7U1%4U1?1$E2+R1[=&5S='T*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+W1E<W1S+T1"+W1E<W1S+W-E<75E;F-E<RYI;F,`````````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`W-38Q`#$P-3$U-#,S-S0R`#`R-#`W,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M+RHJ"B`J(%1E<W1S('1H92!D<FEV97)S)R!S97%U96YC92`H86MA(&%U=&]?
M:6YC<F5M96YT*2!M971H;V1S"B`J"B`J($5X96-U=&5D(&)Y(&1R:79E<B\P
M-7-E<75E;F-E<RYP:'!T"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J
M"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V
M97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I
M;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO
M=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@
M4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$
M0@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H
M<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P
M"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("`D260Z('-E
M<75E;F-E<RYI;F,L=B`Q+C$Q(#(P,#4O,#(O,3@@,C(Z,S@Z-#,@9&%N:65L
M8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A
M8VMA9V4O1$(*("HO"@HO*BH*("H@3&]C86P@97)R;W(@:&%N9&QE<@H@*B\*
M9G5N8W1I;VX@97)R;W)?:&%N9&QE<B@F)&]B:BD@>PH@("`@<')I;G0@(G-E
M<75E;F-E<RYI;F,@97)R;W)?:&%N9&QE<CI<;B`@("`B.PH@("`@<')I;G0@
M)&]B:BT^9V5T1&5B=6=);F9O*"D@+B`B7&Y<;B(["GT*;V)?:6UP;&EC:71?
M9FQU<V@H=')U92D["@HD9')O<"`]("1D8F@M/F1R;W!397%U96YC92@G=&5S
M="<I.PII9B`H1$(Z.FES17)R;W(H)&1R;W`I("8F"B`@("`D9')O<"T^9V5T
M0V]D92@I("$]($1"7T524D]27TY/4U5#2%1!0DQ%*0I["B`@("!P<FEN="`B
M0V]U;&0@;F]T(&1R;W`@<V5Q=65N8V4N+BY<;B(["B`@("!P<FEN="`D9')O
M<"T^9V5T1&5B=6=);F9O*"D@+B`B7&Y<;B(["B`@("!I9B`H)&1B:"T^<&AP
M='EP92`]/2`G:6)A<V4G("8F"B`@("`@("`@)&1R;W`M/F=E=$-O9&4H*2`]
M/2!$0E]%4E)/4E]!0T-%4U-?5DE/3$%424].*0H@("`@>PH@("`@("`@('!R
M:6YT(")5<V4@=&AI<R!Q=65R>2!T;R!P<F]V:61E('1H92!P97)M:7-S:6]N
M<R!N965D960Z7&XB.PH@("`@("`@('!R:6YT("<@("!G<F%N="!A;&P@;VX@
M4D1")$=%3D52051/4E,@=&\@/%5315).04U%/B<["B`@("!]"B`@("!E>&ET
M.PI]"@HO+R`Q*2!T97-T('1H870@<V5Q=65N8V5S(&%R92!N;W0@8W)E871E
M9"!I9B`B;VYD96UA;F0B(&ES(&9A;'-E"@HD92`]("1D8F@M/FYE>'1)9"@B
M=&5S="(L(&9A;'-E*3L*:68@*$1".CII<T5R<F]R*"1E*2`F)B`D92T^9V5T
M0V]D92@I(#T]($1"7T524D]27TY/4U5#2%1!0DQ%*2!["B`@("!P<FEN="`B
M86X@97)R;W(@:7,@=&AE('!R;W!E<B!R97-P;VYS92!H97)E7&XB.PI](&5L
M<V4@>PH@("`@:68@*$1".CII<T5R<F]R*"1E*2D@>PH@("`@("`@(&EF("@D
M9&)H+3YP:'!T>7!E(#T]("=I8F%S92<@)B8@)&4M/F=E=$-O9&4H*2`]/2!$
M0E]%4E)/4E]364Y405@I('L*("`@("`@("`@("`@<')I;G0@(F%N(&5R<F]R
M(&ES('1H92!P<F]P97(@<F5S<&]N<V4@:&5R95QN(CL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!P<FEN="`B=&5S="`Q*2!W92!E>'!E8W1E9"!T
M;R!G970@8F%C:R`G1$(@17)R;W(Z(&YO('-U8V@@=&%B;&4G+EQN(CL*("`@
M("`@("`@("`@<')I;G0@(DAE<F4@:7,@=&AE(&5R<F]R('=E(&=O=#I<;B([
M"B`@("`@("`@("`@('!R:6YT("=#;V1E.B`G("X@)&4M/F=E=$-O9&4H*2`N
M(")<;B(["B`@("`@("`@("`@('!R:6YT("=-97-S86=E.B`G("X@)&4M/F=E
M=$UE<W-A9V4H*2`N(")<;B(["B`@("`@("`@("`@('!R:6YT("=$96)U9SH@
M)R`N("1E+3YG971$96)U9TEN9F\H*2`N(")<;EQN(CL*("`@("`@("!]"B`@
M("!](&5L<V4@>PH@("`@("`@('!R:6YT(")T97-T(#$I('=E(&5X<&5C=&5D
M('1O(&=E="!B86-K("=$0B!%<G)O<CH@;F\@<W5C:"!T86)L92<N7&XB.PH@
M("`@("`@('!R:6YT(")"=70@86X@97)R;W(@=V%S;B=T(&=E;F5R871E9%QN
M7&XB.PH@("`@?0I]"@HO+R`R*2!T97-T('1H870@=&AE('-E<75E;F-E(&ES
M(&YO="!C<F5A=&5D(&)U="!T:&4@97)R;W(@:7,*+R\@:&%N9&QE9"!B>2!T
M:&4@8VQA<W,@97)R;W(@:&%N9&QE<@HD9&)H+3YS971%<G)O<DAA;F1L:6YG
M*%!%05)?15)23U)?4%))3E0L"B`@("`@("`@("`@("`@("`@("`@("`@(F%N
M(&5R<F]R(&-O=6=H="!B>2!T:&4@97)R;W(@:&%N9&QE<B!I<R!G;V]D7&XB
M*3L*)&4@/2`D9&)H+3YN97AT260H(G1E<W0B+"!F86QS92D["FEF("@A1$(Z
M.FES17)R;W(H)&4I*2!["B`@("!P<FEN="`B=&5S="`R*2!F86EL960A7&XB
M.PI]"B1D8F@M/E]D969A=6QT7V5R<F]R7VUO9&4@/2!N=6QL.PH*+R\@,RD@
M=&5S="!T:&%T('-E<75E;F-E<R!A<F4@8W)E871E9"!I9B`B;VYD96UA;F0B
M(&ES('1R=64L(&%N9"!T:&%T"B\O('1W;R!S=6-C97-S:79E(&YE>'1)9',@
M<F5T=7)N(&%D:F%C96YT('9A;'5E<PHD82`]("1D8F@M/FYE>'1)9"@B=&5S
M="(I.PHD8B`]("1D8F@M/FYE>'1)9"@B=&5S="(I.PII9B`H1$(Z.FES17)R
M;W(H)&$I*2!["B`@("!P<FEN="`G83H@)R`N("1A+3YG971$96)U9TEN9F\H
M*2`N(")<;EQN(CL*?2!E;'-E('L*("`@('!R:6YT(")A/21A7&XB.PI]"FEF
M("A$0CHZ:7-%<G)O<B@D8BDI('L*("`@('!R:6YT("=B.B`G("X@)&(M/F=E
M=$1E8G5G26YF;R@I("X@(EQN7&XB.PI](&5L<V4@>PH@("`@<')I;G0@(F(]
M)&)<;B(["GT*:68@*"%$0CHZ:7-%<G)O<B@D82D@)B8@(41".CII<T5R<F]R
M*"1B*2D@>PH@("`@<')I;G0@)V(M83TG("X@*"1B+21A*2`N(")<;B(["GT*
M"B\O(#0I('1E<W0@=&AA="!T:&4@=7-E<BUS<&5C:69I960@97)R;W(@:&%N
M9&QE<B!I<R!R96%L;'D@9&ES86)L960*+R\@9'5R:6YG(&YE>'1)9"P@=VET
M:"!P97(M;V)J96-T(&AA;F1L97(@87,@=V5L;"!A<R!G;&]B86P@:&%N9&QE
M<@HD9&)H+3YD<F]P4V5Q=65N8V4H(G1E<W0B*3L*"B1D8F@M/G-E=$5R<F]R
M2&%N9&QI;F<H4$5!4E]%4E)/4E]#04Q,0D%#2RP@)V5R<F]R7VAA;F1L97(G
M*3L*)&,@/2`D9&)H+3YN97AT260H(G1E<W0B*3L*:68@*"%$0CHZ:7-%<G)O
M<B@D8RDI('L*("`@('!R:6YT(")C/21C7&XB.PI]"B1D8F@M/F1R;W!397%U
M96YC92@B=&5S="(I.PHD9&)H+3Y?9&5F875L=%]E<G)O<E]M;V1E(#T@;G5L
M;#L*)&0@/2`D9&)H+3YN97AT260H(G1E<W0B*3L*:68@*"%$0CHZ:7-%<G)O
M<B@D9"DI('L*("`@('!R:6YT(")D/21D7&XB.PI]"@HO+R`U*2!T97-T('1H
M870@=&AE('-E<75E;F-E(&ES(&AA;F1L960@<FEG:'0@=VAE;B!T:&4@=&%B
M;&4@:7,@96UP='D*"B\O($)A8VME;F0@=VET:"!R96%L('-E<75E;F-E<R!M
M87D@9&]N)W0@;&EK92!T:&%T"E!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG*%!%
M05)?15)23U)?4D5455).*3L*)&1B:"T^<75E<GDH)T1%3$5412!&4D]-('1E
M<W1?<V5Q)RD["E!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L*)&4@/2`D9&)H
M+3YN97AT240H)W1E<W0G*3L*:68@*$1".CII<T5R<F]R*"1D*2D@>PH@("`@
M<')I;G0@)V4Z("<@+B`D9"T^9V5T1&5B=6=);F9O*"D@+B`B7&Y<;B(["GT@
M96QS92!["B`@("!P<FEN="`B93TD9%QN(CL*?0H*+R\@9FEN86P@8VQE86XM
M=7`*)&1B:"T^9')O<%-E<75E;F-E*")T97-T(BD["@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+W-I;7!L
M97%U97)Y+FEN8P``````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-C(U`#$P-3$U
M-#,S-S0R`#`R-#0U-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`H*+RHJ"B`J(%1E<W1S('1H92!D<FEV97)S)R!S
M:6UP;&51=65R>2@I(&UE=&AO9`H@*@H@*B!%>&5C=71E9"!B>2!D<FEV97(O
M,#-S:6UP;&5Q=65R>2YP:'!T"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U
M"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T
M;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A
M=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O
M;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T
M:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H
M<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@
M("!$0@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC
M0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R
M;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("`D260Z
M('-I;7!L97%U97)Y+FEN8RQV(#$N."`R,#`U+S`R+S`S(#`U.C0Y.C0T(&1A
M;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+T1""B`J+PH*+RHJ"B`J($QO8V%L(&5R<F]R(&-A;&QB86-K
M(&AA;F1L97(*("H*("H@1')O<',@=&AE('!H<'1E<W0@=&%B;&4L('!R:6YT
M<R!O=70@86X@97)R;W(@;65S<V%G92!A;F0@:VEL;',@=&AE"B`J('!R;V-E
M<W,N"B`J"B`J($!P87)A;2!O8FIE8W0@("1O("!014%2(&5R<F]R(&]B:F5C
M="!A=71O;6%T:6-A;&QY('!A<W-E9"!T;R!T:&ES(&UE=&AO9`H@*B!`<F5T
M=7)N('9O:60*("H@0'-E92!014%2.CIS971%<G)O<DAA;F1L:6YG*"D*("HO
M"F9U;F-T:6]N('!E*"1O*2!["B`@("!G;&]B86P@)&1B:#L*"B`@("`D9&)H
M+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*("`@(&1R
M;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G*3L*"B`@("!D:64H)&\M/G1O4W1R
M:6YG*"DI.PI]"@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M0T%,3$)!0TLL("=P92<I.PH*"B1S=&@@/2`D9&)H+3YS:6UP;&51=65R>2@B
M4T5,14-4("H@1E)/32!P:'!T97-T(BD["@IS=VET8V@@*"1D8F@M/G!H<'1Y
M<&4I('L*("`@(&-A<V4@)VUY<W%L:2<Z"B`@("`@("`@:68@*&ES7V$H)'-T
M:"P@)VUY<W%L:5]R97-U;'0G*2D@>PH@("`@("`@("`@("!P<FEN="`B<&%S
M<V5D7&XB.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('!R:6YT(")0
M4D]"3$5-7&XB.PH@("`@("`@('T*("`@("`@("!B<F5A:SL*("`@(&1E9F%U
M;'0Z"B`@("`@("`@:68@*&=E='1Y<&4H)'-T:"D@/3T@)W)E<V]U<F-E)RD@
M>PH@("`@("`@("`@("!P<FEN="`B<&%S<V5D7&XB.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@('!R:6YT(")04D]"3$5-7&XB.PH@("`@("`@('T*
M?0H*"G-W:71C:"`H)&1B:"T^<&AP='EP92D@>PH@("`@8V%S92`G:6)A<V4G
M.@H@("`@("`@("\J"B`@("`@("`@("H@26YT97)B87-E(&1O97-N)W0@86QL
M;W<@9')O<'!I;F<@=&%B;&5S('1H870@:&%V92!R97-U;'0*("`@("`@("`@
M*B!S971S('-T:6QL(&]P96XN"B`@("`@("`@("HO"B`@("`@("`@)&1B:"T^
M9G)E95)E<W5L="@D<W1H*3L*("`@("`@("!B<F5A:SL*?0HD9&)H+3YS971%
M<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*9')O<%]T86)L92@D
M9&)H+"`G<&AP=&5S="<I.PH`````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]S:VEP:68N:6YC
M```````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,38U-P`Q,#4Q-30S,S<T
M,@`P,C,S-C4`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"B\J*@H@*B!!('1E<W0@=&\@;6%K92!S=7)E(%!%05(@
M1$(@8V%N(&)E(&9O=6YD"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J
M"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V
M97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I
M;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO
M=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@
M4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$
M0@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H
M<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P
M"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("`D260Z('-K
M:7!I9BYI;F,L=B`Q+C(@,C`P-2\P,B\P,R`P-3HT.3HT-"!D86YI96QC($5X
M<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]$0@H@*B\*"B\J*@H@*B!3970@=7`@=&AE(&EN8VQU9&5?<&%T:"P@97)R
M;W)?<F5P;W)T:6YG(&%N9"!0051(7U-%4$%2051/4@H@*B\*<F5Q=6ER95]O
M;F-E("<N+VEN8VQU9&4N:6YC)SL*"FEF("@A:6YC;'5D95]O;F-E("=$0BYP
M:'`G*2!["B`@("!P<FEN="`G<VMI<"!C;W5L9"!N;W0@9FEN9"!$0BYP:'`G
M.PI]"@``````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]T<F%N
M<V%C=&EO;G,N:6YC````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-38T-``Q,#4Q
M-30S,S<T,@`P,C0V,3``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"B\J*@H@*B!497-T<R!T:&4@9')I=F5R<R<@
M=')A;G-A8W1I;VX@:&%N9&QI;F<@;65T:&]D<PH@*@H@*B!%>&5C=71E9"!B
M>2!D<FEV97(O,3%T<F%N<V%C=&EO;G,N<&AP=`H@*@H@*B!02%`@=F5R<VEO
M;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J
M('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O
M<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B
M=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T
M92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P
M>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@
M0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O
M<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@
M5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I
M;VX@("`@)$ED.B!T<F%N<V%C=&EO;G,N:6YC+'8@,2XY(#(P,#4O,#(O,#,@
M,#4Z-#DZ-#0@9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"@HO+R!497-T:6YG(&AE<F4@
M9'5E('1O('-K:7`@;F]T('=O<FMI;F<@8W5R<F5N=&QY(&EN(&AE860*:68@
M*"$D9&)H+3YF96%T=7)E<ULG=')A;G-A8W1I;VYS)UTI('L*("`@(&1I92@G
M=&AI<R!D<FEV97(@9&]E<R!N;W0@<W5P<&]R="!T<F%N<V%C=&EO;G,G*3L*
M?0H*+R\@5FEE=R!T:&4@=&%B;&4@9G)O;2!A('-E<&%R871E(&-O;FYE8W1I
M;VX@<V\@=V4@9&]N)W0@9&ES='5R8@HO+R!T:&4@=')A;G-A8W1I;VXN"B1D
M8F@R(#T@1$(Z.F-O;FYE8W0H)&1B:"T^9'-N*3L*"F9U;F-T:6]N(&5R<F]R
M7VAA;F1L97(H)B1O8FHI('L*("`@('!R:6YT(")<;B(@+B`D;V)J+3YG971$
M96)U9TEN9F\H*2`N(")<;B(["GT*"F9U;F-T:6]N(&1U;7!T86)L92@D97AP
M96-T960I('L*("`@(&=L;V)A;"`D9&)H+"`D9&)H,CL*("`@('!R:6YT(&EM
M<&QO9&4H)R`G+"`D9&)H+3YG971#;VPH)U-%3$5#5"!B($923TT@<&AP=&5S
M="<I*3L*"B`@("!I9B`H:7-S970H)&1B:"T^=')A;G-A8W1I;VY?;W!C;W5N
M="DI('L*("`@("`@("!I9B`H)&5X<&5C=&5D(#T]("1D8F@M/G1R86YS86-T
M:6]N7V]P8V]U;G0I('L*("`@("`@("`@("`@<')I;G0@(BX@(&]P<SUO:UQN
M(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!P<FEN="`B+B`@;W!S
M/21D8F@M/G1R86YS86-T:6]N7V]P8V]U;G1<;B(["B`@("`@("`@?0H@("`@
M?2!E;'-E('L*("`@("`@("!P<FEN="`B+B`@;W!S/6]K7&XB.PH@("`@?0I]
M"@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL
M("=E<G)O<E]H86YD;&5R)RD["@H*)&1B:"T^875T;T-O;6UI="AT<G5E*3L*
M)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!H<'1E<W0@5D%,5453*#$L("=O
M;F4G+"`G3VYE)RP@)S(P,#$M,#(M,3DG*2(I.PH*<')I;G0@)S$I(&%F=&5R
M(&%U=&]C;VUM:70Z("<["F1U;7!T86)L92@P*3L*"B1D8F@M/F%U=&]#;VUM
M:70H9F%L<V4I.PHD9&)H+3YQ=65R>2@B24Y315)4($E.5$\@<&AP=&5S="!6
M04Q515,H,BP@)W1W;R<L("=4=V\G+"`G,C`P,2TP,BTR,"<I(BD["B1D8F@M
M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T(%9!3%5%4R@S+"`G=&AR964G
M+"`G5&AR964G+"`G,C`P,2TP,BTR,2<I(BD["G!R:6YT("<R*2!B969O<F4@
M8V]M;6ET.B`G.PID=6UP=&%B;&4H,BD["@HD9&)H+3YC;VUM:70H*3L*<')I
M;G0@)S,I(&%F=&5R(&-O;6UI=#H@)SL*9'5M<'1A8FQE*#`I.PH*)&1B:"T^
M<75E<GDH(DE.4T525"!)3E1/('!H<'1E<W0@5D%,5453*#0L("=F;W5R)RP@
M)T9O=7(G+"`G,C`P,2TP,BTR,B<I(BD["B1D8F@M/G%U97)Y*"))3E-%4E0@
M24Y43R!P:'!T97-T(%9!3%5%4R@U+"`G9FEV92<L("=&:79E)RP@)S(P,#$M
M,#(M,C,G*2(I.PIP<FEN="`G-"D@8F5F;W)E(')O;&QB86-K.B`G.PID=6UP
M=&%B;&4H,BD["@HD9&)H+3YR;VQL8F%C:R@I.PIP<FEN="`G-2D@869T97(@
M<F]L;&)A8VLZ("<["F1U;7!T86)L92@P*3L*)&1B:"T^<F]L;&)A8VLH*3L*
M"B1D8F@M/F%U=&]#;VUM:70H=')U92D["B1D8F@M/G%U97)Y*"))3E-%4E0@
M24Y43R!P:'!T97-T(%9!3%5%4R@V+"`G<VEX)RP@)U-I>"<L("<R,#`Q+3`R
M+3(T)RDB*3L*)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!H<'1E<W0@5D%,
M5453*#<L("=S979E;B<L("=3979E;B<L("<R,#`Q+3`R+3(U)RDB*3L*<')I
M;G0@)S8I(&)E9F]R92!A=71O8V]M;6ET*W)O;&QB86-K.B`G.PID=6UP=&%B
M;&4H,"D["@HD9&)H+3YR;VQL8F%C:R@I.PIP<FEN="`G-RD@869T97(@875T
M;V-O;6UI="MR;VQL8F%C:SH@)SL*9'5M<'1A8FQE*#`I.PH*<')I;G0@)S@I
M('1E<W1I;F<@=&AA="!S96QE8W0@9&]E<VY<)W0@9&ES='5R8F4@;W!C;W5N
M=#H@)SL*)&1B:"T^875T;T-O;6UI="AF86QS92D["B1D8F@M/G-I;7!L95%U
M97)Y*")314Q%0U0@*B!&4D]-('!H<'1E<W0B*3L*)&1B:"T^<VEM<&QE475E
M<GDH(E-%3$5#5"!A+&,@1E)/32!P:'!T97-T(BD["B1D8F@M/G-I;7!L95%U
M97)Y*")314Q%0U0@8BQD($923TT@<&AP=&5S="(I.PII9B`H96UP='DH)&1B
M:"T^=')A;G-A8W1I;VY?;W!C;W5N="DI('L*("`@('!R:6YT(")O:UQN(CL*
M?2!E;'-E('L*("`@('!R:6YT(")F86EL960@*&-O=6YT/21D8F@M/G1R86YS
M86-T:6]N7V]P8V]U;G0I7&XB.PI]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+W1E<W1S+T9I;&4O````````````````````````````````
M`````````````````````````````````````````````#`P,#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S0R`#`R,#8R-``@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1FEL92]T97-T<R\`
M````````````````````````````````````````````````````````````
M````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U
M,34T,S,W-#,`,#(Q-S8W`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T
M97-T<R]&:6QE+W1E<W1S+T-35B\`````````````````````````````````
M```````````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<T,P`P,C(T,C(`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S=',O0U-6+S`P,2YC<W8`
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3<V`#$P-3$U-#,S-S0S`#`R
M,S0T,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```B1FEE;&0@,2TQ(BP@(D9I96QD(#$M,B(L(")&:65L9"`Q+3,B+"`B1FEE
M;&0@,2TT(@HB1FEE;&0@,BTQ(BP@(D9I96QD(#(M,B(L(")&:65L9"`R+3,B
M"B)&:65L9"`S+3$B+"`B1FEE;&0@,RTR(@HB1FEE;&0@-"TQ(@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]&:6QE+W1E<W1S+T-35B\P,#$N<&AP=```````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C$U,0`Q,#4Q-30S,S<T,P`P,C,V,38`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+2U415-4+2T*
M1FEL95]#4U8@5&5S="!#87-E(#`P,3H@1FEE;&1S(&-O=6YT(&QE<W,@=&AA
M;B!E>'!E8W1E9`HM+49)3$4M+0H\/W!H<`HO+R`D260Z(#`P,2YP:'!T+'8@
M,2XR(#(P,#4O,#(O,3@@,3$Z,3DZ,S,@9'5F=7H@17AP("0*+RHJ"B`J(%1E
M<W0@9F]R.@H@*B`M($9I;&5?0U-6.CID:7-C;W9E<D9O<FUA="@I"B`J("T@
M1FEL95]#4U8Z.G)E860H*0H@*B\*"G)E<75I<F5?;VYC92`G1FEL92]#4U8N
M<&AP)SL*"B1F:6QE(#T@)S`P,2YC<W8G.PHD8V]N9B`]($9I;&5?0U-6.CID
M:7-C;W9E<D9O<FUA="@D9FEL92D["@IP<FEN="`B1F]R;6%T.EQN(CL*<')I
M;G1?<B@D8V]N9BD["G!R:6YT(")<;B(["@HD9&%T82`](&%R<F%Y*"D["G=H
M:6QE("@D<F5S(#T@1FEL95]#4U8Z.G)E860H)&9I;&4L("1C;VYF*2D@>PH@
M("`@)&1A=&%;72`]("1R97,["GT*"G!R:6YT(")$871A.EQN(CL*<')I;G1?
M<B@D9&%T82D["C\^"BTM15A014-4+2T*1F]R;6%T.@I!<G)A>0HH"B`@("!;
M9FEE;&1S72`]/B`T"B`@("!;<V5P72`]/B`L"B`@("!;<75O=&5=(#T^("(*
M*0H*1&%T83H*07)R87D**`H@("`@6S!=(#T^($%R<F%Y"B`@("`@("`@*`H@
M("`@("`@("`@("!;,%T@/3X@1FEE;&0@,2TQ"B`@("`@("`@("`@(%LQ72`]
M/B!&:65L9"`Q+3(*("`@("`@("`@("`@6S)=(#T^($9I96QD(#$M,PH@("`@
M("`@("`@("!;,UT@/3X@1FEE;&0@,2TT"B`@("`@("`@*0H*("`@(%LQ72`]
M/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@("`@6S!=(#T^($9I96QD(#(M
M,0H@("`@("`@("`@("!;,5T@/3X@1FEE;&0@,BTR"B`@("`@("`@("`@(%LR
M72`]/B!&:65L9"`R+3,*("`@("`@("`@("`@6S-=(#T^(`H@("`@("`@("D*
M"B`@("!;,ET@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%LP72`]
M/B!&:65L9"`S+3$*("`@("`@("`@("`@6S%=(#T^($9I96QD(#,M,@H@("`@
M("`@("`@("!;,ET@/3X@"B`@("`@("`@("`@(%LS72`]/B`*("`@("`@("`I
M"@H@("`@6S-=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;,%T@
M/3X@1FEE;&0@-"TQ"B`@("`@("`@("`@(%LQ72`]/B`*("`@("`@("`@("`@
M6S)=(#T^(`H@("`@("`@("`@("!;,UT@/3X@"B`@("`@("`@*0H**0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S=',O
M0U-6+S`P,BYC<W8`````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,C,R`#$P
M-3$U-#,S-S0S`#`R,S0S-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````B1FEE;&0@,2TQ(BP@(D9I96QD(#$M,B(L(")&:65L
M9"`Q+3,B+"`B1FEE;&0@,2TT(@HB1FEE;&0@,BTQ(BP@(D9I96QD(#(M,B(L
M(")&:65L9"`R+3,B+"`B1FEE;&0@,BTT(BP@(D5X=')A($9I96QD(@HB1FEE
M;&0@,RTQ(BP@(D9I96QD(#,M,B(*(D9I96QD(#0M,2(*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE+W1E<W1S+T-35B\P,#(N<&AP
M=``````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$V,@`Q,#4Q-30S,S<T,P`P
M,C,V,C$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+2U415-4+2T*1FEL95]#4U8@5&5S="!#87-E(#`P,CH@1FEE;&1S(&-O
M=6YT(&UO<F4@=&AA;B!E>'!E8W1E9`HM+49)3$4M+0H\/W!H<`HO+R`D260Z
M(#`P,BYP:'!T+'8@,2XR(#(P,#4O,#(O,3@@,3$Z,3DZ,S,@9'5F=7H@17AP
M("0*+RHJ"B`J(%1E<W0@9F]R.@H@*B`M($9I;&5?0U-6.CID:7-C;W9E<D9O
M<FUA="@I"B`J("T@1FEL95]#4U8Z.G)E860H*0H@*B\*"G)E<75I<F5?;VYC
M92`G1FEL92]#4U8N<&AP)SL*"B1F:6QE(#T@)S`P,BYC<W8G.PHD8V]N9B`]
M($9I;&5?0U-6.CID:7-C;W9E<D9O<FUA="@D9FEL92D["@IP<FEN="`B1F]R
M;6%T.EQN(CL*<')I;G1?<B@D8V]N9BD["G!R:6YT(")<;B(["@HD9&%T82`]
M(&%R<F%Y*"D["G=H:6QE("@D<F5S(#T@1FEL95]#4U8Z.G)E860H)&9I;&4L
M("1C;VYF*2D@>PH@("`@)&1A=&%;72`]("1R97,["GT*"G!R:6YT(")$871A
M.EQN(CL*<')I;G1?<B@D9&%T82D["C\^"BTM15A014-4+2T*1F]R;6%T.@I!
M<G)A>0HH"B`@("!;9FEE;&1S72`]/B`T"B`@("!;<V5P72`]/B`L"B`@("!;
M<75O=&5=(#T^("(**0H*1&%T83H*07)R87D**`H@("`@6S!=(#T^($%R<F%Y
M"B`@("`@("`@*`H@("`@("`@("`@("!;,%T@/3X@1FEE;&0@,2TQ"B`@("`@
M("`@("`@(%LQ72`]/B!&:65L9"`Q+3(*("`@("`@("`@("`@6S)=(#T^($9I
M96QD(#$M,PH@("`@("`@("`@("!;,UT@/3X@1FEE;&0@,2TT"B`@("`@("`@
M*0H*("`@(%LQ72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@("`@6S!=
M(#T^($9I96QD(#(M,0H@("`@("`@("`@("!;,5T@/3X@1FEE;&0@,BTR"B`@
M("`@("`@("`@(%LR72`]/B!&:65L9"`R+3,*("`@("`@("`@("`@6S-=(#T^
M($9I96QD(#(M-`H@("`@("`@("D*"B`@("!;,ET@/3X@07)R87D*("`@("`@
M("`H"B`@("`@("`@("`@(%LP72`]/B!&:65L9"`S+3$*("`@("`@("`@("`@
M6S%=(#T^($9I96QD(#,M,@H@("`@("`@("`@("!;,ET@/3X@"B`@("`@("`@
M("`@(%LS72`]/B`*("`@("`@("`I"@H@("`@6S-=(#T^($%R<F%Y"B`@("`@
M("`@*`H@("`@("`@("`@("!;,%T@/3X@1FEE;&0@-"TQ"B`@("`@("`@("`@
M(%LQ72`]/B`*("`@("`@("`@("`@6S)=(#T^(`H@("`@("`@("`@("!;,UT@
M/3X@"B`@("`@("`@*0H**0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S
M+T9I;&4O=&5S=',O0U-6+S`P,RYC<W8`````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,C(R`#$P-3$U-#,S-S0S`#`R,S0S-0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````B1FEE;&0@,2TQ(BPB1FEE;&0@
M,2TR(BPB1FEE;&0@,2TS(BPB1FEE;&0@,2TT(@T*(D9I96QD(#(M,2(L(D9I
M96QD(#(M,B(L(D9I96QD(#(M,R(L(DDG;2!M=6QT:6QI;F4-"D9I96QD(@T*
M(D9I96QD(#,M,2(L(D9I96QD(#,M,B(L(D9I96QD(#,M,R(-"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE+W1E<W1S
M+T-35B\P,#,N<&AP=```````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3<V,@`Q
M,#4Q-30S,S<T,P`P,C,V,C<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+2U415-4+2T*1FEL95]#4U8@5&5S="!#87-E(#`P
M,SH@5VEN9&]W<R!%3TP*+2U&24Q%+2T*/#]P:'`*+R\@)$ED.B`P,#,N<&AP
M="QV(#$N,B`R,#`U+S`R+S$X(#$Q.C$Y.C,S(&1U9G5Z($5X<"`D"B\J*@H@
M*B!497-T(&9O<CH*("H@+2!&:6QE7T-35CHZ9&ES8V]V97)&;W)M870H*0H@
M*B`M($9I;&5?0U-6.CIR96%D*"D*("HO"@IR97%U:7)E7V]N8V4@)T9I;&4O
M0U-6+G!H<"<["@HD9FEL92`]("<P,#,N8W-V)SL*)&-O;F8@/2!&:6QE7T-3
M5CHZ9&ES8V]V97)&;W)M870H)&9I;&4I.PH*<')I;G0@(D9O<FUA=#I<;B([
M"G!R:6YT7W(H)&-O;F8I.PIP<FEN="`B7&XB.PH*)&1A=&$@/2!A<G)A>2@I
M.PIW:&EL92`H)')E<R`]($9I;&5?0U-6.CIR96%D*"1F:6QE+"`D8V]N9BDI
M('L*("`@("1D871A6UT@/2`D<F5S.PI]"@IP<FEN="`B1&%T83I<;B(["G!R
M:6YT7W(H)&1A=&$I.PH_/@HM+4584$5#5"TM"D9O<FUA=#H*07)R87D**`H@
M("`@6V9I96QD<UT@/3X@-`H@("`@6W-E<%T@/3X@+`H@("`@6W%U;W1E72`]
M/B`B"BD*"D1A=&$Z"D%R<F%Y"B@*("`@(%LP72`]/B!!<G)A>0H@("`@("`@
M("@*("`@("`@("`@("`@6S!=(#T^($9I96QD(#$M,0H@("`@("`@("`@("!;
M,5T@/3X@1FEE;&0@,2TR"B`@("`@("`@("`@(%LR72`]/B!&:65L9"`Q+3,*
M("`@("`@("`@("`@6S-=(#T^($9I96QD(#$M-`H@("`@("`@("D*"B`@("!;
M,5T@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%LP72`]/B!&:65L
M9"`R+3$*("`@("`@("`@("`@6S%=(#T^($9I96QD(#(M,@H@("`@("`@("`@
M("!;,ET@/3X@1FEE;&0@,BTS"B`@("`@("`@("`@(%LS72`]/B!))VT@;75L
M=&EL:6YE"D9I96QD"B`@("`@("`@*0H*("`@(%LR72`]/B!!<G)A>0H@("`@
M("`@("@*("`@("`@("`@("`@6S!=(#T^($9I96QD(#,M,0H@("`@("`@("`@
M("!;,5T@/3X@1FEE;&0@,RTR"B`@("`@("`@("`@(%LR72`]/B!&:65L9"`S
M+3,*("`@("`@("`@("`@6S-=(#T^(`H@("`@("`@("D*"BD`````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE
M+W1E<W1S+T-35B\P,#0N8W-V````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#(Q-@`Q,#4Q-30S,S<T,P`P,C,T-#$`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````(D9I96QD(#$M,2(L(D9I96QD(#$M,B(L
M(D9I96QD(#$M,R(L(D9I96QD(#$M-"(*(D9I96QD(#(M,2(L(D9I96QD(#(M
M,B(L(D9I96QD(#(M,R(L(DDG;2!M=6QT:6QI;F4*1FEE;&0B"B)&:65L9"`S
M+3$B+")&:65L9"`S+3(B+")&:65L9"`S+3,B"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1FEL92]T97-T<R]#4U8O
M,#`T+G!H<'0`````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$W-3<`,3`U,34T
M,S,W-#,`,#(S-C,T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"TM5$535"TM"D9I;&5?0U-6(%1E<W0@0V%S92`P,#0Z(%5N
M:7@@14],"BTM1DE,12TM"CP_<&AP"B\O("1)9#H@,#`T+G!H<'0L=B`Q+C(@
M,C`P-2\P,B\Q."`Q,3HQ.3HS,R!D=69U>B!%>'`@)`HO*BH*("H@5&5S="!F
M;W(Z"B`J("T@1FEL95]#4U8Z.F1I<V-O=F5R1F]R;6%T*"D*("H@+2!&:6QE
M7T-35CHZ<F5A9"@I"B`J+PH*<F5Q=6ER95]O;F-E("=&:6QE+T-35BYP:'`G
M.PH*)&9I;&4@/2`G,#`T+F-S=B<["B1C;VYF(#T@1FEL95]#4U8Z.F1I<V-O
M=F5R1F]R;6%T*"1F:6QE*3L*"G!R:6YT(")&;W)M870Z7&XB.PIP<FEN=%]R
M*"1C;VYF*3L*<')I;G0@(EQN(CL*"B1D871A(#T@87)R87DH*3L*=VAI;&4@
M*"1R97,@/2!&:6QE7T-35CHZ<F5A9"@D9FEL92P@)&-O;F8I*2!["B`@("`D
M9&%T85M=(#T@)')E<SL*?0H*<')I;G0@(D1A=&$Z7&XB.PIP<FEN=%]R*"1D
M871A*3L*/SX*+2U%6%!%0U0M+0I&;W)M870Z"D%R<F%Y"B@*("`@(%MF:65L
M9'-=(#T^(#0*("`@(%MS97!=(#T^("P*("`@(%MQ=6]T95T@/3X@(@HI"@I$
M871A.@I!<G)A>0HH"B`@("!;,%T@/3X@07)R87D*("`@("`@("`H"B`@("`@
M("`@("`@(%LP72`]/B!&:65L9"`Q+3$*("`@("`@("`@("`@6S%=(#T^($9I
M96QD(#$M,@H@("`@("`@("`@("!;,ET@/3X@1FEE;&0@,2TS"B`@("`@("`@
M("`@(%LS72`]/B!&:65L9"`Q+30*("`@("`@("`I"@H@("`@6S%=(#T^($%R
M<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;,%T@/3X@1FEE;&0@,BTQ"B`@
M("`@("`@("`@(%LQ72`]/B!&:65L9"`R+3(*("`@("`@("`@("`@6S)=(#T^
M($9I96QD(#(M,PH@("`@("`@("`@("!;,UT@/3X@22=M(&UU;'1I;&EN90I&
M:65L9`H@("`@("`@("D*"B`@("!;,ET@/3X@07)R87D*("`@("`@("`H"B`@
M("`@("`@("`@(%LP72`]/B!&:65L9"`S+3$*("`@("`@("`@("`@6S%=(#T^
M($9I96QD(#,M,@H@("`@("`@("`@("!;,ET@/3X@1FEE;&0@,RTS"B`@("`@
M("`@("`@(%LS72`]/B`*("`@("`@("`I"@HI```````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1FEL92]T97-T
M<R]#4U8O,#`U+F-S=@``````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R,38`
M,3`U,34T,S,W-#,`,#(S-#0R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````")&:65L9"`Q+3$B+")&:65L9"`Q+3(B+")&:65L
M9"`Q+3,B+")&:65L9"`Q+30B#2)&:65L9"`R+3$B+")&:65L9"`R+3(B+")&
M:65L9"`R+3,B+")))VT@;75L=&EL:6YE#49I96QD(@TB1FEE;&0@,RTQ(BPB
M1FEE;&0@,RTR(BPB1FEE;&0@,RTS(@T`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S=',O0U-6+S`P-2YP
M:'!T`````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-S$R`#$P-3$U-#,S-S0S
M`#`R,S8R-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````M+51%4U0M+0I&:6QE7T-35B!497-T($-A<V4@,#`U.B!-86,@14],
M"BTM1DE,12TM"CP_<&AP"B\O("1)9#H@,#`U+G!H<'0L=B`Q+C,@,C`P-2\P
M,B\Q.2`Q,CHR,SHR."!D=69U>B!%>'`@)`HO*BH*("H@5&5S="!F;W(Z"B`J
M("T@1FEL95]#4U8Z.F1I<V-O=F5R1F]R;6%T*"D*("H@+2!&:6QE7T-35CHZ
M<F5A9"@I"B`J+PH*<F5Q=6ER95]O;F-E("=&:6QE+T-35BYP:'`G.PH*)&9I
M;&4@/2`G,#`U+F-S=B<["B1C;VYF(#T@1FEL95]#4U8Z.F1I<V-O=F5R1F]R
M;6%T*"1F:6QE*3L*"G!R:6YT(")&;W)M870Z7&XB.PIP<FEN=%]R*"1C;VYF
M*3L*<')I;G0@(EQN(CL*"B1D871A(#T@87)R87DH*3L*=VAI;&4@*"1R97,@
M/2!&:6QE7T-35CHZ<F5A9"@D9FEL92P@)&-O;F8I*2!["B`@("`D9&%T85M=
M(#T@)')E<SL*?0H*9G5N8W1I;VX@7V1B9T)U9F8H)&1A=&$I"GL*("`@(&9O
M<F5A8V@@*"1D871A(&%S("1K97D@/3X@)')O=RD@>PH@("`@("`@(&EF("AS
M=')P;W,H)')O=RP@(EQR(BD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("1R
M;W<@/2!S=')?<F5P;&%C92@B7'(B+"`B7W)?(BP@)')O=RD["B`@("`@("`@
M?0H@("`@("`@(&EF("AS=')P;W,H)')O=RP@(EQN(BD@(3T](&9A;'-E*2![
M"B`@("`@("`@("`@("1S='(@/2!S=')?<F5P;&%C92@B7&XB+"`B7VY?(BP@
M)')O=RD["B`@("`@("`@?0H@("`@("`@(&EF("AS=')P;W,H)')O=RP@(EQT
M(BD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("1R;W<@/2!S=')?<F5P;&%C
M92@B7'0B+"`B7W1?(BP@)')O=RD["B`@("`@("`@?0H@("`@("`@("1D871A
M6R1K97E=(#T@)')O=SL*("`@('T*("`@(')E='5R;B`D9&%T83L*?0H*)&1A
M=&$@/2!A<G)A>5]M87`H)U]D8F="=69F)RP@)&1A=&$I.PH*<')I;G0@(D1A
M=&$Z7&XB.PIP<FEN=%]R*"1D871A*3L*/SX*+2U%6%!%0U0M+0I&;W)M870Z
M"D%R<F%Y"B@*("`@(%MF:65L9'-=(#T^(#0*("`@(%MS97!=(#T^("P*("`@
M(%MQ=6]T95T@/3X@(@HI"@I$871A.@I!<G)A>0HH"B`@("!;,%T@/3X@07)R
M87D*("`@("`@("`H"B`@("`@("`@("`@(%LP72`]/B!&:65L9"`Q+3$*("`@
M("`@("`@("`@6S%=(#T^($9I96QD(#$M,@H@("`@("`@("`@("!;,ET@/3X@
M1FEE;&0@,2TS"B`@("`@("`@("`@(%LS72`]/B!&:65L9"`Q+30*("`@("`@
M("`I"@H@("`@6S%=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;
M,%T@/3X@1FEE;&0@,BTQ"B`@("`@("`@("`@(%LQ72`]/B!&:65L9"`R+3(*
M("`@("`@("`@("`@6S)=(#T^($9I96QD(#(M,PH@("`@("`@("`@("!;,UT@
M/3X@22=M(&UU;'1I;&EN95]R7T9I96QD"B`@("`@("`@*0H*("`@(%LR72`]
M/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@("`@6S!=(#T^($9I96QD(#,M
M,0H@("`@("`@("`@("!;,5T@/3X@1FEE;&0@,RTR"B`@("`@("`@("`@(%LR
M72`]/B!&:65L9"`S+3,*("`@("`@("`@("`@6S-=(#T^(`H@("`@("`@("D*
M"BD`````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S
M=',O1FEL92]T97-T<R]#4U8O,#`V+F-S=@``````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`Q-3``,3`U,34T,S,W-#,`,#(S-#0P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````")386UP;&4@1&%T82!,:6YE
M(#$B"B)386UP;&4@1&%T82!,:6YE(#(B"B)386UP;&4@1&%T82!,:6YE(#,B
M"B)386UP;&4@1&%T82!,:6YE(#0B"B)386UP;&4@1&%T82!,:6YE(#4B````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S
M=',O0U-6+S`P-BYP:'!T````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-C(W
M`#$P-3$U-#,S-S0S`#`R,S8S,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````M+51%4U0M+0I&:6QE7T-35B!497-T($-A<V4@
M,#`V.B!/;F4@9FEE;&0@<75O=&4@875T;V1I<V-O=F5R>0HM+49)3$4M+0H\
M/W!H<`HO+R`D260Z(#`P-BYP:'!T+'8@,2XQ(#(P,#4O,#4O,C$@,#8Z,C8Z
M-#@@9'5F=7H@17AP("0*+RHJ"B`J(%1E<W0@9F]R.@H@*B`M($9I;&5?0U-6
M.CID:7-C;W9E<D9O<FUA="@I"B`J+PH*<F5Q=6ER95]O;F-E("=&:6QE+T-3
M5BYP:'`G.PH*)&9I;&4@/2`G,#`V+F-S=B<["B1C;VYF(#T@1FEL95]#4U8Z
M.F1I<V-O=F5R1F]R;6%T*"1F:6QE*3L*"G!R:6YT(")&;W)M870Z7&XB.PIP
M<FEN=%]R*"1C;VYF*3L*<')I;G0@(EQN(CL*/SX*+2U%6%!%0U0M+0I&;W)M
M870Z"D%R<F%Y"B@*("`@(%MF:65L9'-=(#T^(#$*("`@(%MS97!=(#T^("P*
M("`@(%MQ=6]T95T@/3X@(@HI"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE+W1E<W1S+T-35B]T97-T
M<RYT>'0````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3$P-@`Q,#4Q-30S,S<T
M,P`P,C0S,C,`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````1FEL95]#4U8@5&5S="!#87-E"CT]/3T]/3T]/3T]/3T]/3T]/0H*
M("`@("!#87-E("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!#
M;W9E<F5D("!.;W1E<PHM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+0HP,#$@($9I96QD<R!C;W5N="!L97-S('1H86X@97AP96-T960@("`@
M("`@(%MX70HP,#(@($9I96QD<R!C;W5N="!M;W)E('1H86X@97AP96-T960@
M("`@("`@(%MX72`@("`@($AI9V@@<FES:R!P;W-S:6)I;&ET>0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&1I<V-O=F5R960@9FEE;&1S(&-O=6YT"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=W)O;F<*,#`S("!7
M:6YD;W=S($5/3"`@("`@("`@("`@("`@("`@("`@("`@("`@("!;>%T*,#`T
M("!5;FEX($5/3"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!;>%T*
M,#`U("!-86,@14],("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!;
M>%T*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE+W1E<W1S+T9I
M;&5497-T+G!H<```````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,3$Q,0`Q,#4Q
M-30S,S<T,P`P,C0R,3,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"B\O(&YE961E9"!F;W(@;&]C:VEN9R!T97-T
M"F1E9FEN92@G1DE,15],3T-+4U]"3$]#2R<L(&9A;'-E+"!T<G5E*3L*"G)E
M<75I<F5?;VYC92`G4$A056YI="YP:'`G.PIR97%U:7)E7V]N8V4@)T9I;&4N
M<&AP)SL*"F-L87-S($9I;&5497-T(&5X=&5N9',@4$A056YI=%]497-T0V%S
M92`*>PH@("`@9G5N8W1I;VX@1FEL951E<W0H)&YA;64@/2`G1FEL951E<W0G
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y02%!5;FET7U1E<W1#87-E*"1N86UE
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!G971497-T4W1R:6YG*"D*("`@('L*
M("`@("`@("!S=&%T:6,@)'-T<CL*("`@("`@("!I<W-E="@D<W1R*2!O<B`D
M<W1R(#T@<W1R7W)E<&5A="AS=')?<F5P96%T*"(P,3(S-#4V-S@Y(BP@,3`P
M,"DN(EQN(BP@,3`P*3L*("`@("`@("!R971U<FX@)'-T<CL*("`@('T*("`@
M(`H@("`@9G5N8W1I;VX@9V5T5&5S=$QI;F4H*0H@("`@>PH@("`@("`@('-T
M871I8R`D<W1R.PH@("`@("`@(&ES<V5T*"1S='(I(&]R("1S='(@/2!S=')?
M<F5P96%T*"(P,3(S-#4V-S@Y(BP@,3`P,"D["B`@("`@("`@<F5T=7)N("1S
M='(["B`@("!]"B`@("`*("`@(&9U;F-T:6]N('-E=%5P*"D*("`@('L*("`@
M("`@("`D=&AI<RT^=&5A<D1O=VXH*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D92`]($9I;&4Z.G=R:71E*"=T97-T+G1X="<L("1T:&ES+3YG9714
M97-T4W1R:6YG*"DL($9)3$5?34]$15]74DE412DI*2!["B`@("`@("`@("`@
M(&1I92@B0V%N;F]T('-T87)T('1E<W0Z("(N('-T<E]R97!L86-E*"1T:&ES
M+3YG971497-T4W1R:6YG*"DL)RXN+B<L("1E+3YG971-97-S86=E*"DI*3L*
M("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@=&5A<D1O=VXH*0H@("`@
M>PH@("`@("`@($9I;&4Z.F-L;W-E06QL*"D["B`@("`@("`@9FEL95]E>&ES
M=',H)W1E<W0N='AT)RD@86YD('5N;&EN:R@G=&5S="YT>'0G*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!T97-T;&]C:VEN9R@I"B`@("!["B`@("`@("`@)'1H
M:7,M/F%S<V5R=$9A;'-E*%!%05(Z.FES17)R;W(H1FEL93HZ=W)I=&4H)W1E
M<W0N='AT)RP@)V%B8R<L($9)3$5?34]$15]!4%!%3D0L('1R=64I*2D["B`@
M("`@("`@)'1H:7,M/F%S<V5R=%1R=64H4$5!4CHZ:7-%<G)O<BA&:6QE.CIW
M<FET92@G=&5S="YT>'0G+"`G9&5F)RP@1DE,15]-3T1%7U=2251%+"!T<G5E
M*2DI.PH@("`@("`@("1T:&ES+3YA<W-E<G1&86QS92A014%2.CII<T5R<F]R
M*$9I;&4Z.G5N;&]C:R@G=&5S="YT>'0G+"!&24Q%7TU/1$5?05!014Y$*2DI
M.PH@("`@("`@("1T:&ES+3YA<W-E<G1&86QS92A014%2.CII<T5R<F]R*$9I
M;&4Z.G5N;&]C:R@G=&5S="YT>'0G+"!&24Q%7TU/1$5?5U))5$4I*2D["B`@
M("!]"@H@("`@9G5N8W1I;VX@=&5S=&-L;W-E*"D*("`@('L*("`@("`@("`D
M=&AI<RT^87-S97)T1F%L<V4H4$5!4CHZ:7-%<G)O<BA&:6QE.CIC;&]S92@G
M=&5S="YT>'0G+"!&24Q%7TU/1$5?5U))5$4I*2D["B`@("`@("`@)'1H:7,M
M/F%S<V5R=$9A;'-E*%!%05(Z.FES17)R;W(H1FEL93HZ8VQO<V4H)W1E<W0N
M='AT)RP@1DE,15]-3T1%7T%04$5.1"DI*3L*("`@("`@("`D=&AI<RT^87-S
M97)T1F%L<V4H4$5!4CHZ:7-%<G)O<BA&:6QE.CIC;&]S92@G=&5S="YT>'0G
M+"!&24Q%7TU/1$5?4D5!1"DI*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T
M<F5A9$%L;"@I"B`@("!["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@D
M=&AI<RT^9V5T5&5S=%-T<FEN9R@I+"!&:6QE.CIR96%D06QL*"=T97-T+G1X
M="<I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"1T:&ES+3YG9714
M97-T4W1R:6YG*"DL($9I;&4Z.G)E861!;&PH)W1E<W0N='AT)RDI.PH@("`@
M("`@("1T:&ES+3YA<W-E<G1%<75A;',H)'1H:7,M/F=E=%1E<W13=')I;F<H
M*2P@1FEL93HZ<F5A9$%L;"@G=&5S="YT>'0G*2D["B`@("!]"@H@("`@9G5N
M8W1I;VX@=&5S=')E860H*0H@("`@>PH@("`@("`@("1T:&ES+3YA<W-E<G1%
M<75A;',H)'1H:7,M/F=E=%1E<W1,:6YE*"DL($9I;&4Z.G)E860H)W1E<W0N
M='AT)RP@,3`P,#`I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*")<
M;B(L($9I;&4Z.G)E860H)W1E<W0N='AT)RP@,2DI.PH@("`@("`@("1T:&ES
M+3YA<W-E<G1%<75A;',H)S`Q,C,T-38W.#DG+"!&:6QE.CIR96%D*"=T97-T
M+G1X="<L(#$P*2D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S='=R:71E*"D*
M("`@('L*("`@("`@("`D=&AI<RT^87-S97)T1F%L<V4H4$5!4CHZ:7-%<G)O
M<B@D8GET97,@/2!&:6QE.CIW<FET92@G=&5S="YT>'0G+"`G,#$R,S0U-C<X
M.2<I*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@Q,"P@)&)Y=&5S
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T<F5A9$-H87(H*0H@("`@>PH@
M("`@("`@("1T:&ES+3YA<W-E<G1&86QS92A014%2.CII<T5R<F]R*$9I;&4Z
M.G)E=VEN9"@G=&5S="YT>'0G+"!&24Q%7TU/1$5?4D5!1"DI*3L*("`@("`@
M("`D=&AI<RT^87-S97)T17%U86QS*"<P)RP@1FEL93HZ<F5A9$-H87(H)W1E
M<W0N='AT)RDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)S$G+"!&
M:6QE.CIR96%D0VAA<B@G=&5S="YT>'0G*2D["B`@("`@("`@)'1H:7,M/F%S
M<V5R=$5Q=6%L<R@G,B<L($9I;&4Z.G)E861#:&%R*"=T97-T+G1X="<I*3L*
M("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"<S)RP@1FEL93HZ<F5A9$-H
M87(H)W1E<W0N='AT)RDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H
M)S0G+"!&:6QE.CIR96%D0VAA<B@G=&5S="YT>'0G*2D["B`@("`@("`@)'1H
M:7,M/F%S<V5R=$5Q=6%L<R@G-2<L($9I;&4Z.G)E861#:&%R*"=T97-T+G1X
M="<I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"<V)RP@1FEL93HZ
M<F5A9$-H87(H)W1E<W0N='AT)RDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%
M<75A;',H)S<G+"!&:6QE.CIR96%D0VAA<B@G=&5S="YT>'0G*2D["B`@("`@
M("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@G."<L($9I;&4Z.G)E861#:&%R*"=T
M97-T+G1X="<I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"<Y)RP@
M1FEL93HZ<F5A9$-H87(H)W1E<W0N='AT)RDI.PH@("`@("`@("1T:&ES+3YA
M<W-E<G1%<75A;',H)S`G+"!&:6QE.CIR96%D0VAA<B@G=&5S="YT>'0G*2D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@=&5S='=R:71E0VAA<B@I"B`@("!["B`@
M("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@Q+"!&:6QE.CIW<FET94-H87(H
M)W1E<W0N='AT)RP@)V$G*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L
M<R@Q+"!&:6QE.CIW<FET94-H87(H)W1E<W0N='AT)RP@)V(G*2D["B`@("`@
M("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@Q+"!&:6QE.CIW<FET94-H87(H)W1E
M<W0N='AT)RP@)V,G*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@Q
M+"!&:6QE.CIW<FET94-H87(H)W1E<W0N='AT)RP@)V0G*2D["B`@("`@("`@
M)'1H:7,M/F%S<V5R=$5Q=6%L<R@Q+"!&:6QE.CIW<FET94-H87(H)W1E<W0N
M='AT)RP@)V4G*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@Q+"!&
M:6QE.CIW<FET94-H87(H)W1E<W0N='AT)RP@)V8G*2D["B`@("`@("`@)'1H
M:7,M/F%S<V5R=$5Q=6%L<R@Q+"!&:6QE.CIW<FET94-H87(H)W1E<W0N='AT
M)RP@)V<G*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@Q+"!&:6QE
M.CIW<FET94-H87(H)W1E<W0N='AT)RP@)V@G*2D["B`@("`@("`@)'1H:7,M
M/F%S<V5R=$5Q=6%L<R@Q+"!&:6QE.CIW<FET94-H87(H)W1E<W0N='AT)RP@
M)VDG*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@Q+"!&:6QE.CIW
M<FET94-H87(H)W1E<W0N='AT)RP@)VHG*2D["B`@("!]"@H@("`@9G5N8W1I
M;VX@=&5S=')E861,:6YE*"D*("`@('L*("`@("`@("`D=&AI<RT^87-S97)T
M1F%L<V4H4$5!4CHZ:7-%<G)O<BA&:6QE.CIR97=I;F0H)W1E<W0N='AT)RP@
M1DE,15]-3T1%7U)%040I*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L
M<R@D=&AI<RT^9V5T5&5S=$QI;F4H*2P@1FEL93HZ<F5A9$QI;F4H)W1E<W0N
M='AT)RDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)'1H:7,M/F=E
M=%1E<W1,:6YE*"DL($9I;&4Z.G)E861,:6YE*"=T97-T+G1X="<I*3L*("`@
M("`@("`D=&AI<RT^87-S97)T17%U86QS*"1T:&ES+3YG971497-T3&EN92@I
M+"!&:6QE.CIR96%D3&EN92@G=&5S="YT>'0G*2D["B`@("`@("`@)'1H:7,M
M/F%S<V5R=$5Q=6%L<R@D=&AI<RT^9V5T5&5S=$QI;F4H*2P@1FEL93HZ<F5A
M9$QI;F4H)W1E<W0N='AT)RDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A
M;',H)'1H:7,M/F=E=%1E<W1,:6YE*"DL($9I;&4Z.G)E861,:6YE*"=T97-T
M+G1X="<I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"1T:&ES+3YG
M971497-T3&EN92@I+"!&:6QE.CIR96%D3&EN92@G=&5S="YT>'0G*2D["B`@
M("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@D=&AI<RT^9V5T5&5S=$QI;F4H
M*2P@1FEL93HZ<F5A9$QI;F4H)W1E<W0N='AT)RDI.PH@("`@("`@("1T:&ES
M+3YA<W-E<G1%<75A;',H)'1H:7,M/F=E=%1E<W1,:6YE*"DL($9I;&4Z.G)E
M861,:6YE*"=T97-T+G1X="<I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U
M86QS*"1T:&ES+3YG971497-T3&EN92@I+"!&:6QE.CIR96%D3&EN92@G=&5S
M="YT>'0G*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@D=&AI<RT^
M9V5T5&5S=$QI;F4H*2P@1FEL93HZ<F5A9$QI;F4H)W1E<W0N='AT)RDI.PH@
M("`@?0H*("`@(&9U;F-T:6]N('1E<W1W<FET94QI;F4H*0H@("`@>PH@("`@
M("`@("1L:6YE(#T@)'1H:7,M/F=E=%1E<W1,:6YE*"D["B`@("`@("`@)&QE
M;F=T:"`]('-T<FQE;B@D;&EN92D@*R`Q.PH@("`@("`@("1T:&ES+3YA<W-E
M<G1%<75A;',H)&QE;F=T:"P@1FEL93HZ=W)I=&5,:6YE*"=T97-T+G1X="<L
M("1L:6YE*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@D;&5N9W1H
M+"!&:6QE.CIW<FET94QI;F4H)W1E<W0N='AT)RP@)&QI;F4I*3L*("`@("`@
M("`D=&AI<RT^87-S97)T17%U86QS*"1L96YG=&@L($9I;&4Z.G=R:71E3&EN
M92@G=&5S="YT>'0G+"`D;&EN92DI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%
M<75A;',H)&QE;F=T:"P@1FEL93HZ=W)I=&5,:6YE*"=T97-T+G1X="<L("1L
M:6YE*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@D;&5N9W1H+"!&
M:6QE.CIW<FET94QI;F4H)W1E<W0N='AT)RP@)&QI;F4I*3L*("`@("`@("`D
M=&AI<RT^87-S97)T17%U86QS*"1L96YG=&@L($9I;&4Z.G=R:71E3&EN92@G
M=&5S="YT>'0G+"`D;&EN92DI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A
M;',H)&QE;F=T:"P@1FEL93HZ=W)I=&5,:6YE*"=T97-T+G1X="<L("1L:6YE
M*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@D;&5N9W1H+"!&:6QE
M.CIW<FET94QI;F4H)W1E<W0N='AT)RP@)&QI;F4I*3L*("`@("`@("`D=&AI
M<RT^87-S97)T17%U86QS*"1L96YG=&@L($9I;&4Z.G=R:71E3&EN92@G=&5S
M="YT>'0G+"`D;&EN92DI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H
M)&QE;F=T:"P@1FEL93HZ=W)I=&5,:6YE*"=T97-T+G1X="<L("1L:6YE*2D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=')E=VEN9"@I"B`@("!["B`@("`@
M("`@)'1H:7,M/F%S<V5R=$9A;'-E*%!%05(Z.FES17)R;W(H1FEL93HZ<F5W
M:6YD*"=T97-T+G1X="<L($9)3$5?34]$15]74DE412DI*3L*("`@("`@("`D
M=&AI<RT^87-S97)T1F%L<V4H4$5!4CHZ:7-%<G)O<BA&:6QE.CIR97=I;F0H
M)W1E<W0N='AT)RP@1DE,15]-3T1%7U)%040I*2D["B`@("!]"@H@("`@9G5N
M8W1I;VX@=&5S=&)U:6QD4&%T:"@I"B`@("!["B`@("`@("`@)'!A=&@@/2!A
M<G)A>2@*("`@("`@("`@("`@)W-O;64G+`H@("`@("`@("`@("!$25)%0U1/
M4EE?4T5005)!5$]2+`H@("`@("`@("`@("!$25)%0U1/4EE?4T5005)!5$]2
M+`H@("`@("`@("`@("!$25)%0U1/4EE?4T5005)!5$]2+`H@("`@("`@("`@
M("!$25)%0U1/4EE?4T5005)!5$]2+`H@("`@("`@("`@("`G=V5I<F0G+D1)
M4D5#5$]265]315!!4D%43U(L"B`@("`@("`@("`@($1)4D5#5$]265]315!!
M4D%43U(L"B`@("`@("`@("`@($1)4D5#5$]265]315!!4D%43U(L"B`@("`@
M("`@("`@($1)4D5#5$]265]315!!4D%43U(L"B`@("`@("`@("`@($1)4D5#
M5$]265]315!!4D%43U(N)W!A=&@G+D1)4D5#5$]265]315!!4D%43U(N1$E2
M14-43U)97U-%4$%2051/4BP*("`@("`@("`I.PH@("`@("`@("1B=6EL="`]
M(&EM<&QO9&4H1$E214-43U)97U-%4$%2051/4BP@87)R87DH)W-O;64G+"=W
M96ER9"<L)W!A=&@G+"<G+"<G*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q
M=6%L<R@D8G5I;'0L($9I;&4Z.F)U:6QD4&%T:"@D<&%T:"DI.PH@("`@?0H*
M("`@(&9U;F-T:6]N('1E<W1S:VEP4F]O="@I"B`@("!["B`@("`@("`@:68@
M*$]37U=)3D1/5U,I('L*("`@("`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L
M<R@G5TE.1$]74R<L($9I;&4Z.G-K:7!2;V]T*"=#.EQ<5TE.1$]74R<I*3L*
M("`@("`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@G5TE.1$]74R<L($9I
M;&4Z.G-K:7!2;V]T*"=#.EQ<7%Q724Y$3U=3)RDI.PH@("`@("`@("`@("`D
M=&AI<RT^87-S97)T17%U86QS*"=724Y$3U=3)RP@1FEL93HZ<VMI<%)O;W0H
M)T,Z+U=)3D1/5U,G*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1H:7,M/F%S<V5R=$5Q=6%L<R@G=7-R+W-H87)E+W!E87(G+"!&:6QE.CIS
M:VEP4F]O="@G+W5S<B]S:&%R92]P96%R)RDI.PH@("`@("`@('T*("`@('T*
M"B`@("!F=6YC=&EO;B!T97-T9V5T5&5M<$1I<B@I"B`@("!["B`@("`@("`@
M)&1I<B`]($9I;&4Z.F=E=%1E;7!$:7(H*3L*("`@("`@("`D=&AI<RT^87-S
M97)T5')U92AI<U]D:7(H)&1I<BDL(")I<U]D:7(H)&1I<BDB*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!T97-T9V5T5&5M<$9I;&4H*0H@("`@>PH@("`@("`@
M("1T;7`@/2!&:6QE.CIG971496UP1FEL92@I.PH@("`@("`@("1T:&ES+3YA
M<W-E<G14<G5E*&9I;&5?97AI<W1S*"1T;7`I*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!T97-T:7-!8G-O;'5T92@I"B`@("!["B`@("`@("`@)'1H:7,M/F%S
M<V5R=$9A;'-E*$9I;&4Z.FES06)S;VQU=&4H)V%B<F$O+BXO8V%D86)R82<I
M*3L*("`@("`@("`D=&AI<RT^87-S97)T1F%L<V4H1FEL93HZ:7-!8G-O;'5T
M92@G9&%T82]D:7(G*2D["B`@("`@("`@:68@*$]37U=)3D1/5U,I('L*("`@
M("`@("`@("`@)'1H:7,M/F%S<V5R=%1R=64H1FEL93HZ:7-!8G-O;'5T92@G
M0SI<7%Q<9&%T82<I*3L*("`@("`@("`@("`@)'1H:7,M/F%S<V5R=%1R=64H
M1FEL93HZ:7-!8G-O;'5T92@G9#HO9&%T82<I*3L*("`@("`@("`@("`@)'1H
M:7,M/F%S<V5R=$9A;'-E*$9I;&4Z.FES06)S;VQU=&4H)UQ<)RDI.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YA<W-E<G14<G5E*$9I
M;&4Z.FES06)S;VQU=&4H)R\G*2D["B`@("`@("`@("`@("1T:&ES+3YA<W-E
M<G1&86QS92A&:6QE.CII<T%B<V]L=71E*"=<7"<I*3L*("`@("`@("`@("`@
M)'1H:7,M/F%S<V5R=%1R=64H1FEL93HZ:7-!8G-O;'5T92@G?FUI:V4O8FEN
M)RDI.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!T97-T<F5L871I
M=F50871H*"D*("`@('L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"=T
M97-T<R]&:6QE)RP@1FEL93HZ<F5L871I=F50871H*"<O=7-R+W-H87)E+W!E
M87(O=&5S=',O1FEL92<L("<O=7-R+W-H87)E+W!E87(G+"`G+R<I*3L*("`@
M("`@("`D=&AI<RT^87-S97)T17%U86QS*"<N+B]E=&,G+"!&:6QE.CIR96QA
M=&EV95!A=&@H)R]E=&,G+"`G+W5S<B<L("<O)RDI.PH@("`@("`@("1T:&ES
M+3YA<W-E<G1%<75A;',H)T0Z7%Q$871A)RP@1FEL93HZ<F5L871I=F50871H
M*"=$.EQ<1&%T82<L("=#.EQ<1&%T82<L("=<7"<I*3L*("`@("`@("!I9B`H
M3U-?5TE.1$]74RD@>PH@("`@("`@("`@("`D=&AI<RT^87-S97)T17%U86QS
M*"=D871A7%QD:7(G+"!&:6QE.CIR96QA=&EV95!A=&@H)R]V87(O9&%T82]D
M:7(G+"`G+W9A<B<I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M=&AI<RT^87-S97)T17%U86QS*"=D871A+V1I<B<L($9I;&4Z.G)E;&%T:79E
M4&%T:"@G+W9A<B]D871A+V1I<B<L("<O=F%R)RDI.PH@("`@("`@('T*("`@
M("`@("`D=&AI<RT^87-S97)T17%U86QS*"<N+B\G+"!&:6QE.CIR96QA=&EV
M95!A=&@H)V1A=&$G+"`G9&%T82]D:7(G+"`G+R<I*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!T97-T<F5A;'!A=&@H*0H@("`@>PH@("`@("`@("1D<FEV92`]
M($]37U=)3D1/5U,@/R!S=6)S='(H9V5T8W=D*"DL,"P@,BD@.B<G.PH@("`@
M("`@("1T:&ES+3YA<W-E<G1%<75A;',H)&1R:79E("X@)R]A+W=E:7)D+W!A
M=&@O:7,G+"!&:6QE.CIR96%L<&%T:"@G+V%<7'=E:7)D+R]P871H7&ES+W1H
M870O+B\N+B\G+"`G+R<I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS
M*"1D<FEV92`N("<O82]W96ER9"]P871H+VES+W1H870G+"!&:6QE.CIR96%L
M<&%T:"@G+V%<7'=E:7)D+R]P871H7&ES+W1H870O+B\N+B]T:&%T+RXG+"`G
M+R<I*3L*("`@('T*?0H*)')E<W5L="`]("902%!5;FET.CIR=6XH;F5W(%!(
M4%5N:71?5&5S=%-U:71E*"=&:6QE5&5S="<I*3L*96-H;R`D<F5S=6QT+3YT
M;U-T<FEN9R@I.PH*/SX`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O
M=&5S=',O<&%R<V5R+G!H<```````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q
M,C`P`#$P-3$U-#,S-S0S`#`R,S<V-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HD<&%T:"`](&EN:5]G970H)VEN
M8VQU9&5?<&%T:"<I.PII;FE?<V5T*"=I;F-L=61E7W!A=&@G+"!R96%L<&%T
M:"@G+BXO)RD@+B`B.B1P871H(BD["G)E<75I<F5?;VYC92`G1FEL92]#4U8N
M<&AP)SL*"B\J+T5X86UP;&4@8V]N9CH*)&-O;F8@/2!A<G)A>2@*("`@("=F
M:65L9',G(#T^(#0L"B`@("`G<V5P)R`@("`]/B`B7'0B+`H@("`@)W%U;W1E
M)R`@/3X@)R(G+`H@("`@)VAE861E<B<@/3X@9F%L<V4**3L*+R\J+PIO8E]I
M;7!L:6-I=%]F;'5S:"AT<G5E*3L*)&%R9W8@/2`D7U-%4E9%4ELG87)G=B==
M.PHD9FEL92`]("1A<F=V6S%=.PHD=W)I=&4@/2`H:7-S970H)&%R9W9;,ETI
M*2`_("1A<F=V6S)=(#H@9F%L<V4["E!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H
M4$5!4E]%4E)/4E]04DE.5"P@(G=A<FYI;F<Z("5S7&XB*3L*"B1C;VYF(#T@
M1FEL95]#4U8Z.F1I<V-O=F5R1F]R;6%T*"1F:6QE*3L*=VAI;&4@*"1F:65L
M9',@/2!&:6QE7T-35CHZ<F5A9"@D9FEL92P@)&-O;F8I*2!["B`@("!I9B`H
M)'=R:71E*2!["B`@("`@("`@1FEL95]#4U8Z.G=R:71E*"1W<FET92P@)&9I
M96QD<RP@)&-O;F8I.PH@("`@?0H@("`@<')I;G1?<B@D9FEE;&1S*3L*?0H*
M=F%R7V1U;7`H)&-O;F8I.PIE8VAO(")<;B(*"C\^````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S
M+T9I;&4O=&5S=',O=&5S="YC<W8`````````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`Q,#,Q`#$P-3$U-#,S-S0S`#`R,S0U-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!F,0EF,@EF,PEF-`IG;V]D,0EG
M;V]D,@EG;V]D,PEG;V]D-`H[.SL[.PD[.SL[.PD[.SL[.PD[.SL[.PHZ(#H@
M.@D[(#L@(@DB+@DB"3HZ.CH[.SL[(@IN;R)Q=6]T90EN;R)Q=2)O=&4);B)Q
M=6]T92();B)Q(G4B;R)T(@HB<75O=&4Q(@DB<75O=&4R(@EN;W%U;W1E,R()
M;F]Q=6]T930*=&5S=#$)(FQO;F<*=&5S=#(B"2)L;VYG('1E<W0S"7=I=&@)
M<V5P<R()(DDG;0H)"0D)"7-I;&QY"@D)"0D);&]N9R(*;&5S<S$)(FQE<W,R
M"2XB"6QE<W,S"FES=F%L:60Q"6ES=F%L:60R"6ES=F%L:60S"6ES=F%L:60T
M"FUO<F4R,0DB;6]R93(R"0DN(@EM;W)E,C,);6]R93(T"6UO<F4R-0EM;W)E
M,C8*:7-V86QI9#(Q"6ES=F%L:60R,@EI<W9A;&ED,C,):7-V86QI9#(T"FQE
M<W-N;W$S,0EL97-S;F]Q,S();&5S<VYO<3,S"FES=F%L:60S,0EI<W9A;&ED
M,S():7-V86QI9#,S"6ES=F%L:60S-`IM;W)E;F]Q-#$);6]R96YO<30R"6UO
M<F5N;W$T,PEM;W)E;F]Q-#0);6]R96YO<30U"FES=F%L:60T,0EI<W9A;&ED
M-#():7-V86QI9#0S"6ES=F%L:60T-`H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+W1E<W1S+TQO9R\`````````````````````````````````````````````
M`````````````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S0R`#`R,#0V-@`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O3&]G+W1E<W1S+P``````````````
M````````````````````````````````````````````````````````,#`P
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-#(`
M,#(Q-C,P`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R],;V<O
M=&5S=',O8V]M<&]S:71E+G!H<'0`````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,30U,@`Q,#4Q-30S,S<T,@`P,C0U,S$`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+2U415-4+2T*3&]G.B!#;VUP;W-I=&4@
M2&%N9&QE<@HM+49)3$4M+0H\/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N<&AP
M)SL*"B1C;VYF(#T@87)R87DH)VQI;F5&;W)M870G(#T^("<E,B1S(%LE,R1S
M72`E-"1S)RD["B1C;VYS;VQE,2`]("9,;V<Z.G-I;F=L971O;B@G8V]N<V]L
M92<L("<G+"`G0T].4T],13$G+"`D8V]N9BD["B1C;VYS;VQE,B`]("9,;V<Z
M.G-I;F=L971O;B@G8V]N<V]L92<L("<G+"`G0T].4T],13(G+"`D8V]N9BD[
M"@HD8V]M<&]S:71E(#T@)DQO9SHZ<VEN9VQE=&]N*"=C;VUP;W-I=&4G*3L*
M)&-O;7!O<VET92T^861D0VAI;&0H)&-O;G-O;&4Q*3L*)&-O;7!O<VET92T^
M861D0VAI;&0H)&-O;G-O;&4R*3L*"B1C;VUP;W-I=&4M/FQO9R@G5&AI<R!E
M=F5N="!W:6QL(&)E(&QO9V=E9"!T;R!B;W1H(&AA;F1L97)S+B<I.PH*)&-O
M;7!O<VET92T^<V5T261E;G0H)TE$14Y4)RD["F5C:&\@)&-O;7!O<VET92T^
M9V5T261E;G0H*2`N(")<;B(["@HD8V]M<&]S:71E+3YL;V<H)U1H:7,@979E
M;G0@=VEL;"!B92!L;V=G960@=&\@8F]T:"!H86YD;&5R<RXG*3L*"BTM15A0
M14-4+2T*0T].4T],13$@6VEN9F]=(%1H:7,@979E;G0@=VEL;"!B92!L;V=G
M960@=&\@8F]T:"!H86YD;&5R<RX*0T].4T],13(@6VEN9F]=(%1H:7,@979E
M;G0@=VEL;"!B92!L;V=G960@=&\@8F]T:"!H86YD;&5R<RX*241%3E0*241%
M3E0@6VEN9F]=(%1H:7,@979E;G0@=VEL;"!B92!L;V=G960@=&\@8F]T:"!H
M86YD;&5R<RX*241%3E0@6VEN9F]=(%1H:7,@979E;G0@=VEL;"!B92!L;V=G
M960@=&\@8F]T:"!H86YD;&5R<RX*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T
M<R],;V<O=&5S=',O8V]N<V]L92YP:'!T````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C$W-P`Q,#4Q-30S,S<T,@`P,C0Q-S8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+2U415-4+2T*3&]G.B!#;VYS
M;VQE($AA;F1L97(*+2U&24Q%+2T*/#]P:'`*"G)E<75I<F5?;VYC92`G3&]G
M+G!H<"<["@HD8V]N9B`](&%R<F%Y*"=L:6YE1F]R;6%T)R`]/B`G)3(D<R!;
M)3,D<UT@)30D<R<I.PHD;&]G9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=C;VYS
M;VQE)RP@)R<L("=I9&5N="<L("1C;VYF*3L*9F]R("@D:2`](#`[("1I(#P@
M,SL@)&DK*RD@>PH))&QO9V=E<BT^;&]G*"),;V<@96YT<GD@)&DB*3L*?0H*
M96-H;R`B7&Y;0G5F9F5R:6YG("\@1FQU<V@@5&5S=%U<;B(["B1C;VYF(#T@
M87)R87DH)VQI;F5&;W)M870G(#T^("<E,B1S(%LE,R1S72`E-"1S)RP@)V)U
M9F9E<FEN9R<@/3X@=')U92D["B1B=69F97)E9%]L;V=G97(@/2`F3&]G.CIS
M:6YG;&5T;VXH)V-O;G-O;&4G+"`G)RP@)V)U9F9E<F5D)RP@)&-O;F8I.PIF
M;W(@*"1I(#T@,#L@)&D@/"`S.R`D:2LK*2!["B`@("`D8G5F9F5R961?;&]G
M9V5R+3YL;V<H(E!R92UF;'5S:"!B=69F97)E9"!L;V<@96YT<GD@)&DB*3L*
M?0IE8VAO(")0<F4M9FQU<VA<;B(["B1B=69F97)E9%]L;V=G97(M/F9L=7-H
M*"D["F5C:&\@(E!O<W0M9FQU<VA<;B(["F9O<B`H)&D@/2`P.R`D:2`\(#,[
M("1I*RLI('L*("`@("1B=69F97)E9%]L;V=G97(M/FQO9R@B4&]S="UF;'5S
M:"!B=69F97)E9"!L;V<@96YT<GD@)&DB*3L*?0IE8VAO(")3:'5T9&]W;EQN
M(CL*)&)U9F9E<F5D7VQO9V=E<BT^8VQO<V4H*3L*"BTM15A014-4+2T*:61E
M;G0@6VEN9F]=($QO9R!E;G1R>2`P"FED96YT(%MI;F9O72!,;V<@96YT<GD@
M,0II9&5N="!;:6YF;UT@3&]G(&5N=')Y(#(*"EM"=69F97)I;F<@+R!&;'5S
M:"!497-T70I0<F4M9FQU<V@*8G5F9F5R960@6VEN9F]=(%!R92UF;'5S:"!B
M=69F97)E9"!L;V<@96YT<GD@,`IB=69F97)E9"!;:6YF;UT@4')E+69L=7-H
M(&)U9F9E<F5D(&QO9R!E;G1R>2`Q"F)U9F9E<F5D(%MI;F9O72!0<F4M9FQU
M<V@@8G5F9F5R960@;&]G(&5N=')Y(#(*4&]S="UF;'5S:`I3:'5T9&]W;@IB
M=69F97)E9"!;:6YF;UT@4&]S="UF;'5S:"!B=69F97)E9"!L;V<@96YT<GD@
M,`IB=69F97)E9"!;:6YF;UT@4&]S="UF;'5S:"!B=69F97)E9"!L;V<@96YT
M<GD@,0IB=69F97)E9"!;:6YF;UT@4&]S="UF;'5S:"!B=69F97)E9"!L;V<@
M96YT<GD@,@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+TQO9R]T97-T<R]D:7-P;&%Y+G!H
M<'0``````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#<R`#$P-3$U-#,S-S0R
M`#`R-#$W,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````M+51%4U0M+0I,;V<Z($1I<W!L87D@2&%N9&QE<@HM+49)3$4M+0H\
M/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*"B1C;VYF(#T@87)R87DH
M)V5R<F]R7W!R97!E;F0G(#T^("<\='0^)RP*("`@("`@("`@("`@("`G97)R
M;W)?87!P96YD)R`@/3X@)SPO='0^)RP*("`@("`@("`@("`@("`G;&EN96)R
M96%K)R`@("`@/3X@(CQB<B`O/CQB<B`O/EQN(BD["B1L;V=G97(@/2`F3&]G
M.CIS:6YG;&5T;VXH)V1I<W!L87DG+"`G)RP@)R<L("1C;VYF*3L*9F]R("@D
M:2`](#`[("1I(#P@,SL@)&DK*RD@>PH))&QO9V=E<BT^;&]G*"),;V<@96YT
M<GD@)&DB*3L*?0HD;&]G9V5R+3YL;V<H(DUU;'1I7&Y,:6YE7&Y%;G1R>2(I
M.PH*+2U%6%!%0U0M+0H\='0^/&(^26YF;SPO8CXZ($QO9R!E;G1R>2`P/"]T
M=#X\8G(@+SX\8G(@+SX*/'1T/CQB/DEN9F\\+V(^.B!,;V<@96YT<GD@,3PO
M='0^/&)R("\^/&)R("\^"CQT=#X\8CY);F9O/"]B/CH@3&]G(&5N=')Y(#(\
M+W1T/CQB<B`O/CQB<B`O/@H\='0^/&(^26YF;SPO8CXZ($UU;'1I/&)R("\^
M"DQI;F4\8G(@+SX*16YT<GD\+W1T/CQB<B`O/CQB<B`O/@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+TQO9R]T97-T<R]E<G)O
M<E]L;V<N<&AP=```````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#(S`#$P-3$U
M-#,S-S0R`#`R-#4Q-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````M+51%4U0M+0I,;V<Z($5R<F]R7TQO9R!(86YD;&5R"BTM
M1DE,12TM"CP_<&AP"@IR97%U:7)E7V]N8V4@)TQO9RYP:'`G.PH*)&QO9V=E
M<B`]("9,;V<Z.G-I;F=L971O;B@G97)R;W)?;&]G)RP@4$5!4E],3T=?5%E0
M15]365-414TL("=I9&5N="<I.PIF;W(@*"1I(#T@,#L@)&D@/"`S.R`D:2LK
M*2!["@DD;&]G9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PI]"@HM+4584$5#
M5"TM"FED96YT.B!,;V<@96YT<GD@,`II9&5N=#H@3&]G(&5N=')Y(#$*:61E
M;G0Z($QO9R!E;G1R>2`R"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]T97-T<R],;V<O=&5S=',O97AT<F%C="YP:'!T````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,U,0`Q,#4Q-30S,S<T,@`P,C0R
M,#``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+2U415-4+2T*3&]G.B!?97AT<F%C=$UE<W-A9V4H*2!;6F5N9"!%;F=I;F4@
M,5T*+2U32TE0248M+0H\/W!H<"!I9B`H=F5R<VEO;E]C;VUP87)E*'IE;F1?
M=F5R<VEO;B@I+"`B,BXP+C`B+"`B/CTB*2D@9&EE*"=S:VEP)RD[(#\^"BTM
M1DE,12TM"CP_<&AP"@IR97%U:7)E7V]N8V4@)TQO9RYP:'`G.PH*)&-O;F8@
M/2!A<G)A>2@G;&EN949O<FUA="<@/3X@)R4R)',@6R4S)'-=("4T)',G*3L*
M)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G8V]N<V]L92<L("<G+"`G:61E
M;G0G+"`D8V]N9BD["@HO*B!,;V=G:6YG(&$@<F5G=6QA<B!S=')I;F<N("HO
M"B1L;V=G97(M/FQO9R@G4W1R:6YG)RD["@HO*B!,;V=G:6YG(&$@8F%R92!O
M8FIE8W0N("HO"F-L87-S($)A<F5/8FIE8W0@>WT*)&QO9V=E<BT^;&]G*&YE
M=R!"87)E3V)J96-T*"DI.PH*+RH@3&]G9VEN9R!A;B!O8FIE8W0@=VET:"!A
M(&=E=$UE<W-A9V4H*2!M971H;V0N("HO"F-L87-S($=E=$UE<W-A9V5/8FIE
M8W0@>R!F=6YC=&EO;B!G971-97-S86=E*"D@>R!R971U<FX@(F=E=$UE<W-A
M9V4B.R!]('T*)&QO9V=E<BT^;&]G*&YE=R!'971-97-S86=E3V)J96-T*"DI
M.PH*+RH@3&]G9VEN9R!A;B!O8FIE8W0@=VET:"!A('1O4W1R:6YG*"D@;65T
M:&]D+B`J+PIC;&%S<R!4;U-T<FEN9T]B:F5C="![(&9U;F-T:6]N('1O4W1R
M:6YG*"D@>R!R971U<FX@(G1O4W1R:6YG(CL@?2!]"B1L;V=G97(M/FQO9RAN
M97<@5&]3=')I;F=/8FIE8W0H*2D["@HO*B!,;V=G:6YG(&$@4$5!4E]%<G)O
M<B!O8FIE8W0N("HO"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PHD;&]G9V5R
M+3YL;V<H;F5W(%!%05)?17)R;W(H)U!%05)?17)R;W(@;V)J96-T)RP@,3`P
M*2D["@HO*B!,;V=G:6YG(&%N(&%R<F%Y+B`J+PHD;&]G9V5R+3YL;V<H87)R
M87DH,2P@,BP@)W1H<F5E)R`]/B`S*2D["@HO*B!,;V=G:6YG(&%N(&%R<F%Y
M('=I=&@@82`G;65S<V%G92<@:V5Y+B`J+PHD;&]G9V5R+3YL;V<H87)R87DH
M)VUE<W-A9V4G(#T^("=-97-S86=E($ME>2<I*3L*"BTM15A014-4+2T*:61E
M;G0@6VEN9F]=(%-T<FEN9PII9&5N="!;:6YF;UT@8F%R96]B:F5C="!/8FIE
M8W0**`HI"@II9&5N="!;:6YF;UT@9V5T365S<V%G90II9&5N="!;:6YF;UT@
M=&]3=')I;F<*:61E;G0@6VEN9F]=(%!%05)?17)R;W(@;V)J96-T"FED96YT
M(%MI;F9O72!!<G)A>0HH"B`@("!;,%T@/3X@,0H@("`@6S%=(#T^(#(*("`@
M(%MT:')E95T@/3X@,PHI"@II9&5N="!;:6YF;UT@365S<V%G92!+97D*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+TQO
M9R]T97-T<R]E>'1R86-T,BYP:'!T````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R-C8Q`#$P-3$U-#,S-S0R`#`R-#(V-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````M+51%4U0M+0I,;V<Z(%]E>'1R86-T
M365S<V%G92@I(%M:96YD($5N9VEN92`R70HM+5-+25!)1BTM"CP_<&AP(&EF
M("AV97)S:6]N7V-O;7!A<F4H>F5N9%]V97)S:6]N*"DL("(R+C`N,"(L("(\
M(BDI(&1I92@G<VMI<"<I.R`_/@HM+49)3$4M+0H\/W!H<`H*<F5Q=6ER95]O
M;F-E("=,;V<N<&AP)SL*"B1C;VYF(#T@87)R87DH)VQI;F5&;W)M870G(#T^
M("<E,B1S(%LE,R1S72`E-"1S)RD["B1L;V=G97(@/2`F3&]G.CIS:6YG;&5T
M;VXH)V-O;G-O;&4G+"`G)RP@)VED96YT)RP@)&-O;F8I.PH*+RH@3&]G9VEN
M9R!A(')E9W5L87(@<W1R:6YG+B`J+PHD;&]G9V5R+3YL;V<H)U-T<FEN9R<I
M.PH*+RH@3&]G9VEN9R!A(&)A<F4@;V)J96-T+B`J+PIC;&%S<R!"87)E3V)J
M96-T('M]"B1L;V=G97(M/FQO9RAN97<@0F%R94]B:F5C="@I*3L*"B\J($QO
M9V=I;F<@86X@;V)J96-T('=I=&@@82!G971-97-S86=E*"D@;65T:&]D+B`J
M+PIC;&%S<R!'971-97-S86=E3V)J96-T('L@9G5N8W1I;VX@9V5T365S<V%G
M92@I('L@<F5T=7)N(")G971-97-S86=E(CL@?2!]"B1L;V=G97(M/FQO9RAN
M97<@1V5T365S<V%G94]B:F5C="@I*3L*"B\J($QO9V=I;F<@86X@;V)J96-T
M('=I=&@@82!T;U-T<FEN9R@I(&UE=&AO9"X@*B\*8VQA<W,@5&]3=')I;F=/
M8FIE8W0@>R!F=6YC=&EO;B!T;U-T<FEN9R@I('L@<F5T=7)N(")T;U-T<FEN
M9R([('T@?0HD;&]G9V5R+3YL;V<H;F5W(%1O4W1R:6YG3V)J96-T*"DI.PH*
M+RH@3&]G9VEN9R!A;B!O8FIE8W0@=VET:"!A(%]?=&]3=')I;F<H*2!M971H
M;V0@=7-I;F<@8V%S=&EN9RX@*B\*8VQA<W,@0V%S=&%B;&5/8FIE8W0@>R!F
M=6YC=&EO;B!?7W1O4W1R:6YG*"D@>R!R971U<FX@(E]?=&]3=')I;F<B.R!]
M('T*)&QO9V=E<BT^;&]G*&YE=R!#87-T86)L94]B:F5C="@I*3L*"B\J($QO
M9V=I;F<@82!014%27T5R<F]R(&]B:F5C="X@*B\*<F5Q=6ER95]O;F-E("=0
M14%2+G!H<"<["B1L;V=G97(M/FQO9RAN97<@4$5!4E]%<G)O<B@G4$5!4E]%
M<G)O<B!O8FIE8W0G+"`Q,#`I*3L*"B\J($QO9V=I;F<@86X@87)R87DN("HO
M"B1L;V=G97(M/FQO9RAA<G)A>2@Q+"`R+"`G=&AR964G(#T^(#,I*3L*"B\J
M($QO9V=I;F<@86X@87)R87D@=VET:"!A("=M97-S86=E)R!K97DN("HO"B1L
M;V=G97(M/FQO9RAA<G)A>2@G;65S<V%G92<@/3X@)TUE<W-A9V4@2V5Y)RDI
M.PH*+2U%6%!%0U0M+0II9&5N="!;:6YF;UT@4W1R:6YG"FED96YT(%MI;F9O
M72!"87)E3V)J96-T($]B:F5C=`HH"BD*"FED96YT(%MI;F9O72!G971-97-S
M86=E"FED96YT(%MI;F9O72!T;U-T<FEN9PII9&5N="!;:6YF;UT@3V)J96-T
M(&ED(",R"FED96YT(%MI;F9O72!014%27T5R<F]R(&]B:F5C=`II9&5N="!;
M:6YF;UT@07)R87D**`H@("`@6S!=(#T^(#$*("`@(%LQ72`]/B`R"B`@("!;
M=&AR965=(#T^(#,**0H*:61E;G0@6VEN9F]=($UE<W-A9V4@2V5Y"@``````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O=&5S=',O3&]G+W1E<W1S+V9A8W1O<GDN<&AP=```
M````````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`V,C4`,3`U,34T,S,W-#(`,#(T
M,3<W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"TM5$535"TM"DQO9SH@1F%C=&]R>0HM+49)3$4M+0H\/W!H<`H*<F5Q=6ER
M95]O;F-E("=,;V<N<&AP)SL*"B1C;VYS;VQE,2`]("9,;V<Z.F9A8W1O<GDH
M)V-O;G-O;&4G*3L*)&-O;G-O;&4R(#T@)DQO9SHZ9F%C=&]R>2@G8V]N<V]L
M92<I.PH*:68@*&ES7V$H)&-O;G-O;&4Q+"`G3&]G7V-O;G-O;&4G*2`F)B!I
M<U]A*"1C;VYS;VQE,BP@)TQO9U]C;VYS;VQE)RDI"GL*"65C:&\@(E1W;R!,
M;V=?8V]N<V]L92!O8FIE8W1S+EQN(CL*?0H*:68@*"1C;VYS;VQE,2T^7VED
M("$]("1C;VYS;VQE,BT^7VED*2!["@EE8VAO(")4:&4@;V)J96-T<R!H879E
M(&1I9F9E<F5N="!)1',N7&XB.PI]"@HM+4584$5#5"TM"E1W;R!,;V=?8V]N
M<V]L92!O8FIE8W1S+@I4:&4@;V)J96-T<R!H879E(&1I9F9E<F5N="!)1',N
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+W1E<W1S+TQO9R]T97-T<R]F:6QE+G!H<'0`````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`Q,38R`#$P-3$U-#,S-S0R`#`R,S0T-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````M+51%4U0M+0I,
M;V<Z($9I;&4@2&%N9&QE<@HM+49)3$4M+0H\/W!H<`H*<F5Q=6ER95]O;F-E
M("=,;V<N<&AP)SL*"B1F:6QE;F%M92`](&1I<FYA;64H7U]&24Q%7U\I("X@
M1$E214-43U)97U-%4$%2051/4B`N("=T97-T+FQO9R<["FEF("AF:6QE7V5X
M:7-T<R@D9FEL96YA;64I*2!U;FQI;FLH)&9I;&5N86UE*3L*"B\J(%=R:71E
M('-O;64@96YT<FEE<R!T;R!T:&4@;&]G(&9I;&4N("HO"B1C;VYF(#T@87)R
M87DH)VQI;F5&;W)M870G(#T^("<E,B1S(%LE,R1S72`E-"1S)RD["B1L;V=G
M97(@/2`F3&]G.CIS:6YG;&5T;VXH)V9I;&4G+"`D9FEL96YA;64L("<G+"`D
M8V]N9BD["@IF;W(@*"1I(#T@,#L@)&D@/"`S.R`D:2LK*2!["@DD;&]G9V5R
M+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PI]"B1L;V=G97(M/F-L;W-E*"D["@HO
M*B!$=6UP('1H92!C;VYT96YT<R!O9B!T:&4@;&]G(&9I;&4N("HO"F5C:&\@
M9FEL95]G971?8V]N=&5N=',H)&9I;&5N86UE*3L*"B\J($-L96%N('5P+B`J
M+PII9B`H9FEL95]E>&ES=',H)&9I;&5N86UE*2D@=6YL:6YK*"1F:6QE;F%M
M92D["@HM+4584$5#5"TM"B!;:6YF;UT@3&]G(&5N=')Y(#`*(%MI;F9O72!,
M;V<@96YT<GD@,0H@6VEN9F]=($QO9R!E;G1R>2`R"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+W1E<W1S+TQO9R]T97-T<R]L979E;',N<&AP=```````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-3<T`#$P-3$U-#,S-S0R`#`R-#`R-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````M+51%
M4U0M+0I,;V<Z($QE=F5L<PHM+49)3$4M+0H\/W!H<`H*<F5Q=6ER95]O;F-E
M("=,;V<N<&AP)SL*"F9U;F-T:6]N('9E<FEF>2@D97AP+"`D;7-G*0I["B`@
M("!E8VAO("1M<V<@+B`G.B`G.PH@("`@96-H;R`H)&5X<"D@/R`G<&%S<R<@
M.B`G9F%I;"<["B`@("!E8VAO(")<;B(["GT*"F9U;F-T:6]N('1E<W1,979E
M;',H)&UA<VLI"GL*("`@(&5C:&\@(DUA<VLZ("1M87-K7&XB.PH*("`@(&9O
M<B`H)'!R:6]R:71Y(#T@4$5!4E],3T=?14U%4D<[("1P<FEO<FET>2`\/2!0
M14%27TQ/1U]$14)51SL@)'!R:6]R:71Y*RLI('L*("`@("`@("`D;6%S:V5D
M(#T@*$QO9SHZ34%32R@D<')I;W)I='DI("8@)&UA<VLI.PH@("`@("`@(&5C
M:&\@(E!R:6]R:71Y("1P<FEO<FET>3H@(CL*("`@("`@("!E8VAO*"1M87-K
M960I(#\@(FUA<VME9%QN(B`Z(")U;FUA<VME9%QN(CL*("`@('T*?0H*=&5S
M=$QE=F5L<RA,;V<Z.DU)3BA014%27TQ/1U]705).24Y'*2D["F5C:&\@(EQN
M(CL*=&5S=$QE=F5L<RA,;V<Z.DU!6"A014%27TQ/1U]705).24Y'*2D["@HM
M+4584$5#5"TM"DUA<VLZ(#(T,`I0<FEO<FET>2`P.B!U;FUA<VME9`I0<FEO
M<FET>2`Q.B!U;FUA<VME9`I0<FEO<FET>2`R.B!U;FUA<VME9`I0<FEO<FET
M>2`S.B!U;FUA<VME9`I0<FEO<FET>2`T.B!M87-K960*4')I;W)I='D@-3H@
M;6%S:V5D"E!R:6]R:71Y(#8Z(&UA<VME9`I0<FEO<FET>2`W.B!M87-K960*
M"DUA<VLZ(#,Q"E!R:6]R:71Y(#`Z(&UA<VME9`I0<FEO<FET>2`Q.B!M87-K
M960*4')I;W)I='D@,CH@;6%S:V5D"E!R:6]R:71Y(#,Z(&UA<VME9`I0<FEO
M<FET>2`T.B!M87-K960*4')I;W)I='D@-3H@=6YM87-K960*4')I;W)I='D@
M-CH@=6YM87-K960*4')I;W)I='D@-SH@=6YM87-K960*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+W1E<W1S+TQO9R]T97-T<R]N=6QL+G!H<'0`````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,C8Q`#$P-3$U-#,S-S0R`#`R
M,S0W-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```M+51%4U0M+0I,;V<Z($YU;&P@2&%N9&QE<@HM+49)3$4M+0H\/W!H<`H*
M<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*"B1L;V=G97(@/2`F3&]G.CIS:6YG
M;&5T;VXH)VYU;&PG*3L*9F]R("@D:2`](#`[("1I(#P@,SL@)&DK*RD@>PH)
M)&QO9V=E<BT^;&]G*"),;V<@96YT<GD@)&DB*3L*?0H*+2U%6%!%0U0M+0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]T97-T<R],;V<O=&5S=',O<')I;W)I='DN<&AP=```````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,3,R-P`Q,#4Q-30S,S<T,@`P,C0T,3$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+2U415-4+2T*
M3&]G.B!0<FEO<FET:65S"BTM1DE,12TM"CP_<&AP"@IR97%U:7)E7V]N8V4@
M)TQO9RYP:'`G.PH*)&-O;F8@/2!A<G)A>2@G;&EN949O<FUA="<@/3X@)ULE
M,R1S72`E-"1S)RD["B1L;V=G97(@/2`F3&]G.CIS:6YG;&5T;VXH)V-O;G-O
M;&4G+"`G)RP@)VED96YT)RP@)&-O;F8I.PH*+RH@3&]G(&%T('1H92!D969A
M=6QT(%!%05)?3$]'7TE.1D\@;&5V96PN("HO"B1L;V=G97(M/FQO9R@G3&]G
M(&UE<W-A9V4G*3L*"B\J(%-E="!T:&4@9&5F875L="!P<FEO<FET>2!T;R!0
M14%27TQ/1U]$14)51RX@*B\*)&QO9V=E<BT^<V5T4')I;W)I='DH4$5!4E],
M3T=?1$5"54<I.PHD;&]G9V5R+3YL;V<H)TQO9R!M97-S86=E)RD["@HO*B!6
M97)I9GD@=&AA="!T:&4@9V5T4')I;W)I='DH*2!M971H;V0@86QS;R!T:&EN
M9W,@=V4G<F4@870@4$5!4E],3T=?1$5"54<N("HO"B1P<FEO<FET>2`]("1L
M;V=G97(M/G!R:6]R:71Y5&]3=')I;F<H)&QO9V=E<BT^9V5T4')I;W)I='DH
M*2D["F5C:&\@(B1P<FEO<FET>5QN(CL*"B\J(%9E<FEF>2!T:&%T('-T<FEN
M9U1O4')I;W)I='DH*2!C86X@8V]N=F5R="!B86-K('1O(&$@8V]N<W1A;G0N
M("HO"B1P<FEO<FET>2`]("1L;V=G97(M/G-T<FEN9U1O4')I;W)I='DH)'!R
M:6]R:71Y*3L*96-H;R`B)'!R:6]R:71Y7&XB.PH*+2U%6%!%0U0M+0I;:6YF
M;UT@3&]G(&UE<W-A9V4*6V1E8G5G72!,;V<@;65S<V%G90ID96)U9PHW"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]T97-T<R],;V<O=&5S=',O<VEN9VQE=&]N+G!H<'0`````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#8R-P`Q,#4Q-30S,S<T,@`P,C0U,S0`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+2U4
M15-4+2T*3&]G.B!3:6YG;&5T;VX*+2U&24Q%+2T*/#]P:'`*"G)E<75I<F5?
M;VYC92`G3&]G+G!H<"<["@HD8V]N<V]L93$@/2`F3&]G.CIS:6YG;&5T;VXH
M)V-O;G-O;&4G*3L*)&-O;G-O;&4R(#T@)DQO9SHZ<VEN9VQE=&]N*"=C;VYS
M;VQE)RD["@II9B`H:7-?82@D8V]N<V]L93$L("=,;V=?8V]N<V]L92<I("8F
M(&ES7V$H)&-O;G-O;&4R+"`G3&]G7V-O;G-O;&4G*2D*>PH)96-H;R`B5'=O
M($QO9U]C;VYS;VQE(&]B:F5C=',N7&XB.PI]"@II9B`H)&-O;G-O;&4Q+3Y?
M:60@/3T@)&-O;G-O;&4R+3Y?:60I('L*"65C:&\@(E1H92!O8FIE8W1S(&AA
M=F4@=&AE('-A;64@240N7&XB.PI]"@HM+4584$5#5"TM"E1W;R!,;V=?8V]N
M<V]L92!O8FIE8W1S+@I4:&4@;V)J96-T<R!H879E('1H92!S86UE($E$+@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M=&5S=',O3&]G+W1E<W1S+W-Q;%]I9&5N="YP:'!T````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`W,3(`,3`U,34T,S,W-#(`,#(T-3`W`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"TM5$535"TM"DQO9SH@
M4U%,('-E=$ED96YT*"D*+2U32TE0248M+0H\/W!H<`H*<F5Q=6ER95]O;F-E
M("=014%2+U)E9VES=')Y+G!H<"<["B1R96=I<W1R>2`]("9N97<@4$5!4E]2
M96=I<W1R>2@I.PH*:68@*"$D<F5G:7-T<GDM/G!A8VMA9V5%>&ES=',H)T1"
M)RDI(&1I92@B<VMI<%QN(BD["BTM1DE,12TM"CP_<&AP"@IR97%U:7)E7V]N
M8V4@)TQO9RYP:'`G.PH*)&ED96YT(#T@)S$R,S0U-C<X.3`Q,C,T-38W.#DP
M)SL*"B1L;V=G97(@/2`F3&]G.CIS:6YG;&5T;VXH)W-Q;"<L("=L;V=?=&%B
M;&4G+"`D:61E;G0L(&%R<F%Y*"=D<VXG(#T^("<G*2D["F5C:&\@)&QO9V=E
M<BT^9V5T261E;G0H*2`N(")<;B(["@HD;&]G9V5R+3YS971)9&5N="@D:61E
M;G0I.PIE8VAO("1L;V=G97(M/F=E=$ED96YT*"D@+B`B7&XB.PH*+2U%6%!%
M0U0M+0HQ,C,T-38W.#DP,3(S-#4V"C$R,S0U-C<X.3`Q,C,T-38*````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+TQO9R]T
M97-T<R]S<6QI=&4N<&AP=```````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q
M,C4W`#$P-3$U-#,S-S0R`#`R-#`S,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````M+51%4U0M+0I,;V<Z(%-Q;&ET92!(86YD
M;&5R"BTM4TM)4$E&+2T*/#]P:'`@:68@*"%F=6YC=&EO;E]E>&ES=',H)W-Q
M;&ET95]O<&5N)RDI(&1I92@B<VMI<%QN(BD[(#\^"BTM1DE,12TM"CP_<&AP
M"@IR97%U:7)E7V]N8V4@)TQO9RYP:'`G.PH*)&9I;&5N86UE(#T@9&ER;F%M
M92A?7T9)3$5?7RD@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)W-Q;&ET92UL
M;V<N9&(G.PII9B`H9FEL95]E>&ES=',H)&9I;&5N86UE*2D@=6YL:6YK*"1F
M:6QE;F%M92D["@HD9&(@/2!S<6QI=&5?;W!E;B@D9FEL96YA;64L(#`V-C8L
M("1E<G)O<BD["B1I9&5N="`]('1I;64H*3L*)&UE<W-A9V4@/2`G;&]G9VEN
M9R!A;B!E=F5N="<["B1L;V=G97(@/28@3&]G.CIF86-T;W)Y*"=S<6QI=&4G
M+"`G;&]G7W1A8FQE)RP@)&ED96YT+"`D9&(I.PHD;&]G9V5R+3YL;V<H)&UE
M<W-A9V4L(%!%05)?3$]'7U=!4DY)3D<I.PH*)'$@/2`B4T5,14-4(&UE<W-A
M9V4@1E)/32!L;V=?=&%B;&4@5TA%4D4@:61E;G0])R1I9&5N="<B.PHD<F5S
M(#T@<W%L:71E7W%U97)Y*"1D8BP@)'$I.PII9B`H<W%L:71E7V9E=&-H7W-T
M<FEN9R@D<F5S*2`]/2`D;65S<V%G92D@>PH)96-H;R`G;VLG.PI]"@IS<6QI
M=&5?8VQO<V4H)&1B*3L*:68@*&9I;&5?97AI<W1S*"1F:6QE;F%M92DI('5N
M;&EN:R@D9FEL96YA;64I.PH*+2U%6%!%0U0M+0IO:PH`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S
M+TUA:6PO````````````````````````````````````````````````````
M`````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-3$U-#,S-S0R`#`R,#8R-P`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O=&5S=',O36%I;"]T97-T<R\`````````````````````
M````````````````````````````````````````````````,#`P,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-#(`,#(Q-S<Q
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]-86EL+W1E<W1S
M+W)F8S@R,BYP:'!T````````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3$Q-0`Q
M,#4Q-30S,S<T,@`P,C,V-S8`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+2U415-4+2T*36%I;%]21D,X,C(Z($%D9')E<W,@
M4&%R<VEN9PHM+49)3$4M+0H\/W!H<`IR97%U:7)E7V]N8V4@)TUA:6PO4D9#
M.#(R+G!H<"<["@HD<&%R<V5R(#T@)FYE=R!-86EL7U)&0S@R,B@I.PH@"B\J
M($$@<VEM<&QE+"!B87)E(&%D9')E<W,N("HO"B1A9&1R97-S(#T@)W5S97)`
M97AA;7!L92YC;VTG.PIP<FEN=%]R*"1P87)S97(M/G!A<G-E061D<F5S<TQI
M<W0H)&%D9')E<W,L(&YU;&PL('1R=64L('1R=64I*3L*"B\J($%D9')E<W,@
M9W)O=7!S+B`J+PHD861D<F5S<R`]("=->2!'<F]U<#H@(E)I8VAA<F0B(#QR
M:6-H87)D0&QO8V%L:&]S=#X@*$$@8V]M;65N="DL('1E9$!E>&%M<&QE+F-O
M;2`H5&5D($)L;V=G<RDL($)A<FYE>3LG.PIP<FEN=%]R*"1P87)S97(M/G!A
M<G-E061D<F5S<TQI<W0H)&%D9')E<W,L(&YU;&PL('1R=64L('1R=64I*3L*
M"B\J($$@=F%L:60@861D<F5S<R!W:71H('-P86-E<R!I;B!T:&4@;&]C86P@
M<&%R="X@*B\*)&%D9')E<W,@/2`G/")*;VX@4&%R:7-E(D!P:'`N;F5T/B<[
M"G!R:6YT7W(H)'!A<G-E<BT^<&%R<V5!9&1R97-S3&ES="@D861D<F5S<RP@
M;G5L;"P@=')U92P@=')U92DI.PH*+RH@06X@:6YV86QI9"!A9&1R97-S('=I
M=&@@<W!A8V5S(&EN('1H92!L;V-A;"!P87)T+B`J+PHD861D<F5S<R`]("<\
M2F]N(%!A<FES94!P:'`N;F5T/B<["B1R97-U;'0@/2`D<&%R<V5R+3YP87)S
M94%D9')E<W-,:7-T*"1A9&1R97-S+"!N=6QL+"!T<G5E+"!T<G5E*3L*:68@
M*%!%05(Z.FES17)R;W(H)')E<W5L="DI(&5C:&\@)')E<W5L="T^9V5T365S
M<V%G92@I("X@(EQN(CL*"BTM15A014-4+2T*07)R87D**`H@("`@6S!=(#T^
M('-T9$-L87-S($]B:F5C=`H@("`@("`@("@*("`@("`@("`@("`@6W!E<G-O
M;F%L72`]/B`*("`@("`@("`@("`@6V-O;6UE;G1=(#T^($%R<F%Y"B`@("`@
M("`@("`@("`@("`H"B`@("`@("`@("`@("`@("`I"@H@("`@("`@("`@("!;
M;6%I;&)O>%T@/3X@=7-E<@H@("`@("`@("`@("!;:&]S=%T@/3X@97AA;7!L
M92YC;VT*("`@("`@("`I"@HI"D%R<F%Y"B@*("`@(%LP72`]/B!S=&1#;&%S
M<R!/8FIE8W0*("`@("`@("`H"B`@("`@("`@("`@(%MG<F]U<&YA;65=(#T^
M($UY($=R;W5P"B`@("`@("`@("`@(%MA9&1R97-S97-=(#T^($%R<F%Y"B`@
M("`@("`@("`@("`@("`H"B`@("`@("`@("`@("`@("`@("`@6S!=(#T^('-T
M9$-L87-S($]B:F5C=`H@("`@("`@("`@("`@("`@("`@("`@("`H"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!;<&5R<V]N86Q=(#T^(")2:6-H87)D
M(@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@6V-O;6UE;G1=(#T^($%R
M<F%Y"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!;,%T@/3X@02!C;VUM96YT
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*0H*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%MM86EL8F]X72`]/B!R:6-H87)D"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!;:&]S=%T@/3X@;&]C86QH;W-T"B`@
M("`@("`@("`@("`@("`@("`@("`@("D*"B`@("`@("`@("`@("`@("`@("`@
M6S%=(#T^('-T9$-L87-S($]B:F5C=`H@("`@("`@("`@("`@("`@("`@("`@
M("`H"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!;<&5R<V]N86Q=(#T^
M(`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@6V-O;6UE;G1=(#T^($%R
M<F%Y"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!;,%T@/3X@5&5D($)L;V=G
M<PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("D*"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!;;6%I;&)O>%T@/3X@=&5D"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!;:&]S=%T@/3X@97AA;7!L92YC;VT*("`@
M("`@("`@("`@("`@("`@("`@("`@*0H*("`@("`@("`@("`@("`@("`@("!;
M,ET@/3X@<W1D0VQA<W,@3V)J96-T"B`@("`@("`@("`@("`@("`@("`@("`@
M("@*("`@("`@("`@("`@("`@("`@("`@("`@("`@(%MP97)S;VYA;%T@/3X@
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!;8V]M;65N=%T@/3X@07)R
M87D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`H"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*0H*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%MM86EL8F]X72`]/B!"87)N97D*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%MH;W-T72`]/B!L;V-A;&AO<W0*("`@("`@("`@("`@
M("`@("`@("`@("`@*0H*("`@("`@("`@("`@("`@("D*"B`@("`@("`@*0H*
M*0I!<G)A>0HH"B`@("!;,%T@/3X@<W1D0VQA<W,@3V)J96-T"B`@("`@("`@
M*`H@("`@("`@("`@("!;<&5R<V]N86Q=(#T^(`H@("`@("`@("`@("!;8V]M
M;65N=%T@/3X@07)R87D*("`@("`@("`@("`@("`@("@*("`@("`@("`@("`@
M("`@("D*"B`@("`@("`@("`@(%MM86EL8F]X72`]/B`B2F]N(%!A<FES92(*
M("`@("`@("`@("`@6VAO<W1=(#T^('!H<"YN970*("`@("`@("`I"@HI"E9A
M;&ED871I;VX@9F%I;&5D(&9O<CH@/$IO;B!087)I<V5`<&AP+FYE=#X*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+W1E<W1S+TUA:6PO=&5S=',O<VUT<%]E<G)O<BYP:'!T
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,S(W`#$P-3$U-#,S-S0R`#`R-3`V
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````M
M+51%4U0M+0I-86EL.B!33510($5R<F]R(%)E<&]R=&EN9PHM+5-+25!)1BTM
M"CP_<&AP"@IR97%U:7)E7V]N8V4@)U!%05(O4F5G:7-T<GDN<&AP)SL*)')E
M9VES=')Y(#T@)FYE=R!014%27U)E9VES=')Y*"D["@II9B`H(21R96=I<W1R
M>2T^<&%C:V%G945X:7-T<R@G3F5T7U--5%`G*2D@9&EE*")S:VEP7&XB*3L*
M+2U&24Q%+2T*/#]P:'`*<F5Q=6ER95]O;F-E("=-86EL+G!H<"<["@HO*B!2
M969E<F5N8V4@82!B;V=U<R!33510('-E<G9E<B!A9&1R97-S('1O(&=U87)A
M;G1E92!A(&-O;FYE8W1I;VX@9F%I;'5R92X@*B\*)'!A<F%M<R`](&%R<F%Y
M*"=H;W-T)R`]/B`G8F]G=7,N:&]S="YT;&0G*3L*"B\J($-R96%T92!O=7(@
M4TU44"UB87-E9"!M86EL97(@;V)J96-T+B`J+PHD;6%I;&5R(#T@)DUA:6PZ
M.F9A8W1O<GDH)W-M='`G+"`D<&%R86US*3L*"B\J($%T=&5M<'0@=&\@<V5N
M9"!A;B!E;7!T>2!M97-S86=E(&EN(&]R9&5R('1O('1R:6=G97(@86X@97)R
M;W(N("HO"FEF("A014%2.CII<T5R<F]R*"1E(#T@)&UA:6QE<BT^<V5N9"AA
M<G)A>2@I+"!A<G)A>2@I+"`G)RDI*2!["B`@("!D:64H)&4M/F=E=$UE<W-A
M9V4H*2`N(")<;B(I.PI]"@HM+4584$5#5"TM"D9A:6QE9"!T;R!C;VYN96-T
M('1O(&)O9W5S+FAO<W0N=&QD.C(U(%M33510.B!&86EL960@=&\@8V]N;F5C
M="!S;V-K970Z(%5N:VYO=VX@97)R;W(Z(#`@*&-O9&4Z("TQ+"!R97-P;VYS
M93H@*5T*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+TYE=%]33510+P``````````````
M`````````````````````````````````````````````````````````#`P
M,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S0R
M`#`R,3,S-@`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O3F5T
M7U--5%`O=&5S=',O````````````````````````````````````````````
M````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`U,34T,S,W-#(`,#(R-3`P`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]T97-T<R].971?4TU44"]T97-T<R]A=71H+G!H<'0`````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,30S-@`Q,#4Q-30S,S<T,@`P,C0S-#(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+2U415-4
M+2T*3F5T7U--5%`Z(%--5%`@075T:&5N=&EC871I;VX*+2U&24Q%+2T*/#]P
M:'`*"G)E<75I<F5?;VYC92`G3F5T+U--5%`N<&AP)SL*<F5Q=6ER95]O;F-E
M("=C;VYF:6<N<&AP)SL*"FEF("@A("@D<VUT<"`](&YE=R!.971?4TU44"A4
M15-47TA/4U1.04U%+"!415-47U!/4E0L(%1%4U1?3$]#04Q(3U-4*2DI('L*
M"61I92@B56YA8FQE('1O(&EN<W1A;G1I871E($YE=%]33510(&]B:F5C=%QN
M(BD["GT*"FEF("A014%2.CII<T5R<F]R*"1E(#T@)'-M='`M/F-O;FYE8W0H
M*2DI('L*"61I92@D92T^9V5T365S<V%G92@I("X@(EQN(BD["GT*"FEF("A0
M14%2.CII<T5R<F]R*"1E(#T@)'-M='`M/F%U=&@H5$535%]!551(7U5315(L
M(%1%4U1?05542%]005-3*2DI('L*?0H*:68@*%!%05(Z.FES17)R;W(H)'-M
M='`M/FUA:6Q&<F]M*%1%4U1?1E)/32DI*2!["@ED:64H)U5N86)L92!T;R!S
M970@<V5N9&5R('1O(#PG("X@5$535%]&4D]-("X@(CY<;B(I.PI]"@II9B`H
M4$5!4CHZ:7-%<G)O<B@D<F5S(#T@)'-M='`M/G)C<'14;RA415-47U1/*2DI
M('L*"61I92@G56YA8FQE('1O(&%D9"!R96-I<&EE;G0@/"<@+B!415-47U1/
M("X@)SXZ("<@+@H)"21R97,M/F=E=$UE<W-A9V4H*2`N(")<;B(I.PI]"@II
M9B`H4$5!4CHZ:7-%<G)O<B@D<VUT<"T^9&%T82A415-47U-50DI%0U0@+B`B
M7')<;B(@+B!415-47T)/1%DI*2D@>PH)9&EE*")5;F%B;&4@=&\@<V5N9"!D
M871A7&XB*3L*?0H*)'-M='`M/F1I<V-O;FYE8W0H*3L*"F5C:&\@)U-U8V-E
M<W,A)SL*"BTM15A014-4+2T*4W5C8V5S<R$*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]T97-T<R].971?4TU44"]T97-T<R]B87-I8RYP:'!T
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3,R-``Q,#4Q-30S,S<T,@`P,C0T
M-38`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+2U415-4+2T*3F5T7U--5%`Z($)A<VEC($9U;F-T:6]N86QI='D*+2U&24Q%
M+2T*/#]P:'`*"G)E<75I<F5?;VYC92`G3F5T+U--5%`N<&AP)SL*<F5Q=6ER
M95]O;F-E("=C;VYF:6<N<&AP)SL*"FEF("@A("@D<VUT<"`](&YE=R!.971?
M4TU44"A415-47TA/4U1.04U%+"!415-47U!/4E0L(%1%4U1?3$]#04Q(3U-4
M*2DI('L*"61I92@B56YA8FQE('1O(&EN<W1A;G1I871E($YE=%]33510(&]B
M:F5C=%QN(BD["GT*"FEF("A014%2.CII<T5R<F]R*"1E(#T@)'-M='`M/F-O
M;FYE8W0H*2DI('L*"61I92@D92T^9V5T365S<V%G92@I("X@(EQN(BD["GT*
M"FEF("A014%2.CII<T5R<F]R*"1S;71P+3YM86EL1G)O;2A415-47T923TTI
M*2D@>PH)9&EE*"=5;F%B;&4@=&\@<V5T('-E;F1E<B!T;R`\)R`N(%1%4U1?
M1E)/32`N("(^7&XB*3L*?0H*:68@*%!%05(Z.FES17)R;W(H)')E<R`]("1S
M;71P+3YR8W!T5&\H5$535%]43RDI*2!["@ED:64H)U5N86)L92!T;R!A9&0@
M<F5C:7!I96YT(#PG("X@5$535%]43R`N("<^.B`G("X*"0DD<F5S+3YG971-
M97-S86=E*"D@+B`B7&XB*3L*?0H*:68@*%!%05(Z.FES17)R;W(H)'-M='`M
M/F1A=&$H5$535%]354)*14-4("X@(EQR7&XB("X@5$535%]"3T19*2DI('L*
M"61I92@B56YA8FQE('1O('-E;F0@9&%T85QN(BD["GT*"B1S;71P+3YD:7-C
M;VYN96-T*"D["@IE8VAO("=3=6-C97-S(2<["@HM+4584$5#5"TM"E-U8V-E
M<W,A"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R].971?4TU44"]T97-T<R]C;VYF
M:6<N<&AP+F1I<W0````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<U,``Q,#4Q-30S,S<T
M,@`P,C4T,C(`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J($-O<'D@=&AI<R!F:6QE('1O(&-O;F9I9RYP
M:'`@86YD(&-U<W1O;6EZ92!T:&4@9F]L;&]W:6YG('9A;'5E<R!T;PH@*B!S
M=6ET('EO=7(@8V]N9FEG=7)A=&EO;BX*("HO"@ID969I;F4H)U1%4U1?2$]3
M5$Y!344G+"`@("`@)VQO8V%L:&]S="<I.PID969I;F4H)U1%4U1?4$]25"<L
M("`@("`@("`@,C4I.PID969I;F4H)U1%4U1?3$]#04Q(3U-4)RP@("`@)VQO
M8V%L:&]S="<I.PID969I;F4H)U1%4U1?05542%]54T52)RP@("`@)VIO;B<I
M.PID969I;F4H)U1%4U1?05542%]005-3)RP@("`@)W-E8W)E="<I.PID969I
M;F4H)U1%4U1?1E)/32<L("`@("`@("`@)V9R;VU`97AA;7!L92YC;VTG*3L*
M9&5F:6YE*"=415-47U1/)RP@("`@("`@("`@("=T;T!E>&%M<&QE+F-O;2<I
M.PID969I;F4H)U1%4U1?4U5"2D5#5"<L("`@("`@)U1E<W0@4W5B:F5C="<I
M.PID969I;F4H)U1%4U1?0D]$62<L("`@("`@("`@)U1E<W0@0F]D>2<I.PH`
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O=&5S=',O3F5T7U--5%`O=&5S=',O<75O=&5D871A+G!H<'0`
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#,T,#,`,3`U,34T,S,W-#(`,#(U,S8T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"TM5$53
M5"TM"DYE=%]33510.B!Q=6]T961A=&$H*2!<;B!\(%QR("`]/B!<<EQN(')E
M<&QA8V5M96YT"BTM1DE,12TM"CP_<&AP"@IE<G)O<E]R97!O<G1I;F<H15]!
M3$PI.PIR97%U:7)E7V]N8V4@)TYE="]33510+G!H<"<["@HD=&5S=',@/2!A
M<G)A>2@*("`@(")<;B(@("`@("`@("`@("`@("`]/B`B7')<;B(L"B`@("`B
M7')<;B(@("`@("`@("`@("`@/3X@(EQR7&XB+`H@("`@(EQN>'@B("`@("`@
M("`@("`@(#T^(")<<EQN>'@B+`H@("`@(GAX7&XB("`@("`@("`@("`@(#T^
M(")X>%QR7&XB+`H@("`@(GAX7&YX>"(@("`@("`@("`@(#T^(")X>%QR7&YX
M>"(L"B`@("`B7&Y<;GAX(B`@("`@("`@("`@/3X@(EQR7&Y<<EQN>'@B+`H@
M("`@(GAX7&Y<;GAX(B`@("`@("`@(#T^(")X>%QR7&Y<<EQN>'@B+`H@("`@
M(GAX7&Y<;B(@("`@("`@("`@(#T^(")X>%QR7&Y<<EQN(BP*("`@(")<<EQN
M>'@B("`@("`@("`@("`]/B`B7')<;GAX(BP*("`@(")X>%QR7&XB("`@("`@
M("`@("`]/B`B>'A<<EQN(BP*("`@(")X>%QR7&YX>"(@("`@("`@("`]/B`B
M>'A<<EQN>'@B+`H@("`@(EQR7&Y<<EQN>'@B("`@("`@(#T^(")<<EQN7')<
M;GAX(BP*("`@(")X>%QR7&Y<<EQN>'@B("`@("`]/B`B>'A<<EQN7')<;GAX
M(BP*("`@(")X>%QR7&Y<<EQN(B`@("`@("`]/B`B>'A<<EQN7')<;B(L"B`@
M("`B7')<;EQN>'@B("`@("`@("`@/3X@(EQR7&Y<<EQN>'@B+`H@("`@(EQN
M7')<;GAX(B`@("`@("`@(#T^(")<<EQN7')<;GAX(BP*("`@(")X>%QR7&Y<
M;GAX(B`@("`@("`]/B`B>'A<<EQN7')<;GAX(BP*("`@(")X>%QN7')<;GAX
M(B`@("`@("`]/B`B>'A<<EQN7')<;GAX(BP*("`@(")X>%QR7&Y<;B(@("`@
M("`@("`]/B`B>'A<<EQN7')<;B(L"B`@("`B>'A<;EQR7&XB("`@("`@("`@
M/3X@(GAX7')<;EQR7&XB+`H@("`@(EQR(B`@("`@("`@("`@("`@(#T^(")<
M<EQN(BP*("`@(")<<GAX(B`@("`@("`@("`@("`]/B`B7')<;GAX(BP*("`@
M(")X>%QR>'@B("`@("`@("`@("`]/B`B>'A<<EQN>'@B+`H@("`@(GAX7'(B
M("`@("`@("`@("`@(#T^(")X>%QR7&XB+`H@("`@(EQR7'(B("`@("`@("`@
M("`@(#T^(")<<EQN7')<;B(L"B`@("`B7')<<GAX(B`@("`@("`@("`@/3X@
M(EQR7&Y<<EQN>'@B+`H@("`@(GAX7')<<GAX(B`@("`@("`@(#T^(")X>%QR
M7&Y<<EQN>'@B+`H@("`@(GAX7')<<B(@("`@("`@("`@(#T^(")X>%QR7&Y<
M<EQN(BP*("`@(")X>%QR>'A<;GAX7')<;GAX(B`]/B`B>'A<<EQN>'A<<EQN
M>'A<<EQN>'@B+`H@("`@(EQR7')<;EQN(B`@("`@("`@(#T^(")<<EQN7')<
M;EQR7&XB+`HI.PH*)&AA9$5R<F]R(#T@9F%L<V4["F9O<F5A8V@@*"1T97-T
M<R!A<R`D:6YP=70@/3X@)&5X<&5C="D@>PH@("`@)&]U='!U="`]("1I;G!U
M=#L*("`@($YE=%]33510.CIQ=6]T961A=&$H)&]U='!U="D["B`@("!I9B`H
M)&]U='!U="`A/2`D97AP96-T*2!["B`@("`@("`@96-H;R`B17)R;W(Z(&EN
M<'5T("(@+B!P<F5T='EP<FEN="@D:6YP=70I("X@(BP@;W5T<'5T("(@+B!P
M<F5T='EP<FEN="@D;W5T<'5T*2`N("(L(&5X<&5C=&5D("(@+B!P<F5T='EP
M<FEN="@D97AP96-T*2`N(")<;B(["B`@("`@("`@)&AA9$5R<F]R(#T@=')U
M93L*("`@('T*?0H*:68@*"$D:&%D17)R;W(I('L*("`@(&5C:&\@(G-U8V-E
M<W-<;B(["GT*"F9U;F-T:6]N('!R971T>7!R:6YT*"1X*0I["B`@("!R971U
M<FX@<W1R7W)E<&QA8V4H87)R87DH(EQR(BP@(EQN(BDL(&%R<F%Y*"=<<B<L
M("=<;B<I+"`D>"D["GT*"BTM15A014-4+2T*<W5C8V5S<PH`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+W1E<W1S+UA-3%]087)S97(O````````````````````````````````
M`````````````````````````````````````#`P,#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S0Q`#`R,3<R,``@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O6$U,7U!A<G-E<B]T97-T<R\`
M````````````````````````````````````````````````````````````
M,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W
M-#$`,#(S,#8R`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]8
M34Q?4&%R<V5R+W1E<W1S+S`P,2YP:'!T````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C(S-P`Q,#4Q-30S,S<T,0`P,C0R-C,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+2U415-4+2T*6$U,(%!A<G-E<CH@
M<&%R<V4@<VEM<&QE('-T<FEN9PHM+5-+25!)1BTM"CP_<&AP(&EF("@A97AT
M96YS:6]N7VQO861E9"@B>&UL(BDI(&5C:&\@)W-K:7`G.R`_/@HM+49)3$4M
M+0H\/W!H<`HO+PHO+R!497-T(&9O<CH@6$U,+U!A<G-E<BYP:'`*+R\@4&%R
M=',@=&5S=&5D.B`M('!A<G-E<B!C<F5A=&EO;@HO+R`@("`@("`@("`@("`@
M("T@<V]M92!H86YD;&5R<PHO+R`@("`@("`@("`@("`@("T@<&%R<V4@<VEM
M<&QE('-T<FEN9PHO+PH*<F5Q=6ER95]O;F-E("(N+B]087)S97(N<&AP(CL*
M"F-L87-S(%]?5&5S=%!A<G-E<C$@97AT96YD<R!834Q?4&%R<V5R('L*("`@
M(&9U;F-T:6]N(%]?5&5S=%!A<G-E<C$H*2!["B`@("`@("`@)'1H:7,M/EA-
M3%]087)S97(H*3L*("`@('T*("`@(&9U;F-T:6]N('-T87)T2&%N9&QE<B@D
M>'`L("1E;&5M96YT+"`D871T<FEB<RD@>PH@("`@("`@('!R:6YT("(\)&5L
M96UE;G0B.PH@("`@("`@(')E<V5T*"1A='1R:6)S*3L*("`@("`@("!W:&EL
M92`H;&ES="@D:V5Y+"`D=F%L*2`](&5A8V@H)&%T=')I8G,I*2!["B`@("`@
M("`@("`@("1E;F,@/2!H=&UL96YT:71I97,H)'9A;"D["B`@("`@("`@("`@
M('!R:6YT("(@)&ME>3U<(B1E;F-<(B(["B`@("`@("`@?0H@("`@("`@('!R
M:6YT("(^(CL*("`@('T*("`@(&9U;F-T:6]N(&5N9$AA;F1L97(H)'AP+"`D
M96QE;65N="D@>PH@("`@("`@('!R:6YT("(\+R1E;&5M96YT/EQN(CL*("`@
M('T*("`@(&9U;F-T:6]N(&-D871A2&%N9&QE<B@D>'`L("1C9&%T82D@>PH@
M("`@("`@('!R:6YT("(\(5M#1$%405LD8V1A=&%=73XB.PH@("`@?0H@("`@
M9G5N8W1I;VX@9&5F875L=$AA;F1L97(H)'AP+"`D8V1A=&$I('L*"B`@("!]
M"GT*97)R;W)?<F5P;W)T:6YG*#$P,C,I.PIP<FEN="`B;F5W(%]?5&5S=%!A
M<G-E<C$@(CL*=F%R7V1U;7`H9V5T7V-L87-S*"1O(#T@;F5W(%]?5&5S=%!A
M<G-E<C$H*2DI.PIP<FEN="`B<&%R<V53=')I;F<@(CL*=F%R7V1U;7`H)&\M
M/G!A<G-E4W1R:6YG*"(\/WAM;"!V97)S:6]N/2<Q+C`G(#\^/')O;W0^9F]O
M/"]R;V]T/B(L(#$I*3L*"C\^"BTM15A014-4+2T*;F5W(%]?5&5S=%!A<G-E
M<C$@<W1R:6YG*#$S*2`B7U]T97-T<&%R<V5R,2(*<&%R<V53=')I;F<@/%)/
M3U0^/"%;0T1!5$%;9F]O75T^/"]23T]4/@IB;V]L*'1R=64I"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+W1E<W1S+UA-3%]087)S97(O=&5S=',O,#`R+G!H
M<'0``````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S$R`#$P-3$U-#,S-S0Q`#`R
M-#(U-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```M+51%4U0M+0I834P@4&%R<V5R.B!P87)S92!F<F]M(&9I;&4*+2U32TE0
M248M+0H\/W!H<"!I9B`H(65X=&5N<VEO;E]L;V%D960H(GAM;"(I*2!E8VAO
M("=S:VEP)SL@/SX*+2U&24Q%+2T*/#]P:'`@+R\@+2HM($,K*R`M*BT*+R\*
M+R\@5&5S="!F;W(Z(%A-3"]087)S97(N<&AP"B\O(%!A<G1S('1E<W1E9#H@
M+2!P87)S97(@8W)E871I;VX*+R\@("`@("`@("`@("`@("`M('-O;64@:&%N
M9&QE<G,*+R\@("`@("`@("`@("`@("`M('!A<G-E(&9R;VT@9FEL90HO+PIC
M:&1I<B`H9&ER;F%M92A?7T9)3$5?7RDI.PH*<F5Q=6ER95]O;F-E("(N+B]0
M87)S97(N<&AP(CL*"F-L87-S(%]?5&5S=%!A<G-E<C(@97AT96YD<R!834Q?
M4&%R<V5R('L*("`@(&9U;F-T:6]N(%]?5&5S=%!A<G-E<C(H*2!["B`@("`@
M("`@)'1H:7,M/EA-3%]087)S97(H*3L*("`@('T*("`@(&9U;F-T:6]N('-T
M87)T2&%N9&QE<B@D>'`L("1E;&5M96YT+"`D871T<FEB<RD@>PH@("`@("`@
M('!R:6YT("(\)&5L96UE;G0B.PH@("`@("`@(')E<V5T*"1A='1R:6)S*3L*
M("`@("`@("!W:&EL92`H;&ES="@D:V5Y+"`D=F%L*2`](&5A8V@H)&%T=')I
M8G,I*2!["B`@("`@("`@("`@("1E;F,@/2!H=&UL96YT:71I97,H)'9A;"D[
M"B`@("`@("`@("`@('!R:6YT("(@)&ME>3U<(B1E;F-<(B(["B`@("`@("`@
M?0H@("`@("`@('!R:6YT("(^(CL*("`@('T*("`@(&9U;F-T:6]N(&5N9$AA
M;F1L97(H)'AP+"`D96QE;65N="D@>PH@("`@("`@('!R:6YT("(\+R1E;&5M
M96YT/EQN(CL*("`@('T*("`@(&9U;F-T:6]N(&-D871A2&%N9&QE<B@D>'`L
M("1C9&%T82D@>PH@("`@("`@('!R:6YT("(\(5M#1$%405LD8V1A=&%=73XB
M.PH@("`@?0H@("`@9G5N8W1I;VX@9&5F875L=$AA;F1L97(H)'AP+"`D8V1A
M=&$I('L*"B`@("!]"GT*<')I;G0@(FYE=R!?7U1E<W1087)S97(R("(["G9A
M<E]D=6UP*&=E=%]C;&%S<R@D;R`](&YE=R!?7U1E<W1087)S97(R*"DI*3L*
M<')I;G0@(G-E=$EN<'5T1FEL92`B.PIP<FEN="!I<U]R97-O=7)C92@D;RT^
M<V5T26YP=71&:6QE*")T97-T,BYX;6PB*2DN(EQN(CL*<')I;G0@(G!A<G-E
M("(["G9A<E]D=6UP*"1O+3YP87)S92@I*3L*"C\^"BTM15A014-4+2T*;F5W
M(%]?5&5S=%!A<G-E<C(@<W1R:6YG*#$S*2`B7U]T97-T<&%R<V5R,B(*<V5T
M26YP=71&:6QE(#$*<&%R<V4@/%)/3U0^/"%;0T1!5$%;9F]O75T^/"]23T]4
M/@IB;V]L*'1R=64I"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O
M6$U,7U!A<G-E<B]T97-T<R\P,#,N<&AP=```````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(T,C(`,3`U,34T,S,W-#$`,#(T,C8Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"TM5$535"TM"EA-3"!087)S97(Z
M('!A<G-E(&9R;VT@9FEL92!R97-O=7)C90HM+5-+25!)1BTM"CP_<&AP(&EF
M("@A97AT96YS:6]N7VQO861E9"@B>&UL(BDI(&5C:&\@)W-K:7`G.R`_/@HM
M+49)3$4M+0H\/W!H<"`O+R`M*BT@0RLK("TJ+0HO+PHO+R!497-T(&9O<CH@
M6$U,+U!A<G-E<BYP:'`*+R\@4&%R=',@=&5S=&5D.B`M('!A<G-E<B!C<F5A
M=&EO;@HO+R`@("`@("`@("`@("`@("T@<V]M92!H86YD;&5R<PHO+R`@("`@
M("`@("`@("`@("T@<&%R<V4@9G)O;2!F:6QE(')E<V]U<F-E"B\O"F-H9&ER
M("AD:7)N86UE*%]?1DE,15]?*2D["@IR97%U:7)E7V]N8V4@(BXN+U!A<G-E
M<BYP:'`B.PH*8VQA<W,@7U]497-T4&%R<V5R,R!E>'1E;F1S(%A-3%]087)S
M97(@>PH@("`@9G5N8W1I;VX@7U]497-T4&%R<V5R,R@I('L*("`@("`@("`D
M=&AI<RT^6$U,7U!A<G-E<B@I.PH@("`@?0H@("`@9G5N8W1I;VX@<W1A<G1(
M86YD;&5R*"1X<"P@)&5L96UE;G0L("1A='1R:6)S*2!["B`@("`@("`@<')I
M;G0@(CPD96QE;65N="(["B`@("`@("`@<F5S970H)&%T=')I8G,I.PH@("`@
M("`@('=H:6QE("AL:7-T*"1K97DL("1V86PI(#T@96%C:"@D871T<FEB<RDI
M('L*("`@("`@("`@("`@)&5N8R`](&AT;6QE;G1I=&EE<R@D=F%L*3L*("`@
M("`@("`@("`@<')I;G0@(B`D:V5Y/5PB)&5N8UPB(CL*("`@("`@("!]"B`@
M("`@("`@<')I;G0@(CXB.PH@("`@?0H@("`@9G5N8W1I;VX@96YD2&%N9&QE
M<B@D>'`L("1E;&5M96YT*2!["B`@("`@("`@<')I;G0@(CPO)&5L96UE;G0^
M7&XB.PH@("`@?0H@("`@9G5N8W1I;VX@8V1A=&%(86YD;&5R*"1X<"P@)&-D
M871A*2!["B`@("`@("`@<')I;G0@(CPA6T-$051!6R1C9&%T85U=/B(["B`@
M("!]"B`@("!F=6YC=&EO;B!D969A=6QT2&%N9&QE<B@D>'`L("1C9&%T82D@
M>PH*("`@('T*?0IP<FEN="`B;F5W(%]?5&5S=%!A<G-E<C,@(CL*=F%R7V1U
M;7`H9V5T7V-L87-S*"1O(#T@;F5W(%]?5&5S=%!A<G-E<C,H*2DI.PIP<FEN
M="`B9F]P96X@(CL*<')I;G0@:7-?<F5S;W5R8V4H)&9P(#T@9F]P96XH(G1E
M<W0S+GAM;"(L(")R(BDI+B)<;B(["G!R:6YT(")S971);G!U="`B.PIV87)?
M9'5M<"@D;RT^<V5T26YP=70H)&9P*2D["G!R:6YT(")P87)S92`B.PIV87)?
M9'5M<"@D;RT^<&%R<V4H*2D["@H_/@HM+4584$5#5"TM"FYE=R!?7U1E<W10
M87)S97(S('-T<FEN9R@Q,RD@(E]?=&5S='!A<G-E<C,B"F9O<&5N(#$*<V5T
M26YP=70@8F]O;"AT<G5E*0IP87)S92`\4D]/5#X\(5M#1$%405MF;V]=73X\
M+U)/3U0^"F)O;VPH=')U92D*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]T97-T<R]834Q?4&%R<V5R+W1E<W1S+S`P-"YP
M:'!T```````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3$R,0`Q,#4Q-30S,S<T,0`P
M,C0R-34`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+2U415-4+2T*6$U,(%!A<G-E<CH@97)R;W(@8VQA<W,*+2U32TE0248M
M+0H\/W!H<"!I9B`H(65X=&5N<VEO;E]L;V%D960H(GAM;"(I*2!E8VAO("=S
M:VEP)SL@/SX*+2U&24Q%+2T*/#]P:'`@+R\@+2HM($,K*R`M*BT*+R\*+R\@
M5&5S="!F;W(Z(%A-3"]087)S97(N<&AP"B\O(%!A<G1S('1E<W1E9#H@+2!P
M87)S97(@97)R;W(@8VQA<W,*+R\*"G)E<75I<F5?;VYC92`B+BXO4&%R<V5R
M+G!H<"(["@IP<FEN="`B;F5W(%A-3%]087)S97(@(CL*=F%R7V1U;7`H9V5T
M7V-L87-S*"1P(#T@;F5W(%A-3%]087)S97(H*2DI.PHD92`]("1P+3YP87)S
M95-T<FEN9R@B/#]X;6P@=F5R<VEO;CTG,2XP)R`_/CQF;V\^/"]B87(^(BP@
M=')U92D["FEF("A014%2.CII<T5R<F]R*"1E*2D@>PH@("`@<')I;G1F*")E
M<G)O<B!M97-S86=E.B`E<UQN(BP@)&4M/F=E=$UE<W-A9V4H*2D["GT@96QS
M92!["B`@("!P<FEN="`B;F\@97)R;W)<;B(["GT*"C\^"BTM15A014-4+2T*
M;F5W(%A-3%]087)S97(@<W1R:6YG*#$P*2`B>&UL7W!A<G-E<B(*97)R;W(@
M;65S<V%G93H@6$U,7U!A<G-E<CH@;6ES;6%T8VAE9"!T86<@870@6$U,(&EN
M<'5T(&QI;F4@,0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]834Q?4&%R<V5R+W1E<W1S
M+S`P-2YP:'!T````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S8W-0`Q,#4Q-30S
M,S<T,0`P,C0R-S8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+2U415-4+2T*6$U,(%!A<G-E<CH@;6EX:6YG(&-H87)A8W1E
M<B!E;F-O9&EN9W,*+2U32TE0248M+0H\/W!H<"!I9B`H(65X=&5N<VEO;E]L
M;V%D960H(GAM;"(I*2!E8VAO("=S:VEP)SL@/SX*+2U&24Q%+2T*/#]P:'`@
M+R\@+2HM($,K*R`M*BT*+R\*+R\@5&5S="!F;W(Z(%A-3"]087)S97(N<&AP
M"B\O(%!A<G1S('1E<W1E9#H@+2!M:7AI;F<@8VAA<F%C=&5R(&5N8V]D:6YG
M<PHO+PHO+R!4:&ES(&ES('=H870@=V4@=&5S=#H*+R\@,2!55$8M."`@("`@
M("T^($E33RTX.#4Y+3$*+R\@,B!55$8M."`@("`@("T^(%53+4%30TE)"B\O
M(#,@25-/+3@X-3DM,2`M/B!55$8M.`HO+R`T($E33RTX.#4Y+3$@+3X@55,M
M05-#24D*+R\@-2!54RU!4T-)22`@("T^(%541BTX"B\O(#8@55,M05-#24D@
M("`M/B!)4T\M.#@U.2TQ"B\O"@IR97%U:7)E7V]N8V4@(BXN+U!A<G-E<BYP
M:'`B.PH*8VQA<W,@5&5S=$5N8V]D:6YG<S$@97AT96YD<R!834Q?4&%R<V5R
M('L*("`@('9A<B`D;W5T<'5T(#T@)R<["@H@("`@9G5N8W1I;VX@5&5S=$5N
M8V]D:6YG<S$H)'1O+"`D9G)O;2D@>PH@("`@("`@("1T:&ES+3Y834Q?4&%R
M<V5R*"1F<F]M+"`G979E;G0G+"`D=&\I.PH@("`@?0H@("`@9G5N8W1I;VX@
M<W1A<G1(86YD;&5R*"1X<"P@)&5L96TL("1A='1R:6)S*2!["B`@("`@("`@
M)'1H:7,M/F]U='!U="`N/2`B/"1E;&5M/B(["B`@("!]"B`@("!F=6YC=&EO
M;B!E;F1(86YD;&5R*"1X<"P@)&5L96TI('L*("`@("`@("`D=&AI<RT^;W5T
M<'5T("X]("(\+R1E;&5M/B(["B`@("!]"B`@("!F=6YC=&EO;B!C9&%T84AA
M;F1L97(H)'AP+"`D9&%T82D@>PH@("`@("`@("1T:&ES+3YO=71P=70@+CT@
M)&1A=&$["B`@("!]"B`@("!F=6YC=&EO;B!T97-T*"1D871A*2!["B`@("`@
M("`@+R\@)'1H:7,M/F]U='!U="`]("<G.PH@("`@("`@("1T:&ES+3YP87)S
M95-T<FEN9R@D9&%T82P@=')U92D["B`@("`@("`@<F5T=7)N("1T:&ES+3YO
M=71P=70["B`@("!]"GT*"B1X;6P@/2`B/#]X;6P@=F5R<VEO;CTG,2XP)R`_
M/B(["B1I;G!U="`](&%R<F%Y*`H@("`@(E541BTX(B`@("`@(#T^("(\83YA
M8F/#IL.XPZ4\+V$^(BP*("`@("))4T\M.#@U.2TQ(B`]/B`B/&$^86)CYOCE
M/"]A/B(L"B`@("`B55,M05-#24DB("`@/3X@(CQA/F%B8V%O83PO83XB"BD[
M"@HD96YC;V1I;F=S(#T@87)R87E?:V5Y<R@D:6YP=70I.PIF;W)E86-H("@D
M:6YP=70@87,@)'-R8V5N8R`]/B`D<W1R:6YG*2!["B`@("!F;W)E86-H("@D
M96YC;V1I;F=S(&%S("1T9W1E;F,I('L*("`@("`@("!I9B`H)'-R8V5N8R`]
M/2`D=&=T96YC*2!["B`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@('T*
M("`@("`@("!P<FEN="`B5&5S=&EN9R`D<W)C96YC("T^("1T9W1E;F,Z("([
M"B`@("`@("`@)'`@/28@;F5W(%1E<W1%;F-O9&EN9W,Q*"1T9W1E;F,L("1S
M<F-E;F,I.PH@("`@("`@("1E(#T@)'`M/G1E<W0H)&EN<'5T6R1S<F-E;F-=
M*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92DI('L*("`@("`@("`@
M("`@<')I;G1F*")/3U!3.B`E<UQN(BP@)&4M/F=E=$UE<W-A9V4H*2D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@=F%R7V1U;7`H)&4I.PH@("`@
M("`@('T*("`@('T*?0H*/SX*+2U%6%!%0U0M+0I497-T:6YG(%541BTX("T^
M($E33RTX.#4Y+3$Z('-T<FEN9R@Q,RD@(CQ!/F%B8^;XY3PO03XB"E1E<W1I
M;F<@551&+3@@+3X@55,M05-#24DZ('-T<FEN9R@Q,RD@(CQ!/F%B8S\_/SPO
M03XB"E1E<W1I;F<@25-/+3@X-3DM,2`M/B!55$8M.#H@<W1R:6YG*#$V*2`B
M/$$^86)CPZ;#N,.E/"]!/B(*5&5S=&EN9R!)4T\M.#@U.2TQ("T^(%53+4%3
M0TE).B!S=')I;F<H,3,I("(\03YA8F,_/S\\+T$^(@I497-T:6YG(%53+4%3
M0TE)("T^(%541BTX.B!S=')I;F<H,3,I("(\03YA8F-A;V$\+T$^(@I497-T
M:6YG(%53+4%30TE)("T^($E33RTX.#4Y+3$Z('-T<FEN9R@Q,RD@(CQ!/F%B
M8V%O83PO03XB"@``````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O6$U,7U!A<G-E<B]T97-T<R]T97-T
M,BYX;6P`````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P-#<`,3`U,34T,S,W-#$`
M,#(T-C0V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_>&UL('9E<G-I;VX])S$N,"<@/SX*/')O;W0^9F]O/"]R;V]T/@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+W1E<W1S+UA-3%]087)S97(O=&5S=',O=&5S=#,N>&UL````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#0W`#$P-3$U-#,S-S0Q`#`R-#8T-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/WAM;"!V
M97)S:6]N/2<Q+C`G(#\^"CQR;V]T/F9O;SPO<F]O=#X`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T
M<R]834Q?4E!#+P``````````````````````````````````````````````
M```````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#4Q-30S,S<T,@`P,C$Q,3$`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+W1E<W1S+UA-3%]24$,O=&5S=',O````````````````
M`````````````````````````````````````````````````#`P,#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S0R`#`R,C(U
M,P`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O6$U,7U)00R]T
M97-T<R]A;&QG;W0N:6YC````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,P-C``
M,3`U,34T,S,W-#(`,#(T,C(W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@HO*BH*("H@"B`J"B`J(%!(4"!V97)S
M:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*
M("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@
M;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N
M;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!796(@4V5R=FEC
M97,*("H@0'!A8VMA9V4@("`@6$U,7U)00PH@*B!`875T:&]R("`@("!$86YI
M96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@
M(#(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS90H@*B!`=F5R
M<VEO;B`@("!#5E,Z("1)9#H@86QL9V]T+FEN8RQV(#$N,2`R,#`U+S$P+S$U
M(#(P.C(Y.C0V(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+UA-3%]24$,*("H@0'-I;F-E("`@("`@
M1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N-`H@*B\*"F]B7W-T
M87)T*"D["@IF=6YC=&EO;B!R971U<FY!;&Q';W0H)'!A<F%M<RD@>PH@("`@
M)&]U="`]("<G.PH@("`@)&-O=6YT(#T@8V]U;G0H)'!A<F%M<RT^<&%R86US
M*3L*("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C;W5N=#L@)&DK*RD@>PH@("`@
M("`@("1P87)A;2`]("1P87)A;7,M/F=E=%!A<F%M*"1I*3L*("`@("`@("!I
M9B`H(5A-3%]24$-?5F%L=64Z.FES5F%L=64H)'!A<F%M*2D@>PH@("`@("`@
M("`@("`D;W5T("X](")P87)A;65T97(@)&D@=V%S(&5R<F]R.B`D<&%R86U<
M;B(["B`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@('T*("`@("`@("`D
M9V]T(#T@6$U,7U)00U]$96-O9&4H)'!A<F%M*3L*("`@("`@("`D;W5T("X]
M(")P87)A;2`D:3H@(B`N('9A<E]E>'!O<G0H)&=O="P@=')U92D@+B`B7&XB
M.PH@("`@?0H@("`@)'9A;"`](&YE=R!834Q?4E!#7U9A;'5E*"1O=70L("=S
M=')I;F<G*3L*("`@(')E='5R;B!N97<@6$U,7U)00U]297-P;VYS92@D=F%L
M*3L*?0H*)'-E<G9E<B`](&YE=R!834Q?4E!#7U-E<G9E<B@*("`@(&%R<F%Y
M*`H@("`@("`@("=A;&QG;W0G(#T^(&%R<F%Y*`H@("`@("`@("`@("`G9G5N
M8W1I;VXG(#T^("=R971U<FY!;&Q';W0G+`H@("`@("`@("DL"B`@("`I"BD[
M"@HD9V]T(#T@;V)?9V5T7V-L96%N*"D["@II9B`H)&=O="`]/2`D97AP96-T
M*2!["B`@("!E8VAO(")P87-S961<;B(["GT@96QS92!["B`@("!E8VAO(")&
M04E,141<;B(["B`@("!E8VAO(")%>'!E8W1E9#I<;B1E>'!E8W1<;B(["B`@
M("!E8VAO(")';W0Z7&XD9V]T7&XB.PI]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+UA-3%]24$,O=&5S=',O
M96UP='DM=F%L=64M<W1R=6-T+G!H<```````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U,#8T`#$P-3$U
M-#,S-S0R`#`R-C4V,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`H*+RHJ"B`J(%1E<W1S(&AO=R!T:&4@6$U,7U)0
M0R!S97)V97(@:&%N9&QE<R!A('!A<F%M971E<B!W:71H(&%N(&5M<'1Y('-T
M<G5C="!W:71H;W5T"B`J(&%N>2!S<&%C97,@:6X@=&AE(%A-3"!A9G1E<B!T
M:&4@96UP='D@=F%L=64N"B`J"B`J($EF('EO=2!A<F4@<G5N;FEN9R!T:&ES
M('1E<W0@9G)O;2!A($-64R!C:&5C:V]U="P@>6]U(&UU<W0@<F5N86UE('1H
M92!W;W)K:6YG"B`J(&1I<F5C=&]R>2!F<F]M(")834Q?4E!#(B!T;R`B6$U,
M(BX*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@
M5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F
M('1H92!02%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D
M:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A
M;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P
M;&5A<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E
M(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E
M9V]R>2`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("!834Q?4E!#"B`J
M($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE
M=#X*("H@0&-O<'ER:6=H="`@,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(
M4"!,:6-E;G-E"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!E;7!T>2UV86QU
M92US=')U8W0N<&AP+'8@,2XQ(#(P,#4O,3`O,34@,C`Z,CDZ-#8@9&%N:65L
M8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A
M8VMA9V4O6$U,7U)00PH@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S
M:6YC92!296QE87-E(#$N-"XT"B`J+PH*+RH*("H@268@=&AE('!A8VMA9V4@
M=F5R<VEO;B!N=6UB97(@:7,@9F]U;F0@:6X@=&AE(&QE9G0@:&%N9`H@*B!P
M;W)T:6]N(&]F('1H92!I9B@I(&5X<')E<W-I;VX@8F5L;W<L('1H870@;65A
M;G,@=&AI<R!F:6QE(&AA<PH@*B!C;VUE(&9R;VT@=&AE(%!%05(@:6YS=&%L
M;&5R+B`@5&AE<F5F;W)E+"!L970G<R!T97-T('1H90H@*B!I;G-T86QL960@
M=F5R<VEO;B!O9B!834Q?4E!#('=H:6-H('-H;W5L9"!B92!I;B!T:&4@:6YC
M;'5D92!P871H+@H@*B`*("H@268@=&AE('9E<G-I;VX@:&%S(&YO="!B965N
M('-U8G-T:71U=&5D(&EN('1H92!I9B@I(&5X<')E<W-I;VXL"B`J('1H:7,@
M9FEL92!H87,@;&EK96QY(&-O;64@9G)O;2!A($-64R!C:&5C:V]U="!O<B!A
M("YT87(@9FEL92X*("H@5&AE<F5F;W)E+"!W92=L;"!A<W-U;64@=&AE('1E
M<W1S('-H;W5L9"!U<V4@=&AE('9E<G-I;VX@;V8*("H@6$U,7U)00R!T:&%T
M(&AA<R!C;VUE(&9R;VT@=&AE<F4@87,@=V5L;"X*("HO"FEF("@G,2XT+C@G
M("$]("=`)RXG<&%C:V%G95]V97)S:6]N)RXG0"<I('L*("`@("\J*@H@("`@
M("H@1V5T('1H92!N965D960@8VQA<W,@9G)O;2!T:&4@4$5!4B!I;G-T86QL
M871I;VX*("`@("`J+PH@("`@<F5Q=6ER95]O;F-E("=834PO4E!#+U-E<G9E
M<BYP:'`G.PI](&5L<V4@>PH@("`@:68@*'-U8G-T<BAD:7)N86UE*%]?1DE,
M15]?*2P@+3DL("TV*2`A/2`G6$U,)RD@>PH@("`@("`@(&5C:&\@(E1H92!P
M87)E;G0@9&ER96-T;W)Y(&UU<W0@8F4@;F%M960@)UA-3"<N7&XB.PH@("`@
M("`@(&5X:70["B`@("!]"@H@("`@:6YI7W-E="@G:6YC;'5D95]P871H)RP@
M)RXN+RXN+R<*("`@("`@("`@("`@+B!0051(7U-%4$%2051/4B`N("<N)R`N
M(%!!5$A?4T5005)!5$]2"B`@("`@("`@("`@("X@:6YI7V=E="@G:6YC;'5D
M95]P871H)RD*("`@("D["@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&YE961E
M9"!C;&%S<R!F<F]M('1H92!P87)E;G0@9&ER96-T;W)Y"B`@("`@*B\*("`@
M(')E<75I<F5?;VYC92`G+BXO4V5R=F5R+G!H<"<["GT*"B1'3$]"04Q36R=(
M5%107U)!5U]03U-47T1!5$$G72`](#P\/$5/4$]35`H\/WAM;"!V97)S:6]N
M/2(Q+C`B/SX*/&UE=&AO9$-A;&P^"B`\;65T:&]D3F%M93YA;&QG;W0\+VUE
M=&AO9$YA;64^"B`@/'!A<F%M<SX*("`@/'!A<F%M/@H@("`@/'9A;'5E/@H@
M("`@(#QS=')U8W0^"B`@("`@(#QM96UB97(^"B`@("`@(#QN86UE/F9L9#$\
M+VYA;64^/'9A;'5E/CPO=F%L=64^/"]M96UB97(^/"]S=')U8W0^/"]V86QU
M93X*("`@/"]P87)A;3X*("`\+W!A<F%M<SX*(#PO;65T:&]D0V%L;#X*14]0
M3U-4.PH*)&5X<&5C="`](#P\/$5/15A0"CP_>&UL('9E<G-I;VX](C$N,"(@
M96YC;V1I;F<](E541BTX(C\^"CQM971H;V1297-P;VYS93X*/'!A<F%M<SX*
M/'!A<F%M/@H\=F%L=64^/'-T<FEN9SYP87)A;2`P.B!A<G)A>2`H"B`@)V9L
M9#$G(#TF9W0[("<G+`HI"CPO<W1R:6YG/CPO=F%L=64^"CPO<&%R86T^"CPO
M<&%R86US/@H\+VUE=&AO9%)E<W!O;G-E/@I%3T584#L*"FEN8VQU9&4@)RXO
M86QL9V]T+FEN8R<["@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O=&5S=',O6$U,7U)00R]T97-T<R]E;7!T>2UV86QU92YP:'``
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#4P-#(`,3`U,34T,S,W-#(`,#(U,C,U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"@HO*BH*("H@5&5S=',@:&]W('1H92!834Q?4E!#('-E<G9E<B!H86YD;&5S
M('!A<F%M971E<G,@=VET:"!E;7!T>2!V86QU97,N"B`J"B`J($EF('EO=2!A
M<F4@<G5N;FEN9R!T:&ES('1E<W0@9G)O;2!A($-64R!C:&5C:V]U="P@>6]U
M(&UU<W0@<F5N86UE('1H92!W;W)K:6YG"B`J(&1I<F5C=&]R>2!F<F]M(")8
M34Q?4E!#(B!T;R`B6$U,(BX*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*
M("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O
M('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90H@*B!T:&%T(&ES(&%V
M86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L
M;&]W:6YG(%5223H*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H
M92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR
M;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS
M94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E
M;'DN"B`J"B`J($!C871E9V]R>2`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G
M92`@("!834Q?4E!#"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@
M/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,C`P-2!4:&4@4$A0
M($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E"B`J($!V97)S:6]N("`@($-64SH@
M)$ED.B!E;7!T>2UV86QU92YP:'`L=B`Q+C$@,C`P-2\Q,"\Q-2`R,#HR.3HT
M-B!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H
M<"YN970O<&%C:V%G92]834Q?4E!#"B`J($!S:6YC92`@("`@($9I;&4@879A
M:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C0*("HO"@HO*@H@*B!)9B!T:&4@
M<&%C:V%G92!V97)S:6]N(&YU;6)E<B!I<R!F;W5N9"!I;B!T:&4@;&5F="!H
M86YD"B`J('!O<G1I;VX@;V8@=&AE(&EF*"D@97AP<F5S<VEO;B!B96QO=RP@
M=&AA="!M96%N<R!T:&ES(&9I;&4@:&%S"B`J(&-O;64@9G)O;2!T:&4@4$5!
M4B!I;G-T86QL97(N("!4:&5R969O<F4L(&QE="=S('1E<W0@=&AE"B`J(&EN
M<W1A;&QE9"!V97)S:6]N(&]F(%A-3%]24$,@=VAI8V@@<VAO=6QD(&)E(&EN
M('1H92!I;F-L=61E('!A=&@N"B`J(`H@*B!)9B!T:&4@=F5R<VEO;B!H87,@
M;F]T(&)E96X@<W5B<W1I='5T960@:6X@=&AE(&EF*"D@97AP<F5S<VEO;BP*
M("H@=&AI<R!F:6QE(&AA<R!L:6ME;'D@8V]M92!F<F]M(&$@0U93(&-H96-K
M;W5T(&]R(&$@+G1A<B!F:6QE+@H@*B!4:&5R969O<F4L('=E)VQL(&%S<W5M
M92!T:&4@=&5S=',@<VAO=6QD('5S92!T:&4@=F5R<VEO;B!O9@H@*B!834Q?
M4E!#('1H870@:&%S(&-O;64@9G)O;2!T:&5R92!A<R!W96QL+@H@*B\*:68@
M*"<Q+C0N."<@(3T@)T`G+B=P86-K86=E7W9E<G-I;VXG+B=`)RD@>PH@("`@
M+RHJ"B`@("`@*B!'970@=&AE(&YE961E9"!C;&%S<R!F<F]M('1H92!014%2
M(&EN<W1A;&QA=&EO;@H@("`@("HO"B`@("!R97%U:7)E7V]N8V4@)UA-3"]2
M4$,O4V5R=F5R+G!H<"<["GT@96QS92!["B`@("!I9B`H<W5B<W1R*&1I<FYA
M;64H7U]&24Q%7U\I+"`M.2P@+38I("$]("=834PG*2!["B`@("`@("`@96-H
M;R`B5&AE('!A<F5N="!D:7)E8W1O<GD@;75S="!B92!N86UE9"`G6$U,)RY<
M;B(["B`@("`@("`@97AI=#L*("`@('T*"B`@("!I;FE?<V5T*"=I;F-L=61E
M7W!A=&@G+"`G+BXO+BXO)PH@("`@("`@("`@("`N(%!!5$A?4T5005)!5$]2
M("X@)RXG("X@4$%42%]315!!4D%43U(*("`@("`@("`@("`@+B!I;FE?9V5T
M*"=I;F-L=61E7W!A=&@G*0H@("`@*3L*"B`@("`O*BH*("`@("`J($=E="!T
M:&4@;F5E9&5D(&-L87-S(&9R;VT@=&AE('!A<F5N="!D:7)E8W1O<GD*("`@
M("`J+PH@("`@<F5Q=6ER95]O;F-E("<N+B]397)V97(N<&AP)SL*?0H*)$=,
M3T)!3%-;)TA45%!?4D%77U!/4U1?1$%402==(#T@/#P\14]03U-4"CP_>&UL
M('9E<G-I;VX](C$N,"(_/@H\;65T:&]D0V%L;#X*(#QM971H;V1.86UE/F%L
M;&=O=#PO;65T:&]D3F%M93X*("`\<&%R86US/@H@("`\<&%R86T^/'9A;'5E
M/CQS=')I;F<^/"]S=')I;F<^/"]V86QU93X\+W!A<F%M/@H@("`\<&%R86T^
M/'9A;'5E/F9I<G-T/"]V86QU93X\+W!A<F%M/@H@("`\<&%R86T^/'9A;'5E
M/B`@/"]V86QU93X\+W!A<F%M/@H@("`\<&%R86T^/'9A;'5E/CPO=F%L=64^
M/"]P87)A;3X*("`\+W!A<F%M<SX*(#PO;65T:&]D0V%L;#X*14]03U-4.PH*
M)&5X<&5C="`](#P\/$5/15A0"CP_>&UL('9E<G-I;VX](C$N,"(@96YC;V1I
M;F<](E541BTX(C\^"CQM971H;V1297-P;VYS93X*/'!A<F%M<SX*/'!A<F%M
M/@H\=F%L=64^/'-T<FEN9SYP87)A;2`P.B`G)PIP87)A;2`Q.B`G9FER<W0G
M"G!A<F%M(#(Z("<@("<*<&%R86T@,SH@)R<*/"]S=')I;F<^/"]V86QU93X*
M/"]P87)A;3X*/"]P87)A;7,^"CPO;65T:&]D4F5S<&]N<V4^"D5/15A0.PH*
M:6YC;'5D92`G+B]A;&QG;W0N:6YC)SL*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]8
M34Q?4E!#+W1E<W1S+V5X=')A+6QI;F5S+G!H<```````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P-C`Q-``Q,#4Q-30S,S<T,@`P,C4R,C``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`-"@T*+RHJ#0H@*B!497-T
M<R!H;W<@=&AE(%A-3%]24$,@<V5R=F5R(&AA;F1L97,@<&%R86UE=&5R<R!W
M:71H(&5M<'1Y('9A;'5E<RX-"B`J#0H@*B!)9B!Y;W4@87)E(')U;FYI;F<@
M=&AI<R!T97-T(&9R;VT@82!#5E,@8VAE8VMO=70L('EO=2!M=7-T(')E;F%M
M92!T:&4@=V]R:VEN9PT*("H@9&ER96-T;W)Y(&9R;VT@(EA-3%]24$,B('1O
M(")834PB+@T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@
M3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I
M;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B
M;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN
M9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!0
M2%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G
M:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+@T*("H-"B`J($!C871E9V]R>2`@(%=E8B!397)V:6-E<PT*("H@0'!A8VMA
M9V4@("`@6$U,7U)00PT*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O
M<B`\9&%N:65L8T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,C`P-2!4:&4@
M4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS90T*("H@0'9E<G-I;VX@("`@
M0U93.B`D260Z(&5X=')A+6QI;F5S+G!H<"QV(#$N,2`R,#`V+S`T+S`W(#$T
M.C0X.C$T(&1A;FEE;&,@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P
M96%R+G!H<"YN970O<&%C:V%G92]834Q?4E!##0H@*B!`<VEN8V4@("`@("!&
M:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XT#0H@*B\-"@T*+RH-
M"B`J($EF('1H92!P86-K86=E('9E<G-I;VX@;G5M8F5R(&ES(&9O=6YD(&EN
M('1H92!L969T(&AA;F0-"B`J('!O<G1I;VX@;V8@=&AE(&EF*"D@97AP<F5S
M<VEO;B!B96QO=RP@=&AA="!M96%N<R!T:&ES(&9I;&4@:&%S#0H@*B!C;VUE
M(&9R;VT@=&AE(%!%05(@:6YS=&%L;&5R+B`@5&AE<F5F;W)E+"!L970G<R!T
M97-T('1H90T*("H@:6YS=&%L;&5D('9E<G-I;VX@;V8@6$U,7U)00R!W:&EC
M:"!S:&]U;&0@8F4@:6X@=&AE(&EN8VQU9&4@<&%T:"X-"B`J(`T*("H@268@
M=&AE('9E<G-I;VX@:&%S(&YO="!B965N('-U8G-T:71U=&5D(&EN('1H92!I
M9B@I(&5X<')E<W-I;VXL#0H@*B!T:&ES(&9I;&4@:&%S(&QI:V5L>2!C;VUE
M(&9R;VT@82!#5E,@8VAE8VMO=70@;W(@82`N=&%R(&9I;&4N#0H@*B!4:&5R
M969O<F4L('=E)VQL(&%S<W5M92!T:&4@=&5S=',@<VAO=6QD('5S92!T:&4@
M=F5R<VEO;B!O9@T*("H@6$U,7U)00R!T:&%T(&AA<R!C;VUE(&9R;VT@=&AE
M<F4@87,@=V5L;"X-"B`J+PT*:68@*"<Q+C0N."<@(3T@)T`G+B=P86-K86=E
M7W9E<G-I;VXG+B=`)RD@>PT*("`@("\J*@T*("`@("`J($=E="!T:&4@;F5E
M9&5D(&-L87-S(&9R;VT@=&AE(%!%05(@:6YS=&%L;&%T:6]N#0H@("`@("HO
M#0H@("`@<F5Q=6ER95]O;F-E("=834PO4E!#+G!H<"<[#0I](&5L<V4@>PT*
M("`@(&EF("AS=6)S='(H9&ER;F%M92A?7T9)3$5?7RDL("TY+"`M-BD@(3T@
M)UA-3"<I('L-"B`@("`@("`@96-H;R`B5&AE('!A<F5N="!D:7)E8W1O<GD@
M;75S="!B92!N86UE9"`G6$U,)RY<;B([#0H@("`@("`@(&5X:70[#0H@("`@
M?0T*#0H@("`@:6YI7W-E="@G:6YC;'5D95]P871H)RP@)RXN+RXN+R<-"B`@
M("`@("`@("`@("X@4$%42%]315!!4D%43U(@+B`G+B<@+B!0051(7U-%4$%2
M051/4@T*("`@("`@("`@("`@+B!I;FE?9V5T*"=I;F-L=61E7W!A=&@G*0T*
M("`@("D[#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(&YE961E9"!C;&%S
M<R!F<F]M('1H92!P87)E;G0@9&ER96-T;W)Y#0H@("`@("HO#0H@("`@<F5Q
M=6ER95]O;F-E("<N+B]24$,N<&AP)SL-"GT-"@T*)&EN<'5T(#T@(D9I<G-T
M(&QF<UQN7&Y396-O;F0@8W)L9G-<<EQN7')<;E1H:7)D(&-R<UQR7')&;W5R
M=&@@;&EN92([#0H-"B1E>'!E8W1?<F5M;W9E9"`]("(\/WAM;"!V97)S:6]N
M/5PB,2XP7"(@96YC;V1I;F<]7")55$8M.%PB/SX-"CQM971H;V1#86QL/@T*
M/&UE=&AO9$YA;64^;F%D83PO;65T:&]D3F%M93X-"CQP87)A;7,^#0H\<&%R
M86T^#0H\=F%L=64^/'-T<FEN9SY&:7)S="!L9G,-"E-E8V]N9"!C<FQF<PT*
M5&AI<F0@8W)S#0I&;W5R=&@@;&EN93PO<W1R:6YG/CPO=F%L=64^#0H\+W!A
M<F%M/@T*/"]P87)A;7,^#0H\+VUE=&AO9$-A;&P^#0HB.PT*#0HD97AP96-T
M7VYO=%]R96UO=F5D(#T@(CP_>&UL('9E<G-I;VX]7"(Q+C!<(B!E;F-O9&EN
M9SU<(E541BTX7"(_/@T*/&UE=&AO9$-A;&P^#0H\;65T:&]D3F%M93YN861A
M/"]M971H;V1.86UE/@T*/'!A<F%M<SX-"CQP87)A;3X-"CQV86QU93X\<W1R
M:6YG/D9I<G-T(&QF<PT*#0I396-O;F0@8W)L9G,-"@T*5&AI<F0@8W)S#0H-
M"D9O=7)T:"!L:6YE/"]S=')I;F<^/"]V86QU93X-"CPO<&%R86T^#0H\+W!A
M<F%M<SX-"CPO;65T:&]D0V%L;#X-"B([#0H-"@T*)&US9R`](&YE=R!834Q?
M4E!#7TUE<W-A9V4H)VYA9&$G+"!A<G)A>2A834Q?4E!#7V5N8V]D92@D:6YP
M=70I*2D[#0HD;7-G+3YC<F5A=&5087EL;V%D*"D[#0II9B`H)&US9RT^<&%Y
M;&]A9"`]/2`D97AP96-T7W)E;6]V960I('L-"B`@("!E8VAO(")P87-S961<
M;B([#0I](&5L<V4@>PT*("`@(&5C:&\@(E!23T),14U<;B([#0I]#0H-"B1M
M<V<@/2!N97<@6$U,7U)00U]-97-S86=E*"=N861A)RP@87)R87DH6$U,7U)0
M0U]E;F-O9&4H)&EN<'5T*2DI.PT*)&US9RT^<F5M;W9E7V5X=')A7VQI;F5S
M(#T@9F%L<V4[#0HD;7-G+3YC<F5A=&5087EL;V%D*"D[#0II9B`H)&US9RT^
M<&%Y;&]A9"`]/2`D97AP96-T7VYO=%]R96UO=F5D*2![#0H@("`@96-H;R`B
M<&%S<V5D7&XB.PT*?2!E;'-E('L-"B`@("!E8VAO(")04D]"3$5-7&XB.PT*
M?0T*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O
M6$U,7U)00R]T97-T<R]P<F]T;W!O<G0N<&AP````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,C4U-#,`,3`U,34T,S,W-#(`,#(U,#0U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@HO*BH*("H@5&5S=',@
M=&AA="!P<F]P97)T:65S(&]F(%A-3%]24$-?0VQI96YT(&=E="!P<F]P97)L
M>2!S970*("H*("H@06YY(&EN9&EV:61U86P@=&5S=',@=&AA="!F86EL('=I
M;&P@:&%V92!T:&5I<B!N86UE+"!E>'!E8W1E9"!R97-U;'0*("H@86YD(&%C
M='5A;"!R97-U;'0@<')I;G1E9"!O=70N("!3;R!S965I;F<@;F\@;W5T<'5T
M('=H96X@97AE8W5T:6YG"B`J('1H:7,@9FEL92!I<R!A(&=O;V0@=&AI;F<N
M"B`J"B`J($-A;B!B92!R=6X@=FEA($-,22!O<B!A('=E8B!S97)V97(N"B`J
M"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@
M<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@
M4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO
M="!R96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R
M92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E
M"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@
M;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@
M("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@6$U,7U)00PH@*B!`875T
M:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J
M($!C;W!Y<FEG:'0@(#(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC
M96YS90H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@<')O=&]P;W)T+G!H<"QV
M(#$N-"`R,#`U+S`Q+S(T(#$W.C0X.C0W(&1A;FEE;&,@17AP("0*("H@0&QI
M;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+UA-3%]24$,*
M("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q
M+C(*("HO"@HO*@H@*B!)9B!T:&4@<&%C:V%G92!V97)S:6]N(&YU;6)E<B!I
M<R!F;W5N9"!I;B!T:&4@;&5F="!H86YD"B`J('!O<G1I;VX@;V8@=&AE(&EF
M*"D@97AP<F5S<VEO;B!B96QO=RP@=&AA="!M96%N<R!T:&ES(&9I;&4@:&%S
M"B`J(&-O;64@9G)O;2!T:&4@4$5!4B!I;G-T86QL97(N("!4:&5R969O<F4L
M(&QE="=S('1E<W0@=&AE"B`J(&EN<W1A;&QE9"!V97)S:6]N(&]F(%A-3%]2
M4$,@=VAI8V@@<VAO=6QD(&)E(&EN('1H92!I;F-L=61E('!A=&@N"B`J(`H@
M*B!)9B!T:&4@=F5R<VEO;B!H87,@;F]T(&)E96X@<W5B<W1I='5T960@:6X@
M=&AE(&EF*"D@97AP<F5S<VEO;BP*("H@=&AI<R!F:6QE(&AA<R!L:6ME;'D@
M8V]M92!F<F]M(&$@0U93(&-H96-K;W5T(&]R(&$@+G1A<B!F:6QE+@H@*B!4
M:&5R969O<F4L('=E)VQL(&%S<W5M92!T:&4@=&5S=',@<VAO=6QD('5S92!T
M:&4@=F5R<VEO;B!O9@H@*B!834Q?4E!#('1H870@:&%S(&-O;64@9G)O;2!T
M:&5R92!A<R!W96QL+@H@*B\*:68@*"<Q+C0N."<@(3T@)T`G+B=P86-K86=E
M7W9E<G-I;VXG+B=`)RD@>PH@("`@+RHJ"B`@("`@*B!'970@=&AE(&YE961E
M9"!C;&%S<R!F<F]M('1H92!014%2(&EN<W1A;&QA=&EO;@H@("`@("HO"B`@
M("!R97%U:7)E7V]N8V4@)UA-3"]24$,N<&AP)SL*?2!E;'-E('L*("`@("\J
M*@H@("`@("H@1V5T('1H92!N965D960@8VQA<W,@9G)O;2!T:&4@<&%R96YT
M(&1I<F5C=&]R>0H@("`@("HO"B`@("!R97%U:7)E7V]N8V4@)RXN+U)00RYP
M:'`G.PI]"@HO*BH*("H@0V]M<&%R92!T:&4@=&5S="!R97-U;'0@=&\@=&AE
M(&5X<&5C=&5D(')E<W5L=`H@*@H@*B!)9B!T:&4@=&5S="!F86EL<RP@96-H
M;R!O=70@=&AE(')E<W5L=',N"B`J"B`J($!P87)A;2!A<G)A>2`@)&5X<&5C
M="`@("`@=&AE(&%R<F%Y(&]F(&]B:F5C="!P<F]P97)T:65S('EO=2!E>'!E
M8W0*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@9G)O;2!T:&4@=&5S
M=`H@*B!`<&%R86T@;V)J96-T("1A8W1U86P@("`@('1H92!O8FIE8W0@<F5S
M=6QT<R!F<F]M('1H92!T97-T"B`J($!P87)A;2!S=')I;F<@)'1E<W1?;F%M
M92`@=&AE(&YA;64@;V8@=&AE('1E<W0*("H*("H@0')E='5R;B!V;VED"B`J
M+PIF=6YC=&EO;B!C;VUP87)E*"1E>'!E8W0L("1A8W1U86PL("1T97-T7VYA
M;64I('L*("`@("1A8W1U86P@/2!G971?;V)J96-T7W9A<G,H)&%C='5A;"D[
M"B`@("!I9B`H8V]U;G0H87)R87E?9&EF9B@D86-T=6%L+"`D97AP96-T*2DI
M('L*("`@("`@("!E8VAO("(D=&5S=%]N86UE(&9A:6QE9"Y<;D5X<&5C=#H@
M(CL*("`@("`@("!P<FEN=%]R*"1E>'!E8W0I.PH@("`@("`@(&5C:&\@(D%C
M='5A;#H@(CL*("`@("`@("!P<FEN=%]R*"1A8W1U86PI.PH@("`@("`@(&5C
M:&\@(EQN(CL*("`@('T*?0H*:68@*'!H<%]S87!I7VYA;64H*2`A/2`G8VQI
M)RD@>PH@("`@96-H;R`B/'!R93Y<;B(["GT*"@HD>"`](&%R<F%Y*`H@("`@
M)W!A=&@G(#T^("=T:&5P871H)RP*("`@("=S97)V97(G(#T^("=T:&5S97)V
M97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G:'1T<#HO+R<L"B`@("`G<&]R="<@
M/3X@.#`L"B`@("`G<')O>'DG(#T^("<G+`H@("`@)W!R;WAY7W!R;W1O8V]L
M)R`]/B`G:'1T<#HO+R<L"B`@("`G<')O>'E?<&]R="<@/3X@.#`X,"P*("`@
M("=P<F]X>5]U<V5R)R`]/B`G)RP*("`@("=P<F]X>5]P87-S)R`]/B`G)RP*
M("`@("=E<G)N;R<@/3X@,"P*("`@("=E<G)S=')I;F<G(#T^("<G+`H@("`@
M)V1E8G5G)R`]/B`P+`H@("`@)W5S97)N86UE)R`]/B`G)RP*("`@("=P87-S
M=V]R9"<@/3X@)R<L"BD["B1C(#T@;F5W(%A-3%]24$-?0VQI96YT*"=T:&5P
M871H)RP@)W1H97-E<G9E<B<I.PIC;VUP87)E*"1X+"`D8RP@)V1E9F%U;'1S
M)RD["@HD>"`](&%R<F%Y*`H@("`@)W!A=&@G(#T^("=T:&5P871H)RP*("`@
M("=S97)V97(G(#T^("=T:&5S97)V97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G
M:'1T<#HO+R<L"B`@("`G<&]R="<@/3X@.#`L"B`@("`G<')O>'DG(#T^("<G
M+`H@("`@)W!R;WAY7W!R;W1O8V]L)R`]/B`G:'1T<#HO+R<L"B`@("`G<')O
M>'E?<&]R="<@/3X@.#`X,"P*("`@("=P<F]X>5]U<V5R)R`]/B`G)RP*("`@
M("=P<F]X>5]P87-S)R`]/B`G)RP*("`@("=E<G)N;R<@/3X@,"P*("`@("=E
M<G)S=')I;F<G(#T^("<G+`H@("`@)V1E8G5G)R`]/B`P+`H@("`@)W5S97)N
M86UE)R`]/B`G)RP*("`@("=P87-S=V]R9"<@/3X@)R<L"BD["B1C(#T@;F5W
M(%A-3%]24$-?0VQI96YT*"=T:&5P871H)RP@)VAT='`Z+R]T:&5S97)V97(G
M*3L*8V]M<&%R92@D>"P@)&,L("=D969A=6QT<R!W:71H(&AT='`G*3L*"B1X
M(#T@87)R87DH"B`@("`G<&%T:"<@/3X@)W1H97!A=&@G+`H@("`@)W-E<G9E
M<B<@/3X@)W1H97-E<G9E<B<L"B`@("`G<')O=&]C;VPG(#T^("=S<VPZ+R\G
M+`H@("`@)W!O<G0G(#T^(#0T,RP*("`@("=P<F]X>2<@/3X@)R<L"B`@("`G
M<')O>'E?<')O=&]C;VPG(#T^("=H='1P.B\O)RP*("`@("=P<F]X>5]P;W)T
M)R`]/B`X,#@P+`H@("`@)W!R;WAY7W5S97(G(#T^("<G+`H@("`@)W!R;WAY
M7W!A<W,G(#T^("<G+`H@("`@)V5R<FYO)R`]/B`P+`H@("`@)V5R<G-T<FEN
M9R<@/3X@)R<L"B`@("`G9&5B=6<G(#T^(#`L"B`@("`G=7-E<FYA;64G(#T^
M("<G+`H@("`@)W!A<W-W;W)D)R`]/B`G)RP**3L*)&,@/2!N97<@6$U,7U)0
M0U]#;&EE;G0H)W1H97!A=&@G+"`G:'1T<',Z+R]T:&5S97)V97(G*3L*8V]M
M<&%R92@D>"P@)&,L("=D969A=6QT<R!W:71H(&AT='!S)RD["@HD>"`](&%R
M<F%Y*`H@("`@)W!A=&@G(#T^("=T:&5P871H)RP*("`@("=S97)V97(G(#T^
M("=T:&5S97)V97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G<W-L.B\O)RP*("`@
M("=P;W)T)R`]/B`T-#,L"B`@("`G<')O>'DG(#T^("<G+`H@("`@)W!R;WAY
M7W!R;W1O8V]L)R`]/B`G:'1T<#HO+R<L"B`@("`G<')O>'E?<&]R="<@/3X@
M.#`X,"P*("`@("=P<F]X>5]U<V5R)R`]/B`G)RP*("`@("=P<F]X>5]P87-S
M)R`]/B`G)RP*("`@("=E<G)N;R<@/3X@,"P*("`@("=E<G)S=')I;F<G(#T^
M("<G+`H@("`@)V1E8G5G)R`]/B`P+`H@("`@)W5S97)N86UE)R`]/B`G)RP*
M("`@("=P87-S=V]R9"<@/3X@)R<L"BD["B1C(#T@;F5W(%A-3%]24$-?0VQI
M96YT*"=T:&5P871H)RP@)W-S;#HO+W1H97-E<G9E<B<I.PIC;VUP87)E*"1X
M+"`D8RP@)V1E9F%U;'1S('=I=&@@<W-L)RD["@H*)'@@/2!A<G)A>2@*("`@
M("=P871H)R`]/B`G=&AE<&%T:"<L"B`@("`G<V5R=F5R)R`]/B`G=&AE<V5R
M=F5R)RP*("`@("=P<F]T;V-O;"<@/3X@)VAT='`Z+R\G+`H@("`@)W!O<G0G
M(#T^(#8U+`H@("`@)W!R;WAY)R`]/B`G)RP*("`@("=P<F]X>5]P<F]T;V-O
M;"<@/3X@)VAT='`Z+R\G+`H@("`@)W!R;WAY7W!O<G0G(#T^(#@P.#`L"B`@
M("`G<')O>'E?=7-E<B<@/3X@)R<L"B`@("`G<')O>'E?<&%S<R<@/3X@)R<L
M"B`@("`G97)R;F\G(#T^(#`L"B`@("`G97)R<W1R:6YG)R`]/B`G)RP*("`@
M("=D96)U9R<@/3X@,"P*("`@("=U<V5R;F%M92<@/3X@)R<L"B`@("`G<&%S
M<W=O<F0G(#T^("<G+`HI.PHD8R`](&YE=R!834Q?4E!#7T-L:65N="@G=&AE
M<&%T:"<L("=T:&5S97)V97(G+"`V-2D["F-O;7!A<F4H)'@L("1C+"`G<&]R
M="`V-2<I.PH*)'@@/2!A<G)A>2@*("`@("=P871H)R`]/B`G=&AE<&%T:"<L
M"B`@("`G<V5R=F5R)R`]/B`G=&AE<V5R=F5R)RP*("`@("=P<F]T;V-O;"<@
M/3X@)VAT='`Z+R\G+`H@("`@)W!O<G0G(#T^(#8U+`H@("`@)W!R;WAY)R`]
M/B`G)RP*("`@("=P<F]X>5]P<F]T;V-O;"<@/3X@)VAT='`Z+R\G+`H@("`@
M)W!R;WAY7W!O<G0G(#T^(#@P.#`L"B`@("`G<')O>'E?=7-E<B<@/3X@)R<L
M"B`@("`G<')O>'E?<&%S<R<@/3X@)R<L"B`@("`G97)R;F\G(#T^(#`L"B`@
M("`G97)R<W1R:6YG)R`]/B`G)RP*("`@("=D96)U9R<@/3X@,"P*("`@("=U
M<V5R;F%M92<@/3X@)R<L"B`@("`G<&%S<W=O<F0G(#T^("<G+`HI.PHD8R`]
M(&YE=R!834Q?4E!#7T-L:65N="@G=&AE<&%T:"<L("=H='1P.B\O=&AE<V5R
M=F5R)RP@-C4I.PIC;VUP87)E*"1X+"`D8RP@)W!O<G0@-C4@=VET:"!H='1P
M)RD["@HD>"`](&%R<F%Y*`H@("`@)W!A=&@G(#T^("=T:&5P871H)RP*("`@
M("=S97)V97(G(#T^("=T:&5S97)V97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G
M<W-L.B\O)RP*("`@("=P;W)T)R`]/B`V-2P*("`@("=P<F]X>2<@/3X@)R<L
M"B`@("`G<')O>'E?<')O=&]C;VPG(#T^("=H='1P.B\O)RP*("`@("=P<F]X
M>5]P;W)T)R`]/B`X,#@P+`H@("`@)W!R;WAY7W5S97(G(#T^("<G+`H@("`@
M)W!R;WAY7W!A<W,G(#T^("<G+`H@("`@)V5R<FYO)R`]/B`P+`H@("`@)V5R
M<G-T<FEN9R<@/3X@)R<L"B`@("`G9&5B=6<G(#T^(#`L"B`@("`G=7-E<FYA
M;64G(#T^("<G+`H@("`@)W!A<W-W;W)D)R`]/B`G)RP**3L*)&,@/2!N97<@
M6$U,7U)00U]#;&EE;G0H)W1H97!A=&@G+"`G:'1T<',Z+R]T:&5S97)V97(G
M+"`V-2D["F-O;7!A<F4H)'@L("1C+"`G<&]R="`V-2!W:71H(&AT='!S)RD[
M"@HD>"`](&%R<F%Y*`H@("`@)W!A=&@G(#T^("=T:&5P871H)RP*("`@("=S
M97)V97(G(#T^("=T:&5S97)V97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G<W-L
M.B\O)RP*("`@("=P;W)T)R`]/B`V-2P*("`@("=P<F]X>2<@/3X@)R<L"B`@
M("`G<')O>'E?<')O=&]C;VPG(#T^("=H='1P.B\O)RP*("`@("=P<F]X>5]P
M;W)T)R`]/B`X,#@P+`H@("`@)W!R;WAY7W5S97(G(#T^("<G+`H@("`@)W!R
M;WAY7W!A<W,G(#T^("<G+`H@("`@)V5R<FYO)R`]/B`P+`H@("`@)V5R<G-T
M<FEN9R<@/3X@)R<L"B`@("`G9&5B=6<G(#T^(#`L"B`@("`G=7-E<FYA;64G
M(#T^("<G+`H@("`@)W!A<W-W;W)D)R`]/B`G)RP**3L*)&,@/2!N97<@6$U,
M7U)00U]#;&EE;G0H)W1H97!A=&@G+"`G<W-L.B\O=&AE<V5R=F5R)RP@-C4I
M.PIC;VUP87)E*"1X+"`D8RP@)W!O<G0@-C4@=VET:"!S<VPG*3L*"@HD>"`]
M(&%R<F%Y*`H@("`@)W!A=&@G(#T^("=T:&5P871H)RP*("`@("=S97)V97(G
M(#T^("=T:&5S97)V97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G:'1T<#HO+R<L
M"B`@("`G<&]R="<@/3X@.#`L"B`@("`G<')O>'DG(#T^("=T:&5P<F]X>2<L
M"B`@("`G<')O>'E?<')O=&]C;VPG(#T^("=H='1P.B\O)RP*("`@("=P<F]X
M>5]P;W)T)R`]/B`X,#@P+`H@("`@)W!R;WAY7W5S97(G(#T^("<G+`H@("`@
M)W!R;WAY7W!A<W,G(#T^("<G+`H@("`@)V5R<FYO)R`]/B`P+`H@("`@)V5R
M<G-T<FEN9R<@/3X@)R<L"B`@("`G9&5B=6<G(#T^(#`L"B`@("`G=7-E<FYA
M;64G(#T^("<G+`H@("`@)W!A<W-W;W)D)R`]/B`G)RP**3L*)&,@/2!N97<@
M6$U,7U)00U]#;&EE;G0H)W1H97!A=&@G+"`G=&AE<V5R=F5R)RP@,"P*("`@
M("`@("`@("`@("`@("`@("`@("`@)W1H97!R;WAY)RD["F-O;7!A<F4H)'@L
M("1C+"`G9&5F875L=',@<')O>'DG*3L*"B1X(#T@87)R87DH"B`@("`G<&%T
M:"<@/3X@)W1H97!A=&@G+`H@("`@)W-E<G9E<B<@/3X@)W1H97-E<G9E<B<L
M"B`@("`G<')O=&]C;VPG(#T^("=H='1P.B\O)RP*("`@("=P;W)T)R`]/B`X
M,"P*("`@("=P<F]X>2<@/3X@)W1H97!R;WAY)RP*("`@("=P<F]X>5]P<F]T
M;V-O;"<@/3X@)VAT='`Z+R\G+`H@("`@)W!R;WAY7W!O<G0G(#T^(#@P.#`L
M"B`@("`G<')O>'E?=7-E<B<@/3X@)R<L"B`@("`G<')O>'E?<&%S<R<@/3X@
M)R<L"B`@("`G97)R;F\G(#T^(#`L"B`@("`G97)R<W1R:6YG)R`]/B`G)RP*
M("`@("=D96)U9R<@/3X@,"P*("`@("=U<V5R;F%M92<@/3X@)R<L"B`@("`G
M<&%S<W=O<F0G(#T^("<G+`HI.PHD8R`](&YE=R!834Q?4E!#7T-L:65N="@G
M=&AE<&%T:"<L("=H='1P.B\O=&AE<V5R=F5R)RP@,"P*("`@("`@("`@("`@
M("`@("`@("`@("`@)VAT='`Z+R]T:&5P<F]X>2<I.PIC;VUP87)E*"1X+"`D
M8RP@)V1E9F%U;'1S('=I=&@@:'1T<"!P<F]X>2<I.PH*)'@@/2!A<G)A>2@*
M("`@("=P871H)R`]/B`G=&AE<&%T:"<L"B`@("`G<V5R=F5R)R`]/B`G=&AE
M<V5R=F5R)RP*("`@("=P<F]T;V-O;"<@/3X@)W-S;#HO+R<L"B`@("`G<&]R
M="<@/3X@-#0S+`H@("`@)W!R;WAY)R`]/B`G=&AE<')O>'DG+`H@("`@)W!R
M;WAY7W!R;W1O8V]L)R`]/B`G<W-L.B\O)RP*("`@("=P<F]X>5]P;W)T)R`]
M/B`T-#,L"B`@("`G<')O>'E?=7-E<B<@/3X@)R<L"B`@("`G<')O>'E?<&%S
M<R<@/3X@)R<L"B`@("`G97)R;F\G(#T^(#`L"B`@("`G97)R<W1R:6YG)R`]
M/B`G)RP*("`@("=D96)U9R<@/3X@,"P*("`@("=U<V5R;F%M92<@/3X@)R<L
M"B`@("`G<&%S<W=O<F0G(#T^("<G+`HI.PHD8R`](&YE=R!834Q?4E!#7T-L
M:65N="@G=&AE<&%T:"<L("=H='1P<SHO+W1H97-E<G9E<B<L(#`L"B`@("`@
M("`@("`@("`@("`@("`@("`@("=H='1P<SHO+W1H97!R;WAY)RD["F-O;7!A
M<F4H)'@L("1C+"`G9&5F875L=',@=VET:"!H='1P<R!P<F]X>2<I.PH*)'@@
M/2!A<G)A>2@*("`@("=P871H)R`]/B`G=&AE<&%T:"<L"B`@("`G<V5R=F5R
M)R`]/B`G=&AE<V5R=F5R)RP*("`@("=P<F]T;V-O;"<@/3X@)W-S;#HO+R<L
M"B`@("`G<&]R="<@/3X@-#0S+`H@("`@)W!R;WAY)R`]/B`G=&AE<')O>'DG
M+`H@("`@)W!R;WAY7W!R;W1O8V]L)R`]/B`G<W-L.B\O)RP*("`@("=P<F]X
M>5]P;W)T)R`]/B`T-#,L"B`@("`G<')O>'E?=7-E<B<@/3X@)R<L"B`@("`G
M<')O>'E?<&%S<R<@/3X@)R<L"B`@("`G97)R;F\G(#T^(#`L"B`@("`G97)R
M<W1R:6YG)R`]/B`G)RP*("`@("=D96)U9R<@/3X@,"P*("`@("=U<V5R;F%M
M92<@/3X@)R<L"B`@("`G<&%S<W=O<F0G(#T^("<G+`HI.PHD8R`](&YE=R!8
M34Q?4E!#7T-L:65N="@G=&AE<&%T:"<L("=S<VPZ+R]T:&5S97)V97(G+"`P
M+`H@("`@("`@("`@("`@("`@("`@("`@("`G<W-L.B\O=&AE<')O>'DG*3L*
M8V]M<&%R92@D>"P@)&,L("=D969A=6QT<R!W:71H('-S;"!P<F]X>2<I.PH*
M"B1X(#T@87)R87DH"B`@("`G<&%T:"<@/3X@)W1H97!A=&@G+`H@("`@)W-E
M<G9E<B<@/3X@)W1H97-E<G9E<B<L"B`@("`G<')O=&]C;VPG(#T^("=H='1P
M.B\O)RP*("`@("=P;W)T)R`]/B`V-2P*("`@("=P<F]X>2<@/3X@)W1H97!R
M;WAY)RP*("`@("=P<F]X>5]P<F]T;V-O;"<@/3X@)VAT='`Z+R\G+`H@("`@
M)W!R;WAY7W!O<G0G(#T^(#8U-C4L"B`@("`G<')O>'E?=7-E<B<@/3X@)R<L
M"B`@("`G<')O>'E?<&%S<R<@/3X@)R<L"B`@("`G97)R;F\G(#T^(#`L"B`@
M("`G97)R<W1R:6YG)R`]/B`G)RP*("`@("=D96)U9R<@/3X@,"P*("`@("=U
M<V5R;F%M92<@/3X@)R<L"B`@("`G<&%S<W=O<F0G(#T^("<G+`HI.PHD8R`]
M(&YE=R!834Q?4E!#7T-L:65N="@G=&AE<&%T:"<L("=T:&5S97)V97(G+"`V
M-2P*("`@("`@("`@("`@("`@("`@("`@("`@)W1H97!R;WAY)RP@-C4V-2D[
M"F-O;7!A<F4H)'@L("1C+"`G<&]R="`V-2!P<F]X>2`V-38U)RD["@HD>"`]
M(&%R<F%Y*`H@("`@)W!A=&@G(#T^("=T:&5P871H)RP*("`@("=S97)V97(G
M(#T^("=T:&5S97)V97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G:'1T<#HO+R<L
M"B`@("`G<&]R="<@/3X@-C4L"B`@("`G<')O>'DG(#T^("=T:&5P<F]X>2<L
M"B`@("`G<')O>'E?<')O=&]C;VPG(#T^("=H='1P.B\O)RP*("`@("=P<F]X
M>5]P;W)T)R`]/B`V-38U+`H@("`@)W!R;WAY7W5S97(G(#T^("<G+`H@("`@
M)W!R;WAY7W!A<W,G(#T^("<G+`H@("`@)V5R<FYO)R`]/B`P+`H@("`@)V5R
M<G-T<FEN9R<@/3X@)R<L"B`@("`G9&5B=6<G(#T^(#`L"B`@("`G=7-E<FYA
M;64G(#T^("<G+`H@("`@)W!A<W-W;W)D)R`]/B`G)RP**3L*)&,@/2!N97<@
M6$U,7U)00U]#;&EE;G0H)W1H97!A=&@G+"`G:'1T<#HO+W1H97-E<G9E<B<L
M(#8U+`H@("`@("`@("`@("`@("`@("`@("`@("`G:'1T<#HO+W1H97!R;WAY
M)RP@-C4V-2D["F-O;7!A<F4H)'@L("1C+"`G<&]R="`V-2!W:71H(&AT='`@
M<')O>'D@-C4V-2<I.PH*)'@@/2!A<G)A>2@*("`@("=P871H)R`]/B`G=&AE
M<&%T:"<L"B`@("`G<V5R=F5R)R`]/B`G=&AE<V5R=F5R)RP*("`@("=P<F]T
M;V-O;"<@/3X@)W-S;#HO+R<L"B`@("`G<&]R="<@/3X@-C4L"B`@("`G<')O
M>'DG(#T^("=T:&5P<F]X>2<L"B`@("`G<')O>'E?<')O=&]C;VPG(#T^("=S
M<VPZ+R\G+`H@("`@)W!R;WAY7W!O<G0G(#T^(#8U-C4L"B`@("`G<')O>'E?
M=7-E<B<@/3X@)R<L"B`@("`G<')O>'E?<&%S<R<@/3X@)R<L"B`@("`G97)R
M;F\G(#T^(#`L"B`@("`G97)R<W1R:6YG)R`]/B`G)RP*("`@("=D96)U9R<@
M/3X@,"P*("`@("=U<V5R;F%M92<@/3X@)R<L"B`@("`G<&%S<W=O<F0G(#T^
M("<G+`HI.PHD8R`](&YE=R!834Q?4E!#7T-L:65N="@G=&AE<&%T:"<L("=H
M='1P<SHO+W1H97-E<G9E<B<L(#8U+`H@("`@("`@("`@("`@("`@("`@("`@
M("`G:'1T<',Z+R]T:&5P<F]X>2<L(#8U-C4I.PIC;VUP87)E*"1X+"`D8RP@
M)W!O<G0@-C4@=VET:"!H='1P<R!P<F]X>2`V-38U)RD["@HD>"`](&%R<F%Y
M*`H@("`@)W!A=&@G(#T^("=T:&5P871H)RP*("`@("=S97)V97(G(#T^("=T
M:&5S97)V97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G<W-L.B\O)RP*("`@("=P
M;W)T)R`]/B`V-2P*("`@("=P<F]X>2<@/3X@)W1H97!R;WAY)RP*("`@("=P
M<F]X>5]P<F]T;V-O;"<@/3X@)W-S;#HO+R<L"B`@("`G<')O>'E?<&]R="<@
M/3X@-C4V-2P*("`@("=P<F]X>5]U<V5R)R`]/B`G)RP*("`@("=P<F]X>5]P
M87-S)R`]/B`G)RP*("`@("=E<G)N;R<@/3X@,"P*("`@("=E<G)S=')I;F<G
M(#T^("<G+`H@("`@)V1E8G5G)R`]/B`P+`H@("`@)W5S97)N86UE)R`]/B`G
M)RP*("`@("=P87-S=V]R9"<@/3X@)R<L"BD["B1C(#T@;F5W(%A-3%]24$-?
M0VQI96YT*"=T:&5P871H)RP@)W-S;#HO+W1H97-E<G9E<B<L(#8U+`H@("`@
M("`@("`@("`@("`@("`@("`@("`G<W-L.B\O=&AE<')O>'DG+"`V-38U*3L*
M8V]M<&%R92@D>"P@)&,L("=P;W)T(#8U('=I=&@@<W-L('!R;WAY(#8U-C4G
M*3L*"@HD>"`](&%R<F%Y*`H@("`@)W!A=&@G(#T^("=T:&5P871H)RP*("`@
M("=S97)V97(G(#T^("=T:&5S97)V97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G
M<W-L.B\O)RP*("`@("=P;W)T)R`]/B`T-#,L"B`@("`G<')O>'DG(#T^("=T
M:&5P<F]X>2<L"B`@("`G<')O>'E?<')O=&]C;VPG(#T^("=S<VPZ+R\G+`H@
M("`@)W!R;WAY7W!O<G0G(#T^(#0T,RP*("`@("=P<F]X>5]U<V5R)R`]/B`G
M)RP*("`@("=P<F]X>5]P87-S)R`]/B`G)RP*("`@("=E<G)N;R<@/3X@,"P*
M("`@("=E<G)S=')I;F<G(#T^("<G+`H@("`@)V1E8G5G)R`]/B`P+`H@("`@
M)W5S97)N86UE)R`]/B`G)RP*("`@("=P87-S=V]R9"<@/3X@)R<L"BD["B1C
M(#T@;F5W(%A-3%]24$-?0VQI96YT*"=T:&5P871H)RP@)W1H97-E<G9E<B<L
M(#0T,RP*("`@("`@("`@("`@("`@("`@("`@("`@)W1H97!R;WAY)RP@-#0S
M*3L*8V]M<&%R92@D>"P@)&,L("=P;W)T(#0T,R!N;R!P<F]T;V-O;"!A;F0@
M<')O>'D@<&]R="`T-#,@;F\@<')O=&]C;VPG*3L*"B1X(#T@87)R87DH"B`@
M("`G<&%T:"<@/3X@)W1H97!A=&@G+`H@("`@)W-E<G9E<B<@/3X@)W1H97-E
M<G9E<B<L"B`@("`G<')O=&]C;VPG(#T^("=H='1P.B\O)RP*("`@("=P;W)T
M)R`]/B`X,"P*("`@("=P<F]X>2<@/3X@)W1H97!R;WAY)RP*("`@("=P<F]X
M>5]P<F]T;V-O;"<@/3X@)W-S;#HO+R<L"B`@("`G<')O>'E?<&]R="<@/3X@
M-C4V-2P*("`@("=P<F]X>5]U<V5R)R`]/B`G)RP*("`@("=P<F]X>5]P87-S
M)R`]/B`G)RP*("`@("=E<G)N;R<@/3X@,"P*("`@("=E<G)S=')I;F<G(#T^
M("<G+`H@("`@)V1E8G5G)R`]/B`P+`H@("`@)W5S97)N86UE)R`]/B`G)RP*
M("`@("=P87-S=V]R9"<@/3X@)R<L"BD["B1C(#T@;F5W(%A-3%]24$-?0VQI
M96YT*"=T:&5P871H)RP@)W1H97-E<G9E<B<L(#`L"B`@("`@("`@("`@("`@
M("`@("`@("`@("=S<VPZ+R]T:&5P<F]X>2<L(#8U-C4I.PIC;VUP87)E*"1X
M+"`D8RP@)W!O<G0@-#0S(&YO('!R;W1O8V]L(&%N9"!P<F]X>2!P;W)T(#0T
M,R!N;R!P<F]T;V-O;"<I.PH`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+UA-3%]24$,O=&5S=',O
M=&5S=%]$=6UP+G!H<```````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,#0R`#$P-3$U
M-#,S-S0R`#`R-#<R-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`H*+RH*("H@268@=&AE('!A8VMA9V4@=F5R<VEO
M;B!N=6UB97(@:7,@9F]U;F0@:6X@=&AE(&QE9G0@:&%N9`H@*B!P;W)T:6]N
M(&]F('1H92!I9B@I(&5X<')E<W-I;VX@8F5L;W<L('1H870@;65A;G,@=&AI
M<R!F:6QE(&AA<PH@*B!C;VUE(&9R;VT@=&AE(%!%05(@:6YS=&%L;&5R+B`@
M5&AE<F5F;W)E+"!L970G<R!T97-T('1H90H@*B!I;G-T86QL960@=F5R<VEO
M;B!O9B!834Q?4E!#('=H:6-H('-H;W5L9"!B92!I;B!T:&4@:6YC;'5D92!P
M871H+@H@*B`*("H@268@=&AE('9E<G-I;VX@:&%S(&YO="!B965N('-U8G-T
M:71U=&5D(&EN('1H92!I9B@I(&5X<')E<W-I;VXL"B`J('1H:7,@9FEL92!H
M87,@;&EK96QY(&-O;64@9G)O;2!A($-64R!C:&5C:V]U="!O<B!A("YT87(@
M9FEL92X*("H@5&AE<F5F;W)E+"!W92=L;"!A<W-U;64@=&AE('1E<W1S('-H
M;W5L9"!U<V4@=&AE('9E<G-I;VX@;V8*("H@6$U,7U)00R!T:&%T(&AA<R!C
M;VUE(&9R;VT@=&AE<F4@87,@=V5L;"X*("HO"FEF("@G,2XT+C@G("$]("=`
M)RXG<&%C:V%G95]V97)S:6]N)RXG0"<I('L*("`@("\J*@H@("`@("H@1V5T
M('1H92!N965D960@8VQA<W,@9G)O;2!T:&4@4$5!4B!I;G-T86QL871I;VX*
M("`@("`J+PH@("`@<F5Q=6ER95]O;F-E("=834PO4E!#+T1U;7`N<&AP)SL*
M?2!E;'-E('L*("`@("\J*@H@("`@("H@1V5T('1H92!N965D960@8VQA<W,@
M9G)O;2!T:&4@<&%R96YT(&1I<F5C=&]R>0H@("`@("HO"B`@("!R97%U:7)E
M7V]N8V4@)RXN+T1U;7`N<&AP)SL*?0H*)'9A;"`](&YE=R!834Q?4E!#7U9A
M;'5E*&%R<F%Y*`H@("`@)W1I=&QE)R`@("`]/FYE=R!834Q?4E!#7U9A;'5E
M*"=D87,@:7-T(&1E<B!4:71E;"<L("=S=')I;F<G*2P*("`@("=S=&%R=$1A
M=&4G/3YN97<@6$U,7U)00U]686QU92AM:W1I;64H,"PP+#`L,3,L,3$L,C`P
M-"DL("=D871E5&EM92YI<V\X-C`Q)RDL"B`@("`G96YD1&%T92<@(#T^;F5W
M(%A-3%]24$-?5F%L=64H;6MT:6UE*#`L,"PP+#$U+#$Q+#(P,#0I+"`G9&%T
M951I;64N:7-O.#8P,2<I+`H@("`@)V5R<F]R)R`@("`]/B=S=')I;F<G+`H@
M("`@)V%R:V5Y)R`@("`]/B!N97<@6$U,7U)00U]686QU92@@87)R87DH"B`@
M("`@("`@;F5W(%A-3%]24$-?5F%L=64H)W-I;7!L92!S=')I;F<G*2P*("`@
M("`@("!N97<@6$U,7U)00U]686QU92@Q,C,T-2P@)VEN="<I"B`@("`@("`@
M*2P@)V%R<F%Y)RD*("`@("D*("`@("PG<W1R=6-T)RD["@I834Q?4E!#7T1U
M;7`H)'9A;"D["@IE8VAO("<]/3T]/3T]/3T]/3T]/2<@+B`B7')<;B(["B1V
M86PR(#T@;F5W(%A-3%]24$-?5F%L=64H-#0S-3,L("=I;G0G*3L*6$U,7U)0
M0U]$=6UP*"1V86PR*3L*"F5C:&\@)ST]/3T]/3T]/3T]/3T])R`N(")<<EQN
M(CL*)'9A;#,@/2!N97<@6$U,7U)00U]686QU92@G=&AI<R!S:&]U;&0@8F4@
M82!S=')I;F<G+"`G<W1R:6YG)RD["EA-3%]24$-?1'5M<"@D=F%L,RD["@IE
M8VAO("<]/3T]/3T]/3T]/3T]/2<@+B`B7')<;B(["B1V86PT(#T@;F5W(%A-
M3%]24$-?5F%L=64H=')U92P@)V)O;VQE86XG*3L*6$U,7U)00U]$=6UP*"1V
M86PT*3L*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]834Q?4E!#+W1E<W1S+W1Y<&5S
M+G!H<``````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-C0T,``Q,#4Q-30S,S<T
M,@`P,C0Q,S0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"B\J*@H@*B!497-T<R!H;W<@=&AE(%A-3%]24$,@<V5R
M=F5R(&AA;F1L97,@82!B=6YC:"!O9B!D:69F97)E;G0@<&%R86UE=&5R"B`J
M(&1A=&$@='EP97,N"B`J"B`J($EF('EO=2!A<F4@<G5N;FEN9R!T:&ES('1E
M<W0@9G)O;2!A($-64R!C:&5C:V]U="P@>6]U(&UU<W0@<F5N86UE('1H92!W
M;W)K:6YG"B`J(&1I<F5C=&]R>2!F<F]M(")834Q?4E!#(B!T;R`B6$U,(BX*
M("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H
M92!02%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@
M87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A
M<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A
M;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R
M>2`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("!834Q?4E!#"B`J($!A
M=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*
M("H@0&-O<'ER:6=H="`@,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!T>7!E<RYP:'`L=B`Q
M+C$@,C`P-2\Q,"\Q-2`R,#HR.3HT-B!D86YI96QC($5X<"`D"B`J($!L:6YK
M("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]834Q?4E!#"B`J
M($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT
M+C0*("HO"@HO*@H@*B!)9B!T:&4@<&%C:V%G92!V97)S:6]N(&YU;6)E<B!I
M<R!F;W5N9"!I;B!T:&4@;&5F="!H86YD"B`J('!O<G1I;VX@;V8@=&AE(&EF
M*"D@97AP<F5S<VEO;B!B96QO=RP@=&AA="!M96%N<R!T:&ES(&9I;&4@:&%S
M"B`J(&-O;64@9G)O;2!T:&4@4$5!4B!I;G-T86QL97(N("!4:&5R969O<F4L
M(&QE="=S('1E<W0@=&AE"B`J(&EN<W1A;&QE9"!V97)S:6]N(&]F(%A-3%]2
M4$,@=VAI8V@@<VAO=6QD(&)E(&EN('1H92!I;F-L=61E('!A=&@N"B`J(`H@
M*B!)9B!T:&4@=F5R<VEO;B!H87,@;F]T(&)E96X@<W5B<W1I='5T960@:6X@
M=&AE(&EF*"D@97AP<F5S<VEO;BP*("H@=&AI<R!F:6QE(&AA<R!L:6ME;'D@
M8V]M92!F<F]M(&$@0U93(&-H96-K;W5T(&]R(&$@+G1A<B!F:6QE+@H@*B!4
M:&5R969O<F4L('=E)VQL(&%S<W5M92!T:&4@=&5S=',@<VAO=6QD('5S92!T
M:&4@=F5R<VEO;B!O9@H@*B!834Q?4E!#('1H870@:&%S(&-O;64@9G)O;2!T
M:&5R92!A<R!W96QL+@H@*B\*:68@*"<Q+C0N."<@(3T@)T`G+B=P86-K86=E
M7W9E<G-I;VXG+B=`)RD@>PH@("`@+RHJ"B`@("`@*B!'970@=&AE(&YE961E
M9"!C;&%S<R!F<F]M('1H92!014%2(&EN<W1A;&QA=&EO;@H@("`@("HO"B`@
M("!R97%U:7)E7V]N8V4@)UA-3"]24$,O4V5R=F5R+G!H<"<["GT@96QS92![
M"B`@("!I9B`H<W5B<W1R*&1I<FYA;64H7U]&24Q%7U\I+"`M.2P@+38I("$]
M("=834PG*2!["B`@("`@("`@96-H;R`B5&AE('!A<F5N="!D:7)E8W1O<GD@
M;75S="!B92!N86UE9"`G6$U,)RY<;B(["B`@("`@("`@97AI=#L*("`@('T*
M"B`@("!I;FE?<V5T*"=I;F-L=61E7W!A=&@G+"`G+BXO+BXO)PH@("`@("`@
M("`@("`N(%!!5$A?4T5005)!5$]2("X@)RXG("X@4$%42%]315!!4D%43U(*
M("`@("`@("`@("`@+B!I;FE?9V5T*"=I;F-L=61E7W!A=&@G*0H@("`@*3L*
M"B`@("`O*BH*("`@("`J($=E="!T:&4@;F5E9&5D(&-L87-S(&9R;VT@=&AE
M('!A<F5N="!D:7)E8W1O<GD*("`@("`J+PH@("`@<F5Q=6ER95]O;F-E("<N
M+B]397)V97(N<&AP)SL*?0H*)$=,3T)!3%-;)TA45%!?4D%77U!/4U1?1$%4
M02==(#T@/#P\14]03U-4"CP_>&UL('9E<G-I;VX](C$N,"(_/@H\;65T:&]D
M0V%L;#X*(#QM971H;V1.86UE/F%L;&=O=#PO;65T:&]D3F%M93X*("`\<&%R
M86US/@H@("`\<&%R86T^/'9A;'5E/F1E9F%U;'0@=&\@<W1R:6YG/"]V86QU
M93X\+W!A<F%M/@H@("`\<&%R86T^/'9A;'5E/CQS=')I;F<^:6YS:61E('-T
M<FEN9SPO<W1R:6YG/CPO=F%L=64^/"]P87)A;3X*("`@/'!A<F%M/CQV86QU
M93X\:6YT/C@\+VEN=#X\+W9A;'5E/CPO<&%R86T^"B`@(#QP87)A;3X\=F%L
M=64^/&1A=&5T:6UE+FES;S@V,#$^,C`P-3`X,#E4,#$Z,S,Z-#0\+V1A=&5T
M:6UE+FES;S@V,#$^/"]V86QU93X\+W!A<F%M/@H*("`@/'!A<F%M/@H@("`@
M/'9A;'5E/@H@("`@(#QA<G)A>3X*("`@("`@/&1A=&$^"B`@("`@("`\=F%L
M=64^"B`@("`@("`@/'-T<FEN9SYA/"]S=')I;F<^"B`@("`@("`\+W9A;'5E
M/@H@("`@("`@/'9A;'5E/@H@("`@("`@(#QS=')I;F<^8CPO<W1R:6YG/@H@
M("`@("`@/"]V86QU93X*("`@("`@/"]D871A/@H@("`@(#PO87)R87D^"B`@
M("`\+W9A;'5E/@H@("`\+W!A<F%M/@H*("`@/'!A<F%M/@H@("`@/'9A;'5E
M/@H@("`@(#QS=')U8W0^"B`@("`@(#QM96UB97(^"B`@("`@("`\;F%M93YA
M/"]N86UE/@H@("`@("`@/'9A;'5E/@H@("`@("`@(#QS=')I;F<^87D\+W-T
M<FEN9SX*("`@("`@(#PO=F%L=64^"B`@("`@(#PO;65M8F5R/@H@("`@("`\
M;65M8F5R/@H@("`@("`@/&YA;64^8CPO;F%M93X*("`@("`@(#QV86QU93X*
M("`@("`@("`\<W1R:6YG/F)E/"]S=')I;F<^"B`@("`@("`\+W9A;'5E/@H@
M("`@("`\+VUE;6)E<CX*("`@("`\+W-T<G5C=#X*("`@(#PO=F%L=64^"B`@
M(#PO<&%R86T^"@H@(#PO<&%R86US/@H@/"]M971H;V1#86QL/@I%3U!/4U0[
M"@HD97AP96-T(#T@/#P\14]%6%`*/#]X;6P@=F5R<VEO;CTB,2XP(B!E;F-O
M9&EN9STB551&+3@B/SX*/&UE=&AO9%)E<W!O;G-E/@H\<&%R86US/@H\<&%R
M86T^"CQV86QU93X\<W1R:6YG/G!A<F%M(#`Z("=D969A=6QT('1O('-T<FEN
M9R<*<&%R86T@,3H@)VEN<VED92!S=')I;F<G"G!A<F%M(#(Z("<X)PIP87)A
M;2`S.B`G,C`P-3`X,#E4,#$Z,S,Z-#0G"G!A<F%M(#0Z(&%R<F%Y("@*("`P
M(#TF9W0[("=A)RP*("`Q(#TF9W0[("=B)RP**0IP87)A;2`U.B!A<G)A>2`H
M"B`@)V$G(#TF9W0[("=A>2<L"B`@)V(G(#TF9W0[("=B92<L"BD*/"]S=')I
M;F<^/"]V86QU93X*/"]P87)A;3X*/"]P87)A;7,^"CPO;65T:&]D4F5S<&]N
M<V4^"D5/15A0.PH*:6YC;'5D92`G+B]A;&QG;W0N:6YC)SL*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O6$U,+P``````````````````````````
M````````````````````````````````````````````````````````````
M,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W
M,S8`,#$W,C0V`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]834PO4&%R
M<V5R+P``````````````````````````````````````````````````````
M```````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#4Q-30S,S<S-@`P,C`U,#(`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+UA-3"]087)S97(O4VEM<&QE+G!H<```````````````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#(P,C`T`#$P-3$U-#,S-S,V`#`R,C0T,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@
M5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`T(%1H92!02%`@
M1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL
M92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS
M92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C
M:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@
M?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C
M;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*
M+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L
M96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P
M:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN
M("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!!=71H;W(Z(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+71O
M;VQS+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z(%-I;7!L92YP:'`L=B`Q
M+C8@,C`P-2\P,R\R-2`Q-SHQ,SHQ,"!S8VAS="!%>'`@)`H*+RHJ"B`J(%-I
M;7!L92!834P@<&%R<V5R(&-L87-S+@H@*@H@*B!4:&ES(&-L87-S(&ES(&$@
M<VEM<&QI9FEE9"!V97)S:6]N(&]F(%A-3%]087)S97(N"B`J($EN(&UO<W0@
M6$U,(&%P<&QI8V%T:6]N<R!T:&4@<F5A;"!A8W1I;VX@:7,@97AE8W5T960L
M"B`J('=H96X@82!C;&]S:6YG('1A9R!I<R!F;W5N9"X*("H*("H@6$U,7U!A
M<G-E<E]3:6UP;&4@86QL;W=S('EO=2!T;R!J=7-T(&EM<&QE;65N="!O;F4@
M8V%L;&)A8VL*("H@9F]R(&5A8V@@=&%G('1H870@=VEL;"!R96-E:79E('1H
M92!T86<@=VET:"!I=',@871T<FEB=71E<PH@*B!A;F0@0T1A=&$*("H*("H@
M0&-A=&5G;W)Y(%A-3`H@*B!`<&%C:V%G92!834Q?4&%R<V5R"B`J($!A=71H
M;W(@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+71O;VQS+FYE=#X*("HO
M"@HO*BH*("H@8G5I;'0@;VX@6$U,7U!A<G-E<@H@*B\*<F5Q=6ER95]O;F-E
M("=834PO4&%R<V5R+G!H<"<["@HO*BH*("H@4VEM<&QE(%A-3"!P87)S97(@
M8VQA<W,N"B`J"B`J(%1H:7,@8VQA<W,@:7,@82!S:6UP;&EF:65D('9E<G-I
M;VX@;V8@6$U,7U!A<G-E<BX*("H@26X@;6]S="!834P@87!P;&EC871I;VYS
M('1H92!R96%L(&%C=&EO;B!I<R!E>&5C=71E9"P*("H@=VAE;B!A(&-L;W-I
M;F<@=&%G(&ES(&9O=6YD+@H@*@H@*B!834Q?4&%R<V5R7U-I;7!L92!A;&QO
M=W,@>6]U('1O(&IU<W0@:6UP;&5M96YT(&]N92!C86QL8F%C:PH@*B!F;W(@
M96%C:"!T86<@=&AA="!W:6QL(')E8V5I=F4@=&AE('1A9R!W:71H(&ET<R!A
M='1R:6)U=&5S"B`J(&%N9"!#1&%T82X*("H*("H@/&-O9&4^"B`J(')E<75I
M<F5?;VYC92`G+BXO4&%R<V5R+U-I;7!L92YP:'`G.PH@*@H@*B!C;&%S<R!M
M>5!A<G-E<B!E>'1E;F1S(%A-3%]087)S97)?4VEM<&QE"B`J('L*("H@("`@
M(&9U;F-T:6]N(&UY4&%R<V5R*"D*("H@("`@('L*("H@("`@("`@("1T:&ES
M+3Y834Q?4&%R<V5R7U-I;7!L92@I.PH@*B`@("`@('T*("H@"B`J("`@(&9U
M;F-T:6]N(&AA;F1L945L96UE;G0H)&YA;64L("1A='1R:6)S+"`D9&%T82D*
M("H@("`@('L*("H@("`@("`@("!P<FEN=&8H)VAA;F1L92`E<SQB<CXG+"`D
M;F%M92D["B`J("`@("!]"B`J('T*("H@"B`J("1P(#T@)FYE=R!M>5!A<G-E
M<B@I.PH@*B`*("H@)')E<W5L="`]("1P+3YS971);G!U=$9I;&4H)VUY1&]C
M+GAM;"<I.PH@*B`D<F5S=6QT(#T@)'`M/G!A<G-E*"D["B`J(#PO8V]D93X*
M("H*("H@0&-A=&5G;W)Y(%A-3`H@*B!`<&%C:V%G92!834Q?4&%R<V5R"B`J
M($!A=71H;W(@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+71O;VQS+FYE
M=#X*("HO"F-L87-S(%A-3%]087)S97)?4VEM<&QE(&5X=&5N9',@6$U,7U!A
M<G-E<@I["B`@("\J*@H@("`@*B!E;&5M96YT('-T86-K"B`@("`J"B`@("`J
M($!A8V-E<W,@("!P<FEV871E"B`@("`J($!V87(@("`@("!A<G)A>0H@("`@
M*B\*("`@('9A<B`D7V5L4W1A8VL@/2!A<G)A>2@I.PH*("`@+RHJ"B`@("`J
M(&%L;"!C:&%R86-T97(@9&%T80H@("`@*@H@("`@*B!`86-C97-S("`@<')I
M=F%T90H@("`@*B!`=F%R("`@("`@87)R87D*("`@("HO"B`@("!V87(@)%]D
M871A(#T@87)R87DH*3L*"B`@("\J*@H@("`@*B!E;&5M96YT(&1E<'1H"B`@
M("`J"B`@("`J($!A8V-E<W,@("!P<FEV871E"B`@("`J($!V87(@("`@("!I
M;G1E9V5R"B`@("`J+PH@("`@=F%R("1?9&5P=&@@/2`P.PH*("`@("\J*@H@
M("`@("H@36%P<&EN9R!F<F]M(&5X<&%T(&AA;F1L97(@9G5N8W1I;VX@=&\@
M8VQA<W,@;65T:&]D+@H@("`@("H*("`@("`J($!V87(@(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D:&%N9&QE<B`](&%R<F%Y*`H@("`@("`@("=D969A=6QT
M7VAA;F1L97(G("`@("`@("`@("`@("`@("`@(#T^("=D969A=6QT2&%N9&QE
M<B<L"B`@("`@("`@)W!R;V-E<W-I;F=?:6YS=')U8W1I;VY?:&%N9&QE<B<@
M("`@/3X@)W!I2&%N9&QE<B<L"B`@("`@("`@)W5N<&%R<V5D7V5N=&ET>5]D
M96-L7VAA;F1L97(G("`@("`@/3X@)W5N<&%R<V5D2&%N9&QE<B<L"B`@("`@
M("`@)VYO=&%T:6]N7V1E8VQ?:&%N9&QE<B<@("`@("`@("`@("`@/3X@)VYO
M=&%T:6]N2&%N9&QE<B<L"B`@("`@("`@)V5X=&5R;F%L7V5N=&ET>5]R969?
M:&%N9&QE<B<@("`@("`@/3X@)V5N=&ET>7)E9DAA;F1L97(G"B`@("`I.PH@
M("`@"B`@("`O*BH*("`@("`J($-R96%T97,@86X@6$U,('!A<G-E<BX*("`@
M("`J"B`@("`@*B!4:&ES(&ES(&YE961E9"!F;W(@4$A0-"!C;VUP871I8FEL
M:71Y+"!I="!W:6QL"B`@("`@*B!C86QL('1H92!C;VYS=')U8W1O<BP@=VAE
M;B!A(&YE=R!I;G-T86YC92!I<R!C<F5A=&5D+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'-R8V5N8R!S;W5R8V4@8VAA<G-E="!E;F-O9&EN9RP@
M=7-E($Y53$P@*&1E9F%U;'0I('1O('5S90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@('=H871E=F5R('1H92!D;V-U;65N="!S<&5C:69I97,*("`@
M("`J($!P87)A;2!S=')I;F<@)&UO9&4@("!H;W<@=&AI<R!P87)S97(@;V)J
M96-T('-H;W5L9"!W;W)K+"`B979E;G0B(&9O<@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(&AA;F1L945L96UE;G0H*2P@(F9U;F,B('1O(&AA=F4@
M:70@8V%L;"!F=6YC=&EO;G,*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!N86UE9"!A9G1E<B!E;&5M96YT<R`H:&%N9&QE16QE;65N=%\D;F%M92@I
M*0H@("`@("H@0'!A<F%M('-T<FEN9R`D=&=E;F,@(&$@=F%L:60@=&%R9V5T
M(&5N8V]D:6YG"B`@("`@*B\*("`@(&9U;F-T:6]N(%A-3%]087)S97)?4VEM
M<&QE*"1S<F-E;F,@/2!N=6QL+"`D;6]D92`]("=E=F5N="<L("1T9W1E;F,@
M/2!N=6QL*0H@("`@>PH@("`@("`@("1T:&ES+3Y834Q?4&%R<V5R*"1S<F-E
M;F,L("1M;V1E+"`D=&=T96YC*3L*("`@('T*"B`@("`O*BH*("`@("`J(&EN
M:71S('1H92!H86YD;&5R<PH@("`@("H*("`@("`J($!A8V-E<W,@('!R:79A
M=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7VEN:71(86YD;&5R<R@I"B`@("![
M"B`@("`@("`@:68@*"%I<U]O8FIE8W0H)'1H:7,M/E]H86YD;&5R3V)J*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7VAA;F1L97)/8FH@/2`F)'1H:7,["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/FUO9&4@(3T@)V9U;F,G("8F
M("1T:&ES+3YM;V1E("$]("=E=F5N="<I('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"=5;G-U<'!O<G1E9"!M;V1E(&=I=F5N)RP@
M6$U,7U!!4E-%4E]%4E)/4E]53E-54%!/4E1%1%]-3T1%*3L*("`@("`@("!]
M"B`@("`@("`@>&UL7W-E=%]O8FIE8W0H)'1H:7,M/G!A<G-E<BP@)'1H:7,M
M/E]H86YD;&5R3V)J*3L*"B`@("`@("`@>&UL7W-E=%]E;&5M96YT7VAA;F1L
M97(H)'1H:7,M/G!A<G-E<BP@87)R87DH)B1T:&ES+"`G<W1A<G1(86YD;&5R
M)RDL(&%R<F%Y*"8D=&AI<RP@)V5N9$AA;F1L97(G*2D["B`@("`@("`@>&UL
M7W-E=%]C:&%R86-T97)?9&%T85]H86YD;&5R*"1T:&ES+3YP87)S97(L(&%R
M<F%Y*"8D=&AI<RP@)V-D871A2&%N9&QE<B<I*3L*("`@("`@("`*("`@("`@
M("`O*BH*("`@("`@("`@*B!S970@861D:71I;VYA;"!H86YD;&5R<R!F;W(@
M8VAA<F%C=&5R(&1A=&$L(&5N=&ET:65S+"!E=&,N"B`@("`@("`@("HO"B`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/FAA;F1L97(@87,@)'AM;%]F=6YC(#T^
M("1M971H;V0I('L*("`@("`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H)'1H
M:7,M/E]H86YD;&5R3V)J+"`D;65T:&]D*2D@>PH@("`@("`@("`@("`@("`@
M)'AM;%]F=6YC(#T@)WAM;%]S971?)R`N("1X;6Q?9G5N8SL*("`@("`@("`@
M("`@("`@("1X;6Q?9G5N8R@D=&AI<RT^<&%R<V5R+"`D;65T:&]D*3L*("`@
M("`@("`@("`@?0H)"7T*("`@('T*"B`@("`O*BH*("`@("`J(%)E<V5T('1H
M92!P87)S97(N"B`@("`@*@H@("`@("H@5&AI<R!A;&QO=W,@>6]U('1O('5S
M92!O;F4@<&%R<V5R(&EN<W1A;F-E"B`@("`@*B!T;R!P87)S92!M=6QT:7!L
M92!834P@9&]C=6UE;G1S+@H@("`@("H*("`@("`J($!A8V-E<W,@("!P=6)L
M:6,*("`@("`J($!R971U<FX@("!B;V]L96%N?&]B:F5C="`@("`@=')U92!O
M;B!S=6-C97-S+"!014%27T5R<F]R(&]T:&5R=VES90H@("`@("HO"B`@("!F
M=6YC=&EO;B!R97-E="@I"B`@("!["B`@("`@("`@)'1H:7,M/E]E;%-T86-K
M(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^7V1A=&$@("`@/2!A<G)A>2@I
M.PH@("`@("`@("1T:&ES+3Y?9&5P=&@@("`](#`["B`@("`@("`@"B`@("`@
M("`@)')E<W5L="`]("1T:&ES+3Y?8W)E871E*"D["B`@("`@("`@:68@*"1T
M:&ES+3YI<T5R<F]R*"`D<F5S=6QT("DI('L*("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M?0H*("`@+RHJ"B`@("`J('-T87)T(&AA;F1L97(*("`@("H*("`@("H@4'5S
M:&5S(&%T=')I8G5T97,@86YD('1A9VYA;64@;VYT;R!A('-T86-K"B`@("`J
M"B`@("`J($!A8V-E<W,@("!P<FEV871E"B`@("`J($!F:6YA;`H@("`@*B!`
M<&%R86T@("`@<F5S;W5R8V4@("`@>&UL('!A<G-E<B!R97-O=7)C90H@("`@
M*B!`<&%R86T@("`@<W1R:6YG("`@("`@96QE;65N="!N86UE"B`@("`J($!P
M87)A;2`@("!A<G)A>2`@("`@("!A='1R:6)U=&5S"B`@("`J+PH@("`@9G5N
M8W1I;VX@<W1A<G1(86YD;&5R*"1X<"P@)&5L96TL("8D871T<FEB<RD*("`@
M('L*("`@("`@("!A<G)A>5]P=7-H*"1T:&ES+3Y?96Q3=&%C:RP@87)R87DH
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VYA;64G("`@(#T^("1E;&5M+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=A='1R:6)S)R`]/B`D871T<FEB<PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*0H@("`@("`@
M("`@("`@("`@("`I.PH@("`@("`@("1T:&ES+3Y?9&5P=&@K*SL*("`@("`@
M("`D=&AI<RT^7V1A=&%;)'1H:7,M/E]D97!T:%T@/2`G)SL*("`@('T*"B`@
M("\J*@H@("`@*B!E;F0@:&%N9&QE<@H@("`@*@H@("`@*B!0=6QL<R!A='1R
M:6)U=&5S(&%N9"!T86=N86UE(&9R;VT@82!S=&%C:PH@("`@*@H@("`@*B!`
M86-C97-S("`@<')I=F%T90H@("`@*B!`9FEN86P*("`@("H@0'!A<F%M("`@
M(')E<V]U<F-E("`@('AM;"!P87)S97(@<F5S;W5R8V4*("`@("H@0'!A<F%M
M("`@('-T<FEN9R`@("`@(&5L96UE;G0@;F%M90H@("`@*B\*("`@(&9U;F-T
M:6]N(&5N9$AA;F1L97(H)'AP+"`D96QE;2D*("`@('L*("`@("`@("`D96P@
M("`](&%R<F%Y7W!O<"@D=&AI<RT^7V5L4W1A8VLI.PH@("`@("`@("1D871A
M(#T@)'1H:7,M/E]D871A6R1T:&ES+3Y?9&5P=&A=.PH@("`@("`@("1T:&ES
M+3Y?9&5P=&@M+3L*"B`@("`@("`@<W=I=&-H("@D=&AI<RT^;6]D92D@>PH@
M("`@("`@("`@("!C87-E("=E=F5N="<Z"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7VAA;F1L97)/8FHM/FAA;F1L945L96UE;G0H)&5L6R=N86UE)UTL("1E
M;%LG871T<FEB<R==+"`D9&%T82D["B`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@8V%S92`G9G5N8R<Z"B`@("`@("`@("`@("`@("`D9G5N
M8R`]("=H86YD;&5%;&5M96YT7R<@+B`D96QE;3L*("`@("`@("`@("`@("`@
M(&EF("AS=')C:'(H)&9U;F,L("<N)RDI('L*("`@("`@("`@("`@("`@("`@
M("`D9G5N8R`]('-T<E]R97!L86-E*"<N)RP@)U\G+"`D9G5N8RD["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H;65T:&]D7V5X:7-T
M<R@D=&AI<RT^7VAA;F1L97)/8FHL("1F=6YC*2D@>PH@("`@("`@("`@("`@
M("`@("`@(&-A;&Q?=7-E<E]F=6YC*&%R<F%Y*"8D=&AI<RT^7VAA;F1L97)/
M8FHL("1F=6YC*2P@)&5L6R=N86UE)UTL("1E;%LG871T<FEB<R==+"`D9&%T
M82D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("!]"B`@("!]"@H@("`O*BH*("`@("H@:&%N9&QE(&-H87)A8W1E
M<B!D871A"B`@("`J"B`@("`J($!A8V-E<W,@("!P<FEV871E"B`@("`J($!F
M:6YA;`H@("`@*B!`<&%R86T@("`@<F5S;W5R8V4@("`@>&UL('!A<G-E<B!R
M97-O=7)C90H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@9&%T80H@("`@
M*B\*("`@(&9U;F-T:6]N(&-D871A2&%N9&QE<B@D>'`L("1D871A*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?9&%T85LD=&AI<RT^7V1E<'1H72`N/2`D9&%T
M83L*("`@('T*"B`@("\J*@H@("`@*B!H86YD;&4@82!T86<*("`@("H*("`@
M("H@26UP;&5M96YT('1H:7,@:6X@>6]U<B!P87)S97(@"B`@("`J"B`@("`J
M($!A8V-E<W,@("!P=6)L:6,*("`@("H@0&%B<W1R86-T"B`@("`J($!P87)A
M;2`@("!S=')I;F<@("`@("!E;&5M96YT(&YA;64*("`@("H@0'!A<F%M("`@
M(&%R<F%Y("`@("`@(&%T=')I8G5T97,*("`@("H@0'!A<F%M("`@('-T<FEN
M9R`@("`@(&-H87)A8W1E<B!D871A"B`@("`J+PH@("`@9G5N8W1I;VX@:&%N
M9&QE16QE;65N="@D;F%M92P@)&%T=')I8G,L("1D871A*0H@("`@>PH@("`@
M?0H*("`@+RHJ"B`@("`J(&=E="!T:&4@8W5R<F5N="!T86<@9&5P=&@*("`@
M("H*("`@("H@5&AE(')O;W0@=&%G(&ES(&EN(&1E<'1H(#`N"B`@("`J"B`@
M("`J($!A8V-E<W,@("!P=6)L:6,*("`@("H@0')E='5R;B`@(&EN=&5G97(*
M("`@("HO"B`@("!F=6YC=&EO;B!G971#=7)R96YT1&5P=&@H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7V1E<'1H.PH@("`@?0H*("`@+RHJ"B`@
M("`J(&%D9"!S;VUE('-T<FEN9R!T;R!T:&4@8W5R<F5N="!D9&%T82X*("`@
M("H*("`@("H@5&AI<R!I<R!C;VUM;VYL>2!N965D960L('=H96X@82!D;V-U
M;65N="!I<R!P87)S960@<F5C=7)S:79E;'DN"B`@("`J"B`@("`J($!A8V-E
M<W,@("!P=6)L:6,*("`@("H@0'!A<F%M("`@('-T<FEN9R`@("`@(&1A=&$@
M=&\@861D"B`@("`J($!R971U<FX@("!V;VED"B`@("`J+PH@("`@9G5N8W1I
M;VX@861D5&]$871A*"`D9&%T82`I"B`@("!["B`@("`@("`@)'1H:7,M/E]D
M871A6R1T:&ES+3Y?9&5P=&A=("X]("1D871A.PH@("`@?0I]"C\^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+UA-3"]087)S97(N<&AP````````````````````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#0U,#4V`#$P-3$U-#,S-S,V`#`R,3(R-0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO+PHO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`T(%1H92!02%`@1W)O=7`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J
M96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@
M?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T
M:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B
M;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H
M92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A
M:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD
M(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O
M('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!
M=71H;W(Z(%-T:6<@0F%K:V5N(#QS<V)`9F%S="YN;SX@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("!4;VUA<R!6
M+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\("`@("`@("`@4W1E<&AA;B!38VAM:61T(#QS8VAS
M=$!P:'`M=&]O;',N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@4&%R<V5R
M+G!H<"QV(#$N,C8@,C`P-2\P.2\R,R`Q,3HU,3HQ,"!S8VAS="!%>'`@)`H*
M+RHJ"B`J(%A-3"!087)S97(@8VQA<W,N"B`J"B`J(%1H:7,@:7,@86X@6$U,
M('!A<G-E<B!B87-E9"!O;B!02%`G<R`B>&UL(B!E>'1E;G-I;VXL"B`J(&)A
M<V5D(&]N('1H92!B=6YD;&5D(&5X<&%T(&QI8G)A<GDN"B`J"B`J($!C871E
M9V]R>2!834P*("H@0'!A8VMA9V4@6$U,7U!A<G-E<@H@*B!`875T:&]R("!3
M=&EG($)A:VME;B`\<W-B0&9A<W0N;F\^"B`J($!A=71H;W(@(%1O;6%S(%8N
M5BY#;W@@/&-O>$!I9&5C;F5T+F-O;3X*("H@0&%U=&AO<B`@4W1E<&AA;B!3
M8VAM:61T(#QS8VAS=$!P:'`M=&]O;',N;F5T/@H@*B\*"B\J*@H@*B!U<V5S
M(%!%05(G<R!E<G)O<B!H86YD;&EN9PH@*B\*<F5Q=6ER95]O;F-E("=014%2
M+G!H<"<["@HO*BH*("H@<F5S;W5R8V4@8V]U;&0@;F]T(&)E(&-R96%T960*
M("HO"F1E9FEN92@G6$U,7U!!4E-%4E]%4E)/4E].3U]215-/55)#12<L(#(P
M,"D["@HO*BH*("H@=6YS=7!P;W)T960@;6]D90H@*B\*9&5F:6YE*"=834Q?
M4$%24T527T524D]27U5.4U504$]25$5$7TU/1$4G+"`R,#$I.PH*+RHJ"B`J
M(&EN=F%L:60@96YC;V1I;F<@=V%S(&=I=F5N"B`J+PID969I;F4H)UA-3%]0
M05)315)?15)23U)?24Y604Q)1%]%3D-/1$E.1R<L(#(P,BD["@HO*BH*("H@
M<W!E8VEF:65D(&9I;&4@8V]U;&0@;F]T(&)E(')E860*("HO"F1E9FEN92@G
M6$U,7U!!4E-%4E]%4E)/4E]&24Q%7TY/5%]214%$04),12<L(#(P,RD["@HO
M*BH*("H@:6YV86QI9"!I;G!U=`H@*B\*9&5F:6YE*"=834Q?4$%24T527T52
M4D]27TE.5D%,241?24Y0550G+"`R,#0I.PH*+RHJ"B`J(')E;6]T92!F:6QE
M(&-A;FYO="!B92!R971R:65V960@:6X@<V%F92!M;V1E"B`J+PID969I;F4H
M)UA-3%]005)315)?15)23U)?4D5-3U1%)RP@,C`U*3L*"B\J*@H@*B!834P@
M4&%R<V5R(&-L87-S+@H@*@H@*B!4:&ES(&ES(&%N(%A-3"!P87)S97(@8F%S
M960@;VX@4$A0)W,@(GAM;"(@97AT96YS:6]N+`H@*B!B87-E9"!O;B!T:&4@
M8G5N9&QE9"!E>'!A="!L:6)R87)Y+@H@*@H@*B!.;W1E<SH*("H@+2!)="!R
M97%U:7)E<R!02%`@-"XP+C1P;#$@;W(@9W)E871E<@H@*B`M($9R;VT@<F5V
M:7-I;VX@,2XQ-RP@=&AE(&9U;F-T:6]N(&YA;65S('5S960@8GD@=&AE("=F
M=6YC)R!M;V1E"B`J("`@87)E(&EN('1H92!F;W)M870@(GAM;'1A9U\D96QE
M;2(L(&9O<B!E>&%M<&QE.B!U<V4@(GAM;'1A9U]N86UE(@H@*B`@('1O(&AA
M;F1L92!T:&4@/&YA;64^/"]N86UE/B!T86=S(&]F('EO=7(@>&UL(&9I;&4N
M"B`J"B`J($!C871E9V]R>2!834P*("H@0'!A8VMA9V4@6$U,7U!A<G-E<@H@
M*B!`875T:&]R("!3=&EG($)A:VME;B`\<W-B0&9A<W0N;F\^"B`J($!A=71H
M;W(@(%1O;6%S(%8N5BY#;W@@/&-O>$!I9&5C;F5T+F-O;3X*("H@0&%U=&AO
M<B`@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`M=&]O;',N;F5T/@H@*B!`
M=&]D;R`@("!C<F5A=&4@6$U,7U!A<G-E<E].86UE<W!A8V4@=&\@<&%R<V4@
M9&]C=6UE;G1S('=I=&@@;F%M97-P86-E<PH@*B!`=&]D;R`@("!C<F5A=&4@
M6$U,7U!A<G-E<E]0=6QL"B`J($!T;V1O("`@(%1E<W1S('1H870@;F5E9"!T
M;R!B92!M861E.@H@*B`@("`@("`@("`M(&UI>&EN9R!C:&%R86-T97(@96YC
M;V1I;F=S"B`J("`@("`@("`@("T@82!T97-T('5S:6YG(&%L;"!E>'!A="!H
M86YD;&5R<PH@*B`@("`@("`@("`M(&]P=&EO;G,@*&9O;&1I;F<L(&]U='!U
M="!C:&%R<V5T*0H@*B`@("`@("`@("`M(&1I9F9E<F5N="!P87)S:6YG(&UO
M9&5S"B`J+PIC;&%S<R!834Q?4&%R<V5R(&5X=&5N9',@4$5!4@I["B`@("`O
M+R![>WL@<')O<&5R=&EE<PH*("`@+RHJ"B`@("`@*B!834P@<&%R<V5R(&AA
M;F1L90H@("`@("H*("`@("`J($!V87(@(')E<V]U<F-E"B`@("`@*B!`<V5E
M("!X;6Q?<&%R<V5R7V-R96%T92@I"B`@("`@*B\*("`@('9A<B`D<&%R<V5R
M.PH*("`@("\J*@H@("`@("H@1FEL92!H86YD;&4@:68@<&%R<VEN9R!F<F]M
M(&$@9FEL90H@("`@("H*("`@("`J($!V87(@(')E<V]U<F-E"B`@("`@*B\*
M("`@('9A<B`D9G`["@H@("`@+RHJ"B`@("`@*B!7:&5T:&5R('1O(&1O(&-A
M<V4@9F]L9&EN9PH@("`@("H*("`@("`J($EF('-E="!T;R!T<G5E+"!A;&P@
M=&%G(&%N9"!A='1R:6)U=&4@;F%M97,@=VEL;`H@("`@("H@8F4@8V]N=F5R
M=&5D('1O(%504$52($-!4T4N"B`@("`@*@H@("`@("H@0'9A<B`@8F]O;&5A
M;@H@("`@("HO"B`@("!V87(@)&9O;&1I;F<@/2!T<G5E.PH*("`@("\J*@H@
M("`@("H@36]D92!O9B!O<&5R871I;VXL(&]N92!O9B`B979E;G0B(&]R(")F
M=6YC(@H@("`@("H*("`@("`J($!V87(@('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)&UO9&4["@H@("`@+RHJ"B`@("`@*B!-87!P:6YG(&9R;VT@97AP870@
M:&%N9&QE<B!F=6YC=&EO;B!T;R!C;&%S<R!M971H;V0N"B`@("`@*@H@("`@
M("H@0'9A<B`@87)R87D*("`@("`J+PH@("`@=F%R("1H86YD;&5R(#T@87)R
M87DH"B`@("`@("`@)V-H87)A8W1E<E]D871A7VAA;F1L97(G("`@("`@("`@
M("`@/3X@)V-D871A2&%N9&QE<B<L"B`@("`@("`@)V1E9F%U;'1?:&%N9&QE
M<B<@("`@("`@("`@("`@("`@("`@/3X@)V1E9F%U;'1(86YD;&5R)RP*("`@
M("`@("`G<')O8V5S<VEN9U]I;G-T<G5C=&EO;E]H86YD;&5R)R`@("`]/B`G
M<&E(86YD;&5R)RP*("`@("`@("`G=6YP87)S961?96YT:71Y7V1E8VQ?:&%N
M9&QE<B<@("`@("`]/B`G=6YP87)S961(86YD;&5R)RP*("`@("`@("`G;F]T
M871I;VY?9&5C;%]H86YD;&5R)R`@("`@("`@("`@("`]/B`G;F]T871I;VY(
M86YD;&5R)RP*("`@("`@("`G97AT97)N86Q?96YT:71Y7W)E9E]H86YD;&5R
M)R`@("`@("`]/B`G96YT:71Y<F5F2&%N9&QE<B<*("`@("D["@H@("`@+RHJ
M"B`@("`@*B!S;W5R8V4@96YC;V1I;F<*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)'-R8V5N8SL*"B`@("`O*BH*("`@("`J
M('1A<F=E="!E;F-O9&EN9PH@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D=&=T96YC.PH*("`@("\J*@H@("`@("H@:&%N9&QE
M<B!O8FIE8W0*("`@("`J"B`@("`@*B!`=F%R(&]B:F5C=`H@("`@("HO"B`@
M("!V87(@)%]H86YD;&5R3V)J.PH*("`@("\O('U]?0H@("`@+R\@>WM[(&-O
M;G-T<G5C=&]R"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&%N(%A-3"!P87)S
M97(N"B`@("`@*@H@("`@("H@5&AI<R!I<R!N965D960@9F]R(%!(4#0@8V]M
M<&%T:6)I;&ET>2P@:70@=VEL;`H@("`@("H@8V%L;"!T:&4@8V]N<W1R=6-T
M;W(L('=H96X@82!N97<@:6YS=&%N8V4@:7,@8W)E871E9"X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1S<F-E;F,@<V]U<F-E(&-H87)S970@96YC
M;V1I;F<L('5S92!.54Q,("AD969A=6QT*2!T;R!U<V4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!W:&%T979E<B!T:&4@9&]C=6UE;G0@<W!E8VEF
M:65S"B`@("`@*B!`<&%R86T@<W1R:6YG("1M;V1E("`@:&]W('1H:7,@<&%R
M<V5R(&]B:F5C="!S:&]U;&0@=V]R:RP@(F5V96YT(B!F;W(*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!S=&%R=&5L96UE;G0O96YD96QE;65N="UT
M>7!E(&5V96YT<RP@(F9U;F,B"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@=&\@:&%V92!I="!C86QL(&9U;F-T:6]N<R!N86UE9"!A9G1E<B!E;&5M
M96YT<PH@("`@("H@0'!A<F%M('-T<FEN9R`D=&=E;F,@(&$@=F%L:60@=&%R
M9V5T(&5N8V]D:6YG"B`@("`@*B\*("`@(&9U;F-T:6]N(%A-3%]087)S97(H
M)'-R8V5N8R`](&YU;&PL("1M;V1E(#T@)V5V96YT)RP@)'1G=&5N8R`](&YU
M;&PI"B`@("!["B`@("`@("`@6$U,7U!A<G-E<CHZ7U]C;VYS=')U8W0H)'-R
M8V5N8RP@)&UO9&4L("1T9W1E;F,I.PH@("`@?0H@("`@+R\@?7U]"@H@("`@
M+RHJ"B`@("`@*B!02%`U(&-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<W)C96YC('-O=7)C92!C:&%R<V5T(&5N8V]D:6YG+"!U
M<V4@3E5,3"`H9&5F875L="D@=&\@=7-E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@=VAA=&5V97(@=&AE(&1O8W5M96YT('-P96-I9FEE<PH@("`@
M("H@0'!A<F%M('-T<FEN9R`D;6]D92`@(&AO=R!T:&ES('!A<G-E<B!O8FIE
M8W0@<VAO=6QD('=O<FLL(")E=F5N="(@9F]R"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@<W1A<G1E;&5M96YT+V5N9&5L96UE;G0M='EP92!E=F5N
M=',L(")F=6YC(@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('1O(&AA
M=F4@:70@8V%L;"!F=6YC=&EO;G,@;F%M960@869T97(@96QE;65N=',*("`@
M("`J($!P87)A;2!S=')I;F<@)'1G96YC("!A('9A;&ED('1A<F=E="!E;F-O
M9&EN9PH@("`@("HO"B`@("!F=6YC=&EO;B!?7V-O;G-T<G5C="@D<W)C96YC
M(#T@;G5L;"P@)&UO9&4@/2`G979E;G0G+"`D=&=T96YC(#T@;G5L;"D*("`@
M('L*("`@("`@("`D=&AI<RT^4$5!4B@G6$U,7U!A<G-E<E]%<G)O<B<I.PH*
M("`@("`@("`D=&AI<RT^;6]D92`@(#T@)&UO9&4["B`@("`@("`@)'1H:7,M
M/G-R8V5N8R`]("1S<F-E;F,["B`@("`@("`@)'1H:7,M/G1G=&5N8R`]("1T
M9W1E;F,["B`@("!]"B`@("`O+R!]?7T*"B`@("`O*BH*("`@("`J(%-E=',@
M=&AE(&UO9&4@;V8@=&AE('!A<G-E<BX*("`@("`J"B`@("`@*B!0;W-S:6)L
M92!M;V1E<R!A<F4Z"B`@("`@*B`M(&9U;F,*("`@("`J("T@979E;G0*("`@
M("`J"B`@("`@*B!9;W4@8V%N('-E="!T:&4@;6]D92!U<VEN9R!T:&4@<V5C
M;VYD('!A<F%M971E<@H@("`@("H@:6X@=&AE(&-O;G-T<G5C=&]R+@H@("`@
M("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&]N;'D@;F5E9&5D+"!W:&5N('-W
M:71C:&EN9R!T;R!A(&YE=PH@("`@("H@;6]D92!A="!A(&QA=&5R('!O:6YT
M+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'!A<F%M
M("`@<W1R:6YG("`@("`@("`@(&UO9&4L(&5I=&AE<B`G9G5N8R<@;W(@)V5V
M96YT)PH@("`@("H@0')E='5R;B`@8F]O;&5A;GQO8FIE8W0@('1R=64@;VX@
M<W5C8V5S<RP@4$5!4E]%<G)O<B!O=&AE<G=I<V4@("`*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T36]D92@D;6]D92D*("`@('L*("`@("`@("!I9B`H)&UO
M9&4@(3T@)V9U;F,G("8F("1M;V1E("$]("=E=F5N="<I('L*("`@("`@("`@
M("`@)'1H:7,M/G)A:7-E17)R;W(H)U5N<W5P<&]R=&5D(&UO9&4@9VEV96XG
M+"!834Q?4$%24T527T524D]27U5.4U504$]25$5$7TU/1$4I.PH@("`@("`@
M('T*"B`@("`@("`@)'1H:7,M/FUO9&4@/2`D;6]D93L*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(&]B:F5C
M="P@=&AA="!W:6QL(&AA;F1L92!T:&4@6$U,(&5V96YT<PH@("`@("H*("`@
M("`J(%1H:7,@86QL;W=S('EO=2!T;R!C<F5A=&4@82!H86YD;&5R(&]B:F5C
M="!I;F1E<&5N9&5N="!O9B!T:&4*("`@("`J('!A<G-E<B!O8FIE8W0@=&AA
M="!Y;W4@87)E('5S:6YG(&%N9"!E87-I;'D@<W=I=&-H('1H92!U;F1E<FQY
M:6YG"B`@("`@*B!P87)S97(N"B`@("`@*@H@("`@("H@268@;F\@;V)J96-T
M('=I;&P@8F4@<V5T+"!834Q?4&%R<V5R(&%S<W5M97,@=&AA="!Y;W4*("`@
M("`J(&5X=&5N9"!T:&ES(&-L87-S(&%N9"!H86YD;&4@=&AE(&5V96YT<R!I
M;B`D=&AI<RX*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J
M($!P87)A;2`@(&]B:F5C="`@("`@(&]B:F5C="!T;R!H86YD;&4@=&AE(&5V
M96YT<PH@("`@("H@0')E='5R;B`@8F]O;&5A;B`@("`@=VEL;"!A;'=A>7,@
M<F5T=7)N('1R=64*("`@("`J($!S:6YC92`@('8Q+C(N,&)E=&$S"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=$AA;F1L97)/8FHH)B1O8FHI"B`@("!["B`@
M("`@("`@)'1H:7,M/E]H86YD;&5R3V)J(#T@)B1O8FH["B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!);FET('1H92!E;&5M
M96YT(&AA;F1L97)S"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@
M("`@("HO"B`@("!F=6YC=&EO;B!?:6YI=$AA;F1L97)S*"D*("`@('L*("`@
M("`@("!I9B`H(6ES7W)E<V]U<F-E*"1T:&ES+3YP87)S97(I*2!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("@A
M:7-?;V)J96-T*"1T:&ES+3Y?:&%N9&QE<D]B:BDI('L*("`@("`@("`@("`@
M)'1H:7,M/E]H86YD;&5R3V)J(#T@)B1T:&ES.PH@("`@("`@('T*("`@("`@
M("!S=VET8V@@*"1T:&ES+3YM;V1E*2!["@H@("`@("`@("`@("!C87-E("=F
M=6YC)SH*("`@("`@("`@("`@("`@('AM;%]S971?;V)J96-T*"1T:&ES+3YP
M87)S97(L("1T:&ES+3Y?:&%N9&QE<D]B:BD["B`@("`@("`@("`@("`@("!X
M;6Q?<V5T7V5L96UE;G1?:&%N9&QE<B@D=&AI<RT^<&%R<V5R+"!A<G)A>2@F
M)'1H:7,L("=F=6YC4W1A<G1(86YD;&5R)RDL(&%R<F%Y*"8D=&AI<RP@)V9U
M;F-%;F1(86YD;&5R)RDI.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!C87-E("=E=F5N="<Z"B`@("`@("`@("`@("`@("!X;6Q?<V5T
M7V]B:F5C="@D=&AI<RT^<&%R<V5R+"`D=&AI<RT^7VAA;F1L97)/8FHI.PH@
M("`@("`@("`@("`@("`@>&UL7W-E=%]E;&5M96YT7VAA;F1L97(H)'1H:7,M
M/G!A<G-E<BP@)W-T87)T2&%N9&QE<B<L("=E;F1(86YD;&5R)RD["B`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G56YS=7!P;W)T
M960@;6]D92!G:79E;B<L(%A-3%]005)315)?15)23U)?54Y355!03U)4141?
M34]$12D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H*("`@
M("`@("`O*BH*("`@("`@("`@*B!S970@861D:71I;VYA;"!H86YD;&5R<R!F
M;W(@8VAA<F%C=&5R(&1A=&$L(&5N=&ET:65S+"!E=&,N"B`@("`@("`@("HO
M"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/FAA;F1L97(@87,@)'AM;%]F=6YC
M(#T^("1M971H;V0I('L*("`@("`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H
M)'1H:7,M/E]H86YD;&5R3V)J+"`D;65T:&]D*2D@>PH@("`@("`@("`@("`@
M("`@)'AM;%]F=6YC(#T@)WAM;%]S971?)R`N("1X;6Q?9G5N8SL*("`@("`@
M("`@("`@("`@("1X;6Q?9G5N8R@D=&AI<RT^<&%R<V5R+"`D;65T:&]D*3L*
M("`@("`@("`@("`@?0H)"7T*("`@('T*"B`@("`O+R![>WL@7V-R96%T92@I
M"@H@("`@+RHJ"B`@("`@*B!C<F5A=&4@=&AE(%A-3"!P87)S97(@<F5S;W5R
M8V4*("`@("`J"B`@("`@*B!(87,@8F5E;B!M;W9E9"!F<F]M('1H92!C;VYS
M=')U8W1O<B!T;R!A=F]I9`H@("`@("H@<')O8FQE;7,@=VET:"!O8FIE8W0@
M<F5F97)E;F-E<RX*("`@("`J"B`@("`@*B!&=7)T:&5R;6]R92!I="!A;&QO
M=W,@=7,@<F5T=7)N:6YG(&%N(&5R<F]R"B`@("`@*B!I9B!S;VUE=&AI;F<@
M9F%I;',N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@('!R:79A=&4*("`@("`J
M($!R971U<FX@("!B;V]L96%N?&]B:F5C="`@("`@=')U92!O;B!S=6-C97-S
M+"!014%27T5R<F]R(&]T:&5R=VES90H@("`@("H*("`@("`J($!S964@>&UL
M7W!A<G-E<E]C<F5A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V-R96%T92@I
M"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YS<F-E;F,@/3T](&YU;&PI('L*
M("`@("`@("`@("`@)'AP(#T@0'AM;%]P87)S97)?8W)E871E*"D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'AP(#T@0'AM;%]P87)S97)?8W)E
M871E*"1T:&ES+3YS<F-E;F,I.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?
M<F5S;W5R8V4H)'AP*2D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/G1G=&5N
M8R`A/3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@:68@*"%`>&UL7W!A<G-E
M<E]S971?;W!T:6]N*"1X<"P@6$U,7T]05$E/3E]405)'151?14Y#3T1)3D<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/G1G=&5N8RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)VEN=F%L:60@=&%R9V5T(&5N8V]D:6YG)RP@
M6$U,7U!!4E-%4E]%4E)/4E])3E9!3$E$7T5.0T]$24Y'*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^<&%R
M<V5R(#T@)'AP.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;FET
M2&%N9&QE<G,H)'1H:7,M/FUO9&4I.PH@("`@("`@("`@("!I9B`H)'1H:7,M
M/FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@("`@('AM;%]P87)S97)?
M<V5T7V]P=&EO;B@D>'`L(%A-3%]/4%1)3TY?0T%315]&3TQ$24Y'+"`D=&AI
M<RT^9F]L9&EN9RD["@H@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=5;F%B;&4@
M=&\@8W)E871E(%A-3"!P87)S97(@<F5S;W5R8V4N)RP@6$U,7U!!4E-%4E]%
M4E)/4E].3U]215-/55)#12D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@<F5S970H*0H*("`@("\J*@H@("`@("H@4F5S970@=&AE('!A<G-E<BX*
M("`@("`J"B`@("`@*B!4:&ES(&%L;&]W<R!Y;W4@=&\@=7-E(&]N92!P87)S
M97(@:6YS=&%N8V4*("`@("`J('1O('!A<G-E(&UU;'1I<&QE(%A-3"!D;V-U
M;65N=',N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@("H@
M0')E='5R;B`@(&)O;VQE86Y\;V)J96-T("`@("!T<G5E(&]N('-U8V-E<W,L
M(%!%05)?17)R;W(@;W1H97)W:7-E"B`@("`@*B\*("`@(&9U;F-T:6]N(')E
M<V5T*"D*("`@('L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C<F5A=&4H
M*3L*("`@("`@("!I9B`H)'1H:7,M/FES17)R;W(H("1R97-U;'0@*2D@>PH@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<V5T
M26YP=71&:6QE*"D*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(&EN<'5T('AM
M;"!F:6QE('1O(&)E('!A<G-E9`H@("`@("H*("`@("`J($!P87)A;2`@("!S
M=')I;F<@("`@("!&:6QE;F%M92`H9G5L;"!P871H*0H@("`@("H@0')E='5R
M;B`@(')E<V]U<F-E("`@(&9O<&5N(&AA;F1L92!O9B!T:&4@9VEV96X@9FEL
M90H@("`@("H@0'1H<F]W<R`@(%A-3%]087)S97)?17)R;W(*("`@("`J($!S
M964@("`@("!S971);G!U="@I+"!S971);G!U=%-T<FEN9R@I+"!P87)S92@I
M"B`@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E=$EN<'5T1FEL92@D9FEL92D*("`@('L*("`@("`@("`O*BH*("`@("`@
M("`@*B!C:&5C:RP@:68@9FEL92!I<R!A(')E;6]T92!F:6QE"B`@("`@("`@
M("HO"B`@("`@("`@:68@*&5R96=I*"=>*&AT='!\9G1P*3HO+R<L('-U8G-T
M<B@D9FEL92P@,"P@,3`I*2D@>PH@("`@("`@("`@("!I9B`H(6EN:5]G970H
M)V%L;&]W7W5R;%]F;W!E;B<I*2!["B`@("`@("`@("`@(`ER971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H)U)E;6]T92!F:6QE<R!C86YN;W0@8F4@<&%R<V5D
M+"!A<R!S869E(&UO9&4@:7,@96YA8FQE9"XG+"!834Q?4$%24T527T524D]2
M7U)%34]412D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@"B`@
M("`@("`@)&9P(#T@0&9O<&5N*"1F:6QE+"`G<F(G*3L*("`@("`@("!I9B`H
M:7-?<F5S;W5R8V4H)&9P*2D@>PH@("`@("`@("`@("`D=&AI<RT^9G`@/2`D
M9G`["B`@("`@("`@("`@(')E='5R;B`D9G`["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G1FEL92!C;W5L9"!N;W0@8F4@
M;W!E;F5D+B<L(%A-3%]005)315)?15)23U)?1DE,15].3U1?4D5!1$%"3$4I
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('-E=$EN<'5T4W1R:6YG
M*"D*("`@(`H@("`@+RHJ"B`@("`@*B!834Q?4&%R<V5R.CIS971);G!U=%-T
M<FEN9R@I"B`@("`@*B`*("`@("`J(%-E=',@=&AE('AM;"!I;G!U="!F<F]M
M(&$@<W1R:6YG"B`@("`@*B`*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&$@
M82!S=')I;F<@8V]N=&%I;FEN9R!T:&4@6$U,(&1O8W5M96YT"B`@("`@*B!`
M<F5T=7)N(&YU;&P*("`@("`J*B\*("`@(&9U;F-T:6]N('-E=$EN<'5T4W1R
M:6YG*"1D871A*0H@("`@>PH@("`@("`@("1T:&ES+3YF<"`]("1D871A.PH@
M("`@("`@(')E='5R;B!N=6QL.PH@("`@?0H@("`@"B`@("`O+R!]?7T*("`@
M("\O('M[>R!S971);G!U="@I"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!F
M:6QE(&AA;F1L92!T;R!U<V4@=VET:"!P87)S92@I+@H@("`@("H*("`@("`J
M(%EO=2!S:&]U;&0@=7-E('-E=$EN<'5T1FEL92@I(&]R('-E=$EN<'5T4W1R
M:6YG*"D@:68@>6]U"B`@("`@*B!P87-S(&$@<W1R:6YG(`H@("`@("H*("`@
M("`J($!P87)A;2`@("!M:7AE9"`@)&9P("!#86X@8F4@96ET:&5R(&$@<F5S
M;W5R8V4@<F5T=7)N960@9G)O;2!F;W!E;B@I+`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(&$@55),+"!A(&QO8V%L(&9I;&5N86UE(&]R(&$@<W1R
M:6YG+@H@("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@("H@0'-E92`@("`@
M('!A<G-E*"D*("`@("`J($!U<V5S("`@("!S971);G!U=%-T<FEN9R@I+"!S
M971);G!U=$9I;&4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!S971);G!U="@D
M9G`I"B`@("!["B`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1F<"DI('L*("`@
M("`@("`@("`@)'1H:7,M/F9P(#T@)&9P.PH@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("!]"B`@("`@("`@+R\@<V5E(&EF(&ET)W,@86X@86)S
M;VQU=&4@55),("AH87,@82!S8VAE;64@870@=&AE(&)E9VEN;FEN9RD*("`@
M("`@("!E;'-E:68@*&5R96=I*"=>6V$M>ETK.B\O)RP@<W5B<W1R*"1F<"P@
M,"P@,3`I*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-E=$EN<'5T
M1FEL92@D9G`I.PH@("`@("`@('T*("`@("`@("`O+R!S964@:68@:70G<R!A
M(&QO8V%L(&9I;&4*("`@("`@("!E;'-E:68@*&9I;&5?97AI<W1S*"1F<"DI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS971);G!U=$9I;&4H)&9P
M*3L*("`@("`@("!]"B`@("`@("`@+R\@:70@;75S="!B92!A('-T<FEN9PH@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^9G`@/2`D9G`["B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*"=);&QE9V%L(&EN<'5T(&9O<FUA="<L
M(%A-3%]005)315)?15)23U)?24Y604Q)1%])3E!55"D["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@<&%R<V4H*0H*("`@("\J*@H@("`@("H@0V5N
M=')A;"!P87)S:6YG(&9U;F-T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@
M("!T<G5E?&]B:F5C="!014%2(&5R<F]R("`@("!R971U<FYS('1R=64@;VX@
M<W5C8V5S<RP@;W(@82!014%27T5R<F]R(&]T:&5R=VES90H@("`@("H@0&%C
M8V5S<R`@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!P87)S92@I"B`@
M("!["B`@("`@("`@+RHJ"B`@("`@("`@("H@<F5S970@=&AE('!A<G-E<@H@
M("`@("`@("`J+PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^<F5S970H*3L*
M("`@("`@("!I9B`H)'1H:7,M/FES17)R;W(H)')E<W5L="DI('L*("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@("`@("\O(&EF
M("1T:&ES+3YF<"!W87,@9F]P96YE9"!P<F5V:6]U<VQY"B`@("`@("`@:68@
M*&ES7W)E<V]U<F-E*"1T:&ES+3YF<"DI('L*("`@("`@("`*("`@("`@("`@
M("`@=VAI;&4@*"1D871A(#T@9G)E860H)'1H:7,M/F9P+"`T,#DV*2D@>PH@
M("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^7W!A<G-E4W1R:6YG*"1D871A
M+"!F96]F*"1T:&ES+3YF<"DI*2!["B`@("`@("`@("`@("`@("`@("`@)&5R
M<F]R(#T@)B1T:&ES+3YR86ES945R<F]R*"D["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/F9R964H*3L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)&5R<F]R.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@+R\@;W1H97)W:7-E+"`D=&AI<RT^9G`@;75S="!B92!A('-T<FEN9PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]P87)S
M95-T<FEN9R@D=&AI<RT^9G`L('1R=64I*2!["B`@("`@("`@("`@("`@("`D
M97)R;W(@/2`F)'1H:7,M/G)A:7-E17)R;W(H*3L*("`@("`@("`@("`@("`@
M("1T:&ES+3YF<F5E*"D["B`@("`@("`@("`@("`@("!R971U<FX@)&5R<F]R
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1T:&ES+3YF<F5E
M*"D["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@6$U,7U!A<G-E<CHZ7W!A<G-E4W1R:6YG*"D*("`@("`J(`H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9&%T80H@("`@("H@0'!A<F%M(&)O;VQE86X@)&5O
M9@H@("`@("H@0')E='5R;B!B;V]L"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J($!S964@<&%R<V53=')I;F<H*0H@("`@("HJ+PH@("`@9G5N8W1I
M;VX@7W!A<G-E4W1R:6YG*"1D871A+"`D96]F(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@<F5T=7)N('AM;%]P87)S92@D=&AI<RT^<&%R<V5R+"`D9&%T82P@
M)&5O9BD["B`@("!]"B`@("`*("`@("\O('U]?0H@("`@+R\@>WM[('!A<G-E
M4W1R:6YG*"D*"B`@("`O*BH*("`@("`J(%A-3%]087)S97(Z.G!A<G-E4W1R
M:6YG*"D*("`@("`J(`H@("`@("H@4&%R<V5S(&$@<W1R:6YG+@H@("`@("H*
M("`@("`J($!P87)A;2`@("!S=')I;F<@("1D871A(%A-3"!D871A"B`@("`@
M*B!`<&%R86T@("`@8F]O;&5A;B`D96]F("!)9B!S970@86YD(%12544L(&1A
M=&$@:7,@=&AE(&QA<W0@<&EE8V4@;V8@9&%T82!S96YT(&EN('1H:7,@<&%R
M<V5R"B`@("`@*B!`=&AR;W=S("`@6$U,7U!A<G-E<E]%<G)O<@H@("`@("H@
M0')E='5R;B`@(%!E87(@17)R;W)\=')U92`@('1R=64@;VX@<W5C8V5S<R!O
M<B!A(%!%05(@17)R;W(*("`@("`J($!S964@("`@("!?<&%R<V53=')I;F<H
M*0H@("`@("HO"B`@("!F=6YC=&EO;B!P87)S95-T<FEN9R@D9&%T82P@)&5O
M9B`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/G!A
M<G-E<BD@?'P@(6ES7W)E<V]U<F-E*"1T:&ES+3YP87)S97(I*2!["B`@("`@
M("`@("`@("1T:&ES+3YR97-E="@I.PH@("`@("`@('T*("`@("`@("`*("`@
M("`@("!I9B`H(21T:&ES+3Y?<&%R<V53=')I;F<H)&1A=&$L("1E;V8I*2![
M"B`@("`@("`@("`@)&5R<F]R(#T@)B1T:&ES+3YR86ES945R<F]R*"D["B`@
M("`@("`@("`@)'1H:7,M/F9R964H*3L*("`@("`@("`@("!R971U<FX@)&5R
M<F]R.PH@("`@("`@('T*"B`@("`@("`@:68@*"1E;V8@/3T]('1R=64I('L*
M("`@("`@("`@("`@)'1H:7,M/F9R964H*3L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"B`@("`*("`@("\J*@H@("`@("H@6$U,7U!A
M<G-E<CHZ9G)E92@I"B`@("`@*B`*("`@("`J($9R964@=&AE(&EN=&5R;F%L
M(')E<V]U<F-E<R!A<W-O8VEA=&5D('=I=&@@=&AE('!A<G-E<@H@("`@("H@
M"B`@("`@*B!`<F5T=7)N(&YU;&P*("`@("`J*B\*("`@(&9U;F-T:6]N(&9R
M964H*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^<&%R<V5R*2`F
M)B!I<U]R97-O=7)C92@D=&AI<RT^<&%R<V5R*2D@>PH@("`@("`@("`@("!X
M;6Q?<&%R<V5R7V9R964H)'1H:7,M/G!A<G-E<BD["B`@("`@("`@("`@('5N
M<V5T*"`D=&AI<RT^<&%R<V5R("D["B`@("`@("`@?0H@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^9G`I("8F(&ES7W)E<V]U<F-E*"1T:&ES+3YF<"DI('L*
M("`@("`@("`@("`@9F-L;W-E*"1T:&ES+3YF<"D["B`@("`@("`@?0H@("`@
M("`@('5N<V5T*"1T:&ES+3YF<"D["B`@("`@("`@<F5T=7)N(&YU;&P["B`@
M("!]"B`@("`*("`@("\J*@H@("`@("H@6$U,7U!A<G-E<CHZ<F%I<V5%<G)O
M<B@I"B`@("`@*B`*("`@("`J(%1H<F]W<R!A(%A-3%]087)S97)?17)R;W(*
M("`@("`J(`H@("`@("H@0'!A<F%M('-T<FEN9R`@)&US9R`@('1H92!E<G)O
M<B!M97-S86=E"B`@("`@*B!`<&%R86T@:6YT96=E<B`D96-O9&4@=&AE(&5R
M<F]R(&UE<W-A9V4@8V]D90H@("`@("H@0')E='5R;B!834Q?4&%R<V5R7T5R
M<F]R(`H@("`@("HJ+PH@("`@9G5N8W1I;VX@<F%I<V5%<G)O<B@D;7-G(#T@
M;G5L;"P@)&5C;V1E(#T@,"D*("`@('L*("`@("`@("`D;7-G(#T@(6ES7VYU
M;&PH)&US9RD@/R`D;7-G(#H@)'1H:7,M/G!A<G-E<CL*("`@("`@("`D97)R
M(#T@)FYE=R!834Q?4&%R<V5R7T5R<F]R*"1M<V<L("1E8V]D92D["B`@("`@
M("`@<F5T=7)N('!A<F5N=#HZ<F%I<V5%<G)O<B@D97)R*3L*("`@('T*("`@
M(`H@("`@+R\@?7U]"B`@("`O+R![>WL@9G5N8U-T87)T2&%N9&QE<B@I"@H@
M("`@9G5N8W1I;VX@9G5N8U-T87)T2&%N9&QE<B@D>'`L("1E;&5M+"`D871T
M<FEB<RD*("`@('L*("`@("`@("`D9G5N8R`]("=X;6QT86=?)R`N("1E;&5M
M.PH@("`@("`@(&EF("AS=')C:'(H)&9U;F,L("<N)RDI('L*("`@("`@("`@
M("`@)&9U;F,@/2!S=')?<F5P;&%C92@G+B<L("=?)RP@)&9U;F,I.PH@("`@
M("`@('T*("`@("`@("!I9B`H;65T:&]D7V5X:7-T<R@D=&AI<RT^7VAA;F1L
M97)/8FHL("1F=6YC*2D@>PH@("`@("`@("`@("!C86QL7W5S97)?9G5N8RAA
M<G)A>2@F)'1H:7,M/E]H86YD;&5R3V)J+"`D9G5N8RDL("1X<"P@)&5L96TL
M("1A='1R:6)S*3L*("`@("`@("!](&5L<V5I9B`H;65T:&]D7V5X:7-T<R@D
M=&AI<RT^7VAA;F1L97)/8FHL("=X;6QT86<G*2D@>PH@("`@("`@("`@("!C
M86QL7W5S97)?9G5N8RAA<G)A>2@F)'1H:7,M/E]H86YD;&5R3V)J+"`G>&UL
M=&%G)RDL("1X<"P@)&5L96TL("1A='1R:6)S*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9G5N8T5N9$AA;F1L97(H*0H*("`@
M(&9U;F-T:6]N(&9U;F-%;F1(86YD;&5R*"1X<"P@)&5L96TI"B`@("!["B`@
M("`@("`@)&9U;F,@/2`G>&UL=&%G7R<@+B`D96QE;2`N("=?)SL*("`@("`@
M("!I9B`H<W1R8VAR*"1F=6YC+"`G+B<I*2!["B`@("`@("`@("`@("1F=6YC
M(#T@<W1R7W)E<&QA8V4H)RXG+"`G7R<L("1F=6YC*3L*("`@("`@("!]"B`@
M("`@("`@:68@*&UE=&AO9%]E>&ES=',H)'1H:7,M/E]H86YD;&5R3V)J+"`D
M9G5N8RDI('L*("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F,H87)R87DH)B1T
M:&ES+3Y?:&%N9&QE<D]B:BP@)&9U;F,I+"`D>'`L("1E;&5M*3L*("`@("`@
M("!](&5L<V5I9B`H;65T:&]D7V5X:7-T<R@D=&AI<RT^7VAA;F1L97)/8FHL
M("=X;6QT86=?)RDI('L*("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F,H87)R
M87DH)B1T:&ES+3Y?:&%N9&QE<D]B:BP@)WAM;'1A9U\G*2P@)'AP+"`D96QE
M;2D["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('-T
M87)T2&%N9&QE<B@I"@H@("`@+RHJ"B`@("`@*@H@("`@("H@0&%B<W1R86-T
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-T87)T2&%N9&QE<B@D>'`L("1E;&5M
M+"`F)&%T=')I8G,I"B`@("!["B`@("`@("`@<F5T=7)N($Y53$P["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@96YD2&%N9&QE<B@I"@H@("`@+RHJ
M"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&5N9$AA;F1L97(H)'AP+"`D96QE;2D*("`@('L*("`@("`@("!R971U<FX@
M3E5,3#L*("`@('T*"@H@("`@+R\@?7U];64*?0H*+RHJ"B`J(&5R<F]R(&-L
M87-S+"!R97!L86-E<R!014%27T5R<F]R"B`J"B`J($%N(&EN<W1A;F-E(&]F
M('1H:7,@8VQA<W,@=VEL;"!B92!R971U<FYE9`H@*B!I9B!A;B!E<G)O<B!O
M8V-U<G,@:6YS:61E(%A-3%]087)S97(N"B`J"B`J(%1H97)E(&%R92!T:')E
M92!A9'9A;G1A9V5S(&]V97(@=7-I;F<@=&AE('-T86YD87)D(%!%05)?17)R
M;W(Z"B`J("T@06QL(&UE<W-A9V5S('=I;&P@8F4@<')E9FEX960*("H@+2!C
M:&5C:R!F;W(@6$U,7U!A<G-E<B!E<G)O<BP@=7-I;F<@:7-?82@@)&5R<F]R
M+"`G6$U,7U!A<G-E<E]%<G)O<B<@*0H@*B`M(&UE<W-A9V5S(&-A;B!B92!G
M96YE<F%T960@9G)O;2!T:&4@>&UL7W!A<G-E<B!R97-O=7)C90H@*@H@*B!`
M<&%C:V%G92!834Q?4&%R<V5R"B`J($!A8V-E<W,@('!U8FQI8PH@*B!`<V5E
M("`@("!014%27T5R<F]R"B`J+PIC;&%S<R!834Q?4&%R<V5R7T5R<F]R(&5X
M=&5N9',@4$5!4E]%<G)O<@I["B`@("`O+R![>WL@<')O<&5R=&EE<PH*("`@
M+RHJ"B`@("`J('!R969I>"!F;W(@86QL(&UE<W-A9V5S"B`@("`J"B`@("`J
M($!V87(@("`@("!S=')I;F<*("`@("HO("`@(`H@("`@=F%R("1E<G)O<E]M
M97-S86=E7W!R969I>"`]("=834Q?4&%R<V5R.B`G.PH*("`@("\O('U]?0H@
M("`@+R\@>WM[(&-O;G-T<G5C=&]R*"D*("`@+RHJ"B`@("`J(&-O;G-T<G5C
M="!A(&YE=R!E<G)O<B!I;G-T86YC90H@("`@*@H@("`@*B!9;W4@;6%Y(&5I
M=&AE<B!P87-S(&$@;65S<V%G92!O<B!A;B!X;6Q?<&%R<V5R(')E<V]U<F-E
M(&%S(&9I<G-T"B`@("`J('!A<F%M971E<BX@268@82!R97-O=7)C92!H87,@
M8F5E;B!P87-S960L('1H92!L87-T(&5R<F]R('1H870*("`@("H@:&%P<&5N
M960@=VEL;"!B92!R971R:65V960@86YD(')E='5R;F5D+@H@("`@*@H@("`@
M*B!`86-C97-S("`@<'5B;&EC"B`@("`J($!P87)A;2`@("!S=')I;F=\<F5S
M;W5R8V4@("`@(&UE<W-A9V4@;W(@<&%R<V5R(')E<V]U<F-E"B`@("`J($!P
M87)A;2`@("!I;G1E9V5R("`@("`@("`@("`@(&5R<F]R(&-O9&4*("`@("H@
M0'!A<F%M("`@(&EN=&5G97(@("`@("`@("`@("`@97)R;W(@:&%N9&QI;F<*
M("`@("H@0'!A<F%M("`@(&EN=&5G97(@("`@("`@("`@("`@97)R;W(@;&5V
M96P*("`@("HO("`@(`H@("`@9G5N8W1I;VX@6$U,7U!A<G-E<E]%<G)O<B@D
M;7-G;W)P87)S97(@/2`G=6YK;F]W;B!E<G)O<B<L("1C;V1E(#T@,"P@)&UO
M9&4@/2!014%27T524D]27U)%5%523BP@)&QE=F5L(#T@15]54T527TY/5$E#
M12D*("`@('L*("`@("`@("!I9B`H:7-?<F5S;W5R8V4H)&US9V]R<&%R<V5R
M*2D@>PH@("`@("`@("`@("`D8V]D92`]('AM;%]G971?97)R;W)?8V]D92@D
M;7-G;W)P87)S97(I.PH@("`@("`@("`@("`D;7-G;W)P87)S97(@/2!S<')I
M;G1F*"<E<R!A="!834P@:6YP=70@;&EN92`E9#HE9"<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@>&UL7V5R<F]R7W-T<FEN9R@D8V]D
M92DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@>&UL7V=E
M=%]C=7)R96YT7VQI;F5?;G5M8F5R*"1M<V=O<G!A<G-E<BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@>&UL7V=E=%]C=7)R96YT7V-O
M;'5M;E]N=6UB97(H)&US9V]R<&%R<V5R*2D["B`@("`@("`@?0H@("`@("`@
M("1T:&ES+3Y014%27T5R<F]R*"1M<V=O<G!A<G-E<BP@)&-O9&4L("1M;V1E
M+"`D;&5V96PI.PH@("`@?0H@("`@+R\@?7U]"GT*/SX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+UA-3"]24$,O````
M````````````````````````````````````````````````````````````
M`````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-3$U-#,S-S,V`#`Q-S8W,@`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O6$U,+U)00R]$=6UP+G!H<```````````````````````````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,3(P-S0`,3`U,34T,S,W,S8`,#(Q,S$T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@HO
M*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S
M;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J($9U;F-T:6]N(&%N9"!C;&%S<R!T
M;R!D=6UP(%A-3%]24$-?5F%L=64@;V)J96-T<R!I;B!A(&YI8V4@=V%Y"B`J
M"B`J(%-H;W5L9"!B92!H96QP9G5L(&%S(&$@;F]R;6%L('9A<E]D=6UP*"XN
M*2!D:7-P;&%Y<R!A;&P@:6YT97)N86QS('=H:6-H"B`J(&1O97-N)W0@<F5A
M;&QY(&=I=F4@>6]U(&%N(&]V97)V:65W(&1U92!T;R!T;V\@;75C:"!I;F9O
M<FUA=&EO;BX*("H*("H@0&-A=&5G;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P
M86-K86=E("`@(%A-3%]24$,*("H@0&%U=&AO<B`@("`@0VAR:7-T:6%N(%=E
M:7-K92`\8W=E:7-K94!P:'`N;F5T/@H@*B!`=F5R<VEO;B`@("!#5E,Z("1)
M9#H@1'5M<"YP:'`L=B`Q+C<@,C`P-2\P,2\R-"`P,SHT-SHU-2!D86YI96QC
M($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]834Q?4E!#"B`J+PH*"B\J*@H@*B!0=6QL(&EN('1H92!834Q?4E!#
M(&-L87-S"B`J+PIR97%U:7)E7V]N8V4@)UA-3"]24$,N<&AP)SL*"@HO*BH*
M("H@1V5N97)A=&5S('1H92!D=6UP(&]F('1H92!834Q?4E!#7U9A;'5E(&%N
M9"!E8VAO97,@:70*("H*("H@0'!A<F%M(&]B:F5C="`D=F%L=64@('1H92!8
M34Q?4E!#7U9A;'5E(&]B:F5C="!T;R!D=6UP"B`J"B`J($!R971U<FX@=F]I
M9`H@*B\*9G5N8W1I;VX@6$U,7U)00U]$=6UP*"1V86QU92D*>PH@("`@)&1U
M;7!E<B`](&YE=R!834Q?4E!#7T1U;7`H*3L*("`@(&5C:&\@)&1U;7!E<BT^
M9V5N97)A=&5$=6UP*"1V86QU92D["GT*"@HO*BH*("H@0VQA<W,@=VAI8V@@
M9V5N97)A=&5S(&$@9'5M<"!O9B!A(%A-3%]24$-?5F%L=64@;V)J96-T"B`J
M"B`J($!C871E9V]R>2`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("!8
M34Q?4E!#"B`J($!A=71H;W(@("`@($-H<FES=&EA;B!796ES:V4@/&-W96ES
M:V5`<&AP+FYE=#X*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+C@*("H@
M0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+UA-3%]2
M4$,*("HO"F-L87-S(%A-3%]24$-?1'5M<`I["B`@("`O*BH*("`@("`J(%1H
M92!I;F1E;G1A=&EO;B!A<G)A>2!C86-H90H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)&%R26YD96YT("`@("`@/2!A<G)A>2@I.PH*("`@
M("\J*@H@("`@("H@5&AE('-P86-E<R!U<V5D(&9O<B!I;F1E;G1I;F<@=&AE
M(%A-3`H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1S=')"
M87-E26YD96YT(#T@)R`@("`G.PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@9'5M<"!I;B!834P@9F]R;6%T('=I=&AO=70@<')I;G1I;F<@:70@;W5T
M"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`D=F%L=64@("!T:&4@6$U,
M7U)00U]686QU92!O8FIE8W0@=&\@9'5M<`H@("`@("H@0'!A<F%M(&EN="`@
M("`D;DQE=F5L("!T:&4@;&5V96P@;V8@:6YD96YT871I;VX*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&1U;7`*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5N97)A=&5$=6UP*"1V86QU92P@)&Y,979E;"`](#`I"B`@("![
M"B`@("`@("`@:68@*"%I<U]O8FIE8W0H)'9A;'5E*2`F)B!G971?8VQA<W,H
M)'9A;'5E*2`A/2`G>&UL7W)P8U]V86QU92<I('L*("`@("`@("`@("`@<F5Q
M=6ER95]O;F-E("=014%2+G!H<"<["B`@("`@("`@("`@(%!%05(Z.G)A:7-E
M17)R;W(H)U1R:65D('1O(&1U;7`@;F]N+5A-3%]24$-?5F%L=64@=F%R:6%B
M;&4G("X@(EQR7&XB+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#`L
M(%!%05)?15)23U)?4%))3E0I.PH@("`@("`@("`@("!I9B`H:7-?;V)J96-T
M*"1V86QU92DI('L*("`@("`@("`@("`@("`@("1S=')4>7!E(#T@9V5T7V-L
M87-S*"1V86QU92D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D<W1R5'EP92`](&=E='1Y<&4H)'9A;'5E*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/F=E=$EN9&5N="@D;DQE=F5L
M*2`N("=.3U0@02!834Q?4E!#7U9A;'5E.B`G"B`@("`@("`@("`@("`@("`@
M("`N("1S=')4>7!E("X@(EQR7&XB.PH@("`@("`@('T*"B`@("`@("`@<W=I
M=&-H("@D=F%L=64M/FMI;F1/9B@I*2!["B`@("`@("`@8V%S92`G<W1R=6-T
M)SH*("`@("`@("`@("`@)')E="`]("1T:&ES+3YG96Y3=')U8W0H)'9A;'5E
M+"`D;DQE=F5L*3L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S92`G
M87)R87DG.@H@("`@("`@("`@("`D<F5T(#T@)'1H:7,M/F=E;D%R<F%Y*"1V
M86QU92P@)&Y,979E;"D["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&-A
M<V4@)W-C86QA<B<Z"B`@("`@("`@("`@("1R970@/2`D=&AI<RT^9V5N4V-A
M;&%R*"1V86QU92T^<V-A;&%R=F%L*"DL("1N3&5V96PI.PH@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)U!%05(N<&AP)SL*("`@("`@("`@("`@4$5!4CHZ<F%I<V5%<G)O
M<B@G26QL96=A;"!T>7!E("(G("X@)'9A;'5E+3YK:6YD3V8H*0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("X@)R(@:6X@6$U,7U)00U]686QU92<@
M+B`B7')<;B(L(#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!
M4E]%4E)/4E]04DE.5"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E
M=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('-C86QA<B!V
M86QU92!D=6UP"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`D=F%L=64@
M("!T:&4@<V-A;&%R(%A-3%]24$-?5F%L=64@;V)J96-T('1O(&1U;7`*("`@
M("`J($!P87)A;2!I;G0@("`@)&Y,979E;"`@=&AE(&QE=F5L(&]F(&EN9&5N
M=&%T:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($1U;7!E9"!V
M97)S:6]N(&]F('1H92!S8V%L87(@=F%L=64*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5N4V-A;&%R*"1V86QU92P@)&Y,979E;"D*("`@('L*("`@("`@("!I
M9B`H9V5T='EP92@D=F%L=64I(#T]("=O8FIE8W0G*2!["B`@("`@("`@("`@
M("1S=')#;&%S<R`]("<@)R`N(&=E=%]C;&%S<R@D=F%L=64I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1S=')#;&%S<R`]("<G.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)'1H:7,M/F=E=$EN9&5N="@D;DQE=F5L*2`N
M(&=E='1Y<&4H)'9A;'5E*2`N("1S=')#;&%S<PH@("`@("`@("`@("`@("`N
M("<@)R`N("1V86QU92`N(")<<EQN(CL*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE(&1U;7`@;V8@82!S=')U8W0*("`@("`J"B`@("`@*B!`
M<&%R86T@;V)J96-T("1V86QU92`@('1H92!S=')U8W0@6$U,7U)00U]686QU
M92!O8FIE8W0@=&\@9'5M<`H@("`@("H@0'!A<F%M(&EN="`@("`D;DQE=F5L
M("!T:&4@;&5V96P@;V8@:6YD96YT871I;VX*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@1'5M<&5D('9E<G-I;VX@;V8@=&AE('-C86QA<B!V86QU
M90H@("`@("HO"B`@("!F=6YC=&EO;B!G96Y3=')U8W0H)'9A;'5E+"`D;DQE
M=F5L*0H@("`@>PH@("`@("`@("1V86QU92T^<W1R=6-T<F5S970H*3L*("`@
M("`@("`D<W1R3W5T<'5T(#T@)'1H:7,M/F=E=$EN9&5N="@D;DQE=F5L*2`N
M("=S=')U8W0G("X@(EQR7&XB.PH@("`@("`@('=H:6QE("AL:7-T*"1K97DL
M("1K97EV86PI(#T@)'9A;'5E+3YS=')U8W1E86-H*"DI('L*("`@("`@("`@
M("`@)'-T<D]U='!U="`N/2`D=&AI<RT^9V5T26YD96YT*"1N3&5V96P@*R`Q
M*2`N("1K97D@+B`B7')<;B(["B`@("`@("`@("`@("1S=')/=71P=70@+CT@
M)'1H:7,M/F=E;F5R871E1'5M<"@D:V5Y=F%L+"`D;DQE=F5L("L@,BD["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D<W1R3W5T<'5T.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@9'5M<"!O9B!A;B!A<G)A>0H@("`@
M("H*("`@("`J($!P87)A;2!O8FIE8W0@)'9A;'5E("`@=&AE(&%R<F%Y(%A-
M3%]24$-?5F%L=64@;V)J96-T('1O(&1U;7`*("`@("`J($!P87)A;2!I;G0@
M("`@)&Y,979E;"`@=&AE(&QE=F5L(&]F(&EN9&5N=&%T:6]N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@($1U;7!E9"!V97)S:6]N(&]F('1H92!S
M8V%L87(@=F%L=64*("`@("`J+PH@("`@9G5N8W1I;VX@9V5N07)R87DH)'9A
M;'5E+"`D;DQE=F5L*0H@("`@>PH@("`@("`@("1N4VEZ92`@("`@/2`D=F%L
M=64M/F%R<F%Y<VEZ92@I.PH@("`@("`@("1S=')/=71P=70@/2`D=&AI<RT^
M9V5T26YD96YT*"1N3&5V96PI("X@)V%R<F%Y)R`N(")<<EQN(CL*("`@("`@
M("!F;W(H)&Y!(#T@,#L@)&Y!(#P@)&Y3:7IE.R`D;D$K*RD@>PH@("`@("`@
M("`@("`D<W1R3W5T<'5T("X]("1T:&ES+3YG971);F1E;G0H)&Y,979E;"`K
M(#$I("X@)&Y!("X@(EQR7&XB.PH@("`@("`@("`@("`D<W1R3W5T<'5T("X]
M("1T:&ES+3YG96YE<F%T941U;7`H)'9A;'5E+3YA<G)A>6UE;2@D;D$I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&Y,979E;"`K(#(I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'-T<D]U
M='!U=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&EN9&5N
M="!F;W(@82!S<&5C:69I8R!L979E;"!A;F0@8V%C:&5S(&ET(&9O<B!F87-T
M97(@=7-E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`D;DQE=F5L("!T:&4@
M;&5V96P*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&EN9&5N
M=&5D('-T<FEN9PH@("`@("HO"B`@("!F=6YC=&EO;B!G971);F1E;G0H)&Y,
M979E;"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YA<DEN9&5N
M=%LD;DQE=F5L72DI('L*("`@("`@("`@("`@)'1H:7,M/F%R26YD96YT6R1N
M3&5V96Q=(#T@<W1R7W)E<&5A="@D=&AI<RT^<W1R0F%S94EN9&5N="P@)&Y,
M979E;"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^87));F1E
M;G1;)&Y,979E;%T["B`@("!]"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*
M("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J(&,M:&%N
M9VEN9RUC;VUM96YT+65N9&5R+7`Z(&YI;`H@*B!%;F0Z"B`J+PH*/SX*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O6$U,+U)00R]397)V97(N
M<&AP````````````````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-3(S-#<`
M,3`U,34T,S,W,S8`,#(Q-C8T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@HO*B!V:6TZ('-E="!E>'!A;F1T86(@
M=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ
M"B`J(%-E<G9E<B!C;VUM86YD<R!F;W(@;W5R(%!(4"!I;7!L96UE;G1A=&EO
M;B!O9B!T:&4@6$U,+5)00R!P<F]T;V-O;`H@*@H@*B!4:&ES(&ES(&$@4$5!
M4BUI9FEE9"!V97)S:6]N(&]F(%5S969U;"!I;F,G<R!834PM4E!#(&9O<B!0
M2%`N"B`J($ET(&AA<R!S=7!P;W)T(&9O<B!(5%10('1R86YS<&]R="P@<')O
M>&EE<R!A;F0@875T:&5N=&EC871I;VXN"B`J"B`J(%!(4"!V97)S:6]N<R`T
M(&%N9"`U"B`J"B`J($Q)0T5.4T4Z($QI8V5N<V4@:7,@9W)A;G1E9"!T;R!U
M<V4@;W(@;6]D:69Y('1H:7,@<V]F='=A<F4*("H@*")834PM4E!#(&9O<B!0
M2%`B*2!F;W(@8V]M;65R8VEA;"!O<B!N;VXM8V]M;65R8VEA;"!U<V4@<')O
M=FED960@=&AE"B`J(&-O<'ER:6=H="!O9B!T:&4@875T:&]R(&ES('!R97-E
M<G9E9"!I;B!A;GD@9&ES=')I8G5T960@;W(@9&5R:79A=&EV92!W;W)K+@H@
M*@H@*B!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!!551(3U(@
M(D%3($E3(B!!3D0@04Y9($584%)%4U-%1"!/4@H@*B!)35!,245$(%=!4E)!
M3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$(%1/+"!42$4@24U0
M3$E%1"!705)204Y42453"B`J($]&($U%4D-(04Y404))3$E462!!3D0@1DE4
M3D534R!&3U(@02!005)424-53$%2(%!54E!/4T4@05)%($1)4T-,04E-140N
M"B`J($E.($Y/($5614Y4(%-(04Q,(%1(12!!551(3U(@0D4@3$E!0DQ%($9/
M4B!!3ED@1$E214-4+"!)3D1)4D5#5"P*("H@24Y#241%3E1!3"P@4U!%0TE!
M3"P@15A%35!,05)9+"!/4B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ5
M1$E.1RP@0E54"B`J($Y/5"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!3
M54)35$E4551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P*("H@
M1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)255!424].*2!(
M3U=%5D52($-!55-%1"!!3D0@3TX@04Y9"B`J(%1(14]262!/1B!,24%"24Q)
M5%DL(%=(151(15(@24X@0T].5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL($]2
M(%1/4E0*("H@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D@
M05))4TE.1R!)3B!!3ED@5T%9($]55"!/1B!42$4@55-%($]&"B`J(%1(25,@
M4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!42$4@4$]34TE"24Q)5%D@
M3T8@4U5#2"!$04U!1T4N"B`J"B`J($!C871E9V]R>2`@(%=E8B!397)V:6-E
M<PH@*B!`<&%C:V%G92`@("!834Q?4E!#"B`J($!A=71H;W(@("`@($5D9"!$
M=6UB:6QL(#QE9&1`=7-E9G5L:6YC+F-O;3X*("H@0&%U=&AO<B`@("`@4W1I
M9R!"86MK96X@/'-T:6=`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@36%R=&EN
M($IA;G-E;B`\;6I`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O
M;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DY
M+3(P,#$@161D($1U;6)I;&PL(#(P,#$M,C`P-2!4:&4@4$A0($=R;W5P"B`J
M($!V97)S:6]N("`@($-64SH@)$ED.B!397)V97(N<&AP+'8@,2XS,R`R,#`V
M+S`Q+S$T(#(R.C,P.C,Q(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@
M:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+UA-3%]24$,*("HO"@H*+RHJ
M"B`J(%!U;&P@:6X@=&AE(%A-3%]24$,@8VQA<W,*("HO"G)E<75I<F5?;VYC
M92`G6$U,+U)00RYP:'`G.PH*"B\J*@H@*B!S:6=N871U<F4@9F]R('-Y<W1E
M;2YL:7-T365T:&]D<SH@<F5T=7)N(#T@87)R87DL"B`J('!A<F%M971E<G,@
M/2!A('-T<FEN9R!O<B!N;W1H:6YG"B`J($!G;&]B86P@87)R87D@)$=,3T)!
M3%-;)UA-3%]24$-?4V5R=F5R7VQI<W1-971H;V1S7W-I9R=="B`J+PHD1TQ/
M0D%,4ULG6$U,7U)00U]397)V97)?;&ES=$UE=&AO9'-?<VEG)UT@/2!A<G)A
M>2@*("`@(&%R<F%Y*"1'3$]"04Q36R=834Q?4E!#7T%R<F%Y)UTL"B`@("`@
M("`@("`D1TQ/0D%,4ULG6$U,7U)00U]3=')I;F<G70H@("`@*2P*("`@(&%R
M<F%Y*"1'3$]"04Q36R=834Q?4E!#7T%R<F%Y)UTI"BD["@HO*BH*("H@9&]C
M<W1R:6YG(&9O<B!S>7-T96TN;&ES=$UE=&AO9',*("H@0&=L;V)A;"!S=')I
M;F<@)$=,3T)!3%-;)UA-3%]24$-?4V5R=F5R7VQI<W1-971H;V1S7V1O8R==
M"B`J+PHD1TQ/0D%,4ULG6$U,7U)00U]397)V97)?;&ES=$UE=&AO9'-?9&]C
M)UT@/2`G5&AI<R!M971H;V0@;&ES=',@86QL('1H92<*("`@("`@("`N("<@
M;65T:&]D<R!T:&%T('1H92!834PM4E!#('-E<G9E<B!K;F]W<R!H;W<@=&\@
M9&ES<&%T8V@G.PH*+RHJ"B`J('-I9VYA='5R92!F;W(@<WES=&5M+FUE=&AO
M9%-I9VYA='5R93H@<F5T=7)N(#T@87)R87DL"B`J('!A<F%M971E<G,@/2!S
M=')I;F<*("H@0&=L;V)A;"!A<G)A>2`D1TQ/0D%,4ULG6$U,7U)00U]397)V
M97)?;65T:&]D4VEG;F%T=7)E7W-I9R=="B`J+PHD1TQ/0D%,4ULG6$U,7U)0
M0U]397)V97)?;65T:&]D4VEG;F%T=7)E7W-I9R==(#T@87)R87DH"B`@("!A
M<G)A>2@D1TQ/0D%,4ULG6$U,7U)00U]!<G)A>2==+`H@("`@("`@("`@)$=,
M3T)!3%-;)UA-3%]24$-?4W1R:6YG)UT*("`@("D**3L*"B\J*@H@*B!D;V-S
M=')I;F<@9F]R('-Y<W1E;2YM971H;V13:6=N871U<F4*("H@0&=L;V)A;"!S
M=')I;F<@)$=,3T)!3%-;)UA-3%]24$-?4V5R=F5R7VUE=&AO9%-I9VYA='5R
M95]D;V,G70H@*B\*)$=,3T)!3%-;)UA-3%]24$-?4V5R=F5R7VUE=&AO9%-I
M9VYA='5R95]D;V,G72`]("=2971U<FYS(&%N(&%R<F%Y(&]F(&MN;W=N)PH@
M("`@("`@("X@)R!S:6=N871U<F5S("AA;B!A<G)A>2!O9B!A<G)A>7,I(&9O
M<B!T:&4@;65T:&]D(&YA;64@<&%S<V5D+B!)9B<*("`@("`@("`N("<@;F\@
M<VEG;F%T=7)E<R!A<F4@:VYO=VXL(')E='5R;G,@82!N;VYE+6%R<F%Y("AT
M97-T(&9O<B!T>7!E("$])PH@("`@("`@("X@)R!A<G)A>2!T;R!D971E8W0@
M;6ES<VEN9R!S:6=N871U<F4I)SL*"B\J*@H@*B!S:6=N871U<F4@9F]R('-Y
M<W1E;2YM971H;V1(96QP.B!R971U<FX@/2!S=')I;F<L"B`J('!A<F%M971E
M<G,@/2!S=')I;F<*("H@0&=L;V)A;"!A<G)A>2`D1TQ/0D%,4ULG6$U,7U)0
M0U]397)V97)?;65T:&]D2&5L<%]S:6<G70H@*B\*)$=,3T)!3%-;)UA-3%]2
M4$-?4V5R=F5R7VUE=&AO9$AE;'!?<VEG)UT@/2!A<G)A>2@*("`@(&%R<F%Y
M*"1'3$]"04Q36R=834Q?4E!#7U-T<FEN9R==+`H@("`@("`@("`@)$=,3T)!
M3%-;)UA-3%]24$-?4W1R:6YG)UT*("`@("D**3L*"B\J*@H@*B!D;V-S=')I
M;F<@9F]R(&UE=&AO9$AE;'`*("H@0&=L;V)A;"!S=')I;F<@)$=,3T)!3%-;
M)UA-3%]24$-?4V5R=F5R7VUE=&AO9$AE;'!?9&]C)UT*("HO"B1'3$]"04Q3
M6R=834Q?4E!#7U-E<G9E<E]M971H;V1(96QP7V1O8R==(#T@)U)E='5R;G,@
M:&5L<"!T97AT(&EF(&1E9FEN960G"B`@("`@("`@+B`G(&9O<B!T:&4@;65T
M:&]D('!A<W-E9"P@;W1H97)W:7-E(')E='5R;G,@86X@96UP='D@<W1R:6YG
M)SL*"B\J*@H@*B!D:7-P871C:"!M87`@9F]R('1H92!A=71O;6%T:6-A;&QY
M(&1E8VQA<F5D(%A-3"U24$,@;65T:&]D<RX*("H@0&=L;V)A;"!A<G)A>2`D
M1TQ/0D%,4ULG6$U,7U)00U]397)V97)?9&UA<"=="B`J+PHD1TQ/0D%,4ULG
M6$U,7U)00U]397)V97)?9&UA<"==(#T@87)R87DH"B`@("`G<WES=&5M+FQI
M<W1-971H;V1S)R`]/B!A<G)A>2@*("`@("`@("`G9G5N8W1I;VXG("`]/B`G
M6$U,7U)00U]397)V97)?;&ES=$UE=&AO9',G+`H@("`@("`@("=S:6=N871U
M<F4G(#T^("1'3$]"04Q36R=834Q?4E!#7U-E<G9E<E]L:7-T365T:&]D<U]S
M:6<G72P*("`@("`@("`G9&]C<W1R:6YG)R`]/B`D1TQ/0D%,4ULG6$U,7U)0
M0U]397)V97)?;&ES=$UE=&AO9'-?9&]C)UT*("`@("DL"B`@("`G<WES=&5M
M+FUE=&AO9$AE;'`G(#T^(&%R<F%Y*`H@("`@("`@("=F=6YC=&EO;B<@(#T^
M("=834Q?4E!#7U-E<G9E<E]M971H;V1(96QP)RP*("`@("`@("`G<VEG;F%T
M=7)E)R`]/B`D1TQ/0D%,4ULG6$U,7U)00U]397)V97)?;65T:&]D2&5L<%]S
M:6<G72P*("`@("`@("`G9&]C<W1R:6YG)R`]/B`D1TQ/0D%,4ULG6$U,7U)0
M0U]397)V97)?;65T:&]D2&5L<%]D;V,G70H@("`@*2P*("`@("=S>7-T96TN
M;65T:&]D4VEG;F%T=7)E)R`]/B!A<G)A>2@*("`@("`@("`G9G5N8W1I;VXG
M("`]/B`G6$U,7U)00U]397)V97)?;65T:&]D4VEG;F%T=7)E)RP*("`@("`@
M("`G<VEG;F%T=7)E)R`]/B`D1TQ/0D%,4ULG6$U,7U)00U]397)V97)?;65T
M:&]D4VEG;F%T=7)E7W-I9R==+`H@("`@("`@("=D;V-S=')I;F<G(#T^("1'
M3$]"04Q36R=834Q?4E!#7U-E<G9E<E]M971H;V13:6=N871U<F5?9&]C)UT*
M("`@("D**3L*"B\J*@H@*B!`9VQO8F%L('-T<FEN9R`D1TQ/0D%,4ULG6$U,
M7U)00U]397)V97)?9&5B=6=I;F9O)UT*("HO"B1'3$]"04Q36R=834Q?4E!#
M7U-E<G9E<E]D96)U9VEN9F\G72`]("<G.PH*"B\J*@H@*B!,:7-T<R!A;&P@
M=&AE(&UE=&AO9',@=&AA="!T:&4@6$U,+5)00R!S97)V97(@:VYO=W,@:&]W
M('1O(&1I<W!A=&-H"B`J"B`J($!R971U<FX@;V)J96-T("!A(&YE=R!834Q?
M4E!#7U)E<W!O;G-E(&]B:F5C=`H@*B\*9G5N8W1I;VX@6$U,7U)00U]397)V
M97)?;&ES=$UE=&AO9',H)'-E<G9E<BP@)&TI"GL*("`@(&=L;V)A;"`D6$U,
M7U)00U]E<G(L("1834Q?4E!#7W-T<BP@)%A-3%]24$-?4V5R=F5R7V1M87`[
M"@H@("`@)'8@/2!N97<@6$U,7U)00U]686QU92@I.PH@("`@)&]U=$%R(#T@
M87)R87DH*3L*("`@(&9O<F5A8V@@*"1S97)V97(M/F1M87`@87,@)&ME>2`]
M/B`D=F%L*2!["B`@("`@("`@)&]U=$%R6UT@/2!N97<@6$U,7U)00U]686QU
M92@D:V5Y+"`G<W1R:6YG)RD["B`@("!]"B`@("!F;W)E86-H("@D6$U,7U)0
M0U]397)V97)?9&UA<"!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`D;W5T
M07);72`](&YE=R!834Q?4E!#7U9A;'5E*"1K97DL("=S=')I;F<G*3L*("`@
M('T*("`@("1V+3YA9&1!<G)A>2@D;W5T07(I.PH@("`@<F5T=7)N(&YE=R!8
M34Q?4E!#7U)E<W!O;G-E*"1V*3L*?0H*+RHJ"B`J(%)E='5R;G,@86X@87)R
M87D@;V8@:VYO=VX@<VEG;F%T=7)E<R`H86X@87)R87D@;V8@87)R87ES*0H@
M*B!F;W(@=&AE(&=I=F5N(&UE=&AO9`H@*@H@*B!)9B!N;R!S:6=N871U<F5S
M(&%R92!K;F]W;BP@<F5T=7)N<R!A(&YO;F4M87)R87D*("H@*'1E<W0@9F]R
M('1Y<&4@(3T@87)R87D@=&\@9&5T96-T(&UI<W-I;F<@<VEG;F%T=7)E*0H@
M*@H@*B!`<F5T=7)N(&]B:F5C="`@82!N97<@6$U,7U)00U]297-P;VYS92!O
M8FIE8W0*("HO"F9U;F-T:6]N(%A-3%]24$-?4V5R=F5R7VUE=&AO9%-I9VYA
M='5R92@D<V5R=F5R+"`D;2D*>PH@("`@9VQO8F%L("1834Q?4E!#7V5R<BP@
M)%A-3%]24$-?<W1R+"`D6$U,7U)00U]397)V97)?9&UA<#L*"B`@("`D;65T
M:$YA;64@/2`D;2T^9V5T4&%R86TH,"D["B`@("`D;65T:$YA;64@/2`D;65T
M:$YA;64M/G-C86QA<G9A;"@I.PH@("`@:68@*'-T<G!O<R@D;65T:$YA;64L
M("=S>7-T96TN)RD@/3T](#`I('L*("`@("`@("`D9&UA<"`]("1834Q?4E!#
M7U-E<G9E<E]D;6%P.PH@("`@("`@("1S>7-#86QL(#T@,3L*("`@('T@96QS
M92!["B`@("`@("`@)&1M87`@/2`D<V5R=F5R+3YD;6%P.PH@("`@("`@("1S
M>7-#86QL(#T@,#L*("`@('T*("`@("\O("!P<FEN="`B/"$M+2`D>VUE=&A.
M86UE?2`M+3Y<;B(["B`@("!I9B`H:7-S970H)&1M87!;)&UE=&A.86UE72DI
M('L*("`@("`@("!I9B`H)&1M87!;)&UE=&A.86UE75LG<VEG;F%T=7)E)UTI
M('L*("`@("`@("`@("`@)'-I9W,@/2!A<G)A>2@I.PH@("`@("`@("`@("`D
M=&AE<VEG<R`]("1D;6%P6R1M971H3F%M95U;)W-I9VYA='5R92==.PH@("`@
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'1H97-I9W,I.R`D
M:2LK*2!["B`@("`@("`@("`@("`@("`D8W5R<VEG(#T@87)R87DH*3L*("`@
M("`@("`@("`@("`@("1I;E-I9R`]("1T:&5S:6=S6R1I73L*("`@("`@("`@
M("`@("`@(&9O<B`H)&H@/2`P.R`D:B`\('-I>F5O9B@D:6Y3:6<I.R`D:BLK
M*2!["B`@("`@("`@("`@("`@("`@("`@)&-U<G-I9UM=(#T@;F5W(%A-3%]2
M4$-?5F%L=64H)&EN4VEG6R1J72P@)W-T<FEN9R<I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)'-I9W-;72`](&YE=R!834Q?4E!#7U9A
M;'5E*"1C=7)S:6<L("=A<G)A>2<I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1R(#T@;F5W(%A-3%]24$-?4F5S<&]N<V4H;F5W(%A-3%]24$-?5F%L
M=64H)'-I9W,L("=A<G)A>2<I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D<B`](&YE=R!834Q?4E!#7U)E<W!O;G-E*&YE=R!834Q?4E!#7U9A
M;'5E*"=U;F1E9B<L("=S=')I;F<G*2D["B`@("`@("`@?0H@("`@?2!E;'-E
M('L*("`@("`@("`D<B`](&YE=R!834Q?4E!#7U)E<W!O;G-E*#`L("1834Q?
M4E!#7V5R<ELG:6YT<F]S<&5C=%]U;FMN;W=N)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D6$U,7U)00U]S=');)VEN=')O<W!E8W1?
M=6YK;F]W;B==*3L*("`@('T*("`@(')E='5R;B`D<CL*?0H*+RHJ"B`J(%)E
M='5R;G,@:&5L<"!T97AT(&EF(&1E9FEN960@9F]R('1H92!M971H;V0@<&%S
M<V5D+"!O=&AE<G=I<V4@<F5T=7)N<PH@*B!A;B!E;7!T>2!S=')I;F<*("H*
M("H@0')E='5R;B!O8FIE8W0@(&$@;F5W(%A-3%]24$-?4F5S<&]N<V4@;V)J
M96-T"B`J+PIF=6YC=&EO;B!834Q?4E!#7U-E<G9E<E]M971H;V1(96QP*"1S
M97)V97(L("1M*0I["B`@("!G;&]B86P@)%A-3%]24$-?97)R+"`D6$U,7U)0
M0U]S='(L("1834Q?4E!#7U-E<G9E<E]D;6%P.PH*("`@("1M971H3F%M92`]
M("1M+3YG971087)A;2@P*3L*("`@("1M971H3F%M92`]("1M971H3F%M92T^
M<V-A;&%R=F%L*"D["B`@("!I9B`H<W1R<&]S*"1M971H3F%M92P@)W-Y<W1E
M;2XG*2`]/3T@,"D@>PH@("`@("`@("1D;6%P(#T@)%A-3%]24$-?4V5R=F5R
M7V1M87`["B`@("`@("`@)'-Y<T-A;&P@/2`Q.PH@("`@?2!E;'-E('L*("`@
M("`@("`D9&UA<"`]("1S97)V97(M/F1M87`["B`@("`@("`@)'-Y<T-A;&P@
M/2`P.PH@("`@?0H*("`@(&EF("AI<W-E="@D9&UA<%LD;65T:$YA;65=*2D@
M>PH@("`@("`@(&EF("@D9&UA<%LD;65T:$YA;65=6R=D;V-S=')I;F<G72D@
M>PH@("`@("`@("`@("`D<B`](&YE=R!834Q?4E!#7U)E<W!O;G-E*&YE=R!8
M34Q?4E!#7U9A;'5E*"1D;6%P6R1M971H3F%M95U;)V1O8W-T<FEN9R==*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<W1R:6YG)RD["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'(@/2!N97<@6$U,7U)00U]297-P;VYS92AN97<@6$U,7U)00U]6
M86QU92@G)RP@)W-T<FEN9R<I*3L*("`@("`@("!]"B`@("!](&5L<V4@>PH@
M("`@("`@("1R(#T@;F5W(%A-3%]24$-?4F5S<&]N<V4H,"P@)%A-3%]24$-?
M97)R6R=I;G1R;W-P96-T7W5N:VYO=VXG72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1834Q?4E!#7W-T<ELG:6YT<F]S<&5C=%]U
M;FMN;W=N)UTI.PH@("`@?0H@("`@<F5T=7)N("1R.PI]"@HO*BH*("H@0')E
M='5R;B!V;VED"B`J+PIF=6YC=&EO;B!834Q?4E!#7U-E<G9E<E]D96)U9VUS
M9R@D;2D*>PH@("`@9VQO8F%L("1834Q?4E!#7U-E<G9E<E]D96)U9VEN9F\[
M"B`@("`D6$U,7U)00U]397)V97)?9&5B=6=I;F9O(#T@)%A-3%]24$-?4V5R
M=F5R7V1E8G5G:6YF;R`N("1M("X@(EQN(CL*?0H*"B\J*@H@*B!!('-E<G9E
M<B!F;W(@<F5C96EV:6YG(&%N9"!R97!L>6EN9R!T;R!834P@4E!#(')E<75E
M<W1S"B`J"B`J(#QC;V1E/@H@*B`D<V5R=F5R(#T@;F5W(%A-3%]24$-?4V5R
M=F5R*`H@*B`@("`@87)R87DH"B`J("`@("`@("`@)VES86XX)R`]/@H@*B`@
M("`@("`@("`@("!A<G)A>2@*("H@("`@("`@("`@("`@("`@("=F=6YC=&EO
M;B<@/3X@)VES7S@G+`H@*B`@("`@("`@("`@("`@("`@)W-I9VYA='5R92<@
M/3X*("H@("`@("`@("`@("`@("`@("`@("`@87)R87DH"B`J("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@G8F]O;&5A;B<L("=I;G0G*2P*("H@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=B;V]L96%N)RP@)VEN
M="<L("=B;V]L96%N)RDL"B`J("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G8F]O;&5A;B<L("=S=')I;F<G*2P*("H@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*"=B;V]L96%N)RP@)W-T<FEN9R<L("=B;V]L96%N
M)RDL"B`J("`@("`@("`@("`@("`@("`@("`@("DL"B`J("`@("`@("`@("`@
M("`@("`G9&]C<W1R:6YG)R`]/B`G27,@=&AE('9A;'5E(&%N(#@_)PH@*B`@
M("`@("`@("`@("`I+`H@*B`@("`@*2P*("H@("`@(#$L"B`J("`@("`P"B`J
M("D[(`H@*B`\+V-O9&4^"B`J"B`J($!C871E9V]R>2`@(%=E8B!397)V:6-E
M<PH@*B!`<&%C:V%G92`@("!834Q?4E!#"B`J($!A=71H;W(@("`@($5D9"!$
M=6UB:6QL(#QE9&1`=7-E9G5L:6YC+F-O;3X*("H@0&%U=&AO<B`@("`@4W1I
M9R!"86MK96X@/'-T:6=`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@36%R=&EN
M($IA;G-E;B`\;6I`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O
M;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DY
M+3(P,#$@161D($1U;6)I;&PL(#(P,#$M,C`P-2!4:&4@4$A0($=R;W5P"B`J
M($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XX"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]834Q?4E!#"B`J+PIC;&%S<R!8
M34Q?4E!#7U-E<G9E<@I["B`@("`O*BH*("`@("`J(%1H92!D:7-P871C:"!M
M87`L(&QI<W1I;F<@=&AE(&UE=&AO9',@=&AI<R!S97)V97(@<')O=FED97,N
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D9&UA<"`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@<')E<V5N="!R97-P;VYS92=S
M(&5N8V]D:6YG"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0'-E92!834Q?
M4E!#7TUE<W-A9V4Z.F=E=$5N8V]D:6YG*"D*("`@("`J+PH@("`@=F%R("1E
M;F-O9&EN9R`]("<G.PH*("`@("\J*@H@("`@("H@1&5B=6<@;6]D92`H,"`]
M(&]F9BP@,2`](&]N*0H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@
M('9A<B`D9&5B=6<@/2`P.PH*("`@("\J*@H@("`@("H@5&AE(')E<W!O;G-E
M)W,@2%144"!H96%D97)S"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)'-E<G9E<E]H96%D97)S(#T@)R<["@H@("`@+RHJ"B`@("`@*B!4
M:&4@<F5S<&]N<V4G<R!834P@<&%Y;&]A9`H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1S97)V97)?<&%Y;&]A9"`]("<G.PH*"B`@("`O
M*BH*("`@("`J($-O;G-T<G5C=&]R(&9O<B!T:&4@6$U,7U)00U]397)V97(@
M8VQA<W,*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&1I<W!-87`@("!T
M:&4@9&ES<&%T8V@@;6%P+B!!;B!A<W-O8VEA=&EV92!A<G)A>0H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@(&5X<&QA:6YI;F<@96%C:"!F=6YC
M=&EO;BX@5&AE(&ME>7,@;V8@=&AE(&UA:6X*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2!A<F4@=&AE('!R;V-E9'5R92!N86UE<R!U
M<V5D(&)Y('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&-L
M:65N=',N(%1H92!V86QU92!I<R!A;F]T:&5R(&%S<V]C:6%T:79E(&%R<F%Y
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=&AA="!C;VYT86EN
M<R!U<"!T;R!T:')E92!E;&5M96YT<SH*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("L@5&AE("=F=6YC=&EO;B<@96QE;65N="=S('9A;'5E
M(&ES('1H92!N86UE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&]F('1H92!F=6YC=&EO;B!O<B!M971H;V0@=&AA="!G971S(&-A;&QE
M9"X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@5&\@9&5F
M:6YE(&$@8VQA<W,G(&UE=&AO9#H@)V-L87-S.CIM971H;V0G+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*R!4:&4@)W-I9VYA='5R92<@
M96QE;65N="`H;W!T:6]N86PI(&ES(&%N"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y(&1E<V-R:6)I;F<@=&AE(')E='5R;B!V
M86QU97,@86YD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('!A<F%M971E<G,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("L@5&AE("=D;V-S=')I;F<G(&5L96UE;G0@*&]P=&EO;F%L*2!I<R!A"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T<FEN9R!D97-C
M<FEB:6YG('=H870@=&AE(&UE=&AO9"!D;V5S"B`@("`@*B!`<&%R86T@:6YT
M("1S97)V:6-E3F]W("!S:&]U;&0@=&AE($A45%`@<F5S<&]N<V4@8F4@<V5N
M="!N;W<_"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@*#$@/2!Y
M97,L(#`@/2!N;RD*("`@("`J($!P87)A;2!I;G0@)&1E8G5G("`@("`@('-H
M;W5L9"!D96)U9R!O=71P=70@8F4@9&ES<&QA>65D/PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("@Q(#T@>65S+"`P(#T@;F\I"B`@("`@*@H@
M("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(%A-3%]2
M4$-?4V5R=F5R*"1D:7-P36%P+"`D<V5R=FEC94YO=R`](#$L("1D96)U9R`]
M(#`I"B`@("!["B`@("`@("`@9VQO8F%L("1(5%107U)!5U]03U-47T1!5$$[
M"@H@("`@("`@(&EF("@D9&5B=6<I('L*("`@("`@("`@("`@)'1H:7,M/F1E
M8G5G(#T@,3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^
M9&5B=6<@/2`P.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/F1M87`@/2`D
M9&ES<$UA<#L*"B`@("`@("`@:68@*"1S97)V:6-E3F]W*2!["B`@("`@("`@
M("`@("1T:&ES+3YS97)V:6-E*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'1H:7,M/F-R96%T95-E<G9E<E!A>6QO860H*3L*("`@("`@("`@
M("`@)'1H:7,M/F-R96%T95-E<G9E<DAE861E<G,H*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&1E8G5G
M(&EN9F]R;6%T:6]N(&EF(&1E8G5G(&1E8G5G(&UO9&4@:7,@;VX*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5R:6%L:7IE1&5B=6<H*0H@("`@>PH@("`@("`@
M(&=L;V)A;"`D6$U,7U)00U]397)V97)?9&5B=6=I;F9O+"`D2%144%]205=?
M4$]35%]$051!.PH*("`@("`@("!I9B`H)'1H:7,M/F1E8G5G*2!["B`@("`@
M("`@("`@(%A-3%]24$-?4V5R=F5R7V1E8G5G;7-G*"=V=G8@4$]35"!$051!
M(%)%0T5)5D5$($)9(%-%4E9%4B!V=G8G("X@(EQN(@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`N("1(5%107U)!5U]03U-47T1!5$$*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`B7&XB("X@
M)UY>7B!%3D0@4$]35"!$051!(%Y>7B<I.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"1834Q?4E!#7U-E<G9E<E]D96)U9VEN9F\@(3T@)R<I('L*("`@("`@
M("`@("`@<F5T=7)N("(\(2TM(%!%05(@6$U,7U)00R!315)615(@1$5"54<@
M24Y&3SI<;EQN(@H@("`@("`@("`@("`@("`@("`@+B!P<F5G7W)E<&QA8V4H
M)R\M*#\]+2DO)RP@)RT@)RP@)%A-3%]24$-?4V5R=F5R7V1E8G5G:6YF;RD*
M("`@("`@("`@("`@("`@("`@("X@(BTM/EQN(CL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@4V5N9',@=&AE(')E<W!O;G-E"B`@("`@*@H@("`@("H@
M5&AE(&5N8V]D:6YG(&%N9"!C;VYT96YT+71Y<&4@87)E(&1E=&5R;6EN960@
M8GD*("`@("`J(%A-3%]24$-?365S<V%G93HZ9V5T16YC;V1I;F<H*0H@("`@
M("H*("`@("`J($!R971U<FX@=F]I9`H@("`@("H*("`@("`J($!U<V5S(%A-
M3%]24$-?4V5R=F5R.CIC<F5A=&5397)V97)087EL;V%D*"DL"B`@("`@*B`@
M("`@("!834Q?4E!#7U-E<G9E<CHZ8W)E871E4V5R=F5R2&5A9&5R<R@I"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E<G9I8V4H*0H@("`@>PH@("`@("`@(&EF
M("@A)'1H:7,M/G-E<G9E<E]P87EL;V%D*2!["B`@("`@("`@("`@("1T:&ES
M+3YC<F5A=&5397)V97)087EL;V%D*"D["B`@("`@("`@?0H@("`@("`@(&EF
M("@A)'1H:7,M/G-E<G9E<E]H96%D97)S*2!["B`@("`@("`@("`@("1T:&ES
M+3YC<F5A=&5397)V97)(96%D97)S*"D["B`@("`@("`@?0H*("`@("`@("`O
M*@H@("`@("`@("`J("1S97)V97)?:&5A9&5R<R!N965D<R!T;R!R96UA:6X@
M82!S=')I;F<@9F]R(&-O;7!A=&EB:6QI='D@=VET:`H@("`@("`@("`J(&]L
M9"!S8W)I<'1S('5S:6YG('1H:7,@<&%C:V%G92P@8G5T(%!(4"`T+C0N,B!N
M;R!L;VYG97(@86QL;W=S"B`@("`@("`@("H@;&EN92!B<F5A:W,@:6X@:&5A
M9&5R*"D@8V%L;',N("!3;RP@=V4@<W!L:70@96%C:"!H96%D97(@:6YT;PH@
M("`@("`@("`J(&%N(&EN9&EV:61U86P@8V%L;"X@(%1H92!I;FET:6%L(')E
M<&QA8V4@:&%N9&QE<R!T:&4@;V9F(&-H86YC90H@("`@("`@("`J('1H870@
M<V]M96]N92!C;VUP;W-E9"!A('-I;F=L92!H96%D97(@=VET:"!M=6QT:7!L
M92!L:6YE<RP@=VAI8V@*("`@("`@("`@*B!T:&4@4D9#<R!A;&QO=RX*("`@
M("`@("`@*B\*("`@("`@("`D=&AI<RT^<V5R=F5R7VAE861E<G,@/2!P<F5G
M7W)E<&QA8V4H(B];7')<;ETK6R!<=%TK+R(L("<@)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=')I;2@D=&AI<RT^
M<V5R=F5R7VAE861E<G,I*3L*("`@("`@("`D:&5A9&5R<R`]('!R96=?<W!L
M:70H(B];7')<;ETK+R(L("1T:&ES+3YS97)V97)?:&5A9&5R<RD["B`@("`@
M("`@9F]R96%C:"`H)&AE861E<G,@87,@)&AE861E<BD*("`@("`@("!["B`@
M("`@("`@("`@(&AE861E<B@D:&5A9&5R*3L*("`@("`@("!]"@H@("`@("`@
M('!R:6YT("1T:&ES+3YS97)V97)?<&%Y;&]A9#L*("`@('T*"B`@("`O*BH*
M("`@("`J($=E;F5R871E<R!T:&4@<&%Y;&]A9"!A;F0@<'5T<R!I="!I;B!T
M:&4@)'-E<G9E<E]P87EL;V%D('!R;W!E<G1Y"B`@("`@*@H@("`@("H@0')E
M='5R;B!V;VED"B`@("`@*@H@("`@("H@0'5S97,@6$U,7U)00U]397)V97(Z
M.G!A<G-E4F5Q=65S="@I+"!834Q?4E!#7U-E<G9E<CHZ)&5N8V]D:6YG+`H@
M("`@("H@("`@("`@6$U,7U)00U]297-P;VYS93HZ<V5R:6%L:7IE*"DL(%A-
M3%]24$-?4V5R=F5R.CIS97)I86QI>F5$96)U9R@I"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&-R96%T95-E<G9E<E!A>6QO860H*0H@("`@>PH@("`@("`@("1R
M(#T@)'1H:7,M/G!A<G-E4F5Q=65S="@I.PH@("`@("`@("1T:&ES+3YS97)V
M97)?<&%Y;&]A9"`]("<\/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2(G
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)'1H:7,M/F5N8V]D
M:6YG("X@)R(_/B<@+B`B7&XB"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("X@)'1H:7,M/G-E<FEA;&EZ941E8G5G*"D*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+B`D<BT^<V5R:6%L:7IE*"D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$971E<FUI;F5S('1H92!(5%10(&AE861E<G,@86YD('!U
M=',@=&AE;2!I;B!T:&4@)'-E<G9E<E]H96%D97)S"B`@("`@*B!P<F]P97)T
M>0H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5%)512!I9B!O:V%Y
M+"!&04Q312!I9B`D<V5R=F5R7W!A>6QO860@:7-N)W0@<V5T+@H@("`@("H*
M("`@("`J($!U<V5S(%A-3%]24$-?4V5R=F5R.CIC<F5A=&5397)V97)087EL
M;V%D*"DL"B`@("`@*B`@("`@("!834Q?4E!#7U-E<G9E<CHZ)'-E<G9E<E]H
M96%D97)S"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T95-E<G9E<DAE861E
M<G,H*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/G-E<G9E<E]P87EL;V%D
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@
M("`@)'1H:7,M/G-E<G9E<E]H96%D97)S(#T@)T-O;G1E;G0M3&5N9W1H.B`G
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@<W1R;&5N*"1T:&ES
M+3YS97)V97)?<&%Y;&]A9"D@+B`B7')<;B(*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+B`G0V]N=&5N="U4>7!E.B!T97AT+WAM;#LG"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("X@)R!C:&%R<V5T/2<@+B`D=&AI
M<RT^96YC;V1I;F<["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!`<F5T=7)N(&%R<F%Y"B`@("`@*B\*("`@(&9U;F-T:6]N
M('9E<FEF>5-I9VYA='5R92@D:6XL("1S:6<I"B`@("!["B`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@<VEZ96]F*"1S:6<I.R`D:2LK*2!["B`@("`@("`@
M("`@("\O(&-H96-K(&5A8V@@<&]S<VEB;&4@<VEG;F%T=7)E(&EN('1U<FX*
M("`@("`@("`@("`@)&-U<G-I9R`]("1S:6=;)&E=.PH@("`@("`@("`@("!I
M9B`H<VEZ96]F*"1C=7)S:6<I(#T]("1I;BT^9V5T3G5M4&%R86US*"D@*R`Q
M*2!["B`@("`@("`@("`@("`@("`D:71S3TL@/2`Q.PH@("`@("`@("`@("`@
M("`@9F]R("@D;B`](#`[("1N(#P@)&EN+3YG971.=6U087)A;7,H*3L@)&XK
M*RD@>PH@("`@("`@("`@("`@("`@("`@("1P(#T@)&EN+3YG971087)A;2@D
M;BD["B`@("`@("`@("`@("`@("`@("`@+R\@<')I;G0@(CPA+2T@)'`@+2T^
M7&XB.PH@("`@("`@("`@("`@("`@("`@(&EF("@D<"T^:VEN9$]F*"D@/3T@
M)W-C86QA<B<I('L*("`@("`@("`@("`@("`@("`@("`@("`@)'!T(#T@)'`M
M/G-C86QA<G1Y<"@I.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1P="`]("1P+3YK:6YD3V8H*3L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@+R\@)&XK
M,2!A<R!F:7)S="!T>7!E(&]F('-I9R!I<R!R971U<FX@='EP90H@("`@("`@
M("`@("`@("`@("`@(&EF("@D<'0@(3T@)&-U<G-I9ULD;BLQ72D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D:71S3TL@/2`P.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D<&YO(#T@)&XK,3L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'=A;G1E9"`]("1C=7)S:6=;)&XK,5T["B`@("`@("`@("`@("`@("`@
M("`@("`@("1G;W0@/2`D<'0["B`@("`@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&EF("@D:71S3TLI('L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@87)R87DH,2D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1W86YT960I
M*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@P+"`B5V%N=&5D("1[=V%N
M=&5D?2P@9V]T("1[9V]T?2!A="!P87)A;2`D>W!N;WTB*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D86QL;W=E9"`](&%R<F%Y*"D["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1S:6<@87,@)'9A;"D@>PH@("`@("`@("`@("`@
M("`@96YD*"1V86PI.PH@("`@("`@("`@("`@("`@)&%L;&]W961;72`](&ME
M>2@D=F%L*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D86QL;W=E9"`]
M(&%R<F%Y7W5N:7%U92@D86QL;W=E9"D["B`@("`@("`@("`@("1L87-T(#T@
M8V]U;G0H)&%L;&]W960I("T@,3L*("`@("`@("`@("`@:68@*"1L87-T(#X@
M,"D@>PH@("`@("`@("`@("`@("`@)&%L;&]W961;)&QA<W1=(#T@)V]R("<@
M+B`D86QL;W=E9%LD;&%S=%T["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M<F5T=7)N(&%R<F%Y*#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`G4VEG
M;F%T=7)E('!E<FUI=',@)R`N(&EM<&QO9&4H)RP@)RP@)&%L;&]W960I"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G('!A<F%M971E<G,@
M8G5T('1H92!R97%U97-T(&AA9"`G"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+B`D:6XM/F=E=$YU;5!A<F%M<R@I*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@82!N97<@6$U,
M7U)00U]297-P;VYS92!O8FIE8W0*("`@("`J"B`@("`@*B!`=7-E<R!834Q?
M4E!#7TUE<W-A9V4Z.F=E=$5N8V]D:6YG*"DL(%A-3%]24$-?4V5R=F5R.CHD
M96YC;V1I;F<*("`@("`J+PH@("`@9G5N8W1I;VX@<&%R<V5297%U97-T*"1D
M871A(#T@)R<I"B`@("!["B`@("`@("`@9VQO8F%L("1834Q?4E!#7WAH+"`D
M2%144%]205=?4$]35%]$051!+`H@("`@("`@("`@("`@("`@)%A-3%]24$-?
M97)R+"`D6$U,7U)00U]S='(L("1834Q?4E!#7V5R<GAM;"P*("`@("`@("`@
M("`@("`@("1834Q?4E!#7V1E9F5N8V]D:6YG+"`D6$U,7U)00U]397)V97)?
M9&UA<#L*"B`@("`@("`@:68@*"1D871A(#T]("<G*2!["B`@("`@("`@("`@
M("1D871A(#T@)$A45%!?4D%77U!/4U1?1$%403L*("`@("`@("!]"@H@("`@
M("`@("1T:&ES+3YE;F-O9&EN9R`](%A-3%]24$-?365S<V%G93HZ9V5T16YC
M;V1I;F<H)&1A=&$I.PH@("`@("`@("1P87)S97)?<F5S;W5R8V4@/2!X;6Q?
M<&%R<V5R7V-R96%T92@D=&AI<RT^96YC;V1I;F<I.PH@("`@("`@("1P87)S
M97(@/2`H:6YT*2`D<&%R<V5R7W)E<V]U<F-E.PH*("`@("`@("`D6$U,7U)0
M0U]X:%LD<&%R<V5R72`](&%R<F%Y*"D["B`@("`@("`@)%A-3%]24$-?>&A;
M)'!A<G-E<EU;)V-M)UT@("`@(#T@,#L*("`@("`@("`D6$U,7U)00U]X:%LD
M<&%R<V5R75LG:7-F)UT@("`@/2`P.PH@("`@("`@("1834Q?4E!#7WAH6R1P
M87)S97)=6R=P87)A;7,G72`](&%R<F%Y*"D["B`@("`@("`@)%A-3%]24$-?
M>&A;)'!A<G-E<EU;)VUE=&AO9"==(#T@)R<["B`@("`@("`@)%A-3%]24$-?
M>&A;)'!A<G-E<EU;)W-T86-K)UT@/2!A<G)A>2@I.PD*("`@("`@("`D6$U,
M7U)00U]X:%LD<&%R<V5R75LG=F%L=65S=&%C:R==(#T@87)R87DH*3L)"@H@
M("`@("`@("1P;&ES="`]("<G.PH*("`@("`@("`O+R!D96-O;7!O<V4@:6YC
M;VUI;F<@6$U,(&EN=&\@<F5Q=65S="!S=')U8W1U<F4*"B`@("`@("`@>&UL
M7W!A<G-E<E]S971?;W!T:6]N*"1P87)S97)?<F5S;W5R8V4L(%A-3%]/4%1)
M3TY?0T%315]&3TQ$24Y'+"!T<G5E*3L*("`@("`@("!X;6Q?<V5T7V5L96UE
M;G1?:&%N9&QE<B@D<&%R<V5R7W)E<V]U<F-E+"`G6$U,7U)00U]S92<L("=8
M34Q?4E!#7V5E)RD["B`@("`@("`@>&UL7W-E=%]C:&%R86-T97)?9&%T85]H
M86YD;&5R*"1P87)S97)?<F5S;W5R8V4L("=834Q?4E!#7V-D)RD["B`@("`@
M("`@:68@*"%X;6Q?<&%R<V4H)'!A<G-E<E]R97-O=7)C92P@)&1A=&$L(#$I
M*2!["B`@("`@("`@("`@("\O(')E='5R;B!834P@97)R;W(@87,@82!F875L
M=$-O9&4*("`@("`@("`@("`@)'(@/2!N97<@6$U,7U)00U]297-P;VYS92@P
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1834Q?
M4E!#7V5R<GAM;"MX;6Q?9V5T7V5R<F]R7V-O9&4H)'!A<G-E<E]R97-O=7)C
M92DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W!R
M:6YT9B@G6$U,(&5R<F]R.B`E<R!A="!L:6YE("5D)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('AM;%]E<G)O<E]S
M=')I;F<H>&UL7V=E=%]E<G)O<E]C;V1E*"1P87)S97)?<F5S;W5R8V4I*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('AM;%]G971?8W5R<F5N=%]L:6YE7VYU;6)E<B@D<&%R<V5R7W)E<V]U<F-E
M*2DI.PH@("`@("`@("`@("!X;6Q?<&%R<V5R7V9R964H)'!A<G-E<E]R97-O
M=7)C92D["B`@("`@("`@?2!E;'-E:68@*"1834Q?4E!#7WAH6R1P87)S97)=
M6R=I<V8G73XQ*2!["B`@("`@("`@("`@("1R(#T@;F5W(%A-3%]24$-?4F5S
M<&]N<V4H,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D6$U,7U)00U]E<G);)VEN=F%L:61?<F5Q=65S="==+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1834Q?4E!#7W-T<ELG:6YV
M86QI9%]R97%U97-T)UT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`N("<Z("<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`N("1834Q?4E!#7WAH6R1P87)S97)=6R=I<V9?<F5A<V]N)UTI
M.PH@("`@("`@("`@("!X;6Q?<&%R<V5R7V9R964H)'!A<G-E<E]R97-O=7)C
M92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@>&UL7W!A<G-E<E]F
M<F5E*"1P87)S97)?<F5S;W5R8V4I.PH@("`@("`@("`@("`D;2`](&YE=R!8
M34Q?4E!#7TUE<W-A9V4H)%A-3%]24$-?>&A;)'!A<G-E<EU;)VUE=&AO9"==
M*3L*("`@("`@("`@("`@+R\@;F]W(&%D9"!P87)A;65T97)S(&EN"B`@("`@
M("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D6$U,7U)00U]X:%LD
M<&%R<V5R75LG<&%R86US)UTI.R`D:2LK*2!["B`@("`@("`@("`@("`@("`O
M+R!P<FEN="`G/"$M+2`G("X@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W!A<F%M
M<R==6R1I72X@(BTM/EQN(CL*("`@("`@("`@("`@("`@("1P;&ES="`N/2`B
M)&D@+2`B("X@=F%R7V5X<&]R="@D6$U,7U)00U]X:%LD<&%R<V5R75LG<&%R
M86US)UU;)&E=+"!T<G5E*2`N("(@7&XB.PH@("`@("`@("`@("`@("`@)&TM
M/F%D9%!A<F%M*"1834Q?4E!#7WAH6R1P87)S97)=6R=P87)A;7,G75LD:5TI
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)'1H:7,M/F1E8G5G
M*2!["B`@("`@("`@("`@("`@("!834Q?4E!#7U-E<G9E<E]D96)U9VUS9R@D
M<&QI<W0I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!N;W<@=&\@
M9&5A;"!W:71H('1H92!M971H;V0*("`@("`@("`@("`@)&UE=&A.86UE(#T@
M)%A-3%]24$-?>&A;)'!A<G-E<EU;)VUE=&AO9"==.PH@("`@("`@("`@("!I
M9B`H<W1R<&]S*"1M971H3F%M92P@)W-Y<W1E;2XG*2`]/3T@,"D@>PH@("`@
M("`@("`@("`@("`@)&1M87`@/2`D6$U,7U)00U]397)V97)?9&UA<#L*("`@
M("`@("`@("`@("`@("1S>7-#86QL(#T@,3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1D;6%P(#T@)'1H:7,M/F1M87`["B`@("`@
M("`@("`@("`@("`D<WES0V%L;"`](#`["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(&EF("AI<W-E="@D9&UA<%LD;65T:$YA;65=6R=F=6YC=&EO;B==
M*0H@("`@("`@("`@("`@("`@)B8@:7-?<W1R:6YG*"1D;6%P6R1M971H3F%M
M95U;)V9U;F-T:6]N)UTI"B`@("`@("`@("`@("`@("`F)B!S=')P;W,H)&1M
M87!;)&UE=&A.86UE75LG9G5N8W1I;VXG72P@)SHZ)RD@(3T](&9A;'-E*0H@
M("`@("`@("`@("!["B`@("`@("`@("`@("`@("`D9&UA<%LD;65T:$YA;65=
M6R=F=6YC=&EO;B==(#T*("`@("`@("`@("`@("`@("`@("`@("`@97AP;&]D
M92@G.CHG+"`D9&UA<%LD;65T:$YA;65=6R=F=6YC=&EO;B==*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@:68@*&ES<V5T*"1D;6%P6R1M971H3F%M
M95U;)V9U;F-T:6]N)UTI"B`@("`@("`@("`@("`@("`F)B!I<U]C86QL86)L
M92@D9&UA<%LD;65T:$YA;65=6R=F=6YC=&EO;B==*2D*("`@("`@("`@("`@
M>PH@("`@("`@("`@("`@("`@+R\@9&ES<&%T8V@@:68@97AI<W1S"B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&1M87!;)&UE=&A.86UE75LG<VEG;F%T
M=7)E)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)'-R(#T@)'1H:7,M/G9E
M<FEF>5-I9VYA='5R92@D;2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1D;6%P6R1M971H3F%M95U;)W-I9VYA
M='5R92==("D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1D;6%P6R1M971H3F%M95U;)W-I9VYA='5R92==*2!\?"`D
M<W);,%TI('L*("`@("`@("`@("`@("`@("`@("`O+R!I9B!N;R!S:6=N871U
M<F4@;W(@8V]R<F5C="!S:6=N871U<F4*("`@("`@("`@("`@("`@("`@("!I
M9B`H)'-Y<T-A;&PI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'(@/2!C
M86QL7W5S97)?9G5N8R@D9&UA<%LD;65T:$YA;65=6R=F=6YC=&EO;B==+"`D
M=&AI<RP@)&TI.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1R(#T@8V%L;%]U<V5R7V9U;F,H)&1M87!;
M)&UE=&A.86UE75LG9G5N8W1I;VXG72P@)&TI.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7V$H)'(L("=834Q?
M4E!#7U)E<W!O;G-E)RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'(@
M/2!N97<@6$U,7U)00U]297-P;VYS92@P+"`D6$U,7U)00U]E<G);)VYO=%]R
M97-P;VYS95]O8FIE8W0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D6$U,7U)00U]S=');)VYO=%]R97-P
M;VYS95]O8FIE8W0G72D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<B`](&YE
M=R!834Q?4E!#7U)E<W!O;G-E*#`L("1834Q?4E!#7V5R<ELG:6YC;W)R96-T
M7W!A<F%M<R==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)%A-3%]24$-?<W1R6R=I;F-O<G)E8W1?<&%R86US)UT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("X@)SH@)R`N("1S<ELQ72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O+R!E;'-E('!R97!A<F4@
M97)R;W(@<F5S<&]N<V4*("`@("`@("`@("`@("`@("1R(#T@;F5W(%A-3%]2
M4$-?4F5S<&]N<V4H,"P@)%A-3%]24$-?97)R6R=U;FMN;W=N7VUE=&AO9"==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M6$U,7U)00U]S=');)W5N:VYO=VY?;65T:&]D)UTI.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<CL*("`@('T*"B`@("`O*BH*
M("`@("`J($5C:&]S(&)A8VL@=&AE(&EN<'5T('!A8VME="!A<R!A('-T<FEN
M9R!V86QU90H@("`@("H*("`@("`J($!R971U<FX@=F]I9`H@("`@("H*("`@
M("`J(%5S969U;"!F;W(@9&5B=6=G:6YG+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!E8VAO26YP=70H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D2%144%]205=?
M4$]35%]$051!.PH*("`@("`@("`D<B`](&YE=R!834Q?4E!#7U)E<W!O;G-E
M*#`I.PH@("`@("`@("1R+3YX=B`](&YE=R!834Q?4E!#7U9A;'5E*"(G06AA
M('-A:60@23H@)R(@+B`D2%144%]205=?4$]35%]$051!+"`G<W1R:6YG)RD[
M"B`@("`@("`@<')I;G0@)'(M/G-E<FEA;&EZ92@I.PH@("`@?0I]"@HO*@H@
M*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC
M+6]F9G-E=#H@-`H@*B!C+6AA;F=I;F<M8V]M;65N="UE;F1E<BUP.B!N:6P*
M("H@16YD.@H@*B\*"C\^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+UA-3"]24$,N<&AP````````````````````````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,38P,S,R`#$P-3$U-#,S-S,V`#`R,#0Q
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I
M9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!02%`@:6UP;&5M96YT
M871I;VX@;V8@=&AE(%A-3"U24$,@<')O=&]C;VP*("H*("H@5&AI<R!I<R!A
M(%!%05(M:69I960@=F5R<VEO;B!O9B!5<V5F=6P@:6YC)W,@6$U,+5)00R!F
M;W(@4$A0+@H@*B!)="!H87,@<W5P<&]R="!F;W(@2%144"!T<F%N<W!O<G0L
M('!R;WAI97,@86YD(&%U=&AE;G1I8V%T:6]N+@H@*@H@*B!02%`@=F5R<VEO
M;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!,:6-E;G-E(&ES(&=R86YT960@
M=&\@=7-E(&]R(&UO9&EF>2!T:&ES('-O9G1W87)E"B`J("@B6$U,+5)00R!F
M;W(@4$A0(BD@9F]R(&-O;6UE<F-I86P@;W(@;F]N+6-O;6UE<F-I86P@=7-E
M('!R;W9I9&5D('1H90H@*B!C;W!Y<FEG:'0@;V8@=&AE(&%U=&AO<B!I<R!P
M<F5S97)V960@:6X@86YY(&1I<W1R:6)U=&5D(&]R(&1E<FEV871I=F4@=V]R
M:RX*("H*("H@5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0554
M2$]2(")!4R!)4R(@04Y$($%.62!%6%!215-3140@3U(*("H@24U03$E%1"!7
M05)204Y42453+"!)3D-,541)3D<L($)55"!.3U0@3$E-251%1"!43RP@5$A%
M($E-4$Q)140@5T%24D%.5$E%4PH@*B!/1B!-15)#2$%.5$%"24Q)5%D@04Y$
M($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%($%212!$25-#3$%)
M345$+@H@*B!)3B!.3R!%5D5.5"!32$%,3"!42$4@05542$]2($)%($Q)04),
M12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L"B`J($E.0TE$14Y404PL(%-0
M14-)04PL($5814U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!1T53("A)
M3D-,541)3D<L($)55`H@*B!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@
M3T8@4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L
M"B`J($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3($E.5$524E505$E/
M3BD@2$]7159%4B!#0553140@04Y$($].($%.60H@*B!42$5/4ED@3T8@3$E!
M0DE,2519+"!72$542$52($E.($-/3E1204-4+"!35%))0U0@3$E!0DE,2519
M+"!/4B!43U)4"B`J("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)
M4T4I($%225-)3D<@24X@04Y9(%=!62!/550@3T8@5$A%(%5312!/1@H@*B!4
M2$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%(%!/4U-)0DE,
M2519($]&(%-50T@@1$%-04=%+@H@*@H@*B!`8V%T96=O<GD@("!796(@4V5R
M=FEC97,*("H@0'!A8VMA9V4@("`@6$U,7U)00PH@*B!`875T:&]R("`@("!%
M9&0@1'5M8FEL;"`\961D0'5S969U;&EN8RYC;VT^"B`J($!A=71H;W(@("`@
M(%-T:6<@0F%K:V5N(#QS=&EG0'!H<"YN970^"B`J($!A=71H;W(@("`@($UA
M<G1I;B!*86YS96X@/&UJ0'!H<"YN970^"B`J($!A=71H;W(@("`@($1A;FEE
M;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@
M,3DY.2TR,#`Q($5D9"!$=6UB:6QL+"`R,#`Q+3(P,#4@5&AE(%!(4"!'<F]U
M<`H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@4E!#+G!H<"QV(#$N.34@,C`P
M-B\P-"\Q-B`Q-3HP-#HU,R!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]834Q?4E!#"B`J+PH*"FEF
M("@A9G5N8W1I;VY?97AI<W1S*"=X;6Q?<&%R<V5R7V-R96%T92<I*2!["B`@
M("!I;F-L=61E7V]N8V4@)U!%05(N<&AP)SL*("`@(%!%05(Z.FQO861%>'1E
M;G-I;VXH)WAM;"<I.PI]"@HO*BHC0"L*("H@17)R;W(@8V]N<W1A;G1S"B`J
M+PHO*BH*("H@4&%R86UE=&5R('9A;'5E<R!D;VXG="!M871C:"!P87)A;65T
M97(@='EP97,*("HO"F1E9FEN92@G6$U,7U)00U]%4E)/4E])3E9!3$E$7U19
M4$4G+"`Q,#$I.PHO*BH*("H@4&%R86UE=&5R(&1E8VQA<F5D('1O(&)E(&YU
M;65R:6,@8G5T('1H92!V86QU97,@87)E(&YO=`H@*B\*9&5F:6YE*"=834Q?
M4E!#7T524D]27TY/3E].54U%4DE#7T9/54Y$)RP@,3`R*3L*+RHJ"B`J($-O
M;6UU;FEC871I;VX@97)R;W(*("HO"F1E9FEN92@G6$U,7U)00U]%4E)/4E]#
M3TY.14-424].7T9!24Q%1"<L(#$P,RD["B\J*@H@*B!4:&4@87)R87D@;W(@
M<W1R=6-T(&AA<R!A;')E861Y(&)E96X@<W1A<G1E9`H@*B\*9&5F:6YE*"=8
M34Q?4E!#7T524D]27T%,4D5!1%E?24Y)5$E!3$E:140G+"`Q,#0I.PHO*BH*
M("H@26YC;W)R96-T('!A<F%M971E<G,@<W5B;6ET=&5D"B`J+PID969I;F4H
M)UA-3%]24$-?15)23U)?24Y#3U)214-47U!!4D%-4R<L(#$P-2D["B\J*@H@
M*B!0<F]G<F%M;6EN9R!E<G)O<B!B>2!D979E;&]P97(*("HO"F1E9FEN92@G
M6$U,7U)00U]%4E)/4E]04D]'4D%-34E.1R<L(#$P-BD["B\J*B-`+2HO"@H*
M+RHJ"B`J($1A=&$@='EP97,*("H@0&=L;V)A;"!S=')I;F<@)$=,3T)!3%-;
M)UA-3%]24$-?230G70H@*B\*)$=,3T)!3%-;)UA-3%]24$-?230G72`]("=I
M-"<["@HO*BH*("H@1&%T82!T>7!E<PH@*B!`9VQO8F%L('-T<FEN9R`D1TQ/
M0D%,4ULG6$U,7U)00U]);G0G70H@*B\*)$=,3T)!3%-;)UA-3%]24$-?26YT
M)UT@/2`G:6YT)SL*"B\J*@H@*B!$871A('1Y<&5S"B`J($!G;&]B86P@<W1R
M:6YG("1'3$]"04Q36R=834Q?4E!#7T)O;VQE86XG70H@*B\*)$=,3T)!3%-;
M)UA-3%]24$-?0F]O;&5A;B==(#T@)V)O;VQE86XG.PH*+RHJ"B`J($1A=&$@
M='EP97,*("H@0&=L;V)A;"!S=')I;F<@)$=,3T)!3%-;)UA-3%]24$-?1&]U
M8FQE)UT*("HO"B1'3$]"04Q36R=834Q?4E!#7T1O=6)L92==(#T@)V1O=6)L
M92<["@HO*BH*("H@1&%T82!T>7!E<PH@*B!`9VQO8F%L('-T<FEN9R`D1TQ/
M0D%,4ULG6$U,7U)00U]3=')I;F<G70H@*B\*)$=,3T)!3%-;)UA-3%]24$-?
M4W1R:6YG)UT@/2`G<W1R:6YG)SL*"B\J*@H@*B!$871A('1Y<&5S"B`J($!G
M;&]B86P@<W1R:6YG("1'3$]"04Q36R=834Q?4E!#7T1A=&54:6UE)UT*("HO
M"B1'3$]"04Q36R=834Q?4E!#7T1A=&54:6UE)UT@/2`G9&%T951I;64N:7-O
M.#8P,2<["@HO*BH*("H@1&%T82!T>7!E<PH@*B!`9VQO8F%L('-T<FEN9R`D
M1TQ/0D%,4ULG6$U,7U)00U]"87-E-C0G70H@*B\*)$=,3T)!3%-;)UA-3%]2
M4$-?0F%S938T)UT@/2`G8F%S938T)SL*"B\J*@H@*B!$871A('1Y<&5S"B`J
M($!G;&]B86P@<W1R:6YG("1'3$]"04Q36R=834Q?4E!#7T%R<F%Y)UT*("HO
M"B1'3$]"04Q36R=834Q?4E!#7T%R<F%Y)UT@/2`G87)R87DG.PH*+RHJ"B`J
M($1A=&$@='EP97,*("H@0&=L;V)A;"!S=')I;F<@)$=,3T)!3%-;)UA-3%]2
M4$-?4W1R=6-T)UT*("HO"B1'3$]"04Q36R=834Q?4E!#7U-T<G5C="==(#T@
M)W-T<G5C="<["@H*+RHJ"B`J($1A=&$@='EP92!M971A+71Y<&5S"B`J($!G
M;&]B86P@87)R87D@)$=,3T)!3%-;)UA-3%]24$-?5'EP97,G70H@*B\*)$=,
M3T)!3%-;)UA-3%]24$-?5'EP97,G72`](&%R<F%Y*`H@("`@)$=,3T)!3%-;
M)UA-3%]24$-?230G72`@("`@("`]/B`Q+`H@("`@)$=,3T)!3%-;)UA-3%]2
M4$-?26YT)UT@("`@("`]/B`Q+`H@("`@)$=,3T)!3%-;)UA-3%]24$-?0F]O
M;&5A;B==("`]/B`Q+`H@("`@)$=,3T)!3%-;)UA-3%]24$-?4W1R:6YG)UT@
M("`]/B`Q+`H@("`@)$=,3T)!3%-;)UA-3%]24$-?1&]U8FQE)UT@("`]/B`Q
M+`H@("`@)$=,3T)!3%-;)UA-3%]24$-?1&%T951I;64G72`]/B`Q+`H@("`@
M)$=,3T)!3%-;)UA-3%]24$-?0F%S938T)UT@("`]/B`Q+`H@("`@)$=,3T)!
M3%-;)UA-3%]24$-?07)R87DG72`@("`]/B`R+`H@("`@)$=,3T)!3%-;)UA-
M3%]24$-?4W1R=6-T)UT@("`]/B`S+`HI.PH*"B\J*@H@*B!%<G)O<B!M97-S
M86=E(&YU;6)E<G,*("H@0&=L;V)A;"!A<G)A>2`D1TQ/0D%,4ULG6$U,7U)0
M0U]E<G(G70H@*B\*)$=,3T)!3%-;)UA-3%]24$-?97)R)UT@/2!A<G)A>2@*
M("`@("=U;FMN;W=N7VUE=&AO9"<@("`@("`]/B`Q+`H@("`@)VEN=F%L:61?
M<F5T=7)N)R`@("`@(#T^(#(L"B`@("`G:6YC;W)R96-T7W!A<F%M<R<@("`@
M/3X@,RP*("`@("=I;G1R;W-P96-T7W5N:VYO=VXG("`]/B`T+`H@("`@)VAT
M='!?97)R;W(G("`@("`@("`@(#T^(#4L"B`@("`G;F]T7W)E<W!O;G-E7V]B
M:F5C="<@/3X@-BP*("`@("=I;G9A;&ED7W)E<75E<W0G("`@("`]/B`W+`HI
M.PH*+RHJ"B`J($5R<F]R(&UE<W-A9V4@<W1R:6YG<PH@*B!`9VQO8F%L(&%R
M<F%Y("1'3$]"04Q36R=834Q?4E!#7W-T<B=="B`J+PHD1TQ/0D%,4ULG6$U,
M7U)00U]S='(G72`](&%R<F%Y*`H@("`@)W5N:VYO=VY?;65T:&]D)R`@("`@
M(#T^("=5;FMN;W=N(&UE=&AO9"<L"B`@("`G:6YV86QI9%]R971U<FXG("`@
M("`@/3X@)TEN=F%L:60@<F5T=7)N('!A>6QO860Z(&5N86)L92!D96)U9V=I
M;F<@=&\@97AA;6EN92!I;F-O;6EN9R!P87EL;V%D)RP*("`@("=I;F-O<G)E
M8W1?<&%R86US)R`@("`]/B`G26YC;W)R96-T('!A<F%M971E<G,@<&%S<V5D
M('1O(&UE=&AO9"<L"B`@("`G:6YT<F]S<&5C=%]U;FMN;W=N)R`@/3X@)T-A
M;EPG="!I;G1R;W-P96-T.B!M971H;V0@=6YK;F]W;B<L"B`@("`G:'1T<%]E
M<G)O<B<@("`@("`@("`@/3X@)T1I9&Y<)W0@<F5C96EV92`R,#`@3TL@9G)O
M;2!R96UO=&4@<V5R=F5R+B<L"B`@("`G;F]T7W)E<W!O;G-E7V]B:F5C="<@
M/3X@)U1H92!R97%U97-T960@;65T:&]D(&1I9&Y<)W0@<F5T=7)N(&%N(%A-
M3%]24$-?4F5S<&]N<V4@;V)J96-T+B<L"B`@("`G:6YV86QI9%]R97%U97-T
M)R`@("`@/3X@)TEN=F%L:60@<F5Q=65S="!P87EL;V%D)RP**3L*"@HO*BH*
M("H@1&5F875L="!834P@96YC;V1I;F<@*$E33RTX.#4Y+3$L(%541BTX(&]R
M(%53+4%30TE)*0H@*B!`9VQO8F%L('-T<FEN9R`D1TQ/0D%,4ULG6$U,7U)0
M0U]D969E;F-O9&EN9R=="B`J+PHD1TQ/0D%,4ULG6$U,7U)00U]D969E;F-O
M9&EN9R==(#T@)U541BTX)SL*"B\J*@H@*B!5<V5R(&5R<F]R(&-O9&5S('-T
M87)T(&%T(#@P,`H@*B!`9VQO8F%L(&EN="`D1TQ/0D%,4ULG6$U,7U)00U]E
M<G)U<V5R)UT*("HO"B1'3$]"04Q36R=834Q?4E!#7V5R<G5S97(G72`](#@P
M,#L*"B\J*@H@*B!834P@<&%R<V4@97)R;W(@8V]D97,@<W1A<G0@870@,3`P
M"B`J($!G;&]B86P@:6YT("1'3$]"04Q36R=834Q?4E!#7V5R<GAM;"=="B`J
M+PHD1TQ/0D%,4ULG6$U,7U)00U]E<G)X;6PG72`](#$P,#L*"@HO*BH*("H@
M0V]M<&]S92!B86-K<VQA<VAE<R!F;W(@97-C87!I;F<@<F5G97AP"B`J($!G
M;&]B86P@<W1R:6YG("1'3$]"04Q36R=834Q?4E!#7V)A8VMS;&%S:"=="B`J
M+PHD1TQ/0D%,4ULG6$U,7U)00U]B86-K<VQA<V@G72`](&-H<B@Y,BD@+B!C
M:'(H.3(I.PH*"B\J*@H@*B!686QI9"!P87)E;G1S(&]F(%A-3"!E;&5M96YT
M<PH@*B!`9VQO8F%L(&%R<F%Y("1'3$]"04Q36R=834Q?4E!#7W9A;&ED7W!A
M<F5N=',G70H@*B\*)$=,3T)!3%-;)UA-3%]24$-?=F%L:61?<&%R96YT<R==
M(#T@87)R87DH"B`@("`G0D]/3$5!3B<@/3X@87)R87DH)U9!3%5%)RDL"B`@
M("`G230G(#T^(&%R<F%Y*"=604Q512<I+`H@("`@)TE.5"<@/3X@87)R87DH
M)U9!3%5%)RDL"B`@("`G4U1224Y')R`]/B!A<G)A>2@G5D%,544G*2P*("`@
M("=$3U5"3$4G(#T^(&%R<F%Y*"=604Q512<I+`H@("`@)T1!5$5424U%+DE3
M3S@V,#$G(#T^(&%R<F%Y*"=604Q512<I+`H@("`@)T)!4T4V-"<@/3X@87)R
M87DH)U9!3%5%)RDL"B`@("`G05)205DG(#T^(&%R<F%Y*"=604Q512<I+`H@
M("`@)U-44E5#5"<@/3X@87)R87DH)U9!3%5%)RDL"B`@("`G4$%204TG(#T^
M(&%R<F%Y*"=005)!35,G*2P*("`@("=-151(3T1.04U%)R`]/B!A<G)A>2@G
M34542$]$0T%,3"<I+`H@("`@)U!!4D%-4R<@/3X@87)R87DH)TU%5$A/1$-!
M3$PG+"`G34542$]$4D534$].4T4G*2P*("`@("=-14U"15(G(#T^(&%R<F%Y
M*"=35%)50U0G*2P*("`@("=.04U%)R`]/B!A<G)A>2@G345-0D52)RDL"B`@
M("`G1$%402<@/3X@87)R87DH)T%24D%9)RDL"B`@("`G1D%53%0G(#T^(&%R
M<F%Y*"=-151(3T1215-03TY312<I+`H@("`@)U9!3%5%)R`]/B!A<G)A>2@G
M345-0D52)RP@)T1!5$$G+"`G4$%204TG+"`G1D%53%0G*2P**3L*"@HO*BH*
M("H@4W1O<F5S('-T871E(&1U<FEN9R!P87)S:6YG"B`J"B`J('%U:6-K(&5X
M<&QA;F%T:6]N(&]F(&-O;7!O;F5N=',Z"B`J("`@*R!A8R`@("`@/2!A8V-U
M;75L871E<R!V86QU97,*("H@("`K('%T("`@("`](&1E8VED97,@:68@<75O
M=&5S(&%R92!N965D960@9F]R(&5V86QU871I;VX*("H@("`K(&-M("`@("`]
M(&1E;F]T97,@<W1R=6-T(&]R(&%R<F%Y("AC;VUM82!N965D960I"B`J("`@
M*R!I<V8@("`@/2!I;F1I8V%T97,@82!F875L=`H@*B`@("L@;'8@("`@(#T@
M:6YD:6-A=&5S(")L;V]K:6YG(&9O<B!A('9A;'5E(CH@:6UP;&5M96YT<R!T
M:&4@;&]G:6,*("H@("`@("`@("`@("`@("!T;R!A;&QO=R!V86QU97,@=VET
M:"!N;R!T>7!E<R!T;R!B92!S=')I;F=S"B`J("`@*R!P87)A;7,@/2!S=&]R
M97,@<&%R86UE=&5R<R!I;B!M971H;V0@8V%L;',*("H@("`K(&UE=&AO9"`]
M('-T;W)E<R!M971H;V0@;F%M90H@*@H@*B!`9VQO8F%L(&%R<F%Y("1'3$]"
M04Q36R=834Q?4E!#7WAH)UT*("HO"B1'3$]"04Q36R=834Q?4E!#7WAH)UT@
M/2!A<G)A>2@I.PH*"B\J*@H@*B!3=&%R="!E;&5M96YT(&AA;F1L97(@9F]R
M('1H92!834P@<&%R<V5R"B`J"B`J($!R971U<FX@=F]I9`H@*B\*9G5N8W1I
M;VX@6$U,7U)00U]S92@D<&%R<V5R7W)E<V]U<F-E+"`D;F%M92P@)&%T=')S
M*0I["B`@("!G;&]B86P@)%A-3%]24$-?>&@L("1834Q?4E!#7W9A;&ED7W!A
M<F5N=',["@H@("`@)'!A<G-E<B`]("AI;G0I("1P87)S97)?<F5S;W5R8V4[
M"@H@("`@+R\@:68@:6YV86QI9"!X;6QR<&,@86QR96%D>2!D971E8W1E9"P@
M<VMI<"!A;&P@<')O8V5S<VEN9PH@("`@:68@*"1834Q?4E!#7WAH6R1P87)S
M97)=6R=I<V8G72`^/2`R*2!["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@
M("\O(&-H96-K(&9O<B!C;W)R96-T(&5L96UE;G0@;F5S=&EN9PH@("`@+R\@
M=&]P(&QE=F5L(&5L96UE;G0@8V%N(&]N;'D@8F4@;V8@,B!T>7!E<PH@("`@
M:68@*&-O=6YT*"1834Q?4E!#7WAH6R1P87)S97)=6R=S=&%C:R==*2`]/2`P
M*2!["B`@("`@("`@:68@*"1N86UE("$]("=-151(3T1215-03TY312<@)B8@
M)&YA;64@(3T@)TU%5$A/1$-!3$PG*2!["B`@("`@("`@("`@("1834Q?4E!#
M7WAH6R1P87)S97)=6R=I<V8G72`](#(["B`@("`@("`@("`@("1834Q?4E!#
M7WAH6R1P87)S97)=6R=I<V9?<F5A<V]N)UT@/2`G;6ES<VEN9R!T;W`@;&5V
M96P@>&UL<G!C(&5L96UE;G0G.PH@("`@("`@("`@("!R971U<FX["B`@("`@
M("`@?0H@("`@?2!E;'-E('L*("`@("`@("`O+R!N;W0@=&]P(&QE=F5L(&5L
M96UE;G0Z('-E92!I9B!P87)E;G0@:7,@3TL*("`@("`@("!I9B`H(6EN7V%R
M<F%Y*"1834Q?4E!#7WAH6R1P87)S97)=6R=S=&%C:R==6S!=+"`D6$U,7U)0
M0U]V86QI9%]P87)E;G1S6R1N86UE72DI('L*("`@("`@("`@("`@)&YA;64@
M/2!P<F5G7W)E<&QA8V4H)UM>82UZ02U:,"TY+E\M72<L("<G+"`D;F%M92D[
M"B`@("`@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=I<V8G72`](#([
M"B`@("`@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=I<V9?<F5A<V]N
M)UT@/2`B>&UL<G!C(&5L96UE;G0@)&YA;64@8V%N;F]T(&)E(&-H:6QD(&]F
M('LD6$U,7U)00U]X:%LD<&%R<V5R75LG<W1A8VLG75LP77TB.PH@("`@("`@
M("`@("!R971U<FX["B`@("`@("`@?0H@("`@?0H*("`@('-W:71C:"`H)&YA
M;64I('L*("`@(&-A<V4@)U-44E5#5"<Z"B`@("`@("`@)%A-3%]24$-?>&A;
M)'!A<G-E<EU;)V-M)UTK*SL*"B`@("`@("`@+R\@='5R;B!Q=6]T:6YG(&]F
M9@H@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=Q="==(#T@,#L*"B`@
M("`@("`@)&-U<E]V86P@/2!A<G)A>2@I.PH@("`@("`@("1C=7)?=F%L6R=V
M86QU92==(#T@87)R87DH*3L*("`@("`@("`D8W5R7W9A;%LG;65M8F5R<R==
M(#T@,3L*("`@("`@("!A<G)A>5]U;G-H:69T*"1834Q?4E!#7WAH6R1P87)S
M97)=6R=V86QU97-T86-K)UTL("1C=7)?=F%L*3L*("`@("`@("!B<F5A:SL*
M"B`@("!C87-E("=!4E)!62<Z"B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E
M<EU;)V-M)UTK*SL*"B`@("`@("`@+R\@='5R;B!Q=6]T:6YG(&]F9@H@("`@
M("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=Q="==(#T@,#L*"B`@("`@("`@
M)&-U<E]V86P@/2!A<G)A>2@I.PH@("`@("`@("1C=7)?=F%L6R=V86QU92==
M(#T@87)R87DH*3L*("`@("`@("`D8W5R7W9A;%LG;65M8F5R<R==(#T@,#L*
M("`@("`@("!A<G)A>5]U;G-H:69T*"1834Q?4E!#7WAH6R1P87)S97)=6R=V
M86QU97-T86-K)UTL("1C=7)?=F%L*3L*("`@("`@("!B<F5A:SL*"B`@("!C
M87-E("=.04U%)SH*("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG86,G
M72`]("<G.PH@("`@("`@(&)R96%K.PH*("`@(&-A<V4@)T9!54Q4)SH*("`@
M("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG:7-F)UT@/2`Q.PH@("`@("`@
M(&)R96%K.PH*("`@(&-A<V4@)U!!4D%-)SH*("`@("`@("`D6$U,7U)00U]X
M:%LD<&%R<V5R75LG=F%L=65S=&%C:R==(#T@87)R87DH*3L*("`@("`@("!B
M<F5A:SL*"B`@("!C87-E("=604Q512<Z"B`@("`@("`@)%A-3%]24$-?>&A;
M)'!A<G-E<EU;)VQV)UT@/2`Q.PH@("`@("`@("1834Q?4E!#7WAH6R1P87)S
M97)=6R=V="==(#T@)$=,3T)!3%-;)UA-3%]24$-?4W1R:6YG)UT["B`@("`@
M("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)V%C)UT@/2`G)SL*("`@("`@("`D
M6$U,7U)00U]X:%LD<&%R<V5R75LG<70G72`](#`["B`@("`@("`@+R\@;&]O
M:R!F;W(@82!V86QU93H@:68@=&AI<R!I<R!S=&EL;"`Q(&)Y('1H90H@("`@
M("`@("\O('1I;64@=V4@<F5A8V@@=&AE(&9I<G-T(&1A=&$@<V5G;65N="!T
M:&5N('1H92!T>7!E(&ES('-T<FEN9PH@("`@("`@("\O(&)Y(&EM<&QI8V%T
M:6]N(&%N9"!W92!N965D('1O(&%D9"!I;B!A('%U;W1E"B`@("`@("`@8G)E
M86L["@H@("`@8V%S92`G230G.@H@("`@8V%S92`G24Y4)SH*("`@(&-A<V4@
M)U-44DE.1R<Z"B`@("!C87-E("="3T],14%.)SH*("`@(&-A<V4@)T1/54),
M12<Z"B`@("!C87-E("=$051%5$E-12Y)4T\X-C`Q)SH*("`@(&-A<V4@)T)!
M4T4V-"<Z"B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)V%C)UT@/2`G
M)SL@+R\@<F5S970@=&AE(&%C8W5M=6QA=&]R"@H@("`@("`@(&EF("@D;F%M
M92`]/2`G1$%4151)344N25-/.#8P,2<@?'P@)&YA;64@/3T@)U-44DE.1R<I
M('L*("`@("`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W%T)UT@/2`Q
M.PH*("`@("`@("`@("`@:68@*"1N86UE(#T]("=$051%5$E-12Y)4T\X-C`Q
M)RD@>PH@("`@("`@("`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9T
M)UT@/2`D1TQ/0D%,4ULG6$U,7U)00U]$871E5&EM92==.PH@("`@("`@("`@
M("!]"@H@("`@("`@('T@96QS96EF("@D;F%M92`]/2`G0D%3138T)RD@>PH@
M("`@("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG<70G72`](#(["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@3F\@<75O=&EN9R!I<R!R
M97%U:7)E9"!H97)E("TM(&)U=`H@("`@("`@("`@("`O+R!A="!T:&4@96YD
M(&]F('1H92!E;&5M96YT('=E(&UU<W0@8VAE8VL*("`@("`@("`@("`@+R\@
M9F]R(&1A=&$@9F]R;6%T(&5R<F]R<RX*("`@("`@("`@("`@)%A-3%]24$-?
M>&A;)'!A<G-E<EU;)W%T)UT@/2`P.PH@("`@("`@('T*("`@("`@("!B<F5A
M:SL*"B`@("!C87-E("=-14U"15(G.@H@("`@("`@("1834Q?4E!#7WAH6R1P
M87)S97)=6R=A8R==(#T@)R<["B`@("`@("`@8G)E86L["@H@("`@8V%S92`G
M1$%402<Z"B`@("!C87-E("=-151(3T1#04Q,)SH*("`@(&-A<V4@)TU%5$A/
M1$Y!344G.@H@("`@8V%S92`G34542$]$4D534$].4T4G.@H@("`@8V%S92`G
M4$%204U3)SH*("`@("`@("`O+R!V86QI9"!E;&5M96YT<R!T:&%T(&%D9"!L
M:71T;&4@=&\@<')O8V5S<VEN9PH@("`@("`@(&)R96%K.PH@("`@?0H*"B`@
M("`O+R!3879E(&-U<G)E;G0@96QE;65N="!T;R!S=&%C:PH@("`@87)R87E?
M=6YS:&EF="@D6$U,7U)00U]X:%LD<&%R<V5R75LG<W1A8VLG72P@)&YA;64I
M.PH*("`@(&EF("@D;F%M92`A/2`G5D%,544G*2!["B`@("`@("`@)%A-3%]2
M4$-?>&A;)'!A<G-E<EU;)VQV)UT@/2`P.PH@("`@?0I]"@HO*BH*("H@16YD
M(&5L96UE;G0@:&%N9&QE<B!F;W(@=&AE(%A-3"!P87)S97(*("H*("H@0')E
M='5R;B!V;VED"B`J+PIF=6YC=&EO;B!834Q?4E!#7V5E*"1P87)S97)?<F5S
M;W5R8V4L("1N86UE*0I["B`@("!G;&]B86P@)%A-3%]24$-?>&@["@H@("`@
M)'!A<G-E<B`]("AI;G0I("1P87)S97)?<F5S;W5R8V4["@H@("`@:68@*"18
M34Q?4E!#7WAH6R1P87)S97)=6R=I<V8G72`^/2`R*2!["B`@("`@("`@<F5T
M=7)N.PH@("`@?0H*("`@("\O('!U<V@@=&AI<R!E;&5M96YT(&9R;VT@<W1A
M8VL*("`@("\O($Y".B!I9B!834P@=F%L:61A=&5S+"!C;W)R96-T(&]P96YI
M;F<O8VQO<VEN9R!I<R!G=6%R86YT965D(&%N9`H@("`@+R\@=V4@9&\@;F]T
M(&AA=F4@=&\@8VAE8VL@9F]R("1N86UE(#T]("1C=7)R7V5L96TN"B`@("`O
M+R!W92!A;'-O(&-H96-K960@9F]R('!R;W!E<B!N97-T:6YG(&%T('-T87)T
M(&]F(&5L96UE;G1S+BXN"B`@("`D8W5R<E]E;&5M(#T@87)R87E?<VAI9G0H
M)%A-3%]24$-?>&A;)'!A<G-E<EU;)W-T86-K)UTI.PH*("`@('-W:71C:"`H
M)&YA;64I('L*("`@(&-A<V4@)U-44E5#5"<Z"B`@("!C87-E("=!4E)!62<Z
M"B`@("`D8W5R7W9A;"`](&%R<F%Y7W-H:69T*"1834Q?4E!#7WAH6R1P87)S
M97)=6R=V86QU97-T86-K)UTI.PH@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;
M)W9A;'5E)UT@/2`D8W5R7W9A;%LG=F%L=64G73L*("`@("`@("`D6$U,7U)0
M0U]X:%LD<&%R<V5R75LG=G0G72`]('-T<G1O;&]W97(H)&YA;64I.PH@("`@
M("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=C;2==+2T["B`@("`@("`@8G)E
M86L["@H@("`@8V%S92`G3D%-12<Z"B`@("`D6$U,7U)00U]X:%LD<&%R<V5R
M75LG=F%L=65S=&%C:R==6S!=6R=N86UE)UT@/2`D6$U,7U)00U]X:%LD<&%R
M<V5R75LG86,G73L*("`@("`@("!B<F5A:SL*"B`@("!C87-E("="3T],14%.
M)SH*("`@("`@("`O+R!S<&5C:6%L(&-A<V4@:&5R93H@=V4@=')A;G-L871E
M(&)O;VQE86X@,2!O<B`P(&EN=&\@4$A0"B`@("`@("`@+R\@8V]N<W1A;G1S
M('1R=64@;W(@9F%L<V4*("`@("`@("!I9B`H)%A-3%]24$-?>&A;)'!A<G-E
M<EU;)V%C)UT@/3T@)S$G*2!["B`@("`@("`@("`@("1834Q?4E!#7WAH6R1P
M87)S97)=6R=A8R==(#T@)W1R=64G.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=A8R==(#T@)V9A;'-E)SL*
M("`@("`@("!]"@H@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=V="==
M(#T@<W1R=&]L;W=E<B@D;F%M92D["B`@("`@("`@+R\@1')O<"!T:')O=6=H
M(&EN=&5N=&EO;F%L;'DN"@H@("`@8V%S92`G230G.@H@("`@8V%S92`G24Y4
M)SH*("`@(&-A<V4@)U-44DE.1R<Z"B`@("!C87-E("=$3U5"3$4G.@H@("`@
M8V%S92`G1$%4151)344N25-/.#8P,2<Z"B`@("!C87-E("="05-%-C0G.@H@
M("`@("`@(&EF("@D6$U,7U)00U]X:%LD<&%R<V5R75LG<70G72`]/2`Q*2![
M"B`@("`@("`@("`@("\O('=E('5S92!D;W5B;&4@<75O=&5S(')A=&AE<B!T
M:&%N('-I;F=L92!S;R!B86-K<VQA<VAI9FEC871I;VX@=V]R:W,@3TL*("`@
M("`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9A;'5E)UT@/2`D6$U,
M7U)00U]X:%LD<&%R<V5R75LG86,G73L*("`@("`@("!](&5L<V5I9B`H)%A-
M3%]24$-?>&A;)'!A<G-E<EU;)W%T)UT@/3T@,BD@>PH@("`@("`@("`@("`D
M6$U,7U)00U]X:%LD<&%R<V5R75LG=F%L=64G72`](&)A<V4V-%]D96-O9&4H
M)%A-3%]24$-?>&A;)'!A<G-E<EU;)V%C)UTI.PH@("`@("`@('T@96QS96EF
M("@D;F%M92`]/2`G0D]/3$5!3B<I('L*("`@("`@("`@("`@)%A-3%]24$-?
M>&A;)'!A<G-E<EU;)W9A;'5E)UT@/2`D6$U,7U)00U]X:%LD<&%R<V5R75LG
M86,G73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!W92!H879E
M(&%N($DT+"!)3E0@;W(@82!$3U5"3$4*("`@("`@("`@("`@+R\@=V4@;75S
M="!C:&5C:R!T:&%T(&]N;'D@,#$R,S0U-C<X.2TN/'-P86-E/B!A<F4@8VAA
M<F%C=&5R<R!H97)E"B`@("`@("`@("`@(&EF("@A97)E9R@B7ELK+5T_6S`Q
M,C,T-38W.#D@7'1<+ETK)"(L("1834Q?4E!#7WAH6R1P87)S97)=6R=A8R==
M*2D@>PH@("`@("`@("`@("`@("`@6$U,7U)00U]"87-E.CIR86ES945R<F]R
M*"=.;VXM;G5M97)I8R!V86QU92!R96-E:79E9"!I;B!)3E0@;W(@1$]50DQ%
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!8
M34Q?4E!#7T524D]27TY/3E].54U%4DE#7T9/54Y$*3L*("`@("`@("`@("`@
M("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=V86QU92==(#T@6$U,7U)00U]%
M4E)/4E].3TY?3E5-15))0U]&3U5.1#L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("\O(&ET)W,@;VLL(&%D9"!I="!O;@H@("`@("`@
M("`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9A;'5E)UT@/2`D6$U,
M7U)00U]X:%LD<&%R<V5R75LG86,G73L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)V%C)UT@/2`G)SL*
M("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG<70G72`](#`["B`@("`@
M("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)VQV)UT@/2`S.R`O+R!I;F1I8V%T
M92!W92=V92!F;W5N9"!A('9A;'5E"B`@("`@("`@8G)E86L["@H@("`@8V%S
M92`G5D%,544G.@H@("`@("`@(&EF("@D6$U,7U)00U]X:%LD<&%R<V5R75LG
M=G0G72`]/2`D1TQ/0D%,4ULG6$U,7U)00U]3=')I;F<G72D@>PH@("`@("`@
M("`@("!I9B`H<W1R;&5N*"1834Q?4E!#7WAH6R1P87)S97)=6R=A8R==*2`^
M(#`I('L*("`@("`@("`@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=V
M86QU92==(#T@)%A-3%]24$-?>&A;)'!A<G-E<EU;)V%C)UT["B`@("`@("`@
M("`@('T@96QS96EF("@D6$U,7U)00U]X:%LD<&%R<V5R75LG;'8G72`]/2`Q
M*2!["B`@("`@("`@("`@("`@("`O+R!4:&4@/'9A;'5E/B!E;&5M96YT('=A
M<R!E;7!T>2X*("`@("`@("`@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=
M6R=V86QU92==(#T@)R<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("1T96UP(#T@;F5W(%A-3%]24$-?5F%L=64H)%A-3%]24$-?>&A;)'!A
M<G-E<EU;)W9A;'5E)UTL("1834Q?4E!#7WAH6R1P87)S97)=6R=V="==*3L*
M"B`@("`@("`@)&-U<E]V86P@/2!A<G)A>5]S:&EF="@D6$U,7U)00U]X:%LD
M<&%R<V5R75LG=F%L=65S=&%C:R==*3L*("`@("`@("!I9B`H:7-?87)R87DH
M)&-U<E]V86PI*2!["B`@("`@("`@("`@(&EF("@D8W5R7W9A;%LG;65M8F5R
M<R==/3TP*2!["B`@("`@("`@("`@("`@("`D8W5R7W9A;%LG=F%L=64G75M=
M(#T@)'1E;7`["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D6$U,7U)00U]X:%LD<&%R<V5R75LG=F%L=64G72`]("1T96UP.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&%R<F%Y7W5N<VAI9G0H)%A-3%]24$-?
M>&A;)'!A<G-E<EU;)W9A;'5E<W1A8VLG72P@)&-U<E]V86PI.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=V
M86QU92==(#T@)'1E;7`["B`@("`@("`@?0H@("`@("`@(&)R96%K.PH*("`@
M(&-A<V4@)TU%34)%4B<Z"B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;
M)V%C)UT@/2`G)SL*("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG<70G
M72`](#`["@H@("`@("`@("1C=7)?=F%L(#T@87)R87E?<VAI9G0H)%A-3%]2
M4$-?>&A;)'!A<G-E<EU;)W9A;'5E<W1A8VLG72D["B`@("`@("`@:68@*&ES
M7V%R<F%Y*"1C=7)?=F%L*2D@>PH@("`@("`@("`@("!I9B`H)&-U<E]V86Q;
M)VUE;6)E<G,G73T],2D@>PH@("`@("`@("`@("`@("`@)&-U<E]V86Q;)W9A
M;'5E)UU;)&-U<E]V86Q;)VYA;64G75T@/2`D6$U,7U)00U]X:%LD<&%R<V5R
M75LG=F%L=64G73L*("`@("`@("`@("`@?0H@("`@("`@("`@("!A<G)A>5]U
M;G-H:69T*"1834Q?4E!#7WAH6R1P87)S97)=6R=V86QU97-T86-K)UTL("1C
M=7)?=F%L*3L*("`@("`@("!]"B`@("`@("`@8G)E86L["@H@("`@8V%S92`G
M1$%402<Z"B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)V%C)UT@/2`G
M)SL*("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG<70G72`](#`["B`@
M("`@("`@8G)E86L["@H@("`@8V%S92`G4$%204TG.@H@("`@("`@("1834Q?
M4E!#7WAH6R1P87)S97)=6R=P87)A;7,G75M=(#T@)%A-3%]24$-?>&A;)'!A
M<G-E<EU;)W9A;'5E)UT["B`@("`@("`@8G)E86L["@H@("`@8V%S92`G3454
M2$]$3D%-12<Z"B`@("!C87-E("=24$--151(3T1.04U%)SH*("`@("`@("`D
M6$U,7U)00U]X:%LD<&%R<V5R75LG;65T:&]D)UT@/2!E<F5G7W)E<&QA8V4H
M(EY;7&Y<<EQT(%TK(BP@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1834Q?4E!#7WAH6R1P87)S
M97)=6R=A8R==*3L*("`@("`@("!B<F5A:SL*("`@('T*"B`@("`O+R!I9B!I
M="=S(&$@=F%L:60@='EP92!N86UE+"!S970@=&AE('1Y<&4*("`@(&EF("AI
M<W-E="@D1TQ/0D%,4ULG6$U,7U)00U]4>7!E<R==6W-T<G1O;&]W97(H)&YA
M;64I72DI('L*("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG=G0G72`]
M('-T<G1O;&]W97(H)&YA;64I.PH@("`@?0I]"@HO*BH*("H@0VAA<F%C=&5R
M(&1A=&$@:&%N9&QE<B!F;W(@=&AE(%A-3"!P87)S97(*("H*("H@0')E='5R
M;B!V;VED"B`J+PIF=6YC=&EO;B!834Q?4E!#7V-D*"1P87)S97)?<F5S;W5R
M8V4L("1D871A*0I["B`@("!G;&]B86P@)%A-3%]24$-?>&@L("1834Q?4E!#
M7V)A8VMS;&%S:#L*"B`@("`D<&%R<V5R(#T@*&EN="D@)'!A<G-E<E]R97-O
M=7)C93L*"B`@("!I9B`H)%A-3%]24$-?>&A;)'!A<G-E<EU;)VQV)UT@(3T@
M,RD@>PH@("`@("`@("\O(")L;V]K9F]R=F%L=64]/3,B(&UE86YS('1H870@
M=V4G=F4@9F]U;F0@86X@96YT:7)E('9A;'5E"B`@("`@("`@+R\@86YD('-H
M;W5L9"!D:7-C87)D(&%N>2!F=7)T:&5R(&-H87)A8W1E<B!D871A"@H@("`@
M("`@(&EF("@D6$U,7U)00U]X:%LD<&%R<V5R75LG;'8G72`]/2`Q*2!["B`@
M("`@("`@("`@("\O(&EF('=E)W9E(&9O=6YD('1E>'0@86YD('=E)W)E(&IU
M<W0@:6X@82`\=F%L=64^('1H96X*("`@("`@("`@("`@+R\@='5R;B!Q=6]T
M:6YG(&]N+"!A<R!T:&ES('=I;&P@8F4@82!S=')I;F<*("`@("`@("`@("`@
M)%A-3%]24$-?>&A;)'!A<G-E<EU;)W%T)UT@/2`Q.PH@("`@("`@("`@("`O
M+R!A;F0@<V%Y('=E)W9E(&9O=6YD(&$@=F%L=64*("`@("`@("`@("`@)%A-
M3%]24$-?>&A;)'!A<G-E<EU;)VQV)UT@/2`R.PH@("`@("`@('T*"B`@("`@
M("`@+R\@<F5P;&%C92!C:&%R86-T97)S('1H870@979A;"!W;W5L9`H@("`@
M("`@("\O(&1O('-P96-I86P@=&AI;F=S('=I=&@*("`@("`@("!I9B`H(6ES
M<V5T*"1834Q?4E!#7WAH6R1P87)S97)=6R=A8R==*2D@>PH@("`@("`@("`@
M("`D6$U,7U)00U]X:%LD<&%R<V5R75LG86,G72`]("<G.PH@("`@("`@('T*
M("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG86,G72`N/2`D9&%T83L*
M("`@('T*?0H*+RHJ"B`J(%1H92!C;VUM;VX@;65T:&]D<R!A;F0@<')O<&5R
M=&EE<R!F;W(@86QL(&]F('1H92!834Q?4E!#(&-L87-S97,*("H*("H@0&-A
M=&5G;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@(%A-3%]24$,*
M("H@0&%U=&AO<B`@("`@161D($1U;6)I;&P@/&5D9$!U<V5F=6QI;F,N8V]M
M/@H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W1I9T!P:'`N;F5T/@H@
M*B!`875T:&]R("`@("!-87)T:6X@2F%N<V5N(#QM:D!P:'`N;F5T/@H@*B!`
M875T:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^
M"B`J($!C;W!Y<FEG:'0@(#$Y.3DM,C`P,2!%9&0@1'5M8FEL;"P@,C`P,2TR
M,#`U(%1H92!02%`@1W)O=7`*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT
M+C@*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+UA-3%]24$,*("HO"F-L87-S(%A-3%]24$-?0F%S92!["@H@("`@+RHJ"B`@
M("`@*B!014%2($5R<F]R(&AA;F1L:6YG"B`@("`@*@H@("`@("H@0')E='5R
M;B!O8FIE8W0@(%!%05)?17)R;W(@;V)J96-T"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')A:7-E17)R;W(H)&US9RP@)&-O9&4I"B`@("!["B`@("`@("`@:6YC
M;'5D95]O;F-E("=014%2+G!H<"<["B`@("`@("`@:68@*&ES7V]B:F5C="A`
M)'1H:7,I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*&=E=%]C;&%S<R@D=&AI<RD@+B`G.B`G("X@)&US9RP@)&-O9&4I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"=834Q?4E!#.B`G("X@)&US9RP@)&-O9&4I.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J(%1E;&P@=VAE=&AE<B!S;VUE=&AI;F<@:7,@
M82!014%27T5R<F]R(&]B:F5C=`H@("`@("H*("`@("`J($!P87)A;2!M:7AE
M9"`D=F%L=64@('1H92!I=&5M('1O(&-H96-K"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L("!W:&5T:&5R("1V86QU92!I<R!A(%!%05)?17)R;W(@;V)J
M96-T(&]R(&YO=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&ES17)R;W(H)'9A;'5E*0H@("`@>PH@("`@("`@
M(')E='5R;B!I<U]A*"1V86QU92P@)U!%05)?17)R;W(G*3L*("`@('T*?0H*
M+RHJ"B`J(%1H92!M971H;V1S(&%N9"!P<F]P97)T:65S(&9O<B!S=6)M:71T
M:6YG(%A-3"!24$,@<F5Q=65S=',*("H*("H@0&-A=&5G;W)Y("`@5V5B(%-E
M<G9I8V5S"B`J($!P86-K86=E("`@(%A-3%]24$,*("H@0&%U=&AO<B`@("`@
M161D($1U;6)I;&P@/&5D9$!U<V5F=6QI;F,N8V]M/@H@*B!`875T:&]R("`@
M("!3=&EG($)A:VME;B`\<W1I9T!P:'`N;F5T/@H@*B!`875T:&]R("`@("!-
M87)T:6X@2F%N<V5N(#QM:D!P:'`N;F5T/@H@*B!`875T:&]R("`@("!$86YI
M96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@
M(#$Y.3DM,C`P,2!%9&0@1'5M8FEL;"P@,C`P,2TR,#`U(%1H92!02%`@1W)O
M=7`*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+C@*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+UA-3%]24$,*("HO"F-L
M87-S(%A-3%]24$-?0VQI96YT(&5X=&5N9',@6$U,7U)00U]"87-E('L*"B`@
M("`O*BH*("`@("`J(%1H92!P871H(&%N9"!N86UE(&]F('1H92!24$,@<V5R
M=F5R('-C<FEP="!Y;W4@=V%N="!T:&4@<F5Q=65S="!T;R!G;R!T;PH@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1P871H(#T@)R<["@H@
M("`@+RHJ"B`@("`@*B!4:&4@;F%M92!O9B!T:&4@<F5M;W1E('-E<G9E<B!T
M;R!C;VYN96-T('1O"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)'-E<G9E<B`]("<G.PH*("`@("\J*@H@("`@("H@5&AE('!R;W1O8V]L
M('1O('5S92!I;B!C;VYT86-T:6YG('1H92!R96UO=&4@<V5R=F5R"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)'!R;W1O8V]L(#T@)VAT
M='`Z+R\G.PH*("`@("\J*@H@("`@("H@5&AE('!O<G0@9F]R(&-O;FYE8W1I
M;F<@=&\@=&AE(')E;6]T92!S97)V97(*("`@("`J"B`@("`@*B!4:&4@9&5F
M875L="!I<R`X,"!F;W(@:'1T<#HO+R!C;VYN96-T:6]N<PH@("`@("H@86YD
M(#0T,R!F;W(@:'1T<',Z+R\@86YD('-S;#HO+R!C;VYN96-T:6]N<RX*("`@
M("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1P;W)T
M(#T@.#`["@H@("`@+RHJ"B`@("`@*B!!('5S97(@;F%M92!F;W(@86-C97-S
M:6YG('1H92!24$,@<V5R=F5R"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@
M0'-E92!834Q?4E!#7T-L:65N=#HZ<V5T0W)E9&5N=&EA;',H*0H@("`@("HO
M"B`@("!V87(@)'5S97)N86UE(#T@)R<["@H@("`@+RHJ"B`@("`@*B!!('!A
M<W-W;W)D(&9O<B!A8V-E<W-I;F<@=&AE(%)00R!S97)V97(*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B!`<V5E(%A-3%]24$-?0VQI96YT.CIS971#<F5D
M96YT:6%L<R@I"B`@("`@*B\*("`@('9A<B`D<&%S<W=O<F0@/2`G)SL*"B`@
M("`O*BH*("`@("`J(%1H92!N86UE(&]F('1H92!P<F]X>2!S97)V97(@=&\@
M=7-E+"!I9B!A;GD*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D<')O>'D@/2`G)SL*"B`@("`O*BH*("`@("`J(%1H92!P<F]T;V-O;"!T
M;R!U<V4@:6X@8V]N=&%C=&EN9R!T:&4@<')O>'D@<V5R=F5R+"!I9B!A;GD*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<')O>'E?<')O
M=&]C;VP@/2`G:'1T<#HO+R<["@H@("`@+RHJ"B`@("`@*B!4:&4@<&]R="!F
M;W(@8V]N;F5C=&EN9R!T;R!T:&4@<')O>'D@<V5R=F5R"B`@("`@*@H@("`@
M("H@5&AE(&1E9F%U;'0@:7,@.#`X,"!F;W(@:'1T<#HO+R!C;VYN96-T:6]N
M<PH@("`@("H@86YD(#0T,R!F;W(@:'1T<',Z+R\@86YD('-S;#HO+R!C;VYN
M96-T:6]N<RX*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@
M("`@=F%R("1P<F]X>5]P;W)T(#T@.#`X,#L*"B`@("`O*BH*("`@("`J($$@
M=7-E<B!N86UE(&9O<B!A8V-E<W-I;F<@=&AE('!R;WAY('-E<G9E<@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1P<F]X>5]U<V5R(#T@
M)R<["@H@("`@+RHJ"B`@("`@*B!!('!A<W-W;W)D(&9O<B!A8V-E<W-I;F<@
M=&AE('!R;WAY('-E<G9E<@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1P<F]X>5]P87-S(#T@)R<["@H@("`@+RHJ"B`@("`@*B!4:&4@
M97)R;W(@;G5M8F5R+"!I9B!A;GD*("`@("`J($!V87(@:6YT96=E<@H@("`@
M("HO"B`@("!V87(@)&5R<FYO(#T@,#L*"B`@("`O*BH*("`@("`J(%1H92!E
M<G)O<B!M97-S86=E+"!I9B!A;GD*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D97)R<W1R(#T@)R<["@H@("`@+RHJ"B`@("`@*B!4:&4@
M8W5R<F5N="!D96)U9R!M;V1E("@Q(#T@;VXL(#`@/2!O9F8I"B`@("`@*B!`
M=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1D96)U9R`](#`["@H@("`@
M+RHJ"B`@("`@*B!4:&4@2%144"!H96%D97)S(&9O<B!T:&4@8W5R<F5N="!R
M97%U97-T+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1H
M96%D97)S(#T@)R<["@H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@;V)J96-T
M)W,@<')O<&5R=&EE<PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1P
M871H("`@("`@("!T:&4@<&%T:"!A;F0@;F%M92!O9B!T:&4@4E!#('-E<G9E
M<B!S8W)I<'0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M>6]U('=A;G0@=&AE(')E<75E<W0@=&\@9V\@=&\*("`@("`J($!P87)A;2!S
M=')I;F<@("1S97)V97(@("`@("!T:&4@55),(&]F('1H92!R96UO=&4@<V5R
M=F5R('1O(&-O;FYE8W0@=&\N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@($EF('1H:7,@<&%R86UE=&5R(&1O97-N)W0@<W!E8VEF>2!A
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('!R;W1O8V]L
M(&%N9"`D<&]R="!I<R`T-#,L('-S;#HO+R!I<PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<W-U;65D+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)'!O<G0@("`@("`@(&$@<&]R="!F;W(@8V]N;F5C=&EN9R!T;R!T
M:&4@<F5M;W1E('-E<G9E<BX*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@1&5F875L=',@=&\@.#`@9F]R(&AT='`Z+R\@8V]N;F5C=&EO
M;G,@86YD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#0T
M,R!F;W(@:'1T<',Z+R\@86YD('-S;#HO+R!C;VYN96-T:6]N<RX*("`@("`J
M($!P87)A;2!S=')I;F<@("1P<F]X>2`@("`@("!T:&4@55),(&]F('1H92!P
M<F]X>2!S97)V97(@=&\@=7-E+"!I9B!A;GDN"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@($EF('1H:7,@<&%R86UE=&5R(&1O97-N)W0@
M<W!E8VEF>2!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('!R;W1O8V]L(&%N9"`D<&]R="!I<R`T-#,L('-S;#HO+R!I<PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<W-U;65D+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)'!R;WAY7W!O<G0@(&$@<&]R="!F;W(@8V]N;F5C
M=&EN9R!T;R!T:&4@<F5M;W1E('-E<G9E<BX*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@1&5F875L=',@=&\@.#`X,"!F;W(@:'1T<#HO
M+R!C;VYN96-T:6]N<R!A;F0*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@-#0S(&9O<B!H='1P<SHO+R!A;F0@<W-L.B\O(&-O;FYE8W1I
M;VYS+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'!R;WAY7W5S97(@(&$@=7-E
M<B!N86UE(&9O<B!A8V-E<W-I;F<@=&AE('!R;WAY('-E<G9E<@H@("`@("H@
M0'!A<F%M('-T<FEN9R`@)'!R;WAY7W!A<W,@(&$@<&%S<W=O<F0@9F]R(&%C
M8V5S<VEN9R!T:&4@<')O>'D@<V5R=F5R"B`@("`@*@H@("`@("H@0')E='5R
M;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(%A-3%]24$-?0VQI96YT*"1P
M871H+"`D<V5R=F5R+"`D<&]R="`](#`L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<')O>'D@/2`G)RP@)'!R;WAY7W!O<G0@/2`P+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!R;WAY7W5S97(@/2`G)RP@)'!R;WAY
M7W!A<W,@/2`G)RD*("`@('L*("`@("`@("`D=&AI<RT^<&%T:"`@("`@("`]
M("1P871H.PH@("`@("`@("1T:&ES+3YP<F]X>5]U<V5R(#T@)'!R;WAY7W5S
M97(["B`@("`@("`@)'1H:7,M/G!R;WAY7W!A<W,@/2`D<')O>'E?<&%S<SL*
M"B`@("`@("`@<')E9U]M871C:"@G0%XH:'1T<#HO+WQH='1P<SHO+WQS<VPZ
M+R\I/R@N*BDD0"<L("1S97)V97(L("1M871C:"D["B`@("`@("`@:68@*"1M
M871C:%LQ72`]/2`G)RD@>PH@("`@("`@("`@("!I9B`H)'!O<G0@/3T@-#0S
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5R=F5R("`@/2`D;6%T8VA;
M,ET["B`@("`@("`@("`@("`@("`D=&AI<RT^<')O=&]C;VP@/2`G<W-L.B\O
M)SL*("`@("`@("`@("`@("`@("1T:&ES+3YP;W)T("`@("`](#0T,SL*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3YS97)V
M97(@/2`D;6%T8VA;,ET["B`@("`@("`@("`@("`@("!I9B`H)'!O<G0I('L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<&]R="`]("1P;W)T.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@
M*"1M871C:%LQ72`]/2`G:'1T<#HO+R<I('L*("`@("`@("`@("`@)'1H:7,M
M/G-E<G9E<B`]("1M871C:%LR73L*("`@("`@("`@("`@:68@*"1P;W)T*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<&]R="`]("1P;W)T.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/G-E
M<G9E<B`@(#T@)&UA=&-H6S)=.PH@("`@("`@("`@("`D=&AI<RT^<')O=&]C
M;VP@/2`G<W-L.B\O)SL*("`@("`@("`@("`@:68@*"1P;W)T*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^<&]R="`]("1P;W)T.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G!O<G0@/2`T-#,["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D<')O>'DI('L*
M("`@("`@("`@("`@<')E9U]M871C:"@G0%XH:'1T<#HO+WQH='1P<SHO+WQS
M<VPZ+R\I/R@N*BDD0"<L("1P<F]X>2P@)&UA=&-H*3L*("`@("`@("`@("`@
M:68@*"1M871C:%LQ72`]/2`G)RD@>PH@("`@("`@("`@("`@("`@:68@*"1P
M<F]X>5]P;W)T(#T](#0T,RD@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YP<F]X>2`@("`@("`@("`]("1M871C:%LR73L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^<')O>'E?<')O=&]C;VP@/2`G<W-L.B\O)SL*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^<')O>'E?<&]R="`@("`@/2`T-#,["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YP<F]X>2`]("1M871C:%LR73L*("`@("`@("`@("`@("`@("`@("!I
M9B`H)'!R;WAY7W!O<G0I('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G!R;WAY7W!O<G0@/2`D<')O>'E?<&]R=#L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF
M("@D;6%T8VA;,5T@/3T@)VAT='`Z+R\G*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^<')O>'D@/2`D;6%T8VA;,ET["B`@("`@("`@("`@("`@("!I9B`H
M)'!R;WAY7W!O<G0I('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<')O
M>'E?<&]R="`]("1P<F]X>5]P;W)T.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G!R;WAY
M("`@("`@("`@(#T@)&UA=&-H6S)=.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/G!R;WAY7W!R;W1O8V]L(#T@)W-S;#HO+R<["B`@("`@("`@("`@("`@("!I
M9B`H)'!R;WAY7W!O<G0I('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M<')O>'E?<&]R="`]("1P<F]X>5]P;W)T.PH@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<')O>'E?<&]R="`]
M(#0T,SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($-H86YG92!T:&4@8W5R<F5N="!D
M96)U9R!M;V1E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`D:6X@('=H97)E
M(#$@/2!O;BP@,"`](&]F9@H@("`@("H*("`@("`J($!R971U<FX@=F]I9`H@
M("`@("HO"B`@("!F=6YC=&EO;B!S971$96)U9R@D:6XI"B`@("!["B`@("`@
M("`@:68@*"1I;BD@>PH@("`@("`@("`@("`D=&AI<RT^9&5B=6<@/2`Q.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YD96)U9R`](#`[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4V5T('5S97)N86UE
M(&%N9"!P87-S=V]R9"!P<F]P97)T:65S(&9O<B!C;VYN96-T:6YG('1O('1H
M92!24$,@<V5R=F5R"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=2`@
M=&AE('5S97(@;F%M90H@("`@("H@0'!A<F%M('-T<FEN9R`D<"`@=&AE('!A
M<W-W;W)D"B`@("`@*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*@H@("`@
M("H@0'-E92!834Q?4E!#7T-L:65N=#HZ)'5S97)N86UE+"!834Q?4E!#7T-L
M:65N=#HZ)'!A<W-W;W)D"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$-R961E
M;G1I86QS*"1U+"`D<"D*("`@('L*("`@("`@("`D=&AI<RT^=7-E<FYA;64@
M/2`D=3L*("`@("`@("`D=&AI<RT^<&%S<W=O<F0@/2`D<#L*("`@('T*"B`@
M("`O*BH*("`@("`J(%1R86YS;6ET('1H92!24$,@<F5Q=65S="!V:6$@2%14
M4"`Q+C`@<')O=&]C;VP*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T("1M
M<V<@("`@("`@=&AE(%A-3%]24$-?365S<V%G92!O8FIE8W0*("`@("`J($!P
M87)A;2!I;G0@("`@)'1I;65O=70@("!H;W<@;6%N>2!S96-O;F1S('1O('=A
M:70@9F]R('1H92!R97%U97-T"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE
M8W0@(&%N(%A-3%]24$-?4F5S<&]N<V4@;V)J96-T+B`@,"!I<R!R971U<FYE
M9"!I9B!A;GD*("`@("`J("`@("`@("`@("`@("`@("`@<')O8FQE;7,@:&%P
M<&5N+@H@("`@("H*("`@("`J($!S964@6$U,7U)00U]-97-S86=E+"!834Q?
M4E!#7T-L:65N=#HZ6$U,7U)00U]#;&EE;G0H*2P*("`@("`J("`@("`@6$U,
M7U)00U]#;&EE;G0Z.G-E=$-R961E;G1I86QS*"D*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5N9"@D;7-G+"`D=&EM96]U="`](#`I"B`@("!["B`@("`@("`@
M:68@*"%I<U]A*"1M<V<L("=834Q?4E!#7TUE<W-A9V4G*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^97)R<W1R(#T@)W-E;F0H*5PG<R`D;7-G('!A<F%M971E
M<B!M=7-T(&)E(&%N)PH@("`@("`@("`@("`@("`@("`@("`@("`@("X@)R!8
M34Q?4E!#7TUE<W-A9V4@;V)J96-T+B<["B`@("`@("`@("`@("1T:&ES+3YR
M86ES945R<F]R*"1T:&ES+3YE<G)S='(L(%A-3%]24$-?15)23U)?4%)/1U)!
M34U)3D<I.PH@("`@("`@("`@("!R971U<FX@,#L*("`@("`@("!]"B`@("`@
M("`@)&US9RT^9&5B=6<@/2`D=&AI<RT^9&5B=6<["B`@("`@("`@<F5T=7)N
M("1T:&ES+3YS96YD4&%Y;&]A9$A45%`Q,"@D;7-G+"`D=&AI<RT^<V5R=F5R
M+"`D=&AI<RT^<&]R="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:6UE;W5T+"`D=&AI<RT^=7-E<FYA;64L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<&%S<W=O
M<F0I.PH@("`@?0H*("`@("\J*@H@("`@("H@5')A;G-M:70@=&AE(%)00R!R
M97%U97-T('9I82!(5%10(#$N,"!P<F]T;V-O;`H@("`@("H*("`@("`J(%)E
M<75E<W1S('-H;W5L9"!B92!S96YT('5S:6YG(%A-3%]24$-?0VQI96YT('-E
M;F0H*2!R871H97(@=&AA;@H@("`@("H@8V%L;&EN9R!T:&ES(&UE=&AO9"!D
M:7)E8W1L>2X*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T("1M<V<@("`@
M("`@=&AE(%A-3%]24$-?365S<V%G92!O8FIE8W0*("`@("`J($!P87)A;2!S
M=')I;F<@)'-E<G9E<B`@("!T:&4@<V5R=F5R('1O('-E;F0@=&AE(')E<75E
M<W0@=&\*("`@("`J($!P87)A;2!I;G0@("`@)'!O<G0@("`@("!T:&4@<V5R
M=F5R('!O<G0@<V5N9"!T:&4@<F5Q=65S="!T;PH@("`@("H@0'!A<F%M(&EN
M="`@("`D=&EM96]U="`@(&AO=R!M86YY('-E8V]N9',@=&\@=V%I="!F;W(@
M=&AE(')E<75E<W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8F5F;W)E(&=I=FEN9R!U<`H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<FYA
M;64@(&$@=7-E<B!N86UE(&9O<B!A8V-E<W-I;F<@=&AE(%)00R!S97)V97(*
M("`@("`J($!P87)A;2!S=')I;F<@)'!A<W-W;W)D("!A('!A<W-W;W)D(&9O
M<B!A8V-E<W-I;F<@=&AE(%)00R!S97)V97(*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&]B:F5C="`@86X@6$U,7U)00U]297-P;VYS92!O8FIE8W0N("`P(&ES
M(')E='5R;F5D(&EF(&%N>0H@("`@("H@("`@("`@("`@("`@("`@("!P<F]B
M;&5M<R!H87!P96XN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*
M("`@("`J($!S964@6$U,7U)00U]#;&EE;G0Z.G-E;F0H*0H@("`@("HO"B`@
M("!F=6YC=&EO;B!S96YD4&%Y;&]A9$A45%`Q,"@D;7-G+"`D<V5R=F5R+"`D
M<&]R="P@)'1I;65O=70@/2`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'5S97)N86UE(#T@)R<L("1P87-S=V]R9"`]("<G*0H@("`@>PH@
M("`@("`@("\J"B`@("`@("`@("H@268@=V4G<F4@=7-I;F<@82!P<F]X>2!O
M<&5N(&$@<V]C:V5T('1O('1H92!P<F]X>2!S97)V97(*("`@("`@("`@*B!I
M;G-T96%D('1O('1H92!X;6PM<G!C('-E<G9E<@H@("`@("`@("`J+PH@("`@
M("`@(&EF("@D=&AI<RT^<')O>'DI('L*("`@("`@("`@("`@:68@*"1T:&ES
M+3YP<F]X>5]P<F]T;V-O;"`]/2`G:'1T<#HO+R<I('L*("`@("`@("`@("`@
M("`@("1P<F]T;V-O;"`]("<G.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)'!R;W1O8V]L(#T@)'1H:7,M/G!R;WAY7W!R;W1O8V]L
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D=&EM96]U="`^(#`I
M('L*("`@("`@("`@("`@("`@("1F<"`]($!F<V]C:V]P96XH)'!R;W1O8V]L
M("X@)'1H:7,M/G!R;WAY+"`D=&AI<RT^<')O>'E?<&]R="P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F5R<FYO+"`D=&AI<RT^
M97)R<W1R+"`D=&EM96]U="D["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D9G`@/2!`9G-O8VMO<&5N*"1P<F]T;V-O;"`N("1T:&ES
M+3YP<F]X>2P@)'1H:7,M/G!R;WAY7W!O<G0L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YE<G)N;RP@)'1H:7,M/F5R<G-T<BD[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I
M9B`H)'1H:7,M/G!R;W1O8V]L(#T]("=H='1P.B\O)RD@>PH@("`@("`@("`@
M("`@("`@)'!R;W1O8V]L(#T@)R<["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D<')O=&]C;VP@/2`D=&AI<RT^<')O=&]C;VP["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1T:6UE;W5T(#X@,"D@>PH@
M("`@("`@("`@("`@("`@)&9P(#T@0&9S;V-K;W!E;B@D<')O=&]C;VP@+B`D
M<V5R=F5R+"`D<&]R="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/F5R<FYO+"`D=&AI<RT^97)R<W1R+"`D=&EM96]U="D["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D9G`@/2!`9G-O
M8VMO<&5N*"1P<F]T;V-O;"`N("1S97)V97(L("1P;W)T+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^97)R;F\L("1T:&ES+3YE
M<G)S='(I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*@H@
M("`@("`@("`J($IU<W0@<F%I<VEN9R!T:&4@97)R;W(@=VET:&]U="!R971U
M<FYI;F<@:70@:7,@<W1R86YG92P*("`@("`@("`@*B!B=70@:V5E<"!I="!H
M97)E(&9O<B!B86-K=V%R9',@8V]M<&%T:6)I;&ET>2X*("`@("`@("`@*B\*
M("`@("`@("!I9B`H(21F<"`F)B`D=&AI<RT^<')O>'DI('L*("`@("`@("`@
M("`@)'1H:7,M/G)A:7-E17)R;W(H)T-O;FYE8W1I;VX@=&\@<')O>'D@<V5R
M=F5R("<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^
M<')O>'D@+B`G.B<@+B`D=&AI<RT^<')O>'E?<&]R=`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`N("<@9F%I;&5D+B`G("X@)'1H:7,M/F5R<G-T
M<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U)00U]%4E)/
M4E]#3TY.14-424].7T9!24Q%1"D["B`@("`@("`@("`@(')E='5R;B`P.PH@
M("`@("`@('T@96QS96EF("@A)&9P*2!["B`@("`@("`@("`@("1T:&ES+3YR
M86ES945R<F]R*"=#;VYN96-T:6]N('1O(%)00R!S97)V97(@)PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`N("1S97)V97(@+B`G.B<@+B`D<&]R
M=`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("<@9F%I;&5D+B`G
M("X@)'1H:7,M/F5R<G-T<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@6$U,7U)00U]%4E)/4E]#3TY.14-424].7T9!24Q%1"D["B`@("`@("`@
M("`@(')E='5R;B`P.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:6UE;W5T
M*2!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%5S:6YG('-O8VME
M=%]S971?=&EM96]U="@I(&)E8V%U<V4@<W1R96%M7W-E=%]T:6UE;W5T*"D*
M("`@("`@("`@("`@("H@=V%S(&EN=')O9'5C960@:6X@-"XS+C`L(&)U="!W
M92!N965D('1O('-U<'!O<G0@-"XR+C`N"B`@("`@("`@("`@("`J+PH@("`@
M("`@("`@("!S;V-K971?<V5T7W1I;65O=70H)&9P+"`D=&EM96]U="D["B`@
M("`@("`@?0H*("`@("`@("`O+R!0<F4M96UP=&EV92!"0R!H86-K<R!F;W(@
M9F]O;',@8V%L;&EN9R!S96YD4&%Y;&]A9$A45%`Q,"@I(&1I<F5C=&QY"B`@
M("`@("`@:68@*"1U<V5R;F%M92`A/2`D=&AI<RT^=7-E<FYA;64I('L*("`@
M("`@("`@("`@)'1H:7,M/G-E=$-R961E;G1I86QS*"1U<V5R;F%M92P@)'!A
M<W-W;W)D*3L*("`@("`@("!]"@H@("`@("`@("\O($]N;'D@8W)E871E('1H
M92!P87EL;V%D(&EF(&ET('=A<R!N;W0@8W)E871E9"!P<F5V:6]U<VQY"B`@
M("`@("`@:68@*&5M<'1Y*"1M<V<M/G!A>6QO860I*2!["B`@("`@("`@("`@
M("1M<V<M/F-R96%T95!A>6QO860H*3L*("`@("`@("!]"B`@("`@("`@)'1H
M:7,M/F-R96%T94AE861E<G,H)&US9RD["@H@("`@("`@("1O<"`@/2`D=&AI
M<RT^:&5A9&5R<R`N(")<<EQN7')<;B(["B`@("`@("`@)&]P("X]("1M<V<M
M/G!A>6QO860["@H@("`@("`@(&EF("@A9G!U=',H)&9P+"`D;W`L('-T<FQE
M;B@D;W`I*2D@>PH@("`@("`@("`@("`D=&AI<RT^97)R<W1R(#T@)U=R:71E
M(&5R<F]R)SL*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@?0H@("`@
M("`@("1R97-P(#T@)&US9RT^<&%R<V5297-P;VYS949I;&4H)&9P*3L*"B`@
M("`@("`@)&UE=&$@/2!S;V-K971?9V5T7W-T871U<R@D9G`I.PH@("`@("`@
M(&EF("@D;65T85LG=&EM961?;W5T)UTI('L*("`@("`@("`@("`@9F-L;W-E
M*"1F<"D["B`@("`@("`@("`@("1T:&ES+3YE<G)S='(@/2`G4E!#('-E<G9E
M<B!D:60@;F]T('-E;F0@<F5S<&]N<V4@8F5F;W)E('1I;65O=70N)SL*("`@
M("`@("`@("`@)'1H:7,M/G)A:7-E17)R;W(H)'1H:7,M/F5R<G-T<BP@6$U,
M7U)00U]%4E)/4E]#3TY.14-424].7T9!24Q%1"D["B`@("`@("`@("`@(')E
M='5R;B`P.PH@("`@("`@('T*"B`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@
M("`@<F5T=7)N("1R97-P.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5T97)M
M:6YE<R!T:&4@2%144"!H96%D97)S(&%N9"!P=71S(&ET(&EN('1H92`D:&5A
M9&5R<R!P<F]P97)T>0H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W0@)&US
M9R`@("`@("!T:&4@6$U,7U)00U]-97-S86=E(&]B:F5C=`H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5%)512!I9B!O:V%Y+"!&04Q312!I9B!T
M:&4@;65S<V%G92!P87EL;V%D(&ES;B=T('-E="X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R;W1E8W1E9`H@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A=&5(
M96%D97)S*"1M<V<I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1M<V<M/G!A
M>6QO860I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"B`@("`@("`@:68@*"1T:&ES+3YP<F]X>2D@>PH@("`@("`@("`@("`D=&AI
M<RT^:&5A9&5R<R`]("=03U-4("<@+B`D=&AI<RT^<')O=&]C;VP@+B`D=&AI
M<RT^<V5R=F5R.PH@("`@("`@("`@("!I9B`H)'1H:7,M/G!R;WAY7W!O<G0I
M('L*("`@("`@("`@("`@("`@("1T:&ES+3YH96%D97)S("X]("<Z)R`N("1T
M:&ES+3YP;W)T.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`D=&AI<RT^:&5A9&5R<R`]("=03U-4("<["B`@("`@("`@?0H@
M("`@("`@("1T:&ES+3YH96%D97)S("X]("1T:&ES+3YP871H+B`B($A45%`O
M,2XP7')<;B(["@H@("`@("`@("1T:&ES+3YH96%D97)S("X](")5<V5R+4%G
M96YT.B!014%2(%A-3%]24$-<<EQN(CL*("`@("`@("`D=&AI<RT^:&5A9&5R
M<R`N/2`G2&]S=#H@)R`N("1T:&ES+3YS97)V97(@+B`B7')<;B(["@H@("`@
M("`@(&EF("@D=&AI<RT^<')O>'D@)B8@)'1H:7,M/G!R;WAY7W5S97(I('L*
M("`@("`@("`@("`@)'1H:7,M/FAE861E<G,@+CT@)U!R;WAY+4%U=&AO<FEZ
M871I;VXZ($)A<VEC("<*("`@("`@("`@("`@("`@("`@("`@+B!B87-E-C1?
M96YC;V1E*"(D=&AI<RT^<')O>'E?=7-E<CHD=&AI<RT^<')O>'E?<&%S<R(I
M"B`@("`@("`@("`@("`@("`@("`@("X@(EQR7&XB.PH@("`@("`@('T*"B`@
M("`@("`@+R\@=&AA;FMS('1O($=R86YT(%)A=7-C:&5R(#QG<F%N=#=`9FER
M<W1W;W)L9"YN970^(&9O<B!T:&ES"B`@("`@("`@:68@*"1T:&ES+3YU<V5R
M;F%M92D@>PH@("`@("`@("`@("`D=&AI<RT^:&5A9&5R<R`N/2`G075T:&]R
M:7IA=&EO;CH@0F%S:6,@)PH@("`@("`@("`@("`@("`@("`@("`N(&)A<V4V
M-%]E;F-O9&4H(B1T:&ES+3YU<V5R;F%M93HD=&AI<RT^<&%S<W=O<F0B*0H@
M("`@("`@("`@("`@("`@("`@("`N(")<<EQN(CL*("`@("`@("!]"@H@("`@
M("`@("1T:&ES+3YH96%D97)S("X](")#;VYT96YT+51Y<&4Z('1E>'0O>&UL
M7')<;B(["B`@("`@("`@)'1H:7,M/FAE861E<G,@+CT@)T-O;G1E;G0M3&5N
M9W1H.B`G("X@<W1R;&5N*"1M<V<M/G!A>6QO860I.PH@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0I]"@HO*BH*("H@5&AE(&UE=&AO9',@86YD('!R;W!E
M<G1I97,@9F]R(&EN=&5R<')E=&EN9R!R97-P;VYS97,@=&\@6$U,(%)00R!R
M97%U97-T<PH@*@H@*B!`8V%T96=O<GD@("!796(@4V5R=FEC97,*("H@0'!A
M8VMA9V4@("`@6$U,7U)00PH@*B!`875T:&]R("`@("!%9&0@1'5M8FEL;"`\
M961D0'5S969U;&EN8RYC;VT^"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N
M(#QS=&EG0'!H<"YN970^"B`J($!A=71H;W(@("`@($UA<G1I;B!*86YS96X@
M/&UJ0'!H<"YN970^"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@
M/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY.2TR,#`Q($5D
M9"!$=6UB:6QL+"`R,#`Q+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`=F5R<VEO
M;B`@("!296QE87-E.B`Q+C0N.`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A
M<BYP:'`N;F5T+W!A8VMA9V4O6$U,7U)00PH@*B\*8VQA<W,@6$U,7U)00U]2
M97-P;VYS92!E>'1E;F1S(%A-3%]24$-?0F%S90I["B`@("!V87(@)'AV.PH@
M("`@=F%R("1F;CL*("`@('9A<B`D9G,["B`@("!V87(@)&AD<G,["@H@("`@
M+RHJ"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@
M6$U,7U)00U]297-P;VYS92@D=F%L+"`D9F-O9&4@/2`P+"`D9G-T<B`]("<G
M*0H@("`@>PH@("`@("`@(&EF("@D9F-O9&4@(3T@,"D@>PH@("`@("`@("`@
M("`D=&AI<RT^9FX@/2`D9F-O9&4["B`@("`@("`@("`@("1T:&ES+3YF<R`]
M(&AT;6QS<&5C:6%L8VAA<G,H)&9S='(I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1T:&ES+3YX=B`]("1V86P["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@0')E='5R;B!I;G0@('1H92!E<G)O<B!C;V1E"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&9A=6QT0V]D92@I"B`@("!["B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3YF;BDI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YF;CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M,#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@=&AE(&5R<F]R('-T<FEN9PH@("`@("HO"B`@("!F=6YC=&EO;B!F
M875L=%-T<FEN9R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YF<SL*
M("`@('T*"B`@("`O*BH*("`@("`J($!R971U<FX@;6EX960@('1H92!V86QU
M90H@("`@("HO"B`@("!F=6YC=&EO;B!V86QU92@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3YX=CL*("`@('T*"B`@("`O*BH*("`@("`J($!R971U
M<FX@<W1R:6YG("!T:&4@97)R;W(@;65S<V%G92!I;B!834P@9F]R;6%T"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E<FEA;&EZ92@I"B`@("!["B`@("`@("`@
M)')S(#T@(CQM971H;V1297-P;VYS93Y<;B(["B`@("`@("`@:68@*"1T:&ES
M+3YF;BD@>PH@("`@("`@("`@("`D<G,@+CT@(CQF875L=#X*("`\=F%L=64^
M"B`@("`\<W1R=6-T/@H@("`@("`\;65M8F5R/@H@("`@("`@(#QN86UE/F9A
M=6QT0V]D93PO;F%M93X*("`@("`@("`\=F%L=64^/&EN=#XB("X@)'1H:7,M
M/F9N("X@(CPO:6YT/CPO=F%L=64^"B`@("`@(#PO;65M8F5R/@H@("`@("`\
M;65M8F5R/@H@("`@("`@(#QN86UE/F9A=6QT4W1R:6YG/"]N86UE/@H@("`@
M("`@(#QV86QU93X\<W1R:6YG/B(@+B`D=&AI<RT^9G,@+B`B/"]S=')I;F<^
M/"]V86QU93X*("`@("`@/"]M96UB97(^"B`@("`\+W-T<G5C=#X*("`\+W9A
M;'5E/@H\+V9A=6QT/B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)')S("X]("(\<&%R86US/EQN/'!A<F%M/EQN(B`N("1T:&ES+3YX=BT^<V5R
M:6%L:7IE*"D@+@H@("`@("`@("(\+W!A<F%M/EQN/"]P87)A;7,^(CL*("`@
M("`@("!]"B`@("`@("`@)')S("X](")<;CPO;65T:&]D4F5S<&]N<V4^(CL*
M("`@("`@("!R971U<FX@)')S.PH@("`@?0I]"@HO*BH*("H@5&AE(&UE=&AO
M9',@86YD('!R;W!E<G1I97,@9F]R(&-O;7!O<VEN9R!834P@4E!#(&UE<W-A
M9V5S"B`J"B`J($!C871E9V]R>2`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G
M92`@("!834Q?4E!#"B`J($!A=71H;W(@("`@($5D9"!$=6UB:6QL(#QE9&1`
M=7-E9G5L:6YC+F-O;3X*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-T
M:6=`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@36%R=&EN($IA;G-E;B`\;6I`
M<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N
M:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DY+3(P,#$@161D($1U
M;6)I;&PL(#(P,#$M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!V97)S:6]N("`@
M(%)E;&5A<V4Z(#$N-"XX"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H
M<"YN970O<&%C:V%G92]834Q?4E!#"B`J+PIC;&%S<R!834Q?4E!#7TUE<W-A
M9V4@97AT96YD<R!834Q?4E!#7T)A<V4*>PH@("`@+RHJ"B`@("`@*B!4:&4@
M8W5R<F5N="!D96)U9R!M;V1E("@Q(#T@;VXL(#`@/2!O9F8I"B`@("`@*B!`
M=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1D96)U9R`](#`["@H@("`@
M+RHJ"B`@("`@*B!4:&4@96YC;V1I;F<@=&\@8F4@=7-E9"!F;W(@;W5T9V]I
M;F<@;65S<V%G97,*("`@("`J"B`@("`@*B!$969A=6QT<R!T;R!T:&4@=F%L
M=64@;V8@/'9A<CXD1TQ/0D%,4ULG6$U,7U)00U]D969E;F-O9&EN9R==/"]V
M87(^"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J($!S964@6$U,
M7U)00U]-97-S86=E.CIS971396YD16YC;V1I;F<H*2P*("`@("`J("`@("`@
M)$=,3T)!3%-;)UA-3%]24$-?9&5F96YC;V1I;F<G72P@6$U,7U)00U]-97-S
M86=E.CIX;6Q?:&5A9&5R*"D*("`@("`J+PH@("`@=F%R("1S96YD7V5N8V]D
M:6YG(#T@)R<["@H@("`@+RHJ"B`@("`@*B!4:&4@;65T:&]D('!R97-E;G1L
M>2!B96EN9R!E=F%L=6%T960*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D;65T:&]D;F%M92`]("<G.PH*("`@("\J*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)'!A<F%M<R`](&%R<F%Y*"D["@H@
M("`@+RHJ"B`@("`@*B!4:&4@6$U,(&UE<W-A9V4@8F5I;F<@9V5N97)A=&5D
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)'!A>6QO860@
M/2`G)SL*"B`@("`O*BH*("`@("`J(%-H;W5L9"!E>'1R82!L:6YE(&)R96%K
M<R!B92!R96UO=F5D(&9R;VT@=&AE('!A>6QO860_"B`@("`@*B!`<VEN8V4@
M4')O<&5R='D@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C8*("`@("`J
M($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)')E;6]V95]E>'1R85]L
M:6YE<R`]('1R=64["@H@("`@+RHJ"B`@("`@*B!4:&4@6$U,(')E<W!O;G-E
M(&9R;VT@=&AE(')E;6]T92!S97)V97(*("`@("`J($!S:6YC92!0<F]P97)T
M>2!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N-@H@("`@("H@0'9A<B!S
M=')I;F<*("`@("`J+PH@("`@=F%R("1R97-P;VYS95]P87EL;V%D(#T@)R<[
M"@H*("`@("\J*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%A-3%]24$-?365S<V%G92@D;65T:"P@)'!A<G,@/2`P*0H@("`@
M>PH@("`@("`@("1T:&ES+3YM971H;V1N86UE(#T@)&UE=&@["B`@("`@("`@
M:68@*&ES7V%R<F%Y*"1P87)S*2`F)B!S:7IE;V8H)'!A<G,I(#X@,"D@>PH@
M("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'!A<G,I.R`D
M:2LK*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^861D4&%R86TH)'!A<G-;
M)&E=*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%!R;V1U8V5S('1H92!834P@9&5C;&%R871I;VX@:6YC;'5D:6YG
M('1H92!E;F-O9&EN9R!A='1R:6)U=&4*("`@("`J"B`@("`@*B!4:&4@96YC
M;V1I;F<@:7,@9&5T97)M:6YE9"!B>2!T:&ES(&-L87-S)R`\=F%R/B1S96YD
M7V5N8V]D:6YG/"]V87(^"B`@("`@*B!P<F]P97)T>2X@($EF('1H92`\=F%R
M/B1S96YD7V5N8V]D:6YG/"]V87(^('!R;W!E<G1Y(&ES(&YO="!S970L('5S
M90H@("`@("H@/'9A<CXD1TQ/0D%,4ULG6$U,7U)00U]D969E;F-O9&EN9R==
M/"]V87(^+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@6$U,
M(&1E8VQA<F%T:6]N(&%N9"`\;65T:&]D0V%L;#X@96QE;65N=`H@("`@("H*
M("`@("`J($!S964@6$U,7U)00U]-97-S86=E.CIS971396YD16YC;V1I;F<H
M*2P*("`@("`J("`@("`@6$U,7U)00U]-97-S86=E.CHD<V5N9%]E;F-O9&EN
M9RP@)$=,3T)!3%-;)UA-3%]24$-?9&5F96YC;V1I;F<G70H@("`@("HO"B`@
M("!F=6YC=&EO;B!X;6Q?:&5A9&5R*"D*("`@('L*("`@("`@("!G;&]B86P@
M)%A-3%]24$-?9&5F96YC;V1I;F<["@H@("`@("`@(&EF("@A)'1H:7,M/G-E
M;F1?96YC;V1I;F<I('L*("`@("`@("`@("`@)'1H:7,M/G-E;F1?96YC;V1I
M;F<@/2`D6$U,7U)00U]D969E;F-O9&EN9SL*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("<\/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2(G("X@)'1H
M:7,M/G-E;F1?96YC;V1I;F<@+B`G(C\^)PH@("`@("`@("`@("`@("`N(")<
M;CQM971H;V1#86QL/EQN(CL*("`@('T*"B`@("`O*BH*("`@("`J($!R971U
M<FX@<W1R:6YG("!T:&4@8VQO<VEN9R`\+VUE=&AO9$-A;&P^('1A9PH@("`@
M("HO"B`@("!F=6YC=&EO;B!X;6Q?9F]O=&5R*"D*("`@('L*("`@("`@("!R
M971U<FX@(CPO;65T:&]D0V%L;#Y<;B(["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!&:6QL<R!T:&4@6$U,7U)00U]-97-S86=E.CHD<&%Y;&]A9"!P<F]P97)T
M>0H@("`@("H*("`@("`J(%!A<G0@;V8@=&AE('!R;V-E<W,@;6%K97,@<W5R
M92!A;&P@;&EN92!E;F1I;F=S(&%R92!I;B!$3U,@9F]R;6%T"B`@("`@*B`H
M0U),1BDL('=H:6-H(&ES('!R;V)A8FQY(')E<75I<F5D(&)Y('-P96-I9FEC
M871I;VYS+@H@("`@("H*("`@("`J($!R971U<FX@=F]I9`H@("`@("H*("`@
M("`J($!U<V5S(%A-3%]24$-?365S<V%G93HZ>&UL7VAE861E<B@I+"!834Q?
M4E!#7TUE<W-A9V4Z.GAM;%]F;V]T97(H*0H@("`@("HO"B`@("!F=6YC=&EO
M;B!C<F5A=&5087EL;V%D*"D*("`@('L*("`@("`@("`D=&AI<RT^<&%Y;&]A
M9"`]("1T:&ES+3YX;6Q?:&5A9&5R*"D["B`@("`@("`@)'1H:7,M/G!A>6QO
M860@+CT@)SQM971H;V1.86UE/B<@+B`D=&AI<RT^;65T:&]D;F%M92`N("(\
M+VUE=&AO9$YA;64^7&XB.PH@("`@("`@("1T:&ES+3YP87EL;V%D("X]("(\
M<&%R86US/EQN(CL*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H
M)'1H:7,M/G!A<F%M<RD[("1I*RLI('L*("`@("`@("`@("`@)'`@/2`D=&AI
M<RT^<&%R86US6R1I73L*("`@("`@("`@("`@)'1H:7,M/G!A>6QO860@+CT@
M(CQP87)A;3Y<;B(@+B`D<"T^<V5R:6%L:7IE*"D@+B`B/"]P87)A;3Y<;B([
M"B`@("`@("`@?0H@("`@("`@("1T:&ES+3YP87EL;V%D("X]("(\+W!A<F%M
M<SY<;B(["B`@("`@("`@)'1H:7,M/G!A>6QO860@+CT@)'1H:7,M/GAM;%]F
M;V]T97(H*3L*("`@("`@("!I9B`H)'1H:7,M/G)E;6]V95]E>'1R85]L:6YE
M<RD@>PH@("`@("`@("`@("`D=&AI<RT^<&%Y;&]A9"`](&5R96=?<F5P;&%C
M92@B6UQR7&Y=*R(L(")<<EQN(BP@)'1H:7,M/G!A>6QO860I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YP87EL;V%D(#T@97)E9U]R
M97!L86-E*")<<EQN?%QN?%QR?%QN7'(B+"`B7')<;B(L("1T:&ES+3YP87EL
M;V%D*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@=&AE(&YA;64@;V8@=&AE(&UE=&AO9`H@("`@("HO"B`@("!F
M=6YC=&EO;B!M971H;V0H)&UE=&@@/2`G)RD*("`@('L*("`@("`@("!I9B`H
M)&UE=&@@(3T@)R<I('L*("`@("`@("`@("`@)'1H:7,M/FUE=&AO9&YA;64@
M/2`D;65T:#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YM971H
M;V1N86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@0')E='5R;B!S=')I;F<@
M('1H92!P87EL;V%D"B`@("`@*B\*("`@(&9U;F-T:6]N('-E<FEA;&EZ92@I
M"B`@("!["B`@("`@("`@)'1H:7,M/F-R96%T95!A>6QO860H*3L*("`@("`@
M("!R971U<FX@)'1H:7,M/G!A>6QO860["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@861D4&%R86TH
M)'!A<BD*("`@('L*("`@("`@("`D=&AI<RT^<&%R86US6UT@/2`D<&%R.PH@
M("`@?0H*("`@("\J*@H@("`@("H@3V)T86EN<R!A;B!834Q?4E!#7U9A;'5E
M(&]B:F5C="!F;W(@=&AE(&=I=F5N('!A<F%M971E<@H@("`@("H*("`@("`J
M($!P87)A;2!I;G0@)&D@('1H92!I;F1E>"!N=6UB97(@;V8@=&AE('!A<F%M
M971E<B!T;R!O8G1A:6X*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@
M=&AE(%A-3%]24$-?5F%L=64@;V)J96-T+@H@("`@("H@("`@("`@("`@("`@
M("`@("!)9B!T:&4@<&%R86UE=&5R(&1O97-N)W0@97AI<W0L(&%N(%A-3%]2
M4$-?4F5S<&]N<V4@;V)J96-T+@H@("`@("H*("`@("`J($!S:6YC92!2971U
M<FYS(%A-3%]24$-?4F5S<&]N<V4@;V)J96-T(&]N(&5R<F]R('-I;F-E(%)E
M;&5A<V4@,2XS+C`*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%R86TH)&DI
M"B`@("!["B`@("`@("`@9VQO8F%L("1834Q?4E!#7V5R<BP@)%A-3%]24$-?
M<W1R.PH*("`@("`@("!I9B`H:7-S970H)'1H:7,M/G!A<F%M<ULD:5TI*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<&%R86US6R1I73L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^<F%I<V5%<G)O<B@G5&AE
M('-U8FUI='1E9"!R97%U97-T(&1I9"!N;W0@8V]N=&%I;B!T:&ES('!A<F%M
M971E<B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]24$-?
M15)23U)?24Y#3U)214-47U!!4D%-4RD["B`@("`@("`@("`@(')E='5R;B!N
M97<@6$U,7U)00U]297-P;VYS92@P+"`D6$U,7U)00U]E<G);)VEN8V]R<F5C
M=%]P87)A;7,G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1834Q?4E!#7W-T<ELG:6YC;W)R96-T7W!A<F%M<R==*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE
M(&YU;6)E<B!O9B!P87)A;65T97)S"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$YU;5!A<F%M<R@I"B`@("!["B`@("`@("`@<F5T=7)N('-I>F5O9B@D=&AI
M<RT^<&%R86US*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(%A-
M3"!D96-L87)A=&EO;B=S(&5N8V]D:6YG(&%T=')I8G5T90H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'1Y<&4@('1H92!E;F-O9&EN9R!T>7!E("A)
M4T\M.#@U.2TQ+"!55$8M."!O<B!54RU!4T-)22D*("`@("`J"B`@("`@*B!`
M<F5T=7)N('9O:60*("`@("`J"B`@("`@*B!`<V5E(%A-3%]24$-?365S<V%G
M93HZ)'-E;F1?96YC;V1I;F<L(%A-3%]24$-?365S<V%G93HZ>&UL7VAE861E
M<B@I"B`@("`@*B!`<VEN8V4@365T:&]D(&%V86EL86)L92!S:6YC92!296QE
M87-E(#$N,BXP"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%-E;F1%;F-O9&EN
M9R@D='EP92D*("`@('L*("`@("`@("`D=&AI<RT^<V5N9%]E;F-O9&EN9R`]
M("1T>7!E.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE('1H92!8
M34PG<R!E;F-O9&EN9R!V:6$@=&AE(&5N8V]D:6YG(&%T=')I8G5T90H@("`@
M("H@:6X@=&AE(%A-3"!D96-L87)A=&EO;@H@("`@("H*("`@("`J($EF('1H
M92!E;F-O9&EN9R!P87)A;65T97(@:7,@;F]T('-E="!O<B!I<R!N;W0@25-/
M+3@X-3DM,2P@551&+3@*("`@("`J(&]R(%53+4%30TE)+"`D6$U,7U)00U]D
M969E;F-O9&EN9R!W:6QL(&)E(')E='5R;F5D+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&1A=&$@('1H92!834P@=&AA="!W:6QL(&)E('!A<G-E
M9`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@96YC;V1I;F<@
M=&\@8F4@=7-E9`H@("`@("H*("`@("`J($!L:6YK("`@:'1T<#HO+W!H<"YN
M970O>&UL7W!A<G-E<E]C<F5A=&4*("`@("`J($!S:6YC92`@365T:&]D(&%V
M86EL86)L92!S:6YC92!296QE87-E(#$N,BXP"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$5N8V]D:6YG*"1D871A*0H@("`@>PH@("`@("`@(&=L;V)A;"`D
M6$U,7U)00U]D969E;F-O9&EN9SL*"B`@("`@("`@:68@*'!R96=?;6%T8V@H
M)R\\7#]X;6Q;7CY=*EQS*F5N8V]D:6YG7',J/5QS*EM<)R)=*%M>(EPG72HI
M6UPG(ETO:2<L"B`@("`@("`@("`@("`@("`@("`@("`@)&1A=&$L("1M871C
M:"DI"B`@("`@("`@>PH@("`@("`@("`@("`D;6%T8VA;,5T@/2!T<FEM*'-T
M<G1O=7!P97(H)&UA=&-H6S%=*2D["B`@("`@("`@("`@('-W:71C:"`H)&UA
M=&-H6S%=*2!["B`@("`@("`@("`@("`@("!C87-E("=)4T\M.#@U.2TQ)SH*
M("`@("`@("`@("`@("`@(&-A<V4@)U541BTX)SH*("`@("`@("`@("`@("`@
M(&-A<V4@)U53+4%30TE))SH*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)&UA=&-H6S%=.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1834Q?4E!#7V1E9F5N8V]D:6YG.PH@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1834Q?4E!#7V1E9F5N8V]D
M:6YG.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($!R971U<FX@
M;V)J96-T("!A(&YE=R!834Q?4E!#7U)E<W!O;G-E(&]B:F5C=`H@("`@("HO
M"B`@("!F=6YC=&EO;B!P87)S95)E<W!O;G-E1FEL92@D9G`I"B`@("!["B`@
M("`@("`@)&EP9"`]("<G.PH@("`@("`@('=H:6QE("@D9&%T82`]($!F<F5A
M9"@D9G`L(#@Q.3(I*2!["B`@("`@("`@("`@("1I<&0@+CT@)&1A=&$["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^<&%R<V5297-P;VYS92@D
M:7!D*3L*("`@('T*"B`@("`O*BH*("`@("`J($!R971U<FX@;V)J96-T("!A
M(&YE=R!834Q?4E!#7U)E<W!O;G-E(&]B:F5C=`H@("`@("HO"B`@("!F=6YC
M=&EO;B!P87)S95)E<W!O;G-E*"1D871A(#T@)R<I"B`@("!["B`@("`@("`@
M9VQO8F%L("1834Q?4E!#7WAH+"`D6$U,7U)00U]E<G(L("1834Q?4E!#7W-T
M<BP@)%A-3%]24$-?9&5F96YC;V1I;F<["@H@("`@("`@("1E;F-O9&EN9R`]
M("1T:&ES+3YG971%;F-O9&EN9R@D9&%T82D["B`@("`@("`@)'!A<G-E<E]R
M97-O=7)C92`]('AM;%]P87)S97)?8W)E871E*"1E;F-O9&EN9RD["B`@("`@
M("`@)'!A<G-E<B`]("AI;G0I("1P87)S97)?<F5S;W5R8V4["@H@("`@("`@
M("1834Q?4E!#7WAH(#T@87)R87DH*3L*("`@("`@("`D6$U,7U)00U]X:%LD
M<&%R<V5R72`](&%R<F%Y*"D["@H@("`@("`@("1834Q?4E!#7WAH6R1P87)S
M97)=6R=C;2==(#T@,#L*("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG
M:7-F)UT@/2`P.PH@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=A8R==
M(#T@)R<["B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W%T)UT@/2`G
M)SL*("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG<W1A8VLG72`](&%R
M<F%Y*"D["B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9A;'5E<W1A
M8VLG72`](&%R<F%Y*"D["@H@("`@("`@('AM;%]P87)S97)?<V5T7V]P=&EO
M;B@D<&%R<V5R7W)E<V]U<F-E+"!834Q?3U!424].7T-!4T5?1D],1$E.1RP@
M=')U92D["B`@("`@("`@>&UL7W-E=%]E;&5M96YT7VAA;F1L97(H)'!A<G-E
M<E]R97-O=7)C92P@)UA-3%]24$-?<V4G+"`G6$U,7U)00U]E92<I.PH@("`@
M("`@('AM;%]S971?8VAA<F%C=&5R7V1A=&%?:&%N9&QE<B@D<&%R<V5R7W)E
M<V]U<F-E+"`G6$U,7U)00U]C9"<I.PH*("`@("`@("`D:&1R9FYD(#T@,#L*
M("`@("`@("!I9B`H)'1H:7,M/F1E8G5G*2!["B`@("`@("`@("`@('!R:6YT
M(")<;CQP<F4^+2TM1T]4+2TM7&XB.PH@("`@("`@("`@("!P<FEN="!I<W-E
M="@D7U-%4E9%4ELG4T525D527U!23U1/0T],)UTI(#\@:'1M;'-P96-I86QC
M:&%R<R@D9&%T82D@.B`D9&%T83L*("`@("`@("`@("`@<')I;G0@(EQN+2TM
M14Y$+2TM/"]P<F4^7&XB.PH@("`@("`@('T*"B`@("`@("`@+R\@4V5E(&EF
M(')E<W!O;G-E(&ES(&$@,C`P(&]R(&$@,3`P('1H96X@82`R,#`L(&5L<V4@
M<F%I<V4@97)R;W(N"B`@("`@("`@+R\@0G5T(&]N;'D@9&\@=&AI<R!I9B!W
M92=R92!U<VEN9R!T:&4@2%144"!P<F]T;V-O;"X*("`@("`@("!I9B`H97)E
M9R@G7DA45%`G+"`D9&%T82D@)B8*("`@("`@("`@("`@(65R96<H)UY(5%10
M+ULP+3E<+ETK(#(P,"`G+"`D9&%T82D@)B8*("`@("`@("`@("`@(7!R96=?
M;6%T8V@H)T!>2%144"];,"TY7"Y=*R`Q,%LP+3E=*%M!+5IA+7H@72LI/UM<
M<EQN72M(5%10+ULP+3E<+ETK(#(P,$`G+"`D9&%T82DI"B`@("`@("`@>PH@
M("`@("`@("`@("`@("`@)&5R<G-T<B`]('-U8G-T<B@D9&%T82P@,"P@<W1R
M<&]S*"1D871A+"`B7&XB*2`M(#$I.PH@("`@("`@("`@("`@("`@97)R;W)?
M;&]G*"=(5%10(&5R<F]R+"!G;W0@<F5S<&]N<V4Z("<@+B`D97)R<W1R*3L*
M("`@("`@("`@("`@("`@("1R(#T@;F5W(%A-3%]24$-?4F5S<&]N<V4H,"P@
M)%A-3%]24$-?97)R6R=H='1P7V5R<F]R)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1834Q?4E!#7W-T<ELG:'1T<%]E
M<G)O<B==("X@)R`H)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1E<G)S='(@+B`G*2<I.PH@("`@("`@("`@("`@("`@
M>&UL7W!A<G-E<E]F<F5E*"1P87)S97)?<F5S;W5R8V4I.PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1R.PH@("`@("`@('T*"B`@("`@("`@+R\@9V]T=&$@
M9V5T(')I9"!O9B!H96%D97)S(&AE<F4*("`@("`@("!I9B`H(21H9')F;F0@
M)B8@*"1B<G!O<R`]('-T<G!O<R@D9&%T82PB7')<;EQR7&XB*2DI('L*("`@
M("`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)VAA)UT@/2!S=6)S='(H
M)&1A=&$L(#`L("1B<G!O<RD["B`@("`@("`@("`@("1D871A(#T@<W5B<W1R
M*"1D871A+"`D8G)P;W,@*R`T*3L*("`@("`@("`@("`@)&AD<F9N9"`](#$[
M"B`@("`@("`@?0H*("`@("`@("`O*@H@("`@("`@("`J(&)E('1O;&5R86YT
M(&]F(&IU;FL@869T97(@;65T:&]D4F5S<&]N<V4*("`@("`@("`@*B`H92YG
M+B!J879A<V-R:7!T(&%U=&]M871I8V%L;'D@:6YS97)T960@8GD@9G)E92!H
M;W-T<RD*("`@("`@("`@*B!T:&%N:W,@=&\@3'5C82!-87)I86YO(#QL=6-A
M+FUA<FEA;F]`96UA:6PN:70^"B`@("`@("`@("HO"B`@("`@("`@)&1A=&$@
M/2!S=6)S='(H)&1A=&$L(#`L('-T<G!O<R@D9&%T82P@(CPO;65T:&]D4F5S
M<&]N<V4^(BD@*R`Q-RD["B`@("`@("`@)'1H:7,M/G)E<W!O;G-E7W!A>6QO
M860@/2`D9&%T83L*"B`@("`@("`@:68@*"%X;6Q?<&%R<V4H)'!A<G-E<E]R
M97-O=7)C92P@)&1A=&$L('-I>F5O9B@D9&%T82DI*2!["B`@("`@("`@("`@
M("\O('1H86YK<R!T;R!0971E<B!+;V-K<R`\<&5T97(N:V]C:W-`8F%Y9V%T
M92YC;VT^"B`@("`@("`@("`@(&EF("AX;6Q?9V5T7V-U<G)E;G1?;&EN95]N
M=6UB97(H)'!A<G-E<E]R97-O=7)C92D@/3T@,2D@>PH@("`@("`@("`@("`@
M("`@)&5R<G-T<B`]("=834P@97)R;W(@870@;&EN92`Q+"!C:&5C:R!54DPG
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&5R<G-T
M<B`]('-P<FEN=&8H)UA-3"!E<G)O<CH@)7,@870@;&EN92`E9"<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!X;6Q?97)R;W)?<W1R:6YG
M*'AM;%]G971?97)R;W)?8V]D92@D<&%R<V5R7W)E<V]U<F-E*2DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!X;6Q?9V5T7V-U<G)E;G1?
M;&EN95]N=6UB97(H)'!A<G-E<E]R97-O=7)C92DI.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&5R<F]R7VQO9R@D97)R<W1R*3L*("`@("`@("`@("`@
M)'(@/2!N97<@6$U,7U)00U]297-P;VYS92@P+"`D6$U,7U)00U]E<G);)VEN
M=F%L:61?<F5T=7)N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)%A-3%]24$-?<W1R6R=I;G9A;&ED7W)E='5R;B==*3L*("`@
M("`@("`@("`@>&UL7W!A<G-E<E]F<F5E*"1P87)S97)?<F5S;W5R8V4I.PH@
M("`@("`@("`@("!R971U<FX@)'(["B`@("`@("`@?0H*("`@("`@("!X;6Q?
M<&%R<V5R7V9R964H)'!A<G-E<E]R97-O=7)C92D["@H@("`@("`@(&EF("@D
M=&AI<RT^9&5B=6<I('L*("`@("`@("`@("`@<')I;G0@(EQN/'!R93XM+2U0
M05)3140M+2U<;B(["B`@("`@("`@("`@('9A<E]D=6UP*"1834Q?4E!#7WAH
M6R1P87)S97)=6R=V86QU92==*3L*("`@("`@("`@("`@<')I;G0@(BTM+45.
M1"TM+3PO<')E/EQN(CL*("`@("`@("!]"@H@("`@("`@(&EF("@D6$U,7U)0
M0U]X:%LD<&%R<V5R75LG:7-F)UT@/B`Q*2!["B`@("`@("`@("`@("1R(#T@
M;F5W(%A-3%]24$-?4F5S<&]N<V4H,"P@)%A-3%]24$-?97)R6R=I;G9A;&ED
M7W)E='5R;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1834Q?4E!#7W-T<ELG:6YV86QI9%]R971U<FXG72XG("<N)%A-3%]2
M4$-?>&A;)'!A<G-E<EU;)VES9E]R96%S;VXG72D["B`@("`@("`@?2!E;'-E
M:68@*"%I<U]O8FIE8W0H)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9A;'5E)UTI
M*2!["B`@("`@("`@("`@("\O('1H96X@<V]M971H:6YG(&]D9"!H87,@:&%P
M<&5N960*("`@("`@("`@("`@+R\@86YD(&ET)W,@=&EM92!T;R!G96YE<F%T
M92!A(&-L:65N="!S:61E(&5R<F]R"B`@("`@("`@("`@("\O(&EN9&EC871I
M;F<@<V]M971H:6YG(&]D9"!W96YT(&]N"B`@("`@("`@("`@("1R(#T@;F5W
M(%A-3%]24$-?4F5S<&]N<V4H,"P@)%A-3%]24$-?97)R6R=I;G9A;&ED7W)E
M='5R;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1834Q?4E!#7W-T<ELG:6YV86QI9%]R971U<FXG72D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'8@/2`D6$U,7U)00U]X:%LD<&%R<V5R75LG
M=F%L=64G73L*("`@("`@("`@("`@)&%L;$]+/3$["B`@("`@("`@("`@(&EF
M("@D6$U,7U)00U]X:%LD<&%R<V5R75LG:7-F)UTI('L*("`@("`@("`@("`@
M("`@("1F(#T@)'8M/G-T<G5C=&UE;2@G9F%U;'1#;V1E)RD["B`@("`@("`@
M("`@("`@("`D9G,@/2`D=BT^<W1R=6-T;65M*"=F875L=%-T<FEN9R<I.PH@
M("`@("`@("`@("`@("`@)'(@/2!N97<@6$U,7U)00U]297-P;VYS92@D=BP@
M)&8M/G-C86QA<G9A;"@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9G,M/G-C86QA<G9A;"@I*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1R(#T@;F5W(%A-3%]24$-?4F5S
M<&]N<V4H)'8I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1R
M+3YH9')S(#T@<W!L:70H(EQR/UQN(BP@)%A-3%]24$-?>&A;)'!A<G-E<EU;
M)VAA)UU;,5TI.PH@("`@("`@(')E='5R;B`D<CL*("`@('T*?0H*+RHJ"B`J
M(%1H92!M971H;V1S(&%N9"!P<F]P97)T:65S('1H870@<F5P<F5S96YT(&1A
M=&$@:6X@6$U,(%)00R!F;W)M870*("H*("H@0&-A=&5G;W)Y("`@5V5B(%-E
M<G9I8V5S"B`J($!P86-K86=E("`@(%A-3%]24$,*("H@0&%U=&AO<B`@("`@
M161D($1U;6)I;&P@/&5D9$!U<V5F=6QI;F,N8V]M/@H@*B!`875T:&]R("`@
M("!3=&EG($)A:VME;B`\<W1I9T!P:'`N;F5T/@H@*B!`875T:&]R("`@("!-
M87)T:6X@2F%N<V5N(#QM:D!P:'`N;F5T/@H@*B!`875T:&]R("`@("!$86YI
M96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@
M(#$Y.3DM,C`P,2!%9&0@1'5M8FEL;"P@,C`P,2TR,#`U(%1H92!02%`@1W)O
M=7`*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+C@*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+UA-3%]24$,*("HO"F-L
M87-S(%A-3%]24$-?5F%L=64@97AT96YD<R!834Q?4E!#7T)A<V4*>PH@("`@
M=F%R("1M92`](&%R<F%Y*"D["B`@("!V87(@)&UY='EP92`](#`["@H@("`@
M+RHJ"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@
M6$U,7U)00U]686QU92@D=F%L(#T@+3$L("1T>7!E(#T@)R<I"B`@("!["B`@
M("`@("`@)'1H:7,M/FUE(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^;7ET
M>7!E(#T@,#L*("`@("`@("!I9B`H)'9A;"`A/2`M,2!\?"`D='EP92`A/2`G
M)RD@>PH@("`@("`@("`@("!I9B`H)'1Y<&4@/3T@)R<I('L*("`@("`@("`@
M("`@("`@("1T>7!E(#T@)W-T<FEN9R<["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*"%A<G)A>5]K97E?97AI<W1S*"1T>7!E+"`D1TQ/0D%,4ULG
M6$U,7U)00U]4>7!E<R==*2D@>PH@("`@("`@("`@("`@("`@+R\@6%A8"B`@
M("`@("`@("`@("`@("`O+R!N965D('-O;64@=V%Y('1O(')E<&]R="!T:&ES
M(&5R<F]R"B`@("`@("`@("`@('T@96QS96EF("@D1TQ/0D%,4ULG6$U,7U)0
M0U]4>7!E<R==6R1T>7!E72`]/2`Q*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^861D4V-A;&%R*"1V86PL("1T>7!E*3L*("`@("`@("`@("`@?2!E;'-E
M:68@*"1'3$]"04Q36R=834Q?4E!#7U1Y<&5S)UU;)'1Y<&5=(#T](#(I('L*
M("`@("`@("`@("`@("`@("1T:&ES+3YA9&1!<G)A>2@D=F%L*3L*("`@("`@
M("`@("`@?2!E;'-E:68@*"1'3$]"04Q36R=834Q?4E!#7U1Y<&5S)UU;)'1Y
M<&5=(#T](#,I('L*("`@("`@("`@("`@("`@("1T:&ES+3YA9&13=')U8W0H
M)'9A;"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!`<F5T=7)N(&EN="`@<F5T=7)N<R`Q(&EF('-U8V-E<W-F=6P@
M;W(@,"!I9B!T:&5R92!A<F4@<')O8FQE;7,*("`@("`J+PH@("`@9G5N8W1I
M;VX@861D4V-A;&%R*"1V86PL("1T>7!E(#T@)W-T<FEN9R<I"B`@("!["B`@
M("`@("`@:68@*"1T:&ES+3YM>71Y<&4@/3T@,2D@>PH@("`@("`@("`@("`D
M=&AI<RT^<F%I<V5%<G)O<B@G4V-A;&%R(&-A;B!H879E(&]N;'D@;VYE('9A
M;'5E)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U)00U]%
M4E)/4E])3E9!3$E$7U194$4I.PH@("`@("`@("`@("!R971U<FX@,#L*("`@
M("`@("!]"B`@("`@("`@)'1Y<&5O9B`]("1'3$]"04Q36R=834Q?4E!#7U1Y
M<&5S)UU;)'1Y<&5=.PH@("`@("`@(&EF("@D='EP96]F("$](#$I('L*("`@
M("`@("`@("`@)'1H:7,M/G)A:7-E17)R;W(H(DYO="!A('-C86QA<B!T>7!E
M("@D>W1Y<&5O9GTI(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M6$U,7U)00U]%4E)/4E])3E9!3$E$7U194$4I.PH@("`@("`@("`@("!R971U
M<FX@,#L*("`@("`@("!]"@H@("`@("`@(&EF("@D='EP92`]/2`D1TQ/0D%,
M4ULG6$U,7U)00U]";V]L96%N)UTI('L*("`@("`@("`@("`@:68@*'-T<F-A
M<V5C;7`H)'9A;"P@)W1R=64G*2`]/2`P"B`@("`@("`@("`@("`@("!\?"`D
M=F%L(#T](#$*("`@("`@("`@("`@("`@('Q\("@D=F%L(#T]('1R=64@)B8@
M<W1R8V%S96-M<"@D=F%L+"`G9F%L<V4G*2DI"B`@("`@("`@("`@('L*("`@
M("`@("`@("`@("`@("1V86P@/2`Q.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)'9A;"`](#`["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(&EF("@D=&AI<RT^;7ET>7!E(#T](#(I('L*("`@("`@
M("`@("`@+R\@=V4G<F4@861D:6YG('1O(&%N(&%R<F%Y(&AE<F4*("`@("`@
M("`@("`@)&%R(#T@)'1H:7,M/FUE6R=A<G)A>2==.PH@("`@("`@("`@("`D
M87);72`](&YE=R!834Q?4E!#7U9A;'5E*"1V86PL("1T>7!E*3L*("`@("`@
M("`@("`@)'1H:7,M/FUE6R=A<G)A>2==(#T@)&%R.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("\O(&$@<V-A;&%R+"!S;R!S970@=&AE('9A;'5E
M(&%N9"!R96UE;6)E<B!W92=R92!S8V%L87(*("`@("`@("`@("`@)'1H:7,M
M/FUE6R1T>7!E72`]("1V86P["B`@("`@("`@("`@("1T:&ES+3YM>71Y<&4@
M/2`D='EP96]F.PH@("`@("`@('T*("`@("`@("!R971U<FX@,3L*("`@('T*
M"B`@("`O*BH*("`@("`J($!R971U<FX@:6YT("!R971U<FYS(#$@:68@<W5C
M8V5S<V9U;"!O<B`P(&EF('1H97)E(&%R92!P<F]B;&5M<PH@("`@("HO"B`@
M("!F=6YC=&EO;B!A9&1!<G)A>2@D=F%L<RD*("`@('L*("`@("`@("!I9B`H
M)'1H:7,M/FUY='EP92`A/2`P*2!["B`@("`@("`@("`@("1T:&ES+3YR86ES
M945R<F]R*`H@("`@("`@("`@("`@("`@("`@("=!;')E861Y(&EN:71I86QI
M>F5D(&%S(&$@6R<@+B`D=&AI<RT^:VEN9$]F*"D@+B`G72<L"B`@("`@("`@
M("`@("`@("`@("`@6$U,7U)00U]%4E)/4E]!3%)%04197TE.251)04Q)6D5$
M*3L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@?0H@("`@("`@("1T
M:&ES+3YM>71Y<&4@/2`D1TQ/0D%,4ULG6$U,7U)00U]4>7!E<R==6R=A<G)A
M>2==.PH@("`@("`@("1T:&ES+3YM95LG87)R87DG72`]("1V86QS.PH@("`@
M("`@(')E='5R;B`Q.PH@("`@?0H*("`@("\J*@H@("`@("H@0')E='5R;B!I
M;G0@(')E='5R;G,@,2!I9B!S=6-C97-S9G5L(&]R(#`@:68@=&AE<F4@87)E
M('!R;V)L96US"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9%-T<G5C="@D=F%L
M<RD*("`@('L*("`@("`@("!I9B`H)'1H:7,M/FUY='EP92`A/2`P*2!["B`@
M("`@("`@("`@("1T:&ES+3YR86ES945R<F]R*`H@("`@("`@("`@("`@("`@
M("`@("=!;')E861Y(&EN:71I86QI>F5D(&%S(&$@6R<@+B`D=&AI<RT^:VEN
M9$]F*"D@+B`G72<L"B`@("`@("`@("`@("`@("`@("`@6$U,7U)00U]%4E)/
M4E]!3%)%04197TE.251)04Q)6D5$*3L*("`@("`@("`@("`@<F5T=7)N(#`[
M"B`@("`@("`@?0H@("`@("`@("1T:&ES+3YM>71Y<&4@/2`D1TQ/0D%,4ULG
M6$U,7U)00U]4>7!E<R==6R=S=')U8W0G73L*("`@("`@("`D=&AI<RT^;65;
M)W-T<G5C="==(#T@)'9A;',["B`@("`@("`@<F5T=7)N(#$["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I
M;VX@9'5M<"@D87(I"B`@("!["B`@("`@("`@<F5S970H)&%R*3L*("`@("`@
M("!F;W)E86-H("@D87(@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@
M(&5C:&\@(B1K97D@/3X@)'9A;#QB<B`O/B(["B`@("`@("`@("`@(&EF("@D
M:V5Y(#T]("=A<G)A>2<I('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V
M86P@87,@)&ME>3(@/3X@)'9A;#(I('L*("`@("`@("`@("`@("`@("`@("!E
M8VAO("(M+2`D:V5Y,B`]/B`D=F%L,CQB<B`O/B(["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&1A=&$@='EP92!O9B!T:&4@8W5R
M<F5N="!V86QU90H@("`@("HO"B`@("!F=6YC=&EO;B!K:6YD3V8H*0H@("`@
M>PH@("`@("`@('-W:71C:"`H)'1H:7,M/FUY='EP92D@>PH@("`@("`@(&-A
M<V4@,SH*("`@("`@("`@("`@<F5T=7)N("=S=')U8W0G.PH*("`@("`@("!C
M87-E(#(Z"B`@("`@("`@("`@(')E='5R;B`G87)R87DG.PH*("`@("`@("!C
M87-E(#$Z"B`@("`@("`@("`@(')E='5R;B`G<V-A;&%R)SL*"B`@("`@("`@
M9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N("=U;F1E9B<["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!D
M871A(&EN(%A-3"!F;W)M870*("`@("`J+PH@("`@9G5N8W1I;VX@<V5R:6%L
M:7IE9&%T82@D='EP+"`D=F%L*0H@("`@>PH@("`@("`@("1R<R`]("<G.PH@
M("`@("`@(&EF("@A87)R87E?:V5Y7V5X:7-T<R@D='EP+"`D1TQ/0D%,4ULG
M6$U,7U)00U]4>7!E<R==*2D@>PH@("`@("`@("`@("`O+R!86%@*("`@("`@
M("`@("`@+R\@;F5E9"!S;VUE('=A>2!T;R!R97!O<G0@=&AI<R!E<G)O<@H@
M("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@("`@('-W:71C:"`H
M)$=,3T)!3%-;)UA-3%]24$-?5'EP97,G75LD='EP72D@>PH@("`@("`@(&-A
M<V4@,SH*("`@("`@("`@("`@+R\@<W1R=6-T"B`@("`@("`@("`@("1R<R`N
M/2`B/'-T<G5C=#Y<;B(["B`@("`@("`@("`@(')E<V5T*"1V86PI.PH@("`@
M("`@("`@("!F;W)E86-H("@D=F%L(&%S("1K97DR(#T^("1V86PR*2!["B`@
M("`@("`@("`@("`@("`D<G,@+CT@(CQM96UB97(^/&YA;64^)'MK97DR?3PO
M;F%M93Y<;B(["B`@("`@("`@("`@("`@("`D<G,@+CT@)'1H:7,M/G-E<FEA
M;&EZ979A;"@D=F%L,BD["B`@("`@("`@("`@("`@("`D<G,@+CT@(CPO;65M
M8F5R/EQN(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<G,@+CT@)SPO
M<W1R=6-T/B<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(#(Z
M"B`@("`@("`@("`@("\O(&%R<F%Y"B`@("`@("`@("`@("1R<R`N/2`B/&%R
M<F%Y/EQN/&1A=&$^7&XB.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@
M/"!S:7IE;V8H)'9A;"D[("1I*RLI('L*("`@("`@("`@("`@("`@("1R<R`N
M/2`D=&AI<RT^<V5R:6%L:7IE=F%L*"1V86Q;)&E=*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D<G,@+CT@(CPO9&%T83Y<;CPO87)R87D^(CL*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@
M<W=I=&-H("@D='EP*2!["B`@("`@("`@("`@(&-A<V4@)$=,3T)!3%-;)UA-
M3%]24$-?0F%S938T)UTZ"B`@("`@("`@("`@("`@("`D<G,@+CT@(CPD>W1Y
M<'T^(B`N(&)A<V4V-%]E;F-O9&4H)'9A;"D@+B`B/"\D>W1Y<'T^(CL*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("1'3$]"04Q3
M6R=834Q?4E!#7T)O;VQE86XG73H*("`@("`@("`@("`@("`@("1R<R`N/2`B
M/"1[='EP?3XB("X@*"1V86P@/R`G,2<@.B`G,"<I("X@(CPO)'MT>7!]/B([
M"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`D1TQ/
M0D%,4ULG6$U,7U)00U]3=')I;F<G73H*("`@("`@("`@("`@("`@("1R<R`N
M/2`B/"1[='EP?3XB("X@:'1M;'-P96-I86QC:&%R<R@D=F%L*2X@(CPO)'MT
M>7!]/B(["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@9&5F
M875L=#H*("`@("`@("`@("`@("`@("1R<R`N/2`B/"1[='EP?3XD>W9A;'T\
M+R1[='EP?3XB.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D<G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@=&AE(&1A=&$@:6X@6$U,(&9O<FUA=`H@("`@("HO"B`@("!F=6YC=&EO
M;B!S97)I86QI>F4H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<V5R
M:6%L:7IE=F%L*"1T:&ES*3L*("`@('T*"B`@("`O*BH*("`@("`J($!R971U
M<FX@<W1R:6YG("!T:&4@9&%T82!I;B!834P@9F]R;6%T"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-E<FEA;&EZ979A;"@D;RD*("`@('L*("`@("`@("!I9B`H
M(6ES7V]B:F5C="@D;RD@?'P@96UP='DH)&\M/FUE*2!\?"`A:7-?87)R87DH
M)&\M/FUE*2D@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H@
M("`@("`@("1A<B`]("1O+3YM93L*("`@("`@("!R97-E="@D87(I.PH@("`@
M("`@(&QI<W0H)'1Y<"P@)'9A;"D@/2!E86-H*"1A<BD["B`@("`@("`@<F5T
M=7)N("<\=F%L=64^)R`N("`D=&AI<RT^<V5R:6%L:7IE9&%T82@D='EP+"`D
M=F%L*2`N("`B/"]V86QU93Y<;B(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!T:&4@8V]N=&5N=',@;V8@=&AE(&5L96UE;G0@<F5Q
M=65S=&5D"B`@("`@*B\*("`@(&9U;F-T:6]N('-T<G5C=&UE;2@D;2D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/FUE6R=S=')U8W0G75LD;5T["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@
M9G5N8W1I;VX@<W1R=6-T<F5S970H*0H@("`@>PH@("`@("`@(')E<V5T*"1T
M:&ES+3YM95LG<W1R=6-T)UTI.PH@("`@?0H*("`@("\J*@H@("`@("H@0')E
M='5R;B`@=&AE(&ME>2]V86QU92!P86ER(&]F('1H92!S=')U8W0G<R!C=7)R
M96YT(&5L96UE;G0*("`@("`J+PH@("`@9G5N8W1I;VX@<W1R=6-T96%C:"@I
M"B`@("!["B`@("`@("`@<F5T=7)N(&5A8V@H)'1H:7,M/FUE6R=S=')U8W0G
M72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N(&UI>&5D("!T:&4@
M8W5R<F5N="!V86QU90H@("`@("HO"B`@("!F=6YC=&EO;B!G971V86PH*0H@
M("`@>PH@("`@("`@("\O(%5.4U1!0DQ%"@H@("`@("`@(')E<V5T*"1T:&ES
M+3YM92D["B`@("`@("`@)&(@/2!C=7)R96YT*"1T:&ES+3YM92D["@H@("`@
M("`@("\O(&-O;G1R:6)U=&5D(&)Y($D@4V]F97(L(#(P,#$M,#,M,C0*("`@
M("`@("`O+R!A9&0@<W5P<&]R="!F;W(@;F5S=&5D(&%R<F%Y<R!T;R!S8V%L
M87)V86P*("`@("`@("`O+R!I)W9E(&-R96%T960@82!N97<@;65T:&]D(&AE
M<F4L('-O(&%S('1O"B`@("`@("`@+R\@<')E<V5R=F4@8F%C:R!C;VUP871I
M8FEL:71Y"@H@("`@("`@(&EF("AI<U]A<G)A>2@D8BDI('L*("`@("`@("`@
M("`@9F]R96%C:"`H)&(@87,@)&ED(#T^("1C;VYT*2!["B`@("`@("`@("`@
M("`@("`D8ELD:61=(#T@)&-O;G0M/G-C86QA<G9A;"@I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`O+R!A9&0@<W5P<&]R="!F;W(@<W1R
M=6-T=7)E<R!D:7)E8W1L>2!E;F-O9&EN9R!P:'`@;V)J96-T<PH@("`@("`@
M(&EF("AI<U]O8FIE8W0H)&(I*2!["B`@("`@("`@("`@("1T(#T@9V5T7V]B
M:F5C=%]V87)S*"1B*3L*("`@("`@("`@("`@9F]R96%C:"`H)'0@87,@)&ED
M(#T^("1C;VYT*2!["B`@("`@("`@("`@("`@("`D=%LD:61=(#T@)&-O;G0M
M/G-C86QA<G9A;"@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1T(&%S("1I9"`]/B`D8V]N="D@>PH@("`@("`@("`@("`@("`@)&(M
M/B1I9"`]("1C;VYT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`O+R!E;F0@8V]N=')I8@H@("`@("`@(')E='5R;B`D8CL*("`@('T*"B`@
M("`O*BH*("`@("`J($!R971U<FX@;6EX960*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V-A;&%R=F%L*"D*("`@('L*("`@("`@("!R97-E="@D=&AI<RT^;64I
M.PH@("`@("`@(')E='5R;B!C=7)R96YT*"1T:&ES+3YM92D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!`<F5T=7)N('-T<FEN9PH@("`@("HO"B`@("!F=6YC
M=&EO;B!S8V%L87)T>7`H*0H@("`@>PH@("`@("`@(')E<V5T*"1T:&ES+3YM
M92D["B`@("`@("`@)&$@/2!K97DH)'1H:7,M/FUE*3L*("`@("`@("!I9B`H
M)&$@/3T@)$=,3T)!3%-;)UA-3%]24$-?230G72D@>PH@("`@("`@("`@("`D
M82`]("1'3$]"04Q36R=834Q?4E!#7TEN="==.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!T:&4@<W1R=6-T)W,@8W5R<F5N="!E;&5M96YT"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&%R<F%Y;65M*"1M*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^;65;)V%R<F%Y)UU;)&U=.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@96QE;65N=',@:6X@=&AE(&%R
M<F%Y"B`@("`@*B\*("`@(&9U;F-T:6]N(&%R<F%Y<VEZ92@I"B`@("!["B`@
M("`@("`@<F5S970H)'1H:7,M/FUE*3L*("`@("`@("!L:7-T*"1A+"`D8BD@
M/2!E86-H*"1T:&ES+3YM92D["B`@("`@("`@<F5T=7)N('-I>F5O9B@D8BD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S(&EF('1H92!I=&5M
M('-U8FUI='1E9"!I<R!A;B!834Q?4E!#7U9A;'5E(&]B:F5C=`H@("`@("H*
M("`@("`J($!P87)A;2!M:7AE9"`D=F%L("!T:&4@=F%R:6%B;&4@=&\@8F4@
M979A;'5A=&5D"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("!44E5%(&EF
M('1H92!I=&5M(&ES(&%N(%A-3%]24$-?5F%L=64@;V)J96-T"B`@("`@*@H@
M("`@("H@0'-T871I8PH@("`@("H@0'-I;F-E($UE=&AO9"!A=F%I;&%B;&4@
M<VEN8V4@4F5L96%S92`Q+C,N,`H@("`@("HO"B`@("!F=6YC=&EO;B!I<U9A
M;'5E*"1V86PI"B`@("!["B`@("`@("`@<F5T=7)N("AS=')T;VQO=V5R*&=E
M=%]C;&%S<R@D=F%L*2D@/3T@)WAM;%]R<&-?=F%L=64G*3L*("`@('T*?0H*
M+RHJ"B`J(%)E='5R;B!A;B!)4T\X-C`Q(&5N8V]D960@<W1R:6YG"B`J"B`J
M(%=H:6QE('1I;65Z;VYE<R!O=6=H="!T;R!B92!S=7!P;W)T960L('1H92!8
M34PM4E!#('-P96,@<V%Y<SH*("H*("H@(D1O;B=T(&%S<W5M92!A('1I;65Z
M;VYE+B!)="!S:&]U;&0@8F4@<W!E8VEF:65D(&)Y('1H92!S97)V97(@:6X@
M:71S"B`J(&1O8W5M96YT871I;VX@=VAA="!A<W-U;7!T:6]N<R!I="!M86ME
M<R!A8F]U="!T:6UE>F]N97,N(@H@*@H@*B!4:&ES(')O=71I;F4@86QW87ES
M(&%S<W5M97,@;&]C86QT:6UE('5N;&5S<R`D=71C(&ES('-E="!T;R`Q+"!I
M;B!W:&EC:`H@*B!C87-E(%540R!I<R!A<W-U;65D(&%N9"!A;B!A9&IU<W1M
M96YT(&9O<B!L;V-A;&4@:7,@;6%D92!W:&5N(&5N8V]D:6YG+@H@*@H@*B!`
M<F5T=7)N('-T<FEN9R`@=&AE(&9O<FUA='1E9"!D871E"B`J+PIF=6YC=&EO
M;B!834Q?4E!#7VES;S@V,#%?96YC;V1E*"1T:6UE="P@)'5T8R`](#`I"GL*
M("`@(&EF("@A)'5T8RD@>PH@("`@("`@("1T(#T@<W1R9G1I;64H)R59)6TE
M9%0E2#HE33HE4R<L("1T:6UE="D["B`@("!](&5L<V4@>PH@("`@("`@(&EF
M("AF=6YC=&EO;E]E>&ES=',H)V=M<W1R9G1I;64G*2D@>PH@("`@("`@("`@
M("`O+R!G;7-T<F9T:6UE(&1O97-N)W0@97AI<W0@:6X@<V]M92!V97)S:6]N
M<PH@("`@("`@("`@("`O+R!O9B!02%`*("`@("`@("`@("`@)'0@/2!G;7-T
M<F9T:6UE*"<E625M)614)4@Z)4TZ)5,G+"`D=&EM970I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1T(#T@<W1R9G1I;64H)R59)6TE9%0E2#HE
M33HE4R<L("1T:6UE="`M(&1A=&4H)UHG*2D["B`@("`@("`@?0H@("`@?0H@
M("`@<F5T=7)N("1T.PI]"@HO*BH*("H@0V]N=F5R="!A(&1A=&5T:6UE('-T
M<FEN9R!I;G1O(&$@56YI>"!T:6UE<W1A;7`*("H*("H@5VAI;&4@=&EM97IO
M;F5S(&]U9VAT('1O(&)E('-U<'!O<G1E9"P@=&AE(%A-3"U24$,@<W!E8R!S
M87ES.@H@*@H@*B`B1&]N)W0@87-S=6UE(&$@=&EM97IO;F4N($ET('-H;W5L
M9"!B92!S<&5C:69I960@8GD@=&AE('-E<G9E<B!I;B!I=',*("H@9&]C=6UE
M;G1A=&EO;B!W:&%T(&%S<W5M<'1I;VYS(&ET(&UA:V5S(&%B;W5T('1I;65Z
M;VYE<RXB"B`J"B`J(%1H:7,@<F]U=&EN92!A;'=A>7,@87-S=6UE<R!L;V-A
M;'1I;64@=6YL97-S("1U=&,@:7,@<V5T('1O(#$L(&EN('=H:6-H"B`J(&-A
M<V4@551#(&ES(&%S<W5M960@86YD(&%N(&%D:G5S=&UE;G0@9F]R(&QO8V%L
M92!I<R!M861E('=H96X@96YC;V1I;F<N"B`J"B`J($!R971U<FX@:6YT("!T
M:&4@=6YI>"!T:6UE<W1A;7`@;V8@=&AE(&1A=&4@<W5B;6ET=&5D"B`J+PIF
M=6YC=&EO;B!834Q?4E!#7VES;S@V,#%?9&5C;V1E*"1I9&%T92P@)'5T8R`]
M(#`I"GL*("`@("1T(#T@,#L*("`@(&EF("AE<F5G*"<H6S`M.5U[-'TI*%LP
M+3E=>S)]*2A;,"TY77LR?2E4*%LP+3E=>S)]*3HH6S`M.5U[,GTI.BA;,"TY
M77LR?2DG+"`D:61A=&4L("1R96=S*2D@>PH@("`@("`@(&EF("@D=71C*2![
M"B`@("`@("`@("`@("1T(#T@9VUM:W1I;64H)')E9W-;-%TL("1R96=S6S5=
M+"`D<F5G<ULV72P@)')E9W-;,ETL("1R96=S6S-=+"`D<F5G<ULQ72D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'0@/2!M:W1I;64H)')E9W-;
M-%TL("1R96=S6S5=+"`D<F5G<ULV72P@)')E9W-;,ETL("1R96=S6S-=+"`D
M<F5G<ULQ72D["B`@("`@("`@?0H@("`@?0H@("`@<F5T=7)N("1T.PI]"@HO
M*BH*("H@0V]N=F5R=',@86X@6$U,7U)00U]686QU92!O8FIE8W0@:6YT;R!N
M871I=F4@4$A0('1Y<&5S"B`J"B`J($!P87)A;2!O8FIE8W0@)%A-3%]24$-?
M=F%L("!T:&4@6$U,7U)00U]686QU92!O8FIE8W0@=&\@9&5C;V1E"B`J"B`J
M($!R971U<FX@;6EX960@('1H92!02%`@=F%L=65S"B`J+PIF=6YC=&EO;B!8
M34Q?4E!#7V1E8V]D92@D6$U,7U)00U]V86PI"GL*("`@("1K:6YD(#T@)%A-
M3%]24$-?=F%L+3YK:6YD3V8H*3L*"B`@("!I9B`H)&MI;F0@/3T@)W-C86QA
M<B<I('L*("`@("`@("!R971U<FX@)%A-3%]24$-?=F%L+3YS8V%L87)V86PH
M*3L*"B`@("!](&5L<V5I9B`H)&MI;F0@/3T@)V%R<F%Y)RD@>PH@("`@("`@
M("1S:7IE(#T@)%A-3%]24$-?=F%L+3YA<G)A>7-I>F4H*3L*("`@("`@("`D
M87)R(#T@87)R87DH*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D<VEZ
M93L@)&DK*RD@>PH@("`@("`@("`@("`D87)R6UT@/2!834Q?4E!#7V1E8V]D
M92@D6$U,7U)00U]V86PM/F%R<F%Y;65M*"1I*2D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D87)R.PH*("`@('T@96QS96EF("@D:VEN9"`]/2`G<W1R
M=6-T)RD@>PH@("`@("`@("1834Q?4E!#7W9A;"T^<W1R=6-T<F5S970H*3L*
M("`@("`@("`D87)R(#T@87)R87DH*3L*("`@("`@("!W:&EL92`H;&ES="@D
M:V5Y+"`D=F%L=64I(#T@)%A-3%]24$-?=F%L+3YS=')U8W1E86-H*"DI('L*
M("`@("`@("`@("`@)&%R<ELD:V5Y72`](%A-3%]24$-?9&5C;V1E*"1V86QU
M92D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D87)R.PH@("`@?0I]"@HO
M*BH*("H@0V]N=F5R=',@;F%T:79E(%!(4"!T>7!E<R!I;G1O(&%N(%A-3%]2
M4$-?5F%L=64@;V)J96-T"B`J"B`J($!P87)A;2!M:7AE9"`D<&AP7W9A;"`@
M=&AE(%!(4"!V86QU92!O<B!V87)I86)L92!Y;W4@=V%N="!E;F-O9&5D"B`J
M"B`J($!R971U<FX@;V)J96-T("!T:&4@6$U,7U)00U]686QU92!O8FIE8W0*
M("HO"F9U;F-T:6]N(%A-3%]24$-?96YC;V1E*"1P:'!?=F%L*0I["B`@("`D
M='EP92`](&=E='1Y<&4H)'!H<%]V86PI.PH@("`@)%A-3%]24$-?=F%L(#T@
M;F5W(%A-3%]24$-?5F%L=64["@H@("`@<W=I=&-H("@D='EP92D@>PH@("`@
M8V%S92`G87)R87DG.@H@("`@("`@(&EF("AE;7!T>2@D<&AP7W9A;"DI('L*
M("`@("`@("`@("`@)%A-3%]24$-?=F%L+3YA9&1!<G)A>2@D<&AP7W9A;"D[
M"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@("`@("`D=&UP(#T@
M87)R87E?9&EF9BAA<G)A>5]K97ES*"1P:'!?=F%L*2P@<F%N9V4H,"P@8V]U
M;G0H)'!H<%]V86PI+3$I*3L*("`@("`@("!I9B`H96UP='DH)'1M<"DI('L*
M("`@("`@("`@("`D87)R(#T@87)R87DH*3L*("`@("`@("`@("!F;W)E86-H
M("@D<&AP7W9A;"!A<R`D:R`]/B`D=BD@>PH@("`@("`@("`@("`@("`D87)R
M6R1K72`](%A-3%]24$-?96YC;V1E*"1V*3L*("`@("`@("`@("!]"B`@("`@
M("`@("`@)%A-3%]24$-?=F%L+3YA9&1!<G)A>2@D87)R*3L*("`@("`@("`@
M("!B<F5A:SL*("`@("`@("!]"B`@("`@("`@+R\@9F%L;"!T:&]U9V@@:68@
M:70G<R!N;W0@86X@96YU;65R871E9"!A<G)A>0H*("`@(&-A<V4@)V]B:F5C
M="<Z"B`@("`@("`@)&%R<B`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H
M)'!H<%]V86P@87,@)&L@/3X@)'8I('L*("`@("`@("`@("`@)&%R<ELD:UT@
M/2!834Q?4E!#7V5N8V]D92@D=BD["B`@("`@("`@?0H@("`@("`@("1834Q?
M4E!#7W9A;"T^861D4W1R=6-T*"1A<G(I.PH@("`@("`@(&)R96%K.PH*("`@
M(&-A<V4@)VEN=&5G97(G.@H@("`@("`@("1834Q?4E!#7W9A;"T^861D4V-A
M;&%R*"1P:'!?=F%L+"`D1TQ/0D%,4ULG6$U,7U)00U]);G0G72D["B`@("`@
M("`@8G)E86L["@H@("`@8V%S92`G9&]U8FQE)SH*("`@("`@("`D6$U,7U)0
M0U]V86PM/F%D9%-C86QA<B@D<&AP7W9A;"P@)$=,3T)!3%-;)UA-3%]24$-?
M1&]U8FQE)UTI.PH@("`@("`@(&)R96%K.PH*("`@(&-A<V4@)W-T<FEN9R<Z
M"B`@("!C87-E("=.54Q,)SH*("`@("`@("!I9B`H97)E9R@G7ELP+3E=>SA]
M7%1[,7U;,"TY77LR?5PZ6S`M.5U[,GU<.ELP+3E=>S)])"<L("1P:'!?=F%L
M*2D@>PH@("`@("`@("`@("`D6$U,7U)00U]V86PM/F%D9%-C86QA<B@D<&AP
M7W9A;"P@)$=,3T)!3%-;)UA-3%]24$-?1&%T951I;64G72D["B`@("`@("`@
M?2!E;'-E:68@*'!R96=?;6%T8V@H)R];7EQX,C`M7'@W15QX,#E<>#!!7'@P
M1%TO)RP@)'!H<%]V86PI*2!["B`@("`@("`@("`@("\O($-H87)A8W1E<G,@
M;W1H97(@=&AA;B!A;'!H82UN=6UE<FEC+"!P=6YC='5A=&EO;BP@4U`L(%1!
M0BP*("`@("`@("`@("`@+R\@3$8@86YD($-2(&)R96%K('1H92!834P@<&%R
M<V5R+"!E;F-O9&4@=F%L=64@=FEA($)A<V4@-C0N"B`@("`@("`@("`@("18
M34Q?4E!#7W9A;"T^861D4V-A;&%R*"1P:'!?=F%L+"`D1TQ/0D%,4ULG6$U,
M7U)00U]"87-E-C0G72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)%A-3%]24$-?=F%L+3YA9&138V%L87(H)'!H<%]V86PL("1'3$]"04Q36R=8
M34Q?4E!#7U-T<FEN9R==*3L*("`@("`@("!]"B`@("`@("`@8G)E86L["@H@
M("`@8V%S92`G8F]O;&5A;B<Z"B`@("`@("`@+R\@061D('-U<'!O<G0@9F]R
M(&5N8V]D:6YG+V1E8V]D:6YG(&]F(&)O;VQE86YS+"!S:6YC92!T:&5Y"B`@
M("`@("`@+R\@87)E('-U<'!O<G1E9"!I;B!02%`*("`@("`@("`O+R!B>2`\
M1U]':75N=&%?,C`P,2TP,BTR.3X*("`@("`@("`D6$U,7U)00U]V86PM/F%D
M9%-C86QA<B@D<&AP7W9A;"P@)$=,3T)!3%-;)UA-3%]24$-?0F]O;&5A;B==
M*3L*("`@("`@("!B<F5A:SL*"B`@("!C87-E("=U;FMN;W=N('1Y<&4G.@H@
M("`@9&5F875L=#H*("`@("`@("`D6$U,7U)00U]V86P@/2!F86QS93L*("`@
M('T*("`@(')E='5R;B`D6$U,7U)00U]V86P["GT*"B\J"B`J($QO8V%L('9A
M<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T
M"B`J(&,M:&%N9VEN9RUC;VUM96YT+65N9&5R+7`Z(&YI;`H@*B!%;F0Z"B`J
M+PH*/SX*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+UA-3"]397)I86QI>F5R+G!H<```````````````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,3$R-#<R`#$P-3$U-#,S-S,V`#`R
M,C`W-P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/U!(4`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T
M=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%A-3%]397)I86QI
M>F5R"B`J"B`J($-R96%T97,@6$U,(&1O8W5M96YT<R!F<F]M(%!(4"!D871A
M('-T<G5C='5R97,@;&EK92!A<G)A>7,L(&]B:F5C=',@;W(@<V-A;&%R<RX*
M("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H
M92!02%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@
M87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A
M<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A
M;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R
M>2`@(%A-3`H@*B!`<&%C:V%G92`@("!834Q?4V5R:6%L:7IE<@H@*B!`875T
M:&]R("`@("!3=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"YN970^"B`J($!C
M;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@4V5R:6%L:7IE
M<BYP:'`L=B`Q+C0W(#(P,#4O,#DO,S`@,3,Z-#`Z,S`@<V-H<W0@17AP("0*
M("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+UA-
M3%]397)I86QI>F5R"B`J($!S964@("`@("`@(%A-3%]5;G-E<FEA;&EZ97(*
M("HO"@HO*BH*("H@=7-E<R!014%2(&5R<F]R(&UA;F%G96UE;G0*("HO"G)E
M<75I<F5?;VYC92`G4$5!4BYP:'`G.PH*+RHJ"B`J('5S97,@6$U,7U5T:6P@
M=&\@8W)E871E(%A-3"!T86=S"B`J+PIR97%U:7)E7V]N8V4@)UA-3"]5=&EL
M+G!H<"<["@HO*BH*("H@;W!T:6]N.B!S=')I;F<@=7-E9"!F;W(@:6YD96YT
M871I;VX*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M(&%N>2!S=')I;F<@
M*&1E9F%U;'0@:7,@86YY('-T<FEN9RD*("HO"F1E9FEN92@G6$U,7U-%4DE!
M3$E:15)?3U!424].7TE.1$5.5"<L("=I;F1E;G0G*3L*"B\J*@H@*B!O<'1I
M;VXZ('-T<FEN9R!U<V5D(&9O<B!L:6YE8G)E86MS"B`J"B`J(%!O<W-I8FQE
M('9A;'5E<SH*("H@+2!A;GD@<W1R:6YG("AD969A=6QT(&ES(%QN*0H@*B\*
M9&5F:6YE*"=834Q?4T5224%,25I%4E]/4%1)3TY?3$E.14)214%+4R<L("=L
M:6YE8G)E86LG*3L*"B\J*@H@*B!O<'1I;VXZ(&5N86)L92!T>7!E(&AI;G1S
M"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@+2!T<G5E"B`J("T@9F%L<V4*
M("HO"F1E9FEN92@G6$U,7U-%4DE!3$E:15)?3U!424].7U194$5(24Y44R<L
M("=T>7!E2&EN=',G*3L*"B\J*@H@*B!O<'1I;VXZ(&%D9"!A;B!834P@9&5C
M;&%R871I;VX*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M('1R=64*("H@
M+2!F86QS90H@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]/4%1)3TY?6$U,
M7T1%0TQ?14Y!0DQ%1"<L("=A9&1$96-L)RD["@HO*BH*("H@;W!T:6]N.B!E
M;F-O9&EN9R!O9B!T:&4@9&]C=6UE;G0*("H*("H@4&]S<VEB;&4@=F%L=65S
M.@H@*B`M(&%N>2!V86QI9"!E;F-O9&EN9PH@*B`M(&YU;&P@*&1E9F%U;'0I
M"B`J+PID969I;F4H)UA-3%]315))04Q)6D527T]05$E/3E]834Q?14Y#3T1)
M3D<G+"`G96YC;V1I;F<G*3L*"B\J*@H@*B!O<'1I;VXZ(&1E9F%U;'0@;F%M
M92!F;W(@=&%G<PH@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@86YY('-T
M<FEN9R`H6$U,7U-E<FEA;&EZ97)?5&%G(&ES(&1E9F%U;'0I"B`J+PID969I
M;F4H)UA-3%]315))04Q)6D527T]05$E/3E]$149!54Q47U1!1R<L("=D969A
M=6QT5&%G3F%M92<I.PH*+RHJ"B`J(&]P=&EO;CH@=7-E(&-L87-S;F%M92!F
M;W(@;V)J96-T<R!I;B!I;F1E>&5D(&%R<F%Y<PH@*@H@*B!0;W-S:6)L92!V
M86QU97,Z"B`J("T@=')U92`H9&5F875L="D*("H@+2!F86QS90H@*B\*9&5F
M:6YE*"=834Q?4T5224%,25I%4E]/4%1)3TY?0TQ!4U-.04U%7T%37U1!1TY!
M344G+"`G8VQA<W-!<U1A9TYA;64G*3L*"B\J*@H@*B!O<'1I;VXZ(&%T=')I
M8G5T92!W:&5R92!O<FEG:6YA;"!K97D@:7,@<W1O<F5D"B`J"B`J(%!O<W-I
M8FQE('9A;'5E<SH*("H@+2!A;GD@<W1R:6YG("AD969A=6QT(&ES(%]O<FEG
M:6YA;$ME>2D*("HO"F1E9FEN92@G6$U,7U-%4DE!3$E:15)?3U!424].7T%4
M5%))0E5415]+15DG+"`G:V5Y071T<FEB=71E)RD["@HO*BH*("H@;W!T:6]N
M.B!A='1R:6)U=&4@9F]R('1Y<&4@*&]N;'D@:68@='EP94AI;G1S(#T^('1R
M=64I"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@+2!A;GD@<W1R:6YG("AD
M969A=6QT(&ES(%]T>7!E*0H@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]/
M4%1)3TY?05144DE"551%7U194$4G+"`G='EP94%T=')I8G5T92<I.PH*+RHJ
M"B`J(&]P=&EO;CH@871T<FEB=71E(&9O<B!C;&%S<R`H;VYL>2!I9B!T>7!E
M2&EN=',@/3X@=')U92D*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M(&%N
M>2!S=')I;F<@*&1E9F%U;'0@:7,@7V-L87-S*0H@*B\*9&5F:6YE*"=834Q?
M4T5224%,25I%4E]/4%1)3TY?05144DE"551%7T-,05-3)RP@)V-L87-S071T
M<FEB=71E)RD["@HO*BH*("H@;W!T:6]N.B!S8V%L87(@=F%L=65S("AS=')I
M;F=S+"!I;G1S+"XN*2!W:6QL(&)E('-E<FEA;&EZ960@87,@871T<FEB=71E
M"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@+2!T<G5E"B`J("T@9F%L<V4@
M*&1E9F%U;'0I"B`J("T@87)R87D@=VAI8V@@<V5T<R!T:&ES(&]P=&EO;B!O
M;B!A('!E<BUT86<@8F%S:7,*("HO"F1E9FEN92@G6$U,7U-%4DE!3$E:15)?
M3U!424].7U-#04Q!4E]!4U]!5%1224)55$53)RP@)W-C86QA<D%S071T<FEB
M=71E<R<I.PH*+RHJ"B`J(&]P=&EO;CH@<')E<&5N9"!S=')I;F<@9F]R(&%T
M=')I8G5T97,*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M(&%N>2!S=')I
M;F<@*&1E9F%U;'0@:7,@86YY('-T<FEN9RD*("HO"F1E9FEN92@G6$U,7U-%
M4DE!3$E:15)?3U!424].7U!215!%3D1?05144DE"551%4R<L("=P<F5P96YD
M071T<FEB=71E<R<I.PH*+RHJ"B`J(&]P=&EO;CH@:6YD96YT('1H92!A='1R
M:6)U=&5S+"!I9B!S970@=&\@)U]A=71O)RP@:70@=VEL;"!I;F1E;G0@871T
M<FEB=71E<R!S;R!T:&5Y(&%L;"!S=&%R="!A="!T:&4@<V%M92!C;VQU;6X*
M("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M('1R=64*("H@+2!F86QS92`H
M9&5F875L="D*("HO"F1E9FEN92@G6$U,7U-%4DE!3$E:15)?3U!424].7TE.
M1$5.5%]!5%1224)55$53)RP@)VEN9&5N=$%T=')I8G5T97,G*3L*"B\J*@H@
M*B!O<'1I;VXZ('5S92`G<VEM<&QE>&UL)R!T;R!U<V4@<&%R96YT(&YA;64@
M87,@=&%G;F%M92!I9B!T<F%N<V9O<FUI;F<@86X@:6YD97AE9"!A<G)A>0H@
M*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@6$U,7U-%4DE!3$E:15)?34]$
M15]$149!54Q4("AD969A=6QT*0H@*B`M(%A-3%]315))04Q)6D527TU/1$5?
M4TE-4$Q%6$U,"B`J+PID969I;F4H)UA-3%]315))04Q)6D527T]05$E/3E]-
M3T1%)RP@)VUO9&4G*3L*"B\J*@H@*B!O<'1I;VXZ(&%D9"!A(&1O8W1Y<&4@
M9&5C;&%R871I;VX*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M('1R=64*
M("H@+2!F86QS92`H9&5F875L="D*("HO"F1E9FEN92@G6$U,7U-%4DE!3$E:
M15)?3U!424].7T1/0U194$5?14Y!0DQ%1"<L("=A9&1$;V-T>7!E)RD["@HO
M*BH*("H@;W!T:6]N.B!S=7!P;'D@82!S=')I;F<@;W(@86X@87)R87D@=VET
M:"!I9"!A;F0@=7)I("A[0'-E92!834Q?571I;#HZ9V5T1&]C='EP941E8VQA
M<F%T:6]N*"E]"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@+2!S=')I;F<*
M("H@+2!A<G)A>0H@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]/4%1)3TY?
M1$]#5%E012<L("=D;V-T>7!E)RD["@HO*BH*("H@;W!T:6]N.B!N86UE(&]F
M('1H92!R;V]T('1A9PH@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@<W1R
M:6YG"B`J("T@;G5L;"`H9&5F875L="D*("HO"F1E9FEN92@G6$U,7U-%4DE!
M3$E:15)?3U!424].7U)/3U1?3D%-12<L("=R;V]T3F%M92<I.PH*+RHJ"B`J
M(&]P=&EO;CH@871T<FEB=71E<R!O9B!T:&4@<F]O="!T86<*("H*("H@4&]S
M<VEB;&4@=F%L=65S.@H@*B`M(&%R<F%Y"B`J+PID969I;F4H)UA-3%]315))
M04Q)6D527T]05$E/3E]23T]47T%45%))0E,G+"`G<F]O=$%T=')I8G5T97,G
M*3L*"B\J*@H@*B!O<'1I;VXZ(&%L;"!V86QU97,@:6X@=&AI<R!K97D@=VEL
M;"!B92!T<F5A=&5D(&%S(&%T=')I8G5T97,*("H*("H@4&]S<VEB;&4@=F%L
M=65S.@H@*B`M(&%R<F%Y"B`J+PID969I;F4H)UA-3%]315))04Q)6D527T]0
M5$E/3E]!5%1224)55$537TM%62<L("=A='1R:6)U=&5S07)R87DG*3L*"B\J
M*@H@*B!O<'1I;VXZ('1H:7,@=F%L=64@=VEL;"!B92!U<V5D(&1I<F5C=&QY
M(&%S(&-O;G1E;G0L(&EN<W1E860@;V8@8W)E871I;F<@82!N97<@=&%G+"!M
M87D@;VYL>2!B92!U<V5D(&EN(&-O;FIU8W1I;VX@=VET:"!A='1R:6)U=&5S
M07)R87D*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M('-T<FEN9PH@*B`M
M(&YU;&P@*&1E9F%U;'0I"B`J+PID969I;F4H)UA-3%]315))04Q)6D527T]0
M5$E/3E]#3TY414Y47TM%62<L("=C;VYT96YT3F%M92<I.PH*+RHJ"B`J(&]P
M=&EO;CH@=&AI<R!V86QU92!W:6QL(&)E('5S960@:6X@82!C;VUM96YT+"!I
M;G-T96%D(&]F(&-R96%T:6YG(&$@;F5W('1A9PH@*@H@*B!0;W-S:6)L92!V
M86QU97,Z"B`J("T@<W1R:6YG"B`J("T@;G5L;"`H9&5F875L="D*("HO"F1E
M9FEN92@G6$U,7U-%4DE!3$E:15)?3U!424].7T-/34U%3E1?2T59)RP@)V-O
M;6UE;G1.86UE)RD["@HO*BH*("H@;W!T:6]N.B!T86<@;F%M97,@=&AA="!W
M:6QL(&)E(&-H86YG960*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M(&%R
M<F%Y"B`J+PID969I;F4H)UA-3%]315))04Q)6D527T]05$E/3E]404=-05`G
M+"`G=&%G36%P)RD["@HO*BH*("H@;W!T:6]N.B!F=6YC=&EO;B!T:&%T('=I
M;&P@8F4@87!P;&EE9"!B969O<F4@<V5R:6%L:7II;F<*("H*("H@4&]S<VEB
M;&4@=F%L=65S.@H@*B`M(&%N>2!V86QI9"!02%`@8V%L;&)A8VL*("HO"F1E
M9FEN92@G6$U,7U-%4DE!3$E:15)?3U!424].7T5.0T]$15]&54Y#)RP@)V5N
M8V]D949U;F-T:6]N)RD["@HO*BH*("H@;W!T:6]N.B!F=6YC=&EO;B!T:&%T
M('=I;&P@8F4@87!P;&EE9"!B969O<F4@<V5R:6%L:7II;F<*("H*("H@4&]S
M<VEB;&4@=F%L=65S.@H@*B`M('-T<FEN9PH@*B`M(&YU;&P@*&1E9F%U;'0I
M"B`J+PID969I;F4H)UA-3%]315))04Q)6D527T]05$E/3E].04U%4U!!0T4G
M+"`G;F%M97-P86-E)RD["@HO*BH*("H@;W!T:6]N.B!T>7!E(&]F(&5N=&ET
M:65S('1O(')E<&QA8V4*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M(%A-
M3%]315))04Q)6D527T5.5$E424537TY/3D4*("H@+2!834Q?4T5224%,25I%
M4E]%3E1)5$E%4U]834P@*&1E9F%U;'0I"B`J("T@6$U,7U-%4DE!3$E:15)?
M14Y4251)15-?6$U,7U)%455)4D5$"B`J("T@6$U,7U-%4DE!3$E:15)?14Y4
M251)15-?2%1-3`H@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]/4%1)3TY?
M14Y4251)15,G+"`G<F5P;&%C945N=&ET:65S)RD["@HO*BH*("H@;W!T:6]N
M.B!W:&5T:&5R('1O(')E='5R;B!T:&4@<F5S=6QT(&]F('1H92!S97)I86QI
M>F%T:6]N(&9R;VT@<V5R:6%L:7IE*"D*("H*("H@4&]S<VEB;&4@=F%L=65S
M.@H@*B`M('1R=64*("H@+2!F86QS92`H9&5F875L="D*("HO"F1E9FEN92@G
M6$U,7U-%4DE!3$E:15)?3U!424].7U)%5%523E]215-53%0G+"`G<F5T=7)N
M4F5S=6QT)RD["@HO*BH*("H@;W!T:6]N.B!W:&5T:&5R('1O(&EG;F]R92!P
M<F]P97)T:65S('1H870@87)E('-E="!T;R!N=6QL"B`J"B`J(%!O<W-I8FQE
M('9A;'5E<SH*("H@+2!T<G5E"B`J("T@9F%L<V4@*&1E9F%U;'0I"B`J+PID
M969I;F4H)UA-3%]315))04Q)6D527T]05$E/3E])1TY/4D5?3E5,3"<L("=I
M9VYO<F5.=6QL)RD["@HO*BH*("H@;W!T:6]N.B!W:&5T:&5R('1O('5S92!C
M9&%T82!S96-T:6]N<R!F;W(@8VAA<F%C=&5R(&1A=&$*("H*("H@4&]S<VEB
M;&4@=F%L=65S.@H@*B`M('1R=64*("H@+2!F86QS92`H9&5F875L="D*("HO
M"F1E9FEN92@G6$U,7U-%4DE!3$E:15)?3U!424].7T-$051!7U-%0U1)3TY3
M)RP@)V-D871A)RD["@H*+RHJ"B`J(&1E9F%U;'0@;6]D90H@*B\*9&5F:6YE
M*"=834Q?4T5224%,25I%4E]-3T1%7T1%1D%53%0G+"`G9&5F875L="<I.PH*
M+RHJ"B`J(%-I;7!L95A-3"!M;V1E"B`J"B`J(%=H96X@<V5R:6%L:7II;F<@
M:6YD97AE9"!A<G)A>7,L('1H92!K97D@;V8@=&AE('!A<F5N="!V86QU92!I
M<R!U<V5D(&%S(&$@=&%G;F%M92X*("HO"F1E9FEN92@G6$U,7U-%4DE!3$E:
M15)?34]$15]324U03$5834PG+"`G<VEM<&QE>&UL)RD["B`@("`@("`@("`@
M("`@("`@("`@("`@("`*+RHJ"B`J(&5R<F]R(&-O9&4@9F]R(&YO('-E<FEA
M;&EZ871I;VX@9&]N90H@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]%4E)/
M4E].3U]315))04Q)6D%424].)RP@-3$I.PH*+RHJ"B`J(&1O(&YO="!R97!L
M86-E(&5N=&ET:71E<PH@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]%3E1)
M5$E%4U].3TY%)RP@6$U,7U5424Q?14Y4251)15-?3D].12D["@HO*BH*("H@
M<F5P;&%C92!A;&P@6$U,(&5N=&ET:71E<PH@*B!4:&ES('-E='1I;F<@=VEL
M;"!R97!L86-E(#PL(#XL("(L("<@86YD("8*("HO"F1E9FEN92@G6$U,7U-%
M4DE!3$E:15)?14Y4251)15-?6$U,)RP@6$U,7U5424Q?14Y4251)15-?6$U,
M*3L*"B\J*@H@*B!R97!L86-E(&]N;'D@<F5Q=6ER960@6$U,(&5N=&ET:71E
M<PH@*B!4:&ES('-E='1I;F<@=VEL;"!R97!L86-E(#PL("(@86YD("8*("HO
M"F1E9FEN92@G6$U,7U-%4DE!3$E:15)?14Y4251)15-?6$U,7U)%455)4D5$
M)RP@6$U,7U5424Q?14Y4251)15-?6$U,7U)%455)4D5$*3L*"B\J*@H@*B!R
M97!L86-E($A434P@96YT:71I=&5S"B`J($!L:6YK("`@(&AT='`Z+R]W=W<N
M<&AP+FYE="]H=&UL96YT:71I97,*("HO"F1E9FEN92@G6$U,7U-%4DE!3$E:
M15)?14Y4251)15-?2%1-3"<L(%A-3%]55$E,7T5.5$E424537TA434PI.PH*
M+RHJ"B`J($-R96%T97,@6$U,(&1O8W5M96YT<R!F<F]M(%!(4"!D871A('-T
M<G5C='5R97,@;&EK92!A<G)A>7,L(&]B:F5C=',@;W(@<V-A;&%R<RX*("H*
M("H@=&AI<R!C;&%S<R!C86X@8F4@=7-E9"!I;B!T=V\@;6]D97,Z"B`J"B`J
M("`Q+B!C<F5A=&4@86X@6$U,(&1O8W5M96YT(&9R;VT@86X@87)R87D@;W(@
M;V)J96-T('1H870@:7,@<')O8V5S<V5D(&)Y(&]T:&5R"B`J("`@(&%P<&QI
M8V%T:6]N<RX@5&AA="!M96%N<RP@>6]U(&-A;B!C<F5A=&4@82!21$8@9&]C
M=6UE;G0@9G)O;2!A;B!A<G)A>2!I;B!T:&4*("H@("`@9F]L;&]W:6YG(&9O
M<FUA=#H*("H*("H@("`@)&1A=&$@/2!A<G)A>2@*("H@("`@("`@("`@("`@
M("=C:&%N;F5L)R`]/B!A<G)A>2@*("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W1I=&QE)R`]/B`G17AA;7!L92!21$8@8VAA;FYE;"<L"B`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=L:6YK)R`@/3X@)VAT='`Z+R]W
M=W<N<&AP+71O;VQS+F1E)RP*("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VEM86=E)R`]/B!A<G)A>2@*("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W1I=&QE)R`]/B`G17AA;7!L92!I;6%G92<L
M"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U
M<FPG("`@/3X@)VAT='`Z+R]W=W<N<&AP+71O;VQS+F1E+VEM86=E+F=I9B<L
M"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=L
M:6YK)R`@/3X@)VAT='`Z+R]W=W<N<&AP+71O;VQS+F1E)PH@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I+`H@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@*("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G=&ET;&4G(#T^("=%>&%M<&QE(&ET96TG
M+`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=L:6YK)R`@
M/3X@)VAT='`Z+R]E>&%M<&QE+F-O;2<*("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`I+`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=&ET;&4G(#T^("=!;F]T:&5R($5X86UP;&4@:71E;2<L"B`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)VQI;FLG("`]/B`G:'1T<#HO+V5X
M86UP;&4N;W)G)PH@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("D*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I"B`J("`@("`@
M("`@("`@("D["B`J"B`J("`@=&\@8W)E871E(&$@4D1&(&1O8W5M96YT(&9R
M;VT@=&AI<R!A<G)A>2!D;R!T:&4@9F]L;&]W:6YG.@H@*@H@*B`@(')E<75I
M<F5?;VYC92`G6$U,+U-E<FEA;&EZ97(N<&AP)SL*("H*("H@("`D;W!T:6]N
M<R`](&%R<F%Y*`H@*B`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)
M6D527T]05$E/3E])3D1%3E0@("`@("`]/B`B7'0B+"`@("`@("`@+R\@:6YD
M96YT('=I=&@@=&%B<PH@*B`@("`@("`@("`@("`@("`@("`@(%A-3%]315))
M04Q)6D527T]05$E/3E],24Y%0E)%04M3("`]/B`B7&XB+"`@("`@("`@+R\@
M=7-E(%5.25@@;&EN92!B<F5A:W,*("H@("`@("`@("`@("`@("`@("`@("!8
M34Q?4T5224%,25I%4E]/4%1)3TY?4D]/5%].04U%("`@/3X@)W)D9CI21$8G
M+"`@("\O(')O;W0@=&%G"B`J("`@("`@("`@("`@("`@("`@("`@6$U,7U-%
M4DE!3$E:15)?3U!424].7T1%1D%53%1?5$%'(#T^("=I=&5M)R`@("`@("`O
M+R!T86<@9F]R('9A;'5E<R!W:71H(&YU;65R:6,@:V5Y<PH@*B`@("D["B`J
M"B`J("`@)'-E<FEA;&EZ97(@/2!N97<@6$U,7U-E<FEA;&EZ97(H)&]P=&EO
M;G,I.PH@*B`@("1R9&8@("`@("`@(#T@)'-E<FEA;&EZ97(M/G-E<FEA;&EZ
M92@D9&%T82D["B`J"B`J(%EO=2!W:6QL(&=E="!A(&-O;7!L971E(%A-3"!D
M;V-U;65N="!T:&%T(&-A;B!B92!P<F]C97-S960@;&EK92!A;GD@4D1&(&1O
M8W5M96YT+@H@*@H@*B`R+B!T:&ES(&-L87-S97,@8V%N(&)E('5S960@=&\@
M<V5R:6%L:7IE(&%N>2!D871A('-T<G5C='5R92!I;B!A('=A>2!T:&%T(&ET
M(&-A;@H@*B`@("!L871E<B!B92!U;G-E<FEA;&EZ960@86=A:6XN"B`J("`@
M(%A-3%]397)I86QI>F5R('=I;&P@<W1O<F4@=&AE('1Y<&4@;V8@=&AE('9A
M;'5E(&%N9"!A9&1I=&EO;F%L(&UE=&$@:6YF;W)M871I;VX*("H@("`@:6X@
M871T<FEB=71E<R!O9B!T:&4@<W5R<F]U;F1I;F<@=&%G+B!4:&ES(&UE870@
M:6YF;W)M871I;VX@8V%N(&QA=&5R(&)E('5S960*("H@("`@=&\@<F5S=&]R
M92!T:&4@;W)I9VEN86P@9&%T82!S=')U8W1U<F4@:6X@4$A0+B!)9B!Y;W4@
M=V%N="!834Q?4V5R:6%L:7IE<@H@*B`@("!T;R!A9&0@;65T82!I;F9O<FUA
M=&EO;B!T;R!T:&4@=&%G<RP@861D"B`J"B`J("`@("`@6$U,7U-%4DE!3$E:
M15)?3U!424].7U194$5(24Y44R`]/B!T<G5E"B`J"B`J("`@('1O('1H92!O
M<'1I;VYS(&%R<F%Y(&EN('1H92!C;VYS=')U8W1O<BX*("H*("H@0&-A=&5G
M;W)Y("`@6$U,"B`J($!P86-K86=E("`@(%A-3%]397)I86QI>F5R"B`J($!A
M=71H;W(@("`@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("H@
M0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N
M<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0
M($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#`N,3@N,`H@
M*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O6$U,
M7U-E<FEA;&EZ97(*("H@0'-E92`@("`@("`@6$U,7U5N<V5R:6%L:7IE<@H@
M*B\*8VQA<W,@6$U,7U-E<FEA;&EZ97(@97AT96YD<R!014%2"GL*("`@+RHJ
M"B`@("`J(&QI<W0@;V8@86QL(&%V86EL86)L92!O<'1I;VYS"B`@("`J"B`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@*B!`=F%R("`@(&%R<F%Y"B`@("`J
M+PH@("`@=F%R("1?:VYO=VY/<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E])
M3D1%3E0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]3
M15))04Q)6D527T]05$E/3E],24Y%0E)%04M3+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?5%E014A)
M3E13+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T52
M24%,25I%4E]/4%1)3TY?6$U,7T1%0TQ?14Y!0DQ%1"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7UA-
M3%]%3D-/1$E.1RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M6$U,7U-%4DE!3$E:15)?3U!424].7T1%1D%53%1?5$%'+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?
M0TQ!4U-.04U%7T%37U1!1TY!344L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]!5%1224)55$5?2T59
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,
M25I%4E]/4%1)3TY?05144DE"551%7U194$4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]!5%1224)5
M5$5?0TQ!4U,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-
M3%]315))04Q)6D527T]05$E/3E]30T%,05)?05-?05144DE"551%4RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?
M3U!424].7U!215!%3D1?05144DE"551%4RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7TE.1$5.5%]!
M5%1224)55$53+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!8
M34Q?4T5224%,25I%4E]/4%1)3TY?34]$12P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7T1/0U194$5?
M14Y!0DQ%1"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,
M7U-%4DE!3$E:15)?3U!424].7T1/0U194$4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]23T]47TY!
M344L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))
M04Q)6D527T]05$E/3E]23T]47T%45%))0E,L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]!5%1224)5
M5$537TM%62P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,
M7U-%4DE!3$E:15)?3U!424].7T-/3E1%3E1?2T59+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?0T]-
M345.5%]+15DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-
M3%]315))04Q)6D527T]05$E/3E]404=-05`L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]%3D-/1$5?
M1E5.0RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%
M4DE!3$E:15)?3U!424].7TY!34534$%#12P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7T5.5$E42453
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,
M25I%4E]/4%1)3TY?4D5455).7U)%4U5,5"P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7TE'3D]215].
M54Q,+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T52
M24%,25I%4E]/4%1)3TY?0T1!5$%?4T5#5$E/3E,*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`I.PH@("`@"B`@("\J*@H@("`@*B!D969A=6QT
M(&]P=&EO;G,@9F]R('1H92!S97)I86QI>F%T:6]N"B`@("`J"B`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@*B!`=F%R("`@(&%R<F%Y"B`@("`J+PH@("`@
M=F%R("1?9&5F875L=$]P=&EO;G,@/2!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E])3D1%3E0@("`@("`@
M("`@("`@("`]/B`G)RP@("`@("`@("`@("`@("`@("`@("\O('-T<FEN9R!U
M<V5D(&9O<B!I;F1E;G1A=&EO;@H@("`@("`@("`@("`@("`@("`@("`@("`@
M6$U,7U-%4DE!3$E:15)?3U!424].7TQ)3D5"4D5!2U,@("`@("`@("`@(#T^
M(")<;B(L("`@("`@("`@("`@("`@("`@+R\@<W1R:6YG('5S960@9F]R(&YE
M=VQI;F5S"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%
M4E]/4%1)3TY?5%E014A)3E13("`@("`@("`@("`@/3X@9F%L<V4L("`@("`@
M("`@("`@("`@("`O+R!A=71O;6%T:6-A;&QY(&%D9"!T>7!E(&AI;B!A='1R
M:6)U=&5S"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%
M4E]/4%1)3TY?6$U,7T1%0TQ?14Y!0DQ%1"`@("`@/3X@9F%L<V4L("`@("`@
M("`@("`@("`@("`O+R!A9&0@86X@6$U,(&1E8VQA<F%T:6]N"B`@("`@("`@
M("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?6$U,7T5.
M0T]$24Y'("`@("`@("`@/3X@;G5L;"P@("`@("`@("`@("`@("`@("`O+R!E
M;F-O9&EN9R!S<&5C:69I960@:6X@=&AE(%A-3"!D96-L87)A=&EO;@H@("`@
M("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7T1%
M1D%53%1?5$%'("`@("`@("`@(#T^("=834Q?4V5R:6%L:7IE<E]486<G+"`@
M+R\@=&%G('5S960@9F]R(&EN9&5X960@87)R87ES(&]R(&EN=F%L:60@;F%M
M97,*("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]0
M5$E/3E]#3$%34TY!345?05-?5$%'3D%-12`]/B!F86QS92P@("`@("`@("`@
M("`@("`@("\O('5S92!C;&%S<VYA;64@9F]R(&]B:F5C=',@:6X@:6YD97AE
M9"!A<G)A>7,*("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)
M6D527T]05$E/3E]!5%1224)55$5?2T59("`@("`@("`]/B`G7V]R:6=I;F%L
M2V5Y)RP@("`@("`@("\O(&%T=')I8G5T92!W:&5R92!O<FEG:6YA;"!K97D@
M:7,@<W1O<F5D"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,
M25I%4E]/4%1)3TY?05144DE"551%7U194$4@("`@("`@/3X@)U]T>7!E)RP@
M("`@("`@("`@("`@("`O+R!A='1R:6)U=&4@9F]R('1Y<&4@*&]N;'D@:68@
M='EP94AI;G1S(#T^('1R=64I"B`@("`@("`@("`@("`@("`@("`@("`@("!8
M34Q?4T5224%,25I%4E]/4%1)3TY?05144DE"551%7T-,05-3("`@("`@/3X@
M)U]C;&%S<R<L("`@("`@("`@("`@("`O+R!A='1R:6)U=&4@9F]R(&-L87-S
M(&]F(&]B:F5C=',@*&]N;'D@:68@='EP94AI;G1S(#T^('1R=64I"B`@("`@
M("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?4T-!
M3$%27T%37T%45%))0E5415,@/3X@9F%L<V4L("`@("`@("`@("`@("`@("`O
M+R!S8V%L87(@=F%L=65S("AS=')I;F=S+"!I;G1S+"XN*2!W:6QL(&)E('-E
M<FEA;&EZ960@87,@871T<FEB=71E"B`@("`@("`@("`@("`@("`@("`@("`@
M("!834Q?4T5224%,25I%4E]/4%1)3TY?4%)%4$5.1%]!5%1224)55$53("`@
M/3X@)R<L("`@("`@("`@("`@("`@("`@("`O+R!P<F5P96YD('-T<FEN9R!F
M;W(@871T<FEB=71E<PH@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%
M4DE!3$E:15)?3U!424].7TE.1$5.5%]!5%1224)55$53("`@(#T^(&9A;'-E
M+"`@("`@("`@("`@("`@("`@+R\@:6YD96YT('1H92!A='1R:6)U=&5S+"!I
M9B!S970@=&\@)U]A=71O)RP@:70@=VEL;"!I;F1E;G0@871T<FEB=71E<R!S
M;R!T:&5Y(&%L;"!S=&%R="!A="!T:&4@<V%M92!C;VQU;6X*("`@("`@("`@
M("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]-3T1%("`@
M("`@("`@("`@("`@("`]/B!834Q?4T5224%,25I%4E]-3T1%7T1%1D%53%0L
M("`@("`@("`@("`@("\O('5S92!834Q?4T5224%,25I%4E]-3T1%7U-)35!,
M15A-3"!T;R!U<V4@<&%R96YT(&YA;64@87,@=&%G;F%M92!I9B!T<F%N<V9O
M<FUI;F<@86X@:6YD97AE9"!A<G)A>0H@("`@("`@("`@("`@("`@("`@("`@
M("`@6$U,7U-%4DE!3$E:15)?3U!424].7T1/0U194$5?14Y!0DQ%1"`@("`@
M(#T^(&9A;'-E+"`@("`@("`@("`@("`@("`@+R\@861D(&$@9&]C='EP92!D
M96-L87)A=&EO;@H@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!
M3$E:15)?3U!424].7T1/0U194$4@("`@("`@("`@("`@(#T^(&YU;&PL("`@
M("`@("`@("`@("`@("`@+R\@<W5P<&QY(&$@<W1R:6YG(&]R(&%N(&%R<F%Y
M('=I=&@@:60@86YD('5R:2`H>T!S964@6$U,7U5T:6PZ.F=E=$1O8W1Y<&5$
M96-L87)A=&EO;B@I?0H@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%
M4DE!3$E:15)?3U!424].7U)/3U1?3D%-12`@("`@("`@("`@(#T^(&YU;&PL
M("`@("`@("`@("`@("`@("`@+R\@;F%M92!O9B!T:&4@<F]O="!T86<*("`@
M("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]2
M3T]47T%45%))0E,@("`@("`@("`]/B!A<G)A>2@I+"`@("`@("`@("`@("`@
M("\O(&%T=')I8G5T97,@;V8@=&AE(')O;W0@=&%G"B`@("`@("`@("`@("`@
M("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?05144DE"551%4U]+
M15D@("`@("`@/3X@;G5L;"P@("`@("`@("`@("`@("`@("`O+R!A;&P@=F%L
M=65S(&EN('1H:7,@:V5Y('=I;&P@8F4@=')E871E9"!A<R!A='1R:6)U=&5S
M"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)
M3TY?0T].5$5.5%]+15D@("`@("`@("`@/3X@;G5L;"P@("`@("`@("`@("`@
M("`@("`O+R!T:&ES('9A;'5E('=I;&P@8F4@=7-E9"!D:7)E8W1L>2!A<R!C
M;VYT96YT+"!I;G-T96%D(&]F(&-R96%T:6YG(&$@;F5W('1A9RP@;6%Y(&]N
M;'D@8F4@=7-E9"!I;B!C;VYJ=6-T:6]N('=I=&@@871T<FEB=71E<T%R<F%Y
M"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)
M3TY?0T]-345.5%]+15D@("`@("`@("`@/3X@;G5L;"P@("`@("`@("`@("`@
M("`@("`O+R!T:&ES('9A;'5E('=I;&P@8F4@=7-E9"!D:7)E8W1L>2!A<R!C
M;VUM96YT+"!I;G-T96%D(&]F(&-R96%T:6YG(&$@;F5W('1A9RP@;6%Y(&]N
M;'D@8F4@=7-E9"!I;B!C;VYJ=6-T:6]N('=I=&@@871T<FEB=71E<T%R<F%Y
M"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)
M3TY?5$%'34%0("`@("`@("`@("`@("`@/3X@87)R87DH*2P@("`@("`@("`@
M("`@("`O+R!T86<@;F%M97,@=&AA="!W:6QL(&)E(&-H86YG960*("`@("`@
M("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]%3D-/
M1$5?1E5.0R`@("`@("`@("`]/B!N=6QL+"`@("`@("`@("`@("`@("`@("\O
M(&9U;F-T:6]N('1H870@=VEL;"!B92!A<'!L:65D(&)E9F]R92!S97)I86QI
M>FEN9PH@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?
M3U!424].7TY!34534$%#12`@("`@("`@("`@(#T^(&YU;&PL("`@("`@("`@
M("`@("`@("`@+R\@;F%M97-P86-E('1O('5S90H@("`@("`@("`@("`@("`@
M("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7T5.5$E42453("`@("`@
M("`@("`@(#T^(%A-3%]315))04Q)6D527T5.5$E424537UA-3"P@+R\@='EP
M92!O9B!E;G1I=&EE<R!T;R!R97!L86-E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7U)%5%523E]215-53%0@("`@
M("`@(#T^(&9A;'-E+"`@("`@("`@("`@("`@("`@+R\@<V5R:6%L:7IE*"D@
M<F5T=7)N<R!T:&4@<F5S=6QT(&]F('1H92!S97)I86QI>F%T:6]N(&EN<W1E
M860@;V8@=')U90H@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!
M3$E:15)?3U!424].7TE'3D]215].54Q,("`@("`@("`@(#T^(&9A;'-E+"`@
M("`@("`@("`@("`@("`@+R\@:6=N;W)E('!R;W!E<G1I97,@=&AA="!A<F4@
M<V5T('1O(&YU;&P*("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))
M04Q)6D527T]05$E/3E]#1$%405]314-424].4R`@("`@("`]/B!F86QS92`@
M("`@("`@("`@("`@("`@("\O(%=H971H97(@=&\@=7-E(&-D871A('-E8W1I
M;VYS(&9O<B!P;&%I;B!C:&%R86-T97(@9&%T80H@("`@("`@("`@("`@("`@
M("`@("`@("`I.PH*("`@+RHJ"B`@("`J(&]P=&EO;G,@9F]R('1H92!S97)I
M86QI>F%T:6]N"B`@("`J"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J($!V
M87(@("`@87)R87D*("`@("HO"B`@("!V87(@)&]P=&EO;G,@/2!A<G)A>2@I
M.PH*("`@+RHJ"B`@("`J(&-U<G)E;G0@=&%G(&1E<'1H"B`@("`J"B`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@*B!`=F%R("`@(&EN=&5G97(*("`@("HO
M"B`@("!V87(@)%]T86=$97!T:"`](#`["@H@("`O*BH*("`@("H@<V5R:6QI
M86QI>F5D(')E<')E<V5N=&%T:6]N(&]F('1H92!D871A"B`@("`J"B`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@*B!`=F%R("`@('-T<FEN9PH@("`@*B\*
M("`@('9A<B`D7W-E<FEA;&EZ961$871A(#T@;G5L;#L*("`@(`H@("`O*BH*
M("`@("H@8V]N<W1R=6-T;W(*("`@("H*("`@("H@0&%C8V5S<R`@('!U8FQI
M8PH@("`@*B!`<&%R86T@("`@;6EX960@("`D;W!T:6]N<R`@("!A<G)A>2!C
M;VYT86EN:6YG(&]P=&EO;G,@9F]R('1H92!S97)I86QI>F%T:6]N"B`@("`J
M+PH@("`@9G5N8W1I;VX@6$U,7U-E<FEA;&EZ97(H("1O<'1I;VYS(#T@;G5L
M;"`I"B`@("!["B`@("`@("`@)'1H:7,M/E!%05(H*3L*("`@("`@("!I9B`H
M:7-?87)R87DH)&]P=&EO;G,I*2!["B`@("`@("`@("`@("1T:&ES+3YO<'1I
M;VYS(#T@87)R87E?;65R9V4H)'1H:7,M/E]D969A=6QT3W!T:6]N<RP@)&]P
M=&EO;G,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YO
M<'1I;VYS(#T@)'1H:7,M/E]D969A=6QT3W!T:6]N<SL*("`@("`@("!]"B`@
M("!]"@H@("`O*BH*("`@("H@<F5T=7)N($%022!V97)S:6]N"B`@("`J"B`@
M("`J($!A8V-E<W,@("!P=6)L:6,*("`@("H@0'-T871I8PH@("`@*B!`<F5T
M=7)N("`@<W1R:6YG("`D=F5R<VEO;B!!4$D@=F5R<VEO;@H@("`@*B\*("`@
M(&9U;F-T:6]N(&%P:59E<G-I;VXH*0H@("`@>PH@("`@("`@(')E='5R;B`G
M,"XQ."XP)SL*("`@('T*"B`@("\J*@H@("`@*B!R97-E="!A;&P@;W!T:6]N
M<R!T;R!D969A=6QT(&]P=&EO;G,*("`@("H*("`@("H@0&%C8V5S<R`@('!U
M8FQI8PH@("`@*B!`<V5E("`@("`@<V5T3W!T:6]N*"DL(%A-3%]397)I86QI
M>F5R*"D*("`@("HO"B`@("!F=6YC=&EO;B!R97-E=$]P=&EO;G,H*0H@("`@
M>PH@("`@("`@("1T:&ES+3YO<'1I;VYS(#T@)'1H:7,M/E]D969A=6QT3W!T
M:6]N<SL*("`@('T*"B`@("\J*@H@("`@*B!S970@86X@;W!T:6]N"B`@("`J
M"B`@("`J(%EO=2!C86X@=7-E('1H:7,@;65T:&]D(&EF('EO=2!D;R!N;W0@
M=V%N="!T;R!S970@86QL(&]P=&EO;G,@:6X@=&AE(&-O;G-T<G5C=&]R"B`@
M("`J"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("H@0'-E92`@("`@(')E
M<V5T3W!T:6]N*"DL(%A-3%]397)I86QI>F5R*"D*("`@("HO"B`@("!F=6YC
M=&EO;B!S971/<'1I;VXH)&YA;64L("1V86QU92D*("`@('L*("`@("`@("`D
M=&AI<RT^;W!T:6]N<ULD;F%M95T@/2`D=F%L=64["B`@("!]"B`@("`*("`@
M+RHJ"B`@("`J('-E=',@<V5V97)A;"!O<'1I;VYS(&%T(&]N8V4*("`@("H*
M("`@("H@66]U(&-A;B!U<V4@=&AI<R!M971H;V0@:68@>6]U(&1O(&YO="!W
M86YT('1O('-E="!A;&P@;W!T:6]N<R!I;B!T:&4@8V]N<W1R=6-T;W(*("`@
M("H*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B!`<V5E("`@("`@<F5S
M971/<'1I;VXH*2P@6$U,7U5N<V5R:6%L:7IE<B@I+"!S971/<'1I;VXH*0H@
M("`@*B\*("`@(&9U;F-T:6]N('-E=$]P=&EO;G,H)&]P=&EO;G,I"B`@("![
M"B`@("`@("`@)'1H:7,M/F]P=&EO;G,@/2!A<G)A>5]M97)G92@D=&AI<RT^
M;W!T:6]N<RP@)&]P=&EO;G,I.PH@("`@?0H*("`@+RHJ"B`@("`J('-E<FEA
M;&EZ92!D871A"B`@("`J"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("H@
M0'!A<F%M("`@(&UI>&5D("`@("1D871A(&1A=&$@=&\@<V5R:6%L:7IE"B`@
M("`J($!R971U<FX@("!B;V]L96%N("!T<G5E(&]N('-U8V-E<W,L('!E87(@
M97)R;W(@;VX@9F%I;'5R90H@("`@*B\*("`@(&9U;F-T:6]N('-E<FEA;&EZ
M92@D9&%T82P@)&]P=&EO;G,@/2!N=6QL*0H@("`@>PH@("`@("`@("\O(&EF
M(&]P=&EO;G,@:&%V92!B965N('-P96-I9FEE9"P@=7-E('1H96T@:6YS=&5A
M9`H@("`@("`@("\O(&]F('1H92!P<F5V:6]U<VQY(&1E9FEN960@;VYE<PH@
M("`@("`@(&EF("AI<U]A<G)A>2@D;W!T:6]N<RDI('L*("`@("`@("`@("`@
M)&]P=&EO;G-"86L@/2`D=&AI<RT^;W!T:6]N<SL*("`@("`@("`@("`@:68@
M*&ES<V5T*"1O<'1I;VYS6R=O=F5R<FED94]P=&EO;G,G72D@)B8@)&]P=&EO
M;G-;)V]V97)R:61E3W!T:6]N<R==(#T]('1R=64I('L*("`@("`@("`@("`@
M("`@("1T:&ES+3YO<'1I;VYS(#T@87)R87E?;65R9V4H)'1H:7,M/E]D969A
M=6QT3W!T:6]N<RP@)&]P=&EO;G,I.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/F]P=&EO;G,@/2!A<G)A>5]M97)G92@D
M=&AI<RT^;W!T:6]N<RP@)&]P=&EO;G,I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&]P=&EO;G-"86L@/2!N=6QL.PH@
M("`@("`@('T*("`@("`@("`*("`@("`@("`O+R`@<W1A<G0@9&5P=&@@:7,@
M>F5R;PH@("`@("`@("1T:&ES+3Y?=&%G1&5P=&@@/2`P.PH*("`@("`@("`D
M<F]O=$%T=')I8G5T97,@/2`D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%
M4E]/4%1)3TY?4D]/5%]!5%1224)373L*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TY!34534$%#15TI
M("8F(&ES7V%R<F%Y*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]0
M5$E/3E].04U%4U!!0T5=*2D@>PH@("`@("`@(`DD<F]O=$%T=')I8G5T97-;
M)WAM;&YS.B<N)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].
M7TY!34534$%#15U;,%U=(#T@)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:
M15)?3U!424].7TY!34534$%#15U;,5T["B`@("`@("`@?0H@("`@("`@(`H@
M("`@("`@("1T:&ES+3Y?<V5R:6%L:7IE9$1A=&$@/2`G)SL*("`@("`@("`O
M+R!S97)I86QI>F4@86X@87)R87D*("`@("`@("!I9B`H:7-?87)R87DH)&1A
M=&$I*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^;W!T:6]N<UM8
M34Q?4T5224%,25I%4E]/4%1)3TY?4D]/5%].04U%72DI('L*("`@("`@("`@
M("`@("`@("1T86=.86UE(#T@)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:
M15)?3U!424].7U)/3U1?3D%-15T["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D=&%G3F%M92`]("=A<G)A>2<["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1T:&ES+3Y?<V5R:6%L:7IE9$1A=&$@+CT@)'1H
M:7,M/E]S97)I86QI>F5!<G)A>2@D9&%T82P@)'1A9TYA;64L("1R;V]T071T
M<FEB=71E<RD["B`@("`@("`@?2!E;'-E:68@*&ES7V]B:F5C="@D9&%T82DI
M('L*("`@("`@("`@("`@+R\@<V5R:6%L:7IE(&%N(&]B:F5C=`H@("`@("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?
M3U!424].7U)/3U1?3D%-15TI*2!["B`@("`@("`@("`@("`@("`D=&%G3F%M
M92`]("1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]23T]4
M7TY!345=.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)'1A9TYA;64@/2!G971?8VQA<W,H)&1A=&$I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1T:&ES+3Y?<V5R:6%L:7IE9$1A=&$@+CT@)'1H:7,M/E]S
M97)I86QI>F5/8FIE8W0H)&1A=&$L("1T86=.86UE+"`D<F]O=$%T=')I8G5T
M97,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T86<@/2!A<G)A
M>2@I.PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/F]P=&EO;G-;6$U,
M7U-%4DE!3$E:15)?3U!424].7U)/3U1?3D%-15TI*2!["B`@("`@("`@("`@
M("`@("`D=&%G6R=Q;F%M92==(#T@)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!
M3$E:15)?3U!424].7U)/3U1?3D%-15T["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D=&%G6R=Q;F%M92==(#T@9V5T='EP92@D9&%T
M82D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I
M;VYS6UA-3%]315))04Q)6D527T]05$E/3E]465!%2$E.5%-=(#T]/2!T<G5E
M*2!["B`@("`@("`@("`@("`@("`D<F]O=$%T=')I8G5T97-;)'1H:7,M/F]P
M=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7T%45%))0E5415]465!%75T@
M/2!G971T>7!E*"1D871A*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!`
M<V5T='EP92@D9&%T82P@)W-T<FEN9R<I.PH@("`@("`@("`@("`D=&%G6R=C
M;VYT96YT)UT@("`@/2`D9&%T83L*("`@("`@("`@("`@)'1A9ULG871T<FEB
M=71E<R==(#T@)')O;W1!='1R:6)U=&5S.PH@("`@("`@("`@("`D=&AI<RT^
M7W-E<FEA;&EZ961$871A(#T@)'1H:7,M/E]C<F5A=&5834Q486<H)'1A9RD[
M"B`@("`@("`@?0H@("`@("`@(`H@("`@("`@("\O(&%D9"!D;V-T>7!E(&1E
M8VQA<F%T:6]N"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6UA-3%]315))
M04Q)6D527T]05$E/3E]$3T-465!%7T5.04),141=(#T]/2!T<G5E*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<V5R:6%L:7IE9$1A=&$@/2!834Q?571I;#HZ
M9V5T1&]C='EP941E8VQA<F%T:6]N*"1T86=.86UE+"`D=&AI<RT^;W!T:6]N
M<UM834Q?4T5224%,25I%4E]/4%1)3TY?1$]#5%E015TI"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^;W!T:6]N<UM834Q?
M4T5224%,25I%4E]/4%1)3TY?3$E.14)214%+4UT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`N("1T:&ES+3Y?<V5R:6%L:7IE9$1A=&$[
M"B`@("`@("`@?0H*("`@("`@("`O+R`@8G5I;&0@>&UL(&1E8VQA<F%T:6]N
M"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]0
M5$E/3E]834Q?1$5#3%]%3D%"3$5$72D@>PH@("`@("`@("`@("`D871T<R`]
M(&%R<F%Y*"D["B`@("`@("`@("`@("1T:&ES+3Y?<V5R:6%L:7IE9$1A=&$@
M/2!834Q?571I;#HZ9V5T6$U,1&5C;&%R871I;VXH)S$N,"<L("1T:&ES+3YO
M<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]834Q?14Y#3T1)3D==*0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)'1H:7,M/F]P
M=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TQ)3D5"4D5!2U-="B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^7W-E<FEA
M;&EZ961$871A.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3YO<'1I
M;VYS6UA-3%]315))04Q)6D527T]05$E/3E]215154DY?4D5354Q472`]/3T@
M=')U92D@>PH@("`@("`@(`DD<F5S=6QT(#T@)'1H:7,M/E]S97)I86QI>F5D
M1&%T83L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S=6QT(#T@
M=')U93L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@:68@*"1O<'1I;VYS
M0F%K("$]/2!N=6QL*2!["B`@("`@("`@("`@("1T:&ES+3YO<'1I;VYS(#T@
M)&]P=&EO;G-"86L["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@('T*"B`@("\J*@H@("`@*B!G970@=&AE(')E<W5L="!O9B!T:&4@
M<V5R:6%L:7IA=&EO;@H@("`@*@H@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M*B!`<F5T=7)N('-T<FEN9R!S97)I86QI>F5D(%A-3`H@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%-E<FEA;&EZ961$871A*"D*("`@('L*("`@("`@("!I9B`H
M)'1H:7,M/E]S97)I86QI>F5D1&%T82`]/2!N=6QL*2!["B`@("`@("`@("`@
M(')E='5R;B`@)'1H:7,M/G)A:7-E17)R;W(H)TYO('-E<FEA;&EZ960@9&%T
M82!A=F%I;&%B;&4N(%5S92!834Q?4V5R:6%L:7IE<CHZ<V5R:6%L:7IE*"D@
M9FER<W0N)RP@6$U,7U-%4DE!3$E:15)?15)23U)?3D]?4T5224%,25I!5$E/
M3BD["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^7W-E<FEA;&EZ
M961$871A.PH@("`@?0H@("`@"B`@("\J*@H@("`@*B!S97)I86QI>F4@86YY
M('9A;'5E"B`@("`J"B`@("`J(%1H:7,@;65T:&]D(&-H96-K<R!F;W(@=&AE
M('1Y<&4@;V8@=&AE('9A;'5E(&%N9"!C86QL<R!T:&4@87!P<F]P<FEA=&4@
M;65T:&]D"B`@("`J"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@*B!`<&%R
M86T@(&UI>&5D("`@("`D=F%L=64*("`@("H@0'!A<F%M("!S=')I;F<@("`@
M)'1A9TYA;64*("`@("H@0'!A<F%M("!A<G)A>2`@("`@)&%T=')I8G5T97,*
M("`@("H@0')E='5R;B!S=')I;F<*("`@("HO"B`@("!F=6YC=&EO;B!?<V5R
M:6%L:7IE5F%L=64H)'9A;'5E+"`D=&%G3F%M92`](&YU;&PL("1A='1R:6)U
M=&5S(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)'9A
M;'5E*2D@>PH@("`@("`@("`@("`D>&UL(#T@)'1H:7,M/E]S97)I86QI>F5!
M<G)A>2@D=F%L=64L("1T86=.86UE+"`D871T<FEB=71E<RD["B`@("`@("`@
M?2!E;'-E:68@*&ES7V]B:F5C="@D=F%L=64I*2!["B`@("`@("`@("`@("1X
M;6P@/2`D=&AI<RT^7W-E<FEA;&EZ94]B:F5C="@D=F%L=64L("1T86=.86UE
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&%G(#T@87)R87DH
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@)W%N86UE)R`@("`@(#T^("1T
M86=.86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("=A='1R:6)U=&5S
M)R`]/B`D871T<FEB=71E<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`G
M8V]N=&5N="<@("`@/3X@)'9A;'5E"B`@("`@("`@("`@("`@("`@("`@("`@
M("D["B`@("`@("`@("`@("1X;6P@/2`D=&AI<RT^7V-R96%T95A-3%1A9R@D
M=&%G*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1X;6P["B`@("!]"B`@
M("`*("`@+RHJ"B`@("`J('-E<FEA;&EZ92!A;B!A<G)A>0H@("`@*@H@("`@
M*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`<&%R86T@("`@87)R87D@("`D
M87)R87D@("`@("`@87)R87D@=&\@<V5R:6%L:7IE"B`@("`J($!P87)A;2`@
M("!S=')I;F<@("1T86=.86UE("`@("!N86UE(&]F('1H92!R;V]T('1A9PH@
M("`@*B!`<&%R86T@("`@87)R87D@("`D871T<FEB=71E<R`@871T<FEB=71E
M<R!F;W(@=&AE(')O;W0@=&%G"B`@("`J($!R971U<FX@("!S=')I;F<@("1S
M=')I;F<@("`@("!S97)I86QI>F5D(&1A=&$*("`@("H@0'5S97,@("`@(%A-
M3%]5=&EL.CII<U9A;&ED3F%M92@I('1O(&-H96-K+"!W:&5T:&5R(&ME>2!H
M87,@=&\@8F4@<W5B<W1I='5T960*("`@("HO"B`@("!F=6YC=&EO;B!?<V5R
M:6%L:7IE07)R87DH)B1A<G)A>2P@)'1A9TYA;64@/2!N=6QL+"`D871T<FEB
M=71E<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)%]C;VYT96YT(#T@;G5L
M;#L*("`@("`@("`D7V-O;6UE;G0@/2!N=6QL.PH*("`@("`@("`O+R!C:&5C
M:R!F;W(@8V]M;65N=`H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<UM834Q?
M4T5224%,25I%4E]/4%1)3TY?0T]-345.5%]+15E=("$]/2!N=6QL*2!["B`@
M("`@("`@("`@(&EF("AI<W-E="@D87)R87E;)'1H:7,M/F]P=&EO;G-;6$U,
M7U-%4DE!3$E:15)?3U!424].7T-/34U%3E1?2T5975TI*2!["B`@("`@("`@
M("`@("`@("`D7V-O;6UE;G0@/2`D87)R87E;)'1H:7,M/F]P=&EO;G-;6$U,
M7U-%4DE!3$E:15)?3U!424].7T-/34U%3E1?2T5975T["B`@("`@("`@("`@
M("`@("!U;G-E="@D87)R87E;)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:
M15)?3U!424].7T-/34U%3E1?2T5975TI.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(`H@("`@("`@("\J*@H@("`@("`@("`J(&-H96-K(&9O
M<B!S<&5C:6%L(&%T=')I8G5T97,*("`@("`@("`@*B\*("`@("`@("!I9B`H
M)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7T%45%))0E54
M15-?2T5972`A/3T@;G5L;"D@>PH@("`@("`@("`@("!I9B`H:7-S970H)&%R
M<F%Y6R1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]!5%12
M24)55$537TM%65U=*2D@>PH@("`@("`@("`@("`@("`@)&%T=')I8G5T97,@
M/2`D87)R87E;)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].
M7T%45%))0E5415-?2T5975T["B`@("`@("`@("`@("`@("!U;G-E="@D87)R
M87E;)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7T%45%))
M0E5415-?2T5975TI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("\J*@H@
M("`@("`@("`@("`@*B!C:&5C:R!F;W(@<W!E8VEA;"!C;VYT96YT"B`@("`@
M("`@("`@("`J+PH@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;6$U,
M7U-%4DE!3$E:15)?3U!424].7T-/3E1%3E1?2T5972`A/3T@;G5L;"D@>PH@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A<G)A>5LD=&AI<RT^;W!T:6]N
M<UM834Q?4T5224%,25I%4E]/4%1)3TY?0T].5$5.5%]+15E=72DI('L*("`@
M("`@("`@("`@("`@("`@("`D7V-O;G1E;G0@/2`D87)R87E;)'1H:7,M/F]P
M=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7T-/3E1%3E1?2T5975T["B`@
M("`@("`@("`@("`@("`@("`@=6YS970H)&%R<F%Y6R1T:&ES+3YO<'1I;VYS
M6UA-3%]315))04Q)6D527T]05$E/3E]#3TY414Y47TM%65U=*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M:68@*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E])1TY/
M4D5?3E5,3%T@/3T]('1R=64I('L*("`@("`@("`)9F]R96%C:"`H87)R87E?
M:V5Y<R@D87)R87DI(&%S("1K97DI('L*("`@("`@("`)"6EF("AI<U]N=6QL
M*"1A<G)A>5LD:V5Y72DI('L*("`@("`@("`)"0EU;G-E="@D87)R87E;)&ME
M>5TI.PH@("`@("`@(`D)?0H@("`@("`@(`E]"B`@("`@("`@?0H*("`@("`@
M("`O*@H@("`@("`@("H@:68@;6]D92!I<R!S970@=&\@<VEM<&QE6$U,+"!C
M:&5C:R!W:&5T:&5R"B`@("`@("`@*B!T:&4@87)R87D@:7,@87-S;V-I871I
M=F4@;W(@:6YD97AE9`H@("`@("`@("HO"B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1A<G)A>2D@)B8@(65M<'1Y*"1A<G)A>2D@)B8@)'1H:7,M/F]P=&EO;G-;
M6$U,7U-%4DE!3$E:15)?3U!424].7TU/1$5=(#T](%A-3%]315))04Q)6D52
M7TU/1$5?4TE-4$Q%6$U,*2!["B`@("`@("`@("`@("1I;F1E>&5D(#T@=')U
M93L*("`@("`@("`@("`@9F]R96%C:"`H)&%R<F%Y(&%S("1K97D@/3X@)'9A
M;"D@>PH@("`@("`@("`@("`@("`@:68@*"%I<U]I;G0H)&ME>2DI('L*("`@
M("`@("`@("`@("`@("`@("`D:6YD97AE9"`](&9A;'-E.PH@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!I9B`H)&EN9&5X960@)B8@)'1H:7,M/F]P=&EO
M;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TU/1$5=(#T](%A-3%]315))04Q)
M6D527TU/1$5?4TE-4$Q%6$U,*2!["B`@("`@("`@("`@("`@("`D<W1R:6YG
M(#T@)R<["B`@("`@("`@("`@("`@("!F;W)E86-H("@D87)R87D@87,@)&ME
M>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`N/2`D
M=&AI<RT^7W-E<FEA;&EZ959A;'5E*"`D=F%L+"`D=&%G3F%M92P@)&%T=')I
M8G5T97,I.PH@("`@("`@("`@("`@("`@("`@(`H@("`@("`@("`@("`@("`@
M("`@("1S=')I;F<@+CT@)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?
M3U!424].7TQ)3D5"4D5!2U-=.PH@("`@("`@("`@("`@("`@("`@("\O(&1O
M(&EN9&5N=&%T:6]N"B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YO
M<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E])3D1%3E1=(3T];G5L;"`F
M)B`D=&AI<RT^7W1A9T1E<'1H/C`I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'-T<FEN9R`N/2!S=')?<F5P96%T*"1T:&ES+3YO<'1I;VYS6UA-3%]3
M15))04Q)6D527T]05$E/3E])3D1%3E1=+"`D=&AI<RT^7W1A9T1E<'1H*3L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!R971U<FX@<G1R:6TH)'-T<FEN9RD["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@)'-C86QA<D%S071T<FEB
M=71E<R`](&9A;'-E.PH@("`@("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^;W!T
M:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?4T-!3$%27T%37T%45%))0E54
M15-=*2`F)B!I<W-E="@D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/
M4%1)3TY?4T-!3$%27T%37T%45%))0E5415-=6R1T86=.86UE72DI('L*("`@
M("`@("`@("`@)'-C86QA<D%S071T<FEB=71E<R`]("1T:&ES+3YO<'1I;VYS
M6UA-3%]315))04Q)6D527T]05$E/3E]30T%,05)?05-?05144DE"551%4UU;
M)'1A9TYA;65=.PH@("`@("`@('T@96QS96EF("@D=&AI<RT^;W!T:6]N<UM8
M34Q?4T5224%,25I%4E]/4%1)3TY?4T-!3$%27T%37T%45%))0E5415-=(#T]
M/2!T<G5E*2!["B`@("`@("`@("`@("1S8V%L87)!<T%T=')I8G5T97,@/2!T
M<G5E.PH@("`@("`@('T*("`@("`@("`*("`@("`@("!I9B`H)'-C86QA<D%S
M071T<FEB=71E<R`]/3T@=')U92D@>PH@("`@("`@("`@("`D=&AI<RT^97AP
M96-T17)R;W(H)RHG*3L*("`@("`@("`@("`@9F]R96%C:"`H)&%R<F%Y(&%S
M("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?<V-A
M;&%R*"1V86QU92D@)B8@*%A-3%]5=&EL.CII<U9A;&ED3F%M92@D:V5Y*2`]
M/3T@=')U92DI('L*("`@("`@("`@("`@("`@("`@("!U;G-E="@D87)R87E;
M)&ME>5TI.PH@("`@("`@("`@("`@("`@("`@("1A='1R:6)U=&5S6R1T:&ES
M+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]04D5014Y$7T%45%))
M0E5415-=+B1K97E=(#T@)'9A;'5E.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3YP;W!%>'!E8W0H*3L*("`@
M("`@("!](&5L<V5I9B`H:7-?87)R87DH)'-C86QA<D%S071T<FEB=71E<RDI
M('L*("`@("`@("`@("`@)'1H:7,M/F5X<&5C=$5R<F]R*"<J)RD["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1S8V%L87)!<T%T=')I8G5T97,@87,@)&ME>2D@
M>PH@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D87)R87E;)&ME>5TI*2![
M"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`D=F%L=64@/2`D87)R87E;)&ME>5T["B`@
M("`@("`@("`@("`@("!I9B`H:7-?<V-A;&%R*"1V86QU92D@)B8@*%A-3%]5
M=&EL.CII<U9A;&ED3F%M92@D:V5Y*2`]/3T@=')U92DI('L*("`@("`@("`@
M("`@("`@("`@("!U;G-E="@D87)R87E;)&ME>5TI.PH@("`@("`@("`@("`@
M("`@("`@("1A='1R:6)U=&5S6R1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)
M6D527T]05$E/3E]04D5014Y$7T%45%))0E5415-=+B1K97E=(#T@)'9A;'5E
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1T:&ES+3YP;W!%>'!E8W0H*3L*("`@("`@("!]"@H@("`@("`@("\O(&-H
M96-K(&9O<B!E;7!T>2!A<G)A>2`]/B!C<F5A=&4@96UP='D@=&%G"B`@("`@
M("`@:68@*&5M<'1Y*"1A<G)A>2DI('L*("`@("`@("`@("`@)'1A9R`](&%R
M<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W%N86UE)R`@("`@
M(#T^("1T86=.86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-O
M;G1E;G0G("`@(#T^("1?8V]N=&5N="P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=A='1R:6)U=&5S)R`]/B`D871T<FEB=71E<PH@("`@("`@("`@
M("`@("`@("`@("`@("`I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1T:&ES+3Y?=&%G1&5P=&@K*SL*("`@("`@("`@("`@)'1M<"`]("1T:&ES
M+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E],24Y%0E)%04M373L*
M("`@("`@("`@("`@9F]R96%C:"`H)&%R<F%Y(&%S("1K97D@/3X@)'9A;'5E
M*2!["B`@("`@("`@("`@("`@("`O+R!D;R!I;F1E;G1A=&EO;@H@("`@("`@
M("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]0
M5$E/3E])3D1%3E1=(3T];G5L;"`F)B`D=&AI<RT^7W1A9T1E<'1H/C`I('L*
M("`@("`@("`@("`@("`@("`@("`D=&UP("X]('-T<E]R97!E870H)'1H:7,M
M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TE.1$5.5%TL("1T:&ES
M+3Y?=&%G1&5P=&@I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/
M4%1)3TY?5$%'34%075LD:V5Y72DI('L*("`@("`@("`@("`@("`@("`@("`D
M:V5Y(#T@)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7U1!
M1TU!4%U;)&ME>5T["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@+R\@8V]P>2!K97D*("`@("`@("`@("`@("`@("1O<FEG2V5Y(#T@)&ME
M>3L*("`@("`@("`@("`@("`@("1T:&ES+3YE>'!E8W1%<G)O<B@G*B<I.PH@
M("`@("`@("`@("`@("`@+R\@:V5Y(&-A;FYO="!B92!U<V5D(&%S('1A9VYA
M;64@/3X@=7-E(&1E9F%U;'0@=&%G"B`@("`@("`@("`@("`@("`D=F%L:60@
M/2!834Q?571I;#HZ:7-686QI9$YA;64H)&ME>2D["B`@("`@("`@("`@("`@
M("`D=&AI<RT^<&]P17AP96-T*"D["B`@("`@("`@("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D=F%L:60I*2!["B`@("`@("`@("`@("`@("`@("`@:68@
M*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]#3$%34TY!
M345?05-?5$%'3D%-15T@)B8@:7-?;V)J96-T*"1V86QU92DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&ME>2`](&=E=%]C;&%S<R@D=F%L=64I.PH@
M("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1K97D@/2`D=&AI<RT^7V=E=$1E9F%U;'1486=N86UE*"1T86=.
M86UE*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`D871T<R`](&%R<F%Y*"D["B`@("`@("`@("`@
M("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].
M7U194$5(24Y44UT@/3T]('1R=64I('L*("`@("`@("`@("`@("`@("`@("`D
M871T<ULD=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?0514
M4DE"551%7U194$5=72`](&=E='1Y<&4H)'9A;'5E*3L*("`@("`@("`@("`@
M("`@("`@("!I9B`H)&ME>2`A/3T@)&]R:6=+97DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&%T='-;)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:
M15)?3U!424].7T%45%))0E5415]+15E=72`]("AS=')I;F<I)&]R:6=+97D[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@("`@("1T;7`@+CT@)'1H:7,M/E]C<F5A=&5834Q486<H87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<6YA;64G("`@("`@/3X@)&ME>2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A='1R
M:6)U=&5S)R`]/B`D871T<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=C;VYT96YT)R`@("`]/B`D=F%L
M=64@*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("D["B`@("`@("`@("`@("`@("`D=&UP("X]("1T:&ES+3YO<'1I;VYS
M6UA-3%]315))04Q)6D527T]05$E/3E],24Y%0E)%04M373L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`*("`@("`@("`@("`@)'1H:7,M/E]T86=$97!T
M:"TM.PH@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!
M3$E:15)?3U!424].7TE.1$5.5%TA/3UN=6QL("8F("1T:&ES+3Y?=&%G1&5P
M=&@^,"D@>PH@("`@("`@("`@("`@("`@)'1M<"`N/2!S=')?<F5P96%T*"1T
M:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E])3D1%3E1=+"`D
M=&AI<RT^7W1A9T1E<'1H*3L*("`@("`@("`@("`@?0H@("`@"B`@("`@("`@
M("`@(&EF("AT<FEM*"1T;7`I(#T]/2`G)RD@>PH@("`@("`@("`@("`@("`@
M)'1M<"`](&YU;&P["B`@("`@("`@("`@('T*("`@("`@("`@("`@"B`@("`@
M("`@("`@("1T86<@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<6YA;64G("`@("`@/3X@)'1A9TYA;64L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V-O;G1E;G0G("`@(#T^("1T;7`L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V%T=')I8G5T97,G(#T^("1A='1R:6)U=&5S"B`@("`@
M("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@?0H@("`@("`@(&EF("@D
M=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?5%E014A)3E13
M72`]/3T@=')U92D@>PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1T86=;)V%T
M=')I8G5T97,G75LD=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)
M3TY?05144DE"551%7U194$5=72DI('L*("`@("`@("`@("`@("`@("1T86=;
M)V%T=')I8G5T97,G75LD=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/
M4%1)3TY?05144DE"551%7U194$5=72`]("=A<G)A>2<["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("1S=')I;F<@/2`G)SL*("`@("`@("!I
M9B`H(6ES7VYU;&PH)%]C;VUM96YT*2D@>PH@("`@("`@(`DD<W1R:6YG("X]
M(%A-3%]5=&EL.CIC<F5A=&5#;VUM96YT*"1?8V]M;65N="D["B`@("`@("`@
M"21S=')I;F<@+CT@)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!4
M24].7TQ)3D5"4D5!2U-=.PH@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO
M;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TE.1$5.5%TA/3UN=6QL("8F("1T
M:&ES+3Y?=&%G1&5P=&@^,"D@>PH@("`@("`@("`@("`@("`@)'-T<FEN9R`N
M/2!S=')?<F5P96%T*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]0
M5$E/3E])3D1%3E1=+"`D=&AI<RT^7W1A9T1E<'1H*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("`D<W1R:6YG("X]("1T:&ES+3Y?8W)E871E
M6$U,5&%G*"1T86<L(&9A;'-E*3L*("`@("`@("!R971U<FX@)'-T<FEN9SL*
M("`@('T*"B`@("\J*@H@("`@*B!G970@=&AE(&YA;64@;V8@=&AE(&1E9F%U
M;'0@=&%G+@H@("`@*@H@("`@*B!4:&4@;F%M92!O9B!T:&4@<&%R96YT('1A
M9R!N965D<R!T;R!B92!P87-S960@87,@=&AE"B`@("`J(&1E9F%U;'0@;F%M
M92!C86X@9&5P96YD(&]N('1H92!C;VYT97AT+@H@("`@*@H@("`@*B!`<&%R
M86T@('-T<FEN9R`@("`@;F%M92!O9B!T:&4@<&%R96YT('1A9PH@("`@*B!`
M<F5T=7)N('-T<FEN9R`@("`@9&5F875L="!T86<@;F%M90H@("`@*B\*("`@
M(&9U;F-T:6]N(%]G971$969A=6QT5&%G;F%M92@D<&%R96YT*0H@("`@>PH@
M("`@("`@(&EF("AI<U]S=')I;F<H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!
M3$E:15)?3U!424].7T1%1D%53%1?5$%'72DI('L*("`@("`@("`)<F5T=7)N
M("1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]$149!54Q4
M7U1!1UT["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^;W!T
M:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?1$5&055,5%]404==6R1P87)E
M;G1=*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]P=&EO;G-;6$U,
M7U-%4DE!3$E:15)?3U!424].7T1%1D%53%1?5$%'75LD<&%R96YT73L*("`@
M("`@("!](&5L<V5I9B`H:7-S970H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!
M3$E:15)?3U!424].7T1%1D%53%1?5$%'75LG(V1E9F%U;'0G72DI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D52
M7T]05$E/3E]$149!54Q47U1!1UU;)R-D969A=6QT)UT["B`@("`@("`@?2!E
M;'-E:68@*&ES<V5T*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]0
M5$E/3E]$149!54Q47U1!1UU;)U]?9&5F875L="==*2D@>PH@("`@("`@("`@
M("`O+R!K965P('1H:7,@9F]R($)#"B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?1$5&055,5%]404==
M6R=?7V1E9F%U;'0G73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("=834Q?
M4V5R:6%L:7IE<E]486<G.PH@("`@?0H@("`@"B`@("\J*@H@("`@*B!S97)I
M86QI>F4@86X@;V)J96-T"B`@("`J"B`@("`J($!A8V-E<W,@("!P<FEV871E
M"B`@("`J($!P87)A;2`@("!O8FIE8W0@("1O8FIE8W0@;V)J96-T('1O('-E
M<FEA;&EZ90H@("`@*B!`<F5T=7)N("`@<W1R:6YG("`D<W1R:6YG('-E<FEA
M;&EZ960@9&%T80H@("`@*B\*("`@(&9U;F-T:6]N(%]S97)I86QI>F5/8FIE
M8W0H)B1O8FIE8W0L("1T86=.86UE(#T@;G5L;"P@)&%T=')I8G5T97,@/2!A
M<G)A>2@I*0H@("`@>PH@("`@("`@("\O(&-H96-K(&9O<B!M86=I8R!F=6YC
M=&EO;@H@("`@("`@(&EF("AM971H;V1?97AI<W1S*"1O8FIE8W0L("=?7W-L
M965P)RDI('L*("`@("`@("`@("`@)'!R;W!.86UE<R`]("1O8FIE8W0M/E]?
M<VQE97`H*3L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1P<F]P3F%M97,I
M*2!["B`@("`@("`@("`@(`DD<')O<&5R=&EE<R`](&%R<F%Y*"D["B`@("`@
M("`@("`@(`EF;W)E86-H("@D<')O<$YA;65S(&%S("1P<F]P3F%M92D@>PH@
M("`@("`@("`@("`)"21P<F]P97)T:65S6R1P<F]P3F%M95T@/2`D;V)J96-T
M+3XD<')O<$YA;64["B`@("`@("`@("`@(`E]"B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D<')O<&5R=&EE<R`](&=E=%]O8FIE8W1?
M=F%R<R@D;V)J96-T*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1P<F]P97)T:65S(#T@9V5T7V]B:F5C=%]V87)S*"1O
M8FIE8W0I.PH@("`@("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1T86=.86UE
M*2D@>PH@("`@("`@("`@("`D=&%G3F%M92`](&=E=%]C;&%S<R@D;V)J96-T
M*3L*("`@("`@("!]"@H@("`@("`@("\O('1Y<&5H:6YT<R!A8W1I=F%T960_
M"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]0
M5$E/3E]465!%2$E.5%-=(#T]/2!T<G5E*2!["B`@("`@("`@("`@("1A='1R
M:6)U=&5S6R1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]!
M5%1224)55$5?5%E015U=("`]("=O8FIE8W0G.PH@("`@("`@("`@("`D871T
M<FEB=71E<ULD=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?
M05144DE"551%7T-,05-375T@/2`@9V5T7V-L87-S*"1O8FIE8W0I.PH@("`@
M("`@('T*("`@("`@("`D<W1R:6YG(#T@)'1H:7,M/E]S97)I86QI>F5!<G)A
M>2@D<')O<&5R=&EE<RP@)'1A9TYA;64L("1A='1R:6)U=&5S*3L*("`@("`@
M("!R971U<FX@)'-T<FEN9SL*("`@('T*("`*("`@+RHJ"B`@("`J(&-R96%T
M92!A('1A9R!F<F]M(&%N(&%R<F%Y"B`@("`J('1H:7,@;65T:&]D(&%W86ET
M<R!A;B!A<G)A>2!I;B!T:&4@9F]L;&]W:6YG(&9O<FUA=`H@("`@*B!A<G)A
M>2@*("`@("H@("`@("`@)W%N86UE)R`@("`@("`@/3X@)'1A9TYA;64L"B`@
M("`J("`@("`@("=A='1R:6)U=&5S)R`@(#T^(&%R<F%Y*"DL"B`@("`J("`@
M("`@("=C;VYT96YT)R`@("`@(#T^("1C;VYT96YT+"`@("`@("\O(&]P=&EO
M;F%L"B`@("`J("`@("`@("=N86UE<W!A8V4G("`@(#T^("1N86UE<W!A8V4@
M("`@("\O(&]P=&EO;F%L"B`@("`J("`@("`@("=N86UE<W!A8V55<FDG(#T^
M("1N86UE<W!A8V55<FD@("\O(&]P=&EO;F%L"B`@("`J("`@*0H@("`@*@H@
M("`@*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`<&%R86T@("`@87)R87D@
M("`D=&%G('1A9R!D969I;FET:6]N"B`@("`J($!P87)A;2`@("!B;V]L96%N
M("1R97!L86-E16YT:71I97,@=VAE=&AE<B!T;R!R97!L86-E(%A-3"!E;G1I
M=&EE<R!I;B!C;VYT96YT(&]R(&YO=`H@("`@*B!`<F5T=7)N("`@<W1R:6YG
M("`D<W1R:6YG(%A-3"!T86<*("`@("HO"B`@("!F=6YC=&EO;B!?8W)E871E
M6$U,5&%G*"1T86<L("1F:7)S=$-A;&P@/2!T<G5E*0H@("`@>PH@("`@("`@
M("\O(&)U:6QD(&9U;&QY('%U86QI9FEE9"!T86<@;F%M90H@("`@("`@(&EF
M("@D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?3D%-15-0
M04-%72`A/3T@;G5L;"D@>PH@("`@("`@(`EI9B`H:7-?87)R87DH)'1H:7,M
M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TY!34534$%#15TI*2![
M"B`@("`@("`@"0DD=&%G6R=Q;F%M92==(#T@)'1H:7,M/F]P=&EO;G-;6$U,
M7U-%4DE!3$E:15)?3U!424].7TY!34534$%#15U;,%T@+B`G.B<@+B`D=&%G
M6R=Q;F%M92==.PH@("`@("`@(`E](&5L<V4@>PH@("`@("`@(`D))'1A9ULG
M<6YA;64G72`]("1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/
M3E].04U%4U!!0T5=("X@)SHG("X@)'1A9ULG<6YA;64G73L*("`@("`@("`)
M?0H@("`@("`@('T*"B`@("`@("`@+R\@871T<FEB=71E(&EN9&5N=&%T:6]N
M"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]0
M5$E/3E])3D1%3E1?05144DE"551%4UT@(3T](&9A;'-E*2!["B`@("`@("`@
M("`@("1M=6QT:6QI;F4@/2!T<G5E.PH@("`@("`@("`@("`D:6YD96YT("`@
M(#T@<W1R7W)E<&5A="@D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/
M4%1)3TY?24Y$14Y472P@)'1H:7,M/E]T86=$97!T:"D["@H@("`@("`@("`@
M("!I9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TE.
M1$5.5%]!5%1224)55$5372`]/2`G7V%U=&\G*2!["B`@("`@("`@("`@("`@
M("`D:6YD96YT("X]('-T<E]R97!E870H)R`G+"`H<W1R;&5N*"1T86=;)W%N
M86UE)UTI*S(I*3L*"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D:6YD96YT("X]("1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D52
M7T]05$E/3E])3D1%3E1?05144DE"551%4UT["B`@("`@("`@("`@('T*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;75L=&EL:6YE(#T@9F%L<V4[
M"B`@("`@("`@("`@("1I;F1E;G0@("`@/2!F86QS93L*("`@("`@("!]"@H@
M("`@("`@(&EF("AI<U]A<G)A>2@D=&%G6R=C;VYT96YT)UTI*2!["B`@("`@
M("`@("`@(&EF("AE;7!T>2@D=&%G6R=C;VYT96YT)UTI*2!["B`@("`@("`@
M("`@("`@("`D=&%G6R=C;VYT96YT)UT@/2`@("<G.PH@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E:68H:7-?<V-A;&%R*"1T86=;)V-O;G1E;G0G72D@
M)B8@*'-T<FEN9RDD=&%G6R=C;VYT96YT)UT@/3T@)R<I('L*("`@("`@("`@
M("`@)'1A9ULG8V]N=&5N="==(#T@("`G)SL*("`@("`@("!]"@H@("`@("`@
M("\O(')E<&QA8V4@6$U,(&5N=&ET:65S("AO;FQY(&YE961E9"P@:68@=&AI
M<R!I<R!N;W0@82!N97-T960@8V%L;"D*("`@("`@("!I9B`H)&9I<G-T0V%L
M;"`]/3T@=')U92D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;
M6$U,7U-%4DE!3$E:15)?3U!424].7T-$051!7U-%0U1)3TY372`]/3T@=')U
M92D@>PH@("`@("`@("`@("`@("`@)')E<&QA8V5%;G1I=&EE<R`](%A-3%]5
M5$E,7T-$051!7U-%0U1)3TX["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@"2`@("`D<F5P;&%C945N=&ET:65S(#T@)'1H:7,M/F]P=&EO;G-;
M6$U,7U-%4DE!3$E:15)?3U!424].7T5.5$E4245373L*("`@("`@("`@("`@
M?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R97!L86-E16YT:71I
M97,@/2!834Q?4T5224%,25I%4E]%3E1)5$E%4U].3TY%.PH@("`@("`@('T*
M("`@("`@("!I9B`H:7-?<V-A;&%R*"1T86=;)V-O;G1E;G0G72D@?'P@:7-?
M;G5L;"@D=&%G6R=C;VYT96YT)UTI*2!["B`@("`@("`@("`@(&EF("@D=&AI
M<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?14Y#3T1%7T953D-=
M*2!["B`@("`@("`@("`@("`@("!I9B`H)&9I<G-T0V%L;"`]/3T@=')U92D@
M>PH@("`@("`@("`@("`@("`@"21T86=;)V-O;G1E;G0G72`](&-A;&Q?=7-E
M<E]F=6YC*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]%
M3D-/1$5?1E5.0UTL("1T86=;)V-O;G1E;G0G72D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@(`DD=&%G6R=A='1R:6)U=&5S)UT@/2!A<G)A>5]M
M87`H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7T5.0T]$
M15]&54Y#72P@)'1A9ULG871T<FEB=71E<R==*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D=&%G(#T@6$U,7U5T:6PZ.F-R96%T951A9T9R;VU!<G)A
M>2@D=&%G+"`D<F5P;&%C945N=&ET:65S+"`D;75L=&EL:6YE+"`D:6YD96YT
M+"`D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?3$E.14)2
M14%+4UTI.PH@("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D=&%G6R=C;VYT
M96YT)UTI*2!["B`@("`@("`@("`@("1T86<@("`@/2`@("1T:&ES+3Y?<V5R
M:6%L:7IE07)R87DH)'1A9ULG8V]N=&5N="==+"`D=&%G6R=Q;F%M92==+"`D
M=&%G6R=A='1R:6)U=&5S)UTI.PH@("`@("`@('T@96QS96EF("AI<U]O8FIE
M8W0H)'1A9ULG8V]N=&5N="==*2D@>PH@("`@("`@("`@("`D=&%G("`@(#T@
M("`D=&AI<RT^7W-E<FEA;&EZ94]B:F5C="@D=&%G6R=C;VYT96YT)UTL("1T
M86=;)W%N86UE)UTL("1T86=;)V%T=')I8G5T97,G72D["B`@("`@("`@?2!E
M;'-E:68@*&ES7W)E<V]U<F-E*"1T86=;)V-O;G1E;G0G72DI('L*("`@("`@
M("`@("`@<V5T='EP92@D=&%G6R=C;VYT96YT)UTL("=S=')I;F<G*3L*("`@
M("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]0
M5$E/3E]%3D-/1$5?1E5.0UTI('L*("`@("`@("`@("`@"6EF("@D<F5P;&%C
M945N=&ET:65S(#T]/2!T<G5E*2!["B`@("`@("`@("`@("`@("`@("`@)'1A
M9ULG8V]N=&5N="==(#T@8V%L;%]U<V5R7V9U;F,H)'1H:7,M/F]P=&EO;G-;
M6$U,7U-%4DE!3$E:15)?3U!424].7T5.0T]$15]&54Y#72P@)'1A9ULG8V]N
M=&5N="==*3L*("`@("`@("`@("`@"7T*("`@("`@("`@("`@"21T86=;)V%T
M=')I8G5T97,G72`](&%R<F%Y7VUA<"@D=&AI<RT^;W!T:6]N<UM834Q?4T52
M24%,25I%4E]/4%1)3TY?14Y#3T1%7T953D-=+"`D=&%G6R=A='1R:6)U=&5S
M)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T86<@/2!834Q?571I
M;#HZ8W)E871E5&%G1G)O;4%R<F%Y*"1T86<L("1R97!L86-E16YT:71I97,I
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@("1T86<["B`@("!]"GT*/SX`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O6$U,+U5N<V5R:6%L:7IE<BYP:'``````````````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P-C<T,S$`,3`U,34T,S,W,S8`,#(R-#0V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_4$A0"B\J('9I
M;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T
M86)S=&]P/30Z("HO"@HO*BH*("H@6$U,7U5N<V5R:6%L:7IE<@H@*@H@*B!0
M87)S97,@86YY(%A-3"!D;V-U;65N="!I;G1O(%!(4"!D871A('-T<G5C='5R
M97,N"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z
M(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O
M9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G
M:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@
M9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@
M86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@
M<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T
M96=O<GD@("!834P*("H@0'!A8VMA9V4@("`@6$U,7U-E<FEA;&EZ97(*("H@
M0&%U=&AO<B`@("`@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@
M*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC
M96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!0
M2%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%5N<V5R
M:6%L:7IE<BYP:'`L=B`Q+C,Y(#(P,#4O,#DO,C@@,3$Z,3DZ-38@<V-H<W0@
M17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+UA-3%]397)I86QI>F5R"B`J($!S964@("`@("`@(%A-3%]5;G-E<FEA
M;&EZ97(*("HO"@HO*BH*("H@=7-E<R!014%2(&5R<F]R(&UA;F%G96UT"B`J
M+PIR97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*"B\J*@H@*B!U<V5S(%A-3%]0
M87)S97(@=&\@=6YS97)I86QI>F4@9&]C=6UE;G0*("HO"G)E<75I<F5?;VYC
M92`G6$U,+U!A<G-E<BYP:'`G.PH*+RHJ"B`J(&]P=&EO;CH@0V]N=F5R="!N
M97-T960@=&%G<R!T;R!A<G)A>2!O<B!O8FIE8W0*("H*("H@4&]S<VEB;&4@
M=F%L=65S.@H@*B`M(&%R<F%Y"B`J("T@;V)J96-T"B`J("T@87-S;V-I871I
M=F4@87)R87D@=&\@9&5F:6YE('1H:7,@;W!T:6]N('!E<B!T86<@;F%M90H@
M*B\*9&5F:6YE*"=834Q?54Y315))04Q)6D527T]05$E/3E]#3TU03$585%E0
M12<L("=C;VUP;&5X5'EP92<I.PH*+RHJ"B`J(&]P=&EO;CH@3F%M92!O9B!T
M:&4@871T<FEB=71E('1H870@<W1O<F5S('1H92!O<FEG:6YA;"!K97D*("H*
M("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M(&%N>2!S=')I;F<*("HO"F1E9FEN
M92@G6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"551%7TM%62<L("=K
M97E!='1R:6)U=&4G*3L*"B\J*@H@*B!O<'1I;VXZ($YA;64@;V8@=&AE(&%T
M=')I8G5T92!T:&%T('-T;W)E<R!T:&4@='EP90H@*@H@*B!0;W-S:6)L92!V
M86QU97,Z"B`J("T@86YY('-T<FEN9PH@*B\*9&5F:6YE*"=834Q?54Y315))
M04Q)6D527T]05$E/3E]!5%1224)55$5?5%E012<L("=T>7!E071T<FEB=71E
M)RD["@HO*BH*("H@;W!T:6]N.B!.86UE(&]F('1H92!A='1R:6)U=&4@=&AA
M="!S=&]R97,@=&AE(&-L87-S(&YA;64*("H*("H@4&]S<VEB;&4@=F%L=65S
M.@H@*B`M(&%N>2!S=')I;F<*("HO"F1E9FEN92@G6$U,7U5.4T5224%,25I%
M4E]/4%1)3TY?05144DE"551%7T-,05-3)RP@)V-L87-S071T<FEB=71E)RD[
M"@HO*BH*("H@;W!T:6]N.B!7:&5T:&5R('1O('5S92!T:&4@=&%G(&YA;64@
M87,@82!C;&%S<R!N86UE"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@+2!T
M<G5E(&]R(&9A;'-E"B`J+PID969I;F4H)UA-3%]53E-%4DE!3$E:15)?3U!4
M24].7U1!1U]!4U]#3$%34TY!344G+"`G=&%G07-#;&%S<R<I.PH*+RHJ"B`J
M(&]P=&EO;CH@3F%M92!O9B!T:&4@9&5F875L="!C;&%S<PH@*@H@*B!0;W-S
M:6)L92!V86QU97,Z"B`J("T@86YY('-T<FEN9PH@*B\*9&5F:6YE*"=834Q?
M54Y315))04Q)6D527T]05$E/3E]$149!54Q47T-,05-3)RP@)V1E9F%U;'1#
M;&%S<R<I.PH*+RHJ"B`J(&]P=&EO;CH@5VAE=&AE<B!T;R!P87)S92!A='1R
M:6)U=&5S"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@+2!T<G5E(&]R(&9A
M;'-E"B`J+PID969I;F4H)UA-3%]53E-%4DE!3$E:15)?3U!424].7T%45%))
M0E5415-?4$%24T4G+"`G<&%R<V5!='1R:6)U=&5S)RD["@HO*BH*("H@;W!T
M:6]N.B!+97D@;V8@=&AE(&%R<F%Y('1O('-T;W)E(&%T=')I8G5T97,@*&EF
M(&%N>2D*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M(&%N>2!S=')I;F<*
M("H@+2!F86QS92`H9&ES86)L960I"B`J+PID969I;F4H)UA-3%]53E-%4DE!
M3$E:15)?3U!424].7T%45%))0E5415-?05)205E+15DG+"`G871T<FEB=71E
M<T%R<F%Y)RD["@HO*BH*("H@;W!T:6]N.B!S=')I;F<@=&\@<')E<&5N9"!A
M='1R:6)U=&4@;F%M92`H:68@86YY*0H@*@H@*B!0;W-S:6)L92!V86QU97,Z
M"B`J("T@86YY('-T<FEN9PH@*B`M(&9A;'-E("AD:7-A8FQE9"D*("HO"F1E
M9FEN92@G6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"551%4U]04D50
M14Y$)RP@)W!R97!E;F1!='1R:6)U=&5S)RD["@HO*BH*("H@;W!T:6]N.B!K
M97D@=&\@<W1O<F4@=&AE(&-O;G1E;G0L(&EF(%A-3%]53E-%4DE!3$E:15)?
M3U!424].7T%45%))0E5415-?4$%24T4@:7,@=7-E9`H@*@H@*B!0;W-S:6)L
M92!V86QU97,Z"B`J("T@86YY('-T<FEN9PH@*B\*9&5F:6YE*"=834Q?54Y3
M15))04Q)6D527T]05$E/3E]#3TY414Y47TM%62<L("=C;VYT96YT3F%M92<I
M.PH*+RHJ"B`J(&]P=&EO;CH@;6%P('1A9R!N86UE<PH@*@H@*B!0;W-S:6)L
M92!V86QU97,Z"B`J("T@87-S;V-I871I=F4@87)R87D*("HO"F1E9FEN92@G
M6$U,7U5.4T5224%,25I%4E]/4%1)3TY?5$%'7TU!4"<L("=T86=-87`G*3L*
M"B\J*@H@*B!O<'1I;VXZ(&QI<W0@;V8@=&%G<R!T:&%T('=I;&P@86QW87ES
M(&)E(&5N=6UE<F%T960*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M(&EN
M9&5X960@87)R87D*("HO"F1E9FEN92@G6$U,7U5.4T5224%,25I%4E]/4%1)
M3TY?1D]20T5?14Y532<L("=F;W)C945N=6TG*3L*"B\J*@H@*B!O<'1I;VXZ
M($5N8V]D:6YG(&]F('1H92!834P@9&]C=6UE;G0*("H*("H@4&]S<VEB;&4@
M=F%L=65S.@H@*B`M(%541BTX"B`J("T@25-/+3@X-3DM,0H@*B\*9&5F:6YE
M*"=834Q?54Y315))04Q)6D527T]05$E/3E]%3D-/1$E.1U]33U520T4G+"`G
M96YC;V1I;F<G*3L*"B\J*@H@*B!O<'1I;VXZ($1E<VER960@=&%R9V5T(&5N
M8V]D:6YG(&]F('1H92!D871A"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@
M+2!55$8M.`H@*B`M($E33RTX.#4Y+3$*("HO"F1E9FEN92@G6$U,7U5.4T52
M24%,25I%4E]/4%1)3TY?14Y#3T1)3D=?5$%21T54)RP@)W1A<F=E=$5N8V]D
M:6YG)RD["@HO*BH*("H@;W!T:6]N.B!#86QL8F%C:R!T:&%T('=I;&P@8F4@
M87!P;&EE9"!T;R!T97AT=6%L(&1A=&$*("H*("H@4&]S<VEB;&4@=F%L=65S
M.@H@*B`M(&%N>2!V86QI9"!02%`@8V%L;&)A8VL*("HO"F1E9FEN92@G6$U,
M7U5.4T5224%,25I%4E]/4%1)3TY?1$5#3T1%7T953D,G+"`G9&5C;V1E1G5N
M8W1I;VXG*3L*"B\J*@H@*B!O<'1I;VXZ('=H971H97(@=&\@<F5T=7)N('1H
M92!R97-U;'0@;V8@=&AE('5N<V5R:6%L:7IA=&EO;B!F<F]M('5N<V5R:6%L
M:7IE*"D*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M('1R=64*("H@+2!F
M86QS92`H9&5F875L="D*("HO"F1E9FEN92@G6$U,7U5.4T5224%,25I%4E]/
M4%1)3TY?4D5455).7U)%4U5,5"<L("=R971U<FY297-U;'0G*3L*"B\J*@H@
M*B!O<'1I;VXZ('-E="!T:&4@=VAI=&5S<&%C92!B96AA=FEO=7(*("H*("H@
M4&]S<VEB;&4@=F%L=65S.@H@*B`M(%A-3%]53E-%4DE!3$E:15)?5TA)5$53
M4$%#15]+1450"B`J("T@6$U,7U5.4T5224%,25I%4E]72$E415-004-%7U12
M24T*("H@+2!834Q?54Y315))04Q)6D527U=(251%4U!!0T5?3D]234%,25I%
M"B`J+PID969I;F4H)UA-3%]53E-%4DE!3$E:15)?3U!424].7U=(251%4U!!
M0T4G+"`G=VAI=&5S<&%C92<I.PH*+RHJ"B`J($ME97`@86QL('=H:71E<W!A
M8V4*("HO"F1E9FEN92@G6$U,7U5.4T5224%,25I%4E]72$E415-004-%7TM%
M15`G+"`G:V5E<"<I.PH*+RHJ"B`J(')E;6]V92!W:&ET97-P86-E(&9R;VT@
M<W1A<G0@86YD(&5N9"!O9B!T:&4@9&%T80H@*B\*9&5F:6YE*"=834Q?54Y3
M15))04Q)6D527U=(251%4U!!0T5?5%))32<L("=T<FEM)RD["@HO*BH*("H@
M;F]R;6%L:7IE('=H:71E<W!A8V4*("HO"F1E9FEN92@G6$U,7U5.4T5224%,
M25I%4E]72$E415-004-%7TY/4DU!3$E:12<L("=N;W)M86QI>F4G*3L*"B\J
M*@H@*B!O<'1I;VXZ('=H971H97(@=&\@;W9V97)R:61E(&%L;"!O<'1I;VYS
M('1H870@:&%V92!B965N('-E="!B969O<F4*("H*("H@4&]S<VEB;&4@=F%L
M=65S.@H@*B`M('1R=64*("H@+2!F86QS92`H9&5F875L="D*("HO"F1E9FEN
M92@G6$U,7U5.4T5224%,25I%4E]/4%1)3TY?3U9%4E))1$5?3U!424].4R<L
M("=O=F5R<FED94]P=&EO;G,G*3L*"B\J*@H@*B!O<'1I;VXZ(&QI<W0@;V8@
M=&%G<RP@=&AA="!W:6QL(&YO="!B92!U<V5D(&%S(&ME>7,*("HO"F1E9FEN
M92@G6$U,7U5.4T5224%,25I%4E]/4%1)3TY?24=.3U)%7TM%65,G+"`G:6=N
M;W)E2V5Y<R<I.PH*+RHJ"B`J(&]P=&EO;CH@=VAE=&AE<B!T;R!U<V4@='EP
M92!G=65S<VEN9R!F;W(@<V-A;&%R('9A;'5E<PH@*B\*9&5F:6YE*"=834Q?
M54Y315))04Q)6D527T]05$E/3E]'54534U]465!%4R<L("=G=65S<U1Y<&5S
M)RD["@HO*BH*("H@97)R;W(@8V]D92!F;W(@;F\@<V5R:6%L:7IA=&EO;B!D
M;VYE"B`J+PID969I;F4H)UA-3%]53E-%4DE!3$E:15)?15)23U)?3D]?54Y3
M15))04Q)6D%424].)RP@,34Q*3L*"B\J*@H@*B!834Q?56YS97)I86QI>F5R
M"B`J"B`J(&-L87-S('1O('5N<V5R:6%L:7IE(%A-3"!D;V-U;65N=',@=&AA
M="!H879E(&)E96X@8W)E871E9"!W:71H"B`J(%A-3%]397)I86QI>F5R+B!4
M;R!U;G-E<FEA;&EZ92!A;B!834P@9&]C=6UE;G0@>6]U(&AA=F4@=&\@861D
M"B`J('1Y<&4@:&EN=',@=&\@=&AE(%A-3%]397)I86QI>F5R(&]P=&EO;G,N
M"B`J"B`J($EF(&YO('1Y<&4@:&EN=',@87)E(&%V86EL86)L92P@6$U,7U5N
M<V5R:6%L:7IE<B!W:6QL(&=U97-S(&AO=PH@*B!T:&4@=&%G<R!S:&]U;&0@
M8F4@=')E871E9"P@=&AA="!M96%N<R!C;VUP;&5X('-T<G5C='5R97,@=VEL
M;"!B90H@*B!A<G)A>7,@86YD('1A9W,@=VET:"!O;FQY($-$871A(&EN('1H
M96T@=VEL;"!B92!S=')I;F=S+@H@*@H@*B`\8V]D93X*("H@<F5Q=6ER95]O
M;F-E("=834PO56YS97)I86QI>F5R+G!H<"<["B`J"B`J("\O("!B92!C87)E
M9G5L('1O(&%L=V%Y<R!U<V4@=&AE(&%M<&5R<V%N9"!I;B!F<F]N="!O9B!T
M:&4@;F5W(&]P97)A=&]R"B`J("1U;G-E<FEA;&EZ97(@/2`F;F5W(%A-3%]5
M;G-E<FEA;&EZ97(H*3L*("H*("H@)'5N<V5R:6%L:7IE<BT^=6YS97)I86QI
M>F4H)'AM;"D["B`J"B`J("1D871A(#T@)'5N<V5R:6%L:7IE<BT^9V5T56YS
M97)I86QI>F5D1&%T82@I.PH@*B`\8V]D93X*("H*("H*("H@0&-A=&5G;W)Y
M("`@6$U,"B`J($!P86-K86=E("`@(%A-3%]397)I86QI>F5R"B`J($!A=71H
M;W(@("`@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@
M("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI
M8V5N<V4@,RXP"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#`N,3@N,`H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O6$U,7U-E
M<FEA;&EZ97(*("H@0'-E92`@("`@("`@6$U,7U-E<FEA;&EZ97(*("HO"F-L
M87-S(%A-3%]5;G-E<FEA;&EZ97(@97AT96YD<R!014%2"GL*("`@+RHJ"B`@
M("`J(&QI<W0@;V8@86QL(&%V86EL86)L92!O<'1I;VYS"B`@("`J"B`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@*B!`=F%R("`@(&%R<F%Y"B`@("`J+PH@
M("`@=F%R("1?:VYO=VY/<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?0T]-
M4$Q%6%194$4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,
M7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"551%7TM%62P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/
M3E]!5%1224)55$5?5%E012P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]!5%1224)55$5?0TQ!4U,L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,
M25I%4E]/4%1)3TY?5$%'7T%37T-,05-33D%-12P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]$149!
M54Q47T-,05-3+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-
M3%]53E-%4DE!3$E:15)?3U!424].7T%45%))0E5415-?4$%24T4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/
M4%1)3TY?05144DE"551%4U]!4E)!64M%62P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]!5%1224)5
M5$537U!215!%3D0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M6$U,7U5.4T5224%,25I%4E]/4%1)3TY?0T].5$5.5%]+15DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)
M3TY?5$%'7TU!4"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!8
M34Q?54Y315))04Q)6D527T]05$E/3E]&3U)#15]%3E5-+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].
M7T5.0T]$24Y'7U-/55)#12P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]%3D-/1$E.1U]405)'150L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,
M25I%4E]/4%1)3TY?1$5#3T1%7T953D,L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?4D5455).7U)%
M4U5,5"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?54Y3
M15))04Q)6D527T]05$E/3E]72$E415-004-%+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].7TE'3D]2
M15]+15E3+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]5
M3E-%4DE!3$E:15)?3U!424].7T=515-37U194$53"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("D["B`@("\J*@H@("`@*B!D969A=6QT(&]P=&EO
M;G,@9F]R('1H92!S97)I86QI>F%T:6]N"B`@("`J"B`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@*B!`=F%R("`@(&%R<F%Y"B`@("`J+PH@("`@=F%R("1?
M9&5F875L=$]P=&EO;G,@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@
M("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].7T-/35!,15A465!%("`@("`@
M("`@/3X@)V%R<F%Y)RP@("`@("`@("`@("`@("`@+R\@8V]M<&QE>"!T>7!E
M<R!W:6QL(&)E(&-O;G9E<G1E9"!T;R!A<G)A>7,L(&EF(&YO('1Y<&4@:&EN
M="!I<R!G:79E;@H@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T52
M24%,25I%4E]/4%1)3TY?05144DE"551%7TM%62`@("`@("`]/B`G7V]R:6=I
M;F%L2V5Y)RP@("`@("`@("`O+R!G970@87)R87D@:V5Y+W!R;W!E<G1Y(&YA
M;64@9G)O;2!T:&ES(&%T=')I8G5T90H@("`@("`@("`@("`@("`@("`@("`@
M("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"551%7U194$4@("`@
M("`]/B`G7W1Y<&4G+"`@("`@("`@("`@("`@("`O+R!G970@='EP92!F<F]M
M('1H:7,@871T<FEB=71E"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?
M54Y315))04Q)6D527T]05$E/3E]!5%1224)55$5?0TQ!4U,@("`@(#T^("=?
M8VQA<W,G+"`@("`@("`@("`@("`@("\O(&=E="!C;&%S<R!F<F]M('1H:7,@
M871T<FEB=71E("AI9B!N;W0@9VEV96XL('5S92!T86<@;F%M92D*("`@("`@
M("`@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].7U1!
M1U]!4U]#3$%34TY!344@("`@/3X@=')U92P@("`@("`@("`@("`@("`@("`@
M+R\@=7-E('1H92!T86=N86UE(&%S('1H92!C;&%S<VYA;64*("`@("`@("`@
M("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].7T1%1D%5
M3%1?0TQ!4U,@("`@("`@/3X@)W-T9$-L87-S)RP@("`@("`@("`@("`@+R\@
M;F%M92!O9B!T:&4@8VQA<W,@=&AA="!I<R!U<V5D('1O(&-R96%T92!O8FIE
M8W1S"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?54Y315))04Q)6D52
M7T]05$E/3E]!5%1224)55$537U!!4E-%("`@(#T^(&9A;'-E+"`@("`@("`@
M("`@("`@("`@("\O('!A<G-E('1H92!A='1R:6)U=&5S(&]F('1H92!T86<@
M:6YT;R!A;B!A<G)A>0H@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U5.
M4T5224%,25I%4E]/4%1)3TY?05144DE"551%4U]!4E)!64M%62`]/B!F86QS
M92P@("`@("`@("`@("`@("`@("`O+R!P87)S92!T:&5M(&EN=&\@<W!E<F%T
M92!A<G)A>2`H<W!E8VEF>2!N86UE(&]F(&%R<F%Y(&AE<F4I"B`@("`@("`@
M("`@("`@("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]!5%12
M24)55$537U!215!%3D0@(#T^("<G+"`@("`@("`@("`@("`@("`@("`@("\O
M('!R97!E;F0@871T<FEB=71E(&YA;65S('=I=&@@=&AI<R!S=')I;F<*("`@
M("`@("`@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].
M7T-/3E1%3E1?2T59("`@("`@("`@/3X@)U]C;VYT96YT)RP@("`@("`@("`@
M("`@+R\@<'5T(&-D871A(&9O=6YD(&EN(&$@=&%G('1H870@:&%S(&)E96X@
M8V]N=F5R=&5D('1O(&$@8V]M<&QE>"!T>7!E(&EN('1H:7,@:V5Y"B`@("`@
M("`@("`@("`@("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]4
M04=?34%0("`@("`@("`@("`@(#T^(&%R<F%Y*"DL("`@("`@("`@("`@("`@
M("\O('5S92!T:&ES('1O(&UA<"!T86=N86UE<PH@("`@("`@("`@("`@("`@
M("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?1D]20T5?14Y532`@
M("`@("`@("`]/B!A<G)A>2@I+"`@("`@("`@("`@("`@("`O+R!T:&5S92!T
M86=S('=I;&P@86QW87ES(&)E(&%N(&EN9&5X960@87)R87D*("`@("`@("`@
M("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].7T5.0T]$
M24Y'7U-/55)#12`@("`@/3X@;G5L;"P@("`@("`@("`@("`@("`@("`@+R\@
M<W!E8VEF>2!T:&4@96YC;V1I;F<@8VAA<F%C=&5R(&]F('1H92!D;V-U;65N
M="!T;R!P87)S90H@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T52
M24%,25I%4E]/4%1)3TY?14Y#3T1)3D=?5$%21T54("`@("`]/B!N=6QL+"`@
M("`@("`@("`@("`@("`@("`O+R!S<&5C:69Y('1H92!T87)G970@96YC;V1I
M;F<*("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?
M3U!424].7T1%0T]$15]&54Y#("`@("`@("`@/3X@;G5L;"P@("`@("`@("`@
M("`@("`@("`@+R\@9G5N8W1I;VX@=7-E9"!T;R!D96-O9&4@9&%T80H@("`@
M("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?
M4D5455).7U)%4U5,5"`@("`@("`]/B!F86QS92P@("`@("`@("`@("`@("`@
M("`O+R!U;G-E<FEA;&EZ92@I(')E='5R;G,@=&AE(')E<W5L="!O9B!T:&4@
M=6YS97)I86QI>F%T:6]N(&EN<W1E860@;V8@=')U90H@("`@("`@("`@("`@
M("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?5TA)5$534$%#
M12`@("`@("`@("`]/B!834Q?54Y315))04Q)6D527U=(251%4U!!0T5?5%))
M32P@+R\@<F5M;W9E('=H:71E<W!A8V4@87)O=6YD(&1A=&$*("`@("`@("`@
M("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].7TE'3D]2
M15]+15E3("`@("`@("`@/3X@87)R87DH*2P@("`@("`@("`@("`@("`@+R\@
M3&ES="!O9B!T86=S('1H870@=VEL;"!A=71O;6%T:6-A;&QY(&)E(&%D9&5D
M('1O('1H92!P87)E;G0L(&EN<W1E860@;V8@861D:6YG(&$@;F5W(&ME>0H@
M("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)
M3TY?1U5%4U-?5%E015,@("`@("`@("`]/B!F86QS92`@("`@("`@("`@("`@
M("`@("`O+R!7:&5T:&5R('1O('5S92!T>7!E(&=U97-S:6YG"B`@("`@("`@
M("`@("`@("`@("`@("`@("D["@H@("`O*BH*("`@("H@8W5R<F5N="!O<'1I
M;VYS(&9O<B!T:&4@<V5R:6%L:7IA=&EO;@H@("`@*@H@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@*B!`=F%R("`@(&%R<F%Y"B`@("`J+PH@("`@=F%R("1O
M<'1I;VYS(#T@87)R87DH*3L*"B`@("\J*@H@("`@*B!U;G-E<FEA;&EZ960@
M9&%T80H@("`@*@H@("`@*B!`86-C97-S('!R:79A=&4*("`@("H@0'9A<B`@
M("!S=')I;F<*("`@("HO"B`@("!V87(@)%]U;G-E<FEA;&EZ961$871A(#T@
M;G5L;#L*"B`@("\J*@H@("`@*B!N86UE(&]F('1H92!R;V]T('1A9PH@("`@
M*@H@("`@*B!`86-C97-S('!R:79A=&4*("`@("H@0'9A<B`@("!S=')I;F<*
M("`@("HO"B`@("!V87(@)%]R;V]T(#T@;G5L;#L*"B`@("\J*@H@("`@*B!S
M=&%C:R!F;W(@86QL(&1A=&$@=&AA="!I<R!F;W5N9`H@("`@*@H@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("H@0'9A<B`@("!A<G)A>0H@("`@*B\*("`@
M('9A<B`D7V1A=&%3=&%C:R`@/2`@(&%R<F%Y*"D["@H@("`O*BH*("`@("H@
M<W1A8VL@9F]R(&%L;"!V86QU97,@=&AA="!A<F4@9V5N97)A=&5D"B`@("`J
M"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@*B!`=F%R("`@(&%R<F%Y"B`@
M("`J+PH@("`@=F%R("1?=F%L4W1A8VL@(#T@("!A<G)A>2@I.PH*("`@+RHJ
M"B`@("`J(&-U<G)E;G0@=&%G(&1E<'1H"B`@("`J"B`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@*B!`=F%R("`@(&EN=`H@("`@*B\*("`@('9A<B`D7V1E
M<'1H(#T@,#L*"B`@("\J*@H@("`@*B!834Q?4&%R<V5R(&EN<W1A;F-E"B`@
M("`J"B`@("`J($!A8V-E<W,@("!P<FEV871E"B`@("`J($!V87(@("`@("!O
M8FIE8W0@6$U,7U!A<G-E<@H@("`@*B\*("`@('9A<B`D7W!A<G-E<B`](&YU
M;&P["B`@("`*("`@+RHJ"B`@("`J(&-O;G-T<G5C=&]R"B`@("`J"B`@("`J
M($!A8V-E<W,@("!P=6)L:6,*("`@("H@0'!A<F%M("`@(&UI>&5D("`@)&]P
M=&EO;G,@("`@87)R87D@8V]N=&%I;FEN9R!O<'1I;VYS(&9O<B!T:&4@=6YS
M97)I86QI>F%T:6]N"B`@("`J+PH@("`@9G5N8W1I;VX@6$U,7U5N<V5R:6%L
M:7IE<B@D;W!T:6]N<R`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1O<'1I;VYS*2D@>PH@("`@("`@("`@("`D=&AI<RT^;W!T:6]N<R`]
M(&%R<F%Y7VUE<F=E*"1T:&ES+3Y?9&5F875L=$]P=&EO;G,L("1O<'1I;VYS
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^;W!T:6]N
M<R`]("1T:&ES+3Y?9&5F875L=$]P=&EO;G,["B`@("`@("`@?0H@("`@?0H*
M("`@+RHJ"B`@("`J(')E='5R;B!!4$D@=F5R<VEO;@H@("`@*@H@("`@*B!`
M86-C97-S("`@<'5B;&EC"B`@("`J($!S=&%T:6,*("`@("H@0')E='5R;B`@
M('-T<FEN9R`@)'9E<G-I;VX@05!)('9E<G-I;VX*("`@("HO"B`@("!F=6YC
M=&EO;B!A<&E697)S:6]N*"D*("`@('L*("`@("`@("!R971U<FX@)S`N,3@N
M,"<["B`@("!]"@H@("`O*BH*("`@("H@<F5S970@86QL(&]P=&EO;G,@=&\@
M9&5F875L="!O<'1I;VYS"B`@("`J"B`@("`J($!A8V-E<W,@("!P=6)L:6,*
M("`@("H@0'-E92`@("`@('-E=$]P=&EO;B@I+"!834Q?56YS97)I86QI>F5R
M*"DL('-E=$]P=&EO;G,H*0H@("`@*B\*("`@(&9U;F-T:6]N(')E<V5T3W!T
M:6]N<R@I"B`@("!["B`@("`@("`@)'1H:7,M/F]P=&EO;G,@/2`D=&AI<RT^
M7V1E9F%U;'1/<'1I;VYS.PH@("`@?0H*("`@+RHJ"B`@("`J('-E="!A;B!O
M<'1I;VX*("`@("H*("`@("H@66]U(&-A;B!U<V4@=&AI<R!M971H;V0@:68@
M>6]U(&1O(&YO="!W86YT('1O('-E="!A;&P@;W!T:6]N<R!I;B!T:&4@8V]N
M<W1R=6-T;W(*("`@("H*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B!`
M<V5E("`@("`@<F5S971/<'1I;VXH*2P@6$U,7U5N<V5R:6%L:7IE<B@I+"!S
M971/<'1I;VYS*"D*("`@("HO"B`@("!F=6YC=&EO;B!S971/<'1I;VXH)&YA
M;64L("1V86QU92D*("`@('L*("`@("`@("`D=&AI<RT^;W!T:6]N<ULD;F%M
M95T@/2`D=F%L=64["B`@("!]"@H@("`O*BH*("`@("H@<V5T<R!S979E<F%L
M(&]P=&EO;G,@870@;VYC90H@("`@*@H@("`@*B!9;W4@8V%N('5S92!T:&ES
M(&UE=&AO9"!I9B!Y;W4@9&\@;F]T('=A;G0@=&\@<V5T(&%L;"!O<'1I;VYS
M(&EN('1H92!C;VYS=')U8W1O<@H@("`@*@H@("`@*B!`86-C97-S("`@<'5B
M;&EC"B`@("`J($!S964@("`@("!R97-E=$]P=&EO;B@I+"!834Q?56YS97)I
M86QI>F5R*"DL('-E=$]P=&EO;B@I"B`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M3W!T:6]N<R@D;W!T:6]N<RD*("`@('L*("`@("`@("`D=&AI<RT^;W!T:6]N
M<R`](&%R<F%Y7VUE<F=E*"1T:&ES+3YO<'1I;VYS+"`D;W!T:6]N<RD["B`@
M("!]"@H@("`O*BH*("`@("H@=6YS97)I86QI>F4@9&%T80H@("`@*@H@("`@
M*B!`86-C97-S("`@<'5B;&EC"B`@("`J($!P87)A;2`@("!M:7AE9"`@("`D
M9&%T82`@("`@9&%T82!T;R!U;G-E<FEA;&EZ92`H<W1R:6YG+"!F:6QE;F%M
M92!O<B!R97-O=7)C92D*("`@("H@0'!A<F%M("`@(&)O;VQE86X@("1I<T9I
M;&4@("!D871A('-H;W5L9"!B92!T<F5A=&5D(&%S(&$@9FEL90H@("`@*B!`
M<&%R86T@("`@87)R87D@("`@)&]P=&EO;G,@(&]P=&EO;G,@=&AA="!W:6QL
M(&]V97)R:61E('1H92!G;&]B86P@;W!T:6]N<R!F;W(@=&AI<R!C86QL"B`@
M("`J($!R971U<FX@("!B;V]L96%N("`D<W5C8V5S<PH@("`@*B\*("`@(&9U
M;F-T:6]N('5N<V5R:6%L:7IE*"1D871A+"`D:7-&:6QE(#T@9F%L<V4L("1O
M<'1I;VYS(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7W5N<V5R:6%L
M:7IE9$1A=&$@/2!N=6QL.PH@("`@("`@("1T:&ES+3Y?<F]O="`](&YU;&P[
M"@H@("`@("`@("\O(&EF(&]P=&EO;G,@:&%V92!B965N('-P96-I9FEE9"P@
M=7-E('1H96T@:6YS=&5A9`H@("`@("`@("\O(&]F('1H92!P<F5V:6]U<VQY
M(&1E9FEN960@;VYE<PH@("`@("`@(&EF("AI<U]A<G)A>2@D;W!T:6]N<RDI
M('L*("`@("`@("`@("`@)&]P=&EO;G-"86L@/2`D=&AI<RT^;W!T:6]N<SL*
M("`@("`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6UA-3%]53E-%4DE!3$E:
M15)?3U!424].7T]615)2241%7T]05$E/3E-=*2`F)B`D;W!T:6]N<UM834Q?
M54Y315))04Q)6D527T]05$E/3E]/5D524DE$15]/4%1)3TY372`]/2!T<G5E
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^;W!T:6]N<R`](&%R<F%Y7VUE
M<F=E*"1T:&ES+3Y?9&5F875L=$]P=&EO;G,L("1O<'1I;VYS*3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3YO<'1I;VYS
M(#T@87)R87E?;65R9V4H)'1H:7,M/F]P=&EO;G,L("1O<'1I;VYS*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1O<'1I
M;VYS0F%K(#T@;G5L;#L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?=F%L
M4W1A8VL@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3Y?9&%T85-T86-K(#T@
M87)R87DH*3L*("`@("`@("`D=&AI<RT^7V1E<'1H(#T@,#L*"B`@("`@("`@
M)'1H:7,M/E]C<F5A=&5087)S97(H*3L*("`@("`@("`*("`@("`@("!I9B`H
M:7-?<W1R:6YG*"1D871A*2D@>PH@("`@("`@("`@("!I9B`H)&ES1FEL92D@
M>PH@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?<&%R<V5R+3YS
M971);G!U=$9I;&4H)&1A=&$I.PH@("`@("`@("`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("1R97-U;'0@/2`D=&AI<RT^7W!A<G-E<BT^<&%R<V4H*3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M7W!A<G-E<BT^<&%R<V53=')I;F<H)&1A=&$L=')U92D["B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("1T:&ES+3Y?<&%R<V5R
M+3YS971);G!U="@D9&%T82D["B`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?<&%R<V5R+3YP87)S92@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T
M:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].7U)%5%523E]2
M15-53%1=(#T]/2!T<G5E*2!["B`@("`@("`@"21R971U<FX@/2`D=&AI<RT^
M7W5N<V5R:6%L:7IE9$1A=&$["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)')E='5R;B`]('1R=64["B`@("`@("`@?0H*("`@("`@("!I9B`H)&]P
M=&EO;G-"86L@(3T](&YU;&PI('L*("`@("`@("`@("`@)'1H:7,M/F]P=&EO
M;G,@/2`D;W!T:6]N<T)A:SL*("`@("`@("!]"@H@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R971U<FX["B`@("!]
M"@H@("`O*BH*("`@("H@9V5T('1H92!R97-U;'0@;V8@=&AE('-E<FEA;&EZ
M871I;VX*("`@("H*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@0')E='5R
M;B!S=')I;F<@("1S97)I86QI>F5D1&%T80H@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=%5N<V5R:6%L:7IE9$1A=&$H*0H@("`@>PH@("`@("`@(&EF("@D=&AI
M<RT^7W)O;W0@/3T](&YU;&PI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"=.;R!U;G-E<FEA;&EZ960@9&%T82!A=F%I;&%B;&4N
M(%5S92!834Q?56YS97)I86QI>F5R.CIU;G-E<FEA;&EZ92@I(&9I<G-T+B<L
M(%A-3%]53E-%4DE!3$E:15)?15)23U)?3D]?54Y315))04Q)6D%424].*3L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=6YS97)I86QI>F5D
M1&%T83L*("`@('T*"B`@("\J*@H@("`@*B!G970@=&AE(&YA;64@;V8@=&AE
M(')O;W0@=&%G"B`@("`J"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J($!R
M971U<FX@<W1R:6YG("`D<F]O=$YA;64*("`@("HO"B`@("!F=6YC=&EO;B!G
M9712;V]T3F%M92@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?<F]O="`]
M/3T@;G5L;"D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H)TYO('5N<V5R:6%L:7IE9"!D871A(&%V86EL86)L92X@57-E(%A-3%]5
M;G-E<FEA;&EZ97(Z.G5N<V5R:6%L:7IE*"D@9FER<W0N)RP@6$U,7U5.4T52
M24%,25I%4E]%4E)/4E].3U]53E-%4DE!3$E:051)3TXI.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)'1H:7,M/E]R;V]T.PH@("`@?0H*("`@+RHJ"B`@
M("`J(%-T87)T(&5L96UE;G0@:&%N9&QE<B!F;W(@6$U,('!A<G-E<@H@("`@
M*@H@("`@*B!`86-C97-S('!R:79A=&4*("`@("H@0'!A<F%M("!O8FIE8W0@
M)'!A<G-E<B`@6$U,('!A<G-E<B!O8FIE8W0*("`@("H@0'!A<F%M("!S=')I
M;F<@)&5L96UE;G0@6$U,(&5L96UE;G0*("`@("H@0'!A<F%M("!A<G)A>2`@
M)&%T=')I8G,@871T<FEB=71E<R!O9B!834P@=&%G"B`@("`J($!R971U<FX@
M=F]I9`H@("`@*B\*("`@(&9U;F-T:6]N('-T87)T2&%N9&QE<B@D<&%R<V5R
M+"`D96QE;65N="P@)&%T=')I8G,I"B`@("!["B`@("`@("`@:68@*&ES<V5T
M*"1A='1R:6)S6R1T:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!4
M24].7T%45%))0E5415]465!%75TI*2!["B`@("`@("`@("`@("1T>7!E(#T@
M)&%T=')I8G-;)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)
M3TY?05144DE"551%7U194$5=73L*("`@("`@("`@("`@)&=U97-S5'EP92`]
M(&9A;'-E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T>7!E(#T@
M)W-T<FEN9R<["B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<UM834Q?
M54Y315))04Q)6D527T]05$E/3E]'54534U]465!%4UT@/3T]('1R=64I('L*
M("`@("`@("`@("`@("`@("1G=65S<U1Y<&4@/2!T<G5E.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&=U97-S5'EP92`](&9A;'-E
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M
M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?1$5#3T1%7T953D-=
M("$]/2!N=6QL*2!["B`@("`@("`@("`@("1A='1R:6)S(#T@87)R87E?;6%P
M*"1T:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].7T1%0T]$
M15]&54Y#72P@)&%T=')I8G,I.PH@("`@("`@('T*("`@("`@("`*("`@("`@
M("`D=&AI<RT^7V1E<'1H*RL["B`@("`@("`@)'1H:7,M/E]D871A4W1A8VM;
M)'1H:7,M/E]D97!T:%T@/2!N=6QL.PH*("`@("`@("!I9B`H:7-?87)R87DH
M)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?5$%'7TU!
M4%TI("8F(&ES<V5T*"1T:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?
M3U!424].7U1!1U]-05!=6R1E;&5M96YT72DI('L*("`@("`@("`@("`@)&5L
M96UE;G0@/2`D=&AI<RT^;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/
M3E]404=?34%075LD96QE;65N=%T["B`@("`@("`@?0H*("`@("`@("`D=F%L
M(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("=N86UE)R`@("`@("`@
M(#T^("1E;&5M96YT+`H@("`@("`@("`@("`@("`@("`@("`G=F%L=64G("`@
M("`@("`]/B!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`G='EP92<@("`@
M("`@("`]/B`D='EP92P*("`@("`@("`@("`@("`@("`@("`@)V=U97-S5'EP
M92<@("`@/3X@)&=U97-S5'EP92P*("`@("`@("`@("`@("`@("`@("`@)V-H
M:6QD<F5N2V5Y<R<@/3X@87)R87DH*2P*("`@("`@("`@("`@("`@("`@("`@
M)V%G9W)E9TME>7,G("`@/3X@87)R87DH*0H@("`@("`@("`@("`@("`@("`@
M("D["@H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<UM834Q?54Y315))04Q)
M6D527T]05$E/3E]!5%1224)55$537U!!4E-%72`]/2!T<G5E("8F("AC;W5N
M="@D871T<FEB<RD@/B`P*2D@>PH@("`@("`@("`@("`D=F%L6R=C:&EL9')E
M;B==(#T@87)R87DH*3L*("`@("`@("`@("`@)'9A;%LG='EP92==("`]("1T
M:&ES+3Y?9V5T0V]M<&QE>%1Y<&4H)&5L96UE;G0I.PH@("`@("`@("`@("`D
M=F%L6R=C;&%S<R==(#T@)&5L96UE;G0["@H@("`@("`@("`@("!I9B`H)'1H
M:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?1U5%4U-?5%E0
M15-=(#T]/2!T<G5E*2!["B`@("`@("`@("`@(`DD871T<FEB<R`]("1T:&ES
M+3Y?9W5E<W-!;F139714>7!E<R@D871T<FEB<RD["B`@("`@("`@("`@('T@
M("`@("`@("`@("`*("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6UA-
M3%]53E-%4DE!3$E:15)?3U!424].7T%45%))0E5415-?05)205E+15E=("$]
M(&9A;'-E*2!["B`@("`@("`@("`@("`@("`D=F%L6R=C:&EL9')E;B==6R1T
M:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].7T%45%))0E54
M15-?05)205E+15E=72`]("1A='1R:6)S.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&%T=')I8G,@87,@)&%T=')I
M8B`]/B`D=F%L=64I('L*("`@("`@("`@("`@("`@("`@("`D=F%L6R=C:&EL
M9')E;B==6R1T:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].
M7T%45%))0E5415-?4%)%4$5.1%TN)&%T=')I8ET@/2`D=F%L=64["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("1K97E!='1R(#T@9F%L<V4["B`@("`@("`@"B`@("`@("`@:68@*&ES7W-T
M<FEN9R@D=&AI<RT^;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/3E]!
M5%1224)55$5?2T5972DI('L*("`@("`@("`@("`@)&ME>4%T='(@/2`D=&AI
M<RT^;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/3E]!5%1224)55$5?
M2T5973L*("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH)'1H:7,M/F]P=&EO
M;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"551%7TM%65TI*2![
M"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^;W!T:6]N<UM834Q?54Y3
M15))04Q)6D527T]05$E/3E]!5%1224)55$5?2T5975LD96QE;65N=%TI*2![
M"B`@("`@("`@("`@("`@("`D:V5Y071T<B`]("1T:&ES+3YO<'1I;VYS6UA-
M3%]53E-%4DE!3$E:15)?3U!424].7T%45%))0E5415]+15E=6R1E;&5M96YT
M73L*("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3YO<'1I;VYS
M6UA-3%]53E-%4DE!3$E:15)?3U!424].7T%45%))0E5415]+15E=6R<C9&5F
M875L="==*2D@>PH@("`@("`@("`@("`@("`@)&ME>4%T='(@/2`D=&AI<RT^
M;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/3E]!5%1224)55$5?2T59
M75LG(V1E9F%U;'0G73L*("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T
M:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].7T%45%))0E54
M15]+15E=6R=?7V1E9F%U;'0G72DI('L*("`@("`@("`@("`@("`@("\O(&ME
M97`@=&AI<R!F;W(@0D,*("`@("`@("`@("`@("`@("1K97E!='1R(#T@)'1H
M:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"551%
M7TM%65U;)U]?9&5F875L="==.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(`H@("`@("`@(&EF("@D:V5Y071T<B`A/3T@9F%L<V4@)B8@:7-S
M970H)&%T=')I8G-;)&ME>4%T=')=*2D@>PH@("`@("`@("`@("`D=F%L6R=N
M86UE)UT@/2`D871T<FEB<ULD:V5Y071T<ET["B`@("`@("`@?0H*("`@("`@
M("!I9B`H:7-S970H)&%T=')I8G-;)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T52
M24%,25I%4E]/4%1)3TY?05144DE"551%7T-,05-375TI*2!["B`@("`@("`@
M("`@("1V86Q;)V-L87-S)UT@/2`D871T<FEB<ULD=&AI<RT^;W!T:6]N<UM8
M34Q?54Y315))04Q)6D527T]05$E/3E]!5%1224)55$5?0TQ!4U-=73L*("`@
M("`@("!]"@H@("`@("`@(&%R<F%Y7W!U<V@H)'1H:7,M/E]V86Q3=&%C:RP@
M)'9A;"D["B`@("!]"@H@("`O*BH*("`@("H@5')Y('1O(&=U97-S('1H92!T
M>7!E(&]F('-E=F5R86P@=F%L=65S(&%N9`H@("`@*B!S970@=&AE;2!A8V-O
M<F1I;F=L>0H@("`@*@H@("`@*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`
M<&%R86T@("`@87)R87D@("`@("!A<G)A>2P@8V]N=&%I;FEN9R!T:&4@=F%L
M=65S"B`@("`J($!R971U<FX@("!A<G)A>2`@("`@(&%R<F%Y+"!C;VYT86EN
M:6YG('1H92!V86QU97,@=VET:"!T:&5I<B!C;W)R96-T('1Y<&5S(`H@("`@
M*B\*("`@(&9U;F-T:6]N(%]G=65S<T%N9%-E=%1Y<&5S*"1A<G)A>2D*("`@
M('L*("`@("`@("!F;W)E86-H("@D87)R87D@87,@)&ME>2`]/B`D=F%L=64I
M('L*("`@("`@("`))&%R<F%Y6R1K97E=(#T@)'1H:7,M/E]G=65S<T%N9%-E
M=%1Y<&4H)'9A;'5E*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1A<G)A
M>3L*("`@('T*("`@(`H@("`O*BH*("`@("H@5')Y('1O(&=U97-S('1H92!T
M>7!E(&]F(&$@=F%L=64@86YD"B`@("`J('-E="!I="!A8V-O<F1I;F=L>0H@
M("`@*@H@("`@*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`<&%R86T@("`@
M<W1R:6YG("`@("`@8VAA<F%C=&5R(&1A=&$*("`@("H@0')E='5R;B`@(&UI
M>&5D("`@("`@('9A;'5E('=I=&@@=&AE(&)E<W0@;6%T8VAI;F<@='EP90H@
M("`@*B\*("`@(&9U;F-T:6]N(%]G=65S<T%N9%-E=%1Y<&4H)'9A;'5E*0H@
M("`@>PH@("`@("`@(&EF("@D=F%L=64@/3T]("=T<G5E)RD@>PH@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("!]"B`@("`@("`@:68@*"1V86QU
M92`]/3T@)V9A;'-E)RD@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H@("`@("`@(&EF("@D=F%L=64@/3T]("=.54Q,)RD@>PH@("`@
M("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@("`@:68@*'!R
M96=?;6%T8V@H)R]>6RTK73];,"TY77LQ+'TD+R<L("1V86QU92DI('L*("`@
M("`@("`)<F5T=7)N(&EN='9A;"@D=F%L=64I.PH@("`@("`@('T*("`@("`@
M("!I9B`H<')E9U]M871C:"@G+UY;+2M=/ULP+3E=>S$L?5PN6S`M.5U[,2Q]
M)"\G+"`D=F%L=64I*2!["B`@("`@("`@"7)E='5R;B!D;W5B;&5V86PH)'9A
M;'5E*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("AS=')I;F<I)'9A;'5E
M.PH@("`@?0H@("`@"B`@("\J*@H@("`@*B!%;F0@96QE;65N="!H86YD;&5R
M(&9O<B!834P@<&%R<V5R"B`@("`J"B`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@*B!`<&%R86T@(&]B:F5C="!834P@<&%R<V5R(&]B:F5C=`H@("`@*B!`
M<&%R86T@('-T<FEN9PH@("`@*B!`<F5T=7)N('9O:60*("`@("HO"B`@("!F
M=6YC=&EO;B!E;F1(86YD;&5R*"1P87)S97(L("1E;&5M96YT*0H@("`@>PH@
M("`@("`@("1V86QU92`](&%R<F%Y7W!O<"@D=&AI<RT^7W9A;%-T86-K*3L*
M("`@("`@("!S=VET8V@@*"1T:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:
M15)?3U!424].7U=(251%4U!!0T5=*2!["B`@("`@("`@("`@(&-A<V4@6$U,
M7U5.4T5224%,25I%4E]72$E415-004-%7TM%15`Z"B`@("`@("`@("`@("`@
M("`D9&%T82`]("1T:&ES+3Y?9&%T85-T86-K6R1T:&ES+3Y?9&5P=&A=.PH@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@6$U,7U5.
M4T5224%,25I%4E]72$E415-004-%7TY/4DU!3$E:13H*("`@("`@("`@("`@
M("`@("1D871A(#T@=')I;2AP<F5G7W)E<&QA8V4H)R]<<UQS*R]M)RP@)R`G
M+"`D=&AI<RT^7V1A=&%3=&%C:ULD=&AI<RT^7V1E<'1H72DI.PH@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@6$U,7U5.4T5224%,
M25I%4E]72$E415-004-%7U1224TZ"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@
M("`@("`@("`@("`@("`D9&%T82`@/2!T<FEM*"1T:&ES+3Y?9&%T85-T86-K
M6R1T:&ES+3Y?9&5P=&A=*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@('T*"B`@("`@("`@+R\@861J=7-T('1Y<&4@;V8@=&AE('9A;'5E"B`@
M("`@("`@<W=I=&-H*'-T<G1O;&]W97(H)'9A;'5E6R=T>7!E)UTI*2!["@H@
M("`@("`@("`@("`O+R!U;G-E<FEA;&EZ92!A;B!O8FIE8W0*("`@("`@("`@
M("`@8V%S92`G;V)J96-T)SH*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M=F%L=65;)V-L87-S)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&-L87-S
M;F%M92`@/2`D=F%L=65;)V-L87-S)UT["B`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("1C;&%S<VYA;64@/2`G)SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("\O(&EN<W1A;G1I871E
M('1H92!C;&%S<PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS
M6UA-3%]53E-%4DE!3$E:15)?3U!424].7U1!1U]!4U]#3$%34TY!345=(#T]
M/2!T<G5E("8F(&-L87-S7V5X:7-T<R@D8VQA<W-N86UE*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1V86QU95LG=F%L=64G72`]("9N97<@)&-L87-S;F%M
M93L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@)'9A;'5E6R=V86QU92==(#T@)FYE=R`D=&AI<RT^;W!T:6]N<UM834Q?
M54Y315))04Q)6D527T]05$E/3E]$149!54Q47T-,05-373L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&EF("AT<FEM*"1D871A*2`A/3T@
M)R<I('L*("`@("`@("`@("`@("`@("`@("!I9B`H)'9A;'5E6R=G=65S<U1Y
M<&4G72`]/3T@=')U92D@>PH@("`@("`@("`@("`@("`@("`@(`DD9&%T82`]
M("1T:&ES+3Y?9W5E<W-!;F139714>7!E*"1D871A*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E6R=C:&EL9')E
M;B==6R1T:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].7T-/
M3E1%3E1?2T5975T@/2`D9&%T83L*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("`O+R!S970@<')O<&5R=&EE<PH@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)'9A;'5E6R=C:&EL9')E;B==(&%S("1P<F]P(#T^("1P<F]P
M5F%L*2!["B`@("`@("`@("`@("`@("`@("`@+R\@8VAE8VL@=VAE=&AE<B!T
M:&5R92!I<R!A('-P96-I86P@;65T:&]D('1O('-E="!T:&ES('!R;W!E<G1Y
M"B`@("`@("`@("`@("`@("`@("`@)'-E=$UE=&AO9"`]("=S970G+B1P<F]P
M.PH@("`@("`@("`@("`@("`@("`@(&EF("AM971H;V1?97AI<W1S*"1V86QU
M95LG=F%L=64G72P@)'-E=$UE=&AO9"DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@8V%L;%]U<V5R7V9U;F,H87)R87DH)B1V86QU95LG=F%L=64G72P@
M)'-E=$UE=&AO9"DL("1P<F]P5F%L*3L*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=65;)W9A;'5E
M)UTM/B1P<F]P(#T@)'!R;W!686P["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@+R\@(&-H96-K(&9O
M<B!M86=I8R!F=6YC=&EO;@H@("`@("`@("`@("`@("`@:68@*&UE=&AO9%]E
M>&ES=',H)'9A;'5E6R=V86QU92==+"`G7U]W86ME=7`G*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1V86QU95LG=F%L=64G72T^7U]W86ME=7`H*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@+R\@=6YS97)I86QI>F4@86X@87)R87D*("`@("`@("`@("`@8V%S
M92`G87)R87DG.@H@("`@("`@("`@("`@("`@:68@*'1R:6TH)&1A=&$I("$]
M/2`G)RD@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D=F%L=65;)V=U97-S
M5'EP92==(#T]/2!T<G5E*2!["B`@("`@("`@("`@("`@("`@("`@"21D871A
M(#T@)'1H:7,M/E]G=65S<T%N9%-E=%1Y<&4H)&1A=&$I.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D=F%L=65;)V-H:6QD
M<F5N)UU;)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?
M0T].5$5.5%]+15E=72`]("1D871A.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1V86QU95LG8VAI;&1R96XG72DI('L*
M("`@("`@("`@("`@("`@("`@("`D=F%L=65;)W9A;'5E)UT@/2`D=F%L=65;
M)V-H:6QD<F5N)UT["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1V86QU95LG=F%L=64G72`](&%R<F%Y*"D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("\O('5N<V5R:6%L:7IE(&$@;G5L;"!V86QU90H@("`@("`@("`@("!C
M87-E("=N=6QL)SH*("`@("`@("`@("`@("`@("1D871A(#T@;G5L;#L*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@+R\@=6YS97)I86QI
M>F4@82!R97-O=7)C92`]/B!T:&ES(&ES(&YO="!P;W-S:6)L92`Z+2@*("`@
M("`@("`@("`@8V%S92`G<F5S;W5R8V4G.@H@("`@("`@("`@("`@("`@)'9A
M;'5E6R=V86QU92==(#T@)&1A=&$["B`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@("\O('5N<V5R:6%L:7IE(&%N>2!S8V%L87(@=F%L=64*
M("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@(&EF("@D=F%L
M=65;)V=U97-S5'EP92==(#T]/2!T<G5E*2!["B`@("`@("`@("`@("`@("`@
M("`@)&1A=&$@/2`D=&AI<RT^7V=U97-S06YD4V5T5'EP92@D9&%T82D["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@('-E
M='1Y<&4H)&1A=&$L("1V86QU95LG='EP92==*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@"B`@("`@("`@("`@("`@("`D=F%L=65;)W9A;'5E
M)UT@/2`D9&%T83L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*
M("`@("`@("`D<&%R96YT(#T@87)R87E?<&]P*"1T:&ES+3Y?=F%L4W1A8VLI
M.PH@("`@("`@(&EF("@D<&%R96YT(#T]/2!N=6QL*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?=6YS97)I86QI>F5D1&%T82`]("8D=F%L=65;)W9A;'5E)UT[
M"B`@("`@("`@("`@("1T:&ES+3Y?<F]O="`]("8D=F%L=65;)VYA;64G73L*
M("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@+R\@<&%R96YT(&AA<R!T;R!B92!A;B!A<G)A>0H@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1P87)E;G1;)V-H:6QD<F5N)UTI('Q\("%I<U]A
M<G)A>2@D<&%R96YT6R=C:&EL9')E;B==*2D@>PH@("`@("`@("`@("`@("`@
M)'!A<F5N=%LG8VAI;&1R96XG72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@
M("!I9B`H(6EN7V%R<F%Y*"1P87)E;G1;)W1Y<&4G72P@87)R87DH)V%R<F%Y
M)RP@)V]B:F5C="<I*2D@>PH@("`@("`@("`@("`@("`@("`@("1P87)E;G1;
M)W1Y<&4G72`]("1T:&ES+3Y?9V5T0V]M<&QE>%1Y<&4H)'!A<F5N=%LG;F%M
M92==*3L*("`@("`@("`@("`@("`@("`@("!I9B`H)'!A<F5N=%LG='EP92==
M(#T]("=O8FIE8W0G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1P87)E
M;G1;)V-L87-S)UT@/2`D<&%R96YT6R=N86UE)UT["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!I9B`H:6Y?87)R87DH)&5L96UE;G0L("1T:&ES+3YO<'1I;VYS
M6UA-3%]53E-%4DE!3$E:15)?3U!424].7TE'3D]215]+15E372DI('L*("`@
M("`@("`@("`@("`@("1I9VYO<F5+97D@/2!T<G5E.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`))&EG;F]R94ME>2`](&9A;'-E.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(`H@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1V86QU95LG;F%M92==*2`F)B`D:6=N;W)E2V5Y(#T]/2!F86QS92D@>PH@
M("`@("`@("`@("`@("`@+R\@=&AE<F4@86QR96%D>2!H87,@8F5E;B!A('1A
M9R!W:71H('1H:7,@;F%M90H@("`@("`@("`@("`@("`@:68@*&EN7V%R<F%Y
M*"1V86QU95LG;F%M92==+"`D<&%R96YT6R=C:&EL9')E;DME>7,G72D@?'P@
M:6Y?87)R87DH)'9A;'5E6R=N86UE)UTL("1T:&ES+3YO<'1I;VYS6UA-3%]5
M3E-%4DE!3$E:15)?3U!424].7T9/4D-%7T5.54U=*2D@>PH@("`@("`@("`@
M("`@("`@("`@("\O(&YO(&%G9W)E9V%T92!H87,@8F5E;B!C<F5A=&5D(&9O
M<B!T:&ES('1A9PH@("`@("`@("`@("`@("`@("`@(&EF("@A:6Y?87)R87DH
M)'9A;'5E6R=N86UE)UTL("1P87)E;G1;)V%G9W)E9TME>7,G72DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P87)E;G1;)V-H:6QD
M<F5N)UU;)'9A;'5E6R=N86UE)UU=*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!A<F5N=%LG8VAI;&1R96XG75LD=F%L=65;)VYA;64G75T@
M/2!A<G)A>2@D<&%R96YT6R=C:&EL9')E;B==6R1V86QU95LG;F%M92==72D[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<&%R96YT6R=C:&EL9')E;B==6R1V86QU95LG
M;F%M92==72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?<'5S:"@D<&%R96YT6R=A
M9V=R96=+97ES)UTL("1V86QU95LG;F%M92==*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@87)R87E?<'5S:"@D<&%R96YT
M6R=C:&EL9')E;B==6R1V86QU95LG;F%M92==72P@)'9A;'5E6R=V86QU92==
M*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@)'!A<F5N=%LG8VAI;&1R96XG75LD=F%L=65;)VYA;64G75T@/2`F)'9A
M;'5E6R=V86QU92==.PH@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H
M)'!A<F5N=%LG8VAI;&1R96Y+97ES)UTL("1V86QU95LG;F%M92==*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@(&%R<F%Y7W!U<V@H)'!A<F5N=%LG8VAI;&1R96XG72P@)'9A;'5E
M6R=V86QU92==*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!A<G)A>5]P
M=7-H*"1T:&ES+3Y?=F%L4W1A8VLL("1P87)E;G0I.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/E]D97!T:"TM.PH@("`@?0H*("`@+RHJ"B`@("`J($AA
M;F1L97(@9F]R(&-H87)A8W1E<B!D871A"B`@("`J"B`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@*B!`<&%R86T@(&]B:F5C="!834P@<&%R<V5R(&]B:F5C
M=`H@("`@*B!`<&%R86T@('-T<FEN9R!#1$%400H@("`@*B!`<F5T=7)N('9O
M:60*("`@("HO"B`@("!F=6YC=&EO;B!C9&%T84AA;F1L97(H)'!A<G-E<BP@
M)&-D871A*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<UM834Q?
M54Y315))04Q)6D527T]05$E/3E]$14-/1$5?1E5.0UT@(3T](&YU;&PI('L*
M("`@("`@("`@("`@)&-D871A(#T@8V%L;%]U<V5R7V9U;F,H)'1H:7,M/F]P
M=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?1$5#3T1%7T953D-=+"`D
M8V1A=&$I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7V1A=&%3=&%C:ULD
M=&AI<RT^7V1E<'1H72`N/2`D8V1A=&$["B`@("!]"@H@("`O*BH*("`@("H@
M9V5T('1H92!C;VUP;&5X('1Y<&4L('1H870@<VAO=6QD(&)E('5S960@9F]R
M(&$@<W!E8VEF:65D('1A9PH@("`@*@H@("`@*B!`86-C97-S("`@<')I=F%T
M90H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@;F%M92!O9B!T:&4@=&%G
M"B`@("`J($!R971U<FX@("!S=')I;F<@("`@("!C;VUP;&5X('1Y<&4@*"=A
M<G)A>2<@;W(@)V]B:F5C="<I"B`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$-O
M;7!L97A4>7!E*"1T86=N86UE*0H@("`@>PH@("`@("`@(&EF("AI<U]S=')I
M;F<H)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?0T]-
M4$Q%6%194$5=*2D@>PH@("`@("`@(`ER971U<FX@)'1H:7,M/F]P=&EO;G-;
M6$U,7U5.4T5224%,25I%4E]/4%1)3TY?0T]-4$Q%6%194$5=.PH@("`@("`@
M('T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T52
M24%,25I%4E]/4%1)3TY?0T]-4$Q%6%194$5=6R1T86=N86UE72DI('L*("`@
M("`@("`)<F5T=7)N("1T:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?
M3U!424].7T-/35!,15A465!%75LD=&%G;F%M95T["B`@("`@("`@?0H@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^;W!T:6]N<UM834Q?54Y315))04Q)6D52
M7T]05$E/3E]#3TU03$585%E015U;)R-D969A=6QT)UTI*2!["B`@("`@("`@
M"7)E='5R;B`D=&AI<RT^;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/
M3E]#3TU03$585%E015U;)R-D969A=6QT)UT["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`G87)R87DG.PH@("`@?0H@("`@"B`@("\J*@H@("`@*B!C<F5A
M=&4@=&AE(%A-3%]087)S97(@:6YS=&%N8V4*("`@("H*("`@("H@0&%C8V5S
M<R`@("!P<FEV871E"B`@("`J($!R971U<FX@("`@8F]O;&5A;@H@("`@*B\*
M("`@(&9U;F-T:6]N(%]C<F5A=&5087)S97(H*0H@("`@>PH@("`@("`@(&EF
M("AI<U]O8FIE8W0H)'1H:7,M/E]P87)S97(I*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?<&%R<V5R+3YF<F5E*"D["B`@("`@("`@("`@('5N<V5T*"1T:&ES
M+3Y?<&%R<V5R*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]P87)S97(@
M/2`F;F5W(%A-3%]087)S97(H)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,
M25I%4E]/4%1)3TY?14Y#3T1)3D=?4T]54D-%72P@)V5V96YT)RP@)'1H:7,M
M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?14Y#3T1)3D=?5$%2
M1T5472D["B`@("`@("`@)'1H:7,M/E]P87)S97(M/F9O;&1I;F<@/2!F86QS
M93L*("`@("`@("`D=&AI<RT^7W!A<G-E<BT^<V5T2&%N9&QE<D]B:B@D=&AI
M<RD["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"GT*/SX`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O6$U,+U5T:6PN<&AP````````
M````````````````````````````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P-C4S-C,`,3`U
M,34T,S,W,S8`,#(P-S$Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_4$A0#0HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B
M<W1O<#TT('-H:69T=VED=&@]-#H@*B\-"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PT*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@0V]P>7)I9VAT
M("AC*2`Q.3DW+3(P,#(@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK#0HO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S
M:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P-"B\O('P@=&AA
M="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)
M0T5.4T4L(&%N9"!I<R`@("`@("`@?`T*+R\@?"!A=F%I;&%B;&4@870@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\#0HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?
M,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O
M('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L
M:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`T*+R\@?"!O8G1A:6X@:70@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T
M92!T;R`@("`@("`@("!\#0HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C
M86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@
M('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!!=71H
M;W)S.B!3=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"UT;V]L<RYN970^("`@
M("`@("`@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L-"B\O#0HO+R`@("`D260Z(%5T:6PN<&AP+'8@,2XR-"`R,#`T
M+S$R+S(S(#$S.C(Q.C4Y('-C:'-T($5X<"`D#0H-"B\J*@T*("H@97)R;W(@
M8V]D92!F;W(@:6YV86QI9"!C:&%R<R!I;B!834P@;F%M90T*("HO#0ID969I
M;F4H(EA-3%]55$E,7T524D]27TE.5D%,241?0TA!4E,B+"`U,2D[#0H-"B\J
M*@T*("H@97)R;W(@8V]D92!F;W(@:6YV86QI9"!C:&%R<R!I;B!834P@;F%M
M90T*("HO#0ID969I;F4H(EA-3%]55$E,7T524D]27TE.5D%,241?4U1!4E0B
M+"`U,BD[#0H-"B\J*@T*("H@97)R;W(@8V]D92!F;W(@;F]N+7-C86QA<B!T
M86<@8V]N=&5N=`T*("HO#0ID969I;F4H(EA-3%]55$E,7T524D]27TY/3E]3
M0T%,05)?0T].5$5.5"(L(#8P*3L-"B`@("`-"B\J*@T*("H@97)R;W(@8V]D
M92!F;W(@;6ES<VEN9R!T86<@;F%M90T*("HO#0ID969I;F4H(EA-3%]55$E,
M7T524D]27TY/7U1!1U].04U%(BP@-C$I.PT*("`@(`T*+RHJ#0H@*B!R97!L
M86-E(%A-3"!E;G1I=&EE<PT*("HO#0ID969I;F4H(EA-3%]55$E,7U)%4$Q!
M0T5?14Y4251)15,B+"`Q*3L-"@T*+RHJ#0H@*B!E;6)E9&0@8V]N=&5N="!I
M;B!A($-$871A(%-E8W1I;VX-"B`J+PT*9&5F:6YE*")834Q?551)3%]#1$%4
M05]314-424].(BP@-2D[#0H-"B\J*@T*("H@9&\@;F]T(')E<&QA8V4@96YT
M:71I=&5S#0H@*B\-"F1E9FEN92@B6$U,7U5424Q?14Y4251)15-?3D].12(L
M(#`I.PT*#0HO*BH-"B`J(')E<&QA8V4@86QL(%A-3"!E;G1I=&ET97,-"B`J
M(%1H:7,@<V5T=&EN9R!W:6QL(')E<&QA8V4@/"P@/BP@(BP@)R!A;F0@)@T*
M("HO#0ID969I;F4H(EA-3%]55$E,7T5.5$E424537UA-3"(L(#$I.PT*#0HO
M*BH-"B`J(')E<&QA8V4@;VYL>2!R97%U:7)E9"!834P@96YT:71I=&5S#0H@
M*B!4:&ES('-E='1I;F<@=VEL;"!R97!L86-E(#PL("(@86YD("8-"B`J+PT*
M9&5F:6YE*")834Q?551)3%]%3E1)5$E%4U]834Q?4D5154E2140B+"`R*3L-
M"@T*+RHJ#0H@*B!R97!L86-E($A434P@96YT:71I=&5S#0H@*B!`;&EN:R`@
M("!H='1P.B\O=W=W+G!H<"YN970O:'1M;&5N=&ET:65S#0H@*B\-"F1E9FEN
M92@B6$U,7U5424Q?14Y4251)15-?2%1-3"(L(#,I.PT*#0HO*BH-"B`J($-O
M;&QA<'-E(&%L;"!E;7!T>2!T86=S+@T*("HO#0ID969I;F4H(EA-3%]55$E,
M7T-/3$Q!4%-%7T%,3"(L(#$I.PT*#0HO*BH-"B`J($-O;&QA<'-E(&]N;'D@
M96UP='D@6$A434P@=&%G<R!T:&%T(&AA=F4@;F\@96YD('1A9RX-"B`J+PT*
M9&5F:6YE*")834Q?551)3%]#3TQ,05!315]82%1-3%]/3DQ9(BP@,BD[#0H-
M"B\J*@T*("H@=71I;&ET>2!C;&%S<R!F;W(@=V]R:VEN9R!W:71H(%A-3"!D
M;V-U;65N=',-"B`J#0H@*B!`8V%T96=O<GD@6$U,#0H@*B!`<&%C:V%G92`@
M6$U,7U5T:6P-"B`J($!V97)S:6]N("`Q+C$N,`T*("H@0&%U=&AO<B`@(%-T
M97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X-"B`J+PT*8VQA<W,@6$U,
M7U5T:6P@>PT*#0H@("`O*BH-"B`@("`J(')E='5R;B!!4$D@=F5R<VEO;@T*
M("`@("H-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@("`J($!S=&%T:6,-
M"B`@("`J($!R971U<FX@("!S=')I;F<@("1V97)S:6]N($%022!V97)S:6]N
M#0H@("`@*B\-"B`@("!F=6YC=&EO;B!A<&E697)S:6]N*"D-"B`@("![#0H@
M("`@("`@(')E='5R;B`G,2XQ)SL-"B`@("!]#0H-"B`@("\J*@T*("`@("H@
M<F5P;&%C92!834P@96YT:71I97,-"B`@("`J#0H@("`@*B!7:71H('1H92!O
M<'1I;VYA;"!S96-O;F0@<&%R86UE=&5R+"!Y;W4@;6%Y('-E;&5C="P@=VAI
M8V@-"B`@("`J(&5N=&ET:65S('-H;W5L9"!B92!R97!L86-E9"X-"B`@("`J
M#0H@("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?;VYC92`G6$U,+U5T:6PN
M<&AP)SL-"B`@("`J(`T*("`@("H@+R\@<F5P;&%C92!834P@96YT:71E<SH-
M"B`@("`J("1S=')I;F<@/2!834Q?571I;#HZ<F5P;&%C945N=&ET:65S*")4
M:&ES('-T<FEN9R!C;VYT86EN<R`\("8@/BXB*3L-"B`@("`J(#PO8V]D93X-
M"B`@("`J#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`<W1A=&EC
M#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("!S=')I;F<@=VAE<F4@6$U,('-P
M96-I86P@8VAA<G,@<VAO=6QD(&)E(')E<&QA8V5D#0H@("`@*B!`<&%R86T@
M("`@:6YT96=E<B!S971T:6YG(&9O<B!E;G1I=&EE<R!I;B!A='1R:6)U=&4@
M=F%L=65S("AO;F4@;V8@6$U,7U5424Q?14Y4251)15-?6$U,+"!834Q?551)
M3%]%3E1)5$E%4U]834Q?4D5154E2140L(%A-3%]55$E,7T5.5$E424537TA4
M34PI#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG("!S=')I;F<@=VET:"!R97!L
M86-E9"!C:&%R<PT*("`@("H@0'-E92`@("`@(')E=F5R<V5%;G1I=&EE<R@I
M#0H@("`@*B\-"B`@("!F=6YC=&EO;B!R97!L86-E16YT:71I97,H)'-T<FEN
M9RP@)')E<&QA8V5%;G1I=&EE<R`](%A-3%]55$E,7T5.5$E424537UA-3"D-
M"B`@("![#0H@("`@("`@('-W:71C:"`H)')E<&QA8V5%;G1I=&EE<RD@>PT*
M("`@("`@("`@("`@8V%S92!834Q?551)3%]%3E1)5$E%4U]834PZ#0H@("`@
M("`@("`@("`@("`@<F5T=7)N('-T<G1R*"1S=')I;F<L87)R87DH#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)B<@(#T^
M("<F86UP.R<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G/B<@(#T^("<F9W0[)RP-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("<\)R`@/3X@)R9L=#LG+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(G("`]/B`G
M)G%U;W0[)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=<)R<@/3X@)R9A<&]S.R<@*2D[#0H@("`@("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@("`@("!C87-E(%A-3%]55$E,7T5.5$E424537UA-
M3%]215%525)%1#H-"B`@("`@("`@("`@("`@("!R971U<FX@<W1R='(H)'-T
M<FEN9RQA<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("<F)R`@/3X@)R9A;7`[)RP-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("<\)R`@/3X@)R9L=#LG+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(G("`]
M/B`G)G%U;W0[)R`I*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@("`@(&-A<V4@6$U,7U5424Q?14Y4251)15-?2%1-3#H-"B`@("`@("`@
M("`@("`@("!R971U<FX@:'1M;&5N=&ET:65S*"1S=')I;F<I.PT*("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D
M<W1R:6YG.PT*("`@('T-"@T*("`@+RHJ#0H@("`@*B!R979E<G-E(%A-3"!E
M;G1I=&EE<PT*("`@("H-"B`@("`J(%=I=&@@=&AE(&]P=&EO;F%L('-E8V]N
M9"!P87)A;65T97(L('EO=2!M87D@<V5L96-T+"!W:&EC:`T*("`@("H@96YT
M:71I97,@<VAO=6QD(&)E(')E=F5R<V5D+@T*("`@("H-"B`@("`J(#QC;V1E
M/@T*("`@("H@<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G.PT*("`@("H@
M#0H@("`@*B`O+R!R979E<G-E(%A-3"!E;G1I=&5S.@T*("`@("H@)'-T<FEN
M9R`](%A-3%]5=&EL.CIR979E<G-E16YT:71I97,H(E1H:7,@<W1R:6YG(&-O
M;G1A:6YS("9L=#L@)F%M<#L@)F=T.RXB*3L-"B`@("`J(#PO8V]D93X-"B`@
M("`J#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@
M("`@*B!`<&%R86T@("`@<W1R:6YG("!S=')I;F<@=VAE<F4@6$U,('-P96-I
M86P@8VAA<G,@<VAO=6QD(&)E(')E<&QA8V5D#0H@("`@*B!`<&%R86T@("`@
M:6YT96=E<B!S971T:6YG(&9O<B!E;G1I=&EE<R!I;B!A='1R:6)U=&4@=F%L
M=65S("AO;F4@;V8@6$U,7U5424Q?14Y4251)15-?6$U,+"!834Q?551)3%]%
M3E1)5$E%4U]834Q?4D5154E2140L(%A-3%]55$E,7T5.5$E424537TA434PI
M#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG("!S=')I;F<@=VET:"!R97!L86-E
M9"!C:&%R<PT*("`@("H@0'-E92`@("`@(')E<&QA8V5%;G1I=&EE<R@I#0H@
M("`@*B\-"B`@("!F=6YC=&EO;B!R979E<G-E16YT:71I97,H)'-T<FEN9RP@
M)')E<&QA8V5%;G1I=&EE<R`](%A-3%]55$E,7T5.5$E424537UA-3"D-"B`@
M("![#0H@("`@("`@('-W:71C:"`H)')E<&QA8V5%;G1I=&EE<RD@>PT*("`@
M("`@("`@("`@8V%S92!834Q?551)3%]%3E1)5$E%4U]834PZ#0H@("`@("`@
M("`@("`@("`@<F5T=7)N('-T<G1R*"1S=')I;F<L87)R87DH#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)F%M<#LG("`]
M/B`G)B<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G)F=T.R<@("`]/B`G/B<L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G)FQT.R<@("`]/B`G/"<L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)G%U;W0[)R`]
M/B`G(B<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G)F%P;W,[)R`]/B`G7"<G("DI.PT*("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@8V%S92!834Q?551)3%]%3E1)5$E%4U]834Q?
M4D5154E2140Z#0H@("`@("`@("`@("`@("`@<F5T=7)N('-T<G1R*"1S=')I
M;F<L87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G)F%M<#LG("`]/B`G)B<L#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G)FQT.R<@("`]/B`G/"<L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)G%U;W0[
M)R`]/B`G(B<@*2D[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M("`@("!C87-E(%A-3%]55$E,7T5.5$E424537TA434PZ#0H@("`@("`@("`@
M("`@("`@)&%R<B`](&%R<F%Y7V9L:7`H9V5T7VAT;6Q?=')A;G-L871I;VY?
M=&%B;&4H2%1-3%]%3E1)5$E%4RDI.PT*("`@("`@("`@("`@("`@(')E='5R
M;B!S=')T<B@D<W1R:6YG+"`D87)R*3L-"B`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'-T<FEN9SL-"B`@("!]
M#0H-"B`@("\J*@T*("`@("H@8G5I;&0@86X@>&UL(&1E8VQA<F%T:6]N#0H@
M("`@*@T*("`@("H@/&-O9&4^#0H@("`@*B!R97%U:7)E7V]N8V4@)UA-3"]5
M=&EL+G!H<"<[#0H@("`@*B`-"B`@("`J("\O(&=E="!A;B!834P@9&5C;&%R
M871I;VXZ#0H@("`@*B`D>&UL1&5C;"`](%A-3%]5=&EL.CIG971834Q$96-L
M87)A=&EO;B@B,2XP(BP@(E541BTX(BP@=')U92D[#0H@("`@*B`\+V-O9&4^
M#0H@("`@*@T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'-T871I
M8PT*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)'9E<G-I;VX@("`@('AM;"!V
M97)S:6]N#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D96YC;V1I;F<@("`@
M8VAA<F%C=&5R(&5N8V]D:6YG#0H@("`@*B!`<&%R86T@("`@8F]O;&5A;B`D
M<W1A;F1!;&]N92`@9&]C=6UE;G0@:7,@<W1A;F1A;&]N92`H;W(@;F]T*0T*
M("`@("H@0')E='5R;B`@('-T<FEN9R`@)&1E8VP@>&UL(&1E8VQA<F%T:6]N
M#0H@("`@*B!`=7-E<R`@("`@6$U,7U5T:6PZ.F%T=')I8G5T97-4;U-T<FEN
M9R@I('1O('-E<FEA;&EZ92!T:&4@871T<FEB=71E<R!O9B!T:&4@6$U,(&1E
M8VQA<F%T:6]N#0H@("`@*B\-"B`@("!F=6YC=&EO;B!G971834Q$96-L87)A
M=&EO;B@D=F5R<VEO;B`]("(Q+C`B+"`D96YC;V1I;F<@/2!N=6QL+"`D<W1A
M;F1A;&]N92`](&YU;&PI#0H@("`@>PT*("`@("`@("`D871T<FEB=71E<R`]
M(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(")V97)S:6]N
M(B`]/B`D=F5R<VEO;BP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("D[
M#0H@("`@("`@("\O(&%D9"!E;F-O9&EN9PT*("`@("`@("!I9B`H)&5N8V]D
M:6YG("$]/2!N=6QL*2![#0H@("`@("`@("`@("`D871T<FEB=71E<ULB96YC
M;V1I;F<B72`]("1E;F-O9&EN9SL-"B`@("`@("`@?0T*("`@("`@("`O+R!A
M9&0@<W1A;F1A;&]N92P@:68@<W!E8VEF:65D#0H@("`@("`@(&EF("@D<W1A
M;F1A;&]N92`A/3T@;G5L;"D@>PT*("`@("`@("`@("`@)&%T=')I8G5T97-;
M(G-T86YD86QO;F4B72`]("1S=&%N9&%L;VYE(#\@(GEE<R(@.B`B;F\B.PT*
M("`@("`@("!]#0H@("`@("`@(`T*("`@("`@("!R971U<FX@<W!R:6YT9B@B
M/#]X;6PE<S\^(BP@6$U,7U5T:6PZ.F%T=')I8G5T97-4;U-T<FEN9R@D871T
M<FEB=71E<RP@9F%L<V4I*3L-"B`@("!]#0H-"B`@("\J*@T*("`@("H@8G5I
M;&0@82!D;V-U;65N="!T>7!E(&1E8VQA<F%T:6]N#0H@("`@*@T*("`@("H@
M/&-O9&4^#0H@("`@*B!R97%U:7)E7V]N8V4@)UA-3"]5=&EL+G!H<"<[#0H@
M("`@*B`-"B`@("`J("\O(&=E="!A(&1O8W1Y<&4@9&5C;&%R871I;VXZ#0H@
M("`@*B`D>&UL1&5C;"`](%A-3%]5=&EL.CIG971$;V-4>7!E1&5C;&%R871I
M;VXH(G)O;W1486<B+")M>41O8U1Y<&4N9'1D(BD[#0H@("`@*B`\+V-O9&4^
M#0H@("`@*@T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'-T871I
M8PT*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)')O;W0@("`@("`@("!N86UE
M(&]F('1H92!R;V]T('1A9PT*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)'5R
M:2`@("`@("`@("!U<FD@;V8@=&AE(&1O8W1Y<&4@9&5F:6YI=&EO;B`H;W(@
M87)R87D@=VET:"!U<FD@86YD('!U8FQI8R!I9"D-"B`@("`J($!P87)A;2`@
M("!S=')I;F<@("1I;G1E<FYA;$1T9"`@:6YT97)N86P@9'1D(&5N=')I97,@
M("`-"B`@("`J($!R971U<FX@("!S=')I;F<@("1D96-L("`@("`@("`@9&]C
M='EP92!D96-L87)A=&EO;@T*("`@("H@0'-I;F-E("`@(#`N,@T*("`@("HO
M#0H@("`@9G5N8W1I;VX@9V5T1&]C5'EP941E8VQA<F%T:6]N*"1R;V]T+"`D
M=7)I(#T@;G5L;"P@)&EN=&5R;F%L1'1D(#T@;G5L;"D-"B`@("![#0H@("`@
M("`@(&EF("AI<U]A<G)A>2@D=7)I*2D@>PT*("`@("`@("`@("`@)')E9B`]
M('-P<FEN=&8H("<@4%5"3$E#("(E<R(@(B5S(B<L("1U<FE;(FED(ETL("1U
M<FE;(G5R:2)=("D[#0H@("`@("`@('T@96QS96EF("@A96UP='DH)'5R:2DI
M('L-"B`@("`@("`@("`@("1R968@/2!S<')I;G1F*"`G(%-94U1%32`B)7,B
M)RP@)'5R:2`I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)')E
M9B`]("(B.PT*("`@("`@("!]#0H-"B`@("`@("`@:68@*&5M<'1Y*"1I;G1E
M<FYA;$1T9"DI('L-"B`@("`@("`@("`@(')E='5R;B!S<')I;G1F*"(\(41/
M0U194$4@)7,E<SXB+"`D<F]O="P@)')E9BD[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("!R971U<FX@<W!R:6YT9B@B/"%$3T-465!%("5S)7,@
M6UQN)7-<;ET^(BP@)')O;W0L("1R968L("1I;G1E<FYA;$1T9"D[#0H@("`@
M("`@('T-"B`@("!]#0H-"B`@("\J*@T*("`@("H@8W)E871E('-T<FEN9R!R
M97!R97-E;G1A=&EO;B!O9B!A;B!A='1R:6)U=&4@;&ES=`T*("`@("H-"B`@
M("`J(#QC;V1E/@T*("`@("H@<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G
M.PT*("`@("H@#0H@("`@*B`O+R!B=6EL9"!A;B!A='1R:6)U=&4@<W1R:6YG
M#0H@("`@*B`D871T(#T@87)R87DH#0H@("`@*B`@("`@("`@("`@("`@(F9O
M;R(@("`]/B`@(F)A<B(L#0H@("`@*B`@("`@("`@("`@("`@(F%R9V@B("`]
M/B`@(G1O;6%T;R(-"B`@("`J("`@("`@("`@("`@*3L-"B`@("`J#0H@("`@
M*B`D871T3&ES="`](%A-3%]5=&EL.CIA='1R:6)U=&5S5&]3=')I;F<H)&%T
M="D[("`@(`T*("`@("H@/"]C;V1E/@T*("`@("H-"B`@("`J($!A8V-E<W,@
M("!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P87)A;2`@("!A<G)A
M>2`@("`@("`@("1A='1R:6)U=&5S("`@("`@("!A='1R:6)U=&4@87)R87D-
M"B`@("`J($!P87)A;2`@("!B;V]L96%N?&%R<F%Y("1S;W)T("`@("`@("`@
M("`@("!S;W)T(&%T=')I8G5T92!L:7-T(&%L<&AA8F5T:6-A;&QY+"!M87D@
M86QS;R!B92!A;B!A<W-O8R!A<G)A>2!C;VYT86EN:6YG('1H92!K97ES("=S
M;W)T)RP@)VUU;'1I;&EN92<L("=I;F1E;G0G+"`G;&EN96)R96%K)R!A;F0@
M)V5N=&ET:65S)PT*("`@("H@0'!A<F%M("`@(&)O;VQE86X@("`@("`@)&UU
M;'1I;&EN92`@("`@("`@('5S92!L:6YE8G)E86MS+"!I9B!M;W)E('1H86X@
M;VYE(&%T=')I8G5T92!I<R!G:79E;@T*("`@("H@0'!A<F%M("`@('-T<FEN
M9R`@("`@("`@)&EN9&5N="`@("`@("`@("`@('-T<FEN9R!U<V5D(&9O<B!I
M;F1E;G1A=&EO;B!O9B!M=6QT:6QI;F4@871T<FEB=71E<PT*("`@("H@0'!A
M<F%M("`@('-T<FEN9R`@("`@("`@)&QI;F5B<F5A:R`@("`@("`@('-T<FEN
M9R!U<V5D(&9O<B!L:6YE8G)E86MS(&]F(&UU;'1I;&EN92!A='1R:6)U=&5S
M#0H@("`@*B!`<&%R86T@("`@:6YT96=E<B`@("`@("`D96YT:71I97,@("`@
M("`@("`@<V5T=&EN9R!F;W(@96YT:71I97,@:6X@871T<FEB=71E('9A;'5E
M<R`H;VYE(&]F(%A-3%]55$E,7T5.5$E424537TY/3D4L(%A-3%]55$E,7T5.
M5$E424537UA-3"P@6$U,7U5424Q?14Y4251)15-?6$U,7U)%455)4D5$+"!8
M34Q?551)3%]%3E1)5$E%4U](5$U,*0T*("`@("H@0')E='5R;B`@('-T<FEN
M9R`@("`@("`@("`@("`@("`@("`@("`@("`@('-T<FEN9R!R97!R97-E;G1A
M=&EO;B!O9B!T:&4@871T<FEB=71E<PT*("`@("H@0'5S97,@("`@(%A-3%]5
M=&EL.CIR97!L86-E16YT:71I97,H*2!T;R!R97!L86-E(%A-3"!E;G1I=&EE
M<R!I;B!A='1R:6)U=&4@=F%L=65S#0H@("`@*B!`=&]D;R`@("`@86QL;W<@
M<V]R="!A;'-O('1O(&)E(&%N(&]P=&EO;G,@87)R87D-"B`@("`J+PT*("`@
M(&9U;F-T:6]N(&%T=')I8G5T97-4;U-T<FEN9R@D871T<FEB=71E<RP@)'-O
M<G0@/2!T<G5E+"`D;75L=&EL:6YE(#T@9F%L<V4L("1I;F1E;G0@/2`G("`@
M("<L("1L:6YE8G)E86L@/2`B7&XB+"`D96YT:71I97,@/2!834Q?551)3%]%
M3E1)5$E%4U]834PI#0H@("`@>PT*("`@("`@("`O*BH-"B`@("`@("`@("H@
M<V5C;VYD('!A<F%M971E<B!M87D@8F4@86X@87)R87D-"B`@("`@("`@("HO
M#0H@("`@("`@(&EF("AI<U]A<G)A>2@D<V]R="DI('L-"B`@("`@("`@("`@
M(&EF("AI<W-E="@D<V]R=%LG;75L=&EL:6YE)UTI*2![#0H@("`@("`@("`@
M("`@("`@)&UU;'1I;&EN92`]("1S;W)T6R=M=6QT:6QI;F4G73L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D<V]R=%LG:6YD96YT
M)UTI*2![#0H@("`@("`@("`@("`@("`@)&EN9&5N="`]("1S;W)T6R=I;F1E
M;G0G73L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D
M<V]R=%LG;&EN96)R96%K)UTI*2![#0H@("`@("`@("`@("`@("`@)&UU;'1I
M;&EN92`]("1S;W)T6R=L:6YE8G)E86LG73L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("AI<W-E="@D<V]R=%LG96YT:71I97,G72DI('L-"B`@
M("`@("`@("`@("`@("`D96YT:71I97,@/2`D<V]R=%LG96YT:71I97,G73L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D<V]R=%LG
M<V]R="==*2D@>PT*("`@("`@("`@("`@("`@("1S;W)T(#T@)'-O<G1;)W-O
M<G0G73L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M)'-O<G0@/2!T<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@("1S=')I;F<@/2`G)SL-"B`@("`@("`@:68@*&ES7V%R<F%Y*"1A='1R
M:6)U=&5S*2`F)B`A96UP='DH)&%T=')I8G5T97,I*2![#0H@("`@("`@("`@
M("!I9B`H)'-O<G0I('L-"B`@("`@("`@("`@("`@("!K<V]R="@D871T<FEB
M=71E<RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B@@(21M=6QT
M:6QI;F4@?'P@8V]U;G0H)&%T=')I8G5T97,I(#T](#$I('L-"B`@("`@("`@
M("`@("`@("!F;W)E86-H("@D871T<FEB=71E<R!A<R`D:V5Y(#T^("1V86QU
M92D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)&5N=&ET:65S("$](%A-
M3%]55$E,7T5.5$E424537TY/3D4I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@D96YT:71I97,@/3T](%A-3%]55$E,7T-$051!7U-%0U1)3TXI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(`DD96YT:71I97,@/2!834Q?
M551)3%]%3E1)5$E%4U]834P[#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2!834Q?571I;#HZ
M<F5P;&%C945N=&ET:65S*"1V86QU92P@)&5N=&ET:65S*3L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D<W1R:6YG("X]
M("<@)RXD:V5Y+B<](B<N)'9A;'5E+B<B)SL-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1F:7)S
M="`]('1R=64[#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&%T=')I8G5T
M97,@87,@)&ME>2`]/B`D=F%L=64I('L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"1E;G1I=&EE<R`A/2!834Q?551)3%]%3E1)5$E%4U].3TY%*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2!834Q?571I;#HZ<F5P
M;&%C945N=&ET:65S*"1V86QU92P@)&5N=&ET:65S*3L-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H)&9I<G-T*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D<W1R:6YG("X]("(@(BXD:V5Y
M+B<](B<N)'9A;'5E+B<B)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("1F
M:7)S="`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`N/2`D;&EN96)R96%K
M+B1I;F1E;G0N)&ME>2XG/2(G+B1V86QU92XG(B<[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N("1S=')I;F<[#0H@("`@?0T*#0H@
M("`O*BH-"B`@("`J($-O;&QA<'-E<R!E;7!T>2!T86=S+@T*("`@("H-"B`@
M("`J($!A8V-E<W,@("!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P
M87)A;2`@("!S=')I;F<@("1X;6P@(%A-3`T*("`@("H@0'!A<F%M("`@(&EN
M=&5G97(@)&UO9&4@5VAE=&AE<B!T;R!C;VQL87!S92!A;&P@96UP='D@=&%G
M<R`H6$U,7U5424Q?0T],3$%04T5?04Q,*2!O<B!O;FQY(%A(5$U,("A834Q?
M551)3%]#3TQ,05!315]82%1-3%]/3DQ9*2!O;F5S+@T*("`@("H@0')E='5R
M;B`@('-T<FEN9R`@)'AM;"`@6$U,#0H@("`@*B\-"B`@("!F=6YC=&EO;B!C
M;VQL87!S945M<'1Y5&%G<R@D>&UL+"`D;6]D92`](%A-3%]55$E,7T-/3$Q!
M4%-%7T%,3"D@>PT*("`@("`@("!I9B`H)&UO9&4@/3T@6$U,7U5424Q?0T],
M3$%04T5?6$A434Q?3TY,62D@>PT*("`@("`@("`@("`@<F5T=7)N('!R96=?
M<F5P;&%C92@-"B`@("`@("`@("`@("`@)R\\*&%R96%\8F%S97QB<GQC;VQ\
M:')\:6UG?&EN<'5T?&QI;FM\;65T87QP87)A;2DH6UX^72HI/CQ<+UQ<,3XO
M<R<L#0H@("`@("`@("`@("`@("<\7%PQ7%PR("\^)RP-"B`@("`@("`@("`@
M("`@)'AM;`T*("`@("`@("`@("`@*3L-"B`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@(')E='5R;B!P<F5G7W)E<&QA8V4H#0H@("`@("`@("`@("`@
M("<O/"A<=RLI*%M>/ETJ*3X\7"]<7#$^+W,G+`T*("`@("`@("`@("`@("`G
M/%Q<,5Q<,B`O/B<L#0H@("`@("`@("`@("`@("1X;6P-"B`@("`@("`@("`@
M("D[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("\J*@T*("`@("H@8W)E871E
M(&$@=&%G#0H@("`@*@T*("`@("H@5&AI<R!M971H;V0@=VEL;"!C86QL(%A-
M3%]5=&EL.CIC<F5A=&5486=&<F]M07)R87DH*2P@=VAI8V@-"B`@("`J(&ES
M(&UO<F4@9FQE>&EB;&4N#0H@("`@*@T*("`@("H@/&-O9&4^#0H@("`@*B!R
M97%U:7)E7V]N8V4@)UA-3"]5=&EL+G!H<"<[#0H@("`@*B`-"B`@("`J("\O
M(&-R96%T92!A;B!834P@=&%G.@T*("`@("H@)'1A9R`](%A-3%]5=&EL.CIC
M<F5A=&5486<H(FUY3G,Z;7E486<B+"!A<G)A>2@B9F]O(B`]/B`B8F%R(BDL
M(")4:&ES(&ES(&EN<VED92!T:&4@=&%G(BP@(FAT='`Z+R]W=W<N=S-C+F]R
M9R]M>4YS(R(I.PT*("`@("H@/"]C;V1E/@T*("`@("H-"B`@("`J($!A8V-E
M<W,@("!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P87)A;2`@("!S
M=')I;F<@("1Q;F%M92`@("`@("`@("`@("!Q=6%L:69I960@=&%G;F%M92`H
M:6YC;'5D:6YG(&YA;65S<&%C92D-"B`@("`J($!P87)A;2`@("!A<G)A>2`@
M("1A='1R:6)U=&5S("`@("`@("!A<G)A>2!C;VYT86EN9R!A='1R:6)U=&5S
M#0H@("`@*B!`<&%R86T@("`@;6EX960@("`D8V]N=&5N=`T*("`@("H@0'!A
M<F%M("`@('-T<FEN9R`@)&YA;65S<&%C955R:2`@("`@(%5222!O9B!T:&4@
M;F%M97-P86-E#0H@("`@*B!`<&%R86T@("`@:6YT96=E<B`D<F5P;&%C945N
M=&ET:65S("`@=VAE=&AE<B!T;R!R97!L86-E(%A-3"!S<&5C:6%L(&-H87)S
M(&EN(&-O;G1E;G0L(&5M8F5D9"!I="!I;B!A($-$871A('-E8W1I;VX@;W(@
M;F]N92!O9B!B;W1H#0H@("`@*B!`<&%R86T@("`@8F]O;&5A;B`D;75L=&EL
M:6YE("`@("`@("`@=VAE=&AE<B!T;R!C<F5A=&4@82!M=6QT:6QI;F4@=&%G
M('=H97)E(&5A8V@@871T<FEB=71E(&=E=',@=W)I='1E;B!T;R!A('-I;F=L
M92!L:6YE#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D:6YD96YT("`@("`@
M("`@("`@<W1R:6YG('5S960@=&\@:6YD96YT(&%T=')I8G5T97,@*%]A=71O
M(&EN9&5N=',@871T<FEB=71E<R!S;R!T:&5Y('-T87)T(&%T('1H92!S86UE
M(&-O;'5M;BD-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1L:6YE8G)E86L@
M("`@("`@("!S=')I;F<@=7-E9"!F;W(@;&EN96)R96%K<PT*("`@("H@0')E
M='5R;B`@('-T<FEN9R`@)'-T<FEN9R`@("`@("`@("`@(%A-3"!T86<-"B`@
M("`J($!S964@("`@("!834Q?571I;#HZ8W)E871E5&%G1G)O;4%R<F%Y*"D-
M"B`@("`J($!U<V5S("`@("!834Q?571I;#HZ8W)E871E5&%G1G)O;4%R<F%Y
M*"D@=&\@8W)E871E('1H92!T86<-"B`@("`J+PT*("`@(&9U;F-T:6]N(&-R
M96%T951A9R@D<6YA;64L("1A='1R:6)U=&5S(#T@87)R87DH*2P@)&-O;G1E
M;G0@/2!N=6QL+"`D;F%M97-P86-E57)I(#T@;G5L;"P@)')E<&QA8V5%;G1I
M=&EE<R`](%A-3%]55$E,7U)%4$Q!0T5?14Y4251)15,L("1M=6QT:6QI;F4@
M/2!F86QS92P@)&EN9&5N="`](")?875T;R(L("1L:6YE8G)E86L@/2`B7&XB
M*0T*("`@('L-"B`@("`@("`@)'1A9R`](&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("`@("`@(G%N86UE(B`@("`@(#T^("1Q;F%M92P-"B`@("`@("`@("`@
M("`@("`@("`@(")A='1R:6)U=&5S(B`]/B`D871T<FEB=71E<PT*("`@("`@
M("`@("`@("`@("`@("`I.PT*#0H@("`@("`@("\O(&%D9"!T86<@8V]N=&5N
M=`T*("`@("`@("!I9B`H)&-O;G1E;G0@(3T](&YU;&PI('L-"B`@("`@("`@
M("`@("1T86=;(F-O;G1E;G0B72`]("1C;VYT96YT.PT*("`@("`@("!]#0H@
M("`@("`@(`T*("`@("`@("`O+R!A9&0@;F%M97-P86-E(%5R:0T*("`@("`@
M("!I9B`H)&YA;65S<&%C955R:2`A/3T@;G5L;"D@>PT*("`@("`@("`@("`@
M)'1A9ULB;F%M97-P86-E57)I(ET@/2`D;F%M97-P86-E57)I.PT*("`@("`@
M("!]#0H-"B`@("`@("`@<F5T=7)N(%A-3%]5=&EL.CIC<F5A=&5486=&<F]M
M07)R87DH)'1A9RP@)')E<&QA8V5%;G1I=&EE<RP@)&UU;'1I;&EN92P@)&EN
M9&5N="P@)&QI;F5B<F5A:RD[#0H@("`@?0T*#0H@("`O*BH-"B`@("`J(&-R
M96%T92!A('1A9R!F<F]M(&%N(&%R<F%Y#0H@("`@*B!T:&ES(&UE=&AO9"!A
M=V%I=',@86X@87)R87D@:6X@=&AE(&9O;&QO=VEN9R!F;W)M870-"B`@("`J
M(#QP<F4^#0H@("`@*B!A<G)A>2@-"B`@("`J("`B<6YA;64B("`@("`@("`]
M/B`D<6YA;64@("`@("`@("`O+R!Q=6%L:69I960@;F%M92!O9B!T:&4@=&%G
M#0H@("`@*B`@(FYA;65S<&%C92(@("`@/3X@)&YA;65S<&%C92`@("`@+R\@
M;F%M97-P86-E('!R969I>"`H;W!T:6]N86PL(&EF('%N86UE(&ES('-P96-I
M9FEE9"!O<B!N;R!N86UE<W!A8V4I#0H@("`@*B`@(FQO8V%L<&%R="(@("`@
M/3X@)&QO8V%L<&%R="P@("`@+R\@;&]C86P@<&%R="!O9B!T:&4@=&%G;F%M
M92`H;W!T:6]N86PL(&EF('%N86UE(&ES('-P96-I9FEE9"D-"B`@("`J("`B
M871T<FEB=71E<R(@("`]/B!A<G)A>2@I+"`@("`@("`O+R!A<G)A>2!C;VYT
M86EN:6YG(&%L;"!A='1R:6)U=&5S("AO<'1I;VYA;"D-"B`@("`J("`B8V]N
M=&5N="(@("`@("`]/B`D8V]N=&5N="P@("`@("`O+R!T86<@8V]N=&5N="`H
M;W!T:6]N86PI#0H@("`@*B`@(FYA;65S<&%C955R:2(@/3X@)&YA;65S<&%C
M955R:2`@+R\@;F%M97-P86-E57)I(&9O<B!T:&4@9VEV96X@;F%M97-P86-E
M("AO<'1I;VYA;"D-"B`@("`J("`@*0T*("`@("H@/"]P<F4^#0H@("`@*@T*
M("`@("H@/&-O9&4^#0H@("`@*B!R97%U:7)E7V]N8V4@)UA-3"]5=&EL+G!H
M<"<[#0H@("`@*B`-"B`@("`J("1T86<@/2!A<G)A>2@-"B`@("`J("`@("`@
M("`@("`B<6YA;64B("`@("`@("`]/B`B9F]O.F)A<B(L#0H@("`@*B`@("`@
M("`@("`@(FYA;65S<&%C955R:2(@/3X@(FAT='`Z+R]F;V\N8V]M(BP-"B`@
M("`J("`@("`@("`@("`B871T<FEB=71E<R(@("`]/B!A<G)A>2@@(FME>2(@
M/3X@(G9A;'5E(BP@(F%R9V@B(#T^(")F<G5I="9V96=E=&%B;&4B("DL#0H@
M("`@*B`@("`@("`@("`@(F-O;G1E;G0B("`@("`@/3X@(DDG;2!I;G-I9&4@
M=&AE('1A9R(L#0H@("`@*B`@("`@("`@("`@("D[#0H@("`@*B`O+R!C<F5A
M=&EN9R!A('1A9R!W:71H('%U86QI9FEE9"!N86UE(&%N9"!N86UE<W!A8V55
M<FD-"B`@("`J("1S=')I;F<@/2!834Q?571I;#HZ8W)E871E5&%G1G)O;4%R
M<F%Y*"1T86<I.PT*("`@("H@/"]C;V1E/@T*("`@("H-"B`@("`J($!A8V-E
M<W,@("!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P87)A;2`@("!A
M<G)A>2`@("1T86<@("`@("`@("`@("`@("!T86<@9&5F:6YI=&EO;@T*("`@
M("H@0'!A<F%M("`@(&EN=&5G97(@)')E<&QA8V5%;G1I=&EE<R`@('=H971H
M97(@=&\@<F5P;&%C92!834P@<W!E8VEA;"!C:&%R<R!I;B!C;VYT96YT+"!E
M;6)E9&0@:70@:6X@82!#1&%T82!S96-T:6]N(&]R(&YO;F4@;V8@8F]T:`T*
M("`@("H@0'!A<F%M("`@(&)O;VQE86X@)&UU;'1I;&EN92`@("`@("`@('=H
M971H97(@=&\@8W)E871E(&$@;75L=&EL:6YE('1A9R!W:&5R92!E86-H(&%T
M=')I8G5T92!G971S('=R:71T96X@=&\@82!S:6YG;&4@;&EN90T*("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@)&EN9&5N="`@("`@("`@("`@('-T<FEN9R!U
M<V5D('1O(&EN9&5N="!A='1R:6)U=&5S("A?875T;R!I;F1E;G1S(&%T=')I
M8G5T97,@<V\@=&AE>2!S=&%R="!A="!T:&4@<V%M92!C;VQU;6XI#0H@("`@
M*B!`<&%R86T@("`@<W1R:6YG("`D;&EN96)R96%K("`@("`@("`@<W1R:6YG
M('5S960@9F]R(&QI;F5B<F5A:W,-"B`@("`J($!R971U<FX@("!S=')I;F<@
M("1S=')I;F<@("`@("`@("`@("!834P@=&%G#0H@("`@*B!`<V5E("`@("`@
M6$U,7U5T:6PZ.F-R96%T951A9R@I#0H@("`@*B!`=7-E<R`@("`@6$U,7U5T
M:6PZ.F%T=')I8G5T97-4;U-T<FEN9R@I('1O('-E<FEA;&EZ92!T:&4@871T
M<FEB=71E<R!O9B!T:&4@=&%G#0H@("`@*B!`=7-E<R`@("`@6$U,7U5T:6PZ
M.G-P;&ET475A;&EF:65D3F%M92@I('1O(&=E="!L;V-A;"!P87)T(&%N9"!N
M86UE<W!A8V4@;V8@82!Q=6%L:69I960@;F%M90T*("`@("HO#0H@("`@9G5N
M8W1I;VX@8W)E871E5&%G1G)O;4%R<F%Y*"1T86<L("1R97!L86-E16YT:71I
M97,@/2!834Q?551)3%]215!,04-%7T5.5$E42453+"`D;75L=&EL:6YE(#T@
M9F%L<V4L("1I;F1E;G0@/2`B7V%U=&\B+"`D;&EN96)R96%K(#T@(EQN(B`I
M#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1A9ULG8V]N=&5N="==*2`F
M)B`A:7-?<V-A;&%R*"1T86=;)V-O;G1E;G0G72DI('L-"B`@("`@("`@("`@
M(')E='5R;B!834Q?571I;#HZ<F%I<V5%<G)O<B@@)U-U<'!L:65D(&YO;BUS
M8V%L87(@=F%L=64@87,@=&%G(&-O;G1E;G0G+"!834Q?551)3%]%4E)/4E].
M3TY?4T-!3$%27T-/3E1%3E0@*3L-"B`@("`@("`@?0T*#0H@("`@("`@(&EF
M("@A:7-S970H)'1A9ULG<6YA;64G72D@)B8@(6ES<V5T*"1T86=;)VQO8V%L
M4&%R="==*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%A-3%]5=&EL.CIR86ES
M945R<F]R*"`G66]U(&UU<W0@96ET:&5R('-U<'!L>2!A('%U86QI9FEE9"!N
M86UE("AQ;F%M92D@;W(@;&]C86P@=&%G(&YA;64@*&QO8V%L4&%R="DN)RP@
M6$U,7U5424Q?15)23U)?3D]?5$%'7TY!344@*3L-"B`@("`@("`@?0T*#0H@
M("`@("`@("\O(&EF(&YO(&%T=')I8G5T97,@:&%V(&)E96X@<V5T+"!U<V4@
M96UP='D@871T<FEB=71E<PT*("`@("`@("!I9B`H(6ES<V5T*"1T86=;(F%T
M=')I8G5T97,B72D@?'P@(6ES7V%R<F%Y*"1T86=;(F%T=')I8G5T97,B72DI
M('L-"B`@("`@("`@("`@("1T86=;(F%T=')I8G5T97,B72`](&%R<F%Y*"D[
M#0H@("`@("`@('T-"B`@("`@("`@#0H@("`@("`@("\O('%U86QI9FEE9"!N
M86UE(&ES(&YO="!G:79E;@T*("`@("`@("!I9B`H(6ES<V5T*"1T86=;(G%N
M86UE(ETI*2![#0H@("`@("`@("`@("`O+R!C:&5C:R!F;W(@;F%M97-P86-E
M#0H@("`@("`@("`@("!I9B`H:7-S970H)'1A9ULB;F%M97-P86-E(ETI("8F
M("%E;7!T>2@D=&%G6R)N86UE<W!A8V4B72DI('L-"B`@("`@("`@("`@("`@
M("`D=&%G6R)Q;F%M92)=(#T@)'1A9ULB;F%M97-P86-E(ETN(CHB+B1T86=;
M(FQO8V%L4&%R=")=.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`D=&%G6R)Q;F%M92)=(#T@)'1A9ULB;&]C86Q087)T(ET[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("\O(&YA;65S<&%C92!54DD@:7,@<V5T
M+"!B=70@;F\@;F%M97-P86-E#0H@("`@("`@('T@96QS96EF("AI<W-E="@D
M=&%G6R)N86UE<W!A8V55<FDB72D@)B8@(6ES<V5T*"1T86=;(FYA;65S<&%C
M92)=*2D@>PT*("`@("`@("`@("`@)'!A<G1S(#T@6$U,7U5T:6PZ.G-P;&ET
M475A;&EF:65D3F%M92@D=&%G6R)Q;F%M92)=*3L-"B`@("`@("`@("`@("1T
M86=;(FQO8V%L4&%R=")=(#T@)'!A<G1S6R)L;V-A;%!A<G0B73L-"B`@("`@
M("`@("`@(&EF("AI<W-E="@D<&%R='-;(FYA;65S<&%C92)=*2D@>PT*("`@
M("`@("`@("`@("`@("1T86=;(FYA;65S<&%C92)=(#T@)'!A<G1S6R)N86UE
M<W!A8V4B73L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@
M(&EF("AI<W-E="@D=&%G6R)N86UE<W!A8V55<FDB72D@)B8@(65M<'1Y*"1T
M86=;(FYA;65S<&%C955R:2)=*2D@>PT*("`@("`@("`@("`@+R\@:7,@82!N
M86UE<W!A8V4@9VEV96X-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&%G6R)N
M86UE<W!A8V4B72D@)B8@(65M<'1Y*"1T86=;(FYA;65S<&%C92)=*2D@>PT*
M("`@("`@("`@("`@("`@("1T86=;(F%T=')I8G5T97,B75LB>&UL;G,Z(BXD
M=&%G6R)N86UE<W!A8V4B75T@/2`D=&%G6R)N86UE<W!A8V55<FDB73L-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@+R\@9&5F:6YE
M('1H:7,@57)I(&%S('1H92!D969A=6QT(&YA;65S<&%C90T*("`@("`@("`@
M("`@("`@("1T86=;(F%T=')I8G5T97,B75LB>&UL;G,B72`]("1T86=;(FYA
M;65S<&%C955R:2)=.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H-"B`@
M("`@("`@+R\@8VAE8VL@9F]R(&UU;'1I;&EN92!A='1R:6)U=&5S#0H@("`@
M("`@(&EF("@D;75L=&EL:6YE(#T]/2!T<G5E*2![#0H@("`@("`@("`@("!I
M9B`H)&EN9&5N="`]/3T@(E]A=71O(BD@>PT*("`@("`@("`@("`@("`@("1I
M;F1E;G0@/2!S=')?<F5P96%T*"(@(BP@*'-T<FQE;B@D=&%G6R)Q;F%M92)=
M*2LR*2D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@#0H@
M("`@("`@("\O(&-R96%T92!A='1R:6)U=&4@;&ES=`T*("`@("`@("`D871T
M3&ES="`@("`]("`@6$U,7U5T:6PZ.F%T=')I8G5T97-4;U-T<FEN9R@D=&%G
M6R=A='1R:6)U=&5S)UTL('1R=64L("1M=6QT:6QI;F4L("1I;F1E;G0L("1L
M:6YE8G)E86LL("1R97!L86-E16YT:71I97,@*3L-"B`@("`@("`@:68@*"%I
M<W-E="@D=&%G6R=C;VYT96YT)UTI('Q\("AS=')I;F<I)'1A9ULG8V]N=&5N
M="==(#T]("<G*2![#0H@("`@("`@("`@("`D=&%G("`@(#T@("!S<')I;G1F
M*"<\)7,E<R`O/B<L("1T86=;)W%N86UE)UTL("1A='1,:7-T*3L-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@('-W:71C:"`H)')E<&QA8V5%;G1I
M=&EE<RD@>PT*("`@("`@("`@("`@("`@(&-A<V4@6$U,7U5424Q?14Y4251)
M15-?3D].13H-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M("`@("`@("`@8V%S92!834Q?551)3%]#1$%405]314-424]..@T*("`@("`@
M("`@("`@("`@("`@("`D=&%G6R=C;VYT96YT)UT@/2!834Q?571I;#HZ8W)E
M871E0T1A=&%396-T:6]N*"1T86=;)V-O;G1E;G0G72D[#0H@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@(&1E9F%U;'0Z#0H@
M("`@("`@("`@("`@("`@("`@("1T86=;)V-O;G1E;G0G72`](%A-3%]5=&EL
M.CIR97!L86-E16YT:71I97,H)'1A9ULG8V]N=&5N="==+"`D<F5P;&%C945N
M=&ET:65S*3L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`D=&%G("`@(#T@("!S<')I;G1F*"<\)7,E
M<SXE<SPO)7,^)RP@)'1A9ULG<6YA;64G72P@)&%T=$QI<W0L("1T86=;)V-O
M;G1E;G0G72P@)'1A9ULG<6YA;64G72`I.PT*("`@("`@("!]("`@("`@("`-
M"B`@("`@("`@<F5T=7)N("`D=&%G.PT*("`@('T-"@T*("`@+RHJ#0H@("`@
M*B!C<F5A=&4@82!S=&%R="!E;&5M96YT#0H@("`@*@T*("`@("H@/&-O9&4^
M#0H@("`@*B!R97%U:7)E7V]N8V4@)UA-3"]5=&EL+G!H<"<[#0H@("`@*B`-
M"B`@("`J("\O(&-R96%T92!A;B!834P@<W1A<G0@96QE;65N=#H-"B`@("`J
M("1T86<@/2!834Q?571I;#HZ8W)E871E4W1A<G1%;&5M96YT*")M>4YS.FUY
M5&%G(BP@87)R87DH(F9O;R(@/3X@(F)A<B(I("PB:'1T<#HO+W=W=RYW,V,N
M;W)G+VUY3G,C(BD[#0H@("`@*B`\+V-O9&4^#0H@("`@*@T*("`@("H@0&%C
M8V5S<R`@('!U8FQI8PT*("`@("H@0'-T871I8PT*("`@("H@0'!A<F%M("`@
M('-T<FEN9R`@)'%N86UE("`@("`@("`@("`@('%U86QI9FEE9"!T86=N86UE
M("AI;F-L=61I;F<@;F%M97-P86-E*0T*("`@("H@0'!A<F%M("`@(&%R<F%Y
M("`@)&%T=')I8G5T97,@("`@("`@(&%R<F%Y(&-O;G1A:6YG(&%T=')I8G5T
M97,-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1N86UE<W!A8V55<FD@("`@
M("!54DD@;V8@=&AE(&YA;65S<&%C90T*("`@("H@0'!A<F%M("`@(&)O;VQE
M86X@)&UU;'1I;&EN92`@("`@("`@('=H971H97(@=&\@8W)E871E(&$@;75L
M=&EL:6YE('1A9R!W:&5R92!E86-H(&%T=')I8G5T92!G971S('=R:71T96X@
M=&\@82!S:6YG;&4@;&EN90T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&EN
M9&5N="`@("`@("`@("`@('-T<FEN9R!U<V5D('1O(&EN9&5N="!A='1R:6)U
M=&5S("A?875T;R!I;F1E;G1S(&%T=')I8G5T97,@<V\@=&AE>2!S=&%R="!A
M="!T:&4@<V%M92!C;VQU;6XI#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D
M;&EN96)R96%K("`@("`@("`@<W1R:6YG('5S960@9F]R(&QI;F5B<F5A:W,-
M"B`@("`J($!R971U<FX@("!S=')I;F<@("1S=')I;F<@("`@("`@("`@("!8
M34P@<W1A<G0@96QE;65N=`T*("`@("H@0'-E92`@("`@(%A-3%]5=&EL.CIC
M<F5A=&5%;F1%;&5M96YT*"DL(%A-3%]5=&EL.CIC<F5A=&5486<H*0T*("`@
M("HO#0H@("`@9G5N8W1I;VX@8W)E871E4W1A<G1%;&5M96YT*"1Q;F%M92P@
M)&%T=')I8G5T97,@/2!A<G)A>2@I+"`D;F%M97-P86-E57)I(#T@;G5L;"P@
M)&UU;'1I;&EN92`](&9A;'-E+"`D:6YD96YT(#T@)U]A=71O)RP@)&QI;F5B
M<F5A:R`](")<;B(I#0H@("`@>PT*("`@("`@("`O+R!I9B!N;R!A='1R:6)U
M=&5S(&AA=B!B965N('-E="P@=7-E(&5M<'1Y(&%T=')I8G5T97,-"B`@("`@
M("`@:68@*"%I<W-E="@D871T<FEB=71E<RD@?'P@(6ES7V%R<F%Y*"1A='1R
M:6)U=&5S*2D@>PT*("`@("`@("`@("`@)&%T=')I8G5T97,@/2!A<G)A>2@I
M.PT*("`@("`@("!]#0H@("`@("`@(`T*("`@("`@("!I9B`H)&YA;65S<&%C
M955R:2`A/2!N=6QL*2![#0H@("`@("`@("`@("`D<&%R=',@/2!834Q?571I
M;#HZ<W!L:711=6%L:69I961.86UE*"1Q;F%M92D[#0H@("`@("`@('T-"@T*
M("`@("`@("`O+R!C:&5C:R!F;W(@;75L=&EL:6YE(&%T=')I8G5T97,-"B`@
M("`@("`@:68@*"1M=6QT:6QI;F4@/3T]('1R=64I('L-"B`@("`@("`@("`@
M(&EF("@D:6YD96YT(#T]/2`B7V%U=&\B*2![#0H@("`@("`@("`@("`@("`@
M)&EN9&5N="`]('-T<E]R97!E870H(B`B+"`H<W1R;&5N*"1Q;F%M92DK,BDI
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@:68@*"1N
M86UE<W!A8V55<FD@(3T@;G5L;"D@>PT*("`@("`@("`@("`@+R\@:7,@82!N
M86UE<W!A8V4@9VEV96X-"B`@("`@("`@("`@(&EF("AI<W-E="@D<&%R='-;
M(FYA;65S<&%C92)=*2`F)B`A96UP='DH)'!A<G1S6R)N86UE<W!A8V4B72DI
M('L-"B`@("`@("`@("`@("`@("`D871T<FEB=71E<ULB>&UL;G,Z(BXD<&%R
M='-;(FYA;65S<&%C92)=72`]("1N86UE<W!A8V55<FD[#0H@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("\O(&1E9FEN92!T:&ES(%5R
M:2!A<R!T:&4@9&5F875L="!N86UE<W!A8V4-"B`@("`@("`@("`@("`@("`D
M871T<FEB=71E<ULB>&UL;G,B72`]("1N86UE<W!A8V55<FD[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"@T*("`@("`@("`O+R!C<F5A=&4@871T<FEB
M=71E(&QI<W0-"B`@("`@("`@)&%T=$QI<W0@("`@/2`@(%A-3%]5=&EL.CIA
M='1R:6)U=&5S5&]3=')I;F<H)&%T=')I8G5T97,L('1R=64L("1M=6QT:6QI
M;F4L("1I;F1E;G0L("1L:6YE8G)E86LI.PT*("`@("`@("`D96QE;65N="`@
M("`]("`@<W!R:6YT9B@B/"5S)7,^(BP@)'%N86UE+"`D871T3&ES="D[#0H@
M("`@("`@(')E='5R;B`@)&5L96UE;G0[#0H@("`@?0T*#0H@("`O*BH-"B`@
M("`J(&-R96%T92!A;B!E;F0@96QE;65N=`T*("`@("H-"B`@("`J(#QC;V1E
M/@T*("`@("H@<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G.PT*("`@("H@
M#0H@("`@*B`O+R!C<F5A=&4@86X@6$U,('-T87)T(&5L96UE;G0Z#0H@("`@
M*B`D=&%G(#T@6$U,7U5T:6PZ.F-R96%T945N9$5L96UE;G0H(FUY3G,Z;7E4
M86<B*3L-"B`@("`J(#PO8V]D93X-"B`@("`J#0H@("`@*B!`86-C97-S("`@
M<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@("`@*B!`<&%R86T@("`@<W1R:6YG
M("`D<6YA;64@("`@("`@("`@("`@<75A;&EF:65D('1A9VYA;64@*&EN8VQU
M9&EN9R!N86UE<W!A8V4I#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG("`D<W1R
M:6YG("`@("`@("`@("`@6$U,(&5N9"!E;&5M96YT#0H@("`@*B!`<V5E("`@
M("`@6$U,7U5T:6PZ.F-R96%T95-T87)T16QE;65N="@I+"!834Q?571I;#HZ
M8W)E871E5&%G*"D-"B`@("`J+PT*("`@(&9U;F-T:6]N(&-R96%T945N9$5L
M96UE;G0H)'%N86UE*0T*("`@('L-"B`@("`@("`@)&5L96UE;G0@("`@/2`@
M('-P<FEN=&8H(CPO)7,^(BP@)'%N86UE*3L-"B`@("`@("`@<F5T=7)N("`D
M96QE;65N=#L-"B`@("!]#0H@("`@#0H@("`O*BH-"B`@("`J(&-R96%T92!A
M;B!834P@8V]M;65N=`T*("`@("H-"B`@("`J(#QC;V1E/@T*("`@("H@<F5Q
M=6ER95]O;F-E("=834PO571I;"YP:'`G.PT*("`@("H@#0H@("`@*B`O+R!C
M<F5A=&4@86X@6$U,('-T87)T(&5L96UE;G0Z#0H@("`@*B`D=&%G(#T@6$U,
M7U5T:6PZ.F-R96%T94-O;6UE;G0H(DD@86T@82!C;VUM96YT(BD[#0H@("`@
M*B`\+V-O9&4^#0H@("`@*@T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@
M("H@0'-T871I8PT*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&-O;G1E;G0@
M("`@("`@("`@(&-O;G1E;G0@;V8@=&AE(&-O;6UE;G0-"B`@("`J($!R971U
M<FX@("!S=')I;F<@("1C;VUM96YT("`@("`@("`@("!834P@8V]M;65N=`T*
M("`@("HO#0H@("`@9G5N8W1I;VX@8W)E871E0V]M;65N="@D8V]N=&5N="D-
M"B`@("![#0H@("`@("`@("1C;VUM96YT("`@(#T@("!S<')I;G1F*"(\(2TM
M("5S("TM/B(L("1C;VYT96YT*3L-"B`@("`@("`@<F5T=7)N("`D8V]M;65N
M=#L-"B`@("!]#0H@("`@#0H@("`O*BH-"B`@("`J(&-R96%T92!A($-$871A
M('-E8W1I;VX-"B`@("`J#0H@("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?
M;VYC92`G6$U,+U5T:6PN<&AP)SL-"B`@("`J(`T*("`@("H@+R\@8W)E871E
M(&$@0T1A=&$@<V5C=&EO;@T*("`@("H@)'1A9R`](%A-3%]5=&EL.CIC<F5A
M=&5#1&%T85-E8W1I;VXH(DD@86T@8V]N=&5N="XB*3L-"B`@("`J(#PO8V]D
M93X-"B`@("`J#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`<W1A
M=&EC#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D9&%T82`@("`@("`@("`@
M("`@9&%T82!O9B!T:&4@0T1A=&$@<V5C=&EO;@T*("`@("H@0')E='5R;B`@
M('-T<FEN9R`@)'-T<FEN9R`@("`@("`@("`@($-$871A('-E8W1I;VX@=VET
M:"!C;VYT96YT#0H@("`@*B\-"B`@("!F=6YC=&EO;B!C<F5A=&5#1&%T85-E
M8W1I;VXH)&1A=&$I#0H@("`@>PT*("`@("`@("!R971U<FX@('-P<FEN=&8H
M(CPA6T-$051!6R5S75T^(BP@)&1A=&$I.PT*("`@('T-"@T*("`@+RHJ#0H@
M("`@*B!S<&QI="!Q=6%L:69I960@;F%M92!A;F0@<F5T=7)N(&YA;65S<&%C
M92!A;F0@;&]C86P@<&%R=`T*("`@("H-"B`@("`J(#QC;V1E/@T*("`@("H@
M<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G.PT*("`@("H@#0H@("`@*B`O
M+R!S<&QI="!Q=6%L:69I960@=&%G#0H@("`@*B`D<&%R=',@/2!834Q?571I
M;#HZ<W!L:711=6%L:69I961.86UE*")X<VQT.G-T>6QE<VAE970B*3L-"B`@
M("`J(#PO8V]D93X-"B`@("`J('1H92!R971U<FYE9"!A<G)A>2!W:6QL(&-O
M;G1A:6X@='=O(&5L96UE;G1S.@T*("`@("H@/'!R93X-"B`@("`J(&%R<F%Y
M*`T*("`@("H@("`@("`@(FYA;65S<&%C92(@/3X@(GAS;'0B+`T*("`@("H@
M("`@("`@(FQO8V%L4&%R="(@/3X@(G-T>6QE<VAE970B#0H@("`@*B`@("`@
M("D[#0H@("`@*B`\+W!R93X-"B`@("`J#0H@("`@*B!`86-C97-S('!U8FQI
M8PT*("`@("H@0'-T871I8PT*("`@("H@0'!A<F%M("!S=')I;F<@("`@)'%N
M86UE("`@("`@<75A;&EF:65D('1A9R!N86UE#0H@("`@*B!`<&%R86T@('-T
M<FEN9R`@("`D9&5F875L=$YS("!D969A=6QT(&YA;65S<&%C92`H;W!T:6]N
M86PI#0H@("`@*B!`<F5T=7)N(&%R<F%Y("`@("`D<&%R=',@("`@("!A<G)A
M>2!C;VYT86EN:6YG(&YA;65S<&%C92!A;F0@;&]C86P@<&%R=`T*("`@("HO
M#0H@("`@9G5N8W1I;VX@<W!L:711=6%L:69I961.86UE*"1Q;F%M92P@)&1E
M9F%U;'1.<R`](&YU;&PI#0H@("`@>PT*("`@("`@("!I9B`H<W1R<W1R*"1Q
M;F%M92P@)SHG*2D@>PT*("`@("`@("`@("`@)'1M<"`](&5X<&QO9&4H(CHB
M+"`D<6YA;64I.PT*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`B;F%M97-P86-E(B`]/B`D=&UP6S!=+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`B;&]C86Q087)T(B`]/B`D=&UP
M6S%=#0H@("`@("`@("`@("`@("`@("`@("`@("`I.PT*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`B
M;F%M97-P86-E(B`]/B`D9&5F875L=$YS+`T*("`@("`@("`@("`@("`@("`@
M("`@(")L;V-A;%!A<G0B(#T^("1Q;F%M90T*("`@("`@("`@("`@("`@("`@
M("`I.PT*("`@('T-"@T*("`@+RHJ#0H@("`@*B!C:&5C:RP@=VAE=&AE<B!S
M=')I;F<@:7,@=F%L:60@6$U,(&YA;64-"B`@("`J#0H@("`@*B`\<#Y834P@
M;F%M97,@87)E('5S960@9F]R('1A9VYA;64L(&%T=')I8G5T92!N86UE<R!A
M;F0@=F%R:6]U<PT*("`@("H@;W1H97(L(&QE<W-E<B!K;F]W;B!E;G1I=&EE
M<RX\+W`^#0H@("`@*B`\<#Y!;B!834P@;F%M92!M87D@;VYL>2!C;VYS:7-T
M(&]F(&%L<&AA;G5M97)I8R!C:&%R86-T97)S+`T*("`@("H@9&%S:&5S+"!U
M;F1E<V-O<F5S(&%N9"!P97)I;V1S+"!A;F0@:&%S('1O('-T87)T('=I=&@@
M82!L971T97(-"B`@("`J(&]R(&%N('5N9&5R<V-O<F4N#0H@("`@*B`\+W`^
M#0H@("`@*@T*("`@("H@/&-O9&4^#0H@("`@*B!R97%U:7)E7V]N8V4@)UA-
M3"]5=&EL+G!H<"<[#0H@("`@*B`-"B`@("`J("\O('9E<FEF>2!T86<@;F%M
M90T*("`@("H@)')E<W5L="`](%A-3%]5=&EL.CII<U9A;&ED3F%M92@B:6YV
M86QI9%1A9S\B*3L-"B`@("`J(&EF("A834Q?571I;#HZ:7-%<G)O<B@D<F5S
M=6QT*2D@>PT*("`@("H@("`@<')I;G0@(DEN=F%L:60@6$U,(&YA;64Z("(@
M+B`D<F5S=6QT+3YG971-97-S86=E*"D[#0H@("`@*B!]#0H@("`@*B`\+V-O
M9&4^#0H@("`@*@T*("`@("H@0&%C8V5S<R`@<'5B;&EC#0H@("`@*B!`<W1A
M=&EC#0H@("`@*B!`<&%R86T@("!S=')I;F<@("1S=')I;F<@<W1R:6YG('1H
M870@<VAO=6QD(&)E(&-H96-K960-"B`@("`J($!R971U<FX@(&UI>&5D("`@
M)'9A;&ED("!T<G5E+"!I9B!S=')I;F<@:7,@82!V86QI9"!834P@;F%M92P@
M4$5!4B!E<G)O<B!O=&AE<G=I<V4-"B`@("`J($!T;V1O("`@('-U<'!O<G0@
M9F]R(&]T:&5R(&-H87)S971S#0H@("`@*B\-"B`@("!F=6YC=&EO;B!I<U9A
M;&ED3F%M92@D<W1R:6YG*0T*("`@('L-"B`@("`@("`@+R\@8VAE8VL@9F]R
M(&EN=F%L:60@8VAA<G,-"B`@("`@("`@:68@*"%P<F5G7VUA=&-H*"(O7EM;
M.F%L;G5M.EU?7"TN720O(BP@)'-T<FEN9WLP?2DI('L-"B`@("`@("`@("`@
M(')E='5R;B!834Q?571I;#HZ<F%I<V5%<G)O<B@@(EA-3"!N86UE<R!M87D@
M;VYL>2!S=&%R="!W:71H(&QE='1E<B!O<B!U;F1E<G-C;W)E(BP@6$U,7U54
M24Q?15)23U)?24Y604Q)1%]35$%25"`I.PT*("`@("`@("!]#0H@("`@("`@
M(`T*("`@("`@("`O+R!C:&5C:R!F;W(@:6YV86QI9"!C:&%R<PT*("`@("`@
M("!I9B`H(7!R96=?;6%T8V@H(B]>*%MA+7I!+5I?72A;82UZ02U:,"TY7UPM
M7"Y=*BD_.BD_6V$M>D$M6E]=*%MA+7I!+5HP+3E?7"U<+ETK*3\D+R(L("1S
M=')I;F<I*2![#0H@("`@("`@("`@("!R971U<FX@6$U,7U5T:6PZ.G)A:7-E
M17)R;W(H(")834P@;F%M97,@;6%Y(&]N;'D@8V]N=&%I;B!A;'!H86YU;65R
M:6,@8VAA<G,L('!E<FEO9"P@:'EP:&5N+"!C;VQO;B!A;F0@=6YD97)S8V]R
M97,B+"!834Q?551)3%]%4E)/4E])3E9!3$E$7T-(05)3("D[#0H@("`@("`@
M("!]#0H@("`@("`@("\O(%A-3"!N86UE(&ES('9A;&ED#0H@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@('T-"@T*("`@+RHJ#0H@("`@*B!R97!L86-E;65N
M="!F;W(@6$U,7U5T:6PZ.G)A:7-E17)R;W(-"B`@("`J#0H@("`@*B!!=F]I
M9',@=&AE(&YE8V5S<VET>2!T;R!A;'=A>7,@<F5Q=6ER90T*("`@("H@4$5!
M4BYP:'`-"B`@("`J#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`
M<&%R86T@("`@<W1R:6YG("`@("`@97)R;W(@;65S<V%G90T*("`@("H@0'!A
M<F%M("`@(&EN=&5G97(@("`@(&5R<F]R(&-O9&4-"B`@("`J($!R971U<FX@
M("!O8FIE8W0@4$5!4E]%<G)O<@T*("`@("HO#0H@("`@9G5N8W1I;VX@<F%I
M<V5%<G)O<B@D;7-G+"`D8V]D92D-"B`@("![#0H@("`@("`@(')E<75I<F5?
M;VYC92`G4$5!4BYP:'`G.PT*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@D;7-G+"`D8V]D92D[#0H@("`@?0T*?0T*/SX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&\O````````````````````````````````````````
M```````````````````````````````````````````````````````P,#`P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U-0`P
M,38R-S8`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R\N:'1A8V-E<W,`````
M````````````````````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#$V`#$P-3$U-#,S-S4T`#`R,#`W,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!$96YY(&9R;VT@86QL"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&\O87)?4UDN<&\`````````````````````
M````````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#8Q-C$U-P`Q,#4Q-30S
M,S<U-``P,3<V-S(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(R!(3U)$12!!<F%B:6,@=')A;G-L871I;VX*(R!4:&ES(&9I
M;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS92!A<R!T
M:&4@2&]R9&4@<&%C:V%G92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#,@4&QA=&EN
M=6T@26YC+B`\<&Q`=&EN=6TN:6YF;SX*(R!#=7-T;VT@5V5B($%P<&QI8V%T
M:6]N<R`\:'1T<#HO+W!L871I;G5M+7-Y+F-O;3X*(R!0;&%T:6YU;2!$979E
M;&]P;65N="!496%M(#QD979T96%M0'!L871I;G5M+7-Y+FYE=#X*(PIM<V=I
M9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2$]21$4@=C(N
M,"XP7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E
M+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K
M,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P,RTP-"TS,"`Q,CHP,"LP
M,C`P7&XB"B),87-T+51R86YS;&%T;W(Z(%!L871I;G5M($1E=F5L;W!M96YT
M(%1E86T@/&1E=G1E86U`<&QA=&EN=6TM<WDN;F5T/EQN(@HB3&%N9W5A9V4M
M5&5A;3H@07)A8FEC(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M
M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O:'1M;#L@8VAA
M<G-E=#U#4#$R-39<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB
M:71<;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S<P"B,L('!H<"UF;W)M870*
M;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,S<W"B,L('!H<"UF;W)M870*;7-G:60@(B`H
M:6X@)7,@9&%Y<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,W,PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-0IM<V=I9"`B("AT;VUO<G)O=RDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,0IM
M<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-38@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,V,0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`W"FUS
M9VED("(@870@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@
M82!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)
M+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A
M('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+U)E9VES=')Y+G!H<#HV-3D*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+U)E9VES=')Y+G!H<#HQ,#0R"B,L('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O
M=7!S('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D8VAI
M;&0N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D
M960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E
M9#H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@
M86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S
M(&%N9"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L('!H<"UF
M;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I
M<F5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@
M(LKDR.WE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW
M,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M
M86EN=&5N86YC92YP:'`Z-#D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS
M9W-T<B`BRN3=[=`@VN/A[<?*(,?AU>W'Y,DB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O
M9B!!9W)E96UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HT,C@@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3`*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV-3$@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D
M>2!E>&ES=',N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,34Y(&QI8B]";&]C:R]M971A<BYP:'`Z,38U(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C,Y"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S0U(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S4Q"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@
M<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E
M;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO
M=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("+6VB#:
MX<?CR2#=[2#CT<C:(,?AVN/A[<D@*,?AVN/A[<?**2#'X<KM(,K1[<\@RN3=
M[=#EQR#-Q^''\"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S0P
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@V"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(M_A(#4@S][MWLDB
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(S
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM
M<V=S='(@(MOMT2#CYLSFSR(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S
M(&]F("5S(@IM<V=S='(@(EO'X=/8T2`E<R#CY"`E<UTB"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDR,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`BS]W*T2#:Y,?F[>0B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R("+#S.3/
MR2(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`V"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@
M9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN
M9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD
M97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C4@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C0Q,`IM<V=I9"`B+"!G=7-T:6YG("(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X."!L:6(O0FQO8VLO
M;65T87(N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@
M)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,CDT(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$R.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-S0Y"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W1I;64N<&AP.C(P"B,L(&9U>GIY"FUS9VED("(Q,B!(;W5R($9O
M<FUA="(*;7-G<W1R("+([<?DQ\K?.B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HQ.0HC+"!F=7IZ>0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B
MR.W'Y,?*WSHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I
M9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@T\?:R2(*"B,Z(&9R86UE=V]R:R]5
M22]522]086=E<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B02!D871A8F%S
M92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V,`HC+"!F=7IZ
M>0IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B
M/&(^(,W5X2#.V,,Z("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T
M;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V-0IM<V=I9"`B02!P=6)L:6,@4$=0
M(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3`Y-PIM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A
M("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$P,34*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4P-0IM<V=I9"`B(@HB02!P=6)L
M:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O
M34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N
M("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME
M>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM
M<V=I9"`B04T@0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$Q"FUS9VED(")!32!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3
M:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-
M+U!-(@IM<V=S='(@(N3EQ]''\"_A[>''\"(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4R"FUS9VED(")!8F]U
M="XN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM
M<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I
M;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A
M=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB
M"FUS9W-T<B`BR.W'Y,?*WSHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-S4*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B
MW^'CR2#'X>/1YM$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,S"B,L(&9U
M>GIY"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(LKDW>W0.B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T
M86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H
M:6QD+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B061D(@IM<V=S='(@(L?AVN3F
MQ^0B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP
M.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*(RP@
M9G5Z>GD*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R("+'X=KDYL?D(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G
M:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO
M;B!T;R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*
M;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34T"FUS9VED(")!9&0@
M8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z,S0*;7-G:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@
M<&%I<B(*;7-G<W1R("+#UMT@R^3'QNTB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N
M=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*(RP@9G5Z>GD*;7-G
M:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(L_=RM$@VN3'YNWD
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<X
M"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S
M='(@(L_=RM$@VN3'YNWD(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*(RP@9G5Z
M>GD*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(L/6W2#+Y,?&[2(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D
M(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I
M=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*
M"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@
M7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*
M;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#$*;7-G:60@(D%D9')E<W,B"FUS
M9W-T<B`BQ^':Y.;'Y"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M,SD*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R("+/W<K1(-KDQ^;MY"(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS
M9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U
M<V5R<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T
M,0HC+"!F=7IZ>0IM<V=I9"`B061S(@IM<V=S='(@(L?AVN3FQ^0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4V"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4W"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G
M:60@(D%L9V5R:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHQ-@IM<V=I9"`B06QI9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM
M96YT.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*
M;7-G:60@(D%L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS
M9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"FUS9VED
M(")!;&P@1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E
M+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S$*;7-G:60@(D%L;&]W(&UU;'1I<&QE
M(&%D9')E<W-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3,T"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T
M>7!E/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R
M964O<W%L+G!H<#HU,#0*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C,*;7-G:60@(D%L=&5R
M;F%T92!)35-0($QO9VEN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,#<*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3D*;7-G:60@
M(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"B,L(&9U>GIY"FUS9VED(")!;'1E
M<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R("+:Y.;'Y"#(T>W/WR#'X<7A
MW\K1YN3M.B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!
M;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I
M9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G
M:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE
M9"XB"FUS9W-T<B`BRN,@RLW/[<\@WNWCR2#;[=$@X][(YN')(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-PHC+"!F=7IZ>0IM<V=I9"`B
M06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`BS=7A(,[8
MPSHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W
M"FUS9VED(")!;F=U:6QL82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*;7-G
M:60@(D%N<W=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A
M<F-T:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@
M86YD($)A<F)U9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N
M:'1M;#HV"B,L(&9U>GIY"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R("+'
MX<K8R.W>Q\H@Q^'CYLSFS\DZ("5S(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N
M<&AP.C0R"B,L(&9U>GIY"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S
M='(@(L?ARMC([=['RB#'X>/FS.;/R3H@)7,B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G
M:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HX,S,*;7-G:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-`HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G
M:60@(D%P<FEL(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU.2!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#$*;7-G:60@(D%R8VAI=F4@
M1FEL92!3:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HV-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@P"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E
M('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB
M)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS
M9VED(")!<FUE;FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3<V"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I
M;VX@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E
M9VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(U
M"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`BRL/?[<\@Q^'8X<@@WLCA
M(,?AR,_!(,C:X^'MQ\H@Q^'5[<?DR;\B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3$S"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T
M<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T
M;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@
M9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T('1O
M(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@V"FUS9VED(")!='1R:6)U=&5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G
M:60@(D%U<W1R:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D
M(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y
M<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET
M97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N
M<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E
M9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T
M:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P
M.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@
M(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U
M<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B075T:%]L
M9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I
M=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@
M(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H
M<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U
M<V5R("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@
M(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z
M-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N
M(@IM<V=S='(@(LKC(-'=UB#'X<K-WMX@X^0@Q^'EYNW)(./D(-[(X2#'X>/.
MS^,@T<?/[>;3+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4Q
M"B,L(&9U>GIY"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"XB"FUS9W-T<B`BS=7A(,[8PR#.X<?A(,?AQ<K5Q^$@R./.S^,@
MQ^'<($944"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P"B,L
M(&9U>GIY"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E
M<B!F86EL960N(@IM<V=S='(@(LW5X2#.V,,@SN''X2#'X<7*U<?A(,CCSL_C
M(,?AW"!&5%`N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM
M<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`BQ^'-WN;A(,?AX\KF
MW=').B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X
M8W5S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K
M97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`BW^'CR2#CT>;1(-O(T2#CWLCF
MX<D@*-_MT<CMT>;3*2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP
M:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B
MQ]/C(,?AX]/*SL_C(-O(T2#CWLCFX2`HW^W1R.W1YM,I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED
M(")"86AR86EN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3<W"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R
M87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*
M;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B
M0F5L9VEU;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QI>F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD
M87DB"FUS9W-T<B`B[>;C(,?AX^WAQ\\B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4S"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`BX>,@[=K+T2#:X>P@Q^'CT\KCVB`E<RXB"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.#D*;7-G:60@(D)L;V-K
M(%-E='1I;F=S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@
M(D)O;&0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`U"FUS
M9VED(")";V]K;6%R:W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`HC+"!F=7IZ>0IM<V=I
M9"`B0F]R9&5R(@IM<V=S='(@(N7FT<_M(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K
M;F5S<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B0F]R9&5R
M<R(*;7-G<W1R("+EYM'/[2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A
M;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*
M;7-G:60@(D)O='-W86YA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)<VQA;F0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B0G)A>FEL
M(@IM<V=S='(@(L?AR-'MSR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H
M($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T
M960@3&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA
M($9A<V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0T"B,L
M(&9U>GIY"FUS9VED(")#35,B"FUS9W-T<B`B0U93(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW
M"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B0V%C
M:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-"!C;VYF:6<O
M:&]O:W,N<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ-34*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(L/,Y,_)(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-@IM<V=I9"`B0V%L;2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@
M<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R
M:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I
M;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S
M97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S
M<6PN<&AP.C,Q.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@
M8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`BX<?%X]_'Y.W)
M(.'AQ<K5Q^$@R,?AX\[/XR!,1$%0+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C0Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"B,L(&9U>GIY
M"FUS9VED(")#86YA9&$B"FUS9W-T<B`BP\SDS\DB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE
M87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z
M,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P
M;W)T(@IM<V=S='(@(L7AV\?!(,?AR.''VR#:Y"#CU-_AR2(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G:60@
M(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HT-@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED
M(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z
M.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G
M('!A<F%M971E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HS,30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A;FYO
M="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`BQ>34Q\$@Q^'C
MS.'/("5S(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ
M,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N
M(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T
M851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N
M=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO
M="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G
M:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR-`HC+"!F=7IZ>0IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R
M("+.[<?1Q\HB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S
M;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDP"FUS9VED(")#871E9V]R:65S(&%N9"!,
M86)E;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)
M<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B
MQ^'EQ\K=(,?AS.;'X2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C4*(RP@9G5Z>GD*;7-G:60@(D-E;&P@4')O
M<&5R=&EE<R(*;7-G<W1R("+'X>7'RMT@Q^',YL?A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@
M<&%D9&EN9SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T
M:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S0*(RP@9G5Z>GD*
M;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R("+'X>7'RMT@Q^',YL?A(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I8R`H25-/+3@X
M-3DM,30I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L
M:6,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G
M:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-CDY"FUS9VED
M(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$Q"FUS9VED(")#97)T:69I8V%T
M92!/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y-@IM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED(")#:&%D(@IM
M<V=S='(@(G9#87)D(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC+"!F=7IZ>0IM
M<V=I9"`B0VAA;F=E(@IM<V=S='(@(LK1Q\S:(-KD(,?ARMOM[=''RB(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0IM<V=I9"`B0VAA;F=E
M(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E
M<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T
M;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN9R!Y;W5R('!A
M<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF
M:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C<*(RP@9G5Z>GD*;7-G:60@(D-H87(B"FUS9W-T<B`B
M=D-A<F0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D-H:6QE(@IM<V=S='(@
M(L?AX=[((@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;F$B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM
M<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X,0IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C(V.0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.`IM<V=I9"`B0VAO
M;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(Y.`IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL
M92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z.#DS"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D
M969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`BX>,@[=K+T2#:
MX>P@Q^'CT\KCVB`E<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ-`HC+"!F=7IZ>0IM<V=I9"`B0VQE87(B"FUS9W-T<B`B
MP\SDS\DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@(D-L96%R(%%U97)Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN
M8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S97(@9&%T
M82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM
M<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED
M(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(L7;X<?>(,?AY,?=T,DB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-`IM<V=I9"`B0VQO=61S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D-L
M;W5D>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E
M;&EN9RD@27-L86YD<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+W-I9&5B87(N:6YC.C(S"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(T"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C4*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,"!S97)V:6-E<R]I;6%G97,O
M8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@T-@IM<V=I9"`B
M0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-@IM<V=I
M9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C8T"FUS9VED(")#;VUI8W,B"FUS9W-T<B`BT=/FX\?*
M(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"B,L(&9U>GIY"FUS9VED(")#
M;VUM86YD(@IM<V=S='(@(L?AP^;'X]$Z(@H*(SH@861M:6XO8VUD<VAE;&PN
M<&AP.C(P"B,L(&9U>GIY"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@
M(L?AP^;'X]$Z(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$S"B,L(&9U>GIY"FUS9VED(")#;VUM96YT(@IM<V=S='(@(L?AP^;'X]$Z
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8*;7-G
M:60@(D-O;6UO;B!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"B,L(&9U
M>GIY"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(M'3YN/'RB(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O
M;7!A;GDB"FUS9W-T<B`BQ^'4T=_)(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y-PHC+"!F=7IZ>0IM<V=I9"`B0V]N
M9&ET:6]N(@IM<V=S='(@(LKDW>W0(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-#D*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF9F5R
M96YC97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T
M,PIM<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L
M(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3,U"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES
M(&]U="!O9B!D871E+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C4Q"B,L(&9U>GIY"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@
M(M_AX\D@Q^'CT>;1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC
M(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")#;VYN
M96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`BS=7A(,[8PR#.X<?A(,?AQ<K5Q^$@
MR./.S^,@Q^'<($944"XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N(&9A:6QE
M9#H@(@IM<V=S='(@(LW5X2#.V,,@SN''X2#'X<7*U<?A(,CCSL_C(,?AW"!&
M5%`N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"B,L
M(&9U>GIY"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI
M8R!K97ES97)V97(N(@IM<V=S='(@(LW5X2#.V,,@SN''X2#'X<7*U<?A(,CC
MSL_C(,?AW"!&5%`N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E
M9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#0U"B,L
M(&9U>GIY"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D
M+B(*;7-G<W1R("+-U>$@SMC#(,[AQ^$@Q^'%RM7'X2#(X\[/XR#'X=P@1E10
M+B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#$T"FUS9VED(")#;VYT
M86-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U
M;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(N/-RN;M
MQ\H@)R5S)R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B
M0V]O:VEE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B0V]P
M>2(*;7-G<W1R("+'X=31W\DB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C0V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL
M960Z("5S(@IM<V=S='(@(L?AS=[FX2#'X>/3RN;1S\DZ("5S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B
M0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDW-@IM<V=I9"`B0V]U
M;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-3,*;7-G:60@(D-O=6QD
M(&YO="!01U`@<VEG;B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T
M(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N
M;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@
M)7,B"FUS9W-T<B`BX<<@Q>/?Q^3MR2#AY-/.("5S(,7A["`E<R(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C$R,0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T
M(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(N''Q>/?Q^3MR2#AX<7*
MU<?A(,C'X>/.S^,@3$1!4"XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-#4W"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HQ-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R("+AQR#%X]_'Y.W)
M(.'DT\X@)7,@Q>'L("5S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T
M,0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S
M97)V97(B"FUS9W-T<B`BX<?%X]_'Y.W)(.'AQ<K5Q^$@R,?AX\[/XR!334(N
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I
M;F<@1E10.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,B"FUS9W-T<B`BX<?%X]_'Y.W)(.'%Y-3'P2#CS.'/(./-X>T@*&QO8V%L
M*2#CY"##S.$@X^'=(,?AX=O)("5S.B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$Q,C4*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!D
M96-R>7!T(%!'4"!D871A+B(*;7-G<W1R("+AQR#%X]_'Y.W)(.'DT\X@)7,@
MQ>'L("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M,C(*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C(T-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R("+AQR#%X]_'Y.W)(.'D
MT\X@)7,@Q>'L("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU
M,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@
M92UM86EL(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y
M,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO
M;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H
M('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R
M871E9WD@7"(E<UPB+B(*;7-G<W1R("+AQR#%X]_'Y.W)(.'DT\X@)7,@Q>'L
M("5S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C
M="YP:'`Z,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K
M97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z,3,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(N''(,7C
MW\?D[<D@X>33SB`E<R#%X>P@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("+AQR#%X]_'
MY.W)(.'DT\X@)7,@Q>'L("5S(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T
M<B`BX<?%X]_'Y.W)(.'=RLT@36%I;G1E;F%N8V5?5&%S:R#AX<C1[>/,("5S
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G
M<W1R("+AQR#%X]_'Y.W)(.'DT\X@)7,@Q>'L("5S(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-CDY"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE
M($Q$05`@<V5R=F5R+B(*;7-G<W1R("+AQ\7CW\?D[<D@X>'%RM7'X2#(Q^'C
MSL_C($Q$05`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR
M,S@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D
M("5S+B(*;7-G<W1R("+AQR#%X]_'Y.W)(.'DT\X@)7,@Q>'L("5S(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD
M(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E
M<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R
M96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-PHC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K
M+B`E<R(*;7-G<W1R("+AQ\7CW\?D[<D@X<7DU,?!(./,X<\@X\WA[2`H;&]C
M86PI(./D(,/,X2#CX=T@Q^'AV\D@)7,Z(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PIM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"B,L(&9U
M>GIY"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(N'C(.W*XR#%VL_'SR#EYM'/[2#(U-_A(-7-[<TB"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(N'C(.W:R]$@
MVN'L("=P;W)T)R#=[2#%VL_'S\?*(%9&4RXB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*;7-G:60@
M(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO
M;CH@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E
M<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F
M('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O
M<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T,PHC+"!F
M=7IZ>0IM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N
M(@IM<V=S='(@(N''Q>/?Q^3MR2#AX<7*U<?A(,C'X>/.S^,@3$1!4"XB"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N
M("5S(@IM<V=S='(@(N''(,7CW\?D[<D@X>33SB`E<R#%X>P@)7,B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@
M(N''Q>/?Q^3MR2#AQ>34Q\$@X\SASR#CS>'M("AL;V-A;"D@X^0@P\SA(./A
MW2#'X>';R2`E<SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8V"FUS
M9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@
M<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@
M9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3D*;7-G
M:60@(D-O=6YT960@=&5X="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<S"FUS9VED(")#
M;W5R<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT
M"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A
M=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(S,`IM
M<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G
M:60@(D-U8F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V
M"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HT.`IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM
M92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HS,PIM<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED(")#=7)R96YT
M(%=E871H97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(W-0IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S
M=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED(")#=70@
M<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I
M9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED
M(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,2!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B[>;C("T@
MT=[C[>0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@Q"FUS9VED
M("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P
M86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3D*
M;7-G:60@(D1A:6QY(@IM<V=S='(@(NWFX^TB"@HC.B!A9&UI;B]D871A=')E
M92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W.0IM<V=I9"`B1&%T86)A
M<V4@3&]O:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,Y.0IM<V=I9"`B1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`W"FUS
M9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,CDR(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS,C(*(RP@9G5Z>GD*;7-G:60@(D1A>2(*;7-G<W1R("+MYN/M(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,V"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B
M1&5C96UB97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N
M=6UB97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$X-R!L
M:6(O<')E9G,N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="(*;7-G
M<W1R("+'X<K-WMX@Q^''W<K1Q];M(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U
M;'0@0V]L;W(B"FUS9W-T<B`BQ]/*SL_C(,?AWNWC(,?AQ=W*T<?6[<DB"@HC
M.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.CDQ"FUS9VED(")$
M969A=6QT($ED96YT:71Y(@IM<V=S='(@(L?ARLW>WB#'X<?=RM''UNTB"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E
M9F%U;'0@4VAE;&PB"FUS9W-T<B`BQ^'*S=[>(,?AQ]W*T<?6[2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,R!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X
M,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O9&5L971E+FEN8SHQ,"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B
M1&5L971E($-E;&PB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ
M.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*
M;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G
M:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M-PIM<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B
M1&5L971E(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP
M;&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO
M;G,@9F]R(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@
M<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S:6]N
M<S\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U
M"B,L(&9U>GIY"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS
M9W-T<B`BQ^'*S=[>(,?AQ]W*T<?6[2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E
M('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@
M(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR-3,*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I
M8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`BU-'-(,?AX]3?X<DB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HY,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`HC+"!F=7IZ>0IM<V=I9"`B1&5S
M8W)I<'1I;VXB"FUS9W-T<B`BQ^'4T<T@Q^'*W=7MX>TZ(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.34*;7-G:60@(D1E=&%I;',@*&%L<V\@
M:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ.3D*;7-G:60@(D1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(LKC(,W=
MV2#'X<K=Q]7MX2#AX\_MT2#'X>39Q^,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C$Y"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-PIM<V=I9"`B1&5W(%!O:6YT(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDT"FUS9VED(")$
M97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C<*;7-G:60@(D1E=R!P;VEN=#H@
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E
M8W1O<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V
M-@IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D1I<W!L87D@3W!T
M:6]N<R(*;7-G<W1R("+.[<?1Q\H@Q^':T=8B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@9&5T
M86EL960@9F]R96-A<W0B"FUS9W-T<B`BSNW'T<?*(,?AVM'6(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HX-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H
M5$%&*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#$W"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R("+.
M[<?1Q\H@Q^':T=8B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z
M,3DP"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*;7-G:60@(D1O(&YO
M="!D96QE=&4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA
M;F-E+G!H<"(*;7-G<W1R("+AQR#*S\[A(./(Q]31R?`@Q>'L(,?AX^'=(&UA
M:6YT96YA;F-E+G!H<"(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S
M('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE
M<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G
M:60@(D1O;6EN:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O
M;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_
M(%-I9VX@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C@T-`IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R("+#
MX]$@V^W1(./:T>;=("5S.B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S
M(%!(4"!S8W)I<'0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q,#<*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S
M"B,L(&9U>GIY"FUS9VED(")%+4UA:6PB"FUS9W-T<B`BQ^'(T>W/(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G
M:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S
M('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,`IM<V=I9"`B16-U861O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z-S(*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I
M9"`B161I="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M54DN<&AP.C4P('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G:60@
M(D5D:70@0FQO8VLB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ
M.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`IM<V=I9"`B161I="!0
M97)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO
M;G,@9F]R.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I
M;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI
M<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<P"FUS9VED(")%9WEP="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C,Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")%:71H97(@
M96YA8FQE(&ET('1H96XZ("5S+"!O<B!U<V4@=&AE(&)A<VEC($A434P@=F5R
M<VEO;CH@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B16P@
M4V%L=F%D;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X-CD*;7-G:60@(D5M86EL(@IM<V=S='(@(L?AR-'M
MSR#'X<7AW\K1YN3M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"B,L(&9U>GIY
M"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(MKDYL?D(,C1[<_?(,?A
MQ>'?RM'FY.TZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV,PIM
M<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#D*(RP@9G5Z>GD*;7-G
M:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(N/:X>;CQ\H@
MPL[1["(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N
M<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDX
M"B,L(&9U>GIY"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T<B`BSNW'T<?*(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`R"B,L(&9U>GIY"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R("+A
MQ\KFS,\@Y,K'QLPN(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R
M("+AQ\KFS,\@Y,K'QLPN(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R
M9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#,*;7-G:60@(D5N86)L
M92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN
M('1E>'0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,3@*;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.3@@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,0IM<V=I9"`B16YD('EE87(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,0IM<V=I9"`B(@HB16YT97(@82!S
M96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y
M;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T
M(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX
M.3$*;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDY(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+W-T871U<RYP:'`Z,C<*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-0HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,V('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z.#(*
M;7-G:60@(D5R<F]R(@IM<V=S='(@(L[8PR(*"B,Z(&9R86UE=V]R:R]496UP
M;&%T92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@(D5R
M<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8X"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U
M<F]P92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y
M"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(M_A(#$U(,_>[=[)
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.0HC+"!F=7IZ>0IM<V=I
M9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(M_A(#4@S][MWLDB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.#<*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`BW^$@,S`@
MS][MWLDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,X(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.3`*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G
M<W1R("+?X2`U(,_>[=[)(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA
M:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B
MW^$@S\[FX2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`*;7-G:60@
M(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R("+?X2#DU=T@T\?:R2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S<@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,X.`IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(M_A(,_>[=[)(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP
M;&4@=F%L=65S.B(*;7-G<W1R("+#X\OAR2#:X>P@Q^'>[>,Z(@H*(SH@861M
M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3(W"B,L(&9U>GIY"FUS9VED(")%>&5C=71E(@IM
M<V=S='(@(LKDW>W0.B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C0W-0IM<V=I9"`B17AP86YD(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N9"!3:61E
M8F%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S
M+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E
M8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I
M9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C<V"FUS9VED(")%>'!O;F5N="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F
M('-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S
M<6PN<&AP.C(Q-@IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC
M97,N(@IM<V=S='(@(N''Q>/?Q^3MR2#AX=K+YM$@VN'L(,?ARMW6[>''RBXB
M"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O
M;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(N''Q>/?Q^3MR2#AX<7*
MU<?A(,C'X>/.S^,@3$1!4"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M
M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V
M97(N(@IM<V=S='(@(N''Q>/?Q^3MR2#AX<7*U<?A(,C'X>/.S^,@4TU"+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@V"B,L('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8Y,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB
M+B(*;7-G<W1R("+AQ\7CW\?D[<D@X>'%RM7'X2#(Q^'CSL_C(%--0BXB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL
M960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DW(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-S(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(N''Q>/?Q^3M
MR2#AX<7*U<?A(,C'X>/.S^,@4TU"+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z-#8Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL
M960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(N''Q>/?Q^3MR2#AX=K+YM$@
MVN'L(,?ARMW6[>''RBXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X"B,L(&9U>GIY"FUS
M9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`BS=7A(,[8PSHB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&
M87@B"FUS9W-T<B`BW<??TR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS-#D*(RP@9G5Z>GD*;7-G:60@(D9A>&5S(@IM<V=S='(@(MW'W],B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I
M9"`B1F5B<G5A<GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR,C`*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B1F5E;',@;&EK93H@
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B
M1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.30T"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-`IM<V=I9"`B1FEG
M;&5T($-!4%1#2$$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S,S.`IM<V=I9"`B1FEG;&5T(&9O;G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(D9I;&4B"FUS
M9W-T<B`BQ^'AWL@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF
M;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#<*;7-G:60@(D9I;&4@
M36%N86=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HX-0HC+"!F=7IZ>0IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(L?AQ]/C
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDY-0IM<V=I9"`B1FEL
M92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30X-@IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4Y"FUS9VED(")&:6QE
M('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C@Y"FUS9VED(")&:6QT97)S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO
M;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-38*;7-G
M:60@(D9I>"!R871I;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Q"FUS9VED(")&;&EP(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,S0@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I
M9"`B1F]N="!#;VQO<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"FUS
M9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S-`IM<V=I9"`B
M1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C<Y"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E
M('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@
M86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L
M="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R
M9#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V
M,@IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`HC+"!F=7IZ>0IM
M<V=I9"`B1F]R='5N97,B"FUS9W-T<B`BX^''S=G'RB(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4S"FUS9VED(")&;W)U
M;7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P
M.0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS,PHC+"!F=7IZ>0IM<V=I9"`B1G)A;65S(@IM<V=S='(@(L?A
MQ]/C(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E
M+"!-971R;W!O;&ET86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B
M1G)E;F-H($=U:6%N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B
M1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G
M:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS
M9VED(")&<F]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-#@@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,`HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`V"FUS9VED(")&<F]M
M('1H92`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z-#@*(RP@9G5Z>GD*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS
M9W-T<B`BQ^'4T<T@Q^'*W=7MX>TZ(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV,`HC+"!F=7IZ>0IM<V=I9"`B
M1G5L;"!.86UE(@IM<V=S='(@(L?3X]\Z(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B
M1V%B;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O
M('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@
M(D=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=A;6)I
M82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L
M('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH
M=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM
M<V=I9"`B1V5R;6%N>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'
M:&%N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-S4*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V%P<"YI;F,Z,3(*;7-G:60@(D=O(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,3(X"FUS9VED(")';V]G;&4@36%P<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,S<*;7-G:60@(D=R87ES8V%L92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@U"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`Z-3D@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B1W)O
M=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,P-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q."!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?
M;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S,X(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*
M;7-G:60@(D=U86TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U
M871E;6%L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDR"FUS9VED(")'=65R;G-E>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C@X"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<P"FUS9VED(")'=65S
M=&)O;VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W5I;F5A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-C`*;7-G:60@(DA4
M34PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D
M96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%144"!!
M=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R:71H;2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR,@IM<V=I9"`B2&%Z92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HY,3D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS
M,@IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-C$*;7-G:60@(DAE861E<G,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD
M($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*;7-G:60@(DAE879Y(%0M4W1O
M<FTB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G
M:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS
M9VED(")(96EG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+TAE;'`N<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP
M:'`Z,3@V"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L871E
M<R]H96QP+VEN9&5X+FEN8SHS"FUS9VED(")(96QP(@IM<V=S='(@(L?AX]/'
MVL_)(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W,0HC+"!F=7IZ>0IM<V=I9"`B
M2&5L<&5R(@IM<V=S='(@(L?AX]/'VL_)(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE
M(&9I;&4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")(:6=H(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M
M;6]N+6AE861E<BYI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B2&]?;64B"FUS9W-T
M<B`BQ^'(S\?MR2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6
M871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,34S-0IM<V=I9"`B2&]M92(*;7-G<W1R("+'X<C/
MQ^W)(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$R,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`BVN3FQ^0@Q^'CY-+A
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"FUS9VED(")(;VUE($1I
M<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@
M(N7'RMT@Q^'CY-+A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C4*;7-G:60@
M(DAO<F1E(@IM<V=S='(@(N7FT<_M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HT-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G
M92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN
M(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HQ,C4P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E
M+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G
M9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@
M;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3(T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#<T"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)
M1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q.3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S
M7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,3,S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA
M8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@R"FUS9VED
M(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO
M;G1A;#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G
M970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS
M9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E
M/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR
M,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@
M>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S`*
M;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-3D*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W
M,B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,U"B,L('!H<"UF
M;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP
M.C(Q-"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H
M<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N
M<&AP.C$W.2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C0R"B,L
M('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO
M;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S,38*(RP@9G5Z>GD*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T
M<B`BQ^':Y.;'Y"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP
M:'`Z-S<*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX.0IM
M<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C
M:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I
M;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F
M;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<V"FUS9VED
M("))8V]N<R!/;FQY(@IM<V=S='(@(L/MWN;DQ\H@W=[8(@H*(SH@=71I;"]I
M8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(DEC;VYS
M(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S<W"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`BP^W>YN3'RB#C
MVB#DU>;5(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B
M261E;G1I='DG<R!N86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@
M:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#4U"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N
M>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D
M('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A
M<F5N8WDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ-S,*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M
M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P
M;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E(%!R979I97<Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM86=E
M('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A
M+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DEM
M<&]R="P@4W1E<"`E9"(*;7-G<W1R("+'X<W>YN$@Q^'CT\KFT<_).B`E<R(*
M"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M
M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("+'X<W>YN$@
MQ^'CT\KFT<_).B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`BQ^'-WN;A(,?A
MX]/*YM'/R3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N
M<&AP.C$S-0IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S,@HC+"!F=7IZ>0IM<V=I9"`B26YC;W)R96-T('5S97)N
M86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`BSMC#(-WM(,?3XR#'X>/3
MRL[/XR#F+\/F(-_AX\D@Q^'3T2XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L
M=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*
M(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@Q"FUS9VED("));F1I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(DEN9&]N97-I82(*;7-G
M<W1R("+*XR#(Y,S'S2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U-PHC+"!F=7IZ>0IM<V=I9"`B26YF
M;W)M871I;VXB"FUS9W-T<B`BR.W'Y,?*WSHB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S,P"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG
M97(@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R
M="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B
M26YS97)T($EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H
M92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R
M="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE
M(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T
M(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C
M=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@
M82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B
M(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A
M;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(S.0IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@
M=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP
M"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS
M9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV.0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X
M"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C,P"FUS9VED("));G-E<G0@=&AE(')E<75I
M<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I
M9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("))
M;G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO
M;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R
M961I="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3`W-0IM<V=I9"`B26YT96=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3,S"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D
M97(I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O>FEP+G!H<#HQ-S`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+WII<"YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z
M:7`N<&AP.C(Q,`IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"B,L(&9U>GIY"FUS9VED
M("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R("+'X<K8R.W>Q\H@Q^'C
MYLSFS\DZ("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@W(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(S,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,CDY"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@
M(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I
M9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HX,0HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#`*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,C(P"FUS9VED("))
M;G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-S<*;7-G:60@(DEN=F%L:60@;&EC96YS92!K
M97DN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-S$*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T
M97)S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S,*;7-G:60@
M(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$W-0IM<V=I9"`B26YV86QI9"!P<F]D=6-T
M(&-O9&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O
M;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z
M(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C$P-S8@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C8R"FUS9VED
M("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@
M(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I
M9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS-3<*;7-G:60@(DEN=F5N=&]R>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-C<Y"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F
M($UA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C4*;7-G:60@
M(DES<W5E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#(*(RP@9G5Z>GD*;7-G:60@(DET86QY(@IM<V=S='(@(NWF
MX^TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G
M:60@(DIA;G5A<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*
M87!A;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM
M<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`IM<V=I9"`B(@HB2F%V87-C
M<FEP="!H87,@8F5E;B!D:7-A8FQE9"!O;B!Y;W5R(&)R;W=S97(@86YD('1H
M:7,@<&%G92!M87D@;F]T(&)E("(*(F1I<W!L87EI;F<@8V]R<F5C=&QY+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,@IM
M<V=I9"`B2F5R<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B
M2F]R9&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*
M=6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G
M:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S
M=&EF>2!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA
M>F%K:'-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(V-`IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+
M97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(L?AX\[/XR#?[='([='FTR#1W=8@Q^'*S=[>(./D(,?AY>;MR2XB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B
M:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,0IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I
M;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME
M>2!4>7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DX"B,L(&9U>GIY"FUS9VED(")+97D@57-A9V4B"FUS9W-T
M<B`BS<SC(,?AQ]/*SL_'XSHB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U
M"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O
M9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U
M8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M.`IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM
M<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VUE;G4N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(DQA7WEO=70B"FUS9W-T
M<B`BSM'FS"(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G
M:60@(DQA;F=U86=E(@IM<V=S='(@(L?AX=O)(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS
M9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA
M;&8B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"FUS
M9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED
M("),87-T(%%U87)T97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-3$*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G
M:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.C<R,0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO
M9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.C<Q-@IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),87<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<Y"B,L(&9U>GIY"FUS9VED("),87EO=70B"FUS9W-T<B`BSM'F
MS"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV
M.0IM<V=I9"`B3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3$Y"FUS9VED("),969T(&AE861E<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$U"B,L(&9U>GIY"FUS9VED
M("),969T('9A;'5E<R(*;7-G<W1R("+#X\OAR2#:X>P@Q^'>[>,Z(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B3&5V
M96PB"FUS9W-T<B`BP\C/Q_`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R
M:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A
M8B!*86UA:&ER:7EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B
M3&EE8VAT96YS=&5I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R("+/
MSN;A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI
M9VAT(%)A:6X@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W
M97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H
M="!3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X,30*(RP@9G5Z>GD*;7-G:60@(DQI;FLB
M"FUS9W-T<B`BS\[FX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S4*
M;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@
M<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,PIM<V=I9"`B
M3&EN:W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V
M"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U
M<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3,S"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,`IM<V=I9"`B3&ES
M="!(96QP(%1O<&EC<R(*;7-G<W1R("+>Q\;CR2#:Y,?F[>0@Q^'CT\?:S\DB
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,R"FUS9VED("),:7-T(%1A8FQE
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N
M<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3@Y"B,L(&9U>GIY"FUS
M9VED("),:7-T+4AE;'`B"FUS9W-T<B`BWL?&X\D@VN3'YNWD(,?AX]/'VL_)
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.38*;7-G
M:60@(DQI<W0M260B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12](96%D97)S+G!H<#HU.3(*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3,*;7-G
M:60@(DQI<W0M4&]S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU
M.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I
M;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U
M<V5R<R!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D
M:7-A8FQE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.#,*(RP@9G5Z>GD*;7-G:60@
M(DQO861I;F<N+BXB"FUS9W-T<B`BRLWC[>$@Q^'CW\K(Q\HN+BXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Q"FUS9VED("),;V-A;"!T
M:6UE.B`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S
M"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C8T"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L
M:6(O0FQO8VLO;65T87(N<&AP.C8U"FUS9VED("),;V-A=&EO;B(*;7-G<W1R
M("(B"@HC.B!L;V=I;BYP:'`Z,3<R('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HQ.3$@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP
M;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS9W-T<B`BS\[FX2(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R
M979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,3@U"FUS9VED("),;V<@;W5T(@IM<V=S='(@
M(L[1YLPB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*(RP@9G5Z>GD*
M;7-G:60@(DQO9VEN(@IM<V=S='(@(L_.YN$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3`W"B,L(&9U>GIY"FUS9VED("),;V=I;B!487-K<R(*;7-G
M<W1R("+'X>/EX\?*(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DV
M"B,L(&9U>GIY"FUS9VED("),;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S
M97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*
M;7-G<W1R("(B"B+-U>$@SMC#(.'3R,@@X\<@P\ODQ\$@Q^'/SN;A+B#:X>P@
MQ^'#T<S-(,/D(,?3XR#'X>/3RL[/XR##YB#?X>/)(,?AX]'FT>'MT\H@(@HB
MU<WMS<DB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3(*(RP@9G5Z
M>GD*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`BW=3A(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-0HC+"!F=7IZ>0IM<V=I9"`B3&]N
M9R!T97AT(@IM<V=S='(@(L[1YLPB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#@*;7-G:60@(DQO=F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(DQO=R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#,X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G
M<W1R("+4Y=$@+2#1WN/MY"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR.#$*;7-G:60@(DU/5$0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T
M86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B
M:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,@IM<V=I9"`B36%C86\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED
M(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0HC+"!F=7IZ
M>0IM<V=I9"`B36%G:6,B"FUS9W-T<B`BQ^'(T>W/(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C@Q"FUS9VED(")-86EL(@IM<V=S='(@(L?AR-'M
MSR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C(*;7-G:60@(DUA
M:6P@061M:6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K
M+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B
M36%L87=I(@IM<V=S='(@(L?AR-'MSR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B
M36%L87ES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD
M:79E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@
M(DUA;&DB"FUS9W-T<B`BQ^'(T>W/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY
M"FUS9VED(")-86QT82(*;7-G<W1R("+'X<C1[<\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3$*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C
M871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C
M;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,34S"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#0*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-C@*;7-G:60@
M(DUA<%%U97-T(&UA<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*(RP@9G5Z>GD*;7-G
M:60@(DUA<F=I;B(*;7-G<W1R("+*Y,CMY2(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E
M;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE
M<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA
M=&-H:6YG(&9I96QD<R(*;7-G<W1R("+CV,?(WLD@Q^'-WN;A(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B
M36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA
M>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,P-@IM<V=I9"`B36%X('1E;7`@;&%S="`R-"!H
M;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDX
M"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R
M=&%L($)L;V-K<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-87AI;75M(&QE;F=T
M:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3<*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"B,L(&9U>GIY"FUS
M9VED(")-96UB97)S(@IM<V=S='(@(N/0W]''RB(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-S@*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`BYM;:
M(,?AX]#?T<?*.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@(M'3Q^')(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*
M(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R
M)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB
M"FUS9W-T<B`BT=/'X<DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"B,L(&9U>GIY"FUS9VED
M(")-97-S86=E('1Y<&4B"FUS9W-T<B`BT=/'X<DB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(LKC(,W=V2#'X<K=Q]7MX2#AX\_MT2#'
MX>39Q^,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS
M9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z
M.#$@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP:'`Z,3$W"B,L('!H<"UF;W)M
M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T
M:&]D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-0IM<V=I9"`B365T<FEC
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&961E<F%T
M960@4W1A=&5S(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@HC+"!F=7IZ>0IM<V=I9"`B
M36ED9&QE(@IM<V=S='(@(L?AR-'MSR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3`*;7-G:60@(DUI;B!T
M96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,P,@IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT
M,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X
M<&ER960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(S-`HC+"!F=7IZ>0IM<V=I9"`B36ER<F]R(@IM<V=S
M='(@(L[8PR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B
M36ES8V5L;&%N96]U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@
M4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF
M:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U
M('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I
M;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HW-`IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C@*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HW,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T9WHN<&AP.C@X"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W,PIM<V=I9"`B36]D
M=6QU<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B
M36]N86-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N9V]L
M:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y
M-`IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N
M=&AL>2(*;7-G<W1R("+4Y='MQ_`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUO
M;G1S97)R870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-S(@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C4S"B,L('!H<"UF;W)M870*;7-G
M:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP
M96-T960@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R
M;V-C;R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS
M9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N
M;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z-3`Y"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$S"FUS9VED(")-;W9E
M($QE9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z-3$W"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P-0IM<V=I9"`B
M36]V92!5<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R
M,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T
M"FUS9VED(")-;W9E('5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I
M9"`B36]Z86UB:7%U92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3@T"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$P-34*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0R"FUS9VED(")-
M=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0P,`IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@
M(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`BR.W'Y,?*WSHB"@HC
M.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C4T"FUS9VED(")->2!0;W)T
M86PB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C$S
M-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)
M($1O($Y/5"!!9W)E92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,3$@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R("+'X<?3XR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I
M9"`B3F5P86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").971H
M97)L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R
M;&%N9',@06YT:6QL97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E($)A<V4@55),
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3@S"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X
M-0IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I9"`B
M3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E(%)E
M=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P92!34TP@<V5R=F5R
M(&YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE
M;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#`*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U,0IM<V=I
M9"`B3F5T=V]R:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-0HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS9VED(").979E<B(*;7-G<W1R
M("+#R,_'\"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D;VYI82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-
M86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX
M,0HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z
M.#<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP
M.CDW"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H
M<#HQ,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C
M:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").
M97<@36]O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L86YD(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PHC
M+"!F=7IZ>0IM<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(M_AX\D@Q^'C
MT>;1(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C(R-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@
M)7@N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X.0HC+"!F=7IZ
M>0IM<V=I9"`B3F5W<R(*;7-G<W1R("+CX<?-V<?*(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,P-0IM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-2!T96UP;&%T
M97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T82]C<W9M
M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-0IM<V=I
M9"`B3F5X="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*
M;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HS-S(@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HS-S8*(RP@9G5Z>GD*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G
M<W1R("+:YL_)(,7A["#'X<[MQ]''RB(*"B,Z(&9R86UE=V]R:R]522]522]0
M86=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.38*(RP@9G5Z>GD*;7-G:60@(DYI9V5R(@IM<V=S='(@(L/(S\?P(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.#`*;7-G:60@(DYI9VAT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-PHC+"!F=7IZ>0IM<V=I9"`B3FEU92(*;7-G
M<W1R("+*Y,CMY2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HY-C,*;7-G:60@(DYO(@IM<V=S='(@(N''(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").;R!A=F%I;&%B
M;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(N<&AP.C$P-0IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O
M<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").
M;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z-SD@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z,C0U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C(V-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U
M97-T960@<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]M8V%L+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B3F\@8V%L96YD87(@
M;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`BX<?*YLS/(-_AX\D@X]'FT2#AX<K-WMX@4TU"/B(*"B,Z(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C4T"B,L(&9U>GIY"FUS9VED(").;R!C:&%N9V4N(@IM
M<V=S='(@(LK1Q\S:(-KD(,?ARMOM[=''RB(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@
M861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V-R!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C4P,@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-S,*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`BX<?*YLS/(./:
MX>;CQ\H@S>;A(,7:S\?/Q\H@Q^'<(%-13"!61E,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HX,C0*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R("+A
MQ\KFS,\@X]KAYN/'RB#-YN$@Q=K/Q\_'RB#'X=P@1E10(%9&4RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8V.0IM<V=I9"`B3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM
M<V=S='(@(N''RN;,SR#CVN'FX\?*(,WFX2#%VL_'S\?*(,?AW"!344P@5D93
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,3<*;7-G
M:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!344PM1FEL92!61E,N(@IM<V=S='(@(N''RN;,SR#CVN'FX\?*(,WFX2#%
MVL_'S\?*(./AW<?*(%-13"!61E,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@
M;&5F="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U
M<'!L:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W
M<V5R+G!H<#HX-S<*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B
M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I8V]N
M<R!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$R."!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ,C,*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V
M.0HC+"!F=7IZ>0IM<V=I9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM<V=S
M='(@(N'C(.W*XR#*S<_MSR#AV\D@X\WA[<DN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*(RP@9G5Z>GD*;7-G
M:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(N'C(.W*XR#*S<_M
MSR#AV\D@X\WA[<DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S8*(RP@9G5Z>GD*;7-G:60@(DYO(&YA;64@<W!E
M8VEF:65D+B(*;7-G<W1R("+AXR#MRN,@RLW/[<\@X=O)(./-X>W)+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W
M"B,L(&9U>GIY"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R
M("+AXR#MRN,@RLW/[<\@X=O)(./-X>W)+B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$*(RP@
M9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+AQ\KFS,\@W^'CR2#CT>;1(.'ARLW>
MWB!,1$%0+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X
M"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!
M4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BX<?*YLS/(-_AX\D@X]'FT2#A
MX<K-WMX@3$1!4"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP
M.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(N''RN;,SR#?X>/)(./1YM$@X>'*
MS=[>(-_MT<CMT>;3(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H
M<#HW-R!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`BX<?*YLS/(-_AX\D@X]'FT2#AX<K-WMX@3$1!4"XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U"B,L(&9U>GIY"FUS
M9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R("+AQ\KFS,\@W^'CR2#CT>;1(.'ARLW>WB!334(^
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C@T"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R("+AQ\KFS,\@W^'CR2#CT>;1(.'ARLW>WB!334(^(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@V"FUS9VED("(B"B).
M;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P
M96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#
M4R`Q,B!D871A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW-3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S
M"B,L(&9U>GIY"FUS9VED(").;R!R=6QE<R(*;7-G<W1R("+CX<?-V<?*(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Y"B,L(&9U>GIY"FUS
M9VED(").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G<W1R("+AXR#MRN,@
MRLW/[<\@X=O)(./-X>W)+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*(RP@9G5Z>GD*;7-G:60@(DYO('-I
M9&5S(@IM<V=S='(@(N/AQ\W9Q\HB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C4X,PIM<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,S@*;7-G:60@(DYO('1E
M;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HR,C$*(RP@9G5Z>GD*;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S
M=V]R9"!S96YT+B(*;7-G<W1R("+.V,,@W>T@Q]/C(,?AX]/*SL_C(.8OP^8@
MW^'CR2#'X=/1+B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z
M,30P"FUS9VED(").;R!V86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.3<Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY
M.#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY
M,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`P
M.0IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I
M9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(X"FUS
M9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@
M4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T
M97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"B,L(&9U>GIY"FUS9VED
M(").;VYE(@IM<V=S='(@(LKC(,CDS,?-(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM
M<&QI8VET*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M.0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P
M"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED
M(").;W0@069T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#`X"B,L(&9U>GIY
M"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`BQ>34Q\$@Q^'CS.'/
M("5S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H
M<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+G!H<#HX,PHC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-`HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L
M96UE;G1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV.`HC+"!F=7IZ>0IM<V=I9"`B3F]T('-E="(*
M;7-G<W1R("+CX<?-V<?*(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#,*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S,*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#<*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR
M,S0@9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z,C`U(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,S`*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C(T."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,C8U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.#$@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C(Y-PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$R(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HS,CD*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C,V,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(R"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HU,#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W,`HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3@W(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HV-C4*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N
M9FEG+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$W.`IM<V=I9"`B3F]T97,B"FUS9W-T<B`BX^''S=G'RB(*"B,Z
M('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN
M9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"B,L(&9U>GIY"FUS9VED
M(").;W9E;6)E<B(*;7-G<W1R("+#R,_'\"(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$P-#8*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B(*;7-G<W1R
M("+'X<?3XR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C4*;7-G
M:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30R,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0U('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"B,L(&9U>GIY
M"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R("+:S\\@Q^'#VN//
MR2#=[2#'X>/ASM4Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V
M-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T-#,@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T
M:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+
M(@IM<V=S='(@(N/FQ]W>(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@
M0W)E871O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@
M(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS,C8*;7-G:60@(D]F9FEC92(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@
M;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"B,L(&9U>GIY"FUS
M9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`BW^'CR2#'X>/1YM$B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*(RP@9G5Z>GD*;7-G:60@
M(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`BSMC#(-WM
M(,?3XR#'X>/3RL[/XR#F+\/F(-_AX\D@Q^'3T2XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*
M;7-G:60@(D]M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S
M('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R
M='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3@U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q"FUS9VED(")/;FQY
M(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@
M;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE
M<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,S4*;7-G:60@(D]P
M96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R
M.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P
M87)T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN
M:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@
M(D]P=&EO;G,B"FUS9W-T<B`BSNW'T<?*(@H*(SH@<V5R=FEC97,O<')E9G,N
M<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$T"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R("+.[<?1
MQ\HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D]R9V%N:7-A
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,R"FUS9VED(")/
M<F=A;FEZ:6YG(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC
M97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,C(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S
M,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q"FUS9VED(")/=&AE<B!);F9O
M<FUA=&EO;B(*;7-G<W1R("+CVN'FX\?*(,+.T>PB"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-SD*
M;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S
M;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<S"FUS
M9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,Q.0IM<V=I9"`B4$=0($5N
M8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$S-S$*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-3,*
M;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"B,L(&9U>GIY"FUS9VED(")02%`@
M0V]D92(*;7-G<W1R("+EYM'/[2(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR
M,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,:6=H="!2
M86EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,X"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED
M(")032!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#$*;7-G:60@(E!-(%-U;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@5"U3=&]R
M;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W-`IM
M<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B(@H*
M(SH@;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q
M"FUS9VED(")086QA=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED
M(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B4&%N86UA(@IM<V=S='(@
M(L?AQ]/C(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,V"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3@*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C,*;7-G:60@
M(E!A<W-W;W)D(@IM<V=S='(@(M_AX\D@Q^'CT>;1(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D
M('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HQ,S(R"B,L(&9U>GIY"FUS9VED(")087-S=V]R
M9"!I;F-O<G)E8W0B"FUS9W-T<B`BW^'CR2#'X>/1YM$B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,34R"B,L(&9U>GIY"FUS9VED(")0
M87-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R("+AQ\KFS,\@W^'CR2#CT>;1(.'ARLW>WB#1Q\_MYM,N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,PIM<V=I9"`B4&%S<W=O<F0@
M=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.CDP"B,L(&9U>GIY"FUS9VED(")087-S=V]R9#HB
M"FUS9W-T<B`BW^'CR2#'X>/1YM$B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B
M:6QE+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R
M("+?X>/)(,?AX]'FT2(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I
M9"`B4&%S=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A
M<F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N
M=7!S.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*
M(RP@9G5Z>GD*;7-G:60@(E!E;W!L92(*;7-G<W1R("+'X<_FT2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED
M(")097)C96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA
M;F-E($]P97)A=&EO;G,B"FUS9W-T<B`BRN3=[=`@VN/A[<?*(,?AU>W'Y,DB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`V"B,L(&9U>GIY"FUS9VED
M(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM
M<V=S='(@(LKDW>W0(-KCX>W'RB#'X=7MQ^3)(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#8*;7-G
M:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI
M;&0N<&AP.C8P"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C4X"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES
M=')A=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C4*(RP@9G5Z>GD*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S
M='(@(N/:X>;CQ\H@PL[1["(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@
M(E!E=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P
M:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R("+EQ\K=(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W.`IM<V=I9"`B4&AO=&]S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@
M>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O
M('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(U-S$*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO
M;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@96YT
M97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Q"FUS9VED(")0;&5A<V4@
M96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8P"FUS9VED(")0;&5A<V4@96YT97(@
M82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE
M(&UO;G1H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-#4Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS
M9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN
M(@IM<V=S='(@(L?AT<S'P2#*TN;MS^3'(./ASM4@Q^'CU-_AR2XB"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA
M;64@86YD('!A<W-W;W)D(@IM<V=S='(@(L?AT<S'P2#*TN;MS^3'(,C'T^,@
MQ^'CT\K.S^,@YM_AX\D@Q^'3T2XB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@
M=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H
M92`B"B)S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP
M92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.0IM<V=I9"`B4&]L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X-PIM<V=I9"`B4&]L;',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM
M86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A
M8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@
M96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Y.`IM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP:'`Z.3@*;7-G
M:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-E
M<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S
M97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C(U"FUS9VED(")0<F5S<W5R92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U.0IM<V=I9"`B4')E<W-U
M<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C`U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O
M=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C,V,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V-@HC+"!F=7IZ
M>0IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R("+:YL_)(,7A["#'
MX<[MQ]''RB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I
M=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TUE;G4N<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R
M(");RM[1[=$@Q^'CU-_AR5TB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ
M,C8*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`BU-'-(,?A
MX]3?X<DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S8Y"FUS9VED
M(")0<F]J96-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,3$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#@*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X-0IM<V=I9"`B4')O;7!T('1E>'0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y
M($%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8T-`IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C(T,0IM
M<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U
M8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B
M4'5E<G1O(%)I8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B
M46%T87(B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8S"FUS
M9VED(")1=65R>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C8S"B,L('!H<"UF;W)M870*;7-G:60@
M(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0*;7-G:60@(E)A9&EO('-E;&5C=&EO
M;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT,PIM<V=I9"`B4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B!%
M87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS9VED
M(")286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I9"`B4F%I;B!A;F0@4VYO=R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT.`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*
M;7-G:60@(E)A=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"B,L(&9U
M>GIY"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@(M'3Q^')(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A
M;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL
M>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO
M;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@
M>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B
M4F5F<F5S:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,SDQ"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,0IM<V=I9"`B
M4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.#DT(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,3,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-0IM<V=I9"`B4F5G
M97@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(T
M.0IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(P.`IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V"FUS9VED(")296UA<FMS(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,30*;7-G:60@(E)E
M;6]T92!397)V97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE
M>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M<75E=65D+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(@IM<V=S='(@
M(L72X<D@Q^'+Y,?&[2(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(L72
MX<D@Q^'+Y,?&[2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HU-3<*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`HC
M+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`BQ=+A
MR2#'X<ODQ\;M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*
M;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(L72X<D@Q^'+Y,?&[2(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S879E
M9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#(*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!T:&4B
M"FUS9W-T<B`BQ=+AR2#'X<ODQ\;M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@
M=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*(RP@9G5Z>GD*;7-G
M:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(L72X<D@Q^'+Y,?&[2(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(L72X<D@
MQ^'+Y,?&[2(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X
M"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE
M9"!E<G)O<F-O9&4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,34W"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L
M9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,3<T(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$R
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@
M;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+A
MXR#MVLO1(-KA["`G<&]R="<@W>T@Q=K/Q\_'RB!61E,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HV-S4@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R
M,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB
M(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(N'C(.W:R]$@VN'L("=P;W)T)R#=[2#%VL_'S\?*(%9&4RXB"@HC.B!F<F%M
M97=O<FLO571I;"]5=&EL+G!H<#HW.#$*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(N'C(.W:R]$@VN'L("=P;W)T)R#=[2#%VL_'
MS\?*(%9&4RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H
M<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S.0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C`@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@HC+"!F=7IZ>0IM<V=I
M9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`BW^'CR2#'X>/1YM$B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U
M<B!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3,P"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A
M9&UI;B]S<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T
M97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*
M;7-G<W1R("+:YL_)(,7A["#'X<[MQ]''RB(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,@HC+"!F
M=7IZ>0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@
M(MKFS\D@Q>'L(,?ASNW'T<?*(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG
M:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R
M,0IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,3<*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(L?AS^;1(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(U"FUS9VED(")2;W1A=&4@
M,3@P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,C(*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C@*
M;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2
M;W<@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O
M<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU,PHC+"!F=7IZ>0IM<V=I9"`B4G5L97,B"FUS9W-T<B`BQ^'/YM$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S
M(&%N9"!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I
M;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*;7-G:60@
M(E)U;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N
M($9E9&5R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B
M4G=A;F1A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N
M871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q
M"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#0*
M(RP@9G5Z>GD*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`BT=/'X<DB
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@S"FUS
M9VED(")344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S$*;7-G:60@(E-3
M2"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3
M:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`T"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,SD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@W"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E
M;&]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I
M;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A
M;64@9G)A;64@*%]S96QF*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS
M9VED(")386UO82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3
M86X@36%R:6YO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A
M;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A
M8FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8SHY.`IM<V=I9"`B4V%V92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E-A
M=F4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,C$V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E("5S
M(@IM<V=S='(@(LW=V2#'X<[MQ]''RB(*"B,Z('1E;7!L871E<R]P<F5F<R]E
M;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R("+-W=D@Q^'.
M[<?1Q\HB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B
M"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP
M="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L('!H<"UF
M;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")3
M8VEE;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS
M9VED(")396%R8V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,R,`IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW,PIM<V=I9"`B4V5L96-T
M($9I;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT.#0*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&1A
M=&4B"FUS9W-T<B`BQ\[*T2#*Y-/MWB#'X<K'T>W..B(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T
M;R!A9&0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T
M(&$@<V5R=F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C<W"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(V-C,*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A
M;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R("+'SLK1(,KDT^W>(,?ARL?1
M[<XZ(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<X"FUS9VED
M(")396QE8W0@;F]N92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R
M9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C
M=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T
M:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A
M+B(*;7-G<W1R("+-S\\@Q^'-T>;=+\?AT>/FTB#'X<KM(,K1[<_EQR##S^3'
MY2X@YN/D(,OC(.WCW^0@Y-/.Y<?FX=7>Y<<@UN/D(,?AY-4N(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T
M92!D96QI;6ET97(Z(@IM<V=S='(@(L?.RM$@Q^'=YL?5X2#AX<K'T>W..B(*
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@
M=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R("+'SLK1(,KDT^W>(,?ARL?1[<XZ
M(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM
M<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G
M<W1R("+'SLK1(,?AW>;'U>$@X>'*Q]'MSCHB"@HC.B!T96UP;&%T97,O9&%T
M82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB
M"FUS9W-T<B`BQ\[*T2#*Y-/MWB#'X>;>RCHB"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I
M96QD<RXB"FUS9W-T<B`BQ<[*T2#-WN'MY"#CRN/'R^'MY"XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S`V"FUS9VED(")396QE8W0@>6]U<B!C;VQO
M<B!S8VAE;64N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-#@*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB
M"FUS9W-T<B`BQ<[*T2#AV\K?(,?AX]W6X<DZ(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O
M<G0B"FUS9W-T<B`BP]'3X2#*WM'MT<?P(,CCU-_AR2#-U>'*(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,SD*;7-G:60@
M(E-E;F0@4TU3(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E
M;F5G86PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,38*
M;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B
M4V5R:6%L($YU;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,38Q"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP
M:'`Z,C<*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS
M9VED(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z(&QI8B]A
M<&DN<&AP.C$T-0HC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B
MS=W9(,?ASNW'T<?*(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q
M-`IM<V=I9"`B4V5T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW-@IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E
M<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(")3
M970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@
M9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@T"B,L(&9U>GIY"FUS9VED(")3970@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S
M='(@(L?.RM$@RLW/[<L@Q^'5W<W)(.;.[<?1Q\H@Q^'4Q]3)(,?AP\[1["XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*(RP@9G5Z>GD*;7-G:60@
M(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M
M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I
M;VYS+B(*;7-G<W1R("+'SLK1(,K-S^W+(,?AU=W-R2#FSNW'T<?*(,?AU,?4
MR2#'X</.T>PN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0IM<V=I
M9"`B4V5T=7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A
M=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$X-@IM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@
M=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#DV"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PHC+"!F=7IZ
M>0IM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R("+'X>3*[<S)(,?AX\[*
MU=').B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#8*;7-G:60@(E-H
M;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R,R!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E
M96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*
M(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT.3`*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@
M;&]G9VEN9R!I;C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3<V-0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA
M;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$S
M"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3(V"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@
M;65N=2!B87(_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O
M;B!T:&4@;&5F=#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H
M92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@
M4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3
M:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8S"FUS9VED(")3:&]W('5P
M;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU,`IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B
M4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R!,871E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4S"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT.#`*
M;7-G:60@(E-H<FEN:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HW-S0@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z.#,V"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.CDR,B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY.#0*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`T-R!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#@W"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q,38@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z,3$T.0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@
M;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M,C8U"FUS9VED(")3:6=N('5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW
M,3$*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@W(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$U(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(T-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,P"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*;7-G:60@(E-I>F4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT
M;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`BQ>7CX2#'
MX=7MQ^3)(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*
M;7-G:60@(E-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4V"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N;W<@
M4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S($QA
M=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*;7-G
M:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(X,@IM<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED
M(")3;VYG<R`F(%!O96US(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Y,C8*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HQ.#D*(RP@9G5Z>GD*;7-G:60@(E-O=7)C92!A9&1R
M97-S(@IM<V=S='(@(MKDYL?D(,?AVN/A(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I
M9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA
M(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R
M"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED
M(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS
M9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q-0IM
M<V=I9"`B4W!A8V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@(E-P86TB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED
M(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R("+%S\['T2#-T>;=
M(,['U<DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED
M(")3<&QI="!R;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")3<&]R=',B"FUS9W-T<B`BQ]/*[=''
MSR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,R!L:6(O0FQO8VLO
M;65T87(N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R
M("+#S.3/R2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B
M4W1A<B!4<F5K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(U.38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P.0IM<V=I9"`B
M4W1A<G0@>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ
M,3(*;7-G:60@(E-T871U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.#$U"B,L(&9U>GIY"FUS9VED(")3=&]R86=E(&9O<FUA
M="(*;7-G<W1R("+([<?DQ\K?.B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3<R"B,L(&9U>GIY"FUS9VED(")3=')E970@061D<F5S
M<R(*;7-G<W1R("+:Y.;'Y"#'X=KCX2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,PIM
M<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@W,PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE
M(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BX>,@[=K+
MT2#:X>P@Q^'CT\KCVB`E<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*;7-G:60@(E-U8FUI="(*;7-G<W1R
M("(B"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E
M;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H
M87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#0*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R("+*XR#(Y,S'S2(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB
M(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V"B,L('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T
M96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*
M;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!2
M96QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM
M<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C
M:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,38X"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W5D86XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU-@HC+"!F=7IZ>0IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R("+'X<[AQ]7)
M(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G
M:60@(E-U;B!3970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-U;FYY(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(E-U
M;G)I<V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E
M="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C$U"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Q.0IM<V=I9"`B4W5N<V5T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3@*;7-G:60@
M(E-U;G-E=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S@*(RP@9G5Z
M>GD*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`BQ]/*[=''SR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#8*(RP@9G5Z>GD*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(L?AQ]/C
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*(RP@
M9G5Z>GD*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`BQ^''T^,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC(&QO9R!D
M96QE=&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-#(*;7-G:60@(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,
M+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S
M96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B
M4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E0M4W1O<FTB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS
M9VED(")4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;7,@16%R;'DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$V
M-@HC+"!F=7IZ>0IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`BQ^'AWL@B"@HC
M.B!F<F%M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S-`HC+"!F=7IZ>0IM<V=I
M9"`B5&%B;&4B"FUS9W-T<B`BQ^'AWL@B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED(")486)L92!0
M<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO
M5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I
M9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY-0HC+"!F=7IZ>0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R("+-
MS.,@Q^''T\K.S\?C.B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.38@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X-PIM<V=I9"`B5&%S:W,B"FUS
M9W-T<B`BQ^'CY>/'RB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3<S"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP"FUS9VED(")496UP(&9O<B!L
M87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(Q-`IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,PIM<V=I9"`B5&5M<&5R871U<F4Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,CDS"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S
M2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U1E;7!L871E+U1E;7!L871E+G!H<#HV.#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN
M:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-@HC+"!F=7IZ
M>0IM<V=I9"`B5&5X="(*;7-G<W1R("+DU2#=WM@B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S<U"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`BY-4@
MW=[8(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW-`HC+"!F=7IZ>0IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R
M("+DU2#=WM@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED
M(")4:&%I("A425,M-C(P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS
M9VED(")4:&%I;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.#@*(RP@9G5Z>GD*;7-G:60@(E1H86YK('EO=2!F;W(@=7-I
M;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`BRN,@Q^'.T>;,(,CDS,?-+B`\8G(@
M+SX@U-_1Q_`@X<?3RL[/Q^/?XR#ET,<@Q^'DV<?C+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#(P"FUS9VED(")4:&4@1E10(&5X=&5N<VEO
M;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O
M<G0@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])
M35-0+T)O;VLN<&AP.C$R.3(*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N
M;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA
M<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@
M3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C0@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A
M9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!0
M97)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M
M:7-S:6]N<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S
M:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T
M($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W
M87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS
M9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO
M=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,38Y"FUS9VED("(B"B)4:&4@9&5T86-H960@
M4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE
M('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE
M(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE
M9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T
M('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0N<&AP.C$Q,PIM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A
M='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S4@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V."!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M,3D*;7-G:60@(E1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S
M96QF+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR
M.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@
M=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED
M("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P
M<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O
M=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N
M("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA
M8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@
M8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G
M<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0
M<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U
M(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U
M('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T
M960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED
M92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G50
M1R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA
M<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H
M<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N
M="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I
M<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE
M<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W"FUS9VED(")4:&4@
M;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Q
M"B,L(&9U>GIY"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E
M(&YU;65R:6,N(@IM<V=S='(@(NW,R"##Y"#*W^;D(.70Y2#'X=[MX\D@T=[C
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,0IM
M<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@
M2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E
M9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L
M;&]W86)L92!S:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A
M('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S
M='(@(B(*(N'C(.W*XR#'X=K+YM$@VN'L(,?AR-'DQ^/,(,?AX]/*SL_C(.'%
MV>7'T2#'X='3Q\;A(./D(.3FVB`H)7,I(-;CY"#DV<?CWRXB"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-30*;7-G:60@(E1H92!Q=6]T92!C
M:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED
M92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C0T-@IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG
M;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R
M(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z,S,P"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES
M="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ
M-S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@
M9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(L7D(./AW<?*
M(%!/(.'AV\D@)7,@V^W1(./FS.;/R2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,S,3$*;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N
M;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4
M:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@
M<W1E<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N
M<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,3<R"FUS9VED
M(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-38*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$Q-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3$Y"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ-S@*(RP@9G5Z>GD*;7-G:60@(E1H97)E(&%R92!N;R!O
M<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`BX<?*YLS/(,/MR2#*W=;MX<?*
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T,@IM
M<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE
M9"!I;FQI;F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O
M;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT
M97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H
M86X@)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E
M<BYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@
M7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N
M<&AP.C@X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B
M;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.C@X.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B
M;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T
M:&%N('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX
M.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I
M86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C
M="!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM
M8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C@P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O
M=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@
M(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I
M960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN
M(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W
M87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@
M24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q-#4*(RP@9G5Z>GD*;7-G
M:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M
M8F5R+B(*;7-G<W1R("+MS,@@P^0@RM_FY"#ET.4@Q^'>[>/)(-'>XRXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ
M.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC
M:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B
M"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*
M;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I
M;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P
M+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A
M;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R
M97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A
M;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$S.3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T,3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4W(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S
M-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`V"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,X,30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R
M,@IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F
M:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$X"FUS9VED(")4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DT"FUS
M9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S
M"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S
M97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HY.#D*(RP@9G5Z>GD*;7-G:60@(E1H:7,@
M9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B[<S((,/D
M(,K?YN0@Y=#E(,?AWNWCR2#1WN,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@S-@IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@
M82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP
M;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B
M965N('!R;V-E<W-E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VAE;'`O
M86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P
M=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E
M9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L
M86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL
M("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R
M86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@
M(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R("+M
MS,@@P^0@[=_FY"#ET,<@Q^'1WN,@P]_(T2#CY"#'X=7=T2(*"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI
M<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R
M>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A
M8W1I=F%T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB
M97(N(@IM<V=S='(@(NW,R"##Y"#*W^;D(.70Y2#'X=[MX\D@T=[C+B(*"B,Z
M('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H
M:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD
M;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C0*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-`IM<V=I9"`B5&EC:V5T<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(X('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B5&EM
M92(*;7-G<W1R("+'X>'>R"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS.#8*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,Y"FUS9VED(")4
M:6UE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED
M(")4:6UO<BU,97-T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C(P"FUS9VED(")4:71L92(*;7-G<W1R("+'X>'>R"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE
M("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM
M<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@
M=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL
M92!C;&EC:VEN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,Q,0IM<V=I9"`B5&]D87DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B
M5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*
M(RP@9G5Z>GD*;7-G:60@(E1O9V\B"FUS9W-T<B`BSM'FS"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,Q,PIM<V=I9"`B5&]M;W)R;W<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<W"FUS9VED(")4;W`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?
M=&]P*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*
M;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q
M"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W.3`*;7-G:60@(E1R=64@;W(@9F%L
M<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q
M"FUS9VED(")4=7)K97DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.3(*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES
M;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-C0*;7-G
M:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8Y"FUS9VED(")5+E8N(&EN9&5X.B`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B55),
M(@IM<V=S='(@(MKDYL?D(,?AQ>3*T>3MRB(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R
M('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M-PHC+"!F=7IZ>0IM<V=I9"`B55),.B(*;7-G<W1R("+:Y.;'Y"#'X<7DRM'D
M[<HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,3(*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BX<<@
MQ>/?Q^3MR2#AWM''P<D@X\SASR!V9G-R;V]T+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O(&%D9"!E
M>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS.#@*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES
M<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+AQR#%X]_'Y.W)
M(.'*V^WMT2#'X=/CQ\WMQ\H@X>/AW2!61E,@)7,O)7,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@U(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H
M86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B
MX<<@Q>/?Q^3MR2#ARMOM[=$@Q^'3X\?-[<?*(.'CX=T@5D93("5S+R5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4U"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G
M<W1R("+AQR#%X]_'Y.W)(.'AQ<K5Q^$@R./.S^,@4U%,+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,R"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB
M"FUS9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*V^WMT2#'T^,@(./AW2#'X=P@
M5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8X
M."!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S
M7"(N(@IM<V=S='(@(N''(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C("#CX=T@
MQ^'<(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP
M:'`Z-#,U"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R
M+B(*;7-G<W1R("+AQR#%X]_'Y.W)(.'AQ<K5Q^$@R./.S^,@4U%,+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,Y"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`BX<<@Q>/?
MQ^3MR2#AX<7*U<?A(,CCSL_C(%-13"XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR,C4@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,P
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ.38@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@
M=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*
MV^WMT2#'T^,@(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,S8U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G
M<W1R("+AQR#%X]_'Y.W)(.'>T<?!R2#CS.'/('9F<W)O;W0N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S4T(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C(U-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R("+AQR#%X]_'Y.W)(.'>T<?!R2#CS.'/('9F
M<W)O;W0N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R-`HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS
M9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*V^WMT2#'T^,@(./AW2#'X=P@5D93
M("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@V"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&
M4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D[<D@X<K;
M[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C8U"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@
M8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D
M[<D@X<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-S8*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED(")5;F%B;&4@
M=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C(R-"!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C(Y.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G
M<W1R("+AQR#%X]_'Y.W)(.'>T<?!R2#CS.'/('9F<W)O;W0N(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB
M)7-<(CH@)7,N(@IM<V=S='(@(N''(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C
M("#CX=T@Q^'<(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HS,S$@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS.3(*(SH@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,S,T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO
M="!E;7!T>2(*;7-G<W1R("+AQR#%X]_'Y.W)(.'>T<?!R2#CS.'/('9F<W)O
M;W0N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T."!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E
M;'DN(@IM<V=S='(@(N''(,7CW\?D[<D@X=[1Q\')(./,X<\@=F9S<F]O="XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S<@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T-`HC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G
M<W1R("+AQR#%X]_'Y.W)(.'>T<?!R2#CS.'/('9F<W)O;W0N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,3<@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HT,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(N''(,7C
MW\?D[<D@X=[1Q\')(./,X<\@=F9S<F]O="XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C(P-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(N''
M(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E<R\E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,#,@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HR.#@*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,X,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,SDQ"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!F:6QE+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D[<D@X<K;[>W1
M(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HR-#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(N''
M(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E<R\E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0P-@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S
M:79E;'DZ("5S+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3
MXR`@X^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX,#,*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D971E<FUI
M;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(N''(,7CW\?D[<D@X=[1
MQ\')(./,X<\@=F9S<F]O="XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8P,PIM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF
M:6-A=&4@9&5T86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-
M4U`O24U34"YP:'`Z-#4Q(&9R86UE=V]R:R].971?24U34"])35-0+T%U=&@N
M<&AP.C$Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(N''(,7CW\?D
M[<D@X=[1Q\')(./,X<\@=F9S<F]O="XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`Q
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-C8@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W,0HC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(N''(,KFS,\@Q>/?
MQ^3MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E<R\E<RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z,3`R"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C0X(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.3@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*V^WMT2#'T^,@(./AW2#'X=P@5D93
M("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W-R!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S,*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R("+A
MQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#`@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HW,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&]P96X@
M5D93(&9I;&4N(@IM<V=S='(@(N''(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C
M("#CX=T@Q^'<(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C0U"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@
M;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(N''(,7CW\?D[<D@
MX>'%RM7'X2#(X\[/XR!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C@S-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@
M*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`BX<<@RN;,SR#%X]_'Y.W)
M(.'*V^WMT2#'T^,@(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HX-C8*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R
M96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@
M(N''(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E<R\E
M<RXB"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L
M97(O;F]N92YP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96%D
M(&9I;&4Z("(*;7-G<W1R("+AQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3XR`@
MX^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z-C8Y"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D
M:7)E8W1O<GDN(@IM<V=S='(@(N''(,7CW\?D[<D@X=[1Q\')(./,X<\@=F9S
M<F]O="XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q,#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@
M9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.3,*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS
M9W-T<B`BX<<@Q>/?Q^3MR2#AWM''P<D@X\SASR!V9G-R;V]T+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(Y"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S
M+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3XR`@X^'=(,?A
MW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M-C<@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-#,*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3XR`@X^'=
M(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z-C$P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E
M<RXB"FUS9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*V^WMT2#'T^,@(./AW2#'
MX=P@5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M,S(S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,3,*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,C@U"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS,#$*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4N(@IM<V=S='(@(N''(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C("#C
MX=T@Q^'<(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D
M[<D@X<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA
M8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B
MV^W1(-['S]$@VN'L(,K1S./)(./3RN3/(,?AYM'/(.70QR(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,30Y(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,34R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+AQR#*YLS/(,7C
MW\?D[<D@X<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3<Y"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G
M<W1R("+AQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@
M)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@Q(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T,PHC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(N''(,KFS,\@
MQ>/?Q^3MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E<R\E<RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z.#0Q"FUS9VED(")5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B
MRM''S-H@VN0@Q^'*V^WMT<?*(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A
M8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,C(S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,Y,`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M
M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S@*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*(RP@
M9G5Z>GD*;7-G:60@(E5N9FEL960B"FUS9W-T<B`BW=3A(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET960@2VEN
M9V1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@
M4W1A=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E
M9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HW,0IM<V=I9"`B56YI=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0S,`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE
M;G0@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O
M=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y,0HC+"!F=7IZ>0IM<V=I9"`B56YK;F]W
M;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`BSMC#(-WM(,?3XR#'
MX>/3RL[/XR#F+\/F(-_AX\D@Q^'3T2XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN
M:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,CDV"B,L(&9U>GIY"FUS9VED(")5
M;FYA;65D(@IM<V=S='(@(L?AQ]/C(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D
M('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M
M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T
M;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B
M"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T
M:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C
M;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8X-B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR
M-@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,@IM<V=I
M9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B
M"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R
M;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R
M861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ.3D*;7-G:60@(E5P;&]A9"(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@87!P
M;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E5S92!I9B!N86UE+W!A
M<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*(RP@
M9G5Z>GD*;7-G:60@(E5S97(B"FUS9W-T<B`BQ]/C(,?AX]/*SL_C(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW,C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@
M)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B
M57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C(U,0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM
M<V=S='(@(L[MQ]''RB#'X>/3RL[/XR(*"B,Z('-I9VYU<"YP:'`Z-C(*(RP@
M9G5Z>GD*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(L[MQ]''
MRB#'X>/3RL[/XR(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G
M:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-CD*;7-G:60@
M(E5S97(@86-C;W5N="!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY
M.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HQ.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ
M-3`@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHW,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`BQ]/C(,?AX]/*
MSL_C(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C$R-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR96%D>2!E
M>&ES=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHX-PHC+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(L?3
MXR#'X>/3RL[/XR(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*
M(RP@9G5Z>GD*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`BQ]/C(,?AX]/*
MSL_C(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I
M9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-`IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HQ-C,@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C4U"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$X
M"FUS9VED(")686-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HX-C8*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I
M;F-L=61E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV,S@*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4V(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L
M=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#0@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S$V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C@*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L
M=65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M,#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-@IM<V=I9"`B5F%L=65S
M('1O('-E;&5C="!F<F]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G
M:60@(E9A;G5A='4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(T-`IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I
M9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@
M=&%M<&5R960@=VET:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R-@IM<V=I9"`B5F5R
M<VEO;B!#;VYT<F]L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L
M(&%L:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS9VED(")697)Y
M($AI9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FEE="!.
M86TB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G
M:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.38R"B,L('!H<"UF;W)M870*
M;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX
M,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES
M:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L
M86YD<RP@52Y3+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(P.0IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8S"FUS9VED(")6:7-I8FEL:71Y.B`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE
M:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!3
M3510(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!
M3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA($A45%`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&
M=71U;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM<V=S='(@(LKDR.WE(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM
M<V=I9"`B5V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,C<*;7-G:60@(E=E
M871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HX.3(*;7-G:60@(E=E871H97(N8V]M(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S-PIM
M<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT
M96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S
M='(@(L/3R.;:[<?P(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z
M,C@*(RP@9G5Z>GD*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`BP^7AQR#FT^7A
MQR`E<R(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7
M96QC;VUE('1O("5S(@IM<V=S='(@(L/EX<<@R-_C(,7A["`E<R(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*
M;7-G<W1R("+#Y>''(.;3Y>''("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.34*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED(")797-T97)N("A)
M4T\M.#@U.2TQ-2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E
M<W1E<FX@4V%H87)A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E=H870@87!P
M;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S
M='(@(N/'(,?AR-'DQ^/,(,?AX\K1UB#:T=;E(./D(.7FT<_M(,C:SR#'X<_.
MYN&_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@
M(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T
M(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#8Q"FUS9VED(")7
M:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PIM<V=I9"`B5VAI8V@@<&QU
M9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(U"FUS9VED(")7:61T:"!I;B!#4U,@
M=6YI=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O
M;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,3,*
M;7-G:60@(E=I:VDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV-0IM<V=I9"`B5VEN9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B5VEN9"!%87)L
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@P"FUS9VED
M(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,34V"FUS9VED(")7:6YD.B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0R"B,L(&9U>GIY"FUS9VED
M(")7:6YD.B`B"FUS9W-T<B`BRN3([>4Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5VES:&QI<W0B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(MKDYL?D
M(,?AVN/A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R("+EQ\K=(,?AVN/A
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,38Y(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D
M+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z,S`P"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E
M<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3$T"B,L('!H<"UF
M;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@
M5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR-#,*;7-G:60@(E@M4F5F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@0F%S
M:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.3(*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+
M97D@57-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T
M:79E($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N
M=&EF:65R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C@R"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T
M<B`BT^3)("T@U]<B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-34*(RP@9G5Z>GD*;7-G:60@(EE965DB"FUS9W-T<B`BT^3)
M("T@U]<B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3$P.`IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")9
M96%R;'DB"FUS9W-T<B`BT^3F[<?P(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B
M665M96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B665S(@IM<V=S='(@(N3:XR(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS
M9VED(")997,L($D@06=R964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I
M;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B
M86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]E9&ET+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO
M="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,3$*;7-G
M:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")9
M;W4@8V%N(&YO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U
M;&P@;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@U-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"FUS9VED(")9
M;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R
M;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE
M;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.#@*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E(&)E96X@;&]G
M9V5D(&]U="XB"FUS9W-T<B`BRN,@RLW/[<L@Q^'.[<?1Q\HB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V92!T
M;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY
M('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA
M;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!V86QU92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$
M871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0U-@IM<V=I9"`B66]U(&UU
M<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S
M="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H
M92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B[<S((-31S2#'X>/4W^')(-[(
MX2#'T=/'X2#*WM'MT<?P(,CEQRXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T
M:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M
M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U
M<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C<Q"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A
M=&5G;W)Y(&YA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E
M9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S
M92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`BQ^3*Y<H@U>''S>W)(,?AQ\K5Q^$@
M)7,N(,?AT<S'P2#%VL?/R2#'X<_.YN$N(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z,S@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@16UA:6P@
M061D<F5S<R(*;7-G<W1R("+:Y.;'Y"#(T>W/WR#'X<7AW\K1YN3M.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3(*(RP@9G5Z>GD*;7-G:60@(EEO
M=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`BVN3FQ^0@R-'MS]\@Q^'%X=_*
MT>;D[3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(EEO=7(@26YF;W)M871I
M;VXB"FUS9W-T<B`BR.W'Y,?*WSHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE
M="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@
M>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL
M('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PHC+"!F=7IZ>0IM<V=I9"`B66]U
M<B!.86UE(@IM<V=S='(@(L?3X]\Z(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U
M('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O
M=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO
M;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@
M=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H
M97(@<F5A<V]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R
M(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I
M='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO:69R86UE+G!H<#HU,`IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@
M;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B
M<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R
M97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3<*;7-G:60@(EEO=7(@
M8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R
M969S+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT
M:71Y(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@(LKC(,K-S^W+(,?ASNW'
MT<?*(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U.`HC+"!F=7IZ>0IM
M<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R("+'X<K-WMX@
MQ^''W<K1Q];M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,0HC+"!F
M=7IZ>0IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(L?3X]\Z(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z,3`P,`HC+"!F=7IZ>0IM<V=I
M9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`BRN,@RLW/[<L@
MQ^'.[<?1Q\HB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@
M:7,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,34T"B,L(&9U>GIY"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B
M965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN
M(@IM<V=S='(@(LKC(,K-S^W+(,?ASNW'T<?*(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"XB"FUS9W-T<B`BRN,@RLW/[<L@Q^'.[<?1Q\HB"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P
M87-S=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R
M9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN
M('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C<S,@IM<V=I9"`B66]U<B!P87-S=V]R
M9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA
M=FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*
M;7-G:60@(EIA;6)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED
M(")::6UB86)W92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]4
M97AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@
M(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M<F]B;&5M+G!H<#HX.`IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R
M(");RM[1[=$@Q^'CU-_AR5TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q
M=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI
M9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G:60@(EM3
M:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G
M:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R(");Q^'3V-$@)7,@X^0@)7-=
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-30Q('1E;7!L871E
M<R]P;W)T86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*
M;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS
M9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?1&%T851R964B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O=R(*;7-G<W1R
M("(B"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0HC
M+"!F=7IZ>0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`BQ^'CT\?:S\DB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*(RP@9G5Z>GD*
M;7-G:60@(E],;V<@:6XB"FUS9W-T<B`BS\[FX2(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]-96YU+G!H<#HQ.3`*(RP@9G5Z>GD*;7-G:60@(E],;V<@
M;W5T(@IM<V=S='(@(L[1YLPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN
M:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N
M=2YP:'`Z,38T"B,L(&9U>GIY"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R("+.
M[<?1Q\HB"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]097)M:7-S:6]N
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G:60@(E]296UO=F4@
M3&EN:RXN+B(*;7-G<W1R("+%TN')(,?AR^3'QNTB"@HC.B!L:6(O87!I+G!H
M<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@
M(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN
M<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3(Q"B,L(&9U>GIY"FUS9VED(")A9&1R97-S
M(&)O;VLB"FUS9W-T<B`BS]W*T2#:Y,?F[>0B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO
M=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M,3,*(RP@9G5Z>GD*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(L/,Y,_)(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B
M8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T
M(&]P96X@:6YP=70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z-3DR"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(R"FUS
M9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O
M;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E
M;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3@R"B,L(&9U>GIY"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T
M<B`BV^W1(./FS.;/(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-S$*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4U"B,L(&9U>GIY"FUS9VED
M(")F:6QE(@IM<V=S='(@(MW4X2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,3<T(&QI8B]";&]C:R]M971A<BYP:'`Z,S8P(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S@V"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@
M870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(U,`IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Y"FUS9VED(")H
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S4X"FUS9VED(")H:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE
M('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO
M<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B
M:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T
M=V%R92!E<G)O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S
M+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O
M9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V.0IM<V=I9"`B;6TB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR
M.3$@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,C,R"FUS9VED(")N86UE(@IM<V=S='(@
M(L?AQ]/C(@H*(SH@9G)A;65W;W)K+U)00R]24$,N<&AP.C$R,0IM<V=I9"`B
M;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,3(Q.0IM<V=I9"`B;F]T('EE="!I;7!L96UE
M;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDP-0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P
M97)C96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E
M<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B<FES
M:6YG(@IM<V=S='(@(LKDR.WE(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HY.0IM<V=I9"`B
M<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M
M86EL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HS.#4*;7-G:60@(G-S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS
M9VED(")S=&5A9'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HS,#D*;7-G:60@(G-W:71C:"!O9F8@:F%V87-C<FEP="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U
M,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3(Y"FUS9VED(")T87-K(&QI<W0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C8*
M;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,S`U"B,L(&9U>GIY"FUS9VED(")T<GD@
M86=A:6XB"FUS9W-T<B`BW^$@S\[FX2(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(G1Y
M<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(G5N:69I960B"FUS9W-T<B`BW=3A(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR-PHC+"!F=7IZ>0IM
M<V=I9"`B=6YN86UE9"(*;7-G<W1R("+'X<?3XR(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B
M=7-E<B!S96QE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V
M0V%R9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-#$*;7-G:60@(G<Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*;7-G<W1R("(B
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]B9U]"1RYP;P``````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-C0S-S$Q`#$P
M-3$U-#,S-S4T`#`Q-S8Q,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````C($)U;&=A<FEA;B!T<F%N<VQA=&EO;G,@9F]R($AO
M<F1E('!A8VMA9V4N"B,@0V]P>7)I9VAT("A#*2`R,#`R($AO<F1E(%!R;VIE
M8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@
M;&EC96YS92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*(R!-:7)O<VQA=B!096YD
M978@/&UI<F]`8WEB97)S:&%D92YU<SXL(#(P,#(N"B,*;7-G:60@(B(*;7-G
M<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,"UC=G-<;B(*
M(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB
M"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB
M"B)03RU2979I<VEO;BU$871E.B`R,#`R+3$Q+3$Y(#(P.C0T+3`U,#!<;B(*
M(DQA<W0M5')A;G-L871O<CH@36ER;W-L878@4&5N9&5V(#QM:7)O0&-Y8F5R
M<VAA9&4N=7,^7&XB"B),86YG=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E
M+F]R9UQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@
M=&5X="]P;&%I;CL@8VAA<G-E=#U#4#$R-3%<;B(*(D-O;G1E;G0M5')A;G-F
M97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB
M"FUS9W-T<B`B("@E<R#D[>@@[>#GX.0I(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ,S<P"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S
M:V5Y("5S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S<W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A
M>7,I(@IM<V=S='(@(B`H)7,@Y.WH(.W@Y^#D*2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S-S,*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B`H
MY.WE\2DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<U"FUS9VED
M("(@*'1O;6]R<F]W*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S<Q"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B("CB
M]^7PX"DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4V(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C$*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C0P-PIM<V=I9"`B(&%T("(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-C4Y
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`T,@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF
M:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B)R5S)R#M
MY2#E(.KN[?3HX_/PZ/#@[2#B($AO<F1E(%)E9VES=')Y+B(*"B,Z(&9R86UE
M=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM
M<V=S='(@(B<E<R?AY?CE(.3NX>#BY>W@(.KZ["#C\//OZ/+E+B(*"B,Z(&%D
M;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@
M<WES=&5M+B(*;7-G<W1R("(G)7,G(.'E^.4@Y.[AX.+E[2#J^NP@\>CQ\N7L
MX/+@(.?@(._PX.+@(.W@(._N\O#EX>CRY>OH\N4N(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z
M("5S+B(*;7-G<W1R("(G)7,G[>4@X>7XY2#Q^N?DX.3E[3H@)7,N(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@
M(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U
M;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M
M($YO=&EC92(*;7-G<W1R("(E<R`M(,?@X>7KY>;JX"(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`T"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@S,R!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HX,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@
M+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@SN'QZ_/FXN#YZ"#N[^7PX/;H
MZ"`M(,_N\N+Z\.;DY>WHY2(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!3971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z,C8S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I
M9VX@57`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N
M="(*;7-G<W1R("(E<R#3\>ONXNC_(._N(-'O[O#@Y_/LY>WHY?+N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,C@@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HT.3`*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV
M-3$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,34Y(&QI8B]";&]C:R]M971A<BYP:'`Z,38U
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C,Y"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S0U(&QI8B]";&]C:R]M971A<BYP:'`Z,S4Q"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A
M;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T
M:6UE+B(*;7-G<W1R("+(Y^'E\.7RY2#N[^7PX/;HZ/+E+"#J[NGR[B#H\>K@
M\N4@Y.`@Z.?B^O#XZ/+E(/'EX^`N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E
M9"(*;7-G<W1R("(E<R#MY>[A]>[DZ.PB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(X-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E
M<R(*;7-G<W1R("+"\>7JZ"`U(.SH[?/RZ"(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B[>4@X>7XY2#MX.SE
M\.7M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T
M<B`B6^OH[>C_("5S(.[R("5S72(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D
M9')E<W,@0F]O:R(*;7-G<W1R("+`Y/#E\>7M(.'EZ^7F[>CJ(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,30*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`BRN#KY>WDX/`B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B5S("T@Q^#A
MY>OEYNK@(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]M;V)I;&4N<&AP.CDV"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E
M<SH@)7,B"FUS9W-T<B`B)7/MX.SE\.7M.B5S("5S(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H
M;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N
M>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H
M(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V-2!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-#$P"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@X(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P,0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR.30@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3(X
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HW-#D*
M;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=&EM92YP:'`Z,C`*(RP@9G5Z>GD*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM
M<V=S='(@(LCM].[P[.#VZ/\@Y^`@PN#Q(@H*(SH@;&EB+T)L;V-K+W1I;64N
M<&AP.C$Y"B,L(&9U>GIY"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R
M("+([?3N\.S@]NC_(.?@(,+@\2(*"B,Z('1E;7!L871E<R]D871A+W1I;64N
M:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"#WX/'@(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED
M(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO
M8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,38P"B,L(&9U>GIY"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E
M9"(*;7-G<W1R("(\8C[-Y>_PY>[D[NOH[.`@X_#E^.K@.CPO8CXB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B
M;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N
M(@IM<V=S='(@(L?@(.3@(.KPZ._RZ/#@\N4@[^CQ[.X@Y2#MY>[A]>[DZ.P@
M[_/AZ^CWY>T@4$=0(.KK_O<N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3$V-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U
M:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`BQ^`@
MY.`@[_#NXN7PZ/+E(._NY._H\>#M[B#OZ/'L[B#E(.WE[N'U[N3H["!01U`@
MZNO^]RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#DW
M"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB
M;65S<V%G92XB"FUS9W-T<B`B(@HBQ^`@Y.`@Y.7J\.CO\NCPX/+E(._H\>SN
M(/'@(.WE[N'U[N3H[.@Z(._SX>OH]^7M(.KK_O<L(.OH]^7M(.KK_O<@Z"#J
MZ_[W[N+@("(*(O3PX.?@+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$P,34*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A
M=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I
M9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B+'X"#DX"#O[N3OZ/CE\N4@
M[^CQ[.X@\>`@[>7NX?7NY.CLZ#H@[_/AZ^CWY>T@ZNO^]RP@Z^CWY>T@ZNO^
M]R#H(.KK_O?NXN`@(@HB]/#@Y^`N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU,#4*(RP@9G5Z>GD*;7-G:60@(B(*(D$@<'5B;&EC
M(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G
M<W1R("(B"B+'X"#DX"#DY>KPZ._RZ/#@\N4@[^CQ[.X@\>`@[>7NX?7NY.CL
MZ#H@[_/AZ^CWY>T@4TU)344@ZNO^]RP@Z^CWY>T@4TU)344@(@HBZNO^]R#H
M(.KK_O?NXN`@]/#@Y^`N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HT,S$*(RP@9G5Z>GD*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-
M12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"B+'
MX"#DX"#O[N3OZ/CE\N4@[^CQ[.X@\>`@[>7NX?7NY.CLZ#H@[_/AZ^CWY>T@
M4TU)344@ZNO^]RP@Z^CWY>T@4TU)344@ZNO^]R#H("(*(NKK_O?NXN`@]/#@
MY^`N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS-C0*
M;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R
M>7!T(&$@;65S<V%G92XB"FUS9W-T<B`BQ^`@Y.`@ZO#H[_+H\.#RY2#OZ/'L
M[B#E(.WE[N'U[N3H["#O\^'KZ/?E[2!334E-12#JZ_[W+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L
M;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM
M<V=I9"`B04T@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R
M(")!32]032(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@
M(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE
M;'`O:6YD97@N<&AP.C4R"FUS9VED(")!8F]U="XN+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS
M9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-S`*
M;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$S
M-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*(RP@9G5Z>GD*
M;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`BR.WT[O#LX/;H
M_R#GX"#"X/$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4*(RP@9G5Z
M>GD*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`BS^[RXOKPY.7R
MY2#OX/#NZ^#RX"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S,*(RP@9G5Z
M>GD*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`BS.[_\N`@S^[YX"(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X('1E;7!L871E<R]P
M;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D
M9&-H:6QD+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B061D(@IM<V=S='(@(L3N
MX>#BZN@B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N
M<&AP.C(R-0HC+"!F=7IZ>0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S
M='(@(L3NX>#B_^WE(.W@(.WNXN`@X_#S[^`B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM
M<V=S='(@(L3NX>#B_^WE(.W@(.WNXN@@[_#@XN`B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+V%D9"YI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B061D($AE<F4Z(@IM
M<V=S='(@(L#D\.7Q(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO
M9W)O=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B
MQ.[AX.+_[>4@[>`@[>[BX"#C\//OX"(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX
M.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(L3NX>#B_^WE
M(.W@(.WNXN@@[_#@XN`B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D
M9&-H:6QD+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@
M82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`BQ.[AX.+H(.W@\>OE
MY.7MX"#C\//OX"#J^NP@)R5S)R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,30W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@
M82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R("+$[N'@XN@@
M[>#QZ^7DY>WH(._PX.+@(.KZ["`G)7,G(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R("+$[N'@XN@@[>[B
M(._N\O#EX>CRY>LZ(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4U-`IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"B,L(&9U>GIY
M"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`BQ.[AX.+H(.WNXB#W
MZ^7M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0HC+"!F=7IZ
M>0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`BQ.[AX.+H(/#EY_[LY2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HW,0HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS
M9W-T<B`BQ.[AX.+H(.KZ["#L[O_RX"#@Y/#E\>W@(.KMZ./@.B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`HC+"!F=7IZ
M>0IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R("+$[N'@
MXN@@ZOKL(.SN__+@(.#D\.7Q[>`@ZNWHX^`Z(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(L3NX>#B
MZ"#M[N(@[^[R\.7AZ/+EZSHB"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E
M;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M
M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0U"B,L
M('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M
M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@
M:7,@9&ES86)L960N(@IM<V=S='(@(L3NX>#B_^WE\NX@[>`@[^[R\.7AZ/+E
MZ^@@Y2#GX.'PX.WE[>XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#$*
M;7-G:60@(D%D9')E<W,B"FUS9W-T<B`BP.3PY?$B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3,Y"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T
M<B`BP.3PY?'E[2#AY>OEYNWHZB(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")!9&UI;FES=&5R
M("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R("+0
MY>3@ZO;H_R#MX"#O\.#BX/+@(.?@("<E<R<B"@HC.B!A9&UI;B]I;F1E>"YP
M:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B
M061M:6YI<W1R871I;VXB"FUS9W-T<B`BP.3LZ.WH\?+PZ/#@[>4B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Q"FUS9VED(")!9',B"FUS9W-T
M<B`BQ.[AX.+JZ"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(D%L8F%N:6$B
M"FUS9W-T<B`BS_'EXN3N[>CL(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`HC+"!F=7IZ>0IM<V=I
M9"`B06QG97)I82(*;7-G<W1R("+/\>7BY.[MZ.PB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*
M;7-G<W1R("+/\>7BY.[MZ.PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C$V"B,L(&9U>GIY"FUS9VED(")!;&EG
M;B(*;7-G<W1R("+/\>7BY.[MZ.PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!
M=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U
M<',B"FUS9W-T<B`BPO'H]^KH(./P\^_H(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R
M964N<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`BPO'H
M]^KH(._PX.+@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,0IM<V=I9"`B
M06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,S0*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@
M;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$
M871A5')E92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E
M>&ES=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M,PIM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-PIM<V=I9"`B06QT97)N871E($E-
M4U`@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0Y.0IM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*(RP@9G5Z
M>GD*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(L+@
M^.C_($5M86EL(.#D\.7Q.B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R
M"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S
M('-P96-I9FEE9"XB"FUS9W-T<B`BPOKBY>3E[>#RX"#Q\N[I[>[Q\B#MY2#E
M(.3N[_/Q\NCLX"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,38W"B,L(&9U>GIY"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U
M<F5D+B(*;7-G<W1R("+MY>_PY>[D[NOH[.`@X_#E^.K@.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-34*;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I
M9"`B06YG;VQA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I
M;&QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H
M<'-H96QL+G!H<#HS-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP
M.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*(RP@9G5Z
M>GD*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(L+@ZN#M]NC_(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"B,L(&9U>GIY"FUS9VED(")!<'!L
M:6-A=&EO;B!,:7-T(@IM<V=S='(@(LW@[.7PY>WH(._PZ.ONYN7MZ/\Z("5S
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC
M871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S"FUS9VED(")!<'!R;WAI;6%T
M92!3:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I9"`B07)A8FEC("A7:6YD;W=S
M+3$R-38I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HV-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@Q"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R("+0X.?LY?`@
M[>`@X/#UZ.+MZ/\@].#IZR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HV-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@P"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T<B`BR.SE(.W@(.#P]>CB
MX"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z
M,3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_
M(@IM<V=S='(@(M'HX_/P[>@@Z^@@\?+E+"#WY2#H\>K@\N4@Y.`@Z.?R\.CE
M\N4@)R5S)R#H(.+QZ/?JZ"#O[N3O\.#BX#\B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@
M86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R("+1Z./S\.WH(.OH(/'RY2P@
M]^4@Z/'JX/+E(.3@(.CG\O#HY?+E("<E<R<@Z"#B\>CWZN@@[^[DX_#S[^@_
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I
M9"`B07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R=6)A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G
M:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA
M+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT,C4*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R
M92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R("+$X"#Q
MY2#H\>K@(.OH(._N\N+Z\.;DY>WHY2#O\.7DZ"#NX?'K\^;BX/GH\N4@[N_E
M\.#VZ.@_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q,PIM<V=I
M9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X
M:7-T96YT(&=R;W5P+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CG\O#HXN#MY2#M
MX"#MY?'Z^>7Q\N+SXN#YX"#C\//OX"XB"@HC.B!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES
M=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CG\O#HXN#M
MY2#MY2#MY?'Z^>7Q\N+SXN#YZ"#O\.#BX"XB"@HC.B!A9&UI;B]P97)M<R]E
M9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(L/PY?CJX"#O\.@@\.7DX.KRZ/#@
M[>4@[>`@[>7Q^OGE\?+B\^+@^>@@[_#@XN`N(@H*(SH@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C4S"B,L(&9U>GIY"FUS9VED(")!='1E;7!T('1O(&5D
M:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(L/PY?CJX"#O\.@@
M\.7DX.KRZ/#@[>4@[>`@[>7Q^OGE\?+B\^+@^>@@[_#@XN`N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#8*;7-G:60@(D%T=')I8G5T97,B"FUS
M9W-T<B`BP/+PZ.'S\N@B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW,@HC+"!F=7IZ>0IM<V=I9"`B075G=7-T(@IM<V=S='(@
M(L'ZX^[BY2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U
M=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP
M.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E
M(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z
M(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C,V"FUS9VED("(B
M"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z
M-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D
M:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O
M<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T
M('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H
M7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D
M('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO
M=F4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z
M(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P
M.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@
M1&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E
M<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B
MP_#E^.K@(._PZ"#HY.7M\NCTZ.K@]NC_(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS
M9W-T<B`BP_#E^.K@(._PZ"#HY.7M\NCTZ.K@]NC_(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC871I
M;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`BR.3E[?+H
M].CJX/;H__+@(.'E^.4@[O+UXOKPZ^7MX"#N\B!2041)55,@\?KPXOKPX"XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U,0HC+"!F=7IZ>0IM
M<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM
M<V=S='(@(L/PY?CJX"#O\.@@Z.3E[?+H].CJX/;H_R(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(D%U=&AE;G1I
M8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`BPO#Z
MY^K@\N`@\?KQ($944"#Q^O#B^O#@(/'E(._P[N+@Z^@N(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD
M<SHB"FUS9W-T<B`BS>#KZ/?MZ"#O[NOE\N`Z(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I
M9"`B07IE<F)A:6IA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X
M"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U
M;F0@0V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K
M<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G
M<W1R("+-Y>+@Z^CD[>`@:V5R8F5R;W,@(._@\.[KX"XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@
M=7-E<FYA;64N(@IM<V=S='(@(LWEXN#KZ.3M[B!K97)B97)O<R#O[O+PY>'H
M\N7K\>KN(.CLY2XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(D)A:')A:6XB"FUS
M9W-T<B`B0F%R8FEE(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G
M:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C`*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM
M<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S
M97(N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@
M9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM
M<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B
M0F5L87)U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(D)E;&EZ
M92(*;7-G<W1R("+0X.?LY?`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"96YI;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED
M(")":7)T:&1A>2(*;7-G<W1R("+0[N;DY>T@Y.7M(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U,PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB
M)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(M'K\_C@\N7K__(@)7,@[>4@Y2#M
MX.SE\.7M+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHX.0IM
M<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R("+3Y.7AY>OE[>@B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR,#4*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R("+.
M\NSE\NKH(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR,`HC+"!F=7IZ>0IM<V=I9"`B0F]R9&5R(@IM<V=S='(@
M(DAO<F1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR,0HC+"!F=7IZ>0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")(;W)D92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")"
M;W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(D)O
M='-W86YA(@IM<V=S='(@(D)R;W=N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T;VTB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")"<F%Z:6PB"FUS
M9W-T<B`BS^[YX"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H($EN9&EA
M;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I
M9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM
M<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0HC+"!F=7IZ>0IM<V=I9"`B0G5L
M;&5T960@3&ES="(*;7-G<W1R("+/[N3PY>3E[2#Q[^CQ^NHB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#0T"FUS9VED(")#35,B"FUS9W-T<B`B0TU3(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B
M0U)#(@IM<V=S='(@(D-20R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V
M,PIM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0X-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ-34*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(LK@
MZ^7MY.#P(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-@HC
M+"!F=7IZ>0IM<V=I9"`B0V%L;2(*;7-G<W1R("+.\NK@YN@B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM
M<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@
M875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,Q.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E
M<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I
M9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R
M.B`E<R(*;7-G<W1R("+#\.7XZN`@[_#H(/'B^O#GXN#MY2#Q(.SEZ>L@\?KP
MXOKP.B`E<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0Q,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8T"B,L(&9U>GIY"FUS9VED(")#86YA9&$B
M"FUS9W-T<B`BRN#KY>WDX/`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M
M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T
M92YI;F,Z,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A
M;F-E;"(*;7-G<W1R("+.\NK@YN@B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$X"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+V-O<'DN<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I
M=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,30*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB
M"FUS9W-T<B`BP_#E^.K@(._PZ"#O\.7LX/7BX.WE.R`H)7,I(.+E]^4@\?KY
MY?'RXO/BX"(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92YP:'`Z
M,3(X(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8X,`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@
M8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(L/PY?CJX"#O\.@@[_#E[.#UXN#M
MY3L@*"5S*2#BY??E(/'Z^>7Q\N+SXN`B"@HC.B!F<F%M97=O<FLO1&%T851R
M964O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R96]R
M9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D
M;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N
M=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R
M9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR-`HC+"!F=7IZ>0IM<V=I9"`B0V%P=&EO;B(*
M;7-G<W1R("+.[_;HZ"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE
M<FEC7W-M='`N<&AP.C$P-`HC+"!F=7IZ>0IM<V=I9"`B0V%R<FEE<B(*;7-G
M<W1R(")"87)B:64B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`*;7-G
M:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B
M0V5L;"!0:&]N92(*;7-G<W1R("+,[N'HZ^7M(/+EZ^7T[NTB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"B,L
M(&9U>GIY"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`BS.[AZ.OE
M[2#RY>OE].[M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED
M(")#96QL('-P86-I;F<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R-S0*(RP@9G5Z>GD*;7-G:60@(D-E;&QP:&]N92(*;7-G
M<W1R("+,[N'HZ^7M(/+EZ^7T[NTB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W.`IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR-@HC+"!F=7IZ>0IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(M;E[?+PZ/#@
M[2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI
M8R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I
M9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.3D*;7-G:60@
M(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3$*;7-G:60@(D-E<G1I9FEC871E
M($]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DV"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*(RP@9G5Z>GD*;7-G:60@(D-H860B"FUS
M9W-T<B`B=D-A<F0B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,L(&9U>GIY"FUS
M9VED(")#:&%N9V4B"FUS9W-T<B`B3W)A;F=E(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")#:&%N9V4@66]U
M<B!087-S=V]R9"(*;7-G<W1R("+/[O+B^O#DY?+E(._@\.[KX/+@(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE
M(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R
M96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#
M:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T
M:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*(RP@9G5Z>GD*;7-G:60@
M(D-H87(B"FUS9W-T<B`B=D-A<F0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,
M:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@
M(D-H:6QE(@IM<V=S='(@(O3@Z>LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EN
M82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I
M9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#:&EN97-E(%1R861I
M=&EO;F%L("A":6<U*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z,C8Y"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@82!P
M87-S=V]R9"(*;7-G<W1R("+/[O+B^O#DY?+E(._@\.[KX/+@(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.`IM<V=I9"`B0VAO;W-E
M(&$@=7-E<FYA;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(Y.`IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T
M>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z.#DS"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I
M;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`BT>OS^.#RY>O_\B`E
M<R#MY2#E(.W@[.7PY>TN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,30*(RP@9G5Z>GD*;7-G:60@(D-L96%R(@IM<V=S='(@
M(LK@Z^7MY.#P(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS9VED(")#;&5A<B!1
M=65R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A
M<BYI;F,Z-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T
M('5S97(Z("5S(@IM<V=S='(@(L_PY>S@]>WH(._N\O#EX>CRY>LZ("5S(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED(")#
M;&5A<B!U<V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C,T"B,L(&9U>GIY"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B
M"FUS9W-T<B`BR.?AY?#H(._N\O#EX>CRY>L@Y^`@Y.[AX.+_[>4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B
M0VQE87)I;F<@3&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N
M=&EN=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(
M5%10(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@HC+"!F=7IZ>0IM<V=I9"`B
M0VQO<V4@5VEN9&]W(@IM<V=S='(@(L?@\N+N\.@@[_#NY^[PY?8@7"+/[NSN
M^5PB(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#0*;7-G:60@(D-L;W5D
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W"B,L(&9U
M>GIY"FUS9VED(")#;&]U9'DB"FUS9W-T<B`BRN[OZ/#@Z2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O
M;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P
M<V5D(&)O<F1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L
M;VUB:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L
M:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H
M<#HS,C0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP
M.C,R-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3`P('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@
M(D-O;&]R(%!I8VME<B(*;7-G<W1R("+(Y^'H\.#MY2#MX"#VXO_R(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@T-@IM<V=I9"`B0V]L;W5R('-E
M;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-@IM<V=I9"`B0V]L=6UN
M('1I=&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C8T"FUS9VED(")#;VUI8W,B"FUS9W-T<B`BRN[LZ.KQZ"(*"B,Z(&%D
M;6EN+V-M9'-H96QL+G!H<#HR-0HC+"!F=7IZ>0IM<V=I9"`B0V]M;6%N9"(*
M;7-G<W1R("+*[NS@[>3H.B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`HC
M+"!F=7IZ>0IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R("+*[NS@[>3H
M.B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PHC+"!F
M=7IZ>0IM<V=I9"`B0V]M;65N="(*;7-G<W1R("+*[NS@[>3H.B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38V"FUS9VED(")#;VUM
M;VX@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`HC+"!F=7IZ>0IM<V=I
M9"`B0V]M;W)O<R(*;7-G<W1R("+*[NSHZO'H(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*
M;7-G<W1R("+*[NSOX.WH_R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.3<*(RP@9G5Z>GD*;7-G:60@(D-O;F1I=&EO
M;B(*;7-G<W1R("+*[NWTZ./S\.#VZ/\B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(T.0HC+"!F=7IZ>0IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R("+*
M[NWTZ./S\.#VZ/\B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY-@HC+"!F
M=7IZ>0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R
M("+*[NWTZ./S\.#VZ/\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30S
M"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@
M4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ,S4*(RP@9G5Z>GD*;7-G:60@(D-O;F9I9W5R
M871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(LKN[?3HX_/PX/;H_R(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R("+*[NWTZ./S\.#V
MZ/\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS
M9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(L_N\N+Z\.3E\N4@[^#P
M[NO@\N`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L
M:6,@;V8@=&AE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(D-O;FYE8W1I;VX@
M9F%I;&5D+B(*;7-G<W1R("+"\/KGZN#RX"#Q^O$@1E10(/'Z\.+Z\.`@\>4@
M[_#NXN#KZ"XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM
M<V=S='(@(L+P^N?JX/+@(/'Z\2!&5%`@\?KPXOKPX"#QY2#O\.[BX.OH+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B
M0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*
M;7-G<W1R("+$[O'R^N_@(.3N(._SX>OH]^WH_R#Q^O#B^O`@X>7XY2#N\NK@
MY^#M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D
M('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS
M9W-T<B`BQ.[Q\OKOX"#D[B#O\^'KZ/?MZ/\@\?KPXOKP(.'E^.4@[O+JX.?@
M[2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T-0HC+"!F=7IZ
M>0IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS
M9W-T<B`BPO#ZY^K@\N`@\?KQ($944"#Q^O#B^O#@(/'E(._P[N+@Z^@N(@H*
M(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,30*;7-G:60@(D-O;G1A8W1S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HU,PHC+"!F=7IZ>0IM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C
M97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@
M(B(*(M+EY^@@Y.#M[>@@Y^`@ZN[M\N#J\B#A__7@(//Q[^7X[>X@Y.[AX.+E
M[>@@ZOKL(,+@^.#RX"#O\.[C\.#LX"X@RNOHZNWE\N4@[^XM(@HBY.[K\R#G
MX"#DX"#BZ.3H\N4Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HU-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C8S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<
M(B(*;7-G<W1R("+1^N3Z\.;@[>CE(.W@("<E<R<B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*
M;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`BRN[OZ/#@Z2(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-#8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`BR.SO[O#RZ/#@[>X@[^[K
MY3H@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B0V]S
M="!)1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;W-T82!2:6-A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M.3<V"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92XB"FUS
M9W-T<B`BP_#E^.K@(._PZ"!01U`@ZO#H[_+H\.#MY?+N(.W@(._H\>SN+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-3,*;7-G:60@
M(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+B(*;7-G<W1R("+#\.7XZN`@
M[_#H(%!'4"#O[N3OZ/'BX.WE\NX@[>`@[^CQ[.XN(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*(RP@9G5Z>GD*;7-G:60@(D-O
M=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("+#\.7X
MZN`@[_#H(%--24U%(.KPZ._RZ/#@[>7R[B#MX"#OZ/'L[BXB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PHC+"!F=7IZ>0IM<V=I
M9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(L/P
MY?CJX"#O\.@@4TU)344@[^[D[^CQXN#MY?+N(.W@(._H\>SN+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A
M8W0N("5S(@IM<V=S='(@(LWEXOKG[.[F[>[Q\B#DX"#QY2#J[N_H\.`@)7,@
M\NX@)7,N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.CDV
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"B,L(&9U>GIY"FUS
M9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B
MS>7B^N?L[N;M[O'R(.3@(/'E(.[Q^OGE\?+BZ"#B\/KGZN`@\2!,1$%0(/'Z
M\.+Z\"XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#4W"B,L(&9U>GIY
M"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<B(*;7-G<W1R
M("+#\.7XZN`@[_#H(._NZ_/WX.+@[>7R[B#MX"#O\^'KZ/?MZ/\@ZNO^]R#N
M\B#JZ_[W+?'Z\.+Z\.`N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B
MS>7B^N?L[N;M[O'R(.3@(/'E(.KN[^CPX"`E<R#R[B`E<RXB"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-#0Q"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N
M;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<B(*;7-G<W1R("+#\.7XZN`@[_#H
M(/'B^O#GXN#MY2#Q^O$@4TU"(/'Z\.+Z\"XB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*
M;7-G<W1R("+#\.7XZN`@[_#H(/'B^O#GXN#MY2#Q(%)00R#Q^O#B^O`Z("5S
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HS,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C
M<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(L/PY?CJX"#O
M\.@@\?KGY.#BX.WE(.W@(.ONZN#K[>`@Y.CPY>KR[O#H_R#GX"#K[NK@Z^CG
MX/;H_R`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q
M,C4*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+B(*;7-G<W1R
M("+#\.7XZN`@[_#H(.3EZO#H[_+H\.#MY?+N(.W@(%!'4"#DX.WMZ"XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,@HC+"!F=7IZ
M>0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S
M='(@(L/PY?CJX"#O\.@@Y.7J\.CO\NCPX.WE\NX@[>`@4TU)344@Y.#M[>@N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HR-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D
M96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`BS>7B^N?L[N;M[O'R(.3@(/'E
M(.KN[^CPX"`E<R#R[B`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R
M:7!T(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HS.#$@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE
M;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`BS>7J[O#EZO+E[2!E;6%I
M;"#@Y/#E\2#MX"#O[NOS]^#RY>O_+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"B,L(&9U>GIY"FUS9VED(")#
M;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R
M("+-Y>KN\.7J\N7M(&5M86EL(.#D\.7Q(.W@(._NZ_/WX/+EZ_\N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*
M;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@
M;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T
M:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T
M96=Y(%PB)7-<(BXB"FUS9W-T<B`BS>7B^N?L[N;M[O'R(.3@(/'E(.KN[^CP
MX"`E<R#R[B`E<RXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E
M9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@
M<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(L/PY?CJ
MX"#O\.@@[^[K\_?@XN#MY?+N(.W@(._SX>OH]^WH_R#JZ_[W(.[R(.KK_O<M
M\?KPXOKPX"XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R
M:71I;F<N(@IM<V=S='(@(LWEXOKG[.[F[>[Q\B#DX"#QY2#J[N_H\.`@)7,@
M\NX@)7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,C8R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`BS>7B^N?L[N;M[O'R(.3@(/'E(.KN
M[^CPX"`E<R#R[B`E<RXB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I
M;G1E;F%N8V4N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R("+-
MY>+ZY^SNYNWN\?(@Y.`@\>4@[O+B[O#H(,[A\>OSYN+@^>A?Y^#DX/?H(.SN
MY//K("5S("(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<
M(BXB"FUS9W-T<B`BS>7B^N?L[N;M[O'R(.3@(/'E(.KN[^CPX"`E<R#R[B`E
M<RXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HU,38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV.3D*(RP@9G5Z>GD*;7-G:60@(D-O
M=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(LWEXOKG
M[.[F[>[Q\B#DX"#QY2#N\?KYY?'RXN@@XO#ZY^K@(/$@3$1!4"#Q^O#B^O`N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR,S@*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G
M<W1R("+-Y>+ZY^SNYNWN\?(@Y.`@\>4@ZN[OZ/#@("5S(/+N("5S+B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L
M9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S
M97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R
M<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.0IM<V=I9"`B0V]U;&0@
M;F]T(')E=')I979E($%#3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O
M:RX@)7,B"FUS9W-T<B`BS>7J[O#EZO+E[2!E;6%I;"#@Y/#E\2#MX"#O[NOS
M]^#RY>O_+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R
M971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R
M:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@
M;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")(;W)D92#MY2#E
M(.KN[?3HX_/PZ/#@[2#J[O#EZO+M[B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BS>7NX?7NY.CLZ/\@)W!O<G0G(.WE
M(.4@Y^#DX.3E[2#B^N(@5D93(.KN[?3HX_/PX/;H__+@+B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU
M.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N
M9FEG=6%T:6]N.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V
M92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO
M;B!F:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S879E
M('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S
M92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K
M(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,30S"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0
M('-E<G9E<BXB"FUS9W-T<B`BS>7B^N?L[N;M[O'R(.3@(/'E(.[Q^OGE\?+B
MZ"#B\/KGZN`@\2!,1$%0(/'Z\.+Z\"XB"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI
M;FL@7"(E<UPB+B(*;7-G<W1R("+#\.7XZN`@[_#H(%!'4"#O[N3OZ/'BX.WE
M\NX@[>`@[^CQ[.XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HR,3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`BS>7B^N?L
M[N;M[O'R(.3@(/'E(.KN[^CPX"`E<R#R[B`E<RXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C
M;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(L/PY?CJX"#O
M\.@@\?KGY.#BX.WE(.W@(.ONZN#K[>`@Y.CPY>KR[O#H_R#GX"#K[NK@Z^CG
MX/;H_R`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C8*;7-G:60@
M(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E
M('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL
M;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q.0IM<V=I9"`B
M0V]U;G1E9"!T97AT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-38Y"B,L(&9U>GIY"FUS9VED(")#;W5N=')Y(@IM
M<V=S='(@(NCG\.7FZ"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-S,*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED
M(")#<F5A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L
M:6YK(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E
M;&5C="YI;F,Z.30*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B
M"FUS9W-T<B`BR.?AY?#E\N4@[>[B(._PZ/+EYN#RY>L@[>`@X_#S[^`B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I
M9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,C0P"B,L(&9U>GIY"FUS9VED(")#<F5A
M=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(L_PX.+@(._N(._NY/#@Y^'H\.#M
MY2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,S`*;7-G:60@(D-R
M961I="!C87)D(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I
M9"`B0W)O871I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#=6)A
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@IM<V=I9"`B
M0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N
M<RYP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS
M9W-T<B`BS_#@XN`@Y^`@X^[Q\N@B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z
M,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS,PHC+"!F=7IZ>0IM<V=I
M9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R("+"X/CH\N4@\?KPXOKPZ#HB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED(")#=7)R96YT(%=E871H
M97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(W-0IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,R"FUS
M9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE
M('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R("+HY_#EYN@B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED(")#=70@
M<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I
M9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED
M(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,2!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`BQ,0B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@Q"FUS9VED("(B"B)$4TX@
M*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A
M=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3D*;7-G:60@(D1A
M:6QY(@IM<V=S='(@(L7FY>3MY>+M[B(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H
M<#HV-0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<Y"FUS9VED(")$871A8F%S92!,
M;V]K=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDY
M"B,L(&9U>GIY"FUS9VED(")$871E(@IM<V=S='(@(L3@[>WH(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@
M4F5C96EV960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@P-PIM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S(R"B,L(&9U>GIY"FUS9VED(")$87DB"FUS9W-T
M<B`BQ>;EY.WEXNWN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,V"B,L(&9U>GIY"FUS9VED(")$95]L971E
M($-O;'5M;B(*;7-G<W1R("+(Y^'E\.7RY2#J[NON[>@Z(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*(RP@9G5Z>GD*;7-G
M:60@(D1E8V5M8F5R(@IM<V=S='(@(M?KY>WNXN4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED
M(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`HC+"!F=7IZ>0IM<V=I9"`B
M1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(LW@[.#KZ"#SY>3MX.KB_^+@[>7R
M[B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI8B]P
M<F5F<RYP:'`Z,3$W"B,L(&9U>GIY"FUS9VED(")$969A=6QT(@IM<V=S='(@
M(LCG\O#HZ2(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C<W"B,L(&9U>GIY"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S
M='(@(LCG[^[KY^+@Z2#O[N3PX.?AZ/#@^>#RX"#QY2#Q\N[I[>[Q\B(*"B,Z
M(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z.3$*;7-G:60@(D1E
M9F%U;'0@261E;G1I='DB"FUS9W-T<B`BR.3E[?+H]^WN\?(@[^X@[^[D\.#G
MX>CPX.WE(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"B,L(&9U>GIY
M"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(LCDY>WRZ/?M[O'R(._N
M(._NY/#@Y^'H\.#MY2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM
M<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C,V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S
M='(@(LCG\O#HZ2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS,@HC+"!F=7IZ>0IM<V=I9"`B1&5L971E($-E
M;&PB"FUS9W-T<B`BR.?R\.CI(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@
M861M:6XO9W)O=7!S+G!H<#HR,C<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!'
M<F]U<"(*;7-G<W1R("+(Y_+PZ.DB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR-#D*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T
M<B`BR.?R\.CI(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW
M-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0HC+"!F=7IZ>0IM
M<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`BS_#@XN`@[^X@[^[D
M\.#GX>CPX.WE(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&-E;&PB"FUS
M9W-T<B`BR.?R\.CI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV,PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&-O
M;'5M;B(*;7-G<W1R("+(Y^'E\.7RY2#J[NON[>@Z(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA
M=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HT,C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E
M;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(M#EY.#J]NC_
M(.W@(._PX.+@\N`@Y^`@)R5S)R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-#(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S
M:6]N<S\B"FUS9W-T<B`BT>CC\_#MZ"#KZ"#Q\N4L(/?E(.CQZN#RY2#DX"#H
MY_+PZ.7RY2`G)7,G(.@@XO'H]^KH(._NY._PX.+@/R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*(RP@9G5Z
M>GD*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`BR.?R\.CI(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0HC+"!F=7IZ>0IM
M<V=I9"`B1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(LCDY>WR
MZ/?M[O'R(._N(._NY/#@Y^'H\.#MY2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E
M('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@
M(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR-3,*(RP@9G5Z>GD*;7-G:60@(D1E;&EV97)Y('1I;64B
M"FUS9W-T<B`BR.?R\.CI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR
M.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*(RP@9G5Z>GD*;7-G:60@
M(D1E<V-R:7!T:6]N(@IM<V=S='(@(L_ZZ^WN(.[OZ/'@[>CE.B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DU"FUS9VED(")$971A:6QS("AA
M;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,3DY"FUS9VED(")$971A:6QS(&AA=F4@
M8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("+$
MY?+@Z>OH\N4@X?_UX"#PY>/H\?+PZ/#@[>@@Y^`@X.3LZ.WH\?+PX/+N\.`N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q.0IM<V=I9"`B1&5V
M96QO<&UE;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,3<*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(Y-`IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C(W"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E
M8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I
M;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C8*;7-G:60@(D1I<W!L87D@,C0M:&]U
M<B!T:6UE<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDW"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`BQ.CQ[^OEZ2#.
M[_;HZ"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY-@HC+"!F
M=7IZ>0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R
M("+$Z/'OZ^7I(,[O]NCH(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-0IM
M<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$W"B,L(&9U>GIY"FUS9VED(")$
M:7-P;&%Y(&9O<FUA="(*;7-G<W1R("+$Z/'OZ^7I(,[O]NCH(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B1&ES<&]S:71I
M;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@
M(D1J:6)O=71I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-#(R"B,L(&9U>GIY"FUS9VED(")$;R!N;W0@9&5L971E(@IM
M<V=S='(@(LCG\O#HZ2(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR
M-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP
M:'`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z
M,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@
M=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S
M+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I
M9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M
M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@
M4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z.#0T"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(LWE
MZ.?BY?'R[>`@ZN[LX.WDX#H@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO
M;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,3`W"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*(RP@9G5Z>GD*;7-G
M:60@(D1R=6=S(@IM<V=S='(@(L'ZX^[BY2(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B12U-86EL(@IM
M<V=S='(@(L_N^>`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I
M8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3(&=A=&5W87D@9')I
M=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@HC.B!T96UP;&%T97,O<&]R=&%L
M+V5D:70N:6YC.C(U"FUS9VED(")%9&ET(@IM<V=S='(@(M#EY.#J]NC_(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU,"!T96UP;&%T97,O
M<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z
M,C(V"B,L(&9U>GIY"FUS9VED(")%9&ET($=R;W5P(@IM<V=S='(@(L/P\^_H
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`HC+"!F=7IZ>0IM<V=I9"`B161I
M="!097)M:7-S:6]N(@IM<V=S='(@(L_PX.+@(@H*(SH@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C(S-PHC+"!F=7IZ>0IM<V=I9"`B161I="!097)M:7-S
M:6]N<R(*;7-G<W1R("+/\.#BX"(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HR,SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R
M;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(M#EY.#J]NC_(.W@(._PX.+@\N`@
MY^`@)R5S)R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*(RP@9G5Z
M>GD*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(M#EY.#J]NC_
M(.W@(._PX.+@\N`@Y^`@)R5S)R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,S8W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET
M('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`BT.7DX.KVZ/\@[>`@
M[_#@XN#RX"#GX"`G)7,G(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S
M:6]N<R!F;W(@)7,B"FUS9W-T<B`BT.7DX.KVZ/\@[>`@[_#@XN#RX"#GX"`G
M)7,G(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"B,L(&9U>GIY"FUS
M9VED(")%9'5C871I;VXB"FUS9W-T<B`BPN#JX.WVZ/\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P
M"FUS9VED(")%9WEP="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C,Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")%:71H97(@96YA
M8FQE(&ET('1H96XZ("5S+"!O<B!U<V4@=&AE(&)A<VEC($A434P@=F5R<VEO
M;CH@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B16P@4V%L
M=F%D;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X-CD*;7-G:60@(D5M86EL(@IM<V=S='(@(L_H\>SN(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C4@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"FUS9VED(")%;6%I;"!!9&1R97-S(@IM
M<V=S='(@(L5M86EL(.#D\.7Q(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DV,PIM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM
M<V=S='(@(D5M86EL(.#D\.7QZ/+E(/+P_^'BX"#DX"#Q^N+OX.3@\BXB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@Y"B,L(&9U>GIY"FUS9VED
M(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("+$\//CX"#H[?3N
M\.S@]NC_(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT
M<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M.3@*(RP@9G5Z>GD*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R("+.[_;HZ"(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P,@HC+"!F=7IZ>0IM<V=I9"`B16UP='D@;65S<V%G92XB"FUS9W-T<B`B
MS_#@Y^7M(/#EY_/K\N#R+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0X
M-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C8R(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS
M9W-T<B`BS_#@Y^7M(/#EY_/K\N#R+B(*"B,Z(&9R86UE=V]R:R]344PO4U%,
M+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30S"FUS9VED
M(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE
M<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3$X"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M
M96YU/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-3DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3$*;7-G:60@(D5N9"!Y
M96%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C$*;7-G:60@(B(*(D5N
M=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K
M960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG
M+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.#DQ"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HT-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-34*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E<R]P;W)T86PO:6YD97@N
M<&AP.C@R"FUS9VED(")%<G)O<B(*;7-G<W1R("+#\.7XZN`B"@HC.B!F<F%M
M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP
M.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E
M;G0Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P
M87-S=V]R9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H
M(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U
M"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,S.0IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R("+"
M\>7JZ"`Q-2#LZ.WS\N@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Y
M"B,L(&9U>GIY"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`BPO'E
MZN@@-2#LZ.WS\N@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,V(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#<*;7-G:60@(D5V97)Y(#,P('-E8V]N
M9',B"FUS9W-T<B`BPO'EZN@@,S`@\>7J\^WDZ"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS,S@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,`IM<V=I
M9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(L+QY>KH(#4@[.CM\_+H(@H*
M(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HV,`IM
M<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`BPO'_ZNX@Z^[CXN#MY2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`*;7-G:60@(D5V97)Y(&AA;&8@
M:&]U<B(*;7-G<W1R("+-X"#B\>7JZ"#O[NONXNCM(/?@\2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X
M.`IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(L+Q_^K@(.SH[?/RX"(*
M"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M
M<&QE('9A;'5E<SHB"FUS9W-T<B`BS_#H[.7P[>@@\?+NZ>WN\?+H.B(*"B,Z
M(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@
M861M:6XO<W%L<VAE;&PN<&AP.C$R-PHC+"!F=7IZ>0IM<V=I9"`B17AE8W5T
M92(*;7-G<W1R("+(Y^_ZZ^W_XN#MY2#MX#HB"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HT-S4*;7-G:60@(D5X<&%N9"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS9VED
M(")%>'!A;F0@4VED96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,
M+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W
M-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@
M=&5R;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-@IM<V=I9"`B
M17AP;VYE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PHC+"!F=7IZ
M>0IM<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R("+(Y^_PX/G@
M[>7R[B#MX"#TX.GK[N+E(.WE(/'E(._NY.3Z\.;@+B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(Q-@IM<V=I9"`B1F%I;&5D(')E=')I
M979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(LWEXOKG[.[F[>[Q\B#DX"#Q
MY2#GX/#EY/_R(._PY?3E\.7M]NCH\N4N(@H*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R
M+B(*;7-G<W1R("+-Y>+ZY^SNYNWN\?(@Y.`@\>4@[O'Z^>7Q\N+H(.+P^N?J
MX"#Q($Q$05`@\?KPXOKP+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB
M+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E
M<BXB"FUS9W-T<B`BP_#E^.K@(._PZ"#QXOKPY^+@[>4@\?KQ(%--0B#Q^O#B
M^O`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-CDQ"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<
M(B5S7"(N(@IM<V=S='(@(L/PY?CJX"#O\.@@\>+Z\.?BX.WE(/'Z\2!334(@
M\?KPXOKP+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<*
M;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3<@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C0*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T
M<B`BP_#E^.K@(._PZ"#QXOKPY^+@[>4@\?KQ(%--0B#Q^O#B^O`N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C$*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B
MS>7B^N?L[N;M[O'R(.3@(/'E(.?@\.7D__(@[_#E].7PY>WVZ.CRY2XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I
M9"`B1F%I<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N
M9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM
M<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0TQ)+T-,22YP:'`Z,C,X"B,L(&9U>GIY"FUS9VED(")&871A;"!%<G)O<CHB
M"FUS9W-T<B`BP_#E^.K@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(M3@ZO$B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"B,L(&9U>GIY"FUS9VED
M(")&87AE<R(*;7-G<W1R("+4X.KQ(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(P"FUS9VED(")&965L<R!,
M:6ME(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,S$*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W
M(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-`IM<V=I
M9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,S,S0*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S@*;7-G:60@(D9I
M9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U
M"B,L(&9U>GIY"FUS9VED(")&:6QE(@IM<V=S='(@(O3@Z>LB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(L'P[ND@].#IZ^[BY3H@)7,@
M].#IZR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF
M;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(L'P
M[ND@].#IZ^[BY3H@)7,@].#IZ^`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#`W"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`BU.#IZR#L
MY>W@YN7P(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*;7-G:60@
M(D9I;&4@3F%M92(*;7-G<W1R("+([.4@[>`@].#IZR(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Y.34*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.#8*(RP@
M9G5Z>GD*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(LCLY2#MX"#TX.GK
M(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4Y"FUS9VED
M(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`BR.?O\.#Y
MX.WE\NX@[>`@].#IZ^[BY2#MY2#QY2#O[N3D^O#FX"XB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B
MU.CK\OKP(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S="!(86QF
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U
M-@IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,S$*;7-G:60@(D9L:7`B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O
M9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(S
M-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L('!H<"UF;W)M
M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R
M"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA
M9V5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,T"FUS
M9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-SD*;7-G:60@(B(*(D9O<F5C87-T($1A>7,@
M*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H
M(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@
M<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R('!A
M<W-W;W)D/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#8R"B,L(&9U>GIY"FUS9VED(")&;W)M<R(*;7-G<W1R("+4[O#S[.@B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*(RP@9G5Z>GD*;7-G:60@
M(D9O<G1U;F4B"FUS9W-T<B`BU.[P\^SH(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")&;W)T
M=6YE<R(*;7-G<W1R("+4[O#S[.@B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,SD*(RP@9G5Z>GD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`BU.[P
M\^SH(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U,PIM<V=I9"`B
M1F]R=6US(@IM<V=S='(@(M3N\//LZ"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ,#D*(RP@9G5Z>GD*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@
M(L_PY>_PX/G@[>C_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PHC+"!F
M=7IZ>0IM<V=I9"`B1G)A;65S(@IM<V=S='(@(M3N\//LZ"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S,*(RP@9G5Z>GD*;7-G:60@(D9R86YC92(*;7-G<W1R(")/<F%N9V4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC
M92P@365T<F]P;VQI=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@
M(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@
M(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS
M9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`HC
M+"!F=7IZ>0IM<V=I9"`B1G)O;2(*;7-G<W1R("+4[O#S[.@B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS-C`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C0P-@IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"B,L(&9U>GIY"FUS9VED(")&=6QL
M($1E<V-R:7!T:6]N(@IM<V=S='(@(L_ZZ^WN(.[OZ/'@[>CE.B(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS
M9VED(")&=6QL($UO;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*
M;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R("+([.4@[>`@].#IZR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I
M9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U
M"FUS9VED(")'86UB:6$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HT,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A
M=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("+*[NWTZ./S\.#VZ/\B"@HC
M.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B
M1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B
M1V5O<F=I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M86YY
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0HC+"!F=7IZ
M>0IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R("+([.4@[>`@].#IZR(*"B,Z
M('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E
M;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3$R.`IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H
M<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E
M87)C:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C,W"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S8*(RP@9G5Z>GD*;7-G:60@(D=R965C92(*;7-G<W1R(")'
M<F5E;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")'<F5E
M:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0HC+"!F=7IZ
M>0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(D=R965N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-`HC+"!F=7IZ>0IM<V=I9"`B1W)E;F%D82(*;7-G<W1R(")'<F5E;B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A
M=&EO;B(*;7-G<W1R("+`Y.SH[>CQ\O#H\.#MY2#MX"#C\//OZ"(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N
M;VXM96UP='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P
M.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C$Q."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,3(T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT,3@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L
M92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`BP_#E^.K@(._PZ"#HY_+P
MZ.+@[>4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C,S."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U
M<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*
M;7-G<W1R("+#\//OZ"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"B,L(&9U>GIY"FUS9VED
M(")'=65R;G-E>2(*;7-G<W1R(")'<F5Y(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX
M.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`BS_#@XN`@Y^`@
MX^[Q\N@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<P"FUS9VED
M(")'=65S=&)O;VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W5I
M;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A+4)I
M<W-A=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-C`*;7-G
M:60@(DA434PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B
M2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(DA45%`@
MZ.3E[?+H].CJX/;H_R#MY2#E(.W@[.7PY>W@+B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`HC
M+"!F=7IZ>0IM<V=I9"`B2&%I=&DB"FUS9W-T<B`BRN[E].CVZ.7M\B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S
M:"U!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Y,S(*(RP@9G5Z>GD*;7-G:60@(DAE861E<B(*;7-G<W1R
M("+'X./KX.+H_R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L
M97-E="YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B
MQ^#CZ^#BZ/\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A
M;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3
M=&]R;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM
M<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*
M;7-G:60@(DAE:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O2&5L<"YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92](96QP
M+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA
M=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G:60@(DAE;'`B"FUS9W-T<B`BS^[L
M[ODB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q"B,L(&9U>GIY"FUS9VED(")(
M96QP97(B"FUS9W-T<B`BS^[L[ODB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL
M93HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-CD*;7-G:60@(DAI9V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM
M:&5A9&5R+FEN8SHU"B,L(&9U>GIY"FUS9VED(")(;U]M92(*;7-G<W1R("+-
MX/?@Z^XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H5F%T:6-A
M;B!#:71Y(%-T871E*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C$U,S4*;7-G:60@(DAO;64B"FUS9W-T<B`BS>#WX.ON(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS
M9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`BQ.[LX/CE[2#@Y/#E\2(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`IM<V=I9"`B2&]M92!$:7)E8W1O
M<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R("+$[NS@
M^.7M(/+EZ^7T[NTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-0IM<V=I9"`B
M2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E
M(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@
M;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$R-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T
M<B`BT_'OY?CM[B#O\.7LX/7MX/(@)R5S)R#N\B#QZ/'RY>S@\N`N(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO
M;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M
M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J
M96-T("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,3(T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA
M8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#<T"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F
M;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$Q.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3,S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE
M('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@R"FUS9VED(")(
M;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A
M;#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G970@
M:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED
M(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM
M<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U
M(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S`*;7-G
M:60@(DAU;6ED:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-3D*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES=',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W,B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,U"B,L('!H<"UF;W)M
M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM
M<V=S='(@(L/PY?CJX"#O\.@@\?KGY.#BX.WE(.W@($E-05`@[^[YY>WQZN`@
MZO/RZ/\Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,C$T(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@
M)7,B"FUS9W-T<B`BP_#E^.K@(._PZ"#HY_+PZ.+@[>4@[>`@24U!4"#O[OGE
M[?'JX"#J\_+H_SH@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I
M;VX@9F%I;&5D.B`E<R(*;7-G<W1R("+#\.7XZN`@[^[PX.3H(.KB[O+@(._P
MZ"#Q^N?DX.+@[>4@[>`@24U!4"#O[OGE[?'JX"#J\_+H_SH@)7,B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S$V"B,L(&9U>GIY"FUS9VED("))
M4"!!9&1R97-S(@IM<V=S='(@(L#D\.7Q(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]I<&)A<VEC+G!H<#HW-PHC+"!F=7IZ>0IM<V=I9"`B25`@061D<F5S
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("))4"#@Y/#E\>`@[>4@Y2#B(._N
MY^+NZ^7MZ/\@0TE$4B#AZ^[J+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A
M;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(DE0(.#D\.7QX"#MY2#E(.(@
M[^[GXN[KY>WH_R!#2412(.'K[NHN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W
M;B!V:6]L871I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0HC+"!F=7IZ>0IM<V=I
M9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(L+L^NKMZ"#O[N3PX.+M
MZ/+EZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<V"FUS9VED("))8V]N<R!/
M;FQY(@IM<V=S='(@(M'@[.X@Z.KN[>@B"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S<*;7-G:60@
M(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R("+(ZN[MZ"#Q(/+EZO'R(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B261E;G1I='DG<R!N
M86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T
M(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@
M=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#4U"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN
M9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*
M(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ-S,*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N
M;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B
M92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C@*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G
M:60@(DEM86=E(%523#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("))
M;6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED
M("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA
M9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E
M9"(*;7-G<W1R("+([._N\/+H\.#M[B#O[NOE.B`E<R(*"B,Z('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM
M<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("+([._N\/+H\.#M[B#O[NOE.B`E
M<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM
M<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`BR.SO[O#RZ/#@[>@@[^[KY?+@.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS,`HC+"!F=7IZ>0IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS
M9W-T<B`BPNSZZNWH(._NY/#@XNWH\N7K(@H*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED("));F-O<G)E8W0@86-T
M:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"B,L(&9U>GIY"FUS9VED
M("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R
M("+-Y>KN\.7J\NW@(._@\.[KX"#HZ^@@[^[R\.7AZ/+EZ_'J[B#H[.4A(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN
M8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G
M86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N
M965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B
M26YC<F5A<V4@26YD96YT(@IM<V=S='(@(M/BY>OH]^#BX.WE(.W@(//EY.W@
MZN+_XN#MY?+N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("));F1I82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5
M<V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@
M(DEN9&]N97-I82(*;7-G<W1R("+-X._PX.+E[>XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3<*(RP@
M9G5Z>GD*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@(LCM].[P[.#VZ/\@
MY^`@PN#Q(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,S,`IM
M<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,U"B,L(&9U>GIY"FUS9VED("));G-E<G0@0U]O;'5M;B!!
M9G1E<B(*;7-G<W1R("+"[/KJ[>@@[^[D\.#B[>CRY>LB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*
M(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R("+"[/KJ[>@@
M[^[D\.#B[>CRY>LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`P"B,L(&9U>GIY"FUS9VED("));G-E<G0@5&%B;&4B"FUS
M9W-T<B`BPNSZZNWH(._NY/#@XNWH\N7K(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,
M:6YK(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T
M(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(L+L^NKMZ"#O[N3PX.+MZ/+EZR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@
M8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@
M82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C
M=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A
M(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R
M<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@
M<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT
M97)N871E('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,SD*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O
M('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4X"B,L(&9U>GIY"FUS9VED("));G-E<G0@8V5L;"!A9G1E
M<B(*;7-G<W1R("+"[/KJ[>@@[^[D\.#B[>CRY>LB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y"B,L(&9U>GIY
M"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`BPNSZZNWH(._N
MY/#@XNWH\N7K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV-`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(&-O;'5M
M;B!A9G1E<B(*;7-G<W1R("+"[/KJ[>@@[^[D\.#B[>CRY>LB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"B,L
M(&9U>GIY"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R("+"
M[/KJ[>@@[^[D\.#B[>CRY>LB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F
M;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-CD*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!R
M;W<@869T97(B"FUS9W-T<B`BPNSZZNWH(._NY/#@XNWH\N7K(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`HC
M+"!F=7IZ>0IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`BPNSZ
MZNWH(._NY/#@XNWH\N7K(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S
M,`IM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E
M8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D
M:69Y($EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN
M:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T
M;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S4*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-S4*;7-G:60@(DEN=&5G97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$S,PIM
M<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV
M86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3<P"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(P,0HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,3`*(RP@9G5Z>GD*
M;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`BR.?O\.#RY>WH\N4@
MY.#M[>@@\>`@[>7BX.OHY.WH+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z,S0*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM
M<V=S='(@(LW@[.7PY>WH(._PZ.ONYN7MZ/\Z("5S(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"B,L(&9U>GIY
M"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R("+(Y^_PX/+E[>CR
MY2#DX.WMZ"#QX"#MY>+@Z^CD[>@N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S
M970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G
M<W1R("+(Y^_PX/+E[>CRY2#DX.WMZ"#QX"#MY>+@Z^CD[>@N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS
M9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`*;7-G:60@
M(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$W-PIM<V=I9"`B26YV86QI9"!L:6-E;G-E
M(&ME>2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$W,0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V
M:61E9"XB"FUS9W-T<B`BR.?O\.#RY>WH\N4@Y.#M[>@@\>`@[>7BX.OHY.WH
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P-PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS
M9W-T<B`BR.?O\.#RY>WH\N4@Y.#M[>@@\>`@[>7BX.OHY.WH+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM
M<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W"FUS9VED
M("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<S"B,L(&9U>GIY"FUS9VED
M("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(LCG[_#@\N7MZ/+E(.3@
M[>WH(/'@(.WEXN#KZ.3MZ"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3<U"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`W-B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-C(*;7-G:60@(DEN=F%L:60@<VAA
M<F4@;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S;W5R
M8V4@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N
M:6-O9&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,U-PIM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-SD*;7-G:60@
M(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS
M9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T
M"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-0IM<V=I9"`B27-S=65R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(LW@ZNON[>7MZ"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,@HC+"!F=7IZ>0IM<V=I9"`B271A;'DB"FUS9W-T<B`BS>#JZ^[M
MY>WH(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#$*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS
M9VED(")*86YU87)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B
M2F%P86XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*
M;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*;7-G:60@(B(*(DIA=F%S
M8W)I<'0@:&%S(&)E96X@9&ES86)L960@;VX@>6]U<B!B<F]W<V5R(&%N9"!T
M:&ES('!A9V4@;6%Y(&YO="!B92`B"B)D:7-P;&%Y:6YG(&-O<G)E8W1L>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*
M(RP@9G5Z>GD*;7-G:60@(DIE<G-E>2(*;7-G<W1R(")'<F5Y(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`HC+"!F=7IZ>0IM
M<V=I9"`B2G5S=&EF>2(*;7-G<W1R("+K_^+N(._NY/#@XNW_XN#MY2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$U"B,L(&9U>GIY"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R("+K
M_^+N(._NY/#@XNW_XN#MY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB
M"FUS9W-T<B`B[_KK[>X@[^[D\.#B[?_BX.WE(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU
M<W1I9GD@3&5F="(*;7-G<W1R("+K_^+N(._NY/#@XNW_XN#MY2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V
M"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(N3_\>WN(._NY/#@XNW_
MXN#MY2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C8T"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#,*(RP@9G5Z>GD*;7-G:60@(DME;GEA(@IM<V=S='(@(L?@X?#@[>@B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+
M97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(DME<F)E<F]S(/'Z\.+Z\.`@[O+UXOKPZ^@@Z.3E[?+H].CJX/;H__+@
M+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L
M($YE=V)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+
M97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0HC+"!F
M=7IZ>0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B36EM92#RZ.\B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`HC+"!F=7IZ>0IM
M<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(LCG[^[KY^+@[>4Z.B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L
M<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R
M("+*Z_[WX"#BY??E(/'Z^>7Q\N+SXN`@XB#O\^'KZ/?MZ/\@ZNO^]_'Z\.+Z
M\"XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC
M(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")+;W)E86X@*$550RU+4BDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`HC+"!F=7IZ>0IM
M<V=I9"`B3&%?>6]U="(*;7-G<W1R("+(Y_7NY"(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(L7G
MZ.HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A
M=&EC(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-S8*(RP@9G5Z>GD*;7-G:60@(DQA<W0@4&%S<W=O
M<F0@0VAA;F=E(@IM<V=S='(@(L_@\.[KX#H@(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1
M=6%R=&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Q
M"B,L(&9U>GIY"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(L[O\.7Q
M[>@B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z-S(Q"B,L('!H<"UF;W)M870*;7-G:60@
M(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z-S$V"FUS9VED("),87-T(&QO9VEN.B!.979E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*(RP@9G5Z>GD*;7-G:60@(DQA
M='9I82(*;7-G<W1R("+$X.WMZ"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0HC+"!F=7IZ>0IM<V=I
M9"`B3&%Y;W5T(@IM<V=S='(@(LCG]>[D(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@
M9F]R(&YO(&)O<F1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@
M(DQE8F%N;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS9VED("),969T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3D*;7-G:60@(DQE
M9G0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,34*(RP@9G5Z>GD*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@
M(LW_[.`@\?+NZ>WN\?+H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"B,L(&9U>GIY"FUS9VED
M("),97-O=&AO(@IM<V=S='(@(LSE\N[D(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED("),979E;"(*;7-G<W1R
M("+-Z.KNX^`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER
M:7EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS
M=&5I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR-0HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@1')I>GIL92(*
M;7-G<W1R("),:6=H="!";'5E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%)A:6XB
M"FUS9W-T<B`BPO7NY"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN($5A<FQY(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X
M"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT
M(%)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I=&@@
M5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4VYO=R(*
M;7-G<W1R("),:6=H="!";'5E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B
M3&EM97)I8VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@Q-`HC+"!F=7IZ>0IM<V=I9"`B3&EN:R(*;7-G<W1R("+"]>[D(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B3&EN:R!T:&4@
M96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA
M>6EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL
M=&5R+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED("),:6YK<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O
M;VMI92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@
M9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*
M;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+VAE;'`O:6YD97@N<&AP.C4P"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM
M<V=S='(@(L_N[.[Y(/+E[.@B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,R
M"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3@Y"B,L(&9U>GIY"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`BS^[L
M[OD@\N7LZ"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3DV"FUS9VED("),:7-T+4ED(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3DS"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R
M:6)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R
M<RYP:'`Z-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@
M(M'OZ/'ZZN`@\2#O[O+PY>'H\N7KZ"#E(.?@X?#@[>7M+B(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HS-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(@IM<V=S='(@(M'OZ/'ZZN`@\2#O
M[O+PY>'H\N7KZ"#E(.?@X?#@[>7M+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"XB"FUS9W-T<B`BT>_H\?KJX"#Q(._N\O#EX>CRY>OH(.4@Y^#A\.#M
MY>TN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E
M<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&ET:'5A
M;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEM86=E<RYP:'`Z.#,*(RP@9G5Z>GD*;7-G:60@(DQO861I;F<N+BXB"FUS
M9W-T<B`BY^#PY>;DX.WE(.W@(.'HX>OH[O+EZNCRY2XN+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3$*;7-G:60@(DQO8V%L('1I;64Z
M("(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G
M:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,2!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-C0*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]"
M;&]C:R]M971A<BYP:'`Z-C4*(RP@9G5Z>GD*;7-G:60@(DQO8V%T:6]N(@IM
M<V=S='(@(L+@ZN#M]NC_(@H*(SH@;&]G:6XN<&AP.C$W,B!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,3DQ('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@
M(L+U[N0B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G
M:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$X-0IM<V=I9"`B3&]G
M(&]U="(*;7-G<W1R("+(Y_7NY"(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HU.0HC+"!F=7IZ>0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`BPO7NY"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*(RP@9G5Z>GD*;7-G:60@(DQO
M9VEN(%1A<VMS(@IM<V=S='(@(L?@Y.#WZ"(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDY-@IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U
M<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L
M>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DR
M"B,L(&9U>GIY"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@(N_P[N+@
MZ^7M[B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C4*(RP@9G5Z
M>GD*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R("+(Y_7NY"(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B3&]V92(*;7-G
M<W1R("+/\.7LX/7MZ"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8W"FUS9VED("),;W<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM
M<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y
M"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#`*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S."!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`BS,PB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Q"FUS9VED(")-3U1$(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP
M.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A
M=&$N(@IM<V=S='(@(DU3+51.148@[_#HZO#E[^7MZ/_R(/3@Z>L@[>4@\?KD
M^O#FX/CE(.3@[>WH+B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*(RP@9G5Z>GD*;7-G
M:60@(DU31R(*;7-G<W1R(")#35,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*(RP@9G5Z>GD*
M;7-G:60@(DUA8V%O(@IM<V=S='(@(L+@ZN#M]NC_(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ
M"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S
M8V%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0HC
M+"!F=7IZ>0IM<V=I9"`B36%G:6,B"FUS9W-T<B`BS^[YX"(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HX,0IM<V=I9"`B36%I;"(*;7-G<W1R("+/
M[OG@(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R,@IM<V=I9"`B
M36%I;"!!9&UI;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN
M7VLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED
M(")-86QA=VDB"FUS9W-T<B`BS^[YX"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B
M36%L87ES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD
M:79E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@
M(DUA;&DB"FUS9W-T<B`BS^[YX"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM
M<V=I9"`B36%L=&$B"FUS9W-T<B`BS^[YX"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G
M;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R
M<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Q-3,*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-`HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$V.`IM<V=I9"`B36%P
M475E<W0@;6%P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#$*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM
M<V=I9"`B36%R8V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0HC+"!F=7IZ>0IM<V=I9"`B
M36%R9VEN(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N
M+U5N<V5E;B!F;&%G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R
M(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T
M8VAI;F<@9FEE;&1S(@IM<V=S='(@(M'ZXN_@Y.#YZ"#O[NOE\N`B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED
M(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B
M36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S`V"FUS9VED(")-87@@=&5M<"!L87-T(#(T
M(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M.3@*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!0
M;W)T86P@0FQO8VMS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM=6T@;&5N
M9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*;7-G:60@(DUE
M;6)E<G,B"FUS9W-T<B`BU^OE[>[BY2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-S@*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`BPNCD(.W@(.SE
M[?[R[CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R("+/Z/'L[B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$V"B,L(&9U>GIY"FUS9VED
M("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I
M9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB
M"FUS9W-T<B`B(@HBS^CQ[.[R[B#AY?CE(._P[N+E\.7M[B#S\>_E^.WN+"#M
M[B#QY?#RZ/3HZN#RX"#MX"#O[N3OZ/'@(.WE(.'E^.4@[^[RXOKPY.7M+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!E>'!I<F5D+B(*;7-G<W1R
M("+/Z/'L[B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*(RP@9G5Z>GD*;7-G:60@(DUE<W-A
M9V4@='EP92(*;7-G<W1R("+/Z/'L[B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q
M,@HC+"!F=7IZ>0IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L
M92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R
M871O<BXB"FUS9W-T<B`BQ.7RX.GKZ/+E(.'_]>`@\.7CZ/'R\.CPX.WH(.?@
M(.#D[.CMZ/'R\.#R[O#@+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-C4*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS
M9VED(")-971H;V0B"FUS9W-T<B`BS.7R[N0B"@HC.B!F<F%M97=O<FLO4E!#
M+U)00R]X;6QR<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#+W-O87`N<&AP
M.C$Q-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(%PB)7-<
M(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R("+,Y?+NY"`G)7,G(.WE(.4@Y.7T
MZ.WH\.#M(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@
M;65T:&]D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-0IM<V=I9"`B365T
M<FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&961E
M<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@HC+"!F=7IZ>0IM<V=I
M9"`B36ED9&QE(@IM<V=S='(@(O3@Z>LB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S
M='(@(DUI;64@\NCO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3`*;7-G
M:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B36EN('1E;7`@;&%S="`V
M(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N
M;W0@>65T(&5X<&ER960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-`HC+"!F=7IZ>0IM<V=I9"`B36ER
M<F]R(@IM<V=S='(@(L/PY?CJX"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G
M:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B(@HB
M36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I
M="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I
M=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2
M('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG
M('-E<W-I;VX@240N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-`IM<V=I9"`B36]B:6QE
M($UA:6PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@(DUO9&5R871E(@IM<V=S
M='(@(L3@\N`@[>`@[_#N[.7M_^WE(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#@*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`BQ.#RX"#M
MX"#O\.[LY>W_[>4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S,*
M;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED
M(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G
M:60@(DUO;F=O;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(U.30*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3<*
M;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`BS.7QY??M[B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@
M4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C$W,B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T
M:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP
M"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE87(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@
M(DUO<W1L>2!3=6YN>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HU,#D*(RP@9G5Z>GD*;7-G:60@(DUO=F4@1&]W
M;B(*;7-G<W1R("+O\.7LY?'RZ"#MX"#D[NOS+^3_\>WN(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$S"B,L(&9U>GIY"FUS9VED
M(")-;W9E($QE9G0B"FUS9W-T<B`B[_#E[.7Q\N@@[>`@X^[PY2_K_^+N(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$W"B,L(&9U
M>GIY"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(N_PY>SE\?+H(.W@(.3N
MZ_,OY/_Q[>XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HU,#4*(RP@9G5Z>GD*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B[_#E[.7Q
M\N@@[>`@X^[PY2_K_^+N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4R-`HC+"!F=7IZ>0IM<V=I9"`B36]V92!D;W=N(@IM
M<V=S='(@(N_PY>SE\?+H(.W@(.3NZ_,OY/_Q[>XB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(S"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*(RP@9G5Z>GD*;7-G:60@
M(DUO=F4@=7`B"FUS9W-T<B`B[_#E[.7Q\N@@[>`@X^[PY2_K_^+N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#0*;7-G:60@(DUU;'1I+6QE=F5L
M(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U-0IM<V=I9"`B375L=&EM87`@
M54L@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R-#(*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`P"FUS9VED(")->2!!8V-O
M=6YT(@IM<V=S='(@(LSN__+@(,_N^>`B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@(DUY($%C8V]U;G0@26YF;W)M871I
M;VXB"FUS9W-T<B`BR.WT[O#LX/;H_R#GX"#"X/$B"@HC.B!S97)V:6-E<R]P
M;W)T86PO:6YD97@N<&AP.C4T"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C$S-@IM<V=I9"`B37D@
M4&]R=&%L($QA>6]U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@
M(DUY86YM87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3$@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM
M<V=I9"`B3F%M92(*;7-G<W1R("+([.4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@
M(DYA;6EB:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").875R
M=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3@Q"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B
M3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C
M87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E(%)E;F5W
M86P@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X-@IM<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@W"FUS
M9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@P"FUS9VED
M(").971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3$*;7-G:60@(DYE='=O<FLB"FUS
M9W-T<B`BS/#EYN`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-0HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S@V"FUS9VED(").979E<B(*;7-G<W1R("+-Z.KNX^`B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#$*(SH@9G)A
M;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&9R
M86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HY-PHC.B!F
M<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L
M('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B
MS>[B[B#O[O+PY>'H\N7K\>KN(.CLY2`H[N_VZ.[MX.OM[BDB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3@*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B3F5W
M('!A<W-W;W)D(@IM<V=S='(@(L_@\.[KX"(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A
M<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*(RP@9G5Z>GD*;7-G:60@(DYE
M=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(LWEZN[PY>KR[>`@
M[^#P[NO@+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#D*(RP@
M9G5Z>GD*;7-G:60@(DYE=W,B"FUS9W-T<B`BP>7KY>;JZ"(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS,#4*(RP@9G5Z>GD*;7-G:60@(DYE=W-G
M<F]U<',B"FUS9W-T<B`BP_#S[^@B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I
M;F9O+FEN8SHQ-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S(@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S8*(RP@9G5Z>GD*;7-G:60@
M(DYE>'0@;W!T:6]N<R(*;7-G<W1R("+.[_;HZ"(*"B,Z(&9R86UE=V]R:R]5
M22]522]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(DYI9V5R(@IM<V=S='(@(LWHZN[C
MX"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S@P"FUS9VED(").:6=H
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*(RP@9G5Z>GD*;7-G:60@(DYI
M=64B"FUS9W-T<B`BT?KNX?GE[>CE(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B3F\B"FUS9W-T<B`BS>4B
M"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@
M(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F
M97)E;F-E<R!F;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`U"FUS9VED(").;R!A=F%I;&%B;&4@
M<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW.2!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-#4*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z,C8W"FUS9VED(").;R!B;&]C:R!E>&ES=',@
M870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P"B,L(&9U>GIY"FUS9VED(").
M;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R("+-_^S@(.?@Y.#DY>W@(._@\.[KX"#GX"!)34%0(.CD
MY>WRZ/3HZN#VZ/\N(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*;7-G
M:60@(DYO(&-H86YG92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ-38*(RP@9G5Z>GD*;7-G:60@(DYO(&-H:6QD<F5N
M(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(B<E
M<R<@X>7XY2#D[N'@XN7M(.KZ["#QZ/'RY>S@\N`@Y^`@[_#@XN`@[>`@[^[R
M\.7AZ/+EZ^CRY2XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V
M-R!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,@HC.B!F<F%M97=O<FLO
M571I;"]5=&EL+G!H<#HW-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E
M<RXB"FUS9W-T<B`BS?_LX"#GX.3@Y.7MX"#J[NWTZ./S\.#VZ/\@Y^`@4U%,
M(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R-`IM<V=I
M9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M($944"!61E,N(@IM<V=S='(@(LW_[.`@Y^#DX.3E[>`@ZN[M].CC\_#@]NC_
M(.?@($944"!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV
M-CD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344P@5D93+B(*;7-G<W1R("+-_^S@(.?@Y.#DY>W@(.KN[?3H
MX_/PX/;H_R#GX"!344P@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HW,3<*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(LW_
M[.`@Y^#DX.3E[>`@ZN[M].CC\_#@]NC_(.?@(%-13"U&:6QE(%9&4RXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,30*;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I
M9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@W-PIM<V=I9"`B3F\@9FEL
M92!U<&QO861E9"(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(X(&QI8B]";&]C:R]S=6YR
M:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R,PIM<V=I9"`B
M3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(").;R!L;V-A
M=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`BS?_LX"#GX.3@Y.7MX"#K[NK@Z^CG
MX/;H_RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S,PHC+"!F=7IZ>0IM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE
M9"XB"FUS9W-T<B`BS?_LX"#GX.3@Y.7MX"#K[NK@Z^CGX/;H_RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@HC
M+"!F=7IZ>0IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@(LW_
M[.`@Y^#DX.3E[>`@Z^[JX.OHY^#VZ/\N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*(RP@9G5Z>GD*;7-G:60@
M(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(LW_[.`@Y^#DX.3E[>`@
MZ^[JX.OHY^#VZ/\N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS
M9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HY,0HC+"!F=7IZ>0IM<V=I9"`B
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(LW_[.`@Y^#DX.3E[>`@[^#P[NO@(.?@($E-05`@Z.3E[?+H
M].CJX/;H_RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C$P
M.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(LW_[.`@Y^#DX.3E[>`@[^#P[NO@(.?@($E-
M05`@Z.3E[?+H].CJX/;H_RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR
M8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R
M8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(LW_[.`@Y^#DX.3E[>`@
M[^#P[NO@(.?@($ME<F)E<F]S(.CDY>WRZ/3HZN#VZ/\N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO075T:"]!=71H
M+VQO9VEN+G!H<#HX-`HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z
M-S4*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,
M;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BS?_LX"#J[NWTZ./S\.#V
MZ.[M[>`@Z.WT[O#LX/;H_R#GX"!,1$%0(.CDY>WRZ/3HZN#VZ/\N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]P87-S=V0N<&AP.C$S-0HC+"!F=7IZ>0IM
M<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`BS?_LX"#J[NWTZ./S\.#VZ.[M[>`@Z.WT[O#L
MX/;H_R#GX"!334(@Z.3E[?+H].CJX/;H_RXB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(LW_[.`@ZN[M].CC
M\_#@]NCN[>W@(.CM].[P[.#VZ/\@Y^`@4TU"(.CDY>WRZ/3HZN#VZ/\N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@V"FUS9VED
M("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@
M5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I
M=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU
M<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW-3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0S"B,L(&9U>GIY"FUS9VED(").;R!R=6QE<R(*;7-G<W1R("+-_^S@
M(/'R[NGM[O'RZ"(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T
M.0HC+"!F=7IZ>0IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS
M9W-T<B`BS?_LX"#GX.3@Y.7MX"#K[NK@Z^CGX/;H_RXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T"B,L(&9U
M>GIY"FUS9VED(").;R!S:61E<R(*;7-G<W1R("+!Y>OEYNKH(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#,*;7-G:60@(DYO('-U8V@@9FEL
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3,X"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F
M;W(@8V%C:&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"B,L(&9U>GIY"FUS9VED(").;R!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`BS>7J[O#EZO+M
MX"#OX/#NZ^`@Z.OH(._N\O#EX>CRY>OQZNX@Z.SE(2(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI9"!834P@
M9&%T82!R971U<FYE9"(*;7-G<W1R("+"^O#MX/+H\N4@Y.#M[>@@[>4@\>`@
M6$U,(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDW,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.3@Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY
M.3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M,#D*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("+-_^S@(/'R[NGM[O'RZ"(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E<G-I
M;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T
M92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@
M8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS
M"B,L(&9U>GIY"FUS9VED(").;VYE(@IM<V=S='(@(LW@[_#@XN7M[B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G
M:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA
M;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]"
M;&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA
M;F$@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO
M<G=A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8T,`IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(").;W0@
M0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C0P.`HC+"!F=7IZ>0IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S
M='(@(M'ZY^3@XN#MY2#MX"#DZ/#EZO+N\.C_("5S(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H
M<#HX,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+G!H<#HY-`HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV
M.`HC+"!F=7IZ>0IM<V=I9"`B3F]T('-E="(*;7-G<W1R("+!Y>OEYNKH(@H*
M(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H
M<#HQ-#,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+G!H<#HQ-3@*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I
M;VY(86YD;&5R+G!H<#HQ-S,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#<*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`U(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(T."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8U"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(Y-PHC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$R(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HS,CD*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V,B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z-#(R"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU,#$@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W,`HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-3@W(&9R86UE=V]R:R]61E,O5D93+G!H<#HV-C4*(RP@9G5Z>GD*
M;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(LCG[_#@^>#MY?+N(.W@
M(/3@Z>ONXN4@[>4@\>4@[^[DY/KPYN`N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I
M<W0Z,3`P-0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3<X"FUS9VED
M(").;W1E<R(*;7-G<W1R("+!Y>OEYNKH(@H*(SH@<V5R=FEC97,O;V)R;W=S
M97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@
M8F%C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S4*(RP@9G5Z>GD*;7-G:60@(DYO=F5M8F5R(@IM<V=S
M='(@(M?KY>WNXN4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V
M"B,L(&9U>GIY"FUS9VED(").=6UB97(B"FUS9W-T<B`BU^OE[>[BY2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C4*;7-G:60@(DYU;6)E<B!O
M9B!C:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0U('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L
M=6UN<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S8W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C$*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30T,R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D
M871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B
M3TLB"FUS9W-T<B`BSLHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#
M<F5A=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B
M3V9F96YS92!F:6QT97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,R-@HC+"!F=7IZ>0IM<V=I9"`B3V9F:6-E(@IM<V=S='(@
M(LCGZNLN(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS
M9VED(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS
M-@HC+"!F=7IZ>0IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(L_@\.[K
MX"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@HC+"!F=7IZ
M>0IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R
M("+-Y>KN\.7J\NW@(._@\.[KX"#HZ^@@[^[R\.7AZ/+EZ_'J[B#H[.4A(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDX"B,L(&9U>GIY"FUS9VED(")/;6%N(@IM<V=S='(@(L+J
MZRXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW
M,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L
M9&5R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU
M"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Y-S$*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@
M86QL;W=E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N
M<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M
M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P
M97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO:69R86UE+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T
M(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@
M(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R("+.
M[_;HZ"(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E
M9G,O87!P+FEN8SHQ-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3W!T
M:6]N<R!F;W(@)7,B"FUS9W-T<B`BSN_VZ.@B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI
M<W0B"FUS9W-T<B`BS^[D\.7DY>T@\>_H\?KJ(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*(RP@9G5Z>GD*;7-G:60@(D]R9V%N
M:7-A=&EO;B(*;7-G<W1R("+`Y.SH[>CQ\O#H\.#MY2(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I
M;VYA;"!5;FET(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ,S(*(RP@9G5Z>GD*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B
M3W)A;F=E(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R
M:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R
M:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP
M:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$R,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,Q(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-#$*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S
M='(@(L3P\^/@(.CM].[P[.#VZ/\B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R("+/
M\.#BX"#MX"#O\.CRY>;@\N7K_R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<&%M+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N
M(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.3E[?+H
M].CJX/;H_R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M
M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R-S,*;7-G
M:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S$Y"FUS9VED(")01U`@16YC
M<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3,W,0IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U,PIM
M<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@(E!(4"!#
M;V1E(@IM<V=S='(@(DAO<F1E(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P
M"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B4$=0(%-H96QL(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@(E!-
M($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,SD*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-N;W<@4VAO
M=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,0HC+"!F=7IZ>0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@
M(E-U;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0R"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@
M;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#D*(RP@9G5Z
M>GD*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B4$=0(%-H96QL(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*(RP@
M9G5Z>GD*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(L+L^NKMZ"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V
M"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3@*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C,*;7-G:60@(E!A<W-W
M;W)D(@IM<V=S='(@(L_@\.[KX"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L
M;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,3,R,@HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T
M(@IM<V=S='(@(L_@\.[KX#H@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R
M861I=7,N<&AP.C$U,@HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER
M960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BS?_LX"#J
M[NWTZ./S\.#VZ.[M[>`@Z.WT[O#LX/;H_R#GX"!2041)55,@Z.3E[?+H].CJ
MX/;H_RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#4S"FUS9VED
M(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D
M.B(*;7-G<W1R("+/X/#NZ^`Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`BS^#P[NO@.B`B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C`S-`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U
M"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`BS>7J[O#E
MZO+MX"#OX/#NZ^`N(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q.2!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*
M;7-G:60@(E!A<W1E(@IM<V=S='(@(L+L^NKMZ"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R
M;VT@8VQI<&)O87)D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*(RP@9G5Z>GD*;7-G:60@(E!A=&@B
M"FUS9W-T<B`BPNSZZNWH(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N
M:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")096]P
M;&4B"FUS9W-T<B`BT.[K_R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y
M"B,L(&9U>GIY"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO
M;G,B"FUS9W-T<B`BQ.`@\>4@Z.?B^O#XXN#R(.OH(.[A\>OSYN+@^>CRY2#N
M[^7PX/;HZ"#O\.@@PO7NY#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#`V"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@
M;&]G:6X_(@IM<V=S='(@(L3@(/'E(.CGXOKP^.+@\B#KZ"#NX?'K\^;BX/GH
M\N4@[N_E\.#VZ.@@[_#H(,+U[N0_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ-38*(RP@9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VXB"FUS
M9W-T<B`BS_#@XN`B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L
M('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE
M=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C4X-@HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T
M<B`BS_#@XN`B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R
M;6ES<VEO;G,B"FUS9W-T<B`BS_#@XN`B"@HC.B!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN
M+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X
M"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R("+`
MY.SH[>CQ\O#H\.#MY2#MX"#O\.#BX/+@(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8U"B,L(&9U>GIY"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO
M;B(*;7-G<W1R("+$\//CX"#H[?3N\.S@]NC_(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS
M9VED(")097)U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G
M:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S
M='(@(M+EZ^7T[NTB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<X
M"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I
M9"`B4&ET8V%I<FXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I
M='5D97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN
M=&\@<V]M92!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H
M870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4W,0IM<V=I9"`B4&QE
M87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`BS.[K_RP@
MXOKBY>3E\N4@[.7QY?8@Z"#C[N3H[>`N(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*(RP@9G5Z>GD*;7-G:60@(E!L
M96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S
M='(@(LSNZ_\L(.+ZXN7DY?+E(.SE\>7V(.@@X^[DZ.W@+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#$*(RP@9G5Z>GD*;7-G:60@(E!L96%S
M92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(LSNZ_\L(.+Z
MXN7DY?+E(.SE\>7V(.@@X^[DZ.W@+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(V-C`*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L
M(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-3$*(RP@9G5Z
M>GD*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@
M(LSNZ_\L(.+ZXN7DY?+E(.SE\>7V(.@@X^[DZ.W@+B(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E
M(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE
M(&%N9"!P87-S=V]R9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(B(*(E!L96%S92!R96%D('1H
M92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R
M;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*(LSNZ_\L(._P
M[O?E\N7RY2#QZ^7D[>C_\B#RY>KQ\BX@(,+HY2#2T-_!PL`@Y.`@\>4@\?KC
MZ^#QZ/+E(/$@\_'K[N+H__+@(.?@("(*(NCG[^[KY^+@[>4@[>`@\>CQ\N7L
MX/+@+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G
M97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y
M(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0HC+"!F=7IZ>0IM<V=I
M9"`B4&]L86YD(@IM<V=S='(@(M/DY>'EZ^7MZ"(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X-PIM<V=I9"`B4&]L;',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM
M86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A
M8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@
M96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Y.`IM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP:'`Z.3@*;7-G
M:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-E
M<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S
M97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C(U"FUS9VED(")0<F5S<W5R92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U.0IM<V=I9"`B4')E<W-U
M<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S-0HC+"!F=7IZ>0IM<V=I9"`B4')E<W-U<F4Z
M("(*;7-G<W1R("+/X/#NZ^`Z("(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA
M9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,S8R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,S8V"B,L(&9U>GIY"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM
M<V=S='(@(L_PY>?E[?+@]NCH(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S
M"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(")0<F]B
M;&5M(@IM<V=S='(@(L_P[N'KY>P_(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP
M:'`Z,3(V"B,L(&9U>GIY"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM
M<V=S='(@(L_ZZ^WN(.[OZ/'@[>CE.B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS-CD*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3$@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$X.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@U"FUS
M9VED(")0<F]M<'0@=&5X="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*
M;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0T"FUS9VED(")0=6)L
M:6,@2V5Y($EN9F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER
M(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("+*Z_[W[N+@
M(.3B[NGJX"#O\^'KZ/?E[2_WX/'RY>T@ZNO^]R#MY2#AY?CE(./E[>7PZ/#@
M[>`N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,@HC+"!F=7IZ>0IM<V=I9"`B46%T87(B"FUS
M9W-T<B`BQ.#M[>@B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C,*;7-G:60@
M(E%U97)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW
M,`IM<V=I9"`B475O=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!
M(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(V-`IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0S"B,L(&9U>GIY"FUS9VED(")286EN(@IM<V=S='(@(LKNY?3H]NCE
M[?(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M-`IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!,871E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0V"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I9"`B
M4F%I;B!A;F0@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")2
M86YD;VT@1F]R='5N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(LKNY?3H]NCE
M[?(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-"!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM
M<V=I9"`B4F5A9"(*;7-G<W1R("+7Y?+E[>4B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PHC+"!F=7IZ>0IM<V=I9"`B4F5A
M9"!M97-S86=E<R(*;7-G<W1R("+/Z/'L[B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L
M;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE
M+B(*;7-G<W1R("+(\>K@\N4@Y.`@Z.?R\.CE\N4@)7,@Z^@_(-+@Y^@@[N_E
M\.#VZ/\@[>4@[.[FY2#DX"#QY2#B^O#MY2#MX.?@Y"XB"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_
M(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(LCQ
MZN#RY2#DX"#HY_+PZ.7RY2`E<R#KZ#\@TN#GZ"#N[^7PX/;H_R#MY2#L[N;E
M(.3@(/'E(.+Z\.WE(.W@Y^#D+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@
M86-T:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@
M(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"B,L(&9U>GIY"FUS9VED(")2
M969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R("+.[_#E\>WH(-#EY_[LY2#H
MY^/KY>3@.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-"!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$S"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,S4*;7-G:60@(E)E9V5X(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,R-#D*;7-G:60@(E)E;&%T:6]N<VAI<"!"
M<F]W<V5R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(RP@9G5Z
M>GD*;7-G:60@(E)E;&]A9"(*;7-G<W1R("+7Y?+E[>4B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,R-@HC+"!F=7IZ>0IM<V=I9"`B4F5M87)K<R(*;7-G
M<W1R("+.\NSE\NKH(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-`HC
M+"!F=7IZ>0IM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`BPN#XZ/+E
M(/'Z\.+Z\.@Z(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T
M"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO
M<F1E*3HB"FUS9W-T<B`BP.3PY?$@55),("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*3HB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*;7-G
M:60@(E)E;6]V92(*;7-G<W1R("+/\.7LX/7MZ"(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;&%Y;W5T+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E($)L
M;V-K(@IM<V=S='(@(L_PY>S@]>WH(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4U-PHC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E
M(&-O;'5M;B(*;7-G<W1R("+/\.7LX/7MZ"#PY>?^[.4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0P"B,L(&9U>GIY"FUS
M9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R("+([?3N\.S@]NC_(.?@
M(,+@\2(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"B,L(&9U
M>GIY"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R("+/\.7LX/7MZ"#PY>?^
M[.4B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")296UO
M=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"B,L(&9U>GIY"FUS9VED(")296UO
M=F4@=&AE(@IM<V=S='(@(L_PY>S@]>WH(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO
M=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*(RP@9G5Z>GD*
M;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(L_PY>S@]>WH(._N\O#EX>CR
MY>LZ("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU
M"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R
M("+/\.7LX/7MZ"#O[O+PY>'H\N7K.B`E<R(*"B,Z(&9R86UE=V]R:R]24$,O
M4E!#+WAM;')P8RYP:'`Z,3,X"B,L(&9U>GIY"FUS9VED(")297%U97-T(&-O
M=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G
M<W1R("+-X"#GX._H\N+@[>7R[B#MY2#AY?CE(.[RX^[B[O#E[>XZ("(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*(RP@9G5Z>GD*;7-G
M:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS
M9W-T<B`BS>`@Y^#OZ/+BX.WE\NX@[>4@X>7XY2#N\N/NXN[PY>WN.B`B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-"!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C4Q,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`BS>7NX?7NY.CLZ/\@)W!O<G0G(.WE(.4@Y^#DX.3E
M[2#B^N(@5D93(.KN[?3HX_/PX/;H__+@+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z-C<U(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,P
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E
M8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+-Y>[A]>[D
MZ.SH_R`G<&]R="<@[>4@Y2#GX.3@Y.7M(.+ZXB!61E,@ZN[M].CC\_#@]NC_
M\N`N(@H*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S@Q"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I
M9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+-Y>[A]>[DZ.SH_R`G
M<&]R="<@[>4@Y2#GX.3@Y.7M(.+ZXB!61E,@ZN[M].CC\_#@]NC_\N`N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S,U"FUS9VED
M(")297%U:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SD*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(P('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-#8*(RP@9G5Z>GD*;7-G:60@(E)E<V5T(%!A
M<W-W;W)D(@IM<V=S='(@(L_@\.[KX"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C(W"B,L(&9U>GIY"FUS9VED(")297-E="!9;W5R(%!A<W-W
M;W)D(@IM<V=S='(@(L_N\N+Z\.3E\N4@[^#P[NO@\N`B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3,P"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H
M96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L
M=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@
M=&\@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T
M:6]N(@IM<V=S='(@(LKN[?3HX_/PX/;H_R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S(*(RP@9G5Z>GD*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@
M3W!T:6]N<R(*;7-G<W1R(")$2%1-3"!2:6-H(%1E>'0@\.7DX.KR[O`B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(Q"FUS9VED(")2:6=H="!H96%D97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-PHC
M+"!F=7IZ>0IM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(DQI9VAT($)L
M=64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(M#NZ_\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R
M"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,C4*;7-G:60@(E)O=&%T92`Q.#`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(R,@IM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R.`IM<V=I
M9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0
M<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T
M:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S
M"B,L(&9U>GIY"FUS9VED(")2=6QE<R(*;7-G<W1R("+0[NO_(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM
M<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@
M8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS
M9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P"B,L(&9U>GIY"FUS
M9VED(")2=6XB"FUS9W-T<B`B4W5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B
M4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*
M(RP@9G5Z>GD*;7-G:60@(E)W86YD82(*;7-G<W1R("+7Y?+E[>4B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-
M24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S"B,L(&9U>GIY"FUS
M9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`BP_#E^.K@
M(._PZ"!334E-12#J\.CO\NCPX.WE\NX@[>`@[^CQ[.XN(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0HC+"!F=7IZ>0IM<V=I9"`B4T%3
M3"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("+#
M\.7XZN`@[_#H(.CDY>WRZ/3HZN#VZ/\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-3`T"B,L(&9U>GIY"FUS9VED(")335,@365S<V%G:6YG(@IM
M<V=S='(@(L_H\>SN(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED
M(")344P@4VAE;&PB"FUS9W-T<B`B4U%,(%-H96QL(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S(X,PIM<V=I9"`B4U%,('-T871E;65N="!F;W(@
M=F%L=64@;&]O:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#,Q"FUS9VED(")34T@B"FUS9W-T<B`B4U-((@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B
M:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R("(B"@HC.B!L:6(O
M87!I+G!H<#HQ-3,*(RP@9G5Z>GD*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T
M<B`B4U%,(%-H96QL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC
M96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE
M(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I
M9"`B4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N
M($UA<FEN;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")386\@
M5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I
M82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E
M(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C(Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*
M;7-G<W1R("+.[_#E\>WH("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI
M;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(L[O
M]NCH(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I9"`B(@HB
M4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@
M=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`BRN[M].CC\_#@]NC_(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E-C871T
M97)E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(P"FUS9VED(")396%R8V@@16YG
M:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.3<S"B,L(&9U>GIY"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`BR.?A
MY?#H(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0X-`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R("+(
MY^'E\.7RY2#Q^O#B^O`B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(LCG
MX>7PY?+E(./P\^_@(.?@(.3NX>#B_^WE(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S
M='(@(LCGX>7PY?+E(.WNXB#O\.CRY>;@\N7K(.W@(./P\^_@(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")396QE8W0@82!S
M97)V97(B"FUS9W-T<B`BR.?AY?#E\N4@\?KPXOKP(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@
M861D(@IM<V=S='(@(LCGX>7PZ"#O[O+PY>'H\N7K(.?@(.3NX>#B_^WE(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PHC
M+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R("+(Y^'E\.@B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8S"B,L(&9U>GIY"FUS9VED
M(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`BR.?AY?#E
M\N4@].[P[.#R(.?@(,3@\N#RX#HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.#<S"B,L(&9U>GIY"FUS9VED(")396QE8W0@
M86X@;V)J96-T(@IM<V=S='(@(LCGX>7PY?+E(.WNXB#O\.CRY>;@\N7K(.W@
M(./P\^_@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C8W.`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B
MR.?AY?#E\N4@[>[B(._PZ/+EYN#RY>L@[>`@X_#S[^`B"@HC.B!S97)V:6-E
M<R]K97EB;V%R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(B(*(E-E;&5C="!T
M:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@
M66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@
M=&5X="!A<F5A+B(*;7-G<W1R("(B"B+(Y^'E\.7RY2#MY>[A]>[DZ.SH\N4@
MPN@@\>CLXN[KZ"X@T>OEY"#R[N+@(./H(.KN[^CPX.GRY2#N\B#RY>KQ\N[B
M[O+N(._NZ^4N(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G
M:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(LCGX>7P
MY?+E(,3@\N`@\.#GY.7KZ/+EZSHB"@HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T
M<B`BR.?AY?#E\N4@].[P[.#R(.?@(,3@\N#RX#HB"@HC.B!T96UP;&%T97,O
M<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")396QE8W0@=&AE
M(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(E-E
M;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S='(@(LCGX>7PY?+E(,3@
M\N`@\.#GY.7KZ/+EZSHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR
M-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`BR.?A
MY?#E\N4@].[P[.#R(.?@(-?@\>`Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N
M(@IM<V=S='(@(LCGX>7PY?+E(.3BY2#Q^N+OX.3@^>@@[^[KY?+@.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#8*;7-G:60@(E-E;&5C="!Y;W5R
M(&-O;&]R('-C:&5M92XB"FUS9W-T<B`BR.?AY?#E\N4@XN#XX/+@(/'UY>S@
M(.?@(/;BY?+NXN7RY2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0X
M"FUS9VED(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S
M='(@(LCGX>7PY?+E(._PY>3O[O?H\N#MZ/_R(.[R(,+@\2#EY^CJ.B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD
M(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HQ,#,Y"FUS9VED(")396YD(%--4R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$V"FUS9VED(")396YS
M;W(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW,PHC+"!F=7IZ>0IM<V=I9"`B4V5P=&5M8F5R(@IM<V=S
M='(@(M?KY>WNXN4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS
M9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-C$*;7-G:60@(E-E<G9E<B!D871A('=R;VYG
M(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I
M;VYS+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G
M<W1R("+`Y.SH[>CQ\O#H\.#MY2#MX"#O\.#BX/+@(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")3
M97-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP
M.C$T-0HC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`BS_#@XN`B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$T"B,L(&9U>GIY"FUS
M9VED(")3970B"FUS9W-T<B`BR.?AY?#H(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<V"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@
M<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@
M(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S
M<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#0*(RP@9G5Z>GD*;7-G:60@(E-E="!Y;W5R('!R969E
M<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS
M9W-T<B`BR.?AY?#E\N4@[_#EY._N]^CRX.WH__(@[O(@PN#Q(.7GZ.HZ(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX"FUS9VED("(B"B)3970@>6]U
M<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F
M<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T
M<B`B(@HBQ^#DX.GRY2#"X/CE\NX@[>#WX.OM[B#O\.CK[N;E[>CE+"#Q]>7L
MX"#GX"#VXN7R[N+E+"#N[_#E\>W_XN#MY2#MX"`B"B+Q\O#@[>CVX/+@(.@@
MY/#SX^@@[N_VZ.@@Y^`@Y.CQ[^OE_RXB"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C<U"FUS9VED(")3971U<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G
M<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@V"FUS9VED(")3979E<F%L(&QO8V%T
M:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.38*;7-G:60@(E-H;W!P
M:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C0S"B,L(&9U>GIY"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@
M(LKPX/+J[B#PY>?^[.4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T
M-@IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO
M<W0@;&EN:W,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(L_NZN#GXN#M
MY2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H
M;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H
M92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y,`IM<V=I9"`B4VAO=R!L
M87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P
M=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X,3,*(RP@9G5Z>GD*;7-G:60@(E-H;W<@<&EC
M:V5R(@IM<V=S='(@(LCGX>CPX.WE(.W@(/;B__(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3(V"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@
M;65N=2!B87(_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O
M;B!T:&4@;&5F=#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H
M92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@
M4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3
M:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8S"FUS9VED(")3:&]W('5P
M;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R
M("+/[NK@Y^+@[>4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU,0IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I
M9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S(&EN('1H
M92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HT.#`*;7-G:60@(E-H<FEN:R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW-S0@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#,V"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.CDR,B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HY.#0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z,3`T-R!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HQ,#@W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q
M,38@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$T.0IM<V=I
M9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O
M9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G
M:60@(E-I97)R82!,96]N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z,C8U"FUS9VED(")3:6=N('5P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R"FUS
M9VED(")3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HW,3$*;7-G:60@(E-I9VYA='5R92!!;&=O<FET
M:&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@W(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.3,P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*
M;7-G:60@(E-I>F4B"FUS9W-T<B`BT.#G[.7P(@H*(SH@=&5M<&QA=&5S+VUA
M:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I
M;G1E;F%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO
M=F%K:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N
M:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(E-N;W<B"FUS9W-T<B`BS^[J
MX.?BX.WE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-34*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W
M(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*;7-G:60@(E-N;W<@9&5P=&@Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM<V=I
M9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C8*
M;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ
M.#D*(RP@9G5Z>GD*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(L'H
MY^WE\2#@Y/#E\2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC
M82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I
M9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H
M(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE
M<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E
M;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T
M=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,34*;7-G:60@(E-P86-E<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.CDX"FUS9VED(")3<&%M(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R
M86-T97(@26YP=70B"FUS9W-T<B`BPOKBY>;DX.WE(.W@(/'OY?;HX.OMZ"#Q
MZ.SB[NOH(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8V"B,L(&9U>GIY"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`BR.?A
MY?#E\N4@ZN[K[NWH.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E-P;W)T
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S,@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B4W1A;F1A
M<F0B"FUS9W-T<B`B)7,@T?+@[>3@\/(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(X,#D*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(E-T871E
M(&]R(%!R;W9I;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S
M971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-0HC+"!F=7IZ>0IM<V=I
M9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`BR.WT[O#LX/;H_R#GX"#"X/$B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,@HC+"!F
M=7IZ>0IM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`BP>CG[>7Q(.#D
M\.7Q(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@;&ES="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S"FUS
M9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"B,L(&9U>GIY
M"FUS9VED(")3=2(*;7-G<W1R(")3=6XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C
M=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("+1Z_/XX/+EZ__R("5S
M(.WE(.4@[>#LY?#E[2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")3=6)J96-T(@IM<V=S
M='(@(LCGX>7PZ"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*;7-G:60@(E-U
M8FUI="(*;7-G<W1R("+(Y^_PX/+H(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@
M7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I
M;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(*(RP@9G5Z>GD*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R("+(Y^_PX/+H
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-`HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X
M"FUS9VED(")3=6-C97-S(@IM<V=S='(@(M/Q[^7U(@H*(SH@861M:6XO=7-E
M<BYP:'`Z.#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`BT_'O
MY?CM[B#D[N'@XN7M("<E<R<@ZOKL(/'H\?+E[.#RX"XB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`BT_'OY?CM[B#O\.7LX/7MX/(@)R5S)R#N\B#Q
MZ/'RY>S@\N`N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M
M<R]D96QE=&4N<&AP.C0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S='(@(M/Q[^7X[>X@
MZ.?R\.CR("<E<R<N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S
M7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("+3\>_E^.WN(._PY>S@]>W@
M\B`G)7,G(.[R(/'H\?+E[.#RX"XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A
M=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@
M=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S='(@(M/Q
M[^7X[>X@X>7XY2#NX>WNXN7M("<E<R<N(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G
M<W1R("+3\>_E^.WN(.'E^.4@[N'M[N+E[2`G)7,G+B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#0*(RP@9G5Z>GD*;7-G:60@(E-U9&%N(@IM<V=S='(@(E-U;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*
M(RP@9G5Z>GD*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`BRO#@\NKN(/#EY_[L
MY3HB"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@(E-U;B!2
M:7-E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`HC
M+"!F=7IZ>0IM<V=I9"`B4W5N(%-E="(*;7-G<W1R(")3=6XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0HC+"!F=7IZ>0IM
M<V=I9"`B4W5N;GDB"FUS9W-T<B`B4W5N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(Q-@HC+"!F=7IZ>0IM<V=I9"`B4W5N<FES92(*;7-G
M<W1R(")3=6XB"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,34*;7-G
M:60@(E-U;G)I<V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C$Y"B,L(&9U>GIY"FUS9VED(")3=6YS970B"FUS9W-T
M<B`B4W5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.`IM
M<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W.`IM
M<V=I9"`B4W5P<&]R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"B,L(&9U
M>GIY"FUS9VED(")3=7)I;F%M92(*;7-G<W1R("+AY><@Z.SE(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*(RP@9G5Z>GD*;7-G
M:60@(E-U<FYA;64B"FUS9W-T<B`BX>7G(.CLY2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*
M;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,@IM<V=I
M9"`B4WEN8TU,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME
M>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T
M97)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@
M07)A8B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,0IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M
M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8S"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,38V"B,L(&9U
M>GIY"FUS9VED(")44U8@9FEL92(*;7-G<W1R("+TX.GK(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U1A8FQE+G!H<#HQ,S0*(RP@9G5Z>GD*;7-G:60@(E1A8FQE
M(@IM<V=S='(@(L3K^N;M[O'R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R
M=&EE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O
M=&%B;&5S970N<&AP.C4W"FUS9VED(")486)L92!3970B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-"!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A
M:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.34*(RP@9G5Z>GD*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`BR.?O[NOG
MXN#MY3HZ(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDY-B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3@W"FUS9VED(")487-K<R(*;7-G<W1R("+'
MX.3@]^@B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M,PIM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(Y,`IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,30*;7-G
M:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,C,*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,
M;R5S*2`F9&5G.R5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T
M92]496UP;&%T92YP:'`Z-C@W"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!L
M871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(")496UP;&%T92!!9&UI
M;FES=')A=&EO;B(*;7-G<W1R("+`Y.SH[>CQ\O#H\.#MY2#MX"#O[O+PY>'H
M\N7KZ/+E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,V"B,L(&9U>GIY"FUS9VED(")497AT
M(@IM<V=S='(@(M'@[.X@\N7J\?(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S<U"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`BT>#L[B#RY>KQ\B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S0*(RP@9G5Z>GD*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`BT>#L
M[B#RY>KQ\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@
M(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G
M:60@(E1H86EL86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDX.`IM<V=I9"`B5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES
M=&5M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C@R,`IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G
M<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]";V]K+G!H<#HQ,CDR
M"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D
M+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*
M;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S
M=6-C97-S9G5L;'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O
M;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA
M<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D
M<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N
M9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO
M="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T
M:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0HC+"!F=7IZ>0IM<V=I9"`B5&AE
M(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E
M<W,@8F]O:RXB"FUS9W-T<B`B(@HBTN7GZ"#DX.WMZ"#GX"#J[NWRX.KR(.'_
M]>`@\_'OY?CM[B#D[N'@XN7MZ"#J^NP@PN#XX/+@(._P[N/PX.S@+B#*Z^CJ
M[>7RY2#O[BTB"B+D[NOS(.?@(.3@(.+HY.CRY3HB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38Y"FUS9VED("(B"B)4:&4@9&5T86-H
M960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@
M=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"B+/\.CJ\.7OY>WH__(@
M4$=0(._NY._H\2#E(.WE[N'U[N3H["#GX"#DX"#QY2#O\.[BY?#H(._NY._H
M\>#M[O+N(._H\>SN+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK
M(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C
M:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP
M:'`Z,3$S"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E
M(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("+*\.CO\NCPX.WE
M\NX@Z.?H\>KBX"#J\.CO\NCPX.W@('=E8B#B\/KGZN`N(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S4@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HU,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO
M=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V."!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S
M:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,3D*;7-G:60@(E1H92!F
M:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.#`*(RP@9G5Z>GD*;7-G
M:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")-4RU4
M3D5&(._PZ.KPY>_E[>C_\B#TX.GK(.WE(/'ZY/KPYN#XY2#DX.WMZ"XB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS
M9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M
M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4
M:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M
M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B
M=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@
M;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@
M961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE
M<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y
M(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T
M:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@
M8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL
M('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O;FQY
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA
M<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM
M<V=S='(@(B(*(LSE\?+N[^[K[N;E[>CE\NX@[>`@1VYU4$<@].#IZ^`@\O#_
MX>+@(.3@(.'ZY.4@Y.#DY>UO(.W@($-R>7!T7W!G<#HZ(&-L87,B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S
M=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES
M(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@
M;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@W-PIM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN
M:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I9"`B5&AE
M(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R("+2
MX.?H(/'R[NGM[O'R(/+P_^'BX"#DX"#E(/?H\>ON+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,0HC+"!F=7IZ>0IM<V=I9"`B
M5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?
M0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`BS.[D\^OZ\B!/<&5N4U-,
M(.4@[>7NX?7NY.CL(.?@($-R>7!T7W-M:6UE.CH@8VQA<W,N(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E
M9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L
M;&]W86)L92!S:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H
M)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HB
MS_#NX_#@[.#RX"P@ZN[_\NX@\>OSYN@@Y^`@[^[JX.?BX.WE(.W@(/+NY^@@
M\NCO(.3@[>WH("@E<RD@[>4@X>7XY2#N\NKPZ/+@("(*(N(@\>CQ\N7LX/+@
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#4T"FUS9VED(")4
M:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T
M97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F
M="!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H
M="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HT-#8*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B
M92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N
M(')E;6]V960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C,S,`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@9&]E
M<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z,3<W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R
M(")(;W)D92!03R#TX.GK(.?@(.ONZN#KZ.?@]NC_("5S(.WE(/'Z^>7Q\N+S
MXN`Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Q,0IM<V=I9"`B
M5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O
M;B!T:&4@<V-R965N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P
M(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED
M(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1&%T82]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A
M<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$
M871A+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE
M(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C0V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HU-@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$U(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3D*;7-G:60@(E1H92!W96%T
M:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC
M.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$W.`HC+"!F
M=7IZ>0IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*
M;7-G<W1R("+-_^S@(.3B[NGJZ"P@ZN[H\NX@Y.`@X?KDX/(@[^[JX.?@[>@@
MXB#KZ.WH__+@+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C,T,@IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E
M(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(LW_[.`@Y.+NZ>KH+"#J[NCR
M[B#DX"#A^N3@\B#O[NK@Y^#MZ"#B(.OH[>C_\N`N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9
M;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N
M=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@HBR.S@(/+B^O#DY2#L[>[C
M[B#QZ.SB[NOH(.(@\N[BX"#O[NOE+B#"^N+EZ^@@\?+E("5S(/'H[.+NZ^`[
M(/+P_^'BX"#DX"`B"B+B^N+EY.7RY2#O[BWLX.OJ[B#N\B`E<RXB"@HC.B!S
M:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S
M7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`BP_#E^.K@(._PZ"#D[N'@
MXO_MY2#MX"`G)7,G(.KZ["#QZ/'RY>S@\N`N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@
M=&AE('-Y<W1E;3H@(@IM<V=S='(@(L/PY?CJX"#O\.@@[_#E[.#UXN#MY?+N
M(.W@("<E<R<@[O(@\>CQ\N7LX/+@+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P
M,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T
M<B`BP_#E^.K@(._PZ"#O\.7LX/7BX.WE\NX@[>`@)R5S)R#N\B#QZ/'RY>S@
M\N`N(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<
M(CH@)7,B"FUS9W-T<B`BP_#E^.K@(._PZ"#N[_#E\>W_XN#MY2#MX"`G)7,G
M.B`E<R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@
M(L/PY?CJX"#O\.@@Z.?O\.#YX.WE\NX@[>`@].#IZ^`Z("5S(.WE(.'E^.4@
MZ.?O\.#RY>TN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z
M.#@Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H
M86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM
M<V=S='(@(B(*(LCLX/CE(._P[N'KY>P@[_#H(.CG[_#@^>#MY?+N(.W@(/3@
MZ>O@+B`E<R#E(._N+>/NZ__L(.[R(.S@ZO'H[.#K[>X@(@HBY.[O\_'RZ.SH
M_R#PX.?LY?`@*"5D(.'@Z?+@*2XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"
M<F]W<V5R+G!H<#HX.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A
M<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`BP_#E^.K@(._P
MZ"#HY^_PX/G@[>7R[B#MX"#TX.GKX"X@)7,@X>7XY2#QX.SN(.[R]^#Q\N@@
MZ.?O\.#RY>TN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`BP_#E^.K@
M(._PZ"#O\.[BY?#JX/+@(.W@(/+NXN`@[^CQ[.XN(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R
M("+#\.7XZN`@[_#H(.CL[^[P\B#MX"#DX.WMZ"#GX"#J[NWRX.KRZ"XB"@HC
M.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*(RP@9G5Z>GD*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A
M<B!D871A+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CL[^[P\NCPX.WE(.W@(.CG
MX?#@[>CRY2#DX.WMZ"#GX"#JX.OE[>3@\"XB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C@P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@
M=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@
M82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*
M(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@
M861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA
M=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T,`HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.SO
M[O#R(.W@(.3@[>WH(.?@(.KN[?+@ZO+H+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"B,L(&9U>GIY"FUS9VED("(B
M"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO
M;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("+#\.7X
MZN`@[_#H(.CL[^[P\B#MX"#DX.WMZ"#GX"#J[NWRX.KRZ"XB"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H
M:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E
M<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E
M(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(M+NXN`@[>4@Y2#BX.OH
MY.7M(')A<B#@\/7HXBXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B
M92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R("+2[N+@(.WE(.4@XN#KZ.3E
M[2!Z:7`@].#IZRXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,30U
M"B,L(&9U>GIY"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V
M86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`BTN[BX"#MY2#E(.+@Z^CDY>T@
M<F%R(.#P]>CB+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H
M:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO
M+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P
M.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@
M05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H
M92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE
M(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B
M"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,#@V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C4V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#4@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-34W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,SD*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU."!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,#`U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,CD@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`W.`HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,30Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C$*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q,"!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-#4T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3<@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R.`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,3,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,#8*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q-"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS.#(R"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D
M+B(*;7-G<W1R("+2[N+@(._NZ^4@Y2#MY>[A]>[DZ.SN+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`BTN[BX"#O[NOE(.SN
MYN4@Y.`@\?KD^O#FX"#QX.SN(/;EZ^@@]^CQZ^`N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C0Q.`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL
M>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`BTN[B
MX"#O[NOE(.SNYN4@Y.`@\?KD^O#FX"#QX.SN(/?H\>O@(.@@Y.+NY?+N]^CE
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30*(RP@9G5Z>GD*
M;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU
M97,N(@IM<V=S='(@(M+NXN`@[^[KY2#L[N;E(.3@(/'ZY/KPYN`@\>#L[B#M
M[NSE\.`N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,PIM<V=I
M9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A
M=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`BTN[BX"#O[NOE(/+P_^'B
MX"#DX"#E(.?@[^7RX/\@Z.OH(.CM\N7PXN#K(/#@Y^3EZ^7M(/'OZ/'ZZB#O
M\.[LY>WKZ.+H(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@Y"B,L
M(&9U>GIY"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB
M97(N(@IM<V=S='(@(M+@Y^@@\?+NZ>WN\?(@\O#_X>+@(.3@(.4@]^CQZ^XN
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@S-@IM<V=I9"`B(@HB
M5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!2
M1T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C$*;7-G:60@
M(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T
M<B`BTN#GZ"#T[O#LX"#BY??E(.'E^.4@[N'PX.'N\N7MX"XB"@HC.B!T96UP
M;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&ES(&ES("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C0U.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@
M2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y
M;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A
M;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F
M('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DQ
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E
M;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N
M(@IM<V=S='(@(M+NXN`@]^CQZ^X@\O#_X>+@(.3@(.4@[^[MY2#EY.CMZ/;@
M+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HT
M-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD
M(&=Z:7`@9FEL97,N(@IM<V=S='(@(M+NY^@@\?KPXOKP(.WE(.SNYN4@Y.`@
MY.7J[NSO\.7QZ/#@('II<"#H(&=Z:7`@].#IZ^[BY2XB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S
M>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI
M<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R("+2X.?H(/'R[NGM
M[O'R(/+P_^'BX"#DX"#E(/?H\>ON+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C
M;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@
M8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@
M(E1H=6YD97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(S-`IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-#(X('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B5&EM92(*;7-G<W1R("+$Z_KF[>[Q
M\B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#8*;7-G:60@(E1I
M;64@5')A8VMI;F<B"FUS9W-T<B`BS_#N\>OEY/_BX.WE(.WE(.+PY>SE(@H*
M(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,Y"FUS
M9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P
M"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R("+$Z_KF[>[Q\B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G
M:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H
M;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME
M>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,Q,0HC+"!F=7IZ>0IM<V=I9"`B5&]D87DB
M"FUS9W-T<B`B("CD[>7Q*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"B,L(&9U>GIY"FUS9VED(")4;V=O
M(@IM<V=S='(@(LCG]>[D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA
M=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S$S"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P
M"FUS9VED(")4;VYG82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B5')A
M;G-L871I;VYS(@IM<V=S='(@(L_PY>?E[?+@]NCH(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A
M;'-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,0HC+"!F=7IZ>0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(D=R97DB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B5'5R:VES:"`H25-/+3@X
M-3DM.2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE
M;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS
M(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q
M"FUS9VED(")4=79A;'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#
M3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-CD*;7-G:60@
M(E4N5BX@:6YD97@Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F
M;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDW"B,L(&9U>GIY"FUS9VED(")54DPZ(@IM<V=S='(@(E523"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$R"B,L(&9U>GIY"FUS9VED(")5:W)A:6YE(@IM<V=S='(@(L_NY/?E\/+@
M[>@B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,3(*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS
M9W-T<B`BP_#E^.K@(._PZ"#WY?+E[>7R[B#MX"!V9G-R;V]T(._@[^K@+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B
M56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG
M;FEN9R!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HS.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG
M92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,X-2!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E
M('1O("5S+B(*;7-G<W1R("+-Y>+ZY^SNYNWN\?(@Y^`@XO#ZY^K@(/$@4U%,
M(/'Z\.+Z\"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S,@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I
M;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.?R\.CB
MX.WE("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C8X."!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S
M+R5S7"(N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.?R\.CBX.WE("<E<R<Z("5S
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HT,S4*;7-G:60@
M(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(LWE
MXOKG[.[F[>[Q\B#GX"#B\/KGZN`@\2!344P@\?KPXOKP+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,Y"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`BS>7B^N?L[N;M[O'R
M(.?@(.+P^N?JX"#Q(%-13"#Q^O#B^O`N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C(U(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S
M,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3DV(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C(P.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE
M('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(LWEXOKG[.[F[>[Q\B#GX"#B
M\/KGZN`@\2!344P@\?KPXOKP+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,S8U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("+#\.7X
MZN`@[_#H(/?E\N7MY?+N(.W@('9F<W)O;W0@[^#OZN`N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,S4T(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C(U-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R("+#\.7XZN`@[_#H(/?E\N7MY?+N(.W@('9F<W)O
M;W0@[^#OZN`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R
M-`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB
M"FUS9W-T<B`BP_#E^.K@(._PZ"#WY?+E[>7R[B#MX"!V9G-R;V]T(._@[^K@
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@V"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD
M97(@7"(E<UPB+B(*;7-G<W1R("+#\.7XZN`@[_#H(/?E\N7MY?+N(.W@('9F
M<W)O;W0@[^#OZN`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,C8U"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&
M4R!F:6QE+B(*;7-G<W1R("+-Y>+ZY^SNYNWN\?(@Y^`@XO#ZY^K@(/$@4U%,
M(/'Z\.+Z\"XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R
M+G!H<#HW-@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP
M:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A
M=&$N(@IM<V=S='(@(L/PY?CJX"#O\.@@[O+BX/#_[>7R[B#MX"#J[NSO\.7Q
MZ/#@[2#@\/7HXBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R
M-"!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Y.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D
M:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R("+#\.7XZN`@[_#H(/?E
M\N7MY?+N(.W@('9F<W)O;W0@[^#OZN`N(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM
M<V=S='(@(L/PY?CJX"#O\.@@Z.?R\.CBX.WE("<E<R<Z("5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,S0*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H
M92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(L/PY?CJX"#O\.@@
M]^7RY>WE\NX@[>`@=F9S<F]O="#OX._JX"XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,S0X(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HS-3(*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`BP_#E^.K@(._P
MZ"#WY?+E[>7R[B#MX"!V9G-R;V]T(._@[^K@+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C,S-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,S4@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,S0T"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(L/PY?CJX"#O\.@@
M]^7RY>WE\NX@[>`@=F9S<F]O="#OX._JX"XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C0Q-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0R
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`BP_#E^.K@(._PZ"#HY_+P
MZ.+@[>4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HR,#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CG
M\O#HXN#MY2`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR.#@*(SH@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HQ.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,X,PHC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R("+#\.7X
MZN`@[_#H(.CG\O#HXN#MY2`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C(T-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B
MP_#E^.K@(._PZ"#HY_+PZ.+@[>4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HT,#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS
M9W-T<B`BP_#E^.K@(._PZ"#HY_+PZ.+@[>4@)R5S)SH@)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,#,*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@
M(L/PY?CJX"#O\.@@]^7RY>WE\NX@[>`@=F9S<F]O="#OX._JX"XB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8P,PIM<V=I9"`B56YA
M8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#4Q(&9R86UE=V]R
M:R].971?24U34"])35-0+T%U=&@N<&AP.C$Q.`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@
M)7,N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.?R\.CBX.WE("<E<R<Z("5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$V-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,3<Q"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB
M"FUS9W-T<B`BS>7B^N?L[N;M[O'R(.?@(.+P^N?JX"#Q(%-13"#Q^O#B^O`N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C$P,@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C8T."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.?R\.CBX.WE("<E<R<Z("5S
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W-R!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ,S,*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R("+#\.7XZN`@
M[_#H(.[RXN#P_^WE\NX@[>`@ZN[L[_#E\>CPX.T@X/#UZ.(N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#`@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HW,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N
M(@IM<V=S='(@(L/PY?CJX"#O\.@@[O+BX/#_[>7R[B#MX"#J[NSO\.7QZ/#@
M[2#@\/7HXBXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI
M=F4N(@IM<V=S='(@(L/PY?CJX"#O\.@@[O+BX/#_[>7R[B#MX"#J[NSO\.7Q
MZ/#@[2#@\/7HXBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#,U"FUS
M9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL
M960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8V
M"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H
M*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA
M;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*(RP@9G5Z>GD*;7-G
M:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R("+#\.7XZN`@[_#H
M(.CG\O#HXN#MY2`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HV-CD*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T
M(&1I<F5C=&]R>2XB"FUS9W-T<B`BP_#E^.K@(._PZ"#WY?+E[>7R[B#MX"!V
M9G-R;V]T(._@[^K@+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S
M('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Y
M,PHC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T
M;W)Y+B(*;7-G<W1R("+#\.7XZN`@[_#H(/?E\N7MY?+N(.W@('9F<W)O;W0@
M[^#OZN`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,CD*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(L/PY?CJX"#O\.@@]^7RY>WE\NX@
M[>`@=F9S<F]O="#OX._JX"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C(V-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M-C$P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@
M)7,O)7,N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.?R\.CBX.WE("<E<R<Z("5S
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(S(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HR,3,*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C0U,B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,C@U"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$*(RP@
M9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM<V=S
M='(@(L/PY?CJX"#O\.@@]^7RY>WE\NX@[>`@=F9S<F]O="#OX._JX"XB"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP
M:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G
M+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CG\O#HXN#MY2`G)7,G.B`E<RXB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS
M9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*
M;7-G<W1R("+#\.7XZN`@[_#H(._PY>+NY.`@[>`@\N[GZ"!7;W)D(.3NZO/L
MY>WR(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-#D@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HQ-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(L/PY?CJX"#O\.@@Z.?R\.CBX.WE("<E<R<Z("5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W.0IM<V=I9"`B56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@Q(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$T,PIM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX
M-#$*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL
M;"!B92!E>&-E961E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM
M<V=S='(@(L_NY/?E\/+@[>@B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN
M8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD
M;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y,`HC+"!F=7IZ>0IM<V=I9"`B
M56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N
M.B`B"FUS9W-T<B`BS>7BX.OHY.7M(.[RX^[B[O`@[O(@\?KPXOKPX"(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-`HC+"!F=7IZ>0IM
M<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM
M<V=S='(@(LWEXN#KZ.3E[2#N\N/NXN[P(.[R(/'Z\.+Z\.`B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0HC+"!F
M=7IZ>0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R("+O\.[BX.OE[>XB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B56YI8V]D92`H551&+3@I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%
M;6ER871E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E
M9"!+:6YG9&]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N
M:71E9"!3=&%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B
M56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV.2!L:6(O0FQO
M8VLO;65T87(N<&AP.C<Q"FUS9VED(")5;FET<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@
M240I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@
M*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$U.0IM<V=I9"`B56YK;F]W;B!L;V-A=&EO
M;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"B,L(&9U>GIY"FUS9VED(")5
M;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R("+-Y>KN\.7J
M\NW@(._@\.[KX"#HZ^@@[^[R\.7AZ/+EZ_'J[B#H[.4A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS
M9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C(Y-@HC+"!F=7IZ
M>0IM<V=I9"`B56YN86UE9"(*;7-G<W1R("+AY><@Z.SE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB
M56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]0
M87-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N
M("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA
M+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T
M('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"B,L
M(&9U>GIY"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R("+"[/KJ[>@@[^[D
M\.#B[>CRY>LB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8X-B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,@IM<V=I9"`B56YS
M=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`BSN_PY?'MZ"(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(L[O\.7Q[>@@)7,B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"B,L(&9U>GIY
M"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R("+.[_#E\>WH("5S(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R
M('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R("+.[_#E\>WE
M[6$@)R5S)RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I
M9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3DY"FUS9VED(")5<&QO860B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@
M86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED(")5<V4@:68@
M;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C(Q"B,L(&9U>GIY"FUS9VED(")5<V5R(@IM<V=S='(@(L_N\O#EX>CRY>OH
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW,C,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E
M9"!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM
M<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R("+`Y.SH[>CQ\O#H
M\.#MY2#MX"#O[O+PY>'H\N7KZ/+E(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HR-3$*(RP@9G5Z>GD*;7-G:60@(E5S97(@3W!T:6]N<R(*
M;7-G<W1R("+.[_;HZ"(*"B,Z('-I9VYU<"YP:'`Z-C(*(RP@9G5Z>GD*;7-G
M:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(L#D[.CMZ/'R\.CPX.WE
M(.W@(._N\O#EX>CRY>OH\N4B"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5
M<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S
M:71E+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8Y
M"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M,S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(LCL
MY2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI
M<W1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R("+([.4Z(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*
M;7-G<W1R("+([.4Z("(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(L_N
M\O#EX>CRY>OH(.(@\>CQ\N7LX/+@.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@
M(E5Z8F5K:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,38S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(U-0IM
M<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C
M871I;VXB"FUS9W-T<B`BPN#JX.WVZ/\B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HX-C8*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L
M=61E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV,S@*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U
M-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4V(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@
M:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#0@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S$V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C@*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0HC+"!F=7IZ>0IM<V=I
M9"`B5F%L=65S(@IM<V=S='(@(LW_[.`@\?+NZ>WN\?+H(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$P.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,3@V"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0T"FUS9VED(")687)I
M86)L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E
M;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE
M<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R("+#
M\.7XZN`@[_#H(._P[N+E\.K@\N`@+2#R[N+@(._H\>SN(.SNYN4@Y.`@Y2#A
MZ.ON(._NY._PX.+E[>XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HW,#`*(RP@9G5Z>GD*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B
MS_#@XN`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(V"FUS9VED
M(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R
M=&EC86P@86QI9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN
M9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@
M(E9E<GD@2&EG:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"B,L(&9U>GIY
M"FUS9VED(")6:65T($YA;2(*;7-G<W1R("+([.4@[>`@].#IZR(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")6:65T;F%M97-E("A625-#
M24DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.CDV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@
M86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E9I97<@87,@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I
M9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI
M='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(V,PIM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS
M9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!
M4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:'1M;"YP:'`Z,C<R(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B
M5V%R;FEN9R(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B
M5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-#(W"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED
M960@8GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.#DR"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S<*;7-G:60@(E=E8B!3:71E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC
M92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R("+1Y>3LZ/?M[B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"B,L(&9U>GIY"FUS9VED
M(")796QC;VUE(@IM<V=S='(@(L3NX?#E(.3N^.OH+"`E<R(*"B,Z('1E;7!L
M871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM
M<V=S='(@(L3NX?#E(,3N^.OH(.(@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO
M;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`BQ.[A\.4@
MY.[XZ^@L("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@
M(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DV"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@
M9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`BR.?AY?#E\N4@[_#HZ^[F
MY>WHY?+N+"#J[N7R[B`E<R#DX"#O[NK@YN4@\>OEY"#B]>[D+B(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H
M92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O
M=&4@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V,0IM<V=I9"`B5VAE<F5I<R!!=7-T
M<F%L:6$@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR
M,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA
M8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$R-0IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@
M*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS
M9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I
M9'1H('5N:70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$S"FUS9VED(")7:6MI
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,#`@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G
M:60@(E=I;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,`IM<V=I9"`B5VEN9"!S<&5E
M9"!I;B!K;F]T<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$U-@IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(T,@HC+"!F=7IZ>0IM<V=I9"`B5VEN9#H@(@IM
M<V=S='(@(L+MZ.S@[>CE.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3DV"FUS9VED(")7:7-H;&ES="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`BP>CG[>7Q(.#D\.7Q
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y
M,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R("+!Z.?MY?$@\N7KY?3N[2(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$V.2!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O
M;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@
M9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C,P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@
M;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Q-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&
M4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C0S"FUS9VED(")8+5)E9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($)A<VEC
M($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y
M(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV
M92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I
M9FEE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@
M(L/#(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#4U"B,L(&9U>GIY"FUS9VED(")965E9(@IM<V=S='(@(L/#(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,#@*;7-G:60@
M(EEA:&]O(2!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA
M;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@
M(L/NY.CX[>XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"B,L(&9U>GIY"FUS9VED(")996UE
M;B(*;7-G<W1R(")'<F5E;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(EEE<R(*;7-G<W1R("+$X"(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS
M9VED(")997,L($D@06=R964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I
M;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B
M86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]E9&ET+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO
M="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,3$*;7-G
M:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")9
M;W4@8V%N(&YO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U
M;&P@;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@U-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"FUS9VED(")9
M;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S
M='(@(LWE(.+ZXN7D[O7RY2#BX.OHY.7M(&5M86EL(.#D\.7Q+B(*"B,Z(&9R
M86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R
M=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*
M(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS
M9W-T<B`BPN#XZ/+E(.KN[?3HX_/PX/;H[NWMZ"#N[_;HZ"#A__7@(.[A[>[B
MY>WH+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@
M(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E
M<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H
M92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@X"B,L(&9U>GIY"FUS9VED
M(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R("+-
MY2#B^N+EY.[U\N4@XN#KZ.3E[2!E;6%I;"#@Y/#E\2XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O
M;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#4V"FUS
M9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G
M:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@
M8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED
M(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN
M=',@=&\B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP
M:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V
M97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`BTO#_X>+@(.3@(.?@Y.#DY?+E
M(._N\O#EX>CRY>L@Y^`@Z.?R\.CBX.WE+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$Q.0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`BTO#_X>+@(.3@(.?@Y.#DY?+E
M(._N\O#EX>CRY>L@Y^`@Z.?R\.CBX.WE+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E
M;6]V92XB"FUS9W-T<B`BTO#_X>+@(.3@(.?@Y.#DY?+E(._N\O#EX>CRY>L@
MY^`@Z.?R\.CBX.WE+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R("+2\/_AXN`@Y.`@
MY^#DX.3E\N4@[^[R\.7AZ/+EZR#GX"#D[N'@XO_MY2XB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N
M86UE('1O('5P9&%T92XB"FUS9W-T<B`BTO#_X>+@(.3@(.?@Y.#DY?+E(._N
M\O#EX>CRY>L@Y^`@[N_PY?'M_^+@[>4N(@H*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+WII<"YP:'`Z,3,X"B,L(&9U>GIY"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@
M(M+P_^'BX"#DX"#GX.3@Y.7RY2#O[O+PY>'H\N7K(.?@(.CG\O#HXN#MY2XB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H
M<#HW,0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E
M9V]R>2!N86UE+B(*;7-G<W1R("+2\/_AXN`@Y.`@Y^#DX.3E\N4@[^[R\.7A
MZ/+EZR#GX"#HY_+PZ.+@[>4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O
M('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<V"B,L('!H<"UF;W)M870*
M;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO
M9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHS.`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!%;6%I;"!!9&1R
M97-S(@IM<V=S='(@(L+@^.C_($5M86EL(.#D\.7Q.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,3(*(RP@9G5Z>GD*;7-G:60@(EEO=7(@1G)O;3H@
M861D<F5S<SHB"FUS9W-T<B`BPN#XZ/\@16UA:6P@X.3PY?$Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(LCM
M].[P[.#VZ/\@Y^`@PN#Q(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M.3@P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D
M<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@
M)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@
M;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z,S,*(RP@9G5Z>GD*;7-G:60@(EEO=7(@3F%M
M92(*;7-G<W1R("+"X/CE\NX@Z.SE.B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO861D+FEN8SHU"B,L(&9U>GIY"FUS9VED("(B"B)9;W5R(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E
M<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R
M('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A
M=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"B+"X/CH__(@Z.3E
M[?+H].CJX/;H[NWE[2#D\.#IXN7P(.WE(._NY.3Z\.;@(.3NX>#B_^WE(.W@
M(._N\O#EX>CRY>OH+"#HZ^@@(@HB\N#GZ"#B^N?L[N;M[O'R(.4@Y^#A\.#M
MY>W@+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM
M<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T
M('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S
M(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R
M("(B"B+"X/CH__(@Z.3E[?+H].CJX/;H[NWE[2#D\.#IXN7P(.WE(._NY.3Z
M\.;@(/'OZ/'ZZB#MX"#O[O+PY>'H\N7KZ/+E+"#HZ^@@(@HB\N#GZ"#B^N?L
M[N;M[O'R(.4@Y^#A\.#MY>W@+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDX-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S97(@
M87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O
M9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U<FET
M>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C4P"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N
M;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9;W5R(&)R
M;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E
M<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-PIM<V=I9"`B66]U<B!C
M=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E
M9G,N<&AP.CDV"B,L(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I
M='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`BPN#XZ/+E(.KN[?3HX_/P
MX/;H[NWMZ"#N[_;HZ"#A__7@(.[A[>[BY>WH+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-3@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L="!I
M9&5N=&ET>3HB"FUS9W-T<B`BR.3E[?+H]^WN\?(@[^X@[^[D\.#GX>CPX.WE
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,0HC+"!F=7IZ>0IM<V=I
M9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(L+@^.7R[B#H[.4Z(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z,3`P,`HC+"!F=7IZ>0IM<V=I9"`B
M66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`BPN#XZ/+E(.KN[?3H
MX_/PX/;H[NWMZ"#N[_;HZ"#A__7@(.[A[>[BY>WH+B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO
M=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*(RP@9G5Z>GD*;7-G
M:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U
M<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`BPN#XZ/+E(.KN[?3H
MX_/PX/;H[NWMZ"#N[_;HZ"#A__7@(.[A[>[BY>WH+B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R(&]P=&EO;G,@
M:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(L+@^.CRY2#J[NWTZ./S\.#V
MZ.[M[>@@[N_VZ.@@X?_UX"#NX>WNXN7MZ"XB"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E
M="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@
M(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.C<S,@IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X
M"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R("+"X/CH\N4@
M\?KPXOKPZ#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA
M=FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*
M;7-G:60@(EIA;6)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED
M(")::6UB86)W92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]4
M97AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@
M(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M<F]B;&5M+G!H<#HX.`IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ
M,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP
M:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT
M("T@)7,@;&EN97-=(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F
M("5S72(*;7-G<W1R(");Z^CMZ/\@)7,@[O(@)7-=(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ-30Q('1E;7!L871E<R]P;W)T86PO;65N=2YI
M;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R
M("+`Y.SH[>CQ\O#H\.#MY2(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B
M7T-,22(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#$*(RP@9G5Z>GD*
M;7-G:60@(E]$871A5')E92(*;7-G<W1R("+$X.WMZ"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0HC+"!F
M=7IZ>0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T<B`BR.?R\.CI(@H*(SH@
M;&EB+V%P:2YP:'`Z,3,S"B,L(&9U>GIY"FUS9VED(")?1W)O=7!S(@IM<V=S
M='(@(L/P\^_H(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP
M.C$W-0HC+"!F=7IZ>0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`BS^[L[ODB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*(RP@9G5Z
M>GD*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`BPO7NY"(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]-96YU+G!H<#HQ.3`*(RP@9G5Z>GD*;7-G:60@(E],
M;V<@;W5T(@IM<V=S='(@(LCG]>[D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y
M($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TUE;G4N<&AP.C$V-`HC+"!F=7IZ>0IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T
M<B`BSN_VZ.@B"@HC.B!L:6(O87!I+G!H<#HQ,S<*(RP@9G5Z>GD*;7-G:60@
M(E]097)M:7-S:6]N<R(*;7-G<W1R("+/\.#BX"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B
M7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$R
M-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A
M8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z
M,3(Y"B,L(&9U>GIY"FUS9VED(")?57-E<G,B"FUS9W-T<B`BS^[R\.7AZ/+E
MZ^@B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,0HC+"!F=7IZ
M>0IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(L#D\.7QY>T@X>7KY>;M
MZ.HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S-`IM
M<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3,*(RP@9G5Z>GD*;7-G:60@(F-A;&5N
M9&%R(@IM<V=S='(@(LK@Z^7MY.#P(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B8V%L;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T92!O=71P=70@
M9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DR"FUS
M9VED(")C;&EC:R!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A
M9V4@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-S@*(RP@9G5Z>GD*;7-G:60@(F-O;F9I9W5R871I;VX@
M97)R;W(B"FUS9W-T<B`BRN[M].CC\_#@]NC_(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E
M;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3@R"B,L(&9U>GIY"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T
M<B`B[>4@X>7XY2#MX.SE\.7M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4U"FUS9VED(")F
M:6QE(@IM<V=S='(@(O3@Z>LB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W
M-"!L:6(O0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO8VLO;65T87(N<&AP
M.C,X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T
M("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-3`*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.0IM<V=I9"`B:#HB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C,U.`IM<V=I9"`B:&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U
M;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")I;FQI;F4B"FUS9W-T
M<B`BS^[D]^7P\N#MZ"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G
M:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"B,L(&9U>GIY
M"FUS9VED(")L:6YE<UTB"FUS9W-T<B`BQ^#CZ^#BZ/\B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE
M(&UA:VEN9R!)4T\N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HS-CD*;7-G:60@(FUM(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,CDQ('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C(S,@HC+"!F=7IZ>0IM<V=I9"`B;F%M92(*;7-G<W1R("+(
M[.4B"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(Q"FUS9VED(")N;W0@
M:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HQ,C$Y"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`U
M"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E
M;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-S0*(RP@9G5Z>GD*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM
M<V=S='(@(L_PX.+@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED
M(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*(RP@9G5Z>GD*
M;7-G:60@(G)I<VEN9R(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V:6-E('5N
M879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z.3D*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*
M;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@U"FUS9VED(")S
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HW,@HC+"!F=7IZ>0IM<V=I9"`B<W1E861Y(@IM<V=S='(@(M?E
M\N7MY2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`Y"FUS9VED
M(")S=VET8V@@;V9F(&IA=F%S8W)I<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E
M<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDR.0IM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@
M9F%I;'5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C,P-0HC+"!F=7IZ>0IM<V=I9"`B=')Y(&%G86EN(@IM<V=S='(@(L+Q
M_^KN(.ONX^+@[>4B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")T>7!E('1H92!P87-S
M=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"B,L(&9U
M>GIY"FUS9VED(")U;FEF:65D(@IM<V=S='(@(N_P[N+@Z^7M[B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B
M"FUS9W-T<B`BX>7G(.CLY2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-#$*;7-G:60@
M(G<Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HV"FUS9VED(")W96%T:&5R+F-O;2(*;7-G<W1R("(B"@``````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+V)S7T)!+G!O````````````
M````````````````````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`V-3`V,S$`
M,3`U,34T,S,W-30`,#$W-C$V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````",@=')A;G-L871I;VX@;V8@:&]R9&4M8G,N<&\@
M=&\@0F]S;FEA;@HC($)O<VYI86X@=')A;G-L871I;VYS(&9O<B!I;7`@<&%C
M:V%G92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#,@2&]R9&4@4')O:F5C=`HC(%1H
M:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E
M(&%S('1H92!I;7`@<&%C:V%G92X*(R!!=71O;6%T:6-A;&QY(&=E;F5R871E
M9"P@,C`P,RX*(R!!;&5N(%-A<FMI;F]V:6,@/&%L96Y`;&EN=7@N;W)G+F)A
M/BP@,C`P-"X*(R!6961R86X@3&IU8F]V:6,@/'9L:G5B;W9I8T!S;6%R=&YE
M="YB83XL(#(P,#4N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED
M+59E<G-I;VXZ(&AO<F1E+6)S7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@
M9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P
M,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P
M-2TP-RTP,2`Q,SHS,2LP,C`P7&XB"B),87-T+51R86YS;&%T;W(Z(%9E9')A
M;B!,:G5B;W9I8R`\=FQJ=6)O=FEC0'-M87)T;F5T+F)A/EQN(@HB3&%N9W5A
M9V4M5&5A;3H@0F]S;FEA;B`\;&]K86Q`;&EN=7@N;W)G+F)A/EQN(@HB34E-
M12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@
M8VAA<G-E=#U)4T\M.#@U.2TR7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D
M:6YG.B`X8FET7&XB"B)8+4=E;F5R871O<CH@2T)A8F5L(#$N,3!<;B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B("AP<FEJ92`E<R!D86YA
M*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B`H>F$@)7,@9&%N82DB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<S"FUS9VED("(@*'1O9&%Y
M*2(*;7-G<W1R("(@*&1A;F%S*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S-S4*;7-G:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(B`H<W5T<F$I
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,0IM<V=I9"`B("AY
M97-T97)D87DI(@IM<V=S='(@(B`H:G7H92DB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C4V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS-C$*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-PIM<V=I
M9"`B(&%T("(*;7-G<W1R("(@=2`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C(Q-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB
M(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B4')A=F%C('-O<G1I<F%N
M:F$B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E
M+B(*;7-G<W1R("(G)7,G(&YI:F4@9&]Z=F]L:F5N(&EZ8F]R+B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-C4Y"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`T,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN
M('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B)R5S)R!N:6IE('!O9&6Y
M96X@=2!R96=I<W1R>2UJ=2!A<&QI:V%C:6IE+B(*"B,Z(&9R86UE=V]R:R]4
M<F5E+U1R964N<&AP.C$W,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R("(E<R!N
M:6IE('!R;VYA\&5N+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE
M(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!J92!U<W!E<VYO(&1O
M9&%N('4@861R97-A<B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H
M92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@
M*"4N,F8E)2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B
M"FUS9W-T<B`B)60@)7,@:2`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X
M<&ER97,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(E<R`M
M($YA<&]M96YA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HW,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M.#,S(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM
M<V=S='(@(B5S(%-E<G9I<VYE(&]P97)A8VEJ92`M('!O='9R9&$B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B
M)7,@<&]D9;EA=F%N:F4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,C8S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS
M9W-T<B`B)7,@<')I:F%V82(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE
M;G0B"FUS9W-T<B`B)7,@=7-L;W9I('5G;W9O<F$B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C0R."!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C0Y,`HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8U,2!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B)7,@=F7F('!O<W1O:FDN(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3D@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-C4@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,SD*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS-#4@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B)7,@=2`E<R`E<R(*
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T
M:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E
M<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(@)B,Q-3$[("5S(.9E('-A
M9&$@:7IV<KEI=&D@<V5R=FES;F4@;W!E<F%C:6IE(&YA=F5D96YE(&ES<&]D
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M;6EN=71E<R(*;7-G<W1R("(E<R!M:6YU=&$B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@;FEJ92!P<F]N8?!E;BXB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B5S('IA("5S
M(&]D("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B
M)7,@861R97-A<B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$T
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B
M)7,@:V%L96YD87(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B
M)7,@8FEL:F6^;FEC82(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3,P"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T
M<B`B)7,@>F%D86-I(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7,Z("5S(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H
M;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N
M>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H
M(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V-2!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-#$P"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@X(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3DS"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@
M)7,@)7,B"FUS9W-T<B`B)7,@=2`E<R`E<R(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O
M;2`E<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(Y-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T
M.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q,C@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C<T.0IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@
M(BTM(&EZ86)E<FET92`M+2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM
M<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`B,3(M<V%T;FD@9F]R;6%T
M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R($9O
M<FUA="(*;7-G<W1R("(R-"US871N:2!F;W)M870B"@HC.B!T96UP;&%T97,O
M9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@
M<V%T82(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z-CD*(RP@9G5Z
M>GD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R(")0<F5T:&]D;F$@<W1R86YA
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@(D$@9&%T86)A
M<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C`*;7-G:60@
M(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(D1ON6QO(&IE
M(&1O(&9A=&%L;F4@9W)EN6ME(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38U"FUS9VED(")!('!U8FQI
M8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HQ,#DW"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E
M(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R
M>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3`Q-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3`U"FUS9VED("(B"B)!
M('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A
M=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)
M344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HY"B,L(&9U>GIY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B2V]P:7)A
M:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P
M"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"B,L(&9U>GIY"FUS9VED
M(")!32!286EN(@IM<V=S='(@(E5P;WIO<F5N:F4B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*
M;7-G<W1R(")!32]032(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*
M;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(D\@;W9O;2!E9&ET
M;W)U(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3(*;7-G:60@(D%B
M;W5T+BXN(@IM<V=S='(@(D\@<')O9W)A;74N+BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"B,L(&9U>GIY"FUS9VED
M(")!8G-B;W1T;VTB"FUS9W-T<B`B1&YO(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-S`*
M;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$S
M-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*(RP@9G5Z>GD*
M;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B5F&Y92!I;F9O
M<FUA8VEJ92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-0IM<V=I9"`B
M06-C;W5N="!087-S=V]R9"(*;7-G<W1R("*I:69R82!K;W)I<VYIZ&MO9R!N
M86QO9V$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R(").
M86QO9R!J92!Z86UR>FYU="XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S,S"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(E)AZ'5N;W9O9'-T
M=F\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T96UP
M;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R(")$;V1A
M:B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z
M,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.CDY"B,L(&9U>GIY"FUS9VED(")!9&0@0VAI;&0@4&5R
M;6ES<VEO;B(*;7-G<W1R("))>FUI:F5N:2!D;WIV;VQU(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R
M(")$;V1A:B!O=F1J93HB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI
M;B]G<F]U<',N<&AP.C(Q.0HC+"!F=7IZ>0IM<V=I9"`B061D($YE=R!'<F]U
M<"(*;7-G<W1R(").97=S+6=R=7!E(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@X
M"B,L(&9U>GIY"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS9W-T<B`B
M27IM:6IE;FD@9&]Z=F]L=2(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M861D8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI
M;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,30W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R
M("))>FUI:F5N:2!D;WIV;VQE('IA("5S(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R(")$;V1A:B!N;W9O
M9R!K;W)I<VYI:V$Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4U-`IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R(")$;V1A
M:B!K;VQO;G4B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C,T"B,L(&9U>GIY"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`B
M1&]D86H@;F]V;V<@:V]R:7-N:6MA.B(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@
M(D1O9&%J("5S(&UE;FD@=2!-;WII;&QA(%-I9&5B87(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D9"!T
M;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(D1O9&%J('4@861R97-A<CHB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*(RP@
M9G5Z>GD*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B
M1&]D86H@=2!I;65N:6L@*"5S*2(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"B,L
M(&9U>GIY"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R(")$;V1A:B!O=F1J93HB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A
M9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G
M<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@
M(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N
M;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D
M+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q"B,L(&9U>GIY"FUS
M9VED(")!9&1R97-S(@IM<V=S='(@(D]D(&%D<F5S92(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ,SD*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G
M<W1R("));65N:6LB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N
M<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B061M:6YI<W1R:7)A;FIE("T@
M<&]D9;EA=F%N:F4@9&]Z=F]L82!D<G5G:6@@:V]R:7-N:6MA(@H*(SH@861M
M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ
M,3,*(RP@9G5Z>GD*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E]!
M9&UI;FES=')A8VEJ82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M-#$*(RP@9G5Z>GD*;7-G:60@(D%D<R(*;7-G<W1R(")$;V1A:B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(D%F9V%N:7-T86XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4W"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(D%L8F%N:6IA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG97)I82(*;7-G<W1R(")!;+YI<B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*
M(RP@9G5Z>GD*;7-G:60@(D%L:6%S(@IM<V=S='(@(D%LOFER(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM
M<V=I9"`B06QI9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L
M;"(*;7-G<W1R(")3=F4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U"B,L(&9U>GIY
M"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R(")5<VUJ
M97)E;FIE(&YI:F4@=7-P96QO+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@
M861M:6XO9W)O=7!S+G!H<#HR,C(*(RP@9G5Z>GD*;7-G:60@(D%L;"!'<F]U
M<',B"FUS9W-T<B`B7T=R=7!E(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HY,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP
M.C<U"B,L(&9U>GIY"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B
M7T1O>G9O;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<Q"FUS9VED(")!
M;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4S-`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O
M<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B1&]Z=F]L:2!P<F%V;&IE;FIE
M(&YU;65R:7-A;FEH(&QI<W1I/R(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$
M871A5')E92]S<6PN<&AP.C4P-`HC+"!F=7IZ>0IM<V=I9"`B06QR96%D>2!E
M>&ES=',B"FUS9W-T<B`B)7,@=F7F('!O<W1O:FDN(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$R,PIM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB
M"FUS9W-T<B`B06QT97)N871I=FYI($E-4U`@;&]G:6XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3`W"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S
M=V]R9"(*;7-G<W1R(")!;'1E<FYA=&EV;F$@24U34""Y:69R82(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3D*;7-G:60@(D%L=&5R;F%T92!)35-0
M(%5S97)N86UE(@IM<V=S='(@(D%L=&5R;F%T:79N;R!)35-0(&MO<FES;FGH
M:V\@:6UE(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*(RP@
M9G5Z>GD*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@
M(DYE9&]Z=F]L:F5N82!S;&]V82!U(&5M86EL(&%D<F5S:2XB"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$T,@HC+"!F=7IZ>0IM<V=I9"`B06QT97)N871E
M('1E;7!L871E<R(*;7-G<W1R(").961O>G9O;&IE;F$@<VQO=F$@=2!E;6%I
M;"!A9')E<VDN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HY
M-2!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@
M:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R(")5;F6Y96YA
M(&IE(&EL96=A;&YA('9R:6IE9&YO<W0N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$V-PHC+"!F=7IZ>0IM<V=I9"`B06X@=6YK;F]W;B!E
M<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B1&^Y;&\@:F4@9&\@9F%T86QN
M92!G<F6Y:V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O
M>'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-#D*(RP@9G5Z>GD*;7-G:60@(D%N<W=E<B(*;7-G<W1R(")/9&=O=F]R96YE
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN
M<&AP.C,U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@=&5M
M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@HC+"!F=7IZ>0IM<V=I
M9"`B07!P;&EC871I;VXB"FUS9W-T<B`B06MC:6IA(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C0R"B,L(&9U>GIY"FUS9VED(")!<'!L:6-A=&EO;B!,
M:7-T(@IM<V=S='(@(D%K8VEJ82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-#`*(RP@9G5Z>GD*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*
M;7-G<W1R(")!:V-I:F$B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED
M(")!<'!R;W9E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C@S,PIM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B07!R:6PB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$W-0IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV
M-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@Q"FUS
M9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX,`HC+"!F=7IZ>0IM<V=I9"`B07)C:&EV92!.
M86UE(@IM<V=S='(@(DEM92!D871O=&5K92(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE
M('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(D1A(&QI('-T92!S
M:6=U<FYI(&1A(+YE;&ET92!I<W!R87IN:71I(&9O;&1E<B!K;W)P83\B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R(")$
M82!L:2!S=&4@<VEG=7)N:2!D82"^96QI=&4@;V)R:7-A=&D@;W9E('!O<G5K
M93\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4X"B,L(&9U>GIY"FUS9VED(")!<F=E;G1I;F$B"FUS
M9W-T<B`B06R^:7(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED(")!<FUE
M;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y
M"FUS9VED(")!<G5B82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@
M07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(U"FUS9VED(")!<VL@9F]R(&-O
M;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<S\B"FUS9W-T<B`B4&ET86H@<')I:F4@;V)A=FQJ86YJ82!S97)V:7-N:6@@
M;W!E<F%C:6IA/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3,*
M;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM
M97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R
M;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE
M>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO
M;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#8*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G
M:60@(D%U9W5S="(*;7-G<W1R(")!=6=U<W0B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"B,L(&9U
M>GIY"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B075G=7-T(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU.0HC+"!F=7IZ>0IM<V=I9"`B075S=')I82(*;7-G<W1R(")!=6=U<W0B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED
M(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@
M:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y
M<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O9G1P+G!H<#HS-@IM<V=I
M9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I
M=&-H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N
M<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K
M<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD87`Z
M($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER
M96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B
M075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,S,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N
M86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9#H@(@IM<V=S='(@(DYI:F4@=7-P96QO('-P8;EA=F%N:F4@;F5Z879R
MN65N92!P;W)U:V4N($]V;R!J92!P;W)U:V$@<V5R=F5R83H@)7,B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0Y
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B
M;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B3FEJ92!U<W!E;&\@<W!A
MN6%V86YJ92!N97IA=G*Y96YE('!O<G5K92X@3W9O(&IE('!O<G5K82!S97)V
M97)A.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#`U
M"FUS9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P
M;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A
M;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z-C`*;7-G:60@
M(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*(RP@9G5Z>GD*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R(")5<VUJ97)E;FIE(&YI:F4@=7-P
M96QO+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C<V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!=71H
M96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(E5S;6IE<F5N:F4@;FEJ
M92!U<W!E;&\N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP
M.C$W-@IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553
M('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX-3$*(RP@9G5Z>GD*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($94
M4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")5<VUJ97)E;FIE(&YI:F4@=7-P
M96QO+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`*(RP@9G5Z
M>GD*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A
M:6QE9"XB"FUS9W-T<B`B57-M:F5R96YJ92!N:6IE('5S<&5L;RXB"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"B,L(&9U>GIY"FUS9VED(")!
M=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R(").82!R87-P;VQA9V%N:G4@<W4@
M<VQJ961EYFD@:6UE;FEC:3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I
M:F%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM
M<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A
M8VMG<F]U;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@Q
M"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K
M97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I
M9"`B0F%H86UA<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"B,L(&9U>GIY"FUS
M9VED(")"86AR86EN(@IM<V=S='(@(D)R87II;"(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3<W"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G
M<W1R(")"86QT:>AK:2`H25-/+3@X-3DM,3,I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I
M9"`B0F%N9VQA9&5S:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"
M87)B861O<R(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O
M<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"B,L(&9U>GIY
M"FUS9VED(")"87-E;&EN92(*;7-G<W1R(")696QIZ&EN82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`HC+"!F
M=7IZ>0IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R(")696QIZ&EN82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(D)E;&EZ92(*;7-G<W1R(")696QIZ&EN
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(D)E;FEN(@IM<V=S='(@
M(E)E=6YI;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED
M(")":7)T:&1A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO0V]L;&5C=&EO;BYP:'`Z,S4S"B,L('!H<"UF;W)M870*;7-G:60@(D)L
M;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.#D*
M;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G
M<W1R(")6<G-T82!B;&]K82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R(")-87-N;R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B0F]L:79I:F$B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`U"FUS9VED(")";V]K
M;6%R:W,B"FUS9W-T<B`B6F%B:6QJ9;EK92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*;7-G:60@(D)O<F1E
M<B(*;7-G<W1R(")2=6(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G
M<W1R(")$96)L:FEN82!R=6)O=F$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*
M;7-G<W1R(")2=6)O=FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@86YD
M($AE<GIE9V]V:6YA(@IM<V=S='(@(D)O<VYA(&D@2&5R8V5G;W9I;F$B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T
M<B`B3V)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B
M0F]C=F%N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(D1N;R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B0F]U=F5T
M(&]S=')V;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R87II;"(*;7-G<W1R(")"
M<F%Z:6PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E
M86X@5&5R<FET;W)Y(@IM<V=S='(@(D)R:71A;G-K82!);F1I:G-K;RU/:V5A
M;G-K82!497)I=&]R:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A
M<G5S<V%L86TB"FUS9W-T<B`B0G)U;F5I($1A<G5S<V%L86TB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R(")"=6=A<G-K82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@
M(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`B3&ES=&$@<V$@=&'H:V%M82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R(")"=7)K:6YA
M($9A<V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(D)U
M<G5N9&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0T"FUS9VED
M(")#35,B"FUS9W-T<B`B0TU3(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-20R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#
M4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G
M:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B3W-O8FEN92#F7V5L
M:6IE+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,PIM
M<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X
M-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ-34*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(DMA;&5N
M9&%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-@HC+"!F
M=7IZ>0IM<V=I9"`B0V%L;2(*;7-G<W1R(")/9'5S=&%N:2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R(")+86UB;_!A(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B2V%M97)U;B(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E
M<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET
M92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N
M<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S
M<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)U<RYP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L
M+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T
M;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B3F4@;6]G=2!S92!S<&]J:71I
M(&YA($E-05`@<V5R=F5R.B`E<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C0Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#86YA
M9&$B"FUS9W-T<B`B2V%N861A(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D
M;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE
M=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R"FUS9VED(")#
M86YC96PB"FUS9W-T<B`B3V1U<W1A;FDB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T
M(@IM<V=S='(@(D]D=7-T86YI(&]D('!R:6IA=F4@<')O8FQE;6$B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM
M<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N
M<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&
M:6QE)R!P87)A;65T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,S$T"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R
M96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4
M<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV,#@*
M;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S
M=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB
M<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M
M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`HC+"!F
M=7IZ>0IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R(")/<&-I:F4B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@
M(D-A<G)I97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDP"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B2V%T
M96=O<FEJ92!I(&]Z;F%K92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"B,L(&9U>GIY"FUS9VED
M(")#87EM86X@27-L86YD<R(*;7-G<W1R(")-87*Y86QO=F$@;W-T<G9A(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`HC
M+"!F=7IZ>0IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R(")496QE9F]N("AK
M=>9I*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C4*(RP@9G5Z>GD*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*
M;7-G<W1R(")/<V]B:6YE(.9?96QI:F4N+BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D
M:6YG.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8Q"B,L(&9U>GIY"FUS9VED(")#96QL('!R
M;W!E<G1I97,B"FUS9W-T<B`B3W-O8FEN92#F7V5L:6IE+BXN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@
M(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(W-`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")#96QT:6,@*$E33RTX
M.#4Y+3$T*2(*;7-G<W1R(")+96QT<VMI("A)4T\M.#@U.2TQ-"DB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V
M"B,L(&9U>GIY"FUS9VED(")#96YT97(B"FUS9W-T<B`B2W)E:7)A:B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G
M<W1R(")#96YT<F%L;F\M069R:>AK82!297!U8FQI:V$B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/
M+3@X-3DM,BDB"FUS9W-T<B`B0V5N=')A;&YO+65V<F]P<VMI("A)4T\M.#@U
M.2TR*2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-CDY
M"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$Q"FUS9VED(")#97)T
M:69I8V%T92!/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED(")#
M:&%D(@IM<V=S='(@(E1O:R!T96UE(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@IM
M<V=I9"`B0VAA;F=E(@IM<V=S='(@(E!R;VUJ96YI(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")#:&%N9V4@
M66]U<B!087-S=V]R9"(*;7-G<W1R(")087-S=V]R9"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-@IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N
M9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@
M<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*(E!R;VUI:F5N
M:71E(&EM92!I(&%D<F5S=2!K;VIE('9I9&4@9')U9VD@:V%D82#H:71A:G4@
M:2!O9&=O=F%R86IU(&YA('9AN64@(@HB<&]R=6ME+B(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U
M<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@
M8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(W"B,L(&9U>GIY"FUS9VED(")#:&%R(@IM<V=S
M='(@(E1O:R!T96UE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(U"B,L(&9U>GIY"FUS9VED(")#:&5C7VL@
M3&EN:RXN+B(*;7-G<W1R(")?27IM:6IE;FD@;&EN:RXN+B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C<*;7-G:60@(D-H:6QE(@IM<V=S='(@(LAI;&4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#:&EN82(*;7-G<W1R(")+:6YA(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*
M;7-G<W1R(")+:6YE<VMI('!O:F5D;F]S=&%V;&IE;FD@*$=",C,Q,BDB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0VAI;F5S92!4<F%D
M:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B2VEN97-K:2!T<F%D:6-I;VYA;&YI
M("A":6<U*2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR
M-CD*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(DEZ86)E<FET
M92"Y:69R=2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR
M-C@*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(DEZ86)E<FET
M92!K;W)I<VYIZ&MO(&EM92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M.3@*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T
M<B`B27IA8F5R:71E(&MA:V\@<V4@<')I:V%Z=6IE(&1A='5M.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D
M(&QI<W1S*2(*;7-G<W1R("))>F%B97)I=&4@=G)S='4@<W1I;&$@*'IA(&YU
M;65R:7-A;F4@;&ES=&4I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S
M($ES;&%N9"(*;7-G<W1R(")5<VMRN6YJ92!O<W1R=F\B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M.#DS"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@
M)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B0VQE87(B"FUS9W-T<B`B
M3^AI<W1I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R(")/
MZ&ES=&D@35-/9F9I8V4@=&%G;W9E(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$R.`HC+"!F=7IZ>0IM<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`B3^AI
M<W1I(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0HC+"!F
M=7IZ>0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R(")/Z&ES=&DB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`HC+"!F=7IZ>0IM<V=I
M9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(D]D86)E<FD@:V]D;FD@<F%S
M<&]R960@<VQO=F$Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*
M;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I
M9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(T-`HC+"!F=7IZ>0IM<V=I9"`B0VQO=61S(@IM<V=S
M='(@(DMO<&ER86HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-@HC+"!F=7IZ>0IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S
M='(@(DMO<&ER86HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-PHC+"!F=7IZ>0IM<V=I9"`B0VQO=61Y(@IM<V=S='(@(DMO
M<&ER86HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N
M:6YC.C(S"B,L(&9U>GIY"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S
M='(@(E-K=7!I(&9O;&1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*(RP@9G5Z>GD*;7-G:60@(D-O;&QA
M<'-E9"!B;W)D97)S(@IM<V=S='(@(E-K=7!I(&9O;&1E<B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C<*(RP@9G5Z>GD*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(DMA;6)O\&$B
M"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP
M:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR.0HC+"!F=7IZ>0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B2V]M
M;W)I(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP
M.C,R-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z
M,S(U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU
M,#`@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B
M0V]L;W(@4&EC:V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X-#8*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B
M27IB;W(@8F]J92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30V"FUS9VED(")#;VQU;6X@=&ET;&5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C0*
M(RP@9G5Z>GD*;7-G:60@(D-O;6EC<R(*;7-G<W1R(").;W9A('!O<G5K82(*
M"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-0HC+"!F=7IZ>0IM<V=I9"`B0V]M
M;6%N9"(*;7-G<W1R(")+;VUP86YI:F$B"@HC.B!A9&UI;B]C;61S:&5L;"YP
M:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"B,L(&9U>GIY"FUS9VED
M(")#;VUM96YT(@IM<V=S='(@(EIA=G*Y96YO(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8*(RP@9G5Z>GD*;7-G:60@(D-O;6UO
M;B!.86UE(@IM<V=S='(@(E9AN64@:6UE(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@
M(D-O;6]R;W,B"FUS9W-T<B`B2V]M;W)I(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G
M<W1R(")+;VUP86YI:F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*
M(RP@9G5Z>GD*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R(").;W9A('!O<G5K
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3<*(RP@9G5Z
M>GD*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R(")/<&-I:F4@;F%R961B93HB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T.0HC+"!F=7IZ>0IM<V=I9"`B
M0V]N9&ET:6]N<R(*;7-G<W1R(")/<&-I:F4@;F%R961B93HB"@HC.B!A9&UI
M;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F
M97)E;F-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,30S"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!
M<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I;VX@
M:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-3$*(RP@9G5Z>GD*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T
M<B`B4&%S<W=O<F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"B,L(&9U>GIY"FUS9VED(")#;VYG
M;R(*;7-G<W1R("):82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*(RP@9G5Z>GD*;7-G:60@(D-O
M;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B
M3&%O($YA<F]D;F$@1&5M;VMR871S:V$@4F5P=6)L:6MA(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I
M9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@(E5S;6IE<F5N:F4@;FEJ
M92!U<W!E;&\N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*
M;7-G<W1R(")5<VUJ97)E;FIE(&YI:F4@=7-P96QO+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R
M969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-#4*(RP@9G5Z>GD*;7-G:60@(D-O
M;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(E5S;6IE
M<F5N:F4@;FEJ92!U<W!E;&\N(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T
M.C$P,30*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PHC+"!F=7IZ>0IM<V=I
M9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A
M9&1R97-S(&)O;VLN(@IM<V=S='(@(EPB)7-<(B!J92!U<W!E<VYO(&1O9&%N
M('4@861R97-A<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-38@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV
M,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C8*(RP@9G5Z>GD*;7-G:60@(D-O;VL@27-L86YD
M<R(*;7-G<W1R(")";W5V970@;W-T<G9O(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,R"B,L(&9U>GIY"FUS9VED(")#;V]K:64B"FUS9W-T<B`B3F]V
M82!P;W)U:V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B2V]P:7)A
M:B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8X"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B
M57-M:F5R96YJ92!N:6IE('5S<&5L;RXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO
M;B(*;7-G<W1R(")+;W!I<F%J(&EZ86)R86YO(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDW-@IM<V=I9"`B
M0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-3,*;7-G:60@(D-O
M=6QD(&YO="!01U`@<VEG;B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@
M;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L
M9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C
M="X@)7,B"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U
M:V4@;V0@)7,Z("5S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"FUS9VED
M(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0U-PIM<V=I9"`B0V]U;&0@;F]T
M(&)I;F0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC
M92X@)7,B"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U
M:V4@;V0@)7,Z("5S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0HC
M+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V
M97(B"FUS9W-T<B`B3F4@;6]G=2!S92!S<&]J:71I(&YA($E-05`@<V5R=F5R
M.B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R
M(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(DYE(&UO9W4@<V4@<W!O
M:FET:2!N82!)34%0('-E<G9E<CH@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,B"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U
M:V4@;V0@)7,Z("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3$R-0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0
M(&1A=&$N(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R
M=6ME(&]D("5S.B`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3(R"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T
M82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HR-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B3FEJ92!B
M:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@;V0@)7,Z("5S(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@
M;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C,X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS
M9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@;V0@)7,Z
M("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S"B,L(&9U>GIY"FUS
M9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA
M:6P@861D<F5S<RXB"FUS9W-T<B`B3F5D;WIV;VQJ96YA('-L;W9A('4@96UA
M:6P@861R97-I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,C@S"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@9F5T
M8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R(").:6IE(&)I;&\@
M;6]G=6-E(&]B<FES871I('!O<G5K92!O9"`E<SH@)7,B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PHC+"!F=7IZ
M>0IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO
M;B!L:7-T+B(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B<FES871I('!O
M<G5K92!O9"`E<SH@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C0T-@HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T
M(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T
M<RXB"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@
M;V0@)7,Z("5S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@
M<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B
M<FES871I('!O<G5K92!O9"`E<SH@)7,B"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M,3$P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD
M(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HR-C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B
M<FES871I('!O<G5K92!O9"`E<SH@)7,B"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q
M,2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-3$V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV
M,3(*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-CDY"FUS9VED(")#;W5L9"!N
M;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S.`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(DYI:F4@
M8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N
M;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N
M(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C
M="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF
M('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.0HC+"!F=7IZ>0IM<V=I9"`B
M0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R(").:6IE(&)I;&\@;6]G
M=6-E(&]B<FES871I('!O<G5K92!O9"`E<SH@)7,B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@
M8F]O:RX@)7,B"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P
M;W)U:V4@;V0@)7,Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B
M"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@;V0@
M)7,Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HT,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@
M(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"B,L(&9U
M>GIY"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I
M;&ET:65S(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R
M=6ME(&]D("5S.B`E<R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*
M(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@
M;V0@)7,Z("5S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B<FES871I('!O<G5K92!O
M9"`E<SH@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B3FEJ92!B
M:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@;V0@)7,Z("5S(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S
M(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D
M("5S.B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDU"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U
M<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(").:6IE(&)I;&\@
M;6]G=6-E(&]B<FES871I('!O<G5K92!O9"`E<SH@)7,B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C8T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL
M92`E<RXB"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U
M:V4@;V0@)7,Z("5S(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F
M('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O
M<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T,PIM<V=I
M9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(DYI
M:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E
M(&-O;G1A8W0N("5S(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A
M=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<R(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B<FES871I('!O<G5K92!O
M9"`E<SH@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U
M<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U
M8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-C8*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL
M;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C$U-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E
M('5S97(@7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L
M9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30Q.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;G1E9"!T97AT(@IM
M<V=S='(@(DES<')A=FQJ96X@=&5K<W0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4V.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;G1R>2(*
M;7-G<W1R(").;W9A('!O<G5K82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR-S,*(RP@9G5Z>GD*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B3F]V
M82!P;W)U:V$B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R(")+
M<F5I<F%J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@
M(DYA<')A=FD@;&EN:R(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E
M;&5C="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B
M3F%P<F%V:2!N;W9I(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R
M(")0<F%V;&IE;FIE('!O9"UF;VQD97)A(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HR-#`*(RP@9G5Z>GD*;7-G:60@(D-R96%T;W(@4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B1&5F875L="!D;WIV;VQE(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S(S,`HC+"!F=7IZ>0IM<V=I9"`B0W)E9&ET
M(&-A<F0@;G5M8F5R(@IM<V=S='(@(D1E8V5M8F%R(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*
M(RP@9G5Z>GD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B2W)E:7)A:B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(V"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(#0@4&AA<V5S
M(@IM<V=S='(@(DES<')A=FQJ96X@=&5K<W0B"@HC.B!A9&UI;B]S97-S:6]N
M<RYP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS
M9W-T<B`B27-P<F%V;&IE;B!T96MS="(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`HC+"!F=7IZ>0IM<V=I9"`B0W5R
M<F5N="!4:6UE(@IM<V=S='(@(DES<')A=FQJ96X@=&5K<W0B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*
M(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(DES<')A
M=FQJ96X@=&5K<W0B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S,*(RP@9G5Z
M>GD*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`B27-P<F%V;&IE;B!T
M96MS="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*(RP@9G5Z>GD*;7-G
M:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R("))<W!R879L:F5N('1E:W-T
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W-0IM<V=I9"`B
M0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,R"B,L(&9U>GIY"FUS9VED
M(")#=7)R96YT('-T>6QE(@IM<V=S='(@(DES<')A=FQJ96X@=&5K<W0B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF;W)M870*;7-G
M:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB
M"FUS9W-T<B`B4&]D97-I=&4@>F%D871K92!K;VII(.9E('-E(&EZ=G*Y879A
M=&D@;F%K;VX@<')I:F%V92!N82`E<RXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,U"B,L(&9U>GIY"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S
M='(@(DEZ8F]R(&)O:F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R=7,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@(D-Y
M<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0WER
M:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-CD*(RP@9G5Z>GD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(D-E
M;G1R86QN;RU!9G)IZ&MA(%)E<'5B;&EK82(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-3$@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,R.#$*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R
M+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M
M9'-N+G!H<"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B1&YE
M=FYO(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U"B,L(&9U>GIY"FUS9VED
M(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(E]$871A5')E92(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-SD*;7-G:60@(D1A=&%B87-E($QO
M;VMU<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.3D*
M;7-G:60@(D1A=&4B"FUS9W-T<B`B1&%T=6TB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B1&%T92!2
M96-E:79E9"(*;7-G<W1R(")0<FEM;&IE;F$@;F$B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#`W"B,L(&9U>GIY"FUS9VED(")$871E('-E;&5C
M=&EO;B(*;7-G<W1R(")6<F5M96YS:V$@>F]N82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.3(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,R,@HC+"!F=7IZ>0IM<V=I9"`B1&%Y(@IM<V=S='(@(DUA:B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS-@HC+"!F=7IZ>0IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B
M3V)R:;EI(&9O;&1E<BAE*2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0U,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R(")$96-E
M;6)A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,38*(RP@9G5Z>GD*;7-G:60@(D1E8VEM86P@;G5M8F5R
M<R(*;7-G<W1R(")$96-E;6)A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$X
M-R!L:6(O<')E9G,N<&AP.C$Q-PIM<V=I9"`B1&5F875L="(*;7-G<W1R(")3
M=&%N9&%R9&YO(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-S<*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B4W1A
M;F1A<F1N82!B;VIA(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y
M+G!H<#HY,0IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R(")$969A
M=6QT(&ED96YT:71E="(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-PHC
M+"!F=7IZ>0IM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R(")3=&%N9&%R
M9&YO(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I
M;FET:6]N<R(*;7-G<W1R(")$969I;FEC:6IE(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C,V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S
M='(@(D]B<FFY:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS,@HC+"!F=7IZ>0IM<V=I9"`B1&5L971E($-E
M;&PB"FUS9W-T<B`B3V)R:;EI(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@
M861M:6XO9W)O=7!S+G!H<#HR,C<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!'
M<F]U<"(*;7-G<W1R(")/8G)IN6DB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR-#D*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T
M<B`B3V)R:;EI(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW
M-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0HC+"!F=7IZ>0IM
M<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B3V)R:;EI('!O<G5K
M92(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS
M"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(D)R
M:7-A;FIE(&D@:7IB86-I=F%N:F4@<&]R=6MA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PHC+"!F=7IZ>0IM
M<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B3V)R:;EI(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PHC+"!F
M=7IZ>0IM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R(")/8G)IN6DB"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T
M:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T
M<B`B27IM:6IE;FD@9&]Z=F]L92!Z82`E<R(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T
M92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I
M;VYS/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@
M<F]W(@IM<V=S='(@(D]B<FFY:2(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE
M=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N
M=&ET>2(*;7-G<W1R(")/8G)IN6D@:7IA8G)A;FD@:61E;G1I=&5T(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN
M(@IM<V=S='(@(E!O9&5S:2!V<F5M96YS:W4@>F]N=2XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*(RP@
M9G5Z>GD*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B
M4&]D97-I('9R96UE;G-K=2!Z;VYU+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C,V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D
M('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B3FEJ92!B
M:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@;V0@)7,Z("5S(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(U,PHC+"!F=7IZ>0IM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R
M(")/8G)IN6DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM87)K(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED
M(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R(")/<&FY:71E('!R;V)L
M96UE('4@<F%D=2!S82!W96)M86EL;VTB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B3W!I
M<R(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DU"FUS9VED(")$
M971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DY"B,L(&9U>GIY"FUS
M9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R(")/=F$@<&]R=6MA(&IE('!R:6IA=FQJ96YA(&MA
M;R!S<&%M('!O<G5K82!A9&UI;FES=')A=&]R=2!S:7-T96UA+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,3D*;7-G:60@(D1E=F5L;W!M96YT
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$W"FUS9VED
M(")$97<@4&]I;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR.30*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-PIM<V=I
M9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE
M9G0@=&\@<FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT
M('1O(&QE9G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R(")$:7)E:W1O<FEJ(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V-@IM<V=I9"`B1&ES<&QA>2`R-"UH
M;W5R('1I;65S/R(*;7-G<W1R(")0<FEK8;YI('9R:6IE;64@=2`R-"US871N
M;VT@9F]R;6%T=3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G
M:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R(")/<&-I:F4@<')I:V%Z82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY-@HC+"!F=7IZ>0IM
M<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R(")0<FEK
M8;YI('!R;V=N;WIU("A4048I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX
M-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R(")0<FEK
M8;YI('!R;V=N;WIU("A4048I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@Q-PHC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T
M<B`B4')I:V&^:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HQ
M.3`*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,@HC+"!F=7IZ>0IM<V=I
M9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R(")5;F1E;&5T92(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY
M(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H
M92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC
M(@IM<V=S='(@(D-E;G1R86QN;RU!9G)IZ&MA(%)E<'5B;&EK82(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@
M86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"FUS9VED(")$;W=N;&]A9"(*
M;7-G<W1R(")$;W=N;&]A9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C@T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E
M<R(*;7-G<W1R(")$;W=N;&]A9"`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q,#<*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U
M9W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#$S"B,L(&9U>GIY"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B4V%N9'5C
M92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP
M.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C
M87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C<R"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z
M,C4*;7-G:60@(D5D:70B"FUS9W-T<B`B27IM:6IE;FDB"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P('1E;7!L871E<R]P;W)T86PO961I
M="YI;F,Z,C4*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*(RP@9G5Z
M>GD*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B3V)R:;EI(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C$P,`IM<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S
M='(@(DEZ;6EJ96YI(&1O>G9O;'4B"@HC.B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(DEZ
M;6EJ96YI(&1O>G9O;&4B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R
M("5S(@IM<V=S='(@(DEZ;6EJ96YI(&1O>G9O;&4@>F$@)7,B"@HC.B!T96UP
M;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R
M.B(*;7-G<W1R("))>FUI:F5N:71E(&]P8VEJ92!Z83HB"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@
M(DEZ;6EJ96YI(&1O>G9O;&4@>F$@)7,B"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET
M('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("))>FUI:F5N:2!D;WIV;VQE
M('IA("5S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"B,L(&9U>GIY
M"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B06MC:6IA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HS,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B16ET:&5R(&5N
M86)L92!I="!T:&5N.B`E<RP@;W(@=7-E('1H92!B87-I8R!(5$U,('9E<G-I
M;VXZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A
M;'9A9&]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N="XN+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#8Y"B,L(&9U>GIY"FUS9VED(")%;6%I;"(*;7-G<W1R
M(")386YD=6-E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"FUS9VED(")%;6%I
M;"!!9&1R97-S(@IM<V=S='(@(D5M86EL(&%D<F5S82(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-C,*(RP@9G5Z>GD*;7-G:60@(D5M86EL(&%D
M9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")%;6%I;"!A9')E<V$B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@Y"B,L(&9U>GIY"FUS9VED
M(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")/<W1A;&4@:6YF
M;W)M86-I:F4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S
M;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(Y.`IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(E-M86IL:6II(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R
M"B,L(&9U>GIY"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R(")68;YN
M92!P;W)U:V4B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z,34P"B,L(&9U>GIY"FUS9VED(")%;7!T>2!R97-U;'0N(@IM
M<V=S='(@(DES<')A>FYI(&MO<G!U(@H*(SH@9G)A;65W;W)K+U-13"]344PO
M2V5Y=V]R9',N<&AP.C$Q,PHC+"!F=7IZ>0IM<V=I9"`B16UP='D@<V5A<F-H
M('1E<FUS(@IM<V=S='(@(DES<')A>FYI(&9O;&1E<B!K;W)P82(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#,*;7-G:60@(D5N86)L92!I;G-E<G1I
M;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3@*;7-G:60@
M(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(D%K
M=&EV:7)A:B!K;VYT96MS="!M96YI(&YA(&1E<VYO;2!K;&EK=3\B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,3$*(RP@9G5Z>GD*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@
M(E!R;[EI<FD@9F]L9&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,0IM<V=I9"`B(@HB
M16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A
M<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E
M+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HX.3$*;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDY(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U:6YE
M82(*;7-G<W1R(")%:W9A=&]R:6IA;&YA($=V:6YE:F$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q
M"FUS9VED(")%<FET<F5A(@IM<V=S='(@(D5R:71R96IA(@H*(SH@9G)A;65W
M;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S
M+G!H<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#4@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4U"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S8@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HX,@IM<V=I9"`B
M17)R;W(B"FUS9W-T<B`B1W)EN6MA(@H*(SH@9G)A;65W;W)K+U1E;7!L871E
M+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(D5S=&]N:6IA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B171I;W!I
M:F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI
M8R(*;7-G<W1R(")%=&YIZ&MI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B179R;W!A(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.0IM<V=I9"`B179E<GD@,34@;6EN
M=71E<R(*;7-G<W1R(")3=F%K:6@@,34@;6EN=71A(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,X.0IM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S
M='(@(E-V86MI:"`R(&UI;G5T92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,S8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-PIM<V=I9"`B179E<GD@
M,S`@<V5C;VYD<R(*;7-G<W1R(")3=F%K:6@@,S`@<V5K=6YD:2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,Y,`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(E-V86MI:"`U
M(&UI;G5T82(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC
M92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(DMO9"!S=F%K
M92!P<FEJ879E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,`IM<V=I
M9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(E-V86MI:"!P;VQA('-A=&$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,W(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.#@*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")3=F%K
M:2!M:6YU="(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(T"FUS
M9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B5G)I:F5D;F]S=&D@<')I
M;6IE<FDZ(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D;6EN+V-M9'-H
M96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(W"FUS9VED(")%>&5C
M=71E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C0W-0HC+"!F=7IZ>0IM<V=I9"`B17AP86YD(@IM<V=S='(@(E!R
M;[EI<FD@<W9E(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS
M,@HC+"!F=7IZ>0IM<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B4')O
MN6ER:2!F;VQD97(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP
M:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T
M960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@
M(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8W-@IM<V=I9"`B17AP;VYE;G0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A9"!O9B!S
M971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L
M+G!H<#HR,38*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`HC+"!F=7IZ
M>0IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM
M<V=S='(@(DYE(&UO9W4@<V4@<W!O:FET:2!N82!)34%0('-E<G9E<CH@)7,B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.3@*(RP@9G5Z>GD*
M;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S
M='(@(DYE(&UO9W4@<V4@<W!O:FET:2!N82!)34%0('-E<G9E<CH@)7,B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.3$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"FUS9VED
M(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DW(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(T"B,L('!H<"UF;W)M870*;7-G:60@
M(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`HC+"!F=7IZ>0IM
M<V=I9"`B1F%I<B(*;7-G<W1R("):86ER(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B
M1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B
M0F]U=F5T(&]S=')V;R(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR,S@*
M(RP@9G5Z>GD*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R(")'<F6Y:V$Z
M("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.#<*;7-G:60@(D9A>"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S0Y"B,L(&9U>GIY"FUS9VED(")&87AE<R(*;7-G<W1R("))
M;64B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B1F5B<G5A<B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C(P"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@
M(D9E96QS(&QI:V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-`IM<V=I9"`B1FEE;&0@;6%T
M<FEX(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S
M,S0*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S@*;7-G:60@(D9I9VQE="!F;VYT(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS
M9VED(")&:6QE(@IM<V=S='(@(D9I;'1E<FDB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT
M.B`E<R!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I
M;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,#<*(RP@9G5Z>GD*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R("));64@
M9&%T;W1E:V4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-0HC+"!F
M=7IZ>0IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(DEM92!D871O=&5K92(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34*(RP@9G5Z>GD*;7-G
M:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(FYI:F5D;F\@<')A=FEL;R!N
M:6IE(&]D86)R86YO(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30X
M-@HC+"!F=7IZ>0IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B4&]L:F4B
M"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-3D*;7-G:60@
M(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G:60@(D9I;'1E<G,B"FUS
M9W-T<B`B1FEL=&5R:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(D9I
M;FQA;F0B"FUS9W-T<B`B5')AOFDB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,38V"B,L(&9U>GIY"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(E!R=F$@
M4W1R86YA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M
M;V]N+G!H<#HW-@HC+"!F=7IZ>0IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G
M<W1R(")0<G9A(%-T<F%N82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR-38*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Q
M"FUS9VED(")&;&EP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@
M97AI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR,@HC+"!F=7IZ>0IM<V=I9"`B1F]N="!#;VQO<B(*
M;7-G<W1R(")3=&%N9&%R9&YA(&)O:F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"B,L
M(&9U>GIY"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T
M(&EM86=E<R(*;7-G<W1R(")68;D@8G)O=W-E<B!N92!P;V1ROF%V82!O=G4@
M;6]G=>9N;W-T+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,T"B,L(&9U
M>GIY"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R(")0<FEK8;YI('!R
M;V=N;WIU("A4048I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C<Y"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E
M='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A
M("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@
M8FQO8VLI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,3`R"B,L(&9U>GIY"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B
M"FUS9W-T<B`B27IA8F5R:71E(+EI9G)U(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0V,@HC+"!F=7IZ>0IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B
M3V0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*(RP@9G5Z>GD*;7-G
M:60@(D9O<G1U;F4B"FUS9W-T<B`B1F]L9&5R:2(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B
M1F]R='5N97,B"FUS9W-T<B`B1F]L9&5R:2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS.0HC+"!F=7IZ>0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R
M(")&;VQD97)I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U,PHC
M+"!F=7IZ>0IM<V=I9"`B1F]R=6US(@IM<V=S='(@(D9O;&1E<FDB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`Y"B,L(&9U>GIY"FUS9VED(")&
M;W)W87)D<R(*;7-G<W1R(")0<F]S;&EJ961I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`HC+"!F=7IZ>0IM<V=I9"`B
M1G(B"FUS9W-T<B`B3V0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,S"B,L(&9U>GIY"FUS9VED(")&<F%M97,B
M"FUS9W-T<B`B26UE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B1G)A
M;F-E(@IM<V=S='(@(DEM92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R
M:71O<FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(D]D(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T."!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S8P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HT,#8*(RP@9G5Z>GD*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R
M(")/9"(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS
M9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(D1E=&%L:F%N(&]P:7,B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN<&AP
M.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C8P"B,L(&9U>GIY"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B26UE
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(D=A;6)I82(*;7-G<W1R("):86UB
M:6IA(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*
M;7-G<W1R(")6<F%T:2!S=&%R=2!K;VYF:6=U<F%C:6IU(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E
M9"!#;V1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<U"B,L(&9U>GIY"FUS9VED(")':&%N82(*;7-G<W1R
M(")+:6YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U"B,L
M(&9U>GIY"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(DEM92!D871O=&5K
M92(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*
M;7-G<W1R(")+<F5N:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM
M<V=I9"`B1V]E9&5L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,3(X"B,L(&9U>GIY"FUS9VED(")';V]G
M;&4@36%P<R(*;7-G<W1R(")';V]G;&4@<')E=')A9V$B"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S
M='(@(D=O;V=L92!P<F5T<F%G82(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,S<*;7-G:60@(D=R87ES8V%L92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")'<F5E:R`H25-/+3@X
M-3DM-RDB"FUS9W-T<B`B1W+H:VD@*$E33RTX.#4Y+3<I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-0HC+"!F=7IZ>0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(E1O:R!T96UE
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B1W)E;F%D82(*;7-G<W1R
M(")4;VL@=&5M92(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"B,L(&9U>GIY
M"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(E<R!A9&UI
M;FES=')A8VEJ82(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`Z-3D@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B1W)O
M=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,P-PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U
M<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@
M(DYI:F4@=7-P96QO('-P8;EA=F%N:F4@;F5Z879RN65N92!P;W)U:V4N($]V
M;R!J92!P;W)U:V$@<V5R=F5R83H@)7,B"@HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0Q
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M9&5L971E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5
M;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W"B,L(&9U
M>GIY"FUS9VED(")'<F]U<',B"FUS9W-T<B`B7T=R=7!E(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PHC
M+"!F=7IZ>0IM<V=I9"`B1W5A;2(*;7-G<W1R(")*=6YI(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C@X"B,L(&9U>GIY"FUS9VED(")'=65S="!0
M97)M:7-S:6]N<R(*;7-G<W1R("))>FUI:F5N:2!D;WIV;VQE(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,`IM<V=I9"`B1W5E<W1B;V]K(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(D=U:6YE82(*
M;7-G<W1R(")*=6YI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"B,L(&9U>GIY"FUS9VED(")'
M=6EN96$M0FES<V%U(@IM<V=S='(@(DIU;FDB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*(RP@
M9G5Z>GD*;7-G:60@(D=U>6%N82(*;7-G<W1R(")*=6YI(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L
M971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS
M9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@
M(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T
M(')O=R!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]H='1P+G!H<#HQ-3<*(RP@9G5Z>GD*;7-G:60@(DA45%`@075T:&5N
M=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")5<VUJ97)E;FIE(&YI:F4@
M=7-P96QO+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED
M(")(87-H+4%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B2&%Z92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,3D@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,CDS,@HC+"!F=7IZ>0IM<V=I9"`B2&5A9&5R(@IM
M<V=S='(@(E!O;6_F(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A
M8FQE<V5T+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R
M(")0;VUOYB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N
M9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")(96%V>2!4+5-T
M;W)M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS
M9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B2&5B<F5J<VMI
M("A)4T\M.#@U.2TX+4DI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`HC+"!F=7IZ>0IM<V=I9"`B2&5I9VAT
M(@IM<V=S='(@(DYOYB(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92](96QP
M+G!H<#HQ-SD@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X-@HC
M.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T96UP;&%T97,O:&5L<"]I
M;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*;7-G<W1R(")0;VUOYB(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@
M(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S-S$*(RP@9G5Z>GD*;7-G:60@(DAE;'!E<B(*;7-G
M<W1R(")0;VUOYB(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0HC+"!F=7IZ
M>0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R(")0;VUOYB(*"B,Z('1E;7!L
M871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE
M(&9I;&4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8Y"B,L(&9U>GIY"FUS9VED(")(:6=H(@IM<V=S='(@
M(DYOYB(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T
M97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0IM<V=I9"`B2&]?;64B"FUS
M9W-T<B`B4&_H7V5T86LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E
M92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$U,S4*;7-G:60@(DAO;64B"FUS9W-T<B`B
M4&_H971A:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D%D<F5S82`H
M:W7F:2DB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*(RP@9G5Z>GD*
M;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(D1I<F5K=&]R:6HB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS
M9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(E1E;&5F;VX@*&MUYFDI(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R(")(;VYD=7)A<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(DAO;F<@
M2V]N9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-0IM<V=I9"`B
M2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E
M(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@
M;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$R-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T
M<B`B26UE(&9O;&1E<F$@7"(E<UPB(&IE('5S<&IEN6YO('!R;VUJ96YJ96YO
M('4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S
M"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R
M97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4P,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@
M6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$R-#<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<
M(CH@)7,B"FUS9W-T<B`B26UE(&9O;&1E<F$@7"(E<UPB(&IE('5S<&IEN6YO
M('!R;VUJ96YJ96YO('4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z-#<T"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@
M='EP92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C$Q.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G
M<W1R(")5<W!J9;EN;R!S=&4@<')I:F%V;&IE;FD@;F$@7"(E<UPB(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,V"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N
M:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B57-P:F6Y;F\@<W1E('!R:6IA=FQJ
M96YI(&YA(%PB)7-<(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N
M('-H87)E(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U
M;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM
M<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L
M9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H
M8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(
M;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C,P"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4Y"FUS9VED(")(
M=6UI9&ET>3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G5S+G!H<#HQ-S(@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S
M<6PN<&AP.C(S-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M
M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B57-M:F5R96YJ
M92!N:6IE('5S<&5L;RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I
M;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G5S+G!H<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T
M,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U
M;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B57-M:F5R96YJ92!N
M:6IE('5S<&5L;RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S$V
M"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(DE0(&%D<F5S82(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D
M9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B25`@861R97-A(&YI:F4@
M9&]S='5P;F$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H
M<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$
M4B!B;&]C:RXB"FUS9W-T<B`B25`@861R97-A(&YI:F4@9&]Z=F]L:F5N82!U
M;G5T87(@0TE$4B!B;&]K82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I
M;VQA=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"B,L(&9U>GIY"FUS9VED("))
M7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B4')I;6QJ96YA('!R:6IE(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@(DES;&%N9"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S8*;7-G:60@(DEC;VYS($]N
M;'DB"FUS9W-T<B`B4V%M;R!I:V]N92(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS
M9W-T<B`B26MO;F4@>F$@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S<W"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B26MO;F4@<V$@
M=&5K<W1O;2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3`*;7-G:60@
M(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B26UE(&ED96YT:71E=&$Z(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DR"B,L('!H
M<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C
M=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U-0IM<V=I9"`B(@HB268@
M>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R
M97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N
M(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<S"FUS9VED("(B"B))
M9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G
M92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y
M('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"B,L(&9U>GIY
M"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R(")0<F5T:&]D;F$@<W1R
M86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*
M;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,0HC+"!F=7IZ>0IM<V=I9"`B
M26UA9V4@=7!L;V%D(@IM<V=S='(@(E!O;&IE(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A+V1A=&5M
M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@
M(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T
M82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E
M9"!F:65L9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-0IM
M<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S,@HC+"!F=7IZ>0IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N9"]O
M<B!P87-S=V]R9"XB"FUS9W-T<B`B3FEJ92!P;W-L86YO(&MO<FES;FGH:V\@
M:6UE(&DO:6QI(+EI9G)A+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N
M871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M
M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#$*(RP@9G5Z>GD*;7-G:60@(DEN9&EA(@IM<V=S='(@(FYO;F4B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(DEN9&]N
M97-I82(*;7-G<W1R(")N;VYE(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B26YF;R(*;7-G
M<W1R("))9VYO<FFY:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-3<*(RP@9G5Z>GD*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@(E!E<G-O
M;F%L;F4@:6YF;W)M86-I:F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S,P"B,L(&9U>GIY"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG
M97(@879A:6QA8FQE+B(*;7-G<W1R(").96UA(&1O<W1U<&YI:"!O<&-I:F$N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!);6%G92(*
M;7-G<W1R(")/9&=O=F]R96YE('!O<G5K92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*(RP@9G5Z>GD*;7-G:60@(DEN
M<V5R="!486)L92(*;7-G<W1R(")/9&=O=F]R96YE('!O<G5K92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@
M(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*(RP@9G5Z>GD*
M;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R(")0<FEM;&IE
M;F$@<')I:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@
M869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I
M9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV,@HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(&$@
M;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B4&]D97-I
M('9R96UE;G-K=2!Z;VYU+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W
M(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW
M,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT
M(&YO9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A
M9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA
M=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(S.0IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI
M8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3@*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM
M<V=S='(@(E!R:6UL:F5N82!P<FEJ92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*(RP@9G5Z>GD*;7-G:60@
M(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R(")0<FEM;&IE;F$@<')I:F4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8T"B,L(&9U>GIY"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM
M<V=S='(@(E!R:6UL:F5N82!P<FEJ92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*(RP@9G5Z>GD*;7-G:60@
M(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(E!R:6UL:F5N82!P<FEJ
M92(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP
M"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS9W-T<B`B1&]D879A;FIE('!O
M<G5K82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#0*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!P87)A
M9W)A<&@@8F5F;W)E(@IM<V=S='(@(E!R:6UL:F5N82!P<FEJ92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*
M(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B3V1G
M;W9O<F5N92!P;W)U:V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8X"B,L(&9U>GIY"FUS9VED("));G-E<G0@
M<F]W(&)E9F]R92(*;7-G<W1R(")0<FEM;&IE;F$@<')I:F4B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C,P"FUS9VED("));G-E<G0@=&AE(')E<75I
M<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C8*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T
M<B`B3V1G;W9O<F5N92!P;W)U:V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@Y"B,L(&9U>GIY"FUS9VED("));G-E<G0O
M36]D:69Y($QI;FLB"FUS9W-T<B`B7TEZ;6EJ96YI(&QI;FLN+BXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM
M<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T
M<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC
M:65N="!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$P-S4*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$S,PIM<V=I9"`B26YT96=E<B!L:7-T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A
M=&$@2&5A9&5R*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+WII<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]Z:7`N<&AP.C(P,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O>FEP+G!H<#HR,3`*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`HC+"!F=7IZ
M>0IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B3F5D;WIV
M;VQJ96YA('-L;W9A('4@96UA:6P@861R97-I+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV
M86QI9"!B871C:"!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B
M;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#`*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@9&5S=&EN
M871I;VX@861D<F5S<RXB"FUS9W-T<B`B3F5D;WIV;VQJ96YA('-L;W9A('4@
M96UA:6P@861R97-I+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]D8G@N<&AP.C@Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D
M8G@N<&AP.C$P,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X
M+G!H<#HR,C`*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B
M"FUS9W-T<B`B5G)E;65N<VMA('IO;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,3<W"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&QI8V5N
M<V4@:V5Y+B(*;7-G<W1R(").961O>G9O;&IE;F$@<VQO=F$@=2!E;6%I;"!A
M9')E<VDN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,0HC
M+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS
M9W-T<B`B3F5D;WIV;VQJ96YA('-L;W9A('4@96UA:6P@861R97-I+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"B,L
M(&9U>GIY"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G
M<W1R(").961O>G9O;&IE;F$@<VQO=F$@=2!E;6%I;"!A9')E<VDN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV
M"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R
M<RXB"FUS9W-T<B`B3F5D;WIV;VQJ96YA('-L;W9A('4@96UA:6P@861R97-I
M+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PHC+"!F=7IZ>0IM
M<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B3F5D
M;WIV;VQJ96YA('-L;W9A('4@96UA:6P@861R97-I+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S,*(RP@9G5Z>GD*;7-G:60@(DEN=F%L
M:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B3F5D;WIV;VQJ96YA('-L;W9A('4@
M96UA:6P@861R97-I+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-S4*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*
M;7-G<W1R(").961O>G9O;&IE;F$@<VQO=F$@=2!E;6%I;"!A9')E<VDN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`V"B,L(&9U>GIY"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R
M(").961O>G9O;&IE;F$@<VQO=F$@=2!E;6%I;"!A9')E<VDN(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C<Q(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P-S8@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,C8R"B,L(&9U>GIY"FUS9VED("));G9A;&ED('-H
M87)E(&]B:F5C="(*;7-G<W1R(").961O>G9O;&IE;F$@<VQO=F$@=2!E;6%I
M;"!A9')E<VDN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`Q"B,L(&9U>GIY"FUS9VED("));G9A;&ED('-O=7)C
M92!A9&1R97-S+B(*;7-G<W1R(").961O>G9O;&IE;F$@<VQO=F$@=2!E;6%I
M;"!A9')E<VDN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$Q"B,L(&9U>GIY"FUS9VED("));G9A;&ED('5N:6-O
M9&4@9&%T82XB"FUS9W-T<B`B3F5D;WIV;VQJ96YA('-L;W9A('4@96UA:6P@
M861R97-I+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3<*;7-G
M:60@(DEN=F5N=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<Y"B,L(&9U>GIY"FUS9VED("));G9E
M<G0@<V5L96-T:6]N(@IM<V=S='(@(E9R96UE;G-K82!Z;VYA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B
M5&]K('1E;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM
M<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M
M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`HC+"!F=7IZ>0IM<V=I
M9"`B27-R865L(@IM<V=S='(@(E1O:R!T96UE(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C4*;7-G:60@(DES<W5E<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CD*;7-G:60@(DET86QI8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*(RP@
M9G5Z>GD*;7-G:60@(DET86QY(@IM<V=S='(@(D1N979N;R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,@HC+"!F=7IZ>0IM<V=I9"`B2F%M86EC82(*;7-G<W1R("):86UB:6IA
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*
M;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B2F%N=6%R(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S
M"FUS9VED(")*87!A;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X-PIM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R
M(")*87!A;G-K:2`H25-/+3(P,C(M2E`I(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HS,3`*;7-G:60@(B(*(DIA=F%S8W)I<'0@:&%S(&)E96X@
M9&ES86)L960@;VX@>6]U<B!B<F]W<V5R(&%N9"!T:&ES('!A9V4@;6%Y(&YO
M="!B92`B"B)D:7-P;&%Y:6YG(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`W"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M,0IM<V=I9"`B2G5L>2(*;7-G<W1R(")*=6QI(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T
M<B`B2G5N:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS
M9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU
M<W1I9GD@3&5F="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2
M:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T
M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(V-`IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+97)B97)O
M<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE
M=V)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$Q"B,L(&9U>GIY"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T
M<B`B3W!C:6IE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N
M9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,0HC+"!F=7IZ>0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B36EM
M92!T:7`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y
M.`HC+"!F=7IZ>0IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(E!O<G5K82(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B
M2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@
M(DMI9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T
M:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*(RP@9G5Z>GD*;7-G:60@(DMO
M<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@
M(DQA;R!.87)O9&YA($1E;6]K<F%T<VMA(%)E<'5B;&EK82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")+;W)E86X@*$550RU+
M4BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B
M3&%?>6]U="(*;7-G<W1R(")285]S<&]R960B"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG=6%G92(*;7-G<W1R(")*97II
M:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T
M:6,@4F5P=6)L:6,B"FUS9W-T<B`B3&%O($YA<F]D;F$@1&5M;VMR871S:V$@
M4F5P=6)L:6MA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0HC+"!F=7IZ
M>0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(E!R=F$@4W1R86YA(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"B,L(&9U>GIY"FUS9VED("),87-T
M(%!A<W-W;W)D($-H86YG92(*;7-G<W1R(")087-S=V]R9"(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*(RP@9G5Z
M>GD*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R(")0<G9A(%-T<F%N82(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Q"FUS9VED("),87-T(%5P9&%T
M960Z(@IM<V=S='(@(EIA9&YJ82!I>FUJ96YA.B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO
M9VEN.B`E<R(*;7-G<W1R("):861N:F$@<')I:F%V83H@)7,B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HW,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R("):861N:F$@<')I:F%V
M83H@)7,@<V$@861R97-E.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.C<Q-@IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B6F%D
M;FIA('!R:6IA=F$Z($YI:V%D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V
M:6$B"FUS9W-T<B`B3&%T=FEJ82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(EIA:V]N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),
M87EO=70B"FUS9W-T<B`B4F%S<&]R960B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F
M;W(@;F\@8F]R9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B
M3&5B86YO;B(*;7-G<W1R("),:6)A;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0HC+"!F=7IZ>0IM<V=I9"`B
M3&5F="(*;7-G<W1R(")0<F5B86-I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S$Q.0IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-0HC+"!F=7IZ>0IM<V=I9"`B
M3&5F="!V86QU97,B"FUS9W-T<B`B6F%D;FIA('-T<F%N82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("),97-O=&\B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(DQE
M=F5L(@IM<V=S='(@(DYI:V%D82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB
M97)I82(*;7-G<W1R("),:6)E<FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B
M3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("),:6)I:G-K82!!<F%P
M<VMA($2^86UA:&ER:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C:'1E
M;G-T96EN(@IM<V=S='(@(DQI:'1E;KET86IN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT($1R:7IZ
M;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T
M<B`B4')I:F%V:2!S92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN($5A<FQY(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X
M"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT
M(%)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I=&@@
M5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM
M<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0U"B,L(&9U>GIY"FUS9VED("),:6UE<FEC:R(*
M;7-G<W1R("),:6)E<FEJ82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X,30*(RP@9G5Z>GD*;7-G:60@(DQI;FLB"FUS9W-T<B`B3&EN:V]V:2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S4*;7-G:60@(DQI;FL@=&AE
M(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L
M87EI;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]H=&UL,G1E>'0N<&AP.C$X,PIM<V=I9"`B3&EN:W,B"FUS9W-T<B`B
M3&EN:V]V:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@HC+"!F=7IZ
M>0IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(DYO=F$@<&]R=6MA(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G
M:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("),
M:7-T86YJ92`M(&MO<FES;FEK(&UOOF4@=FED:F5T:2!F;VQD97(B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"B,L(&9U>GIY"FUS9VED("),:7-T($1A
M=&%B87-E<R(*;7-G<W1R("):861N:F$@<W1R86YA(@H*(SH@<V5R=FEC97,O
M:&5L<"]I;F1E>"YP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(DQI<W0@2&5L<"!4
M;W!I8W,B"FUS9W-T<B`B4&]M;^8B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3,R"B,L(&9U>GIY"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R("):861N
M:F$@<W1R86YA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.30*(RP@9G5Z>GD*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R(")3
M86MR:6H@;F5U<&ES86YE(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D
M97)S+G!H<#HU.#D*(RP@9G5Z>GD*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R
M(")0;VUOYB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3DV"B,L(&9U>GIY"FUS9VED("),:7-T+4ED(@IM<V=S='(@(E!O;6_F(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3(*(RP@9G5Z
M>GD*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B4&]M;^8B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0
M;W-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R
M<RYP:'`Z-3DQ"B,L(&9U>GIY"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G
M<W1R(")386MR:6H@;F5U<&ES86YE(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12](96%D97)S+G!H<#HU.3`*(RP@9G5Z>GD*;7-G:60@(DQI<W0M56YS=6)S
M8W)I8F4B"FUS9W-T<B`B4V%K<FEJ(&YE=7!I<V%N92(*"B,Z(&%D;6EN+W-E
M<W-I;VYS+G!H<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3&ES
M=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(E5S;6IE<F5N:F4@
M;FEJ92!U<W!E;&\N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"B,L('!H
M<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*
M;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-PHC+"!F=7IZ>0IM<V=I9"`B
M3&ET97)A='5R92(*;7-G<W1R(")68;D@<&]T<&ES.B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(DQI='9A(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6UA9V5S+G!H<#HX,PIM<V=I9"`B3&]A
M9&EN9RXN+B(*;7-G<W1R(")5Z&ET879A;2XN+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,3$*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G
M<W1R("),;VMA;&YO('9R:6IE;64Z("(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX,PIM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(DQO:V%L
M;F4@<&]S=&%V:V4@:2!V<FEJ96UE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C8T"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T
M87(N<&AP.C8U"FUS9VED("),;V-A=&EO;B(*;7-G<W1R("),;VMA8VEJ82(*
M"B,Z(&QO9VEN+G!H<#HQ-S(@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M.C$Y,2!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z.3`*;7-G:60@(DQO9R!I;B(*;7-G<W1R(")0<FEJ879I('-E(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@;V8@
M<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HQ.#4*;7-G:60@(DQO9R!O=70B"FUS9W-T
M<B`B27IL87HB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*(RP@9G5Z
M>GD*;7-G:60@(DQO9VEN(@IM<V=S='(@(E!R:6IA=FD@<V4B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`W"FUS9VED("),;V=I;B!487-K<R(*;7-G
M<W1R("):861A8VD@<')I:F%V92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDY-@IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R
M;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS
M9W-T<B`B(@HB4')I:F%V82!N:6IE('5S<&IE;&$N($YA:G9E<F]V871N:6IE
M(&IE('!O9W)EN6YO('5N97-E;F\@:V]R:7-N:>AK;R!I;64@:6QI("(*(KEI
M9G)A+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,@IM<V=I9"`B
M3&]G:6X@9F%I;&5D+B(*;7-G<W1R(")0<FEJ879A(&YI:F4@=7-P:F5L82XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8U"FUS9VED("),;VYG
M('1E>'0B"FUS9W-T<B`B1'5G:2!T96MS="(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B3&]V92(*;7-G<W1R(").87-T
M879I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C<*(RP@9G5Z>GD*;7-G:60@(DQO=R(*;7-G<W1R("):86MO;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$W"B,L(&9U>GIY"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM
M<V=S='(@(D1E8V5M8F%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE;6)O
M=7)G(@IM<V=S='(@(DQU:W-E;6)U<F<B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,S@@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-3`*;7-G:60@(DU-(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR.#$*;7-G:60@(DU/5$0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.
M148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O;6]B:6QE+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B35-'(@IM<V=S='(@
M(D--4R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B36%C86\B"FUS
M9W-T<B`B36%R="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4
M:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*(RP@9G5Z>GD*;7-G:60@(DUA9VEC
M(@IM<V=S='(@(DUA<G0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M.#$*(RP@9G5Z>GD*;7-G:60@(DUA:6PB"FUS9W-T<B`B4V%N9'5C92(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C(*;7-G:60@(DUA:6P@061M
M:6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%L87=I
M(@IM<V=S='(@(E-A;F1U8V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y
M<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B
M36%L9&EV97,B"FUS9W-T<B`B1FEL=&5R:2!P;[ET92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,@HC+"!F=7IZ>0IM<V=I9"`B36%L:2(*;7-G<W1R(")386YD=6-E(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-86QT82(*;7-G<W1R(")386YD
M=6-E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ"FUS9VED("(B"B)-
M86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E
M;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T
M:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"B).87!R879I=&4@:V%T96=O
M<FEJ92!S=&%V:VD@:2!Z82!S=F%K=2!O9"!N:FEH(&]D<F5D:71E(&]D9V]V
M87)A:G7F=2!B;VIU+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,34S"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#0*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-C@*
M;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(DUA<G0B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"B,L
M(&9U>GIY"FUS9VED(")-87)G:6XB"FUS9W-T<B`B57!O>F]R96YJ92(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED
M(")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B3WIN8>AA
M=F%N:F4@:V%O('!R;^AI=&%N;R]N97!R;^AI=&%N;R(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I
M=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G
M<W1R(")/>FYAZ&%V86YJ92!D<G5G:6T@;WIN86MA;6$@*&YP<BX@=F&^;F\@
M:6QI(&]D9V]V;W)E;F\I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L
M;"!)<VQA;F1S(@IM<V=S='(@(DUA<KEA;&]V82!O<W1R=F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R=&EN:6LB"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI
M;F<@9FEE;&1S(@IM<V=S='(@(D]D9V]V87)A:G7F82!P;VQJ82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G<W1R(")-875R:71A;FEJ
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(DUA
M=7)I8VEJ=7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`X"B,L(&9U>GIY"FUS9VED(")-87@@;65S<V%G92!P87)T
M<R!E>&-E961E9"XB"FUS9W-T<B`B4&]L:F$@<&]R=6ME(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U
M<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y.`IM
M<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A
M;"!";&]C:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG=&@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R(")-86HB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$W"B,L(&9U>GIY"FUS9VED(")-87EO='1E(@IM<V=S='(@(DUA:B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B365D
M:6-I;F4B"FUS9W-T<B`B3V)R:7-A;F$B"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB97)S(@IM<V=S='(@(LAL
M86YO=FDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X"FUS9VED(")-
M96YU(&UO9&4Z(@IM<V=S='(@(E9R<W1A(&UE;FEJ83HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS9VED
M(")-97)G92!C96QL<R(*;7-G<W1R(")3<&]J:2!P;VQJ82(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U
M<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS
M9VED(")-97-S86=E(@IM<V=S='(@(E!O<G5K82(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E
M<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC
M871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P
M"B,L(&9U>GIY"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(E!O
M;&IA('!O<G5K92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*(RP@9G5Z>GD*;7-G:60@(DUE
M<W-A9V4@='EP92(*;7-G<W1R(")$871U;2!P;W)U:V4B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B
M365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3F5M82!D;W-T
M=7!N:6@@;W!C:6IA+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$R"B,L
M(&9U>GIY"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R(")/=F$@<&]R=6MA(&IE('!R:6IA=FQJ96YA(&MA;R!S<&%M
M('!O<G5K82!A9&UI;FES=')A=&]R=2!S:7-T96UA+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DUE=&%R1$(@:7,@;F]T
M(&-O;FYE8W1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")-971H;V0B"FUS9W-T<B`B
M3&5S;W1O(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX,2!F
M<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HW-"!L:6(O0FQO8VLO;65T87(N<&AP.C<U"FUS9VED(")-971R:6,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-97AI8V\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3
M=&%T97,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<V"B,L(&9U>GIY"FUS9VED(")-:61D
M;&4B"FUS9W-T<B`B4')E8F%C:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B
M36EM92!T:7`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,`IM<V=I9"`B
M36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S`R"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U
M<G,Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y
M970@97AP:7)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C,T"B,L(&9U>GIY"FUS9VED(")-:7)R;W(B
M"FUS9W-T<B`B1W)EN6MA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q
M"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B
M36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-:7-S
M:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO
M=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`T"B,L(&9U>GIY"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@
M240N(@IM<V=S='(@(D]V82!P;W)U:V$@=2(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S
M:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.30*(RP@9G5Z>GD*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T
M<B`B3W9A('!O<G5K82!U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHU-@HC+"!F=7IZ>0IM<V=I9"`B36\B"FUS9W-T<B`B
M4')E8F%C:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-`HC+"!F
M=7IZ>0IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B3F]V82!P;[ET82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS
M9VED(")-;V1E<F%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HX.`IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3,*(RP@9G5Z>GD*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B7TEZ
M;6EJ96YI(&QI;FLN+BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8W,PHC+"!F=7IZ>0IM<V=I9"`B36]D=6QU<R(*;7-G<W1R(")0
M<F5B86-I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI
M8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*(RP@9G5Z>GD*;7-G:60@
M(DUO;F%C;R(*;7-G<W1R(")-87)T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-
M;VYG;VQI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-3DT"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED
M(")-;VYT:&QY(@IM<V=S='(@(DUJ97-EZ&YO(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS
M9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M,3<R(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(U,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@
M=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G
M:60@(DUO<F]C8V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS-`HC+"!F=7IZ>0IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R(")+
M;W!I<F%J(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S4*;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#D*(RP@9G5Z>GD*;7-G
M:60@(DUO=F4@1&]W;B(*;7-G<W1R(")P;VUJ97)I(&YIOF4B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3,*(RP@9G5Z>GD*;7-G
M:60@(DUO=F4@3&5F="(*;7-G<W1R(")0<F5B86-I(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$W"B,L(&9U>GIY"FUS9VED(")-
M;W9E(%)I9VAT(@IM<V=S='(@(E!R96)A8VDB"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#4*(RP@9G5Z>GD*;7-G:60@(DUO=F4@
M57`B"FUS9W-T<B`B4')E8F%C:2(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HU,C0*(RP@9G5Z>GD*;7-G:60@(DUO=F4@9&]W
M;B(*;7-G<W1R(")P;VUJ97)I(&YIOF4B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(S"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU,C0*(RP@9G5Z>GD*;7-G:60@(DUO=F4@
M=7`B"FUS9W-T<B`B<&]M:F5R:2!V:;EE(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"B,L(&9U
M>GIY"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(DUA<G1I;FEK(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-`IM<V=I9"`B375L=&DM;&5V
M96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#4U"FUS9VED(")-=6QT:6UA
M<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(T,@HC+"!F=7IZ>0IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM
M<V=S='(@(FYI:F5D;F\@<')A=FEL;R!N:6IE(&]D86)R86YO(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,`HC+"!F=7IZ>0IM<V=I9"`B37D@
M06-C;W5N="(*;7-G<W1R(")28>AU;F]V;V1S='9O(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C(X"B,L(&9U>GIY"FUS9VED(")->2!!8V-O=6YT($EN
M9F]R;6%T:6]N(@IM<V=S='(@(E9AN64@:6YF;W)M86-I:F4B"@HC.B!S97)V
M:6-E<R]P;W)T86PO:6YD97@N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")->2!0
M;W)T86PB"FUS9W-T<B`B4F%S<&]R960@;6]G('!O<G1A;&$B"@HC.B!S97)V
M:6-E<R]P;W)T86PO961I="YP:'`Z,3,V"FUS9VED(")->2!0;W)T86P@3&%Y
M;W5T(@IM<V=S='(@(E)A<W!O<F5D(&UO9R!P;W)T86QA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$
M;R!.3U0@06=R964B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE
M9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`B26UE(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDU"B,L(&9U>GIY"FUS9VED(").86UI8FEA(@IM<V=S='(@(EIA;6)I:F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-PHC+"!F=7IZ>0IM<V=I9"`B3F5P86PB"FUS9W-T<B`B3F]V82!P
M;[ET82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-PHC+"!F=7IZ>0IM<V=I9"`B3F5T:&5R;&%N
M9',B"FUS9W-T<B`B3F]V:2!:96QA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B
M3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E($)A
M<V4@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N(%52
M3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-`IM
M<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C
M87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P92!34TP@
M<V5R=F5R(&YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E
M(&-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#`*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y
M<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U
M,0IM<V=I9"`B3F5T=V]R:R(*;7-G<W1R(")-<F6^82(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S,U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*;7-G:60@(DYE
M=F5R(@IM<V=S='(@(DYI:V%D82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F5W
M($-A;&5D;VYI82(*;7-G<W1R(").;W9A($MA;&5D;VYI:F$B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I
M9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(DYO=F$@:V%T96=O<FEJ82(*"B,Z
M(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX,0HC
M.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#<*
M(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.CDW
M"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HQ
M,#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O
M("5S(@IM<V=S='(@(DYO=F$@<&]R=6MA("@E<RDB"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(DYO=FD@;6IE
M<V5C(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM
M<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B3F]V;R!K
M;W)I<VYIZ&MO(&EM92`H;FEJ92!O8F%V97IN;RDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*
M;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(DYO=FD@6F5L86YD(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED
M(").97<@<&%S<W=O<F0B"FUS9W-T<B`BJ6EF<F$B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@(DYE
M=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED(").97<@<&%S
M<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN
M9&]W("A?8FQA;FLI(@IM<V=S='(@(DYO=FD@<')O>F]R("A?<')A>F%N*2(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y"FUS9VED
M(").97=S(@IM<V=S='(@(DYO=F]S=&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S`U"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(DYE=W,M
M9W)U<&4B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-2!T96UP
M;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-0IM
M<V=I9"`B3F5X="(*;7-G<W1R(")$86QJ92(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R
M(")3;&IE9&7F82!F87IA(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HS-S(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S8*;7-G
M:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R(")3;&IE9&7F92!O<&-I:F4B"@HC
M.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I
M9"`B3F5X=#XB"FUS9W-T<B`B1&%L:F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@
M(DYI8V%R86=U82(*;7-G<W1R(").:6MA<F%G=F$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*
M;7-G:60@(DYI9V5R(@IM<V=S='(@(DYI9V5R(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS
M9VED(").:6=E<FEA(@IM<V=S='(@(DYI9V5R:6IA(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,X,`IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B
M3F_F(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").:75E(@IM<V=S='(@(DYI=64B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S
M"FUS9VED(").;R(*;7-G<W1R(").92(*"B,Z('1E;7!L871E<R]A9&UI;B]S
M971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R
M871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ
M,#4*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E3
M3R!I;6%G97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M
M<&QA=&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C<Y(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C(T-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-C<*
M;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP
M:'`Z-3`*;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#
M04P@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C4T"B,L(&9U>GIY"FUS9VED(").;R!C:&%N9V4N(@IM<V=S
M='(@(E!R;VUJ96YI(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES
M('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,38W(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`R"B,Z
M(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<W,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.#(T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HV-CD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S$W"FUS9VED
M(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,+49I;&4@5D93+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I
M="!L969T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S-`HC+"!F=7IZ>0IM<V=I9"`B3F\@9&5S
M=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(DYO=F4@<&]R=6ME(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<W"B,L(&9U>GIY"FUS
M9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(E!O;&IE(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(").;R!I8V]N
M<R!F;W5N9"XB"FUS9W-T<B`B)7,@;FEJ92!P<F]N8?!E;BXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(X(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R,PIM<V=I9"`B3F\@
M;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(").;R!L;V-A=&EO
M;B!P<F]V:61E9"XB"FUS9W-T<B`B3FEJ961A;B!F;VQD97(@;FEJ92!S<&5C
M:69I8VER86XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S,PHC+"!F=7IZ>0IM<V=I9"`B3F\@;65S<V%G92!S=7!P
M;&EE9"XB"FUS9W-T<B`B3F]V92!P;W)U:V4B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@HC+"!F=7IZ>0IM<V=I
M9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@(FYI:V%K878@=&5K<W0@
M;FEJ92!S<&5C:69I8VER86XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S-PHC+"!F=7IZ>0IM<V=I9"`B3F\@;G5M
M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B;FEK86MA=B!T96MS="!N:6IE('-P
M96-I9FEC:7)A;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I
M9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z
M-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN+G!H
M<#HX-`HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*;7-G:60@
M(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P87-S=V0N
M<&AP.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-7
M1"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#8*;7-G:60@(B(*(DYO
M('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E
M;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3
M(#$R(&1A=&$N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C<U,`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R(").
M92!I>F)R:7-A;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0S"B,L(&9U>GIY"FUS9VED(").;R!R=6QE<R(*
M;7-G<W1R(").:6IE9&YA(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z-#0Y"B,L(&9U>GIY"FUS9VED(").;R!S97!A<F%T;W(@<W!E8VEF:65D
M+B(*;7-G<W1R(")N:6MA:V%V('1E:W-T(&YI:F4@<W!E8VEF:6-I<F%N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT-`HC+"!F=7IZ>0IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B3F4@:7IB
M<FES86YA(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#,*;7-G
M:60@(DYO('-U8V@@9FEL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3,X"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T
M;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"FUS9VED(").
M;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B3FEJ
M92!P;W-L86YO(&MO<FES;FGH:V\@:6UE(&DO:6QI(+EI9G)A+B(*"B,Z(&9R
M86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI
M9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3<Q"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HY.#$*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY,@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`P.0IM<V=I9"`B3F\@=F%L=65S
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G
M:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO
M;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O
M=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES
M96QE8W0N:6YC.CDS"FUS9VED(").;VYE(@IM<V=S='(@(DYI:F5D86XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS
M9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P
M*2(*;7-G<W1R(").;W)D:6IS:VD@*$E33RTX.#4Y+3$P*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-@HC+"!F=7IZ>0IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B
M36%RN6%L;W9A(&]S=')V82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"B,L(&9U>GIY"FUS9VED(").
M;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B36%RN6%L;W9A(&]S
M=')V82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-PHC+"!F=7IZ>0IM<V=I9"`B3F]R=V%Y(@IM
M<V=S='(@(E!R;W-L:6IE9&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8T,`HC+"!F=7IZ>0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S
M='(@(DYO="!$<F%F="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C,Y"B,L(&9U>GIY"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@
M(DYO="!$<F%F="(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0P
M.`HC+"!F=7IZ>0IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(E!R
M879A8R!S;W)T:7)A;FIA(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX,PHC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+G!H<#HY-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*(RP@
M9G5Z>GD*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B3F4@:7IB
M<FES86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV.`HC+"!F=7IZ>0IM<V=I9"`B3F]T('-E="(*;7-G<W1R(").92!I
M>F)R:7-A;F$B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO
M;DAA;F1L97(N<&AP.C$T,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O
M4V5S<VEO;DAA;F1L97(N<&AP.C$U.`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA
M;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W,PHC.B!F<F%M97=O<FLO4V5S
M<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X-PHC.B!F<F%M97=O
M<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-"!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S,`HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C0X(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-C4*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,CDW"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,3(@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C,R.0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8R
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HT,C(*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C4P,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<P"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HU.#<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V
M-0HC+"!F=7IZ>0IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B3F4@
M:7IB<FES86YA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`P-0HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3<X"B,L(&9U>GIY"FUS9VED(").;W1E
M<R(*;7-G<W1R(").:6IE9&YA(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD
M97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(DYO=F5M8F%R(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`T-@HC+"!F=7IZ>0IM<V=I
M9"`B3G5M8F5R(@IM<V=S='(@(DYO=F5M8F%R(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30R-0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(S"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T-#4@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#0*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS
M(@IM<V=S='(@(G!O;6IE<FD@;FF^92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0S('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"B,L(&9U>GIY"FUS9VED(").=6UB
M97(@;V8@<F]W<R(*;7-G<W1R(").;W9E;6)A<B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB
M97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO
M;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*(RP@9G5Z
M>GD*;7-G:60@(D]B:F5C="(*;7-G<W1R(")496UA(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,3$*(RP@9G5Z>GD*;7-G:60@(D]B:F5C="!#
M<F5A=&]R(@IM<V=S='(@(E1E;6$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E
M<B(*;7-G<W1R(")/:W1O8F%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(V"FUS9VED(")/9F9I8V4B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED
M(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@HC
M+"!F=7IZ>0IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(JEI9G)A(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"B,L(&9U>GIY"FUS
M9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@(E!A
M<W-W;W)D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS
M9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G
M:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3$@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3DW,0HC+"!F=7IZ>0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D
M<F5S<R!A;&QO=V5D+B(*;7-G<W1R(").961O>G9O;&IE;F$@<VQO=F$@=2!E
M;6%I;"!A9')E<VDN(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C8U
M"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R
M871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S
M:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R
M86UE+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*
M;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@
M9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM
M<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P97)A
M=&EN9R!3>7-T96TB"FUS9W-T<B`B3W!E<F%T:79N:2!S:7-T96TB"@HC.B!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS
M(@IM<V=S='(@(D]P8VEJ92(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T
M96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R(")/<&-I:F4@>F$@)7,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"B,L(&9U
M>GIY"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B3&ES=&$@<V$@=&'H
M:V%M82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38W
M"B,L(&9U>GIY"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B4F5G:7-T
M<F%C:6IA(&MO<FES;FEK82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S(*(RP@9G5Z
M>GD*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B57!O>F]R96YJ92(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L
M:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP
M;&%T97,@:6X@)7,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED
M(")/=&AE<B(*;7-G<W1R(")/<W1A;&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C(*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,2!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,30Q"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R(")/
M<W1A;&4@:6YF;W)M86-I:F4B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C,Q"B,L(&9U>GIY"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G
M<W1R(")+;W)I<VYIZ&ME(&]P8VEJ92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<&%M+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T
M:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E5S;6IE<F5N:F4@;FEJ
M92!U<W!E;&\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?
M<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(W,PHC
M+"!F=7IZ>0IM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@
M(EIA=&%M;FD@<&]T<&ES93\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,S$Y"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W,0IM
M<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U,PIM<V=I9"`B4$=0(%-I9VYE9"]%
M;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP
M:'`Z-C@*(RP@9G5Z>GD*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(DAO<F1E
M(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@
M(E!-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*
M;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4W5N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0R"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E;G-I
M;VX@:7,@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#D*
M;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D
M9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@
M(E!A:VES=&%N(@IM<V=S='(@(D%F9V%N:7-T86XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q
M"FUS9VED(")086QA=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED
M(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B4&%N86UA(@IM<V=S='(@
M(DMA;F%D82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"B,L(&9U>GIY"FUS9VED(")0
M87)A9W5A>2(*;7-G<W1R(").:6MA<F%G=F$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@HC+"!F=7IZ>0IM<V=I9"`B4&%R
M=&QY($-L;W5D>2(*;7-G<W1R(")+;W!I<F%J(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`Q.`HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C<W('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R,PIM<V=I9"`B4&%S<W=O<F0B
M"FUS9W-T<B`BJ6EF<F$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C$S,C(*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G
M<W1R(")087-S=V]R9"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S
M+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(P-3,*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D('=I=&@@
M8V]N9FER;6%T:6]N(@IM<V=S='(@(E!A<W-W;W)D(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.CDP"B,L(&9U>GIY"FUS9VED(")087-S=V]R
M9#HB"FUS9W-T<B`B4&%S<W=O<F0B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B
M:6QE+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R
M(")087-S=V]R9"(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z,34*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA
M=&-H+B(*;7-G<W1R(")%;6%I;"!A9')E<V$B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3$Y('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR,@HC+"!F=7IZ>0IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B
M1&%T=6TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q
M"B,L(&9U>GIY"FUS9VED(")0871H(@IM<V=S='(@(D1A='5M(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG
M;G5P<SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T
M"FUS9VED(")096]P;&4B"FUS9W-T<B`B3&IU9&DB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N
M="(*;7-G<W1R(")0<F]C96YA="(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA
M;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B27IV<KEI('-E<G9I<VYE(&]P97)A
M8VEJ92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#8*;7-G:60@(E!E
M<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T
M<B`B27IV<KEI('-E<G9I<VYE(&]P97)A8VEJ92!P<FEL:6MO;2!L;V=I<F%N
M:F$_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G
M:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B1&]Z=F]L92(*"B,Z(&%D;6EN+W!E
M<FUS+V1E;&5T92YP:'`Z-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R(")$;WIV
M;VQE('IA(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#8*(RP@
M9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(D1O>G9O
M;&4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`HC+"!F=7IZ>0IM<V=I9"`B
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B7T1O>G9O;&4B"@HC.B!A9&UI;B]P97)M
M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z
M(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C4X"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G
M<W1R(")!9&UI;FES=')A8VEJ82!D;WIV;VQA("AP<FEV:6QE9VEJ82DB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*;7-G:60@(E!E<G-O;F%L($EN
M9F]R;6%T:6]N(@IM<V=S='(@(DQIZ&YE(&EN9F]R;6%C:6IE(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDX"FUS9VED(")097)U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*(RP@9G5Z>GD*
M;7-G:60@(E!H;VYE(@IM<V=S='(@(FYO;F4B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#<X"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@
M(E!I>&5L<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B
M4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO
M=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L
M96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE
M;65N="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C4W,0HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD
M(&$@>65A<BXB"FUS9W-T<B`B36]L:6T@=&4@<&]P<F%V:2!D=F]S;6ES;&5N
M92!O9&YO<VYO(&EN=F%L:61N92!A9')E<V4N(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E
M;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#$*(RP@9G5Z>GD*;7-G
M:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@
M(DUO;&EM('1E('!O<')A=FD@9'9O<VUI<VQE;F4@;V1N;W-N;R!I;G9A;&ED
M;F4@861R97-E+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C`*
M;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N
M=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-3$*(RP@9G5Z>GD*;7-G:60@(E!L
M96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(DUO;&EM('1E('!O
M<')A=FD@9'9O<VUI<VQE;F4@;V1N;W-N;R!I;G9A;&ED;F4@861R97-E+B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L
M96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T
M<B`B36]L:6UO(&1A:G1E(&MR871A:R!O<&ES('9AN65G('!R;V)L96UA('-A
M('=E8FUA:6QO;2XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*(RP@9G5Z>GD*;7-G:60@
M(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM
M<V=S='(@(DYI:F4@<&]S;&%N;R!K;W)I<VYIZ&MO(&EM92!I+VEL:2"Y:69R
M82XB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*
M(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R
M964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G
M97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y
M(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0HC+"!F=7IZ>0IM<V=I
M9"`B4&]L86YD(@IM<V=S='(@(E1R8;YI(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@W"FUS9VED(")0;VQL<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O
M<F-E9"!B>2!)34%0*2(*;7-G<W1R(")3;&%N:F4@=2!O=F%J(&9O;&1E<B`H
M;FEJ92!P<FEN=?!E;F\@;V0@<W1R86YE($E-05!A*2(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C8V(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U
M<BAS*3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.3@*;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP.CDX
M"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER
M960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-0IM<V=I9"`B4')E<W-U<F4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G:60@(E!R
M97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*(RP@9G5Z>GD*;7-G:60@(E!R97-S
M=7)E.B`B"FUS9W-T<B`B4&%S<W=O<F0B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`U"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PHC+"!F=7IZ>0IM
M<V=I9"`B4')E=FEE=R(*;7-G<W1R(")0<F5T:&]D;F$@<W1R86YA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD
M;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HS-C(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8*;7-G:60@
M(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B4')E=&AO9&YE(&]P8VEJ92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*
M;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP
M.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R(")0<F]B;&5M/R(*"B,Z('-E
M<G9I8V5S+W!R;V)L96TN<&AP.C$R-@IM<V=I9"`B4')O8FQE;2!$97-C<FEP
M=&EO;B(*;7-G<W1R(")/<&ES('!R;V)L96UA(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,V.0IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,3@X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M.#4*(RP@9G5Z>GD*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(DES<')A
M=FQJ96X@=&5K<W0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+
M97D@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C0T"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q
M"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@
M<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED
M(")0=65R=&\@4FEC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"B,L(&9U
M>GIY"FUS9VED(")1871A<B(*;7-G<W1R(")$871U;2(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HV,PIM<V=I9"`B475E<GDB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C<P"FUS9VED(")1=6]T82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8T"B,L(&9U
M>GIY"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B5G)E;65N<VMA
M('IO;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT,PHC+"!F=7IZ>0IM<V=I9"`B4F%I;B(*;7-G<W1R(")5<&]Z;W)E;FIE
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*
M;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6X@3&%T92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT-@IM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A
M:6X@86YD(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N
M9&]M($9O<G1U;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<V"B,L(&9U>GIY"FUS9VED(")2871I;R(*;7-G<W1R(")/
M<&-I:F4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-"!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X
M,`HC+"!F=7IZ>0IM<V=I9"`B4F5A9"(*;7-G<W1R(").92!P<F_H:71A;F4B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PIM
M<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R("+(:71A;FIE('!O<G5K82(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO
M;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M96%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`HC+"!F=7IZ>0IM
M<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B26YF;W)M
M86-I:F4@<V5R=FES82(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(E)E
M9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R(")!OG5R:7)A
M:B!D:6YA;6GH:V4@96QE;65N=&4@;65N:6IA.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-#$*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM
M<V=S='(@(D&^=7)I<F%J('!OZ&5T;G4@<W1R86YI8W4Z(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.#DT(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R,3,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-0HC+"!F=7IZ
M>0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B4&]N:;ET:2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,R-#D*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W
M<V5R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(RP@9G5Z>GD*
M;7-G:60@(E)E;&]A9"(*;7-G<W1R(").92!P<F_H:71A;F4B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,R-@HC+"!F=7IZ>0IM<V=I9"`B4F5M87)K<R(*
M;7-G<W1R("):86)I;&IEN6ME(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q-`IM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B561A;&IE;FD@
M<V5R=F5R:2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM
M<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D
M92DZ(@IM<V=S='(@(E5D86QJ96YI(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE
M+F-O;2]H;W)D92DZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S"B,L
M(&9U>GIY"FUS9VED(")296UO=F4B"FUS9W-T<B`B3F%S=&%V:2(*"B,Z('1E
M;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B
M4F5M;W9E($)L;V-K(@IM<V=S='(@(E5K;&]N:2!O9&%B<F%N:2(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-3<*(RP@9G5Z
M>GD*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B<&]M:F5R:2!N:;YE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M,`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`B
M26YF;W)M86-I:F4@<V5R=FES82(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z,3(X"B,L(&9U>GIY"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R
M(")P;VUJ97)I('9IN64B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R
M"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M
M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"B,L(&9U>GIY
M"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(E5K;&]N:2!O9&%B<F%N:2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U
M;65N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO
M=F4N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R
M(")I>F)A8VD@:7IV;W(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO
M=F4N:6YC.C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U
M<V5R.B`E<R(*;7-G<W1R(")I>F)A8VD@:7IV;W(B"@HC.B!F<F%M97=O<FLO
M4E!#+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG
M="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PIM<V=I9"`B
M4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-"!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M97%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C8W-2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S,`HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(S"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO571I;"]5=&EL
M+G!H<#HW.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB
M(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S,U"FUS9VED
M(")297%U:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SD*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(P('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B4&]N:;ET:2(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"B,L(&9U>GIY"FUS9VED(")2
M97-E="!087-S=V]R9"(*;7-G<W1R(")087-S=V]R9"(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C(W"B,L(&9U>GIY"FUS9VED(")297-E="!9
M;W5R(%!A<W-W;W)D(@IM<V=S='(@(E!A<W-W;W)D(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$S,`IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI;B]C;61S:&5L
M;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP.C8V"B,L(&9U>GIY"FUS9VED
M(")297-U;'1S(@IM<V=S='(@(E)E>G5L=&%T:2!P<F5T<F%G92(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S
M+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B
M3F%Z860@;F$@;W!C:6IE(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C,X"B,L(&9U>GIY"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D(@IM
M<V=S='(@(E!A<W-W;W)D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO
M;B(*;7-G<W1R(")2975N:6]N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@
M0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")6<F%T:2!S=&%R=2!K;VYF:6=U<F%C
M:6IU(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,@IM<V=I9"`B4FEC
M:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(D]P8VEJ92!E9&ET;W)A
M('1E:W-T82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B
M4FED9&QE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*(RP@9G5Z>GD*;7-G:60@(E)I9VAT
M(@IM<V=S='(@(DYOYB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,C$*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3$W"B,L(&9U>GIY"FUS9VED(")2:6=H="!V
M86QU97,B"FUS9W-T<B`B6F%D;FIA('-T<F%N82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`HC+"!F=7IZ
M>0IM<V=I9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(D]S;V)I;F4@
MYE]E;&EJ92XN+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HR,S0*(RP@9G5Z>GD*;7-G:60@(E)O;&4B"FUS9W-T<B`B3F%S
M=&%V:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R
M-0HC+"!F=7IZ>0IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R("),:7-T82!K
M;VYT86MT82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,C(*(RP@9G5Z>GD*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@
M(DQI<W1A(&MO;G1A:W1A(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(R.`HC+"!F=7IZ>0IM<V=I9"`B4F]T871E(%)I9VAT
M(@IM<V=S='(@(DQI<W1A(&MO;G1A:W1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0HC+"!F=7IZ>0IM<V=I
M9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B3W-O8FEN92#F7V5L:6IE+BXN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW,`HC+"!F=7IZ>0IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T
M<B`B3W-O8FEN92#F7V5L:6IE+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3,*(RP@9G5Z>GD*;7-G:60@(E)U;&5S(@IM<V=S='(@(E)E>G5L
M=&%T:2!P<F5T<F%G92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$R,`HC+"!F=7IZ>0IM<V=I9"`B4G5N(@IM<V=S='(@(E)E=6YI
M;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I9"`B4G=A
M;F1A(@IM<V=S='(@(DMA;F%D82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3
M:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP
M.C@Q"B,L(&9U>GIY"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(E5S;6IE<F5N:F4@;FEJ92!U<W!E;&\N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P-`HC+"!F=7IZ>0IM
M<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R(")0<F5G;&5D879A;FIE('!O
M<G5K92(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H
M96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M.#,*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,0IM<V=I
M9"`B4U-((@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-5
M0T-%4U,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED(")3
M7U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-C$*(RP@9G5Z>GD*;7-G:60@(E-A(@IM<V=S
M='(@(E-AZ'5V86H@:V%O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@
M2&5L96YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@
M2VET=',@86YD($YE=FES(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I
M9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I
M9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D
M:6YE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B4V%M;V$B
M"FUS9W-T<B`B2V%M8F_P82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*(RP@9G5Z>GD*;7-G
M:60@(E-A;B!-87)I;F\B"FUS9W-T<B`B57!O>F]R96YJ92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3
M871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM
M<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;&%Y;W5T+FEN8SHY.`HC+"!F=7IZ>0IM<V=I9"`B4V%V92(*;7-G
M<W1R(")38>AU=F%J(&MA;R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F4@
M7"(E<UPB(@IM<V=S='(@(E-AZ'5V86H@:V%O(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHR,38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E-A=F4@)7,B"FUS9W-T<B`B4V'H=79A:B!K86\B"@HC.B!T96UP;&%T97,O
M<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B
M4V'H=79A:B!O<&-I:F4B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W
M"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@
M4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E
M8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C<Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R(")6<F%T:2!S=&%R=2!K;VYF:6=U<F%C:6IU
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O
M.B!<(B5S7"(N(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@
M<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")3
M8VEE;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS
M9VED(")396%R8V@B"FUS9W-T<B`B5')AOFDB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S(P"B,L(&9U>GIY"FUS9VED(")396%R8V@@16YG:6YE
M<R(*;7-G<W1R(")297IU;'1A=&D@<')E=')A9V4B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.3<S"B,L(&9U>GIY"FUS9VED(")396QE8W0@1FEL
M97,B"FUS9W-T<B`B3V1A8F5R:2!S=F4B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T"B,L(&9U>GIY"FUS9VED(")396QE
M8W0@82!D871E(@IM<V=S='(@(D]D86)E<FD@:61E;G1I=&5T(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*(RP@9G5Z>GD*;7-G:60@(E-E
M;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R(")/9&%B97)I(&MO9&YI(')A
M<W!O<F5D('-L;W9A.B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-#,*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R
M(")/9&%B97)I(&YO;F4B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R("))>F%B97)I
M=&4@<V5R=F5R(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*
M(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@
M(D]D86)E<FD@:V]D;FD@<F%S<&]R960@<VQO=F$Z(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PHC+"!F=7IZ>0IM<V=I
M9"`B4V5L96-T(&%L;"(*;7-G<W1R(")/9&%B97)I('-V92(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C,*(RP@9G5Z>GD*;7-G:60@(E-E;&5C
M="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R(")0<FEL;V<@:F4@;V)R
M:7-A;BXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.#<S"B,L(&9U>GIY"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S
M='(@(D]D86)E<FD@;F]N92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HV-S@*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!N;VYE
M(@IM<V=S='(@(D]D86)E<FD@;F]N92(*"B,Z('-E<G9I8V5S+VME>6)O87)D
M+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N
M965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A
M;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"B,L(&9U>GIY"FUS
M9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R(")/9&%B
M97)I(&MO9&YI(')A<W!O<F5D('-L;W9A.B(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0T"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE(&1A=&4@
M9F]R;6%T.B(*;7-G<W1R(")/9&%B97)I(&MO9&YI(')A<W!O<F5D('-L;W9A
M.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*
M;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E
M.B(*;7-G<W1R("))>F%B97)I=&4@:61E;G1I=&5T(&MO:FD@OF5L:71E('!R
M;VUI:F5N:71I.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G
M<W1R(")/9&%B97)I(&MO9&YI(')A<W!O<F5D('-L;W9A.B(*"B,Z('1E;7!L
M871E<R]D871A+W1I;64N:6YC.C(U"B,L(&9U>GIY"FUS9VED(")396QE8W0@
M=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R(")/9&%B97)I(&MO9&YI(')A<W!O
M<F5D('-L;W9A.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*
M(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*
M;7-G<W1R(")/9&=O=F%R86IUYF$@<&]L:F$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S`V"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N
M(@IM<V=S='(@(DEZ86)E<FET92"Y96UU(&)O:F$N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(T.`IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D
M(&QA;F=U86=E.B(*;7-G<W1R("))>F%B97)I=&4@OF5L:F5N:2!J97II:SHB
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B
M4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")0;[EA;&II('!R:6IA=G4@
M<')O8FQE;6$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3`S.0IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B4&^Y86QJ:2!3
M35,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S='(@(E-E
M;F5G86PB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-@IM<V=I9"`B4V5N
M<V]R.B`B"FUS9W-T<B`B4V5N>F]R.B`B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S
M='(@(E-E<'1E;6)A<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T
M<B`B4W)B:6IA(&D@0W)N82!';W)A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T
M<B`B4V5R:6IS:VD@8G)O:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-C$*(RP@9G5Z>GD*;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DYE;6$@9&]S='5P;FEH(&]P8VEJ
M82XB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@
M(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B061M:6YI<W1R86-I:F$@9&]Z=F]L
M82`H<')I=FEL96=I:F$I(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X<&ER
M960N(@IM<V=S='(@(DE$('-E<VEJ92!J92!I<W1E:V%O+B(*"B,Z(&QI8B]A
M<&DN<&AP.C$T-0HC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B
M7T1O>G9O;&4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$T"FUS
M9VED(")3970B"FUS9W-T<B`B3V1A8F5R:2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW-@IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O
M(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*
M;7-G<W1R("(B"B)0;V1E<VET92!O<&-I:F4@:V]J92!V86T@;VUO9W7F=6IU
M(&1A('!O;FFY=&ET92"Y:69R=2!A:V\@:F4@>F%B;W)A=FET92XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(")3970@=7`@<F5M;W1E
M('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O
M<G1A;"XB"FUS9W-T<B`B(@HB4&]D97-I=&4@=61A;&IE;F4@<V5R=F5R92!K
M;VII;6$@OF5L:71E('!R:7-T=7!I=&D@<'5T96T@=F&Y96<@<&]R=&%L82XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0*;7-G:60@(E-E="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N
M<RXB"FUS9W-T<B`B3V1A8F5R:71E(+YE;&IE;FD@:F5Z:6LL('9R96UE;G-K
M=2!Z;VYU(&D@<&]S=&%V:V4@>F$@9&%T=6TN(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDX"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI
M8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T
M:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HB4&]D97-I=&4@
M<W1A<G1N=2!K;VUP;VYE;G1U+""Y96UU(&)O:F$L(&]S=FIEOF%V86YJ92!S
M=')A;FEC92!I(&1R=6=E(&]P8VEJ92`B"B)K;VIE('-E('1IZ'4@<')I:V%Z
M82XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"FUS9VED(")3971U
M<"(*;7-G<W1R(")0;W-T879K92(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@
M879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ.#8*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE
M('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B4V5JN65L:2(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.38*;7-G:60@(E-H;W!P:6YG(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S
M"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(DMR871A:R!O<&ES(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T-@IM<V=I9"`B4VAO=6QD(&%C
M8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@
M(D1A(&QI(&1E9FEN:7-A=&D@<')I<W1U<&YE('1I<&ME('IA(&QI;FMO=F4_
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G
M:60@(E-H;W<B"FUS9W-T<B`B4')I:V&^:2(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E
M;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0Y,`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L
M;V=G:6YG(&EN/R(*;7-G<W1R(")0<FEK8;YI('9R:6IE;64@>F%D;FIE('!R
M:6IA=F4@;F%K;VX@;&]G:7)A;FIA/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$W-C4*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN
M86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q
M,PIM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4R-@IM<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS
M(&UE;G4@8F%R/R(*;7-G<W1R(")0<FEK8;YI(&UE;FD@>F$@;6%N:7!U;&%C
M:6IE('1A8F5L86UA/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@
M;&5F=#\B"FUS9W-T<B`B4')I:V&^:2`E<R!M96YI(&QI:F5V;S\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L
M;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8T"B,L(&9U>GIY"FUS9VED(")3:&]W('1H
M92!486)L92!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")0<FEK8;YI(&UE
M;FD@>F$@;6%N:7!U;&%C:6IE('1A8F5L86UA/R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B
M4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3<V,PHC+"!F=7IZ>0IM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B1&]W
M;FQO860B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,`HC+"!F=7IZ>0IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R(")0<FEK8;YI
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*
M(RP@9G5Z>GD*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B2W)A=&%K
M(&]P:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,@IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W
M97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT.#`*;7-G:60@(E-H<FEN:R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW
M-S0@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#,V"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDR,B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY.#0*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z,3`T-R!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HQ,#@W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C$Q,38@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M,3$T.0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K
M*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8U"B,L(&9U>GIY"FUS9VED
M(")3:6=N('5P(@IM<V=S='(@(B5S('!R:6IA=F$B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@HC+"!F=7IZ>0IM<V=I9"`B4VEG
M;F%T=7)E(@IM<V=S='(@(E9AN2!P;W1P:7,Z(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3$*(RP@9G5Z>GD*;7-G:60@(E-I9VYA
M='5R92!!;&=O<FET:&TB"FUS9W-T<B`B5F&Y('!O='!I<SHB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`T"B,L(&9U>GIY"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B5F&Y
M('!O='!I<SHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#8@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,CDS,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(S"FUS
M9VED(")3:7IE(@IM<V=S='(@(E9E;&GH:6YA(@H*(SH@=&5M<&QA=&5S+VUA
M:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I
M;G1E;F%N8V4B"FUS9W-T<B`B4')E<VMOZ&D@<V5R=FES(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-0IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(E-N
M;W<B"FUS9W-T<B`B4')I:V&^:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H
M;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X"B,L(&9U
M>GIY"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B(%1E;6$Z("(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C@R"FUS9VED(")3;F]W(&5Q=6EV86QE
M;G0@:6X@=V%T97(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED
M(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM
M<V=I9"`B4V]M86QI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR-@HC+"!F=7IZ>0IM<V=I9"`B
M4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B4')A=F%C('-O<G1I<F%N
M:F$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,3@Y"B,L(&9U>GIY"FUS9VED(")3;W5R8V4@861D<F5S<R(*
M;7-G<W1R(")68;EA(&4M;6%I;"!A9')E<V$Z(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM
M<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM
M,RDB"FUS9W-T<B`B2G6^;F\M979R;W!S:VD@*$E33RTX.#4Y+3,I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@
M4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R
M;B!(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N
M(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W
M965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q-0HC+"!F=7IZ>0IM<V=I9"`B
M4W!A8V5R(@IM<V=S='(@(E-AZ'5V86H@:V%O(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"FUS9VED(")3<&%C
M:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I
M;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY.`IM<V=I9"`B
M4W!A;2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*
M(RP@9G5Z>GD*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S
M='(@(E-P96-I:F%L;FD@:V%R86MT97)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@HC+"!F=7IZ>0IM<V=I
M9"`B4W!L:70@8V5L;"(*;7-G<W1R(")/9&%B97)I('-V92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*(RP@
M9G5Z>GD*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R(")/9&%B97)I('-V
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S$*(RP@9G5Z>GD*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R(")/
M9&%B97)I('-V92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM<V=I
M9"`B4W!O<G1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I
M($QA;FMA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP.C<T"B,L(&9U>GIY"FUS9VED
M(")3=&%N9&%R9"(*;7-G<W1R(")+86QE;F1A<B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.38@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@P.0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B
M4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U"B,L(&9U>GIY
M"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R("));F9O<FUA8VEJ92!S
M97)V:7-A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S(*(RP@9G5Z>GD*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(D]D
M(&%D<F5S92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,PHC+"!F=7IZ>0IM<V=I9"`B
M4W1R:6YG(&QI<W0B"FUS9W-T<B`B;&ES=&$@>F%D871A:V$B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I<"!D;VUA:6X@
M9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL
M92!;0U-372(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R("(B"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M("(E<R!N:6IE('!R;VYA\&5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B
M5&5M82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,B!F<F%M97=O
M<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*(RP@9G5Z>GD*;7-G:60@
M(E-U8FUI="(*;7-G<W1R(")496UA(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@
M7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I
M;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(*(RP@9G5Z>GD*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R(")496UA(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-`HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS
M9VED(")3=6-C97-S(@IM<V=S='(@(E5S<&IEN6YO(@H*(SH@861M:6XO=7-E
M<BYP:'`Z.#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B7"(E
M<UPB(&IE('5S<&5S;F\@9&]D86X@=2!A9')E<V%R(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S
M>7-T96TN(@IM<V=S='(@(EPB)7-<(B!J92!U<W!E<VYO(&1O9&%N('4@861R
M97-A<B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L
M971E+G!H<#HT-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R("));64@9F]L9&5R82!<
M(B5S7"(@:F4@=7-P:F6Y;F\@<')O;6IE;FIE;F\@=2!<(B5S7"(N(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3`U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M
M+B(*;7-G<W1R(")<(B5S7"(@:F4@=7-P97-N;R!D;V1A;B!U(&%D<F5S87(B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S
M9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C
M:&%N9V5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F
M=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V
M.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P
M9&%T960@7"(E<UPB(@IM<V=S='(@(DEM92!F;VQD97)A(%PB)7-<(B!J92!U
M<W!J9;EN;R!P<F]M:F5N:F5N;R!U(%PB)7-<(BXB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S
M(@IM<V=S='(@(DEM92!F;VQD97)A(%PB)7-<(B!J92!U<W!J9;EN;R!P<F]M
M:F5N:F5N;R!U(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=61A
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4V"B,L(&9U>GIY"FUS9VED(")3=6UM87)Y(@IM
M<V=S='(@(DMR871A:R!O<&ES(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP
M.C8U"B,L(&9U>GIY"FUS9VED(")3=6X@4FES92(*;7-G<W1R(")496UA(@H*
M(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X"B,L(&9U>GIY"FUS9VED(")3
M=6X@4V5T(@IM<V=S='(@(E1E;6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-@HC+"!F=7IZ>0IM
M<V=I9"`B4W5N<FES92(*;7-G<W1R(")496UA(@H*(SH@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"B,L(&9U>GIY
M"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R(")496UA(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-0HC+"!F=7IZ>0IM<V=I9"`B
M4W5N<FES93H@(@IM<V=S='(@(B!496UA.B`B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C$Y"B,L(&9U>GIY"FUS9VED(")3=6YS970B"FUS
M9W-T<B`B5&5M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,3@*(RP@9G5Z>GD*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(B!496UA.B`B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S
M"B,L(&9U>GIY"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R(")496UA(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W.`IM<V=I9"`B4W5P<&]R
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"B,L(&9U>GIY"FUS9VED(")3
M=7)I;F%M92(*;7-G<W1R("));64@9&%T;W1E:V4B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`HC+"!F=7IZ>0IM<V=I9"`B4W5R
M;F%M92(*;7-G<W1R(")5<V5R;F%M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@
M(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P.`HC+"!F=7IZ>0IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(E1R8;YI
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-`HC+"!F=7IZ>0IM<V=I9"`B4W=E9&5N(@IM<V=S
M='(@(E9I9&IE;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*
M(RP@9G5Z>GD*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`B56YD
M96QE=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30R"FUS9VED(")3
M>6YC34PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R
M9',N<&AP.CDW"B,L(&9U>GIY"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A
M<F-H('1E<FUS(@IM<V=S='(@(DES<')A>FYI(&9O;&1E<B!K;W)P82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#<*(RP@9G5Z>GD*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B
M;&EC(@IM<V=S='(@(D-E;G1R86QN;RU!9G)IZ&MA(%)E<'5B;&EK82(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED
M(")4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B3V0B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM
M<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T1A=&$O1&%T82]T<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ,S0*(RP@9G5Z
M>GD*;7-G:60@(E1A8FQE(@IM<V=S='(@(EIA9&YJ82!S=')A;F$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S
M"B,L(&9U>GIY"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(D]S
M;V)I;F4@7W1A8F5L92XN+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP
M92]T86)L97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<R"B,L(&9U>GIY"FUS9VED(")486)L92!P<F]P97)T:65S(@IM<V=S
M='(@(D]S;V)I;F4@7W1A8F5L92XN+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*
M;7-G:60@(E1A:7=A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O
M9B!#:&EN82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II
M:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA
M;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0HC+"!F=7IZ>0IM
M<V=I9"`B5&%R9V5T.B(*;7-G<W1R(")0;W)U:V$B"@HC.B!C;VYF:6<O:&]O
M:W,N<&AP+F1I<W0Z.3DV(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#<*
M(RP@9G5Z>GD*;7-G:60@(E1A<VMS(@IM<V=S='(@(DQO9VEN('IA9&%C:2(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S"B,L(&9U
M>GIY"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(E-E<FEJ<VMI
M(&)R;VHB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,`IM<V=I9"`B5&5M
M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,30*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C,*;7-G:60@(E1E;7!E
M<F%T=7)E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R93QB
M<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-C@W"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R("(E<R!N:6IE('!R;VYA\&5N+B(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(")496UP;&%T92!!9&UI;FES=')A
M=&EO;B(*;7-G<W1R("(E<R!A9&UI;FES=')A8VEJ82(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,S-@IM<V=I9"`B5&5X="(*;7-G<W1R(")496MS="(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-S4*(RP@9G5Z>GD*;7-G:60@(E1E>'0@3VYL>2(*
M;7-G<W1R(")496MS="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S0*(RP@9G5Z>GD*;7-G:60@(E1E>'0@86QI
M9VXB"FUS9W-T<B`B4VQJ961E8V$@<W1R86YA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0HC+"!F=7IZ>0IM<V=I9"`B
M5&5X='1O<"(*;7-G<W1R(")496MS="(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")4:&%I("A425,M
M-C(P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"B,L(&9U>GIY"FUS9VED
M(")4:&%I;&%N9"(*;7-G<W1R(")4<F&^:2(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDX.`IM<V=I9"`B5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@
M<WES=&5M+B(*;7-G<W1R(")(=F%L82"Y=&\@:V]R:7-T:71E($5N97)G;V1A
M=&$@=V5B;6%I;"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R
M,`HC+"!F=7IZ>0IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B25`@861R97-A(&YI:F4@9&]S='5P;F$N(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D
M;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7TE-4U`O24U34"]";V]K+G!H<#HQ,CDR"FUS9VED(")4:&4@24U3
M4"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H92!-86EN
M=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR
M.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I
M;F<N(@IM<V=S='(@(E!R;WIO<B!Z82!O<&-I:F4@<V4@>F%T=F]R:6\N($EZ
M;&%Z:6TN(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HR-C0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*
M(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA
M;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S
M92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O
M='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C
M;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N
M:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C4Q"B,L(&9U>GIY"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U
M;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")<(B5S
M7"(@:F4@=7-P97-N;R!D;V1A;B!U(&%D<F5S87(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38Y"FUS9VED("(B"B)4:&4@9&5T86-H
M960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@
M=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB
M5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I
M9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B
M87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L
M:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q,PIM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@
M9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S4@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V."!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I
M;F=S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR,3D*;7-G:60@(E1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@
M:71S96QF+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H
M<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F
M;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS
M9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S
M92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@
M8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U
M;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL
M(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S
M97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@
M:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B
M"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN
M66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@
M>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E
M;&5T960N(@IM<V=S='(@(DED96YT:71E="!<(B5S7"(@:F4@;V)R:7-A;BXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G
M:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@
M8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`Q"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@
M=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4
M:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N
M(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@W-PIM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H
M96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I
M9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G
M<W1R(")/=F$@=G)I:F5D;F]S="!M;W)A(&)I=&D@8G)O:BXB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S$*;7-G:60@(E1H92!O
M<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T
M7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<RYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P
M<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I
M=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D
M96(N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R
M:7!T+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O
M=V5R<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VUS=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<G!M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C
M<'`N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI
M9VAL:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M
M<V5X8V5L+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O
M9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T
M(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C0U-`IM<V=I9"`B5&AE('%U;W1E(&-H87)A
M8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M-#0V"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C
M:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S
M=6TN<&AP.C<X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R
M=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("))9&5N=&ET
M970@7"(E<UPB(&IE(&]B<FES86XN(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P
M8W-U;2YP:'`Z-#D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!S
M97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R("))9&5N=&ET
M970@7"(E<UPB(&IE('-AZ'5V86XN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E
M<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(DED96YT:71E
M="!<(B5S7"(@:F4@<V'H=79A;BXB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S<&5C:69I960@<F]W(&1O
M97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R
M87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S$Q"FUS9VED(")4:&4@=&5X
M="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S
M8W)E96XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O
M='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T
M;W`@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A
M=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@
M<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O1&%T
M82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@
M;F]T(&)E('-A=F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4V
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$Q.0HC+"!F=7IZ>0IM<V=I9"`B5&AE('=E
M871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DYE
M;6$@9&]S='5P;FEH(&]P8VEJ82XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<
M(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO
M;G,@879A:6QA8FQE+B(*;7-G<W1R(").96UA(&1O<W1U<&YI:"!O<&-I:F$N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z,S0R"B,L
M(&9U>GIY"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@
M9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B3F5M82!D;W-T=7!N:6@@;W!C
M:6IA+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E
M<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T
M97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@
M(B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D
M:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R(")$97-I;&$@
M<V4@9W)EN6MA('1O:V]M('-L86YJ82!P;W)U:V4Z("5S(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T
M:&4@<WES=&5M.B`B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B
M;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R
M(")$97-I;&$@<V4@9W)EN6MA('1O:V]M('-L86YJ82!P;W)U:V4Z("5S(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,34Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B1&5S:6QA('-E(&=R9;EK82!T;VMO;2!S;&%N:F$@<&]R=6ME
M.B`E<R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X-`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*
M;7-G<W1R("(B"B)*879I;R!S92!P<F]B;&5M('-A(&1O9&%V86YJ82!D871O
M=&5K92X@36]G=>9I('!R;V)L96TL(&1A=&]T96MA(&IE('9EYF$@;V0@(@HB
M;6%X(&1O>G9O;&IE;FEH($U"+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R
M;W=S97(N<&AP.C@X.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE
M("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I
M>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HB2F%V:6\@<V4@<')O8FQE;2!S
M82!D;V1A=F%N:F5M(&1A=&]T96ME+B!-;V=UYFD@<')O8FQE;2P@=F5L:>AI
M;F$@9&%T;W1E:V4@(@HB:F4@=F7F82!O9"!M87@N(&1O>G9O;&IE;FEH("@E
M9"!-0BDN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DQ
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@
M<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"B)*879I;R!S92!P<F]B
M;&5M('-A(&1O9&%V86YJ82!D871O=&5K92X@36]G=>9I('!R;V)L96TL(&1A
M=&]T96MA(&IE('9EYF$@;V0@(@HB;6%X(&1O>G9O;&IE;FEH($U"+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G
M92!P87)T(@IM<V=S='(@(D1E<VEL82!S92!G<F6Y:V$@=&]K;VT@<')I:V%Z
M82!O=F]G(&1I:F5L82!P;W)U:V4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@
M(D1E<VEL82!S92!G<F6Y:V$@=&]K;VT@<W!AN6%V86YJ82!N97IA=G*Y96YE
M('!O<G5K92XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*
M(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(")$97-I;&$@<V4@9W)EN6MA
M('1O:V]M('-P8;EA=F%N:F$@;F5Z879RN65N92!P;W)U:V4N(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,`HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E
M<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S
M='(@(D1E<VEL82!S92!G<F6Y:V$@=&]K;VT@Z&ET86YJ82!O9&%B<F%N92!P
M;W)U:V4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S@*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E
M<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U
M;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R(")$
M97-I;&$@<V4@9W)EN6MA('1O:V]M(.AI=&%N:F$@;V1A8G)A;F4@<&]R=6ME
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0P"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I
M;B!L871E<BXB"FUS9W-T<B`B1&5S:6QA('-E(&=R9;EK82!T;VMO;2!P<FEK
M87IA(&]V;V<@9&EJ96QA('!O<G5K92(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"B,L(&9U>GIY"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L
M:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R(")$97-I;&$@
M<V4@9W)EN6MA('1O:V]M(.AI=&%N:F$@;V1A8G)A;F4@<&]R=6ME+B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`HC+"!F
M=7IZ>0IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T
M('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B5F&Y(&)R;W=S97(@;F4@<&]D
M<KYA=F$@;W9U(&UO9W7F;F]S="XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")4:&ES(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R
M("(E<R!N92!I>F=L961A(&MA;R!D;WIV;VQJ96X@=&EP('-A;F1U8V5T82XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"B,L
M(&9U>GIY"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A
M;&ED('II<"!F:6QE+B(*;7-G<W1R("(E<R!N92!I>F=L961A(&MA;R!D;WIV
M;VQJ96X@=&EP('-A;F1U8V5T82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,30U"B,L(&9U>GIY"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@
M=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B)7,@;F4@:7IG
M;&5D82!K86\@9&]Z=F]L:F5N('1I<"!S86YD=6-E=&$N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC
M;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S-`IM<V=I
M9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A
M>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B
M"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*
M;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A
M=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@
M86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P
M.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.CDW."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#4W"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#8@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@R
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-38*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,P-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,SDX
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U-3<@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.34X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#4*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`R.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,#<X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-#D@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-#$P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-30*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C8U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.#(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,S<@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S,P-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS.#$T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,C(*;7-G:60@
M(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q.`IM<V=I9"`B5&AI<R!F:65L9"!M87D@
M;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y-`IM<V=I9"`B5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,PIM<V=I9"`B
M5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D
M(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.3@Y"B,L(&9U>GIY"FUS9VED(")4:&ES(&9I96QD(&UU
M<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(D]V82!V<FEJ961N;W-T
M(&UO<F$@8FET:2!B<F]J+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,S8*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L
M;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*
M(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P
M<F]C97-S960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]H96QP+V%B;W5T
M+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#4Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@
M;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@
M96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R
M;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C
M;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R
M('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES
M(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B5G)I:F5D
M;F]S="!O=F]G(&)R;VIA(&UO<F$@;F%J;6%N:F4@:7IN;W-I=&D@,2XB"@HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G
M:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP
M(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N
M=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E
M(&$@;G5M8F5R+B(*;7-G<W1R(")/=F$@=G)I:F5D;F]S="!M;W)A(&)I=&D@
M8G)O:BXB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U
M"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P
M=&EO;G,@=VEN9&]W(@IM<V=S='(@(D]V86H@<')O>F]R('-E('-M:6IE('!O
M>FEV871I('-A;6\@:7H@<')O>F]R82!/<&-I:F4B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B5&AU;F1E<B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,T"FUS
M9VED(")4:6-K971S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(T,C@@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L
M(&9U>GIY"FUS9VED(")4:6UE(@IM<V=S='(@(E9R96UE;G-K82!Z;VYA(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X-@IM<V=I9"`B5&EM92!4
M<F%C:VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*
M(RP@9G5Z>GD*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(E9R96UE;G-K
M82!Z;VYA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S.0HC+"!F
M=7IZ>0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B5G)E;65N<VMA
M('IO;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"B,L(&9U>GIY"FUS9VED
M(")4:71L92(*;7-G<W1R(")6<F5M96YS:V$@>F]N82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE
M("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B6F$B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C4T
M"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W
M;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H
M:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S$Q"B,L(&9U>GIY"FUS9VED(")4;V1A>2(*;7-G<W1R
M(")4:6IE;&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.0HC+"!F=7IZ>0IM<V=I9"`B5&]G;R(*;7-G<W1R
M("):82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,PHC+"!F=7IZ
M>0IM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B("AS=71R82DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$P"B,L(&9U>GIY"FUS9VED(")4;VYG82(*;7-G<W1R("):82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M-PHC+"!F=7IZ>0IM<V=I9"`B5&]P(@IM<V=S='(@(EIA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P
M(&9R86UE("A?=&]P*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R
M(")!:V-I:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@
M5&]B86=O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$W.3`*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B
M5'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E1U<FMI
M<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(E1U<G-K:2`H25-/+3@X-3DM.2DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N:7-T86XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C8T"FUS9VED
M(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(V.0IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI
M=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3<*;7-G:60@(E523#HB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B56=A;F1A
M(@IM<V=S='(@(DMA;F%D82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G
M:60@(E5K<F%I;F4B"FUS9W-T<B`B56YD96QE=&4B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HT,3(*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A
M('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,X.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&
M4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,S@U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M
M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8X."!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S-0HC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS
M9W-T<B`B3F4@;6]G=2!S92!S<&]J:71I(&YA($E-05`@<V5R=F5R.B`E<R(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,Y"FUS9VED(")5;F%B
M;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(U(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,3DV(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#$*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P.0IM<V=I9"`B56YA8FQE
M('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,S8U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,U-"!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HR-38*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C$R-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR.#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9F]L
M9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C8U"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&
M4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O=&%R+G!H<#HW-@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M,C(T(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,CDX"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T
M;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,Q(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,SDR"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HS,3$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S
M+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0X(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,W(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#0*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,3<@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HT,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HR,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,P,R!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C(X.`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,38W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#`*(SH@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X-R!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,S@S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HS.3$*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I
M;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M,C0T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z-#`V"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,#,*;7-G:60@(E5N86)L92!T
M;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C`S"FUS9VED(")5
M;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+G!H<#HT-3$@9G)A;65W
M;W)K+TYE=%])35-0+TE-4U`O075T:"YP:'`Z,3$X"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ.38@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HQ-C8@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$W,0IM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#(*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HV-#@@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HY
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C(W-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,P
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S,*;7-G:60@
M(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX,"!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C<R"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A
M<F-H:79E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M.#,U"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H
M*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z.#8V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL
M95-I>F4H*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4V5S
M<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*;7-G:60@
M(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HV-CD*;7-G:60@(E5N86)L92!T;R!R96%D
M('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3`U"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E
M<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z,S(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C8W(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HV,3`@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C,R,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,C$S"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(X-0HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L
M92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@
M=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$T.2!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C$U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-SD*;7-G:60@(E5N86)L92!T;R!W
M<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X,2!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ-#,*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL
M92!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M.#0Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I
M;&P@8F4@97AC965D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*(RP@9G5Z>GD*;7-G:60@(E5N
M9&5R;&EN92(*;7-G<W1R(")5;F1E;&5T92(*"B,Z('1E;7!L871E<R]P<F5F
M<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R(")0;VYI
MN71I(&EZ;6IE;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HR,C,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,SDP"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R
M(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,W.`HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS.#0*;7-G:60@(E5N97AP96-T960@<F5S<&]N
M<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF
M:6QE9"(*;7-G<W1R(").96MA=&5G;W)I<V%N;R(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DS"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B
M56YI:V]D("A55$8M."DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R
M86(@16UI<F%T97,B"FUS9W-T<B`B56IE9&EN:F5N:2!!<F%P<VMI($5M:7)A
M=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*(RP@9G5Z>GD*;7-G:60@(E5N:71E9"!3
M=&%T97,B"FUS9W-T<B`B56IE9&EN:F5N:2!!<F%P<VMI($5M:7)A=&DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY
M:6YG($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C8Y(&QI8B]";&]C:R]M971A<BYP:'`Z-S$*;7-G:60@(E5N
M:71S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0R.2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,S`*;7-G
M:60@(E5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P
M:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I
M9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"FUS
M9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S
M='(@(DYE<&]Z;F%T;R!K;W)I<VYIZ&MO(&EM92!I;&D@N6EF<F$N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4X"B,L(&9U>GIY"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N
M="(*;7-G<W1R(")0;V1E<VD@=G)E;65N<VMU('IO;G4N(@H*(SH@9G)A;65W
M;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HR.38*;7-G:60@(E5N;F%M960B
M"FUS9W-T<B`B0F5Z:6UE;FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R
M:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC
M86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E
M92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H
M;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C
M;&EP8F]A<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*(RP@9G5Z>GD*;7-G:60@(E5N
M<V5T(&-O;&]R(@IM<V=S='(@(E!R:6UL:F5N82!P<FEJ92(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@V(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z.3,R"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*(RP@9G5Z>GD*
M;7-G:60@(E5P9&%T92(*;7-G<W1R(")$871U;2(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R(")$871U;2(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*(RP@9G5Z>GD*;7-G:60@(E5P
M9&%T92!U<V5R(@IM<V=S='(@(D1A='5M(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E
M<R]E9&ET+G!H<#HR,S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5P
M9&%T960@7"(E<UPB+B(*;7-G<W1R(")$871U;2(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3D*;7-G:60@
M(E5P;&]A9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3@V"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL
M97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B
M57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X"B,L(&9U
M>GIY"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(D1E8V5M
M8F%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H
M<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B57-E(&EF(&YA;64O<&%S
M<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B
M2V]R:7-T:71E(&]V;R!A:V\@<V4@:6UE+[EI9G)A(')A>FQI:W5J=2!Z82!)
M35-0('-E<G9E<BXB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C(Q"B,L(&9U>GIY"FUS9VED(")5<V5R(@IM<V=S='(@(E5S97)N86UE
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW,C,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E
M9"!F;W(@)7,N(@IM<V=S='(@(DMO<FES;FEK("5S(&YE;6$@9&]Z=F]L=2!Z
M82`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*(RP@9G5Z>GD*;7-G:60@
M(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B)7,@861M:6YI<W1R86-I
M:F$B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,0IM<V=I
M9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(DMO<FES;FGH:V4@;W!C:6IE(@H*
M(SH@<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS
M9W-T<B`B4F5G:7-T<F%C:6IA(&MO<FES;FEK82(*"B,Z('-I9VYU<"YP:'`Z
M,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D
M(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HT-CD*(RP@9G5Z>GD*;7-G:60@(E5S97(@86-C;W5N="!N;W0@
M9F]U;F0B"FUS9W-T<B`B)7,@;FEJ92!P<F]N8?!E;BXB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U
M,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R(")+;W)I<VYIZ&MO
M(&EM92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ,C0*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A
M;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B1F]L9&5R(%PB)7-<(B!V9>8@<&]S
M=&]J:2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PHC+"!F
M=7IZ>0IM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(E5S97)N86UE(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B
M57-E<FYA;64Z("(*;7-G<W1R(")5<V5R;F%M92(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T
M96TZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T
M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,38S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(U-0IM<V=I9"`B5D93
M(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`HC+"!F=7IZ>0IM<V=I9"`B5F%C
M871I;VXB"FUS9W-T<B`B06MC:6IA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.#8V"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D
M93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C,X"FUS9VED(")686QI9&ET>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*
M;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@U-B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES
M(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0T(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R-C8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q
M-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(X"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`Y(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T;R!S
M96QE8W0@9G)O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")6
M86YU871U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-#0*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T
M:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E
M<F5D('=I=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-S`P"B,L(&9U>GIY"FUS9VED(")697)S:6]N(@IM<V=S
M='(@(DQIZ&YO(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R-@HC
M+"!F=7IZ>0IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(DQIZ&YO
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX,PHC+"!F=7IZ>0IM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T
M<B`B4VQJ961E8V$@<W1R86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(E9E
M<GD@2&EG:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"B,L(&9U>GIY"FUS
M9VED(")6:65T($YA;2(*;7-G<W1R("));64@9&%T;W1E:V4B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HY-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R
M(")0<FEK87H@)7,B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED
M(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R(")0<FEK87H@
M)7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I
M=&ES:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@
M27-L86YD<RP@52Y3+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(P.0IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8S"FUS9VED(")6:7-I8FEL:71Y
M.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F
M;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I
M82!33510(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!
M4DXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4
M($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA($A4
M5%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N
M9"!&=71U;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM<V=S='(@(E5P;WIO
M<F5N:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C4X"FUS9VED(")792(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0R-PIM
M<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y,@HC+"!F=7IZ>0IM<V=I9"`B
M5V5A=&AE<BYC;VTB"FUS9W-T<B`B=V5A=&AE<BYC;VTB"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S<*;7-G:60@(E=E8B!3:71E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC
M92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R(")3961M:>AN;R(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC;VUE
M(@IM<V=S='(@(D1O8G)O(&1ON6QI(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H
M<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B1&]B<F\@
M9&^Y;&D@;F$@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR
M.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B1&]B<F\@9&^Y;&DL("5S(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E=E<W1E<FX@*$E3
M3RTX.#4Y+3$I(@IM<V=S='(@(EIA<&%D;FD@*$E33RTX.#4Y+3$I(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*;7-G:60@(E=E<W1E<FX@*$E33RTX
M.#4Y+3$U*2(*;7-G<W1R("):87!A9&YI("A)4T\M.#@U.2TQ-2DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B6F%P861N
M82!386AA<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,W"B,L('!H
M<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I
M<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(DMO:G4@:V]M<&]N96YT=2#F
M92`E<R!P<FEK87IA=&D@;F%K;VX@=6QA>F$_(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E
M<B!C:&%R86-T97(_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T
M97(_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,#8Q"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7
M:&EC:"!P:&%S97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$S,PIM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H
M92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R(")+;VIE(&1O9&%T:V4@OF5L
M:71E(&%K=&EV:7)A=&D@>F$@961I=&]R(&9O<FUA=&ER86YO9R`H<FEC:"D@
M=&5K<W1A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#0*(RP@9G5Z>GD*;7-G:60@(E=I9'1H(@IM<V=S='(@
M(E1R8;YI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-0IM<V=I
M9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@
M;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N
M97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*(JEI<FEN82`E<R!M96YI:F$@<V$@
M;&EJ979E('-T<F%N:6-E("AS='5P82!N82!S;F%G=2!K;V0@<VQJ961EYF4@
M<')I:F%V92DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q,`HC+"!F=7IZ>0IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("),:71V
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`U"B,L(&9U>GIY"FUS9VED(")7:61T:#HB"FUS9W-T<B`B5')AOFDB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$S"FUS9VED(")7:6MI(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*(RP@9G5Z
M>GD*;7-G:60@(E=I;F0B"FUS9W-T<B`B5')AOFDB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@HC+"!F=7IZ>0IM<V=I9"`B
M5VEN9"!%87)L>2(*;7-G<W1R(")4<F&^:2(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-38*(RP@9G5Z>GD*;7-G:60@
M(E=I;F0Z(@IM<V=S='(@(E1R8;YI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(T,@HC+"!F=7IZ>0IM<V=I9"`B5VEN9#H@(@IM<V=S='(@
M(E1R8;YI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"B,L(&9U>GIY
M"FUS9VED(")7:7-D;VTB"FUS9W-T<B`B5')AOFDB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3DV"FUS9VED(")7:7-H;&ES="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*(RP@9G5Z>GD*;7-G:60@
M(E=O<FLB"FUS9W-T<B`B:6QI(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,38T"B,L(&9U>GIY"FUS9VED(")7;W)K($%D9')E
M<W,B"FUS9W-T<B`B3V0@861R97-E(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$Y,@HC+"!F=7IZ>0IM<V=I9"`B5V]R:R!0
M:&]N92(*;7-G<W1R(")496QE9F]N("AK=>9I*2(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C$V.2!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I
M96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,P,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E
M8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C$Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N
M9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C0S"FUS9VED(")8
M+5)E9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3DR"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS
M9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS
M9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X,@IM<V=I
M9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-0IM<V=I9"`B65E962(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$P.`IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED
M(")996%R;'DB"FUS9W-T<B`B1V]D:;EN:F4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"B,L
M(&9U>GIY"FUS9VED(")996UE;B(*;7-G<W1R(")6:61J96YA(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B
M665S(@IM<V=S='(@(D1A(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA
M:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^
M72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C@R"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@
M=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,30Q,0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC
M871E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT
M:71Y+G!H<#HS,#(*;7-G:60@(EEO=2!C86X@;F]T(&AA=F4@=&AE("=<7"<@
M8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R(").92!M;[YE
M('-A9'*^879A=&D@)UQ<)R!K87)A:W1E<B!U('1V;VT@<'5N;VT@:6UE;G4N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U-2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.3<U"B,L(&9U>GIY"FUS9VED(")9;W4@9&ED(&YO
M="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(DYE9&]Z
M=F]L:F5N82!S;&]V82!U(&5M86EL(&%D<F5S:2XB"@HC.B!F<F%M97=O<FLO
M1&%T82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U
M(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE
M('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED(")9
M;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(D]D:F%V;&II=F%N
M:F4@:F4@=7-P:F6Y;F\@:7IV<KEE;F\N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P
M=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P
M<F5F:7@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q.#@*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L
M:60@=F%L=64N(@IM<V=S='(@(DYE9&]Z=F]L:F5N82!S;&]V82!U(&5M86EL
M(&%D<F5S:2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME
M;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z-#4V"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@
M82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H
M92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P
M;W)T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),
M('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(EEO
M=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T
M<B`B36]R871E(&]D86)R871I(&ED96YT:71E="!K;VII(+YE;&ET92!B<FES
M871I+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0HC+"!F=7IZ>0IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS
M9W-T<B`B36]R871E(&]D86)R871I(&ED96YT:71E="!K;VII(+YE;&ET92!B
M<FES871I+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`HC+"!F=7IZ>0IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS
M9W-T<B`B36]R871E(&]D86)R871I(&ED96YT:71E="!K;VII(+YE;&ET92!B
M<FES871I+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R(")-;W)A=&4@
M;V1A8G)A=&D@:61E;G1I=&5T(&MO:FD@OF5L:71E(&)R:7-A=&DN(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,30V"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(DUO<F%T
M92!O9&%B<F%T:2!I9&5N=&ET970@:V]J:2"^96QI=&4@8G)I<V%T:2XB"@HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*(RP@
M9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@
M<&5R9F]R;2XB"FUS9W-T<B`B36]R871E(&]D86)R871I(&ED96YT:71E="!K
M;VII(+YE;&ET92!B<FES871I+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")9;W4@
M;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(DUO<F%T
M92!O9&%B<F%T:2!I9&5N=&ET970@:V]J:2"^96QI=&4@8G)I<V%T:2XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H
M;VYE(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N
M(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(B`E
M<R!S97-I:F$@:F4@:7-T96ML82X@36]L:6UO(&1A('-E('!O;F]V;R!P<FEJ
M879I=&4N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*
M;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R(")68;EA(&4M;6%I
M;"!A9')E<V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$R"FUS9VED
M(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(E9AN6$@1G)O;3H@861R
M97-A.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-"!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B66]U<B!);F9O<FUA=&EO
M;B(*;7-G<W1R(")68;EE(&EN9F]R;6%C:6IE(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.3@P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@
M26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN
M:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E
M8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB5F&Y
M82!);G1E<FYE="!A9')E<V$@:F4@<')O;6EJ96YJ96YA(&YA:V]N('!R:6IA
M=FQJ:79A;FIA(&YA("5S+B!$82!B:2!V8;EA("(*(G-I9W5R;F]S="!B:6QA
M('-AZ'5V86YA+"!M;W)A=&4@<V4@<&]N;W9O('!R:6IA=FET:2XB"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.
M86UE(@IM<V=S='(@(E9AN64@:6UE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U
M('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O
M=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO
M;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@
M=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H
M97(@<F5A<V]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@
M8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G
M:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R
M('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB
M5F&Y82!);G1E<FYE="!A9')E<V$@:F4@<')O;6EJ96YJ96YA(&YA:V]N('!R
M:6IA=FQJ:79A;FIA(&YA("5S+B!$82!B:2!V8;EA("(*(G-I9W5R;F]S="!B
M:6QA('-AZ'5V86YA+"!M;W)A=&4@<V4@<&]N;W9O('!R:6IA=FET:2XB"@HC
M.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU,`IM<V=I9"`B66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R(")68;D@
M8G)O=W-E<B!N92!P;V1ROF%V82!O=G4@;6]G=>9N;W-T+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"B,L(&9U>GIY"FUS9VED("(B
M"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P
M=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB
M"FUS9W-T<B`B(@HB5F&Y(&)R;W=S97(@;F4@<&]D<KYA=F$@;W!C:6IU(+ET
M86UP86YJ82X@4')I=&ES;FET92!T:7!K92!#;VYT<F]L*U`@:6QI("(*(D]P
M=&EO;BM0('IA(+ET86UP86YJ92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C4W"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R
M(")4<F5N=71N82!V<F5M96YS:V$@>F]N83HB"@HC.B!S97)V:6-E<R]P<F5F
M<RYP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET
M>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R(")68;D@9&5F875L="!I9&5N
M=&ET970Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U.`IM<V=I9"`B
M66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R(")68;D@9&5F875L="!I
M9&5N=&ET970Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,0IM<V=I
M9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(E9AN64@:6UE(&D@<')E>FEM
M93HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HQ,#`P"B,L(&9U>GIY
M"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")/<&-I
M:F4@<W4@<V'H=79A;F4N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@
M9F]R("5S(&ES.B`E<R(*;7-G<W1R(")68;EA(&YO=F$@N6EF<F$@>F$@)7,@
M:F4Z("5S(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*
M;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE
M(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B5F&Y92!O<&-I
M:F4@<W4@<V'H=79A;F4@=&]K;VT@=')A:F%N:F$@;W9E('-E<VEJ92XB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R(")/<&-I:F4@
M<W4@<V'H=79A;F4N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T
M<B`B5F&Y82"Y:69R82!J92!P;VYIN71E;F$B"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@
M8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@
M>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*(E9AN6$@N6EF<F$@
M:F4@<&]N:;ET96YA+"!P<F]V:F5R:71E('9AN2!E+6UA:6P@:2!P<FEJ879I
M=&4@<V4@<V$@;F]V;VT@(@HBN6EF<F]M+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.C<S,@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!P87-S=V]R9"!H
M87,@97AP:7)E9"XB"FUS9W-T<B`B5F&Y82"Y:69R82!J92!P;VYIN71E;F$B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO
M=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(E9AN6D@=61A;&IE;FD@<V5R
M=F5R:3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA
M(@IM<V=S='(@(DIU9V]S;&%V:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B6F%I<B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("):86UB:6IA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B6FEM8F%B
M=F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y
M(@IM<V=S='(@(EII<'!Y(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D
M(%1E>'1=(@IM<V=S='(@(EM386MR:6H@8VET:7)A;FD@=&5K<W1=(@H*(SH@
M<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G:60@(EM0<F]B;&5M(%)E<&]R
M=%TB"FUS9W-T<B`B6U!R:6IA=F$@<')O8FQE;6%=(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U
M;W1E9"!497AT("TB"FUS9W-T<B`B6U!R:6MAOFD@8VET:7)A;FD@=&5K<W0@
M+2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT
M<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O
M=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B6U!R:6MAOFD@8VET:7)A
M;FD@=&5K<W0@+2`E<R!R961O=F%=(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@
M)7-=(@IM<V=S='(@(EMR960@)7,@;V0@)7-=(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-30Q('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z
M,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")?061M:6YI<W1R
M86-I:F$B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T
M<B`B7T-,22(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A=&%4<F5E
M(@IM<V=S='(@(E]$871A5')E92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2
M;W<B"FUS9W-T<B`B7T]B<FFY:2!R960B"@HC.B!L:6(O87!I+G!H<#HQ,S,*
M;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B7T=R=7!E(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0IM<V=I9"`B7TAE;'`B"FUS9W-T
M<B`B7U!O;6_F(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN
M+B(*;7-G<W1R(")?3W-O8FEN92!S;&EK92XN+B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]-96YU+G!H<#HQ.30*;7-G:60@(E],;V<@:6XB"FUS9W-T
M<B`B7U!R:6IA=FD@<V4B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N
M=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*;7-G<W1R(")?27IL87HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R(")?27IM:6IE
M;FD@;&EN:RXN+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H
M<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(E]/<&-I:F4B"@HC.B!L
M:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R(")?
M1&]Z=F]L92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S
M='(@(E]5:VQO;FD@;&EN:RXN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I
M9"`B7U-E='5P(@IM<V=S='(@(E]0;V1E<VDB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]4
M86)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(D]S;V)I;F4@7W1A8F5L92XN
M+B(*"B,Z(&QI8B]A<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@
M(E]+;W)I<VYI8VDB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR
M,0IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(FEM96YI:R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,T"B,L(&9U>GIY"FUS
M9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R(")I;65N:6LB"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ,PHC+"!F=7IZ>0IM<V=I9"`B
M8V%L96YD87(B"FUS9W-T<B`B2V%L96YD87(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")C86QM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN;W0@8W)E871E(&]U
M='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU
M.3(*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN
M92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$W.`HC+"!F=7IZ>0IM<V=I9"`B8V]N9FEG=7)A
M=&EO;B!E<G)O<B(*;7-G<W1R(")6<F%T:2!S=&%R=2!K;VYF:6=U<F%C:6IU
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-30*;7-G
M:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C8*;7-G:60@
M(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3@R"B,L(&9U>GIY"FUS9VED(")E;G1R
M>2!N;W0@9F]U;F0B"FUS9W-T<B`B)7,@;FEJ92!P<F]N8?!E;BXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B
M9F%L;&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W
M<V5R+G!H<#HX-34*(RP@9G5Z>GD*;7-G:60@(F9I;&4B"FUS9W-T<B`B3F5K
M871E9V]R:7-A;F\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L:6(O
M0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO8VLO;65T87(N<&AP.C,X-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A
M="`E<R`E<R(*;7-G<W1R("(E<R!U("5S("5S(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(U,`HC+"!F=7IZ>0IM<V=I9"`B9W5S=&EN9R(*
M;7-G<W1R(")!=6=U<W0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C0Y"FUS9VED(")H.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4X"FUS9VED(")H
M:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*(RP@
M9G5Z>GD*;7-G:60@(FEN;&EN92(*;7-G<W1R(")N;VYE(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U
M='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R
M;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5"
M;&]C:W,N:G,Z,3,*(RP@9G5Z>GD*;7-G:60@(FQI;F5S72(*;7-G<W1R(")N
M;VYE(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK
M:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R
M;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8Y"FUS9VED
M(")M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C(Y,2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,S(*(RP@9G5Z>GD*;7-G:60@
M(FYA;64B"FUS9W-T<B`B26UE(@H*(SH@9G)A;65W;W)K+U)00R]24$,N<&AP
M.C$R,0HC+"!F=7IZ>0IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@
M(DYE(&EZ8G)I<V%N82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,3(Q.0HC+"!F=7IZ>0IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E
M9"(*;7-G<W1R(").92!I>F)R:7-A;F$B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDP-0HC+"!F=7IZ>0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R
M(").92!P<F_H:71A;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@X"B,L(&9U>GIY"FUS9VED(")P97)C96YT
M(@IM<V=S='(@(E!R;V-E;F%T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-S0*(RP@9G5Z>GD*;7-G:60@(G!E<FUI<W-I;VX@9&5N
M:65D(@IM<V=S='(@(D1O>G9O;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PHC
M+"!F=7IZ>0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(E5P;WIO<F5N:F4B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B
M<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.CDY"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X
M-0IM<V=I9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(G-T96%D>2(*
M;7-G<W1R(").92!P<F_H:71A;F4B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C,P.0IM<V=I9"`B<W=I=&-H(&]F9B!J879A<V-R:7!T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P
M"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,CD*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R
M(")L:7-T82!Z861A=&%K82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P-0HC+"!F=7IZ
M>0IM<V=I9"`B=')Y(&%G86EN(@IM<V=S='(@(DMO9"!S=F%K92!P<FEJ879E
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T:"]3
M:6=N=7`N<&AP.C(V.0IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@
M=&\@8V]N9FER;2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H
M<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B
M=6YI9FEE9"(*;7-G<W1R(").96MA=&5G;W)I<V%N;R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T
M<B`B8F5Z(&EM96YA(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C(S"B,L(&9U>GIY"FUS9VED(")U<V5R('-E
M;&5C="(*;7-G<W1R("))>F)O<B!B;VIE(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R
M(")V0V%R9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR-#$*(RP@9G5Z>GD*;7-G:60@(G<Z(@IM<V=S='(@(D9W9#HB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE
M<BYC;VTB"FUS9W-T<B`B=V5A=&AE<BYC;VTB"@``````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+V-A7T53+G!O````````````````
M````````````````````````````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`W,3(V,S``,3`U
M,34T,S,W-30`,#$W-C(P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````",@2&]R9&4@0V%T86QA;B!T<F%N<VQA=&EO;BX*(R!#
M;W!Y<FEG:'0@*$,I(#(P,#0@2&]R9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I
M<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!(
M;W)D92!P86-K86=E+@HC($IO<F1I($=I<F%L="`\<')O:F5C=&4N:S)`=7!C
M;F5T+F5S/BP@,C`P-BX*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M
M260M5F5R<VEO;CH@2&]R9&4@,RXP-5QN(@HB4F5P;W)T+4US9VED+4)U9W,M
M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E
M.B`R,#`V+3`U+3$Q(#$R.C4Q*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z
M(#(P,#8M,#<M,30@,3$Z,#@K,#$P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!*
M;W)D:2!':7)A;'0@/'!R;VIE8W1E+FLR0'5P8VYE="YE9'4^7&XB"B),86YG
M=6%G92U496%M.B!#871A;&%N(#QD979`;&ES=',N:&]R9&4N;W)G/EQN(@HB
M34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I
M;CL@8VAA<G-E=#UI<V\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N
M8V]D:6YG.B`X8FET7&XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#D*;7-G
M:60@(B(*(B`@+4TL("TM;65S<V%G93U-15-304=%("!5<V4@=&AI<R!C;VUM
M:70@;65S<V%G92!I;G-T96%D(&]F('1H92!D969A=6QT(&]N97,N(@IM<V=S
M='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU,PIM<V=I9"`B(@HB("`M
M82P@+2UA9&0]1DE,12`@("`@("`@061D('1H:7,@4$\@9FEL92!T;R!T:&4@
M8V]M<&5N9&EU;2X@57-E9G5L('1O7&XB"B(@("`@("`@("`@("`@("`@("`@
M("`@("!I;F-L=61E(&$@8V]M<&5N9&EU;2!F<F]M(&$@9&EF9F5R96YT(&)R
M86YC:"!T;UQN(@HB("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&=E;F5R
M871E9"!C;VUP96YD:75M+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3$S"FUS9VED("(B"B(@("UB+"`M+6)A<V4]+U!!5$@@($9U;&P@
M<&%T:"!T;R!T:&4@*$AO<F1E*2!B87-E(&1I<F5C=&]R>2!T:&%T('-H;W5L
M9"!B95QN(@HB("`@("`@("`@("`@("`@("`@("!U<V5D+B(*;7-G<W1R("(B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-CD*;7-G:60@(B(*(B`@+6,L("TM
M8V]M<&5N9&EU;3U&24Q%("!-97)G92!N97<@=')A;G-L871I;VYS('1O('1H
M:7,@8V]M<&5N9&EU;2!F:6QE7&XB"B(@("`@("`@("`@("`@("`@("`@("`@
M("`@:6YS=&5A9"!O9B!T:&4@9&5F875L="!O;F4@*&-O;7!E;F1I=6TN<&\@
M:6X@=&AE7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("`@:&]R9&4O<&\@
M9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-C,@<&\O=')A;G-L871I;VXN<&AP.C@Q('!O+W1R86YS;&%T:6]N+G!H<#HX
M-PIM<V=I9"`B(@HB("`M8RP@+2UC;VUP96YD:75M/49)3$4@(%5S92!T:&ES
M(&-O;7!E;F1I=6T@9FEL92!I;G-T96%D(&]F('1H92!D969A=6QT7&XB"B(@
M("`@("`@("`@("`@("`@("`@("`@("`@;VYE("AC;VUP96YD:75M+G!O(&EN
M('1H92!H;W)D92]P;R!D:7)E8W1O<GDI+B(*;7-G<W1R("(B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3$T"FUS9VED("(@("UD+"`M+61E8G5G("`@("`@
M(%-H;W<@97)R;W(@;65S<V%G97,@9G)O;2!T:&4@97AE8W5T960@8FEN87)I
M97,N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU-`IM<V=I
M9"`B("`M9"P@+2UD:7)E8W1O<GD]1$E2("`@0W)E871E(&-O;7!E;F1I=6T@
M:6X@=&AI<R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HQ,34*;7-G:60@(B`@+6@L("TM:&5L<"`@("`@("`@4VAO=R!T
M:&ES(&AE;'`@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C0R('!O+W1R86YS;&%T:6]N+G!H<#HV-R!P;R]T<F%N<VQA=&EO
M;BYP:'`Z-S4*;7-G:60@(B`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V4@
M;VYL>2!T:&ES(&QO8V%L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C0W('!O+W1R86YS;&%T:6]N+G!H<#HV,2!P;R]T<F%N<VQA=&EO
M;BYP:'`Z-SD*(SH@<&\O=')A;G-L871I;VXN<&AP.C@U"FUS9VED("(@("UL
M+"`M+6QO8V%L93UL;%]#0R`@("`@57-E('1H:7,@;&]C86QE+B(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-34*;7-G:60@(B`@+6PL("TM
M;&]C86QE/6QL7T-#("`@(%5S92!T:&ES(&QO8V%L92XB"FUS9W-T<B`B(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C8X"FUS9VED("(@("UM+"`M+6UO9'5L
M93U-3T153$4@("`@0G5I;&0@34\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R
M9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C0S"FUS9VED("(@("UM+"`M+6UO9'5L93U-3T153$4@("`@0VQE86YU<"!0
M3R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#@*;7-G:60@(B(*(B`@+6TL
M("TM;6]D=6QE/4U/1%5,12`@("!#;VUM:70@=')A;G-L871I;VYS(&]N;'D@
M9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S='(@(B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HV,@IM<V=I9"`B("`M;2P@+2UM;V1U;&4]34]$54Q%
M("`@($-R96%T92!A(%!/(&9I;&4@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO
M9'5L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C@P"FUS
M9VED("(@("UM+"`M+6UO9'5L93U-3T153$4@("`@365R9V4@4$\@9FEL97,@
M;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C<V"FUS9VED("(B"B(@("UM+"`M+6UO9'5L
M93U-3T153$4@("`@57!D871E(&AE;'`@9FEL97,@;VYL>2!F;W(@=&AI<R`H
M2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C@V"FUS9VED("(@("UM+"`M+6UO9'5L93U-3T153$4@("`@57!D871E
M(&]N;'D@=&AI<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C4X"FUS9VED("(@("UM+"`M+6UO9'5L93U-3T15
M3$4@($=E;F5R871E(%!/5"!F:6QE(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M
M;V1U;&4N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW,`IM
M<V=I9"`B(@HB("`M;BP@+2UN;RUC;VUP96YD:75M("`@($1O;B=T(&UE<F=E
M(&YE=R!T<F%N<VQA=&EO;G,@=&\@=&AE(&-O;7!E;F1I=6TN(@IM<V=S='(@
M(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV-"!P;R]T<F%N<VQA=&EO;BYP
M:'`Z.#(@<&\O=')A;G-L871I;VXN<&AP.C@X"FUS9VED("(@("UN+"`M+6YO
M+6-O;7!E;F1I=6T@("`@1&]N)W0@=7-E(&$@8V]M<&5N9&EU;2XB"FUS9W-T
M<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C<Q"FUS9VED("(@("US+"`M
M+7-T871I<W1I8W,@("`@("`@4V%V92!T<F%N<VQA=&EO;B!S=&%T:7-T:6-S
M(&EN(&$@;&]C86P@9FEL92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C$Q-@IM<V=I9"`B("`M="P@+2UT97-T("`@("`@("!3:&]W('1H
M92!E>&5C=71E9"!C;VUM86YD<R!B=70@9&]N)W0@<G5N(&%N>71H:6YG+B(*
M;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`U"FUS9VED("(B
M"B(@(&-L96%N=7`@("`@($-L96%N<R!T:&4@4$\@9FEL97,@=7`@9G)O;2!U
M;G1R86YS;&%T960@86YD(&]B<V]L971E(&5N=')I97,N(@IM<V=S='(@(B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#@*;7-G:60@(B`@8V]M;6ET("`@
M("`@0V]M;6ET('1R86YS;&%T:6]N<R!T;R!T:&4@0U93('-E<G9E<BXB"FUS
M9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P.0IM<V=I9"`B("!C
M;VUM:70M:&5L<"!#;VUM:70@:&5L<"!F:6QE<R!T;R!T:&4@0U93('-E<G9E
M<BXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.CDY"FUS9VED
M("(B"B(@(&-O;7!E;F1I=6T@(%)E8G5I;&0@=&AE(&-O;7!E;F1I=6T@9FEL
M92X@5V%R;FEN9SH@5&AI<R!O=F5R=W)I=&5S('1H95QN(@HB("`@("`@("`@
M("`@("!C=7)R96YT(&-O;7!E;F1I=6TN(@IM<V=S='(@(B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,#`*;7-G:60@(B`@97AT<F%C="`@("`@1V5N97)A
M=&4@4$\@=&5M<&QA=&4@*"YP;W0I(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z.3@*;7-G:60@(B`@:&5L<"`@("`@("`@4VAO
M=R!T:&ES(&AE;'`@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C$P,0IM<V=I9"`B(@HB("!I;FET("`@("`@("!#<F5A=&4@
M;VYE(&]R(&UO<F4@4$\@9FEL97,@9F]R(&$@;F5W(&QO8V%L92X@5V%R;FEN
M9SH@5&AI<UQN(@HB("`@("`@("`@("`@("!O=F5R=W)I=&5S('1H92!E>&ES
M=&EN9R!03R!F:6QE<R!O9B!T:&ES(&QO8V%L92XB"FUS9W-T<B`B(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$P-@IM<V=I9"`B("!M86ME("`@("`@("!"
M=6EL9"!B:6YA<GD@34\@9FEL97,@9G)O;2!T:&4@<W!E8VEF:65D(%!/(&9I
M;&5S+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`W"FUS
M9VED("(B"B(@(&UA:V4M:&5L<"`@($UA<FL@86QL(&5N=')I97,@:6X@=&AE
M(%A-3"!H96QP(&9I;&4@8F5I;F<@=7`M=&\M9&%T92!A;F1<;B(*(B`@("`@
M("`@("`@("`@<')E<&%R92!T:&4@9FEL92!F;W(@=&AE(&YE>'0@97AE8W5T
M:6]N(&]F('5P9&%T92UH96QP+B!9;W5<;B(*(B`@("`@("`@("`@("`@<VAO
M=6QD(&]N;'D@<G5N(&UA:V4M:&5L<"!!1E1%4B!U<&1A=&4M:&5L<"!A;F0@
M<F5V:7-I;F<@=&AE7&XB"B(@("`@("`@("`@("`@(&AE;'`@9FEL92XB"FUS
M9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P,@IM<V=I9"`B(@HB
M("!M97)G92`@("`@("!-97)G92!T:&4@8W5R<F5N="!03R!F:6QE('=I=&@@
M=&AE(&-U<G)E;G0@4$\@=&5M<&QA=&4@9FEL92XB"FUS9W-T<B`B(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$P,PIM<V=I9"`B("!U<&1A=&4@("`@("!2
M=6X@97AT<F%C="!A;F0@;65R9V4@<V5Q=65N="XB"FUS9W-T<B`B(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$P-`IM<V=I9"`B(@HB("!U<&1A=&4M:&5L
M<"!%>'1R86-T(&%L;"!N97<@86YD(&-H86YG960@96YT<FEE<R!F<F]M('1H
M92!%;F=L:7-H(%A-3"!H96QP7&XB"B(@("`@("`@("`@("`@(&9I;&4@86YD
M(&UE<F=E('1H96T@=VET:"!T:&4@97AI<W1I;F<@;VYE<RXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHQ
M,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB("8C,34Q.R`E<R!I
M<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS
M(&-H96-K960@8F5L;W<N(@IM<V=S='(@(B(*(DUA<G%U974@82!L82!C87-E
M;&QA(&PG;W!E<F%C:?,@;R!O<&5R86-I;VYS('%U92!D97-I=&=E=2!E>&5C
M=71A<B!E;B`B"B)A<75E<W1A(&]C87-I\RXB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O
M*2(*;7-G<W1R("(H9F$@)7,@9&EE<RDB"@HC.B!L:6(O2&]R9&4N<&AP.C$R
M-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S
M='(@(B`H0VQA=2!D)V%C8^ES("5S*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,S<U"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS
M9W-T<B`B*&5N("5S(&1I97,I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S
M-S$*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(BAA=G5I*2(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,S<S"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R
M("(H9&5MX"DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,V.0IM<V=I9"`B
M("AY97-T97)D87DI(@IM<V=S='(@(BAA:&ER*2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-#,*;7-G:60@(B!A="`B"FUS9W-T<B`B96XB
M"@HC.B!L:6(O5D93+W-M8BYP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@(EPB)7-<(B!N
M;R#I<R!U;B!D:7)E8W1O<FDN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B
M"FUS9W-T<B`B)60@)7,@:2`E<R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,3<V"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&)Y=&5S('=R:71T96XN(@IM
M<V=S='(@(B5D(&)Y=&5S(&5S8W)I=',N(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C$R.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@;V8@)60@96YT<FEE
M<R!M87)K960@87,@=7`M=&\M9&%T92(*;7-G<W1R("(E9"!D92`E9"!E;G1R
M861E<R!M87)C861E<R!C;VT@86-T=6%L:71Z861E<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(G!R979I<VGS('!E<B!A;"!D:6$@
M)60B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;F]T:6-E7W1O<"YI;F,Z
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R(")!
M=NUS("T@)7,B"@HC.B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI
M;F,Z,S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S($%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(B5S($%D;6EN:7-T<F%C:?,B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C<P-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!&:6YG97)P<FEN="(*;7-G<W1R(")%;7!R96UT82!D86-T:6QA<B`E<R(*
M"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX,C8@;&EB+TAO<F1E
M+TU)344O0V]N=&5N=',N<&AP.C@R.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]C;VYF:7)M7W1O<"YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-
M86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@
M(D]P97)A8VEO;G,@9&4@;6%N=&5N:6UE;G0@)7,@+2!#;VYF:7)M86-I\R(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,3@@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G
M<W1R(")#;VYF:6=U<F%C:?,@9&4@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]3
M:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P
M(@IM<V=S='(@(D%L=&$@9&4@)7,B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O86=R965M96YT7W1O<"YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!497)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B0V]N9&EC:6]N<R!D96P@
M8V]N=')A8W1E("5S(@H*(SH@;&EB+U9&4R]F='`N<&AP.C4V."!L:6(O5D93
M+V9T<"YP:'`Z-C,V(&QI8B]61E,O<VUB+G!H<#HT,S`*(SH@;&EB+U9&4R]S
M;6(N<&AP.C0Y,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X
M:7-T<RXB"FUS9W-T<B`B)7,@:F$@97AI<W1E:7@N(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-3<@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C,@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,S<*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#,@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@870@)7,@)7,B"FUS9W-T<B`B)7,@96X@)7,@)7,B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,C@W('!O+W1R86YS;&%T:6]N+G!H<#HS,30*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(B5S(&ES(&YO="!W<FET86)L92XB"FUS
M9W-T<B`B)R5S)R!N;R#I<R!U;F$@;W!C:?,@=N!L:61A+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,S,X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES
M(')E<75I<F5D(@IM<V=S='(@(LES(&YE8V5S<V%R:2`E<RXB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(X-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M
M:6YU=&5S(@IM<V=S='(@(B5S(&UI;G5T<R(*"B,Z(&QI8B](;W)D92]";&]C
M:R]#;VQL96-T:6]N+G!H<#HQ,C,@<&\O=')A;G-L871I;VXN<&AP.C$S-3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R(").
M;R!S)VAA('1R;V)A="`E<RXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-3@U
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N9"X@4G5N("=T<F%N
M<VQA=&EO;B!E>'1R86-T)R!F:7)S="XB"FUS9W-T<B`B)7,@;F\@=')O8F%T
M+B!%>&5C=71A("=T<F%N<VQA=&EO;B!E>'1R86-T)R!P<FEM97(N(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(E<R!A;"`E<R!D92`E
M<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.#DQ"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(DQL:6)R971A(&0G
M861R96-E<R!D92`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.#@S"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B06=E
M;F1A(&1E("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HX-S4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(D)L;V,@9&4@
M;F]T97,@9&4@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C@Y.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(DQL:7-T
M82!D92!T87-Q=65S(&1E("5S(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S.B`E<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!L:6(O2&]R9&4O0TQ)+G!H
M<#HR-S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B<E<R<@:7,@;F]T
M(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R("(G)7,G(&YO(.ES('5N82!O<&-I
M\R!VX&QI9&$N(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HU-30@;&EB
M+TAO<F1E+U)E9VES=')Y+G!H<#HY,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B<E<R<@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E
M9VES=')Y+B(*;7-G<W1R("(G)7,G(&YO(&5S=.`@8V]N9FEG=7)A="!E;B!E
M;"!R96=I<W1R92!D92!(;W)D92XB"@HC.B!L:6(O2&]R9&4O5')E92YP:'`Z
M,38T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(G)7,G('1R964@<F5N
M9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R(").;R!S)VAA('1R;V)A="!E;"!G
M96YE<F%D;W(@9"=A<F)R97,@)R5S)RXB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C4W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(G)7,G('=A<R!A9&1E
M9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B4R=H82!A9F5G:70@
M)R5S)R!A;"!S:7-T96UA(&1E(&=R=7!S+B(*"B,Z(&%D;6EN+W!E<FUS+V%D
M9&-H:6QD+G!H<#HX-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)R5S
M)R!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T
M<B`B4R=H82!A9F5G:70@)R5S)R!A;"!S:7-T96UA(&1E(&QL:6/H;F-I97,N
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-2!A9&UI;B]P97)M<R]A9&1C:&EL
M9"YP:'`Z.#,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B<E<R<@=V%S
M(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B)R5S)R!N;R!H82!E<W1A="!C
M<F5A=#H@)7,N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#8@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T
M:6YG("5S("5S(@IM<V=S='(@(BP@=F5N=/-S("5S("5S("(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3DY"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R
M:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(L('9A<FEA8FQE(&1E("5S
M(&$@)7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`V.2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C$R.`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C@X"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@<V5L
M96-C:6]N87(@+2TB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,R."!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3,S,`IM<V=I9"`B+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM(@IM<V=S='(@(BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&
M;W)M870B"FUS9W-T<B`B9F]R;6%T(&1E(#$R(&AO<F5S(@H*(SH@;&EB+T)L
M;V-K+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R
M(")F;W)M870@9&4@,C0@:&]R97,B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE
M+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@:&]R97,B"@HC
M.B!L:6(O2&]R9&4O54DO4&%G97(N<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B
M"FUS9W-T<B`B/$%N=&5R:6]R(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C,T
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(\9V5T=&5X=#X@=&%G(&YO="!C
M;&]S960@:6X@9FEL92`E<RY<;B(*(D]P96YI;F<@=&%G(&9O=6YD(&EN(&QI
M;F4@)60N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$W
M"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H
M:7,@8FQO8VLN(@IM<V=S='(@(E!E<B!A(&%Q=65S="!B;&]C(&5S(&YE8V5S
M<VET82!U;B!M;W1O<B!D92!B87-E<R!D92!D861E<RXB"@HC.B!L:6(O2&]R
M9&4N<&AP.C$V,`IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B
M"FUS9W-T<B`B4R=H82!P<F]D=>]T('5N(&5R<F]R(&ER<F5P87)A8FQE+B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDR,`IM<V=I9"`B02!P=6)L
M:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB
M"FUS9W-T<B`B17,@;F5C97-S:71A('5N82!C;&%U(%!'4"!P^F)L:6-A('!E
M<B!X:69R87(@=6X@;6ES<V%T9V4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z,3$T-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B17,@;F5C
M97-S:71A('5N82!C;&%U(%!'4"!P^F)L:6-A('!E<B!V97)I9FEC87(@=6X@
M;6ES<V%T9V4@<VEG;F%T+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C$P-S<*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@
M82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B)%<R!N96-E<W-I=&5N('5N82!C
M;&%U(%!'4"!P^F)L:6-A+"!U;F$@8VQA=2!01U`@<')I=F%D82!I('5N82!C
M;VYT<F%S96YY82`B"B)P97(@9&5S>&EF<F%R('5N(&UI<W-A=&=E+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDY-0IM<V=I9"`B(@HB02!P=6)L
M:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*
M(D5S(&YE8V5S<VET96X@=6YA(&-L874@4$=0('#Z8FQI8V$L('5N82!C;&%U
M(%!'4"!P<FEV861A(&D@=6YA(&-O;G1R87-E;GEA("(*(G!E<B!S:6=N87(@
M=6X@;6ES<V%T9V4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M,#4*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-
M24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E
M8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B)%<R!N96-E<W-I=&5N('5N
M82!C;&%U(%,O34E-12!P^F)L:6-A+"!U;F$@8VQA=2!3+TU)344@<')I=F%D
M82!I('5N82`B"B)C;VYT<F%S96YY82!P97(@9&5S>&EF<F%R('5N(&UI<W-A
M=&=E+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED
M("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S
M<V%G92XB"FUS9W-T<B`B(@HB17,@;F5C97-S:71E;B!U;F$@8VQA=2!3+TU)
M344@</IB;&EC82P@=6YA(&-L874@4R]-24U%('!R:79A9&$@:2!U;F$@(@HB
M8V]N=')A<V5N>6$@<&5R('-I9VYA<B!U;B!M:7-S871G92XB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)
M344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G
M<W1R(")%<R!N96-E<W-I=&$@=6YA(&-L874@4TU)344@</IB;&EC82!P97(@
M>&EF<F%R('5N(&UI<W-A=&=E+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C<*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R(").
M^G9O;',@86P@;6%T[2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C@*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`B4&QU
M:F$@9F5B;&4@86P@;6%T[2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B4&QU:F$@
M86P@;6%T[2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$P"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@(E)U:7AA=',@86P@
M;6%T[2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$Q"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B6.!F96-S(&1E
M(&YE=2!A;"!M873M+B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y
M"FUS9VED(")!32]032(*;7-G<W1R(")!32]032(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"FUS9VED(")!4$D@240B"FUS9W-T
M<B`B240@9&4@05!)(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T
M<B`B4V]B<F4@87%U97-T(&5D:71O<B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD
M97@N<&AP.C4R"FUS9VED(")!8F]U="XN+B(*;7-G<W1R(")%;B!Q=6%N="!A
M+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(D%L:6YE86-I\R!I;F9E
M<FEO<B!E>&%C=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B06QI;F5A
M8VGS(&%L(&UI9R!E>&%C=&$B"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HR-S`*
M;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B4R=H82!D96YE9V%T(&PG86-CZ7,@96X@8W)E87(@96P@9&ER
M96-T;W)I(%9&4RXB"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@
M(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(E,G
M:&$@9&5N96=A="!L)V%C8^ES(&5N(&-R96%R(&PG87)X:74@5D93+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-0IM<V=I9"`B06-C;W5N="!087-S
M=V]R9"(*;7-G<W1R(")#;VYT<F%S96YY82!D96P@8V]M<'1E(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(D%C8V]U
M;G0@9G)O>F5N+B(*;7-G<W1R(")#;VUP=&4@8V]N9V5L870N(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,Q-0IM<V=I9"`B06-C;W5N=&EN9R(*
M;7-G<W1R(")#;VUP=&%B:6QI='IA8VGS(@H*(SH@861M:6XO<&5R;7,O861D
M8VAI;&0N<&AP.C4T(&QI8B](;W)D92]097)M<R]522YP:'`Z,3,R"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$V('1E;7!L871E
M<R]P;W)T86PO861D+FEN8SHQ-`IM<V=I9"`B061D(@IM<V=S='(@(D%F96=I
M<B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$T(&%D;6EN+V=R;W5P<RYP:'`Z
M,C$U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B069E9VER('5N
M(&=R=7`@9&5S8V5N9&5N="(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z
M.#0@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX-0IM<V=I9"`B061D($-H:6QD
M(%!E<FUI<W-I;VXB"FUS9W-T<B`B069E9VER('5N82!A=71O<FET>F%C:?,@
M9&5S8V5N9&5N="(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS
M9VED(")!9&0@2&5R93HB"FUS9W-T<B`B069E9VER(&$@8V]N=&EN=6%C:?,Z
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,#@@861M:6XO9W)O=7!S+G!H<#HR
M,#D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B069E9VER('5N(&YO
M=2!G<G5P(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HW,R!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C<T"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB
M"FUS9W-T<B`B069E9VER('5N82!N;W9A(&%U=&]R:71Z86-I\R`B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHY"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G<F]U<"!T;R`G)7,G
M(@IM<V=S='(@(D%F96=I<B!U;B!G<G5P(&1E<V-E;F1E;G0@82`G)7,G+B(*
M"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,R!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C$S,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D
M(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`G)7,G(@IM<V=S='(@(D%F96=I<B!U
M;F$@875T;W)I='IA8VGS(&1E<V-E;F1E;G0@82`G)7,G+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B
M069E9VER('5N(&YO=2!U<W5A<FDZ(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C4R-@IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R
M(")!9F5G:7(@=6YA(&-O;'5M;F$N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHS-0IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S
M='(@(D%F96=I<B!N;W5S(&UE;6)R97,N(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHQ,#,*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(D%F96=I
M<B!U;F$@<&%R96QL82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z
M:6QL82!3:61E8F%R(@IM<V=S='(@(D%F96=I<B!E;"!M96[Z("5S(&-O;2!U
M;F$@8F%R<F$@;&%T97)A;"!D92!-;WII;&QA(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HW,0IM<V=I9"`B061D('1O(&%D9')E<W,@
M8F]O:SHB"FUS9W-T<B`B069E9V5I>"!A(&QA(&QL:6)R971A(&0G861R96-E
M<SHB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"FUS
M9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(D%F96=E:7@@
M82!L82!M979A(&QL:6)R971A(&0G861R96-E<R(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R(")!9F5G:7(@=6X@=7-U
M87)I(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B(*(D%D9&5D("<E<R<@=&\@=&AE('-Y<W1E;2P@8G5T(&-O
M=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("4B
M"B)S+B(*;7-G<W1R("(B"B)3)VAA(&%F96=I="`G)7,G(&%L('-I<W1E;6$L
M('!E<O(@;F\@<R=H82!P;V=U="!A9F5G:7(@;>ES(&1A9&5S('-O8G)E("(*
M(FPG86QT83H@)7,B"@HC.B!S:6=N=7`N<&AP.C0U"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")!9&1E9"`G)7,G('1O('1H92!S>7-T96TN(%EO=2!C
M86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B4R=H82!A9F5G:70@)R5S)R!A;"!S
M:7-T96UA+B!!<F$@:F$@<&]T(&EN:6-I87(@;&$@<V5S<VGS+B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HY-C(*;7-G:60@(D%D9&EN9R!N97<@9FEL97,@
M=&\@<F5P;W-I=&]R>3HB"FUS9W-T<B`B069E9VEN="!N;W5S(&9I='AE<G,@
M86P@<F5P;W-I=&]R:2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D
M+FEN8SHT"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S
M='(@(E,G:&$@:6YH86)I;&ET870@;"=O<&-I\R!D)V%F96=I<B!U<W5A<FES
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#0V(&QI8B](;W)D92]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3<S"FUS9VED(")!9&1R97-S(@IM<V=S='(@(D%D<F7G
M82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S<*;7-G:60@(D%D
M9')E<W,@0F]O:R(*;7-G<W1R("),;&EB<F5T82!D)V%D<F5C97,B"@HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D;6EN
M:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S
M='(@(D%D;6EN:7-T<F%D;W(@+2!D969I;F5I>"!L97,@875T;W)I='IA8VEO
M;G,@<&5R(&$@86QT<F5S('5S=6%R:7,B"@HC.B!A9&UI;B]I;F1E>"YP:'`Z
M,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R86-I\R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS.#,*;7-G:60@(D%D<R(*;7-G<W1R(")!
M;G5N8VES(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ.`IM<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`B069G86YI<W1A
M;B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C$*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B06QBX&YI82(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<P(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S0*;7-G:60@(D%L
M9V5R:6$B"FUS9W-T<B`B06QGZ')I82(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R("+`;&EE
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@(D%L:6YE87(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED
M(")!;&EG;FUE;G0Z(@IM<V=S='(@(D%L:6YE86-I\SHB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R(")4;W1S(@H*
M(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3$X('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM
M<V=S='(@(E1O=',@96QS('5S=6%R:7,@875T96YT:6-A=',B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C$R"FUS9VED(")!
M;&P@1W)O=7!S(@IM<V=S='(@(E1O=',@96QS(&=R=7!S(@H*(SH@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C,X(&QI8B](;W)D92]097)M<R]522YP:'`Z
M-S<*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R(")4;W1S(&5L<R!P
M97)M:7-O<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@
M(E1O=',@<75A=')E(&-O<W1A=',B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3@W,0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@
M(E!E<FUE="!M;VQT97,@861R96-E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU,C,*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T
M('1Y<&4_(@IM<V=S='(@(D5S('!E<FUE="!L82!C;VYF:6=U<F%C:?,@9&5L
M('1I<'5S(&1E(&QL:7-T97,@;W)D96YA9&5S/R(*"B,Z(&QI8B](;W)D92]$
M871A5')E92]S<6PN<&AP.C0P.`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS
M9W-T<B`B2F$@97AI<W1E:7@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3(R"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R(")!8V/I
M<R!)35-0(&%L=&5R;F%T:74B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#DV"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R(")#
M;VYT<F%S96YY82!)35-0(&%L=&5R;F%T:79A(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0X.`IM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B
M"FUS9W-T<B`B3F]M(&0G=7-U87)I($E-4U`@86QT97)N871I=2(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E<FYA=&4@
M96UA:6P@861D<F5S<R(*;7-G<W1R(")!9')EYV$@96QE8W1R\FYI8V$@86QT
M97)N871I=F$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B
M06QT97)N871E('1E;7!L871E<R(*;7-G<W1R(")0;&%N=&EL;&5S(&%L=&5R
M;F%T:79E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM
M<V=S='(@(E1E>'0@86QT97)N871I=3HB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(W"FUS9VED(")!;65R:6-A;B!386UO
M82(*;7-G<W1R(")386UO82!!;65R:6-A;F$B"@HC.B!L:6(O2&]R9&4O4')E
M9G,O54DN<&AP.CDU(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3$U"FUS9VED
M(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(E,G
M:&$@97-P96-I9FEC870@=6X@=F%L;W(@<')O:&EB:70N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.0IM<V=I9"`B06X@=6YK;F]W;B!E
M<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B4R=H82!P<F]D=>]T('5N(&5R
M<F]R(&1E<V-O;F5G=70N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-@IM<V=I9"`B06YD;W)R82(*;7-G<W1R(")!;F1O
M<G)A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-`IM<V=I9"`B06YG;VQA(@IM<V=S='(@(D%N9V]L82(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C4W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`*;7-G:60@(D%N
M9W5I;&QA(@IM<V=S='(@(D%N9W5I;&QA(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B
M4V5R=FED;W(@4')O>'D@86[R;FEM(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R(")297-P;W-T82(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4*
M;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B06YTX')T:61A(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.0IM<V=I9"`B
M06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R(")!;G1I9W5A(&D@0F%R8G5D
M82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN
M<&AP.C,U(&QI8B](;W)D92]";&]C:R]522YP:'`Z-3@*(SH@=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB
M"FUS9W-T<B`B07!L:6-A8VGS(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP
M.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@(DQL:7-T82!D
M)V%P;&EC86-I;VYS(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S.0IM
M<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(DPG87!L:6-A
M8VGS(.ES(&$@<'5N="XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(D%P
M;&EC87(@82!R96-U<G-O<R!C;VUP87)T:71S(&1E<V-E;F1E;G1S+B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!
M<'!R;W9E(@IM<V=S='(@(D%P<F]V87(B"@HC.B!L:6(O2&]R9&4O34E-12]#
M;VYT96YT<RYP:'`Z.#(V"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S
M='(@(DUI9&$@87!R;WAI;6%D82(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HS-S<@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R(")!8G)I;"(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M
M,3(U-BDB"FUS9W-T<B`B07+@8FEC("A7:6YD;W=S+3$R-38B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV,R!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&=Z+G!H<#HX,0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R
M+G!H<#HU.0IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B36ED
M82!D92!L)V%R>&EU(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#`*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@*;7-G:60@(D%R8VAI=F4@
M3F%M92(*;7-G<W1R(").;VT@9&4@;"=A<GAI=2(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N
M=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R(")6;VQE=2!S=7!R:6UI<B!L
M82!S;VRW;&EC:71U9"!D)V%L=&$@82`E<S\B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V1E;&5T92YI;F,Z.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92`G)7,G(&%N
M9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`B5F]L974@97-B;W)R87(@)R5S
M)R!I('1O=',@96QS('-U8F=R=7!S/R(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C8*;7-G:60@(D%R9V5N=&EN82(*;7-G
M<W1R(")!<F=E;G1I;F$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(R"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(D%R;>AN
M:6$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-@IM<V=I9"`B07)M96YI
M86X@*$%235-#24DM."DB"FUS9W-T<B`B07)M96YI("A!4DU30TE)+3@I(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T
M<B`B07)T(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HS,`IM<V=I9"`B07)U8F$B"FUS9W-T<B`B07)U8F$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B
M"FUS9W-T<B`B26QL82!D92!L)T%S8V5N<VGS(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B9W+@9FEC
M($%30TE)(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*;7-G:60@
M(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B4F5G:?,@9&5L(%!A8^UF
M:6,@87-IX'1I8R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,34*;7-G
M:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N
M86YC92!O<&5R871I;VYS/R(*;7-G<W1R(")6;VQE=2!C;VYF:7)M86-I\R!A
M8F%N<R!D)V5F96-T=6%R(&QE<R!O<&5R86-I;VYS(&1E(&UA;G1E;FEM96YT
M/R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3$Q"FUS9VED(")!<W-I9VYM
M96YT(&-O;'5M;G,B"FUS9W-T<B`B0V]L=6UN97,@9"=A<W-I9VYA8VGS(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HW-0IM<V=I9"`B071T96UP="!T;R!D96QE
M=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(E,G:&$@:6YT96YT
M870@<W5P<FEM:7(@=6X@9W)U<"!N;R!E>&ES=&5N="XB"@HC.B!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C,X"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A
M(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")3)VAA(&EN=&5N
M=&%T('-U<')I;6ER('5N82!A=71O<FET>F%C:?,@;F\@97AI<W1E;G0N(@H*
M(SH@861M:6XO<&5R;7,O961I="YP:'`Z.3@*;7-G:60@(D%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")3)VAA
M(&EN=&5N=&%T(&5D:71A<B!U;F$@875T;W)I='IA8VGS(&YO(&5X:7-T96YT
M+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T
M96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R(")3
M)VAA(&EN=&5N=&%T(&5D:71A<B!U;B!R96-U<G,@8V]M<&%R=&ET(&YO(&5X
M:7-T96YT+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8X
M(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@V"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R87(N<&AP.C8T"FUS9VED(")!='1R:6)U=&5S(@IM
M<V=S='(@(D%T<FEB=71S(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,X,2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R(")!9V]S="(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C4Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,CD*;7-G:60@(D%U
M<W1R86QI82(*;7-G<W1R(")!=7-T<N!L:6$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HU.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(X"FUS9VED(")!=7-T<FEA(@IM
M<V=S='(@(L!U<W1R:6$B"@HC.B!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP
M.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)S<6PZ($YO(',G:&$@
M=')O8F%T(&PG97AT96YS:?,@:6UA<"!N96-E<W/@<FEA+B(*"B,Z(&QI8B](
M;W)D92]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A
M8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS
M9W-T<B`B075T:%]C>7)U<SH@16P@;6]T;W(@;F\@=.D@;&5S(&-A<&%C:71A
M=',@;F5C97-SX')I97,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP
M.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!.;R!S)VAA('1R
M;V)A="!L)V5X=&5N<VGS($E-05`@;F5C97-SX')I82XB"@HC.B!L:6(O2&]R
M9&4O075T:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER
M960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@
M=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*(D%U=&A?
M9G1P.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N<VGS($944"!N96-E<W/@<FEA
M+B!#86P@8V]M<&EL87(@4$A0(&%M8B!E;"`B"B)C;VUM=71A9&]R("UE;F%B
M;&4M9G1P+B(*"B,Z(&QI8B](;W)D92]!=71H+VEM87`N<&AP.C8T"FUS9VED
M(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B075T:%]I;6%P.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N
M<VGS($E-05`@;F5C97-SX')I82XB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U
M+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:W)B-3H@3F\@<R=H82!T
M<F]B870@;"=E>'1E;G-I\R!K<F(U(&YE8V5S<^!R:6$N(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O;&1A<"YP:'`Z-3@*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER
M960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VQD
M87`Z($YO(',G:&$@=')O8F%T(&PG97AT96YS:?,@3$1!4"!N96-E<W/@<FEA
M+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$X-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*(D%U
M=&A?;&1A<#H@3F\@<R=H82!P;V=U="!A9F5G:7(@;"=U<W5A<FD@)7,N($%I
M>/(@Z7,@96P@<75E(&AA(&1I="!E;"`B"B)S97)V:61O<CHB"@HC.B!L:6(O
M2&]R9&4O075T:"]L9&%P+G!H<#HR,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B
M075T:%]L9&%P.B!.;R!S)VAA('!O9W5T('-U<')I;6ER(&PG=7-U87)I("5S
M+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C(X,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E
M<R(*;7-G<W1R(")!=71O7VQD87`Z($YO(',G:&$@<&]G=70@86-T=6%L:71Z
M87(@;"=U<W5A<FD@)7,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'`Z
M-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")!=71O7VUC86PZ($YO(',G:&$@=')O8F%T
M(&PG97AT96YS:?,@34-!3"!N96-E<W/@<FEA+B(*"B,Z(&QI8B](;W)D92]!
M=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@
M<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7W-M
M8F%U=&@Z($YO(',G:&$@=')O8F%T(&PG97AT96YS:?,@4TU"05542"!N96-E
M<W/@<FEA+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C@Y"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B4R=H
M82!P<F]D=>]T('5N(&5R<F]R(&5N(&PG875T96YT:6-A8VGS+B(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(E,G:&$@<')O9'7O
M="!U;B!E<G)O<B!E;B!L)V%U=&5N=&EC86-I\RX@)7,B"@HC.B!L:6(O2&]R
M9&4O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC871I;VX@
M<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`B16P@<V5R=FED
M;W(@4D%$2553(&AA(')E8G5T:F%T(&PG875T96YT:6-A8VGS+B(*"B,Z(&QI
M8B]61E,O9G1P+G!H<#HW-C@*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($94
M4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")3)VAA('!R;V1U[W0@=6X@97)R
M;W(@96X@;"=A=71E;G1I8V%C:?,@86UB(&5L('-E<G9I9&]R($944"XB"@HC
M.B!L:6(O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O
M('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B4R=H82!P<F]D=>]T
M('5N(&5R<F]R(&5N(&PG875T96YT:6-A8VGS(&%M8B!E;"!S97)V:61O<B!3
M34(N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHX,PIM<V=I9"`B
M079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B0V%M<',@9&ES<&]N:6)L97,Z
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS
M,0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R(")!>F5R8F%I9&IA;B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S
M(@IM<V=S='(@(D)/1D@@17AC=7-E<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U
M;F0B"FUS9W-T<B`B1F]N<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS
M9W-T<B`B0V]L;W(@9&5L(&9O;G,B"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U
M+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R
M(")#;VYT<F%S96YY82!+97)B97)O<R!I;F-O<G)E8W1A+B(*"B,Z(&QI8B](
M;W)D92]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E
M<FYA;64N(@IM<V=S='(@(DYO;2!D)W5S=6%R:2!+97)B97)O<R!I;F-O<G)E
M8W1E+B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-#4*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B0F%H86UE<R(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8Q(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S@*;7-G:60@
M(D)A:')A:6XB"FUS9W-T<B`B0F%H<F%I;B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3<W"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R
M(")"X&QT:6,@*$E33RTX.#4Y+3$S*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S0*;7-G:60@(D)A;F=L861E<V@B"FUS
M9W-T<B`B0F%N9VQA($1E<V@B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C,S"FUS9VED(")"87)B861O<R(*;7-G<W1R(")"
M87)B861O<R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@
M)R5S)R!N;W0@9F]U;F0N(@IM<V=S='(@(DYO(',G:&$@=')O8F%T(&5L(&1I
M<F5C=&]R:2!D92!G<N!F:6-S(&+@<VEC<R`G)7,G(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"FUS9VED(")"
M87-E;&EN92(*;7-G<W1R("),[6YI82!B87-E(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,P
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT.0IM<V=I9"`B0F5L87)U<R(*
M;7-G<W1R(")":65L;W)R^G-I82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,S4*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B
M0NAL9VEC82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-3`*;7-G:60@(D)E;&EZ92(*;7-G<W1R(")"96QI>F4B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0P"FUS9VED
M(")"96YI;B(*;7-G<W1R(")"96[M;B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#$*;7-G:60@(D)E<FUU9&$B"FUS9W-T
M<B`B0F5R;75D97,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C0V"FUS9VED(")":'5T86XB"FUS9W-T<B`B0FAU=&%N(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@
M(D)I<G1H9&%Y(@IM<V=S='(@(D%N:79E<G-A<FDB"@HC.B!L:6(O2&]R9&4O
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(W"B,L('!H<"UF;W)M870*;7-G:60@
M(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R(").;R!S)VAA('1R;V)A="!E;"!B;&]C(%PB)7-<(B!D92!L
M)V%P;&EC86-I\R!<(B5S7"(@+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B4&%R
MX&UE=')E<R!D96P@8FQO8R(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R(")4:7!U<R!D92!B
M;&]C(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX"FUS9VED(")";VQD(@IM<V=S='(@(DYE9W)E=&$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0S"FUS9VED(")";VQI
M=FEA(@IM<V=S='(@(D)O;.UV:6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,3@Y"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B36%R8V%D;W)S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(D-O;G1O<FXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@U"FUS9VED
M(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R(")'<G5I>"!D96P@8V]N=&]R
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B0V]N=&]R;G,B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,R"FUS
M9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(D+R<VYI82!I
M($AE<F-E9V]V:6YA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS
M9VED(")";W1H(@IM<V=S='(@(D%M8F3S<R(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS.`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#@*;7-G:60@(D)O='-W86YA(@IM
M<V=S='(@(D)O='-W86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T;VTB"FUS9W-T<B`B
M26YF97)I;W(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C0W"FUS9VED(")";W5V970@27-L86YD(@IM<V=S='(@(DEL;&$@
M9&4@0F]U=F5T(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HT-`IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(D)R87-I;"(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HT,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$W"FUS
M9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B
M5&5R<FET;W)I(&]C9>!N:6,@9&4@;"?-;F1I82!B<FETX&YI8V$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0R"FUS9VED
M(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R(")"<G5N96D@1&%R=7-S86QA
M;2(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV-C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0G5I;&1I;F<@34\@9FEL97,@9F]R(&UO9'5L92`E<RXN+B(*;7-G
M<W1R(")#;VYT<G5I;G0@9FET>&5R<R!-3R!P97(@86P@;?)D=6P@)7,N+BXB
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C<S"B,L('!H<"UF;W)M870*;7-G
M:60@(D)U:6QD:6YG(&QO8V%L92`E<RXN+B`B"FUS9W-T<B`B0V]N<W1R=6EN
M="`E<RXN+B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,S<*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(D)U;&?@<FEA(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM
M<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R("),;&ES=&$@9&4@<&EC<R(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HT-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S8*
M;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R(")"=7)K:6YA($9A<V\B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,Y"FUS
M9VED(")"=7)U;F1I(@IM<V=S='(@(D)U<G5N9&DB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S<T"FUS9VED(")#35,B"FUS9W-T<B`B0TU3(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*;7-G:60@(D-2
M0R(*;7-G<W1R(")#4D,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4Y-PIM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B
M4'5N=',@9&4@9&ES=')I8G5C:?,@9&4@0U),(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED(")#
M7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(E!R;W!I971A=',@9&4@8V5L
MMVQA+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-0IM
M<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B
M3F\@<R=H82!F:6YA;&ET>F%T(&5L('!R;V/I<R!D)VEN:6-I86QI='IA8VGS
M(&1E(&QA(&UE;?)R:6$@8V%U(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0U-B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30V
M"FUS9VED(")#86QE;F1A<B(*;7-G<W1R(")#86QE;F1A<FDB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,X"FUS9VED(")#86QM(@IM<V=S
M='(@(D-A;&UA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,C@*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(D-A;6)O9&IA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C0W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV
M,`IM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B0V%M97)U;B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T
M('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R("(B"B+)<R!I;7!O<W-I8FQE(')E:6YI8VEA<B!L
M82!C;VYT<F%S96YY82!A=71O;>!T:6-A;65N="P@<&]S82=T(&5N(&-O;G1A
M8W1E("(*(F%M8B!L)V%D;6EN:7-T<F%D;W(@9&5L('-I<W1E;6$N(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C(S-2!L:6(O2&]R9&4O075T:"]C
M>7)S<6PN<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN
M96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R("+)<R!I;7!O<W-I8FQE
M(&-O;FYE8W1A<B!A;6(@96P@<V5R=FED;W(@24U!4#H@)7,N(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C0X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,0IM<V=I9"`B
M0V%N861A(@IM<V=S='(@(D-A;F%DX"(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P
M,2!A9&UI;B]U<V5R+G!H<#HQ,C`@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E+FEN8SHQ-PHC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M,3<@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$T"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0IM<V=I9"`B
M0V%N8V5L(@IM<V=S='(@(D-A;F-E;+=L87(B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P
M;W)T(@IM<V=S='(@(D-A;F-E;+=L87(@;"=I;F9O<FUE(&1E('!R;V)L96UE
M<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C4V"B,L('!H<"UF;W)M870*;7-G
M:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYO(&5S
M('!O="!E<V)O<G)A<B!L)V%R>&EU(%PB)7-<(BXB"@HC.B!L:6(O5D93+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!L:6(O
M5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*
M;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B3F\@97,@<&]T('1R;V)A<B!U;B!D:7)E8W1O<FD@=&5M<&]R86PN
M(@H*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@
M<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S
M='(@(DYO(&5S('!O="!C;VYT:6YU87(@<V5N<V4@96P@<&%RX&UE=')E("=T
M87)G971&:6QE)RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C4R"B,L('!H<"UF
M;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB
M"FUS9W-T<B`B3F\@97,@<&]T(&5S8F]R<F%R(&5L(&1I<F5C=&]R:2!<(B5S
M7"(N(@H*(SH@;&EB+TAO<F1E+T1A=&%4<F5E+G!H<#HQ,3(@;&EB+TAO<F1E
M+T1A=&%4<F5E+W-Q;"YP:'`Z-3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R(").;R!E
M<R!P;W0@97-B;W)R87(L(&-O;G3I(&1E<V-E;F1E;G1S("5D+B`B"@HC.B!L
M:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HU,3(*;7-G:60@(B(*(D-A;FYO
M="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O
M<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R
M("(B"B).;R!E<R!P;W0@<F5O<F1E;F%R+"!E;"!N;VUB<F4@9"=E;G1R861E
M<R!Q=64@<R=H86X@9&4@<F5O<F1E;F%R(&YO("(*(F-O:6YC:61E:7@@86UB
M(&QE<R!Q=64@:&D@:&$@96UM86=A='IE;6%D97,N(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(D-A;FYO="!R;W5T
M92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(DYO(&5S
M('!O="!A9')EYV%R(&5L(&UI<W-A=&=E(&%L(&YO;6)R92!E<W!E8VEF:6-A
M="XB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C8U"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(D-A<"!697)D(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R("),;&5G96YD82(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B
M96QS(@IM<V=S='(@(D-A=&5G;W)I97,@:2!E=&EQ=65T97,B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-0IM<V=I9"`B
M0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B26QL97,@0V%I;6%N(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@
M4&AO;F4B"FUS9W-T<B`B5&5LZ&9O;B!M\F)I;"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E
M;&P@4')O<&5R=&EE<R(*;7-G<W1R(")0<F]P:65T871S(&1E(&-E;+=L82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T
M"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(D9A<F-I;65N="!D92!C
M96RW;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B
M4')O<&EE=&%T<R!D92!L82!C96RW;&$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG
M.B(*;7-G<W1R(")%<W!A:6%T(&5N=')E(&-E;+=L97,B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3(W-`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(E1E
M;.AF;VX@;?)B:6PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I
M9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B0^AL=&EC("A)4T\M
M.#@U.2TQ-"DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T<B`B0V5N=')A
M<B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8U(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-30*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R(")2
M97#Z8FQI8V$@0V5N=')E869R:6-A;F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$W.0IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB
M"FUS9W-T<B`B175R;W!A(&-E;G1R86P@*$E33RTX.#4Y+3(I(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.3D*;7-G:60@(D-E<G1I9FEC871E
M($1E=&%I;',B"FUS9W-T<B`B1&5T86QL<R!D96P@8V5R=&EF:6-A="(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C$Q"FUS9VED(")#97)T:69I
M8V%T92!/=VYE<B(*;7-G<W1R(")4:71U;&%R(&1E;"!C97)T:69I8V%T(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@(D-E<G1I
M9FEC871E(%!O;&EC:65S(@IM<V=S='(@(E!O;.UT:7%U97,@9&4@8V5R=&EF
M:6-A8VGS(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C(Q"FUS9VED(")#:&%D(@IM<V=S='(@(E1X860B"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.CDW"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B1&5S9NES(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@
M=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE
M>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B
M(@HB0V%N=FEE=2!E;"!N;VT@:2!L)V%D<F7G82!Q=64@<_-N('9I<VEB;&5S
M('%U86X@97,@;&QE9V5I>&5N(&\@97,@<F5S<&]N96X@(@HB96QS('9O<W1R
M97,@;6ES<V%T9V5S(&1E(&-O<G)E=2!E;&5C='+R;FEC+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G
M:60@(D-H87(B"FUS9W-T<B`B0VAA<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K
M($QI;FLN+BXB"FUS9W-T<B`B5F5R:69I8V$@;"=E;FQL8><N+BXB"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$S"B,L(&9U
M>GIY"FUS9VED(")#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I
M('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(B
M"B)-87)C82!A(&QA(&-A<V5L;&$@;"=O<&5R86-I\R!O(&]P97)A8VEO;G,@
M<75E(&1E<VET9VES(&5X96-U=&%R(&5N(&%Q=65S=&$@(@HB;V-A<VGS+B(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HU,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3D*
M;7-G:60@(D-H:6QE(@IM<V=S='(@(EAI;&4B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8Q"FUS9VED(")#:&EN82(*;7-G
M<W1R(")8:6YA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@
M(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R(")8:6[H<R!S
M:6UP;&EF:6-A="`H1T(R,S$R*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@Q"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R
M(")8:6[H<R!T<F%D:6-I;VYA;"`H0FEG-2DB"@HC.B!L:6(O2&]R9&4O075T
M:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS
M9W-T<B`B5')I82!U;F$@8V]N=')A<V5N>6$B"@HC.B!L:6(O2&]R9&4O075T
M:"]3:6=N=7`N<&AP.C(V.`IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS
M9W-T<B`B5')I82!U;B!N;VT@9"=U<W5A<FDB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C@X"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T
M97,Z(@IM<V=S='(@(E1R:6$@8V]M('9O;',@=FES=6%L:71Z87(@;&5S(&1A
M=&5S.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@
M*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R(")4<FEA('5N('1I<'5S(&0G
M97-T:6P@9&4@;&QI<W1A("AP97(@82!L;&ES=&5S(&]R9&5N861E<RDB"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-34*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8V"FUS
M9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(DEL;&$@9&4@0VAR:7-T
M;6%S(@H*(SH@;&EB+U9&4RYP:'`Z.3$S(&QI8B].970O4TU3+G!H<#HR.30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N
M;W0@9F]U;F0N(@IM<V=S='(@(DYO(',G:&$@=')O8F%T(&QA(&1E9FEN:6-I
M\R!D92!C;&%S<V4@9&4@("5S+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX
M-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE86YI;F<@=7`@4$\@9FEL97,@
M9F]R(&UO9'5L92`E<RXN+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z.#8W"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%N:6YG('5P(&QO
M8V%L92`E<RXN+B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D-L96%R(@IM<V=S='(@(D5L
M:6UI;F%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R(")%
M;&EM:6YA(&QE<R!E=&EQ=65T97,@9&4@35-/9F9I8V4B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B17-B;W)R82!L)W5S=6%R
M:3H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,38*
M;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B17-B;W)R82!L)W5S=6%R:2(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#
M;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B17-B;W)R82!L97,@9&%D97,@9&4@
M;"=U<W5A<FDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ,PIM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R(")3)V%C;&%R
M:7+@(&-A<"!A;"!T87)D+B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]N
M;W1I8V5?8F]T=&]M+FEN8SHV"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*
M;7-G<W1R(")0<F5M:2!P97(@8V]N=&EN=6%R(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#,*;7-G:60@(D-L:6-K871E;&P@=FEA
M($A45%`B"FUS9W-T<B`B0VQI8VMA=&5L;"!P97(@2%144"(*"B,Z('-E<G9I
M8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(E1A;F-A(&QA(&9I
M;F5S=')A(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#(*;7-G:60@(D-L
M;W5D<R(*;7-G<W1R(").^G9O;',B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S
M='(@(D[Z=F]L<R!A('!R:6UE<F$@:&]R82(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#;&]U9'DB"FUS9W-T
M<B`B16YN=79O;&%T(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HU,@IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B
M"FUS9W-T<B`B26QL97,@9&4@0V]C;W,@*$ME96QI;F<I(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHT"FUS9VED(")#;VQL87!S92!3:61E
M8F%R(@IM<V=S='(@(E)E9'7O=2!L82!B87)R82!L871E<F%L(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM
M<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B36%R9V5S(')E9'7O
M=',B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C8R"FUS9VED(")#;VQO;6)I82(*;7-G<W1R(")#;VSR;6)I82(*"B,Z(&QI
M8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R(")#;VQO<B(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT-S(@;&EB+TAO<F1E+T)L;V-K
M+T-O;&QE8W1I;VXN<&AP.C(Y.`HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C
M=&EO;BYP:'`Z,CDY('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z
M,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-3$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-3(*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-C@*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-CD*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M.#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M.#8*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R(")396QE8W1O<B!D92!C
M;VQO<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#0T"FUS9VED(")#;VQO
M=7(@<V5L96-T:6]N(@IM<V=S='(@(E-E;&5C8VGS(&1E(&-O;&]R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G
M:60@(D-O;',Z(@IM<V=S='(@(D-O;'5M;F5S.B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ.30V"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(E3M
M=&]L<R!D92!L97,@8V]L=6UN97,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C@T"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B0_)M:6-S(@H*(SH@
M861M:6XO8VUD<VAE;&PN<&AP.C(U"FUS9VED(")#;VUM86YD(@IM<V=S='(@
M(D]R9')E(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM
M86YD(%-H96QL(@IM<V=S='(@(D-O;G-O;&$B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(D-O;6UA;F0@;W!T:6]N<SHB"FUS
M9W-T<B`B3W!C:6]N<R!D92!L82!C;VQU;6YA(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.CDW"B,L(&9U>GIY"FUS9VED(")#;VUM86YD<SHB"FUS9W-T<B`B
M3W)D<F4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#(*;7-G:60@
M(D-O;6UE;G0B"FUS9W-T<B`B0V]M96YT87)I(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C$P,#`*(RP@9G5Z>GD*;7-G:60@(D-O;6UI='1I;F<Z(@IM<V=S
M='(@(D-O;F1I8VEO;G,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4V-@IM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B3F]M(&-O;?HB"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,`IM
M<V=I9"`B0V]M;W)O<R(*;7-G<W1R(")#;VUO<F5S(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS
M9W-T<B`B0V]M<&%N>6EA(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M
M86EL<RYP:'`Z.#$@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z
M.#<*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.3<@;&EB
M+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O;7!O<V4@365S<V%G92`H)7,I(@IM<V=S='(@(D5S8W)I
M=2!E;"!M:7-S871G92`H)7,I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B3W)D:6YA9&]R<R(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C0W"FUS9VED(")#;VYD:71I;VYS(@IM
M<V=S='(@(D-O;F1I8VEO;G,B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY
M-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R(")$
M:69E<NAN8VEE<R!D92!C;VYF:6=U<F%C:?,B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3,T"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D
M871E+B(*;7-G<W1R("),82!C;VYF:6=U<F%C:?,@;F\@97-TX"!A8W1U86QI
M='IA9&$N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.CDY"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R(")#;VYF:6=U<F$@
M)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,W"FUS
M9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(D-O;F9I<FUA<B!L82!C
M;VYT<F%S96YY82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-34*;7-G:60@(D-O;F=O(@IM<V=S='(@(D-O;F=O(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C4@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C8P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,PIM<V=I
M9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G
M<W1R(")#;VYG;RP@4F5P^F)L:6-A($1E;6]C<N!T:6-A(&1E;"(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL
M960N(@IM<V=S='(@(DYO(.ES('!O<W-I8FQE(')E86QI='IA<B!L82!C;VYN
M97AI\RXB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O
M;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B3F\@Z7,@<&]S<VEB;&4@<F5A
M;&ET>F%R(&QA(&-O;FYE>&GS.B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C<W.0IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")3)VAA(')E8G5T:F%T(&QA(&-O;FYE
M>&GS(&%L('-E<G9I9&]R(&1E(&-L875S('#Z8FQI<75E<RXB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HW.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!2
M96%S;VXZ("5S("@E<RDB"FUS9W-T<B`B4R=H82!R96)U=&IA="!L82!C;VYN
M97AI\R!A;"!S97)V:61O<B!D92!C;&%U<R!P^F)L:7%U97,N(%)A\SH@)7,@
M*"5S*2(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW-C(*;7-G:60@(D-O;FYE8W1I
M;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(DYO(.ES('!O<W-I
M8FQE(')E86QI='IA<B!L82!C;VYN97AI\R!A;"!S97)V:61O<B!&5%`N(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B
M0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R
M97-S(&)O;VLN(@IM<V=S='(@(D5L<R!C;VYT86-T97,@<R=H86X@869E9VET
M(&-O<G)E8W1A;65N="!A(&QA('1E=F$@;&QI8G)E=&$@9"=A9')E8V5S+B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8P(&QI8B](;W)D
M92]-24U%+U9I97=E<B]T9WHN<&AP.C<X"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]R87(N<&AP.C4V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;VYT96YT<R!O9B`G)7,G(@IM<V=S='(@(D-O;G1I;F=U="!D92`E<R(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y"FUS9VED(")#;VYT:6YU
M92(*;7-G<W1R(")#;VYT:6YU87(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C4X"FUS9VED(")#;V]K($ES;&%N9',B"FUS
M9W-T<B`B26QL97,@0V]O:R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(D=A;&5T82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I
M9"`B0V]P>2(*;7-G<W1R(")#;W!I87(B"@HC.B!L:6(O5D93+W-M8BYP:'`Z
M-#<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G
M<W1R("+)<R!I;7!O<W-I8FQE(&-O<&EA<CH@)7,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E
M;&5C=&EO;B(*;7-G<W1R(")#;W!I87(@<V5L96-C:?,B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,3`X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]P>6EN9R`E<R!T;R`E<R(*;7-G<W1R(");;.UN:6$@)7,@9&4@)7-=(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C8R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,PIM
M<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R(")#;W-T82!2:6-A(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C8S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-PIM<V=I9"`B
M0V]T92!D)TEV;VER92(*;7-G<W1R(")#;W-T82!D)TEV;W)I(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.34V"B,L(&9U>GIY"FUS9VED(")#;W5L
M9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B3F\@97,@<&]T
M('AI9G)A<B!E;"!M:7-S871G92!A;6(@4$=0+B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C$P,S,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!0
M1U`@<VEG;B!M97-S86=E+B(*;7-G<W1R(").;R!E<R!P;W0@<VEG;F%R(&5L
M(&UI<W-A=&=E(&%M8B!01U`N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S
M86=E+B(*;7-G<W1R(").;R!E<R!P;W0@>&EF<F%R(&5L(&UI<W-A=&=E(&%M
M8B!3+TU)344N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HT-C<*
M;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R
M(").;R!E<R!P;W0@<VEG;F%R(&5L(&UI<W-A=&=E(&%M8B!3+TU)344N(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S
M='(@(DYO(&5S('!O="!A9F5G:7(@96P@8V]N=&%C=&4N("5S(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3$P"FUS9VED(")#;W5L9"!N;W0@8FEN
M9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3F\@97,@<&]T(&-O;FYE8W1A
M<B!A;6(@96P@<V5R=FED;W(@3$1!4"XB"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$W,B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,34U"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C
M:R!B86QA;F-E+B`E<R(*;7-G<W1R(").;R!E<R!P;W0@8V]M<')O=F%R(&5L
M('-A;&1O+B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@
M<V5R=F5R("<E<R<@=7-I;F<@1E10.B`E<R(*;7-G<W1R(").;R!S)VAA('!O
M9W5T(&-O;FYE8W1A<B!A;6(@96P@<V5R=FED;W(@)R5S)R!M:71J86[G86YT
M($944#H@)7,N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P.#<*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;W!Y("5S('1O("5S
M(@IM<V=S='(@(DYO(',G:&$@<&]G=70@;V)R:7(@)7,N(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R(").;R!S)VAA('!O9W5T(&-R96%R('5N82!L;&ES=&$@9&4@9&ES
M=')I8G5C:?,N("5S(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8X,2!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3`W-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&-R96%T92!L;V-A;&4@9&ER96-T;W)Y(&9O<B!L;V-A
M;&4@)7,Z(@IM<V=S='(@(DYO(',G:&$@<&]G=70@;V)R:7(@96P@9&ER96-T
M;W)I("<E<R<N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$P-0HC
M+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N(@IM
M<V=S='(@(DYO(',G:&$@<&]G=70@9&5S>&EF<F%R(&QE<R!D861E<R!01U`N
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU,C(*;7-G:60@(D-O
M=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R(").;R!S)VAA
M('!O9W5T(&1E<WAI9G)A<B!L97,@9&%D97,@4R]-24U%+B(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R(").
M;R!S)VAA('!O9W5T(&5S8F]R<F%R(&5L(&-O;G1A8W1E+B`E<R(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-34*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,B"FUS9W-T<B`B3F\@<R=H82!P;V=U="!E<V)O<G)A<B!L82!L;&ES=&$@
M9&4@9&ES=')I8G5C:?,N("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D
M96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@)R5S)RXB"FUS9W-T<B`B3F\@
M<R=H82!P;V=U="!E<V)O<G)A<B!L82!S97'\Z&YC:6$@9"=A8W1U86QI='IA
M8VGS(&EN<W1A;+=L861A("<E<R<N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z.3,X(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S@Q"FUS9VED
M(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@
M861D<F5S<RXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!D971E<FUI;F%R(&PG
M861R9>=A(&5L96-T<O)N:6-A(&1E;"!D97-T:6YA=&%R:2XB"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@R"FUS9VED(")#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R(").;R!S
M)VAA('!O9W5T(')E8V]L;&ER('1O=&$@;&$@;&QI8G)E=&$@9"=A9')E8V5S
M+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3(*;7-G
M:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES
M="XB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!R96-O;&QI<B!T;W1A(&QA(&QL
M:7-T82!D92!D:7-T<FEB=6-I\RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-#0U"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O
M;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R(").
M;R!S)VAA('!O9W5T(')E8V]L;&ER('1O=&$@;&$@;&QI<W1A(&1E(&QE<R!L
M;&ES=&5S(&1E(&1I<W1R:6)U8VGS+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC.B!L:6(O5D93+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`G)7,G+B(*;7-G
M<W1R(").;R!S)VAA('!O9W5T(&-A<G)E9V%R(&PG97-T<F%TZ&=I82`G)7,G
M+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C$Q,`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDO9&ER96-T+G!H<#HS,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&UK9&ER("<E<R<N(@IM<V=S='(@(DYO(',G:&$@<&]G
M=70@8W)E87(@96P@9&ER96-T;W)I("<E<R<N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-S`X"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI
M8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R(").;R!S)VAA('!O
M9W5T(&]B=&5N:7(@=6YA(&-L874@</IB;&EC82!D96P@<V5R=FED;W(@9&4@
M8VQA=7,N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M-#0@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B3F\@
M<R=H82!P;V=U="!O8G)I<B`E<RXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("<E<R<@9F]R('=R:71I;F<N
M(@IM<V=S='(@(DYO(',G:&$@<&]G=70@;V)R:7(@)R5S)R!P97(@97-C<FEU
M<F4N(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HT,3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S
M:R!M;V1U;&4@)7,B"FUS9W-T<B`B3F\@<R=H82!P;V=U="!O8G)I<B!E;"!M
M\F1U;"!D92!T87-Q=65S(&1E(&UA;G1E;FEM96YT("5S+B(*"B,Z(&QI8B]6
M1E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E
M8W1O<GD@)R5S)RXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!O8G)I<B!E;"!D
M:7)E8W1O<FD@)R5S)RXB"@HC.B!L:6(O5D93+T]B:F5C="YP:'`Z,C,X"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R
M(").;R!S)VAA('!O9W5T(&QL96=I<B`E<RXB"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H
M92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L
M;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I
M;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B
M"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(DYO(',G:&$@<&]G=70@<F5I
M;FEC:6%R(&QA(&-O;G1R87-E;GEA('!E<B!A(&PG=7-U87)I('-O;+=L:6-I
M=&%T+B!!;&=U;G,@(@HB9&5T86QL<R!O('1O=',@;F\@<_-N(&-O<G)E8W1E
M<RX@5&]R;F%R+6AO(&$@:6YT96YT87(@;RP@<&5R(&$@;>ES("(*(FEN9F]R
M;6%C:?,L('!O<V$G="!E;B!C;VYT86-T92!A;6(@;"=A9&UI;FES=')A9&]R
M(&1E;"!S:7-T96UA+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS,#D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<W(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*(SH@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,X.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M($%#3"(*;7-G<W1R(").;R!S)VAA('!O9W5T(')E8W5P97)A<B!L97,@04-,
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B
M;V]K+B`E<R(*;7-G<W1R(").;R!S)VAA('!O9W5T(')E8W5P97)A<B!L82!L
M;&EB<F5T82!D)V%D<F5C97,N("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C0X,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYO
M(',G:&$@<&]G=70@<F5C=7!E<F%R(&QA(&QL:7-T82!D92!D:7-T<FEB=6-I
M\RX@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,V
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T
M<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(DYO(',G:&$@<&]G=70@<F5C
M=7!E<F%R(&QE<R!L;&ES=&5S(&1E(&1I<W1R:6)U8VGS+B`E<R(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,C(S"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R
M=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(DYO(',G:&$@<&]G=70@<F5C
M=7!E<F%R(&QE<R!P;W-S:6)I;&ET871S(&1E;"!S97)V:61O<B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!R979E
M<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!R97-T
M875R87(@;&$@8V]N9FEG=7)A8VGS+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@)R5S)RXB"FUS9W-T<B`B
M3F\@<R=H82!P;V=U="!E;&EM:6YA<B!E;"!D:7)E8W1O<FD@)R5S)RXB"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M(").;R!S)VAA('!O9W5T(&1E<V%R(&QA(&-O;F9I9W5R86-I\R`E<RXB"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-R!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-C,*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I
M9W5A=&EO;BXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!D97-A<B!U;F$@8V]N
M9FEG=7)A8VGS(&1E('-E9W5R971A="XB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R(").;R!S)VAA('!O
M9W5T(&1E<V%R('5N82!C;VYF:6=U<F%C:?,@9&4@<V5G=7)E=&%T.B`E<R(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDR"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C
M<FEP="!T;SH@)R5S)RXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!D97-A<B!L
M82!S97'\Z&YC:6$@9"=A8W1U86QI='IA8VGS(&EN<W1A;+=L861A(&5N.B`G
M)7,G+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U
M<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*(DYO(',G:&$@<&]G=70@9&5S
M87(@;&$@8_)P:6$@9&4@<V5G=7)E=&%T(&1E(&PG87)X:74@9&4@8V]N9FEG
M=7)A8VGS("5S+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I
M9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T
M:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@
M8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B
M(@HB3F\@<R=H82!P;V=U="!D97-A<B!L)V%R>&EU(&1E(&-O;F9I9W5R86-I
M\R`E<RX@4&]T<R!U=&EL:71Z87(@=6YA(&1E(&QE<R`B"B)O<&-I;VYS('!E
M<B!T;W)N87(@82!D97-A<B!E;"!C;V1I(&5N("5S(&\@8ND@8V]P:6%R(&UA
M;G5A;&UE;G0@96P@8V]D:2`B"B)S96?\96YT(&5N("5S+B(*"B,Z(&QI8B](
M;W)D92]!=71H+VQD87`N<&AP.C$R,`IM<V=I9"`B0V]U;&0@;F]T('-E87)C
M:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DYO(',G:&$@<&]G=70@8V5R
M8V%R(&%L('-E<G9I9&]R($Q$05`N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@)R5S)RXB"FUS9W-T<B`B
M3F\@<R=H82!P;V=U="!D97-E;FQL8>=A<B`G)7,G+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R(").;R!S
M)VAA('!O9W5T(&%C='5A;&ET>F%R(&5L(&-O;G1A8W1E+B`E<R(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.34*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,B"FUS9W-T<B`B3F\@<R=H82!P;V=U="!A8W1U86QI='IA<B!L82!L;&ES
M=&$@9&4@9&ES=')I8G5C:?,N("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@)R5S)SH@)7,B"FUS9W-T<B`B3F\@
M<R=H82!P;V=U="!E<V-R:75R92!L82!C;VYF:6=U<F%C:?,@<&5R(&$@)R5S
M)SH@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4V"FUS9VED(")#
M;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T
M:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B"B).;R!S)VAA('!O9W5T
M(&QO8V%L:71Z87(@;&$@8F%R<F$@;&%T97)A;"!D92!-;WII;&QA+B!#;VUP
M<F]V82!Q=64@;&$@8F%R<F$@(@HB;&%T97)A;"!E<W1I9W5I(&]B97)T82XB
M"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9&XG="!G:79E('5S97(@)R5S
M)R!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`G)7,G.B`E
M<R(*;7-G<W1R("(B"B).;R!S)VAA('!O9W5T(&-O;F-E9&ER(&$@;"=U<W5A
M<FD@)R5S)R!E;',@9')E=',@<V5G_&5N=',@<&5R(&$@;&$@8V%R<&5T82`G
M)2(*(G,G.B`E<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(T"FUS9VED
M(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B5&5X="!C;VUP=&%T(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D-O=6YT<GDB"FUS
M9W-T<B`B4&'M<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C@*
M;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B0W5R<V]S(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHY-PHC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q"FUS
M9VED(")#<F5A=&4B"FUS9W-T<B`B0W)E87(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D-R
M96%T92!A(&QI;FLB"FUS9W-T<B`B0W)E87(@=6X@96YL;&'G(@H*(SH@=&5M
M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PIM<V=I9"`B0W)E
M871E(&$@;F5W(&]N92(*;7-G<W1R(")#<F5A<BUN92!U;B!D92!N;W4B"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R
M96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R(")#<F5A<B!S=6)C87)P971E<R(*
M"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$S-B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C(Q-`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R
M(")097)M:7-O<R!D96P@8W)E861O<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HS,C(X"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B3OIM
M97)O(&1E(&QA('1A<F=E=&$@9&4@8W+H9&ET(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8T
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#D*;7-G:60@(D-R;V%T:6$B
M"FUS9W-T<B`B0W)OX&-I82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-C0*;7-G:60@(D-U8F$B"FUS9W-T<B`B0W5B82(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H
M87-E<R(*;7-G<W1R("(T(&9A<V5S(&%C='5A;',B"@HC.B!L:6(O0FQO8VLO
M=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E
M;G0@5&EM92(*;7-G<W1R(")496UP<R!A8W1U86PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@
M(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(D5L(%523"!A8W1U86P@Z7,B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED(")#=7)R96YT(%=E871H
M97(B"FUS9W-T<B`B5&5M<',@86-T=6%L(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(V,@IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*
M;7-G<W1R(")#;VYD:6-I\R!A8W1U86PZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL
M92(*;7-G<W1R(")%<W1I;"!A8W1U86PB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3`X"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K
M<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B(@HB4&5R<V]N
M86QI='IE=2!L97,@=&%S<75E<R!Q=64@<R=H86X@97AE8W5T87(@<75A;B!S
M)VEN:6-I82!L82!S97-S:?,@82`E<RXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*
M;7-G<W1R(")2971A;&QA<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T
M<B`B4F5T86QL87(@;&$@<V5L96-C:?,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8W"FUS9VED(")#>7!R=7,B"FUS9W-T
M<B`B6&EP<F4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B
M0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B0VER[6RW;&EC("A+3TDX+5(I
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-Y<FEL;&EC
M("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(D-I<NULMVQI8R`H5VEN9&]W<RTQ
M,C4Q*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED(")#>7)I
M;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B0VER[6RW;&EC+U5C
M<F'O;NAS("A+3TDX+54I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HV.`IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T
M<B`B4F5P^F)L:6-A(%1X96-A(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0R,R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I
M9"`B1$0B"FUS9W-T<B`B1$0B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N
M<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R(")$:>!R:6%M96YT(@H*(SH@
M861M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R
M(@IM<V=S='(@(DYA=F5G861O<B!D92!$871A5')E92(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,SDW(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C<R"FUS9VED(")$871E(@IM<V=S='(@(D1A=&$B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E
M:79E9"(*;7-G<W1R(")3)VAA(')E8G5T(&QA(&1A=&$B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C@P-0IM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T
M<B`B4V5L96-C:?,@9&4@9&%T82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,#8*;7-G:60@(D1A>2(*;7-G<W1R(")$:6$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*
M;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(E-U<')I;6ER(&-O;'5M
M;F$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@U
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,C(*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B
M1&5C96UB97(B"FUS9W-T<B`B1&5S96UB<F4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED(")$
M96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B3F]M8G)E<R!D96-I;6%L<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G
M:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R(")2961U[W4@96P@<V%G;F%T
M(@H*(SH@;&EB+W!R969S+G!H<#HQ,3$@;&EB+TAO<F1E+U!R969S+U5)+G!H
M<#HQ.#<*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B4')E9&5T97)M:6YA="(*
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0W
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q
M"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(D-O;&]R('!R961E=&5R
M;6EN870B"@HC.B!L:6(O2&]R9&4O261E;G1I='DN<&AP.CDQ"FUS9VED(")$
M969A=6QT($ED96YT:71Y(@IM<V=S='(@(DED96YT:71A="!P<F5D971E<FUI
M;F%D82(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$Q.2!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C$Y-@HC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!097)M
M:7-S:6]N<R(*;7-G<W1R(")3=7!R:6UI<B!P97)M[7,B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C$Y-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!P
M97)M:7-S:6]N<R(*;7-G<W1R(")3=7!R:6UI<B!P97)M[7,B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S
M='(@(D1E9FEN:6-I;VYS(@H*(SH@;&%N9W1E<W0N<&AP.C(Q(&QA;F=T97-T
M+G!H<#HR,R!A9&UI;B]G<F]U<',N<&AP.C<R"B,Z(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-#8@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,B!L:6(O2&]R
M9&4O4&5R;7,N<&AP.C(Y-0HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,Q
M-2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,S,@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHS,2!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E
M;&5T92YI;F,Z,3,*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.0HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,@IM<V=I9"`B
M1&5L971E(@IM<V=S='(@(E-U<')I;6ER(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HQ.#D@861M:6XO9W)O=7!S+G!H<#HR,3<*;7-G:60@(D1E;&5T92!'<F]U
M<"(*;7-G<W1R(")3=7!R:6UI<B!G<G5P(@H*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HV,R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C@W"FUS9VED(")$
M96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R(")3=7!R:6UI<B!P97)M[7,B"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E
M;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B4W5P<FEM:7(@:2!B
M=6ED87(@;6ES<V%T9V5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB"FUS
M9W-T<B`B4W5P<FEM:7(@8V5LMVQA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O
M;'5M;B(*;7-G<W1R(")3=7!R:6UI<B!C;VQU;6YA(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA
M=&4@=&5M<&QA=&4B"FUS9W-T<B`B4W5P<FEM:7(@;&$@<&QA;G1I;&QA(&%L
M=&5R;F%T:79A(&5X:7-T96YT(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H
M<#HU,"!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,Q-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B`G)7,G(@IM
M<V=S='(@(E-U<')I;6ER('!E<FUI<V]S('!E<B!A("<E<R<B"@HC.B!L:6(O
M2&]R9&4O4&5R;7,O54DN<&AP.C,Q-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B`G)7,G(&%N9"!A;GD@<W5B
M+7!E<FUI<W-I;VYS/R(*;7-G<W1R(")3=7!R:6UI<B!P97)M:7-O<R!P97(@
M82`G)7,G(&D@=&]T<R!E;',@<W5B<&5R;6ES;W,_(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B
M1&5L971E(')O=R(*;7-G<W1R(")3=7!R:6UI<B!F:6QA(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B1&5L971E
M('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(E-U<')I;6ER(&QA(&ED96YT
M:71A="!S96QE8V-I;VYA9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(D1E;&5T92!T:&4@
M8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B4W5P<FEM:7(@;&$@8V]L=6UN82!A
M8W1U86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C(*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B
M"FUS9W-T<B`B4W5P<FEM:7(@;&$@9FEL82!A8W1U86PB"@HC.B!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")$96QE=&4@=&AI
M<R!P97)M:7-S:6]N(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R
M(")3=7!R:6UI<B!P97)M:7-O<R!P97(@82`G)7,G(&D@=&]T<R!E;',@<W5B
M<&5R;6ES;W,_(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S4*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@)R5S)RXB"FUS9W-T<B`B4R=H82!S=7!R:6UI="!L82!S97'\
MZ&YC:6$@9"=A8W1U86QI='IA8VGS(&EN<W1A;+=L861A("<E<R<N(@H*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C`@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3(*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V,B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3DT"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(DAO<F$@
M9&4@;&QI=7)A;65N="(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-S$*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B1&EN86UA
M<F-A(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3$P('-E<G9I8V5S+W!R
M;V)L96TN<&AP.C$Q-"!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C0*;7-G:60@
M(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(D1E<V-R:79I=2!E;"!P
M<F]B;&5M82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY,S@@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B
M1&5S8W)I<'1I;VXB"FUS9W-T<B`B1&5S8W)I<&-I\R(*"B,Z(&QI8B](;W)D
M92YP:'`Z,3DU"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G
M9FEL92DZ(@IM<V=S='(@(D1E=&%L;',@*'1A;6+I(&%L(&9I='AE<B!D92!R
M96=I<W1R92!D92!(;W)D92DZ(@H*(SH@;&EB+TAO<F1E+G!H<#HQ.3D*;7-G
M:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(D5L<R!D971A;&QS(&AA;B!E<W1A="!R96=I<W1R
M871S('!E<B!A(&PG861M:6YI<W1R861O<BXB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3DV"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R(")$
M97-E;G9O;'5P86UE;G0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-0IM
M<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(E!U;G0@9&4@<F]S861A(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3(*;7-G:60@(D1E=R!0;VEN="!F;W(@
M;&%S="!H;W5R.B`B"FUS9W-T<B`B4'5N="!D92!R;W-A9&$@9&4@;&$@9&%R
M<F5R82!H;W)A.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,3D*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(E!U;G0@9&4@<F]S861A
M.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R(")$
M)V5S<75E<G)A(&$@9')E=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@
M;&5F="(*;7-G<W1R(")$92!D<F5T82!A(&5S<75E<G)A(@H*(SH@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R(")$
M:7)E8W1O<FDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4V"FUS9VED
M(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(E9O;',@=FES=6%L
M:71Z87(M:&\@96X@9F]R;6%T(&1E(#(T(&AO<F5S/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S
M='(@(D]P8VEO;G,@9&4@=FES=6%L:71Z86-I\R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z.#,*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS
M9W-T<B`B36]S=')A(&QA('!R979I<VGS("A4048I(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(X,34*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@
M(D9O<FUA="!D92!V:7-U86QI='IA8VGS(@H*(SH@;&EB+TAO<F1E+TU)344O
M341.+G!H<#HQ.3`*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*
M;7-G<W1R(").;W1I9FEC86-I\R!D92!R96-E<&-I\R(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HV.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S`*;7-G:60@(D1J:6)O
M=71I(@IM<V=S='(@(D1J:6)O=71I(@H*(SH@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HT-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,Q-0IM<V=I9"`B1&\@
M;F]T(&1E;&5T92(*;7-G<W1R(").;R!H;R!S=7!R:6UI=2(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HR-`IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY
M(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B3F\@86-C961I=2!D
M:7)E8W1A;65N="!A(&UA:6YT96YA;F-E+G!H<"(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C$Y('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C$Y"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE
M;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(B(*
M(DQA('!R:6UE<F$@9FEL82!C;VYTZ2!E;',@;F]M<R!D96QS(&-A;7!S/R!%
M;B!C87,@869I<FUA=&EU+"!A8W1I=F$@87%U97-T82`B"B)C87-E;&QA.B(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HW,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S(*
M;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(D1O;6EN:6-A(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C<Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,PIM<V=I9"`B1&]M
M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(E)E</IB;&EC82!$;VUI;FEC86YA
M(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@S-PIM<V=I9"`B
M1&]W;FQO860B"FUS9W-T<B`B1&5S8V%R<F5G87(B"@HC.B!L:6(O2&]R9&4O
M34E-12]#;VYT96YT<RYP:'`Z.#,W"B,L('!H<"UF;W)M870*;7-G:60@(D1O
M=VYL;V%D("5S(@IM<V=S='(@(D1E<V-A<G)E9V%R("5S(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$V-0IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B1&5S8V%R
M<F5G87(@;&$@8V]N9FEG=7)A8VGS(&=E;F5R861A(&-O;2!U;F$@<V5Q_.AN
M8VEA(%!(4"XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$P-PIM<V=I9"`B
M1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B3&QI<W1A(&1E<W!L96=A8FQE(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G
M<W1R(")$<F]G=65S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`R
M"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B0V]R<F5U(&5L96-T<O)N:6,B"@HC
M.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z
M,S0*;7-G:60@(D524B(*;7-G<W1R(")%4E(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<U"FUS9VED(")%8W5A9&]R(@IM
M<V=S='(@(D5Q=6%D;W(B"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(Y-"!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHS-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,34*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,S@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]E9&ET+FEN8SHR,@IM<V=I9"`B161I="(*;7-G<W1R(")%
M9&ET82(*"B,Z(&QI8B](;W)D92]";&]C:R]522YP:'`Z-3`@=&5M<&QA=&5S
M+W!O<G1A;"]E9&ET+FEN8SHR,@IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R
M(")%9&ET82!B;&]C(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.#@@861M:6XO
M9W)O=7!S+G!H<#HR,38*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B161I
M=&$@9W)U<"(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-C(@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HX-@IM<V=I9"`B161I="!097)M:7-S:6]N(@IM
M<V=S='(@(D5D:71A('!E<FWM<R(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B161I
M=&$@<&5R;6ES;W,B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S
M(@IM<V=S='(@(D5D:71A('!E<FUI<V]S(&1E("5S(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS
M9W-T<B`B161I=&$@;W!C:6]N<R!D93HB"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES
M<VEO;G,@9F]R("5S(@IM<V=S='(@(D5D:71A('!E<FUI<V]S(&1E("5S(@H*
M(SH@861M:6XO<&5R;7,O961I="YP:'`Z,C`T(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,C@P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E
M<FUI<W-I;VYS(&9O<B`G)7,G(@IM<V=S='(@(D5D:71A('!E<FUI<V]S(&1E
M("5S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C
M871I;VXB"FUS9W-T<B`B161U8V%C:?,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<W"FUS9VED(")%9WEP="(*;7-G<W1R
M(")%9VEP=&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,3<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(D5L(%-A
M;'9A9&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0R"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(D5L
M96UE;G0N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B475A9')A=.TB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3@V.2!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(R-`IM<V=I9"`B16UA:6PB"FUS9W-T<B`B0V]R<F5U(&5L
M96-T<O)N:6,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V-2!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0P"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3(*;7-G:60@(D5M86EL($%D9')E
M<W,B"FUS9W-T<B`B061R9>=A(&5L96-T<O)N:6-A(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Y-C,*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA
M=&-H+B(*;7-G<W1R("),97,@861R96-E<R!E;&5C='+R;FEQ=65S(&AA;B!D
M92!C;VEN8VED:7(N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y.#D*;7-G
M:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D-O<G)E=2!E
M;&5C='+R;FEC(&%M8B!C;VYF:7)M86-I\R(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR.#`*;7-G:60@(D5M;W1I8V]N<R(*;7-G
M<W1R(")%;6]T:6-O;F5S(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#$*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(DUI
M<W-A=&=E(&5N(&)L86YC+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP
M.C$R.`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R(")297-U;'1A="!E
M;B!B;&%N8RXB"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ,3,*
M;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R(")"=6ED87(@96QS
M('1E<FUE<R!D92!C97)C82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,S(*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO
M=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(DAA8FEL:71A<B!L82!I
M;G-E<F-I\R!D92!I;6%T9V5S(&1E(&QE<R!G86QE<FEE<R!D92!F;W1O<R!E
M;B!E;"!T97AT/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#<*;7-G
M:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@
M(DAA8FEL:71A<B!E;"!M96[Z(&1E(&-O;G1E>'0@8VQI8V%N="!E;B!E;"!B
M;W3S(&1R970_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.38@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(X,#D*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(D%N
M>2!D92!F:6YA;&ET>F%C:?,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G
M<W1R(")!;7!L:6%R(&PG961I=&]R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(Q,0IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W
M:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y
M;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO
M=7(@<&5T/R<Z(@IM<V=S='(@(B(*(DEN=')O9'7O=2!U;F$@<')E9W5N=&$@
M9&4@<V5G=7)E=&%T('%U92!S92!U<R!F;W)M=6QA<N`@<VD@=7,@8V%L(')E
M:6YI8VEA<B`B"B)L82!C;VYT<F%S96YY82P@<&5R(&5X96UP;&4@)V-O;2!E
M<R!D:74@96P@=F]S=')E(&%N:6UA;"!D92!C;VUP86YY:6$_)SHB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R
M("));G1R;V1U[W4@87%U[2!E;"!54DP@9&4@;&$@:6UA=&=E(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C$Q-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B16YT
M<FEE<SH@)60@=&]T86PL("5D('5P+71O+61A=&4L("5D(&YE=RP@)60@8VAA
M;F=E9"P@)60@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDY"FUS9VED(")%<75A=&]R:6%L
M($=U:6YE82(*;7-G<W1R(")'=6EN96$@17%U871O<FEA;"(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HW-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-SD*;7-G:60@(D5R
M:71R96$B"FUS9W-T<B`B17)I=')E82(*"B,Z(&QI8B](;W)D92].;W1I9FEC
M871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C4U"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S8*;7-G:60@(D5R<F]R(@IM
M<V=S='(@(D5R<F]R(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#0*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS
M9W-T<B`B2&D@:&$@:&%G=70@=6X@97)R;W(@86UB(&5L(&UI<W-A=&=E(&5L
M96-T<O)N:6,N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z,30R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!W<FET:6YG("<E<R<N(@IM<V=S='(@(DAI(&AA(&AA9W5T('5N
M(&5R<F]R(&5N(&5S8W)I=7)E("<E<R<N(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C0Q,R!P;R]T<F%N<VQA=&EO;BYP:'`Z-3(R('!O+W1R86YS;&%T:6]N
M+G!H<#HQ,S<W"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ-#,X('!O+W1R86YS
M;&%T:6]N+G!H<#HQ-3`Q"B,L(&9U>GIY"FUS9VED(")%<G)O<CH@(@IM<V=S
M='(@(D5R<F]R(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HW-@IM<V=I9"`B17-T;VYI82(*;7-G<W1R(")%<W3R;FEA(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C<X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,0IM
M<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B171I\G!I82(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(LAT;FEC
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P
M92(*;7-G<W1R(")%=7)O<&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S(Y"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(D-A9&$@,34@
M;6EN=71S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.0IM<V=I9"`B
M179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(D-A9&$@,B!M:6YU=',B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(V(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-S<*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B0V%D82`S
M,"!S96=O;G,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(X(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.#`*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*
M;7-G<W1R(")#861A(#4@;6EN=71S(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA
M;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B0V%D82!I
M;FEC:2!D92!S97-S:?,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,P
M"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B0V%D82!M:71J82!H
M;W)A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R-R!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S<X"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B
M0V%D82!M:6YU="(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(X
M"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B5F%L;W)S(&0G97AE
M;7!L93HB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z.#$@861M:6XO8VUD<VAE
M;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@(D5X96-U
M=&4B"FUS9W-T<B`B17AE8W5T82(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HR
M.3D@<&\O=')A;G-L871I;VXN<&AP.C,R,"!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,S8R"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT-#$@<&\O=')A;G-L871I;VXN
M<&AP.C4T,2!P;R]T<F%N<VQA=&EO;BYP:'`Z-C`Q"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HW,#(@<&\O=')A;G-L871I;VXN<&AP.C<S-R!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-SDX"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX-S4@<&\O=')A
M;G-L871I;VXN<&AP.CDY-"!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`Q-@HC+"!F
M=7IZ>0IM<V=I9"`B17AE8W5T:6YG.B(*;7-G<W1R(")%>&5C=71A<B(*"B,Z
M(&QA;F=T97-T,BYP:'`Z,3<*(RP@9G5Z>GD*;7-G:60@(D5X:70B"FUS9W-T
M<B`B161I=&$B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HS.30*
M;7-G:60@(D5X<&%N9"(*;7-G<W1R(")%>'!A;F1E:7@B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+W-I9&5B87(N:6YC.C,Q"FUS9VED(")%>'!A;F0@4VED96)A
M<B(*;7-G<W1R(")%>'!A;F1I<B!L82!B87)R82!L871E<F%L(@H*(SH@;&EB
M+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G
M*2<B"FUS9W-T<B`B4R=E<W!E<F%V82`G*2<B"@HC.B!L:6(O2&]R9&4O4U%,
M+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O
M<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B4R=E<W!E<F%V82!U;B!S
M;VP@;6]T(&\@=6X@=&5R;64@9&4@8V5R8V$@8VET870B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HT,#$*;7-G:60@(D5X<&ER871I;VX@1&%T92(*
M;7-G<W1R(")$871A(&1E('9E;F-I;65N="(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-C<V"FUS9VED(")%>'!O;F5N="(*;7-G<W1R(")%>'!O
M;F5N="(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HR-S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B17AT<F%C=&EN9R!F<F]M("5S+BXN("(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R(")#;VQO<B!D92!P<FEM97(@
M<&QA(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`IM<V=I9"`B1E10
M('5P;&]A9"!O9B!S971U<"(*;7-G<W1R(")#X')R96=A(&1E(&QA(&-O;F9I
M9W5R86-I\R!D96P@1E10(@H*(SH@;&EB+TAO<F1E+U!R969S+W-Q;"YP:'`Z
M,C$V"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS
M9W-T<B`BR7,@:6UP;W-S:6)L92!R96-U<&5R87(@;&5S('!R969E<NAN8VEE
M<RXB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ,#`*;7-G:60@(D9A
M:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("+)<R!I
M;7!O<W-I8FQE(&-O;FYE8W1A<B!A;6(@96P@<V5R=FED;W(@3$1!4"XB"@HC
M.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP.CDX"FUS9VED(")&86EL960@=&\@
M8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R("+)<R!I;7!O<W-I8FQE
M(&-O;FYE8W1A<B!A;6(@96P@<V5R=FED;W(@4TU"+B(*"B,Z(&QI8B]61E,O
M9G1P+G!H<#HV,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O
M<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(LES(&EM<&]S<VEB;&4@8V]P:6%R
M(&1E(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-C`X"B,L('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T
M<B`BR7,@:6UP;W-S:6)L92!C;W!I87(@82!<(B5S7"(N(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O<V%S;"YP:'`Z.#<*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@
M;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`BR7,@:6UP;W-S:6)L92!C
M<F5A<B!U;F$@;F]V82!C;VYN97AI\R!305-,+B(*"B,Z(&QI8B]61E,O9G1P
M+G!H<#HV-#$@;&EB+U9&4R]S;6(N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(LES(&EM
M<&]S<VEB;&4@=')A;G-F97)I<B!A(%PB)7-<(BXB"@HC.B!L:6(O5D93+W-M
M8BYP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R
M:65V93H@)7,B"FUS9W-T<B`BR7,@:6UP;W-S:6)L92!R96-U<&5R87(Z("5S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*
M;7-G:60@(D9A:7(B"FUS9W-T<B`B0VQA<B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW.0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#0*;7-G:60@(D9A;&ML86YD($ES
M;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R("));&QE<R!&86QK;&%N9"`H36%L
M=FEN97,I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HX-@IM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("));&QE<R!&
MZ')O92(*"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(S.`IM<V=I9"`B1F%T86P@
M17)R;W(Z(@IM<V=S='(@(D5R<F]R(&ER<F5C=7!E<F%B;&4@(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*
M;7-G<W1R(")&87@B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S<U(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,3(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B1F5B<F5R(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,3@*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B
M4V4@<V5N="!C;VTB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C(S"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B4V4@<V5N="!C;VTZ
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*
M;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(E!O<75E<R!P;'5G97,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I
M9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")0;V-S('C@9F5C<R!D92!N
M974B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DT-`IM<V=I9"`B1FEE;&0@
M;6%T<FEX(@IM<V=S='(@(DUA=')I=2!D96P@8V%M<"(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HX,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#,*;7-G:60@(D9I:FDB
M"FUS9W-T<B`B1FEJ:2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N
M<&AP.C8T(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8P"B,L('!H<"UF;W)M870*
M;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B4F5C;VUP=&4@
M9"=A<GAI=7,Z(&%R>&EU("5S(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C0@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B4F5C
M;VUP=&4@9"=A<GAI=7,Z("5S(&%R>&EU<R(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS-#0*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R(")'
M97-T;W(@9"=A<GAI=7,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP
M+G!H<#HV-R!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-0HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV,PIM<V=I9"`B1FEL92!.
M86UE(@IM<V=S='(@(DYO;2!D92!L)V%R>&EU(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(Y.3,*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(E-E
M;&5C8VGS(&0G87)X:75S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T.3$*
M;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(D/@<G)E9V$@9&4@;"=A<GAI
M=2(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX-3,*;7-G:60@(D9I;&4@
M=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R(").;R#I<R!P97)MZ',@
M<&5N:F%R(&%R>&EU<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX
M-PIM<V=I9"`B1FEL=&5R<R(*;7-G<W1R(")&:6QT<F5S(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C@R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,@IM<V=I9"`B1FEN
M;&%N9"(*;7-G<W1R(")&:6YLX&YD:6$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,3<Q"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(E!R:6UE<F$@;65I
M=&%T(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N
M+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R(")0<FEM97(@
M<75A<G0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C,Y"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B4F'S(&9I>&$C(R(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,30*;7-G:60@
M(D9L:7`B"FUS9W-T<B`B26YV97)T:74B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*
M;7-G<W1R(")#;VUA(&9L;W1A;G0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F]G(@IM<V=S='(@(D)O:7)A
M(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C$V,"!L:6(O5D93+VUU<W%L+G!H<#HQ
M,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X
M:7-T(@IM<V=S='(@(DQA(&-A<G!E=&$@)7,@;F\@97AI<W1E:7@B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS9VED
M(")&;VYT($-O;&]R(@IM<V=S='(@(D-O;&]R(&1E(&QA(&9O;G0B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B
M365N:F%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D
M;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R(")097(@86QS(&YA=F5G861O
M<G,@<75E(&YO(&%D;65T96X@;&5S(&EM871G97,B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,S,@IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B
M4')E=FES:?,@*%1!1BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-S@*;7-G:60@(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@
M<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[
M(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED
M92!B;&]C:RDB"FUS9W-T<B`B(@HB4')E=FES:?,@<&5R(&%L<R!D:65S("AT
M:6YG=65U('!R97-E;G0@<75E(&QA('!R979I<VGS(&9A8VEL:71A9&$@8V]M
M<'+H;B!E;"`B"B)D:6$@:2!L82!N:70Z('5N(&YO;6)R92!E;&5V870@<&]D
M<FEA('1E;FER(&-O;2!A(')E<W5L=&%T('5N(&)L;V,@86UP;&4N(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1F]R9V]T('EO
M=7(@<&%S<W=O<F0_(@IM<V=S='(@(DAE=2!O8FQI9&%T(&QA(&-O;G1R87-E
M;GEA/R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#`*;7-G:60@
M(D9O<FUS(@IM<V=S='(@(D9O<FUU;&%R:7,B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B1&ET82(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E
M(@IM<V=S='(@(E1I<'5S(&1E(&1I=&5S(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R(")$:71E<R(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*
M;7-G<W1R(")$:71E<R`R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,Y,0IM<V=I9"`B1F]R=6US(@IM<V=S='(@(D;R<G5M<R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#<*;7-G:60@(D9O<G=A<F1S(@IM<V=S
M='(@(E)E96YV:6%M96YT<R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ-#4X
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&;W5N9"!A<'!L:6-A=&EO
M;G,Z("5S(@IM<V=S='(@(D%P;&EC86-I\R!N;R!VX&QI9&$N(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C$T-3(*(RP@9G5Z>GD*;7-G:60@(D9O=6YD(&1I
M<F5C=&]R:65S.B(*;7-G<W1R(").;R#I<R!U;B!D:7)E8W1O<FDB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED
M(")&<B(*;7-G<W1R(")$=BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,S"FUS9VED(")&<F%M97,B"FUS9W-T
M<B`B36%R8W,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C@W"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B1G)A;N=A(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T
M<F]P;VQI=&%N(@IM<V=S='(@(D9R86[G82!M971R;W!O;&ET86YA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C@T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,0IM<V=I
M9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R(")'=6%I86YA($9R86YC97-A(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C@U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#0*
M;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B4&]L:6[H<VEA($9R
M86YC97-A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C(R"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B
M"FUS9W-T<B`B5&5R<FET;W)I<R!&<F%N8V5S;W,@9&5L(%-U9"(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M
M(@IM<V=S='(@(D1E<R!D92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-#`*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R(")$97,@9&5L(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*;7-G:60@(D9U
M;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B1&5S8W)I<&-I\R!C;VUP;&5T82(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,3@Q"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B3&QU;F$@<&QE;F$B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,Y"FUS9VED(")&
M=6QL($YA;64B"FUS9W-T<B`B3F]M(&-O;7!L970B"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-C4W"FUS9VED(")&=7IZ>2(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@X"FUS9VED(")'
M86)O;B(*;7-G<W1R(")'86)O;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R
M>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B3&$@9V%L97)I82!D92!L
M82!Q=6%L(',G97AT<F5U(&QA(&EM871G92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B
M1V%L;&5R>3HB"FUS9W-T<B`B1V%L97)I82(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX.`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.38*;7-G:60@(D=A;6)I82(*;7-G
M<W1R(")'X&UB:6$B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L
M('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB
M"FUS9W-T<B`B17,@9V5N97)A(&QA(&-O;F9I9W5R86-I\R`E<R(*"B,Z('1E
M;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HQ,`IM<V=I9"`B1V5N
M97)A=&5D($-O9&4B"FUS9W-T<B`B0V]D:2!G96YE<F%T(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C0W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T
M:6YG('-T871U<R!F;W(@;6]D=6QE("5S+BXN(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<T(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HX.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3`*;7-G:60@
M(D=E;W)G:6$B"FUS9W-T<B`B1V7R<F=I82(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS
M9W-T<B`B06QE;6%N>6$B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,W,0HC
M+"!F=7IZ>0IM<V=I9"`B1V5T;W!T($5R<F]R.B`B"FUS9W-T<B`B17)R;W(@
M:7)R96-U<&5R86)L92`B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.CDS"FUS9VED(")':&%N82(*;7-G<W1R(")':&%N82(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HY,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.30*
M;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R(")':6)R86QT87(B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B1VEV96X@3F%M92(*
M;7-G<W1R(").;VT@9&4@<&EL82(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N
M:6YC.C$R"FUS9VED(")';R(*;7-G<W1R(")!;F%R(&$B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R(")']F1E
M;"(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L
M92!396%R8V@B"FUS9W-T<B`B0V5R8V$@86P@1V]O9VQE(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,`IM<V=I9"`B1W)A>7-C
M86QE(@IM<V=S='(@(D5S8V%L82!D92!G<FES;W,B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,`IM<V=I9"`B1W)E96-E
M(@IM<V=S='(@(D=RZ&-I82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U
M"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B1W)E8R`H25-/
M+3@X-3DM-RDB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.CDU"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B1W)E;FS@;F1I
M82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.#D*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B1W)A;F%D82(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,3<P"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*
M;7-G<W1R(")'97-T:?,@9&4@9W)U<',B"@HC.B!L:6(O2&]R9&4O1W)O=7`N
M<&AP.C4X"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*
M;7-G<W1R(")%;',@;F]M<R!D92!G<G5P(&YO(&5S('!O9&5N(&1E:7AA<B!E
M;B!B;&%N8R(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(P,2!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C(W-PHC+"!F=7IZ>0IM<V=I9"`B1W)O=7`@<&5R
M;6ES<VEO;G,B"FUS9W-T<B`B4&5R;6ES;W,@9&5L<R!V:7-I=&%N=',B"@HC
M.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ-S8@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HR-3`@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R(")'
M<G5P<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.3@*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B1W5A9&%L=7!E(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.CDW"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#,*
M;7-G:60@(D=U86TB"FUS9W-T<B`B1W5A;2(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY.`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`R"FUS9VED(")'=6%T96UA;&$B
M"FUS9W-T<B`B1W5A=&5M86QA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.CDR"FUS9VED(")'=65R;G-E>2(*;7-G<W1R(")'=65R;G-E>2(*"B,Z(&%D
M;6EN+W!E<FUS+V5D:70N<&AP.C$R-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C(P-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'
M=65S="!097)M:7-S:6]N<R(*;7-G<W1R(")097)M:7-O<R!D96QS('9I<VET
M86YT<R(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$R."!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C(P-@HC+"!F=7IZ>0IM<V=I9"`B1W5E<W0@<&5R;6ES
M<VEO;G,B"FUS9W-T<B`B4&5R;6ES;W,@9&5L<R!V:7-I=&%N=',B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`X"FUS9VED(")'=65S=&)O;VLB
M"FUS9W-T<B`B3&QI8G)E(&1E('9I<VET86YT<R(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY
M.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3<*;7-G:60@(D=U:6YE82(*
M;7-G<W1R(")'=6EN96$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,#0*;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T
M<B`B1W5I;F5A($)I<W-A=2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$P-0IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(D=U
M>6%N82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY-C`*;7-G:60@(DA434PB
M"FUS9W-T<B`B2%1-3"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY
M(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G
M<W1R(")(5$U,07)E82!N;R!P97)M970@<W5P<FEM:7(@;&$@9&%R<F5R82!C
M96RW;&$@9&4@;&$@9FEL82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A
M<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B
M;&4N(@IM<V=S='(@(DA434Q!<F5A(&YO('!E<FUE="!S=7!R:6UI<B!L82!D
M87)R97)A(&-O;'5M;F$@9&4@;&$@=&%U;&$N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W
M(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,07)E82!N;R!P97)M970@<W5P<FEM
M:7(@;&$@9&%R<F5R82!F:6QA(&1E(&QA('1A=6QA+B(*"B,Z(&QI8B](;W)D
M92]!=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H96YT:6-A=&EO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(DYO(',G:&$@=')O8F%T(&PG875T96YT
M:6-A8VGS($A45%`N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3$P"FUS9VED(")(86ET:2(*;7-G<W1R(")(86ET[2(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0P,@IM<V=I9"`B2&%S:"U!
M;&=O<FET:&TB"FUS9W-T<B`B06QG;W)I<VUE(&1E(&AA<V@B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B2&%Z
M92(*;7-G<W1R(")#86QI=&IA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDQ
M.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDS,`IM<V=I9"`B2&5A9&5R(@IM<V=S
M='(@(D-A<.=A;&5R82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$P-PIM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O
M;F%L9"!)<VQA;F1S(@IM<V=S='(@(DEL;&$@2&5A<F0@:2!I;&QE<R!-8T1O
M;F%L9"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED(")(96)R
M97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B2&5B<F5U("A)4T\M.#@U.2TX
M+4DI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(D%LYV%D82(*"B,Z
M(&QI8B](;W)D92](96QP+G!H<#HQ-S@@;&EB+TAO<F1E+TAE;'`N<&AP.C$X
M-2!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-PHC.B!T96UP;&%T97,O:&5L
M<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*;7-G<W1R(")!:G5D82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G
M:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(D%J=61A('!E<B!U=&EL
M:71Z87(@;"=E9&ET;W(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W-@IM
M<V=I9"`B2&5L<&5R(@IM<V=S='(@(D%P;&EC86-I\R!D)V%J=61A(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.CDU"FUS9VED("(B"B)(96QP97(@87!P;&EC
M871I;VX@=&\@8W)E871E(&%N9"!M86EN=&%I;B!T<F%N<VQA=&EO;G,@9F]R
M('1H92!(;W)D95QN(@HB9G)A;65W;W)K(&%N9"!I=',@87!P;&EC871I;VYS
M+EQN(@HB1F]R(&%N(&EN=')O9'5C=&EO;B!R96%D('1H92!F:6QE(%)%041-
M12!I;B!T:&ES(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@(DAE;6ES
M9F5R:2(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W('1E;7!L
M871E<R]D871A+W1S=FEN9F\N:6YC.C$W"FUS9VED(")(97)E(&ES('1H92!B
M96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(D%Q=65S="#I<R!L)VEN
M:6-I(&1E;"!F:71X97(Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C4*;7-G:60@(DAI9V@B"FUS9W-T<B`B06QT(@H*(SH@
M;&EB+TAO<F1E+TAI<W1O<GDN<&AP.C,R,0HC+"!F=7IZ>0IM<V=I9"`B2&ES
M=&]R>2!E;G1R>2!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R(")%
M;',@;F]M<R!D92!G<G5P(&YO(&5S('!O9&5N(&1E:7AA<B!E;B!B;&%N8R(*
M"B,Z('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHT('1E;7!L
M871E<R]P;W)T86PO;65N=2YI;F,Z-@IM<V=I9"`B2&]?;64B"FUS9W-T<B`B
M26YI8VDB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,30@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0S"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E
M*2(*;7-G<W1R(")L82!386YT82!3974@*$-I=71A="!%<W1A="!D96P@5F%T
M:6/@*2(*"B,Z(&QI8B](;W)D92YP:'`Z,30R-@IM<V=I9"`B2&]M92(*;7-G
M<W1R("));FEC:2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3(R(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS
M9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`B061R9>=A('!A<G1I8W5L87(B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I
M9"`B2&]M92!0:&]N92(*;7-G<W1R(")496SH9F]N('!A<G1I8W5L87(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#@*
M;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(DAO;F1U<F5S(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$P-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`V"FUS9VED(")(
M;VYG($MO;F<B"FUS9W-T<B`B2&]N9R!+;VYG(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C8S"FUS9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S(Y"FUS9VED(")(;W)D92!T<F%N
M<VQA=&EO;B!G96YE<F%T;W(B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HT,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E
M<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@4R=H86X@=')O8F%T(&1A9&5S(%A-
M3"`E<R!N;R!VX&QI9&5S(&5N(&5L(&UI<W-A=&=E("5S(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HR-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM
M<V=S='(@(B(*(DAO<F1E+TMO;&%B.B!.;R!H:2!H82!C87`@;6ES<V%T9V4@
M<75E(&5S(&-O<G)E<W!O;F=U:2!A;6(@;"=O8FIE8W1E("5S(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HT,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A
M9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($YO(',G:&$@=')O8F%T(&-A
M<"!O8FIE8W1E(&1E;"!T:7!U<R`E<R!E;B!E;"!M:7-S871G92`E<R(*"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(P.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B`E<R!<(B5S7"(@:&$@97-T870@97AT
M<F5T(&-O<G)E8W1A;65N="(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3$U
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U
M8V-E<W-F=6QL>2!S>6YC:')O;FES960@)7,@7"(E<UPB(@IM<V=S='(@(DAO
M<F1E+TMO;&%B.B`E<R!<(B5S7"(@:&$@97-T870@97AT<F5T(&-O<G)E8W1A
M;65N="(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D
M92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@
M)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R(")(;W)D92]+;VQA8CH@
M16P@;6]T;W(@9"=I;G1E9W)A8VGS(&YE8V5S<VET82!L)V5X=&5N<VGS(%!(
M4"`G9&]M>&UL)R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#@Q"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E
M(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B!.;R!S)VAA('!O9W5T(&-R96%R('5N(&YO=2!A<F)R92!834P@<&5R
M(&$@;"=O8FIE8W1E("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C`U
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($YO
M(',G:&$@<&]G=70@97AT<F5U<F4@)7,@7"(E<UPB.B`E<R(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z-#4R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A
M<G0@;V8@='EP92`E<R(*;7-G<W1R("(B"B)(;W)D92]+;VQA8CH@3F\@<R=H
M82!P;V=U="!R96-U<&5R87(@;"=I9&5N=&EF:6-A9&]R($U)344@<&5R(&$@
M;&$@<&%R="!D96P@(@HB=&EP=7,@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.C$Q-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO
M<F1E+TMO;&%B.B!.;R!S)VAA('!O9W5T('-I;F-R;VYI='IA<B`E<UPB)7-<
M(CH@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$R.#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES
M92!S:&%R97,Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.;R!S)VAA('!O
M9W5T('-I;F-R;VYI='IA<B!L97,@<75O=&5S.B`E<R(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA
M8CH@17-P86D@9&ES<&]N:6)L92!D97-C;VYE9W5T(%PB)7-<(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@
M(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R(")296=L82!H;W)I='IO;G1A;"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*
M;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R(")&87)C:6UE;G0@
M:&]R:71Z;VYT86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R(")(;W)I
M='IO;G1A;#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E
M/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@(D-O;2!H974@87)R:6)A="!F
M:6YS(&%Q=>T_("A&974M;F]S+6AO('-A8F5R(2DB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(
M;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G
M<W1R(")1=6%N=&5S(&-O;'5M;F5S('9O;&5U(')E9F]N9')E/R(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(X"FUS9VED(")(;W<@;6%N>2!F
M:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B475A;G1S(&-A
M;7!S("AC;VQU;6YE<RD@:&D@:&$_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@
M<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B475A;G1E
M<R!F:6QE<R!V;VQE=2!R969O;F1R93\B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(R.`IM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B2'5M:71A="(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#8*;7-G:60@(DAU;6ED
M:71Y.B`B"FUS9W-T<B`B2'5M:71A=#HB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R(")(=6UO<FES=&5S
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$P-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3$Q"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(DAO;F=R:6$B"@HC.B!L:6(O
M2&]R9&4O075T:"]C>7)U<RYP:'`Z,3<R(&QI8B](;W)D92]!=71H+V-Y<G-Q
M;"YP:'`Z,C,U"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C
M<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(LES(&EM<&]S<VEB;&4@8W)E
M87(@;&$@8OIS=&EA($E-05`Z("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER
M=7,N<&AP.C(Q-"!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D
M.B`E<R(*;7-G<W1R("+)<R!I;7!O<W-I8FQE('-U<')I;6ER(&QA(&+Z<W1I
M82!)34%0.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ-SD@
M;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B
M"FUS9W-T<B`BR7,@:6UP;W-S:6)L92!C<F5A<B!U;B!E<W!A:2!D:7-P;VYI
M8FQE('!E<B!A(&QA(&+Z<W1I82!)34%0.B`E<R(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,S(P"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(D%D<F7G
M82!)4"(*"B,Z(&QI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED
M("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DPG861R9>=A
M($E0(&YO(&5S=.`@9&ES<&]N:6)L92XB"@HC.B!L:6(O2&]R9&4O075T:"]I
M<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L
M;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B3"=A9')EYV$@25`@;F\@97,@
M=')O8F$@96X@96P@8FQO8R!#2412('!E<FWH<RXB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B25`@;&]C:V1O=VX@
M=FEO;&%T:6]N+B(*;7-G<W1R(")6:6]L86-I\R!D96P@8FQO<75E:6<@25`N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B
M26YS97)I=2!U;F$@9FEL82!D86UU;G0B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C`*;7-G:60@(DEC96QA;F0B"FUS
M9W-T<B`B27-LX&YD:6$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8V
M"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@(DYO;>ES(&EC;VYE<R(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B26-O;F5S(&1E("5S(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,V-PIM<V=I9"`B26-O;G,@=VET:"!T97AT
M(@IM<V=S='(@(DEC;VYE<R!A;6(@=&5X="(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ.#`*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B
M3F]M(&0G:61E;G1I=&%T.B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S
M+G!H<#HU.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I
M<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN
M9&]W+B(*;7-G<W1R(")3:2!N;R!E<R!V:7-U86QI='IA(&-O<G)E8W1A;65N
M="P@;V)R:74@)7,@96X@=6YA(&YO=F$@9FEN97-T<F$N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0T-0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E
M92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@
M;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A
M;G-P87)E;F-Y+B(*;7-G<W1R("(B"B)3:2!N;R!V:7-U86QI='IE=2!C87`@
M:6-O;F$@;6ET:F%NYV%N="!L)TEN=&5R;F5T($5X<&QO<F5R+"#I<R!P;W-S
M:6)L92!Q=64@(@HB:.!G:74@9"=A8W1I=F%R(&%Q=65S="!Q=6%D<F4@<&5R
M(&1E<V%C=&EV87(@;&$@=')A;G-P87+H;F-I82!D92!03D<N(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$U.`IM<V=I9"`B(@HB
M268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA
M9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B
M>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*(E-I('9E:65U(&%Q=65S="!M
M:7-S871G92!E;B!L;&]C(&1E(&QA(&EM871G92P@96P@=F]S=')E(&YA=F5G
M861O<B!N;R!P;W0@(@HB;6]S=')A<B!L82!I;6%T9V4@<75E('9O;&5U('!E
M;FIA<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S
M='(@(E9I<W5A;&ET>F%C:?,@<'+H=FEA(&1E(&QA(&EM871G93HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,W
M"FUS9VED("));6%G92!54DPB"FUS9W-T<B`B55),(&1E(&QA(&EM871G92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R(")54DP@9&4@
M;&$@:6UA=&=E.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL
M97)Y(@IM<V=S='(@(DEM871G92!D92!L82!G86QE<FEA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q
M"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(DEM871G92!D
M92!L82!G86QE<FEA.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8U"FUS
M9VED("));6%G92!U<&QO860B"FUS9W-T<B`B0^!R<F5G82!D92!L82!I;6%T
M9V4B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S
M(@IM<V=S='(@(DEM871G97,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"B,Z('1E;7!L
M871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V1A=&5M
M87`N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E
M9"(*;7-G<W1R("));7!O<G1A8VGS+"!P87,@)60B"@HC.B!T96UP;&%T97,O
M9&%T82]D871E;6%P+FEN8SHR,`HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O
M<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B0V%M<"!I;7!O<G1A=#H@)7,B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<S"FUS9VED("));7!O<G1E
M9"!F:65L9',Z(@IM<V=S='(@(D-A;7!S(&EM<&]R=&%T<SHB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*
M;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(DEN<V5R:74@=6YA
M(&9I;&$@82!S;W1A(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z
M,3,U"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S
M='(@(D5L(&-O9&D@9&4@;"=A8V-I\R!Q=64@<R=H82!F86-I;&ET870@Z7,@
M:6YC;W)R96-T92XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,Q"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W
M;W)D+B(*;7-G<W1R(").;VT@9"=U<W5A<FD@:2]O(&-O;G1R87-E;GEE<R!I
M;F-O<G)E8W1E<RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU
M,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A
M9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T
M<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)3
M)VAA(&9A8VEL:71A="!U;B!N;VT@9"=U<W5A<FD@;R!U;F$@861R9>=A(&%L
M=&5R;F%T:79A(&EN8V]R<F5C=&5S+B!4;W)N974M(@HB:&\@82!I;G1E;G1A
M<B!O('!O<V5U+79O<R!E;B!C;VYT86-T92!A;6(@;"=A9&UI;FES=')A9&]R
M('!E<B!A(&WI<R!A:G5D82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B"FUS
M9W-T<B`B075G;65N=&%R(&5L('-A9VYA="(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#D*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-@IM<V=I9"`B26YD:6$B"FUS
M9W-T<B`BS6YD:6$B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ-#$@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@
M57-E<G,B"FUS9W-T<B`B57-U87)I<R!I;F1I=FED=6%L<R(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,3`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,@IM<V=I9"`B
M26YD;VYE<VEA(@IM<V=S='(@(DEN9&]NZ'-I82(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@
M(DEN9F]R;6%C:?,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C0T
M"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA8VGS(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C4X,@HC+"!P:'`M9F]R;6%T"FUS9VED("))
M;FET:6%L:7II;F<@;6]D=6QE("5S+BXN("(*;7-G<W1R("));FEC:6%L:71Z
M86YT(&WR9'5L("5S+BXN("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T($-?;VQU
M;6X@069T97(B"FUS9W-T<B`B26YS97)E:7@@=6YA(&-O;'5M;F$@82!S;W1A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(P"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`B26YS
M97)E:7@@=6YA(&EM871G92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R
M("));G-E<F5I>"!U;F$@=&%U;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB
M"FUS9W-T<B`B26YS97)E:7@@96YL;&'G('=E8B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B
M26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(DEN<V5R96EX(&QA(&-O
M;'5M;F$@9&%M=6YT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L
M=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("));G-E<F5I>"!U
M;F$@;F]V82!C;VQU;6YA(&$@<V]T82!D92!L)V%C='5A;"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM
M<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@
M;VYE(@IM<V=S='(@(DEN<V5R96EX('5N82!N;W9A(&-O;'5M;F$@82!S;V)R
M92!D92!L)V%C='5A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O
M=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B26YS97)E:7@@=6YA
M(&YO=F$@9FEL82!A('-O=&$@9&4@;"=A8W1U86PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@
M(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G
M<W1R("));G-E<F5I>"!U;F$@;F]V82!F:6QA(&$@<V]B<F4@9&4@;"=A8W1U
M86P@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@
M=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("));G-E<F5I>"!U;B!P87+@9W)A
M9B!A('-O=&$@9&5L(&YO9&4@86-T=6%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED("));G-E
M<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T
M<B`B26YS97)E:7@@=6X@<&%RX&=R868@82!S;V)R92!D96P@;F]D92!A8W1U
M86PB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T
M(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("));G-E<F5I>"!L)V%L=')A
M('!L86YT:6QL82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,CD*;7-G
M:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@
M<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("(B"B));G-E<F5I
M>"!U;F$@861R9>=A(&1E(&-O<G)E=2!P97(@<F5B<F4@;&$@;F]V82!C;VYT
M<F%S96YY84EN<V5R:74@=6YA("(*(F%D<F7G82!E;&5C='+R;FEC82!A(&QA
M('%U86P@<&]D974@<F5B<F4@;&$@;F]V82!C;VYT<F%S96YY83HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X
M"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R("));G-E<F5I>"!U
M;F$@8V5LMVQA(&$@<V]T82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL(&)E
M9F]R92(*;7-G<W1R("));G-E<F5I>"!U;F$@8V5LMVQA(&$@<V]B<F4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(DEN<V5R
M:74@=6YA(&-O;'5M;F$@82!S;W1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O
M;'5M;B!B969O<F4B"FUS9W-T<B`B26YS97)I=2!U;F$@8V]L=6UN82!A('-O
M8G)E(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS
M9VED("));G-E<G0@;65S<V%G97,B"FUS9W-T<B`B26YS97)I=2!M:7-S871G
M97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS
M9W-T<B`B26YS97)I=2!U;B!P87+@9W)A9B!A('-O=&$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G
M:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(DEN<V5R:74@
M=6X@<&%RX&=R868@82!S;V)R92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@
M869T97(B"FUS9W-T<B`B26YS97)I=2!U;F$@9FEL82!A('-O=&$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X
M"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R("));G-E<FEU('5N
M82!F:6QA(&$@<V]B<F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(P
M"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C
M=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(DEN<V5R:74@;&$@<F5S<&]S=&$@
M82!L82!P<F5G=6YT82!D92!S96=U<F5T870Z(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS97)T+TUO
M9&EF>2!);6%G92(*;7-G<W1R("));G-E<FER+TUO9&EF:6-A<B!I;6%T9V4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y
M"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B26YS97)I<B]-
M;V1I9FEC87(@96YL;&'G(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,@IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD
M('1O('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B3F\@9&ES<&]S
M974@9&4@<')O=2!C<NAD:70@<&5R(&5N=FEA<BUL;R!A(&QA(&QL:7-T82!D
M92!D:7-T<FEB=6-I\RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,T"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R
M(")#<NAD:70@:6YS=69I8VEE;G0N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$P-S4*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B3F]M8G)E(&5N=&5R(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,S,*;7-G:60@(DEN=&5G97(@;&ES
M="(*;7-G<W1R("),;&ES=&$@9&4@;F]M8G)E<R!E;G1E<G,B"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI
M9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B541((&YO(';@
M;&ED82X@*$-A<.=A;&5R82!D92!D861E<R!D)W5S=6%R:2DN(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A
M=&EO;BXB"FUS9W-T<B`B07!L:6-A8VGS(&YO(';@;&ED82XB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI
M9"!B871C:"!)1"XB"FUS9W-T<B`B3"=I9&5N=&EF:6-A9&]R(&1E;"!L;W0@
M;F\@Z7,@=N!L:60B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`X-R!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C$U."!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(S,@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(Y-PIM<V=I9"`B26YV86QI9"!D871A
M('-U8FUI='1E9"XB"FUS9W-T<B`B3&5S(&1A9&5S('%U92!S)VAA;B!T<F%M
MZ',@;F\@<_-N(';@;&ED97,N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3D*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D
M<F5S<RXB"FUS9W-T<B`B3"=A9')EYV$@9&4@9&5S=&EN86-I\R!N;R#I<R!V
MX&QI9&$N(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z.#$@;&EB
M+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,3`P"B,Z(&QI8B](;W)D92]#;VUP
M<F5S<R]D8G@N<&AP.C(R,`IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*
M;7-G<W1R(")%;"!F;W)M870@9&4@;"=A<GAI=2!N;R#I<R!VX&QI9"XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Y"FUS9VED("));G9A
M;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R("),82!C;&%U(&1E(&QA(&QL:6/H
M;F-I82!N;R#I<R!VX&QI9&$N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$V,PIM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB
M"FUS9W-T<B`B3&$@=6)I8V%C:?,@<75E(&AE=2!P<F]P;W)C:6]N870@;F\@
MZ7,@=N!L:61A+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`V"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R(")%;"!T
M:7!U<RUM<V<@;F\@Z7,@=N!L:60N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A
M<&E?:60N(@IM<V=S='(@(DUA;F-A(&5L(&%P:5]I9"!O(&5L('%U92!S)VAA
M(&9A8VEL:71A="!N;R#I<R!VX&QI9"XB"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG
M('!A<F%M971E<G,N(@IM<V=S='(@(DUA;G%U96X@<&%RX&UE=')E<R!O(&5L
M<R!Q=64@<R=H86X@9F%C:6QI=&%T(&YO('/S;B!VX&QI9',N(@H*(SH@861M
M:6XO<&5R;7,O861D8VAI;&0N<&AP.C0S"FUS9VED("));G9A;&ED('!A<F5N
M="!P97)M:7-S:6]N+B(*;7-G<W1R("),)V%U=&]R:71Z86-I\R!P871E<FYA
M(&YO(.ES(';@;&ED82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,38U"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(D5L
M(&-O9&D@9"=I9&5N=&EF:6-A8VGS(&1E('-O8VD@;F\@Z7,@=N!L:60N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-PIM<V=I9"`B26YV
M86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(D5L(&-O9&D@9&5L('!R;V1U
M8W1E(&YO(.ES(';@;&ED+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`U"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R
M(")%;"!P<F]T;V-O;"!N;R#I<R!VX&QI9"XB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z.3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(DEN=F%L:60@<F5C:7!I96YT.B`G)7,G(@IM<V=S='(@(D5L(&1E<W1I
M;F%T87)I(&YO(.ES(';@;&ED.B`G)7,G(@H*(SH@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HQ,#0S(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(R,`IM<V=I9"`B26YV
M86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B3"=O8FIE8W1E(&-O;7!A<G1I
M="!N;R#I<R!VX&QI9"(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`P"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G
M<W1R("),)V%D<F7G82!D)V]R:6=E;B!N;R#I<R!VX&QI9&$N(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DEN=F%L
M:60@=6YI8V]D92!D871A+B(*;7-G<W1R("),97,@9&%D97,@56YI8V]D92!N
M;R!S\VX@=N!L:61E<RXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S(S"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B26YV96YT87)I(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Q,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$Y"FUS
M9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(DER86XL
M(%)E</IB;&EC82!)<VS@;6EC82!D)R(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q.`IM<V=I9"`B27)A<2(*;7-G<W1R
M("))<F%Q(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3$S"FUS9VED("))<F5L86YD(@IM<V=S='(@(DER;&%N9&$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA
M;B(*;7-G<W1R("));&QA(&1E($UA;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED("))<V]L871E9"!4+5-T;W)M
M<R(*;7-G<W1R(")496UP97-T97,@8>]L;&%D97,B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,30*;7-G:60@(DES<F%E
M;"(*;7-G<W1R("))<W)A96PB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C8R-0IM<V=I9"`B27-S=65R(@IM<V=S='(@(D5M:7-S;W(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@
M(DET86QI8R(*;7-G<W1R(")#=7)S:79A(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(Q"FUS9VED("))=&%L>2(*;7-G
M<W1R("))=.!L:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,C,*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B2F%M86EC
M82(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS-S0@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*
M86YU87)Y(@IM<V=S='(@(D=E;F5R(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(U"FUS9VED(")*87!A;B(*;7-G<W1R
M(")*87#S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(DIA
M<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B2F%P;V[H<R`H25-/+3(P
M,#(M2E`I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B
M2F5R<V5Y(@IM<V=S='(@(DIE<G-E>2(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-`IM<V=I9"`B2F]R9&%N(@IM<V=S
M='(@(DIO<F3@;FEA(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C,X,"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B2G5L:6]L(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W.2!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#$V"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B2G5N
M>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B2G5S=&EF:6-A<B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R(")*=7-T:69I
M8V%R(&%L(&-E;G1R92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS
M9W-T<B`B2G5S=&EF:6-A<B!A('1O=',@9&]S(&UA<F=E<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS
M9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`B2G5S=&EF:6-A<B!A(&PG97-Q
M=65R<F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R(")*
M=7-T:69I8V%R(&$@;&$@9')E=&$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,S8*;7-G:60@(DMA>F%K:'-T86XB"FUS
M9W-T<B`B2V%Z86MH<W1A;B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HR-#8*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@
M(E9O;&5U(&-O;G-E<G9A<B!L)V]R:6=I;F%L/R(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,C`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-@IM<V=I9"`B2V5N>6$B
M"FUS9W-T<B`B2V5N>6$B"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX
M-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R(")%;"!S97)V:61O<B!+97)B97)O<R!H82!R96)U=&IA
M="!L)V%U=&5N=&EC86-I\RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(DME<FYE;"!.97=B
M:65S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`P"FUS9VED(")+
M97D@0W)E871I;VXB"FUS9W-T<B`B0W)E86-I\R!D92!C;&%U<R(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C0P,PIM<V=I9"`B2V5Y($9I;F=E<G!R
M:6YT(@IM<V=S='(@(D5M<')E;71A(&1I9VET86P@9&4@;&$@8VQA=2(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0P,0IM<V=I9"`B2V5Y($QE;F=T
M:"(*;7-G<W1R("),;VYG:71U9"!D92!L82!C;&%U(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z-#`P"FUS9VED(")+97D@5'EP92(*;7-G<W1R(")4
M:7!U<R!D92!C;&%U(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M.3@*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R("+:<R!D92!L82!C;&%U(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S(Y"FUS9VED(")+97D@86QR
M96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@
M(DIA(&5X:7-T96EX('5N82!C;&%U(&5N(&5L('-E<G9I9&]R(&1E(&-L875S
M('#Z8FQI<75E<RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G
M:60@(DMI9',B"FUS9W-T<B`B3F]I<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R.0IM<V=I9"`B2VER:6)A=&DB"FUS
M9W-T<B`B2VER:6)A=&DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,S(*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E
M;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(D-O<F5A+"!297#Z8FQI8V$@
M1&5M;V-RX'1I8V$@4&]P=6QA<B!D92(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,PIM<V=I9"`B2V]R96$L(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(D-O<F5A+"!297#Z8FQI8V$@9&4B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM
M<V=S='(@(D-O<F7@("A%54,M2U(I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,T"FUS9VED(")+=7=A:70B"FUS9W-T
M<B`B2W5W86ET(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3(W"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(DMI<F=U
M:7II<W1A;B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I
M9"`B3&%?>6]U="(*;7-G<W1R(")&;W)M870B"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C<W('!O+W1R86YS;&%T:6]N+G!H<#HV-3<*;7-G:60@
M(DQA;F=U86=E(@IM<V=S='(@(DED:6]M82(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C8*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-PIM<V=I9"`B3&%O(%!E;W!L
M92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B4F5P^F)L:6-A($1E
M;6]C<N!T:6-A(%!O<'5L87(@9&4@3&%O<R(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-S0*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R(")$87)R97)A(&UE
M:71A="(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX."!L:6(O0FQO8VLO;6]O
M;BYP:'`Z.3`*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R(")$87)R97(@
M<75A<G0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$T.0IM<V=I9"`B3&%S
M="!5<&1A=&5D.B(*;7-G<W1R(")$87)R97)A(&%C='5A;&ET>F%C:?,Z(@H*
M(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C8V-@HC+"!P:'`M9F]R;6%T"FUS9VED
M("),87-T(&QO9VEN.B`E<R(*;7-G<W1R(")$87)R97)A(&-O;FYE>&GS.B`E
M<R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HV-C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R(")$87)R97)A
M(&-O;FYE>&GS.B`E<R!D92`E<R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HV
M-C,*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(D1A<G)E<F$@
M8V]N;F5X:?,Z(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,30V"FUS9VED("),871V:6$B"FUS9W-T<B`B3&5T\FYI82(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S
M='(@(DQL96DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*;7-G<W1R(")$:7-S96YY
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R(")$
M96EX87(M:&\@96X@8FQA;F,@<&5R(&5L:6UI;F%R(&5L(&-O;G1O<FXB"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S@*
M;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B3.UB86XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE
M9G0B"FUS9W-T<B`B17-Q=65R<F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S$Q-PIM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B0V%PYV%L97)A(&5S
M<75E<G)A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,3,*;7-G:60@(DQE
M9G0@=F%L=65S(@IM<V=S='(@(E9A;&]R<R!D92!L)V5S<75E<G)A(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$R.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30S"FUS
M9VED("),97-O=&AO(@IM<V=S='(@(DQE<V]T:&\B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#(*;7-G:60@(DQI8F5R
M:6$B"FUS9W-T<B`B3&EBZ')I82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$T-PIM<V=I9"`B3&EB>6%N($%R86(@2F%M
M86AI<FEY82(*;7-G<W1R("),[6)I82(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,`IM<V=I9"`B3&EE8VAT96YS=&5I
M;B(*;7-G<W1R("),:65C:'1E;G-T96EN(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DQI9VAT($1R:7IZ;&4B
M"FUS9W-T<B`B4&QU9VEM(&9E8FQE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C,*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T
M<B`B4&QU:F$@9F5B;&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR-`IM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R
M(")0;'5J82!F96)L92!A('!R:6UE<F$@:&]R82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!286EN
M($QA=&4B"FUS9W-T<B`B4&QU:F$@9F5B;&4@8V%P(&%L('1A<F0B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@IM<V=I9"`B
M3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B4G5I>&%T(&9E8FQE(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@
M(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(E)U:7AA="!F96)L
M92!A;6(@=')O;G,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R(").979A9&$@
M9F5B;&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR.0IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B6.!F96,@
M9&4@;F5U(&9E8FQE(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS
M9VED("),:6UE<FEC:R(*;7-G<W1R("),:6UE<FEC:R(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ.#$X"FUS9VED("),:6YK(@IM<V=S='(@(D5N;&QAYR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-@IM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(D5N;&QA
M8^=A<B!E;',@<'5N=',@86UB.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.#<U"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP
M;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(D5N;&QAYV%R(&PG
M861R9>=A(&5L96-T<O)N:6-A(&$@;&$@<.!G:6YA(&1E(')E9&%C=&%T('%U
M86X@97,@;6]S=')I(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAT;6PR
M=&5X="YP:'`Z,3@S"FUS9VED("),:6YK<R(*;7-G<W1R(")%;FQL8>=O<R(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O
M:VEE(@IM<V=S='(@(D=A;&5T82!,:6YU>"(*"B,Z(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E
M92!T:&4@9F]L9&5R(@IM<V=S='(@(DQL:7-T87(@+2!,)W5S=6%R:2!P;W0@
M=F5U<F4@;&$@8V%R<&5T82(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S`*
M;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(DQL:7-T87(@;&5S(&)A
M<V5S(&1E(&1A9&5S(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3`*
M;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B3&QI<W1A(&1E;',@
M=&5M97,@9"=A:G5D82(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,CD*;7-G
M:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(DQL:7-T87(@;&5S('1A=6QE<R(*
M"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES
M="U!<F-H:79E(@IM<V=S='(@(DQI<W0M07)C:&EV92(*"B,Z(&QI8B](;W)D
M92]-24U%+TAE861E<G,N<&AP.C4X.0IM<V=I9"`B3&ES="U(96QP(@IM<V=S
M='(@(DQI<W0M2&5L<"(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP
M.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("),:7-T+4ED(@H*(SH@;&EB
M+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R
M(@IM<V=S='(@(DQI<W0M3W=N97(B"@HC.B!L:6(O2&]R9&4O34E-12](96%D
M97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R("),:7-T+5!O
M<W0B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@
M(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(DQI<W0M4W5B<V-R:6)E(@H*(SH@
M;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),:7-T+55N
M<W5B<V-R:6)E(@IM<V=S='(@(DQI<W0M56YS=6)S8W)I8F4B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C0*;7-G:60@(DQI<W1I;F<@
M=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(DQA(&QL:7-T82!D)W5S=6%R
M:7,@97-TX"!I;FAA8FEL:71A9&$N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(D)I8FQI;V=R869I
M82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$T-`IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(DQI='7@;FEA(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$S,S@*(RP@9G5Z>GD*;7-G:60@(DQO861I
M;F<@;&EB<F%R:65S+BXN(@IM<V=S='(@(E,G97-TX"!C87)R96=A;G0N+BXB
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6UA9V5S+G!H<#HX,PIM<V=I
M9"`B3&]A9&EN9RXN+B(*;7-G<W1R(")3)V5S=.`@8V%R<F5G86YT+BXN(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P,PIM<V=I9"`B3&]C
M86P@=&EM93H@(@IM<V=S='(@(DAO<F$@;&]C86PZ("(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX,PIM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S
M='(@(DED:6]M82!I(&AO<F$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4W,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C0*(SH@;&EB
M+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z-C,*
M;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(E5B:6-A8VGS(@H*(SH@;&]G:6XN
M<&AP.C$U-2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,38T('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z.#0*(SH@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z,R!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-0IM<V=I
M9"`B3&]G(&EN(@IM<V=S='(@(DEN:6-I82!L82!S97-S:?,B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34X"FUS9VED("),;V<@;W5T(@IM
M<V=S='(@(E-U<G0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"FUS
M9VED("),;V=I;B!487-K<R(*;7-G<W1R(")487-Q=65S(&0G:6YI8VD@9&4@
M<V5S<VGS(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDQ,0IM<V=I9"`B3&]G
M:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W
M87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB2&D@:&$@:&%G
M=70@=6X@97)R;W(@9&4@8V]N;F5X:?,@<&5R<77H(&AE=2!I;G1R;V1U[W0@
M:6YC;W)R96-T86UE;G0@96P@;F]M("(*(F0G=7-U87)I(&\@;&$@8V]N=')A
M<V5N>6$N(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDP-PIM<V=I9"`B3&]G
M:6X@9F%I;&5D+B(*;7-G<W1R(")(82!F86QL870@;&$@8V]N;F5X:?,N(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-S`*;7-G:60@(DQO;F<@=&5X="(*
M;7-G<W1R(")497AT(&QL87)G(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0X"FUS9VED("),;W9E(@IM<V=S='(@(D%M;W(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B3&]W(@IM<V=S
M='(@(D)A:7@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S
M(@IM<V=S='(@(D%L9F%B970@9W)E8R!E;B!M:6[Z<V-U;&$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y
M"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@(D%L9F%B970@
M;&QA=.T@96X@;6EN^G-C=6QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M
M86X@;G5M8F5R<R(*;7-G<W1R(")8:69R97,@<F]M86YE<R!E;B!M:6[Z<V-U
M;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-#4*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B3'5X96UB=7)G(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W,R!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")-32(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR-3$*;7-G:60@(DU/5$0B"FUS9W-T<B`B
M34]41"(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM
M<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*
M;7-G<W1R("),)V%R>&EU(&%D:G5N="!-4RU43D5&(&YO(&-O;G1E;FEA(&1A
M9&5S+B(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B
M:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(DU31R(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDR(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,S4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-PIM<V=I9"`B
M36%C86\B"FUS9W-T<B`B36%C874B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-3,*;7-G:60@(DUA8V5D;VYI82P@5&AE
M($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R(")-86-E9/)N
M:6$L($%N=&EG82!297#Z8FQI8V$@275G;W-L879A(&1E(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$S-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34Q"FUS9VED(")-
M861A9V%S8V%R(@IM<V=S='(@(DUA9&%G87-C87(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#D*;7-G:60@(DUA9VEC(@IM<V=S='(@(DW@9VEC(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<Y"FUS9VED(")-86EL(@IM
M<V=S='(@(D-O<G)E=2!E;&5C='+R;FEC(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0V.`IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R(")!9&UI
M;FES=')A9&]R(&1E(&-O<G)E=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`IM<V=I9"`B36%K92!L:6Y?
M:RXN+B(*;7-G<W1R(")3)V5S=.`@8W)E86YT('5N(&5N;&QAYRXN+B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HQ,S4W"FUS9VED(")-86ME('-U<F4@=&AA
M="!Y;W4@:&%V92!014%2(&EN<W1A;&QE9"!A;F0@:6X@>6]U<B!I;F-L=61E
M('!A=&@N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV-S@@
M<&\O=')A;G-L871I;VXN<&AP.C$P-S0*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(DUA:VEN9R!D:7)E8W1O<GD@)7,B"FUS9W-T<B`B3F\@Z7,@=6X@
M9&ER96-T;W)I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,38U"FUS9VED(")-86QA=VDB"FUS9W-T<B`B36%L87=I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$S.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38W
M"FUS9VED(")-86QA>7-I82(*;7-G<W1R(")-86S@:7-I82(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDT(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-#`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-`IM<V=I9"`B
M36%L9&EV97,B"FUS9W-T<B`B36%L9&EV97,B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-30*;7-G:60@(DUA;&DB"FUS
M9W-T<B`B36%L:2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$V,@IM<V=I9"`B36%L=&$B"FUS9W-T<B`B36%L=&$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$*;7-G:60@(B(*(DUA;F%G92!T
M:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US
M('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A
M=&5G;W)I97,N(@IM<V=S='(@(B(*(D=E<W1I;VYE=2!L82!L;&ES=&$@9&4@
M8V%T96=O<FEE<R!A;6(@;&5S('%U86QS(&AE=2!D)V5T:7%U971A<B!E;',@
M(@HB96QE;65N=',L(&D@96QS(&-O;&]R<R!A<W-O8VEA=',@86UB(&%Q=65S
M=&5S(&-A=&5G;W)I97,N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$P,SD*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R(")-87!A
M($UA<#(T(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDW-PHC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U
M-`IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(DUA<&$@36%P475E<W0B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<V(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R
M8V@B"FUS9W-T<B`B36%RYR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R
M(")-87)G92(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX
M.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@
M(DUA<F-A<B!A;6(@:6YD:6-A9&]R<R!V:7-I8FQE<R]I;G9I<VEB;&5S(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-
M87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D
M*2(*;7-G<W1R(")-87)C87(@86UB(&%L=')E<R!I;F1I8V%D;W)S("AP+B!E
M+BP@:6UP;W)T86YT+W)E<W!O<W0I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34R"FUS9VED(")-87)S:&%L;"!)<VQA
M;F1S(@IM<V=S='(@(DEL;&5S($UA<G-H86QL(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T
M-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34Y"FUS9VED(")-87)T:6YI
M<75E(@IM<V=S='(@(DUA<G1I;FEC82(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z,3$Q"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B
M0V%M<',@<75E(&-O:6YC:61E:7AI;B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDS(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,`IM<V=I9"`B36%U<FET86YI82(*
M;7-G<W1R(")-875R:73@;FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,38S"FUS9VED(")-875R:71I=7,B"FUS9W-T
M<B`B36%U<FEC:2(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S$T"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(D-R
MZ&1I="!MX'AI;2!P97)MZ',N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#<*;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E
M9&5D+B(*;7-G<W1R(")3)VAA('-U<&5R870@96P@;F]M8G)E(&W@>&EM(&1E
M('!A<G1S(&1E(&UI<W-A=&=E+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S`T"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B
M5&5M<&5R871U<F$@;>!X:6UA(&1E(&QE<R!D87)R97)E<R`R-"!H;W)E<SH@
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.38*;7-G:60@(DUA>"!T96UP
M(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(E1E;7!E<F%T=7)A(&W@>&EM82!D
M92!L97,@9&%R<F5R97,@-B!H;W)E<SH@(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C@Y."!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q-R!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B3&]N
M9VET=60@;>!X:6UA(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C,W."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-CD*;7-G:60@(DUA>2(*;7-G<W1R(")-86EG(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,PIM<V=I9"`B36%Y;W1T
M92(*;7-G<W1R(")-87EO='1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R(")-961I8VEN82(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3D*;7-G:60@(DUE;6)E
M<G,B"FUS9W-T<B`B365M8G)E<R(*"B,Z(&QA;F=T97-T+G!H<#HW"FUS9VED
M(")-96UO<GD@97AH875S=&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-C@*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B5&EP
M=7,@9&4@;65N^CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R
M(")2969O;F%R(&QE<R!C96RW;&5S(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C4R-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-97)G:6YG(&%L;"`E<RYP;R!F
M:6QE<R!T;R!T:&4@8V]M<&5N9&EU;2XN+B`B"FUS9W-T<B`B(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C0S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")-97)G
M:6YG(&QO8V%L92`E<RXN+B`B"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C<X.`HC+"!P:'`M9F]R;6%T"FUS9VED(")-97)G:6YG('1H92!0
M3R!F:6QE(&9O<B`E<R!T;R!T:&4@8V]M<&5N9&EU;2XN+B`B"FUS9W-T<B`B
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0R-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")-97)G:6YG('1R86YS;&%T:6]N(&9O<B!M;V1U;&4@)7,N+BXB"FUS
M9W-T<B`B(@H*(SH@;&%N9W1E<W0N<&AP.C$W(&QI8B](;W)D92].;W1I9FEC
M871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`IM<V=I9"`B365S<V%G92(*
M;7-G<W1R(")-:7-S871G92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL
M>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B
M"B)V97)I9FEE9"XB"FUS9W-T<B`B(@HB16P@;6ES<V%T9V4@:&$@97-T870@
M=F5R:69I8V%T(&-O<G)E8W1A;65N="P@<&5R\B!N;R!S)VAA('!O9W5T('9E
M<FEF:6-A<B!E;"`B"B)C97)T:69I8V%T(&5L('-I9VYA;G0N(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(DUE<W-A
M9V4@97AP:7)E9"XB"FUS9W-T<B`B36ES<V%T9V4@8V%D=6-A="XB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U.0HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-38X(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,#$*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")4:7!U<R!D
M92!M:7-S871G92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B
M365T87(@5V5A=&AE<B(*;7-G<W1R(")496UP<R!D92!-151!4B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(D5L(&)L;V,@345405(@;F\@97-TX"!D:7-P
M;VYI8FQE+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$P"FUS9VED("(B
M"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E
M;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)%
M;"!B;&]C($U%5$%2(&YO(&5S=.`@9&ES<&]N:6)L92X@16QS(&1E=&%L;',@
M:&%N(&5S=&%T(')E9VES=')A=',@<&5R(&$@(@HB;"=A9&UI;FES=')A9&]R
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G:60@
M(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B3&$@8F%S92!D
M92!D861E<R!-151!4B!N;R!E<W3@(&-O;FYE8W1A9&$N(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S$@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C<*;7-G:60@(DUE=&AO9"(*;7-G<W1R(")-Z'1O9&4B
M"@HC.B!L:6(O2&]R9&4O4E!#+W-O87`N<&AP.C$Q-R!L:6(O2&]R9&4O4E!#
M+WAM;')P8RYP:'`Z.#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUE
M=&AO9"`G)7,G(&ES(&YO="!D969I;F5D(@IM<V=S='(@(D5L(&WH=&]D92`G
M)7,G(&YO(&5S=.`@9&5F:6YI="XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-S,@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,PIM<V=I9"`B365T
M<FEC(@IM<V=S='(@(DWH=')I8R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDU(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$V-@IM<V=I9"`B365X:6-O(@IM<V=S='(@
M(DWH>&EC(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.#4*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@
M;V8B"FUS9W-T<B`B36EC<F]NZ'-I82P@17-T871S($9E9&5R871S(&1E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<V"FUS9VED(")-:61D;&4B"FUS9W-T<B`B0V5N=')E(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B
M"FUS9W-T<B`B5&EP=7,@34E-12(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S`X"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B
M5&5M<&5R871U<F$@;>UN:6UA(&1E(&QE<R!D87)R97)E<R`R-"!H;W)E<SH@
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#`*;7-G:60@(DUI;B!T96UP
M(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(E1E;7!E<F%T=7)A(&WM;FEM82!D
M92!L97,@9&%R<F5R97,@-B!H;W)E<SH@(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(Q-PIM<V=I9"`B36ER<F]R(@IM<V=S='(@
M(E+H<&QI8V$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@
M(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B36ES8V5LMVQA;FDB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,S.2!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C<Q"FUS9VED(")-:7-S:6YG(%!%05(@<&%C
M:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(D9A;'1A(&QA('-O;+=L:6-I
M='5D($A45%`@<&5R(&%L('!A<75E="!014%2+B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ,30*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO
M;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O
M('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"B)&86QT82!L
M82!C;VYF:6=U<F%C:?,N($PG:&5U(&1E(&=E;F5R87(@87)A('-I('9O;&5U
M('5T:6QI='IA<B!A<75E<W1A("(*(F%P;&EC86-I\RXB"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B36ES<VEN9R!M
M97-S86=E($E$+B(*;7-G<W1R(")&86QT82!L)VED96YT:69I8V%D;W(@9&5L
M(&UI<W-A=&=E+B(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z-3<*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E
M($UA:6PN(@IM<V=S='(@(D9A;'1A(&5L(&-O<G)E=2!E;&5C='+R;FEC(&1E
M;"!P87%U970@4$5!4B!N96-E<W-A<FDN(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)
M1"XB"FUS9W-T<B`B1F%L=&$@;"=I9&5N=&EF:6-A9&]R(&1E('-E<W-I\RXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V
M"FUS9VED(")-;R(*;7-G<W1R(")$;"XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-S(*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@(D-O<G)E
M=2!M\F)I;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8T"FUS9VED(")-;V1E<F%T92(*;7-G<W1R(")-;V1E<F%T(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S`@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W1G>BYP:'`Z.#@*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C8*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B1&%T
M82!M;V1I9FEC861A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")-;V1I9GD@55),(@IM<V=S
M='(@(DUO9&EF:6-A<B!L82!54DPB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-C4W"B,L(&9U>GIY"FUS9VED(")-;V1U;&4B"FUS9W-T<B`B3?)D=6PB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8W,PIM<V=I9"`B36]D=6QU
M<R(*;7-G<W1R(")-\F1U;"(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDP(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$U,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@
M;V8B"FUS9W-T<B`B36]L9.!V:6$L(%)E</IB;&EC82!D92(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDP(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-3$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T.0IM<V=I9"`B
M36]N86-O(@IM<V=S='(@(DWR;F%C;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDR(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-@IM<V=I9"`B36]N9V]L:6$B"FUS
M9W-T<B`B36]N9_)L:6$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y,@IM
M<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B365S(&D@86YY(@H*(SH@
M;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*
M;7-G<W1R(")-96YS=6%L;65N="(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$V,0IM<V=I9"`B36]N='-E<G)A="(*;7-G
M<W1R(")-;VYT<V5R<F%T(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R
M(")&87-E<R!L=6YA<G,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-#@*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B36%R
M<F]C(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S`*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R(")-86IO<FETX')I86UE
M;G0@9&5S8V]B97)T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S$*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B36%J
M;W)I=.!R:6%M96YT(&5N;G5V;VQA="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS
M9W-T<B`B36%J;W)I=.!R:6%M96YT(&%S<V]L96QL870B"@HC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+G!H<#HT,C@*;7-G:60@(DUO=F4@1&]W;B(*;7-G
M<W1R(")-;W5R92!C87`@879A;&PB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+G!H<#HT,S(*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R(")-;W5R92!A
M(&PG97-Q=65R<F$B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HT
M,S8*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B36]U<F4@82!L82!D<F5T
M82(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C0R-`IM<V=I9"`B
M36]V92!5<"(*;7-G<W1R(")-;W5R92!C87`@86UU;G0B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#DV"FUS9VED(")-;W9E(&1O
M=VXB"FUS9W-T<B`B36]U<F4@8V%P(&%V86QL(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Y-2!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#DV"FUS9VED(")-;W9E('5P(@IM<V=S='(@(DUO
M=7)E(&-A<"!A;75N="(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$V.`IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R(")-
M;^=A;6)I8R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3@T"FUS9VED(")-
M=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B3&ES=&5S(&1E
M<W!L96=A8FQE<R!E;FQL8>=A9&5S(&5N(&1I=F5R<V]S(&YI=F5L;',B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T,@IM<V=I9"`B375L=&EP;&4@<V5L
M96-T:6]N(@IM<V=S='(@(E-E;&5C8VGS(&WZ;'1I<&QE(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,R.2!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S,V"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(D5L(&UE=2!C;VUP
M=&4B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C4P"FUS9VED(")-
M>2!0;W)T86PB"FUS9W-T<B`B16P@;65U('!O<G1A;"(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]E9&ET+G!H<#HQ,C0*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B
M"FUS9W-T<B`B1&ES<V5N>2!D96P@;65U('!O<G1A;"(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDR(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-38*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-0IM<V=I9"`B37EA
M;FUA<B(*;7-G<W1R(")->6%N;6%R(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+V%G<F5E;65N=%]B;W1T;VTN:6YC.C<*;7-G:60@(DY/+"!)($1O($Y/
M5"!!9W)E92(*;7-G<W1R(").3RP@3D\@:&D@97-T:6,@9"=A8V]R9"(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS."!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HT,#`*;7-G:60@(DYA;64B"FUS9W-T<B`B3F]M(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.34@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$U-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38Y"FUS9VED
M(").86UI8FEA(@IM<V=S='(@(DYA;>UB:6$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S@*;7-G:60@(DYA=7)U(@IM
M<V=S='(@(DYA=7)U(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3<W"FUS9VED(").97!A;"(*;7-G<W1R(").97!A;"(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-C`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W
M-0IM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B4&'O<V]S($)A:7AO<R(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-C$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S
M"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R(")!;G1I;&QE
M<R!.965R;&%N9&5S97,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4X,0IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B55),(&)A
M<V4@9&4@3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4X,PIM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T
M<B`B55),(&1E(')E=F]C86-I\R!D92!#02!D92!.971S8V%P92(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!#
M02!P;VQI8WD@55),(@IM<V=S='(@(E523"!D92!P;VSM=&EQ=65S(&1E($-!
M(&1E($YE='-C87!E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M.#0*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(E523"!D
M92!R96YO=F%C:?,@9&4@3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB
M"FUS9W-T<B`B55),(&1E(')E=F]C86-I\R!D92!.971S8V%P92(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P92!3
M4TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B3F]M(&1E;"!S97)V:61O<B!34TP@
M9&4@3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X
M-PIM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R
M(")#;VUE;G1A<FD@9&5L(&-E<G1I9FEC870@9&4@3F5T<V-A<&4B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,`IM<V=I9"`B3F5T<V-A<&4@
M8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R(")4:7!U<R!D92!C97)T:69I8V%T
M(&1E($YE='-C87!E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S
M-PIM<V=I9"`B3F5T=V]R:R(*;7-G<W1R(")887)X82(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C0Q-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(U
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S8*;7-G:60@(DYE=F5R(@IM
M<V=S='(@(DUA:2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$W,`IM<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R(").
M;W9A($-A;&5D\FYI82(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C(W"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`B3F]V
M82!C871E9V]R:6$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L
M;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-SD*;7-G:60@
M(DYE=R!-;V]N(@IM<V=S='(@(DQL=6YA(&YO=F$B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@
M*&]P=&EO;F%L*2(*;7-G<W1R(").;W4@;F]M(&0G=7-U87)I("AO<&-I;VYA
M;"DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.#`*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(DYO=F$@6F5L86YD
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B3F]V82!F
M:6YE<W1R82`H7V5N(&)L86YC*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C4Y"FUS9VED(").97=S(@IM<V=S='(@(DUI<W-A=&=E
M<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.3,*;7-G:60@(DYE
M=W-G<F]U<',B"FUS9W-T<B`B1W)U<',@9&4@9&ES8W5S<VGS(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,S(@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,C$@
M=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#8*;7-G:60@(DYE>'0B"FUS
M9W-T<B`B4V5G_&5N="(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I
M9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R("(T(&9A<V5S('-E9_QE;G1S(@H*
M(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-C@@;&EB+TAO<F1E+U!R969S
M+U5)+G!H<#HS-S(*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R(")/<&-I
M;VYS('-E9_QE;G1S(@H*(SH@;&EB+TAO<F1E+U5)+U!A9V5R+G!H<#HQ,#,*
M;7-G:60@(DYE>'0^(@IM<V=S='(@(E-E9_QE;G0^(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$V-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<T"FUS9VED(").:6-A
M<F%G=6$B"FUS9W-T<B`B3FEC87)A9W5A(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Q"FUS9VED(").:6=E<B(*;7-G
M<W1R(").[6=E<B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$W,PIM<V=I9"`B3FEG97)I82(*;7-G<W1R(").:6?H<FEA
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q.`IM<V=I9"`B
M3FEG:'0B"FUS9W-T<B`B3FET(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Y"FUS9VED(").:75E(@IM<V=S='(@(DYI
M=64B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#@U
M"FUS9VED(").;R(*;7-G<W1R(").;R(*"B,Z('1E;7!L871E<R]A9&UI;B]S
M971U<"]D:69F+FAT;6PZ,38*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U
M<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@
M(DYO(&5S(&1I<W!O<V5N(&1E(&1A9&5S(&1E(&-O;F9I9W5R86-I\R!P97(@
M;6]S=')A<B!L97,@9&EF97+H;F-I97,N(@H*(SH@;&EB+U9&4R])4T]7<FET
M97(N<&AP.C$P-0IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M
M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B3F\@97,@9&ES<&]S82!D)W5N
M82!E<W1R873H9VEA('!E<B!C<F5A<B!I;6%T9V5S($E33RXB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B3F\@8F%T
M8V@@=&5M<&QA=&4N(@IM<V=S='(@(DYO(&AI(&AA('!L86YT:6QL82!D92!L
M;W1S+B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C<Y(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C(S,`HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+G!H<#HR-3(*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@
M<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(DYO(&5X:7-T96EX(&-A<"!B
M;&]C(&5N(&QA('!O<VEC:?,@<V]LMVQI8VET861A(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O;6-A;"YP:'`Z-3`*;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O
M=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYO(',G
M:&$@<')O<&]R8VEO;F%T('5N(&YO;2!D)V%G96YD82!P97(@82!L)V%U=&5N
M=&EC86-I\R!-0T%,+B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS
M9VED(").;R!C:&%N9V4N(@IM<V=S='(@(E-E;G-E(&-A;G9I<RXB"@HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T,`HC+"!F=7IZ>0IM<V=I9"`B3F\@
M8VAI;&0@<&5R;6ES<VEO;G,@87)E('1O(&)E(&%D9&5D(&)E;&]W('1H:7,@
M;&5V96PN(@IM<V=S='(@(DYO(&5S('!O9&5N(&%F96=I<B!D97-C96YD96YT
M<R!A(&%Q=65S="!P97)M[7,B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z-C$*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES
M('!E<FUI<W-I;VXN(@IM<V=S='(@(DYO(&5S('!O9&5N(&%F96=I<B!D97-C
M96YD96YT<R!A(&%Q=65S="!P97)M[7,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,3,W-PHC+"!F=7IZ>0IM<V=I9"`B3F\@8V]M;6%N9"!S<&5C:69I960N
M(@IM<V=S='(@(DYO(',G:&$@97-P96-I9FEC870@=6X@;F]M+B(*"B,Z(&QI
M8B](;W)D92YP:'`Z,38W(&QI8B](;W)D92YP:'`Z-#<W(&QI8B](;W)D92]5
M=&EL+G!H<#HW-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R(").
M;R!S)VAA(&5S<&5C:69I8V%T(&QE<R!D861E<R!D92!C;VYF:6=U<F%C:?,@
M<&5R(&$@)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<T,0IM<V=I9"`B3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!6
M1E,N(@IM<V=S='(@(DYO(',G:&$@97-P96-I9FEC870@;&5S(&1A9&5S(&1E
M(&-O;F9I9W5R86-I\R!P97(@82!&5%`@<&5R(%9&4RXB"@HC.B!L:6(O5D93
M+W-Q;"YP:'`Z-3DQ"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B3F\@<R=H82!E
M<W!E8VEF:6-A="!L97,@9&%D97,@9&4@8V]N9FEG=7)A8VGS('!E<B!A(%-1
M3"!P97(@5D93+B(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<P-`IM<V=I
M9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B(@HB3F\@<R=H82!E<W!E8VEF:6-A
M="!L97,@9&%D97,@9&4@8V]N9FEG=7)A8VGS(&1E(%-13"!P97(@86P@9FET
M>&5R(%-13"XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q,PIM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(DYO('%U961A
M(&-RZ&1I="XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,S"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B
M3F\@<R=H82!F86-I;&ET870@=6YA(&1E<W1I;F%C:?,N(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C$R-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@96YT
M<GD@=VET:"!T:&4@:60@)R5S)R!E>&ES=',@:6X@=&AE(&]R:6=I;F%L(&AE
M;'`@9FEL92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP
M.C@W,0IM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R(").;R!S)VAA
M(&-A<G)E9V%T(&-A<"!A<GAI=2XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R(").;R!S)VAA
M('1R;V)A="!C87`@:6-O;F$N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0Q
M,R!P;R]T<F%N<VQA=&EO;BYP:'`Z-3(R"B,L(&9U>GIY"FUS9VED(").;R!L
M;V-A;&4@<W!E8VEF:65D+B(*;7-G<W1R(").;R!S)VAA(&5S<&5C:69I8V%T
M('5N(&YO;2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(P
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$R,0IM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R(").
M;R!S)VAA(&1E9FEN:70@=6YA('5B:6-A8VGS+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-C$*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I
M9&5D+B(*;7-G<W1R(").;R!S)VAA(&9A8VEL:71A="!U;F$@=6)I8V%C:?,N
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@IM<V=I
M9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B3F\@<R=H82!I;G1R
M;V1U[W0@=6X@;6ES<V%T9V4N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S-0IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S
M='(@(DYO(',G:&$@97-P96-I9FEC870@=6X@;F]M+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YU;6)E<B!S
M<&5C:69I960N(@IM<V=S='(@(DYO(',G:&$@97-P96-I9FEC870@=6YA('AI
M9G)A+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@
M;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(DYO(&5S('!E<FUE=&5N(&QE
M<R!D:71E<R!O9F5N<VEV97,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:'1T<"YP
M:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").;R!S)VAA(&EN=')O9'7O="!U;F$@
M8V]N=')A<V5N>6$@<&5R(&$@;"=A=71E;G1I8V%C:?,@2%144"XB"@HC.B!L
M:6(O2&]R9&4O075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").
M;R!S)VAA(&EN=')O9'7O="!U;F$@8V]N=')A<V5N>6$@<&5R(&$@;"=A=71E
M;G1I8V%C:?,@24U!4"XB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HW
M,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").;R!S)VAA(&EN=')O9'7O="!U;F$@
M8V]N=')A<V5N>6$@<&5R(&$@;"=A=71E;G1I8V%C:?,@2V5R8F5R;W,N(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@
M(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,1$%0(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R(").;R!S)VAA(&EN=')O9'7O="!U;F$@8V]N=')A<V5N>6$@
M<&5R(&$@;"=A=71E;G1I8V%C:?,@24U!4"XB"@HC.B!L:6(O2&]R9&4O075T
M:"]S87-L+G!H<#HW-R!L:6(O2&]R9&4O075T:"]P86TN<&AP.C<U"B,Z(&QI
M8B](;W)D92]!=71H+VQO9VEN+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").
M;R!S)VAA(&EN=')O9'7O="!U;F$@8V]N=')A<V5N>6$@<&5R(&$@;"=A=71E
M;G1I8V%C:?,@9"=I;FEC:2XB"@HC.B!L:6(O2&]R9&4O075T:"]P87-S=V0N
M<&AP.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-7
M1"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F\@<R=H82!I;G1R;V1U[W0@
M=6YA(&-O;G1R87-E;GEA('!E<B!A(&PG875T96YT:6-A8VGS(%!!4U-71"XB
M"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M(").;R!S)VAA(&EN=')O9'7O="!U;F$@8V]N=')A<V5N>6$@<&5R(&$@;"=A
M=71E;G1I8V%C:?,@4TU"+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z,3(X-@IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA
M<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@
M=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@HB3F\@
M<R=H82!I;F1I8V%T(&QA('9I82!D)V%C8^ES(&%L(&)I;F%R:2!/<&5N4U-,
M+B!#86P@96P@8FEN87)I($]P96Y34TP@<&5R("(*(G1R96)A;&QA<B!A;6(@
M;&5S(&1A9&5S(%!+0U,@,3(N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G
M<W1R(").;R!H:2!H82!A;'1E<R!P96YD96YT<RXB"@HC.B!L:6(O5D93+G!H
M<#HW-C4*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B3F\@<R=H82!D
M969I;FET(&PG97-P86D@9&ES<&]N:6)L92XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S"FUS9VED(").;R!R
M=6QE<R(*;7-G<W1R(")396YS92!R96=L97,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T"FUS9VED(").;R!S
M:61E<R(*;7-G<W1R(")396YS92!C87)E<R(*"B,Z(&QI8B]61E,O<VUB+G!H
M<#HU.#4*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R(").;R!E>&ES=&5I
M>"!A<75E<W0@87)X:74B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3,P"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L
M92!F;W(@8V%C:&4N(@IM<V=S='(@(DYO(&5S(&1I<W!O<V$@9&4@8V%P(&1I
M<F5C=&]R:2!T96UP;W)A;"!P97(@82!L82!M96WR<FEA(&-A=2XB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,P"FUS9VED(").;R!U
M<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B3F\@:&5U
M(&5N=FEA="!E;"!N;VT@9"=U<W5A<FD@;FDO;R!L82!C;VYT<F%S96YY82(*
M"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A
M;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(DYO(',G:&%N(')E=&]R
M;F%T(&1A9&5S(%A-3"!VX&QI9&5S(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C@Y,R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.3`S"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HY,30@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDS
M,0IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(E-E;G-E('9A;&]R<R(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,3D*;7-G:60@(DYO('9E<G-I;VX@
M9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B).;R!S)VAA('1R;V)A="!L82!V
M97)S:?,@96X@;&$@8V]N9FEG=7)A8VGS(&]R:6=I;F%L+B!296=E;F5R974@
M;&$@(@HB8V]N9FEG=7)A8VGS+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ,C<*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U
M<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M(DYO(',G:&$@=')O8F%T(&QA('9E<G-I\R!E;B!L82!C;VYF:6=U<F%C:?,N
M(%)E9V5N97)E=2!L82!C;VYF:6=U<F%C:?,N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-#$V('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y
M<V5L96-T+FEN8SHY,@IM<V=I9"`B3F]N92(*;7-G<W1R(")#87`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED
M(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(D-A<"`H^G,@:6UP;.UC
M:70I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DYO<F1I
M8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(D[R<F1I8R`H25-/+3@X-3DM,3`I
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$V.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3<R"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R("));&QA(&1E($YO
M<F9O;&LB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO
M;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@
M(DAE;6ES9F5R:2!N;W)D(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,34X"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES
M;&%N9',B"FUS9W-T<B`B26QL97,@36%R:6%N;F5S(&1E;"!.;W)D(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$W,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<V"FUS
M9VED(").;W)W87DB"FUS9W-T<B`B3F]R=65G82(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B
M3F\@9&5S<'+I<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C,Y
M"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(DYO(&%B86YS(@H*(SH@;&EB
M+U9&4R]F:6QE+G!H<#HS,S$*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G
M<W1R(").;R#I<R!U;B!D:7)E8W1O<FDB"@HC.B!L:6(O5D93+TE33U=R:71E
M<BYP:'`Z-C,@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN
M<&AP.C0X"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+G!H<#HU.0HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E
M9WDN<&AP.C@S"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2YP:'`Z.30*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B
M3F\@:6UP;&5M96YT870N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*;7-G<W1R(").;R!D
M969I;FET(@H*(SH@;&EB+U9&4RYP:'`Z,3DS(&QI8B]61E,N<&AP.C(P."!L
M:6(O5D93+G!H<#HR,S,@;&EB+U9&4RYP:'`Z,C4Q"B,Z(&QI8B]61E,N<&AP
M.C(V."!L:6(O5D93+G!H<#HR.#0@;&EB+U9&4RYP:'`Z,S`P(&QI8B]61E,N
M<&AP.C,Q-0HC.B!L:6(O5D93+G!H<#HS,S(@;&EB+U9&4RYP:'`Z,S8U(&QI
M8B]61E,N<&AP.C0R-2!L:6(O5D93+G!H<#HU,#0*(SH@;&EB+U9&4RYP:'`Z
M-3<S(&QI8B]61E,N<&AP.C4Y,"!L:6(O5D93+G!H<#HV-C@*(SH@;&EB+TAO
M<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#,@;&EB+TAO<F1E+U-E<W-I;VY(
M86YD;&5R+G!H<#HQ-3@*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H
M<#HQ-S,@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#<*(SH@;&EB
M+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HR,S0*;7-G:60@(DYO="!S=7!P
M;W)T960N(@IM<V=S='(@(DYO('!E<FWH<RXB"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,38R"FUS9VED(").;W1E<R(*;7-G<W1R(").;W1E<R(*"B,Z('-E<G9I
M8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B
M<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(DYO(&AI(&AA(')E<R!A('9I<W5A
M;&ET>F%R+"!R971R;V-E9&EU+B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]C;VYF:7)M7W1O<"YI;F,Z,3`*(RP@9G5Z>GD*;7-G:60@(DYO=&EC92(*
M;7-G<W1R(").;W1E<R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HS.#0@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<U"FUS9VED(").;W9E;6)E<B(*;7-G<W1R(").;W9E;6)R92(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,#0V"FUS9VED(").=6UB97(B"FUS9W-T<B`B
M3F]M8G)E(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,S`*;7-G:60@(DYU
M;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(DYO;6)R92!D92!C87+@8W1E
M<G,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W-"!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,30R."!L:6(O2&]R9&4O1F]R;2YP:'`Z,30U,`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M
M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B3F]M8G)E(&1E(&-O;'5M;F5S(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-S(@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$T,C8@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#@*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O
M9B!R;W=S(@IM<V=S='(@(DYO;6)R92!D92!F:6QE<R(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DYU;6)E<G,@;F]T
M('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N
M(@IM<V=S='(@(B(*(DYO(',G:&%N(&5S<&5C:69I8V%T(&YO;6)R97,@<75E
M(&AA9VEN(&1E('-E<B!A8W1U86QI='IA=',@96X@;&$@;&QI<W1A(&1E("(*
M(F1I<W1R:6)U8VGS+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHV-"!P;R]T<F%N<VQA=&EO;BYP:'`Z,30X"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,S0X"FUS9VED(")/2R(*;7-G<W1R(")$)V%C;W)D
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Q,0IM
M<V=I9"`B3V)J96-T(@IM<V=S='(@(D]B:F5C=&4B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS
M9W-T<B`B0W)E861O<B!D92!L)V]B:F5C=&4B"@HC.B!A9&UI;B]P97)M<R]E
M9&ET+G!H<#HQ,S<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR,34*(RP@9G5Z
M>GD*;7-G:60@(D]B:F5C="!C<F5A=&]R('!E<FUI<W-I;VYS(@IM<V=S='(@
M(E!E<FUI<V]S(&1E;"!C<F5A9&]R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(D]C=&%L(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,R!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T
M<B`B3V-T=6)R92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I
M9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B1FEL=')E(&0G:6YF<F%C8VEO
M;G,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,CDY"FUS9VED(")/
M9F9I8V4B"FUS9W-T<B`B3V9I8VEN82(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDX(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,0IM<V=I9"`B3VUA;B(*;7-G<W1R
M(")/;6%N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S
M"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD
M97)S+B(*;7-G<W1R(").;VWI<R!E;',@<V5R=FED;W)S($E-05`@<&5R;65T
M96X@;"?Z<R!D92!C87)P971E<R!C;VUP87)T:61E<RXB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U
M;F5S(@IM<V=S='(@(DYO;>ES(&UI<W-A=&=E<R!O9F5N<VEU<R(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ.#4Q(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<Q
M"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S
M='(@(DYO;>ES(.ES('!E<FUE<V$@=6YA(/IN:6-A(&%D<F7G82!E;&5C='+R
M;FEC82XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@
M(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA
M>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O
M<B!A('-H87)E(@IM<V=S='(@(B(*(DYO;>ES(&5L('!R;W!I971A<FD@;R!L
M)V%D;6EN:7-T<F%D;W(@9&4@<VES=&5M97,@<&]T(&-A;G9I87(@;&$@<')O
M<&EE=&%T(&\@(@HB96QS('!E<FUI<V]S(&1E;"!P<F]P:65T87)I('!E<B!A
M(')E8W5R<V]S(&-O;7!A<G1I=',B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H
M<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B3V)R
M:74@96X@=6YA(&YO=F$@9FEN97-T<F$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T
M(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T
M<B`B(@HB17)R;W(@3W!E;E-33#H@;F\@<R=H86X@<&]G=70@97AT<F5U<F4@
M;&5S(&1A9&5S(&1E(&QA('!A<G0@4R]-24U%('-I9VYA9&$N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T
M"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S
M='(@(D]B<F4@87%U97-T(&5N;&QAYR!E;B!U;F$@;F]V82!F:6YE<W1R82(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG
M(%-Y<W1E;2(*;7-G<W1R(")3:7-T96UA(&]P97)A=&EU(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G
M<W1R(")/<&-I;VYS(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C(Y('1E;7!L
M871E<R]P<F5F<R]A<'`N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D]P
M=&EO;G,@9F]R("5S(@IM<V=S='(@(D]P8VEO;G,@9"<E<R(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(D]P=&EO;G,Z(@IM
M<V=S='(@(D]P8VEO;G,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B
M3&QI<W1A(&]R9&5N861A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU-C<*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R(")/<F=A;FET>F%C
M:?,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B
M3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R(")5;FET870@;W)G86YI='IA
M=&EV82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S`*;7-G:60@
M(D]R9V%N:7II;F<B"FUS9W-T<B`B4R=E<W3@(&]R9V%N:71Z86YT(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI
M8V%T:6]N('1E;7!L871E(@IM<V=S='(@(E!L86YT:6QL82!D)V%P;&EC86-I
M\R!O<FEG:6YA;"(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H
M<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS
M9W-T<B`B4&QA;G1I;&QE<R!O<FEG:6YA;',@96X@)7,Z(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ
M,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B06QT<F4B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,C$*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R.0IM<V=I9"`B3W1H
M97(@26YF;W)M871I;VXB"FUS9W-T<B`B06QT<F$@:6YF;W)M86-I\R(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUI<V]S(&1E;"!P<F]P:65T87)I(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE
M;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DPG875T96YT
M:6-A8VGS(%!!32!N;R!E<W3@(&1I<W!O;FEB;&4N(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z,3(U,PIM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T
M=7)E(@IM<V=S='(@(E-I9VYA='5R82!D:6=I=&%L(%!'4"(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C$R.3D*;7-G:60@(E!'4"!%;F-R>7!T960@
M1&%T82(*;7-G<W1R(")$861E<R!X:69R861E<R!A;6(@4$=0(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,U,0IM<V=I9"`B4$=0(%!U8FQI8R!+
M97DB"FUS9W-T<B`B0VQA=2!01U`@</IB;&EC82(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C$S,S,*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D
M($1A=&$B"FUS9W-T<B`B1&%D97,@<VEG;F%D97,O>&EF<F%D97,@86UB(%!'
M4"(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.`IM<V=I9"`B4$A0($-O9&4B
M"FUS9W-T<B`B0V]D:2!02%`B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*
M;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R("));G3H<G!R970@9"=O<F1R97,@
M4$A0(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S0*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B4&QU9VEM<R!D92!T
M87)D82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,U"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(E!L=6=E<R!D92!T87)D
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V
M"FUS9VED(")032!3;F]W(@IM<V=S='(@(DYE=F%D97,@9&4@=&%R9&$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I
M9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(EC@9F5C<R!D92!N974@82!L
M82!T87)D82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,X"FUS9VED(")032!3=6XB"FUS9W-T<B`B4V]L(&1E('1A<F1A(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*;7-G
M:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(E1E;7!E<W1E<R!D92!T87)D82(*
M"B,Z(&QI8B]A<&DN<&AP.C$R.`IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R
M("));G3H<G!R970@9"=O<F1R97,@4%](4"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I
M;F<B"FUS9W-T<B`B4V5P87)A8VGS(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@W"FUS9VED(")086MI<W1A;B(*;7-G
M<W1R(")086MI<W1A;B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.30*;7-G:60@(E!A;&%U(@IM<V=S='(@(E!A;&%U
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Y,@IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*
M;7-G<W1R(")497)R:71O<FD@<&%L97-T[2P@;V-U<&%T(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$W-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@R"FUS9VED(")0
M86YA;6$B"FUS9W-T<B`B4&%N86W@(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@U"FUS9VED(")087!U82!.97<@1W5I
M;F5A(@IM<V=S='(@(E!A<'5A($YO=F$@1W5I;F5A(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-S<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-0IM<V=I9"`B4&%R
M86=U87DB"FUS9W-T<B`B4&%R86=U86DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B4&%R=&QY($-L;W5D>2(*
M;7-G<W1R(")087)C:6%L;65N="!E;FYU=F]L870B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@S(&QI8B](;W)D92]&
M;W)M+G!H<#HR,#$X"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,3DX(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C<Q"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS-3,*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(D-O;G1R87-E;GEA(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,S(R"FUS9VED(")087-S
M=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B0V]N=')A<V5N>6$@:6YC;W)R96-T
M82(*"B,Z(&QI8B](;W)D92]!=71H+W)A9&EU<RYP:'`Z,34R"FUS9VED(")0
M87-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(")#86P@:6YT<F]D=6ER('5N82!C;VYT<F%S96YY82!P97(@82!L
M)V%U=&5N=&EC86-I\R!2041)55,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(P-3,*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S
M='(@(D-O;G1R87-E;GEA(&%M8B!C;VYF:7)M86-I\R(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S
M='(@(D-O;G1R87-E;GEA.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(D-O;G1R87-E;GEA
M.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(P,S0*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM
M<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(DQE<R!C;VYT
M<F%S96YY97,@:&%N(&1E(&-O:6YC:61I<BXB"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3(P('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B16YG86YX87(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W
M"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R(")%;F=A;GAA
M<B!D96P@<&]R=&$M<F5T86QL<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B0V%M
M[2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHT"FUS9VED(")0
M96YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(D%L=&5S('!E;F1E;G1S.B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S
M='(@(D=E;G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R(")097)C96YT871G
M92(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M7V)O='1O;2YI
M;F,Z-@IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM
M<V=S='(@(E)E86QI='IA<B!O<&5R86-I;VYS(&1E(&UA;G1E;FEM96YT(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-@IM<V=I9"`B4&5R9F]R;2!M
M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")6;VQE
M=2!R96%L:71Z87(@;W!E<F%C:6]N<R!D92!M86YT96YI;65N="!E;B!I;FEC
M:6%R(&QA('-E<W-I\S\B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M-C$@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8T"B,Z(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HV-PIM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R(")0
M97)M[7,B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C8X"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N("<E<R<@;F]T(&1E;&5T
M960N(@IM<V=S='(@(DYO(',G:&$@96QI;6EN870@96P@<&5R;>US("<E<R<N
M(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C4X.`IM<V=I9"`B4&5R;6ES<VEO;B!$
M96YI960B"FUS9W-T<B`B4&5R;6ES(&1E;F5G870B"@HC.B!A9&UI;B]P97)M
M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.CDS"B,Z
M(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(R-"!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C<T"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G
M<W1R(")!9&UI;FES=')A9&]R(&1E('!E<FUI<V]S(@H*(SH@;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<#HQ-#4@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-#@*
M(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@
M(E!E<FUI<W-I;VYS(&9O<B(*;7-G<W1R(")?4&5R;6ES;W,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C4*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T
M:6]N(@IM<V=S='(@(D1A9&5S('!E<G-O;F%L<R(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDX(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-S@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,PIM<V=I9"`B4&5R=2(*
M;7-G<W1R(")097+Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS
M9VED(")0971S(@IM<V=S='(@(D%N:6UA;',@9&4@8V]M<&%N>6EA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$W.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@V"FUS
M9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R(")&:6QI<&EN97,B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B
M"FUS9W-T<B`B5&5LZ&9O;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,38*;7-G:60@(E!H;W1O<R(*;7-G<W1R(")&;W1O<R(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3`*;7-G:60@
M(E!I=&-A:7)N(@IM<V=S='(@(E!I=&-A:7)N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*
M;7-G<W1R(")0[7AE;',B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*
M;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B5/)P:6-S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I
M9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(D-L:6-A
M<B!E;B!U;F$@8V5LMVQA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0X"FUS9VED(")0;&5A<V4@8V]N9FER
M;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S
M='(@(D-O;F9I<FUA<B!Q=64@=F]L974@<W5P<FEM:7(@87%U97-T(&5L96UE
M;G0Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4U"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W
M86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(D-O;F9I<FUA
M<B!Q=64@=F]L974@9&5S96YL;&'G87(@87%U97-T(&5L96UE;G0N(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(U-CD*;7-G:60@(E!L96%S92!E;G1E<B!A
M(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(DEN=')O9'7O=2!U;B!M97,@
M:2!U;B!A;GDN(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H
M92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(DEN=')O9'7O=2!U;B!N;VT@<&5R
M(&$@;&$@;F]V82!C871E9V]R:6$Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$S,#<*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N
M(@IM<V=S='(@(DEN=')O9'7O=2!U;F$@861R9>=A($E0(';@;&ED82XB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8U.`IM<V=I9"`B4&QE87-E(&5N=&5R
M(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H
M92!M;VYT:"XB"FUS9W-T<B`B26YT<F]D=>]U('5N82!D871A(';@;&ED82P@
M8V]M<')O=F5U(&5L<R!D:65S('%U92!TZ2!E;"!M97,N(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(T-#D*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED
M('1I;64N(@IM<V=S='(@(DEN=')O9'7O=2!U;F$@:&]R82!VX&QI9&$N(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE
M87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R
M(")0<F]P;W)C:6]N974@=6X@<F5S=6T@9&5L('!R;V)L96UA+B(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3@@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHR,@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M
M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B4')O<&]R8VEO;F5U(&5L(&YO;2!D
M)W5S=6%R:2!I(&QA(&-O;G1R87-E;GEA(@H*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+V%G<F5E;65N=%]T;W`N:6YC.C$R"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N
M("!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*
M(G-Y<W1E;2XB"FUS9W-T<B`B(@HB3&QE9VEU(&5L('1E>'0@<V5G_&5N="X@
M2&5U(&0G86-C97!T87(@;&5S(&-O;F1I8VEO;G,@<&5R('!O9&5R('5T:6QI
M='IA<B!E;"`B"B)S:7-T96UA+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M-PIM<V=I9"`B4&QE87-E(')E<&]R="!A;GD@8G5G<R!T;R!I,3AN0&QI<W1S
M+FAO<F1E+F]R9RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@(E!L96%S92!T>7!E('1H92!N
M97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B5&5C;&5G974@96P@;F]M(&1E
M(&QA(&YO=F$@8V%T96=O<FEA.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDY(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$X.`IM<V=I9"`B4&]L86YD(@IM<V=S='(@
M(E!O;/)N:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@
M(E!O;&ET:6-S(@IM<V=S='(@(E!O;.UT:6-A(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0R-0IM<V=I9"`B4&]L;',B"FUS9W-T<B`B16YQ=65S
M=&5S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Y,PIM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B4&]R='5G86PB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS
M9W-T<B`B0V]LMVQO8V%C:?,@9"=A<75E<W1A(&EM871G92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0
M;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(D-O;+=L;V-A8VGS
M(&0G87%U97-T82!T875L82(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N
M9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(D5N=FEA<B!A(&%Q=65S=&$@8V%R
M<&5T82`H;F\@:&D@;V)L:6=A($E-05`I(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR-C0@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-CD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B
M"FUS9W-T<B`B4')E8VEP:71A8VGS(&1U<F%N="!L82!D87)R97)A("5S(&AO
M<F$@;R!H;W)E<SH@(@H*(SH@;&EB+TAO<F1E+U!R969S+VQD87`N<&AP.CDX
M"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7VQD87`Z($YO(',G:&$@=')O8F%T
M(&PG97AT96YS:?,@3$1!4"!S;VRW;&EC:71A9&$N(@H*(SH@;&EB+TAO<F1E
M+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!2
M97%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(E!R969S7W-E<W-I;VXZ($YO(',G:&$@=')O8F%T(&PG97AT96YS:?,@9&4@
M<V5S<VGS('-O;+=L:6-I=&%D82XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(R,PIM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B4')E<W-I\R(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C4W"FUS9VED(")0<F5S<W5R92!A="!S96$@
M;&5V96PZ("(*;7-G<W1R(")0<F5S<VGS(&%L(&YI=F5L;"!D96P@;6%R.B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C<*;7-G:60@(E!R
M97-S=7)E.B`B"FUS9W-T<B`B4')E<W-I\SH@(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$X.`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R
M979I97<B"FUS9W-T<B`B5FES=6%L:71Z86-I\R!P<NAV:6$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C0*;7-G:60@(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*
M;7-G<W1R(")6:7-U86QI='IA<B!P<NAV:6%M96YT(&QA(&EM871G92!E;B!U
M;F$@;F]V82!F:6YE<W1R82(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z
M,S4X(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S8R"FUS9VED(")0<F5V:6]U
M<R!O<'1I;VYS(@IM<V=S='(@(D]P8VEO;G,@<'+H=FEE<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R
M:6YT(&1O8W5M96YT(@IM<V=S='(@(DEM<')I;6ER(&5L(&1O8W5M96YT(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")0<FEV871E
M($ME>2(*;7-G<W1R(")#;&%U('!R:79A9&$B"@HC.B!L:6(O2&]R9&4O365N
M=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(E!R;V)L96UA(@H*
M(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(W"FUS9VED(")0<F]B;&5M($1E
M<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:7!C:?,@9&5L('!R;V)L96UA(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q,0IM<V=I9"`B4')O:F5C
M=',B"FUS9W-T<B`B4')O:F5C=&5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(Q,3$@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.#@*;7-G:60@(E!R;VUP="!T
M97AT(@IM<V=S='(@(E1E>'0@:6YD:6-A9&]R(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(D-L
M874@</IB;&EC82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0U
M"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R(")!;&=O<FES
M;64@9&4@8VQA=2!P^F)L:6-A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HV-#0*;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R("));F9O
M<FUA8VGS(&1E(&-L874@</IB;&EC82(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C(S,`IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@
M9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B3F\@<R=H82!G96YE
M<F%T(&-O<G)E8W1A;65N="!L82!P87)E;&QA(&1E(&-L875S('#Z8FQI8V$O
M<')I=F%D82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.3$*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(E!U97)T
M;R!2:6-O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Y-@IM<V=I9"`B46%T87(B"FUS9W-T<B`B46%T87(B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z-C(*;7-G:60@(E%U97)Y(@IM<V=S='(@(D-O
M;G-U;'1A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS
M9W-T<B`B0VQA=2!P^F)L:6-A(%)302`H)60@8FET*2(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,C8T"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T
M<B`B0F]T\R!D92!S96QE8V-I\R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")286EN(@IM<V=S='(@(E!L=6IA
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*
M;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B4&QU:F$@82!P<FEM97)A(&AO
M<F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M,@IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(E!L=6IA(&-A<"!A;"!T87)D
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*
M;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(E)U:7AA="(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN
M(&%N9"!3;F]W(@IM<V=S='(@(E!L=6IA(&D@;F5W(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6X@=&\@
M4VYO=R(*;7-G<W1R(")!:6=U86YE=2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R(")$:71A(&%L
M96%T\G)I82(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<S
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8X"FUS9VED(")2871I
M;R(*;7-G<W1R(")296QA8VGS(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR
M.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T<B`B3&QE9VEU(@H*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"FUS9VED(")296%D(&UE
M<W-A9V5S(@IM<V=S='(@(DQL96=I=2!E;',@;6ES<V%T9V5S(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN
M;W0@8F4@=6YD;VYE+B(*;7-G<W1R(")#;VYF:7)M974@<75E('9O;&5U('-U
M<')I;6ER("5S/R!!<75E<W1A(&]P97)A8VGS(&YO(&5S('!O="!D97-F97(N
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,L('!H
M<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U
M<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G
M<W1R("(B"B)#;VYF:7)M974@<75E('9O;&5U('-U<')I;6ER(&QE<R!D861E
M<R!D92!L)W5S=6%R:2!P97(@82!L)W5S=6%R:2`E<S\@(@HB07%U97-T82!O
M<&5R86-I\R!N;R!E<R!P;W0@9&5S9F5R+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R
M(&QA<W0@86-T:6]N(@IM<V=S='(@(E1O<FYA(&$@9F5R(&QA(&1A<G)E<F$@
M86-C:?,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Q"FUS9VED(")2
M969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B4F5F<F5S
M8V%R(&5L<R!E;&5M96YT<R!D96P@;65N^B!D:6[@;6EC<R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,S$*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I
M97<Z(@IM<V=S='(@(E)E9G)E<V-A<B!L82!V:7-U86QI='IA8VGS(&1E;"!P
M;W)T86PB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DT(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,C$S(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,U"FUS9VED(")2
M96=E>"(*;7-G<W1R(")%>'!R97-S:?,@<F5G=6QA<B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HS,C0W"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*
M;7-G<W1R(").879E9V%D;W(@9&4@<F5L86-I;VYS(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,C0*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B0V]M96YT
M87)I<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,30*;7-G:60@(E)E
M;6]T92!397)V97)S(@IM<V=S='(@(E-E<G9I9&]R<R!R96UO=',B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!5
M4DP@*&AT='`Z+R]W=W<N97AE;7!L92YE<R]H;W)D92DZ(@IM<V=S='(@(E52
M3"!R96UO="`H:'1T<',Z+R]W=W<N97AE;7!L92YE<R]H;W)D92DZ(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ-2!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"FUS9VED(")296UO=F4B"FUS9W-T
M<B`B4W5P<FEM:7(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M,3$*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R(")3=7!R:6UI<B!B;&]C
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R.0IM
M<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")3=7!R:6UI<B!C;VQU;6YA
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M,`IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`B4W5P<FEM:7(@
M;&$@9F]R;6%T86-I\R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M,3,V"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R(")3=7!R:6UI<B!L82!P
M87)E;&QA(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P-0IM<V=I9"`B
M4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D
M:7)E8W1O<GDN(@IM<V=S='(@(E-U<')I;6ER(&QA('-E<?SH;F-I82!D97-A
M9&$@9&5L(&1I<F5C=&]R:2!T96UP;W)A;"!D96P@<V5R=FED;W(N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0Q"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(E-U<')I;6ER(&5L(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0Y"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M
M96YT(@IM<V=S='(@(E-U<')I;6ER(&%Q=65S="!N;V1E(&1E;"!D;V-U;65N
M="(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,38*;7-G
M:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(E-U<')I;6ER(&PG=7-U87)I(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHW"B,L('!H<"UF
M;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R(")3=7!R:6UI
M<B!L)W5S=6%R:3H@)7,B"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z
M,3,X"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U
M<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R(").;R!S)VAA('!O9W5T(')E<W!O
M;F1R92!A(&QA('-O;+=L:6-I='5D+B!#;V1I(&0G97)R;W(@<F5T;W)N870Z
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#D*;7-G:60@
M(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T
M<B`B3F\@<R=H82!T<F]B870@96P@<V5R=F5I('-O;+=L:6-I=&%T+B(*"B,Z
M(&QI8B](;W)D92YP:'`Z,3<T(&QI8B](;W)D92YP:'`Z-#@W"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"`G)7,G(&YO="!S<&5C:69I
M960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3F\@<R=H82!E<W!E
M8VEF:6-A="!E;"`G)7,G(&YE8V5S<V%R:2!E;B!L82!C;VYF:6=U<F%C:?,@
M9&4@)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<T-R!L:6(O5D93+W-Q;"YP
M:'`Z-3DW(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<Q,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@)R5S)R!N;W0@<W!E8VEF:65D(&EN
M(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").;R!S)VAA(&5S<&5C:69I
M8V%T(&5L("<E<R<@;F5C97-S87)I('!E<B!A(&QA(&-O;F9I9W5R86-I\R!6
M1E,N(@H*(SH@;&EB+TAO<F1E+U5T:6PN<&AP.C<X-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@)R5S)R!N;W0@<W!E8VEF:65D(&EN
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DYO(',G:&$@97-P96-I9FEC870@
M96P@)R5S)R!N96-E<W-A<FD@<&5R(&$@;&$@8V]N9FEG=7)A8VGS+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,C@*;7-G:60@(E)E<75I
M<F5D($9I96QD(@IM<V=S='(@(D-A;7`@<V]LMVQI8VET870B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,Y(&QI8B](;W)D
M92]&;W)M+U)E;F1E<F5R+G!H<#HS,34*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHT-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,3`Q"FUS9VED(")297-E="(*;7-G<W1R(")296EN:6-I82(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E="!087-S=V]R
M9"(*;7-G<W1R(")296EN:6-I87(@;&$@8V]N=')A<V5N>6$B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!0
M87-S=V]R9"(*;7-G<W1R(")296EN:6-I87(@;&$@8V]N=')A<V5N>6$B"@HC
M.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE;&PN<&AP.C(X
M(&%D;6EN+W-Q;'-H96QL+G!H<#HV-0IM<V=I9"`B4F5S=6QT<R(*;7-G<W1R
M(")297-U;'1A=',B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#(Q"FUS9VED
M(")297-U;'1S("AI;F-L=61I;F<@2&]R9&4I.B(*;7-G<W1R("(B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z.#$Y"B,L(&9U>GIY"FUS9VED(")297-U;'1S
M.B(*;7-G<W1R(")297-U;'1A=',B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z,3`R('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@
M(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(E1O<FYA(&$@;W!C:6]N<R(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.3<*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B4F5U;FGS(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X
M"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")297-T875R
M87(@;&$@8V]N9FEG=7)A8VGS(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S,`IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@
M(D]P8VEO;G,@9&4@;"=E9&ET;W(@9&4@=&5X="!E;G)I<75I="(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R
M(")%;FEG;65S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R(")$<F5T82(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3$Y"FUS9VED(")2:6=H="!H96%D
M97(B"FUS9W-T<B`B0V%PYV%L97)A(&1R971A(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,Q,34*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R(")686QO
M<G,@9&4@;&$@9')E=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE
M<RXN+B(*;7-G<W1R(")0<F]P:65T871S(&1E(&QA(&9I;&$N+BXB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L
M92(*;7-G<W1R(")&=6YC:?,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3DX"FUS9VED(")2;VUA;FEA(@IM<V=S='(@
M(E)O;6%N:6$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C`X"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(D=I<F%R(#$X,"(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,#4*;7-G
M:60@(E)O=&%T92!,969T(@IM<V=S='(@(D=I<F%R(&$@;"=E<W%U97)R82(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,3$*;7-G
M:60@(E)O=&%T92!2:6=H="(*;7-G<W1R(")':7)A<B!A(&QA(&1R971A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B4')O<&EE=&%T
M<R!D92!L82!F:6QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS
M9W-T<B`B4')O<&EE=&%T<R!D92!L82!F:6QA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM
M<V=S='(@(D9I;&5S.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM<V=S='(@(E)E
M9VQE<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@
M86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B07!A<F5I>&5R86X@<F5G
M;&5S(&5N=')E('1O=&5S(&QE<R!F:6QE<R!I(&-O;'5M;F5S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM
M<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB
M"FUS9W-T<B`B07!A<F5I>&5R86X@<F5G;&5S(&YO;>ES(&5N=')E(&-O;'5M
M;F5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R
M;W=S(&]N;'DB"FUS9W-T<B`B07!A<F5I>&5R86X@<F5G;&5S(&YO;>ES(&5N
M=')E(&9I;&5S(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,0IM<V=I9"`B
M4G5N(@IM<V=S='(@(D5X96-U=&%R(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y.0IM<V=I9"`B4G5S<VEA;B!&961E
M<F%T:6]N(@IM<V=S='(@(D9E9&5R86-I\R!2=7-S82(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#`*;7-G:60@(E)W
M86YD82(*;7-G<W1R(")2=V%N9&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T
M=7)E(@IM<V=S='(@(E-I9VYA='5R82!C<FEP=&]G<N!F:6-A(&%M8B!3+TU)
M344B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B
M4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(DUI<W-A=&=E('AI
M9G)A="!A;6(@4R]-24U%(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z
M.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B3"=A=71E;G1I8V%C:?,@4T%33"!N;R!E<W3@(&1I<W!O
M;FEB;&4N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U,`IM<V=I
M9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R(")-:7-S871G97)I82!335,B"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G
M<W1R("));G3H<G!R970@9"=O<F1R97,@4U%,(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,V,0IM<V=I9"`B4U-((@IM<V=S='(@(E-32"(*"B,Z
M(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS
M-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R("+(6$E4(@H*(SH@;&EB+V%P:2YP
M:'`Z,3,R"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(DEN=.AR<')E="!D
M)V]R9')E<R!344PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R(")$<RXB"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$X.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`W"FUS9VED
M(")386EN="!(96QE;F$B"FUS9W-T<B`B4V%I;G0@2&5L96YA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Y,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,Q"FUS9VED
M(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B4V%I;G0@0VAR:7-T
M;W!H97(@:2!.979I<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$S.0IM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B
M4V%I;G0@3'5C:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3@Y"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E
M;&]N(@IM<V=S='(@(E-A:6YT+5!I97)R92UE="U-:7%U96QO;B(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DS"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#0*;7-G
M:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@
M(E-A:6YT(%9I;F-E;G0@:2!L97,@1W)E;F%D:6YE<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@
M9G)A;64@*%]S96QF*2(*;7-G<W1R(")-871E:7@@;6%R8R`H7W-E;&8I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.30*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U
M,0IM<V=I9"`B4V%M;V$B"FUS9W-T<B`B4V%M;V$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Y-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$R"FUS9VED(")386X@
M36%R:6YO(@IM<V=S='(@(E-A;B!-87)I;F\B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y
M-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$V"FUS9VED(")386\@5&]M
M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B4V%O(%1O;>D@:2!0<NUN8VEP92(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL
M:71E(%!R;W9I9&5R(@IM<V=S='(@(E!R;W9E[V1O<B!D92!S873H;+=L:70B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C`Q"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B07+@8FEA(%-A=61I
M=&$B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3@*;7-G:60@
M(E-A=F4B"FUS9W-T<B`B1&5S82(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,C$V"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T
M<B`B1&5S82`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI
M;F,Z-#D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F4@)R5S)R(*
M;7-G<W1R(")$97-A("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z
M-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(D1E<V$@;&5S(&]P8VEO
M;G,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<P"FUS9VED("(B"B)3
M879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T
M;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S
M='(@(B(*(D1E<V5U(&QA(&-O;F9I9W5R86-I\R!G96YE<F%D82!C;VT@=6YA
M('-E<?SH;F-I82!02%`@96X@96P@9&ER96-T;W)I("(*(G1E;7!O<F%L(&1E
M;"!S97)V:61O<BXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HV.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R(")3)VAA(&1E<V%T(&QA(&-O;F9I9W5R86-I\R!D92`E<RXB"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("<E
M<R<N(@IM<V=S='(@(E,G:&$@9&5S870@;&$@<V5Q_.AN8VEA(&%C='5A;&ET
M>F%D82!D92!C;VYF:6=U<F%C:?,@83H@)R5S)RXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4V-A='1E<F5D
M(%0M4W1O<FUS(@IM<V=S='(@(E1E;7!E<W1E<R!D:7-P97)S97,B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T
M<B`B0VGH;F-I82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")3
M96%R8V@B"FUS9W-T<B`B0V5R8V$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C<V"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R(")-;W1O
M<G,@9&4@8V5R8V$B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,30T.`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V5A<F-H:6YG($AO<F1E(&%P<&QI
M8V%T:6]N<R!I;B`E<R(*;7-G<W1R(")/<&-I;VYS(&1E(&-E<F-A(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$R,PHC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H
M:6YG(&=E='1E>'0@8FEN87)I97,N+BXB"FUS9W-T<B`B3W!C:6]N<R!D92!C
M97)C82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.3<Q"FUS9VED(")396QE
M8W0@1FEL97,B"FUS9W-T<B`B4V5L96-C:6]N87(@96QS(&%R>&EU<R(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-38*;7-G:60@
M(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B4V5L96-C:6]N87(@=6YA(&1A=&$B
M"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L
M96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(E-E;&5C8VEO;F%R('5N(&=R
M=7`@<75E('9U;&=U974@869E9VER(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@
M(E-E;&5C8VEO;F5U('5N(&YO=2!P<F]P:65T87)I(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V97(B
M"FUS9W-T<B`B4V5L96-C:6]N974@=6X@<V5R=FED;W(B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T
M;R!A9&0B"FUS9W-T<B`B4V5L96-C:6]N974@=6X@=7-U87)I('%U92!V=6QG
M=65U(&%F96=I<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-C8Q"FUS9VED
M(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B4V5L96-C
M:6]N974@=&]T<R!E;',@96QE;65N=',@9&4@;&$@9&%T82XB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#$Q"FUS9VED(")396QE
M8W0@86X@;V)J96-T(@IM<V=S='(@(E-E;&5C8VEO;F5U('5N(&]B:F5C=&4B
M"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C
M="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO
M=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T
M:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B)396QE8V-I;VYE=2!E;',@8V%R
MX&-T97)S('%U92!N96-E<W-I=&5U(&1E(&QE<R!C87-E;&QE<R!D92!S;W1A
M+B!0;V1E=2`B"B)C;W!I87(M;&]S(&D@96YG86YX87(M;&]S(&1E(&PGX')E
M82!D92!T97AT+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS
M9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R(")396QE
M8V-I;VYA<B!E;"!D96QI;6ET861O<B!D92!L82!D871A.B(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@
M9F]R;6%T.B(*;7-G<W1R(")396QE8V-I;VYA<B!E;"!F;W)M870@9&4@;&$@
M9&%T83HB"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC
M.C@Y"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H
M86YG93HB"FUS9W-T<B`B4V5L96-C:6]N87(@;&$@:61E;G1I=&%T('%U92!V
M;VQE=2!Q=64@8V%N=FEA<CHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN
M8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T
M<B`B4V5L96-C:6]N87(@96P@9&5L:6UI=&%D;W(@9&4@;"=H;W)A.B(*"B,Z
M('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE
M('1I;64@9F]R;6%T.B(*;7-G<W1R(")396QE8V-I;VYA<B!E;"!F;W)M870@
M9&4@;"=H;W)A.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C0*
M;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R(")3
M96QE8V-I;VYA<B!D;W,@8V%M<',@<75E(&-O:6YC:61E:7AI;BXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDV"FUS9VED(")396QE8W0@>6]U<B!C
M;VQO<B!S8VAE;64N(@IM<V=S='(@(E-E;&5C8VEO;F%R(&QA(&-O;6)I;F%C
M:?,@9&4@8V]L;W)S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S@*
M;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T
M<B`B4V5L96-C:6]N87(@;"=I9&EO;6$@<')E9F5R:70Z(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE
M;2!297!O<G0B"FUS9W-T<B`B16YV:6%R(&PG:6YF;W)M92!D96QS('!R;V)L
M96UE<R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY
M-C$*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(D5N=FEA<B!335,B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Y.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$S"FUS
M9VED(")396YE9V%L(@IM<V=S='(@(E-E;F5G86PB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,Q-`IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B4V5N<V]R
M.B`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@R
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3D*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B
M4V5P=&5M8F5R(@IM<V=S='(@(E-E=&5M8G)E(@H*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE
M9W)O(@IM<V=S='(@(E/H<F)I82!I($UO;G1E;F5G<F\B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*
M;7-G<W1R(").^FUE<F\@9&4@<^AR:64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,34S"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R("),97,@9&%D97,@9&5L('-E<G9I9&]R
M('/S;B!I;F-O<G)E8W1E<R!O(&YO(&5S=&%N(&1I<W!O;FEB;&5S+B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")3
M97-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(DAA(&-A9'5C870@;"=I9&5N
M=&EF:6-A9&]R(&1E('-E<W-I\RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C,Q,@IM<V=I9"`B4V5T(@IM<V=S='(@(D1E9FEN96EX(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<V"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO
M=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G
M970@:70N(@IM<V=S='(@(B(*(D1E9FEN96EX(&QE<R!O<&-I;VYS('%U92!U
M<R!P97)M971E;B!R96EN:6-I87(@;&$@8V]N=')A<V5N>6$@<VD@;6%I("(*
M(FPG;V)L:61E=2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS
M9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A
M8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B1&5F:6YI=2!E;',@
M<V5R=FED;W)S(')E;6]T<R!A('%UZ"!V;VQE=2!A8V-E9&ER(&1E<R!D96P@
M<&]R=&%L+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`IM<V=I9"`B
M4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T
M92!O<'1I;VYS+B(*;7-G<W1R("(B"B)$969I;FEU(&5L('9O<W1R92!I9&EO
M;6$@<')E9F5R:70L(&QA('IO;F$@:&]RX')I82!I(&QE<R!O<&-I;VYS(&1E
M(&1A=&$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX"FUS9VED("(B
M"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L
M('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N
M<RXB"FUS9W-T<B`B(@HB1&5F:6YI=2!L)V%P;&EC86-I\R!D)VEN:6-I+"!L
M82!C;VUB:6YA8VGS(&1E(&-O;&]R<RP@96P@<F5F<F5S8V%M96YT(&1E(&QE
M<R`B"B)PX&=I;F5S(&D@86QT<F5S(&]P8VEO;G,@9&4@=FES=6%L:71Z86-I
M\RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<T"FUS9VED(")3971U
M<"(*;7-G<W1R(")#;VYF:6=U<F%C:?,B"@HC.B!T96UP;&%T97,O861M:6XO
M<V5T=7`O:6YD97@N:'1M;#HS.0IM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I
M<'1S(&%V86EL86)L92(*;7-G<W1R(")(:2!H82!S97'\Z&YC:65S(&0G86-T
M=6%L:71Z86-I\R!D92!L82!C;VYF:6=U<F%C:?,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3<X"FUS9VED(")3979E<F%L(&QO8V%T:6]N
M<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R(")(:2!H
M82!D:79E<G-E<R!U8FEC86-I;VYS('!O<W-I8FQE<R!A;6(@96P@<&%RX&UE
M=')E.B`B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C`S"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(E-E>6-H96QL
M97,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0R"FUS9VED(")3
M:&]P<&EN9R(*;7-G<W1R(")#;VUP<F5S(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T
M<B`B4F5S=6T@8G)E=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,S8*
M;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T
M(&QI;FMS/R(*;7-G<W1R(")6;VQE=2!D969I;FER(&QE<R!C;&%U<R!D)V%C
M8^ES('!E<B!A(&QA(&UA:F]R('!A<G0@9"=E;FQL8>=O<S\B"@HC.B!L:6(O
M2&]R9&4O4&5R;7,N<&AP.C(Y,B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R
M(")-;W-T<F$B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34X"FUS9VED
M("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D
M(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(DUO<W1R82!L97,@9&EF97+H;F-I97,@96YT<F4@;&$@8V]N9FEG
M=7)A8VGS(&1E<V%D82!I(&QA(&YO=F$N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0X,`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L
M;V=G:6YG(&EN/R(*;7-G<W1R(")6;VQE=2!V:7-U86QI='IA<B!L)VAO<F$@
M9&4@;&$@9&%R<F5R82!S97-S:?,@96X@:6YI8VEA<C\B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3<V.0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O
M<FEG:6YA;"(*;7-G<W1R(")-;W-T<F$@;"=O<&-I\R!D92!C;VYS97)V87(@
M;"=O<FEG:6YA;"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#$Q"FUS9VED
M(")3:&]W('!I8VME<B(*;7-G<W1R(")-;W-T<F$@96P@8V%P='5R861O<B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,34*;7-G:60@(E-H;W<@=&%B
M;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B5F]L974@=FES=6%L
M:71Z87(@;&$@8F%R<F$@9&4@;65N^B!D)V]P97)A8VEO;G,@9&4@=&%U;&$_
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R
M(")6;VQE=2!V:7-U86QI='IA<B!E;"!M96[Z("5S(&1E(&PG97-Q=65R<F$_
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4X"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I
M97,@9&EA;&]G(@IM<V=S='(@(DUO<W1R82!E;"!D:>!L96<@9&4@<')O<&EE
M=&%T<R!D92!C96RW;&$@9&4@=&%U;&$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(E-H;W<@
M=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(DUO<W1R82!E
M;"!D:>!L96<@9&4@<')O<&EE=&%T<R!D92!T875L82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I
M9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S
M='(@(DUO<W1R82!E;"!D:>!L96<@9&4@<')O<&EE=&%T<R!D92!F:6QA(&1E
M('1A=6QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4Q"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T
M:65S(&1I86QO9R(*;7-G<W1R(")-;W-T<F$@96P@9&G@;&5G(&1E('!R;W!I
M971A=',@9&4@:6UA=&=E(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C<*
M;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(DUO<W1R82!L82!CX')R96=A
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*
M;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B4G5I>&%T<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")3:&]W97)S
M($5A<FQY(@IM<V=S='(@(E)U:7AA=',@82!P<FEM97)A(&AO<F$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B
M4VAO=V5R<R!,871E(@IM<V=S='(@(E)U:7AA=',@8V%P(&%L('1A<F0B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I
M9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B4G5I>&%T<R!A
M(&QA(')O9&%L:6$B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HS
M.3D*;7-G:60@(E-H<FEN:R(*;7-G<W1R(")2961U[W4B"@HC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+G!H<#HV.3(@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="YP:'`Z-S4T"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C@Q,B!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HX-S0*(SH@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="YP:'`Z.3`Y(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP
M.CDT-@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HY-S0@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="YP:'`Z,3`P-`IM<V=I9"`B4VAR:6YK(&]R(&UO
M=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T
M(@IM<V=S='(@(E!R:6UE<B!R961U[W4@;R!A<&%R=&5U(&5L*',I(&)L;V,H
M<RD@9&5L(&-O<W1A="(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,3$*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R
M(")3:65R<F$@3&5O;F4B"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP
M.C(V-0IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R(")$;VYE=2UV;W,@9"=A;'1A
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B4VEG
M;B!U<"!I9B!N;W0@<F5G:7-T97)E9"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E(@IM<V=S
M='(@(E-I9VYA='5R82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-S$Q"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(D%L9V]R
M:7-M92!D92!S:6=N871U<F$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C`V"FUS9VED(")3:6YG87!O<F4B"FUS9W-T
M<B`B4VEN9V%P=7(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DV(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,C$U(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,W"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,C0V(&QI8B](;W)D92]&;W)M+G!H<#HR
M.3(X(&QI8B](;W)D92]&;W)M+G!H<#HS,3(Q"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8Y(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN
M<&AP.C@W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8U"FUS
M9VED(")3:7IE(@IM<V=S='(@(DUI9&$B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O8V]N9FER;5]B;W1T;VTN:6YC.CD*;7-G:60@(E-K:7`@36%I;G1E
M;F%N8V4B"FUS9W-T<B`B3VUE="!M86YT96YI;65N="(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HT,S$@<&\O=')A;G-L871I;VXN<&AP.C0X-"!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-C8V"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX-C`@<&\O
M=')A;G-L871I;VXN<&AP.C$R,C,*;7-G:60@(E-K:7!P960N+BXB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(Q,`IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B17-L;W;@<75I82(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,#@*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(D5S;&]VZ&YI82(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")3
M;F]W(@IM<V=S='(@(DYE=F%D82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R
M(")8X&9E8R!D92!N974B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU,PIM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(EC@
M9F5C<R!D92!N974B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU-`IM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@
M(EC@9F5C<R!D92!N974@82!P<FEM97)A(&AO<F$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R!3:&]W
M97)S($QA=&4B"FUS9W-T<B`B6.!F96-S(&1E(&YE=2!C87`@86P@=&%R9"(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<V"FUS9VED(")3;F]W(&1E<'1H
M.B`B"FUS9W-T<B`B1W)U:7@@9&4@;F5U.B`B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(X,`IM<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B
M"FUS9W-T<B`B17%U:79A;&5N="!D92!L82!N974@96X@86EG=6$Z("(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#(*
M;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R("));&QE<R!386QO;?,B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(P-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C$T"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(E-O;>!L:6$B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS
M9W-T<B`B0V%NYV]N<R!I('!O96UE<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR.3(T"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R(")3
M96QE8V-I\R!E;B!E;"!S96YT:70@9&4@;&$@8VQA<W-I9FEC86-I\R(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$V(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0V"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-3@@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4X.`IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B061R
M9>=A(&0G;W)I9V5N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(U-0IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@
M(E-U9"W@9G)I8V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I
M9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(E-U9"UE
M=7)O<&5U("A)4T\M.#@U.2TS*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$P,0IM<V=I9"`B4V]U=&@@1V5O<F=I82!A
M;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B1V7R<F=I
M82!D96P@4W5D(&D@;&5S(&EL;&5S(%-A;F1W:6-H(&1E;"!3=60B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS
M9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(DAE;6ES9F5R:2!S
M=60B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G
M<W1R(")%<W!A:2!E;G1R92!C96RW;&5S(&%D:F%C96YT<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3
M<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S
M='(@(D5S<&%I(&5N=')E(&5L(&-O;G1I;F=U="!I(&5L(&-O;G1O<FX@9&4@
M;&$@8V5LMVQA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Q-0IM<V=I9"`B
M4W!A8V5R(@IM<V=S='(@(D5S<&%I861O<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN
M9R(*;7-G<W1R(")%<W!A:6%T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@
M<&%D9&EN9R(*;7-G<W1R(")%<W!A:6%T(&D@9F%R8VEM96YT(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(P.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#`*;7-G:60@
M(E-P86EN(@IM<V=S='(@(D5S<&%N>6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z.38*;7-G:60@(E-P86TB"FUS9W-T<B`B0V]R<F5U(&)R;W-S
M82(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA
M;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B17-C<FEP='5R82!D92!C87+@
M8W1E<G,@97-P96-I86QS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G
M<W1R(")$:79I9&ER(&-E;+=L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M
M;B(*;7-G<W1R(")$:79I9&ER(&-O;'5M;F$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI
M="!R;W<B"FUS9W-T<B`B1&EV:61I<B!F:6QA(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`B17-P;W)T<R(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,3`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T
M,0IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(E-R:2!,86YK82(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,B!L:6(O0FQO8VLO;65T87(N
M<&AP.C<R"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R(")%<W3@;F1A<F0B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*
M;7-G<W1R(")3=&%R(%1R96LB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y
M-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@P-PIM<V=I9"`B4W1A<G0@>65A<B(*
M;7-G<W1R(")!;GD@9"=I;FEC:2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3<P"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R(")%
M<W1A="!O('!R;W;M;F-I82(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I
M;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B17-T870B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#DQ"B,L('!H<"UF;W)M870*;7-G:60@
M(E-T871U<R!F;W(@;&]C86QE("5S+BXN("(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C@Q,PIM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS
M9W-T<B`B1F]R;6%T(&0G96UM86=A='IE;6%T9V4B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4W,@IM<V=I9"`B4W1R965T($%D9')E<W,B"FUS
M9W-T<B`B061R9>=A('!A<G1I8W5L87(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H
M(@IM<V=S='(@(D)A<G)A="(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,S
M"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R("),;&ES=&$@9&4@8V%D96YE
M<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I<"!D
M;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R(")%;&EM:6YE=2!E;"!D
M;VUI;FD@9&4@;"=A9')EYV$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*
M;7-G<W1R(")%<W1I;"!;0U-372(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(D1G+B(*
M"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y("<E<R<@;F]T(&9O=6YD+B(*;7-G
M<W1R(").;R!S)VAA('1R;V)A="!E;"!S=6)D:7)E8W1O<FD@("<E<R<N(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@
M(E-U8FIE8W0B"FUS9W-T<B`B07-S=6UP=&4B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S,R(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,3(*;7-G
M:60@(E-U8FUI="(*;7-G<W1R(")%;G9I82(*"B,Z('-I9VYU<"YP:'`Z-#D*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U
M97-T('1O(&%D9"`G)7,G('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO
M9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N
M(@IM<V=S='(@(B(*(E,G:&$@=')A;>AS('5N82!S;VRW;&EC:71U9"!P97(@
M869E9VER("<E<R<@86P@<VES=&5M82X@3F\@<&]D974@:6YI8VEA<B!L82`B
M"B)S97-S:?,@9FEN<R!Q=64@<R=H86=I(&%P<F]V870@;&$@<V]LMVQI8VET
M=60N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(E-U8NUN9&5X(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$P-2!L:6(O2&]R9&4O3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T
M<B`BR'AI="(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@)R5S)R!T;R!T:&4@
M<WES=&5M+B(*;7-G<W1R(")3)VAA(&%F96=I="!C;W)R96-T86UE;G0@)R5S
M)R!A;"!S:7-T96UA+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T
M82!F;W(@=7-E<B`G)7,G(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B4R=H
M86X@96QI;6EN870@8V]R<F5C=&%M96YT(&1E;"!S:7-T96UA(&QE<R!D861E
M<R!D92!L)W5S=6%R:2`G)7,G+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#$@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HV,0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@)R5S)RXB"FUS9W-T<B`B
M4R=H82!S=7!R:6UI="!C;W)R96-T86UE;G0@)R5S)RXB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!R96UO=F5D("<E<R<@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R
M(")3)VAA('-U<')I;6ET(&-O<G)E8W1A;65N="`G)7,G(&1E;"!S:7-T96UA
M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E
M<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E
M(&-H86YG97,N(@IM<V=S='(@(B(*(E,G:&$@<F5S=&%U<F%T(&-O<G)E8W1A
M;65N="!L82!C;VYF:6=U<F%C:?,N($%C='5A;&ET>F5U('!E<B!V975R92!E
M;',@(@HB8V%N=FES+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4U
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.0IM<V=I9"`B4W5C8V5S<V9U;&QY
M('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")3)VAA(&1E
M<V%T(&-O<G)E8W1A;65N="!L82!C;VYF:6=U<F%C:?,@9&4@8_)P:6$N(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N(&9I;&4@)7,N(@IM<V=S='(@(E,G:&$@9&5S870@8V]R<F5C=&%M96YT
M(&PG87)X:74@9&4@;&$@8V]N9FEG=7)A8VGS(&1E(&/R<&EA("5S+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY('5P9&%T960@)R5S)R(*;7-G<W1R(")3)VAA(&%C
M='5A;&ET>F%T(&-O<G)E8W1A;65N="`G)7,G(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C<R(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@
M(E,G:&$@97-C<FET(&-O<G)E8W1A;65N="`G)7,G(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,3$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-`IM<V=I9"`B4W5D
M86XB"FUS9W-T<B`B4W5D86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y(@IM<V=S
M='(@(E)E<W5M(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8V"FUS9VED
M(")3=6X@4FES92(*;7-G<W1R(")3;W)T:61A(&1E;"!S;VPB"@HC.B!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z-S$*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B
M4&]S=&$@9&5L('-O;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4V"FUS9VED(")3=6YN>2(*;7-G<W1R(")!<W-O;&5L;&%T
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P.`IM<V=I9"`B
M4W5N<FES92(*;7-G<W1R(")3;W)T:61A(&1E;"!S;VPB"@HC.B!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G
M:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(E-O<G1I9&$@9&5L('-O;"]0
M;W-T82!D96P@<V]L(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(P-PIM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(E-O<G1I9&$@9&5L('-O
M;#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,0IM<V=I
M9"`B4W5N<V5T(@IM<V=S='(@(E!O<W1A(&1E;"!S;VPB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$P"FUS9VED(")3=6YS970Z("(*;7-G
M<W1R(")0;W-T82!D96P@<V]L.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S
M='(@(E-U<&5R[6YD97@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#,T"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(D%S<VES=.AN8VEA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,3(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-0IM
M<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B4W5R:6YA;2(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3<T"FUS9VED(")3=7)N86UE(@IM<V=S='(@
M(D-O9VYO;2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,#D*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS
M9W-T<B`B4W9A;&)A<F0@:2!*86X@36%Y96XB"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q
M-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$Y"FUS9VED(")3=V%Z:6QA
M;F0B"FUS9W-T<B`B4W=A>FELX&YD:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`U"FUS9VED(")3=V5D96XB"FUS
M9W-T<B`B4W7H8VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-38*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(E-U
M[W-S82(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED
M(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(D5R<F]R
M(&1E('-I;G1A>&D@96X@96QS('1E<FUE<R!D92!C97)C82(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3@*;7-G:60@
M(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(E)E</IB;&EC82#`<F%B
M(%-I<FEA;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU-PIM<V=I9"`B5"U3=&]R;2(*;7-G<W1R(")496UP97-T82(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED
M(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R(")496UP97-T82!I('9E;G3S
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y
M"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R(")496UP97-T97,B"@HC.B!L:6(O
M2&]R9&4O1&%T82]T<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T
M<B`B07)X:74@5%-6(@H*(SH@;&EB+TAO<F1E+U5)+U1A8FQE+G!H<#HQ,S8*
M(RP@9G5Z>GD*;7-G:60@(E1A8FQE(@IM<V=S='(@(E1A=6QA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM
M<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R(")0<F]P:65T871S(&1E
M('1A=6QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R
M(")0<F]P:65T871S(&1E('1A=6QA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S0*;7-G:60@(E1A
M:7=A;B(*;7-G<W1R(")486EW86XB"@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA
M(@IM<V=S='(@(E1A:7=A;BP@<')O=NUN8VEA(&1E(&QA(%AI;F$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(Q.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(U"FUS
M9VED(")486II:VES=&%N(@IM<V=S='(@(E1A9&II:VES=&%N(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,C`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-0IM<V=I
M9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R(")486YZ
MX&YI82P@4F5P^F)L:6-A(%5N:61A(&1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G
M<W1R(")/8FIE8W1I=3HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3<Q"FUS9VED(")487-K<R(*;7-G<W1R(")487-Q=65S(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E1E;&5P:&]N92!.=6UB
M97(B"FUS9W-T<B`B3OIM97)O(&1E('1E;.AF;VXB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(X.`IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS
M9W-T<B`B5&5M<&5R871U<F$@9'5R86YT(&QA(&1A<G)E<F$@:&]R83H@(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3(*;7-G:60@(E1E;7!E<F%T=7)E
M(@IM<V=S='(@(E1E;7!E<F%T=7)A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Q-0IM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R(")4
M96UP97)A='5R83H@(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HR,3<*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E("<E<R<@;F]T
M(&9O=6YD+B(*;7-G<W1R(").;R!S)VAA('1R;V)A="!L82!P;&%N=&EL;&$@
M)R5S)RXB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M
M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R86-I\R!D
M92!P;&%N=&EL;&5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,3$*;7-G
M:60@(E1E>'0B"FUS9W-T<B`B5&5X="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-C4*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R(").;VWI<R!T97AT
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R(")!;&EN96%C:?,@
M9&4@=&5X="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B06QI;F5A="!A(&1A
M;'0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C4Y"FUS9VED(")4:"(*;7-G<W1R(")$:BXB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y,0IM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B5&%I
M;&%N9.AS("A425,M-C(P*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,C0*;7-G:60@(E1H86EL86YD(@IM<V=S='(@
M(E1A:6S@;F1I82(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY,#,*;7-G:60@
M(E1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C$P-CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE("5S(&AE;'`@9FEL92!F;W(@)7,@9&]E<VXG="!Y970@97AI<W0N
M($-R96%T:6YG(&$@;F5W(&]N92XB"FUS9W-T<B`B(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C<S-PIM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B3"=E>'1E;G-I\R!&5%`@;F\@97-TX"!D:7-P
M;VYI8FQE+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3`S"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I
M;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B16P@;6]T;W(@
M9"=I;G1E9W)A8VGS($AO<F1E+TMO;&%B(&YO('!E<FUE="!L)_IS(&1E(%PB
M)7-<(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR.0IM<V=I9"`B
M5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F
M=6QL>2(*;7-G<W1R("),82!C;&%S<V4@36%I;G1E;F%N8V4Z.B!N;R!S)VAA
M(&-A<G)E9V%T(&-O<G)E8W1A;65N=",C(@H*(SH@<V5R=FEC97,O:6UA9V5S
M+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W
M(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(E,G:&$@=&%N8V%T(&QA
M(&9I;F5S=')A(&0G;W!C:6]N<RX@4V]R=&EN="!D96P@<VES=&5M82(*"B,Z
M(&QI8B](;W)D92]097)M<RYP:'`Z,34X(&QI8B](;W)D92]097)M<RYP:'`Z
M,38Y(&QI8B](;W)D92]097)M<RYP:'`Z,3@P"B,Z(&QI8B](;W)D92]097)M
M<RYP:'`Z,3DR(&QI8B](;W)D92]097)M<RYP:'`Z,C`S(&QI8B](;W)D92]0
M97)M<RYP:'`Z,C(Q"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,C,S(&QI8B](
M;W)D92]097)M<RYP:'`Z,C<R"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O
M<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@
M8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM
M<V=S='(@(B(*(E-I('9O;&5U('5T:6QI='IA<B!E;',@<&5R;6ES;W,L(&PG
M861M:6YI<W1R861O<B!H82!D92!C;VYF:6=U<F%R('5N(&UO=&]R("(*(F1E
M('!E<FUI<V]S('!E<FUA;F5N="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M
M('-I9&4@;VYL>2(*;7-G<W1R(").;VWI<R!E;"!C;VYT;W)N(&EN9F5R:6]R
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I
M9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D
M+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B
M87-E+B(*;7-G<W1R("(B"B)%;"!N^FUE<F\@:61E;G1I9FEC861O<B!D96P@
M8V]N=&%C=&4@;F\@<R=H82!E<W!E8VEF:6-A="P@<R=H82!D96EX870@96X@
M(@HB8FQA;F,@;R!N;R!S)VAA('1R;V)A="!A(&QA(&)A<V4@9&4@9&%D97,N
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I
M9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R
M(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B4R=H82!A9F5G:70@8V]R<F5C=&%M
M96YT(&5L(&-O;G1A8W1E(&$@;&$@;&QI8G)E=&$@9"=A9')E8V5S+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q-#D*;7-G:60@(B(*(E1H92!D
M971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E
M<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*(D5S(&YE8V5S
M<VET82!E;"!B;&]C(&1E('-I9VYA='5R97,@4$=0('-E<&%R870@<&5R('9E
M<FEF:6-A<B!E;"!M:7-S871G92`B"B)S:6=N870N(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G
M<W1R("(B"B),)VED96YT:69I8V%D;W(@9&4@;&$@;&QI<W1A(&1E(&1I<W1R
M:6)U8VGS(&YO(',G:&$@97-P96-I9FEC870L(',G:&$@9&5I>&%T("(*(F5N
M(&)L86YC(&\@;F\@<R=H82!T<F]B870@82!L82!B87-E(&1E(&1A9&5S+B(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@
M(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS
M9W-T<B`B3F\@<R=H82!E<W!E8VEF:6-A="!L82!L;&ES=&$@9&4@9&ES=')I
M8G5C:?,N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+G!H<#HQ,3,*;7-G:60@(E1H
M92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O
M;FYE8W1I;VXN(@IM<V=S='(@(DQE<R!C87)A8W1E<NUS=&EQ=65S(&1E;"!X
M:69R871G92!E>&EG96EX96X@=6YA(&-O;FYE>&GS('=E8B!F:6%B;&4N(@H*
M(SH@;&EB+TAO<F1E+G!H<#HQ-S4@;&EB+TAO<F1E+G!H<#HT.#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E
M<R!S971T:6YG+B(*;7-G<W1R("),)V%R>&EU("5S(&AA=7)I82!D92!C;VYT
M96YI<B!U;B!P87+@;65T<F4@)7,N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-C@@
M;&EB+TAO<F1E+G!H<#HT-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I
M;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T
M<B`B3"=A<GAI=2`E<R!H875R:6$@9&4@8V]N=&5N:7(@86QG=6YS('!A<N!M
M971R97,@)7,N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ-3(*(RP@9G5Z>GD*
M;7-G:60@(E1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF
M+B(*;7-G<W1R("),)V%R>&EU(&YO(&-O;G1E;FEA(&1A9&5S+B(*"B,Z(&QI
M8B](;W)D92]$871A+G!H<#HR-C`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE
M9"!N;R!D871A+B(*;7-G<W1R("),)V%R>&EU(&YO(&-O;G1E;FEA(&1A9&5S
M+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS
M9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M
M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R("(B"B)!(&-O;G1I;G5A
M8VGS(&5S('!R97-E;G1E;B!L97,@8V%PYV%L97)E<R!D)V%Q=65S="!M:7-S
M871G92]M:7-S871G92!R9F,X,C(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R
M965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E
M<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E
M('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R
M:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC
M=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y
M;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA
M="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@
M86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D
M+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R
M>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"B)3)VAA(&-O
M;G-T871A="!Q=64@96P@;6]D92!D92!P86YT86QL82!C;VUP;&5T82!D\VYA
M('!R;V)L96UE<R!A;6(@26YT97)N970@(@HB17AP;&]R97(@82!C875S82!D
M)V5R<F]R<R!E;B!E;"!N879E9V%D;W(@<75E(&YO(&AE;2!P;V=U="!R97-O
M;&1R92X@4&]T('-E<B`B"B)Q=64@=FES=6%L:71Z974@8G)O<W-A+"!U<R!M
M86YQ=6EN(&9U;F-I;VYS(&5N(&PG961I=&]R(&DO;R!Q=64@96P@;F%V96=A
M9&]R("(*(G5S(&9A;&QI(&1E(&UA;F5R82!A;&5A=/)R:6$N(%-I('1E;FEU
M(&5L('-I<W1E;6$@5VEN9&]W<R`Y>"#I<R!M;VQT("(*(G!R;V)A8FQE('%U
M92!E<R!P<F]D=65I>&D@=6X@)V5R<F]R(&1E('!R;W1E8V-I\R!G96YE<F%L
M)R!I(&AA9W5E=2!D92`B"B)R96EN:6-I87(@9&4@;F]U+B!3:2P@=&]T(&D@
M87%U97-T(&%D=F5R=&EM96YT+"!E;F-A<F$@=F]L974@<')O=F%R(&PG961I
M=&]R("(*(F1E('!A;G1A;&QA(&-O;7!L971A+"!P<F5M974@1"=A8V]R9"XB
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`Y-R!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,3(S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:&5L<"!F:6QE("5S
M(&1I9&XG="!S=&%R="!W:71H(#P_>&UL(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!R969S+G!H<#HX.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E
M;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(E,G:&$@
M<W5P<FEM:70@;&$@:61E;G1I=&%T(%PB)7-<(BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4
M:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R(").;VWI<R!E;"!C;W-T
M870@97-Q=65R<F4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ-#8*
M;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU
M<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R
M("),82!U8FEC86-I\R!D96P@8FEN87)I($=N=5!'(',G:&$@9"=I;F1I8V%R
M(&$@;&$@8VQA<W-E($-R>7!T7W!G<"XB"@HC.B!L:6(O2&]R9&4O34E-12]-
M1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G
M92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E
M96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T
M:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S
M='(@(B(*(E,G:&$@;6]S=')A="!E;"!M:7-S871G92!E;G9I870@96P@)7,@
M82`E<R!A;6(@;"=A<W-U;7!T92!<(B5S7"(N($%I>/(@;F\@(@HB9V%R86YT
M96EX('%U92!S)VAA9VD@;&QE9VET(&\@96YTZ',@96P@;6ES<V%T9V4N(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S<*;7-G:60@(E1H92!N86UE('1O
M('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R
M(")%;"!N;VT@<75E(',G:&$@9"=U=&EL:71Z87(@96X@96YL;&'G87(@86UB
M($-R96%R('#@9VEN82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M,3(S,0IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O
M<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B17,@
M;F5C97-S:71A(&5L(&WR9'5L(&]P96YS<VP@<&5R(&$@;&$@8VQA<W-E($AO
M<F1E7T-R>7!T7W-M:6UE+B(*"B,Z(&QI8B](;W)D92]0<F5F<RYP:'`Z,C@U
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<
M(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E
M9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"B).
M;R!S)VAA('!O9W5T(&1E<V%R(&QA('!R969E<NAN8VEA(%PB)7-<(B!P97)Q
M=>@@;&$@:6YF;W)M86-I\R!Q=64@8V]N=&5N:6$@(@HB<W5P97)A=F$@;&$@
M;6ED82!MX'AI;6$@<&5R;65S82XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O;7-E>&-E;"YP:'`Z,S(@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS=V]R
M9"YP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z
M,S<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS
M-R!L:6(O2&]R9&4O34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U(&QI8B](;W)D92]-24U%
M+U9I97=E<B]D96(N<&AP.C,R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M
M<W!O=V5R<&]I;G0N<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A
M<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HB3F\@<R=H
M82!T<F]B870@96X@96P@<VES=&5M82!E;"!P<F]G<F%M82!U<V%T('!E<B!V
M:7-U86QI='IA<B!A<75E<W0@=&EP=7,@(@HB9&4@9&%D97,@*"5S*2XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G
M<W1R(").;VWI<R!E;',@8V]S=&%T<R!D<F5T(&D@97-Q=65R<F4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X
M"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B3F]M
MZ7,@96P@8V]S=&%T(&1R970B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M
M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<
M(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")3)VAA('-U<')I;6ET(&5L
M('-E<G9I9&]R(%PB)7-<(BXB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M
M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<
M(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B4R=H82!D97-A="!E;"!S97)V
M:61O<B!<(B5S7"(N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E
M96X@<F5M;W9E9"XB"FUS9W-T<B`B4R=H82!E;&EM:6YA="!L82!S;VRW;&EC
M:71U9"!D)V%L=&$@9&4@)7,N(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="YP:'`Z,CDP"B,L(&9U>GIY"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D
M;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B3F\@97AI<W1E:7@@;&$@9FEL82!E
M<W!E8VEF:6-A9&$N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C$P.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@
M;F]T(&5X:7-T+B(*;7-G<W1R(").;R!E>&ES=&5I>"!L)V%R>&EU('1E;7!O
M<F%L(%PB)7-<(BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@
M<VED97,@;VYL>2(*;7-G<W1R(").;VWI<R!E;',@8V]S=&%T<R!S=7!E<FEO
M<B!I(&EN9F5R:6]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB
M"FUS9W-T<B`B3F]MZ7,@96P@8V]S=&%T('-U<&5R:6]R(@H*(SH@;&EB+TAO
M<F1E+T1A=&$N<&AP.C,P-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S
M(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(E,G:&%N
M('!E<F1U="!L97,@9&%D97,@8V%R<F5G861E<R!D97,@9&5L('!A<R!A;G1E
M<FEO<BXB"@HC.B!L:6(O2&]R9&4O1&%T82]T<W8N<&AP.C$W,B!L:6(O2&]R
M9&4O1&%T82]C<W8N<&AP.C(T,`IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@
M8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&1E
M<V%R(&PG87)X:74@8V%R<F5G870N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C0V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3`W(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ,3$*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B
M;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")%;"!B;&]C('=E871H
M97(N8V]M(&YO(&5S=.`@9&ES<&]N:6)L92XB"@HC.B!U=&EL+VEC;VY?8G)O
M=W-E<BYP:'`Z,C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H96UE
M<R!D:7)E8W1O<GD@)R5S)R!N;W0@9F]U;F0N(@IM<V=S='(@(DYO(',G:&$@
M=')O8F%T(&5L(&1I<F5C=&]R:2!4:&5M97,@)R5S)RXB"@HC.B!L:6(O2&]R
M9&4O4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO
M;G,@879A:6QA8FQE+B(*;7-G<W1R(").;R!H:2!H82!C87`@;W!C:?,@9&ES
M<&]N:6)L92XB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z,S0P
M"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA
M>65D(&EN;&EN92XB"FUS9W-T<B`B3F\@:&D@:&$@8V%P('!A<G0@<75E(&5S
M('!U9W5I(&UO<W1R87(@96X@;.UN:6$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,30P-@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O
M(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E
M<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA
M;B`E<RXB"FUS9W-T<B`B(@HB07%U97-T(&-A;7`@8V]N=.D@;6%S<V$@8V%R
MX&-T97)S+B!(974@:6YT<F]D=>]T("5S(&-A<N!C=&5R<R!I(&XG:&5U("(*
M(F0G:6YT<F]D=6ER(&UE;GES(&1E("5S+B(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HQ,#8P"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E(&1O97-N)W0@
M>65T(&5X:7-T(&$@:&5L<"!F:6QE(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@
M<VEG;G5P+G!H<#HU,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@)R5S)R!T;R!T:&4@<WES=&5M+B`E
M<RXB"FUS9W-T<B`B2&D@:&$@:&%G=70@=6X@<')O8FQE;6$@96X@869E9VER
M("<E<R<@86P@<VES=&5M83H@)7,B"@HC.B!A9&UI;B]U<V5R+G!H<#HW,PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!A9&1I;F<@)R5S)R!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R(")(:2!H
M82!H86=U="!U;B!P<F]B;&5M82!E;B!A9F5G:7(@)R5S)R!A;"!S:7-T96UA
M.B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A
M(&9O<B!U<V5R("<E<R<@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@HB
M2&D@:&$@:&%G=70@=6X@<')O8FQE;6$@96X@97-B;W)R87(@9&5L('-I<W1E
M;6$@;&5S(&1A9&5S(&1E(&PG=7-U87)I("<E<R<N("(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$P,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&$@<')O8FQE;2!R96UO=FEN9R`G)7,G(&9R;VT@=&AE('-Y<W1E;3H@
M(@IM<V=S='(@(DAI(&AA(&AA9W5T('5N('!R;V)L96UA(&5N('-U<')I;6ER
M("<E<R<@9&5L('-I<W1E;6$Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!U<&1A=&EN9R`G)7,G.B`E<R(*;7-G<W1R(")(:2!H82!H86=U="!U;B!P
M<F]B;&5M82!E;B!A8W1U86QI='IA<B`G)7,G.B`E<R(*"B,Z(&QI8B](;W)D
M92]"<F]W<V5R+G!H<#HX-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S
M('5P;&]A9&5D+B(*;7-G<W1R(")(:2!H82!H86=U="!U;B!P<F]B;&5M82!E
M;B!C87)R96=A<B!L)V%R>&EU.B!N;R!S)VAA(&-A<G)E9V%T("5S+B(*"B,Z
M(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX.#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO
M=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HB2&D@:&$@:&%G=70@
M=6X@<')O8FQE;6$@96X@8V%R<F5G87(@;"=A<GAI=3H@96P@)7,@97)A('-U
M<&5R:6]R(&$@;&$@;6ED82`B"B)MX'AI;6$@<&5R;65S82`H)2!B>71E<RDN
M(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.C@X-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*
M;7-G<W1R("(B"B)(:2!H82!H86=U="!U;B!P<F]B;&5M82!E;B!C87)R96=A
M<B!L)V%R>&EU.B!N;VWI<R!S)VAA(&-A<G)E9V%T('!A<F-I86QM96YT("(*
M(F5L("5S+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES
M(&UE<W-A9V4@<&%R="(*;7-G<W1R(")3)VAA('!R;V1U[W0@=6X@97)R;W(@
M96X@;6]S=')A<B!A<75E<W1A('!A<G0@9&5L(&UI<W-A=&=E(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.2!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(E,G:&$@
M<')O9'7O="!U;B!E<G)O<B!E;B!I;7!O<G1A<B!L97,@9&%D97,@9&4@8V]N
M=&%C=&4N(@H*(SH@;&EB+TAO<F1E+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A
M=&$N(@IM<V=S='(@(E,G:&$@<')O9'7O="!U;B!E<G)O<B!E;B!I;7!O<G1A
M<B!L97,@9&%D97,@:4-A;&5N9&%R+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-SD*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@
M8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*
M(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"B)3)VAA('!R;V1U[W0@=6X@
M97)R;W(@96X@96P@9F]R;75L87)I(&1E(&-O;F9I9W5R86-I\RX@4&]T<V5R
M('5S(&AE=2`B"B)D97-C=6ED870@9"=E;7!L96YA<B!U;B!C86UP(&YE8V5S
M<V%R:2XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$P-R!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,3$Q,R!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(T-0HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3(U,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@;W!E;FEN9R!T:&4@9FEL92`E<RX@5')Y(')U
M;FYI;F<@=')A;G-L871I;VXN<&AP('=I=&@@=&AE("(*(F9L86<@+60@=&\@
M<V5E(&%N>2!E<G)O<B!M97-S86=E<R!F<F]M('1H92!X;6P@<&%R<V5R+B(*
M;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,W"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T
M:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*
M(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB4R=H82!P<F]D=>]T('5N
M(&5R<F]R(&5N(&5X96-U=&%R(&QA(&9U;F-I\R!E<W!E8VEF:6-A9&$@9&4@
M;&$@;&QI8G)E=&$@(@HB9"=A9')E8V5S+B!4;W)N974M:&\@82!I;G1E;G1A
M<B!MZ7,@=&%R9"XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,Y"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB
M"FUS9W-T<B`B(@HB4R=H82!P<F]D=>]T('5N(&5R<F]R(&5N(&%C='5A;&ET
M>F%R(&5L<R!D971A;&QS(&1E(&-O;G1A8W1E+B!4;W)N974M:&\@82`B"B)I
M;G1E;G1A<B!MZ7,@=&%R9"XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN
M(&QA=&5R+B(*;7-G<W1R("(B"B)3)VAA('!R;V1U[W0@=6X@97)R;W(@96X@
M86-T=6%L:71Z87(@;&$@;&QI<W1A(&1E(&1I<W1R:6)U8VGS+B!4;W)N974M
M:&\@82`B"B)I;G1E;G1A<B!MZ7,@=&%R9"XB"@HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-05`@<V5R=F5R
M(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R(")!
M<75E<W0@<V5R=FED;W(@24U!4"!N;R!P97)M970@;"?Z<R!D92!C87)P971E
M<R!C;VUP87)T:61E<RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R
M+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V
M86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B3F\@<V5M8FQA('%U92!S:6=U
M:2!U;B!A<GAI=2!R87(@=N!L:60N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O
M(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(DYO('-E;6)L82!Q=64@
M<VEG=6D@=6X@87)X:74@>FEP(';@;&ED+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HS,30S"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V
M86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B3F\@<V5M8FQA('%U92!A<75E
M<W0@;OIM97)O(&1E('1A<F=E=&$@<VEG=6D@=N!L:60N(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(B(*(E1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE
M($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A
M>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(D%Q=65S="!C;VYT
M<F]L861O<B!P97)M970@96YV:6%R(&UI<W-A=&=E<R!P97(@;6ET:N`@9&4@
M;&$@<&%S<V%R96RW;&$@(@HB0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E
M;&PN8V]M*2P@=71I;&ET>F%N="!L82!!4$D@2%144"(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(B(*(E1H:7,@9')I
M=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M
M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S
M:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)!<75E<W0@8V]N=')O;&%D
M;W(@<&5R;65T(&5N=FEA<B!M:7-S871G97,@<&5R(&UI=&K@(&1E(&QA('!A
M<W-A<F5LMVQA("(*(G-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI
M('5T:6QI='IA;G0@;&$@05!)($A45%`B"@HC.B!L:6(O3F5T+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.C@P"FUS9VED("(B"B)4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H
M92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE
M(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B
M"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R
M("(B"B)!<75E<W0@8V]N=')O;&%D;W(@<&5R;65T(&5N=FEA<B!M:7-S871G
M97,@<&5R('9I82!D92!33510(&$@=')A=NES(&1E(&QA("(*(G!A<W-A<F5L
MMVQA(%9O9&%F;VYE(&0G273@;&EA+"!N;VWI<R!A(&[Z;65R;W,@5F]D869O
M;F4N($-A;"!T96YI<B!U;B!C;VUP=&4@(@HB9&4@8V]R<F5U(&5L96-T<O)N
M:6,@86UB(%9O9&%F;VYE(&0G273@;&EA("AH='1P.B\O=W=W+C$Y,"YI="DN
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDW."!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3`U-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`X-@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3$Q-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$X,B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3(U-@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Y,"!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,30P,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,34V
M,@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@T,R!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3DU."!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`P-0HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C`R.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`W."!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C$T.0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(R,2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C0P."!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0U
M,@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8U-2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C@R-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$S-0HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S<R,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S<S,`IM<V=I9"`B
M5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`BR7,@;F5C97-S87)I
M(&%Q=65S="!C86UP+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#8U"FUS
M9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM
M<V=S='(@(D%Q=65S="!C86UP(&YO;>ES('!O="!C;VYT96YI<B!N;VUB<F5S
M(&5N=&5R<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0Q-@IM<V=I9"`B
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C
M;VQO;BXB"FUS9W-T<B`B07%U97-T(&-A;7`@;F]MZ7,@<&]T(&-O;G1E;FER
M(&YO;6)R97,@:2!E;',@9&]S('!U;G1S+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,#DT"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M;V-T86P@=F%L=65S+B(*;7-G<W1R(")!<75E<W0@8V%M<"!N;VWI<R!P;W0@
M8V]N=&5N:7(@=F%L;W)S(&]C=&%L<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3$R,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@
M<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B(@HB
M07%U97-T(&-A;7`@:&$@9&4@<V5R('5N82!L;&ES=&$@9&4@;F]M8G)E<R!E
M;G1E<G,@<V5P87)A=',@<&5R(&-O;65S(&\@(@HB97-P86ES+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HY.#D*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B
M92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B07%U97-T(&-A;7`@:&$@9&4@
M<V5R('5N(&[Z;65R;R!VX&QI9"XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C@S-`IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO
M<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB
M)R,Q,C,T868G+B(*;7-G<W1R("(B"B)!<75E<W0@8V%M<"!H82!D92!C;VYT
M96YI<B!U;B!C;V1I(&1E(&-O;&]R(&1E(&9O<FUA="!21T(@:&5X861E8VEM
M86PL('!E<B`B"B)E>&5M<&QE("<C,3(S-&%F)RXB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E
M;B!P<F]C97-S960N(@IM<V=S='(@(DIA(',G:&$@<')O8V5S<V%T(&%Q=65S
M="!F;W)M=6QA<FDN(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B06EX
M\B#I<R`E<RXB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0S-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B
M:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M
M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U
M<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI
M96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@HB06EX\B#I<R!U;B!O
M8FIE8W1E(&1E($MO;&%B($=R;W5P=V%R92X@4&5R('9I<W5A;&ET>F%R(&%Q
M=65S="!O8FIE8W1E+"!U<R`B"B)C86P@=6X@8VQI96YT(&1E(&-O<G)E=2!E
M;&5C='+R;FEC('%U92!A9&UE=&D@96P@9F]R;6%T(&1E($MO;&%B($=R;W5P
M=V%R92X@(@HB4&5R('1E;FER(&%C8^ES(&$@=6YA(&QL:7-T82!D)V%Q=65S
M=',@8VQI96YT<R!D92!C;W)R974@96QE8W1R\FYI8RP@=FES:71E=2`B"B(E
M<R(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HU.#<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@
M8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S
M='(@(B(*(D%Q=65S="!M:7-S871G92!V82!S97(@97-C<FET(&%M8B!U;B!J
M;V,@9&4@8V%RX&-T97)S("@E<RD@9&EF97)E;G0@9&5L("(*(G9O<W1R92XB
M"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N
M=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(D%Q=65S="!N
M^FUE<F\@:&$@9&4@<V5R(&-O;2!A(&WM;FEM('5N(#$N(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C$S,#0*;7-G:60@(E1H:7,@<V-R:7!T(&UU<W0@8F4@
M<G5N(&9R;VT@=&AE(&-O;6UA;F0@;&EN92XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E
M<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T
M<B`B07%U97-T('-E<G9I9&]R(&YO('!O="!D97-C;VUP<FEM:7(@87)X:75S
M('II<"!I(&=Z:7`N(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HQ-#<*
M;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB
M"FUS9W-T<B`B07%U97-T('-I<W1E;6$@97-TX"!D97-A8W1I=F%T(&%C='5A
M;&UE;G0N(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@
M(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B07%U97-T
M('9A;&]R(&AA(&1E('-E<B!U;B!N^FUE<F\N(@H*(SH@<V5R=FEC97,O:6UA
M9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S
M="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R(")!
M<75E<W1A(&9I;F5S=')A(',G:&$@9&4@8W)I9&%R(&1E<R!D)W5N82!F:6YE
M<W1R82!D)V]P8VEO;G,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV,`IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R(")4<F\B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(P"FUS9VED(")4:6-K971S
M(@IM<V=S='(@(E1I<75E=',B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0R
M-@IM<V=I9"`B5&EM92(*;7-G<W1R(")(;W)A(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,P-@IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R
M(")#;VYT<F]L(&1E('1E;7!S(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W
M"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R(")&;W)M870@:&]R87)I(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U,S<*;7-G:60@(E1I;64@<V5L96-T
M:6]N(@IM<V=S='(@(E-E;&5C8VGS(&1E('1E;7!S(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,C(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,`IM<V=I9"`B5&EM
M;W(M3&5S=&4B"FUS9W-T<B`B5&EM;W(@3W)I96YT86PB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE
M+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B5.UT;VPB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4
M:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(E3M=&]L("ARZ'1O;"!I;F1I8V%D
M;W(@9&4@9G5N8VGS*3HB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B02(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HV,C8*;7-G:60@(B(*(E1O('-E
M;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A0
M0RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM
M<V=S='(@(B(*(E!E<B!S96QE8V-I;VYA<B!D:79E<G-O<R!E;&5M96YT<RP@
M;6%N=&EN9W5E=2!P:71J861A(&QA('1E8VQA($-O;G1R;VP@*%!#*2`B"B)O
M($-O;6UA;F0@*$UA8RD@;65N=')E(&-L:7%U974N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(X,`IM<V=I9"`B5&]D87DB"FUS9W-T<B`B
M079U:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R(")#;VUM
M=71E=2!L82!F;VYT($A434PB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C(S"FUS9VED(")4;V=O(@IM<V=S='(@(E1O
M9V\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C(V"FUS9VED(")4;VME;&%U(@IM<V=S='(@(E1O:V5L874B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@R"FUS9VED(")4;VUO<G)O
M=R(*;7-G<W1R(")$96W@(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(R.0IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B5&]N
M9V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G<W1R(")3=7!E<FEO<B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@
M(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B36%R8R!S=7!E<FEO<B`H7W-U
M<&5R:6]R*2(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV-3<*(RP@9G5Z>GD*
M;7-G:60@(E1R86YS;&%T960B"FUS9W-T<B`B5')A9'5C8VEO;G,B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*
M;7-G<W1R(")4<F%D=6-C:6]N<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,S(*;7-G:60@(E1R:6YI9&%D(&%N9"!4
M;V)A9V\B"FUS9W-T<B`B5')I;FET870@:2!4;V)A9V\B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3<Y-`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R
M(")697)I=&%T(&\@9F%L<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(D1T+B(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C@*
M;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B5'5N[7-I82(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S$*;7-G:60@(E1U
M<FME>2(*;7-G<W1R(")4=7)Q=6EA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.3(*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(E1U
M<F,@*$E33RTX.#4Y+3DI(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(R-PIM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S
M='(@(E1U<FMM96YI<W1A;B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,C`*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@
M27-L86YD<R(*;7-G<W1R("));&QE<R!4=7)K<R!I($-A:6-O<R(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S,*;7-G
M:60@(E1U=F%L=2(*;7-G<W1R(")4=79A;'4B"@HC.B!L:6(O2&]R9&4O0TQ)
M+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R(")4
M96-L96=E=2!L82!V;W-T<F$@;W!C:?,Z("(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-38*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R
M("+-;F1E>"!55CH@(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*
M;7-G<W1R(")54DPB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-30P"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T
M871U<R!R97!O<G0B"FUS9W-T<B`B55),(&1E;"!V;W-T<F4@:6YF;W)M92!D
M92!L)V5S=&%T(&1E('1R86UE<V$@9&4@;&$@<V5Q_.AN8VEA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B
M55),.B(*;7-G<W1R(")54DPZ(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(S-PIM<V=I9"`B56=A;F1A(@IM<V=S='(@
M(E5G86YD82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,S8*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B56-R8>]N82(*
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S,U"FUS9VED(")5;F%B;&4@=&\@86-C
M97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYO(',G:&$@<&]G=70@86-C
M961I<B!A;"!D:7)E8W1O<FD@5D93+B(*"B,Z(&QI8B](;W)D92]!=71H+U-I
M9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I
M;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(DYO(',G:&$@
M<&]G=70@869E9VER(&WI<R!D861E<R!D92!L)W5S=6%R:2!E;B!E9F5C='5A
M<B!L)V%L=&$N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,R-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&
M4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!C86YV:6%R
M(&5L('!E<FWM<R!D92!L)V%R>&EU(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&
M4R]F:6QE+G!H<#HS,#@@;&EB+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@
M5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(DYO(',G:&$@<&]G=70@8V%N=FEA
M<B!E;"!P97)M[7,@9&4@;"=A<GAI=2!61E,@)7,O)7,N(@H*(SH@;&EB+U9&
M4R]F='`N<&AP.C8W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8VAA;F=E('1O("5S+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&-A;G9I87(@
M82`E<RXB"@HC.B!L:6(O2&]R9&4O075T:"]S<6PN<&AP.C,W,0IM<V=I9"`B
M56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B3F\@
M<R=H82!P;V=U="!C;VYN96-T87(@86P@<V5R=FED;W(@4U%,+B(*"B,Z(&QI
M8B]61E,O9G1P+G!H<#HW-38*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I
M=&@@4U-,+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&-O;FYE8W1A<B!A;6(@
M4U-,+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,34X(&QI8B]61E,O9FEL92YP
M:'`Z,38S(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$X.`HC.B!L:6(O5D93+W-Q
M;%]F:6QE+G!H<#HQ.3,@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q"FUS9VED
M(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B3F\@<R=H82!P
M;V=U="!C;W!I87(@;"=A<GAI=2!61E,N(@H*(SH@;&EB+U9&4R]F='`N<&AP
M.C,P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&-R
M96%R(&5L(&1I<F5C=&]R:2!61E,@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL
M92YP:'`Z,C<W(&QI8B]61E,O;75S<6PN<&AP.C(U."!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HR-#@*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!C<F5A<B!E;"!D:7)E8W1O
M<FD@5D93+B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$R-`IM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`B3F\@<R=H82!P;V=U
M="!C<F5A<B!L)V%R>&EU(%9&4RXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z,C@V
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O
M;&1E<B!<(B5S7"(N(@IM<V=S='(@(DYO(',G:&$@<&]G=70@8W)E87(@;&$@
M8V%R<&5T82!61E,@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3DX
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G
M<W1R(").;R!S)VAA('!O9W5T(&-R96%R('5N(&%R>&EU(%9&4R!B=6ET+B(*
M"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]T87(N<&AP.C<V(&QI8B](;W)D92]#
M;VUP<F5S<R]G>FEP+G!H<#HW.0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E
M<W,@9&%T82XB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!D97-C;VUP<FEM:7(@
M;&5S(&1A9&5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR,S8@;&EB+U9&4R]S
M;6(N<&AP.C(R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S
M='(@(DYO(',G:&$@<&]G=70@<W5P<FEM:7(@7"(E<UPB+"!E;"!D:7)E8W1O
M<FD@;F\@97-TX"!B=6ET+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C4T(&QI
M8B]61E,O<W%L+G!H<#HS,30@;&EB+U9&4R]M=7-Q;"YP:'`Z,S$Q"B,Z(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C,R-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>2(*;7-G<W1R(").;R!S)VAA('!O9W5T('-U<')I;6ER("5S+"!E;"!D:7)E
M8W1O<FD@;F\@97-TX"!B=6ET+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-SD@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HU.0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`G)7,G.B`E<RXB"FUS9W-T<B`B
M3F\@<R=H82!P;V=U="!S=7!R:6UI<B`G)7,G.B`E<RXB"@HC.B!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HS-#`@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S0T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E
M;'DN(@IM<V=S='(@(DYO(',G:&$@<&]G=70@<W5P<FEM:7(@96P@9&ER96-T
M;W)I(%9&4R!D92!M86YE<F$@<F5C=7)S:79A+B(*"B,Z(&QI8B]61E,O9FEL
M92YP:'`Z,C8P(&QI8B]61E,O;75S<6PN<&AP.C,R,B!L:6(O5D93+VUU<W%L
M+G!H<#HS,S4*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,S0S(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C,S-@IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R(").;R!S)VAA('!O9W5T('-U<')I;6ER(&5L(&1I
M<F5C=&]R:2!61E,N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C,S.2!L:6(O5D93
M+W-Q;"YP:'`Z,S4Q"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(DYO(',G:&$@<&]G
M=70@<W5P<FEM:7(@96P@9&ER96-T;W)I(%9&4SH@)7,N(@H*(SH@;&EB+U9&
M4R]F='`N<&AP.C$W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F\@<R=H82!P;V=U
M="!S=7!R:6UI<B!L)V%R>&EU(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HR,C8@;&EB+U9&4R]S<6PN<&AP.C(Q,"!L:6(O5D93+VUU<W%L
M+G!H<#HQ-C<*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3@P(&QI8B]61E,O;75S
M<6PN<&AP.C$X-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS-S`*(SH@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,S<X"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!F:6QE+B(*;7-G<W1R(").;R!S)VAA('!O9W5T('-U<')I;6ER(&PG87)X
M:74@5D93+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HR-#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB
M"FUS9W-T<B`B3F\@<R=H82!P;V=U="!S=7!R:6UI<B!L82!C87)P971A(%9&
M4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C,R.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@
M)7,N(@IM<V=S='(@(DYO(',G:&$@<&]G=70@<W5P<FEM:7(@5D93(&1E(&UA
M;F5R82!R96-U<G-I=F$Z("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW,C`*
M;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN
M(@IM<V=S='(@(DYO(',G:&$@<&]G=70@9&5T97)M:6YA<B!E;"!D:7)E8W1O
M<FD@86-T=6%L+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C`S
M"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS
M(@IM<V=S='(@(DYO(',G:&$@<&]G=70@97AT<F5U<F4@96QS(&1E=&%L;',@
M9&5L(&-E<G1I9FEC870N(@H*(SH@;&EB+TYE="])35-0+G!H<#HT-3$@;&EB
M+TYE="])35-0+T%U=&@N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B
M3F\@<R=H82!P;V=U="!C87)R96=A<B!L82!D969I;FEC:?,@9&4@)7,N(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HQ,CD@;&EB+U9&4R]F:6QE+G!H<#HQ,S0@
M;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,34X"B,Z(&QI8B]61E,O<W%L7V9I;&4N
M<&AP.C$V,PIM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S
M='(@(DYO(',G:&$@<&]G=70@;6]U<F4@;"=A<GAI=2!61E,N(@H*(SH@;&EB
M+U9&4R]F='`N<&AP.C<V(&QI8B]61E,O<VUB+G!H<#HY,R!L:6(O5D93+W-M
M8BYP:'`Z,3`R"B,Z(&QI8B]61E,O<VUB+G!H<#HV-3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R(").;R!S)VAA('!O9W5T(&]B<FER(&PG87)X:74@5D93(%PB)7-<(BXB
M"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(P-2!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HQ,C(@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3(U"FUS9VED(")5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B3F\@<R=H
M82!P;V=U="!O8G)I<B!L)V%R>&EU(%9&4R!P97(@97-C<FEU<F4M:&DN(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HV-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW
M,@IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(DYO
M(',G:&$@<&]G=70@;V)R:7(@;"=A<GAI=2!61E,N(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N
M(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!O
M8G)I<B!L)V%R>&EU(&-O;7!R:6UI="XB"@HC.B!L:6(O5D93+G!H<#HX-34*
M;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A
M:6QE9"DN(@IM<V=S='(@(B(*(DYO(',G:&$@<&]G=70@;&QE9VER(&PG87)X
M:74@5D93("AL82!M:61A(&1E(&PG87)X:74H*2!H82!D;VYA="!E<G)O<BDN
M(@H*(SH@;&EB+U9&4RYP:'`Z.#@V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!6
M1E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G<W1R(").;R!S
M)VAA('!O9W5T(&QL96=I<B!L)V%R>&EU(%9&4R`H9V5T1FEL95-I>F4H*2!H
M82!D;VYA="!E<G)O<BDN(@H*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R
M+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS
M9W-T<B`B3F\@<R=H82!P;V=U="!L;&5G:7(@;"=A<GAI=3H@+B(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z-3DR"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@
M=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(DYO(',G:&$@<&]G=70@;&QE
M9VER(&5L(&1I<F5C=&]R:2!A<G)E;"!D92!61E,N(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HQ,#8W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y
M(&5X:7-T<R(*;7-G<W1R("(B"B).;R!S)VAA('!O9W5T(&-A;G9I87(@96P@
M;F]M(&1E("5S('!E<B`E<SH@;&$@8V%R<&5T82!D92!D97-T:6YA8VGS(&IA
M("(*(F5X:7-T96EX(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C@U"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@
M(DYO(',G:&$@<&]G=70@8V%N=FEA<B!E;"!N;VT@9&5L(&1I<F5C=&]R:2!6
M1E,N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C(U,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G
M<W1R(").;R!S)VAA('!O9W5T(&-A;G9I87(@96P@;F]M(&1E;"!D:7)E8W1O
M<FD@5D93.B`E<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C@Q(&QI8B]61E,O
M<VUB+G!H<#HR-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYO(',G:&$@<&]G=70@
M8V%N=FEA<B!E;"!N;VT@9&4@;"=A<GAI=2!61E,@7"(E<UPB+B(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z-3,S(&QI8B]61E,O;75S<6PN<&AP.C(R.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S
M+R5S+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&-A;G9I87(@96P@;F]M(&1E
M(&PG87)X:74@5D93("5S+R5S+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HR-#4@
M;&EB+U9&4R]M=7-Q;"YP:'`Z,C$S(&QI8B]61E,O;75S<6PN<&AP.C0U,@HC
M.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR-S<@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z,CDS"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G
M<W1R(").;R!S)VAA('!O9W5T(&-A;G9I87(@96P@;F]M(&1E(&PG87)X:74@
M5D93+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS
M9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B3F\@<R=H
M82!P;V=U="!E>&5C=71A<B`G;6MI<V]F<R<N(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T<F%N
M<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(DYO(',G:&$@<&]G
M=70@=')A9'5I<B!A<75E<W0@9&]C=6UE;G0@9&4@5V]R9"(*"B,Z(&QI8B]6
M1E,O9G1P+G!H<#HQ,C(@;&EB+U9&4R]F='`N<&AP.C$R-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R(").;R!S)VAA('!O9W5T(&5S8W)I=7)E(&PG87)X:74@5D93(%PB
M)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$Q,@IM<V=I9"`B56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B
M(@HB3F\@<R=H82!P;V=U="!E<V-R:75R92!L)V%R>&EU(%9&4R`H(W,G:&$@
M<')O9'7O="!U;B!E<G)O<B!E;B!C;W!I87(M;&\H*2`C*2XB"@HC.B!L:6(O
M5D93+V9I;&4N<&AP.C(P.2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ,S`@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z,3,U"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!E<V-R:75R
M92!L97,@9&%D97,@9&4@;"=A<GAI=2!61E,N(@H*(SH@;&EB+U9&4RYP:'`Z
M.#8Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I
M;&P@8F4@97AC965D960N(@IM<V=S='(@(DYO(',G:&$@<&]G=70@97-C<FEU
M<F4@;"=A<GAI=2!61E,L('-E('-U<&5R87+@(&PG97-P86D@9&ES<&]N:6)L
M92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B4W5B<F%T;&QA="(*"B,Z
M('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E
M<R(*;7-G<W1R(")$97-FZ7,@96QS(&-A;G9I<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(D1E<V;@(&QA(&1A<G)E<F$@86-C
M:?,B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*;7-G:60@(E5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM
M<V=S='(@(D5L('-E<G9I9&]R(&AA(&1O;F%T('5N82!R97-P;W-T82!I;F5S
M<&5R861A(&5N(&-O;FYE8W1A<BUS93H@(@H*(SH@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C(Q.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S0Q"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M-S@@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-`IM<V=I9"`B
M56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@
M(D5L('-E<G9I9&]R(&AA(&1O;F%T('5N82!R97-P;W-T82!I;F5S<&5R861A
M(&$Z("(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP
M.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C8T"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(E-E;G-E(&-A=&5G;W)I82(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")5;FEC;V1E("A5
M5$8M."DB"FUS9W-T<B`B56YI8V]D92`H551&+3@I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(S-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<*;7-G:60@(E5N:71E
M9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(E5N:?,@9&5L<R!%;6ER871S(,!R
M86)S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C,X"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R(")296=N92!5
M;FET(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$S(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(T,`IM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R(")%<W1A=',@
M56YI=',B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C,Y"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG
M($ES;&%N9',B"FUS9W-T<B`B26QL97,@4&5R:6;H<FEQ=65S($UE;F]R<R!D
M96QS($5S=&%T<R!5;FET<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HV.2!L:6(O0FQO8VLO;65T87(N<&AP.C8Y"FUS9VED(")5;FET<R(*
M;7-G<W1R(")5;FET871S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M-#$X(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q.0IM<V=I9"`B56YK;F]W
M;B(*;7-G<W1R(")$97-C;VYE9W5T(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%0
M22!-97-S86=E($E$*2XB"FUS9W-T<B`B87!I;7-G:60@*&ED96YT:69I8V%D
M;W(@9&5L(&UI<W-A=&=E(&1E(&QA($%022D@9&5S8V]N96=U="XB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK
M;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R(")#
M;&EM<V=I9"!D97-C;VYE9W5T("AI9&5N=&EF:6-A9&]R(&1E;"!M:7-S871G
M92!D96P@8VQI96YT*2XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,34P,0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YK;F]W;B!C;VUM86YD.B`E
M<R(*;7-G<W1R(")$97-C87)R96=A<B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-3$*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O
M=FED960N(@IM<V=S='(@(E,G:&$@<')O<&]R8VEO;F%T('5N82!U8FEC86-I
M\R!D97-C;VYE9W5D82XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y,`IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R
M9"XB"FUS9W-T<B`B3F]M(&0G=7-U87)I(&\@8V]N=')A<V5N>6$@9&5S8V]N
M96=U=',N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4W"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE
M;65N="(*;7-G<W1R(")$97-E;FQL8>=A<B!L)V5L96UE;G0@86-T=6%L(@H*
M(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H<#HR.38*;7-G:60@(E5N;F%M960B
M"FUS9W-T<B`B4V5N<V4@;F]M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C
M<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I
M8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S
M964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S
M:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@
M8VQI<&)O87)D+B(*;7-G<W1R("(B"B),97,@<V5Q_.AN8VEE<R!S96YS92!P
M97)M:7-O<R!N;R!P;V1E;B!A8V-E9&ER(&$@4F5T86QL87(O0V]P:6%R+T5N
M9V%N>&%R(&1E("(*(FUA;F5R82!P<F]G<F%MX'1I8V$@<&5R(')A;VYS(&1E
M('-E9W5R971A="X@0VQI<75E=2!E;B!$)V%C;W)D('!E<B`B"B)V:7-U86QI
M='IA<B!U;F$@;F]T82!TZ&-N:6-A(&$@;6]Z:6QL82YO<F<@<75E('5S(&UO
M<W1R82!C;VT@<&]D974@9F5R('%U92`B"B)U;F$@<V5Q_.AN8VEA(&%C8V5D
M96EX:2!A;"!P;W)T82UR971A;&QS+B`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C
M;VQO<B(*;7-G<W1R(")%;&EM:6YA<B!E;"!C;VQO<B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-C@V(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z.3(V"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z.3,R"FUS9VED
M(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B17AT96YS:?,@;F\@
M:6UP;&5M96YT861A(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8U-PHC+"!F
M=7IZ>0IM<V=I9"`B56YT<F%N<VQA=&5D(@IM<V=S='(@(E-E;G-E(&YO;2(*
M"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P-B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C$X,PHC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS
M,PIM<V=I9"`B57!D871E(@IM<V=S='(@(D%C='5A;&ET>F%R(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B06-T=6%L:71Z87(@)7,B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"FUS9VED(")5
M<&1A=&4@=7-E<B(*;7-G<W1R(")!8W1U86QI='IA<B!L)W5S=6%R:2(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,3,W(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(Q
M-R!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5<&1A=&5D("<E<R<N(@IM<V=S='(@(E,G:&$@86-T
M=6%L:71Z870@)R5S)RXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`Y,B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,3(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<&1A=&EN9R`E<R!H96QP(&9I;&4@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,0IM<V=I9"`B57!G<F%D92!S8W)I
M<'0@9&5L971E9"XB"FUS9W-T<B`B4R=H82!S=7!R:6UI="!L82!S97'\Z&YC
M:6$@9"=A8W1U86QI='IA8VGS+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ.#$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$X,@IM
M<V=I9"`B57!L;V%D(@IM<V=S='(@(D-A<G)E9V%R(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$X.0IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T
M:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(B(*(E,G
M:&$@8V%R<F5G870@86P@<V5R=FED;W(@=&]T<R!E;',@87)X:75S(&1E(&-O
M;F9I9W5R86-I\R!D)V%P;&EC86-I;VYS+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P
M<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B06QF86)E="!L;&%T[2!E;B!M
M86KZ<V-U;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S
M(@IM<V=S='(@(EAI9G)E<R!R;VUA;F5S(&5N(&UA:OIS8W5L82(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#$*;7-G
M:60@(E5R=6=U87DB"FUS9W-T<B`B57)U9W5A:2(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HS-2!P;R]T<F%N<VQA=&EO;BYP:'`Z.3(@<&\O=')A;G-L871I
M;VXN<&AP.CDS"B,L(&9U>GIY"FUS9VED(")5<V%G93HB"FUS9W-T<B`B3F]M
M(&0G=7-U87)I.B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G
M97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E
M<R(*;7-G<W1R(")5=&EL:71Z87(@;"=A8W1U86PZ("5S(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PIM<V=I9"`B57-E(%-33"(*
M;7-G<W1R(")5=&EL:71Z87(@4U-,(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$R,PIM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R
M96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B571I;&ET>F5U('-I(&5L
M(&YO;2!O(&QA(&-O;G1R87-E;GEA('/S;B!D:69E<F5N=',@86P@<V5R=FED
M;W(@24U34"XB"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C8Q.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O
M<B`E<RXB"FUS9W-T<B`B3"=U<W5A<FD@)7,@;F\@97-TX"!A=71O<FET>F%T
M('!E<B!A("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E
M<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A8VGS(&0G=7-U
M87)I<R(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,C4P"FUS9VED(")5
M<V5R($]P=&EO;G,B"FUS9W-T<B`B3W!C:6]N<R!D)W5S=6%R:2(*"B,Z('-I
M9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@
M(E)E9VES=')E(&0G=7-U87)I<R(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@
M(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES
M('-I=&4N(@IM<V=S='(@(D5L(')E9VES=')E(&0G=7-U87)I<R!D)V%Q=65S
M="!L;&]C(&5S=.`@:6YH86)I;&ET870N(@H*(SH@861M:6XO<&5R;7,O961I
M="YP:'`Z,3<R(&QI8B](;W)D92]097)M<R]522YP:'`Z,C0V"B,L(&9U>GIY
M"FUS9VED(")5<V5R('!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUI<V]S(&1E
M;"!P<F]P:65T87)I(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$X,@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$Y-R!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP
M.CDS"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S4@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O87!P<F]V92YI;F,Z,3(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHV-@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B3F]M(&0G=7-U87)I(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E5S97)N86UE("<E<R<@86QR96%D>2!E>&ES=',N
M(@IM<V=S='(@(D5L(&YO;2!D)W5S=6%R:2`G)7,G(&IA(&5X:7-T96EX+B(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E
M<FYA;64Z(@IM<V=S='(@(DYO;2!D)W5S=6%R:3HB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@
M(DYO;2!D)W5S=6%R:3H@(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR
M,3D*(RP@9G5Z>GD*;7-G:60@(E5S97)S(@IM<V=S='(@(E]5<W5A<FES(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E
M<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B57-U87)I<R!D96P@<VES=&5M
M83HB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,30@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C0R"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(E5Z8F5K:7-T86XB
M"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$P,2!L:6(O5D93+V9I;&4N<&AP.C$X
M.`IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T
M<B`B16P@9&ER96-T;W)I(%9&4R!N;R!E>&ES=&5I>"XB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3$V"FUS9VED(")686-A=&EO;B(*;7-G<W1R
M(")!8G/H;F-I82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX-C8*;7-G:60@
M(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B3&5S
M('5B:6-A8VEO;G,@=N!L:61E<R!Q=64@<R=H86X@=')O8F%T('/S;CHB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8S.`IM<V=I9"`B5F%L:61I
M='DB"FUS9W-T<B`B5F%L:61E<V$B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(U-"!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3DV"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G
M<W1R(")686QO<B!E;B!M:6YU=',@82!P87)T:7(@9"=A<F$N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C@U-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$W-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I<R!O=F5R('1H92!M87AI;75M
M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B16P@=F%L;W(@<W5P97)A(&QA(&QO
M;F=I='5D(&W@>&EM82!D92`E<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C(T-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(V-B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C,Q-`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDR-@IM<V=I9"`B5F%L
M=65S(@IM<V=S='(@(E9A;&]R<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M,3`Y(&QI8B](;W)D92]&;W)M+G!H<#HR,3@V"FUS9VED(")686QU97,@=&\@
M<V5L96-T(&9R;VTB"FUS9W-T<B`B5F%L;W)S('%U92!S)VAA;B!S96QE8V-I
M;VYA<B!D92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-#D*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B5F%N=6%T=2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S8*;7-G:60@(E9A
M<FEA8FQE(@IM<V=S='(@(E9A<FEA8FQE(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#$*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-0IM<V=I9"`B5F5N97IU96QA
M(@IM<V=S='(@(E9E;F7G=65L82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M
M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B
M2&$@9F%L;&%T(&QA('9E<FEF:6-A8VGS.B#I<R!P;W-S:6)L92!Q=64@<R=H
M86=I(&%L=&5R870@96P@;6ES<V%T9V4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HW,#`*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B5F5R<VGS
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P,PIM<V=I9"`B5F5R
M<VEO;B!#;VYT<F]L(@IM<V=S='(@(D-O;G1R;VP@9&4@=F5R<VEO;G,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R(")!;&EN96%C:?,@
M=F5R=&EC86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(D9A
M<F-I;65N="!V97)T:6-A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R(")6
M97)T:6-A;#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV-@IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(DUO;'0@86QT(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR-#(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T
M.`IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B5FEE=&YA;2(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")6:65T;F%M97-E("A625-#24DI
M(@IM<V=S='(@(E9I971N86UI=&$@*%9)4T-)22DB"@HC.B!L:6(O2&]R9&4O
M34E-12]#;VYT96YT<RYP:'`Z.34U"B,L('!H<"UF;W)M870*;7-G:60@(E9I
M97<@)7,B"FUS9W-T<B`B5FES=6%L:71Z87(@)7,B"@HC.B!L:6(O0FQO8VLO
M:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E
M(@IM<V=S='(@(E9I<W5A;&ET>F%R('5N82!PX&=I;F$@=V5B(&5X=&5R;F$B
M"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#$T"B,L('!H<"UF
M;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B5FES=6%L:71Z87(@
M8V]M(&$@)7,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C0V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*
M;7-G<W1R("));&QE<R!697)G97,@8G)I=.!N:7%U97,B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(T-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0W"FUS9VED(")6
M:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R("));&QE<R!697)G97,@;F]R
M9"UA;65R:6-A;F5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#<*;7-G
M:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B5FES:6)I;&ET870B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4P"FUS9VED(")6:7-I8FEL:71Y
M.B`B"FUS9W-T<B`B5FES:6)I;&ET870Z("(*"B,Z(&QI8B].970O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z-SD*;7-G:60@(E9O9&%F;VYE($ET86QY
M('9I82!33510(@IM<V=S='(@(E9O9&%F;VYE(&0G273@;&EA('!E<B!V:6$@
M9&4@4TU44"(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R(")!1%9%4E3(3D-)
M02(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"B,L('!H<"UF;W)M
M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&
M4D]-("5S+B(*;7-G<W1R(")!5LU3(2!%3$E-24Y!4B!,02!315'<R$Y#24$@
M34%.54%,345.5"!$12`E<RXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C4P"FUS9VED(")786QL:7,@86YD($9U='5N
M82(*;7-G<W1R(")786QL:7,@:2!&=71U;F$B"@HC.B!L:6(O2&]R9&4O3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*;7-G:60@(E=A<FYI
M;F<B"FUS9W-T<B`B07;M<R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ-#4@
M<&\O=')A;G-L871I;VXN<&AP.C8X,2!P;R]T<F%N<VQA=&EO;BYP:'`Z-S$Q
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW,C4@<&\O=')A;G-L871I;VXN<&AP
M.C$P-C`@<&\O=')A;G-L871I;VXN<&AP.C$P-CD*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C$P-S<@<&\O=')A;G-L871I;VXN<&AP.C$P.#<@<&\O=')A;G-L
M871I;VXN<&AP.C$P.3<*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q,#<@<&\O
M=')A;G-L871I;VXN<&AP.C$Q,3,@<&\O=')A;G-L871I;VXN<&AP.C$R,S4*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C$R-#4@<&\O=')A;G-L871I;VXN<&AP
M.C$R-3$@<&\O=')A;G-L871I;VXN<&AP.C$R-S$*(RP@9G5Z>GD*;7-G:60@
M(E=A<FYI;F<Z("(*;7-G<W1R(")!=NUS(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B
M1&,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED
M(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@(E!R979I<VGS(&1E;"!T96UP
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,S0*;7-G:60@
M(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R("));F9O<FUA8VGS
M(&UE=&5O<F]L\F=I8V$@<')O<&]R8VEO;F%D82!P97(B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z.#DR"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R(")7
M96%T:&5R+F-O;2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED
M(")796(B"FUS9W-T<B`B5V5B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,V-PIM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B3&QO8R!W96(B"@HC
M.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7965K;'DB
M"FUS9W-T<B`B4V5T;6%N86QM96YT(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO
M8FEL92YP:'`Z,C@*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B0F5N=FEN9W5T
M<R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3`@=&5M<&QA=&5S
M+VQO9VEN+VUO8FEL92YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC
M;VUE('1O("5S(@IM<V=S='(@(D)E;G9I;F=U=',@82`E<R(*"B,Z(&QA;F=T
M97-T,BYP:'`Z,30*;7-G:60@(E=E;&-O;64@=&\@37D@4$A0($%P<&QI8V%T
M:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP
M.C(Y('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R(")"96YV:6YG=71S+"`E<R(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")797-T97)N("A)
M4T\M.#@U.2TQ*2(*;7-G<W1R(")/8V-I9&5N=&%L("A)4T\M.#@U.2TQ*2(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED(")797-T97)N("A)
M4T\M.#@U.2TQ-2DB"FUS9W-T<B`B3V-C:61E;G1A;"`H25-/+3@X-3DM,34I
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(T-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-S@*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(E/@:&%R82!/8V-I
M9&5N=&%L(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P
M;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R(")1=6EN82!A<&QI8V%C:?,@:&%U
M<FEA(&1E(&UO<W1R87(@)7,@96X@:6YI8VEA<B!L82!S97-S:?,_(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(E=H870@:7,@
M=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(E%U:6X@Z7,@96P@
M8V%RX&-T97(@9&5L:6UI=&%D;W(_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,C0*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E
M<C\B"FUS9W-T<B`B475I;B#I<R!E;"!C87+@8W1E<B!D92!C:71A8VGS/R(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S
M(@IM<V=S='(@(E%U:6YE<R!F87-E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,S$*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T
M:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B4&QU9VEN<R!H86)I;&ET
M871S(&1E(&PG961I=&]R(&1E('1E>'0@96YR:7%U:70N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I
M9"`B5VED=&@B"FUS9W-T<B`B06UP;&%D82(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HS,3(S"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B
M06UP;&%D82!D92!L97,@=6YI=&%T<R!#4U,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S0W"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H
M92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L
M;V<M:6XI.B(*;7-G<W1R(")!;7!L861A(&1E;"!M96[Z("5S(&1E(&PG97-Q
M=65R<F$@*&1I<W!O;FEB;&4@96X@;&$@<')O<&5R82!S97-S:?,I.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS
M9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B06UP;&%D82!D92!L
M82!T875L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@(E5N:71A="!D
M)V%M<&QA9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(D%M<&QA9&$Z(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U.0IM<V=I9"`B5VEK:2(*
M;7-G<W1R(")7:6MI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C$*;7-G:60@(E=I;F0B"FUS9W-T<B`B5F5N="(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")7
M:6YD($5A<FQY(@IM<V=S='(@(E9E;G0@82!P<FEM97)A(&AO<F$B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C<X"FUS9VED(")7:6YD('-P965D(&EN(&MN
M;W1S(@IM<V=S='(@(E9E;&]C:71A="!D96P@=F5N="!E;B!N=7-O<R(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,34T"FUS9VED(")7:6YD.B(*;7-G<W1R
M(")696YT.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S0*
M;7-G:60@(E=I;F0Z("(*;7-G<W1R(")696YT.B`B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R(")3879I97-A
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X,`HC+"!F=7IZ>0IM
M<V=I9"`B5VES:&QI<W1S(@IM<V=S='(@(DQL:7-T97,@9&4@9&5S:71J;W,B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB"FUS
M9W-T<B`B1F5I;F$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$R-"!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM
M<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(D%D<F7G82!D92!L82!F96EN
M82(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS
M9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(E1E;.AF;VX@9&4@;&$@9F5I;F$B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$V.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")7<FET:6YG('5P9&%T960@:&5L<"!F:6QE('1O("5S+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(Y"FUS9VED(")8
M+5)E9B(*;7-G<W1R(")8+5)E9B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS
M9W-T<B`B3&EM:71A8VEO;G,@8N!S:7%U97,@6#4P.78S(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3(*;7-G:60@(E@U,#EV,R!%>'1E;F1E
M9"!+97D@57-A9V4B"FUS9W-T<B`BVG,@9&4@;&$@8VQA=2!E<W1E<V$@>#4P
M.78S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@
M(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B3F]M
M(&%L=&5R;F%T:74@9"=A<W-U;7!T92!8-3`Y=C,B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y
M($ED96YT:69I97(B"FUS9W-T<B`B261E;G1I9FEC861O<B!D92!C;&%U(&0G
M87-S=6UP=&4@6#4P.78S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HV.#(*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(D5X=&5N
M<VEO;G,@6#4P.'8S(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@
M(EE9(@IM<V=S='(@(D%!(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,X-B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#(W"FUS9VED(")965E9(@IM<V=S='(@(D%!04$B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`P,0IM<V=I9"`B66%H;V\A
M(&UA<"(*;7-G<W1R(")-87!A(&1E(%EA:&]O(2(*"B,Z(&QI8B](;W)D92]-
M86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R(")!;G5A
M;&UE;G0B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C4R"FUS9VED(")996UE;B(*;7-G<W1R("))96UE;B(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX.#4*;7-G:60@(EEE
M<R(*;7-G<W1R(")3[2(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]A9W)E
M96UE;G1?8F]T=&]M+FEN8SHV"FUS9VED(")997,L($D@06=R964B"FUS9W-T
M<B`B4^TL(&AO(&%C8V5P=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$
M12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE3
M25=91RXB"FUS9W-T<B`B4V]U(&5N(&5L($U/1$4@5$585"X@57-E=2!E;"!B
M;W3S(%L\/ET@<&5R('1O<FYA<B!A(%=94TE764<N(@H*(SH@;&EB+TAO<F1E
M+G!H<#HQ,C@X"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*
M;7-G<W1R(").;R!E<W1E=2!A=71E;G1I8V%T<RXB"@HC.B!L:6(O2&]R9&4O
M261E;G1I='DN<&AP.C,P,@HC+"!F=7IZ>0IM<V=I9"`B66]U(&-A;B!N;W0@
M:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM
M<V=S='(@(DYO('!O9&5U(&EN8VQO=7)E(&5L(&-A<N!C=&5R("=<7"<@96X@
M96P@;F]M(&-O;7!L970N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-34@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-S4*;7-G:60@(EEO=2!D:60@;F]T(&5N
M=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`B3F\@:&5U(&EN
M=')O9'7O="!U;F$@861R9>=A(&5L96-T<O)N:6-A(';@;&ED82XB"@HC.B!L
M:6(O2&]R9&4O1&%T82YP:'`Z,C<P"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@
M9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM
M<V=S='(@(B(*(DYO(&AE=2!A<W-O8VEA="!C87`@8V%M<"!D92!L)V%R>&EU
M(&EM<&]R=&%T(&%M8B!E;',@8V%M<',@8V]R<F5S<&]N96YT<R!D92`E(@HB
M<RXB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3`S"FUS9VED(")9;W4@:&%V
M92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(DAE=2!S;W)T:70@9&4@;&$@
M<V5S<VGS+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B
M"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L
M(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@
M:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@HB2&5U
M(&0G:6YT<F]D=6ER('5N(&[Z;65R;R!D92!T96SH9F]N(&WR8FEL(';@;&ED
M+"!N;VWI<R!D[6=I=',@86UB('5N("<K)R`B"B)O<&-I;VYA;"!P97(@86P@
M<')E9FEX(&1E('1R=6-A9&$@:6YT97)N86-I;VYA;"XB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!V86QU92XB"FUS9W-T<B`B2&5U(&0G:6YT<F]D=6ER('5N('9A;&]R
M(';@;&ED+B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G
M:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@
M=7-E(%-I9VYU<',N(@IM<V=S='(@(DAE=2!D92!C;VYF:6=U<F%R('5N(&UO
M=&]R(&1E($1A=&%4<F5E('!E<B!U=&EL:71Z87(@06QT97,N(@H*(SH@;&EB
M+TAO<F1E+G!H<#HT,S$*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&
M4R!B86-K96YD+B(*;7-G<W1R(")(974@9&4@8V]N9FEG=7)A<B!U;B!M;W1O
M<B!D92!61E,N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R
M92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R(")(
M974@9&4@9&5S8W)I=7)E(&5L('!R;V)L96UA(&%B86YS(&0G96YV:6%R+6YE
M(&PG:6YF;W)M92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H
M97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B2&5U(&0G:6YT<F]D
M=6ER(&5L(%523"!Q=64@87%U97-T(&5N;&QAYR!I;F1I8V$N(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M=7-T('-E
M;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B2&5U(&1E
M('-E;&5C8VEO;F%R('5N('-E<G9I9&]R('%U92!V=6QG=65U(&5L:6UI;F%R
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E
M8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B2&5U(&0G
M97-P96-I9FEC87(@=6X@;F]M(&0G=7-U87)I('%U92!V=6QG=65U(&5S8F]R
M<F%R+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B2&5U(&0G
M97-P96-I9FEC87(@=6X@;F]M(&0G=7-U87)I('%U92!V=6QG=65U('-U<')I
M;6ER+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@
M=7-E<FYA;64@=&\@861D+B(*;7-G<W1R(")(974@9"=E<W!E8VEF:6-A<B!Q
M=6EN(&YO;2!D)W5S=6%R:2!V;VQE=2!A9F5G:7(N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M
M92!T;R!U<&1A=&4N(@IM<V=S='(@(DAE=2!D)V5S<&5C:69I8V%R(&5L(&YO
M;2!D)W5S=6%R:2!Q=64@=F]L974@86-T=6%L:71Z87(N(@H*(SH@;&EB+TAO
M<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(DAE=2!D)V5S
M<&5C:69I8V%R('%U:6YA(&%C8VGS('9O;&5U(&5X96-U=&%R+B(*"B,Z(&QI
M8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<R"FUS9VED(")9
M;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(DAE
M=2!D92!T96-L96IA<B!U;B!N;W4@;F]M(&1E(&-A=&5G;W)I82XB"@HC.B!L
M:6(O2&]R9&4O075T:"YP:'`Z.#DQ"B,L('!H<"UF;W)M870*;7-G:60@(EEO
M=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN
M+B(*;7-G<W1R("(B"B),82!V;W-T<F$@<V5S<VGS(&5N("5S(&AA(&5X<&ER
M870N(%-I('5S('!L874L(&EN:6-I974@=6YA(&YO=F$@<V5S<VGS+B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9;W5R
M($5M86EL($%D9')E<W,B"FUS9W-T<B`B3&$@=F]S=')A(&%D<F7G82!E;&5C
M='+R;FEC82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#(*;7-G:60@
M(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B3&$@=&5V82!A9')EYV$@
M9&4@<F5S<&]S=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(EEO=7(@26YF
M;W)M871I;VXB"FUS9W-T<B`B3&$@=F]S=')A(&EN9F]R;6%C:?,B"@HC.B!L
M:6(O2&]R9&4O075T:"YP:'`Z.#DU"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@
M8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y
M;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B
M(@HB3&$@=F]S=')A(&%D<F7G82!D)TEN=&5R;F5T(&AA(&-A;G9I870@9&5S
M('%U92!H974@8V]M96[G870@;&$@<V5S<VGS("5S+B`B"B)097(@<F%O;G,@
M9&4@<V5G=7)E=&%T+"!H974@9&4@<F5I;FEC:6%R(&QA('-E<W-I\RXB"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U
M<B!.86UE(@IM<V=S='(@(D5L('9O<W1R92!N;VTB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]N;V%D9"YI;F,Z.0HC+"!F=7IZ>0IM<V=I9"`B(@HB66]U
M<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D
M:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*(D5L('9O<W1R
M92!M;W1O<B!D)V%U=&5N=&EC86-I\R!N;R!P97)M970@<75E(&5S(&QL:7-T
M:6X@96QS('5S=6%R:7,L(&\@8ND@(@HB<&5R(&%L9W5N82!R8?,@87%U97-T
M82!C87)A8W1E<NUS=&EC82!E<W3@(&EN:&%B:6QI=&%D82XB"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.CD*;7-G:60@(B(*(EEO=7(@
M875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I
M;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D
M(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@HB16P@=F]S=')E
M(&UO=&]R(&0G875T96YT:6-A8VGS(&YO('!E<FUE="!Q=64@97,@;&QI<W1I
M;B!E;',@=7-U87)I<RP@;R!BZ2`B"B)P97(@86QG=6YA(')A\R!A<75E<W1A
M(&-A<F%C=&5R[7-T:6-A(&5S=.`@:6YH86)I;&ET861A+B(*"B,Z(&QI8B](
M;W)D92]!=71H+G!H<#HX.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U
M<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B
M96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO
M=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B
M"B)396UB;&$@<75E(&5L(&YA=F5G861O<B!H82!C86YV:6%T(&1E<R!Q=64@
M=F%U(&-O;65NYV%R(&QA('-E<W-I\R`E<RX@4&5R("(*(G)A;VYS(&1E('-E
M9W5R971A="P@:&5U(&1E('1O<FYA<B!A(&5N=')A<B!A;"!S:7-T96UA+B(*
M"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4P"FUS9VED(")9;W5R(&)R;W=S
M97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S='(@(D5L
M('9O<W1R92!N879E9V%D;W(@;F\@86-C97!T82!A<75E<W1A(&-A<F%C=&5R
M[7-T:6-A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R
M"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES
M('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T
M;R!P<FEN="XB"FUS9W-T<B`B(@HB16P@=F]S=')E(&YA=F5G861O<B!N;R!P
M97)M970@87%U97-T82!O<&-I\R!D)VEM<')E<W-I\RX@4')E;6D@0V]N=')O
M;"`K(%`@(@HB<&5R(&EM<')I;6ER+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR-#<*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S
M='(@(EIO;F$@:&]RX')I82!A8W1U86PZ(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$T.`IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G
M<W1R("))9&5N=&ET870@<')E9&5T97)M:6YA9&$Z(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Y,0IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S
M='(@(DYO;2!C;VUP;&5T.B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ-#4*
M;7-G:60@(B(*(EEO=7(@9V5T=&5X="!V97)S:6]N(&ES('1O;R!O;&0@86YD
M(&1O97,@;F]T('-U<'!O<G0@4$A0(&YA=&EV96QY+EQN(@HB3F]T(&%L;"!S
M=')I;F=S('=I;&P@8F4@97AT<F%C=&5D+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(DQA
M(&YO=F$@8V]N=')A<V5N>6$@<&5R(&$@)7,@Z7,Z("5S(@H*(SH@;&EB+TAO
M<F1E+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO
M;BXB"FUS9W-T<B`B3&5S(&]P8VEO;G,@:&%N(&5S=&%T(&%C='5A;&ET>F%D
M97,@<&5R(&$@;&$@9'5R861A(&0G87%U97-T82!S97-S:?,N(@H*(SH@;&EB
M+TAO<F1E+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H
M879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`B3&5S(&]P8VEO;G,@:&%N(&5S
M=&%T(&%C='5A;&ET>F%D97,N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B
M"FUS9W-T<B`B4R=H82!R96EN:6-I870@;&$@=F]S=')A(&-O;G1R87-E;GEA
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*
M(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA
M:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G
M<W1R("(B"B)3)VAA(')E:6YI8VEA="!L82!V;W-T<F$@8V]N=')A<V5N>6$L
M(')E=FES82!E;"!C;W)R974@96QE8W1R\FYI8R!I(&EN:6-I82`B"B)L82!S
M97-S:?,@86UB(&QA(&YO=F$@8V]N=')A<V5N>6$N(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V
M97)S.B(*;7-G<W1R(")397)V:61O<G,@<F5M;W1S.B(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q."!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4T
M"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@(DEU9V]S;.!V:6$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S
M='(@(EIA:7)E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(U-@IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(EK@;6)I82(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-3<*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(EII;6)A8G=E(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G<W1R("):
M:7!P>2(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T
M97,N<&AP.C$W,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K
M<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(EM/
M8W5L=&$@=&5X="!C:71A=%TB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HU
M-@IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");26YF;W)M92!D
M96P@<')O8FQE;6%=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5"
M;&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T
M<B`B6TUO<W1R82!T97AT(&-I=&%T("TB"@HC.B!L:6(O2&]R9&4O5&5X="]&
M:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B
M6TUO<W1R82!T97AT(&-I=&%T("T@)7,@;.UN:65S72(*"B,Z(&QI8B](;W)D
M92YP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S
M72(*;7-G<W1R(");;.UN:6$@)7,@9&4@)7-=(@H*(SH@;&EB+TAO<F1E+G!H
M<#HQ-#,R('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!
M9&UI;FES=')A=&EO;B(*;7-G<W1R(")?061M;FES=')A8VGS(@H*(SH@;&EB
M+V%P:2YP:'`Z,3,V"FUS9VED(")?0TQ)(@IM<V=S='(@(E]#3$DB"@HC.B!L
M:6(O87!I+G!H<#HQ,C0*;7-G:60@(E]$871A5')E92(*;7-G<W1R(")?07)B
M<F4@9&4@9&%D97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S
M='(@(E]3=7!R:6UI<B!F:6QA(@H*(SH@;&EB+V%P:2YP:'`Z,3$V"FUS9VED
M(")?1W)O=7!S(@IM<V=S='(@(E]'<G5P<R(*"B,Z(&QI8B](;W)D92]-96YU
M+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@(E]!:G5D82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B7U!R;W!I
M971A=',@9&4@;&$@:6UA=&=E+BXN(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP
M.C$Y-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R(")?26YI8VEA(&QA('-E<W-I
M\R(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T
M(@IM<V=S='(@(E]3=7)T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN
M+BXB"FUS9W-T<B`B7TUO9&EF:6-A(&PG96YL;&'G+BXN(@H*(SH@;&EB+TAO
M<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`B7T]P
M8VEO;G,B"@HC.B!L:6(O87!I+G!H<#HQ,C`*;7-G:60@(E]097)M:7-S:6]N
M<R(*;7-G<W1R(")?4&5R;6ES;W,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@
M3&EN:RXN+B(*;7-G<W1R(")?16QI;6EN82!L)V5N;&QAYRXN+B(*"B,Z(&QI
M8B]A<&DN<&AP.C$P.`IM<V=I9"`B7U-E='5P(@IM<V=S='(@(E]#;VYF:6=U
M<F%C:?,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S(*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM
M<V=S='(@(E]0<F]P:65T871S(&1E(&QA('1A=6QA+BXN(@H*(SH@;&EB+V%P
M:2YP:'`Z,3$R"FUS9VED(")?57-E<G,B"FUS9W-T<B`B7U5S=6%R:7,B"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.C@Y,`IM<V=I9"`B861D<F5S<R!B;V]K
M(@IM<V=S='(@(FQL:6)R971A(&0G861R96-E<R(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HW,3$*(RP@9G5Z>GD*;7-G:60@(F%N(&5R<F]R(&AA<R!O8V-U
M<F5D.B(*;7-G<W1R(")3)VAA('!R;V1U[W0@=6X@97)R;W(@:7)R97!A<F%B
M;&4N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HX.#(*;7-G:60@(F-A;&5N
M9&%R(@IM<V=S='(@(F%G96YD82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,3<P(&QI8B]";&]C:R]M971A<BYP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G
M:60@(F-A;&TB"FUS9W-T<B`B8V%L;6$B"@HC.B!L:6(O2&]R9&4O34E-12]#
M;VYT96YT<RYP:'`Z-3@X"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(E!R
M96UI(&%Q=>TB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#0U('!O+W1R86YS
M;&%T:6]N+G!H<#HU-3`@<&\O=')A;G-L871I;VXN<&AP.C8Q,0HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-S0Y('!O+W1R86YS;&%T:6]N+G!H<#HX,3`@<&\O
M=')A;G-L871I;VXN<&AP.C@X-PHC+"!F=7IZ>0IM<V=I9"`B9&]N92(*;7-G
M<W1R(")F970B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-34R('!O+W1R86YS
M;&%T:6]N+G!H<#HU.#0@<&\O=')A;G-L871I;VXN<&AP.C8Q,PHC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-S<X('!O+W1R86YS;&%T:6]N+G!H<#HX,3(@<&\O
M=')A;G-L871I;VXN<&AP.C@Y,`HC+"!F=7IZ>0IM<V=I9"`B9F%I;&5D(@IM
M<V=S='(@(F9A;&QI9&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV-PIM<V=I9"`B9F%L;&EN9R(*;7-G<W1R(")E<W3@(&-A
M:65N="(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX-#D*;7-G:60@(F9I
M;&4B"FUS9W-T<B`B87)X:74B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(Y
M"B,L(&9U>GIY"FUS9VED(")F;W5N9#H@(@IM<V=S='(@(E9E;G0Z("(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S4X(&QI8B]";&]C:R]M971A<BYP:'`Z,S@T"B,L('!H<"UF;W)M870*;7-G
M:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B9&5S(&1E
M;"`E<R`H)7,I(&$@;&5S("5S("5S(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(S,@IM<V=I9"`B:#HB"FUS9W-T<B`B:#HB"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S,Q"FUS9VED
M(")H:"(*;7-G<W1R(")H:"(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C(R(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-C0*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R(")I;6UE9&EA="(*"B,Z(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y
M"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B:6YS97)E:7@B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=
M(@IM<V=S='(@(FSM;FEE<UTB"@HC.B!L:6(O5D93+TE33U=R:71E<B]M:VES
M;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R
M(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B4R=H82!P<F]D
M=>]T('5N(&-O9&D@9"=E<G)O<B`E9"!D96P@;6MI<V]F<R!E;B!C<F5A<B!)
M4T\N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,T
M,@IM<V=I9"`B;6TB"FUS9W-T<B`B(VUM(R(*"B,Z(&QI8B](;W)D92]0<F5F
M<R]522YP:'`Z,C@W('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,#4*
M;7-G:60@(FYA;64B"FUS9W-T<B`B;F]M(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C,W.`HC+"!F=7IZ>0IM<V=I9"`B;F]T(&-H86YG960B"FUS9W-T<B`B
M4V5N<V4@8V%N=FES+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S$*(RP@
M9G5Z>GD*;7-G:60@(FYO="!F;W5N9"(*;7-G<W1R(").;R!S)VAA('1R;V)A
M="`E<RXB"@HC.B!L:6(O2&]R9&4O4E!#+G!H<#HQ,C$*;7-G:60@(FYO="!I
M;7!L96UE;G1E9"(*;7-G<W1R(")N;R!S)VAA(&EM<&QE;65N=&%T(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y"FUS9VED(")N;W0@>65T
M(&EM<&QE;65N=&5D(@IM<V=S='(@(F5N8V%R82!N;R!S)VAA(&EM<&QE;65N
M=&%T(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HX-S0*;7-G:60@(FYO=&5P
M860B"FUS9W-T<B`B8FQO8R!D92!N;W1E<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E
M;G0B"FUS9W-T<B`B<&5R8V5N=&%T9V4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B
M"FUS9W-T<B`B<.UX96QS(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-CD*;7-G:60@(G)I<VEN9R(*;7-G<W1R(")E<W3@('!U
M:F%N="(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.3@*;7-G:60@(G-H
M;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B;6]S=')A<B!D:69E<NAN8VEE<R(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,3,*;7-G:60@
M(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R(")S;7,R96UA:6P@<&5R('9I
M82!D92!(5%10(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,U.`IM<V=I9"`B<W,B"FUS9W-T<B`B<W,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B<W1E861Y(@IM
M<V=S='(@(F-O;G-T86YT(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HX.3@*
M;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R(")L;&ES=&$@9&4@=&%S<75E<R(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW,C4*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(G1H92!(;W)D92!03R!F:6QE(&9O<B!T:&4@;&]C86QE("5S
M(&1O97,@;F]T(&5X:7-T.B(*;7-G<W1R(").;R!E>&ES=&5I>"!L)V%R>&EU
M('1E;7!O<F%L(%PB)7-<(BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!L:6(O
M2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B='EP92!T:&4@<&%S
M<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R(")T96-L96=E=2!L82!C
M;VYT<F%S96YY82!D=65S('9E9V%D97,@<&5R(&-O;F9I<FUA<BUL82(*"B,Z
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP
M.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@(G5N:69I8V%T(@H*(SH@;&EB
M+TAO<F1E+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T
M<B`B<V5N<V4@;F]M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C,W-0HC+"!F
M=7IZ>0IM<V=I9"`B=7!D871E9"(*;7-G<W1R(")!8W1U86QI='IA<B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(R(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C0*;7-G:60@(G5S97(@<V5L96-T
M(@IM<V=S='(@(G-E;&5C8VGS(&1E(&PG=7-U87)I(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T
M<B`B=D-A<F0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C(T"FUS9VED(")W.B(*;7-G<W1R(")W.B,C(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S
M='(@(G=E871H97(N8V]M(@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&\O8W-?0UHN<&\`````````````````````````````
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#<R,3$W,0`Q,#4Q-30S,S<U-``P
M,3<V-#<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````(R!#>F5C:"!T<F%N<VQA=&EO;G,@9F]R($AO<F1E+@HC($-O<'ER:6=H
M="`H0RD@,C`P-"!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R
M:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE($AO<F1E('!A
M8VMA9V4N"B,@4&%V96P@0VAY=&EL(#QP879E;$!C:'ET:6PN=&L^+"`R,#`Q
M+3(P,#0N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I
M;VXZ($AO<F1E(#,N,%QN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L
M:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P
M+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#0M,#<M
M,C(@,3$Z-#DM,#<P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!-:6QO<R!7:6UM
M97(@/'=I;6UE<D!Z8W4N8WH^7&XB"B),86YG=6%G92U496%M.B!#>F5C:"`\
M:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN
M(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y
M+3)<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*(E!L
M=7)A;"U&;W)M<SH@;G!L=7)A;',],SL@<&QU<F%L/2AN)3$P/3TQ("8F(&XE
M,3`P(3TQ,2`_(#`@.B!N)3$P/CTR("8F(&XE(@HB,3`\/30@)B8@*&XE,3`P
M/#$P('Q\(&XE,3`P/CTR,"D@/R`Q(#H@,BD[7&XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S8Y"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@
M9&%Y<R!A9V\I(@IM<V=S='(@(B`H</AE9"`E<R!D;GDI(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S<P"B,L('!H<"UF;W)M870*;7-G:60@
M(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(@*%#X[7-T=7!O=OT@:VSMZ"`E
M<RDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<W"B,L('!H<"UF
M;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B("AV("5S(&1N
M96-H*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S,*;7-G:60@
M(B`H=&]D87DI(@IM<V=S='(@(B`H9&YE<RDB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S<U"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@
M*'KM=')A*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S$*;7-G
M:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(@*';H97)A*2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-38@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,V,0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-#`W"FUS9VED("(@870@(@IM<V=S='(@(B!R>6-H;&]S="`B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M3F5N[2!A9')E<^'X96TB"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@
M=F%L:60@8VAO:6-E+B(*;7-G<W1R("(E<R!N96QZ92!Z=F]L:70N(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HV-3D*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#0R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@
M:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R("(G)7,G(&YE;NT@;F%K
M;VYF:6=U<F]VX6X@=B!R96=I<W1R96-H($AO<F1E('-Y<W3I;74N(@H*(SH@
M9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B<E<R<@</AE:VQA9&'H(&YE8GEL(&YA;&5Z96XN(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HU-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T
M<B`B)7,G(&)Y;"!P^&EDX6X@9&\@<WES=.EM=2!S:W5P:6XN(@H*(SH@861M
M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S
M>7-T96TN(@IM<V=S='(@(B<E<R<@8GEL('#X:63A;B!D;R!S>7-TZ6UU('#X
M[7-T=7!O=OUC:"!P<N%V+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M
M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B
M)R5S)R!N96)Y;"!V>71V;_AE;CH@)7,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F
M("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B5D("5S(&$@)7,B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@
M>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@
M(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R("(E9"UD96YN[2!P^&5D<&]V[.\B
M"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B)7,@+2!O>F[A;65N[2(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`T"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B5S(&]T
M:7-K(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S
M='(@(B5S(&]P97)A8V4@^F1ROF)Y("T@<&]T=G)Z96[M(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B5S(&YA
M<W1A=F5N[2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR
M-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(E
M<R!R96=I<W1R86-E(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*
M;7-G<W1R("(E<R!P;V1M[6YK>2!P;W6^[7;A;NTB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C0R."!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C0Y,`HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8U,2!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B)7,@:FF^(&5X:7-T=6IE+B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Y(&QI8B]";&]C:R]M971A<BYP
M:'`Z,38U(&QI8B]";&]C:R]M971A<BYP:'`Z,C,Y"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S0U(&QI8B]";&]C:R]M971A<BYP:'`Z,S4Q"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S(&YA("5S("5S
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H
M92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K
M('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@
M<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(D]Z;F'H:70@<N%M9>AE
M:R!P<F\@=KEE8VAN>2!O<&5R86-E+"!K=&5RZ2!C:&-E=&4@=&7O('!R;W;I
M<W0N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,T,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(E<R!J92!P
M;[YA9&]VX6YO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R!M:6YU="(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(E
M<R!N96)Y;&\@;F%L97IE;F\N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E
M<R(*;7-G<W1R("(E<R!AOB`E<R!Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R
M97-S($)O;VLB"FUS9W-T<B`B)7,@861R97/A^"(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3$T"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@
M0V%L96YD87(B"FUS9W-T<B`B)7,@:V%L96YDX?@B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDP-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S
M($YO=&5P860B"FUS9W-T<B`B)7,@>N%P:7-N[6LB"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDS,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S
M(%1A<VML:7-T(@IM<V=S='(@(B5S('-E>FYA;2#Z:V]L^2(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@
M(B5S.B`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN
M<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S
M86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W
M87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O
M=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS-C4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q,`HC+"!F=7IZ
M>0IM<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(L(&[A<F%Z;W;]("5S("5S
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S
M(@IM<V=S='(@(BP@;N%R87IO=OT@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R
M;VT@)7,@=&\@)7,B"FUS9W-T<B`B+"!P<F]M[&YNX2!O9"`E<R!D;R`E<R(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,CDT(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,S0X"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$R.`HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0Y"FUS9VED
M("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@=OUB['(@+2TB"@HC.B!L:6(O
M0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S
M='(@(C$R(&AO9&EN;W;](&9O<FWA="(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B,C0@:&]D:6YO
M=OT@9F]R;>%T(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G
M:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T(&AO9&EN(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U!A9V5R+G!H<#HV.0HC+"!F=7IZ>0IM<V=I9"`B/%!R979I;W5S
M(@IM<V=S='(@(E#X961C:&]Z[2!S='+A;FMA(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ,3D*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U
M:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B4')O('1E;G1O(&)L;VL@
M:F4@=GF^861O=N%N(&1A=&%BX7IO=OT@>F1R;VHN(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ-C`*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S
M(&]C8W5R<F5D(@IM<V=S='(@(E9Y<VMY=&QA('-E('KA=F&^;N$@8VAY8F$B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@
M(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE
M<W-A9V4N(@IM<V=S='(@(E!R;R!Z8;EI9G)O=N%N[2!Z<'+A=GD@:F4@;G5T
M;F\@<&]UONUT('9E^&5J;OT@4$=0(&ML[>@N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3$V-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME
M>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS
M9W-T<B`B4')O('9E<FEF:6MA8VD@<&]D97!S86[I('IP<N%V>2!J92!N=71N
M;R!P;W6^[70@=F7X96IN_2!01U`@:VSMZ"XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,#DW"FUS9VED("(B"B)!('!U8FQI8R!01U`@
M:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB4')O
M(&1EN6EF<F]VX6[M('IP<N%V>2!J92!N=71N;R!P;W6^[70@=F7X96IN_2!0
M1U`@:VSMZ"P@<')I=N%T;NT@4$=0(&ML[>@@82`B"B)H97-L;RXB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$U"FUS9VED("(B"B)!
M('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T
M<B`B(@HB4')O('!O9&5P<^%N[2!Z<'+A=GD@:F4@;G5T;F\@<&]UONUT('9E
M^&5J;OT@4$=0(&ML[>@L('!R:7;A=&[M(%!'4"!K;.WH(&$@(@HB:&5S;&\N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#4*;7-G
M:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@
M82!M97-S86=E+B(*;7-G<W1R("(B"B)0<F\@9&6Y:69R;W;A;NT@>G!RX79Y
M(&IE(&YU=&YO('!O=;[M="!V9?AE:F[](%,O34E-12!K;.WH+"!P<FEVX71N
M[2!3+TU)344@(@HB:VSMZ"!A(&AE<VQO+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)
M344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@HB
M4')O('!O9&5P<^%N[2!Z<'+A=GD@:F4@;G5T;F\@<&]UONUT('9E^&5J;OT@
M4R]-24U%(&ML[>@L('!R:7;A=&[M(%,O34E-12`B"B)K;.WH(&$@:&5S;&\N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G
M:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92XB"FUS9W-T<B`B4')O('IAN6EF<F]VX6[M('IP<N%V>2!J
M92!N=71N;R!P;W6^[70@=F7X96IN_2!3+TU)344@:VSMZ"XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"B,L(&9U>GIY"FUS
M9VED(")!32!#;&]U9',B"FUS9W-T<B`B6F%T8;YE;F\B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`HC+"!F=7IZ>0IM<V=I
M9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R(")/9'!O;&5D;NT@;&5H:_T@9.FY
MNR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q
M"FUS9VED(")!32!286EN(@IM<V=S='(@(E)A;F[M(&3IN;LB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@
M4VAO=V5R<R(*;7-G<W1R(")286YN[2!P^&5HX?)K>2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W
M(%-H;W=E<G,B"FUS9W-T<B`B4F%N;NT@<V[L:&]VZ2!P^&5HX?)K>2(*"B,Z
M('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G
M<W1R(")!32]032(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(D%022!)
M1"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(DEN9F]R;6%C
M92!O('1O;71O(&5D:71O<G4B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H
M<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B26YF;W)M86-E+BXN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM
M<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(E1E>'0@9&]L^2!D;R!O8G+A>FMU
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(E1E>'0@9&]P<F]S=/AE9"!O
M8G+A>FMU(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(W,`IM
M<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*
M;7-G<W1R(")6>71V;_AE;NT@5D93(&%D<F%SX?AE(&YE8GEL;R!P;W9O;&5N
M;RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS9VED
M(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R(")6
M>71V;_AE;NT@5D93('-O=6)O<G4@;F5B>6QO('!O=F]L96YO+B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HS"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT
M($EN9F]R;6%T:6]N(@IM<V=S='(@(E9AN64@:6YF;W)M86-E(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<U"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D
M(@IM<V=S='(@(E6^:79A=&5L<VOI(&AE<VQO(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O
M=6YT(&9R;WIE;BXB"FUS9W-T<B`B5;YI=F%T96QK_2#ZZ&5T(&)Y;"!Z86)L
M;VMO=N%N+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S,*;7-G
M:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`B5;YI=F%T96QKZ2#ZZ'1Y(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O
M<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D
M8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`B5FQOOB(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED
M(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B4/AI9&%T('!O9'-K=7!I;G4B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M
M:7-S:6]N(@IM<V=S='(@(E#X:61A="!P;V0M<'+A=F$B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@
M(E#X:61A=#HB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U
M<',N<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R(")0^&ED
M870@;F]V;W4@<VMU<&EN=2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`IM<V=I
M9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(E#X:61A="!N;W;A('!R
MX79A(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O
M=7`@=&\@7"(E<UPB(@IM<V=S='(@(E#X:61A="!P;V1S:W5P:6YU(&1O("<E
M<R<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T-PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO
M;B!T;R!<(B5S7"(B"FUS9W-T<B`B4/AI9&%T('!O9"UP<N%V82!D;R`G)7,G
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R
M.B(*;7-G<W1R(")0^&ED870@;F]VZ6AO('6^:79A=&5L93HB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34T"FUS9VED(")!
M9&0@8V]L=6UN(@IM<V=S='(@(E#X:61A="!S;&]U<&5C(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M
M96UB97)S(@IM<V=S='(@(E#X:61A="!N;W;I(.AL96YY(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T
M<B`B4/AI9&%T('#A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z
M:6QL82!3:61E8F%R(@IM<V=S='(@(E#X:61A="`E<R!M96YU(&IA:V\@8F_H
M;NT@<VQO=7!E8R!-;WII;&QY(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K
M.B(*;7-G<W1R(")0^&ED870@9&\@861R97/A^&4Z(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"FUS9VED(")!9&0@=&\@
M;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(E#X:61A="!D;R!MZ6AO(&%D<F5S
MX?AE(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM
M<V=S='(@(E#X:61A="!UOFEV871E;&4B"@HC.B!A9&UI;B]U<V5R+G!H<#HW
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB
M('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@
M<VEG;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B(@HB)R5S)R!B
M>6QO('#X:63A;F\@9&\@<WES=.EM=2P@86QE(&YE;'IE('#X:61A="!NX7-L
M961U:NUC[2!I;F9O<FUA8V4Z("5S+B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@
M<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(B<E<R<@8GEL
M;R!P^&EDX6YO(&1O('-Y<W3I;74N($WYOF5T92!S92!N>6[M('#X:6ALX7-I
M="!D;R!S>7-TZ6UU+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D
M+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S
M='(@(E#X:63A=N%N[2!UOFEV871E;/D@:F4@>F%B;&]K;W;A;F\N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#$*;7-G:60@(D%D9')E<W,B"FUS9W-T
M<B`B061R97-A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S.0IM
M<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D%D<F5SX?@B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M
M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS
M9W-T<B`B(@HB5GEK;V[A=F%T(&%D;6EN:7-T<F%C:2`M(&YA<W1A=F5N[2!P
M^.US='5P;W;]8V@@<'+A=B!P<F\@;W-T871N[2!UOFEV871E;&4B"@HC.B!A
M9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R
M86-E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,0IM<V=I9"`B
M061S(@IM<V=S='(@(DEN>F5RX71Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G
M:&%N:7-T86XB"FUS9W-T<B`B069G:.%N:7-TX6XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS
M9VED(")!;&)A;FEA(@IM<V=S='(@(D%L8N%N:64B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS
M9VED(")!;&=E<FEA(@IM<V=S='(@(D%LONUR<VMO(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B
M"FUS9W-T<B`B4/AE>F3M=FMA+T%L:6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB
M"FUS9W-T<B`B6F%R;W9N870B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@
M(EIA<F]V;N%N[3HB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G
M:60@(D%L;"(*;7-G<W1R(")6N64B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS
M9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R(")6N6EC:&YI
M(&]V[/AE;NT@=;YI=F%T96SI(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A
M9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R
M(")6N65C:&YY('-K=7!I;GDB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.CDQ(&9R86UE=V]R:R]097)M<R]097)M<R]D871A=')E92YP:'`Z
M-S4*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R(")6N65C:&YA('6^
M:79A=&5L<VOA('!RX79A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B
M"FUS9W-T<B`B5KEE8VAN>2#H='GX:2!S=')A;GDB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#<Q"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R
M97-S97,B"FUS9W-T<B`B4&]V;VQI="!V[6-E(&%D<F5S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4S-`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O
M<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B4&]V;VQI="!N87-T879E;NT@
M='EP=2!S973X[63L;OT@<V5Z;F%M/R(*"B,Z(&9R86UE=V]R:R]$871A5')E
M92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E>&ES=',B
M"FUS9W-T<B`B2FF^(&5X:7-T=6IE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$R,PIM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B
M06QT97)N871I=F[M($E-4U`@</AI:&SAN65N[2!D;R!S>7-TZ6UU(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-PIM<V=I9"`B06QT97)N871E($E-
M4U`@4&%S<W=O<F0B"FUS9W-T<B`B06QT97)N871I=F[M($E-4U`@:&5S;&\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DY"FUS9VED(")!;'1E<FYA
M=&4@24U34"!5<V5R;F%M92(*;7-G<W1R(")!;'1E<FYA=&EV;NT@24U34"!U
MOFEV871E;'-KZ2!J;>EN;R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C,U"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R
M(")!;'1E<FYA=&EV;NT@92UM86EL;W;A(&%D<F5S82(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM
M<V=S='(@(D%L=&5R;F%T:79N[2!V>F]R>2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B
M06QT97)N871E('1E>'0Z(@IM<V=S='(@(D%L=&5R;F%T:79N[2!T97AT.B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(D%M
M97)I8VOA(%-A;6]A(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HY-2!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B
M06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R(")">6QA
M('IA9.%N82!N97!O=F]L96[A(&AO9&YO=&$N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$V-PHC+"!F=7IZ>0IM<V=I9"`B06X@=6YK;F]W
M;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B;F%S=&%L82!C:'EB83HB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(D%N9&]R82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R(")!;F=O;&$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R(")!;F=U:6QL82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N
M;VYY;6]U<R!0<F]X>2(*;7-G<W1R(")!;F]N>6UN[2!P<F]X>2(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS
M9W-T<B`B3V1P;W;L[R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B
M"FUS9W-T<B`B06YT87)K=&EK82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG
M=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B06YT:6=U82!A($)A<F)U9&$B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS
M-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4X('1E;7!L871E
M<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N
M(@IM<V=S='(@(D%P;&EK86-E(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP
M.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@(E-E>FYA;2!A
M<&QI:V%C[2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@
M(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R(")!<&QI:V%C92!J92!P
M^&EP<F%V96YA(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*
M;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R(")0;W6^[70@
M<')O(&3L9&GH;ND@<V3M;&5N[2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(E-C:';A
M;&ET(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S
M"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(E#X:6)L:;YNX2!V
M96QI:V]S="(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R(")$=6)E;B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U
M-BDB"FUS9W-T<B`B07)A8G-K>2`H5VEN9&]W<RTQ,C4V*2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E($9I;&4@4VEZ
M92(*;7-G<W1R(")696QI:V]S="!A<F-H:79O=F%NZ6AO('-O=6)O<G4B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4X(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,`IM<V=I9"`B07)C:&EV92!.
M86UE(@IM<V=S='(@(DIMZ6YO(&%R8VAI=G4B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G
M:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU
M<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(E5RZ&ET["!C:&-E=&4@=GEM
M87IA=""^X61O<W0@;R!P^&EH;.&Y96[M(&1O("5S/R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB
M)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(E5RZ&ET["!S:2!P
M^&5J971E('9Y;6%Z870@)R5S)R!A('!O9'-K=7!I;GD_(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(D%R9V5N=&EN82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B07)MZ6YI92(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED(")!<FUE;FEA;B`H05)-4T-)
M22TX*2(*;7-G<W1R(")!<FWI;G-K_2`H05)-4T-)22TX*2(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(E5M[&[M
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B07)U8F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I
M;VX@27-L86YD(@IM<V=S='(@(D%S8V5N<VEO;B!)<VQA;F0B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R
M(")!<V-I:2!U;>QN[2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R(")!<VEE
M+W)E9VEO;B!4:6-HZ6AO(&]C9>%N=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT,C4*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D
M;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R(")0;[[A9&%T
M(&\@<&]T=G)Z96[M('#X960@<')O=F5D96[M;2!O<&5R86/M(/ID<KYB>3\B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$S"FUS9VED(")!<W-I
M9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`B4VQO=7!C92!S(/IK;VQY(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T;R!D96QE=&4@
M82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(E!O:W5S(&\@=GEM87KA
M;NT@;F5E>&ES='5J[6/M('-K=7!I;GDN(@H*(SH@861M:6XO<&5R;7,O9&5L
M971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B4&]K=7,@;R!V>6UA>N%N[2!N
M965X:7-T=6KM8^UC:"!UOFEV871E;'-K_6-H('!RX78N(@H*(SH@861M:6XO
M<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO
M;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")0;VMU<R!O(/IP<F%V
M=2!N965X:7-T=6KM8^UC:"!UOFEV871E;'-K_6-H('!RX78N(@H*(SH@<V5R
M=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O(&5D
M:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(E!O:W5S(&\@^G!R
M879U(&YE97AI<W1U:NUC[6AO('-D[6QE;NEH;R!O8FIE:W1U+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@V"FUS9VED(")!='1R:6)U=&5S(@IM
M<V=S='(@(D%T<FEB=71Y(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R(")3<G!E;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R(")!=7-T<N%L
M:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(E)A:V]U
M<VMO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C$V.`IM
M<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)S<6PZ($YE8GEL82!N86QE>F5N
M82!P;[YA9&]V86[A('#X[7!O;F$@<')O(&EM87`N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"
M86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM
M<V=S='(@(D%U=&A?8WER=7,Z(%ID<F]J(&YE;>$@<&^^861O=F%NZ2!S8VAO
M<&YO<W1I+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$R
M,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!.96)Y;&$@;F%L97IE
M;F$@<&^^861O=F%NX2!P^.UP;VYA('!R;R!I;6%P+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E
M<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W
M:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"B)!
M=71H7V9T<#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N82!P
M<F\@9G1P+B!+;VUP:6QU:G1E(%!(4"!S("TM(@HB96YA8FQE+69T<"(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?
M:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R(")!=71H7VEM87`Z($YE8GEL82!N86QE>F5N82!P;[YA9&]V86[A('#X
M[7!O;F$@<')O($E-05`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U
M+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:W)B-3H@3F5B>6QA(&YA
M;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N82!P<F\@:W)B-2XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P
M.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I
M<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I
M<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@
M(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")!=71H7VQD87`Z($YE8GEL82!N86QE>F5N82!P;[YA9&]V
M86[A('#X[7!O;F$@<')O($Q$05`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z
M(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@(@IM<V=S='(@(D%U=&A?;&1A<#H@3F5L>F4@</AI9&%T('6^
M:79A=&5L92`E<RX@2&SAN65N[2!S97)V97)U.B`B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R(")!
M=71H7VQD87`Z($YE;'IE('9Y;6%Z870@=;YI=F%T96QE("5S(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS
M9W-T<B`B075T:%]L9&%P.B!.96QZ92!A:W1U86QI>F]V870@=;YI=F%T96QE
M("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,#4*;7-G
M:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!2
M97%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?;6-A;#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N82!P
M<F\@34-!3"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z-C`*
M;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7W-M8F%U=&@Z($YE8GEL82!N
M86QE>F5N82!P;[YA9&]V86[A('#X[7!O;F$@<')O('-M8F%U=&@N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP
M"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B3W;L^&5N
M[2!S96QH86QO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N
M=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R(")/=NSX96[M('-E;&AA;&\N
M("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM
M<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E
M<BXB"FUS9W-T<B`B3W;L^&5N[2!B>6QO('IA;>UT;G5T;R!2041)55,@<V5R
M=F5R96TN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G
M<W1R(")396QH86QO(&]V[/AE;NT@1E10('-E=F5R96TN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B075T:&5N
M=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")3
M96QH86QO(&]V[/AE;NT@1E10('-E=F5R96TN(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS
M9W-T<B`B1&]S='5P;N$@<&]L93HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R
M8F%I:F%N(@IM<V=S='(@(D%Z97)B86IDON%N(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B0D]&
M2"!V_6UL=79Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R(")0
M;WIA9.TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(D)A<G9A
M('!O>F%D[2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*
M;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`BJ7!A=&[I
M(&AE<VQO('!R;R!K97)B97)O<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM
M<V=S='(@(JEP871NZ2!UOFEV871E;'-KZ2!J;>EN;R!P<F\@:V5R8F5R;W,N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R(")"86AA;7DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Q"FUS9VED(")"86AR86EN(@IM<V=S='(@(D)A:')A:6XB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B0F%L=&EC("A)
M4T\M.#@U.2TQ,RDB"FUS9W-T<B`B0F%L=&EC:^D@*$E33RTX.#4Y+3$S*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`B0F%N9VQA
M9.FY(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B0F%R
M8F%D;W,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB
M)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DYE8GEL(&YA;&5Z96X@861R97/A
M^"`G)7,G(',@9W)A9FEK86UI+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B"FUS
M9W-T<B`B6N%K;&%D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G
M<W1R(")"[&QO<G5S:V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM
M<V=S='(@(D)E;&=I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G
M<W1R(")"96QI>B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM<V=S='(@
M(D)E;FEN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R(")"
M97)M=61Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(D)H
M^G3A;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(DYA<F]Z96YI;GDB"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4S"B,L
M('!H<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO
M;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(").96QZ92!N86SI>G0@Z.%S
M="!<(B5S7"(@87!L:6MA8V4@7"(E<UPB+B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;&%Y;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T
M<B`B3F%S=&%V96[M(&)L;VMU(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(E1Y<"!B;&]K
M=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.`IM<V=I9"`B0F]L9"(*;7-G<W1R(")4=>AN["(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G
M:60@(D)O;&EV:6$B"FUS9W-T<B`B0F]L[79I92(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR,#4*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R("):
MX6QOOFMY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(D]K<F%J(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM
M<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`BJ>WX:V$@;VMR86IE
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B3VMR86IE(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R
M(")";W-N82!A($AE<F-E9V]V:6YA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@(D]B82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*
M;7-G:60@(D)O='-W86YA(@IM<V=S='(@(D)O='-W86YA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED
M(")";W1T;VTB"FUS9W-T<B`B1&]L;NT@Z.%S="(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G
M:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B0F]U=F5T($ES;&%N9"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C(*;7-G:60@(D)R87II;"(*;7-G<W1R(")"<F%Z[6QI92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@Q"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O
M<GDB"FUS9W-T<B`B0G)I='-KX2!T97)I=&]R:6$@=B!);F1I8VOI;2!O8V7A
M;NPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G
M<W1R(")"<G5N96D@1&%R=7-S86QA;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U
M;&=A<FEA(@IM<V=S='(@(D)U;&AA<G-K;R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI
M<W0B"FUS9W-T<B`B4V5Z;F%M(',@;V1RX;YK86UI(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM
M<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(D)U<FMI;F$@1F%S;R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B0G5R=6YD82(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#0*;7-G:60@(D--4R(*;7-G
M<W1R(")#35,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-23"!$:7-T<FEB
M=71I;VX@4&]I;G1S(@IM<V=S='(@(D-23"!D:7-T<FEB=>AN[2!B;V1Y(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(E9L
M87-T;F]S=&D@8E]U\FMY+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$V,PHC+"!F=7IZ>0IM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T
M(&-O;7!L971E9"XB"FUS9W-T<B`B3F5B>6P@=79E9&5N(&1I<W1R:6)UZ&[M
M('-E>FYA;2XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#@T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.#<*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$U-0IM<V=I9"`B0V%L96YD87(B"FUS9W-T
M<B`B2V%L96YDX?@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C0V"FUS9VED(")#86QM(@IM<V=S='(@(D)E>G;L=/CM(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(DMA;6)O9+YA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B2V%M97)U;B(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E
M<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R+B(*;7-G<W1R("(B"B)(97-L;R!N96QZ92!N87-T879I="!A
M=71O;6%T:6-K>2P@<')O<^UM(&MO;G1A:W1U:G1E(%9AN65H;R!S>7-TZ6UO
M=NEH;R`B"B)A9&UI;FES='+A=&]R82XB"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HS,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A
M;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B3F5L>F4@=GEM
M87IA="!S;W5B;W(@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR
M,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA
M;F1L97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@
M<V5R=F5R.B`E<R(*;7-G<W1R(").96QZ92!S92!P^&EP;VII="!K($E-05`@
M<V5R=F5R=3H@)7,B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT
M,3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(DYE;'IE('9Y;6%Z870@<V]U8F]R(%PB)7-<
M(BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8T"FUS9VED(")#86YA9&$B"FUS9W-T<B`B2V%N861A
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E
M<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`B4W1O
M<FYO(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G
M:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")3=&]R;F\@:&SA
MN65N[2!P<F]B;.EM=2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,S$X"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(DYE;'IE('9Y;6%Z870@<V]U8F]R(%PB)7-<(BXB
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU
M,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*
M;7-G<W1R(").96QZ92!N86KM="!D;^AA<V[](&%D<F5SX?@N(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B
M0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R
M+B(*;7-G<W1R(").96QZ92!P;VMR8>AO=F%T(&)E>B!P87)A;65T<G4@)W1A
M<F=E=$9I;&4G+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$T
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y
M(%PB)7-<(BXB"FUS9W-T<B`B3F5L>F4@=GEM87IA="!A9')E<^'X(%PB)7-<
M(BXB"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964N<&AP.C$R."!F
M<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV.#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI
M<W0N(@IM<V=S='(@(DYE;'IE('9Y;6%Z870L('!R;W1OOF4@97AI<W1U:NT@
M<&]D<VMU<&EN>2`E9"XB"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R
M964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB
M97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M
M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"B).96QZ92!P<F]V
MZ7-T('IM[&YU('5S<&_XX63A;NTL('!OZ&5T('!O<VMY=&YU=/UC:"!P;VQO
MOF5K('!R;R!N;W;I("(*(G5S<&_XX63A;NT@;F5O9'!O=NUDX2!P;^AT=2!U
M;&^^96[]8V@@<&]L;[YE:RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M
M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(DYE;'IE('IA
M<VQA="!Z<'+A=G4@;F$@>F%D86[I(.CM<VQO+B`B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#87!E(%9E<F1E(@IM<V=S='(@(D-A<&4@5F5R9&4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"FUS
M9VED(")#87!T:6]N(@IM<V=S='(@(E1I='5L:WDB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I
M97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP"FUS
M9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B2V%T96=O<FEE
M(&$@>FYAZ&MY(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S
M(@IM<V=S='(@(DMA:FUA;G-KZ2!O<W1R;W9Y(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N
M92(*;7-G<W1R(")-;V)I;&[M('1E;&5F;VXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"FUS9VED(")#96QL
M(%!R;W!E<G1I97,B"FUS9W-T<B`B36^^;F]S=&D@8G7R:WDB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B
M0V5L;"!P861D:6YG.B(*;7-G<W1R(")/9'-T=7`@;65Z:2!B=?)K86UI.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R(")6;&%S=&YO
M<W1I(&)U\FMY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B365Z
M97)Y(&UE>FD@8G7R:V%M:3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C<T"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B36]B:6QN[2!T96QE
M9F]N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I
M8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(DME;'1S:_T@*$E33RTX.#4Y+3$T
M*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R(")3=/AE9"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R
M(")3=/AE9&]A9G)I8VOA(')E<'5B;&EK82(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3<Y"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR
M*2(*;7-G<W1R(")3=/AE9&]E=G)O<'-K_2`H25-/+3@X-3DM,BDB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Y.0IM<V=I9"`B0V5R
M=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R(")0;V1R;V)N;W-T:2!C97)T:69I
M:^%T=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$Q
M"B,L(&9U>GIY"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R(")0
M;V1R;V)N;W-T:2!C97)T:69I:^%T=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE
M<R(*;7-G<W1R(")0;V1M[6YK>2!C97)T:69I:^%T=2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M.`IM<V=I9"`B0VAA9"(*;7-G<W1R("+(860B"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B6FWL;FET(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")#:&%N
M9V4@66]U<B!087-S=V]R9"(*;7-G<W1R(")6_6-H;WKM(&YA<W1A=F5N[2!6
M8;EE:&\@:&5S;&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G
M:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L
M92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA
M:6QS+B(*;7-G<W1R("(B"B).87-T879E;NT@:FWI;F$@82!E;6%I;&]VZ2!A
M9')E<WDN(%1Y=&\@<&]L;[YK>2!L:63I('5V:63M+"!K9'F^('-I(.AT;W4@
M(@HB;F5B;R!O9'!O=NUD86KM(&YA(%9AN64@>G!RX79Y+B(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@
M>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E
M;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(EIN
M86LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(EIK
M;VYT7W)O;&]V870@;V1K87HN+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EL
M92(*;7-G<W1R(")#:&EL92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM
M<V=S='(@(LCM;F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I
M9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(LCM;KET
M:6YA('IJ961N;V1UN65NX2`H1T(R,S$R*2(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@Q"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*
M;7-G<W1R(")4<F%D:>AN[2#H[6ZY=&EN82`H0FEG-2DB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!P
M87-S=V]R9"(*;7-G<W1R("):=F]L=&4@:&5S;&\B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,C8X"FUS9VED(")#:&]O<V4@82!U<V5R
M;F%M92(*;7-G<W1R("):=F]L=&4@=;YI=F%T96QS:^D@:FWI;F\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDX"FUS9VED(")#:&]O<V4@:&]W('1O
M(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(E9Y8G)A="!Z;V)R87IE;NT@9&%T
M=6UU.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@
M*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R(")6>6)R870@='EP('-T>6QU
M('-E>FYA;74@*'!R;R#X87IE;ND@<V5Z;F%M>2DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(E;A;F_H;NT@;W-T<F]V
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C@Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D
M969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B3F5B>6QA(&YA
M;&5Z96YA(&1E9FEN:6-E('3X[61Y("5S+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*;7-G<W1R
M(")6>>AI<W1I="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T
M<B`B5GGH:7-T:70@>FYAZ&MY('H@35-/9F9I8V4B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3(X"B,L(&9U>GIY"FUS9VED(")#;&5A<B!1=65R>2(*;7-G
M<W1R(")/9'-T<F%N:70@=;YI=F%T96QE(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@
M;W5T('5S97(Z("5S(@IM<V=S='(@(D]D<W1R86[L;NT@=;YI=F%T96QE.B`E
M<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I
M9"`B0VQE87(@=7-E<B(*;7-G<W1R(")/9'-T<F%N:70@=;YI=F%T96QE(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L
M96%R('5S97(@9&%T82(*;7-G<W1R(")/9'-T<F%N[&[M(/ID86KY(&\@=;YI
M=F%T96QI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,34*(RP@9G5Z>GD*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B
M4&]Z9&[M(&3IN;LB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T
M<B`B2VQI:V[L=&4@<')O('!O:W)AZ&]VX6[M(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC
M:V%T96QL('9I82!(5%10(@IM<V=S='(@(D-L:6-K871E;&P@</AE<R!(5%10
M(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B
M6F%V^.UT(&]K;F\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-`IM<V=I
M9"`B0VQO=61S(@IM<V=S='(@(EIA=&&^96YO(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*(RP@9G5Z>GD*;7-G:60@(D-L
M;W5D<R!%87)L>2(*;7-G<W1R(")/8FQAZ&YO(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G
M<W1R(")/8FQAZ&YO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI
M;F<I($ES;&%N9',B"FUS9W-T<B`B2V]K;W-O=ND@;W-T<F]V>2(*"B,Z('1E
M;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA<'-E
M(%-I9&5B87(B"FUS9W-T<B`B4VML87!N;W5T(&)OZ&[M(&QIN71U(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B4VML87!N;W5T
M(&]K<F%J92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@
M(DMO;'5M8FEE(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO
M8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(D)A
M<G9A(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP
M.C,R-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z
M,S(U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU
M,#`@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B
M0V]L;W(@4&EC:V5R(@IM<V=S='(@(E;]8NQR(&)A<F5V(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@T-@IM<V=I9"`B0V]L;W5R('-E;&5C=&EO
M;B(*;7-G<W1R(")086QE=&$@8F%R978B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T
M<B`B4VQO=7!C93HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30V
M"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(D[A>G9Y('-L;W5P8V4B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8T"FUS9VED(")#;VUI
M8W,B"FUS9W-T<B`B2V]M:6MS>2(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR
M-0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")0^.UK87HB"@HC.B!A9&UI;B]C
M;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B
M4/CM:V%Z;W;A(&MO;GIO;&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B4&]Z;N%M:V$B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-@IM<V=I
M9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B3V)E8V[I(&IMZ6YO(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#0*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B2V]M;W)O<R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@
M(D-O;7!A;GDB"FUS9W-T<B`B1FER;6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R(")0;^CM=&'H92(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3<*(RP@9G5Z>GD*
M;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R(")0;V1M[6YK>2(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C0Y"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@
M(E!O9&WM;FMY(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@
M(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B4F]Z9.UL>2!V
M(&YA<W1A=F5N[2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#,*;7-G
M:60@(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R
M='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$S-0HC+"!F=7IZ>0IM<V=I9"`B0V]N9FEG=7)A=&EO
M;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B2F4@=/AE8F$@86MT=6%L:7IO
M=F%T(&YA<W1A=F5N[2XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R(").
M87-T879I="`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B4&]T=G)D
M:70@:&5S;&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R(")+
M;VYG;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I
M8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B2V]N9V\L($1E;6]K<F%T:6-K
MX2!R97!U8FQI:V$B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`B
M4W!O:F5N[2!S96QH86QO+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS
M9W-T<B`B4W!O:F5N[2!S96QH86QO.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B0GEL;R!Z86WM=&YU
M=&\@<W!O:F5N[2!S('9E^&5J;OUM(&ML[>AO=OUM('-E<G9E<F5M+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K
M97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R(")">6QO('IA;>UT
M;G5T;R!S<&]J96[M(',@=F7X96IN_6T@:VSMZ&]V_6T@<V5R=F5R96TN($3Y
M=F]D(#H@)7,@*"5S*2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#0U"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*
M;7-G<W1R(")396QH86QO('-P;VIE;NT@<R!&5%`@<V5R=F5R96TN(@H*(SH@
M8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,30*;7-G:60@(D-O;G1A8W1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D
M960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(DMO;G1A:W1Y(&)Y
M;'D@^G-P[+EN["!P^&EDX6YY(&1O(%9AN65H;R!A9')E<^'X92XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(D]B<V%H('8@
M)R5S)R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS
M9W-T<B`B4&]K<F'H;W9A="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L
M86YD<R(*;7-G<W1R(")#;V]K;W9Y(&]S=')O=GDB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R(")+;VSAZ&5K
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@(DMO<.UR;W9A="(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8X"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B4W!O:F5N
M[2!S96QH86QO.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R(")+
M;W#M<F]V870@=OUB['(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$W,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8W"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@(DMO<W1A<FEK82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B4&]B^&6^
M[2!S;&]N;W9I;GDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HY-S8*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+B(*
M;7-G<W1R("):<'+A=G4@;F5L>F4@N6EF<F]V870@<&]M;V/M(%!'4"XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4S"FUS9VED(")#
M;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`B6G!RX79U(&YE
M;'IE('!O9&5P<V%T('!O;6]C[2!01U`N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@
M96YC<GEP="!M97-S86=E+B(*;7-G<W1R("):<'+A=G4@;F5L>F4@N6EF<F]V
M870@<&]M;V/M(%,O34E-12XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE
M<W-A9V4N(@IM<V=S='(@(EIP<N%V=2!N96QZ92!P;V1E<'-A="!P;VUO8^T@
M4R]-24U%+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A
M9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B3F5L>F4@</AI9&%T(&MO;G1A:W0N
M("5S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.CDV(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"FUS9VED(")#;W5L9"!N
M;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3F5L>F4@<V4@</AI
M<&]J:70@:R!,1$%0('-E<G9E<G4N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C0U-PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@;&1A
M<"!S97)V97(B"FUS9W-T<B`B3F5L>F4@<V4@</AI<&]J:70@:R!,1$%0('-E
M<G9E<G4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R(").96QZ92!Z:V]N=')O;&]V
M870@^NAE="X@)7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q"B,L
M(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E
M<B(*;7-G<W1R(").96QZ92!S92!P^&EP;VII="!K(%--0B!S97)V97)U+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<
M(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(DYE;'IE('-E('#X:7!O:FET(&L@
M<V5R=F5R=2`G)7,G('!O;6]C[2!&5%`Z("5S(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,B"FUS9W-T<B`B3F5L>F4@=GET=F_X:70@9&ES=')I8G7H;NT@<V5Z;F%M
M+B`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,C4*
M;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+B(*;7-G<W1R(").
M96QZ92!D9;EI9G)O=F%T(%!'4"!D871A+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3(R"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP
M="!3+TU)344@9&%T82XB"FUS9W-T<B`B3F5L>F4@9&6Y:69R;W9A="!3+TU)
M344@9&%T82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@(DYE;'IE('-M87IA="!K;VYT
M86MT+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D
M96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYE;'IE('-M
M87IA="!D:7-T<FEB=>AN[2!S97IN86TN("5S(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z,S@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*
M;7-G<W1R(").96QZ92!S;6%Z870@;F%S=&%V;W9A8^T@<VMR:7!T('!R;R!A
M:W1U86QI>F%C:2`G)7,G+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU
M,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@
M92UM86EL(&%D9')E<W,N(@IM<V=S='(@(DYE;'IE('IJ:7-T:70@92UM86EL
M;W9O=2!A9')E<W4@</CM:F5M8V4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F
M971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(DYE;'IE('KM
M<VMA="#Z<&QN_2!A9')E<^'X+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T
M8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(DYE;'IE
M('KM<VMA="#Z<&QN_2!D:7-T<FEB=>AN[2!S97IN86TN(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@
M(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB
M=71I;VX@;&ES=',N(@IM<V=S='(@(DYE;'IE('KM<VMA="#Z<&QN_2!S97IN
M86T@9&ES=')I8G7H;NUC:"!S97IN86WY+B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2YP:'`Z.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B4W1R
M871E9VEE("<E<R<@:F4@;F5D;W-T=7!NX2XB"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T
M<B`B3F5L>F4@>F%L;[YI="`G)7,G+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L
M:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B3F5L>F4@>NUS
M:V%T('9E^&5J;OT@:VSMZ"!Z(&ML[>AO=NEH;R!S97)V97)U+B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B
M3F5L>F4@;W1E=OCM="`G)7,G(&L@>N%P:7-U+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B3F5L>F4@
M;W1E=OCM="`E<RXB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E
M;F%N8V4N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R(").96QZ
M92!P<F]VZ7-T(&]P97)A8V4@^F1ROF)Y('!R;R!M;V1U;"`E<R(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B3F5L
M>F4@;W1E=OCM="!A9')E<^'X("<E<R<N(@H*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR
M,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-CDY"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@
M<V5R=F5R+B(*;7-G<W1R(").96QZ92!H;&5D870@=B!,1$%0('-E<G9E<G4N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR,S@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(DYE
M;'IE(.CM<W0@)7,N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R
M('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E
M=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP
M+B(*;7-G<W1R("(B"B).96QZ92!R97-E=&]V870@:&5S;&\@<')O(&1A;NEH
M;R!UOFEV871E;&4N(%:Y96-H;GD@;F5B;R!N[&MT97+I('H@(@HB<&]D<F]B
M;F]S=.T@;F5B>6QY('-P<N%V;NP@>F%DX6YY+B!::W5S=&4@=&\@>FYO=G4@
M;F5B;R!P;VMU9"!P;W3X96)U:F5T92`B"B)P;VUO8RP@:V]N=&%K='5J=&4@
M<W!RX79C92!S>7-TZ6UU+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,P.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-#`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S<W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,X,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS.#D*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T
M<B`B3F5L>F4@>NUS:V%T($%#3"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@
M(DYE;'IE('KM<VMA="!A9')E<^'X+B`E<R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,B"FUS9W-T<B`B3F5L>F4@>NUS:V%T(&1I<W1R:6)UZ&[M('-E>FYA;2X@
M)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R(").96QZ92!Z[7-K
M870@9&ES=')I8G7H;NT@<V5Z;F%M>2X@)7,B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C(R,PIM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R(").96QZ92!Z[7-K
M870@<V-H;W!N;W-T:2!S97)V97)U(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R(").96QZ92!P^&5P;F]U="!K;VYF:6=U<F%C:2XB"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z.30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(DYE;'IE(&]D<W1R
M86YT("<E<R<N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B3F5L>F4@=6QOOFET(&MO;F9I9W5R86-I('!R;R`E
M<RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P
M(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B3F5L>F4@=6QOOFET('KA;&^^;NT@
M:V]N9FEG=7)A8VDN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A
M8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(DYE;'IE('5L;[YI="!Z
MX6QOOF[M(&MO;F9I9W5R86-I("5S+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.CDU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G
M<W1R(").96QZ92!U;&^^:70@;F%S=&%V;W9A8^T@<V-R:7!T('!R;R!A:W1U
M86QI>F%C:2!D;SH@)R5S)RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B
M86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(").96QZ92!U
M;&^^:70@>N%L;VAU(&MO;F9I9W5R8>AN[6AO('-O=6)O<G4@)7,N(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@
M9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T
M:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU
M86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@HB3F5L>F4@
M>F%P<V%T+B!-^;YE=&4@<&]UONUT('-K<FEP="!P<F\@86MT=6%L:7IA8VD@
M;F5B;R!R=>AN["!Z:V]P[7)O=F%T("(*(F[MOF4@=79E9&5N_2!K\V0@9&\@
M)7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,*;7-G
M:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R
M(").96QZ92!H;&5D870@=B!,1$%0('-E<G9E<G4N(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B3F5L>F4@;V1P;VII="`G)7,G
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@
M8V]N=&%C="X@)7,B"FUS9W-T<B`B3F5L>F4@86MT=6%L:7IO=F%T(&MO;G1A
M:W0N("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P
M9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3F5L>F4@86MT
M=6%L:7IO=F%T(&1I<W1R:6)UZ&[M('-E>FYA;2X@)7,B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S
M(@IM<V=S='(@(DYE;'IE('5L;[YI="!K;VYF:6=U<F%C:2!P<F\@)R5S)SH@
M)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8V"FUS9VED(")#;W5L
M9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@
M<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B"B).96QZ92!N86SI>G0@8F_H
M;NT@;&FY='4@<')O($UO>FEL;'4N(%!R;W/M;2!P^&5S=NQDZ'1E('-E+""^
M92!J92!O=&5V^&5NX2XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ-30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*
M(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H
M=',@9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R(")5OFEV871E
M;&D@)R5S)R!N96QZ92!P;W-K>71N;W5T(&[A<VQE9'5J[6/M('!RX79A('!R
M;R!S;&^^:W4@)R5S)SH@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B3V1P;^CM=&%N
M_2!T97AT(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-CD*;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B6F5M["(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR-S,*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B
M5GEUZ&]V86/M('#X961M['1Y(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B
M"FUS9W-T<B`B5GET=F_X:70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI
M;FLB"FUS9W-T<B`B5GET=F_X:70@;V1K87HB"@HC.B!T96UP;&%T97,O<')E
M9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS9VED(")#<F5A=&4@82!N97<@
M;VYE(@IM<V=S='(@(E9Y='9O^&ET(&YO=F]U(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@
M9F]L9&5R<R(*;7-G<W1R(")6>71V;_AI="!P;V1S;&^^:WDB"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!0
M97)M:7-S:6]N<R(*;7-G<W1R(")4=OER8V4@<'+A=B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,R,S`*;7-G:60@(D-R961I="!C87)D(&YU;6)E
M<B(*;7-G<W1R("+([7-L;R!K<F5D:71N[2!K87)T>2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y
M"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(D-H;W)V871S:V\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8X"FUS9VED(")#=6)A(@IM<V=S='(@(DMU8F$B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B
M"FUS9W-T<B`B06MT=>%L;NT@9N%Z92(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H
M<#HT.`HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R
M(")4=OER8V4@<'+A=B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]"
M;&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@
M(D%K='7A;&[M(.AA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B
M"FUS9W-T<B`B06MT=>%L;NT@55),(&IE(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C,S"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@
M(D%K='7A;&[M(&;A>F4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS
M9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B06MT=>%L;NT@<&_H87/M
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W-0IM<V=I9"`B
M0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R(")!:W1UX6QN[2!P;V1M[6YK
M>3H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R(").>6[L:KGM('-T
M>6PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF;W)M
M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T
M;R`E<RXB"FUS9W-T<B`B3F%S=&%V96[M(/IK;VSY('!R;W;A9.QN_6-H('#X
M:2!P^&EH;.&Y96[M(&1O("5S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S
M='(@(E9Y<W3X:6AN;W5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R
M(")6>7-T^&EH;F]U="!V_6+L<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U
M<R(*;7-G<W1R(")+>7!R(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*
M;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(D%Z8G5K82`H2T])
M."U2*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I
M;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R(")!>F)U:V$@*%=I;F1O=W,M
M,3(U,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0WER
M:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(D%Z8G5K82]5:W)A
M:FEN82`H2T])."U5*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B
M;&EC(@IM<V=S='(@(LAE<VOA(')E<'5B;&EK82(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-3$@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(D1$(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S(X,0IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO
M+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI
M;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R
M(")$96YN["(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T
M851R964@0G)O=W-E<B(*;7-G<W1R(")$871A5')E92!P<F]H;.V^9>@B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<Y"FUS9VED(")$871A8F%S
M92!,;V]K=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,SDY"FUS9VED(")$871E(@IM<V=S='(@(D1A='5M(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV
M960B"FUS9W-T<B`B4/AI:F%T;R!D;F4B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#`W"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R(")6
M_6+L<B!D871U;74B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,CDR(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,C(*;7-G:60@(D1A
M>2(*;7-G<W1R(")$96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN
M(@IM<V=S='(@(E-M85]Z870@<VQO=7!E8R(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,3(*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G
M<W1R(")0<F]S:6YE8R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R
M<R(*;7-G<W1R("+([7-L82!D97/M=&MO=ND@<V]U<W1A=GDB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$
M96-R96%S92!);F1E;G0B"FUS9W-T<B`B6FUE;KEI="!O9'-A>F5N[2(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI8B]P<F5F<RYP
M:'`Z,3$W"FUS9VED(")$969A=6QT(@IM<V=S='(@(DEM<&QI8VET;NTB"@HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PIM
M<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R("));7!L:6-I=&[M(&)A<G9A
M(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HY,0IM<V=I
M9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R("));7!L:6-I=&[M(&ED96YT
M:71A(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"B,L(&9U>GIY"FUS
M9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(DEM<&QI8VET;NTB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM
M<V=S='(@(D1E9FEN:6-E(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,2!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(E-M87IA="(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS,@HC+"!F=7IZ>0IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`B
M4VUA>F%T(&)U\FMU(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO
M9W)O=7!S+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R(")3
M;6%Z870@<VMU<&EN=2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(T.0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R(")3;6%Z
M870@^.%D96LB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE
M=&4@4&5R;6ES<VEO;B(*;7-G<W1R(")3;6%Z870@<'+A=F$B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B1&5L
M971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R(")3;6%Z870@82!V>>AI
M<W1I="!Z<'+A=GDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R
M(")3;6%Z870@8G7R:W4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@8V]L=6UN(@IM
M<V=S='(@(E-M87IA="!S;&]U<&5C(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA
M=&4B"FUS9W-T<B`B4VUA>F%T(&5X:7-T=6KM8^T@86QT97)N871I=F[M('9Z
M;W(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O
M<B!<(B5S7"(B"FUS9W-T<B`B4VUA>F%T('!RX79A('!R;R`G)7,G(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB
M(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R(")3;6%Z870@<'+A
M=F$@82!P;V1P<N%V82!P<F\@)R5S)S\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@
M<F]W(@IM<V=S='(@(E-M87IA="#XX61E:R(*"B,Z('1E;7!L871E<R]P<F5F
M<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E
M9"!I9&5N=&ET>2(*;7-G<W1R(")3;6%Z870@=GEB<F%N;W4HZ2D@:61E;G1I
M='4H>2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU
M;6XB"FUS9W-T<B`B4VUA>F%T('-O=>AA<V[]('-L;W5P96,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*
M;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B4VUA>F%T
M('-O=>AA<V[](/CA9&5K(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M,S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")+;VYF:6=U<F'H;NT@
M<V-R:7!T('!R;R!A:W1U86QI>F%C:2`G)7,G(&)Y;"!S;6%ZX6XN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M.34*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(U,PIM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R("+(87,@
M9&]R=>AE;NTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM87)K(@IM<V=S='(@
M(D3A;G-K;R(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C(Y
M"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R(")0;W!S870@
M<')O8FSI;2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDS."!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"FUS
M9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")0;W!I<R(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,3DU"FUS9VED(")$971A:6QS("AA;'-O(&EN
M($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(E!O9')O8FYO<W1I("AT86OI
M('8@;&]G('-O=6)O<G4@2&]R9&4I.B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3DY"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")0;V1R;V)N;W-T:2!B
M>6QY('IA>FYA;65NX6YY(&1O(&QO9R!S;W5B;W)U('!R;R!A9&UI;FES='+A
M=&]R82XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$Y"FUS9VED
M(")$979E;&]P;65N="(*;7-G<W1R(")6_79O:B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C$W"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B4F]S;OT@
M8F]D(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.30*;7-G:60@(D1E=R!0
M;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B4F]S;OT@8F]D('IA('!O
M<VQE9&[M(&AO9&EN=3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(R-PIM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B4F]S;OT@8F]D
M.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R(")3
M;>QR('H@;&5V82!D;W!R879A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O
M(&QE9G0B"FUS9W-T<B`B4VWL<B!Z('!R879A(&1O;&5V82(*"B,Z(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B
M061R97/A^"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C8*;7-G:60@
M(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B6F]B<F%Z:70@,C0M
M:&]D:6YO=OT@Z&%S/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM
M<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(DUOOFYO<W1I('IO8G)A
M>F5N[2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY-@HC+"!F
M=7IZ>0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R
M("):;V)R87II="!P^&5D<&]V[.\@*%1!1BDB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C@U"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S
M='(@(EIO8G)A>FET('#X961P;W;L[R`H5$%&*2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(X,3<*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S
M='(@(D9O<FWA="!Z;V)R87IE;NTB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TU$3BYP:'`Z,3DP"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB
M"FUS9W-T<B`B1&ES<&]Z:>AN[2!U<&]Z;W)N[&[M(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM
M<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B1&II8F]U=&DB"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T
M92(*;7-G<W1R(").97-M87IA="(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N
M86YC92YP:'`B"FUS9W-T<B`B3F5P^&ES='5P;W9A="!P^.UM;R!D;R!M86EN
M=&5N86YC92YP:'`B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ
M,B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T
M:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L
M(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R("(B"B)/8G-A:'5J92!P<G9N[2#X
MX61E:R!NX7IE=B!S;&]U<&/Y/R!0;VMU9"!A;F\L('IAN6MR=&[L=&4@=&5N
M=&\@<N%M9>AE:SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G
M<W1R(")$;VUI;FEK82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!2
M97!U8FQI8R(*;7-G<W1R(")$;VUI;FEKX6YS:^$@<F5P=6)L:6MA(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V
M92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*;7-G:60@(D1O=VYL;V%D
M(@IM<V=S='(@(E-T8;YE;NTB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@
M)7,B"FUS9W-T<B`B4W1AOF5N[2`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(E-T86AN;W5T(&=E;F5R;W9A
M;F]U(&MO;F9I9W5R86-I(&IA:V\@4$A0('-K<FEP="XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3`W"FUS9VED(")$<F]P(&1O=VX@;&ES="(*
M;7-G<W1R(")2;VQE=&]V_2!S97IN86TB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(D1R;V=Y(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")%+4UA:6PB
M"FUS9W-T<B`B12UM86EL(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E
M;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y
M(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V
M:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B
M"FUS9W-T<B`B15)2(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G
M<W1R(")%:W;A9&]R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS
M,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R"B,Z('1E
M;7!L871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G:60@(D5D:70B"FUS9W-T
M<B`B57!R879I="(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z
M-3`@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="!"
M;&]C:R(*;7-G<W1R(")5<')A=FET(&)L;VLB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R-@IM<V=I9"`B161I="!'<F]U
M<"(*;7-G<W1R(")5<')A=FET('-K=7!I;G4B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,3`P"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`B57!R879I
M="!P<N%V82(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G
M:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B57!R879I="!P<N%V82(*
M"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B57!R
M879I="!P<N%V82!P<F\@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN
M8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R(")5<')A=FET
M(&UOOFYO<W1I('!R;SHB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C,V-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M
M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(E5P<F%V:70@<'+A=F$@<')O
M("5S(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R
M(")5<')A=FET('!RX79A('!R;R`E<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS-0IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(E;]=6MA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B16=Y<'0B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%:71H97(@96YA8FQE(&ET('1H96XZ("5S+"!O<B!U<V4@=&AE(&)A<VEC
M($A434P@=F5R<VEO;CH@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM
M<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B16P@4V%L=F%D;W(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B4')V96LN+BXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I
M9"`B16TB"FUS9W-T<B`B16TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M-CD*;7-G:60@(D5M86EL(@IM<V=S='(@(D5M86EL(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C8X"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D5M86EL
M;W;A(&%D<F5S82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C,*
M;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")%
M;6%I;&]VZ2!A9')E<WD@<V4@;75S[2!S:&]D;W9A="XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.3@Y"FUS9VED(")%;6%I;"!W:71H(&-O;F9I
M<FUA=&EO;B(*;7-G<W1R(")%;6%I;"!S('!O='9R>F5N[6TB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B
M16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.`IM<V=I9"`B16UO=&EC
M;VYS(@IM<V=S='(@(DEK;VYK>2!S(&5M;V-E;6DB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@(D5M
M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(E!RX7ID;N$@>G!RX79A+B(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HW,#4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G
M:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B4'+A>F1N_2!V_7-L961E:RXB
M"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED
M(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B4'+A>F1N_2!T97)M[6X@
M<')O('9Y:&QE9.%VX6[M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T
M,PIM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T
M;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B4&]V;VQI="!V:VSA9.%N
M[2!O8G)A>FOY('H@9F]T;R!G86QE<FGM(&1O('1E>'1U/R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,3@*;7-G:60@(D5N86)L92!R:6=H="!C;&EC
M:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(D%K=&EV;W9A="!P<F%VZ2!K;&EK
M;G5T[2!P<F\@:V]N=&5X=&]VZ2!M96YU/R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(U.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,0IM
M<V=I9"`B16YD('EE87(B"FUS9W-T<B`B2V]N96,@<F]K=2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N
M;&%R9V4@161I=&]R(@IM<V=S='(@(EIV['2Y:70@961I=&]R(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(R,0IM<V=I9"`B(@HB16YT97(@82!S96-U
M<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@
M;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES
M('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*(EIA9&5J=&4@
M8F5Z<&7H;F]S=&[M(&]TX7IK=2P@;F$@:W1E<F]U(&)U9&5T92!M=7-E="!O
M9'!O=NQD['0@<&]K=60@<VD@(@HB8G5D971E(&-H=.UT(')E<V5T;W9A="!S
M=ND@:&5S;&\L(&YA</@N("=*86OI(&IE(&IMZ6YO(%9AN65H;R!P<V$_)SHB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*
M;7-G<W1R("):9&4@=FQOOFET(%523"!O8G+A>FMU(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,0IM<V=I9"`B16YT97(@
M=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G
M:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(E)O=F[M:V]VX2!'=6EN
M96$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM<V=S='(@(D5R:71R
M96$B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HT-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-34*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E<R]P;W)T86PO:6YD97@N
M<&AP.C@R"FUS9VED(")%<G)O<B(*;7-G<W1R(")#:'EB82(*"B,Z(&9R86UE
M=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T
M<B`B3F%S=&%L82!C:'EB82!P^&D@;V1E<^ULX6[M(&]D<&]V[&1I.B`E<RXB
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@
M;&]G.B`E<R(*;7-G<W1R(").87-T86QA(&-H>6)A('#X:2!O9&5S[6SA;NT@
M;V1P;W;L9&DZ("5S+B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T
M92YP:'`Z-#8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G
M971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@</AI
M(&]D97/M;.%N[2!O9'!O=NQD:3H@)7,N(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C<V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B3F%S=&%L82!C
M:'EB82!P^&D@;V1E<^ULX6[M(&]D<&]V[&1I.B`E<RXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@
M(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B3F%S=&%L82!C
M:'EB82!S('!ON71O=F[M('IP<N%V;W4N(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C$T,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN
M9R!<(B5S7"(N(@IM<V=S='(@(D-H>6)A('#X:2!ZX7!I<W4@)R5S)RXB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(D5S=&]N<VMO(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B171I;W!I92(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM
M<V=S='(@(D5T;FEC:^DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R(")%=G)O<&$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S
M(@IM<V=S='(@(DMAOF3]8V@@,34@;6EN=70B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S@Y"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B
M2V&^9.D@,B!M:6YU='DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,V
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#<*;7-G:60@(D5V97)Y(#,P('-E
M8V]N9',B"FUS9W-T<B`B2V&^9/UC:"`S,"!S96MU;F0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S,X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*
M;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")+8;YD_6-H(#4@;6EN
M=70B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R(")+8;YDZ2!P^&EH;.&Y
M96[M(&1O('-Y<W3I;74B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0P
M"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B2V&^9&]U('#Y;"!H
M;V1I;G4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,W(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.#@*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R
M(")+8;YD;W4@;6EN=71U(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI
M;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R(")6>F]R;W;]
M('#X[6ML860@:&]D;F]T.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A
M9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R-PIM
M<V=I9"`B17AE8W5T92(*;7-G<W1R(")0<F]VZ7-T(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#<U"FUS9VED(")%>'!A;F0B"FUS
M9W-T<B`B4F]Z=FEN;W5T(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R
M+FEN8SHS,@IM<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B4F]Z8F%L
M:70@8F_H;NT@;&FY='4B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D
M<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B3^AE:^%V
MX6YA("<I)R(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ
M-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H
M('1E<FTB"FUS9W-T<B`B3^AE:^%VX6YO('-A;6]S=&%T;ND@<VQO=F\@;F5B
M;R!H;&5D86[]('1E<FWM;B!V('5V;WIO=FOA8V@B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T
M92(*;7-G<W1R(")$871U;2!P<F\@:V]N96,@<&QA=&YO<W1I(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S8*;7-G:60@(D5X<&]N
M96YT(@IM<V=S='(@(D5X<&]N96YT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B
M"FUS9W-T<B`B0F%R=F$@<&]P^&5D[2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-S<*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B
M4/AE;F]S(&MO;F9I9W5R86-E('!O;6]C[2!&5%`B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O<W%L+G!H<#HR,38*;7-G:60@(D9A:6QE9"!R971R:65V
M:6YG('!R969E<F5N8V5S+B(*;7-G<W1R(")396QH86QO('KM<VOA;NT@;6^^
M;F]S=.TN(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<U
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*;7-G:60@(D9A:6QE
M9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(").96QZ92!S
M92!P^&EP;VII="!K($Q$05`@<V5R=F5R=2XB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W-M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O
M(%--0B!S97)V97(N(@IM<V=S='(@(DYE;'IE('-E('#X:7!O:FET(&L@4TU"
M('-E<G9E<G4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S
M7"(N(@IM<V=S='(@(E-E;&AA;&\@:V]P[7)O=N%N[2!Z(%PB)7-<(BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8Y,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(E-E
M;&AA;&\@:V]P[7)O=N%N[2!D;R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N
M97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R(")396QH86QO('IA;&^^96[M
M(&YO=NEH;R!305-,('-P;VIE;NTN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HT.3<@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*
M;7-G<W1R(")396QH86QO('#X97-U;G5T[2!D;R!<(B5S7"(N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C$*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B4V5L
M:&%L;R!P^&5S=6YU=.T@9&\@7"(E<UPB+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER(@IM<V=S='(@
M(D1O8G+I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H
M36%L=FEN87,I(@IM<V=S='(@(D9A;&ML86YD<VOI(&]S=')O=GD@*$UA;'9I
M;GDI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R
M(")&87)I:G-KZ2!O<W1R;W9Y(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP
M.C(S.`IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(EKA=F&^;N$@8VAY
M8F$Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A>"(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-#D*(RP@9G5Z>GD*;7-G:60@(D9A>&5S(@IM<V=S
M='(@(D9A>"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R("+:;F]R(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,C`*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T
M<B`B0^UT:70@<V4@:F%K;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,S$*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R(")#[71I="!S
M92!J86MO.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R(")$<F]B;ND@</AE
M:.'R:WDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")$<F]B;ND@
M<V[L:&]VZ2!P^&5HX?)K>2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Y-#0*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R(")-871I8V4@<&]L
M92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S0*;7-G:60@(D9I
M9VQE="!#05!40TA!(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,S,S@*;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B1FEJ:2(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B1FEL
M92(*;7-G<W1R(")S;W5B;W(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE
M(@IM<V=S='(@(E!OZ&5T('-O=6)O<ODZ("5S('-O=6)O<B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I
M;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(E!OZ&5T('-O=6)O<ODZ("5S
M('-O=6)O<ODB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`W"FUS
M9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B4W!RX79C92!S;W5B;W+Y(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*;7-G:60@(D9I;&4@3F%M
M92(*;7-G<W1R(").X7IE=B!S;W5B;W)U(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,CDY-0IM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B
M5OUB['(@<V]U8F]R=2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M.#8*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(E#X96[I<W0@<V]U8F]R
M(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4Y"FUS9VED
M(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B4/AE;F]S
M('-O=6)O<OD@;F5N[2!P;V1P;W)O=N%N+B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HX.0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R(")&:6QT<GDB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S='(@(D9I;G-K;R(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B
M"FUS9W-T<B`B4')V;NT@<&]L;W9I;F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R
M=&5R(@IM<V=S='(@(E!R=F[M(.AT=G)T:6YA(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-@IM<V=I9"`B1FEX(')A=&EO
M(@IM<V=S='(@(E!E=F[I(&WL^.UT:V\B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Q"FUS9VED(")&;&EP(@IM<V=S='(@
M(E#X96AO9&ET(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B4&QO=F]U
M8^TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M,0IM<V=I9"`B1F]G(@IM<V=S='(@(DUL:&$B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E
M>&ES="(*;7-G<W1R(")3;&^^:V$@)7,@;F5E>&ES='5J92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O
M;G0@0V]L;W(B"FUS9W-T<B`B0F%R=F$@<.US;6$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B2NUD;&\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O
M<G0@:6UA9V5S(@IM<V=S='(@(E!R;R!P<F]H;.V^9>AE(&YE<&]D<&]R=6KM
M8^T@;V)RX7IK>2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,T"FUS9VED
M(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R(")0^&5D<&]V[.\@*%1!1BDB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-SD*;7-G:60@(B(*(D9O
M<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@
M<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R
M(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B
M(@HB4/AE9'!O=NSO('!OZ&%S[2!P<F\@9&YY("AP;WINX6UK83H@</AE9'!O
M=NSO(&IE('!R;R!D;GD@:2!N;V-I.R!T;W1O(&WYOF4@(@HB=GET=F_X:70@
M<&]M[')N["!O8G/A:&S]('-E>FYA;2XB"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM
M<V=S='(@(EIA<&]M;NQL:2!J<W1E(%9AN64@:&5S;&\_(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0V,@IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B
M1F]R;75LX?AE(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED
M(")&;W)T=6YE(@IM<V=S='(@(JET['-T[2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(E1Y<""Y
M=.QS=.TB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O
M<G1U;F5S(@IM<V=S='(@(JET['-T[2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R("*I=.QS=.T@,B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-3,*;7-G:60@(D9O<G5M
M<R(*;7-G<W1R(")&\W)A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$P.0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B4/AE<&]S;.%N[2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G
M:60@(D9R(@IM<V=S='(@(E#A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S
M='(@(E+A;7DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B
M1G)A;F-I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM
M<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B1G)A;F-I92P@
M;65T<F]P;VQI=&[M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N
M82(*;7-G<W1R(")&<F%N8V]U<VOA($=U86GA;F$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM
M<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R(")&<F%N8V]U<VOA(%!O
M;'ENZ7-I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N
M(%1E<G)I=&]R:65S(@IM<V=S='(@(D9R86YC;W5S:^$@:FF^;NT@=&5R:71O
M<FEA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R(")/9"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-#@@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,V,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`V"FUS
M9VED(")&<F]M('1H92`B"FUS9W-T<B`B3V0B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*
M;7-G<W1R(")0;V1R;V)N_2!P;W!I<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB
M"FUS9W-T<B`BVG!L;NQK(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*;7-G:60@(D9U
M;&P@3F%M92(*;7-G<W1R(")#96SI(&IMZ6YO(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I
M9"`B1V%B;VXB"FUS9W-T<B`B1V%B;VXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A
M;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(D=A;&5R:64@<')O
M(';]8NQR(&]B<N%Z:_DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM
M<V=S='(@(D=A;&5R:64Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM
M<V=S='(@(D=A;6)I92(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO
M;B(*;7-G<W1R(")6>71V;_AI="`E<R!K;VYF:6=U<F%C:2(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T
M960@0V]D92(*;7-G<W1R(")6>6=E;F5R;W9A;OT@:_-D(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R(")'<G5Z[6YS:V\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@(D[L;65C:V\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<U"FUS9VED(")':&%N82(*;7-G<W1R(")':&%N82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R(")':6)R86QT87(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B1VEV96X@
M3F%M92(*;7-G<W1R(")+^&5S=&[M(&IMZ6YO(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V%P<"YI;F,Z,3(*;7-G:60@(D=O(@IM<V=S='(@(DID:2!N82(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S
M='(@(D=O961E;"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,3(X"B,L(&9U>GIY"FUS9VED(")';V]G;&4@36%P<R(*;7-G
M<W1R(")6>6AL963A=N%N[2!P;VUO8^T@1V]O9VQU(@H*(SH@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R
M(")6>6AL963A=N%N[2!P;VUO8^T@1V]O9VQU(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-PIM<V=I9"`B1W)A>7-C86QE
M(@IM<V=S='(@(E-T=7!N[""Y961I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R
M965C92(*;7-G<W1R("+896-K;R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@U"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`BV&5C:^D@
M*$E33RTX.#4Y+3<I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W)E96YL86YD(@IM
M<V=S='(@(D=R\VYS:V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM
M<V=S='(@(D=R96YA9&$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I
M9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R86-E
M('!R;R!S:W5P:6YY(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU
M.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'
M<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R(")-=7/M(&+]
M="!Z863A;F\@:FWI;F\@<VMU<&EN>2(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HS,#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R(")!=71H7VQD87`Z($YE
M;'IE('#X:61A="!UOFEV871E;&4@)7,N($ALX;EE;NT@<V5R=F5R=3H@(@H*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q."!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS
M9W-T<B`B075T:%]L9&%P.B!.96QZ92!A:W1U86QI>F]V870@=;YI=F%T96QE
M("5S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S."!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E
M(&=R;W5P("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@3F5L>F4@86MT=6%L:7IO
M=F%T('6^:79A=&5L92`E<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B
M4VMU<&EN>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T
M<B`B1W5A9&5L;W5P92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S
M='(@(D=U86TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S
M='(@(D=U871E;6%L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(D=U97)N<V5Y(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T
M<B`B4'+A=F$@:&]S=/DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#<P"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B2VYI:&$@:&]S=/DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B1W5I;F5A(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<X"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(D=U:6YE
M82U":7-S874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R
M(")'=7EA;F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-C`*;7-G
M:60@(DA434PB"FUS9W-T<B`B2%1-3"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@
M<F]W+B(*;7-G<W1R(")(5$U,07)E82!Z8F%B[&QE(&]D;>UTX2!S;6%Z870@
M<&]S;&5D;NT@8G7R:W4@;F$@^.%D:W4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN
M(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,07)E82!Z8F%B[&QE(&]D;>UTX2!S
M;6%Z870@<&]S;&5D;NT@8G7R:W4@=F4@<VQO=7!C:2!T86)U;&MY+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E
M('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R96$@>F)A
M8NQL92!O9&WM=.$@<VUA>F%T('!O<VQE9&[M(/CA9&5K('8@=&%B=6QC92XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B
M2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D]V[/AO
M=N%N[2!P;VUO8^T@2%144"!N96)Y;&\@;F%L97IE;F\N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@P"FUS9VED(")(86ET:2(*;7-G<W1R(")(86ET:2(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET
M:&TB"FUS9W-T<B`B2&%S:"UA;&=O<FET;75S(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T
M<B`B36QH879O(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S(*;7-G:60@(DAE861E<B(*;7-G
M<W1R(")(;&%V:>AK82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T
M86)L97-E="YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(DAE861E<G,B"FUS9W-T
M<B`B2&QA=FGH:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N
M9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R(")(96%R9"!)<VQA;F0@
M82!-8T1O;F%L9"!)<VQA;F1S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C,*(RP@9G5Z>GD*;7-G:60@(DAE879Y(%0M4W1O
M<FTB"FUS9W-T<B`B0F]U^&MA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#8*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R(")(96)R
M96JY=&EN82`H25-/+3@X-3DM."U)*2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*
M;7-G<W1R(")6_;EK82(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92](96QP
M+G!H<#HQ-SD@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X-@HC
M.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T96UP;&%T97,O:&5L<"]I
M;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*;7-G<W1R(").X7!O=NQD82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G
M:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(D[A<&]V[&1A('!R;R!E
M9&ET;W(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q"FUS9VED
M(")(96QP97(B"FUS9W-T<B`B4&]M;V-N[6LB"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B2&5M:7-FZ7)A
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN
M;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B6F1E(&IE('IAZ.%T96L@<V]U
M8F]R=3HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV.0IM<V=I9"`B2&EG:"(*;7-G<W1R(")6>7-O:^$B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH
M96%D97(N:6YC.C4*;7-G:60@(DAO7VUE(@IM<V=S='(@(E](;W)D92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A
M=&4I(@IM<V=S='(@(E-V873I($WL<W1O("A6871I:^%N*2(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,34S-0IM<V=I9"`B2&]M92(*;7-G<W1R
M(")(;W)D92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D%D<F5S82!D
M;VWY(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"B,L(&9U>GIY"FUS
M9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R(")!9')E<^'X(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B
M2&]M92!0:&]N92(*;7-G<W1R(")496QE9F]N(&1O;?DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(DAO;F1U<F%S(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B2&]N9R!+;VYG(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8U"FUS9VED(")(;W)D92(*
M;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M-#0R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED
M("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z($YE<&QA=&[I("5S(%A-3"!D871A('9E('IP<N%V
M["`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E
M<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@KN%D
M;N$@>G!RX79A('-E(&YE<VAO9'5J92!S(&]B:F5K=&5M("5S(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN
M(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($YE8GEL(&YA;&5Z
M96X@ON%D;OT@;V)J96MT('1Y<'4@)7,@=F4@>G!RX7;L("5S(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C4P"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S
M7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(-IS<.RY;ND@;V1S=')A;NQN[2`E
M<R!<(B5S7"(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM
M<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q
M=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z($EN=&5G<F'H;NT@;N%S=')O:B!P;W3X96)U:F4@4$A0('#X
M[7!O;G4@)V1O;7AM;"<B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE
M('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R
M(")(;W)D92]+;VQA8CH@3F5L>F4@=GET=F_X:70@;F]V_2!S=')O;2!834P@
M<')O(&]B:F5K="`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3(T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE
M('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B
M.B!.96QZ92!O9'-T<F%N:70@)7,@7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z-#<T"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE
M('!A<G0@;V8@='EP92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3F5L>F4@
M>NUS:V%T($U)344@240@<')O(.CA<W0@='EP=2`E<R(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,3$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@
M)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($YE;'IE('-Y;F-H<F]N:7IO=F%T
M("5S(%PB)7-<(CH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$S,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B!.96QZ92!S>6YC:')O;FEZ;W9A="!S9.UL96[I(&]B:F5K='DZ("5S
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.97INX6W]('-D[6QE;OT@;V)J96MT
M(%PB)7-<(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R(")6;V1O
M<F]V;ND@<')A=NUT:V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS
M9W-T<B`B2&]R:7IO;G3A;&[M(&]D<W1U<"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ
M(@IM<V=S='(@(DAO<FEZ;VYTX6QN[3HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D
M:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@(DIA
M:R!J<W1E('-E('-E;2!D;W-T86QI/R`H6F&Y;&5T92!P<F]S[6T@>G!RX79U
M(2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L
M:6ME('1O(&UE<F=E/R(*;7-G<W1R(")+;VQI:R!S;&]U<&/Y(&-H8V5T92!S
M<&]J:70_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G
M:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G
M<W1R(")+;VQI:R!J92!T86T@<&]L[2`H<VQO=7!C^2D_(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I
M9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS
M9W-T<B`B2V]L:6L@^.%D:_D@8VAC971E('-P;VII=#\B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C,P"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R(")6;&AK;W-T(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.0IM<V=I9"`B2'5M:61I='DZ
M("(*;7-G<W1R(")6;&AK;W-T.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(DAU;6]R;NDB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B36'O87)S:V\B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")3
M96QH86QO('9Y='9O^&5N[2!)34%0;W;I('-C:'+A;FMY.B`E<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-
M05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(E-E;&AA
M;&\@<VUA>N%N[2!)34%0;W;I('-C:'+A;FMY.B`E<R(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G-Q;"YP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I
M;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(E-E;&AA
M;&\@;F%S=&%V96[M(&MV\W1Y('!R;R!)34%0;W9O=2!S8VARX6YK=3H@)7,B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S$V"FUS9VED("))4"!!
M9&1R97-S(@IM<V=S='(@(DE0(&%D<F5S82(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B25`@861R97-A(&YE;NT@9&]S='5P;N$N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B
M25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS
M9W-T<B`B25`@861R97-A(&YE;NT@=B!P;W9O;&5NZ6T@0TE$4B!R;WIS86AU
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R
M(")0;W)UN65N[2!I;G1E9W)I='D@25`N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS
M97)T(%)O=R!"969O<F4B"FUS9W-T<B`B5E]L;[YT92#XX61E:R!P^&5D(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@(DES;&%N9"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S8*;7-G:60@(DEC;VYS($]N
M;'DB"FUS9W-T<B`B4&]U>F4@:6MO;GDB"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM
M<V=S='(@(DEK;VYY('!R;R`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-S<*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R(")):V]N>2!S
M('1E>'1E;2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3`*;7-G:60@
M(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B3N%Z978@:61E;G1I='DZ(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DR"B,L('!H
M<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C
M=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B
M4&]K=60@>F]B<F%Z96[M(&YE;NT@=B!P;_CA9&MU+"`E<R!O=&5V^.UT('8@
M;F]VZ6T@;VMN["XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4U"FUS
M9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E
M<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@
M8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*
M(E!O:W5D('!O=;[M=N%T92!);G1E<FYE="!%>'!L;W)E<B!A(&YE=FED[71E
M(+[A9&[I(&EK;VYY+"!Z^&5J;>P@<&]T^&5B=6IE=&4@(@HB;WIN8>AI="!T
M96YT;R!RX6UEZ&5K('!R;R!V>7!N=73M(%!.1R!T<F%N<W!A<F5N8V4N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,PIM
M<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E
M+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I
M<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*(E!O:W5D('9I
M9.UT92!T=71O('IP<N%V=2!M[7-T;R!O8G+A>FMU+"!O8G+A>F5K(&MT97+]
M(&-H8V5T92!P^&5NZ7-T(&YE;'IE("(*(E9AN>UM('!R;VAL[;YEZ&5M('IO
M8G)A>FET+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS
M9W-T<B`B3N%H;&5D(&]B<N%Z:W4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),
M(@IM<V=S='(@(E523"!O8G+A>FMU(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G
M92!54DPZ(@IM<V=S='(@(E523"!O8G+A>FMU.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I
M9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(D]B<N%Z96L@>B!G86QE
M<FEE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM
M<V=S='(@(D]B<N%Z96L@>B!G86QE<FEE.B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R(")0
M^&5N;W,@;V)RX7IK=2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS
M9VED("));6%G97,B"FUS9W-T<B`B3V)RX7IK>2(*"B,Z('1E;7!L871E<R]D
M871A+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z
M-PHC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T
M+"!3=&5P("5D(@IM<V=S='(@(DEM<&]R="P@:W)O:R`E9"(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@
M(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("));7!O<G1O=F%NZ2!P;VQE
M.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@
M(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B26UP;W)T;W9A;N$@<&]L93HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(E9L
M;[YI="#XX61K=2!Z82(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]Z:7`N<&AP.C$S-0IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I
M=F5N+B(*;7-G<W1R(")">6P@>F%DX6X@;F5S<'+A=F[](&%KZ&[M(&OS9"XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S,@IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R
M9"XB"FUS9W-T<B`B3F5S<'+A=F[L('IA9&%NZ2!UOFEV871E;'-KZ2!J;>EN
M;R!A+VYE8F\@:&5S;&\N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA
M=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI
M;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B
M(@HB3F5S<'+A=F[I('6^:79A=&5L<VOI(&IMZ6YO(&YE8F\@86QT97)N871I
M=F[M(&%D<F5S82X@6FMU<W1E(&IEN73L(&IE9&YO=2`B"B)N96)O(&MO;G1A
M:W1U:G1E(%9AN65H;R!S>7-TZ6UO=NEH;R!A9&UI;FES='+A=&]R82XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS
M9VED("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B6G;L=+EI="!O9'-A>F5N
M[2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B26YD:64B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R
M<R(*;7-G<W1R(")*961N;W1L:7;M('6^:79A=&5LZ2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(DEN9&]NZ7-I92(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@
M(DEN9F\B"FUS9W-T<B`B26YF;W)M86-E(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(U-PIM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B26YF
M;W)M86-E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,S,`HC
M+"!F=7IZ>0IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L
M92XB"FUS9W-T<B`BKN%D;ND@>B!M;[YN;W-T[2!N96IS;W4@9&]S='5P;NDN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R
M(")6;&^^:70@<U]L;W5P96,@>F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R
M="!);6%G92(*;7-G<W1R(")6;&^^:70@;V)RX7IE:R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R
M="!486)L92(*;7-G<W1R(")6;&^^:70@=&%B=6QK=2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN<V5R
M="!796(@3&EN:R(*;7-G<W1R(")6;&^^:70@=V5B;W;](&]D:V%Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,T"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B5FQO
MOFET(%]S;&]U<&5C('#X960@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N
M97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")6;&^^
M:70@;F]V_2!S;&]U<&5C('IA('-O=>AA<V[](@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("))
M;G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`B5FQOOFET(&YO=OT@<VQO=7!E8R!P^&5D('-O=>AA<V[](@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT
M(&]N92(*;7-G<W1R(")6;&^^:70@;F]V_2#XX61E:R!Z82!S;W7H87-N_2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U
M<G)E;G0@;VYE(@IM<V=S='(@(E9L;[YI="!N;W;](/CA9&5K('#X960@<V]U
MZ&%S;OTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E
M<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(E9L;[YI="!O9'-T879E8R!Z
M82!S;W7H87-N_2!U>F5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A
M9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B5FQOOFET
M(&]D<W1A=F5C('#X960@<V]UZ&%S;OT@=7IE;"(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E;7!L871E
M(@IM<V=S='(@(E9L;[YI="!A;'1E<FYA=&EV;NT@=GIO<B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,SD*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A
M9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W
M;W)D.B(*;7-G<W1R(")6;&^^=&4@96UA:6QO=F]U(&%D<F5S=2P@;F$@:W1E
M<F]U(&]B9'*^[71E(&YO=ND@:&5S;&\Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T
M(&-E;&P@869T97(B"FUS9W-T<B`B5FQOOFET(&)U\FMU('IA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM
M<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(E9L;[YI="!B=?)K
M=2!P^&5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G
M<W1R(")6;&^^:70@<VQO=7!E8R!Z82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C
M;VQU;6X@8F5F;W)E(@IM<V=S='(@(E9L;[YI="!S;&]U<&5C('#X960B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I
M9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(E9L;[YI="!Z<'+A=GDB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B
M5FQOOFET(&]D<W1A=F5C('IA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R
M86=R87!H(&)E9F]R92(*;7-G<W1R(")6;&^^:70@;V1S=&%V96,@</AE9"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B5FQOOFET
M(/CA9&5K('IA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS
M9W-T<B`B5FQOOFET(/CA9&5K('#X960B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C,P"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T
M;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(E9L;[YT92!P;[YA
M9&]V86YO=2!O9'!O=NSO(&YA(&)E>G!EZ&YO<W1N[2!O=.%Z:W4Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I
M9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R(")6;&^^:70O=7!R879I
M="!O8G+A>F5K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@
M(E9L;[YI="]U<')A=FET(&]D:V%Z(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N
M="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM
M<V=S='(@(DYE9&]S=&%T9>AN_2!K<F5D:70@:R!O9&5S;.%N[2!Z<'+A=GD@
M;F$@9&ES=')I8G7H;NT@<V5Z;F%M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE
M;G0@8W)E9&ET+B(*;7-G<W1R(").961O<W1A=&7H;OT@:W)E9&ET+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-S4*;7-G:60@(DEN=&5G97(B
M"FUS9W-T<B`B0V5LZ2#H[7-L;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q,S,*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R(")397IN86T@
M8V5L_6-H(.CM<V5L(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@
M1&%T82!(96%D97(I+B(*;7-G<W1R(").97-P<N%V;ND@541(+B`H57-E<B!$
M871A($AE861E<BDN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+WII<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z
M:7`N<&AP.C(P,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP
M+G!H<#HR,3`*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS
M9W-T<B`B3F5P;&%T;N$@9&%T82!U;FEC;V1E+B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM
M<V=S='(@(DYE<&QA=&[A(&%P;&EK86-E+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI
M9"!B871C:"!)1"XB"FUS9W-T<B`B3F5P;&%T;ND@:61E;G1I9FEK8>AN[2#H
M[7-L;R`H240I(&3A=FMY+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(P.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R.3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H
M<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B
M0GEL82!Z863A;F$@;F5P;&%T;N$@9&%T82(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI
M9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R(").97!L871NX2!A9')E
M<V$@</CM:F5M8V4N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+V1B>"YP:'`Z.#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B
M>"YP:'`Z,3`P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N
M<&AP.C(R,`IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R(").
M97!L871N_2!F;W)MX70@<V]U8F]R=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-S<*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;&EC96YS
M92!K97DN(@IM<V=S='(@(DYE<&QA=&[A(&%P;&EK86-E+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S$*(RP@9G5Z>GD*;7-G:60@(DEN
M=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(DYE<&QA=&[A(&%P
M;&EK86-E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T
M<B`B3F5P;&%T;OT@;7-G7W1Y<&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R
M(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R(").97!L871NZ2!N96)O(&-H>6+L
M:NUC[2!A<&E?:60N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@
M<&%R86UE=&5R<RXB"FUS9W-T<B`B3F5P;&%T;ND@;F5B;R!C:'EB[&KM8^T@
M<&%R86UE=')Y+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM
M<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B3F5P
M;&%T;N$@=FQA<W1N:6-KX2!P<N%V82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,3<S"B,L(&9U>GIY"FUS9VED("));G9A;&ED('!A<G1N
M97(@:60N(@IM<V=S='(@(DYE<&QA=&[A('9L87-T;FEC:^$@<'+A=F$N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-0HC+"!F=7IZ>0IM
M<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(DYE<&QA=&[]
M('!R;W1O:V]L+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS
M9W-T<B`B3F5P;&%T;OT@<')O=&]K;VPN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B3F5P;&%T;OT@
M</CM:F5M8V4Z("<E<R<B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$P-S8@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C8R"FUS9VED("))
M;G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R(").97!L871N_2!S9.UL96[]
M(&]B:F5K="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB
M"FUS9W-T<B`B3F5P;&%T;N$@861R97-A(&]D97/M;&%T96QE+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM
M<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(DYE<&QA=&[A
M(&1A=&$@=6YI8V]D92XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S4W"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B26YV96YTX?@B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<Y"B,L(&9U
M>GIY"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(E9Y<W3X:6AN
M;W5T(';]8NQR(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(LURX6XL($ES;.%M<VOA(')E<'5B;&EK
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("))<N%K(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@(DER<VMO(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@
M;V8@36%N(@IM<V=S='(@(D]S=')O=B!M=;YE(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M
M4W1O<FUS(@IM<V=S='(@(D]J961I;NQLZ2!B;W7X:WDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R("))<W)A96PB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-0IM<V=I9"`B27-S=65R(@IM
M<V=S='(@(E!O<VMY=&]V871E;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(DMU
M<GKM=F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DET86QY(@IM<V=S='(@(DET
MX6QI92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R(")*
M86UA:FMA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B3&5D96XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@(DIA<&]N<VMO(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R
M,BU*4"DB"FUS9W-T<B`B2F%P;VZY=&EN82`H25-/+3(P,C(M2E`I(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*;7-G:60@(B(*(DIA=F%S
M8W)I<'0@:&%S(&)E96X@9&ES86)L960@;VX@>6]U<B!B<F]W<V5R(&%N9"!T
M:&ES('!A9V4@;6%Y(&YO="!B92`B"B)D:7-P;&%Y:6YG(&-O<G)E8W1L>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*
M;7-G:60@(DIE<G-E>2(*;7-G<W1R(")4<FEK;W0B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*
M;7-G:60@(DIO<F1A;B(*;7-G<W1R(")*;W)DX6YS:V\B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*
M;7-G<W1R("+(97)V96YE8R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(LAE<G9E;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B6F%R;W9N870B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B6F%R;W9N870@;F$@
M<W3X960B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(EIA
M<F]V;F%T('9Y<&QN[&[M;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B
M"FUS9W-T<B`B6F%R;W9N870@9&]L979A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I
M9GD@4FEG:'0B"FUS9W-T<B`B6F%R;W9N870@9&]P<F%V82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R(")+87IA8VAS=.%N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V-`IM
M<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B56-H;W9A="!O<FEG:6[A
M;#\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DME;GEA(@IM<V=S='(@(DME\F$B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+
M97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(DME<F)E<F]S('-E<G9E<B!Z86WM=&YU;"!O=NSX96[M+B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B
M"FUS9W-T<B`B3F]VX>AC:2!K97)N96QU(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T
M<B`B5GET=F_X96[M(&ML[>AE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B
M5GET=F_X96[M(&]T:7-K=2!K;.WH92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R(")$
MZ6QK82!K;.WH92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B5'EP(&ML[>AE(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(DME
M>2!5<V%G92(*;7-G<W1R(")5OFET[2!K;.WH92(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI
M<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")+;.WH(&II
MOB!E>&ES='5J92!N82!V9?AE:F[I;2!K;.WH;W;I;2!S97)V97)U+B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R
M(")$['1I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R
M(")+:7)I8F%T:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C
M<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B2TQ$4B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@
M(DMO<F5A(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(DMO
M<F5A;B`H155#+4M2*2(*;7-G<W1R(")+;W)E:G-K>2`H155#+4M2*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(DMU=F%J="(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R(")+>7)G:7IS
M=.%N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),
M85]Y;W5T(@IM<V=S='(@(E]2;WIL;[YE;NTB"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG=6%G92(*;7-G<W1R(")*87IY
M:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T
M:6,@4F5P=6)L:6,B"FUS9W-T<B`B3&%O<RP@3&ED;W;L($1E;6]K<F%T:6-K
M82!297!U8FQI:V$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED
M("),87-T($AA;&8B"FUS9W-T<B`B1')U:.$@<&]L;W9I;F$B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-S8*(RP@9G5Z>GD*;7-G:60@(DQA<W0@4&%S
M<W=O<F0@0VAA;F=E(@IM<V=S='(@(E;]8VAO>NT@;F%S=&%V96[M(&AE<VQA
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H
M<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(E!O<VQE9&[M(.AT
M=G)T:6YA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3$*;7-G:60@(DQA
M<W0@57!D871E9#HB"FUS9W-T<B`B4&]S;&5D;NT@86MT=6%L:7IA8V4Z(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*
M;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(E!O<VQE9&[M('#X:6AL
MX;EE;NTZ("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S(Q"B,L
M('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS
M9W-T<B`B4&]S;&5D;NT@</AI:&SAN65N[3H@)7,@>B`E<R(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.C<Q-@IM<V=I9"`B3&%S="!L;V=I;CH@3F5V
M97(B"FUS9W-T<B`B4&]S;&5D;NT@</AI:&SAN65N[3H@3FEK9'DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#D*;7-G:60@(DQA='9I82(*;7-G<W1R("),:71V82(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(E!R
MX79O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<Y"FUS9VED("),87EO=70B"FUS9W-T<B`B4F]Z;&^^96[M(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM
M<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R(").96-H
M870@<'+A>F1NZ2!B97H@;VMR86IE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),
M96)A;F]N(@IM<V=S='(@(DQI8F%N;VXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS
M9W-T<B`B1&]L979A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q
M.0IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B3&5VX2!H;&%V:>AK82(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,34*;7-G:60@(DQE9G0@
M=F%L=65S(@IM<V=S='(@(DAO9&YO='D@;F%L979O(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X
M"FUS9VED("),97-O=&AO(@IM<V=S='(@(DQE<V]T:&\B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(DQE=F5L
M(@IM<V=S='(@(DSA<VMA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA
M(@IM<V=S='(@(DQI8NER:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI8GEA
M;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B3&EB:64B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B3&EC:'1E;KET96IN
M<VMO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C4*;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B3&5H:^D@;7)H;VQE
M;NTB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-@IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R("),96AK_2!DZ;F[(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@
M(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B0G)Z:_T@;&5H:_T@9.FYNR(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS
M9VED("),:6=H="!286EN($QA=&4B"FUS9W-T<B`B4&]Z9.QJ:2!L96AK_2!D
MZ;F[(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(DQE:&OI(&1E
MN;MO=ND@<W+AOFMY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM
M<V=S='(@(DQE:&O](&3IN;L@<R!H^&WL;NUM(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B
M"FUS9W-T<B`B3&5H:^D@<V[LOF5N[2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E
M<B(*;7-G<W1R("),96AKZ2!S;NQH;W;I('#X96CA\FMY(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("),
M:6UE<FEC:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,30*;7-G
M:60@(DQI;FLB"FUS9W-T<B`B3V1K87HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@
M<&]I;G1S('1O.B(*;7-G<W1R(")/9&MA>GD@=6MA>G5J[2!N83HB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H92!E
M;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y
M:6YG(@IM<V=S='(@(B(*(E!O=;[M="!O9&MA>GD@;F$@96UA:6QO=ND@861R
M97-Y('#X:2!Z;V)R87IO=N%N[2!S='+A;FMY('!R;R!P<V%N[2!Z<'+A=B(*
M"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H
M<#HQ.#,*;7-G:60@(DQI;FMS(@IM<V=S='(@(D]D:V%Z>2(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S
M='(@(DQI;G5X;W;I(&-O;VMI92(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E
M('1H92!F;VQD97(B"FUS9W-T<B`B4V5Z;F%M("T@=;YI=F%T96P@;?F^92!V
M:63L="!S;&^^:W4B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS9VED
M("),:7-T($1A=&%B87-E<R(*;7-G<W1R(")397IN86T@9&%T86+A>NTB"@HC
M.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,`IM<V=I9"`B3&ES="!(96QP
M(%1O<&EC<R(*;7-G<W1R(")397IN86T@=.EM870@;N%P;W;L9'DB"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3,R"FUS9VED("),:7-T(%1A8FQE<R(*;7-G
M<W1R(")397IN86T@=&%B=6QE:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B
M4V5Z;F%M+4%R8VAI=B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R
M<RYP:'`Z-3@Y"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`B4V5Z;F%M+4[A
M<&]V[&1A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU
M.38*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B4V5Z;F%M+4ED(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3(*;7-G:60@(DQI<W0M
M3W=N97(B"FUS9W-T<B`B4V5Z;F%M+59L87-T;NUK(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12](96%D97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*
M;7-G<W1R(")397IN86TM3V1E<VSA;NTB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS
M9W-T<B`B4V5Z;F%M+5#X:6ALX;EE;NTB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*
M;7-G<W1R(")397IN86TM3V1H;.&Y96[M(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E
M<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`B5OUP:7,@=;YI=F%T96SY(&YE
M;NT@9&]S='5P;OTN(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B5OUP:7,@=;YI=F%T96SY(&YE;NT@9&]S='5P;OTN(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),
M:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")6_7!I<R!UOFEV
M871E;/D@;F5N[2!D;W-T=7!N_2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B3&ET97)A='5R82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(DQO='FY
M<VMO(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6UA9V5S+G!H
M<#HX,PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R(").86ARX7;A;NTN+BXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Q"FUS9VED("),
M;V-A;"!T:6UE.B`B"FUS9W-T<B`B3>US=&[M(.AA<SH@(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@S"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS
M9W-T<B`B3&]C86QE(&$@Z&%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-S$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8T
M"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N
M<&AP.C8U"FUS9VED("),;V-A=&EO;B(*;7-G<W1R(")-[7-T;R(*"B,Z(&QO
M9VEN+G!H<#HQ-S(@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y,2!T
M96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I
M;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*
M;7-G:60@(DQO9R!I;B(*;7-G<W1R(")0^&EH;.%S:70@<V4B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V
M:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-I9&5B87(N<&AP.C$X-0IM<V=I9"`B3&]G(&]U="(*;7-G<W1R(")/
M9&ALX;EE;NTB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*(RP@9G5Z
M>GD*;7-G:60@(DQO9VEN(@IM<V=S='(@(E#X:6ALX7-I="!S92(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G:60@(DQO9VEN(%1A<VMS(@IM
M<V=S='(@(MIK;VQY('!R;W;A9.QNZ2!P^&D@</AI:&SAN65N[2(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY-@IM<V=I9"`B3&]G:6X@9F%I;&5D
M(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E
M9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB4V5L:&%L;R!P^&EH;.&Y96[M
M(&1O('-Y<W3I;74N(%!R879D['!O9&]B;NP@5F&Y92!UOFEV871E;'-KZ2!J
M;>EN;R!A+VYE8F\@(@HB:&5S;&\@;F5B>6QO('-P<N%V;NP@>F%DX6YO+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,@IM<V=I9"`B3&]G:6X@
M9F%I;&5D+B(*;7-G<W1R(")0^&EH;.&Y96[M('-E;&AA;&\N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-0IM<V=I9"`B3&]N9R!T97AT(@IM
M<V=S='(@(D1L;W5H_2!T97AT(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0X"FUS9VED("),;W9E(@IM<V=S='(@(DSA<VMA(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(DQO=R(*;7-G
M<W1R(").[7IKX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E
M<G,B"FUS9W-T<B`B36%LX2#X96-KX2!P[7-M96YA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I
M9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R(")-86SA('1I<VMA8^T@
M<.US;65N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B
M"FUS9W-T<B`B36%LZ2#X[6US:^D@Z.US;&EC92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM
M<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("),=6-E;6)U<G-K;R(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#`*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S."!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Q"FUS9VED(")-3U1$(@IM<V=S
M='(@(EIP<N%V82!D;F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A
M:6YE9"!N;R!D871A+B(*;7-G<W1R(")0^&EP;VIE;OT@<V]U8F]R($U3+4Y4
M148@;F5O8G-A:'5J92"^X61NX2!D871A+B(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*
M;7-G:60@(DU31R(*;7-G<W1R(")-4T<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@
M(DUA8V%O(@IM<V=S='(@(DUA:V%O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-
M86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS
M9W-T<B`B36%K961O;FEE+"!B_79A;.$@4F5P=6)L:6MA($IU9V]S;.%V:64B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T<B`B36%D
M86=A<VMA<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0IM<V=I9"`B
M36%G:6,B"FUS9W-T<B`B36%G:64B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z.#$*;7-G:60@(DUA:6PB"FUS9W-T<B`B4&^Y=&$B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(R"FUS9VED(")-86EL($%D;6EN(@IM
M<V=S='(@(D%D;6EN:7-T<N%T;W(@<&^Y='DB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA
M:V4@;&EN7VLN+BXB"FUS9W-T<B`B5GET=F_X:70@;V1?:V%Z+BXN(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDT"FUS9VED(")-86QA=VDB"FUS9W-T<B`B36%L87=I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R(")-86QA:G-I92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B36%L9&EV
M>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%L:2(*;7-G<W1R(")-86QI(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDT"FUS9VED(")-86QT82(*;7-G<W1R(")-86QT82(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N86=E('1H
M92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@
M=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T
M96=O<FEE<RXB"FUS9W-T<B`B(@HB4')O('5M;[YN[&[M(&]V;.%DX6[M(&MA
M=&5G;W)I[2!J92!Z87!O=/AE8NT@;WIN8>AI="!P;VQOOFMY(&)A<G9A;6DL
M(&MT97+I("(*(FIS;W4@</AI^&%Z96YY(&L@=.QM=&\@:V%T96=O<FGM;2XB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U
M,PIM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(DUA<&$@36%P,C0B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-`HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$V.`IM<V=I
M9"`B36%P475E<W0@;6%P(@IM<V=S='(@(DUA<&$@36%P475E<W0B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S
M('-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(D+X97IE
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")/:W)A:B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-
M87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B3WIN8>AI="!Z
M;F'H:V]U(%!R;VALZ61N=71O+TYE<')O:&SI9&YU=&\B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W
M:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS
M9W-T<B`B3WIN8>AI="!J:6[];6D@>FYAZ&MA;6D@*&IA:V\@1/EL9;YI=.DO
M3V1P;W;L>F5NZ2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES
M;&%N9',B"FUS9W-T<B`B36%RN6%L<VOI($]S=')O=GDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R=&EN:7%U92(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN
M9R!F:65L9',B"FUS9W-T<B`B4VAO9'5J[6/M('-E('!O;&4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B36%U<F5TX6YI92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(DUA=7)I
M8VEU<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R
M(")-87AI;6%L;NT@<&]V;VQE;OT@:W)E9&ET(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@
M;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B0GEL82!P^&5K<F_H
M96YA(&UA>&EM86QN[2!DZ6QK82!Z<'+A=GDN(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*
M;7-G<W1R(").96IV>;FY[2!T97!L;W1A('IA('!O<VQE9&[M8V@@,C0@:&]D
M:6XZ("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDX"FUS9VED(")-87@@
M=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(").96IV>;FY[2!T97!L;W1A
M('IA('!O<VQE9&[M8V@@-B!H;V1I;CH@(@H*(SH@;&EB+V%P:2YP:'`Z.#8*
M;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B36%X:6WA
M;&[M(&3I;&MA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R(")+=NQT96XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@(DUA>6]T=&4B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S
M='(@(DUE9&EC[6YA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*;7-G<W1R("+(;&5N;W;I(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.`IM<V=I9"`B365N=2!M;V1E.B(*
M;7-G<W1R(")-\V1Y('!R;R!M96YU.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E
M;&QS(@IM<V=S='(@(E-P;VII="!B=?)K>2(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S
M86=E(@IM<V=S='(@(EIP<N%V82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U
M8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD
M(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B6G!RX79A(&)Y;&$@;W;L
M^&5N82!V('!O^.%D:W4L(&%L92!N96QZ92!O=NSX:70@<&]D<&ES;W;](&-E
M<G1I9FEKX70N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$P"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S
M='(@(EIP<N%V82!P<F]P861L82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"FUS9VED(")-
M97-S86=E('1Y<&4B"FUS9W-T<B`B5'EP('IP<N%V>2(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G<W1R(")0
M;^AA<^TB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-971A
M<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")";&]K(&\@<&_H87/M
M(&YE;NT@9&]S='5P;OTN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3(*
M;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@
M:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(B(*(D)L;VL@;R!P;^AA<^T@;F5N[2!D;W-T=7!N_2X@4&]D<F]B;F]S
M=&D@8GEL>2!Z87IN86UE;N%N>2!P<F\@<WES=.EM;W;I:&\@(@HB861M:6YI
M<W1RX71O<F$@9&\@;&]G=2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,38U"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C<@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-`IM
M<V=I9"`B365T:&]D(@IM<V=S='(@(DUE=&]D82(*"B,Z(&9R86UE=V]R:R]2
M4$,O4E!#+WAM;')P8RYP:'`Z.#$@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP
M:'`Z,3$W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E
M<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(DUE=&]D82`G)7,G(&YE;NT@
M9&5F:6YO=N%N82(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R
M"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L
M;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C<T(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*;7-G:60@
M(DUE=')I8R(*;7-G<W1R(")-971R:6-K_2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I
M9"`B365X:6-O(@IM<V=S='(@(DUE>&EK;R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED
M(")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(DUI
M:W)O;NES:64L($9E9&5R86-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<V"FUS9VED(")-:61D;&4B"FUS9W-T
M<B`B57!R;W-T^&5D(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R(")4>7`@36EM
M92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$P"FUS9VED(")-:6X@=&5M
M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B3F5J;FF^N>T@=&5P;&]T82!Z
M82!P;W-L961N[6-H(#(T(&AO9&EN.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,P,@IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T
M<B`B3F5J;FF^N>T@=&5P;&]T82!Z82!P;W-L961N[6-H(#8@:&]D:6XZ("(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-
M:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,S0*;7-G:60@(DUI<G)O<B(*;7-G<W1R("):<F-A9&QO=NPB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B
M"FUS9W-T<B`B4OEZ;NDB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K
M86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B4')O9W)A;6]V_2!B86SM:R!(
M5%107U)E<75E<W0@8VAY8NT@=B!014%2+B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@
M66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S
M92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"B)#:'EB[&KM8^T@
M:V]N9FEG=7)A8V4N(%!O:W5D('-I('#X96IE=&4@<&]UONUV870@='5T;R!A
M<&QI:V%C:2P@;75S[71E("(*(G9Y9V5N97)O=F%T(&MO;F9I9W5R8>AN[2!S
M;W5B;W(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S
M='(@(D-H>6+L:NUC[2!)1"!Z<'+A=GD@*&ED96YT:69I:V'H;NT@Z.US;&\I
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E
M($UA:6PN(@IM<V=S='(@(E!OOF%D;W9A;OT@<')O9W)A;6]V_2!B86SM:R!-
M86EL(&-H>6+M('8@4$5!4BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO
M;B!)1"XB"FUS9W-T<B`B0VAY8NQJ[6/M($E$('!R;R!R96QA8VDN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I
M9"`B36\B"FUS9W-T<B`B4&\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-S0*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@(DUO8FEL;NT@<&^Y
M=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M.`IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B3>UR;OTB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX.`IM<V=I9"`B36]D:69I960@1&%T92(*;7-G
M<W1R(")$871U;2!P;W-L961N[2!Z;>QN>2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D
M:69Y(%523"(*;7-G<W1R("):;>SR:70@55),(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S,*;7-G:60@(DUO9'5L=7,B"FUS9W-T
M<B`B36]D=6PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(DUO;&3A=FEE(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED
M(")-;VYA8V\B"FUS9W-T<B`B36]N86MO(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED
M(")-;VYG;VQI82(*;7-G<W1R(")-;VYG;VQS:V\B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-3DT"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G
M<W1R(")-['/M8R!A(')O:R(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-
M86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B3>QS
M[>AN["(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R
M(")-;VYS97)A="(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C
M:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B1N%Z
M92!-['/M8V4B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-S(@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C4S"B,L('!H<"UF;W)M870*
M;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@
M97AP96-T960@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B
M36]R;V-C;R(*;7-G<W1R(")-87)O:V\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM
M<V=S='(@(E#X97;AOF[L(&IA<VYO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS
M9W-T<B`B4/AE=N&^;NP@;V)L8>AN;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS
M9W-T<B`B4/AE=N&^;NP@<VQU;F7H;F\B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HU,#D*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R
M(")0;W-U;F]U="!D;VSY(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z-3$S"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B4&]S=6YO
M=70@9&]L979A(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z-3$W"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(E!O<W5N;W5T(&1O
M<')A=F$B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU
M,#4*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B4&]S=6YO=70@;F%H;W)U(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM
M<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(E!O<W5N;W5T(&1O;/DB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(S"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@
M(DUO=F4@=7`B"FUS9W-T<B`B4&]S=6YO=70@;F%H;W)U(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(DUO<V%M8FEK(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-`IM<V=I9"`B375L=&DM;&5V
M96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(E;M8V4M^G)O=O)O=ND@<F]L
M971O=ND@<V5Z;F%M>2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,#4U"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,@IM<V=I9"`B
M375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(E;M8V5NX7-O8F[A('-E;&5K
M8V4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`P"FUS9VED(")-
M>2!!8V-O=6YT(@IM<V=S='(@(DWY:B#ZZ&5T(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C(X"B,L(&9U>GIY"FUS9VED(")->2!!8V-O=6YT($EN9F]R
M;6%T:6]N(@IM<V=S='(@(E9AN64@:6YF;W)M86-E(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+VEN9&5X+G!H<#HU-`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@
M(DWY:B!P;W)TX6PB"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z,3,V
M"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(DUO:F4@<F]Z;&^^
M96[M('!O<G3A;'4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS
M9W-T<B`B37EA;FUA<B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN
M=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS
M9W-T<B`B3D4L($Y%4T]52$Q!4\U-(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE
M9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`B2FWI;F\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B3F%M:6)I92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B3F%U<G4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(DYE<.%L(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDW"FUS9VED(").971H97)L86YD<R(*;7-G<W1R(").:7IO>F5M[2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R
M(").:7IO>F5M<VOI($%N=&EL>2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G
M<W1R(").971S8V%P92!"87-E(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!#02!2979O8V%T
M:6]N(%523"(*;7-G<W1R(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED
M(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(DYE='-C87!E($-!
M('!O;&EC>2!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B
M3F5T<V-A<&4@4F5N97=A;"!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!5
M4DPB"FUS9W-T<B`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A
M<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(DIMZ6YO($YE='-C87!E(%-3
M3"!S97)V97)U(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.#<*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS
M9W-T<B`B4&]Z;N%M:V$@:R!C97)T:69I:^%T=2!.971S8V%P=2(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@P"FUS9VED(").971S
M8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(E1Y<"!C97)T:69I:^%T
M=2!.971S8V%P=2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3$*
M;7-G:60@(DYE='=O<FLB"FUS9W-T<B`B4^V[(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M,S4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-@IM<V=I9"`B3F5V97(B
M"FUS9W-T<B`B3FEK9'DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE
M9&]N:6$B"FUS9W-T<B`B3F]VX2!+86QE9&]N:64B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W
M($-A=&5G;W)Y(@IM<V=S='(@(DYO=N$@:V%T96=O<FEE(@H*(SH@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R86UE
M=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F<F%M
M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@9G)A
M;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS
M9W-T<B`B5GET=F_X:70@>G!RX79U("@E<RDB"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(DWL<^UC('8@<')V
M;NT@Z'1V<G1I;NPB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R
M(").;W;I('6^:79A=&5L<VOI(&IMZ6YO("AN97!O=FEN;NDI(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDX"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R(").;W;](%KI;&%N
M9"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PHC+"!F=7IZ
M>0IM<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(DAE<VQO(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU,@HC+"!F=7IZ
M>0IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"XB"FUS9W-T<B`B
M2&5S;&$@<V4@;75S[2!S:&]D;W9A="XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?
M8FQA;FLI(@IM<V=S='(@(DYO=ND@;VMN;R`H7W!RX7ID;NDI(@H*(SH@;&EB
M+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#D*;7-G:60@(DYE=W,B
M"FUS9W-T<B`B3F]V:6YK>2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS,#4*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B3F5W<V=R;W5P<R(*
M"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D
M871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z,3(Y('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").
M97AT(@IM<V=S='(@(D1A;+GM(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W
M"B,L(&9U>GIY"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(D1A;+GM
M(&;A>F4B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W,B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W-@IM<V=I9"`B3F5X="!O
M<'1I;VYS(@IM<V=S='(@(D1A;+GM(&UOOFYO<W1I(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U!A9V5R+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(DYE>'0^(@IM
M<V=S='(@(D1A;+GM(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B
M"FUS9W-T<B`B3FEK87)A9W5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E
M<B(*;7-G<W1R(").:6=E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I
M82(*;7-G<W1R(").:6?I<FEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,X,`IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B3F]C(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDW"FUS9VED(").:75E(@IM<V=S='(@(DYI=64B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(").;R(*
M;7-G<W1R(").92(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT
M;6PZ.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T
M;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`BKF%D;N$@:V]N9FEG
M=7)AZ&[M(&1A=&$@;F5J<V]U(&1O<W1U<&[A('!R;R!Z;V)R87IE;NT@<F]Z
M9.UL^2XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N
M<&AP.C$P-0IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI
M;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B3F5N[2!D;W-T=7!NX2"^X61NX2!S
M=')A=&5G:64@<')O('1V;W)B=2!)4T\@;V)R87KY+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B
M3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(D)E>B!DX79K;W;I:&\@=GIO
M<G4N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-SD@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C0U"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(V-PIM<V=I9"`B3F\@8FQO
M8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B
M3F$@<&^^861O=F%NZ2!P;WII8VD@;F5E>&ES='5J92"^X61N_2!B;&]K(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@
M8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B3F5B>6QO('!O<VMY=&YU=&\@ON%D;ND@:FWI;F\@<')O
M(&MA;&5N9.'X('#X:2!O=NSX;W;A;NT@<&]M;V/M($U#04PN(@H*(SH@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T
M<B`B0F5Z('IM[&YY+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI
M<R!P97)M:7-S:6]N+B(*;7-G<W1R(").96QZ92!P^&ED870@ON%D;N$@<&]D
M+7!RX79A(&L@=.QM=&\@<'+A=OEM+B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,38W(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`R"B,Z
M(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<W,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@)7,N(@IM<V=S='(@(DYE8GEL>2!U=F5D96YY(+[A9&[I(&MO;F9I9W5R
M8>AN[2!I;F9O<FUA8V4@<')O("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.#(T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B3F5B>6QY('5V
M961E;GD@ON%D;ND@:V]N9FEG=7)AZ&[M(&EN9F]R;6%C92!P<F\@1E10(%9&
M4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8V.0IM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-1
M3"!61E,N(@IM<V=S='(@(DYE8GEL>2!U=F5D96YY(+[A9&[I(&MO;F9I9W5R
M8>AN[2!I;F9O<FUA8V4@<')O(%-13"!61E,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C<Q-PIM<V=I9"`B3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS
M9W-T<B`B3F5B>6QY('5V961E;GD@ON%D;ND@:V]N9FEG=7)AZ&[M(&EN9F]R
M;6%C92!P<F\@4U%,+49I;&4@5D93+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET
M(&QE9G0N(@IM<V=S='(@(DYE;>%T92"^X61N_2!K<F5D:70N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G
M:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R(").96)Y;"!P
M;W-K>71N=70@ON%D;OT@8^UL+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R
M;W=S97(N<&AP.C@W-PIM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R
M("*NX61N_2!S;W5B;W(@;F5B>6P@</AE;F5S96XB"@HC.B!U=&EL+VEC;VY?
M8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R
M(").96)Y;'D@;F%L97IE;GD@ON%D;ND@:6MO;GDN(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$R."!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C,*;7-G:60@(DYO(&QO8V%T
M:6]N(&ES('-E="XB"FUS9W-T<B`B3F5B>6QO('9Y8G+A;F\@ON%D;ND@;>US
M=&\N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V.0HC+"!F
M=7IZ>0IM<V=I9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(DYE
M8GEL;R!V>6)RX6YO(+[A9&[I(&WM<W1O+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M97-S
M86=E('-U<'!L:65D+B(*;7-G<W1R(").96)Y;'D@<&]S:WET;G5T>2"^X61N
MZ2!Z<'+A=GDN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G
M<W1R(").96)Y;&\@=79E9&5N;R"^X61NZ2!J;>EN;RXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B
M3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B3F5B>6QO('5V961E;F\@
MON%D;ND@Z.US;&\N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS
M9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B0F5Z(&YE<VQU
MN6[]8V@B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"FUS
M9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B3F5B>6QO('!O<VMY=&YU=&\@:&5S;&\@<')O(&]V
M[/AE;NT@<&]M;V/M($A45%`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I
M;6%P+G!H<#HQ,#@*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)
M34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").96)Y;&\@<&]S:WET;G5T
M;R!H97-L;R!P<F\@;W;L^&5N[2!P;VUO8^T@24U!4"XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VMR8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(DYE8GEL;R!P;W-K>71N=71O(&AE<VQO('!R;R!O=NSX96[M('!O;6]C[2!+
M97)B97)O<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C<W
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&]G:6XN<&AP.C@T"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<&%M+G!H<#HW-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").96)Y
M;&\@<&]S:WET;G5T;R!H97-L;R!P<F\@;W;L^&5N[2!P^&EH;.&Y96[M('-E
M(&1O('-Y<W3I;74N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P87-S=V0N
M<&AP.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-7
M1"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F5B>6QO('!O<VMY=&YU=&\@
M:&5S;&\@<')O(&]V[/AE;NT@<&]M;V/M(%!!4U-71"XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYE8GEL
M;R!P;W-K>71N=71O(&AE<VQO('!R;R!O=NSX96[M('!O;6]C[2!334(N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@V"FUS9VED
M("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@
M5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I
M=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"B).96)Y;&$@<&]S:WET;G5T
M82!C97-T82!K(&)I;N%R;NUM=2!S;W5B;W)U($]P96Y34TPN($)I;N%R;NT@
M<V]U8F]R($]P96Y34TP@(@HB:F4@>F%P;W3X96+M('!R;R!P<N%C:2!S(%!+
M0U,@,3(@9&%T>2XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@(J[A
M9&[I(&YE=GGX[7IE;ND@ON%D;W-T:2!O('#X:6ALX;EE;NTN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C<U,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R(").96[M(&YA<W1A=F5N;R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(D)E>B!P<F%V:61E;"(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T.0HC+"!F=7IZ>0IM
M<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B3F5B>6QO
M('5V961E;F\@ON%D;ND@Z.US;&\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`IM<V=I9"`B3F\@<VED97,B
M"FUS9W-T<B`B0F5Z(&]K<F%J^2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-3@S"B,L(&9U>GIY"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T
M<B`B0F5Z(&]K<F%J^2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ,S@*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE
M(&9O<B!C86-H92XB"FUS9W-T<B`BKN%D;OT@>B!D;^AA<V[]8V@@861R97/A
M^/D@;F5N[2!D;W-T=7!N_2!P<F\@8V%C:&4N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@(DYO('5S97)N
M86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R(").96)Y;&\@;V1E
M<VSA;F\@ON%D;ND@=;YI=F%T96QS:^D@:FWI;F\@82]N96)O(&AE<VQO+B(*
M"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").
M;R!V86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R(").96)Y;&$@;F%V
M<N%C96YA(+[A9&[A('!L871NX2!834P@9&%T82XB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3<Q"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HY.#$*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY,@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`P.0IM<V=I9"`B3F\@=F%L=65S
M(@IM<V=S='(@(J[A9&[I(&AO9&YO='DB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L
M(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B5B!O<FEG:6[A;&[M(&MO;F9I9W5R86-I(&YE8GEL82!N86QE>F5N
M82!V97)Z92X@3V)N;W9T92!K;VYF:6=U<F%C:2XB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO
M=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R(")692!68;GM(&MO;F9I9W5R86-I(&YE8GEL82!N86QE>F5N82!V
M97)Z92X@3V)N;W9T92!K;VYF:6=U<F%C:2XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O
M:61E;G1I='ES96QE8W0N:6YC.CDS"FUS9VED(").;VYE(@IM<V=S='(@(J[A
M9&[](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R("*NX61N
M_2`H<&]UOFEJ=&4@:6UP;&EC:71N[2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X.0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B
M4V5V97)S:_T@*$E33RTX.#4Y+3$P*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B
M3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B3F]R9F]L:W-KZ2!O<W1R;W9Y(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV
M,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")3979E<F[M
M('!O;&]K;W5L92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R
M:6%N82!)<VQA;F1S(@IM<V=S='(@(E-E=F5R;NT@36%R:>%N<VOI(&]S=')O
M=GDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R(").;W)S
M:V\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM
M<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(DYE;NT@<&\B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B3F]T($)E9F]R
M92(*;7-G<W1R(").96[M('#X960B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HT,#@*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R(").
M96[M(&%D<F5SX?AE;2(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP
M:'`Z.30*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED
M(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(DYE;NT@:6UP;&5M96YT;W;A
M;F\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHV.`IM<V=I9"`B3F]T('-E="(*;7-G<W1R(").96[M(&YA<W1A=F5N;R(*
M"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP
M:'`Z,30S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<BYP:'`Z,34X"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<BYP:'`Z,3<S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@W"B,Z(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,T(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HQ.3`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(P-2!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR-#@@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V-0HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.3<*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q,B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,S(Y"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS-C(@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C0R,@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3`Q
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C4X-R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-C8U"FUS9VED(").
M;W0@<W5P<&]R=&5D+B(*;7-G<W1R(").96[M('!O9'!O<F]VX6YO+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N
M9FEG+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$W.`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B4&]Z;N%M:V$B"@HC
M.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI
M;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R(").:6,@:R!P<F]H;.ED
M;G5T[2P@8NR^=&4@>G#L="XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B3&ES
M=&]P860B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V"FUS9VED
M(").=6UB97(B"FUS9W-T<B`BR.US;&\B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-#(U"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G
M<W1R(")0;^AE="!Z;F%K^2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$S-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,PHC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#0U('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*
M;7-G<W1R(")0;^AE="!S;&]U<&/Y(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S
M(@IM<V=S='(@(E!OZ&5T(/CA9&OY(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T
M('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N
M(@IM<V=S='(@(DYE8GEL82!Z863A;F$@Z.US;&$@<')O(&%K='5A;&EZ86-I
M(&1I<W1R:6)UZ&[M:&\@<V5Z;F%M=2XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@(D]+
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W
M,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@(D]B:F5K="(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O<B(*
M;7-G<W1R(")4=OER8V4@;V)J96MT^2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(D]S;6GH:V]V_2(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS
M9VED(")/8W1O8F5R(@IM<V=S='(@(MCM:F5N(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R(")&
M:6QT<F]V870@;F5S;'6Y;NDB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S(V"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B2V%N8V5LX?@B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@
M;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"B,L(&9U>GIY"FUS
M9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B2&5S;&\B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*(RP@9G5Z>GD*;7-G:60@(D]L9"!P
M87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B3F5S<'+A=F[I(&AE
M<VQO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@(D]MX6XB
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM
M<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R
M<RXB"FUS9W-T<B`B4V3M;&5NZ2!S;&^^:WD@:G-O=2!P;W-K>71O=N%N>2!P
M;W5Z92!)34%0('-E<G9E<GDN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(")0
M;W5Z92!N97-L=;ENZ2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW,0IM<V=I9"`B3VYL>2!O
M;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R(")*92!P;W9O;&5N
M82!P;W5Z92!J961N82!E+6UA:6QO=N$@861R97-A+B(*"B,Z('-E<G9I8V5S
M+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@
M;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@
M;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B
M(@HB4&]U>F4@=FQA<W1N[6L@;F5B;R!S>7-TZ6UO=OT@861M:6YI<W1RX71O
M<B!M^;YE(&WL;FET('!RX79A('!R;R!S9.UL96[]("(*(F]B:F5K="XB"@HC
M.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE
M=R!W:6YD;W<B"FUS9W-T<B`B3W1E=OCM="!V(&YO=NEM(&]K;NPN(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P
M96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N
M960@4R]-24U%('!A<G0N(@IM<V=S='(@(D-H>6)A($]P96Y34TPZ($YE;'IE
M('KM<VMA="!D871A('H@<&]D97!S86[I(.CA<W1I(%,O34E-12XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-34*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS
M9W-T<B`B3W1E=OCM="!T96YT;R!O9&MA>B!V(&YO=NEM(&]K;NPB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T
M96TB"FUS9W-T<B`B3W!E<F'H;NT@<WES=.EM(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")-
M;[YN;W-T:2(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS
M(&9O<B`E<R(*;7-G<W1R(")-;[YN;W-T:2!P<F\@)7,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E
M<F5D($QI<W0B"FUS9W-T<B`B4V7X87IE;OT@<V5Z;F%M(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D]R9V%N:7-A
M=&EO;B(*;7-G<W1R(")/<F=A;FEZ86-E(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N
M:70B"FUS9W-T<B`B3W)G86YI>F'H;NT@:F5D;F]T:V$B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3,R"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S
M='(@(D]R9V%N:7IO=N%N[2(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U
M"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R
M(")/<FEG:6[A;&[M('9Z;W(@<')O(+[A9&]S="(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E
M;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B3W)I9VENX6QN[2!V>F]R('8@)7,Z
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E
M<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(D]S=&%T
M;NTB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$S,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q"FUS9VED(")/=&AE
M<B!);F9O<FUA=&EO;B(*;7-G<W1R(")/<W1A=&[M(&EN9F]R;6%C92(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(E6^:79A=&5L<VOA('!RX79A(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N
M=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3W;L^&5N[2!P
M;VUO8^T@4$%-(&YE;NT@9&]S='5P;NDN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL
M(&)A8VME;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3(W,PIM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM
M<V=S='(@(E!'4"!D:6=I=.%L;NT@<&]D<&ES(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3,Q.0IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$
M871A(@IM<V=S='(@(E!'4""Y:69R;W9A;N$@9&%T82(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-S$*;7-G:60@(E!'4"!0=6)L:6,@
M2V5Y(@IM<V=S='(@(E9E^&5J;OT@4$=0(&ML[>@B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4S"FUS9VED(")01U`@4VEG;F5D+T5N
M8W)Y<'1E9"!$871A(@IM<V=S='(@(D1A=&$@<&]D97!S86[A+[EI9G)O=F%N
MX2!P;VUO8^T@4$=0(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"FUS9VED
M(")02%`@0V]D92(*;7-G<W1R(")02%`@:_-D(@H*(SH@861M:6XO<&AP<VAE
M;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B4$A0(&MO;GIO
M;&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M-PIM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R(")/9'!O;&5D;NT@;&5H
M:_T@9.FYNR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,X"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(D]D<&]L961N[2!P
M^&5HX?)K>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,Y"FUS9VED(")032!3;F]W(@IM<V=S='(@(D]D<&]L961N[2!S;NR^
M96[M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#`*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")/9'!O;&5D;NT@
M<V[L:&]VZ2!P^&5HX?)K>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0Q"B,L(&9U>GIY"FUS9VED(")032!3=6XB"FUS9W-T
M<B`B3V1P;VQE9&[M('-N[+YE;NTB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T
M<B`B3V1P;VQE9&[M(&)O=?AK>2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S
M='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L;"(*
M;7-G<W1R(")07TA0(&MO;GIO;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM
M<V=S='(@(D]D<W1U<'DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N
M(@IM<V=S='(@(E#A:VES=.%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L
M874B"FUS9W-T<B`B4&%L874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QE
M<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@(E!A;&5S=&EN
M<VOI('1E<FET;W)I=6TL(&]K=7!O=F%NZ2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I
M9"`B4&%N86UA(@IM<V=S='(@(E!A;F%M82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I
M9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R(")087!U82!.;W;A($=U:6YE
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(E!A
M<F%G=6%Y(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S8*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B3>US='D@>F%T
M8;YE;F\B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#(S"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")(97-L;R(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@
M8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,@IM<V=I9"`B4&%S<W=O<F0@
M:6YC;W)R96-T(@IM<V=S='(@(DYE<W!RX79NZ2!H97-L;R(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D
M(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(E!R;R!O=NSX96[M('!O;6]C[2!2041525,@:F4@;G5T;F\@>F%D870@:&5S
M;&\N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,PIM<V=I9"`B
M4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B2&5S;&\@<R!P
M;W1V<GIE;NUM(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP
M"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`B2&5S;&\Z(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS
M9W-T<B`B2&5S;&\Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*
M;7-G<W1R(")(97-L82!S92!M=7/M('-H;V1O=F%T+B(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R(")6;&^^
M:70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R(")6;&^^
M:70@>F4@<V-H<N%N:WDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@(D-E<W1A(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T
M97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I
M;F<@4VEG;G5P<SHB"FUS9W-T<B`BKN%D;W-T:2!O('#X:6ALX;EE;NTZ(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"FUS9VED(")096]P;&4B"FUS
M9W-T<B`B3&EDZ2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@(E!R;V-E;G0B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT
M.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S
M='(@(E!R;W;I<W0@;W!E<F%C92#Z9'*^8GDB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#`V"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(E!R;W;I<W0@;W!E<F%C92#Z9'*^
M8GD@</AI('#X:6ALX;EE;NT@9&\@<WES=.EM=3\B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G
M<W1R(")0<N%V82(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO
M="!D96QE=&5D+B(*;7-G<W1R(")0<N%V;R`G)7,G(&YE8GEL;R!S;6%ZX6YO
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@V"B,L(&9U>GIY
M"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R(")0<N%V82(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,38T"B,L(&9U>GIY"FUS9VED(")097)M:7-S
M:6]N<R(*;7-G<W1R(")?4'+A=F$B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H
M<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN+W!E
M<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"FUS
M9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI
M;FES=')AZ&[M('!RX79A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U
M"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R(")/<V]B;NT@
M:6YF;W)M86-E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U(@IM<V=S='(@
M(E!E<G4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(E!E
M=',B"FUS9W-T<B`B1&]MX6/M('IV[?AA=&$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G
M:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(D9I;&EP[6YY(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO
M;F4B"FUS9W-T<B`B5&5L969O;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT-S@*;7-G:60@(E!H;W1O<R(*;7-G<W1R(")&;W1O9W)A9FEE(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B4&ET8V%I
M<FXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(E!I>&5L^2(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R
M(")&<N%Z92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@
M8V5L;"(*;7-G<W1R(")0<F]S[6T@:VQI:V[L=&4@;F$@;NQJ86MO=2!B=?)K
M=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N
M="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R(")0<F]S[6T@<&]T
M=G+O=&4L(+YE('-I('#X96IE=&4@;V1S=')A;FET('1E;G1O('!R=F5K.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R(")0<F]S[6T@<&]T=G+O
M=&4L(+YE('-I('#X96IE=&4@;V1S=')A;FET('1E;G1O('!R=F5K+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U-S$*;7-G:60@(E!L96%S92!E
M;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(E!R;W/M;2!Z861E
M:G1E(&WL<^UC(&$@<F]K+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE
M(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R(")0<F]S[6T@>F%D96IT
M92!NX7IE=B!N;W;I(&MA=&5G;W)I93HB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,S`Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A
M9&1R97-S+B(*;7-G<W1R(")0<F]S[6T@>F%D96IT92!S<'+A=FYO=2!)4"!A
M9')E<W4N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C`*;7-G
M:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB
M97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(E!R;W/M;2!Z861E
M:G1E('-P<N%V;OT@9&%T=6T@82!Z:V]N=')O;'5J=&4@<&_H970@9&[M('8@
M;>QS[6-I+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-3$*;7-G
M:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(E!R;W/M
M;2!Z861E:G1E('-P<N%V;OT@Z&%S+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R
M>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`B4')O<^UM('5V9>]T92!S:')N
M=73M(%9AN65H;R!P<F]B;.EM=2XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@
M(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM
M<V=S='(@(E!R;W/M;2!Z861E:G1E(%9AN64@=;YI=F%T96QS:^D@:FWI;F\@
M82!H97-L;R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`HC+"!F
M=7IZ>0IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT
M+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*
M(G-Y<W1E;2XB"FUS9W-T<B`B(@HB4')O<^UM('#X9>AT['1E('-I(&[A<VQE
M9'5J[6/M('1E>'0N($U54\U412!S;W5H;&%S:70@<R!P;V1M[6YK86UI('!O
M=;[M=N%N[2`B"B)S>7-TZ6UU+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T
M:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(E!R;W/M;2!Z861E:G1E
M(&YO=OT@;N%Z978@:V%T96=O<FEE.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B
M4&]L86YD(@IM<V=S='(@(E!O;'-K;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B4&]L:71I:V$B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@W"FUS9VED(")0;VQL<R(*
M;7-G<W1R(")(;&%S;W;A;NTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T
M=6=A;"(*;7-G<W1R(")0;W)T=6=A;'-K;R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B
M4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R(")5;>US=.QN[2!T
M;VAO=&\@;V)RX7IK=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A
M8FQE(@IM<V=S='(@(E5M[7-T[&[M('1A8G5L:WDB"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T
M:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(EIA
M<VQA="!D;R!TZ71O('-L;[YK>2`H;F5N[2!P;W-K>71N=71O($E-05!E;2DB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O
M<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R(")3<N&^:WD@>F$@<&]S;&5D
M;NTH8V@I("5S(&AO9&EN*'4I.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,CDX"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H
M<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L9&%P.B!.96)Y;&$@;F%L
M97IE;F$@<&^^861O=F%NX2!P^.UP;VYA($Q$05`N(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S
M:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(E!R969S7W-E<W-I;VXZ($YE8GEL82!N86QE>F5N82!P;[YA9&]V
M86[A('#X[7!O;F$@<V5K8V4N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,C4*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(D)A<F]M971R:6-K_2!T;&%K
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G:60@(E!R97-S=7)E
M(&%T('-E82!L979E;#H@(@IM<V=S='(@(D)A<F]M971R:6-K_2!T;&%K(&YA
M(/IR;W9N:2!M;_AE.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C,U"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(D)A<F]M971R:6-K
M_2!T;&%K.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(D[A
M:&QE9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@
M82!N97<@=VEN9&]W(@IM<V=S='(@(D[A:&QE9"!O8G+A>FMU('8@;F]VZ6T@
M;VMN["(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8R(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V"FUS9VED(")0<F5V:6]U
M<R!O<'1I;VYS(@IM<V=S='(@(E#X961C:&]Z[2!M;[YN;W-T:2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@
M(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(E1I<VMN;W5T(&1O:W5M96YT(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0
M<FEV871E($ME>2(*;7-G<W1R(")0<FEVX71N[2!K;.WH(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*
M;7-G<W1R(")0<F]B;.EM(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(V
M"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(E!O<&ES('!R
M;V)LZ6UU(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,V.0IM<V=I
M9"`B4')O:F5C=',B"FUS9W-T<B`B4')O:F5K='DB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M.#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X-0IM<V=I9"`B4')O
M;7!T('1E>'0B"FUS9W-T<B`B4')O;7!T('1E>'0B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS
M9W-T<B`B5F7X96IN_2!K;.WH(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM
M<V=S='(@(D%L9V]R:71M=7,@<')O('9E^&5J;OT@:VSMZ"(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0T"B,L(&9U>GIY"FUS9VED
M(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B5F7X96IN_2!K;.WH(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L
M:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY
M+B(*;7-G<W1R(")69?AE:F[]+W!R:7;A=&[M(&ML[>AO=OT@<.%R(&YE8GEL
M(/IS<.RY;NP@=GET=F_X96XN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E
M<G1O(%)I8V\B"FUS9W-T<B`B4&]R=&]R:6MO(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM
M<V=I9"`B46%T87(B"FUS9W-T<B`B2V%T87(B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@(E9Y:&QE9.%N[2(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B475O
M=&$B"FUS9W-T<B`B2V%T87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC
M($ME>2`H)60@8FET*2(*;7-G<W1R(")24T$@=F7X96IN_2!K;.WH("@E9"!B
M:73Y*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0*;7-G:60@
M(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R(")3</AAOF5NZ2!T;&'H[71K;R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS
M9VED(")286EN(@IM<V=S='(@(D3IN;LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B!%87)L>2(*;7-G
M<W1R(")"<GIK_2!DZ;F[(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R(")0;WID
M;NT@9.FYNR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0V"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R(")$9;F[;W;I('#X
M96CA\FMY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#<*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B1.FYNR!S92!S
M;NQH96TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT.`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(D3IN;L@8;X@<V[M
M:"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@
M1F]R='5N92(*;7-G<W1R(").X6AO9&[L('9Y8G)A;ND@N73L<W3M(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2871I;R(*
M;7-G<W1R(")0;VWL<B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(LAT96/M(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E
M860@;65S<V%G97,B"FUS9W-T<B`B4/AEZ'1E;ND@>G!RX79Y(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N(@IM<V=S='(@(D]P<F%V9'4@<VUA>F%T("5S/R!4871O
M(&]P97)A8V4@:F4@;F5V<F%T;N$N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E
M;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A
M;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*(D]P<F%V9'4@<VUA>F%T('6^
M:79A=&5L<VOA(&1A=&$@<')O('6^:79A=&5L92`E<S\@5&%T;R!O<&5R86-E
M(&IE(&YE=G)A=&[A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N
M(@IM<V=S='(@(D]P86MO=F%T('!O<VQE9&[M(&%K8VDB"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM
M<V=I9"`B4F5F<F5S:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,SDQ"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT
M<SHB"FUS9W-T<B`B3V)N;W9I="!D>6YA;6EC:^D@<')V:WD@;65N=3HB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"FUS9VED(")2969R97-H(%!O
M<G1A;"!6:65W.B(*;7-G<W1R(")/8FYO=F$@>F]B<F%Z96[M('!O<G3A;'4Z
M("(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C$S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R,S4*;7-G:60@(E)E9V5X(@IM<V=S='(@(E)E9V5X(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S(T.0IM<V=I9"`B4F5L871I;VYS:&EP($)R
M;W=S97(B"FUS9W-T<B`B4')O:&SMOF7H('9Z=&%H^2(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR,#@*(RP@9G5Z>GD*;7-G:60@(E)E;&]A9"(*;7-G<W1R("+(=&5C
M[2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V"FUS9VED(")296UA<FMS
M(@IM<V=S='(@(DAO9&YO='DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3$T"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R(")6>F3A;&5NZ2!S
M97)V97)Y+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM
M<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D
M92DZ(@IM<V=S='(@(E9Z9.%L96[A(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE
M+F-O;2]H;W)D92DZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S"FUS
M9VED(")296UO=F4B"FUS9W-T<B`B3V1S=')A;FET(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@0FQO8VLB"FUS
M9W-T<B`B3V1S=')A;FET(&)L;VLB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-34W"FUS9VED(")296UO=F4@8V]L=6UN(@IM
M<V=S='(@(D]D<W1R86YI="!S;&]U<&5C(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`IM<V=I9"`B4F5M;W9E(&9O<FUA
M='1I;F<B"FUS9W-T<B`B3V1S=')A;FET(&9O<FWA=&]VX6[M(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER
M(@IM<V=S='(@(D]D<W1R86YI="!PX7(B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,C`R"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R
M=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B3V1S=')A=&ET
M('5L;[YE;OT@<VMR:7!T('H@9&_H87-NZ6AO(&%D<F5SX?AE(&YA('-E<G9E
M<G4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0R"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(D]D<W1R
M86YI="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H
M92!D;V-U;65N="(*;7-G<W1R(")/9'-T<F%N:70@='5T;R#HX7-T(&1O:W5M
M96YT=2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*
M;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(D]D<W1R86YI="!UOFEV871E
M;&4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(D]D
M<W1R86YI="!UOFEV871E;&4Z("5S(@H*(SH@9G)A;65W;W)K+U)00R]24$,O
M>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS
M=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(DYE;'IE(&]D
M<&]V[&3L="!N82!P;[YA9&%V96LN($-H>6)O=ND@:&SAN65N[3H@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PHC+"!F=7IZ>0IM<V=I
M9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G
M<W1R(")0^&5N97-E;OT@<V]U8F]R(&YE;'IE('5L;[YI="XB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-"!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C4Q,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER
M960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B4&^^861O=F%NZ2`G)7,G(&YE8GEL;R!U=F5D96YO('8@:V]N
M9FEG=7)A8VD@<')O("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z-C<U(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,P"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C,*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN
M(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")0;[YA9&]V86[I("<E<R<@
M;F5B>6QO('5V961E;F\@=B!K;VYF:6=U<F%C:2!P<F\@5D93+B(*"B,Z(&9R
M86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<X,0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B4&^^861O=F%NZ2`G)7,G(&YE8GEL;R!U
M=F5D96YO('8@:V]N9FEG=7)A8VDN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2]296YD97)E<BYP:'`Z,S,U"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G
M<W1R(")0;[YA9&]V86[I('!O;&4B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SD*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2]296YD97)E<BYP:'`Z,S(P('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW
M-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B5OUC:&]Z[2!N87-T879E;NTB"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B4F5S970@
M4&%S<W=O<F0B"FUS9W-T<B`B5OUC:&]Z[2!N87-T879E;NT@:&5S;&$B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@
M66]U<B!087-S=V]R9"(*;7-G<W1R(")6_6-H;WKM(&YA<W1A=F5N[2!68;EE
M:&\@:&5S;&$B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"B,L(&9U>GIY
M"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T<B`B4&]S;&5D;NT@
MZ'1V<G1I;F$B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD
M<VAE;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@IM<V=I9"`B4F5S
M=6QT<R(*;7-G<W1R(")6_7-L961K>2(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I
M9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B3N%V<F%T(&1O(&UOOFYO
M<W3M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"B,L(&9U
M>GIY"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(E;]8VAO
M>NT@;F%S=&%V96[M(&AE<VQA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U
M;FEO;B(*;7-G<W1R(")2975N:6]N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E
M<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")0^&5P;F]U="!K;VYF:6=U<F%C
M:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S(*;7-G:60@(E)I8V@@
M5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R(")-;[YN;W-T:2!2:6-H(%1E
M>'0@961I=&]R=2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I
M9"`B4FED9&QE<R(*;7-G<W1R(")(X61A;FMY(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P"FUS9VED(")2:6=H
M="(*;7-G<W1R(")$;W!R879A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S$R,0IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(DAL879IZ&MA
M(&YA<')A=F\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$W"FUS
M9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`B2&]D;F]T>2!N87!R879O(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B5FQA
M<W1N;W-T:2#XX5]D:W4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(MIL;VAA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R(")2=6UU;G-K
M;R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,C4*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B3W1OZ&ET(&\@,3@PL"(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C(*
M;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(D]T;^AI="!D;VQE=F$B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(X"FUS
M9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B3W1OZ&ET(&1O<')A=F$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R(")6;&%S=&YO<W1I
M(/CA9&MU(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B
M5FQA<W1N;W-T:2#XX61K=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R("+8X61K
M>3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R(")0<F%V:61L82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@
M86YD(&-O;'5M;G,B"FUS9W-T<B`B4')A=FED;&$@<V4@=7!L871N[2!M97II
M(':Y96UI(/CA9&MY(&$@<VQO=7!C:2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I
M;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(E!R879I
M9&QA('-E('5P;&%T;NT@<&]U>F4@;65Z:2!S;&]U<&-I(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I
M9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T
M<B`B4')A=FED;&$@<V4@=7!L871N[2!P;W5Z92!M97II(/CA9&MY(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$R,`IM<V=I9"`B4G5N(@IM<V=S='(@(E!R
M;W;I<W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I
M;VXB"FUS9W-T<B`B4G5S:^$@9F5D97)A8V4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS
M9VED(")2=V%N9&$B"FUS9W-T<B`B4G=A;F1A(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G
M<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R(")3+TU)344@N6EF<F]V86[]('!O
M9'!I<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S
M"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B4R]-
M24U%(+EI9G)O=F%NX2!Z<'+A=F$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-A<VPN<&AP.C@Q"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(D]V[/AE;NT@<&]M;V/M(%-!4TP@;F5N
M[2!D;W-T=7!NZ2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`T
M"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@(E--4R!Z<'+A=GDB"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G
M<W1R(")344P@:V]N>F]L82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,R.#,*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,0IM
M<V=I9"`B4U-((@IM<V=S='(@(E-32"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G
M:60@(E-50T-%4U,B"FUS9W-T<B`BVE-0S$-((@H*(SH@;&EB+V%P:2YP:'`Z
M,34S"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(E-?44P@:V]N>F]L82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*
M;7-G:60@(E-A(@IM<V=S='(@(E-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B
M4V%I;G0@2&5L96YA(@IM<V=S='(@(E-V873A($AE;&5N82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(E-V
M873]($MI='1S(&$@3F5V:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT
M($QU8VEA(@IM<V=S='(@(E-A:6YT($QU8VEA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM
M<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R(")386EN
M="!0:65R<F4@86YD($UI<75E;&]N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B
M4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B4V%I
M;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R
M86UE("A?<V5L9BDB"FUS9W-T<B`B4W1E:F[]('+A;2`H7W-E;&8I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B4V%M;V$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(E-A;B!-87)I
M;F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I
M<&4B"FUS9W-T<B`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R
M;W9I9&5R(@IM<V=S='(@(E9L87-T;NUK('-A=&5L:71U(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(E-A=61S:^$@07+A
M8FEE(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDX"FUS9VED
M(")3879E(@IM<V=S='(@(E5L;[YI="(*"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O961I="YI;F,Z-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E-A=F4@7"(E<UPB(@IM<V=S='(@(E5L;[YI="`E<R(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,C$V"B,L('!H<"UF;W)M870*;7-G:60@(E-A
M=F4@)7,B"FUS9W-T<B`B56QOOFET("5S(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(E5L;[YE
M;NT@;6^^;F]S=.TB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS
M9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0
M('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O
M<GDN(@IM<V=S='(@(B(*(E5L;[YI="!V>71V;_AE;OT@:V]N9FEG=7)AZ&[M
M(%!(4"!S:W)I<'0@9&\@9&_H87-NZ6AO(&%D<F5SX?AE(&YA('-E<G9E<G4N
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2V]N
M9FEG=7)A8V4@)7,@=6QOOF5N82XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HY,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B2V]N9FEG
M=7)AZ&[M('-K<FEP="!P<F\@86MT=6%L:7IA8VD@8GEL('5L;[YE;B!D;SH@
M)R5S)RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT.0HC+"!F=7IZ>0IM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S
M='(@(D]J961I;NQLZ2!B;W7X:WDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B5NQD82(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B5GEH;&5D
M870B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(P"FUS9VED(")3
M96%R8V@@16YG:6YE<R(*;7-G<W1R(")6>6AL963A=F%C[2!NX7-T<F]J92(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-S,*;7-G:60@(E-E;&5C
M="!&:6QE<R(*;7-G<W1R(")6>6)R870@<V]U8F]R>2(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0*;7-G:60@(E-E;&5C
M="!A(&1A=&4B"FUS9W-T<B`B5GEB<F%T(&1A='5M(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O
M(&%D9"(*;7-G<W1R(")6>6)R870@<VMU<&EN=2P@:W1E<N$@8G5D92!P^&ED
MX6YA(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B
M4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(E9Y8G)A="!N;W;I:&\@=FQA
M<W1N[6MA(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS
M9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B5GEB<F%T('-E<G9E<B(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V"FUS9VED(")396QE
M8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R(")6>6)R870@=;YI=F%T96QE+"!K
M=&5R_2!B=61E('#X:63A;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HV-S<*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;&PB
M"FUS9W-T<B`B5GEB<F%T('-O=6)O<GDB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-C8S"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT
M<RXB"FUS9W-T<B`B5GEB<F%T(':Y96-H;GD@Z.%S=&D@9&%T=6UU+B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G
M:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B5GEB<F%T(&]B:F5K="(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S@*
M(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(E9Y8G)A="!N
M;W;I:&\@=FQA<W1N[6MA(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W
M"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O
M;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P
M87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@HB5GEB
M97)T92!P;W3X96)NZ2!Z;F%K>2!Z(&[MOF4@=79E9&5N_6-H(&)O>/DN(%!O
M=.D@:F4@;?F^971E(&MO<.UR;W9A="!A("(*(G9L;[YI="!Z('1E>'1O=ND@
M;V)L87-T:2XB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I
M9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B5GEB97)T
M92!O9&3L;&]V86/M('IN86L@<')O(&1A='5M.B(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T
M.B(*;7-G<W1R(")6>6)E<G1E(&9O<FWA="!D871U;74Z(@H*(SH@=&5M<&QA
M=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T
M('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(E9Y
M8F5R=&4@:61E;G1I='4L(&MT97)O=2!S:2!P^&5J971E('IM[&YI=#HB"@HC
M.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H
M92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B5GEB97)T92!O9&3L;&]V86/M
M('IN86L@<')O(.AA<SHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR
M-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B5GEB
M97)T92!F;W)MX70@Z&%S=3HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS
M9W-T<B`B5GEB97)T92!D=NP@;V1P;W;M9&%J[6/M('!O;&4N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,P-@IM<V=I9"`B4V5L96-T('EO=7(@8V]L
M;W(@<V-H96UE+B(*;7-G<W1R(")6>6)E<G1E(&)A<F5V;OT@;6]T:78N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T.`IM<V=I9"`B4V5L96-T('EO
M=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R(")6>6)E<G1E(%;A;6D@
M<')E9F5R;W9A;OT@:F%Z>6LZ(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T
M<B`B4&]S;&%T('IP<N%V=2!O('!R;V)LZ6UU(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,SD*;7-G:60@(E-E;F0@4TU3
M(@IM<V=S='(@(E!O<VQA="!335,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3
M96YE9V%L(@IM<V=S='(@(E-E;F5G86PB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,Q-@IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B4V5N<V]R.B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED
M(")397!T96UB97(B"FUS9W-T<B`B6N'X[2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E
M;F5G<F\B"FUS9W-T<B`B4W)B<VMO(&$@R&5R;N$@2&]R82(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED(")397)I86P@
M3G5M8F5R(@IM<V=S='(@(E/I<FEO=ND@Z.US;&\B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"B,L(&9U>GIY"FUS9VED(")397)V97(@
M9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")";&]K(&\@
M<&_H87/M(&YE;NT@9&]S='5P;OTN(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C(W"B,L(&9U>GIY"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(D%D
M;6EN:7-T<F'H;NT@<'+A=F$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP
M:7)E9"XB"FUS9W-T<B`B240@<V5K8V4@>F%N:6ML;RXB"@HC.B!L:6(O87!I
M+G!H<#HQ-#4*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@(E]0
M<N%V82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,30*;7-G:60@
M(E-E="(*;7-G<W1R(").87-T879I="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW-@IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E
M<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G
M<W1R(").87-T879I="!M;[YN;W-T:2!P<F\@<&]V;VQE;NT@<F5S971U(&AE
M<VQA+"!P;VMU9"!H;R!Z87!O;65N971E+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,34*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T
M('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R
M(").87-T879I="!V>F3A;&5NZ2!S97)V97)Y('1A:RP@OF4@8G5D;W4@</CM
M<W1U<&[I('H@<&]R=.%L=2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#0*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO
M;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B3F%S=&%V96[M(%;A;6D@
M<')E9F5R;W9A;NEH;R!J87IY:V$L(.AA<V]VZ6AO('#A<VUA(&$@='EP=2!D
M871U;74N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX"FUS9VED("(B
M"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L
M('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N
M<RXB"FUS9W-T<B`B(@HB3F%S=&%V96[M('!OZ.%T9>AN[2!A<&QI:V%C92P@
M8F%R979NZ6AO(&UO=&EV=2P@;V)N;W9O=N%N[2!S='+A;F5K(&$@9&%LN>UC
M:"`B"B)M;[YN;W-T[2!Z;V)R87IE;NTN(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HW-0IM<V=I9"`B4V5T=7`B"FUS9W-T<B`B3F%S=&%V96[M(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@
M(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B3F%S
M=&%V;W9A8^T@:V]N9FEG=7)AZ&[M('-K<FEP='D@<')O(&%K='5A;&EZ86-I
M(&IS;W4@9&]S='5P;NDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3@V"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H
M('1H92!P87)A;65T97(Z("(*;7-G<W1R(").[&MT97+A(&WM<W1A(&QZ92!N
M87-T879I="!S('3M;71O('!A<F%M971R96TZ("(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*
M;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B4V5Y8VAE;&QE<R(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.38*;7-G:60@(E-H;W!P:6YG(@IM
M<V=S='(@(DYA:W5P;W;A;NTB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHT,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R(")+<N%T
M:^D@<VAR;G5T[2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#8*;7-G
M:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI
M;FMS/R(*;7-G<W1R(")-[&QY(&)Y(&+]="!P^.US='5P;W;I(&ML[>AE(&1E
M9FEN;W;A;GD@<')O(';L=+EI;G4@;V1K87KY/R(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@
M(EIO8G)A>FET(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I
M9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E
M9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("):;V)R87II="!R;WID[6QY(&UE>FD@<V]UZ&%S;F]U(&$@</AE
M9&-H;WKM(&MO;F9I9W5R86/M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT.3`*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN
M9R!I;C\B"FUS9W-T<B`B6F]B<F%Z:70@Z&%S('!O<VQE9&[M:&\@</AI:&SA
MN65N[2!D;R!S>7-TZ6UU/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$W-C4*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS
M9W-T<B`B6F]B<F%Z:70@;6^^;F]S="!U9'*^96[M(&]R:6=I;N%L=2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3,*;7-G:60@(E-H;W<@<&EC
M:V5R(@IM<V=S='(@(EIO8G)A>FET('-B[')AZ"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,C8*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M
M96YU(&)A<C\B"FUS9W-T<B`B6F]B<F%Z:70@;65N=2!O<&5R8>AN[2!L:;ET
M=2!P<F\@=&%B=6QK>3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE
M(&QE9G0_(@IM<V=S='(@(EIO8G)A>FET("5S(&UE;G4@;F%L979O/R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I
M86QO9R(*;7-G<W1R("):;V)R87II="!D:6%L;V<@<')O('9L87-T;F]S=&D@
M8G5N[&L@=B!T86)U;&OA8V@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A
M8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(EIO8G)A>FET(&1I86QO
M9R!V;&%S=&YO<W3M('1A8G5L96LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE
M(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("):;V)R87II
M="!D:6%L;V<@=FQA<W1N;W-T[2#XX61E:R!T86)U;&5K(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS
M9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R
M("):;V)R87II="!D:6%L;V<@=FQA<W1N;W-T[2!O8G+A>FOY(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,PIM<V=I9"`B4VAO=R!U<&QO860B
M"FUS9W-T<B`B6F]B<F%Z:70@</AE;F]S(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E-H;W=E<G,B"FUS9W-T
M<B`B4/AE:.'R:WDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU,0IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R(")"<GIK
MZ2!P^&5HX?)K>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4R"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B4&]Z9&[M
M('#X96CA\FMY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S
M='(@(E#X96CA\FMY('8@;VMO;.TB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HT.#`*;7-G:60@(E-H<FEN:R(*;7-G<W1R("):;65N
MN6ET(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-S<T
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C@S-@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY,C(@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C$P-#<@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z,3`X-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HQ,3$V(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q
M-#D*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS
M*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R("):;65NN6ET(&YE8F\@
M<&]S=6YO=70@9&\@<V]U<V5D;NUH;R!B;&]K=2CY*2P@>B!C97-T>2!P<G9N
M[6UU(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S
M='(@(E-I97)R82!,96]N92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HR-C4*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B4F5G:7-T<F]V
M870@<V4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q
M,@IM<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(E!O9'!I<R(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$Q"FUS9VED(")3:6=N871U
M<F4@06QG;W)I=&AM(@IM<V=S='(@(D%L9V]R:71M=7,@<')O('!O9'!I<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R(")3:6YG
M87!U<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@W(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.3,P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*;7-G:60@
M(E-I>F4B"FUS9W-T<B`B5F5L:6MO<W0B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N
M86YC92(*;7-G<W1R(")6>6YE8VAA="#Z9'*^8G4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U
M"FUS9VED(")3;&]V86MI82(*;7-G<W1R(")3;&]V96YS:V\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`U"FUS9VED(")3;&]V96YI82(*;7-G<W1R(")3;&]V:6YS:V\B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I
M9"`B4VYO=R(*;7-G<W1R(")3;NR^96[M(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<@4VAO=V5R(@IM
M<V=S='(@(E-N[&AO=N$@</AE:.'R:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM
M<V=S='(@(E-N[&AO=ND@</AE:.'R:WDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W97)S($5A
M<FQY(@IM<V=S='(@(E)A;F[M('-N[&AO=ND@</AE:.'R:WDB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO
M=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B4&]Z9&[M('-N[&AO=ND@</AE:.'R
M:WDB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`IM<V=I9"`B4VYO=R!D
M97!T:#H@(@IM<V=S='(@(E-N[&AO=N$@<&]K<OUV:V$Z(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W
M871E<CH@(@IM<V=S='(@(E9O9&[M(&5K=FEV86QE;G0@<')O('-N[6@Z("(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R
M("*I86QA;6]U;F]V>2!O<W1R;W9Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B
M4V]M86QI82(*;7-G<W1R(")3;VWA;'-K;R(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R(")0[7-N
M["!A(&+A<V[L(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR-@IM
M<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B4VWL<B!T^.UD
M[&[M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$X.0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B
M6F1R;VIO=N$@861R97-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@
M069R:6-A(@IM<V=S='(@(DIIOF[M($%F<FEK82(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM
M,RDB"FUS9W-T<B`B2FEH;V5V<F]P<VO]("A)4T\M.#@U.2TS*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A
M;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B4V]U=&@@1V5O<F=I82!A;F0@=&AE
M(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(
M96UI<W!H97)E(@IM<V=S='(@(DIIOF[M('!O;&]K;W5L92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3
M<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(E!R;W-T;W(@
M;65Z:2!S;W5S961N[6UI(&)U\FMA;6DB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E
M;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R(")0<F]S=&]R
M(&UE>FD@;V)S86AE;2!A(&AR86YI8V5M:2!V(&)U\F-E(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.#$U"FUS9VED(")3<&%C97(B"FUS9W-T<B`B
M365Z97)N[6LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B365Z97)Y
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R(")/
M9'-T=7!Y(&$@;65Z97)Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM
M<V=S='(@(JEP86[L;'-K;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HY.`IM<V=I9"`B4W!A;2(*;7-G<W1R(")3<&%M(@H*(SH@<V5R=FEC97,O
M:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U
M="(*;7-G<W1R(")6<W1U<"!P<F\@>G9LX;ET;NT@>FYA:WDB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8R"FUS
M9VED(")3<&QI="!C96QL(@IM<V=S='(@(E)O>F3L;&ET(&)U\FMU(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(E)O>F3L;&ET('-L;W5P
M96,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B4F]Z9.QL:70@
M^.%D96LB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E-P
M;W)T<R(*;7-G<W1R(")3<&]R="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I
M($QA;FMA(@IM<V=S='(@(E-R:2!,86YK82(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP.C<T"FUS9VED
M(")3=&%N9&%R9"(*;7-G<W1R(")3=&%N9&%R9"(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(E-T87(@
M5')E:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.38@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@P.0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G
M<W1R(")2;VL@>F'HX71K=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3<P"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R
M(")3=.%T(.AI('!R;W9I;F-I92(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B4W1A=B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*;7-G:60@(E-T;W)A
M9V4@9F]R;6%T(@IM<V=S='(@(D9O<FWA="!U;&^^96[M(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(*;7-G:60@(E-T<F5E="!!
M9&1R97-S(@IM<V=S='(@(E5L:6-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*
M;7-G<W1R(")0^&6Y:W)T;G5T_2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,S,*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(E-E>FYA;2#X
M973L>F-E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,PIM<V=I
M9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B3V1S
M=')A;FET(&1O;>EN;W;I(&IMZ6YO('H@861R97-Y(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B
M4W1Y;&4@6T-34UTB"FUS9W-T<B`B4W1Y;"!;0U-372(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM
M<V=S='(@(DYE(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B4&]D861R97/A^"`G)7,G(&YE8GEL(&YA;&5Z
M96XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R(")0^&5D;>QT(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R(&9R86UE=V]R:R]&;W)M+T9O<FTO
M4F5N9&5R97(N<&AP.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@(E!O9&%T
M(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@
M<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U
M97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B"B)">6QA('!O9.%N
M82"^X61O<W0@;R!P^&EDX6[M("<E<R<@9&\@<WES=.EM=2X@0G5D971E('-E
M(&UO8VD@</AI:&SA<VET(&&^('!O("(*(FML861NZ6T@=GGX[7IE;NT@5F&Y
M[2"^X61O<W1I+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R(")$;VQN[2!I
M;F1E>"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#0*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H
M<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R("+:<W#LN6[L(@H*(SH@861M
M:6XO=7-E<BYP:'`Z.#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T
M<B`B)R5S)R!B>6PH82D@^G-P[+EN["!P^&EDX6XH82D@9&\@<WES=.EM=2XB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E
M<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B1&%T82!P<F\@=;YI=F%T
M96QE("5S(&)Y;&$@^G-P[+EN["!O9'-T<F%N[&YA('IE('-Y<W3I;74N(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M9&5L971E9"!<(B5S7"(N(@IM<V=S='(@(MIS<.RY;NP@;V1S=')A;NQN82`G
M)7,G+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@
M=&AE('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R#Z<W#LN6[L(&]D<W1R86[L;BAA
M*2!Z92!S>7-TZ6UU+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*
M;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!2
M96QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(DMO;F9I9W5R86-E(&)Y
M;&$@^G-P[+EN["!Z;>QN[&YA+B!/8FYO=G1E('-T<N%N:W4N(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C4W"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(MIS<.RY;ND@=6QOOF5N[2!ZX6QOOF[M(&MO;F9I
M9W5R86-E+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("+:<W#LN6[I('5L;[YE
M;NT@>N%L;VAY(&MO;F9I9W5R8>AN[6AO('-O=6)O<G4@)7,N(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,38X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`BVG-P[+ENX2!A
M:W1U86QI>F%C92!P<F\@)R5S)R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R("(E<R!B>6QO
M(/IS<.RY;NP@>F%P<^%N;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N
M(@IM<V=S='(@(E-U9.%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R
M(")3:')N=73M(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED
M(")3=6X@4FES92(*;7-G<W1R(")3=NUTX6[M(@H*(SH@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(EKA<&%D(%-L
M=6YC92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4Y"FUS9VED(")3=6YN>2(*;7-G<W1R(")3;'5N9>AN;R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(E-U;G)I<V4B"FUS
M9W-T<B`B5OUC:&]D(%-L=6YC92(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3
M=6YS970B"FUS9W-T<B`B5OUC:&]D+WKA<&%D(%-L=6YC92(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,34*;7-G:60@(E-U;G)I<V4Z("(*
M;7-G<W1R(")6_6-H;V0@4VQU;F-E.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C$Y"FUS9VED(")3=6YS970B"FUS9W-T<B`B6N%P860@
M4VQU;F-E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.`IM
M<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B6N%P860@4VQU;F-E.B`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED
M(")3=7!E<G-C<FEP="(*;7-G<W1R(")(;W)N[2!I;F1E>"(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS-S@*;7-G:60@(E-U<'!O<G0B"FUS9W-T
M<B`B4&]D<&]R82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM
M<V=S='(@(E-U<FEN86UE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S0*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`B4/CM:FUE;NTB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N
M(@IM<V=S='(@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B4W=A>FEL<VMO(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(JEVZ61S:V\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`BJ7;]8V%R
M<VMO(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*(RP@9G5Z
M>GD*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`B3F5S;6%Z870B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30R"FUS9VED(")3>6YC34PB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP
M.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S
M='(@(E-Y;G1A>&]VX2!C:'EB82!V(&AL961A;NEM('1E>'1U(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B
M4_UR:64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV,`IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R(")";W7X:V$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B5"U3
M=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FUS(@IM<V=S
M='(@(D)O=?AK>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G
M<W1R(")"<GIKZ2!P^&5HX?)K>2(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O
M='-V+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(E135B!S;W5B
M;W(B"@HC.B!F<F%M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S-`IM<V=I9"`B
M5&%B;&4B"FUS9W-T<B`B5&%B=6QK82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R
M;W!E<G1I97,B"FUS9W-T<B`B5FQA<W1N;W-T:2!T86)U;&MY(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PHC+"!F=7IZ
M>0IM<V=I9"`B5&%B;&4@4V5T(@IM<V=S='(@(E1A8G5L:V$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS
M9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@(E9L87-T;F]S=&D@=&%B
M=6QK>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A;B(*;7-G
M<W1R(")486EW86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G
M<W1R(")486EW86XL('!R;W9I;F-I92#([6YY(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM
M<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R(")4862^:6MI<W3A;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B5&%N>N%N:64L(%-P;VIE;N$@<F5P=6)L:6MA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B
M5&%R9V5T.B(*;7-G<W1R(")#[6PZ(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD
M:7-T.CDY-B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@W"FUS9VED(")4
M87-K<R(*;7-G<W1R("+::V]L>2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3<S"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S
M='(@(E1E;&5F;VYN[2#H[7-L;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,CDP"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")497!L
M;W1A('IA('!O<VQE9&[M(&AO9&EN=3H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,30*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(E1E<&QO=&$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(S"FUS9VED(")4
M96UP97)A='5R93H@(@IM<V=S='(@(E1E<&QO=&$Z("(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8X
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB
M(&YO="!F;W5N9"XB"FUS9W-T<B`B5GIO<B`G)7,G(&YE8GEL(&YA;&5Z96XN
M(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E
M($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E9Z;W(@<')O(&%D;6EN:7-T<F%C
M:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S,S-@IM<V=I9"`B5&5X="(*;7-G<W1R(")497AT
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-0IM<V=I9"`B5&5X="!/
M;FQY(@IM<V=S='(@(E!O=7IE('1E>'0B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L
M:6=N(@IM<V=S='(@(EIA<F]V;N%N[2!T97AT=2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B
M"FUS9W-T<B`B5G)C:"!T97AT=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(LAT(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(E1H86D@*%1)4RTV
M,C`I(@IM<V=S='(@(E1H86IS:WD@*%1)4RTV,C`I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B5&AA:G-K;R(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B5&AA;FL@>6]U(&9O<B!U
M<VEN9R!T:&4@<WES=&5M+B(*;7-G<W1R(")$[&MU:F5M92!Z82!P;W6^[7;A
M;NT@<WES=.EM=2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R
M,`IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B4/CM<&]N82!P<F\@1E10(&YE;NT@9&]S='5P;N$N(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S
M(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("));G1E9W)AZ&[M(&%L9V]R
M:71M>2!V($AO<F1E+TMO;&%B(&YE<&]D<&]R=6KM(%PB)7-<(B(*"B,Z(&9R
M86UE=V]R:R].971?24U34"])35-0+T)O;VLN<&AP.C$R.3(*(RP@9G5Z>GD*
M;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N
M(@IM<V=S='(@(E#X96YE<V5N_2!S;W5B;W(@;F5L>F4@=6QOOFET+B(*"B,Z
M('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT
M96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G
M<W1R(").9?IS<.RY;ND@;F'H=&5N[2!T^.UD>2!-86EN=&5N86YC93HZ(@H*
M(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B
M5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S
M='(@(D)Y;&\@=7IA=OAE;F\@;VMN;R!S(&UOOFYO<W1M:2X@56MO;NAE;F\N
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C0@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A
M9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!0
M97)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M
M:7-S:6]N<RXB"FUS9W-T<B`B(@HB061M:6YI<W1R[71O<B!P;W3X96)U:F4@
M;F%K;VYF:6=U<F]V870@=')V86SA('!RX79A('8@<WES=.EM=2P@<&]K=60@
M<VD@(@HB</AE:F5T92!P;W6^[70@<'+A=F$N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE
M(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B4&]U>F4@<W!O9&[M('-T<F%N
M82(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO
M="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T
M:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*(DYE8GEL;R!U=F5D96YO($E$
M('!R;R!K;VYT86MT+"!N96)Y;&\@;F%L97IE;F\@=B!D871A8N%Z:2!N96)O
M(&)Y;&\@^G!L;NP@(@HB=GEN96-HX6YO+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@
M=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB
M"FUS9W-T<B`B2V]N=&%K="!B>6P@^G-P[+EN["!P^&EDX6X@9&\@5F&Y96AO
M(&%D<F5SX?AE+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$Q-CD*;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L
M;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N
M(@IM<V=S='(@(DL@;W;L^&5N[2!P;V1E<'-A;ND@>G!RX79Y(&IE('3X96)A
M(&]D9.QL96[](&)L;VL@<R!01U`@<&]D<&ES96TN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*
M(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C
M:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A
M8F%S92XB"FUS9W-T<B`B(@HB3F5B>6QO('5V961E;F\@240@9&ES=')I8G7H
M;NUH;R!S97IN86UU+"!N96)Y;&\@;F%L97IE;F\@=B!D871A8N%Z:2!N96)O
M("(*(F)Y;&\@^G!L;NP@=GEN96-HX6YO+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES
M=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(DYE
M8GEL('5V961E;B!D:7-T<FEB=>AN[2!S97IN86TN(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+G!H<#HQ,3,*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E
M871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S
M='(@(B(*(JEI9G)O=F%C[2!M;[YN;W-T:2!L>F4@=GEUONUT('!O=7IE('#X
M:2!B97IP9>ANZ6T@<W!O:F5N[2!S('=E8F5M("AH='1P<RDN(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S4@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HU,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@
M<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R(")3;W5B;W(@
M)7,@8GD@;>QL(&]B<V%H;W9A="!N87-T879E;NT@)7,N(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C@@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO
M=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B4V]U8F]R
M("5S(&)Y(&WL;"!O8G-A:&]V870@;NQK=&5RX2!Z(&YA<W1A=F5N[2`E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,3D*;7-G:60@(E1H
M92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R
M(")3;W5B;W(@;F5L>F4@:V]P[7)O=F%T('/A;2!D;R!S96)E+B(*"B,Z(&9R
M86UE=V]R:R]$871A+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N
M=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(E-O=6)O<B!N96]B<V%H=6IE(+[A
M9&[A(&1A=&$N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E
M<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B
M3N%S;&5D=6KM(&AL879IZ&MY('!R;R!M97-S86=E+W)F8S@R,B!Z<'+A=G4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V
M"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C
M875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB
M=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA
M<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L
M87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R
M;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@
M.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A
M;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN
M7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@
M:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET
M;W(N(@IM<V=S='(@(B(*(DIE('INX6WI+""^92!M\V0@</AE<R!C96QO=2!O
M8G)A>F]V:W4@=B!);G1E<FYE="!%>'!L;W)E<G4@</ES;V+M('!R;V)LZ6UY
M+"`B"B)P<F]T;[YE('-E('8@;NQM('9Y<VMY='5J92!C:'EB82P@:W1E<ND@
M<V4@;F5L>F4@=GEH;F]U="X@2F%K;R!NX7-L961E:R!M^;YE("(*(F+]="!N
MX6AO9&[I('IH<F]U8V5N[2!T;VAO=&\@<')O9W)A;74L(&-H>6+L:NUC[2!F
M=6YK8V4@961I=&]R=2!N96)O("(*(FYE<W!RX79NZ2!Z;V)R87IO=N%N[2X@
M4&]K=60@:F4@5N&Y('-Y<W1E;>EM(%=I;F]D=W,@.7@L(&IE('9E;&UI("(*
M(G!R879D['!O9&]B;NDL(+YE('-E(&]B:F5V[2!C:'EB;W;I(&ALX;EE;NT@
M)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@82`B"B)B=61E=&4@;75S970@
M<F5S=&%R=&]V870@<&_H[71AZ"Y<7&Y<7&Y">6QI(&IS=&4@=F%R;W;A;FDN
M(%!R;W/M;2!S=&ES:V[L=&4@(@HB3TL@<&]K=60@<VD@</AE:F5T92!P;VMR
M8>AO=F%T('8@;?-D=2!P^&5S(&-E;&]U(&]B<F%Z;W9K=2XB"@HC.B!S97)V
M:6-E<R]P<F5F<RYP:'`Z.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED
M96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("))9&5N
M=&ET82!<(B5S7"(@8GEL82!S;6%ZX6YA+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L
M969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(E!O=7IE(&YA(&QE=ND@<W1R
M86[L(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS
M9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T
M(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B
M56WM<W3L;NT@8FENX7)N[6AO('-O=6)O<G4@1VYU4$<@;75S[2!B_70@>F%D
MX6YO(&1O('3X[61Y($-R>7!T7W!G<#HZ+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O341.+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB
M(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E
M('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D
M+B(*;7-G<W1R("(B"B):<'+A=F$@>F%S;&%NX2!V("5S(&L@)7,@<R!P^&5D
M;>QT96T@7"(E<UPB(&)Y;&$@>F]B<F%Z96YA+EQN(@HB5&]T;R!N97IA<G7H
M=6IE+""^92!Z<'+A=F$@8GEL82!P^&7H=&5N82!N96)O(+YE(&KM(&%D<F5S
MX70H:V$I(')O>G5M[&PH82DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@W-PIM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T
M;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(D[A>F5V+"!K=&5R_2!B=61E
M('!O=;YI="!P^&D@;V1K87IO=N%N[2!N82!S='+A;F-E('1V;W)B>2!Z<'+A
M=B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T,0HC+"!F=7IZ
M>0IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC
M+B(*;7-G<W1R(")4;W1O('!O;&4@;75S[2!B_70@<&QA=&[I(.CM<VQO+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,0IM<V=I
M9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R
M9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B5/CM9&$@2&]R9&5?
M0W)Y<'1?<VUI;64Z.B!V>;YA9'5J92!M;V1U;"!O<&5N<W-L+B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V
M960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A
M;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"B).96QZ92!U;&^^:70@;F%S=&%V
M96[M(%PB)7-<(BP@<')O=&^^92!J96AO('9E;&EK;W-T('#X97/A:&QA('!O
M=F]L96[](&QI;6ET+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O96YS
M8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS
M<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E
M8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<W)C
M:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P
M<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N
M;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B3F5B>6QA(&YA;&5Z
M96YA(&%P;&EK86-E('!R;R#H=&5N[2!T;VAO=&\@='EP=2!D870@*"5S*2XB
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-30*;7-G:60@(E1H
M92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E
M<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T
M('-I9&5S(&]N;'DB"FUS9W-T<B`B4&]U>F4@;F$@<')A=ND@82!L97;I('-T
M<F%N["(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*
M;7-G<W1R(")0;W5Z92!N82!P<F%VZ2!S=')A;NPB"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HT-#8*;7-G:60@(E1H92!S97!A<F%T;W(@;75S
M="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T
M<B`B4V5R=F5R(%PB)7-<(B!B>6P@=GEM87KA;BXB"@HC.B!S97)V:6-E<R]P
M;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B4V5R=F5R
M(%PB)7-<(B!B>6P@=6QOOF5N+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S
M(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(D)Y;&$@;V1S=')A;NQN82"^
MX61O<W0@;R!P^&EH;.&Y96[M('!R;R`E<RXB"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S<&5C:69I960@
M<F]W(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")0;[YA9&]V86[](/CA9&5K
M(&YE97AI<W1U:F4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ
M-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB
M)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B1&_H87-N_2!S;W5B;W(@
M7"(E<UPB(&YE97AI<W1U:F4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S,Q,0IM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M
M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y
M"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R
M(")0;W5Z92!N86AO^&4@82!D;VQE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S
M:61E(&]N;'DB"FUS9W-T<B`B4&]U>F4@;F%H;_AE(@H*(SH@9G)A;65W;W)K
M+T1A=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W
M87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B6G1R
M871I;&$@<V4@</AE;F5S96[A(&1A=&$@>B!P^&5D8VAO>NUH;R!K<F]K=2XB
M"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R
M:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F
M:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B4/AE;F5S96[]('-O
M=6)O<B!N96QZ92!U;&^^:70N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C0V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$U(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ,3D*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C
M:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")";&]K('=E871H97(N8V]M
M(&YE;NT@9&]S='5P;OTN(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y
M(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DYE8GEL(&YA;&5Z96X@861R
M97/A^"!S('3I;6%T>2`G)7,G+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,3<X"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I
M;&%B;&4N(@IM<V=S='(@(J[A9&[I('H@;6^^;F]S=.T@;F5J<V]U(&1O<W1U
M<&[I+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T
M,@IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L
M87EE9"!I;FQI;F4N(@IM<V=S='(@(DYE8GEL>2!N86QE>F5N>2"^X61NZ2#H
MX7-T:2P@:W1E<ND@8GD@8GEL;R!M;[YN;R!Z;V)R87II="!V(/CA9&MU+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@
M=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B
M"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*(E#X
M[6QIN2!M;F]H;R!Z;F%K^2!V('!O;&DN(%IA9&%L:2!J<W1E("5S('IN86OY
M.R!M=7/M=&4@>F%D870@;>EN["!N9;X@)7,@(@HB>FYA:_DN(@H*(SH@<VEG
M;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB
M('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@</AI
M('#X:63A=N%N[2`G)7,G(&1O('-Y<W3I;74Z("5S(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@</AI(&]D
M<W1R8?)O=N%N[2!UOFEV871E;'-K_6-H(&1A="`G)7,G('IE('-Y<W3I;74Z
M("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@
M9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P^&D@
M;V1S=')A\F]VX6[M("<E<R<@>F4@<WES=.EM=3H@(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,34Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B3F%S
M=&%L82!C:'EB82!P^&D@86MT=6%L:7IA8VD@)R5S)SH@)7,B"@HC.B!F<F%M
M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R(").87-T86QA(&-H>6)A
M('#X:2!P^&5N;W-U('-O=6)O<G4Z("5S(&YE8GEL('#X96YE<V5N+B(*"B,Z
M(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I
M;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M
M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"B).87-T
M86QA(&-H>6)A('#X:2!P^&5N;W-U('-O=6)O<G4N("5S(&YE;?F^92!B_70@
M=NQTN>T@;F6^(&UA>&EMX6QN[2`B"B)P;W9O;&5NX2!V96QI:V]S="`H)60@
M8GET^2DN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DQ
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L
M;'D@=7!L;V%D960N(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@</AI('#X96YO
M<W4@<V]U8F]R=3H@8GEL82!P^&5N97-E;F$@:F5N(.CA<W0@<V]U8F]R=2`E
M<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES
M(&UE<W-A9V4@<&%R="(*;7-G<W1R(")$;[EL;R!K(&-H>6+L('#X:2!Z;V)R
M87IO=N%N[2!TZ71O(.CA<W1I('IP<N%V>2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B3F%S
M=&%L82!C:'EB82!P^&D@:6UP;W)T;W;A;NT@:V]N=&%K='4N(@H*(SH@9G)A
M;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T
M<B`B4/AI(&EM<&]R=&]VX6[M(&E#86QE;F1A<B!D870@9&^Y;&\@:R!C:'EB
M["XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@P"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@
M4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS
M9W-T<B`B(@HB0VAY8F$@=B!K;VYF:6=U<F'H;NUM(&9O<FUU;.'X:2X@6OAE
M:FWL(&IS=&4@=GEN96-H86QI('!OOF%D;W9A;ND@<&]L92XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I
M9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A
M:6X@;&%T97(N(@IM<V=S='(@(B(*(DYA<W1A;&$@8VAY8F$@</AI('!R;W;A
M9.QN[2!Z861A;ND@;W!E<F%C92!V(&%D<F5SX?AI+B!0<F]S[6T@>FMU<W1E
M('1O("(*(G!O>F3L:FDN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E
M<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y
M(&%G86EN(&QA=&5R+B(*;7-G<W1R(").87-T86QA(&-H>6)A('#X:2!A:W1U
M86QI>F%C:2!K;VYT86MT=2X@4')O<^UM('IK=7-T92!T;R!P;WID[&II+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R
M"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I
M<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G
M<W1R("(B"B).87-T86QA(&-H>6)A('#X:2!A:W1U86QI>F%C:2!D:7-T<FEB
M=>AN[6AO('-E>FYA;74N(%!R;W/M;2!Z:W5S=&4@=&\@(@HB<&]Z9.QJ:2XB
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*
M;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R
M:6YG(&9O;&1E<G,N(@IM<V=S='(@(E1E;G1O($E-05`@<V5R=F5R(&YE<&]D
M<&]R=6IE('-D[6QE;NT@<VQOOF5K+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P
M96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(E1O=&\@
M;F5V>7!A9.$@:F%K;R!P;&%T;OT@<F%R(&%R8VAI=BXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R
M(")4;W1O(&YE=GEP863A(&IA:V\@<&QA=&[]('II<"!S;W5B;W(N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$T-0IM<V=I9"`B5&AI<R!D;V5S
M(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@
M(E1O=&\@;F5V>7!A9.$@:F%K;R!P;&%T;ND@Z.US;&\@:V%R='DN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA
M=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R
M("(B"B)496YT;R!O=FQA9&'H('5M;[[R=6IE('!O<^ULX6[M('IP<N%V('!O
M;6]C[2!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"XB"B)C;VTI(&)R
MX6YY('#X:2!P;W6^:73M($A45%`@05!)(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HQ,S0*(RP@9G5Z>GD*;7-G:60@(B(*(E1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@
M=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S:6YG
M('1H92!(5%10($%022(*;7-G<W1R("(B"B)496YT;R!O=FQA9&'H('5M;[[R
M=6IE('!O<^ULX6[M('IP<N%V('!O;6]C[2!S;7,R96UA:6P@*&AT='`Z+R]S
M;7,R96UA:6PN(@HB8V]M*2!B<N%N>2!P^&D@<&]UOFET[2!(5%10($%022(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R
M96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T
M<B`B(@HB5&5N=&\@;W9L861AZ"!U;6^^\G5J92!P;W/M;.%N[2!Z<'+A=B!P
M;VUO8^T@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+B(*(F-O;2D@8G+A
M;GD@</AI('!O=;YI=.T@2%144"!!4$DB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@
M=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T
M;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O
M=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET
M*2XB"FUS9W-T<B`B(@HB5&5N=&\@;W9L861AZ"!U;6^^\G5J92!P;W/M;.%N
M[2!Z<'+A=B!P;VUO8^T@4TU44"!D;R!6;V1A9F]N92!)=&%L>2!B<N%N>2`B
M"B)P;W5Z92!P<F\@Z.US;&$@<&]S:WET;G5TZ2!6;V1A9F]N96TN($UU<^UT
M92!M[70@96UA:6QO=OT@^NAE="!U(%9O9&%F;VYE("(*(DET86QY("AH='1P
M.B\O=W=W+C$Y,"YI="DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-3<*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#(@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.3@*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-3@@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-S@*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3`@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-C4W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,C@*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S-R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,S`V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,30@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R,@IM<V=I9"`B5&AI<R!F:65L
M9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B5&]T;R!P;VQE(&IE(&YU=&[I('9Y
M<&QN:70N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-0IM<V=I
M9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G
M<W1R(")4;W1O('!O;&4@;?F^92!O8G-A:&]V870@<&]U>F4@8V5LX2#H[7-L
M82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$X"FUS9VED(")4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O
M;&]N+B(*;7-G<W1R(")4;W1O('!O;&4@;?F^92!O8G-A:&]V870@<&]U>F4@
M8V5LX2#H[7-L82!A(&1V;VIT9>AK=2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,#DT"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R(")4;W1O('!O;&4@;?F^92!O8G-A
M:&]V870@<&]U>F4@;W-M:>AK;W;I(.CM<VQA+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A
M(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM
M<V=S='(@(E1O=&\@<&]L92!M=7/M(&+]="!S97IN86T@8V5L_6-H(.CM<V5L
M(&]D9.QL96[]8V@@Z.%R:V]U(&YE8F\@;65Z97)O=2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.CDX.0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E
M(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R(")4;W1O('!O;&4@;75S[2!B_70@
M<&QA=&[I(.CM<VQO+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,S8*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@
M8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C
M,3(S-&%F)RXB"FUS9W-T<B`B(@HB5&]T;R!P;VQE(&UU<^T@<&)S86AO=F%T
M(&)A<F5V;OT@:_-D('8@N65S=&[A8VMO=NEM(%)'0B!F;W)MX71U+"!N87#X
M+B`B"B(G(S$R,S1A9B<N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M-38Q"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S
M960N(@IM<V=S='(@(E1E;G1O(&9O<FUU;.'X(&IIOB!B>6P@>G!R86-O=N%N
M+B(*"B,Z('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(E1O=&\@:F4@)7,N(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N
M(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B
M"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E
M(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@
M<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*(E1O=&\@:F4@;V)J96MT($MO
M;&%B($=R;W5P=V%R=2X@2R!Z:&SI9&YU=.T@=&]H;W1O(&]B:F5K='4@:F4@
M>F%P;W3X96+M(&WM="`B"B)P;[ET;W9N[6AO(&ML:65N=&$L(&MT97+](')O
M>G5M[2!F;W)MX71U($MO;&%B($=R;W5P=V%R=2X@4')O('-E>FYA;2`B"B)T
M86MO=OUC:"!K;&EE;G3Y('!R;W/M;2!N87:Y=&EV=&4@)7,B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C
M=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(E1A
M=&\@>G!RX79A(&)Y;&$@;F%P<^%N82!V(&II;ND@>FYA:V]VZ2!S863L("@E
M<RD@;F6^(%9AN>TN("(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N
M92XB"FUS9W-T<B`B5&]T;R#H[7-L;R!M=7/M(&+]="!N96IMZ6[L(&IE9&YA
M+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HT
M-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD
M(&=Z:7`@9FEL97,N(@IM<V=S='(@(E-E<G9E<B!N96WYOF4@<F]Z8F%L:70@
M>FEP(&$@9WII<"!S;W5B;W)Y+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R
M96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(E1E;G1O('-Y<W3I;2!J92!V
M('-O=>AA<VYO<W1I(&1E86MT:79O=F%N_2XB"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E
M(&$@;G5M8F5R+B(*;7-G<W1R(")4871O(&AO9&YO=&$@;75S[2!B_70@Z.US
M;&\N(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM
M<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I
M;VYS('=I;F1O=R(*;7-G<W1R(")4;W1O(&]K;F\@;76^92!B_70@=F]LX6YO
M('!O=7IE('H@;VMN82!M;[YN;W-T[2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4:'5N9&5R(@IM<V=S='(@
M(DCX;>QN[2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S0*;7-G
M:60@(E1I8VME=',B"FUS9W-T<B`B3.US=&MY(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C0R."!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-34*;7-G:60@(E1I;64B"FUS9W-T<B`BR&%S(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,X-@IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R
M(")3;&5D;W;A;NT@Z&%S=2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM
M<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B1F]R;>%T(.AA<W4B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,Y"FUS9VED(")4:6UE('-E;&5C
M=&EO;B(*;7-G<W1R(")6_6+L<B#H87-U(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I
M9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B5&EM;W(M3&5S=&4B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R(")4:71U;"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*
M;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B5&ET=6P@*'1I<"DZ
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW
M-0IM<V=I9"`B5&\B"FUS9W-T<B`B2V]M=2(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C
M="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@
M;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S
M='(@(B(*(E!O:W5D('-I('#X96IE=&4@=GEB<F%T(';M8V4@<&]L;[YE:RP@
M>FWAZ&MN['1E(&MLX79E<W4@0V]N=')O;"`H4$,I(&YE8F\@(@HB0V]M;6%N
M9"`H36%C*2!A(&ML:6MN['1E(&YA('!O;&^^:W4N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B5&]D87DB"FUS9W-T<B`B
M1&YE<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R(")0^&5P
M;F]U="!N82!(5$U,('ID<F]J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G
M;R(*;7-G<W1R(")4;V=O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA
M=2(*;7-G<W1R(")4;VME;&%U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,Q,PIM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B6NUT<F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R(")4;VYG82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M-PIM<V=I9"`B5&]P(@IM<V=S='(@(E9R8V@B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@
M*%]T;W`I(@IM<V=S='(@(DAO<F[M('+A;2`H7W1O<"DB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R
M(")0^&5K;&%D>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N
M9"!4;V)A9V\B"FUS9W-T<B`B5')I;FED860@82!4;V)A9V\B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A;'-E
M(@IM<V=S='(@(E-P<N%V;NP@;F5B;R"Y<&%T;NPB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G
M<W1R("+:="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T
M<B`B5'5N:7-K;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G
M<W1R(")4=7)E8VMO(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G
M:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(E1U<F5C:WD@*$E3
M3RTX.#4Y+3DI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N
M(@IM<V=S='(@(E1U<FMM96YI<W3A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@
M(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R(")4=7)K<R!A($-A
M:6-O<R!O<W1R;W9Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM
M<V=S='(@(E1U=F%L=2(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-C0*
M;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R(").87!IN71E(%9A
MN6D@=F]L8G4Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V
M.0IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(E4N5BX@:6YD97@Z("(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")5
M4DPB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4T,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S
M=&%T=7,@<F5P;W)T(@IM<V=S='(@(E523"!P<F\@>G!RX79U(&\@<W1A=G4@
M>F%S;&%NZ6AO('-K<FEP='4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(E523#HB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`B56=A;F1A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G<W1R(")5:W)A
M:FEN82(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q,@IM<V=I
M9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")6
M1E,@861R97/A^"!J92!N97#X[7-T=7!N_2XB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT
M<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@
M(E#X:2!R96=I<W1R86-I(&YE;'IE('#X:61A="!E>'1R82!UOFEV871E;'-K
MZ2#Z9&%J92XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,X.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I
M;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F5L>F4@>FWL;FET
M('!RX79A('!R;R!61E,@<V]U8F]R(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HS.#4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E
M('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(").96QZ
M92!Z;>QN:70@<'+A=F$@<')O(%9&4R!S;W5B;W(@)7,O)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B3F5L>F4@>FWL
M;FET(&YA("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,R
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@
M9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`B3F5L>F4@</AE<W5N;W5T
M(%9&4R!S;W5B;W(@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C8X."!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O
M9B!<(B5S+R5S7"(N(@IM<V=S='(@(DYE;'IE('#X96IM96YO=F%T(%9&4R!S
M;W5B;W(@)7,O)7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP
M.C0S-0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB
M"FUS9W-T<B`B3F5L>F4@<V4@</AI<&]J:70@:R!344P@<V5R=F5R=2XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S.0IM<V=I9"`B56YA8FQE
M('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(DYE;'IE('-E('#X:7!O
M:FET('!O;6]C[2!34TPN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C(U(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S,`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C(P.0IM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N
M(@IM<V=S='(@(DYE;'IE(&MO<.UR;W9A="!61E,@<V]U8F]R+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S8U"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM
M<V=S='(@(DYE;'IE('9Y='9O^&ET(%9&4R!A9')E<^'X(%PB)7-<(BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-30@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,C4V"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(DYE;'IE('9Y='9O^&ET(%9&4R!A9')E<^'X+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@(E5N
M86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(DYE;'IE('9Y='9O
M^&ET(%9&4R!S;W5B;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HR.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(DYE;'IE('#X96IM
M96YO=F%T(%9&4R!S;W5B;W(@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(V-0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T
M>2!61E,@9FEL92XB"FUS9W-T<B`B3F5L>F4@=GET=F_X:70@<'+A>F1N_2!6
M1E,@<V]U8F]R+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T
M87(N<&AP.C<V"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP
M+G!H<#HW.0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS
M9W-T<B`B3F5L>F4@<F]Z8F%L:70@9&%T82XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C(R-"!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Y
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<
M(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(DYE;'IE
M('9Y;6%Z870@7"(E<UPB+"!P<F]T;[YE(&%D<F5SX?@@;F5N[2!P<N%Z9&[]
M+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HT-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R(").96QZ92!V>6UA>F%T("<E
M<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B3F5L
M>F4@=GEM87IA="`E<RP@<')O=&^^92!A9')E<^'X(&YE;NT@<'+A>F1N_2XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0X(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B
M3F5L>F4@<F5K=7)Z:7;L(&]D<W1R86YI="!61E,@861R97/A^"XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S<@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T-`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").96QZ92!V>6UA
M>F%T(%9&4R!A9')E<^'X+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z-#$W(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#(Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@
M)7,N(@IM<V=S='(@(DYE;'IE('9Y;6%Z870@5D93(&%D<F5SX?@Z("5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C`W"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R(").96QZ92!V>6UA>F%T(%9&4R!S;W5B;W(@7"(E<UPB+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,P,R!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C(X.`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,38W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#`*(SH@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X-R!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,S@S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HS.3$*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N
M(@IM<V=S='(@(DYE;'IE('9Y;6%Z870@5D93('-O=6)O<BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(T-`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB
M"FUS9W-T<B`B3F5L>F4@=GEM87IA="!61E,@<V]U8F]R(%PB)7-<(BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0P-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N
M(@IM<V=S='(@(DYE;'IE(')E:W5R>FEV;NP@;V1S=')A;FET(%9&4SH@)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,#,*;7-G:60@(E5N
M86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@
M(DYE;'IE('5RZ&ET(&%K='7A;&[M(&%D<F5SX?@N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#,*;7-G:60@(E5N86)L92!T;R!E
M>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B3F5L>F4@>FII
M<W1I="!P;V1R;V)N;W-T:2!O(&-E<G1I9FEKX71U+B(*"B,Z(&9R86UE=V]R
M:R].971?24U34"])35-0+G!H<#HT-3$@9G)A;65W;W)K+TYE=%])35-0+TE-
M4U`O075T:"YP:'`Z,3$X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R(")$969I;FEC
M92`E<R!N96[M(&1O<W1U<&[A+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#$*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$V-B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<Q"FUS9VED(")5;F%B;&4@=&\@;6]V
M92!61E,@9FEL92XB"FUS9W-T<B`B3F5L>F4@</AE<W5N;W5T(%9&4R!S;W5B
M;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C$P,@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C8T."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B3F5L>F4@</AE<W5N;W5T(%9&4R!S;W5B;W(@7"(E<UPB
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W-R!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ,S,*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&
M4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R(")61E,@<V]U8F]R(&YE;'IE
M(&]T97;X[70@<')O('KA<&ES+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C@P(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S,`HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(*;7-G:60@(E5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R(").96QZ92!O=&5V^.UT(%9&
M4R!S;W5B;W(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H
M:79E+B(*;7-G<W1R(").96QZ92!O=&5V^.UT(&%R8VAI=F]V86[]('-O=6)O
M<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#,U"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL
M960I+B(*;7-G<W1R(").96QZ92!Z87!S870@9&%T82!D;R!61E,@<V]U8F]R
M=2`H<V5L:&%L;R!C;W!Y*"DI+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HX-C8*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE
M("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(DYE;'IE('IA<'-A
M="!D871A(&1O(%9&4R!S;W5B;W)U("AS96QH86QO(&-O<'DH*2DN(@H*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N
M<&AP.C,X"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B
M"FUS9W-T<B`B3F5L>F4@</AE:FUE;F]V870@5D93('-O=6)O<BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV-CD*;7-G:60@(E5N86)L92!T
M;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F5L>F4@
MZ.US="!Z('9F<W)O;W0@861R97/A^&4N(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y
M(&5X:7-T<R(*;7-G<W1R(").96QZ92!P^&5J;65N;W9A="`E<R!N82`E<SH@
M8^UL;W;A('-L;[YK82!J:;X@97AI<W1U:F4B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(E9&4R!A9')E<^'X(&YE;'IE('#X
M96IM96YO=F%T+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I
M<F5C=&]R>3H@)7,N(@IM<V=S='(@(E9&4R!A9')E<^'X(&YE;'IE('#X96IM
M96YO=F%T.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(V
M-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B3F5L>F4@</AE:FUE;F]V870@5D93('-O=6)O<B!<(B5S7"(N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C$P(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B3F5L>F4@
M</AE:FUE;F]V870@5D93('-O=6)O<B`E<R\E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C,R,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,C$S"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(X-0HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE+B(*;7-G<W1R(").96QZ92!P^&5J;65N;W9A="!61E,@
M<V]U8F]R+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F
M<R<N(@IM<V=S='(@(DYE;'IE('!R;W;I<W0@)VUK:7-O9G,G+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@
M(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S
M='(@(E1E;G1O(&1O:W5M96YT(%=O<F0@;F5L>F4@</AE;&^^:70B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$T.2!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C$U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").96QZ92!Z87!S870@
M9&\@5D93('-O=6)O<G4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C$W.0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B3F5L>F4@>F%P<V%T(&1A=&$@
M9&\@5D93('-O=6)O<G4@*'-E;&AA;&\@8V]P>2@I*2XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,30S"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB
M"FUS9W-T<B`B3F5L>F4@>F%P<V%T(&1A=&$@9&\@5D93('-O=6)O<G4B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#0Q"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D
M960N(@IM<V=S='(@(DYE;'IE('IA<'-A="!D871A(&1O(%9&4R!S;W5B;W)U
M("AS96QH86QO(&-O<'DH*2DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@
M(E!O9'1R:&YU=.DB"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS
M9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B4W1O<FYO('IM[&XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED
M(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R(")3=&]R;F]V870@
M<&]S;&5N[2!A:V-I(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,C(S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,Y,`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B3F5OZ&5KX79A;N$@;V1P
M;W;L[R!S97)V97)U(&YA('-P;VIE;NTZ("(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS
M92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(DYE;^AE:^%V86[A(&]D<&]V
M[.\@<V5R=F5R=3H@(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B3F5V
M>7!L;NQN;R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")5
M;FEC;V1E("A55$8M."DB"FUS9W-T<B`B56YI8V]D92`H551&+3@I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@
M(E-P;VIE;ND@07)A8G-KZ2!%;6ERX71Y(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED
M(")5;FET960@2VEN9V1O;2(*;7-G<W1R(")696QKX2!"<FETX6YI92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B4W!O
M:F5NZ2!3=.%T>2!!;65R:6-KZ2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N
M:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R(")3
M<&]J96[I(%-TX71Y($UE;KEI;F]V_6-H(&]S=')O=ODB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE=&%R+G!H<#HW
M,0IM<V=I9"`B56YI=',B"FUS9W-T<B`B2F5D;F]T:WDB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(DYE>F[A
M;>DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E
M($E$*2XB"FUS9W-T<B`B3F5Z;N%MZ2!A<&EM<V=I9"`H05!)($UE<W-A9V4@
M240I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE
M<W-A9V4@240I+B(*;7-G<W1R(").97INX6WI(&-L:6US9VED("A#;&EE;G0@
M365S<V%G92!)1"DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$U.0HC+"!F=7IZ>0IM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E
M9"XB"FUS9W-T<B`B3F5B>6QO('9Y8G+A;F\@ON%D;ND@;>US=&\N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ
M"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R
M(").97INX6WI('6^:79A=&5L<VOI(&IMZ6YO(&YE8F\@:&5S;&\N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R
M(")/9'!O:FET('-O=>AA<V[]('!R=F5K(@H*(SH@9G)A;65W;W)K+TED96YT
M:71Y+TED96YT:71Y+G!H<#HR.38*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B
M0F5Z92!J;>EN82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A
M;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O
M<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C
M:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U
M(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R
M9"XB"FUS9W-T<B`B(@HB3F5P<FEV:6QE9V]V86[I('-K<FEP='D@;F5M;VAO
M=2!V>76^[79A="!F=6YK8V$@5GEJ;6]U="]+;W#M<F]V870O5FQOOB!Z("(*
M(F)E>G!EZ&YO<W1N[6-H(&3Y=F]D^2X@2VQI:V[L=&4@;F$@3TL@86)Y<W1E
M('9I9.QL:2!T96-H;FEC:V]U('IP<N%V=2!Z("(*(FUO>FEL;&$N;W)G+"!K
M=&5RX2!V>7-V['1L=6IE+"!J86L@;F%S=&%V:70@<VMR:7!T('!R;R!P^.US
M='5P(&ME('-C:'+A;F-E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM
M<V=S='(@(DYE;F%S=&%V96[A(&)A<G9A(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV.#8@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HY,C8*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HY,S(*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R(").
M97!O9'!O<F]V86[A('#X[7!O;F$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS
M,PIM<V=I9"`B57!D871E(@IM<V=S='(@(D%K='5A;&EZ;W9A="(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(D%K='5A;&EZ;W9A="`E<R(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*;7-G:60@
M(E5P9&%T92!U<V5R(@IM<V=S='(@(D%K='5A;&EZ;W9A="!UOFEV871E;&4B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H
M<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(D%K
M='5A;&EZ;W;A;GD@)R5S)RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B
M4VMR:7!T('!R;R!A:W1U86QI>F%C:2!B>6P@=GEM87KA;BXB"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ.3D*;7-G:60@(E5P;&]A9"(*;7-G<W1R(")0^&5N
M;W,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO
M861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E
M<BXB"FUS9W-T<B`B5KEE8VAN>2!S;W5B;W)Y('!R;R!N87-T879E;NT@87!L
M:6MA8^T@8GEL>2!P^&5N97-E;GD@;F$@<V5R=F5R+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G
M:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B5F5L:^$@=&ES:V%C
M[2!P[7-M96YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R
M<R(*;7-G<W1R(")696QKZ2#X[6US:^D@Z.US;&EC92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B57)U9W5A>2(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H
M<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R(")0;W6^
M[70@86MT=>%L;NTZ("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B
M4&]UONUT(%-33"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G
M:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U3
M4"!S97)V97(N(@IM<V=S='(@(E!O=;[M="!P;VMU9"!J;>EN;R]H97-L;R!J
M<V]U(&II;ND@;F6^('!R;R!)35-0('-E<G9E<BXB"@HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"B,L(&9U>GIY"FUS9VED(")5<V5R
M(@IM<V=S='(@(E6^:79A=&5LZ2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]296=I<W1R>2YP:'`Z-S(S"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@
M)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R(")5OFEV871E
M;"`E<R!N96[M(&]P<N%V;NQN(&L@<&]UONUVX6[M("5S+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G
M<W1R(")!9&UI;FES=')A8V4@=;YI=F%T96SY(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HR-3$*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G
M<W1R(")5OFEV871E;'-KZ2!M;[YN;W-T:2(*"B,Z('-I9VYU<"YP:'`Z-C(*
M;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(E)E9VES=')A8V4@
M=;YI=F%T96SY(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I
M<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS
M9W-T<B`B3F$@=&]M=&\@<V5R=F5R=2!N96[M(&UOOF[A(')E9VES=')A8V4@
M=;YI=F%T96SY+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-CD*(RP@
M9G5Z>GD*;7-G:60@(E5S97(@86-C;W5N="!N;W0@9F]U;F0B"FUS9W-T<B`B
M)7,@;F5B>6QO(&YA;&5Z96YO+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G
M:60@(E5S97)N86UE(@IM<V=S='(@(E6^:79A=&5L<VOI(&IMZ6YO(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C$R-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI
M<W1S+B(*;7-G<W1R(")5OFEV871E;'-KZ2!J;>EN;R`G)7,G(&IIOB!E>&ES
M='5J92XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G
M:60@(E5S97)N86UE.B(*;7-G<W1R(")5OFEV871E;'-KZ2!J;>EN;SHB"@HC
M.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5<V5R;F%M
M93H@(@IM<V=S='(@(E6^:79A=&5L<VOI(&IMZ6YO.B`B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@
M<WES=&5M.B(*;7-G<W1R(")397IN86T@=;YI=F%T96SY.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B57IB96MI<W3A;B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$V,R!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR-34*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E
M<R!N;W0@97AI<W0N(@IM<V=S='(@(E9&4R!A9')E<^'X(&YE97AI<W1U:F4N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C
M871I;VXB"FUS9W-T<B`B1&]V;VQE;N$B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HX-C8*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L
M=61E.B`B"FUS9W-T<B`B3F%L97IE;N$@<&QA=&[A(&WM<W1A('IA:')N=6KM
M.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.`IM
M<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B4&QA=&YO<W0B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G
M:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(DAO9&YO
M=&$@=B!M:6YU=.%C:"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX
M-38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T
M-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR
M.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y
M"FUS9VED(")686QU97,B"FUS9W-T<B`B2&]D;F]T>2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q,#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$X-@IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(E9Y
M8G)A;ND@:&]D;F]T>2!Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T
M=2(*;7-G<W1R(")686YU871U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(T-`IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B4')O;>QN;NDB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`B5F5N
M97IU96QA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR
M,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@
M;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R(")396QH86QA
M('9E<FEF:6MA8V4@+2!T871O('IP<N%V82!M;VAL82!B_70@>F9A;+EO=N%N
M82XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,`IM
M<V=I9"`B5F5R<VEO;B(*;7-G<W1R(")697)Z92(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR,C8*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G
M<W1R(")697)S:6]N($-O;G1R;VPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A
M;&EG;B(*;7-G<W1R(")697)T:6OA;&[M('IA<F]V;N%N[2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E
M<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B5F5R=&EKX6QN[2!O9'-T=7`B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS
M9VED(")697)T:6-A;#HB"FUS9W-T<B`B5F5R=&EKX6QN[3HB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B5F5R
M>2!(:6=H(@IM<V=S='(@(E9E;&UI('9Y<V]KX2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*
M;7-G:60@(E9I970@3F%M(@IM<V=S='(@(E9I971N86TB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*
M;7-G<W1R(")6:65T;F%M<VMY("A625-#24DI(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z.38R"B,L('!H<"UF;W)M870*;7-G:60@
M(E9I97<@)7,B"FUS9W-T<B`B6F]B<F%Z:70@)7,B"@HC.B!L:6(O0FQO8VLO
M:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E
M(@IM<V=S='(@(EIO8G)A>FET(&5X=&5R;NT@=V5B<W1RX6YK=2(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(EIO8G)A>FET(&IA:V\@
M)7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I
M=&ES:"(*;7-G<W1R(")086YN96YS:^D@3W-T<F]V>2P@0G)I='-KZ2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S
M='(@(E!A;FYE;G-KZ2!/<W1R;W9Y+"!5+E,N(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B5FED:71E
M;&YO<W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8S"FUS
M9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B5FED:71E;&YO<W0Z(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z
M.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S='(@(E9O
M9&%F;VYE($ET86QY('#X97,@4TU44"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G
M:60@(E=!4DXB"FUS9W-T<B`B55!/6D]23DE4(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A
M(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(E50
M3UI/4D[,3LTA(2$@3T135%)!TE1%(%-+4DE05"!25<A.S"!:("5S+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"B,L(&9U
M>GIY"FUS9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B<VUS,F5M86EL('IA
M('!O=;YI=.T@2%144"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A
M;F0@1G5T=6YA(@IM<V=S='(@(E=A;&QI<R!A;F0@1G5T=6YA(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HR.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL
M+G!H<#HR-S(@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N
M:6YG(@IM<V=S='(@(E5P;WIO<F[L;NTB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R(")3
M="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B
M5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R(")0^&5D<&]V[.\@<&_H87/M(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0R-PIM<V=I9"`B5V5A
M=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(D1A=&$@;R!P;^AA<^T@
M<&]S:WET=6IE(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR"FUS
M9VED(")796%T:&5R+F-O;2(*;7-G<W1R(")796%T:&5R+F-O;2(*"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B5V5B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S-PIM<V=I9"`B5V5B
M(%-I=&4B"FUS9W-T<B`B5V5B('-E<G9E<B(*"B,Z(&9R86UE=V]R:R]-86EN
M=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G
M<W1R(")4_61N["(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X
M"FUS9VED(")796QC;VUE(@IM<V=S='(@(E;M=&5J=&4B"@HC.B!T96UP;&%T
M97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G
M<W1R(")6[71E:G1E('8@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE
M+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B5NUT96IT92P@)7,B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5V5S=&5R;B`H
M25-/+3@X-3DM,2DB"FUS9W-T<B`B6N%P861N[2`H25-/+3@X-3DM,2DB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5V5S=&5R;B`H25-/
M+3@X-3DM,34I(@IM<V=S='(@(EKA<&%D;NT@*$E33RTX.#4Y+3$U*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R("):X7!A
M9&[M(%-A:&%R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@
M9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B2W1E<F]U(&%P;&EK86-I
M(&WA("5S('IO8G)A>FET('!O('#X:6ALX;EE;NT@9&\@<WES=.EM=3\B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I
M<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B2F%K_2!J92!O
M9&3L;&]V86/M('IN86L_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS
M9W-T<B`B2F%K_2!J92!Z;F%K('!R;R!C:71A8VD_(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C$*(RP@9G5Z>GD*;7-G
M:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R(")!=7-T<N%L:64B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E
M<R(*;7-G<W1R(")+=&5RZ2!FX7IE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$S,PIM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H
M92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R(")6;VQB82!R;WJY[?AE;NT@
M<')O(%)I8V@@5&5X="!E9&ET;W(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS
M9W-T<B`BJ>WX:V$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(U
M"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`BJ>WX:V$@=B!#
M4U,@:F5D;F]T:^%C:"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@
M=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S
M='(@(JGM^&MA("5S(&UE;G4@=FQE=F\@*'IM[&YA('-E(&]B:F5V[2!P^&D@
M9&%LN>UM('#X:6ALX;EE;NTI.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B
M;&4B"FUS9W-T<B`BJ>WX:V$@=&%B=6QK>2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET
M(@IM<V=S='(@(DIE9&YO=&MA(+GM^&MY(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G
M<W1R("*I[?AK83HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$S
M"FUS9VED(")7:6MI(@IM<V=S='(@(E=I:VDB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8U"FUS9VED(")7:6YD(@IM<V=S='(@(E;M='(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B
M5VEN9"!%87)L>2(*;7-G<W1R(")286YN[2!V[71R(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HX,`IM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G
M<W1R(")2>6-H;&]S="!V['1R=2!V('5Z;&5C:"(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,34V"FUS9VED(")7:6YD.B(*;7-G<W1R(")6[71R.B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#(*;7-G:60@(E=I;F0Z
M("(*;7-G<W1R(")6[71R.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R(")-;W5D<F]S="(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ.38*(RP@9G5Z>GD*;7-G:60@(E=I<VAL
M:7-T(@IM<V=S='(@(E-E>FYA;2!P^.%N[2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R(")0<N%C92(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM<V=I9"`B
M5V]R:R!!9&1R97-S(@IM<V=S='(@(D%D<F5S82!D;R!Z86WL<W1NX6[M(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM
M<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")496QE9F]N(&1O('IA;>QS=&[A
M;NTB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-CD@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@
M(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@
M)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HS,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M
M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,30*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R
M96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(E9Y='9O^&5N[2!61E,@<V]U
M8F]R=2!N96)Y;&\@<&]V;VQE;F\N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(T,PIM<V=I9"`B6"U2968B"FUS9W-T<B`B6"U2968B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P
M.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(E@U,#EV,R!ZX6ML861N
M[2!O;65Z96[M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.3(*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T
M<B`B6#4P.78S(')O>KGM^&5NZ2!P;W6^:73M(&ML[>AE(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!3
M=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B6#4P.78S(&%L=&5R
M;F%T:79N[2!J;>EN;R!O<V]B>2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E
M;G1I9FEE<B(*;7-G<W1R(")8-3`Y=C,@:61E;G1I9FEKX71O<B!K;.WH92(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@R"FUS9VED
M(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R(")8-3`Y=C,@<F]ZN>WX96[M
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@
M(E)2(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#4U"FUS9VED(")965E9(@IM<V=S='(@(E)24E(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$P.`IM<V=I9"`B66%H;V\A
M(&UA<"(*;7-G<W1R(")-87!A(%EA:&]O(2(*"B,Z(&9R86UE=V]R:R]-86EN
M=&5N86YC92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G
M<W1R(")2;^AN["(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S
M='(@(DIE;65N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.CDV,PIM<V=I9"`B665S(@IM<V=S='(@(D%N;R(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")9
M97,L($D@06=R964B"FUS9W-T<B`B06YO+"!S;W5H;&%S[6TB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9
M;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@
M<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@HB2G-T92!V(%1%
M6%1/5LE-($W31%4N(%!O=;YI:G1E(%L\/ET@=&QAZ.UT:V$@:R!Z<.QT;NEM
M=2!P^&5P;G5T[2!D;R!765-)5UE'+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E
M9&ET+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A
M;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,3$*;7-G:60@
M(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(DYE8GEL:2!J
M<W1E('-P<N%V;NP@;W;L^&5N:2XB"@HC.B!F<F%M97=O<FLO261E;G1I='DO
M261E;G1I='DN<&AP.C,P,@IM<V=I9"`B66]U(&-A;B!N;W0@:&%V92!T:&4@
M)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(EIN
M86L@)UQ<)R!N96WYOF4@8OUT('-O=>CA<W3M(%9AN65H;R!J;>EN82XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4U(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Y-S4*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L
M:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`B0GEL82!Z863A;F$@;F5P;&%T
M;N$@92UM86EL;W;A(&%D<F5S82XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A
M+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M
M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C
M;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@HB3F5M
M87!O=F%L:2!J<W1E(+[A9&[A('!O;&4@>B!I;7!O<G1O=F%NZ6AO('-O=6)O
M<G4@:R!O9'!O=NUD86KM8^UM('!O;.UM('8@)2(*(G,N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED(")9;W4@:&%V92!B965N(&QO
M9V=E9"!O=70N(@IM<V=S='(@(D)Y;&D@:G-T92!O9&ALX;EE;FD@>F4@<WES
M=.EM=2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q"FUS9VED
M("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB
M97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T
M:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@HB
M5FQOOG1E(.CM<VQO(&UO8FEL;NUH;R!T96QE9F]N=2P@<&]UOFEJ=&4@:F5N
M(.CM<VQI8R!N96)O('#X[7!A9&[L("<K)R!P<F\@(@HB;65Z:6[A<F]D;NT@
MZ&ES;&$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X.`IM<V=I
M9"`B66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B
M375S[71E('IA9&%T('!L871N;W4@:&]D;F]T=2XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I
M9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S
M='(@(B(*(DUU<^UT92!K;VYF:6=U<F]V870@9&%T86+A>FD@9&%T+"!P;VMU
M9"!S:2!P^&5J971E('!O=;[M=F%T(%)E9VES=')A8V4N(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HT-38*;7-G:60@(EEO=2!M=7-T(&-O;F9I
M9W5R92!A(%9&4R!B86-K96YD+B(*;7-G<W1R(")-=7/M=&4@:V]N9FEG=7)O
M=F%T(%9&4R!B86-K96YD+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE
M;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS
M9W-T<B`B375S[71E(&YE:F3X[79E('!O<'-A="!P<F]B;.EM(&$@<&]TZ2!H
M;R!O9&5S;&%T+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE
M<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R(")-=7/M=&4@>F%D870@
M55),(&YA(&MT97+I(&)U9&4@=&5N=&\@;V1K87H@=6MA>F]V870B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@
M<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R(")-=7/M
M=&4@=GEB<F%T('-E<G9E<BP@:W1E<OT@8G5D92!S;6%ZX6XN(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E
M<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R(")-=7/M=&4@=GEB<F%T('6^
M:79A=&5L<VOI(&IMZ6YO+"!K=&5RZ2!B=61E('-M87KA;F\N(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E
M<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R(")-=7/M=&4@>F%D870@=;YI=F%T
M96QS:^D@:FWI;F\L(&MT97+I(&)U9&4@;V1S=')A;NQN;RXB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D
M9"XB"FUS9W-T<B`B3F5U=F5D;&D@:G-T92!UOFEV871E;'-KZ2!J;>EN;RP@
M:W1E<ND@8G5D92!P^&EDX6YO+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM
M<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E
M+B(*;7-G<W1R(").975V961L:2!J<W1E('6^:79A=&5L<VOI(&IMZ6YO('!R
M;R!A:W1U86QI>F%C:2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A
M8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B375S[71E('IA9&%T(&%K8VDL
M(&MT97+A(&)U9&4@<')O=F5D96YA+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED(")9;W4@;75S="!T
M>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(DUU<^UT92!Z861A
M="!J;>EN;R!N;W;I(&MA=&5G;W)I92XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE
M960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A
M<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(E9AN64@)7,@<F5L86-E(&)Y;&$@
M=6MO;NAE;F$N($]P['0@<V4@</AI:&QAN71E+"!P<F]S[6TN(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G:60@(EEO=7(@16UA
M:6P@061D<F5S<R(*;7-G<W1R(")68;EE(&5M86EL;W;A(&%D<F5S82(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3(*;7-G:60@(EEO=7(@1G)O;3H@
M861D<F5S<SHB"FUS9W-T<B`B5F&Y92!/9"UK;VAO.B!A9')E<V$Z(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@
M(E9AN64@:6YF;W)M86-E(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M.3@P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D
M<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@
M)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@
M;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB5B!R96QA8VD@)7,@<V4@
M>FWL;FEL82!68;EE(&EN=&5R;F5T;W;A(&%D<F5S82X@6B!B97IP9>AN;W-T
M;NUC:"!D^79O9/D@<V4@(@HB;75S[71E(&]P['0@</AI:&SA<VET+B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R
M($YA;64B"FUS9W-T<B`B5F&Y92!J;>EN;R(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VYO861D+FEN8SHU"B,L(&9U>GIY"FUS9VED("(B"B)9;W5R(&%U
M=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@
M=7-E<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES
M=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B
M"B)A=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"B)6X;D@;W;L
M^&]V86/M('-Y<W3I;2!N97!O9'!O<G5J92!P^&EDX7;A;NT@=;YI=F%T96SY
M(&%N96)O('1A=&\@;6^^;F]S="!N96[M("(*(G#X[7-T=7!NX2!Z(&II;OUC
M:"!D^79O9/DN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN
M8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E
M<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B
M"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM
M<V=S='(@(B(*(E;AN2!O=NSX;W9A8^T@<WES=.EM(&YE<&]D<&]R=6IE(';]
M<&ES('6^:79A=&5L^2!A;F5B;R!T871O(&UOOFYO<W0@;F5N[2`B"B)P^.US
M='5P;N$@>B!J:6[]8V@@9/EV;V3Y+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDX-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S
M97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN
M9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U
M<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(EIDX2!S
M92P@OF4@=B!P<OEB[&AU(')E;&%C92`E<R!S92!Z;>QN:6P@5N&Y('!R;VAL
M[;YEZ"X@6B!B97IP9>AN;W-T;NUC:"`B"B)D^79O9/D@<V4@;75S[71E(&]P
M['0@</AI:&SA<VET+B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4P"FUS
M9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U
M<F4N(@IM<V=S='(@(E;AN2!P<F]H;.V^9>@@;F5P;V1P;W)U:F4@='5T;R!M
M;[YN;W-T+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R
M"B,L(&9U>GIY"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P
M<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD
M("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@HB5N&Y('!R;VAL[;YEZ"!N
M975M;[[R=6IE('1I<VL@=.UM=&\@>G#Y<V]B96TN(%!R;W9E9&5N[6T@<W1I
M<VMN=73M($-T<FPO(@HB3W!T:6]N("L@4"!S<'5S=.UT92!T:7-K+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3<*;7-G:60@(EEO=7(@8W5R<F5N
M="!T:6UE('IO;F4Z(@IM<V=S='(@(E9AN64@<V]UZ&%S;ND@Z&%S;W;I('#A
M<VUO.B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY-@HC+"!F=7IZ>0IM<V=I
M9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N(@IM
M<V=S='(@(E9AN64@:6UP;&EC:71N[2!I9&5N=&ET82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-3@*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET
M>3HB"FUS9W-T<B`B5F&Y92!I;7!L:6-I=&[M(&ED96YT:71A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(P,0IM<V=I9"`B66]U<B!F=6QL(&YA;64Z
M(@IM<V=S='(@(E9AN64@^G!L;ND@:FWI;F\Z(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z,3`P,`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!L;V=I;B!H
M87,@97AP:7)E9"XB"FUS9W-T<B`B5F&Y92!N87-T879E;NT@8GEL;R!A:W1U
M86QI>F]VX6YO+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V
M"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E
M<R!I<SH@)7,B"FUS9W-T<B`B5F&Y92!N;W;I(&AE<VQO('!R;R`E<R!J93H@
M)7,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`IM<V=I
M9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R
M871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")68;EE(&YA<W1A=F5N
M[2!B>6QO(&%K='5A;&EZ;W;A;F\@<')O('1R=N%N[2!TZ71O(')E;&%C92XB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B
M66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R(")68;EE
M(&YA<W1A=F5N[2!B>6QO(&%K='5A;&EZ;W;A;F\N(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S
M(&)E96X@<F5S970B"FUS9W-T<B`B5F&Y92!H97-L;R!B>6QO(')E<V5T;W;A
M;F\N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@
M(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@
M96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*
M;7-G<W1R("(B"B)68;EE(&AE<VQO(&)Y;&\@<F5S971O=N%N;RP@>FMO;G1R
M;VQU:G1E('-I('IP<N%V>2!E;&5K=')O;FEC:^D@<&^Y='D@82`B"B)P^&EH
M;&&Y=&4@<V4@<R!68;GM;2!N;W;];2!H97-L96TN(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z-S,R"B,L(&9U>GIY"FUS9VED(")9;W5R('!A<W-W
M;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")68;EE(&AE<VQO(&)Y;&\@<F5S
M971O=N%N;RXB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*
M;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(E9AN64@=GID
MX6QE;ND@<V5R=F5R>3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9
M=6=O<VQA=FEA(@IM<V=S='(@(DIU9V]S;.%V:64B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R("):
M86ER(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(EIA
M;6)I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@
M(EII;6)A8G9E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED
M(")::7!P>2(*;7-G<W1R(")::7!P>2(*"B,Z(&9R86UE=V]R:R]497AT7T9I
M;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E
M(%%U;W1E9"!497AT72(*;7-G<W1R(");56MR_70@8VET;W9A;OT@=&5X=%TB
M"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX.`IM<V=I9"`B6U!R;V)L96T@
M4F5P;W)T72(*;7-G<W1R(");2&SAN65N[2!P<F]B;.EM=5TB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H
M;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R(");6F]B<F%Z:70@8VET;W9A;OT@
M=&5X="`M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H
M;&EG:'1Q=6]T97,N<&AP.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO
M=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");6F]B<F%Z:70@
M8VET;W9A;OT@=&5X="`M("5S(/CA9&OY72(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S
M(&]F("5S72(*;7-G<W1R(");^.%D96L@)7,@>B`E<UTB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$U-#$@=&5M<&QA=&5S+W!O<G1A;"]M96YU
M+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E]!9&UI
M;FES=')A8V4B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS
M9W-T<B`B7T-,22(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A=&%4
M<F5E(@IM<V=S='(@(E]$871A5')E92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T
M92!2;W<B"FUS9W-T<B`B7U-M87IA="#XX61E:R(*"B,Z(&QI8B]A<&DN<&AP
M.C$S,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R(")?4VMU<&EN>2(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP
M(@IM<V=S='(@(E].X7!O=NQD82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R
M;W!E<G1I97,N+BXB"FUS9W-T<B`B7U9L87-T;F]S=&D@;V)RX7IK=2XN+B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*;7-G:60@
M(E],;V<@:6XB"FUS9W-T<B`B7U#X:6ALX;EE;NTB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*;7-G
M<W1R(")?3V1H;.&Y96[M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN
M+BXB"FUS9W-T<B`B7TUO9&EF:6MO=F%T(&]D:V%Z+BXN(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B
M"FUS9W-T<B`B7TUOOFYO<W1I(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED
M(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B7U!RX79A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"FUS9VED
M(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B7T]D<W1R86YI="!O9&MA>BXN
M+B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@
M(E].87-T879E;NTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S
M+BXN(@IM<V=S='(@(E]6;&%S=&YO<W1I('1A8G5L:WDN+BXB"@HC.B!L:6(O
M87!I+G!H<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G<W1R(")?5;YI=F%T96SI
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C$*;7-G:60@(F%D
M9')E<W,@8F]O:R(*;7-G<W1R(")A9')E<^'X(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ,S0*(RP@9G5Z>GD*;7-G:60@(F%D9')E
M<W-E92!U;FMN;W=N(@IM<V=S='(@(F%D<F5SX?@B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDQ,PIM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B
M:V%L96YDX?@B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM
M<V=S='(@(F)E>G;L=/CM(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@IM<V=I9"`B
M8VQI8VL@:&5R92(*;7-G<W1R(")K;&EK;F]U="!Z9&4B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L
M:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3<X"B,L(&9U>GIY"FUS9VED(")C;VYF:6=U
M<F%T:6]N(&5R<F]R(@IM<V=S='(@(E)O>F3M;'D@=B!N87-T879E;NTB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B
M8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T
M82!F;W)M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ.#(*(RP@9G5Z>GD*;7-G:60@(F5N=')Y(&YO
M="!F;W5N9"(*;7-G<W1R(")N96YA;&5Z96YO(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(F9A;&QI;F<B"FUS
M9W-T<B`B<W+AOFMY(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP
M:'`Z.#4U"FUS9VED(")F:6QE(@IM<V=S='(@(G-O=6)O<B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3<T(&QI8B]";&]C:R]M971A<BYP:'`Z,S8P(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S@V"B,L('!H<"UF;W)M870*;7-G:60@(F9R
M;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B>B`E<R`H)7,I(')Y
M8VAL;W-T[2`E<R`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-3`*(RP@9G5Z>GD*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B+"!NX7)A
M>F]V_2`E<R`E<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR-#D*;7-G:60@(F@Z(@IM<V=S='(@(F@Z(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.`IM<V=I9"`B:&@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(F]K86V^:73L(@H*(SH@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z
M-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R(")V(/AA9.PB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T
M<'5T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L
M;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S='(@(OCA9&OY72(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H
M<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@
M)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B8VAY8F]V_2!K\V0@;6MI
M<V]F<R`E9"!P^&D@=GET=N'X96[M($E33RXB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8Y"FUS9VED(")M;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(Y,2!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HR,S(*;7-G:60@(FYA;64B"FUS9W-T<B`B:FWI;F\B
M"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(Q"FUS9VED(")N;W0@:6UP
M;&5M96YT960B"FUS9W-T<B`B;F5N[2!I;7!L96UE;G1O=N%N;R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(Q.0IM<V=I9"`B;F]T
M('EE="!I;7!L96UE;G1E9"(*;7-G<W1R(")N96[M(&1O<W5D(&EM<&QE;65N
M=&]VX6YO(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#4*;7-G
M:60@(FYO=&5P860B"FUS9W-T<B`B>N%P:7-N[6LB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P
M97)C96YT(@IM<V=S='(@(G!R;V-E;G0B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$W-`HC+"!F=7IZ>0IM<V=I9"`B<&5R;6ES<VEO
M;B!D96YI960B"FUS9W-T<B`B4'+A=F$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B
M"FUS9W-T<B`B<&EX96SY(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HW,PIM<V=I9"`B<FES:6YG(@IM<V=S='(@(G-T;W5P86KM8^TB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@HC+"!F=7IZ
M>0IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R(")";&]K(&\@
M<&_H87/M(&YE;NT@9&]S='5P;OTN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HY.0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R(")Z;V)R
M87II="!R;WID[6QY(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*
M;7-G<W1R(")S;7,R96UA:6P@>F$@<&]UOFET[2!(5%10(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-0IM<V=I9"`B<W,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-S(*;7-G:60@(G-T96%D>2(*;7-G<W1R(")V>71R=F%LZ2(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`Y"FUS9VED(")S=VET8V@@
M;V9F(&IA=F%S8W)I<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.0IM<V=I
M9"`B=&%S:R!L:7-T(@IM<V=S='(@(G-E>FYA;2#Z:V]L^2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A
M<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C,P-0HC+"!F=7IZ>0IM<V=I9"`B=')Y(&%G86EN(@IM<V=S='(@
M(DMAOF3I('#X:6ALX;EE;NT@9&\@<WES=.EM=2(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G
M:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T
M<B`B<')O('!O='9R>F5N[2!N87!IN71E(&AE<VQO(&1V86MRX70B"@HC.B!A
M9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW
M.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R(")S:F5D;F]C96[](@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*
M;7-G<W1R(")B97H@;N%Z=G4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T
M(@IM<V=S='(@(G9Y8G)A="!UOFEV871E;&4B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S
M='(@(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(T,0IM<V=I9"`B=SHB"FUS9W-T<B`B=SHB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS
M9W-T<B`B=V5A=&AE<BYC;VTB"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+V1A7T1++G!O````
M````````````````````````````````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#$Q
M,#$R-#$`,3`U,34T,S,W-30`,#$W-3<W`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````",@1&%N:7-H('1R86YS;&%T:6]N<R!F
M;W(@2&]R9&4@<&%C:V%G90HC($1A;G-K92!O=F5R<^9T=&5L<V5R(&9O<B!P
M86MK92!(;W)D92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#$@36%R=&EN($QI<W0M
M4&5T97)S96XN"B,@0V]P>7)I9VAT("A#*2`R,#`U+3(P,#8@0G)I86X@5')U
M96QS96XN"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S
M86UE(&QI8V5N<V4@87,@=&AE($AO<F1E('!A8VMA9V4N"B,@36%R=&EN($QI
M<W0M4&5T97)S96X@/&UA<G1I;D!L:7-T+7!E=&5R<V5N+F1K/BP@,C`P,2X*
M(R!"<FEA;B!4<G5E;'-E;B`\:&]R9&4K:3$X;D!B<FEA;G1R=65L<V5N+F1K
M/BP@,C`P-2TR,#`V+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)
M9"U697)S:6]N.B!(;W)D92`S+C$N,2UC=G-<;B(*(E)E<&]R="U-<V=I9"U"
M=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM
M1&%T93H@,C`P-BTP,RTQ,2`Q,CHS.2LP,3`P7&XB"B)03RU2979I<VEO;BU$
M871E.B`R,#`V+3`S+3$Q(#$V.C4R*S`Q,#!<;B(*(DQA<W0M5')A;G-L871O
M<CH@0G)I86X@5')U96QS96X@/&AO<F1E*VDQ.&Y`8G)I86YT<G5E;'-E;BYD
M:SY<;B(*(DQA;F=U86=E+51E86TZ($1A;FES:"`\:3$X;D!L:7-T<RYH;W)D
M92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E
M.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3%<;B(*(D-O;G1E;G0M
M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*(E!L=7)A;"U&;W)M<SH@;G!L
M=7)A;',],CL@<&QU<F%L/2AN("$](#$I.UQN(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,V.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,V.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*"5S
M(&1A9V4@<VED96XI(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M,S@S(&QI8B](;W)D92YP:'`Z,3,X,PHC+"!P:'`M9F]R;6%T"FUS9VED("(@
M*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B("A!8V-E<W-K97D@)7,I(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-R!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C,W-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM
M<V=S='(@(B`H;VT@)7,@9&%G92DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S<S(&QI8B](;W)D92]&;W)M+G!H<#HR,S<S"FUS9VED("(@*'1O
M9&%Y*2(*;7-G<W1R("(@*&D@9&%G*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-S4@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H
M=&]M;W)R;W<I(@IM<V=S='(@(B`H:2!M;W)G96XI(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,W,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W,0IM
M<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B`H:2!GY7(I(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-2!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S4P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS.38*;7-G:60@(B!A="`B"FUS9W-T<B`B(&UE9"`B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C(Q.2!L:6(O5D93+W-M8BYP:'`Z,C$Y"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN
M(@IM<V=S='(@(EPB)7-<(B!E<B!I:VME(&5T(&MA=&%L;V<N(@H*(SH@9G)A
M;65W;W)K+T-,22]#3$DN<&AP.C(W,B!L:6(O2&]R9&4O0TQ)+G!H<#HR-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H
M;VEC92XB"FUS9W-T<B`B7"(E<UPB(&5R(&EN=&5T(&=Y;&1I9W0@=F%L9RXB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<Q,`HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$P.3@@;&EB
M+TAO<F1E+U)E9VES=')Y+G!H<#HW,3`*(SH@;&EB+TAO<F1E+U)E9VES=')Y
M+G!H<#HQ,#DX"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@
M8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(EPB
M)7-<(B!E<B!I:VME(&MO;F9I9W5R97)E="!I($AO<F1E<R!F;W)T96=N96QS
M92XB"@HC.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$@;&EB+TAO<F1E
M+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E
M92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(EPB)7-<(B!T<N8M;W!B
M>6=G97(@:6MK92!F=6YD970N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G
M<F]U<',@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@8FQE=B!T:6QF^&IE="!I
M(&=R=7!P92US>7-T96UE="XB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T
M;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@8FQE
M=B!T:6QF^&IE="!T:6QL861E;'-E<RUS>7-T96UE="XB"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB
M"FUS9W-T<B`B7"(E<UPB(&)L978@:6MK92!D86YN970Z("5S+B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R
M("(E+C)F34(@8G)U9W0@=60@868@)2XR9DU"('1I;&QA9'0@*"4N,F8E)2DB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(V"B,L('!H<"UF
M;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(E9"`E<R!O9R`E
M<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B](
M;W)D92]!=71H+VQD87`N<&AP.C(V.`HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-3DT"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U
M<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(E9"!D86=E('1I;"!D:70@
M:V]D96]R9"!U9&SX8F5R+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T
M(@IM<V=S='(@(B5D+61A9W,@=61S:6=T(@H*(SH@<V5R=FEC97,O;6%I;G1E
M;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E
M(@IM<V=S='(@(B5S("T@3F]T:71S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HW,#4@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW
M,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T
M<B`B)7,@9FEN9V5R869T<GEK(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z.#0R(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@T-`HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#0R(&QI
M8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R!6
M961L:6=E:&]L9&5L<V4@+2!"96MRYF9T96QS92(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(E<R!O<'/F=&YI
M;F<B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8T(&QI
M8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8T"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B)7,@;W!S:W)I=FYI;F<B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B5S(&)R=6=S8F5T
M:6YG96QS97(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X,B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U,`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C0S,B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y
M-`HC.B!L:6(O5D93+V9T<"YP:'`Z-C@R(&QI8B]61E,O9G1P+G!H<#HW-3`@
M;&EB+U9&4R]S;6(N<&AP.C0S,@HC.B!L:6(O5D93+W-M8BYP:'`Z-#DT"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R
M("(E<R!E:W-I<W1E<F5R(&%L;&5R961E+B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,38V(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C0V"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S4R(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T
M("5S("5S(@IM<V=S='(@(B5S('9E9"`E<R`E<R(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I
M<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS
M(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R
M871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM
M<V=S='(@(B(*(B5S(&5R('!A<F%T('1I;"!A="!U9&;X<F4@9&4@=F5D;&EG
M96AO;&1E;'-E<VAA;F1L:6YG97(L('-O;2!E<B!M87)K97)E="`B"B)N961E
M;F9O<BX@(%/F="!H86L@=60@9F]R(&1E(&AA;F1L:6YG97(L('-O;2!D=2#X
M;G-K97(@=61F^')T(&YU+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S-#`@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B)7,@:W+F=F5T(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@;6EN=71E<R(*;7-G<W1R("(E<R!M:6YU='1E<B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,S(@;&EB+TAO<F1E+T)L
M;V-K+T-O;&QE8W1I;VXN<&AP.C$S,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!N;W0@9F]U;F0N(@IM<V=S='(@(B5S(&EK:V4@9G5N9&5T+B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B)7,@=&EL("5S(&%F("5S
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C8@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HY,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R
M97-S($)O;VLB"FUS9W-T<B`B)7-S(&%D<F5S<V5K87)T;W1E:R(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$X(&QI8B](;W)D92]+;VQA8BYP
M:'`Z.3$X"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS
M9W-T<B`B)7-S(&MA;&5N9&5R(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,3`@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B5S<R!N;W1E<V)L;VLB
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-"!L:6(O2&]R9&4O
M2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML
M:7-T(@IM<V=S='(@(B5S<R!O<&=A=F5R(@H*(SH@9G)A;65W;W)K+TYO=&EF
M:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC
M.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z
M.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B5S.B`E
M<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R
M-R!L:6(O2&]R9&4O34E-12]6:65W97(O:'1M;"YP:'`Z,3(W"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F
M<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG
M("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E
M<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@HB
M)7,Z($1E;FYE(&)E<VME9"!E<B!M=6QI9W9I<R!I:VME(&9R82!D96X@<&5R
M<V]N+"!S;VT@9&5N(&CF=F1E<B!A="!VYG)E("(*(F9R82X@(%;F<B!V87)S
M;VT@;65D(&%T(&;X;&=E(&AE;G9I<VYI;F=E<B!E;&QE<B!F;W)S>6YE(&%F
M<V5N9&5R96X@;65D("(*(G!E<G-O;FQI9V4@:6YF;W)M871I;VYE<BXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4T(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS.3D*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T
M<B`B+"!D:7-E="`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Y-2!L:6(O
M0FQO8VLO;65T87(N<&AP.C(P,`HC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U
M<W1I;F<@)7,@)7,B"FUS9W-T<B`B+"!B;.9S96YD92`E<R`E<R(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C`X"B,L('!H<"UF;W)M870*;7-G:60@(BP@
M=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(L('-K<FEF=&5N9&4@
M9G)A("5S('1I;"`E<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HW-#@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR
M.30*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`V.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,3(X(&QI8B](;W)D92]&;W)M+G!H<#HR,#8Y"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,3(X(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HW-#@*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR.30@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HS-#@*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G
M<W1R("(M+2!VYFQG("TM(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"FUS
M9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R("(Q,BUT:6UE<G,@9F]R;6%T
M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R($9O
M<FUA="(*;7-G<W1R("(R-"UT:6UE<G,@9F]R;6%T(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T
M('1I;65R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.2!L:6(O
M2&]R9&4O54DO4&%G97(N<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B"FUS9W-T
M<B`B/$9O<F5GY65N9&4@9&%G(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M,C8*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@
M=&AI<R!B;&]C:RXB"FUS9W-T<B`B16X@9&%T86)A<V4M8F%C:V5N9"!E<B!K
M<N9V970@9F]R(&1E;FYE(&)L;VLN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ-S$@;&EB+TAO<F1E+G!H<#HQ-S$*;7-G:60@(D$@9F%T86P@
M97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(D1E<B!E<B!O<'-TY65T(&5N
M(&=R879E<F5N9&4@9F5J;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.CDS-2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@
M(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE
M<W-A9V4N(@IM<V=S='(@(D5N(&]F9F5N=&QI9R!01U`M;OAG;&4@97(@:W+F
M=F5T(&9O<B!A="!K<GEP=&5R92!E;B!B97-K960N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V."!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HQ,38X"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D
M('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R(")%;B!O9F9E
M;G1L:6<@4$=0+6[X9VQE(&5R(&MRYG9E="!F;W(@870@=F5R:69I8V5R92!E
M;B!S:6=N97)E="!B97-K960N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3`Y.2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#DY"FUS
M9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S
M<V%G92XB"FUS9W-T<B`B(@HB16X@;V9F96YT;&EG(%!'4"UN^&=L92P@<')I
M=F%T(%!'4"UN^&=L92!O9R!E="!L^'-E;B!E<B!K<N9V970@9F]R(&%T("(*
M(F1E:W)Y<'1E<F4@96X@8F5S:V5D+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$P,38@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`Q
M-@IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE
M<W-A9V4N(@IM<V=S='(@(B(*(D5N(&]F9F5N=&QI9R!01U`M;OAG;&4L('!R
M:79A="!01U`M;OAG;&4@;V<@970@;/AS96X@97(@:W+F=F5T+"!F;W(@870@
M(@HB<VEG;F5R92!E;B!B97-K960N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU,#8@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M,#8*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-
M24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E
M8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B)%;B!O9F9E;G1L:6<@4R]-
M24U%+6[X9VQE+"!P<FEV870@4R]-24U%+6[X9VQE(&]G(&5T(&SX<V5N(&5R
M(&MRYG9E="P@9F]R(&%T("(*(F1E:W)Y<'1E<F4@96X@8F5S:V5D+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)
M344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@HB
M16X@;V9F96YT;&EG(%,O34E-12UN^&=L92P@<&5R<V]N;&EG(%,O34E-12UN
M^&=L92!O9R!L^'-E;B!E<B!K<N9V970@9F]R(&%T("(*(G-I9VYE<F4@96X@
M8F5S:V5D+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,S8T(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U
M8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A
M9V4N(@IM<V=S='(@(D5N(&]F9F5N=&QI9R!3+TU)344M;OAG;&4@97(@:W+F
M=F5T(&9O<B!A="!K<GEP=&5R92!E;B!B97-K960N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO=61S
M(@IM<V=S='(@(D9O<FUI9&1A9R!3:WEE="(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN
M(@IM<V=S='(@(D9O<FUI9&1A9R!,970@4F5G;B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!32!286EN(@IM
M<V=S='(@(D9O<FUI9&1A9R!296=N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T
M<B`B1F]R;6ED9&%G($)Y9V5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G
M<W1R(")&;W)M:61D86<@4VYE8GEG97(B"@HC.B!T96UP;&%T97,O9&%T82]T
M:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@
M(D%022!)1"(*;7-G<W1R(")!4$D@240B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D
M:71O<B(*;7-G<W1R(")/;2!D96YN92!S:W)I8F5N="(*"B,Z('-E<G9I8V5S
M+VAE;'`O:6YD97@N<&AP.C4S"FUS9VED(")!8F]U="XN+B(*;7-G<W1R(")/
M;2XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R(")!8G-B;W1T;VTB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS
M9VED(")!8G-M:61D;&4B"FUS9W-T<B`B06)S;6ED9&QE(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C(W,"!L:6(O5D93+VUU<W%L+G!H<#HR
M-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B061G86YG(&[F9W1E="!V960@9&%N;F5L<V4@868@5D93
M+6MA=&%L;V<N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$S
M-B!L:6(O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@
M8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(D%D9V%N9R!NYF=T970@=F5D
M(&1A;FYE;'-E(&%F(%9&4RUF:6PN(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C,*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B2V]N
M=&\M:6YF;W)M871I;VXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@*
M;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B2V]N=&]E;G,@:V]D
M96]R9"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y,PHC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(DMO;G1O(&EN
M9&5F<F]S<V5T+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S4*
M;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`B2V]N=&5R:6YG+B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X(&QI8B](;W)D92]097)M
M<R]522YP:'`Z,30X"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-"!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B
M061D(@IM<V=S='(@(E1I;&;X:B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B
M"FUS9W-T<B`B5&EL9OAJ('5N9&5R9W)U<'!E(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.CDY"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z.3@@;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB
M"FUS9W-T<B`B5&EL9OAJ('5N9&5R;W)D;F5D92!T:6QL861E;'-E(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*
M;7-G<W1R(")4:6QF^&H@:&5R.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X
M(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM
M<V=S='(@(E1I;&;X:B!N>2!G<G5P<&4B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M.#@*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX-R!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS9W-T
M<B`B5&EL9OAJ(&YY(')E='1I9VAE9"(*"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O861D8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D
M(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(E1I;&;X:B!U;F1E
M<F=R=7!P92!T:6P@7"(E<UPB(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ-#<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-#<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S
M7"(B"FUS9W-T<B`B5&EL9OAJ(&5N('5N9&5R<F5T=&EG:&5D('1I;"!<(B5S
M7"(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S
M97(Z(@IM<V=S='(@(D]P<F5T=&4@96X@;GD@8G)U9V5R.B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-38*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-@IM<V=I9"`B061D(&-O
M;'5M;B(*;7-G<W1R(")4:6QF^&H@:V]L;VYN92(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,S0*;7-G:60@(D%D9"!N97<@;65M8F5R
M<R(*;7-G<W1R(")4:6QF^&H@;GEE(&UE9&QE;6UE<B(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@
M(D]P<F5T('!A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL
M82!3:61E8F%R(@IM<V=S='(@(E1I;&;X:B`E<RUM96YU96X@<V]M(&5N($UO
M>FEL;&$@4VED96)A<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HW,2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C<Q"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R(")4:6QF
M^&H@=&EL(&%D<F5S<V5K87)T;W1E:SHB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HW.`IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*
M;7-G<W1R(")4:6QF^&H@=&EL(&UI="!A9')E<W-E:V%R=&]T96LB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`B3W!R
M970@8G)U9V5R(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C
M;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B
M"B(E<RXB"FUS9W-T<B`B(@HB2&%R('1I;&;X:F5T(%PB)7-<(B!T:6P@<WES
M=&5M970L(&UE;B!K=6YN92!I:VME('1I;&;X:F4@96MS=')A("(*(F]P<VMR
M:79N:6YG<VEN9F]R;6%T:6]N.B`E<RXB"@HC.B!S:6=N=7`N<&AP.C0U"B,L
M('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M
M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(E1I;&;X:F5T(%PB)7-<
M(B!T:6P@<WES=&5M970N($1U(&MA;B!L;V=G92!I;F0@;G4N(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U
M<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B3W!R971T96QS92!A9B!B<G5G
M97)E(&5R('-LY65T(&9R82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#0Q(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3<S"FUS9VED(")!9&1R97-S(@IM<V=S='(@(D%D<F5S<V4B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30Q"FUS9VED(")!9&1R
M97-S($)O;VLB"FUS9W-T<B`B061R97-S96MA<G1O=&5K(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-38@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S0S,30N<&AP.C4V"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N
M<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B061M:6YI<W1RZ7(@+2!I;F1S
M=&EL('1I;&QA9&5L<V5R(&9O<B!A;F1R92!B<G5G97)E(@H*(SH@861M:6XO
M:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*
M;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<F%T:6]N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,PIM<V=I9"`B061S
M(@IM<V=S='(@(E)E:VQA;65R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!9F=H86YI<W1A
M;B(*;7-G<W1R(")!9F=H86YI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB86YI
M82(*;7-G<W1R(")!;&)A;FEE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW
M-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG97)I82(*
M;7-G<W1R(")!;&=E<FEE="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ,#<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(DMA;&1E;F%V;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@(D]P<W1I;&QI;F<B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED
M(")!;&EG;FUE;G0Z(@IM<V=S='(@(DIU<W1E<FEN9SHB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R(")!;&QE(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<#HR,#<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B
M06QL92#F9W1E9&4@8G)U9V5R92(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@
M861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T
M<B`B06QL92!G<G5P<&5R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HY,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U
M"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z.3$@;&EB+TAO<F1E+U!E<FUS
M+V1A=&%T<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S
M='(@(D%L;&4@=&EL;&%D96QS97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S
M:61E<R(*;7-G<W1R(")!;&QE(&9I<F4@<VED97(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#<Q(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<Q"FUS
M9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B5&EL;&%D
M(&UU;'1I<&QE(&%D<F5S<V5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4S.`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP
M93\B"FUS9W-T<B`B5&EL;&%D(&%N9VEV96QS92!A9B!O<F1N970@;&ES=&5T
M>7!E/R(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP
M.C4P-"!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HU,#0*;7-G:60@(D%L
M<F5A9'D@97AI<W1S(@IM<V=S='(@(D5K<VES=&5R97(@86QL97)E9&4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")!;'1E<FYA=&4@
M24U34"!,;V=I;B(*;7-G<W1R(")!;'1E<FYA=&EV($E-4U`M;&]G:6XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$Q"FUS9VED(")!;'1E<FYA=&4@
M24U34"!087-S=V]R9"(*;7-G<W1R(")!;'1E<FYA=&EV($E-4U`M:V]D96]R
M9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#,*;7-G:60@(D%L=&5R
M;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@(D%L=&5R;F%T:78@24U34"UB
M<G5G97)N879N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*
M;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(D1I;B!E
M+6UA:6PM861R97-S92(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS
M9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(D%L=&5R;F%T:79E
M('-K86)E;&]N97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*;7-G:60@(D%L=&5R;F%T92!T97AT
M.B(*;7-G<W1R(")!;'1E<FYA=&EV('1E:W-T.B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B
M06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B06UE<FEK86YS:R!386UO82(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ,34*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H
M<#HY-2!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL
M96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R(")$96X@=N9R9&DL
M(&1E<B!B;&5V(&%N9VEV970L('9A<B!I:VME(&=Y;&1I9RXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34U"FUS9VED(")!;B!U;FMN;W=N
M(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R(")$97(@97(@;W!S=.5E="!E
M;B!U:V5N9'0@9F5J;"XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%N9&]R<F$B"FUS9W-T
M<B`B06YD;W)R82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-"!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM<V=S='(@(D%N
M9V]L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,"!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B06YG=6EL
M;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY
M(@IM<V=S='(@(D%N;VYY;6ES97)E;F1E('!R;WAY(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R(")"
M97-V87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B4WED
M<&]L96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3D@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS
M9W-T<B`B06YT:6=U82!A;F0@0F%R8G5D82(*"B,Z(&%D;6EN+W!H<'-H96QL
M+G!H<#HS-B!A9&UI;B]T96UP;&%T97,N<&AP.C<T"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]522YP:'`Z-3@@;&EB+TAO<F1E+T)L;V-K+U5)+G!H<#HU
M.`HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED
M(")!<'!L:6-A=&EO;B(*;7-G<W1R(")!<'!L:6MA=&EO;B(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*
M;7-G<W1R(")!<'!L:6MA=&EO;G-L:7-T92(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G
M<W1R(")!<'!L:6MA=&EO;B!E<B!P87)A="XB"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S
M(@IM<V=S='(@(E#E9OAR('5N9&5R9&5L:6YG97(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G
M<W1R(")';V1K96YD(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#0R(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#(*;7-G
M:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`B0VER:V%S=/AR<F5L<V4B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#,*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-2!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL
M(@IM<V=S='(@(D%P<FEL(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*
M;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R(")!<F%B:7-K
M("A7:6YD;W=S+3$R-38I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C<X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C8@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C8*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S
M='(@(D%R:VEV+69I;'-T^')R96QS92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HW-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8U(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4X"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<W(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8U"FUS9VED(")!<F-H:79E($YA;64B"FUS
M9W-T<B`B07)K:79N879N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U
M('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F
M;W(@)7,@/R(*;7-G<W1R(")%<B!D=2!S:6MK97(@<.4L(&%T(&1U('9I;"!S
M;&5T=&4@;W!S:W)I=FYI;F=S86YM;V1N:6YG96X@9F]R("5S(#\B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB
M)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(D5R(&1U('-I:VME
M<BP@870@9'4@^&YS:V5R(&%T('-L971T92!<(B5S7"(@;V<@96YH=F5R('5N
M9&5R9W)U<'!E/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@
M(D%R9V5N=&EN82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI82(*;7-G<W1R(")!
M<FUE;FEE;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")!
M<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R(")!<FUE;G-K("A!4DU30TE)
M+3@I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B
M"FUS9W-T<B`B2W5N<W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S`@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S='(@
M(D%R=6)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-2!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B
M"FUS9W-T<B`B07-C96YS:6]N^&5N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B05-#24D@07)T(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM
M<V=S='(@(D%S:6%T:7-K+W-T:6QL96AA=G-R96=I;VXB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#(Y"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO
M;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T
M<B`B4W#X<F<@969T97(@8F5K<N9F=&5L<V4@9OAR('5D9OAR96QS92!A9B!V
M961L:6=E:&]L9&5L<V5S:&%N9&QI;F=E<C\B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,#DU(&QI8B](;W)D92]&;W)M+G!H<#HS,#DU"FUS9VED
M(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`B5&EL9&5L(&MO;&]N;F5R
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(D9O<G/X9R!P
MY2!A="!S;&5T=&4@96X@:6MK92UE:W-I<W1E<F5N9&4@9W)U<'!E+B(*"B,Z
M(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@
M9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(D9O
M<G/X9R!PY2!A="!S;&5T=&4@96X@:6MK92UE:W-I<W1E<F5N9&4@=&EL;&%D
M96QS92XB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T
M96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S
M='(@(D9O<G/X9R!PY2!A="#F;F1R92!E;B!I:VME+65K<VES=&5R96YD92!T
M:6QL861E;'-E+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM
M<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*
M;7-G<W1R(")&;W)S^&<@<.4@870@YFYD<F4@96X@:6MK92UE:W-I<W1E<F5N
M9&4@9&5L:6YG+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8T"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]T9WHN<&AP.C@S(&QI8B](;W)D92]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<Q"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(D%T=')I8G5T
M=&5R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0W"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!
M=6=U<W0B"FUS9W-T<B`B075G=7-T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L
M:6$B"FUS9W-T<B`B075S=')A;&EE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')I
M82(*;7-G<W1R("+8<W1R:6<B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G-Q;"YP:'`Z,38X(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS
M9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G-Q;#H@2W+F=F5T($E-05`M=61V
M:61D96QS92!I:VME(&9U;F1E="XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HQ,S4@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$S-0IM
M<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I
M<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!"86-K96YD
M(&AA<B!I:VME(&1E(&[X9'9E;F1I9V4@979N97(N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R(&QI8B](;W)D92]!=71H+V-Y<G5S
M+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)U<SH@2W+F=F5T
M($E-05`M=61V:61D96QS92!I:VME(&9U;F1E="XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V9T<"YP:'`Z,S8@;&EB+TAO<F1E+T%U=&@O9G1P+G!H<#HS
M-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F
M='`@<W=I=&-H+B(*;7-G<W1R("(B"B)!=71H7V9T<#H@2W+F=F5T($944"UU
M9'9I9&1E;'-E(&EK:V4@9G5N9&5T+B!/=F5R<^9T(%!(4"!M960@+2UE;F%B
M;&4M9G1P+2(*(F9L86=E="XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM
M87`N<&AP.C8T(&QI8B](;W)D92]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!
M=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B075T:%]I;6%P.B!+<N9V970@24U!4"UU9'9I9&1E;'-E(&EK
M:V4@9G5N9&5T+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z
M-3$@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B
M-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!=71H7VMR8C4Z($MRYG9E="!+4D(U+75D=FED9&5L<V4@:6MK92!F=6YD
M970N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,#(@;&EB
M+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD87`Z($%D
M9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T
M;W)Y(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@5&EL9OAJ96QS92!B<G5G97)E
M(&5R(&EK:V4@=6YD97)S=/AT=&5T(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS-3<@;&EB+TAO<F1E
M+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB
M"FUS9W-T<B`B(@HB075T:%]L9&%P.B!3;&5T;FEN9R!A9B!B<G5G97)E(&5R
M(&EK:V4@=6YD97)S=/AT=&5T('9E9"!!8W1I=F4@1&ER96-T;W)Y(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HV,R!L:6(O2&]R9&4O075T
M:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;&1A<#H@2W+F
M=F5T($Q$05`M=61V:61D96QS92!I:VME(&9U;F1E="XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C,S.2!L:6(O2&]R9&4O075T:"]L9&%P
M+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B
M;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60Z("(*;7-G<W1R(")!=71H7VQD87`Z($MU;FYE(&EK:V4@=&EL9OAJ92!B
M<G5G97(@)7,N(%-E<G9E<F5N('-A9V1E.B`B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C,X-2!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS
M.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@
M<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!+86X@:6MK92!S
M;&5T=&4@8G)U9V5R("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HT.3D@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF
M;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R
M("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@2V%N(&EK:V4@;W!D871E<F4@8G)U
M9V5R("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,#4@
M;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z
M(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$
M:7)E8W1O<GDN(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@3W!D871E<FEN9R!A
M9B!B<G5G97)E(&5R(&EK:V4@=6YD97)S=/AT=&5T('9E9"!!8W1I=F4@1&ER
M96-T;W)Y+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-#8@
M;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@
M4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!
M=71H7VUC86PZ($MRYG9E="!-0T%,+75D=FED9&5L<V4@:6MK92!F=6YD970N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C8P(&QI8B](;W)D
M92]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER
M960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H
M7W-M8F%U=&@Z($MRYG9E="!334)!551(+75D=FED9&5L<V4@:6MK92!F=6YD
M970N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!9&UI;BYP:'`Z,3`V(&QI
M8B](;W)D92])34%0+T%D;6EN+G!H<#HQ,#8*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`BQF=T;FEN9R!V
M960@24U!4"US97)V97(@9F5J;&5D92XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I8V%T:6]N
M(&9A:6QE9"(*;7-G<W1R("+&9W1N:6YG(&9E:FQE9&4B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R("+&9W1N:6YG(&9E
M:FQE9&4N("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP
M.C$W-B!L:6(O2&]R9&4O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B075T
M:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T
M<B`BQF=T;FEN9R!A9G9I<W0@868@4D%$2553+7-E<G9E<BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C@X,B!L:6(O5D93+V9T<"YP:'`Z.#@R
M"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB
M"FUS9W-T<B`BQF=T;FEN9R!O=F5R9F]R($944"US97)V97(@9F5J;&5D92XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P(&QI8B]61E,O<VUB
M+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V
M97(@9F%I;&5D+B(*;7-G<W1R("+&9W1N:6YG(&]V97)F;W(@4TU"+7-E<G9E
M<B!F96IL961E+B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*
M;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(D9E;'1E<B!T:6P@
M<N5D:6=H960Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,Q(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@
M(D%S97)B86ED:F%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS
M9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B0D]&2"UU;F1S:WEL9&YI;F=E
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B0F%C:V=R;W5N
M9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B0F%G9W)U;F1S
M9F%R=F4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@Q(&QI
M8B](;W)D92]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R8F5R;W,@
M<&%S<W=O<F0N(@IM<V=S='(@(D3E<FQI9W0@:V5R8F5R;W,M:V]D96]R9"XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S(&QI8B](;W)D
M92]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA
M;64N(@IM<V=S='(@(D3E<FQI9W0@:V5R8F5R;W,M8G)U9V5R;F%V;BXB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#4@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C(*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B0F%H86UA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C,X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q
M"FUS9VED(")"86AR86EN(@IM<V=S='(@(D)A:')A:6XB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB
M"FUS9W-T<B`B0F%L=&EK=6T@*$E33RTX.#4Y+3$S*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HS-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I
M9"`B0F%N9VQA9&5S:"(*;7-G<W1R(")"86YG;&%D97-H(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C,S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS
M9VED(")"87)B861O<R(*;7-G<W1R(")"87)B861O<R(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R
M87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")"
M87-I<R!G<F%F:6MK871A;&]G(%PB)7-<(B!I:VME(&9U;F1E="XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*
M;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(D)A<VES;&EN:64B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-#D@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*
M;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B2'9I9&5R=7-L86YD(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C,U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P
M"FUS9VED(")"96QG:75M(@IM<V=S='(@(D)E;&=I96XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-3`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G
M:60@(D)E;&EZ92(*;7-G<W1R(")"96QI>F4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-#`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E
M;FEN(@IM<V=S='(@(D)E;FEN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0Q
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM
M<V=S='(@(D)E<FUU9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HS-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#8@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R
M(")":'5T86XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3$Q"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R(")&^&1S96QS9&%G(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,V-R!L:6(O
M2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S8W"B,L('!H<"UF;W)M870*
M;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T
M(&9O=6YD+B(*;7-G<W1R(")";&]K(%PB)7-<(B!A9B!A<'!L:6MA=&EO;B!<
M(B5S7"(@:6MK92!F=6YD970N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC.CDP"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R(")";&]K
M+65G96YS:V%B97(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B0FQO:W1Y<&4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@
M(D)O;&0B"FUS9W-T<B`B1F5D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0S
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM
M<V=S='(@(D)O;&EV:65N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(P-PIM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(D)O9VWF<FME<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C`*;7-G:60@(D)O<F1E<B(*;7-G<W1R(")286YD(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R
M('1H:6-K;F5S<SHB"FUS9W-T<B`B4F%M;65T>6MK96QS93HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Q"FUS
M9VED(")";W)D97)S(@IM<V=S='(@(E)A;F1E(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C,R(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"
M;W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(D)O<VYI96X@;V<@2&5R
M>F5G;W9I;F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@
M(D)O=&@B"FUS9W-T<B`B0F5G9V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-#@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA
M(@IM<V=S='(@(D)O='-V86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(R"FUS9VED(")";W1T;VTB"FUS9W-T
M<B`B0G5N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C,Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-R!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R
M(")";W5V973X96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HT,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#0@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R87II;"(*;7-G<W1R(")"
M<F%S:6QI96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-R!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E
M86X@5&5R<FET;W)Y(@IM<V=S='(@(D)R:71I<VLM26YD:65N($]C96%N;VUR
MY61E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0R(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8R"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R
M(")"<G5N96D@1&%R=7-S86QA;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C0S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS
M-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B
M"FUS9W-T<B`B0G5L9V%R:65N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G
M<W1R(")0=6YK=&QI<W1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,V(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B
M"FUS9W-T<B`B0G5R:VEN82!&87-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C,Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U;F1I
M(@IM<V=S='(@(D)U<G5N9&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#0V"FUS9VED(")#35,B"FUS9W-T<B`B0TU3(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-2!L:6(O2&]R9&4O34E-12]6
M:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-20R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DX(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3DX"FUS9VED(")#4DP@1&ES=')I8G5T:6]N
M(%!O:6YT<R(*;7-G<W1R(")#4DP@9&ES=')I8G5T:6]N<W-T961E<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")#96QL
M92UE9V5N<VMA8F5R+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$U,0IM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB
M"FUS9W-T<B`B26YI=&EA;&ES97)I;F<@868@;6ED;&5R=&ED:6=T(&QA9V5R
M(&EK:V4@9N9R9&EG9VIO<G0N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0X-2!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDQ-@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDQ-B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@U"B,Z(&-O;F9I9R]H;V]K<RYP:'`N
M9&ES=#HQ,#0P(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-3<*;7-G:60@
M(D-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9&5R(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B0V%L;2(*;7-G<W1R(")6:6YD
M<W1I;&QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C0V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C@@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(DMA
M;6)O9&EA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8P(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8W"FUS9VED(")#86UE<F]O;B(*;7-G<W1R(")#86UE
M<F]U;B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED
M(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A
M8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")+86X@:6MK92!N=6QS
M=&EL;&4@:V]D96]R9"!A=71O;6%T:7-K.R!K;VYT86MT(&1I;B!A9&UI;FES
M=')A=&]R+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,U,"!L
M:6(O1FEL92]#4U8N<&AP.C,U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86X@
M;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(DMA;B!I:VME('-K
M<FEV92!T:6P@9FEL(%PB)7-<(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR
M,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA
M;F1L97)S+B(*;7-G<W1R(")+86X@:6MK92!HY6YD=&5R92!E:W-T97)N92!S
M97-S:6]N<VCE;F1T86<N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S
M<6PN<&AP.C,Q.2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,S4*
M(SH@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HS,3D@;&EB+TAO<F1E+T%U
M=&@O8WER=7,N<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C
M;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R(")+86X@:6MK92!F
M;W)B:6YD92!T:6P@24U!4"!S97)V97(N("5S(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z-#0V(&QI8B]&:6QE+T-35BYP:'`Z-#0V"B,L('!H
M<"UF;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(DMA;B!I:VME(.5B;F4@9FEL(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-3$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@
M(D-A;F%D82(*;7-G<W1R(")#86YA9&$B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV-2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A
M<BYI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ
M,B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$*;7-G:60@
M(D-A;F-E;"(*;7-G<W1R(")!;FYU;&QE<B(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O
M<G0B"FUS9W-T<B`B069B<GED(')E<&]R=&5R:6YG(&%F('!R;V)L96TB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,R,R!L:6(O5D93+V9T<"YP
M:'`Z,S(S"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(DMA;B!I:VME('-L971T92!F:6P@7"(E<UPB
M+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C0V"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C
M;W!Y+G!H<#HU,@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HT-@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A
M<GD@9&ER96-T;W)Y+B(*;7-G<W1R(")+86X@:6MK92!F:6YD92!E="!M:61L
M97)T:61I9W0@:V%T86QO9RXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(N<&AP.CDQ(&QI8B]61E,O25-/5W)I=&5R+G!H<#HY,0IM
M<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R
M86UE=&5R+B(*;7-G<W1R(")+86X@:6MK92!F;W)T<^9T=&4@=61E;B`G=&%R
M9V5T1FEL92<M<&%R86UE=')E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,Q.2!L:6(O5D93+V9T<"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T
M<B`B2V%N(&EK:V4@9FIE<FYE(&MA=&%L;V<@7"(E<UPB+B(*"B,Z(&9R86UE
M=V]R:R]$871A5')E92]$871A5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$871A
M5')E92]$871A5')E92]S<6PN<&AP.C8X,`HC.B!L:6(O2&]R9&4O1&%T851R
M964N<&AP.C$R."!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HV.#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@
M97AI<W0N(@IM<V=S='(@(DMA;B!I:VME(&9J97)N92P@)60@8OAR;B!E:W-I
M<W1E<F5R+B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN
M<&AP.C8P."!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@
M(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE
M9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D
M+B(*;7-G<W1R("(B"B)+86X@:6MK92!O;69O<F1E;&4[(&%N=&%L;&5T(&%F
M('!U;FMT97(@86YG:79E="!T:6P@;VUF;W)D96QI;F<@<W9A<F5R(&EK:V4@
M(@HB=&EL(&1E="!O<&)E=F%R961E(&%N=&%L+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O
M=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B2V%N
M(&EK:V4@9&ER:6=E<F4@8F5S:V5D('1I;"!A;F=I=FYE(&YU;6UE<BXB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C4@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B2V%P(%9E<F1E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R(")":6QL961T96MS="(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-"!L
M:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE
M<B(*;7-G<W1R(")59&)Y9&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDS"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B2V%T
M96=O<FEE<B!O9R!-YG)K97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S
M-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES
M;&%N9',B"FUS9W-T<B`B0V%Y;6%N^&5R;F4B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE(@IM<V=S
M='(@(DUO8FEL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S
M='(@(D-E;&QE+65G96YS:V%B97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*
M;7-G<W1R(")#96QL969O<G)I;F<Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P
M97)T:65S(@IM<V=S='(@(D-E;&QE+65G96YS:V%B97(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L
M;"!S<&%C:6YG.B(*;7-G<W1R(")#96QL92UM96QL96UR=6TZ(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W-"!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3(W-`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(DUO8FEL=&5L969O;B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#96QT:6,@*$E3
M3RTX.#4Y+3$T*2(*;7-G<W1R(")+96QT:7-K("A)4T\M.#@U.2TQ-"DB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(V"FUS9VED(")#96YT97(B"FUS9W-T<B`B0V5N='+I<B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HU-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-0IM
M<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(D1E;B!C
M96YT<F%L869R:6MA;G-K92!297!U8FQI:R(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@R"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR
M*2(*;7-G<W1R(")#96YT<F%L+65U<F]PYFES:R`H25-/+3@X-3DM,BDB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,"!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T
M86EL<R(*;7-G<W1R(")#97)T:69I:V%T+61E=&%L:F5R(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3(@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV,3(*;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S
M='(@(D-E<G1I9FEK870M96IE<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DW(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DW
M"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R(")#97)T:69I
M:V%T+7!O;&ET:6MK97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C4R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C$@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")#:&%D(@IM<V=S
M='(@(E1C:&%D(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B0VAA;F=E
M(@IM<V=S='(@(L9N9')E(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C,Q"FUS9VED(")#:&%N9V4@66]U<B!087-S=V]R9"(*;7-G<W1R("+&
M;F1R92!D:70@:V]D96]R9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M.0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@
M<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B
M"B)E;6%I;',N(@IM<V=S='(@(B(*(DAE<B!K86X@9'4@YFYD<F4@9&5T(&YA
M=FX@;V<@9&5N(&%D<F5S<V4L('-O;2!A;F1R92!S97(L(&[E<B!D92!LYG-E
M<B!O9R`B"B)S=F%R97(@<.4@9&EN92!E+6UA:6PN(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN9R!Y;W5R
M('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C
M;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(B(*(DMO9&5O<F1SYFYD<FEN9R!E<B!I:VME('5N9&5R<W3X
M='1E="!A9B!D96X@;G5VYG)E;F1E(&]P<^9T;FEN9RX@($MO;G1A:W0@(@HB
M9&EN(&%D;6EN:7-T<F%T;W(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA<B(*;7-G<W1R
M(")496=N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R
M(")(86L@;&EN:R!A9BXN+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C4S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU.2!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;&4B"FUS9W-T
M<B`B0VAI;&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HU-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C$@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@(DMI;F$B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0VAI;F5S92!3
M:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(E-I;7!L:69I8V5R970@:VEN
M97-I<VL@*$=",C,Q,BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM
M<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B5')A
M9&ET:6]N96QT(&MI;F5S:7-K("A":6<U*2(*"B,Z('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C<*;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB"FUS9W-T
M<B`B5N9L9R!A<'!L:6MA=&EO;CHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,C<P(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C<P
M"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R(")6YFQG(&5T(&MO
M9&5O<F0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y
M(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@
M82!U<V5R;F%M92(*;7-G<W1R(")6YFQG(&5T(&)R=6=E<FYA=FXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`R"FUS9VED(")#:&]O<V4@:&]W('1O
M(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(E;F;&<@:'9O<F1A;B!D871O97(@
M<VMA;"!V:7-E<SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL
M92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B5N9L9R!L:7-T
M92US=&EL("AF;W(@;W)D;F5D92!L:7-T97(I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C8V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#
M:')I<W1M87,@27-L86YD(@IM<V=S='(@(DIU;&7X96XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z.3$T(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z
M,CDT(&QI8B]61E,N<&AP.CDQ-`HC.B!L:6(O3F5T+U--4RYP:'`Z,CDT"B,L
M('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T
M(&9O=6YD+B(*;7-G<W1R(")+;&%S<V5D969I;FET:6]N(&%F("5S(&EK:V4@
M9G5N9&5T+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$T"FUS9VED(")#;&5A<B(*;7-G<W1R(")+;&%R="(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L
M96%R($U33V9F:6-E('1A9W,B"FUS9W-T<B`B1FIE<FX@35-/9F9I8V4M;W!M
MYG)K;FEN9V5R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.0IM<V=I9"`B
M0VQE87(@475E<GDB"FUS9W-T<B`B3G5L<W1I;"!F;W)E<W#X<F=S96PB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B4F5N<R!B
M<G5G97(@=60Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N
M:6YC.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(DYU;'-T:6P@8G)U
M9V5R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G
M:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R(")6:7-K(&)R=6=E<F1A=&$@
M=60B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R(")396X@;W!K;&%R:6YG
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(DML:6L@9F]R
M(&%T(&9O<G1SYG1T92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$X-`HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G
M<W1R(")#;&EC:V%T96QL('9I82!(5%10(@H*(SH@<V5R=FEC97,O:V5Y8F]A
M<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED
M(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B3'5K('9I;F1U92(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C4Q"FUS9VED(")#;&]U9',B"FUS9W-T<B`B4VMY
M97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M-@IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(E-K>65R('1I9&QI9W0B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PIM
M<V=I9"`B0VQO=61Y(@IM<V=S='(@(E-K>65T(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C4R(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#
M;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R(")#;V-O<R`H2V5E;&EN
M9RD@V&5R;F4B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S
M"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(D9O;&0@<VED97!A
M;F5L('-A;6UE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM
M<V=S='(@(E-A;6UE;F9O;&1E9&4@<F%N9&4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-C(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O
M;&]M8FEA(@IM<V=S='(@(DMO;'5M8FEE;B(*"B,Z(&QI8B]";&]C:R]C;VQO
M<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#
M;VQO<B(*;7-G<W1R(")&87)V92(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HU,#,*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+T-O;&QE8W1I;VXN<&AP.C,S.`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M0V]L;&5C=&EO;BYP:'`Z,S,Y"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HU,#,@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP
M.C,S.`HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,Y('-E
M<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R
M(%!I8VME<B(*;7-G<W1R(")&87)V97;F;&=E<B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(X,C@@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,C@*;7-G
M:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B1F%R=F5V86QG(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G
M:60@(D-O;',Z(@IM<V=S='(@(DMO;',Z(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DT-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DT-@IM<V=I9"`B
M0V]L=6UN('1I=&QE<R(*;7-G<W1R(")+;VQO;FYE=&ET;&5R(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-@IM<V=I9"`B0V]M:6-S(@IM<V=S
M='(@(E1E9VYE<V5R:65R(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(V"FUS
M9VED(")#;VUM86YD(@IM<V=S='(@(DMO;6UA;F1O(@H*(SH@861M:6XO8VUD
M<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(DMO
M;6UA;F1O;&EN:64B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3,@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")#;VUM
M96YT(@IM<V=S='(@(DMO;6UE;G1A<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-38W(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-38W"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R(")#;VUM;VX@3F%M92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU.`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,P(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(D-O;6]R97)N92(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@
M(D-O;7!A;GDB"FUS9W-T<B`B1FER;6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R(")#;VUP=71E<F4B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@V"FUS9VED(")#
M;VYD:71I;VXB"FUS9W-T<B`B1F]R:&]L9"(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C4V"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(D)E=&EN9V5L
M<V5R(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I
M9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B2V]N9FEG=7)A=&EO;G-F
M;W)S:V5L;&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED
M(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P
M:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(DMO;F9I9W5R871I;VX@=&EL
M('-Y;FMR;VYI<V5R:6YG(&UE9"!01$%E<BP@4VUA<G1P:&]N97,@;V<@3W5T
M;&]O:RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,U"FUS9VED(")#
M;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R(")+;VYF:6=U
M<F%T:6]N96X@97(@9F]RYFQD970N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS
M9W-T<B`B2V]N9FEG=7+I<B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T
M<B`B0F5K<N9F="!K;V1E;W)D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4U
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G
M<W1R(")+;VYG;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C8P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,R!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A
M=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R(")+;VYG;RP@1&5N(&1E;6]K
M<F%T:7-K92!R97!U8FQI:R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$Y-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS,#@@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C$Y-PHC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`X"FUS
M9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`B1F]R8FEN9&5L<V4@
M;6ES;'EK:V5D97,N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,3DW"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,P."!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#@*;7-G:60@
M(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B1F]R8FEN9&5L<V4@;6ES
M;'EK:V5D97,Z("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C<Y,"!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE
M8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T
M<B`B1F]R8FEN9&5L<V4@=&EL(&]F9F5N=&QI9R!N^&=L97-E<G9E<B!NYF=T
M970N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDR(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N
M(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R(")&;W)B:6YD96QS92!T:6P@;V9F
M96YT;&EG(&[X9VQE<V5R=F5R(&[F9W1E="X@Q7)S86<Z("5S("@E<RDB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@W-B!L:6(O5D93+V9T<"YP
M:'`Z.#<V"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D
M+B(*;7-G<W1R(")&;W)B:6YD96QS92!T:6P@1E10+7-E<G9E<B!M:7-L>6MK
M961E<RXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR-"!L:6(O
M2&]R9&4O2V]L86(N<&AP.CDR-`HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z
M,3`V-PIM<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`B2V]N=&%K=&5R(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4S(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S
M('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+B(*;7-G<W1R(")+;VYT86MT97(@8FQE=B!T:6QF^&IE="!T:6P@9&ET(&%D
M<F5S<V5K87)T;W1E:V5T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HV,"!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HV
M,`IM<V=I9"`B0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@(@IM
M<V=S='(@(DEN9&AO;&1S='EP92!A9B!K;VUP<FEM97)E="!F:6PZ("(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW-0HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S(&QI8B](;W)D92]-24U%+U9I
M97=E<B]R87(N<&AP.C4V"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN
M<&AP.C<U(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R("))
M;F1H;VQD(&%F(%PB)7-<(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B
M0V]N=&EN=64B"FUS9W-T<B`B1F]R='/F="(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HU."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]O
M:R!)<VQA;F1S(@IM<V=S='(@(D-O;VL@27-L86YD<R(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(E-MY6MA
M9V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B2V]P:65R(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-S(@;&EB+U9&4R]S;6(N<&AP
M.C0W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B2V]P:65R:6YG(&UI<VQY:VME9&5S.B`E<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@
M<V5L96-T:6]N(@IM<V=S='(@(DMO<&GI<B!M87)K97)I;F<B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-2!L:6(O3F5T+U--4R]W
M:6Y?:'1T<"YP:'`Z,3<P"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ
M.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B1V5B>7(@240B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-C,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*
M;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B0V]S=&$@4FEC82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HU-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R(")%;&9E;F)E;G-K>7-T
M96XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S<@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3<W"FUS9VED(")#;W5L9"!N;W0@4$=0
M(&5N8W)Y<'0@;65S<V%G93H@(@IM<V=S='(@(DMU;FYE(&EK:V4@4$=0+6MR
M>7!TZ7)E(&)E<VME9#H@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3`U-2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#4U"FUS9VED
M(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@(@IM<V=S='(@(DMU;FYE
M(&EK:V4@4$=0+7-I9V[I<F4@8F5S:V5D.B`B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A
M9V4N(@IM<V=S='(@(DMU;FYE(&EK:V4@4R]-24U%+6MR>7!T97)E(&)E<VME
M9"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-R!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T
M(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(DMU;FYE(&EK:V4@4R]-
M24U%+7-I9V[I<F4@8F5S:V5D+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R(")+=6YN92!I:VME('1I;&;X
M:F4@:V]N=&%K="X@)7,B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ,C$*(SH@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.CDV(&QI8B](;W)D92]!=71H+VQD
M87`N<&AP.C$R,0HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#@R"FUS9VED
M(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B2W5N
M;F4@:6MK92!K;V)L92!T:6P@3$1!4"US97)V97(N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(DMU;FYE(&EK
M:V4@:V]N=')O;&QE<B!B86QA;F-E+B`E<R(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HT-C8*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@
M<V5R=F5R+B(*;7-G<W1R(")+=6YN92!I:VME(&9O<F)I;F1E('1I;"!,1$%0
M+7-E<G9E<BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB
M)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@9F]R8FEN
M9&4@=&EL('-E<G9E<B!<(B5S7"(@=F5D(&)R=6<@868@1E10.B`E<R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!O<')E='1E(&1I<W1R:6)U
M=&EO;G-L:7-T92X@)7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HQ,3(X(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q,C@*;7-G:60@
M(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B`B"FUS9W-T<B`B2W5N;F4@
M:6MK92!D96MR>7!T97)E(%!'4"UD871A.B`B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4R,R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4R,PIM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N
M(@IM<V=S='(@(DMU;FYE(&EK:V4@9&5K<GEP=&5R92!3+TU)344M9&%T82XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C(T-@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@
M)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!S;&5T=&4@:V]N=&%K="X@)7,B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U
M-@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@<VQE='1E(&1I<W1R:6)U
M=&EO;G-L:7-T92X@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P
M('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B2W5N;F4@:6MK92!S
M;&5T=&4@/&5M/G-C<FEP=#PO96T^(%PB)7-<(B!T:6P@;W!G<F%D97)I;F<@
M868@;W!SYG1N:6YG+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.CDU,R!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X,0HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,X,2!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE
M(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R(")+=6YN92!I
M:VME(&)E<W1E;6UE(&UO9'1A9V5R96YS(&4M;6%I;"UA9')E<W-E+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G:60@
M(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S
M='(@(DMU;FYE(&EK:V4@:&5N=&4@:&5L92!A9')E<W-E:V%R=&]T96LN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT
M.3,*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I
M9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T
M+B(*;7-G<W1R(")+=6YN92!I:VME(&AE;G1E(&AE;&4@9&ES=')I8G5T:6]N
M<VQI<W1E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-#0V"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES
M="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(DMU;FYE(&EK:V4@
M:&5N=&4@9G5L9'-TYFYD:6<@9F]R=&5G;F5L<V4@;W9E<B!D:7-T<FEB=71I
M;VYS;&ES=&5R+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z
M-C@*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H
M<#HV.`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP
M:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R
M871E9WD@7"(E<UPB+B(*;7-G<W1R(")+=6YN92!I:VME(&AE;G1E('-T<F%T
M96=I(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C$Q,`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T
M<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC.B!L:6(O5D93+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B2W5N
M;F4@:6MK92!M:V1I<B!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-S$Y(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<Q.0IM
M<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME
M>7-E<G9E<BXB"FUS9W-T<B`B2W5N;F4@:6MK92!H96YT92!O9F9E;G1L:6<@
M;OAG;&4@9G)A(&[X9VQE<V5R=F5R+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ
M,SD*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N
M(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B2W5N;F4@:6MK92#E8FYE
M(%PB)7-<(B!F;W(@<VMR:79N:6YG+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(V,B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S0U(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@
M(DMU;FYE(&EK:V4@Y6)N92`E<RXB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N
M8V4O36%I;G1E;F%N8V4N<&AP.C0R,"!L:6(O2&]R9&4O36%I;G1E;F%N8V4N
M<&AP.C0R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-
M86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R(")+=6YN92!I:VME
M(.5B;F4@;6]D=6P@=&EL('9E9&QI9V5H;VQD96QS92`E<R(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HW,`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")+=6YN92!I
M:VME(.5B;F4@:V%T86QO9R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR
M,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-CDY"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ,3$@;&EB+TAO<F1E
M+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP
M:'`Z,C,W(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.C4Q-B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP
M:'`Z-C$R"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV-38@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.C8Y.0IM<V=I9"`B0V]U;&0@;F]T(')E86-H
M('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B2W5N;F4@:6MK92!NY2!,1$%0
M+7-E<G9E<F5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B:F5C="YP:'`Z
M,C0P(&QI8B]61E,O3V)J96-T+G!H<#HR-#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(DMU;FYE(&EK:V4@;.9S
M92`E<RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I
M9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E
M<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A
M<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M
M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S
M='(@(B(*(DMU;FYE(&EK:V4@;G5L<W1I;&QE(&MO9&5O<F1E="!F;W(@9&5N
M(&%N;6]D961E(&)R=6=E<BX@($YO9VQE(&5L;&5R(&%L;&4@(@HB9&5T86QJ
M97(@97(@=6MO<G)E:W1E+B!0<OAV(&EG96X@96QL97(@:V]N=&%K="!D:6X@
M861M:6YI<W1R871O<BP@:'9I<R!D=2`B"B)H87(@8F5H;W8@9F]R('ED97)L
M:6=E<F4@:&KF;'`N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S`W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,S.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS-S4*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S@Q"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,X-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`W"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,S@@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,W-0HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S@Q(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS.#<*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B
M2W5N;F4@:6MK92!H96YT92!!0TPB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(DMU;FYE
M(&EK:V4@:&5N=&4@861R97-S96MA<G1O=&5K970N("5S(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@:&5N=&4@9&ES=')I8G5T:6]N<VQI
M<W1E+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-#,W"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!H
M96YT92!D:7-T<FEB=71I;VYS;&ES=&5R+B`E<R(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3<*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(Q(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ.3<*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C(Q-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(Q"FUS
M9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S
M(@IM<V=S='(@(DMU;FYE(&EK:V4@:&5N=&4@<V5R=F5R<R!E=FYE<B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!R
M979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2W5N;F4@:6MK92!G96YD
M86YN92!K;VYF:6=U<F%T:6]N+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC
M.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E
M<UPB+B(*;7-G<W1R(")+=6YN92!I:VME(')M9&ER(%PB)7-<(BXB"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")+
M=6YN92!I:VME(&=E;6UE("5S+6MO;F9I9W5R871I;VXB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*
M;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB
M"FUS9W-T<B`B2W5N;F4@:6MK92!G96UM92!E;B!B86-K=7`M:V]N9FEG=7)A
M=&EO;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T
M:6]N.B`E<R(*;7-G<W1R(")+=6YN92!I:VME(&=E;6UE(&5N(&)A8VMU<"UK
M;VYF:6=U<F%T:6]N.B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P
M('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(DMU;FYE(&EK
M:V4@9V5M;64@<V-R:7!T('1I;"!O<&=R861E<FEN9R!A9B!O<'/F=&YI;F<@
M=&EL.B!<(B5S7"(N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P
M(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B2W5N;F4@:6MK92!G
M96UM92!B86-K=7`M:V]N9FEG=7)A=&EO;G-F:6QE;B`E<RXB"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO
M=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V
M92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O
M9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*(DMU;FYE(&EK:V4@9V5M;64@
M:V]N9FEG=7)A=&EO;G-F:6QE;B`E<RX@1'4@:V%N(&5N=&5N(&%N=F5N9&4@
M96X@868@(@HB;75L:6=H961E<FYE(&9O<B!A="!G96UM92!K;V1E;B!T:6QB
M86=E('#E("5S(&5L;&5R(&UA;G5E;'0@:V]P:65R92!K;V1E;B`B"B)N961E
M;F9O<B!T:6P@)7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HQ-#,@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L
M9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B2W5N;F4@
M:6MK92!S^&=E($Q$05`M<V5R=F5R96XN(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C@V"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C@V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI
M;FL@7"(E<UPB+B(*;7-G<W1R(")+=6YN92!I:VME(#QE;3YU;FQI;FL\+V5M
M/B!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HR,3D*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E
M(&-O;G1A8W0N("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@;W!D871E<F4@:V]N
M=&%K="X@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C,Y-@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@;W!D
M871E<F4@9&ES=')I8G5T:6]N<VQI<W1E+B`E<R(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R(")+
M=6YN92!I:VME('-K<FEV92!K;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W,`IM<V=I9"`B0V]U;&1N
M)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I
M9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B2W5N;F4@:6MK92!F:6YD92!-;WII
M;&QA(%-I9&5B87(N($9O<G9I<R!D:6<@;VT@870@<VED96)A<F5N(&5R(.5B
M96XN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,34T(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T
M:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S
M(@IM<V=S='(@(B(*(DMU;FYE(&EK:V4@9VEV92!B<G5G97(@7"(E<UPB(&;X
M;&=E;F1E(')E='1I9VAE9&5R('1I;"!M87!P96X@7"(E<UPB.B`E<R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3D@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$T,3D*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R(")/<'1A;'0@
M=&5K<W0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M,"!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B0V]U;G1R
M>2(*;7-G<W1R("),86YD(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(W-0IM<V=I9"`B0V]U<G-E<R(*;7-G<W1R(")+=7)S97(B"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ
M,#`*;7-G:60@(D-R96%T92(*;7-G<W1R(")/<')E="(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I
M9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R(")/<')E="!E;B!H96YV:7-N:6YG
M(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY-`IM
M<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R(")/<')E="!E;B!N>2(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4R(&QI8B](
M;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU,@HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R
M<R(*;7-G<W1R(")/<')E="!U;F1E<FUA<'!E(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HR-#`@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR
M-#`*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4VMA8F5R
M<R!R971T:6=H961E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M,3(@;&EB+TAO<F1E+T9O<FTN<&AP.C,R,3(*;7-G:60@(D-R961I="!C87)D
M(&YU;6)E<B(*;7-G<W1R(")+<F5D:71K;W)T+6YU;6UE<B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3`Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y
M"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(DMR;V%T:65N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C8T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#=6)A(@IM<V=S='(@(D-U8F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,C8*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B3G5VYG)E
M;F1E(#0@9F%S97(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*;7-G:60@
M(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`B26YD97;F<F5N9&4@<V5S<VEO
M;B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H
M<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(D%K='5E;"!T:60B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(DYU=N9R
M96YD92!54DP@97(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*;7-G:60@
M(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`B3G5VYG)E;F1E(&)R=6=E<F4B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED(")#=7)R96YT(%=E871H
M97(B"FUS9W-T<B`B06MT=65L="!V96IR(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(V-`IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*
M;7-G<W1R(").=7;F<F5N9&4@=F5J<CH@(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL
M92(*;7-G<W1R(")!:W1U96P@<W1I;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS
M('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R(")4:6QP87,@;W!G
M879E<BP@9&5R(&)L:79E<B!U9&;X<G0L(&[E<B!D=2!L;V=G97(@:6YD(&D@
M)7,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B2VQI<"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@
M(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B2VQI<"!V86QG(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C8W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#>7!R=7,B"FUS9W-T<B`B0WEP97)N(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#4*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@
M(DMY<FEL;&ES:R`H2T])."U2*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@V"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R(")+
M>7)I;&QI<VL@*%=I;F1O=W,M,3(U,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X-PIM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM
M<V=S='(@(DMY<FEL;&ES:R]5:W)A:6YS:R`H2T])."U5*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HV."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM
M<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`B5&IE:VMI970B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4R"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-3(@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(D1$(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W,B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S(W,@IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M
M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*
M;7-G<W1R("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A
M;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@H*(SH@
M9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.2!L:6(O
M2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R
M(")$86=L:6<B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A
M=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B1&%T851R964@<W1I9FEN9&5R(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W,"!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S(W,`IM<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(D1A
M=&%B87-E+6]P<VQA9R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y.`HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,Y."!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW,@IM<V=I9"`B1&%T92(*;7-G<W1R(")$871O(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@
M(D1A=&4@4F5C96EV960B"FUS9W-T<B`B36]D=&%G96QS97-D871O(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<X.2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C<X.0IM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`B1&%T;W9A
M;&<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*;7-G:60@(D1A>2(*;7-G<W1R
M(")$86<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@
M(E-L970@:V]L;VYN92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0U,0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#$S(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-3$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B1&5C96UB97(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V
M"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B1&5C:6UA;'1A;"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*
M;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R(")-:6YD<VL@:6YD<GEK
M;FEN9R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI
M8B]P<F5F<RYP:'`Z,3$W"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3@W
M"FUS9VED(")$969A=6QT(@IM<V=S='(@(E-T86YD87)D(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*;7-G:60@(D1E
M9F%U;'0@0V]L;W(B"FUS9W-T<B`B4W1A;F1A<F1F87)V92(*"B,Z(&9R86UE
M=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z.38@;&EB+TAO<F1E+TED96YT
M:71Y+G!H<#HY-@IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R(")3
M=&%N9&%R9"UI9&5N=&ET970B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-S4*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B4W1A;F1A<F0M<VMA
M;"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI
M=&EO;G,B"FUS9W-T<B`B1&5F:6YI=&EO;F5R(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C0S.0HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R-B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R,@HC.B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C0S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHY,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.0HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$X,B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M-S,*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O9&5L971E+FEN8SHQ,`IM<V=I9"`B1&5L971E(@IM<V=S='(@(E-L
M970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S(*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(E-L970@
M8V5L;&4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N
M<&AP.C(R-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(E-L970@9W)U
M<'!E(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y"FUS9VED
M(")$96QE=&4@3&]G(@IM<V=S='(@(E-L970@;&]G8F]G(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$P,0HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C<W(&QI
M8B](;W)D92]097)M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE=&4@4&5R;6ES
M<VEO;B(*;7-G<W1R(")3;&5T('1I;&QA9&5L<V5R(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE
M<W-A9V5S(@IM<V=S='(@(D9J97)N(&]G('5D<VQE="!B97-K961E<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3<*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(E-L970@8V5L;&4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8S"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(E-L970@:V]L;VYN
M92(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@
M97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(E-L970@96MS
M:7-T97)E;F1E+"!A;'1E<FYA=&EV92!S:V%B96QO;B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4T(&QI8B](;W)D92])34%0
M+T%#3"]R9F,T,S$T+G!H<#HU-`IM<V=I9"`B1&5L971E(&UE<W-A9V5S(@IM
M<V=S='(@(E-L970@8F5S:V5D97(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C0R,2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<
M(B(*;7-G<W1R(")3;&5T('1I;&QA9&5L<V5R(&9O<B!<(B5S7"(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R-"!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R
M;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B
M"FUS9W-T<B`B4VQE="!T:6QL861E;'-E<B!F;W(@7"(E<UPB(&]G(&%L;&4@
M=6YD97)O<F1N961E('1I;&QA9&5L<V5R/R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T
M92!R;W<B"FUS9W-T<B`B4VQE="!RYFMK92(*"B,Z('1E;7!L871E<R]P<F5F
M<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E
M9"!I9&5N=&ET>2(*;7-G<W1R(")3;&5T('9A;&=T92!I9&5N=&ET970B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,R!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3,*;7-G:60@(D1E;&5T92!S
M=6(@9F]L9&5R<R(*;7-G<W1R(")3;&5T('5N9&5R;6%P<&5R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W
M"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(E-L
M970@9&5N(&%K='5E;&QE(&MO;&]N;F4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T
M92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B4VQE="!D96X@86MT=65L;&4@
M<N9K:V4B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB
M)7-<(BXB"FUS9W-T<B`B3W!G<F%D97)I;F=S<V-R:7!T(%PB)7-<(B!S;&5T
M=&5T+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR-3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4V,R!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3DU"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS9VED(")$96QI
M=F5R>2!T:6UE(@IM<V=S='(@(DQE=F5R:6YG<W1I9'-P=6YK="(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HW,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R(")$86YM87)K(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H
M92!0<F]B;&5M(@IM<V=S='(@(D)E<VMR:78@<')O8FQE;65T(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X(&QI8B](;W)D92]&;W)M+G!H<#HY
M,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B0F5S:W)I=F5L
M<V4B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(P-B!L:6(O2&]R
M9&4N<&AP.C(P-@IM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO
M9V9I;&4I.B(*;7-G<W1R(")$971A;&IE<B`H;V=SY2!I($AO<F1E)W,@;&]G
M9FEL*3HB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(Q,"!L:6(O
M2&]R9&4N<&AP.C(Q,`IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B1&5T86QJ97(@97(@
M<VMR979E="!T:6P@;&]G8F]G96X@868@:&5N<WEN('1I;"!A9&UI;FES=')A
M=&]R96XN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R,0IM<V=I
M9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B561V:6ML:6YG(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,C0*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R(")$
M=6=P=6YK="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`Q"FUS9VED(")$
M97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(D1U9W!U;FMT(&9O
M<B!S:61S=&4@=&EM93H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(Q-@IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B1'5G<'5N:W0Z
M("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(E)E
M=&YI;F<@=F5N<W1R92!T:6P@:/AJ<F4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG
M:'0@=&\@;&5F="(*;7-G<W1R(")2971N:6YG(&CX:G)E('1I;"!V96YS=')E
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R
M>2(*;7-G<W1R(")+871A;&]G(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(W,`IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R(")6
M:7,@=&ED(&UE9"`R-"!T:6UE<C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3`P"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B26YD<W1I
M;&QI;F=E<B!F;W(@=FES;FEN9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HX.0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*
M;7-G<W1R(")6:7,@=61D>6)E;F1E('9E:G)U9'-I9W0B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.CDR"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I
M(@IM<V=S='(@(E9I<R!V96IR=61S:6=T("A4048I(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C<Y.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y.0IM
M<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B5FES;FEN9W-F;W)M870B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DQ(&QI8B](;W)D
M92]-24U%+TU$3BYP:'`Z,3DQ"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC
M871I;VXB"FUS9W-T<B`B3W9E<F1R86=E;'-E<VYO=&ET<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HW,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM
M<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B1&II8F]U=&DB"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R(")&;W)T<GED
M('-L971N:6YG(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS
M9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*
M;7-G<W1R(")$=2!MY2!I:VME(&MA;&1E(&UA:6YT96YA;F-E+G!H<"!D:7)E
M:W1E(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T
M(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T
M:&ES(&)O>#HB"FUS9W-T<B`B26YD96AO;&1E<B!D96X@9OAR<W1E('+F:VME
M(&9E;'1N879N93\@2'9I<R!J82P@;6%R:^ER(&1E;FYE(&)O:W,Z(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C<R(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R(")$96X@9&]M:6YI:V%N<VME
M(%)E<'5B;&EK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<S(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B
M"FUS9W-T<B`B1&5N(&1O;6EN:6MA;G-K92!297!U8FQI:R(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@
M86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B2&%R(&1U(&EK:V4@;F]G96X@
M:V]N=&\_($UE;&0@9&EG('1I;"XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HX-3,@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP
M.C@U,PIM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B2&5N="(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@U,R!L:6(O2&]R9&4O34E-
M12]#;VYT96YT<RYP:'`Z.#4S"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL
M;V%D("5S(@IM<V=S='(@(DAE;G0@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R(")(96YT(&=E;F5R97)E="!K
M;VYF:6=U<F%T:6]N(&YE9"!S;VT@4$A0+7-C<FEP="XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3`W(&QI8B](;W)D92]&;W)M+G!H<#HR,3`W
M"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R(")2=6QL96=A<F1I;BUL
M:7-T92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U
M9W,B"FUS9W-T<B`B365D:6MA;65N=&5R(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$S(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q
M,PIM<V=I9"`B12U-86EL(@IM<V=S='(@(D4M;6%I;"(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDR(&QI8B].970O4TU3
M+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E
M=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S
M97)V:6-E+B(*;7-G<W1R("(B"B)%36%I;"UT:6PM4TU3(&=A=&5W87DM9')I
M=F5R+"!F;W(@;W!E<F%T^')E<BP@<V]M('5D8GED97(@9&5N;F4@<V5R=FEC
M92XB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.C,T"B,Z(&QI8B](;W)D92].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@
M(D524B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C<R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-2!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R(")%<75A9&]R
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@;&EB+TAO<F1E
M+U!E<FUS+G!H<#HS,C4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS
M-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z.3(@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,34*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ.#$*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C<R"FUS9VED(")%9&ET(@IM<V=S='(@(E)E9&EG97(B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P(&QI8B](;W)D92]";&]C
M:R]522YP:'`Z-3`*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`BQFYD<F4@
M8FQO:R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP
M:'`Z,C(V"FUS9VED(")%9&ET($=R;W5P(@IM<V=S='(@(L9N9')E(&=R=7!P
M92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HW-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$P,`IM<V=I9"`B
M161I="!097)M:7-S:6]N(@IM<V=S='(@(L9N9')E('1I;&QA9&5L<V4B"@HC
M.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(L9N9')E('1I;&QA9&5L<V5R(@H*(SH@<V5R
M=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("+&;F1R92!T:6QL
M861E;'-E<B!F;W(@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU
M"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R("+&;F1R92!V86QG
M(&9O<CHB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,V-R!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`BQFYD<F4@
M=&EL;&%D96QS97(@9F]R(%PB)7-<(B(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S
M:6]N<R!F;W(@)7,B"FUS9W-T<B`BQFYD<F4@=&EL;&%D96QS97(@9F]R("5S
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C871I
M;VXB"FUS9W-T<B`B561D86YN96QS92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HW-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B
M"FUS9W-T<B`BQF=Y<'1E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q
M-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A
M9&]R(@IM<V=S='(@(D5L(%-A;'9A9&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M
M96YT+BXN(@IM<V=S='(@(D5L96UE;G0N+BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T
M<B`B16TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$X-CD@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR,C0*;7-G:60@(D5M86EL(@IM<V=S='(@(F5-86EL(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU-C8*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHV."!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$P
M"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(F4M;6%I;"UA9')E<W-E
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV,R!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3DV,PIM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T
M8V@N(@IM<V=S='(@(D4M;6%I;"UA9')E<W-E<B!S:V%L('!A<W-E+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#D@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Y.#D*;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S
M='(@(D4M;6%I;"!M960@8F5K<N9F=&5L<V4B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,2!L:6(O3F5T+U--4R]G96YE
M<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A>2(*
M;7-G<W1R(")%;6%I;"UT;RU335,@1V%T97=A>2(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR.3D*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.0IM<V=I9"`B16UO=&EC;VYS(@IM
M<V=S='(@(E-M:6QE>7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#(*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@
M(E1O;2!B97-K960N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C$U,"!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,C0S
M"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT.#0@;&EB+TAO<F1E+T=R
M;W5P+VQD87`N<&AP.C8V,@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z
M-S`U(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@
M<F5S=6QT+B(*;7-G<W1R("));G1E="!R97-U;'1A="XB"@HC.B!F<F%M97=O
M<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S(&QI8B](;W)D92]344PO2V5Y
M=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S
M='(@(E1O;70@=61T<GEK(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T
M-PIM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T
M;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B06MT:7;I<B!I;F1SYG1T
M96QS92!A9B!B:6QL961E<B!F<F$@1F]T;V=A;&QE<FEE<B!I('1E:W-T/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C(*;7-G:60@(D5N86)L92!R
M:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(D%K=&EVZ7(@:/AJ
M<F4M:VQI:R!C;VYT97AT+6UE;G4_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C4X."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDS"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR-3@X(&QI8B](;W)D92]&;W)M+G!H<#HR-SDS
M"FUS9VED(")%;F0@>65A<B(*;7-G<W1R(")3;'5T+>5R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL
M87)G92!%9&ET;W(B"FUS9W-T<B`B1F]R<W3X<B!E9&ET97)I;F=S=N9R:W3X
M:B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C0*;7-G:60@(B(*(D5N
M=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K
M960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG
M+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B
M"B));F1T87-T(&5T('-I:VME<FAE9'-S</AR9W-MY6PL('-O;2!D=2!V:6P@
M8FQI=F4@<W!U<F=T+"!NY7(@9'4@:&%R(&)R=6<@9F]R("(*(F%T(.9N9')E
M(&1I="!K;V1E;W)D+"!F>"`G:'9A9"!E<B!D:70@:^9L961Y<G,@;F%V;C\G
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q.0IM<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E
M(@IM<V=S='(@(DEN9'1A<W0@55),('1I;"!B:6QL960@:&5R(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DR"FUS9VED(")%;G1E
M<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B26YD=&%S="!B;V=S=&%V
M97(@;F5D96YF;W(Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDY(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U:6YE
M82(*;7-G<W1R("+&:W9A=&]R:6%L($=U:6YE82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HW.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B
M17)I=')E82(*;7-G<W1R("+&<FET<F5A(@H*(SH@9G)A;65W;W)K+TYO=&EF
M:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+U9I97<N<&AP.CDT"B,Z
M(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR
M-PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+U9I97<N<&AP.CDT(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S8*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C0X"FUS9VED(")%<G)O<B(*;7-G<W1R(")&96IL(@H*(SH@9G)A;65W
M;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C,@;&EB+TAO<F1E+U1E;7!L
M871E+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I
M;F<@8FQO8VLZ("5S(@IM<V=S='(@(D9E:FP@=F5D(&1A;FYE;'-E(&%F(&)L
M;VLZ("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z
M("5S(@IM<V=S='(@(D9E:FP@=6YD97(@<VQE=&YI;F<@868@<WEN8RUHYF=T
M93H@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B
M"FUS9W-T<B`B1F5J;"!U;F1E<B!S;&5T;FEN9R!A9B!S>6YC(&QO9SH@)7,B
M"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V."!L:6(O
M2&]R9&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(D9E:FP@=6YD97(@
M:&5N=&YI;F<@868@:6YD:&]L9#H@)7,B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D
M871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(D9E:FP@=6YD97(@;W!D871E
M<FEN9R!A9B!K;V1E;W)D.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M
M97-S86=E+B(*;7-G<W1R(")&96IL(&9O<F)U;F1E="!M960@92UP;W-T(&)E
M<VME9"XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,Z(&QI8B]61E,O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B
M1F5J;"!U;F1E<B!S:W)I=FYI;F<@868@7"(E<UPB+B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HW-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I
M9"`B17-T;VYI82(*;7-G<W1R(")%<W1L86YD(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C@Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%
M=&AI;W!I82(*;7-G<W1R("+&=&EO<&EE;B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(D5T;FES:R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-2!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(D5U<F]P82(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#,*;7-G:60@(D5V97)Y(#$U
M(&UI;G5T97,B"FUS9W-T<B`B2'9E<B!K=F%R=&5R(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Y,PIM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S
M='(@(DAV97)T(#(N(&UI;G5T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,T,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")%=F5R>2`S
M,"!S96-O;F1S(@IM<V=S='(@(DAV97(@:&%L=F4@;6EN=70B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S0R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.30*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")(=F5R(#4N(&UI
M;G5T(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H
M<#HV,"!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R
M>2!,;V=I;B(*;7-G<W1R(")!;'1I9"!V960@;&]G:6XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S0T"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS
M9W-T<B`B2'9E<B!H86QV92!T:6UE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,T,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDR"FUS9VED(")%=F5R
M>2!M:6YU=&4B"FUS9W-T<B`B2'9E<B!M:6YU="(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS
M9W-T<B`B16MS96UP96QVYG)D:65R.B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H
M<#HU,2!A9&UI;B]P:'!S:&5L;"YP:'`Z.#(@861M:6XO<W%L<VAE;&PN<&AP
M.C$R.`IM<V=I9"`B17AE8W5T92(*;7-G<W1R(")59&;X<B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C$T(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C0W-0HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C8Q-`IM<V=I9"`B17AP86YD(@IM<V=S='(@
M(E5D=FED(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,@IM
M<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B1F]L9"!S:61E<&%N96P@
M=60B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X(&QI
M8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@
M)RDG(@IM<V=S='(@(D9O<G9E;G1E9&4@)RDG(@H*(SH@9G)A;65W;W)K+U-1
M3"]344PO2V5Y=V]R9',N<&AP.C$W-2!L:6(O2&]R9&4O4U%,+TME>7=O<F1S
M+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@
M<V5A<F-H('1E<FTB"FUS9W-T<B`B1F]R=F5N=&5D92!R96YT(&]R9"!E;&QE
M<B!C:71E<F5T('/X9V5T97)M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$R(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I
M9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(D9O<N9L9&5L<V5S9&%T;R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<W(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-C<W"FUS9VED(")%>'!O;F5N="(*;7-G
M<W1R(")%:W-P;VYE;G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R
M(")&1RUF87)V92(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G
M:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B1E10+6QA9W)I;F<@
M868@;W!SYG1N:6YG(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-Q;"YP
M:'`Z,C(P(&QI8B](;W)D92]0<F5F<R]S<6PN<&AP.C(R,`IM<V=I9"`B1F%I
M;&5D(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(DMU;FYE(&EK
M:V4@YFYD<F4@:6YD<W1I;&QI;F=E<FYE+B(*"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.CDX"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HW-2!L:6(O2&]R
M9&4O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@
M=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DMU;FYE(&EK:V4@9N4@9F]R8FEN
M9&5L<V4@=&EL($Q$05`@<V5R=F5R96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S;6(N<&AP.CDX(&QI8B](;W)D92]!=71H+W-M8BYP:'`Z.3@*;7-G
M:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@
M(DMU;FYE(&EK:V4@9F]R8FEN9&4@=&EL(%--0BUS97)V97(N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3<@;&EB+U9&4R]F='`N<&AP.C<Q
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB
M)7-<(BXB"FUS9W-T<B`B1F5J;"!U;F1E<B!K;W!I97)I;F<@9G)A(%PB)7-<
M(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R,B!L:6(O5D93
M+V9T<"YP:'`Z-S(R"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C
M;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B2W5N;F4@:6MK92!K;W!I97)E('1I
M;"!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX
M-R!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O
M(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R(")+=6YN92!I
M:VME(&5T86)L97)E(&YY(%-!4TPM9F]R8FEN9&5L<V4N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HW-34@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HU,#$*(SH@;&EB+U9&4R]F='`N<&AP.C<U-2!L:6(O5D93+W-M8BYP
M:'`Z-3`Q"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O
M(%PB)7-<(BXB"FUS9W-T<B`B2W5N;F4@:6MK92!F;'ET=&4@=&EL(%PB)7-<
M(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V-2!L:6(O5D93
M+W-M8BYP:'`Z-#8U"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!R
M971R:65V93H@)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!H96YT93H@)7,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I
M9"`B1F%I<B(*;7-G<W1R(")3;75K="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HX-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA
M;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(D9A;&ML86YD<_AE<FYE
M("A-86QV:6YA<RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HX,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#8@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS
M9W-T<B`B1N9R^&5R;F4B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X
M(&QI8B](;W)D92]#3$DN<&AP.C(S.`IM<V=I9"`B1F%T86P@17)R;W(Z(@IM
M<V=S='(@(D3X9&5L:6<@9F5J;#HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3@W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS9W-T<B`B1F%X(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U,0IM<V=I9"`B1F%X97,B"FUS
M9W-T<B`B1F%K<VEM:6QE<B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T,0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`S(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B1F5B<G5A<B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C(W"FUS9VED(")&965L<R!,:6ME(@IM<V=S
M='(@(D;X;&5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R
M,`IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(D;X;&5S.B`B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B
M1F5W(%-H;W=E<G,B"FUS9W-T<B`B1N4@8GEG97(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@
M4VAO=V5R<R(*;7-G<W1R(")&Y2!S;F5B>6=E<B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Y-#0@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-#0*;7-G
M:60@(D9I96QD(&UA=')I>"(*;7-G<W1R(")&96QT;6%T<FEC92(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,C4@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,S,C4*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S='(@(D9I9VQE="!#
M05!40TA!(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R.2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S,R.0IM<V=I9"`B1FEG;&5T(&9O;G0B"FUS9W-T
M<B`B1FEG;&5T('-K<FEF='-T>7!O9W)A9FDB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I
M:FDB"FUS9W-T<B`B1FEJ:2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(U-0IM<V=I9"`B1FEL92(*;7-G<W1R(")&:6PB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HV-R!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R
M+G!H<#HV,`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.2!L
M:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(D%N=&%L(&9I
M;&5R.B`E<R!F:6PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M-SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-R!L
M:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV,`HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=&=Z+G!H<#HW.2!L:6(O2&]R9&4O34E-12]6:65W97(O
M>FEP+G!H<#HV-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E
M<R!F:6QE<R(*;7-G<W1R(")!;G1A;"!F:6QE<CH@)7,@9FEL97(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`Y"FUS9VED(")&:6QE($UA;F%G
M97(B"FUS9W-T<B`B1FEL:.5N9'1E<FEN9R(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<P(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8S
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@R(&QI8B](;W)D
M92]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"FUS9VED(")&:6QE($YA;64B"FUS
M9W-T<B`B1FEL;F%V;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y
M-S<@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y-S<*;7-G:60@(D9I;&4@<V5L96-T
M:6]N(@IM<V=S='(@(D9I;'9A;&<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#@V(&QI8B](;W)D92]&;W)M+G!H<#HQ-#@V"FUS9VED(")&:6QE
M('5P;&]A9"(*;7-G<W1R(")&:6QL86=R:6YG(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.3`R(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY
M,#(*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R
M(")&:6QL86=R:6YG(&EK:V4@=6YD97)S=/AT=&5T+B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HY,0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R(")&
M:6QT<F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HX,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#(@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B1FEN;&%N
M9"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA
M;&8B"FUS9W-T<B`B1OAR<W1E(&AA;'9D96PB"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1
M=6%R=&5R(@IM<V=S='(@(D;X<G-T92!K=F%R=&%L(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-PHC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4W"FUS9VED(")&:7@@<F%T:6\B
M"FUS9W-T<B`B1FEK<^ER('-T^')R96QS97-F;W)H;VQD(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,R"FUS9VED(")&;&EP(@IM
M<V=S='(@(D9L:7`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R(")&;'ED
M96YD92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B5.5G92(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HQ,#<@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HR,S<*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3`W(&QI8B]61E,O<W%L+G!H
M<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T
M(&5X:7-T(@IM<V=S='(@(DUA<'!E("5S(&5K<VES=&5R97(@:6MK92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G
M:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B5'EP;V=R869I9F%R=F4B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B
M36%D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(S"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG
M="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R(")&;W(@=V5B<')O9W)A;6UE<BP@
M<V]M(&EK:V4@=6YD97)S=/AT=&5R(&)I;&QE9&5R(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-#$*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@
M(E9E:G)U9'-I9W0@*%1!1BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-S(*;7-G:60@(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T
M:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG
M:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@
M=VED92!B;&]C:RDB"FUS9W-T<B`B(@HB561S:6=T<V1A9V4@*&)E;>9R:R!A
M="!D96X@<F5T=7)N97)E('9E:G)U9'-I9W0@=F5D<OAR97(@8N5D92!D86<@
M;V<@;F%T.R!E="`B"B)S=&]R="!A;G1A;"!H97(@:V%N(')E<W5L=&5R92!I
M(&5N(&UE9V5T(&)R960@8FQO:RDB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S
M='(@(D=L96UT(&1I="!K;V1E;W)D/R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-C0*;7-G:60@(D9O<FUS(@IM<V=S='(@(D9O<FUU;&%R97(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B
M"FUS9W-T<B`B3W)D<W!R;V<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R(")%<&EG<F%M='EP92(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B1F]R='5N97,B
M"FUS9W-T<B`B17!I9W)A;6UE<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R(")%<&EG<F%M;65R(#(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4U"FUS9VED(")&;W)U
M;7,B"FUS9W-T<B`B1F]R82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ,3$*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(E9I9&5R97-E;F1E;'-E
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M,`IM<V=I9"`B1G(B"FUS9W-T<B`B1G)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S
M(@IM<V=S='(@(E)A;6UE<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C@S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-R!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E(@IM<V=S
M='(@(D9R86YK<FEG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L
M($UE=')O<&]L:71A;B(*;7-G<W1R(")&<F%N:W)I9RP@365T<F]P;VQI=&%N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDQ(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(D9R86YS
M:R!'=7EA;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-"!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*
M;7-G<W1R(")&<F%N<VL@4&]L>6YE<VEE;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(R,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@
M(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R(")&<F%N<VME
M('-Y9&QI9V4@5&5R<FET;W)I97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C<T"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(D9R82(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,T.0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,SDU"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B1G)A(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*;7-G:60@(D9U;&P@
M1&5S8W)I<'1I;VXB"FUS9W-T<B`B1G5L9"!B97-K<FEV96QS92(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS
M9VED(")&=6QL($UO;VXB"FUS9W-T<B`B1G5L9&WE;F4B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-C4@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHV,`IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(D9U;&1T(&YA=FXB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-PHC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#@@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(D=A8F]N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R
M(")'86QL97)I(&AV;W)F<F$@8FEL;&5D92!S:V%L('1A9V5S(&9R82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B1V%L;&5R:3HB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDV(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.38@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R(")'86UB:6$B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E
M;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B1V5N97+I<B`E<RUK
M;VYF:6=U<F%T:6]N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I
M9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(D=E;F5R
M97)E="!K;V1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDP(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(D=E
M;W)G:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8Y(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@(E1Y<VML
M86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDS(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<U"FUS9VED(")':&%N82(*;7-G<W1R(")':&%N82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HY-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(D=I8G)A;'1A<B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<V(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3<V"FUS9VED(")':79E;B!.86UE(@IM<V=S
M='(@(D9O<FYA=FXB"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,3<U('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$P"B,Z('1E;7!L871E<R]P
M<F5F<R]A<'`N:6YC.C$Y"FUS9VED(")';&]B86P@3W!T:6]N<R(*;7-G<W1R
M(")'<G5N9&SF9V=E;F1E(&EN9'-T:6QL:6YG97(B"@HC.B!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHQ-PIM<V=I9"`B1V\B"FUS9W-T<B`B561F^'(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G
M<W1R(")']F1E;"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,3,Q"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,3,Q"FUS9VED(")';V]G;&4@36%P<R(*;7-G<W1R(")';V]G;&4@
M36%P<R(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O
M;V=L92!396%R8V@B"FUS9W-T<B`B1V]O9VQE+7/X9VYI;F<B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,X"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,S@*;7-G:60@(D=R87ES
M8V%L92(*;7-G<W1R(")'<N5T;VYE<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3`P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E
M8V4B"FUS9W-T<B`B1W+F:V5N;&%N9"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@X"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B1W+F
M<VL@*$E33RTX.#4Y+3<I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.30*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDU(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS
M9W-T<B`B1W+X;FQA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HY-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#D@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T
M<B`B1W)E;F%D82(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'
M<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")'<G5P<&4M861M:6YI<W1R
M871I;VXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*(SH@;&EB+TAO<F1E+T=R
M;W5P+G!H<#HU.2!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED
M(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R(")'<G5P
M<&5N879N92!MY2!I:VME(';F<F4@=&]M;64B"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,S`W(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H
M<#HS,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE
M('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9#H@(@IM<V=S='(@(D=R;W5P7VQD87`Z($MA;B!I:VME('1I;&;X:F4@9W)U
M<'!E("5S+B!397)V97)E;B!M96QD97(Z("(*"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-#$X(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ,3@*(SH@;&EB+TAO<F1E
M+T=R;W5P+VQD87`N<&AP.C$R-"!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z
M-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T
M;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@2V%N(&EK
M:V4@<VQE='1E(&=R=7!P92`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C,W.0HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S,X(&QI8B](;W)D
M92]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O
M=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R(")'
M<F]U<%]L9&%P.B!+86X@:6MK92!O<&1A=&5R92!G<G5P<&4@)7,B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C,Q-`HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS."!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S
M='(@(D=R=7!P97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HY-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3@@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T
M<B`B1W5A9&5L;W5P92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HY-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`S(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@
M(D=U86TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(D=U
M871A;6%L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*;7-G<W1R
M(")'=65R;G-E>2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,C(V(&QI8B](;W)D92]097)M<R]522YP:'`Z,C(V"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(D?F<W1E=&EL;&%D96QS97(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#<R"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B1^9S=&5B
M;V<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDW(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY
M.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G<W1R(")'=6EN96$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`T(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<X"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(D=U:6YE
M82U":7-S874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$P,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`U(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B
M1W5Y86YA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.38P(&QI8B](
M;W)D92]&;W)M+G!H<#HY-C`*;7-G:60@(DA434PB"FUS9W-T<B`B2%1-3"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L
M971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R(")(5$U,07)E82!N
MYF=T97(@<.4@9F5J('9I<R!A="!S;&5T=&4@9&5N('-I9'-T92!C96QL92!I
M('+F:VME+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S
M97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T
M<B`B2%1-3$%R96$@;N9G=&5R('#E(&9E:B!V:7,@870@<VQE='1E(&1E;B!S
M:61S=&4@:V]L;VYN92!I('1A8F5L+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T
M86)L92XB"FUS9W-T<B`B2%1-3$%R96$@;N9G=&5R('#E(&9E:B!V:7,@870@
M<VQE='1E(&1E;B!S:61S=&4@<N9K:V4@:2!T86)E;"XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VAT='`N<&AP.C$U-R!L:6(O2&]R9&4O075T:"]H='1P
M+G!H<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")(5%10+>9G=&YI;F<@:6MK92!F=6YD970N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B2&'O=&DB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G<W1R(")(87-H
M+6%L9V]R:71M92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(D1I<R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.CDQ.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.3$T"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY,3D@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(Y,30*;7-G:60@(DAE861E<B(*;7-G<W1R(")4;W!T96MS="(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-C$*
M(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-C$*;7-G:60@
M(DAE861E<G,B"FUS9W-T<B`B3W9E<G-K<FEF=&5R(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$P-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM
M<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S
M='(@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")(
M96%V>2!4+5-T;W)M(@IM<V=S='(@(DMR869T:6<@=&]R9&5N(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM
M."U)*2(*;7-G<W1R(")(96)R86ES:R`H25-/+3@X-3DM."U)*2(*"B,Z(&QI
M8B]";&]C:R]I9G)A;64N<&AP.C(R('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R
M(")(^&ID92(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ
M.#0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X-@HC.B!L:6(O
M2&]R9&4O2&5L<"YP:'`Z,3@T(&QI8B](;W)D92](96QP+G!H<#HQ.#8@<V5R
M=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<*(SH@=&5M<&QA=&5S+VAE;'`O:6YD
M97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T<B`B2&KF;'`B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(
M96QP('5S:6YG(&5D:71O<B(*;7-G<W1R(")(:N9L<"!T:6P@<F5D:6=E<FEN
M9W-VYG)K=/AJ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W,2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3,W,0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@
M(DAJYFQP97(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE
M;6ES<&AE<F4B"FUS9W-T<B`B2&5M:7-FYG)E(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z
M,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB
M"FUS9W-T<B`B2&5R(&5R('-T87)T96X@868@9FEL96XZ(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(DAI9V@B
M"FUS9W-T<B`B2/AJ(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV
M('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"FUS9VED(")(
M;U]M92(*;7-G<W1R(")(:F5M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-#,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(;VQY
M(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R(")(96QL:6=S^"`H
M5F%T:6MA;G-T871E;BDB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$U-#@@;&EB+TAO<F1E+G!H<#HQ-30X"FUS9VED(")(;VUE(@IM<V=S='(@
M(DAJ96TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3(R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ-34*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO
M;64@061D<F5S<R(*;7-G<W1R(")0<FEV870M861R97-S92(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS
M9W-T<B`B2&IE;6UE:V%T86QO9R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.3`*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B4')I
M=F%T+71E;&5F;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$P-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`X(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G
M<W1R(")(;VYD=7)A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#8@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*
M;7-G<W1R(")(;VYG($MO;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-C<*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3(@;&EB+TAO<F1E+TMO;&%B+G!H<#HT
M-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@
M)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R
M(")(;W)D92]+;VQA8CH@56=Y;&1I9R`E<R!834P@9&%T82!PY71R=69F970@
M:2!B97-K960@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y
M.2!L:6(O2&]R9&4O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE
M8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($EN9V5N(&)E<VME9"!S=F%R
M97(@=&EL(&]B:F5K="`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z-#0U(&QI8B](;W)D92]+;VQA8BYP:'`Z-#0U"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N
M9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!);G1E="!O
M8FIE:W0@868@='EP92`E<R!F=6YD970@:2!B97-K960@)7,B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-3$@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HQ,C4Q"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C
M97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L
M86(Z(%-L971T961E("5S(%PB)7-<(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,C(S(&QI8B](;W)D92]+;VQA8BYP:'`Z,C(S"FUS9VED(")(
M;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T
M:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R(")(;W)D92]+;VQA
M8CH@26YT96=R871I;VYS;6%S:VEN96X@:W+F=F5R(%!(4"UU9'9I9&1E;'-E
M("=D;VUX;6PG(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,3(@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HU,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O
M<B!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($MA;B!I:VME(&1A
M;FYE(&YY="!834PM='+F(&9O<B!O8FIE:W0@)7,B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C$R-#@@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C0X
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($MA
M;B!I:VME('-L971T92`E<R!<(B5S7"(Z("5S(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HT.#,@;&EB+TAO<F1E+TMO;&%B+G!H<#HT.#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R
M:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@
M(DAO<F1E+TMO;&%B.B!+86X@:6MK92!I;F1H96YT92!-24U%+4E$(&9O<B!D
M96QE;B!A9B!T>7!E("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HQ,3DW(&QI8B](;W)D92]+;VQA8BYP:'`Z,3$Y-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S
M(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($MA;B!I:VME('-Y
M;FMR;VYI<V5R92`E<R!<(B5S7"(Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,S,W(&QI8B](;W)D92]+;VQA8BYP:'`Z,3,S-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H
M<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($MA;B!I
M:VME('-Y;FMR;VYI<V5R92!D96QI;F=E<CH@)7,B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C,T,"!L:6(O2&]R9&4O2V]L86(N<&AP.C,T,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R
M92!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(%5K96YD="!D96QI;F<@
M7"(E<UPB(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(E9A;F1R
M970@<W1R96<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B
M5F%N9')E="!F;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R(")686YD
M<F5T.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0
M;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B2'9O<F1A;B!B87(@9'4@9&EG(&%D
M(&UE9"!A="!H879N92!H97(_("A);F1R87!P;W)TZ7(A*2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G
M:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_
M(@IM<V=S='(@(DAV;W(@;6%N9V4@:V]L;VYN97(@^&YS:V5R(&1U(&%T('-A
M;6UE;FSF9V=E/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q
M"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B
M"FUS9W-T<B`B2'9O<B!M86YG92!F96QT97(@*&MO;&]N;F5R*2!E<B!D97(_
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T
M;R!M97)G93\B"FUS9W-T<B`B2'9O<B!M86YG92!RYFMK97(@^&YS:V5R(&1U
M(&%T('-A;6UE;FSF9V=E/R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C,W
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D*;7-G:60@(DAU;6ED
M:71Y(@IM<V=S='(@(D9U9W1I9VAE9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-#@*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B1G5G
M=&EG:&5D.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@
M(DAU;6]R:7-T<R(*;7-G<W1R(")(=6UO<FES=&5R(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Q,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM
M<V=I9"`B2'5N9V%R>2(*;7-G<W1R(")5;F=A<FXB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C$W,@HC.B!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(S
M-2!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3<R"B,L('!H<"UF;W)M870*
M;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S
M='(@(D]P<F5T=&5L<V4@868@24U!4"UM87!P92!F96IL961E.B`E<R(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.34@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T"B,Z(&QI8B](;W)D92]!=71H+V-Y
M<G-Q;"YP:'`Z,CDU(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE
M9#H@)7,B"FUS9W-T<B`B4VQE=&YI;F<@868@24U!4"UM87!P92!F96IL961E
M.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#(@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y"B,Z(&QI8B](;W)D
M92]!=71H+V-Y<G-Q;"YP:'`Z,C0R(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H
M<#HQ-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A
M(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B1&5F:6YE<FEN9R!A9B!K
M=F]T92!F;W(@24U!4"UM87!P92!F96IL961E.B`E<R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S,38@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,38*
M;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B25`M861R97-S92(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<@;&EB+TAO<F1E+T%U
M=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B25`M861R97-S92!I:VME('1I;&?F;F=E;&EG92XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y(&QI8B](
M;W)D92]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO
M="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("))4"UA9')E
M<W-E(&EK:V4@:6YD96YF;W(@0TE$4BUB;&]K+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O
M=VX@=FEO;&%T:6]N+B(*;7-G<W1R("))4"!L;V-K9&]W;B!V:6]L871I;VXN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B
M26YD<^9T('+F:VME(&;X<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,C`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B
M"FUS9W-T<B`B27-L86YD(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X
M,`IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R(")+=6X@:6MO;F5R(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(DEC;VYS(&9O<B`E<R(*;7-G<W1R(")):V]N97(@9F]R("5S(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,X,0IM<V=I9"`B26-O;G,@=VET:"!T97AT
M(@IM<V=S='(@(DEK;VYE<B!M960@=&5K<W0B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3DS"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@
M(DED96YT:71E='-N879N.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C8P,"!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z-C`P
M"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@
M8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS
M9W-T<B`B2'9I<R!D96X@:6MK92!V:7-T(&MO<G)E:W0L("5S(&9O<B!A="#E
M8FYE(&1E;B!I(&5T(&YY="!V:6YD=64N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0U.0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O
M;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C
M:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y
M+B(*;7-G<W1R("(B"B)(=FES(&1U(&EK:V4@<V5R(&YO9V5N(&EK;VYE<B!V
M960@8G)U9R!A9B!);G1E<FYE="!%>'!L;W)E<B!S:V%L(&1U(&WE<VME("(*
M(FAA:VME(&1E;FYE(&)O:W,@868@9F]R(&%T('-LY2!03D<M=')A;G-P87)E
M;G,@9G)A+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ-S(*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$W,@IM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO
M(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E
M("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*(DAV
M:7,@9'4@<V5R(&1E;FYE(&)E<VME9"!I('-T961E="!F;W(@970@8FEL;&5D
M92P@<^4@=FEL(&1U(&EK:V4@:W5N;F4@<V4@(@HB9&5T(&D@9&EN(&YE="UL
MYG-E<B!E9G1E<B!O<&SF9VYI;F<N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"FUS9VED("));6%G
M92!0<F5V:65W.B(*;7-G<W1R(")":6QL960M9F]R:.5N9'-V:7-N:6YG.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R(")":6QL960M55),(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$X"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(D)I;&QE9"U5
M4DPZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS
M9W-T<B`B0FEL;&5D92!F<F$@9V%L;&5R:2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B
M26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R(")":6QL961E(&9R82!G86QL
M97)I.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R
M(")":6QL960M;W!LYF=N:6YG(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R(")":6QL961E<B(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHU-`HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHW('1E;7!L
M871E<R]D871A+W1S=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(DEM<&]R=&5R:6YG+"!T<FEN("5D
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(DEM<&]R
M=&5R961E(&9E;'1E<CH@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(DEM<&]R
M=&5R961E(&9E;'1E<CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F
M=&5R(@IM<V=S='(@(DEN9'/F="!RYFMK92!E9G1E<B(*"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-"!L:6(O2&]R9&4O0V]M
M<')E<W,O>FEP+G!H<#HQ,S0*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D
M92!G:79E;BXB"FUS9W-T<B`B1F5J;&%G=&EG(&AA;F1L:6YG<VMO9&4@86YG
M:79E="XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S,@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,R"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D
M+B(*;7-G<W1R(")5:V]R<F5K="!B<G5G97)N879N(&]G+V5L;&5R(&MO9&5O
M<F0N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@
M(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@
M5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF
M('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB56MO<G)E:W0@
M8G)U9V5R;F%V;B!E;&QE<B!A;'1E<FYA=&EV(&%D<F5S<V4N(%!R^'8@:6=E
M;B!E;&QE<B!K;VYT86MT(&1I;B`B"B)A9&UI;FES=')A=&]R+"!H=FES(&1U
M(&AA<B!B<G5G(&9O<B!Y9&5R;&EG97)E(&AJYFQP+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E
M87-E($EN9&5N="(*;7-G<W1R(")&;W+X9R!I;F1R>6MN:6YG(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B26YD:65N(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-30@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HR-30*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G
M:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B26YD:79I9'5E;&QE(&)R
M=6=E<F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$Q,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$R(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B
M26YD;VYE<VEE;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-C<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`B26YF;R(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR-3D*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S
M='(@(DEN9F]R;6%T:6]N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,Q.0IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L
M92XB"FUS9W-T<B`B26YF;W)M871I;VX@:6MK92!LYFYG97)E('1I;&?F;F=E
M;&EG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G
M<W1R("));F1SYG0@:V]L;VYN92!E9G1E<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PIM<V=I9"`B
M26YS97)T($EM86=E(@IM<V=S='(@(DEN9'/F="!B:6QL961E(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B
M26YS97)T(%1A8FQE(@IM<V=S='(@(DEN9'/F="!T86)E;"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN
M<V5R="!796(@3&EN:R(*;7-G<W1R("));F1SYG0@=V5B+6AE;G9I<VYI;F<B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R
M("));F1SYG0@:V]L;VYN92!F^'(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A
M(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN
M9'/F="!E;B!N>2!K;VQO;FYE(&5F=&5R(&1E;B!A:W1U96QL92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE(@IM<V=S='(@(DEN9'/F="!E;B!N>2!K;VQO;FYE(&;X<B!D96X@
M86MT=65L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T
M97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN9'/F="!E;B!N>2!RYFMK
M92!E9G1E<B!D96X@86MT=65L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A
M(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("));F1S
MYG0@96X@;GD@<N9K:V4@9OAR(&1E;B!A:W1U96QL92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I
M9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B
M"FUS9W-T<B`B26YD<^9T(&5N('!A<F%G<F%F(&5F=&5R(&1E="!A:W1U96QL
M92!P=6YK="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E
M9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(DEN9'/F="!E;B!P87)A
M9W)A9B!F^'(@9&5T(&%K='5E;&QE('!U;FMT(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B
M"FUS9W-T<B`B26YD<^9T(&%L=&5R;F%T:78@<VMA8F5L;VXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C0R"FUS9VED("));G-E<G0@86X@96UA:6P@
M861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S
M=V]R9#HB"FUS9W-T<B`B26YD=&%S="!E;B!E+6UA:6PM861R97-S92P@:'9O
M<G1I;"!D=2!K86X@;6]D=&%G92!D970@;GEE(&MO9&5O<F0Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM
M<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`B26YD<^9T(&-E;&QE
M(&5F=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S
M='(@(DEN9'/F="!C96QL92!F^'(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L
M=6UN(&%F=&5R(@IM<V=S='(@(DEN9'/F="!K;VQO;FYE(&5F=&5R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B26YD<^9T
M(&MO;&]N;F4@9OAR(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.3`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q
M-"YP:'`Z-3`@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4P"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS
M97)T(&UE<W-A9V5S(@IM<V=S='(@(DEN9'/F="!B97-K961E<B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R("));F1S
MYG0@<&%R86=R868@969T97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A
M9W)A<&@@8F5F;W)E(@IM<V=S='(@(DEN9'/F="!P87)A9W)A9B!E9G1E<B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B26YD<^9T
M('+F:VME(&5F=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B
M"FUS9W-T<B`B26YD<^9T('+F:VME(&;X<B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,S,*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R
M('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B26YD=&%S="!D
M970@:W+F=F5D92!S=F%R('1I;"!S:6MK97)H961S<W#X<F=S;>5L970Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM
M<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("));F1SYG0OYFYD
M<F4@8FEL;&5D92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R
M("));F1SYG0OYFYD<F4@:&5N=FES;FEN9R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C
M<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S
M='(@(E5T:6QS='+F:VME;&EG(&MR961I="!T:6P@870@<V5N9&4@=&EL(&1I
M<W1R:6)U=&EO;G-L:7-T96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB
M"FUS9W-T<B`B571I;'-T<N9K:V5L:6=E(&MR961I="XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#<U(&QI8B](;W)D92]&;W)M+G!H<#HQ,#<U
M"FUS9VED("));G1E9V5R(@IM<V=S='(@(DAE;'1A;"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Q,S,@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,S,*
M;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R(")(96QT86QS;&ES=&4B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3<*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G
M:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@
M(E5G>6QD:6<@541(+B`H57-E<B!$871A($AE861E<BDN(@H*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,38W"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$Y-`HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,3(@;&EB+TAO<F1E+T-O;7!R
M97-S+WII<"YP:'`Z,38W"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP
M.C$Y-"!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HR,3(*;7-G:60@(DEN
M=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B56=Y;&1I9V4@6DE0+61A=&$B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P
M<&QI8V%T:6]N+B(*;7-G<W1R(")59WEL9&EG="!A<'!L:6MA=&EO;BXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,3(*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G
M:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(E5G>6QD:6=T('-K<FEP
M="U)1"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@W(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(S,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,CDY"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(P.#<*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q-3@@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(R,S(@;&EB+TAO<F1E+T9O<FTN<&AP.C(R
M.3D*(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G
M:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(E5G>6QD:6=E
M(&1A=&$@869S96YD="XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#`*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D
M<F5S<RXB"FUS9W-T<B`B56=Y;&1I9R!D97-T:6YA=&EO;BXB"@HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#D*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3,Y"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(T,2!L:6(O2&]R9&4O0V]M
M<')E<W,O9&)X+G!H<#HQ,#D*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP
M:'`Z,3,Y(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C(T,0IM<V=I9"`B
M26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R(")59WEL9&EG="!F:6QF;W)M
M870B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED
M("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R(")59WEL9&EG(&QI8V5N
M<V[X9VQE+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*
M;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(E5G
M>6QD:6<@<&QA8V5R:6YG(&%N9VEV970N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T
M>7!E+B(*;7-G<W1R(")59WEL9&EG(&US9U]T>7!E+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PHC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI
M9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B56=Y;&1I9R!E;&QE<B!M
M86YG;&5N(&%P:5]I9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.38*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A
M;65T97)S+B(*;7-G<W1R(")59WEL9&EG92!E;&QE<B!M86YG;&5N9&4@<&%R
M86UE=')E+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I
M9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B56=Y;&1I
M9V4@9F]RYFQD<F4M=&EL;&%D96QS97(N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$V,0IM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*
M;7-G<W1R(")59WEL9&EG('!A<G1N97(M:60N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O
M9&4N(@IM<V=S='(@(E5G>6QD:6<@<')O9'5K="UK;V1E+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV
M86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B56=Y;&1I9R!P<F]T;VMO;"XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HX,`HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,@;&EB+TYE="]335,O=VEN7VAT
M='`N<&AP.C<Q"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM
M<V=S='(@(E5G>6QD:6<@;6]D=&%G97(Z(%PB)7-<(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,3`X,"!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C$R-C,*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,#@P(&QI8B](;W)D
M92]+;VQA8BYP:'`Z,3(V,PIM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B
M"FUS9W-T<B`B56=Y;&1I9W0@9&5L:6YG<V]B:F5K="(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI
M9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B56=Y;&1I9R!O<')I;F1E;'-E
M<V%D<F5S<V4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$Q"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T
M<B`B56=Y;&1I9R!U;FEC;V1E+61A=&$N(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,U.0IM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(DEN9&)O
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W
M.`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<X"FUS
M9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(DEN=F5R=.ER(&UA<FME
M<FEN9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3D@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B27)A;BP@1&5N(&ES;&%M:7-K(')E<'5B;&EK(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3(*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q."!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("))<F%K(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R("))<FQA;F0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-2!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R(")-86XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B
M27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B4W1E9'9I<R!T;W)D96XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$T(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T<B`B27-R865L(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C8@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV,C8*;7-G:60@(DES<W5E<B(*;7-G<W1R(")5
M9'-T961E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(DET86QI96YS:R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C$@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#(*;7-G:60@(DET86QY(@IM<V=S='(@(DET86QI96XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(S(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@R"FUS9VED(")*86UA:6-A(@IM<V=S='(@(DIA;6%I8V$B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS
M9W-T<B`B2F%N=6%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,3<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-2!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T
M<B`B2F%P86XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B
M2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R(")*87!A;G-K("A)4T\M
M,C`R,BU*4"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T
M<B`B2F5R<V5Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,3@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-"!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@
M(DIO<F1E;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T-@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`X(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I
M9"`B2G5L>2(*;7-G<W1R(")*=6QI(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#<@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(DIU;FDB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS
M9VED(")*=7-T:69Y(@IM<V=S='(@(DIU<W3I<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED(")*
M=7-T:69Y($-E;G1E<B(*;7-G<W1R(")#96YT<NER(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@
M(DIU<W1I9GD@1G5L;"(*;7-G<W1R("),:6=E(&UA<F=E;F5R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*
M;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R(")696YS=')E:G5S=&5R970B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R(")(^&IR96IU
M<W1E<F5T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,3D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R
M(")+87-A:VAS=&%N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(V-0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C8U"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G<W1R(")"979A
M<B!O<FEG:6YA;#\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$R,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(V(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R
M(")+96YY82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#4@
M;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E
M<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B2V5R8F5R
M;W,@<V5R=F5R(&%F=FES=&4@9V]D:V5N9&5L<V4@868@:61E;G1I=&5T+B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE
M=V)I97,B"FUS9W-T<B`B2V5R;F4M/&5M/DYE=V)I97,\+V5M/B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R(").
M^&=L92US:V%B96QS92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q-"!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME
M>2!&:6YG97)P<FEN="(*;7-G<W1R(").^&=L92UF:6YG97)A9G1R>6LB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@
M(D[X9VQE;.9N9V1E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#$Q(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y
M(%1Y<&4B"FUS9W-T<B`B3OAG;&5T>7!E(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.3D@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU.3D*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R(").^&=L96%N=F5N9&5L
M<V4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW-#`@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR96%D>2!E
M>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(D[X9VQE
M(&5K<VES=&5R97(@86QL97)E9&4@<.4@9&5N(&]F9F5N=&QI9V4@;OAG;&5S
M97)V97(N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+
M:61S(@IM<V=S='(@(D+X<FXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$R,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3(Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T
M:2(*;7-G<W1R(")+:7)I8F%T:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,S(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A
M+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(E-Y
M9&MO<F5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,S(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,C,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,R!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(DYO<F1K;W)E82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DQ"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B:V]R96%N<VL@
M*$550RU+4BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$R-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,T(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS9W-T<B`B
M2W5W86ET(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,C4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-R!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R
M(")+:7)G:7-I<W1A;B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z
M.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R(")59&9O<FUN:6YG(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS
M9W-T<B`B4W!R;V<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$R-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,W(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@
M1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("),86]S(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(E-I
M9'-T92!H86QV9&5L(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@X"FUS
M9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R(")3:61S=&4@:V]D
M96]R9'/F;F1R:6YG(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]"
M;&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@
M(E-I9'-T92!K=F%R=&%L(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3@*
M;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B4VED<W0@;W!D871E<F5T
M.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-R!L:6(O2&]R9&4O
M075T:"YP:'`Z-S$W"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ
M("5S(@IM<V=S='(@(E-I9'-T92!L;V=I;CH@)7,B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HW,3D@;&EB+TAO<F1E+T%U=&@N<&AP.C<Q.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S
M='(@(E-I9'-T92!I;F1L;V=N:6YG.B`E<R!F<F$@)7,B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HW,30@;&EB+TAO<F1E+T%U=&@N<&AP.C<Q-`IM
M<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B4VED<W1E(&QO9VEN
M.B!!;&1R:6<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$R-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30V(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B
M3&5T;&%N9"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B
M3&%W(@IM<V=S='(@(DQO=B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@
M(DQA>6]U="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS
M9W-T<B`B5&]M('9E9"!I;F=E;B!R86UM97(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3,X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W"FUS9VED
M("),96)A;F]N(@IM<V=S='(@(DQI8F%N;VXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*;7-G:60@(DQE9G0B
M"FUS9W-T<B`B5F5N<W1R92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,#$@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#$*;7-G:60@(DQE9G0@:&5A
M9&5R(@IM<V=S='(@(E9E;G-T<F4@=&]P=&5K<W0B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,#DW(&QI8B](;W)D92]&;W)M+G!H<#HS,#DW"FUS
M9VED("),969T('9A;'5E<R(*;7-G<W1R(")696YS=')E(';F<F1I97(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30S(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM<V=S='(@(DQE<V]T;R(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B3&5V96PB
M"FUS9W-T<B`B3FEV96%U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,S`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T
M,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB97)I82(*
M;7-G<W1R("),:6)E<FEE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-#<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI8GEA;B!!
M<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B3&EB>65N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$T,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM
M<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("),:65C:'1E;G-T96EN(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G
M:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B4W3X=G)E9VXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@IM<V=I9"`B3&EG
M:'0@4F%I;B(*;7-G<W1R("),970@<F5G;B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN($5A
M<FQY(@IM<V=S='(@(DQE="!R96=N('1I9&QI9W0B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I
M;B!,871E(@IM<V=S='(@(DQE="!R96=N('-E;G0B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B3&EG:'0@4F%I
M;B!3:&]W97(B"FUS9W-T<B`B3&5T(&)Y9V4B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W
M:71H(%1H=6YD97(B"FUS9W-T<B`B3&5T(&)Y9V4@;65D('1O<F1E;B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED
M("),:6=H="!3;F]W(@IM<V=S='(@(DQE="!S;F4B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO
M=R!3:&]W97(B"FUS9W-T<B`B3&5T('-N92!B>6=E(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R(")6:71T
M:6=H960B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$T(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.#$T"FUS9VED("),:6YK(@IM<V=S='(@(DAE;G9I
M<VYI;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G<W1R
M(")&;W)B:6YD('!U;FMT97(@=&EL.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X-S4@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S4*;7-G:60@(DQI
M;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N
M(&1I<W!L87EI;F<B"FUS9W-T<B`B1F]R8FEN9"!E+6UA:6PM861R97-S96X@
M;65D(&EN9'-K<FEV;FEN9W-S:61E;B!V960@9G)E;79I<VYI;F<B"@HC.B!F
M<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@R
M"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,@IM
M<V=I9"`B3&EN:W,B"FUS9W-T<B`B2&5N=FES;FEN9V5R(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T
M<B`B3&EN=7@M:VEK<R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C@V"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S
M,30N<&AP.C0V(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HT-@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI
M<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("),:7-T92`M
M(&)R=6=E<B!K86X@<V4@;6%P<&5N(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$S-`IM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B3&ES="!D871A
M8F%S97(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,0IM<V=I9"`B
M3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R(")/<&QI<W1N:6YG(&%F(&AJYFQP
M965M;F5R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES
M="!486)L97,B"FUS9W-T<B`B3&ES="!T86)E;&QE<B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT(&QI8B](;W)D92]-24U%+TAE
M861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S='(@(DQI
M<W1E+4%R8VAI=F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N
M<&AP.C4X.2!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.#D*;7-G:60@
M(DQI<W0M2&5L<"(*;7-G<W1R("),:7-T+4AE;'`B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4Y-B!L:6(O2&]R9&4O34E-12](96%D
M97)S+G!H<#HU.38*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B3&ES="U)9"(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR(&QI8B](
M;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*
M;7-G<W1R("),:7-T+4]W;F5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.3,@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DS
M"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B3&ES="U0;W-T(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3$@;&EB+TAO<F1E+TU)
M344O2&5A9&5R<RYP:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G
M<W1R("),:7-T+5-U8G-C<FEB92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M2&5A9&5R<RYP:'`Z-3DP(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y
M,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R("),:7-T+55N<W5B
M<V-R:6)E(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4R"B,L('!H<"UF;W)M
M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R
M("),:7-T;FEN9R!A9B!S97-S:6]N<R!F96IL961E.B`E<R(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG
M('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B3&ES=&YI;F<@868@8G)U9V5R
M92!F96IL961E.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES
M="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS
M9W-T<B`B5FES;FEN9R!A9B!B<G5G97)E(&5R('-LY65T(&9R82XB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B"FUS
M9W-T<B`B3&ET=&5R871U<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-#0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI
M82(*;7-G<W1R("),:71A=65N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6UA9V5S+G!H<#HW-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M:6UA9V5S+G!H<#HW-PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R(")(96YT
M97(N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`P"FUS
M9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B3&]K86P@=&ED.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX-@IM<V=I9"`B3&]C86QE(&%N9"!4:6UE
M(@IM<V=S='(@(E)E9VEO;F%L9&%T82!O9R!T:60B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4W,@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C<R(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HR,@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-3<*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(E-T960B"@HC.B!L;V=I
M;BYP:'`Z,3@Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,#`@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`HC.B!T96UP;&%T97,O;&]G:6XO
M;6]B:6QE+FEN8SHS('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U"FUS
M9VED("),;V<@:6XB"FUS9W-T<B`B3&]G(&EN9"(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y
M;F,@<V5S<VEO;B(*;7-G<W1R("),;V<@868@=&ED;&EG97)E('-Y;FMR;VYI
M<V5R:6YG<W-E<W-I;VYE<B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HQ.30*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B3&]G('5D(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q"FUS9VED("),;V=I;B(*;7-G<W1R
M("),;V<@:6YD(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,`IM<V=I
M9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B3&]G:6XM;W!G879E<B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY-2!L:6(O2&]R9&4O075T:"YP:'`Z
M.3DU"FUS9VED("),;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE
M(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R
M("(B"B),;V<@:6YD(&9E:FQE9&4@9F]R9&D@9&ET(&)R=6=E<FYA=FX@96QL
M97(@:V]D96]R9"!B;&5V(&%N9VEV970@9F]R:V5R="XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HY.3$@;&EB+TAO<F1E+T%U=&@N<&AP.CDY,0IM
M<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R("),;V=I;F0@;6ES;'EK:V5D
M97,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3,V-0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(DQA
M;F<@=&5K<W0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@
M(DQO=F4B"FUS9W-T<B`B2^9R;&EG:&5D(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DQO=R(*;7-G<W1R("),
M878B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S
M='(@(E-MY2!G<N9S:V4@=&5G;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA
M=&EN(&QE='1E<G,B"FUS9W-T<B`B4VWE(&QA=&EN<VME('1E9VXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(E-MY2!R
M;VUE<G1A;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#4@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T
M<B`B3'5X96UB;W)G(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#,Y"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S
M.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B
M34TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@S"FUS9VED(")-
M3U1$(@IM<V=S='(@(DU/5$0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T;F5F+G!H<#HS-B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP
M:'`Z,S8*;7-G:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@
M9&%T82XB"FUS9W-T<B`B35,M5$Y%1BUB:6QA9R!I;F1H;VQD="!I;F=E;B!D
M871A+B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*(SH@;&EB+TAO<F1E+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T
M<B`B35-'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,S4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-R!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T<B`B36%C
M86\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$S-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34S(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@
M675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B36%K961O;FEE;BP@1&5N
M('1I9&QI9V5R92!J=6=O<VQA=FES:V4@<F5P=6)L:6LB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,34Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP
M"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@(DUA9&%G87-K87(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*;7-G:60@(DUA9VEC(@IM<V=S='(@
M(DUA9VDB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#,*;7-G:60@
M(DUA:6PB"FUS9W-T<B`B12UM86EL(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C4R-`IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R(")%+6UA:6PM
M861M:6YI<W1R871O<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*
M;7-G<W1R(")$86X@:&5N=FES;FEN9RXN+B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-C4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@
M(DUA;&%W:2(*;7-G<W1R(")-86QA=VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,38W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-
M86QA>7-I82(*;7-G<W1R(")-86QA>7-I82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-C0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@
M(DUA;&1I=F5S(@IM<V=S='(@(DUA;&1I=F5R;F4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,34T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR"FUS
M9VED(")-86QI(@IM<V=S='(@(DUA;&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,38R(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-
M86QT82(*;7-G<W1R(")-86QT82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-`IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@
M>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A
M<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@HB
M2.5N9'3I<B!L:7-T96X@868@:V%T96=O<FEE<BP@<V]M(&1U('-K86P@;6%R
M:V5R92!E;6YE<B!M960L(&]G(&9A<G9E<FYE+"`B"B)D97(@<VMA;"!K;GET
M=&5S('1I;"!D:7-S92!K871E9V]R:65R+B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HQ,34V"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,34V"FUS9VED(")-87`R-"!M87`B"FUS
M9W-T<B`B36%P,C0M:V]R="(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#@W"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,3<Q"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,#@W"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,3<Q"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B36%P
M475E<W0M:V]R="(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P
M-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R(")+;W)T;.9G;FEN
M9R!G96UT+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T,@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`T(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I
M9"`B36%R8V@B"FUS9W-T<B`B36%R=',B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED(")-87)G:6XB
M"FUS9W-T<B`B36%R9V5N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.#@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M-#,Q-"YP:'`Z-#@@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C0X
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B
M36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@(DUA<FOI<B!M
M960@4V5T+U5S970M9FQA9R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C@Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S0S,30N<&AP.C0Y(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HT
M.0HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@
M(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R
M960I(@IM<V=S='(@(DUA<FOI<B!M960@86YD<F4@9FQA9R`H9G@@5FEG=&EG
M+T)E<W9A<F5T*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3(@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N
M9',B"FUS9W-T<B`B36%R<VAA;&SX97)N92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-3D@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@
M(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R=&EN:7%U92(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F:65L9',B
M"FUS9W-T<B`B3W9E<F5N<W!A<W-E;F1E(&9E;'1E<B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-C`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*
M;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B36%U<FET86YI96XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38S(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B36%U<FET:75S(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$U"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS
M9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(DUA>"!T:6QL861T
M(&MR961I="XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#@*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*
M;7-G<W1R(")-86MS:6UU;2!B97-K960M9&5L92!O=F5R<VMR961E="XB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,PIM<V=I9"`B36%X('1E;7`@;&%S
M="`R-"!H;W5R<SH@(@IM<V=S='(@(DUA:W,N('1E;7`N('-I9'-T(#(T('1I
M;65R.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-0IM<V=I9"`B36%X
M('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B36%K<RX@=&5M<"X@<VED
M<W1E(#8@=&EM97(Z("(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI
M;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(DUA:W-I;75M
M(&%N=&%L(&%F('!O<G1A;&)L;VMK92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD@;&EB+TAO<F1E+T9O<FTN<&AP
M.C@Y."!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q-PHC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B36%K
M<VEM=6ULYFYG9&4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#0*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P-B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*
M;7-G:60@(DUA>2(*;7-G<W1R(")-86HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(U,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@
M(DUA>6]T=&4B"FUS9W-T<B`B36%Y;W1T92(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B365D:6-I;B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*;7-G:60@
M(DUE;6)E<G,B"FUS9W-T<B`B365D;&5M;65R(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,X,@IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R(")-96YU
M+71I;'-T86YD.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@
M(D9O<NEN(&-E;&QE<B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@;&EB+TAO<F1E
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G
M<W1R(")"97-K960B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C(Q-B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B
M(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N
M97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM
M<V=S='(@(B(*(D)E<VME9"!S=6-C97-F=6QD="!V97)I9FEC97)E="!M960@
M=6YD97)S:W)I=F5R96YS(&-E<G1I9FEK870@:W5N;F4@:6MK92`B"B)V97)I
M9FEC97)E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,3`*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`B0F5S
M:V5D('5D;/AB970N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(V,`HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-38Y(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,#(*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*;7-G
M:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")"97-K961T>7!E(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S
M='(@(DUE=&%R(%=E871H97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W
M"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")-
M971A<F)L;VL@:6MK92!T:6QGYFYG96QI9RXB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$Q.0IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L
M92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R
M871O<BXB"FUS9W-T<B`B(@HB365T87)B;&]K(&EK:V4@=&EL9^9N9V5L:6<N
M($1E=&%L:F5R(&5R(&)L979E="!N;W1E<F5T('1I;"!B<G5G(&9O<B`B"B)A
M9&UI;FES=')A=&]R96XN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$U,PIM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*;7-G
M<W1R(")-971A<D1"(&5R(&EK:V4@9F]R8G5N9&5T+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW-`HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F%R+G!H<#HV-R!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW
M-`IM<V=I9"`B365T:&]D(@IM<V=S='(@(DUE=&]D92(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+W-O87`N<&AP.C$Q-R!F<F%M97=O<FLO4E!#+U)00R]X;6QR
M<&,N<&AP.C@Q"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HX,2!L:6(O
M2&]R9&4O4E!#+W-O87`N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-
M971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(DUE=&]D92!<
M(B5S7"(@97(@:6MK92!D969I;F5R970B"@HC.B!F<F%M97=O<FLO4E!#+U)0
M0R]R97-T+G!H<#HX,B!L:6(O2&]R9&4O4E!#+W)E<W0N<&AP.C@R"B,L('!H
M<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE
M=&AO9#H@)7,B"FUS9W-T<B`B365T;V1E(&EK:V4@9&5F:6YE9"X@365T;V1E
M(&MA;&1T.B`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#(@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C8W"FUS9VED(")-971R:6,B"FUS9W-T
M<B`B3>5L965N:&5D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-#@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S
M='(@(DUE>&EC;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-#D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@U(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&961E
M<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(DUI:W)O;F5S:65N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R"FUS
M9VED(")-:61D;&4B"FUS9W-T<B`B36ED="(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1N968N<&AP.C,X(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(DU)344M
M='EP92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$W"FUS9VED(")-:6X@
M=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B36EN+B!T96UP+B!S:61S
M=&4@,C0@=&EM97(Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`Y"FUS
M9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(")-:6XN('1E
M;7`N('-I9'-T92`V('1I;65R.B`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C0S.2!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HT,SD*;7-G
M:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B
M"FUS9W-T<B`B36EN:6UU;2!K;V1E;W)D<V%L9&5R(&5R(&5N9&YU(&EK:V4@
M=61S=.5E="(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,S4*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(S-0IM<V=I9"`B36ER<F]R(@IM<V=S='(@(E-P96IL92(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G
M<W1R(")&;W)S:V5L;&EG="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C(U,"!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C<R"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S0P(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI
M<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B36%N
M9VQE<B!014%2+7!A:VME($A45%!?4F5Q=65S="XB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I
M;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T
M;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@HB2V]N9FEG
M=7)A=&EO;B!M86YG;&5R+B!$=2!B;&EV97(@;OAD="!T:6P@870@9V5N97)E
M<F4@9&5N(&YU+"!H=FES(&1U(/AN<VME<B`B"B)A="!B<G5G92!D96YN92!A
M<'!L:6MA=&EO;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#0*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T
M<B`B36%N9VQE<B!B97-K960M:60N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*(SH@;&EB+TYE="]335,O
M=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U
M:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B36%N9VQE<B!K<N9V
M970@4$5!4BUP86MK92!-86EL+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$
M+B(*;7-G<W1R(")-86YG;&5R('-E<W-I;VXM240N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS
M9W-T<B`B36%N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<V"FUS
M9VED(")-;V)I;&4@36%I;"(*;7-G<W1R(")-;V)I;"!%+7!O<W0B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B
M36]D97)A=&4B"FUS9W-T<B`B2N9V;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HX-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<S(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8V"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@U(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<S"FUS9VED(")-;V1I9FEE9"!$871E(@IM
M<V=S='(@(L9N9')I;F=S9&%T;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%52
M3"(*;7-G<W1R("+&;F1R92!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8W-"!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8W
M-`IM<V=I9"`B36]D=6QU<R(*;7-G<W1R(")-;V1U;'5S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$U,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B36]L9&]V
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#D@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R(")-;VYA8V\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U
M,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34V(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R(")-;VYG;VQI
M96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3@T(&QI8B](;W)D
M92]&;W)M+G!H<#HR-3@T"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R
M(")-Y6YE9"!O9R#E<B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-3<@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU-PIM
M<V=I9"`B36]N=&AL>2(*;7-G<W1R(")-Y6YE9&QI9R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-C$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*
M;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B36]N='-E<G)A="(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I
M9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B3>5N969A<V5R(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3DV(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C(X,`HC.B!L:6(O1FEL92]#4U8N<&AP.C$Y-B!L:6(O1FEL92]#
M4U8N<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F
M;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R
M(")&;&5R92!F96QT97(@9G5N9&5T(&D@;&EN:64@)60@96YD(&1E="!F;W)V
M96YT961E("5D+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#@@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T
M<B`B36%R;VMK;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B365S="!S
M:WEF<FET(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B365S="!S:WEE
M="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U
M"FUS9VED(")-;W-T;'D@0VQO=61Y(&%N9"!7:6YD>2(*;7-G<W1R(")-97-T
M('-K>65T(&]G(&)LYG-E;F1E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R
M(")-97-T('-O;"(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z-C0X(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C4P
M.0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T.`IM
M<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(D9L>70@;F5D(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-3(@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="YP:'`Z-3$S"B,Z(&QI8B](;W)D92]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z-C4R"FUS9VED(")-;W9E($QE9G0B"FUS9W-T
M<B`B1FQY="!T:6P@=F5N<W1R92(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z-C4V(&QI8B](;W)D92]";&]C:R],87EO
M=70N<&AP.C4Q-PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C8U-@IM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R(")-;V0@:/AJ<F4B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C8T-"!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HU,#4*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#0*;7-G:60@(DUO=F4@
M57`B"FUS9W-T<B`B1FQY="!O<"(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HU,C8*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4R-@IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(D9L
M>70@;F5D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C4R-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-3(V"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU
M,C4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM<V=I
M9"`B36]V92!U<"(*;7-G<W1R(")&;'ET(&]P(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$V."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I
M9"`B36]Z86UB:7%U92(*;7-G<W1R(")-;V-A;6)I<75E(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$X
M-`IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@
M(DUU;'1I+6YI=F5A=2!R=6QL96=A<F1I;G-L:7-T97(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U.0HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U.0IM<V=I9"`B375L=&EM
M87`@54L@;6%P(@IM<V=S='(@(DUU;'1I;6%P(%5+(&MO<G0B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0R(&QI8B](;W)D92]&;W)M+G!H<#HR
M,C0R"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B375L=&EP
M;&4@=F%L9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#(*;7-G
M:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B36EN(&MO;G1O(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T
M:6]N(@IM<V=S='(@(DUI;F4@:V]N=&\M:6YF;W)M871I;VYE<B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-#0*;7-G:60@(DUY(%!O<G1A;"(*
M;7-G<W1R(")-:6X@4&]R=&%L(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N
M<&AP.C0R"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(DUI;B!0
M;W)T86PM=61F;W)M;FEN9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-34@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B
M"FUS9W-T<B`B37EA;FUA<B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M
M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B
M"FUS9W-T<B`B3D5*+"!J96<@97(@24M+12!E;FEG(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,3$*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N
M968N<&AP.C,X(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B3F%M92(*
M;7-G<W1R(").879N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-3<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V.2!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G
M<W1R(").86UI8FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-3@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W."!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T
M<B`B3F%U<G4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$U.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<W(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R(").
M97!A;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S4@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@
M(DYE9&5R;&%N9&5N92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-C$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!
M;G1I;&QE<R(*;7-G<W1R(")(;VQL86YD<VME($%N=&EL;&5R(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E($)A<V4@55),(@IM
M<V=S='(@(DYE='-C87!E($)A<V4@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.#0@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU.#0*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S
M='(@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS
M9W-T<B`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3@U"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R
M(").971S8V%P92!296YE=V%L(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@S(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3@S"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R(").
M971S8V%P92!2979O8V%T:6]N(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@W(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3@W"FUS9VED(").971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B
M3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.#@@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU.#@*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS
M9W-T<B`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!T
M>7!E(@IM<V=S='(@(DYE='-C87!E(&-E<G1I9FEC=&4@='EP92(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3,*;7-G:60@(DYE='=O<FLB"FUS
M9W-T<B`B3F5T=N9R:R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0R-2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C4*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,S.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP
M"FUS9VED(").979E<B(*;7-G<W1R(")!;&1R:6<B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3<P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS
M9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(DYY($MA;&5D;VYI96XB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU
M,`HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM
M<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(DYY(&MA=&5G;W)I(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G<W1R
M(").>6WE;F4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R(").
M>70@8G)U9V5R;F%V;B`H=F%L9V9R:70I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$X,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B
M3F5W(%IE86QA;F0B"FUS9W-T<B`B3F5W(%IE86QA;F0B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*;7-G:60@(DYE=R!P87-S=V]R9"(*
M;7-G<W1R(").>70@:V]D96]R9"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<W%L+G!H<#HR,C<@;&EB+TAO<F1E+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X
M+B(*;7-G<W1R(").>70@:V]D96]R9"!V:6P@=61L^&)E(&1E;B`E>"XB"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@(DYE=R!P
M87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(DYY92!K;V1E;W)D(&5R
M(&EK:V4@96YS+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T
M<B`B3GET('9I;F1U92`H7V)L86YK*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU,B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,`HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,CDQ"FUS9VED(").97=S(@IM<V=S='(@(DYY:&5D
M97(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`W"FUS9VED(").
M97=S9W)O=7!S(@IM<V=S='(@(DYY:&5D<V=R=7!P97(B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHR-2!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C$R.0HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,2!T96UP
M;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-0IM<V=I9"`B3F5X="(*;7-G<W1R
M(").YG-T92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X
M="`T(%!H87-E<R(*;7-G<W1R(").YG-T92`T(&9A<V5R(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HS-S`*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-C8@
M;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-S`*;7-G:60@(DYE>'0@;W!T:6]N
M<R(*;7-G<W1R(").YG-T92!T:6QV86QG(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U!A9V5R+G!H<#HQ,#,@;&EB+TAO<F1E+U5)+U!A9V5R+G!H<#HQ,#,*;7-G
M:60@(DYE>'0^(@IM<V=S='(@(D[F<W1E/B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-S0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@
M(DYI8V%R86=U82(*;7-G<W1R(").:6-A<F%G=6$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3<Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS
M9VED(").:6=E<B(*;7-G<W1R(").:6=E<B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-S,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@
M(DYI9V5R:6$B"FUS9W-T<B`B3FEG97)I82(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS-CD*;7-G:60@(DYI9VAT(@IM<V=S='(@(DYA="(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-SD@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3<*;7-G:60@(DYI=64B"FUS9W-T<B`B3FEU92(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C8*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-@IM<V=I9"`B3F\B
M"FUS9W-T<B`B3F5J(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N
M:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A
M('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R("));F=E;B!T:6QG
MYFYG96QI9V4@:V]N9FEG=7)A=&EO;F1A=&$@870@=FES92!F;W)S:V5L;&4@
M9F]R+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP
M:'`Z,3`V(&QI8B]61E,O25-/5W)I=&5R+G!H<#HQ,#8*;7-G:60@(DYO(&%V
M86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S
M='(@(DEN9V5N('1I;&?F;F=E;&EG('-T<F%T96=I('1I;"!A="!L879E($E3
M3RUB:6QL961E<BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,3,*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R
M("));F=E;B!S:W)I<'0M<VMA8F5L;VXN(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,#$*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HS.#4*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT,#<@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="YP:'`Z-SD*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="YP:'`Z,C0U(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C(V-PHC.B!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P,0HC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C,X-0HC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0P-PIM<V=I9"`B3F\@8FQO
M8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B
M1&5R(&5K<VES=&5R97(@:6MK92!N;V=E;B!B;&]K('#E(&1E;B!F;W)E<W!U
M<F=T92!P;W-I=&EO;B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP
M:'`Z-3`@;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'`Z-3`*;7-G:60@(DYO(&-A
M;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(DEN9V5N(&MA;&5N9&5R(&%N9VEV970@=&EL($U#04PMYF=T
M;FEN9RXB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`IM<V=I9"`B3F\@
M8VAA;F=E+B(*;7-G<W1R("));F=E;B#F;F1R:6YG+B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,34V(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI
M<R!P97)M:7-S:6]N+B(*;7-G<W1R(")$97(@:V%N(&EK:V4@=&EL9OAJ97,@
M8OAR;B!T:6P@9&5N;F4@=&EL;&%D96QS92XB"@HC.B!F<F%M97=O<FLO571I
M;"]5=&EL+G!H<#HW-C@@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S@*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3<@;&EB+TAO<F1E+G!H
M<#HQ-S@@;&EB+TAO<F1E+G!H<#HU,3<*(SH@;&EB+TAO<F1E+U5T:6PN<&AP
M.C<V.`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(DEN9V5N(&MO
M;F9I9W5R871I;VXM:6YF;W)M871I;VX@86YG:79E="!F;W(@)7,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-34@;&EB+U9&4R]F='`N<&AP
M.C@U-0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R($944"!61E,N(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R871I
M;VXM:6YF;W)M871I;VX@86YG:79E="!F;W(@1E10(%9&4RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W,B!L:6(O5D93+W-Q;"YP:'`Z-C<R
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B26YG96X@:V]N9FEG=7)A=&EO;BUI
M;F9O<FUA=&EO;B!A;F=I=F5T(&9O<B!344P@5D93+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C4@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z-S(U"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("));F=E;B!K;VYF
M:6=U<F%T:6]N+6EN9F]R;6%T:6]N(&%N9VEV970@9F]R(%-13"U&:6QE(%9&
M4RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,30*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,30*;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R(")+<F5D:70@=61T
M^&UT+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,T"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R("))
M;G1E="!B97-T96UM96QS97-S=&5D(&%N9VEV970N(@H*(SH@9G)A;65W;W)K
M+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3(P(&QI8B](;W)D92]"<F]W<V5R+G!H
M<#HY,C`*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B26YG96X@
M9FEL('-E;F1T(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED
M(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B1F%N9'0@:6YG96X@:6MO;F5R
M+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3,P(&QI8B]";&]C:R]S=6YR
M:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$V
M"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(DEN=&5T('-T
M960@:6YD<W1I;&QE="XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,34W"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B
M26YT970@<W1E9"!A;F=I=F5T+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N
M(@IM<V=S='(@(DEN9V5N(&)E<VME9"!A;F=I=F5T+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@
M<W!E8VEF:65D+B(*;7-G<W1R("));G1E="!N879N(&%N9VEV970N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B
M3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B26YT970@;G5M;65R(&%N
M9VEV970N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED(").
M;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B26YG96X@86YS=/AD96QI
M9V4@97!I9W)A;6UE<B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP
M:'`Z.3$@;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R("));G1E="!K;V1E;W)D(&%N9VEV970@=&EL(&)R=6<@9F]R($A45%`M
MYF=T;FEN9RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C$P
M."!L:6(O2&]R9&4O075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M("));G1E="!K;V1E;W)D(&%N9VEV970@=&EL(&)R=6<@9F]R($E-05`MYF=T
M;FEN9RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C<R(&QI
M8B](;W)D92]!=71H+VMR8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(DEN=&5T(&MO9&5O<F0@86YG:79E="!T:6P@8G)U9R!F;W(@2V5R8F5R;W,M
MYF=T;FEN9RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<#HX
M-"!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S87-L+G!H<#HW-R!L:6(O2&]R9&4O075T:"]L;V=I;BYP
M:'`Z.#0*(SH@;&EB+TAO<F1E+T%U=&@O<&%M+G!H<#HW-2!L:6(O2&]R9&4O
M075T:"]S87-L+G!H<#HW-PIM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("));G1E="!K;V1E
M;W)D(&%N9VEV970@9F]R($QO9VEN9"WF9W1N:6YG+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<&%S<W=D+G!H<#HQ,S4@;&EB+TAO<F1E+T%U=&@O<&%S
M<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!0
M05-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DEN=&5T(&MO9&5O<F0@
M86YG:79E='0@=&EL(%!!4U-71"WF9W1N:6YG+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<VUB+G!H<#HX-"!L:6(O2&]R9&4O075T:"]S;6(N<&AP.C@T
M"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R("));G1E="!K;V1E;W)D(&%N9VEV970@9F]R(%--
M0BWF9W1N:6YG+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,3(X-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R.#<*;7-G:60@
M(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4
M:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET
M:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*(E-T:2!T:6P@3W!E;E-33"UB
M:6)L:6]T96ME="!M86YG;&5R+B`@3W!E;E-33"UB:6)L:6]T96ME="!E<B!N
M^&1V96YD:6=T(&9O<B`B"B)A="!HY6YD=&5R92!02T-3,3(M9&%T82XB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").
M;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@(DEN9V5N('9E;G1E;F1E(&]P
M<VMR:79N:6YG97(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C<V-B!L
M:6(O5D93+G!H<#HW-C8*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B
M2W9O=&4@:6MK92!I;F1S=&EL;&5T+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S
M(@IM<V=S='(@(DEN9V5N('-T<F5G97(B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HT.#(@;&EB+T9I;&4O0U-6+G!H<#HT.#(*;7-G:60@(DYO
M('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@(DEN9V5N('-K:6QL971E
M9VX@86YG:79E="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0T"FUS9VED(").;R!S:61E<R(*;7-G<W1R("))
M;F=E;B!S:61E<B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@W
M(&QI8B]61E,O<VUB+G!H<#HU.#<*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G
M<W1R("));F=E;B!SY61A;B!F:6PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,3(V"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V
M86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(D1E<B!M86YG;&5R(&5T(&UI
M9&QE<G1I9&EG="!K871A;&]G('1I;"!M96QL96UL86=E<BXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,2!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&QI8B].970O4TU3+W=I
M;E]H='1P+G!H<#HR,C$*;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S
M=V]R9"!S96YT+B(*;7-G<W1R("));G1E="!B<G5G97)N879N(&]G+V5L;&5R
M(&MO9&5O<F0@<V5N9'0N(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C
M+G!H<#HQ-#`@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B
M3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B26YG96X@9WEL
M9&EG92!834PM9&%T82!R971U<FYE<F5T(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW-`HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY.34*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P,3(*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDW-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.3@T"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HY.34*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P,3(*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("));F=E;B!VYG)D:65R
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R
M<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(D]R:6=I;F%L(&MO;F9I
M9W5R871I;VX@;6%N9VQE<B!V97)S:6]N<VYU;6UE<BX@4F5G96YE<NER(&MO
M;F9I9W5R871I;VXN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM
M<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN
M(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B1&EN(&MO;F9I
M9W5R871I;VX@;6%N9VQE<B!V97)S:6]N<VYU;6UE<BX@4F5G96YE<NER(&MO
M;F9I9W5R871I;VXN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#(W(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R-PHC.B!T96UP;&%T
M97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*;7-G:60@(DYO
M;F4B"FUS9W-T<B`B26YG96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I
M(@IM<V=S='(@(DEN9V5N("AB<G5G(&EM<&QI8VET*2(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DR"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*
M;7-G<W1R(").;W)D:7-K("A)4T\M.#@U.2TQ,"DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3<R(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS
M9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R(").;W)F;VQK(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I
M9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(").;W)D;&EG92!H86QV
M:W5G;&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$V.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34X(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES
M;&%N9',B"FUS9W-T<B`B3F]R9&QI9V4@36%R:6%N8?AE<B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-S8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R(").;W)G92(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0Q(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-C0Q"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B26MK92!S
M96YE<F4@96YD(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-#`@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO
M="!"969O<F4B"FUS9W-T<B`B26MK92!F^'(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HT,34@;&EB+U9&4R]F:6QE+G!H<#HT,34*;7-G:60@
M(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R(")):VME(&YO9V5T(&MA=&%L;V<B
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2YP:'`Z-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU.0HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+G!H<#HX-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-0HC.B!L:6(O5D93+TE33U=R:71E
M<BYP:'`Z-C,@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+G!H<#HX-`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E
M9WDN<&AP.CDU"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+G!H<#HT.`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B
M26MK92!I;7!L96UE;G1E<F5T+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B"FUS9W-T<B`B
M26MK92!I;F1S=&EL;&5T(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y
M,R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(U,@HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,C8Y(&9R86UE=V]R:R]61E,O5D93+G!H<#HR
M.#4*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,P,2!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z,S$V"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,S,@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C,V-@HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z-#(V(&9R86UE=V]R:R]61E,O5D93+G!H<#HU,#4*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C4W-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3DQ"B,Z
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HV-CD@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#4*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-C`*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S4*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ
M.#D*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R
M+G!H<#HR,S8@;&EB+U9&4RYP:'`Z,3DS"B,Z(&QI8B]61E,N<&AP.C(P."!L
M:6(O5D93+G!H<#HR,S0@;&EB+U9&4RYP:'`Z,C4R(&QI8B]61E,N<&AP.C(V
M.0HC.B!L:6(O5D93+G!H<#HR.#4@;&EB+U9&4RYP:'`Z,S`Q(&QI8B]61E,N
M<&AP.C,Q-B!L:6(O5D93+G!H<#HS,S,*(SH@;&EB+U9&4RYP:'`Z,S8V(&QI
M8B]61E,N<&AP.C0R-B!L:6(O5D93+G!H<#HU,#4@;&EB+U9&4RYP:'`Z-3<T
M"B,Z(&QI8B]61E,N<&AP.C4Y,2!L:6(O5D93+G!H<#HV-CD@;&EB+TAO<F1E
M+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#4*(SH@;&EB+TAO<F1E+U-E<W-I;VY(
M86YD;&5R+G!H<#HQ-C`@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ
M-S4*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#D@;&EB+TAO
M<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HR,S8*;7-G:60@(DYO="!S=7!P;W)T
M960N(@IM<V=S='(@(DEK:V4@=6YD97)S=/AT=&5T+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,#@*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,#@@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0*(SH@8V]N9FEG
M+VAO;VMS+G!H<"YD:7-T.C$P-3@@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$X,`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B3F]T97(B"@HC.B!S97)V:6-E
M<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O
M=W-E+"!G;R!B86-K+B(*;7-G<W1R("));G1E="!A="!B<F]W<V4L('9E;F0@
M=&EL8F%G92XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-3`*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*;7-G
M:60@(DYO=F5M8F5R(@IM<V=S='(@(DYO=F5M8F5R(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`T-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`T-@IM
M<V=I9"`B3G5M8F5R(@IM<V=S='(@(E1A;"(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T,C4@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C4*;7-G:60@
M(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(D%N=&%L('1E9VXB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T
M-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,V.0HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,30R,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R
M(&]F(&-O;'5M;G,B"FUS9W-T<B`B06YT86P@:V]L;VYN97(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,R!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3,V-PHC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R
M,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T,PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O
M=W,B"FUS9W-T<B`B06YT86P@<N9K:V5R(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E
M8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS
M9W-T<B`B5&%L(&EK:V4@86YG:79E="!F;W(@;W!D871E<FEN9R!I(&1I<W1R
M:6)U=&EO;G-L:7-T92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@(D]+(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PHC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE
M8W0B"FUS9W-T<B`B3V)J96MT(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(D]B:F5K
M=&1A;FYE<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,#0@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(D]K
M=&%L(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0Y"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/
M8W1O8F5R(@IM<V=S='(@(D]K=&]B97(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(D%N<W3X
M9&5N9&4@9FEL=&5R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R
M.`IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(DMO;G1O<B(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S
M<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R(")'86UM96QT(&]G
M(&YY="!K;V1E;W)D('-K86P@=N9R92!F;W)S:V5L;&EG92XB"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*;7-G:60@(D]L9"!P87-S=V]R
M9"(*;7-G<W1R(")'86UM96QT(&MO9&5O<F0B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@
M8V]R<F5C="XB"FUS9W-T<B`B1V%M;65L="!K;V1E;W)D(&5R(&EK:V4@:V]R
M<F5K="XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$W,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Q(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@(D]M86XB
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW,R!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@
M24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@
M(D1E;'1E(&UA<'!E<B!U;F1E<G-T^'1T97,@:W5N(&%F($E-05`M<V5R=F5R
M92XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@
M;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(DMU;B!A;G-T^&1E;&EG92!E
M<&EG<F%M;65R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U,2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ.#4Q(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<Q"FUS9VED(")/;FQY
M(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(DMU;B#I;B!E
M+7!O<W0M861R97-S92!T:6QL861T+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E
M9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M
M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@
M(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HB16X@9&5L
M:6YG<R!E:F5R<VMA8B!O9R!E:F5R=&EL;&%D96QS97(@;>4@:W5N(.9N9')E
M(&%F(&5N("(*(G-Y<W1E;6%D;6EN:7-T<F%T;W(@96QL97(@96IE<F5N('-E
M;'8B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HT,2!L:6(O0FQO8VLO:69R
M86UE+G!H<#HT,@IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T
M<B`BQ6)E;B!I(&5T(&YY="!V:6YD=64B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C(T-2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@
M9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B3W!E;E-3
M3"UF96IL.B!$871A(&MU;FYE(&EK:V4@=61D<F%G97,@9G)A('-I9VYE<F5T
M(%,O34E-12UD96PN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@
M:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(L5B96X@9&5N;F4@:&5N=FES;FEN
M9R!I(&5T(&YY="!V:6YD=64B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B3W!E<F%T:79S
M>7-T96TB"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS
M9VED(")/<'1I;VYS(@IM<V=S='(@(DEN9'-T:6QL:6YG97(B"@HC.B!S97)V
M:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B
M26YD<W1I;&QI;F=E<B!F;W(@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS
M9W-T<B`B3W)D;F5T(&QI<W1E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-C@@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C@*
M;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R(")/<F=A;FES871I;VXB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.2!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B3W)G86YI<V%T:6]N86P@
M56YI="(*;7-G<W1R(")/<F=A;FES871O<FES:R!E;FAE9"(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S0*;7-G:60@(D]R9V%N:7II;F<B"FUS
M9W-T<B`B3W)G86YI<V5R:6YG(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S
M='(@(D]P<FEN9&5L:6<@87!P;&EK871I;VYS<VMA8F5L;VXB"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG
M:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(D]P<FEN9&5L:6=E('-K
M86)E;&]N97(@:2`E<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.0HC.B!S97)V:6-E
M<R]K97EB;V%R9"YP:'`Z,3$W('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(D%N9&5N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDY(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3(U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-`IM<V=I9"`B3W1H97(@26YF
M;W)M871I;VXB"FUS9W-T<B`B06YD96X@:6YF;W)M871I;VXB"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S
M:6]N<R(*;7-G<W1R(")%:F5R<F5T=&EG:&5D97(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W!A;2YP:'`Z-SD@;&EB+TAO<F1E+T%U=&@O<&%M+G!H<#HW
M.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(E!!32WF9W1N:6YG(&5R(&EK:V4@=&EL9^9N9V5L:6=E+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P
M-2!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!
M4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(E!%05(Z.DUA:6PM;6]T;W(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<V(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C$R-S8*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA
M='5R92(*;7-G<W1R(")01U`@9&EG:71A;"!S:6=N871U<B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,C(@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z,3,R,@IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S
M='(@(E!'4"UK<GEP=&5R970@9&%T82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$S-S0@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,W
M-`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B3V9F96YT;&EG(%!'
M4"UN^&=L92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S
M-38@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,U-@IM<V=I9"`B4$=0(%-I
M9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R(")01U`M<VEG;F5R970O:W)Y
M<'1E<F5T(&1A=&$B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-CD*;7-G:60@
M(E!(4"!#;V1E(@IM<V=S='(@(E!(4"UK;V1E(@H*(SH@861M:6XO<&AP<VAE
M;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B4$A0+7-K86PB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM
M<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R(")%9G1M+B!L970@<F5G;B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS
M9VED(")032!286EN(@IM<V=S='(@(D5F=&TN(')E9VXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VAO
M=V5R<R(*;7-G<W1R(")%9G1M+B!B>6=E<B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")032!3;F]W(@IM<V=S
M='(@(D5F=&TN('-N92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0R"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B
M169T;2X@<VYE8GEG97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,PIM<V=I9"`B4$T@4W5N(@IM<V=S='(@(D5F=&TN('-O
M;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T
M"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R(")%9G0N('1O<F1E;B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.#8*;7-G:60@(E!/4TE8(&5X=&5N
M<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(E!/4TE8+75D=FED9&5L<V4@;6%N
M9VQE<B(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L;"(*
M;7-G<W1R(")02%`M<VMA;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T
M<B`B1F]R<FEN9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#<@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S
M='(@(E!A:VES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.30@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QA=2(*;7-G
M<W1R(")086QA=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$W-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DR(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@
M5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R(")086SF<W1I;F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@R(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDX"FUS9VED(")086YA;6$B"FUS9W-T<B`B4&%N86UA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$X-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R(")087!U82!.
M>2!'=6EN96$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-S<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-2!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S
M='(@(E!A<F%G=6%Y(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S<*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B1&5L
M=FES="!S:WEE="(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M,3@*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-R!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!L:6(O3F5T+U--
M4R]W:6Y?:'1T<"YP:'`Z,34Q(&QI8B](;W)D92]&;W)M+G!H<#HR,#$X"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#(U"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")+;V1E;W)D(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R
M9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B2V]D96]R9"#F;F1R
M970N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(S
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3,R,PIM<V=I9"`B4&%S<W=O
M<F0@:6YC;W)R96-T(@IM<V=S='(@(DMO9&5O<F0@9F]R:V5R="(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(@;&EB+TAO<F1E+T%U
M=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O
M<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DMO9&5O<F0@:W+F
M=F5T('9E9"!2041)55,MYF=T;FEN9RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#4S(&QI8B](;W)D92]&;W)M+G!H<#HR,#4S"FUS9VED(")0
M87-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")+;V1E;W)D(&UE
M9"!B96MRYF9T96QS92(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(DMO9&5O<F0Z(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D
M.B`B"FUS9W-T<B`B2V]D96]R9#H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S0@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(P,S0*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ
M-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(DMO9&5O
M<F1E;F4@<VMA;"!VYG)E(&5N<RXB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3(P('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B26YD<^9T(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B
M4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`B26YD<^9T(&9R82!U9&ML
M:7!S:&]L9&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R(")3=&DB"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N
M=7!S.B(*;7-G<W1R(")696YT96YD92!O<'-K<FEV;FEN9V5R.B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@
M(D9O;&LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R(")0<F]C96YT(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G
M:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")5
M9&;X<B!V961L:6=E:&]L9&5L<V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#$P"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M;VX@;&]G:6X_(@IM<V=S='(@(E5D9OAR('9E9&QI9V5H;VQD96QS92!V960@
M;&]G(&EN9#\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U
M-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO
M;B(*;7-G<W1R(")4:6QL861E;'-E<B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S
M7"(@;F]T(&1E;&5T960N(@IM<V=S='(@(E1I;&QA9&5L<V4@7"(E<UPB(&EK
M:V4@<VQE='1E="XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4Y
M,"!L:6(O5D93+W-M8BYP:'`Z-3DP"FUS9VED(")097)M:7-S:6]N($1E;FEE
M9"(*;7-G<W1R(")4:6QL861E;'-E(&[F9W1E="(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,38T"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,38Q(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*;7-G
M<W1R(")4:6QL861E;'-E<B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HV,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"B,Z(&%D;6EN+W!E<FUS
M+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(*;7-G:60@
M(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E1I;&QA9&5L
M<V5S+6%D;6EN:7-T<F%T:6]N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8X"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R(")0<F]F
M:6QE<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#,@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B4&5R=2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G
M<W1R(")+YFQE9'ER(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-SD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B
M"FUS9W-T<B`B1FEL:7!P:6YE<FYE(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$Y-@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B"FUS9W-T<B`B5&5L969O
M;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#`*;7-G:60@(E!H
M;W1O<R(*;7-G<W1R(")&;W1O<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3DP(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET
M8V%I<FXB"FUS9W-T<B`B4&ET8V%I<FXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S
M='(@(E!R:6MK97(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G
M:60@(E!L871I='5D97,B"FUS9W-T<B`B0F%N86QI=&5T97(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS
M9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B2VQI
M:R!I(&5N(&-E;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T
M:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@
M(D)E:W+F9G0@870@9'4@^&YS:V5R(&%T('-L971T92!D971T92!E;&5M96YT
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N
M="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R(")"96MRYF9T(&%T
M(&1U(/AN<VME<B!A="!A9FSF;FME(&1E='1E(&5L96UE;G0N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4V,B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C4V,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB
M"FUS9W-T<B`B26YD=&%S="!E;B!MY6YE9"!O9R!E="#E<G-T86PN(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G
M:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ
M(@IM<V=S='(@(DEN9'1A<W0@970@;F%V;B!T:6P@9&5N(&YY92!K871E9V]R
M:3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Q(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,S`Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)
M4"!A9&1R97-S+B(*;7-G<W1R("));F1T87-T(&5N(&=Y;&1I9R!)4"UA9')E
M<W-E+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-#`@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(V-#`*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED
M(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N
M(@IM<V=S='(@(DEN9'1A<W0@96X@9WEL9&EG(&1A=&\L('1J96L@86YT86QL
M970@868@9&%G92!I(&WE;F5D96XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C0T-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0T-PIM<V=I9"`B4&QE
M87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B26YD=&%S="!E;B!G
M>6QD:6<@=&ED<V%N9VEV96QS92XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@
M;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(E-K<FEV('9E;FQI9W-T+"!H=F%D
M('!R;V)L96UE="!GY7(@=60@<.4@;V<@:'9A9"!D97(@<VME<BXB"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA
M;64@86YD('!A<W-W;W)D(@IM<V=S='(@(DEN9'1A<W0@=F5N;&EG<W0@8G)U
M9V5R;F%V;B!O9R!K;V1E;W)D(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E
M>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@
M(@HB<WES=&5M+B(*;7-G<W1R("(B"B),YG,@9OAL9V5N9&4@=&5K<W0N($1U
M(%-+04P@=N9R92!E;FEG(&D@8F5T:6YG96QS97)N92!F;W(@870@8G)U9V4@
M<WES=&5M970N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y
M36%N86=E<BYP:'`Z-S`*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O
M<GD@;F%M93HB"FUS9W-T<B`B26YD=&%S="!D970@;GEE(&MA=&5G;W)I;F%V
M;CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$X,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@X(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDY"FUS9VED(")0;VQA;F0B"FUS9W-T<B`B4&]L96XB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S
M(@IM<V=S='(@(E!O;&ET:6LB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#@Y"FUS9VED(")0;VQL<R(*;7-G<W1R(")-96YI;F=S;>5L:6YG97(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DS(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.#(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,R!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(E!O<G1U
M9V%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(T"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM
M86=E(@IM<V=S='(@(E!L86-E<FEN9R!A9B!B:6QL961E="(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0
M;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(E!L86-E<FEN9R!A
M9B!D96YN92!T86)E;"(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.CDQ"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S
M,30N<&AP.C4Q(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU,0HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O
M<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G
M<W1R(")396YD('1I;"!D96YN92!M87!P92`H:6MK92!G96YN96UT=G5N9V5T
M(&%F($E-05`I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S,@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP
M:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B3F5D8OAR
M(&=E;FYE;2!S96YE<W0@)7,@=&EM97(Z("(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR.#<*;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC
M:&%N8V4B"FUS9W-T<B`B3F5D8OAR/&)R("\^8VAA;F-E(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+VQD87`N<&AP.CDX(&QI8B](;W)D92]0<F5F<R]L
M9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L9&%P.B!+<N9V
M970@3$1!4"UU9'9I9&1E;"!I:VME(&9U;F1E="XB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,@;&EB+TAO<F1E+U!R969S+W-E
M<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S
M97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7W-E
M<W-I;VXZ($MRYG9E="!S97-S:6]N+75D=FED9&5L<V4@:6MK92!F=6YD970N
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S(*;7-G:60@(E!R97-S=7)E
M(@IM<V=S='(@(E1R>6LB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-@IM
M<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B5')Y:R!V
M960@;W9E<F9L861E;CH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(R-`IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R(")4<GEK.B`B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`S"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,#,*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(P"FUS9VED(")0<F5V:65W(@IM<V=S='(@(D=L:6UT(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q
M"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS
M9W-T<B`B0F5T<F%G="!B:6QL961E="!I(&5T(&YY="!V:6YD=64B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,U-B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C,V,`HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP
M.C,U-B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V,`IM<V=I9"`B4')E=FEO
M=7,@;W!T:6]N<R(*;7-G<W1R(")&;W)R:6=E('1I;'9A;&<B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0
M<FEN="!D;V-U;65N="(*;7-G<W1R(")59'-K<FEV(&1O:W5M96YT(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B
M4')I=F%T(&[X9VQE(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N
M<&AP.C$V.2!L:6(O2&]R9&4O365N=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M
M(@IM<V=S='(@(E!R;V)L96TB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ
M,C<*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B4')O8FQE
M;6)E<VMR:79E;'-E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W
M,0IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B4')O:F5K=&5R(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,3@X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-S8@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(Q,3$*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q
M.#@@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S8*;7-G:60@(E!R;VUP="!T97AT
M(@IM<V=S='(@(E-T:6MO<F1S=&5K<W0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,C,@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(S
M"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(D]F9F5N=&QI9V4@;OAG;&4B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T-@IM<V=I9"`B4'5B;&EC($ME>2!!
M;&=O<FET:&TB"FUS9W-T<B`B3V9F96YT;&EG+6[X9VQE+6%L9V]R:71M92(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($EN
M9F\B"FUS9W-T<B`B3V9F96YT;&EG(&[X9VQE(&EN9F]R;6%T:6]N(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I
M<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B3V9F96YT
M;&EG+W!R:79A="UN^&=L97/F="UG96YE<F5R:6YG(&UI<VQY:VME9&5S+B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X
M,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DQ(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B4'5E
M<G1O(%)I8V\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T
M+G!H<#HU-2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-34*;7-G
M:60@(E!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(E5D<F5N<R!B97-K961E<B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X
M-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DV(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B46%T87(B"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C0*;7-G:60@(E%U97)Y(@IM<V=S='(@
M(D9O<F5S</AR9W-E;"(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,`IM
M<V=I9"`B475O=&$B"FUS9W-T<B`B2W9O=&4B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8V-"!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C8V-`HC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H
M)60@8FET*2(*;7-G<W1R(")/9F9E;G1L:6<@4E-!+6[X9VQE("@E9"!B:70I
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-"!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C(V-`IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@
M(D5N:V5L='9I<R!V86QG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6XB"FUS9W-T<B`B4F5G;B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS9VED
M(")286EN($5A<FQY(@IM<V=S='(@(E)E9VX@=&ED;&EG="(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN
M($QA=&4B"FUS9W-T<B`B4F5G;B!S96YT(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@4VAO=V5R(@IM
M<V=S='(@(E)E9VYB>6=E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@
M(E)E9VX@;V<@<VYE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3`*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R(")3;'5D
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&
M;W)T=6YE(@IM<V=S='(@(E1I;&;F;&1I9W0@97!I9W)A;2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HW-@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<F%R+G!H<#HV."!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H
M<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B1F]R:&]L9"(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,S(T(&QI8B](;W)D92]097)M<RYP:'`Z
M,S(T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.CDQ('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3,W('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(DSF<R(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C0W(&QI8B](;W)D92])34%0
M+T%#3"]R9F,T,S$T+G!H<#HT-PHC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.#<*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B3.9S
M(&)E<VME9&5R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN
M8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H
M:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(E9I<FME
M;&EG('-L971T92`E<S\@1&5N;F4@;W!E<F%T:6]N(&MA;B!I:VME(&)L:79E
M(&]M9VIO<G0N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A
M=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N(@IM<V=S='(@(B(*(E9I<FME;&EG('-L971T92!D871A(&9O<B!B<G5G
M97(@)7,_($1E;FYE(&]P97)A=&EO;B!K86X@:6MK92!B;&EV92!O;6=J;W)T
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(D]M
M9_AR(&1I;B!S:61S=&4@:&%N9&QI;F<B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F
M<F5S:"(*;7-G<W1R(")/<&1A=&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Y-0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z
M(@IM<V=S='(@(D]P9G)I<VL@9'EN86UI<VME(&UE;G4M96QE;65N=&5R.B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#4*;7-G:60@(E)E9G)E<V@@
M4&]R=&%L(%9I97<Z(@IM<V=S='(@(D=E;F]P9G)I<VL@<&]R=&%L=FES;FEN
M9SHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.30@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C,U(&QI8B](;W)D92]&;W)M+G!H<#HX.30@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$R,3,*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,S4*;7-G:60@(E)E
M9V5X(@IM<V=S='(@(E)E9W5LYG)T('5D=')Y:R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,R,S$@;&EB+TAO<F1E+T9O<FTN<&AP.C,R,S$*;7-G
M:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(E)E;&%T:6]N<VSF
M<V5R(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM<V=I9"`B4F5L;V%D(@IM<V=S
M='(@(D=E;F]P9G)I<VLB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S,PIM
M<V=I9"`B4F5M87)K<R(*;7-G<W1R(").;W1E<B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,3<*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@
M(D9J97)N92!S97)V97)E(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*3HB"FUS9W-T<B`B1FIE<FX@55),("AH='1P.B\O=W=W+F5K
M<V5M<&5L+F1K+VAO<F1E*3HB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A
M<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q
M=65U960N:6YC.C$S('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z
M,C(*;7-G:60@(E)E;6]V92(*;7-G<W1R(")3;&5T(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@0FQO8VLB"FUS
M9W-T<B`B4VQE="!B;&]K(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4U.0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-34Y"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(D9J
M97)N(&MO;&]N;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C0P"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R
M(")3;&5T(&9O<FUA=&5R:6YG(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(E-L970@<&%R
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E
M('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O
M<GDN(@IM<V=S='(@(D9J97)N(&QA9W)E="!S:W)I<'0@9G)A('-E<G9E<G,@
M;6ED;&5R=&ED:6=E(&MA=&%L;V<N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED(")296UO=F4@
M=&AE(@IM<V=S='(@(D9J97)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI
M<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(D9J97)N(&1E='1E
M('!U;FMT(&9R82!D;VMU;65N=&5T(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B
M4VQE="!B<G5G97(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N
M:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM
M<V=S='(@(E-L970@8G)U9V5R.B`E<R(*"B,Z(&9R86UE=V]R:R]24$,O4E!#
M+WAM;')P8RYP:'`Z,3,X(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HQ,S@*
M;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D
M(&5R<F]R8V]D93H@(@IM<V=S='(@(D%N;6]D;FEN9R!K=6YN92!I:VME(&)E
M<W9A<F5S+B!2971U<FYE<F5T(&9E:FQK;V1E.B`B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,30U"FUS9VED(")297%U97-T960@<V5R=FEC
M92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(D%N;6]D970@=&IE;F5S
M=&4@:W5N;F4@:6MK92!F:6YD97,N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ.#4@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,C<*(SH@
M;&EB+TAO<F1E+G!H<#HQ.#4@;&EB+TAO<F1E+G!H<#HU,C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@
M)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2W+F=F5D92`G)7,G(&5R(&EK
M:V4@86YG:79E="!I("5S+6MO;F9I9W5R871I;VXN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HX-C$@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HV-S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<S,2!L
M:6(O5D93+V9T<"YP:'`Z.#8Q(&QI8B]61E,O<W%L+G!H<#HV-S@*(SH@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z-S,Q"B,L('!H<"UF;W)M870*;7-G:60@(E)E
M<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")+<N9V970@7"(E<UPB(&5R(&EK:V4@86YG:79E="!I
M(%9&4R!K;VYF:6=U<F%T:6]N+B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN
M<&AP.C<W-B!L:6(O2&]R9&4O571I;"YP:'`Z-S<V"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(DMRYG9E9&4@7"(E<UPB(&5R(&EK:V4@86YG
M:79E="!I(&MO;F9I9W5R871I;VYE;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+U)E;F1E<F5R+G!H<#HS,S8@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N
M<&AP.C,S-@IM<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B2W+F=F5T
M(&9E;'0B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(P"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,S.2!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS
M,C$*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S.2!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C(P"B,Z(&QI8B](;W)D92]&;W)M+U)E;F1E
M<F5R+G!H<#HS,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")2
M97-E="(*;7-G<W1R(").=6QS=&EL(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-#8*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(DYU
M;'-T:6P@:V]D96]R9"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C(W"FUS9VED(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(DYU;'-T
M:6P@9&ET(&MO9&5O<F0B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,Q"FUS
M9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T<B`B1V5N<VMA8B!S:61S
M=&4@9F]R97-P^')G<V5L(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(Y(&%D
M;6EN+W!H<'-H96QL+G!H<#HW,B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C<*;7-G
M:60@(E)E<W5L=',B"FUS9W-T<B`B4F5S=6QT871E<B(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI
M;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B5&EL8F%G
M92!T:6P@:6YD<W1I;&QI;F=E<FYE(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C,X"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S
M='(@(D=E;G1A<W0@;GET(&MO9&5O<F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Y-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@
M(E)E=6YI;VXB"FUS9W-T<B`B4F5U;FEO;B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B
M4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B1V5N9&%N(&MO;F9I9W5R
M871I;VXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED(")2
M:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B26YD<W1I;&QI;F=E
M<B!F;W(@4FEC:"!497AT+7)E9&EG97)I;F<B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B1^5D97(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#@*;7-G:60@(E)I9VAT(@IM<V=S='(@(DCX:G)E(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$P,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P,PIM
M<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(DCX:G)E('1O<'1E:W-T(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y.2!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S`Y.0IM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(DCX:G)E
M(';F<F1I97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*
M;7-G<W1R(")2YFMK92UE9V5N<VMA8F5R+BXN(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R(")2
M96=E;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$X-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DX(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R(")2
M=6WF;FEE;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,C8*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(R-@IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R(")2;W3I<B`Q.#`B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(S"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,C,*;7-G:60@
M(E)O=&%T92!,969T(@IM<V=S='(@(E)O=.ER('9E;G-T<F4B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(Y"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,CD*;7-G:60@(E)O=&%T
M92!2:6=H="(*;7-G<W1R(")2;W3I<B!H^&IR92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O
M=R!0<F]P97)T:65S(@IM<V=S='(@(E+F:VME+65G96YS:V%B97(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P
M"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R(")2YFMK92UE9V5N<VMA
M8F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@(E+F:VME<CHB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"FUS
M9VED(")2=6QE<R(*;7-G<W1R(")3=')E9V5R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*
M;7-G<W1R(")3=')E9V5R('9I;"!O<'1RYF1E(&UE;&QE;2!RYFMK97(@;V<@
M:V]L;VYN97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R(")3=')E9V5R('9I;"!K=6X@;W!T
M<N9D92!M96QL96T@:V]L;VYN97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R(")3=')E9V5R('9I
M;"!K=6X@;W!T<N9D92!M96QL96T@<N9K:V5R(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$R,0IM<V=I9"`B4G5N(@IM<V=S='(@(E5D9OAR(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.3D@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B4G5S
M;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$X.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`P(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@(E)W
M86YD82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@
M0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B2W)Y<'1O9W)A9FES
M:R!3+TU)344M<VEG;F%T=7(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C,R,R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,R,PIM
M<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(E,O34E-
M12US:6=N97)E="!B97-K960B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A
M<VPN<&AP.C@Q(&QI8B](;W)D92]!=71H+W-A<VPN<&AP.C@Q"FUS9VED(")3
M05-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(E-!4TPMYF=T;FEN9R!E<B!I:VME('1I;&?F;F=E;&EG+B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HU,#8*;7-G:60@(E--4R!-97-S86=I;F<B
M"FUS9W-T<B`B4TU3(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED
M(")344P@4VAE;&PB"FUS9W-T<B`B4U%,+69O<G1O;&ME<B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,R-S0@;&EB+TAO<F1E+T9O<FTN<&AP.C,R
M-S0*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS
M9W-T<B`B4U%,+75D=')Y:R!F;W(@;W!S;&%G(&%F(';F<F1I97(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,S"FUS9VED(")34T@B"FUS9W-T
M<B`B4U-((@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0HC.B!L:6(O2&]R9&4O3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B
M"FUS9W-T<B`B4U5#0T53(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED(")3
M7U%,(%-H96QL(@IM<V=S='(@(E-13"UF;W)T;VQK97(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*
M;7-G<W1R("),^'(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.#D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-R!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N
M82(*;7-G<W1R(")3:W0N($AE;&5N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,S$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A
M:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R(")3:W0N($MI='1S(&]G($YE
M=FES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.3$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S.2!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B
M4VMT+B!,=6-I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Y,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Y(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E
M(&%N9"!-:7%U96QO;B(*;7-G<W1R(")3:W0N(%!I97)R92!O9R!-:7%U96QO
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Y,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0T(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE
M($=R96YA9&EN97,B"FUS9W-T<B`B4VMT+B!6:6YC96YT(&]G($=R96YA9&EN
M97)N92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R(")386UM
M92!R86UM92`H7W-E;&8I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-3$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")386UO82(*
M;7-G<W1R(")386UO82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Y-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$R
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN
M;R(*;7-G<W1R(")386X@36%R:6YO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,38@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3
M86\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B4V]A(%1O;64@;V<@4')I
M;F-I<&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R
M;W9I9&5R(@IM<V=S='(@(E-A=&5L:71U9&)Y9&5R(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,#$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S
M"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B4V%U9&EA<F%B:65N(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDY"FUS9VED(")3879E
M(@IM<V=S='(@(D=E;2(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I
M="YI;F,Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS
M9W-T<B`B1V5M(%PB)7-<(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,C$V"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B
M1V5M(%PB)7-<(B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G
M:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R(")'96UM92!);F1S=&EL;&EN9V5R
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I9"`B(@HB4V%V
M92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@
M>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R
M("(B"B)'96T@9V5N97)E<F5T(&MO;F9I9W5R871I;VX@<V]M(%!(4"US:W)I
M<'0@:2!D:6X@<V5R=F5R<R!M:61L97)T:61I9V4@(@HB:V%T86QO9RXB"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")'96UT("5S
M+6MO;F9I9W5R871I;VXN(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B1V5M=&4@<VMR:7!T(&9O<B!O
M<&=R861E<FEN9R!A9B!O<'/F=&YI;F<@=&EL.B!<(B5S7"(N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-C
M871T97)E9"!4+5-T;W)M<R(*;7-G<W1R(")3<')E9'0@=&]R9&5N(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S
M='(@(E9I9&5N<VMA8B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED
M(")396%R8V@B"FUS9W-T<B`B4_AG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,R,@IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B4_AG
M96UA<VMI;F5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDU-2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,CDU-0IM<V=I9"`B4V5L96-T($9I;&5S(@IM
M<V=S='(@(E;F;&<@9FEL97(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#@U"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT.#4*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B
M5N9L9R!E;B!D871O(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R(")6YFQG
M(&5N(&=R=7!P92!A="!T:6QF^&IE(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@
M(E;F;&<@96X@;GD@96IE<B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(E;F;&<@
M96X@<V5R=F5R(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*
M;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@(E;F;&<@96X@
M8G)U9V5R(&%T('1I;&;X:F4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-C<V"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-S8*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B5N9L
M9R!A;&QE(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8T,R!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C8T,PIM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O
M;7!O;F5N=',N(@IM<V=S='(@(E;F;&<@86QL92!D871O+6MO;7!O;F5N=&5R
M+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX
M-S,*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM
M<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R(")6YFQG(&5T(&]B:F5K
M="(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV
M-S<*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PIM
M<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B5N9L9R!I;F=E;B(*"B,Z('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H92!C
M:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@
M8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT
M(&%R96$N(@IM<V=S='(@(B(*(E;F;&<@9&4@=&5G;B!D=2!H87(@8G)U9R!F
M;W(@9G)A(&MA<W-E<FYE(&YE9&5N9F]R+B!$92!K86X@<^4@:VQI<'!E<R!O
M9R`B"B)K;W!I97)E<R!F<F$@=&5X=&9E;'1E="XB"@HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM
M:71E<CHB"FUS9W-T<B`B5N9L9R!D871O+6%D<VMI;&QE<F5N.B(*"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A
M=&4@9F]R;6%T.B(*;7-G<W1R(")6YFQG(&1A=&]F;W)M870Z(@H*(SH@=&5M
M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L
M96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@
M(E;F;&<@9&5N(&ED96YT:71E="P@<V]M(&1U('9I;"#F;F1R93HB"@HC.B!T
M96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T
M:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B5N9L9R!T:61S+6%D<VMI;&QE<F5N
M.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE
M8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R(")6YFQG('1I9'-F;W)M870Z
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L
M96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(E;F;&<@=&\@9F5L
M=&5R+"!D97(@<W9A<F5R('1I;"!H:6YA;F1E;BXB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S$P"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE
M;64N(@IM<V=S='(@(E;F;&<@9&EN(&9A<G9E<V%M;65N<^9T;FEN9RXB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4R"FUS9VED(")396QE8W0@>6]U
M<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(E;F;&<@9&ET(&9O<F5T
M<G5K;F4@<W!R;V<Z(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B4V5N
M9"!P<F]B;&5M8F5S:W)I=F5L<V4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3`T,@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`T,@IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B
M4V5N9"!335,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.3@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,R!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T
M<B`B4V5N96=A;"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(S"FUS9VED
M(")396YS;W(Z("(*;7-G<W1R(")&^&QE<CH@(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,3`@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B4V5P
M=&5M8F5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R
M8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(E-E<F)I96X@;V<@36]N=&5N
M96=R;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`R
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`R"FUS9VED(")397)I86P@
M3G5M8F5R(@IM<V=S='(@(E-E<FEE;G5M;65R(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$T.0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@
M;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4V5R=F5R+61A=&$@9F]R:V5R
M="!E;&QE<B!I:VME('1I;&?F;F=E;&EG+B(*"B,Z(&%D;6EN+W-E<W-I;VYS
M+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R(")397-S:6]N
M<V%D;6EN:7-T<F%T;W(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3(*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS
M9W-T<B`B4V5S<VEO;BU)1"!U9&SX8F5T+B(*"B,Z(&QI8B]A<&DN<&AP.C$T
M-0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B4V5S<VEO;F5R(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-"!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C,Q-`IM<V=I9"`B4V5T(@IM<V=S='(@(DWF;F=D92(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW.0IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@
M>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T
M(&ET+B(*;7-G<W1R("(B"B));F1S=&EL;&EN9V5R(&1E<B!T:6QL861E<B!D
M:6<@870@;G5L<W1I;&QE(&1I="!K;V1E;W)D+"!H=FES(&1U(&YO9V5N<VEN
M9&4@(@HB<VMU;&QE(&=L96UM92!D970N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q.`IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@
M>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@
M(DEN9'-T:6P@9FIE<FYE('-E<G9E<F4L('-O;2!D=2#X;G-K97(@870@=&EL
M9^4@9G)A(&1I;B!P;W)T86PN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@W"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z
M;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(DEN9'-T:6P@9&EN(&9O
M<F5T<G5K;F4@<W!R;V<M+"!T:61S>F]N92T@;V<@9&%T;W9A;&<N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,0IM<V=I9"`B(@HB4V5T('EO=7(@
M<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E
M<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@
M(B(*(DEN9'-T:6P@9&EN92!O<'-T87)T<V%P<&QI:V%T:6]N97(L(&9A<G9E
M<V%M;65N<^9T;FEN9RP@<VED96]P9G)I<VMN:6X@;V<@(@HB86YD<F4@=FES
M;FEN9W-T:6QV86QG+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*
M;7-G:60@(E-E='5P(@IM<V=S='(@(DEN9'-T:6QL:6YG(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P
M9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B4VMR:7!T<R!T:6P@
M;W!G<F%D97)I;F<@868@;W!SYG1N:6YG('1I;&?F;F=E;&EG92(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@(E-E=F5R86P@
M;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S
M='(@(D9L97)E('-T961E<B!M=6QI9R!M960@<&%R86UE=&5R96XZ("(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`S(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R(")397EC:&5L
M;&5R;F4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DX"FUS9VED
M(")3:&]P<&EN9R(*;7-G<W1R(")3:&]P<&EN9R(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R="!3=6UM87)Y(@IM
M<V=S='(@(DMO<G0@;W!S=6UM97)I;F<B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#4P"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE
M9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B4VMA;"!H=7)T:6<M=&%S=&5R
M(&1E9FEN97)E<R!F;W(@9&4@9FQE<W1E(&AE;G9I<VYI;F=E<C\@*/<I(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@;&EB+TAO<F1E+U!E
M<FUS+G!H<#HS,C,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,R!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.3`@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B5FES(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D
M:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE
M=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B)6
M:7,@9F]R<VME;&QE;F4@;65L;&5M(&1E;B!G96UT92!O9R!D96X@;GEL:6=T
M(&=E;F5R97)E9&4@:V]N9FEG=7)A=&EO;BXB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#DT"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N
M(&QO9V=I;F<@:6X_(@IM<V=S='(@(E9I<R!T:61S<'5N:W0@9F]R('-E;F5S
M=&4@=&EL9V%N9R!V960@<.5L;V=N:6YG/R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$W-C4@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C4*;7-G:60@
M(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B5FES(&UU
M;&EG:&5D(&9O<B!A="!B96AO;&1E(&]P<FEN9&5L:6<B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-SDU(&QI8B](;W)D92]&;W)M+G!H<#HR-SDU
M"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R(")6:7,@<VYU<'!E<B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S`*;7-G:60@(E-H;W<@=&%B;&4@
M;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B5FES(%1A8F5L;W!E<F%T
M:6]N97(M:VYA<'!E;B!I(&UE;G5E;C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S4S"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE
M;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(E9I<R`E<RUM96YU96X@=&EL('9E
M;G-T<F4_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R
M;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(E9I<R!D:6%L;V=V:6YD=64@;65D
M(&5G96YS:V%B97(@9F]R('1A8F5L8V5L;&5N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED(")3
M:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")6:7,@
M9&EA;&]G=FEN9'5E(&UE9"!E9V5N<VMA8F5R(&9O<B!T86)E;&QE;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV,`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA
M;&]G(@IM<V=S='(@(E9I<R!D:6%L;V=V:6YD=64@;65D(&5G96YS:V%B97(@
M9F]R('1A8F5L<N9K:V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G
M92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")6:7,@9&EA;&]G=FEN9'5E
M(&UE9"!E9V5N<VMA8F5R(&9O<B!B:6QL961E="(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$W-C,@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C,*;7-G
M:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(E9I<R!A9G-E;F1T92(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3
M:&]W97)S(@IM<V=S='(@(D)Y9V5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS
M9W-T<B`B0GEG97(@=&ED;&EG="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T
M<B`B0GEG97(@<V5N="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4U"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*
M;7-G<W1R(")">6=E<B!I(&[F<FAE9&5N(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV,3D@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="YP:'`Z-#@P"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z-C$Y"FUS9VED(")3:')I;FLB"FUS9W-T<B`B4VMR=6UP(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HY
M,3`*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HY-S(*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HQ,#4X"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z,3$R,`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C$Q.#,*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HQ,C(S"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z,3(U,@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R.#4*(SH@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="YP:'`Z-S<T(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP
M.C@S-@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HY,C(@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="YP:'`Z.3@T"B,Z(&QI8B](;W)D92]";&]C:R],
M87EO=70N<&AP.C$P-#<@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,3`X
M-PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HQ,3$V(&QI8B](;W)D
M92]";&]C:R],87EO=70N<&AP.C$Q-#D*(SH@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HY,3`*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HY-S(*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HQ,#4X"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z,3$R,`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C$Q.#,*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HQ,C(S"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP
M:'`Z,3(U,@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C$R.#4*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C
M:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R(")3:W)U;7`@96QL
M97(@9FQY="!N86)O8FQO:VME(&%F('9E:F5N(&;X<G-T(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,3$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`U"FUS9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B4VEE<G)A($QE;VYE
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-B!L:6(O
M2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V-@IM<V=I9"`B4VEG;B!U<"(*;7-G
M<W1R(")3:W)I=B!I;F0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<Q,R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<Q,PIM<V=I
M9"`B4VEG;F%T=7)E(@IM<V=S='(@(E5N9&5R<VMR:69T(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS
M9W-T<B`B4VEG;F%T=7)A;&=O<FET;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(P-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@
M(E-I;F=A<&]R92(*;7-G<W1R(")3:6YG87!O<F4B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z.#0*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.38*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C,W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R
M-#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDQ,@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3`U(&QI8B](;W)D92]&;W)M+G!H<#HX.38@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$R,34*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R
M,S<@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#8@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(Y,3(*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#4@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#0@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*
M;7-G:60@(E-I>F4B"FUS9W-T<B`B4W3X<G)E;'-E(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@
M36%I;G1E;F%N8V4B"FUS9W-T<B`B4W!R:6YG('9E9&QI9V5H;VQD96QS92!O
M=F5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3`@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V86MI82(*;7-G<W1R(")3
M;&]V86MI970B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,#0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P."!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S
M='(@(E-L;W9E;FEE;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W(@IM<V=S='(@(E-N92(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3
M;F]W(%-H;W=E<B(*;7-G<W1R(")3;F5B>6=E(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N;W<@4VAO=V5R
M<R(*;7-G<W1R(")3;F5B>6=E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB
M"FUS9W-T<B`B4VYE8GEG97(@=&ED;&EG="(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")3;F]W(%-H;W=E<G,@
M3&%T92(*;7-G<W1R(")3;F5B>6=E<B!S96YT(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR.#4*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R(")3;F5D
M>6)D93H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#D*;7-G:60@(E-N
M;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@(E-N9>9K=FEV86QE
M;G0@:2!V86YD.B`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`R(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,#4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L
M86YD<R(*;7-G<W1R(")386QO;6]N^&5R;F4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(Q-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G
M:60@(E-O;6%L:6$B"FUS9W-T<B`B4V]M86QI82(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R(")3
M86YG92!O9R!P;V5S:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y
M,#@@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,#@*;7-G:60@(E-O<G0@;W)D97(@
M<V5L96-T:6]N(@IM<V=S='(@(E-O<G1E<FEN9W-V86QG(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U
M.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$V
M-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$X.2!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,3<*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR-#<@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$V-@HC.B!L
M:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D
M<F5S<R(*;7-G<W1R(")!9G-E;F1E<F%D<F5S<V4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(U-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*
M;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R(")3>61A9G)I:V$B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B4V]U=&@@175R;W!E86X@
M*$E33RTX.#4Y+3,I(@IM<V=S='(@(E-Y9&5U<F]PYFES:R`H25-/+3@X-3DM
M,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(P.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Q(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@
M4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R(")3>60@1V5O<F=I82!O
M9R!$92!S>61L:6=E(%-A;F1W:6-H^&5R(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@
M2&5M:7-P:&5R92(*;7-G<W1R(")3>61L:6=E(&AA;'9K=6=L92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED
M(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(DQU9G0@
M;65L;&5M(&YA8F]C96QL97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT
M96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R("),=69T(&UE;&QE;2!I
M;F1H;VQD(&]G(')A;6UE(&D@8V5L;&4B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HX,34@;&EB+TAO<F1E+T9O<FTN<&AP.C@Q-0IM<V=I9"`B4W!A
M8V5R(@IM<V=S='(@(DUE;&QE;7)U;7-T86YG970B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*;7-G:60@(E-P
M86-I;F<B"FUS9W-T<B`B365L;&5M<G5M(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN
M9R!A;F0@<&%D9&EN9R(*;7-G<W1R("),=69T(&]G(&9O<G)I;F<B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B4W!A;FEE;B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#`*;7-G:60@(E-P86TB"FUS9W-T<B`B
M4VMI9'1P;W-T(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED
M(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R("));F1T87-T;FEN
M9R!F;W(@<W!E8VEA;&MA<F%K=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L
M;"(*;7-G<W1R(")$96P@8V5L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU
M;6XB"FUS9W-T<B`B1&5L(&MO;&]N;F4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R
M;W<B"FUS9W-T<B`B1&5L('+F:VME(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`B4W!O<G0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,30Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B4W)I($QA;FMA(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HX,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-C8*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(E-T86YD87)D(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R96LB
M"FUS9W-T<B`B4W1A<B!4<F5K(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C4X-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDQ"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR-3@V(&QI8B](;W)D92]&;W)M+G!H<#HR-SDQ"FUS
M9VED(")3=&%R="!Y96%R(@IM<V=S='(@(D)E9WEN9&5L<V5SY7(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,2!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4W,0IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B
M"FUS9W-T<B`B1&5L<W1A="!E;&QE<B!P<F]V:6YS(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G
M<W1R(")3=&%T=7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDW
M(&QI8B](;W)D92]&;W)M+G!H<#HR-SDW"FUS9VED(")3=&]R86=E(&9O<FUA
M="(*;7-G<W1R("),86=R:6YG<V9O<FUA="(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3<S(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-3<S"FUS9VED(")3=')E970@061D<F5S<R(*;7-G<W1R(")696HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q"FUS
M9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(D=E;FYE;7-T<F5G;FEN9R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S,@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$R,S,*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(DQI<W1E
M(&%F('-T<F5N9V4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I<"!D;VUA:6X@
M9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R(")&:F5R;B!D;VWF;F4@9G)A(&%D
M<F5S<V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B4W1I
M;"!;0U-372(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(E/X;B(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E
M8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B56YD97)K871A;&]G
M(%PB)7-<(B!I:VME(&9U;F1E="XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C<S"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(D5M;F4B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W;W)K+T9O
M<FTO1F]R;2]296YD97)E<BYP:'`Z,S$X"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HS,S(@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,Q.`IM<V=I9"`B
M4W5B;6ET(@IM<V=S='(@(D=O9&ME;F0B"@HC.B!S:6=N=7`N<&AP.C0Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D
M9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT
M:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R
M("(B"B)!;FUO9&YI;F<@;VT@870@=&EL9OAJ92!<(B5S7"(@=&EL('-Y<W1E
M;2!A9G-E;F1T+B`@1'4@:V%N(&EK:V4@;&]G9V4@<.4@9OAR("(*(F1I;B!A
M;FUO9&YI;F<@97(@8FQE=F5T(&%N97)K96YD="XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I
M<'0B"FUS9W-T<B`B3&%V('-K<FEF="(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,#4*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HR.`HC.B!L:6(O2&]R9&4O3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS
M9W-T<B`B561F^')T(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@
M<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@8FQE=B!T:6QF^&IE="!T:6P@<WES
M=&5M970N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E
M<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B1&%T82!F;W(@8G)U9V5R
M(%PB)7-<(B!B;&5V('-L971T970@9G)A('-Y<W1E;65T+B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N
M(@IM<V=S='(@(EPB)7-<(B!S;&5T=&5T+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E
M9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@<VQE
M='1E="!F<F$@<WES=&5M970N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I
M;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B2V]N9FEG=7)A
M=&EO;B!T:6QB86=E9OAR="X@1V5N:6YD;.9S(&9O<B!A="!S92#F;F1R:6YG
M97)N92XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B
M86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B4F5S97)V96MO;F9I9W5R
M871I;VX@9V5M="XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C
M:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B4F5S97)V96MO
M;F9I9W5R871I;VYF:6P@)7,@9V5M="XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@
M7"(E<UPB(@IM<V=S='(@(EPB)7-<(B!O<&1A=&5R970N(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM
M<V=S='(@(EPB)7-<(B!S:W)E=F5T+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#0@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C`T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B
M4W5D86XB"FUS9W-T<B`B4W5D86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y(@IM
M<V=S='(@(DEN9&AO;&0B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*
M;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(E-O;&]P9V%N9R(*"B,Z(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R(")3
M;VQN961G86YG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C$*;7-G:60@(E-U;FYY(@IM<V=S='(@(E-O;')I9W0B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`U"FUS9VED(")3=6YR:7-E
M(@IM<V=S='(@(E-O;&]P9V%N9R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3
M=6YS970B"FUS9W-T<B`B4V]L;W!G86YG+W-O;&YE9&=A;F<B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`T"FUS9VED(")3=6YR:7-E.B`B
M"FUS9W-T<B`B4V]L;W!G86YG.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C`X"FUS9VED(")3=6YS970B"FUS9W-T<B`B4V]L;F5D9V%N
M9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#<*;7-G:60@
M(E-U;G-E=#H@(@IM<V=S='(@(E-O;&YE9&=A;F<Z("(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R
M<V-R:7!T(@IM<V=S='(@(DCF=F5T('-K<FEF="(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS.#`*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B2&KF
M;'`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,3(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-2!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(E-U
M<FEN86TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M-2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B4W5R;F%M
M92(*;7-G<W1R(")%9G1E<FYA=FXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(P.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V
M86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B4W9A;&)A<F0@;V<@2F%N
M($UA>65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3D@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T
M<B`B4W=A>FEL86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#4@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS
M9W-T<B`B4W9E<FEG92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,38*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4V(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*
M;7-G<W1R(")38VAW96EZ(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`B4WEN8R!L
M;V<@<VQE='1E="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#4*;7-G
M:60@(E-Y;F--3"(*;7-G<W1R(")3>6YC34PB"@HC.B!F<F%M97=O<FLO4U%,
M+U-13"]+97EW;W)D<RYP:'`Z.3<@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP
M:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS
M9W-T<B`B4WEN=&%K<V9E:FP@:2!S^&=E;&5D(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,3@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W"FUS
M9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R(")3>7)I96XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I
M9"`B5"U3=&]R;2(*;7-G<W1R(")4;W)D96XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;2!A;F0@
M5VEN9'DB"FUS9W-T<B`B5&]R9&5N(&]G('9I;F0B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B5"U3=&]R;7,B
M"FUS9W-T<B`B5&]R9&5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@
M(E1O<F1E;B!T:61L:6=T(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N
M<&AP.C$V-B!L:6(O2&]R9&4O1&%T82]T<W8N<&AP.C$V-@IM<V=I9"`B5%-6
M(&9I;&4B"FUS9W-T<B`B5%-6+69I;"(*"B,Z(&QI8B](;W)D92]522]486)L
M92YP:'`Z,3,T"FUS9VED(")486)L92(*;7-G<W1R(")486)E;"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*
M;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B5&%B96PM96=E;G-K
M86)E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP
M:'`Z-3<*(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*
M;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R(")486)E;&WF;F=D92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*
M;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B5&%B96PM96=E;G-K
M86)E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(S-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@
M(E1A:7=A;B(*;7-G<W1R(")486EW86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S
M='(@(E1A:7=A;BP@1&5N(&MI;F5S:7-K92!P<F]V:6YS(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,C4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(E1A9&II:VES=&%N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S4@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC
M(&]F(@IM<V=S='(@(E1A;GIA;FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R
M(")-Y6PZ(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S(@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HY,S(*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T
M.C$P-#D@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X.0IM<V=I9"`B5&%S
M:W,B"FUS9W-T<B`B3W!G879E<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3<T(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<T
M"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(E1E;&5F;VYN=6UM
M97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-PIM<V=I9"`B5&5M<"!F
M;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B5&5M<"X@<VED<W1E('1I;64Z("(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(Q"FUS9VED(")496UP97)A='5R
M92(*;7-G<W1R(")496UP97)A='5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Q,@IM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R(")4
M96UP97)A='5R.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C@R"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S
M2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B5&5M<&5R871U<CQB<B`O
M/B@E<TCX:B5S+R5S3&%V)7,I("9D96<[)7,B"@HC.B!F<F%M97=O<FLO5&5M
M<&QA=&4O5&5M<&QA=&4N<&AP.C8Y-2!L:6(O2&]R9&4O5&5M<&QA=&4N<&AP
M.C8Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T
M(&9O=6YD+B(*;7-G<W1R(")3:V%B96QO;B!<(B5S7"(@:6MK92!F=6YD970N
M(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E
M($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E-K86)E;&]N+6%D;6EN:7-T<F%T
M:6]N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,S(W"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,C$Q(&QI8B](;W)D92]&;W)M+G!H<#HS,S(W"FUS9VED(")497AT(@IM<V=S
M='(@(E1E:W-T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.0IM<V=I
M9"`B5&5X="!/;FQY(@IM<V=S='(@(E)E;B!T96MS="(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@
M(E1E>'0@86QI9VXB"FUS9W-T<B`B5&5K<W0M:G5S=&5R:6YG(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B
M5&5X='1O<"(*;7-G<W1R(")496MS="UT;W`B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R
M(")4;W(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5&AA
M:2`H5$E3+38R,"DB"FUS9W-T<B`B5&AA:2`H5$E3+38R,"DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(R-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(E1H86EL86YD(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$@;&EB+U9&4R]F='`N<&AP
M.C@U,0IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B1E10+75D=FED9&5L<V5N(&5R(&EK:V4@=&EL9^9N9V5L
M:6<N(@H*(SH@9G)A;65W;W)K+TAI<W1O<GDO2&ES=&]R>2YP:'`Z-34@;&EB
M+TAO<F1E+TAI<W1O<GDN<&AP.C4U"FUS9VED(")4:&4@2&ES=&]R>2!S>7-T
M96T@:7,@9&ES86)L960N(@IM<V=S='(@(DAI<W1O<FEK+7-Y<W1E;65T(&5R
M('-LY65T(&9R82XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS
M."!L:6(O2&]R9&4O2V]L86(N<&AP.CDS.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T
M('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B+6EN=&5G<F%T
M:6]N<VUO=&]R96X@=6YD97)S=/AT=&5R(&EK:V4@7"(E<UPB(@H*(SH@9G)A
M;65W;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP:'`Z,3(Y."!L:6(O3F5T+TE-
M4U`O0F]O:RYP:'`Z,3(Y.`IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO
M="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B24U34"UL;V=G96X@:W5N;F4@
M:6MK92!K;&%R9_AR97,N(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO
M860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(DUA:6YT96YA;F-E.CHM:VQA<W-E
M;B!B;&5V(&EK:V4@:6YD;.9S="(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO
M<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@
M8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R(")4:6QV86QG<W9I;F1U970@97(@
M8FQE=F5T(&QU:VME="X@069S;'5T=&5R+B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`P
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,S`S"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,3@Y(&QI8B](;W)D
M92]097)M<RYP:'`Z,C`P(&QI8B](;W)D92]097)M<RYP:'`Z,C$Q"B,Z(&QI
M8B](;W)D92]097)M<RYP:'`Z,C(S(&QI8B](;W)D92]097)M<RYP:'`Z,C,T
M(&QI8B](;W)D92]097)M<RYP:'`Z,C4R"B,Z(&QI8B](;W)D92]097)M<RYP
M:'`Z,C8T(&QI8B](;W)D92]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@
M861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@
M4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R
M;6ES<VEO;G,N(@IM<V=S='(@(B(*(D%D;6EN:7-T<F%T;W)E;B!B;&EV97(@
M;OAD="!T:6P@870@:V]N9FEG=7)E<F4@96X@<&5R;6%N96YT(%1I;&QA9&5L
M<V5S+2(*(F)A8VME;F0L(&AV:7,@9'4@=FEL(&%N=F5N9&4@5&EL;&%D96QS
M97(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T
M<B`B2W5N('5N9&5R<VED96XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S.0HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB
M97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F
M;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*(DMO;G1A:W0M
M240M;G5M;65R970@8FQE=B!I:VME(&%N9VEV970L(&5F=&5R;&%D="!T;VUT
M(&5L;&5R(&)L978@:6MK92!F=6YD970@(@HB:2!D871A8F%S96XN(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT
M86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O
M;VLN(@IM<V=S='(@(DMO;G1A:W1E;B!B;&5V('1I;&;X:F5T('1I;"!D:70@
M861R97-S96MA<G1O=&5K970N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3$W,B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,3<R"FUS
M9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R
M97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R
M("(B"B)$96X@;/AS9VIO<G1E(%!'4"US:6=N871U<BUB;&]K(&5R(&MRYG9E
M="!F;W(@870@:W5N;F4@=F5R:69I8V5R92!D96X@(@HB<VEG;F5R961E(&)E
M<VME9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,0HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I
M=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B
M"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*(D1I<W1R:6)U=&EO;G-L
M:7-T92U)1"!E<B!E;G1E;B!I:VME(&%N9VEV970L('1O;70@96QL97(@:6MK
M92!F=6YD970@:2`B"B)D871A8F%S96XN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO
M;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R(")$:7-T<FEB=71I
M;VYS;&ES=&5N(&EK:V4@86YG:79E="XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0N<&AP.C$Q-B!L:6(O2&]R9&4O0W)Y<'0N<&AP.C$Q-@IM<V=I9"`B
M5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@
M8V]N;F5C=&EO;BXB"FUS9W-T<B`B2W)Y<'1E<FEN9W-F86-I;&ET971E<FYE
M(&MRYG9E<B!E;B!S:6MK97(@=V5B+69O<F)I;F1E;'-E+B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,3@V(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z-3(X"B,Z(&QI8B](;W)D92YP:'`Z,3@V(&QI8B](;W)D92YP:'`Z
M-3(X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C
M;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B1FEL96X@)7,@8OAR(&EN
M9&5H;VQD92!E;B`E<RUI;F1S=&EL;&EN9RXB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q
M.`HC.B!L:6(O2&]R9&4N<&AP.C$W.2!L:6(O2&]R9&4N<&AP.C4Q.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S
M;VUE("5S('-E='1I;F=S+B(*;7-G<W1R(")&:6QE;B`E<R!B^'(@:6YD96AO
M;&1E(&YO9VQE("5S+6EN9'-T:6QL:6YG97(N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C(V(&QI8B]61E,O9FEL92YP:'`Z,C(V"FUS9VED
M(")4:&4@9FEL92!C86YN;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G
M<W1R(")&:6QE;B!K86X@:6MK92!K;W!I97)E<R!O=F5N<.4@<VEG<V5L=BXB
M"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.#`@;&EB+TAO<F1E+T1A
M=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N
M(@IM<V=S='(@(D9I;&5N(&EN9&5H;VQD="!I;F=E;B!D871A+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F
M;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C
M.#(R(&UE<W-A9V4N(@IM<V=S='(@(D;X;&=E;F1E(&5R(&AO=F5D97)N92!F
M<F$@9&5N;F4@;65S<V%G92]R9F,X,C(M8F5S:V5D+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H
M92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US
M('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U
M9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M
M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E
M9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S
M+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@
M;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I
M;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B
M965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@
M=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B
M(@HB1G5L9'-KYG)M<W1I;'-T86YD('9I9&5S(&%T('9O;&1E('!R;V)L96UE
M<B!I($EN=&5R;F5T($5X<&QO<F5R(&=R=6YD970@(@HB8G)O=W-E<BUF96IL
M+"!S;VT@=FD@:6MK92!H87(@:W5N;F5T(&]M9^4N($1U('9I;"!M=6QI9W9I
M<R!O<&QE=F4@(@HB9F]R=F%N<VME9&4@=FES;FEN9V5R+"!M86YG96P@<.4@
M961I=&5R:6YG<V9U;FMT:6]N97(@;V<O96QL97(@=&EL9N9L9&EG92`B"B)B
M<F]W<V5R+6YE9&)R=60N($AV:7,@9&ET('-Y<W1E;2!E<B!7:6YD;W=S)FYB
M<W`[.7@@=FEL(&1U(&UE9"!H^&H@(@HB<V%N9'-Y;FQI9VAE9"!O<&QE=F4@
M)T=E;F5R96P@8F5S:WET=&5L<V5S9F5J;"<@;V<@=FEL(&)L:79E(&[X9'0@
M=&EL(&%T("(*(F=E;G-T87)T92!M87-K:6YE;BY<7&Y<7&Y$=2!E<B!N=2!A
M9'9A<F5T+B`@5')Y:R!/2R!H=FES(&1U('-T861I9R#X;G-K97(@870@(@HB
M<'+X=F5T(&9U;&1S:^9R;7-R961I9V5R:6YG+B(*"B,Z('-E<G9I8V5S+W!R
M969S+G!H<#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y
M(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("))9&5N=&ET971E
M;B!<(B5S7"(@97(@<VQE='1E="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH
M86YD('-I9&4@;VYL>2(*;7-G<W1R(")+=6X@=F5N<W1R92!S:61E+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$U-R!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T
M:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G
M<#HZ(&-L87-S+B(*;7-G<W1R(")0;&%C97)I;F=E;B!A9B!';G501RUP<F]G
M<F%M;65T('-K86P@9VEV97,@=&EL($-R>7!T7W!G<#HZ+6ML87-S96XN(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C(P,B!L:6(O2&]R9&4O
M34E-12]-1$XN<&AP.C(P,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@
M;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@
M:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@
M=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N
M(@IM<V=S='(@(B(*(D)E<VME9&5N+"!S;VT@97(@<V5N9'0@9&5N("5S('1I
M;"`E<R!M960@96UN970@7"(E<UPB(&5R(&)L979E="!V:7-T+EQN(@HB1&5T
M=&4@97(@:6YG96X@9V%R86YT:2!F;W(L(&%T(&)E<VME9&5N(')E;G0@9F%K
M=&ES:R!E<B!B;&5V970@;.9S="!E;&QE<B`B"B)F;W)S=.5E="XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W(&QI8B](;W)D92]&;W)M+G!H
M<#HQ.#<W"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O
M('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B3F%V;F5T+"!D97(@<VMA;"!B
M<G5G92P@;N5R(&1E<B!H96YV:7-E<R!T:6P@<VMR:79E<VED96XB"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-S0@;&EB+T9I;&4O0U-6+G!H
M<#HT-S0*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M
M97)I8RXB"FUS9W-T<B`B06YT86QL970@868@9F5L=&5R('-K86P@=N9R92!E
M="!T86PN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ
M,C,R(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(S,@IM<V=I9"`B5&AE
M(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y
M<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B;W!E;G-S;"UM;V1U;&5T(&5R
M(&MRYG9E="!A9B!(;W)D95]#<GEP=%]S;6EM93HZ+6ML87-S96XN(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+G!H<#HR.34@;&EB+TAO<F1E+U!R969S
M+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N
M8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A
M(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S
M='(@(B(*(E!RYF9E<F5N8V5N(%PB)7-<(B!K=6YN92!I:VME(&=E;6UE<R!F
M;W)D:2!D96YS(&1A=&$@;W9E<G-K<FED97(@9&5N("(*(FUA:W-I;6%L="!T
M:6QL861T92!S=/AR<F5L<V4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]M<V5X8V5L+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=V5B8W!P+G!H<#HS-R!L:6(O2&]R9&4O34E-12]6:65W97(O9&5B
M+G!H<#HS,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O96YS8W)I<'0N<&AP
M.C,U(&QI8B](;W)D92]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,B!L:6(O2&]R9&4O
M34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]W96)C<'`N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P
M<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N
M;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HB4')O9W)A;6UE
M="P@9&5R(&)R=6=E<R!T:6P@870@8F5T<F%G=&4@9&5N;F4@9&%T871Y<&4@
M*"5S*2P@8FQE=F5T(&EK:V4@(@HB9G5N9&5T('#E('-Y<W1E;65T+B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0X-R!L:6(O1FEL92]#4U8N
M<&AP.C0X-PIM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N
M92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R(")#:71A=&EO;G-T96=N970@
M<VMA;"!VYG)E(&5T(&5N:V5L="!T96=N+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R
M:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(DMU;B!H^&IR92!O
M9R!V96YS=')E('-I9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S
M:61E(&]N;'DB"FUS9W-T<B`B2W5N('-I9&5N('1I;"!H^&IR92(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0W.2!L:6(O1FEL92]#4U8N<&AP
M.C0W.0IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@
M8VAA<F%C=&5R+B(*;7-G<W1R(")!9'-K:6QL96QS97-T96=N970@<VMA;"!V
MYG)E(&5T(&5N:V5L="!T96=N+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S
M=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E
M<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(E-E<G9E<F5N(%PB)7-<
M(B!E<B!S;&5T=&5T+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP
M.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA
M<R!B965N('-A=F5D+B(*;7-G<W1R(")397)V97)E;B!<(B5S7"(@97(@9V5M
M="XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D
M+B(*;7-G<W1R(")/<'-K<FEV;FEN9W-A;FUO9&YI;F=E;B!F;W(@)7,@97(@
M<VQE='1E="XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C0W,`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C0W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W!E8VEF:65D
M(')O=R`H)60I(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")$96X@86YG:79N
M92!RYFMK92`H)60I(&5K<VES=&5R97(@:6MK92XB"@HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S<&5C:69I960@<F]W
M(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")$96X@86YG:79N92!RYFMK92!E
M:W-I<W1E<F5R(&EK:V4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HQ-SD@;&EB+U9&4R]S<6PN<&AP.C$W.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*
M;7-G<W1R(")$96X@;6ED;&5R=&ED:6=E(&9I;"!<(B5S7"(@9FEN9&5S(&EK
M:V4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P,B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S,P,@IM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@
M9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R
M(")$96X@=&5K<W0L('-O;2!D=2!I;F1T87-T961E+"!P87-S97(@:6MK92!T
M:6P@=&5K<W1E;B!PY2!S:^9R;65N+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@
M86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(DMU;B!T;W`@;V<@8G5N
M9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(DMU
M;B!T;W`B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HS,C<@;&EB+TAO
M<F1E+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S
M(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(D1E;B!A
M9G-E;F1T92!I;F9O<FUA=&EO;B!E<B!T86)T('-I9&5N('-I9'-T92!T<FEN
M+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W
M;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W,@HC.B!L:6(O2&]R9&4O1&%T82]T
M<W8N<&AP.C$W,B!L:6(O2&]R9&4O1&%T82]C<W8N<&AP.C(V,@IM<V=I9"`B
M5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R
M(")$96X@;W9E<F;X<G1E(&9I;"!K=6YN92!I:VME(&=E;6UE<RXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#D@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$Q,`IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K
M(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(G=E871H97(N8V]M+6)L;VMK
M96X@97(@:6MK92!T:6QGYFYG96QI9RXB"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R
M>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")496UA+6MA=&%L;V=E="!<
M(B5S7"(@:6MK92!F=6YD970N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HQ-S@@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-S@*;7-G:60@
M(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`B26YG
M96X@=&EL=F%L9R!T:6P@<N5D:6=H960N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z,S4P(&QI8B](;W)D92]-24U%+T-O;G1E;G1S
M+G!H<#HS-3`*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B
M92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R(")$97(@9F]R969I;F1E<R!I
M;F=E;B!D96QE+"!S;VT@:V%N('9I<V5S(&EN9&QE:G)E="XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`Q(&QI8B](;W)D92]&;W)M+G!H<#HQ
M-#`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N
M>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@
M)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S
M+B(*;7-G<W1R("(B"B)$97(@97(@9F]R(&UA;F=E('1E9VX@:2!D971T92!F
M96QT+B!$=2!H87(@:6YD=&%S=&5T("5S('1E9VX[(&1U('-K86P@(@HB:6YD
M=&%S=&4@;6EN9')E(&5N9"`E<RXB"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN
M+W5S97(N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G
M<W1R(")$97(@;W!S=&]D(&5T('!R;V)L96T@=6YD97(@=&EL9OAJ96QS96X@
M868@)R5S)R!T:6P@<WES=&5M970Z("5S(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M
M.B`B"FUS9W-T<B`B(@HB1&5R(&]P<W1O9"!E="!P<F]B;&5M('5N9&5R(&9J
M97)N96QS92!A9B!D871A(&9O<B!B<G5G97(@7"(E<UPB(&9R82`B"B)S>7-T
M96UE=#H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(D1E<B!O<'-T;V0@970@<')O8FQE
M;2!U;F1E<B!S;&5T;FEN9R!A9B!<(B5S7"(@9G)A('-Y<W1E;65T.B`B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@
M(D1E<B!O<'-T;V0@970@<')O8FQE;2!U;F1E<B!O<&1A=&5R:6YG(&%F(%PB
M)7-<(CH@)7,B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY
M,C<@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDR-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(D1E<B!O<'-T;V0@970@
M<')O8FQE;2!U;F1E<B!F:6QO=F5R9OAR<VQE;CH@26YG96X@)7,@8FQE=B!O
M=F5R9OAR="XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY
M,S(@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDS,@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L
M;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"B)$97(@;W!S=&]D
M(&5T('!R;V)L96T@=6YD97(@9FEL;W9E<F;X<G-L96XZ("5S('9A<B!S=/AR
M<F4@96YD(&1E;B!M86MS:6UA;'0@(@HB=&EL;&%D=&4@<W3X<G)E;'-E("@E
M9"!B>71E<RDN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z
M.3,T(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P
M;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS
M9W-T<B`B(@HB1&5R(&]P<W1O9"!E="!P<F]B;&5M('5N9&5R(&9I;&]V97)F
M^')S;&5N.B`E<R!B;&5V(&MU;B!D96QV:7-T(&]V97)F^')T+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM
M<V=S='(@(D1E<B!O<'-T;V0@96X@9F5J;"!U;F1E<B!V:7-N:6YG(&%F(&1E
M;FYE(&)E<VME9&1E;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-#@@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HS
M.0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A
M=&$N(@IM<V=S='(@(D1E<B!O<'-T;V0@96X@9F5J;"!U;F1E<B!I;7!O<G1E
M<FEN9V5N(&%F(&MO;G1A:W1I;F9O<FUA=&EO;BXB"@HC.B!F<F%M97=O<FLO
M1&%T82]$871A+VEM8RYP:'`Z,S$@;&EB+TAO<F1E+T1A=&$O:6UC+G!H<#HS
M,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A
M;&5N9&%R(&1A=&$N(@IM<V=S='(@(D1E<B!O<'-T;V0@96X@9F5J;"!U;F1E
M<B!I;7!O<G1E<FEN9V5N(&%F(&E#86QE;F1A<B!D871A+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z.#(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E
M<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L
M969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"B)$97(@
M;W!S=&]D(&5N(&9E:FP@:2!K;VYF:6=U<F%T:6]N<V9O<FUU;&%R96XN($YU
M;&EG=FES(&AA<B!D=2!U9&5L861T(&5T("(*(FMRYG9E="!F96QT+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@
M(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I
M960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN
M(&QA=&5R+B(*;7-G<W1R("(B"B)$97(@;W!S=&]D(&5T('!R;V)L96T@=6YD
M97(@=61F^')E;'-E(&%F(&1E;B!A;F=I=FYE("(*(F%D<F5S<V5K87)T;W1E
M:W-F=6YK=&EO;BX@4'+X=B!I9V5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E
M<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y
M(&%G86EN(&QA=&5R+B(*;7-G<W1R(")$97(@;W!S=&]D(&5N(&9E:FP@=6YD
M97(@;W!D871E<FEN9R!A9B!K;VYT86MT+61E=&%L:F5R;F4N(%!R^'8@:6=E
M;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C(R,B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&QI
M8B].970O4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A
M<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(D1E<B!O<'-T;V0@96X@
M9F5J;"!U;F1E<B!O<&1A=&5R:6YG(&%F(&1I<W1R:6)U=&EO;G-L:7-T96XN
M(%!R^'8@:6=E;BXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ-#@@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T
M.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H
M87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B1&5N;F4@24U!4"US97)V97(@=6YD
M97)S=/AT=&5R(&EK:V4@9&5L:6YG(&%F(&UA<'!E<BXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C0X(&QI8B](;W)D92]-24U%
M+U9I97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R(")$971T92!T
M>61E<B!I:VME('#E(&%T(';F<F4@970@9WEL9&EG="!R87(M87)K:78N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HU,B!L:6(O
M2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S
M(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B
M1&5N;F4@='ED97(@:6MK92!PY2!A="!VYG)E(&5N(&=Y;&1I9R!Z:7`M9FEL
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C<@;&EB+TAO<F1E
M+T9O<FTN<&AP.C,Q,C<*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B
M92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R(")$971T92!T>61E<B!I
M:VME('#E(&%T(';F<F4@970@9WEL9&EG="!K;W)T;G5M;65R+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B
M(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M
M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB1&5N
M;F4@9')I=F5R('1I;&QA9&5R(&%F<V5N9&5L<V4@868@8F5S:V5D97(@:6=E
M;FYE;2!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&%D
M9V%N9W-P=6YK=&5T('9E9"!B<G5G(&%F($A45%`@05!)(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S0@;&EB+TYE="]335,O
M=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O
M=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*(D1E;FYE(&1R:79E<B!T:6QL861E<B!A9G-E;F1E;'-E(&%F
M(&)E<VME9&5R(&EG96YN96T@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB
M861G86YG<W!U;FMT970@=F5D(&)R=6<@868@2%144"!!4$DB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H
M('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E
M=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB1&5N;F4@9')I
M=F5R('1I;&QA9&5R(&%F<V5N9&5L<V4@868@8F5S:V5D97(@:6=E;FYE;2!S
M;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!A9&=A;F=S<'5N
M:W1E="!V960@8G)U9R!A9B!(5%10($%022(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"B,Z(&QI8B].970O
M4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H
M<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@
M5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N
M="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN
M(@IM<V=S='(@(B(*(D1E;FYE(&1R:79E<B!T:6QL861E<B!A9G-E;F1E;'-E
M(&%F(&)E<VME9&5R('9I82!33510(&EG96YN96T@5F]D869O;F4@(@HB271A
M;&EE;B!A9&=A;F=S<'5N:W1E="P@9&]G(&MU;B!T:6P@5F]D869O;F4M;G5M
M<F4N($1E;B!K<N9V97(@96X@92TB"B)M86EL:V]N=&\@:&]S(%9O9&%F;VYE
M($ET86QI96X@*&AT='`Z+R]W=W<N,3DP+FET*2XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`U
M-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3$X,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,Y.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-34W(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DU."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`U"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P,CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C`W.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,30Y(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C0P."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4P"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V,S<@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@Q,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$Y(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.3<*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S@P-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#$S"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HY-S@@;&EB+TAO<F1E+T9O<FTN<&AP.C$P
M-3<@;&EB+TAO<F1E+T9O<FTN<&AP.C$P.#8*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Q,34@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q.#(@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$R-38*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,#4@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$S.3@@;&EB+TAO<F1E+T9O<FTN<&AP.C$U-3<*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$X,SD@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y
M-3@@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,#4*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(P,CD@;&EB+TAO<F1E+T9O<FTN<&AP.C(P-S@@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(Q-#D*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R,C$@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(T,#@@;&EB+TAO<F1E+T9O<FTN<&AP.C(T-3`*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(V,S<@;&EB+TAO<F1E+T9O<FTN<&AP.C(X
M,3`@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,3D*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,R.3<@;&EB+TAO<F1E+T9O<FTN<&AP.C,X,#4@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,X,3,*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM
M<V=S='(@(D1E='1E(&9E;'0@97(@:W+F=F5T+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$P-C4@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-C4*;7-G
M:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS
M9W-T<B`B1&5T=&4@9F5L="!MY2!K=6X@:6YD96AO;&1E(&AE;'1A;"XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$V(&QI8B](;W)D92]&;W)M
M+G!H<#HR-#$V"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R(")$971T92!F96QT(&WE
M(&MU;B!I;F1E:&]L9&4@;G5M<F4@;V<@:V]L;VXN(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`Y-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`Y-`IM
M<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E
M<RXB"FUS9W-T<B`B1&5T=&4@9F5L="!MY2!K=6X@:6YD96AO;&1E(&]K=&%L
M92!VYG)D:65R+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C,@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S
M="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G
M97)S(@IM<V=S='(@(B(*(D1E='1E(&9E;'0@<VMA;"!VYG)E(&5N(&MO;6UA
M+2!E;&QE<B!M96QL96UR=6US861S:VEL9'0@;&ES=&4@868@:&5L=&%L(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@Y(&QI8B](;W)D92]&;W)M
M+G!H<#HY.#D*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU
M;6)E<BXB"FUS9W-T<B`B1&5T=&4@9F5L="!S:V%L(';F<F4@970@9WEL9&EG
M="!N=6UM97(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q."!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C@Q.`IM<V=I9"`B(@HB5&AI<R!F:65L9"!M
M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA
M="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R(")$971T92!F
M96QT('-K86P@:6YD96AO;&1E(&5N(&9A<G9E:V]D92!I(%)'0B!H97@M9F]R
M;6%T+"!F>"`G(S$R,S1A9B<N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z-38Q(&QI8B](;W)D92]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R
M;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B1&5N;F4@
M9F]R;75L87(@97(@86QL97)E9&4@<')O8V5S<V5R970N(@H*(SH@=&5M<&QA
M=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI
M<R!I<R`E<RXB"FUS9W-T<B`B1&5T=&4@97(@)7,N(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HT-CD@;&EB+TAO<F1E+TMO;&%B+G!H<#HT-CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P
M=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E
M9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L
M86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL
M("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*(D1E='1E
M(&5R(&5T($MO;&%B($=R;W5P=V%R92UO8FIE:W0N($9O<B!A="!S92!D971T
M92!O8FIE:W0@:&%R(&1U(&)R=6<@9F]R("(*(F5N(&4M;6%I;"UK;&EE;G0L
M('-O;2!F;W)S=.5R($MO;&%B($=R;W5P=V%R92UF;W)M871E="X@0F5S^&<@
M)7,@9F]R(&5N("(*(FQI<W1E(&%F(&ML:65N=&5R+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y.2!L:6(O2&]R9&4O34E-12]#
M;VYT96YT<RYP:'`Z-3DY"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S
M<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE
M<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R(")$96YN92!B97-K960@97(@<VMR
M979E="!M960@970@86YD970@=&5G;G/F="`H)7,I(&5N9"!D:70@96=E="XB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-B!L:6(O2&]R
M9&4O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B
M92!A="!L96%S="!O;F4N(@IM<V=S='(@(E1A;&QE="!S:V%L(';F<F4@;6EN
M+B`Q+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H
M<#HT-2!L:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H
M:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S
M+B(*;7-G<W1R(")$96YN92!S97)V97(@:V%N(&EK:V4@9&5K;VUP<FEM97)E
M('II<"T@;V<@9WII<"UF:6QE<BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O4F5G:7-T<GDN<&AP.C$X.2!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C$X
M.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D
M+B(*;7-G<W1R(")$971T92!S>7-T96T@97(@9&5A:W1I=F5R970N(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C0@;&EB+TAO<F1E+U!R
M969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU
M;6)E<BXB"FUS9W-T<B`B1&5N;F4@=N9R9&D@<VMA;"!VYG)E(&5T('1A;"XB
M"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED
M(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@
M=VEN9&]W(@IM<V=S='(@(D1E='1E('9I;F1U92!S:V%L(&MA;&1E<R!F<F$@
M970@5&EL=F%L9W-V:6YD=64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R(")4;W)D
M96XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,V"FUS9VED(")4
M:6-K971S(@IM<V=S='(@(E-A9V5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C0R-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0R-0HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(E1I;64B"FUS9W-T<B`B
M5&ED(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X.`IM<V=I9"`B
M5&EM92!4<F%C:VEN9R(*;7-G<W1R(")4:61S;W!G^')E;'-E(@H*(SH@;&EB
M+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R
M(")4:61S9F]R;6%T(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S
M,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4S,0IM<V=I9"`B5&EM92!S96QE8W1I
M;VXB"FUS9W-T<B`B5&ED<W9A;&<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(S,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I
M;6]R+4QE<W1E(@IM<V=S='(@(E1I;6]R+4QE<W1E(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.0HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H
M<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B5&ET96PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L
M92`H=&]O;'1I<"DZ(@IM<V=S='(@(E1I=&QE("AT;V]L=&EP*3HB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*
M;7-G<W1R(")4:6PB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-C4T"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@
M:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K
M97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*(D9O<B!A="!VYFQG
M92!M=6QT:7!L92!I;F1G86YG92!S:V%L($-T<FPM("A00RD@96QL97(@0V]M
M;6%N9"`H36%C*2UT87-T96X@(@HB:&]L9&5S(&YE9&4@;65D96YS(&1E<B!K
M;&EK:V5S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`*
M;7-G:60@(E1O9&%Y(@IM<V=S='(@(DD@1&%G(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A4
M34P@4V]U<F-E(@IM<V=S='(@(E-K:69T($A434PM:VEL9&4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(R,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T<B`B5&]G;R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C(V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R(")4;VME;&%U(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,@IM<V=I9"`B5&]M;W)R;W<B"FUS
M9W-T<B`B22!M;W)G96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,C4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R
M.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM
M<V=S='(@(E1O;F=A(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K;VQA8BYP
M:'`Z,3`T(&QI8B](;W)D92]!=71H+VMO;&%B+G!H<#HQ,#0*;7-G:60@(E1O
M;R!M86YY(&EN=F%L:60@;&]G:6YS(&1U<FEN9R!T:&4@;&%S="!M:6YU=&5S
M+B(*;7-G<W1R(")&;W(@;6%N9V4@=6=Y;&1I9V4@;&]G:6YD+69O<G/X9R!I
M(&SX8F5T(&%F(&1E('-I9'-T92!M:6YU='1E<BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*;7-G:60@(E1O
M<"(*;7-G<W1R(")4;W`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S
M='(@(E1O<"!F<F%M92`H7W1O<"DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R(")/=F5R<^9T=&5L
M<V5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S(@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O
M(@IM<V=S='(@(E1R:6YI9&%D(&]G(%1O8F%G;R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$W.3`@;&EB+TAO<F1E+T9O<FTN<&AP.C$W.3`*;7-G
M:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B4V%N9"!E;&QE<B!F86QS:R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*
M;7-G:60@(E1U(@IM<V=S='(@(E1I<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C(X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B
M5'5N:7-I82(*;7-G<W1R(")4=6YE<VEE;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C,Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I
M9"`B5'5R:V5Y(@IM<V=S='(@(E1Y<FMI970B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y-0IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T
M<B`B5'ER:VES:R`H25-/+3@X-3DM.2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(R-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@
M(E1U<FMM96YI<W1A;B(*;7-G<W1R(")4=7)K;65N:7-T86XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(R,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R
M(")4=7)K<R!O9R!#86EC;W,@V&5R;F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(S,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@
M(E1U=F%L=2(*;7-G<W1R(")4=79A;'4B"@HC.B!F<F%M97=O<FLO0TQ)+T-,
M22YP:'`Z,C8T(&QI8B](;W)D92]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y
M;W5R(&-H;VEC93H@(@IM<V=S='(@(E-K<FEV(&1I="!V86QG.B`B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4X"FUS9VED(")5+E8N(&EN
M9&5X.B`B"FUS9W-T<B`B52Y6+BUI;F1E:W,Z("(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@
M<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B55),(&9O
M<B!S:W)I<'0@=&EL(&UO9'1A9V5L<V4@868@<W1A='5S(')A<'!O<G1E;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3<*
M;7-G:60@(E523#HB"FUS9W-T<B`B55),.B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C,W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I
M9"`B56=A;F1A(@IM<V=S='(@(E5G86YD82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C,V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I
M9"`B56MR86EN92(*;7-G<W1R(")5:W)A:6YE(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z-#$Y(&QI8B]61E,O9FEL92YP:'`Z-#$Y"FUS9VED
M(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DMU
M;FYE(&EK:V4@=&EL9^4@5D93+6MA=&%L;V<N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.CDV(&QI8B](;W)D92]!=71H+U-I9VYU<"YP
M:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA
M=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(DMA;B!I:VME('1I;&;X
M:F4@96MS=')A(&)R=6=E<B!I;F9O<FUA=&EO;B!U;F1E<B!O<'-K<FEV;FEN
M9RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Y,R!L:6(O5D93
M+V9T<"YP:'`Z,SDS"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M(")+86X@:6MK92#F;F1R92!T:6QL861E;'-E<B!F;W(@5D93+69I;"!<(B5S
M7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,SDR(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*(SH@;&EB+U9&4R]F:6QE+G!H
M<#HS.3(@;&EB+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@
M)7,O)7,N(@IM<V=S='(@(DMA;B!I:VME(.9N9')E('1I;&QA9&5L<V5R(&9O
M<B!61E,M9FEL("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-S@V(&QI8B]61E,O9G1P+G!H<#HW.#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B2V%N(&EK:V4@
M<VMI9G1E('1I;"`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C(S-R!L:6(O5D93+V9T<"YP:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R
M(")+86X@:6MK92!T:F5K:V4@9FEL<W3X<G)E;'-E;B!A9B!<(B5S7"(N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-CDU(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,3`R.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z.#4P(&QI8B]61E,O9FEL92YP:'`Z-CDU"B,Z(&QI8B]61E,O
M<W%L+G!H<#HQ,#(X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C@U,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB
M)7,O)7-<(BXB"FUS9W-T<B`B2V%N(&EK:V4@=&IE:VME(&9I;'-T^')R96QS
M96X@868@7"(E<R\E<UPB+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L
M+G!H<#HT,SD@;&EB+TAO<F1E+T%U=&@O<W%L+G!H<#HT,SD*;7-G:60@(E5N
M86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(DMU;FYE
M(&EK:V4@9N4@9F]R8FEN9&5L<V4@=&EL(%-13"!S97)V97)E;BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@W,"!L:6(O5D93+V9T<"YP:'`Z
M.#<P"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T
M<B`B2V%N(&EK:V4@9N4@9F]R8FEN9&5L<V4@;65D(%-33"XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S(@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C,W"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HR,#0@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P.0HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C$W(&QI8B]61E,O9FEL
M92YP:'`Z,C,R"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C,W(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C(P-"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,#D*(SH@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z,C$W"FUS9VED(")5;F%B;&4@=&\@8V]P>2!6
M1E,@9FEL92XB"FUS9W-T<B`B2V%N(&EK:V4@:V]P:65R92!61E,M9FEL+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S<P(&QI8B]61E,O9G1P
M+G!H<#HS-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EK:V4@9&%N
M;F4@5D93+6MA=&%L;V<@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C,V,2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C4X
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-C0@;&EB+U9&
M4R]F:6QE+G!H<#HS-C$*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,C4X(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C(V-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!6
M1E,@9&ER96-T;W)Y+B(*;7-G<W1R(")+86X@:6MK92!D86YN92!61E,M:V%T
M86QO9RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T(&QI
M8B]61E,O;75S<6PN<&AP.C$R-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!6
M1E,@9FEL92XB"FUS9W-T<B`B2V%N(&EK:V4@;&%V92!61E,M9FEL+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,CDP(&QI8B]61E,O<VUB+G!H
M<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!6
M1E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EK:V4@;W!R971T92!6
M1E,M;6%P<&4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(W,B!L:6(O5D93+V9I;&4N<&AP.C(W,@IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EK:V4@;&%V
M92!T;VT@5D93+69I;"XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O9WII<"YP:'`Z-SD*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+W1A<BYP:'`Z-S8@;&EB+TAO<F1E+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"B,Z
M(&QI8B](;W)D92]#;VUP<F5S<R]T87(N<&AP.C<V"FUS9VED(")5;F%B;&4@
M=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R(")+86X@:6MK92!D96MO;7!R
M:6UE<F4@9&%T82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,P
M,R!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R.`HC.B!L:6(O5D93+V9T
M<"YP:'`Z,S`S(&QI8B]61E,O<VUB+G!H<#HR,C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@
M:7,@;F]T(&5M<'1Y+B(*;7-G<W1R(")+86X@:6MK92!S;&5T=&4@7"(E<UPB
M.R!K871A;&]G970@97(@:6MK92!T;VUT+B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@
M(DMA;B!I:VME('-L971T92!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C,S."!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,S$Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,SDU(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#(*(SH@;&EB+U9&4R]F:6QE
M+G!H<#HS,S@@;&EB+U9&4R]M=7-Q;"YP:'`Z,S$Q(&QI8B]61E,O<W%L+G!H
M<#HS.34*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S0R"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@
M:7,@;F]T(&5M<'1Y(@IM<V=S='(@(DMA;B!I:VME('-L971T92`E<SL@:V%T
M86QO9V5T(&5R(&EK:V4@=&]M="(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HS-38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,V,`HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS-38@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,S8P"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E
M8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(DMA;B!I:VME('-L971T92!6
M1E,M:V%T86QO9V5T(')E:W5R<VEV="XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HS-#0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R
M,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,U,B!L:6(O5D93+V9I;&4N<&AP.C,T-`HC.B!L:6(O
M5D93+VUU<W%L+G!H<#HS,C(@;&EB+U9&4R]M=7-Q;"YP:'`Z,S,U(&QI8B]6
M1E,O;75S<6PN<&AP.C,T,PHC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS-3(*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B2V%N(&EK:V4@<VQE='1E(%9&4RUK871A;&]G+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z-#(P(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z-#,R"B,Z(&QI8B]61E,O<W%L+G!H<#HT,C`@;&EB+U9&4R]S<6PN<&AP
M.C0S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(")+86X@:6MK92!S;&5T=&4@5D93
M+6MA=&%L;V<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,C$R(&QI8B]61E,O9G1P+G!H<#HR,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DMA
M;B!I:VME('-L971T92!61E,M9FEL(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HS,3`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C$V-PHC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HR.3$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,Y,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDY
M(&QI8B]61E,O9FEL92YP:'`Z,S$P"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$V
M-R!L:6(O5D93+VUU<W%L+G!H<#HQ.#`@;&EB+U9&4R]M=7-Q;"YP:'`Z,3@W
M"B,Z(&QI8B]61E,O<W%L+G!H<#HR.3$@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M,SDQ(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,Y.0IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EK:V4@<VQE='1E(%9&
M4RUF:6PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-#@@;&EB
M+U9&4R]S;6(N<&AP.C(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")+86X@:6MK
M92!S;&5T=&4@5D93+6UA<'!E(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C0P.2!L:6(O5D93+W-Q;"YP:'`Z-#`Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY
M.B`E<RXB"FUS9W-T<B`B2V%N(&EK:V4@<VQE='1E(%9&4R!R96MU<G-I=G0Z
M("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,T(&QI8B]6
M1E,O9G1P+G!H<#HX,S0*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R
M<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(DMA;B!I:VME(&)E<W1E;6UE(&%K
M='5E;'0@:V%T86QO9RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8P-"!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8P-`IM<V=I
M9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G
M<W1R(")+86X@:6MK92!U9&1R86=E(&-E<G1I9FEK870M9&5T86QJ97(B"@HC
M.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#,W(&9R86UE=V]R:R].
M971?24U34"])35-0+T%U=&@N<&AP.C$R,PHC.B!L:6(O3F5T+TE-4U`N<&AP
M.C0S-R!L:6(O3F5T+TE-4U`O075T:"YP:'`Z,3(S"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*
M;7-G<W1R(")+86X@:6MK92!I;F1LYG-E(&1E9FEN:71I;VYE;B!A9B`E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#,@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C`X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ-S0@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C$W.0HC.B!L:6(O5D93+V9I;&4N<&AP.C(P,R!L:6(O5D93+V9I;&4N<&AP
M.C(P."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-S0*(SH@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB
M"FUS9W-T<B`B2V%N(&EK:V4@9FQY='1E(%9&4RUF:6PN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HY."!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.CDS"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`V(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-C4R"B,Z(&QI8B]61E,O9G1P+G!H<#HY
M."!L:6(O5D93+W-M8BYP:'`Z.3,@;&EB+U9&4R]S;6(N<&AP.C$P-@HC.B!L
M:6(O5D93+W-M8BYP:'`Z-C4R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EK:V4@
MY6)N92!61E,M9FEL(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR.#0@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S
M.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30Q(&QI8B]6
M1E,O9FEL92YP:'`Z,C@T"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$S."!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-#$*;7-G:60@(E5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R(")+86X@:6MK92#E8FYE
M(%9&4RUF:6P@=&EL('-K<FEV;FEN9RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HX,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S<*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<V(&QI8B]61E,O
M9FEL92YP:'`Z.#,@;&EB+U9&4R]F:6QE+G!H<#HQ,S<*(SH@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z-S8*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M+B(*;7-G<W1R(")+86X@:6MK92#E8FYE(%9&4RUF:6PN(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT-2!L:6(O2&]R9&4O34E-
M12]6:65W97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M
M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R(")+86X@:6MK92#E8FYE(&MO;7!R
M:6UE<F5T(&%R:VEV+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-38@
M;&EB+U9&4RYP:'`Z.#4V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL
M92`H9FEL97-I>F4H*2!F86EL960I+B(*;7-G<W1R(")+86X@:6MK92!LYG-E
M(%9&4RUF:6P@*&9I;&5S:7IE*"D@9F5J;&5D92DN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C@X-R!L:6(O5D93+G!H<#HX.#<*;7-G:60@(E5N86)L
M92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM
M<V=S='(@(DMA;B!I:VME(&SF<V4@5D93+69I;"`H9V5T1FEL95-I>F4H*2!F
M96IL961E*2XB"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO
M;DAA;F1L97(O;F]N92YP:'`Z,S@*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD
M;&5R+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B
M"FUS9W-T<B`B2V%N(&EK:V4@;.9S92!F:6PZ("(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C8W-B!L:6(O5D93+V9I;&4N<&AP.C8W-@IM<V=I
M9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G
M<W1R(")+86X@:6MK92!LYG-E('9F<W)O;W0M:V%T86QO9V5T+B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$P.2!L:6(O2&]R9&4O2V]L86(N
M<&AP.C$Q,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S
M(@IM<V=S='(@(DMA;B!I:VME(&]M9/AB92`E<R!T:6P@)7,Z(&WE;&UA<'!E
M;B!F:6YD97,@86QL97)E9&4B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,S`Q(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,P,0IM<V=I9"`B
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")+86X@
M:6MK92!O;63X8F4@5D93+6MA=&%L;V<N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HS,S(@;&EB+U9&4R]S<6PN<&AP.C,S,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S
M+B(*;7-G<W1R(")+86X@:6MK92!O;63X8F4@5D93+6MA=&%L;V<Z("5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S0X(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,C<Q"B,Z(&QI8B]61E,O9G1P+G!H<#HS-#@@;&EB
M+U9&4R]S;6(N<&AP.C(W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EK:V4@
M;VUD^&)E(%9&4RUF:6P@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C8Q-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z-C$W(&QI8B]61E,O;75S<6PN<&AP.C(R
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE("5S+R5S+B(*;7-G<W1R(")+86X@:6MK92!O;63X8F4@5D93+69I;"`E
M<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HS,C8@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C(Y,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Y
M(&QI8B]61E,O;75S<6PN<&AP.C(Q,PHC.B!L:6(O5D93+VUU<W%L+G!H<#HT
M-3(@;&EB+U9&4R]S<6PN<&AP.C,R-B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR
M.3,*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S`Y"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R(")+86X@:6MK92!O;63X8F4@
M5D93+69I;"XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O;6MI<V]F<RYP:'`Z-3`*(SH@;&EB+U9&4R])4T]7<FET97(O;6MI<V]F
M<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G
M<W1R(")+86X@:6MK92!A9G9I:VQE("=M:VES;V9S)RXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@
M=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R(")+=6YN92!I
M:VME(&]V97)SYG1T92!D971T92!7;W)D(&1O:W5M96YT(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HQ-30@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HQ-3<*(SH@;&EB+U9&4R]F='`N<&AP.C$U-"!L:6(O5D93+V9T<"YP
M:'`Z,34W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DMA;B!I:VME('-K<FEV92!61E,M
M9FEL(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ
M.#8@;&EB+U9&4R]F:6QE+G!H<#HQ.#8*;7-G:60@(E5N86)L92!T;R!W<FET
M92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(DMA;B!I:VME
M('-K<FEV92!61E,M9FEL("AC;W!Y*"D@9F5J;&5D92DN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@X(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ-#8*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C$U,2!L:6(O5D93+V9I;&4N<&AP.C(X.`HC.B!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HQ-#8@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,34Q"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B2V%N(&EK
M:V4@<VMR:79E(%9&4RUF:6QD871A+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HX-C(@;&EB+U9&4RYP:'`Z.#8R"FUS9VED(")5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@
M(DMA;B!I:VME('-K<FEV92!61E,M9FEL.R!K=F]T96X@=FEL(&)L:79E(&]V
M97)S:W)E9&5T+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R(")5;F1E<FQI
M;FEE<F5T(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B
M56YD;R!#:&%N9V5S(@IM<V=S='(@(D9O<G1R>60@YFYD<FEN9V5R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I
M9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B3VUG^'(@9&EN
M('-I9'-T92!H86YD;&EN9R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C(R,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS.#@@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(R,0HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@X"FUS
M9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE
M8W1I;VXZ("(*;7-G<W1R(")5=F5N=&5T(')E86MT:6]N(&9R82!S97)V97(@
M<.4@9F]R8FEN9&5L<V5N.B`B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HR,3<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S,Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,W-@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS.#(@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q
M-PHC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S,Y(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S8*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,X,@IM<V=I9"`B56YE>'!E8W1E9"!R97-P
M;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(E5V96YT970@<F5A:W1I
M;VX@9G)A('-E<G9E<B!PY3H@(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@;&EB+TAO<F1E+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B
M26MK92!A;F)R86=T(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*;7-G
M:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R(")5;FEC;V1E("A55$8M."DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-R!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T
M<B`B1F]R96YE9&4@07)A8FES:V4@16UI<F%T97(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C,X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS
M9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R(")3=&]R8G)I='1A;FEE;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S
M-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0P(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R(")5
M4T$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,S<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S.2!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@
M3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R(")54T%S('5N9&5R;W)D;F5D92#X
M97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C<X(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HV,@IM<V=I9"`B56YI=',B"FUS9W-T<B`B16YH961E
M<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-3@@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S,"!L:6(O2&]R9&4O34E-12]6:65W
M97(O=&=Z+G!H<#HU.`HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,CD@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM
M<V=S='(@(E5K96YD="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y.`HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE
M<W-A9V4@240I+B(*;7-G<W1R(")5:V5N9'0@87!I;7-G:60@*$%022!-97-S
M86=E($E$*2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3D*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S
M86=E($E$*2XB"FUS9W-T<B`B56ME;F1T(&-L:6US9VED("A#;&EE;G0@365S
M<V%G92!)1"DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T
M-PIM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B
M56ME;F1T('-T960@86YG:79E="XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@
M;W(@<&%S<W=O<F0N(@IM<V=S='(@(E5K96YD="!B<G5G97)N879N(&5L;&5R
M(&MO9&5O<F0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@
M96QE;65N="(*;7-G<W1R(")(YF=T(&%K='5E;'0@96QE;65N="!A9BXB"@HC
M.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P,B!L:6(O2&]R
M9&4O261E;G1I='DN<&AP.C,P,@IM<V=I9"`B56YN86UE9"(*;7-G<W1R("))
M:VME(&YA=FYG:79E="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S
M(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY
M(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@
M=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@
M>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B
M;V%R9"XB"FUS9W-T<B`B(@HB57!R:79I;&EG97)E9&4@<VMR:7!T97(@:V%N
M(&EK:V4@=&EL9^4@:VQI<'!E+VMO<&DO:6YD<^9T('!R;V=R86UMYG-S:6=T
M(&%F("(*(G-I:VME<FAE9'/E<G-A9V5R+B`@2VQI:R!/2R!F;W(@870@<V4@
M96X@=&5K;FES:R!N;W1E(&AO<R!M;WII;&QA+F]R9RP@<V]M("(*(G9I<V5R
M(&1I9RP@:'9O<F1A;B!D=2!K86X@=&EL;&%D92!E="!S:W)I<'0@870@=&EL
M9^4@=61K;&EP<VAO;&1E<F5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R
M(@IM<V=S='(@(D9A<G9E(&EK:V4@:6YD<W1I;&QE="(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@W(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z.3(W"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z.3,S(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C@W"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z.3(W(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z.3,S"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB
M"FUS9W-T<B`B561V:61D96QS92!I:VME('5N9&5R<W3X='1E="(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW(&QI8B](;W)D92]097)M
M<R]522YP:'`Z,3DW"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B3W!D873I<B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B57!D871E("5S(@IM<V=S='(@(D]P9&%TZ7(@)7,B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@
M=7-E<B(*;7-G<W1R(")/<&1A=.ER(&)R=6=E<B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T
M960@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@;W!D871E<F5T+B(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP
M="!D96QE=&5D+B(*;7-G<W1R(")/<&=R861E<FEN9W,M9F]R97-K<FEF="!S
M;&5T=&5T+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.`HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DX"FUS9VED(")5<&QO860B
M"FUS9W-T<B`B57!L;V%D(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X
M-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S
M('1O('1H92!S97)V97(N(@IM<V=S='(@(D]P<^9T;FEN9W-F:6QE<B!T:6P@
M86QL92!A<'!L:6MA=&EO;F5R(&QA9W0@;W`@<.4@<V5R=F5R+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B4W1O<F4@
M;&%T:6YS:V4@8F]G<W1A=F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M
M86X@;G5M8F5R<R(*;7-G<W1R(")3=&]R92!R;VUE<G1A;"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C0Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R(")5<G5G=6%Y(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(SH@
M;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(D%N=F5N
M9"!N=7;F<F5N9&4Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,S@*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R(")"<G5G(%-3
M3"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C<*;7-G:60@(E5S92!I
M9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N
M(@IM<V=S='(@(D)R=6<@:'9I<R!N879N+VMO9&5O<F0@97(@9F]R<VME;&QI
M9R!F;W(@24U34"US97)V97(N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHR,0IM<V=I9"`B57-E<B(*;7-G<W1R(")"<G5G97(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<W-"!L:6(O
M2&]R9&4O4F5G:7-T<GDN<&AP.C<W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B0G)U
M9V5R("5S(&EK:V4@8F5M>6YD:6=E="!T:6P@)7,N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(D)R=6=E<BUA9&UI;FES=')A=&EO;B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,C0U(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,C0U"FUS
M9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B0G)U9V5R:6YD<W1I;&QI;F=E
M<B(*"B,Z('-I9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N
M(@IM<V=S='(@(D)R=6=E<BUR96=I<W1R97)I;F<B"@HC.B!S:6=N=7`N<&AP
M.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R(")"<G5G97(M<F5G:7-T<F5R:6YG
M(&5R(&)L979E="!S;.5E="!F<F$@<.4@9&5T=&4@=V5B<W1E9"XB"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-#DT"FUS9VED(")5<V5R(&%C8V]U;G0@
M;F]T(&9O=6YD(@IM<V=S='(@(D)R=6=E<FMO;G1O(&EK:V4@9G5N9&5T(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W
M.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HQ.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ-3`@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S
M-@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&QI8B].970O
M4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B
M"FUS9W-T<B`B0G)U9V5R;F%V;B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HQ,C0@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HQ,C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@
M97AI<W1S+B(*;7-G<W1R(")"<G5G97)N879N(%PB)7-<(B!F:6YD97,@86QL
M97)E9&4N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W"FUS
M9VED(")5<V5R;F%M93HB"FUS9W-T<B`B0G)U9V5R;F%V;CHB"@HC.B!T96UP
M;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5<V5R;F%M93H@(@IM
M<V=S='(@(D)R=6=E<FYA=FXZ("(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S
M='(@(D)R=6=E<F4@:2!S>7-T96UE=#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(T,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@
M(E5Z8F5K:7-T86XB"FUS9W-T<B`B57-B96MI<W1A;B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C$W,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR-C(*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ-S`@;&EB+U9&4R]F:6QE
M+G!H<#HR-C(*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N
M(@IM<V=S='(@(E9&4RUK871A;&]G(&5K<VES=&5R97(@:6MK92XB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3(P"FUS9VED(")686-A=&EO;B(*
M;7-G<W1R(")&97)I92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V
M-B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#8V"FUS9VED(")686QI9"!L;V-A=&EO
M;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(D=Y;&1I9V4@9G5N9&5T('-T
M961E<B!I;FML=61E<F5R.B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C,Y(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS
M9VED(")686QI9&ET>2(*;7-G<W1R(")'>6QD:6=H960B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-R!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN
M=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B5N9R9&D@97(@;6EN=71T97(@9G)A
M(&YU+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@U-B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3<W"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX
M-38@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM
M<V=S='(@(E;F<F1I(&5R(&UE<F4@96YD(&1E;B!M86MS:6UA;&4@;.9N9V1E
M(&%F("5S+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#0@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S$V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,3`*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C(T-`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(V
M-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,Q-B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,CDQ,`HC.B!L:6(O2&]R9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM
M<V=I9"`B5F%L=65S(@IM<V=S='(@(E;F<F1I97(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3`Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M.#8*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,#D@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R
M(")6YG)D:65R+"!D97(@:V%N(';F;&=E<R!I8FQA;F1T(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-#D@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$W"FUS9VED(")686YU871U(@IM<V=S='(@(E9A;G5A='4B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,S"FUS9VED(")687)I86)L92(*
M;7-G<W1R(")3:VEF=&5N9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(T-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z
M=65L82(*;7-G<W1R(")696YE>G5E;&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C(Q."!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G
M92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(D5F=&5R
M<'+X=FYI;F<@9F5J;&5D92`M(&1E<B!E<B!B;&5V970@<&EL;&5T('9E9"!D
M96YN92!B97-K960N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HW,#$@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@
M(E9E<G-I;VXB"FUS9W-T<B`B5F5R<VEO;B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR,C@*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R
M(")697)S:6]N<VMO;G1R;VPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG
M;B(*;7-G<W1R("),;V1R970@;W!S=&EL;&EN9R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L
M('!A9&1I;F<B"FUS9W-T<B`B3&]D<F5T(&9O<G)I;F<B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T
M:6-A;#HB"FUS9W-T<B`B3&]D<F5T.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")697)Y($AI9V@B"FUS9W-T
M<B`B365G970@:/AJ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#@@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*
M;7-G<W1R(")6:65T;F%M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3<*
M;7-G:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B5FEE=&YA;65S
M:7-K("A625-#24DI(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.3<Q(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HY-S$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R(")6:7,@)7,B"@HC
M.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R
M;F%L('=E8B!P86=E(@IM<V=S='(@(E-E('#E(&5K<W1E<FX@=V5B<VED92(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S,"!L:6(O
M2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#,P"B,L('!H<"UF;W)M870*;7-G
M:60@(E9I97<@87,@)7,B"FUS9W-T<B`B5FES('-O;2`E<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C0V(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B
M2F]M9G)U^&5R+"!"<FET:7-K92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C0W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER
M9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B2F]M9G)U^&5R+"!!;65R:6MA
M;G-K92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$V"FUS9VED(")6:7-I
M8FEL:71Y(@IM<V=S='(@(E-Y;FQI9VAE9"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-3(*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R
M(")3>6YL:6=H960Z("(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.C@T"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE
M:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!3
M3510(@IM<V=S='(@(E9O9&%F;VYE($ET86QI96X@=FEA(%--5%`B"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.C,V"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N
M97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R(")705).(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@
M)7,N(@IM<V=S='(@(D%$5D%24T5,(2$A($9*15).(%-#4DE05"!-04Y514Q4
M($9202`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$S,R!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")7
M24X@=FEA($A45%`B"FUS9W-T<B`B5TE.('9I82!(5%10(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-3`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$W"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R(")786QL:7,@
M;V<@1G5T=6YA(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C<*(SH@;&EB+TAO<F1E+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]H=&UL+G!H<#HQ,C<@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.CDU"FUS9VED(")787)N:6YG(@IM<V=S='(@(D%D=F%R<V5L(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B
M5V4B"FUS9W-T<B`B3VYS(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@(E9E:G)U
M9'-I9W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$V"FUS
M9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B5F5J<FEN
M9F]R;6%T:6]N('-T:6QL970@=&EL<N5D:6=H960@868B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HX.3(@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y,@IM
M<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B5V5A=&AE<BYC;VTB"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(E=E
M8B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,SD*;7-G:60@(E=E
M8B!3:71E(@IM<V=S='(@(E=E8G-I=&4B"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X(&QI8B](;W)D92]-86EN=&5N86YC
M92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R(")59V5N=&QI9R(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC;VUE
M(@IM<V=S='(@(E9E;&MO;6UE;B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z-3<@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(E9E;&MO;6UE
M;B!T:6P@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T
M96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B5F5L:V]M;65N+"`E<R(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DX"FUS9VED(")797-T97)N("A)4T\M.#@U
M.2TQ*2(*;7-G<W1R(")697-T;&EG("A)4T\M.#@U.2TQ*2(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DY"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ
M-2DB"FUS9W-T<B`B5F5S=&QI9R`H25-/+3@X-3DM,34I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-S@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(E9E<W1S86AA<F$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@
M;&]G:6X_(@IM<V=S='(@(DAV:6QK96X@87!P;&EK871I;VX@<VMA;"`E<R!V
M:7-E(&5F=&5R(&QO9VEN9#\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E
M<C\B"FUS9W-T<B`B2'9A9"!E<B!S97!A<F%T;W)T96=N970_(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE
M('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B2'9A9"!E<B!C:71A=&EO;G-T
M96=N970_(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P-C4*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P-C4*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R(")7
M:&5R96ES($%U<W1R86QI96XM:V]R="(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(DAV:6QK92!F87-E
M<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S8*;7-G:60@(E=H:6-H
M('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB
M"FUS9W-T<B`B2'9I;&ME('!L=6=I;G,@<VMA;"!A:W1I=F5R97,@9F]R(%)I
M8V@@5&5X="UVYG)K=/AJ970N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T
M<B`B0G)E9&1E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P-R!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S$P-PIM<V=I9"`B5VED=&@@:6X@0U-3('5N
M:71S(@IM<V=S='(@(D)R961D92!I($-34RUE;FAE9&5R(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T
M:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N
M(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`B0G)E9&1E(&%F("5S+6UE;G5E;B!T
M:6P@=F5N<W1R92`H8FQI=F5R(&%K=&EV97)E="!V960@;N9S=&4@;&]G:6YD
M*3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(D)R961D
M92!A9B!T86)E;&QE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@(D)R
M961D92UE;FAE9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`B0G)E9&1E.B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,34*;7-G:60@(E=I:VDB
M"FUS9W-T<B`B5VEK:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.#D@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*
M;7-G:60@(E=I;F0B"FUS9W-T<B`B5FEN9"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")7:6YD($5A<FQY(@IM
M<V=S='(@(D)LYG-T('1I9&QI9W0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C@W"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(E9I;F1H
M87-T:6=H960@:2!K;F]B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C,*
M;7-G:60@(E=I;F0Z(@IM<V=S='(@(E9I;F0Z(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(E9I
M;F0Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES
M9&]M(@IM<V=S='(@(E9I<V1O;2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ.3@*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(MAN<VME;&ES=&4B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB"FUS
M9W-T<B`B07)B96ID92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$V-`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$R-"!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM
M<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(D%D<F5S<V4@*&%R8F5J9&4I
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y
M,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I
M9"`B5V]R:R!0:&]N92(*;7-G<W1R(")496QE9F]N("AA<F)E:F1E*2(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$Y,R!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HR.30*(SH@;&EB+T9I;&4O0U-6+G!H<#HQ.3,@;&EB
M+T9I;&4O0U-6+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@
M;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U
M;F0@)60N(@IM<V=S='(@(D9O<FME<G0@86YT86P@9F5L=&5R(&D@;&EN:64@
M)60N($9O<G9E;G1E9&4@)60L(&9A;F1T("5D+B(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C,S,B!L:6(O1FEL92]#4U8N<&AP.C,S,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E
M8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(D9O<FME<G0@86YT86P@9F5L
M=&5R+B!&;W)V96YT961E("5D+"!F86YD="`E9"XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HQ,C$@;&EB+U9&4R]F:6QE+G!H<#HQ,C$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I
M;F<@82!61E,@9FEL92XB"FUS9W-T<B`B1F]R:V5R="!F;W)S:WED;FEN9R`E
M9"!U;F1E<B!I;F1LYG-N:6YG(&%F(&5N(%9&4RUF:6PN(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(T-0IM<V=I9"`B6"U2968B"FUS9W-T<B`B
M6"U2968B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y
M-"!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S
M($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(E@U,#EV,R!"87-I8R!#;VYS
M=')A:6YT<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3DS(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y
M=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(E@U,#EV,R!%>'1E;F1E
M9"!+97D@57-A9V4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4Y-2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B
M6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R(")8-3`Y
M=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU.38*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R
M(@IM<V=S='(@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#,@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV.#,*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS
M(@IM<V=S='(@(E@U,#EV,R!U9'9I9&1E;'-E<B(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R("+%Q2(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,30*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$T(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-38*;7-G:60@(EE965DB"FUS9W-T<B`BQ<7%
MQ2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,3$Q"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3$Q
M"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(EEA:&]O(2UK;W)T(@H*(SH@
M9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-B!L:6(O
M2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T
M<B`BQ7)L:6<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR-#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@
M(EEE;65N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDV-@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.38V"FUS9VED(")997,B"FUS9W-T<B`B2F$B"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G
M<F5E(@IM<V=S='(@(DIA+"!J96<@97(@96YI9R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@
M:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@
M8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"B)$=2!B969I;F1E<B!D:6<@
M:2!414M35"!-3T154RX@($)R=6<@6SP^72UK;F%P<&5N('1I;"!A="!S:VEF
M=&4@=&EL8F%G92!T:6P@(@HB5UE325=91RXB"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C(S-@HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C(S-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@
M)60@8FQO8VMS+B(*;7-G<W1R(")$=2!H87(@:6MK92!T:6QL861E;'-E('1I
M;"!A="!O<')E='1E(&UE<F4@96YD("5D(&)L;VMK92XB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$T,C0@;&EB+TAO<F1E+G!H<#HQ-#(T"FUS
M9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R(")$=2!E
M<B!I:VME(.9G=&5T+B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET
M>2YP:'`Z,S`X(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z,S`X"FUS9VED(")9
M;W4@8V%N;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L
M;"!N86UE+B(*;7-G<W1R(")$=2!K86X@:6MK92!H879E("=<7"<M=&5G;F5T
M(&D@9&ET(&9U;&1E(&YA=FXN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@U-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.#4U(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<U"FUS
M9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N
M(@IM<V=S='(@(D1U(&EN9'1A<W1E9&4@:6MK92!E;B!G>6QD:6<@92UP;W-T
M+6%D<F5S<V4N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP(&QI
M8B](;W)D92]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F
M:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS
M9W-T<B`B(@HB1F]R(&%T(&EM<&]R=&5R92!S:V%L(&1U('1I;&]R9&YE(&9E
M;'1E<B!F<F$@9&5N(&9I;"!D=2!I;7!O<G1E<F5R('1I;"!D92`B"B)T:6QS
M=F%R96YD92!F96QT97(@:2`E<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.#<@;&EB+TAO<F1E+T%U=&@N<&AP.CDX-PIM<V=I9"`B66]U(&AA
M=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R(")$=2!E<B!B;&5V970@;&]G
M9V5T('5D+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO=2!H879E('1O(&5N
M=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET
M:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I
M86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"B)$=2!S:V%L(&EN9'1A<W1E(&5T
M(&9U;F=E<F5N9&4@;6]B:6QN=6UM97([(&MU;B!C:69R92!M960@970@=F%L
M9V9R:2`G*R<@9F]R("(*(F1E;B!I;G1E<FYA=&EO;F%L(')E=&YI;F=S:V]D
M92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@X(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A
M;&ED('9A;'5E+B(*;7-G<W1R(")$=2!S:V%L(&EN9'1A<W1E(&5N(&=Y;&1I
M9R!VYG)D:2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M,S<@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU
M<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P
M<RXB"FUS9W-T<B`B(@HB1'4@<VMA;"!K;VYF:6=U<F5R92!E;B!$871A5')E
M92UB86-K96YD(&9O<B!A="!K=6YN92!A;G9E;F1E($]P<VMR:79N:6YG97(N
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-S$@;&EB+TAO<F1E
M+G!H<#HT-S$*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K
M96YD+B(*;7-G<W1R(")$=2!S:V%L(&MO;F9I9W5R97)E(&5N9"!61E,M8F%C
M:V5N9"XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM
M<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO
M=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(B(*(D1U
M(&)L:79E<B!N^&0@=&EL(&%T(&QA=F4@96X@<')O8FQE;6)E<VMR:79E;'-E
M+"!F^'(@9'4@:V%N('-E;F1E(&1E;B!I;F0N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@
M96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S
M='(@(D1U('-K86P@:6YD=&%S=&4@9&5N(%523"!H=F]R=&EL(&1E;FYE(&CF
M9W1E('-K86P@:&5N=FES92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN
M<&AP.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E
M(&1E;&5T960N(@IM<V=S='(@(D1U('-K86P@=N9L9V4@9&5N('-E<G9E<BP@
M<V]M('-K86P@<VQE='1E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N
M(@IM<V=S='(@(D1U('-K86P@86YG:79E(&)R=6=E<FYA=FYE="P@<V]M(&1U
M('9I;"!F:F5R;F4N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9
M;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R
M(")$=2!S:V%L(&%N9VEV92!B<G5G97)N879N970L('-O;2!D=2!V:6P@9FIE
M<FYE+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@
M=7-E<FYA;64@=&\@861D+B(*;7-G<W1R(")$=2!S:V%L(&%N9VEV92!B<G5G
M97)N879N970L('-O;2!D=2!V:6P@=&EL9OAJ92XB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE
M('1O('5P9&%T92XB"FUS9W-T<B`B1'4@<VMA;"!A;F=I=F4@8G)U9V5R;F%V
M;F5T+"!S;VT@9'4@=FEL(&]P9&%T97)E+B(*"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S."!L:6(O2&]R9&4O0V]M<')E<W,O
M>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I
M;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B1'4@<VMA;"!A;F=I=F4@9&5N(&AA
M;F1L:6YG+"!S;VT@<VMA;"!U9&;X<F5S+B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"B,Z(&QI8B](;W)D92]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED(")9;W4@;75S="!T
M>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(D1U('-K86P@86YG
M:79E(&5T(&YY="!K871E9V]R:6YA=FXN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*(SH@;&EB+TYE="]3
M35,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE960@
M=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R(")$
M=2!B;&EV97(@;OAD="!T:6P@870@86YG:79E(&5T(&ET86QI96YS:V4@=&5L
M969O;FYU;6UE<B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-2!L
M:6(O2&]R9&4O075T:"YP:'`Z.3<U"B,L('!H<"UF;W)M870*;7-G:60@(EEO
M=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN
M+B(*;7-G<W1R(")$:6X@)7,@<V5S<VEO;B!E<B!U9&SX8F5T+B!,;V<@=F5N
M;&EG<W0@:6YD(&EG96XN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z,S@*;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R(")$
M:6X@92UP;W-T+6%D<F5S<V4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C$U"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(D1I;B!&
M<F]M.B!A9')E<W-E.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-R!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,@IM<V=I9"`B66]U<B!)
M;F9O<FUA=&EO;B(*;7-G<W1R(")$:6YE(&EN9F]R;6%T:6]N97(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HY-SD@;&EB+TAO<F1E+T%U=&@N<&AP
M.CDW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D
M9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R
M("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U
M(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(D1I;B!);G1E<FYE="UA
M9')E<W-E(&5R('-K:69T970@<VED96X@8F5G>6YD96QS96X@868@9&EN("5S
M+7-E<W-I;VXN($9O<B!A="`B"B)B97-K>71T92!D:6X@<VEK:V5R:&5D(&)L
M:79E<B!D=2!N^&1T('1I;"!A="!L;V=G92!I;F0@:6=E;BXB"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.86UE
M(@IM<V=S='(@(D1I="!N879N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;F]A9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C
M:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I
M<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT
M<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0N(@IM<V=S='(@(B(*(D1I;B#F9W1N:6YG<RUB86-K96YD('5N
M9&5R<W3X='1E<B!I:VME('1I;&;X:F5L<V5N(&%F(&)R=6=E<F4N($AV:7,@
M9'4@(@HB^&YS:V5R(&%T(&)R=6=E($AO<F1E('1I;"!A="!A9&UI;FES=')E
M<F4@8G)U9V5R:V]N=&DL(&)L:79E<B!D=2!N^&1T('1I;"!A="`B"B)B<G5G
M92!E;B!A;F1E;B#F9W1N:6YG<RUB86-K96YD+B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT
M:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R
M<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O
M;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"B)$:6X@875T;W)I<V%T:6]N
M<RUB86-K96YD('5N9&5R<W3X='1E<B!I:VME(&]P;&ES=&YI;F=E;B!A9B!B
M<G5G97)E(&5L;&5R(&5R("(*(F1E;B!F=6YK=&EO;B!A9B!E;B!E;&QE<B!A
M;F1E;B!G<G5N9"!B;&5V970@<VSE970@9G)A+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.CDX,R!L:6(O2&]R9&4O075T:"YP:'`Z.3@S"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA
M=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S
M<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L
M;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB1&EN(&)R;W=S97(@<WEN97,@870@
M=N9R92!S:VEF=&5T('-I9&5N(&)E9WEN9&5L<V5N(&%F(&1I;B`E<RUS97-S
M:6]N+B!&;W(@(@HB870@8F5S:WET=&4@9&EN('-I:VME<FAE9"P@<VMA;"!D
M=2!L;V=G92!I;F0@:6=E;BXB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU
M-PIM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F
M96%T=7)E+B(*;7-G<W1R(")$:6X@8G)O=W-E<B!U;F1E<G-T^'1T97(@:6MK
M92!D96YN92!F=6YK=&EO;F%L:71E="XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@
M;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO
M0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*(D1I;B!B<F]W
M<V5R('5N9&5R<W3X='1E<B!I:VME(&1E;FYE('!R:6YT+6UU;&EG:&5D+B!4
M<GEK($-T<FPO0V]M;6%N9"`K(%`@(@HB9F]R(&%T('!R:6YT92XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8Q"FUS9VED(")9;W5R(&-U<G)E;G0@
M=&EM92!Z;VYE.B(*;7-G<W1R(")$:6X@86MT=65L;&4@=&ED<WIO;F4Z(@H*
M(SH@<V5R=FEC97,O<')E9G,N<&AP.C$Q-PIM<V=I9"`B66]U<B!D969A=6QT
M(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@(D1I;B!F;W)V
M86QG=&4@:61E;G1I=&5T(&5R(.9N9')E="XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,38Q"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM
M<V=S='(@(D1I;B!S=&%N9&%R9"UI9&5N=&ET970Z(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(P-`IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S
M='(@(D1I="!F=6QD92!N879N.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDY.2!L:6(O2&]R9&4O075T:"YP:'`Z.3DY"FUS9VED(")9;W5R(&QO
M9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")$:70@;&]G:6YD(&5R('5D;/AB
M970N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E
M<R(*;7-G<W1R(")$:70@;GEE(&MO9&5O<F0@9F]R("5S(&5R.B`E<R(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34T(&QI8B](;W)D92]0
M<F5F<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM
M<V=S='(@(D1I;F4@=&EL=F%L9R!E<B!B;&5V970@;W!D871E<F5T(&9O<B!V
M87)I9VAE9&5N(&%F(&1E;FYE('-E<W-I;VXN(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ-38@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ
M-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS
M9W-T<B`B1&EN92!T:6QV86QG(&5R(&]P9&%T97)E="XB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H
M87,@8F5E;B!R97-E="(*;7-G<W1R(")$:70@:V]D96]R9"!E<B!B;&5V970@
M;G5L<W1I;&QE="(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y
M"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C
M:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S
M=V]R9"XB"FUS9W-T<B`B(@HB1&ET(&MO9&5O<F0@97(@8FQE=F5T(&YU;'-T
M:6QL93L@:V]N=')O;&SI<B!D:6X@:6YD8F%K:V4@;V<@;&]G(&EN9"!M960@
M9&ET("(*(FYY92!K;V1E;W)D+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.C<S,R!L:6(O2&]R9&4O075T:"YP:'`Z-S,S"FUS9VED(")9;W5R('!A
M<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")$:70@:V]D96]R9"!E<B!U
M9&SX8F5T+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM
M<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B1&EN92!F:F5R
M;F4@<V5R=F5R93HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$X(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4T"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-30@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@(DIU9V]S;&%V:65N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q."!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(EIA[W)E(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-38@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T<B`B6F%M8FEA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3<@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W92(*;7-G<W1R(")::6UB86)W
M92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB
M"FUS9W-T<B`B6FEP<'DB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL
M=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,Z(&QI8B](;W)D92]497AT
M+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O
M=&5D(%1E>'1=(@IM<V=S='(@(EM3:VIU;"!C:71E<F5T('1E:W-T72(*"B,Z
M('-E<G9I8V5S+W!R;V)L96TN<&AP.C@Y"FUS9VED(");4')O8FQE;2!297!O
M<G1=(@IM<V=S='(@(EM0<F]B;&5M8F5S:W)I=F5L<V5=(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W
M(%%U;W1E9"!497AT("TB"FUS9W-T<B`B6U9I<R!C:71E<F5T('1E:W-T("TB
M"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U
M;W1E<RYP:'`Z,3<T"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H:6=H;&EG
M:'1Q=6]T97,N<&AP.C$W-`HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1
M=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");5FES(&-I=&5R970@
M=&5K<W0@+2`E<R!L:6YI97)=(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HR,#0@;&EB+TAO<F1E+G!H<#HR,#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(EML:6YI92`E<R!U9"!A9B`E
M<UTB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U-30@;&EB+TAO
M<F1E+G!H<#HQ-34T"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*
M;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A=&EO
M;B(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*;7-G<W1R(")#
M3$DB"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*;7-G
M<W1R(")$871A5')E92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS
M9W-T<B`B4VQE="!RYFMK92(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B
M7T=R;W5P<R(*;7-G<W1R(")'<G5P<&5R(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TUE;G4N<&AP.C$W-2!L:6(O2&]R9&4O365N=2YP:'`Z,3<U"FUS
M9VED(")?2&5L<"(*;7-G<W1R(")(:N9L<"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM
M86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B0FEL;&5D+65G96YS:V%B97(N
M+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT(&QI
M8B](;W)D92]-96YU+G!H<#HQ.30*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B
M3&]G(&EN9"(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ
M.3`@;&EB+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O=70B"FUS
M9W-T<B`B3&]G('5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB
M"FUS9W-T<B`BQFYD<FEN9R!H96YV:7-N:6YG+BXN(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-"!L:6(O2&]R9&4O365N=2YP:'`Z
M,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R("));F1S=&EL;&EN9V5R(@H*
M(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T
M<B`B5&EL;&%D96QS97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN:RXN
M+B(*;7-G<W1R(")3;&5T(&AE;G9I<VYI;F<N+BXB"@HC.B!L:6(O87!I+G!H
M<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R(")/<'/F=&YI;F<B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E1A8F5L
M+65G96YS:V%B97(N+BXB"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@(E]5
M<V5R<R(*;7-G<W1R(")"<G5G97)E(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,C4@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,C4*;7-G:60@(F%D
M9')E<W,@8F]O:R(*;7-G<W1R(")A9')E<W-E:V%R=&]T96LB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S-"!L:6(O2&]R9&4O34E-
M12]-97-S86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM
M<V=S='(@(F%D<F5S<V5N="!U:V5N9'0B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDQ-R!L:6(O2&]R9&4O2V]L86(N<&AP.CDQ-PIM<V=I9"`B
M8V%L96YD87(B"FUS9W-T<B`B:V%L96YD97(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$W.2!L:6(O0FQO8VLO;65T87(N<&AP.C,V-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")C86QM(@IM<V=S='(@(G9I;F1S=&EL;&4B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U."!L:6(O2&]R9&4O34E-
M12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T
M(&9I;&4B"FUS9W-T<B`B:V%N(&EK:V4@9&%N;F4@=61D871A+69I;"(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,P(&QI8B](;W)D
M92]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP
M=70B"FUS9W-T<B`B:V%N(&EK:V4@Y6)N92!I;F1D871A(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-C`P(&QI8B](;W)D92]-24U%
M+T-O;G1E;G1S+G!H<#HV,#`*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B
M:VQI:R!H97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$R,B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O
M;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R(")F96IL('9E9"!A;G9E
M;F1E;'-E(&%F(&MO;6UA;F1O+6QI;FEE(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-S@@;&EB+TAO<F1E+TU)344O365S<V%G92YP
M:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(FMO
M;F9I9W5R871I;VYS9F5J;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,34T(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$U-`IM
M<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R(")M
M86YG;&5R(&MR:71I<VL@<WES=&5M9FEL(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ,C8@;&EB+TAO<F1E+TU)344O365S<V%G92YP
M:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R(")F96IL
M(&D@9&%T869O<FUA="(*"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z
M,S`*;7-G:60@(F5D:70B"FUS9W-T<B`B<F5D:6=E<B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,3@R(&QI8B](;W)D92]-24U%+TUE
M<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@
M(FEN9&=A;F<@:6MK92!F=6YD970B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HW,PIM<V=I9"`B9F%L;&EN9R(*;7-G<W1R(")F
M86QD96YD92(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y
M."!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.#DX"FUS9VED(")F:6QE(@IM<V=S
M='(@(F9I;"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@Q(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S8W(&QI8B]";&]C:R]M971A<BYP:'`Z,SDS"B,L('!H
M<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS
M9W-T<B`B9G)A("5S("@E<RD@;65D("5S("5S(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S.0IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R(")S
M=&]R;69U;&0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C4P"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-3`*;7-G:60@(F@Z(@IM<V=S='(@(F@Z(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.0HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4Y"FUS9VED(")H:"(*;7-G<W1R(")H
M:"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,X(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE
M('5N:VYO=VXB"FUS9W-T<B`B=6ME;F1T(&UA<VMI;FYA=FXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-2!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E
M(@IM<V=S='(@(OAJ96)L:6MK96QI9W0B"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE
M(@IM<V=S='(@(FEN9&QE:G)E="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,38R(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$V
M,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(FEN9&1A=&$O
M=61D871A+69E:FPB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$T-B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@
M(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(FEN=&5R;B!S;V9T
M=V%R92UF96IL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C
M:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R(")L:6YI97)=(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP
M.C4S"B,Z(&QI8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H
M<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M
M86MI;F<@25-/+B(*;7-G<W1R(")M:VES;V9S(&9E:FQK;V1E("5D('5N9&5R
M(&1A;FYE;'-E(&%F($E33RXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S<P"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HS-S`*;7-G:60@(FUM(@IM<V=S='(@(FUM(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR.#4@;&EB+TAO<F1E+U!R969S
M+U5)+G!H<#HR.#4*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W
M,"!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C0Q"FUS9VED(")N86UE
M(@IM<V=S='(@(FYA=FXB"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(T
M(&QI8B](;W)D92]24$,N<&AP.C$R-`IM<V=I9"`B;F]T(&EM<&QE;65N=&5D
M(@IM<V=S='(@(FEK:V4@:6UP;&5M96YT97)E="(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,3(R,"!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C$R,C`*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T
M<B`B96YD;G4@:6MK92!I;7!L96UE;G1E<F5T(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,#D@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,#D*;7-G
M:60@(FYO=&5P860B"FUS9W-T<B`B;F]T97-B;&]K(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B
M<&5R8V5N="(*;7-G<W1R(")P<F]C96YT(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-S0@;&EB+TAO<F1E+TU)344O365S<V%G92YP
M:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R(")T:6QL
M861E;'-E(&[F9W1E="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R(")P
M<FEK:V5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-S`@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R96UO
M=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B9F5J;"!I('!R;W1O:V]L
M(&9R82!F:F5R;B!S:61E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-S4*;7-G:60@(G)I<VEN9R(*;7-G<W1R(")S=&EG96YD
M92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30R(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC92!U
M;F%V86EL86)L92(*;7-G<W1R(")T:F5N97-T92!U=&EL9^9N9V5L:6<B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C$P,0IM<V=I9"`B<VAO=R!D:69F
M97)E;F-E<R(*;7-G<W1R(")V:7,@9F]R<VME;&QE(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL
M('9I82!(5%10(@IM<V=S='(@(G-M<S)E;6%I;"!V:6$@2%144"(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.#<*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-PIM<V=I9"`B<W,B
M"FUS9W-T<B`B<W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HW-`IM<V=I9"`B<W1E861Y(@IM<V=S='(@(G-T86)I;'0B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U,"!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*
M;7-G<W1R(")S>7-T96UF96IL(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,S,@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,S,*;7-G:60@(G1A<VL@
M;&ES="(*;7-G<W1R(")O<&=A=F5L:7-T92(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,38V(&QI8B](;W)D92]-24U%+TUE<W-A9V4N
M<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B;6ED
M;&5R=&ED:6<@9F5J;'1I;'-T86YD(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,`HC.B!L:6(O2&]R
M9&4O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B='EP92!T:&4@<&%S<W=O
M<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R(")I;F1T87-T(&MO9&5O<F1E
M="!T;R!G86YG92!F;W(@870@8F5K<N9F=&4B"@HC.B!A9&UI;B]S971U<"]D
M:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B=6YI
M9FEE9"(*;7-G<W1R(")S86UM96YS;65L=&5T(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]087)T+G!H<#HR-R!L:6(O2&]R9&4O34E-12]087)T+G!H<#HR
M-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R(")U;F%V;F=I=F5N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L
M96-T(@IM<V=S='(@(F)R=6=E<G9A;&<B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0R"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-#(*;7-G:60@
M(G<Z(@IM<V=S='(@(G<Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M
M(@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!O+V1E7T1%+G!O````````````````````
M````````````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`W-3`P-#``,3`U,34T
M,S,W-30`,#$W-C`S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````",@1V5R;6%N('1R86YS;&%T:6]N<R!F;W(@2&]R9&4@<&%C
M:V%G90HC($=E<FUA;B!M97-S86=E<R!F;W(@2&]R9&4N"B,@0V]P>7)I9VAT
M("A#*2`R,#`Q+3(P,#8@2&]R9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D
M:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!(;W)D
M92!P86-K86=E+@HC($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^+"`R
M,#`Q+3(P,#8N"B,*(R!M87)G:6XZ($%UWV5N86)S=&%N9`HC('!A9&1I;F<Z
M($EN;F5N86)S=&%N9`HC($AI<W1O<GDZ($-H<F]N:6L*;7-G:60@(B(*;7-G
M<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,2UC=G-<;B(*
M(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB
M"B)03U0M0W)E871I;VXM1&%T93H@,C`P-BTP-RTS,2`Q.#HQ,BLP,C`P7&XB
M"B)03RU2979I<VEO;BU$871E.B`R,#`V+3`X+3`Y(#$V.C0U*S`R,#!<;B(*
M(DQA<W0M5')A;G-L871O<CH@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R
M9SY<;B(*(DQA;F=U86=E+51E86TZ($=E<FUA;B`\9&5V0&QI<W1S+FAO<F1E
M+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z
M('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,5QN(@HB0V]N=&5N="U4
M<F%N<V9E<BU%;F-O9&EN9SH@."UB:71<;B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES
M(&%G;RDB"FUS9W-T<B`B("AV;W(@)7,@5&%G96XI(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ,S<T"B,L('!H<"UF;W)M870*;7-G:60@(B`H
M06-C97-S:V5Y("5S*2(*;7-G<W1R("(@*%IU9W)I9F9S=&%S=&4@)7,I(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B`H:6X@)7,@5&%G96XI
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y,0IM<V=I9"`B("AT
M;V1A>2DB"FUS9W-T<B`B("AH975T92DB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,SDS"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@*&UO
M<F=E;BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S@Y"FUS9VED
M("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B("AG97-T97)N*2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#4@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,U,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,SDV"FUS9VED("(@870@(@IM<V=S='(@(B!M:70@(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HR,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B7"(E<UPB(&ES="!K
M96EN(%9E<GIE:6-H;FES+B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR
M.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED
M(&-H;VEC92XB"FUS9W-T<B`B7"(E<UPB(&ES="!K96EN92!G_&QT:6=E($%U
M<W=A:&PN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H
M<#HW,#<*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ
M,#DU"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG
M=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(EPB)7-<(B!I
M<W0@:6X@9&5R($AO<F1E(%)E9VES=')Y(&YI8VAT(&MO;F9I9W5R:65R="XB
M"@HC.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G
M<W1R(")$97(@0F%U;2U296YD97)E<B!F_'(@7"(E<UPB('=U<F1E(&YI8VAT
M(&=E9G5N9&5N+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y
M<W1E;2XB"FUS9W-T<B`B7"(E<UPB('=U<F1E('IU;2!'<G5P<&5N<WES=&5M
M(&AI;GIU9V5F_&=T+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H
M92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!W=7)D92!Z
M=6T@4F5C:'1E<WES=&5M(&AI;GIU9V5F_&=T+B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G
M<W1R(")<(B5S7"(@=W5R9&4@;FEC:'0@97)S=&5L;'0Z("5S+B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R
M("(E+C)F34(@*"4S)"XR9B4E*2!V;VX@)3(D+C)F34(@97)L875B=&5N('9E
M<F)R875C:'0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(V
M"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(E
M9"`E<R!U;F0@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3DT"B,L('!H<"UF;W)M870*
M;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*
M;7-G<W1R("));B`E9"!486=E;B!W:7)D($EH<B!087-S=V]R="!U;F?\;'1I
M9RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<T"B,L('!H
M<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R("(E9"U4
M86=E+59O<FAE<G-A9V4B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B
M)7,@+2!(:6YW96ES(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HW,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B
M"FUS9W-T<B`B)7,@1FEN9V5R86)D<G5C:R(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C@T,B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS
M9W-T<B`B)7,@2T(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R!787)T=6YG<V%R8F5I=&5N
M("T@0F5S=.1T:6=U;F<B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@4V5T=7`B"FUS9W-T<B`B)7,M2V]N9FEG=7)A=&EO;B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(E<R!296=I<W1R:65R=6YG
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(E<R!.
M=71Z=6YG<V)E9&EN9W5N9V5N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HT-3`@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU,38*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.#D@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HW-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E
M>&ES=',N(@IM<V=S='(@(B5S(&5X:7-T:65R="!B97)E:71S+B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,38Q(&QI8B]";&]C:R]M971A<BYP:'`Z,38W
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Q"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S0W(&QI8B]";&]C:R]M971A<BYP:'`Z,S4S"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S(&UI="`E<R`E<R(*"B,Z
M('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC
M92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B;W@@
M9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T
M:&ES('1I;64N(@IM<V=S='(@(B(*(B5S('=I<F0@9&EE(%=A<G1U;F=S87)B
M96ET96X@9'5R8VAF_&AR96XL(&1I92!U;G1E;B!M87)K:65R="!S:6YD+B!-
M87)K:65R96X@(@HB4VEE(&%L;&4@075F9V%B96XL(&1I92!J971Z="!D=7)C
M:&=E9OQH<G0@=V5R9&5N('-O;&QE;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S4X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I
M<F5D(@IM<V=S='(@(B5S(&ES="!N;W1W96YD:6<B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(X.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S
M(@IM<V=S='(@(B5S($UI;G5T96XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO0V]L;&5C=&EO;BYP:'`Z,3,R"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@;FEC:'0@9V5F=6YD96XN(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(E<R!B:7,@)7,@=F]N
M("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY-3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B)7-S
M($%D<F5S<V)U8V@B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDT
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@
M(B5S<R!+86QE;F1E<B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3,V"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R
M("(E<W,@3F]T:7IB;&]C:R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.38P"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS
M9W-T<B`B)7-S($%U9F=A8F5N;&ES=&4B"@HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(E<SH@)7,B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T
M(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL
M;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@
M<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R
M("(B"B(E<SH@1&EE<V4@3F%C:')I8VAT('-T86UM="!U;G1E<B!5;7-TY&YD
M96X@;FEC:'0@=F]N(&1E;2!A;F=E9V5B96YE;B`B"B)!8G-E;F1E<BX@1F]L
M9V5N(%-I92!K96EN96X@3&EN:W,@:6X@9&EE<V5R($YA8VAR:6-H="!U;F0@
M:/QT96X@4VEE('-I8V@@(@HB9&%V;W(L(&1E;2!!8G-E;F1E<B!P97)S]FYL
M:6-H92!$871E;B!P<F5I<WIU9V5B96XN(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,U-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,SDY"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@8O9I9R`B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$Y,"!L:6(O0FQO8VLO;65T87(N<&AP.C$Y
M-0HC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T
M<B`B+"!B:6<@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B
M"FUS9W-T<B`B+"!S8VAW86YK96YD('9O;B`E<R!B:7,@)7,B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y-"!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C,T.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,#@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-#8*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T.`IM<V=I9"`B+2T@<V5L
M96-T("TM(@IM<V=S='(@(BTM($%U<W?D:&QE;B`M+2(*"B,Z(&QI8B]";&]C
M:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`B
M,3(M4W1U;F1E;BU&;W)M870B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*
M;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(C(T+5-T=6YD96XM1F]R
M;6%T(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T
M(&AO=7)S(@IM<V=S='(@(C(T(%-T=6YD96XB"@HC.B!F<F%M97=O<FLO54DO
M54DO4&%G97(N<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`B/%IU
M<OQC:R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(V"FUS9VED(")!(&1A
M=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM
M<V=S='(@(D9R(&1I97-E;B!";&]C:R!W:7)D(&5I;F4@1&%T96YB86YK(&)E
M;G1I9W0N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S$*;7-G
M:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(D5I;B!S
M8VAW97)E<B!&96AL97(@:7-T(&%U9F=E=')E=&5N.B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.CDT-`IM<V=I9"`B02!P=6)L:6,@4$=0
M(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T
M<B`B(@HB16EN(/9F9F5N=&QI8VAE<B!01U`M4V-H;/QS<V5L('=I<F0@9OQR
M(&1I92!697)S8VAL_'-S96QU;F<@96EN97(@3F%C:')I8VAT("(*(F)E;O9T
M:6=T+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-S<*
M;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y
M(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*(D5I;B#V9F9E;G1L:6-H
M97(@4$=0+5-C:&S\<W-E;"!W:7)D(&;\<B!D:64@W&)E<G!R_&9U;F<@96EN
M97(@(@HB=6YT97)Z96EC:&YE=&5N($YA8VAR:6-H="!B96[V=&EG="XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3`X"FUS9VED("(B
M"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB
M"FUS9W-T<B`B(@HB16EN(/9F9F5N=&QI8VAE<B!U;F0@96EN('!R:79A=&5R
M(%!'4"U38VAL_'-S96P@<V]W:64@96EN(%!A<W-W;W)T('=I<F0@9OQR("(*
M(F1I92!%;G1S8VAL_'-S96QU;F<@96EN97(@3F%C:')I8VAT(&)E;O9T:6=T
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,C4*;7-G
M:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E
M+B(*;7-G<W1R("(B"B)%:6X@]F9F96YT;&EC:&5R('5N9"!E:6X@<')I=F%T
M97(@4$=0+5-C:&S\<W-E;"!S;W=I92!E:6X@4&%S<W=O<G0@=VER9"!F_'(@
M(@HB9&EE(%5N=&5R>F5I8VAN=6YG(&5I;F5R($YA8VAR:6-H="!B96[V=&EG
M="XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4P-@IM
M<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP
M="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*(D5I;B#V9F9E;G1L:6-H97(@=6YD
M(&5I;B!P<FEV871E<B!3+TU)344M4V-H;/QS<V5L('-O=VEE(&5I;B!087-S
M=V]R="!W:7)D("(*(F;\<B!D:64@16YT<V-H;/QS<V5L=6YG(&5I;F5R($YA
M8VAR:6-H="!B96[V=&EG="XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@
M<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*(D5I;B#V9F9E
M;G1L:6-H97(@=6YD(&5I;B!P<FEV871E<B!3+TU)344M4V-H;/QS<V5L('-O
M=VEE(&5I;B!087-S=V]R="!W:7)D("(*(F;\<B!D:64@56YT97)Z96EC:&YU
M;F<@96EN97(@3F%C:')I8VAT(&)E;O9T:6=T+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-
M12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S
M='(@(B(*(D5I;B#V9F9E;G1L:6-H97(@4R]-24U%+5-C:&S\<W-E;"!W:7)D
M(&;\<B!D:64@5F5R<V-H;/QS<V5L=6YG(&5I;F5R("(*(DYA8VAR:6-H="!B
M96[V=&EG="XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B5F]R;6ET=&%G<R!7
M;VQK96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R(")6;W)M:71T86=S
M(&QE:6-H=&5R(%)E9V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-($QI9VAT(%-N;W<B"FUS9W-T<B`B
M5F]R;6ET=&%G<R!L96EC:'1E<B!38VAN965F86QL(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%)A:6XB
M"FUS9W-T<B`B5F]R;6ET=&%G<R!296=E;B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3:&]W97)S(@IM
M<V=S='(@(E9O<FUI='1A9W,@4V-H875E<B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")!32!3;F]W(%-H;W=E
M<G,B"FUS9W-T<B`B5F]R;6ET=&%G<R!38VAN965S8VAA=65R(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@
M(D%-+U!-(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B05!)($E$(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM
M<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`BW&)E<B!D:65S96X@
M161I=&]R(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-30*;7-G:60@
M(D%B;W5T+BXN(@IM<V=S='(@(DEN9F\N+BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB
M"FUS9W-T<B`B06)S;VQU="!5;G1E;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G
M<W1R(")!8G-O;'5T($UI='1E(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C(X,0IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R("):=6=R:69F('9E<G=E:6=E<G0@8F5I;2!!
M;FQE9V5N(&1E<R!61E,M5F5R>F5I8VAN:7-S97,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$S-0IM<V=I9"`B06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B6G5G<FEF9B!V97)W96EG97)T
M(&)E:6T@06YL96=E;B!D97(@5D93+41A=&5I+B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HS"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S
M='(@(DMO;G1O:6YF;W)M871I;VYE;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW.`IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R(")+;VYT
M;W!A<W-W;W)T(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T
M<B`B2V]N=&\@96EN9V5F<F]R96XN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,S-0IM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R(")"=6-H:&%L
M='5N9R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X('1E
M;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B061D(@IM<V=S='(@(DAI
M;GIU9OQG96XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(S,2!A9&UI;B]G<F]U
M<',N<&AP.C(S,@IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(DYE
M=64@56YT97)G<G5P<&4@:&EN>G5F_&=E;B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B3F5U
M92!5;G1E<G)E8VAT92!H:6YZ=6;\9V5N(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R(")(:65R(&AI
M;GIU9OQG96XZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHT-@IM<V=I9"`B061D($UE;6)E<G,B"FUS9W-T<B`B36ET9VQI961E<B!H
M:6YZ=6;\9V5N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O
M=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B3F5U
M92!'<G5P<&4@:&EN>G5F_&=E;B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`IM
M<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(DYE=64@4F5C:'1E
M(&AI;GIU9OQG96XB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H
M:6QD+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R
M;W5P('1O(%PB)7-<(B(*;7-G<W1R(")5;G1E<F=R=7!P92!Z=2!<(B5S7"(@
M:&EN>G5F_&=E;B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,30W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I
M;VX@=&\@7"(E<UPB(@IM<V=S='(@(E5N=&5R<F5C:'1E('IU(%PB)7-<(B!H
M:6YZ=6;\9V5N(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A
M(&YE=R!U<V5R.B(*;7-G<W1R(")&_&=E;B!3:64@96EN96X@;F5U96X@0F5N
M=71Z97(@:&EN>G4Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4U-@IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R(")3<&%L
M=&4@:&EN>G5F_&=E;B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(E!A87(@:&EN>G5F_&=E;B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM
M<V=S='(@(D1A<R`E<RU-96[\('IU<B!-;WII;&QA(%-I9&5B87(@:&EN>G5F
M_&=E;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HW,0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B6G5M
M($%D<F5S<V)U8V@@:&EN>G5F_&=E;CHB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R
M97-S(&)O;VLB"FUS9W-T<B`B6G4@;65I;F5M($%D<F5S<V)U8V@@:&EN>G5F
M_&=E;B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*
M;7-G<W1R(")"96YU='IE<B!H:6YZ=6;\9V5N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O
M('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG
M;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B(@HB7"(E<UPB('=U
M<F1E('IU;2!3>7-T96T@:&EN>G5G96;\9W0L(&%B97(@9&EE('IU<^1T>FQI
M8VAE;B`B"B)296=I<W1R:65R=6YG<VEN9F]R;6%T:6]N96X@:V]N;G1E;B!N
M:6-H="!G97-P96EC:&5R="!W97)D96XZ("5S+B(*"B,Z('-I9VYU<"YP:'`Z
M-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H92!S
M>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B7"(E<UPB('=U
M<F1E('IU;2!3>7-T96T@:&EN>G5G96;\9W0N(%-I92!K]FYN96X@<VEC:"!J
M971Z="!A;FUE;&1E;BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D
M9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G
M<W1R(")$87,@2&EN>G5F_&=E;B!V;VX@0F5N=71Z97)N(&ES="!N:6-H="!M
M]F=L:6-H+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q"FUS9VED(")!
M9&1R97-S(@IM<V=S='(@(D%D<F5S<V4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,30Q"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B061R
M97-S8G5C:"(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N
M<&AP.C4V"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O
M=&AE<B!U<V5R<R(*;7-G<W1R(")697)W86QT96X@+2!296-H=&4@9OQR(&%N
M9&5R92!"96YU='IE<B!F97-T;&5G96XB"@HC.B!A9&UI;B]I;F1E>"YP:'`Z
M,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q-PIM<V=I9"`B061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R871I;VXB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0S"FUS9VED(")!9',B"FUS9W-T<B`B
M5V5R8G5N9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S
M='(@(D%F9VAA;FES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB86YI82(*
M;7-G<W1R(")!;&)A;FEE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B
M"FUS9W-T<B`B06QG97)I96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R(")3<&ET
M>FYA;64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R(")!=7-R:6-H='5N
M9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`B075S<FEC:'1U;F<Z(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T
M<B`B06QL92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C`W
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C8*;7-G:60@(D%L;"!!=71H
M96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(D%N9V5M96QD971E($)E;G5T>F5R
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R
M.`IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R(")!;&QE($=R=7!P96XB"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDQ(&9R86UE=V]R:R]0
M97)M<R]097)M<R]D871A=')E92YP:'`Z-S4*;7-G:60@(D%L;"!097)M:7-S
M:6]N<R(*;7-G<W1R(")!;&QE(%)E8VAT92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F
M;W5R('-I9&5S(@IM<V=S='(@(D%L;&4@=FEE<B!396ET96XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#@Y"FUS9VED(")!;&QO=R!M=6QT:7!L
M92!A9&1R97-S97,B"FUS9W-T<B`B365H<F5R92!!9')E<W-E;B!E<FQA=6)E
M;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S$*;7-G:60@(D%L;&]W
M('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(D9O<FUA
M="!V;VX@;G5M;65R:65R=&5N($QI<W1E;B#D;F1E<FX_(@H*(SH@9G)A;65W
M;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`W"FUS9VED(")!;')E
M861Y(&5X:7-T<R(*;7-G<W1R(")%>&ES=&EE<G0@8F5R96ET<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8*;7-G:60@(D%L=&5R;F%T92!)35-0
M($QO9VEN(@IM<V=S='(@(D%L=&5R;F%T:79E($E-4U`M06YM96QD=6YG(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-`IM<V=I9"`B06QT97)N871E
M($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B06QT97)N871I=F5S($E-4U`M4&%S
M<W=O<G0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DV"FUS9VED(")!
M;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R(")!;'1E<FYA=&EV97(@
M24U34"U"96YU='IE<FYA;64B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HS-@IM<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T
M<B`B06QT97)N871I=F4@12U-86EL+4%D<F5S<V4B"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G
M<W1R(")!;'1E<FYA=&EV92!6;W)L86=E;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B
M06QT97)N871E('1E>'0Z(@IM<V=S='(@(D%L=&5R;F%T:79E<B!497AT.B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(D%M
M97)I:V%N:7-C:"U386UO82(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,34*;7-G
M:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B
M17,@=W5R9&4@96EN('5N9_QL=&EG97(@5V5R="!A;F=E9V5B96XN(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-0IM<V=I9"`B06X@=6YK
M;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B16EN('5N8F5K86YN
M=&5R($9E:&QE<B!I<W0@875F9V5T<F5T96XN(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I
M9"`B06YD;W)R82(*;7-G<W1R(")!;F1O<G)A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I
M9"`B06YG;VQA(@IM<V=S='(@(D%N9V]L82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@
M(D%N9W5I;&QA(@IM<V=S='(@(D%N9W5I;&QA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM
M<V=S='(@(D%N;VYY;65R(%!R;WAY(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-3$*;7-G:60@(D%N<W=E<B(*;7-G<W1R(")!;G1W;W)T(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R(")!;G1A<FMT
M:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM
M<V=S='(@(D%N=&EG=6$@=6YD($)A<F)U9&$B"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO54DN<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I
M;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(D%N=V5N
M9'5N9R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P
M;&EC871I;VX@3&ES="(*;7-G<W1R(")!;G=E;F1U;F=S;&ES=&4B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,Y"FUS9VED(")!<'!L:6-A=&EO;B!I
M<R!R96%D>2XB"FUS9W-T<B`B06YW96YD=6YG(&ES="!B97)E:70N(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3D*;7-G:60@(D%P<&QY('1O
M($-H:6QD(%-H87)E<R(*;7-G<W1R(")!=68@56YT97)R96-H=&4@86YW96YD
M96XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM
M<V=I9"`B07!P<F]V92(*;7-G<W1R(")"97-TY'1I9V5N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0R"FUS9VED(")!<'!R;WAI
M;6%T92!3:7IE(@IM<V=S='(@(E5N9V5FY&AR92!'<O;?92(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I
M;"(*;7-G<W1R(")!<')I;"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X
M"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B07)A8FES
M8V@@*%=I;F1O=W,M,3(U-BDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HW.`IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B07)C:&EV
M9W+VWV4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW-PIM<V=I9"`B
M07)C:&EV92!.86UE(@IM<V=S='(@(D%R8VAI=FYA;64B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L('!H<"UF;W)M
M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE
M('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(B(*(E-I;F0@4VEE
M('-I8VAE<BP@9&%S<R!3:64@9&EE(%)E9VES=')I97)U;F=S86YF<F%G92!V
M;VX@)7,@;/9S8VAE;B!M]F-H=&5N/R(*"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O9&5L971E+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y
M;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B
M+6=R;W5P<S\B"FUS9W-T<B`B(@HB4VEN9"!3:64@<VEC:&5R+"!D87-S(%-I
M92!<(B5S7"(@=6YD(&%L;&4@56YT97)G<G5P<&5N(&SV<V-H96X@;?9C:'1E
M;C\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B07)G
M96YT:6YI96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S='(@
M(D%R;65N:65N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@
M(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(D%R;65N:7-C:"`H05)-
M4T-)22TX*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B
M07)T(@IM<V=S='(@(DMU;G-T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B
M"FUS9W-T<B`B07)U8F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(D%S8V5N<VEO
M;BU);G-E;&XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@
M(D%S8VEI($%R="(*;7-G<W1R(")!4T-)22U+=6YS="(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E
M9VEO;B(*;7-G<W1R(")!<VEE;B]087II9FES8VAE(%)E9VEO;B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT,C(*;7-G:60@(D%S:R!F;W(@8V]N9FER
M;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*
M;7-G<W1R(")!;G-T96AE;F1E(%=A<G1U;F=S87)B96ET96X@8F5S=.1T:6=E
M;B!L87-S96X_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q,PIM
M<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(EIU;W)D;G5N9W-F
M96QD97(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T
M('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B17,@
M=W5R9&4@=F5R<W5C:'0L(&5I;F4@;FEC:'0@97AI<W1I97)E;F1E($=R=7!P
M92!Z=2!L]G-C:&5N+B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*
M;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI
M<W-I;VXN(@IM<V=S='(@(D5S('=U<F1E('9E<G-U8VAT+"!E:6X@;FEC:'0@
M97AI<W1I97)E;F1E<R!296-H="!Z=2!L]G-C:&5N+B(*"B,Z(&%D;6EN+W!E
M<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM
M97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B17,@=W5R9&4@=F5R<W5C
M:'0L(&5I;B!N:6-H="!E>&ES=&EE<F5N9&5S(%)E8VAT('IU(&)E87)B96ET
M96XN(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@
M(D5S('=U<F1E('9E<G-U8VAT+"!E:6X@;FEC:'0@97AI<W1I97)E;F1E<R!2
M96-H="!Z=2!B96%R8F5I=&5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HW,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@S"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(D%T=')I8G5T92(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS
M9VED(")!=6=U<W0B"FUS9W-T<B`B075G=7-T(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I
M9"`B075S=')A;&EA(@IM<V=S='(@(D%U<W1R86QI96XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y
M"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(M9S=&5R<F5I8V@B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y
M<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R(")!=71H7V-Y<G-Q;#H@1&EE(&)E;O9T:6=T92!)34%0+45R=V5I=&5R
M=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N
M9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R
M(")!=71H7V-Y<G5S.B!$87,@0F%C:V5N9"!H870@;FEC:'0@9&EE(&)E;O9T
M:6=T96X@1N1H:6=K96ET96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER=7,Z($1I
M92!B96[V=&EG=&4@24U!4"U%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G969U
M;F1E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z,S8*;7-G
M:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F
M;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W
M:71C:"XB"FUS9W-T<B`B(@HB075T:%]F='`Z($1I92!B96[V=&EG=&4@1E10
M+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+B!+;VUP:6QI97)E
M;B`B"B)3:64@4$A0(&UI="!D96T@+2UE;F%B;&4M9G1P(%!A<F%M971E<BXB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C8P"FUS9VED(")!
M=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B075T:%]I;6%P.B!$:64@8F5N]G1I9W1E($E-05`M17)W96ET
M97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E
M9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:W)B
M-3H@1&EE(&)E;O9T:6=T92!+97)B97)O<RU%<G=E:71E<G5N9R!W=7)D92!N
M:6-H="!G969U;F1E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T
M('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"B)!
M=71H7VQD87`Z($1A<R!(:6YZ=6;\9V5N('9O;B!"96YU='IE<FX@=VER9"!F
M_'(@06-T:79E($1I<F5C=&]R>2!N:6-H="`B"B)U;G1E<G-T_'1Z="(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H
M7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C
M=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@HB075T:%]L9&%P.B!$87,@3/9S
M8VAE;B!V;VX@0F5N=71Z97)N('=I<F0@9OQR($%C=&EV92!$:7)E8W1O<GD@
M;FEC:'0@(@HB=6YT97)S=/QT>G0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P.B!$:64@
M8F5N]G1I9W1E($Q$05`M17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD
M96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S
M97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R
M("(B"B)!=71H7VQD87`Z($1E<B!"96YU='IE<B`E<R!K;VYN=&4@;FEC:'0@
M:&EN>G5G96;\9W0@=V5R9&5N+B!-96QD=6YG(&1E<R`B"B)397)V97)S.B`B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E
M<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z($)E;G5T>F5R("5S(&MO;FYT92!N
M:6-H="!G96SV<V-H="!W97)D96XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z
M(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z
M($)E;G5T>F5R("5S(&MO;FYT92!N:6-H="!A:W1U86QI<VEE<G0@=V5R9&5N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,#4*;7-G:60@
M(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F
M;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB075T:%]L9&%P.B!$
M87,@06MT=6%L:7-I97)E;B!V;VX@0F5N=71Z97)N('=I<F0@9OQR($%C=&EV
M92!$:7)E8W1O<GD@;FEC:'0@(@HB=6YT97)S=/QT>G0N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!2
M97%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?;6-A;#H@1&EE(&)E;O9T:6=T92!-0T%,+45R=V5I=&5R=6YG('=U<F1E
M(&YI8VAT(&=E9G5N9&5N+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB
M+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?<VUB875T:#H@
M1&EE(&)E;O9T:6=T92!386UB82U%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G
M969U;F1E;BXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%D;6EN+G!H<#HQ
M,#,*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE
M9"XB"FUS9W-T<B`B06YM96QD=6YG(&)E:6T@24U!4"U397)V97(@9F5H;&=E
M<V-H;&%G96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B
M"FUS9W-T<B`B075T:&5N=&EF:7II97)U;F<@9F5H;&=E<V-H;&%G96XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL
M960N("5S(@IM<V=S='(@(D%N;65L9'5N9R!F96AL9V5S8VAL86=E;BX@)7,B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED
M(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*
M;7-G<W1R(")$:64@075T:&5N=&EF:7II97)U;F<@=W5R9&4@=F]M(%)!1$E5
M4RU397)V97(@>G5R_&-K9V5W:65S96XN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HX.30*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S
M97)V97(@9F%I;&5D+B(*;7-G<W1R(")!;FUE;&1U;F<@8F5I;2!&5%`M4V5R
M=F5R(&9E:&QG97-C:&QA9V5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R
M=F5R(&9A:6QE9"XB"FUS9W-T<B`B06YM96QD=6YG(&)E:6T@4TU"+5-E<G9E
M<B!F96AL9V5S8VAL86=E;BXB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R(")697)F
M_&=B87)E($9E;&1E<CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N
M(@IM<V=S='(@(D%S97)B86ED<V-H86XB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R(")"3T9(+4%U
M<W)E9&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R(")(:6YT
M97)G<G5N9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B2&EN
M=&5R9W)U;F1F87)B92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP
M:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B
M1F%L<V-H97,@2V5R8F5R;W,M4&%S<W=O<G0N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N
M86UE+B(*;7-G<W1R(")&86QS8VAE<B!+97)B97)O<RU"96YU='IE<FYA;64N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R(")"86AA;6%S
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R(")"86AR96EN
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D)A;'1I8R`H
M25-/+3@X-3DM,3,I(@IM<V=S='(@(D)A;'1I<V-H("A)4T\M.#@U.2TQ,RDB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(D)A;F=L
M861E<V-H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B
M0F%R8F%D;W,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB
M(&YO="!F;W5N9"XB"FUS9W-T<B`B0F%S:7,M0FEL9&5R+59E<GIE:6-H;FES
M(%PB)7-<(B!N:6-H="!G969U;F1E;BXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A<V5L:6YE
M(@IM<V=S='(@(D=R=6YD;&EN:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA
M<G5S(@IM<V=S='(@(E=E:=]R=6QA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"
M96QG:75M(@IM<V=S='(@(D)E;&=I96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"
M96QI>F4B"FUS9W-T<B`B0F5L:7IE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N
M:6XB"FUS9W-T<B`B0F5N:6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A
M(@IM<V=S='(@(D)E<FUU9&%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HT-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N
M(@IM<V=S='(@(D)H=71A;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(D=E
M8G5R='-T86<B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO
M;BYP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O
M9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")";&]C
M:R!<(B5S7"(@9&5R($%N=V5N9'5N9R!<(B5S7"(@;FEC:'0@9V5F=6YD96XN
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDP"FUS9VED(")"
M;&]C:R!3971T:6YG<R(*;7-G<W1R(")";&]C:V5I;G-T96QL=6YG96XB"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K
M(%1Y<&4B"FUS9W-T<B`B0FQO8VMT>7`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B
M1F5T="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B0F]L
M:79I96XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`W"FUS9VED
M(")";V]K;6%R:W,B"FUS9W-T<B`B3&5S97IE:6-H96XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED
M(")";W)D97(B"FUS9W-T<B`B4F%N9"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE
M<W,Z(@IM<V=S='(@(E)A:&UE;F1I8VME.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E
M<G,B"FUS9W-T<B`B4N1N9&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA
M(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R(")";W-N:65N+4AE<GIE9V]W:6YA
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")";W1H(@IM
M<V=S='(@(D)E:61E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM
M<V=S='(@(D)O='-W86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T;VTB"FUS9W-T<B`B
M56YT96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@27-L86YD(@IM<V=S
M='(@(D)O=79E=&EN<V5L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)A>FEL(@IM
M<V=S='(@(D)R87-I;&EE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H
M($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B0G)I=&ES8VAE<R!4
M97)R:71O<FEU;2!I;2!);F1I<V-H96X@3WIE86XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS
M9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R(")"<G5N96D@1&%R=7-S
M86QA;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(D)U
M;&=A<FEE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`B56YN=6UM
M97)I97)T92!,:7-T92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S
M;R(*;7-G<W1R(")"=7)K:6YA($9A<V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"
M=7)U;F1I(@IM<V=S='(@(D)U<G5N9&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#0V"FUS9VED(")#35,B"FUS9W-T<B`B0TU3(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#
M(@IM<V=S='(@(D-20R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3DX"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G
M<W1R(")#4DP@1&ES=')I8G5T:6]N<W-T96QL92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B
M0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")?6F5L;&5N96EG96YS8VAA
M9G1E;BXN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3$*
M;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@
M(D1E<B!:=VES8VAE;G-P96EC:&5R(&MO;FYT92!N:6-H="!I;FET:6%L:7-I
M97)T('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDT
M,B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@U"B,Z
M(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#4P(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ-3<*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9&5R
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B
M0V%L;2(*;7-G<W1R(")7:6YD<W1I;&PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B
M0V%M8F]D:6$B"FUS9W-T<B`B2V%M8F]D<V-H82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G
M:60@(D-A;65R;V]N(@IM<V=S='(@(DMA;65R=6XB"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@
M<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B17AT97)N92!397-S:6]N+4AA
M;F1L97(@:_9N;F5N(&YI8VAT(&%D;6EN:7-T<FEE<G0@=V5R9&5N+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S-2!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(E9E
M<F)I;F1U;F<@>G5M($E-05`M4V5R=F5R(&MA;FX@;FEC:'0@:&5R9V5S=&5L
M;'0@=V5R9&5N.B`E<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C0T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R(")$:64@1&%T96D@7"(E<UPB(&MA;FX@;FEC:'0@9V7V
M9F9N970@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G
M<W1R(")+86YA9&$B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E
M<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z
M,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*
M;7-G<W1R(")!8F)R96-H96XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S
M='(@(E!R;V)L96UB97)I8VAT(&%B8G)E8VAE;B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-#0T(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(S-0HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8W-2!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C(R"FUS9VED(")#86YN;W0@8V]P
M>2!F:6QE*',I("T@<V]U<F-E(&%N9"!D97-T:6YA=&EO;B!A<F4@=&AE('-A
M;64N(@IM<V=S='(@(B(*(D1A=&5I*&5N*2!K]FYN96X@;FEC:'0@:V]P:65R
M="!W97)D96X@+2!1=65L;"T@=6YD(%II96QD871E:65N('-I;F0@(@HB:61E
M;G1I<V-H+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S(R"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(D1I92!$871E:2!<(B5S7"(@:V]N;G1E(&YI8VAT(&=E;/9S
M8VAT('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G
M>2]C;W!Y+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@
M9&ER96-T;W)Y+B(*;7-G<W1R(")+96EN('1E;7!O<N1R97,@5F5R>F5I8VAN
M:7,@9V5F=6YD96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU
M,3`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`U"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z-S4Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HQ.#<*;7-G:60@(D-A;FYO="!M;W9E(&9I;&4H<RD@+2!D97-T
M:6YA=&EO;B!I<R!W:71H:6X@<V]U<F-E+B(*;7-G<W1R("(B"B)$871E:2AE
M;BD@:_9N;F5N(&YI8VAT('9E<G-C:&]B96X@=V5R9&5N("T@6FEE;&1A=&5I
M(&)E9FEN9&5T('-I8V@@:6T@(@HB475E;&QO<F1N97(N(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N
M;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*
M;7-G<W1R(")&;W)T<V5T>G5N9R!O:&YE(%PB=&%R9V5T1FEL95PB+5!A<F%M
M971E<B!N:6-H="!M]F=L:6-H+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@
M9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B1&%S(%9E<GIE:6-H;FES(%PB
M)7-<(B!K;VYN=&4@;FEC:'0@96YT9F5R;G0@=V5R9&5N+B(*"B,Z(&9R86UE
M=V]R:R]$871A5')E92]$871A5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$871A
M5')E92]$871A5')E92]S<6PN<&AP.C8X,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B
M2V]N;G1E(&YI8VAT(&5N=&9E<FYT('=E<F1E;BP@)60@2VEN9&5R(&5X:7-T
M:65R96XN(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP
M:'`Z-C$Q"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N
M=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M
M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@HB56US;W)T:65R96X@;FEC:'0@
M;?9G;&EC:"X@1&EE($%N>F%H;"!D97(@16EN='+D9V4L(&1I92!U;7-O<G1I
M97)T('=E<F1E;B`B"B)S;VQL96XL('-T:6UM="!N:6-H="!M:70@9&5R($%N
M>F%H;"!D97(@9V5S<&5I8VAE<G1E;B!%:6YT<N1G92#\8F5R96EN+B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Q"FUS9VED(")#86YN;W0@
M<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(E!A<W-W;W)T(&MA;FX@;FEC:'0@
M875T;VUA=&ES8V@@>G5R_&-K9V5S971Z="!W97)D96XL(&)I='1E('=E;F1E
M;B!3:64@<VEC:"`B"B)A;B!):')E;B!!9&UI;FES=')A=&]R+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM
M<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E
M<BXB"FUS9W-T<B`B(@HB1&EE($YA8VAR:6-H="!K;VYN=&4@;FEC:'0@86X@
M9&EE(&%N9V5G96)E($YU;6UE<B!W96ET97)G96QE:71E="!W97)D96XN(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S4P"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;FYO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R
M(")$:64@1&%T96D@7"(E<UPB(&MA;FX@;FEC:'0@9V5S<&5I8VAE<G0@=V5R
M9&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R(")+
M87`@5F5R9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(T"FUS9VED(")#87!T:6]N(@IM<V=S='(@(MQB97)S
M8VAR:69T(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT
M<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM<V=S='(@(E!R;W9I9&5R(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS"FUS9VED(")#871E9V]R:65S
M(&%N9"!,86)E;',B"FUS9W-T<B`B2V%T96=O<FEE;B!U;F0@0F5S8VAR:69T
M=6YG96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS
M9W-T<B`B0V%Y;6%N+4EN<V5L;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T
M<B`B36]B:6QT96QE9F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S
M(@IM<V=S='(@(EIE;&QE;F5I9V5N<V-H869T96XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P
M861D:6YG.B(*;7-G<W1R("));FYE;F%B<W1A;F0Z(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B
M0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(EIE;&QE;F5I9V5N<V-H869T96XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("):96QL96YA8G-T86YD
M.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S0*;7-G:60@(D-E
M;&QP:&]N92(*;7-G<W1R(")-;V)I;'1E;&5F;VXB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X,0IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS
M9W-T<B`B2V5L=&ES8V@@*$E33RTX.#4Y+3$T*2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E
M;G1E<B(*;7-G<W1R("):96YT<FEE<G0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#
M96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B6F5N=')A;&%F<FEK
M86YI<V-H92!297!U8FQI:R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R
M"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R
M(")-:71T96QE=7)O<.1I<V-H("A)4T\M.#@U.2TR*2(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")#97)T:69I8V%T
M92!$971A:6QS(@IM<V=S='(@(EIE<G1I9FEK871D971A:6QS(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3(*;7-G:60@(D-E<G1I
M9FEC871E($]W;F5R(@IM<V=S='(@(EIE<G1I9FEK871B97-I='IE<B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#
M97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R("):97)T:69I:V%T<FEC:'1L
M:6YI96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS9W-T<B`B5'-C
M:&%D(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B0VAA;F=E(@IM<V=S
M='(@(L1N9&5R;B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS
M,0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`BQ&YD97)N
M(%-I92!):'(@4&%S<W=O<G0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-CD*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T
M('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@
M(@HB96UA:6QS+B(*;7-G<W1R("(B"B+$;F1E<FX@4VEE(&1E;B!.86UE;B!O
M9&5R(&1I92!!9')E<W-E+"!D:64@9&EE($5M<&;D;F=E<B!):')E<B!%+4UA
M:6PM(@HB3F%C:')I8VAT96X@<V5H96XL('=E;FX@<VEE(&1I97-E(&QE<V5N
M(&]D97(@9&%R875F(&%N=V]R=&5N+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R
M9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A
M=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("(B"B)$87,@Q&YD97)N($EH<F5S(%!A<W-W;W)T<R!W:7)D('9O;B!D:65S
M96T@4WES=&5M('IU<B!:96ET(&YI8VAT("(*(G5N=&5R<W3\='IT+B!":71T
M92!W96YD96X@4VEE('-I8V@@86X@26AR96X@061M:6YI<W1R871O<BXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(EIE:6-H96XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G
M:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(DQI;FL@_&)E<E]P<OQF96XN
M+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EL92(*;7-G<W1R(")#:&EL92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@(D-H:6YA(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-H:6YE<V4@4VEM<&QI
M9FEE9"`H1T(R,S$R*2(*;7-G<W1R(")#:&EN97-I<V-H('9E<F5I;F9A8VAT
M("A'0C(S,3(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@
M(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(D-H:6YE<VES
M8V@@=')A9&ET:6]N96QL("A":6<U*2(*"B,Z('1E;7!L871E<R]P<F5F<R]A
M<'`N:6YC.C<*;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB"FUS9W-T<B`B
M06YW96YD=6YG(&%U<W?D:&QE;CHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,C<P"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G
M<W1R(")7Y&AL96X@4VEE(&5I;B!087-S=V]R="(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(D-H;V]S92!A('5S97)N
M86UE(@IM<V=S='(@(E?D:&QE;B!3:64@96EN96X@0F5N=71Z97)N86UE;B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.34*;7-G:60@(D-H;V]S92!H
M;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B3&5G96X@4VEE(&9E<W0L
M('=I92!D87,@1&%T=6T@86YG97IE:6=T('=E<F1E;B!S;VQL.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D
M(&QI<W1S*2(*;7-G<W1R("),:7-T96YF;W)M870@875S=^1H;&5N("AF_'(@
M;G5M;65R:65R=&4@3&ES=&5N*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H<FES
M=&UA<R!)<VQA;F0B"FUS9W-T<B`B5V5I:&YA8VAT<VEN<V5L(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.CDP-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N
M(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B2VQA<W-E;F1E9FEN:71I;VX@
M9OQR("5S(&YI8VAT(&=E9G5N9&5N+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#;&5A<B(*;7-G<W1R(")(
M96ET97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(DU3
M+4]F9FEC92U486=S(&5N=&9E<FYE;B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,CD*;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@(D%B9G)A9V4@>G5R
M_&-K<V5T>F5N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM
M<V=S='(@(D)E;G5T>F5R9&%T96X@;/9S8VAE;CH@)7,B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B
M"FUS9W-T<B`B0F5N=71Z97)D871E;B!L]G-C:&5N(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S97(@9&%T
M82(*;7-G<W1R(")"96YU='IE<F1A=&5N(&SV<V-H96XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@IM<V=I9"`B0VQE87)I
M;F<@3&%T92(*;7-G<W1R(")3<.1T97(@075F:VQA<F5N9"(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#
M;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R(")&;W)T9F%H<F5N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS
M9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(D-L:6-K871E;&P@
M<&5R($A45%`B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*
M;7-G<W1R(")&96YS=&5R('-C:&QI9=]E;B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C0V"FUS9VED(")#;&]U9',B"FUS9W-T<B`B5V]L:V5N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@
M(D-L;W5D<R!%87)L>2(*;7-G<W1R(")&<OQH(%=O;&ME;B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")#;&]U
M9'DB"FUS9W-T<B`B0F5W]FQK="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-O8V]S
M("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(DMO:V]S:6YS96QN(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P
M<V4@4VED96)A<B(*;7-G<W1R(")-96[\(&5I;F9A:')E;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G
M:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(EIU<V%M;65N:.1N9V5N
M9&4@4F%H;65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B"FUS9W-T
M<B`B2V]L=6UB:65N(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O
M0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@
M(D9A<F)E(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN
M<&AP.C,S.`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP
M:'`Z,S,Y"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU,#,@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I
M9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(D9A<F)A=7-W86AL(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@T-@IM<V=I9"`B0V]L;W5R('-E;&5C
M=&EO;B(*;7-G<W1R(")&87)B=V%H;"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R
M(")3<&%L=&5N.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C0*
M;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B4W!A;'1E;OQB97)S8VAR
M:69T96XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8V"FUS9VED
M(")#;VUI8W,B"FUS9W-T<B`B0V]M:6-S(@H*(SH@861M:6XO8VUD<VAE;&PN
M<&AP.C(V"FUS9VED(")#;VUM86YD(@IM<V=S='(@(D)E9F5H;"(*"B,Z(&%D
M;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G
M<W1R(")"969E:&QS>F5I;&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B2V]M;65N=&%R
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G
M:60@(D-O;6UO;B!.86UE(@IM<V=S='(@(D5I;F1E=71I9V5R($YA;64B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R(")+;VUO<F5N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM
M<V=I9"`B0V]M<&%N>2(*;7-G<W1R(")&:7)M82(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(D-O;7!U
M=&5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-@IM<V=I
M9"`B0V]N9&ET:6]N(@IM<V=S='(@(D)E9&EN9W5N9V5N(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-3$*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B
M0F5D:6YG=6YG96XB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY,PIM<V=I
M9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R(")+;VYF:6=U
M<F%T:6]N<W5N=&5R<V-H:65D92(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ,S0*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM
M<V=S='(@(D1I92!+;VYF:6=U<F%T:6]N(&UU<W,@86MT=6%L:7-I97)T('=E
M<F1E;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R("(E<R!K;VYF:6=U
M<FEE<F5N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU
M,0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R(")087-S=V]R="!B
M97-TY'1I9V5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B
M2V]N9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T
M:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(D1E;6]K<F%T:7-C:&4@4F5P
M=6)L:6,@2V]N9V\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HR,#0*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S0W"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`B
M5F5R8FEN9'5N9R!F96AL9V5S8VAL86=E;BXB"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,#0*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0W"FUS9VED(")#;VYN96-T:6]N(&9A
M:6QE9#H@(@IM<V=S='(@(E9E<F)I;F1U;F<@9F5H;&=E<V-H;&%G96XZ("(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y.0IM<V=I9"`B
M0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*
M;7-G<W1R(")697)B:6YD=6YG('IU;2#V9F9E;G1L:6-H96X@4V-H;/QS<V5L
M<V5R=F5R('=U<F1E(&%B9V5W:65S96XN(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z.#`Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE
M8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N
M.B`E<R`H)7,I(@IM<V=S='(@(B(*(E9E<F)I;F1U;F<@>G5M(/9F9F5N=&QI
M8VAE;B!38VAL_'-S96QS97)V97(@=W5R9&4@86)G97=I97-E;BX@1W)U;F0Z
M("5S("@E<RDB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@X.`IM
M<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T
M<B`B5F5R8FEN9'5N9R!Z=6T@1E10+5-E<G9E<B!F96AL9V5S8VAL86=E;B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.34P(&-O;F9I9R]H;V]K
M<RYP:'`N9&ES=#HQ,#<W"FUS9VED(")#;VYT86-T<R(*;7-G<W1R(")+;VYT
M86MT92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@
M=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(D1I92!+;VYT86MT92!W
M=7)D96X@97)F;VQG<F5I8V@@26AR96T@061R97-S8G5C:"!H:6YZ=6=E9OQG
M="XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C8P
M"FUS9VED(")#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B`B"FUS
M9W-T<B`B26YH86QT<W1Y<"!D97(@:V]M<')I;6EE<G1E;B!$871E:3H@(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU-B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(DEN:&%L="!V;VX@
M7"(E<UPB(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S`@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU92(*
M;7-G<W1R(")796ET97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N
M9',B"FUS9W-T<B`B0V]O:RU);G-E;&XB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R(")#;V]K:64B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B2V]P:65R96XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C0X.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B2V]P:65R96X@9F5H;&=E<V-H;&%G
M96XZ("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B075S=V%H
M;"!K;W!I97)E;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@(DMO<W1E;BU)1"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B0V]S=&$@4FEC
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B
M16QF96YB96EN:_QS=&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HY.#8*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E
M.B`B"FUS9W-T<B`B1&EE($YA8VAR:6-H="!K;VYN=&4@;FEC:'0@;6ET(%!'
M4"!V97)S8VAL_'-S96QT('=E<F1E;CH@(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3`V-`IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N
M(&UE<W-A9V4Z("(*;7-G<W1R(")$:64@3F%C:')I8VAT(&MO;FYT92!N:6-H
M="!M:70@4$=0('5N=&5R>F5I8VAN970@=V5R9&5N.B`B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T
M(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(D1I92!.86-H<FEC
M:'0@:V]N;G1E(&YI8VAT(&UI="!3+TU)344@=F5R<V-H;/QS<V5L="!W97)D
M96XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<*
M;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R
M(")$:64@3F%C:')I8VAT(&MO;FYT92!N:6-H="!M:70@4R]-24U%('5N=&5R
M>F5I8VAN970@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B2V]N=&%K="!K;VYN
M=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+B`E<R(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C$R,`HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#@R"FUS
M9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B
M5F5R8FEN9'5N9R!Z=6T@3$1!4"U397)V97(@9F5H;&=E<V-H;&%G96XN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ
M-38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B
M86QA;F-E+B`E<R(*;7-G<W1R(")+;VYT;W-T86YD(&MO;FYT92!N:6-H="#\
M8F5R<'+\9G0@=V5R9&5N+B`E<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HT-C8*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R
M+B(*;7-G<W1R(")697)B:6YD=6YG('IU;2!,1$%0+5-E<G9E<B!F96AL9V5S
M8VAL86=E;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB
M)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(D944"U697)B:6YD=6YG('IU
M;2!397)V97(@7"(E<UPB(&MO;FYT92!N:6-H="!H97)G97-T96QL="!W97)D
M96XZ("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R
M96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B5F5R=&5I;&5R
M;&ES=&4@:V]N;G1E(&YI8VAT(&5R<W1E;&QT('=E<F1E;BX@)7,B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3,W"FUS9VED(")#;W5L
M9"!N;W0@9&5C<GEP="!01U`@9&%T83H@(@IM<V=S='(@(E!'4"U$871E;B!K
M;VYN=&5N(&YI8VAT(&5N='-C:&S\<W-E;'0@=V5R9&5N.B`B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,PIM<V=I9"`B0V]U;&0@
M;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(E,O34E-12U$871E
M;B!K;VYN=&5N(&YI8VAT(&5N='-C:&S\<W-E;'0@=V5R9&5N+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@
M)7,B"FUS9W-T<B`B2V]N=&%K="!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R
M9&5N+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D
M96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(E9E<G1E:6QE
M<FQI<W1E(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN("5S(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S
M7"(N(@IM<V=S='(@(D1A<R!!:W1U86QI<VEE<G5N9W-S:W)I<'0@7"(E<UPB
M(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z.38R"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H
M92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B1&EE($4M
M36%I;"U!9')E<W-E(&1E<R!%;7!FY&YG97)S(&MO;FYT92!N:6-H="!E<FUI
M='1E;'0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M
M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R(")$87,@061R97-S8G5C:"!K
M;VYN=&4@;FEC:'0@:V]M<&QE='0@9V5L97-E;B!W97)D96XN(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G
M:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES
M="XB"FUS9W-T<B`B5F5R=&5I;&5R;&ES=&4@:V]N;G1E(&YI8VAT(&%U<V=E
M;&5S96X@=V5R9&5N+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@
M=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G
M<W1R("),:7-T92!D97(@5F5R=&5I;&5R;&ES=&5N(&MO;FYT92!N:6-H="!A
M=7-G96QE<V5N('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDN<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D
M('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B1&EE(%-T<F%T96=I92!<(B5S
M7"(@:V]N;G1E(&YI8VAT(&=E;&%D96X@=V5R9&5N+B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HQ,3`*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@
M(D1A<R!697)Z96EC:&YI<R!<(B5S7"(@:V]N;G1E(&YI8VAT(&%N9V5L96=T
M('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW
M,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H
M92!K97ES97)V97(N(@IM<V=S='(@(M9F9F5N=&QI8VAE<B!38VAL_'-S96P@
M:V]N;G1E(&YI8VAT('9O;2!38VAL_'-S96QS97)V97(@9V5H;VQT('=E<F1E
M;BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T
M<B`B7"(E<UPB(&MO;FYT92!N:6-H="!Z=6T@4V-H<F5I8F5N(&=E]F9F;F5T
M('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@)7,N(@IM<V=S='(@(B5S(&MO;FYT92!N:6-H="!G96QE<V5N('=E
M<F1E;BXB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N
M<&AP.C0R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-
M86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R(")$87,@36%I;G1E
M;F%N8V5?5&%S:R!-;V1U;"`E<R!K;VYN=&4@;FEC:'0@9V7V9F9N970@=V5R
M9&5N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@
M(E9E<GIE:6-H;FES(%PB)7-<(B!K;VYN=&4@;FEC:'0@9V7V9F9N970@=V5R
M9&5N+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0IM<V=I9"`B0V]U;&0@;F]T
M(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B5F5R8FEN9'5N9R!Z
M=6T@3$1!4"U397)V97(@:V]N;G1E(&YI8VAT(&AE<F=E<W1E;&QT('=E<F1E
M;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B
M)7,@:V]N;G1E(&YI8VAT(&=E;&5S96X@=V5R9&5N+B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C@V"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S
M970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@
M;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y
M(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N
M965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB1&%S(%!A<W-W;W)T
M(&;\<B!D96X@86YG96=E8F5N96X@0F5N=71Z97(@:V]N;G1E(&YI8VAT('IU
M<OQC:V=E<V5T>G0@=V5R9&5N+"`B"B)W96EL(&5I;FEG92!!;F=A8F5N(&YI
M8VAT(')I8VAT:6<@=V%R96XN(%9E<G-U8VAE;B!3:64@97,@97)N975T(&]D
M97(@=V5N9&5N("(*(E-I92!S:6-H(&%N($EH<F5N($%D;6EN:7-T<F%T;W(L
M('=E;FX@4VEE('=E:71E<F4@2&EL9F4@8F5N]G1I9V5N+B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P-0HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#8*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<W"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C0Q-`HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HT,C`*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z-#(V"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B04-,(&MO;FYT92!N
M:6-H="!G96QE<V5N('=E<F1E;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@
M(D1A<R!!9')E<W-B=6-H(&MO;FYT92!N:6-H="!G96QE<V5N('=E<F1E;BX@
M)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(E9E<G1E:6QE<FQI
M<W1E(&MO;FYT92!N:6-H="!A=7-G96QE<V5N('=E<F1E;BX@)7,B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I
M8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R(")697)T96EL97)L:7-T96X@:V]N
M;G1E(&YI8VAT(&%U<V=E;&5S96X@=V5R9&5N+B`E<R(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(P-`HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C0*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(X"FUS9VED(")#;W5L9"!N;W0@
M<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(D1I92!3
M97)V97)FY&AI9VME:71E;B!K;VYN=&5N(&YI8VAT(&%U<V=E;&5S96X@=V5R
M9&5N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U
M;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")+;VYF:6=U
M<F%T:6]N(&MO;FYT92!N:6-H="!Z=7+\8VMG97-E='IT('=E<F1E;BXB"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B5F5R>F5I8VAN:7,@7"(E
M<UPB(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B)7,M2V]N
M9FEG=7)A=&EO;B!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N
M9FEG=6%T:6]N+B(*;7-G<W1R(")"86-K=7`@9&5R($MO;F9I9W5R871I;VX@
M:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;BXB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R(")"
M86-K=7`@9&5R($MO;F9I9W5R871I;VX@:V]N;G1E(&YI8VAT(&=E<W!E:6-H
M97)T('=E<F1E;CH@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U
M<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")$87,@06MT=6%L
M:7-I97)U;F=S<VMR:7!T(&MO;FYT92!N:6-H="!N86-H(%PB)7-<(B!G97-P
M96EC:&5R="!W97)D96XN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C
M:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B0F%C:W5P(&1E
M<B!+;VYF:6=U<F%T:6]N("5S(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W
M97)D96XN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B
M"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y
M(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"B)$
M:64@2V]N9FEG=7)A=&EO;B`E<R!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@
M=V5R9&5N+B!3:64@:_9N;F5N(&5N='=E9&5R("(*(F5I;F4@9&5R($WV9VQI
M8VAK96ET96X@=6YT97(@)7,@=F5R=V5N9&5N+"!U;2!D96X@0V]D92!Z=2!S
M<&5I8VAE<FXL(&]D97(@(@HB9&5N('5N=&5N<W1E:&5N9&5N($-O9&4@;6%N
M=65L;"!N86-H("5S(&MO<&EE<F5N+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,
M1$%0('-E<G9E<BXB"FUS9W-T<B`B1&5R($Q$05`M4V5R=F5R(&MO;FYT92!N
M:6-H="!D=7)C:'-U8VAT('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S
M7"(N(@IM<V=S='(@(EPB)7-<(B!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R
M9&5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A
M=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B1&5R($MO;G1A:W0@:V]N;G1E(&YI
M8VAT(&=E<W!E:6-H97)T('=E<F1E;BX@)7,B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<R(*;7-G<W1R(")697)T96EL97)L:7-T92!K;VYN=&4@;FEC:'0@86MT=6%L
M:7-I97)T('=E<F1E;BX@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I
M9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B1&EE($MO;F9I9W5R
M871I;VX@9OQR(%PB)7-<(B!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R
M9&5N.B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C,*;7-G:60@
M(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E
M('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*(D1I92!-;WII;&QA
M(%-I9&5B87(@:V]N;G1E(&YI8VAT(&=E9G5N9&5N('=E<F1E;BX@4W1E;&QE
M;B!3:64@<VEC:&5R+"!D87-S("(*(F1I92!3:61E8F%R(&=E]F9F;F5T(&ES
M="XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R
M(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<
M(B5S7"(Z("5S(@IM<V=S='(@(B(*(D1E;2!"96YU='IE<B!<(B5S7"(@:V]N
M;G1E;B!D:64@9F]L9V5N9&4@4F5C:'1E(&;\<B!D96X@3W)D;F5R(%PB)7-<
M(B!N:6-H="`B"B)Z=6=E=VEE<V5N('=E<F1E;CH@)7,B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS
M9W-T<B`B1V5ZY&AL=&5R(%1E>'0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R("),86YD
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W-0IM<V=I9"`B0V]U
M<G-E<R(*;7-G<W1R(")+=7)S92(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E
M(@IM<V=S='(@(D5R<W1E;&QE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@
M;&EN:R(*;7-G<W1R("),:6YK(&5R<W1E;&QE;B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.38*;7-G:60@(D-R96%T92!A(&YE
M=R!O;F4B"FUS9W-T<B`B3F5U92!)9&5N=&ETY'0@86YL96=E;B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4R"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A
M=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B56YT97)O<F1N97(@97)S=&5L;&5N
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*;7-G:60@
M(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B17)S=&5L;&5R<F5C:'1E
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(S,`IM<V=I9"`B0W)E
M9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(DMR961I=&MA<G1E;FYU;6UE<B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(DMR;V%T:65N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R(")+=6)A(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S
M(@IM<V=S='(@(D%K='5E;&QE(#0@4&AA<V5N(@H*(SH@861M:6XO<V5S<VEO
M;G,N<&AP.C4P"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(D%K
M='5E;&QE(%-E<W-I;VYS(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB
M+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T
M<B`B06MT=65L;&4@6F5I="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@
M:7,B"FUS9W-T<B`B06MT=65L;&4@55),(&ES="(*"B,Z(&%D;6EN+W-E<W-I
M;VYS+G!H<#HS-0IM<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R(")!:W1U
M96QL92!"96YU='IE<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G
M:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R(")!:W1U96QL97,@5V5T=&5R
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V-`IM<V=I9"`B
M0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R(")$97)Z96ET:6=E($)E9&EN
M9W5N9V5N.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(D%K='5E
M;&QE<B!3=&EL(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@
M;&]G;VX@=&\@)7,N(@IM<V=S='(@(B(*(DQE9V5N(%-I92!F97-T+"!W96QC
M:&4@075F9V%B96X@;F%C:"!D97(@06YM96QD=6YG(&)E:2`E<R!E<FQE9&EG
M="!W97)D96X@(@HB<V]L;&5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S
M='(@(D%U<W-C:&YE:61E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T
M<B`B075S=V%H;"!A=7-S8VAN96ED96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#
M>7!R=7,B"FUS9W-T<B`B6GEP97)N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#4*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(DMY<FEL
M;&ES8V@@*$M/23@M4BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM
M<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B2WER:6QL
M:7-C:"`H5VEN9&]W<RTQ,C4Q*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@W"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T
M<B`B2WER:6QL:7-C:"]5:W)A:6YI<V-H("A+3TDX+54I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`B5'-C:&5C:&ES8VAE
M(%)E<'5B;&EK(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0U,B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B
M"FUS9W-T<B`B5%0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,CDP
M"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A
M;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S
M='(@(B(*(D133B`H<VEE:&4@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO
M96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*"B,Z(&9R
M86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3D*;7-G:60@
M(D1A:6QY(@IM<V=S='(@(E3D9VQI8V@B"@HC.B!A9&UI;B]D871A=')E92YP
M:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B1&%T851R
M964@0G)O=W-E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#@*
M;7-G:60@(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R(")$871E;F)A;FMA8F9R
M86=E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$V"FUS9VED(")$871E
M(@IM<V=S='(@(D1A='5M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B16UP
M9F%N9W-D871U;2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#<*
M;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@(D1A='5M<V%U<W=A:&PB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*;7-G:60@(D1A>2(*;7-G<W1R(")4
M86<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(E-P
M86QT92!?;/9S8VAE;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0U,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R(")$97IE;6)E
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R("):
M86AL96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B16EN>G5G
M('9E<G)I;F=E<FXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PIM<V=I9"`B1&5F875L="(*;7-G<W1R
M(")3=&%N9&%R9"(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(E-T
M86YD87)D9F%R8F4B"@HC.B!F<F%M97=O<FLO4')E9G,O261E;G1I='DN<&AP
M.CDX"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@(E-T86YD87)D
M:61E;G1I=.1T(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<U"FUS9VED
M(")$969A=6QT(%-H96QL(@IM<V=S='(@(E-T86YD87)D<VAE;&PB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM
M<V=S='(@(D1E9FEN:71I;VYE;B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C<*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-R!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C<Q"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z.30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3<*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-#`@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ.#,*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C<S('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R("),]G-C
M:&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,R"FUS9VED(")$96QE=&4@0V5L;"(*;7-G<W1R("):96QL
M92!L]G-C:&5N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,#4@861M:6XO9W)O
M=7!S+G!H<#HR,S,*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R(")'<G5P
M<&4@;/9S8VAE;B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U
M,0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R("),;V<@;/9S8VAE;B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T92!097)M:7-S:6]N
M(@IM<V=S='(@(E)E8VAT92!L]G-C:&5N(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R
M9V4@;65S<V%G97,B"FUS9W-T<B`B3F%C:')I8VAT96X@;/9S8VAE;B!U;F0@
M96YT9F5R;F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B
M6F5L;&4@;/9S8VAE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS
M9W-T<B`B4W!A;'1E(&SV<V-H96XB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T
M92(*;7-G<W1R(")"97-T96AE;F1E(&%L=&5R;F%T:79E(%9O<FQA9V4@;/9S
M8VAE;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP
M.C4T"FUS9VED(")$96QE=&4@;65S<V%G97,B"FUS9W-T<B`B3F%C:')I8VAT
M96X@;/9S8VAE;B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M-#(Q"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F
M;W(@7"(E<UPB(@IM<V=S='(@(E)E8VAT92!F_'(@7"(E<UPB(&SV<V-H96XB
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A
M;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B4F5C:'1E(&;\<B!<
M(B5S7"(@=6YD(&%L;&4@56YT97)R96-H=&4@;/9S8VAE;C\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS
M9VED(")$96QE=&4@<F]W(@IM<V=S='(@(EIE:6QE(&SV<V-H96XB"@HC.B!T
M96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$
M96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B075S9V5WY&AL=&4@
M261E;G1I=.1T(&SV<V-H96XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,T,S$T+G!H<#HU,PIM<V=I9"`B1&5L971E('-U8B!F;VQD97)S(@IM
M<V=S='(@(E5N=&5R;W)D;F5R(&SV<V-H96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E
M;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B1&EE(&%K='5E;&QE
M(%-P86QT92!L]G-C:&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U
M<G)E;G0@<F]W(@IM<V=S='(@(D1I92!A:W1U96QL92!:96EL92!L]G-C:&5N
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N
M(@IM<V=S='(@(D1A<R!!:W1U86QI<VEE<G5N9W-S:W)I<'0@7"(E<UPB('=U
M<F1E(&=E;/9S8VAT+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*;7-G:60@(D1E;&EV97)Y
M('1I;64B"FUS9W-T<B`B075S;&EE9F5R=6YG<WIE:70B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y
M"FUS9VED(")$96YM87)K(@IM<V=S='(@(D3D;F5M87)K(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H
M92!0<F]B;&5M(@IM<V=S='(@(D)E<V-H<F5I8F5N(%-I92!D87,@4')O8FQE
M;2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDS."!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"FUS9VED(")$
M97-C<FEP=&EO;B(*;7-G<W1R(")"97-C:')E:6)U;F<B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C(P-@IM<V=I9"`B1&5T86EL<R`H86QS;R!I
M;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R(")$971A:6QS("AA=6-H(&EN
M($AO<F1E<R!,;V=D871E:2DZ(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HR,3`*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@
M=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(D1E=&%I;',@=W5R9&5N(&;\
M<B!D96X@061M:6YI<W1R871O<B!M:71G96QO9V=T+B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR,C$*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S
M='(@(D5N='=I8VML=6YG(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3D*
M;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R(")4875P=6YK="(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,CDV"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@
M:&]U<CH@(@IM<V=S='(@(E1A=7!U;FMT(&1E<B!L971Z=&5N(%-T=6YD93H@
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-@IM<V=I9"`B
M1&5W('!O:6YT.B`B"FUS9W-T<B`B5&%U<'5N:W0Z("(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C
M=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(E9O;B!L:6YK<R!N86-H(')E
M8VAT<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@
M(E9O;B!R96-H=',@;F%C:"!L:6YK<R(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B5F5R>F5I8VAN:7,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8R"FUS9VED(")$:7-P;&%Y
M(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(EIE:70@:6T@,C0M4W1U;F1E;BU&
M;W)M870@86YZ96EG96X_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(D%N>F5I9V4M16EN
M<W1E;&QU;F=E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HX
M.0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R(")$
M971A:6QI97)T92!6;W)H97)S86=E(&%N>F5I9V5N(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HY,@IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*
M;7-G<W1R(")6;W)H97)S86=E("A4048I(&%N>F5I9V5N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-PIM<V=I9"`B1&ES<&QA>2!F;W)M870B
M"FUS9W-T<B`B06YZ96EG969O<FUA="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O341.+G!H<#HQ.3$*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO
M;B(*;7-G<W1R(")%;7!F86YG<V)E<W3D=&EG=6YG(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM
M<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B1'-C:&EB=71I(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*;7-G:60@(D1O(&YO="!D96QE
M=&4B"FUS9W-T<B`B3FEC:'0@;/9S8VAE;B(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M
M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B1W)E:69E;B!3:64@;FEC:'0@9&ER
M96MT(&%U9B!M86EN=&5N86YC92YP:'`@>G4B"@HC.B!T96UP;&%T97,O9&%T
M82]T<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ
M,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD
M(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R("(B"B)%
M;G1HY&QT(&1I92!E<G-T92!:96EL92!D:64@1F5L9&YA;65N/R!796YN(&IA
M+"!D:65S97,@075S=V%H;&OD<W1C:&5N("(*(FUA<FMI97)E;CHB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R(")$;VUI;FEC82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R(")$
M;VUI;FEK86YI<V-H92!297!U8FQI:R(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG
M;B!U<"XB"FUS9W-T<B`B3F]C:"!K96EN96X@6G5G86YG/R!(:65R(&%N;65L
M9&5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@U
M,PIM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B2&5R=6YT97)L861E;B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@U,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R("(E<R!(97)U;G1E
M<FQA9&5N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,0IM<V=I9"`B
M1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP
M="XB"FUS9W-T<B`B17)Z975G=&4@2V]N9FEG=7)A=&EO;B!A;',@4$A0+5-K
M<FEP="!H97)U;G1E<FQA9&5N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q,C4*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(D%U<W=A
M:&QL:7-T92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B
M1')U9W,B"FUS9W-T<B`B1')O9V5N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B12U-86EL
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z
M.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A
M<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B
M"B)%+4UA:6PM;F%C:"U335,M9V%T97=A>2!F_'(@4')O=FED97(L(&1I92!E
M:6YE;B!S;VQC:&5N($1I96YS="!U;G1E<G-T_'1Z96XN(@H*(SH@9G)A;65W
M;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(D9%2$Q%4B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B16-U861O<B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,S(V('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,"!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHW,@IM<V=I9"`B161I="(*;7-G<W1R(")"96%R8F5I
M=&5N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU,`IM<V=I
M9"`B161I="!";&]C:R(*;7-G<W1R(")";&]C:R!B96%R8F5I=&5N(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HR,#0*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T
M<B`B1W)U<'!E(&)E87)B96ET96XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`P
M"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`B4F5C:'1E(&)E87)B
M96ET96XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED
M(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(E)E8VAT92!B96%R8F5I=&5N
M(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R(")2
M96-H=&4@9OQR("<E<R<@8F5A<F)E:71E;B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@
M(D5I;G-T96QL=6YG96X@8F5A<F)E:71E;B!F_'(Z(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(E)E8VAT92!F
M_'(@7"(E<UPB(&)E87)B96ET96XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO
M;G,@9F]R("5S(@IM<V=S='(@(E)E8VAT92!F_'(@)7,@8F5A<F)E:71E;B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B161U8V%T:6]N
M(@IM<V=S='(@(D)I;&1U;F<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*
M;7-G<W1R("+$9WEP=&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%;"!386QV
M861O<B(*;7-G<W1R(")%;"!386QV861O<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B16QE
M;65N="XN+B(*;7-G<W1R(")%;&5M96YT+BXN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S
M='(@(D5M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#@W"FUS9VED(")%
M;6%I;"(*;7-G<W1R(")%+4UA:6PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4V-B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C@*
M;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B12U-86EL+4%D<F5S<V4B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@Q"FUS9VED(")%;6%I
M;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`B1&EE($4M36%I;"U!
M9')E<W-E;B!M_'-S96X@9VQE:6-H('-E:6XN(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`P-PIM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I
M;VXB"FUS9W-T<B`B12U-86EL+4%D<F5S<V4@;6ET($)E<W3D=&EG=6YG(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*
M;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@(D4M36%I;"UN
M86-H+5--4RU'871E=V%Y(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(Y.0IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(E-M
M:6QE>7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(DQE
M97)E($YA8VAR:6-H="XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S
M='(@(DQE97)E<R!%<F=E8FYI<RXB"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+
M97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS
M9W-T<B`B4W5C:&)E9W)I9F9E(&SV<V-H96XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-30P"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E
M<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R(")%:6YF
M_&=E;B!V;VX@0FEL9&5R;B!A=7,@1F]T;V=A;&5R:65N(&EN(&1E;B!497AT
M(&5R;&%U8F5N/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,34*;7-G
M:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@
M(DMO;G1E>'1M96[\(&)E:2!296-H='-K;&EC:R!A:W1I=FEE<F5N/R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V,#8@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@Q,0IM<V=I9"`B16YD('EE87(B"FUS9W-T<B`B16YD:F%H
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(D5D:71O<B!V97)G
M<O;?97)N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q-@IM<V=I9"`B
M(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B
M92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D
M+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S
M='(@(B(*(D=E8F5N(%-I92!E:6YE(%-I8VAE<FAE:71S9G)A9V4@96EN+"!D
M:64@26AN96X@9V5S=&5L;'0@=VER9"P@=V5N;B!3:64@26AR("(*(E!A<W-W
M;W)T('IU<OQC:W-E='IE;B!M]F-H=&5N+"!Z+B!"+B!<(E=I92!L875T970@
M9&5R($YA;64@26AR97,@2&%U<W1I97)S/R(*(EPB.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM
M<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(DAI97(@
M9&EE($)I;&0M55),(&%N9V5B96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.#DR"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R
M<R!B96QO=SHB"FUS9W-T<B`B1V5B96X@<VEE(&1I92!"=6-H<W1A8F5N('5N
M=&5N(&5I;CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDY(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U:6YE
M82(*;7-G<W1R("+$<75A=&]R:6%L+4=U:6YE82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G
M:60@(D5R:71R96$B"FUS9W-T<B`B17)I=')E82(*"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z
M,C<*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]6:65W+G!H<#HY
M,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#@*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-@IM<V=I9"`B17)R;W(B"FUS9W-T<B`B1F5H;&5R(@H*
M(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S
M='(@(D9E:&QE<B!B96EM($5R<W1E;&QE;B!E:6YE<R!";&]C:W,Z("5S(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S
M='(@(D9E:&QE<B!B96EM($SV<V-H96X@9&5S(%-Y;F-H<F]N:7-A=&EO;G-A
M;FME<G,Z("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z
M("5S(@IM<V=S='(@(D9E:&QE<B!B96EM($SV<V-H96X@9&5S(%-Y;F-H<F]N
M:7-A=&EO;G-L;V=S.B`E<R(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP
M;&%T92YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&=E='1I
M;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`B1F5H;&5R(&)E:6T@17)Z975G96X@
M9&5S($EN:&%L=',Z("5S(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG('!A
M<W-W;W)D.B`E<R(*;7-G<W1R(")&96AL97(@8F5I;2#$;F1E<FX@9&5S(%!A
M<W-W;W)T<SH@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S
M<V%G92XB"FUS9W-T<B`B1F5H;&5R(&EN(&1E<B!%+4UA:6PM3F%C:')I8VAT
M+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(D9E:&QE<B!B96EM
M(%-C:')E:6)E;B!V;VX@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S
M=&]N:6$B"FUS9W-T<B`B17-T;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T
M:&EO<&EA(@IM<V=S='(@(L1T:&EO<&EE;B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(D5T;FES8VAE<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R
M;W!E(@IM<V=S='(@(D5U<F]P82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,S8*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B06QL92`Q
M-2!-:6YU=&5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-@IM<V=I
M9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(D%L;&4@,B!-:6YU=&5N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S,R!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S@T"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(D%L
M;&4@,S`@4V5K=6YD96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,U
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#<*;7-G:60@(D5V97)Y(#4@;6EN
M=71E<R(*;7-G<W1R(")!;&QE(#4@36EN=71E;B(*"B,Z(&9R86UE=V]R:R]-
M86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO
M9VEN(@IM<V=S='(@(D)E:2!J961E<B!!;FUE;&1U;F<B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S,W"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS
M9W-T<B`B06QL92!H86QB92!3='5N9&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S,T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#4*;7-G:60@(D5V
M97)Y(&UI;G5T92(*;7-G<W1R(")!;&QE(#8P(%-E:W5N9&5N(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L
M=65S.B(*;7-G<W1R(")"96ES<&EE;'=E<G1E.B(*"B,Z(&%D;6EN+W!H<'-H
M96QL+G!H<#HX,B!A9&UI;B]C;61S:&5L;"YP:'`Z-3$@861M:6XO<W%L<VAE
M;&PN<&AP.C$R.`IM<V=I9"`B17AE8W5T92(*;7-G<W1R(")!=7-F_&AR96XB
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C8Q-`IM<V=I9"`B17AP86YD(@IM<V=S='(@(E9E<F=R]M]E<FXB"@HC.B!F
M<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E
M8W1E9"`G*2<B"FUS9W-T<B`B)RDG(&5R=V%R=&5T(@H*(SH@9G)A;65W;W)K
M+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R
M92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R(")%:6YZ96QN
M97,@5V]R="!O9&5R(%-U8VAB96=R:69F(&EN($%N9OQH<G5N9W-Z96EC:&5N
M(&5R=V%R=&5T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$R"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B5F5R9F%L;'-D
M871U;2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<W
M"FUS9VED(")%>'!O;F5N="(*;7-G<W1R(")%>'!O;F5N="(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G
M:60@(D9'($-O;&]R(@IM<V=S='(@(E9O<F1E<F=R=6YD9F%R8F4B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<V"FUS9VED(")&5%`@=7!L;V%D(&]F
M('-E='5P(@IM<V=S='(@(DAO8VAL861E;B!D97(@2V]N9FEG=7)A=&EO;B!P
M97(@1E10(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z,C(U
M"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T
M<B`B0F5N=71Z97)E:6YS=&5L;'5N9V5N(&MO;FYT96X@;FEC:'0@9V5L861E
M;B!W97)D96XN(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*;7-G:60@(D9A
M:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")697)B
M:6YD=6YG('IU;2!,1$%0(%-E<G9E<B!G97-C:&5I=&5R="XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C
M;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(E9E<F)I;F1U;F<@>G5M
M(%--0BU397)V97(@9V5S8VAE:71E<G0N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HW,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O
M(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(D5S(&MO;FYT92!K96EN92!+
M;W!I92!V;VX@7"(E<UPB(&5R<W1E;&QT('=E<F1E;BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C<R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(D5S(&MO;FYT92!N
M:6-H="!N86-H(%PB)7-<(B!K;W!I97)T('=E<F1E;BXB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@8W)E
M871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(D%U9F)A=2!E:6YE
M;B!N975E;B!305-,+59E<F)I;F1U;F<@:7-T(&9E:&QG97-C:&QA9V5N+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3(S(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-S8W"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B17,@:V]N;G1E(&YI8VAT
M(&YA8V@@7"(E<UPB('9E<G-C:&]B96X@=V5R9&5N+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-#@S"B,L('!H<"UF;W)M870*;7-G:60@(D9A
M:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B1F5H;&5R(&)E:6T@3&5S
M96XZ("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3D*;7-G:60@(D9A:7(B"FUS9W-T<B`B2&5I=&5R(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@
M(D9A;&ML86YD:6YS96QN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L
M86YD<R(*;7-G<W1R(")&87+V97(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP
M:'`Z,C0P"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B4V-H=V5R97(@
M1F5H;&5R.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R(")&87@B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S4Q"FUS9VED(")&87AE<R(*;7-G<W1R(")&
M87AE(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(D9E8G)U87(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(R,@IM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R
M(")'96;\:&QT92!496UP97)A='5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(R,`IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(D=E
M9OQH;'1E(%1E;7!E<F%T=7(Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R
M(")697)E:6YZ96QT92!38VAA=65R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B
M"FUS9W-T<B`B5F5R96EN>F5L=&4@4V-H;F5E<V-H875E<B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C(*;7-G:60@(D9I96QD(&UA=')I>"(*
M;7-G<W1R(")&96QD;6%T<FEX(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S,T,PIM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B1FEG;&5T
M($-!4%1#2$$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S0W"FUS
M9VED(")&:6=L970@9F]N="(*;7-G<W1R(")&:6=L970M1F]N="(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B1FED<V-H:2(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-PIM<V=I9"`B1FEL92(*;7-G<W1R
M(")$871E:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B
M06YZ86AL.B`E<R!$871E:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S
M(@IM<V=S='(@(D%N>F%H;#H@)7,@1&%T96EE;B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,#D*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R
M(")$871E:6UA;F%G97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M,@IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(D1A=&5I;F%M92(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34*;7-G:60@(D9I;&4@<V5L96-T
M:6]N(@IM<V=S='(@(D1A=&5I875S=V%H;"(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T.#8*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(D1A
M=&5I+4AO8VAL861E;B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N
M<&AP.CDP,`IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM
M<V=S='(@(D1A<R!(;V-H;&%D96X@=F]N($1A=&5I96X@=VER9"!N:6-H="!U
M;G1E<G-T_'1Z="XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3$*
M;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B1FEL=&5R(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM
M<V=I9"`B1FEN;&%N9"(*;7-G<W1R(")&:6YN;&%N9"(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B17)S
M=&4@2.1L9G1E(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C
M:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R(")%
M<G-T97,@5FEE<G1E;"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR-3<*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R(")697)H
MY&QT;FES('IU<OQC:W-E='IE;B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,S(*;7-G:60@(D9L:7`B"FUS9W-T<B`B56UD
M<F5H96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R(")497AT9FQUWR(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS
M9VED(")&;V<B"FUS9W-T<B`B3F5B96PB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C(X,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`V
M"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES
M="(*;7-G<W1R(")$87,@5F5R>F5I8VAN:7,@)7,@97AI<W1I97)T(&YI8VAT
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R(")38VAR:69T9F%R8F4B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T
M<B`B17-S96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T
M(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(D;\<B!"<F]W<V5R+"!D
M:64@:V5I;F4@0FEL9&5R('5N=&5R<W3\='IE;B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S,V"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R(")6
M;W)H97)S86=E("A4048I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C<R"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE
M(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT
M.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I
M9&4@8FQO8VLI(@IM<V=S='(@(B(*(E9O<FAE<F=E<V%G=&4@5&%G92`H5F]R
M:&5R<V%G96X@96YT:&%L=&5N(%1A9V4@=6YD($[D8VAT92P@96EN(&AO:&5R
M(%=E<G0@(@HB:V%N;B!Z=2!E:6YE;2!S96AR(&=R;]]E;B!";&]C:R!F_&AR
M96XI(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@
M(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R(")087-S=V]R="!V97)G
M97-S96X_(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V-`IM<V=I
M9"`B1F]R;7,B"FUS9W-T<B`B1F]R;75L87)E(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(D=L_&-K<VME
M:W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U
M;F4@='EP92(*;7-G<W1R(")';/QC:W-K96MS='EP(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R(")';/QC
M:W-K96MS92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B
M1F]R='5N97,@,B(*;7-G<W1R(")';/QC:W-K96MS92`R(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0U-0IM<V=I9"`B1F]R=6US(@IM<V=S='(@
M(D9O<F5N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q,0IM<V=I
M9"`B1F]R=V%R9',B"FUS9W-T<B`B5V5I=&5R;&5I='5N9R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R
M(@IM<V=S='(@(D9R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@(E)A
M:&UE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92(*;7-G<W1R(")&<F%N
M:W)E:6-H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS
M9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R(")%=7)O<.1I<V-H
M97,@1G)A;FMR96EC:"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(S"FUS9VED(")&<F5E>FEN9R!$<FEZ>FQE(@IM<V=S='(@
M(D=E9G)I97)E;F1E<B!296=E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC
M:"!'=6EA;F$B"FUS9W-T<B`B1G)A;GKV<VES8V@M1W5A>6%N82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(D9R86YZ
M]G-I<V-H+5!O;'EN97-I96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC
M:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R(")&<F%N>O9S:7-C:&4@
M1V5B:65T92!I;2!S_&1L:6-H96X@26YD:7-C:&5N($]Z96%N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B
M1G)O;2(*;7-G<W1R(")6;VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#D*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-0IM<V=I9"`B1G)O;2!T
M:&4@(@IM<V=S='(@(D%U<R`B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R(")6
M;VQL<W3D;F1I9V4@0F5S8VAR96EB=6YG(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O
M;B(*;7-G<W1R(")6;VQL;6]N9"(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HV-2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"FUS9VED
M(")&=6QL($YA;64B"FUS9W-T<B`B5F]L;'-TY&YD:6=E<B!.86UE(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B1V%B=6XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@
M(D)I;&1E<B!A=7,@9&EE<V5R($=A;&5R:64B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@
M(D=A;&QE<GDZ(@IM<V=S='(@(D=A;&5R:64Z(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I
M9"`B1V%M8FEA(@IM<V=S='(@(D=A;6)I82(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@
M0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(E<RU+;VYF:6=U<F%T:6]N(&5R>F5U
M9V5N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*
M;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(D5R>F5U9W1E<B!#;V1E
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R(")'96]R9VEE
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B1&5U='-C
M:&QA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N82(*;7-G<W1R(")':&%N
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R(")':6)R
M86QT87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M-@IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R(")6;W)N86UE(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W.2!T96UP;&%T97,O<')E9G,O
M87!P+FEN8SHQ,`HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ.0IM<V=I
M9"`B1VQO8F%L($]P=&EO;G,B"FUS9W-T<B`B06QL9V5M96EN92!%:6YS=&5L
M;'5N9V5N(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3<*;7-G:60@
M(D=O(@IM<V=S='(@(DQO<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(D=O961E;"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3,Q"FUS9VED(")';V]G
M;&4@36%P<R(*;7-G<W1R(")';V]G;&4@36%P<R(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B
M1V]O9VQE(%-U8VAE(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(S.`IM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(D=R875S
M='5F96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@(D=R
M:65C:&5N;&%N9"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED
M(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B1W)I96-H:7-C:"`H25-/
M+3@X-3DM-RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T
M<B`B1W+V;FQA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S
M='(@(D=R96YA9&$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$X-0IM<V=I9"`B
M1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B1W)U<'!E;G9E<G=A;'1U
M;F<B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S
M(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(D=R=7!P96YN86UE;B!D_')F
M96X@;FEC:'0@;&5E<B!S96EN(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P
M.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED.B`B"FUS9W-T<B`B(@HB1W)O=7!?;&1A<#H@1&EE($=R=7!P
M92`E<R!K;VYN=&4@;FEC:'0@:&EN>G5G96;\9W0@=V5R9&5N+B!-96QD=6YG
M(&1E<R`B"B)397)V97)S.B`B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ
M,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E
M(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD87`Z($1I92!'<G5P<&4@)7,@
M:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;B(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P
M.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD
M87`Z($1I92!'<G5P<&4@)7,@:V]N;G1E(&YI8VAT(&%K='5A;&ES:65R="!W
M97)D96XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(T,2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C,Q-`HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.`IM<V=I9"`B1W)O=7!S
M(@IM<V=S='(@(D=R=7!P96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO
M=7!E(@IM<V=S='(@(D=U861E;&]U<&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B
M1W5A;2(*;7-G<W1R(")'=6%M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U871E
M;6%L82(*;7-G<W1R(")'=6%T96UA;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*;7-G<W1R(")'=65R;G-E
M>2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C(V('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z.#D*;7-G:60@(D=U97-T(%!E<FUI<W-I
M;VYS(@IM<V=S='(@(D=A<W1R96-H=&4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#<R"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B1^1S=&5B
M=6-H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@(D=U:6YE
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R
M(")'=6EN96$M0FES<V%U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA;F$B
M"FUS9W-T<B`B1W5Y86YA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.38P"FUS9VED(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M96QL(&EN(')O=RXB"FUS9W-T<B`B1&5R($5D:71O<B!K86YN(&1I92!L971Z
M=&4@6F5L;&4@96EN97(@6F5I;&4@;FEC:'0@;/9S8VAE;BXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS
M9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(D1E<B!%9&ET;W(@:V%N
M;B!D:64@;&5T>G1E(%-P86QT92!E:6YE<B!486)E;&QE(&YI8VAT(&SV<V-H
M96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R(")$97(@
M161I=&]R(&MA;FX@9&EE(&QE='IT92!:96EL92!E:6YE<B!486)E;&QE(&YI
M8VAT(&SV<V-H96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H
M<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")(5%10+4%U=&AE;G1I9FEZ:65R=6YG(&YI8VAT(&=E9G5N9&5N
M+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B2&%I=&DB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@
M(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(DAA<V@M06QG;W)I=&AM=7,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I
M9"`B2&%Z92(*;7-G<W1R(")$:65S:6<B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY,3D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,@IM<V=I
M9"`B2&5A9&5R(@IM<V=S='(@(MQB97)S8VAR:69T(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R
M<R(*;7-G<W1R(")+;W!F96EN='+D9V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@
M(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R(")(
M96%R9"T@=6YD($UC1&]N86QD:6YS96QN(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DAE879Y(%0M4W1O<FTB
M"FUS9W-T<B`B4V-H=V5R92!'97=I='1E<B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@Y"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T
M<B`B2&5B<N1I<V-H("A)4T\M.#@U.2TX+4DI(@H*(SH@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z,C(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(DCV:&4B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@T(&9R86UE=V]R
M:R](;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TUE;G4N<&AP.C$W-2!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ
M-PHC.B!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z-`IM<V=I9"`B2&5L<"(*
M;7-G<W1R(")(:6QF92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S
M='(@(D5D:71O<FAI;&9E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,W,0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(DAI;&9E(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@(DAE
M;6ES<&AE<F4B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T
M:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R(")$:65S(&ES="!D
M97(@0F5G:6YN(&1E<B!$871E:3HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HW,PIM<V=I9"`B2&EG:"(*;7-G<W1R(")(;V-H
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A
M9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"FUS9VED(")(;U]M92(*;7-G<W1R
M(")?4W1A<G1S96ET92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E
M("A6871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(E9A=&EK86YS=&%D="(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM
M<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D%D<F5S<V4@<')I=F%T(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"FUS9VED(")(;VUE($1I<F5C
M=&]R>2(*;7-G<W1R(")(96EM=F5R>F5I8VAN:7,B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H
M;VYE(@IM<V=S='(@(E1E;&5F;VX@<')I=F%T(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS
M9VED(")(;VYD=7)A<R(*;7-G<W1R(")(;VYD=7)A<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(DAO;F<@2V]N9R(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-PIM<V=I9"`B2&]R9&4B"FUS9W-T
M<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!8
M34P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO
M<F1E+TMO;&%B.B!5;F?\;'1I9V4@)7,M6$U,+41A=&5N(&EN($YA8VAR:6-H
M="`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDV"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E
M<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@17,@
M<&%S<W0@:V5I;F4@3F%C:')I8VAT('IU;2!/8FIE:W0@)7,B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@
M;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@2V5I;B!/8FIE:W0@
M=F]M(%1Y<"`E<R!I;B!.86-H<FEC:'0@)7,@9V5F=6YD96XB"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R.#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<
M(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@)7,@7"(E<UPB('=U<F1E(&5R9F]L
M9W)E:6-H(&5N=&9E<FYT(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG
M:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S
M='(@(B(*(DAO<F1E+TMO;&%B.B!$:64@26YT96=R871I;VYS9G5N:W1I;VYE
M;B!B96[V=&EG96X@9&EE(%PB9&]M>&UL7"(@4$A0+2(*(D5R=V5I=&5R=6YG
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,S@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W
M(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B(@HB2&]R9&4O2V]L
M86(Z($;\<B!D87,@3V)J96MT("5S(&MO;FYT92!K96EN(&YE=65R(%A-3"U"
M875M(&5R>F5U9W0@=V5R9&5N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HQ,C@R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O
M2V]L86(Z("5S(%PB)7-<(B!K;VYN=&4@;FEC:'0@96YT9F5R;G0@=V5R9&5N
M.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3`Y"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE
M=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R("(B
M"B)(;W)D92]+;VQA8CH@1&EE($U)344M240@9&5S($%B<V-H;FET=',@=F]M
M(%1Y<"`E<R!K;VYN=&4@;FEC:'0@(@HB:&5R875S9V5F=6YD96X@=V5R9&5N
M+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(S-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N
M:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z("5S(%PB
M)7-<(B!K;VYN=&4@;FEC:'0@<WEN8VAR;VYI<VEE<G0@=V5R9&5N.B`E<R(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3,V.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E
M('-H87)E<SH@)7,B"FUS9W-T<B`B(@HB2&]R9&4O2V]L86(Z($1I92!G96UE
M:6YS86UE;B!/8FIE:W1E(&MO;FYT96X@;FEC:'0@<WEN8VAR;VYI<VEE<G0@
M=V5R9&5N.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,S8V
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H
M87)E(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@56YB96MA;FYT97,@
M9V5M96EN<V%M97,@3V)J96MT(%PB)7-<(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@
M4G5L92(*;7-G<W1R(")(;W)I>F]N=&%L92!,:6YI92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ
M;VYT86P@<&%D9&EN9R(*;7-G<W1R(")(;W)I>F]N=&%L97(@26YN96YA8G-T
M86YD(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B2&]R:7IO;G1A;#HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E
M(')E<&]R="$I(@IM<V=S='(@(E=I92!S:6YD(%-I92!H:65R:&5R9V5L86YG
M=#\@0FET=&4@86X@9&EE($5N='=I8VML97(@>G5R_&-K;65L9&5N(2DB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O
M(&UE<F=E/R(*;7-G<W1R(")7:64@=FEE;&4@4W!A;'1E;B!S;VQL96X@>G5S
M86UM96YG96;\9W0@=V5R9&5N/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R
M92!T:&5R93\B"FUS9W-T<B`B5VEE=FEE;&4@1F5L9&5R("A3<&%L=&5N*2!G
M:6)T(&5S/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U
M(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(E=I92!V:65L92!:96EL96X@<V]L
M;&5N('IU<V%M;65N9V5F_&=T('=E<F1E;C\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C@Y(&QI8B]";&]C:R]M971A<BYP:'`Z,C,R"FUS
M9VED(")(=6UI9&ET>2(*;7-G<W1R("),=69T9F5U8VAT:6=K96ET(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T.`IM<V=I9"`B2'5M:61I
M='DZ("(*;7-G<W1R("),=69T9F5U8VAT:6=K96ET.B`B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R(")+
M;VUI:V5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S='(@
M(E5N9V%R;B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W
M,B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,U"B,L('!H<"UF
M;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S
M(@IM<V=S='(@(D%N;&5G96X@9&5S($E-05`M4&]S=&9A8VAS(&ES="!F96AL
M9V5S8VAL86=E;CH@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I
M;&5D.B`E<R(*;7-G<W1R("),]G-C:&5N(&1E<R!)34%0+5!O<W1F86-H<R!I
M<W0@9F5H;&=E<V-H;&%G96XZ("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)U<RYP:'`Z,3<Y(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H
M<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A
M(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B1F5S=&QE9V5N(&1E<B!)
M34%0+5!O<W1F86-H+5%U;W1A(&ES="!F96AL9V5S8VAL86=E;CH@)7,B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S$V"FUS9VED("))4"!!9&1R
M97-S(@IM<V=S='(@(DE0+4%D<F5S<V4B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(DE0+4%D<F5S<V4@;FEC:'0@=F5R9OQG8F%R+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@
M(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM
M<V=S='(@(DE0+4%D<F5S<V4@;FEC:'0@:6T@97)L875B=&5N($-)1%(M0FQO
M8VLN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S
M='(@(E9E<FQE='IU;F<@9&5R(&9E<W1G96QE9W1E;B!)4"XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*
M;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R("):96EL92!E:6YF
M_&=E;B!?=F]R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S
M='(@(DES;&%N9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S,*;7-G
M:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B3G5R($)I;&1E<B(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N
M<R!F;W(@)7,B"FUS9W-T<B`B26-O;G,@9OQR("5S(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,W-`IM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S
M='(@(D)I;&1E<B!U;F0@5&5X="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ.#4*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B0F5Z96EC
M:&YU;F<@9&5R($ED96YT:73D="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C8P,`HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I
M<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A
M(&YE=R!W:6YD;W<N(@IM<V=S='(@(B(*(E=E;FX@<VEE(&YI8VAT(&MO<G)E
M:W0@86YG97IE:6=T('=I<F0L("5S+"!U;2!S:64@:6X@96EN96T@;F5U96X@
M1F5N<W1E<B`B"B)A;F=E>F5I9W0@>G4@8F5K;VUM96XN(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0U,@IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E
M92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@
M;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A
M;G-P87)E;F-Y+B(*;7-G<W1R("(B"B)796YN(%-I92!M:70@9&5M($EN=&5R
M;F5T($5X<&QO<F5R(&ME:6YE(%-Y;6)O;&4@<V5H96XL(&W\<W-E;B!3:64@
M9&EE<V5S("(*(DOD<W1C:&5N(&UA<FMI97)E;BP@=6T@4$Y'+51R86YP87)E
M;GH@875S>G5S=&5L;&5N+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ-S(*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M
M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P
M;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*
M;7-G<W1R("(B"B)796YN(%-I92!D:65S92!.86-H<FEC:'0@86X@4W1E;&QE
M(&5I;F4@0FEL9&5S('-E:&5N+"!K86YN($EH<B!"<F]W<V5R(&1A<R`B"B)"
M:6QD+"!D87,@4VEE(&AO8VAL861E;B!M]F-H=&5N(&YI8VAT(&%N>F5I9V5N
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B
M0FEL9'9O<G-C:&%U.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R
M(")":6QD+5523"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G
M<W1R(")":6QD+5523#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@
M9V%L;&5R>2(*;7-G<W1R(")":6QD('9O;B!'86QE<FEE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q
M"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(D)I;&0@=F]N
M($=A;&5R:64Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,0IM
M<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(D)I;&0M2&]C:&QA9&5N(@H*
M(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G
M<W1R(")":6QD97(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW
M('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHU-"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW
M"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R
M("));7!O<G1I97)E;BP@4V-H<FET="`E9"(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D
M(&9I96QD.B`E<R(*;7-G<W1R("));7!O<G1I97)T97,@1F5L9#H@)7,B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E
M9"!F:65L9',Z(@IM<V=S='(@(DEM<&]R=&EE<G1E($9E;&1E<CHB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(EIE:6QE(&5I
M;F;\9V5N(%]N86-H(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+WII<"YP:'`Z,3,T"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV
M96XN(@IM<V=S='(@(E5N9_QL=&EG92!!:W1I;VX@86YG96=E8F5N+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R
M"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*
M;7-G<W1R(")5;F?\;'1I9V5R($)E;G5T>F5R;F%M92!U;F0O;V1E<B!087-S
M=V]R="XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,PIM<V=I
M9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S
M+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)&86QS8VAE
M<B!"96YU='IE<FYA;64@;V1E<B!%+4UA:6PM061R97-S92X@5F5R<W5C:&5N
M(%-I92!E<R!E<FYE=70@;V1E<B`B"B)W96YD96X@4VEE('-I8V@@86X@26AR
M96X@4WES=&5M861M:6YI<W1R871O<BP@=V5N;B!3:64@=V5I=&5R92!(:6QF
M92`B"B)B96[V=&EG96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S
M='(@(D5I;GIU9R!V97)G<O;?97)N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))
M;F1I82(*;7-G<W1R("));F1I96XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-0IM
M<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R(")%:6YZ96QN92!"96YU
M='IE<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@
M(DEN9&]N97-I96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(DEN9F]R;6%T:6]N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U.0IM<V=I9"`B26YF
M;W)M871I;VXB"FUS9W-T<B`B26YF;W)M871I;VYE;B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,3D*;7-G:60@(DEN9F]R;6%T:6]N(&YO
M(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(DEN9F]R;6%T:6]N96X@;FEC
M:'0@;65H<B!V97)F_&=B87(N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHS-0IM<V=I9"`B26YH97)I=&5D($UE;6)E<G,B"FUS9W-T
M<B`B5F5R97)B=&4@36ET9VQI961E<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T
M($-?;VQU;6X@069T97(B"FUS9W-T<B`B7U-P86QT92!D879O<B!E:6YF_&=E
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM86=E(@IM<V=S='(@(D)I
M;&0@:&EN>G5F_&=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R(")4
M86)E;&QE(&5I;F;\9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S
M='(@(DQI;FL@96EN9OQG96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L
M=6UN($)E9F]R92(*;7-G<W1R(")37W!A;'1E(&1A;F%C:"!E:6YF_&=E;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@
M8W5R<F5N="!O;F4B"FUS9W-T<B`B16EN92!N975E(%-P86QT92!N86-H(&1E
M<B!A:W1U96QL96X@96EN9OQG96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A
M(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")%
M:6YE(&YE=64@4W!A;'1E('9O<B!D97(@86MT=65L;&5N(&5I;F;\9V5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R
M96YT(&]N92(*;7-G<W1R(")%:6YE(&YE=64@6F5I;&4@;F%C:"!D97(@86MT
M=65L;&5N(&5I;F;\9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N97<@
M<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B16EN92!N975E
M(%IE:6QE('9O<B!D97(@86MT=65L;&5N(&5I;F;\9V5N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS
M9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D
M92(*;7-G<W1R(")%:6YE;B!N975E;B!!8G-A='H@;F%C:"!D96T@86MT=65L
M;&5N($5L96UE;G0@96EN9OQG96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A
M('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R(")%
M:6YE;B!N975E;B!!8G-A='H@=F]R(&1E;2!A:W1U96QL96X@16QE;65N="!E
M:6YF_&=E;B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("))
M;G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(D%L=&5R;F%T:79E
M(%9O<FQA9V4@96EN9OQG96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C,T"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y
M;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B(@HB
M1V5B96X@4VEE(&5I;F4@12U-86EL+4%D<F5S<V4@86XL(&%N(&1I92!D87,@
M;F5U92!087-S=V]R="!G97-C:&EC:W0@=V5R9&5N("(*(G-O;&PZ(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`B6F5L;&4@9&%N
M86-H(&5I;F;\9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E
M(@IM<V=S='(@(EIE;&QE(&1A=F]R(&5I;F;\9V5N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B
M26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R(")3<&%L=&4@9&%N86-H(&5I
M;F;\9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS
M9W-T<B`B4W!A;'1E(&1A=F]R(&5I;F;\9V5N(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3`*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S86=E
M<R(*;7-G<W1R(").86-H<FEC:'1E;B!H:6YZ=6;\9V5N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS
M9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(D%B<V%T>B!D
M86YA8V@@96EN9OQG96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A
M<&@@8F5F;W)E(@IM<V=S='(@(D%B<V%T>B!D879O<B!E:6YF_&=E;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B6F5I;&4@9&%N
M86-H(&5I;F;\9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B
M"FUS9W-T<B`B6F5I;&4@9&%V;W(@96EN9OQG96XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C(U"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N
M<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(D=E8F5N
M(%-I92!D:64@06YT=V]R="!A=68@9&EE(%-I8VAE<FAE:71S9G)A9V4@96EN
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B0FEL9"!E
M:6YF_&=E;B]B96%R8F5I=&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK
M(@IM<V=S='(@(DQI;FL@96EN9OQG96XO8F5A<F)E:71E;B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED
M("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U
M=&EO;B!L:7-T+B(*;7-G<W1R("):=2!W96YI9R!'=71H86)E;BP@=6T@86X@
M9&EE(%9E<G1E:6QE<FQI<W1E('IU('9E<G-C:&EC:V5N+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED
M("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R("):=2!W96YI9R!'=71H
M86)E;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U"FUS9VED
M("));G1E9V5R(@IM<V=S='(@(D=A;GIZ86AL(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$S,PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@
M(DQI<W1E('9O;B!'86YZ>F%H;&5N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$
M2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R(")5;F?\;'1I9V5R(%5$
M2"X@*%5S97(@1&%T82!(96%D97(I+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]Z:7`N<&AP.C$V-PHC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O>FEP+G!H<#HQ.30*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+WII<"YP:'`Z,C$R"FUS9VED("));G9A;&ED(%I)4"!D871A(@IM
M<V=S='(@(E5N9_QL=&EG92!:25`M1&%T96XN(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS
M9W-T<B`B56YG_&QT:6=E($%N=V5N9'5N9RXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L
M:60@8F%T8V@@240N(@IM<V=S='(@(E5N9_QL=&EG92!"871C:"U)1"XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`U(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Q-S8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(U
M,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$W"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@
M9&%T82!S=6)M:71T960N(@IM<V=S='(@(E5N9_QL=&EG92!$871E;B!E:6YG
M96)E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S
M<RXB"FUS9W-T<B`B56YG_&QT:6=E(%II96QA9')E<W-E+B(*"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P.0HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,SD*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,C0Q"FUS9VED("));G9A;&ED
M(&9I;&4@9F]R;6%T(@IM<V=S='(@(E5N9_QL=&EG97,@1&%T96EF;W)M870B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED("))
M;G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R(")5;F?\;'1I9V5R($QI>F5N
M>G-C:&S\<W-E;"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,34Y"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R
M(")5;F?\;'1I9V5R($]R="!A;F=E9V5B96XN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A
M;&ED(&US9U]T>7!E+B(*;7-G<W1R(")5;F?\;'1I9V5R(&US9U]T>7!E+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T
M<B`B56YG_&QT:6=E(&]D97(@9F5H;&5N9&4@87!I7VED+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I
M9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(E5N
M9_QL=&EG92!O9&5R(&9E:&QE;F1E(%!A<F%M971E<BXB"@HC.B!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E
M<FUI<W-I;VXN(@IM<V=S='(@(E5N9_QL=&EG97,@W&)E<G)E8VAT+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*;7-G:60@(DEN=F%L
M:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B56YG_&QT:6=E(%!A<G1N97(M240N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B
M26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(E5N9_QL=&EG97(@4')O
M9'5K=&-O9&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G
M<W1R(")5;F?\;'1I9V5S(%!R;W1O:V]L;"XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A
M;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@(E5N9_QL=&EG97(@16UP
M9N1N9V5R.B!<(B5S7"(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$Q,3<@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,CDW"FUS9VED("))
M;G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R(")5;F?\;'1I9V5S(&=E;65I
M;G-A;65S($]B:F5K="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D
M<F5S<RXB"FUS9W-T<B`B56YG_&QT:6=E(%5R<W!R=6YG<V%D<F5S<V4N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$Q"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B56YG
M_&QT:6=E(%5N:6-O9&4M1&%T96XN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,U.0IM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(DEN=F5N=&%R
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W
M.`IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*;7-G<W1R(")!=7-W86AL('5M
M:V5H<F5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E
M<'5B;&EC(&]F(@IM<V=S='(@(DES;&%M:7-C:&4@4F5P=6)L:6L@27)A;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("))<F%K(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@(DER;&%N9"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F
M($UA;B(*;7-G<W1R("))<VQE(&]F($UA;B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"FUS9VED("))<V]L871E9"!4+5-T
M;W)M<R(*;7-G<W1R(")697)E:6YZ96QT92!'97=I='1E<B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,`IM<V=I9"`B27-R865L(@IM<V=S='(@(DES<F%E;"(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(V"FUS9VED("))<W-U97(B
M"FUS9W-T<B`B075S<W1E;&QE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(DMU
M<G-I=B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B271A;'DB"FUS9W-T<B`B271A
M;&EE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R(")*
M86UA:6MA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B2F%N=6%R(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@S"FUS9VED(")*87!A;B(*;7-G<W1R(")*87!A;B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M
M2E`I(@IM<V=S='(@(DIA<&%N:7-C:"`H25-/+3(P,C(M2E`I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G
M<W1R(")*97)S97DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G
M<W1R(")*;W)D86YI96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R(")*=6QI(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@
M(DIU;F4B"FUS9W-T<B`B2G5N:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS
M9W-T<B`B0FQO8VMS871Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R
M(@IM<V=S='(@(EIE;G1R:65R96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&
M=6QL(@IM<V=S='(@(D)L;V-K<V%T>B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y
M($QE9G0B"FUS9W-T<B`B3&EN:W,@875S<FEC:'1E;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED
M(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(E)E8VAT<R!A=7-R:6-H=&5N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(DMA<V%C
M:'-T86XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C8U"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G<W1R(")/<FEG:6YA
M;"!B96EB96AA;'1E;C\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DME;GEA(@IM
M<V=S='(@(DME;FEA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H
M<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R(")+97)B97)O<RU397)V97(@:&%T($%U=&AE;G1I
M9FEZ:65R=6YG('IU<OQC:V=E=VEE<V5N+B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B2V5R
M;F5L+4YE=6QI;F=E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#$Q"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B4V-H;/QS<V5L
M97)Z975G=6YG(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B1FEN9V5R86)D
M<G5C:R!D97,@4V-H;/QS<V5L<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R(")38VAL
M_'-S96QLY&YG92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B4V-H;/QS<V5L='EP(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3D*;7-G:60@
M(DME>2!5<V%G92(*;7-G<W1R(")38VAL_'-S96QZ=V5C:R(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A
M9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B
M"B)$97(@4V-H;/QS<V5L(&)E9FEN9&5T('-I8V@@8F5R96ET<R!A=68@9&5M
M(/9F9F5N=&QI8VAE;B!38VAL_'-S96QS97)V97(N(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(DMI;F1E<B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B2VER:6)A
M=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E
M;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(D1E;6]K<F%T:7-C:&4@5F]L
M:W-R97!U8FQI8R!+;W)E82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(E)E<'5B;&EK($MO<F5A(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*
M;7-G<W1R(")+;W)E86YI<V-H("A%54,M2U(I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS
M9VED(")+=7=A:70B"FUS9W-T<B`B2W5W86ET(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS
M9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(DMI<F=I<VES=&%N(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S
M='(@(D%N7W!A<W-E;B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(E-P<F%C:&4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC
M(@IM<V=S='(@(DQA;W,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS
M9VED("),87-T($AA;&8B"FUS9W-T<B`B3&5T>G1E($CD;&9T92(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HX.`IM<V=I9"`B3&%S="!087-S=V]R9"!#
M:&%N9V4B"FUS9W-T<B`B3&5T>G1E(%!A<W-W;W)TY&YD97)U;F<B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS
M9VED("),87-T(%%U87)T97(B"FUS9W-T<B`B3&5T>G1E<R!6:65R=&5L(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3,*;7-G:60@(DQA<W0@57!D871E
M9#HB"FUS9W-T<B`B3&5T>G1E($%K='5A;&ES:65R=6YG.B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED("),
M87-T(&QO9VEN.B`E<R(*;7-G<W1R("),971Z=&4@06YM96QD=6YG.B`E<R(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(DQE='IT
M92!!;FUE;&1U;F<Z("5S('9O;B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.C<Q-`IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B
M3&5T>G1E($%N;65L9'5N9SH@3F]C:"!N:64B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G
M:60@(DQA='9I82(*;7-G<W1R("),971T;&%N9"(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(D=E<V5T>B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(D9O<FUA="(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E
M(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B3&5E<B!L87-S96X@9OQR
M(&ME:6YE;B!286AM96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB
M"FUS9W-T<B`B3&EB86YO;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R("),
M:6YK<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3D*;7-G:60@
M(DQE9G0@:&5A9&5R(@IM<V=S='(@(DQI;FME(-QB97)S8VAR:69T(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-0IM<V=I9"`B3&5F="!V86QU
M97,B"FUS9W-T<B`B3&EN:V4@5V5R=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@
M(DQE<V]T:&\B"FUS9W-T<B`B3&5S;W1H;R(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(U-PIM<V=I9"`B3&5V96PB"FUS9W-T<B`B16)E;F4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B3&EB97)I
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY
M82(*;7-G<W1R("),:6)Y96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI96-H
M=&5N<W1E:6XB"FUS9W-T<B`B3&EE8VAT96YS=&5I;B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!$
M<FEZ>FQE(@IM<V=S='(@(E-P<OQH<F5G96XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B(*
M;7-G<W1R("),96EC:'1E<B!296=E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN($5A<FQY
M(@IM<V=S='(@(D9R_&@@;&5I8VAT97(@4F5G96XB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I
M;B!,871E(@IM<V=S='(@(E-PY'1E<B!,96EC:'1E<B!296=E;B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),
M:6=H="!286EN(%-H;W=E<B(*;7-G<W1R("),96EC:'1E(%)E9V5N<V-H875E
M<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R
M"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R("),96EC
M:'1E<B!296=E;B!M:70@1V5W:71T97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B3&EG:'0@4VYO=R(*;7-G
M<W1R("),96EC:'1E<B!38VAN965F86QL(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G:60@(DQI9VAT(%-N;W<@4VAO
M=V5R(@IM<V=S='(@(DQE:6-H=&4@4V-H;F5E<V-H875E<B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B
M3&EM97)I8VLB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$T"FUS
M9VED("),:6YK(@IM<V=S='(@(DQI;FLB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#$W"FUS9VED("),:6YK(%523"(*;7-G<W1R("),:6YK+552
M3"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,S(*;7-G:60@(DQI
M;FL@86-C97-S(&ME>2(*;7-G<W1R("),:6YK+5IU9W)I9F9S=&%S=&4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G<W1R("),:6YK('9E
M<G=E:7-T(&%U9CHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#(S
M"FUS9VED("),:6YK('1A<F=E="(*;7-G<W1R("),:6YK+5II96PB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#(P"FUS9VED("),:6YK('1E>'0B
M"FUS9W-T<B`B3&EN:RU497AT(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@Y,PIM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@
M8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R(")%+4UA:6PM
M061R97-S92!V97)L:6YK96X_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@R.0IM<V=I9"`B3&EN:R!T:71L92!A='1R:6)U=&4B"FUS9W-T<B`B
M3&EN:RU4:71L92U!='1R:6)U="(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#(*;7-G:60@(DQI;FMS(@IM<V=S
M='(@(DQI;FMS(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED
M("),:6YU>"!#;V]K:64B"FUS9W-T<B`B3&EN=7@M1VS\8VMS:V5K<V4B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT-@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B
M3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(DQI<W0@
M+2!"96YU='IE<B!K86YN(&1E;B!/<F1N97(@<V5H96XB"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3,T"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R
M(")$871E;F)A;FME;B!A;GIE:6=E;B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD
M97@N<&AP.C4R"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(DAI
M;&9E96EN='+D9V4@86YZ96EG96XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3,S"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R(")486)E;&QE;B!A;GIE
M:6=E;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-C`Q
M"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B3&ES=&5N+4%R8VAI=B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED
M("),:7-T+4AE;'`B"FUS9W-T<B`B3&ES=&5N+4AI;&9E(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12](96%D97)S+G!H<#HV,#,*;7-G:60@(DQI<W0M260B
M"FUS9W-T<B`B3&ES=&5N+4ED(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.3D*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B3&ES
M=&5N+4)E<VET>F5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S
M+G!H<#HV,#`*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R("),:7-T96XM061R
M97-S92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DX
M"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("),:7-T96XM06YM96QD
M=6YG(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3<*
M;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B3&ES=&5N+4%B;65L
M9'5N9R(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`B
M1&%S($%N>F5I9V5N(&1E<B!397-S:6]N<R!I<W0@9F5H;&=E<V-H;&%G96XZ
M("5S(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,W"B,L('!H<"UF;W)M870*
M;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R(")$87,@
M06YZ96EG96X@9&5R($)E;G5T>F5R(&ES="!F96AL9V5S8VAL86=E;CH@)7,B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@
M(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(D1A<R!!;GIE
M:6=E;B!D97(@0F5N=71Z97(@:7-T(&YI8VAT(&WV9VQI8V@N(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S
M='(@(DQI=&5R871U<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&ET:'5A;FEA
M(@IM<V=S='(@(DQI=&%U96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I;6%G97,N<&AP.C<W"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@
M(DQA9&4N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`P
M"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B3&]K86QE(%5H<GIE:70Z
M("(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-@IM<V=I9"`B3&]C86QE
M(&%N9"!4:6UE(@IM<V=S='(@(E-P<F%C:&4@=6YD(%IE:70B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-3<*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R
M(&QI8B]";&]C:R]M971A<BYP:'`Z-S(*;7-G:60@(DQO8V%T:6]N(@IM<V=S
M='(@(D]R="(*"B,Z(&QO9VEN+G!H<#HQ.#D@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C(P-"!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I;B(*;7-G<W1R(")!;FUE;&1E
M;B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-PIM<V=I9"`B
M3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R("),;V<@9&5R
M(&QE='IT96X@4WEN8VAR;VYI<V%T:6]N+B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HQ.3@*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B06)M
M96QD96XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$*;7-G:60@(DQO
M9VEN(@IM<V=S='(@(D%N;65L9&5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q,`IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B06YM96QD96%U
M9F=A8F5N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DU"FUS9VED
M("),;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W
M;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)$:64@
M06YM96QD=6YG(&ES="!F96AL9V5S8VAL86=E;BP@=V5I;"!3:64@26AR96X@
M0F5N=71Z97)N86UE;B!O9&5R($EH<B`B"B)087-S=V]R="!F86QS8V@@96EN
M9V5G96)E;B!H86)E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.3$*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B06YM96QD=6YG(&9E
M:&QG97-C:&QA9V5N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S
M-C4*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R("),86YG97(@5&5X="(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R
M("),:65B92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C<Q"FUS9VED("),;W<B"FUS9W-T<B`B3FEE9')I9R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*
M;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B2VPN(&=R:65C
M:&ES8VAE($)U8VAS=&%B96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I
M;B!L971T97)S(@IM<V=S='(@(DML+B!L871E:6YI<V-H92!"=6-H<W1A8F5N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R
M(")+;"X@<O9M:7-C:&4@6F%H;&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),
M=7AE;6)O=7)G(@IM<V=S='(@(DQU>&5M8G5R9R(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#$*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.2!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C@S"FUS9VED(")-3U1$(@IM<V=S='(@(DU/5$0B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM
M<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*
M;7-G<W1R(")-4RU43D5&+4%N:&%N9R!E;G1H:65L="!K96EN92!$871E;BXB
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B2$E.5T5)
M4R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T<B`B36%C86\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9
M=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R(")$:64@96AE;6%L:6=E($IU
M9V]S;&%W:7-C:&4@4F5P=6)L:6L@36%Z961O;FEE;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R(")-861A9V%S:V%R(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"FUS9VED(")-86=I8R(*;7-G<W1R
M(")-86=I92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,PIM<V=I
M9"`B36%I;"(*;7-G<W1R(")796)M86EL(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C4R-`IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R(")%+4UA
M:6P@061M:6YI<W1R871I;VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN
M+BXB"FUS9W-T<B`B3&EN:R!?86YL96=E;BXN+B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM
M<V=I9"`B36%L87=I(@IM<V=S='(@(DUA;&%W:2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM
M<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B36%L87ES:6$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(DUA;&ED:79E;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,@IM<V=I9"`B36%L:2(*;7-G<W1R(")-86QI(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDT"FUS9VED(")-86QT82(*;7-G<W1R(")-86QT82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-`IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F
M(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD
M(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB
M"FUS9W-T<B`B(@HB5F5R=V%L=&5N(%-I92!D:64@2V%T96=O<FEE;BP@;6ET
M(&1E;F5N(%-I92!%;&5M96YT92!U;F0@16EN='+D9V4@(@HB:V5N;GIE:6-H
M;F5N(&OV;FYE;BP@<V]W:64@9&EE('IU9V5H]G)I9V5N($9A<F)E;BXB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U-@IM
M<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(DUA<#(T+4MA<G1E(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#<*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-S$*;7-G:60@
M(DUA<%%U97-T(&UA<"(*;7-G<W1R(")-87!1=65S="U+87)T92(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@
M<W1O<F5D+B(*;7-G<W1R("):=6]R9&YU;F=E;B!G97-P96EC:&5R="XB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I
M9"`B36%R8V@B"FUS9W-T<B`B3>1R>B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*
M;7-G<W1R(")!==]E;F%B<W1A;F0B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,T,S$T+G!H<#HT.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N
M(&9L86=S(@IM<V=S='(@(DUI="!'96QE<V5N+2]5;F=E;&5S96XM4W1A='5S
M('9E<G-E:&5N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q
M-"YP:'`Z-#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O
M<G1A;G0O06YS=V5R960I(@IM<V=S='(@(DUI="!A;F1E<F5M(%-T871U<R!V
M97)S96AE;B`H>BY"+B!7:6-H=&EG+T)E86YW;W)T970I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(DUA<G-H86QL
M:6YS96QN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E(@IM<V=S
M='(@(DUA<G1I;FEQ=64B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(EIU9V5O<F1N
M971E($9E;&1E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*
M;7-G<W1R(")-875R971A;FEE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U
M<FET:75S(@IM<V=S='(@(DUA=7)I=&EU<R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L
M;&]W960@8W)E9&ET+B(*;7-G<W1R(")-87AI;6%L(&5R;&%U8G1E<B!+<F5D
M:70N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB
M"FUS9W-T<B`B36%X:6UA;&4@3F%C:'1I8VAT96YT96EL92#\8F5R<V-H<FET
M=&5N+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`X"FUS9VED(")-87@@
M=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B2/9C:'-T=&5M<&5R871U
M<B!D97(@;&5T>G1E;B`R-"!3='5N9&5N.B`B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,P,`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS
M9W-T<B`B2/9C:'-T=&5M<&5R871U<B!D97(@;&5T>G1E;B`V(%-T=6YD96XZ
M("(*"B,Z(&QI8B]A<&DN<&AP.C$X,0IM<V=I9"`B36%X:6UU;2!.=6UB97(@
M;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R(")-87AI;6%L92!!;GIA:&P@86X@
M4&]R=&%L8FSV8VME;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y
M."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S
M='(@(DUA>&EM86QE($SD;F=E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R(")-86DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@(DUA>6]T=&4@
M27-L86YD(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-
M961I8VEN92(*;7-G<W1R(")-961I>FEN(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*;7-G<W1R(")-
M:71G;&EE9&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-0IM<V=I
M9"`B365N=2!M;V1E.B(*;7-G<W1R(")-96[\;6]D=7,Z(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I
M9"`B365R9V4@8V5L;',B"FUS9W-T<B`B6F5L;&5N('IU<V%M;65N9OQG96XB
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(U-PIM<V=I9"`B365S<V%G92(*;7-G<W1R(").86-H<FEC:'0B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B
M(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N
M97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM
M<V=S='(@(B(*(D1I92!.86-H<FEC:'0@:V]N;G1E(&5R9F]L9W)E:6-H(/QB
M97)P<OQF="!W97)D96X@86)E<B!N:6-H="!D87,@6F5R=&EF:6MA="`B"B)D
M97,@06)S96YD97)S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S<V%G92!E>'!I<F5D+B(*
M;7-G<W1R(").86-H<FEC:'0@;FEC:'0@;65H<B!G_&QT:6<N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(V,`IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(DYA8VAR:6-H
M=&5N='EP(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A
M<B!796%T:&5R(@IM<V=S='(@(DUE=&%R(%=E='1E<B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B
M;&4N(@IM<V=S='(@(DUE=&%R8FQO8VL@;FEC:'0@=F5R9OQG8F%R+B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED("(B"B)-971A<B!B;&]C
M:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R
M('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)-971A<F)L;V-K(&YI
M8VAT('9E<F;\9V)A<BX@1&5T86EL<R!W=7)D96X@9OQR(&1E;B!!9&UI;FES
M=')A=&]R(&UI=&=E;&]G9W0N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$U,PIM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*
M;7-G<W1R(")+96EN92!697)B:6YD=6YG('IU<B!-971A<D1"+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM
M<V=S='(@(DUE=&AO9&4B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N
M<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM
M<V=S='(@(D1I92!-971H;V1E(%PB)7-<(B!I<W0@;FEC:'0@9&5F:6YI97)T
M(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D
M.B`E<R(*;7-G<W1R(")-971H;V1E(&YI8VAT(&1E9FEN:65R="X@075F9V5R
M=69E;F4@365T:&]D93H@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,@IM<V=I9"`B365T<FEC
M(@IM<V=S='(@(DUE=')I<V-H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-97AI
M8V\B"FUS9W-T<B`B365X:6MO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O
M;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B1O9D97)I97)T
M92!3=&%A=&5N('9O;B!-:6MR;VYE<VEE;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@IM<V=I9"`B36ED9&QE
M(@IM<V=S='(@(DUI='1E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R(")-:6UE
M='EP(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3(*;7-G:60@(DUI;B!T
M96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")4:65F<W1T96UP97)A='5R
M(&1E<B!L971Z=&5N(#(T(%-T=6YD96XZ("(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S`T"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G
M<W1R(")4:65F<W1T96UP97)A='5R(&1E<B!L971Z=&5N(#8@4W1U;F1E;CH@
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@
M(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS
M9W-T<B`B1&%S(&UI;FEM86QE(%!A<W-W;W)T86QT97(@:7-T(&YO8V@@;FEC
M:'0@86)G96QA=69E;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,S4*;7-G:60@(DUI<G)O<B(*;7-G<W1R(")3<&EE9V5L
M;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L
M;&%N96]U<R(*;7-G<W1R(")697)S8VAI961E;F5S(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-
M:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(E!%
M05(M4&%K970@2%144%]297%U97-T(&9E:&QT+B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ,30*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO
M;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O
M('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"B)&96AL96YD
M92!+;VYF:6=U<F%T:6]N+B!3:64@;?QS<V5N(&1I97-E(&IE='IT(&5R>F5U
M9V5N+"!W96YN(%-I92!D:64@(@HB06YW96YD=6YG('9E<G=E;F1E;B!M]F-H
M=&5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R
M(")&96AL96YD92!.86-H<FEC:'1E;BU)1"XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES
M<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B4$5!
M4BU086ME="!-86EL(&9E:&QT+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S
M:6]N($E$+B(*;7-G<W1R(")&96AL96YD92!3:71Z=6YG<RU)1"XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED
M(")-;R(*;7-G<W1R(")-;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HW-@IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B12U-86EL($UO8FEL
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*
M;7-G:60@(DUO9&5R871E(@IM<V=S='(@(DWDWVEG(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#4*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T
M<B`BQ&YD97)U;F=S9&%T=6TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB
M"FUS9W-T<B`B55),(&)E87)B96ET96XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8W-`IM<V=I9"`B36]D=6QU<R(*;7-G<W1R(")-
M;V1U;'5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI
M8R!O9B(*;7-G<W1R(")297!U8FQI:R!-;VQD874B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*
M;7-G:60@(DUO;F%C;R(*;7-G<W1R(")-;VYA8V\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*
M;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(DUO;F=O;&5I(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C8P,@IM<V=I9"`B36]N=&@@86YD('EE87(B
M"FUS9W-T<B`B36]N870@=6YD($IA:'(B"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S
M='(@(DUO;F%T;&EC:"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A
M="(*;7-G<W1R(")-;VYT<V5R<F%T(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*
M;7-G<W1R(")-;VYD<&AA<V5N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z,3DV(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(X,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D
M('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R(")-96AR($9E;&1E<B!I
M;B!:96EL92`E9"!A;',@9&EE(&5R=V%R=&5T96X@)60@9V5F=6YD96XN(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(DUA<F]K:V\B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM
M<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(MQB97)W:65G96YD(&AE:71E
M<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V
M"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(MQB97)W:65G96YD($)E
M=_9L:W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS-PIM<V=I9"`B36]S=&QY($-L;W5D>2!A;F0@5VEN9'DB"FUS9W-T<B`B
MW&)E<G=I96=E;F0@0F5W]FQK="!U;F0@5VEN9&EG(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(DUO<W1L>2!3
M=6YN>2(*;7-G<W1R("+<8F5R=VEE9V5N9"!3;VYN:6<B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T.`IM<V=I9"`B
M36]V92!$;W=N(@IM<V=S='(@(DYA8V@@=6YT96XB"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U,@IM<V=I9"`B36]V
M92!,969T(@IM<V=S='(@(DYA8V@@;&EN:W,B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U-@IM<V=I9"`B36]V92!2
M:6=H="(*;7-G<W1R(").86-H(')E8VAT<R(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0T"FUS9VED(")-;W9E(%5P
M(@IM<V=S='(@(DYA8V@@;V)E;B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HU,C8*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R
M(").86-H('5N=&5N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4R-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-3(V"FUS9VED(")-;W9E('5P(@IM<V=S='(@(DYA8V@@;V)E
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R(")-
M;W-A;6)I:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,#(*;7-G
M:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R(")!=7-W
M86AL;&ES=&4@:6X@;65H<F5R96X@16)E;F5N(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-3D*;7-G:60@(DUU;'1I;6%P
M(%5+(&UA<"(*;7-G<W1R(")-=6QT:6UA<"U52RU+87)T92(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C`*;7-G:60@(DUU;'1I<&QE('-E;&5C
M=&EO;B(*;7-G<W1R(")-96AR9F%C:&%U<W=A:&PB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#`R"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@
M(DUE:6X@2V]N=&\B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*;7-G
M:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B365I;B!+;VYT
M;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-#0*;7-G:60@(DUY
M(%!O<G1A;"(*;7-G<W1R(")-96EN(%!O<G1A;"(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]E9&ET+G!H<#HT,@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G
M<W1R(")-96EN(%!O<G1A;&QA>6]U="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B
M37EA;FUA<B(*;7-G<W1R(")"=7)M82(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@
M06=R964B"FUS9W-T<B`B3D5)3BP@:6-H('-T:6UM92!.24-(5"!Z=2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").86UE(@IM<V=S
M='(@(DYA;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T
M<B`B3F%M:6)I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T
M<B`B3F%U<G4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@
M(DYE<&%L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").971H97)L86YD<R(*;7-G
M<W1R(").:65D97)L86YD92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L
M86YD<R!!;G1I;&QE<R(*;7-G<W1R(").:65D97)LY&YD:7-C:&4@06YT:6QL
M96XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM
M<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B3F5T<V-A<&4M0F%S
M:7,M55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.#0*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@
M(DYE='-C87!E+4-!+5-P97)R=6YG<RU54DPB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L
M:6-Y(%523"(*;7-G<W1R(").971S8V%P92U#02U2:6-H=&QI;FEE;BU54DPB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I
M9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B3F5T<V-A<&4M6F5T
M:69I:V%T<V5R;F5U97)U;F=S+5523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!2979O8V%T:6]N
M(%523"(*;7-G<W1R(").971S8V%P92U3<&5R<G5N9W,M55),(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C
M87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R(").971S8V%P92U34TPM4V5R
M=F5R;F%M92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@X"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S
M='(@(DYE='-C87!E+4MO;6UE;G1A<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!C97)T:69I8V%T
M92!T>7!E(@IM<V=S='(@(DYE='-C87!E+5IE<G1I9FEK871T>7`B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4S"FUS9VED(").971W;W)K(@IM
M<V=S='(@(DYE='IW97)K(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#(U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S(*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,X,PIM<V=I9"`B3F5V97(B"FUS9W-T<B`B3FEE
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDU"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S='(@
M(DYE=6MA;&5D;VYI96XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T
M96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S
M='(@(DYE=64@2V%T96=O<FEE(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V
M(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T
M"FUS9VED(").97<@36]O;B(*;7-G<W1R(").975M;VYD(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N
M86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B3F5U97(@0F5N=71Z97)N86UE("AO
M<'1I;VYA;"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L86YD(@IM
M<V=S='(@(DYE=7-E96QA;F0B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,S<*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R(").975E<R!0
M87-S=V]R="(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HR,C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E
M(&]N("5X+B(*;7-G<W1R(")$87,@;F5U92!087-S=V]R9"!W:7)D(&%M("5X
M(&%B;&%U9F5N+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU
M,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"XB"FUS9W-T<B`B
M1&EE(&YE=65N(%!A<W-W]G)T97(@<W1I;6UE;B!N:6-H="#\8F5R96EN+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*
M;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B3F5U97,@1F5N
M<W1E<B`H7V)L86YK*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,CDQ"FUS9VED(").97=S(@IM<V=S='(@(DYA8VAR:6-H=&5N(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-PIM<V=I9"`B3F5W<V=R
M;W5P<R(*;7-G<W1R(").97=S9W)U<'!E;B(*"B,Z('1E;7!L871E<R]D871A
M+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@(E=E:71E
M<B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H
M87-E<R(*;7-G<W1R(").Y&-H<W1E(#0@4&AA<V5N(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HS-C8@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HS-S`*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R(").Y&-H
M<W1E($5I;G-T96QL=6YG96XB"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N
M<&AP.C$P-@IM<V=I9"`B3F5X=#XB"FUS9W-T<B`B5V5I=&5R/B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(DYI8V%R86=U82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B3FEG97(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B3FEG97)I82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-CD*;7-G:60@(DYI
M9VAT(@IM<V=S='(@(DYA8VAT<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3FEU
M92(*;7-G<W1R(").:75E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDV-@IM<V=I9"`B3F\B"FUS9W-T<B`B3F5I;B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@
M879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N
M8V5S(&9O<BXB"FUS9W-T<B`B2V5I;F4@2V]N9FEG=7)A=&EO;G-D871E;B!V
M97)F_&=B87(L('5M(%5N=&5R<V-H:65D92!A;GIU>F5I9V5N+B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`V"FUS9VED
M(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S
M+B(*;7-G<W1R(")+96EN92!3=')A=&5G:64@>G5M($5R<W1E;&QE;B!V;VX@
M25-/+4%B8FEL9&5R;B!V97)F_&=B87(N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B871C
M:"!T96UP;&%T92XB"FUS9W-T<B`B2V5I;F4@0F%T8V@M5F]R;&%G92XB"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P
M,0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C,X-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C0P-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T
M960@<&]S:71I;VXB"FUS9W-T<B`B17,@97AI<W1I97)T(&ME:6X@0FQO8VL@
M86X@9&5R(&%N9V5G96)E;F5N(%!O<VET:6]N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P
M<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B2V5I
M;B!+86QE;F1E<FYA;64@9OQR(&1I92!-0T%,+4%U=&AE;G1I9FEZ:65R=6YG
M(&%N9V5G96)E;BXB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU,0IM<V=I
M9"`B3F\@8VAA;F=E+B(*;7-G<W1R(")+96EN92#$;F1E<G5N9V5N+B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(").;R!C
M:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G
M<W1R("(B"B)5;G1E<FAA;&(@9&EE<V5R($5B96YE(&OV;FYE;B!K96EN92!W
M96ET97)E;B!5;G1E<G)E8VAT92!H:6YZ=6=E9OQG="!W97)D96XN(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S@@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HU,3$*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-SDR
M"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B1OQR("5S('=U<F1E
M;B!K96EN92!+;VYF:6=U<F%T:6]N<VEN9F]R;6%T:6]N96X@86YG96=E8F5N
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#8W"FUS9VED(").
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10
M(%9&4RXB"FUS9W-T<B`B(@HB1OQR(&1E;B!&5%`M5D93+51R96EB97(@=W5R
M9&5N(&ME:6YE($MO;F9I9W5R871I;VYS:6YF;W)M871I;VYE;B!A;F=E9V5B
M96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HW,C<*;7-G:60@
M(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44P@5D93+B(*;7-G<W1R("(B"B)&_'(@9&5N(%-13"U61E,M5')E:6)E<B!W
M=7)D96X@:V5I;F4@2V]N9FEG=7)A=&EO;G-I;F9O<FUA=&EO;F5N(&%N9V5G
M96)E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S<R
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("(B"B)&_'(@9&5N(%-13"U$
M871E:2U61E,M5')E:6)E<B!W=7)D96X@:V5I;F4@2V]N9FEG=7)A=&EO;G-I
M;F9O<FUA=&EO;F5N("(*(F%N9V5G96)E;BXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R
M961I="!L969T+B(*;7-G<W1R(")+96EN($MR961I="!M96AR(/QB<FEG+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B
M2V5I;B!%;7!FY&YG97(@86YG96=E8F5N+B(*"B,Z(&9R86UE=V]R:R]"<F]W
M<V5R+T)R;W=S97(N<&AP.CDQ.`IM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*
M;7-G<W1R(")+96EN92!$871E:2!H;V-H9V5L861E;B(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S
M='(@(DME:6YE($EC;VYS(&=E9G5N9&5N+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ,38@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3,P"FUS9VED(").;R!L;V-A=&EO;B!I
M<R!S970N(@IM<V=S='(@(D5S('=U<F1E(&ME:6X@3W)T(&9E<W1G96QE9W0N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PIM<V=I9"`B
M3F\@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(DME:6X@3W)T(&%N9V5G
M96)E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T
M<B`B2V5I;F4@3F%C:')I8VAT(&%N9V5G96)E;BXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@
M;F%M92!S<&5C:69I960N(@IM<V=S='(@(DME:6X@3F%M92!A;F=E9V5B96XN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S<*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(DME
M:6YE($YU;6UE<B!A;F=E9V5B96XN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.CDT"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B
M2V5I;F4@86YS=/;?:6=E;B!';/QC:W-K96MS92(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+96EN(%!A
M<W-W;W)T(&;\<B!D:64@2%144"U!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B
M96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ,#`*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R(")+96EN(%!A<W-W;W)T(&;\<B!D:64@24U!4"U!=71H
M96YT:69I>FEE<G5N9R!A;F=E9V5B96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+96EN(%!A
M<W-W;W)T(&;\<B!D:64@2V5R8F5R;W,M075T:&5N=&EF:7II97)U;F<@86YG
M96=E8F5N+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<@
M9G)A;65W;W)K+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]P86TN<&AP.C<U"FUS9VED(").;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DME:6X@
M4&%S<W=O<G0@9OQR(&1I92!,;V=I;BU!=71H96YT:69I>FEE<G5N9R!A;F=E
M9V5B96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P87-S=V0N<&AP.C$S
M-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B2V5I;B!087-S=V]R="!F_'(@9&EE(%!!
M4U-71"U!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B96XN(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+96EN
M(%!A<W-W;W)T(&;\<B!D:64@4TU"+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G
M96)E;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R
M.#<*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R
M;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*
M(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*(DME:6X@4&9A
M9"!Z=6T@3W!E;E-33"U0<F]G<F%M;2!A;F=E9V5B96XN($1A<R!/<&5N4U-,
M+5!R;V=R86UM('=I<F0@(@HB8F5N]G1I9W0L('5M(%!+0U,M,3(M1&%T96X@
M=F5R87)B96ET96X@>G4@:_9N;F5N+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB
M"FUS9W-T<B`B2V5I;F4@875S<W1E:&5N9&5N(%)E9VES=')I97)U;F=E;BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S4S"FUS9VED(").;R!Q=6]T
M82!S970N(@IM<V=S='(@(DME:6X@4W!E:6-H97)P;&%T>BU+;VYT:6YG96YT
M(&9E<W1G96QE9W0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT,PIM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`B
M2V5I;F4@4F%H;65N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M-#@R"FUS9VED(").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G<W1R(")+
M96EN(%1R96YN>F5I8VAE;B!A;F=E9V5B96XN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`IM<V=I9"`B3F\@
M<VED97,B"FUS9W-T<B`B2V5I;F4@4V5I=&5N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HV,#D*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R
M(")$871E:2!N:6-H="!G969U;F1E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ,C8*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@
M879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B2V5I;F4@=&5M<&]RY')E
M<R!697)Z96EC:&YI<R!F_'(@9&5N($-A8VAE(&=E9G5N9&5N+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"FUS9VED
M(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B
M2V5I;B!"96YU='IE<FYA;64@=6YD+V]D97(@4&%S<W=O<G0@86YG96)E;BXB
M"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T-@IM<V=I9"`B
M3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B17,@=W5R9&5N
M(&ME:6YE(&?\;'1I9V5N(%A-3"U$871E;B!Z=7+\8VMG96=E8F5N(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW-`HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@T"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY.34*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,3(*;7-G:60@
M(DYO('9A;'5E<R(*;7-G<W1R(")+96EN92!797)T92(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ,3D*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@
M;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(B"B)+96EN92!697)S:6]N<VYU;6UE<B!I;B!D97(@
M3W)I9VEN86QK;VYF:6=U<F%T:6]N(&=E9G5N9&5N+B!%<FYE=65R;B!3:64@
M(@HB26AR92!+;VYF:6=U<F%T:6]N+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,C<*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF
M:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(B(*(DME:6YE(%9E<G-I;VYS;G5M;65R(&EN($EH<F5R($MO;F9I9W5R871I
M;VX@9V5F=6YD96XN($5R;F5U97)N(%-I92!):')E("(*(DMO;F9I9W5R871I
M;VXN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY-0IM
M<V=I9"`B3F]N92(*;7-G<W1R(")+96EN92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I
M;7!L:6-I="DB"FUS9W-T<B`B2V5I;G,@*%-T86YD87)D(&)E;G5T>F5N*2(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(").;W)D:6,@*$E3
M3RTX.#4Y+3$P*2(*;7-G<W1R(").;W)D:7-C:"`H25-/+3@X-3DM,3`I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R(").
M;W)F;VQK:6YS96PB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L
M;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM
M<V=S='(@(D[V<F1L:6-H92!(96UI<W!H97)E(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS
M9VED(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B3O9R9&QI
M8VAE($UA<FEA;F5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").;W)W87DB"FUS
M9W-T<B`B3F]R=V5G96XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8T,0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(D?\;'1I9R!B
M:7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM
M<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R(")'_&QT:6<@86(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,C0*;7-G:60@(DYO="!A(&1I<F5C
M=&]R>2(*;7-G<W1R(")+96EN(%9E<GIE:6-H;FES(@H*(SH@9G)A;65W;W)K
M+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z,S0X"FUS9VED(").;W0@9F]U
M;F0N(@IM<V=S='(@(DYI8VAT(&=E9G5N9&5N+B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z
M.#0*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2YP:'`Z.34*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(DYI
M8VAT(&EM<&QE;65N=&EE<G0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*;7-G<W1R(").
M:6-H="!F97-T9V5L96=T(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#@*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-C,*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S@*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ.3(*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR
M,S<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z,C,Y(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-C4*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C(X,R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,S`P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,38@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C,S,@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S0W(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HS-C0*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C,Y-R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#4W"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HU,S8@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8P-0HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-C(R"FUS9VED(").;W0@<W5P<&]R
M=&5D+B(*;7-G<W1R(").:6-H="!U;G1E<G-T_'1Z="XB"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDS-"!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C0T"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ
M,#8X(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#`*;7-G:60@(DYO=&5S
M(@IM<V=S='(@(DYO=&EZ96XB"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E
M>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*
M;7-G<W1R(").:6-H=',@86YZ=7IE:6=E;BP@8FET=&4@>G5R_&-K9V5H96XN
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q
M,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*
M;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(DYO=F5M8F5R(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3`T-@IM<V=I9"`B3G5M8F5R(@IM<V=S='(@
M(EIA:&PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U"FUS9VED
M(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R(")!;GIA:&P@9&5R(%IE
M:6-H96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30T-2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B06YZ
M86AL(&1E<B!3<&%L=&5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,V-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T-#,@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S
M='(@(D%N>F%H;"!D97(@6F5I;&5N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T
M('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N
M(@IM<V=S='(@(DME:6YE($YU;6UE<FX@9OQR(&1I92!697)T96EL97)L:7-T
M92!A;F=E9V5B96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R(")/2R(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B
M:F5C="(*;7-G<W1R(")/8FIE:W0B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$Q,@IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`B3V)J
M96MT97)S=&5L;&5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$P
M-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B3VMT86QZ86AL(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B
M97(B"FUS9W-T<B`B3VMT;V)E<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B1FEL=&5R(&;\
M<B!A;G-T]M]I9V4@26YH86QT92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS,C@*;7-G:60@(D]F9FEC92(*;7-G<W1R(")"_')O(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE
M=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(DEH<B!N
M975E<R!087-S=V]R="!M=7-S('-I8V@@=F]N($EH<F5M(&%L=&5N('5N=&5R
M<V-H96ED96XN(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V
M"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B06QT97,@4&%S<W=O<G0B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L
M9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B1F%L<V-H97,@
M86QT97,@4&%S<W=O<G0N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM
M<V=S='(@(D]M86XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#(V
M"FUS9VED(")/;F-L:6-K(&5V96YT(@IM<V=S='(@(D]N8VQI8VLM179E;G0B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM
M<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R
M<RXB"FUS9W-T<B`B3G5R($E-05`M4V5R=F5R('5N=&5R<W3\='IE;B!G96UE
M:6YS86UE($]R9&YE<BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*
M;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(DYU<B!A
M;G-T]M]I9V4@1VS\8VMS:V5K<V4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#D*;7-G:60@
M(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B3G5R
M(&5I;F4@12U-86EL+4%D<F5S<V4@97)L875B="XB"@HC.B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R
M('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R
M(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*
M(DYU<B!D97(@0F5S:71Z97(@;V1E<B!D97(@4WES=&5M861M:6YI<W1R871O
M<B!K86YN(&1E;B!"97-I='IE<B!O9&5R(&1I92`B"B)"97-I='IE<G)E8VAT
M92#D;F1E<FXB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HT,2!L:6(O0FQO
M8VLO:69R86UE+G!H<#HT,@IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B
M"FUS9W-T<B`B26X@;F5U96T@1F5N<W1E<B#V9F9N96XB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E
M<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)
M344@<&%R="XB"FUS9W-T<B`B(@HB3W!E;E-33"U&96AL97(Z(%-I9VYI97)T
M92!3+TU)344M1&%T96X@:V]N;G1E;B!N:6-H="!E>'1R86AI97)T('=E<F1E
M;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W
M:6YD;W<B"FUS9W-T<B`B1&EE<V5N($QI;FL@:6X@96EN96T@;F5U96T@1F5N
M<W1E<B#V9F9N96XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G
M:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B0F5T<FEE8G-Y<W1E;2(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-34*;7-G:60@(D]P
M=&EO;G,B"FUS9W-T<B`B16EN<W1E;&QU;F=E;B(*"B,Z('-E<G9I8V5S+W!R
M969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R(")%:6YS=&5L
M;'5N9V5N(&;\<B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G<W1R(").
M=6UM97)I97)T92!,:7-T92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B3W)G
M86YI<V%T:6]N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-CD*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B3W)G
M86YI<V%T:6]N<V%B=&5I;'5N9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ,S0*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B3W)G86YI<VEE
M<F5N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I
M;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@(D]R:6=I;F%L=F]R
M;&%G92!D97(@06YW96YD=6YG(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN
M("5S.B(*;7-G<W1R(")/<FEG:6YA;'9O<FQA9V4@:6X@)7,Z(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R
M9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(E-O;G-T:6=E(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDY(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3(U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S0*
M;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D%N9&5R92!);F9O
M<FUA=&EO;F5N(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,@IM
M<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B0F5S:71Z97)R96-H
M=&4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-SD*;7-G:60@
M(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R
M(")004TM075T:&5N=&EF:7II97)U;F<@:7-T(&YI8VAT('9E<F;\9V)A<BXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ
M,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R(")014%2.CI-
M86EL+4)A8VME;F0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,C@U"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B
M1&EG:71A;&4@4$=0+55N=&5R<V-H<FEF="(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$S,S$*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T
M82(*;7-G<W1R(")01U`M=F5R<V-H;/QS<V5L=&4@1&%T96XB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S@S"FUS9VED(")01U`@4'5B
M;&EC($ME>2(*;7-G<W1R("+69F9E;G1L:6-H97(@4$=0+5-C:&S\<W-E;"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-C4*;7-G:60@
M(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B36ET(%!'4"!U
M;G1E<GIE:6-H;F5T92]V97)S8VAL_'-S96QT92!$871E;B(*"B,Z(&%D;6EN
M+W!H<'-H96QL+G!H<#HV.0IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B4$A0
M($-O9&4B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3
M:&5L;"(*;7-G<W1R(")02%`@4VAE;&PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@3&EG:'0@4F%I;B(*
M;7-G<W1R(")6;W)M:71T86=S(&QE:6-H=&5R(%)E9V5N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%)A
M:6XB"FUS9W-T<B`B3F%C:&UI='1A9W,@4F5G96XB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@4VAO=V5R
M<R(*;7-G<W1R(").86-H;6ET=&%G<R!38VAA=65R(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G:60@(E!-(%-N;W<B
M"FUS9W-T<B`B3F%C:&UI='1A9W,@4V-H;F5E(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E!-(%-N;W<@4VAO
M=V5R<R(*;7-G<W1R(").86-H;6ET=&%G<R!38VAN965S8VAA=65R(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@
M(E!-(%-U;B(*;7-G<W1R(").86-H;6ET=&%G<R!3;VYN92(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")032!4
M+5-T;W)M<R(*;7-G<W1R(").86-H;6ET=&%G<R!'97=I='1E<B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HR.#8*;7-G:60@(E!/4TE8(&5X=&5N<VEO
M;B!I<R!M:7-S:6YG(@IM<V=S='(@(D1I92!03U-)6"U%<G=E:71E<G5N9R!F
M96AL="(*"B,Z(&QI8B]A<&DN<&AP.C(Q-0IM<V=I9"`B4%](4"!3:&5L;"(*
M;7-G<W1R(")?4$A0(%-H96QL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G
M<W1R("));FYE;F%B<W1A;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES
M=&%N(@IM<V=S='(@(E!A:VES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B
M4&%L874B"FUS9W-T<B`B4&%L874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0
M86QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@(D)E<V5T
M>G1E(%!A;.1S=&EN96YS:7-C:&4@1V5B:65T92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM
M<V=I9"`B4&%N86UA(@IM<V=S='(@(E!A;F%M82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM
M<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R(")087!U82U.975G=6EN
M96$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R(")0
M87)A9W5A>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,Y"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@(E1E:6QW96ES
M92!"97?V;&MT(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4S-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HQ-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S
M-@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<W('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0R-0IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B4&%S<W=O<G0B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A
M<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")087-S=V]R
M="!E<F9O;&=R96EC:"!G9>1N9&5R="XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C$S,C,*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C
M="(*;7-G<W1R(")&86QS8VAE<R!087-S=V]R="(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I
M<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DME:6X@
M4&%S<W=O<G0@9OQR(&1I92!2041)55,M075T:&5N=&EF:7II97)U;F<@86YG
M96=E8F5N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-S$*;7-G
M:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(E!A<W-W
M;W)T(&UI="!"97-TY'1I9W5N9R(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(E!A<W-W;W)T
M.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")0
M87-S=V]R9#H@(@IM<V=S='(@(E!A<W-W;W)T.B`B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S=V]R
M9',@;75S="!M871C:"XB"FUS9W-T<B`B1&EE(%!A<W-W]G)T97(@;?QS<V5N
M(&=L96EC:"!S96EN+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R
M"FUS9VED(")087-T92(*;7-G<W1R(")%:6YF_&=E;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E
M(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(E9O;B!D97(@6G=I<V-H96YA8FQA
M9V4@96EN9OQG96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@(E!F860B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3
M:6=N=7!S.B(*;7-G<W1R(")!=7-S=&5H96YD92!296=I<W1R:65R=6YG96XZ
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"FUS9VED(")096]P;&4B
M"FUS9W-T<B`B4&5R<V]N96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R(")0
M<F]Z96YT(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E
M+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<R(*;7-G<W1R(")787)T=6YG<V%R8F5I=&5N(&1U<F-H9OQH<F5N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P,PIM<V=I9"`B4&5R9F]R;2!M86EN
M=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")787)T=6YG
M<V%R8F5I=&5N(&YA8V@@9&5R($%N;65L9'5N9R!D=7)C:&;\:')E;C\B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R
M;6ES<VEO;B(*;7-G<W1R(")296-H=&4B"@HC.B!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E
M<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R(")296-H="!<(B5S7"(@=W5R9&4@
M;FEC:'0@9V5L]G-C:'0N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HV,3(*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(EIU9W)I
M9F8@=F5R=V5I9V5R="(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,38Q(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38T"FUS9VED
M(")097)M:7-S:6]N<R(*;7-G<W1R(")296-H=&4B"@HC.B!A9&UI;B]P97)M
M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z
M(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C4X"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G
M<W1R(")296-H=&5V97)W86QT=6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8X"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R(")0
M97)S]FYL:6-H92!!;F=A8F5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U
M(@IM<V=S='(@(E!E<G4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*
M;7-G:60@(E!E=',B"FUS9W-T<B`B2&%U<W1I97)E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY
M"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R(")0:&EL:7!P:6YE;B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G
M:60@(E!H;VYE(@IM<V=S='(@(E1E;&5F;VXB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#@P"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B1F]T;W,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R(")0:71C
M86ER;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B4&EX96PB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T
M<B`B4&QA='1H96ET96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT
M;R!S;VUE(&-E;&PB"FUS9W-T<B`B0FET=&4@:VQI8VME;B!3:64@:6X@96EN
M92!:96QL92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R(")":71T
M92!B97-TY'1I9V5N(%-I92P@9&%S<R!3:64@9&EE<V5S($5L96UE;G0@;/9S
M8VAE;B!M]F-H=&5N.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@
M=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R
M("(B"B)":71T92!B973D=&EG96X@4VEE+"!D87-S(%-I92!D96X@3&EN:R!V
M;VX@9&EE<V5M($5L96UE;G0@96YT9F5R;F5N(&WV8VAT96XN(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4X,`IM<V=I9"`B4&QE87-E(&5N=&5R
M(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B0FET=&4@96EN96X@36]N
M870@=6YD(&5I;B!*86AR(&%N9V5B96XN(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E
M<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(D)I='1E
M(&=E8F5N(%-I92!E:6YE;B!.86UE;B!F_'(@9&EE(&YE=64@2V%T96=O<FEE
M(&%N.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#$*;7-G:60@
M(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(D)I
M='1E(&5I;F4@9_QL=&EG92!)4"U!9')E<W-E(&5I;F=E8F5N+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3@*;7-G:60@(E!L96%S92!E;G1E
M<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T
M:&4@;6]N=&@N(@IM<V=S='(@(B(*(D)I='1E(&=E8F5N(%-I92!E:6X@9_QL
M=&EG97,@1&%T=6T@86X[(/QB97)P<OQF96X@4VEE(&1I92!:86AL(&1E<B!4
M86=E(&EN("(*(F1E;2!-;VYA="XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-#8U"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*
M;7-G<W1R(")":71T92!E:6YE;B!G_&QT:6=E;B!:96ET=V5R="!E:6YG96)E
M;BXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED
M(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM
M<V=S='(@(D)I='1E(&=E8F5N(%-I92!E:6YE(%IU<V%M;65N9F%S<W5N9R!)
M:')E<R!0<F]B;&5M<R!A;BXB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L
M96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S
M='(@(D)I='1E(&=E8F5N(%-I92!):')E;B!"96YU='IE<FYA;65N('5N9"!)
M:'(@4&%S<W=O<G0@86XB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M-3@*;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@
M66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S
M>7-T96TN(@IM<V=S='(@(B(*(D)I='1E(&QE<V5N(%-I92!S:6-H(&1E;B!F
M;VQG96YD96X@5&5X="!S;W)G9N1L=&EG(&1U<F-H+B!3:64@3=Q34T5.(&1I
M97-E;B`B"B)"961I;F=U;F=E;B!Z=7-T:6UM96XL('=E;FX@4VEE(&1I97-E
M<R!3>7-T96T@8F5N=71Z96X@;?9C:'1E;BXB"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B4&QE87-E
M('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R(")":71T92!D
M96X@;F5U96X@2V%T96=O<FEE;F%M96X@96EN9V5B96XZ(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDY"FUS9VED(")0;VQA;F0B"FUS9W-T<B`B4&]L96XB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@(E!O
M;&ET:6LB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@Y"FUS9VED
M(")0;VQL<R(*;7-G<W1R(")5;69R86=E;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G
M:60@(E!O<G1U9V%L(@IM<V=S='(@(E!O<G1U9V%L(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS
M9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(E!O<VET
M:6]N:65R=6YG(&1I97-E($)I;&1E<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O
M9B!T:&ES('1A8FQE(@IM<V=S='(@(E!O<VET:6]N:65R=6YG(&1I97-E<B!4
M86)E;&QE(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP
M:'`Z-3$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B
M>2!)34%0*2(*;7-G<W1R(")396YD96X@86X@9&EE<V5N($]R9&YE<B`H;FEC
M:'0@9'5R8V@@24U!4"DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V."!L
M:6(O0FQO8VLO;65T87(N<&AP.C(W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")0
M<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R(").
M:65D97)S8VAL86<@:6X@9&5N(&QE='IT96X@)7,@4W1U;F1E*&XI.B`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@W"FUS9VED(")0<F5C
M:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(DYI961E<G-C:&QA9W,M
M/&)R("\^=V%H<G-C:&5I;FQI8VAK96ET(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+VQD87`N<&AP.C$P-`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER
M960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L
M9&%P.B!$:64@8F5N]G1I9W1E($Q$05`M17)W96ET97)U;F<@=W5R9&4@;FEC
M:'0@9V5F=6YD96XN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-E<W-I
M;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S
M:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7W-E<W-I
M;VXZ($1I92!B96[V=&EG=&4@4V5S<VEO;BU%<G=E:71E<G5N9R!W=7)D92!N
M:6-H="!G969U;F1E;BXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-PIM
M<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B3'5F=&1R=6-K(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-C$*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E
M;#H@(@IM<V=S='(@(DQU9G1D<G5C:R!A=68@4V5E:/9H93H@(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-`IM<V=I9"`B4')E<W-U<F4Z
M("(*;7-G<W1R("),=69T9')U8VLZ("(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR,#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V
M:65W(@IM<V=S='(@(E9O<G-C:&%U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V
M:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B16EN92!6
M;W)S8VAA=2!D97,@0FEL9&5S(&EN(&5I;F5M(&YE=65M($9E;G-T97(@86YZ
M96EG96XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,U-B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V,`IM<V=I9"`B4')E=FEO
M=7,@;W!T:6]N<R(*;7-G<W1R(")6;VAE<FEG92!%:6YS=&5L;'5N9V5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM
M<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B1&]K=6UE;G0@9')U8VME
M;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I
M9"`B4')I=F%T92!+97DB"FUS9W-T<B`B4')I=F%T97(@4V-H;/QS<V5L(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I9"`B
M4')O8FQE;2(*;7-G<W1R(")0<F]B;&5M92(*"B,Z('-E<G9I8V5S+W!R;V)L
M96TN<&AP.C$R-PIM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R
M(")0<F]B;&5M8F5S8VAR96EB=6YG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,W,0IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B4')O:F5K=&4B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3(Y(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R,#8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S(Y-`IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B3F%C:&9R86=E=&5X
M="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I
M9"`B4'5B;&EC($ME>2(*;7-G<W1R("+69F9E;G1L:6-H97(@4V-H;/QS<V5L
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#8*;7-G
M:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(D%L9V]R:71H;75S
M(&1E<R#V9F9E;G1L:6-H96X@4V-H;/QS<V5L<R(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($EN
M9F\B"FUS9W-T<B`B26YF;W)M871I;VYE;B!Z=6T@]F9F96YT;&EC:&5N(%-C
M:&S\<W-E;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C(T
M,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D
M('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B1&%S(/9F9F5N=&QI8VAE+W!R:79A
M=&4@4V-H;/QS<V5L<&%A<B!K;VYN=&4@;FEC:'0@97)S=&5L;'0@=V5R9&5N
M+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@
M(E!U97)T;R!2:6-O(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M-#,Q-"YP:'`Z-34*;7-G:60@(E!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(DYA
M8VAR:6-H=&5N(&5N9&?\;'1I9R!L]G-C:&5N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM
M<V=I9"`B46%T87(B"FUS9W-T<B`B2V%T87(B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z-C0*;7-G:60@(E%U97)Y(@IM<V=S='(@(D%B9G)A9V4B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z.#`*;7-G:60@(E%U;W1A(@IM<V=S='(@
M(E-P96EC:&5R<&QA='HM2V]N=&EN9V5N="(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C8T"B,L('!H<"UF;W)M870*;7-G:60@(E)3
M02!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(M9F9F5N=&QI8VAE<B!2
M4T$@4V-H;/QS<V5L("@E9"!":70I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(X,@IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(D%U
M<W=A:&QK;F]P9B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0W"FUS9VED(")286EN(@IM<V=S='(@(E)E9V5N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A
M:6X@16%R;'DB"FUS9W-T<B`B1G+\:"!296=E;B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")286EN($QA=&4B
M"FUS9W-T<B`B4W#D=&5R(%)E9V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S
M='(@(E)E9V5N<V-H875E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@
M(E-C:&YE97)E9V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3(*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R(")296=E
M;B!I;B!38VAN964@_&)E<F=E:&5N9"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R(")';/QC:W-K
M96MS(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV
M."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED
M(")2871I;R(*;7-G<W1R(")697)HY&QT;FES(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS
M-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$*;7-G:60@(E)E860B"FUS9W-T<B`B
M3&5S96XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H
M<#HT-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX
M-PIM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R(").86-H<FEC:'1E;B!L
M97-E;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P
M97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"B(E<R!W:7)K
M;&EC:"!L]G-C:&5N/R!$:65S97(@5F]R9V%N9R!K86YN(&YI8VAT('+\8VMG
MY&YG:6<@9V5M86-H="!W97)D96XN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E
M;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A
M;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*(D1A=&5N(&1E<R!"96YU='IE
M<G,@)7,@=VER:VQI8V@@;/9S8VAE;C\@1&EE<V5R(%9O<F=A;F<@:V%N;B!N
M:6-H="`B"B)R_&-K9^1N9VEG(&=E;6%C:'0@=V5R9&5N+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E
M9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(D;\:')T(&QE='IT92!!
M:W1I;VX@97)N975T(&%U<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C$T-"!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,3`*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0X"FUS9VED(")2969R97-H(@IM
M<V=S='(@(D%K='5A;&ES:65R92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.#@*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*
M;7-G<W1R(")$>6YA;6ES8VAE($UE;OQE;&5M96YT92!A:W1U86QI<VEE<F5N
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@*;7-G:60@(E)E9G)E
M<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(E!O<G1A;&%N<VEC:'0@86MT=6%L
M:7-I97)E;CHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.30@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C,U"FUS9VED(")296=E>"(*;7-G<W1R(")296=U;.1R97(@
M075S9')U8VLB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C0Y"FUS
M9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R(")697)B:6YD=6YG
M<RU"<F]W<V5R(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30T
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(Q,`IM<V=I9"`B4F5L;V%D
M(@IM<V=S='(@(D%K='5A;&ES:65R96XB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,R.`IM<V=I9"`B4F5M87)K<R(*;7-G<W1R(")"96UE<FMU;F=E;B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3<*;7-G:60@(E)E;6]T92!3
M97)V97)S(@IM<V=S='(@(D5N=&9E<FYT92!397)V97(B"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT
M='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R(")397)V97)A
M9')E<W-E("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R
M(")%;G1F97)N96XB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M,3$*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R(")";&]C:R!L]G-C:&5N
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U
M.0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")3<&%L=&4@;/9S8VAE
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(D9O<FUA=&EE
M<G5N9R!E;G1F97)N96XB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B4&%A<B!L]G-C:&5N
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,0IM<V=I9"`B4F5M;W9E
M('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O
M<GDN(@IM<V=S='(@(D=E<W!E:6-H97)T97,@4VMR:7!T(&%U<R!D96T@=&5M
M<&]RY')E;B!697)Z96EC:&YI<R!E;G1F97)N96XN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED
M(")296UO=F4@=&AE(@IM<V=S='(@(D5N=&9E<FYE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED
M(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@
M(D1I97-E<R!%;&5M96YT(&%U<R!D96T@1&]K=6UE;G0@96YT9F5R;F5N(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B
M4F5M;W9E('5S97(B"FUS9W-T<B`B0F5N=71Z97(@;/9S8VAE;B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B0F5N=71Z97(@;/9S
M8VAE;CH@)7,B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T
M-`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N
M960@97)R;W)C;V1E.B`B"FUS9W-T<B`B06YF<F%G92!K;VYN=&4@;FEC:'0@
M8F5A;G1W;W)T970@=V5R9&5N+B!:=7+\8VMG96=E8F5N97(@1F5H;&5R8V]D
M93H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-0IM<V=I
M9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G
M<W1R(")$97(@9V5W_&YS8VAT92!$:65N<W0@:V]N;G1E(&YI8VAT(&=E9G5N
M9&5N('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$X
M-2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4R,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")<(B5S7"(@=W5R9&4@:6X@9&5R($MO
M;F9I9W5R871I;VX@9OQR("5S(&YI8VAT(&%N9V5G96)E;BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C<S,R!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C@W,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M-S<X"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@
M<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")<(B5S
M7"(@=W5R9&4@:6X@9&5R(%9&4RU+;VYF:6=U<F%T:6]N(&YI8VAT(&%N9V5G
M96)E;BXB"@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HX,#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@
M:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B7"(E<UPB('=U<F1E(&EN(&1E
M<B!+;VYF:6=U<F%T:6]N(&YI8VAT(&%N9V5G96)E;BXB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S8*;7-G:60@(E)E<75I<F5D
M($9I96QD(@IM<V=S='(@(DYO='=E;F1I9V5S($9E;&0B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SD*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(Q"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C`@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R("):=7+\8VMS971Z
M96XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.`IM<V=I9"`B
M4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B4&%S<W=O<G0@>G5R_&-K<V5T>F5N
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C@*;7-G:60@(E)E
M<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B4V5T>F5N(%-I92!):'(@4&%S
M<W=O<G0@>G5R_&-K(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,0IM<V=I
M9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(DQE='IT92!!8F9R86=E
M(&5I;F;\9V5N(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<R(&%D;6EN+V-M
M9'-H96QL+G!H<#HR.2!A9&UI;B]S<6QS:&5L;"YP:'`Z-C<*;7-G:60@(E)E
M<W5L=',B"FUS9W-T<B`B17)G96)N:7-S92(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM
M<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B6G5R_&-K('IU($5I
M;G-T96QL=6YG96XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,S@*;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B"FUS9W-T<B`B3F5U97,@
M4&%S<W=O<G0@97)N975T(&5I;F=E8F5N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I
M9"`B4F5U;FEO;B(*;7-G<W1R(")2Z75N:6]N(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED
M(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")+;VYF:6=U<F%T:6]N
M('IU<OQC:W-E='IE;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*
M;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R(")765-)
M5UE'+45D:71O<B!%:6YS=&5L;'5N9V5N(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@(E+D='-E;"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B4F5C:'1S(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$R,0IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S
M='(@(E)E8VAT92#<8F5R<V-H<FEF="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,Q,3<*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R(")296-H
M=&4@5V5R=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*
M;7-G<W1R(")?6F5I;&5N96EG96YS8VAA9G1E;BXN+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B
M"FUS9W-T<B`B4F]L;&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA
M(@IM<V=S='(@(E)U;>1N:65N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(R-@IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R
M(")5;2`Q.#"P(&1R96AE;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,C,*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@
M(DYA8V@@;&EN:W,@9')E:&5N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(R.0IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S
M='(@(DYA8V@@<F5C:'1S(&1R96AE;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P
M97)T:65S(@IM<V=S='(@(EIE:6QE;F5I9V5N<V-H869T96XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS
M9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R("):96EL96YE:6=E;G-C:&%F
M=&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@(EIE:6QE;CHB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"FUS
M9VED(")2=6QE<R(*;7-G<W1R(")296=E;&XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM
M<V=S='(@(E)A:&UE;B!Z=VES8VAE;B!A;&QE;B!:96EL96X@=6YD(%-P86QT
M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O
M;'5M;G,@;VYL>2(*;7-G<W1R(")286AM96X@;G5R('IW:7-C:&5N(%-P86QT
M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O
M=W,@;VYL>2(*;7-G<W1R(")286AM96X@;G5R('IW:7-C:&5N(%IE:6QE;B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C$*;7-G:60@(E)U;B(*;7-G<W1R
M(")3=&%R=&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA;B!&961E
M<F%T:6]N(@IM<V=S='(@(E)U<W-I<V-H92!&]G)D97)A=&EO;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#,*;7-G:60@(E)W86YD82(*;7-G<W1R(")2=6%N9&$B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-
M24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(E,O34E-12!K
M<GET;V=R87!H:7-C:&4@56YT97)S8VAR:69T(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T
M960@365S<V%G92(*;7-G<W1R(")-:70@4R]-24U%('9E<G-C:&S\<W-E;'1E
M($YA8VAR:6-H="(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z
M.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B4T%33"U!=71H96YT:69I>FEE<G5N9R!I<W0@;FEC:'0@
M=F5R9OQG8F%R+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#8*
M;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`B4TU3+59E<G-A;F0B"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G
M<W1R(")344P@4VAE;&PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,CDR"FUS9VED(")344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM
M<V=S='(@(E-13"U!;G=E:7-U;F<@>G5R($%B9G)A9V4@9&5R(%=E<G1E(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,PIM<V=I9"`B4U-((@IM
M<V=S='(@(E-32"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B
M"FUS9W-T<B`B15)&3TQ'(@H*(SH@;&EB+V%P:2YP:'`Z,C$Y"FUS9VED(")3
M7U%,(%-H96QL(@IM<V=S='(@(E-?44P@4VAE;&PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G
M<W1R(")382(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*
M;7-G<W1R(")386EN="!(96QE;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A
M:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R(")386EN="!+:71T<R!U;F0@
M3F5V:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S
M='(@(E-A:6YT($QU8VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@
M4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R(")386EN="!0:65R<F4@=6YD
M($UI<75E;&]N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N
M="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B4V%I;G0@5FEN8V5N="!U
M;F0@9&EE($=R96YA9&EN96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB
M"FUS9W-T<B`B1VQE:6-H97(@4F%H;65N("A?<V5L9BDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$W"FUS9VED(")386UO82(*;7-G<W1R(")386UO82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`B4V%N($UA<FEN;R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G
M<W1R(")386\@5&]M92!U;F0@4')I;F-I<&4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED97(B
M"FUS9W-T<B`B4V%T96QL:71E;G!R;W9I9&5R(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM
M<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(E-A=61I+4%R86)I96XB"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3D*;7-G:60@(E-A=F4B
M"FUS9W-T<B`B4W!E:6-H97)N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<
M(B(*;7-G<W1R(")<(B5S7"(@<W!E:6-H97)N(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHR,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E
M<R(*;7-G<W1R("(E<R!S<&5I8VAE<FXB"@HC.B!T96UP;&%T97,O<')E9G,O
M96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B16EN<W1E
M;&QU;F=E;B!S<&5I8VAE<FXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,38V"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S
M(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*(D5R>F5U9W1E($MO;F9I9W5R871I;VX@
M86QS(%!(4"U3:W)I<'0@:6T@=&5M<&]RY')E;B!697)Z96EC:&YI<R!):')E
M<R`B"B)397)V97)S('-P96EC:&5R;BXB"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("(E<RU+;VYF:6=U<F%T:6]N(&=E<W!E:6-H
M97)T+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L('!H<"UF
M;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<
M(B5S7"(N(@IM<V=S='(@(D1A<R!!:W1U86QI<VEE<G5N9W-S:W)I<'0@=W5R
M9&4@:6X@7"(E<UPB(&=E<W!E:6-H97)T+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")38V%T=&5R960@5"U3
M=&]R;7,B"FUS9W-T<B`B5F5R96EN>F5L=&4@1V5W:71T97(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B
M5VES<V5N<V-H869T(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI
M;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@
M(E-E87)C:"(*;7-G<W1R(")3=6-H92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS,C(*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(E-U
M8VAM87-C:&EN96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3<S
M"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B1&%T96EE;B!A=7-WY&AL
M96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#@U"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(D1A='5M(&%U<W?D
M:&QE;B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DY"FUS9VED
M(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B2&EN>G5Z=6;\9V5N
M9&4@1W)U<'!E;B!A=7-WY&AL96XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C0T"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`B
M3F5U96X@0F5S:71Z97(@875S=^1H;&5N(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T
M<B`B4V5R=F5R(&%U<W?D:&QE;B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,34W"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R
M(")(:6YZ=7IU9OQG96YD96X@0F5N=71Z97(@875S=^1H;&5N(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-@IM<V=I9"`B
M4V5L96-T(&%L;"(*;7-G<W1R(")!;&QE(&%U<W?D:&QE;B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C$*;7-G:60@(E-E;&5C="!A;&P@9&%T
M92!C;VUP;VYE;G1S+B(*;7-G<W1R("),96=E;B!3:64@86QL92!$871U;7-K
M;VUP;VYE;G1E;B!F97-T+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS
M9W-T<B`B3V)J96MT(&%U<W?D:&QE;B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HV-S<*;7-G:60@(E-E;&5C="!N;VYE(@IM
M<V=S='(@(DME:6YE;B!A=7-WY&AL96XB"@HC.B!S97)V:6-E<R]K97EB;V%R
M9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@
M;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@
M86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R
M("(B"B)7Y&AL96X@4VEE(&1I92!B96[V=&EG=&5N(%IE:6-H96X@875S(&1E
M;B!J97=E:6QI9V5N($9E;&1E<FX@875S+B!$86YN("(*(FOV;FYE;B!3:64@
M9&EE<V4@875S(&1E;2!497AT9F5L9"!K;W!I97)E;B!U;F0@:6X@26AR92!.
M86-H<FEC:'0@96EN9OQG96XN(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S
M='(@(E?D:&QE;B!3:64@9&%S($1A='5M<W1R96YN>F5I8VAE;CHB"@HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H92!D
M871E(&9O<FUA=#HB"FUS9W-T<B`B5^1H;&5N(%-I92!D87,@1&%T=6US9F]R
M;6%T.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z
M.3(*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA
M;F=E.B(*;7-G<W1R(")7Y&AL96X@4VEE(&1I92!)9&5N=&ETY'0L(&1I92!3
M:64@Y&YD97)N(&WV8VAT96XZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI
M;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S
M='(@(E?D:&QE;B!3:64@9&%S(%IE:71T<F5N;GIE:6-H96XZ(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM
M92!F;W)M870Z(@IM<V=S='(@(E?D:&QE;B!3:64@9&%S(%IE:71F;W)M870Z
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L
M96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(E?D:&QE;B!3:64@
M>G=E:2!Z=7-A;6UE;F=E:/9R:6=E($9E;&1E<B!A=7,N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,P,PIM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@
M<V-H96UE+B(*;7-G<W1R(")7Y&AL96X@4VEE(&5I;B!&87)B<V-H96UA+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#0*;7-G:60@(E-E;&5C="!Y
M;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B5^1H;&5N(%-I92!)
M:')E(&)E=F]R>G5G=&4@4W!R86-H93HB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*
M;7-G<W1R(")0<F]B;&5M8F5R:6-H="!A8G-C:&EC:V5N(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-#(*;7-G:60@(E-E
M;F0@4TU3(@IM<V=S='(@(E--4R!V97)S8VAI8VME;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B4V5N96=A;"(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S$X"FUS9VED(")396YS;W(Z("(*;7-G<W1R(")3
M96YS;W(Z("(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B4V5P=&5M8F5R(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@
M(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R(")397)B:65N('5N9"!-
M;VYT96YE9W)O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HW,#(*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B4V5R:65N;G5M
M;65R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T.0IM<V=I
M9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T
M<B`B4V5R=F5R9&%T96X@=6YG_&QT:6<@;V1E<B!N:6-H="!V97)F_&=B87(N
M(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"FUS9VED(")397-S:6]N($%D
M;6EN(@IM<V=S='(@(E-E<W-S:6]N=F5R=V%L='5N9R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B
M4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R(")397-S:6]N+4E$(&%B9V5L
M875F96XN(@H*(SH@;&EB+V%P:2YP:'`Z,C$Q"FUS9VED(")397-S:6]N<R(*
M;7-G<W1R(")3:71Z=6YG96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S,R"FUS9VED(")3970B"FUS9W-T<B`B075S=V%H;"U3871Z(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS9VED(")3970@;W!T:6]N<R!T
M;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E
M<B!F;W)G970@:70N(@IM<V=S='(@(B(*(DQE9V5N(%-I92!D:64@16EN<W1E
M;&QU;F=E;B!F97-T+"!D:64@97,@26AN96X@97)L875B96X@26AR(%!A<W-W
M;W)T("(*(GIU<OQC:WIU<V5T>F5N+"!F86QL<R!S:64@97,@96EN;6%L('9E
M<F=E<W-E;B!S;VQL=&5N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,3@*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT
M('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B"B),96=E
M;B!3:64@96YT9F5R;G1E(%-E<G9E<B!F97-T+"!A=68@9&EE(%-I92!V;VX@
M26AR96T@4&]R=&%L(&%U<R!Z=6=R96EF96X@(@HB;?9C:'1E;BXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<*;7-G:60@(E-E="!Y;W5R('!R969E
M<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS
M9W-T<B`B5^1H;&5N(%-I92!):')E(&)E=F]R>G5G=&4@4W!R86-H92P@6F5I
M='IO;F4@=6YD($1A='5M<V5I;G-T96QL=6YG96XN(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P,0IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A
M<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N
M9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*(DQE9V5N
M(%-I92!D87,@9&EE(%-T87)T86YW96YD=6YG+"!D87,@1F%R8G-C:&5M82P@
M9&EE(%-E:71E;F%K='5A;&ES:65R=6YG("(*(G5N9"!A;F1E<F4@06YZ96EG
M965I;G-T96QL=6YG96X@9F5S="XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C<W"FUS9VED(")3971U<"(*;7-G<W1R(")+;VYF:6=U<F%T:6]N(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@
M(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B06MT
M=6%L:7-I97)U;F=S<VMR:7!T92!S:6YD('9E<F;\9V)A<B(*"B,@365H<F5R
M92!P87-S96YD92!/<G1E(&UI="!D:65S96T@4&%R86UE=&5R.B`*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-0IM<V=I9"`B4V5V97)A;"!L
M;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T
M<B`B365H<F5R92!P87-S96YD92!/<G1E(&UI="!D:65S96T@4&%R86UE=&5R
M.B`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@
M(E-E>6-H96QL96XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DX
M"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R(")%:6YK875F(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U;6UA
M<GDB"FUS9W-T<B`B2W5R>F4@6G5S86UM96YF87-S=6YG(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0T,PIM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES
M(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(E-O;&QE;B!4
M87-T96YK;VUB:6YA=&EO;F5N(&;\<B!D:64@;65I<W1E;B!,:6YK<R!A:W1I
M=FEE<G0@=V5R9&5N/R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3@P"FUS9VED(")3:&]W(@IM<V=S='(@(EIE:6=E;B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-30*;7-G:60@(B(*(E-H;W<@9&EF9F5R
M96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G
M96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB56YT97)S
M8VAI961E('IW:7-C:&5N(&1E<B!A:W1U96QL96X@=6YD(&1E<B!G97)A9&4@
M97)Z975G=&5N($MO;F9I9W5R871I;VX@(@HB86YZ96EG96XN(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0X-PIM<V=I9"`B4VAO=R!L87-T(&QO9VEN
M('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R(")!;GIE:6=E;BP@=V%N
M;B!D:64@;&5T>G1E($%N;65L9'5N9R!E<F9O;&=T(&ES=#\B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P=&EO;B!T
M;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(D5R:&%L=&5N(&1E<R!/<FEG:6YA
M;',@97)M]F=L:6-H96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#$S"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R(")!=7-WY&AL97(@86YZ
M96EG96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(S"FUS9VED(")3
M:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(E=E<FMZ
M975G;&5I<W1E(&;\<B!486)E;&QE;B!A;GIE:6=E;C\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S0V"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@
M=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(D1A<R`E<RU-96[\
M(&%U9B!D97(@;&EN:V5N(%-E:71E(&%N>F5I9V5N/R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I
M9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G
M<W1R(")$:6%L;V<@9OQR(%1A8F5L;&5N>F5L;&5N96EG96YS8VAA9G1E;B!A
M;GIE:6=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R
M=&EE<R!D:6%L;V<B"FUS9W-T<B`B1&EA;&]G(&;\<B!486)E;&QE;F5I9V5N
M<V-H869T96X@86YZ96EG96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A
M8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")$:6%L;V<@9OQR
M(%1A8F5L;&5N>F5I;&5N96EG96YS8VAA9G1E;B!A;GIE:6=E;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS
M9W-T<B`B1&EA;&]G(&;\<B!":6QD96EG96YS8VAA9G1E;B!A;GIE:6=E;B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C,*;7-G:60@(E-H;W<@
M=7!L;V%D(@IM<V=S='(@(DAO8VAL861E;B!E<FWV9VQI8VAE;B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3
M:&]W97)S(@IM<V=S='(@(E-C:&%U97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VAO=V5R<R!%87)L>2(*
M;7-G<W1R(")&<OQH(%-C:&%U97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S
M='(@(E-PY'1E<B!38VAA=65R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN
M:71Y(@IM<V=S='(@(E-C:&%U97(@:6X@9&5R(%5M9V5B=6YG(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV,3D*;7-G
M:60@(E-H<FEN:R(*;7-G<W1R(")697)K;&5I;F5R;B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3$P"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3<R"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`U.`HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q
M,C`*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HQ,3@S"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z,3(R,PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C$R-3(*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HQ,C@U"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG
M:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T
M<B`B5F5R:VQE:6YE<FX@;V1E<B!V97)S8VAI96)E;B!3:64@97)S="!D:64@
M8F5N86-H8F%R=&5N($)L]F-K92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-I
M97)R82!,96]N92(*;7-G<W1R(")3:65R<F$@3&5O;F4B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8V"FUS9VED(")3:6=N('5P(@IM
M<V=S='(@(E)E9VES=')I97)E;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-S$S"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`B4VEG
M;F%T=7(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q
M,@IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R(")3:6=N871U
M<F%L9V]R:71H;75S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E
M(@IM<V=S='(@(E-I;F=A<'5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(S-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8T(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Y,S`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S$R,PIM<V=I9"`B4VEZ92(*;7-G<W1R(")'<O;?92(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3
M:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(E=A<G1U;F=S87)B96ET96X@_&)E
M<G-P<FEN9V5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS
M9W-T<B`B4VQO=V%K96DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI
M82(*;7-G<W1R(")3;&]W96YI96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R(*;7-G<W1R(")38VAN
M964B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M.0IM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B4V-H;F5E<V-H875E<B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS
M9VED(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`B4V-H;F5E<V-H875E<B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED
M(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B1G+\:"!38VAN965S8VAA
M=65R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C(*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(E-PY'1E<B!3
M8VAN965S8VAA=65R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#`*;7-G
M:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R(")38VAN965H]FAE.B`B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(X-`IM<V=I9"`B4VYO=R!E<75I=F%L96YT
M(&EN('=A=&5R.B`B"FUS9W-T<B`B4V-H;F5E;65N9V4@86QS(%=A<W-E<CH@
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S
M='(@(E-O;&]M;VYI;G-E;&XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA
M;&EA(@IM<V=S='(@(E-O;6%L:65N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(DQI961E<B`F
M($=E9&EC:'1E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR-@IM
M<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B075S=V%H;"!D
M97(@4V]R=&EE<G)E:6AE;F9O;&=E(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$X.0IM<V=I9"`B4V]U<F-E
M(&%D9')E<W,B"FUS9W-T<B`B57)S<')U;F=S861R97-S92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R(")3_&1A9G)I:V$B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B4V]U=&@@175R
M;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(E/\9&5U<F]PY&ES8V@@*$E3
M3RTX.#4Y+3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA
M(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R(")3_&1G
M96]R9VEE;B!U;F0@9&EE(%/\9&QI8VAE;B!386YD=VEC:&EN<V5L;B(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*
M;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B4_QD;&EC:&4@
M2&5M:7-P:&5R92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT(&-E
M;&QS(@IM<V=S='(@(D%B<W1A;F0@>G=I<V-H96X@875F96EN86YD97(@9F]L
M9V5N9&5N(%IE;&QE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E;G0@
M86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(D%B<W1A;F0@>G=I<V-H96X@
M26YH86QT('5N9"!286AM96X@=F]N(%IE;&QE;B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C@Q-0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(D%B<W1A
M;F1H86QT97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B06)S=&%N
M9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B
M06)S=.1N9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B
M4W!A;FEE;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#`*;7-G
M:60@(E-P86TB"FUS9W-T<B`B4W!A;2(*"B,Z('-E<G9I8V5S+VME>6)O87)D
M+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T
M<B`B4V]N9&5R>F5I8VAE;BU%:6YG86)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@
M8V5L;"(*;7-G<W1R("):96QL92!T96EL96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI
M="!C;VQU;6XB"FUS9W-T<B`B4W!A;'1E('1E:6QE;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@
M(E-P;&ET(')O=R(*;7-G<W1R("):96EL92!T96EL96XB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E-P;W)T<R(*;7-G<W1R(")3<&]R
M="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(E-R
M:2!,86YK82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-B!L
M:6(O0FQO8VLO;65T87(N<&AP.C@Q"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R
M(")3=&%N9&%R9"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I
M9"`B4W1A<B!4<F5K(@IM<V=S='(@(E-T87(@5')E:R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(V,#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@P.0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R(")3=&%R=&IA:'(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,0IM<V=I9"`B
M4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B0G5N9&5S<W1A870@;V1E<B!0
M<F]V:6YZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ
M,3(*;7-G:60@(E-T871U<R(*;7-G<W1R(")3=&%T=7,B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#$U"FUS9VED(")3=&]R86=E(&9O<FUA="(*
M;7-G<W1R(")3<&5I8VAE<F9O<FUA="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")3=')E970@061D<F5S<R(*;7-G
M<W1R(")3=')AWV4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(D1U
M<F-H9V5S=')I8VAE;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,S,*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(EIE:6-H96YL:7-T92(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X.3$*;7-G:60@(E-T<FEP
M(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(D1O;6%I;B!A=7,@
M9&5R($%D<F5S<V4@96YT9F5R;F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-3
M4UTB"FUS9W-T<B`B4W1I;"!;0U-372(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(E-O
M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L('!H<"UF;W)M870*
M;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M(")5;G1E<G9E<GIE:6-H;FES(%PB)7-<(B!N:6-H="!G969U;F1E;BXB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS
M9VED(")3=6)J96-T(@IM<V=S='(@(D)E=')E9F8B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E
M<BYP:'`Z,S$X"FUS9VED(")3=6)M:70B"FUS9W-T<B`B06)S8VAI8VME;B(*
M"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B
M;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9
M;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E
M96X@87!P<F]V960N(@IM<V=S='(@(B(*(D1I92!296=I<W1R:65R=6YG<V%N
M9G)A9V4@9OQR(%PB)7-<(B!W=7)D92!A8F=E<V-H:6-K="X@4VEE(&OV;FYE
M;B!S:6-H(&YO8V@@(@HB;FEC:'0@86YM96QD96XL('-O;&%N9V4@9&EE($%N
M9G)A9V4@;F]C:"!N:6-H="!B97-TY'1I9W0@=W5R9&4N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B
M<V-R:7!T(@IM<V=S='(@(E1I969G97-T96QL="(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*
M;7-G<W1R(")%<F9O;&<B"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H
M92!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!W=7)D92!E<F9O;&=R96EC:"!H
M:6YZ=6=E9OQG="XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E
M<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")$871E;B!D97,@
M0F5N=71Z97)S(%PB)7-<(B!W=7)D92!E<F9O;&=R96EC:"!G96SV<V-H="XB
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP
M:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T
M960@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@=W5R9&4@97)F;VQG<F5I8V@@
M9V5L]G-C:'0N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H
M92!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!W=7)D92!E<F9O;&=R96EC:"!G
M96SV<V-H="XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED
M(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D
M('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("(B"B)+;VYF:6=U<F%T:6]N(&5R
M9F]L9W)E:6-H('IU<OQC:V=E<V5T>G0N(%-E:71E(&YE=2!L861E;BP@=6T@
M9&EE(,1N9&5R=6YG96X@(@HB86YZ=7IE:6=E;BXB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G
M:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B0F%C:W5P(&1E<B!+;VYF:6=U<F%T:6]N(&5R9F]L9W)E:6-H
M(&=E<W!E:6-H97)T+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B
M86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(")"86-K=7`@
M9&5R($MO;F9I9W5R871I;VX@)7,@97)F;VQG<F5I8V@@9V5S<&5I8VAE<G0N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@
M=W5R9&4@97)F;VQG<F5I8V@@86MT=6%L:7-I97)T(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S
M='(@(B5S('=U<F1E(&5R9F]L9W)E:6-H(&=E<W!E:6-H97)T(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-`IM<V=I9"`B4W5D86XB"FUS9W-T<B`B4W5D86XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS
M9VED(")3=6UM87)Y(@IM<V=S='(@(EIU<V%M;65N9F%S<W5N9R(*"B,Z(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T
M<B`B4V]N;F5N875F9V%N9R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV
M.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R(")3;VYN96YU;G1E<F=A;F<B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I
M9"`B4W5N;GDB"FUS9W-T<B`B4V]N;FEG(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(P-0IM<V=I9"`B4W5N<FES92(*;7-G<W1R(")3;VYN
M96YA=69G86YG(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G
M<W1R(")3;VYN96YA=68O=6YT97)G86YG(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(P-`IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(E-O
M;FYE;F%U9F=A;F<Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,#@*;7-G:60@(E-U;G-E="(*;7-G<W1R(")3;VYN96YU;G1E<F=A;F<B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`W"FUS9VED(")3
M=6YS970Z("(*;7-G<W1R(")3;VYN96YU;G1E<F=A;F<Z("(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U
M<&5R<V-R:7!T(@IM<V=S='(@(DAO8VAG97-T96QL="(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS.#`*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B
M4W5P<&]R="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM<V=S
M='(@(E-U<FEN86TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W-0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R(").86-H;F%M92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS
M9W-T<B`B4W9A;&)A<F0@=6YD($IA;B!-87EE;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*
M;7-G:60@(E-W87II;&%N9"(*;7-G<W1R(")3=V%S:6QA;F0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS9W-T<B`B4V-H=V5D96XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B4V-H=V5I>B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC
M(&QO9R!D96QE=&5D(@IM<V=S='(@(E-Y;F-H<F]N:7IA=&EO;G-L;V<@9V5L
M]G-C:'0B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*
M;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B
M1F]R;6%T9F5H;&5R(&EN(%-U8VAB96=R:69F96XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W
M"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R(")!<F%B:7-C
M:&4@4F5P=6)L:6L@4WER:65N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B1V5W
M:71T97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV-0IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B1V5W:71T
M97(@=6YD(%=I;F1I9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8V"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R(")'97=I='1E
M<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W
M"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R(")&<OQH($=E=VET=&5R
M(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W,`IM<V=I9"`B
M5%-6(&9I;&4B"FUS9W-T<B`B5%-6+41A=&5I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B
M;&4@4')O<&5R=&EE<R(*;7-G<W1R(")486)E;&QE;F5I9V5N<V-H869T96XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W
M"FUS9VED(")486)L92!3970B"FUS9W-T<B`B5&%B96QL92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G
M:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B5&%B96QL96YE:6=E;G-C
M:&%F=&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM
M<V=S='(@(E1A:7=A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM
M<V=S='(@(E1A:7=A;BP@8VAI;F5S:7-C:&4@4')O=FEN>B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B5&%D<V-H:6MI<W1A
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B5F5R96EN:6=T92!297!U8FQI:R!486YS86YI
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B6FEE;#HB"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDU."!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z
M,3`U.0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@Y"FUS9VED(")4
M87-K<R(*;7-G<W1R(")!=69G86)E;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3<T"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM
M<V=S='(@(E1E;&5F;VYN=6UM97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(Y,@IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B5&5M
M<&5R871U<B!D97(@;&5T>G1E;B!3='5N9&4Z("(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C$V"FUS9VED(")496UP97)A='5R92(*;7-G<W1R(")496UP
M97)A='5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,@IM
M<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R(")496UP97)A='5R.B`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@R"B,L('!H<"UF;W)M
M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D
M96<[)7,B"FUS9W-T<B`B5&5M<&5R871U<CQB<B`O/B@E<TUA>"5S+R5S36EN
M)7,I("9D96<[)7,B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N
M<&AP.C8Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@
M;F]T(&9O=6YD+B(*;7-G<W1R(")6;W)L86=E(%PB)7-<(B!N:6-H="!G969U
M;F1E;BXB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M
M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B5F]R;&%G96YV97)W86QT
M=6YG(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,S0U"FUS9VED(")497AT(@IM<V=S='(@(E1E
M>'0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<R"FUS9VED(")497AT
M($]N;'DB"FUS9W-T<B`B3G5R(%1E>'0B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L
M:6=N(@IM<V=S='(@(D%U<W)I8VAT=6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G
M<W1R(")497AT($]B96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R(")$;R(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")4:&%I("A425,M-C(P*2(*
M;7-G<W1R(")4:&%I;.1N9&ES8V@@*%1)4RTV,C`I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B5&AA:6QA;F0B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C@V,PIM<V=I9"`B5&AE($944"!E>'1E
M;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B1&EE($944"U%>'1E
M;G-I;VX@:7-T(&YI8VAT('9E<F;\9V)A<BXB"@HC.B!F<F%M97=O<FLO2&ES
M=&]R>2](:7-T;W)Y+G!H<#HU-0IM<V=I9"`B5&AE($AI<W1O<GD@<WES=&5M
M(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")$:64@0VAR;VYI:R!S=&5H="!N:6-H
M="!Z=7(@5F5R9OQG=6YG+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.38T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I
M;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS
M9W-T<B`B1&EE($AO<F1E+TMO;&%B($EN=&5G<F%T:6]N<V9U;FMT:6]N96X@
M=6YT97)S=/QT>F5N(%PB)7-<(B!N:6-H="(*"B,Z(&9R86UE=V]R:R].971?
M24U34"])35-0+T)O;VLN<&AP.C$R.3@*;7-G:60@(E1H92!)35-0(&QO9R!C
M;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(D1I92!)35-0+4QO
M9V1A=&5I(&MO;FYT92!N:6-H="!E<G-T96QL="!W97)D96XN(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N
M8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@
M(D1I92!-86EN=&5N86YC93HZ($ML87-S92!K;VYN=&4@;FEC:'0@9V5L861E
M;B!W97)D96XB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP
M.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI
M=&EN9RXB"FUS9W-T<B`B1&%S($5I;G-T96QL=6YG96XM1F5N<W1E<B!I<W0@
M9V5S8VAL;W-S96X@=V]R9&5N+B!!8F)R=6-H+B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,3DP(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,C`Q"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$R(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C,U(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4S"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8U(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,S`T"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D
M<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N
M9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@
M(B(*(D1E<B!!9&UI;FES=')A=&]R(&UU<W,@96EN('!E<FUA;F5N=&5S(%)E
M8VAT92U"86-K96YD(&5I;G)I8VAT96XL('=E;FX@4VEE("(*(F1I92!296-H
M=&5V97)W86QT=6YG(&YU='IE;B!M]F-H=&5N+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H
M92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(DYU<B!U;G1E;B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS
M9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I
M960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T
M86)A<V4N(@IM<V=S='(@(B(*(D1I92!)1"U.=6UM97(@9&5S($MO;G1A:W1S
M('=U<F1E(&YI8VAT(&%N9V5B96XL('=A<B!L965R(&]D97(@:V]N;G1E(&EN
M(&1E<B`B"B)$871E;F)A;FL@;FEC:'0@9V5F=6YD96X@=V5R9&5N+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I
M9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R
M(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B1&5R($MO;G1A:W0@=W5R9&4@97)F
M;VQG<F5I8V@@26AR96T@061R97-S8G5C:"!H:6YZ=6=E9OQG="XB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3@Q"FUS9VED("(B"B)4
M:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T
M;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"B)$97(@
M4$=0+5-I9VYA='5R8FQO8VL@=VER9"!B96[V=&EG="P@=6T@9&EE('5N=&5R
M>F5I8VAN971E($YA8VAR:6-H="!Z=2`B"B+\8F5R<'+\9F5N+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS
M9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N
M;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T
M:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*(D1I92!)1"U.=6UM97(@9&5R(%9E
M<G1E:6QE<FQI<W1E('=U<F1E(&YI8VAT(&%N9V5B96XL('=A<B!L965R(&]D
M97(@:V]N;G1E("(*(FEN(&1E<B!$871E;F)A;FL@;FEC:'0@9V5F=6YD96X@
M=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S
M(&YO="!S<&5C:69I960N(@IM<V=S='(@(D1I92!697)T96EL97)L:7-T92!W
M=7)D92!N:6-H="!A;F=E9V5B96XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+G!H<#HQ,38*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E
M<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*(D1I
M92!697)S8VAL_'-S96QU;F=S9G5N:W1I;VYE;B!B96[V=&EG96X@96EN92!S
M:6-H97)E(%-E<G9E<G9E<F)I;F1U;F<N(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ.#8@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A
M:6X@82`E<R!S971T:6YG+B(*;7-G<W1R(")$:64@1&%T96D@)7,@<V]L;'1E
M(&5I;F5N("5S($5I;G1R86<@96YT:&%L=&5N+B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M-3$R"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C
M;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(D1I92!$871E:2`E
M<R!S;VQL=&4@96EN:6=E("5S($5I;G1RY&=E(&5N=&AA;'1E;BXB"@HC.B!F
M<F%M97=O<FLO1&%T82]$871A+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O
M;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")$:64@1&%T96D@96YT:&EE;'0@
M:V5I;F4@1&%T96XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE
M861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T
M<B`B2&EE<B!S:6YD(&1I92!+;W!F96EN='+D9V4@9OQR(&1I97-E(&UE<W-A
M9V4O<F9C.#(R($YA8VAR:6-H="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E
M96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R
M;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@
M=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I
M96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T
M:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO
M=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T
M('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A
M;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N
M("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y
M('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*(D1E<B!6;VQL
M8FEL9&UO9'5S('9E<G5R<V%C:'0@875F($=R=6YD('9O;B!&96AL97)N(&EM
M($EN=&5R;F5T($5X<&QO<F5R("(*(F)E:V%N;G1E<FUAWV5N(%!R;V)L96UE
M(&UI="!D:65S96T@0G)O=W-E<BP@9&EE('=I<B!N:6-H="!U;6=E:&5N(&OV
M;FYE;BX@(@HB56YT97(@56US=.1N9&5N(&5R:&%L=&5N(%-I92!E:6YE(&9E
M:&QE<FAA9G1E($%N>F5I9V4L(&9E:&QE;B`B"B)%9&ET;W)F=6YK=&EO;F5N
M+"!O9&5R(&1E<B!"<F]W<V5R('-T_')Z="!A8BX@075F(&5I;F5M(%=I;F1O
M=R`Y>"!3>7-T96T@(@HB=V5R9&5N(%-I92!V97)M=71L:6-H(&5I;F4@)T%L
M;&=E;65I;F4@4V-H=71Z=F5R;&5T>G5N9R<@97)H86QT96X@=6YD(&W\<W-E
M;B`B"B)D96X@4F5C:&YE<B!N974@<W1A<G1E;BY<7&Y<7&Y3:64@=W5R9&5N
M(&=E=V%R;G0N($)I='1E(&1R_&-K96X@4VEE(&%U9B!/2RP@(@HB=V5N;B!3
M:64@;F]C:"!I;6UE<B!D96X@5F]L;&)I;&1M;V1U<R!V97)W96YD96X@;?9C
M:'1E;BXB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3$Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E
M9"XB"FUS9W-T<B`B1&EE($ED96YT:73D="!<(B5S7"(@=W5R9&4@9V5L]G-C
M:'0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS
M9W-T<B`B3G5R(&QI;FMS(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'
M(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S
M<RXB"FUS9W-T<B`B(@HB1&5R($]R="!D97,@1VYU4$<M4')O9W)A;6US(&UU
M<W,@9&5R($-R>7!T7W!G<#HZ($ML87-S92#\8F5R9V5B96X@=V5R9&5N+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR,#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W
M:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H
M:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@
M<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"B)$:64@3F%C:')I8VAT
M(&UI="!D96T@0F5T<F5F9B!<(B4S)'-<(BP@9&EE(&%M("4Q)',@86X@)3(D
M<R!G97-C:&EC:W0@=W5R9&4L("(*(FES="!A;F=E>F5I9W0@=V]R9&5N+EQN
M(@HB1&%S(&AE:=]T(&YI8VAT+"!D87-S(&1I92!.86-H<FEC:'0@875C:"!G
M96QE<V5N(&]D97(@=F5R<W1A;F1E;B!W=7)D92XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#DU"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE
M;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B3F%M92!F
M_'(@9&5N($QI;FL@>G5R($YA8VAR:6-H=&5N97)S=&5L;'5N9R(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0W-`IM<V=I9"`B5&AE(&YU;6)E
M<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R(")$:64@06YZ
M86AL(&1E<B!&96QD97(@;75S<R!A;',@6F%H;"!A;F=E9V5B96X@=V5R9&5N
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,@IM
M<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@
M2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B1&%S($]P96Y3
M4TPM36]D=6P@=VER9"!F_'(@9&EE($AO<F1E7T-R>7!T7W-M:6UE.CH@2VQA
M<W-E(&)E;O9T:6=T+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z
M,C@X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB
M)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E
M961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B
M"B)$:64@0F5N=71Z97)E:6YS=&5L;'5N9R!<(B5S7"(@:V]N;G1E(&YI8VAT
M(&=E<W!E:6-H97)T('=E<F1E;BP@=V5I;"!I:')E("(*(D1A=&5N(&1I92!M
M87AI;6%L(&5R;&%U8G1E($=R]M]E(/QB97)S8VAR96ET96XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI
M<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN
M(@IM<V=S='(@(B(*(D1A<R!0<F]G<F%M;2!F_'(@9&EE($%N>F5I9V4@9&EE
M<V5S($1A=&5I='EP<R`H)7,I('=U<F1E(&YI8VAT(&=E9G5N9&5N+B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0X-PIM<V=I9"`B5&AE('%U
M;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*
M;7-G<W1R(")$87,@06YF_&AR=6YG<WIE:6-H96X@;75S<R!A;',@96EN>F5L
M;F5S(%IE:6-H96X@86YG96=E8F5N('=E<F1E;BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4
M:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R(").=7(@;&EN
M:W,@=6YD(')E8VAT<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I
M9&4@;VYL>2(*;7-G<W1R(").=7(@<F5C:'1S(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z-#<Y"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@
M8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(D1A<R!4<F5N;GIE
M:6-H96X@;75S<R!A;',@96EN>F5L;F5S(%IE:6-H96X@86YG96=E8F5N('=E
M<F1E;BXB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D
M96QE=&5D+B(*;7-G<W1R(")$97(@4V5R=F5R(%PB)7-<(B!W=7)D92!E;G1F
M97)N="XB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S
M879E9"XB"FUS9W-T<B`B1&5R(%-E<G9E<B!<(B5S7"(@=W5R9&4@9V5S<&5I
M8VAE<G0N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M
M;W9E9"XB"FUS9W-T<B`B1&EE(%)E9VES=')I97)U;F=S86YF<F%G92!V;VX@
M)7,@=W5R9&4@96YT9F5R;G0N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HT-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="XB"FUS9W-T
M<B`B1&EE(&%N9V5G96)E;F4@6F5I;&4@*"5D*2!E>&ES=&EE<G0@;FEC:'0N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,C(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO
M="!E>&ES="XB"FUS9W-T<B`B1&EE('1E;7!O<N1R92!$871E:2!<(B5S7"(@
M97AI<W1I97)T(&YI8VAT+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S,C`*;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T
M8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B(@HB1&5R(%1E
M>'0L(&1E;B!3:64@86YG96=E8F5N(&AA8F5N+"!E;G1S<')I8VAT(&YI8VAT
M(&1E;2!497AT(&%U9B!D96T@(@HB0FEL9'-C:&ER;2XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED
M(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R(").=7(@
M;V)E;B!U;F0@=6YT96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL
M>2(*;7-G<W1R(").=7(@;V)E;B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N
M<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN
M8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(B(*(D1I92!H;V-H9V5L
M861E;F5N($1A=&5N('-I;F0@;F%C:"!D96T@;&5T>G1E;B!38VAR:71T('9E
M<FQO<F5N(&=E9V%N9V5N+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O8W-V
M+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W-@IM<V=I
M9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G
M<W1R(")$:64@:&]C:&=E;&%D96YE($1A=&5I(&MO;FYT92!N:6-H="!G97-P
M96EC:&5R="!W97)D96XN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C0Y(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3`*;7-G:60@
M(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R(")$97(@=V5A=&AE<BYC;VT@0FQO8VL@:7-T(&YI8VAT('9E<F;\9V)A
M<BXB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R(")4:&5M96XM5F5R>F5I8VAN:7,@7"(E<UPB(&YI8VAT(&=E9G5N
M9&5N+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X"FUS
M9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@
M(D5S('-I;F0@:V5I;F4@16EN<W1E;&QU;F=E;B!V97)F_&=B87(N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z,S0Y"FUS9VED(")4
M:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN
M92XB"FUS9W-T<B`B17,@9VEB="!K96EN92!A;GIE:6=B87)E;B!.86-H<FEC
M:'1E;G1E:6QE+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H
M87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C
M:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM
M<V=S='(@(B(*(D1I97-E<R!&96QD(&5N=&CD;'0@>G4@=FEE;&4@6F5I8VAE
M;BX@4VEE(&AA8F5N("5S(%IE:6-H96X@86YG96=E8F5N.R!3:64@(@HB;?QS
M<V5N('=E;FEG97(@86QS("5S(&%N9V5B96XN(@H*(SH@<VEG;G5P+G!H<#HU
M,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@
M)7,B"FUS9W-T<B`B0F5I;2!(:6YZ=6;\9V5N('9O;B!<(B5S7"(@>G5M(%-Y
M<W1E;2!I<W0@96EN(%!R;V)L96T@875F9V5T<F5T96XZ("5S(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O
M;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@HB0F5I;2!,]G-C:&5N(&1E<B!$
M871E;B!V;VX@0F5N=71Z97(@7"(E<UPB(&ES="!E:6X@4')O8FQE;2!A=69G
M971R971E;CH@(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB
M(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(D)E:6T@3/9S8VAE;B!V;VX@
M7"(E<UPB(&%U<R!D96T@4WES=&5M(&ES="!E:6X@4')O8FQE;2!A=69G971R
M971E;CH@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E
M<R(*;7-G<W1R(")"96EM($%K='5A;&ES:65R96X@=F]N(%PB)7-<(B!I<W0@
M96EN(%!R;V)L96T@875F9V5T<F5T96XZ("5S(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.3(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S
M('=A<R!U<&QO861E9"XB"FUS9W-T<B`B(@HB0F5I;2!(;V-H;&%D96X@9&5R
M($1A=&5I(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B`E<R!W=7)D92!N
M:6-H="`B"B)H;V-H9V5L861E;BXB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"
M<F]W<V5R+G!H<#HY,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A
M<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D
M(&)Y=&5S*2XB"FUS9W-T<B`B(@HB0F5I;2!(;V-H;&%D96X@9&5R($1A=&5I
M(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B`E<R!W87(@9W+VWV5R(&%L
M<R!D:64@(@HB;6%X:6UA;"!E<FQA=6)T92!'<O;?92`H)60@0GET97,I+B(*
M"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDS,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE
M(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A
M9&5D+B(*;7-G<W1R("(B"B)"96EM($AO8VAL861E;B!D97(@1&%T96D@:7-T
M(&5I;B!&96AL97(@875F9V5T<F5T96XN("5S('=U<F1E(&YU<B!T96EL=V5I
M<V4@(@HB:&]C:&=E;&%D96XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B0F5I;2!!
M;GIE:6=E;B!D:65S97,@3F%C:')I8VAT96YT96EL<R!I<W0@96EN($9E:&QE
M<B!A=69G971R971E;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T
M:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(D)E:6T@26UP;W)T:65R
M96X@9&5R($MO;G1A:W1D871E;B!I<W0@96EN($9E:&QE<B!A=69G971R971E
M;BXB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S`*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D
M871A+B(*;7-G<W1R(")"96EM($EM<&]R=&EE<F5N(&1E<B!I0V%L96YD87(@
M1&%T96X@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HX,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R
M<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE
M9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*(D1A<R!+
M;VYF:6=U<F%T:6]N<RU&;W)M=6QA<B!E;G1H:65L="!E:6YE;B!&96AL97(N
M(%9I96QL96EC:'0@:&%B96X@4VEE(&5I;B`B"B)09FQI8VAT9F5L9"!L965R
M(&=E;&%S<V5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO
M;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB0F5I
M;2!!=7-F_&AR96X@9&5R(&%N9V5G96)E;F5N($%D<F5S<V)U8VAF=6YK=&EO
M;B!I<W0@96EN($9E:&QE<B`B"B)A=69G971R971E;BX@0FET=&4@=F5R<W5C
M:&5N(%-I92!E<R!S<.1T97(@;F]C:"!E:6YM86PN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*
M(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A
M:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B)"96D@
M9&5R($%K='5A;&ES:65R=6YG(&1E<B!+;VYT86MT9&5T86EL<R!I<W0@96EN
M($9E:&QE<B!A=69G971R971E;BX@0FET=&4@(@HB=F5R<W5C:&5N(%-I92!E
M<R!S<.1T97(@;F]C:"!E:6YM86PN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S
M92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(D)E:2!D97(@06MT=6%L
M:7-I97)U;F<@9&5R(%9E<G1E:6QE<FQI<W1E(&ES="!E:6X@1F5H;&5R(&%U
M9F=E=')E=&5N+B!":71T92`B"B)V97)S=6-H96X@4VEE(&5S('-PY'1E<B!N
M;V-H(&5I;FUA;"XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ-#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,CDY"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U
M<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R(")$:65S97(@24U!4"U3
M97)V97(@=6YT97)S=/QT>G0@:V5I;F4@9V5M96EN<V%M96X@3W)D;F5R+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G
M:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R
M8VAI=F4N(@IM<V=S='(@(D1I97,@<V-H96EN="!K96EN(&?\;'1I9V5S(%)!
M4BU!<F-H:78@>G4@<V5I;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R(")$:65S('-C:&5I;G0@
M:V5I;B!G_&QT:6=E<R!:25`M07)C:&EV('IU('-E:6XN(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S$T-0IM<V=I9"`B5&AI<R!D;V5S(&YO="!S
M965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(D1I97,@
M<V-H96EN="!K96EN92!G_&QT:6=E($MA<G1E;FYU;6UE<B!Z=2!S96EN+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L
M:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS
M9W-T<B`B(@HB1&EE<V5R(%1R96EB97(@97)L875B="!D87,@5F5R<V-H:6-K
M96X@=F]N($YA8VAR:6-H=&5N(&1U<F-H(&1E;B!#;&EC:V%T96QL+2(*(D=A
M=&5W87D@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@;6ET($AI;&9E(&1E<B!(
M5%10+4%022XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O
M;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*
M(D1I97-E<B!4<F5I8F5R(&5R;&%U8G0@9&%S(%9E<G-C:&EC:V5N('9O;B!.
M86-H<FEC:'1E;B!D=7)C:"!D96X@5TE.+4=A=&5W87D@(@HB*&AT='`Z+R]W
M:6YP;&,N8V]M*2!M:70@2&EL9F4@9&5R($A45%`M05!)+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M
M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB1&EE
M<V5R(%1R96EB97(@97)L875B="!D87,@5F5R<V-H:6-K96X@=F]N($YA8VAR
M:6-H=&5N(&1U<F-H(&1E;B!S;7,R;6%I;"TB"B)'871E=V%Y("AH='1P.B\O
M<VUS,FUA:6PN8V]M*2!M:70@2&EL9F4@9&5R($A45%`M05!)+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G
M871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S
M(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T
M<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"B)$:65S97(@5')E:6)E<B!E
M<FQA=6)T(&1A<R!697)S8VAI8VME;B!V;VX@3F%C:')I8VAT96X@<&5R(%--
M5%`@9'5R8V@@9&5N("(*(E9O9&%F;VYE+4ET86QI96XM1V%T97=A>2!A=7-S
M8VAL:67?;&EC:"!A;B!6;V1A9F]N92U.=6UM97)N+B!$86;\<B!W:7)D(&5I
M;B`B"B)%+4UA:6PM2V]N=&\@8F5I(%9O9&%F;VYE($ET86QI96X@*&AT='`Z
M+R]W=W<N,3DP+FET*2!B96[V=&EG="XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`U-PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X,B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y.`HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-34W(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW
M-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(S"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P-#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Y
M-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,38W(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C0R-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#8X"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(V-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@R.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3,W(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S,34*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S@R,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#,Q"FUS9VED(")4
M:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R(")$:65S97,@1F5L9"!I
M<W0@;F]T=V5N9&EG+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P
M-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R
M<RXB"FUS9W-T<B`B1&EE<V5S($9E;&0@9&%R9B!N=7(@9V%N>F4@6F%H;&5N
M(&5N=&AA;'1E;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#,T
M"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A
M;F0@=&AE(&-O;&]N+B(*;7-G<W1R(")$:65S97,@1F5L9"!D87)F(&YU<B!:
M86AL96X@=6YD(&5I;F5N(%!U;FMT(&5N=&AA;'1E;BXB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#DT"FUS9VED(")4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R(")$:65S97,@1F5L
M9"!D87)F(&YU<B!/:W1A;'IA:&QE;B!E;G1H86QT96XN(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T
M(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E
M<G,B"FUS9W-T<B`B(@HB1&EE<V5S($9E;&0@;75S<R!E:6YE(&MO;6UA+2!O
M9&5R(&QE97)Z96EC:&5N9V5T<F5N;G1E($QI<W1E('9O;B!G86YZ96X@(@HB
M6F%H;&5N(&5N=&AA;'1E;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.CDX.0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R
M+B(*;7-G<W1R(")$:65S97,@1F5L9"!M=7-S(&5I;F4@9_QL=&EG92!:86AL
M(&5N=&AA;'1E;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V
M"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O
M9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R
M,S1A9B<N(@IM<V=S='(@(B(*(D1I97-E<R!&96QD(&UU<W,@96EN96X@1F%R
M8G=E<G0@:6T@:&5X861E>FEM86QE;B!21T(M1F]R;6%T(&5N=&AA;'1E;BP@
M>BX@0BX@(@HB)R,Q,C,T868G+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C4V,0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O
M8V5S<V5D+B(*;7-G<W1R(")$:65S97,@1F]R;75L87(@=W5R9&4@8F5R96ET
M<R!V97)A<F)E:71E="XB"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R(")$
M:65S(&ES="`E<RXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0Y
M-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O
M=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N
M965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+
M;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA
M:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@HB1&EE
M(&ES="!E:6X@2V]L86(M1W)O=7!W87)E+4]B:F5K="X@56T@9&EE<V5S($]B
M:F5K="!A;GIU>F5I9V5N+"!B96[V=&EG96X@(@HB4VEE(&5I;B!%+4UA:6PM
M4')O9W)A;6TL(&1A<R!D87,@2V]L86(M1W)O=7!W87)E+49O<FUA="!U;G1E
M<G-T_'1Z="X@16EN92`B"B),:7-T92!S;VQC:&5R(%!R;V=R86UM92!F:6YD
M96X@4VEE('5N=&5R("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z-3DY"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G
M92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T
M:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"B)$:65S92!.86-H<FEC:'0@=W5R
M9&4@:6X@96EN96T@6F5I8VAE;G-A='H@*"5S*2!E<G-T96QL="P@9&5R(&YI
M8VAT($EH<F5M("(*(F5I9V5N96X@96YT<W!R:6-H="XB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@
M;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(D1I97-E(%IA:&P@;75S
M<R`Q(&]D97(@9W+VWV5R('-E:6XN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG
M="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B1&EE
M<V5R(%-E<G9E<B!K86YN(%I)4"T@=6YD($=:25`M1&%T96EN(&YI8VAT(&5N
M='!A8VME;BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN
M<&AP.C$X-@IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T
M:79A=&5D+B(*;7-G<W1R(")$:65S97,@4WES=&5M(&ES="!Z=7(@6F5I="!D
M96%K=&EV:65R="XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G
M<W1R(")$:65S97(@5V5R="!M=7-S(&5I;F4@6F%H;"!S96EN+B(*"B,Z('-E
M<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@
M=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B
M"FUS9W-T<B`B1&EE<V5S($9E;G-T97(@;75S<R!V;VX@96EN96T@16EN<W1E
M;&QU;F=E;BU&96YS=&5R(&=E]F9F;F5T('=E<F1E;B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")4:'5N9&5R
M(@IM<V=S='(@(D1O;FYE<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,S8*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B5&EC:V5T<R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-#,@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C4W"FUS9VED(")4:6UE(@IM<V=S='(@(EIE:70B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@X"FUS9VED(")4:6UE(%1R86-K
M:6YG(@IM<V=S='(@(EIE:71E<F9A<W-U;F<B"@HC.B!L:6(O0FQO8VLO=&EM
M92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(EIE:71F;W)M
M870B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-30Y"FUS9VED(")4
M:6UE('-E;&5C=&EO;B(*;7-G<W1R("):96ET875S=V%H;"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(E1I;6]R+4QE<W1E
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R
M.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T
M<B`B5&ET96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(E1I
M=&5L("A4;V]L=&EP*3HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R(")!;B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-30*;7-G:60@
M(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#
M;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI
M8VMI;F<N(@IM<V=S='(@(B(*(DAA;'1E;B!3:64@8F5I;2!+;&EC:V5N(%-T
M<F<@8GIW+B`H4$,I($-O;6UA;F0@*$UA8RD@9V5D<OQC:W0L('5M(&UE:')E
M<F4@(@HB16EN='+D9V4@875S>G5WY&AL96XN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,P,`IM<V=I9"`B5&]D87DB"FUS9W-T<B`B2&5U
M=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B6G4@2%1-
M3"U1=65L;&-O9&4@=6US8VAA;'1E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@
M(E1O9V\B"FUS9W-T<B`B5&]G;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O
M:V5L874B"FUS9W-T<B`B5&]K96QA=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,#(*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(DUO<F=E
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S='(@(E1O;F=A
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K;VQA8BYP:'`Z,3`T"FUS9VED
M(")4;V\@;6%N>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA<W0@;6EN
M=71E<RXB"FUS9W-T<B`B6G4@=FEE;&4@=6YG_&QT:6=E($%N;65L9&5V97)S
M=6-H92!I;B!D96X@;&5T>G1E;B!-:6YU=&5N+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P
M(@IM<V=S='(@(D]B96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S
M='(@(L1UWV5R<W1E<B!286AM96X@*%]T;W`I(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`BW&)E
M<G-E='IU;F=E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N
M9"!4;V)A9V\B"FUS9W-T<B`B5')I;FED860@=6YD(%1O8F%G;R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W.3`*;7-G:60@(E1R=64@;W(@9F%L
M<V4B"FUS9W-T<B`B5V%H<B!O9&5R(&9A;'-C:"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S
M='(@(D1I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R
M(")4=6YE<VEE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G
M<W1R(")4_')K96DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I
M9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B5/QR:VES8V@@*$E3
M3RTX.#4Y+3DI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N
M(@IM<V=S='(@(E1U<FMM96YI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@
M(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R(")4=7)K<RT@=6YD
M($-A:6-O<VEN<V5L;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*
M;7-G<W1R(")4=79A;'4B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<S
M"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B26AR92!!=7-W
M86AL.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4X"FUS
M9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B558M26YD97@Z("(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")(;VUE<&%G
M92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T
M871U<R!R97!O<G0B"FUS9W-T<B`B55),($EH<F5S(%-K<FEP=',@9OQR(&1E
M;B!697)S86YD<W1A='5S8F5R:6-H="(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T<B`B
M061R97-S93HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T
M<B`B56=A;F1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G
M<W1R(")5:W)A:6YE(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M-#(X"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM
M<V=S='(@(D%U9B!D87,@5D93+59E<GIE:6-H;FES(&MO;FYT92!N:6-H="!Z
M=6=E9W)I9F9E;B!W97)D96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3
M:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@
M:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("(B"B)$:64@
M>G5SY'1Z;&EC:&5N($)E;G5T>F5R:6YF;W)M871I;VYE;B!K;VYN=&5N(&)E
M:2!D97(@4F5G:7-T<FEE<G5N9R!N:6-H="`B"B)H:6YZ=6;\9W0@=V5R9&5N
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,SDU"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"B)$:64@6G5G<FEF9G-R96-H
M=&4@9OQR(&1I92!61E,M1&%T96D@7"(E<UPB(&MO;FYT96X@;FEC:'0@9V7D
M;F1E<G0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C0P,2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#<Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@
M5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(B(*(D1I92!:=6=R:69F<W)E8VAT
M92!F_'(@9&EE(%9&4RU$871E:2`E<R\E<R!K;VYN=&5N(&YI8VAT(&=EY&YD
M97)T('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Y
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S
M+B(*;7-G<W1R(")%<R!K86YN(&YI8VAT(&EN(%9E<GIE:6-H;FES("5S(&=E
M=V5C:'-E;'0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I
M;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(D1I92!'<O;?92!V;VX@7"(E
M<UPB(&MO;FYT92!N:6-H="!B97-T:6UM="!W97)D96XN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z-C4@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HY-`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ
M92!O9B!<(B5S+R5S7"(N(@IM<V=S='(@(D1I92!'<O;?92!V;VX@7"(E<R\E
M<UPB(&MO;FYT92!N:6-H="!B97-T:6UM="!W97)D96XN(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S.0IM<V=I9"`B56YA8FQE('1O(&-O
M;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B5F5R8FEN9'5N9R!Z=6T@
M4U%,(%-E<G9E<B!K86YN(&YI8VAT(&AE<F=E<W1E;&QT('=E<F1E;BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@X,@IM<V=I9"`B56YA8FQE
M('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(E-33"U697)B:6YD=6YG
M(&MO;FYT92!N:6-H="!H97)G97-T96QL="!W97)D96XN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C0Q(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C(T-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,C,S(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,S@*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(T-@IM<V=I9"`B56YA8FQE
M('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(D1I92!61E,M1&%T96D@:V]N
M;G1E(&YI8VAT(&MO<&EE<G0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,S<R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(D1A<R!6
M1E,M5F5R>F5I8VAN:7,@7"(E<UPB(&MO;FYT92!N:6-H="!A;F=E;&5G="!W
M97)D96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S<P(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-CD*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C(Y,PIM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")$87,@5D93+59E<GIE:6-H;FES
M(&MO;FYT92!N:6-H="!A;F=E;&5G="!W97)D96XN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$R,PIM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!61E,@9FEL92XB"FUS9W-T<B`B1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC
M:'0@86YG96QE9W0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z,S`S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A
M=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(D1A<R!61E,M5F5R>F5I
M8VAN:7,@7"(E<UPB(&MO;FYT92!N:6-H="!A;F=E;&5G="!W97)D96XN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@Q"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R("),965R92!6
M1E,M1&%T96D@:V]N;G1E(&YI8VAT(&%N9V5L96=T('=E<F1E;BXB"@HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H<#HW-0HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-3(*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C@R"FUS9VED(")5;F%B
M;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R(")$:64@1&%T96X@:V]N
M;G1E;B!N:6-H="!D96MO;7!R:6UI97)T('=E<F1E;BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C(S,2!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C,P,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@
M(EPB)7-<(B!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N+"!D87,@5F5R
M>F5I8VAN:7,@:7-T(&YI8VAT(&QE97(N(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B
M7"(E<UPB(&MA;FX@;FEC:'0@9V5L]G-C:'0@=V5R9&5N.B`E<RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-#<@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HT-3`*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C,R,B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S@Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E
M8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(B5S(&MO;FYT92!N:6-H="!G
M96SV<V-H="!W97)D96XL(&1A<R!697)Z96EC:&YI<R!I<W0@;FEC:'0@;&5E
M<B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HT,#,@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C0P-PIM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R
M(")$87,@5D93+59E<GIE:6-H;FES(&MO;FYT92!N:6-H="!R96MU<G-I=B!G
M96SV<V-H="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,S4S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,S,*(SH@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T-B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,S4T"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS.3D*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B1&%S(%9&4RU697)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@
M9V5L]G-C:'0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z-#<U(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#@W"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@
M)7,N(@IM<V=S='(@(D1A<R!61E,M5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT
M(&=E;/9S8VAT('=E<F1E;CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HR,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D1I92!61E,M1&%T96D@
M7"(E<UPB(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S$Y(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z,S,T"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ
M-C8@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$W.0HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@V(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HT,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C0T-@IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS
M9W-T<B`B1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R
M9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C4Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B!<
M(B5S7"(N(@IM<V=S='(@(D1A<R!61E,M5F5R>F5I8VAN:7,@7"(E<UPB(&MO
M;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HT-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R(")$87,@
M5D93(&MO;FYT92!N:6-H="!R96MU<G-I=B!G96SV<V-H="!W97)D96XZ("5S
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#0V"FUS9VED(")5
M;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R
M(")$87,@86MT=65L;&4@5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT(&)E<W1I
M;6UT('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8P-`IM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@
M9&5T86EL<R(*;7-G<W1R(")$:64@6F5R=&EF:6MA=&1E=&%I;',@:V]N;G1E
M;B!N:6-H="!A=7-G96QE<V5N('=E<F1E;B(*"B,Z(&9R86UE=V]R:R].971?
M24U34"])35-0+G!H<#HT,S<@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T
M:"YP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D
M('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R(")$97(@)7,M5')E:6)E
M<B!K;VYN=&4@;FEC:'0@9V5L861E;B!W97)D96XN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C$Q(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(Q-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3DX
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#,*;7-G:60@(E5N
M86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R(")$:64@5D93+41A=&5I
M(&MO;FYT92!N:6-H="!V97)S8VAO8F5N('=E<F1E;BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.CDS(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z,3`V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C<T(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B1&EE
M(%9&4RU$871E:2!<(B5S7"(@:V]N;G1E(&YI8VAT(&=E]F9F;F5T('=E<F1E
M;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.3,@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$U-PHC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,38P"FUS9VED(")5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B1&EE(%9&4RU$871E:2!K
M;VYN=&4@;FEC:'0@>G5M($)E<V-H<F5I8F5N(&=E]F9F;F5T('=E<F1E;BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX-B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HQ-#`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.CDU"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB
M"FUS9W-T<B`B1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@9V7V9F9N970@
M=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV
M92XB"FUS9W-T<B`B1&%S($%R8VAI=B!K;VYN=&4@;FEC:'0@9V7V9F9N970@
M=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-#,*;7-G:60@
M(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN
M(@IM<V=S='(@(D1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT(&=E;&5S96X@
M=V5R9&5N("AF:6QE<VEZ92@I(&9E:&QG97-C:&QA9V5N*2XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z.#<X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!6
M1E,@9FEL92`H<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(D1I92!61E,M1&%T
M96D@:V]N;G1E(&YI8VAT(&=E;&5S96X@=V5R9&5N("AS:7IE*"D@9F5H;&=E
M<V-H;&%G96XI+B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA8FQE('1O(')E860@
M9FEL93H@(@IM<V=S='(@(D1I92!$871E:2!K;VYN=&4@;FEC:'0@9V5L97-E
M;B!W97)D96XZ("(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Y
M,0IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y
M+B(*;7-G<W1R(")$87,@=F9S<F]O="U697)Z96EC:&YI<R!K;VYN=&4@;FEC
M:'0@9V5L97-E;B!W97)D96XN(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HQ,30V"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T
M<R(*;7-G<W1R("(B"B(E<R!K;VYN=&4@;FEC:'0@;F%C:"`E<R!U;6)E;F%N
M;G0@=V5R9&5N.B!$87,@6FEE;'9E<GIE:6-H;FES(&5X:7-T:65R="`B"B)B
M97)E:71S(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T
M,@IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G
M<W1R(")$87,@5D93+59E<GIE:6-H;FES(&MO;FYT92!N:6-H="!U;6)E;F%N
M;G0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S@W
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I
M<F5C=&]R>3H@)7,N(@IM<V=S='(@(D1A<R!61E,M5F5R>F5I8VAN:7,@:V]N
M;G1E(&YI8VAT('5M8F5N86YN="!W97)D96XZ("5S+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,C@P(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,S4P"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")$:64@5D93+41A=&5I(%PB)7-<
M(B!K;VYN=&4@;FEC:'0@=6UB96YA;FYT('=E<F1E;BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HV,S(@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C(T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(")$:64@5D93+41A=&5I("5S
M+R5S(&MO;FYT92!N:6-H="!U;6)E;F%N;G0@=V5R9&5N+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S@Q(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HR,3(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V
M,R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S,T"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-38*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@(D1I92!61E,M1&%T96D@:V]N
M;G1E(&YI8VAT('5M8F5N86YN="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED(")5
M;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B7")M:VES;V9S7"(@
M:V]N;G1E(&YI8VAT(&%U<V=E9OQH<G0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L
M92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(D1I
M97-E<R!7;W)D+41O:W5M96YT(&SD<W-T('-I8V@@;FEC:'0@86YZ96EG96XB
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$X,S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O('1R:6=G97(@9G)E92]B=7-Y('5P9&%T
M92!F;W(@)7,B"FUS9W-T<B`B(@HB1&EE($9R96DO1V5B=6-H="U);F9O<FUA
M=&EO;F5N(&;\<B`E<R!K;VYN=&5N(&YI8VAT(&%K='5A;&ES:65R="!W97)D
M96XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$W."!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C$X,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")$:64@
M5D93+41A=&5I(%PB)7-<(B!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R
M9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$X.0IM<V=I
M9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB
M"FUS9W-T<B`B1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@9V5S8VAR:65B
M96X@=V5R9&5N("AC;W!Y*"D@9F5H;&=E<V-H;&%G96XI+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(Y-R!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,38U"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ-S`*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A
M+B(*;7-G<W1R(")$:64@5D93+41A=&5N(&MO;FYT96X@;FEC:'0@9V5S8VAR
M:65B96X@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-3,*
M;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B
M92!E>&-E961E9"XB"FUS9W-T<B`B(@HB1&EE(%9&4RU$871E:2!K;VYN=&4@
M;FEC:'0@9V5S8VAR:65B96X@=V5R9&5N+"!D87,@4W!E:6-H97)P;&%T>BU+
M;VYT:6YG96YT("(*(G?\<F1E(/QB97)S8VAR:71T96XN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD
M97)L:6YE(@IM<V=S='(@(E5N=&5R<W1R:6-H96XB"@HC.B!T96UP;&%T97,O
M<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B
MQ&YD97)U;F=E;B!R_&-K9^1N9VEG(&UA8VAE;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(DUA8VAT(&1I92!L971Z=&4@06MT
M:6]N('+\8VMGY&YG:6<B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HR,C@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z-#(W"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@
M<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R(")5;F?\;'1I9V4@4OQC
M:VUE;&1U;F<@=F]M(%-E<G9E<B!B96EM($AE<G-T96QL96X@9&5R(%9E<F)I
M;F1U;F<Z("(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C(R-`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS-S@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M-#$U"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C0R
M,0IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@
M(@IM<V=S='(@(E5N97)W87)T971E($%N='=O<G0@9&5S(%-E<G9E<G,@875F
M.B`B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R(").:6-H="!Z=6=E;W)D
M;F5T(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*;7-G:60@(E5N:6-O
M9&4@*%541BTX*2(*;7-G<W1R(")5;FEC;V1E("A55$8M."DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B5F5R
M96EN:6=T92!!<F%B:7-C:&4@16UI<F%T92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I
M9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B5F5R96EN:6=T97,@2_9N:6=R
M96EC:"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS
M9W-T<B`B5F5R96EN:6=T92!3=&%A=&5N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I
M9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S
M='(@(DML96EN97)E($%M97)I:V%N:7-C:&4@W&)E<G-E96EN<V5L;B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV,B!L:6(O0FQO8VLO;65T
M87(N<&AP.C<X"FUS9VED(")5;FET<R(*;7-G<W1R(")%:6YH96ET96XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z-3@*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B
M56YB96MA;FYT(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@
M365S<V%G92!)1"DN(@IM<V=S='(@(E5N8F5K86YN=&4@87!I;7-G:60@*$%0
M22!-97-S86=E($E$*2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@
M*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B56YB96MA;FYT92!C;&EM
M<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-#<*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O
M=FED960N(@IM<V=S='(@(D5S('=U<F1E(&5I;B!U;F)E:V%N;G1E<B!/<G0@
M86YG96=E8F5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P
M87-S=V]R9"XB"FUS9W-T<B`B56YB96MA;FYT97(@0F5N=71Z97)N86UE(&]D
M97(@4&%S<W=O<G0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E
M;G0@96QE;65N="(*;7-G<W1R("),:6YK('9O;2!A:W1U96QL96X@16QE;65N
M="!E;G1F97)N96XB"@HC.B!F<F%M97=O<FLO4')E9G,O261E;G1I='DN<&AP
M.C,P-`IM<V=I9"`B56YN86UE9"(*;7-G<W1R(")5;F)E;F%N;G0B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED
M("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#
M;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A
M<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO
M>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S
M8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*(D%U
M<R!3:6-H97)H96ET<V=R_&YD96X@9/QR9F5N('5N875T;W)I<VEE<G1E(%-K
M<FEP=&4@;FEC:'0@875S8VAN96ED96XL("(*(FMO<&EE<F5N('5N9"!E:6YF
M_&=E;BX@2VQI8VME;B!3:64@875F($]++"!U;2!E:6YE;B!(:6YW96ES(&%U
M9B!M;WII;&QA+F]R9R`B"B)A;F=E>F5I9W0@>G4@8F5K;VUM96XL(&1E<B!B
M97-C:')E:6)T+"!W:64@4VEE(&5I;F5M(%-K<FEP="!D96X@6G5G<FEF9B!A
M=68@(@HB9&EE(%IW:7-C:&5N86)L86=E(&5R;&%U8F5N(&OV;FYE;BXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R(")&87)B92!Z=7+\8VMS
M971Z96XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X
M-R!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-PHC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,PIM<V=I9"`B56YS=7!P
M;W)T960@17AT96YS:6]N(@IM<V=S='(@(D5R=V5I=&5R=6YG(&YI8VAT('5N
M=&5R<W3\='IT(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P
M9&%T92(*;7-G<W1R(")!:W1U86QI<VEE<G5N9R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57!D871E("5S(@IM<V=S='(@(B5S(&%K='5A;&ES:65R96XB"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@
M=7-E<B(*;7-G<W1R(")"96YU='IE<B!A:W1U86QI<VEE<F5N(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(EPB)7-<(B!W=7)D92!A:W1U
M86QI<VEE<G0N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G
M:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(D%K='5A;&ES
M:65R=6YG<W-K<FEP="!G96SV<V-H="XB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3<W(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ.3@*;7-G:60@(E5P;&]A9"(*;7-G<W1R(")(;V-H;&%D96XB"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@U"FUS9VED(")5<&QO861E9"!A;&P@
M87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T
M<B`B(@HB1&EE($MO;F9I9W5R871I;VYS9&%T96EE;B!A;&QE<B!!;G=E;F1U
M;F=E;B!W=7)D96X@875F(&1E;B!397)V97(@(@HB:&]C:&=E;&%D96XN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R(")'
M<BX@;&%T96EN:7-C:&4@0G5C:'-T86)E;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P
M<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B1W(N('+V;6ES8VAE(%IA:&QE
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B57)U
M9W5A>2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G
M97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E
M<R(*;7-G<W1R(")!:W1U96QL92!B96YU='IE;CH@)7,B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B
M57-E(%-33"(*;7-G<W1R(")34TP@8F5N=71Z96XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I
M<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R("(B"B)":71T
M92!A=7-F_&QL96XL('=E;FX@4VEE(&5I;F5N(&%N9&5R96X@0F5N=71Z97)N
M86UE;B]087-S=V]R="!F_'(@9&5N($E-4U`M(@HB4V5R=F5R(&AA8F5N+B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*;7-G:60@
M(E5S97(B"FUS9W-T<B`B0F5N=71Z97(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O4F5G:7-T<GDN<&AP.C<W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B0F5N
M=71Z97(@)7,@:7-T(&;\<B`E<R!N:6-H="!A=71O<FES:65R="XB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB
M"FUS9W-T<B`B0F5N=71Z97)V97)W86QT=6YG(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HR-#4*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G
M<W1R(")"96YU='IE<F5I;G-T96QL=6YG96XB"@HC.B!S:6=N=7`N<&AP.C8R
M"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R(")"96YU='IE<G)E
M9VES=')I97)U;F<B"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E
M9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*
M;7-G<W1R(")$:64@0F5N=71Z97)R96=I<W1R:65R=6YG('=U<F1E(&%U9B!D
M:65S96T@4WES=&5M(&1E86MT:79I97)T+B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HT.30*;7-G:60@(E5S97(@86-C;W5N="!N;W0@9F]U;F0B"FUS
M9W-T<B`B0F5N=71Z97)K;VYT;R!N:6-H="!G969U;F1E;B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z
M.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,T"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(D)E;G5T>F5R
M;F%M92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ,C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@
M97AI<W1S+B(*;7-G<W1R(")$97(@0F5N=71Z97)N86UE(%PB)7-<(B!E>&ES
M=&EE<G0@8F5R96ET<RXB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(")"96YU='IE<FYA;64Z
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E
M<FYA;64Z("(*;7-G<W1R(")"96YU='IE<FYA;64Z("(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S
M>7-T96TZ(@IM<V=S='(@(D)E;G5T>F5R(&1E<R!3>7-T96US.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B57-B96MI<W1A
M;B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W,R!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR-S$*;7-G:60@(E9&4R!D:7)E8W1O<GD@
M9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D1A<R!61E,M5F5R>F5I8VAN:7,@
M97AI<W1I97)T(&YI8VAT+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ,C`*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(D%B=V5S96YH96ET(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED(")686QI9"!L
M;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(E!A<W-E;F1E(&=E
M9G5N9&5N92!/<G1E.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8S.0IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B1_QL=&EG:V5I
M="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3DW"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB
M"FUS9W-T<B`B5V5R="!I;B!-:6YU=&5N('9O;B!J971Z="!A;BXB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-38@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I<R!O=F5R
M('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B1&5R(%=E<G0@
M:7-T(/QB97(@9&5R(&UA>&EM86QE;B!,Y&YG92!V;VX@)7,N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V,B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,C@T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,S0@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR.`HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU97,B"FUS9W-T
M<B`B5V5R=&4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3(W(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,#0*;7-G:60@(E9A;'5E<R!T;R!S
M96QE8W0@9G)O;2(*;7-G<W1R(")797)T92P@875S(&1E;F5N(&%U<V=E=^1H
M;'0@=V5R9&5N(&MA;FXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")686YU871U
M(@IM<V=S='(@(E9A;G5A='4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,S"FUS9VED(")687)I86)L92(*;7-G<W1R(")$<F5H96YD(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(E9E;F5Z
M=65L82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X
M"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA
M>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B(@HBW&)E<G!R
M_&9U;F<@9F5H;&=E<V-H;&%G96X@+2!D:65S92!.86-H<FEC:'0@:_9N;G1E
M(&UA;FEP=6QI97)T('=O<F1E;B!S96EN+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED(")697)S:6]N(@IM<V=S='(@
M(E9E<G-I;VXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(X"FUS
M9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B5F5R<VEO;G-K;VYT<F]L
M;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R(")!=7-R
M:6-H='5N9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B5F5R
M=&EK86QE<B!);FYE;F%B<W1A;F0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T
M<B`B5F5R=&EK86PZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-S0*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R(")396AR($AO
M8V@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*;7-G<W1R(")6
M:65T;F%M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3<*;7-G:60@(E9I
M971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B5FEE=&YA;65S:7-C:"`H5DE3
M0TE)*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDW
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(B5S(&%N
M>F5I9V5N(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE
M=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R(")%:6YE(&5X=&5R;F4@
M5V5B<V5I=&4@86YZ96EG96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E
M<R(*;7-G<W1R(")!;GIE:6=E;B!A;',@)7,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS
M9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R(")"<FET:7-C
M:&4@2G5N9V9E<FYI;G-E;&XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G
M:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R(")!;65R:6MA;FES8VAE($IU;F=F
M97)N:6YS96QN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3$*;7-G:60@
M(E9I<VEB:6QI='DB"FUS9W-T<B`B4VEC:'0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C4R"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T
M<B`B4VEC:'0Z("(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N
M96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@
M4TU44"(*;7-G<W1R(")6;V1A9F]N92!)=&%L:65N('!E<B!33510(@H*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R(")705).54Y'(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@
M)7,N(@IM<V=S='(@(E=!4DY53D<A(2$@3-930TA%3B!3244@1$%3(%-+4DE0
M5"!-04Y514Q,($%54R`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@
M(E=)3B#\8F5R($A45%`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@
M86YD($9U='5N82(*;7-G<W1R(")786QL:7,@=6YD($9U='5N82(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T
M871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M
M;"YP:'`Z,3(W(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HY-0IM<V=I9"`B5V%R
M;FEN9R(*;7-G<W1R(")787)N=6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B36DB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E
M871H97(@1F]R96-A<W0B"FUS9W-T<B`B5V5T=&5R=F]R:&5R<V%G92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,38*;7-G:60@(E=E871H
M97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R(")7971T97)D871E;B!V;VXB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3(*;7-G:60@(E=E871H
M97(N8V]M(@IM<V=S='(@(E=E871H97(N8V]M(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R(")796(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Y"FUS9VED(")796(@4VET92(*;7-G
M<W1R(")796)S:71E(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT
M96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(E?V8VAE;G1L
M:6-H(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@
M(E=E;&-O;64B"FUS9W-T<B`B5VEL;&MO;6UE;B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@
M(E=I;&QK;VUM96X@8F5I("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL
M92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF
M;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(E=I;&QK;VUM96XL
M("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3@*;7-G:60@(E=E<W1E
M<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(E=E<W1E=7)O<.1I<V-H("A)4T\M
M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DY"FUS9VED(")7
M97-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B5V5S=&5U<F]PY&ES8V@@
M*$E33RTX.#4Y+3$U*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A
M:&%R82(*;7-G<W1R(")797-T<V%H87)A(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T
M:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R(")7
M96QC:&4@06YW96YD=6YG('-O;&P@)7,@;F%C:"!D96T@06YM96QD96X@86YG
M97IE:6=E;C\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM
M<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T
M<B`B5V5L8VAE<R!4<F5N;GIE:6-H96X@=VER9"!V97)W96YD970_(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@
M=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B5V5L8VAE($%N9OQH<G5N
M9W-Z96EC:&5N('=E<F1E;B!V97)W96YD970_(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C4*;7-G:60@(E=H97)E:7,@
M075S=')A;&EA(&UA<"(*;7-G<W1R(")7:&5R96ES+4%U<W1R86QI82U+87)T
M92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA
M<V5S(@IM<V=S='(@(E=E;&-H92!0:&%S96XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,V"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F
M;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(E=E;&-H92!0;'5G
M:6YS(&;\<B!D96X@5UE325=91RU%9&ET;W(@<V]L;&5N(&%K=&EV:65R="!W
M97)D96X_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B0G)E:71E(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-0IM<V=I9"`B5VED=&@@
M:6X@0U-3('5N:71S(@IM<V=S='(@(D)R96ET92!I;B!#4U,M16EN:&5I=&5N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K
M97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`B0G)E:71E(&1E
M<R`E<RU-96[\<R!L:6YK<R`H=VER:W-A;2!N86-H(&1E<B!NY&-H<W1E;B!!
M;FUE;&1U;F<I.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T
M<B`B5&%B96QL96YB<F5I=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R
M(")%:6YH96ET(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R(")"<F5I=&4Z(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q-0IM<V=I9"`B5VEK:2(*
M;7-G<W1R(")7:6MI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(X.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM
M<V=I9"`B5VEN9"(*;7-G<W1R(")7:6YD(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(E=I;F0@16%R;'DB"FUS
M9W-T<B`B1G+\:"!7:6YD(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-PIM
M<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R(")7:6YD9V5S8VAW
M:6YD:6=T:V5I="!I;B!+;F]T96XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$U.`IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B5VEN9#HB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")7:6YD.B`B"FUS9W-T
M<B`B5VEN9#H@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED
M(")7:7-D;VTB"FUS9W-T<B`B5V5I<VAE:70B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3DX"FUS9VED(")7:7-H;&ES="(*;7-G<W1R(")7=6YS
M8VAZ971T96PB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@
M(E=O<FLB"FUS9W-T<B`B07)B96ET(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS
M9W-T<B`B061R97-S92!G97-C:.1F=&QI8V@B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE
M(@IM<V=S='(@(E1E;&5F;VX@9V5S8VCD9G1L:6-H(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,3DS(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@
M9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS
M9W-T<B`B1F%L<V-H92!!;GIA:&P@86X@1F5L9&5R;B!I;B!:96EL92`E9"X@
M)60@97)W87)T970L("5D(&=E9G5N9&5N+B(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N
M=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S
M='(@(D9A;'-C:&4@06YZ86AL(&%N($9E;&1E<FXN("5D(&5R=V%R=&5T+"`E
M9"!G969U;F1E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ
M,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE
M(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B56YG_&QT:6=E<B!/9F9S
M970@)60@8F5I;2!,97-E;B!D97(@5D93+41A=&5I+B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR-#4*;7-G:60@(E@M4F5F(@IM<V=S='(@(E%U
M97)V97)W96ES92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3DT"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T
M<B`B6#4P.78S($=E;F5R96QL92!%:6YS8VARY&YK=6YG(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!%
M>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B6#4P.78S($5R=V5I=&5R=&5R
M(%-C:&S\<W-E;'IW96-K(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E
M($YA;64B"FUS9W-T<B`B6#4P.78S($%L=&5R;F%T:79E<B!.86UE(&1E<R!:
M97)T:69I:V%T:6YH86)E<G,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y-@IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT
M:69I97(B"FUS9W-T<B`B6#4P.78S($ED96YT:73D="!D97,@6F5R=&EF:6MA
M='-C:&S\<W-E;',B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8X,PIM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B6#4P
M.78S($5R=V5I=&5R=6YG96XB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM
M<V=I9"`B65DB"FUS9W-T<B`B2DHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#$T"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-38*;7-G:60@(EE965DB"FUS9W-T<B`B2DI*
M2B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,3$Q"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(EEA:&]O(2!+87)T92(*
M"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-38*
M;7-G:60@(EEE87)L>2(*;7-G<W1R(")*Y&AR;&EC:"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(DIE;65N(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-@IM<V=I9"`B665S(@IM
M<V=S='(@(DIA(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA
M;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R(")*82P@
M:6-H('-T:6UM92!Z=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@
M57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'
M+B(*;7-G<W1R("(B"B)3:64@8F5F:6YD96X@<VEC:"!I;2!497AT;6]D=7,N
M($)E;G5T>F5N(%-I92!D96X@6SP^72!+;F]P9BP@=6T@:6X@9&5N("(*(E=9
M4TE724<M36]D=7,@>G4@=V5C:'-E;&XN(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HR,S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N
M("5D(&)L;V-K<RXB"FUS9W-T<B`B4VEE(&3\<F9E;B!N:6-H="!M96AR(&%L
M<R`E9"!";/9C:V4@97)S=&5L;&5N+B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,30Q-0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E
M9"XB"FUS9W-T<B`B4VEE('-I;F0@;FEC:'0@86YG96UE;&1E="XB"@HC.B!F
M<F%M97=O<FLO4')E9G,O261E;G1I='DN<&AP.C,Q,`IM<V=I9"`B66]U(&-A
M;FYO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M
M92XB"FUS9W-T<B`B4VEE(&3\<F9E;B!D87,@6F5I8VAE;B`G7%PG(&YI8VAT
M(&EN($EH<F5M($YA;65N('9E<G=E;F1E;BXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.3,*
M;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S
M<RXB"FUS9W-T<B`B4VEE(&AA8F5N(&ME:6YE(&?\;'1I9V4@12U-86EL+4%D
M<F5S<V4@86YG96=E8F5N+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP
M.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A
M;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E
M<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"B)3:64@:&%B
M96X@:V5I;F4@1F5L9&5R(&%U<R!D96X@:6UP;W)T:65R=&5N($1A=&5N(&1E
M;B!E;G1S<')E8VAE;F1E;B!&96QD97)N("(*(FEN("5S('IU9V5O<F1N970N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@W"FUS9VED(")9;W4@
M:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(E-I92!W=7)D96X@86)G
M96UE;&1E="XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q"FUS
M9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N
M=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O
M<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B
M(@HB4VEE(&W\<W-E;B!E:6YE(&?\;'1I9V4@36]B:6QT96QE9F]N;G5M;65R
M(&%N9V5B96XL(&YU<B!A=7,@6F%H;&5N('5N9"!G9V8N("(*(F5I;F5M(%PB
M*UPB(&;\<B!I;G1E<FYA=&EO;F%L92!6;W)W86AL96X@8F5S=&5H96YD+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#@*;7-G:60@(EEO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(E-I92!M_'-S
M96X@96EN96X@9_QL=&EG96X@5V5R="!A;F=E9V5B96XN(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C
M;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*
M;7-G<W1R("(B"B)3:64@;?QS<V5N(&5I;B!$871A5')E92U"86-K96YD(&MO
M;F9I9W5R:65R96XL('5M(%)E9VES=')I97)U;F=E;B!V97)W96YD96X@(@HB
M>G4@:_9N;F5N+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#8U
M"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS
M9W-T<B`B4VEE(&W\<W-E;B!E:6X@5D93+4)A8VME;F0@:V]N9FEG=7)I97)E
M;BXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I
M9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C
M86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(E-I92!M_'-S
M96X@9&%S(%!R;V)L96T@8F5S8VAR96EB96XL('5M(&1E;B!"97)I8VAT(&%B
M>G5S8VAI8VME;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H
M97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B4VEE(&W\<W-E;B!D
M:64@55),(&%N9V5B96XL(&%U9B!D:64@9&EE<V5R($QI;FL@=F5R=V5I<V5N
M('-O;&PB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM<V=I
M9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*
M;7-G<W1R(")3:64@;?QS<V5N(&5R<W0@9&5N('IU(&5N=&9E<FYE;F1E;B!3
M97)V97(@875S=^1H;&5N+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB
M"FUS9W-T<B`B(@HB4VEE(&W\<W-E;B!E:6YE;B!"96YU='IE<FYA;65N(&%N
M9V5B96XL(&1E<W-E;B!$871E;B!G96SV<V-H="!W97)D96X@<V]L;&5N+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B4VEE(&W\<W-E;B!E
M:6YE;B!Z=2!L]G-C:&5N9&5N($)E;G5T>F5R;F%M96X@86YG96)E;BXB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE
M('1O(&%D9"XB"FUS9W-T<B`B4VEE(&W\<W-E;B!E:6YE;B!H:6YZ=7IU9OQG
M96YD96X@0F5N=71Z97)N86UE;B!A;F=E8F5N+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@=7!D871E+B(*;7-G<W1R(")3:64@;?QS<V5N(&1E;B!Z=2!A:W1U86QI
M<VEE<F5N9&5N($)E;G5T>F5R;F%M96X@86YG96)E;BXB"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M
M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B
M4VEE(&W\<W-E;B!E:6YE($%K=&EO;B!A;F=E8F5N+B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED(")9
M;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(E-I
M92!M_'-S96X@96EN96X@;F5U96X@2V%T96=O<FEE;F%M96X@86YG96)E;BXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P
M+G!H<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N
M('!H;VYE(&YU;6)E<B(*;7-G<W1R(")3:64@;?QS<V5N(&5I;F4@271A;&EE
M;FES8VAE(%1E;&5F;VYN=6UM97(@86YG96)E;B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.CDW-0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S
M('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS
M9W-T<B`B26AR92`E<RU397-S:6]N(&ES="!A8F=E;&%U9F5N+B!":71T92!M
M96QD96X@4VEE('-I8V@@97)N975T(&%N+B(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B
M"FUS9W-T<B`B26AR92!%+4UA:6PM061R97-S92(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,#<*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS
M9W-T<B`B26AR92!6;VXZ($%D<F5S<V4Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-R!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR"FUS
M9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(DEH<F4@06YG86)E;B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@
M<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*
M(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN
M(@IM<V=S='(@(B(*(DEH<F4@26YT97)N971A9')E<W-E(&AA="!S:6-H(&=E
MY&YD97)T+"!S96ET(%-I92!D:64@)7,M4VET>G5N9R!B96=O;FYE;B`B"B)H
M86)E;BX@6G5M(%-C:'5T>B!):')E<B!3:6-H97)H96ET(&W\<W-E;B!3:64@
M<VEC:"!N974@86YM96QD96XN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R(")):'(@3F%M
M92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"FUS9VED
M("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D
M92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A
M(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R
M("(B"B)):'(@075T:&5N=&EF:7II97)U;F=S<WES=&5M(&5R;&%U8G0@:V5I
M;B!(:6YZ=6;\9V5N('9O;B!N975E;B!"96YU='IE<FXN("(*(E=E;FX@4VEE
M($AO<F1E(&)E;G5T>F5N(&WV8VAT96XL('5M($EH<F4@0F5N=71Z97(@>G4@
M=F5R=V%L=&5N+"!M_'-S96X@4VEE("(*(F5I;F5N(&%N9&5R96X@075T:&5N
M=&EF:7II97)U;F=S=')E:6)E<B!B96YU='IE;BXB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N
M=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E
M<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S
M;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@HB26AR($%U=&AE;G1I9FEZ
M:65R=6YG<W-Y<W1E;2!E<FQA=6)T(&1A<R!!;GIE:6=E;B!D97(@0F5N=71Z
M97(@;FEC:'0L(&]D97(@(@HB9&EE<V4@3?9G;&EC:&ME:70@=W5R9&4@875S
M9V5S8VAA;'1E="XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@
M=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E
M<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M
M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)):'(@0G)O=W-E<B!H870@
M<VEC:"!A;G-C:&5I;F5N9"!G9>1N9&5R="!S96ET(%-I92!D:64@)7,M4VET
M>G5N9R!B96=O;FYE;B`B"B)H86)E;BX@6G5M(%-C:'5T>B!):')E<B!3:6-H
M97)H96ET(&W\<W-E;B!3:64@<VEC:"!N974@86YM96QD96XN(@H*(SH@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z-3<*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S
M(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B26AR($)R;W=S
M97(@=6YT97)S=/QT>G0@9&EE<V4@1G5N:W1I;VX@;FEC:'0N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*;7-G:60@(B(*(EEO=7(@
M8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0
M<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R
M("(B"B)):'(@0G)O=W-E<B!U;G1E<G-T_'1Z="!D:65S92!$<G5C:V9U;FMT
M:6]N(&YI8VAT+B!":71T92!D<OQC:V5N(%-I92!3=')G+R(*(DMO;6UA;F1O
M("L@4"!U;2!Z=2!D<G5C:V5N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-3,*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@
M(DEH<F4@86MT=65L;&4@6F5I='IO;F4Z(@H*(SH@<V5R=FEC97,O<')E9G,N
M<&AP.C$Q-PIM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N
M(&-H86YG960N(@IM<V=S='(@(DEH<F4@4W1A;F1A<F1I9&5N=&ETY'0@=W5R
M9&4@9V7D;F1E<G0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U,PIM
M<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R(")):')E(%-T
M86YD87)D:61E;G1I=.1T.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M.38*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R(")):'(@=F]L;'-T
MY&YD:6=E<B!.86UE.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY
M.0IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B26AR
M(%IU9V%N9R!I<W0@86)G96QA=69E;BXB"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P
M87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(DEH<B!N975E<R!087-S
M=V]R="!F_'(@)7,@;&%U=&5T.B`E<R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM
M<V=S='(@(DEH<F4@16EN<W1E;&QU;F=E;B!W=7)D96X@9OQR(&1I92!$875E
M<B!D:65S97(@4VET>G5N9R!G97-P96EC:&5R="XB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA
M=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R(")):')E($5I;G-T96QL=6YG96X@
M=W5R9&5N(&=E<W!E:6-H97)T+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C<V"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T
M(@IM<V=S='(@(DEH<B!087-S=V]R="!W=7)D92!Z=7+\8VMG97-E='IT(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#`*;7-G:60@(B(*(EEO
M=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@
M86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R
M("(B"B)):'(@4&%S<W=O<G0@=W5R9&4@>G5R_&-K9V5S971Z="X@4G5F96X@
M4VEE($EH<F4@12U-86EL+4YA8VAR:6-H=&5N(&%B('5N9"`B"B)M96QD96X@
M4VEE('-I8V@@;6ET($EH<F5M(&YE=65N(%!A<W-W;W)T(&%N+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C<S,PIM<V=I9"`B66]U<B!P87-S=V]R
M9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B26AR(%!A<W-W;W)T(&ES="!A8F=E
M;&%U9F5N+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM
M<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B26AR92!397)V
M97(Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*
M;7-G<W1R(")*=6=O<VQA=VEE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(EIA:7)E(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(E-A;6)I82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(E-I;6)A8G=E
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*
M;7-G<W1R(")::7!P>2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O:&EG:&QI9VAT<75O=&5S+G!H<#HR,#,*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!4
M97AT72(*;7-G<W1R(");6FET871T97AT('9E<G-T96-K96Y=(@H*(SH@<V5R
M=FEC97,O<')O8FQE;2YP:'`Z.#D*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB
M"FUS9W-T<B`B6U!R;V)L96UB97)I8VAT72(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1=6]T960@
M5&5X="`M(@IM<V=S='(@(EM::71A='1E>'0@86YZ96EG96X@+2(*"B,Z(&9R
M86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H
M<#HR,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@
M+2`E<R!L:6YE<UTB"FUS9W-T<B`B6UII=&%T=&5X="!A;GIE:6=E;B`M("5S
M(%IE:6QE;ETB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(P-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B
M6UIE:6QE("5S('9O;B`E<UTB"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N
M:6YC.C$Q"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`B7T%D;6EN
M:7-T<F%T:6]N(@H*(SH@;&EB+V%P:2YP:'`Z,C(S"FUS9VED(")?0TQ)(@IM
M<V=S='(@(D)E7V9E:&QS>F5I;&4B"@HC.B!L:6(O87!I+G!H<#HR,#<*;7-G
M:60@(E]$871A5')E92(*;7-G<W1R(")?1&%T851R964B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*;7-G
M:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(EIE:6QE(%]L]G-C:&5N(@H*(SH@
M;&EB+V%P:2YP:'`Z,3DY"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(E]'<G5P
M<&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G
M<W1R(")?0FEL9&5I9V5N<V-H869T96XN+BXB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM<V=S='(@
M(D%N7VUE;&1E;B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H
M<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(D%B7VUE;&1E;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(DQI;FL@7V)E
M87)B96ET96XN+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP
M:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R(")?16EN<W1E;&QU;F=E
M;B(*"B,Z(&QI8B]A<&DN<&AP.C(P,PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM
M<V=S='(@(E]296-H=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN:RXN
M+B(*;7-G<W1R("),:6YK(%]E;G1F97)N96XN+BXB"@HC.B!L:6(O87!I+G!H
M<#HQ.3$*;7-G:60@(E]3971U<"(*;7-G<W1R(")?2V]N9FEG=7)A=&EO;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B
M7U1A8F5L;&5N96EG96YS8VAA9G1E;BXN+B(*"B,Z(&QI8B]A<&DN<&AP.C$Y
M-0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(E]"96YU='IE<B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.34Q"FUS9VED(")A9&1R97-S(&)O;VLB
M"FUS9W-T<B`B061R97-S8G5C:"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G
M<W1R(")!9')E<W-A="!U;F)E:V%N;G0B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDT,PIM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B2V%L96YD
M97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L:6(O0FQO8VLO;65T
M87(N<&AP.C,V,`HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@
M(G=I;F1S=&EL;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,34X"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S
M='(@(D%U<V=A8F5D871E:2!K;VYN=&4@;FEC:'0@97)S=&5L;'0@=V5R9&5N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S`*;7-G
M:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(D5I;F=A8F4@:V%N;B!N
M:6-H="!G9?9F9FYE="!W97)D96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HV,#`*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B
M:VQI8VME;B!3:64@:&EE<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B
M"FUS9W-T<B`B56YG_&QT:6=E($)E;G5T>G5N9R!D97(@2V]M;6%N9&]Z96EL
M92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<X"FUS
M9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(DMO;F9I9W5R871I
M;VYS9F5H;&5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS
M9W-T<B`B2W)I=&ES8VAE(%-Y<W1E;61A=&5I(&9E:&QT(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R
M;6%T(&5R<F]R(@IM<V=S='(@(D1A=&5N9F]R;6%T9F5H;&5R(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHS,`IM<V=I9"`B961I="(*;7-G<W1R
M(")B96%R8F5I=&5N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ.#(*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R(")%:6YT
M<F%G(&YI8VAT(&=E9G5N9&5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-S4*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B9F%L
M;&5N9"(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y-@IM
M<V=I9"`B9FEL92(*;7-G<W1R(")$871E:2(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3<V(&QI8B]";&]C:R]M971A<BYP:'`Z,S8R(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S@X"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S
M("@E<RD@870@)7,@)7,B"FUS9W-T<B`B875S("5S("@E<RD@;6ET("5S("5S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S.0IM<V=I9"`B
M9W5S=&EN9R(*;7-G<W1R(")B]FEG(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(U,`IM<V=I9"`B:#HB"FUS9W-T<B`B:#HB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4Y
M"FUS9VED(")H:"(*;7-G<W1R(")H:"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*
M;7-G<W1R(")(;W-T;F%M92!U;F)E:V%N;G0B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(FEM
M;65D:6%T92(*;7-G<W1R(")S;V9O<G0B"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HV-"!A9&UI;B]S971U<"]D:69F+G!H<#HW-@IM<V=I9"`B:6YL:6YE
M(@IM<V=S='(@(DEN;&EN92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T
M<B`B16EN+2]!=7-G86)E9F5H;&5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R
M<F]R(@IM<V=S='(@(DEN=&5R;F5R(%-O9G1W87)E9F5H;&5R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI
M;F5S72(*;7-G<W1R("):96EL96Y=(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*
M;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/
M+B(*;7-G<W1R(")M:VES;V9S+49E:&QE<F-O9&4@)60@8F5I(&1E<B!%<G-T
M96QL=6YG(&1E<R!)4T\M06)B:6QD97,N(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W,`IM<V=I9"`B;6TB"FUS9W-T<B`B
M;6TB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(X-2!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<T"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HR-#,*;7-G:60@(FYA;64B"FUS9W-T<B`B3F%M92(*
M"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C0*;7-G:60@(FYO="!I;7!L
M96UE;G1E9"(*;7-G<W1R(")N:6-H="!I;7!L96UE;G1I97)T(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C(P"FUS9VED(")N;W0@
M>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(DYO8V@@;FEC:'0@:6UP;&5M96YT
M:65R="(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,U"FUS9VED
M(")N;W1E<&%D(@IM<V=S='(@(DYO=&EZ8FQO8VLB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P
M97)C96YT(@IM<V=S='(@(E!R;WIE;G0B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B
M"FUS9W-T<B`B6G5G<FEF9B!V97)W96EG97)T(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX
M96QS(@IM<V=S='(@(E!I>&5L(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O
M;"(*;7-G<W1R(")296UO=&5F96AL97(@:6T@4')O=&]K;VQL(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S<*;7-G:60@(G)I
M<VEN9R(*;7-G<W1R(")S=&5I9V5N9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE
M(@IM<V=S='(@(E-E<G9I8V4@;FEC:'0@=F5R9OQG8F%R(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HQ,#$*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B
M"FUS9W-T<B`B56YT97)S8VAI961E(&%N>F5I9V5N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M
M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R(")S;7,R96UA:6P@_&)E<B!(5%10
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X
M-PIM<V=I9"`B<W,B"FUS9W-T<B`B<W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HW-@IM<V=I9"`B<W1E861Y(@IM<V=S='(@
M(F=L96EC:&)L96EB96YD(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R(")3>7-T
M96UF96AL97(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDU.0IM
M<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(D%U9F=A8F5N;&ES=&4B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M
M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B5F]R_&)E<F=E:&5N9&5R($9E:&QE
M<B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HR-S`*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E
M('1O(&-O;F9I<FTB"FUS9W-T<B`B9V5B96X@4VEE(&1A<R!087-S=V]R="!E
M:6X@>G=E:71E<R!-86P@>G5R($)E<W3D=&EG=6YG(&5I;B(*"B,Z(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.C8T(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<V"FUS
M9VED(")U;FEF:65D(@IM<V=S='(@(G5N:69I960B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA;65D(@IM<V=S='(@
M(G5N8F5N86YN="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T
M<B`B8F5N=71Z97)D969I;FEE<G0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@(G9#
M87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(T,@IM<V=I9"`B=SHB"FUS9W-T<B`B8CHB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B
M=V5A=&AE<BYC;VTB"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O96Q?1U(N<&\`````````````
M````````````````````````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#4V,#8W,0`Q
M,#4Q-30S,S<U-0`P,3<V-#4`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````(R!(;W)D92!'<F5E:R!T<F%N<VQA=&EO;BX*(R!#
M;W!Y<FEG:'0@*$,I(#(P,#(@4W1E9F%N;W,@22X@1&EM:71R:6]U+@HC(%-T
M969A;F]S($DN($1I;6ET<FEO=2`\<W5P<&]R=%]W96)M86EL0'1E:6%T:"YG
M<CXL(#(P,#(N"B,@4VEL;&EG87)D;W,@6')I<W1O9F]R;W,L(#(P,#(N"B,@
M06YA9VYO<W1O<&]U;&]S($%P;W-T;VQI<RP@,C`P,BX*(R!-:6QO<VES($,N
M($MO;G-T86YT:6YO<RP@,C`P-2X*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R
M;VIE8W0M260M5F5R<VEO;CH@2&]R9&4Z(#,N,"UC=G-<;B(*(E)E<&]R="U-
M<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E
M871I;VXM1&%T93H@,C`P,BTQ,2TP-R`Q,CHP-BLP,C`P7&XB"B)03RU2979I
M<VEO;BU$871E.B`R,#`U+3`T+3(V(#$Q.C$S*S`R,#!<;B(*(DQA<W0M5')A
M;G-L871O<CH@2V]N<W1A;G1I;F]S($,N($UI;&]S:7,@/&MM:6QO<VES0'EA
M:&]O+F-O;3Y<;B(*(DQA;F=U86=E+51E86TZ($=R965K(#QD979`;&ES=',N
M:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M
M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TW7&XB"B)#;VYT
M96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=%QN(@H*(RP@8RUF;W)M870*
M;7-G:60@(B(*(B`F(S$U,3L@)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B(*;7-G<W1R
M("(B"B(@)B,Q-3$[("5S(,7?[>'I(.<@\_3IX^S>(.WA(./?[>_U[2#OZ2#K
MY>GT[_7QX]_E\B#S]>WTWO'G\^?R(/#O]2#EW^WAZ2`B"B+E\.GKY>/LW>WE
M\B#PX?'AZMST^2XB"@IM<V=I9"`B("!4:&4@;6%I;&)O>"!T<F%S:"!I<R!A
M;')E861Y(&5M<'1Y+B(*;7-G<W1R("(@(,<@X_'A[.SA]._H]?'?Y.$@)^K<
MY._R)R#EW^WAZ2#>Y.<@W.3EZ>$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,U,0IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B("CP
M\>GM(.'P_"`E<R#G[-WQY?(I(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ,C<W"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B("C*
MZ^7IY-\@\/'\\^+A\^?R("5S*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S-3D*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B("CSY2`E
M<R#G[-WQY?(I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,U-0IM
M<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B("CSWNSE\>$I(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,U-PIM<V=I9"`B("AT;VUO<G)O=RDB"FUS
M9W-T<B`B("CA_?'I[RDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S4S"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B("CWZ.7R*2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#`*;7-G:60@(B!A="`B
M"FUS9W-T<B`B(//TZ?(@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$X-@IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B5D("5S(.KA
MZ2`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C<*;7-G
M:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R("(E9"WLY?'G(/#Q_.+KY?CG
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VYO=&EC95]T;W`N:6YC.C0*
M;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S("T@T^?LY=_Y\^<B"@HC
M.B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z,CD*;7-G:60@
M(B5S($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B5S+<3IX??EW_'I\^<B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<R.`IM<V=I9"`B
M)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B)7,@Q.'J]/7KZ>K\(.'P[_3]\/GL
MX2(*"B,L(&,M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I
M;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S(,OEZ?3O]?'CW^7R(-/U
M[?3>\>?SY_(@+2#%\.GBY>+AW_GSYR(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P.0IM<V=I9"`B)7,@
M4V5T=7`B"FUS9W-T<B`B)7,MT.'QX>SE]/'O\._?Y_/G(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W-@IM<V=I9"`B)7,@4VEG;B!5
M<"(*;7-G<W1R("(E<R#%X^/QX?;>(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+V%G<F5E;65N=%]T;W`N:6YC.C0*;7-G:60@(B5S(%1E<FUS(&]F($%G
M<F5E;65N="(*;7-G<W1R("(E<R#/\>_I(/?QWO/G\B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z-3DV(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-C8V"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B)7,@
MWN3G(/7PW/'WY>DN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3<@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ-C,@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S<*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#,@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-#D*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S(//E("5S("5S
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HU,S`*;7-G:60@(B5S(&AA<R!C86YC96QL960@)7,N(@IM<V=S='(@(B5S
M(.'J]?'^Z.?JY2`E<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C0R-@IM<V=I9"`B)7,@:&%S(')E<&QI960@=&\@
M82!F<F5E+V)U<WD@<F5Q=65S="XB"FUS9W-T<B`B)7,@X?#<[?3G\^4@\^4@
MY?'^].?LX2#DZ>'HY?/I[/STY_3A\BXB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4R-`IM<V=I9"`B)7,@:&%S(')E
M<&QI960@=&\@=&AE(&EN=FET871I;VX@=&\@)7,N(@IM<V=S='(@(B5S(.'P
MW.WTY_/E(//TY^T@\/'\\^KKY_/G(./IX2`E<RXB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0Q-@IM<V=I9"`B)7,@
M:&%S('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B
M)7,@\^'R(-WS].7IZ^4@\.OG\>_V[_'?Y?(@Y.GAZ.7SZ>S\].?TX?(N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,R,0IM<V=I9"`B)7,@:7,@
M<F5Q=6ER960B"FUS9W-T<B`B)7,@Y=_MX>D@X?#AZ?3O_>SE[>\B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(X-`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G
M<W1R("(E<R#KY?#TW"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-#(Q"FUS9VED("(E<R!R97%U97-T<R!Y;W5R(&9R
M964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B)7,@\^'R(.;>].?SY2#P
MZ^?Q[_;O\=_E\B#DZ>'HY?/I[/STY_3A\BXB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4P.`IM<V=I9"`B)7,@<F5Q
M=65S=',@>6]U<B!P<F5S96YC92!A="`E<RXB"FUS9W-T<B`B)7,@YM[TY_/E
M(/3G[2#PX?'O]?/?X2#SX?(@\_3I\B`E<RXB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHV"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G
M<W1R("(E<R#Y\B`E<R#A\/P@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C4Q,PIM<V=I9"`B)7,@=VES:&5S('1O
M(&%D9"!T;R`E<RXB"FUS9W-T<B`B)7,@Y?#IZ/7LY=\@].?M(/#Q[_/HWNKG
M(//T[R`E<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C4P,@IM<V=I9"`B)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W
M87)E(&]F("5S+B(*;7-G<W1R("(E<R#E\.GH]>SEWR#MX2#SX?(@Y>WG[.7Q
M_O/EZ2#CZ>$@)7,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HU,3@*;7-G:60@(B5S('=I<VAE<R!T;R!R96-E:79E
M('1H92!L871E<W0@:6YF;W)M871I;VX@86)O=70@)7,N(@IM<V=S='(@(B5S
M(.7PZ>CU[.7?(.WA(.O<XN7I(/3I\B#TY>OE]?3AW^7R(/#KY_'O]N_QW^7R
M(./IX2`E<RXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ,@IM
M<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B)7,G<R#$Z>7UZ/7M
M\^GOX_'<]N_R(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#0*
M;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B)7,G<R#'[.7Q[^O\X^GO
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HX.38*;7-G:60@(B5S
M)W,@3F]T97!A9"(*;7-G<W1R("(E<W,@T^?LY>GY[.'TW/'I[R(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(P"FUS9VED("(E<R=S(%1A<VML
M:7-T(@IM<V=S='(@(B5S<R#+W_/TX2#%\>/A\^G^[2(*"B,Z(&9R86UE=V]R
M:R]#3$DO0TQ)+G!H<#HR-S`*;7-G:60@(B<E<R<@:7,@;F]T(&$@=F%L:60@
M8VAO:6-E+B(*;7-G<W1R("(G)7,G(.3E[2#EW^WAZ2#=X^KU\><@Y?#IZ^_C
MWBXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C4X
M,@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.CDX,@IM
M<V=I9"`B)R5S)R!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G
M:7-T<GDN(@IM<V=S='(@(B<E<R<@Y.7M(-WWY>D@\?7H[.GS].7?(//T[R!R
M96=I<W1R>2#TY_(@Y?;A\>SOX][R($AO<F1E(@H*(SH@9G)A;65W;W)K+U1R
M964O5')E92YP:'`Z,38P"FUS9VED("(G)7,G('1R964@<F5N9&5R97(@;F]T
M(&9O=6YD+B(*;7-G<W1R("(E<R#A[>'PX?'A\_3<].?R(.3E[>3QZ>K>\B#D
M[^S>\B#DY>T@XO'=Z.?JY2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4W"FUS
M9VED("(G)7,G('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS
M9W-T<B`B)R5S)R#P\>_S]-WHY^KE(//TZ?(@[^S<Y.7R(//U\_3>[.'T[_(N
M(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C@U"FUS9VED("(G)7,G
M('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R
M("(G)7,G(/#Q[_/TW>CGZN4@\_3I\B#<Y.7IY?(@]._U(//U\_3>[.'T[_(N
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-2!A9&UI;B]P97)M<R]A9&1C:&EL
M9"YP:'`Z.#,*;7-G:60@(B<E<R<@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS
M9W-T<B`B)R5S)R#DY>T@Y.?LZ>_U\>/>Z.?JY3H@)7,N(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ.#8@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3$*;7-G
M:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(L(&=U<W1I;F<@)7,@)7,B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Y.0IM<V=I9"`B+"!V87)I86)L
M92!F<F]M("5S('1O("5S(@IM<V=S='(@(BP@[.7TX>+KY_3>(.'P_"`E<R#S
MY2`E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-3(@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-CDQ"FUS9VED("(M+2!S96QE8W0@+2TB"FUS
M9W-T<B`B+2T@Y?#IZ^_CWB`M+2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR
M,`IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`B,3+Y\><@[._Q]MXB
M"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R
M;6%T(@IM<V=S='(@(C(T^?'G(.SO\?;>(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T(/[QY?(B
M"@IM<V=I9"`B/&(^02!F871A;"!E<G)O<B!H87,@;V-C=7)R960Z/"]B/B(*
M;7-G<W1R("(\8C[0X?'O]?/IW//TY^KE(-WMX2#S[^+A\?P@Z]SH[_(Z/"]B
M/B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38V"FUS9VED(")!
M(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R("+0X?'O]?/IW//H
MY^KE(.KQW_/I[.\@Z]SH[_(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HY-#$*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER
M960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(L'PX>GTY=_TX>D@
MY.?L_//I[R#JZ^7IY-\@4$=0(./IX2#TY^T@ZO'U\/3OX_'<]N?SYR#E[?SR
M(.SG[?WLX?3O\BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,38W"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O
M('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"B+!\.'I].7?
M].'I(.3G[/SSZ>\@ZNOEZ>3?(%!'4"#CZ>$@Y?#IXN7BX=_Y\^<@Y>W\\B#U
M\._CY>/QX>SLW>WO]2#LY^W][.'T[_(N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3`Y.`IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME
M>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(L'PX>GT
MY=_TX>D@Y.?L_//I[RP@\/'O\_GPZ>K\(%!'4"#JZ^7IY-\@ZN'I(.O=[N<M
MZOGDZ>K\\B#CZ>$@[>$@(@HBX?#OZO'U\/3OX_'A]M[SY?3E(-WMX2#LWNWU
M[.$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Q-PIM
M<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE<W-A
M9V4N(@IM<V=S='(@(B(*(L'PX>GTY=_TX>D@Y.?L_//I[RP@\/'O\_GPZ>K\
M(%!'4"#JZ^7IY-\@ZN'I(.O=[N<MZOGDZ>K\\B#CZ>$@[>$@]?#OX_'<^.7T
MY2`B"B+XY_;IX>K<(-WMX2#LWNWU[.$N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU,C,*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-
M12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B
M"B+!\.'I].7?].'I(.3G[/SSZ>\L(/#Q[_/Y\.GJ_"!3+TU)344@ZNOEZ>3?
M(.KAZ2#KW>[G+>KYY.GJ_/(@X^GA(.WA("(*(N'P[^KQ]?#T[^/QX?;>\^7T
MY2#=[>$@[-[M]>SA+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-#0Y"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV
M871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@HBP?#AZ?3EW_3AZ2#D
MY^S\\^GO+"#P\>_S^?#IZOP@4R]-24U%(.KKY>GDWR#JX>D@Z]WNYRWJ^>3I
MZOSR(./IX2#MX2`B"B+U\._C\=SXY?3E(/CG]NGAZMP@W>WA(.S>[?7LX2XB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X,@IM<V=I
M9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@
M82!M97-S86=E+B(*;7-G<W1R("+!\.'I].7?].'I(.3G[/SSZ>\@ZNOEZ>3?
M(%,O34E-12#CZ>$@].?M(.KQ]?#T[^/QW/;G\^<@Y>W\\B#LY^W][.'T[_(N
M(@H*;7-G:60@(D%-+U!-(@IM<V=S='(@(O#L+^SL(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@
M=&AI<R!E9&ET;W(B"FUS9W-T<B`BT.7QWR#A]?3O_2#T[_4@RN7I[.7M[^/Q
MW/;O]2(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4R"FUS9VED(")!
M8F]U="XN+B(*;7-G<W1R("+0Y?'?+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM
M<V=S='(@(L'P_.OU].\@]-WK[_(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T
M<B`BP?#\Z_7TYR#,W?/G(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HV-#`*;7-G:60@(D%C8V5P="!R97%U97-T(@IM
M<V=S='(@(L'P[^3O]]X@X>GTWNSA]._R(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV.#$*;7-G:60@(D%C8V5P=&5D
M(@IM<V=S='(@(L7CZ>WE(.'P[^3EZO3\(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C(X-0IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN
M9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("+'(/#Q_//BX?/G(.'P[_'QW_;H
MY^KE(.KA]-P@].<@Y.?LZ>_U\>/?X2!61E,@ZN'TX>O\X^_U+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S@*;7-G:60@(D%C8V5S<R!D
M96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(L<@\/'\\^+A\^<@
MX?#O\?'?]NCGZN4@ZN'TW"#TYR#DY^SI[_7QX]_A(%9&4R#A\??EW^_U+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-0IM<V=I9"`B06-C;W5N="!0
M87-S=V]R9"(*;7-G<W1R("+*^>3IZOSR(,OOX^'QZ>'S[._](@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS
M9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`BSR#K[^/A\>GA\^S\\B#P
MW./Y\^4N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R,`IM<V=I
M9"`B06-C;W5N=&EN9R(*;7-G<W1R("+*X?3AX_'A]MXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0U,0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8R-0IM<V=I
M9"`B06-T:6]N<R(*;7-G<W1R("+%[=WQX^7IY?(B"@HC.B!A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`Z-30@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ,S8*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$V"FUS9VED(")!9&0B"FUS
M9W-T<B`BT/'O\^C>ZN<B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q-"!A9&UI
M;B]G<F]U<',N<&AP.C(Q-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S
M='(@(M#Q[_/HWNKG(/7P[^_LW.3A\B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z.#$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX
M,@IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`BT/'O\^C>
MZN<@W.3EZ>'R(/7P[^_LW.3A\B`H8VAI;&0@<&5R;6ES<VEO;BDB"@HC.B!T
M96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM
M<V=S='(@(M#Q[_/HWNKG(.7D_CHB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(P
M."!A9&UI;B]G<F]U<',N<&AP.C(P.0IM<V=I9"`B061D($YE=R!'<F]U<"(*
M;7-G<W1R("+0\>_SZ-[JYR#-W>'R(,_LW.3A\B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z-S`@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HW,0IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(M#Q
M[_/HWNKG(.W=X?(@W.3EZ>'R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]A9&1C:&EL9"YI;F,Z.0IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@
M)R5S)R(*;7-G<W1R("+0\>_SZ-[JYR#U\._O[-SDX?(@\_3O("<E<R<B"@HC
M.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3,@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ,S4*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I
M;VX@=&\@)R5S)R(*;7-G<W1R("+0\>_SZ-[JYR#<Y.7IX?(@*'!E<FUI<W-I
M;VXI(/7P[^_LW.3A\B#S].\@)R5S)R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P
M"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`BT/'O\^C>ZN<@[=WO
M]2#W\=[S].<Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4R.0IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R("+0\>_SZ-[J
MYR#S]-[KY_(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C,U"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`BT/'O\^C>ZN<@
M[=WO]2#LW>OO]?(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P
M,PIM<V=I9"`B061D('!A:7(B"FUS9W-T<B`BT/'O\^C>ZN<@YN7]X^_U\B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3$*;7-G:60@(D%D9"!T:&4@
M)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R("+0\>_SZ-[J
MYR#T[_4@)7,@\_3O(.SE[>_](/3O]2!-;WII;&QA(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV,S$*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV,S<*;7-G:60@
M(D%D9"!T:&ES('1O(&UY(&-A;&5N9&%R(@IM<V=S='(@(M#Q[_/HWNKG(.'U
M]._](//T[R#G[.7Q[^O\X^G\(.SO]2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HW-`IM<V=I9"`B061D('1O(&%D9')E<W,@
M8F]O:SHB"FUS9W-T<B`BT/'O\^C>ZN<@\_3O(,3IY?7H]>WSZ>_C\=SV[SHB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z.#$*
M;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`BT/'O\^C>
MZN<@\_3O(,3IY?7H]>WSZ>_C\=SV[R#L[_4B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`BT/'O\^C>ZN<@]_'>\_3G
M(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*;7-G:60@(B(*(D%D9&5D("<E<R<@
M=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S
M:6=N=7`@:6YF;W)M871I;VXZ("4B"B)S+B(*;7-G<W1R("(B"B+0\>_S]-WH
MY^KE("<E<R<@\_3O(//]\_3G[.$L(.'KZ]P@Y.7M(.SP_/'E\^$@[>$@\/'O
M\^C=\_D@\_7L\.OG\?GLX?3IZMWR("(*(O#KY_'O]N_QW^7R(@H*(SH@<VEG
M;G5P+G!H<#HT-@IM<V=I9"`B061D960@)R5S)R!T;R!T:&4@<WES=&5M+B!9
M;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(M#Q[_/TW>CGZN4@)R5S)R#S
M].\@\_WS].?LX2X@S/#O\>7?].4@[>$@\_7MY.7HY=_TY2#T_O'A+B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHT"FUS9VED(")!9&1I
M;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(L<@\/'O\^C>ZN<@]_'G
M\_3^[2#=]^7I(.'PY>WE\>/O\._IY^CEWRXB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(Y"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S8@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30S-PIM<V=I9"`B061D<F5S<R(*;7-G<W1R("+$Z>7]Z/7M\^<B
M"@IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(L3IY?7H]>WSZ>_C\=SV
M[_(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M-PIM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H
M97(@=7-E<G,B"FUS9W-T<B`BQ.GA]^7?\>GSYR`M(,3^\_3E(.3IZN'I_NSA
M].$@\^4@W.OK[_7R(/?QWO/TY?(B"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI
M<W1R871I;VXB"FUS9W-T<B`BQ.GA]^7?\>GSYR(*"FUS9VED(")!:W1I;VX@
M06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA\B#!ZO3?[_4B"@IM<V=I9"`B
M06QE>&%N9')O=7!O;&D@06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GLWNT@P>OE
M[N'MY/'O_?#OZ^?R(@H*;7-G:60@(D%L:6%S(@IM<V=S='(@(MCE]>3^[?7L
M[R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@(L7UZ/7C\=SL[.GSY2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*
M;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`BQ?7H]>/QW.SLZ?/G.B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@
M(L_KX2(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$Q."!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C<Q"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5
M<V5R<R(*;7-G<W1R("+/Z^_I(._I(-WCZO7Q[^D@]_'>\_3E\B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,3(*;7-G:60@
M(D%L;"!'<F]U<',B"FUS9W-T<B`BS^OE\B#OZ2#/[-SDY?(B"@HC.B!A9&UI
M;B]P97)M<R]A9&1C:&EL9"YP:'`Z,S@@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HW-`IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(L_K
MX2#TX2#DZ>KAZ?[LX?3A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B
M"FUS9W-T<B`BRN'I(._I(/3=\_/E\>GR("@T*2#PZ^7U\=WR(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U-`IM<V=I9"`B06QL;W<@;75L=&EP
M;&4@861D<F5S<V5S(@IM<V=S='(@(LWA(.7PZ?3QW?#O[?3AZ2#P[^OKX?#K
MW?(@Y.GE]>C][?/EZ?(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$W
M"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*
M;7-G<W1R("+-X2#E\.GT\=WP[^WTX>D@\?7H[-_SY>GR(/3A[NGM[^SI[-WM
M^>T@Z^GS]/[M.R(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S
M<6PN<&AP.C0P,0IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`BQ^3G
M(/7PW/'WY>DB"@IM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T
M<B`BQ>WAZ^OAZO3IZMX@24U34"#%W_/OY._R(@H*;7-G:60@(D%L=&5R;F%T
M92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(L7MX>OKX>KTZ>K\\B!)35-0(,KY
MY.GJ_/(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#@R"FUS9VED(")!
M;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R("+%[>'KZ^'J].GJ_"!)
M35-0(+SM[^SA(-?QWO/TYR(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C,U"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R
M("+%[>'KZ^'J].GJWB#DZ>7]Z/7M\^<@96UA:6PB"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G
M<W1R("+%[>'KZ^'J].GJW"#P\?ST]?#A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!
M;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`BQ>WAZ^OAZO3IZOP@ZN7?[.7M[SHB
M"@IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G
M<W1R("+/\=_S].?JY2#LW^$@[.<@Y?#I]/'E\/SLY>WG(/3I[-XN(@H*;7-G
M:60@(D%N8VAI86QO<R!!:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(,'C
M]]_AZ^_U+B(*"FUS9VED(")!;F1R879I9&$@06ER<&]R="(*;7-G<W1R("+!
MY?'OZ^GLW>WA\B#![>3QX>+?Y.'R+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,C`*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R
M("+![?[M]>SO\B#$Z>'L[.7S[^OAXN?TWO(@*%!R;WAY*2(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T
M<B`BP?#<[?3G\^<B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN
M+W!H<'-H96QL+G!H<#HS,`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN
M<&AP.C4Y('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G
M:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(L7VX?'L[^/>(@H*(SH@=71I;"]I
M8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM
M<V=S='(@(LO?\_3A(,7VX?'L[^/>\B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,S`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R
M("+'(.7VX?'L[^/>(.7?[>'I(-WT[^GLYRXB"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C(R-`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S
M(@IM<V=S='(@(L7VX?'L[^/>(.KAZ2#S].$@Y>[A\?3^[.7MX2#J[^GM_/?Q
MY_/TX2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C,S
M"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(L7CZO'?[?DB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<W"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,30*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB
M"FUS9W-T<B`BP?#QW^OI[_(B"@IM<V=I9"`B07)A>&]S($%I<G!O<G0B"FUS
M9W-T<B`BP>7Q[^OI[-WMX?(@P?'<[N_U(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV,B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#$*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@
M(LS=X^7H[_(@X?'WY=_O]2#A\??EZ>_HW?3G\^?R(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,2!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#`*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R
M("+/[>_LX2#A\??EW^_U(.'Q]^7IZ-WTY_/G\B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z.0IM<V=I9"`B07)E('EO=2!S
M=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R
M("5S(#\B"FUS9W-T<B`BQ=_S].4@\]_C[_7QYR#CZ>$@].<@Y.GAX_'A]MX@
M].?R(.'?].?SY_(@]?#OX_'A]M[R(./IX2`E<R`_(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.CD*;7-G:60@(D%R92!Y;W4@<W5R
M92!Y;W4@=VES:"!T;R!D96QE=&4@)R5S)R!A;F0@86YY('-U8BUG<F]U<',_
M(@IM<V=S='(@(L7?\_3E(//?X^_U\>_I(/STZ2#HW>OE].4@[>$@Y.GAX_'<
M^.7TY2`G)7,G(.KAZ2#\Z^7R(/3I\B#U\._O[-SDY?(_(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`BU-WW[><B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R
M="(*;7-G<W1R(")!4T-)22#4W??MYR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT,#D*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D
M;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R("+-X2#FY_3E
MW_3E(.7PZ>+EXN'?^?/G(/#QW^T@X?#\(.K<Z.4@Y>W=\>/EZ>$@Y.GA]^7?
M\>GSY_([(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y-PIM<V=I
M9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(L'MW.CE\^<@\_3GZ_[M
M(@H*;7-G:60@(D%T:&EN86D@06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA
M\B#!Z.?M_NTB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C$V-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C(T.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C,Q.`IM<V=I9"`B071T86-H960@:7,@86X@:4-A
M;&5N9&%R(&9I;&4@<F5P;'D@=&\@82!R97%U97-T('EO=2!S96YT(@IM<V=S
M='(@(M3O(//U[>?L[-WM[R#EW^WAZ2#=[>$@X?'WY=_O(.?LY?'OZ^_CW^_U
M(//E(.'PW.WTY_/G(.'I]-[LX?3\\B#SX?(B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C<U"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N
M="!G<F]U<"XB"FUS9W-T<B`BT/'O\_#<Z.7IX2#DZ>'C\>'VWO(@[.<@]?#A
M\>KTWO(@[^S<Y.'R+B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,S@*
M;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI
M<W-I;VXN(@IM<V=S='(@(M#Q[_/PW.CEZ>$@Y.GAX_'A]M[R(.SG(/7PX?'J
M]._](.3IZN'I_NSA]._R+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.CDX
M"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES
M<VEO;BXB"FUS9W-T<B`BT/'O\_#<Z.7IX2#E\.7NY?'CX?/?X?(@[.<@]?#A
M\>KT[_T@Y.GJX>G^[.'T[_(N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N
M<&AP.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@
M<VAA<F4N(@IM<V=S='(@(M#Q[_/PW.CEZ>$@Y?#E[N7QX^'SW^'R(.SG(/7P
MX?'J]._](.3IX>SOZ?'A\^S=[>_U+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3<W"FUS9VED(")!='1E;F1E97,B
M"FUS9W-T<B`BT.'QY?7QZ?/J_.SE[>_I(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#8*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`BR>3I_/3G
M].7R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,X,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R("+!_>/O]?/T[_(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R("+'(.'UZ.7M].GJ
M[_#OW^?SYR#A\-WT]??E(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S@*;7-G:60@(D%U=&AE;G1I8V%T:6]N
M(&9A:6QE9"X@)7,B"FUS9W-T<B`BQR#A]>CE[?3IZN_P[]_G\^<@X?#=]/7W
MY2X@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,3@Q
M"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R
M=F5R+B(*;7-G<W1R("+'(.'UZ.7M].GJ[_#OW^?SYR#A\._Q\=_VZ.?JY2#A
M\/P@]._M(%)!1$E54R!S97)V97(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX,#`*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V
M97(@9F%I;&5D+B(*;7-G<W1R("+'(.'UZ.7M].GJ[_#OW^?SYR#S]._M($94
M4"U397)V97(@X?#=]/7WY2XB"@IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB
M"FUS9W-T<B`BQ.GAZ-WSZ>SA(-#EY-_A.B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C$T"FUS9VED(")!=V%I=&EN
M9R!297-P;VYS92(*;7-G<W1R("+![>'LW>WO[?3A\B#A\-SM].?SYR(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`BU?#\XN'H\>\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED
M(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(M?Q_NSA(/7P_.+AZ/'O]2(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A
M9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`BR]SH[_(@2V5R8F5R;W,M
MZOGDZ>K\\BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U
M"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(LO<Z._R
M($ME<F)E<F]S+;SM[^SA(-?QWO/TYRXB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-3DR"FUS9VED(")"87)E(@IM<V=S='(@(L'DY>GO(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"FUS9VED(")"87-E(&=R87!H:6-S
M(&1I<F5C=&]R>2`G)7,G(&YO="!F;W5N9"XB"FUS9W-T<B`BSR#J_?'I[_(@
MZN'TW.OOX^_R(./QX?;IZO[M("<E<R<@Y.7M(.+QW>CGZN4N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"FUS
M9VED(")"87-E;&EN92(*;7-G<W1R("+"X?/IZMX@X_'A[.S>(@H*;7-G:60@
M(D)I<G1H9&%Y(@IM<V=S='(@(L/E[=WHZ^GA(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.C@Y"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G
M<W1R("+1]>CLW_/EZ?(@].S>[.'T[_(B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`BU/WP
M[_(@].S>[.'T[_(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C
M=&EO;BYP:'`Z,S(V"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC871I
M;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BU.\@].S>[.$@7"(E<UPB
M(/3G\B#E]N'Q[._CWO(@7"(E<UPB(.3E[2#B\=WHY^KE+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L
M9"(*;7-G<W1R("*X[?3O[>$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(Q"FUS9VED(")";W)D97)S(@IM<V=S
M='(@(KSQZ>$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@
M(D)O=&@B"FUS9W-T<B`BRN'I(/3A(.3][R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M
M(@IM<V=S='(@(LKA]/[TX?3O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G
M<W1R("++W_/TX2#LY2#TY>OEW^7R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV,C$*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I
M;G1S(@IM<V=S='(@(M/G[.7?X2#DZ>'M[^S>\B!#4DPB"@IM<V=I9"`B0U93
M(@IM<V=S='(@(L'Q]^7?[R#JY>GLW>WO]2#W^?'I\^S=[>\@[.4@ZOSL[.$@
M*$-64RDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS
M9W-T<B`BR>3I_/3G].7R(,KEZ^G^[2XN+B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-38@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$T,PIM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`BQ^SE\>_K_./I
M[R(*"FUS9VED(")#86QE;F1A<CHB"FUS9W-T<B`BQ^SE\>_K_./I[SHB"@IM
M<V=I9"`B0V%L96YD87(@4W5M;6%R>2(*;7-G<W1R("+0Y?'?Z^?XYR#'[.7Q
M[^O\X^GO]2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.34*
M;7-G:60@(D-A;&TB"FUS9W-T<B`BQ_'E[-_A(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O
M<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(B(*(L'D_>WA].<@YR#A\??IZN_P[]_G\^<@]._U(.KYY.GJ
M[_T@X?7T_.SA].$L(.7PZ>KOZ>WY[=[S].4@[.4@].\@Y.GA]^7I\>GS]-XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR-#$@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q,@IM<V=I9"`B0V%N)W0@8V]N
M;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`BP>3][>'TYR#G(//]
M[>3E\^<@[.4@]._M($E-05`M4V5R=F5R.B`E<R(*"FUS9VED(")#86YC96PB
M"FUS9W-T<B`BP>K]\?GSYR(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T
M<B`BP>K]\?GSYR#![>'V[_'<\B#0\>_BZ][LX?3O\B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,C8Y"FUS9VED(")#86YN;W0@9&5L971E(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R("+!Y/WMX?3G(.<@Y.GAX_'A]MX@]._U(.'Q
M]^7?[_4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-PHC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C4S"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R
M>2!D:7)E8W1O<GDN(@IM<V=S='(@(L3E(.+QW_/J^2#P\>_S^?'I[?P@]MSJ
MY>OO("AT96UP(&1I<BDN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+G!H<#HY-PIM<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U
M="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R("+!Y/WMX?3G(.<@
M\_7MW??EZ>$@]_GQW_(@].?M(/#A\=SLY?3Q[R!<(G1A<F=E=$9I;&5<(BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(V-0IM<V=I9"`B0V%N
M;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("+!Y/WMX?3G
M(.<@Y.GAX_'A]MX@]._U(/;AZMWK[_4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R
M:R]$871A5')E92]$871A5')E92YP:'`Z,3$R(&9R86UE=V]R:R]$871A5')E
M92]$871A5')E92]S<6PN<&AP.C4W-@IM<V=I9"`B0V%N;F]T(')E;6]V92P@
M)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(L'D_>WA].<@YR#DZ>'C\>'V
MWBP@)60@]?#VW.KEZ^_R(/7PW/'WY>DN(@H*(SH@9G)A;65W;W)K+T1A=&%4
M<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`R"FUS9VED("(B"B)#86YN;W0@<F5O
M<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@
M9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@HB
MP>3][>'TYR#G(.7PX>WA].'NZ>W\[.?SYRP@[R#A\>GH[/SR(/3Y[2#EX^/Q
MX?;^[2#P[_4@Y/[SX?3E(./IX2`B"B+E\.'MX?3A[NGM_.SG\^<L(.3E[2#T
MX>GQZ=SFY>D@[.4@]._M(.'QZ>CL_"#T^>T@X?#OZ.?JY?7LW>WY[2XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,3@*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N
M=6UB97(N(@IM<V=S='(@(L3E(.SP[_'^(.WA(.3Q[^SOZ^_CWO/Y(.S>[?7L
MX2#S]._M(.'QZ>CL_"#P[_4@[_'?\^'TY2XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"FUS9VED(")#87!T
M:6]N(@IM<V=S='(@(L7PZ>KE]N'KW^3A(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDP"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T
M<B`BRN'TY^/O\=_E\B#JX>D@Q?3IZMWTY?(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DW"FUS9VED(")#96QL(%!H;VYE
M(@IM<V=S='(@(LKI[>?T_"#4Y^O=]OGM[R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@
M4')O<&5R=&EE<R(*;7-G<W1R("+)Y.G\].?TY?(@RN7KZ>_](@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@
M(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`BP]WLZ?/LX2#*Y>OI[_TZ(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(LGDZ?STY_3E\B#*
MY>OI[_TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("+$Z=SJY>WO
M(,KEZ^G^[3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8U"FUS
M9VED(")#96QL<&AO;F4B"FUS9W-T<B`BRNGMY_3\(-3GZ]WV^>WO(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(LK=[?3Q[R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S(S"FUS9VED(")#97)T:69I8V%T
M92!$971A:6QS(@IM<V=S='(@(LOE\/3O[-WQY>GE\B#0Z?/T[_#OZ>?TZ>KO
M_2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(P"FUS
M9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R("+0[^OI].GJWB#0
MZ?/T[_#OZ>?TZ>KO_2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-3DV(#\_/PIM<V=I9"`B0VAA:7(@4&5R<V]N(@IM
M<V=S='(@(M#Q_.7D\>_R(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-PIM<V=I9"`B
M0VAA;F=E(@IM<V=S='(@(L'KZ^'CWB(*"FUS9VED(")#:&%N9V4@4&%S<W=O
M<F0B"FUS9W-T<B`BP>OKX>/>(.KYY.GJ[_TB"@IM<V=I9"`B(@HB0VAA;F=E
M('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H
M97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@
M(B(*(L'KZ]SN].4@].\@_.WO[.$@ZN'I(/3G(.3IY?WH]>WSYR#P[_4@Z.$@
MXNO=\._U[2#\].'M(.3IX>+<YN_U[2#>(.'PX>WT[_WM("(*(O/E(.SG[?WL
MX?3<(//A\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T<B`BU^'QX>KTWO'A
M\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`BN.OE
MX_?O\B#S_>WDY?/G\BXN+B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C
M;VYF:7)M7W1O<"YI;F,Z,3,*;7-G:60@(D-H96-K('1H92!B;W@@9F]R(&%N
M>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I
M;64N(@IM<V=S='(@(B(*(M/G[.7I_O/TY2#T[R#TY?3QX>/Y[=_DZ>\@X^GA
M(._P[^GAY-[P[_3E(.7QX^'SW^$HY?(I(.C=Z^7TY2#MX2#EZO3EZ^7S]._]
M[2`B"B+A]?3>(/3G(//TZ>/LWBXB"@IM<V=I9"`B0VAI;W,@06ER<&]R="(*
M;7-G<W1R("+!Y?'OZ^GLW>WA\B#7W^_U(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V%P<"YI;F,Z-PIM<V=I9"`B0VAO;W-E($%P<&QI8V%T:6]N.B(*;7-G<W1R
M("+%\.GKW>[TY2#%]N'Q[._CWCHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,C@R"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G
M<W1R("+%\.GKW>[TY2#J^>3IZOPB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,C@Q"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G
M<W1R("+%\.GKW>[TY2#\[>_LX2#W\=[S].<B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0U,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8R-@IM<V=I9"`B0VAO
M;W-E(&%N(&%C=&EO;CHB"FUS9W-T<B`BQ?#IZ]WN].4@[.GA(.7MW?'CY>GA
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.#(*;7-G:60@(D-H;V]S
M92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`BQ?#IZ]WN].4@\/GR
M(.CA(.7L]N'MW^;O[?3AZ2#OZ2#G[.7Q[^SG[=_E\CHB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS
M9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T
M<RDB"FUS9W-T<B`BQ?#IZ]WN].4@]/WP[R#KW_/TX?(@*./IX2#TX>[I[>_L
MY^S=[>7R(.O?\_3E\BDB"@IM<V=I9"`B0VAR>7-O=7!O;&D@06ER<&]R="(*
M;7-G<W1R("+!Y?'OZ^GLW>WA\B#7\?7S[_WP[^OG\B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4RYP:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HV
M-34*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*
M;7-G<W1R("+$Y>T@XO'=Z.?JY2#O\>GS[/SR(.KKW//G\B#T[_4@)7,N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q-`IM<V=I9"`B0VQE
M87(B"FUS9W-T<B`BRN'HW/'I\^4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T
M86=S(@IM<V=S='(@(LKAZ.'QZ?/L_/(@Y?3IZN7T_NT@*'1A9W,I($U3+4]F
M9FEC92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHW"FUS
M9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B)\'DY>GA\^SA)R#7
M\=[S].<Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C$V"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(LKAZ.'QZ?/L_/(@U_'>
M\_3G(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S<*;7-G
M:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R("+*X>CA\>GS[/SR(.3EY._L
MW>WY[2#W\=[S].<B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;F]T:6-E
M7V)O='1O;2YI;F,Z-@IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T
M<B`BRMSM].4@ZNOIZB#CZ>$@\_7MW??EZ>$B"@IM<V=I9"`B0VQO<V4@2&5L
M<"!7:6YD;W<B"FUS9W-T<B`BRNOEW_/I[.\@T.'QW.CU\>_U(,+OWNCEZ>'R
M(@H*;7-G:60@(D-L;W-E($AE;'`B"FUS9W-T<B`BRNOEW_/I[.\@PN_>Z.7I
MX?(B"@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(LKKY=_SZ>SO(-#A
M\=SH]?'O]2(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z-`IM
M<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R("+![>'DW_#K^?/G(-#K
MY?7QZ>K>\B#,\-SQX?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R
M<R(*;7-G<W1R("+![>'DZ?#K^>S=[>$@T.7QZ>C^\>GA(@H*(SH@;&EB+T)L
M;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*
M;7-G:60@(D-O;&]R(@IM<V=S='(@(M?Q_NSA(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C(Y-PHC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,CDX"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-S(@<V5R=FEC97,O:6UA9V5S+V-O
M;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHU,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHU,@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHV.`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHV.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHX-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHX-@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@
M(L7PZ>O=ZO3G\B#7\?[LX?3O\B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(X,S0*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`BQ?#I
MZ^_CWB#7\?[LX?3O\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R("+3]-[KY?(Z
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DR.0IM<V=I9"`B0V]L
M=6UN('1I=&QE<R(*;7-G<W1R("+4W_3K[^D@T_3GZ_[M(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(X.0IM<V=I9"`B0V]M:6-S(@IM<V=S='(@
M(D-O;6EC<R(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-0IM<V=I9"`B0V]M
M;6%N9"(*;7-G<W1R("+%[?3OZ]XB"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z
M,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`BRMWK]?;O\B#%[?3O
MZ_[M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,SDY"FUS
M9VED(")#;VUM96YT(@IM<V=S='(@(M/W_.OI[R(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DP"FUS9VED(")#;VUM;VX@3F%M92(*
M;7-G<W1R("+*[^GM_""\[>_LX2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR-#(*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B
MQ?3AZ?'EW^$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C8Y-PIM<V=I9"`B0V]M<&QE=&5D(@IM<V=S='(@(L_K[^KK
MY_'^Z.?JY2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA
M:6QS+G!H<#HX,0HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M
M86EL<RYP:'`Z.#<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E
M;6%I;',N<&AP.CDW"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O
M96UA:6QS+G!H<#HQ,#$*;7-G:60@(D-O;7!O<V4@365S<V%G92`H)7,I(@IM
M<V=S='(@(M/][>CE\^<@S.?M_>SA]._R("@E<RDB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R("+5\._K
M[^/I\_3=\B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0W"FUS9VED(")#
M;VYD:71I;VYS(@IM<V=S='(@(M/U[>C>ZN7R(@H*(SH@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z.#D*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B
M"FUS9W-T<B`BQ.GA]N_QW?(@T.'QX>SE]/'O\._?Y_/G\B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-#8*;7-G:60@(D-O;F9I9W5R871I;VX@9F]R
M('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB
M"FUS9W-T<B`BQ?#IZ^_CW?(@X^GA(//UX_?Q[^WI\^S\(.SE(%!$07,L(-WN
M]?#MX2#4Y^O=]OGMX2#JX>D@3W5T;&]O:RXB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3,U"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D
M871E+B(*;7-G<W1R(")$:64@2V]N9FEG=7)A=&EO;B!M=7-S(&%K='5A;&ES
M:65R="!W97)D96XN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R-0IM
M<V=I9"`B0V]N9FEG=7)A=&EO;B!N965D<R!U<&1A=&EN9RXB"FUS9W-T<B`B
MQR#PX?'A[.7T\>_P[]_G\^<@]_'EZ=SFY?3AZ2#E[>?LW?'Y\^<N(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.CDY"FUS9VED(")#;VYF:6=U<F4@)7,B
M"FUS9W-T<B`BT.'QX>SE]/'O\._?Y_/G("5S(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHS-PIM<V=I9"`B0V]N9FER;2!087-S=V]R
M9"(*;7-G<W1R("+%\.GBY>+AW_GSYR#*^>3IZN_](@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C`V"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q.0IM<V=I9"`B0V]N;F5C=&EO
M;B!F86EL960N(@IM<V=S='(@(L<@\_WMY.7SYR#A\-WT]??E+B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(P-@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3D*;7-G:60@(D-O
M;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`BQR#S_>WDY?/G(.'PW?3U]^4Z
M("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,PIM<V=I
M9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+B(*;7-G<W1R("+!\>WG\^<@\_WMY.7SY_(@X?#\(/3O(.3G[/SSZ>\@Y>[U
M\.?QY?3G]-X@ZNOEZ>3I_NTN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-SDU"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE
M('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R("+!
M\>WG\^<@\_WMY.7SY_(@X?#\(/3O(.3G[/SSZ>\@Y>[U\.?QY?3G]-X@ZNOE
MZ>3I_NTN(,O\X^_R(#H@)7,@*"5S*2(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-SDT"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@
M9F%I;&5D+B(*;7-G<W1R("+'(//][>3E\^<@[.4@].\@1E10+5-E<G9E<B#A
M\-WT]??E+B(*"FUS9VED(")#;VYT86-T(%-E87)C:"(*;7-G<W1R("+![>'F
MWO3G\^<@Q?#A]M[R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C4V"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL
M>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`BS^D@Y?#A
M]MWR(/#Q[_/TW>CGZN'M(.7PZ?3U]_[R(//T[R#$Z>7UZ/7M\^GOX_'<]N\@
M\^'R+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X"FUS9VED(")#
M;VYT96YT<R!O9B`G)7,G(@IM<V=S='(@(M#E\>GE]_SLY>WA(/3O]2`G)7,G
M(@H*;7-G:60@(D-O;G1E;G1S(&]F('1H92!205(@87)C:&EV92(*;7-G<W1R
M("+0Y?'IY??\[.7MX2#T^>T@X?'WY=_Y[2!205(B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HR.0IM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B
MT_7MW??EZ>$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`BP>WTZ>/Q
MX?;>(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`BP>WTZ>/QX?;>
M(,7PZ>OOX][R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M.3<W"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92XB"FUS
M9W-T<B`BP>3][>'TYR#G(.KQ]?#T[^/QW/;G\^<@]._U(.SG[?WLX?3O\B#L
MY2!01U`N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`U
M-0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N(@IM<V=S='(@
M(L'D_>WA].<@YR#U\._C\>'VWB#T[_4@[.?M_>SA]._R(.SE(%!'4"XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0Q,0IM<V=I9"`B
M0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(L'D
M_>WA].<@YR#J\?7P]._C\=SVY_/G(/3O]2#LY^W][.'T[_(@[.4@4R]-24U%
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#@U"FUS
M9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B
MP>3][>'TYR#G(/7P[^/QX?;>(/3O]2#LY^W][.'T[_(@[.4@4R]-24U%+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,3@T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@
M(L3E[2#L\/SQY?/A(.WA(/#Q[_/HW?/Y(/3G[2#E\.'VWBX@)7,B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$Q,PIM<V=I9"`B0V]U;&0@
M;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(L'D_>WA].<@YR#S
M_>WDY?/G(.SE(/3O($Q$05`M4V5R=F5R+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34T"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PIM<V=I9"`B0V]U
M;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(L'D_>WA]._R(.\@
MW>OEX^_R(/7P[^OOW_#O]2X@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-#@*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B`G)7,G
M('5S:6YG($944#H@)7,B"FUS9W-T<B`BP>3][>'TYR#G(//][>3E\^<@\_3O
M[2#E[O7PY_'E].?TWB`G)7,G(/?QY_/I[/#OZ?[M].'R($944#H@)7,B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R
M.0IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,B"FUS9W-T<B`BP>3][>'TYR#G(.3G[.GO]?'CW^$@Z]_S].'S(.3IX>WO
M[-[R+B`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q
M,C8*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+B(*;7-G<W1R
M("+!Y/WMX?3G(.<@X?#OZO'U\/3OX_'<]N?SYR!01U`@Y.7D[^S=[?GM+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-30P"FUS9VED
M(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T<B`BP>3]
M[>'TYR#G(.'P[^KQ]?#T[^/QW/;G\^<@4R]-24U%(.3EY._LW>WY[2XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(U
M,`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R
M("+!Y/WMX?3G(.<@Y.GAX_'A]MX@Y?#A]M[R+B`E<R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S8U"FUS9VED(")#
M;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R
M("+!Y/WMX?3G(.<@Y.GAX_'A]MX@Z]_S].'R(.3IX>WO[-[R+B`E<R(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,W"FUS9VED(")#;W5L9"!N;W0@
M9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T("<E<R<N(@IM<V=S='(@(L'D
M_>WA].<@YR#DZ>'C\>'VWB!S971U<"!U<&=R861E('-C<FEP="`G)7,G("XB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y.2!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3D*;7-G:60@(D-O=6QD(&YO
M="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*
M;7-G<W1R("+$Y2#L\._Q_B#MX2#DZ>7UZO'I[=[S^2#TYR#DZ>7]Z/7M\^<@
M]._U(/#A\>'KWO#TYRXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C(X.`IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O
M;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`BP>3][>'TYR#G(/#KWO'G
M\B#P\?SSXN'SYR#T[_4@Q.GE]>CU[?/I[^/QW/;O]2XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q,`IM<V=I9"`B
M0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*
M;7-G<W1R("+!Y/WMX?3G(.<@\.O>\>?R(/#Q_//BX?/G(/3G\B#KW_/TX?(@
MY.GA[>_LWO(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HT-C$*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M
M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(L'D
M_>WA].<@YR#PZ][QY_(@\/'\\^+A\^<@Z]_S].'R(.'P_"#KW_/TY?(@Y.GA
M[>_LWO(N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-CD*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-0IM
M<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@)R5S)RXB"FUS9W-T<B`B
MP>3][>'T[R#T[R#V_/'T^>SA(//T\>'TY^/IZM[R(%PB)7-<(BXB"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z,3$Q"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,0IM
M<V=I9"`B0V]U;&0@;F]T(&UK9&ER("<E<R<N(@IM<V=S='(@(L'D_>WA].<@
MYR#DY^SI[_7QX]_A(/;AZMWK[_4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C<R,`IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I
M;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`BP>3]
M[>'TYR#G(.'MW.KTY_/G(.3G[/SSZ>_U(.KKY>GDZ>_](.'P_"#T[^T@Y>[U
M\.?QY?3G]-X@Q.?L+LKKY>GDZ?[M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-S`R"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,U-`IM<V=I9"`B0V]U;&0@
M;F]T(&]P96X@)7,N(@IM<V=S='(@(L'D_>WA].\@].\@W.WOZ>/LX2`E<RXB
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z,30P"FUS9VED(")#;W5L9"!N;W0@;W!E
M;B`G)7,G(&9O<B!W<FET:6YG+B(*;7-G<W1R("+!Y/WMX?3O(/3O(-SM[^GC
M[.$@7"(E<UPB(./IX2#EX^/QX?;>+B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N
M86YC92]-86EN=&5N86YC92YP:'`Z-#$U(&,M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R
M("+!Y/WMX?3O(/3O(-SM[^GC[.$@]._U(.S=\>_U\B#$Z>'WY=_QZ?/G\B`E
M<R(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,0IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@9&ER96-T;W)Y("<E<R<N(@IM<V=S='(@(L3E[2#L\._Q_B#MX2#A[>_?
M[OD@].\@]MSJY>OO(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/
M8FIE8W0N<&AP.C(W,`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S
M='(@(L3E[2#L\._Q_B#MX2#DZ>'BW//Y("5S+B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@
M=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@
M86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G
M86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D
M("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HBP>3][>'TYR#G(.'Q]^GJ
M[_#OW^?SYR#T[_4@ZOGDZ>KO_2#CZ>$@]._M(.'I]._][.7M[R#W\=[S].<N
M(,K<\._IX2#>(/SKY?(@(@HB[^D@Z^7P]._LW?'EZ>7R(.3E[2#EW^WAZ2#S
M^?/TW?(N(,[A[>'D[^KI[-SS].4@WB#E\.GJ[^GM^>W>\_3E(.SE(/3O(.3I
MX??EZ2TB"B+QZ?/TWB#A[2#W\>7IW//E\^CE(/#E\>GS\_STY?'G(.+OWNCE
MZ>$N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S$X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T
M.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#8*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDR"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y.`IM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R("+!Y/WMX?3G(.<@
MX>W<ZO3G\^<@R]_S].'R(,KA[?SM^>T@T/'\\^+A\^?R("A!0TPI(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-SD*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM
M<V=S='(@(L'D_>WA].<@YR#A[=SJ].?SYR#$Z>7UZ/7M\^GOX_'<]N_U+B`E
M<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3`Q"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S(@IM<V=S='(@(L'D_>WA].<@YR#A[=SJ].?SYR#+W_/TX?(@
MQ.GA[>_LWO(N("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HT-3(*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D
M:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(L'D_>WA].<@YR#A[=SJ
M].?SYR#+Z?/T_NT@Q.GA[>_LWO(N("5S(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(V"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C(S,`IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R("+!Y/WMX?3G(.<@
MX>W<ZO3G\^<@]/GM(.GDZ>_TWO3Y[2#T[_4@Y>[U\.?QY?3G]-XB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@<F5V
M97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(L'D_>WA].<@YR#E\.'MX?;O
M\=P@\?7H[-_SY?GM+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-0IM<V=I9"`B
M0V]U;&0@;F]T(')M9&ER("<E<R<N(@IM<V=S='(@(L'D_>WA].<@YR#DZ>'C
M\>'VWB#VX>K=Z^_U("AR;61I<BD@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C<Q"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("+$Y2#L\._Q_B#MX2#A\._HY^KE_?/Y("5S
M(/'UZ.S?\^7I\BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(D-O=6QD(&YO="!S879E
M(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`BQ.4@[/#O\?X@[>$@
MZMSM^2#E]N7D\>GJ_"#A[?3?X_'A]N\@]/GM(/'UZ.S?\^7Y[2XB"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*;7-G:60@(D-O=6QD(&YO="!S879E
M(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`BQ.4@[/#O\?X@
M[>$@ZMSM^2#E]N7D\>GJ_"#A[?3?X_'A]N\@]/GM(/'UZ.S?\^7Y[3H@)7,B
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,@IM<V=I9"`B0V]U;&0@
M;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("<E<R<N(@IM<V=S
M='(@(L3E(.SP[_'^(.WA(.'P[^CGZN7]\_D@\/'\X_'A[.SA(.7MY^S=\?GS
MY_(@\_3O("<E<R<N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(@IM<V=S='(@(L3E(.SP[_'^(.WA(.'P[^CGZN7]\_D@Y?;E
MY/'IZOP@X?'WY=_O(/'UZ.S?\^7Y[2`E<RXB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C<T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F
M('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O
M<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R
M("(B"B+$Y2#L\._Q_B#MX2#A\._HY^KE_?/Y(/3O(.'Q]^7?[R#Q]>CLW_/E
M^>T@)7,N(,SP[_'EW_3E(.7?].4@[>$@]_'G\^GL[_#OZ=XM(@HB\^7TY2#L
MZ>$@X?#\(/3I\B#E\.GK[^/=\B#CZ>$@[>$@X?#OZ.?JY?WSY?3E(/#?\_D@
M\_3O("5S(-X@X>WTZ>/QW/CTY2#LY2#T[R`B"B+WW?'I(/3O[2#J_N3IZN$@
M\-_S^2#S].\@)7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HQ,C,*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R
M+B(*;7-G<W1R("+!Y/WMX?3G(.<@X>WAYM[TY_/G(//T[^T@Y>[U\.?QY?3G
M]-X@3$1!4"XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#<*;7-G:60@(D-O=6QD
M(&YO="!U;FQI;FL@)R5S)RXB"FUS9W-T<B`BQ.4@[/#O\?X@[>$@X?#O\_7M
MY-WS^2!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HR,C$*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N
M=&%C="X@)7,B"FUS9W-T<B`BQ.4@[/#O\?X@[>$@Y>WG[.7Q_O/Y(/3G[2#E
M\.'VWBX@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C0P.0IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B"FUS9W-T<B`BQ.4@[/#O\?X@[>$@Y>WG[.7Q_O/Y
M(/3G(,O?\_3A(,3IX>WO[-[R+B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HW,`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@
M9F]R("<E<R<Z("5S(@IM<V=S='(@(L3E(.SP[_'^(.WA(./QW/CY(/3I\B#Q
M]>S?\^7I\B#CZ>$@)R5S)SH@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S4P"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B
M87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B
M"B+$Y2#L\._Q_B#MX2#B\?X@].<@\.OE]?'IZMX@[/#<\>$@]._U($UO>FEL
M;&$N(,+EXN'I^>CEW_3AZ2#\].D@Y=_MX>D@(@HBX>WOZ>KTWBXB"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-3D*;7-G:60@
M(D-O=6QD;B=T(&=I=F4@=7-E<B`G)7,G('1H92!F;VQL;W=I;F<@<FEG:'1S
M(&9O<B!T:&4@9F]L9&5R("<E<R<Z("5S(@IM<V=S='(@(B(*(L3E(.SP[_'^
M(.WA(.3^\_D@\_3O(/?QWO/TYR`G)7,G(/3A(/#A\>'JW/3Y(.3IZN'I_NSA
M].$@\_3O(/;<ZN7K[R`G)7,G.B`E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T,34*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R("+,Y?3Q
MY^S=[>\@ZN7?[.7M[R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3DS"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(M?^\>$B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<S"FUS9VED(")#;W5R<V5S(@IM
M<V=S='(@(M#O\>7?Y?(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDW"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$*;7-G:60@(D-R96%T92(*;7-G
M<W1R("+$Y^SI[_7QX]_A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED(")#<F5A=&4@82!L:6YK
M(@IM<V=S='(@(L3G[.GO]?'CW^$@Y>W\\B#S]>WDW?/L[_4B"@IM<V=I9"`B
M0W)E871E(&$@;F5W(&]N92(*;7-G<W1R("+$Y^SI[_7QX]_A(.SIX?(@[=WA
M\B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDU
M"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`BQ.?LZ>_U\>/?
MX2#U\._VX>K=Z_GM(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3,V(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C(R"FUS9VED(")#<F5A=&]R
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(L7N[_7SZ>_D[_3>\^7I\B#$Y^SI[_7Q
MX^_](@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(Q-`IM<V=I9"`B
M0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(L'QZ>CL_/(@T.GS]/GTZ>K>
M\B#*W/'TX?(B"@IM<V=I9"`B0W)E9&ET<R(*;7-G<W1R("+%]??A\>GS]-_E
M\B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@IM<V=I9"`B0W5R<F5N="!0
M:&%S92(*;7-G<W1R("+4\=WW[_7SX2#6W//G(@H*(SH@;&EB+T)L;V-K+W1I
M;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT
M(%1I;64B"FUS9W-T<B`BU/'=]^_U\^$@_O'A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")#
M=7)R96YT(%523"!I<R(*;7-G<W1R("+4[R#T\=WW[^T@55),(.7?[>'I(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!796%T
M:&5R(@IM<V=S='(@(M3QW??O[2#*X>GQ_/(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C$Y"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@
M(@IM<V=S='(@(M3QW??O]?/A(//U[>C>ZN<Z("(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@
M<W1Y;&4B"FUS9W-T<B`BU/'=]_GM(//T_>LB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3`X"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P
M;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(M#A\>'LY?3Q[_#OW^?SYR#DZ>'D
MZ>KA\^G^[2#P[_4@Y>KTY>OO_>WTX>D@ZN'TW"#TY^T@Y=_S[^3O("5S+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(L'P[^KO\-XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED(")#
M=70@<V5L96-T:6]N(@IM<V=S='(@(L'P[^KO\-X@Y?#IZ^_CWO(B"@IM<V=I
M9"`B1$0B"FUS9W-T<B`BS,PB"@IM<V=I9"`B1&%I;'DB"FUS9W-T<B`BQ^SE
M\=[SZ>$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS9VED
M(")$871A(@IM<V=S='(@(L3EY._LW>WA(@H*(SH@861M:6XO9&%T871R964N
M<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(L7L]MSM
MZ?/G("A"<F]W<V5R*2!$871A5')E92(*"FUS9VED(")$871A8F%S92!Q=65R
M>2!F86EL960N(@IM<V=S='(@(L<@X>WAYM[TY_/G(//TYR#"W//G(,3EY._L
MW>WY[2#A\-WT]??E+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,X,0IM
M<V=I9"`B1&%T92(*;7-G<W1R("+'[.7Q[^SG[=_A(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(D1A=&4@4F5C96EV
M960B"FUS9W-T<B`BQ^SE\>_LY^W?X2#PX?'AZ^'BWO(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-SDU"FUS9VED(")$871E('-E;&5C=&EO;B(*
M;7-G<W1R("+%\.GK[^/>(,?LY?'O[.?MW^'R(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(V,PIM<V=I9"`B1&%Y(@IM<V=S='(@(L?LW?'A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,U"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R("+$Z>'C
M\>'VWB#3]-[KY_(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S@U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`BQ.7JW>SB\>GO
M\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R("+$
MY>KAY.GJ[]\@X?'IZ.SOWR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-C@U"FUS9VED(")$96-L:6YE9"(*;7-G<W1R
M("*X]^_U[2#A\>WGZ.7?(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S
M='(@(LSEW_GSYR#0Y?'IZ/GQW^_U(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ.3(@;&EB+W!R969S+G!H<#HQ,#@*;7-G:60@(D1E9F%U
M;'0B"FUS9W-T<B`BT/'OZN'H[_'I\^S=[>\B"@HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-PHC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0IM<V=I9"`B1&5F875L="!#
M;VQO<B(*;7-G<W1R("+0\>_E\.GKY>/LW>WO(-?Q_NSA(@H*;7-G:60@(D1E
M9F%U;'0@261E;G1I='DB"FUS9W-T<B`BT/'OY?#IZ^7C[-WMYR#4X?7T_/3G
M].$B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,3D@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HR,#0*;7-G:60@(D1E9F%U;'0@4&5R;6ES<VEO
M;G,B"FUS9W-T<B`BT/'OZN'H[_'I\^S=[>7R(,7N[_7SZ>_D[_3>\^7I\B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C`U"FUS9VED(")$
M969A=6QT('!E<FUI<W-I;VYS(@IM<V=S='(@(M#Q[^KAZ._QZ?/LW>WE\B#%
M[N_U\^GOY._TWO/EZ?(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*
M;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(L_QZ?/L[]\B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8T,PIM<V=I
M9"`B1&5L96=A=&4@<&]S:71I;VXB"FUS9W-T<B`BR-WSYR#A[?3I\/'O\_[P
M[_4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C8Y,PIM<V=I9"`B1&5L96=A=&5D(@IM<V=S='(@(L'M].GP\>_S^?#G
M[-WM[R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S(@861M:6XO<&5R;7,O9&5L
M971E+G!H<#HT-B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,CDW(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,S(W"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,S0W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#(*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHW-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDY"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(R('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,30U"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3@X('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,PHC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3D@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]D96QE=&4N:6YC.C$S"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C,T"FUS9VED(")$96QE=&4B"FUS9W-T<B`BQ.GAX_'A]MXB
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$X.2!A9&UI;B]G<F]U<',N<&AP.C(Q
M-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(L3IX>/QX?;>(,_LW.3A
M\B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-C`@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-`IM<V=I9"`B1&5L971E(%!E<FUI
M<W-I;VXB"FUS9W-T<B`BQ.GAX_'A]MX@Q>[O]?/I[^3\].?SY_(B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-@IM<V=I9"`B
M1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R("+$Z>'C\>'VWB#J
MX>D@Y>KJW>WY\^<@[.?M]>S<]/GM(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E
M;&PB"FUS9W-T<B`BQ.GAX_'A]MX@ZN7KZ>_](@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L
M971E(&-O;'5M;B(*;7-G<W1R("+$Z>'C\>'VWB#3]-[KY_(B"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L
M=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("+$Z>'C\>'VWB#U\-SQ]^_M]._R
M(.7MX>OKX>KTZ>KO_2#P\>_T_?#O]2(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z-3`@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,C8*;7-G
M:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@)R5S)R(*;7-G<W1R("+$Z>'C
M\>'VWB#E[N_U\^GOY._TWO/E^>T@X^GA("<E<R<B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C,R.0IM<V=I9"`B1&5L971E('!E<FUI<W-I
M;VYS(&9O<B`G)7,G(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R
M("+$Z>'C\>'VWB#E[N_U\^GOY._TWO/E^>T@X^GA("<E<R<@ZN'I(.K<Z.4@
M]?#O+>7N[_7SZ>_D_/3G\^<[(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O=R(*
M;7-G<W1R("+$Z>'C\>'VWB#S]-[KY_(B"@HC.B!T96UP;&%T97,O<')E9G,O
M9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@
M:61E;G1I='DB"FUS9W-T<B`BT/'OY?#IZ^7C[-WMYR#4X?7T_/3G].$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C8*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T
M<B`BQ.GAX_'A]MX@]/'=]^_U\^'R(//TWNOG\B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B
M1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R("+$Z>'C\>'VWB#T\=WW
M[_7SX?(@X_'A[.S>\B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#@*
M;7-G:60@(D1E;&5T92!T:&ES('!E<FUI<W-I;VX@86YD(&%N>2!S=6(M<&5R
M;6ES<VEO;G,_(@IM<V=S='(@(L3IX>/QX?;>(.'U]-[R(/3G\B#E[N_U\^GO
MY/STY_/G\B#JX>D@ZMSHY2#U\.\MY>[O]?/I[^3\].?SY_([(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S4*;7-G:60@(D1E;&5T960@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@)R5S)RXB"FUS9W-T<B`BQ.GAX_'<]N?JY2#T[R!S
M971U<"!U<&=R861E('-C<FEP="`G)7,G+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@U"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C$Y"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C$*;7-G
M:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`BO_'A(-SVZ>[G\B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C0R"FUS
M9VED(")$96YY(')E<75E<W0B"FUS9W-T<B`BP?'MY_/G(.'I]-[LX?3O\B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-#<Q"FUS9VED(")$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA
M=&EO;B(*;7-G<W1R("+!\>WG\^<@X>GTWNSA]._R(./IX2#PZ^?Q[_;O\=_E
M\B#DZ>'HY?/I[/STY_3A\B(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.CDU
M('-E<G9I8V5S+W!R;V)L96TN<&AP.CDY('-E<G9I8V5S+W!R;V)L96TN<&AP
M.C$P.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`BT.7Q
MZ>/QX?;>(/3O]2#0\>_BZ][LX?3O\B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-38U(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.CDS,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R("+0
MY?'IX_'A]MXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(P,0IM
M<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G
M<W1R("++Y?#T[^S=\>7IY?(@*.7PW_/G\B#JX>D@\_3O(.'Q]^7?[R#JX?3A
MX_'A]M[R(/3O]2!(;W)D92DZ(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HR,#4*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@
M=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(L_I(.OE\/3O[-WQY>GE\B#=
M]^_U[2#JX?3AX_'A]N7?(./IX2#T[^T@Y.GA]^7I\>GS]-XN(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y,PIM<V=I9"`B1&5V96QO<&UE;G0B
M"FUS9W-T<B`BP>W<\/3U[N<B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q
M-0IM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(M/G[.7?[R#$\>_SZ=SR(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-@IM<V=I9"`B1&5W
M('!O:6YT.B`B"FUS9W-T<B`BT^?LY=_O(,3Q[_/IW/(Z("(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,CDR"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@
M:&]U<CH@(@IM<V=S='(@(M/G[.7?[R#$\>_SZ=SR(./IX2#TY^T@].7KY?7T
MX=_A(/[QX3H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS
M9W-T<B`BRN'TY?WH]>WSYR#A\/P@X?'I\_3E\=P@\/'O\B#TX2#DY>[IW"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*
M;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(LKA].7]
MZ/7M\^<@X?#\(/3A(.3E[NG<(/#Q[_(@].$@X?'I\_3E\=PB"@HC.B!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@
M(LKA]-SK[^/O\B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3`*;7-G
M:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`BQ>SVW.WI\^<@
M_O'A\B#SY2`R-/GQYR#L[_'VWCLB"@IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS
M(@IM<V=S='(@(L7PZ>OOX]WR(,7L]MSMZ?/G\B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z.#,*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS
M9W-T<B`BQ>SVW.WI\^<@\/'OXNO=^.7Y[2`H5$%&*2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X,#4*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM
M<V=S='(@(LSO\?;>(,7L]MSMZ?/G\B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O341.+G!H<#HR,#,*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO
M;B(*;7-G<W1R("+%[>?LW?'Y\^<@Q.G<].'NY_(B"@HC.B!A9&UI;B]P97)M
M<R]D96QE=&4N<&AP.C0V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,S(W"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(LSG(.3IX>/QW/;E
MZ?(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C0*;7-G:60@(D1O
M(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@
M(LSG[2#E\.GWY>GQWO/E].4@[>$@X>WOW^[E].4@X?#E]>CEW^'R(/3O(.'Q
M]^7?[R!M86EN=&5N86YC92YP:'`B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I
M;F9O+FEN8SHQ.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ.0IM<V=I
M9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S
M/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R("+0Y?'IW??EZ2#G
M(/#Q_O3G(./QX>SLWB#O[?SLX?3A(/#EY-_Y[3L@P>T@[>'I(/3SY>K<\>7T
MY2#A]?3\.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C@V-@IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`BRN'TW>+A\^SA(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#8V"FUS9VED(")$
M;W=N;&]A9"`E<R(*;7-G<W1R("+*X?3=XN'S[.$@)7,B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,34V"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@
M8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R("+*X?3=XN'S
M[.$@]._U(.'Q]^7?[_4@\.'QX>S=]/'Y[2#SX>T@4$A0+7-C<FEP="XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#DP"FUS9VED(")$<F]P(&1O
M=VX@;&ES="(*;7-G<W1R("++W_/TX2#*X?3A\=SJ].?R(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R("+6W/'L
MX>KA+>WA\>KY].GJW"(*"FUS9VED(")%9&ET(@IM<V=S='(@(L7PY>[E\>/A
M\]_A(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU,2!T96UP
M;&%T97,O<&]R=&%L+V5D:70N:6YC.C(R"FUS9VED(")%9&ET($)L;V-K(@IM
M<V=S='(@(L7PY>[E\>/A\]_A($)L;V-K(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HQ.#@@861M:6XO9W)O=7!S+G!H<#HR,38*;7-G:60@(D5D:70@1W)O=7`B
M"FUS9W-T<B`BQ?#E[N7QX^'SW^$@S^S<Y.'R(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HU.2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C@S"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`BQ?#E[N7Q
MX^'SW^$@Q>[O]?/I[^3\].?SY_(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(L7P
MY>[E\>/A\]_A(,7N[_7SZ>_D[_3>\^7Y[2(*"B,Z('-E<G9I8V5S+W-H87)E
M<R]E9&ET+G!H<#HR,SD*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S
M(@IM<V=S='(@(L7PY>[E\>/A\]_A(,7N[_7SZ>_D[_3>\^7Y[2#CZ>$@)7,B
M"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHY"FUS9VED(")%9&ET(&]P
M=&EO;G,@9F]R.B(*;7-G<W1R("+%\.7NY?'CX?/?X2#E\.GK[^/^[2#CZ>$Z
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`IM<V=I9"`B161I
M="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`BQ?#E[N7QX^'SW^$@Q>[O
M]?/I[^3O]-[SY?GM(./IX2`E<R(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP
M.C(P-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(X.`IM<V=I9"`B
M161I="!P97)M:7-S:6]N<R!F;W(@)R5S)R(*;7-G<W1R("+%\.7NY?'CX?/?
MX2#%[N_U\^GOY._TWO/E^>T@X^GA("<E<R<B"@IM<V=I9"`B16QE9G-I<R!!
M:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(,7KY?7SW^WA\B(*"FUS9VED
M(")(97)A:VQI;VX@06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA\B#'\>'J
MZ^7?[_4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#(*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`BT_3O
MZ??EW^\N+BXB"@IM<V=I9"`B16UA:6PB"FUS9W-T<B`BP>OKY^OOX_'A]M_A
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#D@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C0P"FUS9VED(")%;6%I;"!!9&1R97-S
M(@IM<V=S='(@(L3IY?WH]>WSYR!%;6%I;"(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Y-#8*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA
M=&-H+B(*;7-G<W1R("+'(.3IY?WH]>WSYR!%;6%I;"#P\=WPY>D@[>$@].'I
M\>G<YN7I+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S(*;7-G
M:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(LS>[?7LX2#L
MY2#Q]>CLW_/EZ?(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C@P"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T<B`BP>GSZ-[L
MX?3A(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$Q"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R("+*Y>W\
M(.S>[?7LX2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$S
M,0IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R("+$Y>T@Y?#I\_3QW/;G
MZN'M(,'P[_3EZ]WS[.'TX2XB"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW
M;W)D<RYP:'`Z,3$T"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T
M<B`BP>3EZ>7R(//U[>C>ZN7R(.'MX>;>].?SY_(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3(V"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM
M86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("+%
M[>7QX^_P[]_G\^<@Y>GSX>/YX][R(.7IZOSM^>T@X?#O(%!H;W1O($-A;&QE
M<FEE=R#S].\@ZN7?[.7M[SLB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3`Q"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*
M;7-G<W1R("+-X2#E[>7QX^_P[^GGZ.7?(/3O(.SE[>_](.SE(.3E[M\@ZNOI
MZCLB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C0T.`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C4U,PIM<V=I9"`B16YD(@IM<V=S='(@(M3=Z^_R(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y,"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-SDY"FUS9VED(")%;F0@>65A<B(*;7-G<W1R("*X]._R(-3=Z^_U
M\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(LSEX]WMZ/7SYR#*
MY>GLY>WOX_'<]N_U(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P-0IM
M<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@
M=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A
M<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z
M(@IM<V=S='(@(B(*(L3^\_3E(.SIX2#E\?[TY_/G(.'S]N'KY=_A\BP@YR#O
M\._?X2#HX2#SX?(@YN?TY^CEWR#A[2#W\>7IX?/HY=\@[>$@X>OKW.[E+2(*
M(O3E(/3O[2#J^>3IZOP@\^'R+"#P+O<N("?0[^G\(.7?[>'I(/3O(/SM[^SA
M(/3O]2#JX?3OZ>KIY-_O]2#SX?([)SHB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N
M=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R("+$_O/TY2#TYR#S_>WD
MY?/G(/3G\B#EZ>K\[>'R(.7D_B(*"FUS9VED(")%<G)O<B(*;7-G<W1R("++
MW.CO\B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z,3DU"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z,C<X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z,S0W"FUS9VED(")%<G)O<B!S96YD:6YG(')E<&QY.B`E
M<RXB"FUS9W-T<B`BR]SH[_(@X?#O\_3=Z^OO[?3A\B#A\-SM].?SYSH@)7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,30*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T
M<B`BR]SH[_(@[.4@[-[M]>SA(&5M86EL+B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HQ-#,*;7-G:60@(D5R<F]R('=R:71I;F<@)R5S)RXB"FUS9W-T<B`BR]SH
M[_(@X_'<]N_M].'R(%PB)7-<(BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R("+%Z.WIZOPB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D5U<F]P92(*;7-G
M<W1R("+%]?'^\.<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(S"FUS
M9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(LK<Z.4@,34@Z^7P]-PB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<S"FUS9VED(")%=F5R>2`R
M(&UI;G5T97,B"FUS9W-T<B`BRMSHY2`R(,OE\/3<(@H*;7-G:60@(D5V97)Y
M(#,P('-E8V]N9',B"FUS9W-T<B`BRMSHY2`S,"#DY?7TY?'\Z^7P].$B"@IM
M<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(LK<Z.4@-2#KY?#TW"(*
M"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R("+*W.CE(/;O\=P@\._U(.SP
MX=_MY?3E(//TY^T@]?#G\>7SW^$B"@IM<V=I9"`B179E<GD@:&%L9B!H;W5R
M(@IM<V=S='(@(LK<Z.4@[.GSWB#^\>$B"@IM<V=I9"`B179E<GD@;6EN=71E
M(@IM<V=S='(@(LK<Z.4@Z^7P]/PB"@IM<V=I9"`B17AA;7!L92!V86QU97,Z
M(@IM<V=S='(@(M#A\>'DY>GC[.'TZ>K=\B#TZ>S=\CHB"@HC.B!A9&UI;B]P
M:'!S:&5L;"YP:'`Z-S8@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,S8*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`BQ>KTW>OE
M\^<B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HS.#8*
M;7-G:60@(D5X<&%N9"(*;7-G<W1R("+%\-WJ].'SYR(*"B,Z('1E;7!L871E
M<R]P;W)T86PO<VED96)A<BYI;F,Z,S$*;7-G:60@(D5X<&%N9"!3:61E8F%R
M(@IM<V=S='(@(L7PW>KTX?/G(-#KY?7QZ>K>\B#,\-SQX?(B"@HC.B!F<F%M
M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,38Y"FUS9VED(")%>'!E8W1E
M9"`G*2<B"FUS9W-T<B`BP>WA[-WM[^WTX>T@)RDG(@H*(SH@8RUF;W)M870*
M;7-G:60@(D5X<&5C=&5D(%PB0D5'24Y<(B!I;B!T:&4@;&EN92`E9"XB"FUS
M9W-T<B`BP>WA[.7M_.SE[>\@7")"14=)3EPB(//TYR#C\>'L[-X@)60N(@H*
M(SH@8RUF;W)M870*;7-G:60@(D5X<&5C=&5D(%PB14Y$.B5S7"(@:6X@;&EN
M92`E9"XB"FUS9W-T<B`BP>WA[.7M_.SE[>\@7")%3D0Z)7-<(B#S].<@X_'A
M[.S>("5D+B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ
M-S8*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H
M('1E<FTB"FUS9W-T<B`BP>WA[-WM[^WTX>T@X?#KWB#KW>[G(-X@\_7MZ-[J
MYR#A[>'FWO3G\^?R(//E(.7I\^'C^>/IZMPB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HS.3@*;7-G:60@(D5X<&ER871I;VX@1&%T92(*
M;7-G<W1R("+'[.7Q[^SG[=_A(,O>[N?R(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@
M(L7JZ-WTY_(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R("+7\?[L
MX2#P\>_SZM[MZ>_U(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W,0IM
M<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R("+1]>CLW_/EZ?(@
MX^GA($944"!U<&QO860B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L
M+G!H<#HR-#`*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S
M+B(*;7-G<W1R("+!\._T]???X2#JX?3<(/3G[2#P\>_S\-SHY>GA(.'MW.KT
MY_/G\B#T^>T@\/'O].GLWO/E^>TN(@H*;7-G:60@(D9A:6QE9"!T;R!C;VYN
M96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("+!\._T]???X2#S_>WDY?/G
M\B#S]._M(.3IX>KO[.GS]-X@RN'TX>O\X^_U+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<VUB+G!H<#HQ,#,*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T
M('1O(%--0B!S97)V97(N(@IM<V=S='(@(L'P[_3U]]_A(//][>3E\^?R(//T
M[^T@4TU"+5-E<G9E<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C8S,0IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S
M='(@(L'P[_3U]]_A(.'M].GC\>'VWO(@X?#\(%PB)7-<(BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C8S-@IM<V=I9"`B1F%I;&5D('1O(&-O
M<'D@=&\@7"(E<UPB+B(*;7-G<W1R("+!\._T]???X2#A[?3IX_'A]M[R(//E
M(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.CDR
M"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN
M(@IM<V=S='(@(L'P[_3U]]_A(.3G[.GO]?'CW^'R(//][>3E\^?R(%-!4TPN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV-S$*;7-G:60@(D9A
M:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`BP?#O]/7WW^$@[.7T
MX?;O\=SR(//E(%PB)7-<(BXB"@IM<V=I9"`B1F%I;'5R92!I;B!C:&%N9VEN
M9R!P87-S=V]R9"!F;W(@=7-E<B`E<R!F<F]M(&-L:65N="`E<RP@<F5A<V]N
M("5S(@IM<V=S='(@(B(*(L'P[_3U]]_A(.KA]-P@].?M(.'KZ^'CWB#J^>3I
MZN_](./IX2#T[^T@]_'>\_3G("5S(.'P_"#T[R#S].'H[/P@)7,L(.O\X^_R
M("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q-@IM<V=I
M9"`B1F%I<B(*;7-G<W1R("+!W^CQZ>_R(@H*(SH@9G)A;65W;W)K+T-,22]#
M3$DN<&AP.C(S-0IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(M#OZ_T@
M\^_BX?'\(,O<Z._R.B(*"FUS9VED(")&87@B"FUS9W-T<B`BUL'.(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W-0HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@
M(D9E8G)U87)Y(@IM<V=S='(@(M;EXO'O]=SQZ>_R(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,3@*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`BQ.G<
MZ.7SYR#CZ>$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@P
M"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`BQ.G<Z.7SYR#CZ>$Z("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3<*;7-G:60@(D9E
M=R!3:&]W97)S(@IM<V=S='(@(LO?X^7R(.+Q[_?=\B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,3@*;7-G:60@(D9E=R!3;F]W(%-H;W=E
M<G,B"FUS9W-T<B`BR]_CY?(@]^GO[>_P]/[SY>GR(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DR-PIM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S
M='(@(M#?[>'JX?(@T.7DW^_U(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#(*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`BP?'I
MZ.S\\B#A\??EW^_U.B`E<R#A\??EW^\B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HX,@IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T
M<B`BP?'IZ.S\\B#A\??EW^_U.B`E<R#A\??EW^$B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S0Y"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T
M<B`BQ.GA]^7I\>GS]-[R(,'Q]^7?^>TB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HX-0IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(KSM[^SA(,'Q
M]^7?[_4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3<Y"FUS9VED
M(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R("+%\.GK[^/>(,'Q]^7?[_4B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#@R"FUS9VED(")&:6QE('5P
M;&]A9"(*;7-G<W1R("(GP>W=XN'S[.$G(,'Q]^7?[_4B"@HC.B!F<F%M97=O
M<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-S0*;7-G:60@(D9I;&4@=7!L;V%D
M<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(GP>W=XN'S[.$G(,'Q]^7?[_4@
MY.7M(/7P[_/TY_'?YN7TX>DN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C@V"FUS9VED(")&:6QT97)S(@IM<V=S='(@(M;?Z_3QX2(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HQ-S$*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T
M<B`BT/'^].\@S.GS_"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T
M<B`BT/'^].\@U-WTX?'T[R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,SD*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R("+3
M].'HY?'\\B#K_./O\B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,30*;7-G:60@(D9L:7`B"FUS9W-T<B`B1FQI<"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(D9L;V%T(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,Q.0IM<V=I9"`B1F]G(@IM<V=S='(@(L_L
MW_?KYR(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,38S(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,#@*;7-G:60@(D9O;&1E<B`E<R!D
M;V5S(&YO="!E>&ES="(*;7-G<W1R("+/(/;<ZN7K[_(@)7,@Y.7M(/7PW/'W
MY>DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(M?Q_NSA(./QW.SLX?3O
M\B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*
M;7-G<W1R("+4\>_VWB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S
M('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`BP^GA($)R;W=S
M97)S+"#P[_4@Y.7M(/7P[_/TY_'?YN_U[2#EZ>K\[>7R(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHY-0IM<V=I9"`B1F]R9V]T('EO=7(@<&%S
M<W=O<F0_(@IM<V=S='(@(L[E]]SSX?3E(/3O[2#J^>3IZOP@\^'R.R(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S$*;7-G:60@(D9O<FUS(@IM
M<V=S='(@(M;\\>SE\B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM
M<V=I9"`B1F]R='5N92(*;7-G<W1R("+0\?SBZ^7XYR(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@
M(M3]\._R(-#Q_.+KY?CG\B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M.`IM<V=I9"`B1F]R='5N97,B"FUS9W-T<B`BT/'OXNO=^.7I\B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G
M<W1R("+0\>_BZ]WXY>GR(#(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#$T"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B1F]R=6US(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U.`IM<V=I9"`B1F]R=V%R9',B"FUS
M9W-T<B`BT/'O^>C>\^7I\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(M#A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@(M#KX=_SZ>$B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0Q-PIM<V=I9"`B
M1G)E92]"=7-Y($EN9F]R;6%T:6]N(@IM<V=S='(@(M#KY_'O]N_QW^7R(,3I
MX>CE\^GL_/3G].'R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HT,C<*;7-G:60@(D9R964O0G5S>2!297!L>2(*;7-G
M<W1R("+!\-SM].?SYR#$Z>'HY?/I[/STY_3A\B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#(R"FUS9VED(")&<F5E
M+T)U<WD@4F5Q=65S="(*;7-G<W1R("+!W_3G[.$@Q.GAZ.7SZ>S\].?TX?(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C(W,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C,T,0IM<V=I9"`B1G)E92]"=7-Y(%)E<75E<W0@4F5S<&]N<V4B"FUS
M9W-T<B`BP?#<[?3G\^<@\^4@X=_TY^SA(,3IX>CE\^GL_/3G].'R(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW.0IM<V=I
M9"`B1G)O;2(*;7-G<W1R("+!\/PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,3DW"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`BP?#\(/3O
M("(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS9VED
M(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(L'MX>OU].GJWB#0Y?'IX_'A
M]MXB"@IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;CHB"FUS9W-T<B`BP>WAZ_7T
MZ>K>(-#E\>GC\>'VWCHB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#(@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$X,0IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@
M(M#KWO'G\B#3Y>O>[><B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C,Y"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`BT.O>\>7R(+SM
M[^SA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@
M9G)O;2(*;7-G<W1R(")'86QL97)Y(.'P_"#TY^T@[_#OW^$@Z.$@\.'?\>WO
M[?3AZ2#OZ2#EZ>K\[>7R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*
M;7-G<W1R(")'86QL97)Y.B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DY"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(LSIZO'\
M(+SM[^SA(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W-2!T
M96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,`HC.B!T96UP;&%T97,O<')E9G,O
M87!P+FEN8SHQ.0IM<V=I9"`B1VQO8F%L($]P=&EO;G,B"FUS9W-T<B`BP^7M
MZ>K=\B#%\.GK[^/=\B(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$V
M"FUS9VED(")';R(*;7-G<W1R("+,Y?3<XN'SYR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS
M9VED(")'<F5E8V4B"FUS9W-T<B`BQ>OKW.3A(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#$*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R
M("+%Z^OG[>GJW"`H25-/+3@X-3DM-RDB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C$W,`IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`BQ.GA
M]^7?\>GSYR#/[-SD^>TB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP
M.C4W"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G
M<W1R("+4X2#O[?SLX?3A(/3Y[2#O[-SD^>T@Y.7M(/#QW?#EZ2#MX2#EW^WA
MZ2#JY>W<(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,C`Q(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,C@U"FUS9VED(")'<F]U<"!P97)M:7-S
M:6]N<R(*;7-G<W1R("+%[N_U\^GOY._TWO/EZ?(@S^S<Y/GM(@H*(SH@861M
M:6XO<&5R;7,O961I="YP:'`Z,3<V(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,C4X"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3@S"FUS9VED(")'<F]U<',B"FUS9W-T<B`B
MS^S<Y.7R(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3(W(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,C$S"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z.30*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@
M(LGDZ?STY_3E\B!'=65S="(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$R
M."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Q-`IM<V=I9"`B1W5E
M<W0@<&5R;6ES<VEO;G,B"FUS9W-T<B`BR>3I_/3G].7R($=U97-T(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S.0IM<V=I9"`B1W5E<W1B;V]K
M(@IM<V=S='(@(D=U97-T8F]O:R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:'1T<"YP:'`Z,38T"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`BU.\@\_WS].?LX2#A]>CE[?3IZN_P[]_G\^?R($A4
M5%`@Y.4@XO'=Z.?JY2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`B
MOOCO\B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ-SD@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X-@HC.B!S97)V:6-E
M<R]H96QP+VEN9&5X+G!H<#HQ-R!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z
M,PIM<V=I9"`B2&5L<"(*;7-G<W1R("+"[][HY>GA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U
M<VEN9R!E9&ET;W(B"FUS9W-T<B`BPN_>Z.7IX2#CZ>$@].<@]_'>\^<@]._U
M(.KEZ>SE[>_C\=SV[_4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S8W"FUS9VED(")(96QP97(B"FUS9W-T<B`BPN_GZ/SR(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@(L?L
MZ?/VX=_QZ>\B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-R!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B2&5R92!I<R!T
M:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R("+%Y/X@Y=_MX>D@
MYR#A\??>(/3O]2#A\??EW^_U.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS-C$*;7-G:60@(DAI9V@B"FUS9W-T<B`BV.?KW"(*"B,Z(&9R
M86UE=V]R:R](:7-T;W)Y+TAI<W1O<GDN<&AP.C,R,@IM<V=I9"`B2&ES=&]R
M>2!E;G1R>2!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R("+'(.7C
MX_'A]MX@Z?/T[_'IZN_](.3E[2#P\=WPY>D@[>$@Y=_MX>D@ZN7MWB(*"B,Z
M('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO
M8V]M;6]N+6AE861E<BYI;F,Z-`IM<V=I9"`B2&]?;64B"FUS9W-T<B`BP?'W
MZ>K>(-/EZ]_DX2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,30V
M,`IM<V=I9"`B2&]M92(*;7-G<W1R("+!\??IZMX@T^7KW^3A(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34X"FUS9VED(")(
M;VUE($%D9')E<W,B"FUS9W-T<B`BQ.GE_>CU[?/G(-/PZ?3I[_TB"@IM<V=I
M9"`B2&]M92!0:&]N92(*;7-G<W1R("+4Y^O=]OGM[R#3\.GTZ>_](@H*;7-G
M:60@(DAO<F1E(@IM<V=S='(@(L'Q]^GJWB#3Y>O?Y.$B"@IM<V=I9"`B2&]R
M9&4@3&]G:6XB"FUS9W-T<B`BQ=_S[^3O\B#S].?M(-7PY_'E\]_A(,?+Y>KT
M\>_MZ>KO_2#4X??UY/'O[.7?[_4B"@IM<V=I9"`B2&]R9&4@4WES=&5M(@IM
M<V=S='(@(M/]\_3G[.$@)TAO<F1E)R(*"FUS9VED(")(;W)D92!7:7)E;&5S
M<R(*;7-G<W1R("(G2&]R9&4G(,'S_?'LX?3G(@H*;7-G:60@(DAO<F1E(&ES
M(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D(@IM<V=S='(@(M3O(/#Q_./QX>SL
MX2`G2&]R9&4G(.3E[2#=]^7I(/'UZ.SI\_3EWR#S^?/TW"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO
M<FEZ;VYT86P@4G5L92(*;7-G<W1R("+/\>GF_.WTZ>_R(,KA[?SMX?(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@R"FUS
M9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`BS_'IYOSM].GO("?C
MW>SI\^SA)R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(L_QZ>;\[?3I
M[SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3`*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE
M87-E(')E<&]R="$I(@IM<V=S='(@(M#Y\B#VZ-SSX?3E(.7D_CL@*/#A\>'J
MX>O^(.WA(/3O(.'MX?;=\>7TY2#S].\@Y.GA]^7I\>GS]-XA*2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*
M;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R
M9V4_(@IM<V=S='(@(M#\\^7R(//TWNOE\B#HW>OE].4@[>$@Y>WO\._IWO/E
M].4[(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C@*;7-G:60@
M(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R
M("+0_//A(/#EY-_A("CS]-[KY?(I(.7?[>'I(.7JY=\[(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I
M9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS
M9W-T<B`BT/SSY?(@X_'A[.S=\B#HW>OE].4@[>$@Y>WO\._IWO/E].4[(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C@*;7-G:60@(DAU;6ED:71Y(@IM
M<V=S='(@(M7C\>'SW^$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C`S"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(M7C\>'SW^$Z(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES=',B
M"FUS9W-T<B`BU^GO]>SO\=_S].'R(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)U<RYP:'`Z,3<V(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H
M<#HR,C,*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S
M(@IM<V=S='(@(L<@Q.?LZ>_U\>/?X2#C\>'L[.'T[^CU\=_DX?(@24U!4"#A
M\-WT]??E.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP
M.C(R,"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C@X"FUS9VED
M("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("+'
M(.3IX>/QX?;>(./QX>SLX?3OZ/7QW^3A\B!)34%0(.'PW?3U]^4Z("5S(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3@S(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S`*;7-G:60@(DE-05`@;6%I;&)O
M>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(L<@Q.?LZ>_U
M\>/?X2#PY>GQ[_'I\^S^[2`H<75O=&$I(./QX>SLX?3OZ/7QW^3A\B!)34%0
M(.'PW?3U]^4Z("5S(@H*;7-G:60@(DE.0D]8(@IM<V=S='(@(L7I\^7Q]_SL
MY>WA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q,0IM<V=I9"`B
M25`@061D<F5S<R(*;7-G<W1R("))4"W$Z>7]Z/7M\^<B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@R"FUS9VED("))4"!!9&1R97-S
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DE0+<3IY?WH]>WSYR#DY>T@Y=_M
MX>D@Y.GAZ-WSZ>SG+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I
M8RYP:'`Z.30*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D
M($-)1%(@8FQO8VLN(@IM<V=S='(@(DE0+<3IY?WH]>WSYR#LYR#E\.GT\>7P
M]-X@[-WSX2#SY2!#2412+4)L;V-K+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B25`@;&]C:V1O
M=VX@=FEO;&%T:6]N+B(*;7-G<W1R("+*Z^7?Y/GLX2W0X?'AXM_A\^<@25`N
M(@H*;7-G:60@(DE?;F)O>"(*;7-G<W1R("+%Z?/E\??\[.7MX2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(L7I\^'C^>/>
M(,/QX>SLWO(@T/'I[2(*"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@(LS\
M[>\@Q>GJ[^W?Y.GA(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"FUS
M9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`BQ>GJ[^W?Y.GA(./IX2`E<R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C$*;7-G:60@(DEC;VYS('=I
M=&@@=&5X="(*;7-G<W1R("+%Z>KO[=_DZ>$@ZN'I(,KEW^SE[>\B"@IM<V=I
M9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R("+/[>_LX2#TX?7T_/3G].'R
M.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C8P.`IM
M<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O
M(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("+![2#DY>T@Y>SV
MX>W?YN7TX>D@\_GS]-PL("5S(./IX2#MX2#A[>_?[N7I(//E(.W=[R#PX?'<
MZ/7Q[RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,Y"FUS9VED("(B
M"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%
M>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O
M('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*(L'M(.3E
M(.+KW?#E].4@ZN'MW>WA(.7IZN_MW^3I[R#W\>?SZ>SO\._I_NWTX?(@]._M
M($EN=&5R;F5T($5X<&QO<F5R+"#?\_GR("(*(O#QW?#EZ2#MX2#T\^7JW/'E
M].4@Y>3^(./IX2#MX2#A\.7MY?'C[_#OZ=[SY?3E(/3G(.3IX?;<[>7IX2!0
M3D<N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$U.`IM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO
M(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E
M("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*(L'M
M(.+KW?#E].4@X?7T_"#T[R#LWNWU[.$@]_GQW_(@Y>GJ_.WA+"#G(.7IZOSM
MX2#P[_4@Z-WKY?3E(.WA(.KA].7BW//E].4@Y.4@(@HB[/#O\>7?(.WA(.7L
M]N'MZ?/HY=\@X?#\(/3O[2!B<F]W<V5R(//A\BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G
M:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(M#Q[^7PZ?/J_/#I\^<@Q>GJ
M_.WA\CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T<B`B55),(,7I
MZOSMX?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*
M;7-G<W1R("+%Z>K\[>$@X?#\($=A;&QE<GDB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@
M(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`BQ>GJ_.WA(.'P_"!'86QL
M97)Y.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-#@*;7-G:60@
M(DEM86=E('5P;&]A9"(*;7-G<W1R("+!\._S]._KWB#%Z>K\[>'R(@H*(SH@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R
M("+%Z>K\[>7R(@H*;7-G:60@(DEM<&]R="(*;7-G<W1R("+%Z?/AX_GCWB(*
M"FUS9VED("));7!O<G0@17)R;W(Z("(*;7-G<W1R("++W.CO\B#JX?3<(/3G
M[2#%Z?/AX_GCWCH@(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z
M,3`@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,3`*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHU-R!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHQ,`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(L7I\^'C^>/>
M+"#"WNSA("5D(@H*(R!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR,"P@
M8RUF;W)M870*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C`*;7-G
M:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("+0Y>3?[R#P[_4@Y>GS
MWO?HYSH@)7,B"@IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R("+0
MY>3?X2#P[_4@Y>GSWO?HY_/A[3HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C<P,0IM<V=I9"`B26X@4')O8V5S<R(*
M;7-G<W1R("+3Y2#%\.7NY?'CX?/?X2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R
M="!2;W<@069T97(B"FUS9W-T<B`BQ>GSX>/YX]X@P_'A[.S>\B#,Y?3<(@H*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,30Q"FUS
M9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(L3\
MZ.?JY2#KW.CO\B#J^>3IZOSR(.7MW?'CY>GA\BXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8U-PIM<V=I9"`B26YC
M;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`BR]SH
M[_(@_.WO[.$@]_'>\_3G(-XOZN'I(.KYY.GJ_/(N(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R
M;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A
M8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@
M:&5L<"XB"FUS9W-T<B`B(@HBR]SH[_(@_.WO[.$@]_'>\_3G(-X@Y>WAZ^OA
MZO3IZMX@Y.GE_>CU[?/G+B#.X>WAY._JZ>S<\_3E(-X@Y?#IZN_I[?GMWO/T
MY2#LY2`B"B+T[R#DZ>'WY>GQZ?/TWB#CZ>$@\.7QX>GTW?'Y(.+OWNCEZ>$N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(L'][N?SYR#0Y?'I
MZ/GQW^_U(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,30Q('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,30P"FUS9VED("));F1I=FED=6%L(%5S97)S
M(@IM<V=S='(@(LGDZ>'?].7Q[^D@U_'>\_3E\B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(*;7-G:60@(DEN9F\B"FUS
M9W-T<B`BT.OG\>_V[_'?Y?(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C0Y"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("+0Z^?Q[_;O\=_E
M\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T
M<B`BQ>GSX>/YX]X@T_3>Z^?R(,SE]-PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN
M<V5R="!);6%G92(*;7-G<W1R("+%Z?/AX_GCWB#%Z>K\[>'R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B
M26YS97)T(%1A8FQE(@IM<V=S='(@(L7I\^'C^>/>(-#?[>'JX2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@
M(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("+%Z?/AX_GCWB#S_>WDY?/G\B!7
M96(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S,*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G
M<W1R("+%Z?/AX_GCWB#3]-[KY_(@T/'I[2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS
M97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T
M<B`BQ>GSX>/YX]X@[=WA\B#S]-[KY_(@[.7TW"#TY^T@]/'=]^_U\^$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C0*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C
M=7)R96YT(&]N92(*;7-G<W1R("+%Z?/AX_GCWB#MW>'R(//TWNOG\B#P\>GM
M(.'P_"#TY^T@]/'=]^_U\^$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE
M=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(L7I\^'C^>/>
M(.W=X?(@X_'A[.S>\B#LY?3<(/3G[2#T\=WW[_7SX2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I
M9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM
M<V=S='(@(L7I\^'C^>/>(.W=X?(@X_'A[.S>\B#LY?3<(/3G[2#T\=WW[_7S
MX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H
M92!C=7)R96YT(&YO9&4B"FUS9W-T<B`BQ>GAX_GCWB#PX?'AX_'<]N_U(.SE
M]-P@]._M(/3QW??O[?3A(.K\[.+O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED("));G-E<G0@
M82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B
MQ>GSX>/YX]X@\.'QX>/QW/;O]2#P\>GM(/3O[2#T\=WW[^WTX2#J_.SB[R(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT
M97)N871E('1E;7!L871E(@IM<V=S='(@(L7I\^'C^>/>(.7MX>OKX>KTZ>KO
M_2#P\>_T_?#O]2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C,*;7-G
M:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@
M<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("(B"B+$_O/TY2!E
M;6%I;"#DZ>7]Z/7M\^<@\_3G[2#O\._?X2#E\.GH]>SEW_3E(.WA(/#A\>'K
MW.+E].4@].\@[=WO(//A\B#J^>3IZOPZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T
M(&-E;&P@869T97(B"FUS9W-T<B`BQ>GSX>/YX]X@ZN7KZ>_](.SE]-PB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`BQ>GSX>/Y
MX]X@ZN7KZ>_](/#QZ>TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F
M=&5R(@IM<V=S='(@(L7I\^'C^>/>(//TWNOG\B#LY?3<(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I
M9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`BQ>GSX>/YX]X@\_3>
MZ^?R(/#QZ>TB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HY,PIM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(L7I\^'C
M^>/>(.SG[?WLX?3O\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P
M:"!A9G1E<B(*;7-G<W1R("+%Z?/AX_GCWB#PX?'AX_'<]N_U(.SE]-PB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#,*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@
M(L7I\^'C^>/>(/#A\>'C\=SV[_4@\/'I[2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R
M="!R;W<@869T97(B"FUS9W-T<B`BQ>GSX>/YX]X@X_'A[.S>\B#LY?3<(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`BQ>GSX>/Y
MX]X@X_'A[.S>\B#P\>GM(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q
M-`IM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E
M8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R("+%Z?/AX_GCWB#TY_(@X?#AZ?3O
M_>SE[>?R(.'PW.WTY_/G\B#S].?M(.7Q_O3G\^<@X?/VX>OEW^'R.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G
M:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`BQ>GSX>/YX]XOQ.G\
M\>CY\^<@Q>GJ_.WA\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G
M<W1R("+%Z?/AX_GCWB_$Z?SQZ/GSYR#3_>WDY?/G\B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C8X"FUS9VED("))
M;G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO
M;B!L:7-T+B(*;7-G<W1R("+,YR#E\.'QZMWR(/7P_.OOZ?#O(./IX2#A\._S
M]._KWB#S].<@Z]_S].$@Y.GA[>_LWO(N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-C`*;7-G:60@(DEN<W5F9FEC
M:65N="!C<F5D:70N(@IM<V=S='(@(LSG(.7PX?'JW?(@]?#\Z^_I\.\N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V.0IM<V=I9"`B26YT96=E
M<B(*;7-G<W1R("+!ZMWQX>GO\B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q,C<*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("++W_/TX2#!
MZN7QX=_Y[2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z,C@S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z,S4R"FUS9VED("));G9A;&ED($%C=&EO;B!S96QE8W1E
M9"!F;W(@=&AI<R!C;VUP;VYE;G0N(@IM<V=S='(@(L7PZ>O=[N'TY2#+W.CO
M\B#%[=WQX^7IX2#CZ2<@X?7T_"#T[R#S]?/TX?3IZOPN(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED
M("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R("+!
MZO7Q[R!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*
M;7-G<W1R("+,YR#=X^KU\><@Y?;A\>SOX]XN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S(Q"FUS9VED("));G9A
M;&ED(&)A=&-H($E$+B(*;7-G<W1R("+!ZO7Q[R!"871C:"U)1"XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<P(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q-#$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(Q-2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C@P"FUS9VED("));G9A;&ED(&1A
M=&$@<W5B;6ET=&5D+B(*;7-G<W1R("+3]-SKZ.?JX>T@Z]SH[_(@Y.7D[^S=
M[>$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`Y"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N
M(@IM<V=S='(@(L'J]?'G(.3IY?WH]>WSYR#P\>_O\>GS[._]+B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@T"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P,PHC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C,*;7-G:60@(DEN=F%L
M:60@9FEL92!F;W)M870B"FUS9W-T<B`BS.<@W>/J]?'G(.SO\?;>(.'Q]^7?
M[_4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,38*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(LSG
M(-WCZO7Q[R!M<V=?='EP92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@;W(@;6ES
M<VEN9R!A<&E?:60N(@IM<V=S='(@(LSG(-WCZO7Q[R#>(.OEW_#EZ2!A<&E?
M:60N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`U"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R
M<RXB"FUS9W-T<B`BS.<@W>/J]?'E\B#>(.7KZ^GPY=_R(/#A\=SLY?3Q[^DN
M(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C0S"FUS9VED("));G9A
M;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R("));G9A;&ED('!A<F5N
M="!P97)M:7-S:6]N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB
M"FUS9W-T<B`BS.<@W>/J]?'O(/#Q^?3\ZN_KZ^\N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,0IM<V=I9"`B26YV
M86QI9"!R96-I<&EE;G0Z("<E<R<B"FUS9W-T<B`BS.<@W>/J]?'O\B#PX?'A
MZ][P].?R.B`G)7,G(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,#<Q(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T.`IM<V=I9"`B26YV
M86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`BS.<@W>/J]?'O(.KOZ>W\]_'G
M\_3O(.'M].GJY=_LY>WO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED("));G9A;&ED('-O=7)C92!A
M9&1R97-S+B(*;7-G<W1R("+,YR#=X^KU\><@X?'WZ>K>(.3IY?WH]>WSYRXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,C`*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R("+,
MYR#=X^KU\>$@Y.7D[^S=[>$@56YI8V]D92XB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S(X"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`BRN'T
MW.OOX^_R(-7PX?'W_.WT^>TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R("+0Z^'C
MZ>$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,S<T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,3$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R("+)X>WO]=SQZ>_R(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,`HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU
M;'DB"FUS9W-T<B`BR>_]Z^GO\B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HS-SD*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0Q-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(LGO_>WI
M[_(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(L7UZ/7C\=SL[.GS
MYR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R("+%]>CU
MX_'<[.SI\^<@\_3O(,K=[?3Q[R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U
M;&PB"FUS9W-T<B`BT.O>\>?R(,7UZ/7C\=SL[.GSYR(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED
M(")*=7-T:69Y($QE9G0B"FUS9W-T<B`BQ?7H]>/QW.SLZ?/G(,'QZ?/TY?'<
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`BQ?7H]>/Q
MW.SLZ?/G(,3E[NG<(@H*;7-G:60@(DMA;&%M871A($%I<G!O<G0B"FUS9W-T
M<B`BP>7Q[^OI[-WMX?(@RN'KX>S<].'R(@H*;7-G:60@(DMA<G!A=&AO<R!!
M:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(,KA\?#<Z._U(@H*;7-G:60@
M(DMA<W1O<FEA($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-WMX?(@RN'S]._Q
MZ=SR(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(T-@IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`BS>$@ZO'A]-[S
M^2#T[R#A]>CE[?3IZOP[(@H*;7-G:60@(DME9F%L:&YI82!!:7)P;W)T(@IM
M<V=S='(@(L'E\>_KZ>S=[>'R(,KE]N'K[^WIW/(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VMR8C4N<&AP.C@W"FUS9VED(")+97)B97)O<R!S97)V97(@
M<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DME<F)E<F]S+5-E
M<G9E<B#A\>W>Z.?JY2#TY^T@X?7HY>WTZ>KO\._?Y_/G+B(*"FUS9VED(")+
M97)K>7)A($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-WMX?(@RMWQZO7QX?(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.
M97=B:65S(@IM<V=S='(@(LW=X2#A\/P@2V5R;F5L(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,SDW"FUS9VED(")+97D@0W)E871I;VXB
M"FUS9W-T<B`BQ.?LZ>_U\>/?X2#*Z^7IY.GO_2(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0P,`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT
M(@IM<V=S='(@(L'P[_3]\/GLX2#*Z^7IY.GO_2(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C,Y.`IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G
M<W1R("+,WNKO\B#*Z^7IY.GO_2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C,Y-PIM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`BU/WP[_(@
MRNOEZ>3I[_TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8R,@IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(M?QWO/G(,KKY>GDZ>_]
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S0S"FUS9VED
M(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N
M(@IM<V=S='(@(M3O(.KKY>GDWR#U\-SQ]^7I(-[DYR#S]._M(.7N]?#G\>7T
MY_3>(.3G[/SSZ?GM(.KKY>GDZ?[M+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R("+0X>GDZ=PB"@IM<V=I9"`B
M2V]S($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-WMX?(@RODB"@IM<V=I9"`B
M2V]Z86YI($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-WMX?(@RN_FW.WG\B(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U
M="(*;7-G<W1R("+$Z=STX>[G(@H*;7-G:60@(DQA<FES82!!:7)P;W)T(@IM
M<V=S='(@(L'E\>_KZ>S=[>'R(,O<\>GSX?(B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,3<T"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`BU.7KY?7TX=_O
M(,SI\_PB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@@;&EB+T)L;V-K+VUO
M;VXN<&AP.CDP"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`BU.7KY?7T
MX=_O(-3=].'Q].\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$T.0IM<V=I
M9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R("+4Y>OE]?3AW^$@Q>WG[-WQ^?/G
M.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C8Y,0IM<V=I9"`B3&%S
M="!L;V=I;CH@)7,B"FUS9W-T<B`BU.7KY?7TX=_A(,7?\^_D[_(@\_3G[2#U
M\.?QY?/?X3H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HV.3,*
M;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`BU.7KY?7T
MX=_A(,7?\^_D[_(@\_3G[2#U\.?QY?/?X3H@)7,@X?#\("5S(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z-C@X"FUS9VED("),87-T(&QO9VEN.B!.
M979E<B(*;7-G<W1R("+4Y>OE]?3AW^$@Q=_S[^3O\B#S].?M(/7PY_'E\]_A
M.B#0[_3=(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),
M87<B"FUS9W-T<B`BS?SL[_(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*;7-G<W1R
M("+$Z=STX>[G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*
M;7-G<W1R("+!]M[S].4@ZN7M_"#CZ>$@[>$@[.?M(/7PW/'W[_7M(/#E\>GH
M_O'IX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R("+!\>GS].7QW"(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#,*;7-G:60@(DQE9G0@:&5A
M9&5R(@IM<V=S='(@(L'QZ?/TY?'>(,7PZ>KE]N'KW^3A(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y.0IM<V=I9"`B3&5F="!V86QU97,B"FUS
M9W-T<B`BP?'I\_3E\=WR(-3I[-WR(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("+0Y>WTW//TZ??O(@H*
M;7-G:60@(DQI;6YO<R!!:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(,O>
M[.WO]2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,#$*;7-G:60@
M(DQI;FLB"FUS9W-T<B`BT_WMY.7SYR(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B3&EN:R!P
M;VEN=',@=&\Z(@IM<V=S='(@(M/][>3E\^<@\._U(.3EW_?MY>D@\^4Z(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U.`IM<V=I9"`B3&EN:R!T
M:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES
M<&QA>6EN9R(*;7-G<W1R("+3_>WDY?/G(/3G\B#DZ>7]Z/7M\^<@X^GA(-SM
M[^GC[.$@\.'QX>C]\>_U(//][>CE\^?R.R(*"B,Z(&9R86UE=V]R:R]497AT
M7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H<#HQ-C(*;7-G:60@(DQI;FMS
M(@IM<V=S='(@(M/U[>3=\^7I\B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(DQI;G5X+4-O;VMI
M92(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y
M"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T
M<B`B3&ES="`M(,\@]_'>\_3G\B#L\._QY=\@[>$@Y.7?(/3O(/;<ZN7K[R(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S@*;7-G:60@(DQI<W0@1&%T86)A
M<V5S(@IM<V=S='(@(LO?\_3A(,+<\^7Y[2#$Y>3O[-WM^>TB"@HC.B!S97)V
M:6-E<R]H96QP+VEN9&5X+G!H<#HU,`IM<V=I9"`B3&ES="!(96QP(%1O<&EC
M<R(*;7-G<W1R("++W_/TX2#HY>S<]/GM(,+OWNCEZ>'R(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$S-PIM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B
MR]_S].$@T.GMW.KY[2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES
M="YI;F,Z-`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS
M9W-T<B`BQR#DY^SI[_7QX]_A(.O?\_3A\B#W\>?S]/[M(-WWY>D@X?#E[>7Q
MX^_P[^GGZ.7?+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z.#8*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`BUOSQ]/GS
MYRXN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C`*;7-G
M:60@(DQO8V%L('1I;64Z("(*;7-G<W1R("+4[_#IZMX@O_'A.B`B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO8V%L92!A;F0@5&EM
M92(*;7-G<W1R("+4_/#O\B#JX>D@_O'A(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.34*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HU-S`@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C4P"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO
M8VLO;65T87(N<&AP.C8S"FUS9VED("),;V-A=&EO;B(*;7-G<W1R("+4_/#O
MZ.7SW^$B"@IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(L7?\^_D[_(B"@IM<V=I
M9"`B3&]G(&]U="(*;7-G<W1R("*X[N_D[_(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3`W"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R("+$Z>7Q
MX^'SW^7R(.7I\_SD[_4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M-3(*;7-G:60@(B(*(DQO9VEN(&9A:6QE9"!F;W(@<V]M92!R96%S;VXN($UO
M<W0@;&EK96QY('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S("(*(F5N
M=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*(L<@Y=_S[^3O\B#!\-WT
M]??E+B#0Z>CA[?STX?3A(.3\Z.?JY2#KW.CO\B#T[R"\[>_LX2#7\=[S].<@
MWB#O(,KYY.GJ_/(N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.30X
M"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@(L7?\^_D[_(@P?#=]/7W
MY2XB"@IM<V=I9"`B3&]G;W5T(@IM<V=S='(@(KCN[^3O\B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C$*;7-G:60@(DQO;F<@=&5X="(*;7-G
M<W1R("+,Y>/<Z^\@RN7?[.7M[R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R("+!X]SPYR(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS-3D*;7-G:60@(DQO=R(*;7-G<W1R("+7
MX>SGZ_PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM
M<V=S='(@(LSIZO'<(,7KZ^?MZ>K<(./QW.SLX?3A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I
M9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("+,Z>KQW"#KX?3I[>GJ
MW"#C\=SL[.'TX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E
M<G,B"FUS9W-T<B`BS.GJ\=P@T?GLX?KJWB#!\=_H[.?SYR(*"FUS9VED(")-
M32(*;7-G<W1R("+,S"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0IM
M<V=I9"`B36%G:6,B"FUS9W-T<B`BS.'CZ>K\(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C<Q"FUS9VED(")-86EL(@IM<V=S='(@(L'KZ^?K[^/Q
MX?;?X2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,30*;7-G:60@
M(DUA:6P@061M:6XB"FUS9W-T<B`BQ.GA]^7?\>GSYR!%;6%I;"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M,`IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R("+$Y^SI[_7QX]_A(-/]
M[>3E\^?R+BXN(@H*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E
M9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO
M<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S
M='(@(L3IX??EW_'I\^<@ZN'TY^/O\>G^[2#JX>D@]_'Y[-ST^>T@\._U(.CA
M(.7L]N'MW^;O[?3AZ2#A]?3=\BXB"@IM<V=I9"`B36%N=6%L(@IM<V=S='(@
M(L7C]^7I\=_DZ>\B"@IM<V=I9"`B36%P($1A=&4@86YD(%1I;64@1FEE;&1S
M(@IM<V=S='(@(M#EY-_A(,?LY?'O[.?MW^'R(.KAZ2"_\>'R(@H*;7-G:60@
M(DUA<"!);7!O<G0@1FEE;&1S(@IM<V=S='(@(M#EY-_A(.7I\^'C^>/>\B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-S8*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS
M9VED(")-87)C:"(*;7-G<W1R("+,W/'TZ>_R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R
M9VEN(@IM<V=S='(@(KSQZ>\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N
M(&9L86=S(@IM<V=S='(@(LSA\>K<\>GS[.$@[.4@W>WDY>GNYR#![>'C[?GS
M[-WM[_4OS.<@X>WAX^WY\^S=[>_U(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F
M;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(LSA\>K<
M\>GS[.$@[.4@W.OKYR#=[>3EZ>[G("CP+O<N(-/G[.'M].GJ_"_!\.'M].?L
MW>WO*2(*"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`BT.7DW^$@
M\._U(/3AZ?'IW.;O]>TB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,C0*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I
M="XB"FUS9W-T<B`BS-WCZ?/TYR#E\.GT\>7P]-X@\-_S]/GSYRXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3<*
M;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R("+5
M\-WQXN'SYR#O\=_O]2#LY^W][.'T[_(N(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS,#0*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G
M<W1R("+,W>/I\_3G(.CE\>SOZO'A\]_A(/3EZ^7U].'?^>T@,C0@^?'^[3H@
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.38*;7-G:60@(DUA>"!T96UP
M(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(LS=X^GS].<@Z.7Q[._J\>'SW^$@
M].7KY?7TX=_Y[2`V(/GQ_NTZ("(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C@Y,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C`X"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S`*;7-G:60@(DUA>&EM=6T@;&5N9W1H
M(@IM<V=S='(@(LS=X^GS].\@[-[J[_(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<X"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(LS<
MZ>_R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HU,S$*;7-G:60@(DUE971I;F<@0V%N8V5L;&%T:6]N(@IM<V=S='(@
M(L'J_?'Y\^<@T_7MW.WTY_/G\B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3`S"FUS9VED(")-965T:6YG($EN9F]R
M;6%T:6]N(@IM<V=S='(@(M#KY_'O]N_QW^7R(-/U[=SM].?SY_(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4P.0IM
M<V=I9"`B365E=&EN9R!0<F]P;W-A;"(*;7-G<W1R("+0\?STX?/G(./IX2#3
M]>W<[?3G\^<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C4R-0IM<V=I9"`B365E=&EN9R!297!L>2(*;7-G<W1R("+!
M\-SM].?SYR#CZ>$@T_7MW.WTY_/G(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,30*;7-G:60@(DUE971I;F<@57!D
M871E(@IM<V=S='(@(L7MY^S=\?GSYR#CZ>$@T_7MW.WTY_/G(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,3D*;7-G
M:60@(DUE971I;F<@57!D871E(%)E<75E<W0B"FUS9W-T<B`BP=_TY^SA(.7M
MY^S=\?GSY_(@X^GA(-/U[=SM].?SYR(*"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O961I="YI;F,Z,3D*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`BS-WK
MYR(*"FUS9VED(")-96UO<R(*;7-G<W1R("+3Y^SEZ?[SY>GR(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,V,@IM<V=I9"`B365N=2!M;V1E.B(*;7-G
M<W1R("+*X?3<\_3A\^<@S.7M[_TZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L
M;',B"FUS9W-T<B`BT_7C]_[MY?7SYR#JY>OI_NTB"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP
M.C,R"FUS9VED(")-97-S86=E(@IM<V=S='(@(LS>[?7LX2(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C(V"FUS9VED("(B"B)-97-S
M86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E
M<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B
M(@HBU.\@[-[M]>SA(.7PZ>+EXN'I_NCGZN4@Y?#I]/7W_O(L(.'KZ]P@].\@
M\.GS]._P[^GG].GJ_"#T[_4@]?#OX_'<]N_M].$@Y.4@(@HB[/#O\>7?(.WA
M(.7PZ>+EXN'I^>CEWRXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,3D*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB
M"FUS9W-T<B`BU.\@[-[M]>SA(-WKY^[E+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DQ"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C(V"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(S,PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C@*;7-G
M:60@(DUE<W-A9V4@='EP92(*;7-G<W1R("+4_?#O\B#LY^W][.'T[_(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B
M"FUS9W-T<B`BRN'I\?SR(.'P_"!-971A<B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ,3`*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I
M;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN
M:7-T<F%T;W(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HW,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T
M"FUS9VED(")-971H;V0B"FUS9W-T<B`BS-WH[^3O\B(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+WAM;')P8RYP:'`Z.#(@9G)A;65W;W)K+U)00R]24$,O<V]A
M<"YP:'`Z,3$W"FUS9VED(")-971H;V0@)R5S)R!I<R!N;W0@9&5F:6YE9"(*
M;7-G<W1R("+'(,S=Z._D[_(@)R5S)R#DY>T@[_'?\^CGZN4B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-3D@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HW,PIM<V=I9"`B365T<FEC(@IM<V=S='(@(LSE]/'IZOPB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*;7-G
M:60@(DUI9&1L92(*;7-G<W1R("+,Y?/AW^\B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T;F5F+G!H<#HT,0IM<V=I9"`B36EM92!4>7!E(@IM
M<V=S='(@(DUI;64@5'EP92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`X
M"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`BS.GJ
M\?STY?'G(.CE\>SOZO'A\]_A(/3EZ^7U].'?^>T@,C0@^?'^[3H@(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#`*;7-G:60@(DUI;B!T96UP(&QA<W0@
M-B!H;W5R<SH@(@IM<V=S='(@(LSIZO'\].7QYR#HY?'L[^KQX?/?X2#TY>OE
M]?3AW_GM(#8@^?'^[3H@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(Q-PIM<V=I9"`B36ER<F]R(@IM<V=S='(@(LKAZ/'=
M\/3G\B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES
M8V5L;&%N96]U<R(*;7-G<W1R("+$Z=SV[_'A(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV.3<*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0Y"FUS9VED(")-
M:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(DUI
M<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3`U"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R
M871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N
M="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@HBR^7?
M\.7I(/3O(&-O;F9I9W5R871I;VXN(-#QW?#EZ2#MX2#T[R#DY^SI[_7QX][S
MY?3E(.'M(.C=Z^7TY2#MX2#W\>?SZ2TB"B+L[_#OZ=[SY?3E(.'U]-X@].?M
M(.7VX?'L[^/>+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*
M;7-G<W1R("++Y=_PY>D@].\@240@]._U(.SG[?WLX?3O\BXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU-PIM
M<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS
M9W-T<B`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#,*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`BR^7?\.7I
M(/3O($E$(/3G\B#S_>WDY?/G\BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R("+$Y2(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,C(*;7-G:60@(DUO8FEL
M92!-86EL(@IM<V=S='(@(D5M86EL(,KI[>?TWO(@U.?KY?;Y[=_A\B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C`*;7-G:60@(DUO9&5R
M871E(@IM<V=S='(@(LS=]/'I[_(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8Y(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HX.`IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R("+'[.7Q[^SG
M[=_A(/3Q[_#O\._?Y_/G\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B36]D:69Y(%523"(*
M;7-G<W1R("+4\>_P[_#OW^?SYR!54DPB"@IM<V=I9"`B36]N=&@@5FEE=R(*
M;7-G<W1R("+%[/;<[>GSYR#,WNWA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C4X-@IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`BS-[M
MX?(@ZN'I(-WT[_(B"@IM<V=I9"`B36]N=&AL>2!%=F5N=',@3&ES="(*;7-G
M<W1R("+,Y^WIX=_A(,O?\_3A(,/EX^_M_/3Y[2(*"B,Z(&9R86UE=V]R:R]-
M86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z,S8*;7-G:60@(DUO;G1H;'DB
M"FUS9W-T<B`BS.?MZ>'?X2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI
M8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T
M<B`BUMSSY>GR(-/EZ][MY_(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HT,C`*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R("+*W^WG
M\^<@ZMST^2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C0R-`IM<V=I9"`B36]V92!,969T(@IM<V=S='(@(LK?[>?SYR#A\>GS].7Q
MW"(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0R.`IM
M<V=I9"`B36]V92!2:6=H="(*;7-G<W1R("+*W^WG\^<@Y.7NZ=PB"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT,38*;7-G:60@(DUO
M=F4@57`B"FUS9W-T<B`BRM_MY_/G(/#<[?DB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#DW"FUS9VED(")-;W9E(&1O=VXB
M"FUS9W-T<B`BRM_MY_/G(.K<]/DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#DV"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT.3<*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B
MRM_MY_/G(/#<[?DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,38W
M"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B
MT._KZ^'PZ]WR(.O?\_3E\B#E\.GK[^/>\B`HZN'TX?'QW.KTY?(I(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R-0IM<V=I9"`B375L=&EP;&4@
M<V5L96-T:6]N(@IM<V=S='(@(M#OZ^OA\.O>(.7PZ>OOX]XB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,T(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS-#$*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`BSR#+[^/A\>GA
M\^S\\B#L[_4B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C4Q"FUS
M9VED(")->2!0;W)T86PB"FUS9W-T<B`BSR#I\_3\]._P_/(@[._U("AP;W)T
M86PI(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C$R-`IM<V=I9"`B
M37D@4&]R=&%L($QA>6]U="(*;7-G<W1R("+'(.7L]MSMZ?/G(/3O]2#I\_3\
M]._P[_T@[._U("AP;W)T86PI(@H*;7-G:60@(DUY(%-U;6UA<GDB"FUS9W-T
M<B`BQR#0Y?'?Z^?XYR#L[_4Z(@H*;7-G:60@(DUY=&EL:6YI($%I<G!O<G0B
M"FUS9W-T<B`BP>7Q[^OI[-WMX?(@S/7TY^O>[>?R(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+V%G<F5E;65N=%]B;W1T;VTN:6YC.C<*;7-G:60@(DY/
M+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R("+/U\DL(,3%(//U[/;Y[?XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HS.3<@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P-0HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HT,0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4X,PIM<V=I9"`B3F%M92(*
M;7-G<W1R("*\[>_LX2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-S`V"FUS9VED(").965D<R!!8W1I;VXB"FUS9W-T
M<B`BP?#AZ?3EW_3AZ2#E[=WQX^7IX2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR-#(*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`BQ-_J]/7O(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,3D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W
M,`IM<V=I9"`B3F5V97(B"FUS9W-T<B`BT._TW2(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4Q"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(W"FUS9VED(").97<@
M0V%T96=O<GDB"FUS9W-T<B`BS=WA(,KA].?C[_'?X2(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K
M+VUO;VXN<&AP.C$W.0IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`BS=WA(-/E
MZ][MYR(*"FUS9VED(").97<@4&%S<W=O<F0B"FUS9W-T<B`BS=WO\B#*^>3I
MZOSR(@H*;7-G:60@(DYE=R!087-S=V]R9"`H86=A:6XI(@IM<V=S='(@(LW=
M[_(@ROGDZ>K\\B`H[N'MW"DB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*
M;7-G<W1R("+-W>\@_.WO[.$@U_'>\_3G("CP\>_AZ?'E].GJ_"DB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED
M(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(LW=[R#PX?'<Z/7Q[R`H
MZN7M_"DB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V
M-`IM<V=I9"`B3F5W<R(*;7-G<W1R("+-W>$B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3`V"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(L_L
MW.3E\B#CZ>$@[=WA("AN97=S9W)O=7!S*2(*"B,Z('1E;7!L871E<R]D871A
M+W1S=FEN9F\N:6YC.C(Q('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0V
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3,W('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C,R"FUS9VED(").97AT(@IM<V=S='(@(L7P_.SE
M[>\B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$Q-2!F<F%M97=O
M<FLO54DO54DO4&%G97(N<&AP.C$Q-@IM<V=I9"`B3F5X="!086=E(@IM<V=S
M='(@(L7P_.SE[><@T^7KW^3A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W
M"FUS9VED(").97AT(%!H87-E(@IM<V=S='(@(L7P_.SE[><@UMSSYR(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,S<P"FUS9VED(").97AT(&]P=&EO;G,B"FUS
M9W-T<B`BQ?#\[.7MY?(@Q?#IZ^_CW?(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#@X"FUS9VED(").;R(*;7-G<W1R("+/
M]^DB"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.C$V"FUS
M9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@
M9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R("+$Y>T@]?#<\??EZ2#DZ>'HW?/I
M[.\@8V]N9FEG=7)A=&EO;B#CZ>$@[>$@Y.7?[OD@Y.GA]N_QW?(N(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,3$*;7-G
M:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G
M97,N(@IM<V=S='(@(L3E[2#U\-SQ]^7I(.3IX>C=\^GLYR#S]/'A].?CZ>K>
M(./IX2#DY^SI[_7QX]_A($E33R!I;6%G97,N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S(R"FUS9VED(").;R!B
M871C:"!T96UP;&%T92XB"FUS9W-T<B`BQ.7M(/7PW/'WY>D@\/'\]/7P[R#C
MZ>$@0F%T8V@N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z-S@@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C(T"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(T-@IM<V=I9"`B
M3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS
M9W-T<B`BQ.7M(/7PW/'WY>D@0FQO8VL@\_3G[2#AZ?3O_>SE[><@Z-WSYR(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-30*;7-G:60@(DYO
M(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(L3E(.3\Z.?JY2#\[>_LX2#CZ>$@X?7HY>WTZ>KO\._?
MY_/G($U#04PN(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-34*;7-G:60@
M(DYO(&-H86YG92XB"FUS9W-T<B`BQ.7M(/7PW/'W[_7M(.'KZ^'CW?(N(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#0*;7-G:60@(DYO
M(&-H:6QD('!E<FUI<W-I;VYS(&%R92!T;R!B92!A9&1E9"!B96QO=R!T:&ES
M(&QE=F5L+B(*;7-G<W1R("+$Y2#L\._Q[_WM(.WA(/#Q[_/TY>CO_>T@Y>[O
M]?/I[^3O]-[SY>GR(.K<]/D@X?`G(.'U]/P@].\@Y?#?\.7D[RXB"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C$*;7-G:60@(DYO(&-H:6QD<F5N
M(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(L3E
M[2#L\._Q[_WM(.WA(/#Q[_/TY>CO_>T@]?#OZN'TY^/O\=_E\B#SY2#A]?3>
M(/3G[2#E[N_U\^GOY/STY_/G+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3<S(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#DS"B,Z(&9R
M86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<U,PIM<V=I9"`B3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R("+$
MY>T@[_'?\^CGZN'M(/#KY_'O]N_QW^7R(/'UZ.S?\^7Y[2#CZ>$@)7,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-S,*;7-G:60@(DYO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93
M+B(*;7-G<W1R("+$Y>T@[_'?\^CGZN'M(/#KY_'O]N_QW^7R(/'UZ.S?\^7Y
M[2#CZ>$@1E10(%9&4RXB"@IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R($Q$05`@4')E9F5R96YC97,N(@IM<V=S
M='(@(L3E[2#=]^_U[2#Q]>CLZ?/TY=\@[^D@\.OG\>_V[_'?Y?(@X^GA(/3G
M[2#U\.?QY?/?X2#*X?3AZ_SC[_4N(@H*;7-G:60@(DYO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@0V%T96=O<FEE<RXB
M"FUS9W-T<B`BQ.7M(-WW[_7M(/'UZ.SI\_3EWR#OZ2#PZ^?Q[_;O\=_E\B#C
MZ>$@].GR(.KA].?C[_'?Y?(@].?R(%-13"XB"@IM<V=I9"`B3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!0<F5F97)E
M;F-E<RXB"FUS9W-T<B`BQ.7M(-WW[_7M(/'UZ.SI\_3EWR#OZ2#PZ^?Q[_;O
M\=_E\B#CZ>$@].GR(/#Q[_3I[-[SY>GR(/3G\B!344PN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HU.34*;7-G:60@(DYO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R
M("+$Y>T@W??O]>T@\?7H[.GS].7?(._I(/#KY_'O]N_QW^7R(./IX2!344P@
M5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW-#D*
M;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(L3E[2#=]^_U[2#Q]>CLZ?/T
MY=\@[^D@\.OG\>_V[_'?Y?(@X^GA(%-13"U&:6QE(%9&4RXB"@IM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-1
M3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BQ.7M(-WW[_7M(/'UZ.SI\_3E
MWR#OZ2#PZ^?Q[_;O\=_E\B#CZ>$@].?M(.'UZ.7M].GJ[_#OW^?SYR#S].?M
M(%-13"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,C,*;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R("+$
MY>T@W>SEZ>WE(/#?\_3Y\^<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-3D*;7-G:60@(DYO(&1E<W1I;F%T:6]N
M('-U<'!L:65D+B(*;7-G<W1R("+$Y2#D_O/A].4@\/'O[_'I\^S\+B(*"B,Z
M(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y,@IM<V=I9"`B3F\@
M9FEL92!U<&QO861E9"(*;7-G<W1R("+$Y2#V[_'T_NCGZN'M(.'Q]^7?X2(*
M"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@
M9F]U;F0N(@IM<V=S='(@(L3E(.+QW>CGZN'M(.7IZN_MW^3IX2XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3`R(&QI8B]";&]C:R]S=6YR
M:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R,0IM<V=I9"`B
M3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R("+$Y>T@[_'?\^CGZN4@]._P
M[^CE\]_A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C4X"FUS9VED(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G
M<W1R("+$Y2#D_O/A].4@[-[M]>SA+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C8Q"FUS9VED(").;R!N86UE('-P
M96-I9FEE9"XB"FUS9W-T<B`BQ.7M(._QW_/HY^KE(/SM[^SA+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C8R"FUS
M9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R("+$Y>T@[_'?\^CG
MZN4@X?'IZ.S\\BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G
M:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("+$Y>T@]?#<\??O
M]>T@Y/7SW/'E\_3E\B#P\>_BZ]WXY>GR(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O87!P<F]V92YI;F,Z,3D*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P
M<RXB"FUS9W-T<B`BQ.7M(.7JZO'E[._][2#EW_/OY._I+B(*"FUS9VED(").
M;R!P<F5F97)E;F-E<R!A<F4@879A:6QA8FQE+B(*;7-G<W1R("+/Z2#P\>_T
MZ>S>\^7I\B#DY>T@Y=_MX>D@Y.GAZ-WSZ>SE\BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S"FUS9VED(").
M;R!R=6QE<R(*;7-G<W1R("+$Y>T@]?#<\??O]>T@ZN'M_.WE\B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*
M;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(L3E[2#U\-SQ]^_U[2#PZ^7U\=WR
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q,@IM<V=I9"`B
M3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*
M;7-G<W1R("+$Y>T@]?#<\??EZ2#P\>_S^?'I[?SR(/?^\>_R(./IX2#L[=[L
MYR!C86-H92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8U-@IM<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W
M;W)D('-E;G0N(@IM<V=S='(@(L3E[2#D_.CGZN4@_.WO[.$@]_'>\_3G(-XO
MZN'I(.KYY.GJ_/(N(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H
M<#HQ-#$*;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S
M='(@(L3E[2#E\.GS]/'<]N?JX>T@W>/C]?'A(%A-3"#DY>3O[-WMX2(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX.38*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDP-@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3$W"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY,S0*;7-G:60@
M(DYO('9A;'5E<R(*;7-G<W1R("+$Y>T@]?#<\??O]>T@].GLW?(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$P"FUS9VED(").;R!V97)S:6]N(&9O
M=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`BQ.4@XO'=Z.?JY2#=ZN3O\^<@\_3O(.'Q
M]^GJ_"!C;VYF:6=U<F%T:6]N+B#.X>WAY.?LZ>_U\>/>\_3E(/3O+B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,3@*;7-G:60@(DYO('9E<G-I;VX@
M9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(L3E(.+QW>CGZN4@W>KD[_/G(//T[R#A\??I
MZOP@\^'R(&-O;F9I9W5R871I;VXN(,[A[>'DY^SI[_7QX][S].4@].\N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV
M,#0*;7-G:60@(DYO;B!087)T:6-I<&%N="(*;7-G<W1R("+*X>W=[>'R(-/U
M[.SE]-WW^>TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,3,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HU-C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N
M:6YC.C@X"FUS9VED(").;VYE(@IM<V=S='(@(LKA[.S?X2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO
M;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`BRN'MW>WA("C7\=[SYR#P\>_J
MX>CO\>GS[-WM[_4I(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]"
M;&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*
M;7-G<W1R("+"_/'EZ>\@Q^SI\_;AW_'I[R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C8T"FUS9VED(").;W0@069T97(B"FUS9W-T
M<B`BO/?I(,SE]-PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8V,PIM<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R("*\]^D@T/'I[2(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,U-PIM<V=I9"`B3F]T
M(&$@9&ER96-T;W)Y(@IM<V=S='(@(L3E[2#EW^WAZ2#JX?3<Z^_C[_(B"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8W"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.C@T"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDU"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP
M:'`Z-#D*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+G!H<#HV,`IM<V=I9"`B3F]T(&EM<&QE;65N=&5D
M+B(*;7-G<W1R("+$Y>T@W??EZ2#OZ^_JZ^?Q^>CEWRXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X"FUS9VED(").;W0@
M<V5T(@IM<V=S='(@(L3E[2#=]^GE(/3EZ.7?(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C$X-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`S"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HR,C$@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(S.`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C4U(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR-S$*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X.2!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,S(U"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HS.#@@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0W,@HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z-30T(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-C(*
M;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(L3E[2#U\._S].?QW^;E
M].4N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(T-R!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34Y"FUS9VED(").;W1E
M<R(*;7-G<W1R("+3Y^SEZ?[SY>GR(@H*;7-G:60@(DYO=&5S.B(*;7-G<W1R
M("+3Y^SEZ?[SY>GR.B(*"FUS9VED(").;W1E<R!3=6UM87)Y(@IM<V=S='(@
M(M/G[.7I_O/EZ?(@+2#0Y?'?Z^?XYR(*"FUS9VED("(B"B).;W1E<R!I<R!A
M;B!A<'!L:6-A=&EO;B!W:&EC:"!A;&QO=W,@>6]U('1O(&-R96%T92!T:&4@
M8V]M<'5T97(@97%U:79A;&5N="`B"B)O9B!S=&EC:WD@;F]T97,N($YO=&5S
M(&-A;B!B92!C<F5A=&5D+"!M;V1I9FEE9"P@9&5L971E9"P@86YD('!R:6YT
M960N(%EO=2`B"B)C86X@86QS;R!S96%R8V@@;VX@>6]U<B!N;W1E<R!T;R!L
M;V-A=&4@:6YF;W)M871I;VXN(%-U<'!O<G0@9F]R(&EM<&]R=&EN9R`B"B)A
M;F0@97AP;W)T:6YG(&YO=&5S(&ES(&%L<V\@879A:6QA8FQE+B(*;7-G<W1R
M("(B"B+/Z2#SY^SEZ?[SY>GR(.7?[>'I(.SIX2#E]N'Q[._CWB#P[_4@\^'R
M(.7PZ?3QW?#EZ2#MX2#DY^SI[_7QX][SY?3E(/3O("(*(N'M]-_S]._I]^\@
M]/GM(.K?]/'I[?GM(.SIZO'^[2#WX?'TZ?[M(//T[^T@]?#OZ^_CZ?/TWBX@
MS/#O\>7?].4@[>$@(@HBY.?LZ>_U\>/>\^7TY2P@[>$@]/'O\._P[^G>\^7T
MY2P@[>$@Y.GAX_'<^.7TY2#JX>D@[>$@]/7P_O/E].4N(,SP[_'EW_3E("(*
M(N7PW_/G\B#MX2#XW.[E].4@\_3I\B#SY^SEW_GSY>GR(//A\B#CZ>$@[>$@
MY>WT[_#?\^7TY2#LZ>$@\.OG\>_V[_'?X2X@(@HBU?#O\_3G\=_FY?3AZ2#J
MX>D@Y>GSX>/YX]X@+2#E[N'C^>/>(/3Y[2#SY^SEZ?[SY?GM+B(*"B,Z('-E
M<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T
M;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(M3?\._TX2#CZ>$@Y>SVW.WI
M\^<L(.7PZ?/T\>_VWBXB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N
M9FER;5]T;W`N:6YC.C$P"FUS9VED(").;W1I8V4B"FUS9W-T<B`BP>WAZN_I
M[?[SY>GR(@H*(RP@8RUF;W)M870*;7-G:60@(DYO=&EF:6-A=&EO;B!L:7-T
M96YE<B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(M3O(/#Q_./QX>SLX2#P[_4@
MY.GA]^7I\=_FY?3AZ2#TZ?(@Y>GD[_#OZ=[SY>GR("5S(.3E[2#B\=WHY^KE
M+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS
M.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R
M,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U
M"FUS9VED(").;W9E;6)E<B(*;7-G<W1R("+-[]WLXO'I[_(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0P"FUS9VED(").=6UB97(B"FUS9W-T
M<B`BP?'IZ.S\\B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C$*
M;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(L'QZ>CL_/(@
M]^'QX>KTWO'Y[2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C4@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q.0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#0Q('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R
M("+!\>GH[/SR(//TY^O^[2(*"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R!I
M;B!T:&4@<W5M;6%R>2!V:65W.B(*;7-G<W1R("+!\>GH[/SR(//TY^O^[2#S
M].?M(.7L]MSMZ?/G(/3G\B#PY?'?Z^?XY_(Z(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,V,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#$W
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,SD@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O
M9B!R;W=S(@IM<V=S='(@(L'QZ>CL_/(@X_'A[.S^[2(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C8Y"FUS9VED(").
M=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U
M=&EO;B!L:7-T+B(*;7-G<W1R("+$Y>T@[_'?\^CGZN4@X?'IZ.S\\B#CZ>$@
MY>WG[-WQ^?/G(/3Y[2#KZ?/T_NT@Y.GA[>_LWO(N(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Q-`IM<V=I9"`B3V)J96-T
M(@IM<V=S='(@(L'M].GJY=_LY>WO(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,3<*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(L3G
M[.GO]?'C_/(@P>WTZ>KEZ>S=[>_U(@H*(SH@861M:6XO<&5R;7,O961I="YP
M:'`Z,3,W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C(S"FUS9VED
M(")/8FIE8W0@8W)E871O<B!P97)M:7-S:6]N<R(*;7-G<W1R("+%[N_U\^GO
MY._TWO/EZ?(@Q.?LZ>_U\>/O_2#![?3IZN7I[-WM[_4B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#DX"FUS9VED(")/8W1A;"(*;7-G<W1R("+/
MZO3AY.GJ_/(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S@S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R("+/ZO3^XO'I[_(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL
M=&5R(@IM<V=S='(@(M;?Z_3Q[R#P\>_SXN_K_NTB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S`T"FUS9VED(")/9F9I8V4B"FUS9W-T<B`BP_'A
M]N7?[R(*"FUS9VED(")/;&0@4&%S<W=O<F0B"FUS9W-T<B`BT.'KZ?SR(,KY
MY.GJ_/(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HW-@IM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@
M9F]L9&5R<RXB"FUS9W-T<B`BS/SM[R!)34%0+5-E<G9E<G,@]?#O\_3G\=_F
M[_7M(.KO]>W\]_'G\_3O]?(@]N'JW>OK[_7R+B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B
M"FUS9W-T<B`BS/SM[R#D]?/<\>7S].7R(/#Q[^+KW?CEZ?(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#,T(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y-30*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E
M9"XB"FUS9W-T<B`BS/SM[R#LZ>$@16UA:6P@Y.GE_>CU[?/G(.7PZ?3QW?#E
M].'I+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B
M(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y
M(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R
M(&$@<VAA<F4B"FUS9W-T<B`B(@HBS/SM[R#O(.GDZ>_J]-[TY_(@WB#O(.3I
MX??EZ?'I\_3>\B#S]?/TWNSA]._R(.SP[_'EWR#MX2#AZ^O<[N7I(/3G[2`B
M"B+IY.GOZO3G\]_A(-X@].GR(.7N[_7SZ>_D[_3>\^7I\B#T[_4@Z>3I[^KT
MWO3G(./IX2#J[^GMWB#W\=[SYRXB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H
M<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`BP>WO
MZ>/LX2#SY2#MW>\@\.'QW.CU\>\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C(U-PIM<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@
M;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS
M9W-T<B`B(@HB3W!E;E-33"W+W.CO\CH@Q.7M(.SP[_'^(.WA(.+CW.OY(.3E
MY._LW>WA(.'P_"!3+TU)344@]?#OX^7C\>'L[-WM[R#LW?'O\BXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-30*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS
M9W-T<B`BP>WOZ>/LX2#A]?3>\B#TY_(@\_WMY.7SY_(@\^4@[=WO(/#A\=SH
M]?'O(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R
M871I;F<@4WES=&5M(@IM<V=S='(@(LOEZ?3O]?'CZ>K\(-/]\_3G[.$B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8P
M,`IM<V=I9"`B3W!T:6]N86P@4&%R=&EC:7!A;G0B"FUS9W-T<B`BT/'OY?'A
MZ?3IZOSR(-/U[.SE]-WW^>TB"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A
M<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(L7PZ>OOX]WR(@H*
M;7-G:60@(D]P=&EO;G,@9F]R(@IM<V=S='(@(L7PZ>OOX]WR(./IX2(*"B,Z
M('-E<G9I8V5S+W!R969S+G!H<#HR.2!T96UP;&%T97,O<')E9G,O87!P+FEN
M8SHT"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R("+%\.GK[^/=\B#C
MZ>$@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`BU.'NZ>WO[.?L
MW>WG(,O?\_3A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.3$*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R("+/\>/A[>GS[/SR
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3(*;7-G
M:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`BU.S>[.$@S_'CX>WI
M\^SO_2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,C<*;7-G:60@
M(D]R9V%N:7II;F<B"FUS9W-T<B`BS_'CW.WY\^<B"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M
M<&QA=&4B"FUS9W-T<B`BP?7HY>WTZ>K\(/#Q_/3U\.\@Y?;A\>SOX][R(@H*
M(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*;7-G:60@(D]R:6=I;F%L('1E
M;7!L871E<R!I;B`E<SHB"FUS9W-T<B`BP?7HY>WTZ>K<(/#Q_/3U\.$@\V4@
M)7,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$R,"!S97)V
M:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(L'K
MZ^\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C$*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$R.0IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`BP>OK
MY?(@T.OG\>_V[_'?Y?(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C,W"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R("+%[N_U\^GO
MY._TWO/EZ?(@R>3I[^KTWO3G(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P
M86TN<&AP.C@S"FUS9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`BQR#!]>CE[?3IZN_P[]_G\^<@4$%-(.3E[2#E
MW^WAZ2#DZ>'HW?/I[.<N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3(W.0IM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S
M='(@(MCG]NGAZMX@U?#OX_'A]MX@4$=0(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3,R.`IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A
M(@IM<V=S='(@(LKQ]?#T[^/QX?;G[-WMX2#DY>3O[-WMX2!01U`B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S@W"FUS9VED(")01U`@
M4'5B;&EC($ME>2(*;7-G<W1R("+$Y^S\\^GO(,KKY>GDWR!01U`B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S8V"FUS9VED(")01U`@
M4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(M7P[^/EX_'A[.S=[>$O
MRO'U\/3OX_'A]N?LW>WA(%!'4"#DY>3O[-WMX2(*"B,Z(&%D;6EN+W!H<'-H
M96QL+G!H<#HV,PIM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B4$A0(,K^Y.GJ
MX?(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L
M;"(*;7-G<W1R(")02%`@RMWK]?;O\B(*"B,Z(&QI8B]A<&DN<&AP.C$R-@IM
M<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R(")02%`@RMWK]?;O\B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*
M;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`BP]WLZ?/LX2(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S0*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3<*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`S(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#$*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHW,"!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C,V"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-C<*;7-G:60@(E!A
M<W-W;W)D(@IM<V=S='(@(LKYY.GJ_/(B"@IM<V=I9"`B4&%S<W=O<F0@8VAA
M;F=E9"!F;W(@=7-E<B`E<R!F<F]M(&-L:65N="`E<R(*;7-G<W1R("+/(.KY
MY.GJ_/(@W.OKX>[E(./IX2#T[^T@]_'>\_3G("5S(.'P_"#T[R#S].'H[/P@
M)7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S-30*
M;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R("++W.CO\B#J^>3I
MZOSR(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$U-PIM
M<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`BP?#AZ?3EW_3AZ2#J^>3IZOSR(./IX2#A]>CE[?3I
MZN_P[]_G\^<@4D%$2553+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(P,S8*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S
M='(@(LKYY.GJ_/(@[.4@Y?#IXN7BX=_Y\^<B"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R("+*
M^>3IZOSR.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS
M9VED(")087-S=V]R9#H@(@IM<V=S='(@(LKYY.GJ_/(Z("(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$W"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A
M<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R("+/(.KYY.GJ_/(@\/'=\.7I
M(.WA(/3AZ?'IW.;EZ2XB"@IM<V=I9"`B4&%S="!%=F5N=',@3&ES="(*;7-G
M<W1R("++W_/TX2#0Y?'A\^S=[?GM(./EX^_M_/3Y[2(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,C@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R("+%\.GJ
M_.OKY_/G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`B
MQ?#IZOSKZ^?SYR#A\/P@].\@8VQI<&)O87)D(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G
M<W1R("+$Z>'D\>_LWB(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C0@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN
M8SHT"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(L7?\^_D[^D@
M\._U(.7JZO'E[._][3HB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*
M;7-G:60@(E!E;W!L92(*;7-G<W1R("+![>CQ^?#OZ2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C
M96YT(@IM<V=S='(@(M#O\^_S]/PB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O8V]N9FER;5]B;W1T;VTN:6YC.C8*;7-G:60@(E!E<F9O<FT@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R("+%ZO3=Z^7SYR#+Y>GT[_7QX^G^
M[2#3]>WTWO'G\^?R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,`IM
M<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN
M/R(*;7-G<W1R("+%ZO3=Z^7SYR#+Y>GT[_7QX^G^[2#3]>WTWO'G\^?R(.KA
M]-P@].?M(.7?\^_D[SLB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M-C$@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8T"B,Z(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HV-PIM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R("+%
M[N_U\^GOY/STY_/G(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HV.`IM
M<V=I9"`B4&5R;6ES<VEO;B`G)7,G(&YO="!D96QE=&5D+B(*;7-G<W1R("+%
M[N_U\^GOY/STY_/G(./IX2`G)7,G(.3E(.3IX>/QW/;GZN4N(@H*(SH@861M
M:6XO<&5R;7,O961I="YP:'`Z,C(T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HY,PHC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HW-`IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`BQ.GA]^7?\>GSYR#%[N_U\^GOY._TWO/E^>TB"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T.2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$U,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO;G,@9F]R(@IM<V=S='(@(L7N
M[_7SZ>_D[_3>\^7I\B#CZ>$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C4*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(M#Q[_/Y
M\.GJW?(@\.OG\>_V[_'?Y?(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-34*;7-G:60@(E!E=',B"FUS9W-T<B`BRN'T[^GJW^3IX2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3D*;7-G:60@(E!H
M;VYE(@IM<V=S='(@(M3GZ]WV^>WO(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0T-PIM<V=I9"`B4&AO=&]S(@IM<V=S='(@(M;Y]._C\>'VW^7R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R("+%Z>KO[>_S]._I]^7?X2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*
M;7-G<W1R("+*[^GM[_3U\-_E\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC
M:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R("+0X?'AZN'K_B#JW.WTY2#JZ^GJ
M(//E(.K<\._I[R#JY>O?(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0X"FUS9VED(")0;&5A<V4@8V]N9FER
M;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S
M='(@(M#A\>'JX>O^(.7PZ>+EXN'I_O/TY2#\].D@Z-WKY?3E(.WA(.3IX>/Q
MW/CE].4@X?7T_"#T[R#S]._I]^7?[SHB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(E!L96%S
M92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N
M="XB"FUS9W-T<B`BT.'QX>KAZ_X@Y?#IXN7BX>G^\_3E(/STZ2#HW>OE].4@
M[>$@X?#O\_7MY-WSY?3E(.'U]/P@].\@\_3OZ??EW^\N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C4U-0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`BT.'QX>KAZ_X@Y/[S].4@[-[M
MX2#JX>D@W?3O\BXB"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@
M=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`BT.'QX>KAZ_X@Y/[S].4@W>WA
M(/SM[^SA(./IX2#TYR#MW>$@ZN'TY^/O\=_A.B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R.3@*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED
M($E0(&%D9')E<W,N(@IM<V=S='(@(M#A\>'JX>O^(.3^\_3E(.SIX2#=X^KU
M\><@25`@Y.GE_>CU[?/G+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(V-3$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K
M('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(B(*
M(M#A\>'JX>O^(.3^\_3E(.SIX2#=X^KU\><@Y^SE\>_LY^W?X2P@Y>O=[O3E
M(/3O[2#A\>GH[/P@]/GM(.?LY?'^[2#T[_4@[-[MX2XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-#,S"FUS9VED(")0;&5A<V4@96YT97(@82!V
M86QI9"!T:6UE+B(*;7-G<W1R("+0X?'AZN'K_B#D_O/TY2#=X^KU\><@_O'A
M+B(*"FUS9VED(")0;&5A<V4@<')O=FED92!A(&YE=R!P87-S=V]R9"(*;7-G
M<W1R("+0X?'AZN'K_B#D_O/TY2#T[R#MW>\@ZOGDZ>K\(//A\B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P
M<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`BT.'Q
MX>KAZ_X@Y/[S].4@[.GA(/#E\=_KY_CG(/3O]2#P\>_BZ][LX?3O\BXB"@IM
M<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!P87-S=V]R9"(*;7-G<W1R("+0
MX?'AZN'K_B#D_O/TY2#T[^T@ZOGDZ>K\(//A\B(*"FUS9VED(")0;&5A<V4@
M<')O=FED92!Y;W5R('5S97)N86UE(@IM<V=S='(@(M#A\>'JX>O^(.3^\_3E
M(/3O(+SM[^SA(-?QWO/TYR(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,3@@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,@IM<V=I9"`B4&QE
M87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T
M<B`BT.'QX>KAZ_X@Y/[S].4@].\@_.WO[.$@ZN'I(/3O[2#J^>3IZOP@\^'R
M(@H*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@=VET:"!`
M9&]M86EN(@IM<V=S='(@(M/U[/#KY_'^\_3E(/3O(/SM[^SA(/?QWO/TYR#L
MY2#T[^T@]._LW>$@*$!E<FUI<RYY9'0I(@H*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+V%G<F5E;65N=%]T;W`N:6YC.C$R"FUS9VED("(B"B)0;&5A<V4@
M<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N("!9;W4@35535"!A9W)E92!W:71H
M('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@HB
MT.'QX>KAZ_X@Y.GAXMSS].4@].\@X>K\Z^_UZ.\@ZN7?[.7O[2X@T/'=\.7I
M(.WA(//U[/;Y[>7?].4@[.4@]._U\B#\\>_U\B`B"B+CZ>$@[>$@]_'G\^GL
M[_#OZ=[SY?3E(.'U]/P@].\@\_WS].?LX2XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4T,`IM<V=I9"`B(@HB4&QE
M87-E(')E=FEE=R!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N+"!A;F0@=&AE
M;B!S96QE8W0@86X@86-T:6]N(&9R;VT@=&AE("(*(FUE;G4@8F5L;W<N(@IM
M<V=S='(@(B(*(M#A\>'JX>O^(.3EW_3E(/3I\B#AZOSK[_7HY?(@\.OG\>_V
M[_'?Y?(@ZN'I(.7PZ>O=[O3E(.SIX2#E[=WQX^7IX2#A\/P@].\@(@HB\.'Q
MX>K<]/D@[.7M[_TN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HT,S4*;7-G:60@(E!L96%S92!S96QE8W0@86X@86-T
M:6]N(&9R;VT@=&AE(&UE;G4@8F5L;W<N(@IM<V=S='(@(M#A\>'JX>O^(.7P
MZ>O=[O3E(.SIX2#E[=WQX^7IX2#A\/P@].\@\.'QX>K<]/D@[.7M[_TN(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-S(*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93HB
M"FUS9W-T<B`BT.'QX>KAZ_X@Y/[S].4@].\@_.WO[.$@].?R(.W=X?(@ZN'T
MY^/O\=_A\CHB"@IM<V=I9"`B4&QE87-E('9E<FEF>2!Y;W5R(&YE=R!P87-S
M=V]R9"(*;7-G<W1R("+0X?'AZN'K_B#E\.GBY>+AZ?[S].4@].\@[=WO(.KY
MY.GJ_"#SX?(B"@IM<V=I9"`B4')E8V5D92!Y;W5R('-I9VYA='5R92!W:71H
M(&1A<VAE<R`H)RTM("<I/R(*;7-G<W1R("+-X2#P\>_TW//S[^WTX>D@Y/WO
M(/#A_>OE\B#P\=_M(/3G[2#U\._C\>'VWB#SX?(@*"<M+2<I.R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R
M("+(W?/G(.'U]-[R(/3G\B#EZ>K\[>'R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG
M(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`BU._P[^CE]/[M].'R(.'U]/P@]._M
M(/#?[>'JX2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDT"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C
M960@8GD@24U!4"DB"FUS9W-T<B`BP?#O\_3OZ]X@\^4@X?7T_"#T[R#VW.KE
MZ^\@*.3E[2#U\._S].?QW^;E].'I(.'P_"#T[R!)34%0*2(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C8T(&QI8B]";&]C:R]M971A<BYP:'`Z,C8Y"FUS
M9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G
M<W1R("+*X?3AZO'>[.WI\^<@X^GA(/3I\B#TY>OE]?3AW^7R("5S(/[QX2CE
M\BDZ("(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HY.0IM
M<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L9&%P.B#$Y2#B\=WHY^KE(.<@X?#A
MZ?3O_>SE[><@Y?#=ZO3A\^<@3$1!4"XB"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O<V5S<VEO;BYP:'`Z,S8*;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E
M<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M4')E9G-?<V5S<VEO;CH@Q.4@XO'=Z.?JY2#G(.'PX>GT[_WLY>WG(.7PW>KT
MX?/G(//U[>7D\=_A\BXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,CDX"FUS9VED(")0<F5S96YT871I;VYS(@IM<V=S='(@(M#A\>_U\^G<\^7I
M\B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(S"FUS9VED(")0<F5S<W5R
M92(*;7-G<W1R("+0W^7SYR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4W
M"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R("+0W^7S
MYR#S].\@Y?#?\.7D[R#TY_(@Z-SKX?/SX?(Z("(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ.#0*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T
M<B`BT-_E\^<Z("(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ.#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@
M(M#Q[^7PZ?/J_/#I\^<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE
M(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("+0\>_E\.GSZOSPZ?/G
M(/3G\B#EZ>K\[>_A\B#SY2#MW>\@\.'QW.CU\>\B"@HC.B!F<F%M97=O<FLO
M54DO54DO4&%G97(N<&AP.C<Q(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z
M-S(*;7-G:60@(E!R979I;W5S(%!A9V4B"FUS9W-T<B`BT/'OY^/O_>SE[><@
MT^7KW^3A(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-38@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C`*;7-G:60@(E!R979I
M;W5S(&]P=&EO;G,B"FUS9W-T<B`BT/'OY^/O_>SE[>7R(,7PZ>OOX]WR(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM
M<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`BQ>KT_?#Y\^<@Y>/C\=SV
M[_4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,#D*;7-G
M:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(M#Q[_/Y\.GJ_"#*Z^7IY-\B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED(")0
M<F]B;&5M(@IM<V=S='(@(M#Q_.+KY^SA(@H*(SH@<V5R=FEC97,O<')O8FQE
M;2YP:'`Z,3$R"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@
M(M#E\>GC\>'VWB#0\>_BZ][LX?3O\B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR,38*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(KCQX^\@*'!R
M;VIE8W0I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Y-"!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3<Q"FUS9VED(")0<F]M<'0@=&5X="(*
M;7-G<W1R("+*Y=_LY>WO(/#Q[_3Q[_#>\B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0P.0IM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R
M("+$Y^S\\^GO(,KKY>GDWR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C8Y"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G
M<W1R("+!Z^/\\>GH[._R(,3G[/SSZ>_U(,KKY>GDZ>_](@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C(S"FUS9VED(")0=6)L:6,O4')I
M=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G
M<W1R("+4[R#FY?WC[_(@Q.?L_//I[_4OT/'O\_GPZ>KO_2#JZ^7IY.GO_2#D
MY2#DY^SI[_7QX][HY^KE(.7PZ?3U]_[R+B(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HW,`IM<V=I9"`B475E<GDB"FUS9W-T<B`BQ?'^].?SYR(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@W"FUS9VED(")24T$@
M4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R("+$Y^S\\^GO(,KKY>GDWR!2
M4T$@*"5D($)I="DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0W
M"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`BQ?#IZ^_CWR#E[?SR
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&
M;W)T=6YE(@IM<V=S='(@(M3U]^'?X2#0\?SBZ^7XYR(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-S$@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B
MR_SC[_(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(Y-2!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C0P"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-S0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY-PHC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R,"!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$T,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X
M-@IM<V=I9"`B4F5A9"(*;7-G<W1R("+![=SC[?GSYR(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED(")296%D(&UE
M<W-A9V5S(@IM<V=S='(@(L'MW./M^?/G(.SG[?WLX?3O\B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(E)E86QL>2!D
M96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM
M<V=S='(@(L7?\_3E(.+=XN'I[_(@X^GA(/3G(.3IX>/QX?;>("5S.R#!]?3\
M(.3E[2#L\._QY=\@[>$@Y?#A[=WKZ.7I+B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V-L96%R+FEN8SHQ,@IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R
M(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U
M;F1O;F4N(@IM<V=S='(@(B(*(L7?\_3E(//?X^_U\>_R(./IX2#TYR#DZ>'C
M\>'VWB#T^>T@Y.7D[^S=[?GM(/3O]2#W\=[S].<@)7,[(,'U]/P@Y.7M(.SP
M[_'EWR`B"B+MX2#E\.'MW>OHY>DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S
M="!A8W1I;VXB"FUS9W-T<B`BQ?#A[>7J]-WKY?/G(/3G\B#TY>OE]?3AW^'R
M(.7QX^'SW^'R(//A\B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S4*
M;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R
M("+![>'MW?GSYR#T^>T@Y/7MX>SIZO[M(//T[^GWY=_Y[2#T[_4@S.7M[_TZ
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R-0IM<V=I9"`B4F5F<F5S
M:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`BP>WA[=WY\^<@].?R(.7L]MSMZ?/G
M\B#T[_4@4&]R=&%L.B(*"FUS9VED(")2969R97-H(%-U;6UA<GD@5FEE=SHB
M"FUS9W-T<B`BP>WA[=WY\^<@].?R(-#Q[^+OZ][R(-#E\=_KY_CG\CHB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.#@@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(P-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C(V
M"FUS9VED(")296=E>"(*;7-G<W1R(")296=E>"(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,R,S,*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R
M(@IM<V=S='(@(L7L]MSMZ?/G(-/WW?/E^>TB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,R-`IM<V=I9"`B4F5M87)K<R(*;7-G<W1R("+3]_SKZ>$B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0U
M-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C0W-@IM<V=I9"`B4F5M96UB97(@=&AE(&9R964O8G5S>2!I;F9O<FUA=&EO
M;BXB"FUS9W-T<B`BP?#O[.WG[/SMY?7SYR#PZ^?Q[_;O\>G^[2#DZ>'HY?/I
M[/STY_3A\BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$T"FUS9VED
M(")296UO=&4@4V5R=F5R<R(*;7-G<W1R("+!\._LX>KQ]?/LW>WOZ2#%[O7P
MY_'E].?TW?(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*
M;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R
M9&4I.B(*;7-G<W1R("+!\._LX>KQ]?/LW>WG(.3IY?WH]>WSYR`H:'1T<#HO
M+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHR,2!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHT,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U
M960N:6YC.C$U"FUS9VED(")296UO=F4B"FUS9W-T<B`BP?;AW_'E\^<B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*;7-G:60@(E)E;6]V
M92!";&]C:R(*;7-G<W1R("+!]N'?\>7SYR#,\.O\ZB(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,S(*;7-G:60@(E)E;6]V
M92!C;VQU;6XB"FUS9W-T<B`BP?;AW_'E\^<@T_3>Z^?R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`IM<V=I9"`B4F5M
M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`BP?;AW_'E\^<@[._Q]N_P[]_G\^?R
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HV-3@*;7-G:60@(E)E;6]V92!F<F]M(&UY(&-A;&5N9&%R(@IM<V=S='(@
M(L'VX=_QY?/G(.'P_"#T[R#G[.7Q[^O\X^G\(.SO]2(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z,3,V"FUS9VED(")296UO=F4@<&%I<B(*;7-G
M<W1R("+!]N'?\>7SYR#FY?WC[_7R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$Y-@IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E
M<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*(L'VX=_QY?/G
M(.'P[^CGZN7U[-WM[_4@<V-R:7!T(.'P_"#T[^T@\/'O\_GQZ>W\(.KA]-SK
M[^/O(/3O]2#E[O7PY_'E].?TWBXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(E)E;6]V92!T
M:&4B"FUS9W-T<B`BP?;AW_'E\^<@]._U(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")296UO
M=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(L'VX=_Q
MY?/G(.'U]._](/3O]2#J_.SB[_4@X?#\(/3O(-WCX_'A]N\B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$V"FUS9VED(")296UO=F4@
M=7-E<B(*;7-G<W1R("+$Z>'C\>'VWB#W\=[S].<B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F4N:6YC.C<*;7-G:60@(E)E;6]V92!U<V5R.B`E
M<R(*;7-G<W1R("+$Z>'C\>'VWB#7\=[S].<Z("5S(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ.3<*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HR.#`*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HS-#D*;7-G
M:60@(E)E<&QY(%-E;G0N(@IM<V=S='(@(M/TW.OHY^KE(,'PW.WTY_/G+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-#4Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-#8X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-#<X"FUS9VED(")297!L>2!W:71H($YO="!3=7!P;W)T960@365S
M<V%G92(*;7-G<W1R("+!\-SM].?SYR#LY2#,QR#U\._S].?QZ>;\[.7M[R#L
MWNWU[.$N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HT-C8*;7-G:60@(E)E<&QY('=I=&@@9G)E92]B=7-Y(&9O<B!N
M97AT(#(@;6]N=&AS+B(*;7-G<W1R("+!\-SM].?SYR#LY2#PZ^?Q[_;O\=_E
M\B#DZ>'HY?/I[/STY_3A\B#CZ>$@]._U\B#E\/SLY>WO]?(@Y/WO(.S>[>7R
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-#8U"FUS9VED(")297!L>2!W:71H(')E<75E<W1E9"!F<F5E+V)U<WD@
M:6YF;W)M871I;VXN(@IM<V=S='(@(L'PW.WTY_/G(.SE(/3I\B#FY_3O_>SE
M[>7R(/#KY_'O]N_QW^7R(.3IX>CE\^GL_/3G].'R+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3@Y"FUS9VED(")2
M97!L>3H@)7,B"FUS9W-T<B`BP?#<[?3G\^<Z("5S(@H*(SH@9G)A;65W;W)K
M+U)00R]24$,O>&UL<G!C+G!H<#HQ,SD*;7-G:60@(E)E<75E<W0@8V]U;&1N
M)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@
M(M3O(.'?].?LX2#DY2#L\._QY=\@[>$@X?#A[?3GZ.7?+B#%\.GS]/'E]OSL
MY>WO\B#J^>3IZOSR(.O<Z._U\CH@(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ.#`@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#,*;7-G
M:60@(E)E<75I<F5D("<E<R<@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("+4[R#A\.'I]._][.7M[R`G)7,G(.3E[2#JX>CO
M\=_SZ.?JY2#S].\@)7,@8V]N9FEG=7)A=&EO;BXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C8P,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C<W.0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S4U"FUS
M9VED(")297%U:7)E9"`G)7,G(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(M3O(.'PX>GT[_WLY>WO("<E<R<@Y.7M(.KA
MZ._QW_/HY^KE(//T[R!61E,@8V]N9FEG=7)A=&EO;BXB"@HC.B!F<F%M97=O
M<FLO571I;"]5=&EL+G!H<#HW-C$*;7-G:60@(E)E<75I<F5D("<E<R<@;F]T
M('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+4[R#A\.'I
M]._][.7M[R`G)7,G(.3E[2#JX>CO\=_SZ.?JY2#S].\@8V]N9FEG=7)A=&EO
M;BXB"@IM<V=I9"`B4F5Q=6ER960@)V)A<V5D;B<@;F]T('-P96-I9FEE9"!I
M;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B+4
M[R#A\.'I]._][.7M[R`G8F%S961N)R#DY>T@W??EZ2#JX>CO\>GS].7?(//T
MZ?(@\?7H[-_SY>GR(.'UZ.7M].GJ[_#OW^?SY_(N(@H*;7-G:60@(E)E<75I
M<F5D("=B87-E9&XG(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HBU.\@X?#AZ?3O_>SE[>\@)V)A<V5D
M;B<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#T^>T@\/'O
M].GLWO/E^>TN(@H*;7-G:60@(E)E<75I<F5D("=D871A8F%S92<@;F]T('-P
M96-I9FEE9"!I;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"B+4[R#A\.'I]._][.7M[R`G9&%T86)A<V4G(.3E[2#=]^7I(.KA
MZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@(@HBX?7HY>WTZ>KO\._?Y_/G\BXB
M"@IM<V=I9"`B4F5Q=6ER960@)V1A=&%B87-E)R!N;W0@<W!E8VEF:65D(&EN
M(&-A=&5G;W)I97,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HBU.\@X?#A
MZ?3O_>SE[>\@)V1A=&%B87-E)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@
M\?7H[-_SY>GR(.KA].?C[_'I_NTN(@H*;7-G:60@(E)E<75I<F5D("=D871A
M8F%S92<@;F]T('-P96-I9FEE9"!I;B!P<F5F97)E;F-E<R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(B"B+4[R#A\.'I]._][.7M[R`G9&%T86)A<V4G(.3E
M[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@]/GM(/#Q[_3I[-[S
MY?GM+B(*"FUS9VED(")297%U:7)E9"`G:&]S='-P96,G(&YO="!S<&5C:69I
M960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M(@HBU.\@X?#AZ?3O_>SE[>\@)VAO<W1S<&5C)R#DY>T@W??EZ2#JX>CO\>GS
M].7?(//TZ?(@\?7H[-_SY>GR("(*(N'UZ.7M].GJ[_#OW^?SY_(N(@H*;7-G
M:60@(E)E<75I<F5D("=H;W-T<W!E8R<@;F]T('-P96-I9FEE9"!I;B!C871E
M9V]R:65S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(M3O(.'PX>GT[_WL
MY>WO("=H;W-T<W!E8R<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?
M\^7I\B#JX?3GX^_QZ?[M+B(*"FUS9VED(")297%U:7)E9"`G:&]S='-P96,G
M(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B(@HBU.\@X?#AZ?3O_>SE[>\@)VAO<W1S<&5C)R#DY>T@W??E
MZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(/3Y[2#P\>_TZ>S>\^7Y[2XB
M"@IM<V=I9"`B4F5Q=6ER960@)W!A<W-W;W)D)R!N;W0@<W!E8VEF:65D(&EN
M(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(M3O
M(.'PX>GT[_WLY>WO("=P87-S=V]R9"<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S
M].GR(/'UZ.S?\^7I\B`B"B+A]>CE[?3IZN_P[]_G\^?R+B(*"FUS9VED(")2
M97%U:7)E9"`G<&%S<W=O<F0G(&YO="!S<&5C:69I960@:6X@8V%T96=O<FEE
M<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B+4[R#A\.'I]._][.7M[R`G
M<&%S<W=O<F0G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@
MZN'TY^/O\>G^[2XB"@IM<V=I9"`B4F5Q=6ER960@)W!A<W-W;W)D)R!N;W0@
M<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B(*(M3O(.'PX>GT[_WLY>WO("=P87-S=V]R9"<@Y.7M(-WWY>D@ZN'H
M[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#T^>T@\/'O].GLWO/E^>TN(@H*;7-G
M:60@(E)E<75I<F5D("=P:'!T>7!E)R!N;W0@<W!E8VEF:65D(&EN(&%U=&AE
M;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(M3O(.'PX>GT
M[_WLY>WO("=P:'!T>7!E)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H
M[-_SY>GR(.'UZ.7M].GJ[_#OW^?SY_(N(@H*;7-G:60@(E)E<75I<F5D("=P
M:'!T>7!E)R!N;W0@<W!E8VEF:65D(&EN(&-A=&5G;W)I97,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B(@HBU.\@X?#AZ?3O_>SE[>\@)W!H<'1Y<&4G(.3E
M[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@ZN'TY^/O\>G^[2XB
M"@IM<V=I9"`B4F5Q=6ER960@)W!H<'1Y<&4G(&YO="!S<&5C:69I960@:6X@
M<')E9F5R96YC97,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HBU.\@X?#A
MZ?3O_>SE[>\@)W!H<'1Y<&4G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q
M]>CLW_/EZ?(@]/GM(/#Q[_3I[-[SY?GM+B(*"FUS9VED(")297%U:7)E9"`G
M=&%B;&4G(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B(@HBU.\@X?#AZ?3O_>SE[>\@)W1A8FQE)R#D
MY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(.'UZ.7M].GJ[_#O
MW^?SY_(N(@H*;7-G:60@(E)E<75I<F5D("=T86)L92<@;F]T('-P96-I9FEE
M9"!I;B!C871E9V]R:65S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(M3O(.'P
MX>GT[_WLY>WO("=T86)L92<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'U
MZ.S?\^7I\B#JX?3GX^_QZ?[M+B(*"FUS9VED(")297%U:7)E9"`G=&%B;&4G
M(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B(@HBU.\@X?#AZ?3O_>SE[>\@)W1A8FQE)R#DY>T@W??EZ2#J
MX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(/3Y[2#P\>_TZ>S>\^7Y[2XB"@IM
M<V=I9"`B4F5Q=6ER960@)W5I9"<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT
M:6-A=&EO;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B+4[R#A\.'I]._]
M[.7M[R`G=6ED)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR
M(.'UZ.7M].GJ[_#OW^?SY_(N(@H*;7-G:60@(E)E<75I<F5D("=U:60G(&YO
M="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B(@HBU.\@X?#AZ?3O_>SE[>\@)W5I9"<@Y.7M(-WWY>D@ZN'H[_'I
M\_3EWR#S].GR(/'UZ.S?\^7I\B#T^>T@\/'O].GLWO/E^>TN(@H*;7-G:60@
M(E)E<75I<F5D("=U<V5R;F%M92<@;F]T('-P96-I9FEE9"!I;B!A=71H96YT
M:6-A=&EO;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B+4[R#A\.'I]._]
M[.7M[R`G=7-E<FYA;64G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CL
MW_/EZ?(@(@HBX?7HY>WTZ>KO\._?Y_/G\BXB"@IM<V=I9"`B4F5Q=6ER960@
M)W5S97)N86UE)R!N;W0@<W!E8VEF:65D(&EN(&-A=&5G;W)I97,@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B(@HBU.\@X?#AZ?3O_>SE[>\@)W5S97)N86UE
M)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(.KA].?C[_'I
M_NTN(@H*;7-G:60@(E)E<75I<F5D("=U<V5R;F%M92<@;F]T('-P96-I9FEE
M9"!I;B!P<F5F97)E;F-E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B+4
M[R#A\.'I]._][.7M[R`G=7-E<FYA;64G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@
M\_3I\B#Q]>CLW_/EZ?(@]/GM(/#Q[_3I[-[SY?GM+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R.`IM<V=I9"`B4F5Q=6ER960@
M1FEE;&0B"FUS9W-T<B`BP?#AZ?3O_>SE[>\@T.7DW^\B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4Y,@IM<V=I9"`B
M4F5Q=6ER960@4&%R=&EC:7!A;G0B"FUS9W-T<B`BP?#AZ?3O_>SE[>_R(-/U
M[.SE]-WW^>TB"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E
M<BYP:'`Z,S$U('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT-`IM<V=I9"`B4F5S
M970B"FUS9W-T<B`BQ?#A[>'V[_'<(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-#8*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(L'K
MZ^'CWB#*^>3IZN_](@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,C<*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`BP>OKW.[T
MY2#T[^T@ROGDZ>K\(//A\B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV-B!A
M9&UI;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP.C<S"FUS
M9VED(")297-U;'1S(@IM<V=S='(@(L'P[_3EZ]WS[.'TX2(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#(@=&5M<&QA=&5S+W!R969S+V5N
M9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`BQ?#I
M\_3Q[_;>(//TZ?(@Q?#IZ^_CW?(B"@IM<V=I9"`B4F5T=7)N('1O(&UA:6PB
M"FUS9W-T<B`BQ?#I\_3Q[_;>(//TY^T@X>OKY^OOX_'A]M_A(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,PIM<V=I9"`B4F5U;FEO;B(*;7-G<W1R("+%\.'MW>WY\^<B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@
M(L7PX>WA]N_QW"!#;VYF:6=U<F%T:6]N(@H*;7-G:60@(E)H;V1E<R!!:7)P
M;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(-'\Y._U(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$S,`IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I
M;VYS(@IM<V=S='(@(L7PZ>OOX]WR(.7PY>[E\>/A\_3>(.7L\.OO]?3I\^S=
M[>_U(.KEZ>S=[>_U(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS
M9VED(")2:61D;&5S(@IM<V=S='(@(L'I[=_C[.'TX2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B
M4FEG:'0B"FUS9W-T<B`BQ.7NZ=PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,3`U"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`BQ.7NZ=P@
MY?#IZN7VX>O?Y.$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`Q
M"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`BQ.7NZ=WR(/3I[-WR(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`BR>3I
M_/3G].7R(./QX>SLWO(N+BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-3@S"FUS9VED(")2;VQE(@IM<V=S='(@(M'\
MZ^_R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(P.`IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R("+0Y?'I\_3Q[_;>(#$X
M,+`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C`U"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R("+0Y?'I\_3Q[_;>(,'Q
MZ?/TY?'<(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(Q,0IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(M#E\>GS]/'O
M]MX@Q.7NZ=PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R
M("+)Y.G\].?TY?(@P_'A[.S>\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T
M:65S(@IM<V=S='(@(LGDZ?STY_3E\B##\>'L[-[R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z
M(@IM<V=S='(@(L/QX>SLW?(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T
M<B`BRN'M_.WE\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`BS^D@ZN'M_.WE
M\B#HX2#E[/;A[=_F[^WTX>D@[.7TX>[](/SK^>T@]/GM(./QX>SL_NT@ZN'I
M(/3Y[2#S].?K_NTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("+/Z2#JX>W\[>7R(.CA(.7L
M]N'MW^;O[?3AZ2#LY?3A[OT@]/GM(//TY^O^[2#L_.WO(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I
M9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T
M<B`BS^D@ZN'M_.WE\B#HX2#E[/;A[=_F[^WTX>D@[.7TX>[](/3Y[2#C\>'L
M[/[M(.S\[>\B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(Y"FUS9VED(")2
M=6XB"FUS9W-T<B`BQ>KTW>OE\^<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C,P,`IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@
M4VEG;F%T=7)E(@IM<V=S='(@(M7P[^/QX?;>(,KQ]?#T[^/QW/;G\^?R(%,O
M34E-12(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S0Q
M"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`BRO'U
M\/3OX_'A]N?LW>WO(.S>[?7LX2!3+TU)344B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W-A<VPN<&AP.C@V"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N
M(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(L<@X?7HY>WTZ>KO\._?Y_/G
M(%-!4TP@Y.7M(.7?[>'I(.3IX>C=\^GLYRXB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#@Q"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@
M(LSG[?WLX?3A(%--4R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I
M9"`B4U%,(%-H96QL(@IM<V=S='(@(E-13"#*W>OU]N_R(@H*(SH@9G)A;65W
M;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HS.`IM<V=I9"`B4U5#0T534R(*;7-G<W1R("+%T,G4U=?9TR(*"B,Z
M(&QI8B]A<&DN<&AP.C$S,`IM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R(")3
M7U%,(,K=Z_7V[_(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R("+3X2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A
M;64@9G)A;64@*%]S96QF*2(*;7-G<W1R("*ZY.GO(/#KX=_SZ>\@*%]S96QF
M*2(*"FUS9VED(")386UO<R!!:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R
M(-/<[._U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$R,`IM
M<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(M#<\>_W[_(@Q._Q
M]?;\\>_U(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDX"FUS
M9VED(")3879E(@IM<V=S='(@(L'P[^C>ZN7U\^<B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C(R,@IM<V=I9"`B4V%V92`E<R(*;7-G<W1R("+!
M\._HWNKE]?/G("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHT.0IM<V=I9"`B4V%V92`G)7,G(@IM<V=S='(@(L'P[^C>ZN7U\^<@
M)R5S)R(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A
M=F4@3W!T:6]N<R(*;7-G<W1R("+!\._HWNKE]?/G(,7PZ>OOX_[M(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,0IM<V=I9"`B(@HB4V%V92!G96YE
M<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S
M97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"B+!
M\._HWNKE]?/G(/3O]2!C;VYF:6=U<F%T:6]N(/#O]2#DY^SI[_7QX][HY^KE
M(//A[2!02%`@4V-R:7!T(//T[^T@\/'O\_GQZ>W\("(*(NKA]-SK[^/O(/3O
M]2#E[O7PY_'E].?TWBXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HV
M.0IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BP?#O
MZ.?JY?7LW>WO("5S(&-O;F9I9W5R871I;VXN(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z.3`*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R
M:7!T('1O.B`G)7,G+B(*;7-G<W1R("+4[R!S8W)I<'0@Y>WG[-WQ^?/G\B#T
M[R!S971U<"#A\._HY^KE_>CGZN4@\_3O.B`G)7,G+B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R("+%\.GS
M]-[LYR(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$U('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$W"FUS9VED(")396%R8V@B
M"FUS9W-T<B`BP>WAYM[TY_/G(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(X,0IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`BS.?WX>W=
M\B#![>'FWO3G\^?R(@H*;7-G:60@(E-E87)C:"!-86EL(@IM<V=S='(@(L'M
MX>;>].?SYR#,Y^WU[-ST^>TB"@IM<V=I9"`B4V5A<F-H(%)E<W5L=',B"FUS
M9W-T<B`BP?#O].7KW?/LX?3A(,'MX>;>].?SY_(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.34W"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T
M<B`BQ?#IZ^_CWB#!\??EW_GM(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0U-@IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G
M<W1R("+%\.GKW>[TY2#LZ>$@Y^SE\>_LY^W?X2(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,C`T"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A
M9&0B"FUS9W-T<B`BQ?#IZ]WN].4@[^S<Y.$@X^GA(/#Q[_/HWNKG(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT.0IM<V=I9"`B4V5L96-T(&$@
M;F5W(&]W;F5R(@IM<V=S='(@(L7PZ>O=[O3E(.W=[R#)Y.GOZO3>].<B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C
M="!A('-E<G9E<B(*;7-G<W1R("+%\.GKW>[TY2#E[O7PY_'E].?TWB(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,38R"FUS9VED(")396QE8W0@
M82!U<V5R('1O(&%D9"(*;7-G<W1R("+%\.GKW>[TY2#W\=[S].<@X^GA(/#Q
M[_/HWNKG(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U-`IM<V=I
M9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(L7PZ>OO
MX]X@_.OY[2#T^>T@Y^SE\>_LY^WI_NTN(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Q-`IM<V=I9"`B4V5L96-T(&%N(&]B
M:F5C="(*;7-G<W1R("+%\.GK[^/>(.7M_/(@X>WTZ>KEZ>S=[>_U(@H*(SH@
M<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B"B)396QE8W0@=&AE
M(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO
M=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E
M>'1A<F5A+B(*;7-G<W1R("(B"B+%\.GKW>[TY2#T[_7R(/?A\>'J]-[QY?(@
M\._U(.C=Z^7TY2#A\/P@].GR(/#A\>'JW/3Y(.O?\_3E\BX@RN'T_/#I[>SP
M[_'EW_3E("(*(NWA(/3A(.'M].GC\=SXY?3E(.KAZ2#MX2#TX2#E\.GJ[^OK
MWO/E].4@\_3O(.S>[?7LX2#SX?(N(@H*;7-G:60@(E-E;&5C="!T:&4@9&%T
M92!D96QI;6ET97(Z(@IM<V=S='(@(L7PZ>OOX]X@]._U(.3IX??Y\>GS]-X@
MY^SE\>_LY^W?X?(Z(@H*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z
M(@IM<V=S='(@(L7PZ>OOX]X@].?R(.SO\?;>\B#P[_4@Z.$@W??EZ2#G(.?L
MY?'O[.?MW^$Z(@H*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A
M;G0@=&\@8VAA;F=E.B(*;7-G<W1R("+%\.GKW>[TY2#TYR#TX?7T_/3G].$@
M\._U(.C=Z^7TY2#MX2#AZ^O<[N7TY3HB"@HC.B!T96UP;&%T97,O9&%T82]T
M:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB
M"FUS9W-T<B`BQ?#IZ]WN].4@].\@Y.GA]_GQZ?/TWB#^\>'R.B(*"B,Z('1E
M;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I
M;64@9F]R;6%T.B(*;7-G<W1R("+%\.GKW>[TY2#TYR#L[_'VWB#P[_4@Z.$@
MW??EZ2#G(/[QX3HB"@IM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L
M9',N(@IM<V=S='(@(L7PZ>O=[O3E(.3][R#PY>3?X2#P[_4@].'I\>G<YN_U
M[2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDP"FUS9VED(")396QE
M8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(L7PZ>O=[O3E(/3O(/?Q
M^>SA].GJ_"`G\_?>[.$G+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,S(*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS
M9W-T<B`BQ?#IZ]WN].4@].<@X^O^\_/A(//A\CHB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8U,PIM<V=I9"`B4V5N
M9"!,871E<W0@26YF;W)M871I;VXB"FUS9W-T<B`BP?#O\_3OZ]X@]/GM(/#I
M[R#P\?SS]N'T^>T@\.OG\>_V[_'I_NTB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*
M;7-G<W1R("+!\._S]._KWB#![>'V[_'<\B#0\>_BZ][LX?3O\B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C0*;7-G:60@
M(E-E;F0@4TU3(@IM<V=S='(@(L'P[_/T[^O>(%--4R(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S$T"FUS9VED(")396YS;W(Z("(*;7-G<W1R("+!Z?/H
MY_3>\>'R.B`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S@R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(M/E\/3=[.+QZ>_R
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,C4*;7-G
M:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`BT^7I\>GAZOSR(,'QZ>CL_/(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#$*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`BU.\@
M240@].?R(//][>3E\^?R(-WKY^[E+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R.34*;7-G:60@(E-E="(*;7-G<W1R("+(W?/E(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<V"FUS9VED(")3970@;W!T:6]N<R!T;R!A
M;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F
M;W)G970@:70N(@IM<V=S='(@(B(*(LC=\_3E(.7PZ>OOX]WR(/#O]2#HX2#S
MX?(@Y?#I]/'=\._U[2#MX2#AZ^O<YN7TY2#T[^T@ZOGDZ>K\(//A\BP@X>K\
M[.<@ZN'I("(*(N'M(/3O[2#=]^7TY2#NY??<\^7I+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R
M<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*
M;7-G<W1R("+0X?'A[.7T\>_P[]_G\^<@X?#O[.'J\?7S[-WM^>T@Y>[U\.?Q
MY?3G]/[M(/#O]2#HW>OE].4@\/'\\^+A\^<N(@H*;7-G:60@(E-E="!Y;W5R
M('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RXB
M"FUS9W-T<B`B(@HBT?7H[-_S].4@Y.G<]N_QY?(@Y?#IZ^_CW?(@Y>SVW.WI
M\^?R(.KAZ2#T[R#W\?SM[R#A[>'MW?GSY_(@]/GM(//EZ]_D^>TN(@H*;7-G
M:60@(E-E="!Y;W5R('!R969E<G)E9"!D:7-P;&%Y(&QA;F=U86=E+B(*;7-G
M<W1R("+%\.GK[^/>(/3G\B#P\>_TZ>SO_>SE[>?R(./K_O/SX?(N(@H*;7-G
M:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD
M(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`BRN'H[_'?\_3E(/3G[2#P\>_TZ>S^
M[.7MYR#CZ_[S\^$L(.;^[><@_O'A\B#JX>D@[._Q]MX@Y^SE\>_LY^W?X?(N
M(@H*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O
M;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES
M<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B"B+*X>CO\=_S].4@].?M(.7VX?'L
M[^/>(.7JZM_MY_/G\BP@].$@\/'O].GL_NSE[>$@]_'^[.'TX2P@].<@\.7Q
MW^_D[R`B"B+A[>'MW?GSY_(@].?R(//EZ]_DX?(@ZN'I(-SKZ^7R(.7PZ>OO
MX]WR(.7L]MSMZ?/G\BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<T
M"FUS9VED(")3971U<"(*;7-G<W1R("+1_>CLZ?/G(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S@*;7-G:60@(E-E='5P('5P9W)A
M9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`BQ=_MX>D@Y.GAZ-WSZ>SA
M(%-C<FEP=',@Y>WG[-WQ^?/G\B#Q]>CLW_/E^>TB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3,U"FUS9VED(")3979E<F%L(&QO8V%T:6]N
M<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R("+0[^OK
MW?(@]._P[^CE\]_E\B#EW^WAZ2#PZ>CA[=WR(.SE(.'U]-X@].<@\.'QW.SE
M]/'O.B`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<S"FUS9VED
M(")3:&]P<&EN9R(*;7-G<W1R("+!X^_QW?(B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G
M<W1R("+3_>WT[^SG(-#E\=_KY_CG(@H*;7-G:60@(E-H;W)T(%-U;6UA<GDZ
M(@IM<V=S='(@(M/][?3O[.<@T.7QW^OG^.<Z(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0S,`IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E
M9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(M#QW?#EZ2#T[R#JZ^7I
MY-\@\/'\\^+A\^?R(.WA(._QZ?/HY=\@X^GA(/#E\>GS\_STY?'E\B#S]>WD
MW?/EZ?([(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR.30@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS.0HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C<S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.38*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3D@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ-#(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M.#4*;7-G:60@(E-H;W<B"FUS9W-T<B`BQ>SVW.WI\^<B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,30Y"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S
M(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A
M=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(L7L]MSMZ?/G(.3I
MX?;O\?[M(.SE].'N_2#T[_4@X?#OZ.?JY?7LW>WO]2#JX>D@]._U(.3G[.GO
M]?'CY^C=[?3O\B`B"B)C;VYF:6=U<F%T:6]N+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT-S0*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H
M96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`BQ>SVW.WI\^<@].?R(/[QX?(@].7K
MY?7TX=_A\B#EZ?/\Y._U(/STX>T@[/#AW^WO]>SE(//T[R#S_?/TY^SA.R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-3(*;7-G:60@(E-H;W<@
M;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`BQ>SVW.WI\^<@Y?#I
MZ^_CWO(@X^GA(.'P[^C>ZN7U\^<@]._U(.'UZ.7M].GJ[_TB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`Q"FUS9VED(")3:&]W('!I8VME<B(*
M;7-G<W1R("+%[/;<[>GSYR#S]>OKW>KTYR(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,#D*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU
M(&)A<C\B"FUS9W-T<B`BS>$@Y>SVX>W?YN7TX>D@].\@[.7M[_T@[.4@Y?'C
MX?/?Y?(@\-_MX>KA.R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S,*
M;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@
M(L7L]MSMZ?/G(/3O]2`E<R#,Y>WO_2#S].$@X?'I\_3E\=P[(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X
M"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G
M(@IM<V=S='(@(L7L]MSMZ?/G(/3O]2#DZ>'K_./O]2#)Y.GO]-[T^>T@RN7K
MZ?[M(-#?[>'JX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O
M<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`BQ>SVW.WI\^<@]._U(.3IX>O\X^_U
M(,GDZ>_TWO3Y[2#0W^WAZN$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A
M8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("+%[/;<[>GSYR#T
M[_4@Y.GAZ_SC[_4@R>3I[_3>]/GM(,/QX>SL_NT@T-_MX>KA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q
M"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G
M<W1R("+%[/;<[>GSYR#T[_4@Y.GAZ_SC[_4@R>3I[_3>]/GM(,7IZOSMX?(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S4P"FUS9VED(")3:&]W
M('5P;&]A9"(*;7-G<W1R("+%[/;<[>GSYR#V_/'T^?/G\B`H=7!L;V%D*2(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C,Y,0IM<V=I
M9"`B4VAR:6YK(@IM<V=S='(@(M/U\?'?ZNWY\^<B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HV.#0@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z-S0V"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C@P-"!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HX-C8*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3`Q
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDS.`HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY-C8@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3DV"FUS9VED(")3:')I;FL@;W(@;6]V
M92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B
M"FUS9W-T<B`BT/'^].$@\_7Q\=_J[?GSYR#>(.SE].'JW^WG\^<@X^7I]._M
MZ>K^[2#T[.?LW/3Y[2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P
M+G!H<#HR-S@*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`BQ=_S[^3O\BW5\._C
M\>'VWB(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#D*;7-G:60@
M(E-I9VX@=7`@:68@;F]T(')E9VES=&5R960B"FUS9W-T<B`BQR#%W_/OY._R
M+=7P[^/QX?;>(.3E[2#=]^7I(.KA].'W^?'GZ.7?+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S,V"FUS9VED(")3:6=N871U<F4B
M"FUS9W-T<B`BU?#OX_'A]MXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C<S-0IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G
M<W1R("+!Z^/\\>GH[._R(-7P[^/QX?;>\B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HW,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y,`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C`V(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3$X"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,#<*;7-G:60@(E-I>F4B"FUS9W-T<B`BS-WCY>CO\B(*
M"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M7V)O='1O;2YI;F,Z
M.0IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R("+!ZOWQ^?/G(-/U
M[?3>\>?SY_(B"@IM<V=I9"`B4V]M92!O9B!(;W)D92=S(&-O;F9I9W5R871I
M;VX@9FEL97,@87)E(&UI<W-I;F<Z(@IM<V=S='(@(LSE\>GJW"#A\/P@].$@
MX?'WY=_A(.3IX??EW_'I\^?R(/3O]2!(;W)D92#=]^_U[2#WX>CEWSHB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3$T"FUS9VED(")3;W)T(&]R
M9&5R('-E;&5C=&EO;B(*;7-G<W1R("+%\.GK[^/>(.KA].7]Z/7M\^?R(/3A
M[NGM_.SG\^?R(@H*;7-G:60@(E-O=61A($%I<G!O<G0B"FUS9W-T<B`BP>7Q
M[^OI[-WMX?(@T^_]Y.'R(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU.#$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,3,*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B4V]U<F-E
M(&%D9')E<W,B"FUS9W-T<B`BQ.GE_>CU[?/G(-#GX][R(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B
M4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("+-_/3I[R#'[.GS]N'?\>GO
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T
M<B`BQ.G<\_3G[.$@[.7TX>[](./EZ?3O[>GJ_NT@ZN7KZ?[M(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@
M(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS
M9W-T<B`BQ.G<\_3G[.$@[.7TX>[](/#E\>GE]^_LW>WO]2#JX>D@X_'A[.S>
M\B#JY>OI_NTB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,30*;7-G
M:60@(E-P86-E<B(*;7-G<W1R("+0Z][J]/'O(,3IX?/TWNSA]._R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P
M"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(L'QX=_Y\^<B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED
M(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(L'QX=_Y\^<@ZN'I(./=
M[.GS[.$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.34*;7-G:60@
M(E-P86TB"FUS9W-T<B`B4W!A;2(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H
M<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B
MQ>GSX>/YX]X@Q>GDZ>K^[2#7X?'AZO3>\?GM(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L
M:70@8V5L;"(*;7-G<W1R("+$Z>'?\>7SYR#JY>OI[_TB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED
M(")3<&QI="!C;VQU;6XB"FUS9W-T<B`BQ.GAW_'E\^<@\_3>Z^?R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(L3IX=_QY?/G(./QX>SLWO(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E-P;W)T<R(*
M;7-G<W1R("+!Z.O>[.'TX2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-#0S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-30X"FUS9VED(")3=&%R="(*;7-G<W1R
M("*X[>'Q[N<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3@X(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.3<*;7-G:60@(E-T87)T('EE87(B
M"FUS9W-T<B`BN/3O\B"X[>'Q[N?R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM
M<V=S='(@(M#OZ^GTY=_A(-X@Q?#A\???X2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3@S"B,Z('1E;7!L871E<R]A
M9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T
M<B`BRN'TW//TX?/G(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P
M,PIM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`BS._Q]MX@X?#OZ-[J
MY?7SY_(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y
M-@IM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`BQ.GE_>CU[?/G+<_D
M_/(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(L3IX>/QX>SLZ?/L
MW>WA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(R-`IM<V=I9"`B
M4W1R:6YG(&QI<W0B"FUS9W-T<B`BR]_S].$@Z]WNY?GM(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@U-@IM<V=I9"`B4W1R:7`@9&]M86EN(&9R
M;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`BP?;AW_'E\^<@]._U(&1O;6%I;B#A
M\/P@].<@Y.GE_>CU[?/G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS
M9W-T<B`BT_3]ZR!;0U-372(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(LKU(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"FUS9VED(")3=6)D:7)E8W1O<GD@
M)R5S)R!N;W0@9F]U;F0N(@IM<V=S='(@(L\@]?#O]MSJY>OO\B`G)7,G(.3E
M(.+QW>CGZN4N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HW.`IM<V=I9"`B4W5B:F5C="(*;7-G<W1R("+(W>SA(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C@*;7-G:60@(E-U8FIE8W0@
M4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(LC=[.$@)]#KY_'O]N_QW^7R(,3G
M[/SSZ>_U(,KKY>GDZ>_])R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S,B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3(*;7-G
M:60@(E-U8FUI="(*;7-G<W1R("+!\._S]._KWB(*"B,Z('-I9VYU<"YP:'`Z
M-3`*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"`G)7,G('1O
M('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*
M(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*(M3O(.'?
M].?LX2#CZ>$@\/'O\^C>ZN<@)R5S)R#S].\@\_WS].?LX2#A\.7S]-SKYRX@
MQ.4@[/#O\>7?].4@[>$@[N'MX>SPY=_TY2`B"B+LW??QZ2#MX2#EX^KQZ>CE
MWR#T[R#AW_3G[-P@\^'R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R("+5
M\._DY=_J].?R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q,PHC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T
M=7,N<&AP.C,P"FUS9VED(")3=6-C97-S(@IM<V=S='(@(L7PZ?3U]]_A(@H*
M(SH@861M:6XO=7-E<BYP:'`Z.#4*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E
M9"`G)7,G('1O('1H92!S>7-T96TN(@IM<V=S='(@(L7PZ?3U]][R(/#Q[_/H
MWNKG("<E<R<@\_3O(//]\_3G[.$N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T
M"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R("<E
M<R<@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("+4X2#DY>3O[-WMX2#T[_4@
M]_'>\_3G("<E<R<@Y.GAX_'<]N?JX>T@Y?#I]/7W_O(@X?#\(/3O(//]\_3G
M[.$N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,2!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C8Q"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"`G)7,G+B(*
M;7-G<W1R("+%\.GT]??>\B#DZ>'C\>'VWB`G)7,G+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$P-0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@)R5S)R!F
M<F]M('1H92!S>7-T96TN(@IM<V=S='(@(L7PZ?3U]][R(.3IX>/QX?;>("<E
M<R<@X?#\(/3O(//]\_3G[.$N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I
M;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B(@HBS^D@\?7H
M[-_SY>GR(.7PX>WA]MWQZ.?JX>T@Y?#I]/7W_O(N(,K<[?3E(.7PX>WA]OSQ
M]/GSYR#CZ>$@[>$@Y.7?].4@].GR("(*(N'KZ^'CW?(N(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4U
M"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(L7PZ?3U]][R(.7P[^C>ZN7U\^<@Y?;EY/'IZN_](&-O
M;F9I9W5R871I;VXN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@IM
M<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+B(*;7-G<W1R("+%\.GT]??>\B#A\._HWNKE]?/G(/3O
M]2#E]N7D\>GJ[_T@X?'WY=_O]2!C;VYF:6=U<F%T:6]N("5S+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$V.`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@
M)R5S)R(*;7-G<W1R("+%\.GT]??>\B#E[>?LW?'Y\^<@)R5S)R(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C<R"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`BQ?#I
M]/7WWO(@Y>/C\>'VWB`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-34X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-38P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB
M"FUS9W-T<B`BT_WM[_CG("T@T.7QW^OG^.<B"@HC.B!L:6(O0FQO8VLO<W5N
M<FES92YP:'`Z-C8*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(L'MX?3OZ]XB
M"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-S$*;7-G:60@(E-U;B!3970B
M"FUS9W-T<B`BQ/WSYR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-C4*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`BP>WA]._KWB(*"B,Z(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ
M-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`BP>WA]._KWB_$_?/G
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-`IM<V=I9"`B
M4W5N<FES93H@(@IM<V=S='(@(L'MX?3OZ]XZ("(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-C@*;7-G:60@(E-U;G-E="(*;7-G<W1R("+$
M_?/G(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-PIM<V=I
M9"`B4W5N<V5T.B`B"FUS9W-T<B`BQ/WSYSH@(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I
M<'0B"FUS9W-T<B`BU?#E\>3EW^KTY?(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#8U"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(M7P[_/TWO'I
M[N<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM
M<V=I9"`B4W5R;F%M92(*;7-G<W1R("+%\-_HY?3O(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B
M"FUS9W-T<B`BU.\@X?'WY=_O(.KA].'C\>'VWO(@\_7C]_'O[>GS[._](.3I
MX>/QW/;GZN4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30U"FUS9VED
M(")3>6YC34PB"FUS9W-T<B`B4WEN8TU,(@H*(SH@9G)A;65W;W)K+U-13"]3
M44PO2V5Y=V]R9',N<&AP.CDX"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A
M<F-H('1E<FUS(@IM<V=S='(@(LO<Z._R(//][?3A[N?R(//T[_7R(/SQ[_7R
M(.'MX>;>].?SY_(B"@HC.B!F<F%M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S
M-0IM<V=I9"`B5&%B;&4B"FUS9W-T<B`BT-_MX>KA\B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@
M(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`BR>3I_/3G].7R(-#?[>'JX2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`BR>3I_/3G
M].7R(-#?[>'JX2(*"FUS9VED(")486YA9W)A($%I<G!O<G0B"FUS9W-T<B`B
MP>7Q[^OI[-WMX?(@U.'MW./QX?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")487)G970Z(@IM<V=S='(@
M(M/T_/?O\CHB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,38X"FUS
M9VED(")487-K<R(*;7-G<W1R("+%\>/A\]_E\B(*"FUS9VED(")4871O:2!!
M:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(-3A]._Z[_4B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B5&5L97!H
M;VYE($YU;6)E<B(*;7-G<W1R("+!\>GH[/SR(-3GZ^7V_NWO]2(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C@X"FUS9VED(")496UP(&9O<B!L87-T(&AO
M=7(Z("(*;7-G<W1R("+(Y?'L[^KQX?/?X2#TY^T@].7KY?7TX=_A(/[QX3H@
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3(*;7-G:60@(E1E;7!E<F%T
M=7)E(@IM<V=S='(@(LCE\>SOZO'A\]_A(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$W,@IM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R
M("+(Y?'L[^KQX?/?X3H@(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L
M871E+G!H<#HR,3$*;7-G:60@(E1E;7!L871E("<E<R<@;F]T(&9O=6YD+B(*
M;7-G<W1R("+4[R#P\?ST]?#O("<E<R<@Y.4@XO'=Z.?JY2XB"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R
M871I;VXB"FUS9W-T<B`BQ.GA]^7?\>GSYR#0\>_T_?#O]2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C0Q"FUS9VED
M(")496YT871I=F5L>2!!8V-E<'0@<F5Q=65S="(*;7-G<W1R("+0\>_S^?'I
M[=X@P?#OY._WWB#AZ?3>[.'T[_(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C8X.0IM<V=I9"`B5&5N=&%T:79E;'D@
M06-C97!T960B"FUS9W-T<B`BT/'O\_GQZ>W<(,'P[^3EZO3\(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(P,@IM<V=I9"`B5&5X="(*;7-G<W1R
M("+*Y=_LY>WO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U.0IM<V=I
M9"`B5&5X="!/;FQY(@IM<V=S='(@(LS\[>\@RN7?[.7M[R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G
M:60@(E1E>'0@86QI9VXB"FUS9W-T<B`BT_3OW_?G\^<@ZN7I[-WM[_4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS
M9VED(")497AT=&]P(@IM<V=S='(@(LKO\?7VWB#JY>GLW>WO]2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@
M(E1H(@IM<V=S='(@(M3E(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M.30T"FUS9VED(")4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN(@IM
M<V=S='(@(L7U]^'QZ?/T[_WLY2#P[_4@]_'G\^GL[_#OZ=[SX?3E(/3O(-/]
M\_3G[-P@[.'R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S8Y
M"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R("+'(.7PW>KTX?/G($944"#DY>T@Y=_MX>D@X>K\[.<@Y.GAZ-WS
MZ>SG+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(T"FUS9VED
M(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T
M('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(M3O(//]\_3G[.$@2&]R9&4O2V]L
M86(@Y.7M(/7P[_/TY_'?YN7I(%PB)7-<(B(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HR.0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@
M9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R("+$Z>'WY=_QZ?/G
M.CH@QR#JZ]SSYR#DY2#V[_'T_NCGZN4@Y?#I]/7W_O(B"@HC.B!S97)V:6-E
M<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N
M<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`BU.\@\.'Q
MW.CU\>\@Y?#IZ^_C_NT@W>KKY>GSY2X@N.[OY._R+B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,38P(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,3<Q"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@R(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,C`U(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,U(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C<T"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N
M965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C
M:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S
M='(@(B(*(L\@Y.GA]^7I\>GS]-[R(/#QW?#EZ2#MX2#Q]>CLW_/EZ2#=[>$@
M[/SMZ>SO(/#KX=_SZ>\@Q>[O]?/I[^3O]-[SY?GM+"#CZ>$@[>$@(@HB[/#O
M\>7?].4@[>$@]_'G\^GL[_#OZ=[SY?3E(.7N[_7SZ>_D[_3>\^7I\BXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R("+'(.K<
M]/D@\.OE]?'<(.S\[>\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C0Y"FUS9VED(")4:&4@8V%L96YD87(@9&%T82!I
M<R!I;G9A;&ED(@IM<V=S='(@(M3A(.3EY._LW>WA(.?LY?'OZ^_CW^_U(.3E
M[2#EW^WAZ2#=X^KU\>$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8V-`IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@
M;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N
M;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"B+4[R!)
M1"#TY_(@Y?#A]M[R(.3E[2#JX>CO\=_SZ.?JY2P@WO3A[2#JY>W\(-X@Y.4@
MXO'=Z.?JY2#S].<@XMSSYR#DY>3O[-WM^>TN(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C4T"FUS9VED(")4:&4@8V]N=&%C
M="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+B(*;7-G<W1R("+'(.7PX?;>(/#Q[_/TW>CGZN4@Y?#I]/7W_O(@\_3O(,3I
MY?7H]>WSZ>_C\=SV[R#SX?(N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3$W,0IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N
M871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@
M;65S<V%G92XB"FUS9W-T<B`B(@HBU.\@].S>[.$@4$=0(/#O]2#A\._S\-SS
MZ.?JY2#A\.'I].7?].\@X^GA(/3G[2#E\.'KWNCE]?/G(/3O]2#U\._CY>/Q
MX>SLW>WO]2`B"B+LY^W>[.'T[_(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-C8*;7-G:60@(B(*(E1H92!D:7-T
M<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE
M9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS
M9W-T<B`B(@HBU.\@240@].?R(.O?\_3A\B#DZ>'M[^S>\B#DY>T@[_'?\^CG
MZN4L(-[TX>T@ZN7M_"#>(.3E(.+QW>CGZN4@\_3G(.+<\^<@(@HBY.7D[^S=
M[?GM+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C8W"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO
M="!S<&5C:69I960N(@IM<V=S='(@(L<@Z]_S].$@Y.GA[>_LWO(@Y.7M(.KA
MZ._QW_/HY^KE+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP:'`Z,3(W
M"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C
M=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("+/Z2#D]>WA]/STY_3E\B#J
M\?7P]._C\=SVY_/G\B#A\.'I]._][2#A\_;AZ]X@\_WMY.7SYR!714(N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HW
M.`IM<V=I9"`B5&AE(&5V96YT(&AA<R!B965N(&%D9&5D('1O('EO=7(@8V%L
M96YD87(N(@IM<V=S='(@(M3O(./EX^_M_/(@\/'O\_3=Z.?JY2#S].\@Y^SE
M\>_K_./I_"#SX?(N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M.#$@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#0*;7-G:60@(E1H92!F
M:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B
MU.\@X?'WY=_O("5S(/#QW?#EZ2#MX2#PY?'IW??EZ2#LZ>$@)7,@\?WH[.GS
MYRXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-"!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C0Y-`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO
M=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`BU.\@X?'W
MY=_O("5S(/#QW?#EZ2#MX2#PY?'IW??EZ2#JW/#OZ>7R("5S(/'UZ.S?\^7I
M\BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-C4*;7-G:60@
M(E1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G
M<W1R("+4[R#A\??EW^\@Y.4@[/#O\>7?(.WA(.'M].GC\>'VY=\@\_3O[2#E
MX?7T_"#T[_4N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,C8T"FUS
M9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`BU.\@
MX?'WY=_O(.3E[2#PY?'IW??EZ2#DY>3O[-WMX2XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R"FUS9VED(")4:&4@9F]L
M;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R
M,B!M97-S86=E+B(*;7-G<W1R("+4X2#PX?'AZMST^2#EW^WAZ2#E\.GJY?;A
MZ]_DY?(@X^GA(.'U]/P@].\@[-[M]>SA+W)F8S@R,B#LWNWU[.$N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I
M9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@
M<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R
M;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD
M+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L
M86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R
M(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET
M)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB
M4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO
M=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO
M=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*
M;7-G<W1R("(B"B+'(.KA]-SS].'SYR#PZ][Q[_7R(._H_.WG\B#EW^WAZ2#C
M[?GS]/P@_/3I(.3G[.GO]?'CY=\@\/'\XNOG[.$@[.4@]._M("(*(DEN=&5R
M;F5T($5X<&QO<F5R+"#E[N'I]-_A\B#P\>_BZ^?LW/3Y[2`H8G5G<RD@]._U
M(&)R;W=S97(L(/3A(._P[]_A(.3E[2`B"B+EW^'I(.3U[>'T_"#MX2#NY?#E
M\>'SZ._][2X@S/#O\>7?(.WA(.3EW_3E("?SZN_U\-_DZ>$G(//TY^T@[^C\
M[><L("(*(O#Q[^+KWNSA].$@\_3G(.OEZ?3O]?'CW^$@]._U(&)R;W=S97(@
MWB#JX>D@ZOSKY^S<(/3O]2X@P>T@].\@\_WS].?LW"#SX?(@(@HBY=_MX>D@
M5VEN9&]W(#EX(.7?[>'I(/#OZ_T@\.GHX>W\(.WA(.3EW_3E("?#Y>WIZMX@
MP?#O]/7WW^$@T/'O\_3A\]_A\B<@ZN'I("(*(NWA(/#QW?#EZ2#MX2#E\.'M
MY>KJZ>W>\^7TY2`H<F5B;V]T*2Y<7&Y<7,'U]-X@Y=_MX>D@\/'OY>GD[_#O
MW^?SYRX@T.'TWO/TY2`B"B+/RB#A[2#HW>OE].4@X>K\[.<@[>$@Y._UZ]WX
MY?3E(//E(.KA]-SS].'SYR#PZ][Q[_7R(._H_.WG\BXB"@HC.B!S97)V:6-E
M<R]P<F5F<RYP:'`Z.#@*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S
M(&)E96X@9&5L971E9"XB"FUS9W-T<B`BQR#TX?7T_/3G].$@7"(E<UPB(.3I
MX>/QW/;GZN4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N
M;'DB"FUS9W-T<B`BQR#A\>GS].7QWB#PZ^7U\=P@[/SM[R(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-@IM<V=I9"`B(@HB5&AE(&QO
M8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T
M:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(B(*(L<@Z-WSYR#T[_4@
M\/'OX_'<[.SA]._R($=N=5!'(/#QW?#EZ2#MX2#D[^CEWR#CZ>$@].<@0W)Y
M<'1?<&=P.CH@ZNO<\^<N(@H*;7-G:60@(E1H92!M86EL8F]X('1R87-H(&ES
M(&%L<F5A9'D@96UP='DN(@IM<V=S='(@(L<@X_'A[.SA]._H]?'?Y.$@)^K<
MY._R)R#EW^WAZ2#>Y.<@W.3EZ>$N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-1$XN<&AP.C(Q-`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E
M<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE
M9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@
M:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"B+4[R#L
MWNWU[.$@\._U(//TW.OHY^KE(//TZ?(@)7,@\_3O[2`E<R#LY2#HW>SA("5S
M(.7L]N'MW_/HY^KE+EQN(@HBP?7T_"#DY>T@X?#O].7KY=\@Y?#IXN7BX=_Y
M\^<@_/3I(.3IX>+<\^CGZN4@ZN'I(-WCZ>WE(.KA].'M[^?T_"XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8P"FUS9VED(")4:&4@;F%M92!T
M;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T
M<B`BU.\@_.WO[.$@\._U(.CA(/?QY_/I[._P[^GEW_3AZ2#\].'M(//U[>3=
MY?/TY2#S].<@\^7KW^3A(//][>CE\^?R+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,3(U.0IM<V=I9"`B5&AE(&]P96YS<VP@;6]D
M=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C
M;&%S<RXB"FUS9W-T<B`BQR#BZ>+KZ>_HWNKG($]P96Y34TP@X?#AZ?3EW_3A
MZ2#CZ>$@2&]R9&5?0W)Y<'1?<VUI;64Z.B#JZ]SSYRXB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,N<&AP.C(Y,0IM<V=I9"`B(@HB5&AE('!R969E<F5N
M8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A
M(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S
M='(@(B(*(L<@\/'O]-_LY_/G(%PB)7-<(B#DY>T@[/#\\>7SY2#MX2#A\._H
MY^KE]>CEWR#CZ>'TWR#TX2#DY>3O[-WMX2#TY_(@(@HB]?#E\>+AW^WO]>T@
M].\@[-WCZ?/T[R#E\.GT\>7P]/P@[-WCY>CO\B(*"B,@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S4L(&,M9F]R;6%T"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z,S4*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,W"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S4*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS-0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP.C,U"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z-#`*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,Y"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,U"FUS9VED
M("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!M97-S86=E('1Y
M<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@
M(B(*(M3O(/#Q_./QX>SLX2#P[_4@]_'G\^GL[_#OZ>7?].4@X^GA(/3G[2#E
M[/;<[>GSYR#A]?3O_2#T[_4@Y=_D[_7R(.SG[?7LW/3Y[2`B"B(H)7,I(.3E
M[2#B\=WHY^KE(//T[R#S_?/TY^SA+B(*"FUS9VED("(B"B)4:&4@<F5G:7-T
M<GD@:7,@:&]W($AO<F1E(&%P<&QI8V%T:6]N<R!F:6YD(&]U="!H;W<@=&\@
M=&%L:R!T;R!E86-H(&]T:&5R+B`B"B)9;W4@<VAO=6QD(&QI<W0@86YY(&EN
M<W1A;&QE9"!(;W)D92!A<'!L:6-A=&EO;G,@=&AA="!Y;W4@:&%V92!H97)E
M+B(*;7-G<W1R("(B"B+'(')E9VES=')Y(.7?[>'I(.\@]/'\\._R(.SE(/3O
M[2#O\._?[R#OZ2#E]N'Q[._CW?(@]._U($AO<F1E(.7PZ>KOZ>WY[>_][2X@
M(@HB[.7TX>[](/3O]?(N(,7D_B#P\=WPY>D@[>$@X_'<^.7TY2#\].D@Y?;A
M\>SOX]WR(/3O]2!(;W)D92#=]^7TY2`B"B+EX^KA].'S]-[SY>DN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T
M<B`BQR#A\>GS].7QWB#JX>D@Y.7NZ=P@\.OE]?'=\B#L_.WO(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM
M<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(L<@Y.7N
MZ=P@\.OE]?'<(.S\[>\B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H
M<#HW.`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E
M9"XB"FUS9W-T<B`BSR#E[O7PY_'E].?TWO(@7"(E<UPB(.3IX>/QW.?JY2XB
M"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0IM<V=I9"`B5&AE
M('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(L\@Y>[U
M\.?QY?3>\B!<(B5S7"(@X?#OZ.?JY?WHY^KE+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$Y.`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@
M8F5E;B!R96UO=F5D+B(*;7-G<W1R("+4[R#AW_3G[.$@Y>GS_.3O]2#CZ>$@
M)7,@Y.GAX_'<]N?JY2XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HR.#0*;7-G:60@(E1H92!S<&5C:69I960@<F]W(&1O97,@;F]T
M(&5X:7-T+B(*;7-G<W1R("+'(./QX>SLWB#P[_4@[_'?\^'TY2#DY>T@]?#<
M\??EZ2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C$P.`IM<V=I9"`B5&AE('1A<VL@:&%S(&)E96X@861D960@=&\@
M>6]U<B!T87-K;&ES="XB"FUS9W-T<B`BQR#E\>/A\]_A(/#Q[_/TW>CGZN4@
M\_3G(.O?\_3A(.7QX^'SZ?[M(//A\BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C$Q,0IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<
M(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`BU.\@\/'O\_GQZ>W\(.'Q]^7?
M[R!<(B5S7"(@Y.7M(/7PW/'WY>DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A
M;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`BQR#PW.WY(.KAZ2#JW/3Y
M(/#KY?7QW?(@[/SM[R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY
M(@IM<V=S='(@(L<@\-SM^2#PZ^7U\=P@[/SM[R(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$N<&AP.C,Q,0IM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S
M(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(M3A(.3E
MY._LW>WA(/#O]2#S]-WK[>'TY2#WW.CGZN'M(.'P_"#T[R#P\>_GX^_][.7M
M[R#BWNSA+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-3`@
M9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W-PIM<V=I9"`B5&AE('5P
M;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R("+4[R#A
M\??EW^\@\._U(//TY=_KX?3E(.3E(.SP_/'E\^4@[>$@\_GHY=\N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HY,PIM
M<V=I9"`B5&AE('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VX@=V%S('-U
M8V5S<V9U;&QY('-T;W)E9"XB"FUS9W-T<B`BS^D@\.OG\>_V[_'?Y?(@Y.GA
MZ.7SZ>S\].?TX?(@X?#OZ.?JY?WHY^KA[2#E\.GT]??^\BXB"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z,C4*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@
M)R5S)R!N;W0@9F]U;F0N(@IM<V=S='(@(L\@ZN'TW.OOX^_R(.CE[-ST^>T@
M)R5S)R#DY2#B\=WHY^KE+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3@S"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B
M;&4N(@IM<V=S='(@(L3E[2#U\-SQ]^_U[2#%\.GK[^/=\B#DZ>'HW?/I[.7R
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T,`IM
M<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE
M9"!I;FQI;F4N(@IM<V=S='(@(L3E[2#U\-SQ]^_U[2#T[-[LX?3A(/#O]2#D
MY2#L\._Q[_WM(.WA(.7L]N'MZ?/H[_WM(.7M\_GLX?3Y[-WMX2XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,SDW"FUS9VED("(B"B)4:&5R92!A
M<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V
M92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE
M<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@HBU?#<\??O]>T@\._KZ^_?(/?A\>'J
M]-[QY?(@\^4@X?7T_"#T[R#PY>3?[RX@Q>GSX>/<X^'TY2`E<R#WX?'AZO3>
M\>7R+"`B"B+P\=WPY>D@[>$@]?#<\??O]>T@Z^GC_/3E\>_I(.'P_"`E<RXB
M"@HC.B!S:6=N=7`N<&AP.C4U"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M(&%D9&EN9R`G)7,G('1O('1H92!S>7-T96TN("5S+B(*;7-G<W1R("+0\?SB
MZ^?LX2#JX?3<(/3G[2#P\>_SZ-[JYR`G)7,G(//T[R#S_?/TY^SA+B`E<RXB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HW,PIM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!A9&1I;F<@)R5S)R!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R("+0
M\?SBZ^?LX2#JX?3<(/3G[2#P\>_SZ-[JYR`G)7,G(//T[R#S_?/TY^SA.B`E
M<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`G)7,G(&9R;VT@=&AE
M('-Y<W1E;3H@(@IM<V=S='(@(M#Q_.+KY^SA(.KA]-P@].<@Y.GAX_'A]MX@
MY.7D[^S=[?GM(/3O]2#W\=[S].<@)R5S)R#A\/P@].\@\_WS].?LX3H@(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3`S"FUS9VED(")4:&5R92!W87,@82!P<F]B
M;&5M(')E;6]V:6YG("<E<R<@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B
MT/'\XNOG[.$@ZN'TW"#TYR#DZ>'C\>'VWB`G)7,G(.'P_"#T[R#S_?/TY^SA
M.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@=7!D871I;F<@)R5S)SH@)7,B"FUS9W-T<B`BT/'\XNOG[.$@
MZN'TW"#TY^T@Y>WG[-WQ^?/G("<E<R<Z("5S(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.#DY"FUS9VED(")4:&5R92!W87,@82!P<F]B
M;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N
M(@IM<V=S='(@(M#Q_.+KY^SA(.KA]-P@].?M(.'P[_/T[^O>(.'Q]^7?[_4Z
M(,3E[2#S]-SKZ.?JY2`E<RXB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W
M<V5R+G!H<#HY,#0*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE
M(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@
M(B(*(M#A\>_U\^G<\^CGZN4@\/'\XNOG[.$@ZN'TW"#TY^T@X?#O\_3OZ]X@
M]._U(.'Q]^7?[_4Z(-3O("5S(.7?[>'I(.SEX^'K_?3E\>\@(@HBX?#\(/3O
M(.S=X^GS].\@Y?#I]/'E\/SLY>WO(.S=X^7H[_(@*"5D($)Y=&5S*2XB"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,#8*;7-G:60@(B(*
M(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H
M92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(B(*
M(M#A\>_U\^G<\^CGZN4@\/'\XNOG[.$@ZN'TW"#TY^T@X?#O\_3OZ]X@]._U
M(.'Q]^7?[_4Z(-/TW.OHY^KE(.S\[>\@W>WA("(*(O3LWNSA(/3O]2`E<RXB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,X
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE
M<W-A9V4@<&%R="(*;7-G<W1R("(B"B+0X?'O]?/IW//HY^KE(//VW.OLX2#J
MX?3<(/3G[2#E[/;<[>GSYR#A]?3O_2#T[_4@].S>[.'T[_(@]._U(.SG[?WL
MX?3O\BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z-#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C4Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C
M;VYT86-T(&1A=&$N(@IM<V=S='(@(M#A\>_U\^G<\^CGZN4@\_;<Z^SA(.KA
M]-P@].?M(.7I\^'C^>/>(.3EY._LW>WY[2#$Z>7UZ/7M\^GOX_'<]N_U+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&5V
M96YT.B`E<RXB"FUS9W-T<B`BT.'Q[_7SZ=SSZ.?JY2#S]MSK[.$@ZN'TW"#T
MY^T@Y>GSX>/YX]X@]._U(./EX^_M[_3O\CH@)7,N(@H*(SH@9G)A;65W;W)K
M+T1A=&$O1&%T82]I;6,N<&AP.C,R"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`BT.'Q
M[_7SZ=SSZ.?JY2#S]MSK[.$@ZN'TW"#TY^T@Y>GSX>/YX]X@Y.7D[^S=[?GM
M(.?LY?'OZ^_CW^_U+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z,3`U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!T87-K.B`E<RXB"FUS9W-T<B`BT.'Q[_7SZ=SSZ.?J
MY2#S]MSK[.$@ZN'TW"#TY^T@Y>GSX>/YX]X@].?R(.7QX^'SW^'R.B`E<RXB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.CDQ"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('5S97(G
M<R!F<F5E+V)U<WD@:6YF;W)M871I;VXZ("5S+B(*;7-G<W1R("+0X?'O]?/I
MW//HY^KE(//VW.OLX2#JX?3<(/3G[2#EZ?/AX_GCWB#PZ^?Q[_;O\>G^[2#D
MZ>'HY?/I[/STY_3A\CH@)7,N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HW.0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF
M:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q
M=6ER960@9FEE;&0N(@IM<V=S='(@(B(*(M#A\>_U\^G<\^CGZN4@\_;<Z^SA
M(//TYR#V_/'LX2#Q]>CLW_/E^>TN(+KS^?(@X?;>\^'TY2#JY>W\(.K<\._I
M[R`B"B+A\.'I]._][.7M[R#PY>3?[RXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8V,PIM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S
M(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM
M<V=S='(@(B(*(M#A\>_U\^G<\^CGZN4@\_;<Z^SA(//TY^T@Y>KTW>OE\^<@
M].?R(.KAZ._QZ?/LW>WG\B#KY>GT[_7QX]_A\B#T[_4@(@HBQ.GE]>CU[?/I
M[^/QW/;O]2X@T.'QX>KAZ_X@Y._JZ>S<\_3E(.'QX_STY?'A+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C8U"FUS
M9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A
M8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B
M(@HB0F5I(&1E<B!!:W1U86QI<VEE<G5N9R!D97(@2V]N=&%K=&1E=&%I;',@
M:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN($)I='1E("(*(G9E<G-U8VAE
M;B!3:64@97,@<W#D=&5R(&YO8V@@96EN;6%L+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<P"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L
M:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B+0X?'O
M]?/IW//HY^KE(//VW.OLX2#JX?3<(/3G[2#E[>?LW?'Y\^<@].?R(.O?\_3A
M\B#DZ>'M[^S>\BX@T.'QX>KAZ_X@(@HBY._JZ>S<\_3E(.'QX_STY?'A+B(*
M"FUS9VED(")4:&5S<V%L;VYI:VD@06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GL
MW>WA\B#(Y?/SX>OO[=_JY_(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HQ-3,*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E
M<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(L\@Y>[U
M\.?QY?3G]-[R($E-05`@Y.7M(/7P[_/TY_'?YN7I(.KOZ>W\]_'G\_3O]?(@
M]N'JW>OO]?(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HX,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.CDV"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z,3$R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z,C`P"FUS9VED(")4:&ES(&%C=&EO;B!I<R!N
M;W0@<W5P<&]R=&5D+B(*;7-G<W1R("+!]?3>(.<@Y>W=\>/EZ>$@Y.7M(/7P
M[_/TY_'?YN7TX>DN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HS-3D*;7-G:60@(E1H:7,@86-T:6]N(&ES(&YO
M="!Y970@:6UP;&5M96YT960N(@IM<V=S='(@(L'U]-X@YR#KY>GT[_7QX]_A
M(.3E[2#=]^7I(._K[^KKY_'YZ.7?(.'J_.SG+B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3$*;7-G:60@(E1H:7,@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@
M(L'U]/P@Y.4@]N'?[>7TX>D@[>$@Y=_MX>D@W>/J]?'O(.'Q]^7?[R!R87(N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HU-0IM
M<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@
M9FEL92XB"FUS9W-T<B`BP?7T_"#DY2#VX=_MY?3AZ2#MX2#EW^WAZ2#=X^KU
M\>\@X?'WY=_O('II<"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3(Y"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C
M87)D(&YU;6)E<BXB"FUS9W-T<B`BP?7T_"#DY2#VX=_MY?3AZ2#MX2#EW^WA
MZ2#=X^KU\>_R(.'QZ>CL_/(@ZMSQ].'R+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-PIM<V=I9"`B(@HB5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T
M:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E
M=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HBP?7T_/(@[R#O
MY.?C_/(@\^'R(.7PZ?3QW?#EZ2#MX2#S]-WK[>7TY2#LY^W][.'TX2#LW?/Y
M($-L:6-K871E;&PM*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@[-WS^2!(
M5%10+4%022XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P
M.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@
M05!)(@IM<V=S='(@(B(*(L'U]/SR(.\@[^3GX_SR(//A\B#E\.GT\=WPY>D@
M[>$@\_3=Z^WE].4@[.?M_>SA].$@[-WS^2!S;7,R96UA:6PM*&AT='`Z+R\B
M"B)S;7,R;6%I;"YC;VTI(.S=\_D@2%144"U!4$DN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#(*;7-G:60@
M(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I
M82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL
M(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA
M:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W
M+C$Y,"YI="DN(@IM<V=S='(@(B(*(L'U]/SR(.\@[^3GX_SR(//A\B#E\.GT
M\=WPY>D@[>$@\_3=Z^WE].4@[.?M_>SA].$@[-WS^2!33510("#JX>D@].?R
M("(*(E9O9&%F;VYE+4ET86QY(.S\[>\@\^4@X?'IZ.SO_?(@5F]D869O;F4N
M(,'PX>GTY=\@W>WA(.OOX^'QZ>'S[/P@96UA:6P@\_3G("(*(E9O9&%F;VYE
M($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C0W
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R.#$@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,Y-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-30V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,C8*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DT,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.3@X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3(@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`V,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,3,R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,#0*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-#,V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-#@@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,3(Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S.#8*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y-`IM<V=I9"`B5&AI<R!F:65L9"!I
M<R!R97%U:7)E9"XB"FUS9W-T<B`BU.\@\.7DW^\@X?7T_"#A\.'I].7?].'I
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-3D*;7-G:60@(E1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B
MU.\@\.7DW^\@X?7T_"#L\._QY=\@[>$@W??EZ2#L_.WO(.'JW?'AZ>_U\BXB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#`P"FUS9VED(")4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N
M+B(*;7-G<W1R("(B"B+!]?3\(/3O(/#EY-_O]2#L\._QY=\@[>$@\.7QZ=WW
MY>D@[/SM[R#A\>GH[._]\B#JX>D@W.WY(.K<]/D@].7KY=_A("@Z*2XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@X"FUS9VED(")4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R("+!
M]?3\(/3O(/#EY-_O(.SP[_'EWR#MX2#PY?'IW??EZ2#L_.WO(._J].'DZ>K=
M\B#TZ>S=\BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$W"FUS
M9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A
M<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"B+!]?3\(/3O(/#E
MY-_O(.SP[_'EWR#MX2#PY?'IW??EZ2#L_.WO(.O?\_3A(.'QZ>CL_NT@]_GQ
MZ?/LW>WY[2#LY2#JY>W\(-X@(@HBY>OKY^WIZOP@Y?'Y].?LX?3IZOPB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY.#,*;7-G:60@(E1H:7,@9FEE
M;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`BP?7T_"#T[R#P
MY>3?[R#P\=WPY>D@[>$@Y=_MX>D@W>WA\B#=X^KU\>_R(.'QZ>CL_/(N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R-`IM<V=I9"`B(@HB5&AI
M<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@
M2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R
M("(B"B+!]?3\(/3O(/#EY-_O(/#QW?#EZ2#MX2#PY?'IW??EZ2#J^>3IZOP@
M]_'^[.'T[_(@\^4@4D="(.3EZN'E[N'DZ>K>(.SO\?;>+"#P+B(*(O<N("<C
M,3(S-&%F)RXB"@IM<V=I9"`B(@HB5&AI<R!F:6QE(&-O;G1R;VQS('1H92!G
M;&]B86P@<V5T(&]F($U)344@9')I=F5R<R!F;W(@=&AE($AO<F1E(&9R86UE
M=V]R:RP@(@HB86QL;W=I;F<@87!P;&EC871I;VYS('1O(&UA:V4@=7-E(&]F
M('!R;V=R86US('-U8V@@87,@96YS8W)I<'0@;W(@;7-W;W)D=FEE=R`B"B)T
M;R!R96YD97(@8V]N=&5N="!I;G1O($A434P@9F]R('9I97=I;F<@:6X@82!B
M<F]W<V5R+B(*;7-G<W1R("(B"B+!]?3\(/3O(.'Q]^7?[R#PY?'IW??EZ2#T
M[_7R($U)344@9')I=F5R<R#P[_4@]_'G\^GL[_#OZ>_][?3AZ2#A\/P@].?M
M("(*(O7PY_'E\]_A(.7PZ?3QW?#O[?3A\B#DZ=SV[_'A(/#Q[^/QW.SLX?3A
M(.WA(.3IX??EZ?'?YN_M].'I(/3A(/#E\>GE]_SLY>WA("(*(O3Y[2!E;6%I
M;"#JX>D@[>$@].$@Y>SVX>W?YN_U[2#LY2#T[^T@ZN'TW.OKY^OO(/3Q_/#O
M+B(*"FUS9VED("(B"B)4:&ES(&9I;&4@8V]N=')O;',@=&AE('-T>6QE<VAE
M970@=&AA="!I<R!U<V5D('1O('-E="!C;VQO<G,@86YD(&9O;G1S(&9O<B`B
M"B)T:&4@2&]R9&4@9G)A;65W;W)K(&%N9"!A;&P@87!P;&EC871I;VYS('1H
M870@9&\@;F]T('!R;W9I9&4@=&AE:7(@;W=N("(*(G-E='1I;F=S+B(*;7-G
M<W1R("(B"B+!]?3\(/3O(.'Q]^7?[R#EZ]WC]^7I(/3I\B#Q]>CLW_/EZ?(@
M]/GM(/?Q^>S<]/GM(.KAZ2#T^>T@X_'A[.SA]._SY>GQ_NT@X^GA("(*(OSK
MX2#T[R#P\?SC\>'L[.$@]._U($AO<F1E+"#JX>D@X^GA(/3I\B#E]N'Q[._C
MW?(@\._U(.7?[>'I(.7CZN'TY?/TY^S=[>7R("(*(O/E(.'U]/P@ZN'I(.3E
M[2#PX?'=]^_U[2#DZ>K=\B#T[_7R(.7PZ>OOX]WR(./IX2#A]?3=\B#TZ?(@
M\?7H[-_SY>GR+B(*"FUS9VED("(B"B)4:&ES(&9I;&4@;6%P<R!F:6QE(&5X
M=&5N<VEO;G,@=&\@;&]G:6-A;"!-24U%('1Y<&5S+"!E;F%B;&EN9R!(;W)D
M92`B"B)A<'!L:6-A=&EO;G,@=&\@9FEG=7)E(&]U="!H;W<@=&\@:&%N9&QE
M('-O;64@8V]N=&5N="!S=6-H(&%S(&5M86EL("(*(F%T=&%C:&UE;G1S(&]R
M($-64R!C:&5C:V]U=',N(@IM<V=S='(@(B(*(L'U]/P@].\@X?'WY=_O(.KA
M].'C\=SVY>D@].GR(.7PY>KTW//EZ?(@]/GM(/3]\/GM(,S)S,4L(/[S].4@
M].$@\.7QZ>7W_.SE[>$@(@HB[_'I\^S=[?GM(&UA:6P@[>$@Y>SVX>W?YN_M
M].'I(.SE(/3O[2#JX?3<Z^OGZ^\@]/'\\.\N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z-38R"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@
M8F5E;B!P<F]C97-S960N(@IM<V=S='(@(L'U]-X@YR#V_/'LX2#=]^7I(-[D
MYR#E\.7NY?'CX?/HY=\N(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC
M.C$*;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(L'U]/P@Y=_MX>D@)7,N
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT,S<*;7-G:60@(B(*
M(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H
M:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H
M870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O
M<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I
M="`E<R(*;7-G<W1R("(B"B+!]?3\(.7?[>'I($MO;&%B($=R;W5P=V%R92!O
M8FIE8W0N(,/IX2#MX2#DY=_TY2#T[R#A[?3IZN7?[.7M[R#A]?3\("(*(O?Q
MY>G<YN7SZ.4@W>WA(/#Q_./QX>SLX2!E;6%I;"#P[_4@ZN'TX>OAXN'?[>7I
M(.'U]-X@].<@[._Q]MXN(,/IX2#KW_/TX2`B"B+TW?3OZ?GM(/#Q[^/QX>SL
MW/3Y[2#L\._QY=_TY2#MX2#E\.GSZN7UZ.7?].4@].\@)7,B"@IM<V=I9"`B
M(@HB5&AI<R!I<R!T:&4@;6%I;B!(;W)D92!C;VYF:6=U<F%T:6]N(&9I;&4N
M($ET(&-O;G1A:6YS('!A=&AS(&%N9"!B87-I8R!I=&5M<R`B"B)T:&%T(&%P
M<&QY('1O('1H92!C;W)E(&9R86UE=V]R:R!A;F0@86QL($AO<F1E(&%P<&QI
M8V%T:6]N<RXB"FUS9W-T<B`B(@HBP?7T_"#EW^WAZ2#T[R#BX?/IZOP@X?'W
MY=_O(/'UZ.S?\^7Y[2#T[_4@\/'OX_'<[.SA]._R("=(;W)D92<N(-#E\>G=
M]^7I(/3A("(*(NSO[>_PW/3IX2#JX>D@].$@XN'SZ>K<(.S=\><@\._U(/?Q
MY_/I[._P[^GO_>WTX>D@X?#\(/3O[2#P]?'>[>$@ZN'I(/3I\B`B"B+E]N'Q
M[._CW?(@]._U(//U\_3>[.'T[_(N("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C8P-PIM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W
M<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U
M<B!O=VXN(@IM<V=S='(@(B(*(M3O(.S>[?7LX2#A]?3\(./QW/;HY^KE(.SE
M(.KYY.GJ[_/EZ]_DX2`H)7,I(.3IX?;O\>7TZ>K>(.'P_"#TYR#DZ>K>(//A
M\BXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R.0IM<V=I
M9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@
M(L'U]/SR(.\@X?'IZ.S\\B#P\=WPY>D@[>$@Y=_MX>D@]._UZ]SWZ?/T[^T@
MW>WA+B(*"FUS9VED("(B"B)4:&ES('!R;V)L96T@<F5P;W)T('=A<R!R96-E
M:79E9"!F<F]M("5S+B!4:&4@=7-E<B!C;&EC:V5D('1H92!P<F]B;&5M("(*
M(G)E<&]R="!L:6YK(&9R;VT@=&AE(&9O;&QO=VEN9R!L;V-A=&EO;CHE<R!A
M;F0@:7,@=7-I;F<@=&AE(&9O;&QO=VEN9R`B"B)B<F]W<V5R.B5S(@IM<V=S
M='(@(B(*(M3O(/#Q_.+KY^SA(.'U]/P@X>WA]MWQZ.?JY2#A\/P@)7,N(,\@
M]_'>\_3G\B#JW.OE\^4@].?M/&)R+S[A[>'V[_'<("(*(O#Q[^+KWNSA]._R
M(.'P_"#T[R#PX?'AZMST^2!54DPZ/&)R+SXE<R#JX>D@]_'G\^GL[_#OZ>7?
M(/3O[2#AZOSK[_7H[R`B"B)B<F]W<V5R.CQB<B\^)7,B"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#@*;7-G:60@(E1H:7,@
M<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*
M;7-G<W1R("+!]?3\\B#O(.7N]?#G\>7TY_3>\B#DY2#L\._QY=\@[>$@X?#O
M\_7L\.G=\^7I('II<"#JX>D@9WII<"#A\??EW^$N(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ-#<*;7-G:60@(E1H:7,@<WES
M=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`BU.\@\_WS
M].?LX2#A]?3\(-WWY>D@X?#E[>7QX^_P[^GGZ.7?+B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(W"FUS9VED(")4:&ES('9A;'5E(&UU
M<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(L'U]-X@YR#TZ>S>(/#QW?#EZ2#M
MX2#EW^WAZ2#A\>GH[/SR+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,C4*;7-G:60@(E1I8VME=',B"FUS9W-T<B`BQ>GSZ?3>\>GA(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q,`IM<V=I9"`B5&EM92(*;7-G
M<W1R("+9\>$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S$Q"FUS
M9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(LGW[>?KX?3^[?3A\B#TY^T@
M_O'A(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O
M<FUA="(*;7-G<W1R("+,[_'VWB#^\>'R(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C4R,0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B
MQ?#IZ^_CWB#^\>'R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(S,B!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B
M5&ET;&4B"FUS9W-T<B`BU-_TZ^_R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I
M.B(*;7-G<W1R("+4W_3K[_(@*%1O;VQT:7`I.B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z.#`*;7-G:60@(E1O(@IM<V=S
M='(@(M#Q_/(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C(Y"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L
M(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@
M:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B+#Z>$@[>$@ZO'A
M]-[SY?3E(/#OZ^OA\.O<(.'M].GJY=_LY>WA+"#J\>'TWO/TY2#PX?3G[-SM
M[R#T[R!#;VYT<F]L("A00RD@WB`B"B+T[R!#;VUM86YD("A-86,I(/#KWNKT
M\>\L(.7M_B#JW.WE].4@ZNOIZBXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C,W"FUS9VED(")4;V1A>2(*;7-G<W1R("+3WNSE\>$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(X"FUS
M9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`BQ>WAZ^OAX]X@\^4@
M\.?CX=_O($A434PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C,Y"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R("+!_?'I[R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PIM<V=I
M9"`B5&]P(@IM<V=S='(@(LKO\?7VWB(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H7W1O
M<"DB"FUS9W-T<B`BT-SM^2#PZ^'?\^GO("A?=&]P*2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L871I;VYS(@IM<V=S='(@
M(LSE].'V\=SSY>GR(@H*;7-G:60@(E1R:7!O;&ES($%I<G!O<G0B"FUS9W-T
M<B`BP>7Q[^OI[-WMX?(@U/'?\._KY_(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-S<W"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(L'K
MY^C=\B#>(/CE]>3=\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(M3Q(@H*;7-G:60@
M(E1Y<&4@;6ES;6%T8V@N(@IM<V=S='(@(LOA[>CA\^S=[>_R(/3]\._R(.3E
MY._LW>WY[2XB"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C8R"FUS9VED
M(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`BT.OGZO3Q[^OOX][S].4@
M].?M(.7PZ>OOX]X@\^'R.B`B"@IM<V=I9"`B55),(@IM<V=S='(@(L?KY>KT
M\>_MZ>K>(,3IY?WH]>WSYR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-38Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R
M:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B(@HBQ^OEZO3Q
M[^WIZMX@Q.GE_>CU[?/G(./IX2#E\.GS]/'O]MX@X>WA]N_QW/(@ZN'TW//T
MX?/G\B#T[_4@\/'OX_'<[.SA]/SR(//A\B(*"FUS9VED(")54DPZ(@IM<V=S
M='(@(L?KY>KT\>_MZ>K>(,3IY?WH]>WSYSHB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HS-C$*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93
M(&1I<F5C=&]R>2XB"FUS9W-T<B`BP>3][>'TYR#G(/#Q_//BX?/G(//T[^T@
M5D93(.KA]-SK[^/O+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P
M+G!H<#HQ,#`*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O
M<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(L'D_>WA].<@YR#P
M\>_SZ-[JY2#E\.GPZ]WO[2#PZ^?Q[_;O\>G^[2#JX?3<(/3G[2#EW_/OY.\@
M]._U(/?QWO/TYRXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T
M-@IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(L'D_>WA].<@YR#AZ^OAX]X@Y>[O]?/I
M[^3O]-[SY?GM(./IX2#T[R!61E,@X?'WY=_O(%PB)7-<(BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S$@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C4P,@IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S
M:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`BP>3][>'TYR#G(.'K
MZ^'CWB#E[N_U\^GOY._TWO/E^>T@X^GA(/3O(%9&4R#A\??EW^\@)7,O)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,#0*;7-G:60@(E5N
M86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(L'D_>WA].<@YR#AZ^OA
MX]X@]._U("5S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HS
M-S4*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM
M<V=S='(@(L3E[2#EW^WAZ2#D]>WA]-X@YR#S_>WDY?/G(//T[R#DZ>'J[^SI
M\_3>(%-13"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<X.`IM
M<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(L3E
M[2#EW^WAZ2#D]>WA]-X@YR#S_>WDY?/G(.SE(%-33"XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HQ-S$@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,3<V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ
M.38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P,0HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"FUS9VED(")5;F%B;&4@
M=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`BP>3][>'TYR#G(.'M].GC\>'V
MWB!61E,@X?'WY=_O]2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C,R,`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB
M)7-<(BXB"FUS9W-T<B`BP>3][>'TYR#G(.3G[.GO]?'CW^$@ZN'TX>O\X^_U
M(%9&4R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,CDV(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-S,*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(V.0IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("+!Y/WMX?3G(.<@Y.?L
MZ>_U\>/?X2#JX?3AZ_SC[_4@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HQ,C8*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I
M;&4N(@IM<V=S='(@(L'D_>WA].<@YR#DY^SI[_7QX]_A(%9&4R#A\??EW^_U
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(Q,PIM<V=I9"`B
M56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`BP>3]
M[>'TYR#G(.3G[.GO]?'CW^$@ZN7M[_T@5D93(.'Q]^7?[_4N(@H*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-SD*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C@R"FUS9VED(")5;F%B
M;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R("+!Y/WMX?3G(.<@X?#O
M\_7L\-_E\^<@Y.7D[^S=[?GM+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,C0Y"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE
M(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(L'D_>WA].<@YR#D
MZ>'C\>'VWB!<(B5S7"(L(.\@]MSJY>OO\B#DY>T@Y=_MX>D@ZN7M_/(N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<Q(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,S(S"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,V,0IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N
M;W0@96UP='DB"FUS9W-T<B`BP>3][>'TYR#G(.3IX>/QX?;>("5S+"#O(/;<
MZN7K[_(@Y.7M(.7?[>'I(.KE[?SR(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW
M.2!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E("<E<R<Z("5S+B(*;7-G<W1R("+!Y/WMX?3G(.<@Y.GAX_'A]MX@
M)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,W-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S@Q"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN
M(@IM<V=S='(@(L'D_>WA].<@YR#DZ>'C\>'VWB#JX?3AZ_SC[_4@5D93(.7P
MX>WAZ^SBX>W\[.7MX2`H<F5C=7)S:79E;'DI+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(W-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,S0X"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-C$@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,V.0HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,S<S"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(L'D_>WA].<@YR#DZ>'C\>'VWB#J
MX?3AZ_SC[_4@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M,S0X(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S8P"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(")$87,@
M5D93+59E<GIE:6-H;FES(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XZ
M("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,3<Y"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
MP>3][>'TYR#G(.3IX>/QX?;>(/3O]2!61E,@X?'WY=_O]2!<(B5S7"(N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C0S(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,C$S"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HQ-S,@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X-@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3DS(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HT,3$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C0Q.0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL
M92XB"FUS9W-T<B`BP>3][>'TYR#G(.3IX>/QX?;>(/3O]2!61E,@X?'WY=_O
M]2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,S-PIM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R
M("+!Y/WMX?3G(.<@Y.GAX_'A]MX@5D93(.7PX>WAZ^'LXN'M_.SE[>$@*')E
M8W5R<VEV96QY*3H@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HW-3(*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E
M8W1O<GDN(@IM<V=S='(@(L3E(.SP[_'^(.WA(/#Q[_/DZ>_QW_/Y(/3O[2#T
M\=WW[^WTX2#JX?3<Z^_C[RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8R-PIM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF
M:6-A=&4@9&5T86EL<R(*;7-G<W1R("+$Y2#L\._Q_B#MX2#E[MSC^2#PZ^?Q
M[_;O\=_E\B#PZ?/T[_#OZ>?TZ>KO_2(*"B,Z(&9R86UE=V]R:R].971?24U3
M4"])35-0+G!H<#HT-C`@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T:"YP
M:'`Z,3$Y"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O
M9B`E<RXB"FUS9W-T<B`BP>3][>'TYR#G(/;\\?3Y\^<@[_'I\^SO_2#T[_4@
M)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,30P(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C$T-0HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,38T(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ-CD*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G
M<W1R("+!Y/WMX?3G(.<@[.7TX>K?[>?SYR#T[_4@5D93(.'Q]]_O]2XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Y"FUS9VED(")5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(L'D_>WA].\@].\@
MW.WOZ>/LX2#T[_4@5D93(.'Q]^7?[_4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(R,"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,3(W"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ,S`*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET
M:6YG+B(*;7-G<W1R("+!Y/WMX?3O(/3O(-SM[^GC[.$@]._U(%9&4R#A\??E
MW^_U(./IX2#C\=SXZ>SO+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C<T(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,PIM<V=I
M9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(L'D_>WA].\@
M].\@W.WOZ>/LX2#T[_4@5D93(.'Q]^7?[_4N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HT-PIM<V=I9"`B56YA8FQE('1O(&]P
M96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R("+$Y2#L\._Q_B#MX2#A
M[>_?[OD@].\@\_7L\.GE\^S=[>\@X?'WY=_O+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C8R,PIM<V=I9"`B56YA8FQE('1O(')E860@=&AE
M('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R("+$Y2#L\._Q_B#MX2#DZ>'B
MW//Y(/3O[2#J_?'I[R#JX?3<Z^_C[R!61E,@*'9F<W)O;W0I+B(*"FUS9VED
M(")5;F%B;&4@=&\@<F5G:7-T97(@<')E9F5R96YC97,@:6X@<V5S<VEO;BXB
M"FUS9W-T<B`BQ.7M(.7?[>'I(.3U[>'T_.T@[>$@ZN'TX??Y\>?H[_WM(._I
M(/#Q[_3I[-[SY>GR(./IX2#A]?3>(/3G[2#S_>WDY?/G+B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`Y-0IM<V=I9"`B56YA8FQE('1O(')E
M;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI
M<W1S(@IM<V=S='(@(L'D_>WA].<@YR#LY?3O[>_LX?/?X2#T[_4@)7,@\^4@
M)7,Z(.\@]MSJY>OK[_(@]?#<\??EZ2#>Y.<B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,S$U"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(L'D_>WA].<@YR#LY?3O[>_LX?/?
MX2#T[_4@5D93(.KA].'K_./O]2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C(U-0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T
M;W)Y.B`E<RXB"FUS9W-T<B`BP>3][>'TYR#G(.SE]._M[^SA\]_A(/3O]2!6
M1E,@ZN'TX>O\X^_U.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C(Y-@IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(L'D_>WA].<@YR#LY?3O[>_LX?/?X2#T[_4@5D93(.'Q
M]^7?[_4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C4V-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C0Q"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("+!Y/WM
MX?3G(.<@[.7T[^WO[.'SW^$@]._U(%9&4R#A\??EW^_U("5S+R5S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C0Y(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HR,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C0X-2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`T"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,C8*;7-G:60@(E5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@(L'D_>WA].<@YR#L
MY?3O[>_LX?/?X2#T[_4@5D93(.'Q]^7?[_4N(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4Q"FUS9VED(")5
M;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`BP>3][>'TYR#G(.7J
M]-WKY?/G(/3O]2!<(FUK:7-O9G-<(BXB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]M<W=O<F0N<&AP.C8R"FUS9VED(")5;F%B;&4@=&\@=')A
M;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R("+$Y>T@[/#\\>7S
MY2#MX2#LY?3A]O'A\_3EWR#A]?3\(/3O(-WCX_'A]N\@5V]R9"(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,3(W(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,3,P"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@
M7"(E<UPB+B(*;7-G<W1R("+$Y2#L\._Q_B#MX2#C\=SX^2#S].\@5D93(.'Q
M]^7?[R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,3(Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F
M86EL960I+B(*;7-G<W1R("+$Y2#L\._Q_B#MX2#C\=SXYR#S].\@5D93(.'Q
M]^7?[R`H8V]P>2@I(.'PW?3U]^4I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(R-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,3,T"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,SD*;7-G
M:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R("+$
MY2#L\._Q_B#MX2#C\=SX^2#DY>3O[-WMX2#T[_4@5D93(.'Q]^7?[_4N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM
M<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(M7P[^/QX>SLZ?/LW>WA(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S
M(@IM<V=S='(@(L'J_?'Y\^<@P>OKX>/^[2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R
M(&QA<W0@86-T:6]N(@IM<V=S='(@(L'J]?'^[>7I(/3G(/3EZ^7U].'?X2#S
MX?(@Y>W=\>/EZ>$B"@IM<V=I9"`B56YE>'!E8W1E9"!E;F0@;V8@9FEL92XB
M"FUS9W-T<B`BS.<@X>WA[.7M_.SE[>\@]-WK[_(@]._U(.'Q]^7?[_4N(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C,P"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y.0IM<V=I
M9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T
M:6]N.B`B"FUS9W-T<B`BS.<@X>WA[.7M_.SE[><@X?#<[?3G\^<@X?#\(/3O
M[2#E[O7PY_'E].?TWB#S].<@\_WMY.7SYSH@(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(V"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,U,`HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS.#<*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,SDS"FUS9VED(")5;F5X<&5C=&5D(')E<W!O
M;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`BS.<@X>WA[.7M_.SE[><@
MX?#<[?3G\^<@X?#\(/3O[2#E[O7PY_'E].?TWB#S].\Z("(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4X"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8T"FUS9VED
M(")5;F9I;&5D(@IM<V=S='(@(LSG(,'Q]^7I[^CE].?LW>WO(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HS.#0*;7-G
M:60@(E5N:&%N9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,B"FUS9W-T<B`B
MS.<@]^7I\>GF_.SE[>\@\_3OZ??EW^\@]/WP[_4Z("5S(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C4U(&QI8B]";&]C:R]M971A<BYP:'`Z
M-CD*;7-G:60@(E5N:71S(@IM<V=S='(@(LSO[=SDY?(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,34@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$V"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(L'C[?GS
M].\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#<*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E
M($E$*2XB"FUS9W-T<B`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@
M240I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P.`IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE
M<W-A9V4@240I+B(*;7-G<W1R(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@
M365S<V%G92!)1"DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R
M('!A<W-W;W)D+B(*;7-G<W1R("+!X^WY\_3O(/SM[^SA(/?QWO/TYR#>(.KY
MY.GJ_/(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4W"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE
M;65N="(*;7-G<W1R("+!\._S_>WDY?/G(/3QW??O[?3O\B#S]._I]^7?[_4B
M"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C(Y.`IM<V=I
M9"`B56YN86UE9"(*;7-G<W1R("+![?[M]>SO(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV
M:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P
M<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC
M:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W
M:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C
M8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"B+,YR#E[N_U\^GOY._T
MY^S=[>$@\/'OX_'<[.SA].$@Y.4@[/#O\>_][2#MX2#=]^_U[2#P\?SSXN'S
MYR#SY2#KY>GT[_7QX]_E\B`B"B+A\._J[_#>\B_A[?3IX_'A]M[R+^7PZ>K\
MZ^?SY_(@X^GA(.O\X^_U\B#A\_;AZ^7?X?(N(-#A]-[S].4@S\H@X^GA(.WA
M(.3EW_3E("(*(O3E]^WIZMWR(//G[.7I_O/EZ?(@\_3O(&UO>FEL;&$N;W)G
M(/#O]2#SX?(@Y.7?]^WO]>T@\/GR(.WA(.7PZ?3QW?CE].4@\^4@(@HB\/'O
MX_'<[.SA].$@].<@\/'\\^+A\^<@\_3O(&-L:7!B;V%R9"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G
M:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(LSG(._QZ?/LW>WO(/?Q_NSA(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3`@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY-3(*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HY-3@*;7-G:60@(E5N<W5P<&]R=&5D($5X
M=&5N<VEO;B(*;7-G<W1R("+,YR#U\._S].?QZ>;\[.7MYR#E\-WJ].'SYR(*
M"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P-B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C$Y,0HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHS-@IM<V=I9"`B57!D871E(@IM<V=S='(@(L7MY^S=\?GSYR(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S$*;7-G:60@(E5P
M9&%T92`E<R(*;7-G<W1R("+%[>?LW?'Y\^<@)7,B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8T.`IM<V=I9"`B57!D
M871E(')E<W!O;F1E;G0@<W1A='5S(@IM<V=S='(@(L7MY^S=\?GSYR#JX?3<
M\_3A\^?R(.'PX>WTY^S=[>_U(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHT,PIM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`BQ>WG
M[-WQ^?/G(/?QWO/TYR(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3,W(&%D;6EN
M+W!E<FUS+V5D:70N<&AP.C(Q-R!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M,C,P"FUS9VED(")5<&1A=&5D("<E<R<N(@IM<V=S='(@(B<E<R<@Q>WG[.7Q
M_NCGZN4N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#$*;7-G:60@
M(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(M3O(/#Q_./QX>SL
MX2#A[>'BW.CLZ?/G\B#DZ>'C\=SVY^KE+B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-S(@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$X,@IM<V=I9"`B57!L;V%D(@IM<V=S='(@(L'P[_/T[^O>(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`IM<V=I9"`B57!L;V%D960@86QL
M(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S
M='(@(L'P[_/T[^O>(/SK^>T@]/GM(.'Q]^7?^>T@\?7H[-_SY?GM(//T[^T@
MY>[U\.?QY?3G]-XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T
M=&5R<R(*;7-G<W1R("+*Y?;AZ^'?X2#KX?3I[>GJW"#C\=SL[.'TX2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`BT?GL
MX?KJ[]\@X?'IZ.SOWRW*Y?;AZ^'?X2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0V"FUS9VED(")5<V4@0W5R<F5N
M=#H@)7,B"FUS9W-T<B`BU_'>\^<@]/'=]^_M]._R.B`E<R(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34X"FUS9VED
M(")5<V4@4U-,(@IM<V=S='(@(M?QWO/G(%-33"(*"FUS9VED(")5<V4@1&5F
M875L="!686QU92(*;7-G<W1R("+-X2#W\>?SZ>SO\._IY^CEWR#G(/#Q[^7P
MZ>OEX^S=[><@].GLWB(*"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I
M<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R("+7\>?SZ>SO
M\._IY=_TX>D@X>T@].\@_.WO[.$OZOGDZ>K\\B#EW^WAZ2#DZ>'V[_'E].GJ
MW"XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C8U
M,0IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM
M<V=S='(@(L\@]_'>\_3G\B`E<R#DY>T@Y=_MX>D@Y>[O]?/I[^3O].?LW>WO
M\B#CZ>$@)7,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`T"FUS9VED(")5<V5R
M($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(L3IX??EW_'I\^<@U_'G\_3^[2(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C4Q"FUS9VED(")5
M<V5R($]P=&EO;G,B"FUS9W-T<B`BQ?#IZ^_CW?(@U_'>\_3G(@H*(SH@<VEG
M;G5P+G!H<#HV-`IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B
MQ>/C\>'VWB#7\=[S].<B"@HC.B!S:6=N=7`N<&AP.C$Y"FUS9VED(")5<V5R
M(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E
M+B(*;7-G<W1R("+'(.7CX_'A]MX@]_'>\_3G(-WWY>D@X?#E[>7QX^_P[^GG
MZ.7?(./I)R#A]?3\(/3O('-I=&4N(@H*;7-G:60@(E5S97(@<&%S<W=O<F0@
M8VAA;F=E(@IM<V=S='(@(L'KZ^'CWB#J^>3IZN_](/?QWO/TYR(*"B,Z(&%D
M;6EN+W!E<FUS+V5D:70N<&AP.C$W,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C(U-`IM<V=I9"`B57-E<B!P97)M:7-S:6]N<R(*;7-G<W1R("+%
M[N_U\^GOY._TWO/EZ?(@U_'>\_3G(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`R('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-C4@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3$*;7-G:60@(E5S
M97)N86UE(@IM<V=S='(@(KSM[^SA(-?QWO/TYR(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HQ,S$*;7-G:60@(E5S97)N86UE("<E<R<@
M86QR96%D>2!E>&ES=',N(@IM<V=S='(@(M3O(/SM[^SA(/?QWO/TYR`G)7,G
M(/7PW/'WY>D@WN3G+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(KSM[^SA(-?QWO/TYSHB
M"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5<V5R
M;F%M93H@(@IM<V=S='(@(KSM[^SA(-?QWO/TYSH@(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C<*;7-G:60@(E5S97)S(@IM<V=S='(@
M(M?QWO/TY?(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT
M"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R("+7\=[S].7R
M(//T[R#3_?/TY^SA.B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C$Q,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#,*;7-G:60@(E9&
M4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(L\@ZN'TW.OO
MX^_R(%9&4R#DY>T@]?#<\??EZ2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S@S"FUS9VED(")686-A=&EO;B(*;7-G<W1R("+$Z>'J[_#=\B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V,`IM<V=I9"`B5F%L:60@
M;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R("*XX^KU\>7R(/3O
M\._HY?/?Y?(@\._U(.+QW>CGZN'M(//U[/#E\>GKX>SBW.WO[?3AZ3H@(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C(*;7-G:60@
M(E9A;&ED:71Y(@IM<V=S='(@(L7CZO7Q_/3G].$B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8R,0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C,*;7-G:60@
M(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(M3I[-X@\^4@
MZ^7P]-P@X?#\(/3^\>$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C(R-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0Y"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(R.3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,CDQ-@IM<V=I9"`B5F%L=65S(@IM<V=S='(@(M3I[-WR(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`Y,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,38Y"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B
MQ/[S].4@].GLW?(@X^GA(.WA(.7PZ>O=[ODB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3DS"FUS9VED(")687)I86)L92(*;7-G<W1R("+,
MY?3AXNOG]-XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C(R.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G
M92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(L<@Y?#I
MXN7BX=_Y\^<@X?#=]/7WY2`M(.'U]/P@].\@[-[M]>SA(.SP[_'EWR#MX2#<
MZ^OA[N4@[.4N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HW,C0*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`BN.KD[_/G(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P,`IM<V=I9"`B5F5R<VEO;B!#;VYT
M<F]L(@IM<V=S='(@(KCKY>/W[_(@N.KD[_/G\B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E
M<G1I8V%L(&%L:6=N(@IM<V=S='(@(LK<Z.7TYR#%]>CUX_'<[.SI\^<B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS
M9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(LK<Z.7T[R#CW>SI\^SA
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(LK<Z.7TX3HB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8R"FUS9VED(")697)Y($AI9V@B
M"FUS9W-T<B`BT._K_2#XY^O>(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z.3DR"FUS9VED(")6:65W("5S(@IM<V=S='(@(L7L]MSM
MZ?/G("5S(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE
M=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R("+%[/;<[>GSYR#E[OGT
MY?'IZM[R(.GS]._SY>O?Y.'R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z.#0U"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(L7L
M]MSMZ?/G(//A[2`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-SD*;7-G:60@(E9I97<@979E;G0B"FUS9W-T<B`B
MQ>SVW.WI\^<@X^7C[^W\]._R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HQ,#D*;7-G:60@(E9I97<@=&%S:R(*;7-G
M<W1R("+%[/;<[>GSYR#E\>/A\]_A\B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C`W"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(L_QX?3\].?TX2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#<*;7-G:60@(E9I
M<VEB:6QI='DZ("(*;7-G<W1R("+/\>'T_/3G].$Z(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#$*;7-G:60@
M(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S='(@(E9O9&%F;VYE(,GT
MX>O?X?(@[-WS^2!33510(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS.0IM<V=I9"`B5T%2
M3B(*;7-G<W1R("+0T<_3S]?'(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z.#,*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,
M62!&4D]-("5S+B(*;7-G<W1R("+0T<_3S]?'(2$A(,'6P<G1Q=/4Q2#4SR#0
MT<_#T<',S,$@S,_-S\D@T\'3(,'0SR`E<RXB"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,Q
M"FUS9VED(")787)N:6YG(@IM<V=S='(@(M#Q[^7IY._P[]_G\^<B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED
M(")792(*;7-G<W1R("+4Y2(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-
M86EN=&5N86YC92YP:'`Z,S<*;7-G:60@(E=E96ML>2(*;7-G<W1R("+%XN3O
M[.'DZ>'?X2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS
M9VED(")796QC;VUE(@IM<V=S='(@(LKAZ_GSWNOHX?3E(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C4P"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(LKAZ_GSWNOH
MX?3E(//T[R`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y
M('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@IM<V=I9"`B5V5L8V]M92P@
M)7,B"FUS9W-T<B`BRN'K^?/>Z^CA].4L("5S(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0R,0IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@
M)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`BT._IW"#E]N'Q[._C
MWB#HX2#E[/;A[-_FY>D@].\@)7,@X?;O_2#S]>WDY>CEW_3E(//TY^T@]?#G
M\>7SW^$[(@H*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD($AO<F1E
M(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(M#OZ>$@Y?;A\>SOX]X@
M[>$@Y>SVX>W?YN7TX>D@X?;O_2#S]>WDY>CEW_3E(//TY^T@]?#G\>7SW^$[
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(E=H
M870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(M#OZ?SR
M(.7?[>'I(.\@Y.GA]_GQZ?/TZ>K\\B#WX?'AZO3>\>'R.R(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C(T"FUS9VED(")7:&%T(&ES('1H92!Q
M=6]T92!C:&%R86-T97(_(@IM<V=S='(@(M#OZ?SR(.7?[>'I(.\@]^'QX>KT
MWO'A\B#EZ?/AX_GCZ>K^[3LB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*
M;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R("+0[^G=\B#6W//EZ?(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,Q"FUS9VED(")7:&EC:"!P;'5G
M:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S
M='(@(B(*(LKAZ._QW_/TY2#P[^G<(/#Q_//HY?3A(.CA(.7MY?'C[_#OZ>?H
M[_WM(//T[^T@Y?#E[N7QX^'S]-X@Y>SPZ^_U].GS[-WM[_4@(@HBZN7I[-WM
M[_4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`BT.O<]._R(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P.0IM<V=I9"`B5VED=&@@:6X@
M0U-3('5N:71S(@IM<V=S='(@(M#KW/3O\B#SY2#L[^W<Y.7R($-34R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$*;7-G:60@(E=I9'1H(&]F('1H
M92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L
M;V<M:6XI.B(*;7-G<W1R("+0Z]ST[_(@]._U("5S(.SE[>_](//TX2#A\>GS
M].7QW"`HZ.$@Y?;A\>SO\^CEWR#S].?M(.7P_.SE[><@Y=_S[^3O*3HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM
M<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(M#KW/3O\B#T[_4@
M\-_MX>KA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`BS._MW.3A(/#K
MW/3O]?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P-0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(M#KW/3O\CHB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C<X"FUS9VED(")7:6YD('-P965D(&EN(&MN
M;W1S(@IM<V=S='(@(KCM].'SYR#A[=WL[_4@\^4@ZOSLXN_U\B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,34T"FUS9VED(")7:6YD.B(*;7-G<W1R("+!
M[>7L[_(Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Y,0IM
M<V=I9"`B5VEN9#H@(@IM<V=S='(@(L'MY>SO\CH@(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T<B`BT^_VW^$B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3<W"FUS9VED(")7:7-H
M;&ES=',B"FUS9W-T<B`BR]_S].$@Y?#IZ/7LZ?[M(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S='(@(L7QX^'SW^$B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(W
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C<*
M;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R("+$Z>7]Z/7M\^<@Q?'CX?/?
MX?(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3DU"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(M3GZ]WV^>WO(,7QX^'S
MW^'R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-`IM<V=I9"`B
M6"U2968B"FUS9W-T<B`B6"U2968B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8Q-PIM<V=I9"`B6#4P.78S($)A<VEC($-O;G-T<F%I
M;G1S(@IM<V=S='(@(E@U,#EV,R#"X?/IZN_?(-#E\>GO\>GS[._?(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,38*;7-G:60@(E@U
M,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B6#4P.78S(-?QWO/G
M(.7PY>KTX>S=[>_U(.KKY>GDZ>_](@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV,3@*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R
M;F%T:79E($YA;64B"FUS9W-T<B`B6#4P.78S(,7MX>OAZO3IZOP@O.WO[.$@
MR-WLX?3O\B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C$Y"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G
M<W1R(")8-3`Y=C,@P>WAX^WY\>GS].GJ_"#*Z^7IY-\@R-WLX?3O\B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`V"FUS9VED(")8
M-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R(")8-3`Y=C,@Q?#EZO3<\^7I\B(*
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R("+%
MQ2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS
M.#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R
M-PIM<V=I9"`B65E962(*;7-G<W1R("+%Q<7%(@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HS-0IM<V=I9"`B665A<FQY(@IM
M<V=S='(@(L7TWO/IX2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HX.#@*;7-G:60@(EEE<R(*;7-G<W1R("+-X=\B"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O86=R965M96YT7V)O='1O;2YI;F,Z-@IM
M<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(LWAZ2P@T_7L]OGM_B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G
M:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O
M;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"B+%W_/T
MY2#SY2#JX?3<\_3A\^<@RL7)S,7-S]4N(-?QY_/I[._P[^GEW_/TY2#T[R!;
M/#Y=(/#KWNKT\>\@X^GA(.WA("(*(N7PZ?/T\=WXY?3E(//E(.KA]-SS].'S
MYR!765-)5TE'+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,R
M,`IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T<B`B
MQ.7M(-WWY?3E(.'UZ.7M].GJ[_#OZ>?HY=\N(@H*(SH@9G)A;65W;W)K+TED
M96YT:71Y+TED96YT:71Y+G!H<#HS,#0*;7-G:60@(EEO=2!C86X@;F]T(&AA
M=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G
M<W1R("+$Y>T@Y?#I]/'=\.7TX>D@[>$@W??E].4@].\@]^'QX>KTWO'A("=<
M7"<@\_3O(+SM[^S<(//A\BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#,X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-3@*;7-G:60@(EEO
M=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T
M<B`BQ.4@Y/[SX?3E(-WCX_7QYR#DZ>7]Z/7M\^<@96UA:6PN(@H*(SH@9G)A
M;65W;W)K+T1A=&$O1&%T82YP:'`Z,C<T"FUS9VED("(B"B)9;W4@9&ED;B=T
M(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE
M(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"B+$
MY>T@X>WTZ?/T[^GWW_/A].4@ZN'MW>WA(/#EY-_O(.'P_"#T[R#A\??EW^\@
MY>GSX>/YX][R(//E(.'M]-_S]._I]^$@\.7DW^$@(@HB\_3O("5S+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDT-`IM<V=I9"`B66]U(&AA=F4@
M8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R("*X]^7TY2#A\._S]>WDY>CEWRXB
M"@IM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+CQB<B`O/E1H86YK
M('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`BN/?E].4@X?#O
M\_7MY.7HY=\N/&)R("\^Q?7WX?'I\_3O_>SE(/#O]2#W\>?SZ>SO\._IWO/A
M].4@].?M(/7PY_'E\]_A+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q-SD*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N
M(@IM<V=S='(@(M#QW?#EZ2#MX2#D_O/E].4@[.GA(-WCZO7QYR#TZ>S>+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HS.`IM<V=I9"`B
M66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@
M4VEG;G5P<RXB"FUS9W-T<B`BT/'=\.7I(.WA(/'UZ.S?\^7TY2#T[R!$871A
M5')E92#CZ>$@[>$@]_'G\^GL[_#OZ>7?].4@4VEG;G5P<RXB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0T-PIM<V=I9"`B66]U(&UU<W0@8V]N
M9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(M#QW?#EZ2#MX2#Q]>CL
MW_/E].4@].\@5D93+4)A8VME;F0N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P
M<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T
M+B(*;7-G<W1R("+0\=WPY>D@[>$@\.7QZ>/QW/CE].4@].\@\/'\XNOG[.$@
M\/'I[2#S].7?Z^7TY2#A[>'V[_'<(./IX2#A]?3\+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M
M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*
M;7-G<W1R("+0\=WPY>D@[>$@\_7L\.OG\?[SY?3E(/3O(%523"#P[_4@Y.7?
M]^WEZ2#A]?3>(.<@\_WMY.7SYR(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S
M=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O
M(&)E(&1E;&5T960N(@IM<V=S='(@(M#QW?#EZ2#MX2#E\.GKW>[E].4@]._M
M(.7N]?#G\>7TY_3>(./IX2#DZ>'C\>'VWBXB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ,3D*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C
M;&5A<B!O=70N(@IM<V=S='(@(M#QW?#EZ2#MX2#O\=_SY?3E(-WMX2#\[>_L
MX2#W\=[S].<@X^GA(.3IX>/QX?;>+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P
M,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V
M92XB"FUS9W-T<B`BT/'=\.7I(.WA(._QW_/E].4@W>WA(/SM[^SA(/?QWO/T
MYR#CZ>$@Y.GAX_'A]MXN(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(M#QW?#EZ2#M
MX2#O\=_SY?3E(-WMX2#\[>_LX2#W\=[S].<@X^GA(/#Q[_/HWNKG+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T
M:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R("+0\=WPY>D@[>$@[_'?
M\^7TY2#=[>$@_.WO[.$@]_'>\_3G(./IX2#E[>?LW?'Y\^<N(@H*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,30T"FUS9VED(")9
M;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S
M='(@(M#QW?#EZ2#MX2#O\=_SY?3E(.SIX2#E[=WQX^7IX2#CZ>$@Y>KTW>OE
M\^<N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E
M<BYP:'`Z-S,*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@
M;F%M92XB"FUS9W-T<B`BT/'=\.7I(.WA(.3^\^7TY2#=[>$@_.WO[.$@X^GA
M(/3G(.W=X2#JX?3GX^_QW^$N(@H*(R!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HY,S(L(&,M9F]R;6%T"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDS
M,@IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@
M;&]G:6X@86=A:6XN(@IM<V=S='(@(L<@\_WMY.7SYR#SX?(@)7,@Y.GAZOSP
MY^KE+B#0X?'AZN'K_B#D[^KI[-SS].4@[>$@[N'MX?/U[>3EZ.7?].4N(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G:60@(EEO
M=7(@16UA:6P@061D<F5S<R(*;7-G<W1R("+'(,?KY>KT\>_MZ>K>(//A\B#$
MZ>7]Z/7M\^<B"@IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S.B(*;7-G<W1R
M("+'(,?KY>KT\>_MZ>K>(//A\B#$Z>7]Z/7M\^<Z(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Y-@IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*
M;7-G<W1R("+'(,'P_#H@Q.GE_>CU[?/G.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM
M<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R("+/Z2#0Z^?Q[_;O\=_E
M\B#SX?(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY,S8*;7-G:60@
M(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T
M:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C
M="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T
M<B`B(@HBQR!);G1E<FYE="#DZ>7]Z/7M\]X@\^'R(-SKZ^'NY2#A\/P@].?M
M(-WMX?'NYR#TY_(@)7,@\_WMY.7SWO(@\^'R+B##Z>$@].?M("(*(O#Q[_/T
MX?/?X2#TY_(@X?/VW.OEZ>'R(/#QW?#EZ2#MX2#NX>WA\_7MY.7HY=_TY2XB
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B
M66]U<B!.86UE(@IM<V=S='(@(M3O(/SM[^S<(//A\B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VYO861D+FEN8SHY"FUS9VED("(B"B)9;W5R(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E
M<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S
M;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@HBU.\@\_WS].?LX2#A]>CE
M[?3IZN_P[]_G\^?R(.3E[2#U\._S].?QW^;EZ2#P\>_SZ-[JYR#W\>?S]/[M
M+"#>(.<@Z^7I]._U\>/?X2`B"B+A]?3>(-WWY>D@X?#E[>7QX^_P[^GGZ.7?
M(./IX2#JW/#OZ>\@Z_SC[RXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N
M;VQI<W0N:6YC.CD*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C
M:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F
M96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E
M87-O;BXB"FUS9W-T<B`B(@HBU.\@\_WS].?LX2#A]>CE[?3IZN_P[]_G\^?R
M(.3E[2#U\._S].?QW^;EZ2#KW_/TX2#W\>?S]/[M+"#>(.<@Z^7I]._U\>/?
MX2`B"B+A]?3>(-WWY>D@X?#E[>7QX^_P[^GGZ.7?(./IX2#JW/#OZ>\@Z_SC
M[RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-#`*;7-G:60@(B(*
M(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T
M:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C
M="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T
M<B`B(@HBSR!"<F]W<V5R(//A\B#VX=_MY?3AZ2#MX2#=]^7I(.'KZ]SNY>D@
MX?#\(/3G[2#=[>'Q[N<@].?R("5S(//][>3E\][R(//A\BX@(@HBP^GA(/3G
M[2#P\>_S].'SW^$@].?R(.'S]MSKY>GA\BP@Z.$@\/'=\.7I(.WA(.[A[>'S
M]>WDY>CEW_3E+B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4P"FUS9VED
M(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N
M(@IM<V=S='(@(L\@0G)O=W-E<B#SX?(@Y.7M(/7P[_/TY_'?YN7I(.'U]-X@
M].<@Z^7I]._U\>/?X2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN
M="YJ<SHR-PIM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO3W!T:6]N("L@
M4"!T;R`B"B)P<FEN="XB"FUS9W-T<B`B(@HBSR!"<F]W<V5R(//A\B#DY>T@
M]?#O\_3G\=_FY>D@X?7TWB#TY^T@Y?#IZ^_CWB#EZO3]\/GSY_(N(-#A]-[S
M].4@0V]N=')O;"\B"B)/<'1I;VX@*R!0(./IX2#EZO3]\/GSYRXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0Q"FUS9VED(")9;W5R(&-U<G)E;G0@
M=&EM92!Z;VYE.B(*;7-G<W1R("+'(/3QW??O]?/A(.;^[><@_O'A\CHB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30X"FUS9VED(")9;W5R(&1E9F%U
M;'0@:61E;G1I='DZ(@IM<V=S='(@(L<@\/'OZN'H[_'I\^S=[><@\^'R(/3A
M]?3\].?TX3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@W"FUS9VED
M(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`BU.\@\.O>\>7R(/SM[^S<(//A
M\CHB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@IM<V=I9"`B
M66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R("+/(.W=
M[_(@\^'R(.KYY.GJ_/(@X^GA("5S(.7?[>'I.B`E<R(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,34W"FUS9VED(")9;W5R(&]P=&EO;G,@
M:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E
M<W-I;VXN(@IM<V=S='(@(L_I(.7PZ>OOX]WR(//A\B#=]^_U[2#E[>?LY?'Y
MZ.7?(./IX2#TYR#DZ=SQZN7IX2#A]?3>\B#TY_(@\_WMY.7SY_(N(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-3D*;7-G:60@(EEO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`BS^D@Y?#IZ^_C
MW?(@\^'R(-WW[_7M(.7MY^SE\?GHY=\N(@H*;7-G:60@(EEO=7(@<&%S<W=O
M<F1S(&1O(&YO="!M871C:"(*;7-G<W1R("+/Z2#MW>_I(.KYY.GJ[]\@Y.7M
M(/3AZ?'IW.;O]>TB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW
M-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R
M("+/(.KYY.GJ_/(@\^'R(-SKZ^'NY2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N
M(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R
M(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HBSR#J^>3IZOSR(//A\B#<
MZ^OA[N4L(.7KW>/N].4@].$@[.?M_>SA]-P@\^'R(.KAZ2#JW.WTY2#EW_/O
MY.\@[.4@].\@[=WO(//A\B`B"B+J^>3IZOPN(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S
M.B(*;7-G<W1R("+/Z2#A\._LX>KQ]?/LW>WOZ2#SX?(@Y>[U\.?QY?3G]-WR
M.B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT
M<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5"
M;&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R
M(");P?#\ZO'U^.<@ZN7I[-WM[_4@\^4@Y>GSX>/YX^GJW%TB"@HC.B!S97)V
M:6-E<R]P<F]B;&5M+G!H<#HU-@IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*
M;7-G<W1R(");P>WA]N_QW"#0\>_BZ][LX?3O\ETB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O
M=&5D(%1E>'0@+2(*;7-G<W1R(");Q>SVW.WI\^<@ZN7I[-WM[_4@\^4@Y>GS
MX>/YX^GJW"`M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H
M:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@IM<V=I9"`B6U-H;W<@475O=&5D(%1E
M>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B6\7L]MSMZ?/G(.KEZ>S=[>_U(//E
M(.7I\^'C^>/IZMP@+2`E<R#C\>'L[-WR72(*"B,@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ.3DL(&,M9F]R;6%T"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3DY"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B
M6^/QX>SLWB`E<R#A\/P@)7-=(@H*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*
M;7-G<W1R("+$Z>'WY=_QZ?/G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O
M=R(*;7-G<W1R("+$Z>'C\>'VWB##\>'L[-[R(@H*(SH@;&EB+V%P:2YP:'`Z
M,3$T"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(L_LW.3E\B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.#$*;7-G:60@(E](96QP(@IM
M<V=S='(@(L+OWNCEZ>$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T
M:65S+BXN(@IM<V=S='(@(LGDZ?STY_3E\B#%Z>K\[>'R+BXN(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C(P,`IM<V=I9"`B7TQO9R!I
M;B(*;7-G<W1R("+%W_/OY._R(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TUE;G4N<&AP.C$Y-@IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`BQ>[OY._R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB"FUS9W-T<B`BU/'O
M\._P[]_G\^<@T_WMY.7S[._U+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+TUE;G4N<&AP.C$W,`IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`BQ?#I
MZ^_CW?(B"@HC.B!L:6(O87!I+G!H<#HQ,3@*;7-G:60@(E]097)M:7-S:6]N
M<R(*;7-G<W1R("+%[N_U\^GOY._TWO/EZ?(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]2
M96UO=F4@3&EN:RXN+B(*;7-G<W1R("+$Z>'C\>'VWB#3]>WDW?/L[_4N+BXB
M"@HC.B!L:6(O87!I+G!H<#HQ,#8*;7-G:60@(E]3971U<"(*;7-G<W1R("+1
M]>CLW_/EZ?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S(*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN
M(@IM<V=S='(@(LGDZ?STY_3E\B#0W^WAZN$N+BXB"@HC.B!L:6(O87!I+G!H
M<#HQ,3`*;7-G:60@(E]5<V5R<R(*;7-G<W1R("+7\=[S].7R(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3$*;7-G:60@(F%D9')E<W,@8F]O
M:R(*;7-G<W1R("+$Z>7UZ/7M\^GOX_'<]N_R(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,#,*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(L?L
MY?'OZ_SCZ>\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,"!L:6(O0FQO
M8VLO;65T87(N<&AP.C,U-@IM<V=I9"`B8V%L;2(*;7-G<W1R("+G\>7LW^$B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HV,#@*;7-G
M:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B\.'TWO/TY2#EY/XB"@HC.B!F<F%M
M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-S`*;7-G:60@(F9I;&4B"FUS
M9W-T<B`BX?'WY=_O(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-3@@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.#0*
M;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`BX?#\
M(/3O("5S("@E<RD@\_3I\B`E<R`E<R(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR,S(*;7-G:60@(F@Z(@IM<V=S='(@(F@Z
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU.#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C(Y"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`BW.SE\^$B"@HC
M.B!A9&UI;B]S971U<"]D:69F+G!H<#HV."!A9&UI;B]S971U<"]D:69F+G!H
M<#HW-@IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(N7M\_GLX?3Y[-WM[R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED
M(")L:6YE<UTB"FUS9W-T<B`BX_'A[.S=\ETB"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-30*;7-G:60@(FUK
M:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R
M(")M:VES;V9S+>KYY.GJ_/(@Z]SH[_7R("5D(.KA]-P@].<@Y.?LZ>_U\>/?
MX2!)4T\N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR.#@@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(P-@IM<V=I9"`B;F%M92(*
M;7-G<W1R("+\[>_LX2(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C(*
M;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R("+DY>T@W??EZ2#EX^KA
M].'S].'HY=\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C$R-#4*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`BY.7M
M(-WWY>D@Y>/JX?3A\_3AZ.7?(.'J_.SG(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HX.34*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B\^?LY>GY
M[.'TW/'I[R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B]._I\B#E
MZN'T_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R("+EZ>KO[>_S]._I
M]^7?X2(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.3@*;7-G:60@(G-H
M;W<@9&EF9F5R96YC97,B"FUS9W-T<B`BY>SVW.WI\^<@Y.GA]N_Q_NTB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S
M,PIM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(G-M<R#SY2!E
M;6%I;"#LW?/Y($A45%`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S8T"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B\_3AZ.7Q_/(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ.0IM<V=I9"`B=&%S:R!L:7-T
M(@IM<V=S='(@(NO?\_3A(.7QX^'SZ?[M(@H*;7-G:60@(G1R87-H(@IM<V=S
M='(@(NK<Y._R(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.C(X,@IM<V=I9"`B='EP92!T:&4@<&%S<W=O
M<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R("+#\=SX].4@]._M(.KYY.GJ
M_"#D_>\@]N_QW?(@X^GA(.7PZ>+EXN'?^?/G(@H*(SH@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z-C@@861M:6XO<V5T=7`O9&EF9BYP:'`Z-S8*;7-G:60@(G5N
M:69I960B"FUS9W-T<B`BY>WO\._IY^S=[>$B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U!A<G0N<&AP.C$W"FUS9VED(")U;FYA;65D(@IM<V=S='(@(N'M
M_NWU[.$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4X-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,CD*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(N7P
MZ>OOX]X@]_'>\_3G(@H*;7-G:60@(G9#87)D(@IM<V=S='(@(MCG]NGAZMX@
MRMSQ].$B"@``````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P;R]E<U]%4RYP;P``````````````````````````
M`````````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-S$V,C<S`#$P-3$U-#,S-S4T
M`#`Q-S8U,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````C(%-P86YI<V@@=')A;G-L871I;VYS(&9O<B!H;W)D92!P86-K86=E
M"B,@5')A9'5C8VEO;F5S(&%L(&5S<&'Q;VP@<&%R82!E;"!P87%U971E(&AO
M<F1E+@HC($-O<'ER:6=H="`H0RD@,C`P-"!(;W)D92!0<F]J96-T"B,@5&AI
M<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@
M87,@=&AE(&AO<F1E('!A8VMA9V4N"B,@075T;VUA=&EC86QL>2!G96YE<F%T
M960L(#(P,#0N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E
M<G-I;VXZ($AO<F1E(#,N,"UC=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O
M.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@
M,C`P-BTP-2TQ."`P.#HQ-RLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R
M,#`V+3`R+3$U(#$W.C(T*S`Q,#!<;B(*(DQA<W0M5')A;G-L871O<CH@36%N
M=65L(%`N($%Y86QA(#QM87EA;&%`=6YE>"YE<SY<;B(*(DQA;F=U86=E+51E
M86TZ(&DQ.&Y`;&ES=',N:&]R9&4N;W)G7&XB"B)-24U%+59E<G-I;VXZ(#$N
M,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX
M.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*
M(E!L=7)A;"U&;W)M<SH@;G!L=7)A;',],CL@<&QU<F%L/2AN("$](#$I.UQN
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B("AH86-E("5S(&3M87,I
M(@H*(SH@;&EB+TAO<F1E+G!H<#HQ,S@S"B,L('!H<"UF;W)M870*;7-G:60@
M(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(@*$%C8V5D:65N9&\@82`E<RDB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B`H96X@)7,@9.UA<RDB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W,PIM<V=I9"`B("AT;V1A>2DB"FUS
M9W-T<B`B("AH;WDI(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S4*;7-G
M:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(B`H;6'Q86YA*2(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,S<Q"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T
M<B`B("AA>65R*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U,`HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDV"FUS9VED("(@870@(@IM<V=S='(@
M(F5N("(*"B,Z(&QI8B]61E,O<VUB+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B7"(E
M<UPB(&YO(&5S('5N(&1I<F5C=&]R:6\N(@H*(SH@;&EB+TAO<F1E+T-,22YP
M:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V
M86QI9"!C:&]I8V4N(@IM<V=S='(@(EPB)7-<(B!N;R!E<R!U;F$@96QE8V-I
M\VX@=N%L:61A+B(*"B,Z(&QI8B](;W)D92]296=I<W1R>2YP:'`Z-S$P(&QI
M8B](;W)D92]296=I<W1R>2YP:'`Z,3`Y.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES
M=')Y+B(*;7-G<W1R(").;R!S92!H82!C;VYF:6=U<F%D;R!<(B5S7"(@96X@
M96P@<F5G:7-T<F\@9&4@2&]R9&4N(@H*(SH@;&EB+TAO<F1E+U1R964N<&AP
M.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E
M<B!N;W0@9F]U;F0N(@IM<V=S='(@(DYO('-E(&5N8V]N='+S(&5L(&=E;F5R
M861O<B!D92#A<F)O;&5S(&1E(%PB)7-<(BXB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@
M=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(E-E(&AA(&'Q861I9&\@
M7"(E<UPB(&%L('-I<W1E;6$@9&4@9W)U<&]S+B(*"B,Z(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@
M(E-E(&AA(&'Q861I9&\@7"(E<UPB(&%L('-I<W1E;6$@9&4@<')I=FEL96=I
M;W,N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C
M:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N
M;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(DYO('-E(&AA(&-R96%D;R!<(B5S
M7"(Z("5S+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H
M)2XR9B4E*2(*;7-G<W1R(")5<V%D;W,@)2XR9DU"(&1E("4N,F9-0B!P97)M
M:71I9&]S("@E+C)F)24I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(R-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS
M9W-T<B`B)60@)7,@>2`E<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU
M.30@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,C8X"B,L('!H<"UF;W)M870*
M;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*
M;7-G<W1R(")1=65D86X@)60@9.UA<R!H87-T82!Q=64@97AP:7)E(&QA(&-O
M;G1R87-E\6$N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T
M<B`B)60@<')O;O-S=&EC;W,@9&EA<FEO<R(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC
M92(*;7-G<W1R("(E<R`M($%V:7-O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HW,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I
M;G0B"FUS9W-T<B`B2'5E;&QA(&1I9VET86P@9&4@)7,B"@HC.B!L:6(O2&]R
M9&4O34E-12]#;VYT96YT<RYP:'`Z.#0R(&QI8B](;W)D92]-24U%+T-O;G1E
M;G1S+G!H<#HX-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T
M<B`B)7,@2T(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M
M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R!O<&5R86-I;VYE<R!D92!M86YT
M96YI;6EE;G1O("T@0V]N9FER;6%C:?-N(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$T"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(D-O;F9I9W5R86-I\VX@
M9&4@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V-`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(D9I<FUA(&1E
M("5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R(")!
M8W5E<F1O<R!D92!L:6-E;F-I82!D92`E<R(*"B,Z(&QI8B]61E,O9G1P+G!H
M<#HV.3`@;&EB+U9&4R]F='`N<&AP.C<V,R!L:6(O5D93+W-M8BYP:'`Z-#0Q
M"B,Z(&QI8B]61E,O<VUB+G!H<#HU,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(EEA(&5X:7-T92`E<RXB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V-B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,U,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(E<R!A(&QA<R`E<R`E
M<R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN
M=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B
M"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R
M;2!A="!T:&ES('1I;64N(@IM<V=S='(@(B(*(B5S(&5S=.$@<')E<&%R861O
M('!A<F$@<F5A;&EZ87(@;&%S(&]P97)A8VEO;F5S(&1E(&UA;G1E;FEM:65N
M=&\@(@HB<V5L96-C:6]N861A<RY!8W1I=F4@;&%S(&-A<VEL;&%S(&1E(&QA
M<R!O<&5R86-I;VYE<R!Q=64@9&5S96$@96IE8W5T87(@96X@(@HB97-T82!O
M8V%S:?-N+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S0P"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(DAA8V4@9F%L
M=&$@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(B5S(&UI;G5T;W,B"@HC
M.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3,R"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B3F\@<V4@:&$@
M96YC;VYT<F%D;R`E<RXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM
M<V=S='(@(B5S(&%L("5S(&1E("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HY,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB
M"FUS9W-T<B`B1&ER96-C:6]N97,@9&4@)7,B"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.CDQ.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R
M(@IM<V=S='(@(D%G96YD82!D92`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z.3$P"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G
M<W1R("),:6)R971A(&1E(&YO=&%S(&1E("5S(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES
M="(*;7-G<W1R(")487)E87,@9&4@)7,B"@HC.B!L:6(O2&]R9&4O3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]H=&UL+G!H<#HQ,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C
M;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS
M(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E
M<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"B(E<SH@17-T92!M96YS
M86IE('!U961E('%U92!N;R!P<F]C961A(&1E('%U:65N('!A<F5C92!S97(N
M($5V:71E('-E9W5I<B`B"B)C=6%L<75I97(@=NUN8W5L;R!I;F-L=>UD;R!O
M('-U;6EN:7-T<F%R(&-U86QQ=6EE<B!I;F9O<FUA8VGS;B!P97)S;VYA;"!A
M;"`B"B)R96UI=&5N=&4N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,U-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDY"FUS9VED
M("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@=F5N=&]S;R`B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$Y-2!L:6(O0FQO8VLO;65T87(N<&AP.C(P,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B+"!V
M96YT;W-O("5S("5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM
M<V=S='(@(BP@=F%R:6%B;&4@9&4@)7,@82`E<R(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,#8Y(&QI8B](;W)D92]&;W)M+G!H<#HR,3(X"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HW-#@@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HR.30*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS-#@*
M;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(M+2!S96QE8V-I;VYA<B`M
M+2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&
M;W)M870B"FUS9W-T<B`B1F]R;6%T;R!D92`Q,B!H;W)A<R(*"B,Z(&QI8B]"
M;&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T
M<B`B1F]R;6%T;R!D92`R-"!H;W)A<R(*"B,Z('1E;7!L871E<R]D871A+W1I
M;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"!H;W)A<R(*
M"B,Z(&QI8B](;W)D92]522]086=E<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U
M<R(*;7-G<W1R("(\06YT97)I;W(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$R-@IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O
M<B!T:&ES(&)L;V-K+B(*;7-G<W1R(")087)A(&5S=&4@8FQO<75E(&AA8V4@
M9F%L=&$@=6X@;6]T;W(@9&4@8F%S92!D92!D871O<RXB"@HC.B!L:6(O2&]R
M9&4N<&AP.C$W,0IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B
M"FUS9W-T<B`B4V4@:&$@<')O9'5C:61O('5N(&5R<F]R(&ER<F5P87)A8FQE
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U
M8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E
M+B(*;7-G<W1R(")(86-E(&9A;'1A('5N82!C;&%V92!01U`@</IB;&EC82!P
M87)A(&-I9G)A<B!U;B!M96YS86IE+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C$Q-C@*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER
M960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(DAA8V4@
M9F%L=&$@=6YA(&-L879E(%!'4"!P^F)L:6-A('!A<F$@8V]M<')O8F%R('5N
M(&UE;G-A:F4@9FER;6%D;RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HQ,#DY"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'
M4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T
M(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB2&%C96X@9F%L=&$@=6YA(&-L
M879E(%!'4"!P^F)L:6-A+"!U;F$@8VQA=F4@4$=0('!R:79A9&$@>2!U;F$@
M9G)A<V4@8VQA=F4@(@HB<&%R82!D97-C:69R87(@=6X@;65N<V%J92XB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#$V"FUS9VED("(B"B)!('!U
M8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B
M(@HB2&%C96X@9F%L=&$@=6YA(&-L879E(%!'4"!P^F)L:6-A+"!U;F$@8VQA
M=F4@4$=0('!R:79A9&$@>2!U;F$@9G)A<V4@8VQA=F4@(@HB<&%R82!F:7)M
M87(@=6X@;65N<V%J92XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4P-@IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3
M+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB
M9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*(DAA8V5N(&9A;'1A('5N
M82!C;&%V92!3+TU)344@</IB;&EC82P@=6YA(&-L879E(%,O34E-12!P<FEV
M861A('D@=6YA(&9R87-E("(*(F-L879E('!A<F$@9&5S8VEF<F%R('5N(&UE
M;G-A:F4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G
M:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M
M97-S86=E+B(*;7-G<W1R("(B"B)(86-E;B!F86QT82!U;F$@8VQA=F4@4R]-
M24U%('#Z8FQI8V$L('5N82!C;&%V92!3+TU)344@<')I=F%D82!Y('5N82!F
M<F%S92`B"B)C;&%V92!P87)A(&9I<FUA<B!U;B!M96YS86IE+B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!3
M34E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM
M<V=S='(@(DAA8V4@9F%L=&$@=6YA(&-L879E(%--24U%('#Z8FQI8V$@<&%R
M82!C:69R87(@=6X@;65N<V%J92XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B
M3G5B97,@;6%T:6YA;&5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`B
M3&EG97)A(&QL=79I82!M871I;F%L(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B
M3&QU=FEA(&UA=&EN86PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R(")!9W5A
M8V5R;W,@;6%T:6YA;&5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R
M(")!9W5A8V5R;R!M871I;F%L(&1E(&YI979E(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(D%-+U!-(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@
M(D%022!)1"(*;7-G<W1R("))1"!D92!!4$DB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES
M(&5D:71O<B(*;7-G<W1R(")!8V5R8V$@9&5L(&5D:71O<B(*"B,Z('-E<G9I
M8V5S+VAE;'`O:6YD97@N<&AP.C4S"FUS9VED(")!8F]U="XN+B(*;7-G<W1R
M(")!8V5R8V$@9&4N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B26YF
M97)I;W(@06)S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R(")%;B!M961I
M;R!!8G,N(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,C@R"FUS9VED(")!8V-E
M<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(E-E
M(&AA(&1E;F5G861O(&5L(&%C8V5S;R!A;"!C<F5A<B!E;"!D:7)E8W1O<FEO
M(%9&4RXB"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S
M<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(E-E(&AA(&1E
M;F5G861O(&5L(&%C8V5S;R!A;"!C<F5A<B!E;"!A<F-H:79O(%9&4RXB"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PIM<V=I9"`B06-C;W5N="!);F9O
M<FUA=&EO;B(*;7-G<W1R("))9&5N=&ED860B"@HC.B!C;VYF:6<O+F)A:R]P
M<F5F<RYP:'`N9&ES=#HW.`IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G
M<W1R(")#;VYT<F%S9?%A(&1E(&%C8V5S;R(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB
M"FUS9W-T<B`B261E;G1I9&%D(&)L;W%U96%D82XB"@HC.B!C;VYF:6<O+F)A
M:R]R96=I<W1R>2YP:'`N9&ES=#HS,S4*;7-G:60@(D%C8V]U;G1I;F<B"FUS
M9W-T<B`B0V]N=&%B:6QI9&%D(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS
M9W-T<B`B0?%A9&ER(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO
M9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R
M(")!\6%D:7(@9W)U<&\@9&5S8V5N9&EE;G1E(@H*(SH@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HY."!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.CDY"FUS9VED
M(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R(")!\6%D:7(@<')I=FEL
M96=I;R!D97-C96YD:65N=&4B"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI
M;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(D'Q861I<B!A<77M.B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y
M"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(D'Q861I<B!G<G5P;R(*
M"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z.#<@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@
M(D'Q861I<B!P<FEV:6QE9VEO(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]A9&1C:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C
M:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B0?%A9&ER(&$@7"(E<UPB
M('5N(&=R=7!O(&1E<V-E;F1I96YT92(*"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E
M<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(D'Q861I<B!A(%PB)7-<(B!U
M;B!P<FEV:6QE9VEO(&1E<V-E;F1I96YT92(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B0?%A9&ER('5N
M('5S=6%R:6\Z(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C4U-@IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R(")!\6%D:7(@8V]L
M=6UN82(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*
M;7-G:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R(")!\6%D:7(@;6EE;6)R
M;W,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!
M9&0@<&%I<B(*;7-G<W1R(")!\6%D:7(@<&%R(@H*(SH@8V]N9FEG+RYB86LO
M<')E9G,N<&AP+F1I<W0Z,S<Q"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T
M:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R(")!\6%D
M:7(@96P@;65N^B`E<R!C;VUO('!A;F5L(&QA=&5R86P@9&4@36]Z:6QL82(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@
M(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(D'Q861I<B!A(&QA<R!D
M:7)E8V-I;VYE<SHB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C<X"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@
M(D'Q861I<B!A(&QA<R!D:7)E8V-I;VYE<SHB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`B0?%A9&ER('5S=6%R:6\B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A
M9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G
M<W1R("(B"B)392!H82!A\6%D:61O(%PB)7-<(B!A;"!S:7-T96UA+"!P97)O
M(&YO('-E('!U961E(&'Q861I<B!L82!I;F9O<FUA8VGS;B`B"B)A9&EC:6]N
M86P@9&4@86QT83H@)7,N(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A
M;B!L;V<@:6X@;F]W+B(*;7-G<W1R(")392!H82!A\6%D:61O(%PB)7-<(B!A
M;"!S:7-T96UA+B!982!P=65D92!I;FEC:6%R(&QA('-E<VGS;BXB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG
M('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("),82!A9&EC:?-N(&1E('5S
M=6%R:6]S(&5S=.$@9&5S:&%B:6QI=&%D82XB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,30T,2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R
M-@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,PIM<V=I
M9"`B061D<F5S<R(*;7-G<W1R(")$:7)E8V-I\VXB"@HC.B!C;VYF:6<O+F)A
M:R]R96=I<W1R>2YP:'`N9&ES=#HQ-#$*;7-G:60@(D%D9')E<W,@0F]O:R(*
M;7-G<W1R(")$:7)E8V-I;VYE<R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HY-"!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z
M-38*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T
M:&5R('5S97)S(@IM<V=S='(@(D%D;6EN:7-T<F%D;W(@+2!D969I;F4@<')I
M=FEL96=I;W,@9&4@;W1R;W,@=7-U87)I;W,B"@HC.B!A9&UI;B]I;F1E>"YP
M:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q-PIM<V=I9"`B
M061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R86-I\VXB"@HC.B!C
M;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HS-#,*;7-G:60@(D%D<R(*
M;7-G<W1R(")!;G5N8VEO<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3@*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@
M(D%F9V%N:7-TX6XB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(Q"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(D%L8F%N:6$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<T
M"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(D%R9V5L:6$B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS
M9W-T<B`B06QI87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R(")!;&EN
M96%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R(")!;&EN96%C:?-N.B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S
M='(@(E1O9&]S(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR,#<@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I
M8V%T960@57-E<G,B"FUS9W-T<B`B5&]D;W,@;&]S('5S=6%R:6]S(&%U=&5N
M=&EF:6-A9&]S(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U
M<',N<&AP.C(R,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R(")4;V1O<R!L
M;W,@9W)U<&]S(@H*(SH@;&EB+TAO<F1E+U!E<FUS+V1A=&%T<F5E+G!H<#HW
M-2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.CDQ"FUS9VED(")!;&P@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B5&]D;W,@;&]S('!R:79I;&5G:6]S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM
M<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B5&]D;W,@;&]S(&QA9&]S
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S$*;7-G:60@(D%L;&]W(&UU
M;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R(")097)M:71I<B!V87)I87,@9&ER
M96-C:6]N97,B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HU,S@*
M;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM
M<V=S='(@(K]097)M:71I<B!C;VYF:6=U<F%C:?-N(&1E('1I<&\@9&4@;&ES
M=&%S(&]R9&5N861A<S\B"@HC.B!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H
M<#HU,#0*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(EEA(&5X:7-T
M92(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$R-@IM<V=I9"`B
M06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B06-C97-O($E-4U`@86QT
M97)N871I=F\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HU,3$*
M;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(D-L879E
M($E-4U`@86QT97)N871I=F$B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N
M9&ES=#HU,#,*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S
M='(@(E5S=6%R:6\@24U04R!A;'1E<FYA=&EV;R(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D
M<F5S<R(*;7-G<W1R(")$:7)E8V-I\VX@96QE8W1R\VYI8V$@86QT97)N871I
M=F$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N
M871E('1E;7!L871E<R(*;7-G<W1R(")0;&%N=&EL;&%S(&%L=&5R;F%T:79A
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R,@IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@
M(E1E>'1O(&%L=&5R;F%T:79O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-PIM<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS
M9W-T<B`B4V%M;V$@06UE<FEC86YA(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)
M+G!H<#HY-2!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@
M:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R(")392!H82!I
M;F1I8V%D;R!U;B!V86QO<B!I;&5G86PN(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$U-0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@
M;V-C=7)E9"XB"FUS9W-T<B`B4V4@:&$@<')O9'5C:61O('5N(&5R<F]R(&1E
M<V-O;F]C:61O+B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,38*;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B06YD;W)R82(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0*
M;7-G:60@(D%N9V]L82(*;7-G<W1R(")!;F=O;&$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HU-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P"FUS9VED(")!;F=U:6QL
M82(*;7-G<W1R(")!;F=U:6QA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B4')O>'D@
M86[S;FEM;R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS
M9VED(")!;G-W97(B"FUS9W-T<B`B4F5S<'5E<W1A(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-0IM<V=I9"`B06YT87)C
M=&EC82(*;7-G<W1R(")!;G3A<G1I9&$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y"FUS9VED(")!;G1I9W5A(&%N9"!"
M87)B=61A(@IM<V=S='(@(D%N=&EG=6$@>2!"87)B861O<R(*"B,Z(&%D;6EN
M+W!H<'-H96QL+G!H<#HS-B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&QI8B](
M;W)D92]";&]C:R]522YP:'`Z-3@*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B07!L
M:6-A8VGS;B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B
M07!P;&EC871I;VX@3&ES="(*;7-G<W1R("),:7-T82!D92!A<&QI8V%C:6]N
M97,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,Y"FUS9VED(")!<'!L
M:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B3&$@87!L:6-A8VGS;B!E<W3A
M(&QI<W1A+B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS
M9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B07!L:6-A<B!A
M(')E8W5R<V]S(&-O;7!A<G1I9&]S(&1E<V-E;F1I96YT97,B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V
M92(*;7-G<W1R(")!<')O8F%R(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N
M=',N<&AP.C@T,@IM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R(")4
M86UA\6\@87!R;WAI;6%D;R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R(")!8G)I;"(*"B,Z(&-O;F9I
M9R\N8F%K+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D%R86)I8R`H5VEN9&]W
M<RTQ,C4V*2(*;7-G<W1R(")!<N%B:6=O("A7:6YD;W=S+3$R-38I(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W1G>BYP:'`Z-S@*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C8*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@
M(E1A;6'Q;R!D96P@87)C:&EV;R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R87(N<&AP.C4X(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<W
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"FUS9VED(")!
M<F-H:79E($YA;64B"FUS9W-T<B`B3F]M8G)E(&1E;"!A<F-H:79O(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M
M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R("*_17-T
M82!S96=U<F\@9&4@<75E(&1E<V5A(&5L:6UI;F%R(&QA('-O;&EC:71U9"!D
M92!A;'1A(&1E("5S/R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L
M971E+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y
M;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B
M"FUS9W-T<B`BOT5S=.$@<V5G=7)O(&1E('%U92!D97-E82!E;&EM:6YA<B!<
M(B5S7"(@>2!T;V1O<R!S=7,@<W5B9W)U<&]S/R(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C4X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C8*;7-G:60@(D%R9V5N=&EN
M82(*;7-G<W1R(")!<F=E;G1I;F$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HU-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(R"FUS9VED(")!<FUE;FEA(@IM<V=S='(@
M(D%R;65N:6$B"@HC.B!C;VYF:6<O+F)A:R]N;',N<&AP+F1I<W0Z,3<Y"FUS
M9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R(")!<FUE;FEO("A!
M4DU30TE)+3@I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED
M(")!<G0B"FUS9W-T<B`B07)T92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,S`*;7-G:60@(D%R=6)A(@IM<V=S='(@(D%R
M=6)A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E
M;G-I;VX@27-L86YD(@IM<V=S='(@(DES;&$@07-C96YS:?-N(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T
M<B`B1W+A9FEC;W,@07-C:6DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R(")296=I
M\VX@9&4@07-I82]086/M9FEC;R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H
M<"YD:7-T.C0R.0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E
M(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(B(*(K]3
M;VQI8VET87(@8V]N9FER;6%C:?-N(&%N=&5S(&1E(')E86QI>F%R(&]P97)A
M8VEO;F5S(&1E(&UA;G1E;FEM:65N=&\_(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,P.34*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R(")#
M;VQU;6YA<R!D92!A<VEG;F%C:?-N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW
M-`IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O
M=7`N(@IM<V=S='(@(DEN=&5N=&$@96QI;6EN87(@=6X@9W)U<&\@:6YE>&ES
M=&5N=&4N(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B
M071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB
M"FUS9W-T<B`B26YT96YT82!E;&EM:6YA<B!U;B!P<FEV:6QE9VEO(&EN97AI
M<W1E;G1E+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS
M9W-T<B`B26YT96YT82!M;V1I9FEC87(@=6X@<')I=FEL96=I;R!I;F5X:7-T
M96YT92XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@
M(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T
M<B`B26YT96YT82!M;V1I9FEC87(@=6X@<F5C=7)S;R!C;VUP87)T:61O(&EN
M97AI<W1E;G1E+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP
M.C8T(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@S"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"FUS9VED(")!='1R:6)U=&5S
M(@IM<V=S='(@(D%T<FEB=71O<R(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#D@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B06=O<W1O(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR.0IM<V=I
M9"`B075S=')A;&EA(@IM<V=S='(@(D%U<W1R86QI82(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C4Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C@*;7-G:60@(D%U<W1R
M:6$B"FUS9W-T<B`B075S=')I82(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G-Q
M;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G-Q;#H@3F\@
M<V4@96YC;VYT<O,@;&$@97AT96YS:?-N(&EM87`@;F5C97-A<FEA+B(*"B,Z
M(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER
M=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E
M<RXB"FUS9W-T<B`B075T:%]C>7)U<SH@16P@;6]T;W(@8V%R96-E(&1E(&QA
M<R!C87!A8VED861E<R!N96-E<V%R:6%S+B(*"B,Z(&QI8B](;W)D92]!=71H
M+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM
M87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)U<SH@
M3F\@<V4@96YC;VYT<O,@;&$@97AT96YS:?-N(&EM87`@;F5C97-A<FEA+B(*
M"B,Z(&QI8B](;W)D92]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?
M9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL
M92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T
M<B`B(@HB075T:%]F='`Z($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!&
M5%`@;F5C97-A<FEA+B!#;VUP:6QE(%!(4"!C;VX@;&$@(@HB;W!C:?-N("TM
M96YA8FQE+69T<"XB"@HC.B!L:6(O2&]R9&4O075T:"]I;6%P+G!H<#HV-`IM
M<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA<#H@3F\@<V4@96YC;VYT<O,@;&$@
M97AT96YS:?-N($E-05`@;F5C97-A<FEA+B(*"B,Z(&QI8B](;W)D92]!=71H
M+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]K<F(U.B!.;R!S
M92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@:W)B-2!N96-E<V%R:6$N(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD87`Z
M($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER
M96-T;W)Y(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@3F\@97-TX2!S;W!O<G1A
M9&$@;&$@861I8VGS;B!D92!U<W5A<FEO<R!D92!!8W1I=F4@1&ER96-T;W)Y
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H
M7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C
M=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@HB075T:%]L9&%P.B!.;R!E<W3A
M('-O<&]R=&%D82!L82!E;&EM:6YA8VGS;B!D92!U<W5A<FEO<R!D92!!8W1I
M=F4@1&ER96-T;W)Y(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-C,*
M;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")!=71H7VQD87`Z($YO('-E(&5N8V]N='+S(&QA
M(&5X=&5N<VGS;B!,1$%0(&YE8V5S87)I82XB"@HC.B!L:6(O2&]R9&4O075T
M:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P
M.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60Z("(*;7-G<W1R("(B"B)!=71H7VQD87`Z($YO('-E('!U961E
M(&'Q861I<B!E;"!U<W5A<FEO("5S+B#)<W1O(&5S(&QO('%U92!D:6IO(&5L
M("(*(G-E<G9I9&]R.B`B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS
M.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@
M<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!);F-A<&%Z(&1E
M(&5L:6UI;F%R(&5L('5S=6%R:6\@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]L
M9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5
M;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!)
M;F-A<&%Z(&1E(&%C='5A;&EZ87(@96P@=7-U87)I;R`E<R(*"B,Z(&QI8B](
M;W)D92]!=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A
M=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T
M;W)Y+B(*;7-G<W1R("(B"B)!=71H7VQD87`Z($YO(&5S=.$@<V]P;W)T861A
M(&QA(&%C='5A;&EZ86-I\VX@9&4@=7-U87)I;W,@9&4@06-T:79E($1I<F5C
M=&]R>2(*"B,Z(&QI8B](;W)D92]!=71H+VUC86PN<&AP.C0V"FUS9VED(")!
M=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B075T:%]M8V%L.B!.;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I
M\VX@34-!3"!N96-E<V%R:6$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H
M<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?<VUB875T:#H@3F\@
M<V4@96YC;VYT<O,@;&$@97AT96YS:?-N('-M8F%U=&@@;F5C97-A<FEA+B(*
M"B,Z(&QI8B](;W)D92])34%0+T%D;6EN+G!H<#HQ,#8*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B1F%L
M;/,@;&$@875T96YT:69I8V%C:?-N(&-O;B!E;"!S97)V:61O<B!)34%0+B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED
M(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B1F%L;/,@;&$@875T
M96YT:69I8V%C:?-N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HV-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L
M('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B
M"FUS9W-T<B`B1F%L;/,@;&$@875T96YT:69I8V%C:?-N+B`E<R(*"B,Z(&QI
M8B](;W)D92]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A
M=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R(")%;"!S
M97)V:61O<B!2041)55,@:&$@<F5C:&%Z861O(&QA(&%U=&5N=&EF:6-A8VGS
M;BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#DU"FUS9VED(")!=71H96YT:6-A
M=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B1F%L;/,@;&$@
M875T96YT:69I8V%C:?-N(&-O;B!E;"!S97)V:61O<B!&5%`N(@H*(SH@;&EB
M+U9&4R]S;6(N<&AP.C<P"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@
M4TU"('-E<G9E<B!F86EL960N(@IM<V=S='(@(D9A;&SS(&QA(&%U=&5N=&EF
M:6-A8VGS;B!C;VX@96P@<V5R=FED;W(@4TU"+B(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM
M<V=S='(@(D-A;7!O<R!D:7-P;VYI8FQE<SHB"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HU.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,Q"FUS9VED(")!>F5R8F%I:F%N
M(@IM<V=S='(@(D%Z97)B86EJ86XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R(")%>&-U<V%S($)/
M1D@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(D9O;F1O(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM
M<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R(")#;VQO<B!D92!F;VYD
M;R(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@
M:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(D-O;G1R87-E\6$@:V5R8F5R
M;W,@:6YC;W)R96-T82XB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX
M,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R(").;VUB
M<F4@9&4@=7-U87)I;R!K97)B97)O<R!I;F-O<G)E8W1O+B(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#4*;7-G:60@(D)A
M:&%M87,B"FUS9W-T<B`B0F%H86UA<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S@*;7-G:60@(D)A:')A:6XB"FUS9W-T
M<B`B0F%H<F%I;B(*"B,Z(&-O;F9I9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.#`*
M;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(D+A;'1I8V\@
M*$E33RTX.#4Y+3$S*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,S0*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`B0F%N
M9VQA9&5S:"(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,S,*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(D)A<F)A9&]S(@H*
M(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G
M:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(DYO('-E(&5N8V]N='+S(&5L(&1I<F5C=&]R:6\@8F%S92!D
M92!I;>%G96YE<R!<(B5S7"(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C$Y"FUS9VED(")"87-E;&EN92(*;7-G
M<W1R("),[6YE82!B87-E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HT.0IM<V=I9"`B0F5L87)U<R(*;7-G<W1R(")"96QA
M<G5S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HS-0IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R(")"Z6QG:6-A(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C,R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,`IM<V=I9"`B
M0F5L:7IE(@IM<V=S='(@(D)E;&EZ92(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#`*;7-G:60@(D)E;FEN(@IM<V=S='(@
M(D)E;FEN(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HT,0IM<V=I9"`B0F5R;75D82(*;7-G<W1R(")"97)M=61A<R(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HS-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#8*;7-G
M:60@(D)H=71A;B(*;7-G<W1R(")":'5T86XB"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T
M<B`B0W5M<&QE8?%O<R(*"B,Z(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N
M+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F
M(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DYO('-E
M(&5N8V]N='+S(&5L(&)L;W%U92!<(B5S7"(@9&4@;&$@87!L:6-A8VGS;B!<
M(B5S7"(N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDP"FUS
M9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R(")/<&-I;VYE<R!D92!B;&]Q
M=64B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@
M(D)L;V-K(%1Y<&4B"FUS9W-T<B`B5&EP;R!D92!B;&]Q=64B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O
M;&0B"FUS9W-T<B`B3F5G<FET82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-#,*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B
M0F]L:79I82(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C(P
M-PIM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(DUA<F-A9&]R97,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P
M"FUS9VED(")";W)D97(B"FUS9W-T<B`B0F]R9&4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@
M=&AI8VMN97-S.B(*;7-G<W1R(")'<F]S;W(@9&5L(&)O<F1E.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*
M;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B0F]R9&5S(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C,W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,@IM<V=I9"`B0F]S;FEA
M(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R(")";W-N:6$@2&5R>F5G;W9I;F$B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS
M9W-T<B`B06UB;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C0X"FUS9VED(")";W1S=V%N82(*;7-G<W1R(")";W1S=V%N
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR,@IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(DEN9F5R:6]R(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C,Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-PIM<V=I
M9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R("))<VQA(&1E($)O=79E="(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HT,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#0*;7-G
M:60@(D)R87II;"(*;7-G<W1R(")"<F%S:6PB"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-PIM<V=I9"`B0G)I=&ES:"!)
M;F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(E1E<G)I=&]R:6\@;V-E
MX6YI8V\@9&4@;&$@26YD:6$@8G)I=.%N:6-A(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0R
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,@IM<V=I9"`B0G)U;F5I($1A
M<G5S<V%L86TB"FUS9W-T<B`B0G)U;F5I($1A<G5S<V%L86TB"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,W"FUS9VED(")"
M=6QG87)I82(*;7-G<W1R(")"=6QG87)I82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI
M<W0B"FUS9W-T<B`B3&ES=&$@9&5S;W)D96YA9&$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,V"FUS9VED(")"=7)K:6YA
M($9A<V\B"FUS9W-T<B`B0G5R:VEN82!&87-O(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0U
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS.0IM<V=I9"`B0G5R=6YD:2(*
M;7-G<W1R(")"=7)U;F1I(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP
M+F1I<W0Z-#0V"FUS9VED(")#35,B"FUS9W-T<B`B0TU3(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R
M(")#4D,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM<V=I
M9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B4'5N=&]S(&1E
M(&1I<W1R:6)U8VGS;B!#4D,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E
M<G1I97,N+BXB"FUS9W-T<B`B4')O<&EE9&%D97,@9&4@7V-E;&1A+BXN(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,0IM<V=I9"`B0V%C
M:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B3F\@<V4@:&$@
M9FEN86QI>F%D;R!E;"!I;FEC:6\@9&4@;&$@8V%C:.DN(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HY,38@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0X-0HC.B!C;VYF:6<O+F)A:R]H;V]K<RYP:'`N9&ES=#HQ,#0P
M(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C$U-PIM<V=I9"`B0V%L
M96YD87(B"FUS9W-T<B`B06=E;F1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(S-0IM<V=I9"`B0V%L;2(*;7-G<W1R(")#86QM82(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HT-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(X"FUS
M9VED(")#86UB;V1I82(*;7-G<W1R(")#86UB;WEA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C0W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,`IM<V=I9"`B0V%M97)O
M;VXB"FUS9W-T<B`B0V%M97+Z;B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C,R
M(&QI8B]61E,O9G1P+G!H<#HV-S8@;&EB+U9&4R]S;6(N<&AP.C0S-0HC.B!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HR,#,*;7-G:60@(D-A;B!N;W0@8V]P>2!F
M:6QE*',I("T@<V]U<F-E(&%N9"!D97-T:6YA=&EO;B!A<F4@=&AE('-A;64N
M(@IM<V=S='(@(B(*(DYO('-E('!U961E*&XI(&-O<&EA<B!E;"]L;W,@87)C
M:&EV;RAS*2`M(&]R:6=E;B!Y(&1E<W1I;F\@<V]N(&5L(&UI<VUO+B(*"B,Z
M(&QI8B]61E,O9FEL92YP:'`Z,C`R(&QI8B]61E,O9G1P+G!H<#HW-3(@;&EB
M+U9&4R]S;6(N<&AP.C4P,0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-C@*
M;7-G:60@(D-A;B!N;W0@;6]V92!F:6QE*',I("T@9&5S=&EN871I;VX@:7,@
M=VET:&EN('-O=7)C92XB"FUS9W-T<B`B(@HB3F\@<V4@<'5E9&4H;BD@=')A
M<VQA9&%R(&5L+VQO<R!A<F-H:79O*',I("T@96P@9&5S=&EN;R!E<W3A(&1E
M;G1R;R!D96P@(@HB;W)I9V5N+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M
M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("(B"B).;R!S92!P=65D92!R96%J=7-T87(@;&$@8VQA=F4@875T;VWA=&EC
M86UE;G1E+"!P\VYG87-E(&5N(&-O;G1A8W1O(&-O;B!E;"`B"B)A9&UI;FES
M=')A9&]R(&1E;"!S:7-T96UA+B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,S4P
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<
M(B5S7"(B"FUS9W-T<B`B3F\@<V4@<'5E9&4@97-C<FEB:7(@96X@96P@87)C
M:&EV;R!<(B5S7"(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@
M(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB
M"FUS9W-T<B`B3F\@<V4@<'5E9&5N(&%D;6EN:7-T<F%R(&UA;F5J861O<F5S
M(&1E('-E<VGS;B!E>'1E<FYO<RXB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)S
M<6PN<&AP.C,Q.2!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,C,U"B,L('!H
M<"UF;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z
M("5S(@IM<V=S='(@(DYO('-E('!U961E(&-O;F5C=&%R(&%L('-E<G9I9&]R
M($E-05`Z("5S(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT-#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M3F\@<V4@<'5E9&4@86)R:7(@96P@87)C:&EV;R!<(B5S7"(N(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C0X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,0IM<V=I9"`B
M0V%N861A(@IM<V=S='(@(D-A;F%DX2(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P
M,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8U('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R
M+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,0IM<V=I9"`B
M0V%N8V5L(@IM<V=S='(@(D-A;F-E;&%R(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R
M="(*;7-G<W1R(")#86YC96QA<B!I;F9O<FUE(&1E('!R;V)L96UA<R(*"B,Z
M(&QI8B]61E,O9G1P+G!H<#HS,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F\@<V4@<'5E9&4@
M96QI;6EN87(@96P@87)C:&EV;R!<(B5S7"(N(@H*(SH@;&EB+U9&4R])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"B,Z(&QI8B]6
M1E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"FUS
M9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S
M='(@(DYO('-E(&5N8W5E;G1R82!U;B!D:7)E8W1O<FEO('1E;7!O<F%L+B(*
M"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R
M;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R
M(").;R!S92!P=65D92!C;VYT:6YU87(@<VEN(&5L('!A<N%M971R;R`G=&%R
M9V5T1FEL92<N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,Q.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM
M<V=S='(@(DYO('-E('!U961E(&5L:6UI;F%R(&5L(&1I<F5C=&]R:6\@7"(E
M<UPB+B(*"B,Z(&QI8B](;W)D92]$871A5')E92YP:'`Z,3(X(&QI8B](;W)D
M92]$871A5')E92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B3F\@
M<V4@<'5E9&4@96QI;6EN87(L('1I96YE("5D(&1E<V-E;F1I96YT97,N(@H*
M(SH@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#
M86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R
M(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS
M9W-T<B`B(@HB3F\@<V4@<'5E9&4@<F5O<F1E;F%R+"!E;"!N^FUE<F\@9&4@
M96YT<F%D87,@<75E('-E(&1E<V5A(&]R9&5N87(@;F\@(@HB8V]I;F-I9&4@
M8V]N(&QA<R!A;&UA8V5N861A<RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@
M=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B3F\@<V4@<'5E9&4@9&ER
M:6=I<B!E;"!M96YS86IE(&%L(&[Z;65R;R!E<W!E8VEF:6-A9&\N(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C0Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-0IM<V=I
M9"`B0V%P92!697)D92(*;7-G<W1R(")#86)O(%9E<F1E(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`IM<V=I
M9"`B0V%P=&EO;B(*;7-G<W1R(")3=6)T[71U;&\B"@HC.B!L:6(O3F5T+U--
M4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*;7-G<W1R
M(")0<F]V965D;W(B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HY
M,PIM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(D-A=&5G
M;W+M87,@>2!E=&EQ=65T87,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$S-0IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS
M9W-T<B`B27-L87,@0V%I;>%N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B5&5L
MZ69O;F\@;?-V:6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(U"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS
M9W-T<B`B4')O<&EE9&%D97,@9&4@8V5L9&$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D
M:6YG.B(*;7-G<W1R(")-87)G96X@9&4@8V5L9&$Z(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B
M0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(E!R;W!I961A9&5S(&1E(&-E;&1A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B17-P86-I861O(&1E
M(&-E;&1A.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C<T"FUS9VED(")#
M96QL<&AO;F4B"FUS9W-T<B`B5&5LZ69O;F\@;?-V:6PB"@HC.B!C;VYF:6<O
M+F)A:R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#96QT:6,@*$E33RTX.#4Y
M+3$T*2(*;7-G<W1R(")#Z6QT:6-O("A)4T\M.#@U.2TQ-"DB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS
M9VED(")#96YT97(B"FUS9W-T<B`B0V5N=')A<B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU
M,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-30*;7-G:60@(D-E;G1R86P@
M069R:6-A;B!297!U8FQI8R(*;7-G<W1R(")297#Z8FQI8V$@0V5N=')O869R
M:6-A;F$B"@HC.B!C;VYF:6<O+F)A:R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED
M(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R(")%=7)O
M<&$@0V5N=')A;"`H25-/+3@X-3DM,BDB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G
M<W1R(")$971A;&QE<R!D96P@8V5R=&EF:6-A9&\B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C8Q,@IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B
M"FUS9W-T<B`B4')O<&EE=&%R:6\@9&5L(&-E<G1I9FEC861O(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-E<G1I9FEC871E
M(%!O;&EC:65S(@IM<V=S='(@(E!O;.UT:6-A<R!D96P@8V5R=&EF:6-A9&\B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C4R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,C$*;7-G:60@(D-H860B"FUS9W-T<B`B0VAA9"(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.38*;7-G:60@(D-H86YG92(*;7-G<W1R(")#86UB:6%R(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"FUS9VED(")#:&%N9V4@66]U
M<B!087-S=V]R9"(*;7-G<W1R(")#86UB:64@;&$@8V]N=')A<V7Q82(*"B,Z
M(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C8Y"FUS9VED("(B"B)#:&%N
M9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@
M=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T
M<B`B(@HB0V%M8FEA(&5L(&YO;6)R92!Y(&QA(&1I<F5C8VGS;B!E;&5C='+S
M;FEC82!V:7-I8FQE<R!A;"!L965R(&\@<F5S<&]N9&5R(&$@(@HB<W5S(&UE
M;G-A:F5S+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM
M<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R
M=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A
M8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B),82!C;VYF:6=U
M<F%C:?-N(&%C='5A;"!N;R!S;W!O<G1A(&5L(&-A;6)I;R!D92!C;VYT<F%S
M9?%A<RX@4/-N9V%S92!E;B`B"B)C;VYT86-T;R!C;VX@96P@861M:6YI<W1R
M861O<B!D96P@<VES=&5M82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@
M(D=RX69I8V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S
M='(@(E9E<FEF:6-A<B!?=NUN8W5L;RXN+B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,PHC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3D*;7-G:60@(D-H:6QE(@IM<V=S
M='(@(D-H:6QE(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HV,0IM<V=I9"`B0VAI;F$B"FUS9W-T<B`B0VAI;F$B"@HC.B!C
M;VYF:6<O+F)A:R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#:&EN97-E(%-I
M;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B0VAI;F\@<VEM<&QI9FEC861O
M("A'0C(S,3(I(@H*(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD:7-T.C$X-`IM
M<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B0VAI
M;F\@=')A9&EC:6]N86P@*$)I9S4I(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P
M<"YI;F,Z-PIM<V=I9"`B0VAO;W-E($%P<&QI8V%T:6]N.B(*;7-G<W1R(")!
M<&QI8V%C:?-N.B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C<P
M"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R(")%;&EJ82!U;F$@
M8V]N=')A<V7Q82(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8Y
M"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R(")%;&EJ82!U;B!N
M;VUB<F4@9&4@=7-U87)I;R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD
M:7-T.C,P,@IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*
M;7-G<W1R(")%;&EJ82!C\VUO(&UO<W1R87(@;&%S(&9E8VAA<SHB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E
M9"!L:7-T<RDB"FUS9W-T<B`B4V5L96-C:6]N87(@=&EP;R!D92!E<W1I;&\@
M9&4@;&ES=&$@*'!A<F$@;&ES=&%S(&]R9&5N861A<RDB"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-34*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8V"FUS9VED(")#:')I
M<W1M87,@27-L86YD(@IM<V=S='(@(DES;&$@9&4@4&%S8W5A(@H*(SH@;&EB
M+U9&4RYP:'`Z.3$T(&QI8B].970O4TU3+G!H<#HR.30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM
M<V=S='(@(DYO('-E(&5N8V]N='+S(&QA(&1E9FEN:6-I\VX@9&4@8VQA<V4@
M9&4@)7,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,30*;7-G:60@(D-L96%R(@IM<V=S='(@(DQI;7!I87(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#
M;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(D5L:6UI;F%R(&5T:7%U971A
M<R!-4T]F9FEC92(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,CD*;7-G:60@
M(D-L96%R(%%U97)Y(@IM<V=S='(@(D)O<G)A<B!C;VYS=6QT82(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*
M;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R(")";W)R87(@=7-U
M87)I;SH@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B0F]R<F%R('5S=6%R:6\B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B
M0VQE87(@=7-E<B!D871A(@IM<V=S='(@(D)O<G)A<B!D871O<R!D96P@=7-U
M87)I;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$U"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(D1E<W!E:F%D;R!T
M87)D[6\B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N
M:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B2&%G
M82!C;&EC:R!P87)A('-E9W5I<B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM
M<V=S='(@(D-L:6-K871E;&P@<&]R($A45%`B"@HC.B!S97)V:6-E<R]K97EB
M;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G
M:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R(")#97)R87(@=F5N=&%N82(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Q"FUS9VED(")#;&]U9',B"FUS9W-T
M<B`B3G5B97,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(DYU8F5S('1E
M;7!R86YA<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B;G5B;W-O(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C4V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,@IM<V=I9"`B
M0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B27-L87,@9&4@8V]C
M;W,@*$ME96QI;F<I(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN
M8SHR,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R(")/8W5L=&%R
M(&)A<G)A(&QA=&5R86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R
M<R(*;7-G<W1R(")#;VQA<'-A<B!B;W)D97,B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8R"FUS9VED(")#;VQO;6)I82(*
M;7-G<W1R(")#;VQO;6)I82(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@
M;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G
M<W1R(")#;VQO<B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HU,#,@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,S.`HC
M.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,Y('-E<G9I8V5S
M+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME
M<B(*;7-G<W1R(")396QE8W1O<B!D92!C;VQO<B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR.#(X"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@
M(E-E;&5C8VGS;B!D92!C;VQO<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R(")#
M;VQU;6YA<SHB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DT-@IM<V=I9"`B
M0V]L=6UN('1I=&QE<R(*;7-G<W1R(")4[71U;&]S(&1E(&QA<R!C;VQU;6YA
M<R(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C(V-@IM<V=I
M9"`B0V]M:6-S(@IM<V=S='(@(D/S;6EC<R(*"B,Z(&%D;6EN+V-M9'-H96QL
M+G!H<#HR-@IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")#;VUA;F1O(@H*(SH@
M861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM
M<V=S='(@(DEN=.ER<'(N(&-O;6%N9&]S(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-#$S"FUS9VED(")#;VUM96YT(@IM<V=S='(@(D-O;65N=&%R
M:6\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B
M0V]M;6]N($YA;64B"FUS9W-T<B`B3F]M8G)E(&-O;?IN(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C4X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S`*;7-G:60@(D-O
M;6]R;W,B"FUS9W-T<B`B0V]M;W)O<R(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(D-O
M;7!A\>UA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#
M;VUP=71E<G,B"FUS9W-T<B`B3W)D96YA9&]R97,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C@V"FUS9VED(")#;VYD:71I;VXB"FUS9W-T
M<B`B0V]N9&EC:?-N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-38*;7-G
M:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B0V]N9&EC:6]N97,B"@HC.B!A9&UI
M;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F
M97)E;F-E<R(*;7-G<W1R(")$:69E<F5N8VEA<R!D92!L82!C;VYF:6=U<F%C
M:?-N(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED
M(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P
M:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(B(*(D-O;F9I9W5R86-I\VX@
M<&%R82!S:6YC<F]N:7IA8VGS;B!C;VX@4$1!<RP@3?-V:6QE<R!C;VX@86=E
M;F1A('D@3W5T;&]O:RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,T
M"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R
M("),82!C;VYF:6=U<F%C:?-N(&5S=.$@9&5S86-T=6%L:7IA9&$N(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B0V]N9FEG=7)A<B`E<R(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3$*;7-G:60@(D-O;F9I
M<FT@4&%S<W=O<F0B"FUS9W-T<B`B0V]N9FER;6%R(&-O;G1R87-E\6$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4U"FUS
M9VED(")#;VYG;R(*;7-G<W1R(")#;VYG;R(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3,*;7-G:60@(D-O;F=O+"!4:&4@
M1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B0V]N9V\L(%)E
M</IB;&EC82!$96UO8W+A=&EC82!D96PB"@HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,3DW(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS,#@*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R(")&
M86QL\R!L82!C;VYE>&GS;BXB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,3DW(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M,#@*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B1F%L;/,@
M;&$@8V]N97AI\VXZ("(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<Y
M,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+B(*;7-G<W1R(")392!H82!R96-H87IA9&\@;&$@8V]N97AI\VX@
M86P@<V5R=FED;W(@9&4@8VQA=F5S('#Z8FQI8V\N(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE
M8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N
M.B`E<R`H)7,I(@IM<V=S='(@(B(*(E-E(&AA(')E8VAA>F%D;R!L82!C;VYE
M>&GS;B!A;"!S97)V:61O<B!D92!C;&%V97,@</IB;&EC;RX@36]T:79O.B`E
M<R`H)7,I(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@X.0IM<V=I9"`B0V]N;F5C
M=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B2&$@9F%L;&%D
M;R!L82!C;VYE>&GS;B!A;"!S97)V:61O<B!&5%`N(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HY,C0@8V]N9FEG+RYB86LO:&]O:W,N<&AP+F1I<W0Z,3`V
M-PIM<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`B0V]N=&%C=&]S(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C
M=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O
M;VLN(@IM<V=S='(@(E-E(&AA;B!A\6%D:61O(&-O<G)E8W1A;65N=&4@;&]S
M(&-O;G1A8W1O<R!A('-U<R!D:7)E8V-I;VYE<R(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]T9WHN<&AP.C8P"FUS9VED(")#;VYT96YT('1Y<&4@;V8@
M8V]M<')E<W-E9"!F:6QE.B`B"FUS9W-T<B`B5&EP;R!D92!C;VYT96YI9&\@
M9&5L(&%R8VAI=F\@8V]M<')I;6ED;SH@(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-38@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-S4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@
M(D-O;G1E;FED;R!D92!<(B5S7"(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z,S,@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD*;7-G
M:60@(D-O;G1I;G5E(@IM<V=S='(@(D-O;G1I;G5A<B(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HV,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3@*;7-G:60@(D-O;VL@
M27-L86YD<R(*;7-G<W1R("))<VQA<R!#;V]K(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,R"FUS9VED(")#;V]K:64B"FUS9W-T<B`B0V]O:VEE(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@(D-O<&EA<B(*"B,Z(&QI8B]6
M1E,O<VUB+G!H<#HT.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL
M960Z("5S(@IM<V=S='(@(D9A;&SS(&QA(&-O<&EA.B`E<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O
M<'D@<V5L96-T:6]N(@IM<V=S='(@(D-O<&EA<B!S96QE8V-I\VXB"@HC.B!L
M:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3<P(&QI8B].970O4TU3+W=I;E]H
M='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B240@9&4@8V]S
M=&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C8S"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@(D-O<W1A(%)I8V$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4W"FUS
M9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(D-O<W1A(&1E($UA<F9I;"(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDW-PIM<V=I9"`B0V]U;&0@
M;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z("(*;7-G<W1R(").;R!S92!P=65D
M92!C:69R87(@96P@;65N<V%J92!M961I86YT92!01U`Z("(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C$P-34*;7-G:60@(D-O=6QD(&YO="!01U`@
M<VEG;B!M97-S86=E.B`B"FUS9W-T<B`B3F\@<V4@<'5E9&4@9FER;6%R(&5L
M(&UE;G-A:F4@;65D:6%N=&4@4$=0.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T
M(&UE<W-A9V4N(@IM<V=S='(@(DYO('-E('!U961E(&-I9G)A<B!E;"!M96YS
M86IE(&UE9&EA;G1E(%,O34E-12(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G
M92XB"FUS9W-T<B`B3F\@<V4@<'5E9&4@9FER;6%R(&5L(&UE;G-A:F4@;65D
M:6%N=&4@(%,O34E-12(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C
M;VYT86-T+B`E<R(*;7-G<W1R(").;R!S92!P=65D92!A\6%D:7(@96P@8V]N
M=&%C=&\N("5S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0X,B!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z.38*(SH@;&EB+TAO<F1E+T%U=&@O;&1A
M<"YP:'`Z,3(Q"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E
M<BXB"FUS9W-T<B`B3F\@<V4@<'5E9&4@96YL87IA<B!A;"!S97)V:61O<B!,
M1$%0+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S
M='(@(DYO('-E('!U961E(&-O;7!R;V)A<B!E;"!S86QD;RX@)7,B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8V"FUS9VED(")#;W5L9"!N;W0@8V]N
M;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3F\@<V4@<'5E9&4@8V]N
M96-T87(@86P@<V5R=FED;W(@3$1!4"XB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE
M8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(DYO
M('-E('!U961E(&-O;F5C=&%R(&%L('-E<G9I9&]R(%PB)7-<(B!M961I86YT
M92!&5%`Z("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").;R!S92!P=65D92!C<F5A
M<B!L82!L:7-T82!D92!D:7-T<FEB=6-I\VXN("5S(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z,3$R.`IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@
M4$=0(&1A=&$Z("(*;7-G<W1R(").;R!S92!P=65D96X@9&5S8VEF<F%R(&QO
M<R!D871O<R!01U`Z("(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3(S"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS
M9W-T<B`B3F\@<V4@<'5E9&5N(&1E<V-I9G)A<B!L;W,@9&%T;W,@4R]-24U%
M+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E
M<R(*;7-G<W1R(").;R!S92!P=65D92!E;&EM:6YA<B!E;"!C;VYT86-T;RX@
M)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S(@IM<V=S='(@(DYO('-E('!U961E(&5L:6UI;F%R(&QA
M(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BX@)7,B"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B
M(@HB3F\@<V4@<'5E9&4@96QI;6EN87(@96P@9W5I\VX@9&4@86-T=6%L:7IA
M8VGS;B!D92!C;VYF:6=U<F%C:?-N(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HY-3,@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS
M.#$*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S
M(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R(").;R!S92!P=65D92!D971E<FUI
M;F%R82!L82!D:7)E8V-I\VX@9&4@8V]R<F5O(&1E;"!D97-T:6YA=&%R:6\N
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I
M9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS
M9W-T<B`B3F\@<V4@<'5E9&4@=')A97(@;&$@;&EB<F5T82!D92!D:7)E8V-I
M;VYE<R!C;VUP;&5T82XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES
M=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(DYO('-E('!U961E('1R865R(&QA
M(&QI<W1A(&1E(&1I<W1R:6)U8VGS;B!C;VUP;&5T82XB"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@
M9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S
M+B(*;7-G<W1R(").;R!S92!P=65D92!T<F%E<B!L82!L:7-T82!C;VUP;&5T
M82!D92!L:7-T87,@9&4@9&ES=')I8G5C:?-N+B(*"B,Z(&QI8B]61E,O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC.B!L:6(O5D93+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS
M9W-T<B`B3F\@<V4@<'5E9&4@8V%R9V%R(&QA(&5S=')A=&5G:6$@7"(E<UPB
M+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D
M:7)E8W0N<&AP.C,P"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C$Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R(").;R!S92!P=65D92!C<F5A
M<B!E;"!D:7)E8W1O<FEO(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME
M>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(DYO('-E('!U961E(&]B
M=&5N97(@;&$@8VQA=F4@</IB;&EC82!D96P@<V5R=FED;W(@9&4@8VQA=F5S
M+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E
M;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(DYO('-E('!U961E(&%B
M<FER(%PB)7-<(B!P87)A(&5S8W)I8FER+B(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S0U(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-S<*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(V,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T
M<B`B3F\@<V4@<'5E9&4@86)R:7(@)7,N(@H*(SH@;&EB+TAO<F1E+TUA:6YT
M96YA;F-E+G!H<#HT,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B3F\@
M<V4@<'5E9&4@86)R:7(@96P@;?-D=6QO(&1E('1A<F5A<R!D92!M86YT96YI
M;6EE;G1O("5S(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B3F\@<V4@<'5E
M9&4@86)R:7(@96P@9&ER96-T;W)I;R!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E
M+T=R;W5P+VQD87`N<&AP.C$Q,2!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z
M,30T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HR,S<@;&EB+TAO<F1E
M+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP
M:'`Z-3$V(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.C8U-B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP
M:'`Z-CDY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R
M+B(*;7-G<W1R(").;R!S92!P=65D92!L;V-A;&EZ87(@96P@<V5R=FED;W(@
M3$1!4"XB"@HC.B!L:6(O5D93+T]B:F5C="YP:'`Z,C0P"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R(").;R!S92!P
M=65D92!L965R("5S+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O
M<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D
M971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@
M>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L
M<"XB"FUS9W-T<B`B(@HB3F\@<V4@<'5E9&4@<F5S=&%B;&5C97(@;&$@8V]N
M=')A<V7Q82!D96P@=7-U87)I;R!S;VQI8VET861O+B!087)T92!D92!L;W,@
M(@HB9&5T86QL97,@;R!T;V1O<RP@<V]N(&EN8V]R<F5C=&]S+B!0<G5E8F4@
M;W1R82!V97H@;R!P\VYG87-E(&5N(&-O;G1A8W1O(&-O;B`B"B)E;"!A9&UI
M;FES=')A9&]R(&1E;"!S:7-T96UA('!A<F$@;>%S(&EN9F]R;6%C:?-N+B(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#<@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,S.`HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S<U(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS.#$*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,X-PIM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R(").
M;R!S92!P=65D92!O8G1E;F5R(&QA($%#3"XB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(DYO
M('-E('!U961E(&]B=&5N97(@;&$@;&EB<F5T82!D92!D:7)E8V-I;VYE<RX@
M)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3F\@<V4@<'5E9&4@;V)T96YE<B!L
M82!L:7-T82!D92!D:7-T<FEB=6-I\VXN("5S(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G
M<W1R(").;R!S92!P=65D96X@;V)T96YE<B!L87,@;&ES=&%S(&1E(&1I<W1R
M:6)U8VGS;BX@)7,B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,3DW(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3<*(SH@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,0IM<V=I9"`B0V]U
M;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R
M(").;R!S92!P=65D96X@;V)T96YE<B!L87,@8V%P86-I9&%D97,@9&5L('-E
M<G9I9&]R(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B
M0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").;R!S
M92!P=65D92!R97-T875R87(@;&$@8V]N9FEG=7)A8VGS;BXB"@HC.B!L:6(O
M5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*
M;7-G<W1R(").;R!S92!P=65D92!E;&EM:6YA<B!E;"!D:7)E8W1O<FEO(%PB
M)7-<(BXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R(").;R!S92!P=65D92!G=6%R9&%R(&QA(&-O;F9I9W5R86-I
M\VX@9&4@)7,N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@<V%V92!A
M(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(DYO('-E('!U961E(&=U
M87)D87(@=6YA(&-O<&EA(&1E(&QA(&-O;F9I9W5R86-I\VXN(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T
M<B`B3F\@<V4@<'5E9&4@9W5A<F1A<B!U;F$@8V]P:6$@9&4@;&$@8V]N9FEG
M=7)A8VGS;CH@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R
M861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"B).;R!S92!P=65D
M92!G=6%R9&%R(&5L(&=U:?-N(&1E(&%C='5A;&EZ86-I\VX@9&4@;&$@8V]N
M9FEG=7)A8VGS;B!E;CH@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(DYO
M('-E('!U961E(&=U87)D87(@;&$@8V]P:6$@)7,@9&4@;&$@8V]N9FEG=7)A
M8VGS;BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T
M:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*
M(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@
M;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*(DYO
M('-E('!U961E(&=U87)D87(@96P@87)C:&EV;R`E<R!D92!C;VYF:6=U<F%C
M:?-N+B!0=65D92!U=&EL:7IA<B!U;F$@9&4@(@HB;&%S(&]P8VEO;F5S('!A
M<F$@<F5S=&%U<F%R(&5L(&/S9&EG;R!D92`E<R!O(&-O<&EA<B!M86YU86QM
M96YT92!A("5S(&5L("(*(F/S9&EG;R!S:6=U:65N=&4N(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H
M('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3F\@<V4@<'5E9&4@8G5S8V%R
M(&5N(&5L('-E<G9I9&]R($Q$05`N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(DYO('-E
M('!U961E(&1E<W9I;F-U;&%R(%PB)7-<(BXB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B3F\@<V4@<'5E
M9&4@86-T=6%L:7IA<B!E;"!C;VYT86-T;RX@)7,B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S
M='(@(DYO('-E('!U961E(&%C='5A;&EZ87(@;&$@;&ES=&$@9&4@9&ES=')I
M8G5C:?-N+B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO
M;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R(").;R!S92!P=65D92!E<V-R:6)I
M<B!L82!C;VYF:6=U<F%C:?-N(&1E(%PB)7-<(CH@)7,B"@HC.B!C;VYF:6<O
M+F)A:R]P<F5F<RYP:'`N9&ES=#HS-S`*;7-G:60@(D-O=6QD;B=T(&9I;F0@
M=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES
M(&]P96XN(@IM<V=S='(@(B(*(DYO('-E('!U961E(&QO8V%L:7IA<B!E;"!P
M86YE;"!L871E<F%L(&1E($UO>FEL;&$N($-O;7!R=65B92!Q=64@97-TZ2`B
M"B)A8FEE<G1O+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U
M<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E
M<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*(DYO('-E('!U961E;B!O=&]R9V%R
M(&%L('5S=6%R:6\@7"(E<UPB(&QO<R!S:6=U:65N=&5S(&1E<F5C:&]S('!A
M<F$@;&$@(@HB8V%R<&5T82!<(B5S7"(Z("5S(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$T,3D*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R(")497AT
M;R!C;VYT861O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S`*
M;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B4&'M<R(*"B,Z(&-O;F9I9R\N8F%K
M+W)E9VES=')Y+G!H<"YD:7-T.C(W-0IM<V=I9"`B0V]U<G-E<R(*;7-G<W1R
M(")#=7)S;W,B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R(")#
M<F5A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R(")#
M<F5A('5N(';M;F-U;&\B"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES
M96QE8W0N:6YC.CDT"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@
M(D-R96%R(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR
M(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU,@IM<V=I9"`B0W)E
M871E('-U8B!F;VQD97)S(@IM<V=S='(@(D-R96%R('-U8F-A<G!E=&%S(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B4')I=FEL96=I;W,@9&4@8W)E861O<B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C$R"FUS9VED(")#<F5D:70@8V%R
M9"!N=6UB97(B"FUS9W-T<B`B3OIM97)O(&1E('1A<FIE=&$@9&4@8W+I9&ET
M;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3`Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(D-R;V%C:6$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8T"FUS9VED(")#
M=6)A(@IM<V=S='(@(D-U8F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*
M;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B-"!&87-E<R!A8W1U
M86QE<R(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`IM<V=I9"`B0W5R<F5N
M="!397-S:6]N<R(*;7-G<W1R(")397-I;VYE<R!A8W1U86QE<R(*"B,Z(&QI
M8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I
M9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(DAO<F$@86-T=6%L(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T
M"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R(")54DP@86-T=6%L(@H*
M(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"FUS9VED(")#=7)R96YT(%5S97)S
M(@IM<V=S='(@(E5S=6%R:6]S(&%C='5A;&5S(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(E1I
M96UP;R!A8W1U86PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C8T"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@(D-O;F1I
M8VGS;B!A8W1U86PZ("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B
M17-T:6QO(&%C='5A;"(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@
M<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(E!E<G-O;F%L:7IA(&QA
M<R!T87)E87,@82!E:F5C=71A<B!A;"!I;FEC:6%R('-E<VGS;B!E;B`E<RXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R(")#;W)T87(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED(")#
M=70@<V5L96-T:6]N(@IM<V=S='(@(D-O<G1A<B!S96QE8V-I\VXB"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8W"FUS9VED
M(")#>7!R=7,B"FUS9W-T<B`B0VAI<')E(@H*(SH@8V]N9FEG+RYB86LO;FQS
M+G!H<"YD:7-T.C$X-0IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T
M<B`B0VER[6QI8V\@*$M/23@M4BDB"@HC.B!C;VYF:6<O+F)A:R]N;',N<&AP
M+F1I<W0Z,3@V"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G
M<W1R(")#:7+M;&EC;R`H5VEN9&]W<RTQ,C4Q*2(*"B,Z(&-O;F9I9R\N8F%K
M+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H
M2T])."U5*2(*;7-G<W1R(")#:7+M;&EC;R]58W)A;FEA;F\@*$M/23@M52DB
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8X
M"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R(")297#Z8FQI8V$@0VAE
M8V$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4R
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")$
M1"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C<R"FUS9VED("(B"B)$4TX@
M*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A
M=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S='(@(B(*(D133B`H=F5A
M(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5S+W!A8VMA9V4N9&%T86)A
M<V4N9&(N:6YT<F\M9'-N+G!H<"DB"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N
M8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R(")$:6%R:6%M96YT92(*
M"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O
M=W-E<B(*;7-G<W1R("+!<E]B;VP@9&%T;W,B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S(W,`IM<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(D-O
M;G-U;'1A(&1E(&QA(&)A<V4@9&4@9&%T;W,B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C,Y."!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW
M,@IM<V=I9"`B1&%T92(*;7-G<W1R(")&96-H82(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I=F5D
M(@IM<V=S='(@(E-E(&AA(')E8VEB:61O(&QA(&9E8VAA(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(W.#D*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S
M='(@(E-E;&5C8VGS;B!D92!F96-H82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR.#$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q
M,0IM<V=I9"`B1&%Y(@IM<V=S='(@(D3M82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B1&5?
M;&5T92!#;VQU;6XB"FUS9W-T<B`B15]L:6UI;F%R(&-O;'5M;F$B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT-3$*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B
M"FUS9W-T<B`B1&EC:65M8G)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N
M=6UB97)S(@IM<V=S='(@(D[Z;65R;W,@9&5C:6UA;&5S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C
M<F5A<V4@26YD96YT(@IM<V=S='(@(E)E9'5C:7(@<V%N9W)A9&\B"@HC.B!L
M:6(O<')E9G,N<&AP.C$Q-R!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$X-PIM
M<V=I9"`B1&5F875L="(*;7-G<W1R(")0;W(@;VUI<VGS;B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$
M969A=6QT($-O;&]R(@IM<V=S='(@(D-O;&]R('!O<B!O;6ES:?-N(@H*(SH@
M;&EB+TAO<F1E+TED96YT:71Y+G!H<#HY-@IM<V=I9"`B1&5F875L="!)9&5N
M=&ET>2(*;7-G<W1R("))9&5N=&ED860@<&]R(&]M:7-I\VXB"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-S4*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS
M9W-T<B`B4VAE;&P@<&]R(&]M:7-I\VXB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(D1E9FEN:6-I
M;VYE<R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@;&EB+TAO<F1E+U!E<FUS
M+G!H<#HS,C8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C(*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HT,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.3,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,38@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C<S"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M."!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`*;7-G:60@(D1E;&5T92(*
M;7-G<W1R("(F;F)S<#M%;&EM:6YA<B9N8G-P.R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B
M1&5L971E($-E;&PB"FUS9W-T<B`B16QI;6EN87(@8V5L9&$B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R-PIM<V=I9"`B
M1&5L971E($=R;W5P(@IM<V=S='(@(D5L:6UI;F%R(&=R=7!O(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y"FUS9VED(")$96QE=&4@3&]G
M(@IM<V=S='(@(D5L:6UI;F%R(')E9VES=')O(@H*(SH@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HW-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$P,0IM<V=I
M9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B16QI;6EN87(@<')I=FEL
M96=I;R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM
M<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R(")%;&EM
M:6YA<B!Y('9A8VEA<B!M96YS86IE<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C
M96QL(@IM<V=S='(@(D5L:6UI;F%R(&-E;&1A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L
M971E(&-O;'5M;B(*;7-G<W1R(")%;&EM:6YA<B!C;VQU;6YA(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A
M;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B16QI;6EN87(@<&QA;G1I;&QA
M<R!A;'1E<FYA=&EV87,@97AI<W1E;G1E<R(*"B,Z(&QI8B](;W)D92])34%0
M+T%#3"]R9F,T,S$T+G!H<#HU-`IM<V=I9"`B1&5L971E(&UE<W-A9V5S(@IM
M<V=S='(@(D5L:6UI;F%R(&UE;G-A:F5S(@H*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI
M<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B16QI;6EN87(@<')I=FEL96=I
M;W,@9&4@7"(E<UPB(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<
M(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(K]%;&EM
M:6YA<B!P<FEV:6QE9VEO<R!P87)A(%PB)7-<(B!Y(&-U86QQ=6EE<B!P<FEV
M:6QE9VEO(&1E<V-E;F1I96YT93\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W
M(@IM<V=S='(@(D5L:6UI;F%R(&9I;&$B"@HC.B!T96UP;&%T97,O<')E9G,O
M9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@
M:61E;G1I='DB"FUS9W-T<B`B16QI;6EN87(@:61E;G1I9&%D('-E;&5C8VEO
M;F%D82(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU,PIM
M<V=I9"`B1&5L971E('-U8B!F;VQD97)S(@IM<V=S='(@(D5L:6UI;F%R('-U
M8F-A<G!E=&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@
M8V]L=6UN(@IM<V=S='(@(D5L:6UI;F$@;&$@8V]L=6UN82!A8W1U86PB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B
M16QI;6EN82!L82!F:6QA(&%C='5A;"(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C,V"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")392!H82!E;&EM:6YA
M9&\@96P@9W5I\VX@9&4@86-T=6%L:7IA8VGS;B!D92!L82!C;VYF:6=U<F%C
M:?-N(%PB)7-<(BXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(R,2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PHC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*;7-G:60@(D1E;&EV97)Y('1I
M;64B"FUS9W-T<B`B2&]R82!D92!E;G1R96=A.B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV
M.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S$*;7-G:60@(D1E;FUA<FLB
M"FUS9W-T<B`B1&EN86UA<F-A(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S
M='(@(D1E<V-R:6)A(&5L('!R;V)L96UA(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.CDS."!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FEP
M8VGS;B(*"B,Z(&QI8B](;W)D92YP:'`Z,C`V"FUS9VED(")$971A:6QS("AA
M;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(D1E=&%L;&5S("AT
M86UB:>EN(&5N(&5L(&%R8VAI=F\@9&4@<F5G:7-T<F\@9&4@2&]R9&4I.B(*
M"B,Z(&QI8B](;W)D92YP:'`Z,C$P"FUS9VED(")$971A:6QS(&AA=F4@8F5E
M;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")392!H
M86X@<F5G:7-T<F%D;R!L;W,@9&5T86QL97,@<&%R82!E;"!A9&UI;FES=')A
M9&]R+B(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C(R,0IM
M<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B1&5S87)R;VQL;R(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C(T"FUS9VED(")$97<@4&]I;G0B"FUS9W-T
M<B`B4'5N=&\@9&4@8V]N9&5N<V%C:?-N(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS,#$*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS
M9W-T<B`B4'5N=&\@9&4@8V]N9&5N<V%C:?-N(&1E(&QA(/IL=&EM82!H;W)A
M.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED
M(")$97<@<&]I;G0Z("(*;7-G<W1R(")0=6YT;R!D92!C;VYD96YS86-I\VXZ
M("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(D1E
M(&EZ<75I97)D82!A(&1E<F5C:&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@
M=&\@;&5F="(*;7-G<W1R(")$92!D97)E8VAA(&$@:7IQ=6EE<F1A(@H*(SH@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G
M<W1R(")$:7)E8W1O<FEO(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I
M<W0Z,C<P"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@
M(K]-;W-T<F%R(&5N(&9O<FUA=&\@9&4@,C0M:&]R87,_(@H*(SH@8V]N9FEG
M+RYB86LO<')E9G,N<&AP+F1I<W0Z,3`P"FUS9VED(")$:7-P;&%Y($]P=&EO
M;G,B"FUS9W-T<B`B3W!C:6]N97,@9&4@5FES=6%L:7IA8VGS;B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HX.0IM<V=I9"`B1&ES<&QA>2!D
M971A:6QE9"!F;W)E8V%S="(*;7-G<W1R(")-;W-T<F%R('!R;V[S<W1I8V\@
M9&5T86QL861O(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HY,@IM<V=I9"`B
M1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R(")-;W-T<F%R('!R;V[S
M<W1I8V\@*%1!1BDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y.0IM<V=I
M9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B1F]R;6%T;R!D92!V:7-U>F%L
M:7IA8VGS;B(*"B,Z(&QI8B](;W)D92]-24U%+TU$3BYP:'`Z,3DQ"FUS9VED
M(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B3F]T:69I8V%C
M:?-N(&1E(&-O;G-U;'1A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HW,`IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B1&II
M8F]U=&DB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R,@IM<V=I9"`B
M1&\@;F]T(&1E;&5T92(*;7-G<W1R(").;R!E;&EM:6YA<B(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY
M(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B3F\@86-C961E<B!D
M:7)E8W1A;65N=&4@82!M86EN=&5N86YC92YP:'`B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN
M8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I
M96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R("(B
M"B*_0V]N=&EE;F4@;&$@<')I;65R82!F:6QA(&QO<R!N;VUB<F5S(&1E(&QO
M<R!C86UP;W,_(%-I(&5S(&%S[2P@<V5L96-C:6]N92`B"B)E<W1A(&-A<VEL
M;&$Z(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HW,@IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B1&]M:6YI8V$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<S"FUS9VED
M(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B4F5P^F)L:6-A($1O;6EN
M:6-A;F$B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED
M(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(K].
M;R!D:7-P;VYE(&1E(&-U96YT83\@4V]L:6/M=&5L82XB"@HC.B!L:6(O2&]R
M9&4O34E-12]#;VYT96YT<RYP:'`Z.#4S"FUS9VED(")$;W=N;&]A9"(*;7-G
M<W1R(")$97-C87)G87(B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP
M:'`Z.#4S"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S
M='(@(D1E<V-A<F=A<B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-C$*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S
M(%!(4"!S8W)I<'0N(@IM<V=S='(@(D1E<V-A<F=A<B!L82!C;VYF:6=U<F%C
M:?-N(&=E;F5R861A(&-O;6\@=6X@9W5I\VX@4$A0+B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,3`W"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R
M("),:7-T82!D97-P;&5G86)L92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`B1')O9V%S(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B
M0V]R<F5O(@H*(SH@;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM
M<V=I9"`B14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE
M<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*(D-O
M;G1R;VQA9&]R(&1E('!A<V%R96QA($-O<G)E;RUA+5--4R!P87)A('!R;W9E
M961O<F5S('%U92!P<F]P;W)C:6]N96X@97-T92`B"B)S97)V:6-I;RXB"@HC
M.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z
M,S0*;7-G:60@(D524B(*;7-G<W1R(")%4E(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<U"FUS9VED(")%8W5A9&]R(@IM
M<V=S='(@(D5C=6%D;W(B"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R-2!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*;7-G:60@(D5D
M:70B"FUS9W-T<B`B)FYB<W`[36]D:69I8V%R)FYB<W`[(@H*(SH@;&EB+TAO
M<F1E+T)L;V-K+U5)+G!H<#HU,`IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R
M(")-;V1I9FEC87(@8FQO<75E(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@
M861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T
M<B`B36]D:69I8V%R(&=R=7!O(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HW-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$P,`IM<V=I9"`B161I="!0
M97)M:7-S:6]N(@IM<V=S='(@(DUO9&EF:6-A<B!P<FEV:6QE9VEO(@H*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M
M:7-S:6]N<R(*;7-G<W1R(")-;V1I9FEC87(@<')I=FEL96=I;W,B"@HC.B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G
M:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(DUO9&EF:6-A
M<B!P<FEV:6QE9VEO<R!D92`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N
M:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(DUO9&EF
M:6-A<B!O<&-I;VYE<R!D93HB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O
M<B!<(B5S7"(B"FUS9W-T<B`B36]D:69I8V%R('!R:79I;&5G:6]S(&1E(%PB
M)7-<(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T
M<B`B36]D:69I8V%R('!R:79I;&5G:6]S(&1E("5S(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B161U
M8V%C:?-N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HW-PIM<V=I9"`B16=Y<'0B"FUS9W-T<B`B16=I<'1O(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HW-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$W"FUS9VED
M(")%;"!386QV861O<B(*;7-G<W1R(")%;"!386QV861O<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM
M<V=I9"`B16QE;65N="XN+B(*;7-G<W1R(")%;&5M96YT;RXN+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED
M(")%;2(*;7-G<W1R(")%;2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#8Y
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T"FUS9VED(")%
M;6%I;"(*;7-G<W1R(")#;W)R96\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4V-B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*;7-G:60@
M(D5M86EL($%D9')E<W,B"FUS9W-T<B`B1&ER96-C:?-N(&1E(&-O<G)E;R(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.38S"FUS9VED(")%;6%I;"!A9&1R
M97-S97,@;75S="!M871C:"XB"FUS9W-T<B`B3&%S(&1I<F5C8VEO;F5S(&1E
M(&-O<G)E;R!T:65N96X@<75E(&-O:6YC:61I<BXB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3DX.0IM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB
M"FUS9W-T<B`B0V]R<F5O(&-O;B!C;VYF:7)M86-I\VXB"@HC.B!L:6(O3F5T
M+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU335,@
M1V%T97=A>2(*;7-G<W1R(")087-A<F5L82!#;W)R96\M82U335,B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDY"FUS9VED(")%
M;6]T:6-O;G,B"FUS9W-T<B`B16UO=&EC;VYE<R(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED(")%;7!T>2!M97-S86=E
M+B(*;7-G<W1R(")-96YS86IE(&5N(&)L86YC;R(*"B,Z(&QI8B](;W)D92]'
M<F]U<"]L9&%P+G!H<#HR-#,@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C0X
M-`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-C8R(&QI8B](;W)D92]'
M<F]U<"]L9&%P+G!H<#HW,#4*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z
M,34P"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@(E)E<W5L=&%D;R!E
M;B!B;&%N8V\N(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,3$S
M"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B3&EM<&EA<B!T
MZ7)M:6YO<R!D92!B^G-Q=65D82(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H
M<"YD:7-T.C4T-PIM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@
M9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`BOU!E<FUI
M=&ER(&EN<V5R8VGS;B!D92!I;>%G96YE<R!D92!L87,@1V%L97+M87,@9&4@
M9F]T;W,_(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-3(R"FUS
M9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R
M("*_4&5R;6ET:7(@;65N^B!D92!C;VYT97AT;R!D96P@8F]T\VX@9&5R96-H
M;R!D96P@<F%T\VX_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.#@@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(W.3,*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@
M(D'Q;R!D92!T97)M:6YA8VGS;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM
M<V=S='(@(D%G<F%N9&%R(&5D:71O<B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S
M+G!H<"YD:7-T.C(R-`IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S
M=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R
M97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE
M(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*(DEN=')O9'5Z8V$@=6YA('!R
M96=U;G1A(&1E('-E9W5R:61A9"!Q=64@<V4@;&4@9F]R;75L87+A('-I('!R
M96-I<V$@(@HB<F5A:G5S=&%R(&QA(&-O;G1R87-E\6$L('`N92X@)[]#=>%L
M(&5S(&5L(&YO;6)R92!D92!S=2!M87-C;W1A/R<Z(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"FUS
M9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B26YT<F]D
M=7IC82!A<77M(&QA(%523"!D92!L82!I;6%G96XB"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DR"FUS9VED(")%;G1E<B!T:&4@
M;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B26YT<F]D=7IC82!L87,@;&5T<F%S
M(&1E(&1E8F%J;SHB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.CDY"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R
M(")'=6EN96$@16-U871O<FEA;"(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-SD*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B
M17)I=')E82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S8@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C0X"B,Z(&QI8B](;W)D92].;W1I9FEC871I
M;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+U9I97<N<&AP.CDT"FUS9VED(")%<G)O<B(*;7-G<W1R(")%<G)O
M<B(*"B,Z(&QI8B](;W)D92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R(")%
M<G)O<B!A;"!C<F5A<B!E;"!B;&]Q=64Z("5S(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(D5R<F]R(&%L(&5L
M:6UI;F%R(&%N8VQA(&1E('-I;F-R;VYI>F%C:?-N.B`E<R(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R(")%<G)O<B!A
M;"!E;&EM:6YA<B!E;"!R96=I<W1R;R!D92!S:6YC<F]N:7IA8VGS;CH@)7,B
M"@HC.B!L:6(O2&]R9&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(D5R
M<F]R(&%L(&]B=&5N97(@8V]N=&5N:61O<SH@)7,B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(D5R<F]R(&%L(&%C
M='5A;&EZ87(@;&$@8V]N=')A<V7Q83H@)7,B"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I
M;"!M97-S86=E+B(*;7-G<W1R(")%<G)O<B!C;VX@96P@;65N<V%J92!D92!C
M;W)R96\N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R
M:71I;F<@7"(E<UPB+B(*;7-G<W1R(")%<G)O<B!A;"!E<V-R:6)I<B!<(B5S
M7"(N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HW-@IM<V=I9"`B17-T;VYI82(*;7-G<W1R(")%<W1O;FEA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C<X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,0IM<V=I9"`B
M171H:6]P:6$B"FUS9W-T<B`B171I;W#M82(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(LET;FEC;R(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS
M9W-T<B`B175R;W!A(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z
M,S0S"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(D-A9&$@,34@
M;6EN=71O<R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C,Y,PIM
M<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(D-A9&$@,B!M:6YU=&]S
M(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S0P(&-O;F9I9R\N
M8F%K+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B179E<GD@,S`@<V5C;VYD
M<R(*;7-G<W1R(")#861A(#,P('-E9W5N9&]S(@H*(SH@8V]N9FEG+RYB86LO
M<')E9G,N<&AP+F1I<W0Z,S0R(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C,Y-`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(D-A9&$@-2!M
M:6YU=&]S(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I
M9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B0V%D82!I;FEC:6\@9&4@<V5S:?-N
M(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S0T"FUS9VED(")%
M=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B0V%D82!M961I82!H;W)A(@H*(SH@
M8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S0Q(&-O;F9I9R\N8F%K+W!R
M969S+G!H<"YD:7-T.C,Y,@IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@
M(D-A9&$@;6EN=71O(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z
M,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R(")686QO<F5S(&1E
M(&5J96UP;&\Z(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C4Q(&%D;6EN+W!H
M<'-H96QL+G!H<#HX,B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS9VED(")%
M>&5C=71E(@IM<V=S='(@(D5J96-U=&%R(@H*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HV,30*;7-G:60@(D5X<&%N9"(*;7-G<W1R
M(")%>'!A;F1I<B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z
M,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(DUO<W1R87(@8F%R
M<F$@;&%T97)A;"(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$V
M.`IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(G-E(&5S<&5R86)A("<I
M)R(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B
M17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G
M<W1R(")392!E<W!E<F%B82!U;F$@^FYI8V$@<&%L86)R82!O('5N('3I<FUI
M;F\@9&4@8OIS<75E9&$@96YT<F5C;VUI;&QA9&\B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G
M<W1R(")&96-H82!D92!V96YC:6UI96YT;R(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-C<W"FUS9VED(")%>'!O;F5N="(*;7-G<W1R(")%>'!O
M;F5N=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R(")#;VQO<B!D
M92!L971R82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S8*;7-G:60@
M(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B0V%R9V%R(&QA(&-O;F9I
M9W5R86-I\VX@<&]R($944"(*"B,Z(&QI8B](;W)D92]0<F5F<R]S<6PN<&AP
M.C(R,`IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N(@IM
M<V=S='(@(D9A;&QO(&%L('1R865R(&QA<R!P<F5F97)E;F-I87,N(@H*(SH@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C<U(&QI8B](;W)D92]!=71H+VQD
M87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E
M<G9E<BXB"FUS9W-T<B`B26YC87!A>B!D92!C;VYE8W1A<G-E(&%L('-E<G9I
M9&]R($Q$05`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HY.`IM<V=I
M9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B
M26YC87!A>B!D92!C;VYE8W1A<G-E(&%L('-E<G9I9&]R(%--0BXB"@HC.B!L
M:6(O5D93+V9T<"YP:'`Z-S(U"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R(")&86QL;R!A;"!C;W!I
M87(@9&4@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW,S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G
M<W1R(")&86QL;R!A;"!C;W!I87(@82!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O<V%S;"YP:'`Z.#<*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W
M(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B1F%L;&\@86P@8W)E87(@=6YA
M(&-O;F5X:?-N(%-!4TPB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S8X(&QI8B]6
M1E,O<VUB+G!H<#HU,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O
M(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R(")&86QL;R!A;"!T<F%S;&%D87(@
M7"(E<UPB+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HT-S0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R(")&86QL
M;R!A;"!R96-U<&5R87(Z("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B1&5S<&5J
M861O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HX-`IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S
M='(@(DES;&%S($UA;'9I;F%S("A&86QK;&%N9"DB"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@V"FUS9VED(")&87)O92!)
M<VQA;F1S(@IM<V=S='(@(DES;&%S($9A<F]E(@H*(SH@;&EB+TAO<F1E+T-,
M22YP:'`Z,C,X"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B17)R;W(@
M:7)R96-U<&5R86)L93HB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A>"(*"B,Z(&-O;F9I
M9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C,U,0IM<V=I9"`B1F%X97,B"FUS
M9W-T<B`B1F%X97,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`S(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B1F5B<F5R;R(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C(W"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@
M(E-E('-I96YT92!C;VUO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(R,`IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(E-E('-I96YT
M92!C;VUO.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B4&]C87,@;&QU
M=FEA<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(D5S8V%S;R!A
M9W5A8V5R;R!D92!N:65V92(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.30T
M"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T<B`B36%T<FEZ(&1E(&-A;7!O
M<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S(U"FUS9VED(")&:6=L970@
M0T%05$-(02(*;7-G<W1R(")#05!40TA!(&1E($9I9VQE="(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HS,S(Y"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R
M("),971R82!D92!&:6=L970B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C@S"FUS9VED(")&:6II(@IM<V=S='(@(D9I:FDB
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(D9I
M;&4B"FUS9W-T<B`B07)C:&EV;R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R87(N<&AP.C8P(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<Y
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,L('!H<"UF
M;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B3KH@
M9&4@87)C:&EV;W,Z("5S(&%R8VAI=F\B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<F%R+G!H<#HV,"!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H
M<#HW.0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R
M(").NB!D92!A<F-H:79O<SH@)7,@87)C:&EV;W,B"@HC.B!C;VYF:6<O+F)A
M:R]R96=I<W1R>2YP:'`N9&ES=#HT,#D*;7-G:60@(D9I;&4@36%N86=E<B(*
M;7-G<W1R(")!<F-H:79O<R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M87(N<&AP.C8S(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"FUS9VED(")&:6QE
M($YA;64B"FUS9W-T<B`B3F]M8G)E(&1E(&%R8VAI=F\B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,CDW-PIM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T
M<B`B4V5L96-C:?-N(&1E(&%R8VAI=F\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,30X-@IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B0V%R9V%R(&%R
M8VAI=F\B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3`P"FUS9VED(")&
M:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B3&$@8V%R9V$@
M9&4@87)C:&EV;W,@;F\@97-TX2!S;W!O<G1A9&$N(@H*(SH@8V]N9FEG+RYB
M86LO<F5G:7-T<GDN<&AP+F1I<W0Z.3$*;7-G:60@(D9I;'1E<G,B"FUS9W-T
M<B`B1FEL=')O<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z.#(*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B1FEN;&%N9&EA
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L
M9B(*;7-G<W1R(")#=6%R=&\@8W)E8VEE;G1E(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@
M475A<G1E<B(*;7-G<W1R(")#=6%R=&\@8W)E8VEE;G1E(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-PIM<V=I9"`B1FEX(')A
M=&EO(@IM<V=S='(@(E)A>O-N(&9I:F$B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C,R"FUS9VED(")&;&EP(@IM<V=S='(@(E9O
M;'1E87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R(")$:7-P;W-I8VGS
M;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q
M"FUS9VED(")&;V<B"FUS9W-T<B`B3FEE8FQA(@H*(SH@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,3`W(&QI8B]61E,O<W%L+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(DQA(&-A
M<G!E=&$@)7,@;F\@97AI<W1E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T
M<B`B0V]L;W(@9&4@;&5T<F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B0V]M:61A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"FUS
M9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*
M;7-G<W1R(")087)A(&YA=F5G861O<F5S('%U92!N;R!A9&UI=&%N(&EMX6=E
M;F5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#$*;7-G:60@(D9O<F5C
M87-T("A4048I(@IM<V=S='(@(E!R;V[S<W1I8V\@*%1!1BDB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S(*;7-G:60@(B(*(D9O<F5C87-T
M($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N
M<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@
M8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@HB1.UA
M<R!D96P@<')O;O-S=&EC;R`H=&5N9V$@96X@8W5E;G1A('%U92!E;"!P<F]N
M\W-T:6-O(&9A8VEL:71A9&\@:6YC;'5Y92`B"B)T86YT;R!E;"!D[6$@8V]M
M;R!L82!N;V-H93L@=6X@;OIM97)O(&=R86YD92!S92!T<F%D=6-I<N$@96X@
M=6X@8FQO<75E(&UU>2`B"B)A;F-H;RDB"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM
M<V=S='(@(K](82!O;'9I9&%D;R!L82!C;VYT<F%S9?%A/R(*"B,Z(&-O;F9I
M9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C0V-`IM<V=I9"`B1F]R;7,B"FUS
M9W-T<B`B1F]R;75L87)I;W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B1F]R='5N82(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S
M='(@(E1I<&\@9&4@9F]R='5N82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS.`IM<V=I9"`B1F]R='5N97,B"FUS9W-T<B`B1F]R='5N87,B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS
M9W-T<B`B1F]R='5N87,@,B(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H
M<"YD:7-T.C0U-0IM<V=I9"`B1F]R=6US(@IM<V=S='(@(D9O<F]S(@H*(SH@
M8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,3$Q"FUS9VED(")&;W)W
M87)D<R(*;7-G<W1R(")2965N=NUO<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(E9I
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S,*;7-G:60@(D9R86UE<R(*;7-G<W1R(")&<F%M97,B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@W"FUS9VED
M(")&<F%N8V4B"FUS9W-T<B`B1G)A;F-I82(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G
M<W1R(")&<F%N8VEA+"!-971R;W!O;&ET86YA(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@T
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,0IM<V=I9"`B1G)E;F-H($=U
M:6%N82(*;7-G<W1R(")'=6%Y86YA(&9R86YC97-A(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C@U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#0*;7-G:60@(D9R96YC
M:"!0;VQY;F5S:6$B"FUS9W-T<B`B4&]L:6YE<VEA(&9R86YC97-A(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HX-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(R"FUS
M9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B5&5R
M<FET;W)I;W,@9G)A;F-E<V5S(&1E;"!S=7(B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R(")$
M92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,T.0HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,SDU"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B1&5L
M("(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS9VED
M(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:7!C:?-N(&-O;7!L
M971A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R("),=6YA(&QL96YA
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8U('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-C`*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R
M(").;VUB<F4@8V]M<&QE=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C@X"FUS9VED(")'86)O;B(*;7-G<W1R(")'86+S
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R
M;VTB"FUS9W-T<B`B1V%L97+M82!D92!L82!Q=64@;V)T96YE<B!L82!I;6%G
M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(D=A;&5R
M[6$Z(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HY-@IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(D=A;6)I82(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N
M97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")'96YE<F%R(&-O;F9I
M9W5R86-I\VX@9&4@)7,B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N
M9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B0_-D
M:6=O(&=E;F5R861O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HY,`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R(")'96]R9VEA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.CDP"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV
M.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R(")!;&5M86YI82(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<U(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HY,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3,*;7-G:60@(D=H
M86YA(@IM<V=S='(@(D=H86YA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HY-`IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@
M(D=I8G)A;'1A<B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<V
M"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(DYO;6)R92!I;F1I8V%D;R(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-SD@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z,3`*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z
M,3D*;7-G:60@(D=L;V)A;"!/<'1I;VYS(@IM<V=S='(@(D]P8VEO;F5S(&=L
M;V)A;&5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3<*;7-G:60@
M(D=O(@IM<V=S='(@(DER(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P
M"FUS9VED(")';V5D96PB"FUS9W-T<B`B1V]E9&5L(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,S$*;7-G:60@(D=O;V=L92!-
M87!S(@IM<V=S='(@(DUA<&%S(&1E($=O;V=L92(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B
M0OIS<75E9&$@96X@1V]O9VQE(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(S.`IM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(D5S
M8V%L82!D92!G<FES97,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$P,`IM<V=I9"`B1W)E96-E(@IM<V=S='(@(D=R96-I
M82(*"B,Z(&-O;F9I9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(D=R
M965K("A)4T\M.#@U.2TW*2(*;7-G<W1R(")'<FEE9V\@*$E33RTX.#4Y+3<I
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.CDT"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY
M-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(D=R;V5N;&%N9&EA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.CDU"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX.0IM<V=I
M9"`B1W)E;F%D82(*;7-G<W1R(")'<F%N861A(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HQ-SD*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(D%D;6EN:7-T<F%C:?-N(&1E(&=R=7!O<R(*"B,Z(&QI8B](;W)D92]'<F]U
M<"YP:'`Z-3D@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B
M1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`B3&]S(&YO
M;6)R97,@9&4@9W)U<&\@;F\@<'5E9&5N(&1E:F%R<V4@96X@8FQA;F-O(@H*
M(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C,P-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@HB1W)O
M=7!?;&1A<#H@3F\@<V4@<'5E9&4@8?%A9&ER(&5L(&=R=7!O("5S+B#)<W1O
M(&5S(&QO('%U92!D:6IO(&5L('-E<G9I9&]R.B`B"@HC.B!L:6(O2&]R9&4O
M1W)O=7`O;&1A<"YP:'`Z,3$X(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ
M,C0*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P
M("5S(@IM<V=S='(@(D=R;W5P7VQD87`Z($EN8V%P87H@9&4@96QI;6EN87(@
M96P@9W)U<&\@)7,B"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S,X
M(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*
M;7-G<W1R(")'<F]U<%]L9&%P.B!);F-A<&%Z(&1E(&%C='5A;&EZ87(@96P@
M9W)U<&\@)7,B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS."!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C,Q-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(D=R=7!O<R(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HY-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3@*;7-G:60@
M(D=U861E;&]U<&4B"FUS9W-T<B`B1W5A9&%L=7!E(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.CDW"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#,*;7-G:60@(D=U86TB
M"FUS9W-T<B`B1W5A;2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3`R"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B1W5A
M=&5M86QA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'
M=65R;G-E>2(*;7-G<W1R(")'=65R;F5S97DB"@HC.B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS
M9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R(")0<FEV:6QE9VEO<R!D
M92!I;G9I=&%D;R(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T
M.C0W,@IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(DPN(&EN=FET861O<R(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HY.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3<*
M;7-G:60@(D=U:6YE82(*;7-G<W1R(")'=6EN96$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#0*;7-G:60@(D=U:6YE
M82U":7-S874B"FUS9W-T<B`B1W5I;F5A+4)I<W-A=2(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-0IM<V=I9"`B1W5Y
M86YA(@IM<V=S='(@(D=U87EA;F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M.38P"FUS9VED(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M96QL(&EN(')O=RXB"FUS9W-T<B`B2%1-3"!S92!N:65G82!C;V)A<F1E;65N
M=&4@82!E;&EM:6YA<B!L82#Z;'1I;6$@8V5L9&$@9&4@;&$@9FEL82XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T
M92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(B(*(DA434Q!
M<F5A('-E(&YI96=A(&-O8F%R9&5M96YT92!A(&5L:6UI;F%R(&QA(/IL=&EM
M82!C;VQU;6YA(&1E(&QA('1A8FQA+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T
M86)L92XB"FUS9W-T<B`B2%1-3"!S92!N:65G82!C;V)A<F1E;65N=&4@82!E
M;&EM:6YA<B!L82#Z;'1I;6$@9FEL82!D92!L82!T86)L82XB"@HC.B!L:6(O
M2&]R9&4O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC
M871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(").;R!S92!E;F-O;G1R\R!L82!A
M=71E;G1I9FEC86-I\VX@2%144"XB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,3`*;7-G:60@(DAA:71I(@IM<V=S='(@
M(DAA:73M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED
M(")(87-H+4%L9V]R:71H;2(*;7-G<W1R(")!;&=O<FEM;R!(87-H(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@
M(DAA>F4B"FUS9W-T<B`B3F5B;&EN82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HY,3D@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,30*;7-G:60@(DAE861E<B(*
M;7-G<W1R(")#86)E8V5R82(*"B,Z(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B
M;&5S970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@(D-A8F5C97)A
M<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$P-PIM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S
M(@IM<V=S='(@(DES;&$@2&5A<F0@92!)<VQA<R!-8T1O;F%L9"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")(
M96%V>2!4+5-T;W)M(@IM<V=S='(@(E1O<FUE;G1A('1R;W!I8V%L(&EN=&5N
M<V$B"@HC.B!C;VYF:6<O+F)A:R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(")(
M96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B2&5B<F5O("A)4T\M.#@U
M.2TX+4DI(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C(@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B
M2&5I9VAT(@IM<V=S='(@(D%L='5R82(*"B,Z(&QI8B](;W)D92](96QP+G!H
M<#HQ.#0@;&EB+TAO<F1E+TAE;'`N<&AP.C$X-B!S97)V:6-E<R]H96QP+VEN
M9&5X+G!H<#HQ-PHC.B!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z-`IM<V=I
M9"`B2&5L<"(*;7-G<W1R(")!>75D82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I
M=&]R(@IM<V=S='(@(D%Y=61A(&1E;"!E9&ET;W(B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3,W,0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(D%Y=61A;G1E
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E
M(@IM<V=S='(@(DAE;6ES9F5R:6\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,`IM<V=I
M9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R
M(")!<77M('1I96YE(&5L(&-O;6EE;GIO(&1E;"!A<F-H:79O.B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")(
M:6=H(@IM<V=S='(@(D%L=&$B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N
M:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*;7-G
M:60@(DAO7VUE(@IM<V=S='(@(E]);FEC:6\B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P
M-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0S"FUS9VED(")(;VQY(%-E
M92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R(")386YT82!3961E("A#
M:75D860M17-T861O(&1E;"!6871I8V%N;RDB"@HC.B!L:6(O2&]R9&4N<&AP
M.C$U-#@*;7-G:60@(DAO;64B"FUS9W-T<B`B26YI8VEO(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G
M<W1R(")$;VUI8VEL:6\B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*
M;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(D1I<F5C=&]R:6\@<&5R
M<V]N86PB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y
M,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R(")496SI9F]N;R!P87)T:6-U
M;&%R(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3`X"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R(")(;VYD=7)A<R(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-@IM
M<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(DAO;F<@2V]N9R(*"B,Z(&-O;F9I
M9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C8W"FUS9VED(")(;W)D92(*;7-G
M<W1R(")(;W)D92(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#4R"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D
M871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@HB2&]R
M9&4O2V]L86(Z(%-E(&AA;B!E;F-O;G1R861O(&1A=&]S(%A-3"`E<R!N;R!V
MX6QI9&]S(&5N(&5L(&UE;G-A:F4@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@
M;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z($YI;F?Z;B!M96YS86IE(&-O<G)E<W!O;F1E(&%L(&]B:F5T
M;R`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#0U"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F
M;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.;R!S
M92!E;F-O;G1R\R!U;B!O8FIE=&\@9&4@=&EP;R`E<R!E;B!E;"!M96YS86IE
M("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C4Q"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E
M<R!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(%-E(&AA(&5L:6UI;F%D
M;R!C;W)R96-T86UE;G1E("5S(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]+;VQA
M8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N
M(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*
M;7-G<W1R("(B"B)(;W)D92]+;VQA8CH@16P@;6]T;W(@9&4@:6YT96=R86-I
M\VX@<')E8VES82!D92!L82!E>'1E;G-I\VX@4$A0("=D;VUX;6PG(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HU,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O
M<B!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($EN8V%P87H@9&4@
M8W)E87(@;G5E=F\@X7)B;VP@6$U,(&1E;"!O8FIE=&\@)7,B"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.C$R-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G
M<W1R(")(;W)D92]+;VQA8CH@26YC87!A>B!D92!E;&EM:6YA<B`E<R!<(B5S
M7"(Z("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT.#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-
M24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(DAO<F1E
M+TMO;&%B.B!);F-A<&%Z(&1E(&]B=&5N97(@240@34E-12!D92!L82!P87)T
M92!D92!T:7!O("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,3DW"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN
M8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@
M26YC87!A>B!D92!S:6YC<F]N:7IA<B`E<R!<(B5S7"(Z("5S(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HQ,S,W"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*
M;7-G<W1R(")(;W)D92]+;VQA8CH@26YC87!A>B!D92!S:6YC<F]N:7IA<B!E
M;&5M96YT;W,@8V]M<&%R=&ED;W,Z("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!%;&5M
M96YT;R!C;VUP87)T:61O(&1E<V-O;F]C:61O(%PB)7-<(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO
M<FEZ;VYT86P@4G5L92(*;7-G<W1R("),[6YE82!H;W)I>F]N=&%L(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I
M9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(DUA<F=E;B!H;W)I>F]N
M=&%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B2&]R:7IO;G1A;#HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E
M(')E<&]R="$I(@IM<V=S='(@(K]#\VUO(&QL96?S(&AA<W1A(&%Q=>T_("BA
M0V]M=6[M<75E;&\L('!O<B!F879O<B$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA
M;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B
MOT-U86YT87,@8V]L=6UN87,@9&5S96$@8V]M8FEN87(_(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD
M<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R("*_0W7A;G1O<R!C86UP
M;W,@*&-O;'5M;F%S*2!H87D_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`BOT-U86YT87,@
M9FEL87,@9&5S96$@8V]M8FEN87(_(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR,S<@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X.0IM<V=I9"`B
M2'5M:61I='DB"FUS9W-T<B`B2'5M961A9"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-#@*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B
M2'5M961A9#H@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED
M(")(=6UO<FES=',B"FUS9W-T<B`B2'5M;W)I<W1A<R(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,0IM<V=I9"`B2'5N
M9V%R>2(*;7-G<W1R(")(=6YG<NUA(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER
M<W%L+G!H<#HR,S4@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$W,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D
M.B`E<R(*;7-G<W1R(")(82!F86QL861O(&QA(&-R96%C:?-N(&1E;"!B=7KS
M;B!)34%0.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,CDU
M(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B2&$@9F%L;&%D;R!L82!E;&EM:6YA8VGS;B!D96P@8G5Z\VX@24U!4#H@
M)7,B"@HC.B!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(T,B!L:6(O2&]R
M9&4O075T:"]C>7)U<RYP:'`Z,3<Y"B,L('!H<"UF;W)M870*;7-G:60@(DE-
M05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@
M(DAA(&9A;&QA9&\@;&$@8W)E86-I\VX@9&4@97-P86-I;R!A<VEG;F%D;R!D
M96P@8G5Z\VX@24U!4#H@)7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,Q
M-@IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R(")$:7)E8V-I\VX@25`B"@HC
M.B!L:6(O2&]R9&4O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D
M<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("),82!D:7)E8V-I\VX@25`@
M;F\@97-TX2!D:7-P;VYI8FQE+B(*"B,Z(&QI8B](;W)D92]!=71H+VEP8F%S
M:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E
M9"!#2412(&)L;V-K+B(*;7-G<W1R("),82!D:7)E8V-I\VX@25`@;F\@97-T
MX2!E;G1R92!B;&]Q=65S($-)1%(@<&5R;6ET:61O<RXB"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O
M=VX@=FEO;&%T:6]N+B(*;7-G<W1R(")6:6]L86-I\VX@;&]C:V1O=VX@25`N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B
M25]N<V5R=&%R(&9I;&$@96YC:6UA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(P"FUS9VED("))8V5L86YD(@IM<V=S
M='(@(DES;&%N9&EA(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z
M,S@P"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@(E/S;&\@:6-O;F]S(@H*
M(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G
M:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R("))8V]N;W,@9&4@)7,B"@HC.B!C
M;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HS.#$*;7-G:60@(DEC;VYS('=I
M=&@@=&5X="(*;7-G<W1R("))8V]N;W,@8V]N('1E>'1O(@H*(SH@8V]N9FEG
M+RYB86LO<')E9G,N<&AP+F1I<W0Z,3DS"FUS9VED("))9&5N=&ET>2=S(&YA
M;64Z(@IM<V=S='(@(DYO;6)R92!D92!L82!I9&5N=&ED860Z(@H*(SH@;&EB
M+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C8P,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@
M;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(E-I(&YO('-E(&UU
M97-T<F$@8V]R<F5C=&%M96YT92P@)7,@<&%R82!A8G)I<FQO(&5N('5N82!V
M96YT86YA(&YU979A+B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C0U.0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I
M;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B
M"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G
M<W1R("(B"B)3:2!N;R!V92!N:6YG^FX@:6-O;F\@;65D:6%N=&4@26YT97)N
M970@17AP;&]R97(L('!U961E('1E;F5R('%U92!A8W1I=F%R("(*(F5S=&$@
M8V%S:6QL82!P87)A(&1E<V%C=&EV87(@;&$@=')A;G-P87)E;F-I82!03D<N
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,@IM
M<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E
M+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I
M<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*(E-I('9E(&5S
M=&4@;65N<V%J92!S:6X@;FEN9W5N82!I;6%G96XL(&QA(&EM86=E;B!Q=64@
M<75I97)E(&-A<F=A<B!N;R!S92`B"B)P=65D92!M;W-T<F%R(&5N('-U(&YA
M=F5G861O<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,C4*;7-G:60@(DEM86=E(%!R979I97<Z(@IM
M<V=S='(@(E9I<W1A('!R979I83HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB
M"FUS9W-T<B`B55),(&1E(&QA(&EM86=E;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`IM<V=I9"`B
M26UA9V4@55),.B(*;7-G<W1R(")54DP@9&4@;&$@:6UA9V5N.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(DEM86=E
M;B!D92!L82!G86QE<NUA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M
M(&=A;&QE<GDZ(@IM<V=S='(@(DEM86=E;B!D92!L82!G86QE<NUA.B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8Q"FUS9VED("));6%G92!U<&QO860B
M"FUS9W-T<B`B4V4@:&$@8V%R9V%D;R!L82!I;6%G96XB"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(DEMX6=E
M;F5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-R!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C4T"B,Z('1E;7!L871E<R]D871A+V1A=&5M
M87`N:6YC.C<@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B26UP;W)T
M87(L('!A<V\@)60B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS
M9W-T<B`B0V%M<&\@:6UP;W)T861O.B`E<R(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T
M<B`B0V%M<&]S(&EM<&]R=&%D;W,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T
M(%)O=R!!9G1E<B(*;7-G<W1R("));E]S97)T87(@9FEL82!D96)A:F\B"@HC
M.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ,S0*;7-G:60@(DEN8V]R
M<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B4V4@:&$@:6YD:6-A
M9&\@=6X@8_-D:6=O(&1E(&%C8VGS;B!I;F-O<G)E8W1O+B(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C
M="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(DYO;6)R92!D
M92!U<W5A<FEO('DO;R!C;VYT<F%S9?%A(&EN8V]R<F5C=&]S+B(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E
M8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O
M<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F
M=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(DYO;6)R92!D92!U<W5A<FEO(&\@
M9&ER96-C:?-N(&%L=&5R;F%T:79A(&EN8V]R<F5C=&]S+B!6=65L=F$@82!I
M;G1E;G1A<FQO(&\@(@HB</-N9V%S92!E;B!C;VYT86-T;R!C;VX@96P@861M
M:6YI<W1R861O<B!D92!S:7-T96UA<R!P87)A(&WA<R!I;F9O<FUA8VGS;BXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q
M"FUS9VED("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B075M96YT87(@<V%N
M9W)A9&\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,38*;7-G:60@(DEN9&EA(@IM<V=S='(@(DEN9&EA(@H*(SH@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B57-U
M87)I;W,@:6YD:79I9'5A;&5S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3$R"FUS9VED("));F1O;F5S:6$B"FUS9W-T
M<B`B26YD;VYE<VEA(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`B26YF;W)M86-I\VXB"@HC
M.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HR-3D*;7-G:60@(DEN
M9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%C:?-N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,Q.0IM<V=I9"`B26YF;W)M871I;VX@;F\@
M;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`B3&$@:6YF;W)M86-I\VX@>6$@
M;F\@97-TX2!D:7-P;VYI8FQE+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?
M;VQU;6X@069T97(B"FUS9W-T<B`B26YS97)T87(@8U]O;'5M;F$@9&5T<N%S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$W"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`B26YS
M97)T87(@:6UA9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(DEN
M<V5R=&%R('1A8FQA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@
M(DEN<V5R=&%R(';M;F-U;&\@5V5B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@
M7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B26YS97)T87(@7V-O;'5M;F$@9&5L
M86YT92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E
M<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B26YS97)T82!U;F$@;G5E=F$@
M8V]L=6UN82!D971RX7,@9&4@;&$@86-T=6%L(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("))
M;G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`B26YS97)T82!U;F$@;G5E=F$@8V]L=6UN82!D96QA;G1E(&1E(&QA
M(&%C='5A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E
M<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B26YS97)T82!U;F$@9FEL82!N
M=65V82!D96)A:F\@9&4@;&$@86-T=6%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E
M<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B
M26YS97)T82!U;F$@9FEL82!N=65V82!E;F-I;6$@9&4@;&$@86-T=6%L(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U
M<G)E;G0@;F]D92(*;7-G<W1R("));G-E<G1A('5N('#A<G)A9F\@=')A<R!E
M;"!N;V1O(&%C='5A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R
M87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(DEN<V5R=&$@
M=6X@<.%R<F%F;R!A;G1E<R!D96P@;F]D;R!A8W1U86PB"@HC.B!A9&UI;B]T
M96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP
M;&%T92(*;7-G<W1R("));G-E<G1A<B!P;&%N=&EL;&$@86QT97)N871I=F$B
M"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HR-#(*;7-G:60@(DEN
M<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV
M92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("));G-E<G1A<B!U;F$@9&ER
M96-C:?-N(&1E(&-O<G)E;R!E;B!L82!Q=64@<F5C:6)I<B!L82!C;VYT<F%S
M9?%A.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@
M(DEN<V5R=&%R(&-E;&1A(&1E='+A<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C
M96QL(&)E9F]R92(*;7-G<W1R("));G-E<G1A<B!C96QD82!A;G1E<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B26YS97)T
M87(@8V]L=6UN82!D971RX7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN
M(&)E9F]R92(*;7-G<W1R("));G-E<G1A<B!C;VQU;6YA(&%N=&5S(@H*(SH@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP(&QI8B](;W)D92])
M34%0+T%#3"]R9F,T,S$T+G!H<#HU,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S
M(@IM<V=S='(@(DEN<V5R=&%R(&UE;G-A:F5S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("))
M;G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(DEN<V5R=&%R('#A<G)A
M9F\@9&5T<N%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E
M9F]R92(*;7-G<W1R("));G-E<G1A<B!PX7)R869O(&%N=&5S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM
M<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("));G-E<G1A<B!F:6QA
M(&1E8F%J;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S
M='(@(DEN<V5R=&%R(&9I;&$@96YC:6UA(@H*(SH@8V]N9FEG+RYB86LO<')E
M9G,N<&AP+F1I<W0Z,C,S"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N
M<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(DEN<V5R
M=&%R(&QA(')E<W!U97-T82!N96-E<V%R:6$@82!L82!P<F5G=6YT82!D92!S
M96=U<FED860Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R
M("));G-E<G1A<B]-;V1I9FEC87(@:6UA9V5N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO
M9&EF>2!,:6YK(@IM<V=S='(@(DEN<V5R=&%R+TUO9&EF:6-A<B!V[6YC=6QO
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I
M9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB
M=71I;VX@;&ES="XB"FUS9W-T<B`B4V%L9&\@:6YS=69I8VEE;G1E('!A<F$@
M96YV:6%R(&$@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N+B(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC
M:65N="!C<F5D:70N(@IM<V=S='(@(E-A;&1O(&EN<W5F:6-I96YT92XB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`W-0IM<V=I9"`B26YT96=E<B(*;7-G
M<W1R(")%;G1E<F\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$S,PIM<V=I
M9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(DQI<W1A(&1E(&5N=&5R;W,B"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B
M26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B541(
M("A#86)E8V5R82!D92!$871O<R!D92!5<W5A<FEO*2!N;R!VX6QI9&$N(@H*
M(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,38W(&QI8B](;W)D92]#
M;VUP<F5S<R]Z:7`N<&AP.C$Y-`HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP
M+G!H<#HR,3(*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B1&%T
M;W,@6DE0(&YO(';A;&ED;W,B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R(")!<&QI
M8V%C:?-N(&YO(';A;&ED82XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T
M<B`B240@9&4@;&]T92!N;R!VX6QI9&\N(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(P.#<@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q-3@@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(R,S(*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R.3D@;&EB+TAO
M<F1E+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@
M9&%T82!S=6)M:71T960N(@IM<V=S='(@(E-E(&AA;B!E;G9I861O(&1A=&]S
M(&YO(';A;&ED;W,N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB
M"FUS9W-T<B`B1&ER96-C:?-N(&1E(&-O<G)E;R!N;R!VX6QI9&$N(@H*(SH@
M;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,3`Y(&QI8B](;W)D92]#;VUP
M<F5S<R]D8G@N<&AP.C$S.0HC.B!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H
M<#HR-#$*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B1F]R
M;6%T;R!D92!A<F-H:79O(&YO(';A;&ED;R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN
M(@IM<V=S='(@(D-L879E(&1E(&QI8V5N8VEA(&YO(';A;&ED82XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"FUS9VED("));G9A;&ED
M(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")392!H82!I;F1I8V%D;R!U
M;F$@=6)I8V%C:?-N(&YO(';A;&ED82XB"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB
M"FUS9W-T<B`B;7-G7W1Y<&4@;F\@=N%L:61O+B(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI
M<W-I;F<@87!I7VED+B(*;7-G<W1R(")A<&E?:60@;F\@=N%L:61O(&\@9&5S
M87!A<F5C:61O+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB
M"FUS9W-T<B`B4&%RX6UE=')O<R!N;R!VX6QI9&]S(&\@9&5S87!A<F5C:61O
M<RXB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN
M=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E!R:79I;&5G:6\@
M9&5L('!A9')E(&YO(';A;&ED;W,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$V,0IM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G
M<W1R("))1"!D92!A<V]C:6%D;R!N;R!VX6QI9&\N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B26YV86QI9"!P<F]D=6-T
M(&-O9&4N(@IM<V=S='(@(D/S9&EG;R!D92!P<F]D=6-T;R!N;R!VX6QI9&\N
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G
M:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(E!R;W1O8V]L;R!N;R!V
MX6QI9&\N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS
M(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HW,0HC.B!L:6(O3F5T+U--4R]W
M:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R
M96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R(")$97-T:6YA=&%R:6\@;F\@=N%L
M:61O.B!<(B5S7"(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$P.#`@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HQ,C8S"FUS9VED("));G9A;&ED('-H87)E(&]B
M:F5C="(*;7-G<W1R(")/8FIE=&\@8V]M<&%R=&ED;R!N;R!VX6QI9&\N(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@
M(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(D1I<F5C8VGS;B!D
M96P@<F5M:71E;G1E(&YO(';A;&ED82(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T
M82XB"FUS9W-T<B`B1&%T;W,@=6YI8V]D92!N;R!VX6QI9&]S+B(*"B,Z(&-O
M;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C,U.0IM<V=I9"`B26YV96YT
M;W)Y(@IM<V=S='(@(DEN=F5N=&%R:6\B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-C<X"FUS9VED("));G9E<G0@<V5L96-T:6]N
M(@IM<V=S='(@(DEN=F5R=&ER('-E;&5C8VGS;B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,3$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q.0IM<V=I9"`B27)A;BP@
M27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("))<N%N+"!297#Z8FQI8V$@
M27-LX6UI8V$@9&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,3@*;7-G:60@(DER87$B"FUS9W-T<B`B27)A<2(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,3,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,PIM
M<V=I9"`B27)E;&%N9"(*;7-G<W1R("))<FQA;F1A(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B
M27-L82!D92!-86XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B
M0F]R<F%S8V%S(&%I<VQA9&%S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3$T"FUS9VED("))<W)A96PB"FUS9W-T<B`B
M27-R865L(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,C8*;7-G
M:60@(DES<W5E<B(*;7-G<W1R(")%;6ES;W(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G
M<W1R(")#=7)S:79A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3(Q"FUS9VED("))=&%L>2(*;7-G<W1R("))=&%L:6$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,C,*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B2F%M86EC82(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#(@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S
M='(@(D5N97)O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3(U"FUS9VED(")*87!A;B(*;7-G<W1R(")*87#S;B(*"B,Z
M(&-O;F9I9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(DIA<&%N97-E
M("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B2F%P;V[I<R`H25-/+3(P,C(M2E`I
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y
M(@IM<V=S='(@(DIE<G-E>2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$R-`IM<V=I9"`B2F]R9&%N(@IM<V=S='(@(DIO
M<F3A;B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#@@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED
M(")*=6QY(@IM<V=S='(@(DIU;&EO(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P-R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B2G5N:6\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X
M"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(DIU<W1I9FEC87(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM
M<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B06QI;F5A<B!A;"!C96YT
M<F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(DIU<W1I
M9FEC87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(D%L
M:6YE87(@82!L82!I>G%U:65R9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2
M:6=H="(*;7-G<W1R(")!;&EN96%R(&$@;&$@9&5R96-H82(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@V(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,3D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-@IM<V=I9"`B
M2V%Z86MH<W1A;B(*;7-G<W1R(")+87IA:VAS=&%N(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V-0IM<V=I9"`B2V5E<"!O<FEG
M:6YA;#\B"FUS9W-T<B`BOT-O;G-E<G9A<B!E;"!O<FEG:6YA;#\B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C8*;7-G
M:60@(DME;GEA(@IM<V=S='(@(DME;GEA(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B16P@<V5R=FED;W(@2V5R8F5R;W,@
M:&$@<F5C:&%Z861O(&QA(&%U=&5N=&EF:6-A8VGS;BXB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S
M='(@(DYO=F%T;W,@9&5L($ME<FYE;"(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(D-R96%C
M:?-N(&1E(&-L879E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$T
M"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B2'5E;&QA(&1I9VET
M86P@9&4@;&$@8VQA=F4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT
M,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B5&%M8?%O(&1E(&-L879E
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@
M5'EP92(*;7-G<W1R(")4:7!O(&1E(&-L879E(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU.3D*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R(")5
M<V\@9&4@;&$@8VQA=F4Z(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M-S0P"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K
M97ES97)V97(N(@IM<V=S='(@(DQA(&-L879E('EA(&5X:7-T92!E;B!E;"!S
M97)V:61O<B!D92!C;&%V97,@</IB;&EC;RXB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B3FGQ;W,B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,CD*;7-G
M:60@(DMI<FEB871I(@IM<V=S='(@(DMI<FEB871I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$R,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,R"FUS9VED(")+;W)E
M82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R(")#
M;W)E82P@4F5P^F)L:6-A(%!O<'5L87(@1&5M;V-RX71I8V$@9&4B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S,*;7-G
M:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R(")#;W)E82P@4F5P^F)L
M:6-A(&1E(@H*(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD:7-T.C$Y,0IM<V=I
M9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(D-O<F5A;F\@*$550RU+4BDB
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,S0*;7-G:60@(DMU=V%I="(*;7-G<W1R(")+=7=A:70B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C<*;7-G:60@(DMY
M<F=Y>G-T86XB"FUS9W-T<B`B2WER9WEZ<W1A;B(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R(")?1&ES
M=')I8G5C:?-N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM
M<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B261I;VUA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$R-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,W"FUS9VED("),86\@
M4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("),86\L(%)E
M</IB;&EC82!$96UO8W+A=&EC82!0;W!U;&%R(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(D-U87)T;R!M
M96YG=6%N=&4B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#@*;7-G:60@
M(DQA<W0@4&%S<W=O<F0@0VAA;F=E(@IM<V=S='(@(MIL=&EM;R!C86UB:6\@
M9&4@8V]N=')A<V7Q82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R
M(")#=6%R=&\@;65N9W5A;G1E(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M-3@*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`BVFQT:6UA(&%C='5A
M;&EZ86-I\VXZ(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C<Q-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R("+:;'1I;6$@
M<V5S:?-N.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R
M("+:;'1I;6$@<V5S:?-N.B`E<R!D97-D92`E<R(*"B,Z(&QI8B](;W)D92]!
M=71H+G!H<#HW,30*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@
M(MIL=&EM82!S97-I\VXZ($YU;F-A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30V"FUS9VED("),871V:6$B"FUS9W-T
M<B`B3&%T=FEA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED
M("),87<B"FUS9W-T<B`B3&5Y97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*;7-G:60@(DQA>6]U="(*;7-G
M<W1R(")$:7-T<FEB=6-I\VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@
M8F]R9&5R(@IM<V=S='(@(D1E:F%R(&5N(&)L86YC;R!P87)A(&5L:6UI;F%R
M(&5L(&)O<F1E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3,X"FUS9VED("),96)A;F]N(@IM<V=S='(@(DQE8F%N;VXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#`*;7-G:60@(DQE9G0B"FUS9W-T<B`B27IQ=6EE<F1A(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,Q,#$*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S
M='(@(D-A8F5C97)A(&EZ<75I97)D82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HS,#DW"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R(")686QO<F5S(&1E
M(&QA(&EZ<75I97)D82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$T,PIM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("),97-O
M=&AO(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED
M("),979E;"(*;7-G<W1R(").:79E;"(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,@IM<V=I9"`B3&EB97)I82(*;7-G
M<W1R("),:6)E<FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,30W"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA
M(@IM<V=S='(@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#`*;7-G:60@(DQI
M96-H=&5N<W1E:6XB"FUS9W-T<B`B3&EE8VAT96YS=&5I;B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H
M="!$<FEZ>FQE(@IM<V=S='(@(DQI9V5R82!L;&]V:7IN82(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"FUS9VED("),:6=H
M="!286EN(@IM<V=S='(@(DQL=79I82!L:6=E<F$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I
M;B!%87)L>2(*;7-G<W1R("),;'5V:6$@;&EG97)A(&UA='5T:6YA(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@
M(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R("),;'5V:6$@;&EG97)A('9E<W!E
M<G1I;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR.0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B06=U86-E
M<F\@;&EG97)O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S
M='(@(DQL=79I87,@>2!T<G5E;F]S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T
M<B`B3F5V861A('-U879E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S
M='(@(DQI9V5R;R!A9W5A8V5R;R!D92!N:65V92(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B0VAA<V-A
M<G)I;&QO(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X,30*;7-G:60@(DQI
M;FLB"FUS9W-T<B`B5NUN8W5L;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN
M=',@=&\Z(@IM<V=S='(@(D5L(';M;F-U;&\@87!U;G1A(&$Z(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$X-S4*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D
M9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS
M9W-T<B`B5FEN8W5L87(@9&ER96-C:?-N(&1E(&-O<G)E;R!A(&QA('#A9VEN
M82!D92!C;VUP;W-I8VGS;B!A;"!M;W-T<F%R(@H*(SH@;&EB+TAO<F1E+U1E
M>'0O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@R"FUS9VED("),:6YK<R(*;7-G
M<W1R(")6[6YC=6QO<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM
M<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(D-O;VMI92!,:6YU>"(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX-B!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A
M;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("),:7-T87(@+2!E;"!U<W5A<FEO
M('!U961E(&5X86UI;F%R(&QA(&-A<G!E=&$B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3,T"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R("),:7-T
M87(@8F%S97,@9&4@9&%T;W,B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H
M<#HU,0IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R("),:7-T87(@
M=&5M87,@9&4@87EU9&$B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS
M9VED("),:7-T(%1A8FQE<R(*;7-G<W1R("),:7-T87(@=&%B;&%S(@H*(SH@
M;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-C`Q"FUS9VED("),:7-T+4%R
M8VAI=F4B"FUS9W-T<B`B3&ES="U!<F-H:79E(@H*(SH@;&EB+TAO<F1E+TU)
M344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`B
M3&ES="U(96QP(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-C`S
M"FUS9VED("),:7-T+4ED(@IM<V=S='(@(DQI<W0M260B"@HC.B!L:6(O2&]R
M9&4O34E-12](96%D97)S+G!H<#HU.3D*;7-G:60@(DQI<W0M3W=N97(B"FUS
M9W-T<B`B3&ES="U/=VYE<B(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N
M<&AP.C8P,`IM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(DQI<W0M4&]S="(*
M"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y.`IM<V=I9"`B3&ES
M="U3=6)S8W)I8F4B"FUS9W-T<B`B3&ES="U3=6)S8W)I8F4B"@HC.B!L:6(O
M2&]R9&4O34E-12](96%D97)S+G!H<#HU.3<*;7-G:60@(DQI<W0M56YS=6)S
M8W)I8F4B"FUS9W-T<B`B3&ES="U5;G-U8G-C<FEB92(*"B,Z(&%D;6EN+W-E
M<W-I;VYS+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E
M<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`B2&$@9F%L;&%D;R!E;"!L:7-T
M861O(&1E(&QA<R!S97-I;VYE<SH@)7,B"@HC.B!A9&UI;B]S97-S:6]N<RYP
M:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!F86EL
M960Z("5S(@IM<V=S='(@(DAA(&9A;&QA9&\@96P@;&ES=&%D;R!D92!U<W5A
M<FEO<SH@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC
M.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@
M(D5L(&QI<W1A9&\@9&4@=7-U87)I;W,@97-TX2!D97-H86)I;&ET861O+B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R
M92(*;7-G<W1R("),:71E<F%T=7)A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30T"FUS9VED("),:71H=6%N:6$B"FUS
M9W-T<B`B3&ET=6%N:6$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6UA
M9V5S+G!H<#HW-PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R("),97EE;F1O
M+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P,`IM<V=I
M9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(DAO<F$@;&]C86PZ("(*"B,Z(&-O
M;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C@V"FUS9VED("),;V-A;&4@86YD
M(%1I;64B"FUS9W-T<B`B261I;VUA('D@:&]R82(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z-S(@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-R!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4W,@IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B56)I8V%C:?-N
M(@H*(SH@;&]G:6XN<&AP.C$X.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP
M:'`Z,C`T('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*(SH@=&5M<&QA
M=&5S+VQO9VEN+VUO8FEL92YI;F,Z,R!T96UP;&%T97,O;&]G:6XO;6]B:6QE
M+FEN8SHQ-0IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(DEN:6-I87(@<V5S:?-N
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),
M;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(E)E9VES=')O
M(&1E(&QA<R!S97-I;VYE<R!D92!S:6YC<F]N:7IA8VGS;B!A;G1E<FEO<F5S
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y.`IM<V=I9"`B
M3&]G(&]U="(*;7-G<W1R(")386QI<B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HV,0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B26YI8VEA<B!S97-I\VXB
M"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ,3`*;7-G:60@(DQO
M9VEN(%1A<VMS(@IM<V=S='(@(E1A<F5A<R!D92!I;FEC:6\@9&4@<V5S:?-N
M(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDY-0IM<V=I9"`B3&]G:6X@9F%I
M;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT
M97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB1F%L;/,@96P@:6YI8VEO
M(&1E('-E<VGS;B!P;W)Q=64@:6YT<F]D=6IO(&EN8V]R<F5C=&%M96YT92!S
M=2!N;VUB<F4@9&4@(@HB=7-U87)I;R!O(&-O;G1R87-E\6$N(@H*(SH@;&EB
M+TAO<F1E+T%U=&@N<&AP.CDY,0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G
M<W1R(")&86QL\R!E;"!I;FEC:6\@9&4@<V5S:?-N+B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,S8U"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B5&5X
M=&\@8V]M<&QE=&\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G
M:60@(DQO=F4B"FUS9W-T<B`B06UO<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED("),;W<B"FUS9W-T<B`B0F%J
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T
M<B`B06QF86)E=&\@9W)I96=O(&5N(&UI;OIS8RXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED
M("),;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@(D%L9F%B971O(&QA=&EN
M;R!E;B!M:6[Z<V,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M
M8F5R<R(*;7-G<W1R(").^FUE<F]S(')O;6%N;W,@96X@;6EN^G-C+B(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,S0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-0IM
M<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("),=7AE;6)U<F=O(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,2!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")-32(*"B,Z(&-O;F9I9R\N8F%K
M+W)E9VES=')Y+G!H<"YD:7-T.C(X,PIM<V=I9"`B34]41"(*;7-G<W1R(")-
M3U1$(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS
M9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM
M<V=S='(@(D5L(&%D:G5N=&\@35,M5$Y%1B!N;R!C;VYT96[M82!D871O<RXB
M"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP
M:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R(")-4T<B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3<*;7-G:60@(DUA8V%O
M(@IM<V=S='(@(DUA8V%O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,34S"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M
M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B36%C961O;FEA+"!!
M;G1I9W5A(%)E</IB;&EC82!9=6=O<VQA=F$@9&4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3$*;7-G:60@(DUA9&%G
M87-C87(B"FUS9W-T<B`B36%D86=A<V-A<B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B36%G:6$B"@HC.B!C
M;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HX,PIM<V=I9"`B36%I;"(*
M;7-G<W1R(")#;W)R96\B"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N
M9&ES=#HU,C0*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B061M+B!C;W)R
M96\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B0W)E
M87(@7W;M;F-U;&\N+BXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-C4*;7-G:60@(DUA;&%W:2(*;7-G<W1R(")-86QA
M=VDB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-C<*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(DUA;&%S:6$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C0*;7-G
M:60@(DUA;&1I=F5S(@IM<V=S='(@(DUA;&1I=F%S(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$T,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34T"FUS9VED(")-86QI
M(@IM<V=S='(@(DUA;&DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-C(*;7-G:60@(DUA;'1A(@IM<V=S='(@(DUA;'1A
M(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z.30*;7-G:60@(B(*
M(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA
M8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H
M('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*(D=E<W1I;VYA(&QA(&QI
M<W1A(&1E(&-A=&5G;W+M87,@8V]N(&QA('%U92!E=&EQ=65T87(@96QE;65N
M=&]S('D@;&]S(&-O;&]R97,@(@HB87-O8VEA9&]S(&$@9&EC:&%S(&-A=&5G
M;W+M87,N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Q-38*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R(")-87!A(&UA<#(T(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#<*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-S$*;7-G:60@
M(DUA<%%U97-T(&UA<"(*;7-G<W1R(")-87!A(&UA<'%U97-T(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S
M=&]R960N(@IM<V=S='(@(D-O<G)E<W!O;F1E;F-I87,@86QM86-E;F%D87,N
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-"!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA
M<F-H(@IM<V=S='(@(DUA<GIO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN(@IM<V=S
M='(@(DUA<F=E;B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX."!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#@*;7-G:60@
M(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R(")-87)C87(@
M8V]N(&QA<R!B86YD97)A<R!D92!,9>UD;R]3:6X@;&5E<B(*"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX.2!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C-#,Q-"YP:'`Z-#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G
M<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(DUA<F-A<B!C
M;VX@;W1R87(@8F%N9&5R87,@*'`N92X@26UP;W)T86YT92]297-P;VYD:61O
M*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDQ(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$U,@IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R("))<VQA<R!-
M87)S:&%L;"(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$U.0IM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R(")-87)T:6YI
M8V$B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B
M36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(D-A;7!O<R!C;VEN8VED96YT97,B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-C`*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B36%U<FET86YI82(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,PIM
M<V=I9"`B36%U<FET:75S(@IM<V=S='(@(DUA=7)I8VEO(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO
M=V5D(&-R961I="XB"FUS9W-T<B`B4V%L9&\@;>%X:6UO('!E<FUI=&ED;RXB
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I
M9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(E-E(&AA
M('-O8G)E<&%S861O(&5L(&[Z;65R;R!MX7AI;6\@9&4@<&%R=&5S(&1E(&UE
M;G-A:F4N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3,*;7-G:60@(DUA
M>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")496UP+B!MX7AI;6$@
M^FQT:6UA<R`R-"!H;W)A<SH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,#4*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(E1E
M;7`N(&WA>&EM82#Z;'1I;6%S(#8@:&]R87,Z("(*"B,Z(&QI8B]A<&DN<&AP
M.C@V"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM
M<V=S='(@(D[Z;65R;R!MX7AI;6\@9&4@8FQO<75E<R!D96P@<&]R=&%L(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y."!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3(Q-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L
M96YG=&@B"FUS9W-T<B`B3&]N9VET=60@;>%X:6UA(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R(")-87EO
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(U,PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R(")-87EO='1E(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R
M(")-961I8VEN82(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI
M;F,Z,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B36EE;6)R;W,B"@HC.B!C
M;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HS.#(*;7-G:60@(DUE;G4@;6]D
M93HB"FUS9W-T<B`B1F]R;6%T;R!D96P@;65N^CHB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-
M97)G92!C96QL<R(*;7-G<W1R(")#;VUB:6YA<B!C96QD87,B"@HC.B!L:6(O
M2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E
M(@IM<V=S='(@(DUE;G-A:F4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L
M;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@
M(@HB=F5R:69I960N(@IM<V=S='(@(B(*(E-E(&AA(&-O;7!R;V)A9&\@8V]R
M<F5C=&%M96YT92!E;"!M96YS86IE('!E<F\@;F\@<V4@<'5E9&4@=F5R:69I
M8V%R(&5L("(*(F-E<G1I9FEC861O(&1E;"!F:7)M86YT92XB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S<V%G
M92!E>'!I<F5D+B(*;7-G<W1R(")-96YS86IE(&-A9'5C861O+B(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU-CD@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8P,@IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(E1I<&\@9&4@
M;65N<V%J92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T
M87(@5V5A=&AE<B(*;7-G<W1R(")4:65M<&\@9&4@365T87(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R(")";&]Q=64@365T87(@;F\@9&ES<&]N:6)L92XB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B(@HB365T87(@
M8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB0FQO<75E($UE
M=&%R(&YO(&1I<W!O;FEB;&4N(%-E(&AA;B!R96=I<W1R861O(&QO<R!D971A
M;&QE<R!P87)A(&5L("(*(F%D;6EN:7-T<F%D;W(N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$U,PIM<V=I9"`B365T87)$0B!I<R!N;W0@
M8V]N;F5C=&5D+B(*;7-G<W1R(").;R!E<W3A(&-O;F5C=&%D82!L82!-971A
M<D1"(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*
M;7-G<W1R(")-Z71O9&\B"@HC.B!L:6(O2&]R9&4O4E!#+W-O87`N<&AP.C$Q
M-R!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z.#$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R(")%
M;"!MZ71O9&\@7"(E<UPB(&YO(&5S=.$@9&5F:6YI9&\B"@HC.B!L:6(O2&]R
M9&4O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO
M9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B3>ET
M;V1O(&YO(&1E9FEN:61O+B!-Z71O9&\@;&QA;6%D;SH@)7,B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C@R(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HV-PIM<V=I9"`B365T<FEC(@IM<V=S='(@(DWI=')I8V\B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C8*;7-G:60@
M(DUE>&EC;R(*;7-G<W1R(")-Z6II8V\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-0IM<V=I9"`B36EC<F]N97-I82P@
M1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R(")-:6-R;VYE<VEA+"!%<W1A
M9&]S($9E9&5R861O<R!D92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@IM<V=I9"`B36ED9&QE(@IM<V=S='(@
M(D5N(&UE9&EO(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP
M.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B5&EP;R!-:6UE(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3<*;7-G:60@(DUI;B!T96UP(&QA<W0@
M,C0@:&]U<G,Z("(*;7-G<W1R(")496UP+B!M[6XN(&QA<R#Z;'1I;6%S(#(T
M(&AO<F%S.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P.0IM<V=I9"`B
M36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B5&5M<"X@;>UN+B!L
M87,@^FQT:6UA<R`V(&AO<F%S.B`B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P
M+G!H<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@
M>65T(&5X<&ER960B"FUS9W-T<B`B5&]D87;M82!N;R!H82!E>'!I<F%D;R!L
M82!A;G1I9_QE9&%D(&WM;FEM82!D92!L82!C;VYT<F%S9?%A(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-0IM<V=I9"`B36ER
M<F]R(@IM<V=S='(@(E)E9FQE:F%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(DUI<V-E;.%N
M96$B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,"!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&QI8B].970O
M4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K
M86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B4&%Q=65T92!014%2($A45%!?
M4F5Q=65S="!D97-A<&%R96-I9&\N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$Q-`IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@
M:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H
M:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*(D9A;'1A(&QA(&-O;F9I
M9W5R86-I\VXN(%1I96YE('%U92!G96YE<F%R;&$@86AO<F$@<VD@9&5S96$@
M=71I;&EZ87(@97-T82`B"B)A<&QI8V%C:?-N+B(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A
M9V4@240N(@IM<V=S='(@(DE$(&1E(&UE;G-A:F4@9&5S87!A<F5C:61O+B(*
M"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G
M:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S
M='(@(E!A<75E=&4@4$5!4B!-86EL(&1E<V%P87)E8VED;RXB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN
M9R!S97-S:6]N($E$+B(*;7-G<W1R("))1"!D92!S97-I\VX@9&5S87!A<F5C
M:61O+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(DQU;B(*"B,Z(&-O;F9I9R\N8F%K
M+W)E9VES=')Y+G!H<"YD:7-T.C<V"FUS9VED(")-;V)I;&4@36%I;"(*;7-G
M<W1R(")#;W)R96\@;?-V:6PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B36]D
M97)A9&\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV-B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-0HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O>FEP+G!H<#HW,PIM<V=I9"`B36]D:69I960@1&%T92(*
M;7-G<W1R(")392!H82!M;V1I9FEC861O(&QA(&9E8VAA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS
M9VED(")-;V1I9GD@55),(@IM<V=S='(@(DUO9&EF:6-A<B!54DPB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8W-`IM<V=I9"`B36]D=6QU<R(*
M;7-G<W1R(")-\V1U;&\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(DUO;&1A=FEA+"!297#Z8FQI8V$@9&4B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#D*;7-G:60@(DUO
M;F%C;R(*;7-G<W1R(")-\VYA8V\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-38*;7-G:60@(DUO;F=O;&EA(@IM<V=S
M='(@(DUO;F=O;&EA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.#0*;7-G
M:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(DUE<R!Y(&'Q;R(*"B,Z(&QI
M8B](;W)D92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS
M9W-T<B`B365N<W5A;&UE;G1E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,38Q"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S
M='(@(DUO;G1S97)R870B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@
M(D9A<V5S(&1E(&QA(&QU;F$B"@HC.B!L:6(O1FEL92]#4U8N<&AP.C$Y-B!L
M:6(O1FEL92]#4U8N<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E
M(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D
M+B(*;7-G<W1R(")392!H86X@96YC;VYT<F%D;R!MX7,@8V%M<&]S(&5N(&QA
M(&SM;F5A("5D('%U92!L;W,@)60@97-P97)A9&]S+B(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDP(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-30*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T.`IM<V=I9"`B36]R
M;V-C;R(*;7-G<W1R(")-87)R=65C;W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM
M<V=S='(@(D9U;F1A;65N=&%L;65N=&4@9&5S<&5J861O(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G:60@(DUO<W1L
M>2!#;&]U9'DB"FUS9W-T<B`B1G5N9&%M96YT86QM96YT92!N=6)O<V\B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I
M9"`B36]S=&QY($-L;W5D>2!A;F0@5VEN9'DB"FUS9W-T<B`B1G5N9&%M96YT
M86QM96YT92!N=6)O<V\@>2!V96YT;W-O(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@(DUO<W1L>2!3=6YN>2(*
M;7-G<W1R(")&=6YD86UE;G1A;&UE;G1E('-O;&5A9&\B"@HC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T.`IM<V=I9"`B36]V92!$
M;W=N(@IM<V=S='(@(D1E<W!L87IA<B!H86-I82!A8F%J;R(*"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4R"FUS9VED(")-;W9E
M($QE9G0B"FUS9W-T<B`B1&5S<&QA>F%R(&$@;&$@:7IQ=6EE<F1A(@H*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-38*;7-G:60@
M(DUO=F4@4FEG:'0B"FUS9W-T<B`B1&5S<&QA>F%R(&$@;&$@9&5R96-H82(*
M"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0T"FUS
M9VED(")-;W9E(%5P(@IM<V=S='(@(D1E<W!L87IA<B!H86-I82!A<G)I8F$B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V"FUS
M9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B1&5S<&QA>F%R(&AA8VEA(&%B86IO
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-2!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V"FUS9VED(")-
M;W9E('5P(@IM<V=S='(@(D1E<W!L87IA<B!H86-I82!A<G)I8F$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C@*;7-G
M:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B36]Z86UB:7%U92(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,3@T"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O
M=VX@;&ES=',B"FUS9W-T<B`B3&ES=&%S(&1E<W!L96=A8FQE<R!M=6QT:2UN
M:79E;"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#4Y"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B36%P82!52R!M
M^FQT:7!L92(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C0R"FUS9VED(")-
M=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B4V5L96-C:?-N(&WZ;'1I<&QE
M(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z-#`R"FUS9VED
M(")->2!!8V-O=6YT(@IM<V=S='(@(DED96YT:61A9"(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HR.`IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO
M;B(*;7-G<W1R(")-:2!I9&5N=&ED860B"@HC.B!S97)V:6-E<R]P;W)T86PO
M:6YD97@N<&AP.C0T"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B36D@<&]R
M=&%L(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C0R"FUS9VED(")-
M>2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(D1I<W1R:6)U8VGS;B!D92!M:2!P
M;W)T86PB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-34*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B37EA;FUA<B(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS
M9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B3D\L($Y/(&5S=&]Y
M(&1E(&%C=65R9&\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP
M:'`Z,S@@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(").86UE(@IM<V=S
M='(@(DYO;6)R92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$V.0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R(").86UI8FEA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$U.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3<X"FUS9VED(").875R=2(*;7-G<W1R(").875R=2(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDW(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-3D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-PIM<V=I9"`B3F5P
M86PB"FUS9W-T<B`B3F5P86PB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-S4*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S
M='(@(DAO;&%N9&$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS
M9W-T<B`B06YT:6QL87,@2&]L86YD97-A<R(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G
M<W1R(")54DP@8F%S92!D92!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N
M(%523"(*;7-G<W1R(")54DP@9&4@86YU;&%C:?-N(&1E($-!(&1E($YE='-C
M87!E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@
M(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B55),(&1E('!O;.UT
M:6-A<R!D92!#02!D92!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G
M<W1R(")54DP@9&4@<F5N;W9A8VGS;B!D92!.971S8V%P92(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!2979O
M8V%T:6]N(%523"(*;7-G<W1R(")54DP@9&4@86YU;&%C:?-N(&1E($YE='-C
M87!E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@
M(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R(").;VUB<F4@9&4@
M<V5R=FED;W(@4U-,(&1E($YE='-C87!E(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU.#@*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O
M;6UE;G0B"FUS9W-T<B`B0V]M96YT87)I;R!D96P@8V5R=&EF:6-A9&\@9&4@
M3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,0IM
M<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R(")4:7!O
M(&1E(&-E<G1I9FEC861O(&1E($YE='-C87!E(@H*(SH@8V]N9FEG+RYB86LO
M<F5G:7-T<GDN<&AP+F1I<W0Z,C4S"FUS9VED(").971W;W)K(@IM<V=S='(@
M(E)E9"(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O
M+F)A:R]P<F5F<RYP:'`N9&ES=#HS,SD*(SH@8V]N9FEG+RYB86LO<')E9G,N
M<&AP+F1I<W0Z,SDP"FUS9VED(").979E<B(*;7-G<W1R(").=6YC82(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-C(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,`IM
M<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R(").=65V82!#86QE9&]N:6$B
M"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM
M<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(DYU979A(&-A=&5G;W+M82(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS
M9W-T<B`B3'5N82!N=65V82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM
M<V=S='(@(DYU979O(&YO;6)R92!D92!U<W5A<FEO("AO<&-I;VYA;"DB"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#`*
M;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(DYU979A(%IE;&%N9&$B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*;7-G:60@(DYE=R!P
M87-S=V]R9"(*;7-G<W1R(")#;VYT<F%S9?%A(&YU979A(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W
M('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("),82!N=65V
M82!C;VYT<F%S9?%A(&5X<&ER87+A(&5L("5X+B(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG
M="!M871C:"XB"FUS9W-T<B`B3&%S(&-O;G1R87-E\6%S(&YO(&-O:6YC:61E
M;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(DYU979A
M('9E;G1A;F$@*%]B;&%N:RDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3(@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`*(SH@8V]N9FEG+RYB86LO<F5G
M:7-T<GDN<&AP+F1I<W0Z,CDQ"FUS9VED(").97=S(@IM<V=S='(@(DYO=&EC
M:6%S(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,S`W"FUS
M9VED(").97=S9W)O=7!S(@IM<V=S='(@(D<N(&1E(&YO=&EC:6%S(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHQ,CD*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z
M-#$@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34*;7-G:60@(DYE>'0B
M"FUS9W-T<B`B4VEG=6EE;G1E(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W
M"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(E!R\WAI;6%S(#0@9F%S
M97,B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V-B!L:6(O2&]R9&4O
M4')E9G,O54DN<&AP.C,W,`IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@
M(D]P8VEO;F5S('-I9W5I96YT97,B"@HC.B!L:6(O2&]R9&4O54DO4&%G97(N
M<&AP.C$P,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B4VEG=6EE;G1E/B(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-C0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-`IM
M<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(DYI8V%R86=U82(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDV(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-C4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,0IM<V=I9"`B
M3FEG97(B"FUS9W-T<B`B3FEG97(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-S,*;7-G:60@(DYI9V5R:6$B"FUS9W-T
M<B`B3FEG97)I82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M-CD*;7-G:60@(DYI9VAT(@IM<V=S='(@(DYO8VAE(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$V-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Y"FUS9VED(").:75E
M(@IM<V=S='(@(DYI=64B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.38V"FUS9VED(").;R(*;7-G<W1R(").;R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A:6QA
M8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O
M<BXB"FUS9W-T<B`B3F\@:&%Y(&1A=&]S(&1E(&-O;F9I9W5R86-I\VX@<&%R
M82!M;W-T<F%R(&1I9F5R96YC:6%S+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+G!H<#HQ,#8*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K
M:6YG($E33R!I;6%G97,N(@IM<V=S='(@(DYO('-E(&1I<W!O;F4@9&4@97-T
M<F%T96=I82!D92!E;&%B;W)A8VGS;B!D92!I;>%G96YE<R!)4T\N(@H*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO
M(&)A=&-H('1E;7!L871E+B(*;7-G<W1R(").;R!H87D@<&QA;G1I;&QA(&1E
M(&QO=&5S(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HQ,#$*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HS
M.#4*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT,#<*
M;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET
M:6]N(@IM<V=S='(@(DYO(&AA>2!B;&]Q=65S(&5N(&QA('!O<VEC:?-N(&EN
M9&EC861A(@H*(SH@;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'`Z-3`*;7-G:60@
M(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(DYO('-E(&AA(&EN=')O9'5C:61O('5N(&YO;6)R
M92!D92!A9V5N9&$@<&%R82!L82!A=71E;G1I9FEC86-I\VX@34-!3"XB"@HC
M.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`IM<V=I9"`B3F\@8VAA;F=E+B(*
M;7-G<W1R(")3:6X@8V%M8FEO<RXB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H
M:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B3F\@<V4@<'5E9&5N(&'Q861I<B!D
M97-C96YD:65N=&5S(&$@97-T92!P<FEV:6QE9VEO+B(*"B,Z(&QI8B](;W)D
M92YP:'`Z,3<X(&QI8B](;W)D92YP:'`Z-3$W(&QI8B](;W)D92]5=&EL+G!H
M<#HW.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R(").;R!S92!H
M82!E<W!E8VEF:6-A9&\@:6YF;W)M86-I\VX@9&4@8V]N9FEG=7)A8VGS;B!P
M87)A("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX-C@*;7-G:60@(DYO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93
M+B(*;7-G<W1R(").;R!S92!H82!E<W!E8VEF:6-A9&\@:6YF;W)M86-I\VX@
M9&4@8V]N9FEG=7)A8VGS;B!P87)A(%9&4R!P;W(@1E10+B(*"B,Z(&QI8B]6
M1E,O<W%L+G!H<#HV.#0*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R(").;R!S92!H
M82!E<W!E8VEF:6-A9&\@:6YF;W)M86-I\VX@9&4@8V]N9FEG=7)A8VGS;B!P
M87)A(%9&4R!P;W(@4U%,+B(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<U
M,PIM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B(@HB3F\@<V4@:&$@97-P
M96-I9FEC861O(&EN9F]R;6%C:?-N(&1E(&-O;F9I9W5R86-I\VX@<&%R82!6
M1E,@<&]R(&%R8VAI=F\@4U%,+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T
M<B`B3F\@<75E9&$@<V%L9&\N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N
M(@IM<V=S='(@(DYO('-E(&AA(&EN=')O9'5C:61O(&5L(&1E<W1I;F\N(@H*
M(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDQ.`IM<V=I9"`B3F\@9FEL92!U
M<&QO861E9"(*;7-G<W1R(").;R!S92!H82!C87)G861O(&YI;F?Z;B!A<F-H
M:79O(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I
M8V]N<R!F;W5N9"XB"FUS9W-T<B`B3F\@<V4@:&%N(&5N8V]N=')A9&\@:6-O
M;F]S+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3,P(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3$V"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(DYO('-E
M(&AA(&1E9FEN:61O(&QA('5B:6-A8VGS;BXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,34W"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E
M9"XB"FUS9W-T<B`B3F\@<V4@:&$@9&5F:6YI9&\@;&$@=6)I8V%C:?-N+B(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@
M(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(DYO('-E(&AA(&EN=')O
M9'5C:61O('5N(&UE;G-A:F4N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S
M='(@(DYO('-E(&AA(&5S<&5C:69I8V%D;R!U;B!N;VUB<F4N(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M
M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B3F\@<V4@:&$@97-P96-I9FEC861O
M('5N(&[Z;65R;RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G
M:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(").;R!O9F5N<VEV
M87,B"@HC.B!L:6(O2&]R9&4O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(DYO('-E(&AA(&EN=')O9'5C:61O('5N82!C;VYT<F%S9?%A('!A
M<F$@;&$@875T96YT:69I8V%C:?-N($A45%`N(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F\@<V4@:&$@:6YT
M<F]D=6-I9&\@=6YA(&-O;G1R87-E\6$@<&%R82!L82!A=71E;G1I9FEC86-I
M\VX@24U!4"XB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HW,@IM<V=I
M9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R(").;R!S92!H82!I;G1R;V1U8VED;R!U;F$@8V]N
M=')A<V7Q82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!+97)B97)O<RXB"@HC
M.B!L:6(O2&]R9&4O075T:"]L;V=I;BYP:'`Z.#0@;&EB+TAO<F1E+T%U=&@O
M<&%M+G!H<#HW-0HC.B!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HW-PIM<V=I
M9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R(").;R!S92!H82!I;G1R;V1U8VED;R!U;F$@8V]N=')A
M<V7Q82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!D92!I;FEC:6\N(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(DYO('-E(&AA(&EN=')O9'5C:61O('5N82!C;VYT<F%S9?%A('!A<F$@
M;&$@875T96YT:69I8V%C:?-N(%!!4U-71"XB"@HC.B!L:6(O2&]R9&4O075T
M:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").;R!S92!H82!I;G1R;V1U
M8VED;R!U;F$@8V]N=')A<V7Q82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!3
M34(N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C@W"FUS9VED
M("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@
M5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I
M=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"B).;R!S92!H82!I;F1I8V%D
M;R!V[6$@9&4@86-C97-O(&$@;&]S(&)I;F%R:6]S($]P96Y34TPN(%!A<F$@
M=')A8F%J87(@8V]N("(*(F1A=&]S(%!+0U,@,3(@:&%C96X@9F%L=&$@;&]S
M(&)I;F%R:6]S($]P96Y34TPN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G
M<W1R(")3:6X@86QT87,@<&5N9&EE;G1E<RXB"@HC.B!L:6(O5D93+G!H<#HW
M-C8*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B0V%R96-E(&1E('%U
M;W1A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(E-I;B!R87EA
M<R(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#@R"FUS9VED(").;R!S97!A<F%T
M;W(@<W!E8VEF:65D+B(*;7-G<W1R(").;R!S92!H82!E<W!E8VEF:6-A9&\@
M=6X@<V5P87)A9&]R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@
M(DYI;F=U;F\B"@HC.B!L:6(O5D93+W-M8BYP:'`Z-C`P"FUS9VED(").;R!S
M=6-H(&9I;&4B"FUS9W-T<B`B3F\@97AI<W1E(&5L(&%R8VAI=F\B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(V"FUS9VED(").;R!T96UP
M;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@
M(DYO('-E(&1I<W!O;F4@9&4@=6X@9&ER96-T;W)I;R!D92!A;&UA8V5N86UI
M96YT;R!T96UP;W)A;"XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,Q(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@
M(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R(").
M;R!S92!H82!E;G9I861O(&5L(&YO;6)R92!D92!U<W5A<FEO('DO;R!L82!C
M;VYT<F%S9?%A+B(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HQ-#`*
M;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(DYO
M('-E(&AA;B!D979U96QT;R!D871O<R!834P@=N%L:61O<R(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY-S0@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX-`HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.3DU"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#$R"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`B
M4VEN('9A;&]R97,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$Y"FUS
M9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I
M;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB3F\@
M<V4@96YC;VYT<O,@;&$@=F5R<VGS;B!E;B!L82!C;VYF:6=U<F%C:?-N(&]R
M:6=I;F%L+B!296=E;F5R87(@;&$@(@HB8V]N9FEG=7)A8VGS;BXB"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(W"FUS9VED(").;R!V97)S:6]N(&9O
M=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("(B"B).;R!S92!E;F-O;G1R\R!L82!V97)S:?-N
M(&5N(&QA(&-O;F9I9W5R86-I\VXN(%)E9V5N97)A<B!L82!C;VYF:6=U<F%C
M:?-N+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R-R!T96UP;&%T
M97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*;7-G:60@(DYO
M;F4B"FUS9W-T<B`B3FEN9W5N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I
M="DB"FUS9W-T<B`B3FEN9W5N;R`H=7-O(&EM<&SM8VET;RDB"@HC.B!C;VYF
M:6<O+F)A:R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(").;W)D:6,@*$E33RTX
M.#4Y+3$P*2(*;7-G<W1R(").\W)D:6-O("A)4T\M.#@U.2TQ,"DB"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S(*;7-G
M:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(DES;&$@9&4@3F]R9F]L:R(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B2&5M:7-F
M97)I;R!N;W)T92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$U.`IM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S
M(@IM<V=S='(@(DES;&%S($UA<FEA;F%S(&1E;"!.;W)T92(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDW(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-S`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-@IM<V=I9"`B
M3F]R=V%Y(@IM<V=S='(@(DYO<G5E9V$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C8T,0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(DYO(&1E
M<W!UZ7,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I
M9"`B3F]T($)E9F]R92(*;7-G<W1R(").;R!A;G1E<R(*"B,Z(&QI8B]61E,O
M9FEL92YP:'`Z-#(Q"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B
M3F\@97,@=6X@9&ER96-T;W)I;R(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H
M<#HV,R!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z
M-#@*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP
M.C4Y"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP
M:'`Z.#0*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+G!H<#HY-0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R(")3:6X@
M9&5S87)R;VQL87(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*;7-G<W1R(")3:6X@97-T
M86)L96-E<B(*"B,Z(&QI8B]61E,N<&AP.C$Y,R!L:6(O5D93+G!H<#HR,#@@
M;&EB+U9&4RYP:'`Z,C,T(&QI8B]61E,N<&AP.C(U,@HC.B!L:6(O5D93+G!H
M<#HR-CD@;&EB+U9&4RYP:'`Z,C@U(&QI8B]61E,N<&AP.C,P,2!L:6(O5D93
M+G!H<#HS,38*(SH@;&EB+U9&4RYP:'`Z,S,S(&QI8B]61E,N<&AP.C,V-B!L
M:6(O5D93+G!H<#HT,C8@;&EB+U9&4RYP:'`Z-3`U"B,Z(&QI8B]61E,N<&AP
M.C4W-"!L:6(O5D93+G!H<#HU.3$@;&EB+U9&4RYP:'`Z-C8Y"B,Z(&QI8B](
M;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,30U(&QI8B](;W)D92]397-S:6]N
M2&%N9&QE<BYP:'`Z,38P"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP
M:'`Z,3<U(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,3@Y"B,Z(&QI
M8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,C,V"FUS9VED(").;W0@<W5P
M<&]R=&5D+B(*;7-G<W1R(").;R!E<W3A('-O<&]R=&%D;RXB"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.CDP."!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(T-`HC.B!C;VYF:6<O+F)A:R]H;V]K<RYP:'`N9&ES=#HQ,#4X
M(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C$X,`IM<V=I9"`B3F]T
M97,B"FUS9W-T<B`B3F]T87,B"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E
M>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*
M;7-G<W1R(").;R!H87D@;F%D82!V:7-U86QI>F%B;&4L(')E=')O8V5D82XB
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V
M96UB97(B"FUS9W-T<B`B3F]V:65M8G)E(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$P-#8*;7-G:60@(DYU;6)E<B(*;7-G<W1R(").^FUE<F\B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,30R-0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A
M8W1E<G,B"FUS9W-T<B`B3OIM97)O(&1E(&-A<F%C=&5R97,B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3,V.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R,R!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,30T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M
M;G,B"FUS9W-T<B`B3OIM97)O(&1E(&-O;'5M;F%S(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$S-C<@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C$@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$T-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S
M='(@(D[Z;65R;R!D92!F:6QA<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F
M;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*
M(DYO('-E(&AA;B!E<W!E8VEF:6-A9&\@;OIM97)O<R!A(&%C='5A;&EZ87(@
M96X@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T
M<B`B06-E<'1A<B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HX-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R(")/8FIE=&\B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R
M96%T;W(B"FUS9W-T<B`B0W)E861O<B!D92!O8FIE=&]S(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(D]C=&%L
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,2!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C
M=&]B97(B"FUS9W-T<B`B3V-T=6)R92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B1FEL=')A
M<B!O9F5N<V%S(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z
M,S(X"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B3V9I8VEN82(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@
M<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R("),82!C;VYT
M<F%S9?%A(&%N=&EG=6$@>2!L82!N=65V82!D96)E;B!S97(@9&ES=&EN=&%S
M+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@IM<V=I9"`B
M3VQD('!A<W-W;W)D(@IM<V=S='(@(D-O;G1R87-E\6$@86YT:6=U82(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A
M<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R("),82!C;VYT<F%S9?%A
M(&%N=&EG=6$@;F\@97,@8V]R<F5C=&$N(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Q"FUS9VED(")/;6%N(@IM<V=S
M='(@(D]MX6XB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O
M;&1E<G,N(@IM<V=S='(@(E/S;&\@;&]S('-E<G9I9&]R97,@24U!4"!S;W!O
M<G1A;B!L87,@8V%R<&5T87,@8V]M<&%R=&ED87,N(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE
M<R(*;7-G<W1R(")3\VQO(&]F96YS:79A<R(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ.#4Q(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<Q"FUS9VED(")/;FQY
M(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(E/S;&\@<V4@
M<&5R;6ET92!U;F$@9&ER96-C:?-N(&1E(&-O<G)E;RXB"@HC.B!S97)V:6-E
M<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R
M(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP
M(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@
M(B(*(E/S;&\@96P@<')O<&EE=&%R:6\@;R!U;B!A9&UI;FES=')A9&]R(&1E
M('-I<W1E;6%S('!U961E(&-A;6)I87(@;&$@(@HB<')O<&EE9&%D(&\@;&]S
M('!R:79I;&5G:6]S(&1E('!R;W!I971A<FEO(&1E('5N(')E8W5R<V\@8V]M
M<&%R=&ED;R(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C0Q(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C0R"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*
M;7-G<W1R(")!8G)I<B!E;B!U;F$@;G5E=F$@=F5N=&%N82(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R
M.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P
M87)T+B(*;7-G<W1R(")%<G)O<B!/<&5N4U-,.B!.;R!S92!P=65D96X@97AT
M<F%E<B!D871O<R!D92!L82!P87)T92!3+TU)344@9FER;6%D82XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-34*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS
M9W-T<B`B06)R:7(@97-T92!V[6YC=6QO(&5N('5N82!V96YT86YA(&YU979A
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I
M;F<@4WES=&5M(@IM<V=S='(@(E-I<W1E;6$@;W!E<F%T:79O(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U-0IM<V=I9"`B3W!T:6]N<R(*
M;7-G<W1R(")/<&-I;VYE<R(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T
M96UP;&%T97,O<')E9G,O87!P+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R(")/<&-I;VYE<R!D92`E<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G
M:60@(D]R9&5R960@3&ES="(*;7-G<W1R("),:7-T82!O<F1E;F%D82(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES
M871I;VXB"FUS9W-T<B`B3W)G86YI>F%C:?-N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B
M"FUS9W-T<B`B56YI9&%D(&]R9V%N:7IA=&EV82(*"B,Z(&-O;F9I9R\N8F%K
M+W)E9VES=')Y+G!H<"YD:7-T.C$S-`IM<V=I9"`B3W)G86YI>FEN9R(*;7-G
M<W1R(")/<F=A;FEZ86-I\VXB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S
M-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T
M<B`B4&QA;G1I;&QA(&1E(&%P;&EC86-I\VX@;W)I9VEN86PB"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG
M:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(E!L86YT:6QL87,@;W)I
M9VEN86QE<R!E;B`E<SHB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G
M<W1R(")/=')O(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z.3D@
M8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,3`Y"B,Z(&-O;F9I9R\N8F%K
M+W!R969S+G!H<"YD:7-T.C$Q-B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES
M=#HQ,C4*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,3,T(&-O;F9I
M9R\N8F%K+W!R969S+G!H<"YD:7-T.C$T-`IM<V=I9"`B3W1H97(@26YF;W)M
M871I;VXB"FUS9W-T<B`B3W1R82!I;F9O<FUA8VGS;B(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(E!R:79I;&5G:6]S(&1E;"!P<F]P:65T87)I;R(*"B,Z(&QI
M8B](;W)D92]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT:6-A
M=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("),82!A=71E;G1I9FEC
M86-I\VX@4$%-(&YO(&5S=.$@9&ES<&]N:6)L92XB"@HC.B!L:6(O3F5T+U--
M4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K
M96YD(@IM<V=S='(@(E!%05(Z.DUO=&]R(&1E(&-O<G)E;R(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C$R-S8*;7-G:60@(E!'4"!$:6=I=&%L(%-I
M9VYA='5R92(*;7-G<W1R(")&:7)M82!D:6=I=&%L(%!'4"(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C$S,C(*;7-G:60@(E!'4"!%;F-R>7!T960@
M1&%T82(*;7-G<W1R(")$871O<R!C:69R861O<R!C;VX@4$=0(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,W-`IM<V=I9"`B4$=0(%!U8FQI8R!+
M97DB"FUS9W-T<B`B0VQA=F4@4$=0('#Z8FQI8V$B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HQ,S4V"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E
M9"!$871A(@IM<V=S='(@(D1A=&]S(&9I<FUA9&]S+V-I9G)A9&]S(&-O;B!0
M1U`B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-CD*;7-G:60@(E!(4"!#;V1E
M(@IM<V=S='(@(D/S9&EG;R!02%`B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z
M,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R("));G3I<G!R+B!02%`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I
M9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R("),;&]V:7IN82!V97-P97)T:6YA
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*
M;7-G:60@(E!-(%)A:6XB"FUS9W-T<B`B3&QU=FEA('9E<W!E<G1I;F$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I
M9"`B4$T@4VAO=V5R<R(*;7-G<W1R(")#:&%P87)R;VYE<R!V97-P97)T:6YO
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q
M"FUS9VED(")032!3;F]W(@IM<V=S='(@(DYI979E('9E<W!E<G1I;F$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I
M9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(D%G=6%C97)O(&1E(&YI979E
M('9E<W!E<G1I;F\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT,PIM<V=I9"`B4$T@4W5N(@IM<V=S='(@(E-O;"!V97-P97)T
M:6YO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#0*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(D)O<G)A<V-A<R!V97-P
M97)T:6YA<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.#8*;7-G:60@
M(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(DYO('-E(&5N
M8W5E;G1R82!L82!E>'1E;G-I\VX@4$]325@B"@HC.B!L:6(O87!I+G!H<#HQ
M-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B26YTZ7)P<BX@4%](4"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B36%R9V5N(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$W,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@W"FUS9VED
M(")086MI<W1A;B(*;7-G<W1R(")086MI<W3A;B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.30*;7-G:60@(E!A;&%U
M(@IM<V=S='(@(E!A;&%U(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$Y,@IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET
M;W)Y+"!/8V-U<&EE9"(*;7-G<W1R(")086QE<W1I;F]S+"!497)R:71O<FEO
M<R!/8W5P861O<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$X,@IM<V=I9"`B4&%N86UA(@IM<V=S='(@(E!A;F%MX2(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-S8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X
M-0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R(")087#Z82!.=65V
M82!'=6EN96$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3DU"FUS9VED(")087)A9W5A>2(*;7-G<W1R(")087)A9W5A
M>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W
M"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@(E!A<F-I86QM96YT92!N
M=6)O<V\B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3<Y"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3DY(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@;&EB
M+TYE="]335,O=VEN7VAT='`N<&AP.C$U,2!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C`Q.`HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<W('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*(SH@8V]N9FEG+RYB86LO<F5G
M:7-T<GDN<&AP+F1I<W0Z-#(U"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")#
M;VYT<F%S9?%A(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R
M"FUS9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T
M<B`B3&$@8V]N=')A<V7Q82!S92!C86UB:6%D;R!C;W)R96-T86UE;G1E+B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3,R,PIM<V=I9"`B4&%S
M<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(D-O;G1R87-E\6$@:6YC;W)R96-T
M82(*"B,Z(&QI8B](;W)D92]!=71H+W)A9&EU<RYP:'`Z,34R"FUS9VED(")0
M87-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(")(87D@<75E(&EN=')O9'5C:7(@=6YA(&-O;G1R87-E\6$@<&%R
M82!L82!A=71E;G1I9FEC86-I\VX@4D%$2553+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,#4S"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO
M;B(*;7-G<W1R(")#;VYT<F%S9?%A(&-O;B!C;VYF:7)M86-I\VXB"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D
M.B(*;7-G<W1R(")#;VYT<F%S9?%A.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M
M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(D-O;G1R
M87-E\6$Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C`S-`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C$U"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B3&%S
M(&-O;G1R87-E\6%S('1I96YE;B!Q=64@8V]I;F-I9&ER+B(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,C`@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R(")0
M96=A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(E!E
M9V%R(&1E;"!P;W)T87!A<&5L97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@(E;M
M82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW"FUS9VED(")0
M96YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(D%L=&%S('!E;F1I96YT97,Z(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"FUS9VED(")096]P;&4B"FUS
M9W-T<B`B1V5N=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R(")0;W)C96YT
M86IE(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT
M;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*
M;7-G<W1R(")296%L:7IA<B!O<&5R86-I;VYE<R!D92!M86YT96YI;6EE;G1O
M(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-#$P"FUS9VED(")0
M97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S
M='(@(K]296%L:7IA<B!O<&5R86-I;VYE<R!D92!M86YT96YI;6EE;G1O(&%L
M(&EN:6-I87(@<V5S:?-N/R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,34V"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(E!R:79I;&5G:6\B"@HC
M.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G
M:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R(").
M;R!S92!H82!E;&EM:6YA9&\@96P@<')I=FEL96=I;R!<(B5S7"(N(@H*(SH@
M;&EB+U9&4R]S;6(N<&AP.C8P,PIM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B
M"FUS9W-T<B`B4')I=FEL96=I;R!D96YE9V%D;R(*"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,38Q(&QI8B](;W)D92]097)M<R]522YP:'`Z,38T"FUS
M9VED(")097)M:7-S:6]N<R(*;7-G<W1R(")0<FEV:6QE9VEO<R(*"B,Z(&%D
M;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,"!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C4X"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M
M<R]I;F1E>"YP:'`Z,C(*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(D%D;6EN:7-T<F%C:?-N(&1E('!R:79I;&5G:6]S(@H*
M(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-C@*;7-G:60@(E!E<G-O
M;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%C:?-N('!E<G-O;F%L
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$W.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3@S"FUS9VED(")097)U(@IM<V=S='(@(E!E<OHB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`B36%S8V]T87,B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.#8*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(D9I;&EP:6YA<R(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0
M:&]N92(*;7-G<W1R(")496SI9F]N;R(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES
M=')Y+G!H<"YD:7-T.C0X,`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(D9O=&]G
M<F%F[6%S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Y,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B4&ET8V%I<FXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(E#M>&5L97,B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B
M5/-P:6-O<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@
M8V5L;"(*;7-G<W1R(")0=6QS92!E;B!U;F$@8V5L9&$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G
M:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H
M:7,@96QE;65N=#HB"FUS9W-T<B`B0V]N9FER;64@<75E(&1E<V5A(&5L:6UI
M;F%R(&5S=&4@96QE;65N=&\Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N
M9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM
M<V=S='(@(D-O;F9I<FUE('%U92!D97-E82!E;&EM:6YA<B!E;"!V[6YC=6QO
M(&$@97-T92!E;&5M96YT;RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4V
M,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS
M9W-T<B`B26YT<F]D=7IC82!U;B!M97,@>2!U;B!A\6\N(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L
M96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S
M='(@(DEN=')O9'5Z8V$@96P@;F]M8G)E(&1E(&QA(&YU979A(&-A=&5G;W+M
M83HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,P,0IM<V=I9"`B4&QE87-E
M(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B26YT<F]D=7IC
M82!U;F$@9&ER96-C:?-N($E0(';A;&ED82XB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C8T,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@
M8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T
M<B`B26YT<F]D=7IC82!U;F$@9F5C:&$@=N%L:61A+"!C;VUP<G5E8F4@96P@
M;OIM97)O(&1E(&3M87,@9&5L(&UE<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C0T-PIM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS
M9W-T<B`B26YT<F]D=7IC82!U;F$@:&]R82!VX6QI9&$N(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I
M9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R(")0<F]P;W)C
M:6]N92!U;B!R97-U;65N(&1E;"!P<F]B;&5M82XB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A
M<W-W;W)D(@IM<V=S='(@(DEN=')O9'5Z8V$@<W4@;F]M8G)E(&1E('5S=6%R
M:6\@>2!C;VYT<F%S9?%A+B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HU.`IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT
M+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*
M(G-Y<W1E;2XB"FUS9W-T<B`B(@HB3&5A(&5L('1E>'1O('-I9W5I96YT92X@
M1$5"12!A8V5P=&%R(&QO<R!TZ7)M:6YO<R!S:2!Q=6EE<F4@=7-A<B!E;"!S
M:7-T96UA+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA
M;64Z(@IM<V=S='(@(DEN=')O9'5Z8V$@96P@;G5E=F\@;F]M8G)E(&1E(&-A
M=&5G;W+M83HB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.#@*;7-G:60@(E!O;&%N9"(*;7-G<W1R(")0;VQO;FEA(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*
M;7-G<W1R(")0;VSM=&EC82(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H
M<"YD:7-T.C0X.0IM<V=I9"`B4&]L;',B"FUS9W-T<B`B16YC=65S=&%S(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.#(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y
M,PIM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B4&]R='5G86PB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C0*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B
M4&]S:6-I\VX@9&4@;&$@:6UA9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F
M('1H:7,@=&%B;&4B"FUS9W-T<B`B4&]S:6-I\VX@9&4@;&$@=&%B;&$B"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S0S,30N<&AP.C4Q"FUS9VED(")0;W-T('1O('1H:7,@
M9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B16YV:6%R
M(&$@97-T82!C87)P971A("AN;R!O8FQI9V%D;R!P;W(@24U!4"DB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(W,R!L:6(O0FQO8VLO;65T87(N<&AP.C(W
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T
M("5S(&AO=7(H<RDZ("(*;7-G<W1R(")0<F5C:7!I=&%C:6]N97,@9&4@;&$H
M<RD@^FQT:6UA*',I("5S(&AO<F$H<RDZ("(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR.#<*;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC
M:&%N8V4B"FUS9W-T<B`B4')O8F%B:6QI9&%D/&)R("\^9&4@<')E8VEP:71A
M8VGS;B(*"B,Z(&QI8B](;W)D92]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B
M4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")0<F5F<U]L9&%P.B!N;R!S92!E;F-O;G1R\R!L82!E>'1E
M;G-I\VX@3$1!4"!R97%U97)I9&$N(@H*(SH@;&EB+TAO<F1E+U!R969S+W-E
M<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S
M97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7W-E
M<W-I;VXZ(&YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!D92!S97-I\VX@
M<F5Q=65R:61A+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C,R"FUS9VED
M(")0<F5S<W5R92(*;7-G<W1R(")0<F5S:?-N(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-C8*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM
M<V=S='(@(E!R97-I\VX@86P@;FEV96P@9&5L(&UA<CH@(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-`IM<V=I9"`B4')E<W-U<F4Z("(*
M;7-G<W1R(")0<F5S:?-N.B`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C`S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`IM<V=I9"`B4')E=FEE=R(*;7-G
M<W1R(")6:7-T82!P<F5V:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*;7-G:60@(E!R979I97<@
M=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")6:7-T82!P<F5V
M:6$@9&4@;&$@:6UA9V5N(&5N('5N82!N=65V82!V96YT86YA(@H*(SH@;&EB
M+TAO<F1E+U!R969S+U5)+G!H<#HS-38@;&EB+TAO<F1E+U!R969S+U5)+G!H
M<#HS-C`*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B3W!C:6]N
M97,@86YT97)I;W)E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@
M(DEM<')I;6ER(&1O8W5M96YT;R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B0VQA=F4@<')I
M=F%D82(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L
M96TB"FUS9W-T<B`BOU!R;V)L96UA<S\B"@HC.B!S97)V:6-E<R]P<F]B;&5M
M+G!H<#HQ,C<*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B
M1&5S8W)I<&-I\VX@9&5L('!R;V)L96UA(@H*(SH@8V]N9FEG+RYB86LO<F5G
M:7-T<GDN<&AP+F1I<W0Z,S<Q"FUS9VED(")0<F]J96-T<R(*;7-G<W1R(")0
M<F]Y96-T;W,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Q,2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C$X."!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(W-@IM<V=I
M9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B5&5X=&\@9&5L(&EN9'5C=&]R(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@
M2V5Y(@IM<V=S='(@(D-L879E(%!'4"!P^F)L:6-A(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV-#8*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I
M=&AM(@IM<V=S='(@(D%L9V]R:71M;R!D92!C;&%V92!P^F)L:6-A(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+
M97D@26YF;R(*;7-G<W1R("));F9O<FUA8VGS;B!D92!C;&%V92!P^F)L:6-A
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L
M:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY
M+B(*;7-G<W1R(").;R!S92!G96YE<F%R;VX@8V]R<F5C=&%M96YT92!L87,@
M8VQA=F5S(%#Z8FQI8V$O4')I=F%D82XB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DQ"FUS9VED(")0=65R=&\@4FEC
M;R(*;7-G<W1R(")0=65R=&\@4FEC;R(*"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,T,S$T+G!H<#HU-0IM<V=I9"`B4'5R9V4@;65S<V%G97,B"FUS9W-T
M<B`B3&EM<&EA<B!M96YS86IE<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.38*;7-G:60@(E%A=&%R(@IM<V=S='(@
M(E%A=&%R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8T"FUS9VED(")1=65R
M>2(*;7-G<W1R(")#;VYS=6QT82(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HX,`IM<V=I9"`B475O=&$B"FUS9W-T<B`B475O=&$B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C8V-`HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M4T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R(")#;&%V92!24T$@</IB
M;&EC82`H)60@8FET*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C8T"FUS
M9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B0F]T\VX@9&4@;W!C:?-N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*
M;7-G:60@(E)A:6XB"FUS9W-T<B`B3&QU=FEA(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@16%R;'DB
M"FUS9W-T<B`B3&QU=FEA(&UA='5T:6YA(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@3&%T92(*;7-G
M<W1R("),;'5V:6$@=F5S<&5R=&EN82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN(%-H;W=E<B(*;7-G
M<W1R(")!9W5A8V5R;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0Y"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@(DQL
M=79I82!Y($YI979E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3`*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R("),;'5V
M:6$@82!.:65V92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED
M(")286YD;VT@1F]R='5N92(*;7-G<W1R(")2=65D82!D92!L82!F;W)T=6YA
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S
M='(@(E)A>O-N(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C0@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*
M;7-G:60@(E)E860B"FUS9W-T<B`B)FYB<W`[3&5E<B9N8G-P.R(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX-R!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-#<*;7-G:60@(E)E860@;65S<V%G97,B"FUS
M9W-T<B`B3&5E<B!M96YS86IE<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L
M971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G
M<W1R("*_16QI;6EN87(@<F5A;&UE;G1E("5S/R!%<W1A(&]P97)A8VGS;B!N
M;R!S92!P=65D92!D97-H86-E<BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@<F5M
M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N
M;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@HBOT5L:6UI;F%R(')E86QM96YT
M92!L;W,@9&%T;W,@9&5L('5S=6%R:6\@)7,_($5S=&$@;W!E<F%C:?-N(&YO
M('-E('!U961E("(*(F1E<VAA8V5R+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA
M<W0@86-T:6]N(@IM<V=S='(@(E9U96QV92!A(')E86QI>F%R(&QA(/IL=&EM
M82!A8V-I\VXB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R(")!
M8W1U86QI>F%R(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,SDU
M"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T
M<B`B06-T=6%L:7IA<B!E;&5M96YT;W,@9&4@;65N^B!D:6[A;6EC;W,Z(@H*
M(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S0U"FUS9VED(")2969R
M97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R(")!8W1U86QI>F%R('9I<W1A(&1E
M;"!P;W)T86PB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DT(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,C$S(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,U"FUS9VED
M(")296=E>"(*;7-G<W1R(")296=E>"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HS,C,Q"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R(").
M879E9V%D;W(@9&4@<F5L86-I;VYE<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*
M;7-G:60@(E)E;&]A9"(*;7-G<W1R(")2969R97-C87(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,S,PIM<V=I9"`B4F5M87)K<R(*;7-G<W1R(")/8G-E
M<G9A8VEO;F5S(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,3$W
M"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R(")397)V:61O<F5S(')E
M;6]T;W,B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G
M:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I
M.B(*;7-G<W1R(")54DP@<F5M;W1A("AH='1P.B\O=W=W+F5J96UP;&\N8V]M
M+VAO<F1E*3HB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN
M8SHR.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC
M.C$S('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(*;7-G:60@
M(E)E;6]V92(*;7-G<W1R(")1=6ET87(B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VQA>6]U="YI;F,Z,3$*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R(")1
M=6ET87(@8FQO<75E(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4U.0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")1=6ET
M87(@8V]L=6UN82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@
M(D5L:6UI;F%R(&9O<FUA=&\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B475I=&%R('!A
M<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#$*;7-G:60@(E)E;6]V
M92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T
M;W)Y+B(*;7-G<W1R(")%;&EM:6YA<B!G=6GS;B!G=6%R9&%D;R!D96P@9&ER
M96-T;W)I;R!T96UP;W)A;"!D96P@<V5R=FED;W(N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED
M(")296UO=F4@=&AE(@IM<V=S='(@(D5L:6UI;F%R("(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I
M9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R
M(")%;&EM:6YA<B!E<W1E(&YO9&\@9&5L(&1O8W5M96YT;R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U
M<V5R(@IM<V=S='(@(D5L:6UI;F%R('5S=6%R:6\B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(D5L:6UI;F%R('5S=6%R:6\Z("5S
M(@H*(SH@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q
M=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E
M.B`B"FUS9W-T<B`B3F\@<V4@<'5E9&4@<F5S<&]N9&5R(&$@;&$@<V]L:6-I
M='5D+B!#\V1I9V\@9&4@97)R;W(@9&5V=65L=&\Z("(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#4*;7-G:60@(E)E<75E<W1E9"!S97)V
M:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B3F\@<V4@96YC;VYT
M<O,@96P@<V5R=FEC:6\@<V]L:6-I=&%D;RXB"@HC.B!L:6(O2&]R9&4N<&AP
M.C$X-2!L:6(O2&]R9&4N<&AP.C4R-PHC+"!P:'`M9F]R;6%T"FUS9VED(")2
M97%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(").;R!S92!H82!E<W!E8VEF:6-A9&\@96P@7"(E<UPB
M(')E<75E<FED;R!E;B!L82!C;VYF:6=U<F%C:?-N(&1E("5S+B(*"B,Z(&QI
M8B]61E,O9G1P+G!H<#HX-S0@;&EB+U9&4R]S<6PN<&AP.C8Y,"!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HW-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER
M960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(DYO('-E(&AA(&5S<&5C:69I8V%D;R!E;"!<(B5S7"(@<F5Q
M=65R:61O(&5N(&QA(&-O;F9I9W5R86-I\VX@9&4@5D93+B(*"B,Z(&QI8B](
M;W)D92]5=&EL+G!H<#HW.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER
M960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B3F\@<V4@:&$@97-P96-I9FEC861O(&5L(%PB)7-<(B!R97%U97)I
M9&\@96X@;&$@8V]N9FEG=7)A8VGS;BXB"@HC.B!L:6(O2&]R9&4O1F]R;2]2
M96YD97)E<BYP:'`Z,S,V"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R
M(")#86UP;R!N96-E<V%R:6\B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S,Y"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,C`@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,R
M,0HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S
M='(@(DQI;7!I87(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT
M-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B3&EM<&EA<B!C;VYT
M<F%S9?%A(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G
M:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B3&EM<&EA<B!C;VYT
M<F%S9?%A(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,0IM<V=I9"`B4F5S
M=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(E)E<W1A=7)A<B#Z;'1I;6$@8V]N
M<W5L=&$B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,CD@861M:6XO<&AP<VAE
M;&PN<&AP.C<R(&%D;6EN+W-Q;'-H96QL+G!H<#HV-PIM<V=I9"`B4F5S=6QT
M<R(*;7-G<W1R(")297-U;'1A9&]S(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED
M(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")296=R97-A<B!A(&]P8VEO
M;F5S(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED
M(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(E)E97-C<FEB:7(@8V]N
M=')A<V7Q82!N=65V82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.3<*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B4F5U
M;FGS;B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB
M"FUS9W-T<B`B4F5S=&%U<F%R(&-O;F9I9W5R86-I\VXB"@HC.B!C;VYF:6<O
M+F)A:R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E)I8V@@5&5X="!%9&ET
M;W(@3W!T:6]N<R(*;7-G<W1R(")/<&-I;VYE<R!D92!E9&EC:?-N(&1E('1E
M>'1O(&5N<FEQ=65C:61O(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X
M"FUS9VED(")2:61D;&5S(@IM<V=S='(@(D-R:6)A<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`IM<V=I9"`B
M4FEG:'0B"FUS9W-T<B`B1&5R96-H82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HS,3`S"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B0V%B96-E<F$@
M9&5R96-H82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,#DY"FUS9VED(")2
M:6=H="!V86QU97,B"FUS9W-T<B`B5F%L;W)E<R!D92!L82!D97)E8VAA(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4')O
M<&EE9&%D97,@9&4@7V9I;&$N+BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R(")&=6YC:?-N
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Y.`IM<V=I9"`B4F]M86YI82(*;7-G<W1R(")2=6UA;NUA(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-@IM<V=I9"`B4F]T
M871E(#$X,"(*;7-G<W1R(")':7)A<B`Q.#`B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(S"FUS9VED(")2;W1A=&4@3&5F="(*
M;7-G<W1R(")':7)A<B!A(&QA(&EZ<75I97)D82(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,CD*;7-G:60@(E)O=&%T92!2:6=H
M="(*;7-G<W1R(")':7)A<B!A(&QA(&1E<F5C:&$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2
M;W<@4')O<&5R=&EE<R(*;7-G<W1R(")0<F]P:65D861E<R!D92!F:6QA(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B4')O<&EE9&%D
M97,@9&4@9FEL82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R(")&:6QA<SHB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R(")287EA<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@
M(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M
M;G,B"FUS9W-T<B`B07!A<F5C97+A;B!R87EA<R!E;G1R92!T;V1A<R!L87,@
M9FEL87,@>2!C;VQU;6YA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(D%P87)E8V5RX6X@
M<F%Y87,@<_-L;R!E;G1R92!L87,@8V]L=6UN87,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R(")!
M<&%R96-E<N%N(')A>6%S('/S;&\@96YT<F4@;&%S(&9I;&%S(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$R,0IM<V=I9"`B4G5N(@IM<V=S='(@(D5J96-U
M=&%R(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Y.0IM<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(D9E
M9&5R86-I\VX@4G5S82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,#`*;7-G:60@(E)W86YD82(*;7-G<W1R(")2=6%N
M9&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B
M4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(D9I<FUA
M(&-R:7!T;V=RX69I8V$@4R]-24U%(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*
M;7-G<W1R(")-96YS86IE(&-I9G)A9&\@96X@4R]-24U%(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I
M;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3F\@97-TX2!D:7-P;VYI
M8FQE(&QA(&%U=&5N=&EF:6-A8VGS;B!305-,+B(*"B,Z(&-O;F9I9R\N8F%K
M+W)E9VES=')Y+G!H<"YD:7-T.C4P-@IM<V=I9"`B4TU3($UE<W-A9VEN9R(*
M;7-G<W1R(")-96YS+B!335,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*
M;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R("));G3I<G!R+B!344PB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S(W-`IM<V=I9"`B4U%,('-T871E;65N="!F
M;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R(")396YT96YC:6$@4U%,('!A<F$@
M8V]N<W5L=&%S(&1E('9A;&]R97,B"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R
M>2YP:'`N9&ES=#HT,S,*;7-G:60@(E-32"(*;7-G<W1R(")34T@B"@HC.B!L
M:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*
M;7-G:60@(E-50T-%4U,B"FUS9W-T<B`BR5A)5$\B"@HC.B!L:6(O87!I+G!H
M<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B26YTZ7)P<BX@4U]1
M3"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C$*;7-G:60@(E-A(@IM<V=S='(@(E-A8B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#<*;7-G:60@(E-A:6YT($AE
M;&5N82(*;7-G<W1R(")386YT82!(96QE;F$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S$*;7-G:60@(E-A:6YT($MI
M='1S(&%N9"!.979I<R(*;7-G<W1R(")386EN="!+:71T<R!Y($YE=FES(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,Y
M"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R(")386YT82!,=6/M82(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DR"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#D*
M;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B4V%I
M;G0@4&EE<G)E('D@36EQ=65L;VXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0T"FUS9VED(")386EN="!6:6YC96YT
M(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R(")386X@5FEC96YT92!Y($=R
M86YA9&EN87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B
M36ES;6\@9G)A;64@*%]S96QF*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-3$*;7-G:60@(E-A;6]A(@IM<V=S='(@
M(E-A;6]A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(Q,@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R(")386X@36%R
M:6YO(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(Q-@IM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@
M(E-A;G1O(%1O;>%S('D@4'+M;F-I<&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R
M(")0<F]V965D;W(@9&4@<V%TZ6QI=&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Q"FUS9VED(")3875D:2!!<F%B
M:6$B"FUS9W-T<B`B07)A8FEA(%-A=61I=&$B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VQA>6]U="YI;F,Z.3D*;7-G:60@(E-A=F4B"FUS9W-T<B`B1W5A<F1A
M<B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B1W5A<F1A
M<B!<(B5S7"(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(D=U87)D87(@
M)7,B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E
M($]P=&EO;G,B"FUS9W-T<B`B1W5A<F1A<B!O<&-I;VYE<R(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-C8*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R
M)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB1W5A<F1A
M<B!L82!C;VYF:6=U<F%C:?-N(&=E;F5R861A(&-O;6\@=6X@9W5I\VX@4$A0
M(&5N(&5L(&1I<F5C=&]R:6\@(@HB=&5M<&]R86P@9&4@<W4@<V5R=FED;W(N
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B4V4@
M:&$@9W5A<F1A9&\@;&$@8V]N9FEG=7)A8VGS;B!D92`E<RXB"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3
M879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R
M(")'=6%R9&%R(&=U:?-N(&1E(&%C='5A;&EZ86-I\VX@9&4@;&$@8V]N9FEG
M=7)A8VGS;B!E;CH@7"(E<UPB+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B
M"FUS9W-T<B`B0F]R<F%S8V%S(&%I<VQA9&%S(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S='(@(D-I96YC:6$B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S
M='(@(D)U<V-A<B(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T
M.C,R,@IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B32X@8OIS<75E
M9&$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDU-0IM<V=I9"`B4V5L96-T
M($9I;&5S(@IM<V=S='(@(E-E;&5C8VEO;F%R(&%R8VAI=F]S(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-0IM<V=I9"`B4V5L
M96-T(&$@9&%T92(*;7-G<W1R(")396QE8V-I;VYE('5N82!F96-H82(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@
M82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B4V5L96-C:6]N92!E;"!G<G5P;R!A
M(&'Q861I<B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G
M:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R(")396QE8V-I;VYE('5N
M(&YU979O('!R;W!I971A<FEO(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B4V5L
M96-C:6]N92!U;B!S97)V:61O<B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R
M(")396QE8V-I;VYE(&5L('5S=6%R:6\@82!A\6%D:7(B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<V"FUS9VED(")396QE8W0@
M86QL(@IM<V=S='(@(E-E;&5C8VEO;F%R('1O9&\B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C8T,PIM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N
M=',N(@IM<V=S='(@(E-E;&5C8VEO;F4@=&]D;W,@;&]S(&-O;7!O;F5N=&5S
M(&1E(&QA(&9E8VAA+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HX-S,*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B
M4V5L96-C:6]N87(@=6X@;V)J971O(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C8W-PIM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T
M<B`B4VEN('-E;&5C8VGS;B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS
M-PIM<V=I9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R
M;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB
M<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(B(*(E-E
M;&5C8VEO;F4@;&]S(&-A<N%C=&5R97,@<75E(&YE8V5S:71E(&1E(&QA<R!C
M87-I;&QA<R!D92!A8F%J;RX@4'5E9&4@(@HB8V]P:6%R;&]S('D@<&5G87)L
M;W,@9&5L(.%R96$@9&4@=&5X=&\N(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM
M<V=S='(@(E-E;&5C8VEO;F4@96P@9&5L:6UI=&%D;W(@9&4@9F5C:&%S.B(*
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@
M=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R(")396QE8V-I;VYE(&5L(&9O<FUA
M=&\@9&4@9F5C:&%S.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E
M;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A
M;G0@=&\@8VAA;F=E.B(*;7-G<W1R(")396QE8V-I;VYE(&QA(&ED96YT:61A
M9"!Q=64@<75I97)A(&-A;6)I87(Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM
M92YI;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM
M<V=S='(@(E-E;&5C8VEO;F4@96P@9&5L:6UI=&%D;W(@9&4@:&]R87,Z(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T
M:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(E-E;&5C8VEO;F4@96P@9F]R;6%T
M;R!D92!H;W)A<SHB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W
M"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B
M4V5L96-C:6]N92!D;W,@8V%M<&]S(&-O:6YC:61E;G1E<RXB"@HC.B!C;VYF
M:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HS,3`*;7-G:60@(E-E;&5C="!Y;W5R
M(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B4V5L96-C:6]N92!S=2!C;VUB:6YA
M8VGS;B!D92!C;VQO<F5S+B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD
M:7-T.C(U,@IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E
M.B(*;7-G<W1R(")396QE8V-I;VYE('-U(&ED:6]M82!P<F5F97)I9&\Z(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E
M;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B16YV:6%R(&EN9F]R;64@9&4@
M<')O8FQE;6%S(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P-#(*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(D5N=FEA<B!335,B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C$S"FUS9VED(")396YE9V%L(@IM<V=S='(@(E-E;F5G86PB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,R,PIM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B
M4V5N<V]R.B`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$P(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM
M<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(E-E<'1I96UB<F4B"@HC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD
M($UO;G1E;F5G<F\B"FUS9W-T<B`B4V5R8FEA('D@36]N=&5N96=R;R(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`R"FUS9VED(")397)I86P@
M3G5M8F5R(@IM<V=S='(@(D[Z;65R;R!D92!S97)I92(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#D*;7-G:60@(E-E<G9E<B!D871A('=R
M;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D1A=&]S(&1E;"!S97)V
M:61O<B!E<G+S;F5O<R!O(&YO(&1I<W!O;FEB;&5S+B(*"B,Z(&%D;6EN+W-E
M<W-I;VYS+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R(")!
M9&UI;FES=')A8VGS;B!D92!S97-I\VXB"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D
M+B(*;7-G<W1R(")(82!C861U8V%D;R!E;"!)1"!D92!S97-I\VXN(@H*(SH@
M;&EB+V%P:2YP:'`Z,30U"FUS9VED(")397-S:6]N<R(*;7-G<W1R(")397-I
M;VYE<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S$T"FUS9VED(")3970B
M"FUS9W-T<B`B17-T86)L96-E<B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H
M<"YD:7-T.C<Y"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@
M<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM
M<V=S='(@(B(*(D5S=&%B;&5C92!O<&-I;VYE<R!Q=64@;&4@<&5R;6ET96X@
M<F5A:G5S=&%R('-U(&-O;G1R87-E\6$@<VD@;&QE9V%R82!A("(*(F]L=FED
M87)L82XB"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ,3@*;7-G
M:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C
M8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R(")#;VYF:6=U<F$@<V5R
M=FED;W)E<R!R96UO=&]S(&$@;&]S('%U92!D97-E92!A8V-E9&5R(&1E<V1E
M(&5L('!O<G1A;"XB"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HX
M-PIM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N
M92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R(")$969I;F4@;&%S(&]P8VEO
M;F5S('!R969E<FED87,@9&4@:61I;VUA+"!Z;VYA(&AO<F%R:6$@>2!F96-H
M87,N(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,3`Q"FUS9VED
M("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE
M;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T
M:6]N<RXB"FUS9W-T<B`B(@HB1&5F:6YE(&QA(&%P;&EC86-I\VX@9&4@:6YI
M8VEO+"!L82!C;VUB:6YA8VGS;B!D92!C;VQO<F5S+"!L82!A8W1U86QI>F%C
M:?-N("(*(F1E('#A9VEN82!Y(&]T<F%S(&]P8VEO;F5S(&1E('9I<W5A;&EZ
M86-I\VXN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-PIM<V=I9"`B
M4V5T=7`B"FUS9W-T<B`B0V]N9FEG=7)A8VGS;B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E
M('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(DAA>2!G=6EO;F5S(&1E(&%C
M='5A;&EZ86-I\VX@9&4@;&$@8V]N9FEG=7)A8VGS;B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@(E-E=F5R86P@;&]C871I
M;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(E9A
M<FEA<R!U8FEC86-I;VYE<R!D:7-P;VYI8FQE<R!C;VX@96P@<&%RX6UE=')O
M.B`B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C`S"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(E-E>6-H96QL97,B
M"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HT.3@*;7-G:60@
M(E-H;W!P:6YG(@IM<V=S='(@(D-O;7!R87,B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G
M<W1R(")297-U;65N(&-O<G1O(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP
M+F1I<W0Z-#4P"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE
M9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`BOT1E9FEN:7(@8VQA=F5S(&1E
M(&%C8V5S;R!P87)A(&QA(&UA>6]R[6$@9&4@;&]S(';M;F-U;&]S/R(*"B,Z
M(&QI8B](;W)D92]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM
M<V=S='(@(B9N8G-P.TUO<W1R87(F;F)S<#LB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,34T"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E
M96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*
M(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(DUU97-T<F$@;&%S(&1I9F5R96YC
M:6%S(&5N=')E(&QA(&YU979A(&-O;F9I9W5R86-I\VX@>2!L82!A;&UA8V5N
M861A(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-#DT"FUS9VED
M(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S
M='(@(K]-;W-T<F%R(&AO<F$@9&4@;&$@^FQT:6UA('-E<VGS;B!A;"!I;FEC
M:6%R/R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W
M(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(DUO<W1R87(@;W!C
M:?-N(&1E(&-O;G-E<G9A<B!E;"!O<FEG:6YA;"(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR-SDU"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R(")-;W-T
M<F%R('-E;&5C=&]R(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z
M-3,P"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM
M<V=S='(@(K]-;W-T<F%R(&QA(&)A<G)A(&1E(&UE;OH@9&4@;W!E<F%C:6]N
M97,@9&4@=&%B;&$_(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z
M,S4S"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@
M=&AE(&QE9G0_(@IM<V=S='(@(K]-;W-T<F%R(&5L(&UE;OH@)7,@82!L82!I
M>G%U:65R9&$_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL
M(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(DUU97-T<F$@96P@9&GA;&]G
M;R!D92!P<F]P:65D861E<R!D92!C96QD82!D92!T86)L82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM
M<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T
M<B`B375E<W1R82!E;"!D:>%L;V=O(&1E('!R;W!I961A9&5S(&1E('1A8FQA
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE
M<R!D:6%L;V<B"FUS9W-T<B`B375E<W1R82!E;"!D:>%L;V=O(&1E('!R;W!I
M961A9&5S(&1E(&9I;&$@9&4@=&%B;&$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@(E-H;W<@
M=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(DUU97-T<F$@
M96P@9&GA;&]G;R!D92!P<F]P:65D861E<R!D92!I;6%G96XB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3<V,PIM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T
M<B`B36]S=')A<B!C87)G82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S(@IM<V=S='(@(D%G=6%C
M97)O<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4S"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(DQL=79I87,@;6%T
M=71I;F%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-30*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R("),;'5V:6%S('9E
M<W!E<G1I;F%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-34*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S
M='(@(D%G=6%C97)O<R!E;B!L82!V96-I;F1A9"(*"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z-C$Y"FUS9VED(")3:')I;FLB"FUS
M9W-T<B`B4F5D=6-I<B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z.3$P"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z.3<R"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP
M:'`Z,3`U.`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C$Q,C`*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ
M,3@S"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(R
M,PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R-3(*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C@U"FUS
M9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T
M(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B4')I;65R;R!R961U>F-A(&\@
M<75I=&4@9&4@96YM961I;R!L;W,@8FQO<75E<R!C97)C86YO<R(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3$*;7-G
M:60@(E-I97)R82!,96]N92(*;7-G<W1R(")3:65R<F$@3&5O;F$B"@HC.B!L
M:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V-@IM<V=I9"`B4VEG;B!U<"(*
M;7-G<W1R(")!;'1A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW
M,3,*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R(")&:7)M82(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4@06QG
M;W)I=&AM(@IM<V=S='(@(D%L9V]R:71M;R!D92!F:7)M82(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#8*;7-G:60@
M(E-I;F=A<&]R92(*;7-G<W1R(")3:6YG87!U<B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HX.38@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,34@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$R,S<*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#8@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(Y,3(@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#4*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#0*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S(*;7-G:60@(E-I>F4B"FUS9W-T<B`B5&%M8?%O(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*
M;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B3VUI=&ER(&UA;G1E
M;FEM:65N=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C$P"FUS9VED(")3;&]V86MI82(*;7-G<W1R(")%<VQO=F%Q
M=6EA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(P.`IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B17-L;W9E;FEA(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G
M:60@(E-N;W<B"FUS9W-T<B`B3FEE=F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W97(B"FUS
M9W-T<B`B06=U86-E<F\@9&4@;FEE=F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S(@IM
M<V=S='(@(D%G=6%C97)O(&1E(&YI979E(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-N;W<@4VAO=V5R<R!%
M87)L>2(*;7-G<W1R(")!9W5A8V5R;R!D92!N:65V92!M871U=&EN;R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED
M(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R(")!9W5A8V5R;R!D92!N:65V
M92!V97-P97)T:6YO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#4*;7-G
M:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R(")%<W!E<V]R(&1E(&QA(&YI979E
M.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X.0IM<V=I9"`B4VYO=R!E
M<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B17%U:79A;&5N=&4@9&4@
M;&$@;FEE=F4@96X@86=U83H@(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(P,@IM<V=I9"`B4V]L;VUO;B!)<VQA;F1S
M(@IM<V=S='(@(DES;&%S(%-A;&]M\VXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$T"FUS9VED(")3;VUA;&EA(@IM
M<V=S='(@(E-O;6%L:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*
M;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B0V%N8VEO;F5S("8@4&]E
M;6%S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,#@*;7-G:60@(E-O<G0@
M;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(E-E;&5C8VGS;B!D96P@<V5N=&ED
M;R!D92!L82!C;&%S:69I8V%C:?-N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,3<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR-#<*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U
M.2!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&QI8B].
M970O4TU3+W=I;E]H='1P+G!H<#HQ-C8@;&EB+TYE="]335,O=VEN7VAT='`N
M<&AP.C$X.0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B4F5M:71E
M;G1E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(U-0IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(E-U9.%F<FEC
M82(*"B,Z(&-O;F9I9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E-O
M=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R(")%=7)O<&$@9&5L
M('-U<B`H25-/+3@X-3DM,RDB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,#$*;7-G:60@(E-O=71H($=E;W)G:6$@86YD
M('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(D=E;W)G:6$@
M9&5L(%-U<B!E($ES;&%S(%-A;F1W:6-H(&1E;"!3=7(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3
M;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(DAE;6ES9F5R:6\@<W5R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*
M;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B
M17-P86-I861O(&5N=')E(&-E;&1A<R!A9'EA8V5N=&5S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P
M86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T
M<B`B17-P86-I861O(&5N=')E(&5L(&-O;G1E;FED;R!Y(&5L(&)O<F1E(&1E
M('5N82!C96QD82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX,34*;7-G:60@
M(E-P86-E<B(*;7-G<W1R(")397!A<F%D;W(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*;7-G:60@(E-P86-I
M;F<B"FUS9W-T<B`B17-P86-I861O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A
M;F0@<&%D9&EN9R(*;7-G<W1R(")%<W!A8VEA9&\@>2!M87)G96XB"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,`IM<V=I
M9"`B4W!A:6XB"FUS9W-T<B`B17-P8?%A(@H*(SH@8V]N9FEG+RYB86LO<F5G
M:7-T<GDN<&AP+F1I<W0Z,3`P"FUS9VED(")3<&%M(@IM<V=S='(@(E-P86TB
M"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@
M0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(D5S8W)I='5R82!D92!C87)A8W1E
M<F5S(&5S<&5C:6%L97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S
M='(@(D1I=FED:7(@8V5L9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB
M"FUS9W-T<B`B1&EV:61I<B!C;VQU;6YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@
M<F]W(@IM<V=S='(@(D1I=FED:7(@9FEL82(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV,0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(D1E<&]R=&5S(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(Q,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30Q
M"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B4W)I($QA;FMA(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HX,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-C8*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(D5S=.%N9&%R(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS
M9W-T<B`B4W1A<B!4<F5K(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.#8@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(W.3$*;7-G:60@(E-T87)T('EE87(B"FUS
M9W-T<B`B0?%O(&1E(&EN:6-I;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3<Q"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R(")%
M<W1A9&\@;R!P<F]V:6YC:6$B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O
M:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(D5S=&%D;R(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-SDW"FUS9VED(")3=&]R86=E(&9O
M<FUA="(*;7-G<W1R(")&;W)M871O(&1E(&%L;6%C96YA;6EE;G1O(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E-T<F5E="!!
M9&1R97-S(@IM<V=S='(@(D1I<F5C8VGS;B!D92!L82!C86QL92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@
M(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B5&%C:&%D82(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R("),
M:7-T82!D92!C861E;F%S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S,*
M;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@
M(D5L:6UI;F%R(&1O;6EN:6\@9&4@;&$@9&ER96-C:?-N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I
M9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B17-T:6QO(%M#4U-=(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B
M4W4B"FUS9W-T<B`B1&]M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T
M(&9O=6YD+B(*;7-G<W1R(").;R!S92!E;F-O;G1R\R!E;"!S=6)D:7)E8W1O
M<FEO(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R(")!<W5N=&\B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S,R(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R
M+G!H<#HS,3@*;7-G:60@(E-U8FUI="(*;7-G<W1R(")%;G9I87(B"@HC.B!S
M:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E
M9"!R97%U97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A
M;FYO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P
M<')O=F5D+B(*;7-G<W1R("(B"B)392!H82!E;G9I861O('5N82!S;VQI8VET
M=60@9&4@86QT82!D92!<(B5S7"(@96X@96P@<VES=&5M82X@3F\@<&]D<N$@
M(@HB:6YI8VEA<B!S97-I\VX@:&%S=&$@<75E('-E(&AA>6$@87!R;V)A9&\@
M;&$@<V]L:6-I='5D+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R(")3=6+M
M;F1I8V4B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`U(&QI8B](;W)D92].
M;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C
M8V5S<R(*;7-G<W1R("+)>&ET;R(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@
M=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B4V4@:&$@8?%A9&ED;R!C;W)R96-T
M86UE;G1E(%PB)7-<(B!A;"!S:7-T96UA+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E
M9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S
M='(@(B(*(E-E(&AA;B!E;&EM:6YA9&\@8V]R<F5C=&%M96YT92!L;W,@9&%T
M;W,@9&5L('5S=6%R:6\@7"(E<UPB(&1E;"!S:7-T96UA+B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N
M(@IM<V=S='(@(E-E(&AA(&5L:6UI;F%D;R!C;W)R96-T86UE;G1E(%PB)7-<
M(BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E
M;2XB"FUS9W-T<B`B4V4@:&$@96QI;6EN861O(&-O<G)E8W1A;65N=&4@7"(E
M<UPB(&1E;"!S:7-T96UA+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N
M+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*(E-E(&AA(')E
M<W1A=7)A9&\@8V]R<F5C=&%M96YT92!L82!C;VYF:6=U<F%C:?-N+B!2969R
M97-Q=64@<&%R82!V97(@;&]S("(*(F-A;6)I;W,N(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS
M9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(E-E(&AA(&=U87)D861O(&-O<G)E8W1A;65N=&$@;&$@8V]P
M:6$@9&4@;&$@8V]N9FEG=7)A8VGS;BXB"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S
M879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T
M<B`B4V4@:&$@9W5A<F1A9&\@8V]R<F5C=&%M96YT92!L82!C;W!I82`E<R!D
M92!L82!C;VYF:6=U<F%C:?-N+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S
M7"(B"FUS9W-T<B`B4V4@:&$@86-T=6%L:7IA9&\@8V]R<F5C=&%M96YT92!<
M(B5S7"(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B4V4@:&$@97-C<FET;R!C;W)R96-T
M86UE;G1E("<E<R<B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C`T"FUS9VED(")3=61A;B(*;7-G<W1R(")3=63A;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B4F5S=6UE;B(*"B,Z(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T
M<B`B06UA;F5C97(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G
M:60@(E-U;B!3970B"FUS9W-T<B`B071A<F1E8V5R(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E-U;FYY(@IM
M<V=S='(@(E-O;&5A9&\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C`U"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(D%M86YE8V5R(@H*(SH@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP
M.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R(")!;6%N96-E<B]!
M=&%R9&5C97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`T
M"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B06UA;F5C97(Z("(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#@*;7-G:60@(E-U;G-E="(*
M;7-G<W1R(")!=&%R9&5C97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C`W"FUS9VED(")3=6YS970Z("(*;7-G<W1R(")!=&%R9&5C97(Z
M("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(E-U<&5R[6YD:6-E(@H*
M(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,S@P"FUS9VED(")3
M=7!P;W)T(@IM<V=S='(@(E-O<&]R=&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$U"FUS9VED(")3=7)I;F%M92(*
M;7-G<W1R(")3=7)I;F%M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU-S4*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`B07!E;&QI9&\B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(Q,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Y"FUS
M9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(E-V86QB87)D
M('D@2F%N($UA>65N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(Q.0IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(E-W
M87II;&%N9&EA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(P-0IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(E-U96-I82(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,38*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4V
M"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R(")3=6EZ82(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC(&QO9R!D96QE
M=&5D(@IM<V=S='(@(E)E9VES=')O(&1E('-I;F-R;VYI>F%C:?-N(&5L:6UI
M;F%D;R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$T-0IM<V=I
M9"`B4WEN8TU,(@IM<V=S='(@(E-Y;F--3"(*"B,Z(&QI8B](;W)D92]344PO
M2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H
M('1E<FUS(@IM<V=S='(@(D5R<F]R(&1E('-I;G1A>&ES(&5N(&QO<R!TZ7)M
M:6YO<R!D92!B^G-Q=65D82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,3@*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B
M;&EC(@IM<V=S='(@(E)E</IB;&EC82#!<F%B92!D92!3:7)I82(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4
M+5-T;W)M(@IM<V=S='(@(D-H=6)A<V-O(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FT@86YD(%=I
M;F1Y(@IM<V=S='(@(D)O<G)A<V-O<V\@>2!V96YT;W-O(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E0M4W1O
M<FUS(@IM<V=S='(@(D)O<G)A<V-A<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")4+5-T;W)M<R!%87)L>2(*
M;7-G<W1R(")";W)R87-C87,@;6%T=71I;F%S(@H*(SH@;&EB+TAO<F1E+T1A
M=&$O='-V+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(D%R8VAI
M=F\@5%-6(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R
M(")0<F]P:65D861E<R!D92!T86)L82(*"B,Z(&QI8B](;W)D92]&;W)M+U1Y
M<&4O=&%B;&5S970N<&AP.C4W"FUS9VED(")486)L92!3970B"FUS9W-T<B`B
M5&%B;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@
M(E!R;W!I961A9&5S(&1E('1A8FQA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S0*;7-G:60@(E1A
M:7=A;B(*;7-G<W1R(")486EWX6XB"@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA
M(@IM<V=S='(@(E1A:7?A;BP@4')O=FEN8VEA(&1E($-H:6YA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,3D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-0IM<V=I
M9"`B5&%J:6MI<W1A;B(*;7-G<W1R(")487EI:VES=.%N(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,C`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-0IM<V=I9"`B
M5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R(")486YZ86YI
M82P@4F5P^F)L:6-A(%5N:61A(&1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R
M(")$97-T:6YO.B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3,R(&-O;F9I
M9R\N8F%K+VAO;VMS+G!H<"YD:7-T.C$P-#D*(SH@8V]N9FEG+RYB86LO<F5G
M:7-T<GDN<&AP+F1I<W0Z,3@Y"FUS9VED(")487-K<R(*;7-G<W1R(")487)E
M87,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B
M5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R(").^FUE<F\@9&4@=&5LZ69O;F\B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-PIM<V=I9"`B5&5M<"!F;W(@
M;&%S="!H;W5R.B`B"FUS9W-T<B`B5&5M<&5R871U<F$@9'5R86YT92!L82#Z
M;'1I;6$@:&]R83H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C$*;7-G
M:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(E1E;7!E<F%T=7)A(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,@IM<V=I9"`B5&5M<&5R871U
M<F4Z("(*;7-G<W1R(")496UP97)A='5R83H@(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(X,@HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP
M97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@
M(E1E;7!E<F%T=7)A/&)R("\^*"5S3>%X)7,O)7--[6XE<RD@)F1E9SLE<R(*
M"B,Z(&QI8B](;W)D92]496UP;&%T92YP:'`Z-CDU"B,L('!H<"UF;W)M870*
M;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DYO
M('-E(&5N8V]N='+S(&QA('!L86YT:6QL82!<(B5S7"(N(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(D%D;6EN:7-T<F%C:?-N(&1E('!L86YT:6QL87,B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q,2!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S,R-PIM<V=I9"`B5&5X="(*;7-G<W1R(")497AT;R(*"B,Z(&-O;F9I9R\N
M8F%K+W!R969S+G!H<"YD:7-T.C,W.0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S
M='(@(E/S;&\@=&5X=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S
M='(@(D%L:6YE86-I\VX@9&4@=&5X=&\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S
M='(@(D)O<F1E('-U<&5R:6]R(&1E;"!T97AT;R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S
M='(@(DIU92(*"B,Z(&-O;F9I9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.30*;7-G
M:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(E1A:6QA;F3I<R`H5$E3+38R
M,"DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C(T"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R(")486EL86YD:6$B"@HC
M.B!L:6(O5D93+V9T<"YP:'`Z.#8T"FUS9VED(")4:&4@1E10(&5X=&5N<VEO
M;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(").;R!E<W3A(&1I<W!O;FEB
M;&4@;&$@97AT96YS:?-N($944"XB"@HC.B!L:6(O2&]R9&4O2&ES=&]R>2YP
M:'`Z-34*;7-G:60@(E1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"XB
M"FUS9W-T<B`B16P@<VES=&5M82!H:7-T\W)I8V\@97-TX2!D97-H86)I;&ET
M861O+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3,X"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@
M9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B16P@;6]T;W(@9&4@
M:6YT96=R86-I\VX@2&]R9&4O2V]L86(@;F\@<V]P;W)T82!<(B5S7"(B"@HC
M.B!L:6(O3F5T+TE-4U`O0F]O:RYP:'`Z,3(Y.`IM<V=I9"`B5&AE($E-4U`@
M;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B3F\@<V4@
M<'5E9&4@:6YI8VEA<B!E;"!R96=I<W1R;R!D92!)35-0+B(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E
M.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R(").
M;R!S92!H82!C87)G861O(&-O<G)E8W1A;65N=&4@;&$@8VQA<V4@36%I;G1E
M;F%N8V4Z.B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z
M,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET
M:6YG+B(*;7-G<W1R(")392!H82!C97)R861O(&QA('9E;G1A;F$@9&4@;W!C
M:6]N97,N(%-A;&EE;F1O+B(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,3@Y
M(&QI8B](;W)D92]097)M<RYP:'`Z,C`P(&QI8B](;W)D92]097)M<RYP:'`Z
M,C$Q"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,C(S(&QI8B](;W)D92]097)M
M<RYP:'`Z,C,T(&QI8B](;W)D92]097)M<RYP:'`Z,C4R"B,Z(&QI8B](;W)D
M92]097)M<RYP:'`Z,C8T(&QI8B](;W)D92]097)M<RYP:'`Z,S`S"FUS9VED
M("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P
M97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T
M;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*(E-I(&1E<V5A('5T:6QI
M>F%R('!E<FUI<V]S+"!E;"!A9&UI;FES=')A9&]R('1I96YE('%U92!C;VYF
M:6=U<F%R('5N('-O<&]R=&4@(@HB9&4@<&5R;6ES;W,@<&5R;6%N96YT92XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R(")3
M\VQO(&5L(&)O<F1E(&EN9F5R:6]R(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M
M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@
M9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"B)%;"!)1"!D
M96P@8V]N=&%C=&\@;F\@<V4@97-P96-I9FEC\RP@<V4@9&5J\R!E;B!B;&%N
M8V\@;R!N;R!S92!E;F-O;G1R\R!E;B`B"B)L82!B87-E(&1E(&1A=&]S+B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@
M(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A
M9&1R97-S(&)O;VLN(@IM<V=S='(@(E-E(&AA(&'Q861I9&\@8V]R<F5C=&%M
M96YT92!E;"!C;VYT86-T;R!A('-U<R!D:7)E8V-I;VYE<RXB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,3<R"FUS9VED("(B"B)4:&4@9&5T86-H
M960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@
M=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"B)087)A(&-O;7!R;V)A
M<B!E;"!M96YS86IE(&9I<FUA9&\@:&%C92!F86QT82!E;"!B;&]Q=64@9&4@
M9FER;6$@<V5P87)A9&\N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$
M('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@
M9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"B)%;"!)1"!D
M92!L82!L:7-T82!D92!D:7-T<FEB=6-I\VX@;F\@<V4@97-P96-I9FEC\RP@
M<V4@9&5J\R!E;B!B;&%N8V\@;R!N;R`B"B)S92!E;F-O;G1R\R!E;B!L82!B
M87-E(&1E(&1A=&]S+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T
M('-P96-I9FEE9"XB"FUS9W-T<B`B3F\@<V4@97-P96-I9FEC\R!L82!L:7-T
M82!D92!D:7-T<FEB=6-I\VXN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+G!H<#HQ
M,38*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S
M96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(DQA<R!C87)A8W1E<NUS
M=&EC87,@9&4@8VEF<F%D;R!N96-E<VET86X@=6YA(&-O;F5X:?-N('=E8B!S
M96=U<F$N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ.#8@;&EB+TAO<F1E+G!H<#HU
M,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O
M;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R(")%;"!A<F-H:79O("5S('1E
M;F1R[6$@<75E(&-O;G1E;F5R('5N82!O<&-I\VX@)7,N(@H*(SH@;&EB+TAO
M<F1E+G!H<#HQ-SD@;&EB+TAO<F1E+G!H<#HU,3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T
M:6YG<RXB"FUS9W-T<B`B16P@87)C:&EV;R`E<R!T96YD<NUA('%U92!C;VYT
M96YE<B!A;&=U;F%S(&]P8VEO;F5S("5S+B(*"B,Z(&QI8B](;W)D92]$871A
M+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*
M;7-G<W1R(")%;"!A<F-H:79O(&YO(&-O;G1I96YE(&1A=&]S+B(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@
M9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F
M8S@R,B!M97-S86=E+B(*;7-G<W1R(")!(&-O;G1I;G5A8VGS;B!T:65N92!L
M87,@8V%B96-E<F%S(&1E(&5S=&4@;65N<V%J92!M97-S86=E+W)F8S@R,BXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V
M"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C
M875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB
M=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA
M<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L
M87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R
M;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@
M.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A
M;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN
M7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@
M:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET
M;W(N(@IM<V=S='(@(B(*(E-E('-A8F4@<75E(&5L(&UO9&\@9&4@<&%N=&%L
M;&$@8V]M<&QE=&$@9&$@<')O8FQE;6%S(&-O;B!);G1E<FYE="!%>'!L;W)E
M<B`B"B)D96)I9&\@82!F86QL;W,@9&5L(&YA=F5G861O<B!Q=64@;F\@:&5M
M;W,@<&]D:61O('-O<VQA>6%R+B!0=65D92!S=69R:7(@(@HB=FES=6%L:7IA
M8VGS;B!D92!B87-U<F$L('#I<F1I9&$@9&4@9G5N8VEO;F5S(&1E;"!E9&ET
M;W(@>2]O(&-U96QG=65S("(*(F%L96%T;W)I;W,@9&5L(&YA=F5G861O<BX@
M4VD@<W4@<VES=&5M82!O<&5R871I=F\@97,@5VEN9&]W<R`Y>"P@97,@;75Y
M("(*(G!R;V)A8FQE('%U92!S=69R82!U;B!F86QL;R!D92!P<F]T96-C:?-N
M(&=E;F5R86P@>2!T96YG82!Q=64@<F5I;FEC:6%R(&5L("(*(F5Q=6EP;RY<
M7&Y<7&Y982!E<W3A(&%V:7-A9&\N(%!U;'-E($%C97!T87(@<VD@8?IN(&1E
M<V5A('!R;V)A<B!E;"!E9&ET;W(@96X@(@HB;6]D;R!D92!P86YT86QL82!C
M;VUP;&5T82XB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3$Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L
M971E9"XB"FUS9W-T<B`B4V4@:&$@96QI;6EN861O(&QA(&ED96YT:61A9"!<
M(B5S7"(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB
M"FUS9W-T<B`B4_-L;R!E;"!B;W)D92!I>G%U:65R9&\B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O
M9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T
M7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B"B)(87D@<75E(&EN9&EC87)L92!A
M(&QA(&-L87-E($-R>7!T7W!G<#HZ(&QA('5B:6-A8VGS;B!D92!L;W,@8FEN
M87)I;W,@1VYU4$<N(@H*(SH@;&EB+TAO<F1E+TU)344O341.+G!H<#HR,#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E
M<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE
M9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@
M:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"B)392!H
M82!M;W-T<F%D;R!E;"!M96YS86IE(&5N=FEA9&\@96P@)7,@82`E<R!C;VX@
M96P@87-U;G1O(%PB)7-<(BY<;B(*(LES=&\@;F\@9V%R86YT:7IA('%U92!E
M;"!M96YS86IE(&AA>6$@<VED;R!L96ED;R!O(&-O;7!R96YD:61O+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<W"FUS9VED(")4:&4@;F%M92!T;R!U
M<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B
M3F]M8G)E('5T:6QI>F%D;R!A;"!V:6YC=6QA<B!A(&QA('#A9VEN82!D92!C
M;VUP;W-I8VGS;B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#<T"FUS9VED(")4
M:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@
M(D5L(&[Z;65R;R!D92!C86UP;W,@=&EE;F4@<75E('-E<B!U;B!N^FUE<F\N
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C,R"FUS9VED(")4
M:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#
M<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R(")(86-E(&9A;'1A(&5L(&WS
M9'5L;R!O<&5N<W-L('!A<F$@;&$@8VQA<V4@2&]R9&5?0W)Y<'1?<VUI;64Z
M.BXB"@HC.B!L:6(O2&]R9&4O4')E9G,N<&AP.C(Y-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E
M('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM
M=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@HB3F\@<V4@<'5E9&4@9W5A
M<F1A<B!L82!P<F5F97)E;F-I82!<(B5S7"(@<&]R<75E('-U<R!D871O<R!S
M;V)R97!A<V%N(&5L("(*(G1A;6'Q;R!MX7AI;6\@<&5R;6ET:61O(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<G!M+G!H<#HS,B!L:6(O2&]R9&4O34E-12]6:65W97(O<W)C:&EG
M:&QI=&4N<&AP.C,W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]W96)C<'`N
M<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S
M960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@
M;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HB3F\@<V4@96YC;VYT<O,@96X@
M96P@<VES=&5M82!E;"!P<F]G<F%M82!P87)A('9E<B!E<W1E('1I<&\@9&4@
M9&%T;W,@*"5S*2XB"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0X-PIM<V=I9"`B
M5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C
M=&5R+B(*;7-G<W1R(")%;"!C87+A8W1E<B!D92!C:71A(&1E8F4@<V5R('-E
M<B!S\VQO('5N;RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@
M<VED97,@;VYL>2(*;7-G<W1R(")3\VQO(&QO<R!L861O<R!I>G%U:65R9&\@
M>2!D97)E8VAO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O
M;FQY(@IM<V=S='(@(E/S;&\@96P@;&%D;R!D97)E8VAO(@H*(SH@;&EB+T9I
M;&4O0U-6+G!H<#HT-SD*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O
M;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B16P@<V5P87)A9&]R(&1E
M8F4@<V5R('/S;&\@=6YO+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN
M<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB
M(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(E-E(&AA(&5L:6UI;F%D;R!E
M;"!S97)V:61O<B!<(B5S7"(N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U
M;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S
M7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(E-E(&AA(&=U87)D861O(&5L
M('-E<G9I9&]R(%PB)7-<(BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H
M87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R(")392!H82!E;&EM:6YA9&\@;&$@
M<V]L:6-I='5D(&1E(&%L=&$@9&4@)7,N(@H*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HT-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="XB"FUS9W-T
M<B`B3&$@9FEL82!E<W!E8VEF:6-A9&$@*"5D*2!N;R!E>&ES=&4N(@H*(SH@
M;&EB+U9&4R]S<6PN<&AP.C$W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R
M(")%;"!A<F-H:79O('1E;7!O<F%L(%PB)7-<(B!N;R!E>&ES=&4N(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,S,#(*;7-G:60@(E1H92!T97AT('EO=2!E
M;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB
M"FUS9W-T<B`B16P@=&5X=&\@<75E(&AA(&EN=')O9'5C:61O(&YO(&-O:6YC
M:61E(&-O;B!E;"!D92!L82!P86YT86QL82XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@
M=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R(")3\VQO(&QO<R!L
M861O<R!S=7!E<FEO<B!E(&EN9F5R:6]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O
M<"!S:61E(&]N;'DB"FUS9W-T<B`B4_-L;R!E;"!L861O('-U<&5R:6]R(@H*
M(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D
M(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S
M='(@(E-E('!E<F1I97)O;B!L;W,@9&%T;W,@8V%R9V%D;W,@9&5S9&4@96P@
M<&%S;R!A;G1E<FEO<BXB"@HC.B!L:6(O2&]R9&4O1&%T82]C<W8N<&AP.C(V
M,B!L:6(O2&]R9&4O1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A
M9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R(").;R!S92!P
M=61O(&=U87)D87(@96P@87)C:&EV;R!C87)G861O+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HT.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3$P"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B3F\@97-TX2!D:7-P;VYI8FQE(&5L(&)L
M;W%U92!D92!W96%T:&5R+F-O;2XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<
M(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(").;R!S92!E;F-O;G1R\R!E;"!D
M:7)E8W1O<FEO(&1E(%1E;6%S(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O4')E
M9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A
M:6QA8FQE+B(*;7-G<W1R(").;R!S92!D:7-P;VYE(&1E(&]P8VEO;F5S+B(*
M"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HS-3`*;7-G:60@(E1H
M97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE
M+B(*;7-G<W1R(").;R!H87D@<&%R=&5S('%U92!S92!P=65D86X@;6]S=')A
M<B!E;B!L[6YE82XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30P,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C
M=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A
M8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T
M<B`B(@HB16X@97-T92!C86UP;R!H87D@9&5M87-I861O<R!C87)A8W1E<F5S
M+B!(82!I;G1R;V1U8VED;R`E<R!C87)A8W1E<F5S('D@(@HB=&EE;F4@<75E
M(&EN=')O9'5C:7(@;65N;W,@9&4@)7,N(@H*(SH@<VEG;G5P+G!H<#HU,R!A
M9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B
M"FUS9W-T<B`B4V4@<')O9'5J;R!U;B!P<F]B;&5M82!A;"!A\6%D:7(@82!<
M(B5S7"(@86P@<VES=&5M83H@)7,B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A
M<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*
M;7-G<W1R("(B"B)392!P<F]D=6IO('5N('!R;V)L96UA(&%L(&)O<G)A<B!L
M;W,@9&%T;W,@9&5L('5S=6%R:6\@7"(E<UPB(&1E;"!S:7-T96UA.B`B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES
M=&5M.B`B"FUS9W-T<B`B4V4@<')O9'5J;R!U;B!P<F]B;&5M82!A;"!E;&EM
M:6YA<B!A(%PB)7-<(B!D96P@<VES=&5M83H@(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,34Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L
M96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R(")392!P<F]D=6IO('5N
M('!R;V)L96UA(&%L(&%C='5A;&EZ87(@7"(E<UPB.B`E<R(*"B,Z(&QI8B](
M;W)D92]"<F]W<V5R+G!H<#HY,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@
M=V%S('5P;&]A9&5D+B(*;7-G<W1R(")392!P<F]D=6IO('5N('!R;V)L96UA
M(&-O;B!L82!C87)G82!D96P@87)C:&EV;SH@3F\@<V4@8V%R9_,@)7,N(@H*
M(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDS,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L
M;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"B)392!P<F]D=6IO
M('5N('!R;V)L96UA(&-O;B!L82!C87)G82!D96P@87)C:&EV;RX@16P@)7,@
M97)A(&WA<R!G<F%N9&4@<75E(&5L("(*(G1A;6'Q;R!MX7AI;6\@<&5R;6ET
M:61O("@E9"!B>71E<RDN(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDS
M,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M
M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA
M;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"B)392!P<F]D=6IO('5N('!R;V)L
M96UA(&-O;B!L82!C87)G82!D96P@87)C:&EV;RX@4_-L;R!S92!C87)G\R!P
M87)C:6%L;65N=&4@(@HB96P@)7,N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D
M:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(E-E('!R;V1U
M:F\@=6X@97)R;W(@86P@;6]S=')A<B!E<W1A('!A<G1E(&1E;"!M96YS86IE
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.2!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S
M='(@(E-E('!R;V1U:F\@=6X@97)R;W(@86P@:6UP;W)T87(@;&]S(&1A=&]S
M(&1E;"!C;VYT86-T;RXB"@HC.B!L:6(O2&]R9&4O1&%T82]I;6,N<&AP.C,Q
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L
M96YD87(@9&%T82XB"FUS9W-T<B`B4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!I
M;7!O<G1A<B!L;W,@9&%T;W,@:4-A;&5N9&%R+B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z.#(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I
M;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U
M="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"B)392!P<F]D=6IO
M('5N(&5R<F]R(&5N(&5L(&9O<FUU;&%R:6\@9&4@8V]N9FEG=7)A8VGS;BX@
M4'5E9&4@<75E(&AA>6$@(@HB;VQV:61A9&\@<F5L;&5N87(@=6X@8V%M<&\@
M;F5C97-A<FEO+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S@*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG
M('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@
M(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B)392!P<F]D=6IO('5N
M(&5R<F]R(&%L(&5J96-U=&%R(&QA(&9U;F-I\VX@97-P96-I9FEC861A(&1E
M(&QA(&QI8G)E=&$@9&4@(@HB9&ER96-C:6]N97,N(%9U96QV82!A('!R;V)A
M<B!MX7,@861E;&%N=&4N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T
M:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N(@IM<V=S='(@(B(*(E-E('!R;V1U:F\@=6X@97)R;W(@86P@86-T=6%L
M:7IA<B!L;W,@9&5T86QL97,@9&5L(&-O;G1A8W1O+B!6=65L=F$@82!P<F]B
M87(@(@HB;>%S(&%D96QA;G1E+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#4@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(R,@IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T
M<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T
M<B`B(@HB4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!A8W1U86QI>F%R(&QA(&QI
M<W1A(&1E(&1I<W1R:6)U8VGS;BX@5G5E;'9A(&$@<')O8F%R("(*(FWA<R!A
M9&5L86YT92XB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,30X"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@
M<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R(")%<W1E('-E<G9I9&]R($E-05`@
M;F\@<V]P;W)T82!L87,@8V%R<&5T87,@8V]M<&%R=&ED87,N(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S
M='(@(LES=&4@;F\@<&%R96-E('-E<B!U;B!A<F-H:79O(')A<B!VX6QI9&\N
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@
M(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N
M(@IM<V=S='(@(LES=&4@;F\@<&%R96-E('-E<B!U;B!A<F-H:79O('II<"!V
MX6QI9&\N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,C<*;7-G:60@(E1H
M:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*
M;7-G<W1R("+)<W1E(&YO('!A<F5C92!S97(@=6X@;OIM97)O(&1E('1A<FIE
M=&$@=N%L:61O+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB
M8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*
M;7-G<W1R("(B"B)%<W1E(&-O;G1R;VQA9&]R('!E<FUI=&4@96YV:6%R(&UE
M;G-A:F5S(&$@=')A=NES(&1E(&QA('!A<V%R96QA($-L:6-K871E;&P@(@HB
M*&AT='`Z+R]C;&EC:V%T96QL+F-O;2DL(&UE9&EA;G1E(&QA($%022!(5%10
M(@H*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G
M:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I
M;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(D5S=&4@8V]N=')O;&%D;W(@
M<&5R;6ET92!E;G9I87(@;65N<V%J97,@82!T<F%VZ7,@9&4@;&$@<&%S87)E
M;&$@5TE.("AH='1P.B\O(@HB=VEN<&QC+F-O;2DL(&UE9&EA;G1E(&QA($%0
M22!(5%10(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q
M-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M
M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@
M(B(*(D5S=&4@8V]N=')O;&%D;W(@<&5R;6ET92!E;G9I87(@;65N<V%J97,@
M82!T<F%VZ7,@9&4@;&$@<&%S87)E;&$@<VUS,F5M86EL("(*(BAH='1P.B\O
M<VUS,F5M86EL+F-O;2DL(&UE9&EA;G1E(&QA($%022!(5%10(@H*(SH@;&EB
M+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--
M5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL
M>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A
M8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP
M+FET*2XB"FUS9W-T<B`B(@HB17-T92!C;VYT<F]L861O<B!P97)M:71E(&5N
M=FEA<B!M96YS86IE<R!V:6$@4TU44"!A('1R87;I<R!D92!L82!P87-A<F5L
M82!D92`B"B)6;V1A9F]N92!D92!)=&%L:6$L('/S;&\@82!N^FUE<F]S(%9O
M9&%F;VYE+B!(86-E(&9A;'1A('5N82!C=65N=&$@9&4@8V]R<F5O("(*(F1E
M(%9O9&%F;VYE(&1E($ET86QI82`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HY-S@@;&EB+TAO<F1E+T9O<FTN<&AP.C$P
M-3<@;&EB+TAO<F1E+T9O<FTN<&AP.C$P.#8*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Q,34@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q.#(@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$R-38*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,#4@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$S.3@@;&EB+TAO<F1E+T9O<FTN<&AP.C$U-3<*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$X,SD@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y
M-3@@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,#4*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(P,CD@;&EB+TAO<F1E+T9O<FTN<&AP.C(P-S@@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(Q-#D*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R,C$@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(T,#@@;&EB+TAO<F1E+T9O<FTN<&AP.C(T-3`*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(V,S<@;&EB+TAO<F1E+T9O<FTN<&AP.C(X
M,3`@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,3D*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,R.3<@;&EB+TAO<F1E+T9O<FTN<&AP.C,X,#4@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,X,3,*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM
M<V=S='(@(DAA8V4@9F%L=&$@97-T92!C86UP;RXB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&EN=&5G97)S+B(*;7-G<W1R(")%<W1E(&-A;7!O('/S;&\@<'5E9&4@
M8V]N=&5N97(@96YT97)O<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0Q
M-@IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@
M86YD('1H92!C;VQO;BXB"FUS9W-T<B`B17-T92!C86UP;R!S\VQO('!U961E
M(&-O;G1E;F5R(&[Z;65R;W,@>2!L;W,@9&]S('!U;G1O<RXB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3`Y-`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL
M>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B17-T92!C86UP;R!S
M\VQO('!U961E(&-O;G1E;F5R('9A;&]R97,@;V-T86QE<RXB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3$R,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E
M(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B
M"FUS9W-T<B`B(@HB17-T92!C86UP;R!T:65N92!Q=64@<V5R('5N82!L:7-T
M82!D92!E;G1E<F]S('-E<&%R861O<R!P;W(@8V]M87,@;R!E<W!A8VEO<RXB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3@Y"FUS9VED(")4:&ES(&9I96QD
M(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(D5S=&4@8V%M<&\@
M=&EE;F4@<75E('-E<B!U;B!N^FUE<F\@=N%L:61O+B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR.#$X"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N
M=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@
M97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*(D5S=&4@8V%M<&\@
M=&EE;F4@<75E(&-O;G1E;F5R('5N(&/S9&EF;R!D92!C;VQO<B!E;B!F;W)M
M871O(%)'0B!(97AA9&5C:6UA;"P@(@HB<&]R(&5J96UP;&\@)R,Q,C,T868G
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R
M;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B66$@<V4@
M:&$@<')O8V5S861O(&5S=&4@9F]R;75L87)I;RXB"@HC.B!T96UP;&%T97,O
M:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES
M("5S+B(*;7-G<W1R(")%<W1O(&5S("5S+B(*"B,Z(&QI8B](;W)D92]+;VQA
M8BYP:'`Z-#8Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+
M;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO
M=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N
M9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@
M<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R
M("(B"B+)<W1O(&5S('5N(&]B:F5T;R!D92!+;VQA8B!'<F]U<'=A<F4N(%!A
M<F$@=F5R;&\@;F5C97-I=&$@=6X@8VQI96YT92!D92`B"B)C;W)R96\@('%U
M92!E;G1I96YD82!E;"!F;W)M871O($MO;&%B($=R;W5P=V%R92X@4&%R82!V
M97(@=6YA(&QI<W1A(&1E("(*(F1I8VAO<R!C;&EE;G1E<R!V:7-I=&4@)7,B
M"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z-3DY"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H
M87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R
M("(B"B)%<W1E(&UE;G-A:F4@<V4@97-C<FEB:?,@8V]N('5N(&IU96=O(&1E
M(&-A<F%C=&5R97,@*"5S*2!D:7-T:6YT;R!A;"!S=7EO+B(*"B,Z(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T
M(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B17-T92!N^FUE<F\@9&5B92!S
M97(@<&]R(&QO(&UE;F]S('5N('5N;RXB"@HC.B!L:6(O2&]R9&4O0V]M<')E
M<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M
M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R(")%<W1E('-E<G9I
M9&]R(&YO('!U961E(&1E<V-O;7!R:6UI<B!A<F-H:79O<R!Z:7`@>2!G>FEP
M+B(*"B,Z(&QI8B](;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES
M('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(D5S
M=&4@<VES=&5M82!A8W1U86QM96YT92!E<W3A(&1E<V%C=&EV861O+B(*"B,Z
M(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E
M(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(D5S=&4@=F%L;W(@=&EE;F4@
M<75E('-E<B!U;B!N^FUE<F\N(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R
M<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL
M960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R(")%<W1A('9E;G1A
M;F$@<_-L;R!P=65D92!A8G)I<G-E(&1E<V1E('5N82!V96YT86YA(&1E(&]P
M8VEO;F5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C8*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B5')U96YO(@H*(SH@8V]N
M9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,C,V"FUS9VED(")4:6-K971S
M(@IM<V=S='(@(DEN8VED96YC:6%S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(T,C4@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")4
M:6UE(@IM<V=S='(@(DAO<F$B"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP
M:'`N9&ES=#HS.#@*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B0RX@
M=&EE;7!O<R(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM
M92!F;W)M870B"FUS9W-T<B`B1F]R;6%T;R!H;W)A<FEO(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(U,S$*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S
M='(@(E-E;&5C8VGS;B!D92!H;W)A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,`IM<V=I9"`B5&EM;W(M3&5S=&4B
M"FUS9W-T<B`B5&EM;W(M3&5S=&4B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H
M<#HR,"!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.0IM<V=I
M9"`B5&ET;&4B"FUS9W-T<B`B5.UT=6QO(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT
M:7`I.B(*;7-G<W1R(")4[71U;&\@*&-O;G-E:F\I.B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R
M(")087)A(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD
M(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B
M"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@HB4&%R82!S96QE8V-I;VYA
M<B!V87)I;W,@8V%M<&]S+"!M86YT96YG82!P=6QS861A(&QA('1E8VQA($-O
M;G1R;VP@*%!#*2!O("(*(D-O;6%N9&\@*$UA8RD@86P@:&%C97(@8VQI8VLN
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,`IM<V=I9"`B
M5&]D87DB"FUS9W-T<B`B2&]Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E
M(@IM<V=S='(@(D-O;FUU=&%R(&]R:6=E;B!(5$U,(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,C,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,PIM<V=I9"`B5&]G
M;R(*;7-G<W1R(")4;V=O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(R-@IM<V=I9"`B5&]K96QA=2(*;7-G<W1R(")4
M;VME;&%U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,@IM
M<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B36'Q86YA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,C4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R.0IM<V=I9"`B5&]N
M9V$B"FUS9W-T<B`B5&]N9V$B"@HC.B!L:6(O2&]R9&4O075T:"]K;VQA8BYP
M:'`Z,3`T"FUS9VED(")4;V\@;6%N>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@
M=&AE(&QA<W0@;6EN=71E<RXB"FUS9W-T<B`B1&5M87-I861O<R!I;G1E;G1O
M<R!F86QL:61O<R!E;B!L;W,@^FQT:6UO<R!M:6YU=&]S+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0IM<V=I
M9"`B5&]P(@IM<V=S='(@(E-U<&5R:6]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?
M=&]P*2(*;7-G<W1R(")&<F%M92!S=7!E<FEO<B`H7W1O<"DB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G
M<W1R(")4<F%D=6-C:6]N97,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C,R"FUS9VED(")4<FEN:61A9"!A;F0@5&]B
M86=O(@IM<V=S='(@(E1R:6YI9&%D('D@5&]B86=O(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$W.3`*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B
M5F5R9&%D97)O(&\@9F%L<V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R(")-87(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(R-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(X
M"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(E3Z;F5Z(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,C@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,0IM<V=I9"`B5'5R
M:V5Y(@IM<V=S='(@(E1U<G%U[6$B"@HC.B!C;VYF:6<O+F)A:R]N;',N<&AP
M+F1I<W0Z,3DU"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G<W1R
M(")4=7)C;R`H25-/+3@X-3DM.2DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(W"FUS9VED(")4=7)K;65N:7-T86XB
M"FUS9W-T<B`B5'5R:VUE;FES=.%N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,`IM<V=I9"`B5'5R:W,@86YD($-A
M:6-O<R!)<VQA;F1S(@IM<V=S='(@(DES;&%S(%1U<FMS('D@0V%I8V]S(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,S$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S
M,PIM<V=I9"`B5'5V86QU(@IM<V=S='(@(E1U=F%L=2(*"B,Z(&QI8B](;W)D
M92]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S
M='(@(D5S8W)I8F$@<W4@96QE8V-I\VXZ("(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-3@*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R
M("+-;F1I8V4@52Y6+CH@(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D*;7-G:60@(E52
M3"(*;7-G<W1R(")54DPB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y
M('-T871U<R!R97!O<G0B"FUS9W-T<B`B55),(&1E('-U(&EN9F]R;64@9&4@
M97-T861O(&1E(&5N=NUO(&1E;"!G=6GS;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T
M<B`B55),.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,S<*;7-G:60@(E5G86YD82(*;7-G<W1R(")59V%N9&$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(S,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,V
M"FUS9VED(")5:W)A:6YE(@IM<V=S='(@(E5C<F%N:6$B"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C0R-0IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R("));F-A<&%Z(&1E(&%C8V5D97(@86P@9&ER96-T
M;W)I;R!61E,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HY-@IM
M<V=I9"`B56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H
M96X@<VEG;FEN9R!U<"XB"FUS9W-T<B`B(@HB26YC87!A>B!D92!A\6%D:7(@
M:6YF;W)M86-I\VX@9&4@=7-U87)I;R!A9&EC:6]N86P@86P@<F5A;&EZ87(@
M96P@86QT82XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,SDV"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R("));F-A<&%Z(&1E(&-A;6)I87(@;&]S
M('!R:79I;&5G:6]S(&1E;"!A<F-H:79O(%9&4R!<(B5S7"(N(@H*(SH@;&EB
M+U9&4R]F:6QE+G!H<#HS.3@@;&EB+U9&4R]M=7-Q;"YP:'`Z-#@P"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F
M;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(DEN8V%P87H@9&4@8V%M8FEA
M<B!L;W,@<')I=FEL96=I;W,@9&5L(&%R8VAI=F\@5D93("5S+R5S+B(*"B,Z
M(&QI8B]61E,O9G1P+G!H<#HW.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B26YC87!A>B!D92!C86UB
M:6%R(&$@)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C(S-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<
M(BXB"FUS9W-T<B`B26YC87!A>B!D92!C;VUP<F]B87(@96P@=&%M8?%O(&1E
M(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C<P-R!L:6(O5D93+W-Q
M;"YP:'`Z,3`T,"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HX-S@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S
M+R5S7"(N(@IM<V=S='(@(DEN8V%P87H@9&4@8V]M<')O8F%R(&5L('1A;6'Q
M;R!D92!<(B5S+R5S7"(N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<W%L+G!H<#HT
M,SD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM
M<V=S='(@(DEN8V%P87H@9&4@8V]N96-T87)S92!A;"!S97)V:61O<B!344PN
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@X,PIM<V=I9"`B56YA8FQE('1O(&-O
M;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(DEN8V%P87H@9&4@8V]N96-T87(@
M8V]N(%-33"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(S."!L:6(O5D93+V9I
M;&4N<&AP.C(T,R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,30*(SH@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,C$Y(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(R-PIM
M<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(DEN8V%P
M87H@9&4@8V]P:6%R(&5L(&%R8VAI=F\@5D93+B(*"B,Z(&QI8B]61E,O9G1P
M+G!H<#HS-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B26YC87!A>B!D92!C
M<F5A<B!E;"!D:7)E8W1O<FEO(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HS-C<@;&EB+U9&4R]M=7-Q;"YP:'`Z,C<P(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C(W-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R("));F-A<&%Z(&1E(&-R96%R(&5L(&1I<F5C=&]R
M:6\@5D93+B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$R-`IM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`B26YC87!A>B!D92!C
M<F5A<B!E;"!A<F-H:79O(%9&4RXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z,CDT
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O
M;&1E<B!<(B5S7"(N(@IM<V=S='(@(DEN8V%P87H@9&4@8W)E87(@;&$@8V%R
M<&5T82!61E,@7"(E<UPB(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR-S@*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@
M(DEN8V%P87H@9&4@8W)E87(@=6X@87)C:&EV;R!61E,@=F%C[6\N(@H*(SH@
M;&EB+TAO<F1E+T-O;7!R97-S+V=Z:7`N<&AP.C<Y(&QI8B](;W)D92]#;VUP
M<F5S<R]T87(N<&AP.C<V"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D
M871A+B(*;7-G<W1R("));F-A<&%Z(&1E(&1E<V-O;7!R:6UI<B!L;W,@9&%T
M;W,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,P,R!L:6(O5D93+W-M8BYP:'`Z
M,C(X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E
M<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B26YC
M87!A>B!D92!E;&EM:6YA<B!<(B5S7"(L(&5L(&1I<F5C=&]R:6\@;F\@97-T
MX2!V86/M;RXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS
M+V1E;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R("));F-A<&%Z(&1E(&5L:6UI
M;F%R(%PB)7-<(CH@)7,N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS-#0@;&EB
M+U9&4R]M=7-Q;"YP:'`Z,S(S(&QI8B]61E,O<W%L+G!H<#HT,#<*(SH@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z,S<P"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M(@IM<V=S='(@(DEN8V%P87H@9&4@96QI;6EN87(@)7,L(&5L(&1I<F5C=&]R
M:6\@;F\@97-TX2!V86/M;R(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,X
M-"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS.#@*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B26YC
M87!A>B!D92!E;&EM:6YA<B!E;"!D:7)E8W1O<FEO(%9&4R!D92!F;W)M82!R
M96-U<G-I=F$N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS-3`@;&EB+U9&4R]M
M=7-Q;"YP:'`Z,S,T(&QI8B]61E,O;75S<6PN<&AP.C,T-PHC.B!L:6(O5D93
M+VUU<W%L+G!H<#HS-34@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S@P"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DEN
M8V%P87H@9&4@96QI;6EN87(@96P@9&ER96-T;W)I;R!61E,N(@H*(SH@;&EB
M+U9&4R]S<6PN<&AP.C0S,B!L:6(O5D93+W-Q;"YP:'`Z-#0T"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@
M)7,N(@IM<V=S='(@(DEN8V%P87H@9&4@96QI;6EN87(@96P@9&ER96-T;W)I
M;R!61E,Z("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR,3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(DEN8V%P87H@9&4@96QI;6EN87(@96P@87)C:&EV;R!61E,@
M7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S$V(&QI8B]61E,O;75S
M<6PN<&AP.C$V-R!L:6(O5D93+VUU<W%L+G!H<#HQ.#`*(SH@;&EB+U9&4R]M
M=7-Q;"YP:'`Z,3@W(&QI8B]61E,O<W%L+G!H<#HR.3$@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z-#$Y"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C0R-PIM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B26YC87!A
M>B!D92!E;&EM:6YA<B!E;"!A<F-H:79O(%9&4RXB"@HC.B!L:6(O5D93+W-M
M8BYP:'`Z,C0X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(DEN8V%P87H@9&4@96QI
M;6EN87(@;&$@8V%R<&5T82!61E,@7"(E<UPB+B(*"B,Z(&QI8B]61E,O<W%L
M+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R("));F-A<&%Z(&1E(&5L
M:6UI;F%R(&5L(%9&4R!D92!F;W)M82!R96-U<G-I=F$Z("5S+B(*"B,Z(&QI
M8B]61E,O9G1P+G!H<#HX-#<*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@
M8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(DEN8V%P87H@9&4@9&5T97)M
M:6YA<B!E;"!D:7)E8W1O<FEO(&%C='5A;"XB"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C8P-`IM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R
M=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R("));F-A<&%Z(&1E(&5X=')A97(@
M;&]S(&1E=&%L;&5S(&1E;"!C97)T:69I8V%D;RXB"@HC.B!L:6(O3F5T+TE-
M4U`N<&AP.C0S-R!L:6(O3F5T+TE-4U`O075T:"YP:'`Z,3(S"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F
M("5S+B(*;7-G<W1R("));F-A<&%Z(&1E(&-A<F=A<B!L82!D969I;FEC:?-N
M(&1E("5S+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C`X(&QI8B]61E,O9FEL
M92YP:'`Z,C$S(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$W.0HC.B!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HQ.#0*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F
M:6QE+B(*;7-G<W1R("));F-A<&%Z(&1E('1R87-L861A<B!E;"!A<F-H:79O
M(%9&4RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.3@@;&EB+U9&4R]S;6(N<&AP
M.CDS(&QI8B]61E,O<VUB+G!H<#HQ,#8*(SH@;&EB+U9&4R]S;6(N<&AP.C8V
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(DEN8V%P87H@9&4@86)R:7(@96P@87)C:&EV
M;R!61E,@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,CDP(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C$S."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-#$*
M;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*
M;7-G<W1R("));F-A<&%Z(&1E(&%B<FER(&5L(&%R8VAI=F\@5D93('!A<F$@
M97-C<FEB:7(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HX,R!L:6(O5D93+V9I
M;&4N<&AP.C$S-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW-@IM<V=I9"`B56YA
M8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(DEN8V%P87H@9&4@86)R
M:7(@96P@87)C:&EV;R!61E,N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@
M87)C:&EV92XB"FUS9W-T<B`B26YC87!A>B!D92!A8G)I<B!E;"!A<F-H:79O
M(&-O;7!R:6UI9&\N(@H*(SH@;&EB+U9&4RYP:'`Z.#4V"FUS9VED(")5;F%B
M;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+B(*;7-G
M<W1R("));F-A<&%Z(&1E(&QE97(@=6X@87)C:&EV;R!61E,@*&AA(&9A;&QA
M9&\@9FEL97-I>F4H*2DN(@H*(SH@;&EB+U9&4RYP:'`Z.#@W"FUS9VED(")5
M;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I
M+B(*;7-G<W1R("));F-A<&%Z(&1E(&QE97(@=6X@87)C:&EV;R!61E,@*&AA
M(&9A;&QA9&\@9V5T1FEL95-I>F4H*2DN(@H*(SH@;&EB+TAO<F1E+U-E<W-I
M;VY(86YD;&5R+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F
M:6QE.B`B"FUS9W-T<B`B26YC87!A>B!D92!L965R('5N(&%R8VAI=F\Z("(*
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z-C@X"FUS9VED(")5;F%B;&4@=&\@<F5A
M9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(DEN8V%P87H@9&4@
M;&5E<B!E;"!D:7)E8W1O<FEO('9F<W)O;W0N(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HQ,3`Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X
M:7-T<R(*;7-G<W1R("));F-A<&%Z(&1E(')E;F]M8G)A<B`E<R!C;VUO("5S
M.B!L82!C87)P971A(&1E<W1I;F\@>6$@97AI<W1E(@H*(SH@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z,S(S"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(DEN8V%P87H@9&4@<F5N;VUB<F%R(&5L(&1I
M<F5C=&]R:6\@5D93+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HS-#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y
M.B`E<RXB"FUS9W-T<B`B26YC87!A>B!D92!R96YO;6)R87(@96P@9&ER96-T
M;W)I;R!61E,Z("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS-3$@;&EB+U9&
M4R]S;6(N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B26YC87!A>B!D92!R
M96YO;6)R87(@96P@87)C:&EV;R!61E,@7"(E<UPB(@H*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HV,CD@;&EB+U9&4R]M=7-Q;"YP:'`Z,C0Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM
M<V=S='(@(DEN8V%P87H@9&4@<F5N;VUB<F%R(&5L(&%R8VAI=F\@5D93("5S
M+R5S+B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C(Q,R!L:6(O5D93+VUU<W%L
M+G!H<#HT-C0@;&EB+U9&4R]S<6PN<&AP.C,S.`HC.B!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HS,34@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S,W"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R("));F-A<&%Z(&1E
M(')E;F]M8G)A<B!E;"!A<F-H:79O(%9&4RXB"@HC.B!L:6(O5D93+TE33U=R
M:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI
M<V]F<R<N(@IM<V=S='(@(DEN8V%P87H@9&4@96IE8W5T87(@)VUK:7-O9G,G
M+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3@Q-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@=')I9V=E<B!F<F5E+V)U<WD@=7!D871E(&9O
M<B`E<R(*;7-G<W1R("(B"B).;R!S92!P=65D92!A8W1I=F%R(&QA(&%C='5A
M;&EZ86-I\VX@9&4@:6YF;W)M86-I\VX@9&4@=&EE;7!O(&1I<W!O;FEB;&4@
M9&4@)2(*(G,B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,34T(&QI8B]61E,O9G1P
M+G!H<#HQ-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B26YC87!A>B!D92!E<V-R:6)I
M<B!E;"!A<F-H:79O(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H
M<#HQ.#8*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I
M(&9A:6QE9"DN(@IM<V=S='(@(DEN8V%P87H@9&4@97-C<FEB:7(@=6X@87)C
M:&EV;R!61E,@*&AA(&9A;&QA9&\@8V]P>2@I*2XB"@HC.B!L:6(O5D93+V9I
M;&4N<&AP.C(Y-"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-#8@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z,34Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@9&%T82XB"FUS9W-T<B`B26YC87!A>B!D92!E<V-R:6)I<B!L;W,@9&%T
M;W,@9&5L(&%R8VAI=F\@5D93+B(*"B,Z(&QI8B]61E,N<&AP.C@V,@IM<V=I
M9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X
M8V5E9&5D+B(*;7-G<W1R("));F-A<&%Z(&1E(&5S8W)I8FER('5N(&%R8VAI
M=F\@5D93+"!S92!S=7!E<F%RX2!L82!Q=6]T82XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI
M;F4B"FUS9W-T<B`B4W5B<F%Y861A(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N
M9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(D1E<VAA8V5R
M(&-A;6)I;W,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G
M<W1R(")$97-H86-E(&QA(/IL=&EM82!A8V-I\VXB"@HC.B!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(Q(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS.#@*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O
M;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(E)E<W!U97-T82!I
M;F5S<&5R861A(&1E;"!S97)V:61O<B!E;B!L82!C;VYE>&GS;CH@(@H*(SH@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q-R!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S,Y"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS-S8@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,X,@IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E
M<B!T;SH@(@IM<V=S='(@(E)E<W!U97-T82!I;F5S<&5R861A(&1E;"!S97)V
M:61O<B!A.B`B"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R(")3:6X@8V%T96=O<NUA
M(@H*(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B56YI
M8V]D92`H551&+3@I(@IM<V=S='(@(E5N:6-O9&4@*%541BTX*2(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C4V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,S0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W"FUS9VED
M(")5;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R(")%;6ER871O<R#!<F%B
M97,@56YI9&]S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C,X"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R("))
M;F=L871E<G)A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$S(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(T,`IM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R(")%
M<W1A9&]S(%5N:61O<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,SD*;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@
M3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R(")%<W1A9&]S(%5N:61O<R!M96YO
M<R!L87,@:7-L87,@<&5R:6;I<FEC87,B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C<X(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV,@IM<V=I9"`B
M56YI=',B"FUS9W-T<B`B56YI9&%D97,B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&=Z+G!H<#HU."!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,CD*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N
M(@IM<V=S='(@(D1E<V-O;F]C:61O(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%0
M22!-97-S86=E($E$*2XB"FUS9W-T<B`B07!I;7-G:60@9&5S8V]N;V-I9&\@
M*$E$(&1E(&UE;G-A:F4@9&4@;&$@05!)*2XB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I
M9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R(")#;&EM<V=I9"!D97-C
M;VYO8VED;R`H240@9&4@;65N<V%J92!D96P@8VQI96YT92DN(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-PIM<V=I9"`B56YK;F]W;B!L
M;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B4V4@:&$@9&5F:6YI9&\@=6YA
M('5B:6-A8VGS;B!D97-C;VYO8VED82XB"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O
M<B!P87-S=V]R9"XB"FUS9W-T<B`B57-U87)I;R!O(&-O;G1R87-E\6$@9&5S
M8V]N;V-I9&]S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT
M(&5L96UE;G0B"FUS9W-T<B`B16QI;6EN87(@=NUN8W5L;R!D96P@96QE;65N
M=&\@86-T=6%L(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H<#HS,#(*;7-G
M:60@(E5N;F%M960B"FUS9W-T<B`B4VEN(&YO;6)R92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N
M<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S
M=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@
M0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO
M<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T
M;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@HB3&]S(&=U:6]N
M97,@<VEN('!R:79I;&5G:6]S(&YO('!U961E;B!A8V-E9&5R(&1E(&9O<FUA
M('!R;V=R86WA=&EC82!A($-O<G1A<B\B"B)#;W!I87(O4&5G87(@<&]R(')A
M>F]N97,@9&4@<V5G=7)I9&%D+B!0=6QS92!!8V5P=&%R('!A<F$@=F5R(&5N
M(&UO>FEL;&$N;W)G("(*(G5N82!N;W1A('3I8VYI8V$@<75E(&QE(&UU97-T
M<F4@8_-M;R!P97)M:71I<B!Q=64@=6X@9W5I\VX@86-C961A(&%L("(*(G!O
M<G1A<&%P96QE<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R
M(")!;G5L87(@8V]L;W(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C8X-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.CDR-PHC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.CDS,PIM<V=I9"`B56YS=7!P;W)T960@17AT
M96YS:6]N(@IM<V=S='(@(D5X=&5N<VGS;B!N;R!S;W!O<G1A9&$B"@HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@(D%C='5A;&EZ
M87(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R(")!8W1U86QI
M>F%R("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW
M-@IM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B06-T=6%L:7IA<B!U<W5A
M<FEO(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I
M="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(E-E(&AA
M(&%C='5A;&EZ861O(%PB)7-<(BXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T
M<B`B4V4@:&$@96QI;6EN861O(&5L(&=U:?-N(&1E(&%C='5A;&EZ86-I\VXN
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-R!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DX"FUS9VED(")5<&QO860B"FUS9W-T
M<B`B0V%R9V%R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X-0IM<V=I
M9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H
M92!S97)V97(N(@IM<V=S='(@(B(*(E-E(&AA;B!C87)G861O(&5N(&5L('-E
M<G9I9&]R('1O9&]S(&QO<R!A<F-H:79O<R!D92!C;VYF:6=U<F%C:?-N(&1E
M("(*(F%P;&EC86-I;VYE<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I
M;B!L971T97)S(@IM<V=S='(@(D%L9F%B971O(&QA=&EN;R!E;B!M87GZ<V,N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R
M(").^FUE<F]S(')O;6%N;W,@96X@;6%Y^G-C+B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#$*;7-G:60@(E5R=6=U
M87DB"FUS9W-T<B`B57)U9W5A>2(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E
M9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#
M=7)R96YT.B`E<R(*;7-G<W1R(")5<V%R(&%C='5A;#H@)7,B"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,
M(@IM<V=S='(@(E5S87(@4U-,(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP
M+F1I<W0Z,3(W"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F
M97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R(")392!U<V$@<VD@96P@
M=7-U87)I;R]C;VYT<F%S9?%A('-O;B!D:7-T:6YT;W,@96X@96P@<V5R=FED
M;W(@24U34"XB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C(Q"FUS9VED(")5<V5R(@IM<V=S='(@(E5S=6%R:6\B"@HC.B!L:6(O2&]R
M9&4O4F5G:7-T<GDN<&AP.C<W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R
M("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B16P@=7-U
M87)I;R`E<R!C87)E8V4@9&4@875T;W)I>F%C:?-N('!A<F$@)7,N(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N
M(@IM<V=S='(@(D%D;6EN:7-T<F%C:?-N(&1E('5S=6%R:6]S(@H*(SH@;&EB
M+TAO<F1E+U!R969S+U5)+G!H<#HR-#4*;7-G:60@(E5S97(@3W!T:6]N<R(*
M;7-G<W1R(")/<&-I;VYE<R!D92!U<W5A<FEO(@H*(SH@<VEG;G5P+G!H<#HV
M,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B4F5G:7-T<F\@
M9&4@=7-U87)I;W,B"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E
M9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*
M;7-G<W1R(")%<W1A('-E9&4@=&EE;F4@9&5S86-T:79A9&\@96P@<F5G:7-T
M<F\@9&4@=7-U87)I;W,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0Y
M-`IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R(").;R!S
M92!H82!E;F-O;G1R861O(&QA(&ED96YT:61A9"(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4S-@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.CDX(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ-3`*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHW,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B57-U87)I;R(*"B,Z
M(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*
M;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T
M<B`B66$@97AI<W1E(&5L(&YO;6)R92!D92!U<W5A<FEO(%PB)7-<(BXB"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N
M86UE.B(*;7-G<W1R(")5<W5A<FEO.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M
M;V)I;&4N:6YC.C@*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B57-U87)I
M;SH@(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I
M9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B57-U87)I;W,@96X@
M96P@<VES=&5M83HB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,30@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C0R"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(E5Z
M8F5K:7-TX6XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$W,"!L:6(O5D93+V9I
M;&4N<&AP.C(V.`IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES
M="XB"FUS9W-T<B`B3F\@97AI<W1E(&5L(&1I<F5C=&]R:6\@5D93+B(*"B,Z
M(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C$R,`IM<V=I9"`B5F%C
M871I;VXB"FUS9W-T<B`B075S96YC:6$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z.#8V"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@
M(@IM<V=S='(@(DQA<R!U8FEC86-I;VYE<R!VX6QI9&%S(&5N8V]N=')A9&%S
M(&EN8VQU>65N.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8S
M.0IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B5F%L:61E>B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU.3<*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@
M9G)O;2!N;W<N(@IM<V=S='(@(E9A;&]R(&5N(&UI;G5T;W,@82!P87)T:7(@
M9&4@86AO<F$N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@U-B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I
M<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B16P@
M=F%L;W(@97AC961E(&5L('1A;6'Q;R!MX7AI;6\@9&4@)7,N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(R-#0@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-C8@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(S,38*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(Y,3`@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G
M:60@(E9A;'5E<R(*;7-G<W1R(")686QO<F5S(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(Q,#D@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.#8*;7-G:60@(E9A
M;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R(")686QO<F5S(&$@<V5L96-C
M:6]N87(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0Y"FUS9VED(")686YU871U(@IM<V=S='(@(E9A;G5A='4B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,S"FUS9VED(")687)I
M86)L92(*;7-G<W1R(")687)I86)L92(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#4*;7-G:60@(E9E;F5Z=65L82(*
M;7-G<W1R(")696YE>G5E;&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S
M<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(DAA
M(&9A;&QA9&\@;&$@8V]M<')O8F%C:?-N("T@97-T92!M96YS86IE('!U961E
M(&AA8F5R<V4@9F]R>F%D;RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C<P,0IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R(")697)S:?-N(@H*(SH@
M8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,C(X"FUS9VED(")697)S
M:6]N($-O;G1R;VPB"FUS9W-T<B`B0RX@=F5R<VEO;F5S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I
M9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B06QI;F5A8VGS;B!V97)T:6-A
M;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B36%R9V5N('9E
M<G1I8V%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(E9E<G1I8V%L.B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS
M9VED(")697)Y($AI9V@B"FUS9W-T<B`B375Y(&%L=&$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(T,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0X"FUS9VED(")6
M:65T($YA;2(*;7-G<W1R(")6:65T;F%M(@H*(SH@8V]N9FEG+RYB86LO;FQS
M+G!H<"YD:7-T.C$Y-PIM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G
M<W1R(")6:65T;F%M:71A("A625-#24DI(@H*(SH@;&EB+TAO<F1E+TU)344O
M0V]N=&5N=',N<&AP.CDW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S
M(@IM<V=S='(@(E9E<B`E<R(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*
M;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T<B`B5F5R
M('5N82!PX6=I;F$@=V5B(&5X=&5R;F$B"@HC.B!L:6(O2&]R9&4O34E-12]#
M;VYT96YT<RYP:'`Z.#,P"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@
M)7,B"FUS9W-T<B`B5F5R(&-O;6\@)7,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0V"FUS9VED(")6:7)G:6X@27-L
M86YD<RP@0G)I=&ES:"(*;7-G<W1R("))<VQA<R!6[7)G96YE<RP@0G)I=.%N
M:6-A<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR-#<*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@
M(DES;&%S(%;M<F=E;F5S+"!5+E,N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR,38*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B5FES:6)I;&ED860B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4R"FUS9VED(")6
M:7-I8FEL:71Y.B`B"FUS9W-T<B`B5FES:6)I;&ED860Z("(*"B,Z(&QI8B].
M970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F
M;VYE($ET86QY('9I82!33510(@IM<V=S='(@(E9O9&%F;VYE(&1E($ET86QI
M82!M961I86YT92!33510(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(D%6
M25-/(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9
M($923TT@)7,N(@IM<V=S='(@(J&AH4%$5D525$5.0TE!(2$A($5,24U)3D4@
M34%.54%,345.5$4@14P@1U5)TTX@1$4@)7,N(@H*(SH@;&EB+TYE="]335,O
M=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@
M(E=)3B!P;W(@2%144"(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-3`*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM
M<V=S='(@(E=A;&QI<R!Y($9U='5N82(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HY-2!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U
M<RYP:'`Z,CD*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R
M-PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")!9'9E<G1E;F-I82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@
M(E=E(@IM<V=S='(@(DUI92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R(")0<F5V
M:7-I\VX@9&5L('1I96UP;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HT,38*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G
M<W1R(")$871O<R!D96P@=&EE;7!O('-U;6EN:7-T<F%D;W,@<&]R(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS
M9W-T<B`B5V5A=&AE<BYC;VTB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M-@IM<V=I9"`B5V5B(@IM<V=S='(@(E=E8B(*"B,Z(&-O;F9I9R\N8F%K+W)E
M9VES=')Y+G!H<"YD:7-T.C0S.0IM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B
M4V5D92!796(B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4X"FUS
M9VED(")7965K;'DB"FUS9W-T<B`B4V5M86YA;&UE;G1E(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@(E=E;&-O;64B"FUS9W-T
M<B`B0FEE;G9E;FED;R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M-3<@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(D)I96YV96YI9&]S(&$@
M)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T
M97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L
M8V]M92P@)7,B"FUS9W-T<B`B0FEE;G9E;FED;RP@)7,B"@HC.B!C;VYF:6<O
M+F)A:R]N;',N<&AP+F1I<W0Z,3DX"FUS9VED(")797-T97)N("A)4T\M.#@U
M.2TQ*2(*;7-G<W1R(")/97-T92`H25-/+3@X-3DM,2DB"@HC.B!C;VYF:6<O
M+F)A:R]N;',N<&AP+F1I<W0Z,3DY"FUS9VED(")797-T97)N("A)4T\M.#@U
M.2TQ-2DB"FUS9W-T<B`B3V5S=&4@*$E33RTX.#4Y+3$U*2(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR-#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<X"FUS9VED(")7
M97-T97)N(%-A:&%R82(*;7-G<W1R(")3X6AA<F$@3V-C:61E;G1A;"(*"B,Z
M(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C0T,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F
M=&5R(&QO9VEN/R(*;7-G<W1R("*_477I(&%P;&EC86-I\VX@9&5B97+M82!M
M;W-T<F%R("5S(&%L(&EN:6-I87(@;&$@<V5S:?-N/R(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI
M;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R("*_0W7A;"!E<R!E;"!C87+A8W1E
M<B!D96QI;6ET861O<C\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G
M<W1R("*_0W7A;"!E<R!E;"!C87+A8W1E<B!D92!C:71A9&\_(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C4*;7-G:60@(E=H
M97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R(")-87!A(&1E(&QO8V%L:7IA
M8VGS;B!D92!!=7-T<F%L:6$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*
M;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R(")1=>D@9F%S97,B"@HC.B!C
M;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ,S8*;7-G:60@(E=H:6-H('!L
M=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS
M9W-T<B`B4&QU9VEN<R!H86)I;&ET861O<R!D96P@961I=&]R(&1E('1E>'1O
M(&5N<FEQ=65C:61O+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(D%N
M8VAU<F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P-PIM<V=I9"`B5VED
M=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(D%N8VAU<F$@96X@=6YI9&%D97,@
M0U-3(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S8Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L
M969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R(")!
M;F-H=7)A(&1E;"!M96[Z("5S(&EZ<75I97)D;R`H9&ES<&]N:6)L92!E;B!L
M82!P<O-X:6UA('-E<VGS;BDZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L
M92(*;7-G<W1R(")!;F-H=7)A(&1E(&QA('1A8FQA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H
M('5N:70B"FUS9W-T<B`B56YI9&%D97,@9&4@86YC:'5R82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7
M:61T:#HB"FUS9W-T<B`B06YC:'5R83HB"@HC.B!C;VYF:6<O+F)A:R]R96=I
M<W1R>2YP:'`N9&ES=#HU,34*;7-G:60@(E=I:VDB"FUS9W-T<B`B5VEK:2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(E=I;F0B"FUS
M9W-T<B`B5FEE;G1O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C@*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B5FEE;G1O
M(&UA='5T:6YA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-PIM<V=I9"`B
M5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R(")696QO8VED860@9&5L('9I
M96YT;R!E;B!N=61O<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38S"FUS
M9VED(")7:6YD.B(*;7-G<W1R(")6:65N=&\Z(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(E9I
M96YT;SH@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7
M:7-D;VTB"FUS9W-T<B`B4V%B:61U<NUA(@H*(SH@8V]N9FEG+RYB86LO<F5G
M:7-T<GDN<&AP+F1I<W0Z,3DX"FUS9VED(")7:7-H;&ES="(*;7-G<W1R(")$
M97-E;W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O
M<FLB"FUS9W-T<B`B16UP;&5O(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,C0@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")$:7)E8V-I\VX@
M9&5L('1R86)A:F\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")496SI9F]N;R!D
M96P@=')A8F%J;R(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,3DS(&QI8B]&:6QE
M+T-35BYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E
M<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D
M+B(*;7-G<W1R(").^FUE<F\@97)R\VYE;R!D92!C86UP;W,@96X@;&$@;.UN
M96$@)60N(%-E(&5S<&5R86)A;B`E9"!Y(&AA>2`E9"XB"@HC.B!L:6(O1FEL
M92]#4U8N<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB
M97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@
M(D[Z;65R;R!E<G+S;F5O(&1E(&-A;7!O<RX@4V4@97-P97)A8F%N("5D('D@
M:&%Y("5D+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3(Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93
M(&9I;&4N(@IM<V=S='(@(D]F9G-E="`E9"!E<G+S;F5O(&%L(&QE97(@=6X@
M87)C:&EV;R!61E,N(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I
M<W0Z,C0U"FUS9VED(")8+5)E9B(*;7-G<W1R(")8+5)E9B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@0F%S:6,@
M0V]N<W1R86EN=',B"FUS9W-T<B`B3&EM:71A8VEO;F5S(&+A<VEC87,@6#4P
M.78S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@
M(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B57-O(&1E(&-L
M879E(&5X=&5N9&ED82!8-3`Y=C,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@
M3F%M92(*;7-G<W1R(").;VUB<F4@86QT97)N871I=F\@9&4@87-U;G1O(%@U
M,#EV,R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED
M(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("))9&5N
M=&EF:6-A9&]R(&1E(&-L879E(&1E(&%S=6YT;R!8-3`Y=C,B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8X,PIM<V=I9"`B6#4P.78S(&5X=&5N
M<VEO;G,B"FUS9W-T<B`B17AT96YS:6]N97,@6#4P.78S(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(D%!(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-"!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4V"FUS9VED(")965E9(@IM<V=S
M='(@(D%!04$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3$Q,0IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R("*A36%P82!D92!9
M86AO;R$B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED
M(")996%R;'DB"FUS9W-T<B`B06YU86QM96YT92(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3(*;7-G:60@(EEE;65N
M(@IM<V=S='(@(EEE;65N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.CDV-@IM<V=I9"`B665S(@IM<V=S='(@(E/M(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@
M(EEE<RP@22!!9W)E92(*;7-G<W1R(")3[2P@;&\@86-E<'1O(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B
M66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O
M('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*(D5S=.$@96X@
M34]$3R!415A43RX@571I;&EC92!E;"!B;W3S;B!;/#Y=('!A<F$@<F5G<F5S
M87(@86P@;6]D;R!765-)5UE'+B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z,C,V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A
M<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N
M(@IM<V=S='(@(DYO(&1I<W!O;F4@9&4@<')I=FEL96=I;W,@<&%R82!C<F5A
M<B!MX7,@9&4@)60@8FQO<75E<RXB"@HC.B!L:6(O2&]R9&4N<&AP.C$T,C0*
M;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(DYO
M(&5S=.$@875T96YT:69I8V%D;RXB"@HC.B!L:6(O2&]R9&4O261E;G1I='DN
M<&AP.C,P.`IM<V=I9"`B66]U(&-A;FYO="!H879E('1H92`G7%PG(&-H87)A
M8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B3F\@<'5E9&4@:6YC
M;'5I<B!E;"!C87+A8W1E<B!<(EQ<7"(@96X@96P@;F]M8G)E(&-O;7!L971O
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#4U(&QI8B](;W)D92]&;W)M
M+G!H<#HQ.3<U"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M
M86EL(&%D9')E<W,N(@IM<V=S='(@(DYO(&EN=')O9'5J;R!U;F$@9&ER96-C
M:?-N(&1E(&-O<G)E;R!VX6QI9&$N(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP
M.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A
M;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E
M<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"B).;R!A<V]C
M:?,@;FEN9W5N;R!D92!L;W,@8V%M<&]S(&1E;"!A<F-H:79O(&EM<&]R=&%D
M;R!A(&QO<R!C86UP;W,@(@HB8V]R<F5S<&]N9&EE;G1E<R!D92`E<RXB"@HC
M.B!L:6(O2&]R9&4O075T:"YP:'`Z.3@W"FUS9VED(")9;W4@:&%V92!B965N
M(&QO9V=E9"!O=70N(@IM<V=S='(@(DAA('-A;&ED;R!D92!L82!S97-I\VXN
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S
M(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA
M=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"B)4:65N92!Q=64@
M:6YT<F]D=6-I<B!U;B!N^FUE<F\@9&4@=&5LZ69O;F\@;?-V:6P@=N%L:61O
M+"!S\VQO(&3M9VET;W,@8V]N('5N("(*(B<K)R!O<&-I;VYA;"!P87)A(&5L
M('!R969I:F\@9&4@;&QA;6%D82!I;G1E<FYA8VEO;F%L+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A
M('9A;&ED('9A;'5E+B(*;7-G<W1R(")4:65N92!Q=64@:6YT<F]D=6-I<B!U
M;B!V86QO<B!VX6QI9&\N(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H
M<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C
M:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B4&%R82!U<V%R($%L=&%S
M('1I96YE('%U92!C;VYF:6=U<F%R('5N(&UO=&]R(&1E($1A=&%4<F5E+B(*
M"B,Z(&QI8B](;W)D92YP:'`Z-#<Q"FUS9VED(")9;W4@;75S="!C;VYF:6=U
M<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B5&EE;F4@<75E(&-O;F9I9W5R
M87(@=6X@;6]T;W(@5D93+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE
M;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS
M9W-T<B`B1&5B92!D97-C<FEB:7(@96P@<')O8FQE;6$@86YT97,@9&4@96YV
M:6%R(&5L(&EN9F]R;64N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%52
M3"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(E1I96YE('%U
M92!I;G1R;V1U8VER(&QA(%523"!A(&QA('%U92!A<'5N=&$@97-T92!V[6YC
M=6QO(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@
M(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS
M9W-T<B`B5&EE;F4@<75E('-E;&5C8VEO;F%R('5N('-E<G9I9&]R(&$@96QI
M;6EN87(N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R(")4
M:65N92!Q=64@97-P96-I9FEC87(@=6X@=7-U87)I;R!A(&5L:6UI;F%R+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B5&EE;F4@<75E(&5S
M<&5C:69I8V%R('5N('5S=6%R:6\@82!E;&EM:6YA<BXB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*
M;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB
M"FUS9W-T<B`B5&EE;F4@<75E(&5S<&5C:69I8V%R(&5L('5S=6%R:6\@82!A
M\6%D:7(N(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(E1I
M96YE('%U92!E<W!E8VEF:6-A<B!E;"!U<W5A<FEO(&$@86-T=6%L:7IA<BXB
M"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T
M<B`B5&EE;F4@<75E(&5S<&5C:69I8V%R('%UZ2!A8V-I\VX@<V4@96IE8W5T
M87+A+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP
M.C<Q"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N
M(@IM<V=S='(@(E1I96YE('%U92!I;G1R;V1U8VER('5N(&YU979O(&YO;6)R
M92!D92!C871E9V]R[6$N(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)
M=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R(")4:65N92!Q=64@:6YT<F]D
M=6-I<B!U;B!N^FUE<F\@9&4@=&5LZ69O;F\@:71A;&EA;F\B"@HC.B!L:6(O
M2&]R9&4O075T:"YP:'`Z.3<U"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@
M)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*
M;7-G<W1R(")(82!E>'!I<F%D;R!S=2!S97-I\VX@)7,N(%9U96QV82!A(&EN
M:6-I87(@<V5S:?-N+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C,X"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B4W4@
M9&ER96-C:?-N(&1E(&-O<G)E;R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H
M<"YD:7-T.C(Q-0IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R
M(")$:7)E8V-I\VX@1&4Z(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I
M<W0Z-C<@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-S<*(SH@8V]N9FEG
M+RYB86LO<')E9G,N<&AP+F1I<W0Z.#4@8V]N9FEG+RYB86LO<')E9G,N<&AP
M+F1I<W0Z.3(*;7-G:60@(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`B4W4@
M:6YF;W)M86-I\VXB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3<Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@
M8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO
M;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I
M;B!A9V%I;BXB"FUS9W-T<B`B(@HB2&$@8V%M8FEA9&\@<W4@9&ER96-C:?-N
M(&1E($EN=&5R;F5T(&1E<V1E(&5L(&-O;6EE;GIO(&1E('-U('-E<VGS;B`E
M<RX@4&]R("(*(G)A>F]N97,@9&4@<V5G=7)I9&%D('1I96YE('%U92!V;VQV
M97(@82!I;FEC:6%R(&QA('-E<VGS;BXB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(E-U
M(&YO;6)R92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU
M"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N
M;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*(G5S
M92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T
M('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD+B(*
M;7-G<W1R("(B"B)3=2!M;W1O<B!D92!A=71E;G1I9FEC86-I\VX@;F\@<&5R
M;6ET92!A\6%D:7(@=7-U87)I;W,N(%-I('%U:7-I97)A('5S87(@(@HB2&]R
M9&4@<&%R82!A9&UI;FES=')A<B!C=65N=&%S(&1E('5S=6%R:6\L('1E;F1R
MX2!Q=64@=71I;&EZ87(@=6X@;6]T;W(@9&4@(@HB875T96YT:69I8V%C:?-N
M(&1I<W1I;G1O+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI
M;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O
M97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@
M(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*
M;7-G<W1R("(B"B)3=2!M;W1O<B!D92!A=71E;G1I9FEC86-I\VX@;F\@<&5R
M;6ET92!L:7-T87(@=7-U87)I;W,L(&\@<V4@:&$@(@HB9&5S:&%B:6QI=&%D
M;R!L82!C87)A8W1E<NUS=&EC82!P;W(@86QG^FX@;6]T:79O+B(*"B,Z(&QI
M8B](;W)D92]!=71H+G!H<#HY.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H
M92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T
M('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R
M("(B"B)087)E8V4@<75E(&AA(&-A;6)I861O('-U(&YA=F5G861O<B!D97-D
M92!E;"!C;VUI96YZ;R!D92!S=2!S97-I\VX@)7,N(%!O<B`B"B)R87IO;F5S
M(&1E('-E9W5R:61A9"!T:65N92!Q=64@=F]L=F5R(&$@:6YI8VEA<B!L82!S
M97-I\VXN(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3<*;7-G:60@(EEO
M=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS
M9W-T<B`B4W4@;F%V96=A9&]R(&YO(&%D;6ET92!E<W1A(&-A<F%C=&5R[7-T
M:6-A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS
M9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R
M:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P
M<FEN="XB"FUS9W-T<B`B(@HB16P@;F%V96=A9&]R(&YO(&%D;6ET92!E<W1A
M(&]P8VGS;B!D92!I;7!R97-I\VXN(%!R97-I;VYE($-O;G1R;VPO0V]M86YD
M;R`K("(*(E`@<&%R82!I;7!R:6UI<BXB"@HC.B!C;VYF:6<O+F)A:R]P<F5F
M<RYP:'`N9&ES=#HR-C$*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z
M(@IM<V=S='(@(EIO;F$@:&]R87)I82!A8W1U86PZ(@H*(SH@<V5R=FEC97,O
M<')E9G,N<&AP.C$Q-PIM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA
M<R!B965N(&-H86YG960N(@IM<V=S='(@(E-E(&AA(&-A;6)I861O('-U(&ED
M96YT:61A9"!P;W(@;VUI<VGS;BXB"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP
M:'`N9&ES=#HQ-C$*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS
M9W-T<B`B261E;G1I9&%D('!O<B!O;6ES:?-N.B(*"B,Z(&-O;F9I9R\N8F%K
M+W!R969S+G!H<"YD:7-T.C(P-`IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM
M<V=S='(@(DYO;6)R92!C;VUP;&5T;SHB"@HC.B!L:6(O2&]R9&4O075T:"YP
M:'`Z.3DY"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R
M(")392!H82!A9V]T861O('-U('1I96UP;R!D92!C;VYE>&GS;BXB"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@
M(DQA(&YU979A(&-O;G1R87-E\6$@<&%R82`E<R!E<SH@)7,B"@HC.B!L:6(O
M2&]R9&4O4')E9G,O54DN<&AP.C$U-`IM<V=I9"`B66]U<B!O<'1I;VYS(&AA
M=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S
M:6]N+B(*;7-G<W1R(")392!H86X@86-T=6%L:7IA9&\@<W5S(&]P8VEO;F5S
M('/S;&\@<&]R(&QA(&1U<F%C:?-N(&1E(&QA('-E<VGS;BXB"@HC.B!L:6(O
M2&]R9&4O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA
M=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R(")392!H86X@86-T=6%L:7IA9&\@
M<W5S(&]P8VEO;F5S+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S
M='(@(E-E(&AA(')E86IU<W1A9&\@<W4@8V]N=')A<V7Q82(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W
M;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@
M:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HB4V4@
M:&$@<F5A:G5S=&%D;R!S=2!C;VYT<F%S9?%A+"!C;VUP<G5E8F4@96P@8V]R
M<F5O(&4@:6YI8VEE('-E<VGS;B!C;VX@<W4@(@HB;G5E=F$@8V]N=')A<V7Q
M82XB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-S,S"FUS9VED(")9;W5R('!A
M<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R("),82!C;VYT<F%S9?%A(&AA
M(&5X<&ER861O+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU
M.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B4V5R=FED
M;W)E<R!R96UO=&]S.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M."!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4T"FUS9VED(")9=6=O<VQA=FEA
M(@IM<V=S='(@(EEU9V]S;&%V:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(EIA:7)E(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR-#@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-@IM<V=I
M9"`B6F%M8FEA(@IM<V=S='(@(EIA;6)I82(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3<*;7-G:60@(EII;6)A8G=E
M(@IM<V=S='(@(EII;6)A8G=E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8V"FUS9VED(")::7!P>2(*;7-G<W1R(")::7!P>2(*"B,Z(&QI8B](;W)D
M92]497AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI
M9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(EM/8W5L=&%R('1E>'1O(&-I=&%D
M;UTB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX.0IM<V=I9"`B6U!R;V)L
M96T@4F5P;W)T72(*;7-G<W1R(");26YF;W)M92!D92!P<F]B;&5M85TB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I
M9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R(");36]S=')A<B!T97AT
M;R!C:71A9&\@+2(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H:6=H;&EG
M:'1Q=6]T97,N<&AP.C$W-`HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1
M=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");36]S=')A<B!T97AT
M;R!C:71A9&\@+2`E<R!L[6YE87-=(@H*(SH@;&EB+TAO<F1E+G!H<#HR,#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@
M(EML[6YE82`E<R!D92`E<UTB"@HC.B!L:6(O2&]R9&4N<&AP.C$U-30@=&5M
M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(E]!9&UI;FES=')A8VGS;B(*"B,Z(&QI8B]A<&DN<&AP
M.C$U-PIM<V=I9"`B7T-,22(*;7-G<W1R(")?0TQ)(@H*(SH@;&EB+V%P:2YP
M:'`Z,30Q"FUS9VED(")?1&%T851R964B"FUS9W-T<B`BP7)?8F]L(&1A=&]S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O=R(*;7-G<W1R(")%7VQI;6EN
M87(@9FEL82(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P<R(*
M;7-G<W1R(")?1W)U<&]S(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$W-0IM
M<V=I9"`B7TAE;'`B"FUS9W-T<B`B05]Y=61A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?
M26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")0<F]P:65D861E<R!D92!?
M:6UA9V5N+BXN(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$Y-`IM<V=I9"`B
M7TQO9R!I;B(*;7-G<W1R(")?26YI8VEA<B!S97-I\VXB"@HC.B!L:6(O2&]R
M9&4O365N=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*;7-G<W1R(")?4V%L
M:7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R(")-
M;V1I9FEC87(@7W;M;F-U;&\N+BXB"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z
M,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R(")?3W!C:6]N97,B"@HC.B!L
M:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R(")?
M4')I=FEL96=I;W,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*
M;7-G<W1R(")?16QI;6EN87(@=NUN8W5L;RXN+B(*"B,Z(&QI8B]A<&DN<&AP
M.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@(D-O;E]F:6=U<F%C+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4')O
M<&EE9&%D97,@9&4@7W1A8FQA+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS
M9VED(")?57-E<G,B"FUS9W-T<B`B7U5S=6%R:6]S(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HY,C4*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R(")D
M:7)E8V-I;VYE<R(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$S
M-`IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B9&5S=&EN871A
M<FEO(&1E<V-O;F]C:61O(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,3<*
M;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(F%G96YD82(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3<Y(&QI8B]";&]C:R]M971A<BYP:'`Z,S8U"B,L('!H
M<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B8V%L;6$B"@HC.B!L:6(O
M2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A
M=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B;F\@<V4@<'5E9&4@8W)E87(@96P@
M87)C:&EV;R!D92!D97-T:6YO(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G
M92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R(")N
M;R!S92!P=65D92!A8G)I<B!E;"!O<FEG96XB"@HC.B!L:6(O2&]R9&4O34E-
M12]#;VYT96YT<RYP:'`Z-C`P"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@
M(G!U;'-E(&%Q=>TB"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ
M,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R(")E
M<G)O<B!D92!L[6YE82!D92!C;VUA;F1O(@H*(SH@;&EB+TAO<F1E+TU)344O
M365S<V%G92YP:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM
M<V=S='(@(F5R<F]R(&1E(&-O;F9I9W5R86-I\VXB"@HC.B!L:6(O2&]R9&4O
M34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F
M:6QE(&UI<W-I;F<B"FUS9W-T<B`B9F%L=&$@=6X@87)C:&EV;R!C<NUT:6-O
M(&1E;"!S:7-T96UA(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z
M,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R(")E<G)O<B!D
M92!F;W)M871O(&1E(&1A=&]S(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET
M+FEN8SHS,`IM<V=I9"`B961I="(*;7-G<W1R(")M;V1I9FEC87(B"@HC.B!L
M:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ.#(*;7-G:60@(F5N=')Y(&YO
M="!F;W5N9"(*;7-G<W1R(")E;G1R861A(&YO(&5N8V]N=')A9&$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PIM<V=I9"`B
M9F%L;&EN9R(*;7-G<W1R(")D97-C96YS;R(*"B,Z(&QI8B](;W)D92]"<F]W
M<V5R+G!H<#HX.38*;7-G:60@(F9I;&4B"FUS9W-T<B`B87)C:&EV;R(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3@Q(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S8W(&QI8B]";&]C:R]M971A<BYP:'`Z,SDS"B,L('!H<"UF;W)M870*;7-G
M:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B9&5L("5S
M("@E<RD@82!L87,@)7,@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,Y"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(G9E;G1O<V\B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4P"FUS9VED
M(")H.B(*;7-G<W1R(")H.B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HS-3D*;7-G:60@(FAH(@IM<V=S='(@(FAH(@H*(SH@;&EB
M+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@
M=6YK;F]W;B(*;7-G<W1R(")N;VUB<F4@9&4@86YF:71R:?-N(&1E<V-O;F]C
M:61O(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0IM<V=I9"`B:6UM
M961I871E(@IM<V=S='(@(FEN;65D:6%T86UE;G1E(@H*(SH@861M:6XO<V5T
M=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@
M(FEN;&EN92(*;7-G<W1R(")E;B!L[6YE82(*"B,Z(&QI8B](;W)D92]-24U%
M+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM
M<V=S='(@(F5R<F]R(&1E(&5N=')A9&$O<V%L:61A(@H*(SH@;&EB+TAO<F1E
M+TU)344O365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R
M92!E<G)O<B(*;7-G<W1R(")E<G)O<B!D92!S;V9T=V%R92!I;G1E<FYO(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G
M:60@(FQI;F5S72(*;7-G<W1R(")L[6YE87-=(@H*(SH@;&EB+U9&4R])4T]7
M<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI
M<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@
M(F/S9&EG;R!D92!E<G)O<B!M:VES;V9S("5D(&%L(')E86QI>F%R($E33RXB
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<P"FUS
M9VED(")M;2(*;7-G<W1R(")M;2(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP
M:'`Z,C@U('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S0*(SH@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(T,PIM<V=I9"`B;F%M92(*;7-G
M<W1R(")N;VUB<F4B"@HC.B!L:6(O2&]R9&4O4E!#+G!H<#HQ,C0*;7-G:60@
M(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R(")S:6X@9&5S87)R;VQL87(B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R,C`*;7-G:60@(FYO="!Y
M970@:6UP;&5M96YT960B"FUS9W-T<B`B8?IN(&YO('-E(&AA(&1E<V%R<F]L
M;&%D;R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3`Y"FUS9VED(")N;W1E
M<&%D(@IM<V=S='(@(FYO=&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G
M<W1R(")P;W)C96YT86IE(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP
M:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R(")P<FEV
M:6QE9VEO(&1E;F5G861O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@
M(G#M>&5L97,B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-S`*
M;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R(")E<G)O
M<B!R96UO=&\@9&4@<')O=&]C;VQO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S4*;7-G:60@(G)I<VEN9R(*;7-G<W1R(")E
M;B!A=6UE;G1O(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,30R
M"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@(G-E<G9I8VEO
M(&YO(&1I<W!O;FEB;&4N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HQ
M,#$*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B;6]S=')A<B!D
M:69E<F5N8VEA<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R(")S;7,R
M96UA:6P@<&]R($A45%`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S@W"FUS9VED(")S<R(*;7-G<W1R(")S<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<T"FUS9VED(")S=&5A
M9'DB"FUS9W-T<B`B97-T86)L92(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A
M9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(F5R<F]R
M(&1E;"!S:7-T96UA(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,S,*;7-G
M:60@(G1A<VL@;&ES="(*;7-G<W1R(")T87)E87,B"@HC.B!L:6(O2&]R9&4O
M34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E
M(@IM<V=S='(@(F9A;&QO('1E;7!O<F%L(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S8@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(G1Y<&4@
M=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B97-C<FEB
M82!D;W,@=F5C97,@;&$@8V]N=')A<V7Q82!P87)A(&-O;F9I<FUA<FQA(@H*
M(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B=6YI9FEC861O(@H*(SH@
M;&EB+TAO<F1E+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS
M9W-T<B`B<VEN(&YO;6)R92(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C(S(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-C4*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(G5S=6%R:6\@<V5L96-C
M:6]N861O(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HS
M-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0R"FUS9VED(")W.B(*;7-G<W1R
M(")W.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED
M(")W96%T:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O;2(*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O971?144N<&\`````````
M````````````````````````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#<R,#(P
M,0`Q,#4Q-30S,S<U-``P,3<V,C``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````(R!(3U)$12!%4U1/3DE!3B!44D%.4TQ!5$E/
M3B`*(PHC(%1O;VUA<R!!87,@/'1O;VUA<RYA87-`;6%I;"YE93XL(#(P,#(@
M+2`R,#`V(`HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S
M:6]N.B!(;W)D92`S+C$M8W9S7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@
M9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P
M,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P
M-BTP,RTS,"`Q-CHQ,2LP,S`P7&XB"B),87-T+51R86YS;&%T;W(Z(%1O;VUA
M<R!!87,@/'1O;VUA<RYA87-`;6%I;"YE93Y<;B(*(DQA;F=U86=E+51E86TZ
M($5S=&]N:6%N(#QD979`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S
M:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E
M=#U)4T\M.#@U.2TQ,UQN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@
M.&)I=%QN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*"5S
M('#D979A('1A9V%S:2DB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$S-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM
M<V=S='(@(B`H2VEI<FML86AV("5S*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES
M*2(*;7-G<W1R("(@*"5S('#D979A('#D<F%S="DB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S<S"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(@
M*'3D;F$I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-0IM<V=I
M9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B("AH;VUM92DB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,S<Q"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS
M9W-T<B`B("AE:6QE*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-38@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,0HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`W"FUS9VED("(@870@(@IM<V=S
M='(@(B!K:6ER=7-E9V$@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B7"(E<UPB(&5I(&]L92!K871A;&]O9RXB"@HC
M.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(EPB
M)7-<(B!E:2!O;&4@=O5I;6%L:6L@=F%L:6LN(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HV-3D*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#0R"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T
M<GDN(@IM<V=S='(@(EPB)7-<(B!E:2!O;&4@2&]R9&4@<F5G:7-T<FES(&CD
MY&QE<W1A='5D+B(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@
M9F]U;F0N(@IM<V=S='(@(EPB)7-<(B!P=74@97-I=&%J870@96D@;&5I='5D
M+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS
M9W-T<B`B7"(E<UPB(&QI<V%T:2!G<G5P<&ED92!S_'-T965M:2XB"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M
M+B(*;7-G<W1R(")<(B5S7"(@;&ES871I(/5I9W5S=&4@<_QS=&5E;6DN(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E
M871E9#H@)7,N(@IM<V=S='(@(EPB)7-<(B!E:2!L;V]D=60Z("5S+B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G
M<W1R("(E+C)F34(@:V%S=71A='5D(&MO:VMU("4N,F9-0BUS="`H)2XR9B4E
M*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B5D("5S(&IA
M("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E
M9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B
M4VEN=2!P87)O;VP@865G=6(@)60@<.1E=F$@<.1R87-T+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B5D('#D979A(&5N;G5S='5S
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S("T@5.1H96QE<&%N
M=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`T"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B5S
M('/U<FUE:N1L9R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@S,R!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO
M;B(*;7-G<W1R("(E<R!H;V]L9'5S=/;V9"`M(&MI;FYI='5S(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,C$U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B5S
M('!A:6=A;&1U<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HR-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R
M("(E<R!K;VYT;R!T86]T;&5M:6YE(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G
M<F5E;65N="(*;7-G<W1R("(E<R!K87-U='5S=&EN9VEM=7-E9"(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#(X(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z-#DP"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C4Q
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(E<R!O;B!J=6)A
M(&]L96UA<RXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.2!L:6(O0FQO
M8VLO;65T87(N<&AP.C$V-2!L:6(O0FQO8VLO;65T87(N<&AP.C(S.0HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,T-2!L:6(O0FQO8VLO;65T87(N<&AP.C,U
M,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(E
M<R!K:6ER=7-E9V$@)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@
M<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E
M;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO
M=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(B"B(E
M<R!O;B!V86QM:7,@=&5G96UA(&%L;'!O;VP@;&]E=&QE='5D(&AO;VQD=7-T
M]O9D+B!-Y')G:7-T82!T]O9D+"!M:61A("(*(G-O;W9I9"!P<F%E9W4@=&5H
M82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S0P"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B5S(&]N(&MO
M:'5S='5S;&EK(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R!M:6YU=&ET
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R
M,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@
M(B5S(&5I(&QE:71U9"XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM
M<V=S='(@(B5S(&MU;FD@)7,@)7,M<W0B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDR,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E
M<W,@0F]O:R(*;7-G<W1R(")+87-U=&%J82`E<R!A861R97-S:7)A86UA="(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$T"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B2V%S=71A:F$@)7,@
M:V%L96YD97(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B2V%S
M=71A:F$@)7,@;>1R:VUE9"(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3,P"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS
M9W-T<B`B2V%S=71A:F$@)7,@_&QE<V%N9&5D(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7,Z("5S
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y
M(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@
M9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@
M=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS
M9W-T<B`B(@HB)7,Z(%-E92!T96%D92!E:2!P<G5U9VD@;VQL82!S86%T:F%L
M="P@:V5L;&5L="!S964@<&%I<W1A8B!O;&5V870N(,1R82`B"B)K:6ER=7-T
M82!K;/5P<V%M82!S96QL97,@97-I;F5V86ED(&QI;FME(';U:2!E<VET86UA
M('-A871J86QE("(*(FUI;F=I=&ES:6ML:6MK=2!I;F9O="XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8U(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HT,3`*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B+"!T
M=75L96EI;&ED("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@X(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S
M=&EN9R`E<R`E<R(*;7-G<W1R("(L('1U=6QE:6EL:60@)7,@)7,B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(L
M('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B+"!V86AE;6EK=7,@
M)7,@:W5N:2`E<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,CDT(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$R.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-S0Y"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@=F%L:2`M
M+2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&
M;W)M870B"FUS9W-T<B`B,3(M='5N;FEN92!E<VET=7,B"@HC.B!L:6(O0FQO
M8VLO=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@
M(C(T+71U;FYI;F4@97-I='5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI
M;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T('1U;F1I(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S
M(@IM<V=S='(@(CQ%96QM:6YE(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M,3D*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@
M=&AI<R!B;&]C:RXB"FUS9W-T<B`B4V5E(&)L;VMK('9A:F%B(&%N9&UE8F%A
M<VD@='5G92XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V,`IM
M<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B2G5H
M='5S(&MO:'5T878@=FEG82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E
M9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B2VER:F$@:W+\<'1E
M97)I;6ES96MS(&]N('9A:F$@879A;&EK:W4@4$=0(';U=&ET+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C4*;7-G:60@(D$@<'5B
M;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE
M<W-A9V4N(@IM<V=S='(@(D%L;&MI<FIA(&MO;G1R;VQL:6UI<V5K<R!O;B!V
M86IA(&%V86QI:VMU(%!'4"!V]71I="XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,#DW"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y
M+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB2W+\<'1E
M97)I='5D(&MI<FIA(&%V86UI<V5K<R!O;B!V86IA(&%V86QI:VMU(%!'4"!V
M]71I="P@<V%L86IA<W0@4$=0(';U=&ET("(*(FIA('-A;&%S]6YA+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,34*;7-G:60@(B(*
M(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G
M<W1R("(B"B)+:7)J82!A;&QK:7)J87-T86UI<V5K<R!O;B!V86IA(&%V86QI
M:VMU(%!'4"!V]71I="P@<V%L86IA<W0@4$=0(';U=&ET(&IA("(*(G-A;&%S
M]6YA+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3`U
M"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R
M>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@HB2W+\<'1E97)I='5D(&MI<FIA
M(&%V86UI<V5K<R!O;B!V86IA(&%V86QI:VMU(%,O34E-12!V]71I="P@<V%L
M86IA<W0@4R]-24U%("(*(G;U=&ET(&IA('-A;&%S]6YA+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS
M9W-T<B`B(@HB2VER:F$@86QL:VER:F%S=&%M:7-E:W,@;VX@=F%J82!A=F%L
M:6MK=2!3+TU)344@=O5T:70L('-A;&%J87-T(%,O34E-12!V]71I="`B"B)J
M82!S86QA<_5N82XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D
M('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")+:7)J82!K<OQP=&5E
M<FEM:7-E:W,@;VX@=F%J82!A=F%L:6MK=2!3+TU)344@=O5T:70B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"FUS9VED(")!
M32!#;&]U9',B"FUS9W-T<B`B14P@<&EL=FEN92(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!2
M86EN(@IM<V=S='(@(D5,(&ME<F=E('9I:&TB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G
M<W1R(")%3"!V:6AM(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B14P@:&]O
M=FEH;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$S"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B14P@='5G978@
M;'5M97-A9'4B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I
M9"`B04TO4$TB"FUS9W-T<B`B14PO4$PB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*
M;7-G<W1R(")!4$D@240B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G
M<W1R(")396QL92!E9&ET;W)I(&EN9F\B"@HC.B!S97)V:6-E<R]H96QP+VEN
M9&5X+G!H<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B26YF;RXN+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*
M;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R(")!8G-B;W1T;VTB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!
M8G-M:61D;&4B"FUS9W-T<B`B06)S;6ED9&QE(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A
M=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")61E,@:V%T86QO;V=I(&QO
M;VUI<V5K<R!J=75R9&5PY.1S(&ME96QA='5D(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A
M=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B5D93(&9A:6QI(&QO;VUI<V5K<R!J
M=75R9&5PY.1S(&ME96QA='5D+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HS"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(DMO;G1O
M(&EN9F\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4*;7-G:60@(D%C
M8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B2V]N=&\@<V%L87/U;F$B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*
M;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R(")+;VYT;R!L=6MU<W1A
M='5D+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S,*;7-G:60@
M(D%C8V]U;G1I;F<B"FUS9W-T<B`B4F%A;6%T=7!I9&%M:6YE(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A
M;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI
M;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`B3&ES82(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!
M9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B3&ES82!A;&%M9W)U<'`B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N
M(@IM<V=S='(@(DQI<V$@86QA;?5I9W5S(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R("),:7-A('-I
M:6$Z(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H
M<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B3&ES82!U=7,@
M9W)U<'`B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@
M4&5R;6ES<VEO;B(*;7-G<W1R("),:7-A('5U<R#U:6=U<R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@
M(DQI<V$@9W)U<'`@7"(E<UPB(&%L;&$B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C
M:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R("),:7-A(/5I9W5S
M(%PB)7-<(B!A;&QA(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D
M9"!A(&YE=R!U<V5R.B(*;7-G<W1R("),:7-A('5U<R!K87-U=&%J83HB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34T"FUS
M9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(DQI<V$@=F5E<F<B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W
M(&UE;6)E<G,B"FUS9W-T<B`B3&ES82!U=65D(&QI:6MM960B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G
M<W1R("),:7-A('!A87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8W
M"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO
M>FEL;&$@4VED96)A<B(*;7-G<W1R(")4964@)7,@;65N_/P@36]Z:6QL82!K
M_&QG<FEB86MS(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R
M("),:7-A(&%A9')E<W-I<F%A;6%T=7-S93HB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D9"!T;R!M>2!A
M9&1R97-S(&)O;VLB"FUS9W-T<B`B3&ES82!M:6YU(&%A9')E<W-I<F%A;6%T
M=7-S92(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*
M;7-G<W1R("),:7-A(&MA<W5T86IA(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S
M>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN
M9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B(@HB7"(E<UPB(&QI<V%T:2!S
M_'-T965M:2P@:W5I9"!TY&EE;F1A=F%T(&QI:71U;6ES:6YF;W0@<&]L;G5D
M(';U:6UA;&EK("(*(FQI<V%D83H@)7,N(@H*(SH@<VEG;G5P+G!H<#HT-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E
M;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R(")<(B5S7"(@;&ES871I
M('/\<W1E96UI+B!._/QD(';U:60@<VES<V4@;&]G:61A+B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E
M<G,@:7,@9&ES86)L960N(@IM<V=S='(@(DMA<W5T86IA=&4@;&ES86UI;F4@
M<&]L92!L=6)A='5D+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q"FUS
M9VED(")!9&1R97-S(@IM<V=S='(@(D%A9')E<W,B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3,Y"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T
M<B`B06%D<F5S<VER86%M870B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M
M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B2&%L9'5S("T@;75U
M9&$@=&5I<W1E(&MA<W5T86IA=&4@]6EG=7-I(@H*(SH@861M:6XO:6YD97@N
M<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@
M(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(DAA;&1U<R(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-#$*;7-G:60@(D%D<R(*;7-G<W1R(")296ML
M86%M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`B
M069G86YI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T
M<B`B06QB86%N:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S
M='(@(D%L>F5E<FEA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B06QI87,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R(")*;V]N9'5S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI
M9VYM96YT.B(*;7-G<W1R(")*;V]N9'5S.B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(DOU:6LB"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*
M;7-G<W1R(")+]6EK('-I<W-E;&]G:71U9"!K87-U=&%J860B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!
M;&P@1W)O=7!S(@IM<V=S='(@(DOU:6L@9W)U<&ED(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M9&%T871R964N<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T
M<B`B2_5I:R#U:6=U<V5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B
M"FUS9W-T<B`B2_5I:R!N96QI(&O\;&=E(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@W,0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S
M(@IM<V=S='(@(DQU8F$@;6ET=70@86%D<F5S<VDB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3,T"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R9&5R
M960@;&ES="!T>7!E/R(*;7-G<W1R("),=6)A(&WDY')A=&$@:N1R:F5S=&%T
M=60@;&]E;F1I('3\_'`B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R
M964O<W%L+G!H<#HU,#0*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@
M(D]N(&IU8F$@;VQE;6%S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M,PIM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B06QT97)N
M871I:79N92!)35-0(&MO;G1O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4P-PIM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B
M06QT97)N871I:79N92!)35-0('-A;&%S]6YA(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0Y.0IM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B
M"FUS9W-T<B`B06QT97)N871I:79N92!)35-0(&MA<W5T86IA;FEM:2(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E<FYA
M=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(")!;'1E<FYA=&EI=FYE(&4M<&]S
M=&D@86%D<F5S<R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED
M(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(D%L=&5R;F%T:6EV<V5D
M(&UA;&QI9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM
M<V=S='(@(D%L=&5R;F%T:6EV;F4@=&5K<W0Z(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I
M9"`B06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B06UE97)I:V$@4V%M;V$B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E
M('=A<R!S<&5C:69I960N(@IM<V=S='(@(E-I<V5S=&%T:2!L=6)A;6%T=2!V
MY.1R='5S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C<*
M;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@
M(DIU:'1U<R!T=6YD;6%T=2!V:6=A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD
M;W)R82(*;7-G<W1R(")!;F1O<G)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG
M;VQA(@IM<V=S='(@(D%N9V]O;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U
M:6QL82(*;7-G<W1R(")!;F=U:6QL82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R
M(")!;F]N_/QM;F4@=F%H96YD86IA(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R(")687-T=7,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(D%N=&%R:W1I
M:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM
M<V=S='(@(D%N=&EG=6$@:F$@0F%R8G5D82(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN
M9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B4F%K96YD
M=7,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI
M8V%T:6]N($QI<W0B"FUS9W-T<B`B4F%K96YD=7-T92!N:6UE:VER:2(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N
M(&ES(')E861Y+B(*;7-G<W1R(")286ME;F1U<R!O;B!T]O9V86QM:7,N(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY
M('1O($-H:6QD(%-H87)E<R(*;7-G<W1R(")286ME;F1A(&%L86UJ86=U9&5L
M92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS
M9VED(")!<'!R;W9E(@IM<V=S='(@(DMI;FYI=&$B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S,*;7-G:60@(D%P<')O>&EM871E
M(%-I>F4B"FUS9W-T<B`B3&EG:6MA=61N92!S=75R=7,B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB
M"FUS9W-T<B`B07!R:6QL(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S4*
M;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R(")!<F%A8FEA
M("A7:6YD;W=S+3$R-38I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M.#$*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(D%R:&EI=FD@
M<W5U<G5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#`*;7-G:60@
M(D%R8VAI=F4@3F%M92(*;7-G<W1R(")!<FAI:79I(&YI;6DB"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L('!H<"UF
M;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@
M=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(D]L960@<V$@
M:VEN9&5L(&5T('-O;W9I9"`E<R!L:6ET=6UI<W-O;W9I(&MU<W1U=&%D83\B
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L
M971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(B(*(D]L
M960@<V$@:VEN9&5L(&5T('-O;W9I9"!K=7-T=71A9&$@9W)U<&D@7"(E<UPB
M(&IA(&OU:6L@=&5M82!A;&%M9W)U<&ED/R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@
M(D%R9V5N=&EN82(*;7-G<W1R(")!<F=E;G1I:6YA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM
M<V=I9"`B07)M96YI82(*;7-G<W1R(")!<FUE96YI82(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3<V"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*
M;7-G<W1R(")!<FUE96YI82`H05)-4T-)22TX*2(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(DMU;G-T(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B07)U8F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L
M86YD(@IM<V=S='(@(DQI:&%V]71T97-A87(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R(")!4T-)22!J
M;V]N:7-T=7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*
M;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B06%S:6$O5F%I
M:W-E(&]O:V5A;FD@<&EI<FMO;F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#(U"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I
M;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B2_QS:2!H;V]L
M9'5S=/;V9&4@=&5G96UI<V5K<R!K:6YN:71U<W0B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3$S"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B
M"FUS9W-T<B`B5F5E<G5D(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I
M9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM
M<V=S='(@(DMA='-E(&MU<W1U=&%D82!O;&5M871U="!G<G5P<&DN(@H*(SH@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B2V%T
M<V4@:W5S='5T861A(&]L96UA='5T(/5I9W5S="XB"@HC.B!A9&UI;B]P97)M
M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X
M:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(DMA='-E(&UU=71A(&]L96UA
M='5T(/5I9W5S="XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*
M;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB
M"FUS9W-T<B`B2V%T<V4@;75U=&$@;VQE;6%T=70@:F%G=2XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX-@IM<V=I9"`B071T<FEB=71E<R(*;7-G
M<W1R(")!=')I8G5U9&ED(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R(")!=6=U<W0B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B075S=')A
M86QI82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B075S
M=')I82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*
M;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER<W%L.B!V86IA;&EK:W4@24U!
M4"!L86EE;F1U<W0@96D@;&5I='5D+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D
M;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R(")!
M=71H7V-Y<G5S.B!S_'-T965M:6P@<'5U9'5V860@=F%J86QI:W5D(';U:6UE
M9"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G
M:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B075T:%]C>7)U<SH@=F%J86QI:VMU($E-05`@;&%I
M96YD=7-T(&5I(&QE:71U9"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V9T
M<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT
M96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B
M;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@HB075T:%]F='`Z(%9A:F%L
M:6MK=2!&5%`@;&%I96YD=7-T(&5I(&QE:71U9"X@2V]M<&EL965R:2!02%`@
M=O5T;65G82`M+65N86)L92TB"B)F='`N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)
M34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA<#H@
M5F%J86QI:VMU($E-05`@;&%I96YD=7-T(&5I(&QE:71U9"XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z
M(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M075T:%]K<F(U.B!686IA;&EK:W4@:W)B-2!L86EE;F1U<W0@96D@;&5I='5D
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED
M(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O
M<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(D%U=&A?;&1A<#H@06-T:79E
M($1I<F5C=&]R>2=S<V4@:V%S=71A:F%T92!L:7-A;6ES92!T=6=I('!U=61U
M8B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED
M(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@
M9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B075T:%]L9&%P.B!!8W1I
M=F4@1&ER96-T;W)Y<W0@:V%S=71A:F%T92!E96UA;&1A;6ES92!T=6=I('!U
M=61U8B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G
M:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")!=71H7VQD87`Z(%9A:F%L:6MK=2!,1$%0(&QA:65N
M9'5S="!E:2!L96ET=60N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B
M;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60Z("(*;7-G<W1R(")!=71H7VQD87`Z($5I('-A82!L:7-A9&$@:V%S=71A
M:F%T("5S+B!397)V97(@_'1L97,Z("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A
M<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A
M<#H@16D@<V%A(&5E;6%L9&%D82!K87-U=&%J870@)7,B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R
M(")!=71H7VQD87`Z($5I('-A82!M=75T82!K87-U=&%J870@)7,B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L
M9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I
M=F4@1&ER96-T;W)Y+B(*;7-G<W1R(")!=71H7VQD87`Z($%C=&EV92!$:7)E
M8W1O<GD@:V%S=71A:F%T92!M=75T;6ES92!T=6=I('!U=61U8BXB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC
M86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]M8V%L.B!686IA;&EK:W4@34-!3"!L86EE;F1U<W0@96D@;&5I
M='5D+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV,`IM<V=I
M9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?<VUB875T:#H@5F%J86QI:VMU('-M
M8F%U=&@@;&%I96YD=7-T(&5I(&QE:71U9"XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R(")3:7-S96QO9VEM:6YE(&YU<FIU
M<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C8W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N
M(&9A:6QE9"X@)7,B"FUS9W-T<B`B4VES<V5L;V=I;6EN92!N=7)J=7,N("5S
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I
M9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB
M"FUS9W-T<B`B4D%$2553('-E<G9E<B!E:2!L=6)A;G5D('-I<W-E(&QO9VED
M82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U,0IM<V=I9"`B
M075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@
M(D944"!S97)V97)I<W-E('-I<W-E;&]G:6UI;F4@;G5R:G5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B4TU"('-E
M<G9E<FES<V4@<VES<V5L;V=I;6EN92!N=7)J=7,N(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB
M"FUS9W-T<B`B2V%S=71A=&%V860@=N1L:F%D.B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G
M:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B07-E<F)A:61Z86%N(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS
M9W-T<B`B0D]&2"!E='1E:^3D;F1E9"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U
M;F0B"FUS9W-T<B`B5&%U<W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM
M<V=S='(@(E1A=7-T82!VY')V(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K
M<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G
M<W1R(")686QE(&ME<F)E<F]S92!S86QA<_5N82XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E
M<FYA;64N(@IM<V=S='(@(E9A;&4@:V5R8F5R;W-E(&MA<W5T86IA;FEM:2XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@(D)A:&%M82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B0F%H<F5I;B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS9VED(")"86QT:6,@*$E3
M3RTX.#4Y+3$S*2(*;7-G<W1R(")"86QT:2`H25-/+3@X-3DM,3,I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R(")"86YG;&%D97-H
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B0F%R8F%D
M;W,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B1W)A869I:V$@</5H:6MA=&%L;V]G:2!<(B5S7"(@
M96D@;&5I='5D+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B0F%S
M96QI;F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S(@IM<V=S='(@(E9A
M;&=E=F5N92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B
M0F5L9VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L:7IE(@IM<V=S='(@(D)E
M;&EZ92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM<V=S='(@(D)E;FEN
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R(")"97)M=61A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(D)H=71A;B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*
M;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(E/\;FYI<.1E=B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<
M(B!N;W0@9F]U;F0N(@IM<V=S='(@(D)L;VMK:2!<(B5S7"(@<F%K96YD=7-E
M<R!<(B5S7"(@96D@;&5I='5D+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B0FQO
M:VD@:.3D;&5S='5S(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC
M.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(D)L;VMI('3\_'`B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G
M:60@(D)O;&0B"FUS9W-T<B`B4&%K<R!K:7)I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I
M9"`B0F]L:79I82(*;7-G<W1R(")";VQI:79I82(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR,#4*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R(")*
MY')J96AO:61J860B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D97(B"FUS9W-T<B`B4&EI
M<FIO;VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R(")*;V]N
M92!P86MS=7,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")0:6ER
M:F]O;F5D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O
M=FEN82(*;7-G<W1R(")";W-N:6$@:F$@2&5R='-E9V]V:6EN82(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R(")-
M]6QE;6%D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B
M0F]T<W=A;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R(")!;&QA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R(")";W5V
M970@<V%A<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R87II;"(*;7-G<W1R(")"
M<F%S:6EL:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@
M3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(D)R:71I($EN9&EA($]O:V5A;FD@
M5&5R<FET;V]R:75M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S
M<V%L86TB"FUS9W-T<B`B0G)U;F5I(%-U;'1A;FER:6EK(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B0G5L9V%A<FEA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B
M0G5L;&5T960@3&ES="(*;7-G<W1R("),;V5T96QU(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM
M<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(D)U<FMI;F$@1F%S;R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B0G5R=6YD:2(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#0*;7-G:60@(D--4R(*;7-G
M<W1R(")3:7-U:&%L9'5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-20R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#4DP@
M1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R(")4_&AI<W1U<VYI;65K:7)J
M82!J86]T=7-P=6YK=&ED(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T
M:65S+BXN(@IM<V=S='(@(DQ?86AT<FD@;VUA9'5S960N+BXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38S"FUS9VED(")#86-H92!I;FET
M('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R(")686AE;>1L=2!I;FET<VEA
M;&ES965R:6UI;F4@96D@:O5U9&YU9"!L]7!U;&4N(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-"!C;VYF:6<O:&]O:W,N
M<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-34*
M;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9&5R(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-@IM<V=I9"`B0V%L;2(*;7-G<W1R
M(")686EK;F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T
M<B`B2V%M8F]D>FAA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS
M9W-T<B`B2V%M97)U;B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L
M;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)0
M87)O;VQI(&5I('-A82!A=71O;6%A='-E;'0@=/QH:7-T861A+"!V]71A(/QH
M96YD=7-T(&%D;6EN:7-T<F%A=&]R:6=A+B(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T
M('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(D5I(/5N;F5S='4@:VER
M:G5T861A(&9A:6QI(%PB)7-<(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR
M,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA
M;F1L97)S+B(*;7-G<W1R(")6Y&QI<V5I9"!S97-S:6]O;FEH86QD=7)E:60@
M<&]L92!V]6EM86QI:R!A9&UI;FES=')E97)I9&$N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER<W%L+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N
M;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B16D@<V%A(/QH96YD
M=7-T($E-05`@<V5R=F5R:6=A.B`E<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C0Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")%:2#U;FYE<W1U(&%V861A(&9A:6QI
M(%PB)7-<(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G<W1R(")+
M86YA9&$B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z
M,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV
M-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R
M("),;V]B=2(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y
M"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B3&]O8G4B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M(")%:2#U;FYE<W1U(&MU<W1U=&%D82!F86EL:2!<(B5S7"(N(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@
M(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M16D@;&5I82!A:G5T:7-T(&MA=&%L;V]G:2(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C
M965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B
M26QM82`G=&%R9V5T1FEL92<@<&%R86UE971R:71A(&5I('-A82!JY'1K871A
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB
M"FUS9W-T<B`B16D@]6YN97-T=2!E96UA;&1A9&$@:V%T86QO;V=I(%PB)7-<
M(BXB"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964N<&AP.C$R."!F
M<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV.#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI
M<W0N(@IM<V=S='(@(D5I('-A82!E96UA;&1A9&$L("5D+6P@;VX@86QL=79A
M:60N(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z
M-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I
M97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R
M("(*(G-T;W)E9"XB"FUS9W-T<B`B(@HB16D@<V%A(/QM8F5R(&KD<FIE<W1A
M9&$L(/QM8F5R:N1R:F5S=&%M:7-E:W,@;>3D<F%T=60@:V%N;F5T92!A<G8@
M96D@:VQA<&D@(@HB<V%L=F5S=&%T=60@87)V=6=A+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B
M0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS
M9W-T<B`B16D@<V%A('-U=6YA=&$@=&5A9&5T(&WDY')A='5D(&YU;6)R:6QE
M+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B4F]H
M96QI<V4@3F5E;64@<V%A<F5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`IM<V=I9"`B0V%P=&EO;B(*;7-G
M<W1R(")096%L:VER:2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE
M<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*;7-G<W1R(")4965N
M=7-E<&%K:W5J82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I
M9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(DMA=&5G;V]R:6%D
M(&IA(&WD<F=E;F1I9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#87EM86X@27-L
M86YD<R(*;7-G<W1R(")#87EM86YI(%-A87)E9"(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO
M;F4B"FUS9W-T<B`B36]B:6EL=&5L969O;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@
M4')O<&5R=&EE<R(*;7-G<W1R("),86AT<FD@;VUA9'5S960B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B
M0V5L;"!P861D:6YG.B(*;7-G<W1R("),86AT<FD@=F]O9&5R9'5S.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R("),86AT<FD@;VUA
M9'5S960B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("),86AT<FET
M92!V86AE:V%U9W5S.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M-S0*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R(")-;V)I:6QT96QE9F]N(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I8R`H25-/
M+3@X-3DM,30I(@IM<V=S='(@(DME;'1I("A)4T\M.#@U.2TQ-"DB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V
M"FUS9VED(")#96YT97(B"FUS9W-T<B`B2V5S:V5L92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*
M;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R(")+97-K
M+4%A9G)I:V$@5F%B87)I:6LB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W
M.0IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T
M<B`B2V5S:RU%=7)O;W!A("A)4T\M.#@U.2TR*2(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-CDY"FUS9VED(")#97)T:69I8V%T92!$
M971A:6QS(@IM<V=S='(@(E-E<G1I9FEK86%D:2#\:W-I:V%S:F%D(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3$*;7-G:60@(D-E
M<G1I9FEC871E($]W;F5R(@IM<V=S='(@(E-E<G1I9FEK86%D:2!O;6%N:6LB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I
M9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B4V5R=&EF:6MA861I
M('!O;&EI=&EK860B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS9W-T
M<B`B5'-H86%D(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B0VAA;F=E
M(@IM<V=S='(@(DUU=61A(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C,Q"FUS9VED(")#:&%N9V4@66]U<B!087-S=V]R9"(*;7-G<W1R(")-
M=75D82!S86QA<_5N82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM
M<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O
M<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E
M;6%I;',N(@IM<V=S='(@(B(*(DUU=61A(&YI;64@:F$@86%D<F5S<VD@;6ED
M82!I;FEM97-E9"!NY&5V860@:W5I(&YA9"!S:6YU(&MI<FIU(&QO979A9"!J
M82`B"B)N96EL92!V87-T879A9"XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z,C0*;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@
M:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I
M;VXN("`B"B)#;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B
M(@HB4_QS=&5E;6D@:V]N9FEG=7)A='-I;V]N(&5I(';U:6UA;&1A('-A;&%S
M]6YA(&UU=71A+B!6]71A(/QH96YD=7-T("`B"B)A9&UI;FES=')A871O<FEG
M82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(DWD<FLB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*
M;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(E]+;VYT<F]L;&D@;&EN
M:VDN+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EL92(*;7-G<W1R(")4<VAI
M:6QI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;F$B"FUS9W-T<B`B2&EI;F$B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0VAI;F5S92!3
M:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(DAI:6YA(&QI:'1S=7-T871U
M9"`H1T(R,S$R*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED
M(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R(")(:6EN82!T
M<F%D:71S:6]O;FEL:6YE("A":6<U*2(*"FUS9VED(")#:&]O<V4@07!P;&EC
M871I;VXZ(@IM<V=S='(@(E9A;&D@<F%K96YD=7,Z(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@<&%S
M<W=O<F0B"FUS9W-T<B`B5F%L:2!S86QA<_5N82(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HR-C@*;7-G:60@(D-H;V]S92!A('5S97)N
M86UE(@IM<V=S='(@(E9A;&D@:V%S=71A:F%N:6UI(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(Y.`IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y
M(&1A=&5S.B(*;7-G<W1R(")686QI(&MU=7#D979A9&4@97-I='5S=FEI<SHB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@
M;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B5F%L:2!L;V5N9&D@<W1I:6P@*&KD
M<FIE<W1A='5D(&QO96YD:71E(&IA;VMS*2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@
M(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B2O5U;'5S86%R960B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z.#DS"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I
M;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R(")+;&%S<VD@)7,@:VER:F5L
M9'5S="!E:2!L96ET=60N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,30*;7-G:60@(D-L96%R(@IM<V=S='(@(E-E;&=E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM
M<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R(")%96UA;&1A($U3
M3V9F:6-E(&WD<F=E;F1I9"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*
M;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@(E3\:&IE;F1A('#D<FEN9R(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF
M;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R(")%96UA
M;&1A(&MA<W5T86IA.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L
M96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R(")%96UA;&1A
M(&MA<W5T86IA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,S0*;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R(")4_&AJ96YD82!K
M87-U=&%J82!A;F1M960B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("+5
M:'1U;"!S96QG:6YE8B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN
M=&5N86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G
M<W1R(")+;/5P<V$@:N1T:V%M:7-E:W,B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E
M;&P@=FEA($A45%`B"FUS9W-T<B`B0VQI8VMA=&5L;"#\;&4@2%144"(*"B,Z
M('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(E-U;&4@
M86ME;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0T"FUS9VED(")#;&]U
M9',B"FUS9W-T<B`B4&EL=F5D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R
M(")(;VUM:6MU;"!P:6QV97,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(E!I;'9E
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S
M(@IM<V=S='(@(DMO;VMO<W-A87)E9"`H2V5E;&EN9VD@<V%A<F5D*2(*"B,Z
M('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA
M<'-E(%-I9&5B87(B"FUS9W-T<B`B4&5I9&$@:_QL9W)I8F$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS
M9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R(")096ED971U9"!P:6ER
M:F]O;F5D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`B
M2V]L=6UB:6$B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C
M:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B5N1R
M=B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS
M,C0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R
M-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`P
M('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O
M;&]R(%!I8VME<B(*;7-G<W1R(")6Y')V:79A;&EK(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@T-@IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*
M;7-G<W1R(")6Y')V:2!V86QI:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R(")6
M965R9V4Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-@IM<V=I
M9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R(")6965R9W5D92!P96%L:VER:F%D
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-`IM<V=I9"`B0V]M
M:6-S(@IM<V=S='(@(DMO;VUI:W-I9"(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H
M<#HR-0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")+Y'-K(@H*(SH@861M:6XO
M8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@
M(DOD<W5R:61A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$S"FUS9VED(")#;VUM96YT(@IM<V=S='(@(DMO;6UE;G1A87(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-@IM<V=I9"`B0V]M
M;6]N($YA;64B"FUS9W-T<B`B3&EH=&YI;6DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I
M9"`B0V]M;W)O<R(*;7-G<W1R(")+;VUO;W)I9"(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB
M"FUS9W-T<B`B1FER;6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*
M;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R(")!<G9U=&ED(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y-PIM<V=I9"`B0V]N9&ET:6]N(@IM
M<V=S='(@(DEL;2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y"FUS9VED
M(")#;VYD:71I;VYS(@IM<V=S='(@(DEL;2(*"B,Z(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM
M<V=S='(@(DMO;F9I9W5R871S:6]O;FD@97)I;F5V=7-E9"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-#,*;7-G:60@(D-O;F9I9W5R871I;VX@9F]R
M('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB
M"FUS9W-T<B`B4V5A9&ES='5S('/\;FMR;VYI<V5E<FEM:7-E:W,@4$1!9&4L
M(&YU=&ET96QE9F]N:61E(&IA($]U=&QO;VMI9V$N(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$S-0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@
M;V8@9&%T92XB"FUS9W-T<B`B4V5A9&ES='5S(&]N(&%E9W5N=60N(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B4V5A9&ES=&$@)7,B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED(")#;VYF:7)M
M(%!A<W-W;W)D(@IM<V=S='(@(DMI;FYI=&$@<V%L87/U;F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R(")+;VYG;R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*
M;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B
M"FUS9W-T<B`B2V]N9V\@1&5M;VMR86%T;&EK(%9A8F%R:6EK(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N
M;F5C=&EO;B!F86EL960N(@IM<V=S='(@(MQH96YD=7,@;G5R:G5S+B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@
M(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`BW&AE;F1U<R!N=7)J=7,Z
M("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I
M9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+B(*;7-G<W1R(")!=F%L:6L@=O5T;65S97)V97(@96D@86YN82#\:&5N9'5S
M="XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B079A
M;&EK(';U=&UE<V5R=F5R(&5I(&%N;F$@_&AE;F1U<W0N(%#U:&IU<SH@)7,@
M*"5S*2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#0U"FUS9VED
M(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("+<
M:&5N9'5S($944"!S97)V97)I9V$@;G5R:G5S+B(*"B,Z(&-O;F9I9R]H;V]K
M<RYP:'`N9&ES=#HQ,#$T"FUS9VED(")#;VYT86-T<R(*;7-G<W1R(")+;VYT
M86MT:60B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D
M('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")+;VYT86MT:60@]6YN
M97-T=7,@;&ES861A('-I;G4@86%D<F5S<VER86%M871U<W-E+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@<VES=2(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B2N1T
M:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B
M0V]O:VD@4V%A<F5D(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"FUS
M9VED(")#;V]K:64B"FUS9W-T<B`B3?5T=&5T97)A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED
M(")#;W!Y(@IM<V=S='(@(DMO<&5E<FDB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE
M9#H@)7,B"FUS9W-T<B`B2V]P965R:6UI;F4@;G5R:G5S.B`E<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@
M(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(DMO<&5E<FD@=F%L:6LB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B0V]S
M="!)1"(*;7-G<W1R(")#;W-T($E$(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S
M=&$@4FEC82(*;7-G<W1R(")+;W-T87)I:6MA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I
M9"`B0V]T92!D)TEV;VER92(*;7-G<W1R(")#;W1E(&0G279O:7)E(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3<V"FUS9VED(")#;W5L
M9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B16D@<V%A;G5D
M(&MI<FIA(%!'4&=A(&MR_'!T:61A+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$P-3,*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M
M97-S86=E+B(*;7-G<W1R(")%:2!S86%N=60@:VER:F$@4$=09V$@86QL:VER
M:F%S=&%D82XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N
M(@IM<V=S='(@(D5I('-A86YU9"!K:7)J82!3+TU)345G82!K<OQP=&ED82XB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I
M9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(D5I
M('-A86YU9"!K:7)J82!3+TU)345G82!A;&QK:7)J87-T861A+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B
M"FUS9W-T<B`B16D@<V%A;G5D(&QI<V%D82!K;VYT86MT:2X@)7,B"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HQ,C$*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O
M($Q$05`@<V5R=F5R+B(*;7-G<W1R(")%:2!S86%N=60@<VES<V4@3$1!4"!S
M97)V97)I<W-E+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*;7-G
M:60@(D-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(D5I
M('-A86YU9"!S:7-S92!,1$%0('-E<G9E<FES<V4B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM
M<V=S='(@(D5I('-A86YU9"!K;VYT;VKDY&MI(&MO;G1R;VQL:61A+B`E<R(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-#$*;7-G:60@(D-O=6QD(&YO
M="!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")%:2!S86%N=60@
M_&AE;F1U<W0@3$1!4"!S97)V97)I9V$N(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN
M96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R(")%
M:2!S86%N=60@<V5R=F5R:6=A(%PB)7-<(B!&5%`@86)I;"#\:&5N9'5S=#H@
M)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")*86]T=7-N:6UE:VER
M:F$@;&]O;6EN92!N=7)J=7,N("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3$R-0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0
M(&1A=&$N(@IM<V=S='(@(D5I('-A86YU9"!01U`@86YD;65I9"!D96MR_'!T
M:61A+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3(R
M"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T
M<B`B16D@<V%A;G5D(%,O34E-12!A;F1M96ED(&1E:W+\<'1I9&$N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T
M+B`E<R(*;7-G<W1R(")%:2!S86%N=60@:W5S='5T861A(&MO;G1A:W1I+B`E
M<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(D5I('-A86YU9"!K=7-T
M=71A9&$@:F%O='5S;FEM96MI<FIA+B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D
M96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")%
M:2!S86%N=60@:W5S='5T861A('!A:6=A;&1U<V4@=75E;F1A;6ES92!S:W)I
M<'1I(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G
M:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I
M;"!A9&1R97-S+B(*;7-G<W1R(")%:2!S=75T;G5D(';D;&IA('-E;&=I=&%D
M82!A9')E<W-A861I(&4M<&]S=&D@86%D<F5S<R(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L
M9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R(")+
M;V=U(&%A9')E<W-I<F%A;6%T=2!K;VAA;&5T:7)I;6EN92!N=7)J=7,N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT
M.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I
M;VX@;&ES="XB"FUS9W-T<B`B2V]G=2!J86]T=7-N:6UE:VER:F$@:V]H86QE
M=&ER:6UI;F4@;G5R:G5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@
M=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G
M<W1R(")+;V=U(&IA;W1U<VYI;65K:7)J861E(&YI;65K:7)J82!K;VAA;&5T
M:7)I;6EN92!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S
M=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(D5I(/5N;F5S='5N=60@;&%A9&ED
M82!S=')A=&5E9VEA="!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q
M,`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U
M='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B;6MD:7(@7"(E
M<UPB(&YU<FIU<RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M
M('1H92!K97ES97)V97(N(@IM<V=S='(@(D5I('-A86YU9"!V]71M97-E<G9E
M<FES="!A=F%L:6MK=2!V]71I="!KY'1T92XB"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB
M)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B7"(E<UPB(&%V86UI;F4@:VER
M:G5T86UI<V5K<R!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("(E<R!A=F%M:6YE(&YU<FIU
M<RXB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN
M=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R(")%:2!S=75T;G5D(&OD
M:79I=&%D82!H;V]L9'5S=/;V(&UO;V1U;&ET("5S(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N
M(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(D5I('-A86YU9"!A=F%D82!K
M871A;&]O9VD@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T
M-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0IM<V=I
M9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B
M16D@<V%A;G5D(&OD='1E($Q$05`@<V5R=F5R:70N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O3V)J96-T+G!H<#HR,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(B5S(&QU9V5M:6YE(&YU<FIU
M<RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B
M(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E
M<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@
M;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@
M(B(*(E-O;W9I='5D(&MA<W5T86IA('!A<F]O;&D@=/QH:F5N9&%M:6YE(&YU
M<FIU<RX@3?5N960@86YD;65D(&5I(&]L92#U:6=E9"X@(@HB4')O;W9I('5U
M97-T:2!V]6D@=O5T82#\:&5N9'5S="!A9&UI;FES=')A871O<FEG82P@:W5I
M('9A:F%D('-I:7-K:2!A8FDN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S`Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,T,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S@S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,X.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G
M<W1R(")!0TQI(&QA861I;6EN92!E8F'U;FYE<W1U<R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN
M("5S(@IM<V=S='(@(D%A9')E<W-I<F%A;6%T=2!L86%D:6UI;F4@96)A]6YN
M97-T=7,N("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")*86]T
M=7-N:6UE:VER:F$@;&%A9&EM:6YE(&5B8?5N;F5S='5S+B`E<R(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB
M=71I;VX@;&ES=',N("5S(@IM<V=S='(@(DIA;W1U<VYI;65K:7)J861E(&QA
M861I;6EN92!E8F'U;FYE<W1U<RX@)7,B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C(R,PIM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R(")397)V97)I(';U:6UA
M;'5S=&4@;&%A9&EM:6YE(&5B8?5N;F5S='5S(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R(")+;VYF:6=U<F%T<VEO;VYI('1A9V%S:6UU=71M
M:6YE(&YU<FIU<RXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B
M<FUD:7(@7"(E<UPB(&5I(/5N;F5S='5N=60N(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B)7,@<V5A9&ES='5S
M92!S86QV97-T86UI;F4@;G5R:G5S+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U
M;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R(")+
M;VYF:6=U<F%T<VEO;VYI('9A<G5K;V]P:6$@<V%L=F5S=&%M:6YE(&YU<FIU
M<RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N
M.B`E<R(*;7-G<W1R(")+;VYF:6=U<F%T<VEO;VYI('9A<G5K;V]P:6$@<V%L
M=F5S=&%M:6YE(&YU<FIU<SH@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S
M971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")086EG
M86QD=7-E('5U96YD86UI<V4@<VMR:7!T:2!E:2!S86%N=60@<V%L=F5S=&%D
M82!K;VAT83H@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(D5I(/5N;F5S
M='5N=60@<V%L=F5S=&%D82!K;VYF:6=U<F%T<VEO;VYI9F%I;&D@=F%R=6MO
M;W!I870@)7,N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG
M=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H
M92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C
M;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("(B
M"B)+;VYF:6=U<F%T<VEO;VYI9F%I;&D@)7,@96D@]6YN97-T=6YU9"!S86QV
M97-T861A+B!382!V]6ED(&MA<W5T861A(/QH="`B"B)V]6EM86QU<W0@:V]O
M9&D@<V%L=F5S=&%M:7-E:W,@=&%G87-I(&9A:6QI("5S(';U:2!K;W!E97)I
M9&$@:V]O9"!KY'-I='-I("(*(F9A:6QI("5S+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H
M('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3$1!4"!O='-I;F<@;G5R:G5S
M+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B=6YL:6YK(%PB
M)7-<(B!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R(")+;VYT86MT:2!U=65N
M9&%M:6YE(&YU<FIU<RX@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R
M(")*86]T=7-N:6UE:VER:F$@=75E;F1A;6EN92!N=7)J=7,N("5S(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S
M(@IM<V=S='(@(EPB)7-<(B!S96%D:7-T=7-E('-A;'9E<W1A;6EN92!N=7)J
M=7,Z("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-@IM<V=I9"`B
M0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@
M=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B16D@;&5I9&YU9"!-;WII
M;&QA(&O\;&=I<F)A+B!686%T82!E="!K_&QG<FEB82!O;&5K<R!A=F%T=60N
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<
M(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E
M<UPB.B`E<R(*;7-G<W1R(")+87-U=&%J86QE(%PB)7-<(B!E:2!S86%N=60@
M86YD82!JY')G;6ES:2#U:6=U<V5I9"!K875S=&%L92!<(B5S7"(Z("5S(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q.0IM<V=I9"`B0V]U;G1E
M9"!T97AT(@IM<V=S='(@(E!I:7)A='5D('!I:VMU<V5G82!T96MS="(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")#
M;W5N=')Y(@IM<V=S='(@(E)I:6LB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C<S"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(DMU<G-U<V5D(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B3&]O(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X
M"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(DQI<V$@;&EN:R(*"B,Z
M('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@
M(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B3&ES82!U=7,B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E
M871E('-U8B!F;VQD97)S(@IM<V=S='(@(DQI<V$@86QA;6MA=7-T860B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E
M871O<B!097)M:7-S:6]N<R(*;7-G<W1R(")!=71O<FD@]6EG=7-E9"(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,S`*;7-G:60@(D-R961I="!C
M87)D(&YU;6)E<B(*;7-G<W1R(")+<F5D:6ET:V%A<F1I(&YU;6)E<B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(DAO<G9A871I82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B2W5U8F$B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,C8*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B
M"FUS9W-T<B`B4')A96=U<V5D(#0@9F%A<VDB"@HC.B!A9&UI;B]S97-S:6]N
M<RYP:'`Z-#@*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`B06MT
M:6EV<V5D('-E<W-I;V]N:60B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L
M:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G
M<W1R(")+96QL86%E9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B
M"FUS9W-T<B`B4')A96=U;F4@55),(&]N(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C,S"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@(D%K=&EI=G-E
M9"!K87-U=&%J860B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED
M(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B4')A96=U;F4@:6QM(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W-0IM<V=I9"`B0W5R<F5N
M="!C;VYD:71I;VXZ("(*;7-G<W1R(")0<F%E9W5N92!I;&TZ(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B
M0W5R<F5N="!S='EL92(*;7-G<W1R(")0<F%E9W5N92!S=&EI;"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G
M<W1R(")(Y.1L97-T82!T]FED(&UI9&$@=&5H86MS92!S:7-E;F5M:7-E;"`E
M<RUI+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(DSU:6MA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I
M9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R("),]6EK82!V86QI:R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R(")+_'!R;W,B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB
M"FUS9W-T<B`B2VER:6QL:71S82`H2T])."U2*2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*
M;7-G<W1R(")+:7)I;&QI='-A("A7:6YD;W=S+3$R-3$I(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H
M2T])."U5*2(*;7-G<W1R(")+:7)I;&QI='-A+U5K<F%I;F$@*$M/23@M52DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R(")4
M<V5H:&D@5F%B87)I:6LB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#4Q('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED
M(")$1"(*;7-G<W1R(")04"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,R.#$*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O
M;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB
M"FUS9W-T<B`B(@HB1%-.("AV86%T82!H='1P.B\O<&5A<BYP:'`N;F5T+VUA
M;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@H*
M(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.0IM
M<V=I9"`B1&%I;'DB"FUS9W-T<B`B26=A('#D978B"@HC.B!A9&UI;B]D871A
M=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B
M1&%T851R964@<VER=FEJ82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,R-SD*;7-G:60@(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R(")!;F1M96)A
M87-I;W1S:6YG(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDY"FUS9VED
M(")$871E(@IM<V=S='(@(DMU=7#D978B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*;7-G
M<W1R(")386%B=6UI<V4@:W5U<.1E=B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,#<*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@(DMU
M=7#D979A('9A;&EK(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Y,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S(R"FUS9VED(")$
M87DB"FUS9W-T<B`B4.1E=B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU
M;6XB"FUS9W-T<B`B2W5?<W1U=&$@=F5E<F<B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS
M9W-T<B`B1&5T<V5M8F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB
M97)S(@IM<V=S='(@(DO\;6YE;F1N=6UB<FED(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@
M26YD96YT(@IM<V=S='(@(E;D:&5N9&$@=&%A;F1R:61A(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*
M;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B5F%I:VEM:7-I(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*;7-G:60@(D1E
M9F%U;'0@0V]L;W(B"FUS9W-T<B`B5F%I:VEM:7-I(';D<G8B"@HC.B!F<F%M
M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.CDQ"FUS9VED(")$969A=6QT
M($ED96YT:71Y(@IM<V=S='(@(E9A:6ME:61E;G1I=&5E="(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HV-PIM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G
M<W1R(")686EK:6UI<VD@<VAE;&PB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(E/U;F%S96QE='5S
M960B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M-#(R(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHW,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D
M96QE=&4N:6YC.C$P('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q
M"FUS9VED(")$96QE=&4B"FUS9W-T<B`B2W5S='5T82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I
M9"`B1&5L971E($-E;&PB"FUS9W-T<B`B2W5S='5T82!L86AT97(B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R-PIM<V=I
M9"`B1&5L971E($=R;W5P(@IM<V=S='(@(DMU<W1U=&$@9W)U<'`B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*;7-G:60@(D1E;&5T92!,
M;V<B"FUS9W-T<B`B2W5S='5T82!L;V=I(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C$P,0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B2W5S='5T
M82#U:6=U<R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S
M='(@(DMU<W1U=&$@:F$@965M86QD82!K:7)J860B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$
M96QE=&4@8V5L;"(*;7-G<W1R(")+=7-T=71A(&QA:'1E<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G
M:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B2W5S='5T82!V965R9R(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I
M;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(DMU<W1U=&$@;VQE;6%S
M;VQE=B!A;'1E<FYA=&EI=FYE(&UA;&PB"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,T,S$T+G!H<#HU-`IM<V=I9"`B1&5L971E(&UE<W-A9V5S
M(@IM<V=S='(@(DMI<FIA9&4@:W5S='5T86UI;F4B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$
M96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")+=7-T=71A
M(/5I9W5S960@7"(E<UPB+6QE(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI
M<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM
M<V=S='(@(DMU<W1U=&$@]6EG=7-E9"!<(B5S7"(M;&4@:F$@:_5I:R!A;&%M
M]6EG=7-E9#\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(DMU
M<W1U=&$@<FED82(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET
M>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G
M<W1R(")+=7-T=71A('9A;&ET=60@:61E;G1I=&5E="(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I
M9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R(")+=7-T=71A
M(&%K=&EI=FYE('9E97)G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U
M<G)E;G0@<F]W(@IM<V=S='(@(DMU<W1U=&$@86MT:6EV;F4@<FED82(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L('!H<"UF;W)M870*;7-G
M:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G
M<W1R(")+=7-T=71A<VEN('!A:6=A;&1U<V4@=75E;F1A;6ES92!S:W)I<'1I
M(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS9VED(")$96QI=F5R>2!T:6UE
M(@IM<V=S='(@(DOD='1E=&]I;65T86UI<V4@865G(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM
M<V=I9"`B1&5N;6%R:R(*;7-G<W1R(")486%N:2(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O
M8FQE;2(*;7-G<W1R(")+:7)J96QD82!P<F]B;&5E;6DB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HY,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS
M9W-T<B`B2VER:F5L9'5S(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ.34*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE
M*3HB"FUS9W-T<B`BW&MS:6MA<VIA9"`H:V%N='5D(&MA($AO<F1E(&QO9VEF
M86EL:2DZ(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3D*;7-G
M:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(MQK<VEK87-J860@;&]G:71I(&%D;6EN:7-T<F%A
M=&]R:2!J86]K<RXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$Y
M"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R(")!<F5N9'5S(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,3<*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R
M(")+87-T97!U;FMT(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.30*;7-G
M:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B165L;6ES
M92!T=6YN:2!K87-T97!U;FMT(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(R-PIM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B2V%S=&5P
M=6YK=#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R
M(")3=75N9"!V87-A:W5L="!P87)E;6%L92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R
M:6=H="!T;R!L969T(@IM<V=S='(@(E-U=6YD('!A<F5M86QT('9A<V%K=6QE
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R
M>2(*;7-G<W1R(")+871A;&]O9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-C8*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B
M17-I=&$@:V5L;&%A:F%D(#(T+71U;FYI<V5N82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY-PIM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@
M(D5K<F%A;FD@<V5A9&5D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.CDV"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S
M='(@(D[D:71A('#U:&IA;&EK:W4@96YN=7-T=7-T(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HX-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*
M;7-G<W1R(").Y&ET82!E;FYU<W1U<W0@*%1!1BDB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#$W"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G
M<W1R(")%:W)A86YI('-E861E9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M341.+G!H<#HQ.3`*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*
M;7-G<W1R(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y
M"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R(")$:FEB;W5T:2(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N;W0@9&5L
M971E(@IM<V=S='(@(L1R82!K=7-T=71A(@H*(SH@<V5R=FEC97,O;6%I;G1E
M;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA
M:6YT96YA;F-E+G!H<"(*;7-G<W1R("+$<F$@_')I=&$@;6%I;G1E;F%N8V4N
M<&AP(&9A:6QI(&]T<V4@:^1I=FET861A(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*
M;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N
M86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B2W5I(&5S
M:6UE;F4@<FED82!S:7-A;&1A8B!VY&QJ861E(&YI;65S:60L(&WD<F=I('-E
M92!R=75T.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@
M(D1O;6EN:6-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B
M;&EC(@IM<V=S='(@(D1O;6EN:6MA86YI(%9A8F%R:6EK(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A
M8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R(")3=6P@<&]L92!K;VYT;W0_(%)E
M9VES=')E97)U+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@T-`IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B4V%L=F5S=&$B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B4V%L=F5S=&$@
M)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N
M;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*
M;7-G<W1R(")386QV97-T82!L;V]D=60@<V5A9&ES='5S(%!(4"!S:W)I<'1I
M;F$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B
M1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B3FEM96MI<FDB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(E)A=FEM
M:60B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G
M:60@(D4M36%I;"(*;7-G<W1R(")%+7!O<W0B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M
M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED
M92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*(D4M<&]S="U335-I;&4@=F%H
M96YD=7-D<F%I=F5R+"!T965N=7-E<&%K:W5J871E;&4@:V5L;&5L('-E;&QI
M;F4@=&5E;G5S(&]N(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM
M<V=S='(@(D524B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T
M<B`B16MU861O<B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(U
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@HC.B!T96UP
M;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET(@IM<V=S='(@
M(DUU=61A(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU,"!T
M96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET($)L;V-K
M(@IM<V=S='(@(DUU=61A(&)L;VMK:2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%9&ET($=R;W5P(@IM
M<V=S='(@(DUU=61A(&=R=7!P:2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*
M;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R(")-=75D82#U:6=U<W0B
M"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(DUU=61A(/5I9W5S:2(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B375U9&$@)7,@]6EG
M=7-I(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I
M="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B375U9&$@<V5A9&5I9#HB"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B
M375U9&$@7"(E<UPB(/5I9W5S:2(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N
M<R!F;W(@)7,B"FUS9W-T<B`B375U9&$@)7,@]6EG=7-I(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B
M2&%R:61U<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(D5G
M:7!T=7,B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%:71H97(@96YA8FQE(&ET('1H96XZ("5S+"!O
M<B!U<V4@=&AE(&)A<VEC($A434P@=F5R<VEO;CH@)7,N(@IM<V=S='(@(DS\
M;&ET82!S964@<VES<V4@:F$@<VEI<SH@)7,L(';U:2!K87-U=&$@;&EH='-A
M="!(5$U,('9E<G-I;V]N:3H@)7,N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%
M;"!386QV861O<B(*;7-G<W1R(")%;"!386QV861O<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I
M9"`B16QE;65N="XN+B(*;7-G<W1R(")%;&5M96YT+BXN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M
M(@IM<V=S='(@(D5M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8Y"FUS
M9VED(")%;6%I;"(*;7-G<W1R(")%+7!O<W0B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4V-2!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-C@*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B12UP;W-T:2!A
M861R97-S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV,PIM<V=I
M9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(D4M<&]S
M=&D@86%D<F5S<VED('!E879A9"!K;&%P<&EM82XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.3@Y"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA
M=&EO;B(*;7-G<W1R(")%+7!O<W0@:VEN;FET=7-E9V$B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA
M:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B12UP;W-T+5--4VEL92!L_/QS
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y
M.`IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(E-M86EL:60B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G
M:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(E/U;G5M(&]N('3\:&DN(@H*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U
M,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R(")4=6QE;75S(&]N('3\
M:&DN(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q,PIM
M<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(D]T<VEN9W5T:6YG
M:6UU<R!O;B!T_&AI(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T,PIM
M<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'
M86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B3'5B82!T96MS=&D@<VES<V4@
M;&ES861A('!I;'1E(&9O=&]G86QE<FEI9&5S="(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,3@*;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT
M97AT(&UE;G4_(@IM<V=S='(@(DQU8F$@<&%R96UK;/5P<W5G82!H_'!I:VUE
M;OS\(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y."!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#$Q"FUS9VED(")%;F0@>65A<B(*;7-G<W1R
M(")!87-T82!L]7!P(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`B
M4W5U<F5N9&$@961I=&]R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R
M,0IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y
M;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*
M(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T
M/R<Z(@IM<V=S='(@(B(*(E-I<V5S=&$@<V%L86IA;F4@:_QS:6UU<R!M:61A
M('-I;G5L="!K_'-I=&%K<V4@<&%R;V]L:2!M=75T;6ES96MS+"!NY&ET96MS
M("(*(B=M:7,@;VX@<VEN=2!L96UM:6ML;V]M82!N:6UI/R<Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B
M4VES97-T82!S:6EA('!I;&1I(%523"(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX.3$*;7-G:60@(D5N=&5R('1H92!L971T
M97)S(&)E;&]W.B(*;7-G<W1R(")3:7-E<W1A(&%L;&$@=.1H960Z(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B16MV
M871O<FEA86PM1VEN96$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM
M<V=S='(@(D5R:71R96$B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HT-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-34*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E<R]P
M;W)T86PO:6YD97@N<&AP.C@R"FUS9VED(")%<G)O<B(*;7-G<W1R(")6:6=A
M(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM
M<V=S='(@(E9I9V$@8FQO:VD@;&]O;6ES96PZ("5S(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(E9I9V$@<_QN
M:W)O;FES965R:6UI<V%N:W)U(&MU<W1U=&%M:7-E;#H@)7,B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B5FEG82!S
M_&YK<F]N:7-E97)I;6ES92!L;V=I(&MU<W1U=&%M:7-E;#H@)7,B"@HC.B!F
M<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@
M(E9I9V$@<VES=2!L86%D:6UI<V5L.B`E<R(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U
M<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B5FEG82!S86QA<_5N82!M
M=75T;6ES96PZ("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE
M<W-A9V4N(@IM<V=S='(@(E9I9V$@92UP;W-T:2!T96%T97,N(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W
M<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B5FEG82!<(B5S7"(@:VER:G5T86UI
M<V5L+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B165S
M=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R(")%=&EO
M;W!I82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H
M;FEC(@IM<V=S='(@(E)A:'9U<VQI:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(D5U<F]O<&$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"FUS9VED(")%=F5R>2`Q
M-2!M:6YU=&5S(@IM<V=S='(@(DEG82`Q-2!M:6YU=&D@=&%G86YT(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.0IM<V=I9"`B179E<GD@,B!M:6YU
M=&5S(@IM<V=S='(@(DEG82`R(&UI;G5T:2!T86=A;G0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#<*
M;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B26=A(#,P('-E:W5N
M9&D@=&%G86YT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S."!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(")%=F5R>2`U(&UI;G5T97,B
M"FUS9W-T<B`B26=A(#4@;6EN=71I('1A9V%N="(*"B,Z(&9R86UE=V]R:R]-
M86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO
M9VEN(@IM<V=S='(@(DEG86P@<VES<V5L;V=I;6ES96PB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S0P"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS
M9W-T<B`B26=A('!O;VQE('1U;FYI('1A9V%N="(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS,S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.`IM<V=I
M9"`B179E<GD@;6EN=71E(@IM<V=S='(@(DMO<F0@;6EN=71I<R(*"B,Z('1E
M;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A
M;'5E<SHB"FUS9W-T<B`B3N1I9&ES=N3D<G1U<V5D.B(*"B,Z(&%D;6EN+W!H
M<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L
M<VAE;&PN<&AP.C$R-PIM<V=I9"`B17AE8W5T92(*;7-G<W1R(")+Y&EV:71A
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#<U"FUS
M9VED(")%>'!A;F0B"FUS9W-T<B`B3&%I96YD82(*"B,Z('1E;7!L871E<R]P
M;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM
M<V=S='(@(D[D:71A(&O\;&=R:6)A(@H*(SH@9G)A;65W;W)K+U-13"]344PO
M2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@
M(D]O=&%S:6X@)RDG(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N
M<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S
M96%R8V@@=&5R;2(*;7-G<W1R(")/;W1A<VEN(&QI:'1S870@<_5N82!V]6D@
M:G5T=6WD<FMI9&5S(&]T<VEN9W5F<F%A<VDB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*
M;7-G<W1R(")!96=U;6ES92!K=75PY&5V(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-S8*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@
M(D5K<W!O;F5N="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(E1E
M:W-T:2!VY')V(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I
M9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R(")396%D:7-T=7-E(/QL
M97-L86%D:6UI;F4@1E10(&MA=61U(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+W-Q;"YP:'`Z,C$V"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F
M97)E;F-E<RXB"FUS9W-T<B`B2.3D;&5S='5S92!L86%D:6UI;F4@;G5R:G5S
M+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@
M8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B16D@<V%A;G5D(/QH
M96YD=7-T($Q$05`@<V5R=F5R:6=A+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<VUB+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"
M('-E<G9E<BXB"FUS9W-T<B`B16D@<V%A;G5D(/QH96YD=7-T(%--0B!S97)V
M97)I9V$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N
M(@IM<V=S='(@(D5I('-A86YU9"!K;W!E97)I9&$@7"(E<UPB+7-T+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-CDQ"B,L('!H<"UF;W)M870*
M;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B16D@
M<V%A;G5D(&MO<&5E<FED82!<(B5S7"(M:2XB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@8W)E871E(&YE
M=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(E5U92!305-,(/QH96YD=7-E
M(&QO;VUI;F4@;G5R:G5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-#DW(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(T"B,L('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T
M<B`B16D@<V%A;G5D('3U<W1A(%PB)7-<(BUI+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-#8Q"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B16D@<V%A;G5D('1I<FED83H@
M)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M.`IM<V=I9"`B1F%I<B(*;7-G<W1R(")(96$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED
M(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B1F%L:VQA
M;F1I('-A87)E9"`H36%L=FEI;FED*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A
M<F]E($ES;&%N9',B"FUS9W-T<B`B1N3D<FD@<V%A<F5D(@H*(SH@9G)A;65W
M;W)K+T-,22]#3$DN<&AP.C(S.`IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S
M='(@(DMO:'5T878@=FEG83HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS9W-T<B`B1F%K<R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#D*;7-G:60@(D9A>&5S
M(@IM<V=S='(@(D9A:W-I9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R(")6965B
M<G5A<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(P"FUS9VED(")&965L
M<R!,:6ME(@IM<V=S='(@(E1U;F1U8B!N86=U(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S
M='(@(E1U;F1U8B!N86=U.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B
MW&MS:6MU9"!V:6AM86AO;V0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G
M<W1R("+<:W-I:W5D(&QU;65S86IU:&]O9"(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Y-#0*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R(")&
M:65L9"!M871R:7@B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,T
M"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R(")&:6=L970@0T%05$-(
M02(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S@*;7-G:60@(D9I
M9VQE="!F;VYT(@IM<V=S='(@(D9I9VQE="!F;VYT(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM
M<V=I9"`B1FEJ:2(*;7-G<W1R(")&:61Z:2(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B1FEL92(*;7-G<W1R(")&86EL(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R(")&86EL:61E(&%R
M=CH@)7,@9F%I;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV
M-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L
M('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S
M='(@(D9A:6QI9&4@87)V.B`E<R!F86EL:2(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT,#<*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R(")&
M86EL:6AA;&1U<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW
M,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U"FUS
M9VED(")&:6QE($YA;64B"FUS9W-T<B`B1F%I;&D@;FEM:2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34*;7-G:60@(D9I;&4@<V5L96-T:6]N
M(@IM<V=S='(@(D9A:6QI('9A;&EK(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30X-@IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B1F%I;&D@
M_&QE<VQA861I;6EN92(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N
M<&AP.C@U.0IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM
M<V=S='(@(D9A:6QI9&4@_&QE<VQA861I;6ES="!E:2!T;V5T871A+B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX.0IM<V=I9"`B1FEL=&5R<R(*
M;7-G<W1R(")&:6QT<FED(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*
M;7-G<W1R(")3;V]M92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G
M:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B17-I;65N92!P;V]L(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I
M9"`B1FER<W0@475A<G1E<B(*;7-G<W1R(")%<VEM96YE('9E97)A;F0B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4V"FUS
M9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B4^1I;&ET82!S=6AE(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,0IM<V=I9"`B
M1FQI<"(*;7-G<W1R(")0965G96QD82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM
M<V=S='(@(DCU;&IU=B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B561U(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@
M9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B2V%T86QO;V=I("5S('!O;&4@;VQE
M;6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R(")496MS=&D@=N1R=B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G
M<W1R(")4;VET(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA
M="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R(")6965B:6QE:&ET<V5J
M871E;&4@;6ES('!I;'1E(&5I('1O971A(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS,S0*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@(D5N;G5S
M='5S("A4048I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<Y
M"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R
M;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*
M(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO
M8VLI(@IM<V=S='(@(B(*(E#D979A9&4@87)V("AO;&=U(/9E;&1U9"!E="!T
M86=A<W1A=&%V(&5N;G5S='5S('-I<V%L9&%B(&YI:2!PY&5V:2!K=6D@]FED
M.R`B"B)S=75R(&%R=B!V]6EB(&)L;VMI(&QA:6%K<R!V96YI=&%D82DB"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P,@IM<V=I9"`B1F]R9V]T
M('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(E5N=7-T87-I9"!S86QA<_5N83\B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8R"FUS9VED(")&;W)M
M<R(*;7-G<W1R(")6;W)M:60B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B2VEL9"(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@
M(DMI;&QU('3\_'`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G
M:60@(D9O<G1U;F5S(@IM<V=S='(@(DMI;&QU9"(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R(")+:6QL
M=60@,B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-3,*;7-G:60@
M(D9O<G5M<R(*;7-G<W1R(")&;V]R=6UI9"(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ,#D*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(D5D87-T
M=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8P"FUS9VED(")&<B(*;7-G<W1R(")292(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@(D9R86UE
M<R(*;7-G<W1R(")286%M:60B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4B
M"FUS9W-T<B`B4')A;G1S=7-M86$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S
M='(@(E!R86YT<W5S;6%A+"!%=7)O;W!A+6]S82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G
M:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B4')A;G1S=7-E($=U86IA86YA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T
M<B`B4')A;G1S=7-E(%!O;/QN965S:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@
M(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R(")0<F%N='-U
M<V4@3/5U;F%A;&%D(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R(")+96QL96QT(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T."!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S8P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HT,#8*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R(")3=75N86=A
M("(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS9VED
M(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(E#U:&IA;&EK(&MI<FIE;&1U
M<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B5.1I<VMU=2(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B5.1I
M<VYI;6DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R(")'86)O
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R
M;VTB"FUS9W-T<B`B1V%L97)I:2P@:W5S="!P:6QT(';U='1A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R(")'86QE<FEI.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R(")'86UB:6$B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E
M;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B1V5N97)E97)I("5S
M(&MO;F9I9W5R871S:6]O;B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C
M;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R(")'
M96YE<F5E<FET=60@:V]O9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B
M"FUS9W-T<B`B1W)U=7-I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB
M"FUS9W-T<B`B4V%K<V%M86$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N82(*
M;7-G<W1R(")'86%N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*
M;7-G<W1R(")':6)R86QT87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4W-0IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R(")%97-N
M:6UI(@H*;7-G:60@(D=L;V)A;"!/<'1I;VYS(@IM<V=S='(@(MQL9&ES960@
M<V5A9&5D(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3(*;7-G:60@
M(D=O(@IM<V=S='(@(DUI;F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#`*;7-G:60@(D=O961E;"(*;7-G<W1R(")']F1E;"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3(X"FUS9VED(")';V]G
M;&4@36%P<R(*;7-G<W1R(")';V]G;&4@:V%A<F1I9"(*"B,Z(&QI8B]";&]C
M:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T
M<B`B1V]O9VQE(&]T<VEN9R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,S<*;7-G:60@(D=R87ES8V%L92(*;7-G<W1R(")(
M86QL=&]O;FED97-S92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS
M9W-T<B`B2W)E96MA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*;7-G
M:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R(")+<F5E:V$@*$E33RTX
M.#4Y+3<I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@
M(D=R]O9N:6UA82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T
M<B`B1W)E;F%D82(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'
M<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")'<G5P<&ED92!H86QD=7,B
M"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU
M<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(D=R=7!P:61E(&YI;65D(&5I(';U
M:2!O;&QA('3\:&IA9"(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HS,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA
M8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9#H@(@IM<V=S='(@(D=R;W5P7VQD87`Z($5I('-A82!L:7-A9&$@9W)U
M<'!I("5S+B!397)V97(@_'1L97,Z("(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X
M"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D
M96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@16D@<V%A(&MU
M<W1U=&%D82!G<G5P<&D@)7,B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS
M-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O
M('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%P.B!%:2!S86$@
M;75U=&$@9W)U<'!I("5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R(")'
M<G5P:60B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@
M(D=U861E;&]U<&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R
M(")'=6%M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R
M(")'=6%T96UA86QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B1W5E<FYS97DB"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C@X"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R
M(")+_&QA;&ES92#U:6=U<V5D(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0W,`IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(DO\;&%L:7-T97)A
M86UA="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G<W1R(")':6YE
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R
M(")':6YE82U":7-S874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*
M;7-G<W1R(")'=6%J86%N82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.CDV,`IM<V=I9"`B2%1-3"(*;7-G<W1R(")(5$U,(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B
M2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@
M8V5L;"!I;B!R;W<N(@IM<V=S='(@(DA434Q!<F5A(&ME96QD=6(@87)G</QK
M<VQI:W5L="!K=7-T=71A;6%S="!R96$@=FEI;6%S="!L86AT<FET+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E
M('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R96$@
M:V5E;&1U8B!A<F=P_&MS;&EK=6QT(&MU<W1U=&%M87-T('1A8F5L:2!V:6EM
M87-T('9E97)G=2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R
M969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S
M='(@(DA434Q!<F5A(&ME96QD=6(@87)G</QK<VQI:W5L="!K=7-T=71A;6%S
M="!T86)E;&D@=FEI;6%S="!R:61A+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B2%144"!A=71E;G1I;6ES="!E:2!L96ET=60N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*;7-G<W1R(")(86EI=&DB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@
M(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(E+D<VEA;&=O<FET;2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(
M87IE(@IM<V=S='(@(DCD9W4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HY,3D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,@IM<V=I9"`B2&5A
M9&5R(@IM<V=S='(@(E#D:7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y
M<&4O=&%B;&5S970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@(E#D
M:7-E9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-
M8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(DAE87)D:2!S86%R(&IA($UC1&]N
M86QD:2!S86%R960B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R(")2Y&YK
M(.1I:V5S971O<FTB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I
M9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(DAE96)R96$@*$E3
M3RTX.#4Y+3@M22DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`B2_5R
M9W5S(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$W.2!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@V"B,Z('-E<G9I8V5S
M+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L871E<R]H96QP+VEN9&5X+FEN8SHS
M"FUS9VED(")(96QP(@IM<V=S='(@(D%B:2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@
M961I=&]R(@IM<V=S='(@(D5D:71O<FD@:V%S=71A;6ES92!A8FDB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q"FUS9VED(")(96QP97(B"FUS
M9W-T<B`B06)I;&EN92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I
M9"`B2&5M:7-P:&5R92(*;7-G<W1R(")P;V]L:V5R82(*"B,Z('1E;7!L871E
M<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I
M;&4Z(@IM<V=S='(@(E-I:6X@;VX@9F%I;&D@86QG=7,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B2&EG:"(*
M;7-G<W1R(")+]7)G92(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z
M-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0IM<V=I9"`B
M2&]?;64B"FUS9W-T<B`B7T%V86QE:'0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED
M(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R(")0_&AA
M(%1O;VP@*%9A=&EK86YI($QI;FYR:6EK*2(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,34S-0IM<V=I9"`B2&]M92(*;7-G<W1R(")!=F%L96AE
M;&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3(R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")+;V1U;F4@86%D<F5S
M<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`IM<V=I9"`B2&]M92!$
M:7)E8W1O<GDB"FUS9W-T<B`B2V]D=6MA=&%L;V]G(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0
M:&]N92(*;7-G<W1R(")+;V1U;F4@=&5L969O;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM
M<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B2&]N9'5U<F%S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B2&]N9VMO;F<B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C4*;7-G:60@(DAO<F1E(@IM<V=S
M='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@
M6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@5FEG87-E9"`E<R!834P@86YD;65D(&MI<FIA<R`E<R(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S
M('1O(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3V)J96MT:6QE
M("5S(&5I('9A<W1A(/QK<VMI(&MI<FDB"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*
M;7-G<W1R(")(;W)D92]+;VQA8CH@16D@;&5I='5D(/QH=&MI("5S('3\_'!I
M(&]B:F5K=&D@:VER:F%S("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HQ,C4P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3
M=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O
M2V]L86(Z(-5N;F5S='5S(&5E;6%L9&%D82`E<R!<(B5S7"(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z
M(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG
M(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B2&]R9&4O2V]L86(Z($EN=&5G<F%T
M<VEO;VYI;6]O=&]R('9A:F%B("=D;VUX;6PG(%!(4"!L86EE;F1U<W0B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4P,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,
M('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@16D@
M<V%A(&QU=6$@=75T(%A-3"!P=75D(&]B:F5K=&D@)7,@:F%O:W,B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB
M.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@16D@<V%A(&5E;6%L9&%D82`E
M<R!<(B5S7"(Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT
M-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM
M<V=S='(@(DAO<F1E+TMO;&%B.B!%:2#U;FYE<W1U(&AA;FMI9&$@34E-12!)
M1"UD("5S('3\_'!I(&]S82!J86]K<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z($5I('-A82!S_&YK<F]N:7-E97)I9&$@)7,@7"(E
M<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3,S-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y
M;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($5I
M('-A82!S_&YK<F]N:7-E97)I9&$@:F%G=7-I9#H@)7,B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z(%1U;F1M871U(&IA9W4@7"(E<UPB(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO
M;G1A;"!2=6QE(@IM<V=S='(@(DAO<FES;VYT86%L:F]O;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO
M<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R(")(;W)I<V]N=&%A;&YE('9O;V1E
M<F1U<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(DAO<FES;VYT86%L
M;F4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L
M96%S92!R97!O<G0A*2(*;7-G<W1R(")+=6ED87,@<V$@<VEI82!S871T=7-I
M9#\@*%!A;'5N('1E871A(2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU
M;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")+=6D@<&%L
M:G4@=F5E<F=E('-O;W9I:W-I9"#\:&5N9&%D83\B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC
M;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(DMU:2!P86QJ=2!VY&QJ=2`H
M=F5E<F=E*2!O;C\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O=6QD
M('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")+=6D@<&%L:G4@<FED=2!S
M;V]V:6MS:60@_&AE;F1A9&$_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,P,"!L:6(O0FQO8VLO;65T87(N<&AP.C(S,`IM<V=I9"`B2'5M
M:61I='DB"FUS9W-T<B`B3FEI<VMU<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-3D*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B3FEI
M<VMU<SHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU
M;6]R:7-T<R(*;7-G<W1R(")(=6UO<FES=&ED(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS
M9VED(")(=6YG87)Y(@IM<V=S='(@(E5N9V%R:2(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C$W,B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G-Q;"YP:'`Z,C,U"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O
M>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DE-05`@<&]S=&MA<W1I
M(&QO;VUI;F4@;G5R:G5S.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z
M,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO
M;B!F86EL960Z("5S(@IM<V=S='(@(DE-05`@<&]S=&MA<W1I(&MU<W1U=&%M
M:6YE(&YU<FIU<SH@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I
M;VX@9F%I;&5D.B`E<R(*;7-G<W1R("))34%0('!O<W1K87-T:2!K=F]O9&D@
M;&]O;6EN92!N=7)J=7,Z("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3,Q-@IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("))4"!A861R97-S
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I
M9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("))4"!A861R
M97-S('!O;&4@=&5A9&$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A
M<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W
M960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B25`@86%D<F5S<R!E:2!K=75L=2!L
M=6)A='5D($-)1%(@8FQO:VMI+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@
M=FEO;&%T:6]N+B(*;7-G<W1R("))4"!P:6ER86YG=2!R:6MK=6UI;F4N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B3&ES
M82!R:61A(%]E;FYE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM
M<V=S='(@(DES;&%N9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S8*
M;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B06EN=6QT(&EK;V]N:60B"@HC
M.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(B5S(&EK;V]N:60B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S<W"FUS9VED("))8V]N<R!W:71H('1E>'0B
M"FUS9W-T<B`B26MO;VYI9"!J82!T96MS="(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ.3`*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B
M261E;G1I=&5E9&D@;FEM:3HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@
M;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N
M97<@=VEN9&]W+B(*;7-G<W1R(")+=6D@<V5D82#U:65T:2!E:2!NY&ED871A
M+"`E<R!J82!S964@879A=&%K<V4@=75E<R!A:VYA<RXB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#4U"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E
M(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N
M965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N
M<W!A<F5N8WDN(@IM<V=S='(@(B(*(DMU:2!S82!K87-U=&%D($EN=&5R;F5T
M($5X<&QO<F5R:70@:F$@96D@;N1E(/QL9'-E(&EK;V]N92P@<VEI<R!P<F]O
M=FD@(@HB;>1R:VED82!S964@<G5U="P@;/QL:71A;6%K<R!S:7-S92!03D<@
M;.1B:7!A:7-T=G5S+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ-S,*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S
M86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A
M9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G
M<W1R("(B"B)+=6D@<V$@;N1E9"!S961A('1E861E="!A9V$@<&EL=&D@96D@
M;N1E+"!S:6ES(&5I(&]S:V$@<VEN=2!V965B:6QE:&ET<V5J82`B"B)NY&ED
M871A('-E9&$@<&EL=&DL(&UI9&$@<V]O=FED(/QL97,@;&%A9&ED82XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C@*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(E!I;&1I
M(&5E;'9A861E.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R(")0
M:6QD:2!54DPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T
M<B`B4&EL9&D@55),.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G
M86QL97)Y(@IM<V=S='(@(E!I;'0@9V%L97)I:7-T(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS
M9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(E!I;'0@9V%L97)I
M:7-T.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$*;7-G:60@
M(DEM86=E('5P;&]A9"(*;7-G<W1R(")0:6QD:2#\;&5S;&%A9&EM:6YE(@H*
M(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G
M<W1R(")0:6QD:60B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW
M('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHU-"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW
M"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R
M("));7!O<G0L('-A;6T@)60B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P
M+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@
M)7,B"FUS9W-T<B`B26UP;W)D:71U9"!VY&QI.B`E<R(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB
M"FUS9W-T<B`B26UP;W)D:71U9"!VY&QJ860Z(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("))
M;E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R("),:7-A(')I9&$@7W#D<F%S="(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-0IM
M<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R(")%
M<VET871I('9A;&4@=&5G979U<V4@:V]O9"XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@IM<V=I9"`B26YC;W)R
M96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B5F%L92!K
M87-U=&%J86YI;6D@:F$O=O5I('!A<F]O;"XB"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE
M(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y
M;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP
M+B(*;7-G<W1R("(B"B)686QE(&MA<W5T86IA;FEM:2!V]6D@86QT97)N971I
M:79N92!A861R97-S+B!0<F]O=FD@=75E<W1I(';U:2!V]71A(/QH96YD=7-T
M("(*(F%D;6EN:7-T<F%A=&]R:6=A+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N
M="(*;7-G<W1R(")3=75R96YD82!T86%N9')I9&$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*
M;7-G:60@(DEN9&EA(@IM<V=S='(@(DEN9&EA(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`BW&MS:6MU
M9"!K87-U=&%J860B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N97-I82(*
M;7-G<W1R("));F1O;F5E<VEA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*;7-G<W1R("));F9O
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U-PIM<V=I9"`B26YF
M;W)M871I;VXB"FUS9W-T<B`B26YF;W)M871S:6]O;B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,S`*;7-G:60@(DEN9F]R;6%T:6]N(&YO
M(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(E1E879E(&5I(&]L92!E;F%M
M(&OD='1E<V%A9&%V+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU;6X@
M069T97(B"FUS9W-T<B`B3&ES82!?=F5E<F<@<.1R87-T(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P
M"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`B3&ES82!P:6QT(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I
M9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(DQI<V$@=&%B96PB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("))
M;G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B3&ES82!H_'!E<FQI;FLB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("),:7-A
M('9E95]R9R!E;FYE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L
M=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("),:7-A('5U<R!V
M965R9R!A:W1I:79S92!V965R=2!JY')E;&4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN
M<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G
M<W1R("),:7-A('5U<R!V965R9R!A:W1I:79S92!V965R=2!E='1E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT
M(&]N92(*;7-G<W1R("),:7-A('5U<R!R:61A(&%K=&EI=G-E(')E82!JY')E
M;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H
M92!C=7)R96YT(&]N92(*;7-G<W1R("),:7-A('5U<R!R:61A(&%K=&EI=G-E
M(')E82!E='1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@
M869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("),:7-A(&SU:6L@<')A
M96=U<V4@87-U:V]H82!JY')E;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A
M('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("),
M:7-A(&SU:6L@<')A96=U<V4@87-U:V]H82!E='1E(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA
M=&4B"FUS9W-T<B`B3&ES82!A;'1E<FYA=&EI=FYE(&UA;&PB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C,Y"FUS9VED("));G-E<G0@86X@96UA:6P@
M861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S
M=V]R9#HB"FUS9W-T<B`B4VES97-T82!M86EL:6%A9')E<W,@:W5H=2!S86%K
M<R!S=6QL92!U=64@<&%R;V]L:2!S86%T83HB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E
M<G0@8V5L;"!A9G1E<B(*;7-G<W1R("),:7-A(&QA:'1E<B!PY')A<W0B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B3&ES82!L
M86AT97(@96YN92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B
M"FUS9W-T<B`B3&ES82!V965R9R!PY')A<W0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED("));G-E
M<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R("),:7-A('9E97)G(&5N;F4B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I
M9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(DQI<V$@:VER:F%D(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0U"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(DQI
M<V$@;/5I:R!PY')A<W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A
M<&@@8F5F;W)E(@IM<V=S='(@(DQI<V$@;/5I:R!E;FYE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I
M9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("),:7-A(')I9&$@<.1R87-T
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B3&ES
M82!R:61A(&5N;F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,P"FUS
M9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I
M='D@<75E<W1I;VXZ(@IM<V=S='(@(DMI<FIU=&$@<V%L86O\<VEM=7-E(/5I
M9V4@=F%S='5S.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T
M<B`B3&ES82]M=75D82!P:6QT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK
M(@IM<V=S='(@(DQI<V$O;75U9&$@;&EN:R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I
M8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T
M+B(*;7-G<W1R(")*86]T=7-N:6UE:VER:F%L92!S86%T;6ES96MS(&5I(&KD
M=&MU(&MR961I:71I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET
M+B(*;7-G<W1R(")+<F5D:6ET:2!E:2!JY'1K=2XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,#<U"FUS9VED("));G1E9V5R(@IM<V=S='(@(E3D
M:7-A<G8B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,S"FUS9VED
M("));G1E9V5R(&QI<W0B"FUS9W-T<B`B5.1I<V%R=G5D92!N:6UE:VER:2(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB
M"FUS9W-T<B`B5FEG86YE(%5$2"`H57-E<B!$871A($AE861E<BDN(@H*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3<P"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(P,0HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,3`*;7-G:60@(DEN
M=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B5FEG87-E9"!:25`@86YD;65D+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@
M87!P;&EC871I;VXN(@IM<V=S='(@(E9I9V%N92!R86ME;F1U<RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*
M;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(E9A;&4@8F%T8V@@
M240B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@W(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q-3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(S,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,CDY"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN
M=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(E-I<V5S=&%T:2!V:6=A
M<V5D(&%N9&UE9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@
M861D<F5S<RXB"FUS9W-T<B`B5FEG86YE('-I:'1A861R97-S+B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`*;7-G:60@(DEN=F%L
M:60@9FEL92!F;W)M870B"FUS9W-T<B`B5F%L92!F86EL:69O<FUA870B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<W"FUS9VED("));G9A
M;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R(")6:6=A;F4@;&ET<V5N='-I=O5T
M:2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<Q"FUS9VED
M("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")3:7-E<W1A
M=&D@=FEG86YE(&%S=6MO:'0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y
M<&4N(@IM<V=S='(@(E9I9V%N92!M<V=?='EP92(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV
M86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B87!I7VED(&]N('!U
M=61U(';U:2!V:6=A;F4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I
M;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B5FEG87-E9"!V]6D@<'5U9'5V860@
M<&%R86UE971R:60N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W
M"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")6
M:6=A;F4@_&QE;?5I9W5S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-S,*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B
M5FEG86YE('!A<G1N97)I($E$(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$W-0IM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S
M='(@(E9I9V%N92!T;V]T96MO;V0N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R
M;W1O8V]L+B(*;7-G<W1R(")6:6=A;F4@<')O=&]K;VQL+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G
M:60@(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B5FEG86YE
M('-A86IA.B!<(B5S7"(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$P-S8@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C8R"FUS9VED("))
M;G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R(")6:6=A;F4@:F%G871U9"!O
M8FIE:W0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM
M<V=S='(@(E9I9V%N92!LY&AT96%A9')E<W,N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A
M;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B5FEG87-E9"!U;FEC;V1E(&%N
M9&UE9"XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4W"FUS9VED
M("));G9E;G1O<GDB"FUS9W-T<B`B3FEM96MI<FDB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<Y"FUS9VED("));G9E<G0@
M<V5L96-T:6]N(@IM<V=S='(@(E#V]G)D=F%L:6LB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*
M;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B27)A
M86YI($ES;&%M:79A8F%R:6EK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q
M(@IM<V=S='(@(DER86%K(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<F5L86YD
M(@IM<V=S='(@(DEI<FEM86$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B36%N:2!S86%R
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*
M;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(MQK<VEK=60@Y&EK
M97-E=&]R;6ED(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T
M<B`B26ES<F%E;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C(U"FUS9VED("))<W-U97(B"FUS9W-T<B`B5N1L:F%A;F1J82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I
M9"`B271A;&EC(@IM<V=S='(@(DMA;&1K:7)I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS
M9VED("))=&%L>2(*;7-G<W1R("))=&%A;&EA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS
M9VED(")*86UA:6-A(@IM<V=S='(@(DIA;6%I:V$B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,SD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*
M;7-G<W1R(")*86%N=6%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*87!A;B(*
M;7-G<W1R(")*86%P86XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM
M<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R(")*86%P86YI
M("A)4T\M,C`R,BU*4"DB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C,Q,`IM<V=I9"`B(@HB2F%V87-C<FEP="!H87,@8F5E;B!D:7-A8FQE9"!O
M;B!Y;W5R(&)R;W=S97(@86YD('1H:7,@<&%G92!M87D@;F]T(&)E("(*(F1I
M<W!L87EI;F<@8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)+=6YA('-I;G4@=F5E
M8FEL96AI='-E:F%S(&]N($IA=F%S8W)I<'0@:V5E;&%T=60L(&5I('!R=75G
M:2!S964@;&5H="#U:65T:2`B"B)P86ES=&$N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R(")*97)S
M97DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R(")*;W)D
M86%N:6$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`W"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R(")*=75L:2(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM
M<V=S='(@(DIU=6YI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R(")2
M]O9P<V5L="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R
M(")+97-K96QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R
M(")2]O9P<V5L="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T
M<B`B5F%S86MU;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G
M<W1R(")087)E;6%L92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A
M;B(*;7-G<W1R(")+87-A:'-T86XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C8T"FUS9VED(")+965P(&]R:6=I;F%L/R(*
M;7-G<W1R(")3Y&EL:71A(&]R:6=I;F%A;#\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(DME;GEA(@IM<V=S='(@(DME96YI82(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE
M8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B2V5R8F5R;W-E('-E<G9E
M<B!E:2!L87-K;G5D('-I<W-E+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B2V5R;F5L:2!V
M]6AI:W5D(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q
M"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B5O5T;64@;&]O;6EN92(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B
M2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(E;U=&UE('/U<FUE:N1L9R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y
M($QE;F=T:"(*;7-G<W1R(")6]71M92!P:6MK=7,B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S
M='(@(E;U=&UE('3\_'`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4Y.`IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(E;U=&UE(&MA
M<W5T=7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW-#`*
M;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BXB"FUS9W-T<B`B5O5T:2!O;B!A=F%L:6MU<R!S97)V97)I<R!J=6)A
M(&]L96UA<RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@
M(DMI9',B"FUS9W-T<B`B3&%P<V5D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+
M:7)I8F%T:2(*;7-G<W1R(")+:7)I8F%T:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I
M9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS
M9W-T<B`B2V]R96$@4F%H=F%D96UO:W)A871L:6L@5F%B87)I:6LB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R(")+
M;W)E82!686)A<FEI:R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS
M9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B2V]R96$@*$550RU+4BDB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R(")+=79E:70B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B2_5R
M9_5Z<W1A;B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I
M9"`B3&%?>6]U="(*;7-G<W1R(")?2W5J=6YD=7,B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG=6%G92(*;7-G<W1R(")+
M965L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R
M871I8R!297!U8FQI8R(*;7-G<W1R("),86]S92!286AV861E;6]K<F%A=&QI
M:R!686)A<FEI:R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-CD*;7-G:60@
M(DQA<W0@2&%L9B(*;7-G<W1R(")6:6EM86YE('!O;VPB"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-S8*;7-G:60@(DQA<W0@4&%S<W=O<F0@0VAA;F=E
M(@IM<V=S='(@(E9I:6UA;F4@<&%R;V]L:2!M=75T=7,B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),
M87-T(%%U87)T97(B"FUS9W-T<B`B5FEI;6%N92!V965R86YD(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ-3$*;7-G:60@(DQA<W0@57!D871E9#HB"FUS
M9W-T<B`B5FEI;6%T:2!M=75D971U9#HB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@
M)7,B"FUS9W-T<B`B165L;6EN92!K_&QA<W1U<SH@)7,B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HW,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S
M="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R(")%96QM:6YE(&O\;&%S='5S
M.B`E<R!A861R97-S:6QT("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z-S$V"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R(")%96QM
M:6YE(&O\;&%S='5S.B!M:71T92!K=6YA9VDB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G
M:60@(DQA='9I82(*;7-G<W1R("),Y'1I(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0T"FUS9VED("),87<B"FUS9W-T<B`B4V5A9'5S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"FUS
M9VED("),87EO=70B"FUS9W-T<B`B2W5J=6YD=7,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E
M;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(E3\:&D@=.1H96YD86(@<&EI
M<FIO;VYE('!U=61U;6ES="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO
M;B(*;7-G<W1R("),:6EB86YO;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R
M(")687-A:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3D*;7-G
M:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(E9A<V%K('#D:7,B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$U"FUS9VED("),969T('9A;'5E<R(*
M;7-G<W1R(")687-A:W5D(';DY')T=7-E9"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I
M9"`B3&5S;W1H;R(*;7-G<W1R("),97-O=&AO(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED("),979E;"(*;7-G<W1R(")487-E
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@(DQI8F5E
M<FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER
M:7EA(@IM<V=S='(@(DQI:6+\82!!<F%A8FEA(%9A8F%R:6EK(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(DQI96-H=&5N
M<W1E:6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R(")4:6)U=&%B('9I
M:&UA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C8*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B4V5E;F5V:6AM(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@
M(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B2&]M;6EK=6P@=&EB=71A8B!V
M:6AM82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(X"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T<B`BU6AT=6P@=&EB
M=71A8B!V:6AM82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R(")+
M97)G92!H;V]V:6AM(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM
M<V=S='(@(DME<F=E('9I:&T@:F$@Y&EK92(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM
M<V=S='(@(DME<F=E(&QU;65S861U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R
M(@IM<V=S='(@(DME<F=E(&QU;65T;W)M(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("),:6UE<FEK(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-`IM<V=I9"`B3&EN:R(*
M;7-G<W1R("),:6YK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB
M"FUS9W-T<B`B3&EN:R!V:6ET86(@87-U:V]H=&$Z(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D
M<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G
M<W1R(")%<VET86UI<V5L('-E;W-T82!E+7!O<W1I(&%A9')E<W,@=75E(&MI
M<FIA(&%K;F%G82(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O
M:'1M;#)T97AT+G!H<#HQ.#,*;7-G:60@(DQI;FMS(@IM<V=S='(@(DQI;F=I
M9"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@
M0V]O:VEE(@IM<V=S='(@(DQI;G5X:2!P<N3D;FEK(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U
M<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("),:7-T("T@:V%S=71A
M:F$@=O5I8B!K875S=&$@;N1H82(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,S,*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(D%N9&UE8F%A<VED
M92!L;V5T96QU(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3`*;7-G
M:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B06)I:6YF;R!T965M861E
M(&YI;65K:7)I(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM<V=I9"`B
M3&ES="!486)L97,B"FUS9W-T<B`B5&%B96QI=&4@;&]E=&5L=2(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),:7-T
M+4%R8VAI=F4B"FUS9W-T<B`B3&ES="U!<F-H:79E(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12](96%D97)S+G!H<#HU.#D*;7-G:60@(DQI<W0M2&5L<"(*
M;7-G<W1R("),:7-T+4AE;'`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE
M861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("),:7-T+4ED
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3(*;7-G
M:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B3&ES="U/=VYE<B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O
M<W0B"FUS9W-T<B`B3&ES="U0;W-T(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S
M='(@(DQI<W0M4W5B<V-R:6)E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T
M<B`B3&ES="U5;G-U8G-C<FEB92(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU
M,`IM<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@
M(E-E<W-I;V]N:61E(&YI;65K:7)J82!E<VET86UI;F4@;G5R:G5S.B`E<R(*
M"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("),:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B2V%S=71A:F%T
M92!N:6UE:VER:F$@97-I=&%M:6YE(&YU<FIU<SH@)7,B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E
M<G,@:7,@9&ES86)L960N(@IM<V=S='(@(DMA<W5T86IA=&4@;FEM96MI<FIA
M('!O;&4@;'5B871U9"!NY&AA+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R(")+:7)J86YD=7,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("),965D=2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.#,*
M;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B3&%E;BXN+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3$*;7-G:60@(DQO8V%L('1I;64Z
M("(*;7-G<W1R(")+;VAA;&EK(&%E9SH@(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@S"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B4F5G
M:6]O;B!J82!A96<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C0*(SH@;&EB
M+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z-C4*
M;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(D%S=6MO:'0B"@HC.B!L;V=I;BYP
M:'`Z,3<R('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.3$@=&5M<&QA
M=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B
M:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED
M("),;V<@:6XB"FUS9W-T<B`B3&]G:2!S:7-S92(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y
M;F,@<V5S<VEO;B(*;7-G<W1R(")%96QM:7-E('/\;FMR;VYI<V5E<FEM:7-E
M(&QO9VDB"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3@U"FUS
M9VED("),;V<@;W5T(@IM<V=S='(@(DQO9VD@=N1L:F$B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-3D*;7-G:60@(DQO9VEN(@IM<V=S='(@(DMA<W5T
M86IA;FEM:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G:60@
M(DQO9VEN(%1A<VMS(@IM<V=S='(@(E3V]F0@<VES<V5L;V=I;6ES96PB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.38*;7-G:60@(DQO9VEN(&9A
M:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N
M=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(E-I<W-E;&]G:6UI;F4@;G5R
M:G5S+"!K=6YA(&MA<W5T86IA;FEM:2!V]6D@<&%R;V]L('!O;&YU9"#U:6=E
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,@IM<V=I9"`B3&]G
M:6X@9F%I;&5D+B(*;7-G<W1R(")3:7-S96QO9VEM:6YE(&YU<FIU<RXB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8U"FUS9VED("),;VYG('1E
M>'0B"FUS9W-T<B`B4&EK:R!T96MS="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R(")!<FUA<W1U<R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED("),
M;W<B"FUS9W-T<B`B36%D86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E
M:R!L971T97)S(@IM<V=S='(@(DMR965K82!VY&EK973D:&5D(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ
M.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("),861I;F$@
M=N1I:V5TY&AE9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E
M<G,B"FUS9W-T<B`B5N1I:V5S960@<F]O;6$@;G5M8G)I9"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("),=6MS96UB=7)G(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,`HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,X('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")+2R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#$*;7-G:60@(DU/5$0B
M"FUS9W-T<B`B34]41"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1N968N<&AP.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I
M;F5D(&YO(&1A=&$N(@IM<V=S='(@(DU3+51.148@;&ES86YD(&5I('-I<V%L
M9&%N=60@86YD;65I9"XB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B
M"FUS9W-T<B`B35-'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G
M<W1R(")-86MA;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4
M:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUA:V5D
M;V]N:6$@*$5N9&EN92!*=6=O<VQA879I82!686)A<FEI:RDB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T<B`B36%D86=A<VMA<B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS
M9W-T<B`B36%A9VEA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Q
M"FUS9VED(")-86EL(@IM<V=S='(@(D4M<&]S="(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HU,C(*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B
M4&]S=&D@861M:6YI<W1R86%T;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN
M7VLN+BXB"FUS9W-T<B`B7U1E92!L:6YK(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED
M(")-86QA=VDB"FUS9W-T<B`B36%L87=I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED
M(")-86QA>7-I82(*;7-G<W1R(")-86QA:7-I82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM
M<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B36%L9&EI=FED(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDR"FUS9VED(")-86QI(@IM<V=S='(@(DUA;&DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*
M;7-G:60@(DUA;'1A(@IM<V=S='(@(DUA;'1A(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDQ"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T
M96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L
M;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G
M<W1R("(B"B)396%D:7-T82!K871E9V]O<FEA:60L(&UI9&$@:V%S=71A=&%K
M<V4@_&MS=7-T92!MY')G96YD86UI<V5K<R!J82!N96YD96QE("(*(FMA=&5G
M;V]R:6%T96QE('9A<W1A=F%I9"!VY')V92XB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U,PIM<V=I9"`B36%P,C0@;6%P
M(@IM<V=S='(@(DUA<#(T(&MA87)T(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-C@*;7-G:60@(DUA<%%U97-T(&UA<"(*
M;7-G<W1R(")-87!1=65S="!K86%R="(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R
M(")687-T879U<V5D('-A;'9E<W1A='5D+B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G<W1R
M(")-Y')T<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")397)V(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G
M:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R(")4Y&AI
M<W1A(&QO971U9"]L=6=E;6%T82!S=&%A='5S(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O
M=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@
M(E3D:&ES=&$@;75U('-T86%T=7,@*&YT+B!TY&AT:7,O=F%S=&%T=60I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@
M(DUA<G-H86QL:2!S86%R960B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I
M;FEQ=64B"FUS9W-T<B`B36%R=&EN:7%U92(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T
M<B`B4V]B:79A9"!VY&QJ860B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA=7)I
M=&%N:6$B"FUS9W-T<B`B36%U<F5T86%N:6$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G
M:60@(DUA=7)I=&EU<R(*;7-G<W1R(")-875R:6ET:75S(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED
M(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(E-U=7)I;2!L=6)A='5D
M(&MR961I:70N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E
M961E9"XB"FUS9W-T<B`B2VER:F$@;W-A9&4@<&EI<F%N9R#\;&5T871U9"XB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-@IM<V=I9"`B36%X('1E;7`@
M;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(E9I:6UA<V4@,C0@='5N;FD@:_5R
M9V5I;2!T96UP97)A='5U<CH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M.3@*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(E9I
M:6UA<V4@-B!T=6YN:2!K]7)G96EM('1E;7!E<F%T=75R.B`B"@HC.B!L:6(O
M87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L
M;V-K<R(*;7-G<W1R(")3=75R:6T@<&]R=&%A;&D@8FQO:VMI9&4@87)V(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S
M.0IM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B4W5U<FEM('!I:VMU
M<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y
M"FUS9VED(")-87DB"FUS9W-T<B`B36%I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I
M9"`B36%Y;W1T92(*;7-G<W1R(")-87EO='1E(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R(")-961I='-I
M:6XB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS
M9VED(")-96UB97)S(@IM<V=S='(@(DQI:6MM960B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S<X"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(DUE
M;OS\(&5S:71U<SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R
M("+<:&5N9&$@;&%H=')I9"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S
M='(@(E1E861E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY
M(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*
M(G9E<FEF:65D+B(*;7-G<W1R("(B"B)+:7)I(&]N(&5D=6MA;'0@:V]N=')O
M;&QI='5D+"!E;G0@86QL:VER:F%S=&%J82!S97)T:69I:V%A=&D@96D@<V%A
M;G5D("(*(FMO;G1R;VQL:61A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S<V%G92!E>'!I
M<F5D+B(*;7-G<W1R(")496%D92!O;B!A96=U;G5D+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-C`*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")496%T92!T_/QP(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R
M(@IM<V=S='(@(DUE=&%R(&EL;2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(DUE=&%R(&)L;VMK(&5I(&]L92!S86%D879A;"XB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$Q,@IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL
M86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`B365T87(@8FQO:VL@96D@;VQE('-A861A=F%L
M+B#<:W-I:V%S:F%D(&QO9VET:2!A9&UI;FES=')A871O<FD@:F%O:W,N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B365T
M87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*;7-G<W1R(")-971A<D1"(/QH96YD
M=7,@<'5U9'5B+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW
M-`IM<V=I9"`B365T:&]D(@IM<V=S='(@(DUE971O9"(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+WAM;')P8RYP:'`Z.#$@9G)A;65W;W)K+U)00R]24$,O<V]A
M<"YP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@
M:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B365E=&]D(%PB)7-<(B!E:2!O;&4@
M9&5F:6YE97)I='5D(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z
M.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#
M86QL960@;65T:&]D.B`E<R(*;7-G<W1R(")-965T;V0@96D@;VQE(&1E9FEN
M965R:71U9"X@2^1I=FET871U9"!M965T;V0Z("5S(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C<T(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*
M;7-G:60@(DUE=')I8R(*;7-G<W1R(")-965T97(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*
M;7-G:60@(DUE>&EC;R(*;7-G<W1R(")-96AH:6MO(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*
M;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T
M<B`B36EK<F]N965S:6$@1O9D97)A='-I;V]N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"FUS9VED(")-:61D
M;&4B"FUS9W-T<B`B2V5S:V5L92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B
M34E-12!T_/QP(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3`*;7-G:60@
M(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")6:6EM87-E(#(T
M('1U;FYI(&UA9&%L86EM('1E;7!E<F%T=75R.B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S`R"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*
M;7-G<W1R(")6:6EM87-E(#8@='5N;FD@;6%D86QA:6T@=&5M<&5R871U=7(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B
M36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G
M<W1R(")087)O;VQI(&UI;FEM86%L;F4@=F%N=7,@<&]L92!V965L('3D:7,B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,T
M"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B4&5E9V5L9&$B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T
M<B`B36ET;65S=6=U<W0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K
M86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B4'5U9'5B(%!%05(@<&%K971T
M($A45%!?4F5Q=65S="XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U
M"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O
M(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A
M<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@HB2V]N9FEG=7)A='-I;V]N('!U=61U
M8BX@2W5I('1A:&%D('-E9&$@<F%K96YD=7-T(&MA<W5T861A+"!P96%D(&5N
M;F4@(@HB9V5N97)E97)I;6$@:V]N9FEG=7)A='-I;V]N:2XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G
M:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B4'5U9'5B('/U;G5M
M:2!)1"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A
M8VMA9V4@36%I;"XB"FUS9W-T<B`B4'5U9'5B('9A:F%L:6L@4$5!4B!P86ME
M='0@36%I;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS
M9W-T<B`B4'5U9'5B('-E<W-I;V]N:2!)1"XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R
M(")%<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-`IM<V=I9"`B
M36]B:6QE($UA:6PB"FUS9W-T<B`B36]B:6EL;F4@92UP;W-T(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DUO
M9&5R871E(@IM<V=S='(@(DWU]61U:V%S(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#@*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B375U
M=&UI<V4@:W5U<.1E=B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G
M<W1R(")-=75D82!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8W,PIM<V=I9"`B36]D=6QU<R(*;7-G<W1R(")*Y.1K(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R
M(")-;VQD;W9A(%9A8F%R:6EK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA
M8V\B"FUS9W-T<B`B36]N86MO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG
M;VQI82(*;7-G<W1R(")-;VYG;V]L:6$B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-3DT"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R(")+
M=74@:F$@86%S=&$B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E
M;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(DMO<F0@:W5U
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R(")-
M;VYT<V5R<F%T(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K
M+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R(")+=75F
M86%S:60B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-S(@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C4S"B,L('!H<"UF;W)M870*;7-G
M:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP
M96-T960@)60N(@IM<V=S='(@(E)E87,@)60@;&5I=&D@<F]H:V5M(';D;&IU
M(&MU:2!E96QD871A=B`E9"XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C
M8V\B"FUS9W-T<B`B36%R;VMO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R
M(")686QD879A;'0@<V5L9V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R
M(")686QD879A;'0@<&EL=F5S(@H*;7-G:60@(DUO<W1L>2!#;&]U9'D@86YD
M(%=I;F1Y(@IM<V=S='(@(E9A;&1A=F%L="!P:6QV97,@:F$@='5U;&EN92(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS
M9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B5F%L9&%V86QT('#D:6ME<V5P
M86ES=&5L:6YE(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z-3`Y"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B3FEH=71A(&%L;&$B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3,*;7-G
M:60@(DUO=F4@3&5F="(*;7-G<W1R(").:6AU=&$@=F%S86MU;&4B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3<*;7-G:60@(DUO
M=F4@4FEG:'0B"FUS9W-T<B`B3FEH=71A('!A<F5M86QE(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`U"FUS9VED(")-;W9E(%5P
M(@IM<V=S='(@(DYI:'5T82#\;&5S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V92!D;W=N(@IM<V=S
M='(@(DYI:'5T82!A;&QA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4R,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E('5P(@IM<V=S='(@(DYI:'5T
M82#\;&5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S
M='(@(DUO<V%M8FEI:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M.#0*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R
M(")-:71M971A<V5M96QI;F4@;&]E;F0B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U-0IM<V=I9"`B375L=&EM87`@54L@
M;6%P(@IM<V=S='(@(DUU;'1I;6%P(%5+(&MA87)T(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(T,@IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N
M(@IM<V=S='(@(E9A;&EK(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0P,`IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R(")-:6YU(&MO;G1O(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED(")->2!!8V-O=6YT
M($EN9F]R;6%T:6]N(@IM<V=S='(@(DUI;G4@:V]N=&\@:6YF;R(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-30*;7-G:60@(DUY(%!O<G1A;"(*
M;7-G<W1R(")-:6YU('!O<G1A86PB"@HC.B!S97)V:6-E<R]P;W)T86PO961I
M="YP:'`Z,3,V"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(DUI
M;G4@<&]R=&%A;&D@:W5J=6YD=7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY
M86YM87(B"FUS9W-T<B`B37EA;FUA<B(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@
M06=R964B"FUS9W-T<B`B14DL(&UA($5)($],12!N]75S(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`B3FEM
M:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R(").86UI
M:6)I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B3F%U
M<G4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(DYE<&%A
M;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B
M2&]L;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I
M;&QE<R(*;7-G<W1R(")(;VQL86YD:2!!;G1I;&QI9"(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!"
M87-E(%523"(*;7-G<W1R(").971S8V%P92!"87-E(%523"(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P
M92!#02!2979O8V%T:6]N(%523"(*;7-G<W1R(").971S8V%P92!#02!T_&AI
M<W1U<V4@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.#4*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B
M3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!296YE=V%L(%52
M3"(*;7-G<W1R(").971S8V%P92!U=65N9'5S92!54DPB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@
M4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B3F5T<V-A<&4@=/QH:7-T=7-E(%52
M3"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS
M9VED(").971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B3F5T<V-A
M<&4@4U-,('-E<G9E<FD@;FEM:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C
M;VUM96YT(@IM<V=S='(@(DYE='-C87!E('-E<G1I9FEK86%D:2!K;VUM96YT
M86%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#`*
M;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B3F5T
M<V-A<&4@<V5R=&EF:6MA861I('3\_'`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C4Q"FUS9VED(").971W;W)K(@IM<V=S='(@(E;U<FLB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,S-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V
M"FUS9VED(").979E<B(*;7-G<W1R(")-:71T92!K=6YA9VDB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B575S+4MA;&5D
M;V]N:6$B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(E5U<R!K
M871E9V]O<FEA(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E
M;6%I;',N<&AP.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O
M96UA:6QS+G!H<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+V5M86EL<RYP:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E
M<B]E;6%I;',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S
M<V%G92!T;R`E<R(*;7-G<W1R(")5=7,@:VER:2`E<RUL92(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L
M;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B3F]O
M<FMU=2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*
M;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(E5U<R!K
M87-U=&%J86YI;6D@*'!O;&4@:V]H=7-T=7-L:6LI(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R(")5=7,M365R96UA82(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PIM<V=I9"`B3F5W('!A
M<W-W;W)D(@IM<V=S='(@(E5U<R!S86QA<_5N82(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W
M('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R(")5=7,@<V%L
M87/U;F$@865G=6(@)7@N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C4R"FUS9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G
M<W1R(")386QA<_5N860@<&5A=F%D(&ML87!P:6UA+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W
M:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B575E<R!A:VYA<R`H7V)L86YK*2(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y"FUS9VED
M(").97=S(@IM<V=S='(@(E5U9&ES960B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S`U"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(D=R=7!I
M9"(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z,3(Y('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED
M(").97AT(@IM<V=S='(@(DKD<F=M:6YE(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C(W"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(DKD<F=M:7-E
M9"`T(&9A87-I(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS
M-S(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S8*;7-G:60@(DYE
M>'0@;W!T:6]N<R(*;7-G<W1R(")*Y')G;6ES960@<V5A9&5D(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#,*;7-G:60@(DYE>'0^(@IM<V=S
M='(@(DKD<F=M:6YE/B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A
M(@IM<V=S='(@(DYI:V%R86%G=6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI
M9V5R(@IM<V=S='(@(DYI9V5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E
M<FEA(@IM<V=S='(@(DYI9V5E<FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,X,`IM<V=I9"`B3FEG:'0B"FUS9W-T<B`BUO8B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3<*;7-G:60@(DYI=64B"FUS9W-T<B`B3FEU92(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(DYO
M(@IM<V=S='(@(D5I(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N
M:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A
M('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R(")0=75D=79A9"!K
M;VYF:6=U<F%T<VEO;VYI86YD;65D(&UI;&QE(&5R:6YE=G5S:2!NY&ED871A
M+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z
M,3`U"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)
M4T\@:6UA9V5S+B(*;7-G<W1R(")0=75D=6(@<W1R871E96=I82!)4T]D92!L
M;V]M:7-E:W,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS
M9W-T<B`B4'5U9'5B(&UA;&PN(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z-SD@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z,C0U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(V
M-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S
M:71I;VXB"FUS9W-T<B`B4V5L;&5S(&%S=6MO:&%S(&5I(&]L92!B;&]K:VDB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P"FUS9VED(").
M;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R(")-0T%,(&%U=&5N=&EM:7-E:W,@=F%J86QI:R!K86QE
M;F1R:2!N:6UI(&]N('!U=61U+B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP
M.C4T"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@(D5R:6YE=G5S:2!E:2!O
M;&4N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G
M:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I
M;VXN(@IM<V=S='(@(E-E;&QE;&4@]6EG=7-E;&4@96D@<V%A(&%L86UA:60@
M;&ES861A+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38W(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`R"B,Z(&9R86UE=V]R:R]5=&EL
M+U5T:6PN<&AP.C<W,PHC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@
M(B5S(&CDY&QE<W1U<VEN9F\@<'5U9'5B+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z.#(T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B1E10(%9&
M4R!HY.1L97-T=7-I;F9O('!U=61U8BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C8V.0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(E-13"!61E,@
M:.3D;&5S='5S:6YF;R!P=75D=6(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C<Q-PIM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B
M4U%,+49I;&4@5D93(&CDY&QE<W1U<VEN9F\@<'5U9'5B+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I
M9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(DMR961I:70@;VX@86UM96YD
M871U9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM
M<V=S='(@(E-I:'1K;VAT(&WDY')A;6%T82XB"@HC.B!F<F%M97=O<FLO0G)O
M=W-E<B]"<F]W<V5R+G!H<#HX-S<*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B
M"FUS9W-T<B`B1F%I;&D@96D@;&%E='5D(@H*(SH@=71I;"]I8V]N7V)R;W=S
M97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B26MO
M;VYE(&5I(&QE:71U9"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3(X(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$R,PIM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G
M<W1R(")!<W5K;VAT(&WDY')A;6%T82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,38Y"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB
M"FUS9W-T<B`B07-U:V]H="!MY.1R86UA=&$B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S
M<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B4_5N=6T@<'5U9'5B+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS
M9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B3FEM:2!P=75D=6(N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S<*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(DYU
M;6)E<B!P=75D=6(N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS
M9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B06EN=6QT('9I
M:7-A:V%D(&MI;&QU9"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP
M:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")(5%10(&%U=&5N=&EM:7-E('-A;&%S
M]6YA('!U=61U8BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP
M.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(DE-05`@875T96YT:6UI<V4@<V%L87/U
M;F$@<'5U9'5B+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z
M-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B2V5R8F5R;W,@875T96YT:6UI<V4@
M<V%L87/U;F$@<'5U9'5B+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S
M;"YP:'`Z-S<@9G)A;65W;W)K+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<U"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(DQO9VEN(&%U=&5N=&EM:7-E('-A;&%S]6YA('!U=61U8BXB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(")005-35T0@875T96YT:6UI<V4@<V%L87/U;F$@<'5U9'5B+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B4TU"(&%U=&5N=&EM:7-E('-A;&%S]6YA('!U=61U8BXB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#8*;7-G:60@(B(*
M(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@
M3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!0
M2T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*(D]P96Y34TP@<')O9W)A;6UI(&%S
M=6MO:'0@96D@;VQE(&WDY')A='5D+B!/<&5N4U-,('!R;V=R86UM(&]N('9A
M:F%L:6L@(@HB4$M#4R,Q,B!A;F1M971E9V$@=/;V=&%M:7-E:W,N(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@
M<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R(")/;W1E;"!L:6ET=6UI<W-O;W9E
M(&5I(&]L92XB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S4P"B,L('!H
M<"UF;W)M870*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B4&EI<F%N
M9W5T(&5I(&]L92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*;7-G<W1R(")0
M=75D=79A9"(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T.0IM
M<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B17)A;&1A
M:F$@<&]L92!MY.1R871U9"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0T"FUS9VED(").;R!S:61E<R(*;7-G
M<W1R(")-:71T92#\:W-K:2!K_&QG(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HU.#,*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R(")396QL
M:7-T(&9A:6QI(&5I(&]L92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ,S@*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA
M8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B4'5H=F5R9&%M:7-E:W,@<'5U9'5B
M(&%J=71I;F4@:V%T86QO;V<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@(DYO('5S97)N86UE(&%N9"]O
M<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R(")+87-U=&%J86YI;64@:F$O=O5I
M('-A;&%S]6YA(&5I('-A861E='5D+B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#
M+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI9"!834P@9&%T82!R971U
M<FYE9"(*;7-G<W1R(")%:2!T86=A<W1A='5D(&MO<G)E:W1S96ED(%A-3"!A
M;F1M96ED(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDW,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.3@Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HY.3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P,#D*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R(")6Y.1R='5S960@<'5U
M9'5V860B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").
M;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB06QG;F4@:V]N
M9FEG=7)A='-I;V]N(&5I('-I<V%L9&$@=F5R<VEO;VYI+B!,;V\@:V]N9FEG
M=7)A='-I;V]N('5U97-T:2XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A
M=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")3:6YU
M(&MO;F9I9W5R871S:6]O;B!E:2!S:7-A;&1A('9E<G-I;V]N:2X@3&]O(&MO
M;F9I9W5R871S:6]O;B!U=65S=&DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT
M:71Y<V5L96-T+FEN8SHY,PIM<V=I9"`B3F]N92(*;7-G<W1R(")-Y.1R86UA
M=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(DWDY')A
M;6%T82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(").;W)D
M:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R(")0]6AJ86UA860@*$E33RTX.#4Y
M+3$P*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS
M9W-T<B`B3F]R9F]L:VD@<V%A<B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS
M,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES
M<&AE<F4B"FUS9W-T<B`B4/5H:F%P;V]L:V5R82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM
M<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(E#U:&IA
M+4UA<FEA86YI('-A87)E9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y
M(@IM<V=S='(@(DYO<G)A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R(")-:71T92!H
M:6QJ96T@:W5I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV,SD*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B36ET=&4@=F%R96T@
M:W5I(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#`X"FUS9VED
M(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B16D@;VQE(&MA=&%L;V]G(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HV,PHC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U
M=%-T<F%T96=Y+G!H<#HX,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-`HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN
M<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE;G1E
M9"XB"FUS9W-T<B`B4&]L92!T96]S=&%T=60N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*
M;7-G<W1R(")-Y.1R86UA=&$B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T,PHC.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$U.`HC.B!F<F%M97=O<FLO
M4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W,PHC.B!F<F%M
M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X-PHC
M.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP
M.C(S-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S,`HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,C0X(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR-C4*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X,2!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,CDW"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,3(@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C,R.0HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,S8R(&9R86UE=V]R:R]61E,O5D93+G!H<#HT,C(*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C4P,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<P
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU.#<@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C8V-0IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B16D@
M;VQE('1O971A='5D+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$W.`IM<V=I9"`B3F]T97,B"FUS
M9W-T<B`B3>1R:VUE9"(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H
M<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S
M='(@(E!O;&4@;6ED86=I('-I<G9I9&$L(&UI;F4@=&%G87-I+B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").
M;W9E;6)E<B(*;7-G<W1R(").;W9E;6)E<B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$P-#8*;7-G:60@(DYU;6)E<B(*;7-G<W1R(")!<G8B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U"FUS9VED(").=6UB97(@
M;V8@8VAA<F%C=&5R<R(*;7-G<W1R(")-Y')K:61E(&%R=B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30R,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0U('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").
M=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R(")6965R9W5D92!A<G8B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,R!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I
M9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B4FED861E(&%R=B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS
M9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I
M<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")*86]T=7-N:6UE:VER:F%S(&UU
M=71M:7-E;&4@:W5U;'5V860@;G5M8G)I9"!P;VQE(&WDY')A='5D+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I
M9"`B3TLB"FUS9W-T<B`B3TLB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B3V)J
M96MT(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@
M(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(D]B:F5K=&D@;&]O:F$B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G
M<W1R(")+86AE:W-A;F1N=6UB97(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R(")/
M:W1O;V)E<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B
M3V9F96YS92!F:6QT97(B"FUS9W-T<B`B5FEI<V%K=7-E(&%S=&4B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(V"FUS9VED(")/9F9I8V4B"FUS
M9W-T<B`B2V]N=&]R:73V]B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@
M9&EF9F5R96YT+B(*;7-G<W1R(")686YA(&IA('5U<R!S86QA<_5N82!P96%V
M860@;VQE;6$@97)I;F5V860N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C,V"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B4')A96=U
M;F4@<V%L87/U;F$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M-#8*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T
M<B`B4')A96=U;F4@<V%L87/U;F$@96D@;VQE(/5I9V4N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDX"FUS9VED(")/;6%N(@IM<V=S='(@(D]M86%N(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!
M4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(MQH
M:7-K875S='4@=O5I;6%L9&%V860@86EN=6QT($E-05`@<V5R=F5R:60N(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N
M<VEV92!F;W)T=6YE<R(*;7-G<W1R(")!:6YU;'0@96)A=FEI<V%K860@:VEL
M;'5D(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U,2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q"FUS9VED(")/;FQY(&]N92!E;6%I;"!A
M9&1R97-S(&%L;&]W960N(@IM<V=S='(@(DQU8F%T=60@;VX@86EN=6QT(/QK
M<R!E+7!O<W1I(&%A9')E<W,N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N
M<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M
M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P
M97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"B)*86\@;VUA;FEK
M:W4@=O5I(&]M86YI:W4@]6EG=7-I('-A86(@;75U=&$@86EN=6QT(&]M86YI
M:R!V]6D@<_QS=&5E;6D@(@HB861M:6YI<W1R86%T;W(N(@H*(SH@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z,S4*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W
M(@IM<V=S='(@(D%V82!U=65S(&%K;F%S(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O
M=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N
M(@IM<V=S='(@(D]P96Y34TP@=FEG83H@06YD;65T92!E<F%L9&%M:6YE(&%L
M;&MI<FIA<W1A='5D(%,O34E-12!O<V%S="!N=7)J=7,N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS
M9VED(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@
M(D%V86(@<V5L;&4@;&EN9VD@=75E<R!A:VYA<R(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R
M(")/<&5R871S:6]O;FES_'-T965M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")396%D960B
M"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P
M<"YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B
M"FUS9W-T<B`B4V5A9&ES='5S.B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*
M;7-G<W1R(").=6UM97)D871U9"!L;V5T96QU(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D]R9V%N:7-A=&EO;B(*
M;7-G<W1R(")/<F=A;FES871S:6]O;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET
M(@IM<V=S='(@(D%L;/QK<W5S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$S,@IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R("));F9O(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI
M8V%T:6]N('1E;7!L871E(@IM<V=S='(@(E)A:V5N9'5S92!A;&=N92!M86QL
M(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R(")!;&=S
M960@;6%L;&ED(&MA=&%L;V]G:7,@)7,Z(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G
M:60@(D]T:&5R(@IM<V=S='(@(DUU=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,Q(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-#$*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(DUU
M=2!I;F9O(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I
M9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B3VUA;FEK=2#U:6=U<V5D
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y"FUS9VED(")0
M04T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M4$%-(&%U=&5N=&EM:6YE(&5I(&]L92!S86%D879A;"XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%
M05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R(")014%2.CI-86EL('1U9VDB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<S"FUS9VED(")0
M1U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B4$=0(&1I9VET86%L86QL
M:VER:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,3D*
M;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R(")01U`@:W+\<'1I
M='5D(&%N9&UE9"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$S-S$*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(E!'4"!A=F%L
M:6L@=O5T:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S
M-3,*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B
M4$=0(&%L;&MI<FIA<W1A='5D+VMR_'!T:71U9"!A;F1M960B"@HC.B!A9&UI
M;B]P:'!S:&5L;"YP:'`Z-C@*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(E!(
M4"!K;V]D(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@
M4VAE;&PB"FUS9W-T<B`B4$A0(&OD<W5R:61A(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A
M:6XB"FUS9W-T<B`B4$P@:V5R9V4@=FEH;2(*"FUS9VED(")032!286EN(@IM
M<V=S='(@(E!,('9I:&TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R(")03"!H
M;V]V:6AM860B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS.0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R(")03"!L=6UI(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@
M(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")03"!T:6AE(&QU;65S861U(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*;7-G
M:60@(E!-(%-U;B(*;7-G<W1R(")03"!PY&EK92(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")032!4+5-T;W)M
M<R(*;7-G<W1R(")03"#D:6ME<V5T;W)M(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C(W-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B
M"FUS9W-T<B`B4$]325@@;&%I96YD=7,@<'5U9'5B(@H*(SH@;&EB+V%P:2YP
M:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(E!?2%`@:^1S=7)I
M9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@(E3D:61E(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R(")086MI<W1A;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(E!A;&%U(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/
M8V-U<&EE9"(*;7-G<W1R(")086QE<W1I:6YA(&]K=7!E97)I='5D('1E<G)I
M=&]O<FEU;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@
M(E!A;F%M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE
M82(*;7-G<W1R(")086%P=6$@575S+4=I;F5A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM
M<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B4&%R86=U86DB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R=&QY
M($-L;W5D>2(*;7-G<W1R(")686AE;&1U=B!P:6QV:7-U<R(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3@*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C,*;7-G:60@(E!A
M<W-W;W)D(@IM<V=S='(@(E-A;&%S]6YA(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E
M<W-F=6QL>2XB"FUS9W-T<B`B4V%L87/U;F$@;75U9&5T=60N(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(R"FUS9VED(")087-S
M=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B5F%L92!S86QA<_5N82(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W
M;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(E)!1$E54R!A=71E;G1I;6ES96MS(&]N('9A:F%L:6L@<V%L87/U;F$N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,PIM<V=I9"`B4&%S
M<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B4V%L87/U;F$@:VEN
M;FET=7-E9V$B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*
M;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R(")386QA<_5N83HB"@HC.B!T96UP
M;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*
M;7-G<W1R(")386QA<_5N83H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S0*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T
M8V@N(@IM<V=S='(@(E-A;&%S]6YA9"!P96%V860@:VQA<'!I;6$N(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$Q.2!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S
M='(@(D%S971A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T
M<B`B07-E=&$@;/5I:V5P=6AV<FES="(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B
M07-U:V]H="(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC
M.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW"FUS
M9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(D]O=&5L(&QI:71U;6ES
M<V]O=FED.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B
M4&5O<&QE(@IM<V=S='(@(DEN:6UE<V5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS
M9W-T<B`B4')O='-E;G1I(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA
M:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<R(*;7-G<W1R(")+Y&EV:71A(&AO;VQD=7-T]O9D(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P-@IM<V=I9"`B4&5R9F]R;2!M86EN
M=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")4964@<VES
M<V5L;V=I;6ES96P@:&]O;&1U<W3V:60B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R("+5
M:6=U<R(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM
M<V=S='(@(M5I9W5S="!<(B5S7"(@96D@:W5S='5T871U9"XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X-@IM<V=I9"`B4&5R;6ES<VEO;B!$
M96YI960B"FUS9W-T<B`B2G5U<F1E<.3D<R!K965L871U9"(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R("+5
M:6=U<V5D(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E
M<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z
M,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R;6ES<VEO
M;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`BU6EG=7-T92!H86QD=7,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*;7-G:60@(E!E<G-O;F%L($EN
M9F]R;6%T:6]N(@IM<V=S='(@(DES:6ML:6L@:6YF;R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M.`IM<V=I9"`B4&5R=2(*;7-G<W1R(")097)U=2(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R("),96UM:6ML;V]M
M860B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@
M(D9I;&EP:6EN:60B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R(")496QE9F]N(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W.`IM<V=I9"`B4&AO=&]S
M(@IM<V=S='(@(D9O=&]D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I
M<FXB"FUS9W-T<B`B4&ET8V%I<FXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@
M(E!I:W-L:70B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@
M(E!L871I='5D97,B"FUS9W-T<B`B3?5T=&5T=7-E9"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@
M(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R(")+;/5P<V$@
M;?5N9&$@;&%H=')I<W-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER
M;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S
M='(@(DMI;FYI=&$@970@<V]O=FED('-E;&QE(&5L96UE;F1I(&5E;6%L9&%D
M83HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A
M;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B2VEN;FET82!E
M="!S;V]V:60@<V5L;&4@96QE;65N9&D@;&%H=&D@_&AE;F1A9&$N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4W,0IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B4VES97-T82!K=74@
M:F$@86%S=&$N(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H
M92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(E-I<V5S=&$@<V5L;&4@=75E(&MA
M=&5G;V]R:6$@;FEM:3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S`Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*
M;7-G<W1R(")3:7-E<W1A(&MO<G)E:W1N92!)4"!A861R97-S+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C`*;7-G:60@(E!L96%S92!E;G1E
M<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T
M:&4@;6]N=&@N(@IM<V=S='(@(E-I<V5S=&$@:V]R<F5K=&YE(&MU=7#D978L
M(&MO;G1R;VQL:2!PY&5V861E(&%R=G4@:W5U<RXB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-#4Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI
M9"!T:6UE+B(*;7-G<W1R(")3:7-E<W1A(&MO<G)E:W1N92!A96<N(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E
M('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R(")+
M:7)J96QD82!P<F]B;&5E;6DN(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0
M;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G
M<W1R(")3:7-E<W1A(&]M82!K87-U=&%J86YI;6D@:F$@<V%L87/U;F$B"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S
M92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET
M:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*
M(DQO92!JY')G;F5V('1E:W-T(&SD8FDN(%/\<W1E96UI(&MA<W5T86UI<V5K
M<R!014%$('1I;F=I;75S=&5G82!N]75S='5M82XB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B4&QE
M87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R(")+:7)J
M=71A('5U92!K871E9V]O<FEA(&YI;6DZ(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED
M(")0;VQA;F0B"FUS9W-T<B`B4&]O;&$B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@(E!O;&EI=&EK82(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#<*;7-G:60@(E!O;&QS
M(@IM<V=S='(@(DO\<VET;'5S960B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0
M;W)T=6=A;"(*;7-G<W1R(")0;W)T=6=A;"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B
M4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R(")396QL92!P:6QD
M:2!P86EG=71U<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE
M(@IM<V=S='(@(E-E;&QE('1A8F5L:2!P86EG=71U<R(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O
M('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B
M2VER:G5T82!S96QL97-S92!K875S=&$@*$E-05`@96D@:V]N=')O;&QI*2(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8V(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R
M(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(E9I:6UA<V4@)7,@='5N;FD@
M<V%D96UE9#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y
M.`IM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R(")3
M861E;65T93QB<B`O/G3U96[D;W-U<R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@
M3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L9&%P
M.B!686IA;&EK:W4@3$1!4"!L86EE;F1U<W0@96D@;&5I='5D+B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E
M9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")0<F5F<U]S97-S:6]N.B!686IA;&EK:W4@<V5S<VEO
M;B!L86EE;F1U<W0@96D@;&5I='5D+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C(U"FUS9VED(")0<F5S<W5R92(*;7-G<W1R("+5:'5R]6AK(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G:60@(E!R97-S=7)E(&%T('-E
M82!L979E;#H@(@IM<V=S='(@(M5H=7+U:&L@;65R97!I;FYA;#HB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")0<F5S<W5R
M93H@(@IM<V=S='(@(M5H=7+U:&LZ(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(P-0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I
M97<B"FUS9W-T<B`B165L=F%A9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I
M97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")0:6QD:2!E
M96QV86%D92!U=65S(&%K;F%S(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HS-C(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8*
M;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B165L;6ES960@<V5A
M9&5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B5'+\:VD@9&]K
M=6UE;G0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*
M;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(E-A;&%J86YE(';U=&DB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y"FUS9VED(")0
M<F]B;&5M(@IM<V=S='(@(E!R;V)L965M(@H*(SH@<V5R=FEC97,O<')O8FQE
M;2YP:'`Z,3(V"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@
M(E!R;V)L965M:2!K:7)J96QD=7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S8Y"FUS9VED(")0<F]J96-T<R(*;7-G<W1R(")0<F]J96MT:60B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q.#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S(X-0IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B4V5L9VET878@=&5K
M<W0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G
M:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B079A;&EK(';U=&DB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC
M($ME>2!!;&=O<FET:&TB"FUS9W-T<B`B079A;&EK=2!V]71M92!A;&=O<FET
M;2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0T"FUS
M9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B079A;&EK=2!V]71M92!I
M;F9O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS
M9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C
M8V5S<V9U;&QY+B(*;7-G<W1R(")6]71M97!A87)I(&=E;F5R965R:6UI;F4@
M96D@]6YN97-T=6YU9"XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@
M4FEC;R(*;7-G<W1R(")0=65R=&]R:6EK;R(*"FUS9VED(")0=7)G92!M97-S
M86=E<R(*;7-G<W1R(")+=7-T=71A='5D(&MI<FIA9&4@965M86QD86UI;F4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`R"FUS9VED(")1871A<B(*;7-G<W1R(")+871A<B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV,PIM<V=I9"`B475E<GDB"FUS9W-T
M<B`B4.1R:6YG(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"FUS9VED
M(")1=6]T82(*;7-G<W1R(")0:6ER86YG(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!
M(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B4E-!(&%V86QI:R!V]71I
M("@E9"!B:71T:2DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8T
M"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B5F%L:6LB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B
M4F%I;B(*;7-G<W1R(")6:6AM(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B
M2&]M;6EK=6P@=FEH;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0U"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`BU6AT=6P@
M=FEH;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0V"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R(")(;V]V:6AM(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@
M(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B5FEH;2!J82!L=6UI(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A
M:6X@=&\@4VYO=R(*;7-G<W1R(")6:6AM(&IA(&QU;6DB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T
M<B`B2G5H=7-L:6L@:VEL9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B4')O='-E;G0B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S
M-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A
M9"(*;7-G<W1R("),;V4B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HX-PIM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R("),
M;V4@:VER:G4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC
M.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B2V%S('3U
M97-T:2!K=7-T=71A9&$@)7,_(%-E92!T;VEM:6YG(&]N('#V]G)D=6UA='4N
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S
M97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S
M='(@(DMA<R!T]65S=&D@:W5S='5T861A(&MA<W5T86IA("5S(&%N9&UE9#\@
M4V5E('1O:6UI;F<@;VX@</;V<F1U;6%T=2XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U
M<B!L87-T(&%C=&EO;B(*;7-G<W1R(")486%S=&%B('9I:6UA<V4@=&5G979U
M<V4B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R(")6Y')S:V5N
M9&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")2969R
M97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B5N1R<VME;F1A
M(&3\;F%A;6EL:7-E9"!M96[\_"!E;&5M96YD:60Z(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,T,0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB
M"FUS9W-T<B`B5N1R<VME;F1A('!O<G1A86QI('9A861E.B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C$S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S4*;7-G:60@
M(E)E9V5X(@IM<V=S='(@(E)E9W5L86%R879A;&1I<R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,R-#D*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W
M<V5R(@IM<V=S='(@(E-U:&5T92!S:7)V:6IA(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(P.`IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(DQA92!U=65S=&DB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,R-@IM<V=I9"`B4F5M87)K<R(*;7-G<W1R
M(")-Y')K=7-E9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,30*;7-G
M:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(E;D;&ES960@<V5R=F5R:60B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E
M;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G
M<W1R(")6Y&QI;F4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E
M*3HB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*;7-G:60@(E)E;6]V
M92(*;7-G<W1R(")%96UA;&1A(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC.C$Q"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B165M86QD
M82!B;&]K:R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HU-3<*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B2W5S='5T
M82!V965R9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(D5E
M;6%L9&$@:W5J=6YD=7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B165M86QD82!P86%R
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E
M('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O
M<GDN(@IM<V=S='(@(DMU<W1U=&$@<V%L=F5S=&%T=60@<VMR:7!T('-E<G9E
M<FD@86IU=&ES97-T(&MA=&%L;V]G:7-T+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B4F5M
M;W9E('1H92(*;7-G<W1R(")%96UA;&1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO
M=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(D5E;6%L
M9&$@9&]K=6UE;F1I<W0B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO
M=F4N:6YC.C$Q"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R(")+=7-T=71A
M(&MA<W5T86IA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN
M8SHU"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G
M<W1R(")+=7-T=71A(&MA<W5T86IA.B`E<R(*"B,Z(&9R86UE=V]R:R]24$,O
M4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E
M(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R(")0Y')I
M;F=U;&4@<&]L;G5D(';U:6UA;&EK('9A<W1A=&$N(%1A9V%S=&%T:2!V96%K
M;V]D.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"FUS
M9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM
M<V=S='(@(E-O;W9I=&%V870@=&5E;G5S="!E:2!L96ET=60N(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S0@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HU,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E
M<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B5F%J86QI:R!<(B5S7"(@<'5U9'5B("5S('-E861I<W1U<V5S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C<U(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z.#,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HW,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB
M(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(E9A:F%L:6L@7"(E<UPB('!U=61U8B!61E,@<V5A9&ES='5S97,N(@H*(SH@
M9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S@Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(E9A:F%L:6L@7"(E<UPB('!U=61U8B!S96%D:7-T
M=7-E<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS
M,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(DMO:'5S='5S;&EK
M(';D;&DB"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP
M:'`Z,S(P('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B
M"FUS9W-T<B`B5/QH:F5N9&$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HT-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B375U9&$@
M<V%L87/U;F$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM
M<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R(")5;G5S=&%S:6X@
M;VUA('-A;&%S]6YA(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,`IM<V=I
M9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(E1A87-T82!E96QM:6YE
M('#D<FEN9R(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI;B]C;61S
M:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP.C8V"FUS9VED(")297-U
M;'1S(@IM<V=S='(@(E1U;&5M=7-E9"(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I
M9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B5&%G87-I('-E861I<W1U
M<W-E(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED
M(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(DMO<F1A('5U="!S86QA
M<_5N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B
M4F5U;FEO;B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I
M;VXB"FUS9W-T<B`B5O5T82!K;VYF:6=U<F%T<VEO;VX@=&%G87-I(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,@IM<V=I9"`B4FEC:"!497AT($5D
M:71O<B!/<'1I;VYS(@IM<V=S='(@(E)I8V@@5&5X="!%9&ET;W)I('-E861I
M<W1U<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED
M9&QE<R(*;7-G<W1R(")-]6ES=&%T=7-E9"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B
M"FUS9W-T<B`B4&%R96TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3(Q"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B4&%R96T@<.1I<R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3<*;7-G:60@(E)I9VAT
M('9A;'5E<R(*;7-G<W1R(")087)E;6%D(';DY')T=7-E9"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM
M<V=I9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(E]296$@<V5A9&5D
M+BXN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R(")2;VQL(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R(")2=6UE96YI82(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C4*;7-G:60@(E)O
M=&%T92`Q.#`B"FUS9W-T<B`B4/;V<F$@,3@P(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,@IM<V=I9"`B4F]T871E($QE
M9G0B"FUS9W-T<B`B4/;V<F$@=F%S86MU;&4B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(X"FUS9VED(")2;W1A=&4@4FEG
M:'0B"FUS9W-T<B`B4/;V<F$@<&%R96UA;&4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@
M4')O<&5R=&EE<R(*;7-G<W1R(")296$@<V5A9&5D(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B
M4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B4F5A('-E861E9"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2
M;W=S.B(*;7-G<W1R(")2:61U.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM<V=S
M='(@(DIO;VYE9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B2F]O;F5D('1E
M:VEV860@:_5I9VD@<FED861E(&IA('9E97)G=61E('9A:&5L92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*
M;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY
M(@IM<V=S='(@(DIO;VYE9"!T96MI=F%D(&%I;G5L="!V965R9W5D92!V86AE
M;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O
M=W,@;VYL>2(*;7-G<W1R(")*;V]N960@=&5K:79A9"!A:6YU;'0@<FED861E
M('9A:&5L92(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*;7-G:60@(E)U
M;B(*;7-G<W1R(")+Y&EV:71A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S
M<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(E9E;F4@1O9D97)A='-I;V]N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@(E)U86YD82(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED
M(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B4R]-
M24U%(&MR_'!T;V=R86%F:6QI;F4@86QL:VER:2(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@16YC<GEP
M=&5D($UE<W-A9V4B"FUS9W-T<B`B4R]-24U%(&MR_'!T:71U9"!K:7)I(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%3
M3"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")3
M05-,(&%U=&5N=&EM:6YE(&5I(&]L92!S86%D879A;"XB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-3`T"FUS9VED(")335,@365S<V%G:6YG(@IM
M<V=S='(@(E--4R!L_&AI<_5N=6UI9"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(E-13"!KY'-U<FED82(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#,*;7-G:60@(E-13"!S
M=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B4U%,(&%V86QD
M:7,@=N3D<G1U<W1E(&QE:61M:7-E:W,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#,Q"FUS9VED(")34T@B"FUS9W-T<B`B4U-((@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B
M:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R("+53DY%4U154R(*
M"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R
M(")37U%,(&OD<W5R:61A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B3&$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`T"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T<B`B4V%I;G0@
M2&5L96YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@
M3F5V:7,B"FUS9W-T<B`B4V%I;G0@2VET=',@:F$@3F5V:7,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(E-A:6YT($QU8VEA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U
M96QO;B(*;7-G<W1R(")386EN="!0:65R<F4@:F$@36EQ=65L;VXB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D
M:6YE<R(*;7-G<W1R(")386EN="!6:6YC96YT(&IA($=R96YA9&EI;FED(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM
M<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(E-A;6%S(')A86UI
M<R`H7W-E;&8I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T
M<B`B4V%M;V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO(@IM
M<V=S='(@(E-A;B!-87)I;F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")386\@
M5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B4V%O(%1O;64@:F$@4')I;F-I
M<&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED
M(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B4V%T96QL:6ET<VED92!K
M87-U=&%J82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I82(*
M;7-G<W1R(")3875D:2!!<F%A8FEA(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L
M87EO=70N:6YC.CDX"FUS9VED(")3879E(@IM<V=S='(@(E-A;'9E<W1A("(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B4V%L=F5S=&$@
M7"(E<UPB(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R(")386QV97-T82`E
M<R(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@
M3W!T:6]N<R(*;7-G<W1R(")386QV97-T82!S96%D:7-T=7,B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3879E(&=E;F5R871E
M9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E
M<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*(E-A;'9E
M<W1A(&=E;F5R965R:71U9"!K;VYF:6=U<F%T<VEO;VX@4$A0('-K<FEP=&EN
M82!S97)V97)I(&%J=71I<W-E("(*(FMA=&%L;V]G:2XB"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E
M9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(E<R!K;VYF:6=U<F%T<VEO
M;VX@<V%L=F5S=&%T=60N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B4&%I9V%L9'5S92!U=65N9&%M
M:7-E('-K<FEP="!S86QV97-T871U9"!F86EL:3H@7"(E<UPB+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")3
M8V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B2&%J=7-A9"#D:6ME<VAO;V0B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B
M"FUS9W-T<B`B5&5A9'5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G
M:60@(E-E87)C:"(*;7-G<W1R(")/='-I;F<B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S(P"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R
M(")/='-I;F=U;6]O=&]R:60B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.3<S"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B5F%L:2!F86EL
M:60B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#@T"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(E9A;&D@:W5U<.1E
M=B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")3
M96QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B5F%L:2!L:7-A=&%V(&=R
M=7!P(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B
M4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(E9A;&D@=75S(&]M86YI:R(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L
M96-T(&$@<V5R=F5R(@IM<V=S='(@(E9A;&D@<V5R=F5R(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@
M=&\@861D(@IM<V=S='(@(E9A;&D@;&ES871A=B!K87-U=&%J82(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S<*;7-G:60@
M(E-E;&5C="!A;&PB"FUS9W-T<B`B5F%L:2!K]6EK(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C8V,PIM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O
M;7!O;F5N=',N(@IM<V=S='(@(E9A;&D@:_5I:R!K=75PY&5V82!K;V]S=&ES
M;W-A9"XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.#<S"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(E9A;&D@
M;V)J96MT(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C8W.`IM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`BQ')A('9A;&D@
M;6ED86=I(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B
M"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X
M97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M
M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B5F%L:2!V86IA;&EK=60@
M;>1R9VED(&MA<W1I9&5S="X@4VEI<R!S86%D(&YE960@:V]P965R:61A(&MI
M<FIA('-I<W-E+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS
M9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R(")686QI
M(&MU=7#D979A(&5R86QD86IA.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R
M(")686QI(&MU=7#D979A(&5S:71U<W9I:7,Z(@H*(SH@=&5M<&QA=&5S+W!R
M969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I
M9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(E9A;&D@:61E
M;G1I=&5E="!M:61A('-O;W9I9"!M=75T83HB"@HC.B!T96UP;&%T97,O9&%T
M82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E
M<CHB"FUS9W-T<B`B5F%L:2!K96QL86%J82!E<F%L9&%J83HB"@HC.B!T96UP
M;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE
M(&9O<FUA=#HB"FUS9W-T<B`B5F%L:2!K96QL86%J82!E<VET=7-V:6ES.B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C
M="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R(")686QI(&MA:W,@<V]B
M:79A="!VY&QJ82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`V"FUS
M9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(E9A;&D@
M=N1R=FES:V5E;2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0X"FUS
M9VED(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@
M(E9A;&D@;VUA(&QE;6UI:VME96PZ(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS
M9W-T<B`B4V%A9&$@<')O8FQE96UI(&MI<FIE;&1U<R(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#,Y"FUS9VED(")396YD
M(%--4R(*;7-G<W1R(")386%D82!335,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED
M(")396YE9V%L(@IM<V=S='(@(E-E;F5G86PB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,Q-@IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B4V5N<V]R.B`B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM
M<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(E-E<'1E;6)E<B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@
M86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B4V5R8FEA(&IA($UO;G1E;F5G<F\B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I
M9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R(")*Y')J96YU;6)E<B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*;7-G:60@(E-E<G9E<B!D
M871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E-E<G9E<FD@
M86YD;65D(&]N('9A;&5D(';U:2!P=75D=79A9"XB"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z,C<*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B4V5S
M<VEO;VYI9&4@:&%L9'5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X<&ER
M960N(@IM<V=S='(@(E-E<W-I;V]N:2!)1"!O;B!A96=U;G5D+B(*"B,Z(&QI
M8B]A<&DN<&AP.C$T-0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B4U]E<W-I
M;V]N:60B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$T"FUS9VED
M(")3970B"FUS9W-T<B`B2'5L:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW-@IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T
M('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R
M("(B"B)-Y.1R82!A;F1M960@;6ES(';U:6UA;&1A=F%D('-U;"!O;6$@<&%R
M;V]L:2#D<F$@;75U=&$@:W5I('-A('-E;&QE('5N=7-T860N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S
M97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T
M86PN(@IM<V=S='(@(E-E861I<W1A(';D;&ES960@<V5R=F5R:60@;6ED82!S
M;V]V:60@;VUA('!O<G1A86QI<R!K87-U=&%D82XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#0*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG
M=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B4&%N
M92!P86EK82!O;6$@:V5E;&4L(&%J87;V]FYD:2!J82!K=75PY&5V82!S96%D
M:7-T=7,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX"FUS9VED("(B
M"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L
M('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N
M<RXB"FUS9W-T<B`B(@HB3>3D<F$@;VUA(&%L9W)A:V5N9'5S+"!VY')V:7-K
M965M+"!L96AE:_QL:F4@=N1R<VME;F1A;6ES92!S86=E9'5S(&IA(&UU=60@
M("(*(F5S:71U<V4@<V5A9&5D+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-S4*;7-G:60@(E-E='5P(@IM<V=S='(@(E!A:6=A;&1U<R(*"B,Z('1E
M;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U
M<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(D]L96UA<V]L
M979A9"!P86EG86QD=7-E('5U96YD86UI<V4@<VMR:7!T:60B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@V"FUS9VED(")3979E<F%L(&QO
M8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R
M(")087)A;65E=&5R(&WDY')A8B!M:71U(';U:6UA;&EK:W4@87-U:V]H=&$Z
M("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B
M4V5I<VAE;&QI9"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.38*
M;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(D]S=&QE;6EN92(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R="!3=6UM
M87)Y(@IM<V=S='(@(DS\:&EK;VMK=7;U=&4B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#0V"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F
M:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B2V%S(&5N86UU<V5L92!L
M:6YK:61E;&4@='5L96MS(&WDY')A=&$@:VEI<FML86AV:60_(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B
M"FUS9W-T<B`B3N1I=&$B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34U
M"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY
M('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(D[D:71A(&]L96UA<V]L979A(&IA(.1S:F$@9V5N97)E
M97)I='5D(&MO;F9I9W5R871S:6]O;FD@97)I;F5V=7-I+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT.3`*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T
M:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B3N1I=&$@<VES<V5L;V=I
M;6ES96P@965L;6ES92!S:7-S96QO9VEM:7-E(&%E9V$B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K
M965P(&]R:6=I;F%L(@IM<V=S='(@(E!A:W4@=O5I;6%L=7-T(&]R:6=I;F%A
M;&D@<^1I;&ET86UI<V5K<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,3,*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(D[D:71A('9A;&EJ
M870B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(V"FUS9VED(")3:&]W
M('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(D[D:71A('1A
M8F5L:71O:6UI;F=U=&4@;65N_/QR:6)A(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-
M96YU(&]N('1H92!L969T/R(*;7-G<W1R(").Y&ET82!V87-A:W5L("5S(&UE
M;OS\9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P
M97)T:65S(&1I86QO9R(*;7-G<W1R(").Y&ET82!T86)E;&D@;&%H=')I(&]M
M861U<W1E(&1I86QO;V=I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L
M92!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(").Y&ET82!T86)E;&D@;VUA
M9'5S=&4@9&EA;&]O9VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE
M(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(").Y&ET82!T86)E;&D@
M<F5A(&]M861U<W1E(&1I86QO;V=I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H
M92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(").Y&ET82!P:6QD
M:2!O;6%D=7-T92!D:6%L;V]G:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$W-C,*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(D[D:71A('5P
M;&]A9&DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,`IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R(")(;V]V:6AM(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-H
M;W=E<G,@16%R;'DB"FUS9W-T<B`B2&]M;6EK=6P@:&]O=FEH;6%D(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@
M(E-H;W=E<G,@3&%T92(*;7-G<W1R("+5:'1U;"!H;V]V:6AM860B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B
M4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B2&]O=FEH;6%D(/QM
M8G)U<VMO;FYA<R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C0X,`IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(DMI='-E;F1A(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-S<T(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C@S-@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HY,C(@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C$P-#<@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M,3`X-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,3$V
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q-#D*;7-G:60@
M(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@
M=&AE('=A>2!F:7)S="(*;7-G<W1R(")+:71S96YD82!K]6EG97!E86QT(&YA
M86)E<F)L;VMK92!V]6D@;FEH=71A(&YE960@965S="#D<F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B4VEE<G)A($QE
M;VYE(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-0IM
M<V=I9"`B4VEG;B!U<"(*;7-G<W1R("),:6ET=2(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4B"FUS
M9W-T<B`B06QL:VER:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-S$Q"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@
M(D%L;&MI<FIA(&%L9V]R:71M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN
M9V%P;W)E(@IM<V=S='(@(E-I;F=A<'5R(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(S-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0V(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S`*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$R,PIM<V=I9"`B4VEZ92(*;7-G<W1R(")3=75R=7,B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM
M<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R(")*Y'1A(&AO;VQD=7,@
M=F%H96QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T
M<B`B4VQO=F%K:VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N:6$B
M"FUS9W-T<B`B4VQO=F5E;FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-N;W<B"FUS9W-T<B`B3'5M:2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS
M9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R(")4:6AE(&QU;65S861U(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@
M(E-N;W<@4VAO=V5R<R(*;7-G<W1R(")4:6AE9&%D(&QU;65S86IU9"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED
M(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B2&]M;6EK=6P@=&EH961A
M9"!L=6UE<V%J=60B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B
MU6AT=6P@=&EH961A9"!L=6UE<V%J=60B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(W.`IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(DQU;64@<&%K
M<W5S.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM<V=I9"`B4VYO
M=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B3'5M92!V964M96MV
M:79A;&5N=#H@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA
M;F1S(@IM<V=S='(@(E-A86QO;6]N:2!S86%R960B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V
M"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(E-O;6%A;&EA(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S
M='(@(DQA=6QU9"!J82!L=75L971U<V5D(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,CDR-@IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS
M9W-T<B`B4V]R=&5E<FEM:7-JY')J96MO<G)A('9A;&EK(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$V
M-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$X.0IM
M<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B3.1H=&5A861R97-S(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(DSU
M=6YA+4%A9G)I:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I
M9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(DSU=6YA
M+45U<F]O<&$@*$E33RTX.#4Y+3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3
M;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*
M;7-G<W1R("),]75N82U'96]R9VEA(&IA($SU=6YA+5-A;F1W:6-H:2!386%R
M960B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN
M<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(DSU
M=6YA<&]O;&ME<F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C
M96QL<R(*;7-G<W1R(")686AE(&QA:'1R:71E('9A:&5L(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P
M86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T
M<B`B5F%H92!L86AT<FD@<VES=2!J82#DY')E('9A:&5L(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.#$U"FUS9VED(")3<&%C97(B"FUS9W-T<B`B
M17)A;&1A:F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B5F%H92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B5F%H
M960@:F$@=F]O9&5R9'5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM
M<V=S='(@(DAI<W!A86YI82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HY.`IM<V=I9"`B4W!A;2(*;7-G<W1R(")2Y&UP<W!O<W0B"@HC.B!S97)V
M:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R
M($EN<'5T(@IM<V=S='(@(D5R:6WD<FMI9&4@<VES97-T=7,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8R"FUS
M9VED(")3<&QI="!C96QL(@IM<V=S='(@(D5R86QD82!L86AT<FED(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(DQA:'5T82!V965R9R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R("),86AU=&$@<FED82(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM<V=I9"`B4W!O<G1S(@IM
M<V=S='(@(E-P;W)T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B
M"FUS9W-T<B`B4W)I($QA;FMA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C<S(&QI8B]";&]C:R]M971A<BYP:'`Z-S0*;7-G:60@(E-T86YD
M87)D(@IM<V=S='(@(E-T86YD87)D(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B4W1A<B!4<F5K(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.#`Y"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(D%L
M9W5S86%S=&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4W,`IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B3W-A<FEI
M:R!V]6D@;6%A:V]N9"(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E
M>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B3VQE:R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*;7-G:60@(E-T;W)A9V4@9F]R
M;6%T(@IM<V=S='(@(E-A;'9E<W1U<V9O<FUA870B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,@IM<V=I9"`B4W1R965T($%D9')E
M<W,B"FUS9W-T<B`B5.1N878@:F$@;6%J82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U
M9V@B"FUS9W-T<B`B3.1B:6IO;VYI='5D('1E:W-T(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T
M<B`B4W1R:6YG:61E(&QO96YD(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@W,PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B
M"FUS9W-T<B`B17)A;&1A(&1O;65E;B!A861R97-S:7-T(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I
M9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B4W1I:6P@6T-34UTB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3
M=2(*;7-G<W1R(")0_"(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B06QA;6MA=&%L;V]G:2!<(B5S7"(@96D@;&5I='5D
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B5&5E;6$B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD
M97)E<BYP:'`Z,S$W"FUS9VED(")3=6)M:70B"FUS9W-T<B`B2VEN;FET82(*
M"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B
M;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9
M;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B
M965N(&%P<')O=F5D+B(*;7-G<W1R("(B"B)3;V]V(%PB)7-<(B!L:7-A;6ES
M96MS('/\<W1E96UI(&]N('-A;'9E<W1A='5D+B!382!E:2!S86$@<VES<V4@
M;&]G:61A(&5N;F4@(@HB:W5I('-I;G4@<V]O=B!O;B!H96%K<R!K:6ED971U
M9"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B06QA:6YD96MS(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$P-`HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED
M(")3=6-C97-S(@IM<V=S='(@(DSD:W,@:V]R9&$B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D
M960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!O;B!S
M_'-T965M:2!L:7-A='5D+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O
M<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(EPB)7-<
M(B!A;F1M960@;VX@<_QS=&5E;6ES="!E96UA;&1A='5D+B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N
M(@IM<V=S='(@(EPB)7-<(B!O;B!K=7-T=71A='5D+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")<(B5S
M7"(@;VX@<_QS=&5E;6ES="!E96UA;&1A='5D+B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C
M;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@
M(B(*(DMO;F9I9W5R871S:6]O;B!O;B!T86=A<VD@=O5E='5D+B!-=75T=7-T
M92!NY&=E;6ES96MS(';D<G-K96YD82!V86%D970N(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS
M9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(DMO;F9I9W5R871S:6]O;FD@=F%R=6MO;W!I82#U;FYE<W1U
M<R!S86QV97-T861A+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B
M86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(")+;VYF:6=U
M<F%T<VEO;VYI9F%I;&D@=F%R=6MO;W!I82`E<R#U;FYE<W1U<R!S86QV97-T
M861A+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B7"(E
M<UPB(&UU=71M:6YE(/5N;F5S='5S+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R("(E<R!K
M:7)J=71A;6EN92#U;FYE<W1U<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U
M9&%N(@IM<V=S='(@(E-U9&%A;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS
M9W-T<B`B4VES=6MO:VMU=O5T92(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B4.1I:V5S973U=7,B"@HC
M.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS
M9W-T<B`B4.1I:V5S96QO;VIA;F<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B4.1I
M:V5S97!A:7-T96QI;F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C$V"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(E#D:6ME<V5T]75S(@H*
M(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N
M<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R(")0Y&EK97-E
M=/5U<R]L;V]J86YG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Q-0IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(E#D:6ME<V5T]75S.B`B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Y"FUS9VED(")3
M=6YS970B"FUS9W-T<B`B4.1I:V5S96QO;VIA;F<B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C$X"FUS9VED(")3=6YS970Z("(*;7-G<W1R
M(")0Y&EK97-E;&]O:F%N9SH@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T
M<B`BW&QA:6YD96MS(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W
M.`IM<V=I9"`B4W5P<&]R="(*;7-G<W1R(")4=6=I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-@IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B4W5R:6YA;6DB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B4W5R;F%M
M92(*;7-G<W1R(")097)E:V]N;F%N:6UI(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I
M9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R(")3=F%L8F%R9"!J
M82!*86X@36%Y96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B
M"FUS9W-T<B`B4W9A87-I;6%A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E
M9&5N(@IM<V=S='(@(E)O;W1S:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3=VET
M>F5R;&%N9"(*;7-G<W1R(")3:'9E:71S(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T
M<B`B4_QN:W)O;FES965R:6UI<V4@;&]G:2!K=7-T=71A='5D(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$T,@IM<V=I9"`B4WEN8TU,(@IM<V=S='(@
M(E-Y;F--3"(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY
M-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R
M(")+:7)J879I9V$@;W1S:6YG=71I;F=I;75S=&5S(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B4_S\<FEA
M($%R86%B:6$@5F%B87)I:6LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R("+$:6ME
M<V5T;W)M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C$*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(E1U=6QI
M;F4@:F$@Y&EK97-E;&EN92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R("+$:6ME
M<V5P=6AA;F=U9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8S"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R(")(;VUM
M:6MU;"#D:6ME<V5P=6AA;F=U9"(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O
M='-V+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(E135B!F86EL
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ,S0*;7-G:60@(E1A
M8FQE(@IM<V=S='(@(E1A8F5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R
M=&EE<R(*;7-G<W1R(")486)E;&D@;VUA9'5S960B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS9VED(")486)L92!3
M970B"FUS9W-T<B`B5&%B96QI=&4@:'5L:R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE
M('!R;W!E<G1I97,B"FUS9W-T<B`B5&%B96QI(&]M861U<V5D(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@(E1A:79A;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED
M(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(E1A:79A;BP@
M2&EI;F$@<')O=FEN=',B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II:VES
M=&%N(@IM<V=S='(@(E1A9'II:VES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I
M9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R(")486YS
M86%N:6$@W&AE;F1V86)A<FEI:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B
M079A;F5M:6YE.B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.38@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X-PIM<V=I9"`B5&%S:W,B"FUS9W-T
M<B`B5/;V9"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3<S"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(E1E;&5F;VYI
M;G5M8F5R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3`*;7-G:60@(E1E
M;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E9I:6UA<V4@='5N;FD@=&5M
M<&5R871U=7(Z(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,30*;7-G:60@
M(E1E;7!E<F%T=7)E(@IM<V=S='(@(E1E;7!E<F%T=75R(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,PIM<V=I9"`B5&5M<&5R871U<F4Z
M("(*;7-G<W1R(")496UP97)A='5U<CH@(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A
M='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(E1E
M;7!E<F%T=75R/&)R("\^*"5S36%X)7,O)7--:6XE<RD@)F1E9SLE<R(*"B,Z
M(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-C@W"B,L('!H<"UF
M;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S
M='(@(DUA;&QI(%PB)7-<(B!E:2!L96ET=60N(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(DUA;&QI9&4@:&%L9'5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,V"FUS9VED
M(")497AT(@IM<V=S='(@(E1E:W-T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,W-0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(D%I;G5L="!T96MS
M="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B5&5K<W1I(&IO
M;VYD=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(E1E>'1T;W`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED
M(")4:"(*;7-G<W1R(").92(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ
M"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R(")486D@*%1)4RTV,C`I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B5&%I
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED(")4:&%N
M:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN(@IM<V=S='(@(E3D;F%M92!K
M_&QA<W1A;6%S="XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R
M,`IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B1E10(&QA:65N9'5S(&5I(&]L92!S86%D879A;"XB"@IM<V=I
M9"`B5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")(
M:7-T;W)Y('/\<W1E96T@;VX@=N1L:F$@;/QL:71A='5D+B(*"B,@<&AP+69O
M<FUA=`HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-`IM<V=I9"`B
M5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S
M=7!P;W)T(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8B!I;G1E9W)A='-I
M;V]N:6UO;W1O<B!E:2!T;V5T82!<(B5S7"(M:2(*"B,Z(&9R86UE=V]R:R].
M971?24U34"])35-0+T)O;VLN<&AP.C$R.3(*;7-G:60@(E1H92!)35-0(&QO
M9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(DE-4U`@;&]G
M:2!A;&=VY.1R='5S=&%M:6YE(&YU<FIU<RXB"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S
M(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B36%I;G1E;F%N
M8V4Z.B!K;&%S<VD@;&%A9&EM:6YE(&YU<FIU<R(*"B,Z('-E<G9I8V5S+VEM
M86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I
M;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R(")396%D971E(&%K
M96X@;VX@<W5L971U9"X@5N1L:G5N+B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C
M;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y
M;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*(DMU
M:2!T86AA9"!K87-U=&%D82#U:6=U<VDL('!E86(@861M:6YI<W1R86%T;W(@
M<V5A9&ES=&%M82!P_'-I=F$@]6EG=7-T92`B"B)S_'-T965M:2XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U
M"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R(")!:6YU;'0@
M86QU;6EN92!K_&QG(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU
M;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T
M(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@HB2V]N=&%K
M=&D@240@;G5M8G)I="!E:2!MY.1R871U9"P@:N1E=&D@=/QH:F%K<R!V]6D@
M<V5E('!U=61U8B!A;F1M96)A87-I<RXB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A
M<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM
M<V=S='(@(DMI<FIE(/5N;F5S='5S(&QI<V%D82!S:6YU(&%A9')E<W-I<F%A
M;6%T=7-S92XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,38Y"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C
M:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*
M;7-G<W1R("(B"B)!;&QK:7)J87-T871U9"!K:7)J82!K;VYT<F]L;&EM:7-E
M:W,@;VX@=F%J82!E<F%L9&D@4$=0(&%L;&MI<FIA8FQO:VMI+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS
M9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N
M;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T
M:&4@9&%T86)A<V4N(@IM<V=S='(@(DIA;W1U<VYI;65K:7)J82!)1"!O;B!M
MY.1R86UA=&$L(&KD971I('3\:&IA:W,@=O5I('!U=61U8B!A;F1M96)A87-I
M<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@
M<W!E8VEF:65D+B(*;7-G<W1R(")*86]T=7-N:6UE:VER:2!P;VQE(&WDY')A
M='5D+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$S"FUS9VED
M(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E
M8B!C;VYN96-T:6]N+B(*;7-G<W1R(")+<OQP=&EM:7-E:W,@;VX@=F%J82!T
M=7)V86QI<W0@2%144"#\:&5N9'5S="XB"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C$W-2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I
M;B!A("5S('-E='1I;F<N(@IM<V=S='(@(D9A:6P@)7,@<&5A:W,@<VES86QD
M86UA("5S(&WDY')A;F=U="XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$V."!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE
M("5S('-E='1I;F=S+B(*;7-G<W1R(")&86EL("5S('!E86MS('-I<V%L9&%M
M82!M:6YG96ED("5S(&WDY')A;F=U:60N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C$Y"FUS9VED(")4:&4@9FEL92!C86X@;F]T(&)E(&-O
M<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B1F%I;&D@96D@<V%A(&MO<&5E
M<FED82!I<V5E;F1A;&4@;W1S82XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A
M+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*
M;7-G<W1R(")&86EL(&5I('-I<V%L9&%N=60@86YD;65I9"XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4
M:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E
M+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R(")*Y')G;F5V860@<V5L;&4@;65S
M<V%G92]R9F,X,C(@:VER:F$@<.1I<V5D+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL
M('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@
M26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA
M="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E
M>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@
M9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@
M(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY
M('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U
M;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A
M<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T
M;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@HB5.1I
M<V5K<F%A;FER97II:6UI(&MA<W5T86UI;F4@=&5K:71A8B!P<F]B;&5E;64@
M26YT97)N970@17AP;&]R97)I<R!TY&YU("(*(G-E;&QE('9E96)I;&5H:71S
M96IA('9I9V%D96QE+"!M:61A(&UE:6P@96D@]6YN97-T=2!M86AA('-U<G5D
M82X@17-I;F5D82`B"B)V]6EB(&SD8G4@:W5J=71I<V5S+"!E9&ET;W)I(&9U
M;FMT<VEO;VYI9&4@<'5U9'5M:7-T(&IA+W;U:2!V965B:6QE:&ET<V5J82`B
M"B)J=6AU<VQI:VMU(&MI;FYI:F]O:W-M:7-T+B!+=6D@<VEN=2!A<G9U=&D@
M;W!E<F%T<VEO;VYI:W,@;VX@5VEN9&]W<R`Y>"P@(@HB<VEI<R!O;B!VY&=A
M('3U96[D;VQI;F4@970@<V%A9"!<(D=E;F5R86P@4')O=&5C=&EO;B!&875L
M=%PB('9E871E871E(&IA("(*(G!E860@87)V=71I('1A87-KY&EV:71A;6$N
M7%QN7%QN4VEN9"!O;B!H;VEA=&%T=60N($ML]7!S82!/2RP@:W5I('-O;W9I
M9"`B"B)S:6ES:VD@=.1I<V5K<F%A;FER97II:6UI('!R;V]V:61A+B(*"B,Z
M('-E<G9I8V5S+W!R969S+G!H<#HY,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@
M(DED96YT:71E970@7"(E<UPB(&]N(&MU<W1U=&%T=60N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I
M9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B06EN=6QT('9A
M<V%K(&O\;&<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y
M(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G
M<W1R(")#<GEP=%]P9W`Z.B!K;&%S<VD@:F%O:W,@<&5A8B!O;&5M82!MY.1R
M871U9"!';G501R!P<F]G<F%M;6D@87-U:V]H="XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TU$3BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB
M)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A
M;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S
M=&]O9"XB"FUS9W-T<B`B(@HB2VER:2!M:7,@<V%A9&5T:2`E<R!A861R97-S
M:6QE("5S('1E96UA9V$@7"(E<UPB(&]N(&%V871U9"Y<;B(*(E-E92!E:2!G
M87)A;G1E97)I(&5T(&MI<FD@;.1B:2!L;V5T:2!V]6D@<V5L;&5S="!A<G4@
M<V%A9&DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM<V=I
M9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S
M92!P86=E(@IM<V=S='(@(DYI;6D@;6ED82!K87-U=&%D82!E9&ET;W)I(&QE
M:&5G82!L:6YK:6UI<V5L(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z-#0Q"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU
M;65R:6,N(@IM<V=S='(@(E;D;&IA9&4@87)V('!E86(@;VQE;6$@87)V+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,0IM<V=I
M9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R
M9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B2&]R9&5?0W)Y<'1?
M<VUI;64Z.B!K;&%S<R!V86IA8B!O<&5N<W-L(&UO;V1U;&ET+B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V
M960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A
M;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"B)%96QI<W1U<W0@7"(E<UPB(&5I
M(/5N;F5S='5N=60@<V%L=F5S=&%D82P@:W5N82!A;F1M971E(&AU;&L@_&QE
M=&%S('-U=7)I;6$@(@HB;'5B871U9"!MY.1R82(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@
M='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T
M<B`B(@HB4V5D82!T_/QP:2!A;F1M971E("@E<RD@=F%A=&%M:7-E:W,@=F%J
M86QI:VMU('!R;V=R86UM:2!E:2!L96ET=60@<_QS=&5E;6ES="XB"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-30*;7-G:60@(E1H92!Q=6]T
M92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS
M9W-T<B`B2G5T=6WD<FL@<&5A8B!O;&5M82#\:W,@;>1R:RXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS
M9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R(")!
M:6YU;'0@=F%S86L@:F$@<&%R96T@:_QL9R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R
M:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R(")!:6YU;'0@<&%R96T@:_QL
M9R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T-@IM<V=I9"`B
M5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*
M;7-G<W1R(")%<F%L9&%J82!P96%B(&]L96UA(/QK<R!MY')K+B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S
M='(@(E-E<G9E<B!<(B5S7"(@;VX@:W5S='5T871U9"XB"@HC.B!S97)V:6-E
M<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B4V5R
M=F5R(%PB)7-<(B!O;B!S86QV97-T871U9"XB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T
M(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("(E<R!L:6ET=6UI
M<W-O;W8@;VX@965M86QD871U9"XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S<&5C:69I960@<F]W(&1O
M97,@;F]T(&5X:7-T+B(*;7-G<W1R(")-Y.1R871U9"!R:61A('!O;&4@;VQE
M;6%S+B(*"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T
M(&5X:7-T+B(*;7-G<W1R(")-Y.1R871U9"!R:61A("@E9"D@<&]L92!O;&5M
M87,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ-S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S
M(&YO="!E>&ES="XB"FUS9W-T<B`B06IU=&ES="!F86EL:2!<(B5S7"(@<&]L
M92!O;&5M87,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Q,0IM
M<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@
M=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R(")3:6YU('-I<V5S=&%T=60@
M=&5K<W0@96D@:V%T='4@96MR86%N:6P@;VQE=F%G82XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED
M(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R(")!:6YU
M;'0@_&QE;6EN92!J82!A;'5M:6YE(&O\;&<B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@
M=&]P('-I9&4@;VYL>2(*;7-G<W1R(")!:6YU;'0@_&QE;6EN92!K_&QG(@H*
M(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L
M;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB
M"FUS9W-T<B`B4V%A9&5T=60@86YD;65D(&]N('9A:&5P96%L(&MA;W1S:2!L
MY&EN=60N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V,B!F
M<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L
M;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(E-A861E
M='5D(&9A:6QI(&5I('-A86YU9"!S86QV97-T861A+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HT-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-38*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-2!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$Y"FUS9VED(")4:&4@=V5A
M=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B=V5A
M=&AE<BYC;VT@8FQO:VL@96D@;VQE(&OD='1E<V%A9&%V+B(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M
M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DMU:G5N
M9'5S=&4@:V%T86QO;V=I(%PB)7-<(B!E:2!L96ET=60N(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N
M;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`B16D@;VQE(&UI9&%G:2!S
M96%D:7-T861A+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C,T,@IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E
M(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(DMI<FIA;"!E:2!O;&4@=F%H
M971U;'0@97-I=&%T879A:60@;W-I+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E
M('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@
M96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S
M('1H86X@)7,N(@IM<V=S='(@(B(*(E-E;&QE<R!VY&QJ87,@;VX@;&EI86QT
M('!A;&IU(&WD<FME+B!382!S:7-E<W1A<VED("5S(&WD<FMI.R!L=6)A='5D
M('!O;&4@(@HB<F]H:V5M(&MU:2`E<RXB"@HC.B!S:6=N=7`N<&AP.C4S(&%D
M;6EN+W5S97(N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*
M;7-G<W1R(")<(B5S7"(@;&ES86UI<V5L('/\<W1E96UI('1E:VMI<R!P<F]B
M;&5E;3H@)7,B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O
M<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(")+87-U
M=&%J82!<(B5S7"(@86YD;65T92!S_'-T965M:7-T(&5E;6%L9&%M:7-E;"!T
M96MK:7,@<')O8FQE96TZ("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG
M(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(")<(B5S7"(@965M
M86QD86UI<V5L('/\<W1E96UI<W0@=&5K:VES('!R;V)L965M.B`B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@(EPB
M)7-<(B!M=75T;6ES96P@=&5K:VES('!R;V)L965M.B`E<R(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(D9A:6QI(&QA861I;6ES
M96P@<V5R=F5R:7-S92!T96MK:7,@<')O8FQE96TZ("5S(&5I(&QA971U9"XB
M"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X
M:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HB
M1F%I;&D@;&%A9&EM:7-E;"!S97)V97)I<W-E('1E:VMI<R!P<F]B;&5E;3H@
M)7,@;VQI('-U=7)E;2!K=6D@=O5I;6%L9&%B("(*(G!I:7)A;F<@*"5D(&)A
M:71I*2XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL
M>2!U<&QO861E9"XB"FUS9W-T<B`B(@HB1F%I;&D@;&%A9&EM:7-E;"!S97)V
M97)I<W-E('1E:VMI<R!P<F]B;&5E;3H@)7,@;&%E=&D@86EN=6QT(&]S86QI
M<V5L="XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T
M:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R(")396QL92!K:7)J82!O<V$@97-I
M=&%M:7-E;"!T96MK:7,@=FEG82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B2V]N=&%K=&%N
M9&UE=&4@:6UP;W)T:6UI<V5L('1E:VMI<R!V:6=A+B(*"B,Z(&9R86UE=V]R
M:R]$871A+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(FE#
M86QE;F1A<B=I(&%N9&UE=&4@:6UP;W)T:6UI<V5L('1E:VMI<R!V:6=A+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#`*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H
M87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R
M("(B"B)396%D:7-T=7-E('9O<FUI;"!E<VEN97,@=FEG82X@16AK(&KD='-I
M9"!TY&ET;6%T82!M]6YE(&MO:'5S='5S;&EK=2!VY&QJ82XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I
M9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A
M:6X@;&%T97(N(@IM<V=S='(@(B(*(E-O;W9I='5D(&%A9')E<W-I<F%A;6%T
M=2!O<&5R871S:6]O;FD@<V]O<FET86UI<V5L('1E:VMI<R!V:6=A+B!086QU
M;B!P<F]O=FD@(@HB:&EL:F5M('5U97-T:2XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N
M(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(DMO;G1A:W1A;F1M
M971E('5U96YD86UI<V5L('1E:VMI<R!V:6=A+B!086QU;B!P<F]O=FD@:&EL
M:F5M('5U97-T:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P
M9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I
M;B!L871E<BXB"FUS9W-T<B`B2F%O='5S;FEM96MI<FIA('5U96YD86UI<V5L
M('1E:VMI<R!V:6=A+B!086QU;B!P<F]O=FD@:&EL:F5M('5U97-T:2XB"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G
M:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG
M(&9O;&1E<G,N(@IM<V=S='(@(E-E92!)34%0('-E<G9E<B!E:2!V]6EM86QD
M82!K875S=&%D92!J86=A;6ES="XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R(")3964@96D@
M;N1I(&]L979A="!K;W)R86QI:R!205(@87)H:6EV+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@
M(E-E92!E:2!NY&D@;VQE=F%T(&MO<G)A;&EK(%I)4"!F86EL+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q-#4*;7-G:60@(E1H:7,@9&]E<R!N
M;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R(")3
M964@96D@;N1I(&]L979A="!K96AT:78@:V%A<F1I(&YU;6)E<BXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*
M;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T
M96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@
M(B(*(E-E92!D<F%I=F5R(';U:6UA;&1A8B!S86%T82!S]6YU;65I9"!LY&)I
M($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@(@HB;/S\<VDL
M(&MA<W5T861E<R!(5%10($%0270B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P
M.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)
M(@IM<V=S='(@(B(*(E-E92!D<F%I=F5R(';U:6UA;&1A8B!S86%T82!S]6YU
M;65I9"!LY&)I(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&S\_'-I+"`B"B)K
M87-U=&%D97,@2%144"!!4$ET+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E
M<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R
M96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN
M9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB4V5E(&1R86EV97(@=O5I;6%L
M9&%B('-A871A('/U;G5M96ED(&SD8FD@<VUS,F5M86EL("AH='1P.B\O<VUS
M,F5M86EL+F-O;2D@(@HB;/S\<VDL(&MA<W5T861E<R!(5%10($%0270N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY
M("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q
M=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY
M("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*(E-E92!D<F%I=F5R
M(';U:6UA;&1A8B!S]6YU;6ET92!S86%T;6ES="!33510('!R;W1O:V]L;&EG
M82!LY&)I(%9O9&%F;VYE("(*(DET86QY(&S\_'-I+"!A:6YU;'0@5F]D869O
M;F4@;G5M8G)I=&5L92X@4V5L;&5K<R!O;B!V86IA(%9O9&%F;VYE($ET86QY
M(&4M(@HB<&]S=&D@:V]N=&]T("AH='1P.B\O=W=W+C$Y,"YI="DB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3,Y.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-34W
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,SD*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DU."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`U
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,CD@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`W.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,30Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C$*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C0Q,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-#4T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3<@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@R.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,3,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,#8*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS.#(R"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R
M(")3964@=N1L:2!O;B!K;VAU<W1U<VQI:RXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O
M;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(E-E92!VY&QI(';U:6(@<VES86QD
M861A('9A:60@=.1I<V%R=F4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C0Q.`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU
M;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B4V5E(';D;&D@=O5I8B!S
M:7-A;&1A9&$@86EN=6QT(&YU;6)R96ED(&IA(&MO;VQO;FET+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@
M;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(E-E92!V
MY&QI(';U:6(@<VES86QD861A(&%I;G5L="!K86AE:W-A;F1A<G9E+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE
M;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F
M(&EN=&5G97)S(@IM<V=S='(@(E-E92!VY&QI('!E86(@;VQE;6$@:V]M86=A
M(';U:2!T_&AI:W5G82!E<F%L9&%T=60@=.1I<V%R=G5D92!L;V5N9"(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX.0IM<V=I9"`B5&AI<R!F:65L
M9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R(")3964@=N1L:2!P
M96%B(&]L96UA(&MO<G)E:W1N92!A<G8N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@S-@IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A
M:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X
M86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R(")3964@=N1L:2!P96%B('-I
M<V%L9&%M82!VY')V:6MO;V1I(%)'0B!(97@@:W5J=6PL(&[D:71E:W,@)R,Q
M,C,T868G+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4V,0IM<V=I
M9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G
M<W1R(")3964@=F]R;2!O;B!J=6)A(&SD8FD@=/;V=&%T=60N(@H*(SH@=&5M
M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AI<R!I<R`E<RXB"FUS9W-T<B`B4V5E(&]N("5S+B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z-#4Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H
M:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H
M870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O
M<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I
M="`E<R(*;7-G<W1R("(B"B)3964@;VX@2V]L86(@1W)O=7!W87)E(&]B:F5K
M="X@4V5L;&4@;V)J96MT:2!V86%T86UI<V5K<R!V86IA9"!E+7!O<W1I("(*
M(FML:65N=&D@;6ES(&WU:7-T86(@2V]L86(@1W)O=7!W87)E(&9O<FUA871I
M+B!396QL:7-T92!E+7!O<W1I(&ML:65N=&ED92`B"B)N:6UE:VER:F$@;&5I
M860@86%D<F5S<VEL="`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C4Y,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A
M9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@
M=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B4V5E(&MI<FD@;VX@:VER:G5T871U
M9"!MY')G:7-T:6MU<R`H)7,I(&UI<R!E<FEN96(@<VEN=2!O;6%S="XB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI
M<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(E-E92!A
M<G8@<&5A8B!O;&5M82!VY&AE;6%L="#\:W,N(@H*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E
M<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T
M<B`B4V5E('-E<G9E<B!E:2!M]6ES=&$@;&%H=&D@<&%K:VED82!Z:7`@:F$@
M9WII<"!F86EL92XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T
M<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E
M86-T:79A=&5D+B(*;7-G<W1R(")3964@<_QS=&5E;2!O;B!P<F%E9W4@=N1L
M:F$@;/QL:71A='5D+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM
M<V=S='(@(E-E;&QE(&MO:&$@<&5A;"!P96%B(&]L96UA(&%R=BXB"@HC.B!S
M97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES
M('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W
M(@IM<V=S='(@(E-E92!A:V5N('1U;&5B(&%V861A(%-E861E=&4@86MN87-T
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*
M;7-G:60@(E1H=6YD97(B"FUS9W-T<B`BQ&EK92(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR,S0*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B2&5L
M<&1E<VLB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(X('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B5&EM92(*;7-G<W1R
M(")!96<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@V"FUS9VED
M(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(E3V]F%J871A8F5L(@H*(SH@;&EB
M+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R
M(")!:F$@97-I='5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S
M.0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B06IA('9A;&EK(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B261A
M+51I;6]R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B
M"FUS9W-T<B`B4&5A;&MI<FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM
M<V=S='(@(E!E86QK:7)I("AT;V]L=&EP*2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@
M(DME;&QE;&4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C4T"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L
M(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@
M:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B)-:71M92!O8FIE
M:W1I('9A;&EM:7-E:W,@:&]I82!A;&P@0W1R;"`H4$,I(';U:2!#;VUM86YD
M("A-86,I(&ML86AV:2!J82`B"B)K;/5P<V$@;V)J96MT:61E;"XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q"FUS9VED(")4;V1A>2(*
M;7-G<W1R(")4Y&YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S
M='(@(DA434P@:V]O9&D@<F5Z:6EM(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B
M5&]G;R(*;7-G<W1R(")4;V=O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K
M96QA=2(*;7-G<W1R(")4;VME;&%U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,Q,PIM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B2&]M;64B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R(")4;VYG82(*
M"FUS9VED(")4;V\@;6%N>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA
M<W0@;6EN=71E<RXB"FUS9W-T<B`B5FEI;6%S=&5L(&UI;G5T:71E;"!O;B!L
M:6EG82!P86QJ=2!N=7)J=6YU9"!S:7-S96QO9VEM:7-I+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PIM<V=I
M9"`B5&]P(@IM<V=S='(@(MQL97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I
M(@IM<V=S='(@(E!E86QM:7-E<R!R86%M:7,@*%]T;W`I(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T
M<B`B5/5L:V5D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@86YD
M(%1O8F%G;R(*;7-G<W1R(")4<FEN:61A9"!J82!4;V)A9V\B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A;'-E
M(@IM<V=S='(@(E3U9&4@=O5I('9A;&4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R(")4
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B5'5N
M965S:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B
M5/QR9VDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B5'5R
M:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B5/QR9VD@*$E33RTX.#4Y+3DI
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@
M(E1U<FMM96YI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N
M9"!#86EC;W,@27-L86YD<R(*;7-G<W1R(")4=7)K<R!J82!#86EC;W,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B5'5V86QU(@H*
M(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R
M(&-H;VEC93H@(@IM<V=S='(@(DMI<FIU=&$@;VUA('9A;&EK.B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-CD*;7-G:60@(E4N5BX@:6YD
M97@Z("(*;7-G<W1R(")55BUI;F1E:W,Z("(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP
M:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),
M(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S
M='(@(E-I;G4@<VMR:7!T:2!KY'1T971O:6UE=&%M:7-R87!O<G1I(%523"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3<*
M;7-G:60@(E523#HB"FUS9W-T<B`B55),.B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G
M:60@(E5G86YD82(*;7-G<W1R(")59V%N9&$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS
M9VED(")5:W)A:6YE(@IM<V=S='(@(E5K<F%I;F$B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HT,3(*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B16D@<.3D<V4@;&EG:2!61E,@:V%T
M86QO;V=I;&4N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I
M;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R(")4Y&EE;F1A=F$@:V%S=71A
M:F%I;F9O(&QI<V%M:6YE(&QI:71U;6ES96P@96D@]6YN97-T=2XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,X.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`B16D@<V%A(&UU=71A(%9&4R!F86EL:2!<(B5S
M7"(@]6EG=7-I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,X
M-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93
M(&9I;&4@)7,O)7,N(@IM<V=S='(@(D5I('-A82!M=75T82!61E,@9F%I;&D@
M)7,O)7,@]6EG=7-I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M-S4U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@
M)7,N(@IM<V=S='(@(D5I('-A82!M:6YN82!K871A;&]O9VD@)7,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM
M<V=S='(@(D9A:6QI(%PB)7-<(B!S=75R=7-T('!O;&4@=O5I;6%L:6L@:V]N
M=')O;&QI9&$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C@X
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`Q-@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#,T"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G
M<W1R(")&86EL:2!<(B5S+R5S7"(@<W5U<G5S="!P;VQE(';U:6UA;&EK(&MO
M;G1R;VQL:61A+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HT
M,S4*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM
M<V=S='(@(D5I('-A82#\:&5N9'5S="!344P@<V5R=F5R:6=A+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,Y"FUS9VED(")5;F%B;&4@=&\@
M8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B4U-,(/QH96YD=7-E(&%L9V%T
M86UI;F4@;G5R:G5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(R-2!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S`*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HR,#D*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*
M;7-G<W1R(")61E,@9F%I;&D@:V]P965R:6UI;F4@;G5R:G5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S8U"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM
M<V=S='(@(E9&4R!K871A;&]O9VD@7"(E<UPB(&QO;VUI;F4@;G5R:G5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,U-"!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HR-38*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B5D93(&MA=&%L;V]G:2!L;V]M:6YE(&YU<FIU
M<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T"FUS9VED
M(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@9F%I
M;&D@;&]O;6EN92!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HR.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B5D93(&MA=7-T82!<(B5S
M7"(@;&]O;6EN92!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C8U"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F
M:6QE+B(*;7-G<W1R(")%:2!S86$@;'5U82!T_&AJ82!61E,@9F%I;&DN(@H*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-S8*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED
M(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R("),86AT:7!A
M:VMI;6EN92!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HR,C0@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR.3@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E
M8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R(")<(B5S7"(@96D@<V%A(&MU
M<W1U=&%D82P@:V%T86QO;V<@96D@;VQE('3\:&DN(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS
M9W-T<B`B16D@<V%A(&MU<W1U=&%D82!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S$Q
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,S0*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M(@IM<V=S='(@(B5S(&5I('-A82!K=7-T=71A9&$L(&MA=&%L;V]G(&5I(&]L
M92!T_&AI(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T
M."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM
M<V=S='(@(E9&4R!K871A;&]O9VEP=74@:W5S='5T86UI;F4@;G5R:G5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S-R!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(E9&4R!K
M871A;&]O9VD@:W5S='5T86UI;F4@;G5R:G5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z-#$W(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M-#(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(D5I('-A82!K=7-T=71A9&$@5D93
M(&MA=&%L;V]G:3H@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HR,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D5I('-A82!K=7-T=71A9&$@5D93
M(&9A:6QI(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR.#@*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ
M.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,X,PHC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@9F%I;&D@:W5S='5T
M86UI;F4@;G5R:G5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M,C0T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(D5I('-A82!K=7-T=71A9&$@5D93
M(&MA=7-T82!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HT,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R(")%:2!S86$@:W5S='5T861A
M(%9&4VD@<F5K=7)S:6EV<V5L=#H@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HX,#,*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R
M<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(DIO;VMS=F%T(&MA=&%L;V]G:2!E
M:2#U;FYE<W1U('1U=F%S=&%D82XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8P,PIM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R
M=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R(")%:2!S86$@:^1T=&4@<V5R=&EF
M:6MA861I(/QK<VEK87-J=2(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0
M+G!H<#HT-3$@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T:"YP:'`Z,3$X
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I
M;FET:6]N(&]F("5S+B(*;7-G<W1R("(E<R!D969I;FET<VEO;VYI(&QA861I
M;6EN92!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,3DV(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38V(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HQ-S$*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F
M:6QE+B(*;7-G<W1R(")61E,@9F%I;&D@_&UB97)T]7-T;6EN92!N=7)J=7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C$P,@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C8T."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B16D@<V%A(&%V861A(%9&4R!F86EL:2!<(B5S7"(N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<W(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$S,PIM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@
M9F]R('=R:71I;F<N(@IM<V=S='(@(D5I('-A82!A=F%D82!61E,@9F%I;&D@
M;75U=&UI<V5K<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX
M,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R"FUS9VED(")5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92XB"FUS9W-T<B`B5D93(&9A:6QI(&%V86UI;F4@;G5R:G5S
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*
M;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS
M9W-T<B`B4&%K:71U9"!A<FAI:79I(&%V86UI;F4@;G5R:G5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HX,S4*;7-G:60@(E5N86)L92!T;R!R96%D
M(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(D5I('-A
M82!L=6=E9&$@5D93(&9A:6QI("AF:6QE<VEZ92@I(&YU<FIU<RDN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V-@IM<V=I9"`B56YA8FQE('1O(')E
M860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B
M16D@<V%A(&QU9V5D82!61E,@9F%I;&D@*&=E=$9I;&53:7IE*"D@;G5R:G5S
M*2XB"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L
M97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*
M;7-G<W1R(")%:2#U;FYE<W1U(&QU9V5D82!F86EL:3H@(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z-C8Y"FUS9VED(")5;F%B;&4@=&\@<F5A
M9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(G9F<W)O;W0@:V%T
M86QO;V=I(&QU9V5M:6YE(&YU<FIU<RXB"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$Q,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@
M97AI<W1S(@IM<V=S='(@(B5S(&5I('-A82#\;6)E<B!N:6UE=&%D82`E<RUK
M<SH@<VEH=&MA=7-T(&]N(&IU8F$@;VQE;6%S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HR.3,*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B5D93(&MA=&%L;V]G:2#\;6)E
M<FYI;65T86UI;F4@;G5R:G5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,S(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(D5I('-A82#\;6)E<B!N
M:6UE=&%D82!61E,@:V%T86QO;V=I.B`E<R(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z,C8W(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S0S
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R(")%:2!S86$@_&UB97(@;FEM971A9&$@5D93
M(&9A:6QI(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HV,3`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S
M+B(*;7-G<W1R(")%:2!S=75D82#\;6)E<B!N:6UE=&%D82!61E,@9F%I;&D@
M)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,C,@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q,PHC.B!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z-#4R(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HR.#4*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P
M,0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`B
M5D93(&9A:6QI(/QM8F5R;FEM971A;6EN92!N=7)J=7,N(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS
M9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B16D@]6YN
M97-T=2!KY&EV:71A9&$@)VUK:7-O9G,G+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T
M<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(E-E9&$@5V]R
M9&D@9&]K=6UE;G1I(&]N(';U:6UA='4@=/5L9V5N9&%D82(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,30Y(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,34R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET
M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D5I('-A82!K:7)J=71A9&$@
M5D93(&9A:6QI(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HQ-SD*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P
M>2@I(&9A:6QE9"DN(@IM<V=S='(@(D5I('-A82!K:7)J=71A9&$@5D93(&9A
M:6QI("AC;W!Y*"D@;G5R:G5S*2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S
M.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30S"FUS9VED
M(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B5D93
M(&9A:6QI(&%N9&UE=&4@<V%L=F5S=&%M:6YE(&YU<FIU<RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z.#0Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@(D5I
M('-A82!K:7)J=71A9&$@5D93(&9A:6QI+"!K971T86MV;V]T(&SD:&5B(&SU
M:&MI+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R(")!;&QA:F]O;FET=60@
M=&5K<W0B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5
M;F1O($-H86YG97,B"FUS9W-T<B`B5&%A<W1A(&%L9W-E:7,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5
M;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R(")6]71A8B!V:6EM87-E
M('1E9V5V=7-E('1A9V%S:2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C(R,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS.3`*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O
M;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(D]O=&%M871U('9A
M<W1U<R!S97)V97)I;'0@_&AE;F1U<V4@;&]O;6ES96PZ("(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E
M9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(D]O=&%M871U
M('9A<W1U<R!S97)V97)I;'0Z("(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM<V=S
M='(@(DMA=&5G;V]R:6%T82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS
M"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B56YI8V]D92`H551&
M+3@I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S
M(@IM<V=S='(@(D%R86%B:6$@W&AE;F1E;6ER86%D:60B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(E-U=7)B<FET86YN
M:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S
M='(@(D%M965R:6MA(-QH96YD<FEI9VED(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I
M9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S
M='(@(D%M965R:6MA(-QH96YD<FEI:VED92!VY&EK97-A87)E9"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV.2!L:6(O0FQO8VLO;65T87(N
M<&AP.C<Q"FUS9VED(")5;FET<R(*;7-G<W1R("+<:&EK=60B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(E1U
M;F1M871U(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S
M<V%G92!)1"DN(@IM<V=S='(@(E1U;F1M871U(&%P:6US9VED("A!4$D@365S
M<V%G92!)1"DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE
M;G0@365S<V%G92!)1"DN(@IM<V=S='(@(E1U;F1M871U(&-L:6US9VED("A#
M;&EE;G0@365S<V%G92!)1"DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$U.0IM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB
M"FUS9W-T<B`B3>3D<F%T:2!T=6YD;6%T=2!A<W5K;VAT+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I
M9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B5'5N
M9&UA='4@:V%S=71A:F%N:6UI(&IA('-A;&%S]6YN82XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G
M:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(MQH96YD
M82!S964@96QE;65N="!L86AT:2XB"@HC.B!F<F%M97=O<FLO261E;G1I='DO
M261E;G1I='DN<&AP.C(Y-@IM<V=I9"`B56YN86UE9"(*;7-G<W1R(").:6UE
M='4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C
M97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C
M=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N
M;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@
M86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S
M='(@(B(*(M5I9W5S=&5T82!S:W)I<'1I9"!E:2!S86$@='5R=F%K86%L=71L
M=7-T96P@<')O9W)A;7-E;'0@<V]O<FET861A(&SU:6MA;6ES="\B"B)K;&5E
M<&EM:7-T+B!+=6D@:VSU<'-A9"!/2RP@;N1E9"!M;WII;&QA+F]R9R!T96AN
M:6QI<W0@<V5L9VET=7-T(&MU:61A<R`B"B)L=6)A9&$@<VMR:7!T:61E;"!L
M]6EK97!U:'9R:70@:V%S=71A9&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L
M;W(B"FUS9W-T<B`B165M86QD82!VY')V(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV.#8@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HY,C8*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HY,S(*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R(")4
M;V5T86UA=&$@;&%I96YD=7,B"@HC.B`M+2T@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R(")+:6YN:71A(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B375U9&$@)7,B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E
M<B(*;7-G<W1R(")-=75D82!K87-U=&%J82(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@
M7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@;75U9&5T=60N(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E
M;&5T960N(@IM<V=S='(@(E5U96YD=7-E('-K<FEP="!K=7-T=71A='5D+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.0IM<V=I9"`B57!L;V%D(@IM<V=S
M='(@(DQA92!S97)V97)I<W-E(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I
M;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(DOU:6L@<F%K96YD=7-E('!A
M:6=A;&1U<V9A:6QI9"!O;B!S97)V97)I<W-E(&QA971U9"XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P
M"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(DQA9&EN82!S
M=75R=.1H960B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S
M(@IM<V=S='(@(E-U=7)E9"!R;V]M82!N=6UB<FED(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R(")5<G5G=6%I(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(DMA<W5T
M82!P<F%E9W5S=#H@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R(")+
M87-U=&$@4U-,:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G
M:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U3
M4"!S97)V97(N(@IM<V=S='(@(DMA<W5T82!J=6AU;"!K=6D@;FEM:2]S86QA
M<_5N82!)35-0('-E<G9E<FES(&]N(&5R:6YE=BXB"@HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"FUS9VED(")5<V5R(@IM<V=S='(@
M(DMA<W5T86IA(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y
M+G!H<#HW,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@
M875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(DMA<W5T86IA;"`E<R!E:2!O
M;&4@;'5B871U9"`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@
M(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B2V%S=71A:F%H86QD=7,B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,0IM<V=I9"`B
M57-E<B!/<'1I;VYS(@IM<V=S='(@(DMA<W5T86IA('-E861I<W1U<R(*"B,Z
M('-I9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S
M='(@(DMA<W5T86IA(')E9VES=')E97)I;6EN92(*"B,Z('-I9VYU<"YP:'`Z
M,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D
M(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(E-E;&QE<R!S86ED:7,@:V%S=71A
M:F%T92!R96=I<W1R965R:6UI<W0@96D@=O5I;6%L9&%T82XB"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T
M(&9O=6YD(@IM<V=S='(@(DMA<W5T86IA:V]N=&]T(&5I(&QE:71U9"(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M,S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(DMA
M<W5T86IA;FEM:2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L
M<F5A9'D@97AI<W1S+B(*;7-G<W1R(")+87-U=&%J86YI;6D@7"(E<UPB(&]N
M(&IU8F$@;VQE;6%S+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(DMA<W5T86IA;FEM:3HB
M"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5<V5R
M;F%M93H@(@IM<V=S='(@(DMA<W5T86IA;FEM:3HB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES
M=&5M.B(*;7-G<W1R(")+87-U=&%J860@<_QS=&5E;6ES.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B57-B96MI<W1A;B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$V,R!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR-34*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E
M<R!N;W0@97AI<W0N(@IM<V=S='(@(E9&4R!K871A;&]O9VD@<&]L92!O;&5M
M87,N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B
M5F%C871I;VXB"FUS9W-T<B`B4'5H:W5S(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#8V"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC
M;'5D93H@(@IM<V=S='(@(D]L96UA<V]L979A9"!K;W)R96MT<V5D(&%S=6MO
M:&%D(&]N.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8S.`IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B2V5H=&EV=7,B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@
M(DUI;G5T:71E(&%R=B!P<F%E9W5S97-T(&AE=&ME<W0@86QA=&5S+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@U-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V
M97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R(")6Y.1R='5S
M(/QL971A8B`E<R!M86MS:6UU;7!I:VMU<V4N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(T-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8V
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,38@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,CDR.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O
M=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU97,B"FUS9W-T<B`B5N3D<G1U
M<V5D(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P.2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3@V"FUS9VED(")686QU97,@=&\@<V5L96-T
M(&9R;VTB"FUS9W-T<B`B5N3D<G1U<V5D(&UI;&QE(&AU;&=A<W0@=F%L:61A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R(")686YU
M871U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-`IM<V=I
M9"`B5F%R:6%B;&4B"FUS9W-T<B`B375U=&QI:R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*
M;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R(")696YE='-U965L82(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I
M9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@
M=&%M<&5R960@=VET:"XB"FUS9W-T<B`B2V]N=')O;&QI;6EN92!N=7)J=7,@
M+2!S964@:VER:2!V]6EB(&]L;&$@<&%H871A:'1L:6MU;'0@;75U9&5T=60N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G
M:60@(E9E<G-I;VXB"FUS9W-T<B`B2N1R:F5N=6UB97(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C(V"FUS9VED(")697)S:6]N($-O;G1R;VPB
M"FUS9W-T<B`B5F5R<VEO;VYI:&%L9'5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC
M86P@86QI9VXB"FUS9W-T<B`B5F5R=&EK86%L;F4@:F]O;F1U<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@
M(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B5F5R=&EK86%L;F4@=F]O9&5R
M9'5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(E9E<G1I:V%A;&YE.B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS
M9VED(")697)Y($AI9V@B"FUS9W-T<B`B5N1G82!K]7)G92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,38*;7-G:60@(E9I970@3F%M(@IM<V=S='(@(E9I971N86TB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5FEE=&YA;65S92`H5DE3
M0TE)*2(*;7-G<W1R(")6:65T;F%M:2`H5DE30TE)*2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDV,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")6:65W("5S(@IM<V=S='(@(E9A871A("5S(@H*(SH@;&EB+T)L;V-K
M+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G
M92(*;7-G<W1R(")686%T82!VY&QI<W0@=F5E8FEL96AT92(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(E9A871A(&MU:2`E<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM
M<V=S='(@(D)R:71I($YE:71S:7-A87)E9"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G
M:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(E5302!.96ET<VES
M86%R960B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.0IM<V=I9"`B5FES
M:6)I;&ET>2(*;7-G<W1R(").Y&AT879U<R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R
M(").Y&AT879U<SH@(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F
M;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I
M82!33510(@IM<V=S='(@(E9O9&%F;VYE($ET86QY(/QL92!33510(@H*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R(")(3TE!5%53(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@
M)7,N(@IM<V=S='(@(DA/24%455,A(2$@2U535%5402!32U))4%0@2\132513
M22!+051!3$]/1TE35"`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@
M(E=)3B#\;&4@2%144"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A
M;F0@1G5T=6YA(@IM<V=S='(@(E=A;&QI<R!J82!&=71U;F$B"@HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T
M=7,N<&AP.C(Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN
M<&AP.C(W,B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@(E=A<FYI
M;F<B"FUS9W-T<B`B2&]I871U<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(DMO(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T
M:&5R($9O<F5C87-T(@IM<V=S='(@(DEL;6%E;FYU<W1U<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,C<*;7-G:60@(E=E871H97(@9&%T
M82!P<F]V:61E9"!B>2(*;7-G<W1R("));&UA86YD;65I9"!P86MU8B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A=&AE<BYC
M;VTB"FUS9W-T<B`B5V5A=&AE<BYC;VTB"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(E9E96(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#,W"FUS9VED(")796(@4VET92(*;7-G<W1R
M(")6965B:7-A:70B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E
M;F%N8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B2V]R9"!NY&1A
M;&%S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@
M(E=E;&-O;64B"FUS9W-T<B`B5&5R92!T=6QE;6%S="(*"B,Z('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S
M='(@(E1E<F4@='5L96UA<W0@)7,M:2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M
M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R(")497)E('1U
M;&5M87-T+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED
M(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R("),Y.1N92`H25-/+3@X
M-3DM,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5V5S
M=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(DSDY&YE("A)4T\M.#@U.2TQ
M-2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T
M<B`B3.3D;F4M4V%H87)A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L
M9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R(")-:6QL:7-E(')A
M:V5N9'5S92!P96%K<R`E<R!PY')A<W0@<VES<V5L;V=I;6ES="!A=F%M83\B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA
M="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B36EL;&ES
M="!MY')K:2!K87-U=&%T86MS92!E<F%L9&%J86YA/R(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES('1H92!Q=6]T
M92!C:&%R86-T97(_(@IM<V=S='(@(DUI;&QI<W0@;>1R:VD@:V%S=71A=&%K
M<V4@:G5T=6WD<F=I;F$_(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$P-C$*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA
M<"(*;7-G<W1R(")7:&5R96ES($%U<W1R86QI82!K86%R="(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@
M(DUI;&QI<V5D(&9A87-I9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S,*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC
M:"!497AT(&5D:71O<BXB"FUS9W-T<B`B36EL;&ES96ED('!L=6=I;F%I9"!L
M=6)A9&$@4FEC:"!497AT(&5D:71O<FES+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H
M(@IM<V=S='(@(DQA:75S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$R-0IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(DQA:75S
M($-34R#\:&EK=71E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@
M=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S
M='(@(B5S(&UE;OS\(&QA:75S('9A<V%K=6P@*&AA:VMA8B!M]6IU;6$@:N1R
M9VUI<V5L('-I<W-E;&]G:6UI<V5L*3HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE
M('1A8FQE(@IM<V=S='(@(E1A8F5L:2!L86EU<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U
M;FET(@IM<V=S='(@(DQA:75S_&AI:R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T
M<B`B3&%I=7,Z(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q,PIM
M<V=I9"`B5VEK:2(*;7-G<W1R(")7:6MI(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV-0IM<V=I9"`B5VEN9"(*;7-G<W1R(")4=75L(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I
M;F0@16%R;'DB"FUS9W-T<B`B2&]M;6EK=6P@='5U;"(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS
M9W-T<B`B5'5U;&4@:VEI<G5S('/U;&UE9&5S(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ-38*;7-G:60@(E=I;F0Z(@IM<V=S='(@(E1U=6PZ(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T,@IM<V=I9"`B5VEN9#H@
M(@IM<V=S='(@(E1U=6PZ("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV
M-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(E1A<FMU<R(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ.38*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@
M(E-O;W9I;FEM96MI<FDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*
M;7-G:60@(E=O<FLB"FUS9W-T<B`B5/;V(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B
M"FUS9W-T<B`B5/;V:V]H82!A861R97-S(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*
M;7-G<W1R(")4]O9T96QE9F]N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z,38Y(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(V,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI
M;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B4F5A<R`E
M9"!O;B!V86QE(&%R=B!VY&QJ=2X@4&5A:W,@;VQE;6$@)60L(&%G82!O;B`E
M9"XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T
M960@)60L(&9O=6YD("5D+B(*;7-G<W1R(")686QE(&%R=B!VY&QJ=2X@4&5A
M:W,@;VQE;6$@)60L(&%G82!O;B`E9"XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HQ,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F
M<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B5F%L
M92!A;&=U<W!U;FMT("5D(%9&4R!F86EL:2!L=6=E;6ES96PN(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T,PIM<V=I9"`B6"U2968B"FUS9W-T
M<B`B6"U2968B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4Y,PIM<V=I9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@
M(E@U,#EV,R!P]6AI;&ES960@<&EI<F%N9W5D(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3(*;7-G:60@(E@U,#EV,R!%>'1E;F1E
M9"!+97D@57-A9V4B"FUS9W-T<B`B6#4P.78S(';U=&UE(&QA:65N9&%T=60@
M:V%S=71U<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3DT"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM
M<V=S='(@(E@U,#EV,R!S=6)J96MT:2!A;'1E<FYA=&EI=FYE(&YI;6DB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B
M6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B6#4P.78S
M('-U8FIE:W1I(';U=&UE(&ED96YT:69I:V%A=&]R(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#(*;7-G:60@(E@U,#EV,R!E>'1E
M;G-I;VYS(@IM<V=S='(@(E@U,#EV,R!L86EE;F1U<V5D(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(D%!(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,PHC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4U"FUS9VED(")9
M65E9(@IM<V=S='(@(D%!04$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3$P.`IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R
M(")986AO;R$@:V%A<G0B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I
M;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`B2V]R9"!A
M87-T87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")996UE;B(*;7-G<W1R(")*
M965M96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.38S"FUS9VED(")997,B"FUS9W-T<B`B2F%H(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@
M22!!9W)E92(*;7-G<W1R(")*86@L(&]L96X@;O5U<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A
M<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET
M8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R(")/;&5D(%1%2U-425)%6DE)
M34E3+B!+;/5P<V$@6SP^72!E="!M:6YN82!T86=A<VD@5UE325=91R!R97II
M:6UI+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HX,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M
M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R(")%:2!O;&4@;'5B871U9"!L
M=75A(')O:&ME;2!K=6D@)60@8FQO:VMI+B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,30Q,0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC
M871E9"XB"FUS9W-T<B`B4V$@96D@;VQE('-I<W-E(&QO9VET=60N(@H*(SH@
M9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(EEO
M=2!C86X@;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L
M;"!N86UE+B(*;7-G<W1R(")3:6YU('3D:7-N:6UI(&5I(';U:2!S:7-A;&1A
M9&$@)UQ<)R!MY')K:2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#4U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S4*;7-G:60@(EEO=2!D
M:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`B
M4V$@96D@<VES97-T86YU9"!K;W)R96MT<V5T(&4M<&]S=&D@86%D<F5S<VDN
M(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T
M:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@
M(@HB:6X@)7,N(@IM<V=S='(@(E-A(&5I('-E861N=60@:6UP;W)D:71U9"!F
M86EL:2!VY&QJ=2!V87-T879U<W-E("5S(';D;&IA9&5G82XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@(EEO=2!H879E(&)E96X@
M;&]G9V5D(&]U="XB"FUS9W-T<B`B4VEN9"!L;V=I=&D@=N1L:F$N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA
M=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@
M;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T
M:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*(E-A('!E860@<VES
M97-T86UA(&ME:'1I=F$@;6]B:6EL=&5L969O;FD@;G5M8G)I(&UI<R!S:7-A
M;&1A8B!A:6YU;'0@;G5M8G)E:60@(@HB:F$@;6EL;&4@86QG=7-E<R!V]6EB
M(&]L;&$@)RLG(')A:'9U<W9A:&5L:7-E('-U=6YA:V]O9&D@='5N;G5S96YA
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#@*;7-G:60@(EEO
M=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(E-A('!E
M860@<VES97-T86UA(&MO<G)E:W1S92!VY.1R='5S92XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O
M;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM
M<V=S='(@(DQI:71U;6ES92!L=6)A;6ES96MS('!E860@<V5A9&ES=&%M82!$
M871A5')E92!S_'-T965M:2XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C0U-@IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME
M;F0N(@IM<V=S='(@(E-A('!E860@<V5A9&ES=&%M82!61E,@<_QS=&5E;6DN
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@
M(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N
M('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R(")%;FYE('-A871M
M:7-T(&]L96MS('1A<FL@<')O8FQE96UI(&MI<FIE;&1A9&$N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B
M66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S
M('1O(@IM<V=S='(@(E-A('!E860@<VES97-T86UA(%523&D@:W5H=2!S964@
M;&EN:R!V:6ET86(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX
M,`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE
M=&5D+B(*;7-G<W1R(")096%D(&WDY')A;6$@:W5S='5T871A=F$@<V5R=F5R
M:2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO=2!M=7-T('-P
M96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(E!E860@
M;>3D<F%M82!K87-U=&%J86YI;64@;6ED82!T_&AJ96YD861A+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S
M97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B4&5A9"!MY.1R86UA(&MA<W5T
M86IA;FEM92!M:61A(&5E;6%L9&%D82XB"@HC.B!A9&UI;B]U<V5R+G!H<#HV
M,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B
M4&5A9"!MY.1R86UA(&MA<W5T86IA;FEM92!M:61A(&QI<V%D82XB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE
M('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B4&5A9"!MY.1R86UA(&MA
M<W5T86IA;FEM92!M:61A(&UU=71A+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R(")096%D(&WDY')A
M;6$@=&5G979U<V4L(&UI9&$@<V]O=FED('1E:&$N(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO
M=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B4&5A
M9"!S:7-E<W1A;6$@=75E(&MA=&5G;V]R:6$@;FEM92XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I
M9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E
M<B(*;7-G<W1R(")096%D('-I<V5S=&%M82!)=&%A;&EA('1E;&5F;VYI;G5M
M8G)I(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<V"FUS9VED(")9
M;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I
M;BXB"FUS9W-T<B`B4VEN=2`E<R!S97-S:6]O;B!O;B!A96=U;G5D+B!086QU
M;B!L;V=I('5U97-T:2!S:7-S92XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S
M='(@(E-I;G4@92UP;W-T:2!A861R97-S.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,3(*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T
M<B`B4VEN=2!S86%T:F$@86%D<F5S<SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<T(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G
M:60@(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`B4VEN=2!I;F9O(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@P"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC
M92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O
M=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS
M9W-T<B`B(@HB4VEN=2!I;G1E<FYE=&EA861R97-S(&]N("5S('-E<W-I;V]N
M:2!J;V]K<W5L(&UU=71U;G5D+B!4=7)V86QI<W5S92`B"B)T86=A;6ES96MS
M('!E860@=75E<W1I('-I<W-E(&QO9VEM82XB"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@
M(E-I;G4@;FEM:2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN
M8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E
M<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*
M(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M
M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD
M+B(*;7-G<W1R("(B"B)3:6YU(&%U=&5N=&EM:7-S_'-T965M(&5I(';U:6UA
M;&1A(&MA<W5T86IA:60@;&ES861A+B!+=6D@<V]O=FED($AO<F1E(&%B:6P@
M(@HB:V%S=71A:F%I9"!H86QL871A+"!P96%D(&MA<W5T86UA('1E:7-T<W5G
M=7-T(&%U=&5N=&EM:7-S_'-T965M:2XB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I
M;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R
M('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T
M:&5R(')E87-O;BXB"FUS9W-T<B`B(@HB4VEN=2!A=71E;G1I;6ES<_QS=&5E
M;2!E:2!V]6EM86QD82!K87-U=&%J871E(&YI;65K:7)J82!NY&AA+"!V]6D@
M;VX@<V5E("(*(G;U:6UA;'5S(&UI;F=I;"!M=75L('#U:&IU<V5L(';D;&IA
M(&S\;&ET871U9"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@
M=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E
M<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M
M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)3:6YU('9E96)I;&5H:71S
M96IA(&[D:6(@;VQE=F%T("5S('-E<W-I;V]N:2!J;V]K<W5L(&UU=71U;G5D
M+B!4=7)V86QI<W5S92`B"B)T86=A;6ES96MS('!E860@=75E<W1I('-I<W-E
M(&QO9VEM82XB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU,`IM<V=I9"`B
M66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*
M;7-G<W1R(")3:6YU('9E96)I;&5H:71S96IA(&5I(';U:6UA;&1A('-E9&$@
M;VUA9'5S="!K87-U=&%D82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P
M<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U
M<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N
M9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*(E-I;G4@=F5E8FEL96AI
M='-E:F$@96D@=O5I;6%L9&$@;FEI;6]O9&D@='+\:VMI9&$N(%9A:G5T82!T
M<OQK:VEM:7-E:W,@(@HB0V]N=')O;"M0(';U:2!#;VUM86YD*U`N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-PIM<V=I9"`B66]U<B!C=7)R96YT
M('1I;64@>F]N93HB"FUS9W-T<B`B4VEN=2!A:F%V]O9N9#HB"@HC.B!S97)V
M:6-E<R]P<F5F<RYP:'`Z.38*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET
M>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R(")3:6YU('9A:6ME:61E;G1I
M=&5E="!O;B!M=75D971U9"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,34X"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(E-I
M;G4@=F%I:V5I9&5N=&ET965T.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,#$*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R(")3:6YU('3D
M:65L:6L@;FEM:3HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HQ,#`P
M"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")3:6YU
M('-I<W-E;&]G:6UI;F4@;VX@865G=6YU9"XB"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE
M=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(E-I;G4@=75S("5S
M('-A;&%S]6YA(&]N.B`E<R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@
M(DUU=61A='5S960@;VX@<V%L=F5S=&%T=60@<V5L;&4@<V5S<VEO;VYI(&SU
M<'5N:2XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM
M<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R
M(")-=75D871U<V5D(&]N('-A;'9E<W1A='5D+B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B
M965N(')E<V5T(@IM<V=S='(@(E-I;G4@<V%L87/U;F$@;VX@=F%H971A='5D
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*
M(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA
M:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G
M<W1R("(B"B)3:6YU('-A;&%S]6YA(&]N('9A:&5T871U9"P@=F%A=&$@;VUA
M(&4M<&]S=&D@:F$@;&]G:2!S:7-S92!U=64@<V%L87/U;F%G82XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HW,S(*;7-G:60@(EEO=7(@<&%S<W=O
M<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(E-I;G4@<V%L87/U;F$@;VX@865G
M=6YU9"XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G
M:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(E-I;G4@=N1L:7-E
M9"!S97)V97)I9#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O
M<VQA=FEA(@IM<V=S='(@(DIU9V]S;&%A=FEA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B6F%I
M<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R(")386UB
M:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W92(*;7-G<W1R("):
M:6UB86)W92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B
M6FEP<'DB"FUS9W-T<B`B6FEP<'DB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT
M97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1
M=6]T960@5&5X=%TB"FUS9W-T<B`B6U!E:61A(&]S=6YD871U9"!T96MS=%TB
M"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX.`IM<V=I9"`B6U!R;V)L96T@
M4F5P;W)T72(*;7-G<W1R(");2&]R9&4@<')O8FQE96U=(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W
M(%%U;W1E9"!497AT("TB"FUS9W-T<B`B6T[D:71A(&]S=6YD871U9"!T96MS
M=&D@+2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI
M9VAT<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@
M475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B6T[D:71A(&]S=6YD
M871U9"!T96MS=&D@+2`E<R!R:61A72(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F
M("5S72(*;7-G<W1R(");<FED82`E<R`E<RUS=%TB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$U-#$@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN
M8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E](86QD=7,B
M"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`B2^1S
M=5]R:61A(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?1&%T851R964B
M"FUS9W-T<B`B7T1A=&%4<F5E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O
M=R(*;7-G<W1R(")?2W5S='5T82!R:61A(@H*(SH@;&EB+V%P:2YP:'`Z,3,S
M"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(E]'<G5P:60B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED(")?2&5L<"(*;7-G
M<W1R(")!7V)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN
M+B(*;7-G<W1R(")?4&EL9&D@;VUA9'5S960N+BXB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM<V=S
M='(@(E],;V=I('-I<W-E(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE
M;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B7TQO9VD@=N1L
M:F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R(")?
M375U9&$@;&EN:VDN+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N
M=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R(")?4V5A9&ES='5S
M(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS
M9W-T<B`BU6EG7W5S960B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN:RXN
M+B(*;7-G<W1R(")?165M86QD82!L:6YK+BXN(@H*(SH@;&EB+V%P:2YP:'`Z
M,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B7U!A:6=A;&1U<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B7U1A8F5L
M:2!O;6%D=7-E9"XN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R.0IM<V=I9"`B7U5S
M97)S(@IM<V=S='(@(E]+87-U=&%J860B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDR,0IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(F%A
M9')E<W-I<F%A;6%T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(F%D
M<F5S<V%A="!T=6YD;6%T=2(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3$S"FUS9VED(")C86QE;F1A<B(*;7-G<W1R(")K86QE;F1E<B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S4X"B,L('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B=F%I:VYE
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G
M:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B=N1L:G5N
M9&9A:6QI(&QO;VUI;F4@;G5R:G5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM
M<V=S='(@(G-I<V5N9&D@879A;6EN92!N=7)J=7,B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*;7-G:60@(F-L:6-K(&AE<F4B
M"FUS9W-T<B`B:VSU<'-A('-I:6$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R
M<F]R(@IM<V=S='(@(FOD<W5R96$@:V%S=71A;6ES92!V:6=A(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O;F9I
M9W5R871I;VX@97)R;W(B"FUS9W-T<B`B<V5A9&ES='5S92!V:6=A(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R
M:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B96QU=.1H=&ES
M('/\<W1E96UI9F%I;"!O;B!P=75D=2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*
M;7-G<W1R(")A;F1M971E(&9O<FUA861I('9I9V$B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+V5D:70N:6YC.C,P"FUS9VED(")E9&ET(@IM<V=S='(@(FUU=61A
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ.#(*;7-G
M:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R(")K86YN970@96D@;&5I='5D
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*
M;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B;&%N9V5B(@H*(SH@9G)A;65W;W)K
M+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4U"FUS9VED(")F:6QE(@IM<V=S='(@
M(F9A:6PB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L:6(O0FQO8VLO
M;65T87(N<&AP.C,V,"!L:6(O0FQO8VLO;65T87(N<&AP.C,X-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S
M='(@(G-U=6YD("5S("@E<RD@:F$@:VEI<G5S("5S("5S(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,`IM<V=I9"`B9W5S=&EN9R(*;7-G
M<W1R(")P=6AA;F=U;&EN92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR-#D*;7-G:60@(F@Z(@IM<V=S='(@(FLZ(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.`IM<V=I
M9"`B:&@B"FUS9W-T<B`B='0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T
M<B`B='5N9&UA='4@:&]S=&EN:6UI(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA
M=&4B"FUS9W-T<B`B=FEI=FET86UA='4B"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE
M(@IM<V=S='(@(FEN;&EN92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T
M<B`B<VES96YD+W;D;&IU;F0@=FEG82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E
M<G)O<B(*;7-G<W1R(")T87)K=F%R82!S965S;6EN92!V:6=A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI
M;F5S72(*;7-G<W1R(")R:61A72(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB
M"FUS9W-T<B`B;6MI<V]F<R!V96%K;V]D("5D($E33R!L;V]M:7-E;"XB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8Y"FUS
M9VED(")M;2(*;7-G<W1R(")M;2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,CDQ('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*
M(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(S,@IM<V=I9"`B;F%M
M92(*;7-G<W1R(")N:6UI(@H*(SH@9G)A;65W;W)K+U)00R]24$,N<&AP.C$R
M,0IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(G!O;&4@=&5O<W1A
M='5D(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y
M"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(G!O;&4@=F5E
M;"!T96]S=&%T=60B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP
M-0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R(")MY')K;6EK(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I
M9"`B<&5R8V5N="(*;7-G<W1R(")P<F]T<V5N=&DB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R;6ES<VEO;B!D
M96YI960B"FUS9W-T<B`B]6EG=7-E9"!P=75D=79A9"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@
M(G!I>&5L<R(*;7-G<W1R(")P:6MS;&ET(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P
M<F]T;V-O;"(*;7-G<W1R(")P<F]T;VMO;&QI('9I9V$@=&5I<V5S(&]T<V%S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*
M;7-G:60@(G)I<VEN9R(*;7-G<W1R(")T]75S96(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V
M86EL86)L92(*;7-G<W1R(")T965N=7,@<&]L92!KY'1T97-A861A=B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.3D*;7-G:60@(G-H;W<@9&EF9F5R
M96YC97,B"FUS9W-T<B`B;N1I=&$@97)I;F5V=7-I(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M
M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R(")S;7,R96UA:6P@_&QE($A45%`B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@U
M"FUS9VED(")S<R(*;7-G<W1R(")S<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B
M_&AT;&%N92(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`Y"FUS
M9VED(")S=VET8V@@;V9F(&IA=F%S8W)I<'0B"FUS9W-T<B`B;/QL:71A(&IA
M=F%S8W)I<'0@=N1L:F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(G/\<W1E
M96UI('9I9V$B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.0IM
M<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(OQL97-A;FYE=&4@;FEM96MI<FDB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I
M9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B86IU=&EN92!T]7)G92(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`U"FUS9VED(")T<GD@
M86=A:6XB"FUS9W-T<B`B<')O;W9I('5U97-T:2(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G
M:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T
M<B`B:VER:G5T82!S86QA<_5N82!E:W-I='5S92!VY&QT:6UI<V5K<R!K86MS
M(&MO<F1A(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T
M=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B_&AI=&%T
M=60B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP.C(W"FUS9VED
M(")U;FYA;65D(@IM<V=S='(@(FYI;65T=2(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E
M<B!S96QE8W0B"FUS9W-T<B`B:V%S=71A:F$@=F%L:6LB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D
M(@IM<V=S='(@(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(T,0IM<V=I9"`B=SHB"FUS9W-T<B`B;#HB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC
M;VTB"FUS9W-T<B`B=V5A=&AE<BYC;VTB"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]F85])4BYP;P``````
M````````````````````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`Q,#`U
M,S`S`#$P-3$U-#,S-S4T`#`Q-S8Q-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````C($AO<F1E(%!E<G-I86X@=')A;G-L871I
M;VYS+@HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M
M92!L:6-E;G-E(&%S('1H92!(;W)D92!P86-K86=E+@HC(`HC($-O<'ER:6=H
M="`H0RD@,C`P-"!(:6=H($-O;F-I;"!O9B!);F9O<FUA=&EC<R`H=W=W+G-H
M8VDN:7(I"B,@4')O=FED960@8GD@($%M:7)K86)I<B!-971A;F5T=V]R:VEN
M9R!,=&0L(#(P,#0@/'!E<G-I86XM:&]R9&5`;65T86YE='=O<FMI;F<N8V]M
M/@HC($UO:'-E;B!.861E<BU"861R("`@("`@(#QN861E<FE`;65T86YE='=O
M<FMI;F<N8V]M/@HC($-H86-K86UE:"!-;W)T97IA;FEA("`@(#QM;W)T97IA
M;FEA0&UE=&%N971W;W)K:6YG+F-O;3X*(R!386QM86X@3FEK<V5F870@("`@
M("`@("`\;FEK<V5F871`;65T86YE='=O<FMI;F<N8V]M/@HC($AA;65D($=H
M97EB:2`@("`@("`@("`@(#QG:&5Y8FE`;65T86YE='=O<FMI;F<N8V]M/@HC
M(%9A:&ED($=H869A<G!O=7(@("`@("`@(#QG:&%F87)P;W5R0&UE=&%N971W
M;W)K:6YG+F-O;3X*(R!:86AR82!!:&UA9&D@("`@("`@("`@("`\86AM861I
M0&UE=&%N971W;W)K:6YG+F-O;3X*(R`*;7-G:60@(B(*;7-G<W1R("(B"B)0
M<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,@7&XB"B)297!O<G0M37-G:60M
M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N
M+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM
M1&%T93H@,C`P-2TP-RTP."`Q-3HR-RLP,C`P7&XB"B),87-T+51R86YS;&%T
M;W(Z06UI<FMA8FER($UE=&%N971W;W)K:6YG(&QT9"X@/'!E<G-I86XM:&]R
M9&5`;65T86YE='=O<FMI;F<N(@HB8V]M/EQN(@HB3&%N9W5A9V4M5&5A;3H@
M4&5R<VEA;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I
M;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T
M/5541BTX7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`HV+'9B-BR(-F"
MV*C9A"`E<RDB"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@
M,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$S-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM
M<V=S='(@(BC:J=F$VXS8KR#8K]BSV*K8L=BSVXP@)7,I(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@
M*&EN("5S(&1A>7,I(@IM<V=S='(@(BC8K]BQ("5S(-BQV8C8LBDB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<S"FUS9VED("(@*'1O9&%Y*2(*
M;7-G<W1R("(@*-BGV878L=F(V+(I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,W-0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B("C9@=BQ
MV*_8IRDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<Q"FUS9VED
M("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B("C8K]N,V+'9B-BR*2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-38@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,V,0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-#`W"FUS9VED("(@870@(@IM<V=S='(@(B#8K]BQ("(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$U"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R("+;
MC-JI(-BTV*?8KMF'(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN
M<&AP.C(W,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES
M(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B)R5S)R#8I]F&V*K8KMBG
MV*@@V878N=BJV*C8L=N,(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+U)E9VES=')Y+G!H<#HV-3D*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+U)E9VES=')Y+G!H<#HQ,#0R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E
M9VES=')Y+B(*;7-G<W1R("(G)7,G(-BOV+$@V+'8K-N,V+/8JMBQ(-F'V8C8
ML=BO(-F^VXS:J=BQV*C9AMBOVXP@V8;8M-BOV8<@V*?8L]BJ(@H*(SH@9G)A
M;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B<E<R<@V*?8K-BQV*<@VJG9AMF&V*_9AR#8K]BQV*[8JB#9OMN,V*_8
MIR#9AMBTV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@
M,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]G<F]U<',N<&AP.C4V"B,L('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P
M<R!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B#8J-F'(-JOV+'9B-F'XH",V8?8
MI]N,(-BSV*?9A=BGV8;9AR#8I]BVV*?9@=F'(-BTV*\B"@HC(",M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M
M+B(*;7-G<W1R(")<(B5S7"(@V*C9AR#8L]BGV878I]F&V8<@V878K-F(V++B
M@(S9A]BG(-BGV+;8I]F!V8<@V+38KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G
M<W1R(")<(B5S7"(@V*?;C-BLV*?8KR#9AMBTV*_9AR#8J-F(V*\Z("5S+B(*
M"B,@"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E
M*2(*;7-G<W1R("(E+C)F34(@V*?8L]BJV8'8I]BOV8<@V+38K]F'(-BGV+(@
M)2XR9DU"(-F%V*S8I]BR("@E+C)F34(I(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A
M;F0@)7,B"FUS9W-T<B`B)60@)7,@V8@@)7,B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W
M"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S
M=V]R9"!E>'!I<F5S+B(*;7-G<W1R("+8I]BSV84@V+'9A=BR(-BTV878IR`E
M9"#8L=F(V+(@V*_;C-JOV+$@V878N=BJV*C8L2#8I]BSV*HN(@H*(R`C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`BV;[;C-BTPJW8
MJ-N,V8;;C"`E9"W8L=F(V++9AR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M
M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC
M92(*;7-G<W1R("(E<R`M(-BJV8C8K-F'(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HW,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M1FEN9V5R<')I;G0B"FUS9W-T<B`BV*?8J]BQ(-BGV8;:K]BTV*H@)7,B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S,@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,U"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S($M"(@IM<V=S='(@(MJIVXS9A-F(V*C8I]N,V*H@)7,B"@HC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M
M(PHC(`HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I
M<FUA=&EO;B(*;7-G<W1R("(E<R#8N=F%V83;C-BGV*H@V8;:K]F'V*_8I]BQ
MVXP@+2#8JMBCVXS;C-BO(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS
M,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(%-E='5P(@IM<V=S='(@(B#8L=BGV8<F(W@R,#!C.]BGV8;8K]BG
MV++;C"`E<R`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M,C8S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B
M)7,@V*O8J-BJ(-F&V*?9A2(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O
M("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!
M9W)E96UE;G0B"FUS9W-T<B`BV+38L=F(V+<@V*K9B-BGV8'9@B`E<R(*"B,@
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#(X(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-#DP"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-C4Q(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(E<R#8
MI]BR(-F"V*C9A"#9A=F(V*S9B-BO(-BGV+/8JB(*"B,@(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,34Y(&QI8B]";&]C:R]M971A<BYP:'`Z,38U(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C,Y"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S0U(&QI8B]";&]C:R]M971A<BYP:'`Z,S4Q"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S(-BOV+$@)7,@)7,B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O
M<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI
M<R!T:6UE+B(*;7-G<W1R("(B"B(E<R#8HMF%V*?8K]F'(-BGV*S8L=BGVXP@
MV+G9A=F$VXS8I]BJ(-F&VJ_9A]BOV*?8L=N,(-BGV8;8JMBNV*?8J"#8M-BO
MV8<@V*?8L]BJ+B#8K-BYV*C9AR#9A]BQ(-BYV879A-N,V*?8JMN,(-BQV*<@
MVJG9AR#9A]F%(-BGVJG9AMF(V88@(@HBV87;C.*`C-BNV8C8I]F'VXS8KR#8
MI]BLV+'8IR#:J=F&VXS8KR#8N=F$V*?9A=BJ(-BHV++9AMN,V*\B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S0P"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B5S(-F%V8C8L=BO(-F&VXS8
MI]BR(-BGV+/8JB(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D
M92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@V
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B)7,@
MV*_9@MN,V8+9AR(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T
M:6]N+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD
M+B(*;7-G<W1R("(E<R#9OMN,V*_8IR#9AMBTV*\B"@HC(`HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B5S(-BHV8<@)7,@V*?8LB`E<R(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(R"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(MJIV*K8I]BH
MVH;9A]F4(-BBV*_8L=BS("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*
M;7-G<W1R("+8JMF"V8C;C-F%("5S(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.
M;W1E<&%D(@IM<V=S='(@(B5S)W,@3F]T97!A9"(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3,P"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@
M5&%S:VQI<W0B"FUS9W-T<B`BV8'9A]BQV+/8JB#9B-BXV*?;C-F!("5S(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B
M"FUS9W-T<B`B)7,Z("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:'1M;"YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4
M:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O
M(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O
M<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I
M;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,V-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-#$P"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(MB,(-BHV*?8KR(*
M"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M
M(RTC"B,@"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@X(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S=&EN9R`E
M<R`E<R(*;7-G<W1R("+8C"#8J-BGV*\@)7,@)7,B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE
M(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`BV(P@V878JMBZVXS;C-BQ(-BGV+(@
M)7,@V*C9AR`E<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,CDT(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$R.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-S0Y"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B(-BGV8;8JMBN
MV*?8J"`B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO
M=7(@1F]R;6%T(@IM<V=S='(@(MF"V*?9A-BH(-NQV[(@V+/8I]BYV*K;C"(*
M"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M
M870B"FUS9W-T<B`BV8+8I]F$V*@@V[+;M"#8L]BGV+G8JMN,(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S
M='(@(MNRV[0@V+/8I]BYV*K9AR(*"B,Z(&9R86UE=V]R:R]522]522]086=E
M<BYP:'`Z-CD*(RP@9G5Z>GD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("+8
MM=F!V*W9AR#9@MBHV83;C"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y
M"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H
M:7,@8FQO8VLN(@IM<V=S='(@(MN,VJD@V;[8M-BJVXS8J-BGV88@V*_8I]BO
MVJ_8I]F&(-BHV+'8I]N,(-BGVXS9AB#8J-F$V*?:J2#9A=F(V+'8KR#9AMN,
MV*?8LB#8I]BSV*HB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V
M,`IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B
MVXS:J2#8KMBWV*?;C"#8K-BOVXP@V+'8KB#8K]BGV*_9AR#8I]BSV*HB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@
M<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A
M9V4N(@IM<V=S='(@(MN,VJD@VJG9A-N,V*\@V+G9A=F(V87;C"!01U`@V*C8
ML=BGVXP@V+'9A=BRV*C9AMBOVXP@VXS:J2#9OMN,V+K8I]F%(-F%V8C8L=BO
M(-F&VXS8I]BR(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$Q-C4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER
M960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(MN,VJD@
MVJG9A-N,V*\@V+G9A=F(V87;C"!01U`@V*C8L=BGVXP@V*C8I]BRV*C;C-F&
MVXP@VXS:J2#9OMN,V+K8I]F%(-BGV878MMBGV*$@V+38K]F'(-F%V8C8L=BO
M(-F&VXS8I]BR(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$P.3<*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A
M=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E
M8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B+;C-JI(-JIV83;C-BO
M(-BYV879B-F%VXS8C"#;C-JI(-JIV83;C-BO(-BNV+79B-BUVXP@4$=0(-F(
M(-N,VJD@V+G8J-BGV+'8JB#:K]BPV+$@V*C8L=BGVXP@V+'9A=BRVJ_8M-BG
MVXS;C"#;C-JI(-F^VXS8NMBGV84@V879B-BQV*\@(@HBV8;;C-BGV+(@V*?8
ML]BJ(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Q-0IM
M<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE<W-A
M9V4N(@IM<V=S='(@(B(*(MN,VJD@VJG9A-N,V*\@V+G9A=F(V87;C-B,(-N,
MVJD@VJG9A-N,V*\@V*[8M=F(V+7;C"!01U`@V8@@VXS:J2#8N=BHV*?8L=BJ
M(-JOV+#8L2#8J-BQV*?;C"#8I]F%V+;8I]BA(-N,VJD@V;[;C-BZV*?9A2#9
MA=F(V+'8KR`B"B+9AMN,V*?8LB#8I]BSV*HB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4P-0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-
M24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@
M(B(*(MN,VJD@VJG9A-N,V*\@V+G9A=F(V87;C-B,(-N,VJD@VJG9A-N,V*\@
MV*[8M=F(V+7;C"!3+TU)344@V8@@VXS:J2#8N=BHV*?8L=BJ(-JOV+#8L2#8
MJ-BQV*?;C"#8L=F%V++:K]BTV*?;C-N,(-F^VXS8NMBGV84@V879B-BQV*\@
M(@HBV8;;C-BGV+(@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL
M('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"B+;C-JI(-JI
MV83;C-BO(-BYV879B-F%VXS8C"#;C-JI(-JIV83;C-BO(-BNV+79B-BUVXP@
M4R]-24U%(-F((-N,VJD@V+G8J-BGV+'8JB#:K]BPV+$@V*C8L=BGVXP@V*?9
MA=BVV*?8H2#;C-JI(-F^VXS8NMBGV84@V879B-BQV*\@(@HBV8;;C-BGV+(@
MV*?8L]BJ(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS
M-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`BVXS:J2#:J=F$VXS8KR#8N=F%
MV8C9A=N,(%,O34E-12#8J-BQV*?;C"#8L=F%V++8J-F&V*_;C"#9OMN,V+K8
MI]F%(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8JB(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*(RP@9G5Z>GD*;7-G:60@(D%-
M($-L;W5D<R(*;7-G<W1R("+8I]BHV+'9A]BG(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A
M:6XB"FUS9W-T<B`BV*C8I]BQV*?9AB#8L]BHVJD@V+78J-BMVJ_8I]F'VXPB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM
M<V=I9"`B04T@4F%I;B(*;7-G<W1R("+8J-BGV+'8I]F&(-BUV*C8K=JOV*?9
MA]N,(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`BV+':K]BHV*?8L2#8M=BH
MV*W:K]BGV8?;C"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`BV*K:
MK]BQVJ\@V+78J-BMVJ_8I]F'VXPB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE
M+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`BV+78J-BM+]BYV+78L2(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H
M:7,@961I=&]R(@IM<V=S='(@(MBOV+'8J-BGV+'9AR#8I]N,V88@V8C;C-BQ
MV*?8L]BJV*?8L2(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4R"FUS
M9VED(")!8F]U="XN+B(*;7-G<W1R("+8K]BQV*C8I]BQV8<N+BXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS9VED
M(")!8G-B;W1T;VTB"FUS9W-T<B`BV;[8I]N,VXS9AB#9A=BWV839@B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G
M:60@(D%B<VUI9&1L92(*;7-G<W1R("+9B-BSV+<@V878M]F$V8(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@
M9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(MBGVXS8
MK-BGV*\@V+38I]BNV8<@5D93(-F%V*S9B-BR(-BOV+/8JMBQV+/;C"#9AMBO
MV*?8L=BO(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$S-@IM
M<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T
M<B`BV*?;C-BLV*?8KR#9OMBQV8C9AMBOV8<@5D93(-F%V*S9B-BR(-BOV+/8
MJMBQV+/;C"#9AMBOV*?8L=BO(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C,*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`BV*?8M]F$
MV*?8N=BGV*H@V*W8L]BGV*@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-S4*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`BV*?8L]F%(-BQ
MV878LB#8K=BSV*?8J"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM
M<V=S='(@(MBMV+/8I]BH(-F%V+/8K]F(V*\B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S,S"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(MBM
MV+/8I]BHV*_8I]BQVXPB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$T."!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D9"(*
M;7-G<W1R("+8I]BVV*?9@=F'(-JIV+'8K]F&(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL
M9"!'<F]U<"(*;7-G<W1R("+8I]BVV*?9@=F'(-JIV+'8K]F&(-JOV+'9B-F'
M(-F!V+'8N=N,(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY
M."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY"FUS9VED(")!9&0@
M0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R("+8I]BVV*?9@=F'(-JIV+'8K]F&
M(-F%V*S9B-BR(-F!V+'8N=N,XH",(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A
M9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R("+8I]N,V8;8K-BG
M(-BGV+;8I]F!V8<@VJG9ACHB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A
M9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G
M<W1R("+8I]BVV*?9@=F'(-JIV+'8K]F&(-JOV+'9B-F'(-BLV*_;C-BO(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I
M;VXB"FUS9W-T<B`BV*?8MMBGV8'9AR#:J=BQV*_9AB#9A=BLV8C8LB#8K-BO
MVXS8KR(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC
M.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R
M;W5P('1O(%PB)7-<(B(*;7-G<W1R("+8I]BVV*?9@=F'(-JIV+'8K]F&(-N,
MVJD@VJ_8L=F(V8<@V8'8L=BYVXP@V*C9AR`G)7,G(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`BV*?8
MMMBGV8'9AR#:J=BQV*_9AB#;C-JI(-F%V*S9B-BR(-F!V+'8N=N,(-BHV8<@
M7"(E<UPB(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE
M=R!U<V5R.B(*;7-G<W1R("+8I]BVV*?9@=F'(-JIV+'8K]F&(-N,VJD@VJG8
MI]BQV*C8L2#8K-BOVXS8KSHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-34T"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@
M(MBGV+;8I]F!V8<@VJG8L=BOV88@V+/8JMF(V88B"@HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E
M<G,B"FUS9W-T<B`BV*?8MMBGV8'9AR#:J=BQV*_9AB#8I]BYV+;8I]N,(-BL
MV*_;C-BO(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I
M9"`B061D('!A:7(B"FUS9W-T<B`BV*?8MMBGV8'9AR#:J=BQV*_9AB#8LMF(
MV*PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8W"B,L('!H<"UF;W)M
M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A
M<B(*;7-G<W1R("(@V*?8MMBGV8'9AR#:J=BQV*_9AB#:K]BRVXS9AMJOV*?9
MAB`E<R#8J-BYV8;9B-BGV88@V8;9B-BGV+$@V*S8I]F&V*C;C"#9A=F(V++;
MC-F$V*<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z-S$*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(MBG
MV+;8I]F!V8<@VJG8L=BOV88@V*C9AR#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8
MLSHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`BV*?8
MMMBGV8'9AR#:J=BQV*_9AB#8J-F'(-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS
M(-F%V88B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D('5S97(B
M"FUS9W-T<B`BV*?8MMBGV8'9AR#9@]BQV*_9AB#:J=BGV+'8J-BQ(@H*(R`C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*
M(R`*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U
M;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB
M)7,N(@IM<V=S='(@(B(*(B<E<R<@V*C9AR#8L]BGV878I]F&V8<@V*?8MMBG
MV8'9AR#8M-BOV(P@V*?9A=BG(-F&V87;C.*`C-BJV8C8I]F&(-BGV+?9A-BG
MV+G8I]BJ(-BOVXS:K]BQ(-BGV8'8JMBJV*?8K2#8K=BSV*?8J"#8L=BG(-BG
MV+;8I]F!V8<@VJG8L=BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@<VEG;G5P+G!H<#HT-0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H92!S
M>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B)R5S)R#8J-F'
M(-BSV*?9A=BGV8;9AR#8I]BVV*?9@=F'(-BTV*\N(-BGVJG9AMF(V88@V+39
MA=BG(-F%VXSB@(S8JMF(V*?9AMN,V*\@V8C8I]BQV*\@V+39B-N,V*\B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D
M:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("+8I]BVV*?9@=F'(-JI
MV+'8K]F&(-JIV*?8L=BHV+'8I]F&(-F!V+G8I]F$(-F&VXS8L]BJ(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#$*;7-G:60@(D%D9')E<W,B"FUS9W-T
M<B`BV*+8K]BQV+,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,Y
M"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`BVJG8JMBGV*C:AMF'V90@
MV*+8K]BQV+,@(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E
M(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES
M<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(MBSV+'9OMBQV+/8JB#8
ML]BGV878I]F&V8<M(-BJV+G;C-N,V88@V878K-F(V++9A]BGVXP@VJG8I]BQ
MV*C8L=BGV88@V*_;C-JOV+$B"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R
M871I;VXB"FUS9W-T<B`BV+/8L=F^V+'8L]BJVXPB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S0Q"FUS9VED(")!9',B"FUS9W-T<B`BV*K8J-F$
MVXS8NMBGV*HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4V"B,L(&9U>GIY"FUS9VED(")!9F=H86YI
M<W1A;B(*;7-G<W1R("+8L]BGV++9A=BGV88B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"B,L(&9U
M>GIY"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(MF%V+G8I]BOV80B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<P"B,L(&9U>GIY"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(MF%V+G8
MI]BOV80B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R("+9A=BYV*?8K]F$(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ
M-@IM<V=I9"`B06QI9VXB"FUS9W-T<B`BV*K8L=BGV+(@VJG8L=BOV88B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS
M9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(MBJV+'8I]BR.B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(MF'V879
MAR(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C`W('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A
M=&5D(%5S97)S(@IM<V=S='(@(MBJV878I]F%VXP@VJG8I]BQV*C8L=BGV88@
MV*K8H]N,VXS8KR#8M=F$V*?8K=N,V*H@V+38K]F'(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I9"`B06QL($=R
M;W5P<R(*;7-G<W1R("+9A]F%V8<@VJ_8L=F(V8?B@(S9A]BG(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O9&%T871R964N<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`BV8?9A=F'(-F%V*S9B-BRXH",V8?8IR(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@
M(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(MF'V879A]F4(-J&V8?8I]BQ(-BS
MV878JB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S$*;7-G:60@
M(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R("+8I]BLV*?8LMF'
M(-J&V8;8KR#8HMBOV+'8L]N,(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4S-`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP
M93\B"FUS9W-T<B`BV*+;C-BG(-BGV*S8I]BRV8<@V*K9AMBXVXS9A2#9AMF(
MV+D@V8'9A]BQV+/8JB#9A=BQV*K8J"#8K]BGV*_9AR#8M-F(V*_8GR(*"B,Z
M(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I
M9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`BV*?8LB#9@MBHV80@V879B-BL
MV8C8KR#8I]BSV*HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(S"FUS
M9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R("+9B-BQV8C8KR!)
M35-0(-BLV*?;C-JOV++;C-F&(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4P-PIM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B
MV*?8L]F%(-BQV878LB!)35-0(-BLV*?;C-JOV++;C-F&(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0Y.0IM<V=I9"`B06QT97)N871E($E-4U`@57-E
M<FYA;64B"FUS9W-T<B`BV8;8I]F%(-JIV*?8L=BHV+';C"!)35-0(-BLV*?;
MC-JOV++;C-F&(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*
M;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(MBBV*_8
ML=BS(-F^V+/8JB#8I]F$VJG8JMBQV8C9AMN,VJD@V*S8I]N,VJ_8LMN,V88B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N871E
M('1E;7!L871E<R(*;7-G<W1R("+8I]F$VJ_9B.*`C-F'V*?;C"#8K-BGVXS:
MK]BRVXS9AB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM
M<V=S='(@(MF%V*K9AB#8K-BGVXS:K]BRVXS9ACHB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS
M9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I
M960N(@IM<V=S='(@(MN,VJD@V879@MBOV*?8L2#9AMBGV*_8L=BSV*H@V*K8
MN=N,VXS9AB#8M-BOV8<@V*C9B-BO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$V-PHC+"!F=7IZ>0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O
M<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`BVXS:J2#8KMBWV*?;C"#8K-BOVXP@
MV+'8KB#8K]BGV*_9AR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O
M<G)A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!
M;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`BV;[;C-BTVJG8I]BQ(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G
M<W1R("+9OMBGV+/8KB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R
M8G5D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D
M;6EN+W!H<'-H96QL+G!H<#HS-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M54DN<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*
M;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(MBHV+'9AMBGV879A]F4XH",
M(-JIV*?8L=BHV+'8K]N,(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R
M"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@(MF!V8?8L=BSV*H@
MV*C8L=F&V*?9A=F'XH",V8?8I]N,(-JIV*?8L=BHV+'8K]N,(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@
M<F5A9'DN(@IM<V=S='(@(MBHV+'9AMBGV879AR#8HMF%V*?8K]F'(-BGV+/8
MJB(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!
M<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`BV*?8N=F%V*?9A"#8J-BQ
M(-BQV8C;C"#8I]BTV*K8L=BGVJG9A]BGVXP@V8'8L=BYVXPB"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V
M92(*;7-G<W1R("+8JMBUV8C;C-BH(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z.#,S"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM
M<V=S='(@(MBGV8;8K]BGV++9AR#8JMF"V+';C-BHVXPB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB
M"FUS9W-T<B`BV*+9B-BQVXS9A"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B07)A
M8FEC("A7:6YD;W=S+3$R-38I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#$*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(MBGV8;8
MK]BGV++9AR#9OMBQV8C9AMBOV8<@V*+8L=BTVXS9B"(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C@P"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T
M<B`BV8;8I]F%(-BBV+'8M-N,V8@B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F5Q=65U960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@(D%R
M92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U
M97-T(&9O<B`E<R`_(@IM<V=S='(@(MBBVXS8IR#8M-F%V*<@V878M]F%V*;9
MAMN,V*\@VJG9AR#9A=N,XH",V*[9B-BGV8?;C-BO(-BGV+?9A-BGV+G8I]BJ
M(-BGV8'8JMBJV*?8K2#8K=BSV*?8J"`E<R#8L=BG(-F^V*?:J2#:J=F&VXS8
MK]B?(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C
M+2,M(RTC+2,*(R`*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N
M:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R
M92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P
M<S\B"FUS9W-T<B`BV*+;C-BG(-BTV878IR#9A=BWV878IMF&VXS8KR#:J=F'
M(-F%VXSB@(S8KMF(V*?9A]N,V*\@)R5S)R#9B"#8JMF%V*?9A2#8LMN,V+$@
MVJ_8L=F(V8?B@(S9A]BGVXS8M"#8L=BG(-BMV+#9@2#:J=F&VXS8K]B?(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM
M<V=S='(@(D%R;65N:6%N("A!4DU30TE)+3@I(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`BV8?9AMBQ(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@
M(D%S8VEI($%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R-0IM<V=I9"`B07-K
M(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,_(@IM<V=S='(@(MBBVXS8IR#9@MBHV80@V*?8LB#8N=F%V83;
MC-BGV*H@V8;:K]F'V*_8I]BQVXP@V*C8L=BGVXP@V*K8H]N,VXS8KR#8HMF&
M(-BSV*;9B-BGV80@V+39B-BOV)\@(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S$Q,PIM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@
M(MBGV8;8JMBSV*?8J"#8L]BJV8C9AMF'V*<B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N
M="!G<F]U<"XB"FUS9W-T<B`BV+/8N=N,(-BOV+$@V*W8L-F!(-JOV+'9B-F'
MVXP@V+38K]F'(-BGV+/8JB#:J=F'(-F%V8C8K-F(V*\@V8;;C-BSV*HB"@HC
M.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("+8
ML]BYVXP@V*_8L2#8K=BPV8$@V878K-F(V++;C"#8M-BOV8<@V*?8L]BJ(-JI
MV8<@V879B-BLV8C8KR#9AMN,V+/8JB(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N
M<&AP.C@W"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@
M<&5R;6ES<VEO;BXB"FUS9W-T<B`BV+/8N=N,(-BOV+$@V8C;C-BQV*?;C-BT
M(-F%V*S9B-BRVXP@V+38K]F'(-BGV+/8JB#:J=F'(-F%V8C8K-F(V*\@V8;;
MC-BSV*HB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@
M(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T
M<B`BV+/8N=N,(-BOV+$@V8C;C-BQV*?;C-BT(-BGV+38JMBQV*?:J=N,(-BT
MV*_9AR#8I]BSV*H@VJG9AR#9A=F(V*S9B-BO(-F&VXS8L]BJ(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#8*;7-G:60@(D%T=')I8G5T97,B"FUS
M9W-T<B`BXH",V8C;C-J8VJ_;C-F'V*<B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@
M(MBBVJ_9B-BSV*HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B075S=')I82(*
M;7-G<W1R("+8HMJOV8C8L]BJ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM
M87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)S<6PZ
M(-BHV+/8MR#9A=F(V+'8KR#9AMN,V*?8LB!)34%0(-F^VXS8K]BG(-F&V+38
MKR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I
M9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D
M(&-A<&%B:6QI=&5S+B(*;7-G<W1R(")!=71H7V-Y<G-Q;#H@V+/8I]F%V*?9
MAMF'(-F^V+38JMN,V*C8I]F&(-F"V*?8J-F$VXS8JMF'V*?;C"#9A=F(V+'8
MKR#9AMN,V*?8LB#8L=BG(-F&V*_8I]BQV*\B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I
M<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:&EM
M<#H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR($E-05`@V;[;C-BOV*<@V8;8
MM-BO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C,V"FUS9VED
M("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET
M8V@N(@IM<V=S='(@(D%U=&A?9G1P.B#8J-BSV+<@V879B-BQV*\@V8;;C-BG
MV+(@1E10(-F^VXS8K]BG(-F&V+38KR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM<#H@V*C8
ML]BW(-F%V8C8L=BO(-F&VXS8I]BR($E-05`@V;[;C-BOV*<@V8;8M-BO(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T
M:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%U=&A?:W)B-3H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR(&MR
M8C4@V;[;C-BOV*<@V8;8M-BO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@
M(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F
M;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E<75I
M<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]L
M9&%P.B#8J-BSV+<@V879B-BQV*\@V8;;C-BGV+(@3$1!4"#9OMN,V*_8IR#9
MAMBTV*\B"@HC(`HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,S
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A
M9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM
M<V=S='(@(B(*(D%U=&A?;&1A<#K8I]BVV*?9@=F'(-JIV+'8K]F&(-JIV*?8
ML=BHV+$@)7,@V879A=JIV88@V8;;C-BSV*HN(-BGVXS9AB#:AMN,V++;C"#8
MI]BSV*H@VJG9AR#:J=BGV+'8L]BGV+(@VJ_9@=BJV8<@V*?8L]BJ(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B
M"FUS9W-T<B`B075T:%]L9&%P.MBMV+#9@2#:J=BGV+'8J-BQ("5S(-F%V87:
MJ=F&(-F&VXS8L]BJ("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE
M('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#K8J-BQV8C8
MLMBQV+/8I]F&VXP@VJG8I]BQV*C8L2`E<R#9A=F%VJG9AB#9AMN,V+/8JB(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!
M=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R
M($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER
M960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VUC
M86PZ(-BHV+/8MR#9A=F(V+'8KR#9AMN,V*?8LB!-0T%,(-F^VXS8K]BG(-F&
MV+38KR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV,`IM<V=I
M9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?<VUB875T:#H@V*C8L]BW(-F%V8C8
ML=BO(-F&VXS8I]BR('-M8F%U=&@@V;[;C-BOV*<@V8;8M-BO(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS
M9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`BV*K8M=BOVXS9
M@B#9A]F(VXS9D=BJ(-F&V*?9A=F(V8'9D=F"(-BHV8C8KR(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L
M('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B
M"FUS9W-T<B`BV*K8M=BOVXS9@B#9A]F(VXS9D=BJ(-F&V*?9A=F(V8'9D=F"
M(-BHV8C8KRX@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP
M:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)
M55,@<V5R=F5R+B(*;7-G<W1R("+8JMBUV*_;C-F"(-F'V8C;C-F1V*H@V*?8
MLB#8M]BQV8$@VJG8I]BQV+/8I]BR(%)!1$E54R#8L=BO(-BTV*_9AR#8I]BS
MV*HB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U,0IM<V=I9"`B
M075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@
M(MBJV+78K]N,V8(@V8?9B-N,V9'8JB#8K]BQ(-JIV*?8L=BSV*?8LB!&5%`@
MV8;8I]F%V8C9@=F1V8(@V*C9B-BO("(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O
M('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`BV*K8M=BOVXS9@B#9
MA]F(VXS9D=BJ(-BOV+$@VJG8I]BQV+/8I]BR($944"#9AMBGV879B-F!V9'9
M@B#8J-F(V*\@(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM
M<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`BV8';C-F$V*_9A]BG
MVXP@V8+8I]BHV80@V*_8L]BJV+'8L]N,.B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@
M(D%Z97)B86EJ86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM
M<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R("+9OMBSXH",V++9A=N,V8;9AR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*
M;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`BV+'9AMJO(-F^V+/B
M@(S8LMF%VXS9AMF'(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H
M<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R("+8
MI]BSV84@V+'9A=BR(-F&V*?8K]BQV+/8JB!K97)B97)O<R(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O
M<R!U<V5R;F%M92XB"FUS9W-T<B`BV8;8I]F%(-JIV*?8L=BHV+$@V8;8I]BO
MV+'8L]BJ(&ME<F)E<F]S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")"86AR86EN
M(@IM<V=S='(@(MBMV*?8M-N,V8<B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W-PIM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B0F%L
M=&EC("A)4T\M.#@U.2TQ,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D
M97-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM
M<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BV+38I]BNV8<@VJ_8L=BGV8';
MC-JIVXP@V878J-F&V*?;C"`G)7,G(-N,V*?9@=BJ(-F&V+38KR(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM
M<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`BV*[8MR#9A=BHV8;8IR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM
M<V=I9"`B0F5L9VEU;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"B,L(&9U>GIY
M"FUS9VED(")"96QI>F4B"FUS9W-T<B`BV*[8MR#9A=BHV8;8IR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(D)E;FEN(@IM<V=S='(@(MJOV+'8K]F'
MV878I]N,VXPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED
M(")":7)T:&1A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO0V]L;&5C=&EO;BYP:'`Z,S4S"B,L('!H<"UF;W)M870*;7-G:60@(D)L
M;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R("+8J-F$V8C:J2!<(B5S7"(@V*?8LB#8J-BQV8;8I]F%V8?9E"#:
MJ=BGV+'8J-BQV*_;C"!<(B5S7"(@VXS8I]F!V*H@V8;8M-BO(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C@Y"FUS9VED(")";&]C:R!3971T
M:6YG<R(*;7-G<W1R("+8JMF&V+C;C-F%V*?8JB#8J-F$V8C:J2(*"B,Z('1E
M;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP
M92(*;7-G<W1R("+9AMF(V+D@V*C9A-F(VJDB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T
M<B`BV+/;C-BGV8<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#4*;7-G:60@
M(D)O;VMM87)K<R(*;7-G<W1R("+:AMF(V*@@V*?9A-F!(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I
M9"`B0F]R9&5R(@IM<V=S='(@(MF$V*C9AR(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC
M:VYE<W,Z(@IM<V=S='(@(MF^V8?9AMBGVXP@V838J-F'.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G
M:60@(D)O<F1E<G,B"FUS9W-T<B`BV838J-F'XH",V8?8IR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")";W1H(@IM<V=S
M='(@(MF'V+$@V*_9B"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(MF^V*?;C-N,
MV88B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@27-L86YD(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(D)R87II;"(*;7-G<W1R
M("+9AMBGV879AR#8I]F$VJG8JMBQV8C9AMN,VJG;C"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q
M"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R("+9A-N,V+/8JB#8J-F(
MV838JN*`C-BOV*?8L2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S
M;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U;F1I(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#0*;7-G:60@
M(D--4R(*;7-G<W1R(")#35,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-2
M3"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(MF&V8+8I]BW(-BJV8C8
MLMN,V+D@0U),(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN
M(@IM<V=S='(@(MBNV+79B-BUVXS8I]BJ(-BSV839B-F$+BXN(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,PHC+"!F=7IZ>0IM<V=I9"`B
M0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`BV8'9A]BQ
MV+/8JB#8JMF(V++;C-BYVXP@V878M-BNV+4@V8;8M-BOV8<@V*?8L]BJ(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-"!C
M;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ-34*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(MBJV8+9B-N,
MV84B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0V"FUS9VED
M(")#86QM(@IM<V=S='(@(MBBV+'8I]F%(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@
M(D-A;6)O9&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G
M:60@(D-A;65R;V]N(@IM<V=S='(@(MF%V*_;C-BQ(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S
M<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(N(@IM<V=S='(@(B(*(MF&V87;C.*`C-BJV8C8I]F&(-BGV+/9A2#8L=F%
MV+(@V+'8IR#8J-BWV8C8L2#8KMF(V*_:J=BGV+$@V*_9B-BHV*?8L=F'(-BH
MV*?8LMF&V+38I]F&V*_8C"#8J-BG(-BSV+'9OMBQV+/8JB#8L]BGV878I]F&
MV8<@V*[9B-BO(-BJV878I]BS("(*(MBHVJ_;C-BQVXS8KR(*"B,Z(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(MF&V87;
MC.*`C-BJV8C8I]F&(-BOV+$@V;[8L=F(V8;8K]F'(%PB)7-<(B#9AMF(V+38
MJB(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M
M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,S4@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R
M("+9AMF%VXSB@(S8JMF(V*?9AB#8J-F'(-JIV*?8L=BSV*?8LB#9OMBSV*H@
MV*?9A-JIV*K8L=F(V8;;C-JI(-F%V*K8M=F$(-BTV*\Z("5S(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#$S"B,L('!H<"UF;W)M870*;7-G
M:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(MF&V87;C.*`
MC-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!<(B5S7"(@V+'8IR#8J-BGV+(@VJG8
ML=BO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-`HC+"!F=7IZ>0IM<V=I9"`B0V%N861A(@IM<V=S
M='(@(MBJV8+9B-N,V84B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO
M=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI
M;F,Z,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E
M;"(*;7-G<W1R("+8I]F&V+78L=BGV8$B"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T
M(@IM<V=S='(@(MBGV8;8M=BQV*?9@2#8I]BR(-BGV+'8L]BGV80@VJ_8LMBG
MV+'8M"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$X"B,L('!H
M<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!<(B5S7"(@
MV+'8IR#8K=BPV8$@VJG8L=BO("`B"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P
M=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T
M96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9
MAB#;C-JI(-BTV*?8KMF'(-F%V8C9@MBJ(-F^VXS8K]BG(-JIV+'8KR(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G
M:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M
M971E<BXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V*C8K]F(V88@V;[8
MI]BQV*?9A=BJV+$@)]F^V+'9B-F&V*_9AR#9A=F"V+78KR<@V*?8K]BGV879
MAR#8K]BGV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@
M,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C,Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C
M=&]R>2!<(B5S7"(N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BTV*?8
MKMF'(%PB)7-<(MBQV*<@V*W8L-F!(-JIV+'8KR`B"@HC.B!F<F%M97=O<FLO
M1&%T851R964O1&%T851R964N<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O
M1&%T851R964O<W%L+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(MF&V87;
MC.*`C-BJV8C8I]F&(-BMV+#9@2#9AMF%V8C8K]B,("5D(-F!V+'8LMF&V*\@
MV879B-BLV8C8KR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T
M851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N
M=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO
M="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"B+9AMF%VXSB
M@(S8JMF(V*?9AB#8K]F(V*C8I]BQV8<@V878L=BJV*@@V8;9A=F(V*_8C"#8
MJ-BQV*[;C"#8I]BR(-F(V+'9B-BOVXS9A]BGVXP@V8'8L=BGV8?9A2#8M-BO
MV8<@V*C8L=BGVXP@V878L=BJV*@@V+/8I]BRVXP@V*C8IR`B"B+8M-F%V*?8
ML=F'XH",V8?8I]N,(-BPV*[;C-BQV8<@V+38K]F'V(P@V+/8I]BRVJ_8I]BQ
M(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T
M;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9
MAB#9OMN,V+K8I]F%(-BQV*<@V*C9AR#8M-F%V*?8L=F'(-BJV+G;C-N,V88@
MV+38K]F'(-JOV+#8L2#8K]BGV*\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E
M(%9E<F1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*;7-G:60@(D-A<'1I;VXB"FUS9W-T
M<B`BV+G9AMF(V*?9AB(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE
M<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*;7-G<W1R("+8K=BG
MV879A"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I9"`B0V%T
M96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(MJOV+'9B-F'XH",V8?8IR#9
MB"#8J-BQVH;8L]BHV8?8IR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#87EM86X@
M27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@
M(MF%V8C8J-BGVXS9A"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*
M;7-G<W1R("+8KMBUV8C8M=N,V*?8JB#8L]F$V8C9A"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL
M('!A9&1I;F<Z(@IM<V=S='(@(MF!V*?8M=F$V8<@V+/9A-F(V80B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q
M"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`BV*[8M=F(V+7;C-BG
MV*H@V+/9A-F(V80B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("+9
M@=BGV+79A-F'XH",VJ_8L-BGV+';C"#8L]F$V8C9A"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R-S0*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R
M("+9A=F(V*C8I]N,V80B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM
M<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B0V5L=&EC("A)
M4T\M.#@U.2TQ-"DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T<B`BV878
ML=JIV+(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P
M=6)L:6,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*
M;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@
M(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.3D*;7-G:60@(D-E<G1I9FEC871E
M($1E=&%I;',B"FUS9W-T<B`BV*S8LMBFVXS8I]BJ(-JOV8C8I]F'VXP@(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3$*(RP@9G5Z
M>GD*;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S='(@(MBLV++8IMN,
MV*?8JB#:K]F(V*?9A]N,("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DV"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G
M<W1R("+8L]N,V*?8L]BJV8?8I]N,(-JOV8C8I]F'VXPB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#@*(RP@9G5Z>GD*;7-G:60@(D-H860B"FUS9W-T<B`BV8;9B-N,V+/9AR(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.38*;7-G:60@(D-H86YG92(*;7-G<W1R("+8
MJMBZVXS;C-BQ("(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS
M,0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`BV*?8L]F%
M(-BQV878LB#8KMF(V*\@V+'8IR#8JMBZVXS;C-BQ(-BOV8?;C-BO(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE
M(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R
M96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@HB
MV*K8NMN,VXS8L=BOV*?8K]F&(-F&V*?9A2#9B"#8HMBOV+'8L]N,(-JIV8<@
MV*?9@=BQV*?8KR#9A]F&VJ_8I]F%(-BNV8C8I]F&V*_9AB#9B"#9OMBGV+/8
MKB#8K]BGV*_9AB#8J-F'(-F&V*?9A=F'V90@V+39A=BG(-BNV8C8I]F'V8;8
MKR`B"B+8K]N,V*\@(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C(T"FUS9VED("(B"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S
M=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB
M0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(MBJV+K;
MC-N,V+'8K]BGV*_9AB#8I]BSV84@V+'9A=BR(-BTV878IR#8K]BQ(-F^VXS:
MJ=BQV*C9AMBOVXP@V8'8N=F$VXP@V;[8M-BJVXS8J-BGV8;;C"#9AMF%VXSB
M@(S8M-F(V*\N(-BHV*<@V+/8L=F^V+'8L]BJ(-BSV*?9A=BGV8;9AR#8KMF(
MV*\@(@HBV*K9A=BGV+,@V*C:K]N,V+';C-BO(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA
M<B(*;7-G<W1R("+9AMF(VXS8L]F'(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@
M3&EN:RXN+B(*;7-G<W1R("+8J-BQV+'8L]N,(-F^VXS9B-F&V*\N+BXB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8W"FUS9VED(")#:&EL92(*;7-G<W1R("+B@(PB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8W"B,L(&9U>GIY"FUS9VED(")#:&EN82(*;7-G<W1R("+9AMF(VXS8L]F'
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@
M4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R(")#:&EN97-E(%-I;7!L:69I
M960@*$=",C,Q,BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I
M9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B0VAI;F5S
M92!4<F%D:71I;VYA;"`H0FEG-2DB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G
M<W1R("+8I]F&V*K8KMBGV*@@VXS:J2#8I]BSV84@V+'9A=BR(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.`IM<V=I9"`B0VAO;W-E
M(&$@=7-E<FYA;64B"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-N,VJD@V8;8I]F%
M(-JIV*?8L=BHV+';C"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3@*
M;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B
MV*?9AMBJV*[8I]BH(-J&VJ_9B-F&VJ_;C"#9AMF%V*?;C-BT(-BJV*?8L=N,
MV*XZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H
M9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#9AMF(
MV+D@V+/8J-JI(-F!V8?8L=BSV*H@*-BHV+'8I]N,(-F!V8?8L=BSV*K9A]BG
MVXP@V878L=BJV*@I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES
M;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP
M.C(Y-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#DS"B,L('!H<"UF;W)M870*
M;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G
M<W1R("+8JMBYV+';C-F!(-JIV838I]BS("5S(-N,V*?9@=BJ(-F&V+38KR(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS
M9VED(")#;&5A<B(*;7-G<W1R("+8M=BGV8$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F
M9FEC92!T86=S(@IM<V=S='(@(MF^V*?:J2#:J=BQV*_9AB#8JMJOV8?8I]N,
M($U33V9F:6-E(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.`HC+"!F=7IZ
M>0IM<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`BV;[8I]JI(-JIV+'8K]F&
M(-JIV*?8L=BHV+$B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R
M9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C
M;&5A<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E
M<CH@)7,B"FUS9W-T<B`BV;[8I]JI(-JIV+'8K]F&(-JIV*?8L=BHV+$@.B`E
M<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I
M9"`B0VQE87(@=7-E<B(*;7-G<W1R("+9OMBGVJD@VJG8L=BOV88@VJG8I]BQ
MV*C8L2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS
M9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`BV;[8I]JI(-JIV+'8K]F&
M(-BOV*?8K]F'V90@VJG8I]BQV*C8L2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$U"B,L(&9U>GIY"FUS9VED(")#;&5A<FEN
M9R!,871E(@IM<V=S='(@(MBHV*?8L=BGV88@V*_;C-BQV8?9AMJOV*?9A2(*
M"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C8P
M"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R("+8J-BQV*?;C"#8
MI]BOV*?9A=F'V(P@VJG9A-N,VJD@VJG9AMN,V*\B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L
M:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B0VQI8VMA=&5L;"#8I]BR(-BW
MV+';C-F"($A45%`B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O
M=R(*;7-G<W1R("+8J-BSV*K9AB#9OMF&V*S8L=F'(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-#0*;7-G:60@(D-L;W5D<R(*;7-G<W1R("+8I]BHV+'9
MA]BG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,38*(RP@9G5Z>GD*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R("+8I]BH
MV+';C"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T<B`BV*?8J-BQVXPB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S"FUS9VED(")#
M;VQL87!S92!3:61E8F%R(@IM<V=S='(@(MBLV878N2#8M-BOV88@V8;9B-BG
MV+$@VJG9AMBGV+';C"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S
M(@IM<V=S='(@(MJ&V878N2#8M-BOV88@V838J-F'XH",V8?8IR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(MBQV8;:
MKR(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R
M+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R("+8L=F&VJ\B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(T"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C4*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,"!S97)V
M:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0
M:6-K97(B"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-JIV8;9AMBOV8<@V+'9AMJO
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@T-@IM<V=I9"`B0V]L
M;W5R('-E;&5C=&EO;B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@V+'9AMJO(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*
M;7-G:60@(D-O;',Z(@IM<V=S='(@(MBSV*K9B-F&V8?8ISHB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30V"FUS9VED(")#;VQU;6X@=&ET;&5S
M(@IM<V=S='(@(MBYV8;8I]F(VXS9AB#8L]BJV8C9AMF'V*<B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8T"FUS9VED(")#;VUI8W,B"FUS9W-T
M<B`BV878MMBMVJDB"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*;7-G:60@
M(D-O;6UA;F0B"FUS9W-T<B`BV8'8L=F%V*?9AB(*"B,Z(&%D;6EN+V-M9'-H
M96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R("+9OMF(
MV+/8JMF'(-F!V+'9A=BGV88B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`BV*K9B-BVVXS8
MK2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38V"FUS
M9VED(")#;VUM;VX@3F%M92(*;7-G<W1R("+9AMBGV84@V+G9A=F(V87;C"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@T"B,L(&9U>GIY"FUS9VED(")#;VUO<F]S(@IM<V=S='(@
M(MF!V+'8K]BG(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R("+8M-BQVJG8JB(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S
M(@IM<V=S='(@(MBQV*?;C-BGV8;9A^*`C-F'V*<B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,CDW"FUS9VED(")#;VYD:71I;VXB"FUS9W-T
M<B`BV+38L=BW(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#D*;7-G:60@
M(D-O;F1I=&EO;G,B"FUS9W-T<B`BV+38L=BGVXS8MR(*"B,Z(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N
M8V5S(@IM<V=S='(@(MBJV8'8I]F(V*K9A]BGVXP@V;[;C-JIV+'8J-F&V*_;
MC"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#,*;7-G:60@(D-O;F9I
M9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A
M;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$S-0HC+"!F=7IZ>0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@
M;V8@9&%T92XB"FUS9W-T<B`BV;[;C-JIV+'8J-F&V*_;C"#8J-F'(-BHV+'9
MB-BRV+'8L]BGV8;;C"#9AMN,V*?8LB#8K]BGV+'8KR(*"B,@(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]N9FEG=7)E("5S(@IM<V=S='(@(MF^VXS:J=BQV*C9AMBOVXP@)7,B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED(")#
M;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(MBJV*/;C-N,V*\@V*?8L]F%(-BQ
MV878LB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C8*(RP@9G5Z>GD*;7-G:60@(D-O;F=O(@IM<V=S
M='(@(MBQV8;:KR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M
M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C
M=&EO;B!F86EL960N(@IM<V=S='(@(MBGV*K8M=BGV80@V8;8I]F%V8C9@=F1
MV8(@V*C9B-BO(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R("+8
MI]BJV+78I]F$(-F&V*?9A=F(V8'9D=F"(-BHV8C8KR(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R
M969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("+8I]BJ
MV+78I]F$(-BHV8<@VJG8I]BQV+/8I]BR(-JIV83;C-BO(-BYV879B-F%VXP@
MV+'8KR#8M-BO(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S
M='(@(MBGV*K8M=BGV80@V*C9AR#:J=BGV+'8L]BGV+(@VJG9A-N,V*\@V+G9
MA=F(V87;C"#8L=BO(-BTV*\N(-BOV83;C-F$.B`E<R`H)7,I(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-#4*;7-G:60@(D-O;FYE8W1I;VX@
M=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(MBGV*K8M=BGV80@V*C9
MAR#:J=BGV+'8L]BGV+(@1E10(-F&V*?9A=F(V8'9D=F"(-BHV8C8KR(*"B,Z
M(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#$T"FUS9VED(")#;VYT86-T<R(*
M;7-G<W1R("+9AMF%V*?8L]F'V*<B"@HC(`HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@
M<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G
M<W1R("+8JMF%V*?8L]F'V*<@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BHV8<@
MVJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@V+39A=BG(-BGV+;8I]F!V8<@V+38
MK]F'(-BHV8C8KR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-38@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV
M,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B
M"FUS9W-T<B`BV878K=BJV8C8I]N,("<E<R<@(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C,S"FUS9VED(")#;VYT:6YU92(*;7-G<W1R("+8I]BOV*?9A=F'(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@
M(MJIV8C:J=N,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@(MBQV8C9
MAMF(V+38JB(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8X"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS
M9W-T<B`BV*?8JMBUV*?9A"#9AMBGV879B-F!V9'9@B#8J-F(V*\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,V"FUS9VED
M(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R("+8L=F(V8;9B-BTV*H@V*C8L=BO
MV*?8M-BJV88@V*?8LB#8J-BNV+0@V*?9AMBJV*[8I]BHVXPB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B0V]S="!)
M1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;W-T82!2:6-A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3<V
M"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T
M<B`BV8;9A=N,XH",V*K9B-BGV8;8KR#9OMN,V+K8I]F%(-BQV*<@V+'9A=BR
MV*C9AMBOVXP@VJG9AMBO(%!'4"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$P-3,*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S
M86=E+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AMBO(-F^VXS8NMBGV84@
MV+'8IR#8I]F%V+;8I]BA(-JIV8;8KR!01U`B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-
M12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&
MV*\@V;[;C-BZV*?9A2#8L=BG(-BQV878LMBHV8;8K]N,(-JIV8;8KR!3+TU)
M344B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM
M<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@
M(MF&V87;C.*`C-BJV8C8I]F&V*\@V;[;C-BZV*?9A2#8L=BG(-BGV878MMBG
MV*$@VJG9AMBO(%,O34E-12(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O
M("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`BV8;9A=N,
MXH",V*K9B-BGV88@V*K9A=BGV+/9A]BG(-BQV*<@V*?8MMBGV8'9AR#:J=BQ
MV*\@)7,B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ,C$*;7-G:60@(D-O=6QD
M(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("+9AMF%VXSB@(S8
MJMF(V*?9AB#8J-F'(-JIV*?8L=BSV*?8LB!,1$%0(-F^VXS9B-BSV*H@(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0U-PIM<V=I9"`B0V]U;&0@;F]T
M(&)I;F0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BG
MV88@V*C9AR#:J=BGV+'8L]BGV+(@;&1A<"#9OMN,V8C8L]BJ(@H*(R`C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ
M-38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B
M86QA;F-E+B`E<R(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8J-BGV838
MI]F&V+,@V+'8IR#:AMJI(-JIV+'8KR`E<R(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HT-#$*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@
M<V5R=F5R(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BHV8<@VJG8I]BQ
MV+/8I]BR(&QD87`@V878JMBUV80@V+38KR(*"B,@(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z
M("5S(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BHV*<@V*?8L]BJV8'8
MI]BOV8<@V*?8LB!&5%`@V*C9AR#:J=BGV+'8L]BGV+(@)R5S)R#9B-BUV80@
MV+38KSH@)7,B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@
M,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("+9
MAMF%VXSB@(S8JMF(V*?9AB#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"#8I]N,
MV*S8I]BO(-JIV+'8KRX@)7,B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,3(U"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!0
M1U`@9&%T82XB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V*_8I]BOV8<@
M4$=0(-BQV*<@V+'9A=BRVJ_8M-BGVXS;C"#9AMF%V8C8KR`B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,@IM<V=I9"`B0V]U;&0@
M;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(MF&V87;C.*`C-BJ
MV8C8I]F&(-BOV*?8K]F'(%,O34E-12#8L=BG(-BQV878LMJOV+38I]N,VXP@
MV8;9A=F(V*\@(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E
M(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R("+9AMF%VXSB@(S8
MJMF(V*?9AB#8JMF%V*?8LR#8L=BG(-BMV+#9@2#9AMF%V8C8KRX@)7,B"@HC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M
M(PHC(`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("+9AMF%VXSB@(S8JMF(
MV*?9AB#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"#8L=BG(-BMV+#9@2#9AMF%
MV8C8KRX@)7,B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@
M,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS
M.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T
M92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(MF&V87;
MC.*`C-BJV8C8I]F&(-BGV+/:J=BQVXS9OMBJ(-BHV+'9B-BRV+'8L]BGV8;;
MC"#8L=BGV8?B@(S8I]F&V*_8I]BRVXP@V+'8IR#8K=BPV8$@V8;9A=F(V*\@
M)R5S)RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X
M,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O
M=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R
M97-S+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8HMBOV+'8LR#:K]N,
MV+'9AMBOV8<@V8;8I]F%V8?9E"#8I]F$VJG8JMBQV8C9AMN,VJG;C"#8L=BG
M(-BJV+38KMN,V+4@V*_8I]BO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F971C
M:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(MF&V87;C.*`C-BJ
MV8C8I]F&(-JIV80@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@V+'8IR#9B-BG
MVJG8M-N,(-F&V879B-BO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C
M;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`BV8;9A=N,XH",
MV*K9B-BGV88@VJG9A"#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"#8L=BG(-F(
MV*?:J=BTVXP@V8;9A=F(V*\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H
M('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS
M9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V8'9A]BQV+/8JB#:J=BGV879A"#9
M@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"#8L=BG(-F(V*?:J=BTVXP@V8;9A=F(
MV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M
M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S
M=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BG
MV+/8JMBQV*?8JMJ8VXP@V+'8IR#8J-BGV+$@VJG8L=BO("<E<R<B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB
M)7-<(BXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V+38I]BNV8<@)R5S
M)]BGVXS8K-BGV*\@VJG8L=BO("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@
M:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`BV8;9A=N,XH",V*K9
MB-BGV88@VJG9A-N,V*\@V+G9A=F(V87;C"#8L=BG(-BGV+(@VJG8I]BQV+/8
MI]BR(-JIV83;C-BO(-BHV*_8L]BJ(-BBV8C8L=BO(@H*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C$S.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R("+9
MAMF%VXSB@(S8JMF(V*?9AB`G)7,G(-BQV*<@V*C8L=BGVXP@V8;9B-BTV*K9
MAB#8J-BGV+(@VJG8L=BO("(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O
M("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`BV8;9A=N,XH",V*K9
MB-BGV88@)7,@V+'8IR#8J-BGV+(@VJG8L=BO(@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@
M)7,B"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V878K]F(V80@V8C8N-BG
MVXS9@2#9AMJOV8?8K]BGV+';C"`E<R#8L=BG(-BHV*?8LB#9AMF%V8C8KR(*
M"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M
M(RTC"B,@"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB
M"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V+38I]BNV8<@)R5S)R#8L=BG
M(-BHV*?8LB#9AMF%V8C8KR(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T
M-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0HC+"!F
M=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB
M"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@VJG8I]BQV+/8I]BR($Q$05`@
MV+'8IR#8K-BSV*K8K-F((-JIV+'8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+T]B:F5C="YP:'`Z,C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R96%D("5S+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB`E
M<R#8L=BG(-BNV8C8I]F&V*\B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R
M9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@
M(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT
M86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R
M(&AE;'`N(@IM<V=S='(@(B(*(MF&V87;C.*`C-BJV8C8I]F&(-BGV+/9A2#8
ML=F%V+(@V+'8IR#8J-BQV*?;C"#:J=BGV+'8J-BQ(-F%V8C8L=BO(-F&V+C8
ML2#8J-BGV++9AMBTV*?9AMBO+B#8J-BYV+;;C"#;C-BG(-F'V879AR#8K-BR
MV*;;C-BGV*H@V878L=BHV8C8MR#8J-F'("(*(MBBV88@V8;8I]BOV+'8L]BJ
M(-F%VXSB@(S8J-BGV+38KRX@V*_9B-BHV*?8L=F'(-BSV+G;C"#:J=F&VXS8
MKR#;C-BG(-BHV+'8I]N,(-JIV87:J2#8J-N,V+38JMBQ(-BHV*<@V+/8L=F^
MV+'8L]BJ(-BSV*?9A=BGV8;9AR#8KMF(V*\@(@HBV*K9A=BGV+,@V*C:K]N,
MV+';C-BO(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S`Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,T,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M-S<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.0IM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R("+9AMF%VXSB
M@(S8JMF(V*?9AB!!0TP@V+'8IR#8K]F(V*C8I]BQV8<@V*C8K]BSV*H@V*+9
MB-BQV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@
M(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R("+9AMF%VXSB
M@(S8JMF(V*?9AB#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR#8L=BG(-BOV8C8
MJ-BGV+'9AR#8J-BOV+/8JB#8HMF(V+'8KRX@)7,B"@HC(",M(RTC+2,M(R`@
M8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F!V8?8
ML=BSV*H@V*K9B-BRVXS8N=N,(-BQV*<@V*_9B-BHV*?8L=F'(-BHV*_8L]BJ
M(-BBV8C8L=BO+B`E<R(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(
M;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM
M<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F!V8?8L=BSV*H@V*K9B-BRVXS8
MN=N,(-BQV*<@V*_9B-BHV*?8L=F'(-BHV*_8L]BJ(-BBV8C8L=BO+B`E<R(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM
M<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F"V*?8J-F$VXS8JMF'V*?;C"#:
MJ=BGV+'8L]BGV+(@V+'8IR#8K]F(V*C8I]BQV8<@V*C8K]BSV*H@V*+9B-BQ
MV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M
M(RTC+2,M(PHC(`HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS9VED
M(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(MF&
MV87;C.*`C-BJV8C8I]F&(-F^VXS:J=BQV*C9AMBOVXP@V+'8IR#8J-BGV++:
MK]BQV*_8I]F&V*\B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM
M<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'("<E<R<@V+'8IR#8
MK=BPV8$@V8;9A=F(V*\@+B(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O
M("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E
M("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&
M(-F^VXS:J=BQV*C9AMBOVXP@)7,@V+'8IR#8K]BNVXS8L=F'(-JIV+'8KR(*
M"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M
M(RTC"B,@"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K
M=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9
MOMN,VJG8L=BHV8;8K]N,(-F^V+38JMN,V*C8I]F&(-BQV*<@V*W9@=BX(-JI
MV+'8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@
M(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF
M:6=U871I;VXZ("5S(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^VXS:
MJ=BQV*C9AMBOVXP@V;[8M-BJVXS8J-BGV88@V+'8IR#8K=F!V+@@VJG8L=BO
M.B`E<R`B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@
M(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`BV8;9A=N,
MXH",V*K9B-BGV88@V*?8L]JIV+';C-F^V*H@V*C8L=F(V++8L=BSV*?9AMN,
M(-BQV*?9A^*`C-BGV8;8K]BGV++;C"#8L=BG(-BMV8'8N"#9AMF%V8C8KSH@
M)R5S)RXB"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@
M(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(
MV*?9AB#9OMBQV8C9AMBOV8<@V;[8M-BJVXS8J-BGV88@V;[;C-JIV+'8J-F&
MV*_;C"`E<R#8L=BG(-BMV8'8N"#:J=BQV*\B"@HC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O
M=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C
M86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T
M:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@
M8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*(MF&V87;C.*`C-BJV8C8I]F&(-F^
MV+'9B-F&V*_9AR#9OMN,VJG8L=BHV8;8K]N,("5S(-BQV*<@V*W9@=BX(-F&
MV879B-BO+B#8M-F%V*<@V87;C"#8JMF(V*?9AMN,V*\@V*?8LB#;C-JIVXP@
MV*?8LB#:K]BRVXS9AMF'XH",V8?8IR#8J-BQV*?;C"`B"B+8K=F!V+@@VJG8
MKR#8J-BQ(-BQV8C;C"`E<R#8I]BSV*K9@=BGV*_9AR#9AMF%V*?;C-N,V*\@
MV8@@VXS8IR#8I]N,V8;:J=F'(-BGV+(@VJG8KR#8J-F'(-BUV8C8L=BJ(-BO
MV+/8JMN,(-BOV+$E<R#8L=F(V8;9B-BTV*H@(@HBV*K9A]N,V8<@V8;9A=BG
MVXS;C-BO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,*
M;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G
M<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#:J=BGV+'8L]BGV+(@3$1!4"#8L=BG
M(-BLV+/8JMBLV8@@VJG8L=BO(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB
M)7-<(BXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V;[;C-F(V8;8KR`G
M)7,G(-BQV*<@V8+8M]BY(-JIV+'8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T
M<B`BV8;9A=N,XH",V*K9B-BGV88@V*K9A=BGV+,@(-BQV*<@V*C8L=F(V++8
ML=BSV*?9AMN,(-JIV+'8KRX@)7,B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU
M;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<R(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9@=F'V+'8L]BJ(-BJV8C8
MLMN,V+G;C"#8L=BG(-BHV+'9B-BRV+'8L]BGV8;;C"#:J=BQV*\N("5S(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO
M;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9
MOMN,VJG8L=BHV8;8K]N,(-BQV*<@V*C8L=BGVXP@)R5S)R#9AMF(V+38JCH@
M)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8V"FUS9VED(")#;W5L
M9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@
M<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B"B+9AMF%VXSB@(S8JMF(V*?9
MAB#9AMF(V*?8L2#8K-BGV8;8J-N,(-F%V8C8LMN,V838IR#8L=BG(-F^VXS8
MK]BG(-JIV+'8KRX@V878M]F%V*;9AB#8M-F(VXS8KR#:J=F'(-F&V8C8I]BQ
M(-BLV*?9AMBHVXP@V*C8I]BR(-BGV+/8JB(*"B,@"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@
M9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM
M<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BHV8<@VJG8I]BQV*C8L2`G)7,G
M(-BOV+/8JMBQV+/;C-F'V*?;C"#8LMN,V+$@V*C8L=BGVXP@V;[9B-BTV8<@
M)R5S)R#8K]BGV*\Z("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30Q.0IM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(MF%V*K9AB#8M-F%
MV*?8L=BT(-BTV*_9AR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-38Y"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(MJIV+39B-BQ(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W,PIM<V=I9"`B0V]U<G-E
M<R(*;7-G<W1R("+8K]F(V+'9A^*`C-F'V*<B"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@
M(D-R96%T92(*;7-G<W1R("+8I]N,V*S8I]BO(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#
M<F5A=&4@82!L:6YK(@IM<V=S='(@(MBGVXS8K-BGV*\@VXS:J2#9OMN,V8C9
MAMBO(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY
M-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R("+8I]N,V*S8I]BO
M(-N,VJG;C"#8K-BOVXS8KR(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS
M9W-T<B`BV*?;C-BLV*?8KR#8LMN,V+'9OMF(V+39A^*`C-F'V*<B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E871O
M<B!097)M:7-S:6]N<R(*;7-G<W1R("+9A=BLV8C8LMF'V*?;C"#8I]N,V*S8
MI]BO(-JIV8;9AMBOV8<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,C,P"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`BV+39A=BG
MV+'9AR#:J=BGV+'8JB#8I]BYV*K8J-BGV+';C"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"B,L
M(&9U>GIY"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(MBGVXS8K-BGV*\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8X"FUS9VED(")#=6)A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="`T(%!H87-E
M<R(*;7-G<W1R("+9@=BGV+(@V8'8N=F$VXPB"@HC.B!A9&UI;B]S97-S:6]N
M<RYP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS
M9W-T<B`BV878K-F(V++9A]BGVXP@V*?;C-BLV*?8KR#:J=F&V8;8K]F'(@H*
M(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P
M"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`BV+/8I]BYV*H@V8'8N=F$
MVXPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(E52
M3"#9@=BYV83;C"#9A]BSV*HB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S,*
M(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`BV8'8I]BR
M(-F!V+G9A-N,(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B
M0W5R<F5N="!796%T:&5R(@IM<V=S='(@(MBBV*@@V8@@V8?9B-BGVXP@V8'8
MN=F$VXPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<U"FUS
M9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@(MBTV+'8I]N,V+<@
MV8'8N=F$VXPZ("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`BV+/8
MJ-JI(-F!V+G9A-N,(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P
M;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(MBSV8'8I]BQV+3;C"#:J=BQV*_9
MAB#9B-BXV*?;C-F!(-F'V8;:K]BGV84@V8C8L=F(V*\@V*C9AR`E<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(MBHV+';C-BOV88B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED(")#
M=70@<V5L96-T:6]N(@IM<V=S='(@(MBHV+';C-BOV88@V*?9AMBJV*[8I]BH
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED(")#>7)I;&QI8R`H2T])."U2
M*2(*;7-G<W1R(")#>7)I;&QI8R`H2T])."U2*2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*
M;7-G<W1R(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@T"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/
M23@M52DB"FUS9W-T<B`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,2!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B1$0B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@Q"FUS9VED("(B"B)$
M4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E
M+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3D*;7-G:60@
M(D1A:6QY(@IM<V=S='(@(MBQV8C8LMBGV8;9AR(*"B,Z(&%D;6EN+V1A=&%T
M<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R("+9
MA=BQV8C8L=JOV+$@V*_8L=BNV*H@V*_8I]BOV8<B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,C<Y"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDY"FUS9VED(")$
M871E(@IM<V=S='(@(MBJV*?8L=N,V*XB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*;7-G
M<W1R("+8JMBGV+';C-BN(-BOV+';C-BGV8'8JB#8M-BOV8<B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`W"FUS9VED(")$871E('-E;&5C=&EO
M;B(*;7-G<W1R("+8JMBGV+';C-BN(-BGV8;8JMBNV*?8J"(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3(@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,R,@IM<V=I9"`B1&%Y(@IM<V=S='(@(MBQV8C8LB(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`BV*W8L-F!(-BS
MV*K9B-F&(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(MBOV+/8I]F%V*C8L2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R("+8I]BY
MV*_8I]BO(-BOV8?8K]F'VXPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS
M9W-T<B`BVJG9A2#:J=BQV*_9AB#8JMF(V+'9@=BJVJ_;C"(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI8B]P<F5F<RYP:'`Z,3$W
M"FUS9VED(")$969A=6QT(@IM<V=S='(@(MF^VXS8M"#9@=BQV+8B"@HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PIM<V=I
M9"`B1&5F875L="!#;VQO<B(*;7-G<W1R("+8L=F&VJ\@V;[;C-BT(-F!V+'8
MMB(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z.3$*;7-G
M:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`BV8?9B-N,V9'8JB#9OMN,
MV+0@V8'8L=BV(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"FUS9VED
M(")$969A=6QT(%-H96QL(@IM<V=S='(@(MF^V8C8L]BJV8?9E"#9OMN,V+0@
MV8'8L=BV(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$
M969I;FET:6]N<R(*;7-G<W1R("+8JMBYV*?8L=N,V8$B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(V"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,`HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.3@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B
M"FUS9W-T<B`BV*W8L-F!(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"B,L(&9U>GIY"FUS9VED(")$96QE
M=&4@0V5L;"(*;7-G<W1R("+8K=BPV8$@V+/9A-F(V80B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L
M971E($=R;W5P(@IM<V=S='(@(MBMV+#9@2#:K]BQV8C9AR(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0HC+"!F=7IZ>0IM<V=I9"`B1&5L
M971E($QO9R(*;7-G<W1R("+8K=BPV8$@V+/8M]BQ(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B
MV*W8L-F!(-F%V*S9B-BR(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G
M97,B"FUS9W-T<B`BV*W8L-F!(-F((-F^V*?:J=BSV*?8LMN,(-F^VXS8NMBG
MV879A]BG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T<B`BV*W8
ML-F!(-BSV839B-F$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G
M<W1R("+8K=BPV8$@V+/8JMF(V88B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T
M92(*;7-G<W1R("+8K=BPV8$@V*?9A-JOV8C;C"#8K-BGVXS:K]BRVXS9AB#9
MA=F(V*S9B-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E
M(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I
M;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`BV*W8L-F!(-F%V*S9B-BRV8?8IR#8
MJ-BQV*?;C"`@7"(E<UPB(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I
M;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S
M='(@(MBBVXS8IR#9A=BLV8C8LMF'V*<@V8@@V++;C-BQV878K-F(V++9A]BG
M(-BHV+'8I]N,(%PB)7-<(B#8K=BPV8$@V+39B-BOV)\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED
M(")$96QE=&4@<F]W(@IM<V=S='(@(MBMV+#9@2#8L]BWV+$B"@HC.B!T96UP
M;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$96QE
M=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`BV*W8L-F!(-F'V8C;C-F1
MV*H@V*?9AMBJV*[8I]BH(-BTV*_9AR(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E
M('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R("+8K=BPV8$@V+/8JMF(V88@
MV8'8N=F$VXPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R
M;W<B"FUS9W-T<B`BV*W8L-F!(-BSV+?8L2#9@=BYV83;C"(*"B,@(RTC+2,M
M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<
M(BXB"FUS9W-T<B`BV*?8L]JIV+';C-F^V*H@V*W8L-F!(-BTV*_9A]F4(-BH
MV+'9B-BRV+'8L]BGV8;;C"#8JMF&V+C;C-F%V*?8JB`G)7,G+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR-3,*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`BV++9A=BG
MV88@V*?8L=BSV*?9A"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*(RP@9G5Z>GD*;7-G:60@(D1E
M;FUA<FLB"FUS9W-T<B`BV*K9B-BVVXS8K=BGV*HB"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R
M;V)L96TB"FUS9W-T<B`BV+38L=BM(-F%V+3:J=F$(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S
M='(@(MBJV8C8MMN,V*TB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$Y-0IM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I
M.B(*;7-G<W1R("+8K-BRV9#8IMN,V*?8JCHB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$Y.0IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G
M9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(-BLV++8IMN,
MV*?8JB#8J-BQV*?;C"#8L]BQV;[8L=BSV*H@V+/8I]F%V*?9AMF'(-BKV*C8
MJB#8M-BOV8<@V*?8L]BJ(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(Q.0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`BVJ_8L]BJV+'8M"(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$W"FUS9VED(")$97<@4&]I;G0B
M"FUS9W-T<B`BV8;9@MBWV8<@V+38J-F&V84B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(Y-`IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*
M;7-G<W1R("+9AMF"V+?9AR#8M-BHV8;9A2#8J-BQV*?;C"#8L]BGV+G8JB#:
MK]BPV+38JMF'.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C(W"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R("+9AMF"V+?9AR#8M-BH
MV8;9A3H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T
M<B`BV*S9A]BJ(-BGV+(@VH;9OB#8J-F'(-BQV*?8L]BJ(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER
M96-T:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`BV*S9A]BJ(-BGV+(@V+'8
MI]BSV*H@V*C9AR#:AMF^(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*
M;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R("+8M-BGV*[9AR(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-C8*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T
M:6UE<S\B"FUS9W-T<B`BV*+;C-BG(-BRV878I]F&(#(T(-BSV*?8N=BJV8<@
MV8;9A=BGVXS8M"#8K]BGV*_9AR#8M-F(V*_8GR(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY-PIM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@
M(MJOV++;C-F&V8?B@(S9A]BGVXP@V8;9A=BGVXS8M"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HY-@IM<V=I9"`B1&ES<&QA>2!D971A:6QE
M9"!F;W)E8V%S="(*;7-G<W1R("+9AMF%V*?;C-BT(-BLV++8IMN,V*?8JB#9
MOMN,V+3"K=BHVXS9AMN,(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-0IM
M<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R("+9AMF%V*?;
MC-BT(-F^VXS8M,*MV*C;C-F&VXPB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#$W"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R("+9AMF%
MV*?;C-BT(-F"V*?9A-BH(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN
M<&AP.C$Y,`IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S
M='(@(MBMV*?9A-BJ(-BJV+#:J=BQ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&II
M8F]U=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HT,C(*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`BV*W8L-F!
M(-F&V+39B-BO(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS
M9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*
M;7-G<W1R("+8K]BSV*K8L=BSVXP@V878L]BJV8+;C-F%(-BHV8<@;6%I;G1E
M;F%N8V4N<&AP(-F%V87:J=F&(-F&VXS8L]BJ(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L
M9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B(@HB
MV*+;C-BG(-BSV+?8L2#8I]F(V80@V+38I]F%V80@V8';C-F$V*\@V8;8I]F%
M(-F%VXSB@(S8J-BGV+38K]B?(-BGVJ_8L2#:AMF&VXS9AB#8I]BSV*K8C"#8
MI]N,V88@V*S8N=BHV8<@V+'8IR#8N=F$V*?9A=BJ(-BHV++9AMN,V*\Z(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA
M=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"FUS9VED(")$;W=N;&]A
M9"(*;7-G<W1R("+8I]BSV*K9@MBQV*?8L2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C@T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$
M;W=N;&]A9"`E<R(*;7-G<W1R("+8I]BSV*K9@MBQV*?8L2`E<R(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R
M871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(MBG
MV+/8JMF"V+'8I]BQ(-F^VXS:J=BQV*C9AMBOVXP@V*K9B-F$VXS8KR#8M-BO
MV8<@V*C8N=F&V8C8I]F&(-BOV+/8JB#9AMF(VXS8LR!02%`B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`W"FUS9VED(")$<F]P(&1O=VX@;&ES
M="(*;7-G<W1R("+9@=F'V+'8L]BJ(-F^V*?;C-N,V8;B@(S9OMBQ(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R
M("+8K]BGV+'9B-F'V*<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3,*;7-G:60@(D4M36%I;"(*;7-G<W1R("+9AMBGV879AR#8I]F$
MVJG8JMBQV8C9AMN,VJG;C"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G
M96YE<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A
M>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R
M=FEC92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2
M(@IM<V=S='(@(D524B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R"B,Z('1E;7!L871E
M<R]P;W)T86PO961I="YI;F,Z,C4*;7-G:60@(D5D:70B"FUS9W-T<B`BV8C;
MC-BQV*?;C-BT(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU
M,"!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET($)L
M;V-K(@IM<V=S='(@(MF(VXS8L=BGVXS8M"#8J-F$V8C:J2(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%
M9&ET($=R;W5P(@IM<V=S='(@(MF(VXS8L=BGVXS8M"#:K]BQV8C9AR(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*
M;7-G<W1R("+9B-N,V+'8I]N,V+0@V878K-F(V+(B"@HC.B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(MF(VXS8L=BGVXS8M"#9A=BLV8C8LMF'V*<B"@HC(",M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G
M:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(MF(VXS8L=BG
MVXS8M"#9A=BLV8C8LMF'V*<@V*C8L=BGVXP@)7,B"@HC.B!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G
M<W1R("+:K]BRVXS9AMF'XH",V8?8I]N,(-F(VXS8L=BGVXS8M#HB"@HC(",M
M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC
M(`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS
M9W-T<B`BV8C;C-BQV*?;C-BT(-F%V*S9B-BRXH",V8?8IR#8J-BQV*?;C"!<
M(B5S7"(B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@
M(",M(RTC+2,M(PHC(`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T
M"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S
M(@IM<V=S='(@(MF(VXS8L=BGVXS8M"#9A=BLV8C8LN*`C-F'V*<@V*C8L=BG
MVXP@)7,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D
M=6-A=&EO;B(*;7-G<W1R("+8JMBMV+7;C-F$V*?8JB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*
M;7-G:60@(D5G>7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,S$P"B,L('!H<"UF;W)M870*;7-G:60@(D5I=&AE<B!E;F%B
M;&4@:70@=&AE;CH@)7,L(&]R('5S92!T:&4@8F%S:6,@2%1-3"!V97)S:6]N
M.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%;"!386QV
M861O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS
M9W-T<B`BV+G9AMBUV+$N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B16TB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD*;7-G:60@(D5M86EL(@IM<V=S
M='(@(MF&V*?9A=F'(-BGV83:J=BJV+'9B-F&VXS:J=N,(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C8X"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(MBB
MV*_8L=BS(-F&V*?9A=F'V90@V*?9A-JIV*K8L=F(V8;;C-JIVXPB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38S"FUS9VED(")%;6%I;"!A9&1R
M97-S97,@;75S="!M871C:"XB"FUS9W-T<B`BV*+8K]BQV+/9A]BGVXP@V8;8
MI]F%V8?B@(S9A]BGVXP@V*?9A-JIV*K8L=F(V8;;C-JIVXP@V*C8I]N,V*\@
MV879AMBWV*C9@B#8J-BGV+38KR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y.#D*;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S
M='(@(MF&V*?9A=F'V90@V*?9A-JIV*K8L=F(V8;;C-JIVXP@V*C8IR#8JMBC
MVXS;C-BO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT
M<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M.3@*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R("+8I]BMV+/8I]BSV*?8JB(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P,@IM<V=I9"`B16UP='D@;65S<V%G92XB"FUS9W-T<B`BV*[8I]F$VXP@
MVJG8L=BOV88@V;[;C-BZV*?9A2`B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U;'0N
M(@IM<V=S='(@(MBNV*?9A-N,(-JIV+'8K]F&(-F&V*K;C-BLV8<B"@HC.B!F
M<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T
M>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`BV*[8I]F$VXP@VJG8L=BOV88@V879
MB-BGV+'8KR#8K-BSV*K8K-F((@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4T,PIM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0
M:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`BV*+;C-BG(-BOV+'8
MK"#8JMBUV*?9B-N,V+$@V*?8LB#:K]BGV838L=N,V8?8I]N,(-BYVJG8LR#8
MK]BQ(-F%V*K9AB#9@=BYV*?9A"#8M-F(V*_8GR(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,3@*;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT
M97AT(&UE;G4_(@IM<V=S='(@(MBBVXS8IR#:K]BRVXS9AMJOV*?9AB#8LMF%
MVXS9AMF'(-BQV8C;C"#:J=F$VXS:J2#8L=BGV+/8JB#9@=BYV*?9A"#8M-F(
MV*_8GR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.3@@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,0IM<V=I9"`B16YD('EE87(B"FUS9W-T
M<B`BV*?9AMBJV8?8I]N,(-BSV*?9A"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R
M(@IM<V=S='(@(MBHV++8L=JO(-JIV+'8K]F&(-F(VXS8L=BGV+/8JMBGV+$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q"FUS9VED("(B"B)%;G1E
M<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D
M(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@
M)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@HB
MVXS:J2#8L]BFV8C8I]F$(-BGV879AMN,V*K;C"#8J-BQV*?;C"#9OMBQV+/8
MM"#8I]BR(-BTV878IR#8J-F'(-F'V8;:K]BGV84@V*C8I]BRV8;8M-BGV8;8
MK]F&(-BGV+/9A2#8L=F%V+(@V8C8I]BQV*\@VJG9AMN,V*_8C"#9A=BKV838
MI]F2("(*(B?9AMBGV84@V*W;C-F(V*?9AB#8KMBGV8;:K]N,(-BTV878IR#:
MAMN,V+/8JMB?)R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E
M(%523"!H97)E(@IM<V=S='(@(E523"#8JMBUV8C;C-BQ(-BQV*<@V*?;C-F&
MV*S8IR#9B-BGV+'8KR#:J=F&VXS8KR(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX.3$*;7-G:60@(D5N=&5R('1H92!L971T
M97)S(&)E;&]W.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A
M=&]R:6%L($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%
M<FET<F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C0U(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HU-0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V('-E<G9I8V5S
M+W!O<G1A;"]I;F1E>"YP:'`Z.#(*;7-G:60@(D5R<F]R(@IM<V=S='(@(MBN
MV+?8IR(*"B,@"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z
M-#8S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K
M.B`E<R(*;7-G<W1R("+8J-F$V8C:J2#8I]N,V*S8I]BO(-BNV+?8ISH@)7,B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z
M("5S(@IM<V=S='(@(MBNV+?8IR#8K]BQ(-BHV+'9B-BRV+'8L]BGV8;;C"#8
MI]BSV84@V+'9A=BR(#H@)7,B"@HC(`HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HX,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(MBHV839B-JI(-BGVXS8
MK-BGV*\@V*[8M]BG.B`E<R(*"B,@"B,Z(&9R86UE=V]R:R]496UP;&%T92]4
M96UP;&%T92YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&=E
M='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`BV*[8M]BG(-BOV+$@VJG8L]BH
M(-F%V*W8JMF(V*<Z)7,B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D871I;F<@<&%S
M<W=O<F0Z("5S(@IM<V=S='(@(MBNV+?8IR#8K]BQ(-BHV+'9B-BRV+'8L]BG
MV8;;C"#8I]BSV84@V+'9A=BR(#H@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I
M=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`BV*[8M]BG(-BHV*<@V;[;C-BZ
MV*?9A2#9AMBGV879A]F4(-BGV83:J=BJV+'9B-F&VXS:J=N,(@H*(R`*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(MBNV+?8I]N,(-F&
MV8C8M-BJV88@)R5S)R`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")%
M<W1O;FEA(@IM<V=S='(@(MBYV*K;C-F"V8<B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED
M(")%=&AI;W!I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R("+8N=BJVXS9@MF'(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B
M"FUS9W-T<B`BV*?8L=F(V;[8IR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,SD*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`BV8?8L2#9
MOMBGV8;8LMBOV8<@V*_9@MN,V8+9AR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.#D*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R("+9A]BQ
M(-BOV8@@V*_9@MN,V8+9AR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M,S8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-PIM<V=I9"`B179E<GD@,S`@
M<V5C;VYD<R(*;7-G<W1R("+9A]BQ(-BSVXP@V*_9@MN,V8+9AR(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,Y,`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(MF'V+$@V;[9
MAMBL(-BOV8+;C-F"V8<B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I
M;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R("+8
MK]BQ(-F'V+$@V8C8L=F(V*\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0P"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`BV8?8L2#9AMN,
MV84@V+/8I]BYV*HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,W(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#@*;7-G:60@(D5V97)Y(&UI;G5T92(*
M;7-G<W1R("+9A]BQ(-BOV8+;C-F"V8<B"@HC.B!T96UP;&%T97,O9&%T82]D
M871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@
M(MF%V8+8I]BOVXS8L2#9A=BKV*?9A#HB"@HC.B!A9&UI;B]P:'!S:&5L;"YP
M:'`Z.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,C<*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`BV*?8K-BQV*<B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT-S4*;7-G:60@(D5X
M<&%N9"(*;7-G<W1R("+8J-BGV+(@VJG8L=BOV88B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS9VED(")%>'!A;F0@4VED96)A<B(*
M;7-G<W1R("+8J-BGV++:J=BQV*_9AB#9AMF(V*?8L2#:J=F&V*?8L=N,(@H*
M(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B
M17AP96-T960@)RDG(@IM<V=S='(@(MBGV8;8JMBXV*?8L2#8J-BQV*?;C"`G
M*"<B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS
M9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(MBJV*?8L=N,
MV*X@V*?9AMF"V+;8I]BA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-S8*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@(MF&V878I]N,
MV8;8K]F'(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`BV+'9AMJO
M(-F^VXS8M.*`C-BRV87;C-F&V8<B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(D94
M4"!U<&QO860@;V8@<V5T=7`B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M<W%L+G!H<#HR,38*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N
M8V5S+B(*;7-G<W1R("(@V*C8I]BRVXS8I]BHVXP@V*K9@MBOV878I]BJ(-F&
MV*?9A=F(V8'9D=F"(-BHV8C8KR(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.CDX
M"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS
M9W-T<B`B(-BGV*K8M=BGV80@V*C9AR#:J=BGV+'8L]BGV+(@3$1!4"#9AMBG
MV879B-F!V9'9@B#8J-F(V*\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M
M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V
M97(N(@IM<V=S='(@(B#8I]BJV+78I]F$(-BHV8<@VJG8I]BQV+/8I]BR(%--
M0B#9AMBGV879B-F!V9'9@B#8J-F(V*\@(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HV.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O
M(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(B#8JMF'VXS9AR#8L=F(V8;9
MB-BTV*H@V*?8LB!<(B5S7"(@V8;8I]F%V8C9@=F1V8(@V*C9B-BO(@H*(R`C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*
M(R`*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.3$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R
M("+8I]N,V*S8I]BO(-BQV8C9AMF(V+38JB#8K]BQ(%PB)7-<(B#9AMBGV879
MB-F!V9'9@B#8J-F(V*\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN
M<&AP.C@W"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE
M8W1I;VXN(@IM<V=S='(@(B#8I]N,V*S8I]BO(-N,VJD@V*?8JMBUV*?9A"#8
MK-BOVXS8KR!305-,(-F&V*?9A=F(V8'9D=F"(-BHV8C8KR(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DW(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-S(T"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E
M('1O(%PB)7-<(BXB"FUS9W-T<B`B(-BGV8;8JMF"V*?9A"#8J-F'(%PB)7-<
M(B#9AMBGV879B-F!V9'9@B#8J-F(V*\B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C0V,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R("(@V*?9AMBJV8+8I]F$(-BH
MV8<@7"(E<UPB(-F&V*?9A=F(V8'9D=F"(-BHV8C8KR(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER(@IM
M<V=S='(@(MF$V+?;C-F!(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@
M27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G
M:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,
M22]#3$DN<&AP.C(S.`IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(MBN
MV+?8I]N,(-BLV*_;C#H@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(MF!VJG8LR(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#D*(RP@9G5Z>GD*;7-G
M:60@(D9A>&5S(@IM<V=S='(@(MF!VJG8LR(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G
M<W1R("+9@=F(V+';C-F'(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C`*
M;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R("+8L=JOV*C8I]BQ(-BN
MV8';C-F!(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`BVJG9A=N,
M(-BJVJ_8L=JO(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-`IM
M<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,S,S0*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S@*;7-G:60@
M(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I
M:FDB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C4U"B,L(&9U>GIY"FUS9VED(")&:6QE(@IM<V=S='(@(MF^V+'9B-F&V*_9
MAR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M
M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`BV+39A=BG
MV+'8M"#9OMBQV8C9AMBOV8<Z("5S(-F^V+'9B-F&V*_9AR(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I
M;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(MBTV878I]BQV+0@V;[8L=F(
MV8;8K]F'.B`E<R#9OMBQV8C9AMBOV8<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#`W"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`BV878
MK]N,V+$@V;[8L=F(V8;8K]F'(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<P"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#4*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R("+9AMBGV84@V;[8L=F(
MV8;8K]F'(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDY-0IM<V=I
M9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-F^V+'9
MB-F&V*_9AR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.#8*;7-G
M:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(MBGV+'8L]BGV80@V;[8L=F(V8;8
MK]F'(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4Y"FUS
M9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`BV*?8
ML=BSV*?9A"#9OMBQV8C9AMBOV8<@V;[8M-BJVXS8J-BGV8;;C"#9AMF%VXSB
M@(S8M-F(V*\N+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX.0IM
M<V=I9"`B1FEL=&5R<R(*;7-G<W1R("+9@=N,V838JMBQV8?8IR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`BV*_8L=BN
MV+<B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S="!(
M86QF(@IM<V=S='(@(MF&VXS9A=F'(-BGV8C9A"(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T
M(%%U87)T97(B"FUS9W-T<B`BV+'8J-BY(-BGV8C9A"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-38*;7-G:60@(D9I>"!R
M871I;R(*;7-G<W1R("+9AMBSV*C8JB#8J]BGV*C8JB(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S$*;7-G:60@(D9L:7`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`BV*?8N=BT
MV*?8L=N,(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R("+9A=F'XH",V*+9A-F(V*\B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(S-"!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E
M<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R("+9OMF(V+39AR`E<R#9A=F(
MV*S9B-BO(-F&VXS8L]BJ("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B
MV+'9AMJO(-F"V839A2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM
M<V=I9"`B1F]O9"(*;7-G<W1R("+8NMBPV*<B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*;7-G:60@
M(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S
M='(@(MBHV+'8I]N,(-F%V+'9B-BQVJ_8L=F'V*?;C-N,(-JIV8<@V*K8M=BG
MV8C;C-BQ(-BQV*<@V;[8M-BJVXS8J-BGV8;;C"#9AMF%VXSB@(S:J=F&V8;8
MKR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,T"FUS9VED(")&;W)E8V%S
M="`H5$%&*2(*;7-G<W1R("+9OMN,V+3"K=BHVXS9AMN,(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C<Y"FUS9VED("(B"B)&;W)E8V%S="!$
M87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@
M8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O
M=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U
M<B!P87-S=V]R9#\B"FUS9W-T<B`BV*?8L]F%(-BQV878LB#8KMF(V*\@V+'8
MIR#9@=BQV*?9A=F(V+0@VJG8L=BOV8?B@(S8I^*`C-N,V*_8GR(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C(*;7-G:60@(D9O<FUS(@IM<V=S
M='(@(MF!V+'9A=F'V*<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*
M;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`BV+?8I]F$V+DB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R
M("+9AMF(V+D@V+?8I]F$V+DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(MBWV*?9A-BYV8?8IR(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*
M;7-G<W1R("+8M]BGV838N=F'V*<@V[(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#4S"FUS9VED(")&;W)U;7,B"FUS9W-T<B`BV*?9AMBLV879
MAMF'V*<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`Y"FUS9VED
M(")&;W)W87)D<R(*;7-G<W1R("+8I]BQV*S8I]BYV8?8IR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R
M(@IM<V=S='(@(MBLV878N=F'(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S
M='(@(MJ&V*?8L=J&V8C8J-F'V*<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"B,L(&9U>GIY"FUS
M9VED(")&<F%N8V4B"FUS9W-T<B`BVH;8I]BQVH;9B-BHV8?8IR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-
M971R;W!O;&ET86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E
M;F-H($=U:6%N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E
M;F-H(%!O;'EN97-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@
M(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED
M(")&<F]M(@IM<V=S='(@(MBGV+(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C0X(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C`*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-@IM<V=I9"`B1G)O
M;2!T:&4@(@IM<V=S='(@(MBGV+(@(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z-#@*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T
M<B`BV+38L=BM(-JIV*?9A=F$(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q
M(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G
M<W1R("+9A=BGV8<@VJG8I]F%V80B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV,`IM<V=I
M9"`B1G5L;"!.86UE(@IM<V=S='(@(MF&V*?9A2#:J=BGV879A"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I
M9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`BVJ_8I]F$
MV+';C"#8J-BQV*?;C"#8K]BQVXS8I]F!V*H@V*K8M=F(VXS8L2`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(MJOV*?9A-BQVXPZ(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(B(*"B,@(RTC+2,M
M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("+8JMF(V83;
MC-BO(-F^VXS:J=BQV*C9AMBOVXP@)7,B"@HC.B!T96UP;&%T97,O861M:6XO
M<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS
M9W-T<B`BVJG8KR#8JMF(V83;C-BO(-BTV*_9AR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G
M:60@(D=E;W)G:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R
M;6%N>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G
M:60@(D=I=F5N($YA;64B"FUS9W-T<B`BV8;8I]F%(-BOV*?8K]F'(-BTV*_9
MAR(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*
M;7-G<W1R("+8J-BQV8@B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*
M;7-G:60@(D=O961E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R.`HC+"!F=7IZ>0IM<V=I9"`B1V]O
M9VQE($UA<',B"FUS9W-T<B`BV*S8L]F&V*S9B-N,(-JOV8C:K]F$(@H*(SH@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR
M,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C
M:"(*;7-G<W1R("+8K-BSV8;8K-F(VXP@VJ_9B-JOV80B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,W"FUS9VED(")'<F%Y
M<V-A;&4B"FUS9W-T<B`BV*_8L=BLV8<@V*[8I]JIV+/8JMBQVXPB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@U"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS
M9W-T<B`B1W)E96L@*$E33RTX.#4Y+3<I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B
M1W)E96YL86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=R96YA
M9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G:60@
M(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(MBSV+'9OMBQV+/8JMN,
M(-JOV+'9B-F'(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U
M<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R("+9AMBGV84@VJ_8
ML=F(V8<@V8;8J-BGVXS8KR#8KMBGV83;C"#8J-BGV+38KR(*"B,@"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O
M=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R
M("(B"B)!=71H7VQD87`ZV*?8MMBGV8'9AR#:J=BQV*_9AB#:J=BGV+'8J-BQ
M("5S(-F%V87:J=F&(-F&VXS8L]BJ+B#8I]N,V88@VH;;C-BRVXP@V*?8L]BJ
M(-JIV8<@VJG8I]BQV+/8I]BR(-JOV8'8JMF'(-BGV+/8JB(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-#$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U
M<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(D%U
M=&A?;&1A<#K8J-BQV8C8LMBQV+/8I]F&VXP@VJG8I]BQV*C8L2`E<R#9A=F%
MVJG9AB#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE
M('1O('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R(")!=71H7VQD87`ZV*C8L=F(
MV++8L=BSV*?9AMN,(-JIV*?8L=BHV+$@)7,@V879A=JIV88@V8;;C-BSV*HB
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(MJOV+'9B-F')B-X,C`P8SO9
MA]BG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(D=U97)N<V5Y
M(@IM<V=S='(@(MBRVXS8L=F^VXS8L=BGV8?9AMN,(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`BV878
MK-F(V++9A]BGVXP@V879A]F%V*?9AB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-S`*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R("+:J=BJV*?8
MJ-J&V8?9E"#;C-BGV*_8J-F(V*\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"B,L(&9U>GIY"FUS
M9VED(")'=6EN96$B"FUS9W-T<B`BVIC9B-BFV88B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*
M;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X
M"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U
M"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B2%1-3$%R96$@V*W8L-F!
M(-BBV*[8L=N,V88@V+/9A-F(V80@V+'8IR#8K]BQ(-BQV*_;C-F!(-BQV*\@
MV87;C.*`C-JIV8;8KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY
M(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB
M"FUS9W-T<B`B2%1-3$%R96$@V*W8L-F!(-BBV*[8L=N,V88@V+/8JMF(V88@
MV+'8IR#8K]BQ(-BLV*_9B-F$(-BQV*\@V87;C.*`C-JIV8;8KR(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*
M;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R96$@V*W8L-F!
M(-BBV*[8L=N,V88@V+'8K]N,V8$@V+'8IR#8K]BQ(-BLV*_9B-F$(-BQV*\@
MV87;C.*`C-JIV8;8KR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP
M:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`BV*K8M=BOVXS9@B#9A]F(VXS9D=BJ($A45%`@VXS8I]F!V*K9
MAR#9AMBTV*\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(DAA:71I
M(@IM<V=S='(@(MF&V+/8J-BJ(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G<W1R("+8
MI]F$VJ_9B-BQVXS8JMF%($AA<V@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B2&%Z92(*;7-G<W1R("+9A=F'
MXH",V*+9A-F(V*\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,3D@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,@IM<V=I9"`B2&5A9&5R(@IM
M<V=S='(@(MBSV+'8HMF%V*\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y
M<&4O=&%B;&5S970N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")(96%D97)S(@IM
M<V=S='(@(MBSV+'8HMF%V*\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D
M($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PHC+"!F=7IZ
M>0IM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R(")4+5-T;W)M<R(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED(")(96)R97<@*$E33RTX
M.#4Y+3@M22DB"FUS9W-T<B`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(MBHV839AMBOVXPB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D
M92](;W)D92](96QP+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP
M:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G:60@(DAE;'`B
M"FUS9W-T<B`BV+'8I]F'V8;9A=BG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET
M;W(B"FUS9W-T<B`BV+'8I]F'V8;9A=BGVXP@V*?8L]BJV8'8I]BOV8<@V*?8
MLB#9B-N,V+'8I]N,V+3:K]BQ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3,W,0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(MJIV87:J2#:J=F&V8;8
MK]F'(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H
M97)E(@IM<V=S='(@(MF&VXS9A>*`C-JIV+'9AR(*"B,Z('1E;7!L871E<R]D
M871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z
M(@IM<V=S='(@(MBGVXS9AMBLV*<@V*?8J-BJV*_8I]N,(-F^V+'9B-F&V*_9
MA^*`C"#9A=N,XH",V*C8I]BTV*\Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DAI9V@B"FUS9W-T<B`BV*C8
MI]F$V*<B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA
M=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*;7-G:60@(DAO7VUE(@IM
M<V=S='(@(MBNV*?9AMF'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3
M964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-3,U"FUS9VED(")(;VUE(@IM<V=S='(@
M(MBNV*?9AMF'(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`BV*+8K]BQ
MV+,@V*[8I]F&V8<B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G
M:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(MBTV*?8KMF'V90@V*?8M=F$
MVXPB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(MBTV878I]BQV8<@V*K9
MA-F!V88@V879AMBRV80B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-0IM<V=I
M9"`B2&]R9&4B"FUS9W-T<B`BV8?9B-BQV*\B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S
M86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B`E<R#8J-BG(-BOV*?8K]F'
M(-F&V*?8K]BQV+/8JB!834P@V*_8L2#9OMN,V+K8I]F%("5S(-F%V8C8I]BL
MV8<@V+38K]F'(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M
M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D
M92]+;VQA8CH@V8?;C-J&(-F^VXS8NMBGV87;C"#9A=BWV*?8J-F"V*H@V*C8
MIR#8M-N,V*$@)7,@V8;8K]BGV+'8KR(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z-#,U"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM
M<V=S='(@(DAO<F1E+TMO;&%B.B#9A]N,VH8@V+3;C-BFVXP@V*?8LB#9AMF(
MV+D@)7,@V*_8L2#9OMN,V+K8I]F%("5S(-N,V*?9@=BJ(-F&V+38KR(*"B,@
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(U,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@
M)7,@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B#8J-BG(-F%V8C9@=F1
MV8+;C-F1V*H@)7,@7"(E<UPB(-BMV+#9@2#8M-BO(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@
M:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@
M97AT96YS:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM
M<V=S='(@(DAO<F1E+TMO;&%B.B#8JMF(V83;C-BO(-N,VJD@V*_8L=BNV*H@
MV*S8K]N,V*\@6$U,(-BHV+'8I]N,(-BTVXS8H2`E<R#9A=F"V*_9B-BQ(-F&
MVXS8L]BJ("(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E
M;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B#8K=BP
MV8$@)7,@7"(E<UPB.B5S(-F%V8+8K]F(V+$@V8;;C-BSV*HB"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R
M('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(-BH
MV*?8LMN,V*?8J-N,("!-24U%($E$(-BHV+'8I]N,(-F"V+/9A=BJVXP@V*?8
MLB#9AMF(V+D@)7,@V879@MBOV8C8L2#9AMN,V+/8JB`B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$Q.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z
M("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B#8L]F&VJG8L=F(V88@VJG8L=BO
MV88@)7,@7"(E<UPB.B`E<R#9A=F"V*_9B-BQ(-F&VXS8L]BJ(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,V"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S
M.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@V+/9AMJIV+'9B-F&(-JIV+'8
MK]F&(-BGV+38JMBQV*?:J=F'V*<@V879@MBOV8C8L2#9AMN,V+/8JCH@)7,B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B
M"FUS9W-T<B`B2&]R9&4O2V]L86(Z(-BGV+38JMBQV*?:J2#9AMBGV+39AMBG
MV*[8JMF'(%PB)7-<(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R
M("+9@MBGV8;9B-F&(-BGV8'9@MN,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D
M:6YG(@IM<V=S='(@(MF!V*?8M=F$V8?B@(S:K]BPV*?8L=N,(-BGV8'9@MN,
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B.MBGV8'9@MN,(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O
M<G0A*2(*;7-G<W1R("+:AMJOV8C9AMF'(-BHV*<@V*?;C-F&V*S8IR#8HMBT
MV8;8IR#8M-BOVXS8K]B?("C9A-BWV8'8I]F+(-JOV++8I]BQV+0@V*_9A]N,
MV*\I(2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U
M(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(MJ&V8;8KR#8L]BJV8C9AB#8L=BG
M(-F%VXSB@(S8KMF(V*?9A]N,V*\@V*?8K]BZV*?9A2#:J=F&VXS8K]B?(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M
M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R("+:AMF&
MV*\@V8';C-F$V*\@*-BSV*K9B-F&*2#9B-BLV8C8KR#8K]BGV+'8K]B?(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M
M97)G93\B"FUS9W-T<B`BVH;9AMBO(-BSV+?8L2#8L=BG(-F%VXSB@(S8KMF(
MV*?9A]N,V*\@V*?8K]BZV*?9A2#:J=F&VXS8K]B?(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO;65T87(N<&AP.C(S
M,`IM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`BV+'8M]F(V*C8JB(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3D*;7-G:60@(DAU;6ED:71Y
M.B`B"FUS9W-T<B`BV+'8M]F(V*C8JCH@(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W,B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G-Q;"YP:'`Z,C,U"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I
M;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(MBGVXS8K-BGV*\@
MV8;8I]F%V8?B@(S8K]BGV88@24U!4"#9AMBGV879B-F!V9'9@B#8J-F(V*\Z
M("`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M
M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM
M<V=S='(@(MBMV+#9@2#9AMBGV879A^*`C-BOV*?9AB!)34%0(-F&V*?9A=F(
MV8'9D=F"(-BHV8C8KR`Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)U<RYP:'`Z,3<Y(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR
M-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R
M96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`BV*?;C-BLV*?8KR#9A=BMV*_9
MB-BOVXS9D=BJ(-F&V*?9A=F'XH",V*_8I]F&($E-05`@V8;8I]F%V8C9@=F1
MV8(@V*C9B-BO(#H@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S$V"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(MBBV*_8L=BS($E0(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B
M25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("+8HMBOV+'8LR!)
M4"#9@MBGV*C9A"#8K]BSV*K8L=BSVXP@V8;;C-BSV*HB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S
M(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("+8HMBO
MV+'8LR!)4"#8K]BQ(-BOV*?8KMF$(-BHV839B-JI($-)1%(@V*?8K-BGV++9
MAR#8K]BGV*_9AR#9AMF%VXSB@(S8M-F(V*\B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO
M8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))
M7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`BV*?8J-BJV*_8IR#8L]BWV+$@
MV+'8IR#9B-BGV+'8KR#:J=F&VXS8KR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B
M26-E;&%N9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S<V"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@(MF!V8+8MR#8HMN,VJG9
MB-F&V8?8IR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S
M*2`@(RTC+2,M(RTC"B,@"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`BV*+;
MC-JIV8C9AMF'V*<@V*C8L=BGVXP@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S<W"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`BV*+;
MC-JIV8C9AMF'V*<@V*C8IR#9A=BJV88B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3DP"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(MF&
MV*?9A2#9A]F(VXS9D=BJ.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C4Y,@HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N
M;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE
M=R!W:6YD;W<N(@IM<V=S='(@(MBGVJ_8L2#8HMF&(-BHV8<@V*_8L=BSV*K;
MC"#9AMF%V*?;C-BT(-BOV*?8K]F'(-F&V+38K]B,("5S("#8J-BQV*?;C"#8
MJ-BGV+(@VJG8L=BOV88@V*+9AB#8K]BQ(-N,VJD@V;[9AMBLV+'9AR#8K-BO
MVXS8KR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-34*;7-G:60@(B(*
M(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X
M<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@
M='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@HBV*?:K]BQ
M(-BTV878IR#9A]N,VH8@V*+;C-JIV8C9AMN,(-BQV*<@V*_8L2#9A=BQV8C8
ML=JOV+$@V8;8J-N,V8;;C-BOV(P@V879A=JIV88@V*?8L]BJ(-F$V*?8LMF%
M(-BHV*?8M-BO(-JIV8<@4$Y'("(*(E1R86YS<&%R96YC>2#8L=BG(-BNV*?9
MA=F(V+0@VJG9AMN,V*\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3<S"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S
M<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO
M860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS
M9W-T<B`B(@HBV*?:K]BQ(-BTV878IR#8I]N,V88@V;[;C-BZV*?9A2#8L=BG
M(-F%V+38I]F'V*_9AR#:J=F&VXS8KR#8I]F%V*<@V*K8M=F(VXS8L=N,(-BQ
MV*<@V878M-BGV8?8K]F'(-F&VJG9AMN,V*_8C"#8I]N,V88@V*C9AR#8I]N,
MV88@V+G9A-BJ("(*(MBNV8C8I]F'V*\@V*C9B-BO(-JIV8<@V878L=F(V+':
MK]BQ(-BTV878IR#9@=BGV*_8L2#8J-F'(-F&V878I]N,V+0@V*K8M=F(VXS8
ML2#9AMN,V+/8JB`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E(%!R979I97<Z
M(@IM<V=S='(@(MF^VXS8M.*`C-F&V878I]N,(-BJV+79B-N,V+$Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(E523"#8JMBUV8C;C-BQ(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(E523"#8JMBU
MV8C;C-BQ.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y
M(@IM<V=S='(@(MBJV+79B-N,V+$@V*?8LB#:K]BGV838L=N,(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(MBJV+79
MB-N,V+$@V*?8LB#:K]BGV838L=N,.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$W-C$*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R("+8I]BQ
MV+/8I]F$(-BJV+79B-N,V+$B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(MBJV+78I]F(VXS8L2(*"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@
M"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A
M=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(MBOV+'9B-F&XH",
MV*C8L=BOV(P@VJ_8I]F%("5D(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN
M<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@
M9FEE;&0Z("5S(@IM<V=S='(@(MF!VXS9A-BO(-BOV+'9B-F&XH",V*C8L=BO
M(-BTV*_9ASH@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U
M"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(MF!VXS9A-BOXH",
MV8?8I]N,(-BOV+'9B-F&XH",V*C8L=BO(-BTV*_9ASHB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*;7-G
M:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(MBHV+G8K]BGV8L@V+/8
MM]BQ(-BQV*<@V8C8I]BQV*\@VJG9AMN,V*\B"@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S4*;7-G:60@(DEN8V]R<F5C="!A
M8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`BVJG8KR#8N=F%V83:J=BQV*\@
MV8;8I]BOV+'8L]BJ(-BOV*?8K]F'(-BTV*_9AR#8I]BSV*HB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@IM<V=I
M9"`B26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T
M<B`B(-F&V*?9A2#:J=BGV+'8J-BQ+]BGV+/9A2#8L=F%V+(@(-F&V*?8K]BQ
MV+/8JB#8I]BSV*HB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU
M,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A
M9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T
M<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B+9
MAMBGV84@VJG8I]BQV*C8L2#;C-BG(-BBV*_8L=BS(-BLV*?;C-JOV++;C-F&
M(-F&V*?8K]BQV+/8JB#9A=N,XH",V*C8I]BTV*\N(-F$V+?9@=BG(-F%V*S8
MK]BOV*?9DB#8L]BYVXP@VJG9AMN,V*\@V8@@VXS8IR#8K]BQ(-BUV8C8L=BJ
M("(*(MF&VXS8I]BR(-BHV8<@VJG9A=JI(-BHVXS8M-BJV+$@V*C8IR#8L]BQ
MV;[8L=BSV*H@V+/8I]F%V*?9AMF'(-BJV878I]BS(-BHVJ_;C-BQVXS8KR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*
M;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("+8I]F!V++8I]N,V+0@
MV*K9B-BQV8'8JMJOVXPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DEN9&EA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C4T
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("));F1I=FED
M=6%L(%5S97)S(@IM<V=S='(@(MJIV*?8L=BHV+'8I]F&(-BNV*?8M2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@
M(DEN9F\B"FUS9W-T<B`BV*?8M]F$V*?8N=BGV*HB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C4W"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R
M("+8I]BWV838I]BYV*?8JB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS,S`*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B
M;&4N(@IM<V=S='(@(MBGV+?9A-BGV+G8I]BJ(-BOVXS:K]BQ(-BOV+$@V*_8
ML]BJV+'8LR#9AMN,V+/8JB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU
M;6X@069T97(B"FUS9W-T<B`BV*_8L=BL(-BSV*K9B-F&(-BHV+G8KR#8I]BR
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(P"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`BV*_8
ML=BL(-BJV+79B-N,V+$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`B
MV*_8L=BL(-BLV*_9B-F$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S
M='(@(MBOV+'8K"#9OMN,V8C9AMBO(-F(V*@B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN
M<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("+8I]BHV*K8K]BG(-BSV*K9
MB-F&(-BQV*<@V*_8L=BL(-JIV8;;C-BO(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E
M<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R
M("+;C-JI(-BSV*K9B-F&(-BLV*_;C-BO(-BHV+G8KR#8I]BR(-BSV*K9B-F&
M(-F!V+G9A-N,(-BOV+'8K"#:J=F&VXS8KR(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS
M97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S
M='(@(MN,VJD@V+/8JMF(V88@V*S8K]N,V*\@V8+8J-F$(-BGV+(@V+/8JMF(
MV88@V8'8N=F$VXP@V*_8L=BL(-JIV8;;C-BO(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("))
M;G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R
M("+;C-JI(-BSV+?8L2#8K-BOVXS8KR#8J-BYV*\@V*?8LB#8L]BWV+$@V8'8
MN=F$VXP@V*_8L=BL(-JIV8;;C-BO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@
M82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`BVXS:
MJ2#8L]BWV+$@V*S8K]N,V*\@V8+8J-F$(-BGV+(@V+/8M]BQ(-F!V+G9A-N,
M(-BOV+'8K"#:J=F&VXS8KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R
M86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`BVXS:J2#9
MOMBGV+'8I]JOV+'8I]F!(-BHV+G8KR#8I]BR(-JOV+'9AR#9@=BYV83;C"#8
MK]BQV*P@VJG9AMN,V*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G
M<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("+;C-JI(-F^
MV*?8L=BGVJ_8L=BGV8$@V8+8J-F$(-BGV+(@VJ_8L=F'(-F!V+G9A-N,(-BO
MV+'8K"#:J=F&VXS8KR(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS
M9VED("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(MBOV+'8
MK"#8I]F$VJ_9B-N,(-BLV*?;C-JOV++;C-F&(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(S.0IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@
M=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM
M<V=S='(@(MN,VJD@V*+8K]BQV+,@V;[8L]BJ(-BGV83:J=BJV+'9B-F&VXS:
MJ2#8J-BQV*?;C"#8K]BQVXS8I]F!V*H@V*?8L]F%(-BQV878LB`@V*S8K]N,
MV*\@V*_8L=BL(-JIV8;;C-BO("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL
M(&%F=&5R(@IM<V=S='(@(MBOV+'8K"#8L]F$V8C9A"#8J-BYV*\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y
M"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`BV*_8L=BL(-BS
MV839B-F$(-F"V*C9A"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T
M97(B"FUS9W-T<B`BV*_8L=BL(-BSV*K9B-F&(-BHV+G8KR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G
M:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(MBOV+'8K"#8L]BJ
MV8C9AB#9@MBHV80B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(MBO
MV+'8K"#9OMN,V+K8I]F%(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@<&%R86=R
M87!H(&%F=&5R(@IM<V=S='(@(MBOV+'8K"#9OMBGV+'8I]JOV+'8I]F!(-BH
MV+G8KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B
M"FUS9W-T<B`BV*_8L=BL(-F^V*?8L=BGVJ_8L=BGV8$@V8+8J-F$(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M.0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("+8K]BQV*P@V+/8
MM]BQ(-BHV+G8KR`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*
M;7-G<W1R("+8K]BQV*P@V+/8M]BQ(-F"V*C9A"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,S`*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS
M=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`BV;[8I]BS
MV*X@V879B-BQV*\@V8;;C-BGV+(@V+'8IR#8J-BQV*?;C"#8L]BFV8C8I]F$
M(-BGV879AMN,V*K;C"#8K]BQV*P@VJG9AMN,V*\Z(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS97)T
M+TUO9&EF>2!);6%G92(*;7-G<W1R("+8K]BQV*POV*K8NMN,VXS8L2#8JMBU
MV8C;C-BQ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@(MBO
MV+'8K"_8JMBZVXS;C-BQ(-F^VXS9B-F&V*\B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS=69F
M:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES
M="XB"FUS9W-T<B`BV*?8N=BJV*C8I]BQ(-F&V*?:J=BGV8';C"#8J-BQV*?;
MC"#8I]BQV+/8I]F$(-BHV8<@V8'9A]BQV+/8JB#8JMF(V++;C-BYVXPB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`BV*?8N=BJ
MV*C8I]BQ(-F&V*?:J=BGV8';C"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P-S4*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`BV+G8K]BO(-BUV*W;
MC-BM(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$S,PIM<V=I9"`B
M26YT96=E<B!L:7-T(@IM<V=S='(@(MF!V8?8L=BSV*H@V+G8K]BO(-BUV*W;
MC-BM(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D
M97(I+B(*;7-G<W1R(")51$@@V8;8I]F%V+G8JMBHV+$B"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ-S`*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q,`HC+"!F=7IZ>0IM<V=I9"`B
M26YV86QI9"!:25`@9&%T82(*;7-G<W1R("+8K]BGV*_9AR#;C-F(V8;;C-JI
MV*\@V8;8I]F%V+G8JMBHV+$@(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`BV*C8
ML=F&V*?9A=F'V90@VJG8I]BQV*C8L=BOVXP@V8;8I]F%V+G8JMBHV+$B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(MBOV+/8JMF'
M($E$(-F&V*?9A=BYV*K8J-BQ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R
M("+8K]BGV*_9A]F4(-F&V*?9A=BYV*K8J-BQ(-BGV+'8I]BFV8<@V+38K]F'
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`P"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM
M<V=S='(@(MBBV*_8L=BS(-F%V8+8M=BO(-F&V*?9A=BYV*K8J-BQ(@H*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z.#$*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3`P"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(R,`IM<V=I9"`B26YV
M86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R("+9@MBGV838J"#9OMBQV8C9AMBO
MV8?9E"#9AMBGV878N=BJV*C8L2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-S<*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;&EC96YS92!K
M97DN(@IM<V=S='(@(MBHV+'9AMBGV879A]F4(-JIV*?8L=BHV+'8K]N,(-F&
MV*?9A=BYV*K8J-BQ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$W,0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E
M9"XB"FUS9W-T<B`BV*C8L=F&V*?9A=F'V90@VJG8I]BQV*C8L=BOVXP@V8;8
MI]F%V+G8JMBHV+$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM
M<V=S='(@(MF&V8C8N2#9OMN,V+K8I]F%(-F&V*?9A=BYV*K8J-BQ(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S
M"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R(")A
M<&E?:60@V8;8I]F%V+G8JMBHV+$@V*?8L]BJ(-F((-N,V*<@V*?8LB#8J-N,
MV88@V+'9@=BJV8<@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI
M<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`BV;[8I]BQV*?9A=BJV+$@V8;8
MI]F%V+G8JMBHV+$@V8@@VXS8IR#8I]BR(-BHVXS9AB#8L=F!V*K9AR(*"B,Z
M(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI9"!P
M87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`BV878K-F(V+(@V;[8K]BQ(-F&
MV*?9A=BYV*K8J-BQ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$W,PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G
M<W1R("+9A=BLV8C8LB#9OMBOV+$@V8;8I]F%V+G8JMBHV+$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"B,L(&9U>GIY"FUS9VED("))
M;G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T<B`BV;[8L=F(V*K:J=F$(-F&
MV*?9A=BYV*K8J-BQ(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*
M;7-G<W1R("+9OMBQV8C8JMJIV80@V8;8I]F%V+G8JMBHV+$B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@(MJOVXS8
ML=F&V*_9A]F4(-F&V*?9A=BYV*K8J-BQ.B!<(B5S7"(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$P-S8@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HQ,C8R"FUS9VED("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R
M("+8M-N,V*$@V*C9AR#8I]BTV*K8L=BGVJD@VJ_8L-BGV+38JMF'(-BTV*_9
MA]F4(-F&V*?9A=BYV*K8J-BQ(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED("));G9A;&ED('-O=7)C
M92!A9&1R97-S+B(*;7-G<W1R("+8HMBOV+'8LR#8L]BQVH;8M-F%V8<@V8;8
MI]F%V+G8JMBHV+$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A
M+B(*;7-G<W1R("+8K]BGV*_9AR#;C-F(V8;;C-JIV*\@V8;8I]F%V+G8JMBH
MV+$@(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U-PIM<V=I9"`B
M26YV96YT;W)Y(@IM<V=S='(@(MF%V8C8K-F(V*_;C"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-SD*;7-G:60@(DEN=F5R
M="!S96QE8W1I;VXB"FUS9W-T<B`BV*C8L=JOV+'8K]BGV8;8K]F&(-BGV8;8
MJMBNV*?8J"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L86UI8R!2
M97!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER
M87$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<F5L86YD(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS
M9VED("))<VQE(&]F($UA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3
M=&]R;7,B"FUS9W-T<B`B5"U3=&]R;7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@
M(DES<F%E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8R-0IM<V=I9"`B27-S=65R(@IM<V=S='(@(MF%V8;8JMBT
MV+$@VJG9AMF&V*_9AR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(MBMV+'9B-F!
M(-JIV*PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#(*(RP@9G5Z>GD*;7-G:60@(DET86QY(@IM
M<V=S='(@(MBMV+'9B-F!(-JIV*PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA
M;6%I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`BVIC8I]F&
MV8C;C-F'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*87!A;B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM<V=I9"`B2F%P86YE<V4@
M*$E33RTR,#(R+4I0*2(*;7-G<W1R(")*87!A;F5S92`H25-/+3(P,C(M2E`I
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*;7-G:60@(B(*
M(DIA=F%S8W)I<'0@:&%S(&)E96X@9&ES86)L960@;VX@>6]U<B!B<F]W<V5R
M(&%N9"!T:&ES('!A9V4@;6%Y(&YO="!B92`B"B)D:7-P;&%Y:6YG(&-O<G)E
M8W1L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R("+8LMN,V+'9OMN,V+'8I]F'
MV8;;C"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#<*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS
M9VED(")*=6QY(@IM<V=S='(@(MJ8V8C8IMN,V8<B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G
M<W1R("+:F-F(V*;9AB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B
MV8?9A>*`C-BJV+'8I]BR(-JIV+'8K]F&(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I
M9GD@0V5N=&5R(@IM<V=S='(@(MF'V87B@(S8JMBQV*?8LMN,(-F(V+/8MR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`BV8?9A>*`C-BJ
MV+'8I]BRVXP@VJG8I]F%V80B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T
M(@IM<V=S='(@(MF'V87B@(S8JMBQV*?8LMN,(-J&V;XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I
M9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R("+9A]F%XH",V*K8L=BGV++;C"#8
ML=BGV+/8JB`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(V-`IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`BV*?8M=F$
MVXP@V8;:K]F'(-BOV*?8M-BJV8<@V+39B-BOV)\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*
M;7-G:60@(DME;GEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E
M9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BVJG8I]BQV+/8I]BR(&ME<F)E
M<F]S92#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@V+'8IR#8L=BO(-JIV+'8KR(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE
M=V)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`BV*?;C-BL
MV*?8KR#:J=F$VXS8KR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(MBGV*O8
ML2#8I]F&VJ_8M-BJ(-JIV83;C-BO(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@(MBW
MV8C9A"#:J=F$VXS8KR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`BV8;9B-BY(-JIV83;
MC-BO(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*
M;7-G:60@(DME>2!5<V%G92(*;7-G<W1R("+:J=BGV+'8J-BQV*\@VJG9A-N,
MV*\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G
M:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BXB"FUS9W-T<B`BVJG9A-N,V*\@V8+8J-F$V*?9BR#8K]BQ(-JIV*?8L=BS
MV*?8LB#8N=F%V8C9A=N,(-JIV83;C-BO(-F%V8C8K-F(V*\@V*?8L]BJ(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S
M='(@(N*`C-BHVH;9A^*`C-F'V*<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI
M<FEB871I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L
M($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(DMO<F5A
M;B`H155#+4M2*2(*;7-G<W1R(")+;W)E86X@*$550RU+4BDB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*
M;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@(MBLV*?9
MAMF%V*?;C-N,(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM
M<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`BV++8J-BGV88B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-CD*;7-G:60@(DQA
M<W0@2&%L9B(*;7-G<W1R("+9AMN,V879A]F4(-BBV*[8L2(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HW-@IM<V=I9"`B3&%S="!087-S=V]R9"!#:&%N
M9V4B"FUS9W-T<B`BV*K8NMN,VXS8L2#8HMBNV+';C-F&(-BGV+/9A2#8L=F%
MV+(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN
M<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`BV+'8J-BY(-BB
MV*[8L2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Q"FUS9VED("),87-T
M(%5P9&%T960Z(@IM<V=S='(@(MBBV*[8L=N,V88@V*C8L=F(V++8L=BSV*?9
MAMN,.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R("+8HMBNV+';
MC-F&(-F(V+'9B-BO.B`E<R(*"B,@"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.C<R,0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F
M<F]M("5S(@IM<V=S='(@(MBBV*[8L=N,V88@V8C8L=F(V*\@.B`E<R#8I]BR
M("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$V"FUS9VED("),
M87-T(&QO9VEN.B!.979E<B(*;7-G<W1R("+8HMBNV+';C-F&(-F(V+'9B-BO
M.B#9A]BQVJ_8LB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0HC+"!F=7IZ>0IM<V=I9"`B3&%T
M=FEA(@IM<V=S='(@(MBOV*?8K]F'(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0T"FUS9VED("),87<B"FUS9W-T<B`BV*W9@MF(V8(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*;7-G
M:60@(DQA>6]U="(*;7-G<W1R("+8K-BGV8;9A=BGVXS;C"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE
M879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F
M="(*;7-G<W1R("+:AMF^(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$Q.0IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`BV+/8L=BBV878KR#:
MAMF^(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-0IM<V=I9"`B
M3&5F="!V86QU97,B"FUS9W-T<B`BV879@MBGV*_;C-BQ(-J&V;XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#@*(RP@9G5Z>GD*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`BV+'9
MB-BT(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U
M>GIY"FUS9VED("),979E;"(*;7-G<W1R("+8N=BTV8(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS
M9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B
M3&EG:'0@1')I>GIL92(*;7-G<W1R("+9AMF%XH",V8;9A2#8J-BGV+'8I]F&
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*
M;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`BV*C8I]BQV8;8K]JOVXP@V+/8
MJ-JI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`BV*C8I]BQV8;8
MK]JOVXP@V+/8J-JI(-BRV8C8K]F'V8;:K]BGV84B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I
M;B!,871E(@IM<V=S='(@(MBHV*?8L=F&V*_:K]N,(-BSV*C:J2#8K]N,V+'9
MA]F&VJ_8I]F%(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(MBH
MV*?8L=F&V*_:K]N,(-F((-BQVJ_8J-BGV+$@V+/8J-JI(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT
M(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(MBHV*?8L=BGV88@V+/8J-JI
M(-BHV8<@V8?9A=BQV*?9AR#8L=BYV*\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G
M<W1R("+8J-BQV8$@V+/8J-JI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM
M<V=S='(@(MBHV+'9@2#9B"#8L=JOV*C8I]BQ(-BSV*C:J2(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-`IM<V=I9"`B3&EN
M:R(*;7-G<W1R("+9OMN,V8C9AMBO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O
M:6YT<R!T;SHB"FUS9W-T<B`BV8;9@MBGV+<@V;[;C-F(V8;8KR#8J-F'.B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S4*;7-G:60@(DQI;FL@
M=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I
M<W!L87EI;F<B"FUS9W-T<B`BV*+8K]BQV+,@V;[8L]BJ(-BGV83:J=BJV+'9
MB-F&VXS:J2#8L=BG(-BHV8<@V+79@=BMV8<@V*?;C-BLV*?8KR#9OMN,V+K8
MI]F%V(P@V*C9AR#9A]F&VJ_8I]F%(-F%V+38I]F'V*_9A]B,(-F^VXS9B-F&
MV*\@V*_9A]N,V*\B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED("),:6YK<R(*;7-G<W1R("+9OMN,
MV8C9AMBOXH",V8?8IR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM
M<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(MJIV8C:J=N,(-F$VXS9AMF(
MVJG8LR(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS
M9W-T<B`BV8'9A]BQV+/8JB`M(-JIV*?8L=BHV+$@V87;C.*`C-BJV8C8I]F&
MV*\@V;[9B-BTV8<@V+'8IR#8J-BHVXS9AMBO(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`BV8'9
MA]BQV+/8JB#8K]BGV*_:K]BGV8;9A]BGXH",(@H*(SH@<V5R=FEC97,O:&5L
M<"]I;F1E>"YP:'`Z-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T
M<B`BV8'9A]BQV+/8JB#8N=F&V*?9B-N,V88@V+'8I]F'V8;9A=BG(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM<V=I9"`B3&ES="!486)L97,B"FUS
M9W-T<B`BV8'9A]BQV+/8JB#8K-BOV*?9B-F$(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12](96%D97)S+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*
M;7-G<W1R("+9@=F'V+'8L]BJ(-BBV+'8M-N,V8@B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4X.0IM<V=I9"`B3&ES="U(96QP(@IM
M<V=S='(@(MF!V8?8L=BSV*H@V+'8I]F'V8;9A=BG(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12](96%D97)S+G!H<#HU.38*;7-G:60@(DQI<W0M260B"FUS
M9W-T<B`BV8'9A]BQV+/8JB!)9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@(MF!
MV8?8L=BSV*H@V878I]F$VJDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE
M861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(MF!V8?8
ML=BSV*H@V;[8L]BJVXPB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E
M<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`BV8'9
MA]BQV+/8JB#8N=BVV8C;C-F1V*HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G
M<W1R("+9@=F'V+'8L]BJ(-BYV*_9A2#8N=BVV8C;C-F1V*HB"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(DQI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R("+9@=F'V+'8
ML]BJ(-JIV*?8L=BHV+'8I]F&(-F!V+G8I]F$(-F&V87;C.*`C-BHV*?8M-BO
M(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B
MV8'9A]BQV+/8JB#:J=BGV+'8J-BQV*?9AB#9@=BYV*?9A"#9AMF%VXSB@(S8
MJ-BGV+38KR(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z
M,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B
MV8'9A]BQV+/8JB#:J=BGV+'8J-BQV*?9AB#9@=BYV*?9A"#9AMF%VXSB@(S8
MJ-BGV+38KR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I9"`B
M3&ET97)A='5R92(*;7-G<W1R("+8I]BOV*C;C-BGV*HB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#D*(RP@9G5Z>GD*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("+9B-BGV*W8
MKR#9OMF'V8;8IR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z.#,*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`BV*C8I]BQ
MVJG8L=BOV88N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C$Q"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`BV+/8I]BYV*H@V878
MK=F$VXPZ("(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,PIM<V=I9"`B
M3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(MF%V*W9A-N,V9'8JB#9B"#8L]BG
MV+G8JB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-`HC.B!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV-0IM<V=I9"`B
M3&]C871I;VXB"FUS9W-T<B`BV879B-F"V+G;C-BJ(@H*(SH@;&]G:6XN<&AP
M.C$W,B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3DQ('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z,34@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B
M3&]G(&EN(@IM<V=S='(@(MF(V+'9B-BO(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S
M97-S:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HQ.#4*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`BV*[8L=F(V*PB"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*;7-G:60@(DQO9VEN(@IM<V=S
M='(@(MF(V+'9B-BO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-PIM
M<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`BV8C8N-BGVXS9@2#9B-BQV8C8
MKR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY-@IM<V=I9"`B3&]G
M:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W
M87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`BV8C8L=F(V*\@V8;8
MI]F%V8C9@=F1V8(@V*C9B-BO(-BRVXS8L=BG(-F&V*?9A2#:J=BGV+'8J-BQ
M(-F((-N,V*<@V*?8L]F%(-BQV878LB#9B-BGV+'8KR#8M-BOV8<@V*?8M-BJ
MV*C8I]F'(-BHV8C8KR`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.3(*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`BV8C8L=F(V*\@V8;8
MI]F%V8C9@=F1V8(@V*C9B-BO+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$S-C4*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R("+9A=BJV88@V*C9
MA-F&V*\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO
M=F4B"FUS9W-T<B`BV+G8M-F"(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(DQO=R(*;7-G<W1R("+9OMBGVXS;
MC-F&(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G
M<W1R("+8K=BQV8C9@2#:J=F(VH;:J2#;C-F(V8;8I]F&VXPB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y
M"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@(MBMV+'9B-F!
M(-JIV8C:AMJI(-F$V*?8JMN,V88B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R
M;VUA;B!N=6UB97)S(@IM<V=S='(@(MBGV+G8K]BGV*\@VJG9B-J&VJD@VXS9
MB-F&V*?9AMN,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0S."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS
M9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Q"FUS
M9VED(")-3U1$(@IM<V=S='(@(MF^VXS8NMBGV84@V+'9B-BR(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3
M+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B
MV;[;C-F(V+/8JB!-4RU43D5&(-BTV*?9A=F$(-F'VXS:AB#8K]BGV*_9A^*`
MC-BGXH",VXS;C"#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@
M(DU31R(*;7-G<W1R(")-4T<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G
M:60@(DUA8V%O(@IM<V=S='(@(MBJV+G8M]N,V838I]BJ(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A
M9V%S8V%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M.0IM<V=I9"`B36%G:6,B"FUS9W-T<B`BV*S8I]BOV8@B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z.#$*;7-G:60@(DUA:6PB"FUS9W-T<B`BV8;8
MI]F%V8<@V*?9A-JIV*K8L=F(V8;;C-JIVXPB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-3(R"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@(MBS
MV+'9OMBQV+/8JB#9AMBGV879AR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?
M:RXN+B(*;7-G<W1R("+8L]BGV*[8JMF&(-F^VXS9B-F&V*\N+BXB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA;&%W:2(*;7-G<W1R("+9AMBG
MV879AR#8I]F$VJG8JMBQV8C9AMN,VJG;C"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I
M9"`B36%L87ES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-
M86QD:79E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G
M:60@(DUA;&DB"FUS9W-T<B`BV8;8I]F%V8<@V*?9A-JIV*K8L=F(V8;;C-JI
MVXPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA;'1A(@IM<V=S
M='(@(MF&V*?9A=F'(-BGV83:J=BJV+'9B-F&VXS:J=N,(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDQ"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@
M;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A
M;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S
M+B(*;7-G<W1R("+9A=BOVXS8L=N,V*H@V8@@V*K8N=N,VXS9AB#8L=F&VJ\@
MV*_8L]BJV8?B@(S9A]BGVXS;C"#:J=F'(-BTV878IR#9A=F(V*?8L=BO(-BQ
MV*<@V*C8IR#8HMF&V8?8IR#9AMBGV87B@(S:K]BPV*?8L=N,(-F%VXSB@(S:
MJ=F&VXS8KR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,34S"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B36%P,C0@;6%P
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q
M-C@*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R(")-87!1=65S="!M87`B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA
M<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@
M(MF%V*?8L=BS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(MBMV*?8
MM-N,V8<B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S
M='(@(MBYV838I]F%V*H@VJ_8L-BGV+';C"#8J-BG(-F^V+':AMF%(-F%V+38
MI]F'V*_9AR#8M-BOV8<O(-F%V+38I]F'V*_9AR#9AMBTV*_9AR(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-
M87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D
M*2(*;7-G<W1R("(@V+G9A-BGV878JB#:K]BPV*?8L=N,(-BHV*<@V+G9A-BG
MV*;9A2#8K]N,VJ_8L2`HV878I]F&V8;8KR#9A=F'V84OV;[8I]BSV*X@V*_8
MI]BOV8<@V+38K]F'*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@
M27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*(RP@9G5Z>GD*;7-G
M:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`BV*W8I]BTVXS9AR(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F:65L
M9',B"FUS9W-T<B`BV8';C-F$V*_B@(S9A]BGVXP@V*?9AMBWV*C8I]F"(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDS"B,L(&9U>GIY"FUS9VED(")-875R:71A;FEA(@IM<V=S
M='(@(MBMV*?8M-N,V8<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB
M"FUS9W-T<B`BV*C;C-BTVXS9AMF'(-BGV+G8JMBHV*?8L2#9A=BLV*?8LB(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S
M='(@(MBJV*[8M]N,(-BGV+(@V*C;C-BTVXS9AMF'(-F"V+/9A=BJV8?8I]N,
M(-F^VXS8NMBGV84B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-@IM<V=I
M9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(MBHVXS8M-N,
MV8;9AR#8K]F%V*<@V*_8L2#;LMNT(-BSV*?8N=BJ(-JOV+#8M-BJV8<Z("(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDX"FUS9VED(")-87@@=&5M<"!L
M87-T(#8@:&]U<G,Z("(*;7-G<W1R("+8J-N,V+3;C-F&V8<@V*_9A=BG(-BO
MV+$@V[8@V+/8I]BYV*H@VJ_8L-BTV*K9ASH@(@H*(SH@;&EB+V%P:2YP:'`Z
M.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`BV*C;
MC-BTVXS9AMF'(-BWV8C9A"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`BV87;C"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B
MV*S8I]F&V878I]N,VXPB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*
M;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(MF^V++8M-JIVXPB"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB97)S
M(@IM<V=S='(@(MBGV+G8MMBGV*$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S<X"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(MF%V*\@VJ_8LMN,
MV8;:K]BGV8;;C#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R
M("+8I]BOV+K8I]F%(-BSV839B-F$V8?8IR(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S
M86=E(@IM<V=S='(@(MF^VXS8NMBGV84B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE
M9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C
M;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(MF^VXS8NMBGV84@
MV*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BHV*?8LMBHVXS9AMN,(-BTV*\@V*?9
MA=BG(-JOV8C8I]F'VXP@V*?9A=BVV*?8H2#:J=F&V8;8K]F'(-F&V87;C.*`
MC-BJV8C8I]F&V*\@V*C8I]BRV*C;C-F&VXP@V+39B-BO(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED
M(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(MF^VXS8NMBGV84@V879AMF"
MV+;;C"#8M-BO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`IM<V=I9"`B365S<V%G92!T>7!E
M(@IM<V=S='(@(MF&V8C8N2#9OMN,V+K8I]F%(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(MBBV*@@
MV8@@V8?9B-BGVXP@365T87(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W
M"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("+8
MJ-F$V8C:J2!-971A<B#9@MBGV*C9A"#8K]BSV*K8L=BS(-F&VXS8L]BJ(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3(*;7-G:60@(B(*(DUE=&%R(&)L
M;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F
M;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(MBHV839B-JI($UE=&%R
M(-F"V*?8J-F$(-BOV+/8JMBQV+,@V8;;C-BSV*HN(-BLV++8IMN,V*?8JB#8
MJ-BQV*?;C"#8L]BQV;[8L=BSV*H@V+/8I]F%V*?9AMF'(-BKV*C8JB#8M-BO
MV8<@V*?8L]BJ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V
M-0HC+"!F=7IZ>0IM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*
M;7-G<W1R("+8I]BSV84@V+'9A=BR("#9@MBOVXS9A=N,(-F&V*?8K]BQV+/8
MJB#8I]BSV*HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*
M;7-G:60@(DUE=&AO9"(*;7-G<W1R("+8L=F(V+0B"@HC.B!F<F%M97=O<FLO
M4E!#+U)00R]X;6QR<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#+W-O87`N
M<&AP.C$Q-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(%PB
M)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R("+8L=F(V+0@)R5S)R#8JMBY
MV+';C-F!(-F&V+38K]F'(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]24$,O4E!#
M+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@
M9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<T(&QI8B]";&]C:R]M971A<BYP
M:'`Z-S4*;7-G:60@(DUE=')I8R(*;7-G<W1R("+8I]F&V*_8I]BRV8?B@(S8
MI]N,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDU"B,L(&9U>GIY"FUS9VED(")-97AI8V\B"FUS
M9W-T<B`BV*?9AMBOV*?8LMF'XH",V*?;C"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED
M(")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW-@IM<V=I9"`B36ED9&QE(@IM<V=S='(@(MF(V+/8MR(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE
M(%1Y<&4B"FUS9W-T<B`BV8;9B-BY($UI;64B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,Q,`IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM
M<V=S='(@(B#:J=F%VXS9AMF'(-BOV878I]N,(-NRV[0@V+/8I]BYV*H@VJ_8
ML-BTV*K9ASH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#(*;7-G:60@
M(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B#:J=F%VXS9AMF'
M(-BOV878I]N,(-NV(-BSV*?8N=BJ(-JOV+#8M-BJV8<Z("(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,Y"B,L(&9U>GIY"FUS9VED(")-
M:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S
M='(@(MBGV+/9A2#8L=F%V+(@(-BTV878IR#9A=F&V8+8MMN,(-BTV*_9AR#8
MI]BSV*HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C,T"FUS9VED(")-:7)R;W(B"FUS9W-T<B`BV*+;C-F&V8<B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B
M"FUS9W-T<B`BV878JMF!V+'9@MF'(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%
M05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG
M=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W
M86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"B+9
MOMN,VJG8L=BHV8;8K]N,(-F%V8C8K-F(V*\@V8;;C-BSV*HN(-BTV878IR#8
MI]JOV+$@V87;C.*`C-BNV8C8I]F'VXS8KR#8I]BR(-BGVXS9AB#8J-BQV8;8
MI]F%V8?9E"#:J=BGV+'8J-BQV*_;C"#8I]BSV*K9@=BGV*_9AR#:J=F&VXS8
MKR`B"B+8J-BGVXS8KR#8HMF&V+'8IR#8JMF(V83;C-BO(-JIV8;;C-BO(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(MBGV+(@
MV*C;C-F&(-BQV8'8JMF&($E$(-F^VXS8NMBGV84B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B
M36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(MBG
MV+(@V*C;C-F&(-BQV8'8JMF&($E$(-F&V+38L]BJ("(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*;7-G:60@(DUO(@IM
M<V=S='(@(MBOV8C8M-F&V*C9AR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HW-`IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`BV;[8L]BJ(-BS
MV839B-F$VXPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV.`IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`BV878N=BJV*_9A"#:
MJ=BQV*_9AB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C8@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,PHC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@X"FUS9VED
M(")-;V1I9FEE9"!$871E(@IM<V=S='(@(MBJV*?8L=N,V*X@V*K8NMN,VXS8
ML2#;C-BGV8'8JMF'(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S
M='(@(MBJV+K;C-N,V+$@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV-S,*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.30*;7-G:60@(DUO;G1H(&%N9"!Y
M96%R(@IM<V=S='(@(MF%V*?9AR#9B"#8L]BGV80B"@HC.B!F<F%M97=O<FLO
M36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY
M(@IM<V=S='(@(MF%V*?9A]BGV8;9AR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ
M>0IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R("+9A=BYV*K8K]F$(-JIV+'8
MK]F&(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R("+9@=BGV++9A]BG
MVXP@V878I]F'(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3<R
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(U,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE
M(&5X<&5C=&5D("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@
M(DUO<F]C8V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R
M("+8J-N,V+38JMBQ(-BUV*?9@2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S
M='(@(MBHVXS8M-BJV+$@V*?8J-BQVXPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM
M<V=S='(@(MBHVXS8M-BJV+$@V*+9@=BJV*?8J-N,(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`Y"FUS9VED(")-;W9E($1O=VXB
M"FUS9W-T<B`BV*?9AMBJV8+8I]F$(-BHV8<@V;[8I]N,VXS9AB(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4Q,PIM<V=I9"`B36]V
M92!,969T(@IM<V=S='(@(MBGV8;8JMF"V*?9A"#8J-F'(-BHV*?9A-BG(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$W"FUS9VED
M(")-;W9E(%)I9VAT(@IM<V=S='(@(MBGV8;8JMF"V*?9A"#8J-F'(-BQV*?8
ML]BJ(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`U
M"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(MBGV8;8JMF"V*?9A"#8J-F'(-BH
MV*?9A-BG(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C4R-`IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(MBGV8;8JMF"V*?9
MA"#8J-F'(-F^V*?;C-N,V88B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-3(S"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`BV*?9
MAMBJV8+8I]F$(-BHV8<@V*C8I]F$V*<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@
M(DUO>F%M8FEQ=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$X-`IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S
M(@IM<V=S='(@(MF!V8?8L=BSV*H@V;[8I]N,VXS9AN*`C-F^V+$@VH;9AMBO
M(-BSV+?8K=N,(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$P-34*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0R"FUS9VED(")-=6QT
M:7!L92!S96QE8W1I;VXB"FUS9W-T<B`BVH;9AMBO(-BGV8;8JMBNV*?8J-N,
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,`IM<V=I9"`B37D@
M06-C;W5N="(*;7-G<W1R("+8K=BSV*?8J"#9A=F&(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C(X"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T:6]N
M(@IM<V=S='(@(MBGV+?9A-BGV+G8I]BJ(-BMV+/8I]BH(-F%V88B"@HC.B!S
M97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C4T"FUS9VED(")->2!0;W)T86PB
M"FUS9W-T<B`BV*_8L=JOV*?9AR#9A=F&(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+V5D:70N<&AP.C$S-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R
M("+8K-BGV8;9A=BGVXS;C"#8K]BQVJ_8I]F'(-F%V88B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3(*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA
M:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O
M($Y/5"!!9W)E92(*;7-G<W1R("+9AMF'V(P@V879AB#9A=F(V*?9@=F"(-F&
MVXS8L]BJV84B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,3$@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I
M9"`B3F%M92(*;7-G<W1R("+9AMBGV84B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@
M(DYA;6EB:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").875R
M=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3@Q"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R(")54DP@
MV;[8I]N,V8<@3F5T<V-A<&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!5
M4DPB"FUS9W-T<B`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T
M<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R(").971S8V%P92!#02!P;VQI
M8WD@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.#0*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(DYE='-C
M87!E(%)E;F5W86P@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM
M<V=S='(@(DYE='-C87!E(%)E=F]C871I;VX@55),(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E(%-3
M3"!S97)V97(@;F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A
M=&4@8V]M;65N="(*;7-G<W1R("+8JMF(V+;;C-BM(-JOV8C8I]F'VXP@3F5T
M<V-A<&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X
M,`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R("+9
MAMF(V+D@VJ_9B-BGV8?;C"!.971S8V%P92(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR-3$*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`BV+38J-JI
MV8<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,S-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S@V"FUS9VED(").979E<B(*;7-G<W1R("+9A]BQVJ_8LB(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-0HC+"!F=7IZ>0IM<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R
M("+8K]BSV*K9AR#8K-BOVXS8KR(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T96=O<GDB
M"FUS9W-T<B`BV*_8L]BJV8<@V*S8K]N,V*\B"@HC(`HC.B!F<F%M97=O<FLO
M5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#$*(SH@9G)A;65W;W)K
M+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&9R86UE=V]R
M:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HY-PHC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G92!T;R`E<R(*;7-G<W1R
M("+8I]N,V*S8I]BO(-F^VXS8NMBGV84@*"5S*2(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`BV878I]F'(-F&
MV8@B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS
M9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R("+9AMBGV84@
MVJG8I]BQV*C8L=N,(-BLV*_;C-BO("C8I]BNV*K;C-BGV+';C"DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PIM<V=I9"`B3F5W('!A<W-W
M;W)D(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@V*S8K]N,V*\B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G
M:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B
MV*?8L]F%(-BQV878LB#9A-BZV8@@V*[9B-BGV8?8KR#8M-BO(-BOV+$@)7@@
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED(").
M97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R("+8I]BSV84@V+'9
MA=BRV8?8I]N,(-BLV*_;C-BO(-BJV+?8I]BHV8(@V8;8K]BGV+'8KR(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G
M:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`BV;[9AMBLV+'9AR#8
MK-BOVXS8KR`HV*[8I]F$VXPI(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR.#D*;7-G:60@(DYE=W,B"FUS9W-T<B`BV*?8KMBHV*?8
ML2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#4*;7-G:60@(DYE
M=W-G<F]U<',B"FUS9W-T<B`BVJ_8L=F(V8?B@(S9A]BGVXP@V*[8J-BQVXPB
M"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-2!T96UP;&%T97,O
M9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-0IM<V=I9"`B
M3F5X="(*;7-G<W1R("+8J-BYV*_;C"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR-PHC+"!F=7IZ>0IM<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R("+9
M@=BGV+(@V*C8N=BOVXPB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C,W,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W-@IM<V=I
M9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(MJOV++;C-F&V8?B@(S9A]BGVXP@
MV*C8N=BOVXPB"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,PHC
M+"!F=7IZ>0IM<V=I9"`B3F5X=#XB"FUS9W-T<B`BV*C8N=BOVXPB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.38*(RP@9G5Z>GD*;7-G:60@(DYI9V5R(@IM<V=S='(@(MBTV*@B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,X,`IM<V=I9"`B3FEG:'0B"FUS
M9W-T<B`BV+38J"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PHC+"!F=7IZ>0IM<V=I9"`B3FEU
M92(*;7-G<W1R("+8N=BOV*\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(").;R(*;7-G<W1R("+9AMF'(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").
M;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R
M96YC97,@9F]R+B(*;7-G<W1R("+8K]BGV*_9AR#9OMN,VJG8L=BHV8;8K]N,
M(-BOV+$@V*_8L]BJV+'8L]N,(-BHV+'8I]N,(-F&V+38I]F&(-BOV*?8K]F&
M(-BJV8'8I]F(V*K9A]BG(-F(V*S9B-BO(-F&V*_8I]BQV*\B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C$P-0IM<V=I9"`B
M3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB
M"FUS9W-T<B`B25-/(-F&VXS8L]BJ(-BGV+/8JMBQV*?8JMJ8VXP@V*_8L2#8
MK]BSV*K8L=BSVXP@V*C8L=BGVXP@V+/8I]BNV*K9AB#8JMBUV8C;C-BQ("(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(MBGV83:
MK]F(VXP@V*_8L]BJV8?B@(S8I]N,VXP@V8;;C-BSV*HB"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW.2!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HR-#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z,C8W"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE
M(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R("+8J-F$V*?:J=N,(-BOV+$@
MV879B-F"V+G;C-BJ(-BOV+'8KMF(V*?8L]BJ(-BTV*_9AR#9A=F(V*S9B-BO
M(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HU
M,`IM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BV8?;C-J&(-F&V*?9A2#8JMF"V8C;
MC-F%VXP@V*C8L=BGVXP@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ($U#04P@V8'8
ML=BGV8?9A2#9AMBTV*_9AR#8I]BSV*HB"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HU-`IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R("+8J-BOV8C9AB#8
MJMBZVXS;C-BQ(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E
M<FUI<W-I;VXN(@IM<V=S='(@(MF'VXS:AB#9A=BLV8C8LB#9@=BQV+G;C.*`
MC-BGVXP@V8;9A=N,XH",V*K9B-BGV8;8KR#8J-F'(-BGVXS9AB#9A=BLV8C8
MLB#8I]BVV*?9@=F'(-BTV8C8KR(*"B,@"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,38W(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`R"B,Z
M(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<W,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@)7,N(@IM<V=S='(@(MF'VXS:AB#8I]BWV838I]BYV*?8JB#9OMN,VJG8
ML=BHV8;8K]N,(-BHV+'8I]N,("5S(-F%V+38KMBU(-F&V+38KR(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(T"FUS9VED(").;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS
M9W-T<B`BV8?;C-J&(-BGV+?9A-BGV+G8I]BJ(-F^VXS:J=BQV*C9AMBOVXP@
MV*C8L=BGVXP@1E10(%9&4R#9A=BTV*[8M2#9AMBTV*\B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C8V.0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@
M(MF'VXS:AB#8I]BWV838I]BYV*?8JB#9OMN,VJG8L=BHV8;8K]N,(-BHV+'8
MI]N,(%-13"!61E,@V878M-BNV+4@V8;8M-BO(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C<Q-PIM<V=I9"`B3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS
M9W-T<B`BV8?;C-J&(-BGV+?9A-BGV+G8I]BJ(-F^VXS:J=BQV*C9AMBOVXP@
MV*C8L=BGVXP@4U%,+49I;&4@5D93(-F%V+38KMBU(-F&V+38KR(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM
M<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(MF'VXS:AB#8I]BYV*K8
MJ-BGV+';C"#8J-BGV8+;C"#9AMF%V*?9AMBO(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E
M<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R("+9A]N,VH8@V879@MBUV*_;
MC"#9@=BQV*?9A]F%(-F&V+38KR(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R
M;W=S97(N<&AP.C@W-PIM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R
M("+9A]N,VH8@V;[8L=F(V8;8K]F'XH",V*?;C-N,(-BGV+'8L]BGV80@V8;8
MM-BO(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I
M8V]N<R!F;W5N9"XB"FUS9W-T<B`BV8?;C-J&(-BBVXS:J=F(V8;;C.*`C"#9
MOMN,V*_8IR#9AMBTV*\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3(X(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$R,PIM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G
M<W1R("+9A]N,VH8@V87:J=BGV8;;C"#8JMF&V+C;C-F%(-F&V+38K]F'(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V.0HC+"!F=7IZ>0IM
M<V=I9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(MF'VXS:AB#9
MA=JIV*?9AMN,(-BJV8;8N-N,V84@V8;8M-BOV8<B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@
M;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`BV8?;C-J&(-F^VXS8NMBGV87;
MC"#9@=BQV*?9A]F%(-F&V+38KR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N86UE('-P96-I
M9FEE9"XB"FUS9W-T<B`BV8?;C-J&(-F&V*?9A=N,(-F%V+38KMBU(-F&V+38
MKR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,W"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R("+9
MA]N,VH8@V+39A=BGV+'9A^*`C-BGXH",VXS;C"#9A=BTV*[8M2#9AMBTV*\B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N
M<VEV92!F;W)T=6YE<R(*;7-G<W1R("+8HMN,V8;8K]F'(-F&V*?9A=BWV*C9
MB-BYVXP@V8;;C-BSV*HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N
M<&AP.CDQ"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BV*C8L=BGVXP@V*K8M=BOVXS9@B#9
MA]F(VXS9D=BJ($A45%`@V*?8L]F%(-BQV878LMN,(-F!V+'8I]F'V84@V8;8
MM-BOV8<@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H
M<#HQ,#@*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+8J-BQV*?;C"#8JMBUV*_;C-F"(-F'
MV8C;C-F1V*H@24U!4"#8I]BSV84@V+'9A=BRVXP@V8'8L=BGV8?9A2#9AMBT
MV*_9AR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP
M.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(MBHV+'8I]N,(-BJV+78K]N,V8(@
MV8?9B-N,V9'8JB!+97)B97)O<R#8I]BSV84@V+'9A=BRVXP@V8'8L=BGV8?9
MA2#9AMBTV*_9AR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A
M<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H+T%U=&@O;&]G:6XN<&AP.C@T"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW-0IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R("+8J-BQV*?;C"#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@V8C8L=F(V*\@
MV*?8L]F%(-BQV878LMN,(-F!V+'8I]F'V84@V8;8M-BOV8<@V*?8L]BJ(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]P87-S=V0N<&AP.C$S-0IM<V=I9"`B
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`BV*C8L=BGVXP@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(%!!
M4U-71"#8I]BSV84@V+'9A=BRVXP@V8'8L=BGV8?9A2#9AMBTV*_9AR#8I]BS
MV*HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.#0*;7-G:60@
M(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(MBHV+'8I]N,(-BJV+78K]N,V8(@V8?9B-N,V9'8JB!334(@
MV*?8L]F%(-BQV878LMN,(-F!V+'8I]F'V84@V8;8M-BOV8<@V*?8L]BJ(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@V"FUS9VED
M("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@
M5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I
M=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU
M<',N(@IM<V=S='(@(MBJV8+8I]BVV*?;C"#8J]BHV*H@V8;8I]F%VXP@V*_8
ML2#8I]F&V*K8N-BGV+$@V*K8H]N,VXS8KR#9AMN,V+/8JB(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HW-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`BV*K9AMBXVXS9A2#9AMBTV*_9
MAR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(MBHV*_9B-F&(-F"
MV8C8I]BYV*\B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#D*
M;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@(MF'VXS:
MAB#8K-BOV*?:J=F&V8;8K]F'XH",V*?B@(S;C-N,(-F%V+38KMBU(-F&V+38
MKR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(MBHV*_9B-F&(-BS
MV878JB(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@S"B,L(&9U
M>GIY"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T<B`BV*C8K]F(V88@V+/9
MA=BJ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$S.`IM<V=I
M9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE
M+B(*;7-G<W1R("+8M-BGV*[9AR#9A=F(V8+8JMN,(-BHV+'8I]N,(-JIV*?8
MM-F'(-F%V8C8K-F(V*\@V8;;C-BSV*HB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C(R,0IM<V=I9"`B3F\@=7-E<FYA;64@
M86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(MF'VXS:AB#9AMBGV84@
MVJG8I]BQV*C8L=N,(-F((-N,V*<@V*?8L]F%(-BQV878LMN,(-BGV+'8L]BG
MV80@V8;8M-BO(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ
M-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@
M(MF'VXS:AB#8K]BGV*_9AR!834P@V878N=BJV*C8L=N,(-BHV*?8LMJOV+'8
MK]BGV8;8K]F'(-F&V+38K]F'(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY-S$*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX,0HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DR"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,#`Y"FUS9VED(").;R!V86QU97,B"FUS
M9W-T<B`BV*C8K]F(V88@V879@MBOV*?8L2(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN
M86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("+9AMBSV*[9A^*`C"#8K]BQ(-F^VXS:J=BQV*C9AMBOVXP@V*?8
MM=F$VXP@V;[;C-BOV*<@V8;8M-BO+B#9OMN,VJG8L=BHV8;8K]N,(-BQV*<@
MV*_9B-BHV*?8L=F'(-BJV8C9A-N,V*\@VJG9AMN,V*\B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN
M('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("+9AMBSV*[9A^*`C"#8K]BQ(-F^VXS:J=BQV*C9AMBOVXP@
MV+39A=BG(-F^VXS8K]BG(-F&V+38K]F'(-BGV+/8JBX@V;[;C-JIV+'8J-F&
MV*_;C"#8L=BG(-BOV8C8J-BGV+'9AR#8JMF(V83;C-BO(-JIV8;;C-BO(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@
M=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PIM<V=I9"`B
M3F]N92(*;7-G<W1R("+9A]N,VH;B@(S:J=BOV*?9A2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@
M*'5S92!I;7!L:6-I="DB"FUS9W-T<B`BV8?;C-J&XH",VJG8K]BGV84@*-BV
MV879AMN,(-BGV+/8JMF!V*?8K]F'(-JIV8;;C-BO*2(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@Y"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*
M;7-G<W1R(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM
M<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R
M=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("+9AMN,V84@VJG8L=F'(-BTV878
MI]F$VXPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@
M27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8T,`IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(MF&V8<@V*C8N=BO
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G
M:60@(DYO="!"969O<F4B"FUS9W-T<B`BV8;9AR#9@MBHV80B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,#@*;7-G:60@(DYO="!A(&1I<F5C
M=&]R>2(*;7-G<W1R("+;C-JI(-BTV*?8KMF'(-F&VXS8L]BJ(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HV,PHC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T
M96=Y+G!H<#HX,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-`HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS
M9W-T<B`BV;[;C-BGV*_9A^*`C-BSV*?8LMN,(-F&V+38K]F'(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B
M3F]T('-E="(*;7-G<W1R("+8JMF&V+C;C-F%(-F&V+38K]F'(@H*(SH@9G)A
M;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#,*
M(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H
M<#HQ-3@*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+G!H<#HQ-S,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I
M;VY(86YD;&5R+G!H<#HQ.#<*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C$Y,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`U(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(T."!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8U"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(Y-PHC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z,S$R(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,CD*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V,B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-#(R"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU,#$@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C4W,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M-3@W(&9R86UE=V]R:R]61E,O5D93+G!H<#HV-C4*;7-G:60@(DYO="!S=7!P
M;W)T960N(@IM<V=S='(@(MF^V+38JMN,V*C8I]F&VXP@V8;8M-BOV8<B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O
M;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#`U"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ-S@*;7-G:60@(DYO=&5S(@IM<V=S='(@(MN,V*?8K]BOV*?8
MM-BJV8?8IR(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM
M<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(MJ&
MVXS8LMN,(-BHV+'8I]N,(-F%V+'9B-BQ(-F&VXS8L]BJV(P@V*C9AR#8N=F"
MV*@@V*C8L=JOV+'8KR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G<W1R("+9AMF(V*?9
MA=BHV+$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V"FUS9VED
M(").=6UB97(B"FUS9W-T<B`BV+G8K]BO(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30R-0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS
M9W-T<B`BV*K8N=BOV*?8KR#9AMF(VXS8L]F'XH",V8?8IR(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30R,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0U('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").
M=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R("+8JMBYV*_8I]BO(-BSV*K9B-F&
MV8?8IR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C<@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#0S('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R("+8JMBYV*_8
MI]BO(-BSV+?8L=F'V*<B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF
M:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T
M<B`BV*?8N=BOV*?8KR#8J-BQV*?;C"#8J-BQV8C8LMBQV+/8I]F&VXP@V8'9
MA]BQV+/8JB#8JMF(V++;C-BYVXP@V878M-BNV+4@V8;8M-BOV8;8KR(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I
M9"`B3TLB"FUS9W-T<B`BV*K8H]N,VXS8KR(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B:F5C="(*;7-G
M<W1R("+8M-N,V*$B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q
M,0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`BV*?;C-BLV*?8KR#:
MJ=F&V8;8K]F'(-BTVXS8H2(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O
M("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(MF'V+38JMBGVXS;
MC"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T
M"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(MBGVJG8JMBHV+$B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM
M<V=S='(@(MF!VXS9A-BJV+$@V*C;C.*`C-BMV+'9A=BJVXPB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(V"FUS9VED(")/9F9I8V4B"FUS9W-T
M<B`BV*_9@=BJV+$@VJG8I]BQ(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B
M92!D:69F97)E;G0N(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@V*S8K]N,V*\@
MV8@@V*?8L]F%(-BQV878LB#9@=BYV83;C"#8J-BGVXS8KR#9A=BJV8'8I]F(
MV*H@V*C8I]BTV8;8KR(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HS-@IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(MBGV+/9A2#8L=F%
MV+(@V8+8K]N,V87;C"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G
M<W1R("+8I]BSV84@V+'9A=BR("#9@MBOVXS9A=N,(-F&V*?8K]BQV+/8JB#8
MI]BSV*HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G
M:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N
M(@IM<V=S='(@(MBJV8;9A]BG(-JIV*?8L=BSV*?8LMF'V*?;C"!)34%0V;[9
MB-BTV8?B@(S9A]BGVXP@V878M-BJV+':J2#8L=BG(-F^V+38JMN,V*C8I]F&
MVXP@V87;C.*`C-JIV8;9AMBO("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B
MV8'9@MBW(-BBVXS9AMBOV8<@V8;8I]F%V+?8J-F(V+DB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Y-S$*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB
M"FUS9W-T<B`BV*K9AMF'V*<@VXS:J2#8HMBOV+'8LR#9OMBSV*H@V*?9A-JI
MV*K8L=F(V8;;C-JIVXP@V878K-BGV+(@V*?8L]BJ(@H*(SH@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O
M<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O
M<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B
M"B+8JMF&V8?8IR#9A=BGV83:J2#;C-BG(-BSV+'9OMBQV+/8JB#8L]BGV878
MI]F&V8<@V87;C.*`C-BJV8C8I]F&V*\@V878I]F$VJG;C-BJ(-N,V*<@V878
MK-F(V++9A]BGVXP@V878I]F$VJD@V+'8IR#8J-BQV*?;C"#;C-JI(-BGV+38
MJMBQV*?:J2`B"B+8JMBZVXS;C-BQ(-BOV8?8KR(*"B,Z(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C,U"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G
M<W1R("+8K]BQ(-N,VJD@V;[9AMBLV+'9AR#8K-BOVXS8KR#8J-BGV+(@V+39
MB-BO(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*
M;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@
M9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM
M<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R
M("+8I]N,V88@V;[;C-F(V8;8KR#8K]BQ(-N,VJD@V;[9AMBLV+'9AR#8K-BO
MVXS8KR#8J-BGV+(@V+39B-BO(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(MBSVXS8L]BJ
MV84@V+G8I]F%V80B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(MJOV++;C-F&V8<F(W@R,#!C
M.]F'V*<B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@
M(",M(RTC+2,M(PHC(`HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA
M=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T
M:6]N<R!F;W(@)7,B"FUS9W-T<B`BVJ_8LMN,V8;9A^*`C-F'V*?;C"`E<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*
M;7-G:60@(D]R9&5R960@3&ES="(*;7-G<W1R("+9A-N,V+/8JB#9A=BQV*K8
MJ"#8M-BOV8<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4V-PIM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(MBSV*?8LMF%V*?9
MAB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X"FUS
M9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@(MF(V*?8K=BO(-BS
MV*?8LMF%V*?9AMN,(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S
M,@IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R("+8L]BGV++9A=BGV8;8K]F'
MVXPB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN
M86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`BV*?9A-JOV8C;C"#8
MI]BUV83;C"#8J-BQV8;8I]F%V8?9E"#:J=BGV+'8J-BQV*_;C"(*"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G
M:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`BV*?9A-JO
MV8C9A]BGVXP@V*?8M=F$VXP@V*_8L2`E<SHB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM
M<V=I9"`B3W1H97(B"FUS9W-T<B`BV*_;C-JOV+$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,C(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,30Q"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G
M<W1R("+8I]BWV838I]BYV*?8JB#8K]N,VJ_8L2(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(MF%V*S9B-BRXH",V8?8I]N,(-F%V*?9A-JI(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC
M871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`BV*K8M=BOVXS9@B#9
MA]F(VXS9D=BJ(%!!32#9@MBGV*C9A"#8K]BSV*K8L=BSVXP@V8;;C-BSV*HB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ
M,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<S"FUS9VED(")01U`@
M1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`BV*?9A=BVV*?8H>*`C"#8K]N,
MV*S;C-BJV*?9A-N,(%!'4"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$S,3D*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R
M("+9OMN,V+K8I]F%(-BQV878LMBHV8;8K]N,(-BTV*_9A]F4(%!'4"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-S$*;7-G:60@(E!'
M4"!0=6)L:6,@2V5Y(@IM<V=S='(@(B#:J=F$VXS8KR#8N=F%V8C9A=N,(%!'
M4"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-3,*;7-G
M:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`BV;[;C-BZ
MV*?9A2#8L=F%V++8J-F&V*_;C"#8M-BOV8<OV*?9A=BVV*?8H2#8M-BOV8<@
M4$=0(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"FUS9VED(")02%`@0V]D
M92(*;7-G<W1R("+:J=BO(%!(4"(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR
M,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(MF^V8C8L]BJV8<@4$A0(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G
M:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`BV*C8I]BQV8;8K]JOVXP@V+/8
MJ-JI(-BYV+78L=JOV*?9A]N,(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B
MV+':K]BHV*?8L2#8N=BUV+':K]BGV8?;C"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")032!3;F]W(@IM<V=S
M='(@(MBHV+'9@2#8N=BUV+':K]BGV8?;C"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3;F]W(%-H;W=E
M<G,B"FUS9W-T<B`BV*K:K]BQVJ\@V+G8M=BQVJ_8I]F'VXPB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0HC+"!F=7IZ>0IM
M<V=I9"`B4$T@4W5N(@IM<V=S='(@(MBHV+'9@2#8N=BUV+':K]BGV8?;C"(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS
M9VED(")032!4+5-T;W)M<R(*;7-G<W1R(")4+5-T;W)M<R(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I
M<R!M:7-S:6YG(@IM<V=S='(@(MBHV+/8MR!03U-)6"#8I]BR(-BHVXS9AB#8
ML=F!V*K9AR#B@(S8I]BSV*HB"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@
M(E!?2%`@4VAE;&PB"FUS9W-T<B`BV;[9B-BSV*K9AR!02%`B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V"FUS
M9VED(")0861D:6YG(@IM<V=S='(@(MF!V*?8M=F$V8?B@(S:K]BPV*?8L=N,
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDY"B,L(&9U>GIY"FUS9VED(")086MI<W1A;B(*;7-G
M<W1R("+:AMBSV*C8I]F&V*_9AB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A
M;&%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN
M:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDX"B,L(&9U>GIY"FUS9VED(")086YA;6$B"FUS9W-T<B`BV8;8I]F%(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS
M9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@(MF"V+/9A=BJVXP@V*?8J-BQ
MVXPB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#(S"FUS9VED(")087-S=V]R9"(*;7-G<W1R("+8I]BSV84@V+'9A=BR("(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S
M<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(MBGV+/9A2#8
ML=F%V+(@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BJV+K;C-N,V+$@VXS8I]F!
MV*HN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(R
M"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`BV*?8L]F%(-BQ
MV878LB`@V8;8I]BOV+'8L]BJ(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D
M(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(MBGV+/9A2#8
ML=F%V+(@(-BHV8<@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(%)!1$E54R#9AMN,
MV*?8LB#8K]BGV+'8KR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M-3,*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@
M(MBGV+/9A2#8L=F%V+(@(-BHV*<@V*K8H]N,VXS8KR(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S
M='(@(MBGV+/9A2#8L=F%V+(@.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(MBGV+/9A2#8
ML=F%V+(@.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`S-`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C$U"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T
M<B`BV*?8L]F%(-BQV878LN*`C-F'V*<@V*C8I]N,V*\@V879AMBWV*C9@B#8
MJ-BGV+39AMBO(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q.2!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G
M:60@(E!A<W1E(@IM<V=S='(@(MJ&V+/8J-BGV8;8K]F&(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S
M=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`BVH;8L]BHV*?9AMBOV88@V*?8
MLB#8JMBNV*K9AR#8L=BSV84B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@(MF%V+/;
MC-BQ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@
M(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`BV*O8J-BJ(-F&V*?9A=F'V*?;
MC"#9AMBGV878N=F$V8C9A2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(MF%V+'8K]F%(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E
M<F-E;G0B"FUS9W-T<B`BV*_8L=BUV*\B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN
M=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(MBGV*S8L=BGVXP@V+G9A=F$
MVXS8I]BJ(-F&VJ_9A]BOV*?8L=N,(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0P-@IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS
M(&]N(&QO9VEN/R(*;7-G<W1R("+8HMN,V*<@V+G9A=F$VXS8I]BJ(-F&VJ_9
MA]BOV*?8L=N,(-BOV+$@V838K=BXV8<@V8C8L=F(V*\@V*?8K-BQV*<@V+39
MB-BOV)\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM
M<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R("+9A=BLV8C8LB(*"B,@(RTC+2,M
M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z
M(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S='(@(MF%
MV*S9B-BR("!<(B5S7"(@V*W8L-F!(-F&V+38KR(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-3@V"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N
M($1E;FEE9"(*;7-G<W1R("+9A=BLV8C8LB(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R("+9A=BLV8C8LMF'
MV*<B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A
M9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"FUS9VED(")097)M:7-S:6]N<R!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R("+8L]BQV;[8L=BSV*K;C"#9A=BLV8C8
MLMF'V*<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*;7-G:60@(E!E
M<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(MBGV+?9A-BGV+G8I]BJ(-BT
MV*[8M=N,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G
M<W1R("+8K=N,V8C8I]F&V*?8JB#8KMBGV8;:K]N,(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY
M"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*
M;7-G<W1R("+8JMF$V8'9AB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-S@*;7-G:60@(E!H;W1O<R(*;7-G<W1R("+8N=JIV+/9A]BG(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@
M(E!I>&5L<R(*;7-G<W1R("+9OMN,VJG8L]F$V8?8IR(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS
M9W-T<B`BV838M]F!V*?9BR#8K]BGV*[9A"#:AMF&V*\@V+/9A-F(V80@VJG9
MA-N,VJD@VJG9AMN,V*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M
M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T
M<B`BV838M]F!V*?9BR#8JMBCVXS;C-BO(-JIV8;;C-BO(-JIV8<@V87;C.*`
MC-BNV8C8I]F'VXS8KR#8I]N,V88@V+G9AMBUV+$@V+'8IR#8K=BPV8$@VJG9
MAMN,V*\Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO
M=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(MF$V+?9
M@=BGV8L@V*K8H]N,VXS8KR#:J=F&VXS8KR#:J=F'(-F%VXSB@(S8KMF(V*?9
MA]N,V*\@V;[;C-F(V8;8KR#8I]N,V88@V+G9AMBUV+'9A]BG(-BQV*<@V8+8
MM]BY(-JIV8;;C-BO(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4W
M,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS
M9W-T<B`BV838M]F!V*?9BR#;C-JI(-F%V*?9AR#9B"#;C-JI(-BSV*?9A"#9
MB-BGV+'8KR#:J=F&VXS8KRXB"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M
M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`BV838M]F!V*?9BR#9
MAMBGV87;C"#8J-BQV*?;C"#8K]BSV*K9AR#8K-BOVXS8KR#9B-BGV+'8KR#:
MJ=F&VXS8KSHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Q"FUS
M9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R
M("+9A-BWV8'8I]F+(-BBV*_8L=BS($E0(-F%V+G8JMBHV+';C"#9B-BGV+'8
MKR#:J=F&VXS8KR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C`*
M;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N
M=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(MF$V+?9@=BG
MV8L@VXS:J2#8JMBGV+';C-BN(-F%V+G8JMBHV+$@V8C8I]BQV*\@VJG9AMN,
MV*_8C"#8JMBYV*_8I]BO(-BQV8C8LMF'V*<@V*_8L2#9A=BGV8<@V+'8IR#:
MJ=F&V*K8L=F$(-JIV8;;C-BO(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C0U,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS
M9W-T<B`BV838M]F!V*?9BR#;C-JI(-BRV878I]F&(-F%V+G8JMBHV+$@V8C8
MI]BQV*\@VJG9AMN,V*\B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE
M('!R;V)L96TN(@IM<V=S='(@(MF$V+?9@=BGV8L@V*[9A-BGV+79A^*`C-BG
MXH",VXS;C"#8I]BR(-F%V+3:J=F$(-BQV*<@V*C9AMF(VXS8L]N,V*\B"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E
M<FYA;64@86YD('!A<W-W;W)D(@IM<V=S='(@(MF$V+?9@=BGV8L@V8;8I]F%
M(-JIV*?8L=BHV+$@V8@@V*?8L]F%(-BQV878LB`@V*[9B-BO(-BQV*<@V*+9
MA=BGV*_9AR#:J=F&VXS8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O
M("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HU.`IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN
M9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@
M=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@HBV838M]F!V*?9BR#9A=BJV88@
MV++;C-BQ(-BQV*<@V*C8KMF(V*?9AMN,V*\N(-BTV878IR#8J-BQV*?;C"#8
MI]BSV*K9@=BGV*_9AR#8I]BR(-BSV*?9A=BGV8;9AR#8J-BGVXS8KR#8M-BQ
MV8C8MR#8L=BG(-F"V*C9B-F$(-JIV8;;C-BO(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S
M92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`BV838M]F!
MV*?9BR#9AMBGV84@V*_8L]BJV8<@V*S8K]N,V*\@V+'8IR#9B-BGV+'8KR#:
MJ=F&VXS8KSHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(E!O;&%N
M9"(*;7-G<W1R("+9@=BQV878I]F&(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R("+8L]N,V*?8L]BJV8?8
MIR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#<*;7-G:60@(E!O
M;&QS(@IM<V=S='(@(MBBV+'8I]BA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0HC+"!F=7IZ
M>0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`BV*_8L=JOV*?9AR#9A=F&(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM
M<V=S='(@(MF%V*W9A"#9@MBQV*?8L=JOV+'9@=BJV88@V*?;C-F&(-BJV+79
MB-N,V+$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G
M<W1R("+9A=BMV80@V8+8L=BGV+':K]BQV8'8JMF&(-BGVXS9AB#8K-BOV8C9
MA"(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ
M"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@
M24U!4"DB"FUS9W-T<B`BV;[8L]BJ(-BHV8<@V*?;C-F&(-F^V8C8M-F'(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@
M;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`BV*_8L=BUV*\@V+'8M]F(V*C8
MJB#8K]BQ("5S(-BSV*?8N=BJ(-F"V*C9A#HB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,CDX"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^
M8VAA;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L
M9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L9&%P.B#8J-BS
MV+<@V879B-BQV*\@V8;;C-BGV+(@3$1!4"#9OMN,V*_8IR#9AMBTV*\B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@
M(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?<V5S<VEO;CH@V*C8L]BW(-F%V8C8
ML=BO(-F&VXS8I]BR('-E<W-I;VX@V;[;C-BOV*<@V8;8M-BO(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,C4*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@
M(MF!V+38I]BQ(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G:60@
M(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@(MF!V+38I]BQ(-BO
MV+$@V+/8M]BM(-BOV+';C-BG.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C,U"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(MF!V+38
MI]BQ.B`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C`U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R("+9OMN,
MV+3B@(S9AMF%V*?;C-BT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H
M92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`BV;[;C-BTXH",V8;9
MA=BGVXS8M"#8JMBUV8C;C-BQ(-BOV+$@VXS:J2#9OMF&V*S8L=F'(-BLV*_;
MC-BO("(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8R(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V"FUS9VED(")0<F5V:6]U
M<R!O<'1I;VYS(@IM<V=S='(@(MJOV++;C-F&V8?B@(S9A]BGVXP@V8+8J-F$
MVXPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R("+:AMBGV;X@V+/9
MAMBO(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS
M9VED(")0<FEV871E($ME>2(*;7-G<W1R("+:J=F$VXS8KR#8M-BNV+7;C"(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@
M(E!R;V)L96TB"FUS9W-T<B`BV878M-JIV80B"@HC.B!S97)V:6-E<R]P<F]B
M;&5M+G!H<#HQ,C8*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T
M<B`BV*K9B-BVVXS8K2#9A=BTVJG9A"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS-CD*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(MF^V+'9B-J8
MV8?B@(S9A]BG(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@X"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,R.#4*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(MF%
MV*K9AB#8I]BYV838I]F&(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(MJIV83;C-BO
M(-BYV879B-F%VXPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS9W-T<B`B
MV*?9A-JOV8C8L=N,V*K9A2#:J=F$VXS8KR#8N=F%V8C9A=N,(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#0*(RP@9G5Z>GD*;7-G
M:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R("+:J=F$VXS8KR#8N=F%V8C9
MA=N,(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS
M9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C
M8V5S<V9U;&QY+B(*;7-G<W1R("+8K-F!V*H@VJG9A-N,V*\@V+G9A=F(V87;
MC"_8KMBUV8C8M=N,(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8JMF(V83;C-BO
M(-F&V+38KR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DV(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*(RP@9G5Z>GD*;7-G:60@(E%A=&%R
M(@IM<V=S='(@(MBOV*?8K]F'(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8S
M"FUS9VED(")1=65R>2(*;7-G<W1R("+9OMBQV+/B@(S9B-BLV8@B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S='(@
M(MBSV8?9A=N,V8<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H
M)60@8FET*2(*;7-G<W1R("(@VJG9A-N,V*\@V+G9A=F(V87;C"!24T$@*"5D
M(-BHVXS8JBDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8T"FUS
M9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-BQ
MV*?8K]N,V8@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT,PIM<V=I9"`B4F%I;B(*;7-G<W1R("+8J-BGV+'8I]F&(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@
M(E)A:6X@16%R;'DB"FUS9W-T<B`BV*C8I]BQV*?9AB#8LMF(V*_9A]F&VJ_8
MI]F%(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#4*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R("+8J-BGV+'8I]F&(-BOVXS8
ML=F'V8;:K]BGV84B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`BV*C8I]BQ
MV*?9AB#9B"#8L=JOV*C8I]BQ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T
M<B`BV*C8I]BQV*?9AB#9B"#8J-BQV8$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM
M<V=S='(@(MBHV*?8L=BGV88@V*C9AR#8J-BQV8$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B
MV+?8I]F$V+D@V*K8M=BGV*_9@=N,(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<V"FUS9VED(")2871I;R(*;7-G<W1R("+9AMBSV*C8JB(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(T('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED
M(")296%D(@IM<V=S='(@(MBNV8C8I]F&V*_9AB(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"FUS9VED(")296%D(&UE<W-A
M9V5S(@IM<V=S='(@(MBNV8C8I]F&V*_9AB#9OMN,V+K8I]F%V8?8IR`B"@HC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M
M(PHC(`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`BV8C8I]F"V+G8I]F2
M("5S(-BMV+#9@2#8M-F(V*_8GR#8I]N,V88@V+G9A=F$(-F"V*?8J-F$(-F(
MV*?:K]BQV*\@V8;;C-BSV*HB"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@
M<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@
M8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`BV8C8I]F"V+G8I]F+(-BOV*?8
MK]F'V90@VJG8I]BQV*C8L=N,(-BHV+'8I]N,(-JIV*?8L=BHV+$@)7,@V*W8
ML-F!(-BTV8C8K]B?(-BGVXS9AB#8N=F%V80@V8+8I]BHV80@V8C8I]JOV+'8
MKR#9AMN,V+/8JB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM
M<V=S='(@(MBGV8;8K-BGV84@V*+8KMBQVXS9AB#8N=F%V80@V+39A=BG(-BG
MV+(@V8;9B"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(E)E9G)E<V@@
M1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R("+8J-BGV++8HMF(V+';
MC"#8N=F&V*?8M=BQ(-JOV++;C-F&VJ_8I]F&(-BOVXS9AMBGV87;C-JIVXPZ
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,0IM<V=I9"`B4F5F<F5S
M:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`BV*C8I]BRV*+9B-BQVXP@V8;9A=BG
MVXP@V*_8L=JOV*?9ASHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX
M.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C,U"B,L(&9U>GIY"FUS9VED(")296=E>"(*;7-G
M<W1R("+8J-BGV++9AMBTV*?9AMN,(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(T.0IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T
M<B`BV878L=F(V+':K]BQ(-BQV*?8J-BWV8?B@(S8I^*`C-N,VXPB"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C`X"B,L(&9U>GIY"FUS9VED(")296QO860B"FUS9W-T
M<B`BV*[9B-BGV8;8K]F&(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C8*
M;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`BV*K9B-BVVXS8K=BGV*HB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$T"FUS9VED(")296UO=&4@4V5R=F5R
M<R(*;7-G<W1R("+:J=BGV+'8L]BGV++9A]BGVXP@V+'8I]F'XH",V*_9B-BQ
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")2
M96UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS
M9W-T<B`B55),(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S"FUS9VED
M(")296UO=F4B"FUS9W-T<B`BV*W8L-F!(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B
MV*W8L-F!(-BHV839B-JI(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4U-PIM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R
M("+8K=BPV8$@V+/8JMF(V88B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C0P"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*
M;7-G<W1R("+8K=BPV8$@V8+8I]F$V*@@V*C9AMBOVXPB"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS
M9W-T<B`BV*W8L-F!(-BRV8C8K"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HR,#(*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G
M<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("+8K=BPV8$@V*_8L]BJ
M(.*`C-F&V8C;C-BSV8?8I]N,(-BMV8'8N"#8M-BOV8<@V*_8L2#8M-BGV*[9
MAR#9A=F(V8+8JB#:J=BGV+'8L]BGV+(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@(E)E;6]V
M92!T:&4B"FUS9W-T<B`BV*W8L-F!(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@
M=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(MBMV+#9@2#8
MI]N,V88@VJ_8L=F'(-BGV+(@V+/9AMBO(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T
M<B`BV*W8L-F!(-JIV*?8L=BHV+$B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU
M;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M
M;W9E('5S97(Z("5S(@IM<V=S='(@(MBMV+#9@2#:J=BGV+'8J-BQ.B`E<R(*
M"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")2
M97%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O
M9&4Z("(*;7-G<W1R("+8JMF"V*?8MMBG(-F"V*?8J-F$(-F^V*?8L]BNVJ_9
MB-N,VXP@V8;;C-BSV*HN(-JIV*\@V*[8M]BGVXP@V*C8L=JOV+'8K]BGV8;8
MK]F'(-BTV*_9ASHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,34W"B,L(&9U>GIY"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N
M;W0@8F4@9F]U;F0N(@IM<V=S='(@(MF^V+'9B-F&V*_9AR#8I]BQV+/8I]F$
M(-BTV*_9AR#9AMF%VXSB@(S8JMF(V*?9AMBO(-BMV8'8N"#8M-F(V*\B"@HC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M
M(PHC(`HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-"!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B)R5S)R#9A=F(V+'8KR#9AMN,V*?8LB#8
MK]BQ(-F^VXS:J=BQV*C9AMBOVXP@)7,@V878M-BNV+4@V8;8M-BOV8<@V*?8
ML]BJ(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C
M+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-S4@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,S`*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C<R,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B<E<R<@V879B-BQV*\@V8;;C-BGV+(@
MV*_8L2#9OMN,VJG8L=BHV8;8K]N,(%9&4R#9A=BTV*[8M2#9AMBTV*_9AR#8
MI]BSV*HB"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@
M(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW.#$*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N
M;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B<E<R<@
MV879B-BQV*\@V8;;C-BGV+(@V*_8L2#9OMN,VJG8L=BHV8;8K]N,(-F%V+38
MKMBU(-F&V+38K]F'(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO
M4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T
M<B`BV8';C-F$V*_9A]BGVXP@V879B-BQV*\@V8;;C-BGV+(B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SD*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(P('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`BV*C8I]BR
MV8;8M-BGV8;;C"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V
M"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R("+8J-BGV++9AMBTV*?9
MAMN,(-BGV+/9A2#8L=F%V+(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R("+8
MI]BSV84@V+'9A=BR(-BNV8C8KR#8L=BG(-BHV*?8LMF&V+38I]F&VXP@VJG9
MAMN,V*\B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"B,L(&9U>GIY"FUS
M9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T<B`BV+'8J-BY(-BBV*[8
ML2(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI;B]C;61S:&5L;"YP
M:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP.C8V"FUS9VED(")297-U;'1S(@IM
M<V=S='(@(MF&V*K8I]N,V*PB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E
M='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(MBHV*?8LMJOV+38JB#8J-F'(-JO
MV++;C-F&V8?B@(S9A]BG(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C,X"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(MBJ
MV*?;C-F^(-BOV8C8J-BGV+'9AR#8I]BSV84@V+'9A=BR("#8K-BOVXS8KR`B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM<V=S='(@(MJOV+'8
MK]F'V878I]N,VXPB"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R
M9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#
M;VYF:6=U<F%T:6]N(@IM<V=S='(@(MBHV*?8LMJOV+'8K]BGV8;8K]F&(-F^
MVXS:J=BQV*C9AMBOVXPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,R
M"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`BVJ_8
MLMN,V8;9A^*`C-F'V*?;C"#9B-N,V+'8I]N,V+3:K]BQ(-F%V*K9AB(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G
M<W1R("+9A=BYV878I]F'V*<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@
M(MBQV*?8L]BJ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,0IM
M<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(MBSV+'8HMF%V*\@V+'8I]BS
MV*HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$W"FUS9VED(")2
M:6=H="!V86QU97,B"FUS9W-T<B`BV879@MBGV*_;C-BQ(-BQV*?8L]BJ(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`BV*[8
MM=F(V+7;C-BGV*H@V+/8M]BQ+BXN(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R("+9
MAMF"V+0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,C4*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`BVH;8L=BNV+0@V[';N-NP
M(-BOV+'8K-F'(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(R,@IM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`BVH;8L=BN
MV+0@V*C9AR#:AMF^(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(R.`IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(MJ&
MV+'8KMBT(-BHV8<@V+'8I]BSV*HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R
M=&EE<R(*;7-G<W1R("+8KMBUV8C8M=N,V*?8JB#8L]BWV+$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS
M9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R("+8KMBUV8C8M=N,V*?8JB#8
ML]BWV+$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`BV+/8M]BQV8?8ISHB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R("+9@MF(V*?8N=BO(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM
M<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@
M8V]L=6UN<R(*;7-G<W1R("+9@MF(V*?8N=BO(-BHVXS9AB#8JMF%V*?9A2#8
ML]BWV+'9A]BG(-F((-BSV*K9B-F&V8?8IR#9AMF%V*?;C-BGV88@V*[9B-BG
MV8?8KR#8M-BO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`BV8+9B-BGV+G8KR#9@=F"V+<@
MV*C;C-F&(-BJV878I]F%(-BSV*K9B-F&V8?8IR#9AMF%V*?;C-BGV88@V*[9
MB-BGV8?8KR#8M-BO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`BV8+9B-BGV+G8KR#9@=F"V+<@
MV*C;C-F&(-BJV878I]F%(-BSV+?8L=F'V*<@V8;9A=BGVXS8I]F&(-BNV8C8
MI]F'V*\@V+38KR(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*;7-G:60@
M(E)U;B(*;7-G<W1R("+8I]BLV+'8IR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@
M(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S
M"B,L(&9U>GIY"FUS9VED(")2=V%N9&$B"FUS9W-T<B`BV*[9B-BGV8;8K]F&
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G
M:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I
M9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(MF^VXS8NMBG
MV84@V+'9A=BRV*C9AMBOVXP@(-BTV*_9A]F4(%,O34E-12`B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q"FUS9VED(")305-,(&%U=&AE
M;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(MBJV+78K]N,
MV8(@V8?9B-N,V9'8JB!305-,(-F"V*?8J-F$(-BOV+/8JMBQV+/;C"#9AMN,
MV+/8JB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#0*;7-G:60@
M(E--4R!-97-S86=I;F<B"FUS9W-T<B`BV;[;C-BZV*?9A2!335,B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R
M("+9OMF(V+/8JMF'(%-13"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,R.#,*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,0IM
M<V=I9"`B4U-((@IM<V=S='(@(E-32"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G
M:60@(E-50T-%4U,B"FUS9W-T<B`BV879B-F!V9'9@MN,V9'8JB(*"B,Z(&QI
M8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R("+9OMF(
MV+/8JMF'(%-13"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(MBTV8;8J-F'(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-PHC+"!F=7IZ>0IM<V=I9"`B4V%I;G0@3'5C
M:6$B"FUS9W-T<B`BV*C8I]BQV*?9AB#8K]N,V+'9A]F&VJ_8I]F%(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC96YT
M(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R
M86UE("A?<V5L9BDB"FUS9W-T<B`BV8?9A=BGV88@VH;8I]BQVH;9B-BH("C8
MKMF(V*_8M"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"B,L(&9U>GIY"FUS9VED(")386UO
M82(*;7-G<W1R("+9A]BQV++9AMBGV879AR(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*(RP@
M9G5Z>GD*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`BV*W8I]BTVXS9AR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y
M"B,L(&9U>GIY"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B
MV8C8MMBYVXS8JB#8K=F(V++9A^*`C-F'V*<B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS
M9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.CDX"FUS9VED(")3879E(@IM<V=S='(@(MBMV8'8
MN"#:J=BQV*_9AB(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D
M92`S*2`@(RTC+2,M(RTC"B,@"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F4@
M7"(E<UPB(@IM<V=S='(@(MBMV8'8N"#:J=BQV*_9AB`E<R(*"B,@(RTC+2,M
M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L('!H<"UF;W)M870*
M;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`BV*W9@=BX(-JIV+'8K]F&("5S(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I
M;VYS(@IM<V=S='(@(MBMV8'8N"#:K]BRVXS9AMF'XH",V8?8IR(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R
M=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`BV;[;C-JI
MV+'8J-F&V*_;C"#8JMF(V83;C-BO(-BTV*_9AR#8J-BYV8;9B-BGV88@V*_8
ML]BJ(.*`C-F&V8C;C-BS(%!(4"#8K]BQ(-BTV*?8KMF'V90@V879B-F"V*H@
MVJG8I]BQV+/8I]BR(-BTV878IR#8K=F!V+@@V+39B-BO(@H*(R`C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BV;[;C-JIV+'8
MJ-F&V*_;C"`E<R#8K=F!V+@@V+38KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.CDS"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3
M879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R
M("+8K]BSV*H@XH",V8;9B-N,V+,@V*C8L=F(V++8L=BSV*?9AMN,(-BQV*?9
MA^*`C-BGV8;8K]BGV++;C"#8K=F!V+@@V+38KR#8K]BQ(#HG)7,G("XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0HC+"!F
M=7IZ>0IM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(E0M4W1O
M<FUS(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE
M;F-E(@IM<V=S='(@(MBYV839A2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V
M"FUS9VED(")396%R8V@B"FUS9W-T<B`BV*S8L]BJXH",V8C8K-F((@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R,`IM<V=I9"`B4V5A<F-H($5N
M9VEN97,B"FUS9W-T<B`BV*S9B-N,V+3:K]BQV8?8IR(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Y-S,*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G
M<W1R("+8I]F&V*K8KMBGV*@@V;[8L=F(V8;8K]F'XH",V8?8IR(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0*;7-G:60@
M(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-N,VJD@V*K8
MI]BQVXS8KB(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS
M9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`BV*?9AMBJV*[8
MI]BH(-N,VJD@VJ_8L=F(V8<@V*C8L=BGVXP@V*?8MMBGV8'9AR#:J=BQV*_9
MAB(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E
M;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@VXS:J2#9
MA=BGV83:J2#8K-BOVXS8KR(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(MBGV8;8
MJMBNV*?8J"#;C-JI(-JIV*?8L=BSV*?8LB(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*
M;7-G<W1R("+8I]F&V*K8KMBGV*@@VXS:J2#:J=BGV+'8J-BQ(-BHV+'8I]N,
M(-BGV+;8I]F!V8<@VJG8L=BOV88B"@HC(",M(RTC+2,M(R`@9F%?25(N<&\@
M*%1U<F)A(#$N,BXR*2`@(RTC+2,M(RTC"B,@;7-G:60@(E-E87)C:"!297-U
M;'1S(@HC(&US9W-T<B`BV8;8JMBGVXS8K"#8K-BSV*K8K-F((@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"FUS9VED(")3
M96QE8W0@86QL(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#9A]F%V8<B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8S"FUS9VED(")396QE8W0@86QL
M(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-BJV878
MI]F%(-F%V*39A-F!V8?B@(S9A]BGVXP@V*K8I]BQVXS8KB(*"B,@(RTC+2,M
M(RTC("!F85])4BYP;R`H5'5R8F$@,2XR+C(I("`C+2,M(RTC+2,*(R!M<V=I
M9"`B4V5A<F-H(%)E<W5L=',B"B,@;7-G<W1R("+9AMBJV*?;C-BL(-BLV+/8
MJMBLV8@B"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HX-S,*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`BV*?9AMBJ
MV*[8I]BH(-N,VJD@V+38IB(*"B,@(RTC+2,M(RTC("!F85])4BYP;R`H5'5R
M8F$@,2XR+C(I("`C+2,M(RTC+2,*(R!M<V=I9"`B4V5A<F-H(%)E<W5L=',B
M"B,@;7-G<W1R("+9AMBJV*?;C-BL(-BLV+/8JMBLV8@B"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S@*;7-G:60@(E-E;&5C
M="!N;VYE(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#9A]N,VH;B@(S:J=BOV*?9
MA2(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L
M96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E
M;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M
M('1H92!T97AT(&%R96$N(@IM<V=S='(@(B(*(MF&V8C;C-BSV8?B@(S9A]BG
MVXS;C"#:J=F'(-F$V*?8LMF%(-BOV*?8L=N,V*\@V+'8IR#8I]BR(-BLV+G8
MJ-F'(-BRVXS8L2#8I]F&V*K8KMBGV*@@VJG9AMN,V*\N(-BSV;[8LR#8M-F%
MV*<@V87;C.*`C-BJV8C8I]F&VXS8KR#8I]BR(-BBV8;9A]BG("(*(MBOV+$@
MV879AMBWV8+9AR#9A=BJV88@V8;8L]BNV8?B@(S8J-BQV*_8I]BQVXP@VJG8
ML=BOV8<@V8@@V*_8L2#9A=BMV80@V*_;C-JOV+$@V*C:AMBSV*C8I]F&VXS8
MKR(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")396QE
M8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@
MV878K=BOV8C8K]F'(-BJV*?8L=N,V*XZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM
M<V=S='(@(MBGV8;8JMBNV*?8J"#9@MBGV838J"#8JMBGV+';C-BN.B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@
M(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G
M<W1R("+8I]F&V*K8KMBGV*@@V8?9B-N,V9'8JMN,(-JIV8<@V87;C.*`C-BN
MV8C8I]F'VXS8KR#8JMBZVXS;C-BQ(-BOV8?;C-BO.B(*"B,Z('1E;7!L871E
M<R]D871A+W1I;64N:6YC.C$V"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L
M:6UI=&5R.B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@V878K=BOV8C8K]F'V90@
MV++9A=BGV88Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G
M:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(MBGV8;8JMBN
MV*?8J"#9@MBGV838J"#8LMF%V*?9ACHB"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD
M<RXB"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-BOV8@@V8';C-F$V*\@V879AMBW
MV*C9@B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#8*;7-G:60@(E-E
M;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`BV*?9AMBJV*[8I]BH
M(-BWV+'8K2#8L=F&VJ\@V+39A=BG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(T.`IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E
M.B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@V++8J-BGV88@V879B-BQV*\@V8;8
MN-BQ(-BTV878ISHB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("+8I]BQ
MV+/8I]F$(-JOV++8I]BQV+0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`S.0IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B
MV*?8L=BSV*?9A"!335,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$V"FUS9VED
M(")396YS;W(Z("(*;7-G<W1R("+8K=BSVJ_8L3H@(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E
M<B(*;7-G<W1R("+8L]F^V*K8I]F%V*C8L2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E
M;F5G<F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HW,#$*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`BV*?8
MN=BOV*?8KR#8JMBQV*K;C-BHVXPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,38Q"B,L(&9U>GIY"FUS9VED(")397)V97(@9&%T82!W<F]N
M9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R("+8J-F$V8C:J2!-971A<B#9
M@MBGV*C9A"#8K]BSV*K8L=BS(-F&VXS8L]BJ(@H*(SH@861M:6XO<V5S<VEO
M;G,N<&AP.C(W"B,L(&9U>GIY"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S
M='(@(MBSV+'9OMBQV+/8JMN,(-F%V*S9B-BRV8?8IR(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B
M4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R("))1"#9AMBTV+/8JB#9A=F&
MV8+8MMN,(-BTV*_9AR#8I]BSV*HB"@HC.B!L:6(O87!I+G!H<#HQ-#4*(RP@
M9G5Z>GD*;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@(MF%V*S9B-BRV8?8IR(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,30*;7-G:60@(E-E="(*
M;7-G<W1R("+8JMF&V+C;C-F%(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<V"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@
M>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@
M(B(*(MBJV8;8N-N,V84@VJ_8LMN,V8;9A^*`C-F'V*<@V*C8L=BGVXP@V*?8
MK-BGV++9AR#8K]BGV*_9AB#8J-F'(-BTV878IR#8J-BQV*?;C"#8J-BGV++9
MAMBTV*?9AMN,(-BGV+/9A2#8L=F%V+(@V*C9AR#9A]F&VJ_8I]F%(-F!V+'8
MI]F%V8C8M-N,("(*(MBBV88@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A
M;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(B(*(MBJ
MV8;8N-N,V84@VJG8I]BQV+/8I]BRV8?8I]N,(-BQV*?9AR#8K]F(V+';C"#:
MJ=F'(-BTV878IR#9A=N,XH",V*[9B-BGV8?;C-BO(-BGV+(@V*_8L=JOV*?9
MAR#8KMF(V*\@V*C9AR#8HMF&(-BOV+/8JMBQV+/;C"#8K]BGV+38JMF'("(*
M(MBHV*?8M-N,V*\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0*;7-G
M:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD
M(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-BRV*C8I]F&
M(-F%V8C8L=BO(-F&V+C8L=B,(-BSV*?8N=BJ(-F((-JOV++;C-F&V8?B@(S9
MA]BGVXP@V*K8I]BQVXS8KB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M.`IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L
M;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P
M;&%Y(&]P=&EO;G,N(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#8J-BQV8;8I]F%
MV8<@V++9A=BGV88@V+38L=F(V+G8C"#8M]BQV*T@V+'9AMJOV(P@V*C8I]BR
MV*+9B-BQVXP@V+79@=BMV8<@V8@@V*C9@MN,V8<@VJ_8LMN,V8;9A^*`C-F'
MV*?;C"#9AMF%V*?;C-BT(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW
M-0IM<V=I9"`B4V5T=7`B"FUS9W-T<B`BV+'8I]F')B-X,C`P8SO8I]F&V*_8
MI]BRVXPB"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@
M(",M(RTC+2,M(PHC(`HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N
M:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L
M92(*;7-G<W1R("+8K]BSV*H@XH",V8;9B-N,V+,@(-BHV+'9B-BRV+'8L]BG
MV8;;C"#8L=BGV8?B@(S8I]F&V*_8I]BRVXP@V*_8L2#8K]BSV*K8L=BS(-BG
MV+/8JB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.#8*;7-G
M:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M
M971E<CH@(@IM<V=S='(@(MJ&V8;8K]N,V88@V879B-F"V+G;C-F1V*H@V*C8
MIR#9OMBGV+'8I]F%V*K8L2#9A=F%VJG9AB#8I]BSV*HZ(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#DV"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R
M("+8KMBQVXS8KR(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C0S"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(MBNV838I]BUV8<@
MVJG9B-BJV*?9AR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#8*;7-G
M:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI
M;FMS/R(*;7-G<W1R("+8HMN,V*<@VJG9A-N,V*_9A]BGVXP@V*_8L]BJV+'8
ML]N,(-BHV*?;C-BO(-BHV+'8I]N,(-BHVXS8M-BJV+$@V;[;C-F(V8;8K]F'
MV*<@V*K8N=BQVXS9@2#8M-F(V8;8K]B?(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`BV8;9
MA=BGVXS8M"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@
M(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@
M86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B(-F&V878I]N,V+0@V*K9@=BGV8C8JMF'V*?;C"#9A=N,V*?9AB#9
MOMN,VJG8L=BHV8;8K]N,(-BMV8'8N"#8M-BOV8<@V8'8N=F$VXP@V8@@V*K9
MB-F$VXS8KR#8M-BOV8<@V*S8K]N,V*\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#DP"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO
M9V=I;F<@:6X_(@IM<V=S='(@(MBBVXS8IR#8LMF%V*?9AB#8HMBNV+';C-F&
M(-F(V+'9B-BO(-BHV8<@V8?9AMJOV*?9A2#9B-BQV8C8KR#9AMBTV*?9AB#8
MK]BGV*_9AR#8M-F(V*_8GR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$W-C4*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS
M9W-T<B`BV8;9A=BGVXS8M"#:K]BRVXS9AMF'XH",V8?8IR#8J-BQV*?;C"#9
MAMJOV8?8K]BGV+';C"#8I]BUV80B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#$S"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R("+8I]F&V*K8
MKMBGV*@@V8/9AMF&V*_9AR#9AMF%V*?;C-BT(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4R-@IM<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS(&UE
M;G4@8F%R/R(*;7-G<W1R("+8HMN,V*<@V87;C-F$V8<@VJ_8LMN,V8;:K]BG
MV88@V+G9A=F$VXS8I]BJ(-BLV*_9B-F$XH",(-F&V878I]N,V+0@V*_8I]BO
MV8<@V+39B-BOV)\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R
M9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0Y"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@
M=&AE(&QE9G0_(@IM<V=S='(@(MBBVXS8IR#:K]BRVXS9AMJOV*?9AB`E<R#8
ML]F%V*H@V+'8I]BSV*H@V8;8M-BGV88@V*_8I]BOV8<@V+39B-BOV)\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`BV8;9A=BGVXS8M"#:K]F!V*KB@(S9B-JOV8C;C"#8
MKMBUV8C8M=N,V*?8JB#8L]F$V8C9A"#8K-BOV8C9A"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I
M9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B
MV8;9A=BGVXS8M"#:K]F!V*K:K]F(VXP@V*[8M=F(V+7;C-BGV*H@V*S8K]F(
MV80B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T
M:65S(&1I86QO9R(*;7-G<W1R("+9AMF%V*?;C-BT(-JOV8'8JMJOV8C;C"#8
MKMBUV8C8M=N,V*?8JB#8L]BWV+$@V*S8K]F(V80B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@
M(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(MF&
MV878I]N,V+0@VJ_9@=BJVJ_9B-N,(-BNV+79B-BUVXS8I]BJ(-BJV+79B-N,
MV+$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8S"FUS9VED(")3
M:&]W('5P;&]A9"(*;7-G<W1R("+9AMF%V*?;C-BT(-BGV+'8L]BGV80B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I
M9"`B4VAO=V5R<R(*;7-G<W1R("+8JMJOV+':KR(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")3:&]W97)S($5A
M<FQY(@IM<V=S='(@(MBQVJ_8J-BGV+$@V++9B-BOV8?9AMJOV*?9A2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED
M(")3:&]W97)S($QA=&4B"FUS9W-T<B`BV+':K]BHV*?8L2#8K]N,V+'9A]F&
MVJ_8I]F%(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3,*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0X,`IM
M<V=I9"`B4VAR:6YK(@IM<V=S='(@(MBLV878N2#8M-BOV88B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW-S0@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#,V"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.CDR,B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HY.#0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z,3`T-R!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#@W
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q,38@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$T.0IM<V=I9"`B4VAR
M:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@
M=V%Y(&9I<G-T(@IM<V=S='(@(MBLV878N2#8M-BOV88@VXS8IR#8I]F&V*K9
M@MBGV80@V*C9A-F(VJG9A]BGVXP@V878K-BGV8C8L2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8U"FUS9VED(")3:6=N('5P(@IM
M<V=S='(@(MBKV*C8JB#9AMBGV84B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(MBG
MV878MMBGV*$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C<Q,0IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R("+8I]F$
MVJ_9B-BQVXS8JMF%(-BGV878MMBGV*$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"B,L(&9U
M>GIY"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`BV*?9A=BVV*?8H2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@W(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$U(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,P"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*;7-G:60@(E-I>F4B"FUS
M9W-T<B`BV*?9AMBOV*?8LMF'(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B
M"FUS9W-T<B`BV+78L=F!V8;8N-BQ(-BGV+(@V8;:K]F'V*_8I]BQVXPB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`U"FUS9VED(")3;&]V86MI82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI82(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B4VYO
M=R(*;7-G<W1R("+8J-BQV8$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B
MV*K:K]BQVJ\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(MBJVJ_8L=JO
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*
M;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R("+8L=JOV*C8I]BQ
M(-BRV8C8K]F'V8;:K]BGV84B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS
M9W-T<B`BV+':K]BHV*?8L2#8K]N,V+'9A]F&VJ_8I]F%(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-S@*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R
M("+8N=F%V8(@V*C8L=F!.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X
M,@IM<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B
MV878N=BGV*_9A"#8J-BQV8$@V*_8L2#8HMBH.B`B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S
M"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,30@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B
MV+38N=BQV8?8IR#9B"#8HMF(V*?8LMF'V*<B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.3(V"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*
M;7-G<W1R("+8I]F&V*K8KMBGV*@@V*S9A]BJ(-F%V+'8JMBH(-BSV*?8LMN,
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C$W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$X.0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`BV*+8
MK]BQV+,@V+/8L=J&V+39A=F'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U
M=&@@069R:6-A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T
M<B`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W
M"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@
M27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@
M;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H
M97)E(@IM<V=S='(@(MF&VXS9A2#:J=BQV8<@V*S9AMF(V*C;C"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED
M(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(MF!V*?8
MM=F$V8?9E"#8J-N,V88@V+/9A-F(V839A]BGVXP@V878K-BGV8C8L2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS
M9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL
M(@IM<V=S='(@(MF!V*?8M=F$V8?9E"#8J-N,V88@V878K=BJV8C8IR#9B"#9
MA-BHV8<@V*_8L2#8L]F$V8C9A"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C@Q-0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(MF!V*?8M=F$V8?B@(S:
MK]BPV*?8L2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R("+9@=BGV+79
MA-F'(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R
M("+9@=BGV+79A-F'XH",VJ_8L-BGV+';C"#9B"#8K]BQV++:K]BPV*?8L=N,
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(E-P86EN(@IM<V=S='(@
M(MF!V*?8M=F$V8<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3@*
M;7-G:60@(E-P86TB"FUS9W-T<B`BV8?8L=BRV8;8I]F%V8<B"@HC.B!S97)V
M:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R
M($EN<'5T(@IM<V=S='(@(MJIV*?8L=BGVJG8JMBQ(-BNV*?8M2#9B-BGV+'8
MKR#8M-BO(@H*(R`C+2,M(RTC+2,@(&9A7TE2+G!O("A4=7)B82`Q+C(N,BD@
M(",M(RTC+2,M(PHC(&US9VED(")396%R8V@@4F5S=6QT<R(*(R!M<V=S='(@
M(MF&V*K8I]N,V*P@V*S8L]BJV*S9B"(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L
M;"(*;7-G<W1R("+8JMF"V+/;C-F%(-BSV839B-F$(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B
M4W!L:70@8V]L=6UN(@IM<V=S='(@(MBJV8+8L]N,V84@V+/8JMF(V88B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`BV*K9@MBSVXS9A2#8L]BW
MV+$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E-P;W)T
M<R(*;7-G<W1R("+9B-BQV++8M-N,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"B,L(&9U>GIY
M"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`BV*S9A=BY(-BTV*_9AB(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,R!L:6(O0FQO8VLO;65T
M87(N<&AP.C<T"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R("+8I]BSV*K8I]F&
MV*_8I]BQV*\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@
M(E-T87(@5')E:R(*;7-G<W1R("+8L]BJV*?8L=F'(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C4Y-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#`Y"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(MBSV*?9A"#8M-BQV8C8
MN2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P"FUS
M9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R("+9B-BVV+G;C-BJ(-BM
MV8C8LMF'XH",V8?8IR(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E
M>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`BV8C8MMBYVXS8JN*`
MC"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*;7-G:60@(E-T
M;W)A9V4@9F]R;6%T(@IM<V=S='(@(MF"V*?9A-BH(-BPV*[;C-BQV8<@V+/8
MI]BRVXPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M,@IM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`BV*+8K]BQV+,@V*[;
MC-BGV*C8I]F&(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@
M;&ES="(*;7-G<W1R("+9@=F'V+'8L]BJ(-BQV+38JMF'(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R
M;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@
M6T-34UTB"FUS9W-T<B`BV+3;C-F(V8<@6T-34UTB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G
M<W1R("+;C-JIV+39AMBHV8<B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<
M(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(@V++;C-BQV+38I]BNV8<@)R5S
M)R#9OMN,V*_8IR#9AMBTV*\N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R("+8
MN=F&V8C8I]F&(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R(&9R
M86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PIM<V=I9"`B4W5B
M;6ET(@IM<V=S='(@(MBGV+'8L]BGV80B"@HC.B!S:6=N=7`N<&AP.C0Y"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S
M="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO
M9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N
M(@IM<V=S='(@(B(*(MBJV8+8I]BVV*?;C"#8I]BVV*?9@=F'(-BTV*_9AB`G
M)7,G(-BHV8<@V+/8I]F%V*?9AMF'(-BGV+'8I]BFV8<@V+38KRX@V*K8IR#9
MA]F&VJ_8I]F%VXP@VJG9AR#8JMF"V*?8MMBGVXP@V+39A=BG(-BJV*/;C-N,
MV*\@(@HBV8;:K]BQV*_8KR#9AMF%VXSB@(S8JMF(V*?9AMN,V*\@V*C9AR#8
ML]BGV878I]F&V8<@V8C8I]BQV*\@V+39B-N,V*\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I
M<'0B"FUS9W-T<B`BV++;C-BQV8;9B-N,V+,B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3`T"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS
M9W-T<B`BV879B-F!V9'9@MN,V9'8JB(*"B,@(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W5S97(N
M<&AP.C@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@861D960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@(B<E<R<@
MV*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BHV8<@V+/8I]F%V*?9AMF'(-BGV+;8
MI]F!V8<@V+38KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D
M92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@
M9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R
M("(@V*_8I]BOV8?9E"#:J=BGV+'8J-BQ("<E<R?8J-BG(-F%V8C9@=F1V8+;
MC-F1V*H@V*?8LB#8L]BGV878I]F&V8<@V;[8I]JI(-BTV*\B"@HC(",M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC
M.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z
M-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@
M7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ
M(-BMV+#9@2#8M-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO
M<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E
M9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(G)7,G(-BHV*<@
MV879B-F!V9'9@MN,V9'8JB#8I]BR(-BSV*?9A=BGV8;9AR#9OMBGVJD@V+38
MKR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC
M+2,M(RTC"B,@"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@
M(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@
M=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*(MF^VXS:J=BQV*C9AMBOVXP@
MV*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BHV*?8LMJOV+'8K]BGV8;8K]F'(-BT
MV*\N(-BHV+'8I]N,(-F%V+38I]F'V*_9AR#8JMBZVXS;C-BQV*?8JB#9A=BL
MV*_8K]BGV9(@V*+9AMBQV*<@V*C8I]BQ(-F&V878I]N,VXS8KR(*"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+9OMN,VJG8L=BHV8;8K]N,(-F^V+38
MJMN,V*C8I]F&(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8K=F!V+@@V+38KR(*
M"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M
M(RTC"B,@"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("+9OMBQV8C9AMBOV8<@V;[8
MM-BJVXS8J-BGV88@V;[;C-JIV+'8J-F&V*_;C"`E<R#8J-BG(-F%V8C9@=F1
MV8+;C-F1V*H@V*W9@=BX(-BTV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU
M;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]U<V5R+G!H
M<#HQ-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R("(G)7,G(-BHV*<@V879B-F!V9'9
M@MN,V9'8JB#8J-F'(-BQV8C8LB#8M-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S
M='(@(B5S(-BHV*<@V879B-F!V9'9@MN,V9'8JB#9AMF(V+38JMF'(-BTV*\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T"B,L(&9U>GIY"FUS9VED(")3=61A;B(*;7-G<W1R
M("+8HMF!V*K8I]BHVXPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y(@IM<V=S='(@
M(MBNV838I]BUV8<B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G
M:60@(E-U;B!2:7-E(@IM<V=S='(@(MBWV839B-BY(-BBV8'8JMBGV*@B"@HC
M.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS
M9W-T<B`BV+K8L=F(V*@@V*+9@=BJV*?8J"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3=6YN>2(*;7-G<W1R
M("+8HMF!V*K8I]BHVXPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C$V"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(MBWV839B-BY(@H*(SH@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP
M.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R("+8M]F$V8C8N2_8
MNMBQV8C8J"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,34*
M;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R("+8M]F$V8C8N3H@(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.0IM<V=I9"`B4W5N<V5T(@IM
M<V=S='(@(MBZV+'9B-BH(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(Q.`IM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`BV+K8L=F(V*@Z("(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*
M;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(MBHV*?9A-BGV8;9B-N,V+,B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<X"FUS9VED(")3=7!P
M;W)T(@IM<V=S='(@(MF^V+38JMN,V*C8I]F&VXPB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V
M"B,L(&9U>GIY"FUS9VED(")3=7)I;F%M92(*;7-G<W1R("+9AMBGV84@V*[8
MI]F&V8C8I]BOVJ_;C"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3<T"FUS9VED(")3=7)N86UE(@IM<V=S='(@(MF&V*?9A2#8KMBG
MV8;9B-BGV*_:K]N,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@
M86YD($IA;B!-87EE;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED
M(")3=V%Z:6QA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B
M4W=E9&5N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3=VET>F5R
M;&%N9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HX-@HC+"!F=7IZ>0IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R
M("+8K=BPV8$@V8;8M-F(V*\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,30R"FUS9VED(")3>6YC34PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-1
M3"]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@
M<V5A<F-H('1E<FUS(@IM<V=S='(@(MBNV+?8I]N,(-F&V*W9B-N,(-BOV+$@
MV879B-BGV+'8KR#8K-BSV*K8K-F((@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B
M4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E0M4W1O<FTB
M"FUS9W-T<B`B5"U3=&]R;7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C(*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(E0M4W1O<FUS(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*(RP@9G5Z
M>GD*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@(MBQVJ_8J-BGV+$@
MV++9B-BOV8?9AMJOV*?9A2(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V
M+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(MF^V+'9B-F&V*_9
MAR!44U8B"@HC.B!F<F%M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S-`IM<V=I
M9"`B5&%B;&4B"FUS9W-T<B`BV*S8K]F(V80B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED(")486)L
M92!0<F]P97)T:65S(@IM<V=S='(@(MBNV+79B-BUVXS8I]BJ(-BLV*_9B-F$
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU
M-PHC+"!F=7IZ>0IM<V=I9"`B5&%B;&4@4V5T(@IM<V=S='(@(MBLV*_9B-F$
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R("+8KMBU
MV8C8M=N,V*?8JB#8K-BOV8C9A"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*(RP@
M9G5Z>GD*;7-G:60@(E1A:7=A;B(*;7-G<W1R("+8J-BGV+'8I]F&(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A
M:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`BV8?8K]F!.B(*"B,Z(&-O
M;F9I9R]H;V]K<RYP:'`N9&ES=#HY.38@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$X-PIM<V=I9"`B5&%S:W,B"FUS9W-T<B`BV8C8N-BGVXS9@2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")4
M96QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(MBTV878I]BQV8<@V*K9A-F!V88B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,`IM<V=I9"`B5&5M<"!F;W(@
M;&%S="!H;W5R.B`B"FUS9W-T<B`BV*_9A=BGVXP@V+/8I]BYV*H@V*?8KMN,
MV+$Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$T"FUS9VED(")496UP
M97)A='5R92(*;7-G<W1R("+8K]BQV*S9AR#8K=BQV*?8L=BJ(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,PIM<V=I9"`B5&5M<&5R871U
M<F4Z("(*;7-G<W1R("+8K]BQV*S9AR#8K=BQV*?8L=BJ.B`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDS"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F
M9&5G.R5S(@IM<V=S='(@(B`H)7-(:25S+R5S3&\E<RD@)F1E9SLE<R#8K]F%
MV*<B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8X-PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(-BGV83:K]F(VXP@)R5S)]F^VXS8K]BG(-F&
MV+38KR(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")496UP
M;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R("+8I]F$VJ_9B-N,(-BSV+'9
MOMBQV+/8JMN,(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,V"FUS9VED(")497AT(@IM<V=S
M='(@(MF%V*K9AB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S4*;7-G
M:60@(E1E>'0@3VYL>2(*;7-G<W1R("+9@=F"V+<@V878JMF&(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM
M<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R("+8JMBQV*?8LB#9A=BJV88B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS
M9VED(")497AT=&]P(@IM<V=S='(@(MBHV*?9A-BGVXP@V878JMF&(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I
M9"`B5&@B"FUS9W-T<B`BV;[9AMBLV+39AMBHV8<B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y,0IM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B
M5&AA:2`H5$E3+38R,"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4:&%I;&%N
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*
M;7-G:60@(E1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T
M<B`BV*?8LB#8M-F%V*<@V*C9AR#8KMBGV+?8L2#8I]BSV*K9@=BGV*_9AR#8
MI]BR(-BSV*?9A=BGV8;9AR#9A=BJV+3:J=BQVXS9A2(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#(P"FUS9VED(")4:&4@1E10(&5X=&5N<VEO
M;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("+8J-BSV+<@1E10(-F"V*?8
MJ-F$(-BOV+/8JMBQV+,@V8;;C-BSV*HB"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O
M2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E
M<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+T)O
M;VLN<&AP.C$R.3(*(RP@9G5Z>GD*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L
M9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(MF^V+'9B-F&V*_9AR#8
MI]BQV+/8I]F$(-BTV*_9AR#9AMF%VXSB@(S8JMF(V*?9AMBO(-BMV8'8N"#8
MM-F(V*\B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@
M(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S
M9G5L;'DB"FUS9W-T<B`BV8;:K]F'V*_8I]BQVXPZ.B#:J=F$V*?8LR#8J-BG
M(-F%V8C9@=F1V8+;C-F1V*H@V*C8I]BQ(-F&V+38KR(*"B,Z('-E<G9I8V5S
M+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS
M('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R("+9OMF&V*S8
ML=F'V90@VJ_8LMN,V8;9A^*`C-F'V*<@V*C8L]BJV8<@V+38KRX@V*[8L=F(
MV*PB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X.2!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C(Q,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R,PHC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(V
M-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE
M(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT
M(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E
M<FUI<W-I;VYS+B(*;7-G<W1R("(B"B+8L]BQV;[8L=BSV*H@V*C8I]N,V*\@
MVXS:J2#9OMBTV*K;C-BHV*?9AB#9A=BLV8C8LMF'V*<@V+'8I]B,("#8K]BQ
M(-BUV8C8L=BJ(-BJV878I]N,V80@V+39A=BG(-BHV8<@V*?8L]BJV8'8I]BO
MV8<@V*?8LB#9A=BLV8C8LMF'V*?8C"`B"B+9OMN,VJG8L=BHV8;8K]N,(-JI
MV8;8KRXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G
M<W1R("+8JMF&V8?8IR#8L]F%V*H@V;[8I]N,VXS9AB(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B
M"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE
M9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N
M(@IM<V=S='(@(MBTV878I]BQV8<@240@V*K9A=BGV+,@V878M-BNV+4@V8;8
MM-BOV8<@V*?8L]BJV(P@V*?;C-F&(-BTV878I]BQV8<@V*_8L2#8K]BGV*_:
MK]BGV88@VXS8I]F!V*H@V8;8M-BO(@H*(R`*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W
M87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*
M;7-G<W1R("+8JMF%V*?8LR`@)7,@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BH
MV8<@VJG8JMBGV*C:AMF'(-BBV*_8L=BS(-BTV878IR#8I]BVV*?9@=F'(-BT
MV*\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38Y"FUS
M9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R
M97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R
M("+;C-JI(-BHV839B-JI(-BGV878MMBGVXP@4$=0(-BHV+'8I]N,(-BHV*?8
MLMBHVXS9AMN,(-N,VJD@V;[;C-BZV*?9A2#8I]F%V+;8I]BA(-BTV*_9AR#9
MA=F(V+'8KR#9AMN,V*?8LB#8I]BSV*HB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I
M<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@
M;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*
M;7-G<W1R("))1"#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"#9A=BTV*[8M2#9
MAMBTV*_9AR#8I]BSV*H@V8@@VXS8IR#8K]BQ(-BOV*?8K]JOV*?9AB#9A=F(
MV*S9B-BO(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@
M;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`BV8'9A]BQV+/8JB#8
MJMF(V++;C-BYVXP@V878M-BNV+4@V8;8M-BOV8<@V*?8L]BJ(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,3,*;7-G:60@(E1H92!E;F-R>7!T
M:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN
M(@IM<V=S='(@(MF%V+38KMBUV8?B@(SB@(S9A]BGVXP@V+'9A=BRV*C9AMBO
MVXP@V8;;C-BGV++9A=F&V*\@VXS:J2#8I]BQV*K8M=BGV80@V*?9A=F&(-F(
MV*@@V87;C.*`C-BHV*?8M-F&V*\B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C$W-2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A
M("5S('-E='1I;F<N(@IM<V=S='(@(MF^V+'9B-F&V*_9AR`E<R#8J-BGVXS8
MKR#8K]BGV+'8I]N,(-BJV8;8N-N,V84@)7,@V*C8I]BTV*\B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V."!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S
M:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R("+9OMBQ
MV8C9AMBOV8<@)7,@V*C8I]N,V*\@V*W8I]F(VXP@V*K9AMBXVXS9A=BGV*H@
M)7,@V*C8I]BTV*\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M,3D*;7-G:60@(E1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S
M96QF+B(*;7-G<W1R("+9OMBQV8C9AMBOV8<@V*C8L2#8L=F(VXP@V*[9B-BO
MV+0@V8;9A=N,XH",V*K9B-BGV8;8KR#8L=F(V8;9B-BTV*H@V+39B-BO(@H*
M(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL
M92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`BV;[8L=F(V8;8K]F'(-BM
MV*?9B-N,(-BOV*?8K]F'XH",V*?B@(S;C-N,(-F&VXS8L]BJ("(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@
M(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A
M9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F
M=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I
M=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@
M=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H
M="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET
M;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@
M268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK
M96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@
M1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N
M('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N
M="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@HB
MV878KR#8JMF%V*?9A2#8M=F!V*W9AR#8J-BG($E%(-F%V+3:J=F$(-BOV*?8
ML=BO(-F((-BGVXS9AB#8I]BR(-F%V+3:J=F$V*?8JB#9A=BQV8C8L=JOV+$@
MV87;C.*`C-BHV*?8M-BO+B#8I]JOV+$@V8?9AMF(V+(@(@HBV87;C.*`C-BN
MV8C8I]F'VXS8KR#8K=BGV838JB#9B-N,V+'8I]N,V+3:K]BQ(-BJV878I]F%
M(-BUV8'8K=F'(-BQV*<@V*?9A=BJV*W8I]F&(-JIV8;;C-BOV(P@V838M]F!
MV*?9BR#:J=F$VXS8KR#8JMBCVXS;C-BO(-BQV*<@V8'8M-BGV+$@(@HBV*_9
MA]N,V*\@(@H*(R`*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDP"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L
M971E9"XB"FUS9W-T<B`BV8?9B-N,V9'8JB!<(B5S7"(@V*W8L-F!(-BTV*_9
MAR#8I]BSV*HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL
M>2(*;7-G<W1R("+8JMF&V8?8IR#8L]F%V*H@VH;9OB(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T
M:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@
M0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O341.+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E
M<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N
M=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T
M;V]D+B(*;7-G<W1R("(B"B+9OMN,V+K8I]F%(-F!V+'8L]BJV*?8K]F'(-BT
MV*_9AR#8L=F(VXP@)7,@V*C9AR`E<R#8J-BG(-F%V8C8MMF(V+D@7"(E<UPB
M(-F&V878I]N,V+0@V*_8I]BOV8<@V+38K]F'(-BGV+/8JBY<;B(*(MBJV+;9
MA=N,V8;;C"#8J-BQV*?;C"#8KMF(V*?9AMBOV8<@V+38K]F&(-F((-N,V*<@
MV*_8L=JI(-BBV88@V8C8K-F(V*\@V8;8K]BGV+'8KR(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X-S<*;7-G:60@(E1H92!N86UE('1O('5S92!W
M:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R("+9AMBG
MV87;C"#:J=F'(-BHV8<@V8?9AMJOV*?9A2#9OMN,V8C9AMBOV*_9A]N,(-BH
MV8<@V+79@=BMV8<@V*?;C-BLV*?8KR#9AMBGV879AR#8I]BSV*K9@=BGV*_9
MAR#9A=N,XH",V+39B-BO(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z-#0Q"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU
M;65R:6,N(@IM<V=S='(@(MBJV+G8K]BGV*\@V8';C-F$V*_B@(S9A]BG(-BH
MV*?;C-BO(-N,VJD@V+G8K]BO(-BHV*?8M-BO(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C,Q"FUS9VED(")4:&4@;W!E;G-S;"!M
M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ
M(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,N
M<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC
M92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@
M97AC965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T
M<B`B(@HBV*?9B-F$V8C;C-BJ(%PB)7-<(B#9AMF%VXSB@(S8JMF(V*?9AMBO
M(-BMV8'8N"#:K]BQV*_8KR#8LMN,V+'8IR#9A=F"V*_8I]BQ(-BOV*?8K]F'
M(-BBV88@V*?8LB#8K=BO(-F%V*S8I]BR(-BHVXS8M-BJV+$@V*?8L]BJ(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V
M:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@
M<WES=&5M+B(*;7-G<W1R("(B"B+8J-BQV8;8I]F%V8?B@(S8I^*`C-N,VXP@
MVJG9AR#8J-BQV*?;C"#9A=BTV*?9A]BOV8<@V*?;C-F&(-F&V8C8N2#8K]BG
MV*_9AR`H)7,I(-F"V*C9A-BGV8L@V879B-BQV*\@V*?8L]BJV8'8I]BOV8<@
MV8+8L=BGV+$@V87;C.*`C-JOV+'9@=BJV(P@V*_8L2`B"B+8L]BGV878I]F&
MV8<@V879B-BLV8C8KR#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C0U-`HC+"!F=7IZ>0IM<V=I9"`B5&AE('%U;W1E(&-H87)A
M8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("+8
MK-BOV*<@VJG9AMF&V*_9AR#8J-BGVXS8KR#;C-JI(-F&V8C;C-BSV8<@V*C8
MI]BTV*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@
M;VYL>2(*;7-G<W1R("+8JMF&V8?8IR#8L]F%V*H@V+'8I]BSV*H@V8@@VH;9
MOB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G
M<W1R("+8JMF&V8?8IR#8L]F%V*H@V+'8I]BSV*HB"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HT-#8*;7-G:60@(E1H92!S97!A<F%T;W(@;75S
M="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`BV*S8K]BG(-JI
MV8;9AMBOV8<@V*C8I]N,V*\@VXS:J2#9AMF(VXS8L]F'(-BHV*?8M-BO(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L
M971E9"XB"FUS9W-T<B`BVJG8I]BQV+/8I]BR(%PB)7-<(B#8K=BPV8$@V+38
MK]F'(-BGV+/8JB(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D
M92`S*2`@(RTC+2,M(RTC"B,@"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN
M<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB
M(&AA<R!B965N('-A=F5D+B(*;7-G<W1R("+:J=BGV+'8L]BGV+(@7"(E<UPB
M(-BMV8'8N"#8M-BOV8<@V*?8L]BJ(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO=7-E<BYP
M:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S
M="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`BV*_8L=BNV8C8
MI]BSV*H@V*?9@=BJV*K8I]BM(-BMV+/8I]BH(-BHV+'8I]N,("5S(-BMV+#9
M@2#8M-BOV8<@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z,S,P"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO
M="!E>&ES="XB"FUS9W-T<B`BV+'8K]N,V8$@V878M-BNV+4@V+38K]F'(-F(
MV*S9B-BO(-F&V*_8I]BQV*\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I
M;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("+9OMBQV8C9AMBO
MV8<@V879B-F"V*K;C"`@7"(E<UPBV879B-BLV8C8KR#9AMN,V+/8JB(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,3$*;7-G:60@(E1H92!T97AT
M('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C
M<F5E;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T
M=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`BV*K9AMF'V*<@V+/9A=BJ(-BHV*?9
MA-BG(-F((-F^V*?;C-N,V88B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@
M;VYL>2(*;7-G<W1R("+8JMF&V8?8IR#8L]F%V*H@V*C8I]F$V*<B"@HC.B!F
M<F%M97=O<FLO1&%T82]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E
M9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G
M<W1R("+8K]BGV*_9A]F4(-BGV+'8L]BGV80@V+38K]F'(-BGV+(@VJ_8I]F%
M(-F"V*C9A-N,(-BGV+(@V*_8L]BJ(-BQV8'8JMF'(-BGV+/8JB(*"B,Z(&9R
M86UE=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O
M1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U
M;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R("+9OMBQV8C9AMBOV8<@V*?8L=BS
MV*?9A"#8M-BOV8<@V8;9A=N,XH",V*K9B-BGV8;8KR#8K=F!V+@@V+39B-BO
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0V(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HU-@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,3$U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3D*
M;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R("+8J-F$V8C:J2!W96%T:&5R+F-O;2#9@MBGV*C9A"#8K]BS
MV*K8L=BS(-F&VXS8L]BJ(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y
M(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(MBTV*?8KMF'(-BJV84@)R5S
M)R#;C-BGV8'8JB#9AMBTV*\B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA
M8FQE+B(*;7-G<W1R("+:K]BRVXS9AMF'XH",V*?B@(SB@(S;C-N,(-BOV+$@
MV*_8L]BJV+'8LR#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C,T,@IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H
M870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(MBHV*[8M-N,
M(-JIV8<@V*C8JMF(V*?9AMBO(-BHV+'8KMBW(-F&V878I]N,V+0@V*_8I]BO
MV8<@V+39B-BO(-F%V8C8K-F(V*\@V8;;C-BSV*HB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO
M=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT
M97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"B+9AMF(VXS8L]F'XH",V8?8
MI]N,(-BRVXS8I]BOVXP@V*_8L2#8I]N,V88@V8';C-F$V*\@V8+8L=BGV+$@
MV*_8I]BQV*\N(-BTV878IR`E<R#9AMF(VXS8L]F'(-F(V*?8L=BO(-JIV+'8
MK]F'XH",V*?B@(S;C-BO(-BOV+$@V*W8I]F$VXP@VJG9AR`B"B+8M-F%V*<@
MV*C8I]N,V*\@VJG9A=BJV+$@V*?8LB`E<R#9AMF(VXS8L]F'(-F(V*?8L=BO
M(-JIV8;;C-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E
M(#,I("`C+2,M(RTC+2,*(R`*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R
M+G!H<#HW,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM
M<V=S='(@(MF%V+3:J=F$VXP@V*_8L2#8I]BVV*?9@=F'(-JIV+'8K]F&("<E
M<R<@V*C9AR#8L]BGV878I]F&V8<@V+'8KB#8K]BGV*_9AR#8I]BSV*HZ("5S
M(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M
M(RTC+2,*(R`*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A
M=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@
M(MF%V+3:J=F$VXP@V*_8L2#9OMBGVJD@VJG8L=BOV88@V*_8I]BOV8?9E"#:
MJ=BGV+'8J-BQ("<E<R<@V*?8LB#8L]BGV878I]F&V8<@V+'8KB#8K]BGV*_9
MAR#8I]BSV*HZ("(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D
M92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R
M96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`BV878
MM-JIV83;C"#8K]BQ(-BMV+#9@2`G)7,G(-BGV+(@V+/8I]F%V*?9AMF'(-BQ
MV*X@V*_8I]BOV8<@V*?8L]BJ.B`B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU
M;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]U<V5R+G!H
M<#HQ-3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R("+9A=BTVJG9
MA-N,(-BOV+$@V*C8L=F(V++8L=BSV*?9AMN,("<E<R<@V+'8KB#8K]BGV*_9
MAR#8I]BSV*HZ("5S(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP
M:'`Z.#@T"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB
M"FUS9W-T<B`BV878M-JIV83;C"#8K]BQ(-BGV+'8L]BGV80@V;[8L=F(V8;8
MK]F'(-BQV*X@V*_8I]BOV8<@V*?8L]BJ.B`E<R#8I]BQV+/8I]F$(-F&V+38
MKR(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M
M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B
M"B+9A=BTVJG9A-N,(-BOV+$@V*?8L=BSV*?9A"#9OMBQV8C9AMBOV8<@V+'8
MKB#8K]BGV*_9AR#8I]BSV*HZ(-BGV8;8K]BGV++9AR`E<R#8J-N,V+38JMBQ
M(-BGV+(@V*W8KR#9A=BLV*?8LB#8J-F(V*_9AR#8I]BSV*H@*"`E9"`B"B+8
MJ-BGVXS8JBDN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z
M.#DQ"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T
M:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(B(*(MF%V+3:J=F$VXP@V*_8L2#8
MI]BQV+/8I]F$(-F^V+'9B-F&V*_9AR#9B-BLV8C8KR#8K]BGV+38JMF'(-BG
MV+/8JCH@("5S(-BHV8<@V+79B-BQV*H@V*K:J=F'XH",V*?B@(S;C-N,(-BG
MV+'8L]BGV80@V+38K]F'(-BGV+/8JB`B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R("+8
MKMBWV*?;C-N,(-BOV+$@V8;9A=BGVXS8M"#8I]N,V88@V*C8KMBT(-F^VXS8
MNMBGV84@V+'8KB#8K]BGV*_9AR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(MBN
MV+?8I]N,VXP@V*_8L2#8K]BQV8C9AN*`C-BHV+'8KR#:J=BQV*_9AB#8K]BG
MV*_9AR#8JMF%V*?8LR#8L=BN(-BOV*?8K]F'(-BGV+/8JB(*"B,@"B,Z(&9R
M86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S
M='(@(MBNV+?8I]N,VXP@V*_8L2#8K]BQV8C9AN*`C-BHV+'8KR#:J=BQV*_9
MAB#8K]BGV*_9A]F4(-BJV8+9B-N,V84@V+'8KB#8K]BGV*_9AR#8I]BSV*HB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@P"FUS9VED("(B"B)4:&5R
M92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R
M:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T
M<B`B(@HBV*[8M]BGVXS;C"#8K]BQ(-F^VXS:J=BQV*C9AMBOVXP@V8'8L=F%
M(-BQV*X@V*_8I]BOV8<@V*?8L]BJ+B#8M-BGVXS8KR#9@=N,V838KR#9A=F(
MV+'8KR#9AMN,V*?8LMN,(-BQV*<@V*S8IR#8I]F&V*_8I]BNV*K9A^*`C-BG
MXH",VXS8KR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R
M9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@
M4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HBV*[8M]BG
MVXS;C"#8K]BQ(-BGV*S8L=BG(-JIV+'8K]F&(-BYV879A-N,V*?8JB#9A=BT
MV*[8M2#8M-BOV8?9E"#:J=BJV*?8J-J&V8<@V*+8K]BQV+,@V+'8KB#8K]BG
MV*_9AR#8I]BSV*HN(-F$V+?9@=BGV8L@V*_9B-BHV*?8L=F'(-BSV+G;C"`B
M"B+:J=F&VXS8KR(*"B,@"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R
M;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A
M9V%I;B!L871E<BXB"FUS9W-T<B`BV*[8M]BGVXS;C"#8K]BQ(-BHV+'9B-BR
MV+'8L]BGV8;;C"#8K-BRV*;;C-BGV*H@V*K9A=BGV+,@V+'8KB#8K]BGV*_9
MAR#8I]BSV*HN(-F$V+?9@=BGV8L@V*_9B-BHV*?8L=F'(-BSV+G;C"#:J=F&
MVXS8KR(*"B,@"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I
M;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA
M=&5R+B(*;7-G<W1R("+8KMBWV*?;C-N,(-BOV+$@V*C8L=F(V++8L=BSV*?9
MAMN,(-F!V8?8L=BSV*H@V*K9B-BRVXS8N=N,(-BQV*X@V*_8I]BOV8<@V*?8
ML]BJ+B#9A-BWV8'8I]F+(-BOV8C8J-BGV+'9AR#8L]BYVXP@VJG9AMN,V*\B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*
M;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R
M:6YG(&9O;&1E<G,N(@IM<V=S='(@(B#:J=BGV+'8L]BGV+(@24U!4-F^V8C8
MM-F'XH",V8?8I]N,(-F%V+38JMBQVJD@V+'8IR#9OMBTV*K;C-BHV*?9AMN,
M(-F&V87;C.*`C-JIV8;8KR(*"B,@"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R
M('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(B#8J-F'(-F&
MV+C8L2#9AMF%VXSB@(S8L=BSV*\@VJG9AR#8HMBQV+3;C-F((')A<B#9A=BY
MV*K8J-BQVXP@V*C8I]BTV*\B"@HC(`HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R("(@V*C9AR#9AMBX
MV+$@V8;9A=N,XH",V+'8L]BO(-JIV8<@V;[8L=F(V8;8K]F'('II<"#9A=BY
MV*K8J-BQVXP@V*C8I]BTV*\B"@HC(`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,30U"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V
M86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`BV*C9AR#9AMBXV+$@V8;9A=N,
MXH",V+'8L]BO(-JIV8<@V+39A=BGV+'9AR#:J=BGV+'8JB#9A=BYV*K8J-BQ
MVXP@V*C8I]BTV*\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@
M*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE
M($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO
M=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z
M+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T
M<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@
M86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T
M:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N
M92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@
M(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$P-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3`X-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(U-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`U(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S.3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,34U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#,Y"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-3@@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C`P-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(Y(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-S@*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$T.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3`@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C0U-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4W
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,C@*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$S-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`V
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,30@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S@R,@IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E
M9"XB"FUS9W-T<B`BV*?;C-F&(-F!VXS9A-BO(-F%V8C8L=BO(-F&VXS8I]BR
M(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C4*;7-G
M:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS
M9W-T<B`BV*?;C-F&(-F!VXS9A-BO(-F%V87:J=F&(-BGV+/8JB#8M-BGV879
MA"#8I]BYV*_8I]BO(-BUV*W;C-BM(-BHV*?8M-BO(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C0Q.`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL
M>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`BV*?;
MC-F&(-F!VXS9A-BO(-F%V87:J=F&(-BGV+/8JB#8M-BGV879A"#8I]BYV*_8
MI]BO(-F((-F(VXS8L=JOV8C9A"#8J-BGV+38KR(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(MBGVXS9AB#9@=N,V838
MKR#9A=F%VJG9AB#8I]BSV*H@V+38I]F%V80@V879@MBGV*_;C-BQ(-F'V+38
MJB#9A]BTV*K;C"#8J-BGV+38KR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R
M('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*
M(MBGVXS9AB#9@=N,V838KR#8J-BGVXS8KR#8K=BGV8C;C"#:J=BGV878IR#9
MB"#;C-BG(-F!V8?8L=BSV*K;C"#8I]BR(-BGV+G8K]BGV*\@V+78K=N,V*T@
MV*S8K]BG(-BTV*_9AR#8J-BG(-F&V8C;C-BSV8<@V*[8I]F$VXP@V*C8I]BT
MV*\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY.#D*;7-G:60@(E1H
M:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`BV*?;
MC-F&(-F!VXS9A-BO(-BHV*?;C-BO(-N,VJD@V+G8K]BO(-F%V+G8JMBHV+$@
MV*C8I]BTV*\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V"FUS
M9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@
M:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A
M9B<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4V
M,0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D
M+B(*;7-G<W1R("(B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R
M9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI
M;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R
M("+8I]N,V88@)7,@V87;C.*`C-BHV*?8M-BO(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI
M<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O
M8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U
M;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@
M;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C4Y,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S
M('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y
M;W5R(&]W;BXB"FUS9W-T<B`B(@HBV*?;C-F&(-F^VXS8NMBGV84@V*C8IR#9
MA=BLV879B-BYV8<@VJG8I]BQV*?:J=BJV+$@)7,@V8;9B-BTV*K9AR#8M-BO
MV8<@V*?8L]BJ(-JIV8<@V*C8IR#9A=BLV879B-BYV8<@VJG8I]BQV*?:J=BJ
MV+$@V+39A=BG(-F%V*K9@=BGV8C8JB`B"B+8I]BSV*HB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@
M;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(MBGVXS9AB#8N=BOV*\@
MV*W8K]BGV8+9A"#8J-BGVXS8KR#;C-JI(-BHV*?8M-BO(@H*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES
M('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB
M"FUS9W-T<B`BV*?;C-F&(-JIV*?8L=BSV*?8LB#9OMBQV8C9AMBOV8?B@(S9
MA]BGVXP@>FEP(-F((&=Z:7`@V+'8IR#8J-BGV+(@V8;9A=N,XH",VJG9AMBO
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ.#D*
M;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB
M"FUS9W-T<B`BV*?;C-F&(-BSV*?9A=BGV8;9AR#8K]BQ(-BMV*?9A"#8K=BG
MV+;8L2#8NMN,V+$@V8'8N=BGV80@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B
M92!A(&YU;6)E<BXB"FUS9W-T<B`BV*?;C-F&(-F%V8+8K]BGV+$@V*C8I]N,
MV*\@V+G8K]BO(-BHV*?8M-BO(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R
M<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL
M960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R("+8I]N,V88@V;[9
MAMBLV+'9AR#8J-BGVXS8KR#8I]BR(-F^V8;8K-BQV8?9E"#:K]BRVXS9AMF'
MXH",XH",V8?8IR#9@=BQV*?8KMF(V*?9AMN,(-BTV8C8KR(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4:'5N
M9&5R(@IM<V=S='(@(MBQV+G8KR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR,S0*;7-G:60@(E1I8VME=',B"FUS9W-T<B`BV*C9A-N,V+?9A]BG
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R."!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(E1I;64B"FUS9W-T<B`BV++9
MA=BGV88B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@V"FUS9VED
M(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(MBQV*_;C-BGV*C;C"#8LMF%V*?9
MAB(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M
M870B"FUS9W-T<B`BV8+8I]F$V*@@V++9A=BGV88B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-3,Y"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G
M<W1R("(@V*?9AMBJV*[8I]BH(-BRV878I]F&("(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*
M;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(MBYV8;9B-BGV88B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS
M9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(MBYV8;9B-BGV88@*-BQ
MV*?9A]F&V878I]N,(-BBV8;;C"DZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`BV*C9
MAR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV
M-30*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D
M;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB
M=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*(MBHV+'8I]N,(-BGV8;8JMBN
MV*?8J"#:AMF&V*\@V8';C-F$V*_8C"#8K]JIV879AR!#=')L(-BQV8C;C"`H
M4$,I(-N,V*<@0V]M;6%N9"#8L=F(VXP@*$UA8RD@V+'8IR#8K]BQ(-F%V*_8
MJB#:J=F$VXS:J2`B"B+:J=BQV*_9AB#9AMJOV8?8K]BGV+';C-BO(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B5&]D87DB
M"FUS9W-T<B`BV*?9A=BQV8C8LB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"B,L(&9U>GIY"FUS9VED(")4
M;V=O(@IM<V=S='(@(MBHV8<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME
M;&%U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS,3,*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(MF!V+'8K]BG(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,`HC+"!F=7IZ>0IM<V=I9"`B5&]N9V$B"FUS9W-T<B`BV*?9
MA=BQV8C8LB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@(MBHV*?9A-BG(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM
M<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("+:AMBGV+':AMF(V*@@
MV*C8I]F$V*<@*-BHV*?9A-BG*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV,PIM<V=I9"`B5')A;G-L871I;VYS(@IM<V=S='(@(MBJV+'8K-F%V8?B
M@(S9A]BG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O
M8F%G;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-SDP"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(MBOV+'8L]BJ(-F(
M(-N,V*<@V8;8I]BOV+'8L]BJ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`BV+/9AR#8
MM-F&V*C9AR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(")4=7)K:7-H("A)
M4T\M.#@U.2TY*2(*;7-G<W1R(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-C0*;7-G:60@(E1Y
M<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R("+8I]F&V*K8KMBGV*@@V*[9B-BO
M(-BQV*<@V*K8I]N,V;X@VJG9AMN,V*\Z(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(V.0IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@
M(MBTV*?8KMBU(%4N5BX@.B`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS
M9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U
M<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"FUS
M9VED(")54DPZ(@IM<V=S='(@(E523#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED
M(")59V%N9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@HC+"!F=7IZ>0IM
M<V=I9"`B56MR86EN92(*;7-G<W1R("+8LMN,V+'8KMBWXH",V*_8I]BQ(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$R"FUS9VED(")5;F%B
M;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(MBGV87:J=BG
MV88@V*_8L]BJV+'8L]N,(-BHV8<@V+38I]BNV8<@5D93(-F&VXS8L]BJ(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5
M;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N
M:6YG('5P+B(*;7-G<W1R("+8I]F%VJG8I]F&(-BGV+;8I]F!V8<@VJG8L=BO
MV88@V*?8M]F$V*?8N=BGV*H@V*?8MMBGV8';C"#:J=BGV+'8J-BQ(-BHV8<@
MV8?9AMJOV*?9A2#8J]BHV*H@V8;8I]F%(-F&VXS8L]BJ(@H*(R`C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS.#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F%V*S9B-BR
MV8?8IR#8L=BG(-BHV+'8I]N,(-F^V+'9B-F&V*_9AR!<(B5S7"(@V*K8NMN,
MVXS8L2#8K]BGV*\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS
M.#4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&
M4R!F:6QE("5S+R5S+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9A=BL
MV8C8LMF'V*<@V+'8IR#8J-BQV*?;C"#9OMBQV8C9AMBOV8<@)7,O)7,@5D93
M("#8JMBZVXS;C-BQ(-BOV*?8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M
M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z-S4U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BO
MV+$@)7,@V*K8NMN,VXS8L2#8K]BGV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C(S,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S
M='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@7"(E<UPB
M(-BQV*<@V*C8I]BR(-F&V879B-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z-C@X(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M,3`Q-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#,T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL
M92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BG
MV88@V;[8L=F(V8;8K]F'(%9&4R`E<R\E<R#8L=BG(-BJV+K;C-N,V+$@V8;8
MI]F%(-BOV*?8KR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HT
M,S4*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM
M<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BHV8<@VJG8I]BQV+/8I]BR(%-1
M3-F%V*K8M=F$(-BTV*\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C@S.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S
M='(@(MF&V87;C.*`C-BJV8C8I]F&(-BHV*<@4U-,(-F%V*K8M=F$(-BTV*\B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,C4@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"FUS
M9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`BV8;9A=N,
MXH",V*K9B-BGV88@V*?8LB#9OMBQV8C9AMBOV8<@5D93(-BQV8C9AMF(V+38
MJB#8JMF'VXS9AR#9AMF%V8C8KR(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,S8U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A
M=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(MF&V87;C.*`C-BJ
MV8C8I]F&(-BTV*?8KMF'(%9&4R!<(B5S7"(@V+'8IR#8I]N,V*S8I]BO(-F&
MV879B-BO(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S4T(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C(U-@IM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8
MM-BGV*[9AR!61E,@V+'8IR#8I]N,V*S8I]BO(-F&V879B-BO(@H*(R`C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R-`IM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`BV8;9A=N,XH",V*K9
MB-BGV88@V;[8L=F(V8;8K]F'(%9&4R#8L=BG(-BGVXS8K-BGV*\@V8;9A=F(
MV*\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(X-@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9F]L
M9&5R(%PB)7-<(BXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V;[8L=F(
MV8;8K]F'(%9&4R!<(B5S7"(@V+'8IR#8JMBZVXS;C-BQ(-F&V*?9A2#8K]BG
MV*\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-C4*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(MF&
MV87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR#8KMBGV83;C"!61E,@(-BG
MVXS8K-BGV*\@V8;9A=F(V*\B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O=&%R+G!H<#HW-@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A
M=&$N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BOV*?8K]F'(-BQV*<@
MV*C8I]BR(-JIV+'8KR`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C(R-"!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Y.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C
M=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(MBMV+#9@2!<(B5S7"(@V879
MA=JIV88@V8;;C-BSV*K8C"#8M-BGV*[9AR#8KMBGV83;C"#9AMN,V+/8JB(*
M"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M
M(RTC"B,@"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L
M971E+G!H<#HT-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(%PB
M)7-<(B#8L=BG(-BMV+#9@2#:J=BQV*\Z("5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S$Q(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N
M;W0@96UP='DB"FUS9W-T<B`BV*W8L-F!("5S(-F%V87:J=F&(-F&VXS8L]BJ
MV(P@V+38I]BNV8<@V*[8I]F$VXP@V8;;C-BSV*HB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0X(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I
M<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BG
MV88@V+38I]BNV8<@5D93(-BQV*<@V*C9AR#8M=F(V+'8JB#8JMF((-BOV+$@
MV*K9B"#8K=BPV8$@V8;9A=F(V*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU
M;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HS,S<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,T-`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@9&ER96-T;W)Y+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8M-BG
MV*[9AR!61E,@V+'8IR#8K=BPV8$@V8;9A=F(V*\B"@HC(",M(RTC+2,M(R`@
M8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0Q-R!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C0R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(
MV*?9AB#8M-BGV*[9AR!61E,@V+'8IR#8K=BPV8$@V8;9A=F(V*\Z("5S+B(*
M"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M
M(RTC"B,@"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C`W"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@
M5D93(%PB)7-<(B#8L=BG(-BMV+#9@2#9AMF%V8C8KR(*"B,@(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,P,R!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C(X.`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,38W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#`*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X-R!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,S@S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS.3$*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM
M<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@V+'8
MIR#8K=BPV8$@V8;9A=F(V*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C(T-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`BV8;9
MA=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R!<(B5S7"(@V+'8IR#8
MK=BPV8$@V8;9A=F(V*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C0P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(MF&V87;C.*`C-BJ
MV8C8I]F&(%9&4R#8L=BG(-BHV8<@V+79B-BQV*H@V*K9B"#8K]BQ(-BJV8@@
MV*W8L-F!(-F&V879B-BO.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C@P,PIM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT
M(&1I<F5C=&]R>2XB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V+38I]BN
MV8?9E"#9@=BYV83;C"#8L=BG(-BJV+38KMN,V+4@V*_8I]BO(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#,*;7-G:60@(E5N86)L
M92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`BV8;9
MA=N,XH",V*K9B-BGV88@V*S8LMBFVXS8I]BJ(-JOV8C8I]F'VXP@V+'8IR#8
MI]BSV*K8KMBQV*?8K"#9AMF%V8C8KR(*"B,Z(&9R86UE=V]R:R].971?24U3
M4"])35-0+G!H<#HT-3$@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T:"YP
M:'`Z,3$X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H
M92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9
MAB#8JMBYV+';C-F!("5S("#8L=BG(-BHV*?8L2#9AMF%V8C8KR(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C$V-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<Q"FUS
M9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`BV8;9A=N,
MXH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R#8L=BG(-BGV8;8JMF"V*?9
MA"#8K]BGV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@
M,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.CDS(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`R"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-C0X(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9OMBQ
MV8C9AMBOV8<@5D93(%PB)7-<(B#8L=BG(-BHV*?8LB#9AMF%V8C8KR(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W-R!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ,S,*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M(&9O<B!W<FET:6YG+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9OMBQ
MV8C9AMBOV8<@5D93(-BQV*<@V*C8L=BGVXP@V8;9B-BTV*K9AB#8J-BGV+(@
MVJG8L=BO(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#`@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HW,@IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93
M(&9I;&4N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9
MAR!61E,@V+'8IR#8J-BGV+(@V8;9A=F(V*\B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E
M;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8
MI]F&(-BBV+'8M-N,V8@@V8'8M-BQV*_9AR#8L=BG(-BHV*?8LB#:J=BQV*\B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#,U"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I
M+B(*;7-G<W1R("(@V8;9A=N,XH",V*K9B-BGV88@V*_8L2#9OMBQV8C9AMBO
MV8<@5D93(-F&V8C8M-BJ+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX
M-C8*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG
M971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(B#9AMF%VXSB@(S8JMF(
MV*?9AB#8K]BQ(-F^V+'9B-F&V*_9AR!61E,@V8;9B-BTV*HN(@H*(SH@9G)A
M;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP
M.C,X"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS
M9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R#8L=BG
M(-BJV+K;C-N,V+$@V8;8I]F%(-BOV*?8KR(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C8V.0IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F
M<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8
MM-BGV*[9AR!V9G-R;V]T(-BQV*<@V*[9B-BGV8;8KR(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,3$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@
M86QR96%D>2!E>&ES=',B"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@)7,@
MV+'8IR#8J-F'("5S("#8JMBZVXS;C-BQ(-F&V*?9A2#8K]BGV*\Z(-F^V8C8
MM-F'(-F%V8+8M=BO(-BGV+(@V8+8J-F$(-F%V8C8K-F(V*\@V*?8L]BJ(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Y,PIM<V=I9"`B
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("+9AMF%
MVXSB@(S8JMF(V*?9AB#8M-BGV*[9AR!61E,@V+'8IR#8JMBZVXS;C-BQ(-F&
MV*?9A2#8K]BGV*\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDZ("5S+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8M-BG
MV*[9AR!61E,@V+'8IR#8JMBZVXS;C-BQ(-F&V*?9A2#8K]BGV*\Z("5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C8W(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+9AMF%VXSB
M@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@5D93(%PB)7-<(B#8L=BG(-BJV+K;
MC-N,V+$@V8;8I]F%(-BOV*?8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M
M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C8Q,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4@)7,O)7,N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^V+'9
MB-F&V*_9AR!61E,@)7,O)7,@V+'8IR#8JMBZVXS;C-BQ(-F&V*?9A2#8K]BG
MV*\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R,R!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C(X-0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R("+9AMF%
MVXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@5D93(-BQV*<@V*K8NMN,VXS8
ML2#9AMBGV84@V*_8I]BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED(")5;F%B;&4@
M=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@
M)VUK:7-O9G,G(-BQV*<@V*?8K-BQV*<@V8;9A=F(V*\B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B
M;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R("+9
MAMF%VXSB@(S8JMF(V*?9AB#8I]N,V88@V+/9AMBO(%=O<F0@V+'8IR#8JMBQ
MV*S9A=F'(-F&V879B-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HQ-#D@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-3(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B(-F&V87;C.*`C-BJV8C8I]F&(-BOV+$@V;[8L=F(
MV8;8K]F'(%PB)7-<(B!61E,@(-F&V8C8M-BJ(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R("(@V8;9A=N,XH",V*K9
MB-BGV88@V*_8L2#9OMBQV8C9AMBOV8<@5D93(-F&V8C8M-BJ+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HQ-#,*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D
M871A+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8K]BQ(-F^V+'9B-F&
MV*_9A]F4(-BOV*?8K]F'(%9&4R#9AMF(V+38JB(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HX-#$*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!W<FET
M92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS9W-T<B`B
M(-F&V87;C.*`C-BJV8C8I]F&(-BOV+$@V;[8L=F(V8;8K]F'(%9&4R#9AMF(
MV+38JBXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`BV++;C-BQV*[8M^*`
MC-BOV*?8L2(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@
M(E5N9&\@0VAA;F=E<R(*;7-G<W1R("+9B-BGVJ_8L=BOV*?9AMBOV88@V*K8
MNMN,VXS8L=BGV*HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*
M;7-G<W1R("+9B-BGVJ_8L=BOV*?9AMBOV88@V*+8KMBQVXS9AB#8N=F%V80@
MV+39A=BG(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,C(S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,Y,`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O
M;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`BV;[8I]BSV*X@V+K;C-BQ(-F%V8;8
MJMBXV+'9AR#8I]BR(-JIV*?8L=BSV*?8LB#8J-BQ(-BQV8C;C"#8I]BJV+78
MI]F$.B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M-#$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-`IM
M<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM
M<V=S='(@(MF^V*?8L]BN(-BZVXS8L2#9A=F&V*K8N-BQV8<@V*?8LB#:J=BG
MV+'8L]BGV+(@V*C9ASHB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T
M96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R("+8
MNMN,V+$@V*W9B-BRV8<B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM
M<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(E5N:6-O9&4@*%541BTX
M*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T
M871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV.2!L:6(O0FQO8VLO;65T87(N
M<&AP.C<Q"FUS9VED(")5;FET<R(*;7-G<W1R("+9B-BGV*W8K]F'V*<B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S
M='(@(MBOV*?8K]F'(-F&V*?8M-F&V*?8KMBJV8<B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N
M:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)
M1"DN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-3D*(RP@9G5Z>GD*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O=FED
M960N(@IM<V=S='(@(MF'VXS:AB#9A=JIV*?9AMN,(-BJV8;8N-N,V84@V8;8
MM-BOV8<B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O
M<F0N(@IM<V=S='(@(MF&V*?9A2#:J=BGV+'8J-BQ(-F((-N,V*<@V*?8L]F%
M(-BQV878LB#9AMBGV+39AMBGV*[8JMF'(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI
M;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R("+9@MBWV+D@V;[;C-F(
MV8;8KR#8N=F&V+78L2#9@=BYV83;C"(*"B,Z(&9R86UE=V]R:R])9&5N=&ET
M>2])9&5N=&ET>2YP:'`Z,CDV"FUS9VED(")5;FYA;65D(@IM<V=S='(@(MBH
MVXP@V8;8I]F%(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N
M;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R
M("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H
M;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@
M:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D
M+B(*;7-G<W1R("(B"B+8K]BSV*H@XH",V8;9B-N,V+/9A]BGVXP@V*C8K]F(
MV88@V*?9A=BJVXS8I]BR(-BHV8<@V*_9A-N,V80@V*?9A=F&VXS8JMN,(-F&
MV87;C.*`C-BJV8C8I]F&V8;8KR#8I]BR(-BWV+';C-F"(-BHV+'9AMBGV879
MAR#9AMF(VXS8L]N,(-BHV+';C-BOV8<O(@HBV+'9B-F&V8C8M-BJ(-JOV+'9
M@=BJV8<OVH;8L]BHVXS8K]F'(-BTV8C9AMBO+B#:J=F$VXS8KR#8JMBCVXS;
MC-BO(-BQV*<@V8'8M-BGV+$@V*_9A]N,V*\@V*K8IR#9A=BJV88@V8'9AMN,
MXH",V*?B@(S;C-N,(-BQV*<@V*_8L2`B"B)M;WII;&QA+F]R9R#8J-BG(-BY
MV8;9B-BGV88@VH;:K]F(V8;:K]N,(-BOV+/8JMBQV+/;C"#;C-JI(-BOV+/8
MJB#B@(S9AMF(VXS8LR#8J-F'(-BJV*[8JMF'V90@V+'8L]F%(-BQV*<@V878
MM-BGV8?8K]F'(-JIV8;;C-BO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B
M"FUS9W-T<B`BV+'9AMJO(-BJV8;8N-N,V84@V8;8M-BOV8<B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.CDR-@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.CDS,@IM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N
M(@IM<V=S='(@(MBHV+/8MR#8J-BOV8C9AB#9OMBTV*K;C-BHV*?9AMN,(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R
M("+8J-BQV8C8LMBQV+/8I]F&VXPB"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU
M;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P
M9&%T92`E<R(*;7-G<W1R("+8J-BQV8C8LMBQV+/8I]F&VXP@)7,B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A
M=&4@=7-E<B(*;7-G<W1R("+8J-BQV8C8LMBQV+/8I]F&VXP@VJG8I]BQV*C8
ML2(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC
M+2,M(RTC"B,@"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E<FUS
M+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L
M('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R(")<
M(B5S7"(@V*C8L=F(V++8L=BSV*?9AMN,(-BTV*\B"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E
M9"XB"FUS9W-T<B`BV*_8L]BJXH",(-F&V8C;C-BS(-BHV8?;C-F&V8?B@(S8
ML]BGV++;C"#8K=BPV8$@V+38KR(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-S@@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y
M.0IM<V=I9"`B57!L;V%D(@IM<V=S='(@(MBGV+'8L]BGV80@VJG8L=BOV88B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO861E
M9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB
M"FUS9W-T<B`BV*K9A=BGV84@V;[8L=F(V8;8K]F'XH",XH",V8?8I]N,(-BJ
MV8;8N-N,V84@V*C8L=F&V*?9A=F'XH",V8?8I]N,(-JIV*?8L=BHV+'8K]N,
M(-BHV8<@VJG8I]BQV+/8I]BR(-BGV+'8L]BGV80@V+38KR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*
M;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`BV*W8L=F(V8$@
MV*C8LMBQVJ\@V838I]BJVXS9AB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O
M;6%N(&YU;6)E<G,B"FUS9W-T<B`BV*?8N=BOV*?8KR#;C-F(V8;8I]F&VXP@
MV*C8LMBQVJ\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G
M97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E
M<R(*;7-G<W1R("(@V*?8L]BJV8'8I]BOV8<@V8'8N=F$VXPZ("5S(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*
M;7-G:60@(E5S92!34TPB"FUS9W-T<B`BV*?8L]BJV8'8I]BOV8<@V*?8LB!3
M4TPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED(")5<V4@
M:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R
M+B(*;7-G<W1R("+8I]JOV+$@V8;8I]F%+]BGV+/9A2#8L=F%V+(@V*C8L=BG
MVXP@VJG8I]BQV+/8I]BR($E-4U`@V878JMF!V*?9B-BJ(-BGV+/8JMB,(-BG
MV+/8JMF!V*?8K]F'(-JIV8;;C-BO(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHR,0HC+"!F=7IZ>0IM<V=I9"`B57-E<B(*;7-G<W1R
M("+:J=BGV+'8J-BQV*?9AB(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]2
M96=I<W1R>2YP:'`Z-S(S"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@
M:7,@;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R("+:J=BGV+'8J-BQ
M("5S("#8J-BQV*?;C"`E<R#8I]BMV+'8I]BR(-F'V8C;C-F1V*H@V8;8M-BO
MV8<@V*?8L]BJ(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R
M($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(MBSV+'9OMBQV+/8JMN,(-JIV*?8
ML=BHV+$B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,0IM
M<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(MJOV++;C-F&V8?B@(S9A]BG
MVXP@VJG8I]BQV*C8L2(*"B,Z('-I9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@
M4F5G:7-T<F%T:6]N(@IM<V=S='(@(MBKV*C8JB#9AMBGV84@VJG8I]BQV*C8
ML2(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N
M(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(MBK
MV*C8JB#:J=BGV+'8J-BQ(-BHV+'8I]N,(-BGVXS9AB#9OMBGVXS:K]BGV8<@
MV+K;C-BQ(-F!V+G8I]F$(-BTV*_9AR#8I]BSV*HB"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD
M(@IM<V=S='(@(MBMV+/8I]BH(-JIV*?8L=BHV+$@V;[;C-BOV*<@V8;8M-BO
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T
M<B`BV8;8I]F%(-JIV*?8L=BHV+$B"@HC(`HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z,3(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5<V5R;F%M92!<(B5S7"(@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(MF&
MV*?9A2#:J=BGV+'8J-BQ("<E<R<@V*?8LB#9@MBHV80@V879B-BLV8C8KR#8
MI]BSV*HB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G
M:60@(E5S97)N86UE.B(*;7-G<W1R("+9AMBGV84@VJG8I]BQV*C8L3HB"@HC
M.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5<V5R;F%M
M93H@(@IM<V=S='(@(MF&V*?9A2#:J=BGV+'8J-BQ.B`B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@
M<WES=&5M.B(*;7-G<W1R("+:J=BGV+'8J-BQV*?9AB#8L]BGV878I]F&V8<Z
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-C,@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C4U"FUS9VED(")61E,@9&ER96-T;W)Y(&1O
M97,@;F]T(&5X:7-T+B(*;7-G<W1R("+8M-BGV*[9AR!61E,@V8C8K-F(V*\@
MV8;8K]BGV+'8KR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3@*
M;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(MBJV+G8M]N,V838I]BJ(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED(")686QI9"!L;V-A
M=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(MF%V8C9@MBYVXS8JMF'
MV*?;C"#9A=BYV*K8J-BQ(-N,V*?9@=BJV8<@V+38K]F'(-BYV*C8I]BQV*K9
MAMBO(-BGV+(Z(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV,S@*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(MBGV+G8JMBHV*?8L2(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3DW"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS
M9W-T<B`BV879@MBOV*?8L2#8J-F'(-BOV8+;C-F"V8<@V*?8LB#8K=BGV838
MIR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@U-B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E
M(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("+9
MA=F"V*_8I]BQ(-BGV+(@V*C;C-BTVXS9AMF'(-BWV8C9A"#9A=BLV*?8LB`E
M<R#8J-N,V+38JMBQ(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(R-#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$V(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Y,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T
M+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(MF%V8+8I]BOVXS8L2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#D@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$X-@IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M
M(@IM<V=S='(@(MF%V8+8I]BOVXS8L2#8J-BQV*?;C"#8I]F&V*K8KMBGV*@@
MV*?8LB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-`IM<V=I9"`B
M5F%R:6%B;&4B"FUS9W-T<B`BV878JMBZVXS;C-BQ(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@
M9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@
M=VET:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HW,#`*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`BV8;8L]BNV8<B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(V"FUS9VED(")697)S
M:6]N($-O;G1R;VPB"FUS9W-T<B`BVJG9AMBJV+'9A"#9AMBSV*[9AR(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(MBJV+'8I]BR(-BY
MV879B-BOVXPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(MF!
MV*?8M=F$V8?B@(S:K]BPV*?8L=N,(-BYV879B-BOVXPB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T
M:6-A;#HB"FUS9W-T<B`BV+G9A=F(V*_;C#HB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B5F5R>2!(:6=H(@IM
M<V=S='(@(MBNVXS9A-N,(-BHV*?9A-BG(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@HC+"!F
M=7IZ>0IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`BV8;8I]F%(-F^V+'9B-F&
MV*_9AR(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")6:65T
M;F%M97-E("A625-#24DI(@IM<V=S='(@(E9I971N86UE<V4@*%9)4T-)22DB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HY-C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R("+9AMF%V*?;C"`E
M<R(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@
M97AT97)N86P@=V5B('!A9V4B"FUS9W-T<B`BV8;9A=BGVXP@VXS:J2#8M=F!
MV*W9AR#9B-BH(-BNV*?8L=BLVXPB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HX,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A
M<R`E<R(*;7-G<W1R("(@V8;9A=BG(-BHV8<@V+G9AMF(V*?9AB`E<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S
M+"!5+E,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Y
M"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(MF"V*?8J-F$VXS8JB#9A=BT
MV*?9A]BOV8<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8S
M"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`BV8+8I]BHV83;C-BJ(-F%
MV+38I]F'V*_9ASH@(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F
M;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I
M82!33510(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!
M4DXB"FUS9W-T<B`B(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO
M<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@
M4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(MBGV*[8M]BGV+$A
M(2$@V*_8L]BJ(.*`C-F&V8C;C-BS(-BQV*<@V*C8M]F(V+$@V*_8L]BJVXP@
MV*?8LB`E<R#8K=BPV8$@VJG9AMN,V*\B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T
M=6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R("+8I]BNV+?8I]BQ
M.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C4X"FUS9VED(")792(*;7-G<W1R("+:AMF'V*?8L=BTV8;8J-F'(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R
M($9O<F5C87-T(@IM<V=S='(@(MF^VXS8M.*`C-BHVXS9AMN,(-F'V8C8IR(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,C<*;7-G:60@(E=E
M871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R("+8K]BGV*_9AR#8HMBH
M(-F((-F'V8C8I]N,VXP@V8'8L=BGV8?9A2#8M-BOV8<@V*C9AR#9B-BSVXS9
MA-F'(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR"FUS9VED(")7
M96%T:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O;2(*"B,Z(&QI8B]";&]C
M:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`BV8C8J"(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S<*;7-G:60@(E=E8B!3:71E
M(@IM<V=S='(@(MF(V*CB@(S:K]BGV8<B"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T
M<B`BV8?9@=BJVJ_;C"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP
M.C(X"FUS9VED(")796QC;VUE(@IM<V=S='(@(MBNV8C8M"#8HMF%V*_;C-BO
M(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M
M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C
M+2,M(RTC+2,*(R`*(R`C+2,M(RTC+2,@(&9A7TE2+G!O("A(;W)D92`S*2`@
M(RTC+2,M(RTC"B,@"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(MBHV8<@)7,@V*[9B-BT(-BB
MV878K]N,V*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@
M,RD@(",M(RTC+2,M(PHC(`HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H
M<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B)7/8C"#8KMF(V+0@V*+9
MA=BOVXS8KR(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")7
M97-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R(")797-T97)N("A)4T\M.#@U
M.2TQ*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED(")797-T
M97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B5V5S=&5R;B`H25-/+3@X-3DM
M,34I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S
M='(@(B(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@
M(RTC+2,M(RTC"B,@"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@
M9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`BVH;9AR#8J-BQV8;8I]F%
MV8?9E"#:J=BGV+'8J-BQV*_;C"#8L=BG("5S(-BHV*?;C-BO(-BHV+G8KR#8
MI]BR(-F(V+'9B-BO(-F&V+38I]F&(-BOV8?8K]B?(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM
M:71E<B!C:&%R86-T97(_(@IM<V=S='(@(MF&V8C;C-BSV8?9E.*`C"#8K=BG
MV*;9A"#:AMN,V+/8JMB?(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS
M9W-T<B`BV8;9B-N,V+/9A^*`C-N,(-F&V8+9A"#9@MF(V80@VH;;C-BSV*K8
MGR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#8Q"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B
M"FUS9W-T<B`BVJG8K]BGV84@V8'8I]BR(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S,PIM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R
M('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R("+:J=BOV*?9A2#8J-BQ
MV8;8I]F%V8?B@(S9A]BGVXP@V878JMBUV83B@(S:J=F&V8;8K]F'(.*`C-BH
MV+'8I]N,(-F(VXS8L=BGVXS8M-JOV+$@V878JMF&(-F!V+G8I]F$(-BHV*?8
MM-F&V*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R("+8N=BQV+8B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(U"FUS9VED(")7:61T:"!I
M;B!#4U,@=6YI=',B"FUS9W-T<B`B(-F^V8?9AMBG(-BOV+$@V8C8I]BMV*\@
M0U-3("(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@
M*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(MF^V8?9
MAMBGVXP@VJ_8LMN,V8;:K]BGV88@)7,@V*_8L2#8L=BGV+/8JB`HV*_8L2#9
MB-BQV8C8KR#8J-BYV*_;C"#9A=F(V*O8L2#9A=N,XH",VJ_8L=BOV*\I.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V
M"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`BV;[9A]F&V*?;
MC"#8K-BOV8C9A"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@(MF(V*?8
MK=BO(-F^V8?9AMBG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R("+9OMF'V8;8
MISHB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$S"FUS9VED(")7
M:6MI(@IM<V=S='(@(E=I:VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S`P(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8U"FUS9VED(")7:6YD(@IM<V=S='(@(MBHV*?8KSHB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B5VEN9"!%
M87)L>2(*;7-G<W1R("+8J-BGV*\@V++9B-BOV8?9AMJOV*?9A3H@(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HX,`IM<V=I9"`B5VEN9"!S<&5E9"!I;B!K
M;F]T<R(*;7-G<W1R("+8L]BQV+G8JB#8J-BGV*\@V*C8L=BMV+/8J"#9@=F(
MV*H@V*C8L2#8L]BGV+G8JB(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34V
M"FUS9VED(")7:6YD.B(*;7-G<W1R("+8J-BGV*\Z(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(T,@IM<V=I9"`B5VEN9#H@(@IM<V=S='(@
M(MBHV*?8KSH@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED
M(")7:7-D;VTB"FUS9W-T<B`BV+G9@MF$(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$Y-@HC+"!F=7IZ>0IM<V=I9"`B5VES:&QI<W0B"FUS9W-T
M<B`BV83;C-BSV*H@V*+8L=BRV8C9A]BG(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S='(@(MJIV*?8L2(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM<V=I9"`B
M5V]R:R!!9&1R97-S(@IM<V=S='(@(MBBV*_8L=BS(-F%V*W9A"#:J=BGV+$B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR
M"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(MBJV839@=F&(-F%V*W9A"#:
MJ=BGV+$B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-CD@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G
M:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T
M960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HS,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@
M;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,30*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL
M92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(MBGVXS8K-BGV*\@V;[8
ML=F(V8;8K]F'(%9&4R#9A=BLV8C8LB#8K]BSV*K8L=BSVXP@V8;8K]BGV+'8
MKR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#,*;7-G:60@(E@M
M4F5F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.3(*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G
M:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G
M:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@R"FUS9VED
M(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`BXH",65DB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-34*;7-G:60@(EE9
M65DB"FUS9W-T<B`B65E962(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,3`X"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z
M-38*;7-G:60@(EEE87)L>2(*;7-G<W1R("+8L]BGV838I]F&V8<B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$W"FUS9VED(")996UE;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(")997,B
M"FUS9W-T<B`BV*+8L=N,(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA
M:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R
M("+8J-F$V8?8C"#9A=F(V*?9@=F"V84B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%
M6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@
M=&\@5UE325=91RXB"FUS9W-T<B`BV+39A=BG(-BOV+$@V878KR#9A=BJV88@
MV8?8L]BJVXS8KRX@V*?8LB#8K]JIV879AR`@6SP^72#8J-BQV*?;C"#8J-BQ
MVJ_8M-BJV88@V*C9AR!765-)5UE'(-BGV+/8JMF!V*?8K]F'(-JIV8;;C-BO
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C@R"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@
M=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,30Q,0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC
M871E9"XB"FUS9W-T<B`BV+39A=BG(-BJV+78K]N,V8(@V8?9B-N,V9'8JB#9
MAMBTV*_;C-BO(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H
M<#HS,#(*;7-G:60@(EEO=2!C86X@;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C
M=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R("+8M-F%V*<@V8;9A=N,
MXH",V*K9B-BGV8;;C-BO(-F&V8C;C-BSV8<@)UQ<)R#8L=BG(-BOV+$@V8;8
MI]F%(-JIV*?9A=F$(-BNV8C8KR#8K]BGV+38JMF'(-BHV*?8M-N,V*\B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4U(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Y-S4*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L
M:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`BV+39A=BG(-BBV*_8L=BS(-F^
MV+/8JB#8I]F$VJG8JMBQV8C9AMN,VJD@V878N=BJV*C8L=N,(-F(V*?8L=BO
M(-F&VJG8L=BOV8?B@(S8I]N,V*\B"@HC.B!F<F%M97=O<FLO1&%T82]$871A
M+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M
M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C
M;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@HBV+39
MA=BG(-F'VXS:AB#9@=N,V838K]N,(-BQV*<@V*_8L2#9OMBQV8C9AMBOV8<@
MV*_8L=F(V8;B@(S8J-BQV*\@V+38K]F'(-BHV8<@V8';C-F$V*\@V878JMF"
MV*?8J-F$VXP@V*_8L2`E<R#9AMJOV*?8M-BJ(-F&VJG8L=BOV8?B@(S8I]N,
MV*\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@(EEO
M=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`BV+39A=BG(-BNV*?8
ML=BL(-BTV*_;C-BO(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V
M,0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO
M;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B
M"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S
M='(@(B(*(MBTV878IR#9A=BLV*C9B-BQ(-F'V+/8JMN,V*\@VXS:J2#8M-F%
MV*?8L=F'(-BJV839@=F&(-F%V+G8JMBHV+$@V8C8I]BQV*\@VJG9AMN,V*_8
MC"#8I]BR(-BYV838I]F%V*H@)RLG(-BHV+'8I]N,(-BTV878I]BQV8?B@(S9
MA]BGVXP@(@HBV*C;C-F&(-BGV839A=F$V83;C"#8I]BSV*K9@=BGV*_9AR#:
MJ=F&VXS8KR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#@*;7-G
M:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@
M(MBTV878IR#9A=BLV*C9B-BQ(-F'V+/8JMN,V*\@VXS:J2#9A=F"V*_8I]BQ
M(-F%V+G8JMBHV+$@V8C8I]BQV*\@VJG9AMN,V*\B"@HC(",M(RTC+2,M(R`@
M8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T
M(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N
M(@IM<V=S='(@(MBTV878IR#8J-BGVXS8KR#;C-JI(-F^V+38JMN,V*C8I]F&
M(-BOV+'8KMBJ(-BOV*?8K]F'(-BHV+'8I]N,(-BGV+/8JMF!V*?8K]F'(-BG
MV+(@V*O8J-BJ(-F&V*?9A2#9OMN,VJG8L=BHV8;8K]N,(-JIV8;;C-BO(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-38*;7-G:60@
M(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G<W1R("+8
MM-F%V*<@V*C8I]N,V*\@VXS:J2#8L]BGV878I]F&V8<@V;[8M-BJVXS8J-BG
MV88@5D93(-BQV*<@V;[;C-JIV+'8J-F&V*_;C"#:J=F&VXS8KR(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S
M="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H
M92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`BV8+8J-F$(-BGV+(@V*?8L=BS
MV*?9A"#:K]BRV*?8L=BTV(P@V*C8I]N,V*\@V878M-JIV80@V+'8IR#8M-BQ
MV*T@V*_9A]N,V*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H
M97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`BV+39A=BG(-BHV*?;
MC-BO(%523-BGVXP@VJG9AR#8I]N,V88@V;[;C-F(V8;8KR#8J-F'(-BBV88@
MV*?8M-BGV+'9AR#9A=N,XH",VJG9AMBO(-BQV*<@V8C8I]BQV*\@VJG9AMN,
MV*\B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B
M66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G
M<W1R("+8M-F%V*<@V*C8I]N,V*\@VXS:J2#:J=BGV+'8L]BGV++8C"#8J-BQ
MV*?;C"#8K=BPV8$@VJG8L=BOV88@V*?9AMBJV*[8I]BH(-JIV8;;C-BO(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S="!S<&5C:69Y
M(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R("+8M-F%V*<@V*C8
MI]N,V*\@VXS:J2#9AMBGV84@VJG8I]BQV*C8L=B,(-BHV+'8I]N,(-BMV+#9
M@2#:J=BQV*_9AB#9A=BTV*[8M2#:J=F&VXS8KR(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O
M(')E;6]V92XB"FUS9W-T<B`BV+39A=BG(-BHV*?;C-BO(-N,VJD@V8;8I]F%
M(-JIV*?8L=BHV+'8C"#8J-BQV*?;C"#8K=BPV8$@V+38K]F&(-F%V+38KMBU
M(-JIV8;;C-BO(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y
M('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(MBTV878IR#8J-BGVXS8
MKR#;C-JI(-F&V*?9A2#:J=BGV+'8J-BQV(P@V*C8L=BGVXP@V*?8MMBGV8'9
MAR#:J=BQV*_9AB#9A=BTV*[8M2#:J=F&VXS8KR(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@=7!D871E+B(*;7-G<W1R("+8M-F%V*<@V*C8I]N,V*\@VXS:J2#8M-F&
MV*?8L]F'(-JIV*?8L=BHV+'8C"#8J-BQV*?;C"#8J-BQV8C8LMBQV+/8I]F&
MVXP@V*?9AMBJV*[8I]BH(-JIV8;;C-BO(@H*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(MBTV878IR#8
MJ-BGVXS8KR#9A=BTV*[8M2#:J=F&VXS8KR#:J=F'(-J&V8<@V+G9A=F$VXP@
MV*C8I]N,V*\@V*?9AMBLV*?9A2#:K]N,V+'8KR(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED(")9;W4@
M;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(MBTV878
MIR#8J-BGVXS8KR#9AMBGV84@V*S8K]N,V*\@V*_8L]BJV8<@V+'8IR#8JMBG
MVXS9OB#:J=F&VXS8KR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V
M:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A
M9V%I;BXB"FUS9W-T<B`BV8;8M-BSV*H@)7,@V+39A=BG(-F%V8;9@MBVVXP@
MV+38K]F'(-BGV+/8JBX@V838M]F!V*?9BR#8K]F(V*C8I]BQV8<@V8C8I]BQ
MV*\@V+39B-N,V*\B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(MBBV*_8
ML=BS(-BGV83:J=BJV+'9B-F&VXS:J=N,(-BTV878IR(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,3(*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB
M"FUS9W-T<B`BV*+8K]BQV+,@V8'8L=BSV*K9AMBOV8<Z(-BTV878ISHB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#D*;7-G:60@(EEO=7(@26YF;W)M871I;VXB"FUS9W-T
M<B`BV*?8M]F$V*?8N=BGV*H@V+39A=BG(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z.3@P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT
M97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG
M(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R
M:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HBV*+8K]BQ
MV+,@V*?;C-F&V*K8L=F&V*K;C"#8M-F%V*<@V8;8L]BHV*H@V*C9AR#8I]BH
MV*K8K]BGVXP@V8;8M-BSV*H@)7,@V+39A=BG(-BJV+K;C-N,V+$@VJG8L=BO
MV8<@V*?8L]BJ+MBHV+'8I]N,(-BQV+G8I]N,V*H@V878L]BGV*;9A"`B"B+8
MI]F%V8;;C-BJVXP@V*C8I]N,V*\@V*_9B-BHV*?8L=F'(-F(V*?8L=BO(-BT
MV8C;C-BO(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*
M;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R("+9AMBGV84@V+39A=BG(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*(RP@9G5Z>GD*;7-G
M:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S
M=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E($AO
M<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E
M(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S
M='(@(B(*(MBSV*?9A=BGV8;9AR#9OMBTV*K;C-BHV*?9AB#8JMBUV*_;C-F"
M(-F'V8C;C-F1V*H@V+39A=BG(-BGV+;8I]F!V8<@VJG8L=BOV88@VJG8I]BQ
MV*C8L=BGV88@V+'8IR#9OMBTV*K;C-BHV*?9AMN,(-F&V87;C.*`C-JIV8;8
MK]B,(-N,V*<@V+38I]N,V*\@(@HBV*C9AMBG(-BHV8<@V*_9A-N,V80@V*_;
MC-JOV+';C"#8I]N,V88@VJG8I]BQ(-BGV8;8K-BGV84@V8;9A=N,XH",V+39
MB-BO(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHU"FUS
M9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@
M<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@
M8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@
M(B(*(MBSV*?9A=BGV8;9AR#9OMBTV*K;C-BHV*?9AB#8JMBUV*_;C-F"(-F'
MV8C;C-F1V*H@V+39A=BG(-F!V8?8L=BSV*H@VJG8L=BOV88@VJG8I]BQV*C8
ML=BGV88@V+'8IR#9OMBTV*K;C-BHV*?9AMN,(-F&V87;C.*`C-JIV8;8K]B,
M(-N,V*<@V+38I]N,V*\@(@HBV*C9AMBG(-BHV8<@V*_9A-N,V80@V*_;C-JO
MV+';C"#8I]N,V88@VJG8I]BQ(-BGV8;8K-BGV84@V8;9A=N,XH",V+39B-BO
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@T"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA
M;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@
M(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A
M9V%I;BXB"FUS9W-T<B`B(@HBV+C8I]F'V+$@V878L=F(V+':K]BQ(-BTV878
MIR#9AMBSV*C8JB#8J-F'(-BGV*C8JMBOV*?;C"#9AMBTV+/8JB`E<R#8M-F%
MV*<@V*K8NMN,VXS8L2#:J=BQV*_9AR#8I]BSV*HNV*C8L=BGVXP@V+'8N=BG
MVXS8JB#9A=BSV*?8IMF$("(*(MBGV879AMN,V*K;C"#8J-BGVXS8KR#8K]F(
MV*C8I]BQV8<@V8C8I]BQV*\@V+39B-N,V*\B"@HC.B!L:6(O0FQO8VLO:69R
M86UE+G!H<#HU,`IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R("+9A=BQV8C8L=JOV+$@V+39A=BG
M(-BGVXS9AB#9A=BTV*[8M=F'(-BQV*<@V;[8M-BJVXS8J-BGV8;;C"#9AMF%
MVXSB@(S:J=F&V*\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N
M:G,Z-#(*(RP@9G5Z>GD*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO
M="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O
M;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"B+9A=BQV8C8L=JO
MV+$@V+39A=BG(-BGVXS9AB#:K]BRVXS9AMF'V93B@(P@VH;8I]F^(-BQV*<@
MV;[8M-BJVXS8J-BGV8;;C"#9AMF%VXSB@(S:J=F&V*\N($-O;G1R;VPO3W!T
M:6]N("L@4"#8L=BG(-BHV+'8I]N,(-J&V*?9OB`B"B+9@=BTV*?8L2#8K]F'
MVXS8KR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3<*;7-G:60@(EEO
M=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(MBRV878I]F&(-F!V+G9
MA-N,(-F%V8;8M]F"V8<@V*S8NMBQV*?9@=N,V*?;C-N,(-BTV878ISHB"@HC
M.B!S97)V:6-E<R]P<F5F<RYP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(EEO=7(@
M9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R("+9
MA]F(VXS9D=BJ(-F^VXS8M"#9@=BQV+8@V+39A=BG.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-3@*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET
M>3HB"FUS9W-T<B`BV8?9B-N,V9'8JB#9OMN,V+0@V8'8L=BV(-BTV878ISHB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`Q"FUS9VED(")9;W5R(&9U
M;&P@;F%M93HB"FUS9W-T<B`BV8;8I]F%(-JIV*?9A=F$(-BTV878ISHB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HQ,#`P"FUS9VED(")9;W5R(&QO
M9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R("+9B-BQV8C8KR#8M-F%V*<@V879
MAMF"V+;;C"#8M-BOV8<@V*?8L]BJ(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S
M<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R("+8I]BSV84@V+'9A=BR("#8
MK-BOVXS8KR#8M-F%V*<@V*C8L=BGVXP@)7,@V8?8L]BJ.B`E<R(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P
M=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T
M:&ES('-E<W-I;VXN(@IM<V=S='(@(MJOV++;C-F&V8?B@(S9A]BGVXP@V+39
MA=BG(-BHV+'8I]N,(-BWV8C9A"#8I]N,V88@V8;8M-BSV*H@V*C8L=F(V++8
ML=BSV*?9AMN,(-BTV*_9AR#8I]BSV*H@(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"XB"FUS9W-T<B`BVJ_8LMN,V8;9A^*`C-F'V*?;C"#8M-F%
MV*<@V*C8L=F(V++8L=BSV*?9AMN,(-BTV*_9AR#8I]BSV*HB"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R
M9"!H87,@8F5E;B!R97-E="(*;7-G<W1R("+8I]BSV84@V+'9A=BR("#8M-F%
MV*<@V*C8I]BRV8;8M-BGV8;;C"#8M-BOV8<@V*?8L]BJ(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I
M;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B"B+8I]BS
MV84@V+'9A=BR(-BTV878IR#8J-BGV++9AMBTV*?9AMN,(-BTV*_9AR#8I]BS
MV*K8C"#9OMBSV*H@V*?9A-JIV*K8L=F(V8;;C-JI(-BNV8C8KR#8L=BG(-J&
MVJD@VJG9AMN,V*\@V8@@V*C8IR#8I]BSV84@V+'9A=BR(-BLV*_;C-BO("(*
M(MBNV8C8KR#9B-BGV+'8KR#8M-F(VXS8KR(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.C<S,@IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E
M9"XB"FUS9W-T<B`BV*?8L]F%(-BQV878LB`@V+39A=BG(-F%V8;9@MBVVXP@
MV+38K]F'(-BGV+/8JB(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`BVJG8
MI]BQV+/8I]BRXH",V8?8I]N,(-BQV*?9A^*`C-BOV8C8L2#8M-F%V*<Z(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"B,L(&9U
M>GIY"FUS9VED("):86ER92(*;7-G<W1R("+9A-BWVXS9@2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED(")::6UB86)W92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ
M-S(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*
M;7-G:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R(");V;[9AMF'V*?9
MAB#:J=BQV*_9AB#9A=BJV88@V8;9@MF$(-F"V8C9A"#8M-BOV8==(@H*(SH@
M<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G:60@(EM0<F]B;&5M(%)E<&]R
M=%TB"FUS9W-T<B`B6]JOV++8I]BQV+0@V878M-JIV81=("(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO
M=R!1=6]T960@5&5X="`M(@IM<V=S='(@(EO9AMF%V*?;C-BT(-F%V*K9AB#9
MAMF"V80@V8+9B-F$(-BTV*_9AR`M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL
M=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G
M<W1R("+9AMF%V*?;C-BT(-F%V*K9AB#9AMF"V80@V8+9B-F$(-BTV*_9AUL@
M+2`E<R#8KMBW72(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D
M92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*
M;7-G<W1R(");V*[8MR`E<R#8I]BR("5S(%T@(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-30Q('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z
M,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R("+8L]BQV;[8L=BS
MV*K;C"(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*;7-G<W1R
M(")#3$DB"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*
M;7-G<W1R("+8K]BQV*[8JB#8K]BGV*_9AR(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E
M;&5T92!2;W<B"FUS9W-T<B`BV*W8L-F!(-BSV+?8L2(*"B,Z(&QI8B]A<&DN
M<&AP.C$S,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R("+:K]BQV8C9AR8C>#(P
M,&,[V8?8IR(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ
M-S4*;7-G:60@(E](96QP(@IM<V=S='(@(MBQV*?9A]F&V878IR(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`BV*[8M=F(
MV+7;C-BGV*H@V*K8M=F(VXS8L2XN+B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ.30*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`BV8C8
ML=F(V*\B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP
M"FUS9VED(")?3&]G(&]U="(*;7-G<W1R("+8KMBQV8C8K"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM
M<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(MBJV+K;C-N,V+$@V;[;
MC-F(V8;8KRXN+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H
M<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(MJOV++;C-F&V8?B@(S9
MA]BG(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO;G,B
M"FUS9W-T<B`BV878K-F(V++9A]BG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"FUS9VED(")?4F5M;W9E
M($QI;FLN+BXB"FUS9W-T<B`BV*W8L-F!(-F^VXS9B-F&V*\N+BXB"@HC.B!L
M:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R("+8L=BGV8<F
M(W@R,#!C.]BGV8;8K]BGV++;C"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R
M;W!E<G1I97,N+BXB"FUS9W-T<B`BV*[8M=F(V+7;C-BGV*H@V*S8K]F(V80N
M+BXB"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G<W1R
M("+:J=BGV+'8J-BQV*?9AB(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3(Q"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`BVJG8JMBGV*C:
MAMF'V90@V*+8K]BQV+,@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ,S0*(RP@9G5Z>GD*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N
M(@IM<V=S='(@(MJIV*K8I]BHVH;9A]F4(-BBV*_8L=BS("(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$S"FUS9VED(")C86QE;F1A<B(*;7-G
M<W1R("+8JMF"V8C;C-F%(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B8V%L;2(*;7-G<W1R("+8HMBQV*?9A2(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,34X"B,L(&9U>GIY"FUS9VED(")C86YN
M;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8
MI]F&(-BOV+$@V;[8L=F(V8;8K]F'(%PB)7-<(B#9AMF(V+38JB(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN
M;W0@;W!E;B!I;G!U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HU.3(*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T
M<B`BV*?;C-F&V*S8IR#8L=BG(-F!V+38I]BQ(-BOV8?;C-BO(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA
M;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$W.`HC+"!F=7IZ>0IM<V=I9"`B8V]N
M9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R("+8JMF!V*?9B-BJV8?8I]N,(-F^
MVXS:J=BQV*C9AMBOVXPB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN
M9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ.#(*(RP@9G5Z
M>GD*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R("(E<R#9OMN,V*_8
MIR#9AMBTV*\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HW,0IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-34*;7-G:60@(F9I;&4B"FUS9W-T
M<B`BV;[8L=F(V8;8K]F'(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C`@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S
M*2!A="`E<R`E<R(*;7-G<W1R("+8I]BR("5S("@E<RD@V*_8L2`E<R`E<R(*
M"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M
M(RTC"B,@"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3`*;7-G
M:60@(F=U<W1I;F<B"FUS9W-T<B`BV*C8I]BO(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.0IM<V=I9"`B:#HB"FUS9W-T
M<B`B:#HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S4X"FUS9VED(")H:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO
M=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T
M<B`BV8'9B-BQV*?9BR(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B
MV*_8L=BNV+<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30V"FUS9VED(")I
M;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=
M(@IM<V=S='(@(MBNV+?9B-BW72(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C,V.0IM<V=I9"`B;6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HR.3$@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C,R
M"FUS9VED(")N86UE(@IM<V=S='(@(MF&V*?9A2(*"B,Z(&9R86UE=V]R:R]2
M4$,O4E!#+G!H<#HQ,C$*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R
M("+9OMN,V*?8K]F'(-BSV*?8LMN,(-F&V+38K]F'(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y"FUS9VED(")N;W0@>65T(&EM
M<&QE;65N=&5D(@IM<V=S='(@(MF'V8;9B-BR(-F^VXS8I]BOV8<@V+/8I]BR
MVXP@V8;8M-BOV8<@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,#4*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B;F]T97!A9"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`BV*_8L=BUV*\B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W-`HC+"!F=7IZ>0IM<V=I
M9"`B<&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`BV878K-F(V+(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y
M"FUS9VED(")P:7AE;',B"FUS9W-T<B`BV;[;C-JIV+/9A-F'V*<B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M
M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS9VED(")R:7-I;F<B
M"FUS9W-T<B`BV+?9A-F(V+DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$T,@HC+"!F=7IZ>0IM<V=I9"`B<V5R=FEC92!U;F%V86EL
M86)L92(*;7-G<W1R("+8J-F$V8C:J2!-971A<B#9@MBGV*C9A"#8K]BSV*K8
ML=BS(-F&VXS8L]BJ(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HY.0IM
M<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R("+9AMF%V*?;C-BT(-BJ
MV8'8I]F(V*K9A]BG(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S@U"FUS9VED(")S<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B<W1E861Y(@IM
M<V=S='(@(MF^VXSB@(S8K]BQV;[;C"(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,S`Y"FUS9VED(")S=VET8V@@;V9F(&IA=F%S8W)I<'0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDR.0IM<V=I9"`B=&%S:R!L:7-T(@IM<V=S
M='(@(MF!V8?8L=BSV*H@V8C8N-N,V8'9AR(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P
M-0HC+"!F=7IZ>0IM<V=I9"`B=')Y(&%G86EN(@IM<V=S='(@(MBOV+$@V8?8
ML2#9B-BQV8C8KR(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(G1Y<&4@=&AE('!A<W-W
M;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`BV*?8L]F%(-BQV878LB#8
ML=BG(-BHV+'8I]N,(-BJV*/;C-N,V*\@V*_9B-BHV*?8L2#9B-BGV+'8KR#:
MJ=F&VXS8KR(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@(MN,VJ_8
MI]F&V8<@V+38K]F'(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]087)T+G!H
M<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R("+8J-N,(-F&V*?9A2(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`BV*?9AMBJV*[8I]BH
M(-JIV*?8L=BHV+$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@(G9#87)D(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T,0IM<V=I
M9"`B=SHB"FUS9W-T<B`B=SHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B=V5A=&AE<BYC
M;VTB"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]F:5]&22YP;P``
M````````````````````````````````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M-S,R,C`P`#$P-3$U-#,S-S4T`#`Q-S8Q-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````C($9I;FYI<V@@=')A;G-L871I;VX@
M9F]R($AO<F1E+@HC($-O<'ER:6=H="`H0RD*(R!,965N82!(96EN;R`\;&EI
M;G5`=71A+F9I/BP@,C`P,2TR,#`V+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB
M4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C$M8W9S7&XB"B)297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#8M,#(M,C<@,3DZ-3$K,#(P,%QN(@HB4$\M4F5V
M:7-I;VXM1&%T93H@,C`P-BTP,BTR-"`Q,CHU.2LP,C`P7&XB"B),87-T+51R
M86YS;&%T;W(Z($QE96YA($AE:6YO(#QL:6EN=4!U=&$N9FD^7&XB"B),86YG
M=6%G92U496%M.B!&:6YN:7-H(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*
M(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA
M:6X[(&-H87)S970]:7-O+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%
M;F-O9&EN9SH@."UB:71<;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS
M9W-T<B`B("@E<R!PY&EVY.0@<VET=&5N*2(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,3,W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S
M<VME>2`E<RDB"FUS9W-T<B`B("A0:6MA;N1P<.1I;B`E<RDB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S@Q"B,L('!H<"UF;W)M870*;7-G:60@
M(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B("@E<R!PY&EVY'-SY"DB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<W"FUS9VED("(@*'1O9&%Y*2(*
M;7-G<W1R("(@*'3D;N3D;BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S<Y"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@*&AU;VUE;FYA
M*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H
M>65S=&5R9&%Y*2(*;7-G<W1R("(@*&5I;&5N*2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,U,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDV"FUS
M9VED("(@870@(@IM<V=S='(@(B`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T
M(&$@9&ER96-T;W)Y+B(*;7-G<W1R(")<(B5S7"(@96D@;VQE(&AA:V5M:7-T
M;R(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T
M<B`B7"(E<UPB(&5I(&ME;'!A82!V86QI;FYA:W-I+B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S$P"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`Y.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E
M9VES=')Y+B(*;7-G<W1R(")<(B5S7"(@96D@;VQE(&%S96YN971T=2!(;W)D
M96X@<F5K:7-T97)I<W/D+B(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R964N<&AP
M.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E
M<B!N;W0@9F]U;F0N(@IM<V=S='(@(EPB)7-<(B!P=6ED96X@:W5V86%J86$@
M96D@;/9Y='EN>70N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@
M<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@;&ESY'1T:6EN(')Y:&WD:N1R:F5S
M=&5L;>3D;BXB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R
M;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@;&ESY'1T:6EN(&]I
M:V5U:W-I:6XN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB
M('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(EPB)7-<(B!E:2!L=6]T
M=3H@)7,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"B,L('!H<"UF
M;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E
M+C)F)24I(@IM<V=S='(@(B4N,F9-0B!KY'ET971T>2`E+C)F34(@<V%L;&ET
M=7-T82`H)2XR9B4E*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S
M='(@(B5D("5S(&IA("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E
M<RXB"FUS9W-T<B`B4V%L87-A;F%S:2!V86YH96YT=74@)60@<.1I=N1N('#D
MY'-TY"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<T"B,L
M('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R("(E
M9"!PY&EVY&X@96YN=7-T=7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T
M<B`B)7,@+2!);&UO:71U<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-S`U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R
M:6YT(@IM<V=S='(@(B5S(%-O<FUE;FKD;&MI(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z.#0P(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C@T,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*
M;7-G<W1R("(E<R!+0B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I
M;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S(%EL;.1P:71O=&]I;65N
M<&ET965T("T@5F%R;6ES='5S(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B5S(&%S96YN=7,B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8T"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B)7,@:VER:F%U='5M:6YE;B(*
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B)7,@:^1Y
M='3V96AD;W0B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X,B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U,`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C0S,B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS
M9W-T<B`B)7,@;VX@:F\@;VQE;6%S<V$N(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-#8*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3(@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@
M)7,@)7,B"FUS9W-T<B`B)7,@<W5U;G1A("5S("5S(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S
M(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P
M97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB
M"FUS9W-T<B`B(@HB)7,@;VX@=F%L;6ES('-U;W)I='1A;6%A;B!Y;&SD<&ET
M;W1O:6UE;G!I=&5I=.0N(%9A;&ET<V4@=F%L:6YT87)U=61U:7-T82`B"B)S
M=6]R:71E='1A=F%T('1O:6UE;G!I=&5E="XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S0T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E
M<75I<F5D(@IM<V=S='(@(B5S(&]N('!A:V]L;&EN96XB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU
M=&5S(@IM<V=S='(@(B5S(&UI;G5U='1I82(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(E<R!E:2!L]GET>6YY="XB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B5S("T@)7,@+R`E
M<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(V"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(B5S.FX@
M;W-O:71E:VER:F$B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ
M.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@
M(B5S.FX@:V%L96YT97)I(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S
M='(@(B5S.FX@;75I<W1I;&ES=&$B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T
M(@IM<V=S='(@(B5S.FX@=&5H=.1VY&QI<W1A(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7,Z("5S
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,3(W
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y
M(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@
M9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@
M=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS
M9W-T<B`B(@HB)7,@.B!4Y&WD('9I97-T:2!E:2!O;&4@=N1L='3D;>1T=.0@
M<VEL=.0@;.1H971TY&KD;'3D+"!J;VMA(&]N(&UE<FMI='1Y("(*(FSD:&5T
M=.1JY&MS:2X@4W5H=&%U9'4@=F%R875K<V5L;&$@=FEE<W1I<W/D(&]L979I
M:6X@;&EN:VME:6AI;B!J82!V87)O("(*(F%N=&%M87-T82!LY&AE='3D:N1L
M;&4@;6ETY.1N('EK<VEL]FEV:>0@=&EE=&]J82XB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S4T(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS.3D*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B+"!P=75S:VET
M=&%I<W1A(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.34@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG
M("5S("5S(@IM<V=S='(@(BP@<'5U<VMI='1A:7-T82`E<R`E<R(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C`X"B,L('!H<"UF;W)M870*;7-G:60@(BP@
M=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(L('9A:6AT96QE=F%A
M("5S("T@)7,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-S0X(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,CDT"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P-S,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$S,@IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(BTM('9A;&ET<V4@
M+2TB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@
M1F]R;6%T(@IM<V=S='(@(C$R+71U;FYI;B!JY')J97-T96QMY"(*"B,Z(&QI
M8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS
M9W-T<B`B,C0M='5N;FEN(&KD<FIE<W1E;&WD(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T('1U
M;G1I82(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z-CD*;7-G:60@
M(CQ0<F5V:6]U<R(*;7-G<W1R("(\161E;&QI;F5N(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ,C8*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R
M97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B5&EE=&]K86YT871A
M=7-T86KD<FIE<W1E;&WDY"!E:2!O;&4@;>3D<FET96QT>2!TY&QL92!O<VEO
M;&QE(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C(*;7-G:60@
M(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(E1A<&%H='5I
M('9A:V%V82!V:7)H92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T
M;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B5FEE<W1I;B!S86QA=6MS
M965N('1A<G9I=&%A;B!J=6QK:6YE;B!01U`M879A:6XN(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V.`IM<V=I9"`B02!P=6)L:6,@
M4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G
M92XB"FUS9W-T<B`B06QL96MI<FIO:71E='5N('9I97-T:6X@=&%R:VES='5K
M<V5E;B!T87)V:71A86X@:G5L:VEN96X@4$=0+6%V86EN+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P.3D*;7-G:60@(B(*(D$@<'5B
M;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R
M("(B"B)386QA='5N('9I97-T:6X@879A86UI<V5E;B!T87)V:71A86X@:G5L
M:VEN96X@4$=0+6%V86EN+"!S86QA:6YE;B!01U`M879A:6X@(@HB:F$@<V%L
M87-A;F%T96MS=&DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3`Q-@IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!0
M1U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A
M("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(E9I97-T:6X@86QL96MI<FIO:71T
M86UI<V5K<VD@=&%R=FET86%N(&IU;&MI;F5N(%!'4"UA=F%I;BP@<V%L86EN
M96X@4$=0+2(*(F%V86EN(&IA('-A;&%S86YA=&5K<W1I+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3`V"FUS9VED("(B"B)!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB
M"FUS9W-T<B`B(@HB5FEE<W1I;B!A=F%A;6ES965N('1A<G9I=&%A;B!J=6QK
M:6YE;B!3+TU)344M879A:6XL('-A;&%I;F5N(%,O34E-12UA=F%I;B!J82`B
M"B)S86QA<V%N871E:W-T:2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@
M<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*(E9I97-T:6X@
M86QL96MI<FIO:71T86UI<V5K<VD@=&%R=FET86%N(&IU;&MI;F5N(%,O34E-
M12UA=F%I;BP@<V%L86EN96X@4R\B"B)-24U%+6%V86EN(&IA('-A;&%S86YA
M=&5K<W1I+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@
M96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(E9I97-T:6X@<V%L875K<V5E
M;B!T87)V:71A86X@:G5L:VEN96X@4TU)344M879A:6XN(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO
M=61S(@IM<V=S='(@(D%-(%!I;'9IY"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM
M<V=S='(@(D%-(&ME=GET=.0@<V%D971T82(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!32!286EN(@IM<V=S
M='(@(D%-('-A9&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R(")!32!S871E
M:71A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")!32!L=6UI<V%T
M96ET82(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!
M32]032(*;7-G<W1R(")!32]032(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S
M='(@(D%022!)1"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@
M(E1I971O:F$@961I=&]R:7-T82(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N
M<&AP.C4S"FUS9VED(")!8F]U="XN+B(*;7-G<W1R(")4:65T;VIA+BXN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM
M<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(D%B<RX@86QI;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B
M<VUI9&1L92(*;7-G<W1R(")!8G,N(&ME<VME;&SD(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")3:6YU;&QA(&5I(&]L
M92!O:6ME=6MS:6$@;'5O9&$@5D93+6AA:V5M:7-T;V$N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE
M9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B4VEN=6QL82!E:2!O;&4@
M;VEK975K<VEA(&QU;V1A(%9&4RUT:65D;W-T;V$N(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C,*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS
M9W-T<B`B2^1Y='3D:N1T=6YN=6MS96X@=&EE9&]T(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<X"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S
M='(@(DOD>71TY&KD='5N;G5K<V5N('-A;&%S86YA(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!
M8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B2^1Y='3D:N1T:6QI('-U;&IE='1U
M+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S4*;7-G:60@(D%C
M8V]U;G1I;F<B"FUS9W-T<B`B2VER:F%N<&ET;R(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D+FEN
M8SHQ-`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ
M,0IM<V=I9"`B061D(@IM<V=S='(@(DQI<^3D(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL
M9"!'<F]U<"(*;7-G<W1R("),:7/DY"!A;&ER>6AMY"(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T
M<B`B3&ESY.0@86QI;VEK975S(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N
M:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R("),:7/DY"!TY&CD;CHB
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q
M.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R("),:7/DY"!U=7-I(')Y
M:&WD(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E
M<FUI<W-I;VXB"FUS9W-T<B`B3&ESY.0@=75S:2!O:6ME=7,B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M
M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R
M("),:7/DY"!A;&ER>6AMY"!R>6AMY.1N(%PB)7-<(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@
M(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(DQI
M<^3D(&%L:6]I:V5U9&5T(%PB)7-<(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P
M"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B3&ESY.0@=75S:2!K
MY'ET=.1JY#HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-34V"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(DQI<^3D('-A
M<F%K92(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*
M;7-G:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R("),:7/DY"!U=7-I82!J
MY'-E;FGD(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I
M9"`B061D('!A:7(B"FUS9W-T<B`B3&ESY.0@<&%R:2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H
M92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(DQI<^3D
M("5S('9A;&EK:V\@36]Z:6QL86X@4VED96)A<B!O<VEO;VXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D
M9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(DQI<^3D(&]S;VET96MI<FIA
M86XZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C<X"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(DQI
M<^3D(&]S;VET96MI<FIA86YI.B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS
M9VED(")!9&0@=7-E<B(*;7-G<W1R("),:7/DY"!KY'ET=.1JY"(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D
M(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I
M=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*
M(DQI<^1T=&EI;B!<(B5S7"(@:N1R:F5S=&5L;>3D;BP@;75T=&$@96D@=F]I
M(&QI<^1TY"!S:7/DY&YK:7)J875T=6UI<W!Y>6YN]FX@(@HB;&ESY'1I971O
M:F$Z("5S+B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN
M(&YO=RXB"FUS9W-T<B`B3&ESY'1T:6EN(%PB)7-<(B!JY')J97-T96QMY.1N
M+B!6;VET(&YY="!K:7)J875T=6$@<VESY.1N+B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@
M9&ES86)L960N(@IM<V=S='(@(DOD>71TY&II96X@;&ESY.1M:6YE;B!O;B!E
M<W1E='1Y+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0U"FUS9VED(")!
M9&1R97-S(@IM<V=S='(@(D]S;VET92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ-#$*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R(")/<V]I
M=&5K:7)J82(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N
M<&AP.C4V"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDU"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O
M=&AE<B!U<V5R<R(*;7-G<W1R(")6;VD@87-E='1A82!T86D@;>3D<FET96QL
MY"!O:6ME=6MS:6$@=&]I<VEL;&4@:^1Y='3D:FEL;&4B"@HC.B!A9&UI;B]I
M;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM
M<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B66QLY'!I=&\B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0S"FUS9VED(")!9',B"FUS9W-T
M<B`B36%I;F]K<V5T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.`IM<V=I9"`B069G:&%N:7-T86XB
M"FUS9W-T<B`B069G86YI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$*;7-G:60@(D%L8F%N
M:6$B"FUS9W-T<B`B06QB86YI82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0*;7-G:60@(D%L9V5R
M:6$B"FUS9W-T<B`B06QG97)I82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(D%L
M:6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB"FUS9W-T<B`B5&%S86$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED
M(")!;&EG;FUE;G0Z(@IM<V=S='(@(E1A<V%U<SHB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R(")+86EK:VDB"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5
M<V5R<R(*;7-G<W1R(")+86EK:VD@875T96YT:6MO:61U="!KY'ET=.1JY'0B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R
M"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(DMA:6MK:2!R>6AMY'0B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z.3$*;7-G:60@(D%L;"!097)M:7-S
M:6]N<R(*;7-G<W1R(")+86EK:VD@;VEK975D970B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!
M;&P@9F]U<B!S:61E<R(*;7-G<W1R(")+86EK:6QT82!N96QJY&QTY"!S:79U
M;'1A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B
M06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(E-A;&QI(&UO;F5T
M(&]S;VET=&5E="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S@*;7-G
M:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S
M='(@(E-A;&QI(&KD<FIE<W1E='EN(&QI<W1A;B!T>7EP:6X@87-E='5S+B(*
M"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P-`IM
M<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B3VX@:F\@;VQE;6%S<V$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")!;'1E<FYA
M=&4@24U34"!,;V=I;B(*;7-G<W1R(")686EH=&]E:'1O:6YE;B!)35-0+7-I
M<^3D;FMI<FIA=71U;6EN96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3$Q"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R(")6
M86EH=&]E:'1O:6YE;B!)35-0+7-A;&%S86YA(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4P,PIM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B
M"FUS9W-T<B`B5F%I:'1O96AT;VEN96X@24U34"UKY'ET=.1JY'1U;FYU<R(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E
M<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(")686EH=&]E:'1O:7-E="!S
MY&AK]G!O<W1I;W-O:71T965T(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B5F%I:'1O
M96AT;VES970@;6%L;&ET(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@
M=&5X=#HB"FUS9W-T<B`B5F%I:'1O96AT;VEN96X@=&5K<W1I.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C<*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(EEH9'ES=F%L
M=&%I;B!386UO82(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N
M(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B06YN971T
M=2!A<G9O(&5I(&ME;'!A82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,34U"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D
M+B(*;7-G<W1R(")T87!A:'1U:2!T=6YT96UA=&]N('9I<FAE+B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38*;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B06YD;W)R82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0*;7-G:60@(D%N9V]L82(*;7-G<W1R(")!;F=O;&$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P"FUS9VED(")!;F=U:6QL82(*;7-G<W1R(")!;F=U:6QL82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U
M<R!0<F]X>2(*;7-G<W1R(")!;F]N>7EM:2!P<F]X>2(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B
M5F%S=&%U<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T
M<B`B06YT87)K=&ES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.0IM<V=I9"`B06YT:6=U82!A;F0@
M0F%R8G5D82(*;7-G<W1R(")!;G1I9W5A(&IA($)A<F)U9&$B"@HC.B!A9&UI
M;B]P:'!S:&5L;"YP:'`Z,S8@861M:6XO=&5M<&QA=&5S+G!H<#HW-`HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4X('1E;7!L871E<R]A9&UI
M;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S
M='(@(D]H:F5L;6$B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G
M:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B3VAJ96QM86QI<W1A(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC871I
M;VX@:7,@<F5A9'DN(@IM<V=S='(@(D]H:F5L;6$@;VX@=F%L;6ES+B(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T
M;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B3&%I=&$@:^1Y='3V]FX@:V%I:VMI
M(&%L:6IA:V]I:&EN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B2'EVY&MS>2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T,`IM<V=I9"`B
M07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R(")!<G9I;VET=2!K;VMO(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-0HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@
M(D%P<FEL(@IM<V=S='(@(FAU:'1I:W5U(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-S@*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R
M(")!<F%B:6$@*%=I;F1O=W,M,3(U-BDB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z-S@*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HV-@IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B
M4&%K971I;B!K;VMO(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C<W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*
M;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R(")086ME=&EN(&YI;6DB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L
M('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(D]L
M971K;R!V87)M82P@971TY"!H86QU870@<&]I<W1A82!S:7/DY&YK:7)J875T
M=6UI<W!Y>6YN]FX@)7,@/R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M9&5L971E+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R
M92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P
M<S\B"FUS9W-T<B`B3VQE=&MO('9A<FUA+"!E='3D(&AA;'5A="!P;VES=&%A
M(%PB)7-<(B!J82!K86EK:VD@<V5N(&%L:7)Y:&WD=#\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V
M"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B06=E;G1I:6YA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,@IM<V=I9"`B07)M96YI82(*;7-G<W1R(")!<FUE;FEA(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D%R;65N:6%N("A!4DU30TE)
M+3@I(@IM<V=S='(@(D%R;65N:6$@*$%235-#24DM."DB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R(")486ED92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S`*;7-G:60@(D%R=6)A(@IM<V=S='(@(D%R=6)A(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N
M($ES;&%N9"(*;7-G<W1R(")!<V-E;G-I;VX@<V%A<F5T(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B
M07-C:6DM=&%I9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B07-I86XO
M5'EY;F5N;65R96X@86QU92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M,CD*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M
M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R(")+>7-Y('9A<FUI<W1U
M<R!E;FYE;B!K=6EN('1E:&3DY&X@>6QLY'!I=&]T;VEM96YP:71E970N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y.0IM<V=I9"`B07-S:6=N
M;65N="!C;VQU;6YS(@IM<V=S='(@(E1E:'3D=N1S87)A:VME970B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A
M(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B67)I=&5T=&EI;B!P;VES
M=&%A(&]L96UA=&]N=&$@<GEH;>3D+B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(EER:71E='1I:6X@<&]I<W1A82!O
M;&5M871O;G1A(&]I:V5U='1A+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP
M.C@W"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R
M;6ES<VEO;BXB"FUS9W-T<B`B67)I=&5T=&EI;B!M=6]K871A(&]L96UA=&]N
M=&$@;VEK975T=&$N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S
M"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N
M(@IM<V=S='(@(EER:71E='1I:6X@;75O:V%T82!O;&5M871O;G1A(&IA:V]A
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,PHC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"FUS9VED(")!='1R
M:6)U=&5S(@IM<V=S='(@(DQI<^1MY.1R:71Y:W-E="(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B
M"FUS9W-T<B`B96QO:W5U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.0IM<V=I9"`B075S=')A;&EA
M(@IM<V=S='(@(D%U<W1R86QI82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@*;7-G:60@(D%U<W1R
M:6$B"FUS9W-T<B`B273D=F%L=&$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@
M:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G-Q
M;#H@5&%R=FET=&%V86$@24U!4"UL86%J96YN=7-T82!E:2!L]GET>6YY="XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@
M(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C
M87!A8FEL:71E<RXB"FUS9W-T<B`B075T:%]C>7)U<SH@5&%U<W1A:N1R:F5S
M=&5L;>0@96D@='5E('1A<G9I='1A=FEA(&]M:6YA:7-U=6MS:6$N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H
M7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%U=&A?8WER=7,Z(%1A<G9I='1A=F%A($E-05`M;&%A:F5N;G5S
M=&$@96D@;/9Y='EN>70N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N
M<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE
M+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*(D%U=&A?9G1P.B!T87)V:71T
M879A82!&5%`M;&%A:F5N;G5S=&$@96D@;/9Y='EN>70N($ODY&YNY"!02%`@
M:^1Y='3D96X@+2TB"B)E;F%B;&4M9G1P(&%S971U<W1A+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@
M4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!
M=71H7VEM87`Z(%1A<G9I='1A=F%A($E-05`M;&%A:F5N;G5S=&$@96D@;/9Y
M='EN>70N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU,0IM
M<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D%U=&A?:W)B-3H@5&%R=FET=&%V86$@:W)B-2UL
M86%J96YN=7-T82!E:2!L]GET>6YY="XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G
M<W1R(")!=71H7VQD87`Z(&OD>71TY&II96X@;&ESY.1M:6YE;B!!8W1I=F4@
M1&ER96-T;W)Y>6X@96D@;VQE('1U971T=2(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB
M"FUS9W-T<B`B075T:%]L9&%P.B!+Y'ET=.1J:65N('!O:7-T86UI96YN($%C
M=&EV92!$:7)E8W1O<GES=.0@96D@;VQE('1U971T=2(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@4F5Q
M=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H
M7VQD87`Z(%1A<G9I='1A=F%A($Q$05`M;&%A:F5N;G5S=&$@96D@;/9Y='EN
M>70N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S
M97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R
M("(B"B)!=71H7VQD87`Z($5I('9O:61A(&QI<^1TY"!KY'ET=.1JY.0@)7,N
M(%!A;'9E;&EM96X@=FER:&5I;&UO:71U<R!O;&DZ("(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@
M(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@
M(D%U=&A?;&1A<#H@16D@=F]I9&$@<&]I<W1A82!KY'ET=.1JY.0@)7,B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E
M<R(*;7-G<W1R(")!=71H7VQD87`Z($5I('9O:61A('#D:7;D='3DY"!KY'ET
M=.1JY.0@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0P
M-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R(")!=71H7VQD
M87`Z($OD>71TY&II96X@<.1I=FET=.1M:6YE;B!!8W1I=F4@1&ER96-T;W)Y
M>6X@96D@;VQE('1U971T=2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC
M86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]M8V%L.B!487)V:71T
M879A82!-0T%,+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H
M.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(D%U=&A?<VUB875T:#H@5&%R=FET=&%V86$@<VUB875T:"UL86%J96YN
M=7-T82!E:2!L]GET>6YY="XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%D
M;6EN+G!H<#HQ,#8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R
M=F5R(&9A:6QE9"XB"FUS9W-T<B`B075T96YT:6MO:6YT:2!)34%0+7!A;'9E
M;&EM96QL92!E<.1O;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N(&9A:6QE9"(*;7-G<W1R(")!=71E;G1I:V]I;G1I(&5PY&]N;FES='5I
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@
M9F%I;&5D+B`E<R(*;7-G<W1R(")!=71E;G1I:V]I;G1I(&5PY&]N;FES='5I
M+B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-S8*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V
M97(N(@IM<V=S='(@(D%U=&5N=&EK;VEN=&D@4D%$2553+7!A;'9E;&EM96QT
M82!E<.1O;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C@X,@IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL
M960N(@IM<V=S='(@(D%U=&5N=&EK;VEN=&D@1E10+7!A;'9E;&EM96QL92!E
M<.1O;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P
M"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL
M960N(@IM<V=S='(@(D%U=&5N=&EK;VEN=&D@4TU"+7!A;'9E;&EM96QL92!E
M<.1O;FYI<W1U:2XB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U
M"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R(")+Y'ET971TY'9I
M<W/D;VQE=F%T(&ME;G3D=#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q"FUS9VED(")!>F5R8F%I
M:F%N(@IM<V=S='(@(D%Z97)B86EZ9&%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B0D]&2"!S
M96QI='EK<V5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R(")4
M875S=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(E1A=7-T
M87;D<FDB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@Q"FUS
M9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(E;DY'+D(&ME
M<F)E<F]S('-A;&%S86YA+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B
M-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T
M<B`B5N3D<N0@:V5R8F5R;W,@:^1Y='3D:N1T=6YN=7,N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M-0IM<V=I9"`B0F%H86UA<R(*;7-G<W1R(")"86AA;6$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X
M"FUS9VED(")"86AR86EN(@IM<V=S='(@(D)A:')A:6XB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB
M"FUS9W-T<B`B0F%L=&EA("A)4T\M.#@U.2TQ,RDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T"FUS
M9VED(")"86YG;&%D97-H(@IM<V=S='(@(D)A;F=L861E<V@B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,S"FUS9VED(")"87)B861O<R(*;7-G<W1R(")"87)B861O<R(*"B,Z('5T
M:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"
M87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R(")'<F%F:6EK;VED96X@<&5R=7-H86ME;6ES=&]A(%PB)7-<(B!E:2!L
M]GET>6YY="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,3D*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(E!E<G5S
M=FEI=F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C0Y"FUS9VED(")"96QA<G5S(@IM<V=S='(@(E9A
M;&MO+59E;N1JY"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4*;7-G:60@(D)E;&=I=6TB"FUS9W-T
M<B`B0F5L9VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU,`IM<V=I9"`B0F5L:7IE(@IM<V=S='(@
M(D)E;&EZ92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#`*;7-G:60@(D)E;FEN(@IM<V=S='(@(D)E
M;FEN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT,0IM<V=I9"`B0F5R;75D82(*;7-G<W1R(")"97)M
M=61A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT-@IM<V=I9"`B0FAU=&%N(@IM<V=S='(@(D)H=71A
M;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(E-Y;G1Y;>1PY&EVY"(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N
M(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(D]S:6]T82!<(B5S7"(@;VAJ
M96QM86QL92!<(B5S7"(@96D@;/9Y='EN>70N(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.CDP"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G
M<W1R(")/<VEO;B!A<V5T=6MS970B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA
M>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B3W-I;VX@
M='EY<'!I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(DQI:&%V;VET=2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#,*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B0F]L:79I82(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#<*;7-G:60@(D)O;VMM87)K<R(*
M;7-G<W1R(")+:7)J86YM97)K:70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D97(B"FUS
M9W-T<B`B4F5U;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R
M(")2975N86X@=F%H=G5U<SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(Q"FUS9VED(")";W)D97)S(@IM<V=S
M='(@(E)E=6YA="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(*;7-G:60@(D)O<VYI82!A;F0@2&5R
M>F5G;W9I;F$B"FUS9W-T<B`B0F]S;FEA($AE<GIE9V]V:6YA(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@(DUO
M;&5M;6%T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT.`IM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B
M0F]T<W=A;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C(*;7-G:60@(D)O='1O;2(*;7-G<W1R(")!;&EN(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT-PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R(")";W5V
M970@<V%A<F5T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-`IM<V=I9"`B0G)A>FEL(@IM<V=S='(@
M(D)R87-I;&EA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<*;7-G:60@(D)R:71I<V@@26YD:6%N
M($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R(")"<FET86YN:6%N($EN=&EA;B!V
M86QT86UE<F5N('1E<G)I=&]R:6\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R"FUS9VED(")"<G5N
M96D@1&%R=7-S86QA;2(*;7-G<W1R(")"<G5N96D@1&%R=7-A;&%M(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS-PIM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B0G5L9V%R:6$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS
M9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(E!A;&QU:VMA;&ES=&$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,V"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B0G5R:VEN
M82!&87-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS.0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R(")"
M=7)U;F1I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T-@IM<V=I
M9"`B0TU3(@IM<V=S='(@(D--4R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R(")#4D,B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM<V=I9"`B
M0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B0U),+6IA:V5L=6]S
M;VET=&5E="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*
M;7-G<W1R(")37V]L=6X@=&EE9&]T+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$U,0IM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O
M;7!L971E9"XB"FUS9W-T<B`B5N1L:6UU:7-T:6X@86QU<W1U<R!E:2!V86QM
M:7-T=6YU="XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#@U(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$V"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-3<@8V]N9FEG+VAO;VMS+G!H<"YD
M:7-T.C$P-#`*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(DMA;&5N=&5R:2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G:60@(D-A
M;&TB"FUS9W-T<B`B5'EY;FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.`IM<V=I9"`B0V%M8F]D
M:6$B"FUS9W-T<B`B2V%M<'5T<V5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,`IM<V=I9"`B0V%M
M97)O;VXB"FUS9W-T<B`B2V%M97)U;B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U
M=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R(")386QA<V%N86$@96D@=F]I('1Y:&IE;G3DY"!A=71O;6%A='1I<V5S
M=&DL(&]T82!Y:'1E>71TY"!Y;&SD<&ETY&KDY&XN(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,S4P"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B16D@=F]I(&MI
M<FIO:71T86$@=&EE9&]S=&]O;B!<(B5S7"(B"@HC.B!A9&UI;B]S97-S:6]N
M<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S
M<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B56QK;VES:6$@:7-T=6YT;VOD<VET
M=&5L:6KV:73D(&5I(&]L92!M86AD;VQL:7-T82!H86QL:71A+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,3D@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)U<RYP:'`Z,C,U"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(DE-05`M
M<&%L=F5L:6UE96X@96D@<V%A='4@>6AT97ET=.0Z("5S(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V"B,L('!H<"UF;W)M870*;7-G:60@
M(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(D5I('9O:2!A=F%T
M82!T:65D;W-T;V$@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$*;7-G:60@(D-A;F%D
M82(*;7-G<W1R(")+86YA9&$B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M
M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHV-2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$*;7-G:60@(D-A;F-E
M;"(*;7-G<W1R(")097)U(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R
M(")097)U(&]N9V5L;6%V:65S=&DB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")%:2!V;VED82!P;VES=&%A('1I961O
M<W1O82!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z-#8*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B5N1L:6%I:V%I<VAA:V5M:7-T;V$@96D@
M;/9Y='EN>70N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R
M9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R(")%:2!V;VED82!J871K86$@
M:6QM86X@)W1A<F=E=$9I;&4G("UP87)A;65T<FEA+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B16D@=F]I
M9&$@<&]I<W1A82!H86ME;6ES=&]A(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO
M1&%T851R964O1&%T851R964N<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O
M1&%T851R964O<W%L+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(D5I('9O
M:61A('!O:7-T86$L("5D(&%L:71A<V]J82!O;&5M87-S82XB"@HC.B!F<F%M
M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*
M(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F
M;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*
M;7-G<W1R("(B"B)%:2!V;VD@=75D96QL965N:N1R:F5S=.3D+"!A;FYE='1U
M:F5N('1I971U96ED96X@;>3D<N0@96D@=F%S=&%A("(*(G1A;&QE=&5T='5J
M96X@=&EE='5E:61E;B!MY.1RY.0N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U
M=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R(")%:2!V
M;VD@;VAJ871A('9I97-T:>0@86YN971T=75N(&YU;65R;V]N+B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C4*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B2V%P(%9E<F1E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R(")+=79A=&5K<W1I(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS
M9VED(")#87)R:65R(@IM<V=S='(@(E!A;'9E;'5N=&%R:F]A:F$B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,*;7-G:60@(D-A=&5G;W)I97,@86YD
M($QA8F5L<R(*;7-G<W1R(")+871E9V]R:6%T(&IA(&]T<VEK;W0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S-0IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B0V%Y;6%N
M('-A87)E="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B4'5H96QI;BA'
M4TTI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(E-O
M;'5N('1I961O="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(E-O
M;'5N('3D>71E.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G
M<W1R(")3;VQU;B!T:65D;W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G
M<W1R(")3;VQU;B!VY&QY<SHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C<X"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B36%T:V%P=6AE;&EN
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-E;'1I8R`H
M25-/+3@X-3DM,30I(@IM<V=S='(@(DME;'1T:2`H25-/+3@X-3DM,30I(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(DME<VMI=&5T='DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4T"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T
M<B`B2V5S:VDM069R:6MA;B!T87-A=F%L=&$B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X,@IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM
M,BDB"FUS9W-T<B`B2V5S:VDM175R;V]P<&$@*$E33RTX.#4Y+3(I(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(D-E
M<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B5F%R;65N=&5E;B!T:65D;W0B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,@IM<V=I
M9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B5F%R;65N=&5E;B!O;6ES
M=&%J82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW
M"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R(")687)M96YT
M965N('!O;&ET:6EK870B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$*;7-G:60@(D-H860B"FUS
M9W-T<B`B5'-A9"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR
M-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*;7-G:60@(D-H86YG
M92(*;7-G<W1R(")-=75T82(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HS,0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B
M5F%I:&1A('-A;&%S86YA<VDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-CD*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T
M('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@
M(@HB96UA:6QS+B(*;7-G<W1R("(B"B)6;VET(&UU=71T86$@;.1H971TY&UI
M<W/D<VD@<^1H:_9P;W-T96ES<V$@;N1K>79IY"!N:6UI+2!T86D@;W-O:71E
M=&EE=&]J82XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*
M;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O
M<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT
M86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB4V%L87-A;F%N
M('9A:6AT;R!E:2!O;&4@:^1Y=/9S<^0@;GEK>6ES:6QLY"!A<V5T=6MS:6QL
M82X@3W1A('EH=&5Y='3D("(*(GEL;.1P:73D:FEI;BXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W"FUS9VED
M(")#:&%R(@IM<V=S='(@(DUE<FMK:2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K
M($QI;FLN+BXB"FUS9W-T<B`B5&%R:VES=%]A(&QI;FMK:2XN+B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-3D*;7-G:60@(D-H:6QE(@IM<V=S='(@(D-H:6QE(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M,0IM<V=I9"`B0VAI;F$B"FUS9W-T<B`B2VEI;F$B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X,PIM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S
M,3(I(@IM<V=S='(@(DMI:6YA('EK<VEN:V5R=&%I<W1E='1U("A'0C(S,3(I
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-H:6YE<V4@
M5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(DMI:6YA('!E<FEN=&5I;F5N
M("A":6<U*2(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C<*;7-G:60@
M(D-H;V]S92!!<'!L:6-A=&EO;CHB"FUS9W-T<B`B5F%L:71S92!O:&IE;&UA
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I
M9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B5F%L:71S92!S86QA<V%N
M82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G
M:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(E9A;&ET<V4@:^1Y='3D
M:N1T=6YN=7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`R"FUS9VED
M(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(E9A;&ET
M<V4@<.1I=N1MY.1R:65N(&5S:71Y<V%S=3HB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#
M:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS
M9W-T<B`B5F%L:71S92!L:7-T86X@='EY<'!I("AJY')J97-T971Y:6QL92!L
M:7-T;VEL;&4I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV-@IM<V=I9"`B0VAR:7-T;6%S($ES;&%N
M9"(*;7-G<W1R(")*;W5L=7-A87)E="(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HY,30@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U
M;F0N(@IM<V=S='(@(DQU;VMK86WDY')I='ES=.0@)7,@96D@;/9Y='EN>70N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*
M;7-G:60@(D-L96%R(@IM<V=S='(@(E-E;&MEY"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U3
M3V9F:6-E('1A9W,B"FUS9W-T<B`B4&]I<W1A($U33V9F:6-E('1A9VET(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.0IM<V=I9"`B0VQE87(@475E<GDB
M"FUS9W-T<B`B4&]I<W1A(&MY<V5L>2(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U
M="!U<V5R.B`E<R(*;7-G<W1R(")0;VES=&$@:^1Y='3D:N0Z("5S(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A
M<B!U<V5R(@IM<V=S='(@(E!O:7-T82!KY'ET=.1JY"(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A
M=&$B"FUS9W-T<B`B4&]I<W1A(&OD>71TY&KD;B!T:65D;W0B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE
M87)I;F<@3&%T92(*;7-G<W1R(")396QK96YE=N3D(&UY]FCDY&XB"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM<V=I
M9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B3F%P<V%U=&$@:F%T:V%A
M:W-E<VDB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T
M<B`B0VQI:V%T96QL($A45%`Z;B!K875T=&$B"@HC.B!S97)V:6-E<R]K97EB
M;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G
M:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R(")3=6QJ92!I:VMU;F$B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(U,0IM<V=I9"`B0VQO=61S(@IM<V=S='(@
M(E!I;'9IY"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B4&EL=FEN96X@
M86EK86ES:6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(E!I;'9I;F5N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU,@IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T
M<B`B2V]O:V]S("A+965L:6YG*2!S86%R970B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+W-I9&5B87(N:6YC.C(S"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM
M<V=S='(@(E!I96YE;F[D('-I=G5V86QI:VMO(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L
M;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B4&EE;F5N;F5T>70@<F5U;F%T(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV,@IM<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`B2V]L=6UB:6$B
M"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP
M:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B5N1R:2(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,#,*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,S-0HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,V('-E<G9I8V5S
M+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME
M<B(*;7-G<W1R(")6Y')I=F%L:71S:6XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#,R"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@
M(E;D<FEV86QI;G1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(E-A<F%K.B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-3`*;7-G:60@(D-O;'5M
M;B!T:71L97,B"FUS9W-T<B`B4V%R86MK96ED96X@;W1S:6MO="(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C8*;7-G:60@(D-O;6EC<R(*;7-G
M<W1R(")387)J86MU=F%T(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(V"FUS
M9VED(")#;VUM86YD(@IM<V=S='(@(DMO;65N=&\B"@HC.B!A9&UI;B]C;61S
M:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B2V]M
M96YT;W1U;&MK:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R(")+;VUM96YT=&DB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B0V]M
M;6]N($YA;64B"FUS9W-T<B`B66QE:6YE;B!N:6UI(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S`*
M;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B2V]M;W)I="(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A
M;GDB"FUS9W-T<B`B67)I='ES(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B5&EE=&]K;VYE970B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@V"FUS9VED(")#;VYD
M:71I;VXB"FUS9W-T<B`B3VQO<W5H9&4B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(U-@IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R(")/;&]S=6AT965T
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R
M871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B07-E='5K<VEE;B!E<F]T(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-@IM<V=I9"`B0V]N9FEG=7)A
M=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/
M=71L;V]K+B(*;7-G<W1R(")!<V5T=6MS970@4$1!+6QA:71T96ED96XL(.1L
M>7!U:&5L:6UI96X@:F$@3W5T;&]O:VEN('-Y;FMR;VYO:71I:6XN(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM<V=I9"`B0V]N9FEG=7)A=&EO
M;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B07-E='5K<VEA('!I=.3D('#D
M:79I='3DY"XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R(")!<V5T82!A
M<V5T=6MS970@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(E9A:'9I
M<W1A(&MI<FIO:71T86UA;&QA('-A;&%S86YA('5U9&5S=&%A;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-34*;7-G:60@(D-O;F=O(@IM<V=S='(@(DMO;F=O(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M,PIM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H
M92(*;7-G<W1R(")+;VYG;VX@9&5M;VMR86%T=&EN96X@=&%S879A;'1A(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DX"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.0IM<V=I
M9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@(EEH=&5Y<R!E<.1O;FYI
M<W1U:2XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HQ.3@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S`Y"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(EEH=&5Y
M<R!E<.1O;FYI<W1U:3H@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-SDP"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U
M8FQI8R!K97ES97)V97(N(@IM<V=S='(@(EEH=&5Y<R!J=6QK:7-T96X@879A
M:6YT96X@<&%L=F5L:6UE;&QE(&5PY&]N;FES='5I+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N
M(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R(")9:'1E>7,@:G5L:VES=&5N(&%V
M86EN=&5N('!A;'9E;&EM96QL92!E<.1O;FYI<W1U:2X@5FER:&4Z("5S("@E
M<RDB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@W-@IM<V=I9"`B
M0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B66AT
M97ES(&9T<"UP86QV96QI;65L;&4@97#D;VYN:7-T=6DN(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T
M.C$P-C<*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@(EEH=&5Y<W1I961O="(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM
M<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U
M<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(EEH=&5Y<W1I961O="!L:7/D='1I
M:6X@;W-O:71E:VER:F%A<VDN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HV,`IM<V=I9"`B0V]N=&5N="!T>7!E(&]F(&-O;7!R
M97-S960@9FEL93H@(@IM<V=S='(@(E1I:79I<W1E='EN('1I961O<W1O;B!T
M>7EP<&DZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HU-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<U"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(EPB
M)7-<(CIN('-I<^1L=/8B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z,S,@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD*;7-G:60@(D-O
M;G1I;G5E(@IM<V=S='(@(DIA=&MA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU.`IM<V=I9"`B0V]O
M:R!)<VQA;F1S(@IM<V=S='(@(D-O;VL@<V%A<F5T(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#;V]K:64B"FUS9W-T<B`B17;D<W1E
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@(DMO<&EO:2(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#<R"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R(")+;W!I;VEN=&D@97#D;VYN
M:7-T=6DZ("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B2V]P
M:6]I('9A;&EN=&$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$W,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R(")#;W-T($E$(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV,PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R(")#;W-T82!2:6-A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU-PIM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R(").
M;W)S=6YL=75R86YN:6MK;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A
M9V4Z("(*;7-G<W1R(")6:65S=&EN(%!'4"US86QA=7-T82!E:2!V;VET=2!T
M96ADY#H@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`U
M-0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z("(*;7-G<W1R
M(")6:65S=&EI;B!E:2!V;VET=2!M=6]D;W-T86$@4$=0+6%L;&5K:7)J;VET
M=7-T83H@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS
M.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*
M;7-G<W1R(")6:65S=&EN(%,O34E-12US86QA=7-T82!E:2!V;VET=2!T96AD
MY"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM
M<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@
M(E9I97-T:6EN(&5I('9O:71U(&UU;V1O<W1A82!3+TU)344M86QL96MI<FIO
M:71U<W1A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A
M9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B16D@=F]I='4@;W1T86$@>6AT97ET
M=.0N("5S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.CDV
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HT-3<*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$
M05`@<V5R=F5R+B(*;7-G<W1R("),9&%P+7!A;'9E;&EM965N(&5I('-A871U
M(&%U=&]R:7-O:71U82!Y:'1E>71TY"XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@
M(D5I('9O:71U('1A<FMI<W1A82!S86QD;V$N("5S(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C0T,0IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@
M3$1!4"!S97)V97(N(@IM<V=S='(@(DQ$05`M<&%L=F5L:6UE96X@96D@<V%A
M='4@>6AT97ET=.0N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E
M<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R(")%:2!V;VET=2!O='1A
M82!Y:'1E>71TY"!P86QV96QI;65E;B!<(B5S7"(@:^1Y='3D96X@1E10.B`E
M<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(D5I('9O:71U(&QU;V1A
M(&IA:V5L=6QI<W1A82X@)7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,3(X"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T
M83H@(@IM<V=S='(@(E!'4"US86QA='1U82!T:65T;V$@96D@=F]I='4@875K
M86ES=&$Z("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3(S"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS
M9W-T<B`B4R]-24U%+7-A;&%T='5A('1I971O82!E:2!V;VET=2!A=6MA:7-T
M82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E
M(&-O;G1A8W0N("5S(@IM<V=S='(@(D5I('9O:71U('!O:7-T86$@>6AT97ES
M=&EE=&]A+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(D5I('9O
M:71U('!O:7-T86$@:F%K96QU;&ES=&%A+B`E<R(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R
M(")%:2!V;VET=2!P;VES=&%A('#D:79I='ES<VMR:7!T:>0@7"(E<UPB+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U;&0@;F]T
M(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM
M<V=S='(@(E9I97-T:6X@;.1H971TY&KD;B!SY&AK]G!O<W1I;W-O:71E='1A
M(&5I('!Y<W1Y='1Y(&WDY')I='1E;&5MY.1N+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L
M9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R(")%
M:2!V;VET=2!H86ME82!K;VMO(&]S;VET96MI<FIA82XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B
M0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*
M;7-G<W1R(")%:2!V;VET=2!H86ME82!K;VMO(&IA:V5L=6QI<W1A82XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T
M-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F
M(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B16D@=F]I='4@:&%K96$@
M:V]K;R!L:7-T86$@:F%K96QU;&ES=&]I<W1A+B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z
M.#0*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R(")%:2!V;VET
M=2!L=6ME82!S=')A=&5G:6%A(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C
M="YP:'`Z,S`*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R(")+;VUE
M;G1O(&UK9&ER(%PB)7-<(B!E<.1O;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A
M:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(DIU
M;&MI<W1E;B!A=F%I;G1E;B!P86QV96QI;65L=&$@96D@<V%A='4@:G5L:VES
M=&$@879A:6YT82XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN
M9RXB"FUS9W-T<B`B5&EE9&]S=&]O;B!<(B5S7"(@96D@=F]I(&MI<FIO:71T
M86$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N
M("5S+B(*;7-G<W1R(")%:2!V;VET=2!A=6MA:7-T82`E<RXB"@HC.B!F<F%M
M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0R,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K
M(&UO9'5L92`E<R(*;7-G<W1R(")9;&SD<&ET;VUO9'5U;&EN("5S(&%U:V%I
M<W4@97#D;VYN:7-T=6DB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<
M(BXB"FUS9W-T<B`B16D@=F]I(&%U:V%I<W1A(&AA:V5M:7-T;V$@7"(E<UPB
M+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0IM<V=I9"`B0V]U;&0@;F]T(')E
M86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3$1!4"UP86QV96QI;65L
M=&$@96D@;VQE(&UA:&1O;&QI<W1A(&5T<VGD+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+T]B:F5C="YP:'`Z,C0P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R96%D("5S+B(*;7-G<W1R("(E<SKDY"!E:2!V;VET=2!L=6ME
M82XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B
M(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E
M<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@
M;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@
M(B(*(DOD>71TY&KD;B!S86QA<V%N86$@96D@=F]I='4@;F]L;&%T82X@2F]T
M:W5T('1A<G9I='1A=F%T('1I961O="!O=F%T(';DY')I;BX@(@HB67)I=.0@
M=75D97-T86%N('1A:2!O=&$@>6AT97ET=.0@>6QLY'!I=&]O;B!J;W,@=&%R
M=FET<V5T(&QI<^3D(&%P=6$N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S`X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,S.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-S8*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S@R"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,X.`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G
M<W1R(")%:2!V;VET=2!H86ME82!!0TPM=&EE=&]J82(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN
M("5S(@IM<V=S='(@(D5I('9O:71U(&AA:V5A(&]S;VET96MI<FIA82X@)7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(D5I('9O:71U(&AA:V5A
M(&IA:V5L=6QI<W1A82X@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G
M<W1R(")%:2!V;VET=2!H86ME82!J86ME;'5L:7-T;VIA+B`E<R(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.`HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3@*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(R"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@
M(D5I('9O:71U(&AA:V5A('1I971O:F$@<&%L=F5L:6UE;B!T;VEM:6YN;VES
M=&$B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L
M9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D5I('9O:71U
M('!A;&%U='1A82!A<V5T=6MS:6$N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N
M(@IM<V=S='(@(DMO;65N=&\@<FUD:7(@7"(E<UPB(&5PY&]N;FES='5I+B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(D5I('9O:71U('1A;&QE='1A82`E<R!A<V5T=6MS:6$N(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C8S"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I
M;VXN(@IM<V=S='(@(D5I('9O:71U('1A;&QE='1A82!A<V5T=7-T96X@=F%R
M;75U<VMO<&EO=&$N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O
M;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B16D@=F]I='4@=&%L;&5T=&%A(&%S
M971U<W1E;B!V87)M=75S:V]P:6]T82`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S
M879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@
M(D5I('9O:71U('1A;&QE='1A82!A<V5T=7-PY&EV:71Y<W-K<FEP=&GD.B!<
M(B5S7"(N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I
M9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B16D@=F]I='4@=&%L;&5T=&%A
M(&%S971U<W1E;B!V87)M=75S:V]P:6]T82`E<RXB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD
M(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@
M96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@
M8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L
M;W<@=&\@)7,N(@IM<V=S='(@(B(*(D%S971U<W1I961O<W1O;B`E<R!T86QL
M971U<R!E<.1O;FYI<W1U:2X@5F]I="!KY'ET=.3D(&IO=&%K:6X@87-E='5S
M=&$@(@HB=&%L;&5T=&%A:W-E<VD@:V]O9&EN('1A:V%I<VEN("5S('1A:2!T
M86D@:V]P:6]I9&$@:^1S:6X@86QL82!O;&5V86X@:V]O9&EN("(*(G1I961O
M<W1O;VX@)7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ
M-#,*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*
M;7-G<W1R("),1$%0+7!A;'9E;&EM96QT82!E:2!O;&4@;6%H9&]L;&ES=&$@
M971S:>0N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R(")+;VUE
M;G1O('5N;&EN:R!<(B5S7"(@97#D;VYN:7-T=6DN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G
M<W1R(")%:2!V;VET=2!PY&EV:71TY.0@>6AT97ES=&EE=&]J82X@)7,B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")%:2!V;VET=2!PY&EV:71TY.0@
M:F%K96QU;&ES=&%A+B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG
M=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R(")6:65S=&5JY"!E:2!V
M;VET=2!P;VES=&%A(&MA;G-I;W-T82!<(B5S7"(Z("5S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,W,`IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@
M36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E
M;BXB"FUS9W-T<B`B36]Z:6QL82!3:61E8F%R(&5I(&SV>71Y;GET+B!687)M
M:7-T82!E='3D(%-I9&5B87(@;W-I;R!O;B!A=6MI+B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL
M;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B(@HB2^1Y='3D:N1L;&4@7"(E<UPB(&5I('9O:71U(&%N=&%A('-E=7)A
M879I82!O:6ME=7-I82!K86YS:6]O;B!<(B5S7"(Z("5S(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30R,PIM<V=I9"`B0V]U;G1E9"!T97AT(@IM
M<V=S='(@(DQA<VME='1U('1E:W-T:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(DUA
M82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S4*;7-G:60@(D-O
M=7)S97,B"FUS9W-T<B`B2W5R<W-I="(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E
M871E(@IM<V=S='(@(DQU;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN
M:R(*;7-G<W1R("),=6\@=75S:2!L:6YK:VDB"@HC.B!T96UP;&%T97,O<')E
M9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS9VED(")#<F5A=&4@82!N97<@
M;VYE(@IM<V=S='(@(DQU;R!U=7-I(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-3(*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*
M;7-G<W1R(")6;VD@;'5O9&$@=75S:6$@:V%N<VEO:71A(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B3VEK975D970@=&5K:6KD;&SD(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(Q-@IM<V=I9"`B0W)E9&ET(&-A<F0@
M;G5M8F5R(@IM<V=S='(@(DQU;W1T;VMO<G1I;FYU;65R;R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(DMR;V%T:6$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8T"FUS9VED(")#=6)A(@IM<V=S='(@(DMU=6)A(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@
M(E3D;>1N:&5T:VEN96X@-"!V86EH971T82(*"B,Z(&%D;6EN+W-E<W-I;VYS
M+G!H<#HU,`IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R(")4Y&WD
M;FAE=&MI<V5T(&ES='5N;F]T(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@
M;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS
M9W-T<B`B2V5L;&]N86EK82!TY&QLY"!H971K96QLY"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I
M9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B5.1MY&YH971K:6YE;B!54DP@
M;VXB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*;7-G:60@(D-U<G)E;G0@
M57-E<G,B"FUS9W-T<B`B5.1MY&YH971K:7-E="!KY'ET=.1JY'0B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED(")#=7)R96YT(%=E871H97(B
M"FUS9W-T<B`B5.1MY&YH971K:6YE;B!SY.0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C8T"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@
M(@IM<V=S='(@(E3D;>1N:&5T:VEN96X@=&EL83H@(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N
M="!S='EL92(*;7-G<W1R(")4Y&WD;FAE=&MI;F5N('1Y>6QI(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S
M='(@(B(*(E9O:70@;75O:V%T82!T96ATY'9IY"P@:F]T:V$@<W5O<FET971A
M86X@:W5N(&MI<FIA=61U=&%A;B!S:7/DY&X@;VAJ96QM86%N("4B"B)S+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(DQE:6MK86$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED(")#
M=70@<V5L96-T:6]N(@IM<V=S='(@(DQE:6MK86$@=F%L:71T=2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C<*;7-G:60@(D-Y<')U<R(*;7-G<W1R(")+>7!R;W,B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB
M"FUS9W-T<B`B2WER:6QL:6YE;B`H2T])."U2*2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@V"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*
M;7-G<W1R(")+>7)I;&QI;F5N("A7:6YD;W=S+3$R-3$I(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H
M2T])."U5*2(*;7-G<W1R(")+>7)I;&QI;F5N+U5K<F%I;F$@*$M/23@M52DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8X"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R(")4
M<V5K:6X@=&%S879A;'1A(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0U,B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I
M9"`B1$0B"FUS9W-T<B`B4%`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,C<V"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T
M+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I
M(@IM<V=S='(@(B(*(D133B`H;&ESY'1I971O82!H='1P.B\O<&5A<BYP:'`N
M;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BXB
M"B)P:'`I(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E
M+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B4.1I=FET=.1I;B(*"B,Z
M(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O=W-E
M<B(*;7-G<W1R(")$871A5')E92US96QA:6XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,C<T"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T
M<B`B5&EE=&]K86YT86AA:W4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T
M,#(*;7-G:60@(D1A=&4B"FUS9W-T<B`B4.1I=N1Y<R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I
M=F5D(@IM<V=S='(@(E#D:7;D;>3D<N0@=F%S=&%A;F]T971T=2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.3,*;7-G:60@(D1A=&4@<V5L96-T
M:6]N(@IM<V=S='(@(E#D:7;D;>3D<N1N('9A;&EN=&$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,3$*;7-G:60@(D1A>2(*;7-G<W1R(")0Y&EVY"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M-@IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B4&]?:7-T82!S87)A
M:V4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-3$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B:F]U;'5K=74B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V
M"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B1&5S:6UA86QI;G5M
M97)O="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R(")0:65N96YN
MY"!S:7-E;FYY<W3D(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*;7-G:60@(D1E9F%U;'0B"FUS9W-T
M<B`B3VQE='5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-S<*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B3VQE
M='5S=N1R:2(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z
M.38*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B3VQE='5S<')O
M9FEI;&DB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*;7-G:60@(D1E
M9F%U;'0@4VAE;&PB"FUS9W-T<B`B3VQE='5S(&MO;65N=&]T=6QK:VDB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS
M(@IM<V=S='(@(DWDY')I=&5L;>1T(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O9&5L971E+FEN8SHQ,`IM<V=I9"`B1&5L971E(@IM<V=S='(@(E!O
M:7-T82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS,@IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`B4&]I
M<W1A('-O;'4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U
M<',N<&AP.C(R-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(E!O:7-T
M82!R>6AMY"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0IM
M<V=I9"`B1&5L971E($QO9R(*;7-G<W1R(")0;VES=&$@;&]K:2(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM
M<V=S='(@(E!O:7-T82!O:6ME=7,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M
M97-S86=E<R(*;7-G<W1R(")6;VD@<&]I<W1A82!J82!T=6AO=&$@<&]I<W1E
M='1U:F$@=FEE<W1E:N0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE=&4@8V5L;"(*;7-G
M<W1R(")0;VES=&$@<V]L=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB
M"FUS9W-T<B`B4&]I<W1A('-A<F%K92(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L
M871E(@IM<V=S='(@(E!O:7-T82!O;&5M87-S82!O;&5V870@=F%I:'1O96AT
M;VEN96X@;6%L;&DB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T
M,S$T+G!H<#HU-`IM<V=I9"`B1&5L971E(&UE<W-A9V5S(@IM<V=S='(@(E9O
M:2!P;VES=&%A('9I97-T96KD(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI
M<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B4&]I<W1A(%PB)7-<(CIN(&]I
M:V5U:W-I82(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(T
M"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@
M7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R(")/;&5T
M:V\@=F%R;6$L(&5T=.0@:&%L=6%T('!O:7-T86$@7"(E<UPB(&IA(&MA:6MK
M:2!S96X@86QI;VEK975D970_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O=R(*
M;7-G<W1R(")0;VES=&$@<FEV:2(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE
M=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N
M=&ET>2(*;7-G<W1R(")0;VES=&$@=F%L:71T=2!P<F]F:6EL:2(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4S"FUS9VED(")$
M96QE=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B5F]I(&QU;V1A('5U<VEA(&MA
M;G-I;VET82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O
M;'5M;B(*;7-G<W1R(")0;VES=&$@=F%L:71T=2!S87)A:V4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*
M;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B4&]I<W1A
M('9A;&ET='4@<FEV:2(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V
M"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")0;VES=&5T='4@<.1I=FET>7-S:W)I
M<'1I(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C4S"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"FUS9VED(")$96QI=F5R>2!T
M:6UE(@IM<V=S='(@(E1O:6UI='5S86EK82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$*;7-G:60@
M(D1E;FUA<FLB"FUS9W-T<B`B5&%N<VMA(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M
M(@IM<V=S='(@(D]N9V5L;6%N(&MU=F%U<R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.CDT,B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")+
M=79A=7,B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-PIM<V=I
M9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R
M(")487)K96UM870@=&EE9&]T("AL]GET>7;D="!M>?9S($AO<F1E.FX@;&]K
M:71I961O<W1O<W1A*3HB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C(P,0IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@
M861M:6YI<W1R871O<BXB"FUS9W-T<B`B5&%R:V5M;6%T('1I961O="!O;B!T
M86QL971E='1U('EL;.1P:61O;B!KY'-I=&5L=.1VY&MS:2XB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(Q"FUS9VED(")$979E;&]P;65N="(*
M;7-G<W1R(")+96AI='ES(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C0*
M;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R(")+;W-T975S<&ES=&4B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,P,0IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L
M87-T(&AO=7(Z("(*;7-G<W1R(")%9&5L;&ES96X@='5N;FEN(&MO<W1E=7-P
M:7-T93H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-@IM
M<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B2V]S=&5U<W!I<W1E.B`B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS
M9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R(")3=75N=&$@
M=F%S96UM86QT82!O:6ME86QL92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T
M;R!L969T(@IM<V=S='(@(E-U=6YT82!O:6ME86QT82!V87-E;6UA;&QE(@H*
M(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*
M;7-G<W1R(")(86ME;6ES=&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C<P"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(DOD
M>73D(#(T+71U;FYI;B!A:6MA97-I='ES=.0N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@
M(D[D:WEMY&X@87-E='5K<V5T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C@Y"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM
M<V=S='(@(D5S:71Y<W1A<&$@>6MS:71Y:7-K;VAT86EN96X@96YN=7-T92(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.3(*;7-G:60@(D1I<W!L87D@9F]R
M96-A<W0@*%1!1BDB"FUS9W-T<B`B17-I='ES=&%P82!E;FYU<W1E96QL92`H
M5$%&*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#,*;7-G:60@
M(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(D5S:71Y<W1A<&$B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DQ"FUS9VED(")$:7-P;W-I=&EO
M;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B4&5R:6QL96UE;F]I;&UO:71U<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S`*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(D1J:6)O=71I
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*;7-G:60@
M(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B16D@<V%A('!O:7-T86$B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E
M8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(L1LY"!KY'ET
MY"!S=6]R86%N(&UA:6YT96YA;F-E+G!H<#ITY"(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C$R('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C$R"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE
M;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(DIO
M<R!E;G-I;6WD:6YE;B!R:79I('-I<^1L=.3D('-A<F%K:V5I9&5N(&]T<VEK
M;W0L(&YI:6X@=F%L:71S93HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R"FUS9VED(")$;VUI;FEC
M82(*;7-G<W1R(")$;VUI;FEK86%N:6YE;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S,*;7-G:60@
M(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R(")$;VUI;FEK86%N:6YE;B!T
M87-A=F%L=&$B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS
M9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@
M(D5I:_8@;VQE(&OD>71TY&KD='5N;G5S=&$_($MI<FIA=61U(&OD>71TY&KD
M:W-I+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@U
M,0IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B5&%L;&5N;F$B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-3$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B5&%L;&5N;F$@)7,B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R
M(")486QL96YN82!L=6]T=2!A<V5T=7,@4$A0+7-K<FEP=&ENY"XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$Q"FUS9VED(")$<F]P(&1O=VX@
M;&ES="(*;7-G<W1R(")!;&%S=F5T;W9A;&EK:V\B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(DAU=6UE970B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@
M(D4M36%I;"(*;7-G<W1R(")3Y&AK]G!O<W1I;W-O:71E(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-
M86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H
M('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B"B)%36%I;"UT;RU3
M35,@9V%T97=A>2!A:G5R:2P@;FEI;&QE('!A;'9E;'5N=&%R:F]A:FEL;&4L
M(&IO=&MA('1A<FIO879A="!TY'3D("(*(G!A;'9E;'5A+B(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R(")625)(12(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S4*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B16-U861O<B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHW,@IM<V=I9"`B161I="(*;7-G<W1R(")-=6]K:V%A
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU,`IM<V=I9"`B
M161I="!";&]C:R(*;7-G<W1R(")-=6]K:V%A(&]S:6]T82(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%
M9&ET($=R;W5P(@IM<V=S='(@(DUU;VMK86$@<GEH;>3D(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$P,`IM<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@
M(DUU;VMK86$@;VEK975T=&$B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP
M:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(DUU;VMK
M86$@;VEK975K<VEA(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E
M<R(*;7-G<W1R(")-=6]K:V%A("<E<R<Z;B!O:6ME=6MS:6$B"@HC.B!T96UP
M;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R
M.B(*;7-G<W1R(")-=6]K:V%A(&%S971U:W-I83HB"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%
M9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B375O:VMA82!<
M(B5S7"(Z;B!O:6ME=6MS:6$B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@
M9F]R("5S(@IM<V=S='(@(DUU;VMK86$@)7,Z;B!O:6ME=6MS:6$B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G
M<W1R(")+;W5L=71U<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<*;7-G:60@(D5G>7!T(@IM<V=S
M='(@(D5G>7!T:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-PIM<V=I9"`B16P@4V%L=F%D;W(B
M"FUS9W-T<B`B16P@4V%L=F%D;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N
M+BXB"FUS9W-T<B`B16QE;65N='1I+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@
M(D5M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S"FUS9VED(")%;6%I
M;"(*;7-G<W1R(")3Y&AK]G!O<W1I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-C8@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHV.`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$P
M"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(E/D:&OV<&]S=&EO<V]I
M=&4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38W"FUS9VED(")%
M;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`B4^1H:_9P;W-T
M:6]S;VET=&5I9&5N('!I=.3D(&]L;&$@<V%M870N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DY,PIM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M
M871I;VXB"FUS9W-T<B`B4^1H:_9P;W-T:2!V87)M:7-T=6MS96QL82(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS
M9VED(")%;6%I;"UT;RU335,@1V%T97=A>2(*;7-G<W1R(")%;6%I;"UT;RU3
M35,@1V%T97=A>2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR.3D*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R(")(>6UI]G0B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(E1Y:&KD('9I
M97-T:2XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@(E1Y:&KD
M('9A<W1A=7,N(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP
M.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(E1Y:&KD
M(&AA:W5T97)M:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#<*;7-G
M:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L
M;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(E-A;&QI(&MU=FEE;B!L86ET=&%M
M:6YE;B!K=79A9V%L;&5R:6%S=&$@=&5K<W1I;B!J;W5K:V]O;BXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(R"FUS9VED(")%;F%B;&4@<FEG:'0@
M8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R("),86ET82!PY.1L;&4@;VEK
M96%N('!A:6YI:VME96X@:V]N=&5K<W1I;65N=2XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-3DR(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W
M.3<*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(E#DY'1T>6UI<W9U;W-I(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM
M<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`B4W5U<F5N;F$@961I=&]R
M:6$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(T"FUS9VED("(B"B)%
M;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S
M:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N
M9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B
M(@HB06YN82!K>7-Y;7ES(&IO:V$@:WES>73DY&XL(&IO<R!S86QA<V%N87-I
M(&IO=61U=&%A;B!N;VQL86%M86%N(&5S:6UE<FMI:W-I("(*(B=M:6OD(&]N
M(&QE;6UI:VMI<VD@;FEM:3\G.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@
M=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(DQA:71A(&MU=F$@55),('3D
M:.1N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@Y,@IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@
M(D%N;F$@:VER:F%I;65T(&%L;&4Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY.0IM<V=I9"`B17%U
M871O<FEA;"!'=6EN96$B"FUS9W-T<B`B16MV871O<FEA86QI;F5N($=U:6YE
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-SD*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B17)I=')E
M82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]6:65W+G!H<#HY-"!L:6(O0FQO8VLO;65T87(N<&AP.C,V"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT.`IM<V=I9"`B17)R;W(B
M"FUS9W-T<B`B5FER:&4B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA
M=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN
M9R!B;&]C:SH@)7,B"FUS9W-T<B`B5FER:&4@<.1I=FET971TY&5S<^0@;W-I
M;W1A.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R
M.B`E<R(*;7-G<W1R(")6:7)H92!PY&EV:71E='3D97-SY"!S>6YC(&%N8VAO
M<B`M=&EE=&]A.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C@S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@
M;&]G.B`E<R(*;7-G<W1R(")6:7)H92!P;VES=&5T=&%E<W-A('-Y;F,@;&]K
M:6$Z("5S(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT
M.B`E<R(*;7-G<W1R(")6:7)H92!H865T=&%E<W-A('-I<^1L=/;D.B`E<RXB
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S
M='(@(E9I<FAE('#D:79I=&5T=.1E<W/D('-A;&%S86YA83H@)7,B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*
M;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B5FER
M:&4@<^1H:_9P;W-T:79I97-T:7-SY"XB"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB
M+B(*;7-G<W1R(")6:7)H92!K:7)J;VET971T865S<V$@7"(E<UPB+B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S8*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B165S=&DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R(")%=&EO<&EA(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T
M<B`B171N:6YE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(D5U<F]O<'!A(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T,PIM<V=I9"`B179E<GD@,34@;6EN=71E<R(*
M;7-G<W1R("(Q-2!M:6YU=71I;B!VY&QE:6XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,SDS"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B
M,B!M:6YU=71I;B!VY&QE:6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(D5V97)Y(#,P
M('-E8V]N9',B"FUS9W-T<B`B,S`@<V5K=6YN:6X@=N1L96EN(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,T,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,SDT"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B-2!M:6YU=71I
M;B!VY&QE:6XB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R(")*;VMA:7-E
M;&QA('-I<^3D;FMI<FIA=71U;6ES96QL82(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-#0*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")0
M=6]L96X@='5N;FEN(';D;&5I;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,@IM<V=I9"`B179E<GD@
M;6EN=71E(@IM<V=S='(@(DUI;G5U=&EN(';D;&5I;B(*"B,Z('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB
M"FUS9W-T<B`B17-I;65R:VMI87)V;W0Z(@H*(SH@861M:6XO8VUD<VAE;&PN
M<&AP.C4Q(&%D;6EN+W!H<'-H96QL+G!H<#HX,B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3(X"FUS9VED(")%>&5C=71E(@IM<V=S='(@(E-U;W)I=&$B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q-`IM
M<V=I9"`B17AP86YD(@IM<V=S='(@(DQA86IE;FYA(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]S:61E8F%R+FEN8SHS,@IM<V=I9"`B17AP86YD(%-I9&5B87(B
M"FUS9W-T<B`B3&%A:F5N;F$@<VEV=79A;&EK:V\B"@HC.B!F<F%M97=O<FLO
M4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B
M"FUS9W-T<B`B3V1O=&5T=&EI;B!M97)K:VGD("<I)R(*"B,Z(&9R86UE=V]R
M:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A
M<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B4V%N82!S
M96QL86ES96YA86X@=&%I(&AA:W5T97)M:2!L86EN875S;65R:V5I<W/D(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%
M>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B3&]P<'5PY&EVY&WDY'+D(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S<*;7-G:60@(D5X
M<&]N96YT(@IM<V=S='(@(D5K<W!O;F5N='1I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@
M0V]L;W(B"FUS9W-T<B`B1D<@=N1R:2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-S<*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B
M07-E='5S=&EE9&]S=&]J96X@='5O;G1I($944#IL;.0B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR,C4*;7-G:60@(D9A:6QE9"!R971R
M:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R(")!<V5T=7-T96X@:&%K=2!E
M<.1O;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B
M1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(EEH
M=&5Y<R!,1$%0+7!A;'9E;&EM965N(&5PY&]N;FES='5I+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O
M;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B66AT97ES(%--0BUP86QV
M96QI;65E;B!E<.1O;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P
M>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B2V]P:6]I;G1I(%PB)7-<(CIL=.0@
M97#D;VYN:7-T=6DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW
M,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E
M<UPB+B(*;7-G<W1R(")+;W!I;VEN=&D@7"(E<UPB.FQL92!E<.1O;FYI<W1U
M:2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"FUS9VED
M(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S
M='(@(E5U9&5N(%-!4TPM>6AT97ED96X@;'5O;6EN96X@97#D;VYN:7-T=6DN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-34@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HU,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R(")3:6ER=&\@7"(E<UPB
M.N3D;B!E<.1O;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C0V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE
M=F4Z("5S(@IM<V=S='(@(E-I:7)T;R!E<.1O;FYI<W1U:3H@)7,B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B
M1F%I<B(*;7-G<W1R(")+875N:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T"FUS9VED(")&86QK
M;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B1F%L:VQA;F1I;B!S
M86%R970@*$UA;'9I;F%S*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8*;7-G:60@(D9A<F]E($ES
M;&%N9',B"FUS9W-T<B`B1N1R('-A87)E="(*"B,Z(&9R86UE=V]R:R]#3$DO
M0TQ)+G!H<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R(")686MA
M=F$@=FER:&4Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A:W-I(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U,0IM<V=I9"`B1F%X97,B"FUS9W-T
M<B`B1F%K<VET(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(FAE;&UI:W5U(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C<*;7-G:60@(D9E96QS($QI:V4B
M"FUS9W-T<B`B5'5N='5U(&MU:6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C(P"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B5'5N
M='5U(&MU:6XZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R(")-=75T86UI
M82!S871E:71A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B375U
M=&%M:6$@;'5M:7-A=&5I=&$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.30X"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T<B`B2V5N='3D;6%T
M<FEI<VDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(Y"FUS9VED
M(")&:6=L970@0T%05$-(02(*;7-G<W1R(")&:6=L970@0T%05$-(02(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S,*;7-G:60@(D9I9VQE="!F
M;VYT(@IM<V=S='(@(D9I9VQE="!K:7)J87-I;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,*;7-G
M:60@(D9I:FDB"FUS9W-T<B`B1FED>FDB"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR-34*;7-G:60@(D9I;&4B"FUS9W-T<B`B5&EE9&]S=&\B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(E1I961O<W1O
M:F5N(&QU:W5MY.1RY#H@)7,@=&EE9&]S=&\B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HV-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT
M.B`E<R!F:6QE<R(*;7-G<W1R(")4:65D;W-T;VIE;B!L=6MU;>3D<N0Z("5S
M('1I961O<W1O82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#D*
M;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R(")4:65D;W-T;VIE;B!KY'-I
M='1E;'DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,`IM<V=I9"`B
M1FEL92!.86UE(@IM<V=S='(@(E1I961O<W1O;B!N:6UI(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,CDX,0IM<V=I9"`B1FEL92!S96QE8W1I;VXB
M"FUS9W-T<B`B5&EE9&]S=&]N('9A;&EN=&$B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#DP"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R(")4
M:65D;W-T;VX@='5O;G1I(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.3`R"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB
M"FUS9W-T<B`B5&EE9&]S=&]J96X@='5O;G1I(&5I(&]L92!KY'ET971TY'9I
M<W/D+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY,0IM<V=I9"`B
M1FEL=&5R<R(*;7-G<W1R(")3=6]D871T:6UE="(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(*;7-G
M:60@(D9I;FQA;F0B"FUS9W-T<B`B4W5O;6DB"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,38V"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(D5N<VEM;>1I
M;F5N('!U;VQI<VMO(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]"
M;&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R
M(")%;G-I;6WD:6YE;B!N96QJY&YN97,B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4W"FUS9VED(")&:7@@<F%T:6\B"FUS
M9W-T<B`B2V]R:F%A('-U:&1E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(S,@IM<V=I9"`B1FQI<"(*;7-G<W1R(")+Y.1N
M;N0@>6UPY')I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B2V5L;'5V
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q
M"FUS9VED(")&;V<B"FUS9W-T<B`B4W5M=2(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ,#<@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR
M,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X
M:7-T(@IM<V=S='(@(DMA;G-I;W1A("5S(&5I(&]L92!O;&5M87-S82XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS
M9VED(")&;VYT($-O;&]R(@IM<V=S='(@(DMI<FIA<VEM96X@=N1R:2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R
M(")2=6]K82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@
M9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B4V5L86EM:6QL92P@:F]T
M:V$@96EVY'0@='5E(&MU=FEA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-#$*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@(D5N;G5S=&4@*%1!
M1BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S(*;7-G:60@
M(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R
M96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@
M;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS
M9W-T<B`B(@HB16YN=7-T971T879A="!V=6]R;VMA=61E="`H2'5O;6%A=&AA
M;B!E='3D(&5N;G5S='5K<V5S<V$@;VX@=&EE9&]T('-E:^0@(@HB<.1I=FES
M=.0@971TY"#V:7-TY"P@:F]T96X@<W5U<FD@;>3D<N0@<.1I=FGD(&%I:&5U
M='1A82!L:6EA;B!L979EY&X@;W-I;VXI(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*
M;7-G<W1R(")5;F]H9&ET:V\@<V%L87-A;F%S:3\B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#8T"FUS9VED(")&;W)M<R(*;7-G<W1R("),;VUA
M:VME970B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O
M<G1U;F4B"FUS9W-T<B`B36EE=&5L875S92(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(DUI971E
M;&%U<V5E;B!T>7EP<&DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*
M;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(DUI971E;&%U<V5E="(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G
M<W1R(")-:65T96QA=7-E970@,B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT-34*;7-G:60@(D9O<G5M<R(*;7-G<W1R(")&;V]R=6UI="(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3$*;7-G:60@(D9O<G=A<F1S
M(@IM<V=S='(@(E5U9&5L;&5E;F]H:F%U:W-E="(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S
M='(@(G!E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@(DME:'EK<V5T
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX-PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(E)A;G-K82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A
M;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B4F%N<VMA+"!-971R;W!O;&DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDQ"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(E)A
M;G-K86X@1W5Y86YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0*;7-G:60@(D9R96YC:"!0;VQY
M;F5S:6$B"FUS9W-T<B`B4F%N<VMA;B!0;VQY;F5S:6$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C(*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R
M(")286YS:V%N(&5T96SD:7-E="!T97)R:71O<FEO="(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB
M"FUS9W-T<B`B3.1H971TY&KD(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(S-R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0Y"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.34*;7-G:60@(D9R;VT@
M=&AE("(*;7-G<W1R(")3=75N;F%S=&$@(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z-#@*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS
M9W-T<B`B4&ED96UP:2!K=79A=7,Z(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*
M;7-G<W1R(")4Y'ES:6MU=2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV
M,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&
M=6QL($YA;64B"FUS9W-T<B`B2V]K;R!N:6UI(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.`IM<V=I
M9"`B1V%B;VXB"FUS9W-T<B`B1V%B;VXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A
M;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(D=A;&QE<FEA+"!J
M;W-T82!K=79A(&]T971A86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ
M(@IM<V=S='(@(D=A;&QE<FEA.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38*;7-G:60@(D=A;6)I
M82(*;7-G<W1R(")'86UB:6$B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R
M871I;VXB"FUS9W-T<B`B5&5E("5S(&%S971U:W-E="(*"B,Z('1E;7!L871E
M<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@
M0V]D92(*;7-G<W1R(")'96YE<F]I='4@:V]O9&DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP"FUS
M9VED(")'96]R9VEA(@IM<V=S='(@(D=E;W)G:6$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y"FUS
M9VED(")'97)M86YY(@IM<V=S='(@(E-A:W-A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,PIM<V=I
M9"`B1VAA;F$B"FUS9W-T<B`B1VAA;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT"FUS9VED(")'
M:6)R86QT87(B"FUS9W-T<B`B1VEB<F%L=&%R(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S8*;7-G:60@(D=I=F5N($YA;64B"FUS
M9W-T<B`B171U;FEM:2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ-S4@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3`*(SH@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z,3D*;7-G:60@(D=L;V)A;"!/<'1I;VYS(@IM<V=S
M='(@(EEL96ES970@87-E='5K<V5T(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P
M<"YI;F,Z,3<*;7-G:60@(D=O(@IM<V=S='(@(DUE;F4B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R(")']F1E
M;"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,3,Q"FUS9VED(")';V]G;&4@36%P<R(*;7-G<W1R(")';V]G;&4@2V%R=&%T
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE
M(%-E87)C:"(*;7-G<W1R(")';V]G;&4@:&%K=2(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,S@*;7-G:60@(D=R87ES8V%L
M92(*;7-G<W1R(")(87)M86%SY'9Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`*;7-G:60@(D=R
M965C92(*;7-G<W1R(")+<F5I:VMA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#@*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R(")+<F5I
M:VMA("A)4T\M.#@U.2TW*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34*;7-G:60@(D=R965N;&%N
M9"(*;7-G<W1R(")'<O9N;&%N=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y"FUS9VED(")'<F5N
M861A(@IM<V=S='(@(D=R96YA9&$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W
M.0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B4GEH;>1N
M('EL;.1P:71O(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U
M<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R(")2>6AM:65N(&YI
M;65T(&5I=N1T('-A82!O;&QA('1Y:&IIY"(*"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O
M=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*(D=R;W5P7VQD87`Z($5I
M('9O:61A(&QI<^1TY"!KY'ET=.1JY.0@)7,N(%!A;'9E;&EM96X@=FER:&5I
M;&UO:71U<R!O;&DZ("(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L('!H<"UF
M;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O
M=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@16D@=F]I9&$@<.1I=N1T=.3D
M(&OD>71TY&KDY"`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D
M871E(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD87`Z($5I('9O:61A('#D
M:7;D='3DY"!KY'ET=.1JY.0@)7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S
M='(@(E)Y:&WD="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@*;7-G:60@(D=U861E;&]U<&4B"FUS
M9W-T<B`B1W5A9&5L;W5P92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S"FUS9VED(")'=6%M(@IM
M<V=S='(@(D=U86TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,@IM<V=I9"`B1W5A=&5M86QA(@IM
M<V=S='(@(D=U871E;6%L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(D=U97)N<V5Y(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B5FEE<F%I;&EJ86X@;VEK975D970B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#<R"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B5FEE
M<F%S:VER:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDW"FUS9VED(")'=6EN96$B"FUS9W-T<B`B
M1W5I;F5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`T"FUS9VED(")'=6EN96$M0FES<V%U(@IM
M<V=S='(@(D=U:6YE82U":7-S874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4*;7-G:60@(D=U
M>6%N82(*;7-G<W1R(")'=7EA;F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HY-C0*;7-G:60@(DA434PB"FUS9W-T<B`B2%1-3"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G
M:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R(")(5$U,07)E82!P96QK=7)I;6%I
M<V5S=&D@:VEE;'3D>71Y>2!P;VES=&%M87-T82!R:79I;B!V:6EM96ES=.0@
M<V]L=6$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R
M("(B"B)(5$U,07)E82!P96QK=7)I;6%I<V5S=&D@:VEE;'3D>71Y>2!P;VES
M=&%M87-T82!V:6EM96ES=.0@<V%R86ME='1A("(*(G1A=6QU:V]S=&$N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE
M=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R("(B"B)(5$U,07)E
M82!P96QK=7)I;6%I<V5S=&D@:VEE;'3D>71Y>2!P;VES=&%M87-T82!V:6EM
M96ES=.0@<FEV:>0@=&%U;'5K;W-T82XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(DA45%`M875T96YT:6MO:6YT:6$@96D@;/9Y
M='EN>70N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$P"FUS9VED(")(86ET:2(*;7-G<W1R(")(
M86ET:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM
M<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B2&%S:"UA;&=O<FET;6DB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM
M<V=I9"`B2&%Z92(*;7-G<W1R(")5<W9A(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.3(S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,3@*;7-G
M:60@(DAE861E<B(*;7-G<W1R(")/='-A:V4B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM
M<V=S='(@(D]T<V%K92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-PIM<V=I9"`B2&5A<F0@27-L
M86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(DAE87)D(&IA($UC
M1&]N86QD('-A87)E="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(E9O
M:6UA:V%S('5K:V]S;7ER<VMY(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#D*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R(")(97!R
M96$@*$E33RTX.#4Y+3@M22DB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HR
M,B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`B2V]R:V5U<R(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#0@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TAE;'`N<&AP.C$X-@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H
M<#HQ-R!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z-`IM<V=I9"`B2&5L<"(*
M;7-G<W1R(")/:&IE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T
M<B`B07!U82!E9&ET;W)I;B!KY'ET=/;V;B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S-S4*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")/:&IE(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM
M<V=S='(@(E!A;&QO;G!U;VQI<VMO.B(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P"FUS
M9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S
M='(@(E3D<W/D(&]N('1I961O<W1O;B!A;&MU;W-A.B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")(:6=H(@IM
M<V=S='(@(DMO<FME82(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z
M-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0IM<V=I9"`B
M2&]?;64B"FUS9W-T<B`B2V]?=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S"FUS9VED(")(
M;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R(")0>6CD(&ES
M='5I;B`H5F%T:6MA86YI;B!K875P=6YK:79A;'1I;RDB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$U-#$*;7-G:60@(DAO;64B"FUS9W-T<B`B
M2V]T:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(DMO=&EO<V]I=&4B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G:60@(DAO;64@1&ER
M96-T;W)Y(@IM<V=S='(@(DMO=&EH86ME;6ES=&\B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H
M;VYE(@IM<V=S='(@(E!U:&5L:6X@*&MO=&DI(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X"FUS
M9VED(")(;VYD=7)A<R(*;7-G<W1R(")(;VYD=7)A<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M-@IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(DAO;F<@2V]N9R(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-PIM<V=I9"`B2&]R9&4B"FUS9W-T
M<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0U,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!8
M34P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO
M<F1E+TMO;&%B.B!%<.1K96QP;V$@)7,@6$U,+61A=&%A('9I97-T:7-SY"`E
M<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O
M;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@66MS:6OD
MY&X@=FEE<W1I(&5I('9A<W1A82!O8FIE:W1I82`E<R(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z-#0U"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S
M86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!9:'3D:^3D;B!O8FIE:W1I
M82`E<R!E:2!L]GET>6YY="!V:65S=&ES=.0@)7,B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C$R-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G
M<W1R(")(;W)D92]+;VQA8CH@4&]I<W1E='1I:6X@)7,@7"(E<UPB(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO
M;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M
M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(B(*(DAO<F1E+TMO;&%B.B!)
M;G1E9W)A871I;VMO;F4@=F%A=&EI('1O:6UI86MS965N("=D;VUX;6PG(%!(
M4"UL86%J96YN=6MS96XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C4Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE
M('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R
M(")(;W)D92]+;VQA8CH@16D@=F]I9&$@;'5O9&$@=75T=&$@6$U,+7!U=71A
M(&]B:F5K=&EL;&4@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$R-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA
M8CH@16D@=F]I='4@<&]I<W1A82`E<R!<(B5S7"(Z("5S(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HT.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T
M:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!%:2!V
M;VED82!H86ME82!-24U%($E$.N0@;W-I;VQL92!T>7EP<&GD("5S(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DW"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@
M7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@16D@=F]I('-Y:W)O
M;F]I9&$@)7,@7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3,S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z($5I('9O:61A('-Y;FMR;VYO:61A(&IA:V]J83H@)7,B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS
M9W-T<B`B2&]R9&4O2V]L86(Z(%1U;G1E;6%T;VX@:F%K;R!<(B5S7"(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS
M9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B5F%A:V%S=6]R82!SY.1N
M=/8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B5F%A:V%S
M=6]R82!TY'ET92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(E9A86MA
M<W5O<F$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@
M*%!L96%S92!R97!O<G0A*2(*;7-G<W1R(")-:71E;B!T=6QI="!TY&YN93\@
M*%)A<&]R=&]I(&MI:71O<R$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L
M=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B2W5I;FMA
M(&UO;G1A('-A<F%K971T82!H86QU870@>6AD:7-TY.0_(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD
M<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R(")+96YT=&EE;B`H<V%R
M86MK96ED96XI(&QU:W5MY.1RY"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R
M;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")+=6EN:V$@
M;6]N=&$@<FEV:>0@:&%L=6%T('EH9&ES=.3D/R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C,W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D*
M;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(DMO<W1E=7,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X"FUS9VED(")(=6UI9&ET>3H@(@IM
M<V=S='(@(DMO<W1E=7,Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(DAU;6]R:7-T:70B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,3$*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B56YK87)I(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-2!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B24U!
M4"UP;W-T:6QA871I:V]N(&QU;VYT:2!E<.1O;FYI<W1U:3H@)7,B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C(Q-`HC+"!P:'`M9F]R;6%T"FUS9VED("))
M34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("))34%0
M+7!O<W1I;&%A=&EK;VX@<&]I<W1O(&5PY&]N;FES='5I.B`E<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#(@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)U<RYP:'`Z,3<Y"B,L('!H<"UF;W)M870*;7-G:60@(DE-
M05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@
M(DE-05`M<&]S=&EL86%T:6MO;B!K:6EN=&GV;B!L=6]N=&D@97#D;VYN:7-T
M=6DZ("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,R,`IM<V=I
M9"`B25`@061D<F5S<R(*;7-G<W1R("))4"UO<V]I=&4B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DE0+6]S;VET92!E:2!O;&4@:^1Y
M=&5T=.1V:7-SY"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N
M<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#
M2412(&)L;V-K+B(*;7-G<W1R("))4"UO<V]I=&4@96D@;VQE('-A;&QI='5N
M($-)1%(M8FQO:VEN('-I<^1L;.0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N
M('9I;VQA=&EO;BXB"FUS9W-T<B`B25`M<^3D;F[V<W3V;B!R:6MK;VUU<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(DQ?
M86ET82!R:79I(&5N;F5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P"FUS9VED("))8V5L86YD
M(@IM<V=S='(@(DES;&%N=&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S@P"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@(E9A:6X@:6MO;FET(@H*
M(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G
M:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R(")):V]N:70@)7,Z;&QE(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,0IM<V=I9"`B26-O;G,@=VET:"!T
M97AT(@IM<V=S='(@(DEK;VYI="!J82!T96MS=&DB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3DS"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S
M='(@(E!R;V9I:6QI;B!N:6UI.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C4Y.`HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I
M<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A
M(&YE=R!W:6YD;W<N(@IM<V=S='(@(DIO<R!S:79U(&5I(&[D>2!K=6YN;VQL
M82P@;FEI;B!A=6MA:7-E("5S(&5R:6QL:7-E<W/D(&EK:W5N87-S82XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4Y"FUS9VED("(B"B))9B!Y;W4@
M9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@
M>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F
M(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*(DIO<R!E="!NY&4@:6MO
M;F5I=&$@:^1Y='3D97-SY'-I($EN=&5R;F5T($5X<&QO<F5R('-E;&%I;G1A
M+"!N:6EN('-I;G5N("(*(G!I=.3D(&]T=&%A('!O:7,@<.3D;'3D(%!.1R!L
MY'!I;N1K>79Y>7,@<F%S=&ET=&%M86QL82!TY&WD(&QA871I:VMO+B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S(*;7-G
M:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@
M=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P
M;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"B)*;W,@;N1E="!T
MY&WD;B!V:65S=&EN+"!M=71T82!E="!K=79A82P@;FEI;B!T=6]M86%S:2!K
M=79A82!E:2!V;VD@;N1Y='3DY"`B"B)KY'ET=.1MY'-SY'-I('-E;&%I;65S
M<V$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R
M(")+=79I96X@97-I:V%T<V5L=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*
M;7-G<W1R(")+=79A(%523"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),
M.B(*;7-G<W1R(")+=79A(%523#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E
M(&9R;VT@9V%L;&5R>2(*;7-G<W1R(")+=79A(&=A;&QE<FEA<W1A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(DMU
M=F$@9V%L;&5R:6%S=&$Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3<V-0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(DMU=F%N('9I96YT
M:2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B
M"FUS9W-T<B`B2W5V870B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T96UA<"YI;F,Z-R!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN
M8SHW"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G
M<W1R(")4=6]N=&DL(&%S:V5L("5D(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE
M;&0Z("5S(@IM<V=S='(@(E1U;W1U(&ME;G1TY#H@)7,B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z
M(@IM<V=S='(@(E1U;V1U="!K96YTY'0Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S
M97)T(%)O=R!!9G1E<B(*;7-G<W1R("),85]I=&$@<FEV:2!JY&QK965N(@H*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,T"FUS
M9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(E;D
MY'+D('1O:6UI;G1O:V]O9&D@86YN971T=2XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@IM<V=I9"`B26YC;W)R
M96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B2^1Y='3D
M:N1T=6YN=7,@=&%I('-A;&%S86YA(&]N(';DY')I;BXB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S
M97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N
M=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE
M<B!H96QP+B(*;7-G<W1R("(B"B)6Y.1RY"!KY'ET=.1JY'1U;FYU<R!T86D@
M=F%I:'1O96AT;VEN96X@;W-O:71E+B!9<FETY"!U=61E<W1A86X@:F$@;W1A
M("(*(GEH=&5Y='3D('EL;.1P:71O;VX@:F]S('1A<G9I='-E="!L:7/DY"!A
M<'5A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("),:7/DY"!S
M:7-E;FYY<W3D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V"FUS9VED("));F1I82(*;7-G<W1R
M("));G1I82(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C4T
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("));F1I=FED
M=6%L(%5S97)S(@IM<V=S='(@(EEK<VET=.1I<V5T(&OD>71TY&KD="(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q,@IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(DEN9&]N97-I
M82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`B26YF;R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-3D*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@
M(DEN9F]R;6%A=&EO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,Q.0IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB
M"FUS9W-T<B`B5&EE=&]A(&5I(&]L92!E;N3D('-A871A=FEL;&$N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R("),86ET
M82!S7V%R86ME(&KD;&ME96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!)
M;6%G92(*;7-G<W1R("),86ET82!K=79A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE
M(@IM<V=S='(@(DQA:71A('1A=6QU:VMO(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,
M:6YK(@IM<V=S='(@(DQA:71A('=W=RUL:6YK:VDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@
M(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("),86ET82!?<V%R86ME
M(&5N;F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F
M=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("),86ET82!U=7-I('-A<F%K
M92!N>6MY:7-E;B!JY&QK965N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N
M97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B3&%I
M=&$@=75S:2!S87)A:V4@96YN96X@;GEK>6ES=.0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@
M(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S
M='(@(DQA:71A('5U<VD@<FEV:2!N>6MY:7-E;B!JY&QK965N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q
M"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O
M;F4B"FUS9W-T<B`B3&%I=&$@=75S:2!R:79I(&5N;F5N(&YY:WEI<W3D(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U
M<G)E;G0@;F]D92(*;7-G<W1R("),86ET82!K87!P86QE(&YY:WEI<V5N(&YO
M9&5N(&KD;&ME96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P
M:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("),86ET82!K87!P
M86QE(&5N;F5N(&YY:WEI<W3D(&YO9&5A(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS
M9W-T<B`B3&%I=&$@=F%I:'1O96AT;VEN96X@;6%L;&DB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C0R"FUS9VED("));G-E<G0@86X@96UA:6P@861D
M<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R
M9#HB"FUS9W-T<B`B06YN82!SY&AK]G!O<W1I;W-O:71E(&IO:&]N('5U<VD@
M<V%L87-A;F$@;.1H971E=.3D;CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E<G0@8V5L
M;"!A9G1E<B(*;7-G<W1R("),86ET82!S;VQU(&KD;&ME96XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y"FUS
M9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B3&%I=&$@<V]L=2!E
M;FYE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T
M<B`B3&%I=&$@<V]L=2!JY&QK965N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O
M;'5M;B!B969O<F4B"FUS9W-T<B`B3&%I=&$@<V%R86ME(&5N;F5N(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3`*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(DEN
M<V5R="!M97-S86=E<R(*;7-G<W1R(")6;VD@;&%I='1A82!V:65S=&5JY"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R
M("),86ET82!K87!P86QE(&KD;&ME96XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R
M="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(DQA:71A(&MA<'!A;&4@96YN
M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(DQA
M:71A(')I=FD@96YN96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R
M92(*;7-G<W1R("),86ET82!R:79I(&KD;&ME96XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C,S"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N
M<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(D%N;F$@
M=F%A9&ET=&%V82!V87-T875S('1U<G9A:WES>6UY:W-E96XZ(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B
M26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("),:6ETY"]-=6]K:V%A(&MU
M=FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@(DQI:73D
M+TUU;VMK86$@;&EN:VMIY"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E
M9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R
M("(B"B)3:6YU;&QA(&5I(&]L92!T87)P965K<VD@:W)E9&EI='1E:N0@;.1H
M971TY.1K<V5S:2!V:65S=&EN(&IA:V5L=6QI<W1A;&QE+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED
M("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R(")2:6ET=.1MY'1T]FWD
M<W1I(&MR961I:71T96KD(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3`W.0IM<V=I9"`B26YT96=E<B(*;7-G<W1R(")+;VMO;F%I<VQU:W4B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,W"FUS9VED("));G1E9V5R
M(&QI<W0B"FUS9W-T<B`B2V]K;VYA:7-L=6MU;&ES=&$B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@
M(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(D5P
MY&ME;'!O("!51$@@*%5S97(@1&%T82!(96%D97(I+B(*"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$V-PHC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ.30*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C$R"FUS9VED("));G9A;&ED(%I)
M4"!D871A(@IM<V=S='(@(D5PY&ME;'!O82!:25`M=&EE=&]A+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC
M871I;VXN(@IM<V=S='(@(D5PY&ME;'!O(&]H:F5L;6$N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED
M("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R(")%<.1K96QP;R!B871C:"!)
M1"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#DQ(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q-C(*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(S-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S`S"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN
M=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(DSD:&5T971T:6EN(&5P
MY&ME;'!O82!T:65T;V$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED(&1E<W1I;F%T
M:6]N(&%D9')E<W,N(@IM<V=S='(@(D5PY&ME;'!O('9A<W1A86YO='1A:F%N
M(&]S;VET92XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X
M+G!H<#HQ,#D*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP
M:'`Z,3,Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP
M.C(T,0IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R(")%<.1K
M96QP;R!T:65D;W-T;VUU;W1O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$V-0IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T
M<B`B17#D:V5L<&\@;&ES96YS<VEA=F%I;BXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,34Y"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R
M;W9I9&5D+B(*;7-G<W1R(")%<.1K96QP;R!P86EK:V%T:65T;RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*
M;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(D5PY&ME;'!O(&US
M9U]T>7!E("XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?
M:60N(@IM<V=S='(@(D5PY&ME;'!O('1A:2!P=75T='5V82!A<&E?:60N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS
M9W-T<B`B17#D:V5L<&\@=&%I('!U=71T=79A('!A<F%M971R:2XB"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R
M96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(D5PY&ME;'9O="!O:6ME=61E="!Y
M;&5M;>1L;.0@=&%S;VQL82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,38Q"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@
M(D5PY&ME;'!O('!A<FYE<B!I9"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,38S"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS
M9W-T<B`B17#D:V5L<&\@='5O=&5K;V]D:2XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L
M:60@<')O=&]C;VPN(@IM<V=S='(@(D5PY&ME;'!O('!R;W1O:V]L;&$N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY
M,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C<Q(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R
M(")%<.1K96QP;R!V87-T86%N;W1T86IA.B!<(B5S7"(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$P.#`@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HQ,C8S"FUS9VED("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R
M(")%<.1K96QP;R!J86MO+6]B:F5K=&DB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@
M<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(D5PY&ME;'!O(&SD:&1E;W-O:71E
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@
M(D5PY&ME;'!O82!U;FEC;V1E+71I971O82XB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S4Y"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B26YV
M96YT86%R:6\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<X"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(DOD
MY&YNY"!V86QI;G1A(&ODY&YT96ES96MS:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.0IM<V=I
M9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("))<F%N+"!)
M<VQA;6EL86EN96X@=&%S879A;'1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X"FUS9VED("))
M<F%Q(@IM<V=S='(@(DER86LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,*;7-G:60@(DER96QA
M;F0B"FUS9W-T<B`B27)L86YT:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R(")-86XM<V%A
M<FDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B17)I;&QI<VGD
M(%5K:V]S;7ER<VMY:N0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30*;7-G:60@(DES<F%E;"(*
M;7-G<W1R("))<W)A96PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8R-@IM<V=I9"`B27-S=65R(@IM<V=S='(@(DQI:6MK965L;&5L
M87-K:6IA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T<B`B2W5R<VEV;VET=2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R,0IM<V=I9"`B271A;'DB"FUS9W-T<B`B271A;&EA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(S"FUS9VED(")*86UA:6-A(@IM<V=S='(@(DIA;6%I:V$B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I
M9"`B2F%N=6%R>2(*;7-G<W1R(")T86UM:6MU=2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-0IM
M<V=I9"`B2F%P86XB"FUS9W-T<B`B2F%P86YI(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.3`*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS
M9W-T<B`B2F%P86YI("A)4T\M,C`R,BU*4"DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(DIE<G-E
M>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R-`IM<V=I9"`B2F]R9&%N(@IM<V=S='(@(DIO<F1A
M;FEA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B:&5I;N1K=74B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*
M;7-G<W1R(")K97/D:W5U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R
M(")+97-K:73D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S
M='(@(DME<VMI=.0@:V5S:V5L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`IM<V=I9"`B2G5S=&EF>2!&
M=6QL(@IM<V=S='(@(DME<VMI=.0@=.1Y<VEN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*;7-G:60@(DIU
M<W1I9GD@3&5F="(*;7-G<W1R(")+97-K:73D('9A<V5M;6%L;&4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M.0IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R(")+97-K:73D(&]I:V5A
M;&QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@
M(DMA>F%K<W1A;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR-C4*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(E/D
M:6QY=.0@86QK=7!E<N1I;F5N/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-@IM<V=I9"`B2V5N
M>6$B"FUS9W-T<B`B2V5N:6$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR
M8C4N<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(D%U=&5N=&EK;VEN=&D@97#D;VYN:7-T
M=6D@2V5R8F5R;W,M<&%L=F5L:6UE;&QE+B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B2V5R
M;F5L(&%L;VET=&5L:6IA="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(D%V86EM
M96X@;'5O;G1I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B079A:6UE;B!T
M=6YN:7-T92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R(")!=F%I;65N('!I='5U<R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B
M2V5Y(%1Y<&4B"FUS9W-T<B`B079A:6UE;B!T>7EP<&DB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.0IM<V=I9"`B2V5Y(%5S86=E
M(@IM<V=S='(@(D%V86EM96X@:^1Y='3V(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@
M;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(D%V86EN(&]N(&IO
M(&IU;&MI<W1E;B!A=F%I;G1E;B!P86QV96QI;65L;&$B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B3&%P<V5T
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(Y"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R(")+:7)I
M8F%T:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S,@IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@
M4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B2V]R96$L(&1E;6]K<F%A
M='1I;F5N(&MA;G-A;G1A<V%V86QT82`H4&]H:F]I<RU+;W)E82DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S,*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R(")+
M;W)E82P@=&%S879A;'1A("A%=&5LY"U+;W)E82DB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y,0IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@
M(DMO<F5A("A%54,M2U(I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T"FUS9VED(")+=7=A:70B
M"FUS9W-T<B`B2W5W86ET(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W"FUS9VED(")+>7)G>7IS
M=&%N(@IM<V=S='(@(DMI<F=I<W1A;B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R(")!<U]E='1E;'4B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG
M=6%G92(*;7-G<W1R(")+:65L:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-PIM<V=I9"`B3&%O
M(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B3&%O<RP@
M9&5M;VMR86%T=&EN96X@:V%N<V%N=&%S879A;'1A(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(DKD;&MI
M;6WD:6YE;B!P=6]L:7-K;R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW
M-@IM<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B161E;&QI
M;F5N('-A;&%S86YA;G9A:6AT;R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX
M-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*
M;7-G<W1R(")*Y&QK:6UMY&EN96X@;F5L:N1N;F5S(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-3@*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B
M4.1I=FET971T>2!V:6EM96MS:3HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HW,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B
M"FUS9W-T<B`B161E;&QI;F5N('-I<^3D;FMI<FIA=71U;6EN96XZ("5S(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*
M;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`B161E;&QI
M;F5N('-I<^3D;FMI<FIA=71U;6EN96XZ("5S+"`E<R(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.C<Q-`IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B
M"FUS9W-T<B`B161E;&QI;F5N('-I<^3D;FMI<FIA=71U;6EN96XZ($5I(&UI
M;&QO:6YK86%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V"FUS9VED("),871V:6$B"FUS9W-T
M<B`B3&%T=FEA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED
M("),87<B"FUS9W-T<B`B3&%K:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0IM<V=I9"`B3&%Y;W5T(@IM<V=S
M='(@(D%S971T96QU(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E
M<B(*;7-G<W1R(")*Y'3D('1Y:&KD:W-I(&IO<R!E:2!R975N;VIA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,X"FUS9VED("),96)A;F]N(@IM<V=S='(@(DQI8F%N;VXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#`*;7-G:60@(DQE9G0B"FUS9W-T<B`B5F%S96XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3`U"FUS9VED("),969T(&AE861E<B(*;7-G<W1R
M(")687-E;B!O='-A:V4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3`Q"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R(")687-E;B!A<G9O="(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T,PIM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("),97-O=&\B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DQE
M=F5L(@IM<V=S='(@(E1A<V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(*;7-G:60@(DQI8F5R
M:6$B"FUS9W-T<B`B3&EB97)I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-PIM<V=I9"`B3&EB
M>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("),:6)Y82!!<F%B($IA;6%H
M:7)I>6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#`*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS
M9W-T<B`B3&EC:'1E;G-T86EN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T
M<B`B2V5V>71TY"!RY&YTY.0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR-@IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R(")+
M:7)J875D=2!S:7/DY&XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R
M(")+979Y='3D('-A9&5T=&$@86EK86ES:6XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,
M871E(@IM<V=S='(@(DME=GET=.0@<V%D971T82!M>?9H96UM:6XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B
M3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B2V5V>6ETY"!S861E:W5U<F]J
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P
M"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R(")+979Y
M='3D('-A9&5T=&$@:F$@;7ER<VMY:7-TY"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM
M<V=S='(@(DME=GET=.0@;'5M:7-A9&5T=&$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO=R!3
M:&]W97(B"FUS9W-T<B`B2V5V>6ETY"!L=6UI:W5U<F]J82(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B
M3&EM97)I:VET(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q.`IM
M<V=I9"`B3&EN:R(*;7-G<W1R("),:6YK:VDB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI
M;FL@<&]I;G1S('1O.B(*;7-G<W1R("),:6YK:VD@;W-O:71T86$Z(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W.0IM<V=I9"`B3&EN:R!T:&4@
M96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA
M>6EN9R(*;7-G<W1R("),:6YK:73D('/D:&OV<&]S=&EO<V]I=&4@:VER:F]I
M=&$@=75S:2!V:65S=&D@<VEV=6QL92!NY&MY;>1S<^0B"@HC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@R"FUS9VED
M("),:6YK<R(*;7-G<W1R("),:6YK:70B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R("),:6YU>"!P
M:7!A<F5I=&$B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T
M+G!H<#HT-@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX-PIM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM
M<V=S='(@(E9O:2!L:7-T875K<V5S<V$@;N1H9.0@:V%N<VEO;B(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,S0*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM
M<V=S='(@(D[D>73D('1I971O:V%N;F%T(@H*(SH@<V5R=FEC97,O:&5L<"]I
M;F1E>"YP:'`Z-3$*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B
M3N1Y=.0@;VAJ96ED96X@86EH965T(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$S,PIM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B3N1Y=.0@=&%U;'5T
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.30*;7-G
M:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("),:7-T86XM07)K:7-T;R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3@Y"FUS9VED("),
M:7-T+4AE;'`B"FUS9W-T<B`B3&ES=&%N+4]H:F4B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G
M<W1R("),:7-T86XM260B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E
M<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("),:7-T86XM
M3VUI<W1A:F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP
M.C4Y,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(DQI<W1A+79I97-T:2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS9VED
M("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("),:7-T86XM5&EL875S(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3`*;7-G:60@(DQI
M<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B3&ES=&%N+51I;&%U:W-E;BUL;W!E
M='1A;6EN96XB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S
M='(@(DES='5N=&]J96X@;&ES=&%U<R!E<.1O;FYI<W1U:3H@)7,B"@HC.B!A
M9&UI;B]S97-S:6]N<RYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES
M=&EN9R!U<V5R<R!F86EL960Z("5S(@IM<V=S='(@(DOD>71TY&II96X@;&ES
M=&%U<R!E<.1O;FYI<W1U:3H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L
M960N(@IM<V=S='(@(DOD>71TY&KD=&EE=&]J96X@;N1Y='3D;6EN96X@;VX@
M97-T971T>2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@
M(DQI=&5R871U<F4B"FUS9W-T<B`B2VER:F%L;&ES=75S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30T"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B3&EE='1U82(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z-S<*;7-G:60@
M(DQO861I;F<N+BXB"FUS9W-T<B`B3&%D871A86XN+BXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`P"FUS9VED("),;V-A;"!T:6UE.B`B
M"FUS9W-T<B`B4&%I:V%L;&ES=&$@86EK86$Z("(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX-@IM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@
M(DQO:V%L:7-A871I;R!J82!A:6MA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,@HC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C4W"FUS9VED("),;V-A=&EO;B(*;7-G<W1R(")086EK:V$B"@HC
M.B!L;V=I;BYP:'`Z,3@Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR
M,#`@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.CDP"FUS9VED("),;V<@:6XB"FUS9W-T<B`B2VER:F%U9'4@<VESY.1N(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@
M;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(D5D96QL:7-E;B!S
M>6YK<F]N;VEN=&ES97-S:6]N(&QO:VDB"@HC.B!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,3DT"FUS9VED("),;V<@;W5T(@IM<V=S='(@(DMI<FIA
M=61U('5L;W,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*;7-G:60@
M(DQO9VEN(@IM<V=S='(@(DMI<FIA=61U('-I<^3D;B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,3`*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@
M(E1E:'3D=N1T('-I<^3D;FMI<FIA=71U;6ES97-S82(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.CDY-0IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U
M<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O
M<G)E8W1L>2XB"FUS9W-T<B`B(@HB4VESY.1N:VER:F%U='5M:7-E<VD@97#D
M;VYN:7-T=6DN(%1O9&5N;N1K]FES97-T:2!K:7)J;VET:70@=N3D<FEN("(*
M(FOD>71TY&KD='5N;G5K<V5S:2!T86D@<V%L87-A;F%S:2XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.3$*;7-G:60@(DQO9VEN(&9A:6QE9"XB
M"FUS9W-T<B`B4VESY.1N:VER:F%U='5M:6YE;B!E<.1O;FYI<W1U:2XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y"FUS9VED("),;VYG('1E
M>'0B"FUS9W-T<B`B4&ET:^0@=&5K<W1I(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@(E)A:VMA=7,B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B
M3&]W(@IM<V=S='(@(DUA=&%L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R
M965K(&QE='1E<G,B"FUS9W-T<B`B4&EE;F5T(&MR96EK:V%L86ES970@:VER
M:F%I;65T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*
M;7-G<W1R(")0:65N970@;&%T:6YA;&%I<V5T(&MI<FIA:6UE="(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B4&EE;F5T
M(')O;VUA;&%I<V5T(&YU;65R;W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4*;7-G:60@(DQU
M>&5M8F]U<F<B"FUS9W-T<B`B3'5X96UB=7)G(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")+2R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR.#,*;7-G:60@(DU/5$0B"FUS9W-T<B`B34]41"(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS
M9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM
M<V=S='(@(DU3+51.148@;&EI=&5T:65D;W-T;R!O;&D@='EH:N0N(@H*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(E9)15-422(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U-PIM<V=I9"`B36%C86\B"FUS9W-T<B`B36%C86\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-3,*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA
M=B!297!U8FQI8R!O9B(*;7-G<W1R(")-86ME9&]N:6$L($5N=&EN96X@2G5G
M;W-L879I86X@=&%S879A;&QA;BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3$*;7-G:60@(DUA
M9&%G87-C87(B"FUS9W-T<B`B36%D86=A<VMA<B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B5&%I:W5U<R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,PIM<V=I9"`B36%I;"(*
M;7-G<W1R(")3Y&AK]G!O<W1I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C4R-`IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R(")0;W-T:6X@>6QL
MY'!I=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B
M5&5E(&QI;FM?:VDN+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4*;7-G:60@(DUA;&%W:2(*
M;7-G<W1R(")-86QA=VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<*;7-G:60@(DUA;&%Y<VEA
M(@IM<V=S='(@(DUA;&5S:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0*;7-G:60@(DUA;&1I
M=F5S(@IM<V=S='(@(DUA;&5D:6EV:70B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30*;7-G:60@
M(DUA;&DB"FUS9W-T<B`B4&]S=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(*;7-G:60@(DUA
M;'1A(@IM<V=S='(@(DUA;'1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDT"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y
M;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S
M<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"B)6
M;VET(&AA;&QI;FYO:61A(&QI<W1A82!K871E9V]R:6]I<W1A+"!J;VED96X@
M879U;&QA('9O:70@;&EI='3DY"!A<VEO:71A("(*(GEH=&5E;B!S86UO:F5N
M(&]T<V%K:V5I9&5N(&%L;&4@:F$@;&EI='3DY"!N:6EH:6X@=N1R96KD+B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,34V
M"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B36%P,C0@:V%R='1A(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#<*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-S$*;7-G
M:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R(")-87!1=65S="!K87)T=&$B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I
M;F=S('-T;W)E9"XB"FUS9W-T<B`B5F%S=&%A=G5U9&5T('1A;&QE=&5T='4N
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*
M;7-G:60@(DUA<F-H(@IM<V=S='(@(FUA86QI<VMU=2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*;7-G:60@
M(DUA<F=I;B(*;7-G<W1R(")-87)G:6YA86QI(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#@*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!3965N
M+U5N<V5E;B!F;&%G<R(*;7-G<W1R(")6;VD@;65R:VETY"!686YH82]5=7-I
M('1I971O:F$B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T
M+G!H<#HT.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HY,`IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R
M=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B5F]I(&UE<FMI=.0@=FEE<W1E:N0@
M*&5S:6TN(%3D<FMEY"]687-T871T=2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(*;7-G:60@
M(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B36%R<VAA;&P@<V%A<F5T(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34Y"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(DUA<G1I
M;FEQ=64B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I
M9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(E3D<VWDY';D="!K96YTY'0B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C`*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B36%U
M<FET86YI82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,PIM<V=I9"`B36%U<FET:75S(@IM<V=S
M='(@(DUA=7)I=&EU<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET
M+B(*;7-G<W1R(")3=75R:6X@<V%L;&ET='D@:W)E9&EI='1I+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM
M<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(E-U
M=7)I;B!S86QL:71T=2!V:65S=&EO<VEO;>3D<N0@>6QI=&5T='DN(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3,*;7-G:60@(DUA>"!T96UP(&QA<W0@
M,C0@:&]U<G,Z("(*;7-G<W1R(")%9&5L;&ES96X@,C0@='5N;FEN(&MO<FME
M:6X@;.1M</9T:6QA.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-0IM
M<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B161E;&QI
M<V5N(#8@='5N;FEN(&MO<FME:6X@;.1M</9T:6QA.B`B"@HC.B!L:6(O87!I
M+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K
M<R(*;7-G<W1R(")0;W)T86%L:6]S:6]I9&5N(&5N:6UMY&ES;>3D<N0B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,#(@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C0S
M"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R(")3=75R:6X@<V%L;&ET
M='4@<&ET=75S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R(")T;W5K;VMU=2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-3,*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B36%Y;VYE='1E(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*
M;7-G<W1R("),Y.1K971I961E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*;7-G<W1R(")*Y'-E;F5T
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,@IM<V=I9"`B365N=2!M
M;V1E.B(*;7-G<W1R(")-96YU;B!M=6]T;SHB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G
M92!C96QL<R(*;7-G<W1R(")9:&1I<W3D('-O;'5T(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H
M<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@
M(DUE<W-A9V4B"FUS9W-T<B`B5FEE<W1I(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I
M960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@
M8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B)6:65S=&EN
M('1A<FMI<W1U<R!O;FYI<W1U:2P@;75T=&$@86QL96MI<FIO:71T86IA;B!V
M87)M96YN971T82!E:2!V;VET=2`B"B)T87)K:7-T86$N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED
M(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(E9I97-T:2!V86YH96YI+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR-C`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,#(*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")6
M:65S=&EN('1Y>7!P:2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I
M9"`B365T87(@5V5A=&AE<B(*;7-G<W1R(")-971A<B!SY.0B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R(")-971A<BUO<VEO(&5I(&]L92!KY'ET971TY'9I
M<W/D+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED("(B"B)-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)-971A
M<BUO<VEO(&5I(&]L92!KY'ET971TY'9I<W/D+B!487)K96UM870@=&EE9&]T
M(&]N('1A;&QE=&5T='4@>6QLY'!I9&]N("(*(FOD<VET96QTY';D:W-I+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3,*;7-G:60@(DUE
M=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B365T87)$0B!E:2!O
M;&4@>6AD:7-T971T>2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R(")-971O9&DB"@HC.B!F<F%M
M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<@9G)A;65W;W)K+U)00R]24$,O
M>&UL<G!C+G!H<#HX,0HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E
M<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(DUE=&]D:6$@7"(E<UPB(&5I
M(&]L92!MY.1R:71E;'1Y(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP
M:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D
M+B!#86QL960@;65T:&]D.B`E<R(*;7-G<W1R(")-971O9&EA(&5I(&]L92!M
MY.1R:71E;'1Y+B!+=71S=79A(&UE=&]D:3H@)7,B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C@R(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-PIM
M<V=I9"`B365T<FEC(@IM<V=S='(@(DUE=')I;F5N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V
M"FUS9VED(")-97AI8V\B"FUS9W-T<B`B365K<VEK;R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U
M"FUS9VED(")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S
M='(@(DUI:W)O;F5S:6$L(%EH9&ES='EN965T('9A;'1I;W0B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*;7-G
M:60@(DUI9&1L92(*;7-G<W1R(")+97-K96QLY"(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B
M"FUS9W-T<B`B36EM92UT>7EP<&DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,Q-PIM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@
M(D5D96QL:7-E;B`R-"!T=6YN:6X@;6%T86QI;B!LY&UP]G1I;&$Z("(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S`Y"FUS9VED(")-:6X@=&5M<"!L87-T
M(#8@:&]U<G,Z("(*;7-G<W1R(")%9&5L;&ES96X@-B!T=6YN:6X@;6%T86QI
M;B!LY&UP]G1I;&$Z("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE
M="!E>'!I<F5D(@IM<V=S='(@(E-A;&%S86YA(&5I(&]L92!V:65LY"!T87)P
M965K<VD@=F%N:&$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C,U"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B4&5I;&EK=79A
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL
M86YE;W5S(@IM<V=S='(@(E-E:V%L86ES970B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I
M;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B4$5!4BUP
M86ME='1I($A45%!?4F5Q=65S="!P=75T='5U+B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO
M;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O
M('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"B)0=75T='5V
M870@87-E='5S=&EE9&]S=&\N(%-I;G5N('!I=.3D('1E:&3D(&%S971U<W1I
M961O<W1O(&IO<R!H86QU870@(@HB:^1Y='3DY"!TY'3D(&]H:F5L;6%A+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R(")0=75T
M='5V82!M97-S86=E($E$+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I
M<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R(")6Y&QT=.1MY'3V;B!0
M14%2+7!A:V5T=&D@36%I;"!P=75T='5U+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN
M9R!S97-S:6]N($E$+B(*;7-G<W1R(")0=75T='5V82!S97-S:6]N($E$+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*
M;7-G:60@(DUO(@IM<V=S='(@(FUA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C<V"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R(")-;V)I:6QI
M<^1H:_9P;W-T:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C<P"FUS9VED(")-;V1E<F%T92(*;7-G<W1R(")+;VAT86QA:6YE
M;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"FUS9VED(")-;V1I
M9FEE9"!$871E(@IM<V=S='(@(DUU;VMK875K<V5N('#D:7;D;>3D<N0B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B375O:VMA82!54DPZ
M:6$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-`IM
M<V=I9"`B36]D=6QU<R(*;7-G<W1R(")+97)R;VEN(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P
M"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R(")-;VQD;W9A
M+"!T87-A=F%L=&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D*;7-G:60@(DUO;F%C;R(*;7-G
M<W1R(")-;VYA8V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38*;7-G:60@(DUO;F=O;&EA(@IM
M<V=S='(@(DUO;F=O;&EA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C4X.`IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B:W5U:V%U<VD@
M:F$@=G5O<VDB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(DMU=6MA=7-I='1A
M:6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C$*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B
M36]N='-E<G)A="(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C
M:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B2W5U
M;B!V86EH965T(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3DV
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(X,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE
M(&5X<&5C=&5D("5D+B(*;7-G<W1R(")2:79I;'3D("5D(&SV>71Y:2!E;F5M
M;>1N(&ME;G1T:>0@:W5I;B!O9&]T971T=2`E9"XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@*
M;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B36%R;VMK;R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@
M0VQE87(B"FUS9W-T<B`B16YI;6WD:W-I('-E;&MEY.0B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY
M($-L;W5D>2(*;7-G<W1R(")%;FEM;>1K<VD@<&EL=FES=.0B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S
M=&QY($-L;W5D>2!A;F0@5VEN9'DB"FUS9W-T<B`B16YI;6WD:W-E96X@<&EL
M=FES=.0@:F$@='5U;&ES=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@
M(D5N:6UMY&MS965N(&%U<FEN:V]I<W1A(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#@*;7-G:60@(DUO=F4@1&]W
M;B(*;7-G<W1R(")3:6ER<N0@86QA<W#D:6XB"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U,@IM<V=I9"`B36]V92!,
M969T(@IM<V=S='(@(E-I:7)RY"!V87-E;6UA;&QE(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-38*;7-G:60@(DUO
M=F4@4FEG:'0B"FUS9W-T<B`B4VEI<G+D(&]I:V5A;&QE(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#0*;7-G:60@
M(DUO=F4@57`B"FUS9W-T<B`B4VEI<G+D('EL]G-PY&EN(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM<V=I9"`B36]V
M92!D;W=N(@IM<V=S='(@(E-I:7)RY"!A;&%S<.1I;B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C4*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM<V=I9"`B36]V92!U
M<"(*;7-G<W1R(")3:6ER<N0@>6SV<W#D:6XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@*;7-G
M:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B36]S86UB:6LB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3@X"FUS9VED(")-=6QT:2UL979E;"!D<F]P
M(&1O=VX@;&ES=',B"FUS9W-T<B`B36]N:71A<V]I;F5N(&%L87-V971O=F%L
M:6MK;R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#4X"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B375L=&EM
M87`@27-O+4)R:71A;FYI86X@:V%R='1A(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(T-@IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S
M='(@(DUO;FEV86QI;G1A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0P,@IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R(")+Y'ET=.1JY'1U;FYU
M:W-E;FDB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*;7-G:60@(DUY
M($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B3VUA;B!KY'ET=.1JY'1U
M;FYU:W-E;B!T:65D;W0B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP
M.C0U"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B3VUA('!O<G1A86QI(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C0S"FUS9VED(")->2!0;W)T
M86P@3&%Y;W5T(@IM<V=S='(@(D]M86X@<&]R=&%A;&EN(&%S971T96QU(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34U"FUS9VED(")->6%N;6%R(@IM<V=S='(@(DUY86YM87(@
M*$)U<FUA*2(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC
M92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B
M14DL($5.('-U;W-T=2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1N968N<&AP.C,X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,#(@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q
M"FUS9VED(").86UE(@IM<V=S='(@(DYI;6DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD*;7-G
M:60@(DYA;6EB:6$B"FUS9W-T<B`B3F%M:6)I82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.`IM
M<V=I9"`B3F%U<G4B"FUS9W-T<B`B3F%U<G4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<*;7-G
M:60@(DYE<&%L(@IM<V=S='(@(DYE<&%L(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U"FUS9VED
M(").971H97)L86YD<R(*;7-G<W1R(")!;&%N:V]M86%T(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(D%L86YK
M;VUA:61E;B!!;G1I;&QI="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R
M(").971S8V%P92!"87-E(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N
M(%523"(*;7-G<W1R(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").
M971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(DYE='-C87!E($-!('!O
M;&EC>2!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X-0IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B3F5T
M<V-A<&4@4F5N97=A;"!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB
M"FUS9W-T<B`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@
M4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(DYE='-C87!E(%-33"UP86QV96QI
M;65N(&]S;VET92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3@X"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM
M<V=S='(@(DYE='-C87!E('9A<FUE;G1E96X@:V]M;65N='1I(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C
M87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B3F5T<V-A<&4@=F%R;65N
M=&5E;B!T>7EP<&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4S
M"FUS9VED(").971W;W)K(@IM<V=S='(@(E9E<FMK;R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S,Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G:60@(DYE
M=F5R(@IM<V=S='(@(D5I(&MO<VMA86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S`*;7-G:60@
M(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B575S:2U+86QE9&]N:6$B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM
M<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(E5U<VD@;'5O:VET=7,B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X
M(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S
M='(@(E5U<VEK=74B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R
M(")5=7-I(&OD>71TY&KD='5N;G5S("AV87!A865H=&]I;F5N*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X,`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B575S:2U3965L
M86YT:2(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PIM<V=I
M9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(E5U<VD@<V%L87-A;F$B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*
M;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T
M<B`B575S:2!S86QA<V%N82!V86YH96YE92`E>"XB"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@(DYE=R!P87-S=V]R9',@9&]N
M)W0@;6%T8V@N(@IM<V=S='(@(D%N=&%M87-I('5U9&5T('-A;&%S86YA="!E
M:7;D="!TY'-MY.0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G
M<W1R(")5=7-I(&EK:W5N82`H7V)L86YK*2(*"B,Z(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,CDQ"FUS9VED(").97=S(@IM<V=S='(@(E5U
M=&ES970B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`W"FUS9VED
M(").97=S9W)O=7!S(@IM<V=S='(@(DME<VMU<W1E;'5R>6AMY'0B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHR-0HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT
M,2!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-0IM<V=I9"`B3F5X="(*
M;7-G<W1R(")3975R86%V82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM
M<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R(")3975R86%V870@-"!V86EH
M971T82(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<P"FUS9VED(").97AT(&]P
M=&EO;G,B"FUS9W-T<B`B4V5U<F%A=F%T(&%S971U:W-E="(*"B,Z(&9R86UE
M=V]R:R]522]522]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R
M(")3975R86%V83XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0*;7-G:60@(DYI8V%R86=U82(*
M;7-G<W1R(").:6-A<F%G=6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$*;7-G:60@(DYI9V5R
M(@IM<V=S='(@(DYI9V5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S"FUS9VED(").:6=E<FEA
M(@IM<V=S='(@(DYI9V5R:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S8Y"FUS9VED(").:6=H="(*;7-G<W1R(")9]B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W.0IM<V=I9"`B3FEU92(*;7-G<W1R(").:75E(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-@IM<V=I9"`B3F\B"FUS
M9W-T<B`B16DB"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL
M.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@
M<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(D%S971U<W1I971O:F$@
M96D@;VQE('-A871A=FEL;&$L(&IO<W1A('9O:7-I(&[D>71TY.0@97)O879A
M:7-U=6MS:6$N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+G!H<#HQ,#8*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@
M;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(D5I(&]L92!S86%T879I;&QA
M('-U=6YN:71E;&UA82!)4T\@;&5V>6MU=F%T:65D;W-T;VIE;B!T96ME;6ES
M96MS:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R
M(")%:2!E<N1M86QL:6$N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HQ,#$*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HS.#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT,#<*;7-G:60@(DYO(&)L;V-K(&5X
M:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(D]S:6]T
M82!E:2!O;&4@<'EY9&5T>7-SY"!P86EK87-S82XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A<B!N86UE
M('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+
M86QE;G1E<FEN(&YI;67D(&5I(&]L92!A;FYE='1U($U#04PM875T96YT:6MO
M:6YN:6QL92XB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`IM<V=I9"`B
M3F\@8VAA;F=E+B(*;7-G<W1R(")%:2!M=75T;W-T82XB"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@
M8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B06QI
M=&%S;VIA(&5I('9O:2!L:7/D=.0@=.1L;&4@;VEK975D96QL92XB"@HC.B!F
M<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-C@@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ-CD*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R(")!<V5T=6MS:6$@96D@
M;/9Y='EN>70@)7,Z;&QE+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.#4U"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B07-E='5K<VEA(&5I(&SV
M>71Y;GET($944"!61E,Z;&QE+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z-C<R"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B07-E='5K<VEA(&5I
M(&SV>71Y;GET(%-13"!61E,Z;&QE+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HW,C4*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@
M(D%S971U:W-I82!E:2!L]GET>6YY="!344PM1FEL92!61E,Z;&QE+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q
M-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(DMR961I:71I="!L
M;W!P=2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM
M<V=S='(@(DMO:&1E='1A(&5I(&%N;F5T='4N(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.3(P"FUS9VED(").;R!F:6QE('5P;&]A9&5D
M(@IM<V=S='(@(D5I('1U;W1U(&%I;G5T=&%K86%N('1I961O<W1O82(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U
M;F0N(@IM<V=S='(@(DEK;VYE:71A(&5I(&SV>71Y;GET+B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3,P(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$V"FUS9VED(").;R!L
M;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(E!A:6MK86$@96D@;VQE(&%S971E
M='1U+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G
M:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")086EK:V%A(&5I
M(&]L92!A;FYE='1U+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L:65D
M+B(*;7-G<W1R(")%:2!A;FYE='1U('9I97-T:>0N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO
M(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R(").:6UEY"!E:2!O;&QU="!A;FYE
M='1U+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R
M("),=6MU;>3D<N3D(&5I(&]L;'5T(&%N;F5T='4N(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.CDT"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B
M"FUS9W-T<B`B16D@;&]U:VMA879A="!M:65T96QA=7-E970B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"FUS9VED(").;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
M4V%L87-A;F%A(&5I(&]L92!A;FYE='1U($A45%`M875T96YT:6MO:6YN:7-S
M82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C$P.`IM<V=I
M9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(E-A;&%S86YA82!E:2!O;&4@86YN971T=2!)34%0+6%U
M=&5N=&EK;VEN;FES<V$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U
M+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E
M<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")386QA<V%N86$@96D@;VQE
M(&%N;F5T='4@2V5R8F5R;W,M875T96YT:6MO:6YN:7-S82XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<#HX-"!F<F%M97=O<FLO075T:"]!
M=71H+W!A;2YP:'`Z-S4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H
M<#HW-PIM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")386QA<V%N86$@96D@;VQE(&%N;F5T
M='4@3&]G:6X@875T96YT:6MO:6YN:7-S82XB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")386QA
M<V%N86$@96D@;VQE(&%N;F5T='4@4$%34U=$+6%U=&5N=&EK;VEN;FES<V$N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C@T"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(")386QA<V%N86$@96D@;VQE(&%N;F5T='4@4TU"+6%U=&5N=&EK
M;VEN;FES<V$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HQ,C@W"FUS9VED("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R
M>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T
M;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"B)0;VQK
M=6$@3W!E;E-33"!K;VUE;G1O;VX@96D@;VQE(&WDY')I=&5L='DN($]P96Y3
M4TP@<&ETY.0@;VQL82!KY'ET971TY'9I<W/D("(*(FIO<R!KY'-I=&5L;.3D
M;B!02T-3(#$R(&1A=&%A+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T
M<B`B16D@<VESY.1N:VER:F%U='5M:7-P>7EN=/9JY"!J;VYO<W-A+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HW-C8*;7-G:60@(DYO('%U;W1A('-E
M="XB"FUS9W-T<B`B2VEI;G1I]G3D(&5I(&]L92!A<V5T971T=2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*
M;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(D5I('/DY&YT]FKD(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#@R"FUS9VED(").;R!S97!A<F%T
M;W(@<W!E8VEF:65D+B(*;7-G<W1R(")%<F]T:6YT82!E:2!O;&4@;>3D<FET
M96QT>2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0T"FUS9VED(").;R!S:61E<R(*;7-G<W1R(")%:2!R975N
M;VIA(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#<*;7-G:60@
M(DYO('-U8V@@9FEL92(*;7-G<W1R(")%:2!L]GET>6YY="!T:65D;W-T;V$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(V"FUS9VED(").
M;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM
M<V=S='(@(E;D;&EM=6ES=&EL;&4@96D@;VQE(';D;&EA:6MA:7-H86ME;6ES
M=&]A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N
M="XB"FUS9W-T<B`B2^1Y='3D:N1T=6YN=7-T82!T86D@<V%L87-A;F%A(&5I
M(&SD:&5T971T>2XB"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP
M.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T
M<B`B2V%I:VMI('!A;&%U='5N=70@6$U,+61A=&$@;VQI(&5PY&ME;'!O82(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-S0*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX-`HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DU"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#$R"FUS
M9VED(").;R!V86QU97,B"FUS9W-T<B`B16D@87)V;VIA(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I
M;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*(E9E<G-I;W1I971O:F$@96D@;/9Y='EN>70@
M86QK=7!E<N1I<VETY"!A<V5T=6MS:7-T82X@4VEN=6X@<&ETY.0@=&5H9.0@
M(@HB87-E='5K<V5T('5U9&5S=&%A;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N
M9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("(B"B)697)S:6]T:65T;VIA(&5I(&SV>71Y;GET(&%S971U:W-I<W1A+B!3
M:6YU;B!P:73DY"!T96ADY"!A<V5T=6MS970@=75D97-T86%N+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-R!T96UP;&%T97,O<')E
M9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*;7-G:60@(DYO;F4B"FUS
M9W-T<B`B16D@;6ETY.1N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*
M;7-G<W1R(")%:2!M:73DY&X@*$OD>73D(&EM<&QI<VEI='1I<W3D*2(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(").;W)D:6,@*$E33RTX
M.#4Y+3$P*2(*;7-G<W1R("),87!P:2]0;VAJ;VES;6%A="]%<VMI;6\@*$E3
M3RTX.#4Y+3$P*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,@IM<V=I9"`B3F]R9F]L:R!)<VQA
M;F0B"FUS9W-T<B`B3F]R9F]L:R!S86%R970B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R
M;B!(96UI<W!H97)E(@IM<V=S='(@(E!O:&IO:6YE;B!P86QL;VYP=6]L:7-K
M;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U.`IM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA
M;F1S(@IM<V=S='(@(E!O:&IO:7-E="!-87)I86%N:65N('-A87)E="(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W-@IM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(DYO<FIA(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#$*;7-G:60@(DYO
M="!!9G1E<B(*;7-G<W1R(")%:2!JY&QK965N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!"969O<F4B"FUS
M9W-T<B`B16D@96YN96XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HT,34*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R(")%:2!O;&4@
M:&%K96UI<W1O(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P
M=713=')A=&5G>2YP:'`Z.#0*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.34*;7-G:60@(DYO
M="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B16D@;VQE('1O=&5U=&5T='4N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`IM
M<V=I9"`B3F]T('-E="(*;7-G<W1R(")%:2!A<V5T971T=2(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HQ.3,@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(P
M.`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,T(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HR-3(*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V.2!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,C@U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HS,#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q-@HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,S,S(&9R86UE=V]R:R]61E,O5D93+G!H<#HS-C8*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C0R-B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z-3`U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S0@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C4Y,0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-C8Y
M(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z
M,30U"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE
M<BYP:'`Z,38P"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N
M2&%N9&QE<BYP:'`Z,3<U"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]3
M97-S:6]N2&%N9&QE<BYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N
M9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,V"FUS9VED(").;W0@<W5P<&]R
M=&5D+B(*;7-G<W1R(")%:2!T=65T='4N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDP.`HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@P(&-O
M;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#4X"FUS9VED(").;W1E<R(*;7-G<W1R
M(")-=6ES=&EI;G!A;F]T(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD97@N
M<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS
M9W-T<B`B16D@;6ETY.1N('-E;&%T=&%V86$L('!A;&%A('1A:V%I<VEN+B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS
M9VED(").;W9E;6)E<B(*;7-G<W1R(")M87)R87-K=74B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#4P"FUS9VED(").=6UB97(B"FUS9W-T<B`B
M3'5K=6WDY'+D(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R.0IM
M<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B365R:VMI96X@
M;'5K=6WDY'+D(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W,R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(W"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T-#D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@
M(E-A<F%K:V5I9&5N(&QU:W5MY.1RY"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S-S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R-0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0W('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W
M<R(*;7-G<W1R(")2:79I96X@;'5K=6WDY'+D(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E
M<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N
M(&QI<W0N(@IM<V=S='(@(DIA:V5L=6QI<W1A;B!N=6UE<F]I=&$@96D@;VQE
M(&WDY')I=&5L='D@<.1I=FET971TY';D:W-I+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T
M<B`B3TLB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.#<S"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B3V)J96MT:2(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E
M871O<B(*;7-G<W1R(")/8FIE:W1I;B!L=6]J82(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q,#@*;7-G:60@(D]C=&%L(@IM<V=S='(@(D]K=&%A
M;&DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R(")L;VMA:W5U(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G
M<W1R("),;W5K:V%A=G5U<W-U;V1A=&EN(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,R.`IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(E1O:6UI<W1O
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/
M;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S
M='(@(E5U<VD@<V%L87-A;F$@96D@<V%A(&]L;&$@<V%M82!K=6EN(&YY:WEI
M;F5N('-A;&%S86YA<VDN(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C,V"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B5F%N:&$@<V%L
M87-A;F$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G
M:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B5F%N
M:&$@<V%L87-A;F$@;VX@=N3D<FEN+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,0IM<V=I9"`B
M3VUA;B(*;7-G<W1R(")/;6%N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U
M<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(E9A:6X@24U!4"UP86QV
M96QI;65T('1U:V5V870@:F%E='1U:F$@:V%N<VEO:71A+B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R
M='5N97,B"FUS9W-T<B`B5F%I;B!L;W5K:V%A=F%T(&UI971E;&%U<V5E="(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DW-0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S
M<R!A;&QO=V5D+B(*;7-G<W1R(")6;VET(&QA:71T86$@=F%I;B!Y:&1E;B!S
MY&AK]G!O<W1I;W-O:71T965N+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D
M;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB
M<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HB5F%I;B!O;6ES
M=&%J82!T86D@:N1R:F5S=&5L;>1N('EL;.1P:73D:N0@=F]I(&UU=71T86$@
M:F%K;VIE;B!O;6ES=&%J:6$@=&%I("(*(F]I:V5U:W-I82(*"B,Z(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C0Q(&QI8B]";&]C:R]I9G)A;64N<&AP.C0R"FUS
M9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")!=F%A('5U9&5S
M<V$@:6MK=6YA<W-A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R
M86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*
M(D]P96Y34TP@=FER:&4Z(%1I971O:F$@96D@<V%A='4@97-I;&QE(&%L;&5K
M:7)J;VET971U<W1A(%,O34E-12UO<V%S=&$N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/
M<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D%V86$@
M=.1MY&X@;&EN:VEN('5U9&5S<V$@:6MK=6YA<W-A(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S
M='(@(DOD>71T]FKD<FIE<W1E;&WD(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")!<V5T=6MS
M970B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S
M+V%P<"YI;F,Z,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@
M)7,B"FUS9W-T<B`B07-E='5K<V5T("5S.FQL92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@
M3&ES="(*;7-G<W1R(")*Y')J97-T971T>2!L:7-T82(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I
M;VXB"FUS9W-T<B`B3W)G86YI<V%A=&EO(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N
M:70B"FUS9W-T<B`B3W)G86YI<V%A=&EO>6MS:6MK]B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ,S0*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T
M<B`B3W)G86YI<V]I;G1I(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*
M;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@
M(D%L:W5P97+D:6YE;B!O:&IE;&UA;B!M86QL:2(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E
M;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B06QK=7!E<N1I<V5T(&UA;&QI="`E
M<SIS<^0Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@
M(DUU=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3`Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,38@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-0HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#0*;7-G:60@(D]T
M:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(DUU=70@=&EE9&]T(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B3VUI<W1A:F%N(&]I:V5U9&5T(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC
M871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4$%-+6%U=&5N=&EK
M;VEN=&EA(&5I(&]L92!KY'ET971TY'9I<W/D+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ
M36%I;"!B86-K96YD(@IM<V=S='(@(E!%05(Z.DUA:6P@=&%U<W1A:N1R:F5S
M=&5L;>0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<V
M"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B1&EG:71A
M86QI;F5N(%!'4"UA;&QE:VER:F]I='5S(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3,R,@IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A
M(@IM<V=S='(@(E!'4"US86QA='1U82!T:65T;V$B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S<T"FUS9VED(")01U`@4'5B;&EC($ME
M>2(*;7-G<W1R(")*=6QK:6YE;B!01U`M879A:6XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4V"FUS9VED(")01U`@4VEG;F5D+T5N
M8W)Y<'1E9"!$871A(@IM<V=S='(@(E!'4"UA;&QE:VER:F]I=&5T='5A(&IA
M('-A;&%T='5A('1I971O82(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.0IM
M<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B4$A0+6MO;V1I(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B4$A0
M+6MO;65N=&]T=6QK:VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R(")0
M32!K979Y='3D('-A9&5T=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4F%I;B(*;7-G<W1R(")032!S
M861E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#`*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B4$T@:W5U<F]J82(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED
M(")032!3;F]W(@IM<V=S='(@(E!-(&QU;6DB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@4VYO=R!3:&]W
M97)S(@IM<V=S='(@(E!-(&QU;6ES871E:71A(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G:60@(E!-(%-U;B(*;7-G
M<W1R(")032!L=6UI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#0*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(E!-('5K
M:V]S;7ER<VMY:N0B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C<T"FUS
M9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R(")03U-)
M6"UL86%J96YN=6MS970@<'5U='1U=F%T(@H*(SH@;&EB+V%P:2YP:'`Z,30Y
M"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(E!?2%`M:V]M96YT;W1U;&MK
M:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B5.1Y=&4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#<*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(E!A:VES=&%N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y-`IM<V=I9"`B4&%L874B"FUS9W-T<B`B4&%L874B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DR"FUS9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C
M8W5P:65D(@IM<V=S='(@(E!A;&5S=&EI;F$@*&UI96AI=&5T='D@86QU92DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#(*;7-G:60@(E!A;F%M82(*;7-G<W1R(")086YA;6$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#4*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T
M<B`B4&%P=6$@575S:2U'=6EN96$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU"FUS9VED(")0
M87)A9W5A>2(*;7-G<W1R(")087)A9W5A>2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")087)T;'D@0VQO=61Y
M(@IM<V=S='(@(D]S:71T86EN('!I;'9I<W3D(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`R,@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C<W('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R-0IM<V=I9"`B4&%S<W=O<F0B
M"FUS9W-T<B`B4V%L87-A;F$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY
M+B(*;7-G<W1R(")386QA<V%N86X@=F%I:'1O(&]N;FES='5I+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,PIM<V=I9"`B4&%S
M<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(E;DY'+D('-A;&%S86YA(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S
M<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B4V%L87-A;F%A('1A<G9I=&%A;B!2041)55,M875T96YT:6MO:6YT
M:6EN+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-3<*;7-G:60@
M(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(E-A;&%S86YA
M('9A<FUI<W1U:W-E;&QA(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.CDP"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`B4V%L87-A;F$Z(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W
M;W)D.B`B"FUS9W-T<B`B4V%L87-A;F$Z("(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,X"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M
M=7-T(&UA=&-H+B(*;7-G<W1R(")386QA<V%N;VIE;B!P:73DY"!O;&QA('-A
M;6%T+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")0
M87-T92(*;7-G<W1R("),:6ETY"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O
M87)D(@IM<V=S='(@(DQI:73D(&QE:6ME</9Y9.1L=.0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H
M(@IM<V=S='(@(E!O;&MU(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N
M:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B2F]N;W-S
M82!O;&5V870@<VESY.1N:VER:F%U='5M:7-P>7EN;O9T.B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(DEH
M;6ES970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R(")0<F]S96YT=&DB"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM
M<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@
M(E-U;W)I=&$@>6QLY'!I=&]T;VEM96YP:71E970B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#$P"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(E-U;W)I=&$@>6QLY'!I=&]T
M;VEM96YP:71E970@<VESY.1N:VER:F%U='5M:7-E;B!Y:'1E>61E<W/D+B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(")0
M97)M:7-S:6]N(@IM<V=S='(@(D]I:V5U<R(*"B,Z(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<
M(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S='(@(D]I:V5U='1A(%PB)7-<(B!E
M:2!P;VES=&5T='4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU
M.3`*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(DOD>71T]B!K
M:65L;&5T='DB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B3VEK975D970B"@HC.B!A9&UI;B]P97)M<R]A
M9&1C:&EL9"YP:'`Z-C`@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`HC.B!A
M9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O:6YD97@N<&AP
M.C(R"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R
M(")/:6ME=6MS:65N('EL;.1P:71O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8X"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R(")/
M;6%T('1I961O="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,PIM<V=I9"`B4&5R=2(*;7-G<W1R
M(")097)U(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0
M971S(@IM<V=S='(@(DQE;6UI:VET(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V"FUS9VED(")0
M:&EL:7!P:6YE<R(*;7-G<W1R(")&:6QI<'!I:6YI="(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE
M(@IM<V=S='(@(E!U:&5L:6XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#@P"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B5F%L;VMU=F%T(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B4&ET8V%I<FXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(E!I:W-E;&DB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B
M2VQI<V5E="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@
M8V5L;"(*;7-G<W1R(").87!S875T82!J;W1A:6X@<V]L=6$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*
M;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E
M('1H:7,@96QE;65N=#HB"FUS9W-T<B`B5F%R;6ES=&$@971TY"!H86QU870@
M<&]I<W1A82!TY&WD;B!E;&5M96YT:6XZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0;&5A
M<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE
M;G0N(@IM<V=S='(@(E9A<FUI<W1A(&5T=.0@:&%L=6%T('!O:7-T86$@;&EN
M:VET>6MS96X@=.1HY&X@96QE;65N='1I:6XN(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C4V-@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@
M86YD(&$@>65A<BXB"FUS9W-T<B`B06YN82!K=75K875S:2!J82!V=6]S:2XB
M"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ
M,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E
M9V]R>3HB"FUS9W-T<B`B06YN82!N:6UI('5U9&5L;&4@;'5O:VET=6MS96QL
M93HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`U"FUS9VED(")0
M;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R(")!;FYA
M(&]I:V5A($E0+6]S;VET92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-C0T"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C
M:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R(")!
M;FYA(&]I:V5A('#D:7;D;>3D<N0[(%1A<FMI<W1A('#D:79I96X@;'5K=6WD
MY'+D(&MU=6MA=61E<W-A+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(T-3$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S
M='(@(D%N;F$@86EK82!O:6ME87-S82!M=6]D;W-S82XB"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED
M92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(D%N;F$@;'EH
M>70@:W5V875S(&]N9V5L;6%S=&$N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED
M(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*
M;7-G<W1R(")!;FYA(&OD>71TY&KD='5N;G5K<V5S:2!J82!S86QA<V%N87-I
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0
M;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E
M('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R
M("(B"B),=64@<V5U<F%A=F$@=&5K<W1I+B!3:6YU;B!0253$Q"!S=6]S='5A
M(&OD>71T]F5H=&]I:&EN('9O:61A:W-E<VD@:^1Y='3DY"`B"B)JY')J97-T
M96QMY.0N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O
M<GD@;F%M93HB"FUS9W-T<B`B06YN82!N:6UI('5U9&5L;&4@;'5O:VET=6MS
M96QL93HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#@*;7-G:60@(E!O;&%N9"(*;7-G<W1R(")0
M=6]L82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L
M:71I8W,B"FUS9W-T<B`B4&]L:71I:6MK82(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT.#D*;7-G:60@(E!O;&QS(@IM<V=S='(@(DMY<V5L>70B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DS"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R(")0;W)T
M=6=A;&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@
M:6UA9V4B"FUS9W-T<B`B5.1MY&X@:W5V86X@<&%I:VMA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O
M<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B5.1MY&X@=&%U;'5K
M;VX@<&%I:VMA(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q
M-"YP:'`Z-3$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.3(*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E
M9"!B>2!)34%0*2(*;7-G<W1R(")6;VD@;.1H971TY.0@=FEE<W1E:N0@:V%N
M<VEO;VX@*&5I(&MO<VME($E-05`@>6AT97EK<VGD*2(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C<S(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X"B,L('!H
M<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U
M<BAS*3H@(@IM<V=S='(@(E-A9&5MY.1RY"!E9&5L;&ES:6QL92`E<R!T=6YN
M:6QL93H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-PIM
M<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R(")(86EH
M='5V=75S(#QB<B`O/G1O9&5N;N1K]FES>7ES(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U
M:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S
M7VQD87`Z(%1A<G9I='1A=F%A($Q$05`M;&%A:F5N;G5S=&$@96D@;/9Y='EN
M>70N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S
M"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7W-E<W-I;VXZ(%1A<G9I
M='1A=F%A('-E<W-I;VXM;&%A:F5N;G5S=&$@96D@;/9Y='EN>70B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(S,@IM<V=I9"`B4')E<W-U<F4B"FUS9W-T
M<B`B26QM86YP86EN92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8V"FUS
M9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R("));&UA;G!A
M:6YE(&UE<F5N<&EN;F%S<V$Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,C0*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B26QM86YP
M86EN93H@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(P,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`B17-I
M:V%T<V5L=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@
M:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D5S:6MA='-E;&4@:W5V82!U=61E
M<W-A(&EK:W5N87-S82(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,S4V(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8P"FUS9VED
M(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(D5D96QL:7-E="!A<V5T=6MS
M970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R(")4=6QO<W1A(&1O
M:W5M96YT=&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(E-A;&%I;F5N(&%V86EN
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I
M9"`B4')O8FQE;2(*;7-G<W1R(")/;F=E;&UA(@H*(SH@<V5R=FEC97,O<')O
M8FQE;2YP:'`Z,3(W"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S
M='(@(D]N9V5L;6%N(&MU=F%U<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS-S$*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(E!R;VIE:W1I="(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,34@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$Y,@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,C@P"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R(")+96AO='1E96X@=&5K
M<W1I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS
M9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(DIU;&MI;F5N(&%V86EN(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#8*;7-G:60@(E!U
M8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(DIU;&MI<V5N(&%V86EM96X@
M86QG;W)I=&UI(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R(")*=6QK:7-E
M;B!A=F%I;65N('1I961O="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@
M9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B2G5L:VES96XO<V%L
M86ES96X@879A:6YP87)I;B!L=6]N=&D@97#D;VYN:7-T=6DN(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y,0IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B4'5E<G1O(%)I
M8V\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU
M-0IM<V=I9"`B4'5R9V4@;65S<V%G97,B"FUS9W-T<B`B5F]I('1U:&]T82!P
M;VES=&5T='5J82!V:65S=&5JY"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38*;7-G:60@(E%A
M=&%R(@IM<V=S='(@(E%A=&%R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8T
M"FUS9VED(")1=65R>2(*;7-G<W1R(")+>7-E;&4B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S='(@(DMI:6YT:?8B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G
M<W1R(")24T$@2G5L:VEN96X@879A:6X@*"5D(&)I='1IY"DB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8X"FUS9VED(")2861I;R!S96QE8W1I
M;VXB"FUS9W-T<B`B4F%D:6]P86EN:6ME(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6XB"FUS9W-T<B`B
M4V%D92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0V"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(E-A9&5T=&$@86EK86ES
M:6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M-PIM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(E-A9&5T=&$@;7GV:.3D;B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS
M9VED(")286EN(%-H;W=E<B(*;7-G<W1R(")3861E:W5U<F\B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B4F%I
M;B!A;F0@4VYO=R(*;7-G<W1R(")697-I(&IA(&QU;6DB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4F%I;B!T
M;R!3;F]W(@IM<V=S='(@(E9E9&5S=.0@;'5M965N(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@
M(E-A='5N;F%I;F5N(&UI971E;&%U<V4B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(E-U:&1E(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@
M(E)E860B"FUS9W-T<B`B3'5K=2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S0S,30N<&AP.C0W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C@X"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@
M(E9O:2!L=6ME82!V:65S=&5JY"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L
M971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G
M<W1R(")0;VES=&5T86%N:V\@)7,_(%3D=.0@=&]I;6EN=&]A(&5I('9O:2!P
M97)U=71T86$N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A
M=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N(@IM<V=S='(@(E!O:7-T971A86YK;R!T:65D;W0@:^1Y='3D:N1S=.0@
M)7,_(%3D=.0@=&]I;6EN=&]A(&5I('9O:2!P97)U=71T86$N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B
M4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B5&5E(&UU=71O:W-E
M="!U=61E<W1A86XB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ
M-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R
M(")0Y&EV:73D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-0IM<V=I
M9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S='(@(E#D
M:7;D="!D>6YA86UI<V5T('9A;&EK:V]E;&5M96YT:70Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T-0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE
M=SHB"FUS9W-T<B`B4.1I=FETY"!P;W)T86%L:6[D:WEMY.0Z(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I
M9"`B4F5G97@B"FUS9W-T<B`B4^3D;F[V;&QI;F5N(&QA=7-E:V4B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,U"FUS9VED(")296QA=&EO;G-H
M:7`@0G)O=W-E<B(*;7-G<W1R(")296QA871I;W-E;&%I;B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR,#@*;7-G:60@(E)E;&]A9"(*;7-G<W1R("),871A82!U=61E
M;&QE96XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S,PIM<V=I9"`B4F5M
M87)K<R(*;7-G<W1R(")-=6ES=&EI;G!A;F]T(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Q-PIM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B
M173D<&%L=F5L:6UE="(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O
M;2]H;W)D92DZ(@IM<V=S='(@(D5TY'!A;'9E;'5N(%523"`H:'1T<#HO+W=W
M=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E<75E=65D+FEN8SHQ,R!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C(R"FUS9VED(")296UO=F4B"FUS9W-T<B`B4&]I<W1A(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@0FQO
M8VLB"FUS9W-T<B`B4&]I<W1A(&]S:6\B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34Y"FUS9VED(")296UO=F4@8V]L=6UN
M(@IM<V=S='(@(E!O:7-T82!S87)A:V4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C0P"FUS9VED(")296UO=F4@9F]R;6%T
M=&EN9R(*;7-G<W1R(")0;VES=&$@;75O=&]I;'4B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T
M<B`B4&]I<W1A('!A<FDB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R
M"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M
M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B4&]I<W1A('1A;&QE=&5T='4@
M<VMR:7!T:2!P86QV96QI;65N(';D;&EA:6MA:7-H86ME;6ES=&]S=&$N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0R"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(E!O:7-T82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N
M="(*;7-G<W1R(")0;VES=&$@=.1MY"!N;V]D:2!D;VMU;65N=&ES=&$B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q"FUS9VED(")2
M96UO=F4@=7-E<B(*;7-G<W1R(")0;VES=&$@:^1Y='3D:N0B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(E!O:7-T82!KY'ET=.1J
MY#H@)7,B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.`IM
M<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@
M97)R;W)C;V1E.B`B"FUS9W-T<B`B4'EY;G3V]FX@96D@=F]I='4@=F%S=&%T
M82X@5FER:&5K;V]D:3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$T-0IM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E
M(&9O=6YD+B(*;7-G<W1R(")0>7ED971T>>0@<&%L=F5L=6$@96D@;/9Y='EN
M>70N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S8@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B5&%R=FET=&%V86$@7"(E<UPB+71I971O82!E:2!O
M;&QU="!MY.1R:71E;'1Y("5S(&%S971U:W-I<W-A+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#8Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HW,S$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-S@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C
M:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E1A<G9I='1A
M=F%A(%PB)7-<(BUT:65T;V$@96D@;VQL=70@;>3D<FET96QT>2!61E,@87-E
M='5K<VES<V$N(@H*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S<V"B,L
M('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF
M:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E1A<G9I='1A=F%A(%PB
M)7-<(BUT:65T;V$@96D@;VQL=70@;>3D<FET96QT>2!A<V5T=6MS:7-S82XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S4*;7-G
M:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(E!A:V]L;&EN96X@:V5N='3D
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(R,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS-#,@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(P"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B
M5'EH:F5N;N0B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@IM
M<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B5'EH:F5N;N0@<V%L87-A
M;F$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B
M4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R(")4>6AJ96YNY"!S86QA<V%N
M87-I(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,0IM<V=I9"`B4F5S=&]R
M92!,87-T(%%U97)Y(@IM<V=S='(@(E!A;&%U=&$@961E;&QI;F5N(&MY<V5L
M>2(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR.2!A9&UI;B]P:'!S:&5L;"YP
M:'`Z-S(@861M:6XO<W%L<VAE;&PN<&AP.C8W"FUS9VED(")297-U;'1S(@IM
M<V=S='(@(E1U;&]K<V5T(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U
M<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")086QA82!A<V5T=6MS:6EN(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y<&4@
M;F5W('!A<W-W;W)D(@IM<V=S='(@(E9A:'9I<W1A('5U<VD@<V%L87-A;F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DW"FUS9VED(")2975N:6]N(@IM<V=S='(@(E)E=6YI
M;VXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM
M<V=S='(@(E!A;&%U=&$@87-E='5K<V5T(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S-0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM
M<V=S='(@(E)I8V@@5&5X="!%9&ET;W)I;B!A<V5T=6MS970B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B
M07)V;VET=6MS970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#@*;7-G:60@(E)I9VAT(@IM<V=S='(@(D]I:V5A
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P-PIM<V=I9"`B4FEG
M:'0@:&5A9&5R(@IM<V=S='(@(D]I:V5A(&]T<V%K92(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,#,*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G
M<W1R(")/:6ME82!A<G9O="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T
M:65S+BXN(@IM<V=S='(@(E)I=FE?;B!T:65D;W0N+BXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE
M(@IM<V=S='(@(E)O;VQI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.`IM<V=I9"`B4F]M86YI
M82(*;7-G<W1R(")2;VUA;FEA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(R-@IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R
M(")+Y.1N;N0@,3@P(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(R,PIM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B2^3D
M;F[D('9A<W1A<.1I=N3D;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,CD*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R
M(")+Y.1N;N0@;7GV=.1PY&EVY.1N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E
M<G1I97,B"FUS9W-T<B`B4FEV:6X@=&EE9&]T(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W
M('!R;W!E<G1I97,B"FUS9W-T<B`B4FEV:6X@=&EE9&]T(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O
M=W,Z(@IM<V=S='(@(E)I=FET.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM<V=S
M='(@(E9I:79O:71I;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B5FEI=F]I
M=&EN(&[D:WEY(&MA:6MK:65N(')I=FEE;B!J82!S87)A:VME:61E;B!VY&QI
M;&SD(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C
M;VQU;6YS(&]N;'DB"FUS9W-T<B`B5FEI=F]I=&EN(&[D:WEY('9A:6X@<V%R
M86MK96ED96X@=N1L:6QLY"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(E9I:79O:71I;B!NY&MY
M>2!V86EN(')I=FEE;B!VY&QI;&SD(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$R,0IM<V=I9"`B4G5N(@IM<V=S='(@(E-U;W)I=&$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DY"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B5F5NY&KD
M;B!&961E<F%T:6EV:6YE;B!T87-A=F%L=&$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P"FUS
M9VED(")2=V%N9&$B"FUS9W-T<B`B4G5A;F1A(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G
M<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R(")3+TU)344@:W)Y<'1O9W)A869I
M;F5N(&%L;&5K:7)J;VET=7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E
M(@IM<V=S='(@(E,O34E-12!S86QA='1U('9I97-T:2(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC
M871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4T%33"UA=71E;G1I
M:V]I;G1I(&5I(&]L92!KY'ET971TY'9I<W/D+B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HU,#8*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T
M<B`B4TU3(%1E:W-T:79I97-T:70B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R(")344PM:V]M96YT;W1U;&MK
M:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-S@*;7-G:60@(E-1
M3"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B4U%,+6QA
M=7-E(&%R=F]J96X@:&%K96UI<V5E;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT,S,*;7-G:60@(E-32"(*;7-G<W1R(")34T@B"@HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I
M;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(D].3DE35%5)(@H*
M(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@
M(E-?44PM:V]M96YT;W1U;&MK:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(FQA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P-PIM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(E-A
M:6YT($AE;&5N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,0IM<V=I9"`B4V%I;G0@2VET=',@
M86YD($YE=FES(@IM<V=S='(@(E-A:6YT($MI='1S(&IA($YE=FES(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,Y"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R(")386EN="!,
M=6-I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#D*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@
M36EQ=65L;VXB"FUS9W-T<B`B4V%I;G0@4&EE<G)E(&IA($UI<75E;&]N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T-`IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R
M96YA9&EN97,B"FUS9W-T<B`B4V%I;G0@5FEN8V5N="!J82!'<F5N861I:6YI
M="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R(")386UA86X@
M:V5H>6MS965N("A?<V5L9BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q"FUS9VED(")386UO
M82(*;7-G<W1R(")386UO82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(*;7-G:60@(E-A;B!-
M87)I;F\B"FUS9W-T<B`B4V%N($UA<FEN;R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,38*;7-G
M:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R(")386\@5&]M92!J
M82!0<FEN8VEP92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R(")3871E;&QI
M:71T:2!P86QV96QU;G1A<FIO86IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,0IM<V=I9"`B
M4V%U9&D@07)A8FEA(@IM<V=S='(@(E-A=61I82!!<F%B:6$B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3D*;7-G:60@(E-A=F4B"FUS9W-T
M<B`B5&%L;&5T82(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI
M;F,Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T
M<B`B5&%L;&5T82!<(B5S7"(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C(Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@
M(E1A;&QE=&$@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS
M9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B5&%L;&5T82!A<V5T=6MS970B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3879E
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y
M;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@
M(B(*(E1A;&QE=&$@;'5O9'5T(&%S971U:W-E="!02%`M<VMR:7!T:6[D('!A
M;'9E;&EM97-I(';D;&EA:6MA:7-H86ME;6ES=&]O;BX@(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V
M960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B5&%L;&5T971T:6EN("5S
M.FX@87-E='5K<V5T+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS
M"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R
M:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(D%S971U<W1E;B!PY&EV:71Y<W-K
M<FEP=&D@;VX@=&%L;&5T971T=2!P86EK:V%A;CH@7"(E<UPB+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")3
M8V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B2&%J86YA:7-I82!U:VMO<VUY
M<G-K>6KD(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")3
M8VEE;F-E(@IM<V=S='(@(E1I961E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,38*;7-G:60@(E-E87)C:"(*;7-G<W1R(")(86MU(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,R,@IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS
M9W-T<B`B2&%K=6MO;F5E="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Y-3D*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R(")686QI='-E('1I
M961O<W1O="(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT.#4*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B5F%L:71S
M92!PY&EVY&WDY'+D(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R(")686QI
M='-E(&QI<^1T=.1VY"!R>6AMY"(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R(")6
M86QI='-E('5U<VD@;VUI<W1A:F$B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R(")6
M86QI='-E('!A;'9E;&EN(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@(E9A
M;&ET<V4@;&ESY'1TY';D(&OD>71TY&KD(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-@IM<V=I9"`B4V5L96-T(&%L;"(*
M;7-G<W1R(")686QI='-E(&MA:6MK:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(V-#<*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S
M+B(*;7-G<W1R(")686QI='-E(&MA:6MK:2!PY&EVY&WDY'+D:V]M<&]N96YT
M:70B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#<S"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(E9A;&ET<V4@
M;V)J96MT:2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HV-S<*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(E1Y:&IE;F[D
M('9A;&EN=&$B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@
M(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B
M;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H
M96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B)686QI='-E('1A
M<G9I='1A=F%T(&UE<FMI="!A;&QA(&]L979I<W1A('9A;&EK;VES=&$N(%9O
M:70@<V5N(&KD;&ME96X@(@HB:V]P:6]I9&$@:F$@;&EI='3DY"!M97)K:70@
M=&5K<W1I:7-I+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS
M9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R(")686QI
M='-E('#D:7;D>6MS96X@97)O=&EN;65R:VMI.B(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T
M.B(*;7-G<W1R(")686QI='-E('#D:7;D>6MS96X@97-I='ES=&%P83HB"@HC
M.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDP"FUS9VED
M(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS
M9W-T<B`B5F%L:71S92!M=75T971T879A('!R;V9I:6QI.B(*"B,Z('1E;7!L
M871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED(")396QE8W0@=&AE('1I;64@
M9&5L:6UI=&5R.B(*;7-G<W1R(")686QI='-E(&ME;&QO;F%J86X@97)O=&EN
M;65R:VMI.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED
M(")396QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R(")686QI='-E(&%J
M86X@97-I='ES=&%P83HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T
M<B`B5F%L:71S92!K86MS:2!Y:'1E96YS;W!I=F%A(&ME;G1TY.0N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q,`IM<V=I9"`B4V5L96-T('EO=7(@
M8V]L;W(@<V-H96UE+B(*;7-G<W1R(")686QI='-E(';D<FET965M82XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4R"FUS9VED(")396QE8W0@>6]U
M<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(E9A;&ET<V4@:^1Y=&5T
M=.1VY"!K:65L:3HB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("),Y&AE
M=.0@;VYG96QM879I97-T:2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#0R"FUS9VED(")396YD(%--4R(*;7-G<W1R("),
MY&AE=.0@4TU3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,PIM<V=I9"`B4V5N96=A;"(*;7-G
M<W1R(")396YE9V%L(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C,*;7-G
M:60@(E-E;G-O<CH@(@IM<V=S='(@(E1U;FYI<W1I;CH@(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E
M;6)E<B(*;7-G<W1R(")S>7ES:W5U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R
M;R(*;7-G<W1R(")397)B:6$@:F$@36]N=&5N96=R;R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`R"FUS9VED(")397)I86P@3G5M
M8F5R(@IM<V=S='(@(E-A<FIA;G5M97)O(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$T.0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4&%L=F5L:6UE;B!T:65D;W0@;W9A
M="!VY.1R:>0@=&%I(&5I=N1T(&]L92!KY'ET971TY'9I<W/D+B(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G
M<W1R("))<W1U;G1O:F5N(&AA;&QI;G1A(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N
M($E$(&5X<&ER960N(@IM<V=S='(@(E-E<W-I;VX@240@;VX@=F%N:&5N='5N
M=70N(@H*(SH@;&EB+V%P:2YP:'`Z,30U"FUS9VED(")397-S:6]N<R(*;7-G
M<W1R("))<W1U;FYO="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M,3@*;7-G:60@(E-E="(*;7-G<W1R(")!<V5T82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HW.0IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U
M('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET
M+B(*;7-G<W1R("(B"B)386QA<V%N86X@<F5S971O:6YT:6EN(&QI:71T>79I
MY"!A<V5T=6MS:6$L(&IO<R!J;W-K=7,@=6YO:&1A="!S86QA<V%N87-I+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3@*;7-G:60@(E-E="!U<"!R
M96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO
M=7(@<&]R=&%L+B(*;7-G<W1R("(B"B)6;VET(&%S971T86$@=6QK;VES=&5N
M('!A;'9E;&EM:65N(&%S971U:W-E="P@:F]I=&$@:&%L=6%T(&OD>71TY.0@
M(@HB<&]R=&%A;&ES<V$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@W
M"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE
M(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(B(*(E9O:70@87-E='1A82!K
MY'ET971TY';D;B!K:65L96XL(&%I:V%V>?9H>6MK965N(&IA(&UU:71A('#D
M:7;D;>3D<N1A<V5T=6MS:6$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$P,0IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@
M8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D
M:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*(E9O:70@87-E='1A82!A;&]I
M='5S;VAJ96QM86XL(';D<FET965M86XL(&[D:WEMY&X@<.1I=FET>6MS96X@
M:F$@;75I=&$@(@HB;N1K>6WDY&X@;&EI='1Y=FGD(&%S971U:W-I82XB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W"FUS9VED(")3971U<"(*;7-G
M<W1R(")!<V5N;G5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X
M+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B
M;&4B"FUS9W-T<B`B07-E;FYU:W-E;B!PY&EV:71Y<W-K<FEP=&D@;VX@<V%A
M=&%V:6QL82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*
M;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A
M<F%M971E<CH@(@IM<V=S='(@(E5S96%T('!A:6MA="!S;W!I=F%T(&%N;F5T
M='5U;B!P87)A;65T<FEI;CH@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,PIM<V=I9"`B4V5Y
M8VAE;&QE<R(*;7-G<W1R(")397EC:&5L;&ET(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0Y.`IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B3W-T
M;VMS970B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PIM
M<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R("),>6AY="!K=79A=7,Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U,`IM<V=I9"`B4VAO=6QD(&%C
M8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@
M(D%S971E=&$@<&EK879A;&EN=&%NY'!PY&EM970@=7-E:6UM:6QL92!L:6YK
M96EL;&4N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B3N1Y=.0B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E
M='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D
M("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(D[D>73D(&5R;V%V86ES
M=75D970@87-E='5K<VEE;B!T86QL971E='5S<V$@:F$@=75D97-S82!J=75R
M:2!M=6]K871U<W-A("(*(G9E<G-I;W-S82XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#DT"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N
M(&QO9V=I;F<@:6X_(@IM<V=S='(@(D[D>73D(&5D96QL:7-E;B!S:7/DY&YK
M:7)J875T=6UI<V5N('#D:7;D>7,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3<V.0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA
M;"(*;7-G<W1R(").Y'ETY"!A<V5T=7,@<&ETY.1K<V5S:2!A;&MU<&5RY&ES
M96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDY"FUS9VED(")3
M:&]W('!I8VME<B(*;7-G<W1R(").Y'ETY"!V86QI='-I;B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,S`*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T
M:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B3N1Y=.0@=&%U;'5K:V]T;VEM:6YN
M;W0@=F%L:6MK;RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4S"B,L
M('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE
M9G0_(@IM<V=S='(@(D[D>73D('9A<V5M;6%L;&$@)7,@=F%L:6MK;RXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B3N1Y=.0@=&%U;'5K;VX@<V]L=6X@=&EE9&]T(&1I
M86QO9VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I
M97,@9&EA;&]G(@IM<V=S='(@(D[D>73D('1A=6QU:V]N('1I961O="!D:6%L
M;V=I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R
M=&EE<R!D:6%L;V<B"FUS9W-T<B`B3N1Y=.0@=&%U;'5K;VX@<FEV:6X@=&EE
M9&]T(&1I86QO9VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R
M;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(D[D>73D(&MU=F%N('1I961O="!D
M:6%L;V=I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V-PIM<V=I
M9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B3N1Y=.0@='5O;G1I(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H
M;W=E<G,B"FUS9W-T<B`B4V%T96ET82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S($5A<FQY(@IM
M<V=S='(@(E-A=&5I=&$@86EK86ES:6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B4VAO=V5R<R!,871E(@IM
M<V=S='(@(E-A=&5I=&$@;7GV:&5M;6EN(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-H;W=E<G,@:6X@=&AE
M(%9I8VEN:71Y(@IM<V=S='(@(E-A=&5I=&$@;.1H971T>79I;&QA(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV,3D*
M;7-G:60@(E-H<FEN:R(*;7-G<W1R(")0:65N96YNY"(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3$P"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3<R"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`U.`HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q
M,C`*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HQ,3@S"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z,3(R,PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C$R-3(*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HQ,C@U"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG
M:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T
M<B`B4&EE;F5N;N0@=&%I('-I:7)RY"!V:65R96ES:>0@;W-I;VET82P@:F]T
M=&$@;F4@96EVY'0@;VQE('1I96QLY"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3$*;7-G:60@
M(E-I97)R82!,96]N92(*;7-G<W1R(")3:65R<F$@3&5O;F4B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8V"FUS9VED(")3:6=N('5P
M(@IM<V=S='(@(DMI<FIA=61U(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HW,3,*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R(")!;&QE
M:VER:F]I='5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HW,3(*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B06QL
M96MI<FIO:71U:W-E;B!A;&=O<FET;6DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V"FUS9VED
M(")3:6YG87!O<F4B"FUS9W-T<B`B4VEN9V%P;W)E(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3`P
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3D@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(T,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,C4P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,38*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$P.0IM<V=I9"`B4VEZ92(*;7-G<W1R(")+;VMO
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B3VAI=&$@>6QL
MY'!I=&]T96ATY';D="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`*;7-G:60@(E-L;W9A:VEA
M(@IM<V=S='(@(E-L;W9A:VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.`IM<V=I9"`B4VQO
M=F5N:6$B"FUS9W-T<B`B4VQO=F5N:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R(*;7-G<W1R("),
M=6UI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3<*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(DQU;6ES861E='1A(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G
M:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R("),=6UI<V%T96ET82(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3
M;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B3'5M:7-A=&5I=&$@86EK86ES
M:6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B3'5M:7-A=&5I
M=&$@;7GV:.3D;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@U"FUS9VED
M(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B3'5M96X@<WEV>7ES.B`B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(X.0IM<V=I9"`B4VYO=R!E<75I=F%L96YT
M(&EN('=A=&5R.B`B"FUS9W-T<B`B3'5M96X@;>3D<N0@=F5T96[D.B`B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`R"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B
M4V%L;VUO;B!S86%R970B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T"FUS9VED(")3;VUA;&EA
M(@IM<V=S='(@(E-O;6%L:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B3&%U;'5T(&IA(%)U
M;F]U<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,3(*;7-G:60@
M(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(DKD<FIE<W1Y:W-E;B!S
M=75N;F%N('9A;&EN=&$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D<F5S
M<R(*;7-G<W1R("),Y&AD96]S;VET92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34*;7-G:60@
M(E-O=71H($%F<FEC82(*;7-G<W1R(")%=&5LY"U!9G)I:VMA(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E-O=71H($5U<F]P96%N("A)
M4T\M.#@U.2TS*2(*;7-G<W1R(")%=&5LY"U%=7)O;W!P82`H25-/+3@X-3DM
M,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#$*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H
M92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(D5T96SD+4=E;W)G
M:6$@:F$@971E;.1I<V5T(%-A;F1W:6-H('-A87)E="(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O
M=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B171E;.1I;F5N('!A;&QO;G!U
M;VQI<VMO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B
M"FUS9W-T<B`B5N1L:2!V:65R96ES970@<V]L=6IE;B!VY&QI<W/D(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G
M:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB
M"FUS9W-T<B`B5N1L:2!S;VQU;B!L96EPY'1E:W-T:6X@:F$@<F5U;F%N(';D
M;&ES<^0@(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$Y"FUS9VED
M(")3<&%C97(B"FUS9W-T<B`B5N1L:2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0IM<V=I9"`B4W!A8VEN9R(*
M;7-G<W1R(")6Y&QI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN
M9R(*;7-G<W1R(")6Y&QI(&IA('3D>71E(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#`*;7-G:60@
M(E-P86EN(@IM<V=S='(@(D5S<&%N:F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3`P"FUS9VED(")3<&%M(@IM<V=S='(@(E)O<VMA<&]S=&DB
M"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@
M0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(D5R:6MO:7-M97)K:VEE;B!S>?9T
M=/8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@(DIA82!S;VQU
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(DIA82!S87)A
M:V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B2F%A(')I=FDB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E-P;W)T<R(*
M;7-G<W1R(")5<FAE:6QU(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Q"FUS9VED(")3<FD@3&%N
M:V$B"FUS9W-T<B`B4W)I($QA;FMA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HX,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C8*;7-G:60@(E-T
M86YD87)D(@IM<V=S='(@(E-T86YD87)D:2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(E-T87(@5')E
M:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.3`@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C<Y-0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R
M(")!;&MA;6ES=G5O<VDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4W,0IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B
M3.3D;FD@=&%I(&%L=64B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD
M97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(E1I;&$B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`Q"FUS9VED(")3=&]R86=E(&9O
M<FUA="(*;7-G<W1R(")486QL96YN=7-M=6]T;R(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")3=')E970@061D<F5S
M<R(*;7-G<W1R(")+871U;W-O:71E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*
M;7-G<W1R("),Y'!I;'GV;G1I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(S-PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B365R:VMI:F]N
M;VQI<W1A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM<V=I
M9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B4&]I
M<W1A('1O:6UI86QU92!O<V]I='1E97-T82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE
M(%M#4U-=(@IM<V=S='(@(E1Y>6QI(%M#4U-=(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T
M<B`B<W4B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%L:6AA:V5M:7-T;V$@7"(E<UPB(&5I(&SV>71Y;GET+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G
M:60@(E-U8FIE8W0B"FUS9W-T<B`B3W1S:6MK;R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,S-B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R
M+G!H<#HS,3<*;7-G:60@(E-U8FUI="(*;7-G<W1R("),Y&AE=.0B"@HC.B!S
M:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E
M9"!R97%U97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A
M;FYO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P
M<')O=F5D+B(*;7-G<W1R("(B"B),Y&AE=&5T=&EI;B!<(B5S7"(Z;B!L:7/D
M>7-P>7EN=/8N($5T('9O:2!K:7)J875T=6$@<VESY.1N(&5N;F5N(&MU:6X@
M(@HB<'EY;G3V<VD@;VX@:^1S:71E;'1Y(&IA(&AY=N1K<WET='DN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I
M9"`B4W5B<V-R:7!T(@IM<V=S='(@(D%L:6MI<FIO:71U<R(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C
M8V5S<R(*;7-G<W1R(")/;FYI<W1U:2(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S
M7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB.B!L:7/DY&UI;F5N
M(&KD<FIE<W1E;&WDY&X@;VYN:7-T=6DN(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D
M(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T
M<B`B2^1Y='3D:N1N(%PB)7-<(B!KY'ET=.1JY'1I971O:F5N('!O:7-T86UI
M;F5N(&KD<FIE<W1E;&WD<W3D(&]N;FES='5I+B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S
M='(@(EPB)7-<(B!P;VES=&5T=&EI;B!O;FYI<W1U;F5E<W1I+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R
M(")<(B5S7"(Z(&]N;FES='5T=&EI;B!P;VES=&%M86%N(&KD<FIE<W1E;&WD
M<W3D+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U
M8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@
M<V5E(&-H86YG97,N(@IM<V=S='(@(B(*(E!A;&%T=&EI;B!O;FYI<W1U;F5E
M<W1I('9A;FAO:6AI;B!A<V5T=6MS:6EN+B!,871A82!S:79U('5U9&5S=&%A
M;B`B"B)NY&ADY&MS97-I(&UU=71O:W-E="XB"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HU-R!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D*;7-G:60@
M(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B5&%L;&5N;F5T=&EI;B!A<V5T=6MS:65N('9A<FUU=7-K;W!I;RXB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R
M871I;VX@9FEL92`E<RXB"FUS9W-T<B`B5&%L;&5N;F5T=&EI;B!A<V5T=6MS
M:65N('9A<FUU=7-K;W!I;R`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@7"(E
M<UPB(@IM<V=S='(@(B<E<R<Z('#D:79I='ES(&]N;FES='5I+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C<R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E
M<R(*;7-G<W1R("(E<SIN(&MI<FIO:71T86UI;F5N(&]N;FES='5I+B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(E-U9&%N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M-@IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R(")9:'1E96YV971O(@H*(SH@;&EB
M+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES92(*;7-G<W1R
M(")!=7)I;F=O;FYO=7-U(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X
M"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(D%U<FEN9V]N;&%S:W4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B
M4W5N;GDB"FUS9W-T<B`B075R:6YK;VEN96XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C`U"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(D%U
M<FEN9V]N;F]U<W4B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM
M<V=S='(@(D%U<FEN:V\@;F]U<V5E+VQA<VME92(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,#0*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R
M(")!=7)I;F=O;FYO=7-U.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C`X"FUS9VED(")3=6YS970B"FUS9W-T<B`B075R:6YG;VYL87-K
M=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#<*;7-G:60@
M(E-U;G-E=#H@(@IM<V=S='(@(D%U<FEN9V]N;&%S:W4Z("(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U
M<&5R<V-R:7!T(@IM<V=S='(@(E#DY&QL96MI<FIO:71U<R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS.#`*;7-G:60@(E-U<'!O<G0B"FUS9W-T
M<B`B5'5K:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,34*;7-G:60@(E-U<FEN86UE(@IM<V=S
M='(@(E-U<FEN86TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W-0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R(")3=6MU;FEM:2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#D*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS
M9W-T<B`B2'5I<'!U=G5O<F5T(&IA($IA;B!-87EE;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3D*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R(")3=V%Z:6UA82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#4*;7-G:60@(E-W961E;B(*;7-G<W1R(")2=6]T<VDB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B4W9E:71S:2(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC
M(&QO9R!D96QE=&5D(@IM<V=S='(@(E-Y;F,@;&]K:2!P;VES=&5T='4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30U"FUS9VED(")3>6YC34PB"FUS
M9W-T<B`B4WEN8TU,(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N
M<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM
M<V=S='(@(E-Y;G1A:W-I=FER:&4@:&%K=71E<FUE:7-SY"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3@*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(E-Y
M>7)I82P@87)A8FET87-A=F%L=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R(")5
M:VMO<VUY<G-K>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8S"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R(")5
M:VMO<VUY<G-K>6KD(&IA('1U=6QI<W1A(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E0M4W1O<FUS(@IM<V=S
M='(@(E5K:V]S;7ER<VMY="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R
M(")5:VMO<VUY<G-K>6KD(&%I:V%I<VEN(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82]T<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B5%-6
M+71I961O<W1O(@H*(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ,S0*
M;7-G:60@(E1A8FQE(@IM<V=S='(@(E1A=6QU:VMO(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B
M5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R(")4875L=6MO;B!T:65D;W0B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS
M9VED(")486)L92!3970B"FUS9W-T<B`B5&%U;'5K;VX@87-E='5K<V5T(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R(")4875L=6MO
M;B!T:65D;W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T"FUS9VED(")486EW86XB
M"FUS9W-T<B`B5&%I=V%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B
M"FUS9W-T<B`B5&%I=V%N+"!+:6EN86X@;6%A:W5N=&$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(U"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(E1A9'II:VES=&%N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S-0IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI
M8R!O9B(*;7-G<W1R(")486YZ86YI82P@66AD:7-T>6YY="!T87-A=F%L=&$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU
M"FUS9VED(")487)G970Z(@IM<V=S='(@(DMO:&1E.B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3,R(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ.#D*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-#D*;7-G:60@(E1A
M<VMS(@IM<V=S='(@(E1E:'3D=N1T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S0*;7-G:60@(E1E;&5P:&]N92!.=6UB97(B"FUS
M9W-T<B`B4'5H96QI;FYU;65R;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,CDW"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("),Y&UP
M]G1I;&$@961E;&QI<V5L;&4@='5N;FEL;&4Z("(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C(Q"FUS9VED(")496UP97)A='5R92(*;7-G<W1R("),Y&UP
M]G1I;&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$R"FUS
M9VED(")496UP97)A='5R93H@(@IM<V=S='(@(DSD;7#V=&EL83H@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G
M.R5S(@IM<V=S='(@(DSD;7#V=&EL83QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F
M9&5G.R5S(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HV
M.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B36%L;&EA(%PB)7-<(B!E:2!L]GET>6YY="XB"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B36%L;&EE;B!H86QL:6YT82(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S,S,0IM<V=I9"`B5&5X="(*;7-G<W1R(")496MS=&DB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Y"FUS9VED(")497AT($]N;'DB"FUS
M9W-T<B`B5F%I;B!T96MS=&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM
M<V=S='(@(E1E:W-T:6X@=&%S875S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R
M(")496MS=&ET;W`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R(")T;R(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G
M<W1R(")4:&%I("A425,M-C(P*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0*;7-G:60@(E1H
M86EL86YD(@IM<V=S='(@(E1H86EM86$B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C@U,0IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B1E10+6QI<^1T;VEM:6YT;R!E:2!O;&4@
M:^1Y=&5T=.1V:7-SY"XB"@HC.B!F<F%M97=O<FLO2&ES=&]R>2](:7-T;W)Y
M+G!H<#HU-0IM<V=I9"`B5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D
M+B(*;7-G<W1R(")(:7-T;W)Y(&KD<FIE<W1E;&WD(&5I(&]L92!KY'ET971T
MY'9I<W/D+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,X"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO
M;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B2&]R
M9&4O2V]L86(@:6YT96=R;VEN=&EM;V]T=&]R:2!E:2!T=64@7"(E<UPB(@H*
M(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP:'`Z,3(Y.`IM<V=I
M9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS
M9W-T<B`B24U34"!L;VMI82!E:2!V;VET=2!A;'5S=&%A+B(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E
M.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R(")-
M86EN=&5N86YC93HZ("UL=6]K86X@;&%T86%M:6YE;B!E<.1O;FYI<W1U:2(*
M"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@
M(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G
M<W1R(")!<V5T=6MS970@:6MK=6YA(&]N('-U;&IE='1U+B!0;VES='5T86%N
M+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@
M861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@
M4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R
M;6ES<VEO;G,N(@IM<V=S='(@(B(*(EEL;.1P:61O;B!P:73DY"!O='1A82!K
MY'ET=/;V;B!P>7-Y=N0@=&%L;&5T=7-T>7EP<&D@4&5R;6ES<VEO;BP@:F]S
M(&AA;'5A="`B"B)KY'ET=.3D(&YI:73D+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B
M;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(E9A:6X@86QA<'5O;&DB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM
M<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF
M:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A
M=&%B87-E+B(*;7-G<W1R("(B"B)#;VYT86-T(&ED(&YU;65R;V$@96D@;VQE
M(&WDY')I=&5L='DL(&]N('1Y:&KD('1A:2!E:2!L]GET>6YY="!T:65T;VMA
M;FYA<W1A+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B66AT97ES=&EE
M9&]T(&QI<^1T=&EI;B!O;FYI<W1U;F5E<W1I(&]S;VET96MI<FIA87-I+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-S(*;7-G:60@
M(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I
M<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*
M(E9I97-T:6X@86QL96MI<FIO:71U:W-E;B!T87)K:7-T86UI<V5E;B!T87)V
M:71A86X@97)I;&QI;F5N(%!'4"TB"B)A;&QE:VER:F]I='5S;&]H:V\N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET
M:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*
M(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B(@HB2F%K96QU;&ES=&%N($E$
M(&5I(&]L;'5T(&WDY')I=&5L='DL(&]N('1Y:&KD('1A:2!E:2!L]GET>6YY
M="!T:65T;VMA;FYA<W1A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(DIA:V5L=6QI<W1A
M82!E:2!O;&QU="!MY.1R:71E;'1Y+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="YP:'`Z,3$V"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R
M97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R(")386QA
M=7-T;VEM:6YN;VX@:^1Y='3V('9A871I('-A;&%T='5A(%=75RUY:'1E>71T
MY"XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-R!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C4Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S
M='(@(E1I961O<W1O<W-A("5S('!I=.1I<VD@;VQL82`E<R!A<V5T=7,N(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S`@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HU,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I
M;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T
M<B`B5&EE9&]S=&]S<V$@)7,@<&ETY&ES:2!O;&QA(&IO:71A:VEN("5S(&%S
M971U:W-I82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,C8*
M;7-G:60@(E1H92!F:6QE(&-A;FYO="!B92!C;W!I960@;VYT;R!I='-E;&8N
M(@IM<V=S='(@(E1I961O<W1O82!E:2!V;VED82!K;W!I;VED82!I='-E;G/D
M('#DY&QL92XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.#`*;7-G
M:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")4:65D
M;W-T;R!O;&D@='EH:N0N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE
M(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS
M9W-T<B`B4V5U<F%A=F%S<V$@;VX@;W1S:6MK;W1I961O="!TY'-TY"!M97-S
M86=E+W)F8S@R,B`M=FEE<W1I<W3D+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C
M<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT
M97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W
M92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E
M<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N
M8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB
M>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H
M870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G
M(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE
M9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T
M<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@HB2V]K;W)U
M=61U;B!NY'ET=/9T:6QA(&%I:&5U='1A82!O;F=E;&UI82!J;VEL;&%K:6X@
M26YT97)N970@17AP;&]R97(@(@HB<V5L86EM96X@:^1Y='3D:FEL;.0N(%9A
M;&ET971T879A<W1I(&MY<V5I;F5N('-E;&%I;B!S:7/D;'3DY"!P:6ER=&5I
M=.0@:F$@(@HB=FER:&5I=.0@:F]I:&EN(&5I(&]L92!L]GET>6YY="!K;W)J
M875S=&$@=&%I(&ME:6YO82!K:65R=.3D(&]N9V5L;6$N("(*(DAU;VUA871H
M86X@971TY"!J;W,@:^1Y=.1T('3D=.0@;N1Y='3V=&EL86$@:F$@26YT97)N
M970@17AP;&]R97(@<V5L86EN=&$L("(*(FYI:6X@;N1Y='3V('-A871T86$@
M;65N;N0@<V5K86ES:6XL(&IO=&MU="!T;VEM:6YN;W0@96EVY'0@=&]I;6D@
M=&%I('-E;&%I;B`B"B)S86%T=&%A(&MA871U82X@2F]S(&OD>73D="!7:6YD
M;W=S(#EX('1A:2!-12!V97)S:6]T82P@;FEI;B!O;B!M86AD;VQL:7-T82`B
M"B)E='3D(&OD>71T]FKD<FIE<W1E;&WD(&MA871U=2!N<RX@)T=E;F5R86P@
M4')O=&5C=&EO;B!&875L="<@+79I<FAE97-E96X@:F$@(@HB<VEN=6X@<&ET
MY.0@:^1Y;FYI<W3DY"!K;VYE('5U9&5S=&%A;BY<7&Y<7&X@375I<W1A(&5T
M=.0@<VEN=6$@;VX@(@HB=F%R;VET971T=2X@3F%P<V%U=&$@3TLM;F%P<'5L
M86$@:F]S(&AA;'5A="!K;VME:6QL92!E9&ET;W)I;B!K;VMO<G5U='4@(@HB
M;N1Y='3V=&EL86$N(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$Q,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N
M(&1E;&5T960N(@IM<V=S='(@(E!O:7-T971T:6EN('!R;V9I:6QI(%PB)7-<
M(BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G
M<W1R(")686EN('9A<V5N('!U;VQI(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE
M($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z
M.B!C;&%S<RXB"FUS9W-T<B`B1VYU4$<@;VAJ96QM86X@<VEJ86EN=&D@<&ET
MY.0@;>3D<FET96QLY"!#<GEP=%]P9W`Z.B`M;'5O:V%S<V$N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-1$XN<&AP.C(P,@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B
M:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N
M;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R
M('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*(E9I97-T:2!LY&AE=&5T='D@)7,@
M=F%S=&%A;F]T=&%J86QL92`E<R!O='-I:VMO;F$@7"(E<UPB(&]N(&[D>71E
M='1Y+EQN(@HB16D@;VQE(&UI=.3D;B!T86ME:71A('-I:73D(&5T=.0@=FEE
M<W1I(&]N(&QU971T=2!T86D@>6UMY')R971T>2XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#@Q"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE
M;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B3FEM:2!J
M;W1A(&OD>71E=.3D;B!L:6YK:71E='3D97-S82!L=6\@<VEV=6QL92(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0W-`IM<V=I9"`B5&AE(&YU
M;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R(")+96YT
M=&EE;B!MY.1RY"!P:73DY"!A;G1A82!N=6UE<F]I;F$N(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C,R"FUS9VED(")4:&4@;W!E
M;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S
M;6EM93HZ(&-L87-S+B(*;7-G<W1R(")-;V1U=6QI(&]P96YS<VP@=&%R=FET
M86%N($AO<F1E7T-R>7!T7W-M:6UE.CH@+6QU;VMA;B!KY'ET=.1M:7-E:W-I
M+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,C@S"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N
M;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB
M;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"B)!<V5T=7-T82!<
M(B5S7"(@:V]S:V$@<V5N('1I961O="!Y;&ET=&EVY'0@=&%L;&5T=7-T879A
M;B!S=75R:6UM86X@<V%L;&ET=6X@(@HB<F%J86XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A
M('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S
M='(@(B(*(D]H:F5L;6%A+"!J;VQL82!V;VD@:V%T<V]A('9I97-T:71Y>7!P
M:>0@*"5S*2P@96D@;/9Y='EN>70@:N1R:F5S=&5L;>1S=.0N(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#@W"FUS9VED(")4:&4@<75O=&4@
M8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S
M='(@(DQA:6YA=7-M97)K:VD@<&ETY.0@;VQL82!Y:W-I='3D:6YE;B!M97)K
M:VDN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N
M;'DB"FUS9W-T<B`B5F%I;B!O:6ME82!J82!V87-E;B!P=6]L:2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*
M;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R(")686EN
M(&]I:V5A('!U;VQI(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M-#<Y"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C
M:&%R86-T97(N(@IM<V=S='(@(D5R;W1I;B!P:73DY"!O;&QA('EK<VET=.1I
M;F5N(&UE<FMK:2XB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@
M8F5E;B!D96QE=&5D+B(*;7-G<W1R(")086QV96QI;B!<(B5S7"(@;VX@<&]I
M<W1E='1U+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N
M('-A=F5D+B(*;7-G<W1R(")086QV96QI;B!<(B5S7"(@;VX@=&%L;&5T971T
M=2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D
M+B(*;7-G<W1R(")3:7/DY&YK:7)J875T=6UI<W!Y>6YT]B`E<R!O;B!P;VES
M=&5T='4N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HT-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-P96-I9FEE
M9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B3>3D<FET96QT
M>>0@<FEV:>0@*"5D*2!E:2!O;&4@;VQE;6%S<V$N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HQ-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T
M<B`B5F%L:>1A:6MA:7-T:65D;W-T;V$@7"(E<UPB(&5I(&]L92!O;&5M87-S
M82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`V"FUS9VED(")4
M:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N
M('1H92!S8W)E96XN(@IM<V=S='(@(DMI<FIO:71T86UA<VD@=&5K<W1I(&5I
M('9A<W1A82!T96MS=&GD(')U=61U;&QA+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T
M;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(E9A:6X@>6SD<'5O
M;&D@:F$@86QA<'5O;&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL
M>2(*;7-G<W1R(")686EN('ELY'!U;VQI(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S
M="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B5'5O='4@=&EE
M=&\@:.1V:7-I(&5D96QL:7-E;B!K;VAD86X@86EK86YA+B(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O1&%T
M82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@
M;F]T(&)E('-A=F5D+B(*;7-G<W1R(")4=6]T=6$@=&EE9&]S=&]A(&5I('9O
M:71U('1A;&QE='1A82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-#D@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q,`IM<V=I9"`B
M5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(D]S:6]T82!W96%T:&5R+F-O;2!E:2!O;&4@:^1Y=&5T=.1V:7-SY"XB
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R(")4965M86AA:V5M:7-T;V$@7"(E<UPB(&5I(&SV>71Y;GET+B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X"FUS9VED(")4:&5R
M92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(D%S971U:W-I
M82!E:2!O;&4@<V%A=&%V:6QL82XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HS-#@*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T
M:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R(")%:2!O;&4@
M;W-I;VET82P@:F]T:V$@=F]I9&%A;B!NY'ET=.3D('9I97-T:65N('EH=&5Y
M9&5S<^0N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C
M=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A
M8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T
M<B`B(@HB5.1S<^0@:V5N=.1S<^0@;VX@;&EI86X@;6]N=&$@;65R:VMIY"X@
M06YN;VET("5S(&UE<FMK:>0[('-I;G5N('!I=.3D(&%N=&%A("(*(G;D:&5M
M;>1N(&MU:6X@)7,@;65R:VMIY"XB"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN
M+W5S97(N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G
M<W1R(")*;VET86MI;B!O;F=E;&UI82!<(B5S7"(@;&ESY.1M:7-E<W/D(&KD
M<FIE<W1E;&WDY&XZ("5S(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@
M9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T
M<B`B(@HB2^1Y='3D:N1N(%PB)7-<(B!KY'ET=.1JY'1I971O:F5N('!O:7-T
M86UI<V5S<V$@:N1R:F5S=&5L;>1S<^0@;VQI(&]N9V5L;6EA.B`B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M
M.B`B"FUS9W-T<B`B2F]I=&%K:6X@;VYG96QM:6$@7"(E<UPB('!O:7-T86UI
M<V5S<V$@:N1R:F5S=&5L;>1S=.0Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P
M9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B2F]I=&%K:6X@;VYG96QM:6$@
M7"(E<UPB('#D:79I='EK<V5S<^0Z("5S(@H*(SH@9G)A;65W;W)K+T)R;W=S
M97(O0G)O=W-E<BYP:'`Z.3(W"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A
M<R!U<&QO861E9"XB"FUS9W-T<B`B5&EE9&]S=&]N('1U;VYN:7-S82!O;&D@
M;VYG96QM:6$N(%EH=.3D;B`E<SIA(&5I('1U;W1U(@H*(SH@9G)A;65W;W)K
M+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3,R"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E
M9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*(E1I961O<W1O;B!T=6]N
M;FES<V$@;VQI(&]N9V5L;6EA+B`E<R!K;VMO(&]L:2!S=75R96UP:2!K=6EN
M('-U=7)I;B!S86QL:71T=2`B"B)K;VMO("@E9"!T879U82DN(@H*(SH@9G)A
M;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3,T"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM
M<V=S='(@(E1I961O<W1O;B!T=6]N;FES<V$@;VQI(&]N9V5L;6EA+B`E<R!L
M871A=71U:2!V86EN(&]S86MS:2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R(")487!A
M:'1U:2!V:7)H92!NY'ET971TY&5S<^0@=FEE<W1I;B!TY'3D(&]S:6]T82(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.0HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@
M9&%T82XB"FUS9W-T<B`B66AT97ES=&EE=&]J96X@='5O;FYI<W-A('1A<&%H
M='5I('9I<FAE+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS
M,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A
M;&5N9&%R(&1A=&$N(@IM<V=S='(@(FE#86QE;F1A<BUT:65T;VIE;B!T=6]N
M;FES<V$@=&%P86AT=6D@=FER:&4N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HX,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C
M;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB
M<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*(D%S971U<W1I971O;&]M86MK
M965S<V$@;VX@:F]K:6X@=FER:&4N($5H:^0@:N1T:70@:F]N:W5N('!A:V]L
M;&ES96X@:V]H9&%N("(*(G3D>71TY&WD='3D+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D
M9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E
M<BXB"FUS9W-T<B`B(@HB5&%P86AT=6D@=FER:&4@>7)I=&5T=.1E<W/D('-U
M;W)I='1A82!O<V]I=&5K:7)J871O:6UI;G1O82X@67)I=.0@;7GV:&5M;6EN
M("(*(G5U9&5S=&%A;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@
M86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(EEH=&5Y<W1I971O:F5N('#D:79I
M='EK<V5S<^0@=&%P86AT=6D@=FER:&4N(%ER:73D(&UY]FAE;6UI;B!U=61E
M<W1A86XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N(@IM<V=S='(@(DIA:V5L=6QI<W1A;B!PY&EV:71Y:W-E<W/D('1A<&%H
M='5I('9I<FAE+B!9<FETY"!M>?9H96UM:6X@=75D97-T86%N+B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.0IM<V=I9"`B
M5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L
M9&5R<RXB"FUS9W-T<B`B5.1MY"!)34%0('!A;'9E;&EN(&5I('1U92!K86YS
M:6]I9&5N(&IA:V%M:7-T82XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R(")4Y&WD('1I961O
M<W1O(&5I('9A:6MU=&$@<F%R+71I961O<W1O;'1A+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E
M<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@
M(E3D;>0@=&EE9&]S=&\@96D@=F%I:W5T82!Z:7`M=&EE9&]S=&]L=&$N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S,0IM<V=I9"`B5&AI<R!D
M;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S
M='(@(E3D;>0@96D@=F%I:W5T82!O:6ME86QT82!K;W)T=&EN=6UE<F]L=&$N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB
M8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*
M;7-G<W1R("(B"B)4Y&QLY"!A:G5R:6QL82!V;VD@;.1H971TY.0@=FEE<W1E
M:N0@0VQI8VMA=&5L;&EN("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI("(*(F=A
M=&5W87D@<&%L=F5L=6$@2%144"!!4$DZ;&QA+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R
M:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!7
M24X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$DB"FUS9W-T<B`B(@HB5.1L;.0@86IU<FEL;&$@=F]I(&SD:&5T
M=.3D('9I97-T96KD(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&=A=&5W87D@
M(@HB<&%L=F5L=6X@:V%U='1A($A45%`@05!).FQL82XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B
M(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(E3D;&SD
M(&%J=7)I;&QA('9O:2!LY&AE='3DY"!V:65S=&5JY"!S;7,R96UA:6P@*&AT
M='`Z+R]S;7,R96UA:6PN8V]M*2`B"B)G871E=V%Y('!A;'9E;'5N(&MA=71T
M82!(5%10($%023IL;&$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@
M=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O
M;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H
M("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S
M='(@(B(*(E3D;&SD(&%J=7)I;&QA('9O:2!LY&AE='3DY"!V:65S=&5JY"!6
M;V1A9F]N96X@;G5M97)O:6AI;B!33510.FQLY"!KY'ET=.1E;B`B"B)6;V1A
M9F]N92!)=&%L>2!G871E=V%Y('!A;'9E;'5A+B!4Y'3D('!A;'9E;'5A('9O
M:2!KY'ET=.3D('9A:6X@5F]D869O;F4@(@HB271A;'D@*&AT='`Z+R]W=W<N
M,3DP+FET*2!T=6YN=6MS:6QL82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HY.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V,0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DP(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q,3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X-B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8P"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S,#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P,@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-38Q(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X-#,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV,B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`Y"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(P,S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`X,@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34S(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R,C4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q
M,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4T"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(V-#$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q
M-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(S(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,S,#$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S@P.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#$W"FUS9VED(")4:&ES
M(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R(")4Y&WD(&ME;G1TY"!O;B!P
M86MO;&QI;F5N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-CD*
M;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB
M"FUS9W-T<B`B5.1S<^0@:V5N=.1S<^0@<&ETY.0@;VQL82!V86EN(&MO:V]N
M86ES;'5K=6IA+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C`*
M;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N
M9"!T:&4@8V]L;VXN(@IM<V=S='(@(E3D<W/D(&ME;G3D<W/D('!I=.3D(&]L
M;&$@;G5M97)O:71A(&IA('!I;&MK=2UM97)K:V5JY"XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#DX"FUS9VED(")4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R(")4Y'-SY"!K96YT
MY'-SY"!P:73DY"!O;&QA(&]K=&%A;&EL=6MU:F$N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$R-PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E
M(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B
M"FUS9W-T<B`B(@HB5.1S<^0@:V5N=.1S<^0@<&ETY.0@;VQL82!L:7-T82!K
M;VMO;F%I<VQU:W5J82P@:F]T:V$@<&ETY.0@;VQL82!E<F]T971T=2`B"B)P
M:6QK=6QL82!T86D@=N1L:6QY]FYN:6QLY"(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.CDY,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L
M:60@;G5M8F5R+B(*;7-G<W1R(")!<G9O;B!P:73DY"!O;&QA(&YU;65R;RXB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#(R"FUS9VED("(B"B)4
M:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'
M0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S
M='(@(B(*(E3D<W/D(&ME;G3D<W/D(&]N(';D<FEMY.1R:71Y<RP@:F]N:V$@
M<&ETY.0@;VQL82!21T(@2&5X(&UU;V1O<W,L("(*(F5S:6UE<FMI:W-I("<C
M,3(S-&%F)RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C4*;7-G
M:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS
M9W-T<B`B5.1MY"!L;VUA:V4@;VX@:F\@:^1S:71E;'1Y+B(*"B,Z('1E;7!L
M871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M:7,@:7,@)7,N(@IM<V=S='(@(E3D;>0@;VX@)7,N(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HT-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI
M<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA
M="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R
M(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET
M("5S(@IM<V=S='(@(B(*(E3D;>0@;VX@2V]L86(@1W)O=7!W87)E(&]B:F5K
M=&DN($MA='-O86MS97-I('3D;>1N(&]B:F5K=&EN('-I;G5L;&$@<&ETY.0@
M(@HB;VQL82!SY&AK]G!O<W1I;VAJ96QM82P@:F]K82!Y;6WD<G3DY"!+;VQA
M8B!'<F]U<'=A<F4@9F]R;6%A='1I82X@3&ES=&$@(@HB>6AT965N<V]P:79I
M<W1A('/D:&OV<&]S=&EO:&IE;&UI<W1A(&SV>71Y>2!O<V]I='1E97-T82`E
M<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@
M:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB
M"FUS9W-T<B`B(@HB5.1MY"!V:65S=&D@;VX@:VER:F]I=&5T='4@97)I(&UE
M<FMI<W3V;&SD("@E<RD@:W5I;B!M:6OD('-I;G5L;&$@;VX@(@HB:^1Y=/9S
M<^0N("(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V"FUS
M9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T
M<B`B3G5M97)O;B!P:73DY"!O;&QA(';D:&EN=.3D;B!Y:W-I+B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B
M5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL
M97,N(@IM<V=S='(@(E3D;&SD('!A;'9E;&EM96QL82!E:2!V;VD@875K86ES
M=&$@>FEP+2!T86D@9WII<"UT:65D;W-T;VIA+B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E
M;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(E3D;>0@:N1R
M:F5S=&5L;>0@;VX@<&]I<R!PY.1L=.0N(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A
M(&YU;6)E<BXB"FUS9W-T<B`B07)V;VX@<&ETY.0@;VQL82!N=6UE<F\N(@H*
M(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B
M5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I
M;F1O=R(*;7-G<W1R(")4Y&WD;B!I:VMU;F%N('9O:2!A=6MA:7-T82!V86EN
M($%S971U:W-E="!I:VMU;F%S=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R(")-
M>7)S:WDB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,V"FUS9VED
M(")4:6-K971S(@IM<V=S='(@(E1I:V5T:70B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-#(Y('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U
M-0IM<V=I9"`B5&EM92(*;7-G<W1R(")!:6MA(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,X.`IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R
M(")!:F%N<V5U<F%N=&$B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*;7-G
M:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(D%J86X@97-I='ES;75O=&\B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,U"FUS9VED(")4:6UE('-E
M;&5C=&EO;B(*;7-G<W1R(")!:F%N('9A;&EN=&$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P
M"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R(")4:6UO<BU,97-T92(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(E1I
M='1E;&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(D]T<VEK
M:V\@*'1O;VQT:7`I.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(E9A<W1A86YO='1A
M:F$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C4T"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@
M9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*
M(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B)6;VED86MS97-I('9A;&ET
M82!U<V5A;7!I82!V86EH=&]E:'1O:F$L('!I9.0@0V]N=')O;"T@*%!#*2!T
M86D@0V]M;6%N9"T@(@HB*$UA8RD@;N1P<.1I;G3D('!O:&IA<W-A(&MU;B!N
M87!S875T870@:&EI<F5N('!A:6YI:V5T=&$N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,P,`IM<V=I9"`B5&]D87DB"FUS9W-T<B`B5.1N
MY.1N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(D[D>73D
M($A434PM;.1H9&5K;V]D:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,*;7-G:60@(E1O9V\B
M"FUS9W-T<B`B5&]G;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C8*;7-G:60@(E1O:V5L874B
M"FUS9W-T<B`B5&]K96QA=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS,#(*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(DAU;VUE;FYA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R.0IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B5&]N9V$B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VMO;&%B+G!H<#HQ,#0*;7-G:60@(E1O
M;R!M86YY(&EN=F%L:60@;&]G:6YS(&1U<FEN9R!T:&4@;&%S="!M:6YU=&5S
M+B(*;7-G<W1R("(B"B),:6EA;B!M;VYT82!E<.1O;FYI<W1U;G5T=&$@:VER
M:F%U='5M:7-Y<FET>7-TY"!V:6EM96ES:6UP:65N(&UI;G5U='1I96X@(@HB
M:W5L=65S<V$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@Q"FUS9VED(")4;W`B"FUS9W-T<B`B66SV<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G
M:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B66QI;7#DY&X@:V5H>6MS
M965N("A?=&]P*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I
M9"`B5')A;G-L871I;VYS(@IM<V=S='(@(DODY&YN]FMS970B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,R"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(E1R
M:6YI9&%D(&IA(%1O8F%G;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$W.30*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B5&]S:2!V86D@
M97#D=&]S:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(G1I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M.`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R(")4=6YI<VEA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(E1U<FMK:2(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY
M*2(*;7-G<W1R(")4=7)K:VD@*$E33RTX.#4Y+3DI(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M-PIM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(E1U<FMM96YI<W1A;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,C`*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD
M<R(*;7-G<W1R(")4=7)K<R!J82!#86EC;W,@<V%A<F5T(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S,PIM<V=I9"`B5'5V86QU(@IM<V=S='(@(E1U=F%L=2(*"B,Z(&9R86UE
M=V]R:R]#3$DO0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z
M("(*;7-G<W1R(")+:7)J;VET82!V86QI;G1A<VDZ("(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-3@*;7-G:60@(E4N5BX@:6YD97@Z("(*
M;7-G<W1R(")5+E8N("UI;F1E:W-I.B`B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F
M;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R
M(")54DP@:F]H;VX@<&%L875T971A86X@<VMR:7!T:6X@<W1A='5S(')A<&]R
M='1I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY-PIM<V=I9"`B55),.B(*;7-G<W1R(")54DPZ(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M-PIM<V=I9"`B56=A;F1A(@IM<V=S='(@(E5G86YD82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S8*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B56MR86EN82(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q.0IM<V=I9"`B56YA8FQE('1O(&%C
M8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")61E,M:&%K96UI<W1O82!E
M:2!V;VET=2!L=6ME82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O
M<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(DOD>71TY&KD;B!L
M:7/D=&EE=&]J96X@;&ESY'ES(&5I(&]N;FES='5N=70@:VER:F%U='5M:7-E
M<W-A+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,SDS"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F
M;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")%:2!V;VD@=F%I:'1A82!O
M:6ME=6MS:6$@5D93+71I961O<W1O;&QE(%PB)7-<(BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HS.3(@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA
M;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(")%
M:2!V;VD@=F%I:'1A82!O:6ME=6MS:6$@5D93+71I961O<W1O;&QE("5S+R5S
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S@V"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@
M(D5I('9O:61A('9A:6AT86$@)7,Z;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`B5&EE9&]S=&]N
M(%PB)7-<(B!K;VMO82!E:2!V;VET=2!T87)K:7-T86$N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z-CDU(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HX-3`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ
M,#(X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE
M('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R(")%:2!V;VED82!N:6UE=.0@
M=75D96QL965N(%9&4RUT:65D;W-T;V$@7"(E<R\E<UPB+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HT,SD*;7-G:60@(E5N86)L92!T;R!C
M;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(E-13"UP86QV96QI;65E
M;B!E:2!S86%D82!Y:'1E>71TY"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C@W,`IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN
M(@IM<V=S='(@(EEH=&5Y='3D(&5I('9O:61A(&UU;V1O<W1A82!34TPM<V%L
M871T=6YA+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S,B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S<*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C(P-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,C`Y"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HR,3<*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R
M(")61E,M=&EE9&]S=&]A(&5I('9O:61A(&MO<&EO:61A+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,S<P"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S
M='(@(D5I('9O:61A(&QU;V1A(%9&4RUH86ME;6ES=&]A(%PB)7-<(BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-C$@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,C8T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(D5I('9O:61A(&QU;V1A(%9&4RUH86ME;6ES=&]A
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(D5I('9O:71U
M(&QU;V1A(%9&4RUT:65D;W-T;V$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")%:2!V;VED82!N:6UE
M=.0@=75D96QL965N(%9&4RUK86YS:6]T82!<(B5S7"(N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<R"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R(")%:2!V;VET=2!L=6]D82!T
M>6AJY.0@5D93+71I961O<W1O82XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O9WII<"YP:'`Z-SD*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+W1A<BYP:'`Z-S8*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S
M(&1A=&$N(@IM<V=S='(@(E1I971O82!E:2!V;VED82!L86%J96YT86$N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,#,@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HR,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M+B(*;7-G<W1R(")%:2!V;VED82!P;VES=&%A(%PB)7-<(BP@:&%K96UI<W1O
M(&5I(&]L92!T>6AJY"XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R(")%:2!V;VED82!P
M;VES=&%A(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,S,X(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,3$*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T,B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C,Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*
M;7-G<W1R(")%:2!V;VED82!P;VES=&%A("5S+"!H86ME;6ES=&\@96D@;VQE
M('1Y:&KD+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS
M-38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,V,`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*
M;7-G<W1R(")%:2!V;VED82!P;VES=&%A(%9&4RUH86ME;6ES=&]A(')E:W5R
M<VEI=FES97-T:2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS
M-#0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,U,@IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*
M;7-G<W1R(")%:2!V;VED82!P;VES=&%A(%9&4RUH86ME;6ES=&]A+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#(P(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z-#,R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(D5I('9O:61A
M('!O:7-T86$@5D93+6AA:V5M:7-T;V$Z("5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,C$R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")%:2!V;VED
M82!P;VES=&%A(%9&4RUT:65D;W-T;V$@7"(E<UPB+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C,Q,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,38W"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#`@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X-PHC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HS.3D*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR
M.3$*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@
M(D5I('9O:61A('!O:7-T86$@5D93+71I961O<W1O82XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")%
M:2!V;VED82!P;VES=&%A(%9&4RUK86YS:6]T82!<(B5S7"(N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G
M<W1R(")%:2!V;VED82!P;VES=&%A(%9&4SKDY"!R96MU<G-I:79I<V5S=&DZ
M("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,T"FUS9VED
M(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G
M<W1R(").>6MY:7-TY"!H86ME;6ES=&]A(&5I('9O:71U('-E;'9I='3DY"XB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8P-`IM<V=I
M9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G
M<W1R(")687)M96YT965N('1I971O:F$@96D@=F]I9&$@97AT<F%K=&]I9&$B
M"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#,W(&9R86UE=V]R
M:R].971?24U34"])35-0+T%U=&@N<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS
M9W-T<B`B3>3D<FET>6MS96X@)7,@;'5K96UI;F5N(&5PY&]N;FES='5I+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P,R!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR,#@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$W-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,3<Y"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`B
M16D@=F]I9&$@<VEI<G3DY"!61E,M=&EE9&]S=&]A+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.3@@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HY,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P-B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C8U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D5I('9O
M:61A('!O:7-T86$@5D93+71I961O<W1O82!<(B5S7"(N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@T(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C$T,0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R
M:71I;F<N(@IM<V=S='(@(D5I('9O:61A(&%V871A(%9&4RUT:65D;W-T;V$@
M:VER:F]I='5S=&$@=F%R=&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C@S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S-PHC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S8*;7-G:60@(E5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R(")%:2!V;VED82!A=F%T82!6
M1E,M=&EE9&]S=&]A+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@
M87)C:&EV92XB"FUS9W-T<B`B5&EI=FES=&5T>6X@=&EE9&]S=&]N(&%U:V%I
M<W4@97#D;VYN:7-T=6DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@U
M-@IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@
M9F%I;&5D*2XB"FUS9W-T<B`B16D@=F]I='4@;'5K96$@5D93+71I961O<W1O
M82`H9FEL97-I>F4H*2!E<.1O;FYI<W1U:2DN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C@X-PIM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@
M*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B16D@=F]I9&$@;'5K
M96$@5D93+71I961O<W1O82`H9V5T1FEL95-I>F4H*2!E<.1O;FYI<W1U:2DN
M(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R
M+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS
M9W-T<B`B16D@=F]I='4@;'5K96$@=&EE9&]S=&]A.B`B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HV-S8*;7-G:60@(E5N86)L92!T;R!R96%D
M('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B=F9S<F]O="!J=75R
M:6AA:V5M:7-T;V$@96D@=F]I='4@;'5K96$N(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,3`Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E
M861Y(&5X:7-T<R(*;7-G<W1R("(B"B)5=61E;&QE96YN:6UEY&UI;F5N("5S
M("5S.FMS:2!E<.1O;FYI<W1U:2!K;W-K82!K;VAD96AA:V5M:7-T;R!O;B!J
M;R!O;&5M87-S82(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS,#$*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B16D@=F]I9&$@;FEM973D('5U9&5L;&5E;B!61E,M:&%K96UI
M<W1O82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,S,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O
M<GDZ("5S+B(*;7-G<W1R(")%:2!V;VED82!N:6UE=.0@=75D96QL965N(%9&
M4RUH86ME;6ES=&]A.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C,T."!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(W,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B16D@=F]I9&$@;FEM973D('5U9&5L;&5E;B!61E,M=&EE
M9&]S=&]A(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HV,3<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S
M+B(*;7-G<W1R(")%:2!V;VED82!N:6UE=.0@=75D96QL965N(%9&4RUT:65D
M;W-T;V$@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C(Q,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#4R"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.3,@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,P.0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C,R-@IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS
M9W-T<B`B16D@=F]I='4@;FEM973D('5U9&5L;&5E;B!61E,M=&EE9&]S=&]A
M+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES
M;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM
M<V=S='(@(D5I('9O:61A('-U;W)I='1A82!K;VUE;G1O82`G;6MI<V]F<R<N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU
M.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE
M;G0B"FUS9W-T<B`B5V]R9"UD;VMU;65N='1I82!E:2!V;VET=2!KY.1N=.3D
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-30@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HQ-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B16D@=F]I
M9&$@:VER:F]I='1A82!61E,M=&EE9&]S=&]A(%PB)7-<(BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ.#8*;7-G:60@(E5N86)L92!T;R!W
M<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(D5I('9O
M:61A(&MI<FIO:71T86$@5D93+71I961O<W1O;VX@*&-O<'DH*2!E<.1O;FYI
M<W1U:2DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@X(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#8*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$U,0IM<V=I9"`B56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(D5I('9O:61A(&MI<FIO:71T
M86$@5D93+71I961O<W1O;B!T:65T;VIA+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HX-C(*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@
M<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS9W-T<B`B16D@=F]I9&$@:VER
M:F]I='1A82!61E,M=&EE9&]S=&]A+"!K:6EN=&GV(&]N('3D>6YNY"XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS
M9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B06QL979I:79A='1U(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM
M<V=S='(@(E!E<G4@;75U=&]K<V5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S
M="!A8W1I;VXB"FUS9W-T<B`B4&5R=75T=&%A(&5D96QL:7-E;B!T;VEM96YP
M:71E96XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HR,C(*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S@Y"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N
M(&-O;FYE8W1I;VXZ("(*;7-G<W1R(")4=6YT96UA=&]N('9A<W1A=7,@<&%L
M=F5L:6UE;'1A('EH=&5Y=&5E;CHB"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HR,3@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,W-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS.#,*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O
M;2!S97)V97(@=&\Z("(*;7-G<W1R(")4=6YT96UA=&]N('9A<W1A=7,@<&%L
M=F5L:6UE;'1A.B`B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R("),=6]K
M:71T96QE;6%T;VXB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I
M9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(E5N:6-O9&4@*%541BTX*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G
M<W1R(")9:&1I<W1Y;F5E="!A<F%B:65M:7)A871I="(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M.`IM<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B66AD:7-T>6YE970@
M:W5N:6YG87-K=6YN870B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P"FUS9VED(")5;FET960@
M4W1A=&5S(@IM<V=S='(@(EEH9'ES=F%L;&%T(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.0IM
M<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM
M<V=S='(@(EEH9'ES=F%L=&]J96X@5'EY;F5N;65R96X@97)I;&QI<W-A87)E
M="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z-S@@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C8R"FUS9VED(")5;FET<R(*;7-G<W1R(")-:71T87EK
M<VEK]G0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C4X(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R.0HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,S`*;7-G:60@(E5N:VYO=VXB
M"FUS9W-T<B`B5'5N=&5M871O;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM
M<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R(")4=6YT96UA=&]N(&%P
M:6US9VED("A!4$D@365S<V%G92!)1"DN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N
M(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(E1U;G1E
M;6%T;VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30W"FUS9VED(")5;FMN;W=N(&QO
M8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")!;FYE='1U('!A:6MK871I971O
M(&]N('1U;G1E;6%T;VXN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE
M(&]R('!A<W-W;W)D+B(*;7-G<W1R(")4=6YT96UA=&]N(&OD>71TY&KD='5N
M;G5S('1A:2!S86QA<V%N82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@
M8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(E!O:7-T82!N>6MY:7-E;B!E;&5M
M96YT:6X@;&EN:VET>7,B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I
M='DN<&AP.C,P,@IM<V=I9"`B56YN86UE9"(*;7-G<W1R(").:6UE=/9N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM
M<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#
M=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y
M(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A
M="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W
M(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B
M"B)4:65T;W1U<G9A<WEI<W3D(&5I+7!R:79I;&5E9VES970@<VMR:7!T:70@
M96EVY'0@=F]I(&MU='-U82!,96EK:V%A+TMO<&EO:2\B"B),:6ETY"!T;VEM
M:6YT;VIA+B!.87!S875T82!/2RUN87!P=6QA82!NY&ADY&MS97-I(&UO>FEL
M;&$N;W)G('-I=G5I;&QA("(*(F]L979A;B!O:&IE96XL(&IO<W-A(&YE=79O
M=&%A;B!M:71E;B!S:W)I<'1I<VD@=F]I=F%T(&OD>71TY.0@;&5I:V5P]GET
MY.0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`B4&]I<W1A
M(';D<FDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X
M-R!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-PHC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,PIM<V=I9"`B56YS=7!P
M;W)T960@17AT96YS:6]N(@IM<V=S='(@(D5I+71U971T=2!L86%J96YN=7,B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S
M='(@(E#D:79I=.0B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R
M(")0Y&EV:73D("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B4.1I=FETY"!K
MY'ET=.1JY"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E<FUS
M+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L
M('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R(")0
MY&EV:71E='1I:6X@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R
M(")0Y&EV:71Y<W-K<FEP=&D@<&]I<W1E='1I:6XN(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$W."!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3DX"FUS9VED(")5<&QO860B"FUS9W-T<B`B5'5O(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL
M(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S
M='(@(G1U;R!K86EK:VD@;VAJ96QM:65N(&%S96YN=7-T:65D;W-T;W0@<&%L
M=F5L:6UE;&QE+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E
M<G,B"FUS9W-T<B`B27-O="!L871I;F%L86ES970@:VER:F%I;65T(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("))<V]T
M(')O;VUA;&%I<V5T(&YU;65R;W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q"FUS9VED(")5
M<G5G=6%Y(@IM<V=S='(@(E5R=6=U87DB"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B2^1Y=.0@;GEK>6ES=.0Z
M("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B2^1Y=.0@4U-,+7-A
M;&%U<W1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-PIM<V=I9"`B
M57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E
M<G9E<BXB"FUS9W-T<B`B2^1Y=.0@:F]S('1U;FYU<R]S86QA<V%N82!O;B!E
M<FD@24U34"UP86QV96QI;65L;&4N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHR,0IM<V=I9"`B57-E<B(*;7-G<W1R(")+Y'ET=.1J
MY"(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S<T
M"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES
M960@9F]R("5S+B(*;7-G<W1R(")+Y'ET=.1JY&QLY"`E<R!E:2!O;&4@;VEK
M975K<VEA('1E:&3D("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I
M9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")+Y'ET=.1J:65N('EL
M;.1P:71O(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR-#4*
M;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R(")+Y'ET=.1JY&X@87-E='5K
M<V5T(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I
M;VXB"FUS9W-T<B`B2^1Y='3D:N1N(')E:VES=&5R]FEM:6YE;B(*"B,Z('-I
M9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N
M(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(E3D<W/D(&KD<FIE
M<W1E;&WD<W/D(&5I('9O:2!R96MI<W1E<O9I9.0@:^1Y='3D:FGD+B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@86-C;W5N
M="!N;W0@9F]U;F0B"FUS9W-T<B`B2^1Y='3D:N1T=6YN=7-T82!E:2!L]GET
M>6YY="XB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$U,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HS,R!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M
M92(*;7-G<W1R(")+Y'ET=.1JY'1U;FYU<R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E
M<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R(")+Y'ET=.1J
MY'1U;FYU<R!<(B5S7"(@;VX@:F\@;VQE;6%S<V$N(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T
M<B`B2^1Y='3D:N1T=6YN=7,Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(")+Y'ET=.1JY'1U
M;FYU<SH@(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM
M<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B2N1R:F5S=&5L
M;>1N(&OD>71TY&KD=#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R"FUS9VED(")5>F)E:VES
M=&%N(@IM<V=S='(@(E5Z8F5K:7-T86XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HQ-S`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8R
M"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R
M(")61E,M:&%K96UI<W1O82!E:2!O;&4@;VQE;6%S<V$N(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$R,`IM<V=I9"`B5F%C871I;VXB"FUS9W-T
M<B`B4&]I<W-A;VQO=FEE<W1I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.#<P"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@
M(@IM<V=S='(@(E!A:6MK;VIA(&SV>71Y:2!E<VEM97)K:6MS:3H@(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(E9A
M;&ED:71Y(@IM<V=S='(@(E9O:6UA<W-A;VQO86EK82(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PIM<V=I
M9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B07)V;R!M
M:6YU=71E:7-S82!N>6MY:&5T:V5S=.0N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#8P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L
M96YG=&@@;V8@)7,N(@IM<V=S='(@(D%R=F\@;VX@>6QI('!I='5U9&5N(&UA
M:W-I;6EA<G9O;B`E<RX\(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C(T."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C<P"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S,C`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,CDQ-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP
M.C4Y"FUS9VED(")686QU97,B"FUS9W-T<B`B07)V;W0B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3$S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q.3`*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R(")6
M86QI='1A=F%T(&%R=F]T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.0IM<V=I9"`B5F%N=6%T
M=2(*;7-G<W1R(")686YU871U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(S,PIM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B5F%I:'1E;&5V
M86$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`B
M5F5N97IU96QA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A
M9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R(")487)K
M:7-T=7,@97#D;VYN:7-T=6D@+2!4Y'3D('9I97-T:>0@;VX@=F]I='4@:^1S
M:71E;&SD+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-S`Q"FUS9VED(")697)S:6]N(@IM<V=S='(@(E9E<G-I;R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR,C@*;7-G:60@(E9E<G-I;VX@0V]N=')O
M;"(*;7-G<W1R(")697)S:6]N:&%L;&EN=&$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T
M:6-A;"!A;&EG;B(*;7-G<W1R(")0>7-T>7-U;W)A('1A<V%U<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@
M(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B4'ES='ES=6]R82!TY'ET92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*
M;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R(")0>7-T>7-U;W)A.B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")6
M97)Y($AI9V@B"FUS9W-T<B`B17)I='3D:6X@:V]R:V5A(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T.`IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B5FEE=&YA;2(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DW"FUS9VED(")6:65T;F%M97-E("A625-#
M24DI(@IM<V=S='(@(E9I971N86T@*%9)4T-)22DB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HY-CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5FEE=R`E<R(*;7-G<W1R(").Y'ETY"`E<R(*"B,Z(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B
M"FUS9W-T<B`B3N1Y=.0@97)I;&QI<V5NY"!W=W<M<VEV=6YA(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(X"B,L('!H<"UF;W)M
M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B3N1Y=.0@)7,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G
M<W1R(").96ET<WET<V%A<F5T+"!"<FET=&ELY&EN96XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0W"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R(").96ET
M<WET<V%A<F5T+"!9:&1Y<W9A;'1A:6XB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(Q-@IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R(").Y&MY=N1I<WEY
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3(*;7-G:60@
M(E9I<VEB:6QI='DZ("(*;7-G<W1R(").Y&MY=N1I<WEY<SH@(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*
M;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S='(@(E9O9&%F
M;VYE($ET86QY(%--5%`Z;B!A=G5L;&$B"@HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS
M9VED(")705).(@IM<V=S='(@(E9!4D])5%53(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A
M(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(E9!
M4D])5%53(2$A(%!/25-402!32U))4%1)($OD4TE.(%!!3%9%3$E-14Q402`E
M<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S
M,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(E=)3B!(5%10.FX@879U
M;&QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U,`IM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B
M"FUS9W-T<B`B5V%L;&ES(&IA($9U='5N82(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,3(W(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R
M(")687)O:71U<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(FME(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C
M87-T(@IM<V=S='(@(E/DY&5N;G5S=&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-#$V"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@
M8GDB"FUS9W-T<B`B4^3D=&EE9&]T(&]N('1O:6UI='1A;G5T(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"FUS9VED(")796%T:&5R+F-O;2(*
M;7-G<W1R(")796%T:&5R+F-O;2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,V"FUS9VED(")796(B"FUS9W-T<B`B5U=7(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0S.0IM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B5U=7
M+7-I=G5S=&\B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B5FEI:V]I='1A:6XB
M"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L
M8V]M92(*;7-G<W1R(")497)V971U;&]A(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L
M('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B5&5R
M=F5T=6QO82!O:&IE;&UA86X@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B
M:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B5&5R=F5T=6QO
M82P@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y.`IM<V=I9"`B5V5S
M=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B3.1N<VEM86EN96X@*$E33RTX
M.#4Y+3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3D*;7-G:60@(E=E
M<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R("),Y&YS:6UA:6YE;B]%=7)O
M("A)4T\M.#@U.2TQ-2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.`IM<V=I9"`B5V5S=&5R;B!3
M86AA<F$B"FUS9W-T<B`B3.1N<VDM4V%H87)A(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI
M8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R
M(")-:6YKY"!O:&IE;&UA;B`E<R!KY'EN;FES=.3D('-I<^3D;FMI<FIA=71U
M;6ES96X@:N1L:V5E;BXB"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B
M"FUS9W-T<B`B36ETY"!M97)K:VGD(&OD>71E=.3D;B!E<F]T=&EM96YA/R(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T
M(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(DUI=.0@;65R:VMI
MY"!KY'ET973DY&X@;&%I;F%U:W-E96X_(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C0*;7-G:60@(E=H97)E:7,@075S
M=')A;&EA(&UA<"(*;7-G<W1R(")7:&5R96ES($%U<W1R86QI86X@:V%R='1A
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S
M97,B"FUS9W-T<B`B36ET:^0@=F%I:&5E="(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S8*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O
M<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B5F]I="!MY.1R:71E
M;&SD(&QI<^1T;VEM:6YT;VIA(&QA:71E=&%A;B!PY.1L;&4@4FEC:"!497AT
M(&5D:71O<FES<V$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B3&5V
M97ES(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q,0IM<V=I9"`B
M5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(DQE=F5Y<R!#4U,@;6ET=&%Y
M:W-I:VOV:6[D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@
M;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`B
M(@HB5F%S96UM86QL82!O;&5V86X@)7,@=F%L:6MO;B!L979E>7,@*'1U;&5E
M('9O:6UA86X@<V5U<F%A=F%L;&$@(@HB<VESY.1N:VER:F%U='5M:7-E;&QA
M*3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(E1A=6QU
M:V]N(&QE=F5Y<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@(DQE=F5Y
M9&5N('EK<VEK:_8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(DQE=F5Y<SHB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$U"FUS9VED(")7:6MI
M(@IM<V=S='(@(E=I:VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C@Y(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W
M"FUS9VED(")7:6YD(@IM<V=S='(@(E1U=6QI(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(E=I;F0@16%R;'DB
M"FUS9W-T<B`B5'5U;&ES=&$@86EK86ES:6XB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C@W"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@
M(E1U=6QE;FYO<&5U<R!S;VQM=6ES<V$B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$V,PIM<V=I9"`B5VEN9#HB"FUS9W-T<B`B5'5U;&DZ(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B5VEN9#H@(@IM
M<V=S='(@(E1U=6QI.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*
M;7-G:60@(E=I<V1O;2(*;7-G<W1R(")6:6ES875S(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$Y.`IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B
M5&]I=F5L:7-T870B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G
M:60@(E=O<FLB"FUS9W-T<B`B5'GV(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS
M9W-T<B`B3W-O:71E("AT>?8I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R
M(")0=6AE;&EN("AT>?8I(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z,3DS(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(Y-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@
M)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B5N3D<N0@;>3D
M<N0@:V5N='1IY"!R:79I;&SD("5D+B!/9&]T971T:6EN("5D+"!L]GET>6D@
M)60N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S,R"B,L('!H
M<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C
M=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B5N3D<N0@;>3D<N0@:V5N='1I
MY"X@3V1O=&5T=&EI;B`E9"P@;/9Y='EI("5D+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C$R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N
M9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R
M(")6Y.1RY"!P;VEK:V5A;6$@)60@;'5E='1A97-S82!61E,M=&EE9&]S=&]A
M+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#4*;7-G:60@(E@M
M4F5F(@IM<V=S='(@(E@M4F5F(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT
M<R(*;7-G<W1R(")8-3`Y=C,@<&5R=7-R86IO:71T965T(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!%
M>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B6#4P.78S(&QI<^1T;VEM:6YN
M;W0@879A:6UE;B!KY'ET]FQL92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA
M=&EV92!.86UE(@IM<V=S='(@(E@U,#EV,R!+;VAT965N('9A:6AT;V5H=&]I
M;F5N(&YI;6DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4Y-@IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS
M9W-T<B`B6#4P.78S($MO:'1E96X@879A:6UE;B!T=6YN:7-T92(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@S"FUS9VED(")8-3`Y
M=C,@97AT96YS:6]N<R(*;7-G<W1R(")8-3`Y=C,M;&%A:F5N;G5K<V5T(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(E96
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q
M-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4V
M"FUS9VED(")965E9(@IM<V=S='(@(E965E8B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$Q,0IM<V=I9"`B66%H;V\A(&UA
M<"(*;7-G<W1R(")986AO;R$@:V%R='1A(@H*(SH@9G)A;65W;W)K+TUA:6YT
M96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S
M='(@(E9U;W-I='1A:6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R"FUS9VED(")996UE;B(*
M;7-G<W1R(")*96UE;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HY-C8*;7-G:60@(EEE<R(*;7-G<W1R(")+>6QLY"(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS
M9VED(")997,L($D@06=R964B"FUS9W-T<B`B2WEL;.0L('-U;W-T=6XN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM
M<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T
M=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*(DOD
M>73D="!414M35$E424Q!02X@2^1Y=.0@6SP^72!N87!P=6QA82!V86EH=&%A
M:W-E<VD@=&%K86ES:6X@5UE325=91RUT:6QA86XN(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HR,S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R
M92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B170@=F]I('1E:&3D(&5N96UP
MY.0@:W5I;B`E9"!O<VEO=&$N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-#$U"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*
M;7-G<W1R(")%="!O;&4@875T96YT:6MO:71U;G5T+B(*"B,Z(&9R86UE=V]R
M:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`X"FUS9VED(")9;W4@8V%N;F]T
M(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*
M;7-G<W1R(").:6UE<W/D<VD@96D@<V%A(&]L;&$@)UQ<)RUM97)K:VGD+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3D@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DW.0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V
M86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R(")%="!A;G1A;G5T(&]I:V5A
M;B!M=6]T;VES=&$@<^1H:_9P;W-T:6]S;VET971T82XB"@HC.B!F<F%M97=O
M<FLO1&%T82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F
M:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS
M9W-T<B`B(@HB170@;>3D<FET96QL>70@;6ET:^0@='5O9'5N('1I961O<W1O
M;B!K96YTY'0@=F%S=&%A=F%T(&UI=.1K:6X@:V5N='1IY"`E<SHB"B)S<^0N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@W"FUS9VED(")9;W4@
M:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(D]L970@:VER:F%U='5N
M=70@=6QO<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8U"FUS
M9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N
M=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O
M<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B
M(@HB4VEN=6X@<&ETY.0@86YT86$@;VEK96$@;6%T:V%P=6AE;&EN;G5M97)O
M+"!V86EN(&YU;65R;VET82!J82!M86AD;VQL:7-E<W1I("(*(B<K)R!J;W,@
M:^1Y=.1T(&MA;G-A:6YVY&QI<W3D('!U:&5L:6YN=6UE<F]M=6]T;V$N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Y,@IM<V=I9"`B66]U(&AA
M=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B4VEN=6X@=.1Y
M='EY(&%N=&%A(&]I:V5A(&%R=F\N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$
M871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("(B"B)3
M:6YU;B!P:73DY"!A<V5N=&%A($1A=&%4<F5E+71A=7-T86KD<FIE<W1E;&WD
M(&5N;F5N(&MU:6X@=F]I="!KY'ET=.3D("(*(E-I9VYU<"UT;VEM:6YT;VIA
M+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#8R"FUS9VED(")9
M;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B4VEN
M=6X@<&ETY.0@87-E;G1A82!61E,M=&%U<W1A:N1R:F5S=&5L;>0N(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M
M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@
M=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R("(B"B)3:6YU;B!T=6QE92!K
M=79A:6QL82!O;F=E;&UA=&EL86YN971T82!E;FYE;B!K=6EN('9O:70@;.1H
M971TY.0@(@HB;VYG96QM879I97-T:6XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT
M97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@
M(E-I;G5N('!I=.3D(&%N=&%A(%523"!M:6AI;B!TY&WD(&QI;FMK:2!O<V]I
M='1A82(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED
M(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM
M<V=S='(@(E-I;G5N('!I=.3D('9A;&ET82!P;VES=&5T=&%V82!P86QV96QI
M;BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO=2!M=7-T('-P
M96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(E-I;G5N
M('!I=.3D(&%N=&%A('!O:7-T971T879A(&OD>71TY&KD='5N;G5S+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A
M('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B4VEN=6X@<&ETY.0@86YT
M86$@<&]I<W1E='1A=F$@:^1Y='3D:N1T=6YN=7,N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM
M<V=S='(@(E-I;G5N('!I=.3D(&%N=&%A(&QI<^1T=.1VY"!KY'ET=.1JY'1U
M;FYU<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B4VEN
M=6X@<&ETY.0@86YT86$@<.1I=FET971TY';D(&OD>71TY&KD='5N;G5S+B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM
M<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M
M+B(*;7-G<W1R(")3:6YU;B!P:73DY"!V86QI=&$@<W5O<FET971T879A('1O
M:6UI;G1O+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C<Q"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G
M;W)Y(&YA;64N(@IM<V=S='(@(E-I;G5N('!I=.3D(&%N=&%A('5U9&5N(&MA
M=&5G;W)I86X@;FEM:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O
M=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R(")3:6YU;B!P
M:73DY"!A;G1A82!I=&%L:6%L86EN96X@<'5H96QI;FYU;65R;R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A
M9V%I;BXB"FUS9W-T<B`B27-T=6YT;W-I("5S(&]N('9A;FAE;G1U;G5T+B!+
M:7)J875D=2!U=61E;&QE96X@<VESY.1N+B(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B
M"FUS9W-T<B`B4^1H:_9P;W-T:6]S;VET=&5E<VDB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C$U"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM
M<V=S='(@(E-I;G5N(&SD:&5T=.1JY&]S;VET=&5E<VDZ(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-R!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDR"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D]M870@
M=&EE=&]S:2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S
M(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I
M;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G
M:6X@86=A:6XN(@IM<V=S='(@(B(*(E-I;G5N('1I971O:V]N965S:2!KY'ET
M=.1MY"!T:65T;W9E<FMK;RUO<V]I=&4@;VX@;75U='1U;G5T('-E;B!JY&QK
M965N(&MU;B`B"B)O;&5T(&%L;VET=&%N=70@)7,@:7-T=6YN;VXN(%1I971O
M='5R=F%S>6ES=.0@<VEN=6X@<&ETY.0@:VER:F%U='5A("(*(G5U9&5S=&%A
M;B!JY')J97-T96QMY.1N+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C,S"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B3FEM97-I(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*
M(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O
M(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF
M9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*
M(DOD>71TY&WD<VD@875T:&5N=&EC871I;VX@=&%U<W1A:N1R:F5S=&5L;>0@
M96D@='5E(&OD>71TY&II96X@;&ESY.1M:7-TY"X@(@HB2F]S(&AA;'5A="!H
M86QL:6YN;VED82!KY'ET=.1JY'1U;FYU:W-I82P@<VEN=6X@<&ETY.0@:^1Y
M='3DY"!J;W1A:VEN('1O:7-T82`B"B)A=71H96YT:6-A=&EO;B!T875S=&%J
MY')J97-T96QMY.0N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T
M+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@
M9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R
M92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN
M(@IM<V=S='(@(B(*(DOD>71TY&WD<VD@875T:&5N=&EC871I;VX@=&%U<W1A
M:N1R:F5S=&5L;>0@96D@='5E(&OD>71TY&KD=&EE=&]J96X@(@HB;N1Y='3D
M;6ES=.0@=&%I('3D;>0@<&EI<G)E(&5I(&]L92!J;W-T86MI;B!S>7ES=.0@
M:^1Y=&5T=.1V:7-SY"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A
M<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U
M<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO
M=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)3:6YU;B!KY'ET=.1M
MY'-I('=W=RUS96QA:6X@;N1Y='3DY"!O;&5V86X@;75U='1U;G5T('-E;B!J
MY&QK965N(&MU;B!O;&5T("(*(F%L;VET=&%N=70@)7,@:7-T=6YN;VXN(%1I
M971O='5R=F%S>6ES=.0@<VEN=6X@<&ETY.0@:VER:F%U='5A("(*(G5U9&5S
M=&%A;FKD<FIE<W1E;&WDY&XN(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M-3<*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M9F5A='5R92XB"FUS9W-T<B`B4V5L86EM97-I(&5I('1U92!TY'3D('1O:6UI
M;G1O82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM
M<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P
M<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@
M<')I;G0N(@IM<V=S='(@(B(*(E-E;&%I;65S:2!E:2!T=64@=&%R=FET=&%V
M86$@='5L;W-T=7-T;VEM:6YT;V$N(%!A:6YA($-O;G1R;VPO3W!T:6]N("L@
M4"`B"B)T=6QO<W1A86MS97-I+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-C$*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@
M(D%I:V%V>?9H>6MK965S:3HB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3$W
M"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E
M9"XB"FUS9W-T<B`B3VQE='5S<')O9FEI;&ES:2!O;B!M=75T971T=2XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38Q"FUS9VED(")9;W5R(&1E9F%U
M;'0@:61E;G1I='DZ(@IM<V=S='(@(D]L971U<W!R;V9I:6QI<VDZ(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P-`IM<V=I9"`B66]U<B!F=6QL(&YA
M;64Z(@IM<V=S='(@(DYI;65S:3HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.3D*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S
M='(@(DES='5N=&]S:2!O;B!V86YH96YT=6YU="XB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R
M(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(E-I;G5N('-A
M;&%S86YA<VD@)7,Z;&QE(&]N.B`E<R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM
M<V=S='(@(D%S971U:W-E<VD@;VX@<.1I=FET971T>2!J82!N92!O=F%T('9O
M:6UA<W-A('3D;>1N(&ES='5N;F]N(&%J86XN(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"XB"FUS9W-T<B`B07-E='5K<V5S:2!O;B!PY&EV:71E
M='1Y+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED
M(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(E-A;&%S
M86YA<VD@;VX@;F]L;&%T='4B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E
M="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@
M(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*(E-A;&%S86YA<VD@;VX@;F]L;&%T
M='4L('1A<FMI<W1A('/D:&OV<&]S=&ES:2!J82!K:7)J875D=2!S:7/DY&X@
M=75D96QL82`B"B)S86QA<V%N86QL87-I+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.C<S,PIM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E
M9"XB"FUS9W-T<B`B4V%L87-A;F%S:2!O;B!V86YH96YT=6YU="XB"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M
M;W1E('-E<G9E<G,Z(@IM<V=S='(@(D5TY'!A;'9E;&EM97-I.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-30*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B2G5G
M;W-L879I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*
M;7-G:60@(EIA:7)E(@IM<V=S='(@(EIA:7)E(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-@IM
M<V=I9"`B6F%M8FEA(@IM<V=S='(@(E-A;6)I82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<*
M;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(EII;6)A8G=E(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G<W1R(")::7!P
M>2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT
M<75O=&5S+G!H<#HQ-S0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5"
M;&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R
M(");4&EI;&]T82!L86EN871T=2!T96MS=&E=(@H*(SH@<V5R=FEC97,O<')O
M8FQE;2YP:'`Z.#D*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B
M6T]N9V5L;6%=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C
M:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B
M6T[D>73D(&QA:6YA='1U('1E:W-T:2`M(@H*(SH@9G)A;65W;W)K+U1E>'1?
M1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*
M;7-G<W1R(");3N1Y=.0@;&%I;F%T='4@=&5K<W1I("T@)7,@<FEV:>1=(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.34*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(EMR:79I;&SD("5S
M+R5S72(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34T-R!T96UP
M;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B7UEL;.1P:71O(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS
M9VED(")?0TQ)(@IM<V=S='(@(E]+;VUE;G1O='5L:VMI(@H*(SH@;&EB+V%P
M:2YP:'`Z,30Q"FUS9VED(")?1&%T851R964B"FUS9W-T<B`B7T1A=&%4<F5E
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O=R(*;7-G<W1R(")?4&]I<W1A
M(')I=FDB"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS
M9W-T<B`B7U)Y:&WD="(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU
M+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@(E]/:&IE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S
M"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")?2W5V86X@
M=&EE9&]T+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP
M.C$Y-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R(")?2VER:F%U9'4@<VESY.1N
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I
M9"`B7TQO9R!O=70B"FUS9W-T<B`B7TMI<FIA=61U('5L;W,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*
M;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R(")?375O:VMA82!L:6YK
M:VGD(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-`IM
M<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`B7T%S971U:W-E="(*"B,Z(&QI8B]A
M<&DN<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(E]/:6ME
M=61E="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@
M(E!O:7-T82!L:6YK:VDN+BXB"@HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@
M(E]3971U<"(*;7-G<W1R(")?07-E;FYU<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A
M8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B7U1A=6QU:V]N('1I961O="XN
M+B(*"B,Z(&QI8B]A<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@
M(E]+Y'ET=.1JY'0B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR
M-0IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(F]S;VET96MI<FIA(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G:60@
M(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(G9A<W1A86YO='1A:F$@='5N
M=&5M871O;B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$W"FUS
M9VED(")C86QE;F1A<B(*;7-G<W1R(")K86QE;G1E<FDB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$W.2!L:6(O0FQO8VLO;65T87(N<&AP.C,V-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(G1Y>6YTY"(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN
M;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(F5I('9O:2!L=6]D82!T
M=6QO<W1I961O<W1O82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R(")E
M:2!V;VD@875K86ES=&$@;.1H9&5T=.0B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HU.3@*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T
M<B`B;F%P<V%U=&$@=.1S=.0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R
M(@IM<V=S='(@(G9I<FAE(&MO;65N=&]R:79I;&SD(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O;F9I9W5R871I
M;VX@97)R;W(B"FUS9W-T<B`B87-E='5S=FER:&4B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES
M=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R(")K<FEI='1I;F5N(&KD<FIE<W1E
M;&WD=&EE9&]S=&\@<'5U='1U=2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G
M<W1R(")M=6]T;W9I<FAE('1I961O:7-S82(*"B,Z('1E;7!L871E<R]P;W)T
M86PO961I="YI;F,Z,S`*;7-G:60@(F5D:70B"FUS9W-T<B`B;75O:VMA82(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3@R"FUS9VED
M(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B=&EE='5E='1A(&5I(&SV>71Y
M;GET(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S,*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B;&%S:V5V82(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y.`IM<V=I9"`B9FEL92(*;7-G
M<W1R(")T:65D;W-T;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@Q(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S8W(&QI8B]";&]C:R]M971A<BYP:'`Z,SDS
M"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@
M)7,B"FUS9W-T<B`B<W5U;FYA<W1A("5S("@E<RD@;F]P975D96QL82`E<R`E
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,SD*;7-G:60@
M(F=U<W1I;F<B"FUS9W-T<B`B<'5U<VMI='1A:6XB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4P"FUS9VED(")H.B(*;7-G
M<W1R(")H.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HS-3D*;7-G:60@(FAH(@IM<V=S='(@(FAH(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U
M;FMN;W=N(@IM<V=S='(@(G1U;G1E;6%T;VX@<&%L=F5L:6UE;B!N:6UI(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-38U"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B=N1L:71T]FWD<W1I
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R(")I;FQI;F4B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP
M=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(FEO+79I<FAE(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L
M('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(F]H:F5L;6ES=&]N('-I<^1I;F5N
M('9I<FAE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N
M:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R(")R:79I=%TB"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H
M:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(FUK:7-O9G,@=FER:&5K;V]D:2`E
M9"!)4T\Z82!T96AD97-SY"XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S<P"FUS9VED(")M;2(*;7-G<W1R(")M;2(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C@U('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C(T,0IM<V=I9"`B;F%M92(*;7-G<W1R(")N:6UI(@H*(SH@9G)A
M;65W;W)K+U)00R]24$,N<&AP.C$R-`IM<V=I9"`B;F]T(&EM<&QE;65N=&5D
M(@IM<V=S='(@(F5I(&]L92!T;W1E=71E='1U(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C(P"FUS9VED(")N;W0@>65T(&EM<&QE
M;65N=&5D(@IM<V=S='(@(F5I(&]L92!V:65LY"!T;W1E=71E='1U(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#D*;7-G:60@(FYO=&5P860B
M"FUS9W-T<B`B;75I<W1I;&ES=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM
M<V=S='(@(G!R;W-E;G1T:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R
M(")KY'ET=/8@:VEE;&QE='1Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S
M='(@(G!I:W-E;&5I=.0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM
M<V=S='(@(F5TY'9I<FAE('!R;W1O:V]L;&%S<V$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW-0IM<V=I9"`B<FES:6YG(@IM
M<V=S='(@(FYO=7-E=F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R
M(")P86QV96QU(&5I(&]L92!KY'ET971TY'9I<W/D(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HQ,#$*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS
M9W-T<B`B;N1Y=.0@97)O="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A4
M5%`B"FUS9W-T<B`B<VUS,F5M86EL($A45%`Z;B!A=G5L;&$B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@W"FUS9VED(")S
M<R(*;7-G<W1R(")S<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<T"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B=F%K86$B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B
M<WES=&5M(&5R<F]R(@IM<V=S='(@(FKD<FIE<W1E;&WD=FER:&4B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,PIM<V=I9"`B=&%S:R!L:7-T
M(@IM<V=S='(@(G1E:'3D=N1L:7-T82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*
M;7-G<W1R(")VY&QI86EK86EN96X@=FER:&4B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS-B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED
M(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@
M(G9A<FUI<W1A86MS97-I(&MI<FIO:71A('-A;&%S86YA(&MA:&1E<W1I(@H*
M(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B=6YI9FEE9"(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B
M"FUS9W-T<B`B;FEM973V;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R,PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0IM<V=I9"`B=7-E<B!S96QE8W0B
M"FUS9W-T<B`B:^1Y='3D:N1N('9A;&EN=&$B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S
M='(@(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(T,@IM<V=I9"`B=SHB"FUS9W-T<B`B=SHB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS
M9W-T<B`B=V5A=&AE<BYC;VTB"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O9G)?1E(N<&\`````````````
M````````````````````````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#<T-3<V,P`Q
M,#4Q-30S,S<U-``P,3<V-C$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````(R!(;W)D92`S+C$N,2!&<F5N8V@@=')A;G-L871I
M;VXN"B,@0V]P>7)I9VAT("A#*2`R,#`Q+3(P,#(@5&AE($AO<F1E(%!R;VIE
M8W0N"B,@4&EE<G)E($QA8VAA;F-E(#QP;$!P:65R<F5L86-H86YC92YN970^
M(&5T($)E;F]I="!3="U!;F1RZ2`H8F5N0&)E;F]I='-T+6%N9')E+FYE="DL
M(#(P,#,L(#(P,#0N"B,@1G)E9&5R:6,@5')U9&5A=2`\9G1R=61E875`8V%M
M+F]R9SXL(#(P,#$N"B,@5&AI97)R>2!4:&]M87,@/'1H:65R<GE`<&]M<&\N
M;F5T/BP@,C`P,BP@,C`P-2P@,C`P-BX*(R!#;W5N=')Y('1R86YL871I;VYS
M(&9R;VT@36EG=65L(%1R96UB;&%Y(#QK8F%B96PN;6EG=65L0'!T869F+F-A
M/BP@,C`P-"X*(R!"96YO:70@4W0M06YD<ND@/&)E;D!B96YO:71S="UA;F1R
M92YN970^+"`R,#`T+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)
M9"U697)S:6]N.B!F<E]&4EQN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E
M=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`V
M+3`S+3`V(#$R.C0W*S`Q,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M
M,#,M,S$@,C(Z,S`K,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!4:&EE<G)Y
M(%1H;VUA<R`\=&AI97)R>4!P;VUP;RYN970^7&XB"B),86YG=6%G92U496%M
M.B!&<F5N8V@@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S
M:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E
M=#U)4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X
M8FET7&XB"B)0;'5R86PM1F]R;7,Z(&YP;'5R86QS/3([('!L=7)A;#TH;B`^
M(#$I.UQN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*&EL
M('D@82`E<R!J;W5R<RDB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$S.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM
M<V=S='(@(B`H5&]U8VAE(&0G86-CZ',@<F%P:61E("5S*2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M("AI;B`E<R!D87ES*2(*;7-G<W1R("(@*&1A;G,@)7,@:F]U<G,I(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,`IM<V=I9"`B("AT;V1A>2DB
M"FUS9W-T<B`B("AA=6IO=7)D)VAU:2DB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S<R"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@*&1E
M;6%I;BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8X"FUS9VED
M("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B("AH:65R*2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-#4@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,U,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDV
M"FUS9VED("(@870@(@IM<V=S='(@(B#@("(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I
M<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@(JN@)7.@NR!N)V5S="!P87,@
M=6X@9&]S<VEE<B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC
M92XB"FUS9W-T<B`BJZ`E<Z"[(&XG97-T('!A<R!U;B!C:&]I>"!V86QI9&4N
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW,3`*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#DX"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I
M;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(JN@)7.@NR!N)V5S="!P
M87,@8V]N9FEG=7+I(&1A;G,@;&4@<F5G:7-T<F4@9&4@2&]R9&4N(@H*(SH@
M9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B
M3"=I;G1E<G!RZ71E=7(@9"=A<F)R92"KH"5SH+L@;B=A('!A<R#I=.D@=')O
M=7;I+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB
M"FUS9W-T<B`BJZ`E<Z"[(&$@Z73I(&%J;W5TZ2!A=2!S>7-TZ&UE(&1E<R!G
M<F]U<&5S+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M
M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(JN@)7.@NR!A(.ETZ2!A:F]U=.D@
M874@<WES=.AM92!D97,@<&5R;6ES<VEO;G,N(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S
M='(@(JN@)7.@NR!N)V$@<&%S(.ETZ2!C<NGIH#H@)7,N(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-
M0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B4N
M,F:@36\@=71I;&ESZ7,@<W5R("4N,F:@36\@<&5R;6ES("@E+C)FH"4E*2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B5D("5S(&5T("5S
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D
M87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B)60@
M:F]U<G,@879A;G0@;"=E>'!I<F%T:6]N(&1E('9O=')E(&UO="!D92!P87-S
M92XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<T"B,L('!H
M<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R("(E9"UP
M<NEV:7-I;VX@9'4@:F]U<B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R
M("(E<R`M($YO=&EC92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-S`U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT
M(@IM<V=S='(@(D5M<')E:6YT92!01U`@9&4@)7,B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#`@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z.#0R"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"
M(@IM<V=S='(@(B5SH$MO(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A
M=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@;W#I<F%T:6]N<R!D
M92!M86EN=&5N86YC92`F;F1A<V@[($-O;F9I<FUA=&EO;B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q
M-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R(")#;VYF
M:6=U<F%T:6]N("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C(V-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S
M='(@(DEN<V-R:7!T:6]N(&1E("5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G
M<F5E;65N="(*;7-G<W1R(")#;VYD:71I;VYS(&0G=71I;&ES871I;VX@9&4@
M)7,B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0S,B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C0Y-`HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C8X,B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B
M)7,@97AI<W1E(&3I:N`N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C8@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-#8*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3(@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS
M9W-T<B`B("5SH.`@)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@
M<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E
M;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO
M=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(B"B(E
M<R!E<W0@<'+J="#@(&5F9F5C='5E<B!L97,@;W#I<F%T:6]N<R!D92!M86EN
M=&5N86YC92!C;V-HZ65S(&-I+61E<W-O=7,N("(*(E/I;&5C=&EO;FYE>B!L
M82!O=2!L97,@;W#I<F%T:6]N*',I('%U92!V;W5S('9O=6QE>B!E9F9E8W1U
M97(@8V5T=&4@9F]I<RUC:2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S,W"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM
M<V=S='(@(B5S(&5S="!O8FQI9V%T;VER92(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,CDS"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS
M9W-T<B`B)7,@;6EN=71E<R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#
M;VQL96-T:6]N+G!H<#HQ,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T
M(&9O=6YD+B(*;7-G<W1R("(E<R!N;VX@=')O=7;I(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(E<Z#@("5S(&1E("5S(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B0V%R;F5T(&0G861R97-S
M97,@9&4@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ.`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(D%G
M96YD82!D92`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$P
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R(")"
M;&]C+6YO=&5S(&1E("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G
M<W1R("),:7-T92!D92!TXF-H97,@9&4@)7,B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(E<Z`Z("5S
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,3(W
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y
M(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@
M9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@
M=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS
M9W-T<B`B(@HB)7.@.B!L)^EM971T975R(&1E(&-E(&UE<W-A9V4@82!P=2#J
M=')E(&9A;'-I9FGI+B!!='1E;G1I;VX@96X@<W5I=F%N="!L97,@(@HB;&EE
M;G,@<74G:6P@8V]N=&EE;G0@;W4@96X@9F]U<FYI<W-A;G0@9&5S(&EN9F]R
M;6%T:6]N<R!P97)S;VYN96QL97,@X"`B"B)L)^EM971T975R+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-30@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,Y.0IM<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(L
M(&5N(')A9F%L92`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Y-2!L:6(O
M0FQO8VLO;65T87(N<&AP.C(P,`HC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U
M<W1I;F<@)7,@)7,B"FUS9W-T<B`B<F%F86QE("5S("5S(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I
M86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(G9A<FEA8FQE(&1U("5S(&%U
M("5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR.30@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`V-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3(U
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HW-#@*
M;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(M+2!3Z6QE8W1I;VYN97(@
M+2TB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@
M1F]R;6%T(@IM<V=S='(@(D9O<FUA="`Q,B!H975R97,B"@HC.B!L:6(O0FQO
M8VLO=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@
M(D9O<FUA="`R-"!H975R97,B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN
M8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@:&5U<F5S(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S
M(@IM<V=S='(@(CQ0<NECZ61E;G0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$R-@IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O
M<B!T:&ES(&)L;V-K+B(*;7-G<W1R(")5;F4@8F%S92!D92!D;VYNZ65S('!R
M:6YC:7!A;&4@*&)A8VME;F0I(&5S="!NZ6-E<W-A:7)E('!O=7(@8V4@8FQO
M8R(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<Q"FUS9VED(")!
M(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R(")5;F4@97)R975R
M(&9A=&%L92!S)V5S="!P<F]D=6ET92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R
M97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B56YE(&-L
M968@<'5B;&EQ=64@4$=0(&5S="!NZ6-E<W-A:7)E('!O=7(@8VAI9F9R97(@
M=6X@;65S<V%G92XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,38X"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O
M('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"B)5;F4@8VQE
M9B!P=6)L:7%U92!01U`@97-T(&[I8V5S<V%I<F4@<&]U<B!VZ7)I9FEE<B!L
M82!S:6=N871U<F4@9"=U;B!M97-S86=E+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$P.3D*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K
M97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B)5;F4@
M8VQE9B!P=6)L:7%U92!01U`L('5N92!C;&5F('!R:7;I92!01U`L(&5T('5N
M92!P:')A<V4@<V5C<NAT92!S;VYT("(*(F[I8V5S<V%I<F5S('!O=7(@9.EC
M:&EF9G)E<B!U;B!M97-S86=E+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$P,38*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R
M:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B)5;F4@8VQE9B!P=6)L
M:7%U92!01U`L('5N92!C;&5F('!R:7;I92!01U`L(&5T('5N92!P:')A<V4@
M<V5C<NAT92!S;VYT("(*(F[I8V5S<V%I<F5S('!O=7(@<VEG;F5R('5N(&UE
M<W-A9V4N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M,#8*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-
M24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E
M8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B)5;F4@8VQE9B!P=6)L:7%U
M92!3+TU)344L('5N92!C;&5F('!R:7;I92!3+TU)344L(&5T('5N92!P:')A
M<V4@<V5C<NAT92!S;VYT("(*(F[I8V5S<V%I<F5S('!O=7(@9.EC:&EF9G)E
M<B!U;B!M97-S86=E+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV
M871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@HB56YE(&-L968@<'5B
M;&EQ=64@4R]-24U%+"!U;F4@8VQE9B!P<FEVZ64@4R]-24U%+"!E="!U;F4@
M<&AR87-E('-E8W+H=&4@<V]N="`B"B)NZ6-E<W-A:7)E<R!P;W5R('-I9VYE
M<B!U;B!M97-S86=E+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER
M960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(E5N92!C;&5F('!U
M8FQI<75E(%,O34E-12!E<W0@;NEC97-S86ER92!P;W5R(&-H:69F<F5R('5N
M(&UE<W-A9V4N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z.0IM<V=I9"`B04T@0VQO=61S(@IM<V=S='(@(DYU86=E<R!L92!M
M871I;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(E!L=6EE(&SI9^AR
M92!L92!M871I;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$Q"FUS9VED(")!32!286EN(@IM<V=S='(@(E!L=6EE(&QE(&UA
M=&EN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B079E<G-E<R!L92!M871I
M;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S
M"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B0VAU=&5S(&1E(&YE
M:6=E(&QE(&UA=&EN(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*
M;7-G:60@(D%-+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@
M240B"FUS9W-T<B`B05!)($E$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B
M"FUS9W-T<B`BP"!P<F]P;W,@9&4@8V5T(.ED:71E=7(B"@HC.B!S97)V:6-E
M<R]H96QP+VEN9&5X+G!H<#HU,PIM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B
MP"!P<F]P;W,N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B0F%S(&%B
M<V]L=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R(")-:6QI974@86)S;VQU
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B
M06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R
M(")!8V/H<R!R969U<^D@;&]R<R!D92!L82!C<NEA=&EO;B!D92!RZ7!E<G1O
M:7)E(%9&4R`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$S
M-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS
M9W-T<B`B06-CZ',@<F5F=7/I(&QO<G,@9&4@;&$@8W+I871I;VX@9&4@9FEC
M:&EE<B!61E,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*;7-G:60@
M(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B1&]N;NEE<R!P97)S;VYN
M96QL97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@*;7-G:60@(D%C
M8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B36]T(&1E('!A<W-E(&1U(&-O;7!T
M92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(D-O;7!T
M92!I;F%C=&EF(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S-0IM
M<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R(")#;VUP=&5S(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A
M9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N
M:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`B06IO=71E<B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!
M9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B06IO=71E<B!U;B!S;W5S+6=R;W5P
M92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3@@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD(%!E
M<FUI<W-I;VXB"FUS9W-T<B`B06IO=71E<B!U;F4@;F]U=F5L;&4@<V]U<RUP
M97)M:7-S:6]N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G
M:60@(D%D9"!(97)E.B(*;7-G<W1R(")!:F]U=&5R(&EC::`Z(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G:60@
M(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B06IO=71E<B!U;B!N;W5V96%U(&=R
M;W5P92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#<@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`IM<V=I9"`B061D($YE=R!0
M97)M:7-S:6]N(@IM<V=S='(@(D%J;W5T97(@=6YE(&YO=79E;&QE('!E<FUI
M<W-I;VXB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN
M8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O
M(%PB)7-<(B(*;7-G<W1R(")!:F]U=&5R('5N(&=R;W5P92!F:6QS(.`@JZ`E
M<Z"[(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<
M(B5S7"(B"FUS9W-T<B`B06IO=71E<B!U;F4@<&5R;6ES<VEO;B!F:6QL92#@
M(*N@)7.@NR(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N
M97<@=7-E<CHB"FUS9W-T<B`B06IO=71E<B!U;B!N;W5V96P@=71I;&ES871E
M=7*@.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU-38*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B06IO=71E<B!U;F4@
M8V]L;VYN92(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z
M,S0*;7-G:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R(")!:F]U=&5R(&1E
M(&YO=79E875X(&UE;6)R97,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R(")!:F]U=&5R('5N92!P
M86ER92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E
M8F%R(@IM<V=S='(@(D%J;W5T97(@;&4@;65N=2`E<R#@(&QA(&)A<G)E(&1E
M($UO>FEL;&$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z-S$*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@
M(D%J;W5T97(@874@8V%R;F5T(&0G861R97-S97.@.B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`IM<V=I9"`B061D('1O
M(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R(")!:F]U=&5R(.`@;6]N(&-A<FYE
M="!D)V%D<F5S<V5S(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D
M9"!U<V5R(@IM<V=S='(@(D%J;W5T97(@=6X@=71I;&ES871E=7(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E
M9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D
M:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B
M"B*KH"5SH+L@82#I=.D@86IO=73I(&%U('-Y<W3H;64L(&UA:7,@;"=A:F]U
M="!D)VEN9F]R;6%T:6]N('-U<'!LZ6UE;G1A:7)E<R`E(@HB<R!N)V5S="!P
M87,@<&]S<VEB;&4N(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L
M;V<@:6X@;F]W+B(*;7-G<W1R("*KH"5SH+L@82#I=.D@86IO=73I+B!6;W5S
M('!O=79E>B!V;W5S(&-O;FYE8W1E<BXB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B
M;&5D+B(*;7-G<W1R("),82!F;VYC=&EO;B!D)V%J;W5T(&0G=71I;&ES871E
M=7)S(&5S="!DZ7-A8W1I=NEE+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#,X"FUS9VED(")!9&1R97-S(@IM<V=S='(@(D%D<F5S<V4B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30Q"FUS9VED(")!9&1R97-S($)O;VLB
M"FUS9W-T<B`B0V%R;F5T(&0G861R97-S97,B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU-@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E<B`M('-E
M="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B061M:6YI
M<W1R871E=7(@+2!A:G5S=&5R(&QE<R!P97)M:7-S:6]N<R!P;W5R(&0G875T
M<F5S('5T:6QI<V%T975R<R(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES=')A
M=&EO;B(*;7-G<W1R(")!9&UI;FES=')A=&EO;B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-#,*;7-G:60@(D%D<R(*;7-G<W1R(")0=6)S(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-@IM<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`B069G:&%N
M:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(D%L
M8F%N:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(D%L
M9^ER:64B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R(")!;&EA<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G
M:60@(D%L:6=N(@IM<V=S='(@(D%L:6=N97(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z
M(@IM<V=S='(@(D%L:6=N96UE;G2@.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(E1O=70B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G
M<W1R(")4;W5S(&QE<R!P87)T:6-I<&%N=',@875T:&5N=&EF:>ES(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I
M9"`B06QL($=R;W5P<R(*;7-G<W1R(")4;W5S(&QE<R!G<F]U<&5S(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O9&%T871R964N<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B5&]U=&5S(&QE<R!P97)M:7-S:6]N<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G
M:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(DQE<R!Q=6%T<F4@8_1TZ7,B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8X"FUS9VED(")!;&QO
M=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B4&5R;65T=')E(&1E<R!A
M9')E<W-E<R!D92!C;W5R<FEE;"!M=6QT:7!L97,B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3,X"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R9&5R
M960@;&ES="!T>7!E/R(*;7-G<W1R(")!=71O<FES97(@;&$@;6ES92!E;B!P
M;&%C92!D92!L:7-T97,@;G5MZ7)O=.EE<Z`_(@H*(SH@9G)A;65W;W)K+T1A
M=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!;')E861Y(&5X
M:7-T<R(*;7-G<W1R(")%>&ES=&4@9.EJX"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,C8*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S
M='(@(DYO;2!D)W5T:6QI<V%T975R($E-4U`@86QT97)N871I9B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3$*;7-G:60@(D%L=&5R;F%T92!)35-0
M(%!A<W-W;W)D(@IM<V=S='(@(DUO="!D92!P87-S92!)35-0(&%L=&5R;F%T
M:68B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`S"FUS9VED(")!;'1E
M<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R(").;VT@9"=U=&EL:7-A=&5U
M<B!)35-0(&%L=&5R;F%T:68B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HS-0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T
M<B`B061R97-S92!D92!C;W5R<FEE;"!A;'1E<FYA=&EV92(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S
M(@IM<V=S='(@(D%U=')E<R!M;V3H;&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!
M;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B5&5X=&4@86QT97)N871I9J`Z(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B4V%M
M;V$@06WI<FEC86EN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HY-2!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B
M06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R(")5;F4@
M=F%L975R(&EL;.EG86QE(&$@Z73I('-PZ6-I9FGI92XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34U"FUS9VED(")!;B!U;FMN;W=N(&5R
M<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R(")5;F4@97)R975R(&EN8V]N;G5E
M(',G97-T('!R;V1U:71E+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%N9&]R<F$B
M"FUS9W-T<B`B06YD;W)R92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*
M;7-G<W1R(")!;F=O;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*
M;7-G<W1R(")!;F=U:6QL82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R(")0<F]X
M>2!A;F]N>6UE(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*
M;7-G:60@(D%N<W=E<B(*;7-G<W1R(")2Z7!O;G-E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM
M<V=I9"`B06YT87)C=&EC82(*;7-G<W1R(")!;G1A<F-T:7%U92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B06YT
M:6=U82UE="U"87)B=61A(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A
M9&UI;B]P:'!S:&5L;"YP:'`Z,S8*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+U5)+G!H<#HU."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV
M"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R(")!<'!L:6-A=&EO;B(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@
M3&ES="(*;7-G<W1R("),:7-T92!D)V%P<&QI8V%T:6]N<R(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E
M861Y+B(*;7-G<W1R("),)V%P<&QI8V%T:6]N(&5S="!P<NIT92(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#
M:&EL9"!3:&%R97,B"FUS9W-T<B`B07!P;&EQ=65R(&%U>"!P87)T86=E<R!F
M:6QS(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*
M;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B07!P<F]U=NDB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#`*;7-G:60@(D%P<')O>&EM
M871E(%-I>F4B"FUS9W-T<B`B5&%I;&QE(&%P<')O>&EM871I=F4B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B
M07!R:6PB"FUS9W-T<B`B079R:6PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W.`IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(D%R
M86)E("A7:6YD;W=S+3$R-38I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-S@*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(E1A:6QL
M92!D=2!F:6-H:65R(&%R8VAI=F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HW-PIM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(DYO;2!D92!L
M)V%R8VAI=F4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U
M960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_
M(@IM<V=S='(@(B(*(LIT97,M=F]U<R!C97)T86EN(&1E('9O=6QO:7(@<W5P
M<')I;65R(&-E='1E(')E<77J=&4@9"=I;G-C<FEP=&EO;B`@<&]U<B`E<Z`_
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E
M;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R("+*=&5S
M+79O=7,@8V5R=&%I;B!D92!V;W5L;VER(&5F9F%C97(@JZ`E<Z"[(&5T('-E
M<R!S;W5S+6=R;W5P97.@/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN
M82(*;7-G<W1R(")!<F=E;G1I;F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!<FUE
M;FEA(@IM<V=S='(@(D%R;>EN:64B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W.0IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B07)M
MZ6YI96X@*$%235-#24DM."DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,C@*;7-G:60@(D%R="(*;7-G<W1R(")!<G0B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED
M(")!<G5B82(*;7-G<W1R(")!<G5B82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B
M07-C96YS:6]N("C.;&4I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y
M"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B07)T($%30TE)(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF
M:6,@4F5G:6]N(@IM<V=S='(@(E+I9VEO;B!!<VEE+U!A8VEF:7%U92(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,CD*;7-G:60@(D%S:R!F;W(@8V]N
M9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS
M/R(*;7-G<W1R("(B"B)$96UA;F1E<B!U;F4@8V]N9FER;6%T:6]N(&%V86YT
M(&1E(&QA;F-E<B!L97,@;W#I<F%T:6]N<R!D92!M86EN=&5N86YC9:`_(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y,@IM<V=I9"`B07-S:6=N
M;65N="!C;VQU;6YS(@IM<V=S='(@(D-O;&]N;F5S(&1E<R!TXF-H97,B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T
M92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B5&5N=&%T:79E(&0G
M969F86-E;65N="!D)W5N(&=R;W5P92!I;F5X:7-T86YT+B(*"B,Z(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E1E;G1A=&EV
M92`@9"=E9F9A8V5M96YT(&0G=6YE('!E<FUI<W-I;VX@:6YE>&ES=&%N=&4N
M(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@
M=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")4
M96YT871I=F4@9&4@;6]D:69I8V%T:6]N(&0G=6YE('!E<FUI<W-I;VX@:6YE
M>&ES=&%N=&4N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS
M9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM
M<V=S='(@(E1E;G1A=&EV92!D92!M;V1I9FEC871I;VX@9"=U;B!P87)T86=E
M(&EN97AI<W1A;G0N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#,*
M;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B4')O<')IZ73I<R(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!
M=6=U<W0B"FUS9W-T<B`B06_[="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R
M86QI82(*;7-G<W1R(")!=7-T<F%L:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!
M=7-T<FEA(@IM<V=S='(@(D%U=')I8VAE(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I
M<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C
M>7)U<Z`Z($5X=&5N<VEO;B!R97%U:7-E($E-05`@;F]N('1R;W5VZ64N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!
M=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P
M86)I;&ET97,N(@IM<V=S='(@(D%U=&A?8WER=7.@.B!L92!B86-K96YD(&XG
M82!P87,@;&5S(&-A<&%C:73I<R!R97%U:7-E<RXB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E
M<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T
M:%]C>7)U<Z`Z(&5X=&5N<VEO;B!R97%U:7-E($E-05`@;F]N('1R;W5VZ64B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*
M(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@
M0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB
M"FUS9W-T<B`B(@HB075T:%]F='"@.B!E>'1E;G-I;VX@<F5Q=6ES92!&5%`@
M;F]N('1R;W5VZ64N($EL(&9A=70@8V]M<&EL97(@4$A0(&%V96,@(@HB;"=O
M<'1I;VX@+2UE;F%B;&4M9G1P+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM87"@.B!E>'1E
M;G-I;VX@<F5Q=6ES92!)34%0(&YO;B!T<F]U=NEE+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q
M=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H
M7VMR8C6@.B!E>'1E;G-I;VX@<F5Q=6ES92!K<F(U(&YO;B!T<F]U=NEE+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!
M=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!
M8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*(D%U=&A?;&1A<*`Z(&PG86IO
M=70@9"=U=&EL:7-A=&5U<G,@;B=E<W0@<&%S('-U<'!O<G3I(&%V96,@06-T
M:79E($1I<F5C=&]R>2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO
M="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@HB
M075T:%]L9&%PH#H@;&4@<F5T<F%I="!D)W5T:6QI<V%T975R<R!N)V5S="!P
M87,@<W5P<&]R=.D@879E8R!!8W1I=F4@(@HB1&ER96-T;W)Y(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P
M.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(D%U=&A?;&1A<*`Z(&5X=&5N<VEO;B!R97%U:7-E($Q$05`@;F]N('1R;W5V
MZ64N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S
M97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R
M("(B"B)!=71H7VQD87"@.B!I;7!O<W-I8FQE(&0G86IO=71E<B!L)W5T:6QI
M<V%T975R("5S+B!#96-I(&5S="!L82!RZ7!O;G-E(&1U("(*(G-E<G9E=7*@
M.B`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@
M=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87"@.B!I;7!O<W-I8FQE(&1E('-U
M<'!R:6UE<B!L)W5T:6QI<V%T975R("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B075T:%]L
M9&%PH#H@;6]D:69I8V%T:6]N(&EM<&]S<VEB;&4@9&4@;"=U=&EL:7-A=&5U
M<B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#`U"FUS
M9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T
M960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(B(*(D%U=&A?;&1A
M<*`Z(&QA(&UO9&EF:6-A=&EO;B!D97,@=71I;&ES871E=7)S(&XG97-T('!A
M<R!S=7!P;W)TZ64@879E8R!!8W1I=F4@(@HB1&ER96-T;W)Y+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A
M;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!=71H7VUC86R@.B!E>'1E;G-I;VX@<F5Q=6ES92!-0T%,(&YO;B!T<F]U
M=NEE+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV,`IM<V=I
M9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?<VUB875T:*`Z(&5X=&5N<VEO;B!R
M97%U:7-E('-M8F%U=&@@;F]N('1R;W5VZ64N(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!9&UI;BYP:'`Z,3`V"FUS9VED(")!=71H96YT:6-A=&EO;B!A
M="!)34%0('-E<G9E<B!F86EL960N(@IM<V=S='(@(LEC:&5C(&1E(&PG875T
M:&5N=&EF:6-A=&EO;B!A=2!S97)V975R($E-05`N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!
M=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`BR6-H96,@9&4@;"=A=71H
M96YT:69I8V%T:6]N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T
M:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R("+)8VAE8R!D92!L)V%U
M=&AE;G1I9FEC871I;VX@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A
M9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B
M>2!2041)55,@<V5R=F5R+B(*;7-G<W1R("),92!S97)V975R(%)!1$E54R!A
M(')E:F5TZ2!L)V%U=&AE;G1I9FEC871I;VXN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HX.#(*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($94
M4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("+)8VAE8R!D92!L)V%U=&AE;G1I
M9FEC871I;VX@874@<V5R=F5U<B!&5%`N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--
M0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R("+)8VAE8R!D92!L)V%U=&AE;G1I
M9FEC871I;VX@874@<V5R=F5U<B!334(N(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T
M<B`B0VAA;7!S(&1I<W!O;FEB;&5SH#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!
M>F5R8F%I:F%N(@IM<V=S='(@(D%Z97)B8>]D:F%N(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B
M17AC=7-E<R!"3T9((@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R
M(")#;W5L975R(&1E(&9O;F0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM
M<V=S='(@(D-O=6QE=7(@9&4@9F]N9"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB
M"FUS9W-T<B`B36]T(&1E('!A<W-E($ME<F)E<F]S(&5R<F]NZ2XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R
M8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(DYO;2!D92!C;VYN97AI;VX@2V5R
M8F5R;W,@97)R;V[I+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B"FUS
M9W-T<B`B0F%H86UA<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)A:')A:6XB"FUS
M9W-T<B`B0F%H<F7O;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS
M9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R(")"86QT92`H25-/
M+3@X-3DM,3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G
M<W1R(")"86YG;&%D97-H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B
M"FUS9W-T<B`B0F%R8F%D92(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S(&1I<F5C=&]R
M>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")2Z7!E<G1O:7)E(&1E<R!G
M<F%P:&EQ=65S(*N@)7.@NR!N;VX@=')O=7;I+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S
M96QI;F4B"FUS9W-T<B`B3&EG;F4@9&4@8F%S92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G
M:60@(D)E;&%R=7,B"FUS9W-T<B`B0NEL87)U<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G
M:60@(D)E;&=I=6TB"FUS9W-T<B`B0F5L9VEQ=64B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS
M9VED(")"96QI>F4B"FUS9W-T<B`B0F5L:7IE(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0F5N:6XB"FUS9W-T<B`B0NEN:6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"
M97)M=61A(@IM<V=S='(@(D)E<FUU9&5S(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B
M0FAU=&%N(@IM<V=S='(@(D)H;W5T86XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G
M<W1R(")!;FYI=F5R<V%I<F4B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M0V]L;&5C=&EO;BYP:'`Z,S8T"B,L('!H<"UF;W)M870*;7-G:60@(D)L;V-K
M(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R(")";&]C(*LE<R"[(&1E(&PG87!P;&EC871I;VX@JZ`E<Z"[(&EN8V]N
M;G4B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3`*;7-G:60@
M(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(E!RZ6;I<F5N8V5S(&1E(&)L;V,B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L
M;V-K(%1Y<&4B"FUS9W-T<B`B5'EP92!D92!B;&]C(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM
M<V=S='(@(D=R87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S
M='(@(D)O;&EV:64B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`W
M"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B4VEG;F5T<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*;7-G
M:60@(D)O<F1E<B(*;7-G<W1R(")";W)D=7)E(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H
M:6-K;F5S<SHB"FUS9W-T<B`BR7!A:7-S975R(&1E(&QA(&)O<F1U<F6@.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B0F]R9',B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(D)O
M<VYI92U(97)ZZ6=O=FEN92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY
M-@IM<V=I9"`B0F]T:"(*;7-G<W1R("),97,@9&5U>"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*
M;7-G:60@(D)O='-W86YA(@IM<V=S='(@(D)O='-W86YA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED
M(")";W1T;VTB"FUS9W-T<B`B0F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U
M=F5T($ES;&%N9"(*;7-G<W1R(")";W5V970B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED
M(")"<F%Z:6PB"FUS9W-T<B`B0G+I<VEL(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@
M(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R(")497)R
M:71O:7)E<R!B<FET86YN:7%U97,@9&4@;"=/8^EA;B!);F1I96XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8R"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R(")3=6QT
M86YA="!D=2!"<G5NZ6DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=6QG87)I82(*
M;7-G<W1R(")"=6QG87)I92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T
M<B`B3&ES=&4@X"!P=6-E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@
M1F%S;R(*;7-G<W1R(")"=7)K:6YA($9A<V\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED
M(")"=7)U;F1I(@IM<V=S='(@(D)U<G5N9&DB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#0V"FUS9VED(")#35,B"FUS9W-T<B`B1V5S=&EO;B!D
M92!C;VYT96YU(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-20R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DX"FUS9VED(")#4DP@1&ES=')I
M8G5T:6]N(%!O:6YT<R(*;7-G<W1R(")$:7-T<FEB=71I;VX@9&5S('!O:6YT
M<R!,4D,@*$QI<W1E(&1E('+I=F]C871I;VX@9&5S(&-E<G1I9FEC871S*2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")0
M<F]P<FGI=.ES(&1E(&QA($-?96QL=6QE(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$U,0IM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O
M;7!L971E9"XB"FUS9W-T<B`B3"=I;FET:6%L:7-A=&EO;B!D=2!C86-H92!N
M92!S)V5S="!P87,@=&5R;6ENZ64N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,38@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0X-0HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`T,"!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,34W"FUS9VED(")#86QE;F1A<B(*;7-G<W1R
M(")!9V5N9&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U
M"FUS9VED(")#86QM(@IM<V=S='(@(D-A;&UE(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(D-A;6)O9&EA(@IM<V=S='(@(D-A;6)O9&=E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM
M<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B0V%M97)O=6XB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P
M87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R
M871O<BXB"FUS9W-T<B`B(@HB26UP;W-S:6)L92!D92!RZ6EN:71I86QI<V5R
M(&QE(&UO="!D92!P87-S92!A=71O;6%T:7%U96UE;G0L(&-O;G1A8W1E>B!V
M;W1R92`B"B)A9&UI;FES=')A=&5U<B!S>7-TZ&UE+B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C,U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M86X@;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(DEM<&]S<VEB
M;&4@9&4@<W5P<')I;65R(&QE(&9I8VAI97(@JZ`E<Z"[+B(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E
M<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R("));7!O<W-I8FQE(&0G
M861M:6YI<W1R97(@9&5S(&=E<W1I;VYN86ER97,@9&4@<V5S<VEO;B!E>'1E
M<FYE<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,S4@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*
M;7-G<W1R("+)8VAE8R!D92!L82!C;VYN97AI;VX@874@<V5R=F5U<B!)34%0
MH#H@)7,B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B26UP;W-S:6)L92!D)V]U=G)I<B!L92!F:6-H:65R(*N@)7.@NRXB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8T"FUS9VED(")#86YA9&$B"FUS9W-T<B`B0V%N861A(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A
M9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`B06YN=6QE
M<B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED
M(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B06YN=6QE<B!L92!R
M87!P;W)T(&1U('!R;V)LZ&UE(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HS,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)L92!D92!S=7!P<FEM97(@
M;&4@9FEC:&EE<B"KH"5SH+LN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M
M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B26UP;W-S:6)L92!D92!T<F]U
M=F5R('5N('+I<&5R=&]I<F4@=&5M<&]R86ER92(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P
M<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T
M<B`B26UP;W-S:6)L92!D92!P<F]CZ61E<B!S86YS(&QE('!A<F%MZ'1R92"K
M('1A<F=E=$9I;&4@NR(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T
M;W)Y(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)L92!D92!S=7!P<FEM97(@
M;&4@<NEP97)T;VER92"KH"5SH+LN(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E
M+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E
M+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO
M=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R(")3=7!P<F5S<VEO;B!I
M;7!O<W-I8FQE+"!I;"!Y(&$@)60@96YR96=I<W1R96UE;G1S(&9I;',N(@H*
M(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS
M9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P
M<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T
M;W)E9"XB"FUS9W-T<B`B(@HB26UP;W-S:6)L92!D92!RZ6]R9&]N;F5R+"!L
M92!N;VUB<F4@9"?I;.EM96YT<R#@('+I;W)D;VYN97(@;F4@8V]R<F5S<&]N
M9"`B"B)P87,@874@;F]M8G)E(&0GZ6SI;65N=',@96YR96=I<W1RZ7,N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@
M;G5M8F5R+B(*;7-G<W1R(").92!P975T(&1I<FEG97(@;&4@;65S<V%G92!V
M97)S(&QE(&YO;6)R92!S<.EC:69IZ2XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#
M87!E(%9E<F1E(@IM<V=S='(@(D-A<"U697)T(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`IM<V=I9"`B0V%P
M=&EO;B(*;7-G<W1R("),Z6=E;F1E(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM<V=S
M='(@(E1R86YS<&]R=&5U<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M,PIM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(D-A=.EG
M;W)I97,@970@R71I<75E='1E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#87EM
M86X@27-L86YD<R(*;7-G<W1R("+.;&5S($-A[VUA;B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@
M4&AO;F4B"FUS9W-T<B`B5.ELZ7!H;VYE(&-E;&QU;&%I<F4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"FUS
M9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B4')O<')IZ73I<R!D92!L
M82!C96QL=6QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B4F5M
M<&QI<W-A9V4@875T;W5R(&1E(&QA(&-E;&QU;&6@.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@
M(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R(")0<F]P<FGI=.ES(&1E(&QA(&-E
M;&QU;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R(")%<W!A8V5M
M96YT(&1E(&QA(&-E;&QU;&6@.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R-S$*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R(")4Z6SI<&AO;F4@
M8V5L;'5L86ER92`B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I
M9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B0V5L=&4@*$E33RTX
M.#4Y+3$T*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R(")#96YT<F5R
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC
M(@IM<V=S='(@(E+I<'5B;&EQ=64@8V5N=')A9G)I8V%I;F4B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H
M25-/+3@X-3DM,BDB"FUS9W-T<B`B175R;W#I96X@8V5N=')A;"`H25-/+3@X
M-3DM,BDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P
M,`IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R(")$Z71A:6QS
M(&1U(&-E<G1I9FEC870B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8Q,@IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B
M4')O<')IZ71A:7)E(&1U(&-E<G1I9FEC870B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0V5R=&EF:6-A=&4@4&]L
M:6-I97,B"FUS9W-T<B`B4&]L:71I<75E(&1E(&-E<G1I9FEC871I;VXB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS9W-T<B`B5&-H860B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B36]D:69I
M97(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G:60@
M(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(DUO9&EF:65R('9O=')E
M(&UO="!D92!P87-S92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.0IM
M<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O
M<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E
M;6%I;',N(@IM<V=S='(@(B(*(D-H86YG97(@;&4@;F]M+"!L)V%D<F5S<V4@
M970@;&$@<VEG;F%T=7)E('%U92!L97,@<&5R<V]N;F5S('9O:65N="!Q=6%N
M9"`B"B)E;&QE<R!L:7-E;G0@970@<NEP;VYD96YT(.`@=F]S(&UE<W-A9V5S
M+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B
M(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I
M=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B),82!M;V1I9FEC871I;VX@
M9&4@=F]T<F4@;6]T(&1E('!A<W-E(&XG97-T('!A<R!S=7!P;W)TZ64@879E
M8R!L82`B"B)C;VYF:6=U<F%T:6]N(&%C='5E;&QE+B!#;VYT86-T97H@=F]T
M<F4@861M:6YI<W1R871E=7(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA<B(*;7-G<W1R
M(")#:&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R
M(")6Z5]R:69I97(@;&4@;&EE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6QE
M(@IM<V=S='(@(D-H:6QI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;F$B"FUS
M9W-T<B`B0VAI;F4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I
M9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(D-H:6YO
M:7,@<VEM<&QI9FGI("A'0C(S,3(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#0*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S
M='(@(D-H:6YO:7,@=')A9&ET:6]N;F5L("A":6<U*2(*"B,Z('1E;7!L871E
M<R]P<F5F<R]A<'`N:6YC.C<*;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB
M"FUS9W-T<B`B0VAO:7-I<B!L)V%P<&QI8V%T:6]NH#HB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED(")#:&]O<V4@82!P
M87-S=V]R9"(*;7-G<W1R(")#:&]I<VER('5N(&UO="!D92!P87-S92(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(D-H
M;V]S92!A('5S97)N86UE(@IM<V=S='(@(D-H;VES:7(@=6X@;F]M(&1E(&-O
M;FYE>&EO;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#(*;7-G:60@
M(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B0VAO:7-I
M<B!L92!M;V1E(&0G869F:6-H86=E(&1E<R!D871E<Z`Z(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM
M<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES
M=',I(@IM<V=S='(@(D-H;VES:7(@;&4@<W1Y;&4@9&4@;&ES=&4@*'!O=7(@
M;&5S(&QI<W1E<R!N=6WI<FEQ=65S*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H
M<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`BSFQE<R!#:')I<W1M87,B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z.3$T"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I
M;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R(")$Z69I;FET:6]N(&1E(&QA
M(&-L87-S92!D92`E<R!N;VX@=')O=7;I92XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B0VQE87(B"FUS9W-T
M<B`B169F86-E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T
M<B`B3F5T=&]Y97(@;&5S(&)A;&ES97,@35,M3V9F:6-E(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$R.0IM<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`B
M169F86-E<B!L82!R97%UZG1E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S
M97(Z("5S(@IM<V=S='(@(E)E=&ER97(@;"=U=&EL:7-A=&5U<CH@)7,B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L
M96%R('5S97(B"FUS9W-T<B`B169F86-E<B!L)W5T:6QI<V%T975R(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R
M('5S97(@9&%T82(*;7-G<W1R(")%9F9A8V5R(&QE<R!D;VYNZ65S(&1E(&PG
M=71I;&ES871E=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("+)8VQA
M:7)C:65S('1A<F0@9&%N<R!L82!J;W5R;NEE(@H*(SH@=&5M<&QA=&5S+VUA
M:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O
M($-O;G1I;G5E(@IM<V=S='(@(D-L:7%U97(@<&]U<B!P;W5R<W5I=G)E(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(D-L:6-K
M871E;&P@=FEA($A45%`B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I
M;F1O=R(*;7-G<W1R(")&97)M97(@;&$@9F5NZG1R92(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C4Q"FUS9VED(")#;&]U9',B"FUS9W-T<B`B3G5A9V5S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*
M;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R(").=6%G97,@;6%T:6YA=7@B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PIM
M<V=I9"`B0VQO=61Y(@IM<V=S='(@(DYU86=E=7@B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS
M9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("+.;&5S($-O
M8V]S(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM<V=I
M9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R(")297!L:65R(&QA(&)A<G)E
M(&1E(&/T=.DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G
M<W1R(")2Z61U:7)E(&QE<R!B;W)D<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O
M;&]M8FEA(@IM<V=S='(@(D-O;&]M8FEE(@H*(SH@;&EB+T)L;V-K+V-O;&]R
M+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O
M;&]R(@IM<V=S='(@(D-O=6QE=7(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO0V]L;&5C=&EO;BYP:'`Z,S,U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R]#;VQL96-T:6]N+G!H<#HS,S8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C4P,R!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K
M97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B4&%L971T
M92!D92!C;W5L975R<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,C4*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B4^EL96-T:6]N
M(&0G=6YE(&-O=6QE=7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B0V]L<Z`Z
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT,PIM<V=I9"`B0V]L
M=6UN('1I=&QE<R(*;7-G<W1R(")4:71R97,@9&4@8V]L;VYN92(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C8*;7-G:60@(D-O;6EC<R(*;7-G
M<W1R(")"+D0N(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(V"FUS9VED(")#
M;VUM86YD(@IM<V=S='(@(D-O;6UA;F1E(@H*(SH@861M:6XO8VUD<VAE;&PN
M<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(D-O;6UA;F1E
M('-H96QL(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S
M"FUS9VED(")#;VUM96YT(@IM<V=S='(@(D-O;6UE;G1A:7)E(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D-O;6UO
M;B!.86UE(@IM<V=S='(@(DYO;2!U<W5E;"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED
M(")#;VUO<F]S(@IM<V=S='(@(D-O;6]R97,B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM
M<V=S='(@(E-O8VGI=.DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*
M;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R(")/<F1I;F%T975R<R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#8*;7-G:60@(D-O;F1I=&EO
M;B(*;7-G<W1R(")#;VYD:71I;VXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(U-@IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R(")#;VYD:71I;VYS(@H*
M(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I
M;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B1&EF9NER96YC97,@9&4@8V]N9FEG
M=7)A=&EO;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#8*;7-G:60@
M(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H
M;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@HB4WEN8VAR;VYI<V%T:6]N
M(&1E<R!A<W-I<W1A;G1S('!E<G-O;FYE;',L(#Q)/G-M87)T<&AO;F5S/"])
M/B!E="!/=71L;V]K+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*
M;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@
M(DQA(&-O;F9I9W5R871I;VX@;B=E<W0@<&%S(.`@:F]U<BXB"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M;F9I9W5R92`E<R(*;7-G<W1R(")#;VYF:6=U<F5R("5S(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!0
M87-S=V]R9"(*;7-G<W1R(")#;VYF:7)M97(@;&4@;6]T(&1E('!A<W-E(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B0V]N9V\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@
M;V8@=&AE(@IM<V=S='(@(E+I<'5B;&EQ=64@9.EM;V-R871I<75E(&1U($-O
M;F=O(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,3DW"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P
M.`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@(LEC:&5C(&1E
M(&QA(&-O;FYE>&EO;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$Y-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS,#@*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T
M<B`BR6-H96,@9&4@;&$@8V]N;F5X:6]NH#H@(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN96-T:6]N(')E9G5S
M960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(D-O;FYE>&EO
M;B!A=2!S97)V975R(&1E(&-L969S('!U8FQI8R!R969U<^EE+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES
M97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R(")#;VYN97AI;VX@874@
M<V5R=F5U<B!D92!C;&5F<R!P=6)L:6,@<F5F=7/I92X@4F%I<V]NH#H@("5S
M("@E<RDB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@W-@IM<V=I
M9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B
MR6-H96,@9&4@;&$@8V]N;F5X:6]N(&%U('-E<G9E=7(@1E10(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C0@8V]N9FEG+VAO;VMS+G!H<"YD
M:7-T.C$P-C<*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@(D-O;G1A8W1S(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4S"FUS
M9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R
M(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B0V5S(&-O;G1A8W1S(&]N="!B:65N
M(.ETZ2!A:F]U=.ES(.`@=F]T<F4@8V%R;F5T(&0G861R97-S97,N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HV,`IM<V=I9"`B
M0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@(@IM<V=S='(@(E1Y
M<&4@9&4@8V]N=&5N=2!D=2!F:6-H:65R(&-O;7!R97-SZ:`Z("(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R(")#;VYT96YU(&1E(*N@)7.@
MNR(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS9W-T
M<B`B4&]U<G-U:79R92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD
M<R(*;7-G<W1R("+.;&5S($-O;VLB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R(")4Z6UO:6X@*&-O;VMI92DB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B0V]P:65R(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(LEC:&5C(&1E(&QA(&-O<&EE
MH#H@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R(")3Z6QE8W1I
M;VX@9"=U;F4@8V]P:64B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$W,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R("))9"X@8V_[="(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B0V]S=&$@
M4FEC82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T
M<B`B0_1T92!D)TEV;VER92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A
M9V4Z("(*;7-G<W1R("));7!O<W-I8FQE(&1E(&-H:69F<F5R(&QE(&UE<W-A
M9V6@.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4U
M"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@(@IM<V=S='(@
M(E-I9VYA='5R92!01U`@9'4@;65S<V%G92!I;7!O<W-I8FQEH#H@(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O
M=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("));7!O
M<W-I8FQE(&1E(&-H:69F<F5R(&QE(&UE<W-A9V4@879E8R!3+TU)344N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@
M(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R(")3:6=N
M871U<F4@4R]-24U%(&1U(&UE<W-A9V4@:6UP;W-S:6)L92XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM
M<V=S='(@(D%J;W5T(&1U(&-O;G1A8W0@)7,@:6UP;W-S:6)L92X@(@H*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.CDV(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HT-3<*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*
M;7-G<W1R(").92!P975T('-E(&-O;FYE8W1E<B!A=2!S97)V975R($Q$05`N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C
M:R!B86QA;F-E+B`E<R(*;7-G<W1R(")6Z7)I9FEC871I;VX@9&4@;&$@8F%L
M86YC92`E<R!I;7!O<W-I8FQE+B`B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-#0Q"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E
M<BXB"FUS9W-T<B`BR6-H96,@9&4@;&$@8V]N;F5X:6]N(&%U('-E<G9E=7(@
M3$1!4"XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<
M(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(LEC:&5C(&1E(&QA(&-O;FYE>&EO
M;B!A=2!S97)V975R(*N@)7.@NR!V:6$@1E10H#H@)7,B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<R(*;7-G<W1R(")#<NEA=&EO;B!D92!L:7-T92!D92!D:7-T<FEB
M=71I;VX@:6UP;W-S:6)L92X@)7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,3(X"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@
M9&%T83H@(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@9.EC:&EF9G)E<B!L97,@
M9&]N;NEE<R!01U"@.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4R,PIM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A
M=&$N(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@9.EC:&EF9G)E<B!L97,@9&]N
M;NEE<R!3+TU)344N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R(").92!P975T('!A<R!S
M=7!P<FEM97(@;&4@8V]N=&%C="`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM
M<V=S='(@(DYE('!E=70@<&%S('-U<'!R:6UE<B!L82!L:7-T92!D92!D:7-T
M<FEB=71I;VX@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P
M9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B3F4@<&5U="!P87,@<W5P
M<')I;65R(&QE('-C<FEP="!D92!M:7-E(.`@:F]U<B"KH"5SH+LN(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@9&5T
M97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T
M<B`B1.ET97)M:6YA=&EO;B!D92!L)V%D<F5S<V4@9'4@9&5S=&EN871A:7)E
M(&EM<&]S<VEB;&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP
M;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(DYE('!E=70@<NEC=7#I<F5R
M('1O=70@;&4@8V%R;F5T(&0G861R97-S92XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@
M;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R
M(").92!P975T('+I8W5PZ7)E<B!T;W5T92!L82!L:7-T92!D92!D:7-T<FEB
M=71I;VXN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE
M=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(DXG82!P
M87,@<'4@<NEC=7#I<F5R(&QA(&QI<W1E(&-O;7!LZ'1E(&1E(&QI<W1E<R!D
M92!D:7-T<FEB=71I;VXN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S
M=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@8VAA<F=E
M<B!L82!S=')A=.EG:64@JZ`E<Z"[+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ
M,3`*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB
M;&4@9&4@8W+I97(@;&4@<NEP97)T;VER92"KH"5SH+LN(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@
M;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R
M("));7!O<W-I8FQE(&0G;V)T96YI<B!L82!C;&5F('!U8FQI<75E(.`@<&%R
M=&ER(&1U('-E<G9E=7(@9&4@8VQE9G,N(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S
M7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(D]U=F5R='5R92!D92"KH"5SH+L@
M:6UP;W-S:6)L92!E;B#I8W)I='5R92XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(D]U=F5R='5R92!D
M92`E<R!I;7!O<W-I8FQE+B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-
M86EN=&5N86YC92YP:'`Z-#(P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@
M(DEM<&]S<VEB;&4@9"=O=79R:7(@;&4@;6]D=6QE($UA:6YT96YA;F-E7U1A
M<VL@)7,B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T
M<B`B3W5V97)T=7)E(&1U(&1O<W-I97(@JZ`E<Z"[(&EM<&]S<VEB;&4N(@H*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C0W.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-3$V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-CDY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@
M=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("));7!O<W-I8FQE(&0G871T96EN
M9')E(&QE('-E<G9E=7(@3$1!4"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/
M8FIE8W0N<&AP.C(T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<F5A9"`E<RXB"FUS9W-T<B`B3&5C='5R92!D92`E<R!I;7!O<W-I8FQE+B`B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB
M0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E
M9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T
M(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R
M871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*
M(DXG82!P=2!R96UE='1R92#@('KI<F\@;&4@;6]T(&1E('!A<W-E('!O=7(@
M;"=U=&EL:7-A=&5U<B!D96UA;F3I+B!#97)T86EN<R`B"B(H;W4@=&]U<RD@
M;&5S(&3I=&%I;',@;F4@<V]N="!P87,@8V]R<F5C=',N(%+I97-S87EE>B!O
M=2!C;VYT86-T97H@=F]T<F4@(@HB861M:6YI<W1R871E=7(@<&]U<B!D92!L
M)V%I9&4N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S`W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,S.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M-S4*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Q
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-PIM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R(")2Z6-U<.ER
M871I;VX@9&5S($%#3"!I;7!O<W-I8FQE(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,B"FUS
M9W-T<B`B3F4@<&5U="!RZ6-U<.ER97(@;&4@8V%R;F5T(&0G861R97-S97,N
M("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").92!P975T('+I
M8W5PZ7)E<B!L82!L:7-T92!D92!D:7-T<FEB=71I;VXN("5S(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U
M=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B3F4@<&5U="!RZ6-U<.ER97(@;&5S
M(&QI<W1E<R!D92!D:7-T<FEB=71I;VXN("5S(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q-PHC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HR,C$*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B3F4@<&5U="!R
MZ6-U<.ER97(@;&5S('!O<W-I8FEL:73I<R!D=2!S97)V975R(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T(')E=F5R
M="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").92!P975T('!A<R!R979E;FER
M(.`@;&$@8V]N9FEG=7)A=&EO;B!P<NECZ61E;G1E+B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD
M:7(@7"(E<UPB+B(*;7-G<W1R(")%9F9A8V5M96YT(&1U(&1O<W-I97(@JZ`E
M<Z"[(&EM<&]S<VEB;&4N("(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(DYE('!E=70@<&%S(&5N<F5G:7-T<F5R
M(&QA(&-O;F9I9W5R871I;VX@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD
M(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B3F4@
M<&5U="!P87,@96YR96=I<W1R97(@=6YE('-A=79E9V%R9&4@9&4@;&$@8V]N
M9FEG=7)A=&EO;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N
M9FEG=6%T:6]N.B`E<R(*;7-G<W1R("));7!O<W-I8FQE(&0G96YR96=I<W1R
M97(@=6YE(&-O<&EE(&1E(&QA(&-O;F9I9W5R871I;VZ@.B`E<R(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S
M7"(N(@IM<V=S='(@(DEM<&]S<VEB;&4@9"=E;G)E9VES=')E<B!L92!S8W)I
M<'0@9&4@;6ES92#@(&IO=7(@9&%N<Z`Z(*N@)7.@NRXB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*
M;7-G<W1R("));7!O<W-I8FQE(&0G96YR96=I<W1R97(@=6YE(&-O<&EE(&1U
M(&9I8VAI97(@9&4@8V]N9FEG=7)A=&EO;B`E<RXB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD
M(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@
M96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@
M8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L
M;W<@=&\@)7,N(@IM<V=S='(@(B(*(DEM<&]S<VEB;&4@9"=E;G)E9VES=')E
M<B!L92!F:6-H:65R(&1E(&-O;F9I9W5R871I;VX@)7,N(%9O=7,@<&]U=F5Z
M('-O:70@(@HB=71I;&ES97(@=6YE(&1E<R!O<'1I;VYS('!O=7(@<V%U=F5R
M(&QE(&-O9&4@<W5R("5S('-O:70@8V]P:65R(&UA;G5E;&QE;65N="`B"B)L
M92!C;V1E(&-I+61E<W-O=7,@9&%N<R`E<RXB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T
M:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DYE('!E=70@<&%S(')E8VAE<F-H
M97(@;&4@<V5R=F5U<B!,1$%0+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB
M"FUS9W-T<B`B4W5P<')E<W-I;VX@9&4@JZ`E<Z"[(&EM<&]S<VEB;&4N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR
M,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT
M86-T+B`E<R(*;7-G<W1R(")-:7-E(.`@:F]U<B!D=2!C;VYT86-T(&EM<&]S
M<VEB;&4N("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3F4@<&5U
M="!M971T<F4@X"!J;W5R(&QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO;BX@)7,B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<
M(CH@)7,B"FUS9W-T<B`B3F4@<&5U="!P87,@96YR96=I<W1R97(@;&$@8V]N
M9FEG=7)A=&EO;B!P;W5R(*N@)7.@NZ`Z("5S(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,W,`IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL
M82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS
M9W-T<B`B3F4@<&5U="!T<F]U=F5R(&QA(&)A<G)E(&1E($UO>FEL;&$N("!!
M<W-U<F5Z+79O=7,@<74G96QL92!E<W0@86-T:79E+B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL
M;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B(@HB3F4@<&5U="!A='1R:6)U97(@8V5S(&1R;VET<R#@(&PG=71I;&ES
M871E=7(@JZ`E<Z"[("!S=7(@;&4@9&]S<VEE<B"KH"5SH+N@.B`B"B(E<R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,38*;7-G:60@(D-O=6YT
M960@=&5X="(*;7-G<W1R(")497AT92!C;VUP=.DB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B0V]U;G1R>2(*;7-G
M<W1R(")087ES(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W-0IM
M<V=I9"`B0V]U<G-E<R(*;7-G<W1R(")#;W5R<R(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I
M9"`B0W)E871E(@IM<V=S='(@(D-RZ65R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A
M=&4@82!L:6YK(@IM<V=S='(@(D-RZ65R('5N(&QI96XB"@HC.B!T96UP;&%T
M97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS9VED(")#<F5A=&4@
M82!N97<@;VYE(@IM<V=S='(@(D-RZ65R('5N(&YO=79E874B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E
M('-U8B!F;VQD97)S(@IM<V=S='(@(D-RZ65R('5N('-O=7,M9&]S<VEE<B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0P"FUS9VED(")#
M<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUI<W-I;VYS($1E($-R
MZ6%T975R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(P.0IM<V=I
M9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(DYU;>ER;R!D92!C87)T
M92!D92!C<NED:70B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G
M<W1R(")#<F]A=&EE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R
M(")#=6)A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R
M96YT(#0@4&AA<V5S(@IM<V=S='(@(C0@<&AA<V5S(&-O=7)A;G1E<R(*"B,Z
M(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`IM<V=I9"`B0W5R<F5N="!397-S:6]N
M<R(*;7-G<W1R(")397-S:6]N<R!E;B!C;W5R<R(*"B,Z(&QI8B]";&]C:R]T
M:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N
M="!4:6UE(@IM<V=S='(@(DAE=7)E(&%C='5E;&QE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED
M(")#=7)R96YT(%523"!I<R(*;7-G<W1R("),)V%D<F5S<V4@55),(&%C='5E
M;&QE(&5S="(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0IM<V=I9"`B0W5R
M<F5N="!5<V5R<R(*;7-G<W1R(")5=&EL:7-A=&5U<G,@86-T=65L<R(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE
M<B(*;7-G<W1R(")/8G-E<G9A=&EO;G,@86-T=65L;&5S(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(V-`IM<V=I9"`B0W5R<F5N="!C;VYD
M:71I;VXZ("(*;7-G<W1R(")#;VYD:71I;VX@86-T=65L;&6@.B`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,R"FUS9VED
M(")#=7)R96YT('-T>6QE(@IM<V=S='(@(E-T>6QE(&-O=7)A;G0B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS
M9W-T<B`B1.EF:6YI<B!L97,@=.)C:&5S(.`@969F96-T=65R(&QO<G,@9&4@
M;&$@8V]N;F5X:6]N(.`@)7,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T
M<B`B0V]U<&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R(")#;W5P
M97(@;&$@<^EL96-T:6]N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM
M<V=S='(@(D-H>7!R92(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS
M9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R(")#>7)I;&QI<75E("A+
M3TDX+5(I(@H*(R!C;VYF:6<O;FQS+G!H<"YD:7-T.@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X-@IM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB
M"FUS9W-T<B`B0WER:6QL:7%U92`H5VEN9&]W<RTQ,C4Q*2(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@
M*$M/23@M52DB"FUS9W-T<B`B0WER:6QL:7%U92]5:W)A:6YI96X@*$M/23@M
M52DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R
M(")2Z7!U8FQI<75E(%1C:.AQ=64B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#4R('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P
M"FUS9VED(")$1"(*;7-G<W1R(")*2B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R-CD*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H
M<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N
M+G!H<"DB"FUS9W-T<B`B(@HB1%-.("A#9BX@:'1T<#HO+W!E87(N<&AP+FYE
M="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP
M*2(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z
M-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(D-H87%U92!J;W5R(@H*(SH@861M
M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM
M<V=S='(@(DYA=FEG871E=7(@9&4@1&%T851R964B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,C8W"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS
M9W-T<B`B06QI87,@9&4@;&$@8F%S92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,Y-0IM<V=I9"`B1&%T92(*;7-G<W1R(")$871E(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C
M96EV960B"FUS9W-T<B`B1&%T92!D92!RZ6-E<'1I;VXB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-S@V"FUS9VED(")$871E('-E;&5C=&EO;B(*
M;7-G<W1R(")3Z6QE8W1I;VX@9"=U;F4@9&%T92(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.#$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,Q,0IM<V=I9"`B1&%Y(@IM<V=S='(@(DIO=7(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G
M:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(E-U<'!R:6UE<B!?;&$@8V]L
M;VYN92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0U,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R(")$Z6-E;6)R92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R(").;VUB<F5S(&3I
M8VEM875X(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(D1I;6EN
M=65R(&PG:6YD96YT871I;VXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PIM<V=I9"`B1&5F875L="(*
M;7-G<W1R(")$Z69A=70B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHW-PIM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R
M(")#;W5L975R('!A<B!DZ69A=70B"@HC.B!F<F%M97=O<FLO261E;G1I='DO
M261E;G1I='DN<&AP.CDV"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S
M='(@(DED96YT:73I('!A<B!DZ69A=70B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-C<*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B26YT97)P
M<NET975R(&1E(&-O;6UA;F1E('!A<B!DZ69A=70B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(D3I
M9FEN:71I;VYS(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,2!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY
M,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(D5F9F%C97(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S(*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(D5F9F%C97(@;&$@8V5L
M;'5L92(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP
M:'`Z,C(W"FUS9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B4W5P<')I;65R
M('5N(&=R;W5P92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T
M.0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R(")%9F9A8V5R(&QA('1R86-E
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E<FUI
M<W-I;VXB"FUS9W-T<B`B4W5P<')I;65R('5N92!P97)M:7-S:6]N(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@
M(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B4W5P<')I;65R
M(&5T('!U<F=E<B!L97,@;65S<V%G97,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE=&4@
M8V5L;"(*;7-G<W1R(")%9F9A8V5R(&QA(&-E;&QU;&4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S"FUS9VED
M(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(D5F9F%C97(@;&$@8V]L;VYN92(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI
M<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(E-U<'!R:6UE<B!U
M;B!A=71R92!M;V3H;&4@97AI<W1A;G0B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,T,S$T+G!H<#HU-`IM<V=I9"`B1&5L971E(&UE<W-A9V5S
M(@IM<V=S='(@(E-U<'!R:6UE<B!L97,@;65S<V%G97,B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")3=7!P
M<FEM97(@;&5S('!E<FUI<W-I;VYS('!O=7(@JZ`E<Z"[(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M
M<&5R;6ES<VEO;G,_(@IM<V=S='(@(LIT97,M=F]U<R!C97)T86EN(&1E('9O
M=6QO:7(@969F86-E<B"KH"5SH+L@970@<V5S('-O=7,M<&5R;6ES<VEO;G.@
M/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`B169F86-E<B!L
M82!R86YGZ64B"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN
M:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T
M<B`B4W5P<')I;65R(&PG:61E;G1I=.D@<^EL96-T:6]N;NEE(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3,*;7-G:60@(D1E
M;&5T92!S=6(@9F]L9&5R<R(*;7-G<W1R(")3=7!P<FEM97(@=6X@<V]U<RUD
M;W-S:65R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L
M=6UN(@IM<V=S='(@(D5F9F%C97(@;&$@8V]L;VYN92!A8W1U96QL92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R(")%
M9F9A8V5R(&QA(')A;F?I92!A8W1U96QL92(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C,V"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")38W)I<'0@9&4@
M8V]N9FEG=7)A=&EO;B!D92!M:7-E(.`@:F]U<B!S=7!P<FEMZ2"KH"5SH+LN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(U,PIM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R
M(")(975R92!D92!L:79R86ES;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM
M87)K(@IM<V=S='(@(D1A;F5M87)K(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM
M<V=S='(@(D3I8W)I<F4@;&4@<')O8FSH;64B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HY,S4@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B
M1&5S8W)I<'1I;VXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(P
M-@IM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*
M;7-G<W1R(")$Z71A:6QS("AA=7-S:2!D86YS(&QE(&9I8VAI97(@9&4@=')A
M8V5S(&1E($AO<F1E*:`Z(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HR,3`*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE
M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(DQE<R!DZ71A:6QS(&]N="#I=.D@
M8V]N<VEG;NES('!O=7(@;"=A9&UI;FES=')A=&5U<BXB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C(Q"FUS9VED(")$979E;&]P;65N="(*;7-G
M<W1R(")$Z79E;&]P<&5M96YT(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,C0*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R(")0;VEN="!D92!R;W/I92(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`Q"FUS9VED(")$97<@4&]I;G0@
M9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E!O:6YT(&1E(')O<^EE('!O=7(@
M;&$@9&5R;FGH<F4@:&5U<F6@.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C$V"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R(")0;VEN
M="!D92!R;W/I9:`Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT
M(@IM<V=S='(@(D1E(&=A=6-H92#@(&1R;VET92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO
M;B!R:6=H="!T;R!L969T(@IM<V=S='(@(D1E(&1R;VET92#@(&=A=6-H92(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB
M"FUS9W-T<B`B4NEP97)T;VER92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-S`*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B
M069F:6-H97(@<W5R(#(T(&AE=7)E<Z`_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(D]P
M=&EO;G,@9"=A9F9I8VAA9V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z.#D*;7-G:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS
M9W-T<B`B069F:6-H97(@;&$@<'+I=FES:6]N(&3I=&%I;&SI92(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z.3(*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@
M*%1!1BDB"FUS9W-T<B`B069F:6-H97(@;&$@<'+I=FES:6]N("A4048I(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y-@IM<V=I9"`B1&ES<&QA
M>2!F;W)M870B"FUS9W-T<B`B1F]R;6%T(&0G869F:6-H86=E(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,0IM<V=I9"`B1&ES<&]S:71I
M;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(D%V:7,@9&4@;&EV<F%I<V]N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B1&II8F]U=&DB
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,@IM<V=I9"`B
M1&\@;F]T(&1E;&5T92(*;7-G<W1R(").92!P87,@<W5P<')I;65R(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER
M96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R(").92!P87,@
M86-CZ61E<B!D:7)E8W1E;65N="#@(&UA:6YT96YA;F-E+G!H<"(*"B,Z('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$R('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I
M;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM
M<V=S='(@(B(*(DQE('!R96UI97(@96YR96=I<W1R96UE;G0@8V]N=&EE;G0M
M:6P@;&4@;F]M(&1E<R!C:&%M<'.@/R!$86YS("(*(FPG869F:7)M871I=F4L
M(&-O8VAE>B!C971T92!B;^YT9:`Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&]M
M:6YI8V$B"FUS9W-T<B`B1&]M:6YI<75E(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B
M1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(E+I<'5B;&EQ=64@9&]M:6YI
M8V%I;F4B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED
M(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(E9O
M=7,@;B=A=F5Z('!A<R!D92!C;VUP=&6@/R!%;G)E9VES=')E>BUV;W5S+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@U,0IM<V=I
M9"`B1&]W;FQO860B"FUS9W-T<B`B5.ELZ6-H87)G97(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B5.ELZ6-H87)G97(@)7,B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R
M(")4Z6SI8VAA<F=E<B!L82!C;VYF:6=U<F%T:6]N(&?I;NERZ64@8V]M;64@
M=6X@<V-R:7!T(%!(4"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M,#0*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(DQI<W1E(&3I<F]U
M;&%N=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R
M=6=S(@IM<V=S='(@(D1R;V=U97,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3,*;7-G:60@(D4M36%I;"(*;7-G<W1R(")#;W5R<FEE
M<B#I;&5C=')O;FEQ=64B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N
M97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3(&=A=&5W87D@
M9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I
M8V4N(@IM<V=S='(@(B(*(E!I;&]T92!D92!P87-S97)E;&QE(&-O=7)R:65R
M("\@4TU3+"!P;W5R(&QE<R!F;W5R;FES<V5U<G,@9&4@8V4@<V5R=FEC92XB
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B15)2(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R("+)<75A=&5U<B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@IM<V=I9"`B161I="(*;7-G<W1R
M(")-;V1I9FEE<B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z
M-3`*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`BR61I=&5R(&QE(&)L;V,B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R
M-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R("+)9&ET97(@=6X@9W)O=7!E
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`IM<V=I9"`B161I="!097)M:7-S
M:6]N(@IM<V=S='(@(LED:71E<B!U;F4@<&5R;6ES<VEO;B(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO
M;G,B"FUS9W-T<B`BR61I=&5R(&QE<R!P97)M:7-S:6]N<R(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`BR61I=&5R(&QE<R!P
M97)M:7-S:6]N<R!P;W5R(*N@)7.@NR(*"B,Z('1E;7!L871E<R]P<F5F<R]A
M<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(LED
M:71E<B!L97,@;W!T:6]N<R!P;W5RH#HB"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E
M<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`BR61I=&5R(&QE<R!P97)M
M:7-S:6]N<R!P;W5R(*N@)7.@NR(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N
M<R!F;W(@)7,B"FUS9W-T<B`BR61I=&5R(&QE<R!P97)M:7-S:6]N<R!P;W5R
M("5S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C
M871I;VXB"FUS9W-T<B`BR61U8V%T:6]N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B
M16=Y<'0B"FUS9W-T<B`BR6=Y<'1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%
M;"!386QV861O<B(*;7-G<W1R(")386QV861O<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B
M16QE;65N="XN+B(*;7-G<W1R("+);.EM96YT+BXN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM
M<V=S='(@(D5M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8V"FUS9VED
M(")%;6%I;"(*;7-G<W1R(")!9')E<W-E(.EL96-T<F]N:7%U92(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38V('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHV.`IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R
M(")!9')E<W-E(.EL96-T<F]N:7%U92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-C`*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H
M+B(*;7-G<W1R("),97,@861R97-S97,@Z6QE8W1R;VYI<75E<R!D;VEV96YT
M(&-O<G)E<W!O;F1R92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.3@V"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")#
M;W5R<FEE<B!A=F5C(&-O;F9I<FUA=&EO;B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU3
M35,@1V%T97=A>2(*;7-G<W1R(")087-S97)E;&QE(&-O=7)R:65R("\@4TU3
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y
M.0IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(LEM;W1I8_1N97,B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*
M;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(DUE<W-A9V4@=FED92XB
M"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,34P"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@(E+I<W5L=&%T('9I
M9&4N(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q,PIM
M<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(E1E<FUE<R!D92!R
M96-H97)C:&4@=FED92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#<*
M;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@
M1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(D%C=&EV97(@;"=I;G-E<G1I
M;VX@9"=I;6%G97,@=F5N86YT(&1E<R!A;&)U;7,@<&AO=&]S(&1A;G,@;&4@
M=&5X=&6@/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C(*;7-G:60@
M(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(D%C
M=&EV97(@;&4@;65N=2!C;VYT97AT=65L(&%V96,@=6X@8VQI8R!D<F]I=*`_
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4X-2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-SDP"FUS9VED(")%;F0@>65A<B(*;7-G<W1R(")&
M:6X@9&4@;"=A;F[I92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@
M(D%G<F%N9&ER(&PGZ61I=&5U<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,C0*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI
M8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U
M<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R
M('!E=#\G.B(*;7-G<W1R("(B"B+)8W)I=F5Z('5N92!Q=65S=&EO;B!D92!S
MZ6-U<FETZ2!Q=2=O;B!V;W5S('!O<V5R82!S:2!V;W5S(&1E=F5Z(')E;65T
M=')E(.`@(@HB>NER;R!V;W1R92!M;W0@9&4@<&%S<V4L('!A<B!E>&5M<&QE
M(*L@475E;"!E<W0@;&4@;F]M(&1E('9O=')E(&%N:6UA;"`B"B)P<NEFZ7+I
MH#^@NZ`Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),
M(&AE<F4B"FUS9W-T<B`B26YS8W)I=F5Z(&PG861R97-S92!54DP@9&4@;"=I
M;6%G92!I8VDB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.#DR"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS
M9W-T<B`B16YT<F5Z(&QE<R!L971T<F5S(&-I+61E<W-O=7.@.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(D=U:6[I
M92#I<75A=&]R:6%L92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS
M9W-T<B`BR7)Y=&ARZ64B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O5FEE=RYP:'`Z.30@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C0X"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S8*
M;7-G:60@(D5R<F]R(@IM<V=S='(@(D5R<F5U<B(*"B,Z(&9R86UE=V]R:R]4
M96UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R(")%<G)E=7(@;&]R
M<R!D92!L82!C<NEA=&EO;B!D=2!B;&]CH#H@)7,B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B17)R975R(&QO
M<G,@9&4@;&$@<W5P<')E<W-I;VX@9&4@;"=A;F-R92!D92!S>6YC:')O;FES
M871I;VZ@.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S
M"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G
M.B`E<R(*;7-G<W1R(")%<G)E=7(@;&]R<R!D92!L82!S=7!P<F5S<VEO;B!D
M=2!J;W5R;F%L(&1E('-Y;F-H<F]N:7-A=&EO;J`Z("5S(@H*(SH@9G)A;65W
M;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R(")%<G)E
M=7(@;&]R<R!D92!L82!RZ6-U<.ER871I;VX@9'4@8V]N=&5N=:`Z("5S(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R
M(")%<G)E=7(@;&]R<R!D92!L82!M:7-E(.`@:F]U<B!D=2!M;W0@9&4@<&%S
M<V6@.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S86=E
M+B(*;7-G<W1R(")%<G)E=7(@879E8R!L92!M97-S86=E+B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I
M=&EN9R!<(B5S7"(N(@IM<V=S='(@(D5R<F5U<B!L;W)S(&1E(&PG96YR96=I
M<W1R96UE;G0@9&4@JZ`E<Z"[+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N
M:6$B"FUS9W-T<B`B17-T;VYI92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO
M<&EA(@IM<V=S='(@(LET:&EO<&EE(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B171H;FEQ=64B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*
M;7-G<W1R(")%=7)O<&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0S
M"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(E1O=7,@;&5S("9F
M<F%C,30[(&0G:&5U<F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDS
M"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B5&]U=&5S(&QE<R`R
M(&UI;G5T97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0P(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B
M"FUS9W-T<B`B5&]U=&5S(&QE<R`S,"!S96-O;F1E<R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-#(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-`IM
M<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(E1O=71E<R!L97,@-2!M
M:6YU=&5S(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E
M+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`BP"!C:&%Q=64@
M8V]N;F5X:6]N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T-`IM<V=I
M9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(E1O=71E<R!L97,@)F9R86,Q
M,CL@:&5U<F5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,2!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,SDR"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS
M9W-T<B`B5&]U=&5S(&QE<R!M:6YU=&5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R
M(")%>&5M<&QE(&1E('9A;&5U<G.@.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H
M<#HX,B!A9&UI;B]C;61S:&5L;"YP:'`Z-3$@861M:6XO<W%L<VAE;&PN<&AP
M.C$R.`IM<V=I9"`B17AE8W5T92(*;7-G<W1R(")%>.EC=71E<B(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C$T"FUS
M9VED(")%>'!A;F0B"FUS9W-T<B`B1.EV96QO<'!E<B(*"B,Z('1E;7!L871E
M<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R
M(@IM<V=S='(@(D3I<&QI97(@;&$@8F%R<F4@9&4@8_1TZ2(*"B,Z(&9R86UE
M=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D
M("<I)R(*;7-G<W1R("*K("D@NR!A='1E;F1U92(*"B,Z(&9R86UE=V]R:R]3
M44PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@
M=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B56X@<V5U;"!M
M;W0@;W4@97AP<F5S<VEO;B!E;G1R92!G=6EL;&5M971S(&%T=&5N9'5S(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%
M>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B1&%T92!D)V5X<&ER871I;VXB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-PIM<V=I9"`B
M17AP;VYE;G0B"FUS9W-T<B`B4F5P<NES96YT86YT(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B
M1D<@0V]L;W(B"FUS9W-T<B`B0V]U;&5U<B!D)V%V86YT+7!L86XB"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F
M('-E='5P(@IM<V=S='(@(E3I;.EC:&%R9V5M96YT('9E<G,@;&4@<V5R=F5U
M<B!D92!L82!C;VYF:6=U<F%T:6]N('!A<B!&5%`B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O<W%L+G!H<#HR,C`*;7-G:60@(D9A:6QE9"!R971R:65V
M:6YG('!R969E<F5N8V5S+B(*;7-G<W1R("),96-T=7)E(&1E<R!P<NEFZ7)E
M;F-E<R!I;7!O<W-I8FQE+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HW-2!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.CDX"FUS
M9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T
M<B`BR6-H96,@9&4@;&$@8V]N;F5X:6]N(&%U('-E<G9E=7(@3$1!4"XB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.3@*;7-G:60@(D9A:6QE
M9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(LEC:&5C(&1E
M(&QA(&-O;FYE>&EO;B!A=2!S97)V975R(%--0BXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL
M960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`BR6-H96,@9&4@;&$@
M8V]P:64@9&5P=6ES(*N@)7.@NRXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C<R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P
M>2!T;R!<(B5S7"(N(@IM<V=S='(@(LEC:&5C(&1E(&QA(&-O<&EE('9E<G,@
M(*N@)7.@NRXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W
M"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN
M(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@8W+I97(@=6YE(&YO=79E;&QE(&-O
M;FYE>&EO;B!305-,(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU
M,#$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-34*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R("+)
M8VAE8R!D=2!DZ7!L86-E;65N="!V97)S(*N@)7.@NRXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C0V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(LEC:&5C(&QO<G,@9&4@
M;&$@<NEC=7#I<F%T:6]NH#H@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R(")"96%U
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN
M87,I(@IM<V=S='(@(LYL97,@1F%L:VQA;F0@*$UA;&]U:6YE<RDB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<S"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S='(@(LYL97,@1NER
M;^DB"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X"FUS9VED(")&871A
M;"!%<G)O<CHB"FUS9W-T<B`B17)R975R(&9A=&%L9:`Z(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X
M(@IM<V=S='(@(D9A>"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M-3$*;7-G:60@(D9A>&5S(@IM<V=S='(@(E3I;.EC;W!I97,B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B
M<G5A<GDB"FUS9W-T<B`B1NEV<FEE<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C(W"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(E1E;7#I<F%T=7)E
M(')E<W-E;G1I92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,C`*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R(")496UPZ7)A='5R92!R
M97-S96YT:66@.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B475E;'%U
M97,@879E<G-E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(E%U
M96QQ=65S(&-H=71E<R!D92!N96EG92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-#$*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R(")-871R
M:6-E(&1E<R!C:&%M<',B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,S(R"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R(")&:6=L970@0T%0
M5$-(02(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,C8*;7-G:60@
M(D9I9VQE="!F;VYT(@IM<V=S='(@(E!O;&EC92!D92!L82`\23YF:6=L970\
M+TD^(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G<W1R(")&:61J:2(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B1FEL
M92(*;7-G<W1R(")&:6-H:65R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL
M92(*;7-G<W1R(").;VUB<F4@9&4@9FEC:&EE<G.@.B`E<R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I
M;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(DYO;6)R92!D92!F:6-H:65R
M<Z`Z("5S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P.0IM<V=I
M9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(D=E<W1I;VYN86ER92!D92!F:6-H
M:65R<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"FUS9VED(")&
M:6QE($YA;64B"FUS9W-T<B`B3F]M(&1U(&9I8VAI97(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.3<T"FUS9VED(")&:6QE('-E;&5C=&EO;B(*
M;7-G<W1R(")#:&]I>"!D92!F:6-H:65R(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30X,PIM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B5.EL
MZ6-H87)G96UE;G0@9&4@9FEC:&EE<B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R
M+T)R;W=S97(N<&AP.CDP,@IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P
M;W)T960N(@IM<V=S='(@(DPG96YV;VD@9&4@9FEC:&EE<G,@;B=E<W0@<&%S
M('!R:7,@96X@8V]M<'1E+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HY,0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R(")&:6QT<F5S(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R(")&:6YL86YD92(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T
M<B`B4')E;6GH<F4@9&5M:64B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@
M;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM
M<V=S='(@(E!R96UI97(@<75A<G1I97(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4W"FUS9VED(")&:7@@<F%T:6\B"FUS
M9W-T<B`B1FEX97(@;&4@<F%T:6\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C,R"FUS9VED(")&;&EP(@IM<V=S='(@(E)E
M=&]U<FYE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(D9L;W1T86YT
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*
M;7-G:60@(D9O9R(*;7-G<W1R(")"<F]U:6QL87)D(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HR,S<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N
M;W0@97AI<W0B"FUS9W-T<B`B1&]S<VEE<B`E<R!I;F5X:7-T86YT+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G
M:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B0V]U;&5U<B!D92!P;VQI8V4B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T
M<B`B3F]U<G)I='5R92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S
M('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B4&]U<B!L97,@
M;F%V:6=A=&5U<G,@;F4@<W5P<&]R=&%N="!P87,@;&5S(&EM86=E<R(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S0Q"FUS9VED(")&;W)E8V%S="`H5$%&
M*2(*;7-G<W1R(")0<NEV:7-I;VX@*%1!1BDB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-S(*;7-G:60@(B(*(D9O<F5C87-T($1A>7,@*&YO
M=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A
M>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S
M=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@HB2F]U<G,@9&4@<'+I
M=FES:6]N("AN;W1E>B!Q=64@;&5S('!RZ79I<VEO;G,@9F]U<FYI97,@9&]N
M;F5N="!L92!J;W5R(&5T(&QA("(*(FYU:72@.R!U;B!G<F%N9"!N;VUB<F4@
M:6-I('!E=70@9F%I<F4@=6X@8FQO8R!T<NAS(&QA<F=E(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R('!A
M<W-W;W)D/R(*;7-G<W1R(")6;W5S(&%V97H@;W5B;&GI('9O=')E(&UO="!D
M92!P87-S9:`_(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V-`IM
M<V=I9"`B1F]R;7,B"FUS9W-T<B`B1F]R;75L86ER97,B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B0VET
M871I;VXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O
M<G1U;F4@='EP92(*;7-G<W1R(")4>7!E(&1E(&-I=&%T:6]N(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R
M(")#:71A=&EO;G,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*;7-G
M:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B0VET871I;VYS(#(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4U"FUS9VED(")&;W)U;7,B"FUS9W-T
M<B`B1F]R=6US(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q,0IM
M<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B4F5D:7)E8W1I;VXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&
M<B(*;7-G<W1R(")692(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@(D9R86UE<R(*;7-G<W1R(")#
M861R97,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B1G)A
M;F-E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED
M(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R(")&<F%N8V4@;>ET<F]P
M;VQI=&%I;F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDQ(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM
M<V=S='(@(D=U>6%N92!F<F%NYV%I<V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B
M1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R(")0;VQY;NES:64@9G)A;N=A:7-E
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET
M;W)I97,B"FUS9W-T<B`B5&5R<F5S(&%U<W1R86QE<R!E="!A;G1A<F-T:7%U
M97,@9G)A;N=A:7-E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`B1&4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS-#D*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,Y-0IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(D1U("(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS9VED(")&=6QL($1E
M<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:7!T:6]N(&-O;7!LZ'1E(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*
M;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R(")0;&5I;F4@;'5N92(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C8P"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B3F]M(&-O
M;7!L970B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R(")'86)O
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R
M;VTB"FUS9W-T<B`B06QB=6T@9"=O<FEG:6YE(&1E(&PG:6UA9V4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(D%L8G5MH#HB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B1V%M8FEE(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'
M96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(D?I;NER97(@;&$@
M8V]N9FEG=7)A=&EO;B!D92`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R
M(")#;V1E(&?I;NERZ2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS
M9W-T<B`B1^EO<F=I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS
M9W-T<B`B06QL96UA9VYE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS
M9W-T<B`B1VAA;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS
M9W-T<B`B1VEB<F%L=&%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S8*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`B4'+I;F]M
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W-2!T96UP;&%T
M97,O<')E9G,O87!P+FEN8SHQ,`HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN
M8SHQ.0IM<V=I9"`B1VQO8F%L($]P=&EO;G,B"FUS9W-T<B`B3W!T:6]N<R!G
M;&]B86QE<R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$W"FUS9VED
M(")';R(*;7-G<W1R(")!;&QE<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(D=O961E;"(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3,Q"FUS9VED(")'
M;V]G;&4@36%P<R(*;7-G<W1R(")#87)T97,@1V]O9VQE(@H*(SH@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G
M<W1R(")296-H97)C:&4@1V]O9VQE(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(S.`IM<V=I9"`B1W)A>7-C86QE(@IM<V=S
M='(@(DYI=F5A=2!D92!G<FES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C
M92(*;7-G<W1R(")'<NAC92(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X
M"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B1W)E8R`H25-/
M+3@X-3DM-RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T
M<B`B1W)OZVYL86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G
M<W1R(")'<F5N861E(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G:60@
M(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<F%T:6]N
M(&1E<R!G<F]U<&5S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU
M.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'
M<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R("),97,@;F]M
M<R!D92!G<F]U<&4@;F4@<&5U=F5N="!P87,@ZG1R92!V:61E<R(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*(D=R
M;W5P7VQD87"@.B!I;7!O<W-I8FQE(&0G86IO=71E<B!L92!G<F]U<&4@)7,N
M($-E8VD@97-T(&QA('+I<&]N<V4@9'4@(@HB<V5R=F5U<J`Z(@H*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q."!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A
M<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L
M9&%PH#H@<W5P<')E<W-I;VX@:6UP;W-S:6)L92!D=2!G<F]U<&4@)7,B"@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S,X(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G
M<W1R(")'<F]U<%]L9&%PH#H@;6]D:69I8V%T:6]N(&EM<&]S<VEB;&4@9'4@
M9W)O=7!E("5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS
M,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R(")'<F]U<&5S
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R(")'=6%D
M96QO=7!E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B1W5A
M;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B1W5A
M=&5M86QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,@IM<V=I
M9"`B1W5E<FYS97DB"FUS9W-T<B`B1W5E<FYE<V5Y(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R
M;6ES<VEO;G,@9&5S(&EN=FETZ7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#<R"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B3&EV<F4@9"=O
M<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G<W1R(")'=6ENZ64B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B
M1W5I;NEE+4)I<W-A=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM
M<V=S='(@(D=U>6%N82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDU
M-PIM<V=I9"`B2%1-3"(*;7-G<W1R(")(5$U,(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L
M;"!I;B!R;W<N(@IM<V=S='(@(DA434Q!<F5A(')E9G5S92!BZG1E;65N="!D
M92!S=7!P<FEM97(@;&$@9&5R;FGH<F4@8V5L;'5L92!D92!L82!R86YGZ64B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!
M<F5A(')E9G5S92!BZG1E;65N="!D92!S=7!P<FEM97(@;&$@9&5R;FGH<F4@
M8V]L;VYN92!D=2!T86)L96%U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE
M+B(*;7-G<W1R(")(5$U,07)E82!R969U<V4@8NIT96UE;G0@9&4@<W5P<')I
M;65R(&QA(&1E<FYIZ')E(')A;F?I92!D=2!T86)L96%U(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@075T:&5N
M=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H96YT:69I8V%T:6]N
M($A45%`@;F]N('1R;W5VZ64N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(86ET
M:2(*;7-G<W1R(")(8>]T:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B06QG
M;W)I=&AM92!D92!H86-H86=E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B0G)U;64@
M<^AC:&4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,38@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,CDQ,0IM<V=I9"`B2&5A9&5R(@IM<V=S='(@
M(D5N+73J=&4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S
M970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@(D5N+73J=&5S(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD
M($ES;&%N9',B"FUS9W-T<B`BSFQE<R!(96%R9"!E="!-8T1O;F%L9"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED
M(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(D]R86=E<R!V:6]L96YT<R(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(")(96)R97<@*$E33RTX
M.#4Y+3@M22DB"FUS9W-T<B`B2.EB<F5U("A)4T\M.#@U.2TX+4DI(@H*(SH@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S
M='(@(DAA=71E=7(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP
M:'`Z,3@T(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@
M<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD
M97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T<B`B06ED92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE
M;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(D%I9&4@<&]U<B!L)^ED:71E=7(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8X"FUS9VED(")(96QP
M97(B"FUS9W-T<B`B06ED92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM
M<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R(")(Z6UI<W!HZ')E(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T
M:&4@9FEL93HB"FUS9W-T<B`B5F]I8VD@;&4@9.EB=70@9'4@9FEC:&EE<J`Z
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*
M;7-G:60@(DAI9V@B"FUS9W-T<B`B2&%U=&4B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N
M:6YC.C4*;7-G:60@(DAO7VUE(@IM<V=S='(@(D%?8V-U96EL(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB
M"FUS9W-T<B`B0VETZ2!D=2!6871I8V%N(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-30X"FUS9VED(")(;VUE(@IM<V=S='(@(D%C8W5E:6PB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*
M;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")!9')E<W-E('!E<G-O;FYE
M;&QE(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"FUS9VED(")(;VUE
M($1I<F5C=&]R>2(*;7-G<W1R(")2Z7!E<G1O:7)E('!E<G-O;FYE;"(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G
M:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B5.ELZ7!H;VYE('!E<G-O;FYE;"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B2&]N9'5R
M87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R(")(
M;VYG($MO;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C<*;7-G
M:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HT-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G
M92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8J`Z(&1O;F[I97,@6$U,("5S(&EN
M=F%L:61E<R!R971R;W5VZ65S(&1A;G,@;&4@;65S<V%G92`E<R(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B
M:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8J`Z(&%U8W5N(&UE<W-A9V4@
M;F4@8V]R<F5S<&]N9"!A=2!S=6IE="`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z-#0U"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S
M(@IM<V=S='(@(DAO<F1E+TMO;&%BH#H@<&%S(&0G;V)J970@9&4@='EP92`E
M<R!T<F]U=ND@9&%N<R!L92!M97-S86=E("5S(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,C4Q"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T
M<B`B2&]R9&4O2V]L86*@.B`E<R!S=7!P<FEMZ2"KH"5SH+L@879E8R!S=6-C
MZ',B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B
M2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@
M=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B(@HB2&]R9&4O
M2V]L86*@.B!L92!M;W1E=7(@9"=I;G3I9W)A=&EO;B!NZ6-E<W-I=&4@;"=E
M>'1E;G-I;VX@)V1O;7AM;"<@9&4@4$A0(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HU,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@
M)7,B"FUS9W-T<B`B2&]R9&4O2V]L86*@.B!I;7!O<W-I8FQE(&1E(&-RZ65R
M('5N(&YO=79E;"!A<F)R92!834P@<&]U<B!L)V]B:F5T("5S(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0X"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@
M)7,B"FUS9W-T<B`B2&]R9&4O2V]L86*@.B!I;7!O<W-I8FQE(&0G96YL979E
M<B`E<R"KH"5SH+N@.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z-#@S"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E
M<R(*;7-G<W1R("(B"B)(;W)D92]+;VQA8J`Z(&EM<&]S<VEB;&4@9&4@<NEC
M=7#I<F5R(&PG:61E;G1I9FEA;G0@34E-12!P;W5R(&QA('!A<G1I92!D92`B
M"B)T>7!E("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DW
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA
M8J`Z(&EM<&]S<VEB;&4@9&4@<WEN8VAR;VYI<V5R("5S(*N@)7.@NZ`Z("5S
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,W"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI
M<V4@<VAA<F5S.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8J`Z(&EM<&]S<VEB
M;&4@9&4@<WEN8VAR;VYI<V5R(&QE<R!P87)T86=E<Z`Z("5S(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@
M(DAO<F1E+TMO;&%BH#H@<&%R=&%G92!I;F-O;FYU(*N@)7.@NR(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@
M(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R("),:6=N92!H;W)I>F]N=&%L92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*
M;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R(")296UP;&ES<V%G
M92!H;W)I>F]N=&%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B2&]R
M:7IO;G1A;*`Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R
M93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R(")#;VUM96YT(.IT97,M=F]U
M<R!A<G)I=ND@:6-IH#\@*%-64"!R87!P;W)T97HM;&6@(2DB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS
M9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E
M/R(*;7-G<W1R(")#;VUB:65N(&1E(&-O;&]N;F5S('9O=6QE>BUV;W5S(&9U
M<VEO;FYE<J`_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*
M;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*
M;7-G<W1R(")#;VUB:65N(&1E(&-H86UP<R`H8V]L;VYN97,I('D@82UT+6EL
MH#\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME
M('1O(&UE<F=E/R(*;7-G<W1R(")#;VUB:65N(&1E(')A;F?I97,@=F]U;&5Z
M+79O=7,@9G5S:6]N;F5RH#\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C@Y(&QI8B]";&]C:R]M971A<BYP:'`Z,C,W"FUS9VED(")(=6UI
M9&ET>2(*;7-G<W1R(")(=6UI9&ETZ2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-#@*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B2'5M
M:61I=.F@.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@
M(DAU;6]R:7-T<R(*;7-G<W1R(")(=6UO<FES=&5S(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P
M"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(DAO;F=R:64B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA
M:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("+)8VAE8R!L;W)S
M(&1E(&QA(&-RZ6%T:6]N(&1E(&QA(&)O[G1E($E-05"@.B`E<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-
M05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(LEC:&5C
M(&QO<G,@9&4@;&$@<W5P<')E<W-I;VX@9&4@;&$@8F_N=&4@24U!4*`Z("5S
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B
M"FUS9W-T<B`BR6-H96,@;&]R<R!D92!L82!C<NEA=&EO;B!D=2!Q=6]T82!S
M=7(@;&$@8F_N=&4@24U!4*`Z("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,Q,PIM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R(")!9')E<W-E
M($E0(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM
M<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")!9')E
M<W-E($E0(&YO;B!D:7-P;VYI8FQE+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI
M;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(D%D<F5S<V4@25`@:&]R
M<R!D=2!B;&]C($-)1%(@86QL;W7I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O
M=VX@=FEO;&%T:6]N+B(*;7-G<W1R(")6:6]L871I;VX@9&4@8FQO8V%G92!)
M4"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R
M("))7VYSZ7)E<B!R86YGZ64@879A;G0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@
M(DEC96QA;F0B"FUS9W-T<B`B27-L86YD92(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.#`*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B26/T;F5S
M('-E=6QE;65N="(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B26/T;F5S
M('!O=7(@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Q"FUS9VED
M("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B26/T;F5S('!L=7,@=&5X=&4B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DS"FUS9VED("))9&5N=&ET
M>2=S(&YA;64Z(@IM<V=S='(@(DYO;2!D=2!C;VUP=&6@.B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y.`HC+"!P:'`M9F]R;6%T
M"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@
M=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(B(*(E-I(&PG
M869F:6-H86=E(&XG97-T('!A<R!C;W)R96-T+"`E<R!P;W5R(&PG;W5V<FER
M(&1A;G,@=6YE(&YO=79E;&QE(&9E;NIT<F4N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0U.0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@
M:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T
M;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E
M;F-Y+B(*;7-G<W1R("(B"B)3:2!V;W5S(&YE('9O>65Z(&%U8W5N(&EC]&YE
M(&5N('5T:6QI<V%N="!);G1E<FYE="!%>'!L;W)E<BP@=F]U<R!P;W5V97H@
M(@HB879O:7(@X"!C;V-H97(@8V5T=&4@8V%S92!P;W5R(&3I<V%C=&EV97(@
M;&$@=')A;G-P87)E;F-E(&1E<R!03D<N(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,@IM<V=I9"`B(@HB268@>6]U('-E
M92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A
M;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R
M;W=S97(N(@IM<V=S='(@(B(*(E-I('9O=7,@=F]Y97H@8V4@;65S<V%G92!M
M86ES(&%U8W5N92!I;6%G92P@;"=I;6%G92!Q=64@=F]U<R!V;W5L97H@96YV
M;WEE<B`B"B)N92!P975T(.IT<F4@869F:6-HZ64@<&%R('9O=')E(&YA=FEG
M871E=7(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G
M<W1R(")!<&5RYW4@9&4@;"=I;6%G9:`Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@
M55),(@IM<V=S='(@(D%D<F5S<V4@55),(&1E(&PG:6UA9V4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B061R97-S92!54DP@9&4@
M;"=I;6%G9:`Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE
M<GDB"FUS9W-T<B`B26UA9V4@9&4@;"=A;&)U;2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I
M9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R("));6%G92!D92!L)V%L
M8G5MH#HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S4X"FUS9VED
M("));6%G92!U<&QO860B"FUS9W-T<B`B5.ELZ6-H87)G96UE;G0@9"=I;6%G
M97,B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S
M(@IM<V=S='(@(DEM86=E<R(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N
M:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM
M<V=S='(@(DEM<&]R=&%T:6]N+"#I=&%P92`E9"(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R
M=&5D(&9I96QD.B`E<R(*;7-G<W1R(")#:&%M<"!I;7!O<G3IH#H@)7,B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E
M9"!F:65L9',Z(@IM<V=S='(@(D-H86UP<R!I;7!O<G3I<Z`Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P
M"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R("));E]SZ7)E<B!R
M86YGZ64@87!RZ',B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M>FEP+G!H<#HQ,S0*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E
M;BXB"FUS9W-T<B`B0V]D92!D)V%C=&EO;B!I;F-O<G)E8W0N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*;7-G
M:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S
M='(@(DYO;2!D)W5T:6QI<V%T975R(&5T+V]U('9O=')E(&UO="!D92!P87-S
M92!I;F-O<G)E8W0N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@
M861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES
M=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB
M3F]M(&0G=71I;&ES871E=7(@;W4@861R97-S92!A;'1E<FYA=&EV92!I;F-O
M<G)E8W0N("!2Z65S<V%Y97H@;W4@8V]N=&%C=&5Z("(*(G9O=')E(&%D;6EN
M:7-T<F%T975R('-Y<W3H;64@<&]U<B!D92!L)V%I9&4N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC
M<F5A<V4@26YD96YT(@IM<V=S='(@(D%U9VUE;G1E<B!L)VEN9&5N=&%T:6]N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,38@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@Q"FUS9VED("));F1I82(*;7-G<W1R("));F1E(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B
M"FUS9W-T<B`B571I;&ES871E=7)S(&EN9&EV:61U96QS(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B26YD;V[I<VEE(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I
M9"`B26YF;R(*;7-G<W1R("));F9O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(U.0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M
M871I;VYS(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q.0IM
M<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T
M<B`B3"=I;F9O<FUA=&EO;B!N)V5S="!P;'5S(&1I<W!O;FEB;&4N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R("));G/I
M<F5R(&-?;VQO;FYE(&%P<NAS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E<G0@
M26UA9V4B"FUS9W-T<B`B26YSZ7)E<B!I;6%G92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!4
M86)L92(*;7-G<W1R("));G/I<F5R('5N('1A8FQE874B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("));G-E
M<G0@5V5B($QI;FLB"FUS9W-T<B`B26YSZ7)E<B!U;B!L:65N('=E8B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(DEN
M<^ER97(@7V-O;&]N;F4@879A;G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A
M(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN
M<^ER97(@=6YE(&YO=79E;&QE(&-O;&]N;F4@87!RZ',@;&$@8V]L;VYN92!A
M8W1U96QL92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B
M969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN<^ER97(@=6YE(&YO
M=79E;&QE(&-O;&]N;F4@879A;G0@;&$@8V]L;VYN92!A8W1U96QL92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N
M="!O;F4B"FUS9W-T<B`B26YSZ7)E<B!U;F4@;F]U=F5L;&4@<F%N9^EE(&%P
M<NAS(&QA(')A;F?I92!A8W1U96QL92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T
M(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN
M<^ER97(@=6YE(&YO=79E;&QE(')A;F?I92!A=F%N="!L82!R86YGZ64@86-T
M=65L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E
M<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(DEN<^ER97(@=6X@<&%R86=R
M87!H92!A<'+H<R!L92!N)F]E;&EG.W5D(&%C='5E;"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I
M9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E
M(@IM<V=S='(@(DEN<^ER97(@=6X@<&%R86=R87!H92!A=F%N="!L92!N)F]E
M;&EG.W5D(&%C='5E;"(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS
M9VED("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(DEN<^ER
M97(@=6X@875T<F4@;6]DZ&QE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(T,@IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@
M>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*
M(DEN<V-R:79E>B!U;F4@861R97-S92!D92!C;W5R<FEE<B#@(&QA<75E;&QE
M('9O=7,@<F5C979R97H@;&4@;F]U=F5A=2!M;W0@9&4@(@HB<&%S<V6@.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(DEN<^ER
M97(@8V5L;'5L92!A<'+H<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL(&)E
M9F]R92(*;7-G<W1R("));G/I<F5R(&-E;&QU;&4@879A;G0B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS
M9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(DEN<^ER97(@8V]L
M;VYN92!A<'+H<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E
M(@IM<V=S='(@(DEN<^ER97(@8V]L;VYN92!A=F%N="(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4P"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("));G-E<G0@;65S
M<V%G97,B"FUS9W-T<B`B26YSZ7)E<B!L97,@;65S<V%G97,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*
M;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B26YSZ7)E
M<B!P87)A9W)A<&AE(&%P<NAS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R
M86=R87!H(&)E9F]R92(*;7-G<W1R("));G/I<F5R('!A<F%G<F%P:&4@879A
M;G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(DEN
M<^ER97(@<F%N9^EE(&%P<NAS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B
M969O<F4B"FUS9W-T<B`B26YSZ7)E<B!R86YGZ64@879A;G0B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C,S"FUS9VED("));G-E<G0@=&AE(')E<75I
M<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@
M(DEN<V-R:79E>B!L82!RZ7!O;G-E(.`@;&$@<75E<W1I;VX@9&4@<^EC=7)I
M=.F@.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B26YS
MZ7)E<B]-;V1I9FEE<B!U;F4@:6UA9V4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D:69Y
M($QI;FLB"FUS9W-T<B`B26YSZ7)E<B]-;V1I9FEE<B!U;B!L:65N('=E8B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE
M(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")#<NED:70@:6YS=69F:7-A
M;G0@<&]U<B!E;G9O>65R(.`@;&$@;&ES=&4@9&4@9&ES=')I8G5T:6]N+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R(")#<NED
M:70@:6YS=69F:7-A;G0N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3`W,@IM<V=I9"`B26YT96=E<B(*;7-G<W1R(")%;G1I97(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,P"FUS9VED("));G1E9V5R(&QI<W0B
M"FUS9W-T<B`B3&ES=&4@8V]M<&SH=&4B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@
M541(+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(E5$2"`H57-E<B!$
M871A($AE861E<BD@:6YV86QI9&4B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O>FEP+G!H<#HQ-C<*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+WII<"YP:'`Z,3DT"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]Z:7`N<&AP.C(Q,@IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G
M<W1R(")$;VYNZ64@6DE0(&EN=F%L:61E+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM<V=S
M='(@(D%P<&QI8V%T:6]N(&EN=F%L:61E+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI
M9"!B871C:"!)1"XB"FUS9W-T<B`B1W)O=7!E($E$(&EN=F%L:61E+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#0@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$U-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R.38*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D
M871A('-U8FUI='1E9"XB"FUS9W-T<B`B16YV;VD@9&4@9&]N;NEE<R!I;G9A
M;&ED97,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E
M<W,N(@IM<V=S='(@(D%D<F5S<V4@9&4@9&5S=&EN871I;VX@:6YV86QI9&4N
M(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3`Y
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$S.0HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR-#$*;7-G
M:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B1F]R;6%T(&1E(&9I
M8VAI97(@:6YV86QI9&4N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$V-0IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B
M0VQE9B!D92!L:6-E;F-E(&EN=F%L:61E+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O
M=FED960N(@IM<V=S='(@(D5M<&QA8V5M96YT(&EN9&EQ=>D@:6YV86QI9&4N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R("*K;7-G
M7W1Y<&6[(&EN=F%L:61E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S
M:6YG(&%P:5]I9"XB"FUS9W-T<B`BJV%P:5]I9+L@:6YV86QI9&4@;W4@;6%N
M<75A;G0N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE
M=&5R<RXB"FUS9W-T<B`B4&%R86WH=')E<R!I;G9A;&ED97,@;W4@;6%N<75A
M;G1S+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B
M26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B4&5R;6ES<VEO
M;B!I;G9A;&ED92XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,38Q"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(DED+B!D
M92!P87)T96YA:7)E(&EN=F%L:61E+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-C,*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*
M;7-G<W1R(")#;V1E(&1E('!R;V1U:70@:6YV86QI9&4N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED
M("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R(")0<F]T;V-O;&4@:6YV86QI
M9&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*
M;7-G<W1R(")$97-T:6YA=&%I<F4@:6YV86QI9&6@.B"KH"5SH+LB"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P.#`@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,C8S"FUS9VED("));G9A;&ED('-H87)E(&]B:F5C="(*
M;7-G<W1R(")/8FIE="!D92!P87)T86=E(&EN=F%L:61E(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED
M("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R(")!9')E<W-E('-O
M=7)C92!I;G9A;&ED92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D
M871A+B(*;7-G<W1R(")$;VYNZ64@56YI8V]D92!I;G9A;&ED92XB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4Y"FUS9VED("));G9E;G1O<GDB
M"FUS9W-T<B`B26YV96YT86ER92(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HV-S@*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB
M"FUS9W-T<B`B26YV97)S97(@;&$@<^EL96-T:6]N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R
M"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(DER
M86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T<B`B27)A:R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R("))<FQA;F1E
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES
M;&4@;V8@36%N(@IM<V=S='(@(LYL92!D92!-86XB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@
M5"U3=&]R;7,B"FUS9W-T<B`B5&5M<.IT97,@:7-O;.EE<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,`IM<V=I9"`B27-R865L(@IM<V=S='(@(DES<F'K;"(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(V"FUS9VED("))<W-U97(B
M"FUS9W-T<B`BR6UE='1E=7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R("))=&%L
M:7%U92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B271A;'DB"FUS9W-T<B`B271A
M;&EE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM<V=S='(@(DIA
M;6'O<75E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B2F%N=FEE<B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`B2F%P;VXB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R
M+4I0*2(*;7-G<W1R(")*87!O;F%I<R`H25-/+3(P,C(M2E`I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G
M<W1R(")*97)S97DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G
M<W1R(")*;W)D86YI92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(DIU:6QL970B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I
M9"`B2G5N92(*;7-G<W1R(")*=6EN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*
M;7-G<W1R(")*=7-T:69I97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT
M97(B"FUS9W-T<B`B0V5N=')E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U
M;&PB"FUS9W-T<B`B2G5S=&EF:65R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@
M3&5F="(*;7-G<W1R(")!;&EG;F5R(.`@9V%U8VAE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@
M(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B06QI9VYE<B#@(&1R;VET92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R(")+87IA:VAS
M=&%N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(V-0IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B1V%R9&5R(&PG
M;W)I9VEN86R@/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T
M<B`B2V5N>6$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U
M"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(DQE('-E<G9E=7(@2V5R8F5R;W,@82!R96IE=.D@;"=A
M=71H96YT:69I8V%T:6]N+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B1.EB=71A;G1S(&1U
M(&YO>6%U(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q
M"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B0W+I871I;VX@9&4@8VQE
M9B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I
M9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(D5M<')E:6YT92!D92!L82!C
M;&5F(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS
M9VED(")+97D@3&5N9W1H(@IM<V=S='(@(DQO;F=U975R(&1E(&QA(&-L968B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@
M(DME>2!4>7!E(@IM<V=S='(@(E1Y<&4@9&4@8VQE9B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DY"FUS9VED(")+97D@57-A9V4B
M"FUS9W-T<B`B571I;&ES871I;VX@9&4@;&$@8VQE9B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@
M97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("),82!C
M;&5F('-E('1R;W5V92!DZ6K@('-U<B!L92!S97)V975R(&1E(&-L969S('!U
M8FQI8RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI
M9',B"FUS9W-T<B`B16YF86YT<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER
M:6)A=&DB"FUS9W-T<B`B2VER:6)A=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@
M(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(D-O<NEE(&1U($YO<F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A
M+"!297!U8FQI8R!O9B(*;7-G<W1R(")#;W+I92!D=2!3=60B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM
M<V=S='(@(D-O<NEE;B`H155#+4M2*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B
M2W5W86ET(@IM<V=S='(@(DMO=V7O="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B
M2WER9WEZ<W1A;B(*;7-G<W1R(")+:7)G:&EZ:7-T86XB"@HC.B!T96UP;&%T
M97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO=70B"FUS9W-T<B`B
M4'+I7W-E;G1A=&EO;B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(DQA;F=U92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B
M"FUS9W-T<B`B3&%O<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-CD*;7-G
M:60@(DQA<W0@2&%L9B(*;7-G<W1R(")$97)N:>AR92!D96UI92(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HW-@IM<V=I9"`B3&%S="!087-S=V]R9"!#
M:&%N9V4B"FUS9W-T<B`B1&5R;FGH<F4@;6]D:69I8V%T:6]N(&1U(&UO="!D
M92!P87-S92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R(")$97)N
M:65R('%U87)T:65R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3@*;7-G
M:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B1&5R;FGH<F4@;6ES92#@(&IO
M=7*@.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R(")$97)N:>AR
M92!C;VYN97AI;VZ@.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M
M("5S(@IM<V=S='(@(D1E<FYIZ')E(&-O;FYE>&EO;J`Z("5S(.`@<&%R=&ER
M(&1E("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$T"FUS9VED
M("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R(")$97)N:>AR92!C;VYN97AI
M;VZ@.B!J86UA:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQA='9I82(*;7-G
M<W1R("),971T;VYI92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM
M<V=I9"`B3&%W(@IM<V=S='(@(DQO:2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T(@IM
M<V=S='(@(E!RZ7-E;G1A=&EO;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N
M;R!B;W)D97(B"FUS9W-T<B`B3&%I<W-E<B!V:61E('!O=7(@;F4@<&%S(&%V
M;VER(&1E(&)O<F1U<F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB
M"FUS9W-T<B`B3&EB86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B1V%U
M8VAE(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y.`IM<V=I9"`B
M3&5F="!H96%D97(B"FUS9W-T<B`B16YTZG1E(&=A=6-H92(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,P.30*;7-G:60@(DQE9G0@=F%L=65S(@IM
M<V=S='(@(E9A;&5U<G,@9&4@9V%U8VAE(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED
M("),97-O=&AO(@IM<V=S='(@(DQE<V]T:&\B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DQE=F5L(@IM<V=S='(@(DYI=F5A
M=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R("),:6+I
M<FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER
M:7EA(@IM<V=S='(@(DQI8GEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C
M:'1E;G-T96EN(@IM<V=S='(@(DQI96-H=&5N<W1E:6XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@
M1')I>GIL92(*;7-G<W1R(")"<G5I;F4@;.EGZ')E(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G:60@(DQI9VAT(%)A
M:6XB"FUS9W-T<B`B4&QU:64@;.EGZ')E(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R
M;'DB"FUS9W-T<B`B4&QU:64@;.EGZ')E('3T="!D86YS(&QA(&IO=7)NZ64B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM
M<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(E!L=6EE(&SI9^AR92!T
M87)D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(D%V97)S97,@
M;.EGZ')E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R
M(")0;'5I92!LZ6?H<F4@879E8R!T;VYN97)R92(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W
M(@IM<V=S='(@(DYE:6=E(&EN=&5R;6ET=&5N=&4B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO
M=R!3:&]W97(B"FUS9W-T<B`B079E<G-E(&1E(&YE:6=E(&SI9^AR92(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS
M9W-T<B`B4FEM97,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$Q
M"FUS9VED("),:6YK(@IM<V=S='(@(DQI96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI
M;FL@<&]I;G1S('1O.B(*;7-G<W1R("),92!L:65N('!O:6YT92!V97)SH#HB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<R"FUS9VED("),:6YK
M('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D
M:7-P;&%Y:6YG(@IM<V=S='(@(B(*(DQI92!L)V%D<F5S<V4@9&4@8V]U<G)I
M96P@X"!L82!P86=E(&1E(&-O;7!O<VET:6]N(&1U(&UE<W-A9V4@96X@;"=A
M9F9I8VAA;G0B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT
M;6PR=&5X="YP:'`Z,3@R"FUS9VED("),:6YK<R(*;7-G<W1R("),:65N<R(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O
M:VEE(@IM<V=S='(@(D)I<V-U:70@3&EN=7@B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT-@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N
M('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(DQI<W1E("T@=71I;&ES871E=7(@
M<&5U="!V;VER(&QE(&1O<W-I97(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3,T"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R("),:7-T92!D97,@
M8F%S97,@9&4@9&]N;NEE<R(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP
M.C4Q"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(DEN9&5X(&1E
M(&PG86ED92(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI
M<W0@5&%B;&5S(@IM<V=S='(@(D%F9FEC:&5R(&QE<R!T86)L97,B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES
M="U!<F-H:79E(@IM<V=S='(@(D%R8VAI=F5S(&1E(&QA(&QI<W1E(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.#D*;7-G:60@(DQI
M<W0M2&5L<"(*;7-G<W1R(")!:61E(&1E(&QA(&QI<W1E(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.38*;7-G:60@(DQI<W0M260B
M"FUS9W-T<B`B260N(&1E(&QA(&QI<W1E(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12](96%D97)S+G!H<#HU.3(*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T
M<B`B4')O<')IZ71A:7)E(&1E(&QA(&QI<W1E(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12](96%D97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*;7-G
M<W1R(")%;G9O:2#@(&QA(&QI<W1E(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S
M='(@(D%B;VYN96UE;G0@X"!L82!L:7-T92(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E
M(@IM<V=S='(@(D3I<V%B;VYN96UE;G0@9&4@;&$@;&ES=&4B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN
M9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(LEC:&5C(&1E(&QA(&QI
M<W1E(&1E<R!S97-S:6]N<Z`Z("5S(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C,W"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D
M.B`E<R(*;7-G<W1R("+)8VAE8R!D92!L82!L:7-T92!D97,@=71I;&ES871E
M=7)SH#H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC
M.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@
M(DPG869F:6-H86=E(&1E(&QA(&QI<W1E(&1E<R!U=&EL:7-A=&5U<G,@97-T
M(&3I<V%C=&EVZ2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G
M:60@(DQI=&5R871U<F4B"FUS9W-T<B`B3&ET=.ER871U<F4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("),:71U86YI92(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z-S<*;7-G
M:60@(DQO861I;F<N+BXB"FUS9W-T<B`B0VAA<F=E;65N="XN+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#`*;7-G:60@(DQO8V%L('1I
M;64Z("(*;7-G<W1R(")(975R92!L;V-A;&6@.B`B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#8*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R
M(")(975R92!E="!L;V-A;&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4W,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-3<*
M(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP
M:'`Z-S(*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(DQI974B"@HC.B!L;V=I
M;BYP:'`Z,3@Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,#`@=&5M
M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO
M;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS
M9VED("),;V<@:6XB"FUS9W-T<B`B0V]N;F5X:6]N(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@;V8@<')E=FEO=7,@
M<WEN8R!S97-S:6]N(@IM<V=S='(@(E1R86-E(&1E(&QA(&1E<FYIZ')E('-E
M<W-I;VX@9&4@<WEN8VAR;VYI<V%T:6]N(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$Y-`IM<V=I9"`B3&]G(&]U="(*;7-G<W1R(")$Z6-O
M;FYE>&EO;B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU.0IM<V=I9"`B
M3&]G:6XB"FUS9W-T<B`B0V]N;F5X:6]N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q,`IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B5.)C:&5S
M(&1E(&-O;FYE>&EO;B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY
M-0IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O
M<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B
M(@HB3&$@8V]N;F5X:6]N(&5S="!R969U<^EE+B!);"!E<W0@<')O8F%B;&4@
M<75E('9O=')E(&YO;2!D)W5T:6QI<V%T975R(&]U("(*(G9O=')E(&UO="!D
M92!P87-S92!A(.ETZ2!M86P@<V%I<VDB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.3$*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`BR6-H
M96,@9&4@8V]N;F5X:6]N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$S-C(*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R(")497AT92!L;VYG(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S
M='(@(D%M;W5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-CD*;7-G:60@(DQO=R(*;7-G<W1R(")&86EB;&4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q
M"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(DQE='1R92!G
M<F5C<75E<R!M:6YU<V-U;&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T
M:6X@;&5T=&5R<R(*;7-G<W1R("),971T<F4@;&%T:6YE<R!M:6YU<V-U;&5S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R
M(").;VUB<F4@<F]M86EN<R!M:6YU<V-U;&5S(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS
M9VED("),=7AE;6)O=7)G(@IM<V=S='(@(DQU>&5M8F]U<F<B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,SD@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(DU-(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,PIM<V=I9"`B34]41"(*;7-G<W1R
M(")-97-S86=E(&1U(&IO=7(@*$U/5$0I(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T86-H
M;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B3&$@<&GH8V4@:F]I
M;G1E($U3+51.148@;F4@8V]N=&5N86ET(&%U8W5N92!D;VYNZ64N(@H*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(DU31R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T<B`B36%C86\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!2
M97!U8FQI8R!O9B(*;7-G<W1R(")2Z7!U8FQI<75E(&1E($UA8^ED;VEN92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R(")-861A
M9V%S8V%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"FUS9VED(")-
M86=I8R(*;7-G<W1R(")-86=I92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HX,PIM<V=I9"`B36%I;"(*;7-G<W1R(")#;W5R<FEE<B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C0*;7-G:60@(DUA:6P@061M:6XB
M"FUS9W-T<B`B061M:6YI<W1R871I;VX@9'4@8V]U<G)I96PB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*
M;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B1F%I<F4@=6X@;&EE7VXB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&%W:2(*;7-G<W1R(")-86QA=VDB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(DUA;&%I
M<VEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*;7-G<W1R(")-
M86QD:79E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%L:2(*;7-G<W1R(")-
M86QI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QT82(*;7-G<W1R(")-86QT
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-`IM<V=I9"`B(@HB36%N
M86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@
M:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO
M<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@HB061M:6YI<W1R97H@;&$@;&ES
M=&4@9&4@8V%TZ6=O<FEE<R!E="!L97,@8V]U;&5U<G,@;&GI97,@X"!C97,@
M8V%TZ6=O<FEE<RXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3$U-@IM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(D-A<G1E
M(*L@36%P,C0@NR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#@W"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,3<Q"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B0V%R
M=&4@JR!-87!Q=65S=""[(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S='(@(D-O<G)E
M<W!O;F1A;F-E<R!E;G)E9VES='+I97,N(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@
M(DUA<G,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0Q"FUS9VED(")-87)G:6XB"FUS9W-T<B`B36%R9V4B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT.`HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B
M36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@(DUA<G%U97(@
M879E8R!D97,@Z71I<75E='1E<R!6=2].;VX@=G4B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT.0HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T
M:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B
M36%R<75E<B!A=F5C(&0G875T<F5S(.ET:7%U971T97,@*&5X+CH@26UP;W)T
M86YT+U+I<&]N9'4I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)
M<VQA;F1S(@IM<V=S='(@(LYL97,@36%R<VAA;&PB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*
M;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R=&EN:7%U92(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F
M:65L9',B"FUS9W-T<B`B0VAA;7!S(&%P<&%R96YTZ7,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B36%U<FET86YI92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(LYL92!-875R
M:6-E(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@
M(D-RZ61I="!M87AI;75M(&%L;&]UZ2XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S
M86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R("),:6UI=&4@9'4@;65S<V%G
M92!DZ7!A<W/I92XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,PIM<V=I
M9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(E1E;7#I<F%T
M=7)E(&UA>&EM86QE(&1E<R`R-"!D97)N:>AR97,@:&5U<F5SH#H@(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#4*;7-G:60@(DUA>"!T96UP(&QA<W0@
M-B!H;W5R<SH@(@IM<V=S='(@(E1E;7#I<F%T=7)E(&UA>&EM86QE(&1E<R`V
M(&1E<FYIZ')E<R!H975R97.@.B`B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I
M9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R(").
M;VUB<F4@;6%X:6UU;2!D92!B;&]C<R!D=2!P;W)T86EL(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.#DU(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R,30*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-@IM<V=I9"`B
M36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B3&]N9W5E=7(@;6%X:6UU;2(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED
M(")-87DB"FUS9W-T<B`B36%I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y
M;W1T92(*;7-G<W1R(")-87EO='1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R(")-Z61I8V%M96YT(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B
M365M8F5R<R(*;7-G<W1R(")-96UB<F5S(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,X,@IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R(")4>7!E(&1E
M(&UE;G6@.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(D9U
M<VEO;FYE<B!L97,@8V5L;'5L97,B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*
M;7-G<W1R(")-97-S86=E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S
M<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T
M(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B)6Z7)I9FEC871I;VX@9'4@
M;65S<V%G92!RZ75S<VEE+"!M86ES(&QE(&-E<G1I9FEC870@9'4@<VEG;F%T
M86ER92!N)V$@<&%S('!U("(*(NIT<F4@=NER:69IZ2XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@
M(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`B365S<V%G92!E>'!I<NDN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,#(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(V,`IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(E1Y
M<&4@9&4@;65S<V%G92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I
M9"`B365T87(@5V5A=&AE<B(*;7-G<W1R(")-Z73I;R!-971A<B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(DQE(&)L;V,@JR!-971A<B"[(&XG97-T('!A
M<R!D:7-P;VYI8FQE+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS
M9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA
M=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("(B"B),92!B;&]C(*L@365T87(@NR!N)V5S="!P87,@9&ES<&]N:6)L92X@
M($QE<R!DZ71A:6QS(&]N="#I=.D@8V]N<VEG;NES('!O=7(@(@HB;"=A9&UI
M;FES=')A=&5U<BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,34S"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@
M(DUE=&%R1$(@;B=E<W0@<&%S(&-O;FYE8W3I+B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@(DWI
M=&AO9&4B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q(&9R
M86UE=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(DQA
M(&WI=&AO9&4@JZ`E<Z"[(&XG97-T('!A<R!DZ69I;FEE(@H*(SH@9G)A;65W
M;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<R(*;7-G<W1R
M(")-Z71H;V1E(&YO;B!DZ69I;FEE+B!-Z71H;V1E(&%P<&5LZ66@.B`E<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-R!L:6(O0FQO8VLO
M;65T87(N<&AP.C@R"FUS9VED(")-971R:6,B"FUS9W-T<B`B3>ET<FEQ=64B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R(")-97AI<75E
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3
M=&%T97,@;V8B"FUS9W-T<B`BR71A=',@9NEDZ7+I<R!D92!-:6-R;V[I<VEE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<V"FUS9VED(")-:61D;&4B"FUS9W-T<B`B36EL:65U(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI
M;64@5'EP92(*;7-G<W1R(")4>7!E($U)344B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,Q-PIM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM
M<V=S='(@(E1E;7#I<F%T=7)E(&UI;FEM=6T@9&5S(#(T(&1E<FYIZ')E<R!H
M975R97.@.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P.0IM<V=I9"`B
M36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B5&5M<.ER871U<F4@
M;6EN:6UU;2!D97,@-B!D97)N:>AR97,@:&5U<F5SH#H@(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S
M<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B3&$@9'5R
MZ64@;6EN:6UA;&4@9'4@;6]T(&1E('!A<W-E(&XG82!P87,@96YC;W)E(&5X
M<&ERZ2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,S4*;7-G:60@(DUI<G)O<B(*;7-G<W1R(")-:7)O:7(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS
M9W-T<B`B5F%R:>ES(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G
M92!(5%107U)E<75E<W0N(@IM<V=S='(@(DQE('!A<75E=&%G92!(5%107W)E
M<75E<W0@4$5!4B!E<W0@;6%N<75A;G0N(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$Q-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9
M;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E
M('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*(D-O;F9I9W5R871I
M;VX@:6YE>&ES=&%N=&4N(%9O=7,@9&5V97H@;&$@9^ENZ7)E<B!M86EN=&5N
M86YT('-I('9O=7,@=F]U;&5Z("(*(G5T:6QI<V5R(&-E='1E(&%P<&QI8V%T
M:6]N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R
M("))1"!D=2!M97-S86=E(&UA;G%U86YT+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S
M:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R("),92!P
M87%U971A9V4@4$5!4B!-86EL(&5S="!M86YQ=6%N="XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@
M(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B240@9&4@<V5S<VEO;B!M
M86YQ=6%N="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R("),=2(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HW-@IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T
M<B`B0V]U<G)I96P@<V%N<R!F:6PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B
M36]DZ7+I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*;7-G:60@
M(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B1&%T92!D92!M;V1I9FEC871I;VXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B36]D:69I97(@
M;"=54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W
M-`IM<V=I9"`B36]D=6QU<R(*;7-G<W1R(")-;V1U;&\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUO;&1A
M=FEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B36]N
M86-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R(")-
M;VYG;VQI92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.#$*;7-G
M:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(DUO:7,@970@86YNZ64B"@HC
M.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS
M9VED(")-;VYT:&QY(@IM<V=S='(@(DUE;G-U96QL96UE;G0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B36]N='-E<G)A="(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ
M-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B4&AA<V5S(&1E(&QA(&QU
M;F4B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ.38@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C@P"B,L('!H<"UF;W)M870*;7-G:60@
M(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T
M960@)60N(@IM<V=S='(@(D-H86UP<R!S=7!P;.EM96YT86ER97,@=')O=7;I
M<R#@(&QA(&QI9VYE("5D("AA='1E;F1U<R`E9"DN(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP
M"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(DUA<F]C(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#
M;&5A<B(*;7-G<W1R(")'Z6[I<F%L96UE;G0@96YS;VQE:6QLZ2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-
M;W-T;'D@0VQO=61Y(@IM<V=S='(@(D?I;NER86QE;65N="!N=6%G975X(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G
M:60@(DUO<W1L>2!#;&]U9'D@86YD(%=I;F1Y(@IM<V=S='(@(E!R:6YC:7!A
M;&5M96YT(&YU86=E=7@@970@=F5N=&5U>"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")-;W-T;'D@4W5N;GDB
M"FUS9W-T<B`B1^ENZ7)A;&5M96YT(&5N<V]L96EL;.DB"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T.`IM<V=I9"`B
M36]V92!$;W=N(@IM<V=S='(@(E9E<G,@;&4@8F%S(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-3(*;7-G:60@(DUO
M=F4@3&5F="(*;7-G<W1R(")$Z7!L86-E<B#@(&=A=6-H92(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4V"FUS9VED
M(")-;W9E(%)I9VAT(@IM<V=S='(@(D3I<&QA8V5R(.`@9')O:71E(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#0*
M;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B5F5R<R!L92!H875T(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM<V=I9"`B
M36]V92!D;W=N(@IM<V=S='(@(E9E<G,@;&4@8F%S(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V"FUS9VED(")-;W9E('5P
M(@IM<V=S='(@(E9E<G,@;&4@:&%U="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B
M36]Z86UB:7%U92(*;7-G<W1R(")-;WIA;6)I<75E(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$X,0IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D
M;W=N(&QI<W1S(@IM<V=S='(@(DQI<W1E<R!DZ7)O=6QA;G1E<R!M=6QT:2UN
M:79E875X(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P-3D*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R(")#87)T
M92"KH$UU;'1I;6%P(%5+H+LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,C,Y"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B4^EL
M96-T:6]N(&UU;'1I<&QE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0P,@IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R(")087)A;>ET<F%G92!D
M=2!C;VUP=&4B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*;7-G:60@
M(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B365S(&1O;F[I97,@
M<&5R<V]N;F5L;&5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HT
M-0IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(DUO;B!P;W)T86EL(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C0S"FUS9VED(")->2!0;W)T86P@
M3&%Y;W5T(@IM<V=S='(@(E!RZ7-E;G1A=&EO;B!D92!M;VX@<&]R=&%I;"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R(")":7)M86YI
M92(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL
M.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B3D].+"!J
M92!N)V%C8V5P=&4@<&%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z
M,S@*;7-G:60@(DYA;64B"FUS9W-T<B`B3F]M(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS
M9VED(").86UI8FEA(@IM<V=S='(@(DYA;6EB:64B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*
M;7-G:60@(DYA=7)U(@IM<V=S='(@(DYA=7)U(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS
M9VED(").97!A;"(*;7-G<W1R(").Z7!A;"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I
M9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B4&%Y<RU"87,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B06YT:6QL
M97,@;NEE<FQA;F1A:7-E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R
M(")54DP@9&4@8F%S92!D92!.971S8V%P92(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!#02!2979O
M8V%T:6]N(%523"(*;7-G<W1R(")54DP@9&4@<NEV;V-A=&EO;B!D92!L)T$N
M0RX@3F5T<V-A<&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R
M(")54DP@9&4@;&$@<&]L:71I<75E(&0G02Y#+B!.971S8V%P92(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S
M8V%P92!296YE=V%L(%523"(*;7-G<W1R(")54DP@9&4@<F5N;W5V96QL96UE
M;G0@3F5T<V-A<&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T
M<B`B55),(&1E('+I=F]C871I;VX@3F5T<V-A<&4B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@4U-,
M('-E<G9E<B!N86UE(@IM<V=S='(@(DYO;2!D=2!S97)V975R(%-33"!.971S
M8V%P92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@X
M"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@
M(D-O;6UE;G1A:7)E(&1U(&-E<G1I9FEC870@3F5T<V-A<&4B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A
M<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R(")4>7!E(&1U(&-E<G1I9FEC
M870@3F5T<V-A<&4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4S
M"FUS9VED(").971W;W)K(@IM<V=S='(@(E+I<V5A=2(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S,Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G:60@(DYE
M=F5R(@IM<V=S='(@(DIA;6%I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F5W
M($-A;&5D;VYI82(*;7-G<W1R(").;W5V96QL92U#86SI9&]N:64B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM
M<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(DYO=79E;&QE(&-A=.EG;W)I
M92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB
M"FUS9W-T<B`B3F]U=F5L;&4@;'5N92(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N
M86PI(@IM<V=S='(@(DYO=79E874@;F]M(&1E(&-O;FYE>&EO;B`H9F%C=6QT
M871I9BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S
M='(@(DYO=79E;&QE+5KI;&%N9&4B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z,S<*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R(").;W5V
M96%U(&UO="!D92!P87-S92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L
M+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I
M;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("),92!N;W5V96%U(&UO="!D92!P
M87-S92!E>'!I<F5R82!L92`E>"XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z-3(*;7-G:60@(DYE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N
M(@IM<V=S='(@(DQE<R!N;W5V96%U>"!M;W1S(&1E('!A<W-E(&1I9F;H<F5N
M="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(DYO=79E
M;&QE(&9E;NIT<F4@*%]B;&%N:RDB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H
M<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(Y,0IM<V=I9"`B3F5W<R(*;7-G<W1R(").;W5V96QL
M97,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`W"FUS9VED(").
M97=S9W)O=7!S(@IM<V=S='(@(D9O<G5M<R(*"B,Z('1E;7!L871E<R]D871A
M+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@(E-U:79A
M;G0B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0
M:&%S97,B"FUS9W-T<B`B-"!P:&%S97,@<W5I=F%N=&5S(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HS-S`*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R(")/
M<'1I;VYS('-U:79A;G1E<R(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP
M:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R(")3=6EV86YT/B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(DYI8V%R86=U82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B3FEG97(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B3FEG97)I82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-CD*;7-G:60@(DYI
M9VAT(@IM<V=S='(@(DYU:70B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYI=64B
M"FUS9W-T<B`B3FEU92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HY-C8*;7-G:60@(DYO(@IM<V=S='(@(DYO;B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A
M:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S
M(&9O<BXB"FUS9W-T<B`B(@HB4&%S(&1E(&1O;F[I97,@9&4@8V]N9FEG=7)A
M=&EO;B!P;W5R(&QE<W%U96QL97,@;6]N=')E<B!L97,@9&EF9NER96YC97,N
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ
M,#8*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E3
M3R!I;6%G97,N(@IM<V=S='(@(E!A<R!D92!S=')A=.EG:64@9&ES<&]N:6)L
M92!P;W5R(&9A:7)E(&1E<R!I;6%G97,@25-/+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@
M8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(E!A<R!D92!G86)A<FET(&5N('1R
M86ET96UE;G0@<&%R(&QO="XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C$P,0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C,X-0HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0P-PIM<V=I9"`B3F\@8FQO8VL@
M97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B075C
M=6X@8FQO8R!N)V5X:7-T92#@(&QA('!O<VET:6]N(&1E;6%N9.EE(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@8V%L
M96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B4&%S(&1E(&YO;2!D92!C86QE;F1R:65R(&9O=7)N:2!P;W5R
M(&PG875T:&5N=&EF:6-A=&EO;B!P87(@34-!3"XB"@HC.B!A9&UI;B]S971U
M<"]D:69F+G!H<#HU-`IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R(").;VX@
M;6]D:69IZ2XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U
M-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R
M;6ES<VEO;BXB"FUS9W-T<B`B075C=6YE('-O=7,M<&5R;6ES<VEO;B!N)V$@
M8F5S;VEN(&0GZG1R92!A:F]U=.EE('-O=7,@8V4@;FEV96%U+B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<X(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z-3$W"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<V.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(D%U8W5N92!I;F9O<FUA
M=&EO;B!D92!C;VYF:6=U<F%T:6]N('-PZ6-I9FGI92!P;W5R("5S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4U"FUS9VED(").;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RXB
M"FUS9W-T<B`B075C=6YE(&EN9F]R;6%T:6]N(&1E(&-O;F9I9W5R871I;VX@
M9F]U<FYI92!P;W5R($944"!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HV-S(*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R(")!=6-U;F4@:6YF
M;W)M871I;VX@9&4@8V]N9FEG=7)A=&EO;B!F;W5R;FEE('!O=7(@4U%,(%9&
M4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(U"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R(")!=6-U;F4@:6YF;W)M871I;VX@
M9&4@8V]N9FEG=7)A=&EO;B!F;W5R;FEE('!O=7(@4U%,+49I;&4@5D93+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(D%U8W5N(&-R
MZ61I="!D:7-P;VYI8FQE+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S
M=7!P;&EE9"XB"FUS9W-T<B`B075C=6YE(&1E<W1I;F%T:6]N('1R;W5VZ64N
M(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3(P"FUS9VED
M(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(D%U8W5N(&9I8VAI97(@96YV
M;WGI(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I
M8V]N<R!F;W5N9"XB"FUS9W-T<B`B075C=6X@:6/T;F4@=')O=7;I+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,38@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3,P"FUS9VED
M(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(D%U8W5N(&QI974@;B=E
M<W0@<^EL96-T:6]N;NDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,34W"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B
M075C=6X@96UP;&%C96UE;G0@;B=E<W0@:6YD:7%UZ2XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B
M3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B075C=6X@;65S<V%G92!F
M;W5R;FDB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@
M(D%U8W5N(&YO;2!S<.EC:69IZ2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P
M96-I9FEE9"XB"FUS9W-T<B`B075C=6X@;F]M8G)E('-PZ6-I9FGI+B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E
M(&9O<G1U;F5S(@IM<V=S='(@(E!A<R!D)V%P:&]R:7-M97,@8VAO<75A;G1S
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(D%U8W5N(&UO="!D92!P87-S92!F;W5R;FD@<&]U<B!L)V%U
M=&AE;G1I9FEC871I;VX@<&%R($A45%`N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")!=6-U;B!M;W0@
M9&4@<&%S<V4@9F]U<FYI('!O=7(@;"=A=71H96YT:69I8V%T:6]N('!A<B!)
M34%0+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S(*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B075C=6X@;6]T(&1E('!A<W-E(&9O=7)N:2!P
M;W5R(&PG875T:&5N=&EF:6-A=&EO;B!P87(@2V5R8F5R;W,N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO075T:"]!
M=71H+VQO9VEN+G!H<#HX-`HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP
M:'`Z-S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B075C=6X@;6]T(&1E('!A<W-E('-P
MZ6-I9FGI('!O=7(@;"=A=71H96YT:69I8V%T:6]N+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(D%U8W5N(&UO="!D92!P87-S92!S<.EC:69IZ2!P;W5R(&PG875T:&5N=&EF
M:6-A=&EO;B!005-35T0N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N
M<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")!=6-U;B!M;W0@9&4@<&%S<V4@<W#I
M8VEF:>D@<&]U<B!L)V%U=&AE;G1I9FEC871I;VX@4TU"+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-PIM<V=I9"`B(@HB3F\@
M<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N
M4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@
M,3(@9&%T82XB"FUS9W-T<B`B(@HB075C=6X@8VAE;6EN('9E<G,@;&4@8FEN
M86ER92!/<&5N4U-,(&9O=7)N:2X@3&4@8FEN86ER92!D)T]P96Y34TP@97-T
M("(*(F[I8V5S<V%I<F4@<&]U<B!F;VYC=&EO;FYE<B!A=F5C(&1E<R!D;VYN
MZ65S(%!+0U,@,3(N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R(")!
M=6-U;F4@8V]N9FER;6%T:6]N(&5N(&%T=&5N=&4B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z-S8V"FUS9VED(").;R!Q=6]T82!S970N(@IM<V=S='(@
M(E!A<R!D92!Q=6]T82!P;W-I=&EO;F[I+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G:60@(DYO(')U
M;&5S(@IM<V=S='(@(E!A<R!D92!RZ&=L97,B"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HT.#(*;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I
M960N(@IM<V=S='(@(D%U8W5N('/I<&%R871E=7(@<W#I8VEF:>DN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M-`IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B4&%S(&1E(&/T=.ES(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#<*;7-G:60@(DYO('-U8V@@
M9FEL92(*;7-G<W1R(")&:6-H:65R(&EN97AI<W1A;G0B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(V"FUS9VED(").;R!T96UP;W)A<GD@
M9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(D%U8W5N
M('+I<&5R=&]I<F4@=&5M<&]R86ER92!E<W0@9&ES<&]N:6)L92!P;W5R(&QA
M(&-A8VAE(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HR,C$*;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S
M96YT+B(*;7-G<W1R(")!=6-U;B!N;VT@9"=U=&EL:7-A=&5U<B!E="`O;W4@
M;6]T(&1E('!A<W-E(&5N=F]YZ2XB"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X
M;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N
M960B"FUS9W-T<B`B075C=6YE(&1O;F[I92!834P@=F%L:61E(&XG82#I=.D@
M<F5T;W5R;NEE(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.CDW-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HY.34*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P,3(*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R(")087,@9&4@=F%L
M975R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@
M=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E
M;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(E!A<R!D92!V97)S
M:6]N('1R;W5VZ64@9&%N<R!L82!C;VYF:6=U<F%T:6]N(&]R:6=I;F%L92X@
M4NEGZ6[I<F5Z(&QA("(*(F-O;F9I9W5R871I;VXN(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y
M;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B(@HB4&%S(&1E('9E<G-I;VX@=')O=7;I92!D86YS('9O=')E
M(&-O;F9I9W5R871I;VXN(%+I9^ENZ7)E>B!L82!C;VYF:6=U<F%T:6]N+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z
M('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*;7-G:60@
M(DYO;F4B"FUS9W-T<B`B075C=6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC
M:70I(@IM<V=S='(@(D%U8W5N("AU=&EL:7-E<B!I;7!L:6-I=&5M96YT*2(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(").;W)D:6,@*$E3
M3RTX.#4Y+3$P*2(*;7-G<W1R(").;W)D:7%U92`H25-/+3@X-3DM,3`I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R("+.
M;&4@3F]R9F]L:R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS
M9W-T<B`B2.EM:7-P:.AR92!.;W)D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(").
M;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`BSFQE<R!-87)I86YN
M97,@9'4@;F]R9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S
M='(@(DYO<G;H9V4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8T,0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(E!A<R!A<'+H<R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED
M(").;W0@0F5F;W)E(@IM<V=S='(@(E!A<R!A=F%N="(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C0Q-0IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y
M(@IM<V=S='(@(E!A<R!U;B!D;W-S:65R(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX-`HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U
M=%-T<F%T96=Y+G!H<#HY-0HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP
M:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B3F]N(&EM
M<&SI;65N=.DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*;7-G<W1R("));F%C=&EF(@H*
M(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H
M<#HQ-#4*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+G!H<#HQ-C`*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I
M;VY(86YD;&5R+G!H<#HQ-S4*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#D*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S8@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`X(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR,S0*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(U,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8Y"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR.#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,P,0HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$V(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HS,S,*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V-B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z-#(V"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU,#4@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W-`HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-3DQ(&9R86UE=V]R:R]61E,O5D93+G!H<#HV-CD*;7-G:60@(DYO
M="!S=7!P;W)T960N(@IM<V=S='(@(DYO;B!P<FES(&5N(&-O;7!T92XB"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP."!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T"B,Z(&-O;F9I9R]H;V]K<RYP
M:'`N9&ES=#HQ,#4X(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#`*;7-G
M:60@(DYO=&5S(@IM<V=S='(@(DYO=&5S(@H*(SH@<V5R=FEC97,O;V)R;W=S
M97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@
M8F%C:RXB"FUS9W-T<B`B4FEE;B#@(&YA=FEG=65R+"!R971O=7)N97H@96X@
M87)R:>AR92XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B3F]V96UB<F4B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0S"FUS9VED(").=6UB97(B
M"FUS9W-T<B`B3F]M8G)E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30R,@IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B3F]M
M8G)E(&1E(&-A<F%C=.AR97,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,S8V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C`*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30T,B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B
M"FUS9W-T<B`B3F]M8G)E(&1E(&-O;&]N;F5S(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,V-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#$X
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#`@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O
M9B!R;W=S(@IM<V=S='(@(DYO;6)R92!D92!R86YGZ65S(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@
M(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I
M8G5T:6]N(&QI<W0N(@IM<V=S='(@(DYO;6)R92!N;VX@<W#I8VEF:>D@<&]U
M<B!L82!M:7-E(.`@:F]U<B!D92!L82!L:7-T92!D92!D:7-T<FEB=71I;VXN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T
M"FUS9VED(")/2R(*;7-G<W1R(")/2R(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R
M(")/8FIE="(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS
M9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R(")#<NEA=&5U<B!D)V]B:F5T
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$P,0IM<V=I9"`B3V-T
M86PB"FUS9W-T<B`B3V-T86PB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R(")/8W1O
M8G)E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E
M;G-E(&9I;'1E<B(*;7-G<W1R(")&:6QT<F4@86YT:2UO9F9E;G-A;G0B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(X"FUS9VED(")/9F9I8V4B
M"FUS9W-T<B`B0G5R96%U(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D
M:69F97)E;G0N(@IM<V=S='(@(DPG86YC:65N(&5T(&QE(&YO=79E874@;6]T
M<R!D92!P87-S92!D;VEV96YT(.IT<F4@9&EF9NER96YT<RXB"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*;7-G:60@(D]L9"!P87-S=V]R
M9"(*;7-G<W1R(")!;F-I96X@;6]T(&1E('!A<W-E(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@
M;F]T(&-O<G)E8W0N(@IM<V=S='(@(DPG86YC:65N(&UO="!D92!P87-S92!E
M<W0@:6YC;W)R96-T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S
M='(@(D]M86XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R
M960@9F]L9&5R<RXB"FUS9W-T<B`B4V5U;"!L97,@<V5R=F5U<G,@24U!4"!S
M=7!P;W)T96YT(&QE<R!D;W-S:65R<R!P87)T86?I<RXB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U
M;F5S(@IM<V=S='(@(E-E=6QE;65N="!L97,@JZ!F;W)T=6YE<Z"[(&]F9F5N
M<V%N=&5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@T."!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38X"FUS9VED(")/;FQY(&]N92!E;6%I
M;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(E5N92!S975L92!A9')E<W-E
M(&1E(&-O=7)R:65L('!E<FUI<V4N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D
M:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@
M861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B
M"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"B)3975L<R!L
M92!P<F]P<FGI=&%I<F4@;W4@;"=A9&UI;FES=')A=&5U<B!S>7-TZ&UE('!E
M=70@;6]D:69I97(@;&5S("(*(G!E<FUI<W-I;VYS(&0G=6X@<&%R=&%G92XB
M"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HT,2!L:6(O0FQO8VLO:69R86UE
M+G!H<#HT,@IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B
M3W5V<FER(&1A;G,@=6YE(&YO=79E;&QE(&9E;NIT<F4B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E
M<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)
M344@<&%R="XB"FUS9W-T<B`B(@HB17)R975R($]P96Y34TR@.B!I;7!O<W-I
M8FQE(&0G97AT<F%I<F4@;&5S(&1O;F[I97,@9&4@;&$@<&%R=&EE('-I9V[I
M92!3+TU)344B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A
M(&YE=R!W:6YD;W<B"FUS9W-T<B`B3W5V<FER(&QE<R!L:65N<R!D86YS('5N
M92!N;W5V96QL92!F96[J=')E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(E-Y<W3H;64@
M9"=E>'!L;VET871I;VXB"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP
M:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(D]P=&EO;G,B"@HC.B!S
M97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z
M,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T
M<B`B3W!T:6]N<R!P;W5R("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S
M='(@(DQI<W1E(&YU;>ER;W3I92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B
M3W)G86YI<V%T:6]N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-CD*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B
M56YI=.D@;W)G86YI<V%T:6]N;F5L;&4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3,T"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(D]R9V%N
M:7-A=&EO;B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/
M<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R(")-;V3H;&4@
M;W)I9VEN86P@9"=A<'!L:6-A=&EO;B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E
M<R!I;B`E<SHB"FUS9W-T<B`B36]DZ&QE<R!O<FEG:6YA=7@@9&%N<R`E<Z`Z
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E
M<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(D%U=')E
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDY(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3(U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-`IM<V=I9"`B3W1H97(@
M26YF;W)M871I;VXB"FUS9W-T<B`B075T<F5S(&EN9F]R;6%T:6]N<R(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUI<W-I;VYS(&1U('!R;W!R:>ET86ER
M92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B
M4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(DPG875T:&5N=&EF:6-A=&EO;B!004T@;B=E<W0@<&%S(&1I<W!O;FEB;&4N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z
M,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS9W-T<B`B36]D=6QE
M(%!%05(Z.DUA:6PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,C<V"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B
M4VEG;F%T=7)E(&YU;>ER:7%U92!01U`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,S(R"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B
M"FUS9W-T<B`B1&]N;NEE<R!01U`@8VAI9F9RZ65S(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W-`IM<V=I9"`B4$=0(%!U8FQI8R!+
M97DB"FUS9W-T<B`B0VQE9B!P=6)L:7%U92!01U`B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4V"FUS9VED(")01U`@4VEG;F5D+T5N
M8W)Y<'1E9"!$871A(@IM<V=S='(@(D1O;F[I97,@4$=0('-I9V[I97,O8VAI
M9F9RZ65S(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8Y"FUS9VED(")02%`@
M0V]D92(*;7-G<W1R(")#;V1E(%!(4"(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H
M<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(DEN=&5R<'+I=&5U<B!0
M2%`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M.`IM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R(")0;'5I92!LZ6?H<F4@
M;"=A<'+H<RUM:61I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%)A:6XB"FUS9W-T<B`B4&QU:64@;"=A
M<'+H<RUM:61I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#`*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B079E<G-E<R!L
M)V%P<NAS+6UI9&DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT,0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R(").96EG92!L)V%P
M<NAS+6UI9&DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT,@IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(D-H=71E
M<R!D92!N96EG92!L)V%P<NAS+6UI9&DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4$T@4W5N(@IM<V=S='(@
M(E-O;&5I;"!L)V%P<NAS+6UI9&DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T
M<B`B3W)A9V5S(&PG87!RZ',M;6ED:2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM
M<V=S='(@(D5X=&5N<VEO;B!03U-)6"!A8G-E;G1E(@H*(SH@;&EB+V%P:2YP
M:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(DEN=&5R<'+I=&5U
M<B!07TA0(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R(")296UP;&ES
M<V%G92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B
M4&%K:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QA=2(*;7-G<W1R
M(")"96QA=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E
M<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B4&%L97-T:6YE("AT97)R:71O
M:7)E(&]C8W5PZ2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G
M<W1R(")086YA;6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'
M=6EN96$B"FUS9W-T<B`B4&%P;W5A<VEE+4YO=79E;&QE+4=U:6[I92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(E!A<F%G=6%Y
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*
M;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B4&%R=&EE;&QE;65N="!N
M=6%G975X(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$X,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4S-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q-0HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<W('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-#,*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0R-0IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B36]T(&1E('!A<W-E
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")0
M87-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B0VAA;F=E
M;65N="!D=2!M;W0@9&4@<&%S<V4@969F96-T=>DN(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(S"FUS9VED(")087-S=V]R9"!I
M;F-O<G)E8W0B"FUS9W-T<B`B36]T(&1E('!A<W-E(&EN8V]R<F5C="(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A
M<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(DUO="!D92!P87-S92!R97%U:7,@<&]U<B!L)V%U=&AE;G1I9FEC
M871I;VX@4D%$2553+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M-3`*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@
M(DUO="!D92!P87-S92!A=F5C(&-O;F9I<FUA=&EO;B(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S
M='(@(DUO="!D92!P87-S9:`Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B36]T(&1E('!A
M<W-EH#H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(P,S$*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@
M(DQE<R!M;W1S(&1E('!A<W-E(&1O:79E;G0@ZG1R92!I9&5N=&EQ=65S+B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*
M;7-G<W1R(")#;VQL97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*
M;7-G<W1R(")#;VQL97(@9&5P=6ES(&QE('!R97-S92UP87!I97)S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I
M9"`B4&%T:"(*;7-G<W1R(")#:&5M:6XB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R
M(")#;VYF:7)M871I;VYS(&5N(&%T=&5N=&6@.B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(E!E<G-O;FYE
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@(E!O=7)C96YT86=E(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G
M:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")%
M9F9E8W1U97(@;&5S(&]PZ7)A=&EO;G,@9&4@;6%I;G1E;F%N8V4B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#$P"FUS9VED(")097)F;W)M(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(D5F9F5C='5E
M<B!L97,@;W#I<F%T:6]N<R!D92!M86EN=&5N86YC92#@(&QA(&-O;FYE>&EO
M;J`_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G
M:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B4&5R;6ES<VEO;B(*"B,Z(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R
M;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S='(@(DQA('!E<FUI
M<W-I;VX@JZ`E<Z"[(&XG97-T('!A<R!S=7!P<FEMZ64N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HU.3`*;7-G:60@(E!E<FUI<W-I;VX@1&5N
M:65D(@IM<V=S='(@(E!E<FUI<W-I;VX@<F5F=7/I92(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R(")097)M
M:7-S:6]N<R(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP
M.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G:60@(E!E<FUI<W-I
M;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<F%T:6]N(&1E
M<R!P97)M:7-S:6]N<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.`IM
M<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B1&]N;NEE<R!P
M97)S;VYN96QL97,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T
M<B`B4.ER;W4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@
M(E!E=',B"FUS9W-T<B`B06YI;6%U>"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B
M4&AI;&EP<&EN97,B"FUS9W-T<B`B4&AI;&EP<&EN97,B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N
M92(*;7-G<W1R(")4Z6SI<&AO;F4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#@P"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B4&AO=&]S(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B4&ET8V%I<FXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(E!I>&5L<R(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R(")0
M;&%T:71U9&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M
M92!C96QL(@IM<V=S='(@(E-64"!C;&EQ=65Z(&1A;G,@=6YE(&-E;&QU;&4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@
M=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B4U90(&-O;F9I<FUE
M>B!L82!S=7!P<F5S<VEO;B!D92!C970@Z6SI;65N=*`Z(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS
M9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T
M:&ES(&5L96UE;G0N(@IM<V=S='(@(E-64"!C;VYF:7)M97H@<75E('9O=7,@
M=F]U;&5Z(&3I;&EE<B!C970@Z6SI;65N="XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-34Y"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A
M;F0@82!Y96%R+B(*;7-G<W1R(")6975I;&QE>B!S86ES:7(@=6X@;6]I<R!E
M="!U;F4@86YNZ64N(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R
M('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(E9E=6EL;&5Z('-A:7-I<B!U
M;B!N;VT@<&]U<B!L82!N;W5V96QL92!C873I9V]R:66@.B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R.3@*;7-G:60@(E!L96%S92!E;G1E<B!A
M('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(E9E=6EL;&5Z(&5N=')E<B!U
M;F4@861R97-S92!)4"!V86QI9&4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C8S-PIM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@
M8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T
M<B`B(@HB5F5U:6QL97H@96YT<F5R('5N92!D871E('9A;&ED9:`[(';I<FEF
M:65Z(&QE(&YO;6)R92!D92!J;W5R<R!D=2!M;VES+B`B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-#0T"FUS9VED(")0;&5A<V4@96YT97(@82!V
M86QI9"!T:6UE+B(*;7-G<W1R(")6975I;&QE>B!E;G1R97(@=6YE(&AE=7)E
M('9A;&ED92XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW
M"FUS9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L
M96TN(@IM<V=S='(@(E9E=6EL;&5Z(&9O=7)N:7(@=6X@<NES=6WI(&1U('!R
M;V)LZ&UE+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I
M9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B5F5U:6QL
M97H@9F]U<FYI<B!V;W1R92!N;VT@9"=U=&EL:7-A=&5U<B!E="!V;W1R92!M
M;W0@9&4@<&%S<V4B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*
M;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U
M($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T
M96TN(@IM<V=S='(@(B(*(E9E=6EL;&5Z(&QI<F4@;&4@=&5X=&4@<W5I=F%N
M="X@5F]U<R!D979E>B!A8V-E<'1E<B!L97,@8V]N9&ET:6]N<R!P;W5R("(*
M(G5T:6QI<V5R(&QE('-Y<W3H;64N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E
M('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B5F5U:6QL97H@96YT
M<F5R(&QE(&YO=79E874@;F]MH&1E(&QA(&-A=.EG;W)I9:`Z(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDY"FUS9VED(")0;VQA;F0B"FUS9W-T<B`B4&]L;V=N92(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T
M<B`B4&]L:71I<75E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X
M.0IM<V=I9"`B4&]L;',B"FUS9W-T<B`B4V-R=71I;G,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R(")0;W)T=6=A;"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R
M(")0;W-I=&EO;B!D92!C971T92!I;6%G92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN
M9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(E!O<VET:6]N(&1E(&-E('1A8FQE
M874B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU
M,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM
M<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-
M05`I(@IM<V=S='(@(D5N=F]Y97(@X"!C92!D;W-S:65R("AN;VX@87!P;&EQ
M=>D@<&%R($E-05`I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S,@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E
M8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B4'+I
M8VEP:71A=&EO;G,@<&]U<B!L97,@)7,@9&5R;FGH<F5S(&AE=7)E<Z`Z("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#<*;7-G:60@(E!R
M96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B4')O8F%B:6QI=.D\
M8G(@+SYD92!P;'5I92(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P
M+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L9&%PH#H@97AT96YS
M:6]N(')E<75I<V4@3$1!4"!N;VX@=')O=7;I92XB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I
M;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B4')E9G-?<V5S<VEO;J`Z(&5X=&5N<VEO;B!R97%U:7-E(*N@<V5S
M<VEO;J"[(&YO;B!T<F]U=NEE+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C,R"FUS9VED(")0<F5S<W5R92(*;7-G<W1R(")0<F5S<VEO;B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C8V"FUS9VED(")0<F5S<W5R92!A="!S96$@
M;&5V96PZ("(*;7-G<W1R(")0<F5S<VEO;B!A=2!N:79E874@9&4@;&$@;65R
MH#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-`IM<V=I
M9"`B4')E<W-U<F4Z("(*;7-G<W1R(")0<F5S<VEO;J`Z("(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,#,*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S
M"FUS9VED(")0<F5V:65W(@IM<V=S='(@(D%P97+G=2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM
M<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S
M='(@(D%P97+G=2!D92!L)VEM86=E(&1A;G,@=6YE(&YO=79E;&QE(&9E;NIT
M<F4B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,U-B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V,`IM<V=I9"`B4')E=FEO=7,@
M;W!T:6]N<R(*;7-G<W1R(")/<'1I;VYS('!RZ6/I9&5N=&5S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B
M4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B26UP<FEM97(@;&4@9&]C=6UE;G0B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@
M(E!R:79A=&4@2V5Y(@IM<V=S='(@(D-L968@<')I=NEE(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*
M;7-G<W1R(")0<F]B;.AM92(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R
M-PIM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FEP
M=&EO;B!D=2!P<F]B;.AM92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS-S$*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(E!R;VIE=',B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`X(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q.#4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W,PIM
M<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B5&5X=&4@8V]U<G0B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI
M8R!+97DB"FUS9W-T<B`B0VQE9B!P=6)L:7%U92(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C0V"FUS9VED(")0=6)L:6,@2V5Y($%L
M9V]R:71H;2(*;7-G<W1R(")!;&=O<FET:&UE(&1E(&-L968@<'5B;&EQ=64B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I
M9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(DEN9F]R;6%T:6]N<R!S=7(@
M;&$@8VQE9B!P=6)L:7%U92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@
M9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`BR6-H96,@9&4@;&$@
M9^ENZ7)A=&EO;B!D92!L82!P86ER92!D92!C;&5F<R!P=6)L:7%U92]P<FEV
MZ64N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T
M<B`B4&]R=&\@4FEC;R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S0S,30N<&AP.C4U"FUS9VED(")0=7)G92!M97-S86=E<R(*;7-G<W1R(")0
M=7)G97(@;&5S(&UE<W-A9V5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T
M87(B"FUS9W-T<B`B46%T87(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C0*
M;7-G:60@(E%U97)Y(@IM<V=S='(@(E)E<77J=&4B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S='(@(E%U;W1A(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T
M<B`B0VQE9B!P=6)L:7%U92!24T$@*"5D(&)I=',I(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(V,0IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM
M<V=S='(@(E/I;&5C=&EO;B!R861I;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN(@IM<V=S='(@(E!L
M=6EE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#8*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B4&QU:64@=/1T(&QE(&UA
M=&EN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#<*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R(")0;'5I92!T87)D(&1A;G,@
M;&$@:F]U<F[I92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0X"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R(")!=F5R<V5S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*
M;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B4&QU:64@970@;F5I9V4B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM
M<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(E!L=6EE('!U:7,@;F5I9V4B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O
M<G1U;F4B"FUS9W-T<B`B07!H;W)I<VUE(&%U(&AA<V%R9"(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T
M<B`B5&%U>"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(T('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3@P"FUS9VED(")296%D(@IM<V=S='(@(DQI<F4B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT-PHC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PIM<V=I9"`B4F5A9"!M97-S86=E
M<R(*;7-G<W1R(")-97-S86=E<R!L=7,B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY
M(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB
M"FUS9W-T<B`B4W5P<')E<W-I;VX@9.EF:6YI=&EV92!D92`E<Z`_(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_
M(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*
M(E-U<'!R97-S:6]N(&3I9FEN:71I=F4@9&5S(&1O;F[I97,@<&]U<B!L)W5T
M:6QI<V%T975R("5SH#\@0V5T=&4@;W#I<F%T:6]N("(*(F5S="!DZ69I;FET
M:79E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@
M(E)E<')E;F1R92!V;W1R92!D97)N:>AR92!A8W1I;VXB"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM
M<V=I9"`B4F5F<F5S:"(*;7-G<W1R(")2869R8>YC:&ER(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,Y-0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE
M;G4@16QE;65N=',Z(@IM<V=S='(@(E)A9G)A[F-H:7(@;&5S(.ELZ6UE;G1S
M(&1U(&UE;G4@9'EN86UI<75EH#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S0U"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R(")2
M869R8>YC:&ER(&PGZ6-R86X@9'4@<V]M;6%I<F6@.B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Y,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C$P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S(*;7-G:60@(E)E
M9V5X(@IM<V=S='(@(D5X<')E<W-I;VX@<F%T:6]N;F5L;&4B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C(X"FUS9VED(")296QA=&EO;G-H:7`@
M0G)O=W-E<B(*;7-G<W1R(").879I9V%T975R(')E;&%T:6]N;F5L(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(P.`IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(E)E8VAA
M<F=E<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,S"FUS9VED(")296UA
M<FMS(@IM<V=S='(@(E)E;6%R<75E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,3<*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(E-E<G9E
M=7)S(&1I<W1A;G1S(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M
M+VAO<F1E*3HB"FUS9W-T<B`B55),(&1I<W1A;G1E("AH='1P.B\O=W=W+F5X
M96UP;&4N8V]M+VAO<F1E+RF@.B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z,C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN
M8SHQ,PIM<V=I9"`B4F5M;W9E(@IM<V=S='(@(E)E=&ER97(B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*;7-G:60@(E)E;6]V92!";&]C
M:R(*;7-G<W1R(")2971I<F5R(&QE(&)L;V,B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34Y"FUS9VED(")296UO=F4@8V]L
M=6UN(@IM<V=S='(@(E)E=&ER97(@;&$@8V]L;VYN92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*;7-G:60@(E)E;6]V
M92!F;W)M871T:6YG(@IM<V=S='(@(E)E=&ER97(@;&4@9F]R;6%T86=E(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V
M92!P86ER(@IM<V=S='(@(E)E=&ER97(@;&$@<&%I<F4B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T
M(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M16YL979E<B!L92!S8W)I<'0@96YR96=I<W1RZ2!D=2!RZ7!E<G1O:7)E('1E
M;7!O<F%I<F4@9'4@<V5R=F5U<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@(E)E;6]V92!T
M:&4B"FUS9W-T<B`B4F5T:7)E<B!L92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E
M('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R(")2971I<F5R
M(&-E(&YO975D(&1U(&1O8W5M96YT(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B
M4F5T:7)E<B!L)W5T:6QI<V%T975R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U
M<V5R.B`E<R(*;7-G<W1R(")2971I<F5R(&PG=71I;&ES871E=7*@.B`E<R(*
M"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")2
M97%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O
M9&4Z("(*;7-G<W1R(")!=6-U;F4@<NEP;VYS92#@('9O=')E(')E<77J=&4N
M($-O9&4@9"=E<G)E=7(@<F5T;W5R;NF@.B`B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,30U"FUS9VED(")297%U97-T960@<V5R=FEC92!C
M;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(DQE('-E<G9I8V4@9&5M86YD
MZ2!E<W0@:6YT<F]U=F%B;&4N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ.#4@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,C<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@
M:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB3&4@<&%R86WH=')E
M(&]B;&EG871O:7)E(*N@)7.@NR!N)V5S="!P87,@<W#I8VEF:>D@9&%N<R!L
M82!C;VYF:6=U<F%T:6]N("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z-C<X(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#8Q"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(DQE('!A<F%MZ'1R92!O8FQI
M9V%T;VER92"KH"5SH+L@;B=E<W0@<&%S('-PZ6-I9FGI(&1A;G,@;&$@8V]N
M9FEG=7)A=&EO;B!D=2`B"B)61E,N(@H*(SH@9G)A;65W;W)K+U5T:6PO571I
M;"YP:'`Z-S<V"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<
M(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M(DQE('!A<F%MZ'1R92!O8FQI9V%T;VER92"KH"5SH+L@;B=E<W0@<&%S('-P
MZ6-I9FGI(&1A;G,@;&$@8V]N9FEG=7)A=&EO;BXB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D($9I
M96QD(@IM<V=S='(@(D-H86UP(&]B;&EG871O:7)E(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,V"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R,`HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(P('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B4L!:(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*;7-G:60@(E)E<V5T(%!A<W-W
M;W)D(@IM<V=S='(@(E)E;6ES92#@('KI<F\@9'4@;6]T(&1E('!A<W-E(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E<V5T
M(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B4F5M971T<F4@X"!ZZ7)O('9O=')E
M(&UO="!D92!P87-S92(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S$*;7-G
M:60@(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G<W1R(")2979E;FER(.`@;&$@
M9&5R;FGH<F4@<F5Q=>IT92(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW,B!A
M9&UI;B]C;61S:&5L;"YP:'`Z,CD@861M:6XO<W%L<VAE;&PN<&AP.C8W"FUS
M9VED(")297-U;'1S(@IM<V=S='(@(E+I<W5L=&%T<R(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI
M;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B4F5V96YI
M<B!A=7@@;W!T:6]N<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R(")2Z2UE
M;G1R97(@;&4@;F]U=F5A=2!M;W0@9&4@<&%S<V4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R
M"FUS9VED(")2975N:6]N(@IM<V=S='(@(E+I=6YI;VXB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*
M;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(E)E=F5N:7(@
MX"!L82!C;VYF:6=U<F%T:6]N('!RZ6/I9&5N=&4B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3,U"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO
M;G,B"FUS9W-T<B`B3W!T:6]N<R!D92!L)^ED:71E=7(@4FEC:"!497AT(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM
M<V=S='(@(D1E=FEN971T97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@
M(D1R;VET92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#`*;7-G
M:60@(E)I9VAT(&AE861E<B(*;7-G<W1R(")%;G3J=&4@9&4@9')O:71E(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y-@IM<V=I9"`B4FEG:'0@
M=F%L=65S(@IM<V=S='(@(E9A;&5U<G,@8V]R<F5C=&5S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS
M9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4')O<')IZ73I<R!D
M92!L82!R86Y?9^EE("XN+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B4O1L92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B4F]U;6%N
M:64B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C(V"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(E!I=F]T97(@,3@P(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,PIM
M<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B4&EV;W1E<B#@(&=A=6-H92(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,CD*
M;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R(")0:79O=&5R(.`@9')O:71E
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B4')O<')I
MZ73I<R!D92!L82!R86YGZ64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE
M<R(*;7-G<W1R(")0<F]P<FGI=.ES(&1E(&QA(')A;F?I92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2
M;W=S.B(*;7-G<W1R(")286YGZ65SH#HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"FUS9VED(")2=6QE<R(*
M;7-G<W1R(")2Z&=L97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(D1E<R!F
M:6QE=',@87!P87)A[G1R;VYT(&5N=')E('1O=71E<R!L97,@<F%N9^EE<R!E
M="!L97,@8V]L;VYN97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R(")$97,@9FEL971S(&%P
M<&%R8>YT<F]N="!E;G1R92!L97,@8V]L;VYN97,@<V5U;&5M96YT(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB
M"FUS9W-T<B`B1&5S(&9I;&5T<R!A<'!A<F'N=')O;G0@96YT<F4@;&5S(')A
M;F?I97,@<V5U;&5M96YT(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,0IM
M<V=I9"`B4G5N(@IM<V=S='(@(DQA;F-E<B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G
M:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R(")2=7-S:64B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B4G=A;F1A(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O
M34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R(")3:6=N871U
M<F4@Z6QE8W1R;VYI<75E(%,O34E-12(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE
M<W-A9V4B"FUS9W-T<B`B365S<V%G92!C:&EF9G+I(%,O34E-12(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T
M:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3"=A=71H
M96YT:69I8V%T:6]N(%-!4TP@;B=E<W0@<&%S(&1I<W!O;FEB;&4B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`V"FUS9VED(")335,@365S<V%G
M:6YG(@IM<V=S='(@(DUE<W-A9V5R:64@4TU3(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B26YT97)P<NET
M975R(%-13"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-S$*;7-G
M:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B
M3W)D<F4@4U%,('!O=7(@<F5T;W5R;F5R(&QE<R!V86QE=7)S(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,PIM<V=I9"`B4U-((@IM<V=S='(@
M(E-32"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T
M<B`B4U5#0\A3(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED(")37U%,(%-H
M96QL(@IM<V=S='(@(DEN=&5R<'+I=&5U<B!37U%,(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS
M9W-T<B`B4V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")386EN="!(96QE;F$B
M"FUS9W-T<B`B4V%I;G1E+4CI;.AN92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B
M4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(E-A:6YT+4-H<FES=&]P
M:&4M970M3FGI=NAS(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED(")386EN="!,=6-I
M82(*;7-G<W1R(")386EN=&4M3'5C:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED
M(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@(E-A:6YT+5!I
M97)R92!E="!-:7%U96QO;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT
M(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@(E-A:6YT+59I
M;F-E;G0M970M;&5S($=R96YA9&EN97,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?
M<V5L9BDB"FUS9W-T<B`B3>IM92!C861R92`H7W-E;&8I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B4V%M;V$@;V-C:61E;G1A;&5S
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R(")3
M86EN="U-87)I;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N
M9"!0<FEN8VEP92(*;7-G<W1R(")386\M5&]MZ2UE="U0<FEN8VEP92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L
M;&ET92!0<F]V:61E<B(*;7-G<W1R(")&;W5R;FES<V5U<B!S871E;&QI=&4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B
M07)A8FEE(%-A;W5D:71E(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N
M:6YC.CDY"FUS9VED(")3879E(@IM<V=S='(@(D5N<F5G:7-T<F5R(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R(")%;G)E9VES=')E<B"K
MH"5SH+LB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(D5N<F5G:7-T<F5R
M("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V
M92!/<'1I;VYS(@IM<V=S='(@(D5N<F5G:7-T<F5R(&QE<R!O<'1I;VYS(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I9"`B(@HB4V%V92!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U
M<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B
M"B)%;G)E9VES=')E<B!L82!C;VYF:6=U<F%T:6]N(&?I;NERZ64@8V]M;64@
M=6X@<V-R:7!T(%!(4"!D86YS(&QE('+I<&5R=&]I<F4@(@HB=&5M<&]R86ER
M92!D92!V;W1R92!S97)V975R+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(D5N<F5G:7-T<F5R(&QA(&-O;F9I9W5R871I;VX@
M9&4@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@
M7"(E<UPB+B(*;7-G<W1R(")38W)I<'0@9&4@;6ES92#@(&IO=7(@9&4@8V]N
M9FEG=7)A=&EO;B!E;G)E9VES='+I('-O=7.@.B"K("5SH+LB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B4V-A
M='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(D]R86=E<R!I<V]LZ7,B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T
M<B`B4V-I96YC92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")3
M96%R8V@B"FUS9W-T<B`B4F5C:&5R8VAE(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,R,@IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B
M36]T975R<R!D92!R96-H97)C:&4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.34R"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B0VAO:7-I
M<W-E>B!L97,@9FEC:&EE<G,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#@U"FUS9VED(")396QE8W0@82!D871E(@IM<V=S
M='(@(E/I;&5C=&EO;FYE>B!U;F4@9&%T92(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B
M"FUS9W-T<B`B4^EL96-T:6]N;F5Z('5N(&=R;W5P92#@(&%J;W5T97(B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED(")396QE8W0@
M82!N97<@;W=N97(B"FUS9W-T<B`B4^EL96-T:6]N;F5Z('5N(&YO=79E874@
M<')O<')IZ71A:7)E(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C8P"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B4^EL96-T:6]N
M;F5Z('5N('-E<G9E=7(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B4^EL
M96-T:6]N;F5Z('5N('5T:6QI<V%T975R(.`@86IO=71E<B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S8*;7-G:60@(E-E
M;&5C="!A;&PB"FUS9W-T<B`B5&]U="!SZ6QE8W1I;VYN97(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C0P"FUS9VED(")396QE8W0@86QL(&1A
M=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B4^EL96-T:6]N;F5Z('1O=71E<R!L
M97,@8V]M<&]S86YT97,@9&4@;&$@9&%T92XB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")396QE8W0@86X@
M;V)J96-T(@IM<V=S='(@(D-H;VES:7-S97H@=6X@;V)J970B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"FUS9VED(")3
M96QE8W0@;F]N92(*;7-G<W1R(").92!SZ6QE8W1I;VYN97(@875C=6XB"@HC
M.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T
M:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@
M66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@
M=&5X="!A<F5A+B(*;7-G<W1R("(B"B)3Z6QE8W1I;VYN97H@;&5S(&-A<F%C
M=.AR97,@9&]N="!V;W5S(&%V97H@8F5S;VEN(.`@;"=A:61E(&1E(&PG;W5T
M:6P@8VDM(@HB9&5S<V]U<RX@5F]U<R!P;W5V97H@96YS=6ET92!L97,@8V]P
M:65R(&5T(&QE<R!C;VQL97(@9&%N<R!V;W1R92!T97AT92XB"@HC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D871E
M(&1E;&EM:71E<CHB"FUS9W-T<B`B4^EL96-T:6]N;F5Z(&QE(&3I;&EM:71E
M=7(@9&4@9&%T9:`Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*
M;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(E/I;&5C
M=&EO;FYE>B!L92!F;W)M870@9&4@9&%T9:`Z(@H*(SH@=&5M<&QA=&5S+W!R
M969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I
M9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(E/I;&5C=&EO
M;FYE<B!L92!P<F]F:6P@<75E('9O=7,@9.ES:7)E>B!M;V1I9FEE<CHB"@HC
M.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H
M92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B4^EL96-T:6]N;F5Z(&QE(&3I
M;&EM:71E=7(@9"=H975R9:`Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI
M;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@
M(E/I;&5C=&EO;FYE>B!L92!F;W)M870@9&4@;"=H975R9:`Z(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M
M871C:&EN9R!F:65L9',N(@IM<V=S='(@(E/I;&5C=&EO;FYE>B!D975X(&-H
M86UP<R!A<'!A<F5N=.ES+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M,3`*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B
M4^EL96-T:6]N;F5Z('9O=')E('1HZ&UE(&1E(&-O=6QE=7)S+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3(*;7-G:60@(E-E;&5C="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B4^EL96-T:6]N;F5Z('9O=')E
M(&QA;F=U92!P<NEFZ7+I9:`Z(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T
M<B`B16YV;WEE<B!L92!R87!P;W)T(&0G86YO;6%L:64B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`T,@IM<V=I9"`B4V5N
M9"!335,B"FUS9W-T<B`B16YV;WEE<B!335,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS
M9VED(")396YE9V%L(@IM<V=S='(@(E/I;NEG86PB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,R,PIM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B4V]N9&6@
M.B`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(E-E<'1E;6)R92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B
M:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B4V5R8FEE(&5T($UO;G1E;F5G
M<F\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,@IM
M<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R(").=6WI<F\@9&4@<^ER:64B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30Y"FUS9VED(")3
M97)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R("),
M97,@9&]N;NEE<R!D=2!S97)V975R('-O;G0@9F%U<W-E<R!O=2!N;VX@9&ES
M<&]N:6)L97,N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"FUS9VED(")3
M97-S:6]N($%D;6EN(@IM<V=S='(@(D%D;6EN:7-T<F%T:6]N(&1E<R!S97-S
M:6]N<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R
M("))9"X@9&4@<V5S<VEO;B!E>'!I<NDN(@H*(SH@;&EB+V%P:2YP:'`Z,30U
M"FUS9VED(")397-S:6]N<R(*;7-G<W1R(")397-S:6]N<R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S,3$*;7-G:60@(E-E="(*;7-G<W1R(")3
MZ6QE8W1I;VYN97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SD*;7-G
M:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A
M<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@HB0V]N
M9FEG=7)E<B!L97,@;W!T:6]N<R!P;W5R('9O=7,@<&5R;65T=')E(&1E(')E
M;65T=')E(.`@>NER;R!V;W1R92!M;W0@9&4@(@HB<&%S<V4@<VD@:F%M86ES
M('9O=7,@;"=O=6)L:65Z+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,3@*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT
M('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R(")#;VYF:6=U
M<F5R(&QE<R!S97)V975R<R!D:7-T86YT<R!A8V-E<W-I8FQE<R!D97!U:7,@
M=F]T<F4@<&]R=&%I;"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<*
M;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@
M86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B(@HB4^EL96-T:6]N;F5Z('9O
M=')E(&QA;F=U92!P<NEFZ7+I92P@9G5S96%U(&AO<F%I<F4@970@;&5S(&]P
M=&EO;G,@9&4@9&%T92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Q
M"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO
M<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L
M87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HB1.EF:6YI<W-E>B!L82!P<F5M:>AR
M92!A<'!L:6-A=&EO;B!L86YCZ64L(&QE('1HZ&UE(&1E(&-O=6QE=7)S+"!L
M92`B"B)R869R8>YC:&ES<V5M96YT(&1E<R!P86=E<RP@970@9"=A=71R97,@
M;W!T:6]N<R!D)V%F9FEC:&%G92XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C<W"FUS9VED(")3971U<"(*;7-G<W1R(")#;VYF:6=U<F%T:6]N(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@
M(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B4V-R
M:7!T(&1E(&-O;F9I9W5R871I;VX@9&4@;6ES92#@(&IO=7(@9&ES<&]N:6)L
M92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@
M(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E
M<CH@(@IM<V=S='(@(E!L=7-I975R<R!E;F1R;VET<R!P;W-S:6)L97,@879E
M8R!L92!P87)A;>AT<F6@.B`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC
M:&5L;&5S(@IM<V=S='(@(E-E>6-H96QL97,B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#DX"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R(")!8VAA
M="(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED
M(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(E+I<W5MZ2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT-3`*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B
M92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R(")$;VET+6]N(&3I
M9FEN:7(@9&5S('1O=6-H97,@9&4@<F%C8V]U<F-I<R!P;W5R(&QA('!L=7!A
M<G0@9&5S(&QI96YSH#\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R(")!9F9I8VAE<B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF
M9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L
M>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB36]N
M=')E<B!L97,@9&EF9NER96YC97,@96YT<F4@;&$@8V]N9FEG=7)A=&EO;B!E
M;G)E9VES='+I92!A8W1U96QL96UE;G0@970@(@HB8V5L;&4@;F]U=F5L;&5M
M96YT(&?I;NERZ64N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y-`IM
M<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*
M;7-G<W1R(")-;VYT<F5R(&PG:&5U<F4@9&4@;&$@9&5R;FGH<F4@8V]N;F5X
M:6]N(.`@;"=E;G1RZ66@/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$W-C(*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS
M9W-T<B`B36]N=')E<B!L)V]P=&EO;B!D92!C;VYS97)V97(@;"=O<FEG:6YA
M;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.3(*;7-G:60@(E-H
M;W<@<&EC:V5R(@IM<V=S='(@(DUO;G1R97(@;&4@<^EL96-T975R(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S,`IM<V=I9"`B4VAO=R!T86)L92!O
M<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R(")!9F9I8VAE<B!L82!B87)R
M92!D92!M96YU(&1E('1A8FQE875XH#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S4S"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE
M;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(D%F9FEC:&5R(&QE(&UE;G4@)7,@
MX"!G875C:&6@/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L
M;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")!9F9I8VAE<B!L82!B;^YT
M92!D92!D:6%L;V=U92!T86)L96%U(&-E;&QU;&4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@
M(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(D%F
M9FEC:&5R(&QA(&)O[G1E(&1E(&1I86QO9W5E(&1E<R!P<F]P<FGI=.ES(&1U
M('1A8FQE874B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0
M<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")!9F9I8VAE<B!L82!B;^YT92!D
M92!D:6%L;V=U92!D97,@<')O<')IZ73I<R!D92!L82!R86YGZ64@9'4@=&%B
M;&5A=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE
M<R!D:6%L;V<B"FUS9W-T<B`B069F:6-H97(@;&$@8F_N=&4@9&4@9&EA;&]G
M=64@9&5S('!R;W!R:>ETZ7,@9&4@;"=I;6%G92(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$W-C`*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@
M(D%F9FEC:&5R(&PG96YV;VD@9&4@9FEC:&EE<B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S(@IM
M<V=S='(@(D%V97)S97,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R(")!
M=F5R<V5S('3T="!D86YS(&QA(&IO=7)NZ64B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B4VAO=V5R<R!,871E
M(@IM<V=S='(@(D%V97)S97,@=&%R9"!E;B!J;W5R;NEE(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-H;W=E
M<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(D%V97)S97,@875X(&%L96YT
M;W5R<R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z-C$Y"FUS9VED(")3:')I;FLB"FUS9W-T<B`B4F5S<V5R<F5R(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HY
M,3`*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HY-S(*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HQ,#4X"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z,3$R,`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C$Q.#,*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HQ,C(S"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z,3(U,@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R.#4*;7-G:60@(E-H<FEN:R!O
M<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F
M:7)S="(*;7-G<W1R(")297-S97)R97(@;W4@9.EG86=E<B!D)V%B;W)D(&QE
M*',I(&)L;V,H<RD@=F]I<VEN*',I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B
M4VEE<G)A($QE;VYE(@IM<V=S='(@(E-I97)R82!,96]N92(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C8*;7-G:60@(E-I9VX@=7`B
M"FUS9W-T<B`B4R=I;G-C<FER92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-S$S"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`B4VEG
M;F%T=7)E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW
M,3(*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B06QG;W)I
M=&AM92!D92!S:6=N871U<F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG
M87!O<F4B"FUS9W-T<B`B4VEN9V%P;W5R(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DS"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3(@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(S-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0S(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,#D*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$P,@IM<V=I9"`B4VEZ92(*;7-G<W1R(")486EL;&4B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM
M<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R(")!;FYU;&5R(&QA(&UA
M:6YT96YA;F-E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS
M9W-T<B`B4VQO=F%Q=6EE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N
M:6$B"FUS9W-T<B`B4VQO=NEN:64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R(*;7-G<W1R(").96EG
M92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W
M"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R(")!=F5R<V4@9&4@;F5I9V4B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM
M<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(D%V97)S97,@9&4@;F5I9V4B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM
M<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(D%V97)S97,@9&4@
M;F5I9V4@=/1T(&1A;G,@;&$@:F]U<F[I92(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")3;F]W(%-H;W=E<G,@
M3&%T92(*;7-G<W1R(")!=F5R<V5S(&1E(&YE:6=E('1A<F0@96X@:F]U<F[I
M92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@U"FUS9VED(")3;F]W(&1E
M<'1H.B`B"FUS9W-T<B`B2&%U=&5U<B!D92!N96EG9:`Z("(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C@Y"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@
M=V%T97(Z("(*;7-G<W1R(")1=6%N=&ETZ2!D)V5A=2#I<75I=F%L96YT92#@
M(&QA('%U86YT:73I(&1E(&YE:6=EH#H@(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I
M9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(LYL97,@4V%L;VUO;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B4V]M86QI92(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0
M;V5M<R(*;7-G<W1R(")#:&%N<V]N<R!E="!P;^AM97,B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.3`U"FUS9VED(")3;W)T(&]R9&5R('-E;&5C
M=&EO;B(*;7-G<W1R(")3Z6QE8W1I;VX@9&4@;"=O<F1R92!D92!T<FDB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U
M.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R(")!9')E<W-E
M('-O=7)C92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC82(*
M;7-G<W1R(")!9G)I<75E(&1U('-U9"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3DS"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS
M9W-T<B`B4W5D+65U<F]PZ65N("A)4T\M.#@U.2TS*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H
M($ES;&%N9',B"FUS9W-T<B`B1^EO<F=I92UD=2US=60@970@[FQE<R!386YD
M=VEC:"UD=2US=60B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L
M;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM
M<V=S='(@(DCI;6ES<&CH<F4@4W5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@
M861J86-E;G0@8V5L;',B"FUS9W-T<B`B17-P86-E(&5N=')E(&-E;&QU;&5S
M(&%D:F%C96YT97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N
M9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R(")%<W!A8V4@96YT<F4@;&4@8V]N
M=&5N=2!E="!L82!B;W)D=7)E(&1A;G,@=6YE(&-E;&QU;&4B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX,3(*;7-G:60@(E-P86-E<B(*;7-G<W1R
M(")%<W!A8V5U<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R(")%<W!A
M8V5M96YT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G
M<W1R(")%<W!A8V5M96YT(&5T(')E;7!L:7-S86=E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(E-P86EN(@IM<V=S='(@(D5S<&%G;F4B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3`P"FUS9VED(")3<&%M(@IM<V=S='(@(E!O=7)R
M:65L(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C
M:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R(")#87)A8W3H<F5S('-PZ6-I
M875X(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R(")38VEN9&5R
M(&QA(&-E;&QU;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T
M<B`B4V-I;F1E<B!L82!C;VQO;FYE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W
M(@IM<V=S='(@(E-C:6YD97(@;&$@<F%N9^EE(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`B4W!O<G1S(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B4W)I($QA
M;FMA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8V(&QI8B]"
M;&]C:R]M971A<BYP:'`Z.#$*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(E-T
M86YD87)D(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3
M=&%R(%1R96LB"FUS9W-T<B`B4W1A<B!4<F5K(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C4X,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-S@X
M"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(D%N;NEE(&1E(&3I8G5T(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$*;7-G:60@
M(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(LET870@;W4@<')O=FEN8V4B
M"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I
M9"`B4W1A='5S(@IM<V=S='(@(E-T871U="(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(W.30*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@
M(D9O<FUA="!D92!S875V96=A<F1E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S
M='(@(E)U92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B0F%R<NDB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,P"FUS9VED(")3=')I
M;F<@;&ES="(*;7-G<W1R("),:7-T92!D92!C:&'N;F5S(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,`IM<V=I9"`B4W1R:7`@9&]M86EN(&9R
M;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B4F5T:7)E<B!L92!D;VUA:6YE(&1E
M(&PG861R97-S92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@
M(E-T>6QE(%M#4U-=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B1&DB"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5B
M9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(E-O=7,M<NEP
M97)T;VER92"KH"5SH+L@;F]N('1R;W5VZ2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS
M9W-T<B`B4W5J970B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,CD@
M9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3
M=6)M:70B"FUS9W-T<B`B16YV;VDB"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<
M(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@
M>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B
M"B),82!D96UA;F1E(&0G86IO=70@9&4@JZ`E<Z"[(&%U('-Y<W3H;64@82#I
M=.D@<V]U;6ES92X@5F]U<R!N92!P;W5R<F5Z('!A<R`B"B)V;W5S(&-O;FYE
M8W1E<B!J=7-Q=2?@('-O;B!A<'!R;V)A=&EO;BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I
M<'0B"FUS9W-T<B`B26YD:6-E(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P
M-0HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@(E-U
M8V/H<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB
M"FUS9W-T<B`BJZ`E<Z"[(&$@8FEE;B#I=.D@86IO=73I*&4I+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S
M>7-T96TN(@IM<V=S='(@(DQE<R!D;VYNZ65S(&1E(&PG=71I;&ES871E=7(@
MJZ`E<Z"[(&]N="!B:65N(.ETZ2!R971I<NEE<R!D=2!S>7-TZ&UE+BXB"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z
M-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@
M7"(E<UPB+B(*;7-G<W1R("*KH"5SH+L@82!B:65N(.ETZ2!S=7!P<FEMZ2AE
M*2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E
M;2XB"FUS9W-T<B`BJZ`E<Z"[(&$@8FEE;B#I=.D@<F5T:7+I*&4I+B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL
M>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG
M97,N(@IM<V=S='(@(B(*(E)E=&]U<B#@(&QA(&-O;F9I9W5R871I;VX@:6YI
M=&EA;&4@<NEU<W-I+B`@4F%F<F'N8VAI<B!L82!P86=E('!O=7(@=F]I<B!L
M97,@(@HB;6]D:69I8V%T:6]N<RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E
M<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M16YR96=I<W1R96UE;G0@9&4@;&$@8V]N9FEG=7)A=&EO;B!D92!L82!S875V
M96=A<F1E('+I=7-S:2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@
M8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@HB16YR
M96=I<W1R96UE;G0@<NEU<W-I(&1E(&QA(&-O<&EE(&1E('-A=79E9V%R9&4@
M9'4@9FEC:&EE<B!D92!C;VYF:6=U<F%T:6]N("4B"B)S+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`BJZ`E<Z"[(&$@8FEE;B#I=.D@
M;6ES*&4I(.`@:F]U<BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`BR6-R:71U<F4@9&4@
M)7,@<NEU<W-I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W5D86XB"FUS9W-T
M<B`B4V]U9&%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R(")3;VUM
M86ER92(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N
M(%)I<V4B"FUS9W-T<B`B3&5V97(@9'4@4V]L96EL(@H*(SH@;&EB+T)L;V-K
M+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(D-O=6-H
M97(@9'4@4V]L96EL(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C$*;7-G:60@(E-U;FYY(@IM<V=S='(@(D5N<V]L96EL;.DB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`U"FUS9VED(")3
M=6YR:7-E(@IM<V=S='(@(DQE=F5R(&1U(%-O;&5I;"(*"B,Z(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I
M9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B3&5V97(O0V]U8VAE<B!D=2!3
M;VQE:6PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`T"FUS
M9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B3&5V97(@9'4@4V]L96EL.B`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`X"FUS9VED(")3=6YS
M970B"FUS9W-T<B`B0V]U8VAE<B!D=2!3;VQE:6PB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C`W"FUS9VED(")3=6YS970Z("(*;7-G<W1R
M(")#;W5C:&5R(&1U(%-O;&5I;*`Z("(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM
M<V=S='(@(D5X<&]S86YT(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,X,`IM<V=I9"`B4W5P<&]R="(*;7-G<W1R(")!<W-I<W1A;F-E(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,34@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-@IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B4W5R:6YA;2!O
M=2!'=7EA;F4@:&]L;&%N9&%I<V4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R(").;VT@
M9&4@9F%M:6QL92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N
M9"!*86X@36%Y96XB"FUS9W-T<B`BSFQE<R!3=F%L8F%R9"!E="!*86X@36%Y
M96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B
M4W=A>FEL86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S
M='(@(E-UZ&1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM
M<V=S='(@(E-U:7-S92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C@V"FUS9VED(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(DIO=7)N86P@
M9&4@<WEN8VAR;VYI<V%T:6]N('-U<'!R:6WI(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$T-0IM<V=I9"`B4WEN8TU,(@IM<V=S='(@(E-Y;F--3"(*
M"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B
M4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R(")%<G)E=7(@
M9&4@<WEN=&%X92!D86YS(&QE<R!T97)M97,@9&4@<F5C:&5R8VAE(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T
M<B`B4WER:64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV,@IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R(")/<F%G97,B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B
M5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B3W)A9V4@970@=F5N="(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED
M(")4+5-T;W)M<R(*;7-G<W1R(")/<F%G97,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5"U3=&]R;7,@16%R
M;'DB"FUS9W-T<B`B3W)A9V5S(&UA=&EN875X(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82]T<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B
M1FEC:&EE<B!44U8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM
M<V=S='(@(E!R;W!R:>ETZ7,@9'4@=&%B;&5A=2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE(%-E
M="(*;7-G<W1R(")486)L96%U(&1E('9A;&5U<G,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")4
M86)L92!P<F]P97)T:65S(@IM<V=S='(@(E!R;W!R:>ETZ7,@9'4@=&%B;&5A
M=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A;B(*;7-G<W1R
M(")48>]W86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R
M(")48>]W86XL('!R;W9I;F-E(&1E($-H:6YE(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM
M<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R(")486II:VES=&%N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*
M;7-G<W1R(")486YZ86YI92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B0VEB
M;&6@.B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,R(&-O;F9I
M9R]H;V]K<RYP:'`N9&ES=#HQ,#0Y"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ.#D*;7-G:60@(E1A<VMS(@IM<V=S='(@(E3B8VAE<R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"FUS9VED(")496QE
M<&AO;F4@3G5M8F5R(@IM<V=S='(@(DYU;>ER;R!D92!TZ6SI<&AO;F4B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-PIM<V=I9"`B5&5M<"!F;W(@;&%S
M="!H;W5R.B`B"FUS9W-T<B`B5&5M<.ER871U<F4@<&]U<B!L82!D97)N:>AR
M92!H975R9:`Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(Q"FUS9VED
M(")496UP97)A='5R92(*;7-G<W1R(")496UPZ7)A='5R92(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3(*;7-G:60@(E1E;7!E<F%T=7)E
M.B`B"FUS9W-T<B`B5&5M<.ER871U<F6@.B`B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C@R"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E
M<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B
M5&5M<.ER871U<F4\8G(@+SXH)7-(825S+R5S0F$E<RD@)F1E9SLE<R(*"B,Z
M(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-CDU"B,L('!H<"UF
M;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S
M='(@(E!R;V9I;""KH"5SH+L@;F]N('1R;W5VZ2(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*
M;7-G<W1R(")!9&UI;FES=')A=&EO;B!D97,@;6]DZ&QE<R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,#@@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S,R-`IM<V=I9"`B5&5X="(*;7-G<W1R(")497AT92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-SD*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R
M(")497AT92!S975L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R
M(")!;&EG;F5M96YT(&1U('1E>'1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R
M(")497AT92!E;B!H875T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`B2F4B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5&AA:2`H5$E3+38R,"DB
M"FUS9W-T<B`B5&AA[R`H5$E3+38R,"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED
M(")4:&%I;&%N9"(*;7-G<W1R(")4:&'O;&%N9&4B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@U,0IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@
M:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3"=E>'1E;G-I;VX@1E10(&XG
M97-T('!A<R!D:7-P;VYI8FQE+B(*"B,Z(&9R86UE=V]R:R](:7-T;W)Y+TAI
M<W1O<GDN<&AP.C4U"FUS9VED(")4:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES
M86)L960N(@IM<V=S='(@(DPG:&ES=&]R:7-A=&EO;B!E<W0@9.ES86-T:7;I
M92XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG
M:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(DQE(&UO=&5U
M<B!D)VEN=.EG<F%T:6]N($AO<F1E+TMO;&%B(&YE('-U<'!O<G1E('!A<R"K
MH"5SH+LB"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]";V]K+G!H<#HQ
M,CDX"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI
M>F5D+B(*;7-G<W1R("),92!J;W5R;F%L($E-4U`@;B=A('!A<R!P=2#J=')E
M(&EN:71I86QI<^DN(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q
M"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@
M<W5C8V5S<V9U;&QY(@IM<V=S='(@(DQA(&-L87-S92!-86EN=&5N86YC93HZ
M(&XG82!P87,@Z73I(&-H87)GZ64@8V]R<F5C=&5M96YT(@H*(SH@<V5R=FEC
M97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO
M;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(DQA(&9E
M;NIT<F4@9&5S(&]P=&EO;G,@<R=E<W0@9F5R;>EE+B!3;W)T:64N(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR
M,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C0@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES
M=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S
M:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N
M<RXB"FUS9W-T<B`B(@HB3"=A9&UI;FES=')A=&5U<B!D;VET(&-O;F9I9W5R
M97(@=6X@8F%C:V5N9"!P97)M86YE;G0@<&]U<B!L97,@<&5R;6ES<VEO;G,@
M(@HB<VD@=F]U<R!V;W5L97H@;&5S(&5M<&QO>65R+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@
M(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(DQA(&)O<F1U<F4@9'4@
M8F%S('-E=6QE;65N="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N
M=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO
M="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*(DPG240@
M9'4@8V]N=&%C="!N)V$@<&%S(.ETZ2!S<.EC:69IZ2P@;&%I<W/I('9I9&4@
M;W4@;B=A('!A<R#I=.D@=')O=7;I(&1A;G,@(@HB;&$@8F%S92!D92!D;VYN
MZ65S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E
M9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B0V4@8V]N=&%C="!A
M(&)I96X@Z73I(&%J;W5TZ2#@('9O=')E(&-A<FYE="!D)V%D<F5S<V5S+B`B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3<R"FUS9VED
M("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U
M:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B
M"B),92!B;&]C(&1E('-I9VYA='5R92!01U`@<^EP87+I(&5S="!NZ6-E<W-A
M:7)E('!O=7(@=NER:69I97(@;&$@<VEG;F%T=7)E+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B
M"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E
M8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T
M86)A<V4N(@IM<V=S='(@(B(*(DPG240@9&4@;&$@;&ES=&4@;B=A('!A<R#I
M=.D@<W#I8VEF:>DL(&QA:7-SZ2!V:61E(&]U(&YO;B!T<F]U=ND@9&%N<R!L
M82`B"B)B87-E(&1E(&1O;F[I97,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB
M=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B3&$@;&ES
M=&4@9&4@9&ES=')I8G5T:6]N(&XG82!P87,@Z73I('-PZ6-I9FGI92XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q-@IM<V=I9"`B5&AE(&5N
M8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C
M=&EO;BXB"FUS9W-T<B`B3&4@8VAI9F9R96UE;G0@;NEC97-S:71E('5N92!C
M;VYN97AI;VX@<^EC=7)I<^EE+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3@V(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3(X"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@
M)7,@<V5T=&EN9RXB"FUS9W-T<B`B3&4@9FEC:&EE<B`E<R!D;VET(&-O;G1E
M;FER(&QE<R!O<'1I;VYS("5S+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$X"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O
M;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(DQE(&9I8VAI97(@)7,@9&]I="!C
M;VYT96YI<B!C97)T86EN97,@;W!T:6]N<R`E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR,C8*;7-G:60@(E1H92!F:6QE(&-A;FYO="!B
M92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@(DQE(&9I8VAI97(@;F4@
M<&5U="!P87,@ZG1R92!C;W!IZ2!S=7(@;'5I+6WJ;64N(@H*(SH@9G)A;65W
M;W)K+T1A=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN
M960@;F\@9&%T82XB"FUS9W-T<B`B3&4@9FEC:&EE<B!N92!C;VYT96YA:70@
M875C=6YE(&1O;F[I92XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@
M:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G
M<W1R(")#92!Q=6D@<W5I="!S;VYT(&QE<R!E;BUTZG1E<R!P;W5R(&-E(&UE
M<W-A9V4@;65S<V%G92]21D,X,C(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R
M965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E
M<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E
M('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R
M:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC
M=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y
M;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA
M="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@
M86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D
M+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R
M>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"B),92!M;V1E
M('!L96EN(.EC<F%N(&-A=7-E(&1E<R!P<F]B;.AM97,@879E8R!);G1E<FYE
M="!%>'!L;W)E<B!D^R#@(&1E<R`B"B)B;V=U97,@9'4@;F%V:6=A=&5U<B!Q
M=6D@;B=O;G0@<'4@ZG1R92!C;VYT;W5R;NES+B!6;W5S('!O=79E>B#J=')E
M("(*(F-O;F9R;VYTZ7,@X"!D92!L)V%F9FEC:&%G92!D92!C87)A8W3H<F5S
M(.ET<F%N9V5S+"!A=2!N;VXM9F]N8W1I;VYN96UE;G0@(@HB9&5S(&-E<G1A
M:6YE<R!F;VYC=&EO;G,@970O;W4@874@<&QA;G1A9V4@86SI871O:7)E(&1U
M(&YA=FEG871E=7(N(%-I('9O=')E("(*(G-Y<W3H;64@97-T('5N(%=I;F1O
M=W,@.7@L(&EL(&5S="!T<NAS('!O<W-I8FQE('%U92!V;W5S(&%U<F5Z('5N
M92`G1F%U=&4@(@HB9^ENZ7)A;&4@9&4@<')O=&5C=&EO;B<@970@<75E('9O
M=7,@9&5V<F5Z(')E9.EM87)R97(@=F]T<F4@;W)D:6YA=&5U<BY<7&XB"B)<
M7&Y6;W5S(&%V97H@Z73I('!RZ79E;G5S+B!35E`@87!P=7EE>B!S=7(@3TL@
M<VD@=F]U<R!V;W5L97H@=&]U:F]U<G,@(@HB97-S87EE<B!L92!M;V1E('!L
M96EN(.EC<F%N(&1E(&PGZ61I=&5U<B(*"B,Z('-E<G9I8V5S+W!R969S+G!H
M<#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<
M(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("),)VED96YT:73I(*N@)7.@
MNR`@82#I=.D@<W5P<')I;>EE+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA
M;F0@<VED92!O;FQY(@IM<V=S='(@(DQE(&/T=.D@9V%U8VAE('-E=6QE;65N
M="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$U-PIM<V=I
M9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B
M92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(B(*
M(DPG96UP;&%C96UE;G0@9'4@<')O9W)A;6UE($=N=5!'(&1O:70@ZG1R92!F
M;W5R;FD@X"!L82!C;&%S<V4@0W)Y<'1?<&=P.CHN(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-1$XN<&AP.C(P,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<
M(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R
M86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R
M<W1O;V0N(@IM<V=S='(@(B(*(DQE(&UE<W-A9V4@96YV;WGI(&QE("5S(.`@
M)7,@879E8R!C;VUM92!S=6IE=""KH"5SH+L@82#I=.D@869F:6-HZ2X@7&XB
M"B));"!N)WD@82!A=6-U;F4@9V%R86YT:64@<75E(&-E(&UE<W-A9V4@82#I
M=.D@;'4@;W4@8V]M<')I<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#<T"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O
M('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B3&4@;F]M(.`@=71I;&ES97(@
M96X@;&EA;G0@X"!L82!P86=E(&1E(&-O;7!O<VET:6]N(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#<T"FUS9VED(")4:&4@;G5M8F5R(&]F
M(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@(DQE(&YO;6)R92!D
M92!C:&%M<',@9&]I="#J=')E('5N(&YO;6)R92!V86QI9&4N(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C,R"FUS9VED(")4:&4@
M;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP
M=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R("),92!M;V1U;&4@3W!E;E-33"!E
M<W0@<F5Q=6ES('!O=7(@;&$@8VQA<W-E($AO<F1E7T-R>7!T7W-M:6UE.CHN
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H<#HR.34*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO
M="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M
M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*(DQA('!RZ6;I<F5N
M8V4@JZ`E<Z"[(&XG82!P87,@<'4@ZG1R92!E;G)E9VES='+I92!C87(@<V$@
M=&%I;&QE(&3I<&%S<V4@;&4@(@HB;6%X:6UU;2!A=71O<FESZ2(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T
M:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E
M;2XB"FUS9W-T<B`B(@HB3&4@<')O9W)A;6UE('5T:6QI<^D@<&]U<B!V:7-U
M86QI<V5R(&-E('1Y<&4@9&4@9&]N;NEE<R`H)7,I(&XG82!P87,@Z73I("(*
M(G1R;W5VZ2XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT.#<*
M;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE
M(&-H87)A8W1E<BXB"FUS9W-T<B`B3&4@8V%R86-TZ')E(&1E('!R;W1E8W1I
M;VX@9&]I="#J=')E('5N(&-A<F%C=.AR92!U;FEQ=64N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I
M9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B3&5S
M(&/T=.ES(&=A=6-H92!E="!D<F]I="!S975L96UE;G0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED
M(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B3&4@8_1TZ2!D
M<F]I="!S975L96UE;G0B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HT-SD*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE
M(&-H87)A8W1E<BXB"FUS9W-T<B`B3&4@<^EP87)A=&5U<B!D;VET(.IT<F4@
M=6X@8V%R86-TZ')E('5N:7%U92XB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C
M<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB
M)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("),92!S97)V975R(*N@
M)7.@NR!A(.ETZ2!S=7!P<FEMZ2XB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C
M<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB
M)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B3&4@<V5R=F5U<B"KH"5S
MH+L@82#I=.D@96YR96=I<W1RZ2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E
M<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("),82!R97%UZG1E(&0G96YR
M96=I<W1R96UE;G0@<&]U<B`E<R!A(.ETZ2!DZ7!L86/I92XB"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0W,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@
M;F]T(&5X:7-T+B(*;7-G<W1R("),82!L:6=N92!D96UA;F3I92`H)60I(&XG
M97AI<W1E('!A<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$W
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E
M<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("),92!F:6-H:65R('1E;7!O
M<F%I<F4@JR`E<Z"[(&XG97AI<W1E('!A<RXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,CDY"FUS9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D
M:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@
M(DQE('1E>'1E(&5N='+I(&YE(&-O<G)E<W!O;F0@<&%S(&%U('1E>'1E('-U
M<B!L)^EC<F%N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S
M:61E<R!O;FQY(@IM<V=S='(@(DQE(&AA=70@970@;&4@8F%S('-E=6QE;65N
M="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(DQE
M(&AA=70@<V5U;&5M96YT(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z
M,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T
M:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B(@HB3&5S(&1O;F[I97,@=.EL
MZ6-H87)GZ65S('9E<G,@;&4@<V5R=F5U<B!O;G0@Z73I('!E<F1U97,@9&5P
M=6ES(&PGZ71A<&4@(@HB<'+I8^ED96YT92X@(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP
M:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@
M<V%V960N(@IM<V=S='(@(DQE(&9I8VAI97(@Z6UI<R!N)V$@<&%S('!U(.IT
M<F4@96YR96=I<W1RZ2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-#D@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q,`IM<V=I9"`B
M5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(DQE(&)L;V,@JZ!W96%T:&5R+F-O;:"[(&XG97-T('!A<R!D:7-P;VYI
M8FQE+B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(E+I<&5R=&]I<F4@9&5S('1HZ&UE<R"KH"5SH+L@;F]N('1R
M;W5VZ2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X"FUS
M9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@
M(DEL(&XG>2!A('!A<R!D)V]P=&EO;G,@9&ES<&]N:6)L97,B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HS-#@*;7-G:60@(E1H97)E
M(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*
M;7-G<W1R(")!=6-U;F4@<&%R=&EE(&YE('!E=70@ZG1R92!A9F9I8VCI92!E
M;B!L:6=N92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,SDX"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R
M86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA
M<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G
M<W1R("(B"B));"!Y("!A('1R;W`@9&4@8V%R86-TZ')E<R!D86YS(&-E(&-H
M86UP+B!6;W5S(&5N(&%V97H@96YT<ND@)7.@.R!I;"!E;B!F875T("(*(FUO
M:6YS(&1E("5S+B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z
M-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A
M9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(E5N('!R
M;V)LZ&UE(&5S="!A<'!A<G4@;&]R<R!D92!L)V%J;W5T(&1E(*N@)7.@NZ`Z
M("5S(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E
M<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@HB56X@<')O
M8FSH;64@97-T(&%P<&%R=2!L;W)S(&1E(&QA('-U<'!R97-S:6]N(&1E<R!D
M;VYNZ65S(&1E(&PG=71I;&ES871E=7(@(@HBJZ`E<Z"[H#H@(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@
M(@IM<V=S='(@(E5N('!R;V)LZ&UE(&5S="!A<'!A<G4@;&]R<R!D92!L82!S
M=7!P<F5S<VEO;B!D92"KH"5SH+N@.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U
M<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@(E5N('!R;V)LZ&UE(&5S="!A
M<'!A<G4@;&]R<R!D92!L82!M:7-E(.`@:F]U<B!D92"KH"5SH+N@.B`E<R(*
M"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDR-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I
M;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(B(*(E5N
M('!R;V)LZ&UE(&5S="!A<'!A<G4@;&]R<R!D92!L)V5N=F]I(&1U(&9I8VAI
M97*@.B!A=6-U;B`E<R!N)V$@Z73I("(*(G1R86YS;6ES+B(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDS,@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L
M;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"B)5;F4@97)R975R
M(&5S="!S=7)V96YU92!L;W)S(&1E(&PG96YV;VD@9'4@9FEC:&EE<J`Z(&QE
M("5S(.ET86ET('!L=7,@9W)O<R`B"B)Q=64@;&4@;6%X:6UU;2!A=71O<FES
MZ2`H)60@;V-T971S*2XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R
M+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY
M('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@HB56YE(&5R<F5U<B!E
M<W0@<W5R=F5N=64@;&]R<R!D92!L)V5N=F]I(&1U(&9I8VAI97*@.B!L92`E
M<R!A(.ETZ2!T<F%N<VUI<R`B"B)P87)T:65L;&5M96YT+B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T
M(@IM<V=S='(@(B(*(E5N92!E<G)E=7(@<R=E<W0@<')O9'5I=&4@;&]R<R!D
M92!L)V%F9FEC:&%G92!D92!C971T92!P87)T92!D=2!M97-S86=E(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A
M+B(*;7-G<W1R("(B"B)5;F4@97)R975R(',G97-T('!R;V1U:71E(&QO<G,@
M9&4@;"=I;7!O<G1A=&EO;B!D97,@9&]N;NEE<R!D92!C92!C;VYT86-T+B(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N
M(@IM<V=S='(@(B(*(E5N92!E<G)E=7(@<R=E<W0@<')O9'5I=&4@;&]R<R!D
M92!L)VEM<&]R=&%T:6]N(&1E(&-E='1E(&-A<G1E(&E#86QE;F1A<BXB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@R"FUS9VED("(B"B)4:&5R92!W
M87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P
M<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B
M(@HB26P@>2!A=F%I="!U;F4@97)R975R(&1A;G,@;&4@9F]R;75L86ER92!D
M92!C;VYF:6=U<F%T:6]N+B!0975T+>IT<F4@879E>BTB"B)V;W5S(&QA:7-S
MZ2!U;B!C:&%M<"!R97%U:7,@=FED92XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S
M(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM
M<V=S='(@(B(*(E5N92!E<G)E=7(@<R=E<W0@<')O9'5I=&4@;&]R<R!D92!L
M)V5XZ6-U=&EO;B!D92!C971T92!F;VYC=&EO;B!D=2!C87)N970@(@HB9"=A
M9')E<W-E+B!35E`@97-S87EE<B#@(&YO=79E874@<&QU<R!T87)D+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P
M"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O
M;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T
M<B`B(@HB26P@>2!A(&5U('5N92!E<G)E=7(@;&]R<R!D92!L82!M:7-E(.`@
M:F]U<B!D97,@:6YF;W)M871I;VYS('-U<B!L92`B"B)C;VYT86-T+B`@5F5U
M:6QL97H@97-S87EE<B#@(&YO=79E874N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A
M<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(DEL('D@82!E=2!U
M;F4@97)R975R(&QO<G,@9&4@;&$@;6ES92#@(&IO=7(@9&4@;&$@;&ES=&4@
M9&4@9&ES=')I8G5T:6]N+B`@(@HB5F5U:6QL97H@97-S87EE<B!D92!N;W5V
M96%U+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C$T.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T
M('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B3&4@<'+I<V5N="!S97)V975R
M($E-05`@;F4@<W5P<&]R=&4@<&%S(&QE('!A<G1A9V4@9&4@9&]S<VEE<G,N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HT.`IM
M<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@
M87)C:&EV92XB"FUS9W-T<B`BQV$@;F4@<V5M8FQE('!A<R#J=')E('5N92!A
M<F-H:79E(%)!4B!V86QI9&4N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`BQV$@;F4@<V5M8FQE
M('!A<R#J=')E('5N(&9I8VAI97(@6DE0('9A;&ED92XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3(T"FUS9VED(")4:&ES(&1O97,@;F]T('-E
M96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`BQV$@;F4@
M<V5M8FQE('!A<R#J=')E('5N(&YU;>ER;R!D92!C87)T92!V86QI9&4N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI
M8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G
M<W1R("(B"B)#92!P:6QO=&4@<&5R;65T(&PG96YV;VD@9&4@;65S<V%G97,@
MX"!T<F%V97)S(&QA('!A<W-E<F5L;&4@0VQI8VMA=&5L;"`B"B(H:'1T<#HO
M+V-L:6-K871E;&PN8V]M*2!E;B!U=&EL:7-A;G0@;"=!4$D@2%144"(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y
M+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB0V4@<&EL;W1E('!E
M<FUE="!L)V5N=F]I(&1E(&UE<W-A9V5S('9I82!L82!P87-S97)E;&QE(%=)
M3B`H:'1T<#HO+W=I;G!L8RXB"B)C;VTI(&5N('5T:6QI<V%N="!L)T%022!(
M5%10(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*
M(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*
M;7-G<W1R("(B"B)#92!P:6QO=&4@<&5R;65T(&PG96YV;VD@9&4@;65S<V%G
M97,@X"!T<F%V97)S(&QA('!A<W-E<F5L;&4@<VUS,F5M86EL("(*(BAH='1P
M.B\O<VUS,F5M86EL+F-O;2D@96X@=71I;&ES86YT(&PG05!)($A45%`B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@
M(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U
M:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@
M*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@HB0V4@<&EL;W1E('!E
M<FUE="!L)V5N=F]I(&1E(&UE<W-A9V5S('!A<B!33510(.`@=')A=F5R<R!L
M82!P87-S97)E;&QE("(*(E9O9&%F;VYE($ET86QI92P@<V5U;&5M96YT(&%U
M>"!N=6WI<F]S(%9O9&%F;VYE+B!#96QA(&[I8V5S<VET92!U;B!C;VUP=&4@
M9&4@(@HB8V]U<G)I96P@5F]D869O;F4@271A;&EE("AH='1P.B\O=W=W+C$Y
M,"YI="DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3<U(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$P-30*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3`X,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$R"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-SD@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(U,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`R(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.34*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,34U-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#,V"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-34@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`P,@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(V
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-S4*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$T-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C$X
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,#4@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C0T-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-C,T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#<*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$Q-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,CDT"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,#(@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S@Q,`IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U
M:7)E9"XB"FUS9W-T<B`B0V4@8VAA;7`@97-T(&]B;&EG871O:7)E+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C(*;7-G:60@(E1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B0V4@8VAA
M;7`@;F4@9&]I="!C;VYT96YI<B!Q=64@9&5S(&5N=&EE<G,N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q,PIM<V=I9"`B5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T
M<B`B0V4@8VAA;7`@;F4@9&]I="!C;VYT96YI<B!Q=64@9&5S(&YO;6)R97,@
M970@;&5S(&1E=7@M<&]I;G1S+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P.3$*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O
M8W1A;"!V86QU97,N(@IM<V=S='(@(D-E(&-H86UP(&YE(&1O:70@8V]N=&5N
M:7(@<75E(&1E<R!V86QE=7)S(&]C=&%L97,N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$R,`IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@
M8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS
M9W-T<B`B(@HB0V4@8VAA;7`@9&]I="!C;VYT96YI<B!U;F4@;&ES=&4@9"=E
M;G1I97)S('/I<&%RZ7,@<&%R(&1E<R!V:7)G=6QE<R!O=2!D97,@(@HB97-P
M86-E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX-@IM<V=I9"`B
M5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R(")#
M92!C:&%M<"!D;VET(.IT<F4@=6X@;F]M8G)E('9A;&ED92XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U"FUS9VED("(B"B)4:&ES(&9I96QD
M(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R
M;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*(D-E
M(&-H86UP(&1O:70@8V]N=&5N:7(@=6X@8V]D92!D92!C;W5L975R(&%U(&9O
M<FUA="!21T(@:&5X863I8VEM86PL('!A<B`B"B)E>&5M<&QE("<C,3(S-&%F
M)RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-3@*;7-G:60@(E1H
M:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B
M0V4@9F]R;75L86ER92!A(&3I:N`@Z73I('1R86ETZ2XB"@HC.B!T96UP;&%T
M97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES
M(&ES("5S+B(*;7-G<W1R(")#)V5S="`E<RXB"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C0V.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES
M(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B
M:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N
M9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L
M:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B
M"FUS9W-T<B`B(@HB0V5C:2!E<W0@=6X@;V)J970@2V]L86(@1W)O=7!W87)E
M+B!0;W5R('9O:7(@8V5T(&]B:F5T+"!V;W5S(&1E=G)E>B!A=F]I<B!U;B`B
M"B)C;&EE;G0@9&4@8V]U<G)I96P@<75I(&-O;7!R96YD(&QE(&9O<FUA="!+
M;VQA8B!'<F]U<'=A<F4N(%!O=7(@=6YE(&QI<W1E(&1E("(*(F-E<R!C;&EE
M;G1S(&1E(&-O=7)R:65L+"!V:7-I=&5Z("5S(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z-3DW"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@
M*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"B)#92!M97-S
M86=E(&$@Z73I(.EC<FET(&1A;G,@=6X@8V]D92!D92!C87)A8W3H<F5S("@E
M<RD@875T<F4@<75E(&QE(';T=')E+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T
M(&QE87-T(&]N92XB"FUS9W-T<B`B0V4@;F]M8G)E(&1O:70@ZG1R92!S=7#I
M<FEE=7(@X"!U;BXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E
M<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R(")#92!S97)V975R(&YE
M('!E=70@<&%S(&3I8V]M<')E<W-E<B!L97,@9FEC:&EE<G,@6DE0(&5T(&=Z
M:7`N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ
M.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E
M9"XB"FUS9W-T<B`B0V4@<WES=.AM92!E<W0@<'+I<V5N=&5M96YT(&3I<V%C
M=&EVZ2XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-`IM
M<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R(")#
M971T92!V86QE=7(@9&]I="#J=')E('5N(&YO;6)R92XB"@HC.B!S97)V:6-E
M<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O
M=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S
M='(@(D-E='1E(&9E;NIT<F4@9&]I="#J=')E(&%P<&5LZ64@9&5P=6ES('5N
M92!F96[J=')E(&1E<R!O<'1I;VYS(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B
M5&]N;F5R<F4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,V"FUS
M9VED(")4:6-K971S(@IM<V=S='(@(E1I8VME=',B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-#(R('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(U-0IM<V=I9"`B5&EM92(*;7-G<W1R(")(975R92(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS.#@*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS
M9W-T<B`B4W5I=FD@:&]R86ER92(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ
M-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B1F]R;6%T(&0G:&5U<F4B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3(X"FUS9VED(")4:6UE
M('-E;&5C=&EO;B(*;7-G<W1R(")3Z6QE8W1I;VX@9&4@;"=H975R92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(E1I;6]R
M(&]R:65N=&%L(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET
M;&4B"FUS9W-T<B`B5&ET<F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM
M<V=S='(@(E1I=')E("AI;F9O8G5L;&4IH#HB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R
M("+`(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD
M(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B
M"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@HB4&]U<B!SZ6QE8W1I;VYN
M97(@<&QU<VEE=7)S(&ET96US(.`@;&$@9F]I<RP@;6%I;G1E;F5Z(&5N9F]N
M8^D@;&4@8F]U=&]N("(*(JN@0W1R;*"[("A00RD@;W4@JZ!#;VUM86YD9:"[
M("A-86,I(&5N(&-L:7%U86YT+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,#`*;7-G:60@(E1O9&%Y(@IM<V=S='(@(D%U:F]U<F0G:'5I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(E9O:7(@;&$@
M<V]U<F-E($A434PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4;V=O(@IM<V=S
M='(@(E1O9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U(@IM<V=S
M='(@(E1O:V5L874B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S`R"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R(")$96UA:6XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R(")4;VYG82(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:V]L86(N<&AP.C$P-`IM<V=I9"`B5&]O(&UA;GD@
M:6YV86QI9"!L;V=I;G,@9'5R:6YG('1H92!L87-T(&UI;G5T97,N(@IM<V=S
M='(@(E1R;W`@9&4@8V]N;F5X:6]N<R!I;F9R=6-T=65U<V5S(&1A;G,@;&5S
M(&1E<FYIZ')E<R!M:6YU=&5S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@
M(DAA=70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(D-A9')E
M(&1U(&AA=70@*%]T;W`I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S
M"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B5')A9'5C=&EO;G,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S
M='(@(E1R:6YI=.DM970M5&]B86=O(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3<X-PIM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R(")6<F%I
M(&]U(&9A=7@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R(")-82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B5'5N:7-I92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R(")4=7)Q=6EE(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y
M+3DI(@IM<V=S='(@(E1U<F,@*$E33RTX.#4Y+3DI(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(E1U<FMMZ6YI<W1A;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD
M<R(*;7-G<W1R("+.;&5S(%1U<G%U97,@970@0V'O<75E<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R(")4=79A;'4B"@HC.B!F<F%M
M97=O<FLO0TQ)+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E
M.B`B"FUS9W-T<B`B16YT<F5Z('9O=')E(&-H;VEXH#H@(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.`IM<V=I9"`B52Y6+B!I;F1E>#H@
M(@IM<V=S='(@(DEN9&EC92!55J`Z("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O
M<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@
M(E523"!P;W5R('9O=')E(')A<'!O<G0@9&4@;&EV<F%I<V]N(&1U('-C<FEP
M="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3<*;7-G:60@(E523#HB"FUS9W-T<B`B55),.B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*
M;7-G:60@(E5G86YD82(*;7-G<W1R(")/=6=A;F1A(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,@IM<V=I9"`B56MR86EN92(*;7-G<W1R(")5:W)A:6YE(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$Y"FUS9VED(")5;F%B;&4@=&\@86-C
M97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DEM<&]S<VEB;&4@9"=A='1E
M:6YD<F4@;&4@<NEP97)T;VER92!61E,N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A
M('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("))
M;7!O<W-I8FQE(&0G86IO=71E<B!D97,@:6YF;W)M871I;VYS(&-O;7!LZ6UE
M;G1A:7)E<R#@(&PG:6YS8W)I<'1I;VXN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HS.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(DEM<&]S<VEB;&4@9&4@;6]D:69I97(@;&5S('!E<FUI<W-I;VYS('!O
M=7(@;&4@9FEC:&EE<B!61E,@JZ`E<Z"[+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C,Y,B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R
M;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(DEM<&]S<VEB
M;&4@9&4@;6]D:69I97(@;&5S('!E<FUI<W-I;VYS('!O=7(@;&4@9FEC:&EE
M<B!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW
M.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E
M<RXB"FUS9W-T<B`B26UP;W-S:6)L92!D92!C:&%N9V5R('!O=7(@)7,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N
M(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@=NER:69I97(@;&$@=&%I;&QE(&1U
M(&9I8VAI97(@9&4@JZ`E<Z"[+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C8Y-2!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,C@*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@U,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O
M)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)L92!D92!VZ7)I9FEE<B!L82!T86EL
M;&4@9'4@9FEC:&EE<B!D92"K("5S+R5S(+LN(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S<6PN<&AP.C0S.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@
M=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B0V]N;F5X:6]N(&EM<&]S<VEB;&4@
M874@<V5R=F5U<B!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX-S`*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G
M<W1R(")#;VYN97AI;VX@:6UP;W-S:6)L92!E;B!34TPB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR,S(@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C,W"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR
M,#0@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P.0HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C$W"FUS9VED(")5;F%B;&4@
M=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B26UP;W-S:6)L92!D92!C;W!I
M97(@=6X@9FEC:&EE<B!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HS-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)L92!D
M92!C<NEE<B!U;B!RZ7!E<G1O:7)E(%9&4R"KH"5SH+LN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,S8Q(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C(V-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(*
M;7-G<W1R("));7!O<W-I8FQE(&1E(&-RZ65R('5N('+I<&5R=&]I<F4@5D93
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(DEM<&]S<VEB
M;&4@9&4@8W+I97(@;&4@9FEC:&EE<B!61E,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S
M:6)L92!D92!C<NEE<B!L92!RZ7!E<G1O:7)E(%9&4R"KH"5SH+LN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<R"FUS9VED(")5;F%B;&4@
M=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R("));7!O<W-I8FQE
M(&1E(&-RZ65R('5N(&9I8VAI97(@5D93('9I9&4N("(*"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW.0IM<V=I9"`B56YA8FQE('1O
M(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B3W5V97)T=7)E(&EM<&]S<VEB
M;&4@9&4@;"=A<F-H:79E(&-O;7!R97-SZ64N("(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,C(X(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,S`S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E
M<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B4W5P
M<')E<W-I;VX@:6UP;W-S:6)L92!D92"KH"5SH+LL(&QE(&1O<W-I97(@;B=E
M<W0@<&%S('9I9&4N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW."!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C0T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B4W5P<')E<W-I;VX@
M:6UP;W-S:6)L92!D92"KH"5SH+N@.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HS,S@@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS
M.34*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0R"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T
M(&5M<'1Y(@IM<V=S='(@(E-U<'!R97-S:6]N(&EM<&]S<VEB;&4@9&4@)7,L
M(&QE(&1O<W-I97(@;B=E<W0@<&%S('9I9&4B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,S4V(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HS-C`*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B4W5P<')E<W-I;VX@<NEC=7)S
M:79E(&1U(&1O<W-I97(@5D93(&EM<&]S<VEB;&4N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,S0T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,S-2!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B4W5P<')E<W-I;VX@9'4@<NEP
M97)T;VER92!61E,@:6UP;W-S:6)L92XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C0R,"!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0S,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E
M8W1O<GDZ("5S+B(*;7-G<W1R("));7!O<W-I8FQE(&1E('-U<'!R:6UE<B!L
M92!RZ7!E<G1O:7)E(%9&4Z`Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,C$R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")3=7!P<F5S<VEO;B!I
M;7!O<W-I8FQE(&1U(&9I8VAI97(@5D93(*N@)7.@NRXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HS,3`@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HR.3$*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C,Y,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,SDY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R
M(")3=7!P<F5S<VEO;B!I;7!O<W-I8FQE(&1U(&9I8VAI97(@5D93+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C0X"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM
M<V=S='(@(E-U<'!R97-S:6]N(&EM<&]S<VEB;&4@9'4@<NEP97)T;VER92!6
M1E,@JZ`E<Z"[+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#`Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E
M8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B4W5P<')E<W-I;VX@5D93('+I8W5R
M<VEV92!I;7!O<W-I8FQEH#H@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX,S0*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N
M="!D:7)E8W1O<GDN(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@9.ET97)M:6YE
M<B!L92!D;W-S:65R(&-O=7)A;G0N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV,#0*;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E
M<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B26UP;W-S:6)L92!D)V5X=')A
M:7)E(&QE<R!DZ71A:6QS(&1U(&-E<G1I9FEC870B"@HC.B!F<F%M97=O<FLO
M3F5T7TE-4U`O24U34"YP:'`Z-#,W(&9R86UE=V]R:R].971?24U34"])35-0
M+T%U=&@N<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B26UP;W-S:6)L
M92!D92!C:&%R9V5R(&QA(&3I9FEN:71I;VX@9&4@)7,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`S(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C(P.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,3<T(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-SD*;7-G:60@
M(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R("));7!O<W-I8FQE
M(&1E(&3I<&QA8V5R(&QE(&9I8VAI97(@5D93+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z.3,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ
M,#8*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV-3(@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HY.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB
M;&4@9"=O=79R:7(@;&4@9FEC:&EE<B!61E,@JZ`E<Z"[+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X-"!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ-#$*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W
M<FET:6YG+B(*;7-G<W1R("));7!O<W-I8FQE(&0G;W5V<FER('5N(&9I8VAI
M97(@5D93(&5N(.EC<FET=7)E+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C@S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S-PHC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S8*;7-G:60@(E5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R("));7!O<W-I8FQE(&0G;W5V
M<FER('5N(&9I8VAI97(@5D93+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R
M97-S960@87)C:&EV92XB"FUS9W-T<B`B3W5V97)T=7)E(&EM<&]S<VEB;&4@
M9&4@;"=A<F-H:79E(&-O;7!R97-SZ64N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C@U-@IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I
M;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B26UP;W-S:6)L92!D92!L:7)E
M(&QE(&9I8VAI97(@5D93("CI8VAE8R!D92!F:6QE<VEZ92@I*2XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z.#@W"FUS9VED(")5;F%B;&4@=&\@<F5A
M9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G<W1R("))
M;7!O<W-I8FQE(&1E(&QI<F4@;&4@9FEC:&EE<B!61E,@*.EC:&5C(&1E(&=E
M=$9I;&53:7IE*"DI+B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]3
M97-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA8FQE('1O(')E
M860@9FEL93H@(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@;&ER92!L92!F:6-H
M:65RH#H@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C<V"FUS
M9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM
M<V=S='(@(DQE8W1U<F4@9'4@<NEP97)T;VER92!R86-I;F4@5D93(&EM<&]S
M<VEB;&4N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3`Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z
M(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R("))
M;7!O<W-I8FQE(&1E(')E;F]M;65R("5S(&5N("5SH#H@;&4@9&]S<VEE<B!C
M:6)L92!E>&ES=&4@9.EJX"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HS,#$*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B26UP;W-S:6)L92!D92!R96YO;6UE<B!L92!RZ7!E
M<G1O:7)E(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,S
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDZ("5S+B(*;7-G<W1R("));7!O<W-I8FQE(&1E(')E;F]M;65R
M(&QE('+I<&5R=&]I<F4@5D93H#H@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HR-S$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@<F5N;VUM97(@;&4@
M9FEC:&EE<B!61E,@JZ`E<Z"[+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C8Q-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@
M)7,O)7,N(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@<F5N;VUM97(@;&4@9FEC
M:&EE<B!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HS,C8@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q,PHC.B!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#4R(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HR.3,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C,P.0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB
M"FUS9W-T<B`B26UP;W-S:6)L92!D92!R96YO;6UE<B!L92!F:6-H:65R(%9&
M4RXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI
M<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*
M;7-G<W1R("));7!O<W-I8FQE(&0G97CI8W5T97(@)VUK:7-O9G,G+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G
M:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM
M<V=S='(@(DEM<&]S<VEB;&4@9&4@=')A9'5I<F4@8V4@9&]C=6UE;G0@5V]R
M9"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U-"!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C$U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("));7!O
M<W-I8FQE(&0GZ6-R:7)E(&QE(&9I8VAI97(@5D93(*N@)7.@NRXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ.#8*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(DEM
M<&]S<VEB;&4@9"?I8W)I<F4@;&5S(&1O;F[I97,@9'4@9FEC:&EE<B!61E,@
M*&-O<'DH*2!I;7!O<W-I8FQE*2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR.#@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T
M-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,34Q"FUS9VED
M(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B26UP
M;W-S:6)L92!D)^EC<FER92!L97,@9&]N;NEE<R!D=2!F:6-H:65R(%9&4RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8R"FUS9VED(")5;F%B;&4@
M=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM
M<V=S='(@(DEM<&]S<VEB;&4@9"?I8W)I<F4@;&4@9FEC:&EE<B!61E,L(&QE
M('%U;W1A('-E<F%I="!DZ7!A<W/I+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G
M<W1R(")3;W5L:6=N97(B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV
M"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B06YN=6QE<B!L97,@8VAA
M;F=E;65N=',B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G
M<W1R(")!;FYU;&4@=F]T<F4@9&5R;FGH<F4@86-T:6]N(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(Q"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.`IM<V=I9"`B56YE>'!E
M8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS
M9W-T<B`B4NEP;VYS92!I;F%T=&5N9'5E(&1U('-E<G9E=7(@;&]R<R!D92!L
M82!C;VYN97AI;VZ@.B`B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HR,3<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S,Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,W-@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS.#(*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V
M97(@=&\Z("(*;7-G<W1R(")2Z7!O;G-E(&EN871T96YD=64@9'4@<V5R=F5U
M<B#@H#H@(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B2&]R<R!C873I
M9V]R:64B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B56YI
M8V]D92`H551&+3@I(@IM<V=S='(@(E5N:6-O9&4@*%541BTX*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R("+)
M;6ER871S($%R86)E<R!5;FES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET
M960@2VEN9V1O;2(*;7-G<W1R(")2;WEA=6UE+55N:2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`BR71A=',M56YI<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T
M;'EI;F<@27-L86YD<R(*;7-G<W1R("+.;&5S(&5X=.ER:65U<F5S(&1E<R#)
M=&%T<RU5;FES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8R
M(&QI8B]";&]C:R]M971A<BYP:'`Z-S@*;7-G:60@(E5N:71S(@IM<V=S='(@
M(E5N:73I<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R
M.2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,S`*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HU.`IM<V=I9"`B56YK;F]W
M;B(*;7-G<W1R("));F-O;FYU(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US
M9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(F%P:6US9VED(&EN8V]N
M;G4@*$%022!-97-S86=E($E$*2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI
M;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B8VQI;7-G:60@
M:6YC;VYN=2`H0VQI96YT($UE<W-A9V4@240I+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-#<*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@
M<')O=FED960N(@IM<V=S='(@(D5M<&QA8V5M96YT('/I;&5C=&EO;F[I(&EN
M8V]N;G4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W
M;W)D+B(*;7-G<W1R(").;VT@9"=U=&EL:7-A=&5U<B!O=2!M;W0@9&4@<&%S
M<V4@:6YC;VYN=2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N
M="!E;&5M96YT(@IM<V=S='(@(D3I;&EE<B!L)^ELZ6UE;G0@8V]U<F%N="(*
M"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R"FUS9VED
M(")5;FYA;65D(@IM<V=S='(@(E-A;G,@;F]M(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV
M:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P
M<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC
M:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W
M:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C
M8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"B),97,@<V-R:7!T<R!N
M;VXM<')I=FELZ6=IZ7,@;F4@<&5U=F5N="!A8V/I9&5R(&%U>"!F;VYC=&EO
M;G,@8V]U<&5R+V-O<&EE<B\B"B)C;VQL97(@<&]U<B!D97,@<F%I<V]N<R!D
M92!SZ6-U<FETZ2X@07!P=7EE>B!S=7(@3TL@<&]U<B!V;VER('5N92!N;W1E
M("(*(G1E8VAN:7%U92!S=7(@;6]Z:6QL82YO<F<@<75I('9O=7,@97AP;&EQ
M=65R82!C;VUM96YT(&%U=&]R:7-E<B!U;B!S8W)I<'0@X"`B"B)U=&EL:7-E
M<B!L92!P<F5S<V4M<&%P:65R<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R
M(@IM<V=S='(@(E)E;65T=')E(&QA(&-O=6QE=7(@X"!ZZ7)O(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#<@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C<*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HY,S,*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO
M;B(*;7-G<W1R(")%>'1E;G-I;VX@;F]N('!R:7-E(&5N(&-O;7!T92(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B
M36]D:69I97(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R(")-
M;V1I9FEE<B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-S8*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(DUO9&EF:65R(&PG
M=71I;&ES871E=7(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T
M<B`B36ES92#@(&IO=7(@9&4@JZ`E<Z"[+B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*
M;7-G<W1R("),92!S8W)I<'0@9&4@;6ES92#@(&IO=7(@97-T('-U<'!R:6WI
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DX"FUS9VED(")5<&QO860B"FUS
M9W-T<B`B0VAA<F=E<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#8*
M;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T
M;R!T:&4@<V5R=F5R+B(*;7-G<W1R("(B"B)4;W5S(&QE<R!F:6-H:65R<R!D
M92!C;VYF:6=U<F%T:6]N(&1E<R!A<'!L:6-A=&EO;G,@;VYT(.ETZ2!E;G9O
M>>ES('-U<B!L92`B"B)S97)V975R+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R
M(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B3&5T=')E<R!L871I;F5S(&UA:G5S
M8W5L97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM
M<V=S='(@(DYO;6)R97,@<F]M86EN<R!M86IU<V-U;&5S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R(")5<G5G=6%Y(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(D5M
M<&QO>>D@86-T=65L;&5M96YTH#H@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*
M;7-G<W1R(")5=&EL:7-E<B!34TPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3(W"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E
M;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R("(B"B)5=&EL:7-E<B!S:2!L
M92!N;VT@9"=U=&EL:7-A=&5U<B]M;W0@9&4@<&%S<V4@97-T(&1I9F;I<F5N
M="!D=2!S97)V975R($E-4U`N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHR,0IM<V=I9"`B57-E<B(*;7-G<W1R(")5=&EL:7-A=&5U
M<B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S<T
M"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES
M960@9F]R("5S+B(*;7-G<W1R("),)W5T:6QI<V%T975R("5S(&XG82!P87,@
M;"=A=71O<FES871I;VX@<&]U<B`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HR
M,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI
M<W1R871I;VX@9&5S('5T:6QI<V%T975R<R(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,C0U"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T
M<B`B4'+I9NER96YC97,@<&5R<V]N;F5L;&5S(@H*(SH@<VEG;G5P+G!H<#HV
M,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B16YR96=I<W1R
M96UE;G0@9&5S('5T:6QI<V%T975R<R(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G
M:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T
M:&ES('-I=&4N(@IM<V=S='(@(DPG96YR96=I<W1R96UE;G0@9"=U=&EL:7-A
M=&5U<B!E<W0@9.ES86-T:7;I('-U<B!C92!S>7-TZ&UE+B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@86-C;W5N="!N;W0@
M9F]U;F0B"FUS9W-T<B`B0V]M<'1E('5T:6QI<V%T975R(&YO;B!T<F]U=NDB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R
M(").;VT@9"=U=&EL:7-A=&5U<B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@
M7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("),92!N;VT@9&4@8V]N
M;F5X:6]N(*N@)7.@NR!E>&ES=&4@9.EJX"XB"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(").
M;VT@9"=U=&EL:7-A=&5U<J`Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(").;VT@9"=U=&EL
M:7-A=&5U<J`Z("(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(E5T:6QI
M<V%T975R<R!DZ69I;FESH#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5>F)E
M:VES=&%N(@IM<V=S='(@(D]U>F+I:VES=&%N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,3<P(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(V,@IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS
M9W-T<B`B4NEP97)T;VER92!61E,@:6YE>&ES=&%N="XB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3(P"FUS9VED(")686-A=&EO;B(*;7-G<W1R
M(")!8G-E;F-E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V,PIM
M<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R
M("),97,@96UP;&%C96UE;G1S('9A;&ED97,@=')O=7;I<R!I;F-L=65N=*`Z
M("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS
M9VED(")686QI9&ET>2(*;7-G<W1R(")686QI9&ETZ2(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I
M9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B5F%L975R
M(&5N(&UI;G5T97,@X"!P87)T:7(@9&4@;6%I;G1E;F%N="XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX-3,@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3$W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I<R!O=F5R('1H
M92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B5F%L975R('-U<.ER
M:65U<F4@X"!L82!L;VYG=65U<B!M87AI;6%L92!D92`E<RXB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0Q(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(R-C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q,R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3`W"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R
M(")686QE=7)S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@S"FUS9VED(")686QU97,@=&\@
M<V5L96-T(&9R;VTB"FUS9W-T<B`B5F%L975R<R#@('/I;&5C=&EO;FYE<B!D
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B5F%N
M=6%T=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S,*;7-G
M:60@(E9A<FEA8FQE(@IM<V=S='(@(E9A<FEA8FQE(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(E;I;NEZ=65L82(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I
M9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@
M=&%M<&5R960@=VET:"XB"FUS9W-T<B`BR6-H96,@9&4@;&$@=NER:69I8V%T
M:6]N("9M9&%S:#L@8V4@;65S<V%G92!A('!E=70MZG1R92#I=.D@9F%L<VEF
M:>DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*
M;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B5F5R<VEO;B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR,C@*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*
M;7-G<W1R(")#;VYT<O1L92!D92!V97)S:6]N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R
M=&EC86P@86QI9VXB"FUS9W-T<B`B06QI9VYE;65N="!V97)T:6-A;"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G
M:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B4F5M<&QI<W-A9V4@=F5R
M=&EC86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B5F5R=&EC86R@.B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS
M9VED(")697)Y($AI9V@B"FUS9W-T<B`B5'+H<R!H875T92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,38*;7-G:60@(E9I970@3F%M(@IM<V=S='(@(E9I971N86TB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-PIM<V=I9"`B5FEE=&YA;65S92`H5DE3
M0TE)*2(*;7-G<W1R(")6:>IT+6YA;6EE;B`H5DE30TE)*2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDV.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")6:65W("5S(@IM<V=S='(@(E9O:7(@)7,B"@HC.B!L:6(O0FQO
M8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P
M86=E(@IM<V=S='(@(E9O:7(@=6YE('!A9V4@=V5B(&5X=&5R;F4B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R(")6;VER(&-O;6UE("5S
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I
M<V@B"FUS9W-T<B`BSFQE<R!6:65R9V5S(&)R:71A;FYI<75E<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@
M(LYL97,@5FEE<F=E<R!D97,@R71A=',M56YI<R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C$V"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(E9I<VEB
M:6QI=.DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4R"FUS
M9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B5FES:6)I;&ETZ:`Z("(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP
M.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R(")6
M;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G
M:60@(E=!4DXB"FUS9W-T<B`B3D]424-%(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!2
M14U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(D%45$5.
M5$E/3B$A(2`@4U504%))3452($Q%(%-#4DE05"!-04Y514Q,14U%3E0@1$4@
M)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S
M,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(E=)3B!V:6$@2%144"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S
M='(@(E=A;&QI<R!E="!&=71U;F$B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R-R!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B071T
M96YT:6]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B364B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B
M"FUS9W-T<B`B4'+I=FES:6]N<R!MZ73I;R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT,38*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E
M9"!B>2(*;7-G<W1R(")$;VYNZ65S(&WI=.EO(&9O=7)N:65S('!A<B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@X.0IM<V=I9"`B5V5A=&AE<BYC
M;VTB"FUS9W-T<B`B5V5A=&AE<BYC;VTB"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(E=E8B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT,SD*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@
M(E-I=&4@=V5B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA
M;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(D-H87%U92!S96UA
M:6YE(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@
M(E=E;&-O;64B"FUS9W-T<B`B0FEE;G9E;G5E(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W
M"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B
M0FEE;G9E;G5E(.`@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H
M<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B0FEE;G9E;G5E+"`E<R(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DX"FUS9VED(")797-T97)N("A)
M4T\M.#@U.2TQ*2(*;7-G<W1R(")/8V-I9&5N=&%L("A)4T\M.#@U.2TQ*2(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DY"FUS9VED(")797-T97)N("A)
M4T\M.#@U.2TQ-2DB"FUS9W-T<B`B3V-C:61E;G1A;"`H25-/+3@X-3DM,34I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@
M(E-A:&%R82!/8V-I9&5N=&%L(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H
M;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R(")1=65L;&4@
M87!P;&EC871I;VX@)7,@9&]I="UI;"!P<NES96YT97(@87!RZ',@;&$@8V]N
M;F5X:6]NH#\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM
M<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T
M<B`B475E;"!E<W0@;&4@8V%R86-TZ')E(&1E('/I<&%R871I;VZ@/R(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES
M('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(E%U96P@97-T(&QE(&-A
M<F%C=.AR92!D92!C:71A=&EO;J`_(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C4*;7-G:60@(E=H97)E:7,@075S=')A
M;&EA(&UA<"(*;7-G<W1R(")#87)T92!7:&5R96ES($%U<W1R86QI92(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM
M<V=S='(@(E%U96QL97,@<&AA<V5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$S-@IM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H
M92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R(")1=65L;&5S(&5X=&5N<VEO
M;G,@86-T:79E<B!P;W5R(&PGZ61I=&5U<B!2:6-H(%1E>'0N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM
M<V=I9"`B5VED=&@B"FUS9W-T<B`B3&%R9V5U<B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,#0*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*
M;7-G<W1R("),87)G975R(&5N('5N:73I<R!#4U,B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S8Q"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F
M('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X
M="!L;V<M:6XI.B(*;7-G<W1R("(B"B),87)G975R(&1U(&UE;G4@9&4@9V%U
M8VAE("5S("`H;&$@8V]N9FEG=7)A=&EO;B!P<F5N9')A(&5F9F5T(.`@;&$@
M<')O8VAA:6YE("(*(F-O;FYE>&EO;BF@.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T
M:&4@=&%B;&4B"FUS9W-T<B`B3&%R9V5U<B!D=2!T86)L96%U(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@
M(E=I9'1H('5N:70B"FUS9W-T<B`B56YI=.D@9&4@;&%R9V5U<B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED
M(")7:61T:#HB"FUS9W-T<B`B3&%R9V5U<J`Z(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C4Q-0IM<V=I9"`B5VEK:2(*;7-G<W1R(")7:6MI(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X.2!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B5VEN9"(*;7-G
M<W1R(")696YT(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C@*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B5F5N="!T]'0@
M;&4@;6%T:6XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@W"FUS9VED(")7
M:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(E9I=&5S<V4@9'4@=F5N="!E
M;B!N)F]E;&EG.W5D<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38S"FUS
M9VED(")7:6YD.B(*;7-G<W1R(")696YTH#HB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B5F5N
M=*`Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES
M9&]M(@IM<V=S='(@(E-A9V5S<V4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,3DX"FUS9VED(")7:7-H;&ES="(*;7-G<W1R("),:7-T92!D92!V
M)F]E;&EG.W5X(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED
M(")7;W)K(@IM<V=S='(@(E1R879A:6PB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*
M;7-G<W1R(")!9')E<W-E('!R;V9E<W-I;VYN96QL92(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@
M4&AO;F4B"FUS9W-T<B`B5.ELZ7!H;VYE('!R;V9E<W-I;VYN96PB"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ.3,@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU
M;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD
M("5D+B(*;7-G<W1R(").;VUB<F4@9&4@8VAA;7!S(&EN8V]R<F5C="#@(&QA
M(&QI9VYE("5D+B`E9"!A='1E;F1U<RP@)60@=')O=7;I<RXB"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD
M("5D+B(*;7-G<W1R(").;VUB<F4@9&4@8VAA;7!S(&EN8V]R<F5C="X@)60@
M871T96YD=7,L("5D('1R;W5VZ7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,3(Q"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E
M="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(D3I8V%L
M86=E("5D(&EN8V]R<F5C="!L;W)S(&1E(&QA(&QE8W1U<F4@9&4@9FEC:&EE
M<B!61E,N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T-0IM<V=I
M9"`B6"U2968B"FUS9W-T<B`B6"U2968B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S($)A<VEC($-O;G-T
M<F%I;G1S(@IM<V=S='(@(D-O;G1R86EN=&5S(&)A<VEQ=65S(%@U,#EV,R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED
M(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(E5T:6QI<V%T
M:6]N(&1E(&-LZ2#I=&5N9'5E(%@U,#EV,R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!
M;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(D%U=')E(&YO;2!D=2!S=6IE="!8
M-3`Y=C,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y
M-@IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T
M<B`B261E;G1I9FEA;G0@9&4@8VSI(&1U('-U:F5T(%@U,#EV,R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@S"FUS9VED(")8-3`Y
M=C,@97AT96YS:6]N<R(*;7-G<W1R(")%>'1E;G-I;VYS(%@U,#EV,R(*"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R(")!02(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,30*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-@IM
M<V=I9"`B65E962(*;7-G<W1R(")!04%!(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,3$*;7-G:60@(EEA:&]O(2!M87`B
M"FUS9W-T<B`B0V%R=&4@JZ!986AO;Z`AH+LB"@HC.B!F<F%M97=O<FLO36%I
M;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS
M9W-T<B`B06YN=65L;&5M96YT(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B665M
M96XB"FUS9W-T<B`B6>EM96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.38V"FUS9VED(")997,B"FUS9W-T<B`B3W5I(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*
M;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R(")/=6DL(&HG86-C97!T92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*
M;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U
M='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"B)6
M;W5S(.IT97,@96X@;6]D92"KH%1E>'1EH+LN(%5T:6QI<V5Z(&QE(&)O=71O
M;B!;/#Y=('!O=7(@<F5V96YI<B!A=2!M;V1E("(*(JN@5UE325=91Z"[+B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M,C,V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@
M=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@(E9O=7,@
M;B?J=&5S('!A<R!A=71O<FESZ2#@(&-RZ65R('!L=7,@9&4@)60@8FQO8W,N
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#(T"FUS9VED(")9
M;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R(")6;W5S(&XGZG1E
M<R!P87,@875T:&5N=&EF:>DN(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED
M96YT:71Y+G!H<#HS,#@*;7-G:60@(EEO=2!C86YN;W0@:&%V92!T:&4@)UQ<
M)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(E9O=7,@
M;F4@<&]U=F5Z('!A<R!A=F]I<B!L92!C87)A8W3H<F4@JUQ<NR!D86YS('9O
M=')E(&YO;2!C;VUP;&5T+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-3(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW,@IM<V=I9"`B66]U
M(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R
M(")6;W5S(&XG879E>B!P87,@<V%I<VD@=6YE(&%D<F5S<V4@Z6QE8W1R;VYI
M<75E('9A;&ED92XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I
M96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD
M:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@HB5F]U<R!N)V%V97H@
M<&%S(&%S<V]C:>D@;&5S(&-H86UP<R!D=2!F:6-H:65R(&EM<&]R=.D@875X
M(&-H86UP<R`B"B)C;W)R97-P;VYD86YT<R!D86YS("5S+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.CDX-PIM<V=I9"`B66]U(&AA=F4@8F5E;B!L
M;V=G960@;W5T+B(*;7-G<W1R(")6;W5S(&%V97H@Z73I(&3I8V]N;F5C=.DN
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U.`IM<V=I9"`B(@HB
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D
M:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN
M=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*(E9O=7,@
M9&5V97H@:6YS8W)I<F4@=6X@;G5MZ7)O(&1E(&-E;&QU;&%I<F4@=F%L:61E
M+"!S975L<R!D97,@;F]M8G)E<R!E="!U;B`B"B*KH"N@NR!O<'1I;VYN96P@
M<&]U<B!L97,@87!P96QS(&EN=&5R;F%T:6]N875X+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Q.#4*;7-G:60@(EEO=2!H879E('1O(&5N=&5R
M(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(E9O=7,@;B=A=F5Z('!A<R!S86ES
M:2!U;F4@96YT<NEE('9A;&ED92XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A
M=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*(E9O
M=7,@9&5V97H@8V]N9FEG=7)E<B!U;B!B86-K96YD($1A=&%4<F5E('!O=7(@
M=71I;&ES97(@;&5S(&EN<V-R:7!T:6]N<R(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z-#<Q"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!6
M1E,@8F%C:V5N9"XB"FUS9W-T<B`B5F]U<R!D979E>B!C;VYF:6=U<F5R('5N
M(&UO9'5L92!61E,N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E
M9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R
M("(B"B)6;W5S(&1E=F5Z(&3I8W)I<F4@;&4@<')O8FSH;64@879A;G0@9&4@
M;F]U<R!F86ER92!P87)V96YI<B!L92!R87!P;W)T+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M
M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*
M;7-G<W1R(")6;W5S(&1E=F5Z(&5N=')E<B!U;F4@55),(&_Y('!O:6YT92!D
M92!L:65N+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS
M9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N
M(@IM<V=S='(@(DEL(&9A=70@<^EL96-T:6]N;F5R('5N('-E<G9E=7(@X"!S
M=7!P<FEM97(N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R
M(")6;W5S(&1E=F5Z('-PZ6-I9FEE<B!U;B!U=&EL:7-A=&5U<B#@(')E=&ER
M97(N("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B5F]U<R!D
M979E>B!S<.EC:69I97(@=6X@=71I;&ES871E=7(@X"!R971I<F5R+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@861D+B(*;7-G<W1R(")6;W5S(&1E=F5Z('-PZ6-I9FEE<B!U;B!U=&EL
M:7-A=&5U<B#@(&%J;W5T97(N(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N
M(@IM<V=S='(@(E9O=7,@9&5V97H@<W#I8VEF:65R(&QE(&YO;2!D92!L)W5T
M:6QI<V%T975R(.`@;6]D:69I97(N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S="!S<&5C:69Y
M('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(E9O=7,@9&5V97H@
M:6YD:7%U97(@<75E;&QE(&%C=&EO;B!A8V-O;7!L:7(N(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@
M(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B
M5F]U<R!D979E>B#I8W)I<F4@=6X@;F]M('!O=7(@;&$@;F]U=F5L;&4@8V%T
MZ6=O<FEE+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET
M86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N
M($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(E9O=7,@9&5V97H@9F]U
M<FYI<B!U;B!NL"!D92!TZ6SI<&AO;F4@:71A;&EE;B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.CDW-0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R
M("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB
M"FUS9W-T<B`B5F]T<F4@<V5S<VEO;B`E<R!A(&5X<&ERZ2X@5F5U:6QL97H@
M=F]U<R!R96-O;FYE8W1E<BXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@
M(E9O=')E(&%D<F5S<V4@9&4@8V]U<G)I96PB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C$U"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S
M='(@(E9O=')E(&%D<F5S<V4@9&4@8V]U<G)I96P@JR!$93H@NZ`Z(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDR"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@
M(E9O<R!D;VYNZ65S('!E<G-O;FYE;&QE<R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN
M=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN
M9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U
M<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(E9O=')E
M(&%D<F5S<V4@26YT97)N970@82!C:&%N9^D@9&5P=6ES(&PG;W5V97)T=7)E
M(&1E('9O=')E('-E<W-I;VX@)7,N("`B"B)0;W5R('9O=')E('/I8W5R:73I
M+"!V;W5S(&1E=F5Z('9O=7,@<F5C;VYN96-T97(N(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G
M<W1R(")6;W1R92!N;VTB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D
M9"YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD
M(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T
M;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y
M;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C
M:V5N9"XB"FUS9W-T<B`B(@HB5F]T<F4@;6]D=6QE(&0G875T:&5N=&EF:6-A
M=&EO;B!N92!S=7!P;W)T92!P87,@;"=A:F]U="!D)W5T:6QI<V%T975R<RP@
M4VD@(@HB=F]U<R!S;W5H86ET97H@=71I;&ES97H@2&]R9&4@<&]U<B!A9&UI
M;FES=')E<B!L97,@8V]M<'1E<R!U=&EL:7-A=&5U<G,L("(*(G9O=7,@9&5V
M97H@=71I;&ES97(@=6X@875T<F4@;6]D=6QE(&0G875T:&5N=&EF:6-A=&EO
M;BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G
M:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S
M=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B
M965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B
M(@HB5F]T<F4@;6]D=6QE(&0G875T:&5N=&EF:6-A=&EO;B!N)V5S="!P87,@
M96X@;65S=7)E(&0GZ71A8FQI<B!U;F4@;&ES=&4@9&5S("(*(G5T:6QI<V%T
M975R<RP@;W4@8V5T=&4@9F]N8W1I;VX@82#I=.D@<F5T:7+I92!P;W5R('5N
M92!A=71R92!R86ES;VXN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M.3@S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E
M87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO
M=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y
M;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB5F]T<F4@;F%V:6=A
M=&5U<B!S96UB;&4@879O:7(@8VAA;F?I(&1E<'5I<R!L92!DZ6)U="!D92!V
M;W1R92!S97-S:6]N("5S+B`@(@HB4&]U<B!V;W1R92!SZ6-U<FETZ2P@=F]U
M<R!D979E>B!V;W5S(')E8V]N;F5C=&5R+B(*"B,Z(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C4W"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R
M="!T:&ES(&9E871U<F4N(@IM<V=S='(@(E9O=')E(&YA=FEG871E=7(@;F4@
M<W5P<&]R=&4@<&%S(&-E='1E(&]P=&EO;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E
M<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O
M;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@HB5F]T<F4@
M;F%V:6=A=&5U<B!N92!P<F5N9"!P87,@96X@8V]M<'1E(&-E='1E(&]P=&EO
M;B!D)VEM<')E<W-I;VXN(%!R97-S97H@(@HB0V]N='+T;&4O0V]M;6%N9&4@
M*R!0('!O=7(@:6UP<FEM97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C8Q"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R(")6
M;W1R92!F=7-E874@:&]R86ER92!A8W1U96R@.B(*"B,Z('-E<G9I8V5S+W!R
M969S+G!H<#HQ,3<*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@
M8F5E;B!C:&%N9V5D+B(*;7-G<W1R(")6;W1R92!P<F]F:6P@<&%R(&3I9F%U
M="!A(.ETZ2!M;V1I9FGI+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-C$*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`B4')O
M9FEL('!A<B!DZ69A=72@.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,#0*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R(")6;W1R92!N;VT@
M8V]M<&QE=*`Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DY"FUS
M9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")6;W1R92!C
M;VUP=&4@82!E>'!I<NDN(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@
M9F]R("5S(&ES.B`E<R(*;7-G<W1R(")6;W1R92!N;W5V96%U(&UO="!D92!P
M87-S92!P;W5R("5S(&5S=*`Z)7,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C$U-`IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U
M<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G
M<W1R(")6;W,@;W!T:6]N<R!O;G0@Z73I(&UI<V5S(.`@:F]U<B!P;W5R(&QA
M(&1U<NEE(&1E(&-E='1E('-E<W-I;VXN(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"XB"FUS9W-T<B`B5F]S(&]P=&EO;G,@;VYT(.ETZ2!M:7-E
M<R#@(&IO=7(N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S4*
M;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B
M5F]T<F4@;6]T(&1E('!A<W-E(&$@Z73I(')E;6ES(.`@>NER;R(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A
M<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L
M;V<@:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HB
M5F]T<F4@;6]T(&1E('!A<W-E(&$@Z73I(')E;6ES(.`@>NER;RP@=NER:69I
M97(@=F]T<F4@8V]U<G)I97(@970@8V]N;F5C=&5Z+2(*(G9O=7,@879E>B!V
M;W1R92!N;W5V96%U(&UO="!D92!P87-S92XB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HW,S,*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER
M960N(@IM<V=S='(@(E9O=')E(&UO="!D92!P87-S92!A(&5X<&ERZ2XB"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@
M<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(E9O<R!S97)V975R<R!D:7-T86YT
M<Z`Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*
M;7-G<W1R(")9;W5G;W-L879I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(EIA[W)E(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(EIA;6)I92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(EII;6)A8G=E
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*
M;7-G<W1R(")::7!P>2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!4
M97AT72(*;7-G<W1R(");0V%C:&5R(&QE<R!C:71A=&EO;G-=(@H*(SH@<V5R
M=FEC97,O<')O8FQE;2YP:'`Z.#D*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB
M"FUS9W-T<B`B6U)A<'!O<G0@9&4@<')O8FSH;65=(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U
M;W1E9"!497AT("TB"FUS9W-T<B`B6T%F9FEC:&5R(&QE('1E>'1E(&-I=.D@
M+2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT
M<75O=&5S+G!H<#HQ-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O
M=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B6T%F9FEC:&5R(&QE('1E
M>'1E(&-I=.D@+2`E<R!L:6=N97-=(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HR,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@
M)7-=(@IM<V=S='(@(EML:6=N92`E<R!D92`E<UTB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$U-30@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN
M8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E]!9&UI;FES
M=')A=&EO;B(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*;7-G
M<W1R("),:6=N92!D92!?8V]M;6%N9&4B"@HC.B!L:6(O87!I+G!H<#HQ-#$*
M;7-G:60@(E]$871A5')E92(*;7-G<W1R(")?1&%T851R964B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*
M;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(E-U<'!R:6UE<B!L82!?<F%N
M9^EE(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S
M='(@(E]'<F]U<&5S(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N
M<&AP.C$W-0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`B7T%I9&4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*
M;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E!R;W!R7VGI
M=.ES(&1E(&PG:6UA9V4N+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M365N=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(E]#;VYN97AI
M;VXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"FUS
M9VED(")?3&]G(&]U="(*;7-G<W1R(")?1.EC;VYN97AI;VXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*
M;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R(")?36]D:69I97(@=6X@
M;&EE;B!W96(N+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP
M:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R(")?3W!T:6]N<R(*"B,Z
M(&QI8B]A<&DN<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@
M(E]097)M:7-S:6]N<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK+BXN
M(@IM<V=S='(@(E]2971I<F5R('5N(&QI96XB"@HC.B!L:6(O87!I+G!H<#HQ
M,C4*;7-G:60@(E]3971U<"(*;7-G<W1R(")?0V]N9FEG=7)A=&EO;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4')O
M<')IZ73I<R!D=2!?=&%B;&5A=2(*"B,Z(&QI8B]A<&DN<&AP.C$R.0IM<V=I
M9"`B7U5S97)S(@IM<V=S='(@(E]5=&EL:7-A=&5U<G,B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDR-0IM<V=I9"`B861D<F5S<R!B;V]K(@IM
M<V=S='(@(F-A<FYE="!D)V%D<F5S<V5S(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N
M(@IM<V=S='(@(F1E<W1I;F%T86ER92!I;F-O;FYU(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,3<*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@
M(F%G96YD82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<Y(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S8U"B,L('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS
M9W-T<B`B8V%L;64B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G
M<W1R(")I;7!O<W-I8FQE(&1E(&-RZ65R(&QE(&9I8VAI97(@9&4@<V]R=&EE
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S`*;7-G
M:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(FEM<&]S<VEB;&4@9"=O
M=79R:7(@;"=E;G1RZ64B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HU.3@*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B8VQI<75E
M>B!I8VDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R
M,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(F5R
M<F5U<B!D)W5T:6QI<V%T:6]N(&1E(&QA(&QI9VYE(&1E(&-O;6UA;F1E(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S@*;7-G:60@
M(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B97)R975R(&1E(&-O;F9I
M9W5R871I;VXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G
M<W1R(")A8G-E;F-E(&-R:71I<75E(&0G=6X@9FEC:&EE<B!S>7-TZ&UE(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C8*;7-G:60@
M(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(F5R<F5U<B!D92!F;W)M870@
M9&4@9&]N;NEE(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHS,`IM
M<V=I9"`B961I="(*;7-G<W1R(")M;V1I9FEE<B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3@R"FUS9VED(")E;G1R>2!N;W0@9F]U
M;F0B"FUS9W-T<B`B96YT<NEE(&YO;B!T<F]U=NDB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PIM<V=I9"`B9F%L;&EN9R(*
M;7-G<W1R(")T;VUB86YT(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.#DX"FUS9VED(")F:6QE(@IM<V=S='(@(F9I8VAI97(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$X,2!L:6(O0FQO8VLO;65T87(N<&AP.C,V
M-R!L:6(O0FQO8VLO;65T87(N<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(F1E<'5I<R!L
M92`E<R`H)7,I(.`@)7,@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,Y"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(F5N(')A9F%L92(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-3`*
M;7-G:60@(F@Z(@IM<V=S='(@(FB@.B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HS-3D*;7-G:60@(FAH(@IM<V=S='(@(FAH
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G
M:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(FYO;2!D)VCT=&4@:6YC
M;VYN=2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(FEM;>ED
M:6%T96UE;G0B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S
M971U<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(FEN8V]R
M<&]RZ64B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V
M,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(F5R<F5U<B!D
M)V5N='+I92]S;W)T:64B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS
M9W-T<B`B97)R975R(&QO9VEC:65L;&4@:6YT97)N92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB
M"FUS9W-T<B`B;&EG;F5S72(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS
M9W-T<B`B97)R975R(&UK:7-O9G,@8V]D92`E9"!E;B!C<NEA;G0@;"=)4T\B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<P
M"FUS9VED(")M;2(*;7-G<W1R(")M;2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,C@U('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ
M-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(T,0IM<V=I9"`B
M;F%M92(*;7-G<W1R(")N;VTB"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z
M,3(T"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B;F]N('!R:7,@
M96X@8V]M<'1E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HQ,C(P"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(G!A
M<R!E;F-O<F4@<')I<R!E;B!C;VUP=&4B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDP.0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R(")B;&]C+6YO
M=&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R(")P;W5R8V5N=&%G
M92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<T"FUS
M9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R(")P97)M:7-S:6]N(')E
M9G5SZ64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B<&EX96QS(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@
M(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R(")E<G)E=7(@9&ES
M=&%N=&4@9&%N<R!L92!P<F]T;V-O;&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HW-0IM<V=I9"`B<FES:6YG(@IM<V=S='(@
M(G,GZ6QE=F%N="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,30R"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@(G-E
M<G9I8V4@;F]N(&1I<W!O;FEB;&4N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HQ,#$*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B;6]N
M=')E<B!L97,@9&EF9NER96YC97,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I
M82!(5%10(@IM<V=S='(@(G-M<S)E;6%I;"!V:6$@2%144"(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.#<*;7-G:60@(G-S
M(@IM<V=S='(@(G-S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-S0*;7-G:60@(G-T96%D>2(*;7-G<W1R(")F:7AE(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y
M<W1E;2!E<G)O<B(*;7-G<W1R(")E<G)E=7(@<WES=.AM92(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,S"FUS9VED(")T87-K(&QI<W0B"FUS
M9W-T<B`B;&ES=&4@9&4@=.)C:&5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM
M<V=S='(@(NEC:&5C('1E;7!O<F%I<F4B"@HC.B!A9&UI;B]U<V5R+G!H<#HS
M-B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED(")T
M>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(F5N
M=')E>B!L92!M;W0@9&4@<&%S<V4@9&5U>"!F;VES('!O=7(@8V]N9FER;65R
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B=6YI9FGI(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE
M9"(*;7-G<W1R(")S86YS(&YO;2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S96QE
M8W0B"FUS9W-T<B`B4^EL96-T:6]N(&0G=71I;&ES871E=7(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#
M87)D(@IM<V=S='(@(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(T,@IM<V=I9"`B=SHB"FUS9W-T<B`B;*`Z(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H
M97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M(@H`````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]G;%]%4RYP;P``````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-C$S-3,P`#$P
M-3$U-#,S-S4T`#`Q-S8S-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````C($AO<F1E(#(N,BXT($=A;&EC:6%N('1R86YS;&%T
M:6]N+@HC"B,@5F5R<VEO;B!I;FEC:6%L(&1E.@HC"B,@4F%F865L(%9A<F5L
M82`\<F%F865L+G9A<F5L84!U<V,N97,^"B,@1W5I;&QE<FUO($UE;F1E>B`\
M9W5I;&QE0'5S8RYE<SX*(R!397)V:6-I;R!D92!A=&5N8VEO;B!A('5S=6%R
M:6]S(&4@<VES=&5M87,*(R!5;FEV97)S:61A9&4@9&4@4V%N=&EA9V\@9&4@
M0V]M<&]S=&5L80HC"B,@4F5V:7-A9&$@>2!C;W)R96=I9&$@<&]R.@HC(`HC
M(%-E<G9I8VEO(&1E(&YO<FUA;&EZ86-I;VX@;&EN9W5I<W1I8V$@/'-N;'5S
M8T!U<V,N97,^"B,@56YI=F5R<VED861E(&1E(%-A;G1I86=O(&1E($-O;7!O
M<W1E;&$*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO
M;CH@2&]R9&4@,BXQ7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI
M<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M
M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P,RTP."TQ
M.2`Q,SHS-4=-5"LQ7&XB"B),87-T+51R86YS;&%T;W(Z(%-E<G9I8VEO(&1E
M($YO<FUA;&EZ86-I;VX@3&EN9W5I<W1I8V$@/'-N;'5S8T!U<V,N97,^7&XB
M"B),86YG=6%G92U496%M.B!'86QE9V]<;B(*(DU)344M5F5R<VEO;CH@,2XP
M7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X
M-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@HB
M6"U'96YE<F%T;W(Z($M"86)E;"`P+CDN-5QN(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,V.0HC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A
M>7,@86=O*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$S-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<S"FUS9VED("(@*'1O
M9&%Y*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S<U"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,S<Q"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U-B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Q"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HT,#<*;7-G:60@(B!A="`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,34*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C8U
M.0HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$P-#(*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N
M9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(B<E<R<@
M;F]N(&5S=.$@8V]N9FEG=7)A9&\@;F\@<F5X:7-T<F\@9&4@2&]R9&4N(@H*
M(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R
M;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"B,L('!H<"UF;W)M
M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F
M)24I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8X(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C<P-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HX,S,@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z.#,U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N
M9FER;6%T:6]N(@IM<V=S='(@(D]P97)A8VGS;G,@9&4@;6%N=&5M96YT;R`E
M<R`M($-O;F9I<FUA8VGS;B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!3971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z,C8S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I
M9VX@57`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0R
M."!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y,`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C8U,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3D@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,SD*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H
M92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K
M('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@
M<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(B(*(DUA<G%U92!N82!C
M=6%D<NUC=6QA(&$@;W!E<F%C:?-N(&]U(&]P97)A8VGS;G,@<75E(&1E<V5X
M82!E>&5C=71A<B!A9V]R82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S0P"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@V"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(D-A9&$@
M-2!M:6YU=&]S(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I
M;VXN<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S
M(@IM<V=S='(@(EML:?%A("5S(&1E("5S72(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R(")!>&5N9&$@9&4@96YD97)E>F]S
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,30*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B0V%L
M96YD87)I;R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`V"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP
M:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N
M;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O
M;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H
M92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C4@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q,`IM<V=I9"`B+"!G=7-T:6YG
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X."!L:6(O
M0FQO8VLO;65T87(N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U
M<W1I;F<@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F<F]M("5S
M('1O("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,CDT(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-CD@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$R.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-S0Y"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"B,L(&9U>GIY"FUS9VED("(Q,B!(
M;W5R($9O<FUA="(*;7-G<W1R(")!('/Z82!I;F9O<FUA8VGS;B(*"B,Z(&QI
M8B]";&]C:R]T:6UE+G!H<#HQ.0HC+"!F=7IZ>0IM<V=I9"`B,C0@2&]U<B!&
M;W)M870B"FUS9W-T<B`B02!S^F$@:6YF;W)M86-I\VXB"@HC.B!T96UP;&%T
M97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B
M,C0@:&]R87,B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y"FUS
M9VED("(\4')E=FEO=7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ,3D*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E
M9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-C`*(RP@9G5Z>GD*;7-G:60@(D$@9F%T86P@97)R
M;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(CQB/E!R;V1U8VEU<V4@=6X@97)R
M;R!G<F%V93H@/"]B/B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T
M;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V-0IM<V=I9"`B02!P=6)L:6,@4$=0
M(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3`Y-PIM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A
M("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$P,34*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4P-0IM<V=I9"`B(@HB02!P=6)L
M:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O
M34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N
M("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME
M>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM
M<V=I9"`B04T@0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$Q"FUS9VED(")!32!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3
M:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-
M+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3(*;7-G:60@(D%B;W5T+BXN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!
M8G-M:61D;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&
M4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M,PHC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R
M(")!('/Z82!I;F9O<FUA8VGS;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW-0HC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R
M(")#:&%V92!D92!A8V-E<V\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,S
M"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D+FEN
M8SHQ-`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ
M,0HC+"!F=7IZ>0IM<V=I9"`B061D(@IM<V=S='(@(D5N9&5R97IO(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G
M:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"B,L(&9U>GIY"FUS
M9VED(")!9&0@2&5R93HB"FUS9W-T<B`B16YD97)E>F\B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D
M($YE=R!'<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#@*
M;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M
M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB
M)7-<(B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B
M061D(&$@;F5W('5S97(Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HU-30*;7-G:60@(D%D9"!C;VQU;6XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHS-`IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM
M<V=S='(@(D5N9V%D:7(@=6X@<&%R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@
M87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"B,L(&9U>GIY"FUS9VED
M(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R(")!>&5N9&$@9&4@96YD
M97)E>F]S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C<X"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K
M(@IM<V=S='(@(D%X96YD82!D92!E;F1E<F5Z;W,B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`B16YG
M861I<B!U;B!P87(B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T
M(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ
M("(*(B5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF
M;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@
M8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES
M86)L960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q
M"FUS9VED(")!9&1R97-S(@IM<V=S='(@(D5N9&5R97IO(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$S.0HC+"!F=7IZ>0IM<V=I9"`B061D<F5S
M<R!";V]K(@IM<V=S='(@(D%X96YD82!D92!E;F1E<F5Z;W,B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M
M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#$*(RP@9G5Z
M>GD*;7-G:60@(D%D<R(*;7-G<W1R(")%;F1E<F5Z;R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*
M;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*(RP@
M9G5Z>GD*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B06QC=6UE(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,`HC+"!F=7IZ>0IM<V=I9"`B06QG97)I82(*;7-G<W1R(")!;&-U;64B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W
M"FUS9VED(")!;&EA<R(*;7-G<W1R(")!;&-U;64B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V"B,L(&9U>GIY
M"FUS9VED(")!;&EG;B(*;7-G<W1R(")!;&-U;64B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE
M;G0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM
M<V=I9"`B06QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G
M:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@
M(D%L;"!'<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N
M<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ
M-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,0IM<V=I9"`B06QL;W<@;75L=&EP;&4@
M861D<F5S<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,S0*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y
M<&4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E
M92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,PIM<V=I9"`B06QT97)N
M871E($E-4U`@3&]G:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4P-PIM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y.0IM<V=I9"`B
M06QT97)N871E($E-4U`@57-E<FYA;64B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@(D%L=&5R
M;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(D5N9&5R97IO(&1E(&-O<G)E
M;R!E;&5C='+S;FEC;SHB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM
M<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4X"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S
M<&5C:69I960N(@IM<V=S='(@(D\@=F%L;W(@<75E(&5S<&5C:69I8V]U(&YO
M;B#I(';A;&ED;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-C<*(RP@9G5Z>GD*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R
M960N(@IM<V=S='(@(CQB/E!R;V1U8VEU<V4@=6X@97)R;R!G<F%V93H@/"]B
M/B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-34*;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*
M;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I
M9"`B06YS=V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R
M8W1I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A
M;F0@0F%R8G5D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-0HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO54DN<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH
M=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(B(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,30P"FUS9VED
M(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD
M(%-H87)E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A
M<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S,*;7-G:60@(D%P
M<')O>&EM871E(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<U"FUS9VED(")!<F%B:6,@
M*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#$*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@P"FUS9VED(")!<F-H
M:79E($YA;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S
M="!F;W(@)7,@/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V1E;&5T92YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U
M('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG
M<F]U<',_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED(")!<FUE
M;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y
M"FUS9VED(")!<G5B82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@
M07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(U"FUS9VED(")!<VL@9F]R(&-O
M;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q
M,PIM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@
M;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M
M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N
M+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@
M;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX-@IM<V=I9"`B071T<FEB=71E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#8*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM
M<V=I9"`B075G=7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U
M<W1R86QI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H
M<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N
M9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G
M:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N
M<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE
M+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@
M24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z
M(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@
M(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R
M($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I
M;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C8S"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P
M.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z
M(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0P-0IM
M<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R
M=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ
M(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!
M=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F
M86EL960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT
M:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U,0IM<V=I9"`B075T
M:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A
M:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B0V%M<&]S(&1I<W!O\6EB;&5S.B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S
M"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O
M<R!P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C$*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D)A;'1I8R`H25-/+3@X
M-3DM,3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E
M<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS
M9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF
M;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS
M9VED(")"96YI;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M
M=61A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R(")!;FEV97)S87)I;R(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-3,*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A
M<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(").;VX@<V4@
M871O<&]U(&\@87AE;G1E(&1E(&YO=&EF:6-A8VGS;B`E<RXB"@HC.B!T96UP
M;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.#D*;7-G:60@(D)L;V-K(%-E='1I
M;F=S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`U"FUS9VED(")"
M;V]K;6%R:W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`HC+"!F=7IZ>0IM<V=I9"`B0F]R
M9&5R(@IM<V=S='(@(DAO<F1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B0F]R9&5R<R(*;7-G
M<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R
M>F5G;W9I;F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDV"FUS9VED(")";W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@
M(D)O='-W86YA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B0G)A>FEL(@IM<V=S
M='(@(D-O<G)E;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H($EN9&EA
M;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I
M9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM
M<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0T"B,L(&9U>GIY
M"FUS9VED(")#35,B"FUS9W-T<B`B0U93(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED
M(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*
M;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B0V%C:&4@:6YI
M="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-"!C;VYF:6<O:&]O:W,N
M<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-34*
M;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(D-A;&5N9&%R:6\B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0V"FUS9VED(")#86QM(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8W"FUS9VED(")#86UE<F]O;B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R
M97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B!N;W0@=W)I
M=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO
M;G,N<&AP.C(R"FUS9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E
M<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER=7,N<&AP.C(S-2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q
M;"YP:'`Z,S$Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C
M;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R(")&86QL;W4@\R!C
M;VYE8W1A<B!C;R!S97)V:61O<B!,1$%0+B(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C0Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O
M<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"B,L(&9U
M>GIY"FUS9VED(")#86YA9&$B"FUS9W-T<B`B0V%L96YD87)I;R(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,2!T96UP;&%T97,O861M:6XO
M=7-E<B]C;&5A<BYI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E+FEN8SHQ,@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O
M8FQE;2!297!O<G0B"FUS9W-T<B`B0V%N8V5L87(@;R!I;F9O<FUE(&1E('!R
M;V)L96UA<R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$X"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+V-O<'DN<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I
M=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964N<&AP.C$R."!F
M<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV.#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI
M<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E
M92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E
M<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA
M=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B
M0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(T"B,L(&9U>GIY"FUS9VED(")#87!T:6]N(@IM<V=S='(@(D]P
M8VGS;G,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P
M+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDP"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E
M;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B5&5L
MZ69O;F\@;?-B:6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(U"B,L(&9U>GIY"FUS9VED(")#96QL(%!R;W!E
M<G1I97,B"FUS9W-T<B`B5&5LZ69O;F\@;?-B:6PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P
M861D:6YG.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W-`HC+"!F=7IZ>0IM
M<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(E1E;.EF;VYO(&WS8FEL(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I8R`H25-/+3@X
M-3DM,30I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L
M:6,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G
M:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-CDY"FUS9VED
M(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$Q"FUS9VED(")#97)T:69I8V%T
M92!/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y-@IM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED(")#:&%D(@IM
M<V=S='(@(E1A<GAE=&$@9&4@=FES:71A("AV0V%R9"DB"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.CDV"B,L(&9U>GIY"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B1&5S
M9F%C97(@;W,@8V%M8FEO<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HS,0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N
M9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@
M=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED
M("(B"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@
M=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*(RP@9G5Z>GD*
M;7-G:60@(D-H87(B"FUS9W-T<B`B5&%R>&5T82!D92!V:7-I=&$@*'9#87)D
M*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B0VAI;&4B"FUS9W-T<B`B5.UT
M=6QO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;F$B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI
M9FEE9"`H1T(R,S$R*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X,0IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V
M.0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.`IM<V=I9"`B0VAO;W-E
M(&$@=7-E<FYA;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(Y.`IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T
M>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z.#DS"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I
M;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B3F]N('-E(&%T;W!O
M=2!O(&%X96YT92!D92!N;W1I9FEC86-I\VX@)7,N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*(RP@9G5Z>GD*;7-G:60@
M(D-L96%R(@IM<V=S='(@(D-A;&5N9&%R:6\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F
M9FEC92!T86=S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,C@*;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@
M(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*
M;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I
M;F<@3&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M;6%I;G1E;F%N8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM
M<V=S='(@(E!E8VAA<B!A('AA;F5L82(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C0T"FUS9VED(")#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%
M87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G:60@
M(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L
M;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B
M0V]L;VUB:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ
M."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N
M+G!H<#HS,C0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN
M<&AP.C,R-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-3`P('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G
M:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.#0V"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.30V"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C0*;7-G:60@
M(D-O;6EC<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*
M(RP@9G5Z>GD*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B0V]M<&'Q[6$B"@HC
M.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$S"FUS9VED(")#;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-38V"FUS9VED(")#;VUM;VX@3F%M92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(D-O;7!A\>UA(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y-PIM<V=I
M9"`B0V]N9&ET:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C0Y"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E
M<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-#,*;7-G:60@(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S
M+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I
M<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHU,0HC+"!F=7IZ>0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R
M(")#:&%V92!D92!A8V-E<V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;VYG;R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C
M<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I
M;VX@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO
M;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S
M("@E<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX-#4*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#$T"FUS
M9VED(")#;VYT86-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@
M<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S
M='(@(D-O;G1I9&\@9&4@)R5S)R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I
M9"`B0V]N=&EN=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]O
M:R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0HC+"!F=7IZ
M>0IM<V=I9"`B0V]P>2(*;7-G<W1R(")#;VUP8?'M82(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-#8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B0V%M<&\@:6UP;W)T861O
M.B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T
M($E$(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY
M-S8*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4S
M"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G
M:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM
M<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N
M=&%C="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q
M"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E
M<BXB"FUS9W-T<B`B1F%L;&]U(/,@8V]N96-T87(@8V\@<V5R=FED;W(@3$1!
M4"XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#4W"FUS9VED(")#;W5L
M9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-#$*
M(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R
M=F5R(@IM<V=S='(@(D9A;&QO=2#S(&-O;F5C=&%R(&-O('-E<G9I9&]R($Q$
M05`N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@
M=7-I;F<@1E10.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,3(U"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C(*
M;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E
M(&-O;G1A8W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HY-3,*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E
M8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I
M9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D
M:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD
M(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@
M;&ES=',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@
M<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O
M=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&]P96X@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N
M86YC92]-86EN=&5N86YC92YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM
M<V=S='(@(D9A;&QO(/,@86)R:7(@;R!M\V1U;&\@9&4@=&%R969A<R!D92!M
M86YT96UE;G1O("5S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@
M7"(E<UPB+B(*;7-G<W1R(")&86QL;R#S(&%B<FER(&\@;?-D=6QO(&1E('1A
M<F5F87,@9&4@;6%N=&5M96YT;R`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y
M.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E
M<G9E<BXB"FUS9W-T<B`B1F%L;&]U(/,@8V]N96-T87(@8V\@<V5R=FED;W(@
M3$1!4"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@
M(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U
M97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E
M(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M,#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0P
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-PHC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O
M;VLN("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`HC+"!F=7IZ>0IM<V=I
M9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")(
M;W)D92!N;VX@<V4@8V]N9FEG=7)O=2!C;W)R96-T86UE;G1E(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S
M879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG
M=6%T:6]N.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S
M971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F
M:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C<U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H
M92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O
M;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N
M("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30S
M"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E
M<G9E<BXB"FUS9W-T<B`B1F%L;&]U(/,@8V]N96-T87(@8V\@<V5R=FED;W(@
M3$1!4"XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C
M="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S
M7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-C8*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@
M36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB
M('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q
M.0IM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")#;W5N=')Y(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S,*;7-G
M:60@(D-O=7)S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A
M=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI
M;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@
M(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S
M:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,C,P"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-SD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M.`IM<V=I9"`B0W5B82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,C8*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5S<VEO;G,N<&AP.C0X"FUS9VED(")#=7)R96YT(%-E<W-I;VYS
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C
M:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5S<VEO;G,N<&AP.C,S"FUS9VED(")#=7)R96YT(%5S97)S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U
M<G)E;G0@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C<U"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@
M(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B
M0WEP<G5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R
M"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M
M,3(U,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*
M;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Q
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")$
M1"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#$*;7-G:60@(B(*
M(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA
M9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I
M9"`B1&%I;'DB"FUS9W-T<B`B1&EA<FEA;65N=&4B"@HC.B!A9&UI;B]D871A
M=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W.0IM<V=I9"`B1&%T
M86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,Y.0IM<V=I9"`B1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`W
M"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDR(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,C(*(RP@9G5Z>GD*;7-G:60@(D1A>2(*;7-G<W1R(")$:6%R
M:6%M96YT92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#4P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@
M(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!)
M;F1E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(D1E
M9F%U;'0B"FUS9W-T<B`B261E;G1I9&%D92!P<F5D971E<FUI;F%D82(*"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"B,L
M(&9U>GIY"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(E5S87(@;R!V
M86QO<B!P;W(@9&5F96-T;R(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N
M=&ET>2YP:'`Z.3$*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B
M261E;G1I9&%D92!P<F5D971E<FUI;F%D82(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G
M<W1R("))9&5N=&ED861E('!R961E=&5R;6EN861A(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHW,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE
M=&4N:6YC.C$P('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS
M9VED(")$96QE=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"FUS9VED(")$96QE=&4@
M0V5L;"(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI
M;B]G<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0IM<V=I9"`B
M1&5L971E($QO9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q
M"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B1&5L
M971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED
M(")$96QE=&4@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@
M8V]L=6UN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X
M"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(Q
M"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@
M7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S
M:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*(RP@9G5Z
M>GD*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R("))
M9&5N=&ED861E('!R961E=&5R;6EN861A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED(")$96QE
M=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I
M9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T"FUS9VED(")$
M96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(U,PIM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM87)K(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C
M<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R(")$97-C<FEC:?-N(&1O('!R;V)L
M96UA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*(RP@9G5Z
M>GD*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:6-I\VX@8V]M
M<&QE=&$Z(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.34*;7-G
M:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3D*;7-G:60@
M(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T
M;W(N(@IM<V=S='(@(E)E>&ES='+A<F]N<V4@;W,@9&5T86QL97,@<&%R82!O
M(&%D;6EN:7-T<F%D;W(N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(Q.0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,3<*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I9"`B1&5W(%!O:6YT
M(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C(W"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y
M"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C8*;7-G:60@
M(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS
M9W-T<B`B3W!C:?-N<R!D92!V:7-U86QI>F%C:?-N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.CDV"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y
M(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@(D]P8VGS;G,@9&4@=FES=6%L
M:7IA8VGS;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#4*;7-G:60@(D1I
M<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@Q-PHC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!F
M;W)M870B"FUS9W-T<B`B3W!C:?-N<R!D92!V:7-U86QI>F%C:?-N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B1&ES<&]S
M:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G
M:60@(D1J:6)O=71I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@
M;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B
M3F]N(&%C8V5D82!D:7)E8W1A;65N=&4@82!<(FUA:6YT96YA;F-E+G!H<%PB
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O
M=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES
M(&)O>#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI8V$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B
M;&EC(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M.#0T"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$
M<G5G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3,*(RP@9G5Z>GD*;7-G:60@(D4M36%I;"(*;7-G<W1R(")#;W)R
M96\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H
M<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@
M8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHW,@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC
M.C(U"FUS9VED(")%9&ET(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R]522YP:'`Z-3`@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR
M-0IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R-@IM<V=I9"`B161I="!'
M<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`P"FUS9VED
M(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D
M:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@
M<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D
M:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"B,L('!H<"UF;W)M870*;7-G:60@
M(D5I=&AE<B!E;F%B;&4@:70@=&AE;CH@)7,L(&]R('5S92!T:&4@8F%S:6,@
M2%1-3"!V97)S:6]N.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS
M9VED(")%;"!386QV861O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L
M96UE;G0N+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V.0IM<V=I9"`B16UA:6PB"FUS9W-T
M<B`B0V]R<F5O(&5L96-T<O-N:6-O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X
M"B,L(&9U>GIY"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D5N9&5R
M97IO(&1E(&-O<G)E;R!E;&5C='+S;FEC;SHB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.38S"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M
M871C:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3DX.0HC+"!F=7IZ>0IM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB
M"FUS9W-T<B`B3W5T<F$@:6YF;W)M86-I\VXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M
M4TU3($=A=&5W87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.`HC+"!F=7IZ>0IM<V=I9"`B16UO=&EC
M;VYS(@IM<V=S='(@(D]P8VGS;G,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*(RP@9G5Z>GD*;7-G:60@(D5M
M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(E-E;B!R97-U;'1A9&\N(@H*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C<P-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM<V=I
M9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R(")396X@<F5S=6QT861O+B(*"B,Z
M(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M
M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-30S"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E
M<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$X"FUS9VED(")%;F%B;&4@<FEG
M:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,3$*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R
M9V4@161I=&]R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,C$*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI
M8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U
M<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R
M('!E=#\G.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H
M92!I;6%G92!54DP@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DQ"FUS9VED(")%;G1E<B!T:&4@
M;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B
M17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I
M9"`B17)I=')E82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-2!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-34*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-B!S97)V
M:6-E<R]P;W)T86PO:6YD97@N<&AP.C@R"FUS9VED(")%<G)O<B(*;7-G<W1R
M(")%<G)O(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT
M-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ
M("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@
M86YC:&]R.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN
M9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L
M871E+U1E;7!L871E+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM
M<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R
M<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS
M9VED(")%<W1O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T
M:&EO<&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*;7-G:60@(D5V97)Y(#$U(&UI
M;G5T97,B"FUS9W-T<B`B0V%D82`Q-2!M:6YU=&]S(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,X.0HC+"!F=7IZ>0IM<V=I9"`B179E<GD@,B!M:6YU
M=&5S(@IM<V=S='(@(D-A9&$@-2!M:6YU=&]S(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,S-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@W"FUS9VED
M(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(D-A9&$@,S`@<V5G=6YD;W,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,X(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.3`*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")#
M861A(#4@;6EN=71O<R(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(D-A
M9&$@:6YI8VEO(&1E('-E<VGS;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#`*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")#861A(&UE
M9&EA(&AO<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,W(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.#@*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G
M<W1R(")#861A(&UI;G5T;R(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B17AE;7!L
M;R!D92!V86QO<F5S.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI
M;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R-PIM<V=I
M9"`B17AE8W5T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HT-S4*;7-G:60@(D5X<&%N9"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS9VED(")%>'!A
M;F0@4VED96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+
M97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I
M9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-@IM<V=I9"`B17AP;VYE
M;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B1E10('5P
M;&]A9"!O9B!S971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O<W%L+G!H<#HR,38*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R
M969E<F5N8V5S+B(*;7-G<W1R(")&86QL;W4@\R!R96-U<&5R87(@87,@<')E
M9F5R96YC:6%S+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HW-2!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&
M86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B1F%L
M;&]U(/,@8V]N96-T87(@8V\@<V5R=FED;W(@3$1!4"XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-M8BYP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(D9A:6QE
M9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(D9A;&QO=2#S
M(&-O;F5C=&%R(&-O('-E<G9I9&]R($Q$05`N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HV.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D
M('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z-CDQ"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(D9A;&QO
M=2#S(&-O;F5C=&%R(&-O('-E<G9I9&]R($Q$05`N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S87-L+G!H<#HX-PHC+"!F=7IZ>0IM<V=I9"`B1F%I;&5D
M('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R(")&86QL
M;W4@\R!A8G)I<B!A(&-O;F5X:?-N($Q$05`@82`E<RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C0Y-R!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C<R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O
M(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R(")&86QL;W4@\R!C;VYE8W1A<B!C
M;R!S97)V:61O<B!,1$%0+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-#8Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@
M<F5T<FEE=F4Z("5S(@IM<V=S='(@(D9A;&QO=2#S(')E8W5P97)A<B!O($1.
M(&1O('5S=6%R:6\Z(%LE9%T@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X"B,L(&9U
M>GIY"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B17)R;R!D92!I;7!O
M<G1A8VGS;CH@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A>"(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS-#D*(RP@9G5Z>GD*;7-G:60@(D9A>&5S
M(@IM<V=S='(@(D9A>"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS
M9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0*;7-G:60@(D9I96QD
M(&UA=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,S,T"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X"FUS9VED(")&:6=L970@9F]N
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ
M>0IM<V=I9"`B1FEL92(*;7-G<W1R(")4[71U;&\B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O
M=6YT.B`E<R!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S
M(&9I;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,#<*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX-0HC+"!F=7IZ>0IM<V=I9"`B1FEL92!.
M86UE(@IM<V=S='(@(DYO;64B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.3DU"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#@V"FUS9VED(")&:6QE('5P;&]A
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HX-3D*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G:60@
M(D9I;'1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N
M9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED
M(")&:7)S="!(86QF(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(U-@IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S$*;7-G
M:60@(D9L:7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C$*;7-G:60@(D9O9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`W
M"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T
M('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S,T"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-SD*;7-G:60@(B(*(D9O
M<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@
M<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R
M(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O
M<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#8R"FUS9VED(")&;W)M<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&
M;W)T=6YE('1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,X"B,L(&9U>GIY"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R(").;W1A
M<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N
M97,@,B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#4S"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$P.0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM
M<V=I9"`B1G(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PHC+"!F=7IZ>0IM<V=I9"`B1G)A
M;65S(@IM<V=S='(@(DYO;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S
M"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDQ(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(T."!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S8P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT
M,#8*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHT.`HC+"!F=7IZ>0IM<V=I9"`B1G5L;"!$
M97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FEC:?-N(&-O;7!L971A.B(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V
M"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-C`*(RP@9G5Z>GD*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R(").;VUE.B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS
M,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T
M92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")':79E;B!.86UE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED
M(")';R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*
M;7-G:60@(D=O961E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R.`IM<V=I9"`B1V]O9VQE($UA<',B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I
M9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,W"FUS9VED(")'<F%Y<V-A;&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B1W)E96L@
M*$E33RTX.#4Y+3<I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R
M965N;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'
M<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HS,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE
M('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L('!H<"UF
M;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O
M=7`@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C,S."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U
M<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0W,`HC+"!F=7IZ>0IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(D%X
M96YD82!D92!E;F1E<F5Z;W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'=6EN96$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=6EN96$M0FES<V%U
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV,`IM<V=I9"`B
M2%1-3"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O
M(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10
M($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@P"FUS9VED(")(86ET:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.CDQ.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.3,R"FUS9VED(")(96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A
M;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3
M=&]R;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM
M<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*
M;7-G:60@(DAE:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O2&5L<"YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92](96QP
M+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA
M=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G:60@(DAE;'`B"FUS9W-T<B`B07AU
M9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q"B,L(&9U>GIY"FUS9VED(")(
M96QP97(B"FUS9W-T<B`B07AU9&$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL
M93HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-CD*;7-G:60@(DAI9V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM
M:&5A9&5R+FEN8SHU"B,L(&9U>GIY"FUS9VED(")(;U]M92(*;7-G<W1R(")(
M;W)D92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N
M($-I='D@4W1A=&4I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,34S-0HC+"!F=7IZ>0IM<V=I9"`B2&]M92(*;7-G<W1R(")(
M;W)D92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D5N9&5R97IO('!A
M<G1I8W5L87(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G:60@
M(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B
M"FUS9W-T<B`B5&5LZ69O;F\@<&%R=&EC=6QA<B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM
M<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED
M(")(;VYG($MO;F<B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C8U"FUS9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#0R"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E
M<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#,U"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@
M='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(U,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E
M<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN
M92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4P,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N
M97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DS"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN
M8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$S,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,S0P
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H
M87)E(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I
M9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y
M;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L
M=6UN<RD@87)E('1H97)E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@
M;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C,P"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4Y"FUS9VED(")(=6UI
M9&ET>3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM
M<V=I9"`B2'5N9V%R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G5S+G!H<#HQ-S(@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN
M<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E
M871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G5S+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S
M<6PN<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@
M9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G5S+G!H<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)S<6PN<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB
M;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S$V"B,L(&9U>GIY"FUS9VED("))
M4"!!9&1R97-S(@IM<V=S='(@(D5N9&5R97IO(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@
M86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0
M(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED
M("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R
M"FUS9VED("))8V5L86YD(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-S8*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(DEC;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S<W"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B261E;G1I='DG
M<R!N86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@
M;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N
M97<@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#4U"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U
M<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K
M("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ-S,*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U
M="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG
M="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*
M;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED
M("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS
M9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM86=E('5P;&]A9"(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B
M26UA9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N
M:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E
M<"`E9"(*;7-G<W1R(")#86UP;R!I;7!O<G1A9&\Z("5S(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(D-A;7!O(&EM<&]R=&%D;SH@
M)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("))
M;7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(D-A;7!O<R!I;7!O<G1A9&]S.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,U"FUS
M9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,R"B,L(&9U>GIY"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R
M('!A<W-W;W)D+B(*;7-G<W1R(")!8VAE9W5E(&\@<V5U(&YO;64@9&4@=7-U
M87)I;R!E(&-H879E(&1E(&%C8V5S;R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@
M86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@
M(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#$*;7-G:60@(DEN9&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*
M;7-G:60@(DEN9F\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(U-PHC+"!F=7IZ>0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T
M<B`B02!S^F$@:6YF;W)M86-I\VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S,P"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A
M:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L
M=6UN($%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T
M($EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T
M"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R
M96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE
M=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E
M;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W
M(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW
M,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT
M(&YO9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A
M9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA
M=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(S.0IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI
M8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED
M("));G-E<G0@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("))
M;G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I
M9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM
M<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED
M("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C,P"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N
M<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G
M:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS
M97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I
M8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W-0IM
M<V=I9"`B26YT96=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3,S"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP
M+G!H<#HQ-S`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP
M:'`Z,C`Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP
M.C(Q,`IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI
M8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@
M240N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R
M.3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS
M-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`P"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP
M.C@Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P
M,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`*
M;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-PIM<V=I9"`B26YV86QI9"!L
M:6-E;G-E(&ME>2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$W,0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?
M:60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG
M('!A<F%M971E<G,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H
M:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W
M,PIM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED("));G9A;&ED
M('!R;V1U8W0@8V]D92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED
M('!R;W1O8V]L+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E
M8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,3`W-B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R
M-C(*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$Q"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U-PIM<V=I9"`B26YV96YT
M;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-SD*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@
M(DES;&4@;V8@36%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R
M-0IM<V=I9"`B27-S=65R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,@HC+"!F=7IZ>0IM<V=I9"`B271A;'DB"FUS
M9W-T<B`B1&EA<FEA;65N=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I
M8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@S"FUS9VED(")*87!A;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X-PIM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`IM
M<V=I9"`B(@HB2F%V87-C<FEP="!H87,@8F5E;B!D:7-A8FQE9"!O;B!Y;W5R
M(&)R;W=S97(@86YD('1H:7,@<&%G92!M87D@;F]T(&)E("(*(F1I<W!L87EI
M;F<@8V]R<F5C=&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU
M<W1I9GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V-`IM<V=I9"`B2V5E
M<"!O<FEG:6YA;#\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+
M96YY82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N
M<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E
M871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+
M97D@3&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*(RP@9G5Z>GD*
M;7-G:60@(DME>2!5<V%G92(*;7-G<W1R(")-96YS87AE(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR96%D
M>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O
M<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS
M9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*
M;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(DQI;F=U82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S
M="!(86QF(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW
M-@IM<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM
M<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,34Q"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HW,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S
M="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HW,38*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW.0HC+"!F=7IZ>0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@
M(E!E8VAA<B!A('-E<VGS;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B
M;W)D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A;F]N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$Y"FUS9VED("),969T(&AE861E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$U
M"B,L(&9U>GIY"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R(")%>&5M<&QO
M(&1E('9A;&]R97,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC
M+"!F=7IZ>0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B3G5N8V$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y
M"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I
M9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B3&EG
M:'0@4F%I;B(*;7-G<W1R(")%;G1R87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS
M9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@
M4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-`HC
M+"!F=7IZ>0IM<V=I9"`B3&EN:R(*;7-G<W1R(")%;G1R87(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*
M;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H92!E;6%I;"!A
M9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M
M;#)T97AT+G!H<#HQ.#,*;7-G:60@(DQI;FMS(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B
M3&ES="!$871A8F%S97,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:&5L<"]I
M;F1E>"YP:'`Z-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B
M3&ES=&%R(&]S('1E;6%S(&1E(&%X=61A(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$S,@IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.30*;7-G:60@(DQI<W0M
M07)C:&EV92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE
M861E<G,N<&AP.C4X.0HC+"!F=7IZ>0IM<V=I9"`B3&ES="U(96QP(@IM<V=S
M='(@(DQI<W1A<B!O<R!T96UA<R!D92!A>'5D82(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR
M"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU
M.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),:7-T+55N
M<W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE
M9#H@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"B,L
M('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC
M.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A
M='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M;6%G97,N<&AP.C@S"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3$*;7-G:60@(DQO8V%L
M('1I;64Z("(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#,*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,2!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-C0*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R
M(&QI8B]";&]C:R]M971A<BYP:'`Z-C4*;7-G:60@(DQO8V%T:6]N(@IM<V=S
M='(@(B(*"B,Z(&QO9VEN+G!H<#HQ-S(@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$Y,2!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E
M;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I;B(*;7-G<W1R(")%;G1R87(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O
M9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$X-0IM<V=I9"`B3&]G(&]U="(*;7-G
M<W1R(")096-H87(@82!S97-I\VXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(@IM<V=S='(@(D5N=')A<B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*(RP@9G5Z>GD*;7-G:60@
M(DQO9VEN(%1A<VMS(@IM<V=S='(@(E1A<F5F87,B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY.38*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(&9A:6QE
M9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R
M960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*(E!O<B!A;&=U;FAA(')A>O-N
M(&YO;B!S92!D974@:6YI8VEA9&\@82!S97-I\VXN(%!R;V)A8FQE;65N=&4@
M97-C<FEB:74@(@HB:6YC;W)R96-T86UE;G1E(&\@;F]M92!D92!U<W5A<FEO
M(&]U(&$@8VAA=F4@9&4@86-C97-O+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDY,@IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8U"B,L(&9U>GIY"FUS9VED
M("),;VYG('1E>'0B"FUS9W-T<B`B4&5C:&%R(&$@<V5S:?-N(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS
M9VED("),;W<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E
M96L@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L
M871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R
M(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED
M("),=7AE;6)O=7)G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#`*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0S."!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU
M,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C@Q"FUS9VED(")-3U1$(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU4
M3D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A
M<V-A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*
M(RP@9G5Z>GD*;7-G:60@(DUA9VEC(@IM<V=S='(@(D-O<G)E;R(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,0IM<V=I9"`B36%I;"(*;7-G<W1R
M(")#;W)R96\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(R"FUS
M9VED(")-86EL($%D;6EN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K
M92!L:6Y?:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*
M;7-G:60@(DUA;&%W:2(*;7-G<W1R(")#;W)R96\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*
M;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I
M9"`B36%L9&EV97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"B,L(&9U>GIY
M"FUS9VED(")-86QI(@IM<V=S='(@(D-O<G)E;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC
M+"!F=7IZ>0IM<V=I9"`B36%L=&$B"FUS9W-T<B`B0V]R<F5O(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDQ"FUS9VED("(B"B)-86YA9V4@=&AE(&QI
M<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H
M+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R
M:65S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3$U,PIM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#@T
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,38X
M"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"B,L(&9U
M>GIY"FUS9VED(")-87)G:6XB"FUS9W-T<B`B079I<V\B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W
M:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I
M=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N9',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS
M9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B0V%M<&]S(&-O<G)E<W!O
M;F1E;G1E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA
M>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(Y.`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM
M=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I
M9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B365M8F5R<R(*;7-G<W1R(")-96UO<F%N
M9&]S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.`IM<V=I9"`B365N
M=2!M;V1E.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R(")-96YS
M87AE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,38*
M;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T
M:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF
M:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@
M97AP:7)E9"XB"FUS9W-T<B`B365N<V%X92(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*(RP@
M9G5Z>GD*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")-96YS87AE(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@
M(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3$R"B,L(&9U>GIY"FUS9VED("(B"B)-971A
M<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G
M960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")297AI<W1RX7)O
M;G-E(&]S(&1E=&%L;&5S('!A<F$@;R!A9&UI;FES=')A9&]R+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DUE=&%R1$(@
M:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO
M4E!#+U)00R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T
M:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW-"!L:6(O
M0FQO8VLO;65T87(N<&AP.C<U"FUS9VED(")-971R:6,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDU"FUS9VED(")-97AI8V\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<V"B,L(&9U>GIY"FUS9VED(")-:61D;&4B"FUS9W-T
M<B`B0V]R<F5O(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE
M9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,Q,`IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H
M;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`R
M"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN
M:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C,T"B,L(&9U>GIY"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B17)R;R(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E
M($A45%!?4F5Q=65S="XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$Q-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9
M;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E
M('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B
M36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B
M36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*
M;7-G:60@(DUO(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HW-`IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DUO
M9&5R871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@X"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM
M<V=I9"`B36]D:69Y(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8W,PIM<V=I9"`B36]D=6QU<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-`IM<V=I9"`B36]N
M=&@@86YD('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA
M;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R
M(")-96YS=6%L;65N=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R
M870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L
M;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-S(@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,C4S"B,L('!H<"UF;W)M870*;7-G:60@(DUO
M<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@
M)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-
M;W-T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M-3`Y"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$S"FUS9VED(")-;W9E($QE9G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z-3$W"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P-0IM<V=I9"`B36]V92!5
M<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PHC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED
M(")-;W9E('5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z
M86UB:7%U92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,3@T"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P-34*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0R"FUS9VED(")-=6QT:7!L
M92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0P,`IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@(DUY($%C
M8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B02!S^F$@:6YF;W)M86-I\VXB
M"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C4T"FUS9VED(")->2!0
M;W)T86PB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP
M.C$S-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/
M+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3$@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R(").;VUE(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS
M9VED(").97!A;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE
M=&AE<FQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H
M97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@0F%S92!5
M4DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#,*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@U"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED
M(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@
M4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E(%-33"!S97)V
M97(@;F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M
M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X,`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Q"FUS
M9VED(").971W;W)K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,U"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*;7-G:60@(DYE=F5R(@IM<V=S
M='(@(DYU;F-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").97<@0V%L961O;FEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP
M.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H
M<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP
M:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N
M<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G92!T;R`E
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L
M;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@
M(DYE=R!-;V]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3F5W(%IE86QA;F0B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W
M"B,L(&9U>GIY"FUS9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`B0VAA=F4@
M9&4@86-C97-O(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C(R
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I
M<F4@;VX@)7@N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X.0HC
M+"!F=7IZ>0IM<V=I9"`B3F5W<R(*;7-G<W1R(").;W1A<R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS,#4*;7-G:60@(DYE=W-G<F]U<',B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M
M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*
M;7-G:60@(DYE>'0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C(W"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<R(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,S<V"B,L(&9U>GIY"FUS9VED(").97AT(&]P=&EO;G,B
M"FUS9W-T<B`B4F5G<F5S87(@X7,@;W!C:?-N<R(*"B,Z(&9R86UE=V]R:R]5
M22]522]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(DYI9V5R(@IM<V=S='(@(DYU;F-A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.#`*;7-G:60@(DYI9VAT
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3FEU92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.38S"FUS9VED(").;R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U
M<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z
M,3`U"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)
M4T\@:6UA9V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E
M;7!L871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HW.2!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HR-#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C8W
M"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN
M<&AP.C4P"B,L(&9U>GIY"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I
M9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").;VX@97-P
M96-I9FEC;W4@82!C;VYF:6=U<F%C:?-N('!A<F$@82!A=71E;G1I9FEC86-I
M\VX@<&]R(%-13"XB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`HC+"!F
M=7IZ>0IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R(")$97-F86-E<B!O<R!C
M86UB:6]S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*
M;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI
M<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,38W(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`R"B,Z(&9R86UE
M=V]R:R]5=&EL+U5T:6PN<&AP.C<W,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R("5S+B(*;7-G<W1R(").;VX@97-P96-I9FEC;W4@82!C;VYF:6=U<F%C
M:?-N('!A<F$@87,@8V%T96=O<NUA<R!344PN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HX,C0*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G
M<W1R(").;VX@97-P96-I9FEC;W4@82!C;VYF:6=U<F%C:?-N('!A<F$@87,@
M<')E9F5R96YC:6%S($Q$05`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HV-CD*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R(").;VX@
M97-P96-I9FEC;W4@82!C;VYF:6=U<F%C:?-N('!A<F$@87,@8V%T96=O<NUA
M<R!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<Q
M-PHC+"!F=7IZ>0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B3F]N(&5S
M<&5C:69I8V]U(&$@8V]N9FEG=7)A8VGS;B!P87)A(&%S(&-A=&5G;W+M87,@
M4U%,+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<W"FUS9VED
M(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C@@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(S
M"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-CD*;7-G:60@(DYO(&QO8V%T
M:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G
M92!S=7!P;&EE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E
M8VEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I
M9FEE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT
M"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X"FUS
M9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U
M+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E
M<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H+T%U=&@O;&]G
M:6XN<&AP.C@T"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW-0HC
M+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").;VX@97-P96-I9FEC;W4@82!C
M;VYF:6=U<F%C:?-N('!A<F$@82!A=71E;G1I9FEC86-I\VX@<&]R(%-13"XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U"B,L(&9U
M>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").;VX@97-P96-I9FEC;W4@82!C;VYF
M:6=U<F%C:?-N('!A<F$@82!A=71E;G1I9FEC86-I\VX@<&]R(%-13"XB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.#0*(RP@9G5Z>GD*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(DYO;B!E<W!E8VEF:6-O=2!A(&-O;F9I9W5R86-I\VX@
M<&%R82!A(&%U=&5N=&EF:6-A8VGS;B!P;W(@4U%,+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@<&%T
M:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,
M(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@
M9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S4P"B,L('!H<"UF;W)M
M870*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PHC+"!F
M=7IZ>0IM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`B3F]T87,B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#D*;7-G:60@(DYO('-E<&%R871O
M<B!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*(RP@9G5Z>GD*;7-G:60@
M(DYO('-I9&5S(@IM<V=S='(@(DYO=&%S(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HU.#,*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3,X"FUS9VED(").
M;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,C(Q"B,L(&9U>GIY"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@
M<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B06-H96=U92!O('-E=2!N;VUE(&1E
M('5S=6%R:6\@92!C:&%V92!D92!A8V-E<V\B"@HC.B!F<F%M97=O<FLO4E!#
M+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@
M<F5T=7)N960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDW,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HY.3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$P,#D*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S
M:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A
M=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R
M(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY
M,PHC+"!F=7IZ>0IM<V=I9"`B3F]N92(*;7-G<W1R(")496SI9F]N;R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G
M:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA
M;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]"
M;&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA
M;F$@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO
M<G=A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8T,`IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(").;W0@
M0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C0P.`IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713
M=')A=&5G>2YP:'`Z.#,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.30*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H
M<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT960N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(DYO="!S970B"FUS9W-T<B`B
M3F]T87,B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(N<&AP.C$T,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S
M<VEO;DAA;F1L97(N<&AP.C$U.`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W,PHC.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X-PHC.B!F<F%M97=O<FLO
M4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-"!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR
M,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z,C0X(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-C4*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,CDW"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,3(@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C,R.0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8R(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HT,C(*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C4P,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<P"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HU.#<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V-0IM
M<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N
M<&AP+F1I<W0Z,3`P-0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3<X
M"FUS9VED(").;W1E<R(*;7-G<W1R(").;W1A<R(*"B,Z('-E<G9I8V5S+V]B
M<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L
M(&=O(&)A8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<U"B,L(&9U>GIY"FUS9VED(").;W9E;6)E<B(*
M;7-G<W1R(").=6YC82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P
M-#8*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B(*;7-G<W1R(").;VUE(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R-0IM<V=I9"`B3G5M8F5R(&]F
M(&-H87)A8W1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(S"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#4@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU
M;6YS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S
M-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,0HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#0S('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A
M=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/
M2R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#<F5A
M=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q
M,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F
M96YS92!F:6QT97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,R-@IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@
M<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*(RP@9G5Z>GD*;7-G:60@
M(D]L9"!P87-S=V]R9"(*;7-G<W1R(")#:&%V92!D92!A8V-E<V\B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S
M=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(")/;6%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R
M<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O
M<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW,0IM<V=I9"`B3VYL
M>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE
M(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N
M97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,U"FUS9VED(")/
M<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O
M<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@
M<&%R="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI
M;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED
M(")/<'1I;VYS(@IM<V=S='(@(D]P8VGS;G,B"@HC.B!S97)V:6-E<R]P<F5F
M<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(D]P
M8VGS;G,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D]R9V%N
M:7-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,R"FUS9VED
M(")/<F=A;FEZ:6YG(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q"FUS9VED(")/=&AE<B!)
M;F9O<FUA=&EO;B(*;7-G<W1R(")/=71R82!I;F9O<FUA8VGS;B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI
M<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M
M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G
M96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$R-S,*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S$Y"FUS9VED
M(")01U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W,0IM<V=I9"`B4$=0(%!U8FQI8R!+
M97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3,U,PIM<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-C@*(RP@9G5Z>GD*;7-G
M:60@(E!(4"!#;V1E(@IM<V=S='(@(DAO<F1E(@H*(SH@861M:6XO<&AP<VAE
M;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@(E!-
M($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,SD*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-N;W<@4VAO
M=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")0
M32!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G
M<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@4VAE;&PB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V
M"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3@*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C,*;7-G:60@(E!A<W-W
M;W)D(@IM<V=S='(@(D-H879E(&1E(&%C8V5S;R(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S
M=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,3,R,@HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@
M:6YC;W)R96-T(@IM<V=S='(@(D-H879E(&1E(&%C8V5S;R(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D
M(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-3,*;7-G:60@(E!A
M<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`HC+"!F=7IZ>0IM<V=I9"`B4&%S
M<W=O<F0Z(@IM<V=S='(@(D-H879E(&1E(&%C8V5S;R(*"B,Z('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")087-S=V]R
M9#H@(@IM<V=S='(@(D-H879E(&1E(&%C8V5S;R(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D
M<R!M=7-T(&UA=&-H+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3$Y('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S
M=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I
M9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(E!E;W!L92(*;7-G<W1R
M(")&=6YC:?-N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@
M(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")296%L
M:7IA<B!O<&5R86-I\VYS(&1E(&UA;G1E;65N=&\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#`V"B,L(&9U>GIY"FUS9VED(")097)F;W)M(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(E)E86QI>F%R
M(&]P97)A8VGS;G,@9&4@;6%N=&5M96YT;R(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,34V"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@V"FUS9VED
M(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H:6QD
M+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R
M871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U
M"B,L(&9U>GIY"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R
M(")/=71R82!I;F9O<FUA8VGS;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R
M=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G
M:60@(E!E=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL
M:7!P:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R(")496SI
M9F]N;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S@*;7-G:60@
M(E!H;W1O<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0:71C
M86ER;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE
M(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER
M;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@
M=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3<Q"FUS9VED(")0;&5A<V4@96YT
M97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE
M87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P,0IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,`IM<V=I9"`B4&QE87-E
M(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES
M(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C0U,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM
M92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P
M<F]B;&5M+B(*;7-G<W1R(")!8VAE9W5E('5N(')E<W5M;R!D;R!P<F]B;&5M
M82XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO
M=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S='(@(D%C:&5G=64@;R!S
M974@;F]M92!D92!U<W5A<FEO(&4@8VAA=F4@9&4@86-C97-O(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A
M9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE
M('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM
M<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#<*
M;7-G:60@(E!O;&QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@
M(E!O<G1U9V%L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I
M;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I
M;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T
M:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8V(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R
M(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.3@*;7-G:60@(E!R96-I<&ET871I;VX\8G(@
M+SYC:&%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S
M<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-0IM<V=I9"`B
M4')E<W-U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-3D*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G:60@(E!R
M97-S=7)E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(P-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G
M92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HS-C(@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HS-C8*(RP@9G5Z>GD*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS
M9W-T<B`B4F5G<F5S87(@X7,@;W!C:?-N<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M
M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0HC+"!F=7IZ>0IM<V=I
M9"`B4')O8FQE;2(*;7-G<W1R(");26YF;W)M92!D;R!0<F]B;&5M85TB"@HC
M.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C8*;7-G:60@(E!R;V)L96T@1&5S
M8W)I<'1I;VXB"FUS9W-T<B`B1&5S8W)I8VGS;B!D;R!P<F]B;&5M82(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-CD*;7-G:60@(E!R;VIE8W1S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3$@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X.`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,C@U"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@
M(E!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C0T"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L
M:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@4FEC
M;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1871A<B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C,*;7-G:60@(E%U97)Y
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I
M9"`B475O=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI
M8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(V-`IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S
M"FUS9VED(")286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN($5A<FQY(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0U"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@4VAO
M=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0W"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS
M9VED(")286EN('1O(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T
M:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS
M,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*(RP@9G5Z>GD*;7-G:60@
M(E)E860@;65S<V%G97,B"FUS9W-T<B`B365N<V%X92(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C
M;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E
M('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T
M(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S
M="!A8W1I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#8*;7-G:60@(E)E9G)E<V@B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I
M9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$*(RP@9G5Z>GD*;7-G:60@
M(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(D%C='5A;&EZ87(@82!V
M:7-T82!D;R!R97-U;6\Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.#DT(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(S-0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(T.0IM<V=I9"`B4F5L871I
M;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P
M.`IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S(V"FUS9VED(")296UA<FMS(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,30*;7-G:60@(E)E;6]T92!397)V97)S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM
M<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D
M92DZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I
M="YI;F,Z,C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PHC
M+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(@IM<V=S='(@(E-A8V%R(&\@<&%R(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"B,L(&9U>GIY"FUS
M9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B4V%C87(@;R!P87(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34W"FUS9VED
M(")296UO=F4@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*(RP@9G5Z>GD*;7-G:60@(E)E
M;6]V92!F;W)M871T:6YG(@IM<V=S='(@(E-A8V%R(&\@<&%R(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER
M(@IM<V=S='(@(E-A8V%R(&\@<&%R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E
M<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@HC
M+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R(")386-A<B!O('!A
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D
M;V-U;65N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F4N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")296UO=F4@=7-E<B(*;7-G
M<W1R(")386-A<B!O('!A<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V92YI;F,Z-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E
M('5S97(Z("5S(@IM<V=S='(@(E-A8V%R(&\@<&%R(@H*(SH@9G)A;65W;W)K
M+U)00R]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N
M)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G:60@
M(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S0@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(D\@8V%M<&\@<F5Q=6ER:61O("=U
M:60G(&YO;B!F;VD@97-P96-I9FEC861O(&YA(&-O;F9I9W5R86-I\VX@9&%S
M("(*(G!R969E<F5N8VEA<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C8W-2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S,`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I
M;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB3R!C86UP;R!R97%U
M:7)I9&\@)W5I9"<@;F]N(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N9FEG=7)A
M8VGS;B!D87,@(@HB<')E9F5R96YC:6%S+B(*"B,Z(&9R86UE=V]R:R]5=&EL
M+U5T:6PN<&AP.C<X,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q
M=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B(@HB3R!C86UP;R!R97%U:7)I9&\@)W5I9"<@;F]N(&9O:2!E
M<W!E8VEF:6-A9&\@;F$@8V]N9FEG=7)A8VGS;B!D87,@(@HB<')E9F5R96YC
M:6%S+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S
M-0IM<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R,"!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"B,L(&9U>GIY"FUS9VED(")2
M97-E="!087-S=V]R9"(*;7-G<W1R(")#:&%V92!D92!A8V-E<V\B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U
M<B!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3,P"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A
M9&UI;B]S<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T
M97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*
M;7-G<W1R(")296=R97-A<B#A<R!O<&-I\VYS(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO
M;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,R"B,L
M(&9U>GIY"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T
M<B`B4F5G<F5S87(@X7,@;W!C:?-N<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@
M(E)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,C$*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$W"FUS9VED(")2:6=H="!V86QU97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R(")&=6YC:?-N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(U"FUS9VED(")2
M;W1A=&4@,3@P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,C(*;7-G:60@(E)O=&%T92!,969T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,C@*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS
M9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2
M;W<@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU,PHC+"!F=7IZ>0IM<V=I9"`B4G5L97,B"FUS9W-T<B`B1G5N
M8VGS;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@
M86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R
M;W=S(&]N;'DB"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R
M,`IM<V=I9"`B4G5N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@
M(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S
M"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P
M:&EC(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-
M97-S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S
M;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C4P-`HC+"!F=7IZ>0IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R
M(")-96YS87AE(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED(")3
M44P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S(X,PIM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Q
M"FUS9VED(")34T@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I
M9"`B4U5#0T534R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-3,*;7-G
M:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E
M(&%N9"!-:7%U96QO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED
M(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR
M"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W
M"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL
M:71E(%!R;W9I9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@
M(E-A=61I($%R86)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VQA>6]U="YI;F,Z.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4V%V92`E<R(*;7-G<W1R(")'87)D87(@87,@;W!C:?-N<R(*"B,Z('1E
M;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*
M;7-G<W1R(")'87)D87(@87,@;W!C:?-N<R(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R
M87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E-C
M871T97)E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(P"FUS9VED(")396%R8V@@
M16YG:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.3<S"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-`HC+"!F=7IZ
M>0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")396QE8V-I;VYE(&\@
M9F]R;6%T;R!D82!D871A.B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L
M96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V"FUS9VED
M(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"FUS9VED(")396QE
M8W0@86QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(V-C,*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE
M;G1S+B(*;7-G<W1R(")396QE8V-I;VYE(&\@9F]R;6%T;R!D82!D871A.B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*
M;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.`IM<V=I9"`B4V5L
M96-T(&YO;F4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP
M.C,W"B,L(&9U>GIY"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@
M>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C
M;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS
M9W-T<B`B(@HB4V5L96-C:6]N92!O<R!C87)A8W1E<F5S('%U92!N96-E<VET
M92!D87,@8W5A9'+M8W5L87,@<75E(&%T;W!A<N$@;6%I<R`B"B)A8F%I>&\N
M(%!O9&4@8V]P:6%L;W,@92!P96=A;&]S(&1E;F1E(&$@X7)E82!D92!T97AT
M;RXB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L
M96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B4V5L96-C:6]N92!O
M(&1E;&EM:71A9&]R(&1A(&1A=&$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S
M='(@(E-E;&5C8VEO;F4@;R!F;W)M871O(&1A(&1A=&$Z(@H*(SH@=&5M<&QA
M=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T
M('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"B,L(&9U>GIY"FUS9VED
M(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R(")396QE8V-I
M;VYE(&\@9&5L:6UI=&%D;W(@9&$@9&%T83HB"@HC.B!T96UP;&%T97,O9&%T
M82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB
M"FUS9W-T<B`B4V5L96-C:6]N92!O(&9O<FUA=&\@9&$@:&]R83HB"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE8W0@='=O
M(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B4V5L96-C:6]N92!D;W5S(&-A
M;7!O<R!Q=64@8V]I;F-I9&%N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,#8*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T.`IM<V=I9"`B4V5L
M96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R(")396QE8V-I
M;VYE(&$@;&EN9W5A.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(D5N
M=FEA<B!O(&EN9F]R;64@9&4@<')O8FQE;6%S(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,SD*;7-G:60@(E-E;F0@4TU3
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,38*;7-G:60@(E-E
M;G-O<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@
M(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B4V5R:6%L($YU
M;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,38Q"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA
M8FQE+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*;7-G
M:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S
M:6]N($E$(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T
M-0HC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B1V%R9&%R(&%S
M(&]P8VGS;G,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$T"FUS
M9VED(")3970B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<V"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@
M>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(E-E="!U
M<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M
M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#0*(RP@9G5Z>GD*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B
M(@HB17-T86)L96-E(&$@9G)E8W5E;F-I82!D92!A8W1U86QI>F%C:?-N(&1A
M<R!PX7AI;F%S(&4@;W5T<F%S(&]P8VGS;G,@9&4@(@HB=FES=6%L:7IA8VGS
M;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*(RP@9G5Z>GD*;7-G
M:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C
M:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O
M<'1I;VYS+B(*;7-G<W1R("(B"B)%<W1A8FQE8V4@82!F<F5C=65N8VEA(&1E
M(&%C='5A;&EZ86-I\VX@9&%S('#A>&EN87,@92!O=71R87,@;W!C:?-N<R!D
M92`B"B)V:7-U86QI>F%C:?-N+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-S4*;7-G:60@(E-E='5P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E
M('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ.#8*;7-G:60@(E-E=F5R86P@;&]C871I;VYS
M('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y-@IM<V=I9"`B4VAO<'!I;F<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M-#,*(RP@9G5Z>GD*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B4F5S
M=6UO(&)R979E.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#8*;7-G
M:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI
M;FMS/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S
M(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A
M=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT.3`*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE
M('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3<V-0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O
M<FEG:6YA;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.#$S"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3(V"FUS9VED(")3:&]W('1A8FQE(&]P97)A
M=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@
M365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3
M:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L
M92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS
M9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8S"FUS9VED(")3
M:&]W('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM
M<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R!,
M871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HT.#`*;7-G:60@(E-H<FEN:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW-S0@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z.#,V"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.CDR,B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HY.#0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`T
M-R!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#@W"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q,38@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$T.0IM<V=I9"`B4VAR:6YK(&]R
M(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I
M<G-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,
M96]N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,C8U"FUS9VED(")3:6=N('5P(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HW,3$*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@W(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$U
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,P
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*;7-G:60@(E-I>F4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA
M;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B
M3VUI=&ER(&\@;6%N=&5M96YT;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L
M;W9A:VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E
M;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4T"FUS9VED(")3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W
M(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W
M"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N
M;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C<X"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U:79A;&5N
M="!I;B!W871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@
M(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS
M9VED(")3;VUA;&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(V"FUS9VED(")3;W)T(&]R9&5R
M('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"B,L(&9U>GIY"FUS9VED
M(")3;W5R8V4@861D<F5S<R(*;7-G<W1R(")%;F1E<F5Z;R!D;R!T<F%B86QL
M;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B4V]U=&@@
M175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H
M($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S
M(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P
M:&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N
M="!C96QL<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT
M96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HX,34*;7-G:60@(E-P86-E<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B
M4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM
M<V=I9"`B4W!A:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.CDX"FUS9VED(")3<&%M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP
M=70B"FUS9W-T<B`B16YT<F%D82!D92!C87)A8W1E<F5S(&5S<&5C:6%I<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I
M9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET
M(')O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*
M(RP@9G5Z>GD*;7-G:60@(E-P;W)T<R(*;7-G<W1R("));7!O<G1A<B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,R!L:6(O0FQO8VLO;65T87(N
M<&AP.C<T"B,L(&9U>GIY"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R(")#86QE
M;F1A<FEO(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3
M=&%R(%1R96LB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C4Y-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`Y"FUS9VED(")3
M=&%R="!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3<P"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ
M,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,34*(RP@9G5Z>GD*;7-G:60@(E-T;W)A9V4@9F]R;6%T
M(@IM<V=S='(@(D$@<_IA(&EN9F]R;6%C:?-N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(*(RP@9G5Z>GD*;7-G:60@(E-T<F5E
M="!!9&1R97-S(@IM<V=S='(@(D5N9&5R97IO(&1O('1R86)A;&QO(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I
M9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I
M<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS
M9VED(")3='EL92!;0U-372(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R
M("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R(").;VX@<V4@871O<&]U(&\@87AE;G1E(&1E(&YO=&EF:6-A
M8VGS;B`E<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,S,B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E
M;F1E<F5R+G!H<#HS,3<*;7-G:60@(E-U8FUI="(*;7-G<W1R("(B"@HC.B!S
M:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E
M9"!R97%U97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A
M;B!N;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A
M<'!R;W9E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR
M.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R(")#;W)R96-T86UE;G1E(@H*(SH@
M861M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O
M;2!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I
M9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A
M9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED
M(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M('5P9&%T960@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V
M"B,L(&9U>GIY"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(E)E<W5M;R(*"B,Z
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3
M=6X@4V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3=6YN>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")3=6YR:7-E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-0IM
M<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,3D*;7-G:60@(E-U;G-E="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$X"FUS9VED(")3=6YS
M970Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<X"B,L(&9U>GIY"FUS
M9VED(")3=7!P;W)T(@IM<V=S='(@(DEM<&]R=&%R(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-@HC+"!F=7IZ>0IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B57-U87)I;R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"B,L(&9U
M>GIY"FUS9VED(")3=7)N86UE(@IM<V=S='(@(E5S=6%R:6\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC(&QO9R!D
M96QE=&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-#(*;7-G:60@(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,
M+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S
M96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B
M4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E0M4W1O<FTB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS
M9VED(")4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;7,@16%R;'DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$V
M-@HC+"!F=7IZ>0IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B5.UT=6QO(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ,S0*(RP@9G5Z>GD*;7-G
M:60@(E1A8FQE(@IM<V=S='(@(E3M='5L;R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE
M(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@4V5T(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS
M9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O
M9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDU"FUS9VED(")487)G970Z(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]H;V]K<RYP:'`N9&ES=#HY.38@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$X-PIM<V=I9"`B5&%S:W,B"FUS9W-T<B`B5&%R969A<R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")496QE
M<&AO;F4@3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,CDP"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-`IM<V=I9"`B5&5M<&5R871U
M<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(R,PIM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDS"B,L('!H<"UF;W)M870*;7-G
M:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H
M<#HV.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S,S-@IM<V=I9"`B5&5X="(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<U"FUS9VED(")497AT($]N;'DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS
M9VED(")497AT=&]P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")4:&%I("A425,M
M-C(P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4:&%I;&%N
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*
M(RP@9G5Z>GD*;7-G:60@(E1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E
M;2XB"FUS9W-T<B`B1FEN86QI>F]U(&$@<V5S:?-N+CQB<B`O/D=R86-I87,@
M<&]R('5S87(@;R!S:7-T96UA+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z.#(P"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@
M:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+T)O;VLN<&AP
M.C$R.3(*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA
M;&EZ960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L
M;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]I;6%G
M97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD
M;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,3$@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-3(*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C0@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R
M(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B
M86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W
M87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD
M(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@8V]N
M=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B
M;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HQ,38Y"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R
M92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO
M;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N
M:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E
M8VEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N
M<&AP.C$Q,PIM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER
M92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S4@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HU,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@
M<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V."!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E
M<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,3D*;7-G:60@(E1H
M92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.#`*;7-G:60@(E1H
M92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4
M:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E
M+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L
M;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H
M($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H
M870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@
M97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R
M(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF
M("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L
M>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A
M=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W
M87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@
M=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!R969S+G!H<#HY,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$U-PIM
M<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S
M="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR,#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E
M<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*
M(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E
M96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#<W"FUS9VED(")4:&4@;F%M92!T;R!U<V4@
M=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Q"B,L(&9U>GIY"FUS
M9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM
M<V=S='(@(D\@=F%L;W(@9&5B92!S97(@=6X@;OIM97)O+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,0IM<V=I9"`B5&AE(&]P
M96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?
M<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R
M969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET
M<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V1E
M8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O96YS8W)I
M<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS<&]W
M97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E8F-P
M<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<W)C:&EG
M:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS
M97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G
M<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@
M9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z-#4T"FUS9VED(")4:&4@<75O=&4@8VAA<F%C
M=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT
M-#8*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H
M87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U
M;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S
M7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C,S
M,`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3<W"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@
M9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,S,3$*;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D(&1I
M9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,S(W"FUS9VED
M(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO
M=7,@<W1E<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]C
M<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,3<R"FUS
M9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-38*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$Q-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3$Y"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP
M.C(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E
M<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ-S@*(RP@9G5Z>GD*;7-G:60@(E1H97)E(&%R92!N
M;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`B3F]N(&AA:2!P<F5F97)E
M;F-I87,@9&ES<&_Q:6)L97,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z,S0R"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA
M="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I
M96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M
M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P
M+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y
M<W1E;3H@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I
M;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS
M9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@T"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO
M("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.#@Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H
M92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S
M:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W
M<V5R+T)R;W=S97(N<&AP.C@Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@
M)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A
M9V4@<&%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#`*;7-G:60@(B(*(E1H
M97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!0
M97)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O
M<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L
M96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@
M9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES
M=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C$T.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T
M('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HU,@IM
M<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@
M9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$T-0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E
M(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(D\@=F%L;W(@9&5B92!S
M97(@=6X@;OIM97)O+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L
M;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T
M:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T
M<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M22(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH
M='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E
M<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H
M('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F
M;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET
M:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,#@V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C4V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#4@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y.`HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-34W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,SD*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU."!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#`U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,CD@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`W.`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,30Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C$*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q,"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-#4T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V
M-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S
M,#8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q-"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS.#(R"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I
M<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,#8U"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E
M<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T
M,3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S
M(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A
M(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX.0HC+"!F
M=7IZ>0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R
M+B(*;7-G<W1R(")/('9A;&]R(&1E8F4@<V5R('5N(&[Z;65R;RXB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V"FUS9VED("(B"B)4:&ES(&9I
M96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@
M9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI<R!F
M;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&ES(&ES("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C0U.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES
M(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B
M:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N
M9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L
M:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z-3DQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@
M=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO
M=7(@;W=N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S
M="!O;F4N(@IM<V=S='(@(D\@;OIM97)O(&1E8F4@<V5R('!O;&\@;65N;W,@
M=6X@,2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP
M:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP
M(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@
M:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU
M92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R(")/('9A;&]R(&1E8F4@<V5R
M('5N(&[Z;65R;RXB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N
M<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M
M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4:'5N9&5R(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S0*;7-G
M:60@(E1I8VME=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C0R."!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@
M9G5Z>GD*;7-G:60@(E1I;64B"FUS9W-T<B`B5.UT=6QO(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,X-@IM<V=I9"`B5&EM92!4<F%C:VEN9R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I
M;64@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(U,SD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(E3M
M='5L;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I
M9"`B5&\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE
M(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD
M("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B5&]D87DB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$S"FUS9VED(")4;VUO<G)O=R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A
M;64@*%]T;W`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV,PIM<V=I9"`B5')A;G-L871I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B5')U92!O
M<B!F86QS92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y,@IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC
M;W,@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4
M=79A;'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(V
M-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-CD*;7-G:60@(E4N5BX@:6YD
M97@Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED
M(")54DPB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S
M8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"B,L(&9U
M>GIY"FUS9VED(")54DPZ(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*
M;7-G:60@(E5G86YD82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED
M(")5:W)A:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C0Q,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!6
M1E,@9&ER96-T;W)Y+B(*;7-G<W1R(").;VX@9F]I('!O<VEB;&4@8V]N96-T
M87)S92#S('-E<G9I9&]R(%-13"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E
M<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S@X"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HS.#4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I
M;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C<U-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B3F]N(&9O
M:2!P;W-I8FQE(&-O;F5C=&%R<V4@\R!S97)V:61O<B!344PN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8X."!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S-0IM<V=I9"`B
M56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B3F]N
M(&9O:2!P;W-I8FQE(&-O;F5C=&%R<V4@\R!S97)V:61O<B!344PN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,SD*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R(").;VX@9F]I
M('!O<VEB;&4@8V]N96-T87)S92#S('-E<G9I9&]R(%-13"XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,C4@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P,0HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B3F]N(&9O
M:2!P;W-I8FQE(&-O;F5C=&%R<V4@\R!S97)V:61O<B!344PN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-C4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S4T(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C(U-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE
M('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").;VX@9F]I('!O
M<VEB;&4@8V]N96-T87)S92#S('-E<G9I9&]R(%-13"XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R(").;VX@9F]I('!O<VEB
M;&4@8V]N96-T87)S92#S('-E<G9I9&]R(%-13"XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-C4*(RP@9G5Z>GD*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@
M(DYO;B!F;VD@<&]S:6)L92!C;VYE8W1A<G-E(/,@<V5R=FED;W(@4U%,+B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW.0IM<V=I
M9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,C0@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HR.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS
M+V1E;&5T92YP:'`Z-#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B3F]N(&9O:2!P
M;W-I8FQE(&UO9&EF:6-A<B!A<R!P<F5F97)E;F-I87,Z(%LE9%T@)7,B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S$@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HS.3(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C,Q,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S,T"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D
M:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#@@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,U,@IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HS,S<@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T-`HC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").;VX@9F]I
M('!O<VEB;&4@8V]N96-T87)S92#S('-E<G9I9&]R(%-13"XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0Q-R!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C0R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C(P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S`S(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,C@X"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HQ-C<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X,`HC.B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HS.#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C,Y,0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HT,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@P,PHC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B3F]N(&9O:2!P;W-I8FQE(')E>&ES=')A<B!A<R!P<F5F97)E;F-I87,@
M;F$@<V5S:?-N+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C`S"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D
M971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0
M+G!H<#HT-3$@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T:"YP:'`Z,3$X
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I
M;FET:6]N(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`Q
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-C8@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W,0HC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(DYO;B!F;VD@<&]S
M:6)L92!C;VYE8W1A<G-E(/,@<V5R=FED;W(@4U%,+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z.3,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HQ,#(*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV-#@@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HY.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W-R!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ,S,*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M(&9O<B!W<FET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HX,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S`*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R"B,L(&9U>GIY
M"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B3F]N
M(&9O:2!P;W-I8FQE(&-O;F5C=&%R<V4@\R!S97)V:61O<B!344PN(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT-0HC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*
M;7-G<W1R(").;VX@9F]I('!O<VEB;&4@8V]N96-T87)S92#S('-E<G9I9&]R
M(%-13"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#,U"FUS9VED(")5
M;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8V"FUS9VED
M(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL
M960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O
M4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R
M96%D(&9I;&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HV-CD*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HQ,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X
M:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,CDS"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYO;B!F;VD@<&]S:6)L92!C;VYE8W1A
M<G-E(/,@<V5R=FED;W(@4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,S(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,C8W(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HV,3`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C,R,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(X-0HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R
M=6X@)VUK:7-O9G,G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A
M;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R(").;VX@9F]I('!O
M<VEB;&4@=')A9'5C:7(@97-T92!D;V-U;65N=&\@9&4@5V]R9"(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,30Y(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,34R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W
M<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C$W.0IM<V=I9"`B56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$T,PIM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-#$*
M;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B
M92!E>&-E961E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N
M9&\@0VAA;F=E<R(*;7-G<W1R(")$97-F86-E<B!O<R!C86UB:6]S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I
M9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y,`IM<V=I9"`B56YE
M>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,T,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS-S@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S@T"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O
M.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E5N:6-O9&4@*%54
M1BTX*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R
M86(@16UI<F%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5
M;FET960@2VEN9V1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED
M(")5;FET960@4W1A=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G
M:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HW,0IM<V=I9"`B56YI=',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S,`IM<V=I9"`B56YK;F]W;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S
M86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L:6US
M9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@(E5N:VYO=VX@;&]C
M871I;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W
M;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS
M9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C(Y-@HC+"!F=7IZ
M>0IM<V=I9"`B56YN86UE9"(*;7-G<W1R(")5<W5A<FEO(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB
M56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]0
M87-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N
M("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA
M+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T
M('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS
M9VED(")5;G-E="!C;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8X-B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.CDR-@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.CDS,@IM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-@IM<V=I9"`B
M57!D871E('5S97(B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ
M-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E
M9&ET+G!H<#HR,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S
M"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ.3D*;7-G:60@(E5P;&]A9"(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO
M861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E
M<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T
M=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N
M=6UB97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U
M87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U
M<G)E;G0Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E5S
M92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V
M97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I
M="YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(E5S97(B"FUS9W-T<B`B57-U87)I
M;R(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S(S
M"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES
M960@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*
M;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR-3$*;7-G:60@(E5S97(@3W!T
M:6]N<R(*;7-G<W1R(")/<&-I\VYS(&1O('5S=6%R:6\B"@HC.B!S:6=N=7`N
M<&AP.C8R"B,L(&9U>GIY"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G
M<W1R(")/<&-I\VYS(&1O('5S=6%R:6\B"@HC.B!S:6=N=7`N<&AP.C(R"FUS
M9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M=&AI<R!S:71E+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S
M='(@(E5S=6%R:6\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A
M;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C@W"B,L(&9U>GIY"FUS9VED(")5<V5R;F%M93HB"FUS
M9W-T<B`B57-U87)I;R(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C@*(RP@9G5Z>GD*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B57-U87)I
M;R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@
M(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,38S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(U-0IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM
M<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#8V"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC
M;'5D93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C,X"FUS9VED(")686QI9&ET>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@U-B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E
M(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0T(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R-C8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,Q-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(X"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T
M;R!S96QE8W0@9G)O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")686YU871U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-#0*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I
M8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A
M;7!E<F5D('=I=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")697)S:6]N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C8*;7-G:60@(E9E<G-I
M;VX@0V]N=')O;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A
M;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B5F5R>2!(
M:6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I970@3F%M
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED
M(")6:65T;F%M97-E("A625-#24DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDV,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")6:65W("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N
M<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N
M9',L(%4N4RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,#D*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(V,PIM<V=I9"`B5FES:6)I;&ET>3H@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET
M86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU4
M4"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H
M<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y5
M04Q,62!&4D]-("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T
M=6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")!=FES;R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G
M:60@(E=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#(W"FUS9VED(")796%T
M:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.#DR"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S<*;7-G
M:60@(E=E8B!3:71E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N
M86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R
M(")396UA;F%L;65N=&4B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H
M<#HR.`HC+"!F=7IZ>0IM<V=I9"`B5V5L8V]M92(*;7-G<W1R(")"96YV:61O
M+V$L("5S(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H<"UF;W)M870*;7-G:60@
M(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B0F5N=FED82!A("5S(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M
M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM
M<V=S='(@(D)E;G9I9&\O82P@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y-0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*;7-G:60@(E=E<W1E<FX@*$E3
M3RTX.#4Y+3$U*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S
M=&5R;B!386AA<F$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N
M('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I
M<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE
M('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C$*;7-G:60@(E=H97)E:7,@
M075S=')A;&EA(&UA<"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3,S"FUS9VED(")7:&EC:"!P;'5G:6YS('1O
M(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,C4*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4W"B,L('!H
M<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L
M969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED
M(")7:61T:"!U;FET(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q,PIM<V=I9"`B
M5VEK:2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S`P(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U
M"FUS9VED(")7:6YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")7:6YD($5A<FQY(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@
M<W!E960@:6X@:VYO=',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-38*;7-G:60@(E=I;F0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-#(*;7-G:60@(E=I;F0Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O
M;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DV
M"FUS9VED(")7:7-H;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K
M($%D9')E<W,B"FUS9W-T<B`B16YD97)E>F\@9&\@=')A8F%L;&\B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED
M(")7;W)K(%!H;VYE(@IM<V=S='(@(E1E;.EF;VYO(&1O('1R86)A;&QO(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,38Y(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N
M9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F
M;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z,S`P"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O
M9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3$T"B,L('!H<"UF;W)M
M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93
M(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR-#,*;7-G:60@(E@M4F5F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@0F%S:6,@
M0V]N<W1R86EN=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.3(*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@
M57-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E
M($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF
M:65R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C@R"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`B
M04$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-34*(RP@9G5Z>GD*;7-G:60@(EE965DB"FUS9W-T<B`B04$B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$P.`IM<V=I9"`B
M66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N
M8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`B
M06YU86QM96YT92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HY-C,*;7-G:60@(EEE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G
M<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@
M57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'
M+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z.#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C
M<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#$Q"FUS9VED(")9;W4@87)E(&YO
M="!A=71H96YT:6-A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E
M;G1I='DO261E;G1I='DN<&AP.C,P,@IM<V=I9"`B66]U(&-A;B!N;W0@:&%V
M92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3DW-0IM<V=I9"`B66]U(&1I9"!N;W0@96YT
M97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1&%T82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E
M9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"B,L
M(&9U>GIY"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S
M='(@(D%C='5A;&EZX7)O;G-E(&%S('/Z87,@;W!C:?-N<RXB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V92!T
M;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY
M('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA
M;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!V86QU92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$
M871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0U-@IM<V=I9"`B66]U(&UU
M<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S
M="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H
M92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B1&5S8W)I8F$@;R!P<F]B;&5M
M82!A;G1E<R!D92!E;G9I87(@;R!I;F9O<FUE+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T
M(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM<V=I
M9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO=2!M
M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E
M8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B(@H*(SH@861M
M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A
M9&0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H
M<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@
M<&5R9F]R;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO=2!M=7-T('1Y<&4@
M82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@
M(EEO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<V"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E
M9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R(")#861U8V]U(&$@<_IA
M('-E<VGS;B!E;B`E<R!E>'!I<F]U+B!);FEC:64@=6YH82!N;W9A('-E<VGS
M;BXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`HC+"!F
M=7IZ>0IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(D5N9&5R
M97IO(&1E(&-O<G)E;R!E;&5C='+S;FEC;SHB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C$R"B,L(&9U>GIY"FUS9VED(")9;W5R($9R;VTZ(&%D9')E
M<W,Z(@IM<V=S='(@(D5N9&5R97IO(&1E(&-O<G)E;R!E;&5C='+S;FEC;SHB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(EEO=7(@26YF;W)M871I;VXB"FUS
M9W-T<B`B02!S^F$@:6YF;W)M86-I\VXB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E
M<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I
M='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PHC+"!F=7IZ>0IM<V=I9"`B
M66]U<B!.86UE(@IM<V=S='(@(DYO;64Z(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I
M;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@
M>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A
M8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A
M=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@
M;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@
M;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W
M<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI
M;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C
M=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO:69R86UE+G!H<#HU,`IM<V=I9"`B66]U<B!B<F]W<V5R(&1O
M97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U
M<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN
M(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3<*;7-G:60@(EEO
M=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!R969S+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT(&ED
M96YT:71Y(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@(D%C='5A;&EZX7)O
M;G-E(&%S('/Z87,@;W!C:?-N<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,34X"B,L(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ
M(@IM<V=S='(@(DED96YT:61A9&4@<')E9&5T97)M:6YA9&$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C`Q"B,L(&9U>GIY"FUS9VED(")9;W5R(&9U
M;&P@;F%M93HB"FUS9W-T<B`B3F]M93HB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HQ,#`P"B,L(&9U>GIY"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E
M>'!I<F5D+B(*;7-G<W1R(")!8W1U86QI>N%R;VYS92!A<R!S^F%S(&]P8VGS
M;G,N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$U-`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U
M<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G
M<W1R(")!8W1U86QI>N%R;VYS92!A<R!S^F%S(&]P8VGS;G,N(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`B06-T=6%L:7KA<F]N
M<V4@87,@<_IA<R!O<&-I\VYS+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y
M"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C
M:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S
M=V]R9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M-S,R"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@
M(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3@*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H
M;&EG:'1Q=6]T97,N<&AP.C$W,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q
M=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C@X"FUS9VED(");
M4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EM);F9O<FUE(&1O(%!R;V)L96UA
M72(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S
M"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H
M<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@
M+2`E<R!L:6YE<UTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@
M)7-=(@IM<V=S='(@(EML:?%A("5S(&1E("5S72(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,34T,2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC
M.C$Q"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB
M+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(B(*"B,Z(&QI8B]A
M<&DN<&AP.C$T,0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M,0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP
M:'`Z,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4*(RP@9G5Z>GD*;7-G:60@(E](
M96QP(@IM<V=S='(@(D%X=61A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O
M<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O365N=2YP:'`Z,3DT"B,L(&9U>GIY"FUS9VED(")?3&]G(&EN(@IM<V=S
M='(@(D5N=')A<B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H
M<#HQ.3`*(RP@9G5Z>GD*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(E!E8VAA
M<B!A('-E<VGS;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ
M-C0*(RP@9G5Z>GD*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(D]P8VGS;G,B
M"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G:60@(E]296UO=F4@3&EN:RXN
M+B(*;7-G<W1R(")386-A<B!O('!A<B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM
M<V=I9"`B7U-E='5P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE
M(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y
M"FUS9VED(")?57-E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,C$*(RP@9G5Z>GD*;7-G:60@(F%D9')E<W,@8F]O:R(*
M;7-G<W1R(")!>&5N9&$@9&4@96YD97)E>F]S(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN
M;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3$S"B,L(&9U>GIY"FUS9VED(")C86QE;F1A<B(*;7-G<W1R(")#86QE;F1A
M<FEO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM
M<V=I9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B
M8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z-3DR"FUS9VED(")C;&EC:R!H97)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S@*;7-G
M:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L
M('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T
M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3@R"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*
M;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S
M97(O0G)O=W-E<BYP:'`Z.#4U"B,L(&9U>GIY"FUS9VED(")F:6QE(@IM<V=S
M='(@(E3M='5L;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<T(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S8P(&QI8B]";&]C:R]M971A<BYP:'`Z,S@V"B,L
M('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U
M,`IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Y"FUS9VED(")H.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,S4X"FUS9VED(")H:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T
M<'5T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L
M;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI
M;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V.0IM<V=I9"`B;6TB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR.3$@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,C,R"B,L(&9U>GIY"FUS9VED(")N86UE(@IM<V=S='(@
M(DYO;64B"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(Q"FUS9VED(")N
M;W0@:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y"FUS9VED(")N;W0@>65T(&EM<&QE;65N
M=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3`U"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E
M<F-E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-S0*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R
M<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")R:7-I
M;F<B"FUS9W-T<B`B079I<V\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.CDY"FUS9VED(")S
M:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA
M:6P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C,X-0IM<V=I9"`B<W,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*;7-G
M:60@(G-T96%D>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C,P.0IM<V=I9"`B<W=I=&-H(&]F9B!J879A<V-R:7!T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P
M"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,CD*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM
M<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#4*(RP@9G5Z>GD*;7-G:60@(G1R>2!A
M9V%I;B(*;7-G<W1R(")#861A(&EN:6-I;R!D92!S97-I\VXB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS-B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M,C8Y"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N
M;F%M960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")U<V5R('-E;&5C="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@(E1A<GAE=&$@9&4@=FES
M:71A("AV0V%R9"DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C0Q"FUS9VED(")W.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS
M9W-T<B`B(@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+VAE7TE,+G!O````````````````
M````````````````````````````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`V,#(P-C0`,3`U
M,34T,S,W-30`,#$W-C(U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````",@2&5B<F5W('1R86YS;&%T:6]N<R!F;W(@2&]R9&4@
M<&%C:V%G92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#8@36%T="!396QS:WD@/'-E
M;'-K>4!C;VQU;6)I82YE9'4^"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D
M('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE($AO<F1E('!A8VMA9V4N
M"B,@075T;VUA=&EC86QL>2!G96YE<F%T960L(#(P,#8N"B,*;7-G:60@(B(*
M;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,BUC=G-<
M;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G
M7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,BTP-R`P-#HP."TP-3`P
M7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`V+3`R+3`W(#`T.C`X+3`U,#!<
M;B(*(DQA<W0M5')A;G-L871O<CH@36%T="!396QS:WD@/'-E;'-K>4!C;VQU
M;6)I82YE9'4^7&XB"B),86YG=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E
M+F]R9UQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@
M=&5X="]P;&%I;CL@8VAA<G-E=#U55$8M.%QN(@HB0V]N=&5N="U4<F%N<V9E
M<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,W-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S.#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S@Q"FUS9VED("(@*'1O9&%Y*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S@S"FUS9VED
M("(@*'1O;6]R<F]W*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S<Y"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,"!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S4S"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS.3D*;7-G:60@(B!A="`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HR,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-,22]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<P,PHC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$P-S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(
M;W)D92!296=I<W1R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1R964O
M5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E
M(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HU-0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D
M9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4S(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U
M<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8W(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HU-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R
M('!A<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M
M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C<P-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX
M-#$@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0W"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S.2!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HX-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M34(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO
M;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$T"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@
M;V8@06=R965M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-CDP(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S0W"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#,T(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z-#@V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A
M9'D@97AI<W1S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$W,2!L:6(O0FQO8VLO;65T87(N<&AP.C$W-R!L:6(O0FQO8VLO;65T87(N
M<&AP.C(U,0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,U-R!L:6(O0FQO8VLO
M;65T87(N<&AP.C,V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E
M<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R9F]R
M;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#
M:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT
M('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S0X"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,CDX"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN
M<&AP.C$S-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDP-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S
M($YO=&5P860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]H=&UL+G!H<#HQ,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I
M;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN
M(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O
M;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S4W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HT,#(*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,#`@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$S"B,L('!H<"UF;W)M870*;7-G
M:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S4P(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,CDT"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,S0X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M-S<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$S-@IM<V=I9"`B+2T@
M<V5L96-T("TM(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR
M-0IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W1I;64N<&AP.C(T"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@
M:&]U<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H
M<#HV.0IM<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3,Q"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@
M<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,38R"FUS9VED(")!(&9A=&%L(&5R<F]R
M(&AA<R!O8V-U<G)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I
M='DO261E;G1I='DN<&AP.C0R.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!
M(&UE<W-A9V4@:&%S(&)E96X@<V5N="!T;R!<(B5S7"(@=&\@=F5R:69Y('1H
M870@=&AI<R!I<R!R96%L;'D@>6]U<B`B"B)A9&1R97-S+B!4:&4@;F5W(&5M
M86EL(&%D9')E<W,@:7,@86-T:79A=&5D(&%S('-O;VX@87,@>6]U(&-O;F9I
M<FT@=&AI<R`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C@*;7-G
M:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@
M<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$P.3D*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K
M97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$V"FUS9VED("(B"B)!
M('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#8*
M;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y
M<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%
M(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!
M('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE
M<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I
M9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO
M=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N
M:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%0
M22!)1"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,PIM<V=I9"`B
M06)O=70N+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R
M96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@
M8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HS"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.`IM<V=I9"`B06-C
M;W5N="!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@
M9G)O>F5N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S0Y"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO
M861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD
M+FEN8SHQ,0IM<V=I9"`B061D(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,C(R(&%D;6EN+V=R;W5P<RYP:'`Z,C(S"FUS9VED(")!9&0@0VAI
M;&0@1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY"FUS
M9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO:6YD97@N<&AP.C<R"FUS9VED(")!9&0@0V]N=&5N="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I
M9"`B061D($AE<F4Z(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,C$V(&%D;6EN+V=R;W5P<RYP:'`Z,C$W"FUS9VED(")!9&0@3F5W($=R;W5P
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`IM<V=I9"`B061D
M($YE=R!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30W"B,L('!H<"UF;W)M870*
M;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(Y"FUS9VED(")!9&0@82!N97<@
M=7-E<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4U.`IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED
M(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C<Q"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*
M;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D
M9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S
M='(@(B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO
M=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N
M:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#D*;7-G:60@(D%D9')E
M<W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$T
M.`IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(M>AUZ37J"#7F]>JUY77
MD=>5UZHB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H
M<#HU-@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H
M97(@=7-E<G,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U-PIM<V=I9"`B061S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S
M='(@(M>0UZ37DM>@UYG7H=>JUY\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q"FUS9VED(")!;&)A
M;FEA(@IM<V=S='(@(M>0UYS7D=>@UYG7E"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0*;7-G:60@
M(D%L9V5R:6$B"FUS9W-T<B`BUY#7G->2UZC7F=>4(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I
M9"`B06QI9VYM96YT.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z.3(*;7-G:60@(D%L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,R(&%D;6EN+V=R;W5P<RYP:'`Z
M,C(P"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+V1A=&%T<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-SD*;7-G:60@(D%L;&]W
M(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3,W"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R9&5R
M960@;&ES="!T>7!E/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R
M964O1&%T851R964O<W%L+G!H<#HU,3@*;7-G:60@(D%L<F5A9'D@97AI<W1S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8*;7-G
M:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,3$*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A
M<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,#,*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E
M<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$T,0IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(W"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE
M9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C`*;7-G:60@(D%N('5N:VYO=VX@
M97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38*;7-G
M:60@(D%N9&]R<F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-`IM<V=I9"`B06YG
M;VQA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`*;7-G:60@(D%N9W5I;&QA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*
M;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`BUYG7
MD=>IUZKB@)/7D->@UYC7D->HUZ?7F->9UZ?7E"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3D*;7-G
M:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C,S(&%D;6EN+W1E;7!L871E<RYP:'`Z-S,*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O861M:6XO
M<V5T=7`O:6YD97@N:'1M;#HT"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R
M("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI
M8V%T:6]N($QI<W0B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!
M<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M.#,Y(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T,0IM<V=I
M9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D%R
M86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z-S@*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HV-@IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<W"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*;7-G:60@
M(D%R8VAI=F4@3F%M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R
M97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O9&5L971E+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%R
M92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@
M<W5B+6=R;W5P<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-@IM<V=I9"`B07)G
M96YT:6YA(@IM<V=S='(@(M>0UZC7DM>@UYC7F=>@UY0B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(M>0UZC7GM>@UYG7E"(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED(")!<FUE;FEA;B`H05)-4T-)
M22TX*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*
M;7-G:60@(D%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P"FUS9VED(")!<G5B
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B
M07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#(Y"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B
M969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P-@IM<V=I9"`B07-S
M:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z-S,*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M(&=R;W5P+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C(X"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H
M<#HX-@IM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E
M<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HU,@IM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT
M('-H87)E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW,0IM<V=I9"`B071T<FEB=71E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD*;7-G:60@(D%U<W1R86QI82(*;7-G
M<W1R("+7D->5UZ'7F->HUYS7F=>4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.`IM<V=I9"`B075S
M=')I82(*;7-G<W1R("+7D->5UZ'7F->HUYG7E"(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER<W%L+G!H<#HS,38*;7-G:60@(D%U=&A?8WER<W%L.B!2
M97%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S,0IM<V=I9"`B
M075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A
M<&%B:6QI=&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HR,S0*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM
M87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]F='`N<&AP.C4V"FUS9VED("(B"B)!=71H7V9T<#H@
M4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0
M('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`T"FUS9VED(")!
M=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW
M,PIM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z,S`Q"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I
M<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4V"FUS9VED
M(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@
M9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HY,@IM<V=I9"`B075T:%]L9&%P.B!297%U
M:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,X"B,L('!H<"UF;W)M
M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT
M.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@
M=7!D871E('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HT,#0*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@
M=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HV
M,@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<VUB+G!H<#HX-@IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A
M=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O061M:6XN<&AP.C$P-@IM<V=I9"`B075T:&5N=&EC
M871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S
M+G!H<#HQ.#(*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!
M1$E54R!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.#8P"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R
M=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S
M97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,Q"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B0D]&2"!%>&-U
M<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@R"FUS9VED(")"860@:V5R
M8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z.#0*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-0IM<V=I9"`B0F%H86UA<R(*;7-G
M<W1R("+7D->9UYGB@)/7D=>4UY[7E"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@*;7-G:60@(D)A
M:')A:6XB"FUS9W-T<B`BUY'7E]>HUYG7F=>?(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#,*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S0*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`B
MUY'7H->2UYS7D]>I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,PIM<V=I9"`B0F%R8F%D;W,B"FUS
M9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF
M;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0IM<V=I9"`B0F%S96QI;F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT.0IM<V=I9"`B0F5L87)U<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,U"FUS9VED(")"96QG:75M(@IM<V=S='(@(M>1UYS7DM>9
MUY0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4P"FUS9VED(")"96QI>F4B"FUS9W-T<B`BUY'7G->9
MUY8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0P"FUS9VED(")"96YI;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0Q"FUS9VED(")"97)M=61A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8*
M;7-G:60@(D)H=71A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP
M:'`Z,S8U"B,L('!H<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A
M<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3`*;7-G:60@(D)L;V-K(%-E
M='1I;F=S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHW,@IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O
M;&0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,PIM<V=I9"`B0F]L:79I82(*;7-G
M<W1R("+7D=>5UYS7F=>1UYG7E"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR,C$*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS
M9VED(")";W)D97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S
M<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,R"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HQ,#$*;7-G:60@
M(D)O=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.`IM<V=I9"`B0F]T<W=A;F$B
M"FUS9W-T<B`BUY'7E=>FUY77E=>@UY0B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<U"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*;7-G:60@(D)O='1O;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0W"FUS9VED(")";W5V970@27-L86YD(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#0*;7-G:60@(D)R87II;"(*;7-G<W1R("+7
MD=>HUY;7F=><(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<*;7-G:60@(D)R:71I<V@@26YD:6%N
M($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R"FUS9VED
M(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R("+7D=>HUY77H->9UYDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,W"FUS9VED(")"=6QG87)I82(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"
M=6QL971E9"!,:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8*;7-G:60@(D)U
M<FMI;F$@1F%S;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y"FUS9VED(")"=7)U
M;F1I(@IM<V=S='(@(M>1UY77J->5UZ#7D]>9(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0V-PIM<V=I9"`B0TU3(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-2
M0R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4Y.`IM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-38*;7-G
M:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#<@
M8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-3$*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$V-`IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T,`IM<V=I9"`B0V%L;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.`IM<V=I9"`B0V%M8F]D:6$B"FUS9W-T
M<B`BUZ?7GM>1UY77D]>9UY0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8P"FUS9VED(")#86UE<F]O
M;B(*;7-G<W1R("+7I]>>UZC7E=>?(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T
M;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,U,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E<UPB
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,0IM<V=I9"`B
M0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z
M,S,P(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(T,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT
M-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,0IM<V=I9"`B0V%N861A(@IM<V=S
M='(@(M>GUZ#7D]>4(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P(&%D;6EN+W5S
M97(N<&AP.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-C4@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q"FUS9VED(")#86YC96PB"FUS
M9W-T<B`BUZG7H->4(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z-3(*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,R,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HT-@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T
M87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K
M+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-CDT"B,L('!H<"UF;W)M870*
M;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H
M<#HV,C(*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT
M<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB
M97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R
M;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C4*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`BUZ?7I->4
M(->5UZC7D]>4(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*
M;7-G:60@(D-A<G)I97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDS"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S4*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I
M9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A
M9&1I;F<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C<X"FUS9VED(")#96QL
M<&AO;F4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*
M;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*
M;7-G:60@(D-E;G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T"FUS9VED(")#
M96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`BUY37I]>4UYG7G->9
MUYG7E"#7E->>UZC7F]>6XH"3UY#7I->HUYG7I]>@UYG7JB(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)
M4T\M.#@U.2TR*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8Q,@IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-E
M<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,0IM
M<V=I9"`B0VAA9"(*;7-G<W1R("+7IM>3(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M-@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HS,0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Y"FUS9VED
M("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@
M<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL
M<RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C(T"FUS9VED("(B"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S
M=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB
M0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*
M;7-G:60@(D-H87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@
M3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y"FUS9VED(")#:&EL92(*
M;7-G<W1R("+7IM>9UYS7F2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$*;7-G:60@(D-H:6YA(@IM
M<V=S='(@(M>AUYG7GR(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS
M9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(D-H:6YE<V4@5')A
M9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C<*;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,0IM
M<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B0VAO;W-E(&$@
M=7-E<FYA;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,P,@IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E
M("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-@IM
M<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z.3<Y(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z
M,CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@
M)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B0VQE87(B"FUS9W-T<B`B
MUZG7GM>9UYT@UY'7E->9UZC7G2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A
M9W,B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R-@IM<V=I
M9"`B0VQE87(@475E<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@
M;W5T('5S97(Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B
M0VQE87(@=7-E<B!D871A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#;&5A<FEN9R!,871E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-38*;7-G:60@(D-L;W5D<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")#
M;&]U9'DB"FUS9W-T<B`BUZG7GM>9UYT@UY[7HM>5UZ#7H->9UYTB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4R"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(T"FUS9VED
M(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O
M;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(*;7-G:60@
M(D-O;&]M8FEA(@IM<V=S='(@(M>GUY77G->5UY[7D=>9UY0B"@HC.B!L:6(O
M0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P-0HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,V"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R]#;VQL96-T:6]N+G!H<#HS,S<@<V5R=FEC97,O:6UA9V5S+V-O;&]R
M<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,SD*;7-G:60@(D-O;&]U
M<B!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-30*;7-G:60@(D-O
M;'5M;B!T:71L97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(X,`IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+V-M9'-H96QL+G!H<#HR,PIM<V=I9"`B0V]M;6%N9"(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]C;61S:&5L;"YP:'`Z,3@*;7-G:60@(D-O;6UA;F0@4VAE;&PB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$S"FUS9VED(")#;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-38W"FUS9VED(")#;VUM;VX@3F%M92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS-@IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3`*;7-G:60@(D-O;F1I
M=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V,0IM
M<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D
M:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED
M(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P
M:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F
M(&1A=&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3(*;7-G
M:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TED96YT:71Y+TED96YT:71Y+G!H<#HT,#<*;7-G:60@(D-O;F9I<FT@;F5W
M(&5M86EL(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-0IM<V=I9"`B
M0V]N9V\B"FUS9W-T<B`BUZ?7E=>@UY+7E2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,*;7-G:60@
M(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,3DW"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P
M.`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#@*;7-G:60@(D-O
M;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN96-T:6]N(')E9G5S
M960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES
M97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C@U-`IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&
M5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VAO;VMS
M+G!H<"YD:7-T.C$P.38*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I
M9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A
M9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z-C`*;7-G:60@(D-O;G1E;G0@='EP92!O9B!C
M;VUP<F5S<V5D(&9I;&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HV,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O
M9B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C,S('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y"FUS9VED
M(")#;VYT:6YU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X"FUS9VED(")#;V]K
M($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,W"FUS9VED(")#;V]K:64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#
M;W!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M-#4S"B,L('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B0V]S
M="!)1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8S"FUS9VED(")#;W-T82!2:6-A
M(@IM<V=S='(@(M>GUY77H=>8UY0@UZC7F=>GUY0B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W"FUS
M9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!E
M;F-R>7!T(&UE<W-A9V4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,#4U"FUS9VED(")#;W5L9"!N;W0@4$=0('-I
M9VX@;65S<V%G93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N
M8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@
M<VEG;B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C$R,0HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-#4W"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3<S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,34V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-#0Q"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T
M;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN
M96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3(X"FUS9VED(")#;W5L9"!N;W0@9&5C
M<GEP="!01U`@9&%T83H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3(S"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP
M="!3+TU)344@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q"FUS9VED(")#;W5L
M9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP
M;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L
M9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E
M(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDN<&AP.C@T"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HQ,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K
M97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O
M<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0R
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N
M86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@
M9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-CDY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP
M.C(T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*
M;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H
M92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I
M;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS,#<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S,X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,W-0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M.#$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@W
M"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R
M97-S(&)O;VLN("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q-PHC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C$*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B
M0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C8S"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C
M;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S
M879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R
M('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B
M86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@
M)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,30S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E
M<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E
M(&-O;G1A8W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F
M;W(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S<P"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I
M9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R
M(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<
M(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,C<*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B0V]U
M;G1R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C@Y"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I
M9"`B0W)E871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@
M;&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES
M96QE8W0N:6YC.CDV"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4R
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS
M9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S(R,PIM<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C0*;7-G:60@(D-U8F$B"FUS9W-T<B`BUZ?7E=>1UY0B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,C8*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C0X"FUS9VED(")#=7)R
M96YT(%-E<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS-0IM<V=I9"`B0W5R<F5N="!4:6UE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,S"FUS9VED(")#=7)R
M96YT(%5S97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S`*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8Y"FUS9VED(")#=7)R96YT(&-O
M;F1I=&EO;CH@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G
M;VX@=&\@)7,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV-PIM<V=I9"`B0WEP<G5S(@IM<V=S='(@(M>GUZ37J->9UZ'7F=>?(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(D-Y<FEL;&EC("A+
M3TDX+5(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y
M"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B0WER:6QL:6,O56MR
M86EN:6%N("A+3TDX+54I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@*;7-G:60@
M(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(M>FUYO7F=>4(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-"!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,PIM<V=I9"`B(@HB1%-.("AS964@:'1T
M<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD
M8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I
M;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C,*;7-G:60@(D1A=&%4
M<F5E($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(X,0IM<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0P-@IM<V=I9"`B1&%T92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ
M,PIM<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#`P"FUS9VED(")$871E('-E;&5C=&EO;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@U
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,30*;7-G:60@(D1A>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,34*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0U,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED
M(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@
M26YD96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3@W(&QI8B]P<F5F<RYP:'`Z,3$W"FUS9VED(")$969A=6QT(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z.38*;7-G:60@(D1E
M9F%U;'0@261E;G1I='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C8W"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B1&5F:6YI=&EO;G,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,"!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY
M,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C,Q('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E
M+FEN8SHQ,`IM<V=I9"`B1&5L971E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I
M9"`B1&5L971E($-E;&PB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HQ.3<@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D1E;&5T92!'<F]U
M<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-#D*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*
M;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I
M9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$T-PIM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T
M96UP;&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,T,S$T+G!H<#HU-`IM<V=I9"`B1&5L971E(&UE<W-A9V5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(Q"B,L
M('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E
M<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N
M<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E
M;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,PIM<V=I9"`B1&5L971E
M('-U8B!F;VQD97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E
M('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@
M(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR-3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU.34*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW,0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R("+7D]>@UYG7
ME"(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C(W"FUS9VED
M(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HY-#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3<*;7-G
M:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HR,#$*;7-G:60@
M(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T
M;W(N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M,S4*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C(Y"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(D1E=R!0;VEN="!F
M;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(R,0IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM
M<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<P"FUS9VED(")$
M:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,#`*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.30*;7-G
M:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HY-PIM<V=I9"`B1&ES<&QA>2!F;W)E8V%S
M="`H5$%&*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.#$P"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DQ"FUS9VED(")$:7-P;W-I
M=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,`IM<V=I
M9"`B1&II8F]U=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HT,C(*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N
M;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O
M9&%T82]T<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W
M(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@
M8F]X.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R"FUS9VED(")$;VUI;FEC82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<S"FUS9VED(")$;VUI;FEC86X@4F5P=6)L
M:6,B"FUS9W-T<B`BUY37J->DUY77D=><UYG7I]>4(->4UY/7E=>>UYG7H->9
MUZ?7H->9UZHB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@X"FUS
M9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@U-PIM
M<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.#4W"B,L('!H<"UF;W)M870*;7-G:60@(D1O
M=VYL;V%D("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N
M(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Q,34*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1')U9W,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@S"FUS
M9VED(")$>6YA;6EC($UA:6PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z
M.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A
M<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW-0IM<V=I9"`B16-U861O<B(*;7-G<W1R("+7D->GUY77E=>3UY77
MJ"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(U('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@IM<V=I9"`B161I="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P"FUS
M9VED(")%9&ET($)L;V-K(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,3DV(&%D;6EN+V=R;W5P<RYP:'`Z,C(T"FUS9VED(")%9&ET($=R;W5P
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D
M:70@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O
M961I="YP:'`Z,C,V"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O
M<'1I;VYS(&9O<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M
M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P
M97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0P"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW-PIM<V=I9"`B16=Y<'0B"FUS9W-T<B`BUY[7IM>HUYG7G2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`BUY#7G.*`
MD]>AUYS7E=>5UY/7E=>H(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X-S<*;7-G:60@(D5M86EL(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38V('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z-CD*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHQ,`IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q"FUS9VED(")%
M;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HT-3`*;7-G:60@(D5M86EL
M(&%D9')E<W-E<R!T;R!C;VYF:7)M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DY-PIM<V=I9"`B16UA:6P@
M=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O
M+5--4R!'871E=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HS,#$*;7-G:60@(D5M;W1I8V]N<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HW,#4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ
M-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A
M<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU-30*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@
M4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,C$*;7-G:60@(D5N86)L92!R:6=H="!C;&EC
M:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(U.38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P-`IM
M<V=I9"`B16YD('EE87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET
M;W(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R-`IM
M<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@
M=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A
M<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E
M(%523"!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HX.30*;7-G:60@(D5N=&5R('1H92!L971T97)S
M(&)E;&]W.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDY"FUS9VED(")%<75A=&]R
M:6%L($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y"FUS9VED(")%<FET
M<F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]6:65W+G!H<#HY-"!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-3,*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HT,0IM
M<V=I9"`B17)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E
M+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<V"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(M>0UZK7F=>5UZ37F=>4
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")%=&AN:6,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U
M"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]L87EO=70N:6YC.C$P,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0S"FUS
M9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.3,*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3@@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,T,`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,SDQ"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,#`@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDT"FUS
M9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@
M3&]G:6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N
M:6YC.C$P,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0T"FUS9VED(")%=F5R
M>2!H86QF(&AO=7(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L
M87EO=70N:6YC.C$P,PIM<V=I9"`B179E<GD@:&]U<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3D@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T,0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDR"FUS
M9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z-#@@861M:6XO<&AP<VAE
M;&PN<&AP.C<Y(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C4*;7-G:60@(D5X96-U
M=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HV,30*;7-G:60@(D5X<&%N9"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,Q"FUS9VED(")%>'!A
M;F0@4VED96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+
M97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I
M9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-PIM<V=I9"`B17AP;VYE
M;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B1E10('5P
M;&]A9"!O9B!S971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O<W%L+G!H<#HR-#4*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R
M969E<F5N8V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY
M.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HQ,#$*
M;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S`S"B,L('!H
M<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<P.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z
M.#D*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW
M-3(@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0T-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS
M9VED(")&86ER(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0*;7-G:60@(D9A;&ML
M86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V
M"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#3$DO0TQ)+G!H<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3@W"FUS9VED(")&87@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,V-0IM<V=I9"`B1F%X97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-0HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E
M8G)U87)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C,R
M"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,C4*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3
M;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3DU,@IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S8*;7-G:60@(D9I9VQE="!#
M05!40TA!(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S-#`*;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#,*;7-G:60@(D9I:FDB"FUS9W-T<B`BUZ37F=>2UYDB"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(D9I;&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#,P"FUS9VED(")&:6QE($UA;F%G97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*;7-G:60@
M(D9I;&4@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.3@X"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#DT"FUS9VED(")&:6QE('5P
M;&]A9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R
M+G!H<#HY,#8*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G
M:60@(D9I;'1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,@IM<V=I9"`B1FEN
M;&%N9"(*;7-G<W1R("+7I->9UZ#7G->@UY,B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,38V"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G
M:60@(D9I<G-T(%%U87)T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-0IM<V=I9"`B1FEX(')A=&EO
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,S`*;7-G:60@(D9L:7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I
M9"`B1FQO870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R("+7HM>HUZ37
MG"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,#<@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HR-C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O
M;G0@0V]L;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0R"FUS9VED(")&;V]D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B
M1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#8*;7-G:60@(D9O<F5C
M87-T("A4048I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HW-PIM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T
M('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N
M:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@
M82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.CDT"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X-0IM<V=I
M9"`B1F]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C(V"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HQ,#0*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(D9O<G1U;F5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I
M9"`B1F]R='5N97,@,B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#<V"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B1F]R=V%R9',B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A
M;65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<*;7-G:60@(D9R86YC92(*;7-G
M<W1R("+7IM>HUZ37JB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY,0IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X-`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,C(*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O
M<FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#(@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,U,@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,SDX"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#(*;7-G:60@(D9U;&P@1&5S8W)I
M<'1I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI
M8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHV,0IM<V=I9"`B1G5L;"!.86UE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#@*;7-G:60@(D=A8F]N(@IM<V=S='(@(M>2UY'7
ME=>?(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@
M9G)O;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.38*;7-G:60@(D=A;6)I82(*;7-G<W1R("+7
MDM>>UY'7F=>4(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M
M;#HV"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.CDP"FUS9VED(")'96]R9VEA(@IM<V=S='(@(M>2UY77J->2UYG7E"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`BUY+7J->>UZ#7F=>4
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY,PIM<V=I9"`B1VAA;F$B"FUS9W-T<B`BUY+7H->4(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY-`IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<V"FUS9VED(")':79E
M;B!.86UE(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HQ-S4@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3`*(SH@=&5M<&QA
M=&5S+W!R969S+V%P<"YI;F,Z,3D*;7-G:60@(D=L;V)A;"!/<'1I;VYS(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$W"FUS9VED
M(")';R(*;7-G<W1R("+7G->:(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0U"FUS9VED(")';V5D96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,S,*;7-G:60@(D=O;V=L92!-
M87!S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB
M+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*
M;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-@IM<V=I9"`B1W)A>7-C
M86QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P"FUS9VED(")'<F5E8V4B"FUS
M9W-T<B`BUYG7E=>5UY\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM
M<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.34*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y"FUS
M9VED(")'<F5N861A(@IM<V=S='(@(M>2UZC7H->3UY0B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C$W.`IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N
M86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L('!H<"UF;W)M870*;7-G
M:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P
M.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'
M<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY.`IM
M<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,PIM<V=I
M9"`B1W5A;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,@IM<V=I9"`B1W5A=&5M
M86QA(@IM<V=S='(@(M>2UY77D->8UY[7G->4(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y,PIM
M<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDY"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3<*;7-G:60@
M(D=U:6YE82(*;7-G<W1R("+7DM>9UZ#7D->4(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T"FUS
M9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-0IM
M<V=I9"`B1W5Y86YA(@IM<V=S='(@(M>2UYG7D->@UY0B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HY-C0*;7-G:60@(DA434PB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE
M=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G
M:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B
M2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@
M<F]W(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VAT='`N<&AP.C$U-`IM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,`IM<V=I9"`B2&%I
M=&DB"FUS9W-T<B`BUY37D->9UYC7F2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T-0IM<V=I9"`B(@HB
M2&%V92!A(&)U='1O;B!I;B!T:&4@=&]O;&)A<B!T:&%T('!O<',@=7`@82!W
M:6YD;W<@=VET:"!S<&5C:6%L(&-H87)A8W1E<G,_(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED
M(")(87IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.CDR,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(U"FUS9VED(")(96%D
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A
M8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#<*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R("+7
MH=>5UZ37JN*`D]>HUZ+7GM>9UYT@UZ+7EM>4(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.3(*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X,2!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O2&5L<"YP:'`Z,3@R"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N
M<&AP.C$W('1E;7!L871E<R]H96QP+VEN9&5X+FEN8SHT"FUS9VED(")(96QP
M(@IM<V=S='(@(M>BUY;7J->4(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W.0IM
M<V=I9"`B2&5L<&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]T<W9I;F9O
M+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F
M:6QE.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HW,`IM<V=I9"`B2&EG:"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;65N=2]M96YU+FEN8SHW"FUS9VED(")(;U]M92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0S"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y
M(%-T871E*2(*;7-G<W1R("+7E=>8UYG7I]>?(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-34U"FUS9VED(")(;VUE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I
M9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HV-`IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM
M<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@*;7-G
M:60@(DAO;F1U<F%S(@IM<V=S='(@(M>4UY77H->3UY77J->A(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`V"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C8W"FUS9VED(")(;W)D92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0T,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E
M;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C
M="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J
M96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D
M("5S(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO
M;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C
M<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0S"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB
M)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HT-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3$Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE
M('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,R"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA
M<F5S.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK
M;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A
M;"!2=6QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R
M="$I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@
M=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L
M9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I
M9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,R!L
M:6(O0FQO8VLO;65T87(N<&AP.C(T,@IM<V=I9"`B2'5M:61I='DB"FUS9W-T
M<B`BUYS7E]>5UZHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C4S"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(CK7G->7UYG7JB(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B2'5M;W)I<W1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,0IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R
M("+7E->5UZ#7DM>HUYG7E"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M<W%L+G!H<#HR,S0@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<P
M"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F
M86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER<W%L+G!H<#HR.38@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,C$T"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO
M;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER<W%L+G!H<#HR-#$@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP
M:'`Z,3<W"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T
M82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S,C`*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM
M<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))
M4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(P"FUS9VED("))8V5L86YD(@IM<V=S='(@
M(M>0UYG7H=><UZ#7DR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#`*
M;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R
M;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Q"FUS
M9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Y,PIM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU
M.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE
M9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4Y"FUS9VED
M("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE
M="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X
M('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S(*;7-G
M:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@
M=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P
M;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*
M;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@
M(DEM86=E(%523"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E
M(%523#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M
M(&=A;&QE<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F
M<F]M(&=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$W-CD*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHU-`HC.B!T96UP;&%T97,O9&%T82]D871E
M;6%P+FEN8SHW('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*
M;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L
M9',Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+WII<"YP:'`Z,3,T"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV
M96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,R"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@
M86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE
M(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y
M;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3$V"FUS9VED("));F1I82(*;7-G<W1R("+7E->5UY/7
ME2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C4T('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L(%5S
M97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,@IM<V=I9"`B26YD;VYE<VEA
M(@IM<V=S='(@(M>0UYG7H->3UY77H->6UYG7E"(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W,PIM<V=I
M9"`B26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,R,@IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R
M(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@
M0U]O;'5M;B!!9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN
M<V5R="!);6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@
M8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@
M82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C
M=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A
M(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R
M<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@
M<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30Y"FUS9VED("));G-E<G0@86QT
M97)N871E('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR-#(*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O
M('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4X"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,`HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I
M9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B
M26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G
M:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*
M;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I
M9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(S,PIM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A
M;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS
M9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN
M<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS=69F
M:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES
M="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-SD*
M;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3$S-PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII
M<"YP:'`Z,38W"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N
M<&AP.C$Y-`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H
M<#HR,3(*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L
M:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A=&-H
M($E$+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,#DU(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-C8*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(T,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S`W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z
M,S<*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H
M<#HQ,#D*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z
M,3,Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(T
M,0IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<P"FUS9VED("));G9A;&ED
M(&QI8V5N<V4@:V5Y+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,38T"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I
M9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P
M:5]I9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I
M;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D
M8VAI;&0N<&AP.C(V"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,38V"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C@*;7-G:60@(DEN=F%L
M:60@<')O9'5C="!C;V1E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L
M:60@<')O=&]C;VPN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@
M<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,#<U(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3(U.`IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`Q"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<S"FUS9VED("));G9E
M;G1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C8X,`IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3D*;7-G:60@(DER86XL($ES;&%M:6,@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`BUY#7F=>HUY\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@*;7-G
M:60@(DER87$B"FUS9W-T<B`BUZ+7F=>HUZ<B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,*;7-G
M:60@(DER96QA;F0B"FUS9W-T<B`BUY#7F=>HUYS7H->3(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,30*;7-G:60@(DES<F%E;"(*;7-G<W1R("+7F=>IUX'7J->0
MUYPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-@IM
M<V=I9"`B27-S=65R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R,0IM<V=I9"`B271A;'DB"FUS9W-T<B`BUY#7F=>8
MUYS7F=>4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(S"FUS9VED(")*86UA:6-A(@IM<V=S='(@
M(M>2UY[7F=>9UZ?7E"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R-0IM<V=I9"`B2F%P86XB"FUS9W-T<B`BUYG7I->?(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R
M,BU*4"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0*
M;7-G:60@(DIO<F1A;B(*;7-G<W1R("+7F=>HUY/7GR(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU
M<W1I9GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GD@0V5N=&5R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0P"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S<*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS.0IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S8*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V,PIM<V=I9"`B2V5E
M<"!O<FEG:6YA;#\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V"FUS9VED(")+
M96YY82(*;7-G<W1R("+7I]>@UYG7E"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:W)B-2YP:'`Z.#8*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E
M9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0W"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@
M(DME>2!#<F5A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*
M;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.0IM
M<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S
M(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DMI9',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(Y"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S(*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E
M<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,PIM<V=I9"`B2V]R
M96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DT"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,T"FUS9VED(")+=7=A:70B"FUS9W-T<B`BUYO7E=>5UYG7
MF=>J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(W"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S4*;7-G:60@(DQA
M;F=U86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-PIM<V=I9"`B3&%O(%!E
M;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-@IM<V=I9"`B3&%S="!0
M87-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R
M=&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38S"FUS
M9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO
M9VEN.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O
M;2`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW
M,30*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T-@IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT.0IM<V=I9"`B3&%W(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0IM
M<V=I9"`B3&%Y;W5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O
M<B!N;R!B;W)D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X"FUS9VED("),
M96)A;F]N(@IM<V=S='(@(M><UY'7H->5UY\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*;7-G:60@(DQE9G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q,@IM
M<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$P.`IM<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30S"FUS9VED("),97-O=&AO(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B3&5V96PB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R"FUS9VED("),:6)E<FEA(@IM<V=S
M='(@(M><UYG7D=>HUYG7E"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-PIM<V=I9"`B3&EB>6%N
M($%R86(@2F%M86AI<FEY82(*;7-G<W1R("+7G->5UY$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#`*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT
M($1R:7IZ;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C8*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*
M;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT
M(%)A:6X@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3
M;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3`*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X,C(*;7-G:60@(DQI;FLB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@X,PIM<V=I9"`B3&EN:R!T:&4@
M96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA
M>6EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL
M=&5R+VAT;6PR=&5X="YP:'`Z,3@R"FUS9VED("),:6YK<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DQI;G5X($-O
M;VMI92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,T,S$T+G!H<#HT-@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L
M9&5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S$*;7-G
M:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE
M;'`O:6YD97@N<&AP.C4Q"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S`*;7-G:60@(DQI<W0@
M5&%B;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-3`Y"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU,#0*;7-G:60@
M(DQI<W0M2&5L<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TAE861E<G,N<&AP.C4Q,0IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4P-PIM<V=I9"`B
M3&ES="U/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TAE861E<G,N<&AP.C4P.`IM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3`V"FUS9VED
M("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TAE861E<G,N<&AP.C4P-0IM<V=I9"`B3&ES="U5;G-U8G-C<FEB
M92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED
M("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*;7-G:60@(DQI=&5R871U<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30T"FUS9VED("),:71H=6%N:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6UA9V5S+G!H
M<#HW-PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`U"FUS9VED("),;V-A;"!T:6UE.B`B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V"FUS9VED
M("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C8R"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z-S<@;&EB+T)L;V-K
M+W-U;G)I<V4N<&AP.C(R"FUS9VED("),;V-A=&EO;B(*;7-G<W1R("(B"@HC
M.B!L;V=I;BYP:'`Z,3@X('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR
M,#`@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,@HC.B!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHS('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C$U"FUS9VED("),;V<@:6XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN
M8R!S97-S:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HQ.30*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"FUS9VED("),;V=I;B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$P"FUS9VED("),;V=I;B!4
M87-K<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.34*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@
M;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,0IM<V=I9"`B3&]G
M:6X@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,S<S"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED("),;W9E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS
M9VED("),;W<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E
M96L@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L
M871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R
M(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30U"FUS9VED
M("),=7AE;6)O=7)G(@IM<V=S='(@(M><UY77F]>AUY[7D=>5UZC7DB(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#,*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,2!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Y-PIM<V=I9"`B34]41"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H
M<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D
M871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W"FUS9VED(")-86-A;R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-3,*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE
M<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3$*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T<B`BUY[7D]>2UZ'7I]>H(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"FUS9VED(")-86=I8R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3`*;7-G:60@
M(DUA:6PB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C4T-0IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G
M:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U"FUS
M9VED(")-86QA=VDB"FUS9W-T<B`BUY[7G->5UY77F2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M-PIM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`BUY[7G->9UYG7EM>9UY0B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C0*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(M>4UY#7F=>9
MUYT@UY37GM><UY/7F=>5UY77F=>9UYTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30*;7-G:60@
M(DUA;&DB"FUS9W-T<B`BUY[7G->9(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R"FUS9VED(")-
M86QT82(*;7-G<W1R("+7GM><UYC7E"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-`IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I
M97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B
M"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q
M-3@*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X.0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$W,PIM<V=I9"`B36%P475E
M<W0@;6%P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I
M9"`B36%R8V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP
M.C0X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X
M"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#D*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G
M:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS
M=V5R960I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,@IM<V=I9"`B36%R<VAA
M;&P@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D*;7-G:60@(DUA
M<G1I;FEQ=64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C`*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`BUY[7D->5
MUZC7F=>8UZ#7F=>4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S"FUS9VED(")-875R:71I=7,B
M"FUS9W-T<B`BUY[7D->5UZC7F=>FUYG7E=>A(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED(")-87@@
M86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE
M<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S$X"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3`*;7-G
M:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]A<&DN<&AP.C@V"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!0;W)T86P@
M0FQO8VMS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.CDP,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C(Q"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R-#,*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,PIM
M<V=I9"`B36%Y;W1T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-34*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*;7-G:60@(DUE;6)E<G,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,@IM<V=I
M9"`B365N=2!M;V1E.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C
M96QL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM
M<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H
M92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S<V%G92!E>'!I<F5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C8P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"FUS9VED(")-97-S86=E('1Y<&4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-
M971A<B!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z-#(*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(T"FUS9VED("(B"B)-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34X"FUS9VED(")-971A<D1"
M(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q-R!F<F%M97=O<FLO
M4E!#+U)00R]X;6QR<&,N<&AP.C@Q"B,Z(&9R86UE=V]R:R]24$,O4E!#+W!H
M<&=W+G!H<#HX."!F<F%M97=O<FLO4E!#+U)00R]P:'!G=RYP:'`Z.#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T+G!H<#HX
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N($-A
M;&QE9"!M971H;V0Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HW,B!L:6(O0FQO8VLO;65T87(N<&AP.C@W"FUS9VED
M(")-971R:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V"FUS9VED(")-97AI
M8V\B"FUS9W-T<B`BUY[7F]>AUYG7I]>5(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4*;7-G:60@
M(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0R"FUS9VED(")-:61D;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R,@IM<V=I9"`B
M36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S$T"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U
M<G,Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C0S.`IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y
M970@97AP:7)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C,S"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")-:7-C96QL
M86YE;W5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A
M8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I
M;VXN(%EO=2!M=7-T(&=E;F5R871E(&ET(&)E9F]R92!U<VEN9R!T:&ES(&%P
M<&QI8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S
M<V%G92!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q
M=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I
M9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S8*;7-G
M:60@(DUO8FEL92!-86EL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")-;V1E<F%T92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,PIM<V=I9"`B
M36]D:69I960@1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF
M>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-S0*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34P"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#D*;7-G:60@(DUO;F%C;R(*;7-G<W1R("+7GM>5UZ#7
MI]>5(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34V"FUS9VED(")-;VYG;VQI82(*;7-G<W1R("+7
MGM>5UZ#7DM>5UYS7F=>4(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C4Y,@IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B
M36]N=&AL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C$*;7-G:60@(DUO;G1S
M97)R870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ.38@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C@P"B,L('!H<"UF;W)M870*;7-G:60@
M(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T
M960@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.`IM<V=I9"`B36]R;V-C
M;R(*;7-G<W1R("+7GM>HUY77I]>5(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S
M=&QY(%-U;FYY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z-C0X"FUS9VED(")-;W9E($1O=VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HV-3(*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U-@IM
M<V=I9"`B36]V92!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T-`IM<V=I9"`B36]V92!5
M<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-3(X"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-PHC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(X"FUS9VED
M(")-;W9E('5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.`IM<V=I9"`B36]Z
M86UB:7%U92(*;7-G<W1R("+7GM>5UY;7GM>1UYG7IR(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q.3(*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@
M9&]W;B!L:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3`V,`IM<V=I9"`B375L=&EM87`@54L@;6%P
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-3`*
M;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS9VED(")->2!!8V-O=6YT(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.`IM<V=I9"`B
M37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO:6YD97@N<&AP.C8U"FUS9VED(")->2!0;W)T86PB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C,U"FUS9VED(")-
M>2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-0IM<V=I
M9"`B37EA;FUA<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G
M<F5E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1N968N<&AP.C,X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,#(@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q
M"FUS9VED(").86UE(@IM<V=S='(@(M>IUYTB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD*;7-G
M:60@(DYA;6EB:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X"FUS9VED(").
M875R=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<*;7-G:60@(DYE<&%L(@IM
M<V=S='(@(M>@UZ37G"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-0IM<V=I9"`B3F5T:&5R;&%N
M9',B"FUS9W-T<B`BUY37E=><UZ#7DR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S"FUS9VED(").
M971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@0F%S
M92!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3@V"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS
M9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A
M<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(%-33"!S
M97)V97(@;F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4X.`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@
M8V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP
M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8W
M"FUS9VED(").971W;W)K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0R-2!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z.3<*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,SDP"FUS9VED(").979E<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-S`*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*
M;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#0*(SH@9G)A;65W;W)K
M+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@X"B,Z(&9R86UE=V]R
M:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HQ,3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,V"FUS
M9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#`*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(M>@UYG7E>*`
MD]>6UYG7G->@UY,B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,S<*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-Q;"YP:'`Z,C0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED(").97<@
M<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@
M=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU-R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,`HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S`U"FUS9VED(").97=S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C$*;7-G:60@(DYE=W-G
M<F]U<',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,C4@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$@=&5M<&QA=&5S+V1A=&$O='-V:6YF
M;RYI;F,Z,34*;7-G:60@(DYE>'0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(W"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8R(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V"FUS9VED(").97AT(&]P=&EO;G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#,*
M;7-G:60@(DYE>'0^(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-`IM<V=I9"`B
M3FEC87)A9W5A(@IM<V=S='(@(M>@UYG7I]>HUY+7E=>0UY0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S$*;7-G:60@(DYI9V5R(@IM<V=S='(@(M>@UYG7EM>H(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<S"FUS9VED(").:6=E<FEA(@IM<V=S='(@(M>@UYG7DM>HUYG7E"(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-S(*;7-G:60@(DYI
M9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.0IM<V=I9"`B3FEU92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.38X"FUS9VED(").;R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF
M:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP
M:'`Z,3`V"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN
M9R!)4T\@:6UA9V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H
M('1E;7!L871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P,0HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C,X-0HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0P-PIM<V=I9"`B3F\@8FQO
M8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HV-PIM<V=I9"`B
M3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*
M;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B
M92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<V."!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C$V.0HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4R,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#,S"FUS9VED(").;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV.3@*;7-G:60@(DYO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@
M5D93+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z-S0W"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*
M;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B
M3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDR-`IM<V=I9"`B3F\@9FEL92!U
M<&QO861E9"(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(Q(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3,U"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`IM<V=I9"`B3F\@
M;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,38R"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B3F\@
M;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-PIM<V=I9"`B(@HB3F\@<&%T:"!T
M;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I
M;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T
M82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#$S"FUS9VED(").;R!Q=6]T
M82!S970N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0X,@IM<V=I
M9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`IM
M<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HU-C,*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3,Q"FUS9VED(").
M;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@
M<V5N="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C
M+G!H<#HQ-#`@9G)A;65W;W)K+U)00R]24$,O<&AP9W<N<&AP.C$W-0IM<V=I
M9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW-@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@V"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY.3<*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,30*;7-G:60@
M(DYO('9A;'5E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O
M;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@
M=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A
M=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#(W('1E;7!L871E<R]P<F5F<R]I9&5N=&ET
M>7-E;&5C="YI;F,Z.34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT-0IM<V=I9"`B3F]N92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS
M9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(*;7-G:60@(DYO<F9O;&L@27-L
M86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X"FUS9VED(").;W)T:&5R;B!-87)I
M86YA($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V"FUS9VED(").
M;W)W87DB"FUS9W-T<B`BUZ#7E=>HUY77E=>2UYG7E"(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0Q"FUS9VED(").;W0@069T97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-#`*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z-#0Q"FUS9VED(").;W0@82!D:7)E8W1O
M<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z
M-3D*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2YP:'`Z.#0*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.34*;7-G:60@
M(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DS(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR,#@*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(S-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR-CD@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V,PHC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,S@P(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HT,3,*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0W,R!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z-34R"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HV,C$@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C8S.`HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-S$V(&9R86UE=V]R:R]61E,O5D93+VAO<F1E+G!H<#HX,@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z,3,Q(&9R86UE=V]R:R]61E,O
M5D93+VAO<F1E+G!H<#HQ-3$*(SH@9G)A;65W;W)K+U9&4R]61E,O:&]R9&4N
M<&AP.C$W,"!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z,3@Y"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VAO<F1E+G!H<#HR,#<@9G)A;65W;W)K+U9&4R]6
M1E,O:&]R9&4N<&AP.C(R-PHC.B!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP
M:'`Z,S,P"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<BYP:'`Z,30U"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<BYP:'`Z,38P"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<BYP:'`Z,3<U"B,Z(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R]3
M97-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,V"FUS9VED(").
M;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R]H;V]K<RYP:'`N9&ES
M=#HQ,#@Q"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#<*;7-G:60@
M(DYO=&5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X
M+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,30*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0U,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#4P"FUS9VED(").=6UB97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30S,PIM<V=I9"`B3G5M
M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,W-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#,Q
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-3,@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O
M9B!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$S-S4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R.0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#4Q('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O
M<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS
M9VED(")/2R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.#<U"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C
M="!#<F5A=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q,#@*;7-G:60@(D]C=&%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-PIM<V=I
M9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,T,@IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N
M9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*;7-G:60@(D]L
M9"!P87-S=V]R9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C
M="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q"FUS9VED(")/;6%N(@IM<V=S
M='(@(M>BUY77GM>0UY\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R
M="!S:&%R960@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C$P,`IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Y"FUS9VED(")/;FQY(&]N92!E
M;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W-H87)E<R]E9&ET+G!H<#HV-`IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@
M;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@
M;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,SD@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z-#`*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS
M9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R
M;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G
M:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")/<&5R871I
M;F<@4WES=&5M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`BUY#7I->IUZC7
ME=>9UY77JB(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,B!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS
M(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C@*
M;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B3W)G86YI<V%T:6]N
M86P@56YI="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,30Q"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,3,T"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO
M;B!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@
M:6X@)7,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE
M<B(*;7-G<W1R("+7D->7UZ@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3D@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.0HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C4*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,30T"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M
M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A
M;2YP:'`Z.#`*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,C<V"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,R,@IM<V=I
M9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-S0*;7-G:60@(E!'4"!0=6)L:6,@
M2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$S-38*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8V"FUS9VED(")02%`@
M0V]D92(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,3@*;7-G
M:60@(E!(4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@3&EG:'0@4F%I;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS.`IM<V=I9"`B4$T@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4VAO
M=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B
M4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")032!3=6XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#,*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M
M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B
M4%](4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-PIM<V=I9"`B4&%K:7-T86XB"FUS9W-T
M<B`BUZ37I]>9UZ'7JM>?(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-`IM<V=I9"`B4&%L874B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,@IM<V=I9"`B4&%L97-T:6YI86X@
M5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#(*
M;7-G:60@(E!A;F%M82(*;7-G<W1R("+7I->@UY[7E"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M-0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DU"FUS9VED(")087)A9W5A>2(*;7-G<W1R("+7I->HUY+7E=>0UYG7
MF2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V
M"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P,C8*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHV.2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0T
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#8*;7-G:60@(E!A<W-W
M;W)D(@IM<V=S='(@(M>AUYG7H=>>UY`B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S
M<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C$S,C,*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,34W
M"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#8Q"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G
M:60@(E!A<W-W;W)D.B(*;7-G<W1R("+7H=>9UZ'7GM>0.B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM
M<V=S='(@(M>AUYG7H=>>UY`Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#0R"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA
M=&-H+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$W('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C
M;&EP8F]A<F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN
M9R!3:6=N=7!S.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3D*;7-G:60@(E!E;W!L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R
M871I;VYS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M,3`*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L
M;V=I;C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<&5R;7,O9&5L971E+G!H<#HU,0HC+"!P:'`M9F]R;6%T"FUS9VED(")0
M97)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU-C8*;7-G:60@(E!E<FUI<W-I
M;VX@1&5N:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38T
M"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`Z-3D@861M:6XO<&5R;7,O9&5L971E+G!H<#HU-PHC
M.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#@@861M:6XO<&5R;7,O:6YD97@N
M<&AP.C(Q"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@*;7-G:60@(E!E
M<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,PIM
M<V=I9"`B4&5R=2(*;7-G<W1R("+7I->HUY4B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C`*;7-G:60@(E!E=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@V"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R("+7I->9UYS7F=>DUYG7
MH->9UYG7G2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HU,#$*;7-G:60@(E!H;W1O<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DP"FUS9VED(")0:71C86ER;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM
M<V=I9"`B4&EX96QS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,0IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS
M9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O
M(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I
M9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI
M<R!E;&5M96YT+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-3<P"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y
M96%R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F
M;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3,P-0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L
M:60@25`@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C8U,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T
M92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-0IM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E
M('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@
M=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+VUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE
M(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M
M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@
M(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@X"FUS9VED(")0;VQA;F0B"FUS9W-T<B`BUZ37E=><
MUYG7GR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4&]L
M:71I8W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C4Q,`IM<V=I9"`B4&]L;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,PIM
M<V=I9"`B4&]R='5G86PB"FUS9W-T<B`BUZ37E=>HUYC7E=>2UYPB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z
M-3$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*
M;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)
M34%0*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W."!L
M:6(O0FQO8VLO;65T87(N<&AP.C(X,PHC+"!P:'`M9F]R;6%T"FUS9VED(")0
M<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDQ"FUS9VED(")0
M<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HQ,S,*;7-G:60@(E!R969S7VQD
M87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S<*;7-G:60@(E!R97-S
M=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q"FUS
M9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(Y"FUS9VED(")0<F5S<W5R
M93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@
M82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,S4R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,S4V"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@
M(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0IM
M<V=I9"`B4')O8FQE;2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F]B;&5M
M+G!H<#HQ,C8*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X-0IM<V=I9"`B4')O
M:F5C=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$Q.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3DV"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,R.#<*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM
M<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8T-@IM<V=I9"`B4'5B;&EC($ME>2!!;&=O
M<FET:&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@
M(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S
M9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$*;7-G:60@(E!U97)T
M;R!2:6-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S0S,30N<&AP.C4U"FUS9VED(")0=7)G92!M97-S86=E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DV"FUS9VED(")1871A<B(*;7-G<W1R("+7I]>8
MUZ@B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C$*;7-G:60@(E%U97)Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B
M475O=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+
M97D@*"5D(&)I="DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(W,@IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS
M9VED(")286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V
M"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@4VAO=V5R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0X"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED
M(")286EN('1O(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#<*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E860@;65S<V%G97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN
M8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H
M:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T
M"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,SDU"FUS9VED(")2969R97-H($1Y;F%M:6,@365N
M=2!%;&5M96YT<SHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,T-0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDT"FUS9VED(")2
M969R97-H(')A=&4Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G:60@(E)E9V5X(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-#(*;7-G:60@
M(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR,#@*;7-G:60@(E)E;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,S.`IM<V=I9"`B4F5M87)K<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$W"FUS9VED(")296UO=&4@4V5R
M=F5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC
M;VTO:&]R9&4I.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA
M>6]U="YI;F,Z."!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR
M.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(*;7-G:60@(E)E
M;6]V92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-38Q"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")296UO=F4@<&%I
M<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS
M9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R
M87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED(")296UO
M=F4@=&AE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@
M;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q"FUS9VED(")296UO=F4@=7-E
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N
M:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X
M(&9R86UE=V]R:R]24$,O4E!#+W!H<&=W+G!H<#HQ-S,*;7-G:60@(E)E<75E
M<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-3`*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M-S8@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HX,SD@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HW,#0*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<U,R!F<F%M97=O
M<FLO5D93+U9&4R]H;W)D92YP:'`Z-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP
M.C<W-@HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T
M('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S0*;7-G:60@(E)E
M<75I<F5D($9I96QD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,T,PHC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3D@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C<X"FUS9VED(")297-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G:60@
M(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$R.`IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-B!A9&UI;B]P:'!S:&5L
M;"YP:'`Z-CD@861M:6XO<W%L<VAE;&PN<&AP.C8T"FUS9VED(")297-U;'1S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ
M,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O
M($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C,X"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.3<*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED(")2:6-H
M(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8S"FUS9VED(")2:61D;&5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M.`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$Q-`IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3`*;7-G:60@(E)I9VAT
M('9A;'5E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R
M=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.3@*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`BUZC7E=>>UZ#7
MF=>4(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(R-`IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(Q"FUS9VED(")2;W1A
M=&4@3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C(W"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@
M(E)O=W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL
M(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S
M(&]N;'DB"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q.`IM
M<V=I9"`B4G5N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3D*;7-G:60@(E)U
M<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R("+7J->5UZ'7F=>4(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P,`IM<V=I9"`B4G=A;F1A(@IM<V=S='(@(M>HUY77D->@UY/7E"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED
M(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@
M(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@R"FUS9VED(")305-,(&%U=&AE
M;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C<*;7-G:60@(E--4R!-97-S86=I
M;F<B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Y"FUS9VED
M(")344P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(X-0IM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O
M:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#4T"FUS9VED(")34T@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF
M:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM
M<V=I9"`B4U5#0T534R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-3,*
M;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P-PIM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S,0IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE
M=FES(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.0IM<V=I9"`B4V%I;G0@3'5C
M:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.0IM<V=I9"`B4V%I;G0@4&EE
M<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0T"FUS
M9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(U,0IM<V=I9"`B4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q,@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$V"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T
M96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$*;7-G
M:60@(E-A=61I($%R86)I82(*;7-G<W1R("+7HM>HUY$@UY37H=>BUY77D]>9
MUZHB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$U"FUS9VED
M(")3879E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I
M9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S
M8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E('-C<FEP="!T
M;SH@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I
M9"`B4V-I96YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ
M-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(M>7UYG7I->5UZDB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,V"FUS9VED(")396%R8V@@16YG:6YE
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.38V
M"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-PIM<V=I9"`B4V5L96-T
M(&$@9&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E
M;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I
M9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.`IM<V=I9"`B4V5L
M96-T(&%L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-C4T"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C@W-0IM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<Y"FUS
M9VED(")396QE8W0@;F]N92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB
M;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y
M;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O
M<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B
M4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T
M92!F;W)M870Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N
M=&ET>7-E;&5C="YI;F,Z.3(*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@
M>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM
M:71E<CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z
M,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C
M="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S$P"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S
M8VAE;64N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M-3(*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3$*
M;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-#0*;7-G:60@
M(E-E;F0@4TU3(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,*;7-G:60@(E-E
M;F5G86PB"FUS9W-T<B`BUZ'7H->2UYPB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,R.`IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E
M;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`R
M"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-30*;7-G:60@(E-E<G9E<B!D871A('=R
M;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M<W-I;VYS+G!H<#HR-@IM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`B(@H*
M(SH@;&EB+V%P:2YP:'`Z,30U"FUS9VED(")397-S:6]N<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S(R"FUS9VED(")3970B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS9VED
M(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S
M=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3@*;7-G:60@(E-E="!U<"!R96UO=&4@
M<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R
M=&%L+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<*
M;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@
M86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P,0IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L
M:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O
M=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-S<*;7-G:60@(E-E='5P(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,U"FUS9VED
M(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.#`*;7-G:60@(E-E
M=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,*;7-G:60@(E-E>6-H96QL97,B
M"FUS9W-T<B`BUY#7F=>9XH"3UZ'7F=>9UZG7G"(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HU,3D*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")3
M:&]R="!3=6UM87)Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT-3`*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D
M(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W
M(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@
M;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.30*;7-G:60@(E-H;W<@;&%S
M="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<W,PIM<V=I9"`B4VAO=R!O<'1I
M;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#`V"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(Y"FUS9VED(")3:&]W
M('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA
M;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@
M4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED(")3
M:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I
M86QO9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-S<Q"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B4VAO=V5R
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I
M9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3:&]W97)S(&EN('1H
M92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q.0IM<V=I9"`B4VAR:6YK(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z.3$P"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z.3<R"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z,3`U.`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C$Q,C`*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HQ,3@S"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(R,PHC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R-3(*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C@U"FUS9VED(")3
M:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H
M92!W87D@9FER<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,0IM<V=I9"`B
M4VEE<G)A($QE;VYE(@IM<V=S='(@(M>GUYG7F=>HUY0@UYS7F=>0UY77GR(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C<*;7-G:60@
M(E-I9VX@=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HW,3,*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B
M4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V
M"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`BUZ'7F=>@UY+7I->5UZ@B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#0*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY,#`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C0Q"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R-30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR,PHC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$V"FUS9VED(")3:7IE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC
M92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3`*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#@*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3
M;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I
M9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E<G,@
M16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP"FUS9VED(")3;F]W
M(&1E<'1H.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M.30*;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#(*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$T"FUS9VED(")3;VUA;&EA(@IM<V=S='(@
M(M>AUY77GM><UYG7E"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM
M<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.3$Y"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D<F5S<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U"FUS9VED(")3;W5T:"!!9G)I8V$B
M"FUS9W-T<B`BUY/7J->5UYWB@)/7D->DUZC7F=>GUY0B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX
M.#4Y+3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,0IM<V=I9"`B4V]U=&@@
M1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N
M+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@
M:6X@8V5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HX,3D*;7-G:60@(E-P86-E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*;7-G:60@(E-P
M86-I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D
M9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,`IM<V=I9"`B4W!A:6XB"FUS
M9W-T<B`BUZ'7I->HUY,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3`W"FUS9VED(")3<&%M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O
M87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I
M9"`B4W!L:70@<F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV-@IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M,0IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(M>AUZC7F2#7G->@UZ?7E"(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,2!L:6(O0FQO8VLO
M;65T87(N<&AP.C@V"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C<*;7-G:60@(E-T87(@5')E:R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DT(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#(*;7-G:60@(E-T87)T('EE87(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S$*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$P"FUS9VED(")3=&%T
M=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P
M.`IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E-T<F5E="!!
M9&1R97-S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PIM<V=I9"`B
M4W1R:6YG(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@X,0IM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E
M<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S
M97(N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<
M(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S-B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,38*;7-G:60@(E-U8FUI
M="(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<(B5S7"(@=&\@
M=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R
M97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3
M=6)S8W)I<'0B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P
M,@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB
M(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HW.2!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0U"B,L('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`T"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T
M96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*
M;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!2
M96QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C4W(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.0IM
M<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C
M:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,38W"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P-`IM<V=I9"`B4W5D86XB"FUS9W-T<B`BUZ'7
ME=>3UY\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@
M4V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8P"FUS9VED(")3=6YN>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$P"FUS9VED(")3=6YR:7-E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P.0IM<V=I
M9"`B4W5N<FES93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,3,*;7-G:60@(E-U;G-E="(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$R"FUS9VED(")3=6YS970Z
M("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,SDT"FUS9VED(")3=7!P;W)T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,34*;7-G:60@(E-U<FEN86UE(@IM
M<V=S='(@(M>AUY77J->9UZ#7G2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3<U"FUS9VED(")3=7)N86UE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#D*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.0IM<V=I9"`B4W=A>FEL86YD(@IM<V=S
M='(@(M>AUY77E=>6UYG7G->@UY,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U"FUS9VED(")3
M=V5D96XB"FUS9W-T<B`BUZG7E=>5UY/7F=>4(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38*;7-G
M:60@(E-W:71Z97)L86YD(@IM<V=S='(@(M>IUY77E=>9UZ4B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L;V<@9&5L
M971E9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30U
M"FUS9VED(")3>6YC34PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]3
M44PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A
M<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@*;7-G:60@(E-Y
M<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(M>AUY77J->9UY0B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B
M5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C,*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4+5-T;W)M
M<R!%87)L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+W1S
M=BYP:'`Z,38V"FUS9VED(")44U8@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S-`IM<V=I9"`B5&%B;&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W
M"FUS9VED(")486)L92!3970B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B
M;&4@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T
M"FUS9VED(")486EW86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@
M;V8@0VAI;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-0IM<V=I9"`B5&%J
M:6MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U"FUS9VED(")486YZ
M86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(M>8UZ#7EM>@UYG7
ME"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VAO;VMS
M+G!H<"YD:7-T.C$P-C8@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y-@IM
M<V=I9"`B5&%S:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S0*;7-G:60@(E1E;&5P:&]N92!.=6UB97(B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#(*;7-G:60@(E1E
M;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C(V"FUS9VED(")496UP97)A='5R92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$W"FUS9VED(")496UP
M97)A='5R93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\
M8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8Y-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.`IM<V=I9"`B5&5M<&QA
M=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X
M"FUS9VED(")497AT(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-SD*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS
M9VED(")497AT(&%L:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.3<*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,C0*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(M>JUY#7
MF=><UZ#7DR(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(Y"FUS
M9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&ES=&]R>2](:7-T;W)Y+G!H<#HV,PIM
M<V=I9"`B5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG
M:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?24U34"])35-0+T)O;VLN<&AP.C$R.3@*;7-G:60@(E1H
M92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE
M($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL
M>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N
M<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@
M17AI=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HQ.#D@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HR,C,*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HR-C0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS
M,#,*;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I
M9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B
M"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM
M<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G
M:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE
M9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A
M8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3<R"FUS9VED
M("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U
M:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E
M:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@
M(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE
M(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C0V,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@96UA:6P@861D<F5S<R`E<R!H
M87,@8F5E;B!A9&1E9"!T;R!Y;W5R(&ED96YT:71I97,N(%EO=2!C86X@8VQO
M<V4@=&AI<R`B"B)W:6YD;W<@;F]W+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q-@IM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@
M9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S<@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,S$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W,"!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4R,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I
M;F=S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR-#(*;7-G:60@(E1H92!F:6QE(&-A;FYO="!B92!C;W!I960@;VYT;R!I
M='-E;&8N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP
M.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O
M<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G
M:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E
M('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B
M<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N
M9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@
M;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E
M<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I
M="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*
M(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9
M;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y
M;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$Q.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E
M;&5T960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@
M<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!'
M;G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@
M8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.
M+G!H<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@
M<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N
M(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE
M(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#@U"FUS9VED(")4
M:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A
M9V4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$P,`IM<V=I
M9"`B5&AE(&YE=R!F<F]M(&%D9')E<W,@8V%N)W0@8F4@=F5R:69I960L('1R
M>2!A9V%I;B!L871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C0W-`IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@
M;75S="!B92!N=6UE<FEC+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S(*;7-G:60@(E1H92!O<&5N<W-L(&UO
M9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@
M8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP
M:'`Z,C@S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E
M(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E
M>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N<&AP.C,R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS
M-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N
M<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP
M:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<G!M+G!H<#HS
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP
M:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H
M<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D
M('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N
M('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C0X-PIM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T
M(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS
M9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#<Y"FUS9VED
M(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B
M965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R
M<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@
M7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R
M97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0W
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R`H)60I
M(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C(P,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M
M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S$S"FUS9VED(")4:&4@
M=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H
M92!S8W)E96XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD
M(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H
M92!T;W`@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A
M+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO
M<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O
M1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U
M;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-30@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$Q-0IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<
M(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET
M>2])9&5N=&ET>2YP:'`Z-#0T(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET
M>2YP:'`Z-#0X"FUS9VED(")4:&5R92!A<F4@;F\@96UA:6P@861D<F5S<V5S
M('1O(&-O;F9I<FTN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,3<X"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A
M=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C,T-0IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H
M870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F
M:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@
M;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU
M<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S
M>7-T96TZ("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R
M:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F
M<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDS,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.
M;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M<F]W<V5R+T)R;W=S97(N<&AP.CDS-@HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4
M:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W960@
M<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O
M=W-E<B]"<F]W<V5R+G!H<#HY,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE
M("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S
M86=E('!A<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@R"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@
M4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F
M;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0
M;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T
M(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R
M"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I
M<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R
M="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*
M;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP
M(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,S@*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED
M(&-A<F0@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE
M($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A
M>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H
M92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T
M:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I
M=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M
M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S
M:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--
M5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL
M>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A
M8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP
M+FET*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C$*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`Y,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3$Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#8@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(V,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,S`Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#8*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,34V-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#0W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C8@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,#,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#8*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U-R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,C(Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,38@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U.`HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-C0X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,C$*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S,"!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,S`X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,38@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R-`IM<V=I9"`B5&AI<R!F:65L
M9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3`V.0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&EN=&5G97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-#(T"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DX"FUS9VED(")4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(W"FUS9VED(")4:&ES(&9I96QD
M(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I
M;G1E9V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HY.3,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E
M<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R
M.0IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C
M;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q
M,C,T868G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HU-C4*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E
M<W-E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC
M.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE
M8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I
M;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W
M87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N
M=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C4Y-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T
M("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M
M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H
M:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T
M<GDN<&AP.C$X,@IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E
M86-T:79A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M
M8F5R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K
M97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F
M<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")4:'5N9&5R
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3`*
M;7-G:60@(E1I8VME=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C0S,R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*
M;7-G:60@(E1I;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0P,@IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C(*;7-G:60@(E1I;64@9F]R;6%T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U,SD*;7-G
M:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`*
M;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE
M("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-@IM
M<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@
M=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL
M92!C;&EC:VEN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,P,PIM<V=I9"`B5&]D87DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B
M5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,*
M;7-G:60@(E1O9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-@IM<V=I9"`B
M5&]K96QA=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S`U"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(Y"FUS9VED(")4;VYG82(*;7-G<W1R("+7I]>1UY77IM>JXH"3UY#7
MF=>9XH"3UYC7E=>@UY+7E"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0IM<V=I9"`B5&]P(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*
M;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8X"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S,@IM<V=I9"`B5')I;FED860@86YD(%1O8F%G
M;R(*;7-G<W1R("+7F->HUYG7H->9UY/7DR#7E=>8UY77D=>2UY4B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDX"FUS9VED(")4<G5E(&]R(&9A
M;'-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C@*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`BUYC7E=>@UYG7H=>9UY0B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`BUYC7E=>H
MUZ?7F=>9UY0B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y.`IM<V=I9"`B
M5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M-PIM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C`*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,S"FUS9VED(")4=79A;'4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H
M;VEC93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-C,*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`BUY#7JM>H
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A
M='5S(')E<&]R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(M>0
MUZK7J#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,W"FUS9VED(")59V%N9&$B"FUS9W-T<B`B
MUY#7E=>2UZ#7D]>4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-@IM<V=I9"`B56MR86EN92(*
M;7-G<W1R("+7D->5UZ?7J->9UYG7H->4(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z-#0U"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,SDS"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N
M9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,3@@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<X
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S
M:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z-S(Q(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`V
M,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#<R"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@
M7"(E<R\E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C@T.`IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(U
M."!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-C,*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(R-B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,C,Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HR,SD*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,W,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O
M<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HS.#<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C@V"FUS9VED(")5
M;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L
M92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,C@Q"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(Y.`IM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V"FUS9VED(")5
M;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C,P,R!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S<@861M:6XO<&5R;7,O9&5L
M971E+G!H<#HT,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C,V-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,S$Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#$X(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@
M96UP='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C,W."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S@R
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S
M:79E;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C,W,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,S4@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,S<T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M-#0S(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#4U"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C$R
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HS,S8@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-PHC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HQ.#<*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HS,30@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C0Q,PHC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-#(Q"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0S,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L
M>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.#$R"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER
M96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8P-`IM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF
M:6-A=&4@9&5T86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-
M4U`O24U34"YP:'`Z-#,W(&9R86UE=V]R:R].971?24U34"])35-0+T%U=&@N
M<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T
M:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C$X(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(R,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3@U
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ.3`*;7-G:60@(E5N
M86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.CDX(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z.3,*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#8@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HV,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,3`@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,30Q"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z.#$@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#8*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,30P(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HW-@IM<V=I9"`B56YA8FQE('1O(&]P96X@
M5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R
M97-S960@87)C:&EV92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.CDP,PIM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I
M;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.CDS-`IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@
M*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X
M"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-S`R"FUS9VED(")5;F%B;&4@
M=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$P-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO
M;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,R,PIM<V=I9"`B56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C,U-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T."!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C0S(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q,R!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z-#4R"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M,S0Y(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,34*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,S,0IM<V=I9"`B56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED
M(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B
M56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-30@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HQ-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3@Y"FUS9VED(")5;F%B
M;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,30@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T-@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,34Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.CDP.0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q
M=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E
M<FQI;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z
M-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E
M<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,0HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#@*;7-G:60@(E5N97AP96-T960@
M<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q
M-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,SD*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<V"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,@IM<V=I
M9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G
M97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DY"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A
M=&5S(@IM<V=S='(@(M>4UY#7GM>9UZC7E=>9UY77JB#7E->>UY#7E=>7UY/7
ME=>J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,X"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G
M<W1R("+7E->>UY[7G->;UY0@UY37GM>0UY77E]>3UZHB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0P"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(M>0UZC7IM>5UZKB
M@)/7E->1UZC7F=>J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.0IM<V=I9"`B56YI=&5D(%-T
M871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-R!L:6(O0FQO8VLO;65T87(N
M<&AP.C@S"FUS9VED(")5;FET<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C4X(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0R.0HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,S`*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED
M(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A
M9V4@240I+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,34R"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S
M<W=O<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C
M=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT
M:71Y+TED96YT:71Y+G!H<#HS,3D*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU
M.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S
M<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R
M:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T
M92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L
M;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-R!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-PHC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.CDS,PIM<V=I9"`B56YS=7!P;W)T960@17AT96YS
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED
M(")5<&1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHW-PIM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HQ-#,@861M:6XO<&5R;7,O961I="YP:'`Z,3`Q('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57!D871E9"!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C@Y"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3@*;7-G:60@(E5P
M;&]A9"(*;7-G<W1R("+7E->BUYS7D->4(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E
M='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*
M;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ
M.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0Q"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(M>0UY77J->5UY+7
ME=>5UYDB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-PIM<V=I9"`B57-E(&EF(&YA
M;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR
M,0IM<V=I9"`B57-E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O4F5G:7-T<GDN<&AP.C<V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,C`R"FUS9VED(")5<V5R($%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,C0U"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@<VEG
M;G5P+G!H<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B
M(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I<W1R871I;VX@
M:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V.0IM<V=I9"`B57-E<B!A8V-O
M=6YT(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS
M-"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C8T('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R
M"FUS9VED(")5<V5R;F%M92(*;7-G<W1R("+7I]>5UY,@UY;7F=>4UY77F2#7
MGM>IUZK7GM>I(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C$R-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR
M96%D>2!E>&ES=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*;7-G:60@(E5S97)N86UE
M.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI
M;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T,@IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-S,@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C@X"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@
M;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,3(W"FUS9VED(")686-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX-S`*;7-G:60@(E9A;&ED(&QO8V%T:6]N
M<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(E9A;&ED:71Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(U-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4Y-PIM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO
M=RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8P
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-3(@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(W-`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C$*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM
M<V=I9"`B5F%L=65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q,3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Y-`IM<V=I
M9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#D*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`BUY77H->5UY#7F->5(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S.`IM<V=I9"`B5F%R
M:6%B;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-0IM<V=I9"`B5F5N97IU
M96QA(@IM<V=S='(@(M>5UZ#7EM>5UY#7G->4(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F
M86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W
M:71H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<P,0IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R("+7DM>9UZC7H=>4
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T,@IM<V=I9"`B5F5R
M<VEO;B!#;VYT<F]L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L
M(&%L:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")697)Y
M($AI9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.`IM<V=I9"`B5FEE="!.
M86TB"FUS9W-T<B`BUY77F=>9UYCB@)/7H->=(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HR,#`*;7-G:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.3<U
M"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA
M;"!W96(@<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HX,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A
M<R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V"FUS9VED(")6:7)G:6X@
M27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W"FUS
M9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(R,0IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4W"FUS9VED
M(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F
M;VYE($ET86QY('9I82!33510(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z
M,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!2
M14U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED
M(")724X@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,`IM<V=I
M9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H
M<#HR.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HQ
M,C$@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS-`IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$Y
M"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"FUS9VED(")796%T:&5R
M+F-O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM
M<V=I9"`B5V5B(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT-C`*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E
M96ML>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H
M<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C4W('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C<T('-E<G9I8V5S
M+W!O<G1A;"]M;V)I;&4N<&AP.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E=E
M;&-O;64L("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,C`Q"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C(P,@IM<V=I9"`B5V5S=&5R;B`H25-/
M+3@X-3DM,34I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X"FUS9VED(")797-T
M97)N(%-A:&%R82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#0Q"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@
M<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES
M('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@
M<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V-@IM<V=I9"`B5VAE<F5I<R!!
M=7-T<F%L:6$@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,S8*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@
M96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$Q.`IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE
M9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V
M"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@
M(E=I9'1H('5N:70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3,V"FUS9VED(")7
M:6MI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.3,@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*
M;7-G:60@(E=I;F0B"FUS9W-T<B`BUZC7E=>7(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(E=I;F0@16%R;'DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HY,@IM<V=I9"`B
M5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$V.`IM<V=I9"`B5VEN9#HB"FUS9W-T<B`BUZC7E=>7.B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S8*;7-G:60@(E=I
M;F0Z("(*;7-G<W1R("+7J->5UY<Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV.0IM<V=I9"`B5VES9&]M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR,3(*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HW,`IM<V=I9"`B5V]R:R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED
M(")7;W)K(%!H;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C$Y,R!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR.30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I
M;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,S,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E
M9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S
M970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Y"FUS9VED(")8+5)E9B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4Y-`IM<V=I9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS
M9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8
M-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")8
M-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X,PIM<V=I9"`B6#4P
M.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,38*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U.`IM<V=I9"`B65E962(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3$Q,PIM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R
M;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,@IM<V=I9"`B665M96XB"FUS
M9W-T<B`BUZK7F=>>UY\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.38X"FUS9VED(")997,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@
M(EEE<RP@22!!9W)E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%
M6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@
M=&\@5UE325=91RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HR,S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D
M(&)L;V-K<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-#(U"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP
M.C,R-0IM<V=I9"`B66]U(&-A;FYO="!H879E('1H92`G7%PG(&-H87)A8W1E
M<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U)00R]24$,O<&AP9W<N<&AP.C$Q-PIM<V=I9"`B66]U(&1I9"!N;W0@875T
M:&5N=&EC871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#8S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#,*;7-G:60@
M(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@
M9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F
M:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDX-PIM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN
M<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@:&%V92!R97%U
M97-T960@=&\@861D('1H92!E;6%I;"!A9&1R97-S(%PB)7-<(B!T;R!T:&4@
M;&ES="!O9B!Y;W5R("(*(G!E<G-O;F%L(&5M86EL(&%D9')E<W-E<RY<;B(*
M(EQN(@HB1V\@=&\@=&AE(&9O;&QO=VEN9R!L:6YK('1O(&-O;F9I<FT@=&AA
M="!T:&ES(&ES(')E86QL>2!Y;W5R(&%D9')E<W,Z7&XB"B(E<UQN(@HB7&XB
M"B))9B!Y;W4@9&]N)W0@:VYO=R!W:&%T('1H:7,@;65S<V%G92!M96%N<RP@
M>6]U(&-A;B!D96QE=&4@:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R-C4*;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R
M(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A
M;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI
M;F<@<')E9FEX+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,3DR"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A
M;'5E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E
M(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z-#<T"FUS9VED(")9;W4@;75S="!C;VYF
M:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R
M:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L
M96T@<F5P;W)T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T
M:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M
M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$X"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HY.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S
M97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP
M:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED
M(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-0IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y
M36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T
M96=O<GD@;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D
M('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<U"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E
M(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHS-`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,34*;7-G:60@
M(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-R!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDR"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@
M=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E
M8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,P"FUS
M9VED(")9;W5R($YA;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I
M;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@
M>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A
M8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A
M=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@
M;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@
M;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W
M<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI
M;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C
M=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO:69R86UE+G!H<#HU-0IM<V=I9"`B66]U<B!B<F]W<V5R(&1O
M97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U
M<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN
M(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C$*;7-G:60@(EEO
M=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!R969S+G!H<#HQ,C0*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>2!H
M87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,38Q"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#0*;7-G:60@
M(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HY.3D*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X<&ER960N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V
M"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E
M<R!I<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D
M871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-38*;7-G
M:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO
M=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S
M<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO
M9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,S,*;7-G:60@(EEO=7(@<&%S
M<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R
M<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-`IM<V=I9"`B675G
M;W-L879I82(*;7-G<W1R("+7F=>5UY+7E=>AUYS7D=>9UY0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4V"FUS9VED("):86UB:6$B"FUS9W-T<B`B
MUY;7GM>1UYG7F=>4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-PIM<V=I9"`B6FEM8F%B=V4B
M"FUS9W-T<B`BUY;7F=>>UY'7D=>5UY77E"(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HW,0IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W
M-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM
M<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!R;V)L96TN<&AP.C@X"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS
M+FIS.C$S"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O
M=&5S+G!H<#HQ-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D
M(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@
M)7,@;V8@)7-=(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,34V,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(B(*"B,Z(&QI
M8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED(")?2&5L
M<"(*;7-G<W1R("+7HM>6UZC7E"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R
M;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+TUE;G4N<&AP.C$Y-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"FUS9VED(")?
M3&]G(&]U="(*;7-G<W1R("+7E->JUZ#7JM>GUY77JB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I
M9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S
M='(@(M>0UZ37J=>HUY77F=>5UZHB"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G
M:60@(E]097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]2
M96UO=F4@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,C4*
M;7-G:60@(E]3971U<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L
M92!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$R
M.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3(P"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B
MUZ'7I->H(->;UZK7E=>1UY77JB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ,@IM<V=I
M9"`B8V%L96YD87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ.#0@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B8V%L;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T92!O=71P=70@
M9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DU"FUS
M9VED(")C;&EC:R!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A
M9V4@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C8*
M;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P;W)T86PO961I="YI;F,Z,S`*;7-G:60@(F5D:70B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ.#(*;7-G
M:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B9F%L;&EN9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY
M,#(*;7-G:60@(F9I;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ.#8@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-S(@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@
M*"5S*2!A="`E<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C0T"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-#@*;7-G
M:60@(F@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HS-C$*;7-G:60@(FAH(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T
M(&YA;64@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*;7-G:60@(FEM;65D
M:6%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A
M9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38R"FUS
M9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L
M('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK
M:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R
M;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<R"FUS9VED
M(")M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C(X,2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR-#$*;7-G:60@(FYA;64B"FUS
M9W-T<B`BUZG7G2(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C0*;7-G
M:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,C`*;7-G:60@(FYO="!Y970@:6UP
M;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,#0*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I
M9"`B<&5R8V5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R96UO
M=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S0*;7-G:60@(G)I<VEN9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C$P,@IM<V=I9"`B<VAO=R!D:69F
M97)E;F-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(
M5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HS.#D*;7-G:60@(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS9VED(")S=&5A
M9'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.`IM<V=I9"`B=&%S:R!L:7-T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS-2!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,C<Q"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C
M;VYF:7)M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VAO<F1E+G!H<#HR-SD*;7-G
M:60@(G5N:VYO=VX@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-C4*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B
M=D-A<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(T,`IM<V=I9"`B=SHB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M
M(@IM<V=S='(@(B(*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&\O:&]R9&4N<&]T````````````````````````````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#4W-3$V,0`Q,#4Q-30S,S<U-``P,C`Q-#$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````(R!33TU%
M($1%4T-225!4259%(%1)5$Q%+@HC($-O<'ER:6=H="`H0RD@645!4B!(;W)D
M92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H
M92!S86UE(&QI8V5N<V4@87,@=&AE(%!!0TM!1T4@<&%C:V%G92X*(R!&25)3
M5"!!551(3U(@/$5-04E,0$%$1%)%4U,^+"!914%2+@HC"B,L(&9U>GIY"FUS
M9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!004-+04=%
M(%9%4E-)3TY<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N
M:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-BTP-RTS,2`Q
M.#HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B!914%2+4U/+41!($A/
M.DU)*UI/3D5<;B(*(DQA<W0M5')A;G-L871O<CH@1E5,3"!.04U%(#Q%34%)
M3$!!1$1215-3/EQN(@HB3&%N9W5A9V4M5&5A;3H@3$%.1U5!1T4@/$Q,0&QI
M+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z
M('1E>'0O<&QA:6X[(&-H87)S970]0TA!4E-%5%QN(@HB0V]N=&5N="U4<F%N
M<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,X-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S
M-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDQ"FUS9VED("(@*'1O9&%Y*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDS"FUS
M9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S@Y"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-2!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4P"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS.38*;7-G:60@(B!A="`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-,22]#3$DN<&AP.C(X-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<P-PHC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$P.34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H
M92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1R
M964O5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T
M<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S
M(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E
M<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-
M0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HU.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y
M;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C<P-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HX-#(@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C(Q-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U
M<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,C8T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0U,"!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C4Q-@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C8X.2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<V,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C$@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#$*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS-#<@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY
M(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,U
M.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X.`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M('1O("5S(&]F("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.34R"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S
M<R!";V]K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.30T"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.38P"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,3(W"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO
M="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L
M;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE
M('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U-"!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDY"FUS9VED("(L(&=U<W1I;F<@
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3DP(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3DU"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S
M=&EN9R`E<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(P,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@
M=&\@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HR.30@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,30V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HW-#@*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B
M,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]086=E<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R-@IM<V=I9"`B
M02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W
M,0IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.30T"FUS9VED
M(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M
M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,3<W"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3`X"FUS9VED("(B
M"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3`R-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*
M(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3`V"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y
M+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*
M(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D
M('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"FUS9VED(")!32!#;&]U
M9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G
M:60@(D%-($QI9VAT(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%)A:6XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3,*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G:60@(D%-(%-N
M;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE
M+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!
M4$D@240B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-30*;7-G:60@
M(D%B;W5T+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C(X,0IM<V=I9"`B06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,U"FUS9VED(")!8V-E<W,@9&5N:65D
M(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z,PIM<V=I9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@*;7-G:60@(D%C
M8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT
M(&9R;WIE;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,S-0IM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T96UP;&%T97,O<&]R=&%L
M+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL
M9"YI;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C(S,2!A9&UI;B]G<F]U<',N<&AP.C(S,@IM<V=I9"`B061D($-H
M:6QD($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY.0IM
M<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0V
M"FUS9VED(")!9&0@365M8F5R<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B061D($YE
M=R!'<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#@*;7-G
M:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M870*
M;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<
M(B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D
M(&$@;F5W('5S97(Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU-38*;7-G:60@(D%D9"!C;VQU;6XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I
M9"`B061D('!A:7(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,V-`HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@
M87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@
M861D<F5S<R!B;V]K.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R
M97-S(&)O;VLB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G
M:60@(D%D9"!U<V5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@
M<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I
M;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z
M-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H92!S
M>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U
M<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T-#$*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$T,0IM<V=I9"`B061D<F5S<R!";V]K
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S
M,30N<&AP.C4V"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O
M<B!O=&AE<B!U<V5R<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]I;F1E>"YP:'`Z
M,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q-PIM<V=I9"`B061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,T,PIM<V=I9"`B061S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*
M;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G
M:60@(D%L8F%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG
M97)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V
M"FUS9VED(")!;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B
M06QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C8*;7-G:60@(D%L
M;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C@*;7-G:60@(D%L;"!'
M<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HY,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U
M"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I
M9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@X.0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S
M<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S$*
M;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN
M<&AP.C4P-PIM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-@IM<V=I9"`B06QT97)N871E($E-
M4U`@3&]G:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4P-`IM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y-@IM<V=I9"`B06QT97)N
M871E($E-4U`@57-E<FYA;64B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z,S8*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R
M97-S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS
M9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P
M96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$U-0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S
M(%!R;WAY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C4Q"FUS9VED(")!;G-W97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM
M<V=I9"`B06YT87)C=&EC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED
M(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,V"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E
M='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B
M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A
M=&EO;B!,:7-T(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ,SD*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.0IM<V=I9"`B07!P
M;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T
M,@IM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R
M:6PB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G
M:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HW.`IM<V=I9"`B07)C:&EV92!&:6QE(%-I
M>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C8U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S<*
M;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L('!H<"UF;W)M870*
M;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I
M9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L('!H<"UF;W)M870*;7-G
M:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N
M9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I
M9"`B07)G96YT:6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R
M;65N:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*
M;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA
M;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS
M9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,C(*;7-G:60@
M(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC
M92!O<&5R871I;VYS/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3$S"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T
M<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T
M;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@
M9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T('1O
M(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@S"FUS9VED(")!='1R:6)U=&5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G
M:60@(D%U<W1R:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D
M(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y
M<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET
M97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N
M<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E
M9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T
M:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HV,`IM<V=I9"`B075T:%]I;6%P
M.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@
M(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U
M<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B075T:%]L
M9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I
M=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@
M(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H
M<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U
M<V5R("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@
M(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z
M-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%D;6EN+G!H<#HQ,#,*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&%T
M($E-05`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!
M=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,3<V
M"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R
M=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C@Y-`IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M-S`*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A
M:6QE9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G
M:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A
M<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR
M8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ
M,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"87)B861O<R(*;7-G<W1R
M("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<S"FUS9VED(")"87-E;&EN92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,PIM<V=I9"`B0F5L:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@
M(D)E;FEN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHY,`IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4
M>7!E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR,#<*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(P"FUS9VED(")";W)D97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R
M('1H:6-K;F5S<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE
M9V]V:6YA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY
M-@IM<V=I9"`B0F]T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"
M;W1S=V%N82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@27-L86YD(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R87II;"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A
M;&%M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0T-@IM<V=I9"`B0TU3(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@
M(D-20R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4Y.`IM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3$*
M;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.30R(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#4*(SH@8V]N9FEG+VAO
M;VMS+G!H<"YD:7-T.C$P-3`@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$U
M-PIM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B0V%L;2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S
M<VEO;G,N<&AP.C(R"FUS9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L
M('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C(S-2!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G-Q;"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&-O;FYE
M8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C0T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T
M"FUS9VED(")#86YA9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN
M8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R"FUS
M9VED(")#86YC96PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0T-"!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S4*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HV-S4@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C(R,@IM<V=I9"`B0V%N;F]T(&-O<'D@9FEL92AS*2`M('-O=7)C92!A
M;F0@9&5S=&EN871I;VX@87)E('1H92!S86UE+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM
M<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4Q,"!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#4*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HW-3$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C$X-PIM<V=I9"`B0V%N;F]T(&UO=F4@9FEL92AS*2`M(&1E<W1I;F%T:6]N
M(&ES('=I=&AI;B!S;W5R8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P
M<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964N
M<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV
M.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI
M;&1R96X@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E
M92]$871A5')E92]S<6PN<&AP.C8Q,0IM<V=I9"`B(@HB0V%N;F]T(')E;W)D
M97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O
M97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Q"FUS9VED(")#86YN;W0@
M<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O
M=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S4P"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;FYO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C0*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R
M:65R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,PIM
M<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@V"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED
M(")#96QL(%!H;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@4')O
M<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(W-`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#96QT
M:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#96YT
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I
M8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@R"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C<P,`IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,@IM<V=I9"`B
M0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-E<G1I9FEC871E(%!O
M;&EC:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B0VAA9"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q
M"FUS9VED(")#:&%N9V4@66]U<B!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-CD*;7-G:60@(B(*(D-H86YG92!T:&4@
M;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E
M860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G:60@(B(*(D-H
M86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H
M92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T('EO=7(@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6QE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@S"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q
M,BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G
M:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C<*;7-G:60@(D-H;V]S92!!<'!L
M:6-A=&EO;CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3
M:6=N=7`N<&AP.C(W,`IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM
M<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(Y-0IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P
M;&%Y(&1A=&5S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@
M;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z.3`U"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S
M(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B
M0VQE87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(Y"FUS9VED(")#
M;&5A<B!1=65R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]C;&5A<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@
M=7-E<CH@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A
M<B!U<V5R(&1A=&$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E
M+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-@IM<V=I9"`B0VQO=61S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$W"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D-L;W5D
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN
M9RD@27-L86YD<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I
M9&5B87(N:6YC.C(S"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,X"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,SD*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,R!S97)V:6-E<R]I;6%G97,O8V]L
M;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@T-@IM<V=I9"`B0V]L
M;W5R('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV-`IM<V=I9"`B
M0V]L=6UN('1I=&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C8V"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO8VUD<VAE;&PN<&AP.C(V"FUS9VED(")#;VUM86YD(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L
M;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3,*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D-O;6UO;B!.86UE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-@IM<V=I9"`B0V]N
M9&ET:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Q
M"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.CDS"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S0*;7-G
M:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O
M<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC
M(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,#0*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0W"FUS9VED(")#;VYN96-T:6]N(&9A
M:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,C`T"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,T-PIM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3D*
M;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z.#`Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F
M=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#@X
M"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDU,"!C;VYF
M:6<O:&]O:W,N<&AP+F1I<W0Z,3`W-PIM<V=I9"`B0V]N=&%C=',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T
M;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HV,`IM<V=I9"`B0V]N=&5N="!T
M>7!E(&]F(&-O;7!R97-S960@9FEL93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HS,"!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G
M:60@(D-O;VL@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C$*
M;7-G:60@(D-O<'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HT.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z
M("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS
M9VED(")#;W-T($E$(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O
M<W1A(%)I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D
M)TEV;VER92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HY.#8*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S
M86=E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3`V-`IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HQ,C`*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0X,@IM<V=I
M9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,34V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@
M8F%L86YC92X@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C0V-@IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@3$1!4"!S97)V
M97(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V
M97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3$S-PIM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A
M=&$Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4R,PIM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,C0V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S
M971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.CDV,@IM<V=I9"`B0V]U;&0@;F]T(&1E=&5R
M;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S
M<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H
M(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM
M<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I
M<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z
M-C@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q
M.0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE
M(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@
M9F]R('=R:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT,C`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M
M;V1U;&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T
M-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0IM<V=I
M9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR,SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@V"FUS9VED("(B"B)#
M;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D
M('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@
M8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`U"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T-@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-#$T"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C0R,`HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HT,C8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D
M<F5S<R!B;V]K+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(P-`HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C0*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(X"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@
M(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HU.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@
M8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S
M879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R
M('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B
M86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@
M)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,30S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E
M<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E
M(&-O;G1A8W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F
M;W(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S8S"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I
M9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R
M(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<
M(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,3D*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B0V]U
M;G1R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C<U"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I
M9"`B0W)E871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@
M;&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES
M96QE8W0N:6YC.CDV"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4R
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS
M9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S(S,`IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`IM<V=I9"`B0W5R<F5N="!397-S
M:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O
M0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0IM<V=I9"`B0W5R<F5N="!5<V5R
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED
M(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(V-`IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ
M("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS
M9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G
M:60@(D-Y<')U<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X-0IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(D-Y<FEL;&EC("A7:6YD
M;W=S+3$R-3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@W"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0U,B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(Y,`IM<V=I9"`B
M(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C
M:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS
M9VED(")$86EL>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z
M-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X.`IM<V=I9"`B1&%T86)A<V4@3&]O
M:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q-@IM
M<V=I9"`B1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`W"FUS9VED(")$
M871E('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C@Q(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,3$*;7-G:60@(D1A>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE
M=&4@0V]L=6UN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0U,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM
M<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI8B]P<F5F<RYP:'`Z,3$W"FUS
M9VED(")$969A=6QT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O;&]R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R])9&5N=&ET>2YP:'`Z
M.3@*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C<U"FUS9VED(")$969A=6QT(%-H96QL(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B
M1&5F:6YI=&EO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-PHC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,W('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-S$*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHY-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-PHC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T,"!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$X,PHC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS,@IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`B(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HR,#4@861M:6XO9W)O=7!S+G!H<#HR,S,*;7-G:60@
M(D1E;&5T92!'<F]U<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR-3$*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E<FUI<W-I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG
M(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU-`IM<V=I9"`B1&5L971E(&UE
M<W-A9V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S
M:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T
M92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I
M;VYS/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z
M,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,PIM
M<V=I9"`B1&5L971E('-U8B!F;VQD97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM
M<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*;7-G:60@(D1E;&EV97)Y('1I
M;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM
M<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,C`V
M"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,C$P"FUS
M9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C(Q"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(Q.0IM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDV"FUS9VED(")$97<@4&]I
M;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V,@IM<V=I
M9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`P"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C@Y
M"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.3(*;7-G:60@(D1I<W!L87D@9F]R
M96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@Q-PIM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,0IM<V=I9"`B1&ES
M<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*
M;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B
M1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T
M(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T
M:&ES(&)O>#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI
M8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E
M<'5B;&EC(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z.#4S"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$V,0IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$R-0IM<V=I9"`B1')O<"!D;W=N(&QI<W0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED
M(")$<G5G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3,*;7-G:60@(D4M36%I;"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B
M14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI
M8V@@<')O=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS
M9VED(")%8W5A9&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,S(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,"!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.CDS"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3@R('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHW,@IM<V=I9"`B161I="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO54DN<&AP.C4P"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C`T"FUS9VED(")%9&ET($=R;W5P
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D
M:70@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O
M961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O
M<'1I;VYS(&9O<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M
M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P
M97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W
M"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@
M(D5L96UE;G0N+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@X-PIM<V=I9"`B16UA:6PB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-C8@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"FUS9VED(")%;6%I;"!!
M9&1R97-S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Y.#$*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`W"FUS9VED
M(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B
M16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.0IM<V=I9"`B16UO=&EC
M;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B16UP='D@;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T
M,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%
M;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4T,`IM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G
M97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q-0IM<V=I9"`B16YA8FQE(')I
M9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C8P-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.#$Q"FUS9VED(")%;F0@>65A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA
M<F=E($5D:71O<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C$V"FUS9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H
M:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO
M=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U
M<B!P970_)SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T
M:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,@IM<V=I9"`B16YT97(@=&AE
M(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@
M(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G
M:60@(D5R:71R96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+U9I97<N<&AP.CDR(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT.`HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,V"FUS9VED(")%<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R
M9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL
M(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED
M(")%=7)O<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,S-@IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS9VED(")%=F5R>2`R(&UI;G5T
M97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S,R!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@T"FUS9VED(")%=F5R>2`S,"!S96-O
M;F1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S4@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-PIM<V=I9"`B179E<GD@-2!M:6YU
M=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S<*;7-G:60@(D5V97)Y(&AA
M;&8@:&]U<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S,T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#4*;7-G:60@(D5V97)Y(&UI
M;G5T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN
M8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W!H<'-H96QL+G!H<#HX,B!A9&UI;B]C;61S:&5L;"YP:'`Z-3$@861M
M:6XO<W%L<VAE;&PN<&AP.C$R.`IM<V=I9"`B17AE8W5T92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C8Q-`IM<V=I9"`B17AP86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]3
M44PO4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z
M,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C
M:"!T97)M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<W"FUS9VED
M(")%>'!O;F5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<V"FUS9VED
M(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(R-0IM<V=I9"`B1F%I;&5D(')E=')I
M979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E
M<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N
M<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HW,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A
M<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O
M;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-3(S(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S8W"B,L('!H
M<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ.0IM<V=I9"`B1F%I<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED
M(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C0P"FUS9VED(")&871A;"!%<G)O<CHB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-3$*;7-G:60@(D9A>&5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#,*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS
M9VED(")&96)R=6%R>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(R,@IM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(P"FUS9VED(")&965L<R!L:6ME
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED
M(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Y-C(*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S0S"FUS9VED(")&
M:6=L970@0T%05$-(02(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,S0W"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(U-PIM<V=I9"`B1FEL92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT,#D*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@IM<V=I9"`B
M1FEL92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Y.34*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.#8*;7-G:60@(D9I;&4@=7!L
M;V%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N
M<&AP.CDP,`IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY,0IM<V=I
M9"`B1FEL=&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&:6YL
M86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G
M:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A
M<G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C4W"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,@IM
M<V=I9"`B1FQI<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR,@IM<V=I9"`B1F]G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z,C@P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ
M,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X
M:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N
M)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,S8*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,@IM<V=I9"`B(@HB
M1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S
M="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB
M97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P,@IM<V=I9"`B
M1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT-C0*;7-G:60@(D9O<FUS(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@
M(D9O<G1U;F4@='EP92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4U"FUS9VED(")&
M;W)U;7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$Q,0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S,*;7-G:60@(D9R86YC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI
M=&%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(S"FUS9VED(")&<F5E>FEN9R!$<FEZ>FQE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R
M<FET;W)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS-#D*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,Y-0IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS9VED(")&=6QL($1E
M<V-R:7!T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX
M,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8U('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*;7-G:60@(D9U;&P@3F%M92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N
M97)A=&5D($-O9&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O
M<F=I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M86YY(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-@IM<V=I9"`B1VEV
M96X@3F%M92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A
M<BYP:'`Z,3<Y('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$P"B,Z('1E;7!L
M871E<R]P<F5F<R]A<'`N:6YC.C$Y"FUS9VED(")';&]B86P@3W!T:6]N<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-PIM<V=I
M9"`B1V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P
M"FUS9VED(")';V5D96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,S$*;7-G:60@(D=O;V=L92!-87!S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G
M:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S.`IM<V=I9"`B1W)A>7-C86QE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(D=R965K
M("A)4T\M.#@U.2TW*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'
M<F5E;FQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1W)E;F%D
M82(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$X-0IM<V=I9"`B
M1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,S`W"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L
M92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,C0*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R
M;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M=7!D871E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,C0Q(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$T"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,X('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3<X"FUS9VED(")'<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM
M<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I
M9"`B1W5A;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M
M86QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z.#D*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S(*;7-G:60@(D=U97-T8F]O
M:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'=6EN96$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV,`IM<V=I9"`B2%1-3"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D
M96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T
M92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE
M;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P
M"FUS9VED(")(86ET:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(T"FUS9VED(")(87IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.CDQ.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,R"FUS
M9VED(")(96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$
M;VYA;&0@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B2&5A=GD@5"U3=&]R;2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B
M2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C(R('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@T(&9R86UE=V]R
M:R](;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TUE;G4N<&AP.C$W-2!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ
M-PHC.B!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z-`IM<V=I9"`B2&5L<"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q"FUS9VED(")(96QP
M97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED
M(")(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS
M9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C<S"FUS9VED(")(:6=H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI
M;F,Z-0IM<V=I9"`B2&]?;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM
M<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U
M"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C<P"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS
M9VED(")(;VYG($MO;F<B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C8W"FUS9VED(")(;W)D92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E
M9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,CDV"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y
M<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R.#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<
M(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R
M,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@
M<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,S@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W
M(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C@R"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R
M971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(S-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H
M<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,S8X"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C,V-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R
M92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q
M"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@
M(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U
M(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M
M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA
M;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X.2!L:6(O0FQO8VLO
M;65T87(N<&AP.C(S,@IM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T.`IM<V=I9"`B2'5M:61I
M='DZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*
M;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G
M:60@(DAU;F=A<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)U<RYP:'`Z,3<R(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H
M<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T
M:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L
M+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E
M;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)U<RYP:'`Z,3<Y(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X
M('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q-@IM<V=I9"`B25`@061D<F5S<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP
M.C<W"FUS9VED("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G
M:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W,PIM<V=I9"`B
M26-O;G,@3VYL>2(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S0*;7-G:60@(DEC
M;VYS('=I=&@@=&5X="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3@U"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C8P,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E
M8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-3(*;7-G:60@(B(*(DEF
M('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO
M<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R
M;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,@IM<V=I9"`B(@HB
M268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA
M9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B
M>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B
M26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@
M55),(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L
M;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3<V,0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T
M82]D871E;6%P+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M-30@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H
M<#HQ,S0*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@
M<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C4S"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT
M97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB
M861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#$*;7-G:60@(DEN9&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3,U"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G
M:60@(DEN9F\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(U.0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q.0IM<V=I9"`B26YF;W)M871I
M;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-0IM<V=I9"`B26YH97)I=&5D
M($UE;6)E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O
M;'5M;B!!9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R
M="!);6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N
M97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R
M96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE
M=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N
M="!N;V1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R
M86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N
M871E('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,S0*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H
M:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4X"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,`HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B
M26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS
M97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@
M(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G
M:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B
M26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(R-0IM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W
M97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED
M("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R
M="]-;V1I9GD@3&EN:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I
M96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-S4*;7-G
M:60@(DEN=&5G97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3$S,PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP
M:'`Z,38W"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP
M.C$Y-`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR
M,3(*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A=&-H($E$
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`U
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-S8*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$W
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*
M;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ
M,#D*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3,Y
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(T,0IM
M<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED("));G9A;&ED(&QI
M8V5N<V4@:V5Y+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,34Y"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@
M<&%R86UE=&5R<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D8VAI
M;&0N<&AP.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q
M"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(DEN=F%L:60@
M<')O9'5C="!C;V1E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@
M<')O=&]C;VPN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C
M:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,3$W(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(Y
M-PIM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q
M"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4Y"FUS9VED("));G9E;G1O
M<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C8W.`IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B
M27-L92!O9B!-86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(V
M"FUS9VED("))<W-U97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))=&%L>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA
M;G5A<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*87!A;B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B
M2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED
M(")*=6QY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*
M;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I
M9GD@0V5N=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U
M;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V-0IM
M<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S
M"FUS9VED(")+96YY82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VMR8C4N<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T
M960@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED
M(")+97D@0W)E871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R
M"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3D*
M;7-G:60@(DME>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T
M<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!2
M97!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO
M<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y,0IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO=70B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B
M3&%N9W5A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@
M4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@X"FUS9VED("),87-T
M(%!A<W-W;W)D($-H86YG92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U
M87)T97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3,*
M;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z-S$W"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@
M;&]G:6XZ("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F
M<F]M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.C<Q-`IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),87<B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y
M"FUS9VED("),87EO=70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@
M9F]R(&YO(&)O<F1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@
M(DQE8F%N;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS9VED("),969T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3D*;7-G:60@(DQE
M9G0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,34*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-3<*;7-G:60@(DQE=F5L(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(W"FUS9VED("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),
M:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN($5A<FQY(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,P"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@
M(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!286EN
M('=I=&@@5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B3&EG:'0@4VYO=R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS-`IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$T"FUS9VED
M("),:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X,3<*;7-G:60@(DQI;FL@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X,S(*;7-G:60@(DQI;FL@86-C97-S(&ME>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#(S"FUS9VED
M("),:6YK('1A<F=E="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#(P"FUS9VED("),:6YK('1E>'0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Y,PIM<V=I9"`B3&EN:R!T:&4@
M96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA
M>6EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#(Y"FUS9VED("),:6YK('1I=&QE(&%T=')I8G5T92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z
M,3@R"FUS9VED("),:6YK<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT-@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B
M3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S0*;7-G:60@(DQI<W0@1&%T86)A<V5S
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4R"FUS
M9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-C`Q"FUS9VED
M("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12](96%D97)S+G!H<#HU.38*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C8P,PIM
M<V=I9"`B3&ES="U)9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y.0IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C8P,`IM
M<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DX"FUS9VED("),:7-T+5-U8G-C<FEB92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP
M.C4Y-PIM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S97-S:6]N<RYP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES
M=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG
M('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S97)S(&ES
M(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@Y"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6UA9V5S+G!H<#HW-PIM<V=I9"`B3&]A9&EN
M9RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C`P"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@V"FUS9VED("),;V-A;&4@86YD(%1I;64B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-S(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4W"B,Z(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C<R"FUS
M9VED("),;V-A=&EO;B(*;7-G<W1R("(B"@HC.B!L;V=I;BYP:'`Z,3@Y('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,#0@=&5M<&QA=&5S+VQO9VEN
M+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ
M-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED("),;V<@:6XB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0W
M"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.3@*;7-G:60@
M(DQO9R!O=70B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C8Q"FUS9VED("),;V=I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$P"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.34*;7-G:60@(DQO9VEN(&9A
M:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N
M=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.CDY,0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8U"FUS9VED("),
M;VYG('1E>'0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0X"FUS9VED("),;W9E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED("),;W<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0S.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,PIM<V=I9"`B
M34]41"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A
M:6YE9"!N;R!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS
M9VED(")-4T<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86-A
M;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@
M5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"FUS9VED(")-86=I8R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#,*;7-G:60@(DUA
M:6PB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R
M-`IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@
M(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED
M(")-86QA=VDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-86QA
M>7-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%L:2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;'1A(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-`IM<V=I9"`B(@HB36%N86=E('1H
M92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@
M=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T
M96=O<FEE<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q-38*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3`X-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3$W,0IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O
M<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM
M<V=I9"`B36%R9VEN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S0S,30N<&AP.C0X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E
M96X@9FQA9W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C-#,Q-"YP:'`Z-#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H
M92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I
M96QD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N
M:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D
M960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`X"FUS
M9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#`*;7-G:60@(DUA>"!T96UP(&QA<W0@
M-B!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$X,0IM<V=I
M9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(Q-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C,Y"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(DUA>6]T=&4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-
M961I8VEN92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C$V"FUS9VED(")-96UB97)S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S4*;7-G:60@(DUE;G4@;6]D93HB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-3<*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@
M5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF
M:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(V,`IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-971A
M<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V
M86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$U,PIM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C=&5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#
M+U)00R]X;6QR<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#+W-O87`N<&AP
M.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO
M="!D969I;F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E
M<W0N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F
M:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C8W(&QI8B]";&]C:R]M971A<BYP:'`Z
M.#(*;7-G:60@(DUE=')I8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G
M:60@(DUE>&EC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC
M<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*
M;7-G:60@(DUI9&1L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$R"FUS9VED(")-:6X@
M=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,#0*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M-#,Y"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E
M>'!I<F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,S4*;7-G:60@(DUI<G)O<B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O
M=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G
M92!(5%107U)E<75E<W0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ,30*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@
M66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S
M92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@
M(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@
M(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V
M"FUS9VED(")-;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-S8*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")-
M;V1E<F%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HX-0IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*
M;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S0*;7-G:60@(DUO9'5L=7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O
M9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V,#(*;7-G:60@(DUO
M;G1H(&%N9"!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N
M86YC92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H
M<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3DV(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F
M;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G
M:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B36]S=&QY($-L;W5D
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS-PIM<V=I9"`B36]S=&QY($-L;W5D>2!A;F0@5VEN9'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S@*;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T.`IM<V=I
M9"`B36]V92!$;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4R"FUS9VED(")-;W9E($QE9G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HV-38*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV
M-#0*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM<V=I9"`B36]V92!D;W=N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HU,C4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4R-@IM<V=I9"`B36]V92!U<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(P,@IM<V=I9"`B375L=&DM;&5V96P@9')O
M<"!D;W=N(&QI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,#4Y"FUS9VED(")-=6QT:6UA<"!52R!M
M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V
M,`IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#(*;7-G:60@(DUY($%C8V]U;G0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED
M(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-#0*;7-G:60@(DUY(%!O<G1A;"(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z-#(*;7-G:60@
M(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS
M9VED(")->6%N;6%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@
M06=R964B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z
M,S@*;7-G:60@(DYA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED
M(").86UI8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U
M<G4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@
M(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S
M8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!296YE
M=V%L(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.#<*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X.`IM
M<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I
M9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4S"FUS9VED(").971W;W)K(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R
M-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,R"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.#,*;7-G:60@(DYE=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-0IM<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I
M9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N
M86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED
M(").97<@6F5A;&%N9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z,S<*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF
M;W)M870*;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R
M"FUS9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ
M"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,CDQ"FUS9VED(").97=S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#<*
M;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z
M-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G:60@(DYE>'0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS9VED(").97AT(#0@4&AA<V5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,S8V(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<P"FUS9VED(").
M97AT(&]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A
M9V5R+G!H<#HQ,#8*;7-G:60@(DYE>'0^(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED
M(").:6=E<FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS-CD*;7-G:60@(DYI9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-PIM<V=I9"`B3FEU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38V"FUS9VED(").;R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G
M:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D
M:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`V"FUS9VED(").;R!A=F%I;&%B
M;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P
M,0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C,X-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C0P-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T
M960@<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E
M9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-3$*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G
M:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I
M;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,3<X(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$Q"B,Z(&9R86UE=V]R
M:R]5=&EL+U5T:6PN<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#8W"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@1E10(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HW,C<*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S<R"FUS9VED(").;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@
M5D93+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.CDQ.`IM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R("(B"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3$V(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$S,`IM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"FUS9VED
M(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@
M(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").
M;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU
M;6)E<B!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N
M<&AP.C$P,`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO075T
M:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A
M;2YP:'`Z-S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I
M;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]P87-S=V0N<&AP.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C@T"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R
M.#<*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R
M;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*
M(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I
M;F<@<VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C<U,PIM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S
M"FUS9VED(").;R!R=6QE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HT.#(*;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I
M960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C`Y"FUS9VED(").
M;R!S=6-H(&9I;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$R-@IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A
M=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,0IM<V=I9"`B3F\@=7-E
M<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,30V"FUS9VED(").;R!V86QI
M9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3<T"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HY.#0*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY-0HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`Q,@IM<V=I9"`B3F\@=F%L=65S
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,3D*;7-G
M:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO
M;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(W"FUS9VED(").;R!V97)S:6]N(&9O
M=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES
M96QE8W0N:6YC.CDU"FUS9VED(").;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO
M;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.3(*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M
M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8T,0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED(").;W0@0F5F;W)E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0R
M-`IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C,T.`IM<V=I9"`B3F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@T"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E
M9WDN<&AP.CDU"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU.0IM
M<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X"FUS9VED(").;W0@
M<V5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]3
M97-S:6]N2&%N9&QE<BYP:'`Z,30X"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N
M9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,38S"B,Z(&9R86UE=V]R:R]397-S
M:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3<X"B,Z(&9R86UE=V]R
M:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3DR"B,Z(&9R
M86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,W
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.3,*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(S.2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8U"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR.#,@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,P
M,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$V(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HS,S(*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,T-R!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,S8T"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HS.3<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0U-PHC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z-3,V(&9R86UE=V]R:R]61E,O5D93+G!H<#HV,#4*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C8R,@IM<V=I9"`B3F]T('-U<'!O<G1E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M,S0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T-`HC
M.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`V."!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3@P"FUS9VED(").;W1E<R(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@
M8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`T-@IM<V=I
M9"`B3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,C4*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-CD@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30R,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#0U('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,R!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I
M9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E
M<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N
M(&QI<W0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B
M3V)J96-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3$R"FUS9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C@*;7-G:60@(D]F
M9FEC92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I
M9F9E<F5N="XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C,V"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@<&%S
M<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M.`IM<V=I9"`B3VUA;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#(V"FUS9VED(")/;F-L:6-K(&5V96YT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS
M9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G
M:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3DX.0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO
M=V5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES
M=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI
M<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C0Q(&QI8B]";&]C:R]I9G)A;64N<&AP.C0R"FUS9VED(")/
M<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O
M<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@
M<&%R="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI
M;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34U"FUS9VED
M(")/<'1I;VYS(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS
M,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D
M($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B
M3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3,T"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA
M;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T
M96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA
M;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT
M"FUS9VED(")/=&AE<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3D@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.0HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3$V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C4*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-`IM<V=I9"`B3W1H97(@26YF
M;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS,@IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y"FUS9VED(")004T@
M875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U
M"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(X-0IM<V=I9"`B4$=0($1I
M9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$S,S$*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,S@S"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S8U"FUS9VED(")01U`@
M4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H
M<'-H96QL+G!H<#HV.0IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#`*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%)A
M:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G:60@
M(E!-(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")032!4+5-T;W)M
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@V"FUS
M9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HR,34*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*
M;7-G:60@(E!A;&%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@
M(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")0
M87)T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(P,S8*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW
M-R!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT,C4*;7-G:60@(E!A<W-W;W)D(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I
M9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,PIM<V=I
M9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E
M<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-S$*;7-G:60@(E!A<W-W
M;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED
M(")087-S=V]R9#H@(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U
M,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#4R"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T
M(&UA=&-H+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O
M;2!C;&EP8F]A<F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N
M9&EN9R!3:6=N=7!S.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-30*;7-G:60@(E!E;W!L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R
M8V5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I
M;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/
M<&5R871I;VYS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT,#,*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O
M;B!L;V=I;C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV,3(*;7-G:60@(E!E<FUI
M<W-I;VX@1&5N:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,38T"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P
M"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C4X"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@*;7-G:60@
M(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M.`IM<V=I9"`B4&5R=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY
M"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@P"FUS
M9VED(")0:&]T;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B
M4&ET8V%I<FXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@
M<V]M92!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O
M;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@
M>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4X,`IM<V=I9"`B4&QE87-E
M(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@
M(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#$*;7-G
M:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3@*;7-G:60@(E!L
M96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@
M9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(T-C4*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED
M('1I;64N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T
M:&4@<')O8FQE;2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED
M(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G
M:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U5
M4U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A
M=&5G;W)Y(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B
M4&]L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0X.0IM<V=I9"`B4&]L;',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4Q
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS
M9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!
M4"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C@@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E
M8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-PIM<V=I9"`B4')E
M8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O;&1A<"YP:'`Z,3`T"FUS9VED(")0<F5F<U]L9&%P
M.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM
M<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(R-PIM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-C$*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E
M;#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,C0*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P,PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*
M;7-G:60@(E!R979I97<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0
M<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-38@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HS-C`*;7-G:60@(E!R979I;W5S(&]P=&EO
M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED
M(")0<FEV871E($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O365N=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-PIM<V=I9"`B4')O8FQE;2!$
M97-C<FEP=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S<Q"FUS9VED(")0<F]J96-T<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(R,#8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(Y-`IM<V=I
M9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0V"FUS
M9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC
M($ME>2!);F9O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N
M;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-34*;7-G:60@(E!U
M<F=E(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@
M(E%A=&%R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV-`IM
M<V=I9"`B475E<GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C@P"FUS9VED(")1=6]T82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C@R"FUS9VED(")2861I;R!S96QE8W1I
M;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@
M16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I
M9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E)A:6X@86YD(%-N;W<B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3(*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<V
M"FUS9VED(")2871I;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q
M-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$X,0IM<V=I9"`B4F5A9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT-PHC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PIM<V=I9"`B
M4F5A9"!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY
M(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A
M=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T
M-"!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,3`*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C0X"FUS9VED(")2969R97-H(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#@*;7-G:60@(E)E9G)E
M<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S,X"FUS9VED(")2969R97-H(%!O<G1A;"!6
M:65W.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX
M.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C,U"FUS9VED(")296=E>"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C0Y"FUS9VED(")296QA=&EO
M;G-H:7`@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HQ-#0@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C$P
M"FUS9VED(")296QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS,C@*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q-PIM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS
M9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E
M*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S"FUS
M9VED(")296UO=F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L
M87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U.0IM
M<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0P"FUS9VED(")296UO=F4@
M9F]R;6%T=&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M
M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,0IM<V=I9"`B4F5M;W9E('-A=F5D
M('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C
M=6UE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T-`IM<V=I9"`B4F5Q=65S="!C
M;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-0IM
M<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$X-2!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4R,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C<S,R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@W,PHC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S<X"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&
M4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO571I
M;"]5=&EL+G!H<#HX,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@
M7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S,V
M"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SD*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(Q"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C`@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.`IM<V=I9"`B4F5S970@4&%S<W=O
M<F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,C@*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$S,0IM<V=I9"`B4F5S=&]R92!,87-T(%%U
M97)Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW,B!A9&UI
M;B]C;61S:&5L;"YP:'`Z,CD@861M:6XO<W%L<VAE;&PN<&AP.C8W"FUS9VED
M(")297-U;'1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B
M4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO
M;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS
M9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,0IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3<*;7-G
M:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O
M7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R
M-@IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(S"FUS9VED(")2;W1A=&4@
M3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C(Y"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O
M=W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O
M=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@
M=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,0IM<V=I
M9"`B4G5N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I
M86X@1F5D97)A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED
M(")2=V%N9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I
M9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z
M.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P
M-@IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,CDR"FUS9VED(")344P@<W1A
M=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT,S,*;7-G:60@(E-32"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(B(*
M"B,Z(&QI8B]A<&DN<&AP.C(Q.0IM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8Q"FUS9VED(")382(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED
M(")386EN="!(96QE;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED
M(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@W"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H
M92!'<F5N861I;F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S
M96QF*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")386UO82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0
M<FEN8VEP92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.0IM<V=I9"`B
M4V%V92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D
M:70N:6YC.C4W"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$W"B,L
M('!H<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C8*;7-G:60@
M(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R
M:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@
M(E-C:65N8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*
M;7-G:60@(E-E87)C:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S(R"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3<S"FUS9VED(")396QE
M8W0@1FEL97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0X-0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.0IM<V=I
M9"`B4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-#0*;7-G:60@(E-E;&5C="!A(&YE=R!O
M=VYE<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-PIM<V=I9"`B4V5L96-T(&$@
M=7-E<B!T;R!A9&0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C8W-@IM<V=I9"`B4V5L96-T(&%L;"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8Q"FUS9VED
M(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I
M9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"FUS9VED(")396QE8W0@
M;F]N92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*
M;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M
M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A
M<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D
M871E(&1E;&EM:71E<CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI
M;F,Z.3(*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@
M8VAA;F=E.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN
M8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E
M;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI
M;F<@9FEE;&1S+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S`S"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#0*;7-G:60@(E-E
M;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@
M4')O8FQE;2!297!O<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-#(*;7-G:60@(E-E;F0@4TU3(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3@*;7-G:60@(E-E;G-O
M<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E
M<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,@IM<V=I9"`B4V5R:6%L($YU;6)E
M<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,30Y"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*;7-G:60@
M(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N
M($E$(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C(Q,0IM
M<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,S,@IM<V=I9"`B4V5T(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW.0IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL
M;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R
M9V5T(&ET+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3$X"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N
M="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@W"FUS9VED(")3970@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#$*;7-G:60@
M(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M
M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I
M;VYS+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W
M"FUS9VED(")3971U<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I
M<'1S(&%V86EL86)L92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,3<U"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P;W-S
M:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT.3@*;7-G:60@(E-H;W!P:6YG(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS
M9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT-#,*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D
M969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4VAO=R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34T"FUS9VED("(B
M"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N
M9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.#<*;7-G:60@(E-H
M;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V-0IM<V=I9"`B4VAO
M=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$S"FUS9VED(")3:&]W('!I8VME<B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(S"FUS9VED
M(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I
M97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@
M5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS
M9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T
M:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-S8S"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B
M4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M-@IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3:&]W97)S
M(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q.0IM<V=I9"`B4VAR:6YK
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z.3$P"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z.3<R"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z,3`U.`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q,C`*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,3@S"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(R,PHC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R-3(*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C@U"FUS
M9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T
M(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM
M<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HR-C8*;7-G:60@(E-I9VX@=7`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3,*
M;7-G:60@(E-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E($%L9V]R
M:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#0@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8T(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Y,S`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R
M,PIM<V=I9"`B4VEZ92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N
M86YC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V86MI
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI82(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU.`IM<V=I9"`B4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4VYO=R!3:&]W
M97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C`*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I
M9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")3;F]W(%-H
M;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(X,`IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C@T"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@
M=V%T97(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3;VQO
M;6]N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B
M4V]M86QI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,CDR-@IM<V=I9"`B4V]R="!O<F1E<B!S96QE
M8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C$X.0IM<V=I9"`B4V]U<F-E(&%D9')E
M<W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R
M:6-A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS
M9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U
M=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T
M:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W
M965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B
M971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q-0IM<V=I9"`B4W!A8V5R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3`P"FUS9VED(")3<&%M(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#
M:&%R86-T97(@26YP=70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@
M8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM<V=I9"`B4W!O<G1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-B!L:6(O0FQO
M8VLO;65T87(N<&AP.C@Q"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C`T(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#D*;7-G:60@(E-T87)T('EE87(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-S$*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3
M=&%T=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@Q-0IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E-T<F5E
M="!!9&1R97-S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,PIM<V=I
M9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@Y,0IM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D
M9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R
M;W=S97(N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R
M>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3@*;7-G:60@(E-U
M8FUI="(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<(B5S7"(@
M=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B`B
M"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED
M(")3=6)S8W)I<'0B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$P-0HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E
M<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H92!S
M>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N
M+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU
M-PIM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@
M8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,38X"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W5D86XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV,PIM<V=I9"`B4W5N;GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(P-0IM<V=I9"`B4W5N<FES92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N
M<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#0*;7-G:60@(E-U
M;G)I<V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C`X"FUS9VED(")3=6YS970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-PIM<V=I9"`B4W5N<V5T.B`B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X,`IM<V=I9"`B4W5P<&]R="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3=7)I;F%M92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0IM
M<V=I9"`B4W5R;F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED
M(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`T"FUS9VED(")3=V5D96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G
M:60@(E-W:71Z97)L86YD(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY-PIM
M<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV-`IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5"U3=&]R
M;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W
M"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1&%T82]$871A+W1S=BYP:'`Z,3<P"FUS9VED(")44U8@9FEL92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z
M-3<*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")4
M86)L92!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3$*;7-G:60@(E1A:7=A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC
M92!O9B!#:&EN82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4
M86II:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A
M;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B
M5&%R9V5T.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDU."!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`U.0HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3@Y"FUS9VED(")487-K<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I
M9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(Y,@IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,38*;7-G:60@(E1E
M;7!E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,3(*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F
M9&5G.R5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP
M;&%T92YP:'`Z-CDU"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB
M)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$Q(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,S-#4*;7-G:60@(E1E>'0B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W,@IM<V=I9"`B5&5X="!/
M;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5&AA
M:2`H5$E3+38R,"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B
M5&AA:6QA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX-C,*;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](:7-T;W)Y+TAI<W1O
M<GDN<&AP.C4U"FUS9VED(")4:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.38T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E
M9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP:'`Z,3(Y
M.`IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE
M9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q
M"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@
M<W5C8V5S<V9U;&QY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C
M;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H
M87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C$Y,"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C(P,0HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(Q,B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C(R-`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C(S-2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(U,PHC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(V-2!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C,P-`IM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E
M9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME
M;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N
M;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@
M=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T
M('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$Q.#$*;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L
M;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI
M<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R
M(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R
M"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP:'`Z
M,3$V"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@
M<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$X-B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C4R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U
M;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z-3$R"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H
M;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@
M8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL
M;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R
M(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E
M;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N
M970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W
M97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE
M;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I
M;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U
M<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@
M>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N
M9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@
M(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@
M=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<')E9G,N<&AP.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E
M;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B
M(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G
M:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR,#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H
M('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@
M:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A
M9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#DU"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L
M:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#<T"FUS9VED(")4:&4@;G5M8F5R
M(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,@IM<V=I9"`B5&AE
M(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y
M<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+G!H<#HR.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E
M(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S
M:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O96YS
M8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS
M<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E
M8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<W)C
M:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P
M<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N
M;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#@W"FUS9VED(")4:&4@<75O=&4@8VAA
M<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@
M;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HT-SD*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE
M(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P
M8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<
M(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z-#<P"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S<&5C:69I
M960@<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C(R"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,C`*
M;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE
M('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B
M5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T1A=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@
M9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M
M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,3<V"FUS9VED(")4:&4@=7!L;V%D
M960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT.2!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,3$P"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@
M:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R
M;W=S97(N<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E
M8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N
M;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z,S0Y"FUS9VED(")4:&5R92!A<F4@
M;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P,0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R
M<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E
M<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B
M(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S
M7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@
M<WES=&5M.B`B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I
M;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3(U"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3,P"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@
M(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDS,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN
M9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,`IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#(*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A
M=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D
M(&9I96QD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@
M9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$T.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HR.3D*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N
M;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H
M:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q-#4*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B
M92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@
M(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O
M;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y
M+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*
M(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A
M=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM
M<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T
M97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A
M;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z
M+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-3<*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#(@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.3@*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#4W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y
M-S8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R,PHC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#0W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$V-R!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(T,C8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0V.`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-C4U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S-R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,S$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,X,C,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@S,0IM<V=I9"`B
M5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L9"!M87D@
M;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-#,T"FUS9VED(")4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DT"FUS9VED(")4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S"FUS9VED(")4
M:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@
M;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HY.#D*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A
M;&ED(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@S-@IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@
M82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP
M;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B
M965N('!R;V-E<W-E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VAE;'`O
M86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT.34*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P
M=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E
M9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L
M86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL
M("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R
M86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@
M(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*
M;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G
M>FEP(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O4F5G:7-T<GDN<&AP.C$X-@IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R
M<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T
M(&)E(&$@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]I;6%G97,O
M8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E
M(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED
M(")4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR,S8*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C0T,R!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-3<*;7-G:60@(E1I;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,X.`IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@
M9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(U-#D*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G
M:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H
M;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME
M>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,P,`IM<V=I9"`B5&]D87DB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S`R"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VMO;&%B+G!H<#HQ,#0*;7-G:60@(E1O;R!M
M86YY(&EN=F%L:60@;&]G:6YS(&1U<FEN9R!T:&4@;&%S="!M:6YU=&5S+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4
M;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L871I;VYS(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B
M5')U92!O<B!F86QS92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM
M.2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES
M=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N
M9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS
M9VED(")4=79A;'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN
M<&AP.C(W,PIM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3@*;7-G:60@(E4N
M5BX@:6YD97@Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W
M"FUS9VED(")54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U
M<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"FUS
M9VED(")54DPZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G
M86YD82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A:6YE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0R
M.`IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z.38*
M;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W
M:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,SDU"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,#$@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0W.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE
M("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C<Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E
M('1O("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.CDW"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F
M:6QE('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HV-2!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.CDT"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HV-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F
M(%PB)7,O)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S<6PN<&AP.C0S.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,
M('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX.#(*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-#$@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C0V"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HR,S,@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C(S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,C0V"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,S<P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-CD*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Y,PIM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(S"FUS9VED(")5;F%B;&4@
M=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C,P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.#$*;7-G:60@(E5N86)L
M92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<U"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HU,@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z.#(*;7-G:60@(E5N86)L
M92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,C,Q(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,S`R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C0T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M7"(E<UPB.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,S0W(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#4P"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,C(@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,X.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z-#`S(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HT,#<*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L
M>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,S4S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,S,*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T-B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,S4T"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS.3D*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT-S4@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT.#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C,Q.2!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,S-`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,38V(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HQ-SD*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C$X-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-#,X"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HT-#8*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,C4Q"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#8T"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX
M-#8*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O
M<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C`T"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T
M92!D971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])
M35-0+G!H<#HT,S<@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T:"YP:'`Z
M,3(S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D
M969I;FET:6]N(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR,3$@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,C$V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ.3@@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P,PIM<V=I9"`B56YA8FQE
M('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z.3,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ
M,#8*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV-S0@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HQ,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.3,@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$U-PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,38P"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F
M;W(@=W)I=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z.#8@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,30P"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HY-0IM<V=I9"`B56YA
M8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T
M;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C@T,PIM<V=I9"`B56YA8FQE('1O(')E860@
M5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C@W.`IM<V=I9"`B56YA8FQE('1O(')E
M860@5D93(&9I;&4@*'-I>F4H*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP
M:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV.3$*;7-G:60@(E5N
M86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,30V"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I
M;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0R"FUS9VED(")5;F%B
M;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S@W"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@P(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,S4P"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV,S(@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C(T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,X,2!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,C$R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HT-C,@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,S-`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4V"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*
M;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS
M9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$X,S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('1R:6=G97(@9G)E92]B
M=7-Y('5P9&%T92!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HQ-S@@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ
M.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,3@Y"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@
M*&-O<'DH*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR.3<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C$V-0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<P
M"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@U,PIM<V=I9"`B56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C(R.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HT,C<*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@
M;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R-`HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS-S@*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z-#$U"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C0R,0IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS
M92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I
M;&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS
M9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*
M;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY
M:6YG($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C8R(&QI8B]";&]C:R]M971A<BYP:'`Z-S@*;7-G:60@(E5N
M:71S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0R.2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,S`*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HU.`IM<V=I9"`B
M56YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G
M:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5
M;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#<*;7-G:60@
M(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM
M<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O261E;G1I='DN<&AP.C,P
M-`IM<V=I9"`B56YN86UE9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I
M;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R
M;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K
M($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H
M:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C
M97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N
M<V5T(&-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C@W(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z.3(W"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3,S
M"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@
M=7-E<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI
M;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@
M(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-S<@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$Y.`IM<V=I9"`B57!L;V%D(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#4*;7-G:60@(E5P;&]A9&5D(&%L
M;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-PIM<V=I9"`B57-E(&EF(&YA
M;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR
M,0IM<V=I9"`B57-E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O4F5G:7-T<GDN<&AP.C<W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,C0U"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@<VEG
M;G5P+G!H<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B
M(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I<W1R871I;VX@
M:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0Y-`IM<V=I9"`B57-E<B!A8V-O
M=6YT(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS
M-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HS-`HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C<R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R
M"FUS9VED(")5<V5R;F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E5S
M97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W"FUS9VED(")5<V5R;F%M
M93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z
M.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES
M=&5M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5>F)E:VES
M=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C$W,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-S$*;7-G:60@(E9&
M4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,C`*;7-G:60@(E9A8V%T:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V-@IM<V=I
M9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I
M9"`B5F%L:61I='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS9VED(")686QU92!I
M;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HX-38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$W
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I<R!O=F5R('1H92!M87AI
M;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(V,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C@T
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,S0@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,CDR.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O
M=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$R-R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,C`T"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,S"FUS9VED
M(")687)I86)L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")6
M96YE>G5E;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T
M:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P
M,0IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C(X"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM
M<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T
M:6-A;#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-S0*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-PIM<V=I9"`B5FEE=&YA;65S92`H5DE3
M0TE)*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HY-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W
M(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")6:65W(&%S("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G
M:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$Q"FUS9VED(")6:7-I8FEL
M:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-3(*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM
M<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M05).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VAT;6PN<&AP.C$R-R!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.34*;7-G:60@
M(E=A<FYI;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R
M($9O<F5C87-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HT,38*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3(*;7-G
M:60@(E=E871H97(N8V]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0S.0IM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU
M.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC;VUE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O
M("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP
M.C(Y('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y.`IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3D*;7-G:60@(E=E
M<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM
M<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P
M<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I
M9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H
M870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C4*;7-G:60@
M(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,V"FUS9VED(")7:&EC:"!P
M;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C4*;7-G:60@(E=I9'1H(&EN($-3
M4R!U;FET<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S4T"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU
M(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T
M:#HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q
M-0IM<V=I9"`B5VEK:2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C@Y(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8Y"FUS9VED(")7:6YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS9VED(")7:6YD($5A
M<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#<*;7-G
M:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ-3@*;7-G:60@(E=I;F0Z(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@(E=I;F0Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G
M:60@(E=I<V1O;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,3DX"FUS9VED(")7:7-H;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-`HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS
M9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ
M.3,@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,CDT"B,L('!H<"UF;W)M
M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@
M17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ
M,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE
M(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(T-0IM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@
M(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S
M($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE
M8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B6#4P.78S(%-U8FIE
M8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#,*;7-G:60@(E@U,#EV,R!E>'1E;G-I
M;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED
M(")962(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-38*;7-G:60@(EE965DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,3$*;7-G:60@
M(EEA:&]O(2!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA
M;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C8*;7-G
M:60@(EEE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;
M/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C(S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO
M=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,34*;7-G:60@(EEO
M=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R])9&5N=&ET>2YP:'`Z,S$P"FUS9VED(")9;W4@8V%N;F]T
M(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.3,*;7-G:60@(EEO=2!D:60@;F]T
M(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP
M;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@
M)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX
M-PIM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B"B)9
M;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I
M9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT
M97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@=&\@
M96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF
M:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0V-0IM<V=I
M9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED
M(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A
M;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B
M66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S
M('1O(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP
M.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E
M;&5T960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB
M"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N
M86UE('1O(&%D9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A
M=&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C
M=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U(&UU
M<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW
M,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE
M(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HY-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA
M<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9;W5R
M($5M86EL($%D9')E<W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(P-PIM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-0HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3(*;7-G:60@(EEO=7(@26YF;W)M871I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H
M87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S
M<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L
M;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-0IM<V=I9"`B(@HB
M66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@
M861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@
M861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F
M97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHU"FUS9VED("(B
M"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R
M="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D
M:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@
M<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O
M('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4W"FUS9VED
M(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS
M.C0R"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T
M:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B
M"B)T;R!P<FEN="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(U,PIM<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$Q-PIM<V=I9"`B66]U<B!D
M969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3,*;7-G:60@(EEO=7(@9&5F
M875L="!I9&5N=&ET>3HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Y-@IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY.0IM<V=I9"`B66]U<B!L
M;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N
M97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`IM<V=I9"`B66]U<B!O<'1I
M;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI
M<R!S97-S:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U
M<&1A=&5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HW-@IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX,`IM
M<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@
M>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O
M<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<S
M,PIM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9
M;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI
M9VAT<75O=&5S+G!H<#HR,#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O
M=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX.0IM<V=I9"`B6U!R
M;V)L96T@4F5P;W)T72(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E
M>'0@+2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL
M=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,C`S"B,L('!H<"UF;W)M870*;7-G
M:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,C`T"B,L('!H<"UF;W)M
M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,C(S"FUS9VED(")?0TQ)
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C(P-PIM<V=I9"`B7T1A=&%4
M<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS
M9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3DY"FUS9VED(")?1W)O=7!S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP
M.C$Y-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T"FUS
M9VED(")?3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HR,#,*
M;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@
M(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ
M.3$*;7-G:60@(E]3971U<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]4
M86)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP
M.C$Y-0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.34Q"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*
M;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.30S"FUS9VED(")C86QE;F1A<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L:6(O0FQO8VLO
M;65T87(N<&AP.C,V,`HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34X
M"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,P"FUS9VED
M(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HV,#`*;7-G:60@(F-L:6-K(&AE<F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W.`IM
M<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC
M86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M
M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET
M+FEN8SHS,`IM<V=I9"`B961I="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T(&9O
M=6YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<U"FUS9VED(")F86QL:6YG(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y-@IM<V=I9"`B9FEL92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W-B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,V,B!L:6(O0FQO8VLO;65T87(N<&AP.C,X.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,SD*
M;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U,`IM<V=I9"`B:#HB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U
M.0IM<V=I9"`B:&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8T(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.C<V"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U
M="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C
M:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE
M(&UA:VEN9R!)4T\N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HS-S`*;7-G:60@(FUM(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C@U('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S0*(SH@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C(T,PIM<V=I9"`B;F%M92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4E!#+U)00RYP:'`Z,3(T"FUS9VED(")N;W0@:6UP;&5M96YT960B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HQ,C(P"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,U"FUS9VED(")N;W1E
M<&%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S0*;7-G
M:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@
M(G!I>&5L<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C<W"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E<G9I8V4@
M=6YA=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HQ,#$*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@W"FUS9VED
M(")S<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HW-@IM<V=I9"`B<W1E861Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T
M96T@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY-3D*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R
M87)Y(&9A:6QU<F4B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B='EP
M92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-"!A9&UI;B]S971U<"]D:69F+G!H
M<#HW-@IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA;65D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED
M(")V0V%R9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C0R"FUS9VED(")W.B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC
M;VTB"FUS9W-T<B`B(@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+VAU7TA5+G!O
M````````````````````````````````````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`W,3<R-S8`,3`U,34T,S,W-30`,#$W-C<Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````",@2&]R9&4@2'5N9V%R:6%N('1R
M86YS;&%T:6]N(&9I;&4N"B,@0V]P>7)I9VAT("A#*2`R,#`R+3(P,#8@3&%S
M>FQO($PN(%1O<FYO8VD*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD
M97(@=&AE('-A;64@;&EC96YS92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*(R!,
M871E<W0@=F5R<VEO;G,Z(&9T<#HO+WAE;FEA+G-O=&4N:'4O<'5B+VQI;G5X
M+VAO<F1E+PHC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S
M:6]N.B!(;W)D92`S+C%<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`
M;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-BTP
M,BTQ-R`Q,#HP,"LP,3`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`V+3`R
M+3$W(#$P.C,X*S`Q,#!<;B(*(DQA<W0M5')A;G-L871O<CH@3&%S>FQO($PN
M(%1O<FYO8VD@/'1O<FQA<WI`>&5N:6$N<V]T92YH=3Y<;B(*(DQA;F=U86=E
M+51E86TZ($AU;F=A<FEA;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-
M24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN
M.R!C:&%R<V5T/6ES;RTX.#4Y+3)<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC
M;V1I;F<Z(#AB:71<;B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S<S"B,L
M('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H
M)7,@;F%P<&%L(&5Z96SU='0I(@H*(SH@;&EB+TAO<F1E+G!H<#HQ,S<T"B,L
M('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(@
M*$%L="UB:6QL96YT>?L@)7,I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S
M.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R
M("(@*"5S(&YA<"!M^FQV82DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W
M-PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B("AM82DB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C,W.0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B
M("AH;VQN87`I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S4*;7-G:60@
M(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(@*'1E9VYA<"DB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0U(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS-3`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y
M-@IM<V=I9"`B(&%T("(*;7-G<W1R("(@.B`B"@HC.B!L:6(O5D93+W-M8BYP
M:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D
M:7)E8W1O<GDN(@IM<V=S='(@(EPB)7-<(B!N96T@86QK]FYY=G3A<BXB"@HC
M.B!L:6(O2&]R9&4O0TQ)+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B7"(E<UPB
M(&YE;2#I<G;I;GEE<R!VX6QA<WITX7,N(@H*(SH@;&EB+TAO<F1E+U)E9VES
M=')Y+G!H<#HW,3`@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#DX"B,L('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T
M:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(EPB)7-<(B!N:6YC<R!K;VYF
M:6=U<N%L=F$@82!(;W)D92!296=I<W1R>6)E;BXB"@HC.B!L:6(O2&]R9&4O
M5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E
M(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B7"(E<UPB(&9A<W1R=6MT
M^G)A+6UE9VIE;&5N[73U(&YE;2!T86SA;&AA=/,N(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D
M9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(M="!H
M;WIZX6%D='5K(&$@8W-O<&]R=&]K:&]Z+B(*"B,Z(&%D;6EN+W!E<FUS+V%D
M9&-H:6QD+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S
M(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(EPB
M)7-<(BUT(&AO>GKA861T=6L@82!J;V=O<W5L='/A9VD@<F5N9'-Z97)H97HN
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL
M9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@
M8W)E871E9#H@)7,N(@IM<V=S='(@(EPB)7-<(BUT(&YE;2!H;WIT=6L@;.ET
M<F4Z("5S+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H
M)2XR9B4E*2(*;7-G<W1R("(E+C)F34(@9F5L:&%S>F[A;'0@82`E+C)F34(@
M;65G96YG961E='1B]6P@*"4N,F8E)2DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C(V"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N
M9"`E<R(*;7-G<W1R("(E9"`E<R#I<R`E<R(*"B,Z(&QI8B](;W)D92]!=71H
M+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L('!H
M<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E
M>'!I<F5S+B(*;7-G<W1R("(E9"!N87`@;?IL=F$@;&5JX7(@:F5L<WIA=N%N
M86L@Z7)VZ6YY97-SZ6=E+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T
M(@IM<V=S='(@(B5D(&YA<&]S(&5L]7)E:F5L>NES(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@
M3F]T:6-E(@IM<V=S='(@(B5S("T@1FEG>65L;65Z=&5TZ7,B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(E<R!L96YY;VUA="(*"B,Z(&QI
M8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#$@;&EB+TAO<F1E+TU)344O
M0V]N=&5N=',N<&AP.C@T,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M
M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R!K87)B86YT87)TX7-I(&9E;&%D
M871O:R`M(&UE9V5R]7/M=.ES(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B5S(&)EX6QL[73A<R(*"B,Z(&QI
M8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8T"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B)7,@;&]G:6X@;NEV(&EGZ6YY;.ES
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(E<R!S
M>F]L9^%L=&%TX7-I(&9E;'3I=&5L96LB"@HC.B!L:6(O5D93+W-M8BYP:'`Z
M-#,R(&QI8B]61E,O<VUB+G!H<#HT.30@;&EB+U9&4R]F='`N<&AP.C8X,@HC
M.B!L:6(O5D93+V9T<"YP:'`Z-S4P"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R(")!(%PB)7-<(B!N97;[(.%L;&]M
MX6YY(&WA<B!LZ71E>FEK+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38V
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C0V"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S4R(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM
M<V=S='(@(B5S(#H@)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@
M<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E
M;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO
M=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(B"B)!
M*'HI("5S(&OI<WIE;B#A;&P@87H@86SA8F)I(&MA<F)A;G1A<G3A<VD@9F5L
M861A=&]K(&5L=NEG>NESZ7)E+DIE;/9L:F4@:VD@(@HB87IO:V%T(&$@9F5L
M861A=&\H:V$I="P@86UI*&ME*70@;6]S="!E;"!K[7;A;B!VZ6=E>FYI+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S0T"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B5S(&MI=/9L=.ES92!S>OQK
M<^EG97,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(B5S('!E<F,B"@HC.B!L
M:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@;F5M('1A;.%L
M:&%T\RXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B5S
M("T@)7,@*/9S<WIE<V5N("5S*2(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M.3(V"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM
M<V=S='(@(B5S(&/M;6IE9WEZZ6ME(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HY,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G
M<W1R("(E<R!N87!TX7)A(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B5S
M(&9E;&IE9WEZZ7-E:2(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3,T"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B)7,@
M9F5L861A=&QI<W3A:F$B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]H=&UL
M+G!H<#HQ,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S
M<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E
M=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R
M;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T
M:6]N+B(*;7-G<W1R("(B"B(E<SH@3&5H971SZ6=E<RP@:&]G>2!E>B!A(&QE
M=NEL('9A;/-JX6)A;B!N96T@82!M96=A9&]T="!F96QA9/-T\VP@(@HB<WKA
M<FUA>FEK+B!';VYD;VQJ82!M96<L(&UI96SU='0@<N%K871T:6YT('9A;&%M
M:7)E+"!V86=Y('-Z96WI;'EE<R`B"B)I;F9O<FWA8VGS="!A9"!M96<N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U-"!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,SDY"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S
M='(@(BP@<WKI;&SV:^ES96LB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Y
M-2!L:6(O0FQO8VLO;65T87(N<&AP.C(P,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B+"`E<R`E<RUS('-ZZ6QL]FOI
M<V5K(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(BP@
M=N%L=&]Z\R`E<R#I<R`E<R!K]GKV='0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C`W,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$S,B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C(Y-`HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,T."!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0X"FUS9VED("(M
M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@=N%L87-S>F]N("TM(@H*(SH@;&EB
M+T)L;V-K+W1I;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G
M<W1R("(Q,B#S<N%S(&9O<FWA='5M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP
M.C$Y"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R("(R-"#S<N%S(&9O
M<FWA='5M(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@
M(C(T(&AO=7)S(@IM<V=S='(@(C(T(/-R82(*"B,Z(&QI8B](;W)D92]522]0
M86=E<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(\16SU>O4B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R-@IM<V=I9"`B02!D871A8F%S
M92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R
M(")%>F5N(&)L;VMK(&AA<WINX6QA=.%H;WH@96=Y(&%D871BX7II<R!A;')E
M;F1S>F5R('-Z_&MSZ6=E<RXB"@HC.B!L:6(O2&]R9&4N<&AP.C$V,@IM<V=I
M9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B2&5L>7)E
M:&]Z:&%T871L86X@:&EB82!T]G)TZ6YT(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")!(&QE=NEL('1I
M=&MO<^UTX7/A:&]Z(&5G>2!N>6EL=N%N;W,@4$=0(&MU;&-S('-Z_&MSZ6=E
M<RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,38X"FUS9VED(")!
M('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE
M9"!M97-S86=E+B(*;7-G<W1R("(B"B)!(&1I9VETX6QI<V%N(&%LX>UR="!L
M97;I;"!E;&QE;O5R>NESZ6AE>B!E9WD@;GEI;';A;F]S(%!'4"!K=6QC<R!S
M>OQK<^EG97,N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`Y.0IM
M<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE
M<W-A9V4N(@IM<V=S='(@(B(*(D$@=&ET:V]S[71O='0@;&5VZ6P@9&5K\V1O
M;.%SX6AO>B!E9WD@;GEI;';A;F]S(%!'4"!K=6QC<RP@96=Y('1I=&MO<R!0
M1U`@(@HB:W5L8W,@Z7,@96=Y(&IE;&UO;F1A="!S>OQK<^EG97,N(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`Q-@IM<V=I9"`B(@HB02!P=6)L
M:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*
M(D$@;&5VZ6P@9&EG:73A;&ES(&%LX>URX7/A:&]Z(&5G>2!N>6EL=N%N;W,@
M4$=0(&MU;&-S+"!E9WD@=&ET:V]S(%!'4"!K=6QC<R`B"B+I<R!E9WD@:F5L
M;6]N9&%T('-Z_&MSZ6=E<RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4P-@IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T
M92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*(D$@=&ET:V]S[71O
M='0@;&5VZ6P@9&5K\V1O;.%SX6AO>B!E9WD@;GEI;';A;F]S(%,O34E-12!K
M=6QC<RP@96=Y('1I=&MO<R!3+R(*(DU)344@:W5L8W,@Z7,@96=Y(&IE;&UO
M;F1A="!S>OQK<^EG97,N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@
M4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I
M9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"B)!(&QE=NEL(&1I9VETX6QI
M<R!A;.'M<N%SX6AO>B!E9WD@;GEI;';A;F]S(%,O34E-12!K=6QC<RP@96=Y
M('1I=&MO<R!3+TU)344@(@HB:W5L8W,@Z7,@96=Y(&IE;&UO;F1A="!S>OQK
M<^EG97,N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G
M:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92XB"FUS9W-T<B`B02!L97;I;"!T:71K;W/M=.%SX6AO>B!E
M9WD@;GEI;';A;F]S(%,O34E-12!K=6QC<R!S>OQK<^EG97,N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@
M0VQO=61S(@IM<V=S='(@(D3I;&5L]71T(&)O<G5L="#I9R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,
M:6=H="!286EN(@IM<V=S='(@(D3I;&5L]71T(&=Y96YG92!E<_4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B
M04T@4F%I;B(*;7-G<W1R(")$Z6QE;/5T="!E<_4B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R
M<R(*;7-G<W1R(")$Z6QE;/5T=&D@>N%P;W)O:R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H
M;W=E<G,B"FUS9W-T<B`B1.EL96SU='0@:/-ZX7!O<F]K(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(F1E
M+V1U(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*
M;7-G:60@(D%022!)1"(*;7-G<W1R(")!4$D@240@*&$@<')O9W)A;6]ZX7-I
M(&9E;/QL970@87IO;F]S[73S:F$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET
M;W(B"FUS9W-T<B`B17)R]6P@87H@961I=&]R<O-L(@H*(SH@<V5R=FEC97,O
M:&5L<"]I;F1E>"YP:'`Z-3,*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(D[I
M=FIE9WDN+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B86)S>B!A;'5L
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(F%B<WH@:_9ZZ7`B"@HC.B!L
M:6(O5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3FEN8W,@:F]G;W-U;'1S
MX6=A(&$@5D93(&%L:_9N>79TX7(@;.ET<F5H;WKA<^%H;WHN(@H*(SH@;&EB
M+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T
M:6YG(%9&4R!F:6QE+B(*;7-G<W1R(").:6YC<R!J;V=O<W5L='/A9V$@82!6
M1E,@9N%J;"!LZ71R96AO>N%SX6AO>BXB"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z,PIM<V=I9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")"
M96IE;&5N=&ME>NES:2!I;F9O<FWA8VGS(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<X"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(DIE
M;'-Z\R(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS
M"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B02!J;V=O<W5L='/A
M9R!F96P@=F%N(&;\9V=E<WIT=F4N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,S-0IM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R(")0Z6YZ_&=Y
M96LB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T."!T96UP;&%T97,O
M<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A
M9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R(")"979I=&5L(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*
M;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R(")!;&-S;W!O<G0@;.ET
M<F5H;WKA<V$B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.CDX(&QI8B](
M;W)D92]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S
M:6]N(@IM<V=S='(@(DIO9V]S=6QT<^%G:2!A;&-S;W!O<G0@;.ET<F5H;WKA
M<V$B"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D
M($AE<F4Z(@IM<V=S='(@(D%D9&IU:R!H;WIZX2!I='0Z(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G:60@(D%D
M9"!.97<@1W)O=7`B"FUS9W-T<B`BVFH@8W-O<&]R="!LZ71R96AO>N%S82(*
M"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z.#<@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@
M(MIJ(&IO9V]S=6QT<^%G(&SI=')E:&]ZX7-A(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B06QC<V]P
M;W)T(&AO>GKA863A<V$@7"(E<UPB+6AE>B(*"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD
M('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(DIO9V]S=6QT<^%G:2!A
M;&-S;W!O<G0@:&]Z>N%A9.%S82!<(B5S7"(M:&5Z(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R("+::B!F
M96QH87-Z;N%L\R!LZ71R96AO>N%S83HB"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-34V"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S
M='(@(MIJ(&]S>FQO<"!H;WIZX6%DX7-A(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM
M<V=S='(@(MIJ('1A9V]K(&9E;';I=&5L92(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(MIJ('#A
M<B!H;WIZX6%DX7-A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII
M;&QA(%-I9&5B87(B"FUS9W-T<B`B02AZ*2`E<R!M96[\="!A9&IU:R!H;WIZ
MX2!A($UO>FEL;&$@;65N_'-O<FAO>B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ
M(@IM<V=S='(@(D%D:G5K(&AO>GKA(&$@8^UM:F5G>7KI:VAE>CHB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"FUS9VED(")!9&0@
M=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(D%D:G5K(&AO>GKA(&$@8^UM
M:F5G>7KI:V5M:&5Z(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D
M9"!U<V5R(@IM<V=S='(@(MIJ(&9E;&AA<WINX6SS(&AO>GKA863A<V$B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!
M9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@
M861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R
M("(B"B)<(B5S7"(@9F5L:&%S>F[A;/-T(&AO>GKA861T=6L@82!R96YD<WIE
M<FAE>BP@9&4@;F5M('-I:V5R_&QT(&$@=/9B8FD@(@HB8F5J96QE;G1K97KI
M<VD@861A="!TX7)O;.%S83H@)7,N(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@
M66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R(")<(B5S7"(@9F5L:&%S>F[A
M;/-T(&9E;'9E='3I:R!A(')E;F1S>F5R8F4N($UO<W0@;>%R(&)E:F5L96YT
M:V5Z:&5T+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR
M"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(D$@
M<F5N9'-Z97)H97H@;F5M(&%D:&%T\VL@:&]Z>N$@^FH@9F5L:&%S>F[A;/-K
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#0U(&QI8B](;W)D92]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3<S"FUS9VED(")!9&1R97-S(@IM<V=S='(@(D/M;2(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-#$*;7-G:60@(D%D9')E
M<W,@0F]O:R(*;7-G<W1R(")#[6UJ96=Y>NEK(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S0S,30N<&AP.C4V(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N
M<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B061M:6YI<WIT<N%C:?,@+2!J
M;V=O<W5L='/A9V]K(&%DX7-A('1O=N%B8FD@9F5L:&%S>F[A;/-K;F%K(@H*
M(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN
M:7-Z='+A8VGS(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,PIM
M<V=I9"`B061S(@IM<V=S='(@(DAI<F1E=.ES96LB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!9F=H86YI
M<W1A;B(*;7-G<W1R(")!9F=A;FES>G3A;B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS
M9W-T<B`B06QBX6YI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B06QGZ7)I
M82(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS
M9VED(")!;&EA<R(*;7-G<W1R(")!;&EA<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N
M(@IM<V=S='(@(D5L:&5L>65ZZ7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S
M='(@(E)E;F1E>NES.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM
M<V=I9"`B06QL(@IM<V=S='(@(F%Z(/9S<WIE<V5T(@H*(SH@;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV
M-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B36EN
M9&5N(&YE;2!V96YDZ6<@9F5L:&%S>F[A;/,B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O=7!S
M(@IM<V=S='(@(DUI;F1E;B!C<V]P;W)T(@H*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HY,2!L:6(O2&]R9&4O4&5R;7,O9&%T871R964N<&AP.C<U"FUS
M9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B36EN9&5N(&IO9V]S=6QT
M<^%G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B36EN
M9"!A(&[I9WD@;VQD86QO;B!L96=Y96X@:V5R970B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3@W-0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S
M(@IM<V=S='(@(D5N9V5D:OQN:R!M96<@=/9B8B!C[6UE="!I<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S@*;7-G:60@(D%L;&]W('-E='1I;F<@
M;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(D$@<V]R<WKA;6]S(&9E
M;'-O<F]LX7,@=.UP=7-A(';A;'1O>G1A=&AA=/,@;&5G>65N/R(*"B,Z(&QI
M8B](;W)D92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E
M>&ES=',B"FUS9W-T<B`B3>%R(&SI=&5Z:6LB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3(V"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G
M<W1R("))35-0(&)E:F5L96YT:V5ZZ7-I('!A<F%MZ71E<F5K(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4Q,0IM<V=I9"`B06QT97)N871E($E-4U`@
M4&%S<W=O<F0B"FUS9W-T<B`B3>%S:6LL($E-4U`@:F5L<WKS(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4P,PIM<V=I9"`B06QT97)N871E($E-4U`@
M57-E<FYA;64B"FUS9W-T<B`B3>%S:6LL($E-4U`@8F5J96QE;G1K97KI<VD@
M;NEV(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*;7-G:60@
M(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(DWA<VEK(&5M86EL
M(&/M;2(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E
M<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(D%L=&5R;F%T[78@<V%B;&]N;VLB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R(")!
M;'1E<FYA=.UV('-Z]G9E9SHB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G
M<W1R(")!;65R:6MA:2!3>F%M;V$B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN
M<&AP.CDU(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I
M;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(D$@;65G861O
M='0@Z7)TZ6L@;F5M(&9O9V%D:&%T\R!E;"XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,34U"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA
M<R!O8V-U<F5D+B(*;7-G<W1R("))<VUE<F5T;&5N(&AI8F$@=/9R=.EN="XB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U
M"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(D%N9&]R<F$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O
M;&$B"FUS9W-T<B`B06YG;VQA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B
M06YG=6EL;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G
M:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R(")!;F]N:6T@<')O>'EN(&ME
M<F5S>G3\;&D@:6YT97)N970@96SI<NES(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R(")6X6QA<WHB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X
M"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(D%N=&%R:W1I<WHB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V"FUS9VED
M(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(D%N=&EG=6$@Z7,@0F%R
M8G5D82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE
M;&PN<&AP.C,U(&QI8B](;W)D92]";&]C:R]522YP:'`Z-3@*(SH@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I
M;VXB"FUS9W-T<B`B06QK86QM87KA<R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R(")!;&MA
M;&UA>N%S;VL@;&ES=.%J82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R(")!>B!A
M;&MA;&UA>N%S(&OI<WHN(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R(")!
M(&OV>O9S('3A<G1E<OQL970@86QC<V]P;W)T:F%I<F$@:7,@Z7)VZ6YY97,B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I
M9"`B07!P<F]V92(*;7-G<W1R(")*\W;A:&%G>>%S(@H*(SH@;&EB+TAO<F1E
M+TU)344O0V]N=&5N=',N<&AP.C@T,0IM<V=I9"`B07!P<F]X:6UA=&4@4VEZ
M92(*;7-G<W1R(")+]G+\;&)E;/QL:2!MZ7)E="(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#4@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R("+A<')I
M;&ES(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D%R86)I
M8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R(")A<F%B("A7:6YD;W=S+3$R-38I
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-S@*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM
M<V=S='(@(D$@=/9M]G+M=&5T="#A;&QO;>%N>2!MZ7)E=&4B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU."!L:6(O2&]R9&4O34E-12]6
M:65W97(O>FEP+G!H<#HV-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z
M+G!H<#HW-PIM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(D$@=/9M]G+M
M=&5T="#A;&QO;>%N>2!N979E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S
M="!F;W(@)7,@/R(*;7-G<W1R(")":7IT;W,@8F5N;F4L(&AO9WD@=/9R]FQN
M:2!K[7;A;FIA("5S(&)E:F5L96YT:V5ZZ7-I(&EGZ6YYZ70_(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S
M7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R(")":7IT;W,L(&AO9WD@
M=/9R]FQN:2!A:V%R:F$@7"(E<UPB+70@86QC<V]P;W)T:F%I=F%L(&5G>?QT
M=#\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C8@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B07)G96YT[6YA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I
M9"`B07)M96YI82(*;7-G<W1R("+6<FWI;GEO<G-ZX6<B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB
M"FUS9W-T<B`B]G)MZ6YY("A!4DU30TE)+3@I(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B3?MVZ7-Z970B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS
M9VED(")!<G5B82(*;7-G<W1R(")!<G5B82(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R(")0
M;VAN<&5I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!
M<V-I:2!!<G0B"FUS9W-T<B`B07-C:6D@<F%J>F]K(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB
M"FUS9W-T<B`BP7IS:6$O0W-E;F1E<RWS8V7A;FD@<NEG:?,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#(Y"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA
M=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS
M9W-T<B`B(@HB2^ER:F5N(&$@<F5N9'-Z97(@;65G97+U<^UTZ7-T(&$@:V%R
M8F%N=&%R=.%S:2!F96QA9&%T;VL@96QVZ6=ZZ7-E(&5L]71T/R(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HS,#DY"FUS9VED(")!<W-I9VYM96YT(&-O;'5M
M;G,B"FUS9W-T<B`B2&]Z>N%R96YD96SI<VD@;W-Z;&]P;VLB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B3F5M;.ET97KU(&-S;W!O<G1O
M="!K[7/I<F5L="!M96<@=/9R]FQN:2XB"@HC.B!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES
M=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(").96ULZ71E>O4@:F]G;W-U;'1S
MX6=O="!K[7/I<F5L="!M96<@=/9R]FQN:2XB"@HC.B!A9&UI;B]P97)M<R]E
M9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(DYE;6SI=&5Z]2!J;V=O<W5L='/A
M9V]T(&OM<^ER96QT(&UE9R!M96=VX6QT;WIT871N:2XB"@HC.B!S97)V:6-E
M<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A
M(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B3F5M;.ET97KU(&OV>O9S
M('3A<G1E<OQL971E="!K[7/I<F5L="!M96<@;65G=N%L=&]Z=&%T;FDN(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#,*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B5'5L
M86ID;VYSX6=O:R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#D@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R
M"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B875G=7-Z='5S(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S
M=')A;&EA(@IM<V=S='(@(D%U<WIT<N%L:6$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM
M<V=S='(@(D%U<WIT<FEA(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H
M<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER<W%L.B!A('-Z_&MS
MZ6=E<R!I;6%P(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RXB"@HC.B!L:6(O2&]R
M9&4O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"86-K
M96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM<V=S
M='(@(B(*(D%U=&A?8WER=7,Z(&$@:.%T=.ER<WIO;&?A;'1A=.%S(&YE;2!R
M96YD96QK97II:R!A(&OM=N%N="!KZ7!E<W/I9V5K:V5L+B(*"B,Z(&QI8B](
M;W)D92]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E
M<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T
M:%]C>7)U<SH@82!S>OQK<^EG97,@:6UA<"!B]7;M=.ES(&YE;2!T86SA;&AA
M=/,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB
M075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#
M;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*
M;7-G<W1R("(B"B)!=71H7V9T<#H@82!S>OQK<^EG97,@9G1P(&+U=NUTZ7,@
M;F5M('1A;.%L:&%T\RX@1F]R9.UT<V$@;&4@82!02%`M="!A>B`M+2(*(F5N
M86)L92UF='`@;W!C:?-V86PN(@H*(SH@;&EB+TAO<F1E+T%U=&@O:6UA<"YP
M:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM87`Z(&$@<WK\:W/I9V5S
M(&EM87`@8O5V[73I<R!N96T@=&%LX6QH873S+B(*"B,Z(&QI8B](;W)D92]!
M=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR
M8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]K<F(U.B!A
M('-Z_&MSZ6=E<R!K<F(U(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RXB"@HC.B!L
M:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@
M061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E
M8W1O<GDB"FUS9W-T<B`B075T:%]L9&%P.B!N96T@:&]Z:&%T\VL@;.ET<F4@
M^FH@9F5L:&%S>F[A;/-K($%C=&EV92!$:7)E8W1O<GD@97-E=.EN(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z
M(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$
M:7)E8W1O<GDB"FUS9W-T<B`B075T:%]L9&%P.B!F96QH87-Z;N%L\VL@;F5M
M('3V<O9L:&5T]6L@06-T:79E($1I<F5C=&]R>2!E<V5TZ6XB"@HC.B!L:6(O
M2&]R9&4O075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U
M:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?
M;&1A<#H@82!S>OQK<^EG97,@3$1!4"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B075T:%]L
M9&%P.B`E<R!F96QH87-Z;N%L\R!H;WIZX6%DX7-A(&YE;2!S:6ME<OQL="X@
M02!S>F5R=F5R(';A;&%S>F$Z("(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N
M<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L
M92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z("5S(&9E
M;&AA<WINX6SS('3V<FSI<V4@;F5M('-I:V5R_&QT(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?
M;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(D%U=&A?
M;&1A<#H@)7,@9F5L:&%S>F[A;/,@861A=&%I;F%K(&UE9_IJ[73A<V$@;F5M
M('-I:V5R_&QT(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#`U"FUS
M9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T
M960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(D%U=&A?;&1A<#H@
M82!F96QH87-Z;N%L\VL@;F5M(&WS9&]S[71H873S:R!!8W1I=F4@1&ER96-T
M;W)Y(&5S973I;B(*"B,Z(&QI8B](;W)D92]!=71H+VUC86PN<&AP.C0V"FUS
M9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B075T:%]M8V%L.B!A('-Z_&MSZ6=E<R!-0T%,(&+U
M=NUTZ7,@;F5M('1A;.%L:&%T\RXB"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N
M<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]S;6)A=71H.B!A
M('-Z_&MSZ6=E<R!S;6)A=71H(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RXB"@HC
M.B!L:6(O2&]R9&4O24U!4"]!9&UI;BYP:'`Z,3`V"FUS9VED(")!=71H96YT
M:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N(@IM<V=S='(@(DYE;2!S
M:6ME<OQL="!A>B!)34%0('-Z97)V97)E;B!V86SS(&9E;&AA<WINX6SS87IO
M;F]S[73A<RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(D$@
M9F5L:&%S>F[A;/-A>F]N;W/M=.%S(&YE;2!S:6ME<OQL="XB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T
M:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R(")!(&9E;&AA<WINX6SS
M87IO;F]S[73A<R!N96T@<VEK97+\;'0N("5S(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C
M=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@(D$@9F5L:&%S>F[A;/,@
M87IO;F]S[73A<^%T(&$@4D%$2553('-Z97)V97(@96QU=&%S[71O='1A+B(*
M"B,Z(&QI8B]61E,O9G1P+G!H<#HX.#(*;7-G:60@(D%U=&AE;G1I8V%T:6]N
M('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(").96T@<VEK97+\;'0@
M87H@1E10('-Z97)V97)H97H@=F%L\R!F96QH87-Z;N%L\V%Z;VYO<^UTX7,N
M(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C<P"FUS9VED(")!=71H96YT:6-A=&EO
M;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM<V=S='(@(DYE;2!S:6ME
M<OQL="!A>B!334(@<WIE<G9E<F5N('9A;/,@9F5L:&%S>F[A;/-A>F]N;W/M
M=.%S+B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@
M(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(D$@<F5N9&5L:V5ZZ7-R92#A
M;&SS(&UE>O5K.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B07IE<F)A
M:F1Z<^%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"
M3T9(($5X8W5S97,B"FUS9W-T<B`B02!G;VYO<WH@<F5N9'-Z97)G87ID82!M
M96YT<^EG96DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(DCA
M='3I<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B2.%T=.ER
M('-Z[6XB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B
M0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R(").96T@;65G9F5L96SU
M(&ME<F)E<F]S(&IE;'-Z\RXB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H
M<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R(").
M96T@;65G9F5L96SU(&ME<F)E<F]S(&9E;&AA<WINX6SS;NEV+B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HT-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@
M(D)A:&%M87,B"FUS9W-T<B`B0F%H86WA:R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HS."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)A:')A:6XB"FUS
M9W-T<B`B0F%H<F5I;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS
M9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R(")B86QT:2`H25-/
M+3@X-3DM,3,I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R(")"86YG;&%D
M97,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8P"FUS9VED(")"87)B861O<R(*;7-G<W1R(")"87)B861O<R(*"B,Z('5T
M:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"
M87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R(")!(&=R869I:W5S(.%L;&]MX6YY;VL@7"(E<UPB(&%L:_9N>79TX7)A
M(&YE;2!T86SA;&AA=/,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<S"FUS9VED(")"87-E;&EN92(*;7-G<W1R
M(")A;&%P=F]N86QO;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B1F5HZ7)O
M<F]S>F]R<WKA9R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B0F5L9VEU;2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*
M;7-G:60@(D)E;&EZ92(*;7-G<W1R(")"96QI>F4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,S
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"96YI;B(*
M;7-G<W1R(")"96YI;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B0F5R;75D
M82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R(")":'5TX6XB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB
M"FUS9W-T<B`B4WK\;&5TZ7-N87`B"@HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L
M;&5C=&EO;BYP:'`Z,S8P"B,L('!H<"UF;W)M870*;7-G:60@(D)L;V-K(%PB
M)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!(%PB)7-<(B!B;&]K:R!A(%PB)7-<(B!P<F]G<F%M;6%L(&YE;2!T86SA
M;&AA=/,N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDP"FUS
M9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R(")+Z7!E<FYY]7+I<WH@8F7A
M;&SM=.%S(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS
M9VED(")";&]C:R!4>7!E(@IM<V=S='(@(DOI<&5R;GGU<NES>B!T[7!U<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM
M<V=I9"`B0F]L9"(*;7-G<W1R(")FZ6QK]G;I<B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HT,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B
M"FUS9W-T<B`B0F]L[79I82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,#<*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R(")+961V96YC('=E8F/M
M;65K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(DME<F5T(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I
M9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B2V5R971V87-T86=SX6<Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")+97)E=&5K(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,R(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HS-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I
M9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R(")";W-Z;FEA+4AE
M<F-E9V]V:6YA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED
M(")";W1H(@IM<V=S='(@(DUI;F1K971T]2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HT."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM
M<V=S='(@(D)O='-W86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T;VTB"FUS9W-T<B`B
M86QU;"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B0F]U=F5T+7-Z
M:6=E="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C(*;7-G:60@(D)R87II;"(*;7-G<W1R(")"<F%Z[6QI82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C0Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED
M(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B0G)I
M="!);F1I86DM\V-EX6YI(%1E<OQL970B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<G5N96D@1&%R=7-S
M86QA;2(*;7-G<W1R(")"<G5N96D@1&%R=7-S86QA;2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HS-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A
M<FEA(@IM<V=S='(@(D)U;&?A<FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES="(*
M;7-G<W1R(")&96QS;W)O;.%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S
M='(@(D)U<FMI;F$@1F%S;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS
M.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B0G5R
M=6YD:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#8*;7-G:60@
M(D--4R(*;7-G<W1R(")796)O;&1A;"!K87)B86YT87)TX7,B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S
M='(@(D-20R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DX"FUS
M9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R(")!('1A;OIS
M[71VX6YY=FES<WIA=F]NX7-I(&QI<W3A:R`H0U),*2!C[6UE:2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")#96QL82!T
M=6QA:F1O;G/A9V]K(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$U,0IM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS
M9W-T<B`B02!C86-H92!I;FEC:6%L:7KA;.%S82!N96T@9F5J97KU9/9T="!B
M92XB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@U
M(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#0P"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ-3<*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(DYA<'3A
M<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G:60@
M(D-A;&TB"FUS9W-T<B`B3GEU9V]D="(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G
M<W1R(")+86UB;V1Z<V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8W"FUS9VED(")#86UE<F]O;B(*;7-G<W1R(")+86UE
M<G5N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@
M(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(DYE;2!S:6ME<OQL="!A
M(&IE;'-Z\W0@X73A;&SM=&%N:2P@9F]R9'5L:F]N(&$@<F5N9'-Z97)G87ID
MX6AO>BXB"@HC.B!L:6(O1FEL92]#4U8N<&AP.C,U,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@
M(D$H>BD@7"(E<UPB(.%L;&]MX6YY(&YE;2#M<FAA=/,N(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R
M;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@(D$@:_QL<_4@9F5L:&%S
M>F[A;/-K87!C<V]L870M:V5Z96SU:R!N96T@861M:6YI<WIT<N%L:&%T\VLN
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C(S-2!L:6(O2&]R9&4O
M075T:"]C>7)S<6PN<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG
M="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R(")!(&OV=F5T
M:V5Z]2!)34%0('-Z97)V97(@;F5M(.ER:&5T]2!E;#H@)7,B"@HC.B!L:6(O
M1FEL92]#4U8N<&AP.C0T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O
M<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")!*'HI(%PB)7-<(B#A;&QO;>%N
M>2!N96T@;GEI=&AA=/,@;65G+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HU,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G<W1R(")+
M86YA9&$B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z
M,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV
M-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R
M(")-Z6=S92(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y
M"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B3>EG<V4@
M:_QL9/9K(&AI8F%J96QE;G3I<W0B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S(S
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(D$H>BD@7"(E<UPB(.%L;&]MX6YY(&YE;2!T]G+V;&AE
M=/4N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z-#8*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O
M<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(DYE;2!T86SA;&AA=/,@87H@:61E
M:6=L96YE<R#A;&QO;>%N>6]K870@=&%R=&%L;6%Z\R!A;&OV;GEV=.%R+B(*
M"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R
M;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R
M(")!("=T87)G971&:6QE)R!P87)A;>ET97(@;65G863A<V$@;NEL:_QL(&YE
M;2!F;VQY=&%T:&%T:G5K+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS,3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E
M<UPB+B(*;7-G<W1R(")!*'HI(%PB)7-<(B!A;&OV;GEV=.%R(&YE;2!T]G+V
M;&AE=/4N(@H*(SH@;&EB+TAO<F1E+T1A=&%4<F5E+G!H<#HQ,C@@;&EB+TAO
M<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R(").
M96T@=/9R]FQH973U+"`E9"!A;&-S;W!O<G1J82!V86XN(@H*(SH@;&EB+TAO
M<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O
M<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@
M9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@HB
M07H@^FH@<V]R8F%R96YD97KI<R!N96T@;&5H971SZ6=E<RP@82!M96=A9&]T
M="!A9&%T;VL@<WKA;6$@;F5M(&5G>65Z:6L@82`B"B)TX7)O;'1A:^EV86PN
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G
M:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N
M(@IM<V=S='(@(D$@;65G861O='0@<WKA;7)A(&YE;2!K_&QD:&5T]2!E;"!A
M>B#\>F5N970N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R("):]FQD+69O
M:VDM<WII9V5T96LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(T"FUS9VED(")#87!T:6]N(@IM<V=S='(@(L%B
M<F%S>O9V96<B"@HC.B!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.C$P
M-`IM<V=I9"`B0V%R<FEE<B(*;7-G<W1R(")3>F]L9^%L=&%T\R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY,PIM<V=I9"`B0V%T96=O<FEE<R!A;F0@
M3&%B96QS(@IM<V=S='(@(DMA=&5G\W)IX6L@Z7,@:F5L]FSI<_QK(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G
M:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(DMA:FWA;BUS>FEG971E:R(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED
M(")#96QL(%!H;VYE(@IM<V=S='(@(DUO8FEL('1E;&5F;VXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"FUS
M9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B0V5L;&%T=6QA:F1O;G/A
M9V]K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B0V5L;&$@8F5L
M<_4@;6%R9_,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S
M='(@(D-E;&QA='5L86ID;VYSX6=O:R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z
M(@IM<V=S='(@(D-E;&SA:R!K]GKV='1I('+I<SHB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3(W.`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(DUO8FEL
M('1E;&5F;VXB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B
M0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B:V5L=&$@*$E33RTX.#4Y
M+3$T*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R(")K]GKI<"(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C4*;7-G
M:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R(")+]GKI<"UA
M9G)I:V%I($OV>G3A<G-A<^%G(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#(*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S
M='(@(FME;&5T+65U<O-P86D@*$E33RTX.#4Y+3(I(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(D-E<G1I9FEC871E($1E=&%I
M;',B"FUS9W-T<B`B02!T86[Z<^UT=N%N>2!RZ7-Z;&5T96DB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8Q,@IM<V=I9"`B0V5R=&EF:6-A=&4@
M3W=N97(B"FUS9W-T<B`B02!T86[Z<^UT=N%N>2!T=6QA:F1O;F]S82(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#97)T:69I
M8V%T92!0;VQI8VEE<R(*;7-G<W1R(")486[Z<^UT=N%N>2!F96QH87-Z;N%L
MX7-I(&ERX6YY96QV96LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS9W-T<B`B0W/A9"(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.38*;7-G:60@(D-H86YG92(*;7-G<W1R(")6
MX6QT;WIT873A<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS
M,0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B02!J96QS
M>O,@X73A;&SM=.%S82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.0IM
M<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O
M<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E
M;6%I;',N(@IM<V=S='(@(D%Z(-9N(.%L=&%L(&5L:_QL9/9T="!L979E;&5K
M96X@<WIE<F5P;/4@;NEV(.ES(&/M;2!M96=VX6QT;WIT873A<V$N(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N
M9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@
M8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(N(@IM<V=S='(@(B(*(D$@:F5L96X@:V]N9FEG=7+A8VGS8F%N
M(&YE;2!L96AE='/I9V5S(&$@:F5L<WIA=F%K(&WS9&]S[73A<V$N($9O<F1U
M;&IO;B!A("(*(G)E;F1S>F5R9V%Z9.%H;WHN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA
M<B(*;7-G<W1R(")+87)A:W1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI
M;FLN+BXB"FUS9W-T<B`B3&EN7VME;&QE;O5R>NES+BXN(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C4Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HU,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI
M;&4B"FUS9W-T<B`B0VAI;&4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EN82(*;7-G<W1R(")+[6YA
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-H:6YE<V4@
M4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R(")K[6YA:2P@96=Y<WIE<OMS
M[71E='0@*$=",C,Q,BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM
M<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B:^UN
M86DL(&AA9WEO;>%N>6]S("A":6<U*2(*"B,Z('1E;7!L871E<R]P<F5F<R]A
M<'`N:6YC.C<*;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB"FUS9W-T<B`B
M5N%L87-S>F]N(&MI(&5G>2!A;&MA;&UA>N%S=#HB"@HC.B!L:6(O2&]R9&4O
M075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B
M"FUS9W-T<B`B5N%L87-S>F]N(&IE;'-Z\W0B"@HC.B!L:6(O2&]R9&4O075T
M:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS
M9W-T<B`B5N%L87-S>F]N(&5G>2!F96QH87-Z;N%L\VYE=F5T(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,P,@IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D
M:7-P;&%Y(&1A=&5S.B(*;7-G<W1R(")6X6QA<W-Z82!K:2!A(&3A='5M;VL@
M;65G:F5L96[M=.ES:2!F;W)MX6KA=#HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O
M<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T
M<B`B5N%L87-S>F$@:VD@82!F96QS;W)O;.%S('3M<'5SX70@*'-ZX6UO>F]T
M="!L:7-TX6MNX6PI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R
M(")+87+A8W-O;GDM<WII9V5T96LB"@HC.B!L:6(O5D93+G!H<#HY,30@;&EB
M+TYE="]335,N<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D
M969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B02AZ*2`E<R!C
M;&%S<R!D969I;NUC:?-J82!N96T@=&%LX6QH873S+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*
M;7-G<W1R(")$97+\;'0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM
M<V=S='(@(E3V<FQI(&%Z($U33V9F:6-E('1A9V5K970B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3(X"FUS9VED(")#;&5A<B!1=65R>2(*;7-G<W1R(")!
M(&QE:^ER9&5ZZ7,@=/9R;.ES92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U
M<V5R.B`E<R(*;7-G<W1R("(E<R!F96QH87-Z;N%L\R!T]G)LZ7-E(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A
M<B!U<V5R(@IM<V=S='(@(D$@9F5L:&%S>F[A;/,@=/9R;.ES92(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U
M<V5R(&1A=&$B"FUS9W-T<B`B02!F96QH87-Z;N%L\R!A9&%T86EN86L@=/9R
M;.ES92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$U"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(D5S=.ER92!D97+\
M;'0@Z6<B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N
M:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B02!F
M;VQY=&%TX7-H;WH@:V%T=&EN='-O;B!A>B!E9^ER<F5L(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E
M;&P@=FEA($A45%`B"FUS9W-T<B`B0VQI8VMA=&5L;"!S>F]L9^%L=&%TX7,@
M2%144"UN(&ME<F5S>G3\;"(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ
M-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@
M5VEN9&]W(@IM<V=S='(@(D%Z(&%B;&%K(&)E>N%RX7-A(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-3$*;7-G:60@(D-L;W5D<R(*;7-G<W1R(")";W)U
M;'0@Z6<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(E)E9V=E;"!F96QH
M]7,@:63U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R(")&96QH]7,@:63U(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4R(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HU-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I
M9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B2_-K=7-Z+7-Z
M:6=E=&5K(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM
M<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R(")4_&YT97-S_&L@96P@
M87H@;VQD86QS\R!M96[\="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D
M97)S(@IM<V=S='(@(M9S<WIE>N%R="!K97)E=&5K(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C8R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU
M-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB
M:6$B"FUS9W-T<B`B2V]L=6UB:6$B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP
M.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B
M"FUS9W-T<B`B4WKM;B(*"B,Z(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N
M+G!H<#HS,S$@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,S,@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`S('-E<G9I
M8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I
M8VME<B(*;7-G<W1R(")3>NUN=N%L87-Z=/,B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C@S,@IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R(")3
M>NUN=N%L87-Z=.%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(D]S>FQO<&]K
M.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.34P"FUS9VED(")#;VQU;6X@
M=&ET;&5S(@IM<V=S='(@(D%Z(&]S>FQO<&]K(&/M;65I(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(V-@IM<V=I9"`B0V]M:6-S(@IM<V=S='(@
M(E9I8V-E:R(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-0IM<V=I9"`B0V]M
M;6%N9"(*;7-G<W1R(")087)A;F-S(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP
M.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(E!A<F%N8W/I<G1E
M;&UE>O4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@
M(D-O;6UE;G0B"FUS9W-T<B`B365G:F5G>7KI<R(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-38W"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R
M(").Z78L(&5L;F5V97KI<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(D-O
M;6]R92US>FEG971E:R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(D/I9R(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S
M='(@(E-ZX6WM=/-GZ7!E:R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.#8*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R("))9/5JX7+A<VD@
M:&5L>7IE="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4V"FUS9VED(")#
M;VYD:71I;VYS(@IM<V=S='(@(DED]6KA<N%S:2!H96QY>F5T(@H*(SH@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF
M9F5R96YC97,B"FUS9W-T<B`B2_QL]FYB<^EG96L@82!K;VYF:6=U<N%C:?-B
M86XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED(")#;VYF
M:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@
M86YD($]U=&QO;VLN(@IM<V=S='(@(B(*(DOI>FES>N%M[73S9^EP96MK96PL
M(&]K;W-T96QE9F]N;VMK86PL($]U=&QO;VMK86P@=F%L\R!A9&%T<WII;FMR
M;VYI>N%LX7,@(@HB:V]N9FEG=7+A8VGS:F$B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3,U"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D
M871E+B(*;7-G<W1R(")!(&MO;F9I9W5RX6-I\R!MX7(@;F5M(.ER=NEN>65S
M+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(B5S(&MO;F9I9W5RX6-I
M\VIA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0IM
M<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R(")!(&IE;'-Z\R!M96=E
M<O5S[73I<V4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-34@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R(")+;VYG\R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HU,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@
M(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T
M<B`B2V]N9_-I($1E;6]K<F%T:6MU<R!+]GITX7)S87/A9R(*"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,P.`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960N
M(@IM<V=S='(@(E-I:V5R=&5L96X@82!K87!C<V]L870N(@H*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-R!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S`X"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@
M(@IM<V=S='(@(E-I:V5R=&5L96X@82!K87!C<V]L870Z("(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U
M<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")!(&YY:6QV
MX6YO<R!K=6QC<V]K('-Z97)V97)E(&5L=71A<^UT:F$@82!K87!C<V]L871O
M="XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B02!N>6EL=N%N
M;W,@:W5L8W-O:R!S>F5R=F5R92!E;'5T87/M=&IA(&$@:V%P8W-O;&%T;W0N
M($]K83H@)7,@*"5S*2(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX-S8*;7-G:60@
M(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(E-I
M:V5R=&5L96X@87H@1E10('-Z97)V97)R96P@=F%L\R!K87!C<V]L870N(@H*
M(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-C<*;7-G:60@(D-O;G1A8W1S
M(@IM<V=S='(@(E!A<G1N97)E:R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U
M;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")!('!A
M<G1N97)E:V5T('-I:V5R97-E;B!H;WIZX6%D='5K(&$@8^UM:F5G>7KI:^EH
M97HN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-C`*;7-G
M:60@(D-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z("(*;7-G<W1R
M(")!('3V;?9R[71E='0@X6QL;VWA;GD@=.UP=7-A.B`B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O<F%R+G!H<#HU-B!L:6(O2&]R9&4O34E-12]6:65W
M97(O>FEP+G!H<#HV,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H
M<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B
M"FUS9W-T<B`B7"(E<UPB('1A<G1A;&UA(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S
M"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(")&;VQY=&%TX7,B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C8Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#
M;V]K($ES;&%N9',B"FUS9W-T<B`B0V]O:RUS>FEG971E:R(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(E/\
M=&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B3>%S;VQJ=6L@X70B
M"@HC.B!L:6(O5D93+W-M8BYP:'`Z-#<R"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R(")!(&WA<V]LX7,@;F5M('-I:V5R
M_&QT.B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(D$@:VEJ
M96SV;'0@<NES>B!MX7-O;.%S82(*"B,Z(&QI8B].970O4TU3+W=I;E]H='1P
M+G!H<#HQ-S`@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B
M0V]S="!)1"(*;7-G<W1R(")3>N%M;.%ZX7-I(&%Z;VYO<^UT\R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@
M(D-O<W1A(%)I8V$B"FUS9W-T<B`B0V]S=&$@4FEC82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HU-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@
M9"=)=F]I<F4B"FUS9W-T<B`B16QE9N%N=&-S;VYT<&%R="(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!E
M;F-R>7!T(&UE<W-A9V4Z("(*;7-G<W1R(").96T@<VEK97+\;'0@4$=0+79E
M;"!T:71K;W/M=&%N:2!A(&QE=F5L970Z("(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C$P-34*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S
M86=E.B`B"FUS9W-T<B`B02!L979E;&5T(&YE;2!S:6ME<OQL="!01U`@86SA
M[7+A<W-A;"!E;&SA=&YI.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A
M9V4N(@IM<V=S='(@(D$@;&5V96QE="!N96T@<VEK97+\;'0@87H@4R]-24U%
M('-Z86)VX6YY('-Z97)I;G0@=&ET:V]S[71A;FDN(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@
M<VEG;B!M97-S86=E+B(*;7-G<W1R(")!(&QE=F5L970@;F5M('-I:V5R_&QT
M(%,O34E-12!A;.'M<N%S<V%L(&5L;.%T;FDN(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@(D$@<&%R=&YE<B!A
M9&%T86ET(&YE;2!S:6ME<OQL="!E;'3A<F]L;FDN("5S(@H*(SH@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.CDV(&QI8B](;W)D92]!=71H+VQD87`N<&AP
M.C$R,0HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#4W"FUS9VED(")#;W5L
M9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B07H@3$1!4"!S
M>F5R=F5R(&YE;2#I<FAE=/4@96PN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C$U-B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@
M8F%L86YC92X@)7,B"FUS9W-T<B`B3F5M('-I:V5R_&QT(&5L;&5N]7)I>FYI
M(&$@<WKA;6SA:N%N(')E;F1E;&ME>NES<F4@X6QL\R#V<W-Z96=E="X@)7,B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q"FUS9VED(")#;W5L9"!N
M;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3F5M('-I:V5R
M_&QT(&%Z($Q$05`@<WIE<G9E<FAE>B!K87!C<V]L\V1N:2XB"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S
M(@IM<V=S='(@(DYE;2!S:6ME<OQL="!A*'HI(%PB)7-<(B!S>F5R=F5R<F5L
M($944"!K87!C<V]L871O="!F96QV96YN:3H@)7,B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S
M='(@(DYE;2!S:6ME<OQL="!LZ71R96AO>FYI(&$@:_9R;&5VZ6QL:7-TX70N
M("5S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$R.`IM<V=I9"`B
M0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z("(*;7-G<W1R(")!>B!A9&%T
M;VL@4$=0('1I=&MO<^UTX7-B\VP@=/9R=.EN]2!D96OS9&]LX7-A(&YE;2!S
M:6ME<OQL=#H@(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU,C,*
M;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R
M(")!>B!A9&%T;VL@4R]-24U%('1I=&MO<^UTX7-B\VP@=/9R=.EN]2!D96OS
M9&]LX7-A(&YE;2!S:6ME<OQL="XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,C0V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B02!P87)T;F5R('3V<FSI
M<V4@;F5M('-I:V5R_&QT+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B02!K]G)L
M97;I;&QI<W1A('3V<FSI<V4@;F5M('-I:V5R_&QT+B`E<R(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*
M;7-G<W1R(").96T@<VEK97+\;'0@=/9R]FQN:2!A*'HI(%PB)7-<(B!S971U
M<"!U<&=R861E('!R;V=R86UO="XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C,X,2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@
M(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A
M9&1R97-S+B(*;7-G<W1R(").96T@<VEK97+\;'0@;65GX6QL87#M=&%N:2!A
M(&/M;7IE='0@96UA:6P@8^UMZ70N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L
M971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B3F5M('-I:V5R_&QT(&)E;VQV
M87-N:2!A('1E;&IE<R!C[6UJ96=Y>NEK970N(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H
M(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").96T@<VEK
M97+\;'0@8F5O;'9A<VYI(&$@=&5L:F5S(&OV<FQE=NEL;&ES=.%T+B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O
M=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I
M;VX@;&ES=',N(@IM<V=S='(@(DYE;2!S:6ME<OQL="!B96]L=F%S;FD@82!K
M]G)L97;I;&QI<W3A:R!T96QJ97,@9F5L<V]R;VSA<^%T+B(*"B,Z(&QI8B]6
M1E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@;&EB
M+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<
M(BXB"FUS9W-T<B`B02AZ*2!<(B5S7"(@<W1R873I9VEA(&YE;2!T86SA;&AA
M=/,N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z,3$P"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713
M=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(D$H>BD@7"(E<UPB(&%L
M:_9N>79TX7(@;F5M(&AO>FAA=/,@;.ET<F4N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI
M8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R(")!(&YY:6QVX6YO
M<R!K=6QC<V]T(&YE;2!S:6ME<OQL="!M96=S>F5R97IN:2!A(&MU;&-S<WIE
M<G9E<G+U;"XB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R(").96T@<VEK
M97+\;'0@7"(E<UPB+70@[7+A<VD@8^EL;&%L(&UE9VYY:71N:2XB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&QI8B].970O4TU3+W=I;E]H
M='1P+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@)7,N(@IM<V=S='(@(DYE;2!S:6ME<OQL="`E<RUT(&UE9VYY:71N:2XB
M"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C0R,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO
M9'5L92`E<R(*;7-G<W1R(")!("5S(&MA<F)A;G1A<G3A<VD@;6]D=6P@;F5M
M(&YY:71H873S(&UE9R(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(D$H>BD@
M7"(E<UPB(&%L:_9N>79TX7(@;F5M(&YY:71H873S(&UE9RXB"@HC.B!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,3$Q(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HQ-#0*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C(S-R!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HU,38@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!L
M:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-C4V(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HV.3D*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S
M97)V97(N(@IM<V=S='(@(D%Z($Q$05`@<WIE<G9E<B!N96T@Z7)H973U(&5L
M+B(*"B,Z(&QI8B]61E,O3V)J96-T+G!H<#HR-#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(B5S(&YE;2!O;'9A
M<VAA=/,N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G
M:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R
M97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@
M87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G
M<W1R("(B"B).96T@<VEK97+\;'0@82!K[7;A;G0@9F5L:&%S>F[A;/,@:F5L
M<WIA=N%T(.%TX6QL[71A;FDN($%Z(&UE9V%D;W1T(&%D871O:R`B"B)N96T@
M=F%G>2!N96T@=&5L:F5S96X@9F5L96QN96L@;65G+B!0<O-BX6QJ82#Z:G)A
M+"!V86=Y(&AA('1O=N%B8FD@(@HB<V5G[71SZ6=R92!V86X@<WK\:W/I9V4L
M(&9O<F1U;&IO;B!A(')E;F1S>F5R9V%Z9.%H;WHN(@H*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P-R!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S,X"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS-S4@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,0HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@W"FUS9VED(")#
M;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(DYE;2!S:6ME<OQL="!M
M96=H873A<F]Z;FD@87H@96SI<NES:2!J;V=O<W5L='/A9V]K870@*$%#3"DB
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O
M;VLN("5S(@IM<V=S='(@(DYE;2!S:6ME<OQL="!B96]L=F%S;FD@82!C[6UJ
M96=Y>NEK970N("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYE;2!S:6ME<OQL
M="!B96]L=F%S;FD@82!K]G)L97;I;&QI<W3A="X@)7,B"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S
M(@IM<V=S='(@(DYE;2!S:6ME<OQL="!B96]L=F%S;FD@82!K]G)L97;I;&QI
M<W3A:V%T+B`E<R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HQ.3<@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q-PHC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(Q"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@
M(DYE;2!S:6ME<OQL="!M96=H873A<F]Z;FD@82!S>F5R=F5R(&OI<&5S<^EG
M96ET(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U
M;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").96T@<VEK
M97+\;'0@=FES<WIAX6QL[71A;FD@97H@97)E9&5T:2!K;VYF:6=U<N%C:?-T
M+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I
M<B!<(B5S7"(N(@IM<V=S='(@(D$H>BD@7"(E<UPB(&%L:_9N>79TX7(@;F5M
M('3V<O9L:&5T]2XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R(").96T@<VEK97+\;'0@96QM96YT96YI("5S(&MO
M;F9I9W5RX6-I\W0N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@<V%V
M92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(DYE;2!S:6ME<OQL
M="!E;&UE;G1E;FD@82!B86-K=7`@:V]N9FEG=7+A8VGS="XB"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R
M(").96T@<VEK97+\;'0@96QM96YT96YI(&$@8F%C:W5P(&MO;F9I9W5RX6-I
M\W0Z("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B3F5M('-I:V5R_&QT(&5L;65N
M=&5N:2!A*'HI(%PB)7-<(B!S971U<"!U<&=R861E('!R;V=R86UO="XB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F
M:6QE("5S+B(*;7-G<W1R(").96T@<VEK97+\;'0@96QM96YT96YI(&$H>BD@
M)7,@8F%C:W5P(&MO;F9I9W5RX6-I\W0N(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@
M<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE
M<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@
M8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O
M("5S+B(*;7-G<W1R("(B"B)!*'HI("5S(&MO;F9I9W5RX6-I\W,@X6QL;VWA
M;GET(&YE;2!S:6ME<OQL="!E;&UE;G1E;FDN(%9A9WD@:&%S>F[A;&IA(&$@
M)7,@(@HB;VQD86QO;B!L97;U(&QE:&5T]7/I9V5K970L('9A9WD@;>%S;VQJ
M82#A="!A>B!A;.%B8FD@:_-D;W0@:61E.B`E<RXB"@HC.B!L:6(O2&]R9&4O
M075T:"]L9&%P+G!H<#HQ-#,*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE
M($Q$05`@<V5R=F5R+B(*;7-G<W1R(")!>B!,1$%0('-Z97)V97)E;B!N96T@
M<VEK97+\;'0@96QVZ6=E>FYI(&$@:V5R97/I<W0N(@H*(SH@;&EB+U9&4R])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S
M='(@(EPB)7-<(B!N96T@=F]L="!T]G+V;&AE=/4N(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(D$@<&%R
M=&YE<B!A9&%T86ET(&YE;2!S:6ME<OQL="!M\V1O<^UT86YI+B`E<R(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,B"FUS9W-T<B`B3F5M('-I:V5R_&QT(&$@:_9R;&5VZ6QL:7-T82!M
M\V1O<^UTX7-A+B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A
M=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R(").96T@<VEK97+\;'0@96QM
M96YT96YI(%PB)7-<(B!K;VYF:6=U<N%C:?-JX70Z("5S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,W,`IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@
M36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E
M;BXB"FUS9W-T<B`B02!-;WII;&QA(&UE;OQS;W(@;F5M('1A;.%L:&%T\RX@
M16QL96[U<FEZ>F4L(&AO9WD@;65G('9A;BUE(&YY:71V82XB"@HC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO
M=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R
M("(B"B).96T@<VEK97+\;'0@7"(E<UPB(&9E;&AA<WINX6SS;F%K(&IO9V]S
M=6QT<^%G;W0@861N:2!A*'HI(%PB)7-<(B!M87!PX6AO>CH@)2(*(G,B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R,PIM<V=I9"`B0V]U;G1E9"!T97AT
M(@IM<V=S='(@(DMO<FSA=&]S('-Z]G9E9R(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3<P"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(D]R<WKA
M9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S4*;7-G:60@(D-O
M=7)S97,B"FUS9W-T<B`B5.%V;VMT873A<R(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B
M0W)E871E(@IM<V=S='(@(DSI=')E:&]ZX7,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R
M96%T92!A(&QI;FLB"FUS9W-T<B`B3&EN:R!LZ71R96AO>N%S82(*"B,Z('1E
M;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R
M96%T92!A(&YE=R!O;F4B"FUS9W-T<B`BVFH@;.ET<F5H;WKA<V$B"@HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3(@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E
M<G,B"FUS9W-T<B`B06QM87!PX6L@;.ET<F5H;WKA<V$B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N
M<R(*;7-G<W1R(")!>B!O8FIE:W1U;2!LZ71R96AO>O-JX6YA:R!J;V=O<W5L
M='/A9V%I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R,38*;7-G:60@(D-R
M961I="!C87)D(&YU;6)E<B(*;7-G<W1R(")(:71E;&OA<G1Y87-ZX6TB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HV-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM
M<V=I9"`B0W)O871I82(*;7-G<W1R(")(;W)VX71O<G-ZX6<B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C8U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#
M=6)A(@IM<V=S='(@(DMU8F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*
M;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B2F5L96YL96=I(#0@
M9N%Z:7,B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*;7-G:60@(D-U<G)E
M;G0@4V5S<VEO;G,B"FUS9W-T<B`B02!J96QE;FQE9VD@9F5L:&%S>F[A;/-K
M87!C<V]L871O:R(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C
M:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(E!O
M;G1O<R!I9/4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S
M='(@(D$@:F5L96YL96=I(%523"(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS
M-0IM<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R(")*96QE;FQE9VD@9F5L
M:&%S>F[A;/-K(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B
M0W5R<F5N="!796%T:&5R(@IM<V=S='(@(DIE;&5N;&5G:2!I9/5JX7+A<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C0*;7-G:60@(D-U
M<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B02!J96QE;FQE9VD@:63U:N%R
MX7-I(&AE;'EZ970Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R(")*
M96QE;FQE9VD@<W3M;'5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N
M('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(B(*(DUI;'EE;B!P87)A;F-S
M;VL@9G5S<V%N86L@;&4@875T;VUA=&EK=7-A;B!A("5S8F4@=/9R=.EN]2!B
M96IE;&5N=&ME>NES:V]R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@
M(DMI=N%GX7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(D$@:VEJ
M96SV;'0@<NES>B!K:7;A9^%S82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HV-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R(")#
M:7!R=7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B0WER
M:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B8VER:6QL("A+3TDX+5(I(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(D-Y<FEL;&EC("A7:6YD
M;W=S+3$R-3$I(@IM<V=S='(@(F-I<FEL;"`H5VEN9&]W<RTQ,C4Q*2(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")#>7)I;&QI8R]5:W)A
M:6YI86X@*$M/23@M52DB"FUS9W-T<B`B8VER:6QL+75K<N%N("A+3TDX+54I
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HV-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`B0W-E:"!+]GITX7)S
M87/A9R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-3(@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@
M(D1$(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S8*;7-G:60@(B(*(D13
M3B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N
M9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@HB1%-.("AA
M9&%T9F]R<N%S;&7M<O,@+2!LX7-D.B!H='1P.B\O<&5A<BYP:'`N;F5T+VUA
M;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+B(*(F1B+FEN=')O+61S;BYP:'`I
M(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I
M;'DB"FUS9W-T<B`B;F%P;VYT82(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV
M-0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R(")$871A5')E92!B
M]FYGZ7-Z]2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C<T"FUS9VED(")$
M871A8F%S92!,;V]K=7`B"FUS9W-T<B`B061A=&+A>FES8F%N('9A;/,@:V5R
M97/I<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#`R(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R"FUS9VED(")$871E(@IM<V=S='(@
M(D3A='5M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z
M,3,*;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B02!B9>ER:V5ZZ7,@
M;F%P:F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y,PIM<V=I9"`B1&%T
M92!S96QE8W1I;VXB"FUS9W-T<B`B1.%T=6T@:VEVX6QA<WITX7-A(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,2!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S$Q"FUS9VED(")$87DB"FUS9W-T<B`B;F%P<&%L
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,V"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R(")/<WIL
M;W`@=/9R;.ES92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,3,@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U
M,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V
M"FUS9VED(")$96-E;6)E<B(*;7-G<W1R(")D96-E;6)E<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*
M;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R(")S>N%M;VLB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED
M(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B0F5K97IDZ7,@:VEJ:F5B8B(*
M"B,Z(&QI8B]P<F5F<RYP:'`Z,3$W(&QI8B](;W)D92]0<F5F<R]522YP:'`Z
M,3@W"FUS9VED(")$969A=6QT(@IM<V=S='(@(D%L87#I<G1E;&UE>F5T="(*
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W
M"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(D%Z(&%L87#I<G1E;&UE
M>NES('-Z97)I;G1I('-Z[6XB"@HC.B!L:6(O2&]R9&4O261E;G1I='DN<&AP
M.CDV"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@(D%L87#I<G1E
M;&UE>NES('-Z97)I;G1I(&%Z;VYO<^UT\R(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HV-PIM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R(")!;&%P
MZ7)T96QM97IE='0@<VAE;&PB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(D1E9FEN[6-I\VLB"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&QI8B](;W)D92]097)M<RYP:'`Z,S(V
M(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(R"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z-#,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,"!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.CDS"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3@R('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHW,PHC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`B
M5/9R;.ES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,R"FUS9VED(")$96QE=&4@0V5L;"(*;7-G<W1R(")!
M(&-E;&QA('3V<FSI<V4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI
M;B]G<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@
M(D$@8W-O<&]R="!T]G)LZ7-E(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C0Y"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@(D$@;F%P;//A
M;&QO;>%N>2!T]G)LZ7-E(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HW
M-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E
M<FUI<W-I;VXB"FUS9W-T<B`B02!J;V=O<W5L='/A9R!T]G)LZ7-E(@H*(SH@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED(")$96QE
M=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(DQE=F5L96L@=/9R;.ES
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(D$@8V5L;&$@
M=/9R;.ES92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B
M07H@;W-Z;&]P('3V<FSI<V4B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T
M.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*
M;7-G<W1R(")4]G+V;&K\:R!K:2!A(&UE9VSI=O4@86QT97)N873M=B!S86)L
M;VYT(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4T"FUS
M9VED(")$96QE=&4@;65S<V%G97,B"FUS9W-T<B`B02!L979E;&5K('3V<FSI
M<V4B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G
M<W1R(")<(B5S7"(@:F]G;W-U;'1SX6=A:6YA:R!T]G)LZ7-E(@H*(SH@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R
M;6ES<VEO;G,_(@IM<V=S='(@(E3V<O9L:OQK(%PB)7-<(B!J;V=O<W5L='/A
M9V%I="#I<R!E;FYE:R!E<V5T;&5G97,@86QC<V]P;W)T:F%I=#\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W
M"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(D$@<V]R('3V<FSI<V4B"@HC
M.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED
M(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B02!K:7;A;&%S
M>G1O='0@87IO;F]S[73S('3V<FSI<V4B"@HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C-#,Q-"YP:'`Z-3,*;7-G:60@(D1E;&5T92!S=6(@9F]L9&5R<R(*
M;7-G<W1R(")!>B!A;&UA<'#A:R!T]G)LZ7-E(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED(")$
M96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(D$@:F5L96YL96=I
M(&]S>FQO<"!T]G)LZ7-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U
M<G)E;G0@<F]W(@IM<V=S='(@(D$@:F5L96YL96=I('-O<B!T]G)LZ7-E(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM
M<V=S='(@(E3V<O9L=/QK(&$H>BD@7"(E<UPB('-E='5P('5P9W)A9&4@<')O
M9W)A;6]T+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-C,@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,2!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(U,PIM<V=I9"`B1&5L:79E<GD@=&EM92(*
M;7-G<W1R(")!(&OI>F)E<^UTZ7,@:61E:F4B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM87)K(@IM
M<V=S='(@(D3A;FEA(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(D%D
M:F]N(&QE[7+A<W0@82!P<F]B;.EMX7+S;"(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HY-#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B3&7M<N%S
M(@H*(SH@;&EB+TAO<F1E+G!H<#HQ.3<*;7-G:60@(D1E=&%I;',@*&%L<V\@
M:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B4NES>FQE=&5K("AA($AO
M<F1E(&QO9V;A:FQB86X@:7,@;65G=&%LX6QH873S*3HB"@HC.B!L:6(O2&]R
M9&4N<&AP.C(P,0IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O
M<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B02!RZ7-Z;&5T96L@82!R
M96YD<WIE<F=A>F1A('-ZX6WA<F$@:^ES>OQL]2!N87!L\V;A:FQB82!K97+\
M;'1E:RXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(Q"FUS9VED
M(")$979E;&]P;65N="(*;7-G<W1R(")&96IL97-Z=.ES(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,C0*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R(")(
M87)M871P;VYT(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#$*;7-G:60@
M(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B2&%R;6%T<&]N
M="!J96QE;FQE9SH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Q-@IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B2&%R;6%T<&]N=#H@
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B8F%L
M<O-L(&IO8F)R82#M<N%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE
M9G0B"FUS9W-T<B`B:F]B8G+S;"!B86QR82#M<N%S(@H*(SH@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R(")#[6UT
MX7(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<P"FUS9VED(")$:7-P
M;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(D%Z(&ED]7!O;G1O:V%T(#(T
M(/-RX7,@9F]R;>%T=6UB86X@:F5L96[M='/\:R!M96<_(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$P,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM
M<V=S='(@(DUE9VIE;&5N[73I<VD@8F7A;&SM=.%S;VLB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.#D*;7-G:60@(D1I<W!L87D@9&5T86EL
M960@9F]R96-A<W0B"FUS9W-T<B`B02!RZ7-Z;&5T97,@96SU<F5J96QZZ7,@
M;65G:F5L96[M=.ES92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.3(*;7-G
M:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B16SU<F5J96QZ
MZ7,@;65G:F5L96[M=.ES92`H<F5P_&SU=.ER:2DB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C@P,PIM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B
M365G:F5L96[M=.ES:2!F;W)MX71U;2(*"B,Z(&QI8B](;W)D92]-24U%+TU$
M3BYP:'`Z,3DQ"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS
M9W-T<B`BR7)T97/M=.ES(&$@:^EZ8F5S[71E='0@;&5VZ6P@<V]R<^%R\VPB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C8Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y
M"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R(")$>G-I8G5T:2(*"B,Z(&QI8B](
M;W)D92]097)M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N;W0@9&5L971E(@IM
M<V=S='(@(DYE('3V<O9L:OQK(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA
M;F-E+G!H<"(*;7-G<W1R(")!(&UA:6YT96YA;F-E+G!H<"!N96T@Z7)H973U
M(&5L(&OV>G9E=&QE;OQL+B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N
M:6YC.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$
M;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF
M('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(D%Z(&5L<_4@<V]R(&$@
M;65Z]6L@;F5V96ET('1A<G1A;&UA>GIA/R!(82!I9V5N+"!J96SV;&IE(&MI
M(&5Z=#HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R(")$;VUI;FEK82(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G
M:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R(")$;VUI;FEK86D@2_9Z
M=.%R<V%SX6<B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS
M9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@
M(DYI;F-S(&WI9R!L;V=I;B!N979E/R!)9^EN>65L:F5N(&5G>65T+B(*"B,Z
M(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-3(*;7-G:60@(D1O=VYL
M;V%D(@IM<V=S='(@(DQE=/9L=.ES(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N
M=&5N=',N<&AP.C@U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E
M<R(*;7-G<W1R(")4]FQT<_QK(&QE("5S+70B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG
M=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R(")4]FQT<_QK(&QE(%!(
M4"!P<F]G<F%M(&9O<FWA:N%B86X@87H@96QKZ7-Z_&QT(&MO;F9I9W5RX6-I
M\W0N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,3$*;7-G:60@(D1R;W`@
M9&]W;B!L:7-T(@IM<V=S='(@(DQE9_9R9/QL]2!L:7-T82(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`B2^%B
M[73S<WIE<F5K(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$S"FUS
M9VED(")%+4UA:6PB"FUS9W-T<B`B96UA:6PB"@HC.B!L:6(O3F5T+U--4R]G
M96YE<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A
M>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R
M=FEC92XB"FUS9W-T<B`B(@HB16UA:6QB]6P@4TU3+6O\;&3U(&UE9VAA:G3S
M+"!H82!A('1E;&5F;VYTX7)S87/A9R!B:7IT;W/M=&IA(&5Z="!A("(*(G-Z
M;VQGX6QT873A<W0N(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B2$E"02(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*
M;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B16-U861O<B(*"B,Z(&QI8B](;W)D
M92]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHW,@IM<V=I9"`B161I="(*;7-G<W1R(")-\V1O<^UTX7,B"@HC.B!L
M:6(O2&]R9&4O0FQO8VLO54DN<&AP.C4P"FUS9VED(")%9&ET($)L;V-K(@IM
M<V=S='(@(D)L;VMK(&WS9&]S[73A<R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%9&ET($=R;W5P(@IM
M<V=S='(@(D-S;W!O<G0@;?-D;W/M=.%S(@H*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HW-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$P,`IM<V=I9"`B
M161I="!097)M:7-S:6]N(@IM<V=S='(@(DIO9V]S=6QT<^%G(&WS9&]S[73A
M<R(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D
M:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B2F]G;W-U;'1SX6=O:R!M\V1O<^UT
MX7-A(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R
M("(E<R!J;V=O<W5L='/A9V%I;F%K(&WS9&]S[73A<V$B"@HC.B!T96UP;&%T
M97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*
M;7-G<W1R(")-96QY:6L@;W!C:?-K870@=N%L=&]Z=&%S<W5K.B(*"B,Z(&QI
M8B](;W)D92]097)M<R]522YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@
M(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@
M:F]G;W-U;'1SX6=A:6YA:R!M\V1O<^UTX7-A(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E
M<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(E<R!J;V=O<W5L='/A9V%I;F%K
M(&WS9&]S[73A<V$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G
M:60@(D5D=6-A=&EO;B(*;7-G<W1R(")/:W1A=.%S(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C<W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW
M,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B
M"FUS9W-T<B`B16=Y:7!T;VTB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S
M='(@(E-A;'9A9&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S
M='(@(D5L96TN+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B87H@)VTG(&)E=/L@
M<WKI;&5S<^EG92(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<S(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T"FUS9VED(")%;6%I;"(*
M;7-G<W1R(")%;6%I;"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-38V('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV.`IM<V=I9"`B16UA:6P@
M061D<F5S<R(*;7-G<W1R(")%;6%I;"!C[6TB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3DV-PIM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N
M(@IM<V=S='(@(D%Z(&5M86EL(&/M;65K;F5K(&5G>65Z;FG\:R!K96QL+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.3DS"FUS9VED(")%;6%I;"!W:71H
M(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")%;6%I;"!V:7-S>F%I9V%Z;VSA<W-A
M;"(*"B,Z(&QI8B].970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@
M(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@(D5M86EL+5--4R#A=&KA
M<O,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDY
M"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T<B`B2&%N9W5L871I:V]N;VLB"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B
M16UP='D@;65S<V%G92XB"FUS9W-T<B`BW')E<R#\>F5N970N(@H*(SH@;&EB
M+TAO<F1E+T=R;W5P+VQD87`N<&AP.C(T,R!L:6(O2&]R9&4O1W)O=7`O;&1A
M<"YP:'`Z-#@T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV-C(@;&EB
M+TAO<F1E+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!L:6(O2&]R9&4O075T:"]L
M9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B3FEN
M8W,@:6QY96XN(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,3$S
M"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B5/9R]FQJ_&L@
M:VD@82!K97)E<^ES96ME="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M-#<*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO
M=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(D5N9V5D:OQK(&UE9RP@
M:&]G>2!KZ7!E:V5T(&EL;&5S<WK\;FL@82!S>O9V96=B92!A($9O=/-G86SI
M<FGA:V+S;#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(R"FUS9VED
M(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R("),
M96=Y96X@:F]B8B!E9^ER9V]M8F)A;"!E;.ER:&5T]2P@:V]N=&5X='5S9OQG
M9_4@;65N_#\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y,B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C<Y-PIM<V=I9"`B16YD('EE87(B"FUS9W-T<B`B07H@
M=71O;'/S(.EV(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`BP71V
MX6QTX7,@:_QL]FX@86)L86MR82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,C0*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI
M8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U
M<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R
M('!E=#\G.B(*;7-G<W1R("(B"B)!9&IA(&UE9R!A>G0@82!B:7IT;VYSX6=I
M(&OI<F3I<W0L(&%M96QY<F4@;6%J9"!VX6QA<WIO;&YI82!K96QL(&IE;'-Z
M87;A;F%K("(*(N%TX6QL[73A<^%H;WHL('!L+B`G:&]G>2!H[79JX6L@82!K
M=71YX6KA=#\G.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E
M(%523"!H97)E(@IM<V=S='(@(D%D:F$@;65G(&$@:^EP(%523"UJZ70@:71T
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,@IM
M<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@(LUR:F$@
M8F4@87H@86SA8F)I(&)E=/MK970Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.CDY(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN
M96$B"FUS9W-T<B`B16=Y96YL[73U:2U'=6EN96$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<V
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%<FET<F5A
M(@IM<V=S='(@(D5R:71R96$B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="]6:65W+G!H<#HY-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-#@*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-@IM<V=I9"`B17)R;W(B"FUS
M9W-T<B`B2&EB82(*"B,Z(&QI8B](;W)D92]496UP;&%T92YP:'`Z-#8S"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*
M;7-G<W1R(")(:6)A('3V<G3I;G0@82!B;&]K:R!LZ71R96AO>N%S86MO<CH@
M)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B
M"FUS9W-T<B`B2&EB82!T]G)TZ6YT(&%Z(&%D871S>FEN:W)O;FEZX6-I\W,@
M:F5L('3V<FSI<V5K;W(Z("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@
M<WEN8R!L;V<Z("5S(@IM<V=S='(@(D%Z(&%D871S>FEN:W)O;FEZX6-I\W,@
M;F%P;//A;&QO;>%N>2!T]G)LZ7-E(&YE;2!S:6ME<OQL=#H@)7,B"@HC.B!L
M:6(O2&]R9&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(DAI8F$@=/9R
M=.EN="!A>B!A9&%T;&5KZ7+I<V)E;CH@)7,B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(DAI8F$@=/9R=.EN="!A
M(&IE;'-Z\R!M96=VX6QT;WIT873A<V%K;W(Z("5S(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@
M96UA:6P@;65S<V%G92XB"FUS9W-T<B`B2&EB82!A>B!E;6%I;"#\>F5N971B
M96XN(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I
M;F<@7"(E<UPB+B(*;7-G<W1R(")!*'HI(%PB)7-<(B#A;&QO;>%N>7)A(&YE
M;2!S:6ME<OQL="#M<FYI+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`BR7-Z
M=&]R<WKA9R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(D5T:?-P:6$B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G
M<W1R(").96UZ971I<^EG96LB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(D5U<O-P82(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-#,*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B
M"FUS9W-T<B`B,34@<&5R8V5N:^EN="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.3,*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R("(R('!E
M<F-E;FOI;G0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0P(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B
M"FUS9W-T<B`B,S`@;>%S;V1P97)C96YKZ6YT(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDT"FUS9VED
M(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B-2!P97)C96YKZ6YT(@H*(SH@
M;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G
M:6XB"FUS9W-T<B`B;6EN9&5N(&)E:F5L96YT:V5ZZ7-K;W(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S0T"FUS9VED(")%=F5R>2!H86QF(&AO=7(B
M"FUS9W-T<B`B9NEL\W+A;FOI;G0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S0Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3(*;7-G:60@(D5V97)Y
M(&UI;G5T92(*;7-G<W1R(")P97)C96YKZ6YT(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G
M<W1R(")0Z6QD82#I<G3I:V5K.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX
M,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R
M-PIM<V=I9"`B17AE8W5T92(*;7-G<W1R(")6Z6=R96AA:G3A<R(*"B,Z(&QI
M8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C$T"FUS9VED(")%
M>'!A;F0B"FUS9W-T<B`B3GEI<W-U:R!S>NET(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]S:61E8F%R+FEN8SHS,@IM<V=I9"`B17AP86YD(%-I9&5B87(B"FUS
M9W-T<B`B2F5L96[M='/\:R!M96<@87H@;VQD86QS\R!M96[\="(*"B,Z(&QI
M8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@
M)RDG(@IM<V=S='(@(DET="`G*2<@:V5L;&5N92!K]G9E=&ME>GIE;B(*"B,Z
M(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T
M960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R("(B
M"B))='0@8W-U<&%S>B!S>O-N86L@=F%G>2!I9.EZ]6IE;&)E;B!L97;U(&ME
M<F5SZ7-I(&MI9F5J97KI<VYE:R!K96QL96YE(&QE;FYI92(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E
M(@IM<V=S='(@(D%Z(.ER=NEN>65S<^EG(&QE:N%R871A(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HV-S<*;7-G:60@(D5X<&]N96YT(@IM<V=S
M='(@(DMI=&5V]2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(E-Z
M[6XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@
M=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(D$@:V]N9FEG=7+A8VGS($944"UN
M(.%T('9A;/,@9F5L=/9L=.ES92(*"B,Z(&QI8B](;W)D92]0<F5F<R]S<6PN
M<&AP.C(R-0IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N
M(@IM<V=S='(@(D$@<WIE;>EL>65S(&)EX6QL[73A<V]K870@;F5M('-I:V5R
M_&QT(&)E;VQV87-N:2XB"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z
M-S4@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z.3@*;7-G:60@(D9A:6QE9"!T
M;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")!>B!,1$%0('-Z
M97)V97(@;F5M(.ER:&5T]2!E;"XB"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N
M<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R
M+B(*;7-G<W1R(")!>B!334(@<WIE<G9E<B!N96T@Z7)H973U(&5L+B(*"B,Z
M(&QI8B]61E,O9G1P+G!H<#HW,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(DYE;2!S:6ME<OQL
M="!A*'HI(%PB)7-<(BUB]6P@=/9R=.EN]2!MX7-O;.%S+B(*"B,Z(&QI8B]6
M1E,O9G1P+G!H<#HW,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O
M(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R(").96T@<VEK97+\;'0@82AZ*2!<
M(B5S7"(M8F4@=/9R=.EN]2!MX7-O;.%S+B(*"B,Z(&QI8B](;W)D92]!=71H
M+W-A<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,
M(&-O;FYE8W1I;VXN(@IM<V=S='(@(DYE;2!S:6ME<OQL="#Z:B!305-,(&MA
M<&-S;VQA=&]T(&SI=')E:&]Z;FDN(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C4P
M,2!L:6(O5D93+V9T<"YP:'`Z-S4U"B,L('!H<"UF;W)M870*;7-G:60@(D9A
M:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B3F5M('-I:V5R_&QT
M(&$H>BD@7"(E<UPB+6)E('3V<G3I;O4@X71H96QY97KI<RXB"@HC.B!L:6(O
M5D93+W-M8BYP:'`Z-#8U"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T
M;R!R971R:65V93H@)7,B"FUS9W-T<B`BP6QL;VWA;GEH;WIZX6;I<NES:2!H
M:6)A.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$X"FUS9VED(")&86ER(@IM<V=S='(@(E1I<WIT82(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HX-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A
M;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R(")&86QK;&%N9"US
M>FEG971E:R`H36%L=FEN87,I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C@V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G
M<W1R(")&87)O92US>FEG971E:R(*"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(S
M.`IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(DAE;'ER96AO>FAA=&%T
M;&%N(&AI8F$Z(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R(")&87@B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S4Q"FUS9VED(")&87AE<R(*;7-G<W1R(")&87@B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B
M<G5A<GDB"FUS9W-T<B`B9F5B<G7A<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C(W"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(DCU;>ER<^EK;&5T
MZ7)Z970B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(P"FUS
M9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B2/5MZ7)SZ6ML973I<GIE=#H@
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*
M;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(D5G>2UE9WD@>N%P;W(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I
M9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")3>O-R=N%N>6]S86X@:/-Z
MX7!O<F]K(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-#@*;7-G:60@(D9I
M96QD(&UA=')I>"(*;7-G<W1R(")-97KU(&WA=')I>"(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HS,S(Y"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R
M(")&:6=L970@0T%05$-(02`H8F5T^VMI<F%K\R!H=6WA;G1E<WIT*2(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HS,S,S"FUS9VED(")&:6=L970@9F]N="(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@(D9I9'IS:2(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B1FEL92(*;7-G
M<W1R(")&X6IL(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C`@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R(")!(&;A:FQO:R!S>N%M
M83H@)7,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV,"!L
M:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R(")!(&;A:FQO:R!S>N%M83H@
M)7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`Y"FUS9VED(")&
M:6QE($UA;F%G97(B"FUS9W-T<B`B1N%J;"!M96YE9'IS97(B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV,R!L:6(O2&]R9&4O34E-12]6
M:65W97(O>FEP+G!H<#HW,`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z
M+G!H<#HX,@IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(D;A:FQNZ78B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDX,0IM<V=I9"`B1FEL92!S96QE8W1I
M;VXB"FUS9W-T<B`B1N%J;"!K:6IE;/9LZ7,B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,30Y,`IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B1N%J;"!F
M96QT]FQTZ7-E(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDP,@IM<V=I
M9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@(D;A:FQO
M:R!F96QT]FQTZ7-E(&YE;2!L96AE='/I9V5S+B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HY,0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R(")3>OMR
M]6LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C@R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S='(@(D9I;FYO<G-ZX6<B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S="!(86QF(@IM<V=S
M='(@(F5L<_4@9NEL(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]"
M;&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R
M(")E;'/U(&YE9WEE9"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HR-3<*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R(")6X6QT;WIA
M=&QA;B!MZ7)E=&%RX6YY(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(S,@IM<V=I9"`B1FQI<"(*;7-G<W1R(")4_&MR]GKI<R`H
M9O9L+VQE*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&
M;V<B"FUS9W-T<B`B2_9D(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C(S-R!L:6(O
M5D93+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R
M("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(B5S(&UA<'!A(&YE;2!LZ71E
M>FEK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R(")"973[<WKM;B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R
M("+)=&5L96LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T
M(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(D]L>6%N(&+V;F?I<WKU
M:R!S>N%MX7)A+"!A;6EK(&YE;2!J96QE;NUT:6L@;65G(&$@:^EP96ME="(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S0Q"FUS9VED(")&;W)E8V%S="`H
M5$%&*2(*;7-G<W1R(")%;/5R96IE;'KI<R`H<F5P_&SU=.ER:2DB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S(*;7-G:60@(B(*(D9O<F5C
M87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T
M=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE
M<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@HB
M07H@96SU<F5J96QZZ7,@:63U=&%R=&%M82!N87!O:V)A;B`H87H@96SU<F5J
M96QZZ7,@;F%P<&%L:2#I<R#I:G-Z86MA:2`B"B)A9&%T;VMA="!T87)T86QM
M87HL(&5ZZ7)T(&$@;F%G>2!S>N%M;VL@<WKI;&5S(&)L;VMK;W0@97)E9&WI
M;GEE>FYE:RDB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P,@IM
M<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(D5L9F5L96IT
M971T92!A(&IE;'-Z87;A=#\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#8T"FUS9VED(")&;W)M<R(*;7-G<W1R("+;<FQA<&ME>F5LZ7,B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS
M9W-T<B`B263I>F5T(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS
M9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B263I>F5T(&9A:G3A:F$B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM
M<V=S='(@(DEDZ7IE=&5K(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y
M"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(DEDZ7IE=&5K(#(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4U"FUS9VED(")&;W)U;7,B"FUS
M9W-T<B`B1O-R=6UO:R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M,3$*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(E1O=N%B8NUTX7-O:R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G
M:60@(D9R(@IM<V=S='(@(E#I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S
M='(@(D9R86UE+65K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(D9R86YC:6%O
M<G-ZX6<B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B
M1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B1G)A;F-I86]R<WKA9R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*
M;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B1G)A;F-I82!'=7EA;F$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@T(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HX-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R(")&<F%N8VEA(%!O
M;&ENZ7II82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C(@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S
M(@IM<V=S='(@(D9R86YC:6$@1.EL:2!497+\;&5T96LB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G
M<W1R(")&96QA9/,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C,W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#D*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-0IM<V=I9"`B1G)O;2!T:&4@(@IM
M<V=S='(@(DERX6YY.B`B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R(")2Z7-Z
M;&5T97,@;&7M<N%S(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]"
M;&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R(")T
M96QI:&]L9"(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&=6QL($YA;64B
M"FUS9W-T<B`B5&5L:F5S(&[I=B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HX."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(D=A
M8F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@
M9G)O;2(*;7-G<W1R(")-96QY:6L@9V%LZ7)IX6+S;"!V96=Y_&L@82!KZ7!E
M="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B2^EP9V%L
MZ7)I83HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.38@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B1V%M8FEA(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'
M96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(DAO>GIU:R!LZ71R
M92!A*'HI("5S(&MO;F9I9W5RX6-I\VKA="(*"B,Z('1E;7!L871E<R]A9&UI
M;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D92(*
M;7-G<W1R(")!(&ME;&5T:V5Z971T(&OS9"(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HY,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS
M9W-T<B`B1W+Z>FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8Y(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R(").Z6UE=&]R
M<WKA9R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S4*;7-G:60@(D=H86YA(@IM<V=S='(@(D=HX6YA(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.CDT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HY,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB
M<F%L=&%R(@IM<V=S='(@(D=I8G)A;'3A<B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3<V"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(DME
M<F5S>G1NZ78B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<U
M('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$P"B,Z('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C$Y"FUS9VED(")';&]B86P@3W!T:6]N<R(*;7-G<W1R(")'
M;&]BX6QI<R!B9>%L;.UTX7-O:R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N
M:6YC.C$W"FUS9VED(")';R(*;7-G<W1R(")-96AE="(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(D?V9&5L
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,S$*
M;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(D=O;V=L92!TZ7)KZ7`B"@HC
M.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A
M<F-H(@IM<V=S='(@(D=O;V=L92!K97)E<^ES(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S.`IM<V=I9"`B1W)A>7-C86QE(@IM
M<V=S='(@(D9E:V5T92]F96CI<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B
M1_9R]F=O<G-ZX6<B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I
M9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(F?V<O9G("A)4T\M.#@U
M.2TW*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R(")'<O9N;&%N9"(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HX.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G
M:60@(D=R96YA9&$B"FUS9W-T<B`B1W)E;F%D82(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R
M(")#<V]P;W)T(&%D;6EN:7-Z='+A8VGS(@H*(SH@;&EB+TAO<F1E+T=R;W5P
M+G!H<#HU.2!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'
M<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R(")!(&-S;W!O
M<G1NZ78@;6%R861H870@_')E<V5N(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD
M87`N<&AP.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5
M;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED.B`B"FUS9W-T<B`B1W)O=7!?;&1A<#H@)7,@8W-O<&]R="!H;WIZ
MX6%DX7-A(&YE;2!S:6ME<OQL="X@02!S>F5R=F5R(';A;&%S>F$Z("(*"B,Z
M(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ,3@@;&EB+TAO<F1E+T=R;W5P
M+VQD87`N<&AP.C$R-`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-#$X
M"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D
M96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@)7,@8W-O<&]R
M="!T]G)LZ7-E(&YE;2!S:6ME<OQL="(*"B,Z(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HS,S@@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E
M(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD87`Z("5S(&-S;W!O<G0@861A
M=&%I;F%K(&UE9_IJ[73A<V$@;F5M('-I:V5R_&QT(@H*(SH@;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*
M;7-G<W1R(")#<V]P;W)T;VLB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@
M(D=U861E;&]U<&4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`S(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R(")'=6%M(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<*;7-G
M:60@(D=U871E;6%L82(*;7-G<W1R(")'=6%T96UA;&$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(D=U
M97)N<V5Y(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B5F5N9.EG(&IO9V]S=6QT<^%G;VLB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#<R"FUS9VED(")'=65S=&)O;VLB"FUS9W-T
M<B`B5F5N9.EG:_9N>78B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3<@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B1W5I;F5A
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<X"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(D)I<W-A=2U'=6EN
M96$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`U(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R(")'=7EA;F$B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z.38T"FUS9VED(")(5$U,(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E
M('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R(")(5$U,07)E82!G>>%V
M87/A9V+S;"!N96T@:&%J;&%N9/,@82!S;W(@=71O;'/S(&-E;&SA:N%T('3V
M<O9L;FDN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R
M(")(5$U,07)E82!G>>%V87/A9V+S;"!N96T@:&%J;&%N9/,@82!TX6)LX7IA
M="!U=&]L<_,@;W-Z;&]PX70@=/9R]FQN:2XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@
M:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A(&=YX79A<^%G8O-L(&YE;2!H
M86IL86YD\R!A('3A8FSA>F%T('5T;VQS\R!S;W+A="!T]G+V;&YI+B(*"B,Z
M(&QI8B](;W)D92]!=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H
M96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D$@2%144"!F96QH87-Z
M;N%L\V%Z;VYO<^UTX7,@;F5M('1A;.%L:&%T\RXB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAA:71I
M(@IM<V=S='(@(DAA:71I(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M-#$S"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G<W1R(")(87-H(&%L9V]R
M:71M=7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR,@IM<V=I9"`B2&%Z92(*;7-G<W1R(")+]F0B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z.3(S(&QI8B](;W)D92]&;W)M+G!H<#HR.3$X"FUS9VED(")(
M96%D97(B"FUS9W-T<B`B1F5J;.EC(@H*(SH@;&EB+TAO<F1E+T9O<FTO5'EP
M92]T86)L97-E="YP:'`Z-C$*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B1F5J
M;.EC(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N
M9',B"FUS9W-T<B`B2&5A<F0M(.ES($UC1&]N86QD+7-Z:6=E=&5K(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*;7-G:60@
M(DAE879Y(%0M4W1O<FTB"FUS9W-T<B`B17+U<R!Z:79A=&%R(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM
M."U)*2(*;7-G<W1R(")HZ6)E<B`H25-/+3@X-3DM."U)*2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G
M:60@(DAE:6=H="(*;7-G<W1R(")-86=A<W/A9R(*"B,Z(&QI8B](;W)D92](
M96QP+G!H<#HQ.#0@;&EB+TAO<F1E+TAE;'`N<&AP.C$X-B!S97)V:6-E<R]H
M96QP+VEN9&5X+G!H<#HQ-PHC.B!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z
M-`IM<V=I9"`B2&5L<"(*;7-G<W1R(")396?M='/I9R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@
M=7-I;F<@961I=&]R(@IM<V=S='(@(E-E9^UT<^EG(&$@<WIE<FME<WIT]2!H
M87-Z;N%L873A:&]Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-S4*;7-G
M:60@(DAE;'!E<B(*;7-G<W1R(")396?M='/I9R(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R(")&Z6QT96ME
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN
M;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B17H@82!FX6IL(&5L96IE.B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS
M9VED(")(:6=H(@IM<V=S='(@(FYA9WDB"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC
M.C4*;7-G:60@(DAO7VUE(@IM<V=S='(@(DME>F3U;&%P(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(T,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B
M2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B5F%T:6OA
M;G;A<F]S(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-3,Y"FUS9VED(")(;VUE(@IM
M<V=S='(@(DME>F3U;&%P(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,C(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")/='1H;VYI(&/M;2(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`IM<V=I9"`B2&]M92!$:7)E
M8W1O<GDB"FUS9W-T<B`B4WIE;>EL>65S(&%L:_9N>79TX7(B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0
M:&]N92(*;7-G<W1R(")/='1H;VYI('1E;&5F;VXB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3`X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U
M<F%S(@IM<V=S='(@(DAO;F1U<F%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$P-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS
M9W-T<B`B2&]N9VMO;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-C<*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HT-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G
M92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@:&EBX7,@)7,@6$U,(&%D870@
M=F%N(&$H>BD@)7,@_'IE;F5T8F5N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE
M<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E
M+TMO;&%B.B!N:6YC<R!A*'HI("5S(&]B:F5K='5M;F%K(&UE9V9E;&5L]2#\
M>F5N970B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0T-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@
M9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@;FEN
M8W,@)7,@=.UP=7/Z(&]B:F5K='5M(&$H>BD@)7,@_'IE;F5T8F5N(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C4Q"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B
M"FUS9W-T<B`B2&]R9&4O2V]L86(Z(%-I:V5R97-E;B!T]G+V;'3\:R!E>G0Z
M("5S(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,C(S"FUS9VED
M(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E
M<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@87H@:6YT96=RX6SS('!R;V=R86UH;WH@<WK\:W/I9V5S(&$@)V1O
M;7AM;"<@4$A0(&+U=NUTZ7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C4Q
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@;F5M('-I:V5R_&QT(/IJ(%A-3"!FX70@;.ET<F5H;WIN
M:2!A*'HI("5S(&]B:F5K='5M:&]Z(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HQ,C0X"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L
M86(Z($YE;2!S:6ME<OQL="!T]G+V;&YI("5S+70@7"(E<UPB.B`E<R(*"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z-#@S"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@
M=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R("(B"B)(;W)D92]+;VQA8CH@
M;F5M('-I:V5R_&QT(&UE9VAA=.%R;WIN:2!A($U)344@240M:N%T(&$@:_9V
M971K97KU('3M<'5S^B`B"B)M96QLZ6ML971N96LZ("5S(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HQ,3DW"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*
M;7-G<W1R(")(;W)D92]+;VQA8CH@3F5M('-I:V5R_&QT('-Z:6YK<F]N:7KA
M;&YI("5S(%PB)7-<(CH@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$S
M,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(B(*(DAO<F1E+TMO
M;&%B.B!.96T@<VEK97+\;'0@82!K]G9E=&ME>O4@:_9Z]G,@=.%R=&5R_&QE
M="!S>FEN:W)O;FEZX6SA<V$Z("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO
M=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!I<VUE<F5T
M;&5N(&OV>O9S('3A<G1E<OQL970@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A
M;"!2=6QE(@IM<V=S='(@(E;M>G-Z:6YT97,@=F]N86PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I
M>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B5NUZ<WII;G1E<R!M87)G\R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G
M:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(E;M>G-Z:6YT97,Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q
M"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A
M*2(*;7-G<W1R(")(;V=Y(&IU=&]T="!I9&4_("A+Z7)J_&L@[7)J82!M96<A
M*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI
M:V4@=&\@;65R9V4_(@IM<V=S='(@(DCA;GD@;W-Z;&]P;W0@:^UVX6X@]G-S
M>F5O;'9A<WIT86YI/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R
M93\B"FUS9W-T<B`B2.%N>2!M97KU("AO<WIL;W`I('9A;C\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS
M9VED(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*
M;7-G<W1R(")(X6YY('-O<G0@:^UVX6X@]G-S>F5O;'9A<WIT86YI/R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,S<*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(E#A<F%T87)T
M86QO;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@*;7-G
M:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B4.%R871A<G1A;&]M.B`B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G
M<W1R(")(=6UO<FES=.%K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(DUA
M9WEA<F]R<WKA9R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ-S(@
M;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B07H@24U!4"!L97;I;&SA9&$@;.ET<F5H;WKA<V$@;F5M('-I:V5R_&QT
M.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,30@;&EB+TAO
M<F1E+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B07H@
M24U!4"!L97;I;&SA9&$@=/9R;.ES92!N96T@<VEK97+\;'0Z("5S(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$W.2!L:6(O2&]R9&4O075T:"]C
M>7)S<6PN<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB
M;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")!>B!)34%0
M(&QE=NEL;.%DX6AO>B!T87)T;WKS(&MV\W1A(&SI=')E:&]ZX7-A(&YE;2!S
M:6ME<OQL=#H@)7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,R,`IM<V=I
M9"`B25`@061D<F5S<R(*;7-G<W1R("))4"!C[6TB"@HC.B!L:6(O2&]R9&4O
M075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R(")!>B!)4"!C[6T@;F5M(&AA=.%R;WIH873S(&UE
M9RXB"@HC.B!L:6(O2&]R9&4O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B
M25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS
M9W-T<B`B07H@25`@8^UM(&YI;F-S(&$@;65G96YG961E='0@0TE$4B!T87)T
M;VWA;GEB86XN(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B
M5&EL=&]T="]M96=VX6QT;WIO='0@25`@8^UM+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B
M25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(E-O<B!B96EL;&5S>G3I<V4@
M96;V;.DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B27IL86YD(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,`IM<V=I9"`B26-O;G,@3VYL>2(*
M;7-G<W1R(")C<V%K(&EK;VYO:R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H
M<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T
M<B`B)7,@:6MO;FIA:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#$*
M;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R(")I:V]N;VL@Z7,@<WKV
M=F5G(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,PIM<V=I9"`B261E
M;G1I='DG<R!N86UE.B(*;7-G<W1R(")!>B!A>F]N;W/M=/-H;WH@=N%L87-Z
M=&]T="!E;&YE=F5ZZ7,Z(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N
M<&AP.C4Y.0HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES
M<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD
M;W<N(@IM<V=S='(@(DAA(&$@;65G:F5L96[M=.ES(&YE;2!M96=F96QE;/4L
M("5S(&5G>2#Z:B!A8FQA:V)A;B!V86SS(&UE9VYY:73A<VAO>BXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4Y"FUS9VED("(B"B))9B!Y;W4@9&]N
M)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U
M(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.
M1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*(DAA(-9N($EN=&5R;F5T($5X
M<&QO<F5R="!H87-Z;N%L+"#I<R!N96T@:F5L96YN96L@;65G(&%Z(&EK;VYO
M:RP@86MK;W(@(@HB=N%L87-S>F$@97IT(&%Z(&]P8VGS="P@;65L;'EE;"!K
M:6MA<&-S;VQJ82!A(%!.1R!KZ7!E:R!T<F%N<WIP87)E;F-IX6KA="XB"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<R"FUS9VED
M("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H
M92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA
M>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@HB2&$@;.%T:F$@97IT
M(&$@<WKV=F5G970L(&1E(&$@:^EP970@;F5M+"!A:VMO<B!B]FYGZ7-Z]7!R
M;V=R86UJ82!N96T@:^EP97,@(@HB;65G:F5L96[M=&5N:2!A('-Z97)V97)R
M92!K_&QD96YD]2!KZ7!E="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E(%!R
M979I97<Z(@IM<V=S='(@(D5L]7IE=&5S(&[I>F5T.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@
M(DEM86=E(%523"(*;7-G<W1R(")!(&OI<"!54DPM:F4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*
M;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B02!KZ7`@55),+6IE.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(DUE
M;'EI:R!G86SI<FGA8O-L('9A;B!A(&OI<"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B
M26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R(")+Z7`@96)B]6P@82!G86SI
M<FGA8O-L.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8U"FUS9VED("))
M;6%G92!U<&QO860B"FUS9W-T<B`B2^EP(&9E;'3V;'3I<V4B"@HC.B!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(DOI
M<&5K(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T
M97,O9&%T82]D871E;6%P+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z-30@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B26UP;W)T
MX6SA<RP@)60N(&SI<.ES(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI
M;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S
M(@IM<V=S='(@(D%Z(&EM<&]R=.%L="!M97KU.B`E<R(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB
M"FUS9W-T<B`B07H@:6UP;W)TX6QT(&UE>O5K.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B
M26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B4V]R(&)E:6QL97-Z=.ES92!E
M>F%LX2(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$S-`IM<V=I
M9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R(")(:6+A
M<R!P87)A;F-S<&%R86WI=&5R+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O
M;W(@<&%S<W=O<F0N(@IM<V=S='(@(DYE;2!M96=F96QE;/4@82!B96IE;&5N
M=&ME>NES:2!NZ78@Z7,O=F%G>2!A(&IE;'-Z\RXB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N
M86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C
M="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H
M96QP+B(*;7-G<W1R("(B"B).96T@;65G9F5L96SU(&$@9F5L:&%S>F[A;/-I
M(&[I=B!V86=Y(&%Z(&%L=&5R;F%T[78@8^UM+B!0<O-BX6QJ82#Z:G)A('9A
M9WD@(@HB9F]R9'5L:F]N(&$@<F5N9'-Z97)G87IDX6AO>BP@:&$@=&]VX6)B
M:2!S96?M='/I9W)E('9A;B!S>OQK<^EG92XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!)
M;F1E;G0B"FUS9W-T<B`B0F5K97IDZ7,@8F5L:F5B8B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$P.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD
M:6$B"FUS9W-T<B`B26YD:6$B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD
M:79I9'5A;"!5<V5R<R(*;7-G<W1R(")%9WEE<R!F96QH87-Z;N%L\VLB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$R(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*
M;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("));F1O;NEZ:6$B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*
M;7-G<W1R("));F9O<FWA8VGS(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(U.0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)MX6-I
M\R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3D*;7-G:60@
M(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(D%Z
M(&EN9F]R;>%C:?,@;>%R(&YE;2#A;&P@<F5N9&5L:V5ZZ7-R92XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(D]S>FQO
M<"!B97-Z^G+A<V$@97IU=.%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E<G0@
M26UA9V4B"FUS9W-T<B`B2^EP(&)E:6QL97-Z=.ES92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R
M="!486)L92(*;7-G<W1R(")4X6)LX7IA="!B96EL;&5S>G3I<V4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED
M("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B3&EN:R!LZ71R96AO>N%S82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@
M(D]S>FQO<"!B97-Z^G+A<V$@97IE;.DB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R
M="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@
M(D]S>FQO<"!B97-Z^G+A<V$@97IU=.%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E
M<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T
M<B`B3W-Z;&]P(&)E<WKZ<N%S82!E>F5LZ2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS
M97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B
M4V]R(&)E<WKZ<N%S82!E>F%LX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@
M;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(E-O<B!B
M97-Z^G+A<V$@96;V;.DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A<F%G
M<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(D)E:V5Z9.ES
M(&)E:6QL97-Z=.ES92!E>G5TX6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A
M('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R(")"
M96ME>F3I<R!B96EL;&5S>G3I<V4@97IE;.DB"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*
M;7-G<W1R(")(;WIZ=6YK(&SI=')E(&%L=&5R;F%T[78@<V%B;&]N="(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#(*;7-G:60@(DEN<V5R="!A;B!E
M;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W
M('!A<W-W;W)D.B(*;7-G<W1R(")!9&IO;B!M96<@96=Y(&5M86EL(&/M;65T
M+"!M96QY<F4@96QK_&QD:&5T]2!A>B#6;B#Z:B!J96QS>F%V83HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X
M"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R(")#96QL82!B96EL
M;&5S>G3I<V4@97IU=.%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F
M;W)E(@IM<V=S='(@(D-E;&QA(&)E:6QL97-Z=.ES92!E>F5LZ2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*
M;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B3W-Z;&]P(&)E
M<WKZ<N%S82!E>G5TX6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E
M9F]R92(*;7-G<W1R(")/<WIL;W`@8F5S>OIRX7-A(&5Z96SI(@H*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4P(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM
M<V=S='(@(DQE=F5L96L@8F5MX7-O;.%S82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS
M97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R(")"96ME>F3I<R!B96EL;&5S
M>G3I<V4@97IU=.%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H
M(&)E9F]R92(*;7-G<W1R(")"96ME>F3I<R!B96EL;&5S>G3I<V4@97IE;.DB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(E-O<B!B
M97-Z^G+A<V$@97IA;.$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R
M92(*;7-G<W1R(")3;W(@8F5S>OIRX7-A(&5F]FSI(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(S,PIM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A
M;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R(")!9&IA
M(&UE9R!A(&OM=N%N="!VX6QA<WIT(&$@8FEZ=&]N<^%G:2!KZ7)DZ7-R93HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V
M"FUS9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(DOI<"!B96EL
M;&5S>G3I<V4O;?-D;W/M=.%S82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN
M:R(*;7-G<W1R("),:6YK(&)E:6QL97-Z=.ES92]M\V1O<^UTX7-A(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS
M=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@
M;&ES="XB"FUS9W-T<B`B02!S>N%M;.%JX6X@;FEN8W,@96SI9R!F961E>F5T
M(/QZ96YE=&5T(&O\;&1E;FD@82!K]G)L97;I;&QI<W3A<F$N(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F
M:6-I96YT(&-R961I="XB"FUS9W-T<B`B02!S>N%M;.%JX6X@;FEN8W,@96SI
M9R!F961E>F5T+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#<Y"FUS9VED
M("));G1E9V5R(@IM<V=S='(@(D5GZ7-Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Q,S<*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R(")%9^ES>B!S
M>N%M;VL@;&ES=.%J82(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D
M97(I+B(*;7-G<W1R(")(:6+A<R]E;&9O9V%D:&%T871L86X@541(("A5<V5R
M($1A=&$@2&5A9&5R*2XB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H
M<#HQ-C<@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3DT"B,Z(&QI8B](
M;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C(Q,@IM<V=I9"`B26YV86QI9"!:25`@
M9&%T82(*;7-G<W1R(")(:6+A<R]E;&9O9V%D:&%T871L86X@6DE0('3V;?9R
M[73I<R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN
M=F%L:60@87!P;&EC871I;VXN(@IM<V=S='(@(DAI8N%S+V5L9F]G861H871A
M=&QA;B!A;&MA;&UA>N%S+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R
M(")(:6+A<R]E;&9O9V%D:&%T871L86X@8F%T8V@@87IO;F]S[73S+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,#DQ(&QI8B](;W)D92]&;W)M+G!H<#HR
M,38R(&QI8B](;W)D92]&;W)M+G!H<#HR,C,V"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,S`S(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W
M"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R(")!(&O\
M;&3V='0@861A="!H:6+A<R]E;&9O9V%D:&%T871L86XN(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@
M9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`B2&EBX7,O96QF;V=A9&AA
M=&%T;&%N(&/M;7KI<RXB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H
M<#HQ,#D@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,3,Y"B,Z(&QI8B](
M;W)D92]#;VUP<F5S<R]D8G@N<&AP.C(T,0IM<V=I9"`B26YV86QI9"!F:6QE
M(&9O<FUA="(*;7-G<W1R(")(:6+A<R]E;&9O9V%D:&%T871L86X@9N%J;"!F
M;W)MX71U;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*
M;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(DAI8N%S+V5L
M9F]G861H871A=&QA;B!L:6-E;G-Z:W5L8W,N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$U.0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P
M<F]V:61E9"XB"FUS9W-T<B`B2&EBX7,O96QF;V=A9&AA=&%T;&%N(';A<F]S
M+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS
M9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R(")(:6+A<R]E;&9O9V%D
M:&%T871L86X@_'IE;F5T=.UP=7,N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A
M<&E?:60N(@IM<V=S='(@(DAI8N%S+V5L9F]G861H871A=&QA;B!V86=Y(&AI
MX6YY>O,@<')O9W)A;6]ZX7-I9F5L_&QE="UA>F]N;W/M=/,N(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L
M:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G<W1R(")(:6+A<R]E;&9O
M9V%D:&%T871L86X@<&%R86WI=&5R96LN(@H*(SH@861M:6XO<&5R;7,O861D
M8VAI;&0N<&AP.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N
M+B(*;7-G<W1R(")(:6+A<R!A>B!O8FIE:W1U;2!E;.ERZ7-I(&IO9V]S=6QT
M<^%G82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"FUS
M9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(DAI8N%S+V5L9F]G
M861H871A=&QA;B!P87)T;F5R87IO;F]S[73S+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(DEN=F%L:60@<')O9'5C="!C
M;V1E+B(*;7-G<W1R(")(:6+A<R]E;&9O9V%D:&%T871L86X@=&5R;>EK:_-D
M+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS
M9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R(")(:6+A<R]E;&9O9V%D
M:&%T871L86X@<')O=&]K;VQL+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HY,R!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z-S$*(SH@
M;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G
M:60@(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B2&EBX7,O
M96QF;V=A9&AA=&%T;&%N(&/M;7IE='0Z(%PB)7-<(B(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z,3`X,"!L:6(O2&]R9&4O2V]L86(N<&AP.C$R-C,*;7-G
M:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(DAI8N%S+V5L9F]G
M861H871A=&QA;B!M96=O<WIT;W1T(&]B:F5K='5M(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U
M<F-E(&%D9')E<W,N(@IM<V=S='(@(DAI8N%S+V5L9F]G861H871A=&QA;B!F
M96QA9/-I(&/M;2XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@
M(DAI8N%S+V5L9F]G861H871A=&QA;B!U;FEC;V1E(&%D870N(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U.0IM<V=I9"`B26YV96YT;W)Y(@IM
M<V=S='(@(DYY:6QVX6YT87)TX7,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-C<X"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM
M<V=S='(@(D$@:VEJ96SV;.ES(&EN=F5R=.%LX7-A(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Q.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED("))<F%N
M+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(DERX6YI($ES>FSA;2!+
M]GITX7)S87/A9R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("))<F%K(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS
M9VED("))<F5L86YD(@IM<V=S='(@(LUR;W)S>N%G(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B
M36%N+7-Z:6=E="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R(")3
M>O-R=N%N>6]S('II=F%T87)O:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L(@IM<V=S='(@
M(DEZ<F%E;"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C(V"FUS
M9VED("))<W-U97(B"FUS9W-T<B`B02!T86[Z<^UT=N%N>2!K:6%D\VIA(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS
M9VED("))=&%L:6,B"FUS9W-T<B`B9/5L="(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B271A;'DB"FUS
M9W-T<B`B3VQA<WIO<G-ZX6<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3(S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B
M2F%M86EC82(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#(@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS
M9VED(")*86YU87)Y(@IM<V=S='(@(FIA;G7A<B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q
M-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB
M"FUS9W-T<B`B2F%PX6XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM
M<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R(")J87#A;B`H
M25-/+3(P,C(M2E`I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,@IM
M<V=I9"`B2F5R<V5Y(@IM<V=S='(@(DIE<G-E>2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q
M.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N
M(@IM<V=S='(@(DIO<F3A;FEA(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B:OIL:75S(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-R!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T
M<B`B:OIN:75S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R(")3;W)K
M:7KA<N%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@
M(FOV>NEP<F4@<F5N9&5ZZ7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL
M(@IM<V=S='(@(G-O<FMI>N%RX7,@;6EN9&OI="!O;&1A;')A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*
M;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R(")S;W)K:7KA<N%S(&)A;')A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B<V]R:VEZ
MX7+A<R!J;V)B<F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B2V%Z
M86AS>G3A;B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-C4*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(E1A<G1S=6L@
M;65G(&%Z(&5R961E=&ET/R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B2V5N
M>6$B"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R
M8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M(")!(&ME<F)E<F]S('-Z97)V97(@96QU=&%S[71O='1A(&$@9F5L:&%S>F[A
M;/-A>F]N;W/M=.%S="XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*
M;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(DME>F3U(&ME<FYE;&9E
M:FQE<WIT]6LB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G
M:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R(")+=6QC<R!LZ71R96AO>N%S82(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I
M;F=E<G!R:6YT(@IM<V=S='(@(D$@:W5L8W,@;&5N>6]M871A(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM
M<V=S='(@(DMU;&-S:&]S<WKZ<^%G(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R(")+=6QC<R!T[7!U
M<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DY"FUS9VED(")+
M97D@57-A9V4B"FUS9W-T<B`B02!K=6QC<R!H87-Z;N%L871A(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR96%D>2!E
M>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(D$@:W5L
M8W,@;>%R(&SI=&5Z:6L@82!N>6EL=N%N;W,@:W5L8W-S>F5R=F5R96XN(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S
M='(@(D=Y97)E:V5K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R(")+:7)I
M8F%T:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B2V]R96%I($[I<&D@1&5M;VMR871I:W5S($OV
M>G3A<G-A<^%G(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B2V]R96%I($OV>G3A<G-A<^%G(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.3$*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R(")K;W)E86D@
M*$550RU+4BDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R(")+=79A:70B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*
M;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B2VER9VEZ:7-Z=.%N(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM
M<V=S='(@(E]497)V97KI<R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(DYY96QV(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$S-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W"FUS9VED
M("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("),
M86]S>FD@3NEP:2!$96UO:W)A=&EK=7,@2_9Z=.%R<V%SX6<B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B
M=71O;'/S(&;I;"(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-@IM<V=I
M9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B07H@=71O;'/S(&IE
M;'-Z\W;A;'3A<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R(")U
M=&]L<_,@;F5G>65D(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3@*;7-G
M:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B571O;'/S(';A;'1O>G1A=.%S
M.B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`B571O;'/S(&)E:F5L96YT
M:V5ZZ7,Z("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C<Q.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@
M(E5T;VQS\R!B96IE;&5N=&ME>NES.B`E<RP@)7,@8^UM<O5L(@H*(SH@;&EB
M+TAO<F1E+T%U=&@N<&AP.C<Q-`IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B
M"FUS9W-T<B`B571O;'/S(&)E:F5L96YT:V5ZZ7,Z(&WI9R!S;VAA(&YE;2!V
M;VQT(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B3&5T=&]R<WKA9R(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@
M(DIO9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(D5L:&5L>65ZZ7,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V
M"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(DAA
M9WEJ82#\<F5S96XL(&AA(&YE;2!A:V%R(&ME<F5T970B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3,X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE
M8F%N;VXB"FUS9W-T<B`B3&EB86YO;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G
M<W1R(")B86PB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P-0IM<V=I9"`B
M3&5F="!H96%D97(B"FUS9W-T<B`B0F%L(&]L9&%L:2!F96ILZ6,B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S$P,0IM<V=I9"`B3&5F="!V86QU97,B"FUS
M9W-T<B`B0F%L(&]L9&%L:2#I<G3I:V5K(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$T,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM
M<V=S='(@(DQE<V]T:&\B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-34*;7-G:60@(DQE=F5L(@IM<V=S='(@(E-Z:6YT(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$T,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED("),
M:6)E<FEA(@IM<V=S='(@(DQI8NER:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,30W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B
M($IA;6%H:7)I>6$B"FUS9W-T<B`B3.UB:6%I($%R86(@4WIO8VEA;&ES=&$@
M3F%G>2!.Z7!I($OV>O9S<^EG(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$T,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM
M<V=S='(@(DQI96-H=&5N<W1E:6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G
M<W1R(")'>65N9V4@<WII=.%L\R!E<_4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR-@IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G
M<W1R(")'>65N9V4@97/U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T
M<B`B1.EL96SU='0@9WEE;F=E(&5S]2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H="!286EN($QA=&4B
M"FUS9W-T<B`B1.EL=73A;B]E<W1E(&=Y96YG92!E<_4B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B3&EG:'0@
M4F%I;B!3:&]W97(B"FUS9W-T<B`B1WEE;F=E('KA<&]R(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT
M(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(D=Y96YG92!Z:79A=&%R(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G
M:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B1WEE;F=E(&AA=F%ZX7,B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B
M3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B1WEE;F=E(&CS>N%P;W(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#$X"FUS9VED("),
M:6YK(@IM<V=S='(@(DQI;FLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S
M('1O.B(*;7-G<W1R(")!(&QI;FL@:61E(&UU=&%T.B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ.#<Y"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S
M('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@
M(DUE9VIE;&5N[73I<VMO<B!M=71A<W-O;B!E9WD@;&EN:R!A(&QE=NEL8^UM
M<O5L(&$@;&5VZ6SM<O,@86)L86MH;WHB"@HC.B!L:6(O2&]R9&4O5&5X="]&
M:6QT97(O:'1M;#)T97AT+G!H<#HQ.#(*;7-G:60@(DQI;FMS(@IM<V=S='(@
M(DQI;FME:R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B
M3&EN=7@@0V]O:VEE(@IM<V=S='(@(DQI;G5X(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S0S,30N<&AP.C0V(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L
M9&5R(@IM<V=S='(@(DQI<W3A>N%S("T@82!F96QH87-Z;N%L\R!LX71J82!A
M(&UA<'#A="(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI
M<W0@1&%T86)A<V5S(@IM<V=S='(@(D%Z(&%D871BX7II<V]K(&QI<W3A:F$B
M"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,0IM<V=I9"`B3&ES="!(
M96QP(%1O<&EC<R(*;7-G<W1R(")!>F]K;F%K(&$@=.EMX6MN86L@82!L:7-T
MX6IA(&%M:7+U;"!S96?M='/I9R!K87!H873S(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$S,@IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B07H@861A
M='3A8FSA:R!L:7-TX6IA(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP
M:'`Z-3DT"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B3&ES=&$@87)C
M:.UV=6TB"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.#D*;7-G
M:60@(DQI<W0M2&5L<"(*;7-G<W1R("),:7-T82!S96?M='/I9VOI<NES(@H*
M(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T
M+4ED(@IM<V=S='(@(DQI<W1A(&%Z;VYO<^UT\R(*"B,Z(&QI8B](;W)D92]-
M24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R
M("),:7-T82!T=6QA:F1O;F]S(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R
M<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B3&ES=&$@;&5V
MZ6SM<N%S(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS
M9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("),:7-T82!F96QI<F%T:V]Z
MX7,@*'-U8G-C<FEB92DB"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H
M<#HU.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B3&ES=&$@
M;&5I<F%T:V]ZX7,@*'5N<W5B<V-R:6)E*2(*"B,Z(&%D;6EN+W-E<W-I;VYS
M+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS
M(&9A:6QE9#H@)7,B"FUS9W-T<B`B02!F96QH87-Z;N%L\VMA<&-S;VQA=&]K
M(&MI;&ES=.%ZX7-A(&YE;2!S:6ME<OQL=#H@)7,B"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R
M<R!F86EL960Z("5S(@IM<V=S='(@(D$@9F5L:&%S>F[A;/-K(&MI;&ES=.%Z
MX7-A(&YE;2!S:6ME<OQL=#H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L
M960N(@IM<V=S='(@(D$@9F5L:&%S>F[A;/-K(&MI;&ES=.%ZX7-A('1I;'1V
M82!V86XN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),
M:71E<F%T=7)E(@IM<V=S='(@(DER;V1A;&]M(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$T-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:71H=6%N
M:6$B"FUS9W-T<B`B3&ET=N%N:6$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O:6UA9V5S+G!H<#HW-PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R("),
M973V;'3I<RXN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,#`*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R(")(96QY:2!I9/4Z("(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-@IM<V=I9"`B3&]C86QE(&%N
M9"!4:6UE(@IM<V=S='(@(DYY96QV+"!DX71U;2P@:63U(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S(@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C4W"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO
M8VLO;65T87(N<&AP.C<R"FUS9VED("),;V-A=&EO;B(*;7-G<W1R(")(96QY
M(@H*(SH@;&]G:6XN<&AP.C$X.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP
M:'`Z,C`P('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*(SH@=&5M<&QA
M=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(D)E:F5L96YT:V5ZZ7,B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO
M9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B07H@96SU>O4@
M861A='-Z:6YK<F]N:7KA8VGS(&YA<&SSX6QL;VWA;GEA(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y-`IM<V=I9"`B3&]G(&]U="(*;7-G
M<W1R(")+:6IE;&5N=&ME>NES(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C4Y"FUS9VED("),;V=I;B(*;7-G<W1R(")"96IE;&5N=&ME>NES(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,`IM<V=I9"`B3&]G:6X@5&%S:W,B
M"FUS9W-T<B`B0F5J96QE;G1K97KI<W-E;"!K87!C<V]L871O<R!F96QA9&%T
M;VLB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3DU"FUS9VED("),;V=I;B!F
M86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E
M;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)!(&)E:F5L96YT:V5Z
MZ7,@;F5M('-I:V5R_&QT+"!M97)T(')O<W-Z(&9E;&AA<WINX6SS;F5V970@
M=F%G>2!J96QS>O-T(&%D;W1T("(*(FUE9RXB"@HC.B!L:6(O2&]R9&4O075T
M:"YP:'`Z.3DQ"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@(D$@8F5J
M96QE;G1K97KI<R!N96T@<VEK97+\;'0N(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$S-CD*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R(")(;W-S>OH@<WKV
M=F5G(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E
M(@IM<V=S='(@(E-Z97)E;&5M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DQO=R(*;7-G<W1R(")A;&%C<V]N
M>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T
M<B`B9_9R]F<@:VES8F5T^VLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I
M;B!L971T97)S(@IM<V=S='(@(FQA=&EN(&MI<V)E=/MK(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM
M<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(")K:7-B973[<R!R
M\VUA:2!S>N%M;VLB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30U(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B3'5X
M96UB=7)G(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P,2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")-32(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#,*;7-G:60@(DU/5$0B
M"FUS9W-T<B`B3F%P:2#\>F5N971E:R(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O
M;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")!>B!-4RU43D5&(&UE;&SI:VQE
M=&)E;B!N:6YC<R!A9&%T+B(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(MQ:
M14Y%5"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T<B`B36%K8?,B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,34S(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@
M(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*
M;7-G<W1R(")-86ME9/-N:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,34Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T
M<B`B36%D86=A<WIKX7(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*
M;7-G:60@(DUA9VEC(@IM<V=S='(@(E9A<N%Z<VQA="(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HX,PIM<V=I9"`B36%I;"(*;7-G<W1R("),979E
M;&5ZZ7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(T"FUS9VED
M(")-86EL($%D;6EN(@IM<V=S='(@(D5M86EL(&1O;6%I;B!K97IE;.ES(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(DQI;FL@:^ES
M>NUTZ7-E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDT"FUS9VED(")-86QA=VDB"FUS9W-T<B`B36%L87=I(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS
M9VED(")-86QA>7-I82(*;7-G<W1R(")-86QA:GII82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$T,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L
M9&EV97,B"FUS9W-T<B`B36%L9.UV+7-Z:6=E=&5K(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$U-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86QI
M(@IM<V=S='(@(DUA;&DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;'1A(@IM<V=S='(@(DWA;'1A
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT"FUS9VED("(B"B)-86YA
M9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I
M=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S
M92!C871E9V]R:65S+B(*;7-G<W1R("(B"B)!9&%T86ET(&MA=&5G\W)IX6MB
M82!S;W)O;&AA=&IA+B!%>F5K(&ET="!D969I;FGA;&AA=/-K+"!M\V1O<^UT
M:&%T\VLL("(*(G1O=N%B8N$@<WKM;F5K(')E;F1E;&AE=/5K(&AO>GKA:G5K
M+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,34V
M"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B36%P,C0@=.ER:^EP(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#<*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-S$*;7-G:60@(DUA
M<%%U97-T(&UA<"(*;7-G<W1R(")-87!1=65S="!TZ7)KZ7`B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T
M;W)E9"XB"FUS9W-T<B`B02!H;WIZX7)E;F1E;.ES96ME="!E;&UE;G1E='3\
M:RXB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B
M36%R8V@B"FUS9W-T<B`B;>%R8VEU<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*
M;7-G<W1R(")-87)G\R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T
M+G!H<#HT."!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G
M:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R(")!>B!/
M;'9A<V]T="]/;'9A<V%T;&%N(&IE;'IE=&5K(&AA<WINX6QA=&$B"@HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#D@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@
M9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R(")-X7,@
M:F5L>F5T96L@*'!L+B!&;VYT;W,O365G=N%L87-Z;VQT*2!H87-Z;N%L871A
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(DUA<G-H86QL
M+7-Z:6=E=&5K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(DUA<G1I
M;FEQ=64B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I
M9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(D5G>6WA<VYA:R!M96=F96QE
M;/4@;65Z]6LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B36%U<FET
MX6YI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(DUA=7)I=&EU<R(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED
M(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(DUA>&EMX6QI<R!R96YD
M96QK97KI<W)E(.%L;/,@<WKA;6QA]G-S>F5G+B(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P
M87)T<R!E>&-E961E9"XB"FUS9W-T<B`B07H@_'IE;F5T('3Z;"!S;VL@<NES
M>F+U;"#A;&PN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3,*;7-G:60@
M(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")!>B!E;&WZ;'0@
M,C0@\W)A(&UA>&EMX6QI<R!H]6WI<G/I:VQE=&4Z("(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S`U"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z
M("(*;7-G<W1R(")!>B!E;&WZ;'0@-B#S<F$@;6%X:6WA;&ES(&CU;>ER<^EK
M;&5T93H@(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M
M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B07H@]G-S>F5G]6]L9&%L
M(&)L;VMK:F%I;F%K(&UA>&EMX6QI<R!S>N%M82(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HY,#(@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,C$@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$R-#,*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@
M(DUA>&EMX6QI<R!H;W-S>B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#8@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B;>%J=7,B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C4S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-
M87EO='1E(@IM<V=S='(@(DUA>6]T=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(D]R=F]S='5D;VWA
M;GDB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS
M9VED(")-96UB97)S(@IM<V=S='(@(E1A9V]K(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,X,@IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R(")!(&UE
M;OP@;65G:F5L96[I<V4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS
M9W-T<B`B0V5L;.%K(&5G>6)E;VQV87-Z=.%S82(*"B,Z(&QI8B](;W)D92].
M;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T
M<B`BW'IE;F5T(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR,38*
M;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T
M:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF
M:65D+B(*;7-G<W1R("(B"B)!(&1I9VETX6QI<V%N(&%LX>UR="#\>F5N970@
M:&ET96QE<RP@9&4@87H@86SA[7+S('1A;OIS[71VX6YYX70@;F5M('-I:V5R
M_&QT("(*(F5L;&5N]7)I>FYI+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$P"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S
M='(@(DQE:N%R="!A>B#\>F5N970@Z7)VZ6YY97-SZ6=E+B(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8P,@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(R-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(V,`IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(D%Z(/QZ96YE="!T
M[7!U<V$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R
M(%=E871H97(B"FUS9W-T<B`B365T87(@:63U:N%RX7-J96QE;G3I<R(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(D$@365T87(@8FQO:VL@;F5M(.%L;"!R
M96YD96QK97KI<W)E+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS
M9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA
M=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("(B"B)!($UE=&%R(&)L;VMK(&YE;2#A;&P@<F5N9&5L:V5ZZ7-R92X@02!R
MZ7-Z;&5T96L@82!R96YD<WIE<F=A>F1A('-ZX6WA<F$@(@HB:^ES>OQL]2!N
M87!L\V;A:FQB82!K97+\;'1E:RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,34S"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N
M(@IM<V=S='(@(D$@365T87)$0B!N96T@Z7)H973U(&5L+B(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8W(&QI8B](;W)D92]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`B3?-D<WIE
M<B(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HX,2!L:6(O2&]R9&4O
M4E!#+W-O87`N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@
M7"(E<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(D$H>BD@7"(E<UPB(&WS
M9'-Z97(@9&5F:6YIX6QA=&QA;B(*"B,Z(&QI8B](;W)D92]24$,O<F5S="YP
M:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D
M+B!#86QL960@;65T:&]D.B`E<R(*;7-G<W1R(")!(&WS9'-Z97(@9&5F:6YI
MX6QA=&QA;BX@02!M96=H[79O='0@;?-D<WIE<CH@)7,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HX
M,@IM<V=I9"`B365T<FEC(@IM<V=S='(@(DUE=')I:W5S(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$V-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-
M97AI8V\B"FUS9W-T<B`B365X:6OS(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C@U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E
M9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B36EK<F]NZ7II86D@4WKV=F5T
M<^EG:2#!;&QA;6]K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<V"FUS9VED(")-:61D;&4B"FUS9W-T<B`B:_9Z
MZ7`B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G
M:60@(DUI;64@5'EP92(*;7-G<W1R(")-24U%('3M<'5S(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS,3<*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U
M<G,Z("(*;7-G<W1R(")!>B!E;&WZ;'0@,C0@\W)A(&QE9V%L86-S;VYY86)B
M(&CU;>ER<^EK;&5T93H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#D*
M;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(D%Z(&5L
M;?IL="`V(/-R82!L96=A;&%C<V]N>6%B8B!H]6WI<G/I:VQE=&4Z("(*"B,Z
M(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P
M87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R(")-Z6<@
M;F5M('1E;'0@96P@82!M:6YI;>%L:7,@:63U(&$@:F5L<WKS(&UE9W;A;'1O
M>G1A=.%SX6AO>B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,S4*;7-G:60@(DUI<G)O<B(*;7-G<W1R(")4_&MR]GKI<R`H:F]B
M8B]B86PI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-
M:7-C96QL86YE;W5S(@IM<V=S='(@(E9E9WEE<R(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS-#`*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(U
M,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+B(*
M;7-G<W1R(")(:>%N>7II:R!A($A45%!?4F5Q=65S="!014%2(&-S;VUA9RXB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-:7-S
M:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO
M=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS
M9W-T<B`B(@HB2V]N9FEG=7+A8VGS('-Z_&MSZ6=E<RX@17IT(&UO<W0@:V5L
M;"!LZ71R96AO>FYI82P@:&$@:&%S>F[A;&YI(&%K87)J82!A>B`B"B)A;&MA
M;&UA>N%S="XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R(")(:>%N
M>7II:R!A>B#\>F5N970@87IO;F]S[73S:F$N(@H*(SH@;&EB+TYE="]335,O
M=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U
M:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B2&GA;GEZ:6L@82!-
M86EL(%!%05(@8W-O;6%G+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S
M='(@(DAIX6YY>FEK(&$@9F5L:&%S>F[A;/-K87!C<V]L870@87IO;F]S[73S
M:F$@*'-E<W-I;VX@240I+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(DCI(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<V"FUS9VED(")-;V)I;&4@36%I
M;"(*;7-G<W1R("),979E;&5ZZ7,@;6]B:6QT96QE9F]N<O-L(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DUO
M9&5R871E(@IM<V=S='(@(DOV>F5P97,B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<F%R+G!H<#HV-B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H
M<#HW,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I
M9"`B36]D:69I960@1&%T92(*;7-G<W1R(")!(&WS9&]S[73A<R!DX71U;6$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B07H@55),(&WS
M9&]S[73A<V$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8W-`IM
M<V=I9"`B36]D=6QU<R(*;7-G<W1R(")-;V1U;'5S(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$U,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD
M;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R(")-;VQD;W9A:2!+]GITX7)S87/A
M9R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#D@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$U,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S='(@(DUO;F%C;R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$U,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B
M36]N9V]L:6$B"FUS9W-T<B`B36]N9_-L:6$B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C4X.`IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B2/-N
M87`@Z7,@Z78B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4W"FUS
M9VED(")-;VYT:&QY(@IM<V=S='(@(FAA=F]N=&$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,38Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S
M97)R870B"FUS9W-T<B`B36]N='-E<G)A="(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S
M97,B"FUS9W-T<B`B2&]L9&;A>FES;VLB"@HC.B!L:6(O1FEL92]#4U8N<&AP
M.C$Y-B!L:6(O1FEL92]#4U8N<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C
M=&5D("5D+B(*;7-G<W1R(")!("5D+B!S;W)B86X@=/9B8B!M97KU('9O;'0L
M(&UI;G0@82!VX7)T("5D+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R(")-
M87)O:VOS(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R(")4]F)B;GEI<F4@
M9&5R_&QT(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B5/9B8FYY:7)E
M(&)O<G5L="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B5/9B8FYY:7)E
M(&YA<&]S(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HV-#@*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R(")V:6=Y_&L@;&4B"@HC
M.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U,@IM<V=I
M9"`B36]V92!,969T(@IM<V=S='(@(G9I9WG\:R!B86QR82(*"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4V"FUS9VED(")-;W9E
M(%)I9VAT(@IM<V=S='(@(G9I9WG\:R!J;V)B<F$B"@HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T-`IM<V=I9"`B36]V92!5<"(*
M;7-G<W1R(")V:6=Y_&L@9O9L(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4R-@IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(G9I
M9WG\:R!L92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HU,C4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM
M<V=I9"`B36]V92!U<"(*;7-G<W1R(")V:6=Y_&L@9O9L(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$V."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-
M;WIA;6)I<75E(@IM<V=S='(@(DUO>F%M8FEK(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(Q.#@*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T
M<R(*;7-G<W1R(")4]F)B<WII;G3[(&QE9_9R9/QL]2!L:7-TX6LB"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U.`IM<V=I9"`B
M375L=&EM87`@54L@;6%P(@IM<V=S='(@(DUU;'1I;6%P($YA9WDM0G)I=&%N
M;FEA('3I<FOI<"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C0V"FUS9VED
M(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B5/9B8G-Z]G+V<R!VX6QA
M<WITX7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`R"FUS9VED
M(")->2!!8V-O=6YT(@IM<V=S='(@(D)E:F5L96YT:V5ZZ7-I(&)EX6QL[73A
M<V]K(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED(")->2!!
M8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(D)E:F5L96YT:V5ZZ7-I(&%D
M871A:6TB"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C0U"FUS9VED
M(")->2!0;W)T86PB"FUS9W-T<B`B4V%JX70@]G-S>F5G>O4@;VQD86QA;2(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HT,PIM<V=I9"`B37D@4&]R
M=&%L($QA>6]U="(*;7-G<W1R(")386KA="#V<W-Z96=Z]2!O;&1A;&%M('1E
M<G9E>NES92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-34@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R(")-:6%N;6%R(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*
M;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R(").14TL(&YE;2!E
M9WEE>F5M(&)E;&4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G
M<W1R(").Z78B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B3F%M[6)I82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$U.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B3F%U<G4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3<W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L
M(@IM<V=S='(@(DYE<.%L(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").971H97)L86YD<R(*;7-G<W1R
M(")(;VQL86YD:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS
M9W-T<B`B2&]L;&%N9"!!;G1I;&SA:R(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R
M(").971S8V%P92!BX7II<RU54DPB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB
M"FUS9W-T<B`B3F5T<V-A<&4@=&%N^G/M=';A;GEK:6%DX7-I:F]G*$-!*2UV
M:7-S>F%V;V[A<VD@55),(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU.#8*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B
M3F5T<V-A<&4@=&%N^G/M=';A;GEF96QH87-Z;N%LX7-I(&ERX6YY96QV(%52
M3"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").
M971S8V%P92!296YE=V%L(%523"(*;7-G<W1R(").971S8V%P92!T86[Z<^UT
M=N%N>6UE9_IJ[73A<VD@55),(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU.#,*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S
M='(@(DYE='-C87!E('1A;OIS[71VX6YY=FES<WIA=F]NX7-I(%523"(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P
M92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B3F5T<V-A<&4@4U-,('-Z97)V
M97)NZ78B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X.`IM<V=I
M9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R(").971S
M8V%P92!T86[Z<^UT=N%N>2!M96=J96=Y>NES(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E
M('1Y<&4B"FUS9W-T<B`B3F5T<V-A<&4@=&%N^G/M=';A;GET[7!U<R(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3,*;7-G:60@(DYE='=O<FLB
M"FUS9W-T<B`B2.%L\WIA="(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C0R-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.3`*;7-G:60@(DYE=F5R(@IM<V=S='(@(G-O:&$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<P(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*
M;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`BVFHM2V%L963S;FEA(@H*
M(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G
M:60@(DYE=R!#871E9V]R>2(*;7-G<W1R("+::B!K871E9_-R:6$B"@HC.B!L
M:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HX,2!L:6(O2&]R9&4O
M5&5X="]&:6QT97(O96UA:6QS+G!H<#HX-PHC.B!L:6(O2&]R9&4O5&5X="]&
M:6QT97(O96UA:6QS+G!H<#HY-R!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA
M:6QS+G!H<#HQ,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@
M=&\@)7,B"FUS9W-T<B`BVFH@;&5VZ6P@)7,@8^UM<F4B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C
M:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(OIJ:&]L
M9"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G
M:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(MIJ(&9E;&AA
M<WINX6SS;NEV("AO<&-I;V[A;&ES*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ.#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3F5W(%IE86QA;F0B
M"FUS9W-T<B`BVFHM6NEL86YD(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C,W"FUS9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`BVFH@:F5L
M<WKS(@H*(SH@;&EB+TAO<F1E+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*
M;7-G<W1R(")!>B#Z:B!J96QS>O,@Z7)VZ6YY97-SZ6=E(&5K:V]R(&KA<B!L
M93H@)7@N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS
M9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R(")!(&UE
M9V%D;W1T(/IJ(&IE;'-Z879A:R!N96T@96=Y97IN96LN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W
M('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R("+::B!A8FQA:R`H_')E<RDB"@HC
M.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Y,0IM<V=I9"`B
M3F5W<R(*;7-G<W1R(")([7)E:R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS,#<*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B2.UR8W-O<&]R
M=&]K(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA
M=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G
M:60@(DYE>'0B"FUS9W-T<B`B2_9V971K97KU(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C(W"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(DOV=F5T
M:V5Z]2`T(&;A>FES(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-C8@
M;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-S`*;7-G:60@(DYE>'0@;W!T:6]N
M<R(*;7-G<W1R(")+]G9E=&ME>O4@;W!C:?-K(@H*(SH@;&EB+TAO<F1E+U5)
M+U!A9V5R+G!H<#HQ,#,*;7-G:60@(DYE>'0^(@IM<V=S='(@(DOV=F5T:V5Z
M]3XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<T(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R(").:6-A<F%G=6$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Q(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*
M;7-G:60@(DYI9V5R(@IM<V=S='(@(DYI9V5R(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$W,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA
M(@IM<V=S='(@(DYI9^ER:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S8Y"FUS9VED(").:6=H="(*;7-G<W1R("+I:G-Z86MA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS
M9VED(").:75E(@IM<V=S='(@(DYI=64B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.38V"FUS9VED(").;R(*;7-G<W1R(").96TB
M"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@
M(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F
M97)E;F-E<R!F;W(N(@IM<V=S='(@(B(*(DYI;F-S(')E;F1E;&ME>NES<F4@
MX6QL\R!K;VYF:6=U<N%C:?,L(&%M:6AE>B!KZ7!E<W0@82!K_&SV;F)SZ6=E
M:V5T(&UE9R`B"B)L96AE=&YE(&UU=&%T;FDN(@H*(SH@;&EB+U9&4R])4T]7
M<FET97(N<&AP.C$P-@IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O
M<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B3FEN8W,@;&5H973U<^EG
M($E33R#A;&QO;>%N>6]K(&SI=')E:&]ZX7/A<F$N(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E
M;7!L871E+B(*;7-G<W1R(")(:>%N>7II:R!A(&OV=&5G96QT(&9E;&1O;&=O
M>N%S:&]Z('-Z_&MSZ6=E<R!M:6YT82`H8F%T8V@@=&5M<&QA=&4I+B(*"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`Q"B,Z(&QI
M8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,S@U"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#`W"FUS9VED(").;R!B
M;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R
M(")!(&OM=N%N="!H96QY96X@;FEN8W,@8FQO:VLB"@HC.B!L:6(O2&]R9&4O
M075T:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V
M:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B07H@34-!
M3"!F96QH87-Z;N%L\V%Z;VYO<^UTX7-H;WH@;FEN8W,@;65G861V82!A(&YA
M<'3A<B!N979E+B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED
M(").;R!C:&%N9V4N(@IM<V=S='(@(DYI;F-S(';A;'1O>N%S+B(*"B,Z(&QI
M8B](;W)D92]097)M<R]522YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C
M86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R(")%:&AE
M>B!A(&IO9V]S=6QT<^%G:&]Z(&YE;2!H;WIH873S(&SI=')E(&IO9V]S=6QT
M<^%G:2!A;&-S;W!O<G0N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-CD@;&EB+TAO
M<F1E+G!H<#HU,#@@;&EB+TAO<F1E+U5T:6PN<&AP.C<V.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@)7,N(@IM<V=S='(@(DAIX6YY;WIN86L@82!K;VYF:6=U<N%C
M:?-S(&%D871O:R`E<RUH97HN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@U-0IM
M<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R($944"!61E,N(@IM<V=S='(@(D%Z($944"!61E,@;FEN8W,@:V]N9FEG
M=7+A;'9A+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HV-S(*;7-G:60@(DYO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93
M+B(*;7-G<W1R(")!>B!344P@5D93(&YI;F-S(&MO;F9I9W5RX6QV82XB"@HC
M.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW,C4*;7-G:60@(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N
M(@IM<V=S='(@(D%Z(%-13"U&:6QE(%9&4R!N:6YC<R!K;VYF:6=U<N%L=F$N
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G
M:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R(")!>B#6;B!S>N%M;.%JX6X@
M96QF;V=Y;W1T(&$@<F5N9&5L:V5ZZ7-R92#A;&SS(/9S<WIE9RXB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D
M97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B3FEN8W,@8^UM>NES+B(*
M"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,C`*;7-G:60@(DYO(&9I;&4@
M=7!L;V%D960B"FUS9W-T<B`B02!S>F5R=F5R<F4@;F5M('3V;'3U9/9T="!F
M96P@<V5M;6EL>65N(.%L;&]MX6YY(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N
M<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B07H@:6MO
M;F]K(&YE;2!T86SA;&AA=/-K+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ,38@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3,P"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N
M(@IM<V=S='(@(DYI;F-S(&UE9V%D=F$@82!H96QY+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G:60@(DYO(&QO8V%T:6]N('!R
M;W9I9&5D+B(*;7-G<W1R(").:6YC<R!M96=A9'9A(&$@:&5L>2XB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M
M97-S86=E('-U<'!L:65D+B(*;7-G<W1R(")!>B#\>F5N970@_')E<RXB"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").
M;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B3FEN8W,@;65G861V82!A(&[I
M=BXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS
M9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R(").:6YC<R!M96=A
M9'9A(&$@<WKA;2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G
M:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(").92!L96=Y96X@
M;65G8F]T<N%N:V]Z=&%T\R!I9.EZ970B"@HC.B!L:6(O2&]R9&4O075T:"]H
M='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A4
M5%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYI;F-S(&IE;'-Z\R!M96=A
M9'9A(&$@2%144"!A;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S[73A<VAO>BXB
M"@HC.B!L:6(O2&]R9&4O075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R(").:6YC<R!J96QS>O,@;65G861V82!A>B!)34%0(&%L87#Z(&9E;&AA
M<WINX6SS:2!A>F]N;W/M=.%S:&]Z+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR
M8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R
M8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYI;F-S(&IE;'-Z\R!M
M96=A9'9A(&$@2V5R8F5R;W,@86QA</H@9F5L:&%S>F[A;/-I(&%Z;VYO<^UT
MX7-H;WHN(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z-S<@;&EB+TAO
M<F1E+T%U=&@O;&]G:6XN<&AP.C@T"B,Z(&QI8B](;W)D92]!=71H+W!A;2YP
M:'`Z-S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3FEN8W,@:F5L<WKS(&UE9V%D=F$@
M82!,;V=I;B!A;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S[73A<VAO>BXB"@HC
M.B!L:6(O2&]R9&4O075T:"]P87-S=V0N<&AP.C$S-0IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B3FEN8W,@:F5L<WKS(&UE9V%D=F$@82!005-35T0@86QA</H@9F5L
M:&%S>F[A;/-I(&%Z;VYO<^UTX7-H;WHN(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--
M0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3FEN8W,@:F5L<WKS(&UE9V%D
M=F$@87H@4TU"(&%L87#Z(&9E;&AA<WINX6SS:2!A>F]N;W/M=.%S:&]Z+B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(X-PIM<V=I9"`B(@HB
M3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/
M<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+
M0U,@,3(@9&%T82XB"FUS9W-T<B`B(@HB3FEN8W,@;65G861V82!A>B!/<&5N
M4U-,('!R;V=R86T@96SI<NES:2#Z='9O;F%L82X@07H@3W!E;E-33"!P<F]G
M<F%M("(*(G-Z_&MSZ6=E<R!A(%!+0U,@,3(@861A=&]K(&ME>F5LZ7/I:&5Z
M+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G
M:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`B3FEN8W,@^FH@8F5J
M96QE;G1K97KI<VD@:6?I;GDN(@H*(SH@;&EB+U9&4RYP:'`Z-S8V"FUS9VED
M(").;R!Q=6]T82!S970N(@IM<V=S='(@(DYI;F-S(&MV\W1A(&)EX6QL[71V
M82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*;7-G<W1R(").92!L96=Y96YE
M:R!V;VYA;&%K('-E:&]L+B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#@R"FUS
M9VED(").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G<W1R(").:6YC<R!D
M969I;FGA;'9A(&5L=N%L87-Z=/,@:V%R86MT97(N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`IM<V=I9"`B
M3F\@<VED97,B"FUS9W-T<B`B3F4@;&5G>65N(&ME<F5T(@H*(SH@;&EB+U9&
M4R]S;6(N<&AP.C4X-PIM<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(DYI
M;F-S(&EL>65N(&;A:FPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3(V"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L
M92!F;W(@8V%C:&4N(@IM<V=S='(@(DYI;F-S(&ED96EG;&5N97,@X6QL;VWA
M;GEO:R!TX7)O;.%SX7)A('-Z;VQGX6SS(&%L:_9N>79TX7(N(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,2!L:6(O3F5T+U--4R]W
M:6Y?:'1T<"YP:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S
M<W=O<F0@<V5N="XB"FUS9W-T<B`B2&GA;GEZ:6L@82!F96QH87-Z;N%L\V[I
M=B#I<R]V86=Y(&$@:F5L<WKS+B(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C
M+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM
M<V=S='(@(D$@=FES<WIA:V%P;W1T(&%D871O:R!N96T@Z7)VZ6YY97,@6$U,
M(&%D871O:R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HY-S0@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX-`HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DU"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#$R"FUS9VED(").
M;R!V86QU97,B"FUS9W-T<B`B3FEN8W,@861A="(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I
M9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R(").:6YC<R!MZ6<@:V]N9FEG=7+A8VGS+"!G96YE<N%L:F]N
M(&5G>65T+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@
M(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E
M;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DYI;F-S(&WI9R!K;VYF
M:6=U<N%C:?-J82P@9V5N97+A;&IO;B!E9WEE="XB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HT,C<@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I
M='ES96QE8W0N:6YC.CDS"FUS9VED(").;VYE(@IM<V=S='(@(FYI;F-S(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM
M<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R(")N:6YC<R!M96=A
M9'9A("AL96=Y96X@86QA<.ER=&5L;65Z971T*2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DR"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G
M<W1R(")N;W)D:6MU<R`H25-/+3@X-3DM,3`I(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$W,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK
M($ES;&%N9"(*;7-G<W1R(").;W)F;VQK+7-Z:6=E="(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO
M<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`BR7-Z86MI(&;I;'1E:V4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*
M;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("+)<WIA
M:VDM36%R:6%N82US>FEG971E:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S='(@
M(DYO<G;I9VEA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#$*
M;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R(").96T@:^ES]6)B(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!"969O<F4B
M"FUS9W-T<B`B3F5M(&MO<N%B8F%N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HT
M,34*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R(").96T@86QK]FYY
M=G3A<B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HV,R!L:6(O5D93+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@T"B,Z(&QI8B]61E,O
M25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.34*(SH@;&EB+U9&
M4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&QI8B]6
M1E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B
M3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R(")!('!R;V=R86UN86L@97H@82!R
MZ7-Z92!MZ6<@;FEN8W,@;65G=F%L\W/M='9A+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B
M"FUS9W-T<B`B3FEN8W,@8F7A;&SM='9A(@H*(SH@;&EB+U9&4RYP:'`Z,3DS
M(&QI8B]61E,N<&AP.C(P."!L:6(O5D93+G!H<#HR,S0@;&EB+U9&4RYP:'`Z
M,C4R"B,Z(&QI8B]61E,N<&AP.C(V.2!L:6(O5D93+G!H<#HR.#4@;&EB+U9&
M4RYP:'`Z,S`Q(&QI8B]61E,N<&AP.C,Q-@HC.B!L:6(O5D93+G!H<#HS,S,@
M;&EB+U9&4RYP:'`Z,S8V(&QI8B]61E,N<&AP.C0R-B!L:6(O5D93+G!H<#HU
M,#4*(SH@;&EB+U9&4RYP:'`Z-3<T(&QI8B]61E,N<&AP.C4Y,2!L:6(O5D93
M+G!H<#HV-CD*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#4@
M;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-C`*(SH@;&EB+TAO<F1E
M+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S4@;&EB+TAO<F1E+U-E<W-I;VY(86YD
M;&5R+G!H<#HQ.#D*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HR
M,S8*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(DYE;2!TX6UO9V%T
M;W1T+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T
M(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#4X"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ.#`*;7-G:60@(DYO=&5S(@IM<V=S='(@(D9E;&IE9WEZ
MZ7-E:R(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I
M9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(DYI;F-S
M(&+V;F?I<WIH973U(&%D870L('3I<FIE;B!V:7-S>F$N(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S
M='(@(FYO=F5M8F5R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-3`*;7-G
M:60@(DYU;6)E<B(*;7-G<W1R(")3>N%M(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$T,CD*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@
M(DMA<F%K=&5R96L@<WKA;6$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W
M,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R-R!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,30T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B3W-Z;&]P
M;VL@<WKA;6$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W,2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,30R-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I
M9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B4V]R;VL@<WKA;6$B"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB
M97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO
M;B!L:7-T+B(*;7-G<W1R(")!(&OV<FQE=NEL;&ES=&$@;?-D;W/M=.%SX6AO
M>B!N96T@861O='0@;65G('-ZX6UO:V%T+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`B
M3TLB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S
M"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B3V)J96MT=6TB"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B
M"FUS9W-T<B`B07H@;V)J96MT=6T@;.ET<F5H;WKS:F$B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3$P.`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B3VMTX6QI
M<R!S>N%M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G
M:60@(D]C=&]B97(B"FUS9W-T<B`B;VMT\V)E<B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B
M4WK[<NES(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R.`IM<V=I
M9"`B3V9F:6-E(@IM<V=S='(@(DAI=F%T86PO;75N:V%H96QY(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE
M=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(D$@<NEG
M:2#I<R!A>B#Z:B!J96QS>O-N86L@:_QL]FYB]GIN:64@:V5L;"XB"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*;7-G:60@(D]L9"!P87-S
M=V]R9"(*;7-G<W1R(")!('+I9VD@:F5L<WKS(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T
M(&-O<G)E8W0N(@IM<V=S='(@(D$@<NEG:2!J96QS>O,@;F5M(&UE9V9E;&5L
M]2XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Q(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B3VWA;B(*"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E
M<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB"FUS9W-T<B`B0W-A:R!A
M>B!)34%0('-Z97)V97)E:R!TX6UO9V%T:N%K(&$@;6%P<.%K(&UE9V]S>G3A
M<^%T+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL
M>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B0W-A:R!M96=B;W1RX6YK
M;WIT873S(&EDZ7IE="!L96=Y96XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3@U-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW-0IM<V=I9"`B3VYL>2!O;F4@
M96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R(")#<V%K(&5G>2!E;6%I
M;"!C[6T@861H873S(&UE9RXB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP
M:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI
M;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E
M<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*(D-S86L@82!T=6QA
M:F1O;F]S('9A9WD@82!R96YD<WIE<F=A>F1A(';A;'1O>G1A=&AA=&IA(&UE
M9R!E9WD@:_9Z]G,@(@HB=.%R=&5R_&QE="!T=6QA:F1O;F]SX70@=F%G>2!E
M;.ERZ7-I(&IO9V]S=6QT<^%G86ET(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP
M:'`Z,SD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-#`*;7-G:60@(D]P96X@:6X@
M82!N97<@=VEN9&]W(@IM<V=S='(@(DYY:7-S=6L@;65G(/IJ(&%B;&%K8F%N
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P
M96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N
M960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*(D]P96Y34TP@:&EB83H@3F5M
M('-I:V5R_&QT(&MI;GEE<FYI(&%Z(&%D871O:V%T(&%Z(&%LX>UR="!3+TU)
M344@<NES>F+U;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN
M(&$@;F5W('=I;F1O=R(*;7-G<W1R(").>6ES<W5K(&UE9R!E>G0@82!C[6UE
M="!E9WD@^FH@86)L86MB86XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B3W!E<N%C:?-S
M(')E;F1S>F5R(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U
M,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")/<&-I\VLB"@HC.B!S97)V:6-E
M<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B)7,@
M8F7A;&SM=.%S86DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B4V]R
M<WKA;6]S(&9E;'-O<F]LX7,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(E-Z97)V97IE
M="(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")/
M<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@(E-Z97)V97IE=&D@96=Y<^EG
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S-`IM<V=I9"`B3W)G
M86YI>FEN9R(*;7-G<W1R(")-=6YK87-Z97)V97KI<R(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T
M96UP;&%T92(*;7-G<W1R(")!>B!A;&MA;&UA>N%S(&5R961E=&D@<V%B;&]N
M:F$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(B5S
M(&5R961E=&D@<V%B;&]N:F%I.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R
M(@IM<V=S='(@(D5G>>EB(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDY
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#D*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(U"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T
M-`IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B16=YZ6(@:6YF
M;W)MX6-I\R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G
M:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(D$@='5L86ID;VYO<R!J
M;V=O<W5L='/A9V%I(@H*(SH@;&EB+TAO<F1E+T%U=&@O<&%M+G!H<#HW.0IM
M<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(D$@4$%-(&9E;&AA<WINX6SS87IO;F]S[73A<R!N96T@X6QL(')E
M;F1E;&ME>NES<F4N(@H*(SH@;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H
M<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R(")014%2
M.CI-86EL(&%L<F5N9'-Z97(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HQ,C<V"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B
M4$=0(&1I9VETX6QI<R!A;.'M<N%S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z,3,R,@IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@
M(E!'4"UV96P@=&ET:V]S[71O='0@861A="(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C$S-S0*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@
M(E!'4"!N>6EL=N%N;W,@:W5L8W,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HQ,S4V"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM
M<V=S='(@(E!'4"UV96P@86SA[7)T+W1I=&MO<^UT;W1T(&%D870B"@HC.B!A
M9&UI;B]P:'!S:&5L;"YP:'`Z-C@*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@
M(E!(4"!K\V0B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(
M4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R
M(")$Z6QU=.%N+V5S=&4@9WEE;F=E(&5S]2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!286EN(@IM<V=S
M='(@(D3I;'5TX6X@97/U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B1.EL
M=73A;B]E<W1E('KA<&]R;VLB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R(")$Z6QU
M=.%N+V5S=&4@:&%V87KA<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T
M<B`B1.EL=73A;B]E<W1E(&CS>N%P;W)O:R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")032!3=6XB"FUS9W-T
M<B`B1.EL=73A;B!N87!S_'3I<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R
M(")$Z6QU=.%N+V5S=&4@>FEV871A<F]K(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C(W-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B
M"FUS9W-T<B`B2&GA;GEZ:6L@82!03U-)6"!B]7;M=.ES(@H*(SH@;&EB+V%P
M:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*
M;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B8F5L<_4@;6%R9_,B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3@W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@
M(E!A:VES=&%N(@IM<V=S='(@(E!A:VES>G3A;B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W
M,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U
M(@IM<V=S='(@(E!A;&%U(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET
M;W)Y+"!/8V-U<&EE9"(*;7-G<W1R(")086QE<WIT:6X@5&5R_&QE="`H;65G
M<WKA;&QT*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#(@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@(E!A;F%M82(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#4@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$W-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM
M<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R(")0X7!U82#::BU'=6EN
M96$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DU(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R(")087)A9W5A>2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED
M(")087)T;'D@0VQO=61Y(@IM<V=S='(@(DWI<G/I:V5L=&5N(&)O<G5L="(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M.#`@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,C(*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4S-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$Y.0HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,34Q('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHT,R!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#(U"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")*96QS>O,B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H
M86YG960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")!(&IE;'-Z\W0@<VEK97)E
M<V5N(&UE9W;A;'1O>G1A='1U:RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C$S,C,*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R
M(").96T@;65G9F5L96SU(&IE;'-Z\R(*"B,Z(&QI8B](;W)D92]!=71H+W)A
M9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$
M2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")!(%)!1$E54R!F96QH87-Z
M;N%L\V%Z;VYO<^UTX7-H;WH@:F5L<WKS('-Z_&MSZ6=E<RXB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C`U-PIM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF
M:7)M871I;VXB"FUS9W-T<B`B2F5L<WKS(&UE9V5R]7/M=.ES<V5L(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED(")087-S=V]R
M9#HB"FUS9W-T<B`B2F5L<WKS.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(DIE;'-Z\SH@
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&QI8B](;W)D92]&;W)M+G!H<#HR
M,#,X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G
M:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")!(&IE;'-Z879A
M:VYA:R!E9WEE>FYI_&L@:V5L;"XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3$Y('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B0F5I;&QE<WITZ7,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS
M9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R(")"96EL;&5S>G3A
M<R!A(';A9_-A<WIT86QR\VPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@(MIT=F]N
M86PB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B
M4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R("+::B!F96QH87-Z;N%L\VYA:R!B
M96IE;&5N=&ME>F5T=&5K.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(D5M8F5R96LB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R
M8V5N="(*;7-G<W1R(")S>N%Z86SI:R(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT
M96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B2V%R8F%N=&%R=.%S:2!F96QA
M9&%T;VL@=NEG<F5H86ITX7-A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0Q,`IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N
M(&QO9VEN/R(*;7-G<W1R(")"96IE;&5N=&ME>NES:V]R(&AA:G1S=6L@=NEG
M<F4@82!K87)B86YT87)TX7-I(&9E;&%D871O:V%T/R(*"B,Z(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,34V"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@
M(DIO9V]S=6QT<^%G(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L
M971E9"XB"FUS9W-T<B`B02AZ*2!<(B5S7"(@:F]G;W-U;'1SX6=O="!N96T@
M=/9R]FQT_&LN(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C4Y,`IM<V=I9"`B4&5R
M;6ES<VEO;B!$96YI960B"FUS9W-T<B`BUFYN96L@;FEN8W,@96AH97H@96QE
M9V5N9/4@:F]G;W-U;'1SX6=A(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HQ-C$@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@(E!E<FUI
M<W-I;VYS(@IM<V=S='(@(DIO9V]S=6QT<^%G;VLB"@HC.B!A9&UI;B]P97)M
M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z
M(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C4X"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G
M<W1R(")*;V=O<W5L='/A9R!A9&UI;FES>G1RX6-I\R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV.`IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB
M"FUS9W-T<B`B4WIE;>EL>65S(&%D871O:R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G
M<W1R(")097)U(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED
M(")0971S(@IM<V=S='(@(L%L;&%T:V5D=F5N8V5K(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$X-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL
M:7!P:6YE<R(*;7-G<W1R(")&_&SV<"US>FEG971E:R(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G
M<W1R(")496QE9F]N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X
M,`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(D;I;GEKZ7!G86SI<FEA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`IM
M<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B4&ET8V%I<FXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX
M96QS(@IM<V=S='(@(G!I>&5L(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(DOV>FAE;'EE:R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R
M(")+871T:6YT<V]N('9A;&%M96QY:6L@8V5L;.%R82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I
M9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI
M<R!E;&5M96YT.B(*;7-G<W1R(")":7IT;W-A;B!T]G+V;&YI(&%K87)J82!E
M>G0@87H@96QE;65T.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@
M=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R
M(")+Z7)E;2!E<O5S[71S92!M96<L(&AO9WD@=F%L\V)A;B!T]G+V;&YI(&OM
M=N%N:F$@97IT(&%Z(&5L96UE="XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C4V-@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB
M"FUS9W-T<B`B2^ER96T@861J;VX@;65G(&5G>2!H\VYA<&]T(.ES(&5G>2#I
M=F5T+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C$R"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W
M(&-A=&5G;W)Y.B(*;7-G<W1R(")+Z7)E;2!A9&IA(&UE9R!A>B#Z:B!K871E
M9_-R:6$@;F5VZ70Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,#4*;7-G
M:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@
M(DOI<F5M('9A;/-S($E0(&/M;65T(&%D:F]N(&UE9RXB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C8T-`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@
M9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB
M"FUS9W-T<B`B2^ER96T@=F%L\W,@9.%T=6UO="!A9&IO;B!M96<L(&5L;&5N
M]7)I>GIE(&$@:/-N87`@;F%P:F%I="XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C0U,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS
M9W-T<B`B2^ER96T@=F%L\W,@9.%T=6UO="!A9&IO;B!M96<N(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R
M;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R(")+Z7)E
M;2!R]G9I9&5N(.UR:F$@;&4@82!P<F]B;.EM82!LZ6YY96?I="XB"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA
M;64@86YD('!A<W-W;W)D(@IM<V=S='(@(DOI<F5M(&%D:F$@;65G(&$@8F5J
M96QE;G1K97KI<VD@;F5VZ70@Z7,@:F5L<WIA=N%T(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@
M9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS
M('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"B)+Z7)E;2!O;'9A
M<W-A(&5L(&$@:_9V971K97KU('-Z]G9E9V5T+B!!(')E;F1S>F5R(&AA<WIN
MX6QA=.%N86L@9F5L=.ET96QE:70@(@HB96P@2T5,3"!F;V=A9&YI82XB"@HC
M.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I
M9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R
M(")+Z7)E;2!A9&IA(&UE9R!A>B#Z:B!K871E9_-R:6$@;F5VZ70Z(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS
M9VED(")0;VQA;F0B"FUS9W-T<B`B3&5N9WEE;&]R<WKA9R(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B
M4&]L:71I:V$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@Y"FUS
M9VED(")0;VQL<R(*;7-G<W1R(")3>F%V87KA<V]K(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Y,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R
M='5G86PB"FUS9W-T<B`B4&]R='5GX6QI82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B
M4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R(")!(&OI<"!E;&AE
M;'EE>NES92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM
M<V=S='(@(D$@=.%B;.%Z870@96QH96QY97KI<V4B"@HC.B!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3$@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@
M96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B(@HB2_9Z=F5T;&5N(&QE=NEL
M:_QL9.ES(&5B8F4@82!M87!PX6)A("A)34%0(&YE;2!M:6YD:6<@=F5S>FD@
M9FEG>65L96UB92DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,R!L:6(O
M0FQO8VLO;65T87(N<&AP.C(W.`HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C
M:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R(")!>B!E
M;&WZ;'0@)7,@\W)A(&-S87!A9.EK;65N;GEI<^EG93H@(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-PIM<V=I9"`B4')E8VEP:71A=&EO
M;CQB<B`O/F-H86YC92(*;7-G<W1R(")#<V%P863I:SQB<B`O/G9A;/-S>NUN
M^W/I9R(*"B,Z(&QI8B](;W)D92]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B
M4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")0<F5F<U]L9&%P.B!N96T@=&%LX6QH873S(&$@<WK\:W/I
M9V5S($Q$05`@:VET97)J97-Z=.ES+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]S
M97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@
M<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]S
M97-S:6]N.B!N96T@=&%LX6QH873S(&$@<WK\:W/I9V5S("AS97-S:6]N*2!K
M:71E<FIE<WITZ7,N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S(*;7-G
M:60@(E!R97-S=7)E(@IM<V=S='(@(DSI9VYY;VWA<R(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C8V"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ
M("(*;7-G<W1R(")!('1E;F=E<G-Z:6YT;F5K(&UE9V9E;&5L]2!LZ6=N>6]M
MX7,Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C0*;7-G
M:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B3.EG;GEO;>%S.B`B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`S"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM
M<V=I9"`B4')E=FEE=R(*;7-G<W1R(")%;/5Z971E<R!M96=T96MI;G3I<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@
M=VEN9&]W(@IM<V=S='(@(D$@:^EP(&5L]7IE=&5S(&UE9W1E:VEN=.ES92#Z
M:B!A8FQA:V)A;B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S4V(&QI
M8B](;W)D92]0<F5F<R]522YP:'`Z,S8P"FUS9VED(")0<F5V:6]U<R!O<'1I
M;VYS(@IM<V=S='(@(D5L]7KU(&]P8VGS:R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M
M96YT(@IM<V=S='(@(D$@9&]K=6UE;G1U;2!K:6YY;VUT873A<V$B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y
M(@IM<V=S='(@(E1I=&MO<R!K=6QC<R(*"B,Z(&QI8B](;W)D92]-96YU+G!H
M<#HQ-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B2&EB86)E:F5L96YTZ7,B
M"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C<*;7-G:60@(E!R;V)L96T@
M1&5S8W)I<'1I;VXB"FUS9W-T<B`B02!H:6)A(&QE[7+A<V$B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<Q"FUS9VED(")0<F]J96-T<R(*;7-G
M<W1R(")0<F]J96MT(&ME>F5LZ7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C$Q-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Y,B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,S(X,`IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B02!P<F]M<'0@
M<WKV=F5G92(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R,PIM<V=I
M9"`B4'5B;&EC($ME>2(*;7-G<W1R(").>6EL=N%N;W,@:W5L8W,B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T-@IM<V=I9"`B4'5B;&EC($ME
M>2!!;&=O<FET:&TB"FUS9W-T<B`B3GEI;';A;F]S(&MU;&-S^B!A;&=O<FET
M;75S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@
M(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R(").>6EL=N%N;W,@:W5L8W,@:6YF
M;W)MX6-I\R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C(T,0IM<V=I
M9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E
M<W-F=6QL>2XB"FUS9W-T<B`B02!N>6EL=N%N;W,O=&ET:V]S(&MU;&-S<.%R
M="!N96T@<VEK97+\;'0@;.ET<F5H;WIN:2XB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3DQ(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#,*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@
M4FEC;R(*;7-G<W1R(")0=65R=&\@4FEC;R(*"B,Z(&QI8B](;W)D92])34%0
M+T%#3"]R9F,T,S$T+G!H<#HU-0IM<V=I9"`B4'5R9V4@;65S<V%G97,B"FUS
M9W-T<B`B02!L979E;&5K(';I9VQE9V5S('3V<FSI<V4B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3DV(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1
M871A<B(*;7-G<W1R(")+871A<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV
M,PIM<V=I9"`B475E<GDB"FUS9W-T<B`B2V5R97/U+W!A<F%N8W,@<W1R:6YG
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"FUS9VED(")1=6]T82(*
M;7-G<W1R(")+=O-T82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-C8T"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B
M:70I(@IM<V=S='(@(E)302!N>6EL=N%N;W,@:W5L8W,@*"5D(&)I=&5S*2(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C8X"FUS9VED(")2861I;R!S96QE
M8W1I;VXB"FUS9W-T<B`B4N%D:?-G;VUB;W,@:VEVX6QA<WITX7,B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B
M4F%I;B(*;7-G<W1R(")%<_4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R(")%
M<_4@9.EL96SU='0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(D5S]2!DZ6QU
M=.%N+V5S=&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT-PIM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B6N%P;W(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I
M9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R(")%<_4@Z7,@:&%V87KA<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED
M(")286EN('1O(%-N;W<B"FUS9W-T<B`B2&%V87-E<_4B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T
M<B`B5NEL971L96X@:63I>F5T(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C@@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*
M;7-G:60@(E)A=&EO(@IM<V=S='(@(D%RX6YY(@H*(SH@;&EB+TAO<F1E+U!E
M<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T<B`B3VQV87/A
M<R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HT-R!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E860@;65S
M<V%G97,B"FUS9W-T<B`B3&5V96QE:R!O;'9A<^%S82(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+B(*;7-G<W1R("(B"B)4Z6YY;&5G('3V<O9L:OQK("5S(&9E;&AA
M<WINX6SS=#\@17H@82!VX6QT;WIT873A<R!N96T@9F]R9.UT:&%T\R!V:7-S
M>F$N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R
M('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM
M<V=S='(@(B(*(E3I;GEL96<@=/9R]FQJ_&L@)7,@9F5L:&%S>F[A;/,@861A
M=&%I=#\@17H@82!VX6QT;WIT873A<R!N96T@9F]R9.UT:&%T\R`B"B)V:7-S
M>F$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B
MVFIR82!VZ6=R96AA:G1J82!A>B!U=&]L<_,@=N%L=&]Z=&%TX7-T(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B1G)I<W/M=.ES(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-0IM<V=I9"`B4F5F<F5S:"!$>6YA
M;6EC($UE;G4@16QE;65N=',Z(@IM<V=S='(@(D$@;65N_"!D:6YA;6EK=7,@
M96QE;65I;F5K(&9R:7-S[73I<VD@9WEA:V]R:7/A9V$Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T-0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE
M=SHB"FUS9W-T<B`B07H@]G-S>F5G>O5O;&1A;"!F<FES<^UTZ7/I;F5K(&=Y
M86MO<FESX6=A.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX.3@@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$R,3<@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,SD*;7-G
M:60@(E)E9V5X(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS
M,C,U"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R(")/8FIE
M:W1U;2!B]FYGZ7-Z]2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*;7-G:60@(E)E
M;&]A9"(*;7-G<W1R(")&<FES<^UTZ7,B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,S,PIM<V=I9"`B4F5M87)K<R(*;7-G<W1R(")-96=J96=Y>NES96LB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$W"FUS9VED(")296UO=&4@
M4V5R=F5R<R(*;7-G<W1R(")4X79O;&D@<WIE<G9E<F5K(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),("AH
M='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B02!TX79O
M;&D@55),("AP;"X@:'1T<#HO+W=W=RYV86QA;6DN:'4O;65G=F%L86UI*3HB
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*;7-G:60@(E)E;6]V92(*
M;7-G<W1R(")4]G)LZ7,B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z,3$*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R(")";&]K:R!T]G)L
MZ7-E(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U
M.0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")/<WIL;W`@=/9R;.ES
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(D$@9F]R;6%T
M=.%LX7,@=/9R;.ES92(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R(")!('#A<B!T]G)LZ7-E
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E
M('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O
M<GDN(@IM<V=S='(@(B(*(E3V<O9L:OQK(&%Z(&5L;65N=&5T="!P<F]G<F%M
M;W0@82!S>F5R=F5R(&ED96EG;&5N97,@X6QL;VWA;GEO:V%T('1A<G1A;&UA
M>O,@(@HB86QK]FYY=G3A<N%B\VPN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED(")296UO=F4@
M=&AE(@IM<V=S='(@(E9E9WG\:R!K:2`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V
M92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B5F5G>?QK
M(&MI(&5Z="!A('+I<WIT(&$@9&]K=6UE;G1U;6+S;"(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U<V5R
M(@IM<V=S='(@(D$@9F5L:&%S>F[A;/,@=/9R;.ES92(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B)7,@9F5L:&%S>F[A;/,@=/9R
M;.ES92(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@
M(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R
M8V]D93H@(@IM<V=S='(@(D$@:^ERZ7,@;F5M('1E;&IE<^UT:&5T]2X@02!K
M87!O='0@:&EB86OS9#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$T-0IM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E
M(&9O=6YD+B(*;7-G<W1R(")!(&ME<F5S971T('-Z;VQGX6QT873A<R!N96T@
M=&%LX6QH873S+B(*"B,Z(&QI8B](;W)D92YP:'`Z,3<V(&QI8B](;W)D92YP
M:'`Z-3$X"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N
M;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D$@
M:_9T96QE>O5E;B!M96=A9&%N9/,@7"(E<UPB(&YE;2!S>F5R97!E;"`E<R!K
M;VYF:6=U<N%C:?-JX6)A;BXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z-C<X(&QI
M8B]61E,O9G1P+G!H<#HX-C$@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S,Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF
M:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")!(&OV=&5L97KU
M96X@;65G861A;F3S(%PB)7-<(B!N96T@<WIE<F5P96P@82!61E,@:V]N9FEG
M=7+A8VGS:N%B86XN(@H*(SH@;&EB+TAO<F1E+U5T:6PN<&AP.C<W-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE
M9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")!(&OV=&5L97KU96X@;65G
M861A;F3S(%PB)7-<(B!N96T@<WIE<F5P96P@82!K;VYF:6=U<N%C:?-B86XN
M(@H*(SH@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B
M4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B4WK\:W/I9V5S(&UE>O4B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S0S(&QI8B](
M;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,C`*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(R,"!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(E)E<V5T(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-#8*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM
M<V=S='(@(D$@:F5L<WKS(.%TX6QL[73A<V$B"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*
M;7-G<W1R(")!>B#6;B!J96QS>F%VX6YA:R#A=.%L;.UTX7-A(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$S,`IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y
M(@IM<V=S='(@(D%Z('5T;VQS\R!K97)E<^ES('9I<W-Z8>%L;.UTX7-A(@H*
M(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR
M."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T
M<B`B17)E9&WI;GDB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T
M;R!/<'1I;VYS(@IM<V=S='(@(E9I<W-Z82!A>B!O<&-I\VMH;WHB"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N
M97<@<&%S<W=O<F0B"FUS9W-T<B`B07H@^FH@:F5L<WKS="#M<FIA(&)E(&ES
M;>ET(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R(")2Z75N:6]N(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("+!
M;&SM='-U:R!V:7-S>F$@82!K;VYF:6=U<N%C:?-T(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I
M;VYS(@IM<V=S='(@(E)I8V@@5&5X="!%9&ET;W(@;W!C:?-K(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@
M(E1A;.%L\W,@:^ER9.ES96LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@
M(FIO8F(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P-PIM<V=I9"`B4FEG
M:'0@:&5A9&5R(@IM<V=S='(@(DIO8F(@;VQD86QI(&9E:FSI8R(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HS,3`S"FUS9VED(")2:6=H="!V86QU97,B"FUS
M9W-T<B`B2F]B8B!O;&1A;&D@Z7)TZ6ME:R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?
M=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(E-O<B!T=6QA:F1O;G/A9V]K+BXN
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G
M:60@(E)O;&4B"FUS9W-T<B`B4WIE<F5P(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Y."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*
M;7-G<W1R(")2;VWA;FEA(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(R-@IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R(")&;W)G
M873A<R`Q.#`@9F]K:V%L(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(R,PIM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B0F%L
M<F$@9F]R9V%TX7,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C(Y"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B2F]B8G)A
M(&9O<F=A=.%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T
M<B`B4V]R('1U;&%J9&]N<^%G;VLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R
M=&EE<R(*;7-G<W1R(")3;W(@='5L86ID;VYSX6=O:R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S
M.B(*;7-G<W1R(")3;W)O:SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R
M(")6;VYA;&%K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R(")-:6YD96X@<V]R
M(.ES(&]S>FQO<"!K]GKV='0@;&5G>65N('9O;F%L(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T
M<B`B0W-A:R!A>B!O<WIL;W!O:R!K]GKV='0@;&5G>65N('9O;F%L(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB
M"FUS9W-T<B`B0W-A:R!A('-O<F]K(&OV>O9T="!L96=Y96X@=F]N86PB"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P"FUS9VED(")2=6XB"FUS9W-T<B`B
M1G5T=&%TX7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DY(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T
M<B`B3W)O<WH@1O9D97+A8VGS(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(P,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@
M(E)U86YD82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C@U"FUS
M9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B
M4R]-24U%(&1I9VETX6QI<R!A;.'M<N%S(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G
M92(*;7-G<W1R(")3+TU)344@<WIA8G;A;GD@<WIE<FEN="!T:71K;W/M=&]T
M="!L97;I;"(*"B,Z(&QI8B](;W)D92]!=71H+W-A<VPN<&AP.C@Q"FUS9VED
M(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(E-!4TP@9F5L:&%S>F[A;/-A>F]N;W/M=.%S(&YE;2!T86SA;&AA=/,N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P-@IM<V=I9"`B4TU3
M($UE<W-A9VEN9R(*;7-G<W1R(")335,@:_QL9.ES(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S@*;7-G:60@(E-13"!S=&%T96UE;G0@
M9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B4U%,('!A<F%N8W,@82!K97)E
M<^ES:&5Z(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,PIM<V=I
M9"`B4U-((@IM<V=S='(@(E-32"(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G
M<W1R(")324M%4MQ,5"(*"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]1
M3"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R(")3>F\B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T
M"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T<B`B4WIE;G0@26QO;F$M<WII
M9V5T(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B
M4V%I;G0@2VET=',@Z7,@3F5V:7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3,Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM
M<V=S='(@(E-A:6YT($QU8VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$X.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N
M9"!-:7%U96QO;B(*;7-G<W1R(")386EN="!0:65R<F4@Z7,@36EQ=65L;VXB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0T(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$U"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*
M;7-G<W1R(")386EN="!6:6YC96YT(.ES($=R96YA9&EN92US>FEG971E:R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*
M;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R(")59WEA;F%Z(&$@
M9G)A;64@*%]S96QF*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(E-Z86UO
M82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`B4V%N($UA<FEN;R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,38@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Y-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R(")386\@
M5&]MZ2#I<R!0<NUN8VEP92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(DW[:&]L
M9&%S(&EN=&5R;F5T96SI<NES(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM
M<V=S='(@(E-Z8?ID+4%RX6)I82(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHY.0IM<V=I9"`B4V%V92(*;7-G<W1R(")-96YTZ7,B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L('!H<"UF;W)M
M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(EPB)7-<(B!M96YTZ7-E
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R("(E<R!M96YTZ7-E(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS
M(@IM<V=S='(@(D$@8F7A;&SM=.%S;VL@;65N=.ES92(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@
M=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB365N='/\:R!E
M;"!A>B!E;&OI<WK\;'0@:V]N9FEG=7+A8VGS="!02%`@<')O9W)A;2!F;W)M
MX6KA8F%N(&$@<WIE<G9E<B`B"B)I9&5I9VQE;F5S(.%L;&]MX6YY;VMA="!T
M87)T86QM87KS(&%L:_9N>79TX7+A8F%N+B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B5S(&MO;F9I9W5RX6-I\VKA="!E;&UE
M;G1E='3\:RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E('-C<FEP="!T
M;SH@7"(E<UPB+B(*;7-G<W1R(")%;&UE;G1E='3\:R!A('-E='5P('5P9W)A
M9&4@<')O9W)A;6]T(&ED93H@7"(E<UPB(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E-C871T97)E9"!4+5-T
M;W)M<R(*;7-G<W1R(")3>O-R=N%N>6]S('II=F%T87)O:R(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R(")4
M=61O;>%N>2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T
M('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R
M8V@B"FUS9W-T<B`B2V5R97/I<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS,C(*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(DME<F5S
MZ7-I('-Z;VQGX6QT873A<V]K(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y
M-3D*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R("+!;&QO;>%N>6]K(&MI
M=N%L87-Z=.%S82(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT.#4*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B5N%L87-S
M>F]N(&MI(&5G>2!DX71U;6]T(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R
M(")-96QY:6L@8W-O<&]R=&]T(&OM=N%N:F$@:&]Z>N%A9&YI(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W
M(&]W;F5R(@IM<V=S='(@(E;A;&%S<WIA(&MI(&%Z(/IJ('1U;&%J9&]N;W-T
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")3
M96QE8W0@82!S97)V97(B"FUS9W-T<B`B5N%L87-S>F]N('-Z97)V97)T(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C
M="!A('5S97(@=&\@861D(@IM<V=S='(@(DUE;'EI:R!F96QH87-Z;N%L\W0@
M:^UVX6YJ82!H;WIZX6%D;FDB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-C<V"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(DUI
M;F1E="!K:6IE;/9L:OQK(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-#<*
M;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R(")6
MX6QA<W-Z82!K:2!A>B#V<W-Z97,@9.%T=6WV<W-Z971E=O5T+B(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E
M;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B5N%L87-S>F]N(&5G>2!O8FIE:W1U
M;6]T(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W
M-PIM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B16=Y('-E(&QE9WEE;B!K
M:6IE;/9L=F4B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@
M(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B
M;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H
M96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B)6X6QA<W-Z82!K
M:2!A(&OM=N%N="!K87)A:W1E<BAE:V4I="!A>B!A;.%B8FD@;&5H973U<^EG
M96L@:_9Z_&PN($5Z=73A;B`B"B)<(F-O<'DO<&%S=&5<(B!M\V1S>F5R<F5L
M(&$@;65G9F5L96SU(&AE;'ER92!MX7-O;&AA=&IA(/5K970N(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T
M92!D96QI;6ET97(Z(@IM<V=S='(@(E;A;&%S<WIA(&MI(&$@9.%T=6UE;';A
M;&%S>G3S(&MA<F%K=&5R=#HB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B
M5N%L87-S>F$@:VD@82!DX71U;2!F;W)MX71U;>%T.B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T
M:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R(")6X6QA
M<W-Z82!K:2P@;65L>6EK(&%Z;VYO<^UT\VKA="!K[7;A;FIA(&UE9W;A;'1O
M>G1A=&YI.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED
M(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R(")6X6QA<W-Z
M82!K:2!A>B!I9/5E;';A;&%S>G3S(&MA<F%K=&5R=#HB"@HC.B!T96UP;&%T
M97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O
M<FUA=#HB"FUS9W-T<B`B5N%L87-S>F$@:VD@87H@:63U(&9O<FWA='5MX70Z
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L
M96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(E;A;&%S<WIO;B!K
M:2!KZ70@96=Y;>%S;F%K(&UE9V9E;&5L]2!M97KU="XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S$P"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S
M8VAE;64N(@IM<V=S='(@(E;A;&%S<WIA(&MI(&$@:^UVX6YT('-Z[6YE9WG\
M='1E<W0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U,@IM<V=I9"`B
M4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R(")6X6QA
M<W-Z82!K:2!A>B#6;FYE:R!M96=F96QE;/4@;GEE;'9E=#HB"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B
M;&5M(%)E<&]R="(*;7-G<W1R(")(:6)A:F5L96YTZ7,@:_QL9.ES92(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#0R"FUS9VED
M(")396YD(%--4R(*;7-G<W1R(")335,@:_QL9.ES92(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Y.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E
M;F5G86PB"FUS9W-T<B`B4WIE;F5GX6PB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,R,PIM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B4WIE;GIO<CH@(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,"!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E
M;6)E<B(*;7-G<W1R(")S>F5P=&5M8F5R(@H*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O
M(@IM<V=S='(@(E-Z97)B:6$@Z7,@36]N=&5N96=R\R(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-S`R"FUS9VED(")397)I86P@3G5M8F5R(@IM
M<V=S='(@(E-O<F]Z871S>N%M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$T.0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B02!S>F5R=F5R=/5L(&MA<&]T="!A9&%T(&AI
M8N%S+"!V86=Y(&YE;2#A;&P@<F5N9&5L:V5ZZ7-R92XB"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z,C<*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B
M02!F96QH87-Z;N%L\VMA<&-S;VQA=&]K(&%D;6EN:7-Z='+A8VGS:F$B"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B
M4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R("),96KA<G0@82!F96QH87-Z
M;N%L\VMA<&-S;VQA="!A>F]N;W/M=/-J82`H<V5S<VEO;B!)1"DN(@H*(SH@
M;&EB+V%P:2YP:'`Z,30U"FUS9VED(")397-S:6]N<R(*;7-G<W1R(")&96QH
M87-Z;N%L\VMA<&-S;VQA=&]K(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S
M,3@*;7-G:60@(E-E="(*;7-G<W1R(")(86QM87HB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-SD*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO
M=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I
M="XB"FUS9W-T<B`B3&5H973U<^EG(&IE;'-Z87;A;F%K(.%TX6QL[73A<^%R
M82P@86)B86X@87H@97-E=&)E;BP@:&$@96QF96QE:G1E;NDN(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Q.`IM<V=I9"`B4V5T('5P(')E;6]T92!S
M97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T
M86PN(@IM<V=S='(@(B(*(E3A=F]L:2!S>F5R=F5R96L@96SI<NES92#A;&SM
M=&AA=/,@8F4L(&UE;'EE:V5T(&%Z(&EN9'5L\V]L9&%LX6X@:^UVX6X@(@HB
M;65G:F5L96[M=&5N:2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<*
M;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@
M86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B02!K[7;A;G0@;GEE;'8L(&ED
M]7KS;F$@Z7,@9.%T=6UF;W)MX71U;2!B9>%L;.UTX7-A+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,#$*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T
M=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG
M+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B"B)"
M9>%L;.UT:&%T\RP@:&]G>2!M96QY:6L@86QK86QM87KA<R!J96QE;FIE;B!M
M96<@82!B96IE;&5N=&ME>NES('5TX6XL("(*(FUI;'EE;B!S>NUN96=Y_'1T
M97-T+"!O;&1A;&9R:7-S[73I<VD@9WEA:V]R:7/A9V]T(&EL;"X@96=YZ6(@
M8F7A;&SM=.%S;VMA="`B"B)S>F5R971N92XB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C<W"FUS9VED(")3971U<"(*;7-G<W1R(")"9>%L;.UTX7-O
M:R(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS
M9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@
M(D$@8F7A;&SM=.%S;VMA="!M96?Z:NUT\R!P<F]G<F%M;VL@X6QL;F%K(')E
M;F1E;&ME>NES<F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3<U"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H
M92!P87)A;65T97(Z("(*;7-G<W1R(")!(&UE9V%D;W1T('!A<F%MZ71E<B!T
M]F)B(&AE;'EE="!I<R!J96QE;G1H970Z("(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL
M97,B"FUS9W-T<B`B4V5Y8VAE;&QE+7-Z:6=E=&5K(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0Y.`IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B
M5N%SX7)LX7,B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT
M,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R(")2]G9I9"#V<W-Z969O
M9VQA;.%S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U,`IM<V=I9"`B
M4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_
M(@IM<V=S='(@(D5L(&OM=N%N:F$@Z7)N:2!A>B!E9WEE<R!F=6YK8VGS:V%T
M($%L="UB:6QL96YT>?LM:V]M8FENX6-I\VMK86P@:7,_(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS
M,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B
M365G:F5L96[M=.ES(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM
M<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S
M879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("(B"B)-=71A<W-U:R!M96<@82!K_&SV;F)SZ6=E:V5T(&%Z
M(&5L;65N=&5T="#I<R!A>B#Z:F]N;F%N(&SI=')E:&]Z;W1T("(*(FMO;F9I
M9W5RX6-I\R!K]GKV='0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y
M-`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN
M/R(*;7-G<W1R("(B"B)-:6YD96X@8F5J96QE;G1K97KI<VMO<B#M<O-D:NEK
M(&MI(&$@:V]RX6)B:2!U=&]L<_,@8F5J96QE;G1K97KI<R!I9&5J93\B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V.0IM<V=I9"`B4VAO=R!O<'1I;VX@
M=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R(")6X6QA<WIT:&%T\R!L96=Y96X@
M87H@97)E9&5T:2!M96=T87)TX7-A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(W.3D*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(DQE9WEE;B!DX71U
M;7;A;&%S>G3S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S,`IM<V=I
M9"`B4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R("),
M96=Y96X@96=Y('3A8FSA>F%T:V5Z96SU(&UE;OQS;W(_(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W
M('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R(")-=71A<W-U:R!A
M("5S(&UE;OQT(&$@8F%L(&]L9&%L;VX_(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W
M('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(D[I
M>GK\:R!M96<@=.%B;.%Z870@8V5L;.%I;F%K('1U;&%J9&]N<^%G86ET(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO
M9R(*;7-G<W1R(").Z7IZ_&L@;65G('3A8FSA>F%T('1U;&%J9&]N<^%G86ET
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE
M<R!D:6%L;V<B"FUS9W-T<B`B3NEZ>OQK(&UE9R!TX6)LX7IA="!S;W)A:6YA
M:R!T=6QA:F1O;G/A9V%I="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA
M9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B3NEZ>OQK(&UE9R!A(&OI
M<"!T=6QA:F1O;G/A9V%I="(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8W
M"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R(")-=71A<W-U:R!A(&9E;'3V
M;'3I<W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,0IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R("):X7!O<F]K(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H
M;W=E<G,@16%R;'DB"FUS9W-T<B`B6N%P;W)O:R!DZ6QE;/5T="(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3
M:&]W97)S($QA=&4B"FUS9W-T<B`B6N%P;W)O:R!DZ6QU=.%N+V5S=&4B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I
M9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B2&5L>6D@>N%P
M;W)O:R(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M-C$Y"FUS9VED(")3:')I;FLB"FUS9W-T<B`B2VEC<VEN>>UTZ7,B"@HC.B!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDQ,`HC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDW,@HC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P-3@*(SH@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,3(P"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z,3$X,PHC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R,C,*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HQ,C4R"B,Z(&QI8B](;W)D92]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z,3(X-0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@
M;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM
M<V=S='(@(B(*(D5L]7-Z]G(@:VEC<VEN>>UT96YI92!K96QL+"!V86=Y(&5L
M(&ME;&P@;6]Z9.UT86YI82!A(&AE;'EE="!E;&9O9VQA;/,@(@HB8FQO:VMO
M:V%T+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R(")3:65R<F$@
M3&5O;F4B"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V-@IM<V=I
M9"`B4VEG;B!U<"(*;7-G<W1R("+::B!F96QH87-Z;N%L\VL@8F5J96QE;G1K
M97KI<V4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<Q,PIM<V=I
M9"`B4VEG;F%T=7)E(@IM<V=S='(@(D1I9VETX6QI<R!A;.'M<N%S(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R
M92!!;&=O<FET:&TB"FUS9W-T<B`B02!D:6=I=.%L:7,@86SA[7+A<R!A;&=O
M<FET;75S82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R(")3>FEN9V%P
M^G(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3`P(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,C$Y(&QI8B](;W)D92]&;W)M+G!H<#HQ,C0Q"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,C4P(&QI8B](;W)D92]&;W)M+G!H<#HR.3$V(&QI8B](
M;W)D92]&;W)M+G!H<#HS,3`Y"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M87(N<&AP.C8U(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@T"FUS9VED(")3:7IE
M(@IM<V=S='(@(DWI<F5T(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA
M:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS
M9W-T<B`B02!K87)B86YT87)TX7,@:VEH86=YX7-A(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO
M=F%K:6$B"FUS9W-T<B`B4WIL;W;A:VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(P."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N:6$B
M"FUS9W-T<B`B4WIL;W;I;FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<B"FUS9W-T<B`B2&%V87KA
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V
M"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R(")(\WKA<&]R(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N
M;W<@4VAO=V5R<R(*;7-G<W1R(")(\WKA<&]R;VLB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W
M97)S($5A<FQY(@IM<V=S='(@(DCS>N%P;W)O:R!DZ6QE;/5T="(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3
M;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R(")+Z7/U(&3I;'5TX6YI+V5S=&D@
M:/-ZX7!O<F]K(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#4*;7-G:60@
M(E-N;W<@9&5P=&@Z("(*;7-G<W1R(")!(&CS(&WI;'ESZ6=E.B`B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(X.0IM<V=I9"`B4VYO=R!E<75I=F%L96YT
M(&EN('=A=&5R.B`B"FUS9W-T<B`B2/,@=NUZ;65N;GEI<^EG96)E;B!K:69E
M:F5Z=F4Z("(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#(@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R(")3
M86QA;6]N+7-Z:6=E=&5K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R(")3
M>F]MX6QI82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B
M4V]N9W,@)B!0;V5M<R(*;7-G<W1R(")$86QO:RP@=F5R<V5K(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(Y,3(*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T
M:6]N(@IM<V=S='(@(D$@<V]R8F%R96YD97KI<R!I<N%N>>%N86L@:VEVX6QA
M<WITX7-A(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U
M.2!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&QI8B].970O4TU3+W=I;E]H='1P
M+G!H<#HQ-C8@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$X.0IM<V=I9"`B
M4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B1F5L863S:2!C[6TB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C4U(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED
M(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B1.EL+4%F<FEK82(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/
M+3@X-3DM,RDB"FUS9W-T<B`B9.EL+65U<O-P86D@*$E33RTX.#4Y+3,I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W
M"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@
M27-L86YD<R(*;7-G<W1R(")$Z6QI+4=E;W)G:6$@Z7,@1.EL:2!386YD=VEC
M:"US>FEG971E:R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS
M9W-T<B`B1.EL:2!FZ6QT96ME(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J
M86-E;G0@8V5L;',B"FUS9W-T<B`B4WIO;7-ZZ61O<R!C96QLX6L@:_9Z]G1T
M:2!TX79O;'/A9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD
M(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(D$@8V5L;&$@=&%R=&%L;6$@Z7,@
M:V5R971E(&OV>O9T=&D@=.%V;VQSX6<B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z.#$Y"FUS9VED(")3<&%C97(B"FUS9W-T<B`B2&5L>6MI=/9L=/4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B5.%V;VQSX6<B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS
M9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(E3A=F]L<^%G(.ES
M(&)E;'/U(&UA<F?S(&)EX6QL[73A<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R
M(")3<&%N>6]L;W)S>N%G(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$P,`IM<V=I9"`B4W!A;2(*;7-G<W1R(")3<&%M87-S87-S:6YE(&)EX6QL
M[73A<V]K(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3
M<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R(")3<&5C:>%L:7,@:V%R
M86MT97(@8F5V:71E;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S
M='(@(D$@8V5L;&$@:V5T=.EB;VYTX7-A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@
M8V]L=6UN(@IM<V=S='(@(D%Z(&]S>FQO<"!K971TZ6)O;G3A<V$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q
M"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B02!S;W(@:V5T=.EB;VYTX7-A
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B
M"FUS9W-T<B`B4W!O<G0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R(")3
M<NT@3&%N:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C8@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HX,0IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T
M<B`B4W1A;F1A<F0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G
M:60@(E-T87(@5')E:R(*;7-G<W1R(")3=&%R(%1R96LB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C4Y,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y-0IM<V=I
M9"`B4W1A<G0@>65A<B(*;7-G<W1R(")!>B!E;'/U(.EV(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S$*;7-G:60@(E-T871E(&]R(%!R;W9I
M;F-E(@IM<V=S='(@(L%L;&%M('9A9WD@=&%R=&]MX6YY(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*
M;7-G<W1R("+!;&QA<&]T(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#$*
M;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(DUE;G3I<VD@9F]R;>%T
M=6TB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B
M4W1R965T($%D9')E<W,B"FUS9W-T<B`B0^UM("AU=&-A*2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T
M<FEK971H<F]U9V@B"FUS9W-T<B`BX71H^GIO='0B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3(S-PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B4W1R
M:6YG(&QI<W1A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S<*;7-G:60@
M(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(E3V<O9L
M:OQK(&$@8^UM8O5L(&$@0"!U=.%N:2!RZ7-Z="(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T
M>6QE(%M#4U-=(@IM<V=S='(@(E-T[6QU<R!;0U-372(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM
M<V=S='(@(E9A(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R(")!*'HI(%PB)7-<(B!A;&OV;GEV=.%R(&YE;2!T86SA;&AA
M=/,N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*
M;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B5.%R9WDB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S,V(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*
M;7-G:60@(E-U8FUI="(*;7-G<W1R(")+_&QD:OQK(&5L(@H*(SH@<VEG;G5P
M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q
M=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@
M;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E
M9"XB"FUS9W-T<B`B(@HB7"(E<UPB(/IJ(&9E;&AA<WINX6SS(&)E:F5L96YT
M:V5ZZ7-I(&OI<F5L;>ET('1O=N%B8NUT;W1T=6LN(-9N(&-S86L@(@HB:^ER
M96QMZ6YE:R!E;&9O9V%DX7/A="!K]G9E=/5E;B!T=60@;6%J9"!B96IE;&5N
M=&ME>FYI+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R(")A;'/S(&EN9&5X
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-"!L:6(O2&]R9&4O3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B
M"FUS9W-T<B`B4VEK97+\;'0B"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O
M('1H92!S>7-T96TN(@IM<V=S='(@(E-I:V5R97-E;B!H;WIZX6%D='5K(%PB
M)7-<(BUT(&$@<F5N9'-Z97)H97HN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A
M=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B
M7"(E<UPB(&9E;&AA<WINX6SS(&%D871A:70@<VEK97)E<V5N('3V<O9L=/QK
M(&$@<F5N9'-Z97)B]6PN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI
M;B]P97)M<R]D96QE=&4N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B4VEK97)E<V5N
M('3V<O9L=/QK(%PB)7-<(BUT+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S
M7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")3:6ME<F5S96X@96QTX79O
M;.UT;W1T=6L@7"(E<UPB+70@82!R96YD<WIE<F+U;"XB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T
M960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G
M<W1R("(B"B)!(&MO;F9I9W5RX6-I\W0@<VEK97)E<V5N('9I<W-Z8>%L;.UT
M;W1T=6LN($$@=N%L=&]ZX7-O:R!M96=T96MI;G3I<^EH97H@(@HB9G)I<W/M
M='-E(&%Z(&]L9&%L="XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL
M>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B02!B86-K
M=7`@:V]N9FEG=7+A8VGS="!E;&UE;G1E='3\:RXB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB
M"FUS9W-T<B`B4VEK97)E<V5N(&5L;65N=&5T=/QK(&$H>BD@)7,@8F%C:W5P
M(&MO;F9I9W5RX6-I\W0N(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*
M;7-G<W1R(")<(B5S7"(@861A=&%I;F%K(&WS9&]S[73A<V$@<VEK97)E<V5N
M(&UE9W3V<G3I;G0N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(E-I:V5R97-E;B!E;&UE
M;G1E='3\:R!A("5S(.%L;&]MX6YY="XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C`T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G
M<W1R(")3>G5DX6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(M9S
M<WIE9F]G;&%LX7,B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G
M:60@(E-U;B!2:7-E(@IM<V=S='(@(DYA<&ME;'1E(@H*(SH@;&EB+T)L;V-K
M+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(DYA<&YY
M=6=T82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8P"FUS9VED(")3=6YN>2(*;7-G<W1R(")N87!O<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,#4*;7-G:60@(E-U;G)I<V4B"FUS9W-T
M<B`B3F%P:V5L=&4B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM
M<V=S='(@(DYA<&ME;'1E+VYA<&YY=6=T82(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,#0*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R(").
M87!K96QT93H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P
M.`IM<V=I9"`B4W5N<V5T(@IM<V=S='(@(DYA<&YY=6=T82(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#<*;7-G:60@(E-U;G-E=#H@(@IM
M<V=S='(@(DYA<&YY=6=T83H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T
M<B`B9F5L<_4@:6YD97@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S@P"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(D]N;&EN92!K;VUM=6YI:^%C
M:?,@*&-H870I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P-@IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B4W5R:6YA
M;64B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B
M4W5R;F%M92(*;7-G<W1R(")#<V%LX61NZ78B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3,*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R
M9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(E-V86QB87)D(.ES($IA;B!-87EE
M;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3D@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R(")3>G;A>FEF]FQD(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(E-VZ61O<G-ZX6<B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(Q-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B
M4W=I='IE<FQA;F0B"FUS9W-T<B`B4W;A:F,B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G
M<W1R(")!>B!A9&%T<WII;FMR;VYI>N%C:?-S(&YA<&SSX6QL;VWA;GET('3V
M<O9L=/QK(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-0IM<V=I9"`B
M4WEN8TU,(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N
M<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM
M<V=S='(@(E-Z:6YT86MT:6MA:2!H:6)A(&$@:V5R97/U:VEF96IE>NES8F5N
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B4WKM
M<FEA:2!!<F%B($OV>G3A<G-A<^%G(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B
M6FEV871A<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8R"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R(")::79A
M=&%R+"!E<O5S('-ZZ6PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B6FEV871A
M<F]K(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C0*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@(DMO<F%I('II=F%T
M87)O:R(*"B,Z(&QI8B](;W)D92]$871A+W1S=BYP:'`Z,38V"FUS9VED(")4
M4U8@9FEL92(*;7-G<W1R(")44U8@*%1!0B!K87)A:W1E<G)E;"!E;';A;&%S
M>G1O='0@Z7)TZ6ME:RD@X6QL;VWA;GDB"@HC.B!L:6(O2&]R9&4O54DO5&%B
M;&4N<&AP.C$S-`IM<V=I9"`B5&%B;&4B"FUS9W-T<B`B5.%B;.%Z870B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(D$@=.%B;.%Z
M870@='5L86ID;VYSX6=A:2(*"B,Z(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B
M;&5S970N<&AP.C4W"FUS9VED(")486)L92!3970B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R(")!('3A8FSA>F%T
M('1U;&%J9&]N<^%G86DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,T
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM
M<V=S='(@(E1A:G9A;B(*"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T
M<B`B5&%J=F%N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R(")4861Z
M<VEK:7-Z=.%N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI
M8R!O9B(*;7-G<W1R(")486YZX6YI86D@16=Y97/\;'0@2VERX6QY<^%G(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM
M<V=I9"`B5&%R9V5T.B(*;7-G<W1R(")!(&/I;#HB"@HC.B!C;VYF:6<O:&]O
M:W,N<&AP+F1I<W0Z,3`T.2!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@Y
M"FUS9VED(")487-K<R(*;7-G<W1R(")&96QA9&%T;VLB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B5&5L97!H;VYE($YU;6)E
M<B(*;7-G<W1R(")496QE9F]N<WKA;2(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,CDW"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")!
M>B!E;&WZ;'0@\W)A(&CU;>ER<^EK;&5T93H@(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,C$*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(DCU;>ER
M<^EK;&5T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,@IM
M<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R(")(]6WI<G/I:VQE=#H@(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F
M9&5G.R5S(@IM<V=S='(@(DCU;>ER<^EK;&5T/&)R("\^*"5S36%X)7,O)7--
M:6XE<RD@)F1E9SLE<R(*"B,Z(&QI8B](;W)D92]496UP;&%T92YP:'`Z-CDU
M"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D$H>BD@7"(E<UPB('-A8FQO;B!N96T@=&%LX6QH873S
M+B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")496UP;&%T
M92!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")386)L;VYO:R!A9&UI;FES>G3A
M8VGS:F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q-2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S,S,0IM<V=I9"`B5&5X="(*;7-G<W1R(")3>O9V96<B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Y"FUS9VED(")497AT($]N;'DB
M"FUS9W-T<B`B8W-A:R!S>O9V96<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N
M(@IM<V=S='(@(E-Z]G9E9V5L:&5L>65ZZ7,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM
M<V=S='(@(G-Z]G9E9R!T971E:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R(")#<_PB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5&AA:2`H5$E3
M+38R,"DB"FUS9W-T<B`B=&AA:2`H5$E3+38R,"DB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C(T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4:&%I
M;&%N9"(*;7-G<W1R(")4:&%I9O9L9"(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX
M-3$*;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(D%Z(&9T<"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N(@H*(SH@
M;&EB+TAO<F1E+TAI<W1O<GDN<&AP.C4U"FUS9VED(")4:&4@2&ES=&]R>2!S
M>7-T96T@:7,@9&ES86)L960N(@IM<V=S='(@(D$@2&ES=&]R>2!R96YD<WIE
M<B!M^VOV9.ES92!N:6YC<R!E;F=E9.EL>65Z=F4N(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HY,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E
M+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB
M)7-<(B(*;7-G<W1R(")!($AO<F1E+TMO;&%B(&EN=&5G<N%C:?,@97IT(&YE
M;2!TX6UO9V%T:F$Z(%PB)7-<(B(*"B,Z(&QI8B].970O24U34"]";V]K+G!H
M<#HQ,CDX"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I
M86QI>F5D+B(*;7-G<W1R(")!>B!)35-0(&YA<&SS>N%S="!N96T@<VEK97+\
M;'0@;65G:V5Z9&5N:2XB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A
M9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B02!-86EN=&5N86YC93HZ(&]S>G3A
M;'D@8F5T]FQTZ7-E(&YE;2!S:6ME<OQL="(*"B,Z('-E<G9I8V5S+VEM86=E
M<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O
M=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R(")!>B!/<&-I\R!A8FQA
M:R!B97KA<F]D;W1T+B!+:6SI<.ES(&OV=F5T:V5Z:6LN(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+G!H<#HQ.#D@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,#`@;&EB
M+TAO<F1E+U!E<FUS+G!H<#HR,3$*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR
M,C,@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,S0@;&EB+TAO<F1E+U!E<FUS+G!H
M<#HR-3(*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR-C0@;&EB+TAO<F1E+U!E
M<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S
M('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD
M(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B
M(@HB02!*;V=O<W5L='/A9V]K(&AA<WINX6QA=.%N86L@96SU9F5L=.ET96QE
M+"!H;V=Y(&$@<F5N9'-Z97)G87ID82`B"B)K;VYF:6=U<N%L:F]N(&5G>2!A
M(&IO9V]S=6QT<^%G:2!A9&%T;VMA="!T87)T\W-A;B!TX7)O;&YI(&OI<&5S
M(&%L<F5N9'-Z97)T+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O
M;FQY(@IM<V=S='(@(D-S86L@86QU;"!L96=Y96X@:V5R970B"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@
M8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA
M;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S
M='(@(B(*(D$@<&%R=&YE<B!A>F]N;W/M=/-S>N%M82!N96T@=F]L="!M96=A
M9'9A+_QR97-E;B!M87)A9'0@=F%G>2!A>B!A9&%T8N%Z:7-B86X@(@HB;F5M
M('9O;'0@;65G=&%LX6QH873S+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S
M9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(D$@
M<&%R=&YE<B!A9&%T86ET('-I:V5R97-E;B!H;WIZX6%D='5K(&$@8^UM:F5G
M>7KI:^EH97HN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$W,@IM
M<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@
M<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T
M<B`B(@HB2_QL]F[A;&SS(%!'4"!A;.'M<N%S:2!B;&]K:R!S>OQK<^EG97,@
M82!D:6=I=.%L:7-A;B!A;.'M<G0@_'IE;F5T("(*(FAI=&5L97-SZ6?I;F5K
M(&5L;&5N]7)ZZ7/I:&5Z+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)
M1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T
M(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B(@HB02!K]G)L
M97;I;&QI<W1A(&%Z;VYO<^UT\W-ZX6UA(&YE;2!V;VQT(&UE9V%D=F$O_')E
M<V5N(&UA<F%D="!V86=Y(&%Z("(*(F%D871BX7II<V)A;B!N96T@=F]L="!M
M96=T86SA;&AA=/,N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@
M<W!E8VEF:65D+B(*;7-G<W1R(")!(&OV<FQE=NEL;&ES=&$@;F5M('9O;'0@
M;65G861V82XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0N<&AP.C$Q-@IM<V=I9"`B
M5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@
M8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@HB02!T:71K;W/M=.%S:2!S>F]L9^%L
M=&%TX7-O:VAO>B!B:7IT;VYSX6=O<R`H=&ET:V]S[71O='0I('=E8B!K87!C
M<V]L870@:V5L;"XB"@HC.B!L:6(O2&]R9&4N<&AP.C$W-R!L:6(O2&]R9&4N
M<&AP.C4Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U
M;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(D$H>BD@)7,@X6QL
M;VWA;GEB86X@<WIE<F5P96QN:64@:V5L;&5N92!E9WD@)7,@8F7A;&SM=.%S
M;F%K+B(*"B,Z(&QI8B](;W)D92YP:'`Z,3<P(&QI8B](;W)D92YP:'`Z-3`Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT
M86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(B(*(D$H>BD@)7,@X6QL
M;VWA;GEB86X@<WIE<F5P96QN:64@:V5L;&5N92!V86QA;6EL>65N("5S(&)E
MX6QL[73A<RAO:REN86LN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,C8*;7-G
M:60@(E1H92!F:6QE(&-A;FYO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM
M<V=S='(@(D$@9N%J;"!N96T@;>%S;VQH873S(/9N;6%GX7)A+B(*"B,Z(&QI
M8B](;W)D92]$871A+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE
M9"!N;R!D871A+B(*;7-G<W1R(")!(&;A:FQB86X@;F5M('9O;'0@861A="XB
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I
M9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S
M<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B07H@_'IE;F5T(&9E:FSI
M8W-O<F%I(&$@:_9V971K97KU:RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E
M96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R
M;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@
M=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I
M96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T
M:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO
M=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T
M('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A
M;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N
M("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y
M('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*(D$@=&5L:F5S
M(&OI<&5R;GGU<R#\>F5M;?-D('!R;V)LZ6WA:V%T(&]K;WIH870@87H@26YT
M97)N970@17AP;&]R97(@(@HB:&%S>F[A;&%T82!E<V5TZ6XL(&UE<G0@96)B
M96X@;VQY86X@<')O9W)A;6AI8N%K('9A;FYA:RP@86UI:V5T(&YE;2!T=61T
M=6YK("(*(FUE9VME<OQL;FDN($$@:^EP97)N>?5J92!O;'9A<VAA=&%T;&%N
M;N$@=N%L:&%T+"!B:7IO;GEO<R!E9&ET;W(@9G5N:V-I\VL@(@HB:&GA;GEO
M>FAA=&YA:R#I<R]V86=Y(';A<F%T;&%N=6P@;&5F86=Y:&%T(&$@8O9N9^ES
M>O5P<F]G<F%M+B!7:6YD;W=S(#EX("(*(FAA<WINX6QA=&$@97-E=.EN(&YA
M9WEO;B!V86SS<WKM;OLL(&AO9WD@)T=E;F5R86P@<')O=&5C=&EO;B!F875L
M="<@:&EB82`B"B)M:6%T="#Z:G)A(&ME;&P@:6YD[71A;FEA(&UA:F0@82!G
MZ7#I="Y<7&Y<7&Y&:6=Y96QM97IT971T_&LA($MA='1I;G1S;VX@87H@(@HB
M3TL@9V]M8G)A+"!H82!MZ6=I<R!M96<@:^UVX6YJ82!K[7/I<F5L;FD@82!T
M96QJ97,@:^EP97)N>?5S(/QZ96UM\V1O="XB"@HC.B!S97)V:6-E<R]P<F5F
M<RYP:'`Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<
M(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B02!<(B5S7"(@87IO
M;F]S[73S="!K:73V<O9L=/QK+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA
M;F0@<VED92!O;FQY(@IM<V=S='(@(D-S86L@8F%L(&]L9&%L;VX@;&5G>65N
M(&ME<F5T(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED
M("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E
M(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@HB
M02!';G501R!P<F]G<F%M(&AE;'GI="!M96<@:V5L;"!A9&YI(&$@0W)Y<'1?
M<&=P.CH@;W-Z=.%L>2!H87-Z;N%L873A:&]Z+B(*"B,Z(&QI8B](;W)D92]-
M24U%+TU$3BYP:'`Z,C`R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M
M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H
M87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T
M:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB
M"FUS9W-T<B`B(@HB02!L97;I;"P@;65L>65T("5S(&YA<&KA;B!K_&QD]G1T
M("5S(&/M;7IE='1N96L@7"(E<UPB('3A<F=Y8F%N+"!A(&/M;7IE='0@(@HB
M<WKA;>UT\V?I<.EN(&UE9VIE;&5N="X@07)R82!N:6YC<R!G87)A;F-I82P@
M:&]G>2!E;"!I<R!O;'9A<W3A:R!I;&PN(&AO9WD@(@HB;65GZ7)T971TZ6LN
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X.#$*;7-G:60@(E1H92!N86UE
M('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G
M<W1R(")-:2!L96=Y96X@82!L97;I;.UR\R!A8FQA:VAO>B!M=71A=/,@;&EN
M:R!E;&YE=F5ZZ7-E(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT-S0*;7-G:60@
M(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T
M<B`B02!M97KU:R!S>N%M82!C<V%K(&YU;65R:6MU<R#I<G3I:R!L96AE="XB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R,S(*;7-G:60@(E1H
M92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R
M>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(B(*(D%Z(&]P96YS<VP@;6]D
M=6P@<WK\:W/I9V5S(&$@2&]R9&5?0W)Y<'1?<VUI;64Z.B!O<WITX6QY(&AA
M<WINX6QA=.%H;WHN(@H*(SH@;&EB+TAO<F1E+U!R969S+G!H<#HR.#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O
M=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H
M92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*(D$@7"(E
M<UPB('-Z96WI;'EE<R!B9>%L;.UTX7,@;F5M(&UE;G1H973U(&5L+"!M97)T
M(&WI<F5T92!M96=H86QA9&IA(&$@(@HB;65G96YG961E='0@;6%X:6UU;6]T
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O;7-W;W)D+G!H<#HS,B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<G!M+G!H<#HS,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=V5B8W!P
M+G!H<#HS-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<W)C:&EG:&QI=&4N
M<&AP.C,W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS
M,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O
M('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H
M92!S>7-T96TN(@IM<V=S='(@(B(*(DYE;2!T86SA;&AA=/,@87H@82!P<F]G
M<F%M(&$@<WIE<G9E<F5N+"!A;6D@<WK\:W/I9V5S(&5N;F5K(&%Z(&%D871T
M[7!U<VYA:R`B"B(H)7,I(&$@;65G:F5L96[M=.ESZ6AE>BXB"@HC.B!L:6(O
M1FEL92]#4U8N<&AP.C0X-PIM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M
M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R(")!>B!I9.EZ
M]6IE;"!K87)A:W1E<B!C<V%K(&5G>65T;&5N(&MA<F%K=&5R(&QE:&5T+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM
M<V=S='(@(DIO8F(@Z7,@8F%L(&]L9&%L;VX@;&5G>65N(&ME<F5T(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(D-S
M86L@:F]B8B!O;&1A;&]N(&QE9WEE;B!K97)E="(*"B,Z(&QI8B]&:6QE+T-3
M5BYP:'`Z-#<Y"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I
M;F=L92!C:&%R86-T97(N(@IM<V=S='(@(D%Z(&5L=N%L87-Z=/,@:V%R86MT
M97(@8W-A:R!E9WEE=&QE;B!K87)A:W1E<B!L96AE="XB"@HC.B!S97)V:6-E
M<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")!
M*'HI(%PB)7-<(B!S>F5R=F5R="!T]G+V;'3\:RXB"@HC.B!S97)V:6-E<R]P
M;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B02AZ*2!<
M(B5S7"(@<WIE<G9E<G0@96QM96YT971T_&LN(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S
M="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B)7,@8F5J96QE
M;G1K97KI<VD@:^ER96QMZ70@=/9R]FQT_&LN(@H*(SH@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT-S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="XB"FUS
M9W-T<B`B02!M96=A9&]T="!S;W(@*"5D*2!N96T@;.ET97II:RXB"@HC.B!L
M:6(O5D93+W-Q;"YP:'`Z,3<Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T
M96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@
M(D$H>BD@7"(E<UPB(&ED96EG;&5N97,@9N%J;"!N96T@;.ET97II:RXB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,P-@IM<V=I9"`B5&AE('1E>'0@>6]U
M(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N
M+B(*;7-G<W1R(")!(&)E[7)T('-Z]G9E9R!N96T@96=Y97II:R!A(&OI<&5R
M;GGU;B!L97;U=F5L+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O
M;2!S:61E<R!O;FQY(@IM<V=S='(@(D%L=6P@Z7,@9O9L_&P@;&5G>65N(&ME
M<F5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B
M0W-A:R!F96YT(&QE9WEE;B!K97)E="(*"B,Z(&QI8B](;W)D92]$871A+G!H
M<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E
M('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R(")!(&9E;'3V;'3V='0@861A
M=&]K(&%Z(&5L]7KU(&SI<.ES(/-T82!E;'9E<WIT96LN(@H*(SH@;&EB+TAO
M<F1E+T1A=&$O8W-V+G!H<#HR-C(@;&EB+TAO<F1E+T1A=&$O='-V+G!H<#HQ
M-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E
M9"XB"FUS9W-T<B`B02!F96QT]FQT]G1T(&;A:FQT(&YE;2!S:6ME<OQL="!E
M;&UE;G1E;FDN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Y
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3`*;7-G:60@(E1H92!W
M96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")!
M('=E871H97(N8V]M(&)L;VMK(&YE;2!H87-Z;N%L:&%T\RXB"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")!(&UE
M9VIE;&5NZ7-I('-T[6QU<R`H=&AE;65S*2!A;&OV;GEV=.%R(%PB)7-<(B!N
M96T@=&%LX6QH873S+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3<X
M"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S
M='(@(DYI;F-S96X@=N%L87-Z=&AA=/,@;W!C:?,N(@H*(SH@;&EB+TAO<F1E
M+TU)344O0V]N=&5N=',N<&AP.C,T.0IM<V=I9"`B5&AE<F4@87)E(&YO('!A
M<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(DYI
M;F-S(&$@;&5VZ6P@8F5L<V5JZ6)E;B!M96=J96QE;NUT:&5T]2!M96QLZ6ML
M970N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@
M=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B
M"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*(E3Z
M;"!S;VL@:V%R86MT97(@=F%N(&5B8F5N(&$@;65Z]6)E;BX@UFX@)7,@:V%R
M86MT97)T(&%D;W1T(&UE9SL@82`B"B)M87AI;>%L:7-A;B!M96=A9&AA=/,@
M<&5D:6<@:V5V97-E8F(L(&UI;G0@)7,N(@H*(SH@<VEG;G5P+G!H<#HU,R!A
M9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B
M"FUS9W-T<B`B7"(E<UPB(&9E;&AA<WINX6SS;F%K(&$@<F5N9'-Z97)H97H@
M863A<V%K;W(@:&EB82!T]G)TZ6YT+B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E
M;3H@(@IM<V=S='(@(EPB)7-<(B!F96QH87-Z;N%L\R!A9&%T86EN86L@=/9R
M;.ES92!S;W+A;B!H:6)A(&SI<&5T="!F96PZ("(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B
M;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R
M(")<(B5S7"(@<F5N9'-Z97)B]6P@=F%L\R!T]G)LZ7-E:V]R(&AI8F$@;.EP
M971T(&9E;#H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB
M.B`E<R(*;7-G<W1R(")<(B5S7"(@;?-D;W/M=.%S82!S;W+A;B!H:6)A(&SI
M<&5T="!F96PZ("5S(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDR-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@
M(B(*(D%Z(.%L;&]MX6YY="!N96T@<VEK97+\;'0@82!S>F5R=F5R<F4@9F5L
M=/9L=&5N:2X@)7,@;F5M('3V;'3U9/9T="!F96PN(@H*(SH@;&EB+TAO<F1E
M+T)R;W=S97(N<&AP.CDS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@
M=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H
M)60@8GET97,I+B(*;7-G<W1R("(B"B)!>B#A;&QO;>%N>70@;F5M('-I:V5R
M_&QT(&$@<WIE<G9E<G)E(&9E;'3V;'1E;FDN("5S(&YA9WEO8F(L(&UI;G0@
M82`B"B)M87AI;>%L:7-A;B!M96=E;F=E9&5T="!MZ7)E="`H)60@8N%J="DN
M(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*
M;7-G<W1R("(B"B)!>B#A;&QO;>%N>70@;F5M('-I:V5R_&QT(&$@<WIE<G9E
M<G)E(&9E;'3V;'1E;FDN($$H>BD@)7,@9N%J;&YA:R!C<V%K(&5G>2`B"B)R
MZ7-Z92!T]FQT]63V='0@9O9L+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES
M<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R(")!(&QE=NEL(&4@
M<NES>NEN96L@;65G:F5L96[M=.ES96MO<B!H:6)A('3V<G3I;G0B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B02!P
M87)T;F5R(&%D871O:R!I;7!O<G3A;.%S82!S;W+A;B!H:6)A('3V<G3I;G0N
M(@H*(SH@;&EB+TAO<F1E+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM
M<V=S='(@(D%Z(&E#86QE;F1A<B!A9&%T;VL@:6UP;W)TX6SA<V$@<V]RX6X@
M:&EB82!T]G)TZ6YT+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#(*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A
M=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D
M(&9I96QD+B(*;7-G<W1R("(B"B)(:6+A<R!A(&UE9V%D;W1T(&MO;F9I9W5R
MX6-I\RX@3&5H970L(&AO9WD@;F5M('3V;'3V='0@:VD@96=Y('-Z_&MSZ6=E
M<R`B"B)M97KU="XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN
M9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E
M("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB02!P87)T;F5R:F5G
M>7KI:VME;"!K87!C<V]L871O<R!F96QA9&%T(';I9W)E:&%J=.%S82!S;W+A
M;B!H:6)A(&SI<&5T="!F96PN("(*(DOI<F5M('!R\V+A;&IA(&UE9R!KZ7/U
M8F(N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT
M86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@
M(B(*(DAI8F$@=/9R=.EN="!A('!A<G1N97(@861A=&%I;F%K(&9R:7-S[73I
M<V4@<V]RX6XN($OI<F5M('!R\V+A;&IA(&UE9R!KZ7/U8F(N(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-2!L:6(O3F5T+U--4R]W
M:6Y?:'1T<"YP:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+B(*;7-G<W1R("(B"B)!(&OV<FQE=NEL;&ES=&$@861A=&%I
M;F%K(&9R:7-S[73I<V4@<V]RX6X@:&EB82!T]G)TZ6YT+B!+Z7)E;2!P<O-B
MX6QJ82!M96<@(@HB:^ES]6)B+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N
M;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(B(*(D5Z(&%Z
M($E-05`@<WIE<G9E<B!N96T@=.%M;V=A=&IA(&$@;6%P<.%K:&]Z('9A;/,@
M:&]Z>N%FZ7+I<R!M96=O<WITX7/A="XB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B17H@;F5M('3[
M;FEK('-Z86+A;'EO<R!R87(@X6QL;VWA;GEN86LN(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@
M87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(D5Z(&YE
M;2!T^VYI:R!S>F%BX6QY;W,@>FEP(.%L;&]MX6YY;F%K+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HS,3,Q"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@
M=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B17H@;F5M('3[
M;FEK(.ER=NEN>65S(&OA<G1Y87-ZX6UN86LN(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K
M871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I
M;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(D5Z(&$@;65G:&%J=/,@;&5H
M973U=ND@=&5S>FDL(&AO9WD@2%144"UK87!C<V]L871O;B!335,M="!K_&QD
M:OQN:R!A("(*(D-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@
M<WIO;&?A;'1A=/-N(.%T+B(*"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H
M<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI
M("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)%
M>B!A(&UE9VAA:G3S(&QE:&5T]7;I('1E<WII+"!H;V=Y($A45%`M:V%P8W-O
M;&%T;VX@4TU3+70@:_QL9&K\;FL@82!724X@(@HB*&AT='`Z+R]W:6YP;&,N
M8V]M*2!S>F]L9^%L=&%T\VX@X70N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH
M='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)(@IM<V=S='(@(B(*(D5Z(&$@;65G:&%J=/,@;&5H973U=ND@=&5S
M>FDL(&AO9WD@2%144"UK87!C<V]L871O;B!335,M="!K_&QD:OQN:R!A>B`B
M"B)S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!S>F]L9^%L=&%T
M\VX@X70N(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@
M(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U
M:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@
M*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@HB17H@82!M96=H86IT
M\R!L96AE=/5VZ2!T97-Z:2P@:&]G>2!33510+6MA<&-S;VQA=&]N(%--4RUT
M(&O\;&1J_&YK(%9O9&%F;VYE("(*(G-ZX6UO:W)A(&$@5F]D869O;F4@271A
M;'D@*&AT='`Z+R]W=W<N,3DP+FET*2!S>F]L9^%L=&%T\VX@X70N($$@(@HB
M<WIO;&?A;'1A=.%S(&EGZ6YY8F5VZ71E;.EH97H@5F]D869O;F4@271A;'D@
M96UA:6P@8^UM('-Z_&MSZ6=E<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M.3@R(&QI8B](;W)D92]&;W)M+G!H<#HQ,#8Q(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,#DP"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3$Y(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,3@V(&QI8B](;W)D92]&;W)M+G!H<#HQ,C8P"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,S`Y(&QI8B](;W)D92]&;W)M+G!H<#HQ-#`R(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-38Q"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.#0S(&QI8B](;W)D92]&;W)M+G!H<#HQ.38R(&QI8B](;W)D92]&;W)M+G!H
M<#HR,#`Y"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#,S(&QI8B](;W)D92]&
M;W)M+G!H<#HR,#@R(&QI8B](;W)D92]&;W)M+G!H<#HR,34S"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,C(U(&QI8B](;W)D92]&;W)M+G!H<#HR-#$R(&QI
M8B](;W)D92]&;W)M+G!H<#HR-#4T"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M-C0Q(&QI8B](;W)D92]&;W)M+G!H<#HR.#$T(&QI8B](;W)D92]&;W)M+G!H
M<#HS,3(S"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S`Q(&QI8B](;W)D92]&
M;W)M+G!H<#HS.#`Y(&QI8B](;W)D92]&;W)M+G!H<#HS.#$W"FUS9VED(")4
M:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R(")%>B!A(&UE>O4@;F5M
M(&UA<F%D:&%T(/QR97,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-CD*
M;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB
M"FUS9W-T<B`B16)B96X@82!M97KU8F5N(&-S86L@96?I<WH@<WKA;6]K(.%L
M;&AA=&YA:RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0R,`IM<V=I9"`B
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C
M;VQO;BXB"FUS9W-T<B`B16)B96X@82!M97KU8F5N(&-S86L@96?I<WH@<WKA
M;6]K(.ES(&ME='3U<W!O;G0@;&5H970N(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$P.3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O
M8W1A;"!V86QU97,N(@IM<V=S='(@(D5B8F5N(&$@;65Z]6)E;B!C<V%K(&]K
M=.%L:7,@<WKA;6]K(.%L;&AA=&YA:RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3$R-PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@
M<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B(@HB
M17H@82!M97KU(&-S86L@=F5S<WKU=F5L('9A9WD@<WKS:_9Z>F5L(&5L=N%L
M87-Z=&]T="!E9^ES>B!S>N%M;VMA="`B"B)T87)T86QM87IH870B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z.3DS"FUS9VED(")4:&ES(&9I96QD(&UU<W0@
M8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(D5Z(&%Z(.ER=.EK(&-S86L@
M<WKA;2!L96AE="XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@R,@IM<V=I
M9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN
M('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G
M+B(*;7-G<W1R(")%8F)E;B!A(&UE>O5B96X@:&5X861E8VEMX6QI<R!21T(@
M<WKM;FOS9"#A;&QH870L('!L+B`G(S$R,S1A9B<N(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C4V-0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E
M96X@<')O8V5S<V5D+B(*;7-G<W1R(")%>F5N(&%D871O:VMA;"!K87!C<V]L
M871O<R!F96QA9&%T;VMA="!A('-Z97)V97(@;>%R(&5L=NEG97IT92XB"@HC
M.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&ES(&ES("5S+B(*;7-G<W1R(")%>B`E<R(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z-#8Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@
M:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J
M96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD
M97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI
M<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*
M;7-G<W1R("(B"B)%>B!E9WD@2V]L86(@1W)O=7!W87)E(&]B:F5K='5M+B!!
M>B!I;'EE;B!O8FIE:W1U;2!M96=J96QE;NUTZ7/I:&5Z(&]L>6%N("(*(F5M
M86EL(&ML:65N<W!R;V=R86T@<WK\:W/I9V5S+"!A;65L>2!KZ7!E<R!A($MO
M;&%B($=R;W5P=V%R92!F;W)MX71U;2`B"B)K97IE;.ESZ7)E+B!);'EE;B!E
M;6%I;"!K;&EE;G-E:R!L:7-TX6IA(&SA=&AA=/,@:71T.B`E<R(*"B,Z(&QI
M8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HU.3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R
M('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(D5Z="!A
M(&QE=F5L970@;>%S(&MA<F%K=&5R:^ES>FQE='1E;"`H)7,I(.UR=.%K+"!M
M:6YT(&%M:70@UFX@:&%S>F[A;"XB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN
M<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O
M;F4N(@IM<V=S='(@(D5Z(&$@<WKA;2!N96T@;&5H970@96=Y;NEL(&MI<V5B
M8BXB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@
M(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I
M;&5S+B(*;7-G<W1R(")%>B!A('-Z97)V97(@;F5M(&OI<&5S(&MI8F]N=&%N
M:2!A('II<"!I;&PN(&=Z:7`@X6QL;VWA;GEO:V%T+B(*"B,Z(&QI8B](;W)D
M92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R
M96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(D5Z(&$@<F5N9'-Z97(@:F5L
M96YL96<@:6YA:W1I=N%L=F$@=F%N+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]5
M22YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N
M(@IM<V=S='(@(D5Z(&%Z(.ER=.EK(&-S86L@<WKA;2!L96AE="XB"@HC.B!S
M97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES
M('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W
M(@IM<V=S='(@(D5Z="!A>B!A8FQA:R!C<V%K(&%Z($]P8VGS:R!A8FQA:V+S
M;"!H[79H873S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C4*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B5FEL;.%M;.%S(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-@IM<V=I9"`B5&EC:V5T
M<R(*;7-G<W1R(")(:6)A8F5J96QE;G3I<RUK97IE;.ES(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(T,CD@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C4U"FUS9VED(")4:6UE(@IM<V=S='(@(DED]2(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS.#@*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T
M<B`B375N:V%I9/4M;GEI;';A;G1A<G3A<R(*"B,Z(&QI8B]";&]C:R]T:6UE
M+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B263U(&9O<FWA
M='5M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U,S4*;7-G:60@(E1I;64@
M<V5L96-T:6]N(@IM<V=S='(@(DED]2!VX6QA<WITX7,B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C,P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4
M:6UO<BU,97-T92(*;7-G<W1R(")+96QE="U4:6UO<B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N
M<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R(")4:71U;'5S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B
M5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R(")#[6T@*'1O;VQT:7`I(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O
M(@IM<V=S='(@(D/M;7IE='0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-C4T"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@
M:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@
M*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B)(82!T
M]F)B(&5L96UE="!I<R!K:2!A:V%R(&IE;/9L;FDL('1A<G1S82!L96YY;VUV
M82!A($-O;G1R;VP@*%!#*2!V86=Y(&$@(@HB0V]M;6%N9"`H36%C*2!B:6QL
M96YT>?MT(&$@:V%T=&EN=.%S(&OV>F)E;BXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S`P"FUS9VED(")4;V1A>2(*;7-G<W1R(")-82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*
M;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R(")(5$U,(&9O<G+A
M<V[I>F5T(&MI+V)E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G;R(*;7-G<W1R(")4;V=O(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R(")4;VME;&%U(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,@IM<V=I9"`B5&]M;W)R;W<B"FUS
M9W-T<B`B2&]L;F%P(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B5&]N9V$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S<*;7-G:60@(E1O<"(*;7-G<W1R(")F]FS\;"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F
M<F%M92`H7W1O<"DB"FUS9W-T<B`B3&5G9F5L<_4@9G)A;64@*%]T;W`I(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA=&EO
M;G,B"FUS9W-T<B`B1F]R9.UTX7-O:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N
M9"!4;V)A9V\B"FUS9W-T<B`B5')I;FED860@Z7,@5&]B86=O(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$W.30*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS
M9W-T<B`B26=A>B!V86=Y(&AA;6ES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`B2V4B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(E1U;NEZ:6$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C,Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED
M(")4=7)K97DB"FUS9W-T<B`B5/9R]FMO<G-ZX6<B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS
M9W-T<B`B=/9R]FL@*$E33RTX.#4Y+3DI(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(R-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES
M=&%N(@IM<V=S='(@(E3\<FMM96YI<WITX6XB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C(P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S`*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A
M;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B5'5R:W,M(.ES($-A:6-O<RUS
M>FEG971E:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R(")4=79A;'4B"@HC
M.B!L:6(O2&]R9&4O0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I
M8V4Z("(*;7-G<W1R("+-<FIA(&)E+"!M:70@=N%L87-Z=&]T=#H@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.`IM<V=I9"`B52Y6+B!I
M;F1E>#H@(@IM<V=S='(@(E56(&EN9&5X.B`B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ
M-PIM<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I
M<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B"B)54DPL(&UE
M;'EE;B!E9WD@<')O9W)A;2!E;&9O9V%D:F$@82!S>F]L9^%L=&%T\R#A;'1A
M;"!K_&QD]G1T(&O\;&3V='0@(@HB:^EZ8F5S[73I<VD@:F5L96YTZ7-T(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM
M<V=I9"`B55),.B(*;7-G<W1R(")54DPZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(S-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM
M<V=S='(@(E5G86YD82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B56MR
M86IN82(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-#$Y"FUS9VED(")5;F%B;&4@
M=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYE;2!S:6ME<OQL
M="!A(%9&4R!A;&OV;GETX7)B82!B96SI<&YI+B(*"B,Z(&QI8B](;W)D92]!
M=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@
M=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(B(*
M(D$@8F5J96QE;G1K97KI<VD@:F]G;W-U;'1SX6<@:6?I;GELZ7-E:V]R(&YE
M;2!S:6ME<OQL="!A>B!A9&%T;VL@96QTX7)O;.%S82XB"@HC.B!L:6(O5D93
M+V9T<"YP:'`Z,SDS"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M("(B"B).96T@<VEK97+\;'0@82AZ*2!<(B5S7"(@5D93(&;A:FP@96SI<NES
M:2!J;V=O<W5L='/A9V%I="!M96=VX6QT;WIT871N:2XB"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C,Y,B!L:6(O5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!6
M1E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B(@HB3F5M('-I:V5R_&QT(&$H>BD@
M)7,O)7,@5D93(&;A:FP@96SI<NES:2!J;V=O<W5L='/A9V%I="!M96=VX6QT
M;WIT871N:2XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S@V"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(DYE
M;2!S:6ME<OQL="!A*'HI("5S(&%L:_9N>79TX7)B82!B96SI<&YI+B(*"B,Z
M(&QI8B]61E,O9G1P+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(D$H
M>BD@7"(E<UPB(.%L;&]MX6YY(&WI<F5T92!N96T@X6QL87#M=&AA=/,@;65G
M+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-CDU(&QI8B]61E,O<W%L+G!H<#HQ
M,#(X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C@U,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB
M"FUS9W-T<B`B02AZ*2!<(B5S+R5S7"(@X6QL;VWA;GD@;>ER971E(&YE;2#A
M;&QA<.UT:&%T\R!M96<N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<W%L+G!H<#HT
M,SD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM
M<V=S='(@(D%Z(%-13"!S>F5R=F5R(&YE;2#I<FAE=/4@96PN(@H*(SH@;&EB
M+U9&4R]F='`N<&AP.C@W,`IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET
M:"!34TPN(@IM<V=S='(@(D%Z(%-33"!K87!C<V]L870@;F5M(.EP[71H973U
M(&9E;"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(S,B!L:6(O5D93+V9I;&4N
M<&AP.C(S-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,#0*(SH@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z,C`Y(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(Q-PIM<V=I
M9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(D$@5D93(&;A
M:FP@;F5M(&WA<V]L:&%T\R#A="XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S<P
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I
M<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DYE;2!S:6ME<OQL="!A*'HI(%PB
M)7-<(B!61E,@86QK]FYY=G3A<G0@;.ET<F5H;WIN:2XB"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C,V,2!L:6(O5D93+VUU<W%L+G!H<#HR-3@@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z,C8T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(DYE;2!S:6ME<OQL="!LZ71R96AO>FYI(&$@
M5D93(&%L:_9N>79TX7)T+B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$R-`IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`B3F5M
M('-I:V5R_&QT(&SI=')E:&]Z;FD@82!61E,@9N%J;'0N(@H*(SH@;&EB+U9&
M4R]S;6(N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")!*'HI(%PB)7-<
M(B!61E,@;6%P<&$@;F5M(&AO>FAA=/,@;.ET<F4N(@H*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HR-S(*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93
M(&9I;&4N(@IM<V=S='(@(DYE;2!S:6ME<OQL="!LZ71R96AO>FYI(/QR97,@
M5D93(&;A:FQT+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]T87(N<&AP.C<V
M(&QI8B](;W)D92]#;VUP<F5S<R]G>FEP+G!H<#HW.0IM<V=I9"`B56YA8FQE
M('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B02!T]FWV<NUT971T(.%L
M;&]MX6YY="!N96T@<VEK97+\;'0@:VEB;VYT86YI+B(*"B,Z(&QI8B]61E,O
M<VUB+G!H<#HR,C@@;&EB+U9&4R]F='`N<&AP.C,P,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R
M>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(EPB)7-<(B!N96T@=/9R]FQH973U
M+"!A>B!A;&OV;GEV=.%R(&YE;2#\<F5S+B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@
M(EPB)7-<(B!T]G)LZ7-E(&YE;2!S:6ME<OQL=#H@)7,N(@H*(SH@;&EB+U9&
M4R]F:6QE+G!H<#HS,S@@;&EB+U9&4R]S<6PN<&AP.C,Y-2!L:6(O5D93+VUU
M<W%L+G!H<#HS,3$*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S0R"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E
M8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(B5S(&YE;2!T]G+V;&AE=/4L
M(&%Z(&%L:_9N>79TX7(@;F5M(/QR97,N(@H*(SH@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,S4V(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,V,`IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G
M<W1R(")!(%9&4R!A;&OV;GEV=.%R(&YE;2!T]G+V;&AE=/4@<F5K=7)Z[79A
M;BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,T-"!L:6(O5D93+VUU<W%L+G!H
M<#HS,C(@;&EB+U9&4R]M=7-Q;"YP:'`Z,S,U"B,Z(&QI8B]61E,O;75S<6PN
M<&AP.C,T,R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B02!61E,@86QK
M]FYY=G3A<B!N96T@=/9R]FQH973U+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HT
M,C`@;&EB+U9&4R]S<6PN<&AP.C0S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(")!
M(%9&4R!A;&OV;GEV=.%R(&YE;2!T]G+V;&AE=/4Z("5S+B(*"B,Z(&QI8B]6
M1E,O9G1P+G!H<#HR,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D$H>BD@7"(E<UPB
M(%9&4R!FX6IL(&YE;2!T]G+V;&AE=/4N(@H*(SH@;&EB+U9&4R]F:6QE+G!H
M<#HS,3`@;&EB+U9&4R]S<6PN<&AP.C(Y,2!L:6(O5D93+VUU<W%L+G!H<#HQ
M-C<*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3@P(&QI8B]61E,O;75S<6PN<&AP
M.C$X-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS.3$*(SH@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,SDY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE
M+B(*;7-G<W1R(")!(%9&4R!FX6IL(&YE;2!T]G+V;&AE=/4N(@H*(SH@;&EB
M+U9&4R]S;6(N<&AP.C(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")!*'HI(%PB
M)7-<(B!61E,@;6%P<&$@;F5M('3V<O9L:&5T]2XB"@HC.B!L:6(O5D93+W-Q
M;"YP:'`Z-#`Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B3F5M(';I9V5Z:&5T
M\R!R96MU<GKM=B!T]G)LZ7,@82!61E,M8F5N.B`E<RXB"@HC.B!L:6(O5D93
M+V9T<"YP:'`Z.#,T"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E
M;G0@9&ER96-T;W)Y+B(*;7-G<W1R(").96T@:&%TX7)O>FAA=/,@;65G(&$@
M:F5L96YL96<@Z7)VZ6YY97,@86QK]FYY=.%R+B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-C`T"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C
M97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(D$@=&%N^G/M=';A;GD@<NES
M>FQE=&5S(&%D871A:2!N96T@:&%TX7)O>FAA=/-K(&UE9R(*"B,Z(&QI8B].
M970O24U34"YP:'`Z-#,W(&QI8B].970O24U34"]!=71H+G!H<#HQ,C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I
M;VX@;V8@)7,N(@IM<V=S='(@(DYE;2!S:6ME<OQL="!B96]L=F%S;FD@)7,@
M9&5F:6[M8VGS:N%T+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C`S(&QI8B]6
M1E,O9FEL92YP:'`Z,C`X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$W-`HC.B!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-SD*;7-G:60@(E5N86)L92!T;R!M;W9E
M(%9&4R!F:6QE+B(*;7-G<W1R(")!(%9&4R!FX6IL(&YE;2!H96QY97IH973S
M(.%T+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HY,R!L:6(O5D93+W-M8BYP:'`Z
M,3`V(&QI8B]61E,O<VUB+G!H<#HV-3(*(SH@;&EB+U9&4R]F='`N<&AP.CDX
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`B02AZ*2!<(B5S7"(@5D93(&;A:FP@;F5M(&YY
M:71H873S(&UE9RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(X-"!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HQ,S@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,30Q"FUS
M9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS
M9W-T<B`B02!61E,@9N%J;"!N96T@;GEI=&AA=/,@;65G(.URX7-I(&/I;&QA
M;"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C@S(&QI8B]61E,O9FEL92YP:'`Z
M,3,W(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<V"FUS9VED(")5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B02!61E,@9N%J;"!N96T@;GEI=&AA
M=/,@;65G("XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HT
M-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*
M;7-G<W1R(")!('3V;?9R[71E='0@X6QL;VWA;GD@;F5M(&YY:71H873S(&UE
M9RXB"@HC.B!L:6(O5D93+G!H<#HX-38*;7-G:60@(E5N86)L92!T;R!R96%D
M(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(D$@5D93
M(&;A:FP@;F5M(&]L=F%S:&%T\R`H82!F:6QE<VEZ92@I('-I:V5R=&5L96X@
M=F]L="DN(@H*(SH@;&EB+U9&4RYP:'`Z.#@W"FUS9VED(")5;F%B;&4@=&\@
M<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G<W1R
M(")!(%9&4R!FX6IL(&YE;2!O;'9A<VAA=/,@*&$@9V5T1FEL95-I>F4H*2!S
M:6ME<G1E;&5N('9O;'0I+B(*"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE
M<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM
M<V=S='(@(D5Z(&$@9N%J;"!N96T@;VQV87-H873S.B`B"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C8W-@IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O
M;W0@9&ER96-T;W)Y+B(*;7-G<W1R(")!('9F<W)O;W0@86QK]FYY=G3A<B!N
M96T@;VQV87-H873S+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3$P.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S
M.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B
M)7,@;F5M(&YE=F5Z:&5T]2#A="`E<R!NZ79R93H@;>%R(&SI=&5Z:6L@:6QY
M96X@;F5V^R!M87!P82(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,P,0IM
M<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R
M(")!(%9&4R!A;&OV;GEV=.%R(&YE;2!N979E>FAE=/4@X70N(@H*(SH@;&EB
M+U9&4R]S<6PN<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(")!(%9&4R!A
M;&OV;GEV=.%R(&YE;2!N979E>FAE=/4@X70Z("5S+B(*"B,Z(&QI8B]61E,O
M<VUB+G!H<#HR-S$@;&EB+U9&4R]F='`N<&AP.C,T.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B02AZ*2!<(B5S7"(@5D93(&;A:FP@;F5M(&YE=F5Z:&5T]2#A="XB
M"@HC.B!L:6(O5D93+V9I;&4N<&AP.C8Q-R!L:6(O5D93+VUU<W%L+G!H<#HR
M,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92`E<R\E<RXB"FUS9W-T<B`B02AZ*2`E<R\E<R!61E,@9N%J;"!N96T@
M;F5V97IH973U(.%T+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HS,C8@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,C$S(&QI8B]61E,O;75S<6PN<&AP.C0U,@HC.B!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HR.3,@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S`Y
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R(")!
M(%9&4R!FX6IL(&YE;2!N979E>FAE=/4@X70N(@H*(SH@;&EB+U9&4R])4T]7
M<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK
M:7-O9G,G+B(*;7-G<W1R(")!>B`G;6MI<V]F<R<@<')O9W)A;2!N96T@9G5T
M=&%T:&%T\RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O;7-W;W)D+G!H
M<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C
M=6UE;G0B"FUS9W-T<B`B3F5M('-I:V5R_&QT(&QE9F]R9.UT86YI(&5Z="!A
M(%=O<F0@9&]K=6UE;G1U;6]T(@H*(SH@;&EB+U9&4R]F='`N<&AP.C$U-"!L
M:6(O5D93+V9T<"YP:'`Z,34W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D$H>BD@7"(E
M<UPB(%9&4R!FX6IL(&YE;2#M<FAA=/,N(@H*(SH@;&EB+U9&4R]F:6QE+G!H
M<#HQ.#8*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I
M(&9A:6QE9"DN(@IM<V=S='(@(D$@5D93(&;A:FP@;F5M(.UR:&%T\R`H82!C
M;W!Y*"D@<VEK97)T96QE;B!V;VQT*2XB"@HC.B!L:6(O5D93+V9I;&4N<&AP
M.C(X."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-#8@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,34Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T
M82XB"FUS9W-T<B`B02!61E,@9N%J;"!A9&%T86D@;F5M(.UR:&%T\VL@:VDN
M(@H*(SH@;&EB+U9&4RYP:'`Z.#8R"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@(D$@
M5D93(&;A:FP@[7+A<V$@:W;S=&%T^FQLZ7#I<R!M:6%T="!N96T@9F5J97IH
M973U(&)E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R(")A;.%H^GIO='0B
M"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H
M86YG97,B"FUS9W-T<B`B3>EG<V4@;65N='/\:R!E;"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E
M<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(E9I<W-Z879O;FIA(&%Z('5T
M;VQS\R!VX6QT;WIT873A<W0B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,C(Q(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M.#@*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@
M8V]N;F5C=&EO;CH@(@IM<V=S='(@(B(*(D$@:V%P8W-O;&%T(&9E;';I=&5L
MZ70@:_9V973U96X@=N%R871L86X@=N%L87-Z(.ER:V5Z971T(&$@<WIE<G9E
M<G3U;#H@(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q
M-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S,Y"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S8@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,X,@IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS
M92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(E;A<F%T;&%N(';A;&%S>B#I
M<FME>F5T="!A('-Z97)V97)T]6P@97)R93H@(@H*(SH@;&EB+TAO<F1E+U!R
M969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS
M9W-T<B`B0F5S;W)O;&%T;&%N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.38*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R(")5;FEC;V1E("A5
M5$8M."DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B
M16=Y97/\;'0@07)A8B!%;>UR<^EG96LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C,X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG
M9&]M(@IM<V=S='(@(D5G>65S_&QT($MI<N%L>7/A9R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(S-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N
M:71E9"!3=&%T97,B"FUS9W-T<B`B16=Y97/\;'0@P6QL86UO:R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(S-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G
M:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G
M<W1R(")%9WEE<_QL="#!;&QA;6]K+"!K:7-E8F(@:_QL<_4@<WII9V5T96LB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C(@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HW.`IM<V=I9"`B56YI=',B"FUS9W-T<B`B96=Y<^EG(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(Y(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C0S,`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H
M<#HU.`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R("))<VUE<F5T;&5N(@H*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N
M:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B27-M
M97)E=&QE;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N
M(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(DES;65R
M971L96X@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30W"FUS9VED(")5;FMN;W=N(&QO
M8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")!(&UE9V%D;W1T(&AE;'D@:7-M
M97)E=&QE;BXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS
M9W-T<B`B27-M97)E=&QE;B!F96QH87-Z;N%L\VD@;NEV('9A9WD@:F5L<WKS
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B
M"FUS9W-T<B`B5.%V;VSM='-U:R!E;"!I;FYE;B!A(&QI;FME="(*"B,Z(&QI
M8B](;W)D92])9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")5;FYA;65D(@IM<V=S
M='(@(DYI;F-S(&5L;F5V97IV92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S
M8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T
M:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@
M<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB
M<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE
M(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@HB0FEZ=&]N<^%G:2!O:V]K8O-L(&$@
M9F5L:&%S>F[A;/-I('!R;V=R86UO:R!N96T@:&%S>F[A;&AA=&KA:R!A($MI
M=N%GX7,O(@HB3>%S;VSA<R]"96EL;&5S>G3I<R!M\V1S>F5R="X@2V%T=&EN
M='-O;B!A>B!/2R!G;VUB<F$L(&AA(&$@;6]Z:6QL82YO<F<@(@HB=V5B;VQD
M86QO;B!E;"!K[7;A;FIA(&]L=F%S;FD@82!T96-H;FEK86D@;&7M<N%S="!M
M96QY(&UE9V%D:F$L(&AO9WEA;B!L96AE="`B"B)E>G0@;>EG:7,@96YG963I
M;'EE>FYI+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(D$@
M<WKM;B!V:7-S>F'A;&SM=.%S82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-C@W(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z.3(W"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z.3,S"FUS9VED(")5;G-U<'!O<G1E
M9"!%>'1E;G-I;VXB"FUS9W-T<B`B3F5M('3A;6]G871O='0@97AT96YZ:?,B
M"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@(DWS
M9&]S[73A<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(B5S
M(&%D871A:6YA:R!M\V1O<^UTX7-A(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B
M02!F96QH87-Z;N%L\R!A9&%T86EN86L@;?-D;W/M=.%S82(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V
M:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G:60@
M(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@=N%L=&]ZX7-A:70@
M96QM96YT971T_&LN(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*
M;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(D%Z('5P
M9W)A9&4@<')O9W)A;6]T('3V<O9L=/QK+B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-S@@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Y.`IM<V=I9"`B57!L;V%D(@IM<V=S='(@(D9E;'3V;'3I<R(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A
M<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R
M(")!>B#V<W-Z97,@86QK86QM87KA<R!K;VYF:6=U<N%C:?-JX70@9F5L=/9L
M=/9T=/QK(&$@<WIE<G9E<G)E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA
M=&EN(&QE='1E<G,B"FUS9W-T<B`B;&%T:6X@;F%G>6)E=/MK(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ
M.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(")N86=Y8F5T
M^W,@<O-M86D@<WKA;6]K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R(")5
M<G5G=6%Y(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM
M<V=S='(@(DAA<WINX6QJ=6L@82!J96QE;FQE9VET.B`E<R(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB
M"FUS9W-T<B`B2&%S>F[A;&IU;FL@4U-,+70B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3(W"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D
M:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R("(B"B)!:VMO<B!H
M87-Z;N%L:G5K+"!H82!A>B!)35-0('-Z97)V97)E;B!MX7,@82!B96IE;&5N
M=&ME>NES:2!N97;\;FLO(@HB:F5L<WIA=G5N:RXB"@HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"FUS9VED(")5<V5R(@IM<V=S='(@
M(D9E;&AA<WINX6SS:2!NZ78B"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP
M.C<W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H
M;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B)7,@9F5L:&%S>F[A;/,@;F5M(&IO
M9V]S=6QT("5S+7)E+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B
M57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")&96QH87-Z;N%L\VL@861M
M:6YI<WIT<N%LX7-A(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HR-#4*
M;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R(")&96QH87-Z;N%L\VD@8F7A
M;&SM=.%S;VLB"@HC.B!S:6=N=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E9VES
M=')A=&EO;B(*;7-G<W1R(")"96IE;&5N=&ME>NES(&IO9V]S=6QT<^%G(&EG
MZ6YY;.ES92(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T
M<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S
M='(@(B(*(D5Z96X@82!R96YD<WIE<F5N(&YI;F-S(&5N9V5DZ6QY97IV92!A
M>B#Z:B!F96QH87-Z;N%L\VL@8F5J96QE;G1K97KI<VD@(@HB:F]G;W-U;'1S
MX6?A;F%K(&EGZ6YY;.ES92XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-#8Y"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(D%Z
M(&9E;&AA<WINX6SS:2!A>F]N;W/M=/,@;F5M('1A;.%L:&%T\R(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-B!L:6(O3F5T+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,3DX(&QI8B].970O4TU3+W=I;E]H='1P+G!H
M<#HQ-3`*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHW,@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B1F5L
M:&%S>F[A;/-I(&[I=B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z
M,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E
M861Y(&5X:7-T<RXB"FUS9W-T<B`B02AZ*2!<(B5S7"(@9F5L:&%S>F[A;/-I
M(&[I=B!MX7(@;.ET97II:RXB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(")&96QH87-Z;N%L
M\VD@;NEV.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*;7-G
M:60@(E5S97)N86UE.B`B"FUS9W-T<B`B1F5L:&%S>F[A;/-I(&[I=CH@(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E
M<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B02!R96YD<WIE<B!F96QH87-Z
M;N%L\VDZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R("+<>F)E9VES
M>G3A;B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3<P(&QI8B]61E,O9FEL92YP
M:'`Z,C8R"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*
M;7-G<W1R(")!(%9&4R!A;&OV;GEV=.%R(&YE;2!LZ71E>FEK+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,C`*;7-G:60@(E9A8V%T:6]N(@IM
M<V=S='(@(E-Z86)A9'/A9R!A;&%T=&D@875T;VUA=&EK=7,@96UA:6PM=N%L
M87-Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@W,`IM<V=I9"`B5F%L:60@
M;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R(")!(&OV=F5T:V5Z
M]2!H96QY96ME="!T86SA;'1U:SH@(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HV,SD*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(LER=NEN>65S
M<^EG(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-R!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L
M=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B07H@Z7)TZ6ME:V5T
M('!E<F-B96X@861J=6L@;65G+"!M;W-T86YT\VP@<WKA;>UT=F$N(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C@V,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$X
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I<R!O=F5R('1H92!M87AI
M;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B02#I<G3I:R!N86=Y;V)B+"!M
M:6YT(&$@;&5G;F%G>6]B8B!M96=E;F=E9&5T="!H;W-S>OISX6<Z("5S+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C0X(&QI8B](;W)D92]&;W)M+G!H
M<#HR,C<P(&QI8B](;W)D92]&;W)M+G!H<#HR,S(P"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR.3$T(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP
M.C4Y"FUS9VED(")686QU97,B"FUS9W-T<B`BR7)TZ6ME:R(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,3$S(&QI8B](;W)D92]&;W)M+G!H<#HR,3DP"FUS
M9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B5N%L87-Z=&AA
M=/,@Z7)TZ6ME:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#D@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B5F%N=6%T
M=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S,*;7-G:60@
M(E9A<FEA8FQE(@IM<V=S='(@(G;A;'1O>O,B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C0U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#$*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E
M;&$B"FUS9W-T<B`B5F5N97IU96QA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES
M(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R
M("(B"B)!(&AI=&5L97/M=.ES(&YE;2!S:6ME<OQL="`M(&QE:&5T+"!H;V=Y
M(&$@;&5V96QE="!V86QA:VD@;65G=N%L=&]Z=&%T=&$N(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E9E<G-I;VXB"FUS9W-T
M<B`B5F5R>FGS(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R.`IM
M<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(E9E<GII\VOV=F5TZ7,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R(")&_&=G+B!E
M;&AE;'EE>NES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R(")&
M_&=G]6QE9V5S(&)E;'/U(&UA<F?S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S
M='(@(F;\9V?U;&5G97,Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-S$*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R(")N86=Y
M;VX@;6%G87,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*;7-G<W1R(")6:65T;F%M
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3<*;7-G:60@(E9I971N86UE
M<V4@*%9)4T-)22DB"FUS9W-T<B`B=FEE=&YA;6D@*%9)4T-)22DB"@HC.B!L
M:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.3<P"B,L('!H<"UF;W)M870*
M;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B)7,@;65G=&5K:6YTZ7-E(@H*(SH@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA
M;"!W96(@<&%G92(*;7-G<W1R(")+_&QS]2!W96)O;&1A;"!M96=J96QE;NUT
MZ7-E(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@R.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(DIE;&5N[71S
M_&L@;65G+"!M:6YT("5S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R
M:71I<V@B"FUS9W-T<B`B0G)I="!6:7)G:6XM<WII9V5T96LB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C0W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR-#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED
M(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R(")!;65R:6MA:2!6:7)G
M:6XM<WII9V5T96LB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-@IM<V=I
M9"`B5FES:6)I;&ET>2(*;7-G<W1R("),X73S=.%V;VQSX6<B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4R"FUS9VED(")6:7-I8FEL:71Y
M.B`B"FUS9W-T<B`B3.%T\W3A=F]L<^%G.B`B"@HC.B!L:6(O3F5T+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L
M>2!V:6$@4TU44"(*;7-G<W1R(")6;V1A9F]N92!)=&%L>2!S>F]L9^%L=&%T
MX7,@4TU44"UN(&ME<F5S>G3\;"(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R
M(")&24=914Q-15I4153)4R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#
M4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R(")&24=914Q-15I4153)
M4R$@2\E:6D5,(%3!5D],S51302!%3"!!(%-#4DE05$54("5S+5+53"XB"@HC
M.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA
M($A45%`B"FUS9W-T<B`B5TE.('-Z;VQGX6QT873A<R!(5%10+6X@X70B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4P(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W
M"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R(")786QL:7,@Z7,@
M1G5T=6YA(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S
M=&%T=7,N<&AP.C(Y"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]H=&UL+G!H
M<#HQ,C<@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG
M(@IM<V=S='(@(D9I9WEE;&UE>G1E=.ES(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B
M4WIE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED
M(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@(DED]6KA<N%S(&5L]7)E:F5L
M>NES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q-@IM<V=I
M9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(D%Z(&ED]6KA
M<N%S:2!A9&%T;VL@9F]R<N%S82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX
M.38*;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B5V5B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S.0IM<V=I9"`B5V5B(%-I=&4B
M"FUS9W-T<B`B5V5B:&5L>65K(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E
M+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(FAE=&5N=&4B"@HC.B!S
M97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*
M;7-G<W1R("+<9';V>O9L:OQK(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H<"UF
M;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`BW&1V]GKV;&K\
M:SH@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP
M;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5V5L8V]M92P@)7,B"FUS9W-T<B`BW&1V]GKV;&K\:RP@)7,B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y.`IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM
M,2DB"FUS9W-T<B`B;GEU9V%T+65U<O-P86D@*$E33RTX.#4Y+3$I(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3D*;7-G:60@(E=E<W1E<FX@*$E33RTX
M.#4Y+3$U*2(*;7-G<W1R(")N>75G870M975R\W!A:2`H25-/+3@X-3DM,34I
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR-#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(DYY=6=A="U3>F%H
M87)A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y
M(&%F=&5R(&QO9VEN/R(*;7-G<W1R(")-:6QY96X@86QK86QM87KA<W0@;75T
M87-S;VX@)7,@82!B96IE;&5N=&ME>NES('5TX6X_(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM
M:71E<B!C:&%R86-T97(_(@IM<V=S='(@(DUI(&%Z(&5L=N%L87-Z=/,@:V%R
M86MT97(_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G
M:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B36D@
M87H@:63I>F5T:V%R86MT97(_(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$P-C0*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA
M<"(*;7-G<W1R(")7:&5R96ES($%U<WIT<N%L:6$@=.ER:^EP(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T
M<B`B365L>6EK(&-I:VQU<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S8*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC
M:"!497AT(&5D:71O<BXB"FUS9W-T<B`B365L>6EK(&UO9'5L;VMA="!A:W1I
M=N%L:G5K(&$@4FEC:"!497AT(&5D:71O<F)A;C\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7
M:61T:"(*;7-G<W1R(")3>NEL97-SZ6<B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,S$Q,0IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(E-Z
MZ6QE<W/I9R!#4U,@96=Y<^EG8F5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@
M;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN
M*3HB"FUS9W-T<B`B(@HB02`E<R!M96[\('-ZZ6QE<W/I9V4@82!B86P@;VQD
M86QO;B`H82!K]G9E=&ME>O4@8F5J96QE;G1K97KI<W0@:_9V973U96X@;&5S
M>B`B"B+I<G;I;GEE<RDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM
M<V=S='(@(D$@=.%B;.%Z870@<WKI;&5S<^EG92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U
M;FET(@IM<V=S='(@(D$@<WKI;&5S<^EG(&WI<G3I:V5G>7/I9V4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I
M9"`B5VED=&@Z(@IM<V=S='(@(E-ZZ6QE<W/I9SHB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-3$U"FUS9VED(")7:6MI(@IM<V=S='(@(E=I:VDB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")7:6YD(@IM
M<V=S='(@(E-ZZ6PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV-PIM<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R(")3>NEL(&$@
M<F5G9V5L:2#S<N%K8F%N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-PIM
M<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R(")3>NEL<V5B97-S
MZ6<@8W-O;?-B86XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V,PIM<V=I
M9"`B5VEN9#HB"FUS9W-T<B`B4WKI;#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B4WKI;#H@
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB
M"FUS9W-T<B`B0O9L8W-E<W/I9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ.3@*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(DOM=N%N<^%G;&ES
M=&$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB
M"FUS9W-T<B`B375N:V$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$R-"!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$V
M-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(DUU;FMA:&5L>6D@8^UM
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G
M:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B375N:V%H96QY:2!T96QE9F]N(@H*
M(SH@;&EB+T9I;&4O0U-6+G!H<#HQ.3,@;&EB+T9I;&4O0U-6+G!H<#HR.30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I
M;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(D$@
M)60N('-O<F)A;B!N96T@;65G9F5L96SU(&$@;65Z]6L@<WKA;6$N(%;A<G0Z
M("5D+"!T86SA;'0Z("5D+B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,S,R"B,L
M('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X
M<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B3F5M(&UE9V9E;&5L]2!A
M(&UE>O5K('-ZX6UA+B!6X7)T.B`E9"P@=&%LX6QT.B`E9"XB"@HC.B!L:6(O
M5D93+V9I;&4N<&AP.C$R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O
M9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R(")(
M:6+A<R!O9F9S970@*"5D*2!A(%9&4R!FX6IL(&]L=F%SX7-A:V]R+B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#4*;7-G:60@(E@M4F5F(@IM
M<V=S='(@(DQI;G5X(&9O<G+A<VOS9"!K97)E<WIR969E<F5N8VEA(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!"
M87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R(")8-3`Y=C,@86QA<'9E=/4@:V]R
M;.%T;WKA<V]K(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3,*
M;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B6#4P
M.78S(&MI=&5R:F5S>G1E='0@:W5L8W-H87-Z;N%L870B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@
M06QT97)N871I=F4@3F%M92(*;7-G<W1R(")8-3`Y=C,@='5L86ID;VYO<R!A
M;'1E<FYA=.UV(&UE9VYE=F5ZZ7-E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.38*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF
M:65R(@IM<V=S='(@(E@U,#EV,R!T=6QA:F1O;F]S(&MU;&-S87IO;F]S[73S
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.#,*;7-G:60@(E@U
M,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(E@U,#EV,R!K:71E<FIE<WITZ7-E
M:R(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R
M(")962(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,30@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-@IM<V=I
M9"`B65E962(*;7-G<W1R(")965E9(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q,3$*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T
M<B`B66%H;V\A('3I<FOI<"(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP
M:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R("+I=F5N=&4B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C4R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR-#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")996UE;B(*;7-G<W1R(")*96UE;B(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY-C8*;7-G:60@(EEE<R(*;7-G<W1R("))9V5N
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R("))9V5N+"!B96QE9WEE
M>F5M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;
M/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R
M("(B"B)-;W-T($A434P@5$585"!M\V1B86X@=F%N+B!(87-Z;N%L:F$@82!;
M/#Y=(&=O;6)O="P@:&$@=FES<WIA(&%K87(@=N%L=&%N:2!A("(*(G-Z;VOA
M<V]S(&=R869I:W5S("A765-)5UE'*2!M96=J96QE;NUTZ7-R92XB"@HC.B!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C(S-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M
M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R(").96T@:&]Z:&%T(&SI=')E
M("5D(&)L;VMK;N%L('3V8F)E="XB"@HC.B!L:6(O2&]R9&4N<&AP.C$T,34*
M;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(D%Z
M(-9N(&9E;&AA<WINX6SS87IO;F]S[73A<V$@;F5M('3V<G3I;G0@;65G+B(*
M"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z,S`X"FUS9VED(")9;W4@8V%N
M;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE
M+B(*;7-G<W1R(")!('1E;&IE<R!NZ79B96X@;F5M('-Z97)E<&5L:&5T(&$@
M)UQ<)R!K87)A:W1E<BXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@U.2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3DW.0IM<V=I9"`B66]U(&1I9"!N;W0@96YT
M97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R(").96T@861O='0@
M;65G(.ER=NEN>65S(&5M86EL(&/M;65T+B(*"B,Z(&QI8B](;W)D92]$871A
M+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M
M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C
M;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@HB3F5M
M(&%D=&$@;65G(&$@;65G9F5L96QT973I<W0@87H@:6UP;W)TX6QT(&;A:FP@
MZ7,@82AZ*2`E<R!M97KU:2!K]GKV='0N(@H*(SH@;&EB+TAO<F1E+T%U=&@N
M<&AP.CDX-PIM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G
M<W1R(")3:6ME<F5S96X@:VEJ96QE;G1K97IE='0N(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$R-C4*;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O
M<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@
M<')E9FEX+B(*;7-G<W1R("(B"B)%9WD@;6]B:6QT96QE9F]N<WKA;6]T(&ME
M;&P@;65G861N:6$L(&-S86L@82!S>N%M:F5G>65K970L(&5S971L96<@96=Y
M("<K)R`B"B)K87)A:W1E<G)E;"!K97ID=F4L(&AA(&YE;7IE=&OV>FD@=.%R
M8W/A>N%S:2!M\V1O="!K[7;A;B!H87-Z;N%L;FDN(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Q.3(*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L
M:60@=F%L=64N(@IM<V=S='(@(D5L9F]G861H873S(.ER=.EK970@:V5L;"!M
M96=A9&YI82XB"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C,W"FUS
M9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O
M('5S92!3:6=N=7!S+B(*;7-G<W1R("(B"B)!($1A=&%4<F5E(&%L<F5N9'-Z
M97)T(&)E(&ME;&P@X6QL[71A;FD@82!B96IE;&5N=&ME>NES:2!J;V=O<W5L
M='/A9V]K("(*(FEGZ6YY;.ESZ6AE>BXB"@HC.B!L:6(O2&]R9&4N<&AP.C0V
M,@IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM
M<V=S='(@(D$@5D93(&%L<F5N9'-Z97(@;FEN8W,@8F7A;&SM='9A+B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@
M;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD
M('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B(@HB16SU8F(@;&4@:V5L
M;"#M<FYI82P@:&]G>2!M:6QY96X@<')O8FSI;>%T('1A<&%S>G1A;'0L(&UI
M96SU='0@96QK_&QD:2!A("(*(FAI8F%J96QE;G3I<W0N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U
M(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O
M(@IM<V=S='(@(DUE9R!K96QL(&%D;FD@96=Y(%523"UT+"!A:&]V82!E>B!A
M(&QI;FL@;75T870B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX
M,`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE
M=&5D+B(*;7-G<W1R(")+:2!K96QL(';A;&%S>G1A;FD@96=Y('3V<FQE;F3U
M('-Z97)V97)T+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U
M(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T
M<B`B365G(&ME;&P@861N:6$L(&AO9WD@;65L>6EK(&9E;&AA<WINX6SS(&%D
M871A:70@:^UVX6YJ82!T]G+V;&YI+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P
M,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V
M92XB"FUS9W-T<B`B365G(&ME;&P@861N:6$@87H@96QTX79O;.UT86YD\R!F
M96QH87-Z;N%L\VD@;F5V970N(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(DUE9R!K
M96QL(&%D;FEA(&$@:&]Z>N%A9&%N9/,@9F5L:&%S>F[A;/,@;F5VZ70N(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y
M('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(DUE9R!K96QL(&%D
M;FEA+"!H;V=Y(&UE;'EI:R!F96QH87-Z;N%L\R!A9&%T86ET(&OM=N%N:F$@
MX73M<FYI+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM
M<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M
M+B(*;7-G<W1R(")-96<@:V5L;"!A9&YI82!E9WD@<&%R86YC<V]T+B(*"B,Z
M(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED
M(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@
M(DUE9R!K96QL(&%D;FEA(&%Z(/IJ(&MA=&5G\W)I82!N97;I="XB"@HC.B!L
M:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9
M;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM
M<V=S='(@(D]L87-Z;W)S>N%G:2!T96QE9F]N<WKA;6]T(&ME;&P@;65G861N
M:6$B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3<U"B,L('!H<"UF;W)M870*
M;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO
M9VEN(&%G86EN+B(*;7-G<W1R("(B"B)!>B#6;B`E<R!K87!C<V]L871A(&ED
M]73Z;&SI<.ES(&UI871T(&UE9W-Z86MA9'0N($OI<F5M(&IE;&5N=&ME>GIE
M;B!B92#Z:G)A+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C,X"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B07H@UFX@
M96UA:6P@8^UM92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,34*;7-G
M:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B07H@UFX@9F5L863S
M:2`H1G)O;3HI(&/M;64Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-R!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR"FUS9VED(")9;W5R
M($EN9F]R;6%T:6]N(@IM<V=S='(@(E-Z96WI;'EE<R!I;F9O<FWA8VGS(@H*
M(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDW.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@
M=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E
M8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S
M='(@(B(*(D%Z(-9N("5S(&MA<&-S;VQA=.%N86L@:V5Z9&5T92#S=&$@;65G
M=N%L=&]Z;W1T(&%Z(&EN=&5R;F5T(&/M;64N("(*(D)I>G1O;G/A9^%N86L@
MZ7)D96OI8F5N(&ES;>ET(&)E(&ME;&P@:F5L96YT:V5Z;FEE+B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R($YA
M;64B"FUS9W-T<B`B07H@UFX@;F5V92(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO861D+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO
M=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C
M;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A
M=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"B)!>B#6;B!F96QH87-Z;N%L\V%Z
M;VYO<^UT\R!A;')E;F1S>F5R92!N96T@=&5S>FD@;&5H973U=ND@87H@^FH@
M9F5L:&%S>F[A;/-K("(*(FSI=')E:&]ZX7/A="X@2&$@82!(;W)D92!R96YD
M<WIE<G)E;"!K[7;A;FIA(&ME>F5L;FD@82!F96QH87-Z;N%L\VD@(@HB861A
M=&]K870L(&%K:V]R(&WA<VEK(&9E;&AA<WINX6SS87IO;F]S[73S(&%L<F5N
M9'-Z97)R92!V86X@<WK\:W/I9V4N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;F]L:7-T+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T
M:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE
M<B!R96%S;VXN(@IM<V=S='(@(B(*(D%Z(-9N(&9E;&AA<WINX6SS87IO;F]S
M[73S(&%L<F5N9'-Z97)E(&YE;2!T97-Z:2!L96AE=/5VZ2!A(&9E;&AA<WIN
MX6SS:R`B"B)L:7-TX7KA<^%T+"!V86=Y('9A;&%M:2!O:V+S;"!L971I;'1O
M='3A:R!E>G0@82!L96AE=/5SZ6=E="XB"@HC.B!L:6(O2&]R9&4O075T:"YP
M:'`Z.3@S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A
M<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F
M('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y
M+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB07H@UFX@8O9N
M9^ES>O5P<F]G<F%M:F$@;65G=N%L=&]Z;W1T(&%Z(-9N("5S(&UU;FMA:V%P
M8W-O;&%TX6YA:R!K97ID971E("(*(O-T82X@0FEZ=&]N<^%G82#I<F1E:^EB
M96X@:7-MZ70@8F4@:V5L;"!J96QE;G1K97IN:64N(@H*(SH@;&EB+T)L;V-K
M+VEF<F%M92YP:'`Z-34*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S
M=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B07H@UFX@8O9N9^ES>O5P
M<F]G<F%M:F$@;F5M('3A;6]G871J82!E>G0@82!L96AE=/5SZ6=E="XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB
M66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I
M;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM
M<V=S='(@(B(*(D%Z(-9N(&+V;F?I<WKU<')O9W)A;6IA(&YE;2!TX6UO9V%T
M:F$@97IT(&$@;GEO;71A=.%S:2!O<&-I\W0N(%!R\V+A;&IO;B!A("(*(D-T
M<FPM4"`H=F%G>2!#;VUM86YD+5`I(&QE;GEO;>%SX79A;"!N>6]M=&%T;FDN
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V,0IM<V=I9"`B66]U<B!C
M=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B02!J96QE;FQE9R#I<G;I;GEE
M<R!I9/5Z\VYA.B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,3<*;7-G:60@
M(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G
M<W1R(")!>B#6;B!A;&%PZ7)T96QM97KI<R!S>F5R:6YT:2!A>F]N;W/M=/-J
M82!M96=VX6QT;WIO='0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V
M,0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R(")!>B#6
M;B!A;&%PZ7)T96QM97KI<R!S>F5R:6YT:2!A>F]N;W/M=/-J83HB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`T"FUS9VED(")9;W5R(&9U;&P@;F%M
M93HB"FUS9W-T<B`B07H@UFX@=&5L:F5S(&YE=F4Z(@H*(SH@;&EB+TAO<F1E
M+T%U=&@N<&AP.CDY.0IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB
M"FUS9W-T<B`B3&5JX7)T(&$@8F5J96QE;G1K97KI<VD@:F]G;W-U;'1SX6=A
M+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B
M"FUS9W-T<B`B07H@UFX@)7,M<F4@:&%S>F[A;'0@^FH@:F5L<WIA=F$Z("5S
M(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F
M('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B07H@UFX@^FH@8F7A;&SM=.%S86ET
M(.ER=NEN>65S[71E='3\:R!A(&UO<W1A;FD@8F5J96QE;G1K97KI<R!I9&5J
MZ7)E+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9
M;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(D%Z(-9N
M(/IJ(&)EX6QL[73A<V%I="!E;&UE;G1E='3\:RXB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@
M8F5E;B!R97-E="(*;7-G<W1R(")!>B#6;B!J96QS>F%VX70@X73A;&SM=&]T
M='5K(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@
M(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@
M96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*
M;7-G<W1R("(B"B)!>B#6;B!J96QS>F%VX70@X73A;&SM=&]T='5K+"!NZ7IZ
M92!M96<@82!L979E;&5I="P@;6%J9"!J96QE;G1K97IZ96X@8F4@87H@(@HB
M^FH@:F5L<WKS=F%L+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,S,*;7-G
M:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(D%Z(-9N
M(&IE;'-Z87;A;F%K(&QE:N%R="!A>B#I<G;I;GEE<W/I9VD@:61E:F4N(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R
M(')E;6]T92!S97)V97)S.B(*;7-G<W1R(")!>B#6;B#A;'1A;"!H87-Z;N%L
M="!TX79O;&D@<WIE<G9E<F5K.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-30@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O
M<VQA=FEA(@IM<V=S='(@(DIU9V]S>FSA=FEA(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R("):86ER92(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-38@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("):86UB:6$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C4W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR-#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):
M:6UB86)W92(*;7-G<W1R(")::6UB86)W92(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");
M2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B6TYE(&UU=&%S<W5K(&$@8F5I
M9.EZ971T('-Z]G9E9V5T72(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C@Y
M"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EM(:6)A:F5L96YT
MZ7-=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z
M,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B6TUU=&%S
M<W5K(&$@8F5I9.EZ971T('-Z]G9E9V5T("TB"@HC.B!L:6(O2&]R9&4O5&5X
M="]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T
M<B`B6TUU=&%S<W5K(&$@8F5I9.EZ971T('-Z]G9E9V5T("T@)7,@<V]R72(*
M"B,Z(&QI8B](;W)D92YP:'`Z,3DU"B,L('!H<"UF;W)M870*;7-G:60@(EML
M:6YE("5S(&]F("5S72(*;7-G<W1R(");)7,O)7,@<V]R72(*"B,Z(&QI8B](
M;W)D92YP:'`Z,34T-2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS
M9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`B7T%D;6EN:7-Z='+A8VGS
M(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(E]0
M87)A;F-S<V]R(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?1&%T851R
M964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O=R(*;7-G
M<W1R(")3;W)T]G)LZ7,B"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'
M<F]U<',B"FUS9W-T<B`B7T-S;W!O<G1O:R(*"B,Z(&QI8B](;W)D92]-96YU
M+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@(E-E7V?M='/I9R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B02!K
MZ7`@='5L86ID;VYSX6=A:2XN+B(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ
M.30*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B0F5J96QE;G1K97KI<R(*"B,Z
M(&QI8B](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S
M='(@(E]+:6IE;&5N=&ME>NES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI
M;FLN+BXB"FUS9W-T<B`B02!L:6YK(&WS9&]S[73A<V$N+BXB"@HC.B!L:6(O
M2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R(")?
M3W!C:?-K(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B7TIO9V]S=6QT<^%G;VLB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]2
M96UO=F4@3&EN:RXN+B(*;7-G<W1R(")!(&QI;FL@=/9R;.ES92XN+B(*"B,Z
M(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@(E]"9>%L
M;.UTX7-O:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B5.%B;.%Z870@='5L86ID;VYSX6=O:R(*"B,Z(&QI8B]A<&DN
M<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(E]&96QH87-Z;N%L\VLB
M"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDR-0IM<V=I9"`B861D<F5S<R!B
M;V]K(@IM<V=S='(@(F/M;6IE9WEZZ6LB"@HC.B!L:6(O2&]R9&4O34E-12]-
M97-S86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S
M='(@(F$@8^UM>F5T="!I<VUE<F5T;&5N(@H*(SH@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HY,3<*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(FYA<'3A<B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3<Y(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S8U"B,L('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B;GEU9V]D
M="(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B
M8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R(")A(&MI;65N971I
M(.%L;&]MX6YY(&YE;2!H;WIH873S(&SI=')E(@H*(SH@;&EB+TAO<F1E+TU)
M344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*
M;7-G<W1R(")A(&)E;65N]2#A;&QO;>%N>2!N96T@;GEI=&AA=/,@;65G(@H*
M(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4Y.0IM<V=I9"`B8VQI
M8VL@:&5R92(*;7-G<W1R(")K871T:6YT<V]N(&ED92(*"B,Z(&QI8B](;W)D
M92]-24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S
M86=E(&5R<F]R(@IM<V=S='(@(G!A<F%N8W-S;W)I(&AI8F$B"@HC.B!L:6(O
M2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O;F9I9W5R871I
M;VX@97)R;W(B"FUS9W-T<B`B:V]N9FEG=7+A8VGS<R!H:6)A(@H*(SH@;&EB
M+TAO<F1E+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S
M>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(FAIX6YY>FEK(&5G>2!F;VYT
M;W,@<F5N9'-Z97+A;&QO;>%N>2(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A
M9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B
M861A=&9O<FWA='5M(&AI8F$B"@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N
M:6YC.C,P"FUS9VED(")E9&ET(@IM<V=S='(@(FWS9&]S[73A<R(*"B,Z(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T
M(&9O=6YD(@IM<V=S='(@(F%Z(&%D870@;F5M('1A;.%L:&%T\R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")F
M86QL:6YG(@IM<V=S='(@(F-S]FMK96XB"@HC.B!L:6(O2&]R9&4O0G)O=W-E
M<BYP:'`Z.#DX"FUS9VED(")F:6QE(@IM<V=S='(@(F;A:FPB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$X,2!L:6(O0FQO8VLO;65T87(N<&AP.C,V-R!L
M:6(O0FQO8VLO;65T87(N<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")F
M<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(B5S("@E<RD@:7+A
M;GEB\VPL("5S("5S('-E8F5S<^EG9V5L(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(S.0IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R(")S>NEL
M;/9KZ7-E:R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-3`*;7-G:60@(F@Z(@IM<V=S='(@(FTZ(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.0IM<V=I9"`B:&@B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H
M;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R(")A(&?I<"!N979E(&YE;2!I<VUE
M<G0B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE
M9&EA=&4B"FUS9W-T<B`B87IO;FYA;&DB"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$V
M,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(FEN<'5T+V]U
M='!U="!H:6)A(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,30V
M"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R(")B96QS
M]2!P<F]G<F%M:&EB82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E
M0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B<V]R72(*"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M
M870*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@
M25-/+B(*;7-G<W1R("(B"B)!>B!M:W-I;V9S('!R;V=R86T@)60@:&EB86OS
M9&1A;"!L9>%L;'0@87H@25-/(.%L;&]MX6YY(&OI<WKM=.ES92!K]GIB96XN
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W,`IM
M<V=I9"`B;6TB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H
M<#HR.#4@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C0Q"FUS9VED(")N86UE(@IM<V=S
M='(@(F[I=B(*"B,Z(&QI8B](;W)D92]24$,N<&AP.C$R-`IM<V=I9"`B;F]T
M(&EM<&QE;65N=&5D(@IM<V=S='(@(D$@<')O9W)A;6YA:R!E>B!A('+I<WIE
M(&WI9R!N:6YC<R!M96=V86SS<^UT=F$N(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HQ,C(P"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM
M<V=S='(@(D$@<')O9W)A;6YA:R!E>B!A('+I<WIE(&WI9R!N:6YC<R!M96=V
M86SS<^UT=F$N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,#D*;7-G:60@
M(FYO=&5P860B"FUS9W-T<B`B:F5G>7IE='3V;6(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P
M97)C96YT(@IM<V=S='(@(G-ZX7IA;.EK(@H*(SH@;&EB+TAO<F1E+TU)344O
M365S<V%G92YP:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G
M<W1R(")N:6YC<R!M96=F96QE;/4@:F]G;W-U;'1SX6=A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I
M9"`B<&EX96QS(@IM<V=S='(@(G!I>&5L(@H*(SH@;&EB+TAO<F1E+TU)344O
M365S<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C
M;VPB"FUS9W-T<B`B861A=.%T=FET96QI("AP<F]T;VMO;&PI(&AI8F$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW-`IM<V=I
M9"`B<FES:6YG(@IM<V=S='(@(F5M96QK961I:R(*"B,Z(&QI8B](;W)D92]-
M24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L
M92(*;7-G<W1R(")A('-Z;VQGX6QT873A<R!N96T@X6QL(')E;F1E;&ME>NES
M<F4B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C$P,0IM<V=I9"`B<VAO
M=R!D:69F97)E;F-E<R(*;7-G<W1R(")NZ7IZ_&L@;65G(&$@:_QL]FYB<^EG
M96ME="(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*
M;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R(")S;7,R96UA:6P@
M<WIO;&?A;'1A=.%S($A45%`M;B#A="(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HS.#<*;7-G:60@(G-S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS9VED
M(")S=&5A9'DB"FUS9W-T<B`B=N%L=&]Z871L86XB"@HC.B!L:6(O2&]R9&4O
M34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G
M<W1R(")R96YD<WIE<FAI8F$B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDS
M,PIM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(F9E;&%D871L:7-T82(*"B,Z
M(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R
M87)Y(&9A:6QU<F4B"FUS9W-T<B`BX71M96YE=&D@:&EB82(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,V(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS
M9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S
M='(@(FUE9V5R]7/M=.ES:^EN="!KZ71S>F5R(.UR:F$@8F4@82!J96QS>O-T
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`B
M;NEV(&[I;&O\;"(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-C4@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G
M:60@(G5S97(@<V5L96-T(@IM<V=S='(@(F$@9F5L:&%S>F[A;/,@X6QT86P@
M=N%L87-Z=&AA=/,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-#(*;7-G:60@(G<Z(@IM
M<V=S='(@(G-Z.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV
M"FUS9VED(")W96%T:&5R+F-O;2(*;7-G<W1R("(B"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!O+VED7TE$+G!O````````````````````
M````````````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`V-S`Q,S,`,3`U,34T
M,S,W-30`,#$W-C$W`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````",@2&]R9&4@+2!);F1O;F5S:6%N($QA;F=U86=E(%1R86YS
M;&%T:6]N"B,@0V]P>7)I9VAT("A#*2`R,#`U($AO<F1E(%!R;VIE8W0*(R!4
M:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS
M92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*(R!*86UE<R`\:F%M97-`86-T:6]N
M;65S<V%G92YC;VT^+"`R,#`U+@HC"B,L(&9U>GIY"FUS9VED("(B"FUS9W-T
M<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B`R,#`U+3`X+3`S7&XB"B)297!O
M<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4
M+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M
M4F5V:7-I;VXM1&%T93H@,C`P-2TP."TP-"`P.3HQ,"LP,C`P7&XB"B),87-T
M+51R86YS;&%T;W(Z($IA;65S(#QJ86UE<T!A8W1I;VYM97-S86=E+F-O;3Y<
M;B(*(DQA;F=U86=E+51E86TZ(&ED(#QI9$!L:2YO<F<^7&XB"B)-24U%+59E
M<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R
M<V5T/553+4%30TE)7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`W
M8FET7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@
M*&EN("5S(&1A>7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-S,*(RP@9G5Z>GD*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@
M(DAA<FD@26YI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-0HC
M+"!F=7IZ>0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B0F5S;VLB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<Q"FUS9VED("(@*'EE<W1E
M<F1A>2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(U-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Q"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#<*;7-G:60@(B!A="`B"FUS
M9W-T<B`B('!A9&$@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M,34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@
M82!D:7)E8W1O<GDN(@IM<V=S='(@(EPB)7-<(B!B96QU;2!D:6)U870Z("5S
M+B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HV
M-3D*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#0R
M"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E
M9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B
M7"(E<UPB('-U9&%H(&1I=&%M8F%H:V%N(&ME(&1A;&%M('-I<W1E;2!G<G5P
M+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N
M<R!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!S=61A:"!D:71A;6)A:&MA;B!K
M92!D86QA;2!I>FEN('-I<W1E;2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T
M(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B7"(E
M<UPB(&)E;'5M(&1I8G5A=#H@)7,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N
M,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B4N,F9-0B!S=61A:"!D
M:6=U;F%K86X@9&%R:2`E+C)F34(@>6%N9R!S=61A:"!D:6EJ:6YK86X@*"4N
M,F8E)2DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W"B,L
M('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(E9"`E
M<R!D86X@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C(V
M."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L('!H<"UF;W)M870*;7-G
M:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G
M<W1R("(E9"!H87)I('-A;7!A:2!S86YD:2!A;F1A(&AA8FES(&UA<V$@8F5R
M;&%K=6YY82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@U
M"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R
M("(E9"UH87)I(')A;6%L86X@8W5A8V$B"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B
M"FUS9W-T<B`B)7,@+2!096UB97)I=&%H=6%N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.#,S(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C@S-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O
M;F9I<FUA=&EO;B(*;7-G<W1R(")+;VYF:7)M87-I("T@3W!E<F%S:2!096UE
M;&EH87)A86X@)7,B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@4V5T=7`B"FUS9W-T<B`B)7,@4V5T=7`B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z,C8S"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(%-I9VX@57`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E
M;65N="(*;7-G<W1R("(E<R!3>6%R870M<WEA<F%T(%!E<FIA;FII86XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0R."!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C0Y,`HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C8U,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Q.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3D@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M-C4@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,SD*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-#4@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B)7,@<&%D82`E<R`E<R(*
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N
M86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B
M;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A
M="!T:&ES('1I;64N(@IM<V=S='(@(B(*(B5S('-I87`@=6YT=6L@;65L86MS
M86YA:V%N(&]P97)A<VD@<&5M96QI:&%R86%N('EA;F<@<W5D86@@9&ET86YD
M86D@9&D@8F%W86@@(@HB:6YI+B!"97)I;&%H('1A;F1A('!A9&$@:V]T86L@
M=&5R<V5B=70@=6YT=6L@;W!E<F%S:2!M86YA<'5N('EA;F<@86YD82`B"B)I
M;F=I;FMA;B!U;G1U:R!D:6QA:W-A;F%K86X@<&%D82!W86MT=2!I;FDN(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,T,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU
M=&5S(@IM<V=S='(@(B5S(&UE;FET(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+T-O;&QE8W1I;VXN<&AP.C$R,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R(")4:61A:R!A9&$@:6MO;B!Y
M86YG(&1I=&5M=6MA;BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM
M<V=S='(@(B5S('5N='5K("5S("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S)W,@
M061D<F5S<R!";V]K(@IM<V=S='(@(D)U:W4@06QA;6%T("(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9&5R(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#8*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("(E<R`M(%!E;6)E
M<FET86AU86XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT
M;6PN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M
M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@
M0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@
M<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-C4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q,`HC+"!F
M=7IZ>0IM<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(L(&%N9VEN(&ME;F-A
M;F<B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X."!L:6(O0FQO8VLO;65T
M87(N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@
M)7,B"FUS9W-T<B`B+"!A;F=I;B!K96YC86YG("5S("5S(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I
M86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(BP@=F%R:6%B;&4@9&%R:2`E
M<R!K92`E<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,CDT
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$R.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-S0Y"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W1I;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R
M(")&;W)M870@,3(@2F%M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"FUS
M9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R(")&;W)M870@,C0@2F%M(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S
M(@IM<V=S='(@(C(T(&IA;2(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP
M:'`Z-CD*(RP@9G5Z>GD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("),:6AA
M="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED(")!(&1A=&%B
M87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S
M='(@(D1A=&%B87-E(&)A8VME;F0@9&EP97)L=6MA;B!U;G1U:R!A<F5A(&EN
M:2XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V,`IM<V=I9"`B
M02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI
M8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,38U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E
M<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#DW"FUS9VED("(B"B)!('!U8FQI
M8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Q-0IM<V=I
M9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3`U"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E
M(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B
M"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC
M(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,V-`IM
M<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y
M<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T
M<B`B04T@365N9'5N9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(D%-
M($=E<FEM:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R(")!32!(=6IA;B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED
M(")!32!3:&]W97)S(@IM<V=S='(@(D%-($=E<FEM:7,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO
M=R!3:&]W97)S(@IM<V=S='(@(D%-($=E<FEM:7,@4V%L:G4B"@HC.B!T96UP
M;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B
M04TO4$TB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!
M8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R(")496YT86YG(&5D:71O<B!I;FDB
M"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,@IM<V=I9"`B06)O=70N
M+BXB"FUS9W-T<B`B5&5N=&%N9RXN+B`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS
M9W-T<B`B2F%R86L@86YT87)A(&)A9VEA;B!B87=A:"!B87)I<R!D96YG86X@
M8F%G:6%N(&)A=V%H(&=A;6)A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R
M(")*87)A:R!A;G1A<F$@8F%G:6%N('1E;F=A:"!B87)I<R!D96YG86X@8F%G
M:6%N('1E;F=A:"!G86UB87(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93
M(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS
M"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%S
M:2!!8V-O=6YT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U"FUS9VED
M(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(E-A;F1I($%C8V]U;G0B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3,*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R("))
M;F9O<FUA<VD@06-C;W5N="(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS,S,*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`B06MU;G1A;G-I(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S
M+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M861D8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`B5&%M8F%H(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*
M;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R(")486UB86@@1W)U<"!!
M;F%K(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY"B,L(&9U>GIY"FUS9VED(")!
M9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R(")58F%H($EZ:6XB"@HC.B!T
M96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM
M<V=S='(@(E1A;6)A:"!$:7-I;FDZ(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR
M,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B
M"FUS9W-T<B`B5&%M8F%H($=R=7`@0F%R=2(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HX.`HC+"!F=7IZ>0IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S
M='(@(E5B86@@27II;B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D
M8VAI;&0N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9"!A
M(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R(")486UB86@@9W)U<"!A
M;F%K(&ME("<E<R<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C$T-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@
M<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B5&%M8F%H(&=R=7`@86YA
M:R!K92`G)7,G(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A
M(&YE=R!U<V5R.B(*;7-G<W1R(")486UB86@@<&5N9V=U;F$@8F%R=3HB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34T"B,L
M(&9U>GIY"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(E!I<V%H:V%N(&MO
M;&]M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM
M<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(E1A;6)A:"!A;F=G;W1A
M(&)A<G4B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED
M(")!9&0@<&%I<B(*;7-G<W1R(")486UB86@@<&%S86YG86XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D%D
M9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R(")4
M86UB86@@365N=2`E<R!S96)A9V%I(%!A;F5L(&YA=FEG87-I($UO>FEL;&$B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*
M(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@
M(D)U:W4@06QA;6%T("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HW.`HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&UY(&%D9')E
M<W,@8F]O:R(*;7-G<W1R(")"=6MU($%L86UA="`B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HS,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`B5&%M8F%H('!E;F=G
M=6YA(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@
M8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@
M(@HB)7,N(@IM<V=S='(@(B(*(B`G)7,G('-U9&%H(&1I=&%M8F%H:V%N(&ME
M(&1A;&%M('-I<W1E;2P@=&5T87!I('1I9&%K(&1A<&%T(&UE;F%M8F%H:V%N
M("(*(FEN9F]R;6%S:2!P96YD869T87)A;B!T86UB86AA;CH@)7,N(@H*(SH@
M<VEG;G5P+G!H<#HT-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D
M960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB
M"FUS9W-T<B`B("<E<R<@('-U9&%H(&1I=&%M8F%H:V%N(&ME(&1A;&%M('-I
M<W1E;2X@06YD82!D87!A="!L;V<@:6X@<V5K87)A;F<N(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R
M<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B4&5N86UB86AA;B!P96YG9W5N82!T
M:61A:R!D:6%K=&EF:V%N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q
M"B,L(&9U>GIY"FUS9VED(")!9&1R97-S(@IM<V=S='(@(D)U:W4@06QA;6%T
M("(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,SD*;7-G:60@(D%D
M9')E<W,@0F]O:R(*;7-G<W1R(")"=6MU($%L86UA="`B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`HC+"!F=7IZ>0IM<V=I
M9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E
M<G,B"FUS9W-T<B`B56)A:"!I>FEN('5N='5K("5S(@H*(SH@861M:6XO:6YD
M97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G
M:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<F%S:2(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#$*;7-G:60@(D%D<R(*;7-G
M<W1R(")):VQA;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG97)I82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"B,L(&9U
M>GIY"FUS9VED(")!;&EA<R(*;7-G<W1R(")2871A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B
M06QI9VXB"FUS9W-T<B`B4F%T82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T
M<B`B4&5R871A86XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G
M:60@(D%L;"(*;7-G<W1R(")396UU82(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*
M;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(E-E;75A
M(%!E;F=G=6YA($%S;&DB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN
M+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(E-E
M;75A($=R=7`B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDQ
M(&9R86UE=V]R:R]097)M<R]097)M<R]D871A=')E92YP:'`Z-S4*(RP@9G5Z
M>GD*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R("))>FEN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ
M-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B4V5M=6$@96UP870@
M<VES:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S$*;7-G:60@
M(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3,T"FUS9VED(")!;&QO=R!S971T:6YG(&]F
M(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R("))>FEN:V%N('!E;F=A='5R
M86X@9&%R:2!T:7!E(&1A9G1A<B!N;VUO<B!B97)U<G5T/R(*"B,Z(&9R86UE
M=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR
M96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$R,PIM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B
M4&5N9V=A;G1I($QO9VEN($E-4U`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3`W"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R
M(")096YG9V%N=&D@4V%N9&D@24U34"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT.3D*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S
M='(@(E!E;F=G86YT:2!.86UA(%!E;F=G=6YA($E-4U`B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N871E(&5M86EL
M(&%D9')E<W,B"FUS9W-T<B`B4&5N9V=A;G1I(&%L86UA="!E;6%I;"(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@=&5M
M<&QA=&5S(@IM<V=S='(@(E!E;F=G86YT:2!T96UP;&%T92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(E!E;F=G86YT:2!T
M96MS.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G
M86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-PIM<V=I9"`B06X@=6YK;F]W;B!E
M<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I
M9"`B06YD;W)R82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O
M;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM
M<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B
M2F%W86)A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H
M<'-H96QL+G!H<#HS-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP
M.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@
M(D%P<&QI8V%T:6]N(@IM<V=S='(@(D%P;&EK87-I(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S
M='(@(D1A9G1A<B!!<&QI:V%S:2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R(")!
M<&QI:V%S:2!S=61A:"!S:6%P+B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T
M<B`B1&EG=6YA:V%N('5N='5K($)A9VEA;B!!;F%K(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS
M9W-T<B`B1&ES971U:G5I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z.#,S"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X
M"FUS9VED(")!<')I;"(*;7-G<W1R(")!<')I;"(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS
M9W-T<B`B07)A8B`H5VEN9&]W<RTQ,C4V*2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4X
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,`IM<V=I9"`B07)C
M:&EV92!.86UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E
M('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E
M<W0@9F]R("5S(#\B"FUS9W-T<B`B(@HB07!A:V%H(&%N9&$@>6%K:6X@86YD
M82!I;F=I;B!M96UI;F1A:&MA;B!P97)M;VAO;F%N('!E;F1A9G1A<F%N('5N
M='5K("5S/R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN
M8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_
M(@IM<V=S='(@(D%P86MA:"!A;F1A('EA:VEN(&%N9&$@:6YG:6X@;65N9VAA
M<'5S("<E<R<@9&%N('-U8BUG<G5P(&UA;F%P=6X_(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM
M<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@
M(D%R;65N:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M-S8*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(D%R;65N
M:6$@*$%235-#24DM."DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*
M;7-G:60@(D%R="(*;7-G<W1R(")396YI(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B
M07)U8F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G
M<W1R(")+;V1E($%S8VEI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,C4*;7-G:60@(D%S:R!F;W(@
M8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I
M;VYS/R(*;7-G<W1R(")-96UI;G1A(&MO;F9I<FUA<VD@<V5B96QU;2!M96QA
M:W-A;F%K86X@;W!E<F%S:2!P96UE;&EH87)A86X_(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$Q,PHC+"!F=7IZ>0IM<V=I9"`B07-S:6=N;65N
M="!C;VQU;6YS(@IM<V=S='(@(E!I<V%H:V%N(&MO;&]M(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM
M97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(DUE;F-O8F$@=6YT=6L@;65N9VAA
M<'5S(&=R=7`@>6%N9R!T:61A:R!A9&$N(@H*(SH@861M:6XO<&5R;7,O9&5L
M971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B365N8V]B82!U;G1U:R!M96YG
M:&%P=7,@:7II;B!Y86YG('1I9&%K(&%D82XB"@HC.B!A9&UI;B]P97)M<R]E
M9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(DUE;F-O8F$@=6YT=6L@;65N9W5B
M86@@:7II;B!Y86YG('1I9&%K(&%D82XB"@HC.B!S97)V:6-E<R]S:&%R97,O
M961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES
M=&5N="!S:&%R92XB"FUS9W-T<B`B365N8V]B82!U;G1U:R!M96YG=6)A:"!B
M86=I86X@>6%N9R!T:61A:R!A9&$N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#8*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U
M9W5S="(*;7-G<W1R(")!9W5S='5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S
M=')A;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@
M(D%U<W1R:6$B"FUS9W-T<B`B06=U<W1U<R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U
M:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T
M:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B
M:6QI=&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q
M=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I
M=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?
M:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C4Q"FUS
M9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO
M="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U
M=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D
M($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@
M:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0Y.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A
M=&4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R
M<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C0V"FUS
M9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N
M<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!
M=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@
M)7,B"FUS9W-T<B`B4V5M=6$@4&5N9V=U;F$@07-L:2(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4Q"FUS9VED(")!=71H96YT
M:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC
M871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B
M;&4@9FEE;&1S.B(*;7-G<W1R(")+;VQO;2!Y86YG('1E<G-E9&EA.B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS
M9W-T<B`B06QA<V%N($)/1D@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM
M<V=S='(@(DQA=&%R($)E;&%K86YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO
M<B(*;7-G<W1R(")787)N82!,871A<B!"96QA:V%N9R(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O<R!P
M87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K
M<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B
M36%R9VEN(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D)A
M;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(D)A;'1I8R`H25-/+3@X-3DM
M,3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8P"FUS9VED(")"87)B861O<R(*;7-G<W1R("(B"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D1A<V%R(&1I<F5K=&]R:2!G<F%F:6L@)R5S)R!T:61A
M:R!D:71E;75K86XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<S"FUS9VED(")"87-E;&EN92(*;7-G<W1R(")*
M87)A:R!A;G1A<F$@8F%G:6%N(&)A=V%H(&=A;6)A<B!D96YG86X@9V%R:7,@
M9&%S87(@8F%R:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B0F5L:7IE(@IM<V=S='(@(DIA
M<F%K(&%N=&%R82!B86=I86X@8F%W86@@9V%M8F%R(&1E;F=A;B!G87)I<R!D
M87-A<B!B87)I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(D)E;FEN
M(@IM<V=S='(@(DIA<F%K(&%N=&%R82!B86=I86X@8F%W86@@9V%M8F%R(&1E
M;F=A;B!G87)I<R!D87-A<B!B87)I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E
M<FUU9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<
M(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B
M4&5N9V%T=7)A;B!!<F5A(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N
M:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(E1I<&4@07)E82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM
M<V=I9"`B0F]L9"(*;7-G<W1R(")(=7)U9B!496)A;"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*
M;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(P-0IM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(E!E='5N
M:G5K(&AA;&%M86X@=V5B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@
M(D)O<F1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(DME
M=&5B86QA;B!";W)D97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(Q"FUS9VED(")";W)D97)S(@IM<V=S='(@
M(D)O<F1E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G
M;W9I;F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV
M"FUS9VED(")";W1H(@IM<V=S='(@(DME9'5A;GEA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM
M<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T;VTB
M"FUS9W-T<B`B0F%W86@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@27-L
M86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(D)R
M87II;"(*;7-G<W1R(")3=7)A="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET
M:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L
M;&5T960@3&ES="(*;7-G<W1R(")$869T87(@0G5L;&5T(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*
M;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0T-`IM<V=I9"`B0TU3(@IM<V=S='(@(D--4R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-2
M0R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4Y-PIM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S
M='(@(E!R;W!E<G1I(%-?96PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,38S"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#@T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.#<*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$U-0IM<V=I9"`B0V%L96YD87(B"FUS
M9W-T<B`B2V%L96YD97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C0V"FUS9VED(")#86QM(@IM<V=S='(@(E1E;F%N9R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#86UE<F]O;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A
M=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS
M9W-T<B`B(@HB5&ED86L@9&%P870@;65N9V%T=7(@=6QA;F<@<V%N9&D@<V5C
M87)A(&]T;VUA=&ES+"!S:6QA:V%N(&AU8G5N9VD@(@HB861M:6YI<W1R871O
M<B!A;F1A+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,Q.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E
M<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I
M9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q.0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0
M('-E<G9E<CH@)7,B"FUS9W-T<B`B5&ED86L@9&%P870@=&5R:'5B=6YG(&ME
M('-E<G9E<B!L9&%P(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M-#$S"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*(RP@9G5Z>GD*;7-G:60@(D-A
M;F%D82(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P
M,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M9&5L971E+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I
M9"`B0V%N8V5L(@IM<V=S='(@(D)A=&%L(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R
M="(*;7-G<W1R(")"871A;&MA;B!,87!O<F%N($UA<V%L86@B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M5&ED86L@9&%P870@=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G
M:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H
M<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL
M92<@<&%R86UE=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C,Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M
M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]$871A5')E92]$871A5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E
M92]$871A5')E92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS
M9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P
M<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T
M;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S
M<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8X"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*;7-G:60@
M(D-A<'1I;VXB"FUS9W-T<B`B2G5D=6P@5&%B96PB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I
M97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP"FUS
M9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B2V%T96=O<FD@
M9&%N($QA8F5L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ.30*(RP@9G5Z>GD*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T
M<B`B4')O<&5R=&D@4V5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S
M(@IM<V=S='(@(E!R;W!E<G1I(%-E;"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z
M(@IM<V=S='(@(DIA<F%K('-P87-I(&1A<FD@8F]R9&5R(&1E;F=A;B!T96MS
M(&1I(&1A;&%M('-E;#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B
M"FUS9W-T<B`B<')O<&5R=&D@<V5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB
M"FUS9W-T<B`B2F%R86L@<W!A<VD@86YT87(@<V5L+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R-S0*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B0V5L=&EC
M("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T<B`B5&5N9V%H(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#96YT<F%L
M($5U<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R(")%<F]P82!496YG86@@
M*$E33RTX.#4Y+3(I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV.3D*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3$*;7-G
M:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")#97)T:69I8V%T
M92!0;VQI8VEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*(RP@9G5Z>GD*
M;7-G:60@(D-H860B"FUS9W-T<B`B2V%R86MT97(B"@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B56)A:"(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0IM<V=I9"`B0VAA;F=E(%EO=7(@
M4&%S<W=O<F0B"FUS9W-T<B`B56)A:"!386YD:2!!;F1A(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@
M86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N
M9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@HB56)A:"!N
M86UA(&1A;B!A;&%M870@<V5H:6YG9V$@;W)A;F<@9&%P870@;65L:6AA=&YY
M82!K971I:V$@;65R96MA(&UE;6)A8V$@(@HB9&%N(&UE;6)A;&%S(&ME(&5M
M86EL(&%N9&$N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T
M"FUS9VED("(B"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P
M;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(DUE;F=U8F%H
M('-A;F1I(&%N9&$@=&ED86L@9&ED=6MU;F<@9&5N9V%N(&MO;F9I9W5R87-I
M('EA;F<@<V5K87)A;F<N(%-I;&%K86X@(@HB:'5B=6YG:2!A9&UI;FES=')A
M=&]R(&%N9&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA<B(*;7-G<W1R(")+87)A:W1E
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B4&5R
M:6MS82!,:6YK+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B0VAI
M;&4B"FUS9W-T<B`B2G5D=6PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY"FUS9VED
M(")#:&EN82(*;7-G<W1R(")+87)A:W1E<B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@P"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB
M"FUS9W-T<B`B0VEN82!3961E<FAA;F$@*$=",C,Q,BDB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H
M0FEG-2DB"FUS9W-T<B`B0VEN82!4<F%D:7-I;VYI;"`H0FEG-2DB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"B,L(&9U>GIY"FUS
M9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R(")386YD:2!"87)U(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.`IM<V=I9"`B
M0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(Y.`IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A
M=&5S.B(*;7-G<W1R(")0:6QI:"!C87)A('5N='5K(&UE;F%M<&EL:V%N('1A
M;F=G86PZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP
M92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@(E!I;&EH(&1A9G1A<B!T
M:7!E(&=A>6$@*'5N='5K(&1A9G1A<B!N;VUO<B!B97)U<G5T*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C@Y,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@
M9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(D1I<F5K=&]R
M:2!-;W1I9B`G)7,G('1I9&%K(&1I=&5M=6MA;BXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B0VQE87(B"FUS
M9W-T<B`B0F5R<VEH:V%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*
M;7-G<W1R(")"97)S:6AK86X@=&%G($U33V9F:6-E(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$R.`HC+"!F=7IZ>0IM<V=I9"`B0VQE87(@475E<GDB"FUS
M9W-T<B`B0F5R<VEH:V%N('!E;F=G=6YA(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@
M;W5T('5S97(Z("5S(@IM<V=S='(@(D)E<G-I:&MA;B!P96YG9W5N83H@)7,B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*;7-G:60@
M(D-L96%R('5S97(B"FUS9W-T<B`B0F5R<VEH:V%N('!E;F=G=6YA(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R
M('5S97(@9&%T82(*;7-G<W1R(")"97)S:6AK86X@9&%T82!P96YG9W5N82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS
M9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(D-E<F%H(&)E8F5R87!A('-A
M870@;&%G:2(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC
M92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R(")+
M;&EK('5N='5K($QA;FIU="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@
M2%144"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I
M;F1O=R(*;7-G<W1R(")4=71U<"!*96YD96QA(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-#0*;7-G:60@(D-L;W5D<R(*;7-G<W1R(")-96YD=6YG(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G
M:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R(")-96YD=6YG(&1I('!A9VD@:&%R
M:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W
M"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B0F5R87=A;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*
M;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA
M<'-E(%-I9&5B87(B"FUS9W-T<B`B4&5R8F5S87(@4&%N96P@3F%V:6=A<VD@
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B4&5R
M8F5S87(@8F]R9&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B0V]L
M;VUB:6$B"FUS9W-T<B`B5V%R;F$B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP
M.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B
M"FUS9W-T<B`B5V%R;F$B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L
M;&5C=&EO;BYP:'`Z,S(T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL
M96-T:6]N+G!H<#HS,C4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4P,"!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP
M.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B4&5M:6QI:"!787)N
M82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X-#8*(RP@9G5Z>GD*
M;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B2&%P=7,@<&EL:6AA
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R(")+;VQO;2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-#8*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-`IM<V=I
M9"`B0V]M:6-S(@IM<V=S='(@(D-O;6EC<R(*"B,Z(&%D;6EN+V-M9'-H96QL
M+G!H<#HR-0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")#;VUM86YD(@H*(SH@
M861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM
M<V=S='(@(D-O;6UA;F0@4VAE;&PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3,*(RP@9G5Z>GD*;7-G:60@(D-O;6UE;G0B"FUS9W-T
M<B`B0V]M;6%N9"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-38V"B,L(&9U>GIY"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R(").
M86UA($%N9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`HC+"!F=7IZ>0IM<V=I9"`B0V]M;W)O
M<R(*;7-G<W1R(")"97-O:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,SD*(RP@9G5Z>GD*;7-G:60@(D-O;7!A;GDB"FUS
M9W-T<B`B4V%L:6XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G
M:60@(D-O;7!U=&5R<R(*;7-G<W1R(")+;VUP=71E<B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.3<*;7-G:60@(D-O;F1I=&EO;B(*;7-G
M<W1R(")+;VYD:7-I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#D*;7-G
M:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B2V]N9&ES:2(*"B,Z(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N
M8V5S(@IM<V=S='(@(E!E<F)E9&%A;B!+;VYF:6=U<F%S:2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-#,*;7-G:60@(D-O;F9I9W5R871I;VX@9F]R
M('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM<V=I
M9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B2V]N
M9FEG=7)A<VD@<W5D86@@:&%B:7,@;6%S82!B97)L86MU;GEA+B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]N9FEG=7)E("5S(@IM<V=S='(@(DUE;F=A='5R("5S(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!0
M87-S=V]R9"(*;7-G<W1R(")+;VYF:7)M87-I(%-A;F1I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-@HC+"!F=7IZ>0IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B5V%R;F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@
M;V8@=&AE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N
M;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-#4*;7-G:60@(D-O
M;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#$T"FUS9VED(")#;VYT86-T<R(*
M;7-G<W1R(")+;VYT86LB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U
M;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU92(*;7-G<W1R("),86YJ=70B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#;V]K:64B"FUS9W-T
M<B`B0V]O:VEE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@(E-A;&EN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C@*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R(")+
M;VQO;2!Y86YG(&1I:6UP;W(Z("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB
M"FUS9W-T<B`B4V%L:6X@4&EL:6AA;B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S8*;7-G:60@(D-O=6QD
M(&YO="!01U`@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4S"FUS9VED(")#;W5L9"!N
M;W0@4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3
M+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T
M(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S
M(@IM<V=S='(@(E1I9&%K(&1A<&%T(&UE;GEI;7!A;B!K;VYF:6=U<F%S:2`E
M<RXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ,C$*(RP@9G5Z>GD*;7-G:60@
M(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")4:61A
M:R!D87!A="!T97)I:V%T(&1E;F=A;B!S97)V97(@;&1A<"(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HT-3<*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O
M(&QD87`@<V5R=F5R(@IM<V=S='(@(E1I9&%K(&1A<&%T('1E<FEK870@9&5N
M9V%N('-E<G9E<B!L9&%P(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B
M5&ED86L@9&%P870@=&5R:'5B=6YG(&ME('-E<G9E<B!L9&%P(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE
M8W0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B5&ED86L@9&%P870@=&5R:'5B
M=6YG(&ME('-E<G9E<B!L9&%P(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C0X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N
M;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B
M5&ED86L@9&%P870@=&5R:'5B=6YG(&ME('-E<G9E<B`G)7,G(&1E;F=A;B!M
M96YG9W5N86MA;B!&5%`Z)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B
M"FUS9W-T<B`B5&ED86L@9&%P870@;65N=6QI<R!K;VYF:6=U<F%S:2!U;G1U
M:R`G)7,G.B`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$Q,C4*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R
M,@IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,C0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@(E1I9&%K(&1A<&%T(&ME
M;6)A;&D@:V4@:V]N9FEG=7)A<VDN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(E1I9&%K(&1A<&%T(&UE;F=H87!U<R!S8W)I<'0@<V5T
M=7`@=7!G<F%D92`G)7,G+B`B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HS.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E
M;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(E1I
M9&%K(&1A<&%T(&UE;F=H87!U<R!S8W)I<'0@<V5T=7`@=7!G<F%D92`G)7,G
M+B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X,2!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O=6QD
M(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L
M971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD
M(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@
M;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T
M+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HW,3D*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@
M<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(E1I9&%K
M(&1A<&%T('1E<FEK870@9&5N9V%N('-E<G9E<B!L9&%P(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+V-O<'DN<&AP.C$S.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R(")4:61A
M:R!D87!A="!M96YY:6UP86X@:V]N9FEG=7)A<VD@)7,N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS
M9W-T<B`B5&ED86L@9&%P870@;65N>6EM<&%N(&MO;F9I9W5R87-I("5S+B(*
M"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-#$X
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA
M;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D
M:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HV.3D*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!
M4"!S97)V97(N(@IM<V=S='(@(E1I9&%K(&1A<&%T('1E<FAU8G5N9R!K92!S
M97)V97(@;&1A<"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B:F5C="YP:'`Z
M,C,X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A
M9"`E<RXB"FUS9W-T<B`B7"(E<UPB(&)E;'5M(&1I8G5A=#H@)7,N(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD
M(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E
M<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R
M96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)4:61A
M:R!D87!A="!M96YG871U<B!U;&%N9R!U;G1U:R!P96YG9W5N82!Y86YG(&1I
M;6EN=&$N($)E8F5R87!A(&%T874@<V5M=6$@(@HB9&5T:6P@=&ED86L@8F5N
M87(N($-O8F$@;&%G:2!A=&%U('-I;&%K86X@:'5B=6YG:2!A9&UI;FES=')A
M=&]R(&%N9&$@:FEK82`B"B)A;F1A(&UE;65R;'5K86X@8F%N='5A;B!L96)I
M:"!L86YJ=70N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S`Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,T,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S@S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X
M.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D
M<F5S<R!B;V]K+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<R(*;7-G<W1R(")4:61A:R!D87!A="!K96UB86QI(&ME(&MO;F9I
M9W5R87-I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-#,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R
M(")4:61A:R!D87!A="!K96UB86QI(&ME(&MO;F9I9W5R87-I+B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD
M(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B5&ED86L@9&%P
M870@:V5M8F%L:2!K92!K;VYF:6=U<F%S:2XB"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B5&ED86L@9&%P870@;65N>6EM<&%N(&MO
M;F9I9W5R87-I("5S+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B0V]U
M;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R(")4
M:61A:R!D87!A="!M96YY:6UP86X@:V]N9FEG=7)A<VD@8F%C:W5P+B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N
M.B`E<R(*;7-G<W1R(")4:61A:R!D87!A="!M96YY:6UP86X@:V]N9FEG=7)A
M<VD@8F%C:W5P.B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDU
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S
M971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")4:61A
M:R!D87!A="!M96YY:6UP86X@<V-R:7!T('-E='5P('5P9W)A9&4@:V4Z)R5S
M)RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+B(*;7-G<W1R(")4:61A:R!D87!A="!M96YY:6UP86X@
M9FEL92!K;VYF:6=U<F%S:2!B86-K=7`@)7,N(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N
M;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I
M=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O
M9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W
M('1O("5S+B(*;7-G<W1R("(B"B)4:61A:R!D87!A="!M96YY:6UP86X@9FEL
M92!K;VYF:6=U<F%S:2`E<RX@06YD82!D87!A="!M96YG9W5N86MA;B!S86QA
M:"!S871U("(*(F1A<FD@<&EL:6AA;B!U;G1U:R!M96YY:6UP86X@:V]D92!T
M97)S96)U="!K96UB86QI(&ME("5S(&%T875P=6X@;65N>6%L:6X@(@HB:V]D
M92!D:2!B87=A:"!I;FD@<V5C87)A(&UA;G5A;"!K92`E<RXB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T,PHC+"!F=7IZ>0IM<V=I9"`B
M0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(E1I
M9&%K(&1A<&%T('1E<FAU8G5N9R!K92!S97)V97(@;&1A<"(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS
M9W-T<B`B5&ED86L@9&%P870@;65N>6EM<&%N(&MO;F9I9W5R87-I("5S+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,SDV"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D
M871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")4:61A:R!D87!A
M="!M96YU;&ES(&MO;F9I9W5R87-I('5N='5K("<E<R<Z("5S(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB
M.B`E<R(*;7-G<W1R(")4:61A:R!D87!A="!M96YU;&ES(&MO;F9I9W5R87-I
M('5N='5K("<E<R<Z("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V
M-@IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-
M86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B(@HB5&ED
M86L@9&%P870@;65N96UU:V%N(%!A;F5L($YA=FEG87-I($UO>FEL;&$N(%!A
M<W1I:V%N('!A;F5L(&YA=FEG87-I('-U9&%H("(*(G1E<F)U:V$N(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@
M=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB.B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#$Y
M"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*(RP@9G5Z>GD*;7-G:60@(D-O
M=6YT<GDB"FUS9W-T<B`B2V]M<'5T97(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C<S"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(DMU<G-U<R(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(D)U870B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C@*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B0G5A="!L:6YK(@H*
M(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY-`IM<V=I
M9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R(")"=6%T(&)A<G4B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B
M0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,C0P"B,L(&9U>GIY"FUS9VED(")#<F5A=&]R
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(DEZ:6X@=&%M=2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,R,S`*(RP@9G5Z>GD*;7-G:60@(D-R961I="!C
M87)D(&YU;6)E<B(*;7-G<W1R(")!;F=K82!$97-I;6%L(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-SD*(RP@9G5Z>GD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B0G5A="(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(V"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(#0@4&AA<V5S
M(@IM<V=S='(@(D9A<V4@4V5K87)A;F<B"@HC.B!A9&UI;B]S97-S:6]N<RYP
M:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T
M<B`B27II;B!T86UU(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L
M;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B
M5V%K='4@4V5K87)A;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES
M(@IM<V=S='(@(E523"!396MA<F%N9R!A9&%L86@B"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z,S,*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS
M9W-T<B`B1F%S92!396MA<F%N9R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R(")#=6%C82!396MA
M<F%N9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S4*;7-G
M:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B2V]N9&ES:2!396MA
M<F%N9SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(D=A>6$@4V5K
M87)A;F<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF
M;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O
M;B!T;R`E<RXB"FUS9W-T<B`B2V]S='5M:7-A<VD@='5G87,@=6YT=6L@9&EJ
M86QA;FMA;B!S96)E;'5M(&QO9V]N(&ME("5S+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B
M0W5T(@IM<V=S='(@(DAA<'5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G
M<W1R(")(87!U<R!P:6QI:&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED
M(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R(")#>7)I;&QI8R`H2T])."U2
M*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI
M8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R(")#>7)I;&QI8R`H5VEN9&]W<RTQ
M,C4Q*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED(")#>7)I
M;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B0WER:6QL:6,O56MR
M86EN:6%N("A+3TDX+54I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P
M=6)L:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0U,2!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I
M9"`B1$0B"FUS9W-T<B`B1$0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,C@Q"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T
M+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N
M86YC92YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(D1A:6QY(@IM<V=S='(@(DAA
M<FDB"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E
M($)R;W=S97(B"FUS9W-T<B`B1&%T851R964@0G)O=W-E<B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,R-SD*;7-G:60@(D1A=&%B87-E($QO;VMU
M<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.3D*(RP@
M9G5Z>GD*;7-G:60@(D1A=&4B"FUS9W-T<B`B4V%L:6XB"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E
M:79E9"(*;7-G<W1R(")486YG9V%L($1I=&5R:6UA(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@P-PHC+"!F=7IZ>0IM<V=I9"`B1&%T92!S96QE
M8W1I;VXB"FUS9W-T<B`B2&%P=7,@<&EL:6AA;B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.3(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,R,@IM<V=I9"`B1&%Y(@IM<V=S='(@(DAA<FDB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G
M:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(DAA<'5S($MO;&]M(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@
M(D1E8V5M8F5R(@IM<V=S='(@(D1E<V5M8F5R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B
M1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(D%N9VMA($1E<VEM86PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED
M(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B365N9W5R86YG:2!);F1E;B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI8B]P<F5F
M<RYP:'`Z,3$W"FUS9VED(")$969A=6QT(@IM<V=S='(@(D1E9F%U;'0B"@HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PIM
M<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R(")$969A=6QT(%=A<FYA(@H*
M(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HY,0HC+"!F=7IZ
M>0IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R(")$969A=6QT(&ED
M96YT:71A<R!A;F1A.B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-PIM
M<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R(")$969A=6QT(%-H96QL(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N
M<R(*;7-G<W1R(")$969I;FES:2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C<S('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R(")(87!U
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS,@IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`B2&%P=7,@
M4V5L(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H
M<#HR,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R(")(87!U<R!'<G5P
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y"B,L(&9U>GIY
M"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@(DAA<'5S(&)A<FES(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$P,0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(%!E
M<FUI<W-I;VXB"FUS9W-T<B`B27II;B!T86UU(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@
M<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E
M(&-E;&PB"FUS9W-T<B`B2&%P=7,@<V5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E
M(&-O;'5M;B(*;7-G<W1R(")(87!U<R!K;VQO;2(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N871E
M('1E;7!L871E(@IM<V=S='(@(DAA<'5S('!E;F=G86YT:2!T96UP;&%T92!Y
M86YG('-U9&%H(&%D82(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z-#(Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R
M;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")58F%H(&EZ:6X@=6YT=6L@
M)7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<
M(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM
M<V=I9"`B1&5L971E(')O=R(*;7-G<W1R(")(87!U<R!B87)I<R(*"B,Z('1E
M;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E
M;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R(")(87!U<R!I9&5N=&ET
M87,@>6%N9R!T97)P:6QI:"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C
M=7)R96YT(&-O;'5M;B(*;7-G<W1R(")(87!U<R!K;VQO;2!Y86YG('-E:V%R
M86YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM
M<V=S='(@(DAA<'5S(&)A<FES('EA;F<@<V5K87)A;F<B"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HS-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S
M='(@(DAA<'5S('-C<FEP="!S971U<"!U<&=R861E("<E<R<N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(U,PHC+"!F=7IZ>0IM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R
M(")(87!U<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-CD*(RP@9G5Z>GD*;7-G:60@(D1E;FUA<FLB
M"FUS9W-T<B`B1&ET86YD86DB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T
M<B`B2F5L87-K86X@36%S86QA:"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.CDS."!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")$97-K<FEP
M<VDB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-0IM<V=I9"`B
M1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y.0HC+"!F=7IZ>0IM
M<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`B07)E82!-971A<B!T:61A:R!D:7-E9&EA:V%N
M+B!$971I;"!T96QA:"!D:6-A=&%T('5N='5K(&%D;6EN:7-T<F%T;W(N(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q.0IM<V=I9"`B1&5V96QO
M<&UE;G0B"FUS9W-T<B`B4&5R:V5M8F%N9V%N(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,3<*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R(")4:71I:R!%
M;6)U;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDT"FUS9VED(")$97<@
M4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E1I=&EK($5M8G5N('5N
M='5K(&IA;2!T97)A:VAI<CHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C(W"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R(")4:71I:R!%
M;6)U;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@
M(D%R86@@:VER:2!K92!K86YA;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T
M;R!L969T(@IM<V=S='(@(D%R86@@:V%N86X@:V4@:VER:2(*"B,Z(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B
M1&ER96MT;W)I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V-@IM<V=I
M9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R(")486UP:6QK86X@
M=V%K='4@,C0@:F%M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM
M<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(E1A;7!I;&MA;B!0:6QI
M:&%N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.CDV"FUS9VED
M(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@(E1A;7!I;&MA
M;B!D971I;"!R86UA;&%N(&-U86-A(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HX-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R(")4
M86UP:6QK86X@<F%M86QA;B!C=6%C82`H5$%&*2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(X,3<*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@9F]R
M;6%T(@IM<V=S='(@(E1A;7!I;&MA;B!R86UA;&%N(&-U86-A("A4048I(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B1&ES
M<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*
M;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z-#(R"B,L(&9U>GIY"FUS9VED(")$;R!N;W0@9&5L
M971E(@IM<V=S='(@(DAA<'5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA
M;F-E+G!H<"(*;7-G<W1R(")*86YG86X@;&%N9W-U;F<@;65N9V%K<V5S(&UA
M:6YT96YA;F-E+G!H<"(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S
M('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE
M<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(B(*(D%P86MA:"!B87)I<R!Y
M86YG('!E<G1A;6$@=&5R9&ER:2!D87)I(&MO;&]M(&YA;6$_(&II:V$@>6$L
M(&)E<FD@=&%N9&$@<&%D82`B"B)K;W1A:R!I;FDZ(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM
M<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B
M1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N
M=#\@4VEG;B!U<"XB"FUS9W-T<B`B5&ED86L@;65M:6QI:VD@86-C;W5N=#\@
M4VEL86MA;B!M96YD869T87(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z.#0T"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B1&]W
M;FQO860@:V]N9FEG=7)A<VD@>6%N9R!D:6AA<VEL:V%N('-E8F%G86D@<V-R
M:7!T(%!(4"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`W"FUS
M9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(D]B870M;V)A
M=&%N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"B,L
M(&9U>GIY"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B4W5R870B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B
M14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI
M8V@@<')O=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS
M9VED(")%8W5A9&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHW,@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%
M9&ET(@IM<V=S='(@(E5B86@B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M54DN<&AP.C4P('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G:60@
M(D5D:70@0FQO8VLB"FUS9W-T<B`B56)A:"!";&]K:7(B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R-@IM<V=I9"`B161I
M="!'<F]U<"(*;7-G<W1R(")58F%H($=R=7`B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,3`P"B,L(&9U>GIY"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T
M<B`B56)A:"!)>FEN(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S
M-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R(")58F%H($EZ:6XB
M"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(E5B
M86@@27II;B!U;G1U:R`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC
M.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(E5B86@@<&EL
M:6AA;B!U;G1U:SHB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C,V-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S
M:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(E5B86@@:7II;B!U;G1U:R`E<R(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B56)A
M:"!I>FEN('5N='5K("5S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U
M"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B4&5N9&ED:6MA;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,S$P"B,L('!H<"UF;W)M870*;7-G:60@(D5I=&AE
M<B!E;F%B;&4@:70@=&AE;CH@)7,L(&]R('5S92!T:&4@8F%S:6,@2%1-3"!V
M97)S:6]N.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%
M;"!386QV861O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N
M+BXB"FUS9W-T<B`B16QE;65N+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(D5M
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R
M-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8Y"B,L(&9U>GIY"FUS9VED
M(")%;6%I;"(*;7-G<W1R(")3=7)A="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-38U('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I
M="YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV
M.`IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R(")!;&%M870@16UA:6PB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38S"B,L(&9U>GIY"FUS
M9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`B4V%N
M9&D@:&%R=7,@8V]C;VLN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3DX.0HC+"!F=7IZ>0IM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB
M"FUS9W-T<B`B2V]N9FEG=7)A<VD@)7,@<W5D86@@9&ES:6UP86XN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G
M:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR.3@*(RP@9G5Z>GD*
M;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R(")+;VYD:7-I(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED
M(")%;7!T>2!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C8V,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R
M97-U;'0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O
M<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30S"FUS9VED(")%;F%B
M;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I
M;B!T97AT/R(*;7-G<W1R(")!:W1I9FMA;B!P96YY:7-I<&%N(&=A;6)A<BUG
M86UB87(@9&%R:2!'86QE<FD@1F]T;R!D:2!D86QA;2!T96MS/R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3@*;7-G:60@(D5N86)L92!R:6=H="!C
M;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(D%K=&EF:V%N(&ML:6L@:V%N
M86X@;65N=2!K;VYT96MS/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(U.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,0HC+"!F=7IZ>0IM
M<V=I9"`B16YD('EE87(B"FUS9W-T<B`B4&5R8F5S87(@4&%N96P@3F%V:6=A
M<VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R(")097)B97-A<B!%
M9&ET;W(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q"FUS9VED("(B
M"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E
M(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L
M(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T
M<B`B(@HB36%S=6MK86X@<&5R=&%N>6%A;B!K96%M86YA;B!D:6UA;F$@86YD
M82!A:V%N(&1I=&%N>6%K86X@87!A8FEL82!A;F1A('!E<FQU("(*(G5N='5K
M(&UE;F=A='5R('5L86YG('-A;F1I(&%N9&$L("!C;VYT;V@@)V%P86MA:"!N
M86UA(&)I;F%T86YG(&ME<V%Y86YG86X@(@HB86YD83\G.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M,@IM<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(DUA
M<W5K:V%N(%523"!G86UB87(@9&ES:6YI(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,0IM<V=I9"`B16YT97(@=&AE(&QE
M='1E<G,@8F5L;W<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q
M=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@
M(D5R:71R96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#4@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C4U"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S8@<V5R=FEC
M97,O<&]R=&%L+VEN9&5X+G!H<#HX,@IM<V=I9"`B17)R;W(B"FUS9W-T<B`B
M2V5S86QA:&%N(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H
M<#HT-C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-R96%T
M:6YG(&)L;V-K.B`E<R(*;7-G<W1R(")+97-A;&%H86X@<V%A="!M96UP97)B
M86AA<G5I('-A;F1I.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C<R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE
M=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B2V5S86QA:&%N('-A870@
M;65M<&5R8F%H87)U:2!S86YD:3H@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HX,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(DME<V%L86AA;B!S
M86%T(&UE;7!E<F)A:&%R=6D@<V%N9&DZ("5S(@H*(SH@9G)A;65W;W)K+U1E
M;7!L871E+U1E;7!L871E+G!H<#HT-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`B2V5S
M86QA:&%N('-A870@;65M<&5R8F%H87)U:2!S86YD:3H@)7,B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(DME<V%L
M86AA;B!S86%T(&UE;7!E<F)A:&%R=6D@<V%N9&DZ("5S(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED
M(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*(RP@9G5Z
M>GD*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B4W5K=2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(E-U:W4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"FUS9VED
M(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(E-E=&EA<"`Q-2!M96YI="(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#D*;7-G:60@(D5V97)Y(#(@
M;6EN=71E<R(*;7-G<W1R(")3971I87`@,B!M96YI="(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,S8@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-PIM
M<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R(")3971I87`@,S`@9&5T
M:6LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,X(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.3`*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R
M(")3971I87`@-2!M96YI="(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-
M86EN=&5N86YC92YP:'`Z-C`*(RP@9G5Z>GD*;7-G:60@(D5V97)Y($QO9VEN
M(@IM<V=S='(@(E-E=&EA<"!M96YI="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-#`*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")3971I
M87`@<V5T96YG86@@:F%M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S
M-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@X"FUS9VED(")%=F5R>2!M:6YU
M=&4B"FUS9W-T<B`B4V5T:6%P(&UE;FET(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R
M(")#;VYT;V@@;FEL86DM;FEL86DZ(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP
M.C@Q(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3(W"FUS9VED(")%>&5C=71E(@IM<V=S='(@(DIA;&%N:V%N(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#<U"B,L(&9U>GIY"FUS
M9VED(")%>'!A;F0B"FUS9W-T<B`B4&5R8F5S87(@4&%N96P@3F%V:6=A<VDB
M"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS9VED(")%
M>'!A;F0@4VED96)A<B(*;7-G<W1R(")097)B97-A<B!086YE;"!.879I9V%S
M:2(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-C@*(RP@
M9G5Z>GD*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R(")*86QA;FMA;B(*
M"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@
M(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R
M"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S8*;7-G:60@(D5X<&]N96YT
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(E=A
M<FYA($9'(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B
M1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R(")&5%`@=7!L;V%D('5N='5K
M('-E='5P(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z,C$V
M"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<U(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@
M(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")4
M:61A:R!D87!A="!T97)H=6)U;F<@:V4@<V5R=F5R(&QD87`B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(D9A
M:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(E1I9&%K
M(&1A<&%T('1E<FAU8G5N9R!K92!S97)V97(@;&1A<"(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z-C@V"B,L('!H<"UF;W)M870*;7-G:60@(D9A
M:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C8Y,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<*;7-G:60@(D9A:6QE9"!T
M;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3<@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HW,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A
M:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B5&ED86L@9&%P870@
M=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HT-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D
M('1O(')E=')I979E.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R
M(")#97)A:"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@
M*$UA;'9I;F%S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&87)O
M92!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H
M<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"B,L(&9U>GIY
M"FUS9VED(")&87@B"FUS9W-T<B`B1F%X(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,T.0IM<V=I9"`B1F%X97,B"FUS9W-T<B`B1F%X(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@
M(D9E8G)U87)Y(@IM<V=S='(@(D9E8G)U87)I(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,C`*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B4V5P97)T
M:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@
M(D9E96QS(&QI:V4Z("(*;7-G<W1R(")397!E<G1I.B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO
M=V5R<R(*;7-G<W1R(")'97)I;6ES(%-E8F%G:6%N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W
M(%-H;W=E<G,B"FUS9W-T<B`B1V5R:6UI<R!386QJ=2!396)A9VEA;B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0*;7-G:60@(D9I96QD(&UA
M=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,S,T"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X"FUS9VED(")&:6=L970@9F]N="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM
M<V=I9"`B1FEL92(*;7-G<W1R(")&:6QT97(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT
M.B`E<R!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I
M;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,#<*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R(")&:6QE($UA;F%G97(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8S(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-0HC+"!F=7IZ>0IM<V=I
M9"`B1FEL92!.86UE(@IM<V=S='(@(DYA;6$@3&5N9VMA<"(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34*(RP@9G5Z>GD*;7-G:60@(D9I;&4@
M<V5L96-T:6]N(@IM<V=S='(@(DAA<'5S('!I;&EH86XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#@V"FUS9VED(")&:6QE('5P;&]A9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-3D*
M(RP@9G5Z>GD*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*
M;7-G<W1R(")&5%`@=7!L;V%D('5N='5K('-E='5P(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C@Y"FUS9VED(")&:6QT97)S(@IM<V=S='(@(D9I
M;'1E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(D9I;FQA;F0B"FUS
M9W-T<B`B;6%S:6@@9&D@9&%L86T@86YT<FEA;B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B1F%S92!P
M97)T86UA(&1A<FD@4V5P87)U:"!"=6QA;B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U
M87)T97(B"FUS9W-T<B`B1F%S92!P97)T86UA(&1A<FD@4V5P87)U:"!"=6QA
M;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M-38*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Q"FUS9VED(")&;&EP(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(D9L;V%T(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G
M:60@(D9O9R(*;7-G<W1R(")"97)K86)U="(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ
M,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X
M:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B5V%R
M;F$@5'5L:7-A;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I
M9"`B1F]O9"(*;7-G<W1R(")-86MA;F%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&
M;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R
M(")5;G1U:R!B<F]W<V5R('EA;F<@=&ED86L@9&%P870@;65N9'5K=6YG(&=A
M;6)A<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,T"FUS9VED(")&;W)E
M8V%S="`H5$%&*2(*;7-G<W1R(")286UA;&%N(&-U86-A("A4048I(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<Y"FUS9VED("(B"B)&;W)E
M8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E
M='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H
M97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*
M(DAA<FD@4F%M86QA;B!#=6%C82`H8V%T871A;B!B86AW82!R86UA;&%N(&-U
M86-A('EA;F<@9&EK96UB86QI:V%N(&%K86X@(@HB;65N9V5M8F%L:6MA;B!B
M86EK('-I86YG(&%T874@;6%L86T@:&%R:2P@<V5J=6UL86@@86YG:V$@9&%P
M870@9&EH87-I;&MA;B`B"B)P861A(&%R96$@:6YI*2(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S
M=V]R9#\B"FUS9W-T<B`B3'5P82!D96YG86X@<V%N9&D@86YD83\B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8R"FUS9VED(")&;W)M<R(*;7-G
M<W1R(")&;W)M=6QI<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM
M<V=I9"`B1F]R='5N92(*;7-G<W1R(")286UA;&%N(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B
M5&EP92!286UA;&%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"FUS
M9VED(")&;W)T=6YE<R(*;7-G<W1R(")286UA;&%N(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(E)A
M;6%L86X@,B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-3,*;7-G
M:60@(D9O<G5M<R(*;7-G<W1R(")&;W)U;2(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ,#D*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(D1I=&5R
M=7-K86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R(")*;70B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"FUS9VED(")&
M<F%M97,B"FUS9W-T<B`B1G)A;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"B,L(&9U>GIY"FUS
M9VED(")&<F%N8V4B"FUS9W-T<B`B1G)A;64B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA;F$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S
M:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U
M=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B
M1G)O;2(*;7-G<W1R(")*;70B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C0X(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C`*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-@IM<V=I9"`B1G)O;2!T
M:&4@(@IM<V=S='(@(D1A<FDB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R(")$
M97-K<FEP<VD@3&5N9VMA<"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T
M<B`B0G5L86X@4'5R;F%M82(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV
M,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&
M=6QL($YA;64B"FUS9W-T<B`B3F%M82!,96YG:V%P(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM
M<V=I9"`B1V%B;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL
M97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R(")'86QE<FD@=6YT=6L@
M;65N9V%M8FEL(&=A;6)A<B!D87)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL
M97)Y.B(*;7-G<W1R(")'86QE<FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB
M:6$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N
M(@IM<V=S='(@(DUE;F=H87-I;&MA;B`E<R!+;VYF:6=U<F%S:2`B"@HC.B!T
M96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N
M97)A=&5D($-O9&4B"FUS9W-T<B`B2V]D92!Y86YG(&1I:&%S:6QK86XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I
M9"`B1VAA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L
M=&%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3<U"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*;7-G<W1R(")*
M86QA;FMA;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B
M1V]E9&5L(@IM<V=S='(@(D=O961E;"(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,3(X"B,L(&9U>GIY"FUS9VED(")';V]G
M;&4@36%P<R(*;7-G<W1R(")096YC87)I86X@1V]O9VQE(@H*(SH@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G
M<W1R(")096YC87)I86X@1V]O9VQE(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(S-PIM<V=I9"`B1W)A>7-C86QE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@(D=R965K("A)4T\M
M.#@U.2TW*2(*;7-G<W1R(")9=6YA;FD@*$E33RTX.#4Y+3<I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*
M;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HQ-SD*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D
M;6EN:7-T<F%S:2!'<G5P(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H
M<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED
M(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L('!H<"UF
M;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@
M)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*
M;7-G<W1R(")4:61A:R!D87!A="!U;G1U:R!M96YG:&%P=7,@7"(E<UPB.B`E
M<RXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S,X(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(D=R=7`B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W
M"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B1W5E<FYS97DB"FUS
M9W-T<B`B475E<GDB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'=65S
M="!097)M:7-S:6]N<R(*;7-G<W1R("))>FEN('1A;74B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#<P"FUS9VED(")'=65S=&)O;VLB"FUS9W-T
M<B`B0G5K=2!T86UU(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B1W5I
M;F5A(@IM<V=S='(@(DIU;FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE
M82U":7-S874B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA
M;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.38P
M"FUS9VED(")(5$U,(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@
M<F]W+B(*;7-G<W1R("(B"B)(5$U,07)E82!D96YG86X@<F%G=2!M96YO;&%K
M('5N='5K(&UE;F=H87!U<R!S96P@>6%N9R!T97)A:VAI<B!D:2!D86QA;2`B
M"B)B87)I<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S
M='(@(B(*(DA434Q!<F5A(&1E;F=A;B!R86=U(&UE;F]L86L@=6YT=6L@;65N
M9VAA<'5S(&MO;&]M('EA;F<@=&5R86MH:7(@9&D@9&%L86T@(@HB=&%B96PN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D
M96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R("(B"B)(5$U,
M07)E82!D96YG86X@<F%G=2!M96YO;&%K('5N='5K(&UE;F=H87!U<R!B87)I
M<R!Y86YG('1E<F%K:&ER(&1I(&1A;&%M("(*(G1A8F5L+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE
M;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P
M"FUS9VED(")(86ET:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(R"FUS9VED(")(87IE(@IM<V=S='(@(D)E<FMA8G5T(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Y,S(*(RP@9G5Z>GD*;7-G:60@(DAE861E<B(*;7-G<W1R(")"86-A(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0IM
M<V=I9"`B2&5A9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@
M(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PHC
M+"!F=7IZ>0IM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R(")(=6IA;B!P
M971I<B!D:7-E<G1A:2!D96YG86X@86YG:6X@<FEB=70B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI
M(@IM<V=S='(@(EEA:'5D:2`H25-/+3@X-3DM."U)*2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@
M(DAE:6=H="(*;7-G<W1R(")4:6YG9VDB"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O2&5L<"YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92](96QP
M+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA
M=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G:60@(DAE;'`B"FUS9W-T<B`B0F%N
M='5A;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(D)A;G1U
M86X@;65N9V=U;F%K86X@961I=&]R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,W,0HC+"!F=7IZ>0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(D)A
M;G1U86XB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES
M<&AE<F4B"FUS9W-T<B`B0F5L86AA;B!"=6UI(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB
M"FUS9W-T<B`B26YI(&%D86QA:"!P97)M=6QA86X@9&%R:2!F:6QE.B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED
M(")(:6=H(@IM<V=S='(@(E1I;F=G:2(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z
M-0IM<V=I9"`B2&]?;64B"FUS9W-T<B`B2&]?;64B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T
M"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U,S4*(RP@9G5Z
M>GD*;7-G:60@(DAO;64B"FUS9W-T<B`B2&]?;64B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*(RP@9G5Z>GD*;7-G:60@
M(DAO;64@061D<F5S<R(*;7-G<W1R(")!;&%M870@16UA:6PB"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM
M<V=S='(@(D1I<F5K=&]R:2!(;VUE(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-0IM<V=I9"`B2&]R9&4B
M"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI
M9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E
M<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G
M92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$R-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B7"(E
M<UPB<W5D86@@8F5R:&%S:6P@9&EH87!U<RXB"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E
M9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E
M;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0W"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(E1I9&%K(&1A<&%T('5N
M='5K(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z-#<T"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@
M;V8@='EP92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$Q.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3,S-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N
M:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO
M<FEZ;VYT86P@4G5L92(*;7-G<W1R(")'87)I<R!(;W)I<V]N=&%L(&1I(&1A
M;&%M($A434PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B
M2F%R86L@9V%R:7,@:&]R:7IO;G1A;"!D87)I(&)O<F1E<B!D96YG86X@=&5K
M<R!D:2!D86QA;2!S96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R(")(
M;W)I>F]N=&%L.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE
M<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B0F%G86EM86YA(&-A<F$@
M86YD82!B:7-A('-A;7!A:2!D:7-I;FD_("A3:6QA:V%N(&UE;&%P;W(A*2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@
M=&\@;65R9V4_(@IM<V=S='(@(D)E<F%P82!B86YY86L@:V]L;VT@>6%N9R!I
M;F=I;B!A;F1A(&=A8G5N9VMA;C\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A
M<F4@=&AE<F4_(@IM<V=S='(@(D)E<F%P82!B86YY86L@:V]L;VT@>6%N9R!A
M9&$@9&ES86YA/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@
M>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(D)E<F%P82!B86YY86L@8F%R
M:7,@>6%N9R!I;F=I;B!A;F1A(&=A8G5N9VMA;C\B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]M971A<BYP:'`Z,C,P
M"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R(")+96QE;6)A8F%N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.0IM<V=I9"`B2'5M:61I='DZ
M("(*;7-G<W1R(")+96QE;6)A8F%N.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(E!E;&%W86LB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!
M4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q-@HC+"!F
M=7IZ>0IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R(")!;&%M870@16UA:6PB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C<W"B,L(&9U
M>GIY"FUS9VED("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(D%R96$@365T87(@=&ED86L@9&ES961I86MA;BXB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO
M="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*
M;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B36%S=6MK
M86X@0F%R:7,@4V5B96QU;6YY82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E
M;&%N9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<V
M"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@(DAA;GEA(&EK;VXB"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M26-O;G,@9F]R("5S(@IM<V=S='(@(DEK;VX@=6YT=6L@)7,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S<W"FUS9VED("))8V]N<R!W:71H('1E>'0B
M"FUS9W-T<B`B26MO;B!D96YG86X@=&5K<R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ.3`*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B
M3F%M82!)9&5N=&ET87,Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z-3DR"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO
M="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W
M('=I;F1O=RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0U-0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I
M;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B
M"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G
M<W1R("(B"B)*:6MA(&%N9&$@=&ED86L@;65L:6AA="!I:V]N(&UA;F%P=6X@
M9&5N9V%N(&UE;F=G=6YA:V%N($EN=&5R;F5T($5X<&QO<F5R+"`B"B)A;F1A
M(&UU;F=K:6X@<&5R;'4@=6YT=6L@;65N86YD86D@:V]T86L@:6YI('5N='5K
M(&UE;F]N+6%K=&EF:V%N(&ME;&5M86AA;B`B"B)03D<N(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,PIM<V=I9"`B(@HB
M268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA
M9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B
M>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B
M26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B3&EH870@1V%M8F%R.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*
M;7-G:60@(DEM86=E(%523"(*;7-G<W1R(")54DP@1V%M8F%R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(E523"!'86UB87(Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B
M1V%M8F%R(&1A<FD@9V%L97)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F
M<F]M(&=A;&QE<GDZ(@IM<V=S='(@(D=A;6)A<B!D87)I(&=A;&5R:3HB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Q"FUS9VED("));6%G92!U
M<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*
M;7-G:60@(DEM86=E<R(*;7-G<W1R(")'86UB87(M9V%M8F%R(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E
M;6%P+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED
M("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B26UP;W(L($QA;F=K86@@)60B
M"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B2V]L;VT@
M>6%N9R!D:6EM<&]R.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B2V]L;VT@
M>6%N9R!D:6EM<&]R.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T
M97(B"FUS9W-T<B`B36%S=6MK86X@0F%R:7,@0F5R:6MU=&YY82(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-0IM<V=I9"`B
M26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@HC
M+"!F=7IZ>0IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S
M=V]R9"XB"FUS9W-T<B`B4VEL86MA;B!M87-U:VMA;B!N86UA('!E;F=G=6YA
M(&1A;B!S86YD:2!A;F1A(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA
M=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI
M;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B
M(@HB3F%M82!P96YG9W5N82!A=&%U(&%L86UA="!E;6%I;"!P96YG9V%N=&D@
M=&ED86L@8F5N87(N($-O8F$@;&%G:2!A=&%U("(*(G-I;&%K86X@:'5B=6YG
M:2!A9&UI;FES=')A=&]R(&%N9&$@:FEK82!A;F1A(&UE;65R;'5K86X@8F%N
M='5A;B!L96)I:"!L86YJ=70N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM
M<V=S='(@(DUE;F%M8F%H($EN9&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))
M;F1I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B
M26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R(")096YG9W5N82!0<FEB861I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I
M9"`B26YF;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C4W"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA<VDB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S,P"FUS9VED("))
M;F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+B(*;7-G<W1R("));F9O
M<FUA<VD@<W5D86@@=&ED86L@9&ES961I86MA;BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@
M(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(DUA<W5K:V%N($MO;&]M
M($)E<FEK=71N>6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!);6%G92(*
M;7-G<W1R(")-87-U:VMA;B!'86UB87(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B
M"FUS9W-T<B`B36%S=6MK86X@5&%B96PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B($QI
M;FLB"FUS9W-T<B`B36%S=6MK86X@5V5B($QI;FLB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@
M(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R(")-87-U:VMA;B!+;VQO
M;2!396)E;'5M;GEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L
M=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")-87-U:VMA;B!K
M;VQO;2!Y86YG(&)A<G4@<V5T96QA:"!K;VQO;2!Y86YG('-E:V%R86YG(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@
M8W5R<F5N="!O;F4B"FUS9W-T<B`B36%S=6MK86X@:V]L;VT@>6%N9R!B87)U
M('-E8F5L=6T@:V]L;VT@>6%N9R!S96MA<F%N9R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B
M26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T
M<B`B36%S=6MK86X@8F%R:7,@>6%N9R!B87)U('-E=&5L86@@8F%R:7,@>6%N
M9R!S96MA<F%N9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B
M969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DUA<W5K:V%N(&)A<FES
M('EA;F<@8F%R=2!S96)E;'5M(&MO;&]M('EA;F<@<V5K87)A;F<B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N
M="!N;V1E(@IM<V=S='(@(DUA<W5K:V%N('!A<F%G<F%F('-E=&5L86@@<&%R
M86=R868@>6%N9R!S96MA<F%N9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@
M<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(DUA
M<W5K:V%N('!A<F%G<F%F('-E8F5L=6T@<&%R86=R868@>6%N9R!S96MA<F%N
M9R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@
M86QT97)N871E('1E;7!L871E(@IM<V=S='(@(DUA<W5K:V%N('1E;7!L871E
M('!E;F=G86YT:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,SD*;7-G
M:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@
M<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R(")-87-U:VMA;B!A
M;&%M870@96UA:6P@9&EM86YA(&%N9&$@9&%P870@;65N97)I;6$@<V%N9&D@
M>6%N9R!B87)U.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM
M<V=S='(@(DUA<W5K:V%N('-E;"!B97)I:W5T;GEA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B
M26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(DUA<W5K:V%N('-E;"!S96)E
M;'5M;GEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G
M<W1R(")-87-U:VMA;B!K;VQO;2!B97)I:W5T;GEA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B
M26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B36%S=6MK86X@:V]L;VT@
M<V5B96QU;6YY82(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDP"B,L(&9U>GIY"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS
M9W-T<B`B36%S=6MK86X@1V%M8F%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@
M<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(DUA<W5K:V%N('!A<F%G<F%F(&)E
M<FEK=71N>6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F
M;W)E(@IM<V=S='(@(DUA<W5K:V%N('!A<F%G<F%F('-E8F5L=6UN>6$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(DUA<W5K:V%N
M(&)A<FES(&)E<FEK=71N>6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E
M9F]R92(*;7-G<W1R(")-87-U:VMA;B!B87)I<R!S96)E;'5M;GEA(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,`IM<V=I9"`B26YS97)T('1H92!R
M97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G
M<W1R(")-87-U:VMA;B!J87=A8F%N('EA;F<@9&EP97)L=6MA;B!U;G1U:R!P
M97)T86YY86%A;B!K96%M86YA;CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM
M86=E(@IM<V=S='(@(DUA<W5K:V%N+U5B86@@1V%M8F%R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS
M97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@(DUA<W5K:V%N+U5B86@@3&EN:R(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE
M(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS
M=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3`W-0HC+"!F=7IZ>0IM<V=I9"`B26YT96=E<B(*;7-G
M<W1R(")496YG86@B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,S
M"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("))
M;G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ-S`*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C`Q"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q,`IM<V=I9"`B
M26YV86QI9"!:25`@9&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G
M<W1R(")!<&QI:V%S:2!T:61A:R!V86QI9"XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L
M:60@8F%T8V@@240N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R.3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE
M<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`P"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&1E<W1I;F%T
M:6]N(&%D9')E<W,N(@IM<V=S='(@(D%P;&EK87-I('1I9&%K('9A;&ED+B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`*(RP@9G5Z
M>GD*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B1F]R;6%T
M(%=A:W1U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-PHC
M+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B
M07!L:6MA<VD@=&ED86L@=F%L:60N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$W,0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!L;V-A=&EO
M;B!P<F]V:61E9"XB"FUS9W-T<B`B07!L:6MA<VD@=&ED86L@=F%L:60N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*
M(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM
M<V=S='(@(DEZ:6X@:6YD=6L@=&ED86L@=F%L:60N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"B,L(&9U>GIY
M"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T
M<B`B27II;B!I;F1U:R!T:61A:R!V86QI9"XB"@HC.B!A9&UI;B]P97)M<R]A
M9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I
M;VXN(@IM<V=S='(@(DEZ:6X@:6YD=6L@=&ED86L@=F%L:60N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,PHC+"!F=7IZ>0IM<V=I9"`B
M26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R("))>FEN(&EN9'5K('1I9&%K
M('9A;&ED+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*
M(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R
M(")!<&QI:V%S:2!T:61A:R!V86QI9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*(RP@9G5Z>GD*;7-G:60@
M(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(D%P;&EK87-I('1I9&%K('9A
M;&ED+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HW,2!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C@P"B,L
M('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,#<V
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(V,@IM<V=I9"`B26YV86QI
M9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"B,L(&9U>GIY"FUS9VED
M("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R("))>FEN(&EN9'5K
M('1I9&%K('9A;&ED+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q,0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!U
M;FEC;V1E(&1A=&$N(@IM<V=S='(@(D%P;&EK87-I('1I9&%K('9A;&ED+B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3<*;7-G:60@(DEN=F5N
M=&]R>2(*;7-G<W1R("));G9E;G1O<FES(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.0HC+"!F=7IZ>0IM<V=I9"`B26YV
M97)T('-E;&5C=&EO;B(*;7-G<W1R(")(87!U<R!P:6QI:&%N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R(")(
M=6IA;B!P971I<B!D:7-E<G1A:2!A;F=I;B!R:6)U="!D:2!D865R86@@>6%N
M9R!T97)P96YC:6PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R
M-0IM<V=I9"`B27-S=65R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S
M='(@(DAU<G5F($UI<FEN9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@HC+"!F=7IZ>0IM<V=I
M9"`B271A;'DB"FUS9W-T<B`B2'5R=68@36ER:6YG(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R
M"FUS9VED(")*86UA:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#$*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S
M='(@(DIA;G5A<FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")*87!A
M;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(DIE<&%N9R`H25-/+3(P,C(M
M2E`I(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*;7-G:60@
M(B(*(DIA=F%S8W)I<'0@:&%S(&)E96X@9&ES86)L960@;VX@>6]U<B!B<F]W
M<V5R(&%N9"!T:&ES('!A9V4@;6%Y(&YO="!B92`B"B)D:7-P;&%Y:6YG(&-O
M<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R
M(")*=6QI(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B2G5N:2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@
M(DIU<W1I9GDB"FUS9W-T<B`B4F%T82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y
M($-E;G1E<B(*;7-G<W1R(")2871A(%1E;F=A:"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*
M=7-T:69Y($9U;&PB"FUS9W-T<B`B4F%T82!+:7)I(&1A;B!+86YA;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`B4F%T82!+:7)I(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B4F%T82!+86YA
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8T
M"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#,*;7-G:60@(DME;GEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE
M8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R
M(")+97)N96P@3F5W8FEE<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q,0HC+"!F=7IZ>0IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S
M='(@(DIU9'5L(%1A8F5L(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+
M97D@3&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(DME
M>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(D%N86LM86YA:R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!2
M97!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO
M<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X.`IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(DMO
M<F5A("A%54,M2U(I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B
M3&%?>6]U="(*;7-G<W1R(")486UP:6QA;B(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(D)A:&%S
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T
M:6,@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(D9A<V4@=&5R86MH:7(@
M9&%R:2!397!A<G5H($)U;&%N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C<V"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R(")097)U
M8F%H86X@4V%N9&D@5&5R86MH:7(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B
M"FUS9W-T<B`B1F%S92!T97)A:VAI<B!D87)I(%-E<&%R=6@@0G5L86XB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U,0IM<V=I9"`B3&%S="!5<&1A=&5D
M.B(*;7-G<W1R(")097)U8F%H86X@5&5R86MI<CHB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L
M;V=I;CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z-S(Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN
M.B`E<R!F<F]M("5S(@IM<V=S='(@(B5S('5N='5K("5S("5S(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z-S$V"FUS9VED("),87-T(&QO9VEN.B!.
M979E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQA='9I82(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@
M(DQA=R(*;7-G<W1R(")(=6MU;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T(@IM<V=S
M='(@(E1A;7!I;&%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E
M<B(*;7-G<W1R(")4:6YG9V%L:V%N(&MO<V]N9R!T86YP82!B;W)D97(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS
M9VED("),969T(@IM<V=S='(@(DMI<FDB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3$Y"FUS9VED("),969T(&AE861E<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$U"B,L(&9U>GIY"FUS9VED
M("),969T('9A;'5E<R(*;7-G<W1R(")$869T87(@5&%B96PB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#@*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED("),979E;"(*
M;7-G<W1R(")#:6YT82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`HC+"!F=7IZ>0IM<V=I9"`B
M3&EB97)I82(*;7-G<W1R(")086YT=6X@2F5N86MA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y
M"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I
M9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R(")'97)I;6ES(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G:60@(DQI9VAT
M(%)A:6XB"FUS9W-T<B`B1V5R:6UI<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN($5A<FQY
M(@IM<V=S='(@(D=E<FEM:7,@9&D@<&%G:2!H87)I(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A
M:6X@3&%T92(*;7-G<W1R(")'97)I;6ES(&)E8F5R87!A('-A870@;&%G:2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS
M9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R(")'97)I;6ES(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@
M(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(D=E<FEM:7,@9&ES
M97)T86D@<&5T:7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R(")"97)S86QJ
M=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R
M"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R(")'97)I;6ES(%-A
M;&IU(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE
M<FEC:R(*;7-G<W1R(")086YT=6X@2F5N86MA(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@Q-`HC+"!F=7IZ>0IM<V=I9"`B3&EN:R(*;7-G<W1R
M("),;V=I;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S
M='(@(DQI;FL@;65N=6YJ=6L@:V4Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@W-0IM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T
M:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z
M,3@S"B,L(&9U>GIY"FUS9VED("),:6YK<R(*;7-G<W1R(")4=6=A<R!,;V=I
M;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@
M0V]O:VEE(@IM<V=S='(@(DQI;G5X($-O;VMI92(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E
M<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B
M1&%F=&%R($1A=&%B87-E(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z
M-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B1&%F=&%R(%1O
M<&EK($)A;G1U86XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,R"FUS9VED
M("),:7-T(%1A8FQE<R(*;7-G<W1R(")$869T87(@5&%B96PB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!
M<F-H:79E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-3@Y"B,L(&9U>GIY"FUS9VED("),:7-T+4AE;'`B"FUS9W-T
M<B`B1&%F=&%R(%1O<&EK($)A;G1U86XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I
M9"`B3&ES="U/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DQ"B,L
M(&9U>GIY"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R(")!;F=K82]H
M=7)U9B]S:6UB;VP@>6%N9R!D:71U;&ES(&1I8F%W86@@9V%R:7,@8F%R:7,@
M=&5K<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP
M"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(D1A9G1A<B!P
M96YG9W5N82!D:6YO;BUA:W1I9FMA;BXB"@HC.B!A9&UI;B]S97-S:6]N<RYP
M:'`Z,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E
M<G,@9F%I;&5D.B`E<R(*;7-G<W1R(")$869T87(@<&5N9V=U;F$@9&EN;VXM
M86MT:69K86XN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN
M8SHR"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R
M(")$869T87(@<&5N9V=U;F$@9&EN;VXM86MT:69K86XN(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@
M(D1A9G1A<B!"86-A86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*(RP@9G5Z>GD*;7-G:60@
M(DQI=&AU86YI82(*;7-G<W1R("),96)A<B!U;FET(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6UA9V5S+G!H<#HX,PIM<V=I9"`B3&]A9&EN
M9RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C$Q"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B5V%K='4@;&]C
M86PZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S"FUS9VED("),;V-A
M;&4@86YD(%1I;64B"FUS9W-T<B`B5&5M<&%T(%!E<FES=&EW82!D86X@5V%K
M='4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,2!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C0*(SH@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z-C4*;7-G:60@(DQO
M8V%T:6]N(@IM<V=S='(@(DQO:V%S:2(*"B,Z(&QO9VEN+G!H<#HQ-S(@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y,2!T96UP;&%T97,O;&]G:6XO
M;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I;B(*
M;7-G<W1R("),;V=I;B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3@U"FUS
M9VED("),;V<@;W5T(@IM<V=S='(@(DQO9R!O=70B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-3D*;7-G:60@(DQO9VEN(@IM<V=S='(@(DQO9VEN(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B3&]G:6X@5&%S
M:W,B"FUS9W-T<B`B5'5G87,@3&]G:6XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.38*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@
M=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,@HC
M+"!F=7IZ>0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R(")4:61A:R!D
M:6%R<VEP:V%N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-0HC
M+"!F=7IZ>0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(DQO9R!O=70B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS9W-T
M<B`B0VEN=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV-PIM<V=I9"`B3&]W(@IM<V=S='(@(E)E;F1A:"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*
M;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B4VEM8F]L($AU
M<G5F(&ME8VEL('EU;F%N:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN
M(&QE='1E<G,B"FUS9W-T<B`B4VEM8F]L($AU<G5F(&ME8VEL(&QA=&EN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(")3
M:6UB;VP@2'5R=68@:V5C:6P@<F]M87=I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED
M("),=7AE;6)O=7)G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#`*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0S."!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU
M,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C@Q"FUS9VED(")-3U1$(@IM<V=S='(@(DU/5$0B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B
M35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.C,W"B,L(&9U>GIY"FUS9VED(")-4T<B"FUS
M9W-T<B`B0TU3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")-86-A
M;R(*;7-G<W1R("),:6)U<F%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-86-E
M9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B
M"FUS9W-T<B`B4W5L87`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M.#$*;7-G:60@(DUA:6PB"FUS9W-T<B`B4W5R870B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-3(R"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@
M(E-U<F%T($%D;6EN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM
M<V=S='(@(D)U870@;&EN:RXN+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM
M<V=I9"`B36%L87=I(@IM<V=S='(@(E-U<F%T(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS
M9VED(")-86QA>7-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@
M(DUA;&1I=F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@HC+"!F=7IZ>0IM
M<V=I9"`B36%L:2(*;7-G<W1R(")3=7)A="(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F
M=7IZ>0IM<V=I9"`B36%L=&$B"FUS9W-T<B`B4W5R870B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3$*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O
M9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N
M9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N
M(@IM<V=S='(@(B(*(DUE;F=A='5R(&1A9G1A<B!K871E9V]R:2!Y86YG(&AA
M<G5S(&1I8F5R:2!L86)E;"!I=&5M+"!D86X@=V%R;F$@>6%N9R`B"B)B97)H
M=6)U;F=A;B`@9&5N9V%N(&MA=&5G;W)I('1E<G-E8G5T+B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,34S"FUS9VED(")-
M87`R-"!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$P.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q-C@*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G
M:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM
M<V=S='(@(DUA<F5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(DUA
M<F=I;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A
M;G0O06YS=V5R960I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B
M36%R<VAA;&P@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*(RP@
M9G5Z>GD*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R9VEN(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG
M(&9I96QD<R(*;7-G<W1R(")-96YC;V-O:VMA;B!K;VQO;2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,PHC+"!F=7IZ>0IM<V=I9"`B36%U<FET86YI82(*;7-G<W1R(")-87)G
M:6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T
M96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(@4W5H=2!M86MS:6UU;2!Y
M86YG(&)E<FQA;F=S=6YG('-E;&%M82`R-"!J86TZ(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR.3@*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@
M(@IM<V=S='(@(E-U:'4@;6%K<VEM=6T@>6%N9R!B97)L86YG<W5N9R!S96QA
M;6$@-B!J86TZ(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@
M3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B2G5M;&%H(&UA:W-I
M;75M(&1A<FD@<&]R=&%L('EA;F<@9&EB;&]K:7(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q
M-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-87AI
M;75M(&QE;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(DUE:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(DUA>6]T=&4B"FUS9W-T
M<B`B5&%M<&EL86XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G
M:60@(DUE9&EC:6YE(@IM<V=S='(@(D]B870M;V)A=&%N(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*
M;7-G<W1R(")!;F=G;W1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W
M.`IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R(")-96YU(&UO9&4Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B1V%B=6YG:V%N('-E;"(*
M"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")-97-S86=E(@IM<V=S='(@(E!E<V%N
M(%--4R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$V
M"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@
M=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I
M9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED(")-97-S86=E(&5X<&ER960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*;7-G:60@(DUE<W-A9V4@='EP
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@
M(DUE=&%R(%=E871H97(B"FUS9W-T<B`B($-U86-A($UE=&%R(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B07)E82!-971A<B!T:61A:R!D:7-E9&EA:V%N
M+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$R"FUS9VED("(B"B)-971A
M<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G
M960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")!<F5A($UE=&%R
M('1I9&%K(&1I<V5D:6%K86XN($1E=&EL('1E;&%H(&1I8V%T870@=6YT=6L@
M861M:6YI<W1R871O<BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,38U"B,L(&9U>GIY"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T
M960N(@IM<V=S='(@(E-A;F1I(&QA;6$@=&ED86L@8F5N87(N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-971H;V0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX,2!F
M<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HW-"!L:6(O0FQO8VLO;65T87(N<&AP.C<U"FUS9VED(")-971R:6,B"FUS
M9W-T<B`B365T<FEK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"B,L(&9U>GIY"FUS9VED(")-
M97AI8V\B"FUS9W-T<B`B365T<FEK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI
M8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V
M"FUS9VED(")-:61D;&4B"FUS9W-T<B`B5&5N9V%H(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,`IM<V=I
M9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(E-U:'4@;6EN
M:6UU;2!Y86YG(&)E<FQA;F=S=6YG('-E;&%M82`R-"!J86TZ(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,#(*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H
M;W5R<SH@(@IM<V=S='(@(E-U:'4@;6EN:6UU;2!Y86YG(&)E<FQA;F=S=6YG
M('-E;&%M82`V(&IA;3HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y
M970@97AP:7)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C,T"B,L(&9U>GIY"FUS9VED(")-:7)R;W(B
M"FUS9W-T<B`B2V5S86QA:&%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(DQA:6XM;&%I;B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C<R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS
M9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E
M;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L
M:6-A=&EO;BXB"FUS9W-T<B`B(@HB2V]N9FEG=7)A<VD@=&ED86L@9&ET96UU
M:V%N+B!!;F1A(&AA<G5S(&UE;F=H87-I:V%N(&MO;F9I9W5R87-I('-E:V%R
M86YG("(*(FII:V$@86YD82!I;F=I;B!M96YG9W5N86MA;B!A<&QI:V%S:2!I
M;FDN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M
M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G
M92!-86EL+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO
M;B!)1"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B4V5N(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<T"FUS9VED(")-;V)I;&4@36%I
M;"(*;7-G<W1R(")-;V)I;&4@36%I;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")-;V1E<F%T92(*;7-G<W1R
M(")3961A;F<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX.`HC+"!F
M=7IZ>0IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R(")3961A;F<B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B56)A:"!54DPB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W,PIM<V=I9"`B
M36]D=6QU<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;&1O
M=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I
M9"`B36]N86-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N
M9V]L:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C4Y-`IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B
M36]N=&AL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G
M:60@(DUO;G1S97)R870B"FUS9W-T<B`B4V5D86YG(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N
M(%!H87-E<R(*;7-G<W1R(")&87-E($)U;&%N(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z,3<R(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C(U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I
M;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO
M<W1L>2!#;&5A<B(*;7-G<W1R(")396)A9VEA;B!B97-A<B!#97)A:"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED
M(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(E-E8F%G:6%N(&)E<V%R($)E<F%W
M86XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(E-E8F%G:6%N(&)E<V%R
M($-E<F%H(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M-3`Y"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$S"B,L(&9U>GIY"FUS9VED(")-
M;W9E($QE9G0B"FUS9W-T<B`B2VER:2(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C4Q-PHC+"!F=7IZ>0IM<V=I9"`B36]V92!2:6=H
M="(*;7-G<W1R(")+86YA;B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C4P-0IM<V=I9"`B36]V92!5<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED
M(")-;W9E(&1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PHC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E('5P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@T"FUS9VED(")-=6QT
M:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-34*;7-G:60@(DUU
M;'1I;6%P(%5+(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,C0R"B,L(&9U>GIY"FUS9VED(")-=6QT:7!L92!S96QE8W1I
M;VXB"FUS9W-T<B`B2&%P=7,@<&EL:6AA;B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT,#`*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B06-C
M;W5N="UK=2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.`IM<V=I9"`B
M37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA<VD@06-C
M;W5N="UK=2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-30*;7-G
M:60@(DUY(%!O<G1A;"(*;7-G<W1R(")0;W)T86QK=2(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]E9&ET+G!H<#HQ,S8*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B
M"FUS9W-T<B`B5&%M<&EL86X@4&]R=&%L:W4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G
M:60@(DUY86YM87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!
M9W)E92(*;7-G<W1R(")4241!2RP@4V%Y82!4241!2R!3971U:G4B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B3F%M
M92(*;7-G<W1R(")N86UA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM
M<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E
M($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!#02!P
M;VQI8WD@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X,@IM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G
M:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T
M<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,`IM<V=I9"`B3F5T<V-A
M<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C4Q"FUS9VED(").971W;W)K(@IM<V=S='(@(DYE
M='=O<FLB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-0HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S@V"FUS9VED(").979E<B(*;7-G<W1R(")4:61A:R!P97)N86@B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.34*(RP@9G5Z>GD*;7-G:60@(DYE=R!#86QE9&]N:6$B
M"FUS9W-T<B`B2V%T96=O<FD@0F%R=2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T96=O
M<GDB"FUS9W-T<B`B2V%T96=O<FD@0F%R=2(*"B,Z(&9R86UE=V]R:R]497AT
M7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX,0HC.B!F<F%M97=O<FLO5&5X
M=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@9G)A;65W;W)K+U1E
M>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.CDW"B,Z(&9R86UE=V]R:R]4
M97AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G<W1R(")"
M=6QA;B!"87)U(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B
M3F%M82!096YG9W5N82!"87)U("AP:6QI:&%N*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM
M<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C,W"FUS9VED(").97<@<&%S<W=O<F0B"FUS9W-T
M<B`B4V%N9&D@0F%R=2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H
M<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@
M97AP:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z-3(*;7-G:60@(DYE=R!P87-S=V]R9',@9&]N)W0@;6%T
M8V@N(@IM<V=S='(@(E-A;F1I(&)A<G4@=&ED86L@8V]C;VLN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B
M3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R(")7:6YD;W<@0F%R=2`H7V)L
M86YK*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y
M"FUS9VED(").97=S(@IM<V=S='(@(D)E<FET82(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS,#4*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B
M1W)U<"!"97)I=&$B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ
M-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R(")"97)I:W5T;GEA(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C(W"B,L(&9U>GIY"FUS9VED(").97AT(#0@4&AA
M<V5S(@IM<V=S='(@(D9A<V4@0F5R:6MU=&YY82(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,S<R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,S<V"B,L(&9U>GIY"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T
M<B`B2V5M8F%L:2!K92!0:6QI:&%N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A
M9V5R+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(DYE>'0^(@IM<V=S='(@(D)E
M<FEK=71N>6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(DYI9V5R(@IM
M<V=S='(@(DUA;&%M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.#`*
M;7-G:60@(DYI9VAT(@IM<V=S='(@(DUA;&%M(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS
M9VED(").:75E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY-C,*(RP@9G5Z>GD*;7-G:60@(DYO(@IM<V=S
M='(@(E1I9&%K(&%D82(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F
M+FAT;6PZ.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T
M82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B(@HB5&ED86L@
M861A(&1A=&$@:V]N9FEG=7)A<VD@>6%N9R!T97)S961I82!U;G1U:R!M96YU
M;FIU:VMA;B!P97)B961A86X@=6YT=6LN(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,#4*;7-G:60@(DYO(&%V86EL86)L
M92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<Y(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(T-0HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-C<*;7-G:60@(DYO(&)L;V-K(&5X:7-T
M<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-3`*;7-G:60@(DYO(&-A;&5N
M9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED(").
M;R!C:&%N9V4N(@IM<V=S='(@(E1I9&%K(&%D82!P97)U8F%H86XN(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*(RP@9G5Z>GD*;7-G
M:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I
M;VXN(@IM<V=S='(@(EPB)7-<(B!S=61A:"!D:71A;6)A:&MA;B!K92!D86QA
M;2!I>FEN('-I<W1E;2XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$V-R!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,@HC.B!F<F%M97=O
M<FLO571I;"]5=&EL+G!H<#HW-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R-`IM
M<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R($944"!61E,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z-C8Y"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<Q-PIM<V=I9"`B3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE
M(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HX-S<*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N
M9"XB"FUS9W-T<B`B5&ED86L@861A(&EK;VX@>6%N9R!D:71E;75K86XN(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R."!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C,*;7-G
M:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B5&ED86L@861A(&QO
M:V%S:2!Y86YG(&1I871U<BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E
M9"XB"FUS9W-T<B`B5&ED86L@861A(&QO:V%S:2!Y86YG(&1I871U<BXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*
M;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I
M9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N
M97,B"FUS9W-T<B`B5&ED86L@861A(')A;6%L86X@>6%N9R!T:61A:R!S;W!A
M;B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@
M(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP
M.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO075T:"]!
M=71H+VQO9VEN+G!H<#HX-`HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP
M:'`Z-S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]P87-S=V0N<&AP.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#8*
M;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I
M9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O
M<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@
M<VEG;G5P<RXB"FUS9W-T<B`B5&ED86L@861A('!E;F1A9G1A<F%N('EA;F<@
M9&ET=6YD82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S4P"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(").;R!Q=6]T82!S970N(@IM<V=S='(@
M(D)E;'5M(&1I871U<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@
M(E1I9&%K(&%D82!A='5R86XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HT-#D*;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(E1I9&%K(&%D
M82!S:7-I(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#,*(RP@
M9G5Z>GD*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R(")4:61A:R!A9&$@
M<VES:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,S@*;7-G
M:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H
M92XB"FUS9W-T<B`B5&ED86L@861A(&1I<F5K=&]R:2!S96UE;G1A<F$@>6%N
M9R!T97)S961I82!U;G1U:R!C86-H92(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"B,L(&9U>GIY"FUS9VED(").;R!U
M<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B4VEL86MA
M;B!M87-U:VMA;B!N86UA('!E;F=G=6YA(&1A;B!S86YD:2!A;F1A(@H*(SH@
M9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A
M;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-S$*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX,0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DR"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#`Y"B,L(&9U>GIY"FUS9VED
M(").;R!V86QU97,B"FUS9W-T<B`B5&ED86L@861A(&%T=7)A;B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E<G-I;VX@9F]U
M;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("(B"B)4:61A:R!A9&$@=F5R<VD@>6%N9R!D
M:71E;75K86X@9&D@9&%L86T@:V]N9FEG=7)A<VD@>6%N9R!A<VQI+B!-96YG
M:&%S:6QK86X@(@HB:V]N9FEG=7)A<VD@:V5M8F%L:2XB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN
M('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("(B"B)4:61A:R!A9&$@=F5R<VD@>6%N9R!D:71E;75K86X@
M9&D@9&%L86T@:V]N9FEG=7)A<VD@86YD82X@365N9VAA<VEL:V%N("(*(FMO
M;F9I9W5R87-I(&ME;6)A;&DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y
M<V5L96-T+FEN8SHY,PIM<V=I9"`B3F]N92(*;7-G<W1R(")4:61A:R!A9&$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP
M"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(E1I9&%K(&%D
M82`H9&EG=6YA:V%N('-E;&5N9VMA<&YY82DB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X.0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T
M<B`B4V-A;F1I;F%V:6$@*$E33RTX.#4Y+3$P*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM
M<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R
M=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")"96QA:&%N($)U;6D@571A<F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T
M,`HC+"!F=7IZ>0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(D)E;'5M(&1I
M871U<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y
M"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C0P.`HC+"!F=7IZ>0IM<V=I9"`B3F]T(&$@9&ER
M96-T;W)Y(@IM<V=S='(@(D1I<F5K=&]R:2!(;VUE(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H
M<#HX,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+G!H<#HY-`HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV
M.`IM<V=I9"`B3F]T('-E="(*;7-G<W1R(")"96QU;2!D:6%T=7(B"@HC.B!F
M<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T
M,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N
M<&AP.C$U.`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(N<&AP.C$W,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S
M<VEO;DAA;F1L97(N<&AP.C$X-PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,3DP"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,#4@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C0X
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-C4*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,CDW"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HS,3(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,R
M.0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8R(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HT,C(*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4P,2!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z-3<P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HU.#<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V-0IM<V=I9"`B3F]T('-U
M<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`P
M-0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3<X"FUS9VED(").;W1E
M<R(*;7-G<W1R(")#871A=&%N(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD
M97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB
M"FUS9W-T<B`B5&ED86L@861A('EA;F<@9&%P870@9&EB<F]W<V4L('-I;&%K
M86X@:V5M8F%L:2XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B3F]V96UB97(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V"B,L(&9U>GIY"FUS
M9VED(").=6UB97(B"FUS9W-T<B`B3F]V96UB97(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#(U"B,L(&9U>GIY"FUS9VED(").=6UB97(@;V8@
M8VAA<F%C=&5R<R(*;7-G<W1R(")*=6UL86@@8F%R:7,B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$T,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T-2!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M
M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B2G5M;&%H(&MO;&]M(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@
M(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(DIU;6QA:"!B87)I<R(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS
M9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I
M<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@
M(D]+(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@W,PHC+"!F=7IZ>0IM<V=I9"`B3V)J96-T(@IM<V=S='(@(E!E;F-I<'1A
M($]B:F5K(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G
M:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(E!E;F-I<'1A($]B:F5K(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$P-`HC+"!F=7IZ>0IM<V=I
M9"`B3V-T86PB"FUS9W-T<B`B5&5N86YG(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T
M<B`B3VMT;V)E<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I
M9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B1FEL=&5R(%!E;&%N9V=A<F%N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R-@IM<V=I9"`B3V9F
M:6-E(@IM<V=S='(@(DMA;G1O<B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@
M8F4@9&EF9F5R96YT+B(*;7-G<W1R(")386YD:2!L86UA(&1A;B!B87)U(&AA
M<G5S(&)E<F)E9&$N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C,V"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B4V%N9&D@;&%M82(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD
M('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R(")386YD:2!L86UA
M('1I9&%K(&)E;F%R+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@
M9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(")(
M86YY82!R86UA;&%N('EA;F<@=&ED86L@<V]P86XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y
M-S$*(RP@9G5Z>GD*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL
M;W=E9"XB"FUS9W-T<B`B4&5N9V=A;G1I(&%L86UA="!E;6%I;"(*"B,Z('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@
M;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE
M<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS
M9W-T<B`B(@HB2&%N>6$@<&5M:6QI:R!A=&%U('-I<W1E;2!A9&UI;FES=')A
M=&]R('-A:F$@>6%N9R!D87!A="!M96YG=6)A:"!K97!E;6EL:6MA;B`B"B)A
M=&%U('!E;6EL:6L@:7II;B!U;G1U:R!B86=I86XB"@HC.B!L:6(O0FQO8VLO
M:69R86UE+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS
M9W-T<B`B0G5K82!D:2!J96YD96QA('EA;F<@8F%R=2(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R
M<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-
M12!P87)T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@
M;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B0G5K82!L:6YK(&EN:2!D
M:2!J96YD96QA('EA;F<@8F%R=2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R(")3:7-T96T@
M3W!E<F%S:2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*
M;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B4&EL:6AA;B(*"B,Z('-E<G9I8V5S
M+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R(")0:6QI
M:&%N('5N='5K("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(D1A
M9G1A<B!.;VUO<B!"97)U<G5T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-C<*(RP@9G5Z>GD*;7-G:60@(D]R9V%N:7-A=&EO;B(*
M;7-G<W1R(")4<F%N<VQA<VDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,R"FUS9VED
M(")/<F=A;FEZ:6YG(@IM<V=S='(@(DUE;F=A='5R(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E
M;7!L871E(@IM<V=S='(@(D%P;&EK87-I('1E;7!L871E(&%S;&DB"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/
M<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(E1E;7!L871E(&%S
M;&D@9&D@9&%L86T@)7,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R
M(@IM<V=S='(@(DQA:6XM;&%I;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-#$*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R
M;6%S:2!,86EN(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM
M<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B27II;B!096UI;&EK
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y"B,L(&9U>GIY
M"FUS9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B07)E82!K92!W96%T:&5R+F-O;2!T:61A:R!D:7-E9&EA:V%N
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP
M.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R-S,*;7-G:60@(E!'
M4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S$Y"FUS9VED(")01U`@16YC<GEP=&5D
M($1A=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3,W,0IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U,PIM<V=I9"`B
M4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]P:'!S:&5L;"YP:'`Z-C@*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(DMO
M9&4@4$A0(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@
M4VAE;&PB"FUS9W-T<B`B4$A0(%-H96QL(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A:6XB
M"FUS9W-T<B`B4$T@1V5R:6UI<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@
M(E!-($=E<FEM:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS.0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R(")032!"97)S86QJ
M=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P
M"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B4$T@1V5R:6UI<R!3
M86QJ=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0Q"FUS9VED(")032!3=6XB"FUS9W-T<B`B4$T@0V5R86@B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@
M5"U3=&]R;7,B"FUS9W-T<B`B4$T@2'5J86X@<&5T:7(@9&ES97)T86D@9&5N
M9V%N(&%N9VEN(')I8G5T(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W
M-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B
M16MS=&5N<VD@4$]325@@=&ED86L@9&ET96UU:V%N(@H*(SH@;&EB+V%P:2YP
M:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(E!(4"!3:&5L;"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B2F%R86L@<W!A<VD@9&%R
M:2!B;W)D97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(E!A:VES
M=&%N(@IM<V=S='(@(E-A;&EN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L
M874B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI
M86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3@*(RP@9G5Z>GD*;7-G:60@(E!A;F%M82(*;7-G<W1R(")N86UA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED
M(")087)T;'D@0VQO=61Y(@IM<V=S='(@(E-E8F%G:6%N($)E<F%W86XB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS
M9VED(")087-S=V]R9"(*;7-G<W1R(")386YD:2(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S
M=6-C97-S9G5L;'DN(@IM<V=S='(@(E-A;F1I(&)E<FAA<VEL(&1I=6)A:"XB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S,C(*(RP@
M9G5Z>GD*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R(")386YD
M:2!L86UA('1I9&%K(&)E;F%R+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2
M041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P-3,*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D
M('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(DME=&EK('-A;F1I(&1U82!K
M86QI('5N='5K(&UE;F=K;VYF:7)M87-I(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.CDP"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`B4V%N
M9&DZ(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@
M(E!A<W-W;W)D.B`B"FUS9W-T<B`B4V%N9&DZ(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S0*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S
M(&UU<W0@;6%T8V@N(@IM<V=S='(@(E-A;F1I(&AA<G5S(&-O8V]K+B(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G
M<W1R(")386QI;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S
M='(@(DQE:V%T:V%N(&1A<FD@8VQI<&)O87)D(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G
M<W1R(")0871H(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C<*
M;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B4&5N9&%F=&%R86X@
M>6%N9R!D:71U;F1A.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM
M<V=I9"`B4&5O<&QE(@IM<V=S='(@(D]R86YG(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B
M"FUS9W-T<B`B4&5R<V5N(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA
M:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<R(*;7-G<W1R(")-96QA:W-A;F%K86X@3W!E<F%S:2!096UE
M;&EH87)A86XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`V"FUS9VED
M(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM
M<V=S='(@(DUE;&%K<V%N86MA;B!O<&5R87-I('!E;65L:6AA<F%A;B!P861A
M('=A:W1U(&QO9VEN/R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,34V"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(DEZ
M:6XB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M
M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G
M<W1R("))>FEN('5N='5K(%PB)7-<(B!T:61A:R!D87!A="!D:6AA<'5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@V"B,L(&9U>GIY"FUS
M9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("))>FEN(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C$@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VYS
M(@IM<V=S='(@(DEZ:6XB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#D@
M861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN+W!E<FUS+VEN
M9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"FUS9VED(")0
M97)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R("))>FEN($%D;6EN
M:7-T<F%S:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-0IM<V=I9"`B
M4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M87-I(%!R:6)A
M9&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@
M(D)I;F%T86YG($ME<V%Y86YG86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H
M:6QI<'!I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.38*(RP@9G5Z>GD*;7-G:60@(E!H;VYE(@IM
M<V=S='(@(E1I9&%K(&%D82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-S@*;7-G:60@(E!H;W1O<R(*;7-G<W1R(")&;W1O(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L
M<R(*;7-G<W1R(")0:7AE;"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R(")+871A+6MA=&$@:VQI<V4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS
M9W-T<B`B4VEL86MA;B!K;&EK(&ME(&1A;&%M(&)E8F5R87!A('-E;"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R(")3:6QA:V%N(&MO;F9I<FUA
M<VD@8F%H=V$@86YD82!I;F=I;B!M96UI;F1A:&MA;B!E;&5M96X@:6YI.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R(")3:6QA:V%N(&MO;F9I
M<FUA<VD@8F%H=V$@86YD82!I;F=I;B!M96YG:&%P=7,@;&EN:R!U;G1U:R!E
M;&5M96X@:6YI+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U-S$*
M(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE
M87(N(@IM<V=S='(@(E-I;&%K86X@;6%S=6MK86X@;F%M82!U;G1U:R!K871E
M9V]R:2!Y86YG(&)A<G4Z(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@
M9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(E-I;&%K86X@;6%S=6MK
M86X@;F%M82!U;G1U:R!K871E9V]R:2!Y86YG(&)A<G4Z(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,P,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C8V,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@
M9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,0IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE
M87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R
M(")3:6QA:V%N(&UA<W5K:V%N(')I;F=K87-A;B!U;G1U:R!M87-A;&%H+B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U
M<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B4VEL86MA;B!M87-U:VMA
M;B!N86UA('!E;F=G=6YA(&1A;B!S86YD:2!A;F1A(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@
M9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS
M('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"B)3:6QA:V%N(&UE
M;6)A8V$@=&5K<R!B97)I:W5T(&EN:2X@06YD82!(05)54R!S971U:G4@9&5N
M9V%N('-Y87)A="US>6%R870@(@HB=6YT=6L@;65N9V=U;F%K86X@<VES=&5M
M+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C<P"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A
M=&5G;W)Y(&YA;64Z(@IM<V=S='(@(E-I;&%K86X@;6%S=6MK86X@;F%M82!U
M;G1U:R!K871E9V]R:2!Y86YG(&)A<G4Z(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"B,L(&9U
M>GIY"FUS9VED(")0;VQA;F0B"FUS9W-T<B`B0V]M;6%N9"(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B
M4&]L:71I:R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#<*;7-G
M:60@(E!O;&QS(@IM<V=S='(@(E!O;&QI;F<B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"B,L
M(&9U>GIY"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R(")0;W)T86QK=2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G
M<W1R(")0;W-I<VD@=6YT=6L@9V%M8F%R(&EN:2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO
M;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(E!O<VES:2!U;G1U:R!T86)E
M;"!I;FDB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D
M(&)Y($E-05`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C8V(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S
M='(@(DAU:F%N('-A;&IU('5N='5K("5S(&IA;2!T97)A:VAI<CHB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDX"FUS9VED(")0<F5C:7!I
M=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(DME;75N9VMI;F%N(#QB<B\^
M2'5J86X@<V%L:G4B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP
M:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!2
M97%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(U"FUS9VED(")0<F5S<W5R
M92(*;7-G<W1R(")496MA;F%N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-3D*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@(E1E
M:V%N86X@<&%D82!P97)M=6MA86X@;&%U=#HB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@
M(E1E:V%N86XZ(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(P-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`B
M3&EH870B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM86=E(&EN
M(&$@;F5W('=I;F1O=R(*;7-G<W1R("),:6AA="!G86UB87(@9&D@9&%L86T@
M:F5N9&5L82!Y86YG(&)A<G4B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C,V,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V-@HC
M+"!F=7IZ>0IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")+96UB
M86QI(&ME(%!I;&EH86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R
M(")#971A:R!D;VMU;65N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#(S"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y"B,L(&9U>GIY"FUS
M9VED(")0<F]B;&5M(@IM<V=S='(@(D]R86YG(@H*(SH@<V5R=FEC97,O<')O
M8FQE;2YP:'`Z,3(V"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S
M='(@(D1E<VMR:7!S:2!-87-A;&%H(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,V.0IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B4')O:F5K(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,3@X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M.#4*(RP@9G5Z>GD*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(D1A<FDB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@
M(E!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C0T"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L
M:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@4FEC
M;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"B,L(&9U>GIY"FUS9VED(")1
M871A<B(*;7-G<W1R(")+=6]T82(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV
M,PIM<V=I9"`B475E<GDB"FUS9W-T<B`B475E<GDB"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S='(@(DMU;W1A(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-`HC+"!F=7IZ
M>0IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(E-A;&EN(%!I;&EH
M86XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M,PIM<V=I9"`B4F%I;B(*;7-G<W1R(")(=6IA;B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN($5A<FQY
M(@IM<V=S='(@(DAU:F%N(&1I('!A9VD@:&%R:2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN($QA=&4B
M"FUS9W-T<B`B2'5J86X@8F5B97)A<&$@<V%A="!L86=I(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@
M4VAO=V5R(@IM<V=S='(@(D=E<FEM:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I9"`B4F%I;B!A;F0@4VYO=R(*
M;7-G<W1R(")(=6IA;B!D86X@0F5R<V%L:G4B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!T;R!3;F]W
M(@IM<V=S='(@(DAU:F%N(&)E<F-A;7!U<B!D96YG86X@<V%L:G4B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B
M"FUS9W-T<B`B4F%M86QA;B!!8V%K(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<V"B,L(&9U>GIY"FUS9VED(")2871I;R(*;7-G<W1R(")(
M=6IA;B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(T('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P
M"FUS9VED(")296%D(@IM<V=S='(@(D)A8V$B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PIM<V=I9"`B4F5A9"!M97-S86=E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N
M:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@
M5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B66%K
M:6X@=6YT=6L@;65N9VAA<'5S("5S/R!/<&5R87-I(&EN:2!T:61A:R!D87!A
M="!D:6)A=&%L:V%N+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R
M+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E
M<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+B(*;7-G<W1R("(B"B)986MI;B!U;G1U:R!M96UI;F1A:&MA;B!D
M871A('!E;F=G=6YA('5N='5K('!E;F=G=6YA("5S/R!/<&5R87-I(&EN:2!T
M:61A:R`B"B)D87!A="!D:6)A=&%L:V%N+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R
M(&QA<W0@86-T:6]N(@IM<V=S='(@(E5L86YG:2!A:W-I('1E<F%K:&ER(&%N
M9&$B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")2969R97-H($1Y;F%M
M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B4F5F<F5S:"!%;&5M96X@365N
M=2!$:6YA;6ES.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$*;7-G
M:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(E)E9G)E<V@@3&EH
M870@4&]R=&%L.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-"!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$S"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R,S4*(RP@9G5Z>GD*;7-G:60@(E)E9V5X(@IM<V=S='(@
M(D%T=7(@:V5M8F%L:2`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,C0Y"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C`X"B,L(&9U>GIY"FUS9VED(")296QO860B"FUS
M9W-T<B`B0F%C82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V"FUS9VED
M(")296UA<FMS(@IM<V=S='(@(D1I=&%N9&%I(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Q-`IM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B
M4F5M;W1E(%-E<G9E<B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O
M;2]H;W)D92DZ(@IM<V=S='(@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA
M;7!L92YC;VTO:&]R9&4I(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR
M.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S
M"FUS9VED(")296UO=F4B"FUS9W-T<B`B4&EN9&%H:V%N(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@0FQO8VLB
M"FUS9W-T<B`B4&EN9&%H:V%N($)L;VMI<B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HU-3<*(RP@9G5Z>GD*;7-G:60@(E)E
M;6]V92!C;VQU;6XB"FUS9W-T<B`B2&%P=7,@:V]L;VTB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0P"FUS9VED(")296UO
M=F4@9F]R;6%T=&EN9R(*;7-G<W1R(")0:6YD86AK86X@0V%R82!&;W)M870B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M
M;W9E('!A:7(B"FUS9W-T<B`B4&EN9&%H:V%N('!A<V%N9V%N(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D('-C
M<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S
M='(@(E!I;F1A:&MA;B!S8W)I<'0@>6%N9R!S=61A:"!D:7-I;7!A;B!D87)I
M(&1I<F5K=&]R:2!S97)V97(@<V5M96YT87)A+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B
M4F5M;W9E('1H92(*;7-G<W1R(")0:6YD86AK86XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@
M(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B
M4&EN9&%H:V%N(&YO9&4@:6YI(&1A<FD@9&]K=6UE;B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U<V5R
M(@IM<V=S='(@(E!I;F1A:&MA;B!P96YG9W5N82(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M96UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B4&EN9&%H:V%N('!E;F=G=6YA.B`E
M<R(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED
M(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O
M<F-O9&4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,34W"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@
M8F4@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3<T(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$R"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P
M96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")4:61A:R!D
M87!A="!M96YY:6UP86X@:V]N9FEG=7)A<VD@)7,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HV-S4@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R,PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO
M="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E1I
M9&%K(&1A<&%T(&UE;GEI;7!A;B!K;VYF:6=U<F%S:2`E<RXB"@HC.B!F<F%M
M97=O<FLO571I;"]5=&EL+G!H<#HW.#$*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(E1I9&%K(&1A<&%T(&UE;GEI;7!A;B!K;VYF
M:6=U<F%S:2`E<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R
M+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S
M.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C`@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R(")!
M='5R(&ME;6)A;&D@(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-#8*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(D%T=7(@:V5M8F%L
M:2!386YD:2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS
M9VED(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(D%T=7(@:V5M8F%L
M:2!386YD:2!!;F1A(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,`HC+"!F
M=7IZ>0IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(D9A<V4@
M=&5R86MH:7(@9&%R:2!397!A<G5H($)U;&%N(@H*(SH@861M:6XO<&AP<VAE
M;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L
M;"YP:'`Z-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B2&%S:6PB"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F
M<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@
M(DME;6)A;&D@:V4@4&EL:6AA;B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R
M(")+971I:R!U;&%N9R!S86YD:2!B87)U(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@HC+"!F
M=7IZ>0IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R(")*86QA;FMA;B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B2V5M
M8F%L:2!K92!+;VYF:6=U<F%S:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,S(*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R
M(")0:6QI:&%N($5D:71O<B!2:6-H(%1E>'0B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B5&5K82UT96MI
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R(")+86YA;B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C$*;7-G:60@(E)I9VAT(&AE861E<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$W"B,L
M(&9U>GIY"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`B1&%F=&%R(%1A
M8F5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T
M<B`B4')O<&5R=&D@0F%R:7,N+BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,C,T"B,L(&9U>GIY"FUS9VED(")2;VQE(@IM
M<V=S='(@(D%T=7)A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(R-0IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(R"FUS9VED
M(")2;W1A=&4@3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(X"FUS9VED(")2;W1A=&4@4FEG:'0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T
M<B`B4')O<&5R=&D@0F%R:7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE
M<R(*;7-G<W1R(")0<F]P97)T:2!B87)I<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G
M<W1R(")"87)I<SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R(")!='5R
M86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L
M;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(D%T=7)A;B!A:V%N(&1I=&%M
M<&EL:V%N(&1I86YT87)A('-E;75A(&)A<FES(&1A;B!K;VQO;2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*
M;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY
M(@IM<V=S='(@(D%T=7)A;B!A:V%N(&1I=&%M<&EL:V%N(&AA;GEA(&1I86YT
M87)A(&MO;&]M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B071U<F%N(&%K86X@9&ET86UP:6QK
M86X@:&%N>6$@9&EA;G1A<F$@8F%R:7,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3(P"FUS9VED(")2=6XB"FUS9W-T<B`B2F%L86YK86XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I9"`B4G=A;F1A(@IM<V=S='(@
M(D)A8V$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X
M-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S
M"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0HC+"!F=7IZ>0IM
M<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R(")!<F5A(&ME('=E871H97(N8V]M('1I9&%K(&1I<V5D:6%K86XN
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P-`IM<V=I9"`B4TU3
M($UE<W-A9VEN9R(*;7-G<W1R(")097-A;B!335,B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R(")344P@4VAE
M;&PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@S"FUS9VED(")3
M44P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S$*;7-G:60@(E-32"(*;7-G
M<W1R(")34T@B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM
M<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L
M;"(*;7-G<W1R(")37U%,(%-H96QL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B4V)T
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PHC+"!F=7IZ>0IM<V=I9"`B4V%I
M;G0@3'5C:6$B"FUS9W-T<B`B2'5J86X@8F5B97)A<&$@<V%A="!L86=I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC
M96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE
M(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B1G)A;64@>6%N9R!S86UA("A?<V5L
M9BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$W"B,L(&9U>GIY"FUS9VED(")386UO82(*;7-G
M<W1R(")3<&%M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ>0IM<V=I9"`B4V%N
M($UA<FEN;R(*;7-G<W1R(")-87)G:6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED
M(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R
M;W9I9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I
M($%R86)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U
M="YI;F,Z.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`B4VEM<&%N(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B4VEM<&%N("5S
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R(")3:6UP86X@)7,B"@HC.B!T
M96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B
M"FUS9W-T<B`B4VEM<&%N(%!I;&EH86XB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,38W"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R
M>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*(E-I;7!A;B!K;VYF:6=U<F%S
M:2!Y86YG(&1I:&%S:6QK86X@<V5B86=A:2!S8W)I<'0@4$A0(&ME(&1A;&%M
M(&1I<F5K=&]R:2`B"B)S97)V97(@<V5M96YT87)A(&%N9&$N(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2V]N9FEG=7)A<VD@
M)7,@<W5D86@@9&ES:6UP86XN(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P
M('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(E-C<FEP="!S
M971U<"!U<&=R861E('-U9&%H(&1I<VEM<&%N(&ME.B`G)7,G+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")3
M8V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B4V5B86=I86X@2'5J86X@<&5T
M:7(@9&ES97)T86D@86YG:6X@<FEB=70B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B26QM=2!096YG971A
M:'5A;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B
M"FUS9W-T<B`B4&5N8V%R:6%N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,R,`IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B365S:6X@
M4&5N8V%R:6%N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW,PIM
M<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B4&EL:6@@<V5R=F5R(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R
M;W5P('1O(&%D9"(*;7-G<W1R(")0:6QI:"!G<G5P('5N='5K(&1I=&%M8F%H
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L
M96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(E!I;&EH('!E;6EL:6L@8F%R=2(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L
M96-T(&$@<V5R=F5R(@IM<V=S='(@(E!I;&EH('-E<G9E<B(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R
M('1O(&%D9"(*;7-G<W1R(")0:6QI:"!P96YG9W5N82!U;G1U:R!D:71A;6)A
M:"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV
M-S<*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B2&%P=7,@
M<V5L(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,PHC+"!F=7IZ
M>0IM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@
M(E!I;&EH(&9O<FUA="!T86YG9V%L.B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX-S,*(RP@9G5Z>GD*;7-G:60@(E-E;&5C
M="!A;B!O8FIE8W0B"FUS9W-T<B`B4&EL:6@@<&5M:6QI:R!B87)U(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.`HC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B4&EL:6@@<&5M:6QI
M:R!B87)U(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B
M"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X
M97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M
M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@HB4&EL:6@@:V%R86MT
M97(@>6%N9R!A;F1A('!E<FQU:V%N(&1A<FD@:V]T86LM:V]T86L@9&EB87=A
M:"!I;FDN($%N9&$@9&%P870@(@HB;65N>6%L:6X@9&%N(&UE;&5K871K86YN
M>6$@:V4@9&%L86T@87)E82!T96MS+B(*"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*
M;7-G<W1R(")0:6QI:"!B871A<R!T86YG9V%L.B(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T
M.B(*;7-G<W1R(")0:6QI:"!F;W)M870@=&%N9V=A;#HB"@HC.B!T96UP;&%T
M97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")396QE8W0@
M=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`B4&EL
M:6@@:61E;G1I=&%S('EA;F<@:6YG:6X@9&EU8F%H(&]L96@@86YD83HB"@HC
M.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H
M92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B4&EL:6@@8F%T87,@=V%K='4Z
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C
M="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(E!I;&EH(&9O<FUA="!W86MT
M=3HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")3
M96QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B4&EL:6@@9'5A
M(&MO;&]M('EA;F<@8V]C;VLN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,P-@IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R
M(")0:6QI:"!W87)N82!S8VAE;64@86YD82XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C0X"FUS9VED(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N
M9W5A9V4Z(@IM<V=S='(@(E!I;&EH(&)A:&%S82!Y86YG(&%N9&$@:6YG:6YK
M86XZ(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G
M:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B2VER:6T@3&%P;W)A
M;B!-87-A;&%H(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$P,SD*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS,38*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@(E-E
M;G-O<CHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(E-E<'1E;6)E<B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")3
M97)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*(RP@9G5Z>GD*;7-G:60@(E-E
M<FEA;"!.=6UB97(B"FUS9W-T<B`B06YG:V$@1&5S:6UA;"(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*(RP@9G5Z>GD*;7-G:60@(E-E
M<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D%R
M96$@365T87(@=&ED86L@9&ES961I86MA;BXB"@HC.B!A9&UI;B]S97-S:6]N
M<RYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T
M<B`B27II;B!!9&UI;FES=')A<VDB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@
M97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30U"B,L(&9U
M>GIY"FUS9VED(")397-S:6]N<R(*;7-G<W1R("))>FEN(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-`HC+"!F=7IZ>0IM<V=I9"`B4V5T(@IM
M<V=S='(@(E-E='5P(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V"FUS
M9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P
M87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*(D%T
M=7(@<&EL:6AA;B!U;G1U:R!M96YG:7II;FMA;B!A;F1A(&1A<&%T(&UE;F=A
M='5R('5L86YG(&ME;6)A;&D@<V%N9&D@86YD82`B"B)A<&%B:6QA(&%N9&$@
M;'5P82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(")3
M970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@
M9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B071U<B!R96UO=&4@<V5R=F5R
M('EA;F<@:6YG:6X@86YD82!A:W-E<R!D87)I('!O<G1A;"!A;F1A+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`IM<V=I9"`B4V5T('EO=7(@<')E
M9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*
M;7-G<W1R(")!='5R(&)A:&%S82P@>F]N82!W86MT=2!D86X@<&EL:6AA;B!T
M86YG9V%L+"!Y86YG(&%N9&$@:6YG:6YK86XN(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDX"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI
M8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T
M:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HB071U<B!A<&QI
M:V%S:2!A=V%L(&%N9&$L('=A<FYA('-C:&5M92P@:&%L86UA;B!R969R97-H
M(&1A;B!P:6QI:&%N('1A;7!I;&%N("(*(FQA:6YN>6$N(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HW-0IM<V=I9"`B4V5T=7`B"FUS9W-T<B`B4V5T
M=7`B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM
M<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R
M(")38W)I<'0@<V5T=7`@=7!G<F%D92!T97)S961I82(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ.#8*;7-G:60@(E-E=F5R86P@;&]C871I
M;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(D)E
M8F5R87!A(&QO:V%S:2!Y86YG(&UU;F=K:6X@9&5N9V%N('!A<F%M971E<CHB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.38*;7-G:60@(E-H;W!P
M:6YG(@IM<V=S='(@(D)E;&%N:F$B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHT,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R(")2
M:6YG:V%S86X@4&5N9&5K(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T
M-@IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO
M<W0@;&EN:W,_(@IM<V=S='(@(E!E<FQU:V%H(&MU;F-I(&%K<V5S(&1I9&5F
M:6YI<VEK86X@=6YT=6L@:V5B86YY86MA;B!L:6YK/R(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S
M='(@(E1A;7!I;&MA;B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*
M;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@
M<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B(@HB5&%M<&EL:V%N('!E<F)E9&%A;B!D:6%N=&%R82!K
M;VYF:6=U<F%S:2!Y86YG(&)A<G4@9&ES:6UP86X@9&%N('EA;F<@8F%R=2`B
M"B)D:6AA<VEL:V%N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3`*
M;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B
M"FUS9W-T<B`B5&%M<&EL:V%N('=A:W1U(&QO9VEN('1E<F%K:&ER(&ME=&EK
M82!A;F1A(&QO9VEN/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W
M-C4*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,PHC+"!F=7IZ
M>0IM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B1V5R:6UI<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C8*;7-G:60@(E-H;W<@=&%B;&4@;W!E
M<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B5&%M<&EL:V%N('!A;F5L(&UE
M;G4@=&%B96P@;W!E<F%S:3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0Y"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@
M=&AE(&QE9G0_(@IM<V=S='(@(E1A;7!I;&MA;B!-96YU("5S(&1I('-E8F5L
M86@@:VER:3\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@
M4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B5&%M<&EL:V%N(&1I86QO9R!0
M<F]P97)T:2!396P@5&%B96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A
M8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(E1A;7!I;&MA;B!D:6%L
M;V<@4')O<&5R=&D@5&%B96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A
M8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")486UP:6QK86X@
M9&EA;&]G(%!R;W!E<G1I($)A<FES(%1A8F5L(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3
M:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")486UP
M:6QK86X@9&EA;&]G('!R;W!E<G1I(&=A;6)A<B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$W-C,*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P
M"FUS9VED(")3:&]W97)S(@IM<V=S='(@(D=E<FEM:7,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B4VAO=V5R
M<R!%87)L>2(*;7-G<W1R(")'97)I;6ES(&1I('!A9VD@:&%R:2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3
M:&]W97)S($QA=&4B"FUS9W-T<B`B1V5R:6UI<R!B96)E<F%P82!S86%T(&QA
M9VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M,PIM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B1V5R
M:6UI<R!D:2!S96MI=&%R(&1A97)A:"(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C0X,`IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<W-"!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HX,S8*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3(R(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.CDX-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HQ,#0W(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C$P.#<*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M,3$Q-B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,30Y"FUS
M9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T
M(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM
M<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HR-C4*;7-G:60@(E-I9VX@=7`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*
M(RP@9G5Z>GD*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R(")$869T87(@0F%C
M86%N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3$*
M;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$U(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(T-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,P"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*;7-G:60@(E-I>F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B3&5W871I(%!E
M;65L:6AA<F%A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4T"FUS9VED(")3;F]W(@IM<V=S='(@(E-A;&IU(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<@4VAO
M=V5R(@IM<V=S='(@(D=E<FEM:7,@4V%L:G4B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S
M(@IM<V=S='(@(D=E<FEM:7,@4V%L:G4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W97)S($5A
M<FQY(@IM<V=S='(@(D=E<FEM:7,@4V%L:G4@9&D@<&%G:2!H87)I(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@
M(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(D=E<FEM:7,@4V%L:G4@8F5B
M97)A<&$@<V%A="!L86=I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*
M;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R(")+961A;&%M86X@4V%L:G4Z
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U
M:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@(E!E<F)A;F1I;F=A;B!S86QJ
M=2!D:2`H9&%L86TI(&%I<CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3;VQO
M;6]N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B
M4V]M86QI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B3&%G=2`F(%-A:F%K
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR-@HC+"!F=7IZ>0IM
M<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B2&%P=7,@<&EL
M:6AA;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ.#D*(RP@9G5Z>GD*;7-G:60@(E-O=7)C92!A9&1R97-S
M(@IM<V=S='(@(D%L86UA="!%;6%I;"!!;F1A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM
M<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM
M,RDB"FUS9W-T<B`B17)O<&$@4V5L871A;B`H25-/+3@X-3DM,RDB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!3
M86YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N
M($AE;6ES<&AE<F4B"FUS9W-T<B`B0F5L86AA;B!"=6UI(%-E;&%T86XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM
M<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R(")*
M87)A:R!A;G1A<F$@<V5L('EA;F<@8F5R9&5K871A;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C
M92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@
M(DIA<F%K(&%N=&%R82!I<VD@9&%N(&)O<F1E<B!D:2!D86QA;2!S96PB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,34*(RP@9G5Z>GD*;7-G:60@
M(E-P86-E<B(*;7-G<W1R(")*87)A:R!S<&%S:2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A
M8VEN9R(*;7-G<W1R(")*87)A:R!S<&%S:2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I
M;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B2F%R86L@<W!A<VD@9&%N(&IA<F%K
M('-P87-I(&1A<FD@8F]R9&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*(RP@9G5Z>GD*;7-G
M:60@(E-P86EN(@IM<V=S='(@(DIA<F%K('-P87-I(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.CDX"FUS9VED(")3<&%M(@IM<V=S='(@(E-P86TB
M"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@
M0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(DUA<W5K:V%N($MA<F%K=&5R(%-P
M97-I86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@(E!I<V%H
M:V%N(%-E;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R(")0
M:7-A:&MA;B!K;VQO;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R
M(")0:7-A:&MA;B!B87)I<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV
M,0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(D]L86AR86=A(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C<S(&QI8B]";&]C:R]M971A<BYP:'`Z-S0*
M;7-G:60@(E-T86YD87)D(@IM<V=S='(@(E-T86YD87(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R(")0
M97)J86QA;F%N($)I;G1A;F<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#D*(RP@9G5Z>GD*
M;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B4&5R:F%L86YA;B!":6YT86YG
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G
M:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS
M9W-T<B`B4W1A='5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q
M-0HC+"!F=7IZ>0IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B1F]R
M;6%T(%=A:W1U(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-S(*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@
M(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B06YG:V$O:'5R=68O<VEM8F]L('EA
M;F<@9&EB97)I('1A;F1A(&=A<FES(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,PIM<V=I9"`B4W1R:7`@9&]M
M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B
M4W1Y;&4@6T-34UTB"FUS9W-T<B`B1V%Y82!;0U-372(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM
M<V=S='(@(DUI;B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N
M;W0@9F]U;F0N(@IM<V=S='(@(E-U8F1I<F5K=&]R:2`G)7,G('1I9&%K(&1I
M=&5M=6MA;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")3=6)J96-T(@IM<V=S='(@(D%N
M9VMA+VAU<G5F+W-I;6)O;"!Y86YG(&1I='5L:7,@9&EB87=A:"!G87)I<R!B
M87)I<R!T96MS(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R(&9R
M86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PHC+"!F=7IZ>0IM
M<V=I9"`B4W5B;6ET(@IM<V=S='(@(D%N9VMA+VAU<G5F+W-I;6)O;"!Y86YG
M(&1I='5L:7,@9&EB87=A:"!G87)I<R!B87)I<R!T96MS(@H*(SH@<VEG;G5P
M+G!H<#HT.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET
M=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@
M8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N
M(&%P<')O=F5D+B(*;7-G<W1R("(B"B(@4&5R;6EN=&%A;B!Y86YG(&1I<V%M
M<&%I:V%N('5N='5K(&UE;F%M8F%H:V%N("<E(',G(&ME(&1A;&%M('-I<W1E
M;2X@06YD82`B"B)T:61A:R!D87!A="!L;V<@:6X@<V%M<&%I('!E<FUI;G1A
M86X@86YD82!T96QA:"!D:7-E='5J=6DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM
M<V=S='(@(D%N9VMA+VAU<G5F+W-I;6)O;"!Y86YG(&1I='5L:7,@9&EB87=A
M:"!G87)I<R!B87)I<R!T96MS(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P
M-`HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@(D)E
M<FAA<VEL(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R!S=61A:"!B97)H87-I;"!D:71A;6)A
M:&MA;B!K92!D86QA;2!S:7-T96TN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE
M87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM
M<V=S='(@(D1A=&$@=6YT=6L@<&5N9V=U;F$@)R5S)R!S=61A:"!B97)H87-I
M;"!D:6)E<G-I:&MA;B!D87)I('-I<W1E;2XB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R
M(")<(B5S7")S=61A:"!B97)H87-I;"!D:6AA<'5S+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$P-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T
M<B`B)R5S('-U9&%H(&)E<FAA<VEL(&1I<&EN9&%H:V%N(&1A<FD@<VES=&5M
M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E
M<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E
M(&-H86YG97,N(@IM<V=S='(@(B(*(DMO;F9I9W5R87-I('-U9&%H(&)E<FAA
M<VEL(&1I:V5M8F%L:6MA;BX@56QA;F=I('5N='5K(&UE;&EH870@<&5R=6)A
M:&%N+B`B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B
M86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B0F%C:W5P(&MO;F9I9W5R
M87-I('-U9&%H(&)E<FAA<VEL(&1I<VEM<&%N+B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*
M;7-G<W1R(")&:6QE($)A8VMU<"!+;VYF:6=U<F%S:2`E<R!S=61A:"!B97)H
M87-I;"!D:7-I;7!A;BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB
M)7-<(B(*;7-G<W1R("(G)7,G('-U9&%H(&)E<FAA<VEL(&1I<&5R8F%H87)U
M:2(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!W<F]T92`E<R(*;7-G<W1R("(G)7,G('-U9&%H(&)E<FAA<VEL(&1I='5L
M:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`T"B,L(&9U>GIY"FUS9VED(")3=61A;B(*;7-G
M<W1R(")#97)A:"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B4FEN
M9VMA<V%N(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3
M=6X@4FES92(*;7-G<W1R(")-871A:&%R:2!497)B:70B"@HC.B!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B36%T
M86AA<FD@5&5R8F5N86TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU.0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B0V5R86@B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")3=6YR
M:7-E(@IM<V=S='(@(DUA=&%H87)I(%1E<F)I="(*"B,Z(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B
M4W5N<FES92]3=6YS970B"FUS9W-T<B`B36%T86AA<FD@5&5R8FET+TUA=&%H
M87)I(%1E<F)E;F%M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Q-0IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(DUA=&%H87)I(%1E<F)I
M=#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Y"FUS9VED
M(")3=6YS970B"FUS9W-T<B`B36%T86AA<FD@5&5R8F5N86TB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$X"FUS9VED(")3=6YS970Z("(*
M;7-G<W1R(")-871A:&%R:2!497)B96YA;3HB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP
M="(*;7-G<W1R(")!;F=K82]H=7)U9B]S:6UB;VP@>6%N9R!D:71U;&ES(&1I
M871A<R!B87)I<R!T96MS(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,W.`IM<V=I9"`B4W5P<&]R="(*;7-G<W1R(")$=6MU;F=A;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#8*(RP@9G5Z>GD*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(FYA
M;6$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`HC
M+"!F=7IZ>0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R(")N86UA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L;V<@
M9&5L971E9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,30R"FUS9VED(")3>6YC34PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-1
M3"]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@
M<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@
M(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")4+5-T;W)M
M(@IM<V=S='(@(DAU:F%N('!E=&ER(&1I<V5R=&%I(&1E;F=A;B!A;F=I;B!R
M:6)U="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8Q"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R(")(=6IA;B!P
M971I<B!D:7-E<G1A:2!D96YG86X@8F%D86D@86YG:6X@<FEB=70B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B
M5"U3=&]R;7,B"FUS9W-T<B`B2'5J86X@<&5T:7(@9&ES97)T86D@9&5N9V%N
M(&%N9VEN(')I8G5T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM
M<V=S='(@(D=E<FEM:7,@9&D@<&%G:2!H87)I(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82]T<W8N<&AP.C$V-@HC+"!F=7IZ>0IM<V=I9"`B5%-6(&9I;&4B
M"FUS9W-T<B`B2G5D=6PB"@HC.B!F<F%M97=O<FLO54DO54DO5&%B;&4N<&AP
M.C$S-`HC+"!F=7IZ>0IM<V=I9"`B5&%B;&4B"FUS9W-T<B`B1&%F=&%R(%1A
M8F5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R(")0
M<F]P97)T:2!486)E;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T
M86)L97-E="YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(E1A8FQE(%-E="(*;7-G
M<W1R(")0<F]P97)T:2!486)E;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E
M<G1I97,B"FUS9W-T<B`B4')O<&5R=&D@=&%B96PB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Q"B,L(&9U>GIY"FUS9VED(")486EW86XB"FUS9W-T<B`B2'5J86XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I
M9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R(")487)G970Z(@H*
M(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDY-B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3@W"FUS9VED(")487-K<R(*;7-G<W1R(")4=6=A<R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")4
M96QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,CDP"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R
M(")3=6AU('5N='5K(&IA;2!T97)A:VAI<CHB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(Q-`IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B4W5H=2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C,*;7-G:60@(E1E
M;7!E<F%T=7)E.B`B"FUS9W-T<B`B4W5H=3HB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,CDS"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E
M<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B
M4W5H=3QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@H*(SH@9G)A;65W
M;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HV.#<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S
M='(@(D1I<F5K=&]R:2!-;W1I9B`G)7,G('1I9&%K(&1I=&5M=6MA;BXB"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B5&5M<&QA=&4@061M:6YI<W1R87-I(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,S,V"B,L(&9U>GIY"FUS9VED(")497AT(@IM<V=S='(@
M(D)E<FEK=71N>6$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<U"FUS
M9VED(")497AT($]N;'DB"FUS9W-T<B`B2&%N>6$@5&5K<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G
M:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B4&5R871A86X@5&5K<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@
M(E1E>'1T;W`B"FUS9W-T<B`B5&5K<R!"86=I86X@071A<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H
M(@IM<V=S='(@(DMM<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS
M9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R(")4:&%I("A425,M-C(P*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B5&AA;FL@>6]U
M(&9O<B!U<VEN9R!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C@R,`HC+"!F=7IZ>0IM<V=I9"`B5&AE($94
M4"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B07)E82!K
M92!W96%T:&5R+F-O;2!T:61A:R!D:7-E9&EA:V%N+B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P
M<&]R="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])35-0
M+TE-4U`O0F]O:RYP:'`Z,3(Y,@IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD
M(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C
M;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(E!E;65L
M:6AA<F%A;CHZ(&-L87-S('1I9&%K(&)E<FAA<VEL(&1I<&%N9V=I;"(*"B,Z
M('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H
M92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R
M(")7:6YD;W<@4&EL:6AA;B!S=61A:"!D:71U='5P+B!3:6QA:V%N($ME;'5A
M<B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@
M861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@
M4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R
M;6ES<VEO;G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@
M<VED92!O;FQY(@IM<V=S='(@(DAA;GEA('-I<VD@8F%G:6%N(&)A=V%H(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P
M96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B
M"B)D871A8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@
M<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38Y
M"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I
M<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$
M('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@
M9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I
M9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q,PIM
M<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R
M92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-S4@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU
M,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O
M;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$V."!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,3D*;7-G:60@(E1H92!F:6QE(&-A
M;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1&%T82]$871A+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O
M;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W
M:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M
M97-S86=E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@
M;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T
M($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R
M96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC
M92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N
M<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@
M<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO
M=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@
M;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0
M;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H
M92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*(DUO9&4@3&%Y87(@
M4&5N=6@@9&EK96YA;"!D87!A="!M96YY96)A8FMA;B!M87-A;&%H(&1E;F=A
M;B!);G1E<FYE="!%>'!L;W)E<BP@(@HB:G5G82!U;G1U:R!M96YC87)I(&ME
M<V%L86AA;B!Y86YG(&UE;GEE8F%B:V%N(&%N9&$@=&ED86L@;6%M<'4@8F5K
M97)J82`B"B)D96YG86X@8F%I:RX@06YD82!M=6YG:VEN('!E<FYA:"!M96YG
M86QA;6D@=&%M<&EL86X@>6%N9R!B=7)U:RP@:V5K=7)A;F=A;B`B"B)D87)I
M(&9U;F=S:2!E9&ET;W(@9&%N+V%T874@8G)O=W-E<B!Y86YG('-E<FEN9R!K
M86QI(')U<V%K(&1A;B!H87)U<R!D:75L86YG("(*(FME;6)A;&DN($II:V$@
M<VES=&5M(&%N9&$@861A;&%H(%=I;F1O=W,@.7@@861A(&ME;75N9VMI;F%N
M(&%N9&$@86MA;B`B"B)M96YD87!A=&MA;B`G2V5S86QA:&%N(%!E<FQI;F1U
M;F=A;B!5;75M)R!D86X@<&5R;'4@=6YT=6L@;64M<F5S=&%R="`B"B)K;VUP
M=71E<B!A;F1A+EQ<;EQ<;B!!;F1A('-U9&%H(&1I<&5R:6YG871I+B!3:6QA
M:V%N(&ML:6L@3TL@:FEK82!A;F1A(&EN9VEN("(*(FUE;F-O8F$@961I=&]R
M(&QA>6%R('!E;G5H+B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N
M(&1E;&5T960N(@IM<V=S='(@(DED96YT:71A<R!<(B5S7"(@<W5D86@@9&EH
M87!U<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*
M;7-G<W1R(")(86YY82!S:7-I(&)A9VEA;B!K:7)I(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I
M;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#
M<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S
M7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT
M964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O
M;V0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M-S<*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE
M(&-O;7!O<V4@<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HT-#$*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU
M<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HQ,C,Q"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U
M;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L
M87-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP
M.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<
M(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC
M965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS,@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H
M<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP
M.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z
M,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z
M,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T
M;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T
M:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HT-30*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B
M92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I
M9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B2&%N
M>6$@<VES:2!B86=I86X@:V%N86X@9&%N(&MI<FDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4
M:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B2&%N>6$@<VES:2!B
M86=I86X@:V%N86XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT
M-#8*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H
M87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U
M;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S
M7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B4V5R=F5R(%PB)7-<(B!S
M=61A:"!B97)H87-I;"!D:6AA<'5S+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R
M<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@
M7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R(")397)V97(@7"(E<UPB
M('-U9&%H(&)E<FAA<VEL(&1I<VEM<&%N+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@
M9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(E!E<FUI;G1A86X@
M<&5N9&%F=&%R86X@=6YT=6L@)7,@<W5D86@@8F5R:&%S:6P@9&EP:6YD86AK
M86XN(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,S,P
M"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ-S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D
M;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S,Q,0IM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED
M(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*
M;7-G<W1R(")(86YY82!S:7-I(&)A9VEA;B!A=&%S(&1A;B!B87=A:"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(DAA;GEA('-I
M<VD@8F%G:6%N(&%T87,B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HS
M,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H
M92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H
M<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S
M879E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C0V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$U(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ,3D*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")!<F5A(&ME('=E871H97(N8V]M
M('1I9&%K(&1I<V5D:6%K86XN(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP
M.C(U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T
M;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(D1I<F5K=&]R:2!-;W1I
M9B`G)7,G('1I9&%K(&1I=&5M=6MA;BXB"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C$W.`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@87)E(&YO
M(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R(")!<F5A($UE=&%R('1I9&%K
M(&1I<V5D:6%K86XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z,S0R"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@
M8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9
M;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N
M=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HU
M,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S
M>7-T96TZ("5S(@IM<V=S='(@(D%D82!M87-A;&%H(&ME=&EK82!M96YA;6)A
M:&MA;B`G)7,G(&ME(&1A;&%M('-I<W1E;3H@)7,@(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(D%D82!M87-A;&%H(&ME=&EK82!M
M96UB97)S:6AK86X@9&%T82!U;G1U:R!P96YG9W5N82`G)7,G(&1A<FD@<VES
M=&5M.B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S
M7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B061A(&UA<V%L86@@:V5T
M:6MA(&UE;6EN9&%H:V%N("<E<R<@9&%R:2!S:7-T96TZ(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,34Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B
M061A(&UA<V%L86@@:V5T:6MA(&UE;7!E<F)A:&%R=6D@)R5S)SHE<R(*"B,Z
M(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*
M(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P
M;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@
M=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@P"FUS
M9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I
M;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F
M:65L9"XB"FUS9W-T<B`B(@HB061A(&ME<V%L86AA;B!D:2!D86QA;2!F;W)M
M=6QI<B!K;VYF:6=U<F%S:2X@375N9VMI;B!A;F1A('1I9&%K(&UE;F=I<VD@
M(@HB:V]L;VT@>6%N9R!D:7!E<FQU:V%N+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R
M92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E
M<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#`*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@
M=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B)!9&$@:V5S86QA:&%N(&1I
M(&1A;&%M(&9O<FUU;&ER(&MO;F9I9W5R87-I+B!-=6YG:VEN(&%N9&$@=&ED
M86L@;65N9VES:2`B"B)K;VQO;2!Y86YG(&1I<&5R;'5K86XN(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(*(RP@9G5Z
M>GD*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@
M9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM
M<V=S='(@(B(*(D%D82!K97-A;&%H86X@9&D@9&%L86T@9F]R;75L:7(@:V]N
M9FEG=7)A<VDN($UU;F=K:6X@86YD82!T:61A:R!M96YG:7-I("(*(FMO;&]M
M('EA;F<@9&EP97)L=6MA;BXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HQ-#@*(RP@9G5Z>GD*;7-G:60@(E1H:7,@24U!4"!S
M97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S
M='(@(D)R;W=S97(@86YD82!T:61A:R!M96YD=6MU;F<@=6YT=6L@9FET=7(@
M:6YI+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@
M<F%R(&%R8VAI=F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P
M96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q-#4*;7-G:60@(E1H:7,@9&]E<R!N
M;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C
M;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M
M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E
M;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S
M;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@
M271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)
M="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@
M271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S.3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Y-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(P-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T
M.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(T,3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U
M-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4W(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(X,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$S-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`V"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,X,30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S@R,@IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$X"FUS9VED(")4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DT
M"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L
M=65S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3(S"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C
M92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY.#D*;7-G:60@(E1H:7,@9FEE;&0@
M;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@S-@IM<V=I9"`B(@HB5&AI<R!F:65L9"!M
M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA
M="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H
M87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AI<R!I<R`E<RXB"FUS9W-T<B`B26YI(&%D86QA:"`E<RXB"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C0U.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE
M=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N
M="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T
M+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@
M=FES:70@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z-3DQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S
M<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE
M<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B
M92!A="!L96%S="!O;F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@
M8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3@Y
M"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*
M;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T
M:6]N<R!W:6YD;W<B"FUS9W-T<B`B5VEN9&]W(&EN:2!H87)U<R!D:7!A;F=G
M:6P@9&%R:2!0:6QI:&%N(%=I;F1O=R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4:'5N9&5R(@IM<V=S='(@
M(E!E=&ER(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-`IM<V=I
M9"`B5&EC:V5T<R(*;7-G<W1R(")4:6ME="(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T,C@@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U
M"B,L(&9U>GIY"FUS9VED(")4:6UE(@IM<V=S='(@(DIU9'5L(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X-@IM<V=I9"`B5&EM92!4<F%C:VEN
M9R(*;7-G<W1R(")-96YG:6MU=&D@5V%K='4B"@HC.B!L:6(O0FQO8VLO=&EM
M92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(D9O<FUA="!7
M86MT=2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U,SD*(RP@9G5Z
M>GD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(DAA<'5S('!I;&EH
M86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G
M<W1R(")*=61U;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B
M2G5D=6P@*$-A=&%T86X@<&5T=6YJ=6LI(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B5&\B
M"FUS9W-T<B`B071A<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I
M=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H
M36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*;7-G:60@(E1O9&%Y(@IM
M<V=S='(@(DAA<FD@26YI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM
M<V=S='(@(D=A;G1I(%-O=7)C92!(5$U,(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I
M9"`B5&]G;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME
M;&%U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS,3,*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(D)E<V]K(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,`HC+"!F=7IZ>0IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B2&%R:2!)
M;FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G<W1R(")!=&%S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P
M(&9R86UE("A?=&]P*2(*;7-G<W1R(")&<F%M92!!=&%S("A?=&]P*2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L871I;VYS
M(@IM<V=S='(@(E1R86YS;&%S:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R
M:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C4W"FUS9VED(")4=2(*;7-G<W1R(")396PB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS
M9VED(")4=6YI<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@
M(E1U<FME>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M,@IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B5'5R:VD@
M*$E33RTX.#4Y+3DI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES
M=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N
M9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS
M9VED(")4=79A;'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN
M<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-CD*;7-G:60@(E4N
M5BX@:6YD97@Z("(*;7-G<W1R("));F1E:W,@52Y6.B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I
M9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T<B`B55),.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$R"B,L(&9U>GIY"FUS9VED(")5:W)A:6YE(@IM<V=S='(@(D=A<FES(&)A
M=V%H(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$R"FUS9VED
M(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B
M56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG
M;FEN9R!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HS.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG
M92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,X-2!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E
M('1O("5S+B(*;7-G<W1R(")4:61A:R!D87!A="!U;G1U:R!M96YG:&%P=7,@
M7"(E<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S
M,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K
M(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(E1I9&%K(&1A<&%T('5N
M='5K(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C8X."!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P
M,38*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@
M<VEZ92!O9B!<(B5S+R5S7"(N(@IM<V=S='(@(E1I9&%K(&1A<&%T('5N='5K
M(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<W%L+G!H<#HT,S4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C;VYN
M96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(E1I9&%K(&1A<&%T('1E<FAU
M8G5N9R!K92!S97)V97(@;&1A<"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z.#,Y"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(U
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S,`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C(P.0IM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S8U"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D
M:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")4:61A:R!D87!A="!U;G1U:R!M
M96YG:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HS-30@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C4V"FUS9VED(")5
M;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*(RP@9G5Z>GD*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(E1I9&%K
M(&1A<&%T('5N='5K(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*
M;7-G<W1R(")4:61A:R!D87!A="!U;G1U:R!M96YG:&%P=7,@7"(E<UPB.B`E
M<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-C4*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW.0HC+"!F
M=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T
M<B`B5&ED86L@9&%P870@=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,C0@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HR.3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO
M="!E;7!T>2XB"FUS9W-T<B`B5&ED86L@9&%P870@=6YT=6L@;65N9VAA<'5S
M(%PB)7-<(CH@)7,N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW."!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C0T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B5&ED86L@9&%P870@
M=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,S,Q(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M,SDR"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,3$@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,S-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO
M="!E;7!T>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,S0X(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS
M-3(*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U
M<G-I=F5L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,S,W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,C(*(SH@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,S-2!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HS-#0*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B5&ED86L@9&%P870@=6YT=6L@;65N
M9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HT,3<@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,CD*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I
M<F5C=&]R>3H@)7,N(@IM<V=S='(@(E1I9&%K(&1A<&%T('5N='5K(&UE;F=H
M87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,C`W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B5&ED86L@9&%P870@
M=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,S`S(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M,C@X"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ-C<@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X,`HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS.#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Y,0HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS
M9W-T<B`B5&ED86L@9&%P870@=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-#0*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E
M<B!<(B5S7"(N(@IM<V=S='(@(E1I9&%K(&1A<&%T('5N='5K(&UE;F=H87!U
M<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M-#`V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(E1I9&%K(&1A<&%T
M('5N='5K(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z.#`S"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE
M(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8P,PIM<V=I9"`B56YA8FQE('1O(&5X
M=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#4Q(&9R86UE=V]R:R].971?24U3
M4"])35-0+T%U=&@N<&AP.C$Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S
M='(@(E1I9&%K(&1A<&%T('5N='5K(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$V-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,3<Q"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C$P,@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C8T."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(E1I9&%K(&1A<&%T('5N='5K(&UE;F=H87!U<R!<
M(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W
M-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,P"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S,*;7-G:60@(E5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX,"!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C<R"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT
M-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#,U"FUS9VED
M(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8V"FUS
M9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F
M86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R(")4:61A:R!D87!A="!U
M;G1U:R!M96YG:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HV-CD*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V
M9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E
M861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,CDS"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,S(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,C8W(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,S0S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B5&ED86L@9&%P870@
M=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z-C$P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HR,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(E1I9&%K(&1A<&%T('5N
M='5K(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z,S(S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR
M,3,*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C@U"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O
M(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T
M<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,30Y(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,34R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")4:61A:R!D
M87!A="!U;G1U:R!M96YG:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HQ-SD*;7-G:60@(E5N86)L92!T;R!W<FET
M92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HQ-#,*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D
M871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#0Q
M"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@
M8F4@97AC965D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G
M<W1R(")'87)I<R!B87=A:"(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC
M.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R(")"871A;&MA;B!097)U
M8F%H86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R
M(")"871A;&MA;B!A:W-I('1E<F%K:&ER(&%N9&$B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED(")5;F5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR
M,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W.`HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*;7-G
M:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R(")4:61A:R!D:6%R
M<VEP:V%N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E5N
M:6-O9&4@*%541BTX*2(*;7-G<W1R(")5;FEC;V1E("A55$8M."DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@36EN
M;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,0IM
M<V=I9"`B56YI=',B"FUS9W-T<B`B56YI="(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0R.2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,S`*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED
M(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A
M9V4@240I+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,34Y"B,L(&9U>GIY"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R
M;W9I9&5D+B(*;7-G<W1R(")4:61A:R!A9&$@;&]K87-I('EA;F<@9&EA='5R
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@
M96QE;65N="(*;7-G<W1R(")"871A;&MA;B!L:6YK('!A9&$@96QE;65N('EA
M;F<@<V5K87)A;F<B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN
M<&AP.C(Y-@HC+"!F=7IZ>0IM<V=I9"`B56YN86UE9"(*;7-G<W1R(")N86UA
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU
M.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S
M<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R
M:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T
M92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L
M;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R
M("(B"B)38W)I<'0@>6%N9R!T:61A:R!M96UP=6YY86D@:&%K(&ES=&EM97=A
M('1I9&%K(&1A<&%T(&UE;F=A:W-E<R!(87!U<R]386QI;B\B"B),96MA=&MA
M;B!S97-U86D@<F5N8V%N82!U;G1U:R!A;&%S86X@:V5A;6%N86XN2VQI:R!/
M2R!U;G1U:R!M96QI:&%T(&-A=&%T86X@(@HB=&5K;FES('!A9&$@;6]Z:6QL
M82YO<F<@9&EM86YA(&%N9&$@86MA;B!D:7!E<FQI:&%T:V%N(&-A<F$@8F%G
M86EM86YA('5N='5K("(*(FUE;F=I>FEN:V%N('-C<FEP="!U;G1U:R!D87!A
M="!M96YG86MS97,@:V4@8VQI<&)O87)D+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T
M(&-O;&]R(@IM<V=S='(@(E=A<FYA(&)E;'5M(&1I871U<B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@V(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z.3,R"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P
M9&%T92(*;7-G<W1R(")097)B86AA<G5I(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A
M=&4@)7,B"FUS9W-T<B`B4&5R8F%H87)U:2`E<R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*;7-G:60@(E5P9&%T92!U<V5R(@IM
M<V=S='(@(E!E<F)A:&%R=6D@<&5N9V=U;F$B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D
M(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB('-U9&%H(&1I<&5R8F%H87)U:2XB
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D
M92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B4V-R:7!T('5P9W)A9&4@<W5D
M86@@9&EH87!U<RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3D*;7-G:60@
M(E5P;&]A9"(*;7-G<W1R(")5<&QO860B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T
M=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B4V5M=6$@9FEL92!S
M971U<"!A<&QI:V%S:2!S=61A:"!D:75P;&]A9"!K92!S97)V97(N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R(")3:6UB
M;VP@:'5R=68@8F5S87(@;&%T:6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R
M;VUA;B!N=6UB97)S(@IM<V=S='(@(E-I;6)O;"!H=7)U9B!B97-A<B!R;VUA
M=VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP
M.C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@
M)7,B"FUS9W-T<B`B1F%S92!396MA<F%N9R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G
M:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U3
M4"!S97)V97(N(@IM<V=S='(@(D=U;F%K86YL86@@:FEK82!N86UA+W-A;F1I
M(&%N9&$@8F5R8F5D82!U;G1U:R!S97)V97(@24U34"XB"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"B,L(&9U>GIY"FUS9VED(")5
M<V5R(@IM<V=S='(@(E!E;F=G=6YA(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+U)E9VES=')Y+G!H<#HW,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E
M<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO
M;B(*;7-G<W1R(")!9&UI;FES=')A<VD@4&5N9V=U;F$B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,0HC+"!F=7IZ>0IM<V=I9"`B57-E
M<B!/<'1I;VYS(@IM<V=S='(@(E-I;7!A;B!0:6QI:&%N(@H*(SH@<VEG;G5P
M+G!H<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B4&5N
M9&%F=&%R86X@4&5N9V=U;F$B"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5
M<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S
M:71E+B(*;7-G<W1R(")096YD869T87)A;B!096YG9W5N82!S=61A:"!D:6YO
M;BUA:W1I9FMA;B!U;G1U:R!S:71E(&EN:2XB"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM
M<V=S='(@(D%C8V]U;G0@4&5N9V=U;F$@=&ED86L@9&ET96UU:V%N(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S
M-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P
M+G!H<#HY.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HQ-3`@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B3F%M
M82!096YG9W5N82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L
M<F5A9'D@97AI<W1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(").86UA
M(%!E;F=G=6YA.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*
M;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B3F%M82!096YG9W5N83HB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R
M<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R(")096YG9W5N82!D:2!D86QA;2!S
M:7-T96TZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-C,@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")6
M1E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")3=6)D:7)E
M:W1O<FD@)R5S)R!T:61A:R!D:71E;75K86XN(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B3&EB
M=7)A;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V-@IM<V=I9"`B
M5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.`HC+"!F=7IZ
M>0IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B2V5L96UB86)A;B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U
M-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4V(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@
M:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#0@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S$V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C@*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#D@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-@IM<V=I9"`B5F%L=65S('1O
M('-E;&5C="!F<F]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@
M(E9A;G5A='4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(T-`IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B5F%R:6%B;&4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@
M(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@
M8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,`HC+"!F=7IZ>0IM<V=I9"`B5F5R
M<VEO;B(*;7-G<W1R(")697)S:2!+;VYT<F]L(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(R-@IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S
M='(@(E9E<G-I($MO;G1R;VPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG
M;B(*;7-G<W1R(")*87)A:R!P;W-I<VD@=F5R=&EK86P@86YT87)A(&=A<FES
M(&1A<V%R(&1E;F=A;B!G86UB87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG
M(@IM<V=S='(@(DIA<F%K('!O<VES:2!V97)T:6MA;"!A;G1A<F$@8F]R9&5R
M(&1E;F=A;B!G86UB87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B5F5R
M=&EK86PZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-S`*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R(")386YG870@5&EN9V=I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@(E9I971N86UE<V4@
M*%9)4T-)22DB"FUS9W-T<B`B5FEE=&YA;2`H5DE30TE)*2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDV,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")6:65W("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS
M9W-T<B`B3&EH870@=V5B('!A9V4@96MS=&5R;F%L(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E9I97<@87,@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I
M9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI
M='DB"FUS9W-T<B`B2F%R86L@4&%N9&%N9R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R
M(")*87)A:R!086YD86YG.B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L
M>2!V:6$@4TU44"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED
M(")705).(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#
M4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R(")015))3D=!5$%.(2$A
M(%!)3D1!2$M!3B!30U))4%0@24Y)(%-%0T%202!-04Y504P@1$%222`E<RXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S,PIM
M<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*
M;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U
M<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP
M:'`Z,C<R(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN
M9R(*;7-G<W1R(")097)I;F=A=&%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B4F%B
M=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B
M5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R(")286UA;&%N($-U86-A(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0R-PIM<V=I9"`B5V5A=&AE
M<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(D1A=&$@0W5A8V$@9&ES961I
M86MA;B!O;&5H(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR"B,L
M(&9U>GIY"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O
M;2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS
M9W-T<B`B5V5B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S-PIM
M<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B5V5B(%-I=&4B"@HC.B!F<F%M97=O
M<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7965K
M;'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z
M,C@*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B4V5L86UA="!$871A;F<B"@HC
M.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T
M;R`E<R(*;7-G<W1R(")396QA;6%T(&1A=&%N9R!K92`E<R(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO;65N
M=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*;7-G
M<W1R(")396QA;6%T(&1A=&%N9RP@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y-0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B
M5V5S=&5R;B`H25-/+3@X-3DM,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y-@IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(E=E
M<W1E<FX@*$E33RTX.#4Y+3$U*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T
M97)N(%-A:&%R82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@
M<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(D%P86MA
M:"!A<&QI:V%S:2`E<R!P97)L=2!D:71A;7!I;&MA;B!S971E;&%H(&QO9VEN
M/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7
M:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R(")!<&%K
M86@@>6%N9R!M97)U<&%K86X@8F%T87,@:V%R86MT97(_(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U
M;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B07!A:V%H('EA;F<@;65R=7!A:V%N
M(&MA<F%K=&5R(&EN9&5N=&%S:3\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3`V,0IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L
M:6$@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM
M<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(D9A<V4@>6%N9R!M86YA(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PIM<V=I9"`B5VAI8V@@<&QU
M9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G
M<W1R(")0;'5G:6X@;6%N86MA:"!Y86YG(&1A<&%T(&1I86MT:69K86X@=6YT
M=6L@961I=&]R(%)I8V@@5&5X="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G
M<W1R("),96)A<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C4*
M(RP@9G5Z>GD*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R("),
M96)A<B!U;FET(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@
M;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`B
M(@HB3&5B87(@;65N=2`E<R!P861A(&)A9VEA;B!K:7)I("AA:V%N(&)E<G!E
M;F=A<G5H('!A9&$@;&]G:6X@8F5R:6MU=&YY82DB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@
M;V8@=&AE('1A8FQE(@IM<V=S='(@(DQE8F%R('1A8F5L(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I
M9'1H('5N:70B"FUS9W-T<B`B3&5B87(@=6YI="(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB
M"FUS9W-T<B`B3&5B87(Z(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C4Q,PIM<V=I9"`B5VEK:2(*;7-G<W1R(")7:6MI(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5VEN9"(*;7-G<W1R(")!;F=I;B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS
M9VED(")7:6YD($5A<FQY(@IM<V=S='(@(D%N9VEN(&1I('!A9VD@:&%R:2(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@
M:6X@:VYO=',B"FUS9W-T<B`B2V5C97!A=&%N(&%N9VEN(&1I(&1A;&%M(&MN
M;W0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U-@IM<V=I9"`B5VEN9#HB
M"FUS9W-T<B`B06YG:6XZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(T,@IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(D%N9VEN.B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@
M(DMA=&$@0FEJ86MS86YA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$Y-@IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B1&%F=&%R($ME:6YG:6YA
M;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*
M;7-G<W1R(")096ME<FIA86XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G:60@(E=O<FL@061D<F5S
M<R(*;7-G<W1R(")!;&%M870@16UA:6P@06YD82(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO
M;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M,38Y(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(V,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N
M($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S`P"B,L('!H<"UF;W)M870*;7-G:60@
M(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,3$T"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL
M92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR-#,*;7-G:60@(E@M4F5F(@IM<V=S='(@(E@M
M4F5F(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*
M;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,@IM<V=I9"`B
M6#4P.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S
M(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S
M(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#(*;7-G:60@(E@U,#EV,R!E
M>'1E;G-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P
M"FUS9VED(")962(*;7-G<W1R(")962(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0U-0HC+"!F=7IZ>0IM<V=I9"`B65E962(*
M;7-G<W1R(")962(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,3`X"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-38*;7-G
M:60@(EEE87)L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")9
M96UE;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.38S"FUS9VED(")997,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@
M(EEE<RP@22!!9W)E92(*;7-G<W1R(")982P@4T%902!315152E4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED
M(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@
M=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@HB06YD82!B
M97)A9&$@9&D@9&%L86T@34]$12!414M3+B!'=6YA:V%N('1O;6)O;"!;/#Y=
M('5N='5K(&UE;F=G86YT:2!K96UB86QI("(*(FME(&1A;&%M(&UO9&4@5UE3
M25=91RXB"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z.#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@
M;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B06YD82!T:61A:R!D:6EZ
M:6YK86X@=6YT=6L@;65M8G5A="!L96)I:"!D87)I("5D(&%R96$N(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#$Q"FUS9VED(")9;W4@87)E
M(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M261E;G1I='DO261E;G1I='DN<&AP.C,P,@IM<V=I9"`B66]U(&-A;B!N;W0@
M:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW-0HC+"!F=7IZ>0IM<V=I9"`B66]U
M(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R
M(")096YG9V%N=&D@86QA;6%T(&5M86EL(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N
M)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T
M:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B66]U(&AA
M=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E
M<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@
M86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L
M:6YG('!R969I>"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V
M86QU92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N
M=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E
M92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0U-@IM<V=I9"`B66]U(&UU<W0@8V]N
M9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C
M<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B
M;&5M(')E<&]R="XB"FUS9W-T<B`B(@HB06YD82!H87)U<R!M96YJ96QA<VMA
M;B!M87-A;&%H('-E8F5L=6T@86YD82!D87!A="!M96YG:7)I;6MA;B!L87!O
M<F%N("(*(FUA<V%L86@N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%52
M3"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(D%N9&$@:&%R
M=7,@;65M87-U:VMA;B!54DP@9&EM86YA(&QI;FL@:6YI(&UE;G5N:G5K(&ME
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@(EEO
M=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T
M<B`B06YD82!H87)U<R!M96UI;&EH('-E<G9E<B!U;G1U:R!D87!A="!D:6AA
M<'5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B06YD
M82!H87)U<R!M96YE=&%P:V%N(&YA;6$@<&5N9V=U;F$@>6%N9R!I;F=I;B!D
M:6)E<G-I:&MA;BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@
M(D%N9&$@:&%R=7,@;65N971A<&MA;B!N86UA('!E;F=G=6YA('EA;F<@:6YG
M:6X@9&EP:6YD86AK86XN(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(D%N9&$@:&%R
M=7,@;65N971A<&MA;B!N86UA('!E;F=G=6YA('5N='5K(&1I=&%M8F%H+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R(")!;F1A(&AA<G5S
M(&UE;F5T87!K86X@;F%M82!P96YG9W5N82!U;G1U:R!D:7!E<F)A:&%R=6DN
M(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,X
M"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N
M('1O('!E<F9O<FTN(@IM<V=S='(@(D%N9&$@:&%R=7,@;65N971A<&MA;B!N
M86UA('!E;F=G=6YA('EA;F<@:6YG:6X@9&EP:6YD86AK86XN(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*(RP@
M9G5Z>GD*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M
M92XB"FUS9W-T<B`B06YD82!H87)U<R!M96YE=&%P:V%N(&YA;6$@<&5N9V=U
M;F$@>6%N9R!I;F=I;B!D:7!I;F1A:&MA;BXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U
M(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0
M;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9;W5R($5M86EL($%D9')E
M<W,B"FUS9W-T<B`B06QA;6%T($5M86EL($%N9&$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C$R"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM
M<V=S='(@(D%N9&$@1&%R:3H@86QA;6%T.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM
M<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA<VD@06YD
M82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG
M960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O
M("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A
M:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C,S"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B3F%M82!!;F1A(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*(RP@9G5Z>GD*
M;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO
M="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E
M($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@
M=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM
M<V=S='(@(B(*(D)A8VME;F0@87-L:2!A;F1A('1I9&%K(&1A<&%T(&UE;F1U
M:W5N9R!P96YA;6)A:&%N('!E;F=G=6YA+"!A=&%U(&9I='5R(&EN:2`B"B)S
M=61A:"!D:6YO;BUA:W1I9FMA;B!U;G1U:R!B96)E<F%P82!A;&%S86X@;&%I
M;BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G
M:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S
M=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B
M965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B
M(@HB0F%C:V5N9"!A<VQI(&%N9&$@=&ED86L@9&%P870@;65N9'5K=6YG('!E
M;F1A9G1A<F%N('!E;F=G=6YA+"!A=&%U(&9I='5R(&EN:2`B"B)S=61A:"!D
M:6YO;BUA:W1I9FMA;B!U;G1U:R!B96)E<F%P82!A;&%S86X@;&%I;B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX-`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@
M<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O
M('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4P"FUS9VED
M(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N
M(@IM<V=S='(@(D)R;W=S97(@86YD82!T:61A:R!M96YD=6MU;F<@=6YT=6L@
M9FET=7(@:6YI+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS
M.C0R"B,L(&9U>GIY"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@
M<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM
M86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@HB0G)O=W-E<B!A;F1A
M('1I9&%K(&UE;F1U:W5N9R!P:6QI:&%N('5N='5K(&UE;F-E=&%K+B!496MA
M;B!#;VYT<F]L+U!I;&EH86X@*R`B"B)0('5N='5K(&UE;F-E=&%K+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3<*;7-G:60@(EEO=7(@8W5R<F5N
M="!T:6UE('IO;F4Z(@IM<V=S='(@(EIO;F$@5V%K='4@06YD82!396MA<F%N
M9SHB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.38*;7-G:60@(EEO=7(@9&5F
M875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R(")$969A
M=6QT(&ED96YT:71A<R!A;F1A('-U9&%H(&1I=6)A:"XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,34X"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I
M='DZ(@IM<V=S='(@(D1E9F%U;'0@:61E;G1I=&%S(&%N9&$Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(P,0IM<V=I9"`B66]U<B!F=6QL(&YA;64Z
M(@IM<V=S='(@(DYA;6$@;&5N9VMA<"!A;F1A.B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.C$P,#`*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X<&ER
M960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O
M<B`E<R!I<SH@)7,B"FUS9W-T<B`B4V%N9&D@8F%R=2!A;F1A('5N='5K("5S
M(&%D86QA:#H@)7,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$U-`IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O
M<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@HC+"!F=7IZ>0IM
M<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R
M(")$969A=6QT(&ED96YT:71A<R!A;F1A('-U9&%H(&1I=6)A:"XB"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S
M=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R(")386YD:2!A;F1A('-U9&%H
M(&1I871U<B!U;&%N9R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C
M:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B"B)P
M87-S=V]R9"XB"FUS9W-T<B`B(@HB4V%N9&D@86YD82!S=61A:"!D:6%T=7(@
M=6QA;F<L('!E<FEK<V%L86@@96UA:6P@86YD82!D86X@;&]G:6X@9&5N9V%N
M("(*(FUE;F=G=6YA:V%N('-A;F1I(&)A<G4@86YD82(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.C<S,@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!P87-S
M=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B4V%N9&D@86YD82!S=61A:"!D
M:6%T=7(@=6QA;F<B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(E)E;6]T
M92!S97)V97(@86YD83HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9
M=6=O<VQA=FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@*(RP@9G5Z>GD*;7-G:60@(EIA:7)E(@IM<V=S='(@(D-E
M<F%H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T
M<B`B0V5R:6$B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI
M9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB
M"FUS9W-T<B`B6U-E;6)U;GEI:V%N($EN9&5N=&%S:2!496MS72(*"B,Z('-E
M<G9I8V5S+W!R;V)L96TN<&AP.C@X"FUS9VED(");4')O8FQE;2!297!O<G1=
M(@IM<V=S='(@(EM,87!O<F%N($UA<V%L86A=(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E
M9"!497AT("TB"FUS9W-T<B`B6U1A;7!I;&%N($EN9&5N=&%S:2!496MS("TB
M"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U
M;W1E<RYP:'`Z,3<R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(");4VAO
M=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");5&%M<&EL86X@
M26YD96YT87-I(%1E:W,@+2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,3DS"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E<R!O
M9B`E<UTB"FUS9W-T<B`B)7,@=6YT=6L@)7,@)7,B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$U-#$@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN
M8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E]!9&UI;FES
M=')A<VDB"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T
M<B`B7T-,22(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A=&%4<F5E
M(@IM<V=S='(@(E]$871A5')E92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2
M;W<B"FUS9W-T<B`B2&%P=7,@0F%R:7,B"@HC.B!L:6(O87!I+G!H<#HQ,S,*
M;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B7T=R=7`B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U"B,L(&9U>GIY"FUS9VED(")?2&5L
M<"(*;7-G<W1R(")"86YT=6%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O
M<&5R=&EE<RXN+B(*;7-G<W1R(")0<F]P97)T:2!'86UB87(N+BXB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"B,L(&9U>GIY"FUS
M9VED(")?3&]G(&EN(@IM<V=S='(@(DQO9VEN(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`HC+"!F=7IZ>0IM<V=I9"`B7TQO9R!O
M=70B"FUS9W-T<B`B3&]G(&]U="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,
M:6YK+BXN(@IM<V=S='(@(E5B86@@3&EN:RXN+B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]-96YU+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G:60@(E]/<'1I
M;VYS(@IM<V=S='(@(E!I;&EH86XB"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G
M:60@(E]097)M:7-S:6]N<R(*;7-G<W1R("))>FEN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"FUS9VED
M(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B4&EN9&%H:V%N($QI;FLN+BXB
M"@HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R(")?
M4V5T=7`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM
M<V=S='(@(E!R;W!E<G1I(%1A8F5L+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y
M"FUS9VED(")?57-E<G,B"FUS9W-T<B`B4&5N9V=U;F$B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDR,0HC+"!F=7IZ>0IM<V=I9"`B861D<F5S
M<R!B;V]K(@IM<V=S='(@(D)U:W4@06QA;6%T("(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R97-S964@=6YK
M;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDQ,PHC+"!F=7IZ>0IM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B2V%L96YD
M97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@
M(E1E;F%N9R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,34X"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,P"FUS
M9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*;7-G:60@(F-L:6-K(&AE
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W
M.`HC+"!F=7IZ>0IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R
M(")097)B961A86X@2V]N9FEG=7)A<VDB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I
M;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M.#(*(RP@9G5Z>GD*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R(")!
M8V-O=6YT(%!E;F=G=6YA('1I9&%K(&1I=&5M=6MA;B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")F86QL:6YG
M(@IM<V=S='(@(FIA='5H(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.#4U"B,L(&9U>GIY"FUS9VED(")F:6QE(@IM<V=S='(@(E1I9&%K
M(&1I87)S:7!K86XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L:6(O
M0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO8VLO;65T87(N<&AP.C,X-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S
M(@IM<V=S='(@(D1A<FD@)7,@*"5S*2!P861A("5S("5S(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,`IM<V=I9"`B9W5S=&EN9R(*;7-G
M<W1R(")A;F=I;B!K96YC86YG(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(T.0IM<V=I9"`B:#HB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.`IM<V=I
M9"`B:&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y
M"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B;6%S:6@@9&D@9&%L86T@86YT<FEA
M;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38R"FUS
M9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L
M('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T
M<B`B8F%R:7-=(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O
M9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8Y
M"FUS9VED(")M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C(Y,2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,S(*;7-G:60@(FYA
M;64B"FUS9W-T<B`B;F%M82(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ
M,C$*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,3D*;7-G:60@(FYO="!Y
M970@:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,#4*(RP@9G5Z>GD*;7-G:60@(FYO=&5P860B"FUS9W-T
M<B`B=&5T87`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@(G!E<G-E
M;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<T"B,L
M(&9U>GIY"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("))>FEN
M('5N='5K(%PB)7-<(B!T:61A:R!D87!A="!D:6AA<'5S+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G
M:60@(G!I>&5L<R(*;7-G<W1R(")P:7AE;"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@
M<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-S,*;7-G:60@(G)I<VEN9R(*;7-G<W1R(")N86EK
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*(RP@
M9G5Z>GD*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B07)E
M82!-971A<B!T:61A:R!D:7-E9&EA:V%N+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z.3D*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B
M=&%M<&EL:V%N('!E<F)E9&%A;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA
M($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,X-0IM<V=I9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*;7-G:60@(G-T
M96%D>2(*;7-G<W1R(")T971A<"(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,S`Y"FUS9VED(")S=VET8V@@;V9F(&IA=F%S8W)I<'0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3`*
M;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDR.0IM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38V"FUS
M9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C,P-0IM<V=I9"`B=')Y(&%G86EN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W
M:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B2V5T:6L@<V%N9&D@9'5A(&MA;&D@
M=6YT=6L@;65N9VMO;F9I<FUA<VDB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H
M<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B=6YI9FEE9"(*
M;7-G<W1R(")M96YY871U:V%N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]0
M87)T+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B=6YN86UE9"(*;7-G<W1R(")N
M86UA(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C(S"B,L(&9U>GIY"FUS9VED(")U<V5R('-E;&5C="(*;7-G
M<W1R(")(87!U<R!P:6QI:&%N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C,U"B,L(&9U>GIY"FUS9VED(")V0V%R9"(*;7-G
M<W1R(")+87)A:W1E<B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR-#$*;7-G:60@(G<Z(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*
M;7-G<W1R(")W96%T:&5R+F-O;2(*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&\O:7-?25,N<&\`````````````````````
M````````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#8S,C,T-``Q,#4Q-30S
M,S<U-``P,3<V-3<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(R!)8V5L86YD:6,@=')A;G-L871I;VYS(&9O<B!D:7-K('!A
M8VMA9V4N"B,@0V]P>7)I9VAT("A#*2`R,#`U($AO<F1E(%!R;VIE8W0*(R!4
M:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS
M92!A<R!T:&4@9&ES:R!P86-K86=E+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB
M4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`N-5QN(@HB4F5P;W)T+4US
M9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A
M=&EO;BU$871E.B`R,#`R+3`Q+3$P(#$Y.C`P*S`Q,#!<;B(*(E!/+5)E=FES
M:6]N+41A=&4Z(#(P,#4M,3$M,3D@,C`Z,S,K,#`P,%QN(@HB3&%S="U4<F%N
M<VQA=&]R.B!":F]R;B!$879I9'-S;VX@/&)J;W-S:4!S;F5R<&$N:7,^7&XB
M"B),86YG=6%G92U496%M.B!)8V5L86YD:6,@/'-U<'!O<G1`<VYE<G!A+FES
M/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X
M="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-#D*;7-G:60@(B(*(B`@+4TL("TM;65S<V%G93U-15-304=%("!5<V4@=&AI
M<R!C;VUM:70@;65S<V%G92!I;G-T96%D(&]F('1H92!D969A=6QT(&]N97,N
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU,PIM<V=I9"`B
M(@HB("`M82P@+2UA9&0]1DE,12`@("`@("`@061D('1H:7,@4$\@9FEL92!T
M;R!T:&4@8V]M<&5N9&EU;2X@57-E9G5L('1O7&XB"B(@("`@("`@("`@("`@
M("`@("`@("`@("!I;F-L=61E(&$@8V]M<&5N9&EU;2!F<F]M(&$@9&EF9F5R
M96YT(&)R86YC:"!T;UQN(@HB("`@("`@("`@("`@("`@("`@("`@("`@=&AE
M(&=E;F5R871E9"!C;VUP96YD:75M+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,3$S"FUS9VED("(B"B(@("UB+"`M+6)A<V4]+U!!5$@@
M($9U;&P@<&%T:"!T;R!T:&4@*$AO<F1E*2!B87-E(&1I<F5C=&]R>2!T:&%T
M('-H;W5L9"!B95QN(@HB("`@("`@("`@("`@("`@("`@("!U<V5D+B(*;7-G
M<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-CD*;7-G:60@(B(*(B`@
M+6,L("TM8V]M<&5N9&EU;3U&24Q%("!-97)G92!N97<@=')A;G-L871I;VYS
M('1O('1H:7,@8V]M<&5N9&EU;2!F:6QE7&XB"B(@("`@("`@("`@("`@("`@
M("`@("`@("`@:6YS=&5A9"!O9B!T:&4@9&5F875L="!O;F4@*&-O;7!E;F1I
M=6TN<&\@:6X@=&AE7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("`@:&]R
M9&4O<&\@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z-C,@<&\O=')A;G-L871I;VXN<&AP.C@Q('!O+W1R86YS;&%T:6]N
M+G!H<#HX-PIM<V=I9"`B(@HB("`M8RP@+2UC;VUP96YD:75M/49)3$4@(%5S
M92!T:&ES(&-O;7!E;F1I=6T@9FEL92!I;G-T96%D(&]F('1H92!D969A=6QT
M7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("`@;VYE("AC;VUP96YD:75M
M+G!O(&EN('1H92!H;W)D92]P;R!D:7)E8W1O<GDI+B(*;7-G<W1R("(B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$T"FUS9VED("(@("UD+"`M+61E8G5G
M("`@("`@(%-H;W<@97)R;W(@;65S<V%G97,@9G)O;2!T:&4@97AE8W5T960@
M8FEN87)I97,N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU
M-`IM<V=I9"`B("`M9"P@+2UD:7)E8W1O<GD]1$E2("`@0W)E871E(&-O;7!E
M;F1I=6T@:6X@=&AI<R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,34*;7-G:60@(B`@+6@L("TM:&5L<"`@("`@("`@
M4VAO=R!T:&ES(&AE;'`@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C0R('!O+W1R86YS;&%T:6]N+G!H<#HV-R!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-S4*;7-G:60@(B`@+6PL("TM;&]C86QE/6QL7T-#("`@
M("!5<V4@;VYL>2!T:&ES(&QO8V%L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C0W('!O+W1R86YS;&%T:6]N+G!H<#HV,2!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-SD*(SH@<&\O=')A;G-L871I;VXN<&AP.C@U"FUS9VED
M("(@("UL+"`M+6QO8V%L93UL;%]#0R`@("`@57-E('1H:7,@;&]C86QE+B(*
M;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-34*;7-G:60@(B`@
M+6PL("TM;&]C86QE/6QL7T-#("`@(%5S92!T:&ES(&QO8V%L92XB"FUS9W-T
M<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8X"FUS9VED("(@("UM+"`M
M+6UO9'5L93U-3T153$4@("`@0G5I;&0@34\@9FEL97,@;VYL>2!F;W(@=&AI
M<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C0S"FUS9VED("(@("UM+"`M+6UO9'5L93U-3T153$4@("`@0VQE
M86YU<"!03R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+B(*
M;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#@*;7-G:60@(B(*
M(B`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#;VUM:70@=')A;G-L871I;VYS
M(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S='(@(B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HV,@IM<V=I9"`B("`M;2P@+2UM;V1U;&4]
M34]$54Q%("`@($-R96%T92!A(%!/(&9I;&4@;VYL>2!F;W(@=&AI<R`H2&]R
M9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C@P"FUS9VED("(@("UM+"`M+6UO9'5L93U-3T153$4@("`@365R9V4@4$\@
M9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C<V"FUS9VED("(B"B(@("UM+"`M
M+6UO9'5L93U-3T153$4@("`@57!D871E(&AE;'`@9FEL97,@;VYL>2!F;W(@
M=&AI<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C@V"FUS9VED("(@("UM+"`M+6UO9'5L93U-3T153$4@("`@
M57!D871E(&]N;'D@=&AI<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C4X"FUS9VED("(@("UM+"`M+6UO9'5L
M93U-3T153$4@($=E;F5R871E(%!/5"!F:6QE(&]N;'D@9F]R('1H:7,@*$AO
M<F1E*2!M;V1U;&4N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HW,`IM<V=I9"`B(@HB("`M;BP@+2UN;RUC;VUP96YD:75M("`@($1O;B=T
M(&UE<F=E(&YE=R!T<F%N<VQA=&EO;G,@=&\@=&AE(&-O;7!E;F1I=6TN(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV-"!P;R]T<F%N<VQA
M=&EO;BYP:'`Z.#(@<&\O=')A;G-L871I;VXN<&AP.C@X"FUS9VED("(@("UN
M+"`M+6YO+6-O;7!E;F1I=6T@("`@1&]N)W0@=7-E(&$@8V]M<&5N9&EU;2XB
M"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C<Q"FUS9VED("(@
M("US+"`M+7-T871I<W1I8W,@("`@("`@4V%V92!T<F%N<VQA=&EO;B!S=&%T
M:7-T:6-S(&EN(&$@;&]C86P@9FEL92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C$Q-@IM<V=I9"`B("`M="P@+2UT97-T("`@("`@("!3
M:&]W('1H92!E>&5C=71E9"!C;VUM86YD<R!B=70@9&]N)W0@<G5N(&%N>71H
M:6YG+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`U"FUS
M9VED("(B"B(@(&-L96%N=7`@("`@($-L96%N<R!T:&4@4$\@9FEL97,@=7`@
M9G)O;2!U;G1R86YS;&%T960@86YD(&]B<V]L971E(&5N=')I97,N(@IM<V=S
M='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#@*;7-G:60@(B`@8V]M
M;6ET("`@("`@0V]M;6ET('1R86YS;&%T:6]N<R!T;R!T:&4@0U93('-E<G9E
M<BXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P.0IM<V=I
M9"`B("!C;VUM:70M:&5L<"!#;VUM:70@:&5L<"!F:6QE<R!T;R!T:&4@0U93
M('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.CDY
M"FUS9VED("(B"B(@(&-O;7!E;F1I=6T@(%)E8G5I;&0@=&AE(&-O;7!E;F1I
M=6T@9FEL92X@5V%R;FEN9SH@5&AI<R!O=F5R=W)I=&5S('1H95QN(@HB("`@
M("`@("`@("`@("!C=7)R96YT(&-O;7!E;F1I=6TN(@IM<V=S='(@(B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HQ,#`*;7-G:60@(B`@97AT<F%C="`@("`@
M1V5N97)A=&4@4$\@=&5M<&QA=&4@*"YP;W0I(&9I;&5S+B(*;7-G<W1R("(B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.3@*;7-G:60@(B`@:&5L<"`@("`@
M("`@4VAO=R!T:&ES(&AE;'`@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C$P,0IM<V=I9"`B(@HB("!I;FET("`@("`@("!#
M<F5A=&4@;VYE(&]R(&UO<F4@4$\@9FEL97,@9F]R(&$@;F5W(&QO8V%L92X@
M5V%R;FEN9SH@5&AI<UQN(@HB("`@("`@("`@("`@("!O=F5R=W)I=&5S('1H
M92!E>&ES=&EN9R!03R!F:6QE<R!O9B!T:&ES(&QO8V%L92XB"FUS9W-T<B`B
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P-@IM<V=I9"`B("!M86ME("`@
M("`@("!"=6EL9"!B:6YA<GD@34\@9FEL97,@9G)O;2!T:&4@<W!E8VEF:65D
M(%!/(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3`W"FUS9VED("(B"B(@(&UA:V4M:&5L<"`@($UA<FL@86QL(&5N=')I97,@
M:6X@=&AE(%A-3"!H96QP(&9I;&4@8F5I;F<@=7`M=&\M9&%T92!A;F1<;B(*
M(B`@("`@("`@("`@("`@<')E<&%R92!T:&4@9FEL92!F;W(@=&AE(&YE>'0@
M97AE8W5T:6]N(&]F('5P9&%T92UH96QP+B!9;W5<;B(*(B`@("`@("`@("`@
M("`@<VAO=6QD(&]N;'D@<G5N(&UA:V4M:&5L<"!!1E1%4B!U<&1A=&4M:&5L
M<"!A;F0@<F5V:7-I;F<@=&AE7&XB"B(@("`@("`@("`@("`@(&AE;'`@9FEL
M92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P,@IM<V=I
M9"`B(@HB("!M97)G92`@("`@("!-97)G92!T:&4@8W5R<F5N="!03R!F:6QE
M('=I=&@@=&AE(&-U<G)E;G0@4$\@=&5M<&QA=&4@9FEL92XB"FUS9W-T<B`B
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P,PIM<V=I9"`B("!U<&1A=&4@
M("`@("!2=6X@97AT<F%C="!A;F0@;65R9V4@<V5Q=65N="XB"FUS9W-T<B`B
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P-`IM<V=I9"`B(@HB("!U<&1A
M=&4M:&5L<"!%>'1R86-T(&%L;"!N97<@86YD(&-H86YG960@96YT<FEE<R!F
M<F]M('1H92!%;F=L:7-H(%A-3"!H96QP7&XB"B(@("`@("`@("`@("`@(&9I
M;&4@86YD(&UE<F=E('1H96T@=VET:"!T:&4@97AI<W1I;F<@;VYE<RXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P
M+FEN8SHQ,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(@)B,Q-3$[("5S(&ES
M(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M8VAE8VME9"!B96QO=RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@
M86=O*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$R-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<Q"FUS9VED("(@*'1O9&%Y
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<S
M"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S8Y"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.`IM<V=I
M9"`B(&%T("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C`T"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*
M;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$W-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"!B>71E<R!W<FET=&5N+B(*;7-G<W1R("(B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(X-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E9"!O9B`E9"!E;G1R:65S(&UA<FME9"!A<R!U<"UT;RUD871E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]N;W1I8V5?=&]P+FEN8SHT"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHS,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,C0@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(V"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S($M"(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]C;VYF:7)M7W1O<"YI;F,Z-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*
M;7-G<W1R(")6:?!H86QD<V'P9V5R\&ER(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$X"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O86=R965M96YT7W1O<"YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HU-C@@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HV,S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A
M9'D@97AI<W1S+B(*;7-G<W1R(")-87!P86X@7"(E<UPB(&5R(&[Z(/YE9V%R
M('1I;"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34W(&QI8B]";&]C:R]M
M971A<BYP:'`Z,38S(&QI8B]";&]C:R]M971A<BYP:'`Z,C,W"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S0S(&QI8B]";&]C:R]M971A<BYP:'`Z,S0Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3,P
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!C86YC96QL960@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-#(V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R97!L
M:65D('1O(&$@9G)E92]B=7-Y(')E<75E<W0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3(T"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R97!L:65D('1O('1H92!I;G9I
M=&%T:6]N('1O("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0Q-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!H87,@<V5N="!Y;W4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,C@W('!O+W1R86YS
M;&%T:6]N+G!H<#HS,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@;F]T
M('=R:71A8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S,X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@T"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(L$@
M9FEM;2!M[6[Z=&YA(&9R97-T:2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R]#;VQL96-T:6]N+G!H<#HQ,C,@<&\O=')A;G-L871I;VXN<&AP.C$S-3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-3@U"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&YO="!F;W5N9"X@4G5N("=T<F%N<VQA=&EO;B!E>'1R86-T)R!F
M:7)S="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-3`X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(')E<75E<W1S('EO=7(@
M<')E<V5N8V4@870@)7,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B5D('1I;"`E9"!A9B`E9"!S:V5Y
M='5M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HU,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(&%D
M9"!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HU,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W87)E(&]F("5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C4Q.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@=&\@<F5C96EV
M92!T:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B;W5T("5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C@Y,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B
M3F5T9F%N9V%B\VLB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C@X
M,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.#<U"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C@Y.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)R5S)R!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-34T"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z.3(Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B<E<R<@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E
M(%)E9VES=')Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5')E92]4<F5E
M+G!H<#HQ-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)R5S)R!T<F5E(')E;F1E
M<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HU-PHC+"!P:'`M9F]R;6%T"FUS9VED("(G)7,G('=A<R!A9&1E9"!T;R!T
M:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(B<E<R<@=V%S
M(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-34@861M:6XO<&5R;7,O861D8VAI;&0N
M<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(B<E<R<@=V%S(&YO="!C<F5A
M=&5D.B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M.#8@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3DY"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@
M9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,C@*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8Y,0IM<V=I
M9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HQ,S(X('!O+W1R86YS;&%T:6]N+G!H<#HQ,S,P"FUS9VED("(M+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W1I;64N<&AP.C(P"B,L(&9U>GIY"FUS9VED("(Q,B!(;W5R($9O<FUA
M="(*;7-G<W1R(")5<'!L_7-I;F=A<B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HQ.0HC+"!F=7IZ>0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B
M57!P;/US:6YG87(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM
M<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U!A9V5R+G!H<#HV.0HC+"!F=7IZ>0IM<V=I9"`B/%!R979I;W5S(@IM<V=S
M='(@(D9Y<G)I(&)L8?!S[?!A(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C,T
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(\9V5T=&5X=#X@=&%G(&YO="!C
M;&]S960@:6X@9FEL92`E<RY<;B(*(D]P96YI;F<@=&%G(&9O=6YD(&EN(&QI
M;F4@)60N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$W
M"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H
M:7,@8FQO8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,38P"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY
M,3<*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC
M<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$Q-#(*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@
M:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-S0*
M;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M
M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HY.3(*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A
M=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I
M9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4P-0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-
M24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS
M9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@
M;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R
M97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-PIM<V=I9"`B
M04T@0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C@*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M.0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@4VAO=V5R<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ,0IM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HQ.3D*;7-G:60@(D%022!)1"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!
M8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]H96QP
M+VEN9&5X+G!H<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I
M9"`B06)S8F]T=&]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C8T,`IM<V=I9"`B06-C97!T(')E<75E<W0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV
M.#$*;7-G:60@(D%C8V5P=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<U"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D
M(@IM<V=S='(@(DQY:VEL;W+P(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")!8V-O=6YT(&9R;WIE
M;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,Q
M-`HC+"!F=7IZ>0IM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R(")(YFMK86YD
M:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-#4Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-C(U"B,L(&9U>GIY"FUS9VED(")!8W1I;VYS(@IM<V=S='(@(D'P
M9V5R\"(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU-"!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$S,@HC.B!T96UP;&%T97,O<&]R=&%L
M+V%D9"YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI
M;F,Z,38*;7-G:60@(D%D9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C(Q-"!A9&UI;B]G<F]U<',N<&AP.C(Q-0IM<V=I9"`B061D($-H:6QD
M($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z.#0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-0IM<V=I
M9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(P."!A9&UI;B]G<F]U<',N<&AP
M.C(P.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<S(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z-S0*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN
M8SHY"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O
M("<E<R<B"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP
M.C4S(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3,Q"B,L('!H<"UF
M;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@)R5S)R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@
M;F5W('5S97(Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HU,CD*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-0IM
M<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4W"B,L('!H<"UF;W)M
M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C8S,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C8S-PIM<V=I9"`B061D('1H:7,@=&\@;7D@8V%L
M96YD87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@861D<F5S
M<R!B;V]K.B(*;7-G<W1R(")"YG1A(.T@;F5T9F%N9V%B\VL@*"5S*2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`HC+"!F
M=7IZ>0IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R(")"
MYG1A(.T@;F5T9F%N9V%B\VL@*"5S*2(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q
M"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"`G)7,G('1O('1H
M92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P
M(&EN9F]R;6%T:6]N.B`E(@HB<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H
M<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"`G)7,G('1O('1H92!S
M>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.CDV,@IM<V=I9"`B061D:6YG(&YE=R!F:6QE<R!T
M;R!R97!O<VET;W)Y.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]N;V%D9"YI;F,Z-`IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B
M;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T-@HC
M+"!F=7IZ>0IM<V=I9"`B061D<F5S<R(*;7-G<W1R(")396YD86YD86YE=&9A
M;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,V"FUS9VED(")!
M9&1R97-S($)O;VLB"FUS9W-T<B`B3F5T9F%N9V%B\VLB"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI
M<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T
M<B`B(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#(*;7-G:60@(D%D
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!9F=H86YI<W1A;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;&)A;FEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I
M9"`B06QI87,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R("+6;&P@<VME
M>71I(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3$X('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S
M97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO
M9W)O=7!S+G!H<#HR,3(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C,X(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z-S<*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<Q"FUS9VED(")!;&QO
M=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4R,PIM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E
M<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4
M<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-#`X"FUS9VED(")!;')E861Y(&5X:7-T
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(R"FUS
M9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#DV"FUS9VED(")!;'1E<FYA=&4@24U34"!0
M87-S=V]R9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#@X"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0HC+"!F=7IZ>0IM
M<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T<B`B3F5T9F%N
M9R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA
M=&4@=&5M<&QA=&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT
M97)N871E('1E>'0Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M
M97)I8V%N(%-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ
M,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS
M9W-T<B`BTW3F:W0@9VEL9&D@=&EL9W)E:6YT+B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G
M:60@(D%N9&]R<F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG
M;VQA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*
M;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HT.0HC+"!F=7IZ>0IM<V=I9"`B06YS=V5R
M(@IM<V=S='(@(E-V87)A\"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I
M8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@
M0F%R8G5D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T
M(&%D;6EN+W!H<'-H96QL+G!H<#HS-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO54DN<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL
M.C8*(RP@9G5Z>GD*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(D'P9V5R
M\"(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC
M871I;VX@3&ES="(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3,Y"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P
M<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX
M,C0*;7-G:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W-PHC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$T"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P
M<FEL(@IM<V=S='(@(F%P<NUL(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M-S4*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,0IM<V=I9"`B07)C:&EV92!&
M:6QE(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#`*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.CD*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(D5R
M="#^^B!V:7-S('5M(&'P(/[Z('9I;&II<B!G97)A(/YE='1A/R(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHY"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L
M971E("<E<R<@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R(")%<G0@_OH@
M=FES<R!U;2!A\"#^^B!V:6QJ:7(@=.9M82#^97-S82!M]G!P=3\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-PIM<V=I9"`B07)M96YI82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$W-@IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C
M96YS:6]N($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I
M8R!296=I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0Q-0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3<*;7-G:60@(D%S<VEG;FUE;G0@8V]L
M=6UN<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C$V-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C(T.0HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C,Q.`IM<V=I9"`B071T86-H960@:7,@
M86X@:4-A;&5N9&%R(&9I;&4@<F5P;'D@=&\@82!R97%U97-T('EO=2!S96YT
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S4*;7-G:60@(D%T
M=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C,X"FUS9VED(")!='1E
M;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HY.`IM<V=I9"`B071T
M96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B
M071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C4W-PHC+"!F=7IZ>0IM<V=I9"`B071T96YD965S(@IM<V=S='(@(E9I
M\&AE;F=I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8X"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#8*;7-G:60@
M(D%T=')I8G5T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C,X,0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R("+A
M9_IS="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4Y"B,L(&9U>GIY"FUS9VED(")!=7-T<FEA(@IM<V=S='(@
M(N%G^G-T(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C$V
M.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O
M97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B
M075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z
M,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N
M(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB
M9G1P('-W:71C:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q
M=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S
M97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R
M("(B"B)6:7-T=6X@=7!P:V%S='-I;G,@;6ES=/-K<W0N($YE=/YJ\VYN:6YN
M(&MO;2!M9?`@969T:7)F87)A;F1I('9I;&QU.B`E<R(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3@R"B,L('!H<"UF;W)M870*;7-G:60@
M(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C0P"B,L('!H
M<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U
M<V5R("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A
M;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER
M960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.#D*(RP@9G5Z>GD*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G
M<W1R(")%;F1U<G;M<W5N(&UI<VAE<'!A\&ES="XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E
M<R(*;7-G<W1R(")%;F1U<G;M<W5N(&UI<VAE<'!A\&ES="XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT
M:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<V.`IM<V=I9"`B075T
M:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.#,*(RP@9G5Z>GD*;7-G
M:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(E1I;'3F:V%R(&YE=&9A
M;F=A8N9K=7(Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HV,30*;7-G:60@(D%W86ET:6YG(%)E<W!O;G-E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X
M8W5S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K
M97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N
M86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D)A;'1I8R`H
M25-/+3@X-3DM,3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A
M;F=L861E<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D
M;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8P
M.`IM<V=I9"`B0F%R92(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D
M:7)E8W1O<GD@)R5S)R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM<V=I
M9"`B0F%S96QI;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L
M87)U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(D)E;&EZ92(*
M;7-G<W1R(")3=.9R\"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I
M<G1H9&%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#
M;VQL96-T:6]N+G!H<#HS,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@
M7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHX.0IM<V=I
M9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.`HC+"!F=7IZ>0IM<V=I9"`B0F]L9"(*;7-G<W1R(")-96=I;FWA;"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$X.`IM<V=I9"`B0F]O:VUA<FMS(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(D)O<F1E<B(*;7-G<W1R(")-
M]G!P=7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(Q"B,L(&9U>GIY"FUS9VED(")";W)D97)S(@IM<V=S='(@(DWV<'!U<B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")"
M;W1H(@IM<V=S='(@(D+F\&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W1S=V%N
M82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S4*(RP@9G5Z>GD*;7-G:60@(D)O='1O;2(*;7-G
M<W1R(")"YO!I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E
M<G)I=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<G5N96D@
M1&%R=7-S86QA;2(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D)U:6QD:6YG($U/(&9I;&5S(&9O
M<B!M;V1U;&4@)7,N+BXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C8W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")"=6EL9&EN9R!L;V-A;&4@
M)7,N+BX@(@IM<V=S='(@(D)Y9V=I(&[Z(&QO8V%L92`E<R`N+BXB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"=6QL
M971E9"!,:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI
M;F$@1F%S;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U;F1I
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S,*
M;7-G:60@(D--4R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C<R"FUS9VED(")#4D,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-2
M3"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I
M9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4V(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ-#4*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3,*(RP@9G5Z>GD*
M;7-G:60@(D-A;&TB"FUS9W-T<B`B2.9T=&$@=FGP(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*
M;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@
M(D-A;65R;V]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M
M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,S4@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#86YA9&$B"FUS9W-T<B`B(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$T('1E;7!L871E<R]A
M9&UI;B]U<V5R+V-L96%R+FEN8SHQ-PHC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F4N:6YC.C$W"FUS9VED(")#86YC96PB"FUS9W-T<B`B2.9T=&$@
M=FGP(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G
M:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C(U-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I
M9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP
M.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE
M)R!P87)A;65T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,C4R"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO
M=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ,3(@9G)A;65W;W)K+T1A=&%4<F5E
M+T1A=&%4<F5E+W-Q;"YP:'`Z-3@V"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HU,3,*;7-G
M:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P
M;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O
M<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(D-A;FYO="!R;W5T92!M97-S
M86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`HC+"!F=7IZ
M>0IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R(")686QS=&EL;&EN9V%R(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP"FUS9VED(")#871E9V]R:65S(&%N
M9"!,86)E;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA
M;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T
M"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@
M(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C
M:6YG.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C<T"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G:60@(D-E;G1E<B(*;7-G<W1R
M(")"^F$@=&EL(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N
M(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3<Y"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Y
M.0IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B0V5R
M=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"B,L
M(&9U>GIY"FUS9VED(")#:&%D(@IM<V=S='(@(D5F;FES_G+A\'5R(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU.38*
M(RP@9G5Z>GD*;7-G:60@(D-H86ER(%!E<G-O;B(*;7-G<W1R(")097)S\VYU
M;&5G="(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3<*;7-G:60@(D-H86YG92(*;7-G
M<W1R(")"<F5Y=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*(RP@
M9G5Z>GD*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T
M:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO
M=7(@(@HB96UA:6QS+B(*;7-G<W1R("(B"B)(Z7(@9V5T=7(@_OH@8G)E>71T
M(/YV[2!H=F'P82!N869N+"!N971F86YG(&]G('-K97ET:7-B;W1N(&ME;75R
M(&9R86T@[2`B"B)S:V5Y='5M(/[M;G5M+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*(RP@9G5Z>GD*;7-G
M:60@(D-H87(B"FUS9W-T<B`B0G)E>71A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C
M7VL@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O8V]N9FER;5]T;W`N:6YC.C$S"FUS9VED(")#:&5C:R!T:&4@8F]X(&9O
M<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI
M<R!T:6UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EL92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EN82(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0VAI;F5S92!3
M:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@Q"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8X"B,L(&9U>GIY
M"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R(")396UJ82!N_71T
M('-K97ET:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-#4R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-C(V"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@86X@86-T
M:6]N.B(*;7-G<W1R(")696QD=2!A\&=E<O`Z(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(X.`IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A
M=&5S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S
M='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z-C$S"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN
M:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z.#4U"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%N:6YG
M('5P(%!/(&9I;&5S(&9O<B!M;V1U;&4@)7,N+BXB"FUS9W-T<B`B(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C@V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;&5A;FEN9R!U<"!L;V-A;&4@)7,N+BX@(@IM<V=S='(@(DAR96EN<V$@=&EL
M(.T@;&]C86QE("5S("XN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")#;&5A<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED
M(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@
M(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]C;&5A<BYI;F,Z,38*;7-G:60@(D-L96%R('5S97(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*
M;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B0VQE87)I
M;F<@3&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M;F]T:6-E7V)O='1O;2YI;F,Z-@IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3@S"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0R"FUS9VED(")#
M;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,30*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0HC
M+"!F=7IZ>0IM<V=I9"`B0VQO=61Y(@IM<V=S='(@(D%F<FET(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHT"B,L(&9U>GIY
M"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(DQO:V$@;?9P<'4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(X"B,L(&9U>GIY"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G
M<W1R("),;VMA(&WV<'!U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO
M8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HR.3<*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C(Y.`HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#<R('-E
M<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3$*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3(*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C@*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-CD*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#4*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#8*;7-G:60@(D-O;&]R
M(%!I8VME<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.#4P"B,L(&9U>GIY"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S
M='(@(E9E;&1U(&'P9V5R\#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-@IM<V=I9"`B0V]L=6UN
M('1I=&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C@S"B,L(&9U>GIY"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B4V5M:F$B
M"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*;7-G:60@(D-O;6UA;F0B"FUS
M9W-T<B`B(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM
M86YD(%-H96QL(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HS
M.`IM<V=I9"`B0V]M;6%N9"!O<'1I;VYS.B(*;7-G<W1R("(B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z.3<*;7-G:60@(D-O;6UA;F1S.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HS.3D*;7-G:60@
M(D-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P
M,#`*;7-G:60@(D-O;6UI='1I;F<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38V"FUS9VED(")#;VUM;VX@3F%M
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`HC+"!F=7IZ>0IM<V=I9"`B0V]M
M;W)O<R(*;7-G<W1R(")396UJ82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR,SD*(RP@9G5Z>GD*;7-G:60@(D-O;7!A;GDB
M"FUS9W-T<B`B069R:70B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C8Y-PHC+"!F=7IZ>0IM<V=I9"`B0V]M<&QE=&5D
M(@IM<V=S='(@(E-E;6IA(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;VUP;W-E($UE<W-A9V4@*"5S*2(*;7-G<W1R(")396UJ82!S:V5Y=&D@*"5S
M*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0HC+"!F=7IZ>0IM<V=I
M9"`B0V]M<'5T97)S(@IM<V=S='(@(E-E;6IA(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-#<*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z.#D*;7-G:60@(D-O;F9I9W5R871I;VX@
M1&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$S-`IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.CDY"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,W"B,L(&9U>GIY"FUS
M9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(DQY:VEL;W+P(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HU,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM
M<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS
M9W-T<B`B16YD=7)V[7-U;B!M:7-H97!P8?!I<W0N(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B
M0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R(")%;F1U<G;M<W5N(&UI<VAE
M<'!A\&ES="XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW
M-S8*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-S<X"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@
M<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H
M)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M-S8R"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z-3,*(RP@9G5Z>GD*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(").
M971F86YG:?`@7"(E<UPB('9A<B!BYG1T(.T@;F5T9F%N9V%B\VMI;F$B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C`*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;VYT96YT<R!O9B`G)7,G(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C(Y"FUS9VED(")#;VYT:6YU92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"B,L(&9U>GIY"FUS9VED
M(")#;V]K:64B"FUS9W-T<B`B4V5M:F$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB
M"FUS9W-T<B`B069R:70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,V"B,L(&9U>GIY"FUS9VED(")#;W!Y('-E;&5C=&EO
M;B(*;7-G<W1R(")696QD=2!A\&=E<O`Z(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C$P.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O<'EI;F<@
M)7,@=&\@)7,B"FUS9W-T<B`B5&5N9VIA<W0@)7,B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#;W-T82!2:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@
M(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y
M<'0@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3`S,`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(%!'
M4"!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(M[Z(.%T="`Q(&[]='0@<VME>71I
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,SDS"FUS
M9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<*
M;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C$X,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O
M;G1A8W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z-S`*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R
M=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C$U-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@)R5S)R!U<VEN9R!&5%`Z("5S
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#@W"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;W!Y("5S('1O("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,S(Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HV.#$@<&\O=')A;G-L871I;VXN<&AP.C$P-S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!L;V-A;&4@9&ER
M96-T;W)Y(&9O<B!L;V-A;&4@)7,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,#(*;7-G:60@(D-O=6QD(&YO="!D
M96-R>7!T(%!'4"!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4R,@IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y
M<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0U"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM
M<V=S='(@(D=A="!E:VMI(&5Y='0@<VME>71U;2!F<N$@)7,Z("5S(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-34*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(D=A="!E:VMI(&5Y='0@
M<VME>71U;2!F<N$@)7,Z("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D
M96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@)R5S)RXB"FUS9W-T<B`B1V%T
M(&5K:VD@97ET="!S:V5Y='5M(&9RX2`E<SH@)7,B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HY,S4*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE
M(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,@IM
M<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HT.3(*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T
M92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#4*;7-G:60@(D-O
M=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I
M;VX@;&ES=',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO
M860@<W1R871E9WD@)R5S)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER("<E<R<N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<P-0IM<V=I9"`B0V]U
M;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S0T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!O<&5N("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("<E<R<@
M9F]R('=R:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N
M86YC92]-86EN=&5N86YC92YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@)R5S)RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR,S@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B
M"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S
M=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N
M;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.0IM<V=I9"`B
M0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W,PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E
M<W,@8F]O:RX@)7,B"FUS9W-T<B`B1V%T(&5K:VD@97ET="!S:V5Y='5M(&9R
MX2`E<SH@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C0X,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,V
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T
M<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"FUS9VED(")#;W5L9"!N;W0@<F5T
M<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!R979E
M<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B`G
M)7,G+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(D-O=6QD
M(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@=&\Z("<E<R<N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I
M;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB
M;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M
M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HX,`IM<V=I9"`B0V]U;&0@
M;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@=6YL:6YK("<E<R<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$X"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HS.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@)R5S)SH@)7,B"FUS
M9W-T<B`B1V%T(&5K:VD@97ET="!S:V5Y='5M(&9RX2`E<SH@)7,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4V"FUS9VED(")#;W5L9&XG="!F:6YD
M('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I
M<R!O<&5N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&1N
M)W0@9VEV92!U<V5R("<E<R<@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H
M92!F;VQD97(@)R5S)SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30R-`HC+"!F=7IZ>0IM<V=I9"`B0V]U;G1E9"!T97AT
M(@IM<V=S='(@(DQE:?!RZ71T=7(@=&5X=&DB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8W"FUS9VED(")#
M;W5R<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3<*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,0IM<V=I9"`B0W)E871E(@IM
M<V=S='(@(D+Z82!T:6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*(RP@9G5Z>GD*;7-G:60@(D-R96%T
M92!A(&QI;FLB"FUS9W-T<B`B0OIA('1I;"(*"B,Z('1E;7!L871E<R]P<F5F
M<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*(RP@9G5Z>GD*;7-G:60@(D-R96%T
M92!A(&YE=R!O;F4B"FUS9W-T<B`B0OIA('1I;"!N_6IA(&WV<'!U("AR=7-L
M86OV<F9U*2!U;F1I<B!E>61D('-K97ET:2(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")#<F5A
M=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B0OIA('1I;"!M]G!P=2(*"B,Z(&%D
M;6EN+W!E<FUS+V5D:70N<&AP.C$S-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C(Q-`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,T"FUS9VED(")#
M<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*(RP@
M9G5Z>GD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B0OIA('1I;"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C(V"FUS9VED(")#=7)R96YT(%!H87-E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`HC
M+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(DQE:?!RZ71T
M=7(@=&5X=&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E
M;G0@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C,W"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S
M='(@(E-T:6QL82!A\&=E<O!I<B!S96T@97)U(&9R86UK=N9M9&%R(/YE9V%R
M(/[Z('1E;F=I<W0@)7,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X
M"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#(*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI8R`H
M5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X-`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,C,@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC
M92YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(D1A:6QY(@IM<V=S='(@(MIT;&ET
M(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"
M<F]W<V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y
M-PIM<V=I9"`B1&%T92(*;7-G<W1R(")$86=S(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(D1A=&4@
M4F5C96EV960B"FUS9W-T<B`B3?-T=&5K:?`@_F%N;CHB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#$Q"FUS9VED(")$871E('-E;&5C=&EO;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q
M"B,L(&9U>GIY"FUS9VED(")$87DB"FUS9W-T<B`B;6'M(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,U"B,L
M(&9U>GIY"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R(")%>?!A(&WV
M<'!U*&TI(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,X-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(F1E<V5M8F5R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHQ-@HC+"!F=7IZ>0IM<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@
M(F1E<V5M8F5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HV.#4*(RP@9G5Z>GD*;7-G:60@(D1E8VQI;F5D(@IM<V=S
M='(@(D5Y='0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R969S
M+G!H<#HQ,3$*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B17GP
M82(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C0W"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C@Q"B,L(&9U>GIY"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(DYO
M=&$@<VKA;&9G969I\"!G:6QD:2(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])
M9&5N=&ET>2YP:'`Z.3$*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T
M<B`B4VKA;&9G969I\"!K96YN:6UA<FLB"@HC.B!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HQ,3D@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ.38*;7-G
M:60@(D1E9F%U;'0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ.3<*;7-G:60@(D1E9F%U;'0@<&5R
M;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,S"B,L(&9U>GIY"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R(")3:VEL
M9W)E:6YI;F<@X2!S[75R96=L=2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C0S"B,L(&9U>GIY"FUS9VED(")$96QE
M9V%T92!P;W-I=&EO;B(*;7-G<W1R(")396UJ82!N_71T('-K97ET:2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-CDS
M"B,L(&9U>GIY"FUS9VED(")$96QE9V%T960B"FUS9W-T<B`B17ET="(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z-S(@861M:6XO<&5R;7,O9&5L971E+G!H<#HT
M-B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,CDU(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,S$U"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S,R('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHW,"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,PHC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.3D@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D
M96QE=&4N:6YC.C$S"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`B17GP82(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,3@Y(&%D;6EN+V=R;W5P<RYP:'`Z,C$W"B,L(&9U>GIY"FUS
M9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B17GP82(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z-C,@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HX-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB
M"FUS9W-T<B`B17GP82!S:V5Y='5M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.3,*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!A
M;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B17ED9"!S:V5Y=&DB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W
M"B,L(&9U>GIY"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R(")%>?!A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV,PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R(")%
M>?!A(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T
M92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HU,"!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C,Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R
M;6ES<VEO;G,@9F]R("<E<R<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HS,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E('!E<FUI<W-I;VYS(&9O<B`G)7,G(&%N9"!A;GD@<W5B+7!E<FUI<W-I
M;VYS/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@
M<F]W(@IM<V=S='(@(D5Y\&$B"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E
M:61E;G1I='DN:6YC.C$U"B,L(&9U>GIY"FUS9VED(")$96QE=&4@<V5L96-T
M960@:61E;G1I='DB"FUS9W-T<B`B5F5L9'4@:V5N;FDB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*(RP@
M9G5Z>GD*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T
M<B`B4W1I;&QA(&[Z=F5R86YD:2!T[6UA8F5L=&DN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"B,L(&9U
M>GIY"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@(E-T
M:6QL82!N^G9E<F%N9&D@=.UM86)E;'1I+B(*"B,Z(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-#@*;7-G:60@(D1E;&5T92!T:&ES('!E<FUI<W-I;VX@86YD
M(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C,U"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T
M960@<V5T=7`@=7!G<F%D92!S8W)I<'0@)R5S)RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C(*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M.30*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C(P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(U,@HC+"!F=7IZ>0IM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G
M<W1R(")%>?!A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C8T,@IM<V=I9"`B1&5N>2!R97%U97-T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#<Q"FUS
M9VED(")$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA=&EO;B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,3`@<V5R=FEC
M97,O<')O8FQE;2YP:'`Z,3$T('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-`IM
M<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU-C4@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*(RP@9G5Z>GD*;7-G:60@
M(D1E<V-R:7!T:6]N(@IM<V=S='(@(E9A;&MO<W1I<B!N;W1A;F1A(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.34*;7-G:60@(D1E=&%I;',@
M*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3D*(RP@9G5Z>GD*;7-G:60@(D1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(B(*(MYE='1A('-K97ET:2!H969U<B!V97)I\"!S96YT('1I
M;"!K97)F:7-U;7-J\VYA<B!S96T@=&EL:WEN;FEN9R!U;2!R=7-L</-S="`B
M"B(H4U!!32DN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y-0IM
M<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,34*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(Y,@IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L
M87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,3DT"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS
M9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED
M(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HS.0HC+"!F=7IZ>0IM<V=I9"`B1&ER96-T;W)Y
M(@IM<V=S='(@(E+V\'5N87+A='0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C4V"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B1&ES<&QA
M>2!/<'1I;VYS(@IM<V=S='(@(MIT;&ET<W-T:6QL:6YG87(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C@S"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4
M048I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,C$*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(MIT
M;&ET(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,`IM<V=I
M9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E
M<FUS+V1E;&5T92YP:'`Z-#8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HS,34*(RP@9G5Z>GD*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B
M16YD=7)V96MJ82(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-`IM
M<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3D@
M=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3D*;7-G:60@(D1O97,@=&AE
M(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C
M:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B
M1&]M:6YI8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI
M8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C@S-0IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B
M4^9K:F$@>69I<B#A('9I;FYU<W3V\"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C@S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N
M;&]A9"`E<R(*;7-G<W1R(")3YFMJ82`E<R!Y9FER(.$@=FEN;G5S=/;P(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-0IM<V=I9"`B1&]W;FQO860@
M9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B
M1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HS.3D*(RP@9G5Z>GD*;7-G:60@(D4M
M36%I;"(*;7-G<W1R(")0\W-T;6%P<&$B"@HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS
M9VED(")%4E(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(Y
M-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY
M,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR,@IM<V=I9"`B161I="(*;7-G<W1R
M(")"<F5Y=&$B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P
M('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C(*;7-G:60@(D5D:70@0FQO
M8VLB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.#@@861M:6XO
M9W)O=7!S+G!H<#HR,38*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HV,B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C@V"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM
M<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D
M:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,C`T(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,C@P"B,L('!H<"UF;W)M870*;7-G:60@
M(D5D:70@<&5R;6ES<VEO;G,@9F]R("<E<R<B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,U"B,L(&9U>GIY"FUS9VED(")%9'5C871I
M;VXB"FUS9W-T<B`B0?!G97+P(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%;"!386QV861O<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#D*;7-G:60@(D5M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@V.0IM<V=I9"`B16UA:6PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C0P"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(DYE=&9A
M;F<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38S"B,L(&9U>GIY
M"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`B
M3F5T9F%N9R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#D*;7-G
M:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR.#`*(RP@9G5Z
M>GD*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R(")686QS=&EL;&EN9V%R(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`Q"B,L(&9U>GIY"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R("+!
M<NWP86YD:2!S:V5Y=&DB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C@X"B,L(&9U>GIY"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@
M(E3F;6$@<G5S;&%K]G)F=2(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O
M<F1S+G!H<#HQ,3,*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M
M<R(*;7-G<W1R(")4YFUA(')U<VQA:_9R9G5M]G!P=2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,S(*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@
M:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#<*;7-G:60@(D5N86)L
M92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#0X"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-34S
M"FUS9VED(")%;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C8P-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U"FUS9VED
M(")%;F0@>65A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$Q"FUS9VED
M("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL
M(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O
M<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),
M(&AE<F4B"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q-C,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B16YT<FEE<SH@)60@=&]T86PL("5D('5P
M+71O+61A=&4L("5D(&YE=RP@)60@8VAA;F=E9"P@)60@=6YK;F]W;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDY(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-0HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,V('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP
M:'`Z-SD*;7-G:60@(D5R<F]R(@IM<V=S='(@(E9I;&QA(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ.34*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HR-S@*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HS-#<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@<V5N9&EN9R!R97!L>3H@)7,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@)R5S)RXB"FUS9W-T<B`B
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0Q,R!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-3(R('!O+W1R86YS;&%T:6]N+G!H<#HQ,S<W"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HQ-#,X('!O+W1R86YS;&%T:6]N+G!H<#HQ-3`Q"B,L(&9U>GIY
M"FUS9VED(")%<G)O<CH@(@IM<V=S='(@(E9I;&QA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM
M<V=I9"`B17-T;VYI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%
M=&AI;W!I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(Y"FUS9VED(")%=F5R>2`Q-2!M
M:6YU=&5S(@IM<V=S='(@(L$@:V]R=&5R<R!F<F5S=&DB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S<Y"B,L(&9U>GIY"FUS9VED(")%=F5R>2`R(&UI
M;G5T97,B"FUS9W-T<B`BP2!F:6UM(&WM;OIT;F$@9G)E<W1I(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,R-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S<W"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(L$@,S`@<V5K
M+B!F<F5S=&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(X(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.#`*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*
M;7-G<W1R("+!(&9I;6T@;>UN^G1N82!F<F5S=&DB"@HC.B!F<F%M97=O<FLO
M36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P"B,L(&9U>GIY"FUS9VED
M(")%=F5R>2!,;V=I;B(*;7-G<W1R("+!(&WM;OIT=2!F<F5S=&DB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,P"FUS9VED(")%=F5R>2!H86QF(&AO
M=7(B"FUS9W-T<B`BP2!HX6QF=.UM82!F<F5S=&DB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S(W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S@*;7-G
M:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R("+!(&WM;OIT=2!F<F5S=&DB"@HC
M.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR.`IM<V=I9"`B17AA;7!L
M92!V86QU97,Z(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX
M,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R
M.`IM<V=I9"`B17AE8W5T92(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,CDY('!O+W1R86YS;&%T:6]N+G!H<#HS,C`@<&\O=')A;G-L871I
M;VXN<&AP.C,V,@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#0Q('!O+W1R86YS
M;&%T:6]N+G!H<#HU-#$@<&\O=')A;G-L871I;VXN<&AP.C8P,0HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-S`R('!O+W1R86YS;&%T:6]N+G!H<#HW,S<@<&\O
M=')A;G-L871I;VXN<&AP.C<Y.`HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#<U
M('!O+W1R86YS;&%T:6]N+G!H<#HY.30@<&\O=')A;G-L871I;VXN<&AP.C$P
M,38*;7-G:60@(D5X96-U=&EN9SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,SDT"B,L(&9U>GIY"FUS9VED(")%
M>'!A;F0B"FUS9W-T<B`B3W!N82!A;&QA<B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO<VED96)A<BYI;F,Z,S$*(RP@9G5Z>GD*;7-G:60@(D5X<&%N9"!3:61E
M8F%R(@IM<V=S='(@(D]P;F$@;?9P<'4B"@HC.B!F<F%M97=O<FLO4U%,+U-1
M3"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM
M<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R
M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HS.3@*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-@IM<V=I9"`B17AP
M;VYE;G0B"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C(W,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%>'1R86-T:6YG(&9R;VT@)7,N+BX@(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*;7-G:60@(D944"!U<&QO860@
M;V8@<V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+W-Q;"YP:'`Z,C$V"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E
M;F-E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HV,`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V
M97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H
M<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV,#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M-C`X"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L
M+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN
M96-T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C8T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T
M;R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$V"FUS9VED(")&86ER(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&87)O92!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR,S@*;7-G:60@
M(D9A=&%L($5R<F]R.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W
M-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*
M;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(F9E8G+Z87(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(Q.`IM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3DX"FUS9VED(")&
M965L<R!L:6ME.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$X"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0*;7-G:60@(D9I96QD(&UA=')I
M>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-`HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M
M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8T"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,T,PHC+"!F=7IZ>0IM<V=I9"`B1FEL92!-
M86YA9V5R(@IM<V=S='(@(E-K<N%R;F%F;B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C@U"B,L(&9U>GIY"FUS9VED(")&:6QE($YA;64B"FUS9W-T
M<B`B4VMRX7)N869N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDY
M.0HC+"!F=7IZ>0IM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B96YG
M:6X@<F5G;&$@=F%L:6XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#DQ"B,L(&9U>GIY"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R(")296ET
M=7(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-3,*;7-G
M:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#8*;7-G:60@(D9I;'1E<G,B
M"FUS9W-T<B`B4^UU<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(D9I
M;FQA;F0B"FUS9W-T<B`B1FEN;F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,3<Q"B,L(&9U>GIY"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(D9Y<G-T
M82!S[?!A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M
M;V]N+G!H<#HW-@HC+"!F=7IZ>0IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G
M<W1R(")&>7)S=&$@<^WP82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,SD*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C$T
M"FUS9VED(")&;&EP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$Y"FUS9VED(")&;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HQ-3@@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@
M97AI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D
M;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,S,@IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<X"FUS9VED("(B
M"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C
M87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU
M;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.34*;7-G:60@
M(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,SDY"B,L(&9U>GIY"FUS9VED(")&;W)M<R(*
M;7-G<W1R(")&<N$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G
M:60@(D9O<G1U;F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U
M;F5S(#(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,Y,`HC+"!F=7IZ>0IM<V=I9"`B1F]R=6US(@IM<V=S='(@(DWV<'!U<B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#8*(RP@9G5Z>GD*;7-G
M:60@(D9O<G=A<F1S(@IM<V=S='(@(L%F<F%M<V5N9&$B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,30U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")&;W5N9"!A
M<'!L:6-A=&EO;G,Z("5S(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HQ-#4R"FUS9VED(")&;W5N9"!D:7)E8W1O<FEE<SHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M,`HC+"!F=7IZ>0IM<V=I9"`B1G(B"FUS9W-T<B`B1G+A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PHC+"!F
M=7IZ>0IM<V=I9"`B1G)A;65S(@IM<V=S='(@(DYA9FXB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S
M"B,L(&9U>GIY"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B2.9T=&$@=FGP(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N
M8V4L($UE=')O<&]L:71A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0Q-PHC+"!F=7IZ>0IM<V=I
M9"`B1G)E92]"=7-Y($EN9F]R;6%T:6]N(@IM<V=S='(@(E5P<&S]<VEN9V%R
M(&YE=/YJ\VYS(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HT,C<*;7-G:60@(D9R964O0G5S>2!297!L>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C0R,@IM<V=I9"`B1G)E92]"=7-Y(%)E<75E<W0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HR
M-S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HS-#$*;7-G:60@(D9R964O0G5S>2!297%U97-T(%)E<W!O;G-E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@
M5&5R<FET;W)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R(")&
M<N$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$U"B,L(&9U
M>GIY"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B1G+A(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*(RP@9G5Z>GD*;7-G:60@(D9U
M;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B4VMI;&=R96EN:6YG(.$@<^UU<F5G
M;'4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#(@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$X,0IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,SD*(RP@9G5Z>GD*;7-G:60@
M(D9U;&P@3F%M92(*;7-G<W1R(").869N(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C8U-PIM<V=I9"`B1G5Z>GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM
M<V=I9"`B1V%B;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL
M97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*
M;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@
M(D=A;6)I82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R
M871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O
M;F9I9RYH=&UL.C$P"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R("(B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#<Y"B,L('!H<"UF;W)M870*;7-G
M:60@(D=E;F5R871I;F<@<W1A='5S(&9O<B!M;V1U;&4@)7,N+BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@(B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,S<Q"FUS9VED(")'971O<'0@17)R;W(Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S4*(RP@9G5Z>GD*;7-G
M:60@(D=I=F5N($YA;64B"FUS9W-T<B`B4VMRX7)N869N(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V%P<"YI;F,Z,3(*;7-G:60@(D=O(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*(RP@9G5Z>GD*
M;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B3&5I=&$@[2!S:V5Y='5M
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R
M,`IM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS
M9VED(")'<F5E8V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#4*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-`HC+"!F=7IZ>0IM<V=I9"`B1W)E;F%D82(*;7-G<W1R(")%9FYI<_YR
MX?!U<B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<P"FUS9VED(")'<F]U<"!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`N<&AP.C4X"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE
M;7!T>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HR,#$@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-S<*;7-G:60@(D=R;W5P
M('!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N
M<&AP.C$W-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U,`HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS."!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*
M;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G
M:60@(D=U86TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U871E
M;6%L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.CDR"FUS9VED(")'=65R;G-E>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M
M<R]E9&ET+G!H<#HQ,C<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR
M,#4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E
M<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I
M="YP:'`Z,3(X(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C`V"FUS
M9VED(")'=65S="!P97)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#`W"FUS9VED(")'=65S=&)O;VLB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B1W5I;F5A(@IM<V=S
M='(@(FKZ;NTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,S,0IM<V=I9"`B2$@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G
M:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED(")(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU
M;6X@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T
M86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P
M+G!H<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAA:71I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C,Y.0IM
M<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(DAA>F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S8*;7-G:60@(DAE861E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$
M;VYA;&0@27-L86YD<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X-@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3<X(&9R86UE=V]R:R](;W)D92](
M;W)D92](96QP+G!H<#HQ.#4*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z
M,3<@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G:60@(DAE;'`B"FUS
M9W-T<B`B2&KA;'`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<V"B,L(&9U>GIY
M"FUS9VED(")(96QP97(B"FUS9W-T<B`B2&KA;'`B"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z.34*;7-G:60@(B(*(DAE;'!E<B!A<'!L:6-A=&EO;B!T;R!C
M<F5A=&4@86YD(&UA:6YT86EN('1R86YS;&%T:6]N<R!F;W(@=&AE($AO<F1E
M7&XB"B)F<F%M97=O<FL@86YD(&ET<R!A<'!L:6-A=&EO;G,N7&XB"B)&;W(@
M86X@:6YT<F]D=6-T:6]N(')E860@=&AE(&9I;&4@4D5!1$U%(&EN('1H:7,@
M9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O='-V:6YF;RYI;F,Z,3<@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,3<*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL
M93HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C4*;7-G:60@(DAI9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAI<W1O<GDO2&ES=&]R>2YP:'`Z,S(Q"FUS9VED(")(:7-T;W)Y(&5N
M=')Y(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M
M;6]N+6AE861E<BYI;F,Z-`IM<V=I9"`B2&]?;64B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T
M92DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M-#(V"FUS9VED(")(;VUE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0HC+"!F=7IZ>0IM<V=I9"`B2&]M
M92!!9&1R97-S(@IM<V=S='(@(E-E;F1A;F1A;F5T9F%N9R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*(RP@9G5Z>GD*
M;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B5.UM86)E;'1I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-C(*;7-G:60@(DAO<F1E(@IM<V=S='(@(B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HQ,S(Y"FUS9VED(")(;W)D92!T<F%N<VQA
M=&EO;B!G96YE<F%T;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HT,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G
M92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C(W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S
M<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT,3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD
M(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,C`X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM
M<V=S='(@(DUA<'!A;B!<(B5S7"(@=F%R(&5N9'5R;F5F;F0@7"(E<UPB+B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$U-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!S
M>6YC:')O;FES960@)7,@7"(E<UPB(@IM<V=S='(@(EPB)7-<(B!V87(@9V5R
M\"!V:7)K(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR,C,*;7-G
M:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I
M<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#@Q"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@
M=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3(P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#4R"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE
M=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q-3$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES
M92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,3(X,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS,3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E
M<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I
M9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")(;W<@
M9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME
M('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHR.`IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A
M<F4@=&AE<F4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O
M=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C(X"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(Q"FUS9VED
M(")(=6UI9&ET>3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)S<6PN<&AP.C(S,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB
M;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)S<6PN<&AP.C(Y,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA
M:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-SD@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)S<6PN<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0
M(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S(P"B,L(&9U>GIY"FUS
M9VED("))4"!!9&1R97-S(@IM<V=S='(@(E-E;F1A;F1A;F5T9F%N9R(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0
M($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S
M<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDT"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8V"FUS9VED("))8V]N<R!/;FQY(@IM
M<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,V-PIM<V=I9"`B26-O;G,@=VET:"!T97AT
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#`*;7-G
M:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B2V5N;FEN869N.B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4X-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L
M>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#4*;7-G:60@(B(*(DEF('EO
M=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R
M+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O
M9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$U.`IM<V=I9"`B(@HB268@
M>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@
M>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y
M;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA
M9V4@4')E=FEE=SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R
M>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V
M-0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z,3`*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU
M-R!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z-S,*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HW,#$*;7-G:60@(DEN(%!R;V-E<W,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,P"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S0*;7-G:60@
M(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*
M(RP@9G5Z>GD*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S
M<W=O<F0N(@IM<V=S='(@(E-LX?!U(&EN;B!N;W1A;F1A;F%F;B!O9R!L>6ML
M:6]R\"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED
M("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N
M(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN
M8W)E87-E($EN9&5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@
M(DEN9&EA(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$T
M,2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I
M9'5A;"!5<V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*(RP@9G5Z>GD*
M;7-G:60@(DEN9&]N97-I82(*;7-G<W1R(")E;F=I;FXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"B,L(&9U>GIY"FUS
M9VED("));F9O(@IM<V=S='(@(DAU;F1S82(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR-#,*(RP@9G5Z>GD*;7-G:60@(DEN9F]R;6%T:6]N(@IM
M<V=S='(@(E5P<&S]<VEN9V%R(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C4X
M,@HC+"!P:'`M9F]R;6%T"FUS9VED("));FET:6%L:7II;F<@;6]D=6QE("5S
M+BXN("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!#7V]L=6UN
M($%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`HC+"!F=7IZ>0IM<V=I9"`B
M26YS97)T($EM86=E(@IM<V=S='(@(E-K97ET:2!S96T@8OII\"!E<B!A\"!S
M=F%R82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("))
M;G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED("));G-E
M<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("))
M;G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F
M;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@
M(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV,`IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@
M=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS
M97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8X"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E
M('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R.0IM<V=I
M9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R
M96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*;7-G
M:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*(RP@9G5Z
M>GD*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R(")-\W1T96MI
M\"!F>7)I<CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDP"B,L(&9U>GIY"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS9W-T
M<B`B4VME>71I('-E;2!B^FGP(&5R(&'P('-V87)A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED
M("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM
M<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M.0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS
M9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C(P"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D
M(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*
M;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B
M26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED("));G-U
M9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L
M:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B26YS=69F:6-I96YT(&-R961I
M="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W
M-0IM<V=I9"`B26YT96=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,3,S"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HR.#,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HS-3(*;7-G:60@(DEN=F%L:60@06-T:6]N('-E;&5C=&5D(&9O<B!T
M:&ES(&-O;7!O;F5N="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED
M(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@8F%T8V@@240N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#<@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R.3<*
M;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M.0IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HX
M,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#`*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,C(P"FUS
M9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I
M9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED("))
M;G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G
M:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-#,*;7-G:60@(DEN=F%L
M:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B
M26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@)R5S)R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P-#,@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,C(P"FUS9VED("));G9A;&ED('-H87)E(&]B:F5C
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E
M<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M,C(*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*
M;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,`HC+"!F=7IZ>0IM<V=I9"`B27)E;&%N9"(*;7-G<W1R(")%9FYI<_YR
MX?!U<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED
M("))<VQE(&]F($UA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B27-O;&%T960@5"U3=&]R
M;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M,C4*;7-G:60@(DES<W5E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DET86QY(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<T"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B
M2F%N=6%R>2(*;7-G<W1R(")J86[Z87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@
M(DIA<&%N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W
M"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,X,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B:OIL[2(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HS-SD*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S
M='(@(FKZ;NTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM
M<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*
M=7-T:69Y($QE9G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@
M4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS
M=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR-#8*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R
M;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.
M97=B:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C,Y-PIM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0P,`IM<V=I9"`B2V5Y
M($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C,Y.`IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HS.3<*;7-G:60@
M(DME>2!4>7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DX"B,L(&9U>GIY"FUS9VED(")+97D@57-A9V4B"FUS
M9W-T<B`B4VME>71I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-S(V"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI
M8R!K97ES97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*
M;7-G:60@(DMI<FEB871I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I
M9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@4F5P=6)L:6,@
M;V8B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G
M:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*
M;7-G:60@(DMU=V%I="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@
M(DMY<F=Y>G-T86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M
M96YU+FEN8SHX"B,L(&9U>GIY"FUS9VED("),85]Y;W5T(@IM<V=S='(@(D%F
M=&5N9VIA<W0B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<V('!O
M+W1R86YS;&%T:6]N+G!H<#HV-3<*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@
M(E1U;F=U;>%L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@
M1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,3<T"B,L(&9U>GIY"FUS9VED("),87-T($AA;&8B"FUS9W-T
M<B`B<^WP87-T82!B;',N(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@X(&QI
M8B]";&]C:R]M;V]N+G!H<#HY,`HC+"!F=7IZ>0IM<V=I9"`B3&%S="!1=6%R
M=&5R(@IM<V=S='(@(G/M\&%S=&$@8FQS+B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,30Y"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(G/M\&%S
M="!U<'!FYG)T.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C8V-@HC
M+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R(")3
M[?!A<W0@=&5N9W-T.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.C8V.`HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M
M("5S(@IM<V=S='(@(E/M\&%S="!T96YG<W0Z("5S(&9RX2`E<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C8V,PIM<V=I9"`B3&%S="!L;V=I;CH@
M3F5V97(B"FUS9W-T<B`B4^WP87-T('1E;F=S=#H@06QD<F5I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B3&5T=&QA;F0B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA=R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-SD*;7-G:60@(DQA>6]U="(*;7-G<W1R(")&<F%M<V5T;FEN9R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G
M:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@(DSM8F%N;VXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B5FEN<W1R:2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,C,*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3D*;7-G:60@
M(DQE9G0@=F%L=65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B
M3&5S;W1H;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R
M:6$B"FUS9W-T<B`B3.UB97+M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB
M>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*
M;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DQI9VAT($1R
M:7IZ;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C,*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G
M:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT(%)A
M:6X@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR-@IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X
M"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!3;F]W
M(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X,3@*;7-G:60@(DQI;FLB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4V"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B3&EN:R!T:&4@96UA
M:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN
M9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED("),:6YK<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L
M9&5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S`*;7-G
M:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE
M;'`O:6YD97@N<&AP.C4P"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,CD*;7-G:60@(DQI<W0@
M5&%B;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-3DT"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.#D*(RP@9G5Z
M>GD*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R(")(:N%L<"(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O
M<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S
M+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),
M:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VYO;&ES="YI;F,Z-`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D
M:7-A8FQE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(DQI=&CA96XB"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3,S.`IM<V=I9"`B3&]A9&EN9R!L:6)R87)I97,N
M+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6UA9V5S+G!H<#HX,PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<X"FUS9VED("),;V-A
M;"!T:6UE.B`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@S"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU-S`@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C8T"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C8S"B,L(&9U>GIY"FUS9VED("),
M;V-A=&EO;B(*;7-G<W1R(")!\&=E<O`B"@HC.B!L;V=I;BYP:'`Z,34U('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-C0@=&5M<&QA=&5S+VQO9VEN
M+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ
M-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),;V<@:6XB
M"FUS9W-T<B`B5&5N9VIA<W0B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A
M<BYP:'`Z,34X"FUS9VED("),;V<@;W5T(@IM<V=S='(@(MIT<VMRX2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G:60@(DQO9VEN(%1A<VMS
M(@IM<V=S='(@(E9E<FME9FYI('9I\"!T96YG:6YG=2(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.CDQ,0HC+"!F=7IZ>0IM<V=I9"`B3&]G:6X@9F%I
M;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT
M97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB5&5N9VEN9R!M:7-T\VMS
M="X@3.UK;&5G82!E<B!N;W1A;F1A;F%F;B#^:71T(&7P82!L>6MI;&]R\"!R
M86YG="!I;FYS;&5G:?`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M.3`W"B,L(&9U>GIY"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@(D5N
M9'5R=NUS=6X@;6ES:&5P<&'P:7-T+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S-S`*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*
M;7-G:60@(DQO=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G
M<F5E:R!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R
M(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W
M97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G
M:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,T,@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<S"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,3`@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-3`*;7-G:60@(DU-(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR-3`*;7-G:60@(DU/5$0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.
M148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ
M"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S
M8V%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0IM
M<V=I9"`B36%G:6,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C<X"FUS9VED(")-86EL(@IM<V=S='(@(E9E9G#S<W1U<B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C<*;7-G:60@(DUA:6P@061M
M:6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0P"FUS9VED(")-86ME(&QI;E]K+BXN(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S4W"FUS9VED(")-
M86ME('-U<F4@=&AA="!Y;W4@:&%V92!014%2(&EN<W1A;&QE9"!A;F0@:6X@
M>6]U<B!I;F-L=61E('!A=&@N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HV-S@@<&\O=')A;G-L871I;VXN<&AP.C$P-S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B36%K:6YG(&1I<F5C=&]R>2`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.30*;7-G:60@(DUA;&%W:2(*;7-G<W1R(")-86QA=NTB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(DUA;&'M<^UA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*;7-G<W1R(")'<N9N
M:/9F\&%E>6IA<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%L:2(*;7-G<W1R
M(")-86SM(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QT82(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$*;7-G:60@(B(*(DUA;F%G
M92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET
M96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E
M(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,#0P"FUS9VED(")-87`R-"!M87`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDW.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3`U-0IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-S8*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-
M87)C:"(*;7-G<W1R(")M87)S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN(@IM<V=S
M='(@(E-PX7-S[6$B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@
M26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*
M;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B36%R<VAA;&QE>6IA
M<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$Q,0HC+"!F=7IZ>0IM
M<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(E-VYO!I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(DWA<NUT86[M82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q
M-`IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*
M;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-`IM<V=I9"`B36%X('1E;7`@
M;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,CDV"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3@@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C,Y"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<X"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,34*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I
M9"`B36%Y(@IM<V=S='(@(FUA[2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*(RP@9G5Z>GD*
M;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B;6'M(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4S,0IM
M<V=I9"`B365E=&EN9R!#86YC96QL871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,#,*;7-G
M:60@(DUE971I;F<@26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,#D*;7-G:60@
M(DUE971I;F<@4')O<&]S86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,C4*;7-G:60@(DUE971I
M;F<@4F5P;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HU,30*;7-G:60@(DUE971I;F<@57!D871E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-3$Y"FUS9VED(")-965T:6YG(%5P9&%T92!297%U97-T
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI
M;F,Z,3D*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,V.`IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R("(B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-3(W"B,L('!H<"UF;W)M870*;7-G:60@(DUE<F=I
M;F<@86QL("5S+G!O(&9I;&5S('1O('1H92!C;VUP96YD:75M+BXN("(*;7-G
M<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#,X"B,L('!H<"UF;W)M
M870*;7-G:60@(DUE<F=I;F<@;&]C86QE("5S+BXN("(*;7-G<W1R("(B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S@X"B,L('!H<"UF;W)M870*;7-G:60@
M(DUE<F=I;F<@=&AE(%!/(&9I;&4@9F]R("5S('1O('1H92!C;VUP96YD:75M
M+BXN("(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#(U"B,L
M('!H<"UF;W)M870*;7-G:60@(DUE<F=I;F<@=')A;G-L871I;VX@9F]R(&UO
M9'5L92`E<RXN+B(*;7-G<W1R(")386UE:6YA(/[]\&EN9V%R(&9Y<FER("5S
M(&5I;FEN9W5N82XN+B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*;7-G:60@(DUE<W-A
M9V4B"FUS9W-T<B`B4VME>71I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C
M8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@
M;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(DUE
M<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C@*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#$*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(V"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U.0IM<V=I
M9"`B365S<V%G92!T>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$Q,`IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T
M86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q
M"FUS9VED(")-971H;V0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]2
M4$,O>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ
M,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D("<E<R<@:7,@;F]T(&1E
M9FEN960B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C<S(&QI8B]";&]C:R]M971A<BYP:'`Z-S,*;7-G:60@(DUE=')I8R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R
M(")-97CM:_,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D
M97)A=&5D(%-T871E<R!O9B(*;7-G<W1R(")-[6MR\VYE<^UA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"FUS
M9VED(")-:61D;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P.`IM<V=I9"`B36EN('1E
M;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S`P"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C$W"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B4W!E9VQA(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S
M(@IM<V=S='(@(MUM:7-L96=T(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-S$*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S,Y"FUS9VED(")-:7-S:6YG(%!%
M05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ,30*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG
M=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W
M86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#,*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z
M-3<*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R(")-X2(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HW,0IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C0*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HW,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T9WHN<&AP.C@X"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU,@IM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R(")"<F5Y=&$@
M<VSS\"(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV-3<*;7-G:60@(DUO9'5L
M92(*;7-G<W1R(")%:6YI;F<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8W,PIM<V=I9"`B36]D=6QU<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S='(@(DWS;F%K
M\R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8P,@IM<V=I9"`B36]N=&@@
M86YD('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V
M"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*
M;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DUO<W1L>2!#;&5A<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS,0IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B
M36]S=&QY(%-U;FYY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C0R.`IM<V=I9"`B36]V92!$;W=N(@IM<V=S='(@
M(D9L>71J82!N:?!U<B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C0S,@HC+"!F=7IZ>0IM<V=I9"`B36]V92!,969T(@IM<V=S='(@
M(D9L>71J82!U<'`B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HT,S8*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#(T"FUS9VED(")-;W9E
M(%5P(@IM<V=S='(@(D9L>71J82!U<'`B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#DW"B,L(&9U>GIY"FUS9VED(")-;W9E
M(&1O=VXB"FUS9W-T<B`B9N9R82!N:?!U<B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT.38*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Y-PHC+"!F=7IZ>0IM<V=I9"`B36]V
M92!U<"(*;7-G<W1R(")FYG)A('5P<"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B
M36]Z86UB:7%U92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,3@T"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,@IM
M<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS,C@@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,S-0IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO:6YD97@N<&AP.C4Q"FUS9VED(")->2!0;W)T86PB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C$R-`IM<V=I
M9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*
M;7-G:60@(DUY86YM87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+V%G<F5E;65N=%]B;W1T;VTN:6YC.C<*;7-G:60@(DY/+"!)($1O
M($Y/5"!!9W)E92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HS.3<@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F
M+G!H<#HS.`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C4X,PIM<V=I9"`B3F%M92(*;7-G<W1R(").869N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HW,#8*(RP@9G5Z>GD*;7-G:60@
M(DYE961S($%C=&EO;B(*;7-G<W1R(")!\&=E<O`B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*
M(RP@9G5Z>GD*;7-G:60@(DYE<&%L(@IM<V=S='(@(D[]<B!P\W-T=7(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM
M<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E
M($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!#02!P
M;VQI8WD@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X,@IM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G
M:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T
M<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,`IM<V=I9"`B3F5T<V-A
M<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C,V"B,L(&9U>GIY"FUS9VED(").971W;W)K(@IM
M<V=S='(@(D[]='0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R-0HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S<V"FUS9VED(").979E<B(*;7-G<W1R(")!;&1R96DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z,C<*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]"
M;&]C:R]M;V]N+G!H<#HQ-SD*(RP@9G5Z>GD*;7-G:60@(DYE=R!-;V]N(@IM
M<V=S='(@(D[]<B!P\W-T=7(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(DYE=R!:
M96%L86YD(@IM<V=S='(@(D[]<B!P\W-T=7(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W
M("A?8FQA;FLI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C4X"B,L(&9U>GIY"FUS9VED(").97=S(@IM<V=S='(@
M(D[]='0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,CDR"FUS9VED
M(").97=S9W)O=7!S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C(Q('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0V"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3,W('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C,R"FUS9VED(").97AT(@IM<V=S='(@(D[F<W1A(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"B,L(&9U>GIY"FUS9VED(").97AT
M(%!H87-E(@IM<V=S='(@(D[F<W1A('/M\&$B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C,V."!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C,W,@HC+"!F=7IZ>0IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@
M(E9A;&MO<W1I<B!N;W1A;F1A(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R
M+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(DYE>'0^(@IM<V=S='(@(D[F<W1A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDV"B,L(&9U>GIY"FUS9VED(").:6=E<B(*;7-G<W1R(")!
M;&1R96DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,PIM<V=I9"`B
M3FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").:75E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HX.#@*;7-G:60@(DYO(@IM<V=S='(@(DYE:2(*"B,Z('1E;7!L871E
M<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ,38*;7-G:60@(DYO(&%V86EL86)L
M92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<BYP:'`Z,3`U"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R
M(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DYO
M(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HW.2!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HR,S`*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,C4R"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E
M<W1E9"!P;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I
M9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]D:69F+G!H<#HU-0HC+"!F=7IZ>0IM<V=I9"`B3F\@8VAA
M;F=E+B(*;7-G<W1R(")"<F5Y=&$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$T,`IM<V=I9"`B3F\@8VAI;&0@<&5R;6ES<VEO;G,@87)E
M('1O(&)E(&%D9&5D(&)E;&]W('1H:7,@;&5V96PN(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,0IM<V=I9"`B3F\@8VAI;&1R
M96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S-S<*(RP@9G5Z>GD*;7-G:60@
M(DYO(&-O;6UA;F0@<W!E8VEF:65D+B(*;7-G<W1R(")%;F=I;B!M87!P82!V
M87(@=&EL9W)E:6YD(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M-C<@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-S<*(SH@9G)A;65W;W)K
M+U5T:6PO571I;"YP:'`Z-S<U"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-#$*;7-G
M:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!&5%`@5D93+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C4W-0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,#0*;7-G:60@(DYO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!6
M1E,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,S"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB
M"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R-S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3F\@96YT<GD@=VET:"!T:&4@:60@)R5S)R!E>&ES
M=',@:6X@=&AE(&]R:6=I;F%L(&AE;'`@9FEL92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<Q"FUS9VED(").;R!F
M:6QE('5P;&]A9&5D(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HT,3,@<&\O=')A;G-L871I;VXN<&AP.C4R
M,@HC+"!F=7IZ>0IM<V=I9"`B3F\@;&]C86QE('-P96-I9FEE9"XB"FUS9W-T
M<B`B16YG:6X@;6%P<&$@=F%R('1I;&=R96EN9"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ,C`@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(Q"FUS9VED(").;R!L;V-A=&EO
M;B!I<R!S970N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"B,L(&9U>GIY"FUS9VED(").;R!M
M97-S86=E('-U<'!L:65D+B(*;7-G<W1R(")._2!S:V5Y=&DB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0HC+"!F
M=7IZ>0IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@(F5N9VEN
M;B!T97AT:2!T:6QG<F5I;F1U<B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"B,L(&9U>GIY"FUS9VED(").;R!N
M=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R(")E;F=I;FX@=&5X=&D@=&EL9W)E
M:6YD=7(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@(DYO
M(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VAT='`N<&AP.CDQ"FUS9VED(").;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C<R"FUS
M9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<V%S;"YP:'`Z-S<@9G)A;65W;W)K+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<U"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%S<W=D+G!H<#HQ
M,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@V"FUS9VED("(B"B).;R!P871H
M('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@
M8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D
M871A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*;7-G
M:60@(DYO('-I9&5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ,S`*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@
M879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S`*(RP@9G5Z>GD*
M;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G
M<W1R(")3;.'P=2!I;FX@;F]T86YD86YA9FX@;V<@;'EK;&EO<O`B"@HC.B!F
M<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L
M:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y-@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3`V"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HY,3<*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDS-`IM<V=I9"`B3F\@=F%L=65S
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,3D*;7-G
M:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO
M;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(W"FUS9VED(").;R!V97)S:6]N(&9O
M=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C8P-`IM<V=I9"`B3F]N(%!A<G1I8VEP86YT
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C4V,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C
M="YI;F,Z.3(*;7-G:60@(DYO;F4B"FUS9W-T<B`B16YG:6XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").
M;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@Y"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES
M;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"B,L(&9U>GIY"FUS9VED
M(").;W)W87DB"FUS9W-T<B`BP69R86US96YD82(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C0P"B,L(&9U>GIY"FUS9VED(").;W0@
M069T97(B"FUS9W-T<B`B16MK:2!U<'!K87-T(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(DYO="!"969O<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,Q"B,L
M(&9U>GIY"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B4O;P=6YA
M<N%T="(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP
M:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.30*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"B,L(&9U>GIY"FUS9VED
M(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(D5K:VD@97ET="(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*(RP@9G5Z
M>GD*;7-G:60@(DYO="!S970B"FUS9W-T<B`B16MK:2!E>71T(@H*(SH@9G)A
M;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#,*
M(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H
M<#HQ-3@*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+G!H<#HQ-S,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I
M;VY(86YD;&5R+G!H<#HQ.#<*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C$W-0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DS(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR,3`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(R-B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HR-3<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(W-`HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z,S`W(&9R86UE=V]R:R]61E,O5D93+G!H<#HS-C4*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0T-"!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-3$S"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU,S`*;7-G:60@
M(DYO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$V,0HC+"!F=7IZ>0IM<V=I9"`B3F]T97,B"FUS9W-T<B`B16YG
M:6XB"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@
M(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$P"B,L(&9U
M>GIY"FUS9VED(").;W1I8V4B"FUS9W-T<B`B16YG:6XB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@T"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,C$*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB
M97(B"FUS9W-T<B`B;O-V96UB97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,#0V"B,L(&9U>GIY"FUS9VED(").=6UB97(B"FUS9W-T<B`B;O-V
M96UB97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#,P"FUS9VED
M(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S<T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$T,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30U,"!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M
M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3,W,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(V"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#@@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R
M;W=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I
M960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C0X,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C8V,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-C0@<&\O=')A;G-L871I;VXN<&AP.C$T.`HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,3,T.`IM<V=I9"`B3TLB"FUS9W-T<B`BS2!L86=I(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Q-`HC+"!F
M=7IZ>0IM<V=I9"`B3V)J96-T(@IM<V=S='(@(D5F;FDB"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3,W(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,C$U"FUS9VED(")/8FIE8W0@8W)E
M871O<B!P97)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@S"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,C`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B
M3V-T;V)E<B(*;7-G<W1R(")O:W3S8F5R(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,CDX"FUS9VED(")/9F9I8V4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S
M"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD
M97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*
M;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3$@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DW,0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S<R!A
M;&QO=V5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP
M:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI
M;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E
M<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C,U"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@
M9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4T"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B
M3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8P,`IM<V=I9"`B3W!T:6]N
M86P@4&%R=&EC:7!A;G0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")686QS
M=&EL;&EN9V%R(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E
M<R]P<F5F<R]A<'`N:6YC.C$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R(")686QS=&EL;&EN9V%R(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B3W!T:6]N
M<SHB"FUS9W-T<B`B5F%L<W1I;&QI;F=A<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4V-PIM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A
M;FES871I;VYA;"!5;FET(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ,CD*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B(@H*
M(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P
M<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E
M;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*(RP@
M9G5Z>GD*;7-G:60@(D]T:&5R(@IM<V=S='(@(F]K=/-B97(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,C$*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R.0HC+"!F
M=7IZ>0IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B57!P;/US
M:6YG87(@;F5T_FKS;G,B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H
M96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C4P"B,L(&9U>GIY"FUS
M9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B2&%F82!U;F1I
M<G-K<FEF=&ER(&UE\"!D875F=6T@;&ET/R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$R.38*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,S0X"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S,P"FUS9VED(")01U`@
M4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H
M<'-H96QL+G!H<#HV.`IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S0*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@(E!-(%-H
M;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S8*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@
M(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@4W5N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,Y"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O87!I
M+G!H<#HQ,C8*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM
M<V=I9"`B4&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@
M(E!A:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A
M;&%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN
M:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDX"FUS9VED(")086YA;6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS
M9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")087)T;'D@0VQO
M=61Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P,3@*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,"!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,V"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-3(*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(DQY
M:VEL;W+P(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ
M,S(R"B,L(&9U>GIY"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T
M<B`B3'EK:6QO<O`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP
M:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#4S"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.3`*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R("),>6MI;&]R
M\"(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"B,L(&9U>GIY
M"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(DQY:VEL;W+P(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S0*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B
M4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,C`@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(R"B,L(&9U>GIY"FUS9VED(")087-T92(*;7-G
M<W1R(")$86=S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V97%U975E9"YI;F,Z-`IM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*;7-G:60@(E!E
M;W!L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P-PHC+"!F=7IZ>0IM<V=I9"`B4&5R8V5N="(*;7-G
M<W1R(")0<F5N=&$B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER
M;5]B;W1T;VTN:6YC.C8*(RP@9G5Z>GD*;7-G:60@(E!E<F9O<FT@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")6:?!H86QD<V'P9V5R\&ER(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-@HC+"!F=7IZ>0IM<V=I9"`B
M4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G
M<W1R(")&<F%M:W;F;6$@=FGP:&%L9'-A\&=E<O!I<B!V:?`@=&5N9VEN9W4B
M"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C$@861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP.C8T"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV
M-PHC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R(")097)S\VYU
M;&5G="(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B`G)7,G(&YO="!D96QE=&5D+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HR,C0@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.CDS"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR
M,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")0
M97)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")5<'!L_7-I;F=A
M<B!U;2!N;W1A;F1A(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ-#4@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-3(*;7-G:60@(E!E<FUI<W-I
M;VYS(&9O<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C4*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(E5P<&S]
M<VEN9V%R('5M(&YO=&%N9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED
M(")0971S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&AI;&EP
M<&EN97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$Y-@HC+"!F=7IZ>0IM<V=I9"`B4&AO;F4B"FUS9W-T
M<B`B96YG:6YN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Q-0IM
M<V=I9"`B4&AO=&]S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@
M(E!I=&-A:7)N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U
M9&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O
M('-O;64@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#@*;7-G:60@(E!L96%S92!C
M;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T
M('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U-S$*(RP@9G5Z>GD*;7-G
M:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@
M(E-LX?!U(&EN;B!N_6IA(&YA9FYI\#HB"@HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@HC+"!F=7IZ>0IM<V=I9"`B4&QE
M87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T
M<B`B4VSA\'4@:6YN(&[]='0@;?9P<'5N869N.B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S,#<*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E;G1E
M<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(E-LX?!U(&EN;B!G:6QD
M87(@;&5I=&%R9F]R<V5N9'5R+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(V-C<*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H
M96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-#D*(RP@9G5Z>GD*
M;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(E-L
MX?!U(&EN;B!G:6QD87(@;&5I=&%R9F]R<V5N9'5R+B(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E
M(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ."!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C(R"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE
M(&%N9"!P87-S=V]R9"(*;7-G<W1R(")3;.'P=2!I;FX@;F]T86YD86YA9FX@
M;V<@;'EK;&EO<O`B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O86=R965M
M96YT7W1O<"YI;F,Z,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4&QE87-E
M(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B`@66]U($U54U0@86=R964@=VET
M:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ-PIM<V=I9"`B4&QE87-E(')E<&]R
M="!A;GD@8G5G<R!T;R!I,3AN0&QI<W1S+FAO<F1E+F]R9RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HU-#`*;7-G:60@(B(*(E!L96%S92!R979I97<@=&AE(&9O;&QO=VEN9R!I
M;F9O<FUA=&EO;BP@86YD('1H96X@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H
M92`B"B)M96YU(&)E;&]W+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0S-0HC+"!F=7IZ>0IM<V=I
M9"`B4&QE87-E('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO
M=RXB"FUS9W-T<B`B5F5L9'4@82YM+FL@96EN82!M]G!P=2!T:6P@8?`@;&5I
M=&$@[2XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE
M=R!C871E9V]R>2!N86UE.B(*;7-G<W1R(")3;.'P=2!I;FX@;OUJ82!N869N
M:?`Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0;VQA;F0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(T"FUS
M9VED(")0;VQL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0
M;W)T=6=A;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N
M:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N
M:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI
M<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-"!L:6(O0FQO8VLO;65T87(N<&AP
M.C(V.0HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L
M87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I
M<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0
M<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(S
M"FUS9VED(")0<F5S<W5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(U-PIM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P,@IM
M<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3@X"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PHC+"!F=7IZ
M>0IM<V=I9"`B4')E=FEE=R(*;7-G<W1R(")&>7)R:2!B;&'P<^WP82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN
M9&]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,S4X(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8R"B,L(&9U
M>GIY"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(D9Y<G)A('-K
M97ET:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0P.0IM<V=I9"`B4')I=F%T
M92!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE
M;G4N<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R(")6
M86YD86WA;#\B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C<*;7-G:60@
M(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(Q,`IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3@X"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,#D*;7-G
M:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I
M=&AM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C(R-PIM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N
M97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C8R"FUS9VED(")1=65R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8T"FUS9VED(")2861I;R!S96QE8W1I
M;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#`*;7-G:60@(E)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E)A:6X@
M16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I
M9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A:6X@86YD(%-N;W<B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#4*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S
M"FUS9VED(")2871I;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C(Y,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q
M-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$X,`HC+"!F=7IZ>0IM<V=I9"`B4F5A9"(*;7-G
M<W1R("+3;&5S:?`B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HX-PHC+"!F=7IZ>0IM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G
M<W1R(")._2!S:V5Y=&DB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO
M=F4N:6YC.C$R"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@
M)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@
M=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,0IM<V=I9"`B4F5F
M<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S$*(RP@9G5Z>GD*;7-G:60@(E)E9G)E
M<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(D5N9'5R:&QA\&$@;?9P<'5H86TZ
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(S-0HC+"!F=7IZ>0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B16YD=7)S971J
M82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-3,*;7-G:60@(E)E
M;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S(T"FUS9VED(")296UA<FMS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#4W"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#<V
M"FUS9VED(")296UE;6)E<B!T:&4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$T"B,L(&9U
M>GIY"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R(")&:F%R;.9G:F$@
M=F%L:6XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G
M:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C(Q('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,34*(RP@
M9G5Z>GD*;7-G:60@(E)E;6]V92(*;7-G<W1R(")(86QD82#A9G)A;2(*"B,Z
M('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I
M9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(D9J87)LYF=J82!V86QI;B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,S(*(RP@
M9G5Z>GD*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B9N9R82!N:?!U
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-#`*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@
M(E5P<&S]<VEN9V%R(&YE=/YJ\VYS(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-3@*;7-G:60@(E)E;6]V92!F<F]M
M(&UY(&-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z,3,V"B,L(&9U>GIY"FUS9VED(")296UO=F4@<&%I<B(*;7-G
M<W1R(")FYG)A('5P<"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#4*
M;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP
M;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*(RP@9G5Z>GD*
M;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B1FIA<FSF9VIA('9A;&EN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0Y"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M
M96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M92YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S='(@
M(F9J87)LYF=J82!H86YD<FET(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C$Y-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C(X,`HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C,T.0HC+"!F=7IZ>0IM<V=I9"`B4F5P
M;'D@4V5N="XB"FUS9W-T<B`B4W9A<F$B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0U.0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0V.`HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0W.`IM<V=I9"`B4F5P
M;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-C8*
M;7-G:60@(E)E<&QY('=I=&@@9G)E92]B=7-Y(&9O<B!N97AT(#(@;6]N=&AS
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C0V-0IM<V=I9"`B4F5P;'D@=VET:"!R97%U97-T960@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$X.0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5P;'DZ("5S(@IM<V=S='(@(E-V87(Z
M(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@
M(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R
M8V]D93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,3<T(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#@W"B,L('!H<"UF
M;W)M870*;7-G:60@(E)E<75I<F5D("<E<R<@;F]T('-P96-I9FEE9"!I;B`E
M<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C4X,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<T
M-PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S$P"B,L('!H
M<"UF;W)M870*;7-G:60@(E)E<75I<F5D("<E<R<@;F]T('-P96-I9FEE9"!I
M;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5T:6PO571I;"YP:'`Z-S@S"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I
M<F5D("<E<R<@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS
M,C@*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3DR"FUS9VED
M(")297%U:7)E9"!087)T:6-I<&%N="(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SD*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$U('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHQ,#$*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHT-`IM<V=I9"`B4F5S970B"FUS9W-T<B`B16YD=7)S971J
M82(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"B,L(&9U>GIY
M"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R("),>6MI;&]R\"(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED(")297-E="!9
M;W5R(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H
M<#HW,2!A9&UI;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP
M.C8U"B,L(&9U>GIY"FUS9VED(")297-U;'1S(@IM<V=S='(@(DYI\'5R<W1A
M\&$@;&5I=&%R(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C@R,0IM<V=I9"`B
M4F5S=6QT<R`H:6YC;'5D:6YG($AO<F1E*3HB"FUS9W-T<B`B(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C@Q.0HC+"!F=7IZ>0IM<V=I9"`B4F5S=6QT<SHB
M"FUS9W-T<B`B3FGP=7)S=&'P82!L96ET87(B"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,3`R('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*
M(RP@9G5Z>GD*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(E9A
M;&MO<W1I<B!N;W1A;F1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO
M;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(E)E=F5R
M="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(E5P<&S]<VEN9V%R(&YE=/YJ\VYS
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,`IM<V=I9"`B4FEC:"!4
M97AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0X
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*
M;7-G:60@(E)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,Q,C4*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(Q"FUS9VED(")2:6=H="!V
M86QU97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I
M97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C(S-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C4X,PIM<V=I9"`B4F]L92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,#@*;7-G:60@
M(E)O=&%T92`Q.#`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(P-0HC+"!F=7IZ>0IM<V=I9"`B4F]T871E
M($QE9G0B"FUS9W-T<B`B5&5N9VEL:?!A;&ES=&DB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C$Q"FUS9VED(")2;W1A=&4@
M4FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*(RP@9G5Z>GD*
M;7-G:60@(E)U;&5S(@IM<V=S='(@(D5N9'5R<V5T:F$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED
M(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU
M;6YS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@
M(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C$*;7-G:60@(E)U;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS
M,C,*(RP@9G5Z>GD*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*
M;7-G<W1R(")396YD82!S:V5Y=&DB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-A<VPN<&AP.C@Q"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-#D*(RP@9G5Z>GD*;7-G:60@(E--4R!-97-S86=I;F<B"FUS
M9W-T<B`B4VMO\&$@<VME>71I(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q
M"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.`IM<V=I9"`B4U,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,V,`IM<V=I9"`B
M4U-((@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%
M4U,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3,P"FUS9VED(")37U%,
M(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ
M=65L;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@
M5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B
M4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*
M;7-G:60@(E-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@
M(E-A;B!-87)I;F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B
M4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V
M:61E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!
M<F%B:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N
M:6YC.CDX"B,L(&9U>GIY"FUS9VED(")3879E(@IM<V=S='(@(E9I<W1A('-E
M;2(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(E9I<W1A('-E
M;2(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#D*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F4@)R5S)R(*;7-G<W1R(")6
M:7-T82!S96TB"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"B,L(&9U
M>GIY"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B5F%L:V]S=&ER(&YO
M=&%N9&$B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<P"FUS9VED("(B
M"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP
M="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C8Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDP"B,L('!H<"UF
M;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`G
M)7,G+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT-@IM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I
M96YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I
M9"`B4V5A<F-H(@IM<V=S='(@(DQE:71A(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(W-0HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H($5N9VEN97,B
M"FUS9W-T<B`B3FGP=7)S=&'P82!L96ET87(B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,30T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")396%R8VAI;F<@2&]R
M9&4@87!P;&EC871I;VYS(&EN("5S(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,C,*;7-G:60@(E-E87)C:&EN9R!G971T97AT(&)I;F%R
M:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Y-S<*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R(")6
M96QJ82!A;&QT(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0U-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G
M<W1R(")696QD=2!K96YN:2(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PHC+"!F=7IZ>0IM
M<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(E9E;&IA(&5K:V5R
M="(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`HC+"!F=7IZ
M>0IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(E9E;&1U('-T869A
M<V5T=#HB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@HC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B5F5L
M9'4@<W1A9F%S971T.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V
M-S`*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S
M+B(*;7-G<W1R(")%>?!A('9I\&AE;F=I+B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HX,30*(RP@9G5Z>GD*;7-G:60@(E-E
M;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B5F5L:F$@96MK97)T(@H*(SH@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B"B)396QE8W0@=&AE(&-H
M87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C
M86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@
M87)E82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0T"B,L(&9U>GIY"FUS
M9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R(")696QD=2!S
M=&%F87-E='0Z(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T
M+FEN8SHX.0IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T
M;R!C:&%N9V4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N
M:6YC.C$V"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B
M4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHV-`IM<V=I9"`B4V5L96-T('1W;R!M871C
M:&EN9R!F:65L9',N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR.38*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S.`IM<V=I9"`B
M4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R(")696QD
M=2!S:N%L9F=E9FGP('1U;F=U;>%L.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C4S"B,L(&9U>GIY"FUS9VED(")3
M96YD($QA=&5S="!);F9O<FUA=&EO;B(*;7-G<W1R(")5<'!L_7-I;F=A<B!N
M973^:O-N<R(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X
M"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C0*(RP@9G5Z
M>GD*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(E-E;F1A('-K97ET:2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,30*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS
M.#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S
M"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B<V5P=&5M8F5R(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I
M82!A;F0@36]N=&5N96=R;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3$*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q,@HC+"!F
M=7IZ>0IM<V=I9"`B4V5T(@IM<V=S='(@(E9E;&IA(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<V"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y
M;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@
M:70N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*
M;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O
M(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#0*(RP@9G5Z>GD*;7-G:60@(E-E="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N
M<RXB"FUS9W-T<B`B5F5L9'4@<VKA;&9G969I\"!T=6YG=6WA;#HB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*;7-G:60@(B(*(E-E="!Y;W5R('-T
M87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H
M:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<T"FUS9VED(")3971U<"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M
M;#HS.0IM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34S
M"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P
M87)A;65T97(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3
M97EC:&5L;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT-#$*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R="!3=6UM
M87)Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,S8*
M;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T
M(&QI;FMS/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C(Y,B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,34X"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N
M8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N
M97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT.#`*(RP@9G5Z>GD*;7-G:60@(E-H;W<@;&%S
M="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B4_UN82!H
M=F5NYG(@_OH@=&5N9V1I<W0@<^WP87-T(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3<V.0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG
M:6YA;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#$W"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3$U"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO
M;G,@;65N=2!B87(_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N
M=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")3:&]W
M('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV,PIM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L
M;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!2
M;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED
M(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8W"B,L(&9U>GIY"FUS
M9VED(")3:&]W('5P;&]A9"(*;7-G<W1R(")3YFMJ82!Y9FER(.$@=FEN;G5S
M=/;P(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#<*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E-H;W=E<G,@16%R
M;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#D*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I
M9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,SDY"FUS9VED(")3:')I
M;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z-CDR(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<U
M-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HX,3(@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#<T"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDP.2!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HY-#8*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z.3<T(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C$P,#0*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B
M;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-0IM<V=I9"`B4VEG
M;B!U<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C@Y"FUS9VED(")3:6=N('5P(&EF(&YO="!R96=I<W1E<F5D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R"B,L
M(&9U>GIY"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`B56YD:7)S:W)I9G0@
M_NUN.B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$Q
M"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-CD*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HX.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(R-#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS-`HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(W"FUS9VED(")3:7IE(@IM<V=S='(@
M(E-TYG+P(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?8F]T
M=&]M+FEN8SHY"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,S$@<&\O=')A;G-L871I;VXN<&AP
M.C0X-"!P;R]T<F%N<VQA=&EO;BYP:'`Z-C8V"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HX-C`@<&\O=')A;G-L871I;VXN<&AP.C$R,C,*;7-G:60@(E-K:7!P
M960N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K
M:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N:6$B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3$*;7-G:60@(E-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-N;W<@4VAO
M=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4S"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*;7-G
M:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R!3
M:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-S8*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(X,`IM<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN
M('=A=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L
M;VUO;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@
M(E-O;6%L:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8P"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S`*(RP@9G5Z>GD*;7-G:60@(E-O<G0@
M;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(E+V\'5N87+A='0B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.`HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.`HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M,38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C0V"B,L(&9U>GIY"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R
M(")&=6QL="!N971F86YG(/YI='0@*$9RX3HI(#HB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U
M.2TS*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E
M;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP
M:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*
M;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN
M(&-E;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.#$U"FUS9VED(")3<&%C97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"FUS9VED(")3<&%C
M:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I
M;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY-0IM<V=I9"`B
M4W!A;2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*
M(RP@9G5Z>GD*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S
M='(@(E/I<G3A:VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8R"B,L(&9U>GIY"FUS9VED(")3<&QI="!C96QL
M(@IM<V=S='(@(E9E;&IA(&%L;'0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU
M;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM<V=I9"`B4W!O<G1S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,B!L
M:6(O0FQO8VLO;65T87(N<&AP.C<R"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@
M5')E:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C0T,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C4T.`IM<V=I9"`B4W1A<G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8P-"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#$S"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P"FUS
M9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4X,PHC.B!T96UP
M;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT.3$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W1A='5S(&9O<B!L;V-A;&4@)7,N+BX@(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3D*(RP@9G5Z
M>GD*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(E5P<&S]<VEN9V%R
M(&YE=/YJ\VYS(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-S(*(RP@9G5Z>GD*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@
M(E-E;F1A;F1A;F5T9F%N9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,PIM<V=I9"`B
M4W1R:6YG(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@W,PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E
M<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S
M97(N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2`G
M)7,G(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV,3$*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R(")%
M9FYI(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#0*
M;7-G:60@(E-U8FIE8W0@4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,B!F<F%M97=O<FLO1F]R;2]&
M;W)M+U)E;F1E<F5R+G!H<#HS,3(*(RP@9G5Z>GD*;7-G:60@(E-U8FUI="(*
M;7-G<W1R(")%9FYI(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@)R5S)R!T;R!T
M:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R
M97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"B,L(&9U>GIY
M"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B169N:2(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S
M<R(*;7-G<W1R(")&<F%M:W;F;70B"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D
M("<E<R<@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B3F5T9F%N9VGP(%PB)7-<
M(B!V87(@8N9T="#M(&YE=&9A;F=A8O-K:6YA(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A
M<F5D(&1A=&$@9F]R('5S97(@)R5S)R!F<F]M('1H92!S>7-T96TN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#$@861M:6XO<&5R;7,O9&5L
M971E+G!H<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M9&5L971E9"`G)7,G+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@
M)R5S)R!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E
M9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HU-0IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D("<E<R<B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M('=R;W1E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U
M9&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-34X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-38P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8V"FUS9VED(")3
M=6X@4FES92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M-S$*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-U;FYY(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.#,*;7-G
M:60@(E-U;G)I<V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N
M<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E
M+U-U;G-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3@R"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X-@HC+"!F=7IZ>0IM<V=I9"`B
M4W5N<V5T(@IM<V=S='(@(D5F;FDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,3@U"B,L(&9U>GIY"FUS9VED(")3=6YS970Z("(*;7-G<W1R
M("(@169N:7-L[6YA.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,S"FUS9VED(")3=7!P
M;W)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*(RP@9G5Z>GD*;7-G:60@
M(E-U<FEN86UE(@IM<V=S='(@(E-K<N%R;F%F;B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"B,L(&9U>GIY"FUS9VED(")3=7)N
M86UE(@IM<V=S='(@(DYO=&%N9&%N869N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I
M9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-`HC+"!F=7IZ>0IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(DQE<VGP(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN
M=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM
M<V=I9"`B5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN
M9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3D*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]486)L92YP:'`Z,3,V
M"FUS9VED(")486)L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED(")486)L92!0
M<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E
M<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S0@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B
M5&%I=V%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N
M:71E9"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")487)G970Z(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-S`*(RP@
M9G5Z>GD*;7-G:60@(E1A<VMS(@IM<V=S='(@(E9E<FME9FYI('9I\"!T96YG
M:6YG=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S
M"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C@X"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q,@IM<V=I
M9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$Y,`IM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C(Q-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92`G)7,G(&YO="!F;W5N9"XB
M"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@
M(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C0Q"FUS9VED
M(")496YT871I=F5L>2!!8V-E<'0@<F5Q=65S="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8X.0IM
M<V=I9"`B5&5N=&%T:79E;'D@06-C97!T960B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,0IM<V=I9"`B5&5X="(*;7-G<W1R
M(")497AT:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C4*(RP@9G5Z
M>GD*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R(")497AT:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*(RP@
M9G5Z>GD*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B3N9S=&$@<^WP82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*
M(RP@9G5Z>GD*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B5&5X=&DB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED
M(")4:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM
M<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.3`S"B,L(&9U>GIY"FUS9VED(")4:&%N:R!Y;W4@9F]R
M('5S:6YG('1H92!S>7-T96TN(@IM<V=S='(@(B(*(M[Z(&AE9G5R(&[Z(&%F
M=&5N9W-T("5S+B!486MK(&9Y<FER(&YO=&MU;FEN82X@WF5G87(@_OH@=FEL
M="!T96YG:F%S="!A9G1U<BP@(@HB;F]T8?!U(/[A(')E:71I;F$@:.ER(&'P
M(&YE\&%N+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#8Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92`E<R!H96QP(&9I;&4@9F]R("5S(&1O97-N)W0@
M>65T(&5X:7-T+B!#<F5A=&EN9R!A(&YE=R!O;F4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S,W"FUS9VED(")4:&4@1E10
M(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@
M;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HR.0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA
M<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"B,L(&9U>GIY"FUS
M9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB
M"FUS9W-T<B`B4VME>71I;G4@<V5M('9E<FGP('9A<B!A\"!S96UJ82!H969U
M<B!V97)I\"!L;VMA\"XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C$U."!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$V.0HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C$X,"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C$Y,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P,R!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R,0HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C(S,R!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(W,@IM
M<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E
M(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A
M;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED
M(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0Y"FUS9VED(")4
M:&4@8V%L96YD87(@9&%T82!I<R!I;G9A;&ED(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS
M9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I
M960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T
M86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HU,0HC+"!F=7IZ>0IM<V=I9"`B5&AE(&-O;G1A8W0@
M=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB
M"FUS9W-T<B`B3F5T9F%N9VGP(%PB)7-<(B!V87(@8N9T="#M(&YE=&9A;F=A
M8O-K:6YA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$T
M-@IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@
M:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)
M1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T
M(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G
M:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,3,*
M;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U
M<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-S@*;7-G:60@(E1H92!E
M=F5N="!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-2!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C0X.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38X(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z-#<X"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$U
M,@IM<V=I9"`B5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E
M;&8N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(V
M,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T
M:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@
M(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R
M;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W
M<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@
M(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C
M:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C
M<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S
M('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R
M;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@
M:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@
M<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS
M9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P.3<@<&\O=')A;G-L
M871I;VXN<&AP.C$R,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&AE;'`@
M9FEL92`E<R!D:61N)W0@<W1A<G0@=VET:"`\/WAM;"(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R
M(")+96YN:6YU(%PB)7-<(B!H969U<B!V97)I\"!E>71T+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G
M:60@(E1H92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$T,PIM<V=I9"`B(@HB5&AE
M(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T
M;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O341.+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE
M8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@
M9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U
M;F1E<G-T;V]D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#<W"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG
M('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C,Q"FUS9VED(")4:&4@;W!E;G-S
M;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM
M93HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,N<&AP.C(X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R
M96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A
M=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H
M<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP
M:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O
M:6YT+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O
M<F0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP
M:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H
M<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET
M92YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E
M;"YP:'`Z,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@
M=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N
M9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@
M<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS
M9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T
M960N(@IM<V=S='(@(DME;FYI;G4@7"(E<UPB(&AE9G5R('9E<FGP(&5Y='0N
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N
M('-A=F5D+B(*;7-G<W1R(")+96YN:?`@(%PB)7-<(B!H969U<B!V97)I\"!V
M:7-T8?`N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B
M965N(')E;6]V960N(@IM<V=S='(@(DME;FYI\"`@7"(E<UPB(&AE9G5R('9E
M<FGP('9I<W1A\"XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HR.3`*;7-G:60@(E1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X
M:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C$P.`IM<V=I9"`B5&AE('1A<VL@:&%S(&)E96X@
M861D960@=&\@>6]U<B!T87-K;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HQ,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S
M(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,S`W
M"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@
M<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82]C<W8N<&AP.C(T,"!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z
M,3<R"B,L(&9U>GIY"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N
M;W0@8F4@<V%V960N(@IM<V=S='(@(D5K:VD@=F%R(&CF9W0@8?`@<VMI<'1A
M('5M('5N9&ER<VMR:69T+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z.3,*(RP@9G5Z>GD*;7-G:60@(E1H92!U<V5R
M)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N('=A<R!S=6-E<W-F=6QL>2!S=&]R
M960N(@IM<V=S='(@(E5N9&ER<VMR:69T(&AE9G5R('9E<FGP(&)R97ET="XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#8@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C4V"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ,#<@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q,0IM
M<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y("<E<R<@;F]T(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C$W.`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@
M879A:6QA8FQE+B(*;7-G<W1R("+>8?`@97)U(&5N9VEN('-K97ET:2#M(/YE
M<W-U('#S<W1H\VQF:2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HS,S@*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A
M;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#`V"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N
M(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@
M96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,3`V,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!D;V5S
M;B=T('EE="!E>&ES="!A(&AE;'`@9FEL92!F;W(@)7,N(@IM<V=S='(@(B(*
M"B,Z('-I9VYU<"YP:'`Z-3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG("<E<R<@=&\@=&AE('-Y<W1E
M;2X@)7,N(@IM<V=S='(@(B(*(E9A;F1A;>%L(&MO;2!U<'`@=FGP('3F;6EN
M9W4@X2`E<RX@5FEL;'5T:6QK>6YN:6YG(&YE=/YJ\VYS:6YS(&9Y;&=I<B!H
MZ7(@X2`B"B)E9G1I<B(*"B,Z(&%D;6EN+W5S97(N<&AP.C<S"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN
M9R`G)7,G('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(B(*(E9A;F1A;>%L
M(&MO;2!U<'`@=FGP('3F;6EN9W4@X2`E<RX@5FEL;'5T:6QK>6YN:6YG(&YE
M=/YJ\VYS:6YS(&9Y;&=I<B!HZ7(@X2`B"B)E9G1I<B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$R,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("<E<R<@9G)O
M;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@HB5F%N9&%MX6P@:V]M('5P<"!V
M:?`@=.9M:6YG=2!P\W-T:/-L9G,N(%9I;&QU=&EL:WEN;FEN9R!N973^:O-N
M<VEN<R!F>6QG:7(@(@HB:.ER(.$@969T:7(B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ,#,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@<F5M;W9I;F<@)R5S)R!F<F]M('1H92!S>7-T96TZ("(*;7-G
M<W1R("(B"B)686YD86WA;"!K;VT@=7!P('9I\"!TYFUI;F=U(.$@)7,N(%9I
M;&QU=&EL:WEN;FEN9R!N973^:O-N<VEN<R!F>6QG:7(@:.ER(.$@(@HB969T
M:7(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@)R5S)SH@
M)7,B"FUS9W-T<B`B16MK:2!T\VMS="!A\"!S96YD82!S:V5Y=&GP.B`E<R(*
M"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@W.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R
M("(B"B)686YD86WA;"!K;VT@=7!P('9I\"!U<'!H;&7P<VQU('-K<N%R+B!3
M:W+A:6X@97(@92YT+G8N('-TYG)R:2!E;B!L97EF:6QE9W0@(@HB97(N(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@S"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H
M92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R
M("(B"B)686YD86WA;"!K;VT@=7!P('9I\"!U<'!H;&7P<VQU('-K<N%R+B!3
M:W+A:6X@97(@92YT+G8N('-TYG)R:2!E;B!L97EF:6QE9W0@(@HB97(@*"5D
M($U"*2XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#4*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R
M;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P
M87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(B(*(E9A;F1A;>%L(&MO;2!U
M<'`@=FGP('5P<&AL9?!S;'4@<VMRX7(N(%-K<N%I;B!E<B!E+G0N=BX@<W3F
M<G)I(&5N(&QE>69I;&5G="`B"B)E<BXB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R(")6
M:6QL82!K;VT@=7!P('9I\"!B:7)T:6YG=2#^97-S82!H;'5T82!S:V5Y=&ES
M:6YS(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT
M.`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R(")6:6QL82!K;VT@=7!P(/YE
M9V%R(.%T=&D@8?`@=FES=&$@=7!P:V%S=&GP+B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-S4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&5V96YT.B`E<RXB"FUS9W-T<B`B5FEL;&$@:V]M('5P<"#^96=A<B#A
M='1I(&'P('/];F$@=6UB9?!I\"!S:V5Y=&DN(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82]I;6,N<&AP.C,R"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T
M<B`B5FEL;&$@:V]M('5P<"#^96=A<B#A='1I(&'P('9I<W1A('5P<&MA<W1I
M\"XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C$P-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=&%S:SH@)7,N(@IM<V=S='(@(E9I
M;&QA(&MO;2!U<'`@_F5G87(@X71T:2!A\"!S_6YA('5M8F7P:?`@<VME>71I
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z.3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO
M;CH@)7,N(@IM<V=S='(@(D5K:VD@=/-K<W0@8?`@<V5N9&$@<VME>71I\#H@
M)7,B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Y"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@
M4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS
M9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q,#<@<&\O=')A;G-L
M871I;VXN<&AP.C$Q,3,@<&\O=')A;G-L871I;VXN<&AP.C$R-#4*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C$R-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&%N(&5R<F]R(&]P96YI;F<@=&AE(&9I;&4@)7,N(%1R>2!R
M=6YN:6YG('1R86YS;&%T:6]N+G!H<"!W:71H('1H92`B"B)F;&%G("UD('1O
M('-E92!A;GD@97)R;W(@;65S<V%G97,@9G)O;2!T:&4@>&UL('!A<G-E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S<*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P
M97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N
M+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0HC
M+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG
M('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N
M(@IM<V=S='(@(E9I;&QA(&MO;2!U<'`@=FGP(&)I<G1I;F=U(/YE<W-A(&AL
M=71A('-K97ET:7-I;G,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T-`HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@
M4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B5FEL;&$@:V]M('5P
M<"#^96=A<B#A='1I(&'P('/];F$@=6UB9?!I\"!S:V5Y=&DN(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4
M:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD
M97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C@R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z.38*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HQ,3(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HR,#`*;7-G:60@(E1H:7,@86-T:6]N
M(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3$X"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,S4Y"FUS9VED(")4
M:&ES(&%C=&EO;B!I<R!N;W0@>65T(&EM<&QE;65N=&5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS
M9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A
M<F-H:79E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,30Y"B,L(&9U>GIY"FUS9VED(")4:&ES(&1O
M97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T
M<B`BWF5T=&$@9VEL9&D@=F5R\'5R(&'P('9E<F$@=&%L82XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G
M:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL
M+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3$T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R
M96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?
M<VUT<"YP:'`Z.#`*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE
M($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@
M270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE
M($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDW."!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,#4W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#8@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-38*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Y,"!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-#`S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U-C(@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@T,PHC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.34X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#4*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R.2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#<X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M-#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R,0HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-#`X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T
M-3(*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V-"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#,R"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q-#$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S<R.`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS-S,V"FUS9VED(")4:&ES(&9I96QD(&ES(')E
M<75I<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,#8U"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT
M96=E<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(T,38*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB
M97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B
M92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX.0HC
M+"!F=7IZ>0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M
M8F5R+B(*;7-G<W1R("+>971T82!G:6QD:2!V97+P=7(@8?`@=F5R82!T86QA
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X-#`*;7-G:60@(B(*
M(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@
M4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z-38Q"FUS9VED
M(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W
M('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT
M('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N
M($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V
M:7-I="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HU.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S
M86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R
M('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E
M(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B5&%L86X@=F5R\'5R(&'P('9E<F$@
M8?`@;.%G;6%R:VD@,2XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,P-`IM
M<V=I9"`B5&AI<R!S8W)I<'0@;75S="!B92!R=6X@9G)O;2!T:&4@8V]M;6%N
M9"!L:6YE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N
M8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$T-PIM<V=I9"`B
M5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I
M9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R("+>971T
M82!G:6QD:2!V97+P=7(@8?`@=F5R82!T86QA+B(*"B,Z('-E<G9I8V5S+VEM
M86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@(E1H:7,@
M=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B
M"FUS9W-T<B`B(@HBWF5S<VD@9VQU9V=I(/YA<F8@8?`@=F5R82!V[7-U;B!F
M<N$@9VQU9V=A;G5M(/YA<B!S96T@;OT@<VME>71I(&5R=2!S86UI;BXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I
M9"`B5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C$Y"FUS9VED(")4:6-K971S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C8*(RP@9G5Z>GD*;7-G:60@(E1I;64B
M"FUS9W-T<B`B5.UM86)E;'1I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,P-0IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,3<*(RP@9G5Z>GD*;7-G:60@(E1I;64@9F]R
M;6%T(@IM<V=S='(@(E3M;6%B96QT:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(U,S<*(RP@9G5Z>GD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM
M<V=S='(@(E3M;6%B96QT:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R
M+4QE<W1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G
M:60@(E1I=&QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B5&EL(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8R.0IM<V=I9"`B(@HB
M5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R
M;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN
M9RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(U-0HC+"!F=7IZ>0IM<V=I9"`B5&]D87DB"FUS9W-T<B`B365G:6YMX6PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(X
M"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P.0HC+"!F=7IZ>0IM<V=I9"`B5&]G;R(*;7-G<W1R(")4:6PB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3<*;7-G:60@(E1O;6]R<F]W
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW-PHC+"!F=7IZ>0IM<V=I9"`B5&]P(@IM<V=S='(@(E1I;"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*
M;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C8U-PIM<V=I9"`B5')A;G-L871E9"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T
M:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A
M9"!A;F0@5&]B86=O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$W.30*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM
M<V=I9"`B5'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N
M:7-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@
M(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C
M:&]I8V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,Q"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O
M0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30P
M"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R
M97!O<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B55),.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HS,S4*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A
M('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,R-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&
M4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,S`X(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M
M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV-S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C,W,0IM<V=I9"`B56YA8FQE('1O
M(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HW-38*;7-G:60@(E5N86)L92!T;R!C;VYN
M96-T('=I=&@@4U-,+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HQ-3@@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,38S
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ.#@@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$Y,PHC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q"FUS9VED(")5;F%B;&4@=&\@8V]P>2!6
M1E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HS,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<W(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C(T.`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ.3@*;7-G:60@(E5N
M86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW.0IM<V=I9"`B
M56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@
M;F]T(&5M<'1Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR-30@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,#4*(SH@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,S(V"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-SD@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E("<E<R<Z("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0P(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HS-#0*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I
M<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C8P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,S-2!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS,S8*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HS,S`@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS
M-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HQ-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C(P-@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,38W
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#`*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$X-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,S<P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS-S@*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV
M96QY.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HW,C`*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C`S"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T
M:69I8V%T92!D971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M24U34"])35-0+G!H<#HT-3$@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T
M:"YP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D
M('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HQ,CD@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,3,T"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ
M-3@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$V,PIM<V=I9"`B
M56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#4@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C$R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,3(U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z-C<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C<R"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT-0IM
M<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HU
M.3(*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,#8W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@
M=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C@U
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C0T"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R
M>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,C@Q"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HU,S,@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C(S."!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(W-PHC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,CDS"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R
M=6X@)VUK:7-O9G,G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A
M;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C$R,B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C$R-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HQ,3(*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P.2!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ,S4*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P"B,L(&9U>GIY"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T
M<B`B16YD=7)V96MJ82(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*
M(RP@9G5Z>GD*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R(")"<F5Y=&$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S
M"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED
M(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I
M;VXZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S0Q"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,W.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS.#0*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V
M97(@=&\Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHV-`HC+"!F=7IZ>0IM<V=I9"`B56YF:6QE
M9"(*;7-G<W1R("+3;&5S:?`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C,X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;FAA;F1L960@8V]M<&]N96YT(&]F('1Y<&4Z("5S(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")5;FEC;V1E("A55$8M
M."DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B
M($5M:7)A=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI
M=&5D($MI;F=D;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B
M56YI=&5D(%-T871E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED
M(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8Y(&QI8B]"
M;&]C:R]M971A<BYP:'`Z-CD*;7-G:60@(E5N:71S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-2!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,38*;7-G:60@(E5N:VYO=VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDW"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G
M92!)1"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!C;&EM<V=I
M9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,34P,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M56YK;F]W;B!C;VUM86YD.B`E<R(*;7-G<W1R(")3YFMJ82`E<R!Y9FER(.$@
M=FEN;G5S=/;P(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A
M<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*(RP@9G5Z>GD*;7-G:60@(E5N
M;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(E-T:6QL82!N^G9E
M<F%N9&D@=.UM86)E;'1I+B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N
M=&ET>2YP:'`Z,CDV"FUS9VED(")5;FYA;65D(@IM<V=S='(@(M-N969N="(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*
M;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@
M0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET
M>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@
M870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO
M=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#8@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C8*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HY,S(*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO
M;B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C4W"B,L(&9U
M>GIY"FUS9VED(")5;G1R86YS;&%T960B"FUS9W-T<B`BTW-V87)A\"(*"B,Z
M(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P-B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$X,PHC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHS,PHC+"!F=7IZ>0IM<V=I9"`B57!D871E(@IM<V=S='(@(D1A9W,B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8T.`IM<V=I9"`B
M57!D871E(')E<W!O;F1E;G0@<W1A='5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*;7-G:60@(E5P9&%T92!U
M<V5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3,W(&%D;6EN
M+W!E<FUS+V5D:70N<&AP.C(Q-R!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@)R5S)RXB"FUS9W-T
M<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P.3(@<&\O=')A;G-L871I
M;VXN<&AP.C$R,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871I;F<@)7,@
M:&5L<"!F:6QE(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z.#$*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#$@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$X,@IM<V=I9"`B
M57!L;V%D(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M.#D*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE
M<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5
M<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@
M(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,S4@<&\O=')A;G-L871I;VXN<&AP.CDR('!O+W1R86YS;&%T:6]N
M+G!H<#HY,PHC+"!F=7IZ>0IM<V=I9"`B57-A9V4Z(@IM<V=S='(@(E-K97ET
M:2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4S-PIM<V=I9"`B57-E(%-33"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(S"FUS9VED(")5<V4@:68@;F%M92]P
M87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C8Q
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I
M<V5D(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S
M"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C4P"FUS9VED(")5<V5R($]P
M=&EO;G,B"FUS9W-T<B`B5F%L:V]S=&ER(&YO=&%N9&$B"@HC.B!S:6=N=7`N
M<&AP.C8R"B,L(&9U>GIY"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G
M<W1R(")686QK;W-T:7(@;F]T86YD82(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G
M:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T
M:&ES('-I=&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP
M.C$W,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T-@HC+"!F=7IZ
M>0IM<V=I9"`B57-E<B!P97)M:7-S:6]N<R(*;7-G<W1R(")686QK;W-T:7(@
M;F]T86YD82(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU,S4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F
M;VYE:71A;'E?<VUT<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DW('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-C4@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N
M86UE(@IM<V=S='(@(DYO=&%N9&%N869N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B57-E<FYA;64@)R5S)R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B36%P
M<&%N(%PB)7-<(B!E<B!N^B#^96=A<B!T:6PB"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.#<*(RP@9G5Z>GD*;7-G:60@(E5S97)N86UE.B(*
M;7-G<W1R(").;W1A;F1A;F%F;B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B
M3F]T86YD86YA9FXB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C(Q.0HC+"!F=7IZ>0IM<V=I9"`B57-E<G,B"FUS9W-T<B`B3F]T86YD86YA
M9FXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED
M(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$T"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C$P,2!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HQ.#@*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,34*
M(RP@9G5Z>GD*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(D'P9V5R\"(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V-@IM<V=I9"`B5F%L:60@;&]C
M871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.`IM<V=I9"`B5F%L:61I='DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU.38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C4T"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R
M;VT@;F]W+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HX-38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O
M9B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C(T-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S,30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,CDS,@IM<V=I9"`B5F%L=65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q,#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X
M-@IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,0IM<V=I9"`B5F%R:6%B;&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,C$X"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E
M(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`*(RP@9G5Z>GD*
M;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B4&5R<_-N=6QE9W0B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`R"FUS9VED(")697)S:6]N($-O;G1R
M;VPB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS
M9VED(")697)T:6-A;#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E9E<GD@2&EG:"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5FEE=&YA
M;65S92`H5DE30TE)*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HY-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE
M=R`E<R(*;7-G<W1R(")3_6YA("5S(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP
M:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,3(*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T
M<B`B4_UN82`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-SD*;7-G:60@(E9I97<@979E;G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ
M,#D*(RP@9G5Z>GD*;7-G:60@(E9I97<@=&%S:R(*;7-G<W1R(")3_6YA("5S
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I
M<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES
M;&%N9',L(%4N4RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR,#<*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-0IM<V=I9"`B5FES:6)I;&ET>3H@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N
M96ET86QY7W-M='`N<&AP.C<Y"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@
M4TU44"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"B,L
M('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-
M04Y504Q,62!&4D]-("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS
M9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP.C(Y"FUS9VED(")787)N:6YG(@IM<V=S='(@(D'P=O9R=6XB"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,30U('!O+W1R86YS;&%T:6]N+G!H<#HV.#$@
M<&\O=')A;G-L871I;VXN<&AP.C<Q,0HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-S(U('!O+W1R86YS;&%T:6]N+G!H<#HQ,#8P('!O+W1R86YS;&%T:6]N+G!H
M<#HQ,#8Y"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#<W('!O+W1R86YS;&%T
M:6]N+G!H<#HQ,#@W('!O+W1R86YS;&%T:6]N+G!H<#HQ,#DW"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,3`W('!O+W1R86YS;&%T:6]N+G!H<#HQ,3$S('!O
M+W1R86YS;&%T:6]N+G!H<#HQ,C,U"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,C0U('!O+W1R86YS;&%T:6]N+G!H<#HQ,C4Q('!O+W1R86YS;&%T:6]N+G!H
M<#HQ,C<Q"B,L(&9U>GIY"FUS9VED(")787)N:6YG.B`B"FUS9W-T<B`B0?!V
M]G)U;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`Y"FUS
M9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR"FUS9VED(")796%T:&5R+F-O
M;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I
M9"`B5V5B(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS-C8*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML
M>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR
M.`HC+"!F=7IZ>0IM<V=I9"`B5V5L8V]M92(*;7-G<W1R(")696QK;VUI;BAN
M*2#M("5S(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4P"B,L('!H<"UF;W)M870*;7-G:60@
M(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B5F5L:V]M:6XH;BD@[2`E<R(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T
M86PO;65N=2YI;F,Z,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5V5L
M8V]M92P@)7,B"FUS9W-T<B`B5F5L:V]M:6XH;BD@[2`E<R(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ
M*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I
M9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#(W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R
M(&QO9VEN/R(*;7-G<W1R(")-87!P82!E\&$@:&%M=7(@<V5M(.$@8?`@<_UN
M82#M('5P<&AA9FDZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M,C$*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(T"FUS
M9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S$*;7-G
M:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT
M(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R.0IM<V=I9"`B
M5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@
M=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT
M(&QO9RUI;BDZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B
M;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*
M;7-G:60@(E=I9'1H.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#4X"FUS9VED(")7:6MI(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"B,L(&9U>GIY"FUS
M9VED(")7:6YD(@IM<V=S='(@(D9I;FYA(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E=I;F0@16%R;'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HW.`IM<V=I9"`B5VEN
M9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$U-`HC+"!F=7IZ>0IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B1FEN
M;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`Y"B,L(&9U
M>GIY"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B1FEN;F$B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3<Y"FUS9VED(")7:7-H;&ES
M=',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"B,L
M(&9U>GIY"FUS9VED(")7;W)K(@IM<V=S='(@(F7P82(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`HC+"!F=7IZ>0IM<V=I
M9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(E-E;F1A;F1A;F5T9F%N9R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G
M:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C$Q-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)I=&EN9R!U<&1A=&5D
M(&AE;'`@9FEL92!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(R.`IM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U
M,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P.78S($5X
M=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S(%-U8FIE8W0@
M06QT97)N871I=F4@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@
M2V5Y($ED96YT:69I97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV.#(*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")9
M62(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S@V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,C<*;7-G:60@(EE965DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#(*;7-G:60@(EEA
M:&]O(2!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(EEE;65N(@IM<V=S='(@
M(DQE<VGP(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C@X.`IM<V=I9"`B665S(@IM<V=S='(@(DKA(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+V%G<F5E;65N=%]B;W1T;VTN:6YC.C8*;7-G:60@(EEE
M<RP@22!!9W)E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@
M34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@
M5UE325=91RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ,C@X"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP
M.C,P,@IM<V=I9"`B66]U(&-A;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T
M97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3DW-0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A
M9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H
M<#HR-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@
M86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R
M97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3`S"B,L(&9U>GIY"FUS9VED(")9;W4@
M:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(E-T:6QL:6YG87(@_NUN
M87(@:&%F82!V97)I\"!U<'!FYG+P87(N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P
M=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P
M<F5F:7@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q.#@*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C
M:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HT,S$*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R
M92!A(%9&4R!B86-K96YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@
M=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R
M97!O<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!5
M4DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`HC+"!F=7IZ>0IM<V=I9"`B
M66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G
M<W1R(")696QD=2!H=F'P82!K96YN:2#^^B!V:6QT(&5Y\&$N(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3$Y"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R(")4:6QG<F5I
M;F1U('9I\'1A:V%N9&$N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"B,L(&9U
M>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M
M;W9E+B(*;7-G<W1R(")4:6QG<F5I;F1U('9I\'1A:V%N9&$N(@H*(SH@861M
M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHX"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R
M;F%M92!T;R!A9&0N(@IM<V=S='(@(M[Z(/YA<F9T(&9Y<G-T(&'P('9E;&IA
M(/YA=2!V:?!H96YG:2!S96T@_OH@=FEL="!S96YD82!M9?`@<VME>71I;G4N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"B,L(&9U>GIY"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@
M(M[Z(/YA<F9T(&9Y<G-T(&'P('9E;&IA(/YA=2!V:?!H96YG:2!S96T@_OH@
M=FEL="!S96YD82!M9?`@<VME>71I;G4N(@H*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+WII<"YP:'`Z,3,W"B,L(&9U>GIY"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@
M(E1I;&=R96EN9'4@=FGP=&%K86YD82XB"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,@HC+"!F=7IZ>0IM<V=I9"`B
M66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R(")4
M:6QG<F5I;F1U('9I\'1A:V%N9&$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.#DQ"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO
M;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R("),
M;W1A;B`E<R!E<B!R=6YN:6X@^G0@X2!T[6UA+B!496YG9'4@_FEG(&%F='5R
M+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"B,L(&9U
M>GIY"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B3F5T9F%N
M9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#(*;7-G:60@(EEO=7(@
M1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B1G5L;'0@;F5T9F%N9R#^:71T("A&
M<N$Z*2`Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T
M:6]N(@IM<V=S='(@(E5P<&S]<VEN9V%R(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z.#DU"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT
M97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG
M(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R
M:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@3F%M92(*;7-G<W1R(")&=6QL="!N869N(/YI='0Z(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.CD*;7-G:60@(B(*(EEO=7(@
M875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN
M9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@
M9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.CD*;7-G:60@(B(*(EEO=7(@875T
M:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@
M=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O
M<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.#DY"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO
M=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@
M8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y
M;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB
M"FUS9W-T<B`B(@HB5F5F<VMO\&%R:2#^:6YN('-T>?!U<B!E:VMI(/YE<W-A
M('!R96YT8?!G97+P+B!.;W1A\'4@0U123"]/<'1I;VX@;V<@4"!T:6P@(@HB
M8?`@<')E;G1A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS
M.C(W"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T
M:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]/<'1I;VX@*R!0('1O
M("(*(G!R:6YT+B(*;7-G<W1R("(B"B)6969S:V_P87)I(/YI;FX@<W1Y\'5R
M(&5K:VD@_F5S<V$@<')E;G1A\&=E<O`N($YO=&'P=2!#5%),+T]P=&EO;B!O
M9R!0('1I;"`B"B)A\"!P<F5N=&$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(T-PIM<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T
M<B`B3OIV97)A;F1I('3M;6%B96QT:3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,30X"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S
M='(@(E-JX6QF9V5F:?`@:V5N;FD@_FET=#HB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3DQ"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`B
M1G5L;'0@;F%F;B#^:71T.B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ-#4*
M;7-G:60@(B(*(EEO=7(@9V5T=&5X="!V97)S:6]N(&ES('1O;R!O;&0@86YD
M(&1O97,@;F]T('-U<'!O<G0@4$A0(&YA=&EV96QY+EQN(@HB3F]T(&%L;"!S
M=')I;F=S('=I;&P@8F4@97AT<F%C=&5D+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34T"B,L(&9U>GIY
M"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H
M92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(E-T:6QL:6YG
M87(@_NUN87(@:&%F82!V97)I\"!U<'!FYG+P87(N(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H
M879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`B4W1I;&QI;F=A<B#^[6YA<B!H
M869A('9E<FGP('5P<&;F<O!A<BXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E
M="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW
M.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE
M8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S
M<W=O<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHU.`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB
M"FUS9W-T<B`B1G5L;'0@;F5T9F%N9R#^:71T("A&<N$Z*2`Z(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X
M=%TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z-38*;7-G
M:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U
M;W1E9"!497AT("TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL
M=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#,R('1E;7!L871E<R]P
M;W)T86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G
M<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,S0*;7-G:60@(E]#3$DB"FUS9W-T
M<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3(R"B,L(&9U>GIY"FUS9VED(")?1&%T
M851R964B"FUS9W-T<B`B1&%G<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0HC+"!F=7IZ>0IM<V=I9"`B
M7T1E;&5T92!2;W<B"FUS9W-T<B`B17GP82(*"B,Z(&QI8B]A<&DN<&AP.C$Q
M-`IM<V=I9"`B7T=R;W5P<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R(")(
M:N%L<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y
M-`HC+"!F=7IZ>0IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R(")496YG:F%S="(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@
M(E],;V<@;W5T(@IM<V=S='(@(MIT<VMRX2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO
M9&EF>2!,:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(E9A
M;&MO<W1I<B(*"B,Z(&QI8B]A<&DN<&AP.C$Q.`IM<V=I9"`B7U!E<FUI<W-I
M;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK+BXN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$P-@IM<V=I9"`B7U-E='5P
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N
M+BXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3$P"FUS9VED(")?57-E
M<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HX
M.3`*(RP@9G5Z>GD*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R(").971F
M86YG86+S:R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW,3$*;7-G:60@(F%N
M(&5R<F]R(&AA<R!O8V-U<F5D.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C@X,@IM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S`@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.#8*;7-G
M:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C0T-2!P;R]T<F%N<VQA=&EO;BYP:'`Z-34P('!O+W1R86YS;&%T:6]N
M+G!H<#HV,3$*(SH@<&\O=')A;G-L871I;VXN<&AP.C<T.2!P;R]T<F%N<VQA
M=&EO;BYP:'`Z.#$P('!O+W1R86YS;&%T:6]N+G!H<#HX.#<*;7-G:60@(F1O
M;F4B"FUS9W-T<B`B;&]K:?`B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-34R
M('!O+W1R86YS;&%T:6]N+G!H<#HU.#0@<&\O=')A;G-L871I;VXN<&AP.C8Q
M,PHC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S<X('!O+W1R86YS;&%T:6]N+G!H
M<#HX,3(@<&\O=')A;G-L871I;VXN<&AP.C@Y,`IM<V=I9"`B9F%I;&5D(@IM
M<V=S='(@(FML:6MK8?!I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C<*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#0Y"FUS9VED(")F:6QE
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,CD*;7-G:60@
M(F9O=6YD.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A
M="`E<R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C,R"FUS9VED(")H.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-`HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M,C(*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]D:69F+G!H<#HV."!A9&UI;B]S971U<"]D:69F+G!H<#HW-@HC+"!F=7IZ
M>0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(F5N9VEN;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O
M9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(X-R!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,C`U"B,L(&9U>GIY"FUS9VED(")N86UE
M(@IM<V=S='(@(DYA9FXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,S<X"FUS
M9VED(")N;W0@8VAA;F=E9"(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3,Q"FUS9VED(")N;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U)00R]24$,N<&AP.C$R,0HC+"!F=7IZ>0IM<V=I9"`B;F]T(&EM
M<&QE;65N=&5D(@IM<V=S='(@(D5K:VD@97ET="(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,3(Q.0HC+"!F=7IZ>0IM<V=I9"`B;F]T
M('EE="!I;7!L96UE;G1E9"(*;7-G<W1R(")%:VMI(&5Y='0B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C@W-`HC+"!F=7IZ>0IM<V=I9"`B;F]T
M97!A9"(*;7-G<W1R("+3;&5S:?`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0HC+"!F=7IZ
M>0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(D'P=O9R=6XB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.CDX"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3$S"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C@*;7-G:60@(G-T96%D>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C@Y.`HC+"!F=7IZ>0IM<V=I9"`B=&%S:R!L:7-T(@IM
M<V=S='(@(E-V87)T;&ES=&DB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S(U
M"B,L('!H<"UF;W)M870*;7-G:60@(G1H92!(;W)D92!03R!F:6QE(&9O<B!T
M:&4@;&]C86QE("5S(&1O97,@;F]T(&5X:7-T.B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,C8Y"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF
M:7)M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8X(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C<V"FUS9VED(")U;FEF:65D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<*(RP@9G5Z
M>GD*;7-G:60@(G5N;F%M960B"FUS9W-T<B`BTVYE9FYT(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C,W-0IM<V=I9"`B=7!D871E9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M-`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C(*(RP@9G5Z>GD*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(F5N
M9VEN(')E9VQA('9A;&EN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(T"B,L(&9U
M>GIY"FUS9VED(")W.B(*;7-G<W1R("+!9G)A;7,N.B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*;7-G
M<W1R("(B"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P;R]I=%])5"YP;P``````````````````````````````````````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P-C<Q-30T`#$P-3$U-#,S-S4T`#`Q-S8V-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````C($ET86QI
M86X@=')A;G-L871I;VYS(&9O<B!H;W)D92!P86-K86=E+@HC($-O<'ER:6=H
M="`H0RD@,C`P-B!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R
M:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE(&AO<F1E('!A
M8VMA9V4N"B,@075T;VUA=&EC86QL>2!G96YE<F%T960L(#(P,#8N"B,*;7-G
M:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ(&AO<F1E(#,N
M,2XQ7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E
M+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#0M,3,@,30Z,38K
M,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP-"TQ,R`Q-#HQ-BLP
M,C`P7&XB"B),87-T+51R86YS;&%T;W(Z($UA<F-O(%!I<F]V86YO(#QM87)C
M;RYP:7)O=F%N;T!U;FEB;V-C;VYI+FET/EQN(@HB3&%N9W5A9V4M5&5A;3H@
M:3$X;D!L:7-T<RYH;W)D92YO<F=<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB
M"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM
M,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@HB4&QU
M<F%L+49O<FUS.B!N<&QU<F%L<STR.R!P;'5R86P]*&X@(3T@,2D[7&XB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,V.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*"5S(&=I;W)N:2!S8V]R<VDI
M(@H*(SH@;&EB+TAO<F1E+G!H<#HQ,S@S"B,L('!H<"UF;W)M870*;7-G:60@
M(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(@*$-H:6%V92!D:2!A8V-E<W-O
M("5S*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S<W"B,L('!H<"UF;W)M
M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B("AI;B`E<R!G:6]R
M;FDI(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S,*;7-G:60@(B`H=&]D
M87DI(@IM<V=S='(@(B`H;V=G:2DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C,W-0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B("AD;VUA;FDI(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S$*;7-G:60@(B`H>65S=&5R9&%Y
M*2(*;7-G<W1R("(@*&EE<FDI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(T-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4P"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.38*;7-G:60@(B!A="`B
M"FUS9W-T<B`B(&$@82(*"B,Z(&QI8B]61E,O<VUB+G!H<#HR,3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B7"(E<UPB(&YO;B#H('5N82!D:7)E8W1O<GDN(@H*(SH@;&EB+TAO
M<F1E+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I
M<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(EPB)7-<(B!N;VX@Z"!U
M;F$@<V-E;'1A('9A;&ED82XB"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP
M.C<Q,"!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C$P.3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D
M92!296=I<W1R>2XB"FUS9W-T<B`B7"(E<UPB(&YO;B#H(&-O;F9I9W5R871O
M(&YE:2!296=I<W1R:2!D:2!(;W)D92XB"@HC.B!L:6(O2&]R9&4O5')E92YP
M:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E
M<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B7"(E<UPB(&%L8F5R;R!R96YD97)E
M<B!N;VX@=')O=F%T;RXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4V"B,L('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P
M<R!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B#H('-T871O(&%G9VEU;G1O(&%I
M(&=R=7!P:2!D:2!S:7-T96UA+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD
M+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D
M('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B#H
M('-T871O(&%G9VEU;G1O(&%I('!E<FUE<W-I(&1I('-I<W1E;6$N(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E
M9#H@)7,N(@IM<V=S='(@(EPB)7-<(B!N;VX@Z"!S=&%T;R!C<F5A=&\Z("5S
M+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E
M*2(*;7-G<W1R("(E+C)F34(@=7-A=&D@9&D@)2XR9DU"(&1I<W!O;FEB:6QI
M("@E+C)F)24I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B
M)60@)7,@92`E<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU.30@;&EB
M+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,C8X"B,L('!H<"UF;W)M870*;7-G:60@
M(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R
M("(E9"!G:6]R;FD@86QL;R!S8V%D97)E(&1E;&QA('1U82!P87-S=V]R9"XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<T"B,L('!H<"UF
M;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R("(E9"UG:6]N
M;R!P<F5V:7-I;VYE(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S
M("T@3F]T:7II82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`U
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@
M(B5S($9I<FUA($1I9VET86QE(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N
M=',N<&AP.C@T,B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#0T"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B5S($M"(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB
M"FUS9W-T<B`B)7,@3W!E<F%Z:6]N:2!D:2!-86YU=&5N>FEO;F4@+2!#;VYF
M97)M82(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C(Q-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U
M<"(*;7-G<W1R("(E<R!);7!O<W1A>FEO;F4B"@HC.B!L:6(O2&]R9&4O075T
M:"]3:6=N=7`N<&AP.C(V-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N
M(%5P(@IM<V=S='(@(B5S($9I<FUA(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G
M<F5E;65N="(*;7-G<W1R("(E<R!497)M:6YI(&1I($%C8V]R9&\B"@HC.B!L
M:6(O5D93+V9T<"YP:'`Z-CDP(&QI8B]61E,O9G1P+G!H<#HW-C,@;&EB+U9&
M4R]S;6(N<&AP.C0T,0HC.B!L:6(O5D93+W-M8BYP:'`Z-3`W"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(E<R!G
M:>`@97-I<W1E;G1E+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38V(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,C0V
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S4R(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S
M='(@(B5S(&$@)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R
M9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W
M+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W
M86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(B"B(E<R#H
M('!R;VYT;R!P97(@97-E9W5I<F4@;&4@;W!E<F%Z:6]N:2!D:2!M86YU=&5N
M>FEO;F4@<V]T=&\@<V5L97II;VYA=&4N("(*(E-E;&5Z:6]N82!L82!C87-E
M;&QA('!E<B!O9VYI(&]P97)A>FEO;F4H:2D@8VAE('9U;VD@97-E9W5I<F4@
M;W)A+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S0P"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B5S(.@@<FEC:&EE
M<W1O(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R!M:6YU=&DB"@HC.B!L
M:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3,R"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@;F]N('1R;W9A
M=&\N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(E<R!A
M("5S(&1I("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,C8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B4G5B
M<FEC82!D:2`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3$X"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B0V%L96YD
M87)I;R!D:2`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3$P"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R(").;W1E(&1I
M("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("),:7-T82!!='1I=FET
MX"!D:2`E<R(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS
M9W-T<B`B)7,Z("5S(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VAT;6PN
M<&AP.C$R-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S
M86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W
M87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O
M=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I
M;VXN(@IM<V=S='(@(B(*(B5S.B!1=65S=&\@;65S<V%G9VEO('!O=')E8F)E
M(&YO;B!A<G)I=F4@9&$@8VAI(&1I8VAI87)A(&1I(&5S<V5R92X@(@HB071T
M96YZ:6]N92!A:2!L:6YK('!R97-E;G1I(&EN(&5S<V\@;R!F;W)N:7-C:2!O
M9VYI(&EN9F]R;6%Z:6]N92!A;"!M:71T96YT92XB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S4T(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS.3D*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B+"!S;V9F:6%N
M9&\@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.34@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S
M("5S(@IM<V=S='(@(BP@<V]F9FEA;F1O("5S("5S(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L
M92!F<F]M("5S('1O("5S(@IM<V=S='(@(BP@=F%R:6%B:6QE(&1A("5S(&$@
M)7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`V.2!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C$R.`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-S0X(&QI8B](;W)D92]097)M<R]522YP:'`Z,CDT"B,Z(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,S0X"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T
M<B`B+2T@<V5L97II;VYA("TM(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P
M"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R(")&;W)M871O(#$R(&]R
M92(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B,C0@2&]U<B!&
M;W)M870B"FUS9W-T<B`B1F]R;6%T;R`R-"!O<F4B"@HC.B!T96UP;&%T97,O
M9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@
M;W)E(@H*(SH@;&EB+TAO<F1E+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R
M979I;W5S(@IM<V=S='(@(CQ0<F5C961E;G1E(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ,C8*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U
M:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B56X@9&%T86)A<V4@9&D@
M8F%C:V5N9"#H(')I8VAI97-T;R!P97(@<75E<W1O(&)L;V-C;RXB"@HC.B!L
M:6(O2&]R9&4N<&AP.C$W,0IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C
M=7)R960B"FUS9W-T<B`B12<@86-C861U=&\@=6X@97)R;W)E(&9A=&%L92(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B02!P=6)L
M:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB
M"FUS9W-T<B`B56YA(&-H:6%V92!P=6)B;&EC82!01U`@Z"!R:6-H:65S=&$@
M<&5R(&-I9G)A<F4@:6P@;65S<V%G9VEO+B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C$Q-C@*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*
M(E5N82!C:&EA=F$@<'5B8FQI8V$@4$=0(.@@<FEC:&EE<W1A('!E<B!V97)I
M9FEC87)E(&EL(&UE<W-A9V=I;R!F:7)M871O+B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C$P.3D*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B)5;F$@8VAI
M879E('!U8F)L:6-A(%!'4"P@=6YA(&-H:6%V92!P<FEV871A(%!'4"P@92!U
M;F$@<&%S<W=O<F0@<V]N;R`B"B)R:6-H:65S=&4@<&5R(&1E8VEF<F%R92!U
M;B!M97-S86=G:6\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#$V
M"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S
M<V%G92XB"FUS9W-T<B`B(@HB56YA(&-H:6%V92!P=6)B;&EC82!01U`L('5N
M82!C:&EA=F4@<')I=F%T82!01U`L(&4@=6YA('!A<W-W;W)D('-O;F\@(@HB
M<FEC:&EE<W1E('!E<B!F:7)M87)E('5N(&UE<W-A9V=I;R(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-3`V"FUS9VED("(B"B)!('!U8FQI8R!3
M+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T
M<B`B(@HB56YA(&-H:6%V92!P=6)B;&EC82!3+TU)344L('5N82!C:&EA=F4@
M<')I=F%T82!3+TU)344@92!U;F$@<&%S<W=O<F0@<V]N;R`B"B)R:6-H:65S
M=&4@<&5R(&1E8VEF<F%R92!U;F$@;65S<V%G9VEO+B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)
M344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@HB
M56YA(&-H:6%V92!P=6)B;&EC82!3+TU)344L('5N82!C:&EA=F4@<')I=F%T
M82!3+TU)344@92!U;F$@<&%S<W=O<F0@<V]N;R`B"B)R:6-H:65S=&4@<&5R
M(&9I<FUA<F4@=6X@;65S<V%G9VEO+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q
M=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(E5N82!C:&EA
M=F4@<'5B8FQI8V$@4R]-24U%(.@@<FEC:&EE<W1A('!E<B!C:69R87)E('5N
M(&UE<W-A9V=I;RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B04T@3G5B:2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS
M9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(D%-(%!I;V=G:6$@3&5G9V5R
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q
M"FUS9VED(")!32!286EN(@IM<V=S='(@(D%-(%!I;V=G:6$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@
M4VAO=V5R<R(*;7-G<W1R(")!32!!8W%U87IZ;VYI(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@
M4VAO=V5R<R(*;7-G<W1R(")!32!.979I8V%T92(*"B,Z('1E;7!L871E<R]D
M871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R(")!32]032(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED
M(")!4$D@240B"FUS9W-T<B`B05!)($E$(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E
M9&ET;W(B"FUS9W-T<B`B4FEG=6%R9&\@<75E<W1O(&5D:71O<B(*"B,Z('-E
M<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4S"FUS9VED(")!8F]U="XN+B(*;7-G
M<W1R(")2:6=U87)D;RXN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R
M"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B(@H*(SH@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,C@R"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(D%C8V5S<V\@;F5G871O(&-R96%N9&\@;&$@
M9&ER96-T;W)Y(%9&4RXB"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HQ,S8*;7-G
M:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@
M(D%C8V5S<V\@;F5G871O(&-R96%N9&\@5D93(&9I;&4N(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C,*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB
M"FUS9W-T<B`B26YF;W)M87II;VYI($%C8V]U;G0B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S@*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T
M<B`B4&%S<V]W<F0@06-C;W5N="(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T
M<B`B06-C;W5N="!C;VYG96QA=&\N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,S-0IM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R(")!8V-O=6YT
M:6YG(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S
M+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M861D8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`B06=G:75N9VDB
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP.C(R
M-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(D%G9VEU;F=I($=R
M=7!P;R!&:6=L:6\B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.CDX(&QI
M8B](;W)D92]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M
M:7-S:6]N(@IM<V=S='(@(D%G9VEU;F=I(%!E<FUE<W-I($9I9VQI;R(*"B,Z
M('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB
M"FUS9W-T<B`B06=G:75N9VD@<75I.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,C$X(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P
M(@IM<V=S='(@(D%G9VEU;F=I($YU;W9O($=R=7!P;R(*"B,Z(&QI8B](;W)D
M92]097)M<R]522YP:'`Z.#<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX.`IM
M<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(D%G9VEU;F=I($YU
M;W9O(%!E<FUE<W-O(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C
M:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G
M<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B06=G:75N9VD@=6X@9W)U<'!O(&9I
M9VQI;R!A(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,30W
M"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@
M=&\@7"(E<UPB(@IM<V=S='(@(D%G9VEU;F=I('5N('!E<FUE<W-O(&9I9VQI
M;R!A(%PB)7-<(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@
M82!N97<@=7-E<CHB"FUS9W-T<B`B06=G:75N9VD@=6X@;G5O=F\@=71E;G1E
M.B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU-38*
M;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B06=G:75N9VD@8V]L;VYN82(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*;7-G:60@
M(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R(")!9V=I=6YG:2!N=6]V:2!M96UB
M<FDB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!
M9&0@<&%I<B(*;7-G<W1R(")!9V=I=6YG:2!L82!C;W!P:6$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S<Q"B,L('!H<"UF;W)M870*;7-G:60@(D%D
M9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R(")!
M9V=I=6YG:2!I;"`E<R!-96YU(&-O;64@=6YA($UO>FEL;&$@4VED96)A<B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@
M(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(D%G9VEU;F=I(&%L;&$@
M<G5B<FEC83HB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C<X"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(D%G
M:75N9VD@86QL82!R=6)R:6-A('!E<G-O;F%L92(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R(")!9V=I=6YG:2!U=&5N
M=&4B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO
M="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*
M;7-G<W1R("(B"B)!9V=I=6YT:2!<(B5S7"(@86P@<VES=&5M82P@;6$@;F]N
M('-I('!O<W-O;F\@86=G:75N9V5R92!U;'1E<FEO<FD@(@HB:6YF;W)M87II
M;VYI.B`E<RXB"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G
M:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I
M;B!N;W<N(@IM<V=S='(@(D%G9VEU;G1O(%PB)7-<(B!A;"!S:7-T96UA+B!/
M<F$@<'5O:2!A8V-E9&5R92XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N
M;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*
M;7-G<W1R("),)V%G9VEU;G1A(&1I('5T96YT:2#H(&1I<V%B:6QI=&%T82XB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T,2!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$R-@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$W,PIM<V=I9"`B061D<F5S<R(*;7-G<W1R("));F1I<FEZ
M>F\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30Q"FUS9VED(")!
M9&1R97-S($)O;VLB"FUS9W-T<B`B4G5B<FEC82(*"B,Z(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HY-"!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M-#,Q-"YP:'`Z-38*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO
M;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(D%M;6EN:7-T<F%T;W)E("T@
M:6UP;W-T82!I('!E<FUE<W-I('!E<B!A;'1R:2!U=&5N=&DB"@HC.B!A9&UI
M;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q
M-PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B06UM:6YI<W1R87II
M;VYE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,PIM<V=I9"`B
M061S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3@*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$*
M;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-`IM<V=I9"`B06QG97)I82(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$P
M-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB
M"FUS9W-T<B`B06QL:6YE82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`B
M06QL:6YE86UE;G1O.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM
M<V=I9"`B06QL(@IM<V=S='(@(E1U='1I(@H*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I
M9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B5'5T=&D@9VQI
M('5T96YT:2!A=71E;G1I8V%T:2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@
M861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T
M<B`B5'5T=&D@:2!G<G5P<&DB"@HC.B!L:6(O2&]R9&4O4&5R;7,O9&%T871R
M964N<&AP.C<U(&QI8B](;W)D92]097)M<R]522YP:'`Z.3$*;7-G:60@(D%L
M;"!097)M:7-S:6]N<R(*;7-G<W1R(")4=71T:2!I('!E<FUE<W-I(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ
M-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B5'5T=&D@92!Q=6%T
M=')O(&D@;&%T:2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<Q"FUS9VED
M(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B5'5T=&D@9VQI
M(&EN9&ER:7IZ:2!M=6QT:7!L:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,S@*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y
M<&4_(@IM<V=S='(@(E!E<FUE='1E<F4@;&4@:6UP;W-T87II;VYI(&1I(&QI
M<W1E(&]R9&EN871E('!E<B!T:7!O/R(*"B,Z(&QI8B](;W)D92]$871A5')E
M92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B
M17-I<W1E(&=IX"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8*;7-G
M:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@(DQO9VEN($E-4U`@
M86QT97)N871I=F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$Q"FUS
M9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R(")087-S=V]R
M9"!)35-0(&%L=&5R;F%T:79A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4P,PIM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS9W-T<B`B
M571E;G1E($E-4%,@86QT97)N871I=F\B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B
M"FUS9W-T<B`B26YD:7)I>GIO(&5M86EL(&%L=&5R;F%T:79O(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T
M97,B"FUS9W-T<B`B36%S8VAE<F4@86QT97)N871I=F4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*
M;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R(")497-T;R!A;'1E<FYA
M=&EV;SHB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU."!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(W"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O4')E9G,O54DN<&AP.CDU(&QI8B](;W)D92]0<F5F<R]522YP
M:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N
M(@IM<V=S='(@(D4G('-T871O('-P96-I9FEC871O('5N('9A;&]R92!N;VX@
M=F%L:61O+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-34*
M;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@
M(D5R<F]R92!S8V]N;W-C:75T;RXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HU-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$V"FUS9VED(")!;F1O<G)A(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C0*;7-G:60@(D%N9V]L82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HU-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P"FUS9VED(")!;F=U:6QL82(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G
M:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(E)I
M<W!O<W1A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR-0IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y"FUS9VED(")!
M;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H
M96QL+G!H<#HS-B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&QI8B](;W)D92]"
M;&]C:R]522YP:'`Z-3@*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X
M+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B07!P;&EC87II
M;VYE(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L
M:6-A=&EO;B!,:7-T(@IM<V=S='(@(DQI<W1A($%P<&QI8V%Z:6]N:2(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,SD*;7-G:60@(D%P<&QI8V%T:6]N
M(&ES(')E861Y+B(*;7-G<W1R("),)V%P<&QI8V%Z:6]N92#H('!R;VYT82XB
M"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P
M;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(D%P<&QI8V$@86D@9FEG;&D@
M8V]N9&EV:7-I(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B07!P<F]V82(*"B,Z(&QI
M8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#(*;7-G:60@(D%P<')O>&EM
M871E(%-I>F4B"FUS9W-T<B`B1&EM96YS:6]N92!!<'!R;W-S:6UA=&EV82(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I
M;"(*;7-G<W1R(")!<')I;&4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W
M.`IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&QI8B](;W)D92]-
M24U%+U9I97=E<B]T9WHN<&AP.C<X"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8V"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R
M(")$:6UE;G-I;VYE(&9I;&4@:6X@87)C:&EV:6\B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O<F%R+G!H<#HU."!L:6(O2&]R9&4O34E-12]6:65W97(O
M=&=Z+G!H<#HW-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV
M-0IM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(DYO;64@07)C:&EV:6\B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P
M"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T
M;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@
M(E-E:2!S:6-U<F\@9&D@=F]L97(@<FEM=6]V97)E(&QE(')I8VAI97-T92!F
M:7)M871E('!E<B`E<R`_(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D
M96QE=&4N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E
M('EO=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S
M/R(*;7-G<W1R(")!<V5I('-I8W5R;R!D:2!V;VQE<B!E;&EM:6YA<F4@7"(E
M<UPB(&4@;V=N:2!S;W1T;RUG<G5P<&\_(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-@IM<V=I9"`B07)G96YT:6YA(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C(*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I
M9"`B07)T(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,S`*;7-G:60@(D%R=6)A(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES
M;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*
M;7-G:60@(D%S8VEI($%R="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(Y"FUS9VED(")!
M<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<S\B"FUS9W-T<B`B(@HB4FEC:&EE9&5R92!L82!C;VYF97)M
M82!P<FEM82!D:2!E<V5G=6ER92!L92!O<&5R87II;VYI(&1I(&UA;G5T96YZ
M:6]N93\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S`Y-0IM<V=I9"`B07-S
M:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(D%S<V5G;F%M96YT;R!C;VQO;FYE
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(E-I(.@@8V5R
M8V%T;R!D:2!E;&EM:6YA<F4@=6X@9W)U<'!O(&YO;B!E<VES=&5N=&4N(@H*
M(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T
M;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B
M4VD@Z"!C97)C871O(&1I(&5L:6UI;F%R92!U;B!P97)M97-S;R!N;VX@97-I
M<W1E;G1E+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS
M9W-T<B`B4VD@Z"!C97)C871O(&1I('!U8F)L:6-A<F4@=6X@<&5R;65S<V\@
M;F]N(&5S:7-T96YT92XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R
M92XB"FUS9W-T<B`B4VD@Z"!C97)C871O(&1I('!U8F)L:6-A<F4@=6YA(&-O
M;F1I=FES:6]N92!N;VX@97-I<W1E;G1E+B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]R87(N<&AP.C8T(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN
M<&AP.C@S"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"FUS
M9VED(")!='1R:6)U=&5S(@IM<V=S='(@(D%T=')I8G5T:2(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T
M<B`B06=O<W1O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C4Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C@*;7-G:60@
M(D%U<W1R:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER<W%L
M+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER<W%L.B!E<W1E
M;G-I;VYE(&EM87`@<FEC:&EE<W1A(&YO;B!T<F]V871A+B(*"B,Z(&QI8B](
M;W)D92]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A
M8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS
M9W-T<B`B075T:%]C>7)U<SH@:6P@8F%C:V5N9"!N;VX@:&$@;&4@8V%P86-I
M=.`@<FEC:&EE<W1E+B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ
M,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)U<SH@97-T96YS:6]N92!I
M;6%P(')I8VAI97-T82!N;VX@=')O=F%T82XB"@HC.B!L:6(O2&]R9&4O075T
M:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM
M96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*(D%U=&A?9G1P.B!%
M<W1E;G-I;VYE($944"!R:6-H:65S=&$@;F]N('1R;W9A=&$N($-O;7!I;&$@
M4$A0(&-O;B!L)V]P>FEO;F4@+2TB"B)E;F%B;&4M9G1P+B(*"B,Z(&QI8B](
M;W)D92]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I
M<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I
M;6%P.B`@17-T96YS:6]N92!)34%0(')I8VAI97-T82!N;VX@=')O=F%T82XB
M"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K
M<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(D%U=&A?:W)B-3H@17-T96YS:6]N92!K<F(U(')I8VAI97-T82!N;VX@
M=')O=F%T82XB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS,#(*;7-G
M:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@
M9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B075T:%]L9&%P.B!L)V%G
M9VEU;G1A(&1I('5T96YT:2!N;VX@Z"!S=7!P;W)T871A('!E<B!!8W1I=F4@
M1&ER96-T;W)Y(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S4W"FUS
M9VED(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T
M960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@HB075T:%]L9&%P
M.B!L82!C86YC96QL87II;VYE(&1I('5T96YT:2!N;VX@Z"!S=7!P;W)T871A
M('!E<B!!8W1I=F4@1&ER96-T;W)Y(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A
M<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VQD87`Z($5S=&5N<VEO
M;F4@3$1!4"!R:6-H:65S=&$@;F]N('1R;W9A=&$N(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?
M;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@HB075T:%]L9&%P.B!);7!O<W-I
M8FEL92!A9V=I=6YG97)E(&PG=71E;G1E("5S+B!1=65S=&$@Z"!L82!R:7-P
M;W-T82!D96P@(@HB<V5R=F5R.B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N
M<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L
M92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z($EM<&]S
M<VEB:6QE(&-A;F-E;&QA<F4@;"=U=&5N=&4@)7,B"@HC.B!L:6(O2&]R9&4O
M075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B075T:%]L
M9&%P.B!);7!O<W-I8FEL92!A9V=I;W)N87)E(&PG=71E;G1E("5S(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z
M(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$
M:7)E8W1O<GDN(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@;"=A9V=I;W)N86UE
M;G1O(&1E9VQI('5T96YT:2!N;VX@Z"!S=7!P;W)T871O('!E<B!!8W1I=F4@
M(@HB1&ER96-T;W)Y+B(*"B,Z(&QI8B](;W)D92]!=71H+VUC86PN<&AP.C0V
M"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B075T:%]M8V%L.B!E<W1E;G-I;VYE($U#04P@
M<FEC:&EE<W1A(&YO;B!T<F]V871A+B(*"B,Z(&QI8B](;W)D92]!=71H+W-M
M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T
M:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7W-M8F%U=&@Z
M(&5S=&5N<VEO;F4@<VUB875T:"!R:6-H:65S=&$@;F]N('1R;W9A=&$N(@H*
M(SH@;&EB+TAO<F1E+TE-05`O061M:6XN<&AP.C$P-@IM<V=I9"`B075T:&5N
M=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("),)V%U
M=&5N=&EC87II;VYE(&%L('-E<G9E<B!)34%0(.@@9F%L;&ET82XB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T
M:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(D%U=&5N=&EC87II;VYE(&9A
M;&QI=&$B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R
M(")!=71E;G1I8V%Z:6]N92!F86QL:71A+B`E<R(*"B,Z(&QI8B](;W)D92]!
M=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE
M8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R(")!=71E;G1I8V%Z:6]N
M92!R:69I=71A=&$@9&%L('-E<G9E<B!2041)55,N(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C@Y-0IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E
M<B!F86EL960N(@IM<V=S='(@(D%U=&5N=&EC87II;VYE(&%L('-E<G9E<B!&
M5%`@9F%L;&ET82XB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U
M=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T
M<B`B075T96YT:6-A>FEO;F4@86P@<V5R=F5R(%--0B!F86QL:71A+B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L
M92!F:65L9',Z(@IM<V=S='(@(D-A;7!I(&1I<W!O;FEB:6QI.B(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C4Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S$*;7-G:60@
M(D%Z97)B86EJ86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM
M<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R(")39F]N9&\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K
M9W)O=6YD($-O;&]R(@IM<V=S='(@(D-O;&]R92!S9F]N9&\B"@HC.B!L:6(O
M2&]R9&4O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A
M<W-W;W)D+B(*;7-G<W1R(")087-S=V]R9"!K97)B97)O<R!N;VX@=F%L:61A
M+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@
M:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(E5T96YT92!K97)B97)O<R!N
M;VX@=F%L:61O+B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-#4*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS.`IM<V=I9"`B
M0F%H<F%I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,`IM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-`IM<V=I
M9"`B0F%N9VQA9&5S:"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,S"FUS9VED(")"87)B861O<R(*;7-G
M<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B1&ER96-T;W)Y(&=R869I8V$@9&D@8F%S92!<
M(B5S7"(@;F]N('1R;W9A=&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C$Y"FUS9VED(")"87-E;&EN92(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C0Y"FUS9VED(")"96QA<G5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HS,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S4*;7-G:60@(D)E;&=I
M=6TB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HU,`IM<V=I9"`B0F5L:7IE(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8Q(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HS,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#`*;7-G:60@
M(D)E;FEN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-#$*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C,U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-@IM
M<V=I9"`B0FAU=&%N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R(")#
M;VUP;&5A;FYO(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP
M.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P
M;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B0FQO8V-O(%PB
M)7-<(B!D96QL)V%P<&QI8V%Z:6]N92!<(B5S7"(@;F]N('1R;W9A=&\N(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDP"FUS9VED(")";&]C
M:R!3971T:6YG<R(*;7-G<W1R("));7!O<W1A>FEO;FD@0FQO8V-O(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4
M>7!E(@IM<V=S='(@(E1I<&\@0FQO8V-O(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@
M(D=R87-S971T;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-#,*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P-PIM<V=I9"`B0F]O:VUA<FMS(@IM
M<V=S='(@(E-E9VYA;&EB<FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D97(B"FUS9W-T
M<B`B0F]R9&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R(")3
M<&5S<V]R92!D96P@8F]R9&\Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G
M<W1R(")";W)D:2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,S(*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS
M9W-T<B`B0F]S;FEA(&4@2&5R>F5G;W9I;F$B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B16YT<F%M8F4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0X"FUS
M9VED(")";W1S=V%N82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<U"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*;7-G:60@(D)O='1O;2(*
M;7-G<W1R(")"87-S;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-#<*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C0P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT
M-`IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(D)R87-I;&4B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-PIM<V=I9"`B0G)I
M=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8R(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HT,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#(*;7-G:60@
M(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT
M,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S<*;7-G:60@(D)U;&=A<FEA
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`B16QE
M;F-O('!U;G1A=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C,V"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C0U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS.0IM
M<V=I9"`B0G5R=6YD:2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#0V"FUS9VED(")#35,B"FUS9W-T<B`B0TU3(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G
M<W1R(")#4D,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM
M<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B4'5N=&D@
M1&ES=')I8G5Z:6]N92!#4DPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E
M<G1I97,N+BXB"FUS9W-T<B`B4')O<')I973@($-?96QL92XN+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3$*;7-G:60@(D-A8VAE(&EN
M:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(DQA(&-A8VAE(&EN:7II
M86QE(&YO;B#H('-T871A(&-O;7!L971A=&$N(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HY,38@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0X-0HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`T,"!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,34W"FUS9VED(")#86QE;F1A<B(*;7-G<W1R(")#
M86QE;F1A<FEO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S
M-0IM<V=I9"`B0V%L;2(*;7-G<W1R(")#86QM;R(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT
M-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(X"FUS9VED(")#86UB;V1I
M82(*;7-G<W1R(")#86UB;V=I82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-C`*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C,R(&QI8B]61E,O9G1P+G!H<#HV
M-S8@;&EB+U9&4R]S;6(N<&AP.C0S-0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HR,#,*;7-G:60@(D-A;B!N;W0@8V]P>2!F:6QE*',I("T@<V]U<F-E(&%N
M9"!D97-T:6YA=&EO;B!A<F4@=&AE('-A;64N(@IM<V=S='(@(B(*(DEM<&]S
M<VEB:6QE(&-O<&EA<F4@9FEL92AS*2`M(&QA('-O<F=E;G1E(&4@;&$@9&5S
M=&EN87II;VYE('-O;F\@=6=U86QI+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z
M,C`R(&QI8B]61E,O9G1P+G!H<#HW-3(@;&EB+U9&4R]S;6(N<&AP.C4P,0HC
M.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-C@*;7-G:60@(D-A;B!N;W0@;6]V
M92!F:6QE*',I("T@9&5S=&EN871I;VX@:7,@=VET:&EN('-O=7)C92XB"FUS
M9W-T<B`B(@HB26UP;W-S:6)I;&4@<W!O<W1A<F4@:6P@9FEL92AS*2`M(&QA
M(&1E<W1I;F%Z:6]N92#H(&%L;"=I;G1E<FYO(&1E;&QA("(*(G-O<F=E;G1E
M+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#
M86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@
M>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B));7!O<W-I8FEL92!R
M96EM<&]S=&%R92!L82!P87-S=V]R9"!A=71O;6%T:6-A;65N=&4L(&-O;G1A
M='1A("(*(FPG86UM:6YI<W1R871O<F4N(@H*(SH@;&EB+T9I;&4O0U-6+G!H
M<#HS-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F
M:6QE(%PB)7-<(B(*;7-G<W1R("));7!O<W-I8FEL92!S8VEV97)E(&YE;"!F
M:6QE(%PB)7-<(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B
M0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*
M;7-G<W1R("));7!O<W-I8FEL92!G97-T:7)E('-E<W-I;VYI(&5S=&5R;F4N
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HS,3D@;&EB+TAO<F1E
M+T%U=&@O8WER=7,N<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG
M="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R("));7!O<W-I
M8FEL92!C;VQL96=A<G-I(&%L('-E<G9E<B!)34%0.B`E<R(*"B,Z(&QI8B]&
M:6QE+T-35BYP:'`Z-#0V"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&]P
M96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&%P<FER92!I
M;"!F:6QE(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C4Q"FUS9VED(")#86YA9&$B"FUS9W-T<B`B(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V92YI;F,Z,3(@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE
M=&4N:6YC.C$Q"FUS9VED(")#86YC96PB"FUS9W-T<B`B0V%N8V5L;&$B"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N
M8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(D-A;F-E;&QA(&EL(%)E<&]R
M="!P<F]B;&5M82(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS,C,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T
M<B`B26UP;W-S:6)I;&4@96QI;6EN87)E(&EL(&9I;&4@7"(E<UPB+B(*"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H
M<#HU,@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HT-@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER
M96-T;W)Y+B(*;7-G<W1R("));7!O<W-I8FEL92!T<F]V87)E('5N82!D:7)E
M8W1O<GD@=&5M<&]R86YE82XB"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z
M.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G
M('!A<F%M971E<BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@<')O8V5D97)E('-E
M;GIA(&EL('!A<F%M971R;R`G=&%R9V5T1FEL92<N(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E
M(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB:6QE(')I;75O
M=F5R92!L82!D:7)E8W1O<GD@(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O1&%T
M851R964N<&AP.C$R."!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HV.#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R
M96X@97AI<W0N(@IM<V=S='(@(DEM<&]S<VEB:6QE(')I;75O=F5R92P@97-I
M<W1O;F\@)60@9FEG;&DN(@H*(SH@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP
M:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N
M=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M
M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@HB26UP;W-S:6)I;&4@<FEO<F1I
M;F%R92P@;"=E;&5N8V\@9F]R;FET;R!N;VX@8V]R<FES<&]N9&4@8V]N(&PG
M96QE;F-O("(*(FUE;6]R:7IZ871O+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G
M92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R("));7!O<W-I8FEL92!I
M;G-T<F%D87)E(&EL(&UE<W-A9V=I;R!A;"!N=6UE<F\@<W!E8VEF:6-A=&\N
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV
M-0IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"FUS9VED(")#
M87!T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+V=E;F5R:6-?<VUT
M<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM<V=S='(@(D-A<G)I97)A(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS"FUS9VED(")#871E9V]R:65S
M(&%N9"!,86)E;',B"FUS9W-T<B`B0V%T96=O<FEE(&4@171I8VAE='1E(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C4P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S4*
M;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(DES;VQE($-A>6UA;B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED
M(")#96QL(%!H;VYE(@IM<V=S='(@(D-E;&QU;&%R92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@
M(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R(")0<F]P<FEE=.`@0V5L;&4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM
M<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R(")2:65M<&EM96YT;R!C96QL
M93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B4')O
M<')I973@(&-E;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B
M4W!A>FEO(&-E;&QE.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C<T"FUS
M9VED(")#96QL<&AO;F4B"FUS9W-T<B`B0V5L;'5L87)E(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R(")#96YT
M<F\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C4T"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@(D-E;G1R86P@
M175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(D5U<F]P82!#971R86QE
M("A)4T\M.#@U.2TR*2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-S`P"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(D1E='1A
M9VQI(&1E;"!#97)T:69I8V%T;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-C$R"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R(")0
M<F]P<FEE=&%R:6\@9&5L($-E<G1I9FEC871O(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S
M(@IM<V=S='(@(E!O;&ET:6-H92!D96P@0V5R=&EF:6-A=&\B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C4R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C$*;7-G:60@
M(D-H860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B
M0VAA;F=E(@IM<V=S='(@(D-A;6)I82(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HS,0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS
M9W-T<B`B0V%M8FEA(&QA('1U82!087-S=V]R9"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV.0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A
M9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P
M;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*(D-A;6)I82!I;"!N
M;VUE(&4@;"=I;F1I<FEZ>F\@8VAE(&QE('!E<G-O;F4@=F5D;VYO('%U86YD
M;R!L96=G;VYO(&4@(@HB<FES<&]N9&]N;R!A;&QE('1U92!E;6%I;"XB"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G:60@(B(*(D-H
M86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H
M92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T('EO=7(@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB26P@8V%M8FEO(&1E;&QA('1U82!P
M87-S=V]R9"!N;VX@Z"!S=7!P;W)T871O(&-O;B!L82!C;VYF:6=U<F%Z:6]N
M92`B"B)C;W)R96YT92X@($-O;G1A='1A(&PG86UM:6YI<W1R871O<F4N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR-PIM<V=I9"`B0VAA<B(*;7-G<W1R(")#87)B;VYE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS
M9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R(")#:&5C7VL@3&EN:RXN+B(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HU,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3D*
M;7-G:60@(D-H:6QE(@IM<V=S='(@(D-I;&4B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8Q"FUS9VED(")#:&EN82(*;7-G
M<W1R(")#:6YA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@
M(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0VAI;F5S92!4<F%D:71I
M;VYA;"`H0FEG-2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P
M<"YI;F,Z-PIM<V=I9"`B0VAO;W-E($%P<&QI8V%T:6]N.B(*;7-G<W1R(")3
M8V5G;&D@;"=A<'!L:6-A>FEO;F4Z(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG
M;G5P+G!H<#HR-S`*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@
M(E-C96=L:2!U;F$@<&%S<W=O<F0B"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N
M=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B
M4V-E9VQI('5N(&YO;64@=71E;G1E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,P,@IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*
M;7-G<W1R(")38V5G;&D@8V]M92!V:7-U86QI>GIA<F4@;&$@9&%T83HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D
M97)E9"!L:7-T<RDB"FUS9W-T<B`B4V-E9VQI(&EL('1I<&\@9&D@<W1I;&4@
M9&5L;&$@;&ES=&$@*'!E<B!L:7-T92!O<F1I;F%T92DB"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-34*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8V"FUS9VED(")#:')I
M<W1M87,@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,N<&AP.CDQ-"!L
M:6(O3F5T+U--4RYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S
M(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R("),82!D969I
M;FEZ:6]N92!D:2!C;&%S<V4@9&D@)7,@;F]N(.@@<W1A=&$@=')O=F%T82XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM
M<V=I9"`B0VQE87(B"FUS9W-T<B`B0VAI87)O(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/
M9F9I8V4@=&%G<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3(Y"FUS9VED(")#;&5A<B!1=65R>2(*;7-G<W1R(")!;FYU;&QA($1O;6%N
M9&$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B
M16QI;6EN82!L)W5T96YT93H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B16QI
M;6EN82!U=&5N=&4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHS-`IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(D5L:6UI;F$@
M:6YF;W)M87II;VYI('5T96YT92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S
M='(@(D5L:6UI;F%R92!$;W!O("(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU
M92(*;7-G<W1R(")#;&EC:R!P97(@0V]N=&EN=6%R92(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL
M('9I82!(5%10(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H
M<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO
M<V4@5VEN9&]W(@IM<V=S='(@(D-H:75D:2!&:6YE<W1R82(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C4Q"FUS9VED(")#;&]U9',B"FUS9W-T<B`B3G5B
M:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V
M"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B3G5B:2!P<F5S=&\B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PIM<V=I
M9"`B0VQO=61Y(@IM<V=S='(@(DYU=F]L;W-O(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4V
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,@IM<V=I9"`B0V]C;W,@*$ME
M96QI;F<I($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]S:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G
M<W1R(")#:&EU9&D@4VED96)A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B
M;W)D97)S(@IM<V=S='(@(D-H:75D:2!I(&)O<F1I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C4W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,@IM<V=I9"`B0V]L;VUB
M:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O
M0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@
M(D-O;&]R92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HU,#,@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,S.`HC.B!L
M:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,Y('-E<G9I8V5S+VEM
M86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*
M;7-G<W1R(")-87!P82!#;VQO<FDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C@R.`IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R(")396QE>FEO
M;F4@8V]L;W)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(D-O;&]N;F4Z(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-#8*;7-G:60@(D-O;'5M;B!T:71L
M97,B"FUS9W-T<B`B5&ET;VQO(&-O;&]N;F4B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C8V"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B0V]M:6-H
M92(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-@IM<V=I9"`B0V]M;6%N9"(*
M;7-G<W1R(")#;VUA;F1O(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS
M9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(DQI;F5A(&1I(&-O;6%N9&\B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE
M;G0B"FUS9W-T<B`B0V]M;65N=&\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4V-PIM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B3F]M92!#
M;VUU;F4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$S,`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*
M;7-G<W1R(")!>FEE;F1A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q
M"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B0V]M<'5T97)S(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-@IM<V=I9"`B0V]N9&ET:6]N
M(@IM<V=S='(@(D-O;F1I>FEO;F4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(U-@IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R(")#;VYD:7II;VYI(@H*
M(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I
M;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B1&EF9F5R96YZ92!N96QL82!C;VYF
M:6=U<F%Z:6]N92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#8*;7-G
M:60@(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R
M='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@HB0V]N9FEG=7)A>FEO
M;F4@<&5R(&QA('-I;F-R;VYI>GIA>FEO;F4@8V]N(%!$07,L(%-M87)T<&AO
M;F5S(&4@3W5T;&]O:RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,T
M"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R
M("),82!C;VYF:6=U<F%Z:6]N92#H('9E8V-H:6$N(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U
M<F4@)7,B"FUS9W-T<B`B0V]N9FEG=7)A("5S(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!087-S=V]R
M9"(*;7-G<W1R(")#;VYF97)M82!L82!087-S=V]R9"(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HU.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-34*;7-G:60@(D-O;F=O
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8U(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-3,*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U
M8FQI8R!O9B!T:&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$Y-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S`X"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`B0V]L
M;&5G86UE;G1O(&9A;&QI=&\N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$Y-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S`X"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(D-O;&QE
M9V%M96YT;R!F86QL:71O.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HW.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BXB"FUS9W-T<B`B0V]N;F5S<VEO;F4@86P@:V5Y<V5R=F5R
M(&]U8F)L:6-O(')I9FEU=&%T82XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U
M<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB
M"FUS9W-T<B`B0V]N;F5S<VEO;F4@86P@:V5Y<V5R=F5R('!U8F)L:6-O(')I
M9FEU=&%T82X@36]T:79O.B`E<R`H)7,I(@H*(SH@;&EB+U9&4R]F='`N<&AP
M.C@X.0IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB
M"FUS9W-T<B`B0V]N;F5S<VEO;F4@86P@<V5R=F5R($944"!F86QL:71A+B(*
M"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3(T(&-O;F9I9R]H;V]K<RYP:'`N
M9&ES=#HQ,#8W"FUS9VED(")#;VYT86-T<R(*;7-G<W1R(")#;VYT871T:2(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@
M(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+B(*;7-G<W1R("))(&-O;G1A='1I('-O;F\@<W1A=&D@86=G
M:75N=&D@8V]N('-U8V-E<W-O(&%L;&$@='5A(')U8G)I8V$N(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-C`*;7-G:60@(D-O;G1E;G0@
M='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z("(*;7-G<W1R(")4:7!O(&1I(&-O
M;G1E;G5T;R!D96P@9FEL92!C;VUP<F5S<V\Z("(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R87(N<&AP.C4V(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M9WHN<&AP.C<U"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8S
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G
M<W1R(")#;VYT96YU=&D@9&D@7"(E<UPB(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C,S('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y
M"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(")#;VYT:6YU82(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8V(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HV,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3@*;7-G:60@(D-O
M;VL@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@
M(D-O<'DB"FUS9W-T<B`B0V]P:6$B"@HC.B!L:6(O5D93+W-M8BYP:'`Z-#@P
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R
M(")#;W!I82!F86QL:71A.B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM
M<V=S='(@(D-O<&EA('-E;&5Z:6]N92(*"B,Z(&QI8B].970O4TU3+W=I;E]H
M='1P+G!H<#HQ-S`@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I
M9"`B0V]S="!)1"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C8S"FUS9VED(")#;W-T82!2:6-A(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-3<*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3<W"FUS9VED(")#;W5L9"!N;W0@4$=0
M(&5N8W)Y<'0@;65S<V%G93H@(@IM<V=S='(@(DYO;B!S:2!P=?(@8VEF<F%R
M92!I;B!01U`@:6P@;65S<V%G9VEO(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z,3`U-0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z
M("(*;7-G<W1R(").;VX@<VD@<'7R(&9I<FUA<F4@:6X@4$=0(&EL(&UE<W-A
M9V=I;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED
M(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B
M3F]N('-I('!U\B!C<FEF<F%R92!I;B!3+TU)344@:6P@;65S<V%G9VEO(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD
M(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R(").;VX@<VD@<'7R
M(&9I<FUA<F4@:6X@4R]-24U%(&EL(&UE<W-A9V=I;R(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R(").;VX@<VD@
M<'7R(&%G9VEU;F=E<F4@:6P@8V]N=&%T=&\N("5S(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C0X,B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z.38*
M(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3(Q"FUS9VED(")#;W5L9"!N
M;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3F]N('-I('!U\B!I
M;G1E<G)O9V%R92!I;"!S97)V97(@3$1!4"XB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C$W,R!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,34V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C
M:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R(").;VX@<VD@<'7R('9E<FEF:6-A
M<F4@;"=E<75I;&EB<FEO+B`E<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HT-C8*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R
M+B(*;7-G<W1R("));7!O<W-I8FEL92!C;VQL96=A<G-I(&%L('-E<G9E<B!,
M1$%0+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB
M('5S:6YG($944#H@)7,B"FUS9W-T<B`B26UP;W-S:6)I;&4@8V]L;&5G87)S
M:2!A;"!S97)V97(@7"(E<UPB('5S86YD;R!&5%`Z("5S(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R("));7!O<W-I8FEL92!C<F5A<F4@=6YA(&QI<W1A(&1I(&1I<W1R
M:6)U>FEO;F4N("5S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$R
M.`IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z("(*;7-G<W1R
M("));7!O<W-I8FEL92!D96-I9G)A<F4@:6P@9&%T;R!I;B!F;W)M871O(%!'
M4#H@(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU,C,*;7-G:60@
M(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R("));7!O
M<W-I8FEL92!D96-I9G)A<F4@:6P@9&%T;R!I;B!F;W)M871O(%,O34E-12XB
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B
M"FUS9W-T<B`B26UP;W-S:6)I;&4@96QI;6EN87)E(&EL(&-O;G1A='1O+B`E
M<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I
M;VX@;&ES="X@)7,B"FUS9W-T<B`B26UP;W-S:6)I;&4@96QI;6EN87)E(&QE
M(&QI<W1A(&1I(&1I<W1R:6)U>FEO;F4N("5S(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@
M(B(*(DEM<&]S:6)I;&4@96QI;6EN87)E(&QO('-C<FEP="!D:2!A9V=I;W)N
M86UE;G1O(&1E;&PG:6UP;W-T87II;VYE(%PB)7-<(BXB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HY-3,@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HS.#$*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N
M="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R("));7!O<W-I8FEL92!D971E
M<FUI;F%R92!G;&D@:6YD:7)I>GII(&5M86EL(&1E:2!D97-T:6YA=&%R:2XB
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED
M(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G
M<W1R(")I26UP;W-S:6)I;&4@<V-A<FEC87)E(&EN(&UO9&\@8V]M<&QE=&\@
M;&$@<G5B<FEC82XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I
M8G5T:6]N(&QI<W0N(@IM<V=S='(@(DEM<&]S<VEB:6QE('-C87)I8V%R92!I
M;B!M;V1O(&-O;7!L971O(&QA(&QI<W1A(&1I(&1I<W1R:6)U>FEO;F4N(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B
M0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U
M=&EO;B!L:7-T<RXB"FUS9W-T<B`B(@HB26UP;W-S:6)I;&4@<V-A<FEC87)E
M(&EN(&UO9&\@8V]M<&QE=&\@;&$@;&ES=&$@9&5L;&4@;&ES=&4@9&D@9&ES
M=')I8G5Z:6]N92XB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2YP:'`Z.#0*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U
M=%-T<F%T96=Y+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB:6QE
M(&-A<FEC87)E(&QA('-T<F%T96=I82!<(B5S7"(N(@H*(SH@;&EB+U9&4R])
M4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(SH@
M;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M,3$P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S
M7"(N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&-R96%R92!L82!D:7)E8W1O<GD@
M7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I
M9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E
M<G9E<BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@;W1T96YE<F4@;&$@8VAI879E
M('!U8F)L:6-A(&1A;"!S97)V97(N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS
M9W-T<B`B26UP;W-S:6)I;&4@87!R:7)E(%PB)7-<(B!P97(@;&$@<FES8W)I
M='1U<F$N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M-#4@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!L:6(O
M3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("));7!O<W-I8FEL92!A<')I
M<F4@)7,N(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HT,C`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?
M5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B26UP;W-S:6)I;&4@87!R:7)E(&EL
M(&UO9'5L;R!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+U9&4R])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB
M"FUS9W-T<B`B26UP;W-S:6)I;&4@87!R:7)E(&QA(&1I<F5C=&]R>2!<(B5S
M7"(N(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$Q,2!L:6(O2&]R
M9&4O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HR,S<@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-3$V(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HV,3(*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8U-B!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-CDY"FUS9VED(")#;W5L9"!N;W0@<F5A
M8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("));7!O<W-I8FEL92!C;VYT
M871T87)E(&EL('-E<G9E<B!,1$%0+B(*"B,Z(&QI8B]61E,O3V)J96-T+G!H
M<#HR-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N
M(@IM<V=S='(@(DEM<&]S<VEB:6QE(&QE9V=E<F4@)7,N(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R
M97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M
M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U
M(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B));7!O<W-I8FEL
M92!A>GIE<F%R92!L82!P87-S=V]R9"!P97(@;"=U=&5N=&4@<FEC:&EE<W1O
M+B!!;&-U;FD@;R!T=71T:2!I("(*(F1E='1A9VQI(&YO;B!S;VYO(&-O<G)E
M='1I+B!2:7!R;W9A(&%N8V]R82!O(&-O;G1A='1A(&PG86UM:6YI<W1R871O
M<F4@<V4@(@HB;F5C97-S:71I(&1I('5L=&5R:6]R92!A:75T;RXB"@HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`W(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS,S@*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,W-2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S@Q"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#<*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B26UP;W-S
M:6)I;&4@<F5C=7!E<F%R92!!0TPB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(DEM<&]S<VEB
M:6QE(')E8W5P97)A<F4@;&$@<G5B<FEC82X@)7,B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS
M9W-T<B`B26UP;W-S:6)I;&4@<F5C=7!E<F%R92!L82!L:7-T82!D:2!D:7-T
M<FEB=7II;VYE+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B26UP;W-S:6)I
M;&4@<F5C=7!E<F%R92!L92!L:7-T92!D:2!D:7-T<FEB=7II;VYE+B`E<R(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q-PHC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,C(Q"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(DEM<&]S<VEB:6QE
M(')E8W5P97)A<F4@;&4@<&]S<VEB:6QI=.`@9&5L('-E<G9E<B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!R979E
M<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@:6YV97)T
M:7)E(&QA(&-O;F9I9W5R87II;VYE+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(DEM<&]S
M<VEB:6QE(&-A;F-E;&QA<F4@;&$@9&ER96-T;W)Y(%PB)7-<(BXB"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("))
M;7!O<W-I8FEL92!S86QV87)E(&QA(&-O;F9I9W5R87II;VYE(&1I("5S+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N
M9FEG=6%T:6]N+B(*;7-G<W1R("));7!O<W-I8FEL92!S86QV87)E('5N82!C
M;W!I82!D96QL82!C;VYF:6=U<F%Z:6]N92XB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A
M=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R("));7!O<W-I
M8FEL92!S86QV87)E('5N82!C;W!I82!D96QL82!C;VYF:6=U<F%Z:6]N93H@
M)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP
M="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"B));7!O<W-I8FEL92!S86QV87)E
M(&QO('-C<FEP="!D:2!A9V=I;W)N86UE;G1O(&1E;&QE(&EM<&]S=&%Z:6]N
M:2!S=3H@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU
M<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(DEM<&]S<VEB:6QE
M('-A;'9A<F4@:6P@9FEL92!D:2!S86QV871A9V=I;R!D96QL82!C;VYF:6=U
M<F%Z:6]N92!D:2`E<RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C
M;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@
M;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S
M(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S
M='(@(B(*(DEM<&]S<VEB:6QE('-A;'9A<F4@:6P@9FEL92!D:2!C;VYF:6=U
M<F%Z:6]N92!D:2`E<RX@4'5O:2!U<V%R92!N82!D96QL92`B"B)O<'II;VYI
M('!E<B!S86QV87)E(&EL(&-O9&EC92!S=2`E<R!O(&-O<&EA<F4@;6%N=6%L
M;65N=&4@:6P@8V]D:6-E('-O='1O('-U("(*(B5S+B(*"B,Z(&QI8B](;W)D
M92]!=71H+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T
M:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&9A<F4@=6YA
M(')U8V5R8V$@;F5L('-E<G9E<B!,1$%0+B(*"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B
M"FUS9W-T<B`B26UP;W-S:6)I;&4@86=G:6]R;F%R92!I;"!C;VYT871T;RX@
M)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S(@IM<V=S='(@(DEM<&]S<VEB:6QE(&%G9VEO<FYA<F4@
M;&$@;&ES=&$@9&D@9&ES=')I8G5Z:6]N92X@)7,B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B
M26UP;W-S:6)I;&4@<V-R:79E<F4@;&$@8V]N9FEG=7)A>FEO;F4@<&5R(%PB
M)7-<(CH@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<P"FUS9VED
M(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R
M92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("));7!O<W-I8FEL92!T
M<F]V87)E(&QA(%-I9&5B87(@9&D@36]Z:6QL82X@07-S:6-U<F%T:2!C:&4@
M<VEA(&%P97)T82XB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@
M=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD
M97(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"B));7!O<W-I8FEL92!D87)E(&%L
M;"=U=&5N=&4@7"(E<UPB(&D@<V5G=65N=&D@9&ER:71T:2!P97(@;&$@8V%R
M=&5L;&$@7"(E<R(*(EPB.B`E<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B5&5S=&\@8V]N=&%T
M;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")#
M;W5N=')Y(@IM<V=S='(@(DYA>FEO;F4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C<U"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(D-O<G-I(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B0W)E82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R(")#<F5A('5N(&QI;FLB
M"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS
M9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(D-R96$@=6YO(&YU;W9O
M(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR(&QI8B](
M;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU,@IM<V=I9"`B0W)E871E('-U
M8B!F;VQD97)S(@IM<V=S='(@(D-R96%R92!S;W1T;R!C87)T96QL92(*"B,Z
M(&QI8B](;W)D92]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(D-R96%T;W)E(&1I('!E<FUE<W-I(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,R,3(*;7-G:60@(D-R961I="!C87)D(&YU
M;6)E<B(*;7-G<W1R(").=6UE<F\@8V%R=&$@9&D@8W)E9&ET;R(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HV-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Y"FUS9VED
M(")#<F]A=&EA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-C0*;7-G:60@(D-U8F$B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R96YT(#0@4&AA
M<V5S(@IM<V=S='(@(D-O<G)E;G1E(#0@1F%S:2(*"B,Z(&%D;6EN+W-E<W-I
M;VYS+G!H<#HU,`IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R(")3
M97-S:6]N:2!C;W)R96YT:2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI
M8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S
M='(@(E1E;7!O($%T='5A;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),
M(&ES(@IM<V=S='(@(DQA(%523"!A='1U86QE(.@B"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z,S4*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`B571E
M;G1I($%T='5A;&DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED
M(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B5&5M<&\@071T=6%L92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C0*;7-G:60@(D-U<G)E
M;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B0V]N9&EZ:6]N92!C;W)R96YT93H@
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R(")3=&EL92!C;W)R96YT
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O
M("5S+B(*;7-G<W1R(")097)S;VYA;&EZ>F$@;&4@;W!E<F%Z:6]N:2!D82!E
M<V5G=6ER92!A;&PG879V:6\@9&D@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*
M;7-G<W1R(")486=L:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@
M(E1A9VQI82!L82!S96QE>FEO;F4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C8W"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B
M0VEP<F\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B0WER
M:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#8*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")#>7)I
M;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C8W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV.`IM<V=I9"`B0WIE
M8V@@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0U,B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM
M<V=I9"`B1$0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R
M-S(*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N
M=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I
M9"`B1&%I;'DB"FUS9W-T<B`B1VEO<FYA;&UE;G1E(@H*(SH@861M:6XO9&%T
M871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C<P"FUS9VED(")$871A8F%S
M92!,;V]K=7`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S
M.3@@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(*;7-G:60@
M(D1A=&4B"FUS9W-T<B`B1&%T82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@
M(D1A=&$@4FEC979U=&$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<X.0IM
M<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`B4V5L97II;VYA(&QA(&1A
M=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*;7-G:60@(D1A>2(*;7-G<W1R
M(")':6]R;F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S
M='(@(D5?;&EM:6YA($-O;&]N;F$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#$S(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-3$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B1&EC96UB<F4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B3G5M
M97)I(&1E8VEM86QI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@
M(D1I;6EN=6ES8VD@;&$@<FEE;G1R86YZ82(*"B,Z(&QI8B]P<F5F<RYP:'`Z
M,3$W(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3@W"FUS9VED(")$969A=6QT
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(D-O
M;&]R92!S=&%N9&%R9"(*"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z.38*
M;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B261E;G1I=.`@9&D@
M9&5F875L="(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-0IM<V=I9"`B
M1&5F875L="!3:&5L;"(*;7-G<W1R(")3:&5L;"!D:2!D969A=6QT(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N<R(*
M;7-G<W1R(")$969I;FEZ:6]N:2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@
M;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HT,C(*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,SD@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C<P('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3,*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHY."!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHS,0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`*
M;7-G:60@(D1E;&5T92(*;7-G<W1R(")%;&EM:6YA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"FUS9VED
M(")$96QE=&4@0V5L;"(*;7-G<W1R(")%;&EM:6YA($-E;&QA(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*;7-G:60@
M(D1E;&5T92!'<F]U<"(*;7-G<W1R(")%;&EM:6YA($=R=7!P;R(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0IM<V=I9"`B1&5L971E($QO
M9R(*;7-G<W1R(")%;&EM:6YA($QO9R(*"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z-S<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E
M;&5T92!097)M:7-S:6]N(@IM<V=S='(@(D5L:6UI;F$@4&5R;65S<V\B"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E
M;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B16QI;6EN87)E(&4@
M<W9U;W1A<F4@:2!M97-A9V=I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB
M"FUS9W-T<B`B16QI;6EN82!C96QL82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C
M;VQU;6XB"FUS9W-T<B`B16QI;6EN82!C;VQO;FYA(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA
M=&4@=&5M<&QA=&4B"FUS9W-T<B`B16QI;6EN82!L82!M87-C:&5R82!A;'1E
M<FYA=&EV82!E<VES=&5N=&4B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M-#,Q-"YP:'`Z-30*;7-G:60@(D1E;&5T92!M97-S86=E<R(*;7-G<W1R(")%
M;&EM:6YA(&D@;65S<V%G9VDB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@
M9F]R(%PB)7-<(B(*;7-G<W1R(")%;&EM:6YA(&D@<&5R;65S<VD@<&5R(%PB
M)7-<(B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(T"B,L('!H<"UF
M;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N
M9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R(")%;&EM:6YA(&D@<&5R
M;65S<VD@<&5R(%PB)7-<(B!E(&]G;FD@<V]T=&\M<&5R;65S<V\_(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M-PIM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R(")%;&EM:6YA(')I9V$B"@HC
M.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED
M(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B16QI;6EN82!L
M)VED96YT:73@('-E;&5Z:6]N871A(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S0S,30N<&AP.C4S"FUS9VED(")$96QE=&4@<W5B(&9O;&1E<G,B"FUS
M9W-T<B`B16QI;6EN82!L92!S;W1T;R!C87)T96QL92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I
M9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R(")%;&EM:6YA
M(&QA(&-O;&]N;F$@8V]R<F5N=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T
M:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B16QI;6EN82!L82!R:6=A(&-O<G)E
M;G1E(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S
M7"(N(@IM<V=S='(@(D5L:6UI;F$@;&\@<V-R:7!T(&1I(&%G9VEO<FYA;65N
M=&\@9&5L;&4@:6UP;W-T87II;VYI(&1I(%PB)7-<(BXB"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,2!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(U,PHC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-38S(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M.34*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B5&5M<&\@9"=I;G9I
M;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-S$*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B1&%N:6UA<F-A(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E
M('1H92!0<F]B;&5M(@IM<V=S='(@(D1E<V-R:79I(&EL('!R;V)L96UA(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDS."!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"FUS9VED(")$97-C<FEP=&EO
M;B(*;7-G<W1R(")$97-C<FEZ:6]N92(*"B,Z(&QI8B](;W)D92YP:'`Z,C`V
M"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM
M<V=S='(@(D1E='1A9VQI("AA;F-H92!N96P@9FEL92!D:2!L;V<@9&D@2&]R
M9&4I.B(*"B,Z(&QI8B](;W)D92YP:'`Z,C$P"FUS9VED(")$971A:6QS(&AA
M=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("))(&1E='1A9VQI('-O;F\@<W1A=&D@<V-R:71T:2!N96P@9FEL92!D:2!L
M;V<@<&5R(&PG86UM:6YI<W1R871O<F4N(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(R,0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B4W9I
M;'5P<&\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-`IM<V=I9"`B1&5W
M(%!O:6YT(@IM<V=S='(@(E!U;G1O(&1I(')U9VEA9&$B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,P,0IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO
M=7(Z("(*;7-G<W1R(")0=6YT;R!D:2!R=6=I861A('!E<B!L)W5L=&EM82!O
M<F$Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G
M:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(E!U;G1O(&1I(')U9VEA9&$Z("(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*
M;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(D1I<F5Z
M:6]N92!D82!S:6YI<W1R82!A(&1E<W1R82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R
M:6=H="!T;R!L969T(@IM<V=S='(@(D1I<F5Z:6]N92!D82!D97-T<F$@82!S
M:6YI<W1R82(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$
M:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(W,`IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R(")6
M:7-U86QI>GIA(&EL('1E;7!O(&YE;"!F;W)M871O(#(T(&]R93\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`P"FUS9VED(")$:7-P;&%Y($]P=&EO
M;G,B"FUS9W-T<B`B3W!Z:6]N:2!D:2!V:7-U86QI>GIA>FEO;F4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.#D*;7-G:60@(D1I<W!L87D@
M9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B5FES=6%L:7IZ82!P<F5V:7-I
M;VYE(&1E='1A9VQI871A(@H*(SH@;&EB+V)L;V-K+VUE=&%R+G!H<#HY,@IM
M<V=I9"`B9&ES<&QA>2!F;W)E8V%S="`H=&%F*2(*;7-G<W1R(")V:7-U86QI
M>GIA('!R979I<VEO;F4@*'1A9BDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C<Y.0IM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B1F]R;6%T;R!D
M:2!V:7-U86QI>GIA>FEO;F4B"@HC.B!L:6(O2&]R9&4O34E-12]-1$XN<&AP
M.C$Y,0IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@
M(DYO=&EF:6-A(&1I(&1I<W!O<VEZ:6]N92(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV.0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S`*;7-G:60@(D1J:6)O=71I(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(R"FUS9VED
M(")$;R!N;W0@9&5L971E(@IM<V=S='(@(DYO;B!E;&EM:6YA<F4B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E
M8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(DYO;B!A8V-E
M9&5R92!D:7)E='1A;65N=&4@;6%I;G1E;F%N8V4N<&AP(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O='-V:6YF
M;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H
M92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T
M<B`B(@HB3&%P<FEM82!R:6=A(&-O;G1I96YE(&EL(&-A;7!O(&1E:2!N;VUI
M/R!392!S:2P@<V5L97II;VYA('%U97-T82!C87-E;&QA.B(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HW,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S(*;7-G:60@(D1O
M;6EN:6-A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-S,*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS
M9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@
M(DYO;B!H86D@=6XG=71E;GIA/R!I<V-R:79I=&DN(@H*(SH@;&EB+TAO<F1E
M+TU)344O0V]N=&5N=',N<&AP.C@U,PIM<V=I9"`B1&]W;FQO860B"FUS9W-T
M<B`B4V-A<FEC82(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX
M-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B
M4V-A<FEC82`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C$*;7-G
M:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S
M8W)I<'0N(@IM<V=S='(@(DQA(&-O;F9I9W5R87II;VYE(&=E;F5R871A(.@@
M<W1A=&$@<V-A<FEC871A(&-O;64@<V-R:7!T(%!(4"XB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G
M<R(*;7-G<W1R(")$<F]G:&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HT,3,*;7-G:60@(D4M36%I;"(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--
M4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T
M97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@
M<V5R=FEC92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C<R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW
M-0IM<V=I9"`B16-U861O<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4&5R
M;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M-S(*;7-G:60@(D5D:70B"FUS9W-T<B`B4'5B8FQI8V$B"@HC.B!L:6(O2&]R
M9&4O0FQO8VLO54DN<&AP.C4P"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@
M(E9I<W5A;&EZ>F$@8FQO8V-O(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@
M861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T
M<B`B5FES=6%L:7IZ82!'<G5P<&\B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C<V(&QI8B](;W)D92]097)M<R]522YP:'`Z,3`P"FUS9VED(")%9&ET
M(%!E<FUI<W-I;VXB"FUS9W-T<B`B5FES=6%L:7IZ82!097)M97-S;R(*"B,Z
M('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B5FES=6%L:7IZ82!097)M97-S:2(*"B,Z('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B5FES=6%L:7IZ
M82!097)M97-S:2!P97(@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN
M8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R(")6:7-U86QI
M>GIA(&QE(&]P>FEO;FD@<&5R.B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@
M9F]R(%PB)7-<(B(*;7-G<W1R(")6:7-U86QI>GIA(&D@<&5R;65S:2!P97(@
M7"(E<UPB(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G
M<W1R(")6:7-U86QI>GIA(&D@<&5R;65S<VD@<&5R("5S(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C<S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW
M-PIM<V=I9"`B16=Y<'0B"FUS9W-T<B`B16=I='1O(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HW-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$W"FUS9VED(")%;"!3
M86QV861O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB
M"FUS9W-T<B`B16QE;65N=&\N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-CD@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,C0*;7-G:60@(D5M86EL(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38V('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-C@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHQ,`IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R("))
M;F1I<FEZ>F\@16UA:6PB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DV,PIM
M<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(DPG
M:6YD:7)I>GIO($5M86EL(&1E=F4@8V]R<FES<&]N9&5R92XB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3DX.0IM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M
M871I;VXB"FUS9W-T<B`B16UA:6P@8V]N(&-O;F9E<FUA(@H*(SH@;&EB+TYE
M="]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3
M($=A=&5W87DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(Y.0IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED
M(")%;7!T>2!M97-S86=E+B(*;7-G<W1R(")-97-S86=G:6\@=G5O=&\N(@H*
M(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C(T,R!L:6(O2&]R9&4O1W)O
M=7`O;&1A<"YP:'`Z-#@T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV
M-C(@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!L:6(O2&]R9&4O
M075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T
M<B`B4FES=6QT871O('9U;W1O+B(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R
M9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@
M(E)I8V5R8V$@9&5I('1E<FUI;FD@=G5O=&$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-30W"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E
M<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B"B)!
M8FEL:71A(&PG:6YS97)I;65N=&\@9&D@:6UM86=I;FD@;F5L('1E<W1O(&1A
M;&QA($=A;&QE<FEA(&1E;&QE($9O=&]G<F%F:64_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4R,@IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O
M;G1E>'0@;65N=3\B"FUS9W-T<B`B06)I;&ET87)E(&EL(&UE;G4@9&D@8V]N
M=&5S=&\@8VQI8V-A;F1O(&EL('1A<W1O(&1E<W1R;R!D96P@;6]U<V4_(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.#@@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(W.3,*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(D9I;F4@86YN;R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G
M:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(DEN9W)A9&ES8VD@;"=E9&ET
M;W(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(T"FUS9VED("(B"B)%
M;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S
M:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N
M9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B
M(@HB26YS97)I<V-I('5N82!D;VUA;F1A('-I8W5R82!C:&4@=&D@=F5R<N`@
M8VAI97-T82!S92!A=G)A:2!N96-E<W-I=.`@9&D@(@HB87IZ97)A<F4@;&$@
M='5A('!A<W-W;W)D+"!E<R`G<75A;"?H(&EL(&YO;64@9&5L('1U;R!C=6-C
M:6]L;S\G.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q.0IM<V=I9"`B16YT97(@=&AE(&EM86=E(%52
M3"!H97)E(@IM<V=S='(@(DEN<V5R:7-C:2!L)U523"!D96QL)VEM;6%G:6YE
M('%U:2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX
M.3(*;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(*;7-G<W1R("))
M;G-E<FES8VD@;&4@;&5T=&5R92!S;W1T;R!R:7!O<G1A=&4Z(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C<U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY.0IM<V=I9"`B
M17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<V
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW.0IM<V=I9"`B17)I=')E82(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HT.`HC.B!L:6(O2&]R9&4O3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="]6:65W+G!H<#HY-`IM<V=I9"`B17)R;W(B"FUS9W-T<B`B17)R
M;W)E(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@
M(D5R<F]R92!C<F5A;F1O(&EL(&)L;V-C;SH@)7,B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B17)R;W)E(&5L
M:6UI;F%N9&\@;"=A;F-O<F$@9&D@<VEN8W)O;FEA.B`E<R(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R(")%<G)O<F4@
M96QI;6EN86YD;R!I;"!L;V<@9&D@<VEN8W)O;FEA.B`E<R(*"B,Z(&QI8B](
M;W)D92]496UP;&%T92YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(D5R
M<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`B17)R;W)E(&]T=&5N
M96YD;R!I;"!C;VYT96YU=&\Z("5S(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T
M:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R(")%<G)O<F4@86=G:6]R;F%N9&\@
M;&$@<&%S<W=O<F0Z("5S(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB
M"FUS9W-T<B`B17)R;W)E(&-O;B!I;"!M97-S86=G:6\@96UA:6PN(@H*(SH@
M;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB
M+B(*;7-G<W1R(")%<G)O<F4@<V-R:79E;F1O(%PB)7-<(BXB"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<V"FUS9VED(")%
M<W1O;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z.#$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U"FUS9VED
M(")%=7)O<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,T,PIM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R(")/9VYI(#$U
M(&UI;G5T:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3,*;7-G:60@
M(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R(")/9VYI(#(@;6EN=71I(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,"!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,SDQ"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(D]G;FD@
M,S`@<V5C;VYD:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#(@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,Y-`IM<V=I9"`B179E<GD@-2!M:6YU=&5S
M(@IM<V=S='(@(D]G;FD@-2!M:6YU=&DB"@HC.B!L:6(O2&]R9&4O36%I;G1E
M;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R(")!9"!O
M9VYI(&%C8V5S<V\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0T"FUS
M9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B3V=N:2!M97IZ)V]R82(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,Y,@IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(D]G;FD@
M;6EN=71O(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*;7-G
M:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R(")686QO<FD@9"=E<V5M<&EO
M.B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HU,2!A9&UI;B]P:'!S:&5L;"YP
M:'`Z.#(@861M:6XO<W%L<VAE;&PN<&AP.C$R.`IM<V=I9"`B17AE8W5T92(*
M;7-G<W1R(")%<V5G=6DB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C8Q-`IM<V=I9"`B17AP86YD(@IM<V=S='(@(D5S<&%N9&DB
M"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS9VED(")%
M>'!A;F0@4VED96)A<B(*;7-G<W1R(")%<W!A;F1I(%-I9&5B87(B"@HC.B!L
M:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D
M("<I)R(*;7-G<W1R(")0<F5V:7-T;R`G*2<B"@HC.B!L:6(O2&]R9&4O4U%,
M+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O
M<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B:5!A<F]L82!P<F5V:7-T
M82!O('1E<FUI;F4@8VET871O(&1I(')I8V5R8V$B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G
M<W1R(")$871A(&1I('-C861E;GIA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HV-S<*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@(D5S<&]N96YT
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(D-O;&]R92!&1R(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S8*;7-G:60@(D944"!U<&QO
M860@;V8@<V5T=7`B"FUS9W-T<B`B06=G:6]R;F%M96YT;R!&5%`@9&5L;&4@
M:6UP;W-T87II;VYI(@H*(SH@;&EB+TAO<F1E+U!R969S+W-Q;"YP:'`Z,C(P
M"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T
M<B`B5&5N=&%T:79O(&9A;&QI=&\@;F5L(')E8W5P97)O(&1E;&QE('!R969E
M<F5N>F4N(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C<U(&QI8B](
M;W)D92]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C
M="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B0V]L;&5G86UE;G1O(&%L('-E
M<G9E<B!,1$%0(&9A;&QI=&\N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H
M<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB
M"FUS9W-T<B`B0V]L;&5G86UE;G1O(&%L('-E<G9E<B!334(@9F%L;&ET;RXB
M"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S(U"B,L('!H<"UF;W)M870*;7-G:60@
M(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R(").;VX@Z"!R
M:75S8VET;R!A(&-O<&EA<F4@9&$@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9G1P
M+G!H<#HW,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@
M=&\@7"(E<UPB+B(*;7-G<W1R(").;VX@Z"!R:75S8VET;R!A(&-O<&EA<F4@
M82!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z.#<*;7-G
M:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS
M9W-T<B`B3F]N(.@@<FEU<V-I=&\@82!C<F5A<F4@=6YA(&YU;W9A(&-O;FYE
M<W-I;VYE(%-!4TPN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<V."!L:6(O5D93
M+W-M8BYP:'`Z-3$T"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M
M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B3F]N(.@@<FEU<V-I=&\@82!S<&]S
M=&%R92!A(%PB)7-<(BXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-#<T"B,L('!H
M<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T
M<B`B3F]N(.@@<FEU<V-I=&\@82!R96-U<&5R87)E.B`E<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER
M(@IM<V=S='(@(D=I=7-T;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z.#0*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA
M;'9I;F%S*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C@V"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(S.`IM<V=I9"`B1F%T86P@
M17)R;W(Z(@IM<V=S='(@(D5R<F]R92!&871A;&4Z(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4Q"FUS9VED(")&
M87AE<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`S(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B1F5B8G)A:6\B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(R-PIM<V=I9"`B1F5E;',@3&EK92(*;7-G
M<W1R(")3:6UI;&4@82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,C`*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R(")3:6UI;&4@83HB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM
M<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H
M;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-#0*
M;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S,R-0IM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,CD*;7-G:60@(D9I9VQE="!F
M;VYT(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.#,*;7-G:60@(D9I:FDB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")&:6QE(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8P(&QI
M8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,L('!H<"UF;W)M870*;7-G:60@(D9I
M;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B0V]N=&5G9VEO(&9I;&4Z("5S
M(&9I;&4B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV,"!L
M:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O>FEP+G!H<#HV-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&
M:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R(")#;VYT96=G:6\@9FEL93H@
M)7,@9FEL97,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`Y"FUS
M9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B1V5S=&EO;F4@1FEL92(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8S(&QI8B](;W)D92]-
M24U%+U9I97=E<B]T9WHN<&AP.C@R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<P"FUS9VED(")&:6QE($YA;64B"FUS9W-T<B`B3F]M92!&
M:6QE(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y-S<*;7-G:60@(D9I;&4@
M<V5L96-T:6]N(@IM<V=S='(@(E-E;&5Z:6]N92!F:6QE(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$T.#8*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@
M(D-A<FEC82!&:6QE(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDP,`IM
M<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@(D-A
M<FEC86UE;G1O(&9I;&4@;F]N('-U<'!O<G1A=&\B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z.3$*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B1FEL
M=')I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HX,@IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R(")&:6YL86YD:6$B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S="!(86QF(@IM<V=S
M='(@(E!R:6UO($UE>GIO(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI
M8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G
M<W1R(")0<FEM;R!1=6%R=&\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C4W"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B4F%P
M<&]R=&\@9FES<V\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C,R"FUS9VED(")&;&EP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@
M(D9L;V%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B3F5B8FEA(@H*
M(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3`W(&QI8B]61E,O<W%L+G!H<#HR,S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T
M(@IM<V=S='(@(DQA($-A<G1E;&QA("5S(&YO;B!E<VES=&4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS9VED(")&
M;VYT($-O;&]R(@IM<V=S='(@(D-O;&]R92!D96QL82!F;VYT92(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R(")#
M:6)O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(S"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG
M="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R(")097(@8G)O=W-E<B!C:&4@;F]N
M('-U<'!O<G1A;F\@;&4@:6UM86=I;FDB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,T,0IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B4')E=FES
M:6]N92`H5$%&*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW
M,@IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U
M<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B
M"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L
M;V-K*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(DAA
M:2!D:6UE;G1I8V%T;R!L82!P87-S=V]R9#\B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#8T"FUS9VED(")&;W)M<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T
M=6YE('1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U-0IM<V=I9"`B1F]R=6US
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3$*
M;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(DEN;VQT<FDB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*
M;7-G<W1R(")692(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@(D9R86UE<R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@W"FUS
M9VED(")&<F%N8V4B"FUS9W-T<B`B1G)A;F-I82(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.CDQ"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HX-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@T"FUS
M9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,@IM<V=I9"`B1G)E
M;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM
M<V=S='(@(D1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S
M-R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0Y"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS.34*;7-G:60@(D9R;VT@=&AE("(*;7-G
M<W1R(")$82!I;"`B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FEZ
M:6]N92!#;VUP;&5T82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B
M3&YA(%!I96YA(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8U('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*;7-G:60@(D9U;&P@3F%M
M92(*;7-G<W1R(").;VUE($-O;7!L971O(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HX.`IM<V=I9"`B1V%B;VXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@
M9G)O;2(*;7-G<W1R(")'86QL97)I82!D86QL82!Q=6%L92!P<F5N9&5R92!L
M92!I;6UA9VEN:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T
M<B`B1V%L;&5R:6$Z(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HY-@IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")'96YE<F$@)7,@
M0V]N9FEG=7)A>FEO;F4B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N
M9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B0V]D
M:6-E($=E;F5R871O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HY,`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8Y"FUS9VED
M(")'97)M86YY(@IM<V=S='(@(D=E<FUA;FEA(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDQ
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,PIM<V=I9"`B1VAA;F$B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HY-`IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(D=I8FEL=&5R<F$B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-@IM<V=I9"`B1VEV
M96X@3F%M92(*;7-G<W1R(").;VUE($1A=&\B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<VED96)A<BYP:'`Z,3<Y('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$P
M"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$Y"FUS9VED(")';&]B86P@
M3W!T:6]N<R(*;7-G<W1R(")/<'II;VYI($=L;V)A;&DB"@HC.B!T96UP;&%T
M97,O<')E9G,O87!P+FEN8SHQ-PIM<V=I9"`B1V\B"FUS9W-T<B`B5F%I(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Q,S$*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(DUA<'!E($=O;V=L
M92(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L
M92!396%R8V@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(S.`IM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(E-C
M86QE(&1I(&=R:6=I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,#`*;7-G:60@(D=R965C92(*;7-G<W1R(")'<F5C:6$B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B1W)E96L@*$E3
M3RTX.#4Y+3<I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.34*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C@Y"FUS9VED(")'<F5N861A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R
M(")!;6UI;FES=')A>FEO;F4@1W)U<'!I(@H*(SH@;&EB+TAO<F1E+T=R;W5P
M+G!H<#HU.2!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'
M<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R("))(&YO;6D@
M9&5L(&=R=7!P;R!N;VX@9&5V;VYO(&5S<V5R<F4@=G5O=&DB"@HC.B!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L('!H<"UF;W)M870*;7-G:60@
M(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"B)'<F]U<%]L9&%P
M.B!);7!O<W-I8FEL92!A9V=I=6YG97)E(&EL(&=R=7!P;R`E<RX@475E<W1A
M(.@@;&$@<FES<&]S=&$@9&5L("(*(G-E<G9E<CH@(@H*(SH@;&EB+TAO<F1E
M+T=R;W5P+VQD87`N<&AP.C$Q."!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z
M,3(T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U
M<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%P.B!);7!O<W-I9&EL92!E;&EM:6YA
M<F4@:6P@9W)U<'!O("5S(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP
M.C,S."!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@
M)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@26UP;W-S:6)I;&4@86=G:6]R;F%R
M92!I;"!G<G5P<&\@)7,B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS."!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,Q-`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(D=R=7!P:2(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HY-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3@*
M;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDW
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#,*;7-G:60@(D=U86TB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,#(*;7-G:60@(D=U871E;6%L82(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,C(V('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(E!E<FUE<W-I(&1E9VQI(&]S<&ET:2(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT-S(*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R("),
M:6)R;R!D96=L:2!O<W!I=&DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.CDW"FUS9VED(")'=6EN96$B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$P,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`T
M"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-0IM<V=I9"`B1W5Y
M86YA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY-C`*;7-G
M:60@(DA434PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@
M075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3`*;7-G:60@
M(DAA:71I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA
M>F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDQ.2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,CDQ-`IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(DEN
M=&5S=&%Z:6]N92(*"B,Z(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@(DEN=&5S=&%Z:6]N:2(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P
M-PIM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(")(96)R97<@*$E33RTX.#4Y
M+3@M22DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C(@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(D%L=&5Z>F$B"@HC.B!L:6(O2&]R
M9&4O2&5L<"YP:'`Z,3@T(&QI8B](;W)D92](96QP+G!H<#HQ.#8@<V5R=FEC
M97,O:&5L<"]I;F1E>"YP:'`Z,3<*(SH@=&5M<&QA=&5S+VAE;'`O:6YD97@N
M:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T<B`B06EU=&\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP
M('5S:6YG(&5D:71O<B(*;7-G<W1R(")!:75T;R!U<V%N9&\@;"=E9&ET;W(B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W,0IM<V=I9"`B2&5L<&5R(@IM
M<V=S='(@(D%I=71A;G1E(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS
M9VED(")(96UI<W!H97)E(@IM<V=S='(@(D5M:7-F97)O(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O='-V:6YF
M;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@
M9FEL93HB"FUS9W-T<B`B475E<W1O(.@@;"=I;FEZ:6\@9&5L(&9I;&4Z(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G
M:60@(DAI9V@B"FUS9W-T<B`B06QT;R(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z
M-0IM<V=I9"`B2&]?;64B"FUS9W-T<B`B2&]?<F1E(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,#0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,PIM<V=I9"`B2&]L
M>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B4V%N=&$@4V5D
M92`H0VET=&$G(&1E;"!6871I8V%N;RDB"@HC.B!L:6(O2&]R9&4N<&AP.C$U
M-#@*;7-G:60@(DAO;64B"FUS9W-T<B`B2&]R9&4B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$R,B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@
M(DEN9&ER:7IZ;R!D:2!C87-A(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C<P"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R(")$:7)E8W1O<GD@
M9&D@8V%S82(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(E1E;&5F;VYO(&1I(&-A
M<V$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,#@*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-@IM<V=I9"`B2&]N
M9R!+;VYG(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HV-PIM<V=I9"`B2&]R9&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HT-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E
M<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C(Y.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R
M97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HT-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C4Q"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M
M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@
M96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-3$R"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE
M=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z,3(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#@S"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-
M12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.C$Q.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3,S-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y
M;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO
M<FEZ;VYT86P@4G5L92(*;7-G<W1R(")296=O;&$@;W)I>GIO;G1A;&4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@R"FUS
M9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B4FEE;7!I;65N=&\@
M;W)I>GIO;G1A;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R(")/<FEZ
M>F]N=&%L93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E
M/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@(D-O;64@<V5I(&%R<FEV871O
M('%U:3\@*%-E:2!P<F5G871O(&1I(&9A<F4@=6X@<F%P<&]R=&\A*2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@
M;65R9V4_(@IM<V=S='(@(E%U86YT92!C;VQO;FYE('9U;VD@=6YI<F4_(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M
M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R(")1=6%N
M=&D@8V%M<&D@*&-O;&]N;F4I(&-I('-O;F\@/R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO
M=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@
M(E%U86YT92!R:6=H92!V=6]I('5N:7)E/R(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C,W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D*;7-G
M:60@(DAU;6ED:71Y(@IM<V=S='(@(E5M:61I=.`B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C0X"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S
M='(@(E5M:61I=.`Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM
M<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#<*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,0IM<V=I9"`B2'5N9V%R>2(*
M;7-G<W1R(")5;F=H97)I82(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP
M:'`Z,C,U(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ-S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B
M"FUS9W-T<B`B0W)E87II;VYE(&1E;&QA(&-A<V5L;&$@24U!4"!F86QL:71A
M.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,CDU(&QI8B](
M;W)D92]!=71H+V-Y<G5S+G!H<#HR,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B0V%N
M8V5L;&%Z:6]N92!D96QL82!C87-E;&QA($E-05`@9F%L;&ET83H@)7,B"@HC
M.B!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(T,B!L:6(O2&]R9&4O075T
M:"]C>7)U<RYP:'`Z,3<Y"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I
M;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(D-R96%Z
M:6]N92!D96QL82!Q=6]T82!D96QL82!C87-E;&QA($E-05`@9F%L;&ET83H@
M)7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,Q-@IM<V=I9"`B25`@061D
M<F5S<R(*;7-G<W1R("));F1I<FEZ>F\@25`B"@HC.B!L:6(O2&]R9&4O075T
M:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA
M8FQE+B(*;7-G<W1R("));F1I<FEZ>F\@25`@;F]N(&1I<W!O;FEB:6QE+B(*
M"B,Z(&QI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!
M9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R
M("),)VEN9&ER:7IZ;R!)4"!N;VX@Z"!A;&PG:6YT97)N;R!D96P@8FQO8V-O
M($-)1%(@8V]N<V5N=&ET;RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*
M;7-G<W1R("))7VYS97)I<V-I(&QA(%))9V$@<')I;6$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C`*;7-G:60@(DEC
M96QA;F0B"FUS9W-T<B`B27-L86YD82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.#`*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B4V]L;R!)8V]N
M92(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B26-O;F4@<&5R("5S(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,0IM<V=I9"`B26-O;G,@=VET
M:"!T97AT(@IM<V=S='(@(DEC;VYE(&-O;B!T97-T;R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ.3,*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS
M9W-T<B`B3F]M92!D96QL)TED96YT:73@(@H*(SH@;&EB+TAO<F1E+TU)344O
M0V]N=&5N=',N<&AP.C8P,`HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I
M<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A
M(&YE=R!W:6YD;W<N(@IM<V=S='(@(B(*(E-E(&YO;B#H('-T871O('9I<W5A
M;&EZ>F%T;R!C;W)R971T86UE;G1E+"`E<R!A<')I<F4@:6X@=6YA(&YU;W9A
M(&9I;F5S=')A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-3D*;7-G
M:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R
M;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B
M;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@HB
M4V4@;F]N('9E9&D@;F5S<W5N82!I8V]N82!U<V%N9&\@26YT97)N970@17AP
M;&]R97(L('!O=')E<W1I(&1O=F5R("(*(G-E;&5Z:6]N87)E('%U97-T82!C
M87-E;&QA('!E<B!A;FYU;&QA<F4@;&$@=')A<W!A<F5N>F$@9&5L;&4@:6UM
M86=I;FD@4$Y'+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ-S(*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U
M="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG
M="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B
M"B)392!V961I('%U97-T;R!M97-S86=G:6\@;6$@;F]N(&PG:6UM86=I;F4L
M(&PG:6UA9VEN92!C:&4@=G5O:2!C87)I8V%R92!N;VX@(@HB<'7R(&5S<V5R
M92!V:7-U86QI>GIA=&$@9&%L('1U;R!B<F]W<V5R+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0IM
M<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B4')E+59I<W5A;&EZ>F%Z
M:6]N92!D96QL)TEM;6%G:6YE.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*
M;7-G<W1R(")54DP@26UM86=I;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*;7-G:60@(DEM86=E
M(%523#HB"FUS9W-T<B`B55),($EM;6%G:6YE.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I
M9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(DEM;6%G:6YE(&1A;&QA
M(&=A;&QE<FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE
M<GDZ(@IM<V=S='(@(DEM;6%G:6YE(&1A;&QA(&=A;&QE<FEA.B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-S8Q"FUS9VED("));6%G92!U<&QO860B"FUS
M9W-T<B`B0V%R:6-A;65N=&\@26UM86=I;F4B"@HC.B!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(DEM;6%G:6YI(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C4T"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC
M.C<@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B26UP;W)T82P@4&%S
M<V\@)60B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B
M0V%M<&D@:6UP;W)T871I.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B0V%M
M<&D@:6UP;W)T871I.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T
M97(B"FUS9W-T<B`B26Y?<V5R:7-C:2!R:6=A(&1O<&\B"@HC.B!L:6(O2&]R
M9&4O0V]M<')E<W,O>FEP+G!H<#HQ,S0*;7-G:60@(DEN8V]R<F5C="!A8W1I
M;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B0V]D:6-E(&1I(&%Z:6]N92!E<G)A
M=&\@9&%T;RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,R"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D
M+B(*;7-G<W1R(").;VUE('5T96YT92!E+V\@<&%S<W=O<F0@;F]N(&-O<G)E
M='1O+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED
M("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N
M(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(DYO;64@=71E
M;G1E(&\@:6YD:7)I>GIO(&%L=&5R;F%T:79O(&YO;B!V86QI9&\N(%)I<')O
M=F$@86YC;W)A(&\@8V]N=&%T=&$@(@HB;"=A;6UI;FES=')A=&]R92!S92!N
M96-E<W-I=&D@9&D@=6QT97)I;W)E(&%I=71O+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E
M($EN9&5N="(*;7-G<W1R(")!=6UE;G1A(&QA(')I96YT<F%N>F$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,38*;7-G
M:60@(DEN9&EA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("))
M;F1I=FED=6%L(%5S97)S(@IM<V=S='(@(E5T96YT:2!);F1I=FED=6%L:2(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,3`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q
M,@IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3D*;7-G:60@(DEN
M9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%Z:6]N92(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,3D*;7-G:60@(DEN9F]R;6%T:6]N(&YO
M(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(DEN9F]R;6%Z:6]N92!N;VX@
M<&GY(&1I<W!O;FEB:6QE+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU
M;6X@069T97(B"FUS9W-T<B`B26YS97)I<V-I($-?;VQO;FYA($1O<&\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3<*;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R("));G-E<FES
M8VD@26UM86=I;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`B26YS
M97)I<V-I(%1A8F5L;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T
M<B`B26YS97)I<V-I(&QI;FL@=V5B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@
M7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B26YS97)I<V-I(%]#;VQO;FYA(%!R
M:6UA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R
M('1H92!C=7)R96YT(&]N92(*;7-G<W1R("));G-E<FES8VD@=6YA(&YU;W9A
M(&-O;&]N;F$@9&]P;R!Q=65L;&$@8V]R<F5N=&4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@
M(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*
M;7-G<W1R("));G-E<FES8VD@=6YA(&YU;W9A(&-O;&]N;F$@<')I;6$@9&D@
M<75E;&QA(&-O<G)E;G1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@
M<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("));G-E<FES8VD@
M=6YA(&YU;W9A(')I9V$@9&]P;R!Q=65L;&$@8V]R<F5N=&4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*
M;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N
M92(*;7-G<W1R("));G-E<FES8VD@=6YA(&YU;W9A(')I9V$@<')I;6$@9&D@
M<75E;&QA(&-O<G)E;G1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A
M9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("));G-E<FES
M8VD@=6X@<&%R86=R869O(&1O<&\@:6P@;F]D;R!C;W)R96YT92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N
M="!N;V1E(@IM<V=S='(@(DEN<V5R:7-C:2!U;B!P87)A9W)A9F\@<')I;6$@
M9&5L(&YO9&\@8V]R<F5N=&4B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U
M,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("))
M;G-E<FES8VD@=6YA(&UA<V-H97)A(&%L=&5R;F%T:79A(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(T,@IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D
M9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O
M<F0Z(@IM<V=S='(@(B(*(DEN<V5R:7-C:2!U;B!I;F1I<FEZ>F\@96UA:6P@
M86P@<75A;&4@<&]T<F%I(')I8V5V97)E(&QA(&YU;W9A('!A<W-W;W)D.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(DEN<V5R
M:7-C:2!U;F$@8V5L;&$@9&]P;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL
M(&)E9F]R92(*;7-G<W1R("));G-E<FES8VD@=6YA(&-E;&QA('!R:6UA(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R("));G-E
M<FES8VD@=6YA(&-O;&]N;F$@9&]P;R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C
M;VQU;6X@8F5F;W)E(@IM<V=S='(@(DEN<V5R:7-C:2!U;F$@8V]L;VYN82!P
M<FEM82(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,"!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3`*;7-G:60@(DEN<V5R
M="!M97-S86=E<R(*;7-G<W1R("));G-E<FER92!M97-S86=G:2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R("));G-E
M<FES8VD@=6X@<&%R86=R869O(&1O<&\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R
M="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(DEN<V5R:7-C:2!U;B!P87)A
M9W)A9F\@<')I;6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM
M<V=S='(@(DEN<V5R:7-C:2!U;F$@<FEG82!D;W!O(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B
M26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B26YS97)I<V-I('5N82!R:6=A
M('!R:6UA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,PIM<V=I9"`B
M26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U
M97-T:6]N.B(*;7-G<W1R("));G-E<FES8VD@;&$@<FES<&]S=&$@<FEC:&EE
M<W1A(&%L;&$@9&]M86YD82!D:2!S:6-U<F5Z>F$Z(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS97)T
M+TUO9&EF>2!);6%G92(*;7-G<W1R("));G-E<FES8VDO34]D:69I8V$@;"=I
M;6UA9VEN92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R("))
M;G-E<FES8VDO34]D:69I8V$@:6P@;&EN:R(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D
M:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@
M(D-R961I=&D@:6YS=69F:6-I96YT:2!P97(@<W!E9&ER92!A;&QA(&QI<W1A
M(&1I(&1I<W1R:6)U>FEO;F4N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS
M9W-T<B`B0W)E9&ET:2!I;G-U9F9I8VEE;G1I+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,#<U"FUS9VED("));G1E9V5R(@IM<V=S='(@(DEN=&5R;R(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3,S"FUS9VED("));G1E9V5R(&QI
M<W0B"FUS9W-T<B`B3&ES=&$@:6YT97)A(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E
M<B!$871A($AE861E<BDN(@IM<V=S='(@(E5$2"!N;VX@=F%L:61A("A5<V5R
M($1A=&$@2&5A9&5R*2XB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H
M<#HQ-C<@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3DT"B,Z(&QI8B](
M;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C(Q,@IM<V=I9"`B26YV86QI9"!:25`@
M9&%T82(*;7-G<W1R(")$871A(%I)4"!N;VX@=F%L:61A(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO
M;BXB"FUS9W-T<B`B07!P;&EC87II;VYE(&YO;B!V86QI9&$N(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L
M:60@8F%T8V@@240N(@IM<V=S='(@(D)A=&-H($E$(&YO;B!V86QI9&\B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`X-R!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C$U."!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(S,@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C(Y.2!L:6(O2&]R9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS
M-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B:4PG
M:6YF;W)M87II;VYE('-O='1O;65S<V$@;F]N(.@@=F%L:61A+B(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("));G9A
M;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(DPG:6YD:7)I>GIO
M(&1I(&1D97-T:6YA>FEO;F4@;F]N(.@@=F%L:61O+B(*"B,Z(&QI8B](;W)D
M92]#;VUP<F5S<R]D8G@N<&AP.C$P.2!L:6(O2&]R9&4O0V]M<')E<W,O9&)X
M+G!H<#HQ,SD*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,C0Q"FUS
M9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(DEL(&9O<FUA=&\@
M9&5L(&9I;&4@;F]N(.@@=F%L:61O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$V-0IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS
M9W-T<B`B3&$@8VAI879E(&1E;&QA(&QI8V5N>F$@;F]N(.@@=F%L:61A+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@(DEN
M=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(DEL(&QO9V\@9F]R
M;FET;R!N;VX@Z"!V86QI9&\N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S
M='(@(FUS9U]T>7!E(&YO;B!V86QI9&\N(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN
M9R!A<&E?:60N(@IM<V=S='(@(F%P:5]I9"!N;VX@=F%L:61O(&\@;6%N8V%N
M=&4N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*
M;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G<W1R
M(")087)A;65T<F\@;F]N('9A;&ED;R!O(&UA;F-A;G1E+B(*"B,Z(&%D;6EN
M+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI9"!P87)E;G0@
M<&5R;6ES<VEO;BXB"FUS9W-T<B`B4&5R;65S<V\@9&5L(&=E;FET;W)E(&YO
M;B!V86QI9&\N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V
M,0IM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R(")I9"!D96P@
M<&%R=&YE<B!N;VX@=F%L:61O+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-C,*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G
M<W1R(")#;V1I8V4@<')O9&]T=&\@;F]N('9A;&ED;RXB"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P
M<F]T;V-O;"XB"FUS9W-T<B`B4')O=&]C;VQL;R!N;VX@=F%L:61O+B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,R!L:6(O3F5T+U--
M4R]W:6Y?:'1T<"YP:'`Z-S$*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP
M.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B!<
M(B5S7"(B"FUS9W-T<B`B1&5S=&EN871A<FEO(&YO;B!V86QI9&\Z(%PB)7-<
M(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3`X,"!L:6(O2&]R9&4O2V]L
M86(N<&AP.C$R-C,*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S
M='(@(D]G9V5T=&\@8V]N9&EV:7-O(&YO;B!V86QI9&\B"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S
M;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B26YD:7)I>GIO('-O<F=E;G1E(&YO
M;B!V86QI9&\N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4Y"FUS9VED("));G9E
M;G1O<GDB"FUS9W-T<B`B26YV96YT87)I;R(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HV-S@*;7-G:60@(DEN=F5R="!S96QE8W1I
M;VXB"FUS9W-T<B`B26YV97)T:2!L82!S96QE>FEO;F4B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3D*;7-G:60@(DER
M86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$Q,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$X"FUS9VED("))
M<F%Q(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Q,PIM<V=I9"`B27)E;&%N9"(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA
M;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3$T"FUS9VED("))<W)A96PB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HV,C8*;7-G:60@(DES<W5E<B(*;7-G<W1R(")%;6ET
M=&5N=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C$*;7-G:60@(DET86QY
M(@IM<V=S='(@(DET86QI82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$R,PIM<V=I9"`B2F%M86EC82(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N
M=6%R>2(*;7-G<W1R(")'96YN86EO(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(U"FUS9VED(")*87!A;B(*;7-G<W1R
M(")':6%P<&]N92(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED
M(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,C0*;7-G:60@(DIO<F1A;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R("),=6=L:6\B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N
M92(*;7-G<W1R(")':75G;F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S
M='(@(D=I=7-T:69I8V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B
M"FUS9W-T<B`B1VEU<W1I9FEC82!A;"!C96YT<F\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B
M2G5S=&EF>2!&=6QL(@IM<V=S='(@(D=I=7-T:69I8V$@='5T=&\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(D=I=7-T:69I8V$@82!S
M:6YI<W1R82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@
M(D=I=7-T:69I8V$@82!D97-T<F$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,S8*;7-G:60@(DMA>F%K:'-T86XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(V-0IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B36%N=&5N97)E
M(&PG;W)I9VEN86QE/R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$R-@IM<V=I9"`B2V5N>6$B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E
M<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26P@<V5R
M=F5R($ME<F)E<F]S(&AA(')I9FEU=&%T;R!L)V%U=&5N=&EC87II;VYE+B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE
M=V)I97,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M-#$Q"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B0W)E87II;VYE(&-H
M:6%V92(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B
M2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(DEM<')O;G1A(&1I9VET86QE(&1E
M;&QA(&-H:6%V92(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,@IM
M<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R("),=6YG:&5Z>F$@9&5L;&$@8VAI
M879E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+
M97D@5'EP92(*;7-G<W1R(")4:7!O(&1E;&QA(&-H:6%V92(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-3DY"FUS9VED(")+97D@57-A9V4B"FUS
M9W-T<B`B57-O(&1E;&QA(&-H:6%V92(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("),82!C:&EA=F4@Z"!G:>`@<')E
M<V5N=&4@<W5L(&ME>7-E<G9E<B!P=6)B;&EC;RXB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B0F%M:6)I;FDB
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,CD*;7-G:60@(DMI<FEB871I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,C(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,@IM<V=I9"`B2V]R96$L
M($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#4@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$R,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,S
M"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,S0*;7-G:60@(DMU=V%I="(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C<*;7-G:60@
M(DMY<F=Y>G-T86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M
M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@(D1I7W-P;W-I>FEO
M;F4B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),
M86YG=6%G92(*;7-G<W1R("),:6YG=6%G9VEO(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R
M-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,W"FUS9VED("),86\@4&5O
M<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B
M56QT:6UO(&UE>GIO(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@X"FUS
M9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R(")5;'1I;6$@<&]S
M<VEB:6QI=.`@<&5R(&EL(&-A;6)I;R!D96QL82!P87-S=V]R9"(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G
M:60@(DQA<W0@475A<G1E<B(*;7-G<W1R(")5;'1I;6\@<75A<G1O(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3@*;7-G:60@(DQA<W0@57!D871E9#HB
M"FUS9W-T<B`B56QT:6UO(&%G9VEO<FYA;65N=&\Z(@H*(SH@;&EB+TAO<F1E
M+T%U=&@N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN
M.B`E<R(*;7-G<W1R(")5;'1I;6$@8V]N;F5S<VEO;F4Z("5S(@H*(SH@;&EB
M+TAO<F1E+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T
M(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(E5L=&EM82!C;VYN;F5S<VEO
M;F4Z("5S(&1A("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C<Q-`IM<V=I
M9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B56QT:6UA(&-O;FYE<W-I
M;VYE.B!-86DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-#8*;7-G:60@(DQA='9I82(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA=R(*;7-G<W1R("),96=G
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(D1I<W!O<VEZ:6]N92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*
M;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B3&%S
M8VEA;&\@=G5O=&\@<&5R(&%V97)L;R!S96YZ82!B;W)D:2(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,C@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S.`IM<V=I9"`B
M3&5B86YO;B(*;7-G<W1R("),:6)A;F\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*;7-G:60@(DQE9G0B"FUS
M9W-T<B`B4VEN:7-T<F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P,0IM
M<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B26YT97-T87II;VYE(&1I('-I
M;FES=')A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,P.3<*;7-G:60@(DQE
M9G0@=F%L=65S(@IM<V=S='(@(E9A;&]R:2!D:2!S:6YI<W1R82(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@X(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,CD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,PIM<V=I
M9"`B3&5S;W1H;R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR-34*;7-G:60@(DQE=F5L(@IM<V=S='(@(DQI=F5L;&\B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#(*
M;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30W"FUS9VED("),:6)Y86X@07)A
M8B!*86UA:&ER:7EA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,`IM<V=I9"`B3&EE8VAT96YS=&5I
M;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@IM<V=I
M9"`B3&EG:'0@4F%I;B(*;7-G<W1R(")0:6]G9VEA(&QE9V=E<F$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B
M3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,
M871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G
M:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO
M=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM
M<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$X,30*;7-G:60@(DQI;FLB"FUS9W-T<B`B0V]L;&5G86UE;G1O(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B26P@8V]L
M;&5G86UE;G1O('!U;G1A(&$Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X
M-S4*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O
M<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B(@HB0V]L;&5G82!L
M)VEN9&ER:7IZ;R!E;6%I;"!A;&QA('!A9VEN82!D:2!C;VUP;W-I>FEO;F4@
M<75A;F1O('9I96YE("(*(G9I<W5A;&EZ>F%T;R(*"B,Z(&QI8B](;W)D92]4
M97AT+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,@IM<V=I9"`B3&EN:W,B"FUS
M9W-T<B`B0V]L;&5G86UE;G1I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0V"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V(&QI8B](;W)D92])34%0+T%#
M3"]R9F,T,S$T+G!H<#HT-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T
M:&4@9F]L9&5R(@IM<V=S='(@(D5L96YC;R`M(&PG=71E;G1E('!U\B!V961E
M<F4@;&4@8V%R=&5L;&4B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,T"FUS
M9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R(")%;&5N8V\@9&5I(&1A=&%B
M87-E(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3$*;7-G:60@(DQI
M<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B16QE;F-O(&1E:2!S;V=G971T:2!D
M96QL)V%I=71O(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B
M3&ES="!486)L97,B"FUS9W-T<B`B16QE;F-O(%1A8F5L;&4B"@HC.B!L:6(O
M2&]R9&4O34E-12](96%D97)S+G!H<#HV,#$*;7-G:60@(DQI<W0M07)C:&EV
M92(*;7-G<W1R(")!<F-H:79I;R!D96QL82!,:7-T82(*"B,Z(&QI8B](;W)D
M92]-24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U(96QP(@IM<V=S
M='(@(D%I=71O(&1E;&QA($QI<W1A(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A
M9&5R<RYP:'`Z-C`S"FUS9VED("),:7-T+4ED(@IM<V=S='(@(DED96YT:69I
M8V%T:79O(&1E;&QA($QI<W1A(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R
M<RYP:'`Z-3DY"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@(E!R;W!R:65T
M87)I;R!D96QL82!L:7-T82(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N
M<&AP.C8P,`IM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]-24U%+TAE861E<G,N<&AP.C4Y.`IM<V=I9"`B3&ES="U3=6)S8W)I
M8F4B"FUS9W-T<B`B27-C<FEZ:6]N92!A;&QA($QI<W1A(@H*(SH@;&EB+TAO
M<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DW"FUS9VED("),:7-T+55N<W5B<V-R
M:6)E(@IM<V=S='(@(D%N;G5L;&$@;"=I<V-R:7II;VYE(&%L;&$@3&ES=&$B
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(DPG96QE
M;F-O(&1E;&QE('-E<W-I;VYE(.@@9F%L;&ET;SH@)7,B"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U
M<V5R<R!F86EL960Z("5S(@IM<V=S='(@(DPG96QE;F-O(&1E9VQI('5T96YT
M:2#H(&9A;&QI=&\Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L
M:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*
M;7-G<W1R("),)V5L96YC;R!D96=L:2!U=&5N=&D@Z"!D:7-A8FEL:71A=&\N
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T
M=7)E(@IM<V=S='(@(DQE='1E<F%T=7)A(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30T"FUS9VED("),:71H=6%N:6$B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEM86=E<RYP
M:'`Z-S<*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B0V%R:6-A;65N=&\N
M+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`P"FUS9VED
M("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B3W)A(&QO8V%L93H@(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@V"FUS9VED("),;V-A;&4@86YD(%1I;64B
M"FUS9W-T<B`B3&EN9W5A(&4@3W)A(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HW,B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C4W(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3<R"FUS9VED("),;V-A=&EO;B(*;7-G<W1R("),=6]G;R(*"B,Z(&QO9VEN
M+G!H<#HQ.#D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(P-"!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"B,Z('1E;7!L871E<R]L;V=I;B]M
M;V)I;&4N:6YC.C,@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34*;7-G
M:60@(DQO9R!I;B(*;7-G<W1R(")%;G1R82(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@
M<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A
M<BYP:'`Z,3DX"FUS9VED("),;V<@;W5T(@IM<V=S='(@(D5S8VDB"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$*;7-G:60@(DQO9VEN(@IM<V=S='(@
M(D5N=')A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,`IM<V=I9"`B
M3&]G:6X@5&%S:W,B"FUS9W-T<B`B3W!E<F%Z:6]N:2!D:2!!8V-E<W-O(@H*
M(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDY-0IM<V=I9"`B3&]G:6X@9F%I;&5D
M(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E
M9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB3"=A8V-E<W-O(.@@9F%L;&ET
M;R!P97)C:.@@:6P@;F]M92!U=&5N=&4@;R!L82!P87-S=V]R9"!I;G-E<FET
M:2!N;VX@<V]N;R`B"B)C;W)R971T:2XB"@HC.B!L:6(O2&]R9&4O075T:"YP
M:'`Z.3DQ"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@(D%C8V5S<V\@
M9F%L;&ET;RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,V-0IM<V=I9"`B
M3&]N9R!T97AT(@IM<V=S='(@(E1E<W1O(&QU;F=O(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@(D%M;W)E(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G
M:60@(DQO=R(*;7-G<W1R(")"87-S;R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R
M(&=R965K(&QE='1E<G,B"FUS9W-T<B`B3&5T=&5R92!G<F5C:&4@;6EN=7-C
M;VQE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G
M<W1R("),971T97)E(&QA=&EN92!M:6YU<V-O;&4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED
M("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(DYU;65R:2!R;VUA;FD@
M;6EN=7-C;VQI(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,30U"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(DQU<W-E
M;6)U<F=O(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P,2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@S"FUS9VED(")-3U1$(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS
M-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A
M+B(*;7-G<W1R(")-4RU43D5&(&PG86QL96=A=&\@;F]N(&-O;G1I96YE(&EN
M9F]R;6%Z:6]N:2XB"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3<*;7-G
M:60@(DUA8V%O(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDQ(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$U,PIM<V=I9"`B36%C961O;FEA+"!4:&4@
M1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDP(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,S<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,0IM<V=I
M9"`B36%D86=A<V-A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#D*;7-G:60@(DUA9VEC(@IM<V=S='(@(DUA9VEC;R(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,PIM<V=I9"`B36%I;"(*;7-G<W1R
M(")0;W-T82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C0*;7-G
M:60@(DUA:6P@061M:6XB"FUS9W-T<B`B26YD:7)I>GIO(&%M;6EN:7-T<F%T
M;W)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(D-R
M96$@8V]L;&5G86UE;E]T;RXN+B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$V-0IM<V=I9"`B36%L87=I(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$V-PIM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$T,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38T"FUS9VED(")-86QD
M:79E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-30*;7-G:60@(DUA;&DB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$T,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38R"FUS
M9VED(")-86QT82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.30*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S
M('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB
M87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*
M(D=E<W1I<V-I(&PG96QE;F-O(&1E;&QE(&-A=&5G;W)I92!E=&EC:&5T=&%N
M9&\@9VQI(&%R=&EC;VQI+"!E(&-O;B!I(&-O;&]R:2`B"B)A<W-O8VEA=&D@
M86QL92!C871E9V]R:64N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$Q-38*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-PHC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$W,0IM<V=I9"`B
M36%P475E<W0@;6%P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B
M36%R8V@B"FUS9W-T<B`B36%R>F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED(")-87)G:6XB"FUS
M9W-T<B`B36%R9VEN92(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HX."!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#@*;7-G
M:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R(")#;VYT
M<F%S<V5G;F%R92!C;VX@:2!F;&%G<R!6:7-T;R].;VY6:7-T;R(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX.2!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F
M;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(D-O;G1R
M87-S96=N87)E(&-O;B!A;'1R:2!F;&%G<R`H97,Z($EM<&]R=&%N=&4O4FES
M<&]S=&\I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3$@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,34R"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-#0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U
M.0IM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM
M<V=S='(@(D-A;7!I(&-O<G)I<W!O;F1E;G1I(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T
M-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38P"FUS9VED(")-875R:71A
M;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$V,PIM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED
M(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(D-R961I=&\@;6%S<VEM
M;R!P97)M97-S;RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM
M<V=S='(@(D5C8V5D=71E(&QA('!A<G1I(&UA<W-I;64@9&5L(&UE<W-A9V=I
M;RXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,PIM<V=I9"`B36%X('1E
M;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(E1E;7!O(&UA<W-I;6\@=6QT
M:6UE(#(T(&]R93H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#4*;7-G
M:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(E1E;7!O(&UA
M<W-I;6\@=6QT:6UE(#8@;W)E.B`B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I
M9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R(").
M=6UE<F\@;6%S<VEM;R!D96P@4&]R=&$@0FQO8VMS(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C@Y."!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q-R!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T
M<B`B3'5N9VAE>GIA(&UA<W-I;6$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`V(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(DUA9V=I;R(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3,*;7-G
M:60@(DUA>6]T=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R(")-961I8VEN82(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*;7-G:60@(DUE
M;6)E<G,B"FUS9W-T<B`B365M8G)I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,X,@IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS
M9VED(")-97)G92!C96QL<R(*;7-G<W1R(")5;FES8VD@;&4@8V5L;&4B"@HC
M.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z
M,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-
M97-S86=E(@IM<V=S='(@(DUE<W-A9V=I;R(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U
M8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD
M(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@HB26P@;65S<V%G:6\@
MZ"!S=&%T;R!V97)I9FEC871O(&-O<G)E='1A;65N=&4L(&UA(&EL(&9I<FUA
M=&%R:6\@9&5L("(*(F-E<G1I9FEC871O(&YO;B!P=?(@97-S97)E('9E<FEF
M:6-A=&\N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`B365S<V%G9VEO
M('-C861U=&\N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.2!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"FUS9VED(")-97-S86=E('1Y<&4B
M"FUS9W-T<B`B5&EP;R!M97-S86=G:6\B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M,3D*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I
M;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3,*
M;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R
M(")-971O9&\B"@HC.B!L:6(O2&]R9&4O4E!#+W-O87`N<&AP.C$Q-R!L:6(O
M2&]R9&4O4E!#+WAM;')P8RYP:'`Z.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R("));"!M971O
M9&\@(%PB)7-<(B!N;VX@Z"!D969I;FET;R(*"B,Z(&QI8B](;W)D92]24$,O
M<F5S="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D
M969I;F5D+B!#86QL960@;65T:&]D.B`E<R(*;7-G<W1R(")-971O9&\@;F]N
M(&1E9FEN:71O+B!-971O9&\@8VAI86UA=&$Z("5S(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HX,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C<*
M;7-G:60@(DUE=')I8R(*;7-G<W1R(")-971R:6-A(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$T.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38V"FUS9VED(")-97AI
M8V\B"FUS9W-T<B`B365S<VEC;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C@U"FUS9VED(")-:6-R;VYE<VEA+"!&961E
M<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@IM<V=I9"`B36ED9&QE
M(@IM<V=S='(@(DUE>GIO(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N
M968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,3<*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@
M:&]U<G,Z("(*;7-G<W1R(")496UP;R!M:6YI;6\@=6QT:6UE(#(T(&]R93H@
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#D*;7-G:60@(DUI;B!T96UP
M(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(E1E;7!O(&UI;FEM;R!U;'1I;64@
M-B!O<F4Z("(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C0S.0IM<V=I
M9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*
M;7-G<W1R("));"!T96UP;R!D:2!D=7)A=&$@;6EN:6UO(&1E;&QA('!A<W=O
M<F0@;F]N(.@@<V-A9'5T;R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,S4*;7-G:60@(DUI<G)O<B(*;7-G<W1R(")3<&5C8VAI
M;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L
M;&%N96]U<R(*;7-G<W1R(")687)I;R(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S0P(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-S(*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I
M9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R
M("));"!P86-C:&5T=&\@4$5!4B!(5%107U)E<75E<W0@Z"!M86YC86YT92XB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$T"FUS9VED("(B"B)-:7-S
M:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO
M=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS
M9W-T<B`B(@HB0V]N9FEG=7)A>FEO;F4@;6%N8V%N=&4N($1E=FD@9V5N97)A
M<FYE('5N82!N=6]V82!S92!V=6]I('5S87)E('%U97-T82`B"B)A<'!L:6-A
M>FEO;F4N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B240@9&5L
M(&UE<W-A9V=I;R!M86YC86YT92XB"@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N
M96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I<F5D(%!%
M05(@<&%C:V%G92!-86EL+B(*;7-G<W1R("));"!P86-C:&5T=&\@4$5!4B!-
M86EL(')I8VAI97-T;R#H(&UA;F-A;G1E+B(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@
M240N(@IM<V=S='(@(DE$(&1E;&QA('-E<W-I;VYE(&UA;F-A;G1E+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*;7-G
M:60@(DUO(@IM<V=S='(@(DQU(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C<V"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B36]D
M97)A=&4B"FUS9W-T<B`B36]D97)A=&\B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<F%R+G!H<#HV-B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H
M<#HX-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,PIM<V=I
M9"`B36]D:69I960@1&%T92(*;7-G<W1R(")$871A(&1E;&QA(&UO9&EF:6-A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(DUO9&EF:6-A
M(%523"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C<T"FUS9VED
M(")-;V1U;'5S(@IM<V=S='(@(DUO9'5L;R(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDP(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3`*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,`IM<V=I9"`B36]L9&]V82P@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30Y"FUS9VED(")-;VYA8V\B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,34V"FUS9VED(")-;VYG;VQI82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C4X-`IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T
M<B`B365S92!E(&%N;F\B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP
M.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(DUE;G-I;&UE;G1E(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$U,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38Q"FUS
M9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S
M97,B"FUS9W-T<B`B1F%S:2!L=6YA<FDB"@HC.B!L:6(O1FEL92]#4U8N<&AP
M.C$Y-B!L:6(O1FEL92]#4U8N<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C
M=&5D("5D+B(*;7-G<W1R("(B"B)3;VYO('-T871I('1R;W9A=&D@<&GY(&-A
M;7!I(&YE;&QA(&QI;F5A("5D(')I<W!E='1O(&$@<75E;&QI(&EP<F5V:7-T
M:2`E9"XB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-#@*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L
M>2!#;&5A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M-0IM<V=I9"`B36]S=&QY($-L;W5D>2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G
M:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T.`IM<V=I9"`B36]V92!$;W=N(@IM
M<V=S='(@(E-P;W-T82!3;W1T;R(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z-C4R"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B
M4W!O<W1A(&$@4VEN:7-T<F$B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C8U-@IM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R(")3
M<&]S=&$@82!$97-T<F$B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C8T-`IM<V=I9"`B36]V92!5<"(*;7-G<W1R(")3<&]S=&$@
M4V]P<F$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3(V"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B4W!O<W1A('-O='1O(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-2!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V"FUS9VED(")-;W9E
M('5P(@IM<V=S='(@(E-P;W-T82!S;W!R82(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDU(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-34*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V.`IM<V=I9"`B36]Z86UB:7%U
M92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$X-`IM<V=I
M9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#4Y"FUS9VED
M(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(R-#(*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R
M(")396QE>FEO;F4@;75L=&EP;&$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#`R"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(DUI;R!!8V-O
M=6YT(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED(")->2!!
M8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%Z:6]N:2!D96P@
M36EO($%C8V]U;G0B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C0T
M"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B36EO(%!O<G1A;&4B"@HC.B!S
M97)V:6-E<R]P;W)T86PO961I="YP:'`Z-#(*;7-G:60@(DUY(%!O<G1A;"!,
M87EO=70B"FUS9W-T<B`B1&ES<&]S:7II;VYE(&1E;"!-:6\@4&]R=&%L92(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-38*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U
M-0IM<V=I9"`B37EA;FUA<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@
M3D]4($%G<F5E(@IM<V=S='(@(DY/+"!N;VX@<V]N;R!D)V%C8V]R9&\B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z,S@@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-#$Q"FUS9VED(").86UE(@IM<V=S='(@(DYO;64B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-CD*;7-G
M:60@(DYA;6EB:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<X"FUS9VED(").875R=2(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-S<*;7-G:60@(DYE<&%L(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDW(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-C`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-0IM<V=I9"`B3F5T:&5R
M;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C,*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@R
M"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@0T$@
M4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#4*
M;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!2
M979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@X
M"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").
M971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR-3,*;7-G:60@(DYE='=O<FLB"FUS9W-T
M<B`B4F5T92(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R-2!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.3`*;7-G:60@(DYE=F5R(@IM<V=S='(@(DUA:2(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDU(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-C(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,`IM<V=I9"`B3F5W
M($-A;&5D;VYI82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T
M96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S
M='(@(DYU;W9A($-A=&5G;W)I82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT
M-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W
M-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B3'5N82!.=6]V82(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5
M<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(DYU;W9O($YO;64@571E;G1E
M("AO<'II;VYA;&4I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3@P"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*;7-G:60@(DYE
M=R!P87-S=V]R9"(*;7-G<W1R(").=6]V82!P87-S=V]R9"(*"B,Z(&QI8B](
M;W)D92]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@(DYE
M=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B3&$@;G5O
M=F$@<&%S<W=O<F0@<V-A9'+@(&EN("5X+B(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M
M871C:"XB"FUS9W-T<B`B3&$@;G5O=F$@<&%S<W=O<F0@;F]N(&-O<G)I<W!O
M;F1E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B3G5O
M=F$@9FEN:7-T<F$@*%]V=6]T82DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3(@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(Y,0IM<V=I9"`B3F5W<R(*;7-G<W1R(").;W1I>FEE
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-PIM<V=I9"`B3F5W
M<V=R;W5P<R(*;7-G<W1R(")'<G5P<&D@9&D@3F]T:7II92(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C(U('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z,3(Y"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$U"FUS9VED(").97AT(@IM<V=S
M='(@(E!R;W-S:6UO(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS9VED
M(").97AT(#0@4&AA<V5S(@IM<V=S='(@(E!R;W-S:6UE(#0@1F%S:2(*"B,Z
M(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S8V(&QI8B](;W)D92]0<F5F<R]5
M22YP:'`Z,S<P"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`B4')O<W-I
M;64@;W!Z:6]N:2(*"B,Z(&QI8B](;W)D92]522]086=E<BYP:'`Z,3`S"FUS
M9VED(").97AT/B(*;7-G<W1R(")0<F]S<VEM;SXB"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S0*;7-G:60@(DYI8V%R
M86=U82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-S$*;7-G:60@(DYI9V5R(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-C8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,PIM
M<V=I9"`B3FEG97)I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S8Y"FUS9VED(").:6=H="(*;7-G<W1R(").;W1T92(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-C<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W
M.0IM<V=I9"`B3FEU92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.38V"FUS9VED(").;R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO
M(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E
M;F-E<R!F;W(N(@IM<V=S='(@(B(*(DYO;B!S;VYO(&1I<W!O;FEB:6QI(&EN
M9F]R;6%Z:6]N:2!R:6=U87)D;R!L82!C;VYF:6=U<F%Z:6]N92!P97(@;6]S
M=')A<F4@;&4@(@HB9&EF9F5R96YZ92XB"@HC.B!L:6(O5D93+TE33U=R:71E
M<BYP:'`Z,3`V"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA
M:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R(").;VX@Z"!D:7-P;VYI8FEL92!U
M;F$@<W1R871E9VEA('!E<B!C<F5A<F4@:6UM86=I;FD@25-/+B(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B
M871C:"!T96UP;&%T92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HQ,#$*(SH@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HS.#4*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HT,#<*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T
M:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(DYO;B!E<VES=&4@=6X@
M8FQO8V-O(&%L;&$@<&]S:7II;VYE(')I8VAI97-T82(*"B,Z(&QI8B](;W)D
M92]!=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R
M;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").;VX@
MZ"!S=&%T;R!F;W)N:71O(&EL(&YO;64@9&5L(&-A;&5N9&%R:6\@<&5R(&PG
M875T96YT:6-A>FEO;F4@34-!3"XB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H
M<#HU-`IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R(").97-S=6YA(&UO9&EF
M:6-A+B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,34V"FUS9VED(").
M;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*
M;7-G<W1R(").97-S=6X@9FEG;&EO('!U\B!E<W-E<F4@86=G:75N=&\@82!Q
M=65S=&\@<&5R;65S<V\N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-S@@;&EB+TAO
M<F1E+G!H<#HU,3<@;&EB+TAO<F1E+U5T:6PN<&AP.C<X,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@)7,N(@IM<V=S='(@(B(*(DYO;B#H('-T871A('-P96-I9FEC
M871A(&%L8W5N82!I;F9O<FUA>FEO;F4@<W5L;&$@8V]N9FEG=7)A>FEO;F4@
M<&5R("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX-C@*;7-G:60@(DYO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93
M+B(*;7-G<W1R("(B"B).;VX@Z"!S=&%T82!S<&5C:69I8V%T82!A;&-U;F$@
M:6YF;W)M87II;VYE('-U;&QA(&-O;F9I9W5R87II;VYE('!E<B!&5%`@5D93
M+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HV.#0*;7-G:60@(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G
M<W1R("(B"B).;VX@Z"!S=&%T82!S<&5C:69I8V%T82!A;&-U;F$@:6YF;W)M
M87II;VYE('-U;&QA(&-O;F9I9W5R87II;VYE('!E<B!344P@5D93+B(*"B,Z
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<U,PIM<V=I9"`B3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB
M"FUS9W-T<B`B(@HB3F]N(.@@<W1A=&$@<W!E8VEF:6-A=&$@86QC=6YA(&EN
M9F]R;6%Z:6]N92!S=6QL82!C;VYF:6=U<F%Z:6]N92!P97(@4U%,+2(*(D9I
M;&4@5D93+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B3F]N(.@@<FEM
M87-T;R!N97-S=6X@8W)E9&ET;RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE
M9"XB"FUS9W-T<B`B3F]N(.@@<W1A=&$@9F]R;FET82!L82!D97-T:6YA>FEO
M;F4N(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDQ.`IM<V=I9"`B3F\@
M9FEL92!U<&QO861E9"(*;7-G<W1R("));"!F:6QE(&YO;B#H('-T871O(&-A
M<FEC871O(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").
M;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B3F]N('-O;F\@<W1A=&4@=')O=F%T
M92!L92!I8V]N92XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$S,"!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$Q-@IM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R
M(").;VX@Z"!S=&%T;R!I;7!O<W1A=&\@;&$@<&]S:7II;VYE+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G:60@(DYO(&QO8V%T
M:6]N('!R;W9I9&5D+B(*;7-G<W1R(").;VX@Z"!S=&%T;R!I;F1I8V%T;R!L
M82!P;W-I>FEO;F4N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B
M3F]N(.@@<W1A=&\@9F]R;FET;R!I;"!M97-S86=G:6\N(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S
M<&5C:69I960N(@IM<V=S='(@(DYO;B#H('-T871O('-P96-I9FEC871O(&EL
M(&YO;64N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B3F]N(.@@
M<W1A=&\@<W!E8VEF:6-A=&\@:6P@;G5M97)O+B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+VAT='`N<&AP.CDQ"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B3F]N(.@@<W1A=&$@9F]R;FET82!L82!P87-S=V]R9"!P
M97(@;"=A=71E;G1I8V%Z:6]N92!(5%10+B(*"B,Z(&QI8B](;W)D92]!=71H
M+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYO;B#H('-T871A(&9O
M<FYI=&$@;&$@<&%S<W=O<F0@<&5R(&PG875T96YT:6-A>FEO;F4@24U!4"XB
M"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(").;VX@Z"!S=&%T82!F;W)N:71A(&QA('!A<W-W;W)D('!E<B!L
M)V%U=&5N=&EC87II;VYE($ME<F)E<F]S+B(*"B,Z(&QI8B](;W)D92]!=71H
M+VQO9VEN+G!H<#HX-"!L:6(O2&]R9&4O075T:"]P86TN<&AP.C<U"B,Z(&QI
M8B](;W)D92]!=71H+W-A<VPN<&AP.C<W"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYO
M;B#H('-T871A(&9O<FYI=&$@;&$@<&%S<W=O<F0@<&5R(&PG875T96YT:6-A
M>FEO;F4@3&]G:6XN(@H*(SH@;&EB+TAO<F1E+T%U=&@O<&%S<W=D+G!H<#HQ
M,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(DYO;B#H('-T871A(&9O<FYI=&$@;&$@
M<&%S<W=O<F0@<&5R(&PG875T96YT:6-A>FEO;F4@4$%34U=$+B(*"B,Z(&QI
M8B](;W)D92]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYO;B#H
M('-T871A(&9O<FYI=&$@;&$@<&%S<W=O<F0@<&5R(&PG875T96YT:6-A>FEO
M;F4@4TU"+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(X-PIM
M<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED
M960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R
M:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@HB3F]N(.@@9&ES<&]N
M:6)I;&4@86QC=6YA('!A=&-H('!E<B!L82!V97)S:6]N92!B:6YA<FEA(&1I
M($]P96Y34TPN($QA("(*(G9E<G-I;VYE(&)I;F%R:6$@9&D@3W!E;E-33"#H
M(&YE8V5S<V%R:6\@8VAE(&]P97)I(&-O;B!L92!I;F9O<FUA>FEO;FD@4$M#
M4R`B"B(Q,BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN
M8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]61E,N<&AP.C<V-@IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R
M(").;VX@Z"!S=&%T82!I;7!O<W1A=&$@;&$@<75O=&$N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PIM<V=I
M9"`B3F\@<G5L97,B"FUS9W-T<B`B3F5S<W5N82!R96=O;&$B"@HC.B!L:6(O
M1FEL92]#4U8N<&AP.C0X,@IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE
M9"XB"FUS9W-T<B`B3F]N(.@@<W1A=&\@<W!E8VEF:6-A=&\@:6P@<V5P87)A
M=&]R92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0T"FUS9VED(").;R!S:61E<R(*;7-G<W1R(").97-S=6YA
M(&QA=&\B"@HC.B!L:6(O5D93+W-M8BYP:'`Z-C`P"FUS9VED(").;R!S=6-H
M(&9I;&4B"FUS9W-T<B`B3F5S<W5N('1I<&\@9&D@9FEL92(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C8*;7-G:60@(DYO('1E;7!O<F%R
M>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B3F]N
M(.@@9&ES<&]N:6)I;&4@=6YA(&1I<F5C=&]R>2!T96UP;W)A;F5A('!E<B!L
M82!C86-H92XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,Q(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@(DYO('5S
M97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R(").;VX@Z"!S
M=&%T82!I;G9I871O(&EL(&YO;64@=71E;G1E(&4O;R!P87-S=V]R9"XB"@HC
M.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI
M9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R(").;VX@<V]N;R!R:71O<FYA
M=&4@:6YF;W)M87II;VYI(%A-3"!V86QI9&4B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3<T(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HY.#0*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.CDY-0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3`Q,@IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(DYE<W-U;B!V
M86QO<F4B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$Y"FUS9VED(").
M;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB3F]N(.@@<W1A
M=&$@=')O=F%T82!L82!V97)S:6]N92!N96QL82!C;VYF:6=U<F%Z:6]N92!O
M<FEG:6YA;&4N(%)I9V5N97)A(&QA("(*(F-O;F9I9W5R87II;VYE+B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C<*;7-G:60@(DYO('9E<G-I;VX@
M9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(B(*(DYO;B#H('-T871A('1R;W9A=&$@;&$@
M=F5R<VEO;F4@;F5L;&$@='5A(&-O;F9I9W5R87II;VYE+B!2:6=E;F5R82!L
M82`B"B)C;VYF:6=U<F%Z:6]N92XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HT,C<@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY
M,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0U"FUS9VED(").;VYE(@IM<V=S='(@(DYE<W-U;F\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").
M;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(DYE<W-U;F\@+W5S;R!I;7!L
M:6-I=&\I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(DYO
M<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDV(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-C@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,@IM<V=I9"`B3F]R9F]L
M:R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R
M(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P
M:&5R92(*;7-G<W1R(")%;6ES9F5R;R!3971T96YT<FEO;F%L92(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDS(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-CD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U.`IM<V=I
M9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDW(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-S`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-@IM<V=I
M9"`B3F]R=V%Y(@IM<V=S='(@(DYO<G9E9VEA(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HV-#$*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R(").
M;VX@1&]P;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0P"FUS
M9VED(").;W0@0F5F;W)E(@IM<V=S='(@(DYO;B!0<FEM82(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z-#(Q"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T
M<B`B3F]N('5N82!D:7)E8W1O<GDB"@HC.B!L:6(O5D93+TE33U=R:71E<BYP
M:'`Z-C,@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP
M.C0X"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H
M<#HU.0HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN
M<&AP.C@T"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G
M>2YP:'`Z.34*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B3F]N
M(&EM<&QE;65N=&%T;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B"FUS9W-T<B`B3F]N(&EM
M<&]S=&%T;R(*"B,Z(&QI8B]61E,N<&AP.C$Y,R!L:6(O5D93+G!H<#HR,#@@
M;&EB+U9&4RYP:'`Z,C,T(&QI8B]61E,N<&AP.C(U,@HC.B!L:6(O5D93+G!H
M<#HR-CD@;&EB+U9&4RYP:'`Z,C@U(&QI8B]61E,N<&AP.C,P,2!L:6(O5D93
M+G!H<#HS,38*(SH@;&EB+U9&4RYP:'`Z,S,S(&QI8B]61E,N<&AP.C,V-B!L
M:6(O5D93+G!H<#HT,C8@;&EB+U9&4RYP:'`Z-3`U"B,Z(&QI8B]61E,N<&AP
M.C4W-"!L:6(O5D93+G!H<#HU.3$@;&EB+U9&4RYP:'`Z-C8Y"B,Z(&QI8B](
M;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,30U(&QI8B](;W)D92]397-S:6]N
M2&%N9&QE<BYP:'`Z,38P"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP
M:'`Z,3<U(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,3@Y"B,Z(&QI
M8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,C,V"FUS9VED(").;W0@<W5P
M<&]R=&5D+B(*;7-G<W1R(").;VX@<W5P<&]R=&%T;RXB"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.CDP."!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(T-`HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`U."!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3@P"FUS9VED(").;W1E<R(*;7-G<W1R(")!
M<'!U;G1I(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS
M9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B3G5L
M;&$@9&$@=FES=6%L:7IZ87)E+"!T;W)N82!I;F1I971R;RXB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS
M9W-T<B`B3F]V96UB<F4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`T-@IM
M<V=I9"`B3G5M8F5R(@IM<V=S='(@(DYU;65R;R(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ-#(U"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G
M<W1R(").=6UE<F\@9&D@8V%R871T97)I(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$S-CD@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C,@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$T-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@
M(DYU;65R;R!D:2!C;VQO;FYE(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S
M-C<@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C$@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$T-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(DYU;65R;R!D
M:2!R:6=H92(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@
M:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*(DD@;G5M97)I(&YO
M;B!S;VYO('-T871I('-P96-I9FEC871I('!E<B!L)V%G9VEO<FYA;65N=&\@
M;F5L;&$@;&ES=&$@9&D@(@HB9&ES=')I8G5Z:6]N92XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HX-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R(")/9V=E='1O(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#<F5A
M=&]R(@IM<V=S='(@(D-R96%T;W)E(&1E;&PG3V=G971T;R(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R(")/='1A
M;&4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B
M3V-T;V)E<B(*;7-G<W1R(")/='1O8G)E(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(X"FUS9VED(")/9F9I8V4B
M"FUS9W-T<B`B569F:6-I;R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@
M9&EF9F5R96YT+B(*;7-G<W1R("),92!P87-S=V]R9"!V96-C:&EE(&4@;G5O
M=F4@9&5V;VYO(&5S<V5R92!D:69F97)E;G1I(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C,V"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T
M<B`B5F5C8VAI82!P87-S=V]R9"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T
M+B(*;7-G<W1R("),82!V96-C:&EA('!A<W-W;W)D(&YO;B#H(&-O<G)E='1A
M+B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$X,0IM<V=I9"`B3VUA;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S
M('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(E-O;&\@:2!S97)V
M97(@24U!4"!S=7!P;W)T86YO(&QE(&-A<G1E;&QE(&-O;F1I=FES92XB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS
M:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ.#4Q(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<Q"FUS9VED(")/;FQY(&]N
M92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(D4G('!E<FUE<W-O
M('-O;&\@=6X@:6YD:7)I>GIO(&5M86EL+B(*"B,Z('-E<G9I8V5S+W-H87)E
M<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES
M=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N
M97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HB4V]L
M;R!I;"!P<F]P<FEE=&%R:6\@;R!L)V%M;6EN:7-T<F%T;W)E(&1I('-I<W1E
M;6$@<'7R(&-A;6)I87)E(&QA('!R;W!R:65TX"`B"B)O(&D@<&5R;65S<VD@
M9&5L('!R;W!R:65T87)I;R!P97(@=6YA(&-O;F1I=FES:6]N92(*"B,Z(&QI
M8B]";&]C:R]I9G)A;64N<&AP.C0Q(&QI8B]";&]C:R]I9G)A;64N<&AP.C0R
M"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")!<')E(&EN
M('5N82!N=6]V82!F:6YI<W1R82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT
M<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R("(B
M"B)%<G)O<F4@3W!E;E-33#H@;F]N('-I('!O<W-O;F\@97-T<F%R<F4@;&4@
M:6YF;W)M87II;VYI(&1A;&QA('!A<G1E(&9I<FUA=&$@(@HB4R]-24U%+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O
M=R(*;7-G<W1R(")!<')E('%U97-T;R!C;VQL96=A;65N=&\@:6X@=6YA(&YU
M;W9A(&9I;F5S=')A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS
M9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(E-I<W1E;6$@3W!E<F%T
M:79O(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U-0IM<V=I
M9"`B3W!T:6]N<R(*;7-G<W1R(")/<'II;VYI(@H*(SH@<V5R=FEC97,O<')E
M9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(D]P>FEO;FD@
M<&5R("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(D5L96YC;R!O
M<F1I;F%T;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38X"FUS
M9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B3W)G86YI>GIA>FEO;F4B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B3W)G86YI
M<V%T:6]N86P@56YI="(*;7-G<W1R(")5;FETX"!/<F=A;FEZ>F%T:79A(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S-`IM<V=I9"`B3W)G86YI
M>FEN9R(*;7-G<W1R(")!9V5N9&$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS
M9W-T<B`B36%S8VAE<F$@;W)I9VEN86QE(&1E;&PG87!L:6-A>FEO;F4B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(DUA<V-H97)A
M(&]R:6=I;F%L92!I;B`E<SHB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*
M;7-G<W1R(")!;'1R;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.2!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-0HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3,T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#0*
M;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D%L=')E($EN9F]R
M;6%Z:6]N92(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G
M:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUE<W-I(&1E;"!P
M<F]P<FEE=&%R:6\B"@HC.B!L:6(O2&]R9&4O075T:"]P86TN<&AP.C<Y"FUS
M9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B3"=A=71E;G1I8V%Z:6]N92!004T@;F]N(.@@9&ES<&]N:6)I;&4N
M(@H*(SH@;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@
M(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HQ,C<V"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U
M<F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,R
M,@IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(DEN9F]R;6%Z
M:6]N92!#:69R871A(%!'4"(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C$S-S0*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(D-H:6%V92!0
M=6)B;&EC82!01U`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S4V
M"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(DEN
M9F]R;6%Z:6]N92!&:7)M871A+T-I9G)A=&$@4$=0(@H*(SH@861M:6XO<&AP
M<VAE;&PN<&AP.C8Y"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")#;V1I8V4@
M4$A0(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE
M;&PB"FUS9W-T<B`B4VAE;&P@4$A0(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,SD*;7-G:60@(E!-(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-H;W=E
M<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-
M(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4$T@4W5N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T
M"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z,C@V"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES
M<VEN9R(*;7-G<W1R(")%<W1E;G-I;VYE(%!/4TE8(&UA;F-A;G1E(@H*(SH@
M;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B4FEE;7!I;65N=&\B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#<*
M;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.30*;7-G:60@(E!A;&%U(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.3(*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C
M=7!I960B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3@R"FUS9VED(")086YA;6$B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$W-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@U
M"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.34*;7-G:60@
M(E!A<F%G=6%Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S
M='(@(E!A<GII86QM96YT92!.=79O;&]S;R(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4S-PHC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,34Q
M(&QI8B](;W)D92]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT
M,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(U"FUS9VED(")087-S
M=V]R9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*
M;7-G<W1R(")087-S=V]R9"!C86UB:6%T82!C;VX@<W5C8V5S<V\N(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,S(S"FUS9VED(")087-S=V]R
M9"!I;F-O<G)E8W0B"FUS9W-T<B`B4&%S<V]W<F0@;F]N(&-O<G)E='1A(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W
M;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(D4G(')I8VAI97-T82!L82!P87-S=V]R9"!P97(@;"=A=71E;G1I8V%Z
M:6]N92!2041)55,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P-3,*;7-G
M:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(E!A<W-W
M;W)D(&-O;B!C;VYF97)M82(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C`S-`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C$U"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B3&4@
M<&%S<W=O<F0@9&5V;VYO(&-O<G)I<W!O;F1E<F4N(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$R,"!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S='(@(DEN8V]L
M;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R("));F-O
M;&QA(&1A;&QA(&-L:7!B;V%R9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B4&5R
M8V]R<V\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I
M9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-30*;7-G:60@(E!E;W!L92(*;7-G<W1R(")097)S;VYE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B4&5R8V5N='5A;&4B"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I
M9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(D5S
M96=U:2!L92!/<&5R87II;VYI(&1I($UA;G5T96YZ:6]N92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT,3`*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B17-E9W5I<F4@;&4@
M;W!E<F%Z:6]N:2!D:2!M86YT=71E;GII;VYE(&%L;"=A8V-E<W-O/R(*"B,Z
M(&QI8B](;W)D92]097)M<R]522YP:'`Z,34V"FUS9VED(")097)M:7-S:6]N
M(@IM<V=S='(@(E!E<FUE<W-O(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H
M<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N
M;W0@9&5L971E9"XB"FUS9W-T<B`B4&5R;65S<V\@7"(E<UPB(&YO;B!C86YC
M96QL871O+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HV,#,*;7-G:60@(E!E<FUI
M<W-I;VX@1&5N:65D(@IM<V=S='(@(E!E<FUE<W-O($YE9V%T;R(*"B,Z(&QI
M8B](;W)D92]097)M<R]522YP:'`Z,38Q(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R(")097)M97-S:2(*
M"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,"!A9&UI;B]P97)M<R]D
M96QE=&4N<&AP.C4X"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI
M;B]P97)M<R]I;F1E>"YP:'`Z,C(*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN
M:7-T<F%T:6]N(@IM<V=S='(@(D=E<W1I;VYE(%!E<FUE<W-I(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8X"FUS9VED(")097)S;VYA;"!);F9O<FUA
M=&EO;B(*;7-G<W1R("));F9O<FUA>FEO;FD@4&5R<V]N86QI(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$W.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@S"FUS9VED
M(")097)U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M-0IM<V=I9"`B4&5T<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#8*;7-G:60@(E!H:6QI<'!I;F5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R(")496QE9F]N;R(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#`*;7-G:60@(E!H;W1O<R(*;7-G
M<W1R(")&;W1O9W)A9FEE(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$Y,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@
M(E-I('!R96=A(&1I(&-L:6-C87)E(&EN(&%L8W5N92!C96QL92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO
M=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R(")3:2!P<F5G82!D:2!C;VYF97)M
M87)E(&-H92!S:2!V=6]L92!R:6UU;W9E<F4@<75E<W1O(&5L96UE;G1O.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R(")3:2!P<F5G82!D:2!C
M;VYF97)M87)E(&-H92!S:2!V=6]L92!S8V]L;&5G87)E('%U97-T;R!E;&5M
M96YT;SHB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4V,@IM<V=I9"`B4&QE
M87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B4VD@<')E
M9V$@9&D@:6YS97)I<F4@=6X@;65S92!E('5N(&%N;F\N(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L
M96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S
M='(@(E-I('!R96=A(&1I(&EN<V5R:7)E('5N(&YO;64@<&5R(&QA(&YU;W9A
M(&=A=&5G;W)I83HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,P,0IM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B
M4VD@<')E9V$@9&D@:6YS97)I<F4@=6X@:6YD:7)I>GIO($E0('9A;&ED;RXB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8T,`IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN
M('1H92!M;VYT:"XB"FUS9W-T<B`B(@HB4VD@<')E9V$@9&D@:6YS97)I<F4@
M=6YA(&1A=&$@=F%L:61A+"!C;VYT<F]L;&$@:6P@;G5M97)O(&1I(&=I;W)N
M:2!N96P@;65S92XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0T-PIM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B4VD@<')E
M9V$@9&D@:6YS97)I<F4@=6XG;W)A('9A;&ED82XB"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!A
M('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(E-I('!R96=A(&1I
M(&9O<FYI<F4@=6X@<FEA<W-U;G1O(&1E;"!P<F]B;&5M82XB"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@
M86YD('!A<W-W;W)D(@IM<V=S='(@(E-I('!R96=A(&1I(&9O<FYI<F4@:6P@
M<')O<')I;R!N;VUE('5T96YT92!E('!A<W-W;W)D(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@
M9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS
M('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"B)3:2!P<F5G82!D
M:2!L96=G97)E(&EL('-E9W5E;G1E('1E<W1O+B!$159)(&5S<V5R92!D)V%C
M8V]R9&\@8V]N(&D@=&5R;6EN:2`B"B)D)W5S;R!D96P@<VES=&5M82XB"@HC
M.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I
M9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R
M(")3:2!P<F5G82!D:2!S8W)I=F5R92!I;&YO;64@9&5L;&$@;G5O=F$@8V%T
M96=O<FEA.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$X.`IM<V=I9"`B4&]L86YD(@IM<V=S='(@(E!O;&]N:6$B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM
M<V=S='(@(E!O;&ET:6-A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0X.0IM<V=I9"`B4&]L;',B"FUS9W-T<B`B4V-R=71I;FEO(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.#(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,PIM<V=I
M9"`B4&]R='5G86PB"FUS9W-T<B`B4&]R=&]G86QL;R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`IM
M<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R(")0;W-I
M>FEO;F%M96YT;R!D:2!Q=65S=&$@:6UM86=I;F4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I
M;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R(")0;W-I>FEO;F%M96YT;R!D
M:2!Q=65S=&$@=&%B96QL82(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3$*
M;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)
M34%0*2(*;7-G<W1R(")0;W-T87)E(&$@<75E<W1A(&-A<G1E;&QA("AN;VX@
M87!P;&EC871O(&1A($E-05`I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-S,@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T
M<B`B4')E8VEP:71A>FEO;F4@<&5R(&PG=6QT:6UA("5S(&]R82AE*2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#<*;7-G:60@(E!R96-I
M<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+U!R969S+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E
M9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7VQD
M87`Z($5S=&5N<VEO;F4@3$1!4"!R:6-H:65S=&$@;F]N('1R;W9A=&$N(@H*
M(SH@;&EB+TAO<F1E+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F
M<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(E!R969S7W-E<W-I;VXZ(&5S=&5N<VEO;F4@9&5L;&$@
M<V5S<VEO;F4@<FEC:&EE<W1A(&YO;B!T<F]V871A+B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C,R"FUS9VED(")0<F5S<W5R92(*;7-G<W1R(")0<F5S
M<VEO;F4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-@IM<V=I9"`B4')E
M<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B4')E<W-I;VYE(&%L(&QI
M=F5L;&\@9&5L(&UA<F4Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,C0*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B4')E<W-I;VYE
M.B`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`S
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R,`IM<V=I9"`B4')E=FEE=R(*;7-G<W1R(")!;G1E<')I;6$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C$*;7-G:60@(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W
M('=I;F1O=R(*;7-G<W1R(")!;G1E<')I;6$@9&5L;"=I;6UA9VEN92!I;B!U
M;F$@;G5O=F$@9FEN97-T<F$B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP
M.C,U-B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V,`IM<V=I9"`B4')E=FEO
M=7,@;W!T:6]N<R(*;7-G<W1R(")/<'II;VYI('!R96-D96YT:2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@
M(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(E-T86UP82!D;V-U;65N=&\B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@
M2V5Y(@IM<V=S='(@(D-H:6%V92!0<FEV871A(@H*(SH@;&EB+TAO<F1E+TUE
M;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R(")0<F]B;&5M82(*
M"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-PIM<V=I9"`B4')O8FQE;2!$
M97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FEZ:6]N92!D96P@<')O8FQE;6$B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<Q"FUS9VED(")0<F]J
M96-T<R(*;7-G<W1R(")0<F]G971T:2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,3$Q(&QI8B](;W)D92]&;W)M+G!H<#HR,3@X(&QI8B](;W)D92]&;W)M
M+G!H<#HS,C<V"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB
M"FUS9W-T<B`B0VAI879E(%!U8F)L:6-A(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV-#8*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM
M<V=S='(@(D%L9V]R:71M;R!D96QL82!#:&EA=F4@4'5B8FQI8V$B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME
M>2!);F9O(@IM<V=S='(@(DEN9F]R;6%Z:6]N:2!S=6QL82!#:&EA=F4@4'5B
M8FQI8V$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@
M(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S
M9G5L;'DN(@IM<V=S='(@(DQA(&-O<'!I82!C:&EA=F4@4'5B8FQI8V$O4')I
M=F%T82!N;VX@Z"!S=&%T82!G96YE<F%T82!C;VX@<W5C8V5S<V\N(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,0IM
M<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S0S,30N<&AP.C4U"FUS9VED(")0=7)G92!M97-S86=E<R(*
M;7-G<W1R(")%;&EM:6YA(&D@;65S<V%G9VDB"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X
M-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DV"FUS9VED(")1871A<B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C0*;7-G:60@(E%U
M97)Y(@IM<V=S='(@(D1O;6%N9&$B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z.#`*;7-G:60@(E%U;W1A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-C8T"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0
M=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,C8T"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B
M4V5L97II;VYE(')A9&EO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6XB"FUS9W-T<B`B4&EO9V=I82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS
M9VED(")286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN($QA=&4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#@*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")286EN
M(&%N9"!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4P"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O
M;2!&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R87(N<&AP.C8X(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<V
M"FUS9VED(")2871I;R(*;7-G<W1R(")287!P;W)T;R(*"B,Z(&QI8B](;W)D
M92]097)M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(DQE
M9V=I(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W(&QI
M8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HT-PIM<V=I9"`B4F5A9"!M
M97-S86=E<R(*;7-G<W1R("),96=G97)E(&D@;65S<V%G9VDB"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T
M(&)E('5N9&]N92XB"FUS9W-T<B`B16QI;6EN87)E(')E86QM96YT92`E<S\@
M3"=O<&5R87II;VYE(&YO;B!P=?(@97-S97)E(')E8W5P97)A=&$N(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_
M(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*
M(D5L:6UI;F%R92!R96%L;65N=&4@;&4@:6YF;W)M87II;VYI(')E;&%T:79E
M(&%L;"=U=&5N=&4@)7,_($PG;W!E<F%Z:6]N92!N;VX@(@HB<'7R(&5S<V5R
M92!R96-U<&5R871A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N
M(@IM<V=S='(@(E)I97-E9W5E(&QA('1U82!U;'1I;6$@87II;VYE(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B06=G:6]R;F$B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDU"FUS9VED(")2969R97-H($1Y;F%M
M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B06=G:6]R;F$@9VQI(&5L96UE
M;G1I(&1I;F%M:6-I(&1E;"!M96YU.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-#4*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@
M(D%G9VEO<FYA<F4@;&$@=FES=&$@9&5L('!O<G1A;&4Z(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C@Y-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q,R!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3(S-0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R,S$*;7-G:60@(E)E;&%T:6]N<VAI
M<"!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*;7-G
M:60@(E)E;&]A9"(*;7-G<W1R(")2:6-A<FEC82(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S,S"FUS9VED(")296UA<FMS(@IM<V=S='(@(D]S<V5R=F%Z
M:6]N:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3<*;7-G:60@(E)E
M;6]T92!397)V97)S(@IM<V=S='(@(E-E<G9E<B!R96UO=&DB"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@
M*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R(")54DP@
M<F5M;W1A("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,C(*;7-G:60@(E)E;6]V92(*;7-G<W1R
M(")2:6UU;W9I(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q
M"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B4FEM=6]V:2!I;"!B;&]C
M8V\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34Y
M"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(E)I;75O=FD@;&$@8V]L
M;VYN82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(E)I;75O
M=FD@;&$@9F]R;6%T=&%Z:6]N92(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R(")2:6UU;W9I
M(&QA(&-O<'!I82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#$*;7-G
M:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A
M<GD@9&ER96-T;W)Y+B(*;7-G<W1R(")2:6UU;W9I(&QO('-C<FEP="!S86QV
M871O(&1A;&QA(&1I<F5C=&]R>2!T96UP;W)A;F5A(&1E;"!S97)V97(N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0R"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(E)I;75O=FD@:6PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C
M=6UE;G0B"FUS9W-T<B`B4FEM=6]V:2!Q=65S=&\@;F]D;R!D86P@9&]C=6UE
M;G1O(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM
M<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B4FEM=6]V:2!L)W5T96YT92(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B4FEM=6]V
M:2!L)W5T96YT93H@)7,B"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z
M,3,X"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U
M<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R("),82!R:6-H:65S=&$@;F]N('!U
M\B!E<W-E<F4@979A<V$N($-O9&EC92!D:2!E<G)O<F4@9&D@<FET;W)N;SH@
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-0IM<V=I9"`B
M4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R
M("));"!S97)V:7II;R!R:6-H:65S=&\@;VX@<'7R(&5S<V5R92!T<F]V871O
M+B(*"B,Z(&QI8B](;W)D92YP:'`Z,3@U(&QI8B](;W)D92YP:'`Z-3(W"B,L
M('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF
M:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(EPB)7-<(B!R:6-H
M:65S=&\@;F]N(.@@<W!E8VEF:6-A=&\@;F5L;&$@8V]N9FEG=7)A>FEO;F4@
M9&D@)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@W-"!L:6(O5D93+W-Q;"YP
M:'`Z-CDP(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<U.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B7"(E<UPB(')I8VAI97-T;R!N;VX@
MZ"!S<&5C:69I8V%T;R!N96QL82!C;VYF:6=U<F%Z:6]N92!D:2!61E,N(@H*
M(SH@;&EB+TAO<F1E+U5T:6PN<&AP.C<Y,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")<(B5S7"(@<FEC:&EE<W1O(&YO;B#H('-P96-I9FEC
M871O(&YE;&QA(&-O;F9I9W5R87II;VYE+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+U)E;F1E<F5R+G!H<#HS,S8*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S
M='(@(D-A;7!O(%)I8VAI97-T;R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&QI
M8B](;W)D92]&;W)M+G!H<#HS,SD*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(R,"!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z
M,S(Q"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS
M9W-T<B`B07IZ97)A(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-#8*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(D%Z>F5R82!L82!P
M87-S=V]R9"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS
M9VED(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(D%Z>F5R82!L82!T
M=6$@<&%S<W=O<F0B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,Q"FUS9VED
M(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T<B`B4FEP<FES=&EN82!L)W5L
M=&EM82!D;VUA;F1A(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(Y(&%D;6EN
M+W!H<'-H96QL+G!H<#HW,B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C<*;7-G:60@
M(E)E<W5L=',B"FUS9W-T<B`B4FES=6QT871I(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW
M"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")2:71O<FYA(&%L
M;&4@3W!Z:6]N:2(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS
M.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R(")2:7-C<FEV
M:2!L82!N=6]V82!P87-S=V]R9"(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.3<*;7-G:60@(E)E=6YI;VXB"FUS9W-T
M<B`B4FEU;FEO;F4B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U
M<F%T:6]N(@IM<V=S='(@(DEN=F5R=&D@;&$@0V]N9FEG=7)A>FEO;F4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED(")2:6-H(%1E>'0@
M161I=&]R($]P=&EO;G,B"FUS9W-T<B`B3W!Z:6]N:2!P97(@:6P@4FEC:"!4
M97AT($5D:71O<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I
M9"`B4FED9&QE<R(*;7-G<W1R("));F1O=FEN96QL:2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`IM<V=I9"`B
M4FEG:'0B"FUS9W-T<B`B1&5S=')A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,Q,#,*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R("));G1E<W1A>FEO
M;FD@9&D@9&5S=')A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,P.3D*;7-G
M:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R(")686QO<FD@9&D@9&5S=')A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4')O
M<')I973@(&1E;&QA(%)I7V=A+BXN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B4F5G;VQA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Y.`IM<V=I9"`B4F]M86YI82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(V"FUS9VED(")2;W1A=&4@,3@P
M(@IM<V=S='(@(E)O=71A(&1I(#$X,"(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,C,*;7-G:60@(E)O=&%T92!,969T(@IM<V=S
M='(@(E)O=71A(&$@<VEN:7-T<F$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C(Y"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T
M<B`B4F]U=&$@82!$97-T<F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE
M<R(*;7-G<W1R(")0<F]P<FEE=.`@9&5L;&$@4FEG82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@
M(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(E!R;W!R:65TX"!D96QL82!R:6=A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@(E)I9VAE.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@
M(E)U;&5S(@IM<V=S='(@(E)E9V]L92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I
M;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T
M<B`B3&4@<F5G;VQE(&%P<&%R:7)A;FYO('1R82!T=71T92!L92!R:6=H92!E
M(&QE(&-O;&]N;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("),92!R96=O;&4@87!P87)I
M<F%N;F\@<V]L;R!T<F$@;&4@8V]L;VYN92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(DQE(')E
M9V]L92!A<'!A<FER86YN;R!S;VQO('1R82!L92!R:6=H92(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,C$*;7-G:60@(E)U;B(*;7-G<W1R(")%<V5G=6ER
M92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.3D*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$X.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`P
M"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I
M9VYA='5R92(*;7-G<W1R(")&:7)M82!C:69R871A(%,O34E-12(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@16YC
M<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B365S<V%G9VEO(&-I9G)A=&\@4R]-
M24U%(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!
M4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M3"=A=71E;G1I8V%Z:6]N92!305-,(&YO;B#H(&1I<W!O;FEB:6QE+B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#8*;7-G:60@(E--4R!-97-S
M86=I;F<B"FUS9W-T<B`B365S<V%G9VEO(%--4R(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HS,C<T"FUS9VED(")344P@<W1A=&5M96YT(&9O
M<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(D1I8VAI87)A>FEO;F4@4U%,('!E
M<B!I;"!V86QO<F4@9&D@;&]O:W-U<"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT,S,*;7-G:60@(E-32"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@
M(E-50T-%4U,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED
M(")37U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,#<*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DP"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S$*;7-G:60@(E-A
M:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DQ"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,SD*;7-G:60@(E-A:6YT
M($QU8VEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.#D*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@
M36EQ=65L;VXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(T-`IM<V=I9"`B4V%I;G0@5FEN8V5N="!A
M;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M
M92`H7W-E;&8I(@IM<V=S='(@(E-T97-S82!S=')U='1U<F$@*%]A=71O*2(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-3$*;7-G:60@(E-A;6]A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3(*;7-G:60@(E-A;B!-87)I
M;F\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(Q-@IM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.0IM
M<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(G!R;W9I9&5R('-A
M=&5L;&ET87)E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(P,0IM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.0IM<V=I9"`B4V%V
M92(*;7-G<W1R(")386QV82(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B
M"FUS9W-T<B`B4V%L=F$@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHR,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G
M<W1R(")386QV82`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*
M;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R(")386QV82!L92!/<'II;VYI
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-@IM<V=I9"`B(@HB4V%V
M92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@
M>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R
M("(B"B),82!C;VYF:6=U<F%Z:6]N92!G96YE<F%T82#H('-T871A('-A;'9A
M=&$@8V]M92!S8W)I<'0@4$A0(&YE;&QA(&1I<F5C=&]R>2`B"B)T96UP;W)A
M;F5A(&1E;"!T=6\@<V5R=F5R+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(G-A;'9A=&4@)7,@8V]N9FEG=7)A>FEO;FDN(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB
M"FUS9W-T<B`B4V%L=F%T;R!L;R!S8W)I<'0@9&D@86=G:6]R;F%M96YT;R!D
M96QL92!I;7!O<W1A>FEO;FD@:6XZ(%PB)7-<(BXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B4V-A='1E<F5D
M(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R(")38VEE;GIA(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R(")2:6-E
M<F-A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R,@IM<V=I9"`B
M4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B36]T;W)I(&1I(%)I8V5R8V$B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDU-0IM<V=I9"`B4V5L96-T($9I;&5S
M(@IM<V=S='(@(D9I;&4@<V5L97II;VYA=&DB"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@U"FUS9VED(")396QE8W0@82!D871E
M(@IM<V=S='(@(E-E;&5Z:6]N82!U;F$@9&%T82(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A
M9&0B"FUS9W-T<B`B4V5L97II;VYA('5N(&=R=7!P;R!D82!A9V=I=6YG97)E
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L
M96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(E-E;&5Z:6]N82!U;B!N=6]V;R!P
M<F]P<FEE=&%R:6\B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R(")396QE>FEO;F$@
M=6X@<V5R=F5R(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*
M;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@(E-E;&5Z:6]N
M82!U;B!U=&5N=&4@9&$@86=G:75N9V5R92(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HV-S8*;7-G:60@(E-E;&5C="!A;&PB"FUS
M9W-T<B`B4V5L97II;VYA('1U='1O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(V-#,*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G
M<W1R(")396QE>FEO;F$@='5T=&D@:2!C;VUP;VYE;G1I(&1E;&QA(&1A=&$N
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM
M<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R(")S96QE>FEO;F$@=6X@
M;V=G971T;R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HV-S<*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(DYE<W-U;F$@<V5L
M97II;VYE(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B
M"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X
M97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M
M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@HB4V5L97II;VYA(&D@
M8V%R871T97)I(&1I(&-U:2!H86D@8FES;V=N;R!D86QL92!C87-E;&QE('-O
M='1O(')I<&]R=&%T92X@4'5O:2`B"B)C;W!I87)L:2!E(&EN8V]L;&%R;&D@
M9&%L;"=A<F5A(&1I('1E<W1O+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G
M<W1R(")396QE>FEO;F$@:6P@=&5R;6EN92!D96QL82!D871A.B(*"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A
M=&4@9F]R;6%T.B(*;7-G<W1R(")396QE>FEO;F$@:6P@9F]R;6%T;R!D96QL
M82!D871A.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI
M;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@
M8VAA;F=E.B(*;7-G<W1R(")396QE>FEO;F$@;"=I9&5N=&ETX"!C:&4@=G5O
M:2!M;V1I9FEC87)E.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V
M"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R(")3
M96QE>FEO;F$@:6P@;&EM:71E(&1E;&PG;W)A.B(*"B,Z('1E;7!L871E<R]D
M871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R;6%T
M.B(*;7-G<W1R(")396QE>FEO;F$@:6P@9F]R;6%T;R!D96QL)V]R83HB"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE8W0@
M='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B4V5L97II;VYA(&1U92!C
M86UP:2!C:&4@8V]R<FES<&]N9&]N;RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S$P"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM
M<V=S='(@(E-E;&5Z:6]N82!L;R!S8VAE;6$@9&5I(&-O;&]R:2XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4R"FUS9VED(")396QE8W0@>6]U<B!P
M<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(E-E;&5Z:6]N82!L82!L:6YG
M=6$@<')E9F5R:71A.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(DEN
M=FEA(&EL(%)E<&]R="!D96P@<')O8FQE;6$B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`T,@IM<V=I9"`B4V5N9"!335,B"FUS
M9W-T<B`B26YV:6$@4TU3(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(Q,PIM<V=I9"`B4V5N96=A;"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R,PIM<V=I9"`B4V5N<V]R.B`B
M"FUS9W-T<B`B4V5N<V]R93H@(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0Q,"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R(")3971T96UB<F4B
M"@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")3
M97)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HW,#(*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS
M9W-T<B`B3G5M97)O(&1I(%-E<FEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$T.0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B26YF;W)M87II;VYE(&1E;"!S97)V97(@
M<V)A9VQI871A(&\@;F]N(&1I<W!O;FEB:6QE+B(*"B,Z(&%D;6EN+W-E<W-I
M;VYS+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R(")!;6UI
M;FES=')A=&]R92!D:2!S97-S:6]N92(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X<&ER960N
M(@IM<V=S='(@(DQA('-E<W-I;VYE($E$(.@@<V-A9'5T82(*"B,Z(&QI8B]A
M<&DN<&AP.C$T-0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B4V5S<VEO;FDB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,Q-`IM<V=I9"`B4V5T(@IM<V=S
M='(@(DEM<&]S=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SD*;7-G
M:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A
M<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@HB26UP
M;W-T82!L92!O<'II;VYI('!E<B!P97)M971T97)T:2!D:2!A>GIE<F%R92!L
M82!P87-S=V]R9"!N96P@8V%S;R!D;W9E<W-I("(*(F1I;65N=&EC87)T96QA
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3@*;7-G:60@(E-E="!U
M<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M
M('EO=7(@<&]R=&%L+B(*;7-G<W1R("));7!O<W1A(&EL('-E<G9E<B!R96UO
M=&\@86P@<75A;&4@=G5O:2!A8V-E9&5R92!D86P@='5O('!O<G1A;&4N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@W"FUS9VED(")3970@>6]U<B!P
M<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N
M(@IM<V=S='(@(DEM<&]S=&$@;&$@;&EN9W5A('!R969E<FET82!E(&QE(&]P
M>FEO;FD@<&5R(&PG;W)A(&4@;&$@9&%T82XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3`Q"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI
M8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T
M:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HB26UP;W-T82!L
M92!A<'!L:6-A>FEO;FD@9&D@879V:6\L(&QO('-C:&5M82!D96D@8V]L;W)I
M+"!I;"!T96UP;R!D:2`B"B)A9V=I;W)N86UE;G1O(&1E;&QA('!A9VEN82!E
M(&%L=')E(&]P>FEO;FD@9&D@=FES=6%L:7IZ87II;VYE+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-S<*;7-G:60@(E-E='5P(@IM<V=S='(@(DEM
M<&]S=&%Z:6]N92(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH
M=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE
M(@IM<V=S='(@(E-C<FEP="!D:2!A9V=I;W)N86UE;G1O(&1E;&QE(&EM<&]S
M=&%Z:6]N:2!D:7-P;VYI8FEL:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-S4*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE
M('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(D1I=F5R<V4@<&]S:7II
M;VYI(&1I<W!O;FEB:6QI(&-O;B!I;"!P87)A;65T<F\Z("(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#,*;7-G:60@
M(E-E>6-H96QL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0Y.`IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U
M;6UA<GDB"FUS9W-T<B`B0G)E=F4@4V]M;6%R:6\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#4P"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@
M9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B3&$@8VAI879E(&0G
M86-C97-S;R!D;W9RX"!E<W-E<F4@9&5F:6YI=&$@<&5R('!I^2!C;VQL96=A
M;65N=&D_(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G
M:60@(E-H;W<B"FUS9W-T<B`B36]S=')A(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$U-`IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N
M(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B)-;W-T<F$@;&4@9&EF9F5R96YZ
M92!T<F$@;&$@8V]N9FEG=7)A>FEO;F4@871T=6%L;65N=&4@<V%L=F%T82!E
M(&QA(&YU;W9A("(*(F=E;F5R871A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT.30*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G
M9VEN9R!I;C\B"FUS9W-T<B`B36]S=')A(&PG;W)A(&1E;&PG=6QT:6UO(&%C
M8V5S<V\@<75A;F1O(&5N=')I/R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M-S8U"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S
M='(@(DUO<W1R82!L)V]P>FEO;F4@<&5R(&UA;G1E;F5R92!Q=65L;&$@;W)I
M9VEN86QE(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(W.34*;7-G:60@(E-H
M;W<@<&EC:V5R(@IM<V=S='(@(DUO<W1R82!I;"!R86-C;V=L:71O<F4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,P"FUS9VED(")3:&]W('1A8FQE
M(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(DUO<W1R87)E(&QA('1A
M8F5L;&$@9&5L;&4@;W!E<F%Z:6]N:2!D96P@;65N=2!B87(_(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3
M:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R(")-;W-T<F$@
M:6P@;65N=2!D:2`E<R!S=6QL82!S:6YI<W1R83\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@
M(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S
M(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A
M8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*
M;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8S"FUS9VED(")3:&]W
M('5P;&]A9"(*;7-G<W1R(")-;W-T<F$@:6P@8V%R:6-A;65N=&\B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B
M4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M-`IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3:&]W97)S
M(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q.0IM<V=I9"`B4VAR:6YK(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M.3$P"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3<R
M"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`U.`HC
M.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q,C`*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,3@S"B,Z(&QI
M8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(R,PHC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R-3(*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C@U"FUS9VED(")3:')I
M;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W
M87D@9FER<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8V"FUS
M9VED(")3:6=N('5P(@IM<V=S='(@(D-O;G1R87-S96=N82(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-S$S"FUS9VED(")3:6=N871U<F4B"FUS
M9W-T<B`B1FER;6$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<Q
M,@IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R(")!;&=O<FET
M;6\@9&D@9FER;6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C`V"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y-B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3(Q-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S-PHC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C(T-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ,B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S$P-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H
M<#HV-2!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-`HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,@IM<V=I9"`B4VEZ92(*;7-G
M<W1R(")$:6UE;G-I;VYE(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA
M:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS
M9W-T<B`B4V%L=&$@;&4@;W!E<F%Z:6]N:2!D:2!M86YU=&5N>FEO;F4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(P,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$P
M"FUS9VED(")3;&]V86MI82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P
M-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`X"FUS9VED(")3;&]V96YI
M82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R(*;7-G<W1R(").979E(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N
M;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3D*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B
M4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR.#4*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X.0IM<V=I9"`B4VYO=R!E<75I=F%L
M96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#4*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,@IM<V=I9"`B4V]L;VUO;B!)
M<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,30*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F
M(%!O96US(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.3`X
M"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R(")/<F1I;F$@
M;"=O<F1I;F%M96YT;R!D:2!S96QE>FEO;F4B"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Q-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(T-PHC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-34Y(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@
M;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$V-B!L:6(O3F5T+U--4R]W:6Y?
M:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R("))
M;F1I<FEZ>F\@<V]R9V5N=&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C4U"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS
M9W-T<B`B4W5D($%F<FEC82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS
M"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(P.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3`Q"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I
M8V@@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI
M<W!H97)E(@IM<V=S='(@(F5M:7-F97)O($UE<FED:6]N86QE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@
M(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B4W!A>FEO
M('1R82!C96QL92!A:61A8V5N=&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C
M;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R(")3<&%Z:6\@=')A
M(&EL(&-O;G1E;G5T;R!E(&EL(&)O<F1O(&EN('5N82!C96QL82(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HX,34*;7-G:60@(E-P86-E<B(*;7-G<W1R(")$
M:7-T86YZ:6%T;W)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4U"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(E-P
M87II871U<F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM
M<V=S='(@(E-P87II871U<F$@92!R:65M<&EM96YT;R(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,#D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@P"FUS9VED(")3<&%I
M;B(*;7-G<W1R(")3<&%G;F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3`P"FUS9VED(")3<&%M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME
M>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B
M"FUS9W-T<B`B26YS97)I;65N=&\@0V%R871T97)I(%-P96-I86QI(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R(")397!A<F$@;&$@8V5L;&$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B4V5P87)A(&QA
M(&-O;&]N;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B4V5P
M87)A(&QA(')I9VAA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"FUS
M9VED(")3<&]R=',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30Q"FUS9VED(")3<FD@3&%N:V$B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,2!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-C8*;7-G:60@(E-T86YD87)D(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4
M<F5K(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3@V(&QI
M8B](;W)D92]&;W)M+G!H<#HR-SDQ"FUS9VED(")3=&%R="!Y96%R(@IM<V=S
M='(@(D%N;F\@9&D@<&%R=&5N>F$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4W,0IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B
M4W1A=&\@;R!0<F]V:6YC:6$B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O
M:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR-SDW"FUS9VED(")3=&]R86=E(&9O<FUA="(*
M;7-G<W1R(")&;W)M871O(&1I(&UE;6]R:7IZ87II;VYE(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E-T<F5E="!!9&1R97-S
M(@IM<V=S='(@(DEN9&ER:7IZ;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,S,*;7-G:60@(E-T
M<FEN9R!L:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.#<S"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G
M<W1R(")4;V=L:2!I;"!D;VUI;FEO(&1A;&PG:6YD:7)I>GIO(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM
M<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B4W1I;&4@6T-34UTB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED
M(")3=2(*;7-G<W1R(")$;R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B4V]T=&]D:7)E8W1O<GD@7"(E<UPB(&YO;B!T
M<F]V871A+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(D]G9V5T=&\B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S,R(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H
M<#HS,3@*;7-G:60@(E-U8FUI="(*;7-G<W1R(")3;W1T;VUE='1I(@H*(SH@
M<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T
M960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C
M86YN;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A
M<'!R;W9E9"XB"FUS9W-T<B`B(@HB12<@<W1A=&$@:6YV:6%T82!L82!R:6-H
M:65S=&$@<&5R(&%G9VEU;F=E<F4@7"(E<UPB(&%L('-I<W1E;6$N($YO;B!P
M=6]I("(*(F%C8V5D97)E(&9I;G1A;G1O("!C:&4@;&$@<FEC:&EE<W1A(&YO
M;B!V:65N92!A<'!R;W9A=&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#4@;&EB+TAO<F1E+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y
M<W1E;2XB"FUS9W-T<B`B7"(E<UPB(.@@<W1A=&\@86=G:75N=&\@8V]N('-U
M8V-E<W-O(&%L('-I<W1E;6$N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@
M9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HB
M3&4@:6YF;W)M87II;VYI(')E;&%T:79E(&%L;"=U=&5N=&4@7"(E<UPB('-O
M;F\@<W1A=&4@8V%N8V5L;&%T92!C;VX@(@HB<W5S<V5S<V\@9&%L('-I<W1E
M;6$N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D
M96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB(&5L:6UI;F%T82!C;VX@
M<W5C8V5S<V\N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H
M92!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!R:6UO<W-O(&-O;B!S=6-C97-S
M;R!D86P@<VES=&5M82XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q
M"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@
M4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("(B"B)#;VYF:6=U<F%Z
M:6]N92!I;G9E<G1I=&$@8V]N('-U8V-E<W-O+B!2:6-A<FEC82!P97(@=F5D
M97)E(&D@8V%M8FEA;65N=&DN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED(")3=6-C97-S
M9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D-O
M<&EA(&1E;&QA(&-O;F9I9W5R87II;VYE('-A;'9A=&$@8V]N('-U8V-E<W-O
M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG
M=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(")#;W!I82!D96P@9FEL92!D:2!C
M;VYF:6=U<F%Z:6]N92!D:2`E<R!S86QV871A(&-O;B!S=6-C97-S;RXB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S='(@(D%G9VEO<FYA=&\@
M8V]N('-U8V-E<W-O(%PB)7-<(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R(")38W)I='1O
M(&-O;B!S=6-C97-S;R`E<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B4V]M;6%R:6\B"@HC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@(E-U;B!2:7-E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N
M(%-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV,0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-0IM<V=I9"`B4W5N<FES92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#0*;7-G
M:60@(E-U;G)I<V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C`X"FUS9VED(")3=6YS970B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-PIM<V=I9"`B4W5N<V5T
M.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X,`IM<V=I9"`B4W5P<&]R
M="(*;7-G<W1R(")3=7!P;W)T;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,34*;7-G:60@(E-U<FEN86UE(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED
M(")3=7)N86UE(@IM<V=S='(@(E-O<')A;FYO;64B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(Q,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Y"FUS9VED(")3=F%L
M8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3D*;7-G:60@(E-W87II
M;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C`U"FUS9VED(")3=V5D96XB"FUS9W-T<B`B4W9E
M>FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-38*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(E-V:7IZ97)A(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@
M;&]G(&1E;&5T960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$T-0IM<V=I9"`B4WEN8TU,(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@
M<V5A<F-H('1E<FUS(@IM<V=S='(@(D5R<F]R92!D:2!S:6YT87-S:2!N96D@
M=&5R;6EN:2!D:2!R:6-E<F-A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(Q.`IM<V=I9"`B4WER:6%N($%R86(@4F5P
M=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@
M(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4+5-T;W)M<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV-0IM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T1A=&$O='-V+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T
M<B`B4')O<')I973@(&1E;&QA(%1A8F5L;&$B"@HC.B!L:6(O2&]R9&4O1F]R
M;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@4V5T(@IM<V=S
M='(@(DEM<&]S=&%Z:6]N92!D96QL82!486)E;&QA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B
M5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R(")0<F]P<FEE=.`@9&5L;&$@=&%B
M96QL82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,2!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C,T"FUS9VED(")486EW86XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I
M=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(Q.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(U"FUS9VED(")4
M86II:VES=&%N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,S4*;7-G:60@(E1A;GIA;FEA+"!5;FET
M960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G
M<W1R(")/8FEE='1I=F\Z(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,S(@
M8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-#D*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$X.0IM<V=I9"`B5&%S:W,B"FUS9W-T<B`B071T:79I=.`B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B5&5L
M97!H;VYE($YU;6)E<B(*;7-G<W1R(").=6UE<F\@9&D@=&5L969O;F\B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-PIM<V=I9"`B5&5M<"!F;W(@;&%S
M="!H;W5R.B`B"FUS9W-T<B`B5&5M<&5R871U<F$@<&5R(&PG=6QT:6UA(&]R
M83H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C$*;7-G:60@(E1E;7!E
M<F%T=7)E(@IM<V=S='(@(E1E;7!E<F%T=7)A(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Q,@IM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G
M<W1R(")496UP97)A='5R83H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(X,@HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R93QB
M<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]496UP;&%T92YP:'`Z-CDU"B,L('!H<"UF;W)M870*;7-G:60@
M(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DUA<V-H97)A
M(%PB)7-<(B!N;VX@=')O=F%T82XB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B
M1V5S=&EO;F4@36%S8VAE<F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q
M,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,R-PIM<V=I9"`B5&5X="(*;7-G<W1R
M(")497-T;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-SD*;7-G:60@
M(E1E>'0@3VYL>2(*;7-G<W1R(")3;VQO(%1E<W1O(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B
M5&5X="!A;&EG;B(*;7-G<W1R(")!;&QI;F5A;65N=&\@=&5S=&\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS9VED
M(")497AT=&]P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(D=I(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@(E1H86D@*%1)4RTV
M,C`I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,C0*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(B(*
M"B,Z(&QI8B]61E,O9G1P+G!H<#HX-C0*;7-G:60@(E1H92!&5%`@97AT96YS
M:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DPG97-T96YS:6]N92!&
M5%`@;F]N(.@@9&ES<&]N:6)I;&4N(@H*(SH@;&EB+TAO<F1E+TAI<W1O<GDN
M<&AP.C4U"FUS9VED(")4:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L960N
M(@IM<V=S='(@(DQA(&-R;VYI<W1O<FEA(&1E;"!S:7-T96UA(.@@9&ES86)I
M;&ET871A+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3,X"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I
M;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B26P@;6]T;W)E
M(&1I(&EN=&5G<F%Z:6]N92!(;W)D92]+;VQA8B!N;VX@<W5P<&]R=&$@7"(E
M<UPB(@H*(SH@;&EB+TYE="])35-0+T)O;VLN<&AP.C$R.3@*;7-G:60@(E1H
M92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@
M(DEL(&QO9R!D:2!)35-0(&YO;B!P=?(@97-S97)E(&EN:7II86QI>GIA=&\N
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@
M36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY
M(@IM<V=S='(@(DQA(&-L87-S92!-86EN=&5N86YC93HZ(&YO;B#H('-T871A
M(&-A<FEC871A(&-O;B!S=6-C97-S;R(*"B,Z('-E<G9I8V5S+VEM86=E<R]C
M;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H
M87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R("),82!F:6YI<W1R82!D96QL
M92!/<'II;VYI('-I(.@@8VAI=7-A+B!5<V-I<F4N(@H*(SH@;&EB+TAO<F1E
M+U!E<FUS+G!H<#HQ.#D@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,#`@;&EB+TAO
M<F1E+U!E<FUS+G!H<#HR,3$*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,C,@
M;&EB+TAO<F1E+U!E<FUS+G!H<#HR,S0@;&EB+TAO<F1E+U!E<FUS+G!H<#HR
M-3(*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR-C0@;&EB+TAO<F1E+U!E<FUS
M+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O
M(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF
M('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B4V]L
M86UE;G1E(&EL(&QA=&\@:6YF97)I;W)E(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@
M;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N
M;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@
M8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S
M<R!B;V]K+B(*;7-G<W1R("));"!C;VYT871T;R#H('-T871O(&%G9VEU;G1O
M(&-O;B!S=6-C97-S;R!A;&QA('1U82!R=6)R:6-A+B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C$Q-S(*;7-G:60@(B(*(E1H92!D971A8VAE9"!0
M1U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@
M<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I
M;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA
M;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I
M9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*
M;7-G<W1R(").;VX@Z"!S=&%T82!S<&5C:69I8V%T82!L82!L:7-T82!D:2!D
M:7-T<FEB=7II;VYE+B(*"B,Z(&QI8B](;W)D92]#<GEP="YP:'`Z,3$V"FUS
M9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E
M('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("),82!F=6YZ:6]N92!D:2!C:69R
M871U<F$@<FEC:&EE9&4@=6YA(&-O;FYE<W-I;VYE('=E8B!S:6-U<F$N(@H*
M(SH@;&EB+TAO<F1E+G!H<#HQ.#8@;&EB+TAO<F1E+G!H<#HU,C@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E
M<R!S971T:6YG+B(*;7-G<W1R("));"!F:6QE("5S(&1O=G)E8F)E(&-O;G1E
M;F5R92!U;F$@)7,@:6UP;W-T87II;VYE+B(*"B,Z(&QI8B](;W)D92YP:'`Z
M,3<Y(&QI8B](;W)D92YP:'`Z-3$X"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM
M<V=S='(@(DEL(&9I;&4@)7,@9&]V<F5B8F4@8V]N=&5N97)E(&%L8W5N92`E
M<R!I;7!O<W1A>FEO;FDN(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C(X,`IM
M<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(DEL
M(&9I;&4@;F]N(&-O;G1I96YE(&EN9F]R;6%Z:6]N:2XB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO
M=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@
M;65S<V%G92XB"FUS9W-T<B`B(@HB3&4@<V5G=65N=&D@<V]N;R!L92!I;G1E
M<W1A>FEO;FD@<&5R('%U97-T;R!M97-S86=G:6\O<F9C.#(R(&UE<W-A9V=I
M;RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T
M;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@
M(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O
M<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I
M<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M
M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O
M=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N
M97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N
M7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@
M3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E
M9&ET;W(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@
M8F5E;B!D96QE=&5D+B(*;7-G<W1R("),)VED96YT:73@(%PB)7-<(B#H('-T
M871A(&-A;6-E;&QA=&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S
M:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I
M;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O341.+G!H<#HR,#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T
M;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<
M;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S
M(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3@W-PIM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H
M96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]&:6QE+T-35BYP:'`Z-#<T"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I
M96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@(DEL(&YU;65R;R!D96D@
M8V%M<&D@9&5V92!E<W-E<F4@9&D@=&EP;R!N=6UE<FEC;RXB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R,S(*;7-G:60@(E1H92!O<&5N<W-L
M(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE
M.CH@8VQA<W,N(@IM<V=S='(@(DEL(&UO9'5L;R!O<&5N<W-L(.@@<FEC:&EE
M<W1O('!E<B!L82!C;&%S<V4@2&]R9&5?0W)Y<'1?<VUI;64Z.BXB"@HC.B!L
M:6(O2&]R9&4O4')E9G,N<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E
M8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A
M8FQE('-I>F4B"FUS9W-T<B`B(@HB3&$@<')E9F5R96YZ82!<(B5S7"(@;F]N
M('!U\B!E<W-E<F4@<V%L=F%T82!P97)C:.@@;"=I;F9O<FUA>FEO;F4@8V]N
M=&5N=71A("(*(F5C8V5D92!L82!M87-S:6UA(&1I;65N<VEO;F4@9&ES<&]N
M:6)I;&4B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O9&5B+G!H<#HS,B!L
M:6(O2&]R9&4O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O;7-W;W)D+G!H<#HS,B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<G!M+G!H<#HS,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<W)C:&EG
M:&QI=&4N<&AP.C,W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]W96)C<'`N
M<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S
M960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@
M;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HB26P@<')O9W)A;6UA('5S871O
M('!E<B!V:7-U86QI>GIA<F4@<75E<W1O('1I<&\@9&D@:6YF;W)M87II;VYE
M("@E<RD@;F]N(.@@(@HB<W1A=&\@=')O=F%T;R!N96P@<VES=&5M82XB"@HC
M.B!L:6(O1FEL92]#4U8N<&AP.C0X-PIM<V=I9"`B5&AE('%U;W1E(&-H87)A
M8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT-SD*;7-G:60@
M(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E
M96X@9&5L971E9"XB"FUS9W-T<B`B26P@<V5R=F5R(%PB)7-<(B#H('-T871O
M(&5L:6UI;F%T;RXB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@
M8F5E;B!S879E9"XB"FUS9W-T<B`B26P@<V5R=F5R(%PB)7-<(B#H('-T871O
M('-A;'9A=&\N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@
M<F5M;W9E9"XB"FUS9W-T<B`B3&$@<FEC:&EE<W1A(&1I(&ES8W)I>FEO;F4@
M<&5R("5S(.@@<W1A=&$@<FEM;W-S82XB"@HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C0W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R
M("),82!R:6=A('-P96-I9FEC871A("@E9"D@;F]N(&5S:7-T92XB"@HC.B!L
M:6(O5D93+W-Q;"YP:'`Z,3<Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T
M96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@
M(DEL(&9I;&4@=&5M<&]R86YE;R!<(B5S7"(@;F]N(&5S:7-T92XB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S,P,@IM<V=I9"`B5&AE('1E>'0@>6]U(&5N
M=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*
M;7-G<W1R("));"!T97-T;R!D:6=I=&%T;R!N;VX@8V]R<FES<&]N9&4@86P@
M=&5S=&\@<W5L;&\@<V-H97)M;RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N
M9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4
M:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1&%T
M82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S
M:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B3"=I;F9O<FUA>FEO
M;F4@8V%R:6-A=&$@Z"!S=&%T82!P97)S82!S:6X@9&%L;"=U;'1I;6\@<&%S
M<V\N(@H*(SH@;&EB+TAO<F1E+T1A=&$O8W-V+G!H<#HR-C(@;&EB+TAO<F1E
M+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O
M=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B26P@9FEL92!C87)I8V%T;R!N
M;VX@<'7R(&5S<V5R92!S86QV871O+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HT.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$P
M"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B3&$@9&ER96-T;W)Y(&1E:2!T96UI(%PB)7-<
M(B!N;VX@Z"!S=&%T82!T<F]V871A+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]5
M22YP:'`Z,3<X"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B
M;&4N(@IM<V=S='(@(DYO;B!C:2!S;VYO(&]P>FEO;FD@9&ES<&]N:6)I;&DN
M(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C,U,`IM<V=I9"`B
M5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI
M;F4N(@IM<V=S='(@(DYO;B!C:2!S;VYO('!A<G1I(&-H92!P;W-S;VYO(&5S
M<V5R92!V:7-U86QI>GIA=&4@:6YL:6YE+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T
M;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N
M=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T
M:&%N("5S+B(*;7-G<W1R("(B"B)#:2!S;VYO('1R;W!P:2!C87)A='1E<FD@
M:6X@<75E<W1O(&-A;7!O+B!(86D@9&EG:71A=&\@)7,@8V%R871T97)I.R!D
M979I("(*(F1I9VET87)E('5N(&YU;65R;R!D:2!C87)A='1E<FD@;6EN;W)E
M(&1I("5S+B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I
M;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(D-I('-O;F\@
M86QC=6YI('!R;V)L96UI(&YE;&PG86=G:75N9V5R92!<(B5S7"(@86P@<VES
M=&5M83H@)7,B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O
M<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(B"B)#
M)^@@<W1A=&\@=6X@<')O8FQE;6$@;F5L(&-A;F-E;&QA<F4@;&4@:6YF;W)M
M87II;VYI('!E<B!L)W5T96YT92!<(B5S7"(@9&%L("(*(G-I<W1E;6$Z("(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S
M>7-T96TZ("(*;7-G<W1R(")#)^@@<W1A=&\@=6X@<')O8FQE;6$@;F5L(')I
M;75O=F5R92!<(B5S7"(@9&%L('-I<W1E;6$Z("(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B
M;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B0R?H('-T871O('5N
M('!R;V)L96UA(&YE;&PG86=G:6]R;F%M96YT;R!D:2!<(B5S7"(Z("5S(@H*
M(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDR-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(B(*(D,GZ"!S=&%T;R!U
M;B!P<F]B;&5M82!C;VX@:6P@8V%R:6-A;65N=&\@9&5L(&9I;&4Z($YE<W-U
M;B`E<R#H('-T871O("(*(F-A<FEC871O+B(*"B,Z(&QI8B](;W)D92]"<F]W
M<V5R+G!H<#HY,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L
M87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y
M=&5S*2XB"FUS9W-T<B`B(@HB0R?H('-T871O('5N('!R;V)L96UA(&-O;B!I
M;"!C87)I8V%M96YT;R!D96P@9FEL93H@26P@)7,@97)A('!I^2!L=6YG;R!D
M96QL82`B"B)M87-S:6UA(&1I;65N<VEO;F4@<&5R;65S<V$@*"5D(&)Y=&5S
M*2XB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3,R"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N
M(@IM<V=S='(@(B(*(D,GZ"!S=&%T;R!U;B!P<F]B;&5M82!C;VX@:6P@8V%R
M:6-A;65N=&\@9&5L(&9I;&4Z($EL("5S(.@@<W1A=&\@8V%R:6-A=&\@(@HB
M<V]L;R!P87)Z:6%L;65N=&4N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P
M;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(B(*(D,GZ"!S=&%T
M;R!U;B!E<G)O<F4@;F5L;&$@=FES=6%L:7IZ87II;VYE(&1I('%U97-T82!P
M87)T92!D96P@;65S<V%G9VEO(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HS.2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C0X"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C
M;VYT86-T(&1A=&$N(@IM<V=S='(@(D,GZ"!S=&%T;R!U;B!E<G)O<F4@;F5L
M;"=I;7!O<G1A<F4@;&4@:6YF;W)M87II;VYI(&1E;"!C;VYT871T;RXB"@HC
M.B!L:6(O2&]R9&4O1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T
M<B`B0R?H('-T871O('5N(&5R<F]R92!N96QL)VEM<&]R=&%R92!L92!I;F9O
M<FUA>FEO;FD@9&D@:4-A;&5N9&%R+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z.#(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@
M8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*
M(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"B)#)^@@<W1A=&\@=6X@97)O
M<F4@;F5L;&$@9F]R;2!D:2!C;VYF:6=U<F%Z:6]N92X@4')O8F%B:6QM96YT
M92!H86D@(@HB9&EM96YT:6-A=&\@=6X@8V%M<&\@<FEC:&EE<W1O+B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*
M(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@
M861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA
M=&5R+B(*;7-G<W1R("(B"B)#)^@@<W1A=&\@=6X@97)R;W)E(&YE;&PG97-E
M9W5I<F4@;&$@<W!E8VEF:6-A(&9U;GII;VYE(&1E;&QA(')U8G)I8V$N(%-I
M("(*(G!R96=A(&1I(')I<')O=F%R92!P:?D@=&%R9&DN(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(D,GZ"!S=&%T;R!U
M;B!E<G)O<F4@;F5L;"=A9V=I;W)N86UE;G1O(&1E:2!D971T86=L:2!D96P@
M8V]N=&%T=&\N(%-I('!R96=A("(*(F1I('!R;W9A<F4@<&GY('1A<F1I+B(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4@;&EB+TYE
M="]335,O=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E
M('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB0R?H('-T871O('5N(&5R
M<F]R92!N96QL)V%G9VEO<FYA;65N=&\@9&5L;&$@;&ES=&$@9&D@9&ES=')I
M8G5Z:6]N92X@4VD@(@HB<')E9V$@9&D@<')O=F%R92!P:?D@=&%R9&DN(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B
M5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L
M9&5R<RXB"FUS9W-T<B`B475E<W1O('-E<G9E<B!)34%0(&YO;B!S=7!P;W)T
M82!L82!C;VYD:79I<VEO;F4@9&D@8V%R=&5L;&4N(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@
M87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(E%U
M97-T;R!S96UB<F$@;F]N(&5S<V5R92!U;B!A<F-H:79I;R!D:2!T:7!O(')A
M<B!V86QI9&\N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z
M-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@
M>FEP(&9I;&4N(@IM<V=S='(@(E%U97-T;R!S96UB<F$@;F]N(&5S<V5R92!U
M;B!F:6QE(&1I('1I<&\@>FEP('9A;&ED;RXB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S$R-PIM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@
M=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(E%U97-T;R!N;VX@<V5M8G)A
M(&5S<V5R92!U;B!N=6UE<F\@9&D@8V%R=&$@=F%L:61O+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H
M92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W
M87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!L:6(O3F5T
M+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT
M='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$DB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB
M<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY
M("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q
M=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY
M("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HY-S@@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-3<@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$P.#8*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,34@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Q.#(@;&EB+TAO<F1E+T9O<FTN<&AP.C$R
M-38*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,#4@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$S.3@@;&EB+TAO<F1E+T9O<FTN<&AP.C$U-3<*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$X,SD@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-3@@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(P,#4*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,CD@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(P-S@@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q
M-#D*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R,C$@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(T,#@@;&EB+TAO<F1E+T9O<FTN<&AP.C(T-3`*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(V,S<@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,3`@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,Q,3D*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R.3<@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,X,#4@;&EB+TAO<F1E+T9O<FTN<&AP.C,X
M,3,*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES(&9I96QD
M(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(B!1=65S=&\@
M8V%M<&\@<'7R(&-O;G1E;F5R92!S;VQO(&EN=&5R:2XB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C0Q-@IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C
M;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B(%%U97-T
M;R!C86UP;R!P=?(@8V]N=&5N97)E('-O;&\@;G5M97)I(&4@9'5E('!U;G1I
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#DT"FUS9VED(")4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$R,PIM<V=I9"`B5&AI<R!F:65L
M9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@
M:6YT96=E<G,B"FUS9W-T<B`B(@HB475E<W1O(&-A;7!O('!U\B!E<W-E<F4@
M<V]L;R!U;F$@;&ES=&$@9&D@:6YT97)I('-A<&%R871I(&1A('9I<F=O;&$@
M;R!S<&%Z:6\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3@Y"FUS9VED(")4
M:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(E%U
M97-T;R!C86UP;R!D979E(&5S<V5R92!U;B!N=6UE<F\@=F%L:61O+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR.#$X"FUS9VED("(B"B)4:&ES(&9I96QD
M(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R
M;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*(E%U
M97-T;R!C86UP;R!D979E(&-O;G1E;F5R92!U;B!C;VQO<F\@:6X@9F]R;6%T
M;R!21T(@97-A9&5C:6UA;&4L(&%D(&5S96UP:6\@(@HB)R,Q,C,T868G+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H
M87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B475E<W1A(&9O
M<FT@Z"!G:6$@<W1A=&$@<')O8V5S<V%T82XB"@HC.B!T96UP;&%T97,O:&5L
M<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S
M+B(*;7-G<W1R(")1=65S=&\@Z"`E<RXB"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.C0V.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L
M86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@
M=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S
M('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U
M8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4Y.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C
M:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T
M<B`B(@HB475E<W1O(&UE<W-A9V=I;R#H('-T871O('-C<FET=&\@:6X@=6X@
M<V5T(&1I(&-A<F%T=&5R:2`H)7,I(&1I=F5R<V\@9&%L('1U;RXB"@HC.B!L
M:6(O2&]R9&4O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@
M;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(E%U97-T;R!N=6UE<F\@
M9&5V92!E<W-E<F4@=6YI8V\N(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V=Z
M:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S
M('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B475E<W1O('-E<G9E<B!N
M;VX@<'7R(&1E8V]M<')I;65R92!F:6QE(&EN(&9O<FUA=&\@>FEP(&4@9WII
M<"XB"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI
M<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R(")!
M;"!M;VUE;G1O('%U97-T;R!S:7-T96UA(&YO;B#H(&%T=&EV;RXB"@HC.B!L
M:6(O2&]R9&4O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M
M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R(")1=65S=&\@=F%L;W)E(&1E=F4@
M97-S97)E('5N(&YU;65R;RXB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P
M:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE
M9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(E%U97-T82!F:6YE
M<W1R82!D979E(&5S<V5R92!C:&EA;6%T82!D82!U;F$@9FEN97-T<F$@9&5L
M;&4@3W!Z:6]N:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8V"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(E1U;VYO(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-@IM<V=I9"`B5&EC:V5T<R(*
M;7-G<W1R(")":6=L:65T=&DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0R
M-2!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(E1I;64B
M"FUS9W-T<B`B3W)A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X
M.`IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(D9O
M<FUA=&\@9&5L;"=O<F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4S,0IM
M<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B4V5L97II;VYE(&1E;&PG
M;W)A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(S,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z,C`@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HR,CD*;7-G:60@(E1I=&QE(@IM<V=S='(@(E1I=&]L;R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G
M:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@
M(D$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C4T
M"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W
M;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H
M:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B)097(@<V5L97II;VYE<F4@<&GY
M('9O8VDL('1I96YI('!R96UU=&\@:6P@=&%S=&\@0V]N=')O;"`H4$,I(&\@
M0V]M;6%N9"`B"B(H36%C*2!M96YT<FD@<W1A:2!C;&EC8V%N9&\N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,`IM<V=I9"`B5&]D87DB
M"FUS9W-T<B`B3V=G:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C(S"FUS9VED(")4;V=O(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C8*;7-G:60@(E1O
M:V5L874B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,P,@IM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B1&]M86YI(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,C4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R.0IM
M<V=I9"`B5&]N9V$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O:V]L
M86(N<&AP.C$P-`IM<V=I9"`B5&]O(&UA;GD@:6YV86QI9"!L;V=I;G,@9'5R
M:6YG('1H92!L87-T(&UI;G5T97,N(@IM<V=S='(@(E1R;W!P92!A8V-E<W-I
M(&YO;B!V86QI9&D@9'5R96YT92!G;&D@=6QT:6UI(&UI;G5T:2XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*
M;7-G:60@(E1O<"(*;7-G<W1R(")!;'1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?
M=&]P*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*
M;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R(")4<F%D=7II;VYI(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,C8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,@IM
M<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G
M<W1R(")697)O(&\@9F%L<V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R(")-82(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C@*
M;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C@*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,0IM<V=I9"`B5'5R:V5Y(@IM
M<V=S='(@(E1U<F-H:6$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM
M<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,CD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-PIM<V=I
M9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C`*;7-G:60@(E1U<FMS(&%N
M9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S
M,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,S"FUS9VED(")4=79A;'4B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z,C8T"FUS9VED(")4
M>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B1&EG:71A(&QA('1U82!S8V5L
M=&$Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3@*;7-G
M:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R
M86UE+G!H<#HQ-R!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(T
M.0IM<V=I9"`B55),(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@
M9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"FUS9VED(")54DPZ
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,S<*;7-G:60@(E5G86YD82(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(S,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,V"FUS
M9VED(")5:W)A:6YE(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z
M-#(U"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM
M<V=S='(@(DEM<&]S<VEB:6QE(&%C8V5D97)E(&%L;&$@9&ER96-T;W)Y(%9&
M4RXB"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5
M;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N
M:6YG('5P+B(*;7-G<W1R("(B"B));7!O<W-I8FEL92!A9V=I=6YG97)E(&%L
M=')E(&EN9F]R;6%Z:6]N:2!S=6=L:2!U=&5N=&D@;65N=')E(&1U<F%N=&4@
M;&$@(@HB<V]T=&]S8W)I>FEO;F4N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,Y
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)I
M;&4@8V%M8FEA<F4@:2!P97)M97-S:2!P97(@:6P@9FEL92!61E,@7"(E<UPB
M+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,SDX(&QI8B]61E,O;75S<6PN<&AP
M.C0X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("));7!O<W-I
M8FEL92!C86UB:6%R92!I('!E<FUE<W-I('!E<B!I;"!F:6QE(%9&4R`E<R\E
M<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-SDY"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(DEM<&]S<VEB
M:6QE(&-A;6)I87)E(&$@)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C(S-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE
M(&]F(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@=F5R:69I8V%R92!L
M82!D:6UE;G-I;VYE(&1I(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP
M.C<P-R!L:6(O5D93+W-Q;"YP:'`Z,3`T,"!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HX-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I
M;&4@<VEZ92!O9B!<(B5S+R5S7"(N(@IM<V=S='(@(DEM<&]S<VEB:6QE('9E
M<FEF:6-A<F4@;&$@9&EM96YS:6]N92!D:2!<(B5S+R5S7"(N(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O<W%L+G!H<#HT,SD*;7-G:60@(E5N86)L92!T;R!C;VYN
M96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&-O;FYE
M='1E<G-I(&%L('-E<G9E<B!344PN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@X
M,PIM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@
M(DEM<&]S<VEB:6QE(&-O;FYE='1E<G-I(&-O;B!34TPN(@H*(SH@;&EB+U9&
M4R]F:6QE+G!H<#HR,S@@;&EB+U9&4R]F:6QE+G!H<#HR-#,@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z,C$T"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(Q.2!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HR,C<*;7-G:60@(E5N86)L92!T;R!C;W!Y
M(%9&4R!F:6QE+B(*;7-G<W1R("));7!O<W-I8FEL92!C;W!I87)E(&EL(&9I
M;&4@5D93+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS-S,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<
M(BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@8W)E87)E(&QA(&1I<F5C=&]R>2!6
M1E,@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S8W(&QI8B]61E,O
M;75S<6PN<&AP.C(W,"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR-S0*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B26UP
M;W-S:6)I;&4@8W)E87)E(&QA(&1I<F5C=&]R>2!61E,N(@H*(SH@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F
M:6QE+B(*;7-G<W1R("));7!O<W-I8FEL92!C<F5A<F4@:6P@9FEL92!61E,N
M(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R
M("));7!O<W-I8FEL92!C<F5A<F4@;&$@8V%R=&5L;&$@5D93(%PB)7-<(BXB
M"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(W.`IM<V=I9"`B56YA8FQE('1O(&-R
M96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B26UP;W-S:6)I;&4@8W)E
M87)E(&EL(&9I;&4@5D93('9U;W1O+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S
M<R]G>FEP+G!H<#HW.2!L:6(O2&]R9&4O0V]M<')E<W,O=&%R+G!H<#HW-@IM
M<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B26UP
M;W-S:6)I;&4@9&5C;VUP<FEM97)E(&QE(&EN9F]R;6%Z:6]N:2XB"@HC.B!L
M:6(O5D93+V9T<"YP:'`Z,S`S(&QI8B]61E,O<VUB+G!H<#HR,C@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D
M:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R("));7!O<W-I8FEL92!E
M;&EM:6YA<F4@7"(E<UPB+"!L82!D:7)E8W1O<GD@;F]N(.@@=G5O=&$N(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C0T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E
M<UPB.B`E<RXB"FUS9W-T<B`B26UP;W-S:6)I;&4@96QI;6EN87)E(%PB)7-<
M(CH@)7,N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS-#0@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,S(S(&QI8B]61E,O<W%L+G!H<#HT,#<*(SH@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,S<P"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@
M(DEM<&]S<VEB:6QE(&5L:6UI;F%R92`E<RP@;&$@9&ER96-T;W)Y(&YO;B#H
M('9U;W1A(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S@T(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C,X.`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R("));7!O<W-I8FEL92!E
M;&EM:6YA<F4@;&$@9&ER96-T;W)Y(%9&4R!I;B!M;V1O(')I8V]R<VEV;RXB
M"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,U,"!L:6(O5D93+VUU<W%L+G!H<#HS
M,S0@;&EB+U9&4R]M=7-Q;"YP:'`Z,S0W"B,Z(&QI8B]61E,O;75S<6PN<&AP
M.C,U-2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS.#`*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B26UP;W-S:6)I;&4@
M96QI;6EN87)E(&QA(&1I<F5C=&]R>2!61E,N(@H*(SH@;&EB+U9&4R]S<6PN
M<&AP.C0S,B!L:6(O5D93+W-Q;"YP:'`Z-#0T"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S
M='(@(DEM<&]S<VEB:6QE(&5L:6UI;F%R92!L82!D:7)E8W1O<GD@5D93.B`E
M<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C$R"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M("))37!O<W-I8FEL92!E;&EM:6YA<F4@:6P@9FEL92!61E,@7"(E<UPB+B(*
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S$V(&QI8B]61E,O;75S<6PN<&AP.C$V
M-R!L:6(O5D93+VUU<W%L+G!H<#HQ.#`*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z
M,3@W(&QI8B]61E,O<W%L+G!H<#HR.3$@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M-#$Y"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C0R-PIM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B26UP;W-S:6)I;&4@96QI
M;6EN87)E(&EL(&9I;&4@5D93+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HR-#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L
M9&5R(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@96QI;6EN87)E(&QA
M(&-A<G1E;&QA(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C0R
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R
M96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&5L:6UI;F%R
M92!61E,@:6X@;6]D;R!R:6-O<G-I=F\Z("5S+B(*"B,Z(&QI8B]61E,O9G1P
M+G!H<#HX-#<*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D
M:7)E8W1O<GDN(@IM<V=S='(@(DEM<&]S<VEB:6QE(&1E=&5R;6EN87)E(&QA
M(&1I<F5C=&]R>2!A='1U86QE+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-C`T"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T
M92!D971A:6QS(@IM<V=S='(@(DEM<&]S<VEB:6QE(&5S=&%R<F4@:2!D971T
M86=L:2!D96P@8V5R=&EF:6-A=&\B"@HC.B!L:6(O3F5T+TE-4U`N<&AP.C0S
M-R!L:6(O3F5T+TE-4U`O075T:"YP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G
M<W1R("));7!O<W-I8FEL92!C87)I8V%R92!L82!D969I;FEZ:6]N92!D:2`E
M<RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(P."!L:6(O5D93+V9I;&4N<&AP
M.C(Q,R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-SD*(SH@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,3@T"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB
M"FUS9W-T<B`B26UP;W-S:6)I;&4@<W!O<W1A<F4@:6P@9FEL92!61E,N(@H*
M(SH@;&EB+U9&4R]F='`N<&AP.CDX(&QI8B]61E,O<VUB+G!H<#HY,R!L:6(O
M5D93+W-M8BYP:'`Z,3`V"B,Z(&QI8B]61E,O<VUB+G!H<#HV-C4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R("));7!O<W-I8FEL92!A<')I<F4@:6P@9FEL92!61E,@7"(E
M<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,CDP(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C$S."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-#$*;7-G:60@(E5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R("))
M;7!O<W-I8FEL92!A<')I<F4@:6P@9FEL92!61E,@<&5R(&QA('-C<FET='5R
M82XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C@S(&QI8B]61E,O9FEL92YP:'`Z
M,3,W(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<V"FUS9VED(")5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B26UP;W-S:6)I;&4@87!R:7)E(&EL
M(&9I;&4@5D93+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP
M.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N
M(@IM<V=S='(@(DEM<&]S<VEB:6QE(&%P<FEE(&PG87)C:&EV:6\@8V]M<')E
M<W-O+B(*"B,Z(&QI8B]61E,N<&AP.C@U-@IM<V=I9"`B56YA8FQE('1O(')E
M860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B26UP
M;W-I8FEL92!L96=G97)E(&EL(&9I;&4@5D93("AF:6QE<VEZ92!F:6QE*"D@
M9F%I;&5D*2XB"@HC.B!L:6(O5D93+G!H<#HX.#<*;7-G:60@(E5N86)L92!T
M;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S
M='(@(DEM<&]S<VEB:6QE(&QE9V=E<F4@:6P@9FEL92!61E,@*&=E=$9I;&53
M:7IE*"D@9F%I;&5D*2XB"@HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(O
M;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G
M<W1R("));7!O<W-I8FEL92!L96=G97)E(&EL(&9I;&4Z("(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z-C@X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S
M<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(DEM<&]S<VEB:6QE(&QE9V=E<F4@
M;&$@9&ER96-T;W)Y('9F<W)O;W0N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HQ,3`Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*
M;7-G<W1R("(B"B));7!O<W-I8FEL92!R:6YO;6EN87)E("5S(&EN("5S.B!L
M82!C87)T96QL82!D:2!D97-T:6YA>FEO;F4@Z"!G:6$@<')E<V5N=&4B"@HC
M.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS,C,*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B26UP;W-S:6)I;&4@<FEN
M;VUI;F%R92!L82!D:7)E8W1O<GD@5D93+B(*"B,Z(&QI8B]61E,O<W%L+G!H
M<#HS-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!6
M1E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B26UP;W-S:6)I;&4@<FEN;VUI
M;F%R92!L82!D:7)E8W1O<GD@5D93.B`E<RXB"@HC.B!L:6(O5D93+V9T<"YP
M:'`Z,S4Q(&QI8B]61E,O<VUB+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(DEM<&]S<VEB:6QE(')I;F]M:6YA<F4@:6P@9FEL92!61E,@7"(E<UPB+B(*
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z-C(Y(&QI8B]61E,O;75S<6PN<&AP.C(T
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE("5S+R5S+B(*;7-G<W1R("));7!O<W-I8FEL92!R:6YO;6EN87)E(&EL
M(&9I;&4@5D93("5S+R5S+B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C(Q,R!L
M:6(O5D93+VUU<W%L+G!H<#HT-C0@;&EB+U9&4R]S<6PN<&AP.C,S.`HC.B!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HS,34@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M,S,W"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R
M("));7!O<W-I8FEL92!R:6YO;6EN87)E(&EL(&9I;&4@5D93+B(*"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED(")5;F%B;&4@
M=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B26UP;W-S:6)I;&4@97-E9W5I
M<F4@)VUK:7-O9G,G+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<W=O
M<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R
M9"!D;V-U;65N="(*;7-G<W1R("));7!O<W-I8FEL92!T<F%D=7)R92!Q=65S
M=&\@9&]C=6UE;G1O(%=O<F0B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$X
M,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('1R:6=G97(@9G)E
M92]B=7-Y('5P9&%T92!F;W(@)7,B"FUS9W-T<B`B26UP;W-S:6)I;&4@9&%R
M92!L)V%V=FEO(&%L;"=A9V=I;W)N86UE;G1O(&9R964O8G5S>2!P97(@)7,B
M"@HC.B!L:6(O5D93+V9T<"YP:'`Z,34T(&QI8B]61E,O9G1P+G!H<#HQ-3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@<V-R:79E<F4@:6P@9FEL
M92!61E,@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3@V"FUS9VED
M(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*
M;7-G<W1R("));7!O<W-I8FEL92!S8W)I=F5R92!I;"!F:6QE(%9&4R`H8V]P
M>2@I(&9A:6QE9"DN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR.30@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,30V(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$U,0IM
M<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@
M(DEM<&]S<VEB:6QE('-C<FEV97)E(&QE(&EN9F]R;6%Z:6]N:2!N96P@9FEL
M92!61E,N(@H*(SH@;&EB+U9&4RYP:'`Z.#8R"FUS9VED(")5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S
M='(@(DEM<&]S<VEB:6QE('-C<FEV97)E(&EL(&9I;&4@5D93+"!L82!Q=6]T
M82!C;VYS96YT:71A('9E<G+@(&5C8V5D=71A+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN
M92(*;7-G<W1R(")3;W1T;VQI;F5A=&\B"@HC.B!T96UP;&%T97,O<')E9G,O
M96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B06YN=6QL
M82!-;V1I9FEC:&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*
M;7-G<W1R(").;VX@9F%R92!L82!T=6$@=6QT:6UA(&%Z:6]N92(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C$@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,X.`IM<V=I9"`B56YE>'!E8W1E9"!R97-P
M;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B4FES
M<&]S=&$@:6YA='1E<V$@9&%L('-E<G9E<B!D=7)A;G1E(&QA(&-O;FYE<W-I
M;VYE.B`B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$W
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,SD*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S@R"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E
M(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B4FES<&]S=&$@:6YA='1E<V$@
M9&%L('-E<G9E<B!A.B`B"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-
M86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B56YI8V]D92`H551&+3@I
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$W"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,S@*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#`*
M;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,S<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S.0IM<V=I9"`B56YI
M=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z-S@@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C8R"FUS9VED(")5;FET<R(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HU."!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HT,CD*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#,P"FUS
M9VED(")5;FMN;W=N(@IM<V=S='(@(E-C;VYO<V-I=71O(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@
M87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO
M=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-PIM<V=I9"`B56YK
M;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G:60@(E5N:VYO=VX@
M=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(DYO;64@=71E;G1E(&4@
M<&%S<W=O<F0@<V-O;F]S8VEU=&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T
M:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(DYO;B!C;VQL96=A<F4@;"=E
M;&5M96YT;R!C;W)R96YT92(*"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z
M,S`R"FUS9VED(")5;FYA;65D(@IM<V=S='(@(E-E;GIA(&YO;64B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED
M("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#
M;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A
M<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO
M>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S
M8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-C@W(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z.3(W"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z.3,S"FUS9VED
M(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B17-T96YS:6]N92!N
M;VX@<W5P<&]R=&%T82(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,3DW
M('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A
M=&4B"FUS9W-T<B`B06=G:6]R;F$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E
M<R(*;7-G<W1R(")!9V=I;W)N82`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z-S8*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@
M(D%G9VEO<FYA('5T96YT92(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T(&%D
M;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I="YP
M:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*
M;7-G<W1R(")!9V=I;W)N82!<(B5S7"(N(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM
M<V=S='(@(E-C<FEP="!D:2!C87)I8V%M96YT92!E;&EM:6YA=&$N(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-R!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3DX"FUS9VED(")5<&QO860B"FUS9W-T<B`B0V%R
M:6-A(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X-0IM<V=I9"`B57!L
M;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V
M97(N(@IM<V=S='(@(F-A<FEC871I('1U='1I(&D@9FEL92!D:2!I;7!O<W1A
M>FEO;F4@9&5L;&4@87!P;&EC87II;VYI('-U;"!S97)V97(N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR
M,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R(")C87)A='1E
M<FD@;&%T:6YI(&UA:75S8V]L:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O
M;6%N(&YU;6)E<G,B"FUS9W-T<B`B3G5M97)I(')O;6%N:2!M86EU<V-O;&DB
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(S.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C0Q"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G
M:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R(")U<V$@:6P@8V]R<F5N=&4Z
M("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM
M<V=I9"`B57-E(%-33"(*;7-G<W1R(")5<V$@4U-,(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$R-PIM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@
M:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B57-A('-E
M(&EL(&YO;64@=71E;G1E+W!A<W-W;W)D(.@@9&EF9F5R96YT92!D82!Q=65L
M;&$@9&5L('-E<G9E<B!)35-0+B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z,C$*;7-G:60@(E5S97(B"FUS9W-T<B`B571E;G1E(@H*
M(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HW-S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S
M='(@(DQU=&5N=&4@)7,@;F]N(.@@875T;W)I>GIA=&\@<&5R("5S+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO
M;B(*;7-G<W1R(")'97-T:6]N92!5=&5N=&DB"@HC.B!L:6(O2&]R9&4O4')E
M9G,O54DN<&AP.C(T-0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(D]P
M>FEO;FD@571E;G1I(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E<B!2
M96=I<W1R871I;VXB"FUS9W-T<B`B4F5G:7-T<F%Z:6]N92!5=&5N=&DB"@HC
M.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@
M8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R("),87)E9VES
M=')A>FEO;F4@9&5G;&D@=71E;G1I(.@@<W1A=&$@9&ES86)I;&ET871A('!E
M<B!Q=65S=&\@<VET;RXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#DT
M"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(DYO;64@
M=71E;G1E(&YO;B!T<F]V871O(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$W.`HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C$Y."!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3,V"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z
M.3@@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$U,`HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HS,R!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C<R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS
M9VED(")5<V5R;F%M92(*;7-G<W1R(").;VUE(%5T96YT92(*"B,Z(&QI8B](
M;W)D92]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@
M(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B3F]M
M92!5=&5N=&4@7"(E<UPB(.@@9VEA('!R97-E;G1E+B(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S
M='(@(DYO;64@571E;G1E.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C@*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B3F]M92!5=&5N=&4Z
M("(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@
M(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(E5T96YT:2!N96P@<VES
M=&5M83HB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,30@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0R"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z,3<P(&QI8B]61E,O9FEL92YP:'`Z,C8X"FUS9VED
M(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("),82!D
M:7)E8W1O<GD@5D93(&YO;B!E<VES=&4N(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$R,`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B07-S96YZ
M82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX-C8*;7-G:60@(E9A;&ED(&QO
M8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B4&]S:7II;VYI('9A
M;&ED92!T<F]V871E(&EN8VQU9&]N;SH@(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV,SD*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(E9A;&ED
M:73@(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PIM<V=I9"`B5F%L
M=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B5F%L;W)E(&EN(&UI
M;G5T:2!D82!O<F$N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@U-B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")686QU
M92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B
M26P@=F%L;W)E(.@@;6%G9VEO<F4@9&QL82!M87-S:6UA(&QU;F=H97IZ82!D
M:2`E<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T-"!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C(V-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,Q-@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,CDQ,"!L:6(O2&]R9&4O1F]R;2]4>7!E+W1A8FQE
M<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(E9A;&]R:2(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,3`Y(&QI8B](;W)D92]&;W)M+G!H<#HR
M,3@V"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B5F%L
M;W)I(&1A:2!Q=6%L:2!S96QE>FEO;F%R92(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#D*;7-G:60@(E9A;G5A='4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S
M,PIM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B5F%R:6%B:6QE(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR-#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-0IM<V=I
M9"`B5F5N97IU96QA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI
M<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T
M<B`B5F5R:69I8V$@9F%L;&ET82`M('%U97-T;R!M97-S86=G:6\@<'7R(&5S
M<V5R92!S=&%T;R!A;'1E<F%T;R!C;VXN(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HW,#$*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B5F5R<VEO
M;F4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(X"FUS9VED(")6
M97)S:6]N($-O;G1R;VPB"FUS9W-T<B`B5F5R<VEO;F4@9&D@0V]N=')O;&QO
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B06QL:6YE
M86UE;G1O('9E<G1I8V%L92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS
M9W-T<B`B4FEE;7!I;65N=&\@=F5R=&EC86QE(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ
M(@IM<V=S='(@(E9E<G1I8V%L93HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@
M(DUO;'1O($%L=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C0X"FUS9VED(")6:65T($YA;2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-PIM<V=I9"`B5FEE=&YA;65S92`H
M5DE30TE)*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT
M<RYP:'`Z.3<Q"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T
M<B`B5FES=6%L:7IZ82`E<R(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*
M;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T<B`B5FES
M=6%L:7IZ82!U;F$@<&%G:6YA('=E8B!E<W1E<FYA(@H*(SH@;&EB+TAO<F1E
M+TU)344O0V]N=&5N=',N<&AP.C@S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")6
M:65W(&%S("5S(@IM<V=S='(@(E9I<W5A;&EZ>F$@8V]M92`E<R(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#8*;7-G
M:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#<*;7-G
M:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C$V"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@
M(E9I<VEB:6QI=.`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C4R"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B5FES:6)I;&ETX#H@
M(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM
M<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V
M"FUS9VED(")705).(@IM<V=S='(@(D%45$5.6DE/3D4B"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).
M24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T
M<B`B051414Y:24].12$A(2!224U53U9)($Q/(%-#4DE05"!-04Y504Q-14Y4
M12!$02`E<RXB"@HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS
M9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M-#4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,`IM<V=I9"`B5V%L;&ES
M(&%N9"!&=71U;F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.CDU(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S
M+G!H<#HR.0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:'1M;"YP:'`Z,3(W
M"FUS9VED(")787)N:6YG(@IM<V=S='(@(D%T=&5N>FEO;F4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")7
M92(*;7-G<W1R(")-92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R(")";VQL971T
M:6YO(&UE=&5O<F]L;V=I8V\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#$V"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS
M9W-T<B`B0F]L;&5T=&EN;R!M971E;W)O;&]G:6-O(&9O<FYI=&\@9&$B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DR"FUS9VED(")796%T:&5R+F-O;2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B
M5V5B(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,SD*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-
M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R(")3971T
M:6UA;F%L;65N=&4B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR
M.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R(")"96YV96YU=&\B"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*
M;7-G<W1R(")"96YV96YU=&\@82`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M
M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R(")"96YV96YU
M=&\L("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3@*;7-G:60@(E=E
M<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DY"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-S@*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L
M;V=I;C\B"FUS9W-T<B`B475A;&4@87!P;&EC87II;VYE(&1O=G+@('9I<W5A
M;&EZ>F%R92`E<R!D;W!O(&PG86-C97-S;S\B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R
M(&-H87)A8W1E<C\B"FUS9W-T<B`B475A;"?H(&EL(&-A<F%T=&5R92!D:2!D
M96QI;6ET87II;VYE/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C$W"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#8U"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I
M9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@
M961I=&]R+B(*;7-G<W1R(")1=6%L92!P;'5G:6YS(&%B:6QI=&%R92!P97(@
M:6P@4FEC:"!497AT(&5D:71O<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G
M<W1R("),87)G:&5Z>F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P-PIM
M<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(DQA<F=H97IZ82!I
M;B!U;FETX"!#4U,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H
M92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R
M("(B"B),87)G:&5Z>F$@9&5L(&UE;G4@9&D@)7,@<W5L;&$@<VEN:7-T<F$@
M*&%V<N`@969F971T;R!C;VP@<')O<W-I;6\@86-C97-S;RDZ(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@
M(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R("),87)G:&5Z>F$@9&5L;&$@
M=&%B96QL82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@(E5N:73@(&1I
M(&QA<F=H97IZ82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`B3&%R9VAE>GIA
M.B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,34*;7-G:60@(E=I
M:VDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(X.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM
M<V=I9"`B5VEN9"(*;7-G<W1R(")696YT;R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")7:6YD($5A<FQY(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#<*;7-G:60@(E=I
M;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B5F5L;V-I=.`@9&5L('9E;G1O
M(&EN(&YO9&DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V,PIM<V=I9"`B
M5VEN9#HB"FUS9W-T<B`B5F5N=&\Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(S,0IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(E9E;G1O.B`B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*
M;7-G<W1R(")386=G97IZ82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ.3@*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R("),879O<F\B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-"!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM<V=I9"`B5V]R:R!!
M9&1R97-S(@IM<V=S='(@(DEN9&ER:7IZ;R!D96P@;&%V;W)O(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@
M4&AO;F4B"FUS9W-T<B`B5&5L969O;F\@9&5L(&QA=F]R;R(*"B,Z(&QI8B]&
M:6QE+T-35BYP:'`Z,3DS(&QI8B]&:6QE+T-35BYP:'`Z,CDT"B,L('!H<"UF
M;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E
M9"X@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R(").=6UE<F\@9&D@
M8V%M<&D@97)R871O(&YE;&QA(&QI;F5A("5D+B!!='1E<VD@)60L('1R;W9A
M=&D@)60N(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HS,S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L
M(&9O=6YD("5D+B(*;7-G<W1R(").=6UE<F\@9&D@8V%M<&D@97)R871O+B!!
M='1E<VD@)60L('1R;W9A=&D@)60N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ
M,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE
M(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B0V]M<&5N<V%Z:6]N92!S
M8F%G;&EA=&$@)60@9'5R86YT92!L82!L971T=7)A(&1I('5N(&9I;&4@5D93
M+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#4*;7-G:60@(E@M
M4F5F(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3DT"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U
M,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T
M($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)
M9&5N=&EF:65R(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-C@S"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-"!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4V"FUS9VED(")9
M65E9(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,3$Q"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*
M;7-G<W1R(")!;FYU86QM96YT92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-3(*;7-G:60@(EEE;65N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY-C8*
M;7-G:60@(EEE<R(*;7-G<W1R(")3:2(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")997,L($D@06=R964B
M"FUS9W-T<B`B4VDL('-O;F\@9"=A8V-O<F1O(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I
M;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B
M86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*(E-E:2!I;B!F;W)M871O('1E
M<W1O+B!5<V$@:6P@8F]T=&]N92!;/#Y=('!E<B!T;W)N87)E(&%L(&9O<FUA
M=&\@5UE325=91RXB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C(S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A
M;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R
M(").;VX@:&%I(&EL('!E<FUE<W-O(&1I(&-R96%R92!P:?D@9&D@)60@8FQO
M8V-H:2XB"@HC.B!L:6(O2&]R9&4N<&AP.C$T,C0*;7-G:60@(EEO=2!A<F4@
M;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(DYO;B!T:2!S96D@875T96YT
M:6-A=&\N(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H<#HS,#@*;7-G:60@
M(EEO=2!C86YN;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F
M=6QL(&YA;64N(@IM<V=S='(@(DYO;B!P=6]I(&%V97)E(&EL(&-A<F%T=&5R
M92`G7%PG(&YE;"!T=6\@;F]M92!C;VUP;&5T;RXB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3@U-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW-0IM<V=I9"`B
M66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G
M<W1R(").;VX@:&%I(&EN<V5R:71O('5N(&EN9&ER:7IZ;R!E;6%I;"!V86QI
M9&\N(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE
M(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*
M(FEN("5S+B(*;7-G<W1R("(B"B).;VX@:&%I(&%S<V]C:6%T;R!N97-S=6X@
M9&5I(&-A;7!I(&1A;"!F:6QE(&EM<&]R=&%T;R!C;VX@:2!C86UP:2`B"B)C
M;W)R:7-P;VYD96YT:2!I;B`E<RXB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z
M.3@W"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@
M(E-E:2!S=&%T;R!D:7-C;VYN97-S;RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C
M96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L
M("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N
M(@IM<V=S='(@(B(*(D1E=FD@:6YS97)I<F4@=6X@;G5M97)O(&1I(&-E;&QU
M;&%R92!V86QI9&\L(&-O;G1E;F5N=&4@<V]L;R!N=6UE<FD@8V]N("(*(FPG
M;W!Z:6]N92!D96P@)RLG('!E<B!I('!R969I<W-I(&EN=&5R;F%Z:6]N86QI
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V
M92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R(")$979I(&EN<V5R
M:7)E('5N('9A;&]R92!V86QI9&\N(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG
M;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R
M964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B1&5V:2!C;VYF
M:6=U<F%R92!U;B!B86-K96YD('!E<B!I;"!$871A5')E92!P97(@=7-A<F4@
M4VEG;G5P<RXB"@HC.B!L:6(O2&]R9&4N<&AP.C0W,0IM<V=I9"`B66]U(&UU
M<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(D1E=FD@8V]N
M9FEG=7)A<F4@=6X@8F%C:V5N9"!61E,N(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H
M92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P
M;W)T+B(*;7-G<W1R(")$979I('!R:6UA(&1E<V-R:79E<F4@:6P@<')O8FQE
M;6$@<')I;6$@9&D@;6%N9&%R;&\@8V]M92!R97!O<G0N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U
M(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O
M(@IM<V=S='(@(D1E=FD@:6YS97)I<F4@;"=54DP@86QL82!Q=6%L92!P=6YT
M82!Q=65S=&\@8V]L;&5G86UE;G1O(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P
M8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@
M=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B1&5V:2!S96QE>FEO;F%R92!U;B!S
M97)V97(@9&$@96QI;6EN87)E+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM
M<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U
M="XB"FUS9W-T<B`B1&5V:2!S<&5C:69I8V%R92!U;B!U=&5N=&4@9&$@87IZ
M97)A<F4N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R(")$979I
M('-P96-I9FEC87)E('5N('5T96YT92!D82!R:6UU;W9E<F4N(@H*(SH@861M
M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A
M9&0N(@IM<V=S='(@(D1E=FD@<W!E8VEF:6-A<F4@=6X@=71E;G1E(&1A(&%G
M9VEU;F=E<F4N(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@
M(D1E=FD@<W!E8VEF:6-A<F4@=6X@=71E;G1E(&1A(&%G9VEO<FYA<F4N(@H*
M(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@
M(D1E=FD@<W!E8VEF:6-A<F4@=6XG87II;VYE(&1A(&5S96=U:7)E+B(*"B,Z
M(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED
M(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@
M(D1E=FD@<W!E8VEF:6-A<F4@:6P@;F]M92!D96QL82!N=6]V82!C871E9V]R
M:6$N(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW
M,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE
M(&YU;6)E<B(*;7-G<W1R(")$979I(&EN<V5R:7)E('5N(&YU;65R;R!D:2!T
M96QE9F]N;R!I=&%L:6%N;R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY-S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I
M<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(DQA('1U82!S97-S
M:6]N92`E<R#H('-C861U=&$N(%-I('!R96=A(&1I(&-O;&QE9V%R<VD@;G5O
M=F%M96YT92XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS
M.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(DEL('1U;R!I
M;F1I<FEZ>F\@16UA:6PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$U
M"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(DEL(&-A;7!O
M($1A.B!D96P@='5O(&EN9&ER:7IZ;SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(*;7-G
M:60@(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`B3&4@='5E(&EN9F]R;6%Z
M:6]N:2(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY-SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D
M('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B
M"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN
M+B(*;7-G<W1R("(B"B));"!T=6\@:6YD:7)I>GIO($EN=&5R;F5T(.@@8V%M
M8FEA=&\@9&%L;"=I;FEZ:6\@9&5L;&$@='5A('-E<W-I;VYE("5S+B!097(@
M(@HB<')O=&5G9V5R92!L82!T=6$@<VEC=7)E>GIA+"!D979I(')I8V]L96=A
M<G1I(&YU;W9A;65N=&4N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R("));"!T=6\@3F]M
M92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"FUS9VED
M("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D
M92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A
M(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R
M("(B"B));"!T=6\@8F%C:V5N9"!D:2!A=71E;G1I8V%Z:6]N92!N;VX@<W5P
M<&]R=&$@;"=A9V=I=6YT82!D:2!N=6]V:2!U=&5N=&DN(%-E("(*(G9U;VD@
M=7-A<F4@2&]R9&4@<&5R(&=E<W1I<F4@9VQI('5T96YT:2P@9&5V:2!U<V%R
M92!U;B!B86-K96YD(&1I("(*(F%U=&5N=&EC87II;VYE(&1I9F9E<F5N=&4B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@
M(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P
M;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N
M(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@HB
M26P@='5O(&)A8VME;F0@9&D@875T96YT:6-A>FEO;F4@;F]N('-U<'!O<G1A
M(&PG96QE;F-O(&1E9VQI('5T96YT:2P@;R!L82`B"B)F=6YZ:6]N92#H('-T
M871A(&1I<V%B:6QI=&%T82!P97(@86QT<F4@<F%G:6]N:2XB"@HC.B!L:6(O
M2&]R9&4O075T:"YP:'`Z.3@S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO
M=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@
M8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y
M;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B
M(@HB4V5M8F9R82!C:&4@:6P@='5O(&)R;W=S97(@<VEA(&-A;6)I871A(&1A
M;&PG:6YI>FEO(&1E;&QA('1U82!S97-S:6]N92`E<RX@(@HB4&5R('!R;W1E
M9V=E<F4@;&$@='5A('-I8W5R97IZ82P@9&5V:2!A8V-E9&5R92!N=6]V86UE
M;G1E+B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4W"FUS9VED(")9;W5R
M(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S
M='(@(DEL('1U;R!B<F]W<V5R(&YO;B!S=7!P;W)T82!Q=65S=&$@9G5N>FEO
M;F4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*;7-G
M:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I
M;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R
M:6YT+B(*;7-G<W1R("(B"B));"!T=6\@8G)O=W-E<B!N;VX@<W5P<&]R=&$@
M<75E<W1A(&]P>FEO;F4@9&D@<W1A;7!A+B!0<F5M:2!#;VYT<F]L+T-O;6UA
M;F0@(@HB*R!0('!E<B!S=&%M<&%R92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C8Q"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G
M<W1R("));"!T=6\@9G5S;R!O<F%R:6\Z(@H*(SH@<V5R=FEC97,O<')E9G,N
M<&AP.C$Q-PIM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N
M(&-H86YG960N(@IM<V=S='(@(DQA('1U82!I9&5N=&ETX"!D:2!D969A=6QT
M(.@@<W1A=&$@;6]D:69I8V%T82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,38Q"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@
M(DQA('1U82!I9&5N=&ETX"!D:2!D969A=6QT.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,#0*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R
M("));"!T=6\@;F]M92!C;VUP;&5T;SHB"@HC.B!L:6(O2&]R9&4O075T:"YP
M:'`Z.3DY"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R
M("),82!T=6$@;&]G:6X@Z"!S8V%D=71A+B(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W
M('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B3&$@='5A(&YU;W9A
M('!A<W-W;W)D('!E<B`E<R#H.B`E<R(*"B,Z(&QI8B](;W)D92]0<F5F<R]5
M22YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@
M(DQE('1U92!O<'II;VYI('-O;F\@<W1A=&4@86=G:6]R;F%T92!P97(@;&$@
M9'5R871A(&1I('%U97-T82!S97-S:6]N92XB"@HC.B!L:6(O2&]R9&4O4')E
M9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U
M<&1A=&5D+B(*;7-G<W1R("),92!T=64@;W!Z:6]N:2!S;VYO('-T871E(&%G
M9VEO<FYA=&4N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S4*
M;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B
M3&$@='5A('!A<W-W;W)D(.@@<W1A=&$@87IZ97)A=&$B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R
M9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN
M('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*(DQA('1U
M82!P87-S=V]R9"#H('-T871A(&%Z>F5R871A+"!C;VYT<F]L;&$@;&$@='5A
M(&5M86EL(&4@86-C961I(&-O;B!L82!T=6$@(@HB;G5O=F$@<&%S<W=O<F0N
M(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C<S,PIM<V=I9"`B66]U<B!P87-S
M=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B3&$@='5A('!A<W-W;W)D(.@@
M<V-A9'5T82XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*
M;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(DD@='5O:2!S
M97)V97(@<F5M;W1I.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M."!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4T"FUS9VED(")9=6=O<VQA=FEA
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM
M<V=I9"`B6F%I<F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-@IM<V=I9"`B6F%M8FEA(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q."!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR-3<*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z
M,3<T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R
M"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B6TYA<V-O;F1I
M(&EL('1E<W1O(&-I=&%T;UTB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX
M.0IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");4F5P;W)T(&1E
M;"!P<F]B;&5M85TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L
M;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R
M(");36]S=')A(&EL('1E<W1O(&-I=&%T;R`M(@H*(SH@;&EB+TAO<F1E+U1E
M>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,L('!H<"UF;W)M
M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S
M='(@(EM-;W-T<F$@:6P@=&5S=&\@8VET871O("T@)7,@;&EN965=(@H*(SH@
M;&EB+TAO<F1E+G!H<#HR,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@
M)7,@;V8@)7-=(@IM<V=S='(@(EML:6YE82`E<R!D:2`E<UTB"@HC.B!L:6(O
M2&]R9&4N<&AP.C$U-30@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0IM
M<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E]!;6UI;FES=')A>FEO
M;F4B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?1&%T851R964B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O=R(*;7-G<W1R(")?0V%N
M8V5L;&$@4FEG82(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P
M<R(*;7-G<W1R(")?1W)U<'!I(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$W
M-0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`B7T%I=71O(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED
M(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")P<F]P<FEE=.`@9&5L
M;"=?26UM86=I;F4N+BXB"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,3DT"FUS
M9VED(")?3&]G(&EN(@IM<V=S='(@(E]%;G1R82(*"B,Z(&QI8B](;W)D92]-
M96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(E]%<V-I(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B7TUO9&EF
M:6-A($-O;&QE9V%M96YT;RXN+B(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ
M-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(E]/<'II;VYI(@H*(SH@;&EB
M+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B7U!E
M<FUE<W-I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(V"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T
M<B`B7T5L:6UI;F$@0V]L;&5G86UE;G1O+BXN(@H*(SH@;&EB+V%P:2YP:'`Z
M,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B7TEM<&]S=&%Z:6]N92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4')O
M<')I973@(&1E;&QA(%]486)E;&QA+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y
M"FUS9VED(")?57-E<G,B"FUS9W-T<B`B571E;G1I(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HY,C4*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R(")R
M=6)R:6-A(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3,T"FUS
M9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R(")I;F1I<FEZ>FD@<V-O
M;F]S8VEU=&DB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDQ-PIM<V=I9"`B
M8V%L96YD87(B"FUS9W-T<B`B8V%L96YD87)I;R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3<Y(&QI8B]";&]C:R]M971A<BYP:'`Z,S8U"B,L('!H<"UF
M;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B8V%L;6\B"@HC.B!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@
M;W5T<'5T(&9I;&4B"FUS9W-T<B`B;F]N('!O<W-O(&-R96%R92!I;"!F:6QE
M(&1I(&]U<'5T(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3,P
M"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R(")N;VX@<&]S<V\@
M87!R:7)E(&PG:6YP=70B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP
M:'`Z-C`P"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(G!R96UI('%U:2(*
M"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M
M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(F5R<F]R92!N96QL)W5S
M;R!D96QL82!L:6YE82!D:2!C;VUA;F1O(@H*(SH@;&EB+TAO<F1E+TU)344O
M365S<V%G92YP:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM
M<V=S='(@(F5R<F]R92!D:2!C;VYF:6=U<F%Z:6]N92(*"B,Z(&QI8B](;W)D
M92]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M
M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]-
M97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S
M='(@(F5R<F]R92!N96P@9F]R;6%T;R!D96QL82!D871A(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]E9&ET+FEN8SHS,`IM<V=I9"`B961I="(*;7-G<W1R(")P
M=6)B;&EC82(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$X,@IM
M<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@(F5N=')Y(&YO;B!T<F]V
M871A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S,*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T)R
M;W=S97(N<&AP.C@Y-@IM<V=I9"`B9FEL92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$X,2!L:6(O0FQO8VLO;65T87(N<&AP.C,V-R!L
M:6(O0FQO8VLO;65T87(N<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")F
M<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(F1A;"`E<R`H)7,I
M(&%L("5S("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S
M.0IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4P"FUS9VED(")H.B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4Y"FUS
M9VED(")H:"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E
M+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(FYO
M;64@:&]S="!S8V]N;W-C:75T;R(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C(S(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-C4*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R(")I;6UE9&EA=&\B"@HC
M.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H
M<#HW.0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-
M24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R
M(@IM<V=S='(@(F5R<F]R92!D:2!I;G!U="]O=71P=70B"@HC.B!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W
M87)E(&5R<F]R(@IM<V=S='(@(F5R<F]R92!I;G1E<FYO(&1E;"!S;V9T=V%R
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S
M"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B;&EN965=(@H*(SH@;&EB+U9&4R])
M4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S
M='(@(F5R<F]R92!D:2!C;V1I8V4@)60@9&D@;6MI<V]F<R!D=7)A;G1E(&QA
M('-C<FET=&]R82!)4T\N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,W,`IM<V=I9"`B;6TB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+U!R969S+U5)+G!H<#HR.#4@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N
M<&AP.C$W-`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C0S"FUS
M9VED(")N86UE(@IM<V=S='(@(FYO;64B"@HC.B!L:6(O2&]R9&4O4E!#+G!H
M<#HQ,C0*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R(")N;VX@:6UP
M;&5M96YT871O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C(P
M"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(FYO;B!A;F-O
M<F$@:6UP;&5M96YT861O(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,#D*
M;7-G:60@(FYO=&5P860B"FUS9W-T<B`B8FQO8V-O(&YO=&4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS
M9VED(")P97)C96YT(@IM<V=S='(@(G!E<F-E;G1O(@H*(SH@;&EB+TAO<F1E
M+TU)344O365S<V%G92YP:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E;FEE
M9"(*;7-G<W1R(")P97)M97-S;R!N96=A=&\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE
M;',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z
M,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B
M97)R;W)E(')E;6]T;R!N96P@<')O=&]C;VQL;R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<U"FUS9VED(")R:7-I;F<B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,30R"FUS
M9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@(G-E<G9I>FEO(&YO
M;B!D:7-P;VYI8FEL92(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,3`Q
M"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(FUO<W1R82!L92!D
M:69F97)E;GIE(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS.#<*;7-G:60@
M(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<T"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B8V]S=&%N=&4B
M"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y
M<W1E;2!E<G)O<B(*;7-G<W1R(")E<G)O<F4@9&D@<VES=&5M82(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z.3,S"FUS9VED(")T87-K(&QI<W0B"FUS9W-T
M<B`B96QE;F-O(&%T=&EV:73@(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G
M92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R(")G
M=6%S=&\@=&5M<&]R86YE;R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&QI8B](
M;W)D92]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED(")T>7!E('1H92!P87-S
M=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(G-C<FEV:2!L82!P87-S
M=V]R9"!D=64@=F]L=&4@<&5R(&-O;F9E<FUA<F4B"@HC.B!A9&UI;B]S971U
M<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B
M=6YI9FEE9"(*;7-G<W1R(")U;FEF:6-A=&\B"@HC.B!L:6(O2&]R9&4O34E-
M12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R(")S96YZ82!N
M;VUE(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0IM<V=I9"`B=7-E
M<B!S96QE8W0B"FUS9W-T<B`B=71E;G1E('-E;&5Z:6]N871O(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(T,@IM<V=I9"`B=SHB"FUS9W-T<B`B=SHB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T
M<B`B=V5A=&AE<BYC;VTB"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&\O:F%?2E`N<&\`````````````````````
M````````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#8W-S<S,@`Q,#4Q-30S
M,S<U-``P,3<V-#8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(R!*87!A;F5S92!T<F%N<VQA=&EO;B!F;W(@2&]R9&4N"B,@
M0V]P>7)I9VAT("A#*2`R,#`T($AO<F1E(%!R;VIE8W0*(R!4:&ES(&9I;&4@
M:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS92!A<R!T:&4@
M2&]R9&4@<&%C:V%G92X*(R!(:7)O;6D@2VEM=7)A(#QH:7)O;6E`=&%C+G1S
M=6MU8F$N86,N:G`^"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED
M+59E<G-I;VXZ($AO<F1E(#,N,2XP7&XB"B)03U0M0W)E871I;VXM1&%T93H@
M,C`P-BTP,RTP-B`Q,CHT-RLP,3`P7&XB"B)03RU2979I<VEO;BU$871E.B`R
M,#`V+3`S+3(R(#$R.C`P*S`Y,#!<;B(*(DQA<W0M5')A;G-L871O<CH@2&ER
M;VUI($MI;75R82`\:&ER;VUI0'1A8RYT<W5K=6)A+F%C+FIP/EQN(@HB3&%N
M9W5A9V4M5&5A;3H@2F%P86YE<V4@/'5N:VYO=VY`=6YK;F]W;BYD;VUA:6X^
M7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT
M+W!L86EN.R!C:&%R<V5T/5-(24947TI)4UQN(@HB0V]N=&5N="U4<F%N<V9E
M<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,V-@HC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*
M;7-G<W1R("(@*"5S()/ZD4\I(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ,S@S"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S
M*2(*;7-G<W1R("*#08-.@UJ#6(-,@T,@)7,B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S<T"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@
M9&%Y<RDB"FUS9W-T<B`B@6DE<R"3^H+,D^""R8%J(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,W,`IM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B
M("B-H9/Z*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S(*;7-G
M:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(H%IEKZ3^H%J(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.`IM<V=I9"`B("AY97-T97)D87DI(@IM
M<V=S='(@(B`HC?"3^BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-3`*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-@IM<V=I9"`B(&%T("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*
M;7-G<W1R("(G)7,G((+-@V:#0H.,@TZ#9X.*@5N"Q8+-@J""Z(+<@KF"\8%"
M(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R
M(")<(B5S7"(@@LV0LX*U@J*129'P@L6"S8*@@NB"W(*Y@O&!0B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S$P"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`Y.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO
M<F1E(%)E9VES=')Y+B(*;7-G<W1R(")<(B5S7"(@@LT@2&]R9&4@@XR#5X-8
M@V>#BH+)D-V2Z(*S@NJ"Q(*B@MR"N8+Q+B(*"B,Z(&9R86UE=V]R:R]4<F5E
M+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E
M92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(EPB)7-<(B"#8X.*@5N5
M7(ZFBT"47(*JC*F5=(*I@NB"W(*Y@O&!0B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T
M;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB((*J@T^#BX%;
M@W:#5H-8@V6#@(+)DL>)P8*S@NJ"W(*U@KV!0B(*"B,Z(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@
M(EPB)7-<(B""JH-!@TZ#6H-8C*"#5H-8@V6#@(+)DL>)P8*S@NJ"W(*U@KTN
M(@H*(R!M<V=S='(@(B<E<R>"JHN6B<*0W9+H@U:#6(-E@X""R9+'B<&"LX+J
M@MR"M8*]+B(*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A
M9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A
M<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(EPB)7-<(B""S8WLD*R"LX+J
M@MR"N8+Q@L6"M8*].B`E<RXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@)2XR9DU"
M(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`BEV67RB`E,B0N,F9-0B"2AH+,
M("4Q)"XR9DU"((YGEW`H)3,D+C)F)24I(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(R-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A
M;F0@)7,B"FUS9W-T<B`B)60@)7,@@L8@)7,B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W
M"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S
M=V]R9"!E>'!I<F5S+B(*;7-G<W1R("*#<(-8@X^!6X-H@LV"H(+&("5D()/Z
METR,^(+%@K>!0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("*2RI)M("T@)7,B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(E<R"3
M9(YQCG>6Y"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C@T,"!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*
M;7-G<W1R("(E<R"5VX[GD8"-[(+,BFV41B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(E<R""S)#=DN@B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8T"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B)7,@@U2#0X.3@T&#
M8H-V(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(E
M<R"3KXC3C_"-@"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#,R
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DT"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-C@R(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M-S4P"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*
M;7-G<W1R("(E<R""S8KY@LF1MHW=@K6"W(*W@4(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$V-B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(T-@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,U,B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!A="`E<R`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@
M=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D
M(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I
M('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(B
M"B(E<R""S8Z?@LF.=Y+H@K."ZH+$@J*"Z97;CN>1@(WL@O".P(US@K>"Z8^`
ME/6"JI"N@J*"W(*U@KV!0H[`C7."M8*]@J*1@(WL@LPB"B*#>X-B@TZ#6(+P
M@V"#1H-B@TZ"M8+$@JV"OH*S@J*!0B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER
M960B"FUS9W-T<B`B)7,@@JJ52Y=V@L6"MR(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,CDS"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS
M9W-T<B`B)7,@E:HB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C
M=&EO;BYP:'`Z,3(Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N
M9"XB"FUS9W-T<B`B)7,@@JJ"H(+H@MR"N8+Q@4(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M('1O("5S(&]F("5S(@IM<V=S='(@(B5S((*I@N<@)7.!08V'C'8@)7,B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R("(E<R""S(-!@VB#
MC(-8DJ`B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ.`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(B5S((+,
MEUR2Z)5<(@H*(R!M<V=S='(@(B5S@LR#2H.,@Y.#7R(*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G
M<R!.;W1E<&%D(@IM<V=S='(@(B5S((+,@X&#@I*@(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G
M<R!487-K;&ES="(*;7-G<W1R("(E<R""S(->@UB#3H.*@UB#9R(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S
M='(@(B5S.B`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT
M;6PN<&AP.C$R-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M
M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@
M0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@
M<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M
M871I;VXN(@IM<V=S='(@(B(*(B5S.B""L8+,@X&#8H-:@5N#5X+-CJ:"LX+J
M@L2"HH+ID9>038[2@JF"YX+,@N""S(+%@LV"R(*B@L:.=H+M@NJ"W(*W@4*"
MNX+,DH8B"B*"S(.*@Y.#3H+P@TZ#BH-B@TZ"M8*]@NB!08S"D&R/[I7Q@O"1
MEY!-@K>"Z8+,@LV/7)6J@LF2C8C3@K6"Q(FZ@K."HH%"(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,U-"!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,SDY"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3DU(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C`P"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR.30@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`V-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3(U"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HW-#@*;7-G
M:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(M+2"129'P("TM(@H*(SH@;&EB
M+T)L;V-K+W1I;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G
M<W1R("(Q,HZ>BM2,8(ZN(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"FUS
M9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R("(R-(Z>BM2,8(ZN(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM
M<V=S='(@(C(T((Z>BM0B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP
M.C8Y"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`B/)%/@LR#>8%;@U<B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R-@IM<V=I9"`B02!D871A8F%S92!B
M86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R("*"
ML8+,@W6#C8-B@TZ"R8+-@V:!6X->@WB!6X-8@JJ52Y=V@L6"MX%"(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S$*;7-G:60@(D$@9F%T86P@
M97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(I)VEKV328+(@T>#B8%;@JJ4
MK9"V@K6"W(*U@KTB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@
M96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(E!'4(SVBDJ,KH*J@X&#8H-:
M@5N#5X+,B,.-AHF[@LF52Y=V@L6"MX%"(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3$V.`IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I
M<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T
M<B`B4$=0C/:*2HRN@JJ/D):\@K."ZH*]@X&#8H-:@5N#5X+,C)^/V(+)E4N7
M=H+%@K>!0B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P
M.3D*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B
M"B)M97-S86=E+B(*;7-G<W1R("(B"B)01U",]HI*C*Z!05!'4)3IEJ>,KH*H
M@N:"T8-P@UB#=(.,@5N#68*JB,.-AHF[@X&#8H-:@5N#5X+,E9R-AH+)E4N7
M=H+%@K>!0B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P
M,38*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M
M97-S86=E+B(*;7-G<W1R(")01U",]HI*C*Z!05!'4)3IEJ>,KH*H@N:"T8-P
M@UB#=(.,@5N#68*J@X&#8H-:@5N#5X+,CY"6O(+)E4N7=H+%@K>!0B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3`V"FUS9VED("(B
M"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S
M<V%G92XB"FUS9W-T<B`B(@HB4R]-24U%C/:*2HRN@4%3+TU)3464Z9:GC*Z"
MJ(+F@M&#<(-8@W2#C(%;@UF"JHC#C8:)NX.!@V*#6H%;@U>"S)6<C8:"R95+
MEW:"Q2(*(H*W@4(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T
M92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*(E,O34E-18SVBDJ,KH%!
M4R]-24U%E.F6IXRN@JB"YH+1@W"#6(-T@XR!6X-9@JJ#@8-B@UJ!6X-7@LR/
MD):\@LF52Y=V@L6"MX%"(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U
M:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B4R]-24U%C/:*
M2HRN@JJ#@8-B@UJ!6X-7@LR(PXV&B;N"R95+EW:"Q8*W@4(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"FUS9VED(")!32!#
M;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*
M;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T
M<B`B04TO4$TB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED
M(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R("*"L8+,@T>#9H-"@UZ!6X+)
M@L*"HH+$(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3,*;7-G:60@
M(D%B;W5T+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")61E.#9H-"@XR#3H-G
M@XJ"S(WLD*R"S8-!@TZ#6H-8BY&4VX*S@NJ"W(*U@KV!0B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI
M960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(E9&4X-T@T"#0X.+@LR-
M[)"L@LV#08-.@UJ#6(N1E-N"LX+J@MR"M8*]@4(B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z,PIM<V=I9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G
M<W1R("*#08-*@T6#DX-GC^Z5\2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW.`IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R("*#08-*@T6#
MDX-G@LR#<(-8@X^!6X-H(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB
M"FUS9W-T<B`B@T&#2H-%@Y.#9X+-DX",BX*S@NJ"Q(*B@MR"MX%"(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S-0IM<V=I9"`B06-C;W5N=&EN
M9R(*;7-G<W1R("*#08-*@T6#DX-G(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED
M(")!9&0B"FUS9W-T<B`BDL>)P2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B
M"FUS9W-T<B`B@U2#=8-/@XN!6X-V@O"2QXG!(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.CDY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R("*#
M5(-U@T&#3H-:@UB,H(+PDL>)P2(*"B,@;7-G<W1R("*#5(-UBY:)PH-T@XF#
M3X+PDL>)P2(*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@
M(D%D9"!(97)E.B(*;7-G<W1R("*"L8*Q@LF2QXG!.B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED(")!9&0@
M3F5W($=R;W5P(@IM<V=S='(@(I!6@K6"HH-/@XN!6X-V@O"2QXG!(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB
M"FUS9W-T<B`BD%:"M8*B@O"#08-.@UJ#6(R@@O"2QXG!(@H*(R!M<V=S='(@
M(I!6@K6"HHN6B<*#=(.)@T^"\)+'B<$B"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O861D8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D
M(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(H-4@W6#3X.+@5N#
M=H+P(%PB)7-<(B""R9+'B<$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!P
M97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R("*#5(-U@T&#3H-:@UB,H(+P
M(%PB)7-<(B""R9+'B<$B"@HC(&US9W-T<B`B@U2#=8N6B<*0W9+H@O`G)7,G
M@LF2QXG!(@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W
M('5S97(Z(@IM<V=S='(@(I!6BTN#AH%;@U6"\)+'B<&!1B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-38*;7-G:60@(D%D
M9"!C;VQU;6XB"FUS9W-T<B`BE_&"\)+'B<$B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B
M"FUS9W-T<B`BD%:+2X.!@Y.#;X+PDL>)P8%&(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`B@WF#
M08+PDL>)P2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3
M:61E8F%R(@IM<V=S='(@(B5S((.!@VJ#A8%;@O`@36]Z:6QL82""S(-4@T.#
M:(-O@5N"R9+'B<&"MX+I(@H*(R!M<V=S='(@(H-*@XR#DX-?@5N"R9+'B<$B
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0IM
M<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B@T&#:(.,@UB2
MH(+)DL>)P3HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T
M<B`BCH2"S(+,@T&#:(.,@UB2H(+)DL>)P2(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R("*#AH%;@U6"\)+'B<$B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!
M9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@
M861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R
M("(B"B*#5H-8@V6#@(+)(%PB)7-<(B""\)+'B<&"M8+<@K6"O8*J@4&#5(-#
M@Y.#08-B@W:"S(_NE?&"JI+'B<&"Q8*K@MR"N8+Q@L6"M2(*(H*]@48E<R(*
M"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@
M7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS
M9W-T<B`B@U:#6(-E@X""R2!<(B5S7"(@@O"2QXG!@K6"W(*U@KV"S(+%@4&#
MC8-/@T.#DX+%@JN"W(*W@4(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N
M;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*
M;7-G<W1R("*#AH%;@U6"S)+'B<&/B)>=@LV6LXSX@LF"R(+!@L2"HH+<@K>!
M0B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$W
M,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#,X"FUS9VED(")!9&1R97-S
M(@IM<V=S='(@(H]:CXHB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,30Q"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B@T&#:(.,@UB2H"(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4V"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS9VED
M(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R
M<R(*;7-G<W1R("**QY>=("T@D;R"S(.&@5N#58+,@T&#3H-:@UB,H"(*"B,Z
M(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP
M:'`Z,3$S"FUS9VED(")!9&UI;FES=')A=&EO;B(*;7-G<W1R("**QY>=(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,PIM<V=I9"`B061S(@IM
M<V=S='(@(D%D<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM
M<V=S='(@(H-!@W2#2X-J@UB#7H.3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB
M86YI82(*;7-G<W1R("*#08.+@V^#:H-!(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B
M06QG97)I82(*;7-G<W1R("*#08.+@U>#1H.*@T$B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*
M;7-G<W1R("*5RI:\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM
M<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R("*(RI)UD;6"IH%&(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T<B`BD5.5
ME"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C`W('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A
M=&5D(%5S97)S(@IM<V=S='(@(I%3E$:/V(.&@5N#52(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'
M<F]U<',B"FUS9W-T<B`BD5."Q(+,@T^#BX%;@W8B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.CDQ(&9R86UE=V]R:R]097)M<R]097)M<R]D
M871A=')E92YP:'`Z-S4*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R
M("*14X+$@LR#08-.@UJ#6(R@(@H*(R!M<V=S='(@(I%3@L2"S(N6B<*0W9+H
M(@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8X"FUS9VED(")!;&QO=R!M=6QT
M:7!L92!A9&1R97-S97,B"FUS9W-T<B`BE:&0E(+,@T&#:(.,@UB"\(N6B<(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,X"FUS9VED(")!;&QO=R!S
M971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R("*4U(V&E72"
MJX.*@UB#9X+PD-V2Z(+%@JN"Z8+F@J2"R8*U@MR"MX*I@4@B"@HC.B!F<F%M
M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HU,#0*;7-G:60@(D%L
M<F5A9'D@97AI<W1S(@IM<V=S='(@(HKY@LF1MHW=@K6"W(*W(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$R-@IM<V=I9"`B06QT97)N871E($E-4U`@
M3&]G:6XB"FUS9W-T<B`BD>.1UH+,($E-4U`@@XV#3X-#@Y,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3$Q"FUS9VED(")!;'1E<FYA=&4@24U34"!0
M87-S=V]R9"(*;7-G<W1R("*1XY'6@LP@24U34""#<(-8@X^!6X-H(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P,PIM<V=I9"`B06QT97)N871E($E-
M4U`@57-E<FYA;64B"FUS9W-T<B`BD>.1UH+,($E-4U`@@X:!6X-5EKPB"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N
M871E(&5M86EL(&%D9')E<W,B"FUS9W-T<B`BD>.1UH+,@X&!6X.+@T&#:(.,
M@U@B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N
M871E('1E;7!L871E<R(*;7-G<W1R("*1XY'6@LR#98.3@W:#C(%;@V<B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R("*1XY'6
M@V6#3(-8@V>!1B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A
M(@IM<V=S='(@(H-!@X&#BH-*E\R#5(."@T$B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N
M(@IM<V=S='(@(I5SD+."R))L@JJ.=Y+H@K."ZH+$@J*"W(*W(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-0IM<V=I9"`B06X@=6YK;F]W
M;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`BEUR*^H*U@LB"HH-'@XF!
M6X*JE*V0MH*U@MR"M8*](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*
M;7-G<W1R("*#08.3@VB#B2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*
M;7-G<W1R("*#08.3@U.#B8NDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N
M9W5I;&QA(@IM<V=S='(@(H-!@Y.#3X-"@XDB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS
M9W-T<B`BD[V6O(-V@XV#3(-6@5LB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(I.:@J8B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(I/LB\F!:9'EEZ2!
M:B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS
M9W-T<B`B@T&#DX-E@T*#3X-!@46#;X%;@W6!6X-?(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S8*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O861M:6XO<V5T
M=7`O:6YD97@N:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R("*#
M08-V@XJ#4(%;@U:#AX.3(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R
M"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@(H-!@W:#BH-0@5N#
M5H.'@Y.(ZI>7(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`IM<V=I
M9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(H-!@W:#BH-0@5N#
M5H.'@Y..9Y=PB<(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q
M.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(HFZB,J"
MS(NDETR"R9-+EW`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R("*/LY1&(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0P"FUS9VED(")!<'!R
M;WAI;6%T92!3:7IE(@IM<V=S='(@(H*H@JB"YH*[@LR#5(-#@UDB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B
M07!R:6PB"FUS9W-T<B`B@E.,CB(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3<X"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU.2!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*;7-G:60@(D%R8VAI=F4@
M1FEL92!3:7IE(@IM<V=S='(@(H-!@5N#2H-#@W6#=(-`@T.#BX-4@T.#62(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<W"FUS9VED(")!<F-H:79E
M($YA;64B"FUS9W-T<B`B@T&!6X-*@T.#=9:\(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N
M=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R("(E<R""S(-4@T.#DX-!@V*#
M=I=VBX&"\)9[DY:"R8WMCYR"M8+$@J*"HH+%@K>"J8%((@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@
M86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R("*6>Y.6@LD@7"(E<UPB((+&
M@U2#=8-/@XN!6X-VD5."Q(+PC>V/G(*U@L2"HH*B@L6"MX*I/R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R("*#08.+@UN#DX-@@Y.+
MI)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(H-!
M@XN#@8-J@T&+I)AAC9$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM
M<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B@T&#BX-O(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N
M($ES;&%N9"(*;7-G<W1R("*#08-:@Y.#5H.'@Y.3AR(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I
M82]086-I9FEC(%)E9VEO;B(*;7-G<W1R("*#08-7@T&!7I&^E;V7;9)NB.8B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(Y"FUS9VED(")!<VL@9F]R
M(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<S\B"FUS9W-T<B`BE=N.YXWLB\:"S([`C7.13X+)BFV41H+PBX&"WX+I
M@N:"I(+)@K6"W(*W@JF!2"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,P.3(*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T
M92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`BD;:-W8*U@LB"HH-/
M@XN!6X-V@O"-[8^<@K6"YH*D@L:"M8+<@K6"O8%"(@H*(SH@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N
M;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`BD;:-W8*U@LB"HH-!
M@TZ#6H-8C*""\(WMCYR"M8+F@J2"QH*U@MR"M8*]@4(B"@HC.B!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N
M+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(I&VC=V"M8+(@J*#08-.
M@UJ#6(R@@O"5TH]7@K6"YH*D@L:"M8+<@K6"O8%"(@H*(SH@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N
M;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(I&VC=V"M8+(@J*+I)=,@O"5
MTH]7@K6"YH*D@L:"M8+<@K6"O8%"(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#,*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`BD:Z0JR(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED
M(")!=6=U<W0B"FUS9W-T<B`B@E>,CB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U
M<W1R86QI82(*;7-G<W1R("*#28%;@UB#9X.)@XJ#02(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*
M;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B@TF!6X-8@V>#BH-!BZ2888V1(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B
M075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B075T:%]C>7)S<6PZ()5+EW:"R$E-05"*9Y*CBT"47(*J
MC*F"PH*I@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO
M="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R(")!=71H7V-Y
M<G5S.B"#;X-B@TZ#1X.3@VB"S95+EW:"R)1<E\V"\)=,@K6"Q(*B@MR"N8+Q
M@4(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G
M:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B075T:%]C>7)U<SH@EW:+@8*W@NEI;6%PBF>2HX*J
MC*F"PH*I@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O9G1P
M+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L
M92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"B)!=71H7V9T<#H@1E10BF>2
MHXM`E%R"JH+=@L*"J8+H@MR"N8+Q+B!02%""\"`M+65N86)L92UF='`@@TF#
M=H-6@X>#DX+P@L*"KX+$(@HB@U*#DX-P@T.#BX*U@LB"J(*U@L2"K8*^@K."
MHH%"(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HV-`IM<V=I
M9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D%U=&A?:6UA<#H@24U!4(IGDJ.+0)1<@JJ,J8+"@JF"
MZ(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU
M,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:W)B-3H@:W)B-8IGDJ.+0)1<@JJ,
MJ8+"@JF"Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO
M="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B075T
M:%]L9&%P.B!!8W1I=F4@1&ER96-T;W)Y((+%@LR#AH%;@U62QXG!@LV#5(-\
M@5N#9X*S@NJ"Q(*B@MR"N8+Q(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@
M:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R
M(")!=71H7VQD87`Z($%C=&EV92!$:7)E8W1O<GD@@L6"S(.&@5N#58WMCYR"
MS8-4@WR!6X-G@K."ZH+$@J*"W(*Y@O$B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$
M05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P.B!,
M1$%0BF>2HXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(D%U=&A?;&1A<#H@@X:!6X-5
M("5S((+PDL>)P8+%@JN"W(*Y@O&!0H-4@5N#;X+,B9Z3FCH@(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS
M9W-T<B`B075T:%]L9&%P.B"#AH%;@U4@)7,@@O"-[8^<@L6"JX+<@KF"\2(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF
M;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R
M("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@@X:!6X-5("5S((+PC5B05H+%@JN"
MW(*Y@O$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0P-0IM
M<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R
M=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R(")!=71H7VQD87`Z
M($%C=&EV92!$:7)E8W1O<GD@@L6"S(.&@5N#58U8D%:"S8-4@WR!6X-G@K."
MZH+$@J*"W(*Y@O$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP
M.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]M8V%L.B!-0T%0BF>2HXM`E%R"
MJHRI@L*"J8+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M
M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T
M:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7W-M8F%U=&@Z
M('-M8F%U=&B*9Y*CBT"47(*JC*F"PH*I@NB"W(*Y@O&!0B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O061M:6XN<&AP.C$P-@IM<V=I9"`B075T:&5N=&EC
M871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("))34%0@U2!
M6X-O@L6"S)1&C]B"R8ZXE'."M8+<@K6"O8%"(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H
M96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`BE$:/V(+)CKB4<X*U@MR"M8*]
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@
M9F%I;&5D+B`E<R(*;7-G<W1R("*41H_8@LF.N)1S@K6"W(*U@KV!0B5S(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B
M075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS
M9W-T<B`B4D%$2553@U2!6X-O@LF"YH+HE$:/V(*JBY&4VX*S@NJ"W(*U@KV!
M0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#@R"FUS9VED(")!
M=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B
M1E10@U2!6X-O@LR41H_8@LF.N)1S@K6"W(*U@KV!0B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O
M('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B4TU"@U2!6X-O@LR4
M1H_8@LF.N)1S@K6"W(*U@KV!0B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(HYG
MEW")PI1<@LB#=(-"@5N#BX-H@48B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R
M8F%I:F%N(@IM<V=S='(@(H-!@UN#BX-O@T.#5X.#@Y.+I)AAC9$B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(I1W
MC&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(I1WC&F01B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A
M9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B2V5R;V)E<F]S((-P@UB#
MCX%;@VB"JI:SC/B"Q8*W@4(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR
M8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S
M='(@(DME<F]B97)O<R"#AH%;@U66O(*JEK.,^(+%@K>!0B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B@V^#;H-](@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R("*#;X%;@XR!6X.3(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM
M,3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B
M"FUS9W-T<B`B@V^#DX-/@XF#9H-6@X60;):OBZ2888V1(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B@V^#BX-O@VB#6"(*"B,Z('5T
M:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"
M87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R("**[I9[@T^#B8-T@T*#3H-8@LR#9H-"@XR#3H-G@XJ!6R!<(B5S7"(@
M@JJ"H(+H@MR"N8+Q@4(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@
M(HKNCX"0_"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B
M@WB#B8.+@5N#5HNDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB
M"FUS9W-T<B`B@WB#BX--@5LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QI>F4B
M"FUS9W-T<B`B@WB#BH%;@UDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"96YI;B(*
M;7-G<W1R("*#>(-I@Y.+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M
M=61A(@IM<V=S='(@(H-O@WZ#A8%;@U^!:8^4DX>!:B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*
M;7-G:60@(D)H=71A;B(*;7-G<W1R("*#=8%;@UZ#DXFDC9$B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")"
M:7)T:&1A>2(*;7-G<W1R("*289"VD_HB"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S8T"B,L('!H<"UF;W)M870*;7-G:60@
M(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R("*#=8.-@V*#3B!<(B5S7"(@@LR#08-V@XJ#4(%;@U:#AX.3
M(%PB)7-<(B""JH*@@NB"W(*Y@O&!0B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHY,`IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B
M@W6#C8-B@TZ0W9+H(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC
M.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(H-U@XV#8H-.@UZ#0X-V
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M"FUS9VED(")";VQD(@IM<V=S='(@(I&^CIHB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED
M(")";VQI=FEA(@IM<V=S='(@(H-[@XJ#<H-!BZ2888V1(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(P-PIM<V=I9"`B0F]O:VUA<FMS(@IM<V=S
M='(@(H-U@V*#3H-]@5N#3B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*;7-G:60@(D)O<F1E<B(*;7-G<W1R
M("*)CR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(HF/@LR1
MOH*S@48B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(Q"FUS9VED(")";W)D97)S(@IM<V=S='(@(HF/(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R
M("*#>X-8@VJ#08%%@W>#BX-C@T:#4X-R@VDB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B@WN#8X./@VF+I)AAC9$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED
M(")";W5V970@27-L86YD(@IM<V=S='(@(H-U@5N#>).'(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,@IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(H-U@XF#5X.+(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G
M<W1R("*)<)?,@T.#DX-HCY23AR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE
M:2!$87)U<W-A;&%M(@IM<V=S='(@(H-U@XN#;(-#@46#7X.+@U2#B8%;@X`B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R("*#=8.+@TN#
MBH-!(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R("*)TX_PCY&"JR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R("*#=8.+
M@TR#:8-T@T"#7"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T
M<B`B@W6#BX.3@U>+I)AAC9$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#0V"FUS9VED(")#35,B"FUS9W-T<B`B0TU3(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S
M='(@(D-20R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3DX"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R(")#
M4DP@E'J5>H-\@T.#DX-G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T
M:65S+BXN(@IM<V=S='(@(E]%@UJ#BY&ND*LN+BXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,34Q"FUS9VED(")#86-H92!I;FET('=A<R!N
M;W0@8V]M<&QE=&5D+B(*;7-G<W1R("*#3(.#@V*#5H.%@LR/B8KZB;N"JHJN
ME[F"M8+<@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,38@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0X-0HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`T,"!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,34W"FUS9VED(")#86QE;F1A<B(*;7-G<W1R("*7
M7)+HE5PB"@HC(&US9W-T<B`B@TJ#C(.3@U^!6R(*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B0V%L;2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B@TJ#DX-[@U>#
M02(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(H-*@X&#
MBX%;@Y.+I)AAC9$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR
M,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY
M+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B@W"#6(./
M@5N#:(+-CJF3KH+%@LV#BH-:@V*#9X+%@JN"W(*Y@O&!0HK'EYV.TH+)F$&7
MC8*U@L2)NH*S@J*!0B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C,U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I
M;&4@7"(E<UPB(@IM<V=S='(@(H-T@T"#0X.+(%PB)7-<(B""R8^1@J^"W(*Y
M@O&!0B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@
M861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R
M("**3Y64@LR#6H-B@U:#AX.3@VZ#DX-H@XF!6X+-BL>7G8+%@JN"W(*Y@O&!
M0B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S-2!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S
M='(@(DE-05`@@U2!6X-O@LF0VI&Q@L6"JX+<@KF"\8+%@K6"O3H@)7,B"@HC
M.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B@W2#
M0(-#@XL@7"(E<UPB((*JBDJ"KX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I
M9"`B0V%N861A(@IM<V=S='(@(H-*@VF#7R(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O9&5L971E+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI
M;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM
M<V=I9"`B0V%N8V5L(@IM<V=S='(@(H-,@X.#DX-:@XLB"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L
M96T@4F5P;W)T(@IM<V=S='(@(H_ABE&5\8V0@O"#3(.#@Y.#6H.+@K>"Z2(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S(S"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(H-T@T"#0X.+(%PB)7-<(B""\(WMCYR"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B
M0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("*-
M[(O&@V:#0H.,@TZ#9X.*@JJ,J95T@JF"Z(+<@KF"\8%"(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N
M;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*
M;7-G<W1R("(G=&%R9V5T1FEL92<@@W"#B8.!@5N#7H+(@K6"Q8+-D;&-<X+%
M@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y
M(%PB)7-<(BXB"FUS9W-T<B`B@V:#0H.,@TZ#9X.*@5L@7"(E<UPB((+PC>V/
MG(+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E
M92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP
M.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E+"`E9"!C
M:&EL9')E;B!E>&ES="XB"FUS9W-T<B`BC>V/G(+%@JN"W(*Y@O&!0HYQD;>"
MJB`E9""1MHW=@K6"W(*W@4(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T
M851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N
M=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO
M="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"B*5P(+7D=:"
MIH+,D<Z/VX+,D)2"JI7;D;:"LX+J@L2"HH+ID)2"QHV'@NV"R(*B@LR"Q97`
M@M>1UH*F@JJ"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T
M92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(HYWDNB"
MLX+J@KV4U(V&@LF#@8-B@UJ!6X-7@O"4>I&7@L6"JX+<@KF"\8+%@K6"O8%"
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R("*#2H%;
M@WR#>(.+@V:+I)AAC9$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(T"FUS9VED(")#87!T:6]N(@IM<V=S='(@
M(I5<D>@B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P
M+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T<B`B@TR#@X.*@T$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,*;7-G:60@(D-A=&5G;W)I97,@
M86YD($QA8F5L<R(*;7-G<W1R("*5JI?>@L:#B8-X@XLB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B@U"#0X-]@Y./E).'
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y
M-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R("*,9Y'1DV288B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*
M;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R("*#6H.+D:Z0JR(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS
M9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(H-:@XN6A)&0@48B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q
M"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B@UJ#BY&ND*LB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM
M<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("*#6H.+EUV4DH%&(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W,0IM<V=I9"`B0V5L;'!H;VYE
M(@IM<V=S='(@(HQGD=&39)AB(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#$*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R("*2AHF;(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HU-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM
M<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(I*&B9N#
M08-T@XJ#2HNDF&&-D2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS
M9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I
M9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R("*/V):^CY&"S(_:C=<B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,@IM<V=I
M9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`BC]B6OH^1@LR/BI=,CM(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I
M9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`BC]B6OH^1@WR#BH-6
M@5LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS9W-T<B`B@V"#@X-H
MBZ2888V1(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B0VAA;F=E(@IM
M<V=S='(@(I7/C5@B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,S$*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(H-P@UB#
MCX%;@VB"\)7/C5@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-CD*;7-G
M:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L
M92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA
M:6QS+B(*;7-G<W1R("*39(YQ@X&#0X.+@LF.9Y=P@K>"Z9:\D4^"QH-!@VB#
MC(-8@O"5SXU8@K6"W(*W@4(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,C0*;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@
M;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN
M("`B"B)#;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB
MC+N-W8+,D-V2Z(+%@LV#<(-8@X^!6X-H@LR5SXU8@O"#5(-\@5N#9X*U@L2"
MHH+<@KF"\8%"BL>7G8[2@LF809>-@K6"Q(FZ@K,B"B*"HH%"(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM
M<V=I9"`B0VAA<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,
M:6YK+BXN(@IM<V=S='(@(E]+@XJ#DX-.@O"#8(-&@V*#3BXN+B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C<*;7-G:60@(D-H:6QE(@IM<V=S='(@(H-@@XJ+I)AAC9$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8W"FUS9VED(")#:&EN82(*;7-G<W1R("*2AHG8D&R6KXNDF&&-D2(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#:&EN97-E(%-I
M;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#0*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C<*;7-G
M:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB"FUS9W-T<B`B@T&#=H.*@U"!6X-6
M@X>#DY%)D?"!1B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HR-S`*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(H-P@UB#
MCX%;@VB"\)%)D?`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R("*#AH%;
M@U66O(+PD4F1\"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#(*;7-G
M:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`BD_J5
M=)5<CJ:,8(ZN@48B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL
M92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R("*#3H.*@UB#
M?8-8DX<B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z.3$T"B,L('!H<"UF;W)M870*;7-G:60@(D-L
M87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R("*#3H.)
M@UB2Z(M@("5S((*JC*F5=(*I@NB"W(*Y@O&!0B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(DU3
M+4]F9FEC98+,@UZ#3X+PCN:"Z(^<@JTB"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3(Y"FUS9VED(")#;&5A<B!1=65R>2(*;7-G<W1R("*,GXWUC\&+CB(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF
M;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R("*#AH%;
M@U6"S)'>BXZ!1B5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N
M:6YC.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(H.&@5N#58_!BXXB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B
M0VQE87(@=7-E<B!D871A(@IM<V=S='(@(H.&@5N#58-F@5N#7H_!BXXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I
M9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@
M0V]N=&EN=64B"FUS9W-T<B`B@TZ#BH-B@TZ"MX+I@L:.GX+6(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS
M9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(H-%@T*#DX-H@T6"
M\)7"@K:"Z2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Q"FUS9VED(")#
M;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PIM
M<V=I9"`B0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-O
M8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(H-2@U*#6(^4DX<B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S"FUS9VED(")#;VQL
M87!S92!3:61E8F%R(@IM<V=S='(@(H-4@T.#:(-O@5N"\(_T@MXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X
M"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8W"FUS9VED(")#;VQO;6)I82(*;7-G<W1R("*#4H.-@Y.#<H-!BZ2888V1
M(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N
M<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(I!&(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,S-0HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,V"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,#,@<V5R=FEC97,O
M:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@4&EC:V5R
M(@IM<V=S='(@(I!&D4F1\"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,C4*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`BD$:129'P
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(I?Q@48B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.30S"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S
M='(@(I?Q@UZ#0X-G@XLB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C8V"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B@U*#?H-B@TZ#6"(*"B,Z(&%D
M;6EN+V-M9'-H96QL+G!H<#HR-@IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R("*#
M4H-]@Y.#:"(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M
M;6%N9"!3:&5L;"(*;7-G<W1R("*#4H-]@Y.#:(-6@T:#BR(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B0V]M;65N="(*
M;7-G<W1R("*#4H.!@Y.#9R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-38W"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R("*+I)+*
MEKPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R("*#4H."
M@XV808V'(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R("*)[X[0(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-@IM<V=I
M9"`B0V]N9&ET:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C4V"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E
M<F5N8V5S(@IM<V=S='(@(I#=DNB"S(VWE:HB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,30V"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG
M('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@
M(E!$08%!@UB#?8%;@V>#=(-(@Y.!04]U=&QO;VN"QH+,DZ^*^H+PD-V2Z(*U
M@MR"MX%"(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM<V=I9"`B
M0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`BD-V2Z(+-
MC]R6H8KZC,"0V(+J@L6"MX%"(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T
M<B`B)7,@@O"0W9+H@K>"Z2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B
M@W"#6(./@5N#:(+PBFV41B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM
M<V=S='(@(H-2@Y.#4XNDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-O;F=O
M+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B@U*#
MDX-3EJ^.Y8NDF&&-D2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$Y-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS,#@*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R
M("*0VI&QCKB4<X%"(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,3DW"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,P.`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R
M("*0VI&QCKB4<X%&(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-SDP"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI
M8R!K97ES97)V97(N(@IM<V=S='(@(HSVCT^,KH-4@5N#;X+6@LR0VI&Q@JJ+
MD93;@K."ZH+<@K6"O8%"(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F
M=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I
M(@IM<V=S='(@(HSVBDJ,KH-4@5N#;X+6@LR0VI&Q@JJ+D93;@K."ZH+<@K6"
MO8%"EYV74H%&)7,@*"5S*2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.#<V"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D
M+B(*;7-G<W1R(")&5%"#5(%;@V^"UH+,D-J1L8+)CKB4<X*U@MR"M8*]@4(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR-"!C;VYF:6<O:&]O
M:W,N<&AP+F1I<W0Z,3`V-PIM<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`BF$&7
MC9#F(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T
M;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`BF$&7C9#F@LV#08-H@XR#
M6)*@@LF2QXG!@K."ZH+<@K6"O8%"(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HV,`IM<V=I9"`B0V]N=&5N="!T>7!E(&]F(&-O
M;7!R97-S960@9FEL93H@(@IM<V=S='(@(HBSCVN#=(-`@T.#BX+,@U*#DX-E
M@Y.#8X->@T.#=H%&(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HU-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C8S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S
M='(@(EPB)7-<(B""S)/@EV4B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@
M(D-O;G1I;G5E(@IM<V=S='(@(I&Q@JTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#
M;V]K($ES;&%N9',B"FUS9W-T<B`B@TZ#8H-.CY23AR(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R("*#4H-S@5LB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C0W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B@U*#<X%;CKB4<X%&)7,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,V"FUS9VED
M(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R("*129'PE,V(S8+P@U*#<X%;(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@
M(D-O<W0@240B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@
M4FEC82(*;7-G<W1R("*#4H-8@UZ#BH-*BZ2888V1(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM
M<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R("*#4H%;@V>#5X-[@X^!6X.+
MBZ2888V1(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3<W
M"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@(@IM<V=S
M='(@(H.!@V*#6H%;@U>"S"!01U`@B,.-AHF[@JJ"Q8*K@MR"N8+Q@L6"M8*]
M@4(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4U"FUS
M9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@(@IM<V=S='(@(H.!
M@V*#6H%;@U>"S"!01U`@CY"6O(*J@L6"JX+<@KF"\8+%@K6"O8%"(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O
M=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("*#@8-B
M@UJ!6X-7@LP@4R]-24U%((C#C8:)NX*J@L6"JX+<@KF"\8+%@K6"O8%"(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@
M(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R("*#@8-B
M@UJ!6X-7@LP@4R]-24U%((^0EKR"JH+%@JN"W(*Y@O&"Q8*U@KV!0B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@
M)7,B"FUS9W-T<B`BF$&7C9#F@O"2QXG!@L6"JX+<@KF"\8+%@K6"O8%")7,B
M"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ,C$*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C0U-PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V
M97(N(@IM<V=S='(@(DQ$05`@@U2!6X-O@LF#;X-#@Y.#:(+%@JN"W(*Y@O&"
MQ8*U@KV!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`BCF.-@H*JBFV41H+%@JN"
MW(*Y@O&"Q8*U@KV!0B5S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T
M,0IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM
M<V=S='(@(DQ$05`@@U2!6X-O@LF0VI&Q@L6"JX+<@KF"\8+%@K6"O8%"(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@
M1E10.B`E<R(*;7-G<W1R(")&5%`@@L6#5(%;@V\@7"(E<UPB((+)D-J1L8+%
M@JN"W(*Y@O&"Q8*U@KTZ("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`BD9>039#F@XJ#6(-G@JJ-[)"L@L6"JX+<@KF"\8+%@K6"O8%")7,B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3(X"FUS9VED(")#
M;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@(@IM<V=S='(@(E!'4""#9H%;
M@UZ"S)6<C8:)NX*J@L6"JX+<@KF"\8+%@K6"O3HB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,PIM<V=I9"`B0V]U;&0@;F]T(&1E
M8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(E,O34E-12"#9H%;@UZ"S)6<
MC8:)NX*J@L6"JX+<@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R("*8
M09>-D.:"JHWMCYR"Q8*K@MR"N8+Q@L6"M8*]@4(E<R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S(@IM<V=S='(@(I&7D$V0YH.*@UB#9X*JC>V/G(+%@JN"W(*Y@O&"
MQ8*U@KV!0B5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R
M861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(I#=DNB-6)!6EW"#6(-.@XJ#
M=H-G(%PB)7-<(B""\(WMCYR"Q8*K@MR"N8+Q@L6"M8*]@4(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X,2!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O=6QD(&YO="!D971E<FUI
M;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R("*.
M\Y!-CM*"S)-DCG&#@8%;@XN#08-H@XR#6(*JBFV2Z(+%@JN"W(*Y@O&"Q8*U
M@KV!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D
M<F5S<R!B;V]K+B(*;7-G<W1R("*#08-H@XR#6)*@@JJ*KI%3@LF"S8[FD[Z"
MQ8*K@MR"N8+Q@L6"M8*]@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H
M(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("*1EY!-D.:#
MBH-8@V>"JHJND5."R8+-CN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS
M9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES
M=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R("*1EY!-D.:#BH-8@V>"JHJND5."
MR8+-CN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R("*#6(-G@XF#98-7
M@5L@7"(E<UPB((+P@XV!6X-H@L6"JX+<@KF"\8+%@K6"O8%"(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS
M9W-T<B`B36MD:7(@7"(E<UPB((+)CKB4<X*U@MR"M8*]@4(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO
M="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S
M='(@(HSVBDJ,KH+PC*Z#5(%;@V^"J8+GCN:3OH+%@JN"W(*Y@O&"Q8*U@KV!
M0B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R
M(")<(B5S7"(@@O"/D8*KC9Z"W9=P@LF#28%;@W:#DX+%@JN"W(*Y@O&"Q8*U
M@KV!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E
M;B`E<RXB"FUS9W-T<B`B)7,@@O"#28%;@W:#DX+%@JN"W(*Y@O&"Q8*U@KV!
M0B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z
M-#(P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT
M96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(I7;CN>-[(O&@X*#5X.%
M@5N#BR`E<R""\(I*@J^"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D
M:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("*#9H-"@XR#3H-G@XJ!6R!<(B5S
M7"(@@JJ*2H*O@MR"N8+Q@L6"M8*]@4(B"@HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(S
M-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV
M.3D*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM
M<V=S='(@(DQ$05`@@U2!6X-O@LF0VI&Q@L6"JX+<@KF"\8%"(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR-#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(B5S((*JD\>"W8]O
M@KF"W(*Y@O&!0B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U
M"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T
M:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A
M:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB
M"FUS9W-T<B`B(@HBEW:+@8*S@NJ"O8.&@5N#58+,@W"#6(./@5N#:(+P@XJ#
M6H-B@V>"Q8*K@MR"N8+Q@L6"M8*]@4*"HH*M@L*"J8*@@NF"HH+-D5."Q"(*
M(H+,C^Z5\8+-BM2(X8+!@L2"HH+<@K>!0HW$DWB.CH*U@L2"W8+I@JF*QY>=
MCM*"R9A!EXV"M8+$B;J"LX*B@4(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS,#<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S,X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,W-0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS.#$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S@W"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM
M<V=S='(@(D%#3"""\([FD[Z"Q8*K@MR"N8+Q@L6"M8*](@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O
M:RX@)7,B"FUS9W-T<B`B@T&#:(.,@UB2H(+PCN:3OH+%@JN"W(*Y@O&"Q8*U
M@KV!0B5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E
M=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("*1EY!-D.:#
MBH-8@V>"\([FD[Z"Q8*K@MR"N8+Q@L6"M8*]@4(E<R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES=',N("5S(@IM<V=S='(@(I&7D$V0YH.*@UB#9X+PCN:3OH+%@JN"W(*Y
M@O&"Q8*U@KV!0B5S(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,3DW"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C(Q-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HR,C$*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C
M87!A8FEL:71I97,B"FUS9W-T<B`B@U2!6X-O@LR+0)1<B.J7EX+PCN:3OH+%
M@JN"W(*Y@O&"Q8*U@KTB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T
M"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(I#=DNB"\(RS@LF6WX*Y@MR"N8+Q@L6"M8*]@4(B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M
M9&ER(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB((-F@T*#C(-.@V>#BH%;@JJ-
M[8^<@L6"JX+<@KF"\8%"(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B)7,@D-V2Z(+PE=N1MH+%@JN"W(*Y@O&"
MQ8*U@KV!0B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B
M86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R("*0W9+H@LR#;X-B@TZ#08-B
M@W:"\)7;D;:"Q8*K@MR"N8+Q@L6"M8*]@4(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A
M=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R("*0W9+H@LR#
M;X-B@TZ#08-B@W:"\)7;D;:"Q8*K@MR"N8+Q@L6"M8*]@48E<R(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S
M7"(N(@IM<V=S='(@(I#=DNB-6)!6EW"#6(-.@XJ#=H-G@O`@7"(E<UPB((+)
ME=N1MH+%@JN"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(I#=
MDNB"S(-O@V*#3H-!@V*#=H-T@T"#0X.+("5S((+PE=N1MH+%@JN"W(*Y@O&"
MQ8*U@KV!0B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R
M871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@
M(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P
M>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@HB
MD-V2Z(-T@T"#0X.+("5S((+)E=N1MH+%@JN"W(*Y@O&"Q8*U@KV!0B5S((+)
MEM^"P8+$E=N1MH-)@W:#5H.'@Y."\([`C7."MX+I(@HB@JF!08[H@L6"L8+,
MB>:6RH+,@U*!6X-H@O`@)7,@@LF#4H-S@5N"M8+$B;J"LX*B@4(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@
M;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DQ$05`@@U2!
M6X-O@JJ,GXWU@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB
M+B(*;7-G<W1R(")<(B5S7"(@@O"-[8^<*'5N;&EN:RF"Q8*K@MR"N8+Q@L6"
MM8*]@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D
M871E(&-O;G1A8W0N("5S(@IM<V=S='(@(IA!EXV0YH+PC5B05H+%@JN"W(*Y
M@O&"Q8*U@KV!0B5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`BD9>0
M39#F@XJ#6(-G@O"-6)!6@L6"JX+<@KF"\8+%@K6"O8%")7,B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS
M9W-T<B`B7"(E<UPB((+,D-V2Z(*JCY&"JXV>@M^"W(*Y@O&!1B5S(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W,`IM<V=I9"`B0V]U;&1N)W0@9FEN
M9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@
M:7,@;W!E;BXB"FUS9W-T<B`B36]Z:6QL82""S(-4@T.#:(-O@5N"JHRIE72"
MJ8+H@MR"N8+Q@4*#5(-#@VB#;X%;@O"*2H*B@L2)NH*S@J*!0B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H
M92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q-@IM
M<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")#;W5N=')Y(@IM<V=S
M='(@(HV1(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W-0IM<V=I
M9"`B0V]U<G-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T
M92(*;7-G<W1R("*-[)"L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C
M="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`BD%:+
M2XWLD*PB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H
M<#HU,@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(H-4@W6#=(-(
M@XN#7X+PC>R0K"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(HWLD*R.
MTH+,@T&#3H-:@UB,H"(*"B,@;7-G<W1R("*-[)"LCM*"S)7;C.R0W9+H(@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C`Y"FUS9VED(")#<F5D:70@
M8V%R9"!N=6UB97(B"FUS9W-T<B`B@TZ#C(-7@V*#9X-*@5N#:)34C88B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G<W1R("*#3H.-@T&#8(-!
MBZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R("*#3(.%
M@5N#;XNDF&&-D2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@IM<V=I9"`B
M0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N
M<RYP:'`Z-3`*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`BC+N-
MW8+,@UJ#8H-6@X>#DR(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]"
M;&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@
M(HR[C=V"S(Z>BM0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM
M<V=S='(@(HR[C=V"S"!54DP@@LTB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M,S4*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`BC+N-W8+,@X:!6X-5
M@5LB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED(")#=7)R96YT
M(%=E871H97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(V-`IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S
M=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R
M("(E<R""UH+,@XV#3X-)@Y..GH+)CL"-<X*W@NF#7H-8@TZ"\)#=DNB"M8+<
M@K>!0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(I#8@NB.YH+H(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM
M<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R("*129'PE,V(S8+PD-B"Z([F
M@N@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B@TR#=H.-
M@UB+I)AAC9$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B
M0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#8*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")#
M>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`B@V"#1H-2BZ28
M88V1(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0U,B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T
M<B`BD_HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C8Y"FUS9VED
M("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P
M86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3D*
M;7-G:60@(D1A:6QY(@IM<V=S='(@(I:(D_HB"@HC.B!A9&UI;B]D871A=')E
M92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B1&%T
M851R964@B7N7ER(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-C<*
M;7-G:60@(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R("*#9H%;@UZ#>(%;@UB.
M48_&(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDU"FUS9VED(")$871E
M(@IM<V=S='(@(I/ZE70B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R("*#9H%;
M@UZ.\Y!-(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<X-@IM<V=I
M9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`BD_J5=)%)D?`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,3$*;7-G:60@(D1A>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*
M;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(E],E_&"S(WMCYPB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3$*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I
M9"`B1&5C96UB97(B"FUS9W-T<B`B,3*,CB(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E
M8VEM86P@;G5M8F5R<R(*;7-G<W1R("*/7)!ID)0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S
M92!);F1E;G0B"FUS9W-T<B`BDFF)NH*P@O"0\X*M(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*;7-G
M:60@(D1E9F%U;'0B"FUS9W-T<B`B@V:#=(-(@XN#9R(*"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$969A
M=6QT($-O;&]R(@IM<V=S='(@(H-F@W2#2(.+@V>01B(*"B,Z(&9R86UE=V]R
M:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z.38*;7-G:60@(D1E9F%U;'0@261E
M;G1I='DB"FUS9W-T<B`B@V:#=(-(@XN#9R!)1"(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HV-PIM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R("*#
M9H-T@TB#BX-G('-H96QL(@H*(R!M<V=S='(@(H-F@W2#2(.+@V>+EHG"D-V2
MZ"(*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET
M:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z-#(R(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M-#,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHW,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.CDS('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3,Y('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3@R"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`BC>V/G"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS,@IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`B@UJ#BXWMCYPB"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R-PIM
M<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(H-/@XN!6X-V@O"-[8^<(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y"FUS9VED(")$96QE
M=&4@3&]G(@IM<V=S='(@(H.-@T^"S(WMCYPB"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,3`Q"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R("*#08-.
M@UJ#6(R@@O"-[8^<(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B
M@UJ#BXWMCYPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@
M(I?Q@LR-[8^<(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@
M(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B
MD>.1UH-E@Y.#=H.,@5N#9X+,C>V/G"(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S0S,30N<&AP.C4T"FUS9VED(")$96QE=&4@;65S<V%G97,B
M"FUS9W-T<B`B@X&#8H-:@5N#5X+PC>V/G"(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T
M92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(EPB)7-<(B""S(-!
M@TZ#6H-8C*""\(WMCYPB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO
M;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T
M<B`B7"(E<UPB((+,@T&#3H-:@UB,H(+&@KN"S(-4@W6#08-.@UJ#6(R@@O"1
M4X+$C>V/G(*U@MR"MX*I@4@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM
M<V=S='(@(HUS@LR-[8^<(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E;&5T96ED
M96YT:71Y+FEN8SHQ-0IM<V=I9"`B1&5L971E('-E;&5C=&5D(&ED96YT:71Y
M(@IM<V=S='(@(I%)D?""M8*]242"\(WMCYPB"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,PIM<V=I9"`B1&5L971E('-U8B!F
M;VQD97)S(@IM<V=S='(@(H-4@W6#=(-(@XN#7X+PC>V/G"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM
M<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R("*,NXW=
MB,J2=8+,E_&"\(WMCYPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R
M<F5N="!R;W<B"FUS9W-T<B`BC+N-W8C*DG6"S(US@O"-[8^<(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@
M(I#=DNB-6)!6EW"#6(-.@XJ#=H-G(%PB)7-<(B""\(WMCYR"M8+<@K6"O8%"
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(U,PIM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R
M("*4>I&7CIZ*U"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T
M<B`B@V:#DX-]@5N#3B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R("*/
MX8I1D^"798+,D."6OB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDS
M-2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R("*0X):^(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HR,#8*;7-G:60@(D1E=&%I;',@*&%L
M<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`BC]J-UX%I2&]R9&6"
MS(.-@T^#=(-`@T.#BX+@CE&/QH%J@48B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C(Q,`IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`BC]J-UX+-BL>7G8[2
M@LR"O8+?@LF+3)A>@K."ZH+<@K6"O8%"(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(R,0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`BBDJ4
MK2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(T"FUS9VED(")$97<@4&]I
M;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#$*;7-G
M:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-@IM<V=I9"`B1&5W('!O
M:6YT.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG
M:'0B"FUS9W-T<B`BC;:"J8+GB46"UB(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H
M="!T;R!L969T(@IM<V=S='(@(HE%@JF"YXVV@M8B"@HC.B!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-S`*;7-G:60@(D1I<W!L87D@,C0M
M:&]U<B!T:6UE<S\B"FUS9W-T<B`B,C2.GHK4E5R.IB(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,#`*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G
M<W1R("*57(ZF@TF#=H-6@X>#DR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HX.0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.CDR"FUS9VED(")$
M:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(W.38*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HQ.3$*
M;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R("*#5X-U@V"+I)AA
MC9$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,@IM<V=I
M9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R("*-[8^<@K6"R(*B(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T
M;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R(")M86EN=&5N86YC
M92YP:'`@@LF2O)#:@T&#3H-:@UB"M8+(@J*"Q8*M@KZ"LX*B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN
M('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS
M9W-T<B`BC<6/B8+,E_&"JH-T@T*!6X.+@VB6O(+PBMR"\8+%@J*"W(*W@JD_
M((*[@J2"R(+G@V"#1H-B@TZ"M8+$@JV"OH*S@J*!1B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*
M;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(H-H@WZ#:H-*(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(H-H@WZ#:H-*
MBZ2888V1(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I
M9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R("*#
M08-*@T6#DX-G@JJ52Y=V@LB"YX-4@T.#DX-!@V*#=H%"(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#4Q"FUS9VED(")$;W=N;&]A
M9"(*;7-G<W1R("*#7X-%@Y.#C8%;@V@B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HX-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W
M;FQO860@)7,B"FUS9W-T<B`B)7,@@LR#7X-%@Y.#C8%;@V@B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T
M960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R("*0MI"L
M@K."ZH*]D-V2Z(+P(%!(4""#6(-.@XJ#=H-G@O""QH*U@L2#7X-%@Y.#C8%;
M@VB"MX+I@4(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`T"FUS
M9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B12U-86EL
M(@IM<V=S='(@(I-DCG&#@8%;@XLB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3(&=A
M=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES
M('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@
M(D524B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM
M<V=S='(@(H-'@TZ#08-H@XN+I)AAC9$B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q
M-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z-S(*;7-G:60@(D5D:70B"FUS9W-T<B`BE=*/5R(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R]522YP:'`Z-3`*;7-G:60@(D5D:70@0FQO8VLB"FUS
M9W-T<B`B@W6#C8-B@TZ"S)72CU<B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y
M."!A9&UI;B]G<F]U<',N<&AP.C(R-@IM<V=I9"`B161I="!'<F]U<"(*;7-G
M<W1R("*#3X.+@5N#=H+,E=*/5R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*
M;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R("*#08-.@UJ#6(R@@LR5
MTH]7(@H*(R!M<V=S='(@(HN6B<*0W9+H@LR5TH]7(@HC.B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(H-!@TZ#6H-8C*""S)72CU<B"@HC(&US9W-T<B`BBY:)PI#=DNB"
MS)72CU<B"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T
M<B`B)7,@@LR#08-.@UJ#6(R@@LR5TH]7(@H*(R!M<V=S='(@(B5S((+,BY:)
MPI#=DNB"S)72CU<B"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G
M:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(H-)@W:#5H.'@Y."S)72
MCU>!1B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S8W"B,L
M('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<
M(B(*;7-G<W1R(")<(B5S7"(@@LR#08-.@UJ#6(R@@LR5TH]7(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(E<R""S(-!@TZ#
M6H-8C*""S)72CU<B"@HC(&US9W-T<B`B)7,@@LR+EHG"D-V2Z(+,E=*/5R(*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B
M@T>#5X-V@V>!18-!@XF#=8NDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B
M16P@4V%L=F%D;W(B"FUS9W-T<B`B@T>#BX-4@XN#;X-H@XN+I)AAC9$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V-@IM<V=I
M9"`B16UA:6PB"FUS9W-T<B`BDV2.<8.!@5N#BR(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-38V('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHV.`IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R(")%@X&!6X.+
M@T&#:(.,@U@B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38P"FUS
M9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`B18.!
M@5N#BX-!@VB#C(-8@JJ(ZI)V@K6"R(*O@NJ"SH*B@J^"W(*Y@O&!0B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#8*;7-G:60@(D5M86EL('=I
M=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D6#@8%;@XN#08-H@XR#6(IME$8B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY
M,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.0IM<V=I
M9"`B16UO=&EC;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B16UP='D@;65S
M<V%G92XB"FUS9W-T<B`BB_.#@8-B@UJ!6X-7@L6"MX%"(@H*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P
M-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B
M16UP='D@<F5S=6QT+B(*;7-G<W1R("*)O8+@C*F"PH*I@NB"W(*Y@O&!0B(*
M"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@
M(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R("*+\X+,C)^-]8SJ(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T-PIM<V=I9"`B16YA8FQE(&EN<V5R
M=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B
M"FUS9W-T<B`B@TV#@X.)@XJ!6X*I@N>)YI&<@O"1?9/\@L6"JX+I@N:"I(+)
M@K6"W(*W@JF!2"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C(*;7-G
M:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@
M(HE%@TZ#BH-B@TZ"Q8.!@VJ#A8%;@O"57(ZF@K6"W(*W@JF!2"(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.#4@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C<Y,`IM<V=I9"`B16YD('EE87(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B
M16YL87)G92!%9&ET;W(B"FUS9W-T<B`B@T>#9H-"@UZ!6XGFELJ"\)'E@JN"
MK2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C0*;7-G:60@(B(*(D5N
M=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K
M960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG
M+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B
M"B*"H(+(@KV"S(-P@UB#CX%;@VB"\(.*@UJ#8H-G@K>"Z8Z>@LR7<)!3@LR"
MO8+?@LR.OY;B@O"3_)?-@4*7X8*F@LZ!08%U@WF#8H-G(@HB@LR6O)%/@LV!
M2(%V@48B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@
M:&5R92(*;7-G<W1R("*)YI&<@LQ54DR"\)/\E\TB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DR"FUS9VED(")%;G1E<B!T
M:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I
M9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`BD-23N8--@VJ#08NDF&&-
MD2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B@T>#BH-G
M@XJ#02(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="]6:65W+G!H<#HY-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#@*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-@IM<V=I9"`B17)R
M;W(B"FUS9W-T<B`B@T>#B8%;(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E
M;7!L871E+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E
M871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(H-U@XV#8H-.C>R0K(-'@XF!6SH@
M)7,N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S
M"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G
M.B`E<R(*;7-G<W1R("*3KXKZ@XV#3X+,C>V/G(-'@XF!6SH@)7,N(@H*(SH@
M9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R
M("*3X)=ECN:3OH-'@XF!6SH@)7,N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T
M:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R("*#<(-8@X^!6X-HC5B05H-'@XF!
M6SH@)7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N
M(@IM<V=S='(@(H.!@5N#BX-!@VB#C(-8@LR#1X.)@5N"Q8*W@4(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@@LR/D8*KC9Z"W8-'
M@XF!6X+%@K>!0B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T
M<B`B@T>#6(-G@VJ#08NDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO
M<&EA(@IM<V=S='(@(H-'@V"#28-S@T$B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R
M("*#B(%;@XV#8H-P(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,PIM
M<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R("(Q-96JEH@B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDS"FUS9VED(")%=F5R>2`R(&UI;G5T
M97,B"FUS9W-T<B`B,I6JEH@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(D5V97)Y(#,P
M('-E8V]N9',B"FUS9W-T<B`B,S"5JI:((@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDT"FUS9VED(")%
M=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B-96JEH@B"@HC.B!F<F%M97=O<FLO
M36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,
M;V=I;B(*;7-G<W1R("*#C8-/@T.#DY:((@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T-`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(C,P
ME:J6B"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Y,@IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@
M(C&5JI:((@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*;7-G
M:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R("*.=Y+HDFR"S)?A(@H*(SH@
M861M:6XO<&AP<VAE;&PN<&AP.C@R(&%D;6EN+V-M9'-H96QL+G!H<#HU,2!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS9VED(")%>&5C=71E(@IM<V=S='(@
M(H[`C7,B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C8Q-`IM<V=I9"`B17AP86YD(@IM<V=S='(@(I-7BDHB"@HC.B!T
M96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS9VED(")%>'!A;F0@
M4VED96)A<B(*;7-G<W1R("*#5(-#@VB#;X%;@O"35XI*(@H*(SH@9G)A;65W
M;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@
M)RDG(@IM<V=S='(@(B<I)R""\)-7BDHB"@HC.B!F<F%M97=O<FLO4U%,+U-1
M3"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@
M;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$
M871E(@IM<V=S='(@(I=,C/B*^HS`(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV-S<*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@(HYW
MD)0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R("*13XQID$8B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D
M(&]F('-E='5P(@IM<V=S='(@(I#=DNB"\"!&5%`@@L6#08-B@W:#C8%;@VB"
MMX+I(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z,C(P"FUS
M9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B
M@W:#C(-T@T"#C(.3@UB0W9+H@O".YI.^@L6"JX+<@KF"\8%"(@H*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<U(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O
M($Q$05`@<V5R=F5R+B(*;7-G<W1R("),1$%0((-4@5N#;X+)D-J1L8+%@JN"
MW(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H
M<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB
M"FUS9W-T<B`B4TU"((-4@5N#;X+)D-J1L8+%@JN"W(*Y@O&"Q8*U@KV!0B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$W"B,L('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R
M(")<(B5S7"(@@JF"YX+,@U*#<X%;@LF.N)1S@K6"W(*U@KV!0B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(R"B,L('!H<"UF;W)M870*;7-G
M:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB
M((+6@LR#4H-S@5N"R8ZXE'."M8+<@K6"O8%"(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N
M97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R("*05HM+@LP@4T%33""0VI&Q
M@LF.N)1S@K6"W(*U@KV!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-3`Q(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4U"B,L('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T
M<B`B7"(E<UPB((+6@LR(VI.N@LF.N)1S@K6"W(*U@KV!0B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8U"B,L('!H<"UF;W)M870*;7-G:60@
M(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`BCN:3OH+)CKB4<X*U
M@MR"M8*]@48E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$X"FUS9VED(")&86ER(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*
M;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R("*#
M=(-(@5N#3H.)@Y.#:(^4DX>!:8-]@XN#<H-I@UB/E).'@6HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<S"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S='(@(H-T@T:#C8%;CY23
MAR(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR,S@*;7-G:60@(D9A=&%L
M($5R<F]R.B(*;7-G<W1R("*2=I:]DTF#1X.)@5N!1B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*
M;7-G<W1R(")&05@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4Q
M"FUS9VED(")&87AE<R(*;7-G<W1R(")&05@B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS
M9W-T<B`B@E&,CB(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(W"FUS9VED
M(")&965L<R!,:6ME(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,C`*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM
M<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H
M;W=E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3DT,0IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,S,C(*;7-G:60@(D9I9VQE="!#05!40TA!
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,C8*
M;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G
M:60@(D9I:FDB"FUS9W-T<B`B@W2#0H-7@5N/E).'BZ2888V1(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")&:6QE(@IM<V=S
M='(@(H-T@T"#0X.+(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G
M<W1R("*#=(-`@T.#BY"4.B`E<R"#=(-`@T.#BR(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U
M;G0Z("5S(&9I;&5S(@IM<V=S='(@(H-T@T"#0X.+D)0Z("5S((-T@T"#0X.+
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P.0IM<V=I9"`B1FEL
M92!-86YA9V5R(@IM<V=S='(@(H-T@T"#0X.+@WV#;(%;@U>#@R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"FUS9VED(")&:6QE($YA;64B"FUS
M9W-T<B`B@W2#0(-#@XN6O"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Y-S0*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(H-T@T"#0X.+
MD4F1\"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.#,*;7-G:60@
M(D9I;&4@=7!L;V%D(@IM<V=S='(@(H-T@T"#0X.+@T&#8H-V@XV!6X-H(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3`R"FUS9VED(")&
M:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B@W2#0(-#@XN#
M08-B@W:#C8%;@VB"S8-4@WR!6X-G@K."ZH+$@J*"W(*Y@O&!0B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY,0IM<V=I9"`B1FEL=&5R<R(*;7-G
M<W1R("*#=(-"@XN#7B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS
M9W-T<B`B@W2#0H.3@XF#DX-HBZ2888V1(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED
M(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(H_CC+>"S(R.(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-PIM<V=I9"`B1FEX
M(')A=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,S(*;7-G:60@(D9L:7`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(S-R!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D9O
M;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R("*#=(-(@XN#7X%;("5S
M((*J@J""Z(+<@KF"\2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`BE;:.
MFI!&(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S('1H
M870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`BB>:1G(+P@U2#?(%;
M@V>"M8+(@J*#=8.)@T6#59=P(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-#$*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,@IM<V=I9"`B(@HB1F]R96-A<W0@
M1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS
M(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R92!C
M;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO
M=7(@<&%S<W=O<F0_(@IM<V=S='(@(H-P@UB#CX%;@VB"\)99@NJ"Q(*U@MR"
MHH+<@K6"O8*I@4@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8T
M"FUS9VED(")&;W)M<R(*;7-G<W1R("*#=(-(@5N#@"(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G
M:60@(D9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4U"FUS9VED(")&;W)U;7,B"FUS9W-T
M<B`B@W2#2(%;@XF#@"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M,3$*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S
M='(@(HO@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@(IAG(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(H-T@XF#DX-8BZ2888V1
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&
M<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R("*#=(.)@Y.#6(%IEGN-D8%J
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R("*#
M=(.)@Y.#6)?,@TV#08-I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0
M;VQY;F5S:6$B"FUS9W-T<B`B@W2#B8.3@UB7S(-\@XJ#;(-6@T$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*
M;7-G<W1R("*#=(.)@Y.#6)?,B\F3[(^4DX<B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,T.0HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,SDU"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*;7-G:60@
M(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`BC]J"M8*BD."6OB(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS
M9VED(")&=6QL($UO;VXB"FUS9W-T<B`BEIZ,CB(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C8P"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`BCH&6O"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(H-+@WN#DXNDF&&-D2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T
M<B`BB>:1G(+PCN:"Z(]O@K>#38.#@XF#BH%;(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED
M(")'86QL97)Y.B(*;7-G<W1R("*#38.#@XF#BH%;@48B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U
M"FUS9VED(")'86UB:6$B"FUS9W-T<B`B@TN#DX-R@T&+I)AAC9$B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@
M(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B)7,@C5R0K(_N
ME?&"\)"VD*R"MX+I(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I
M9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(I"VD*R"
MLX+J@KV#4H%;@V@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S
M='(@(H-/@XN#5X-!BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N
M>2(*;7-G<W1R("*#:(-#@V.8099-BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I
M9"`B1VAA;F$B"FUS9W-T<B`B@TN!6X-IBZ2888V1(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM
M<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(H-7@W6#B8.+@UZ#BR(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<V"FUS9VED(")':79E
M;B!.86UE(@IM<V=S='(@(I"I(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$W-2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,`HC.B!T96UP
M;&%T97,O<')E9G,O87!P+FEN8SHQ.0IM<V=I9"`B1VQO8F%L($]P=&EO;G,B
M"FUS9W-T<B`BBZ22RH-)@W:#5H.'@Y,B"@HC.B!T96UP;&%T97,O<')E9G,O
M87!P+FEN8SHQ-PIM<V=I9"`B1V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,S$*;7-G
M:60@(D=O;V=L92!-87!S(@IM<V=S='(@(D=O;V=L92"#?8-B@W8B"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H
M(@IM<V=S='(@(D=O;V=L92",GXWU(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(S.`IM<V=I9"`B1W)A>7-C86QE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B@TV#
MBH-6@X.+I)AAC9$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I
M9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=R965N;&%N9"(*;7-G<W1R("*#3X.*@5N#DX.)@Y.#:"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B@T^#C(-I@U\B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M:6YI<W1R
M871I;VXB"FUS9W-T<B`B@T^#BX%;@W:*QY>=(@H*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*
M;7-G<W1R("*#3X.+@5N#=I:\@LV+\Y22@L6"S8+(@J*"L8+&(@H*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,P-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B1W)O=7!?
M;&1A<#H@@T^#BX%;@W8@)7,@@O"2QXG!@L6"JX+<@KF"\8%"@U2!6X-O@LR)
MGI.:.B`B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$X
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM
M<V=S='(@(D=R;W5P7VQD87`Z((-/@XN!6X-V("5S((+PC>V/G(+%@JN"W(*Y
M@O$B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S,X(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E
M<R(*;7-G<W1R(")'<F]U<%]L9&%P.B"#3X.+@5N#=B`E<R""\(U8D%:"Q8*K
M@MR"N8+Q(@H*(R!M<V=S='(@(H-/@XN!6X-VBY:)PI#=DN@B"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED
M(")'<F]U<',B"FUS9W-T<B`B@T^#BX%;@W8B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED
M(")'=6%D96QO=7!E(@IM<V=S='(@(H-/@T&#:(.+@5N#=I.'(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B@T^#08.`DX<B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(H-/@T&#98-]@XF+I)AA
MC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'
M=65R;G-E>2(*;7-G<W1R("*#2X%;@Y.#5X%;DX<B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C@X"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R("*#48-8
M@V>#08-.@UJ#6(R@(@H*(R!M<V=S='(@(H-1@UB#9XN6B<*0W9+H(@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<R"FUS9VED(")'=65S=&)O;VLB
M"FUS9W-T<B`B@U&#6(-G@W6#8H-.(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W5I
M;F5A(@IM<V=S='(@(H--@VJ#08NDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I
M9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R("*#38-J@T&#<H-4@T6+I)AAC9$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R("*#2X-#@T&#
M:8NDDZ^+I)AAC9$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-3<*
M;7-G:60@(DA434PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R
M;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY
M(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.C$U-PIM<V=I
M9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(DA4
M5%`@E$:/V(*J@MV"PH*I@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I
M9"`B2&%I=&DB"FUS9W-T<B`B@VZ#0X-@BZ2888V1(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R:71H
M;2(*;7-G<W1R("*#;H-B@U:#A8-!@XN#4X.*@UF#@"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDQ-B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3$Q"FUS9VED(")(96%D97(B"FUS9W-T
M<B`B@W>#8H-?(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE
M<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R("*#=X-B@U\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@
M27-L86YD<R(*;7-G<W1R("*#;H%;@VB!18-]@TZ#:(-I@XN#:(^4DX<B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I
M9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X.0IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C(R('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE
M:6=H="(*;7-G<W1R("*-@H*S(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TAE;'`N<&AP.C$X-"!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z
M,3@V"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L871E<R]H
M96QP+VEN9&5X+FEN8SHT"FUS9VED(")(96QP(@IM<V=S='(@(H-W@XN#=B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*
M;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C@*;7-G:60@(DAE;'!E<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE
M<F4B"FUS9W-T<B`BE+R+A2(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N
M:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS9VED(")(
M97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS
M9VED(")(:6=H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N
M=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0IM
M<V=I9"`B2&]?;64B"FUS9W-T<B`B@WJ!6X.`(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM
M<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B
M@XV!6X-]ED")I)*A@6F#;X-@@TJ#DXYSC9&!:B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,34T.`IM<V=I9"`B2&]M92(*;7-G<W1R("*#>H%;
M@X`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3(R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R("*.J9'N@LR/6H^*(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"FUS9VED(")(;VUE($1I<F5C
M=&]R>2(*;7-G<W1R("*#>H%;@X"#9H-"@XR#3H-G@XJ!6R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO
M;64@4&AO;F4B"FUS9W-T<B`BCJF1[H+,DV288I34C88B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(H-Z@Y.#5X.%@XF#6(NDF&&-
MD2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(HV!
MC6`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C<*;7-G:60@(DAO
M<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HT-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN
M=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*
M;7-G<W1R(")(;W)D92]+;VQA8CH@E7.0LX+((%A-3""#9H%;@UX@)7,@@JJ#
M@8-B@UJ!6X-7("5S((+%C)^/;X*S@NJ"W(*U@KTB"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B
M"FUS9W-T<B`B2&]R9&4O2V]L86(Z((-)@W6#5X-&@TZ#9R`E<R""R9'.B9Z"
MMX+I@X&#8H-:@5N#5X+-@J""Z(+<@KF"\2(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z-#0U"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B"#28-U@U>#1H-.@V>,7B`E<R""S8.!
M@V*#6H%;@U<@)7,@@LF"S8*@@NB"W(*Y@O$B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C$R-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R
M(")(;W)D92]+;VQA8CH@)7,@@LV-[8^<@K."ZH+<@K6"O2!<(B5S7"(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O
M2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D
M;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B2&]R9&4O2V]L86(Z(%!(
M4""*9Y*C("=D;VUX;6PG((*JE4N7=H+%@K<B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C4Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C
M="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@@TF#=8-7@T:#3H-G("5S((+,
M(%A-3""#8X.*@5N"JHWLD*R"Q8*K@MR"N8+Q(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,C0X"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z("5S((*JC>V/G(+%@JN"W(*Y@O$@7"(E<UPB.B`E
M<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#@S"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@
M34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R(")(;W)D
M92]+;VQA8CH@)7,@@LP@34E-12!)1"""JH[FD[Z"Q8*K@MR"N8+Q(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DW"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@
M7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@)7,@@L:3KXKZ@L6"
MJX+<@KF"\2!<(B5S7"(Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HQ,S,W"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R(")(;W)D
M92]+;VQA8CH@DZ^*^H+%@JN"W(*Y@O&!1B5S(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B!<(B5S7"(@@LV5<Y:^@LB+I)=,@L6"MR(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT
M86P@4G5L92(*;7-G<W1R("*0A96]D/PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A
M9&1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S
M92!R97!O<G0A*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C
M;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("*"HH*M
M@L*"S)?Q@O",BXV'@K6"W(*W@JF!2"(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I
M(&%R92!T:&5R93\B"FUS9W-T<B`B@W2#0H%;@XN#:"B-<RF"S)"4@LV"HH*M
M@L*"Q8*W@JF!2"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@
M>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(H*B@JV"PH+,C7."\(R+C8>"
MM8+<@K>"J8%((@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X
M.2!L:6(O0FQO8VLO;65T87(N<&AP.C(S-PIM<V=I9"`B2'5M:61I='DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T.`IM
M<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B@VZ#DX-+@XJ!6XND
MF&&-D2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W,B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,U"B,L('!H<"UF;W)M
M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM
M<V=S='(@(DE-05`@@X&!6X.+@WN#8H-.@UB"S(WLD*R"R8ZXE'."M8+<@K6"
MO3H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,30@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*
M;7-G<W1R("))34%0((.!@5N#BX-[@V*#3H-8@LR-[8^<@LF.N)1S@K6"W(*U
M@KTZ("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE
M9#H@)7,B"FUS9W-T<B`B24U!4""#@8%;@XN#>X-B@TZ#6(-.@TB!6X->@LR-
M[)"L@LF.N)1S@K6"W(*U@KTZ("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,Q,PIM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("))4""#08-H
M@XR#6"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*
M;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B25`@
M@T&#:(.,@UB"JH*@@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI
M;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(DE0@T&#:(.,@UB"JHN6
MB<*"LX+J@KU#2412@W6#C8-B@TZ3X(+)@J""Z(+<@KF"\8%"(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS
M9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(DE0E96-O8CA
ME+V"Q8*W@4(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T
M<B`B@T&#0X-8@XF#DX-HBZ2888V1(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,X,`IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R("*#08-#@U*#DX+,
M@MTB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(B5S((+,@T&#0X-2@Y,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Q"FUS9VED("))8V]N<R!W
M:71H('1E>'0B"FUS9W-T<B`B@T&#0X-2@Y."QH-E@TR#6(-G(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Y,PIM<V=I9"`B261E;G1I='DG<R!N86UE
M.B(*;7-G<W1R("))1(+,EKR13R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C4Y.`HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I
M<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A
M(&YE=R!W:6YD;W<N(@IM<V=S='(@(H+@@K6"X)"S@K6"K95<CJ:"LX+J@LB"
MHH+(@N>!025S((*U@L205H*U@J*#18-#@Y.#:(%;@O"*2H*B@L2)NH*S@J*!
M0B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-3D*;7-G:60@(B(*(DEF
M('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO
M<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R
M;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@HB@N""M8+@($EN
M=&5R;F5T($5X<&QO<F5R((+PCF>"P8+$@J*"Q(%!@T&#0X-2@Y."JI5<CJ:"
MLX+J@LB"HH+(@N>!08*Q@K&"\)%)D?`B"B*"M8+$B;J"LX*B@4(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<R"FUS9VED
M("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H
M92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA
M>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"FUS
M9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R("*)YI&<@W:#C(-R@X6!6R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R("*)YI&<(%523"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R("*)YI&<(%523#HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<U.`IM<V=I
M9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`BB>:1G"(*"B,Z('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T
M96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(H-#@Y.#?(%;@V>!08-8@V6#
M8H-V("5D(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@
M(H-#@Y.#?(%;@V>"LX+J@KV#=(-"@5N#BX-H@48@)7,B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z
M(@IM<V=S='(@(H-#@Y.#?(%;@V>"LX+J@KV#=(-"@5N#BX-H@48B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-`IM<V=I9"`B
M26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R("**U(CA@L&"
MO8-!@TZ#5H.'@Y.#4H%;@VB"JI=>@J:"YX+J@L2"HH+<@K>!0B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"FUS
M9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G
M<W1R("*#AH%;@U66O(*I@W"#6(./@5N#:(*JD+."M8*M@J""Z(+<@KF"\8%"
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*
M(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y
M(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO
M=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB@X:!6X-5EKR"J9'C
MD=:#08-H@XR#6(*JD+."M8*M@J""Z(+<@KF"\8%"C<23>(Z.@K6"Q(+=@NF"
MJ8%!BL>7G8[2@LF809>-@K6"Q"(*(HFZ@K."HH%"(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A
M<V4@26YD96YT(@IM<V=S='(@(I)IB;J"L(+PD%N"K2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B@T.#DX-H(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`BC,*5
MRH.&@5N#52(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S
M='(@(H-#@Y.#:(-L@U:#08NDF&&-D2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`B
MC^Z5\2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3D*;7-G:60@
M(DEN9F]R;6%T:6]N(@IM<V=S='(@(H-#@Y.#=(-(@X&!6X-6@X>#DR(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3D*;7-G:60@(DEN9F]R
M;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`B7T^,XX+K
M@LF7\8+PD7V3_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM86=E(@IM
M<V=S='(@(HGFD9R"\)%]D_PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T
M<B`BE5R"\)%]D_PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B
M@XJ#DX-.@O"1?9/\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M;B!"
M969O<F4B"FUS9W-T<B`B7T.13X+)E_&"\)%]D_PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@
M(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM
M<V=S='(@(HR[C=V(RI)U@LR,XX+K@LF7\8+PD7V3_"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I
M9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE
M(@IM<V=S='(@(HR[C=V(RI)U@LR13X+)E_&"\)%]D_PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G
M:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM
M<V=S='(@(HR[C=V(RI)U@LR,XX+K@LF-<X+PD7V3_"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I
M9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM
M<V=S='(@(HR[C=V(RI)U@LR13X+)C7."\)%]D_PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@
M(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM
M<V=S='(@(HR[C=V(RI)U@LR,XX+K@LF2:9>.@O"1?9/\(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS
M9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO
M9&4B"FUS9W-T<B`BC+N-W8C*DG6"S)%/@LF2:9>.@O"1?9/\(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@
M=&5M<&QA=&4B"FUS9W-T<B`BD>.1UH-E@Y.#=H.,@5N#9X+,D7V3_"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#(*;7-G:60@(DEN<V5R="!A;B!E
M;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W
M('!A<W-W;W)D.B(*;7-G<W1R("*05H*U@J*#<(-8@X^!6X-H@O".\X*OCN:"
MZ8.!@5N#BX-!@VB#C(-8@O"3_)?-@48B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E<G0@
M8V5L;"!A9G1E<B(*;7-G<W1R("*,XX+K@LF#6H.+@O"1?9/\(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM
M<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(I%/@LF#6H.+@O"1
M?9/\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R
M("*,XX+K@LF7\8+PD7V3_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@
M8F5F;W)E(@IM<V=S='(@(I%/@LF#6H.+@O"1?9/\(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3`*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S
M86=E<R(*;7-G<W1R("*#@8-B@UJ!6X-7@O"1?9/\(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED
M("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(HSC@NN"R9)IEXZ"
M\)%]D_PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E
M(@IM<V=S='(@(I%/@LF2:9>.@O"1?9/\(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T
M(')O=R!A9G1E<B(*;7-G<W1R("*,XX+K@LF-<X+PD7V3_"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G
M:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(I%/@LF-<X+PD7V3_"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S,*;7-G:60@(DEN<V5R="!T
M:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB
M"FUS9W-T<B`BEW"04X+,@KV"WX+,CK^6XH+,DYJ"IH+PD_R7S8%&(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I
M9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("*)YI&<@LR1?9/\@5Z5
MSXU8(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@(H.*@Y.#
M3H+,D7V3_(%>E<^-6"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET
M('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("*1
MEY!-D.:"R9&7@NF"O8+?@LR.8XV"@JJ5<Y&K@K6"Q(*B@MR"MX%"(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*
M;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(HYCC8*"JI5S
MD:N"Q8*W@4(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<R"FUS
M9VED("));G1E9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q,S`*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N
M<&AP.C$V-PHC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H
M<#HQ.30*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z
M,C$R"FUS9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@(I5SD+."R"!:
M:7`@@V:!6X->@L6"MX%"(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS
M-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`BE7.0LX+(
M@T&#=H.*@U"!6X-6@X>#DX+%@K>!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B
M871C:"!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C`X-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34U"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R,CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R
M("*6LXSX@LB#9H%;@UZ"JI+QCV^"LX+J@MR"M8*]+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B
M26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R("*1EX+HD.:"
MS(-!@VB#C(-8@JJ5<Y"S@L6"MX%"(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+V1B>"YP:'`Z,3`Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]D8G@N<&AP.C$S.0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O9&)X+G!H<#HR-#$*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V
M-0IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`BE7.0LX+(
M@XF#0X-:@Y.#6(-,@T."Q8*W@4(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,34Y"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D
M+B(*;7-G<W1R("*5<Y"S@LB/ZH^*@JJ.=Y+H@K."ZH+<@K6"O8%"(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W
M"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G
M:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B
M26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`BC^.(RH+,@T&#
M3H-:@UB,H(*JE7.0LX+%@K>!0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-C$*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T
M<B`BE7.0LX+(@W"!6X-G@VF!6TE$@L6"MX%"(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O
M9&4N(@IM<V=S='(@(I5SD+."R)"[E6F#4H%;@VB"Q8*W@4(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G
M:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(I5SD+."R(-V@XV#9X-2
M@XN"Q8*W@4(B"@HC("!P:'`M9F]R;6%T"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C@P"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E
M<UPB(@IM<V=S='(@(I5SD+."R([SD$V.TH+%@K>!1EPB)7-<(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`X,"!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$R-C,*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM
M<V=S='(@(I5SD+."R(NDETR#28-U@U>#1H-.@V<B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN
M=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(I5SD+."R)2MD$V,LX-!
M@VB#C(-8@L6"MX%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T
M82XB"FUS9W-T<B`BE7.0LX+(=6YI8V]D98-F@5N#7H+%@K>!0B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3D*;7-G:60@(DEN=F5N=&]R>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<X"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(I%)
MD?""\)2]DUTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B@T.#B8.3@46#0X-8@XF#@(NDF&&-D2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("*#0X.)@TZ+I)AA
MC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B@T&#
M0X.+@XF#DX-H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*
M;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@(H-]@Y.3AR(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L
M871E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@
M(DES<F%E;"(*;7-G<W1R("*#0X-8@XF#1X.+(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C8*;7-G:60@(DES<W5E<B(*;7-G<W1R
M("*4K8USCM(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R("*.SI',(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@R"FUS9VED("))=&%L>2(*;7-G<W1R("*#0X->@XJ#08NDF&&-D2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R("*#5X.#@WV#
M0X-*(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B@E",CB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`BD_J6>R(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DP"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(R"FUS
M9VED(")*97)S97DB"FUS9W-T<B`B@U>#@X%;@U>!6Y.'(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B@XB#BX-?@Y,B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L
M>2(*;7-G<W1R("*"5HR.(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B@E6,CB(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`BD;6"IH+I(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G
M:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(I*&B9N1M8*F(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*
M;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R("*7O));D;6"IB(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T
M"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`BC;:1M8*F(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*
M;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`BB461M8*F(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(H-*@U6#=(-8@UZ#
MDXNDF&&-D2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR-C4*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(H-)@XJ#
M5X-I@XN"\)7;D;:!2"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS
M9W-T<B`B@U"#:H-!BZ2888V1(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K
M<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+97)B97)O<R"#5(%;@V^"JI1&C]B+
MD93;@K6"W(*U@KV!0B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM
M<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I;VXB
M"FUS9W-T<B`BC*Z-[)"LD_HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R("*,
MKHYWEN0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*
M;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`BC*Z2MR(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS
M9W-T<B`BC*Z.[9?>(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.3D*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E
M861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B
MDV2.<8RN@JJ"MX+%@LF,]H]/C*Z#5(%;@V^"R9&VC=V"M8+<@K>!0B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@(H-,
M@XJ#;X-8BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@1&5M
M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R("*2J9%.EJ^.
MY8[EBV"0;):OBZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`BD>6*V):OC9$B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y,0IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(H-.@T6#
M1H%;@V<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T
M<B`B@TR#BX--@UB+I)AAC9$B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N
M:6YC.C@*;7-G:60@(DQA7WEO=70B"FUS9W-T<B`B7UF#C(-#@T&#18-G(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A
M9V4B"FUS9W-T<B`BC+Z,ZB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E
M;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B@XF#28-8D&R6
MKY:OCN6+I)AAC9$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED
M("),87-T($AA;&8B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C<V"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP
M.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`BB;J,MX+,C(XB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.`IM<V=I9"`B3&%S="!5<&1A=&5D
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`B
MD4^)\8+,@XV#3X-#@Y,Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R
M;VT@)7,B"FUS9W-T<B`BD4^)\8+,@XV#3X-#@Y,Z("4R)',@@JF"YR`E,21S
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$T"FUS9VED("),87-T
M(&QO9VEN.B!.979E<B(*;7-G<W1R("*13XGQ@LR#C8-/@T.#DSH@@LB"M2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(H.)@V>#<H-!
MBZ2888V1(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),
M87<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO=70B"FUS9W-T<B`BE'J2
M=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@(H.,@V^#
M;8.3BZ2888V1(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C8Y"FUS9VED("),969T(@IM<V=S='(@(HVV(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y.`IM<V=I9"`B3&5F="!H96%D
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y
M-`IM<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X
M"FUS9VED("),97-O=&AO(@IM<V=S='(@(H.,@UR#9XFDC9$B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DQE=F5L(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R("*#
MBH-X@XJ#08NDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R
M86(@2F%M86AI<FEY82(*;7-G<W1R("*1Y8.*@W*#08%%@T&#B8-UCM")[X[E
MBV"0;):O@U>#@X-]@5N#<8.*@5N#A"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B
M3&EE8VAT96YS=&5I;B(*;7-G<W1R("*#BH-Q@V6#DX-6@X6#7H-#@Y.,]HV1
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*
M;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G:60@(DQI9VAT(%)A
M:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*
M;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B3&EG:'0@
M4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4
M:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS
M9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,3$*;7-G:60@(DQI;FLB
M"FUS9W-T<B`B@XJ#DX-.(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T
M;SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W
M,@IM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S
M92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R("*#@8%;@XN-[)"LEW""
MR8.!@5N#BX-!@VB#C(-8@LF#BH.3@TZ"MX+I(@H*(SH@9G)A;65W;W)K+U1E
M>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,@IM<V=I9"`B3&EN
M:W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS
M9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#8*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A
M;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3,T"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R("*#9H%;
M@UZ#>(%;@UB(ZI>7(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3$*
M;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B@W>#BX-VC8"6VH+P
ME5R.IH*W@NDB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS9VED("),
M:7-T(%1A8FQE<R(*;7-G<W1R("*57(+,B.J7ER(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),:7-T+4%R8VAI=F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.#D*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP
M.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES
M="U5;G-U8G-C<FEB92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP
M:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F
M86EL960Z("5S(@IM<V=S='(@(H-:@V*#5H.'@Y."S(CJEY>-[)"L@LF.N)1S
M@48E<R(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B@X:!
M6X-5@LR(ZI>7C>R0K(+)CKB4<X%&)7,B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES
M86)L960N(@IM<V=S='(@(H.&@5N#58+,@XJ#6(-G@LV6LXSX@LF"R(+!@L2"
MHH+<@K>!0B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I9"`B
M3&ET97)A='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI
M=&AU86YI82(*;7-G<W1R("*#BH-G@T&#:H-!BZ2888V1(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6UA9V5S+G!H<#HW-PIM<V=I9"`B3&]A
M9&EN9RXN+B(*;7-G<W1R("*#C8%;@VB2ABXN+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,#`*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G
M<W1R("*,NY)NCIZ*U(%&(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V
M"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`BDFZ(YH+&CIZ*U"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<R(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-PHC.B!L:6(O0FQO8VLO<W5N<FES
M92YP:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,@IM<V=I9"`B3&]C871I
M;VXB"FUS9W-T<B`BC^J/BB(*"B,Z(&QO9VEN+G!H<#HQ.#D@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C(P,"!T96UP;&%T97,O;&]G:6XO;6]B:6QE
M+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I;B(*;7-G<W1R
M("*#C8-/@T.#DR(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T
M-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3DT"FUS9VED
M("),;V<@;W5T(@IM<V=S='(@(H.-@T^#08-%@V<B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-3D*;7-G:60@(DQO9VEN(@IM<V=S='(@(H.-@T^#0X.3
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,`IM<V=I9"`B3&]G:6X@
M5&%S:W,B"FUS9W-T<B`B@XV#3X-#@Y,@@UZ#6(-.(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3DU"FUS9VED("),;V=I;B!F86EL960@8F5C875S
M92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R
M<F5C=&QY+B(*;7-G<W1R("*#AH%;@U66O(*I@W"#6(./@5N#:(*JD+."M8*M
M@LB"HH*]@M^"R8.-@T^#0X.3@LF.N)1S@K6"W(*U@KV!0B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.CDY,0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*
M;7-G<W1R("*#C8-/@T.#DX+)CKB4<X*U@MR"M8*]@4(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S8R"FUS9VED("),;VYG('1E>'0B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8Y"FUS9VED("),;W<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I
M9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R("*#38.*@U:#@Y6VCIJ!
M:8^LE;:.FH%J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R
M<R(*;7-G<W1R("*#B8-E@Y.5MHZ:@6F/K)6VCIJ!:B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G
M:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B@XV!6X-]D)2.FH%I
MCZR5MHZ:@6HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS
M9W-T<B`B@XN#3H-:@Y.#=8.+@TZ1Y8SVC9$B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,SD@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(HR.(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(X,PIM<V=I9"`B34]41"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B
M35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R
M("*3695T@K."ZH*]($U3+51.148@@LV#9H%;@UZ"\(K<@O&"Q8*B@MR"N8+Q
M@4(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G<W1R("*#?8-*@TDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O
M<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R("*#?8-0@VB#:H-!BXR#AH%;@U.#
M6(.)@W*#08NDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A
M<B(*;7-G<W1R("*#?8-?@TN#6(-*@XN+I)AAC9$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#D*;7-G:60@(DUA9VEC(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,PIM<V=I9"`B36%I;"(*;7-G<W1R
M("*39(YQ@X&!6X.+(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R
M-`IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@
M(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED
M(")-86QA=VDB"FUS9W-T<B`B@WV#B8-%@T.+I)AAC9$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(H-]@XR!6X-6@T$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(H."@XN#9H-"@W6+
MI)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA;&DB"FUS9W-T<B`BDV2.
M<8.!@5N#BR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L=&$B"FUS9W-T<B`B
M@WV#BX->BZ2888V1(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT"FUS
M9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V
M92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T
M960@=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("*01I5T@J^"LX+J
M@KV#B8-X@XN"\)'.B9Z"LX*Y@L25JI?>@O"*QY>=@K6"W(*W@4(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U-@IM<V=I
M9"`B36%P,C0@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,#@W"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,3<Q"FUS9VED(")-87!1=65S="!M87`B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U
M"FUS9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#0*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C
M:"(*;7-G<W1R("*"4HR.(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C0X
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS
M9VED(")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#D*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@
M(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R
M960I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@
M27-L86YD<R(*;7-G<W1R("*#?8%;@U:#@X.+CY23AXNDF&&-D2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R("*#?8.+@V6#0H-J
M@TZ3AR(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED
M(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B@W2#0H%;@XN#:(+PB.J2=H*S
M@KF"Q(*B@MR"MR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*
M;7-G<W1R("*#@H%;@XJ#7H-J@T&!18-#@UB#B8.`BZ2888V1(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B@X*!6X.*@U:#@X-8
MBZ2888V1(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$S"FUS9VED
M(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,#4*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H
M;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-
M87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C$T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S8*
M;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS
M9W-T<B`B@E2,CB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(DUA>6]T=&4B"FUS
M9W-T<B`B@WV#0X.(@V*#9Y.'(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB97)S(@IM<V=S
M='(@(H.!@Y.#;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#(*;7-G
M:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B@X&#:H.%@5N#@H%;@V@B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P
M"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R("*#6H.+C(N-AR(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T
M871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U
M"FUS9VED(")-97-S86=E(@IM<V=S='(@(I9[E;8B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!6
M97)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I
M8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(H.!@V*#
M6H%;@U>"S8R?C]B"Q8*K@MR"M8*]@JJ!08^0EKR.TH+,D&>,LX+-C)^/V(+%
M@JN"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S<V%G92!E>'!I<F5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8P,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"FUS9VED(")-97-S86=E('1Y
M<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED
M(")-971A<B!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED("(B
M"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E
M;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34S"FUS9VED(")-971A
M<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@
M(H.!@UR#8H-H(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX
M,2!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R
M("*#@8-<@V*#:"!<(B5S7"(@@LV2Z(M@@K."ZH+$@MR"N8+Q(@H*(SH@9G)A
M;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C<@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HX,@IM<V=I9"`B365T<FEC(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S='(@(H.!@TR#5H-2
MC8>/3XV1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R
M871E9"!3=&%T97,@;V8B"FUS9W-T<B`B@WZ#3H.-@VR#5H-!F$&632(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M-@IM<V=I9"`B36ED9&QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS
M9W-T<B`B36EM92!4>7!E(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3<*
M;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P.0IM<V=I9"`B36EN('1E;7`@;&%S
M="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA
M<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-0IM<V=I9"`B36ER<F]R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B
M36ES8V5L;&%N96]U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@
M4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B4$5!4B"#<(-B
M@U"!6X-7@LP@2%144%]297%U97-T((*JC*F3EH*]@NB"W(*Y@O&!0B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@
M8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF
M('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R
M("(B"B*6HI#=DNB"Q8*W@4*"L8+,@T&#=H.*@U"!6X-6@X>#DX+PCF>7<(*W
M@NF"O8+?@LF"S9#=DNB#=(-`@T.#BX+PC>R0K(*W@NF52Y=V(@HB@JJ"H(+H
M@MR"MX%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S
M='(@(H.!@V*#6H%;@U<@240@@JJ,J9.6@KV"Z(+<@KF"\8%"(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*
M;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM
M<V=S='(@(E!%05(@@W"#8H-0@5N#5X+,($UA:6P@@JJ,J9.6@KV"Z(+<@KF"
M\8%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@
M(H-:@V*#5H.'@Y,@240@@JJ,J9.6@KV"Z(+<@KF"\8%"(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B
M"FUS9W-T<B`BC(XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S8*
M;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@(HQGD=&#@8%;@XLB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B
M36]D97)A=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#4*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`BCT.0LY/Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<T"FUS9VED(")-;V1U;'5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B@X*#BX-H@V^+I)AAC9$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R("*#@H-I@U*,]HV1(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R("*#@H.3@U.#BR(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.#$*;7-G:60@(DUO;G1H(&%N
M9"!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-
M86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`BEHB,
MCB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R("*#
M@H.3@V>#6H.)@V>3AR(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]"
M;&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B
MC(Z7[B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$Y-B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR.#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E
M8W1E9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O
M8V-O(@IM<V=S='(@(H."@XV#8H-2B:2-D2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE87(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@
M(DUO<W1L>2!#;&]U9'D@86YD(%=I;F1Y(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")-;W-T
M;'D@4W5N;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HV-#@*;7-G:60@(DUO=F4@1&]W;B(*;7-G
M<W1R("*)NH+6(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HV-3(*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R("*-MH+6
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HV-38*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`BB46"UB(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0T"FUS
M9VED(")-;W9E(%5P(@IM<V=S='(@(H_C@M8B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V"FUS9VED(")-;W9E(&1O=VXB
M"FUS9W-T<B`BB;J"UB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HU,C4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4R-@IM<V=I9"`B36]V92!U<"(*;7-G<W1R("*/XX+6(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(H."@U6#
MDX-R@5N#3HNDF&&-D2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M.#$*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3`U.0IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,SD*;7-G:60@(DUU;'1I<&QE('-E
M;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#`R"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(H-!@TJ#18.3@V<B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*;7-G:60@(DUY($%C8V]U
M;G0@26YF;W)M871I;VXB"FUS9W-T<B`B@T&#2H-%@Y.#9X_NE?$B"@HC.B!S
M97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C0U"FUS9VED(")->2!0;W)T86PB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C0S"FUS
M9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R("*#?H.#@Y.#?8%;F$&632(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS
M9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`BDZ^(TX*U@MR"N8+Q
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B
M"FUS9W-T<B`BEKR13R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*
M;7-G<W1R("*#:8-^@W*#08NDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B
M3F%U<G4B"FUS9W-T<B`B@VF#18.+BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS
M9VED(").97!A;"(*;7-G<W1R("*#;(-P@5N#BXFDC9$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(H-)@XF#DX-?B:2-D2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G
M<W1R("*#28.)@Y.#7Y?,@T&#DX-E@T*#BX^4DX<B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@0F%S
M92!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3@V"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS
M9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A
M<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(%-33"!S
M97)V97(@;F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4X.`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@
M8V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP
M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4S
M"FUS9VED(").971W;W)K(@IM<V=S='(@(H-L@V*#9X./@5N#3B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S,Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G
M:60@(DYE=F5R(@IM<V=S='(@(H+(@K4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@
M(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B@W2#B8.3@UB7S(-J@X6!6X-*@XR#
M:(-J@T$B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(I!6BTN5
MJI?>(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N
M+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O
M;B(*;7-G<W1R("*05HR.(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS
M9W-T<B`BD%:"M8*B@X:!6X-5EKPHE$.(TRDB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G
M:60@(DYE=R!:96%L86YD(@IM<V=S='(@(H-J@X6!6X-7@5N#B8.3@V@B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*;7-G:60@(DYE=R!P
M87-S=V]R9"(*;7-G<W1R("*05H*U@J*#<(-8@X^!6X-H(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(I!6
M@K6"HH-P@UB#CX%;@VB"S2`E>"""R8KZC,"0V(+J@LF"R(+H@MR"MX%"(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED(").97<@
M<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R("*05H*U@J*#<(-8@X^!
M6X-H@JJ(ZI)V@K6"W(*Y@O&!0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N
M:RDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR.3$*;7-G:60@(DYE=W,B"FUS9W-T<B`B@VJ#A8%;@U@B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`W"FUS9VED(").97=S9W)O=7!S
M(@IM<V=S='(@(H-J@X6!6X-8@T^#BX%;@W8B"@HC.B!T96UP;&%T97,O9&%T
M82]T<W9I;F9O+FEN8SHQ-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT
M,0HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R("*.GR(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H87-E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C,V-B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W,`IM<V=I9"`B
M3F5X="!O<'1I;VYS(@IM<V=S='(@(HZ?@LR#28-V@U:#AX.3(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#,*;7-G:60@(DYE>'0^(@IM<V=S
M='(@(HZ?@LR#>8%;@U<^(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G
M=6$B"FUS9W-T<B`B@VJ#2H.)@T^#08NDF&&-D2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM
M<V=I9"`B3FEG97(B"FUS9W-T<B`B@VJ#5X-&@5N#BXNDF&&-D2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R("*#:8-#@U>#1H.*@T&8
M099-BZ2888V1(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V
M.0IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED
M(").:75E(@IM<V=S='(@(H-J@T6#1Y.'(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-@IM<V=I9"`B3F\B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED
M(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF
M9F5R96YC97,@9F]R+B(*;7-G<W1R("*-MY6J@O"57(ZF@K>"Z8*]@M^"S)#=
MDNB"JH*@@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<BYP:'`Z,3`V"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E
M9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G
M:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P,0HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C,X-0HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0P-PIM
M<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H
M<#HU,`IM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!
M3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z-30*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`BE<^-6(+(
M@K6!0B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS
M9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S
M:6]N+B(*;7-G<W1R("*"L8+,@T&#3H-:@UB,H(+)@LV#5(-U@T&#3H-:@UB,
MH(+-DL>)P8+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3<X(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$W"B,Z(&9R
M86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<V.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M)7,N(@IM<V=S='(@(B5S((+,D-V2Z(_NE?&"JHYWDNB"LX+J@L2"HH+<@KF"
M\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-34*;7-G:60@
M(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&
M5%`@5D93+B(*;7-G<W1R(")&5%`@5D93((+,C5R0K(_NE?&"JHYWDNB"LX+J
M@L2"HH+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV
M-S(*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344P@5D93+B(*;7-G<W1R(")344P@5D93((+,C5R0K(_NE?&"
MJHYWDNB"LX+J@L2"HH+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C<R-0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B
M4U%,((-*@V6#4X.*@LR-7)"LC^Z5\8*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R("*.8XV"@JJ"
MH(+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI
M960N(@IM<V=S='(@(I&7D$V0YH*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(B"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,C`*;7-G:60@(DYO
M(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B@W2#0(-#@XN"JH-!@V*#=H.-@5N#
M:(*S@NJ"Q(*B@MR"N8+Q(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q
M"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B@T&#0X-2@Y."JH*@
M@NB"W(*Y@O&!0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M,38@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3,P"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G:60@
M(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("*/ZH^*@JJ.=Y+H@K."
MZH+$@J*"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L:65D
M+B(*;7-G<W1R("*#@8-B@UJ!6X-7@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,V"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`BEKR13X*J
MCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P
M96-I9FEE9"XB"FUS9W-T<B`BE-2-AH*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N
M<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VAT='`N<&AP.CDQ"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B2%144""41H_8@LR#
M<(-8@X^!6X-H@JJ"H(+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DE-05`@E$:/V(+,
M@W"#6(./@5N#:(*J@J""Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+97)B97)O
M<R"41H_8@LR#<(-8@X^!6X-H@JJ"H(+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&]G:6XN<&AP.C@T"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW
M-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("*#C8-/@T.#DR"41H_8@LR#<(-8@X^!6X-H
M@JJ"H(+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A<W-W
M9"YP:'`Z,3,U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%3
M4U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")005-35T0@E$:/V(+,@W"#
M6(./@5N#:(*J@J""Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")334(@E$:/V(+,C5R0K(_N
ME?&"JHYWDNB"LX+J@L2"HH+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HQ,C@W"FUS9VED("(B"B).;R!P871H('1O('1H
M92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y
M(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*
M;7-G<W1R("(B"B)/<&5N4U-,((-V@XV#3X.)@X""S(-P@UB"JHYWDNB"LX+J
M@L2"HH+<@KF"\8%"3W!E;E-33"""S2!02T-3(#$R((+,@V:!6X->@O"(M2(*
M(H*D@LR"R95+EW:"Q8*W@4(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A
M<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S
M='(@(I7;EZ^"S(-4@T.#DX-!@V*#=H+(@K6!0B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HW-C8*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B
M@TZ#2(%;@UZ"JI#=DNB"LX+J@L2"HH+<@KF"\8%"(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PIM<V=I9"`B
M3F\@<G5L97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z-#@R"FUS9VED(").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G
M<W1R("*#6H-P@XR!6X->@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*
M;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z-3@W"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T<B`B
MBEF3EH-T@T"#0X.+@LB"M2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ,C8*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA
M8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@(DYO('5S97)N86UE
M(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R("*#AH%;@U66O(*I@W"#
M6(./@5N#:(*JD9>"YX+J@MR"N8+Q@L6"M8*]@4(B"@HC.B!F<F%M97=O<FLO
M4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A
M=&$@<F5T=7)N960B"FUS9W-T<B`BEK.,^(+,6$U,@V:!6X->@JJ5U(+H@MR"
MM8*](@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDW-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.3@T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY
M.34*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M,3(*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("*2;(+(@K4B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD
M(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B@TF#BH-7@VF#BX+,D-V2Z(-T@T"#0X.+@LF#
M;X%;@U>#AX.3@JJ"H(+H@MR"N8+Q@4*0W9+H@O"-Q)"VD*R"M8+<@K>!0B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I
M;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(I#=DNB#=(-`@T.#BX+)@V^!6X-7@X>#
MDX*J@J""Z(+<@KF"\8%"D-V2Z(-T@T"#0X.+@O"-[(+HDKR"M8+$B;J"LX*B
M@4(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"FUS
M9VED(").;VYE(@IM<V=S='(@(H+(@K4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP
M;&EC:70I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR
M"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(H-M@5N#
M=(-(@5N#3I.'(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C
M:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G
M<W1R("*6:Y2\BX4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA
M<FEA;F$@27-L86YD<R(*;7-G<W1R("*6:X-]@XJ#08-ICY23AR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(H-M@XN#18-&@5N)I(V1
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#$*;7-G
M:60@(DYO="!!9G1E<B(*;7-G<W1R("*"L8+J@N:"Z)%/(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!"969O
M<F4B"FUS9W-T<B`B@K&"ZH+F@NB,XR(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C0Q-0IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@
M(H-F@T*#C(-.@V>#BH+%@LV"H(+H@MR"N8+Q(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX
M-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U
M='!U=%-T<F%T96=Y+G!H<#HY-0HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`BCL"1
ME8*S@NJ"Q(*B@MR"N8+Q@4(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8X"FUS9VED(").;W0@<V5T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP
M:'`Z,30U"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<BYP:'`Z,38P"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<BYP:'`Z,3<U"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,V(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HQ.3,*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(P."!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR-3(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V.0HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C@U(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,#$*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q-B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,S,S"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS-C8@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C0R-@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3`U
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S0*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C4Y,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-C8Y"FUS9VED(").
M;W0@<W5P<&]R=&5D+B(*;7-G<W1R("*#5(-\@5N#9X*S@NJ"Q(*B@MR"N8+Q
M@4(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP."!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T"B,Z(&-O;F9I9R]H
M;V]K<RYP:'`N9&ES=#HQ,#4X(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M.#`*;7-G:60@(DYO=&5S(@IM<V=S='(@(H.!@X(B"@HC.B!S97)V:6-E<R]O
M8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E
M+"!G;R!B86-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B
M,3&,CB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-#,*;7-G:60@
M(DYU;6)E<B(*;7-G<W1R("*0E"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,C(*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@
M(I6VCIJ0E"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C8@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,`HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-#0R('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R("*7
M\9"4(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-"!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#$X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T-#`@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(HUSD)0B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T
M-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I
M;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`BD9>039#F@XJ#6(-G@O"-
M6)!6@KV"WX+,E-2-AH*JCG>2Z(*S@NJ"W(*Y@O&"Q8*U@KV!0B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B
M3TLB"FUS9W-T<B`B3TLB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B@TF#=8-7
M@T:#3H-G(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G
M:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(H-)@W6#5X-&@TZ#9XWLD*R.
MTB(*"B,@;7-G<W1R("*#28-U@U>#1H-.@V>-[)"LCM*"S(N6B<*0W9+H(@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`Q"FUS9VED(")/8W1A;"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R("(Q,(R.(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(X"FUS
M9VED(")/9F9I8V4B"FUS9W-T<B`B@TF#=(-"@U@B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W
M;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"FUS9VED(")/;&0@<&%S<W=O<F0B
M"FUS9W-T<B`BC,."HH-P@UB#CX%;@V@B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R
M<F5C="XB"FUS9W-T<B`BC,."HH-P@UB#CX%;@VB"JI"S@K6"K8*@@NB"W(*Y
M@O$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B@TF#?8%;
M@Y,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW
M,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L
M9&5R<RXB"FUS9W-T<B`BBZ273(-T@TB#BX-?@LT@24U!4""#5(%;@V^"OH*O
M@JJ#5(-\@5N#9X+%@JN"W(*W@4(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-#@@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DV.`IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D
M<F5S<R!A;&QO=V5D+B(*;7-G<W1R("*39(YQ@X&!6X.+@T&#:(.,@UB"S3&"
MPH*^@J^.=Y+H@L6"JX+<@K>!0B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D
M;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB
M<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`BCXJ73([2@JF#5H-8
M@V6#@(K'EYV.TH*^@J^"JHNDETR"S(^*ETR,H(+&@T&#3H-:@UB,H(+PE<^-
M6(+%@JN"W(*W(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-#$@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z-#(*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W
M(@IM<V=S='(@(I!6BTN#18-#@Y.#:(%;@LF57(ZF(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R
M;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%
M('!A<G0N(@IM<V=S='(@(B(*(D]P96Y34TP@@T>#B8%;@493+TU)344@CY"6
MO(*S@NJ"O8-P@5N#9X*I@N>#9H%;@UZ"\([F@NB/;X*Y@MR"N8+Q@L6"M8*]
M@4(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W
M:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S
M"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS
M9W-T<B`B@TF#=H-6@X>#DR(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T
M96UP;&%T97,O<')E9G,O87!P+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R("(E<R"#28-V@U:#AX.3(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I
M9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(I34C8:5=(G3C_"/D8*K(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R
M9V%N:7-A=&EO;B(*;7-G<W1R("*19Y!$(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N
M:70B"FUS9W-T<B`BE92/D"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ,S0*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`BD*Z7G2(*"B,Z(&%D
M;6EN+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A
M=&EO;B!T96UP;&%T92(*;7-G<W1R("*,LX+,@T&#=H.*@U"!6X-6@X>#DX-E
M@Y.#=H.,@5N#9R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H
M<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.2!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3`Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,38@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$R-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3,T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#0*;7-G:60@(D]T:&5R
M($EN9F]R;6%T:6]N(@IM<V=S='(@(I&\@LR#0X.3@W2#2(.!@5N#5H.'@Y,B
M"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE
M<B!097)M:7-S:6]N<R(*;7-G<W1R("*/BI=,CM*"S(-!@TZ#6H-8C*`B"@HC
M(&US9W-T<B`BCXJ.G8[2@LR+EHG"D-V2Z"(*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC871I;VX@:7,@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4$%-()1&C]B"S8YGEW""Q8*K@MR"
MN8+Q@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P
M+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<V"FUS9VED
M(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B4$=0()-DCG&/D):\
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,R,@IM<V=I
M9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(E!'4""(PXV&E;8B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S<T"FUS9VED(")0
M1U`@4'5B;&EC($ME>2(*;7-G<W1R(")01U`@C/:*2HRN(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U-@IM<V=I9"`B4$=0(%-I9VYE
M9"]%;F-R>7!T960@1&%T82(*;7-G<W1R(")01U`@CY"6O(W/+XC#C8:)NX-F
M@5N#7B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.0IM<V=I9"`B4$A0($-O
M9&4B"FUS9W-T<B`B4$A0@U*!6X-H(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP
M.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B4$A0@U:#1H.+(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@
M(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%)A:6XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#`*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-N;W<B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#(*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I
M9"`B4$T@4W5N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C<T"FUS9VED(")03U-)
M6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R(")03U-)6""*9Y*C@JJ,
MJ9.6@KV"Z(+<@KF"\2(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](
M4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S
M='(@(I:$D9`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S
M='(@(H-P@TR#6(->@Y.!18-#@UB#B8.`BZ2888V1(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,0IM<V=I9"`B4&%L874B"FUS9W-T<B`B@W"#B8-)BZ2888V1(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE
M9"(*;7-G<W1R("*#<(.,@UB#8(-ICJF.H8OF(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS
M9VED(")086YA;6$B"FUS9W-T<B`B@W"#:8-]BZ2888V1(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(H-P@W:#08-J
M@X6!6X--@VJ#09/&EZ>-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G
M=6%Y(@IM<V=S='(@(H-P@XF#3X-!@T.+I)AAC9$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4&%R=&QY($-L
M;W5D>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#$U"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#(U"FUS9VED(")087-S=V]R9"(*;7-G<W1R("*#<(-8
M@X^!6X-H(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS
M9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B
M@W"#6(./@5N#:(+-D+./[8+)E<^-6(*S@NJ"W(*U@KV!0B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,PIM<V=I9"`B4&%S<W=O
M<F0@:6YC;W)R96-T(@IM<V=S='(@(H-P@UB#CX%;@VB"JI"S@K6"K8*@@NB"
MW(*Y@O$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,34R
M"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R(")2041)55,@E$:/V(+,@W"#6(./@5N#:(*JE4N7
M=H+%@K>!0B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-3`*;7-G
M:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(H-P@UB#
MCX%;@VB"S(IME$8B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.3`*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R("*#<(-8@X^!6X-H.B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R
M9#H@(@IM<V=S='(@(H-P@UB#CX%;@V@Z("(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,Q"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M
M=7-T(&UA=&-H+B(*;7-G<W1R("*#<(-8@X^!6X-H@JJ(ZI)V@K6"W(*Y@O&!
M0B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T
M92(*;7-G<W1R("*37(+HE72"KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O
M87)D(@IM<V=S='(@(H-.@XJ#8H-V@WN!6X-H@JF"YY-<@NB5=(*O(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I
M9"`B4&%T:"(*;7-G<W1R("*#<(-8(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q
M=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B
ME=N7KY*&@LR#5(-#@Y.#08-B@W:!1B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C
M96YT(@IM<V=S='(@(H-P@5N#6H.3@V<B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN
M=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(I7;CN>1@(WL@O".P(US@K>"
MZ2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,3`*;7-G:60@(E!E<F9O
M<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B
M@XV#3X-#@Y..GH+)E=N.YY&`C>R"\([`C7."M8+<@K>"J8%((@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I
M;VXB"FUS9W-T<B`B@T&#3H-:@UB,H"(*"B,@;7-G<W1R("*+EHG"D-V2Z"(*
M(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B
M@T&#3H-:@UB,H"!<(B5S7"(@@LV-[8^<@K."ZH+<@KF"\8+%@K6"O8%"(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.3`*;7-G:60@(E!E<FUI
M<W-I;VX@1&5N:65D(@IM<V=S='(@(H-!@TZ#6H-8@LV+D93;@K."ZH+<@K6"
MO2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N
M<R(*;7-G<W1R("*#08-.@UJ#6(R@(@H*(SH@861M:6XO<&5R;7,O961I="YP
M:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P
M97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`IM
M<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B@T&#
M3H-:@UB,H(+,BL>7G2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.`IM
M<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`BC,*0;(_NE?$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B@WF#BX%;BZ28
M88V1(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B
M"FUS9W-T<B`B@W2#0H.*@W.#DXNDF&&-D2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S
M='(@(I-DF&(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@P"FUS
M9VED(")0:&]T;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B
M4&ET8V%I<FXB"FUS9W-T<B`B@W.#9X-0@T&#DY.'(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L
M<R(*;7-G<W1R("*#<X-.@UJ#BR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED
M(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E
M;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B
M4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E
M;&5M96YT+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-34Y"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R
M+B(*;7-G<W1R("*,CH+&E$Z"\)/\E\V"M8+$@JV"OH*S@J*!0B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED
M(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*
M;7-G<W1R("*05H*U@J*5JI?>@LR6O)%/@O"3_)?-@K6"Q(FZ@K."HCHB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,CDX"FUS9VED(")0;&5A<V4@
M96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C,W"FUS9VED(")0;&5A<V4@96YT97(@
M82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE
M(&UO;G1H+B(*;7-G<W1R("*0LX*U@J*3^I5T@O"3_)?-@K6"Q(*M@KZ"LX*B
M+B",CH+,D_J0E(+P@V"#1H-B@TZ"M8+$@JV"OH*S@J*!0B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(T-#0*;7-G:60@(E!L96%S92!E;G1E<B!A
M('9A;&ED('1I;64N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R
M>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`BC^&*49/@EV6"\)=VEO&"M8+$
M@K*+3)/\@JV"OH*S@J*!0B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE
M87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T
M<B`B@X:!6X-5EKR"QH-P@UB#CX%;@VB"\)/\E\V"M8+$@JV"OH*S@J*!0B(*
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B(@HB4&QE
M87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W
M:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B
M(@HBCI^"S)6VCY&"\)/'@O&"Q8*M@KZ"LX*B+B""L8+,@U:#6(-E@X""\(YG
MEW""MX+I@KV"WX+,BTN2Z(Z6C8""R9.OB-."MX+IE4N7=B(*(H*J@J""Z(+<
M@K>!0B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G
M97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y
M(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD
M(@IM<V=S='(@(H-\@5N#B8.3@VB+I)AAC9$B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#D*;7-G:60@(E!O;&QS(@IM<V=S
M='(@(I.*E5N0E"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DS
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U9V%L(@IM
M<V=S='(@(H-\@XN#9X-+@XN+I)AAC9$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O
M<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O
M<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3$*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@
M=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,R!L:6(O0FQO8VLO;65T87(N
M<&AP.C(W.`HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O
M<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C@W"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R
M("\^8VAA;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L9&%P.B"5
M2Y=V@LA,1$%0BF>2HXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S
M7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B4')E9G-?;&1A<#H@E4N7=H+(<V5S<VEO;HIGDJ.+0)1<
M@JJ,J8+"@JF"Z(+<@KF"\8%"(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,S(*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C8V"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(T
M"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,#,*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S"FUS9VED
M(")0<F5V:65W(@IM<V=S='(@(H-V@XR#<H.%@5LB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G
M:60@(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R
M("*05H*U@J*#18-#@Y.#:(%;@LF)YI&<@O"57(ZF(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HS-38@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HS-C`*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B
MD4^"S(-)@W:#5H.'@Y,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R
M("*(\XW\(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S
M"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R("*4Z9:GC*XB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M
M(@IM<V=S='(@(H_ABE$B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C<*
M;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`BC^&*49/@EV6"
MS)#@EKXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<Q"FUS9VED
M(")0<F]J96-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,3`X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#4*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W,PIM<V=I9"`B4')O;7!T('1E>'0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(HSVBDJ,KB(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0V"FUS9VED(")0=6)L
M:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R("*,]H]/C*Z#08.+@U.#BH-9@X`B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I
M9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(HSVBDJ,KH_NE?$B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@(E!U8FQI
M8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN
M(@IM<V=S='(@(HSVCT^,KB^4Z9:GC*Z"JI"VD*R"Q8*K@MR"N8+Q@L6"M8*]
M@4(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R
M("*#=H-'@XN#9X.*@U(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,T,S$T+G!H<#HU-0IM<V=I9"`B4'5R9V4@;65S<V%G97,B"FUS9W-T<B`B
M@X&#8H-:@5N#5X+P@W"!6X-7(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T
M87(B"FUS9W-T<B`B@TJ#7H%;@XLB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M-C0*;7-G:60@(E%U97)Y(@IM<V=S='(@(H-.@T>#BH%;(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C<P"FUS9VED(")1=6]T82(*;7-G<W1R("*#2H->
M@5N#BR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8T
M"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I
M(@IM<V=S='(@(E)308SVCT^,KB@E9(-R@V*#9RDB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C8Q"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#4*;7-G:60@(E)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@16%R;'DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#<*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I
M;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3`*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV
M."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED
M(")2871I;R(*;7-G<W1R("*4Y"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(I/'@MXB"@HC
M()/'C9X@D\>/;PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T
M+G!H<#HT-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX-PIM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T
M(&)E('5N9&]N92XB"FUS9W-T<B`BEGN3EH+)("5S((+PC>V/G(*U@MR"MX*I
M/R""L8+,D8"-[(+-C+."R9;?@KF"W(*Y@O&!0B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E
M86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A
M=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("*6>Y.6@LF#AH%;@U4@
M)7,@@LR#9H%;@UZ"\(WMCYR"M8+<@K>"J8%(((*Q@LR1@(WL@LV.YH+HC\&"
MN8+<@KF"\8%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS
M9W-T<B`BC<6,XX+,D8"-[(+P@N*"Z)*\@K<B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B
M4F5F<F5S:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,SDU"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS
M9W-T<B`BDZZ328.!@VJ#A8%;@LR-Q)5<CJ:*U(IU.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-#4*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z
M(@IM<V=S='(@(H-\@5N#7H.+@LR-Q)5<CJ8B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HX.3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,`HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,R"FUS9VED(")296=E>"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C(X"FUS
M9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C`X"FUS9VED(")296QO860B"FUS9W-T<B`B@XJ#C8%;@V@B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S,PIM<V=I9"`B4F5M87)K<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$W"FUS9VED
M(")296UO=&4@4V5R=F5R<R(*;7-G<W1R("*#BH."@5N#9X-4@5N#<H-8(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO
M=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T
M<B`B@XJ#@H%;@V=54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I
M.B`B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*;7-G:60@(E)E;6]V
M92(*;7-G<W1R("*-[8^<(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N
M:6YC.C$Q"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B@W6#C8-B@TZ"
M\(WMCYPB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-34Y"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*;7-G:60@
M(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(H^1CJZ"\(WMCYPB"@HC(&US
M9W-T<B`BCJF5JH+,@TJ#C(.3@U^"J8+GC>V/G"(*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@
M(H-Y@T&"\(WMCYPB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS
M9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R
M87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`BE=N1MH*U@KV#6(-.@XJ#=H-G@O"-
M[(O&@V:#0H.,@TZ#9X.*@JF"YXWMCYR"MX+I@4(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@
M(E)E;6]V92!T:&4B"FUS9W-T<B`BC>V/G(%&(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")2
M96UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(H*Q
M@LR#;8%;@VB"\(-H@TR#A8.!@Y.#9X*I@N>-[8^<(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M;W9E('5S97(B
M"FUS9W-T<B`B@X:!6X-5@O"-[8^<(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U
M<V5R.B`E<R(*;7-G<W1R("*#AH%;@U6"\(WMCYPZ("5S(@H*(SH@9G)A;65W
M;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U
M;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S
M='(@(I=VBX&"R974DYJ"Q8*K@MR"N8+Q.B`B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,30U"FUS9VED(")297%U97-T960@<V5R=FEC92!C
M;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,3@U(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M-3(W"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@
M<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(I=VBX&"
MLX+J@KT@7"(E<UPB((+-("5S((+,D-V2Z(+)CG>2Z(*S@NJ"Q(*B@MR"N8+Q
M@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W."!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C@V,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z-S,Q"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D
M(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("*7=HN!@K."ZH*](%PB)7-<(B""S2!61E,@D-V2Z(+)CG>2Z(*S
M@NJ"Q(*B@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW
M-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S
M<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BEW:+@8*S@NJ"
MO2!<(B5S7"(@@LV0W9+H@LF.=Y+H@K."ZH+$@J*"W(*Y@O&!0B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q
M=6ER960@1FEE;&0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,V"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTO4F5N9&5R97(N<&AP.C,R,`HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C(P('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW
M-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B@XJ#6H-B@V<B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B
M"FUS9W-T<B`B@W"#6(./@5N#:(+P@XJ#6H-B@V<B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!087-S=V]R
M9"(*;7-G<W1R("*"H(+(@KV"S(-P@UB#CX%;@VB"\(.*@UJ#8H-G(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$S,0IM<V=I9"`B4F5S=&]R92!,87-T(%%U
M97)Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW,B!A9&UI
M;B]C;61S:&5L;"YP:'`Z,CD@861M:6XO<W%L<VAE;&PN<&AP.C8W"FUS9VED
M(")297-U;'1S(@IM<V=S='(@(HR+B<HB"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G
M:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(H-)@W:#5H.'@Y."R9;?
M@NDB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@
M(E)E='EP92!N97<@<&%S<W=O<F0B"FUS9W-T<B`B@W"#6(./@5N#:(+PC<23
M_)?-(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S
M='(@(HRS@LR-7)"L@LF6WX*W(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S-0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@
M(H-E@TR#6(-G@T>#9H-"@UZ!6X+,@TF#=H-6@X>#DR(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(HE%(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$P,`IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,P.38*;7-G:60@(E)I
M9VAT('9A;'5E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O
M<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(I;P
MBH0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(H.+
M@5N#?8-J@T$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C(V"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(C$X,)-XB?&3
M72(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,C,*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(HVV@LF)\9-=(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R.0IM<V=I
M9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(HE%@LF)\9-=(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I
M9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`BC7.1KI"K(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I
M9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`BC7.1KI"K(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O
M=W,Z(@IM<V=S='(@(HUS@48B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R
M("*,<I#\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E
M;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R("*14X+$@LR-<X+&E_&"
MS(K4@LF,<I#\@O"(^(*M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`BC7."S(K4@LF,<I#\
M@O"(^(*M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E
M;B!R;W=S(&]N;'DB"FUS9W-T<B`BE_&"S(K4@LF,<I#\@O"(^(*M(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$R,0IM<V=I9"`B4G5N(@IM<V=S='(@(H[`
MC7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB
M"FUS9W-T<B`B@XV#5H-!F$&632(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)W
M86YD82(*;7-G<W1R("*#BX./@Y.#7R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI
M8R!3:6=N871U<F4B"FUS9W-T<B`B4R]-24U%((C#C8:/D):\(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-
M12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R(")3+TU)344@B,.-AI6V(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%3
M3"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")3
M05-,()1&C]B"S8YGEW""Q8*K@MR"N8+Q@4(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-3`V"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL
M(@IM<V=S='(@(E-13""#5H-&@XLB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,C<Q"FUS9VED(")344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K
M=7!S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,S,*;7-G:60@(E-32"(*;7-G<W1R(")34T@B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,U
M"FUS9VED(")354-#15-3(@IM<V=S='(@(I"LC/<B"@HC.B!L:6(O87!I+G!H
M<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B
M"FUS9W-T<B`BDWDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")386EN="!(96QE
M;F$B"FUS9W-T<B`B@UJ#DX-G@W>#C(-IDX<B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G
M:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R("*#6H.3@V>#3(-B
M@V.!E8-L@5N#E(-"@U@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU
M8VEA(@IM<V=S='(@(H-:@Y.#9X.+@U:#02(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G
M:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B@U2#DX-S
M@T>!6X.+@46#?H-.@XV#DY.'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I
M;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B@UJ#DX-G
M@W.#DX-:@Y.#9X*H@N:"T8-/@XR#:8-F@T*!6X.3CY23AR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A
M;64@9G)A;64@*%]S96QF*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS
M9VED(")386UO82(*;7-G<W1R("*#5(."@T&3QI>GC9$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`V"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(H-4@Y.#?8.*@VV+I)AA
MC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I
M<&4B"FUS9W-T<B`B@U2#DX-G@X&!18-V@XJ#DX-6@WF6KX[EBZ2888V1(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T
M96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G
M:60@(E-A=61I($%R86)I82(*;7-G<W1R("*#5(-%@U>#08.)@W*#08FDC9$B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3D*;7-G:60@(E-A
M=F4B"FUS9W-T<B`BE=N1MB(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B
M"FUS9W-T<B`B7"(E<UPB((+PE=N1MB(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,C$V"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS
M9W-T<B`B)7,@@O"5VY&V(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z
M-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(H-)@W:#5H.'@Y."\)7;
MD;8B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3
M879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T
M;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S
M='(@(B(*(I"VD*R"LX+J@KV0W9+H@O`@4$A0((-8@TZ#BH-V@V>"QH*U@L2#
M5(%;@V^"S(WLB\:#9H-"@XR#3H-G@XJ"R97;D;:"MX+I@4(B"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(E<R"0W9+H@O"5VY&V
M@K6"W(*U@KV!0B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L
M('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T
M('1O.B!<(B5S7"(N(@IM<V=S='(@(I#=DNB-6)!6EW"#6(-.@XJ#=H-G(%PB
M)7-<(B""\)7;D;:"M8+<@K6"O8%"(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-C871T97)E9"!4+5-T;W)M
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G
M:60@(E-C:65N8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,38*;7-G:60@(E-E87)C:"(*;7-G<W1R("*,GXWU(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,R,@IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS
M9W-T<B`BC)^-]8-'@Y.#5X.3(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,CDU,@IM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(H-T@T"#0X.+
M@O"129'P(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0X-0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R("*3^I5T@O".
M=Y+H@K6"Q(*M@KZ"LX*B@48B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@
M(I+'B<&"MX+I@T^#BX%;@W:"\)%)D?""M8+$@JV"OH*S@J(B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED(")396QE8W0@82!N97<@
M;W=N97(B"FUS9W-T<B`BD%:"M8*BCXJ.G8[2@O"129'P@K6"Q(*M@KZ"LX*B
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")3
M96QE8W0@82!S97)V97(B"FUS9W-T<B`B@U2!6X-O@O"129'P@K6"Q(*M@KZ"
MLX*B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@
M(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@(I+'B<&"MX+I@X:!6X-5
M@O"129'P@K6"Q(*M@KZ"LX*B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C8W-@IM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R
M("*14X+$D4F1\"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-#`*
M;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S
M"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S<*;7-G:60@(E-E
M;&5C="!N;VYE(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H
M<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D
M(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@
M(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(B(*
M(I5+EW:"R)6VCIJ"\(FZ@LR#>X-B@TZ#6(*I@N>128+Q@L6#4H-S@5N"MX+I
M@L:!08-E@TR#6(-G@T>#BH-!@M:#>8%;@UB#9X+%@JLB"B*"W(*W@4(B"@HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H
M92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`BD_J5=(+,B^:0V(+HE;:.FH+P
MCG>2Z(*U@L2"K8*^@K."HH%&(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@
M(I/ZE72"S(Q@CJZ"\(YWDNB"M8+$@JV"OH*S@J*!1B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T
M:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R("*5SXU8
M@K6"O8*B242"\)%)D?`Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z
M,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S='(@
M(HZ>C8^"S(OFD-B"Z)6VCIJ"\(YWDNB"M8+$@JV"OH*S@J*!1B(*"B,Z('1E
M;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I
M;64@9F]R;6%T.B(*;7-G<W1R("*.GHV/@LR,8(ZN@O".=Y+H@K6"Q(*M@KZ"
MLX*B@48B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED
M(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`BB.J2=H*W
M@NF"48+"@LR#=(-"@5N#BX-H@O"128+Q@L6"K8*^@K."HH%"(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,Q,`IM<V=I9"`B4V5L96-T('EO=7(@8V]L
M;W(@<V-H96UE+B(*;7-G<W1R("*01I*R@O"129'P@K6"Q(*M@KZ"LX*B+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3(*;7-G:60@(E-E;&5C="!Y
M;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`BC+Z,ZH+PD4F1\(*U
M@L2"K8*^@K."HCHB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("*/X8I1
M@XR#?(%;@V>"\)&7D$V"MX+I(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$P-#(*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@
M(E--4R"1EY!-(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G
M<W1R("*#6H-L@TN#BXNDF&&-D2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S(S"FUS9VED(")396YS;W(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R
M(@IM<V=S='(@(H)8C(XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S
M='(@(H-:@XN#<H-!@46#@H.3@V6#;(-/@XTB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C<P,@IM<V=I9"`B4V5R:6%L($YU;6)E<B(*
M;7-G<W1R("*2RI34(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$T.0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"FUS9VED
M(")397-S:6]N($%D;6EN(@IM<V=S='(@(H-:@V*#5H.'@Y.*QY>=(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR
M"FUS9VED(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]A<&DN<&AP.C$T-0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B@UJ#8H-6
M@X>#DR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,3$*;7-G:60@
M(E-E="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SD*
M;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R
M('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`BEEF"
MZH+$@K6"W(+!@KV#<(-8@X^!6X-H@O"#BH-:@V*#9X+%@JN"Z8+F@J2"R8*U
M@MR"MX%"(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q.`IM<V=I9"`B
M4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S
M(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(H-\@5N#7H.+@L6#08-.@UJ#
M6(*W@NF#BH."@5N#9X-4@5N#;X+PD-V2Z(*U@MR"MX%"(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@W"FUS9VED(")3970@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@
M(HR^C.J!08Z>BM21T8%!D_J5=(+PD-V2Z(*U@MR"MX%"(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$P,0IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U
M<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L
M(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*(HI*
MCFZ.GH+,@T&#=H.*@U"!6X-6@X>#DX%!D$:2LH%!@WF!6X-7C<257(ZF@4&"
MNX+,D;R"S)5<CJ:#28-V@U:#AX.3@O"129'P@K4B"B*"Q(*M@KZ"LX*B+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*;7-G:60@(E-E='5P(@IM
M<V=S='(@(I#=DN@B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N
M:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L
M92(*;7-G<W1R("*0W9+HC5B05H-8@TZ#BH-V@V<B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED(")3979E<F%L(&QO8V%T:6]N
M<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(H-:@5N#
M5H-&@XN+I)AAC9$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DX
M"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G
M<W1R("**R))0@LB7=I;Q@48B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#4P"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@
M;6]S="!L:6YK<S\B"FUS9W-T<B`B@6F#@8-J@X6!6X+(@L>"Q8%J@U:#AX%;
M@V>#2H-B@V>#3(%;@JJ.9X*F@NF"YH*D@LF"M8+<@K>"J8%((@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B
M"FUS9W-T<B`BE5R.IB(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*
M;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@
M<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`BC+N-W8+,D-V2Z(+&D%:"M8*MD+:0K(*S@NJ"O9#=DNB"
MQH+,C;>5JH+PE5R.IH*W@NF!0B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT.30*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN
M9R!I;C\B"FUS9W-T<B`B@XV#3X-#@Y..GH+)D4^)\8+,@XV#3X-#@Y..GHK4
M@O"57(ZF@K6"W(*W@JF!2"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$W-C(*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y,@IM<V=I
M9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4S,`IM<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@
M8F%R/R(*;7-G<W1R("*57)&`C>R#@8-J@X6!6X+PE5R.IH*U@MR"MX*I@4@B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4S"B,L('!H<"UF;W)M870*
M;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@
M(HGFELJ-MH+)("5S((.!@VJ#A8%;@O"57(ZF@K6"W(*W@JF!2"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO
M9R(*;7-G<W1R("*57(+,@UJ#BY&ND*N#7X-#@T&#C8-/@O"57(ZF(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*
M;7-G<W1R("*57)&ND*N#7X-#@T&#C8-/@O"57(ZF(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED
M(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T
M<B`BE5R"S)?QD:Z0JX-?@T.#08.-@T^"\)5<CJ8B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@
M(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(I5<
M@LR-<Y&ND*N#7X-#@T&#C8-/@O"57(ZF(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3<V,`IM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G
M:60@(E-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-30*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VAO
M=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV,3D*;7-G:60@(E-H
M<FEN:R(*;7-G<W1R("*/:X^L(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HY,3`*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HY-S(*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,#4X"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3$R,`HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q.#,*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C(S"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(U
M,@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C$R.#4*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C
M:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R("*"W(*XE]>"Z(+,
M@W6#C8-B@TZ"\(]KCZR"W(*]@LV(VI.N@K."N8+$@JV"OH*S@J*!0B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R("*#5H-'
M@XF#C(-)@VR+I)AAC9$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,C8V"FUS9VED(")3:6=N('5P(@IM<V=S='(@(H-4@T.#DX-!@V*#
M=B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$S"FUS
M9VED(")3:6=N871U<F4B"FUS9W-T<B`BDV2.<8^0EKPB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E
M($%L9V]R:71H;2(*;7-G<W1R("*39(YQCY"6O(-!@XN#4X.*@UF#@"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R("*#5H.3@TN#
M?(%;@XN+I)AAC9$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-"!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3,*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(Q,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,T"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#,@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,CDP.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`R
M"FUS9VED(")3:7IE(@IM<V=S='(@(H-4@T.#62(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA
M:6YT96YA;F-E(@IM<V=S='(@(I7;CN>"\(-8@TR#8H-V@K>"Z2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(H-8@XV#;X-,@T&+
MI)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI82(*;7-G<W1R
M("*#6(.-@WB#:H-!BZ2888V1(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-N;W<B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@
M(E-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3D*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I
M9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR.#4*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X.0IM<V=I9"`B4VYO=R!E<75I
M=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM
M<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(H-<@XV#@H.3CY23AR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B@UR#?8.*
M@T&6KX[EBZ2888V1(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS
M9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Y,#4*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N
M(@IM<V=S='(@(I7`@M&/AX+,D4F1\"(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-C8*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.#D*;7-G:60@(E-O=7)C
M92!A9&1R97-S(@IM<V=S='(@(I&7D$V,LX-!@VB#C(-8(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(I/L@T&#=(.*@TJ+
MI)AAC9$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B4V]U
M=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W
M:6-H($ES;&%N9',B"FUS9W-T<B`BD^R#5X.'@5N#5X-!DX>!19/L@U2#DX-H
M@T.#8H-@CY23AR(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS
M9W-T<B`BD^R4O(N%(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@
M8V5L;',B"FUS9W-T<B`BE]>"S(-:@XN"QH+,EUV4DB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C
M92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@
M(H-:@XN"QHNKBD6"QH+,EUV4DB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C@Q,@IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B
M4W!A8VEN9R(*;7-G<W1R("*77922(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A
M;F0@<&%D9&EN9R(*;7-G<W1R("*77922@L:6A)&0(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(E-P86EN(@IM<V=S='(@(H-8@WF#0X.3(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$P,`IM<V=I9"`B4W!A;2(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA
M<F%C=&5R($EN<'5T(@IM<V=S='(@(I/!CNJ5MHZ:@LR3_)?-(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM
M<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R("*#6H.+E:J*A"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G
M:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R("*7\96JBH0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED
M(")3<&QI="!R;W<B"FUS9W-T<B`BC7.5JHJ$(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B@UB#BH.)@Y.#2I:O
MCN6.T(GOCN6+8(NDF&&-D2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HV-B!L:6(O0FQO8VLO;65T87(N<&AP.C@Q"FUS9VED(")3=&%N9&%R
M9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G
M:60@(E-T87(@5')E:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-3@S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.#@*;7-G
M:60@(E-T87)T('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-S$*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E
M(@IM<V=S='(@(H]"@MR"O8+-C*<B"@HC.B!T96UP;&%T97,O861M:6XO<V5T
M=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(H_SD=0B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDT"FUS9VED(")3=&]R
M86=E(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T
M<B`BCUJ/BI34DFXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(H[F
MC\&"M9#\(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,`IM<V=I
M9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@W,`IM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D
M9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS
M9W-T<B`B@UB#7H-#@XL@6T-34UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R("*3^B(*
M"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
M@U2#=8-F@T*#C(-.@V>#BB!<(B5S7"(@@JJ"H(+H@MR"N8+Q@4(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED
M(")3=6)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,R.2!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*
M;7-G:60@(E-U8FUI="(*;7-G<W1R("*.P(US(@H*(SH@<VEG;G5P+G!H<#HT
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T
M;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN
M('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(HFZE72"JR(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I
M9"`B4W5C8V5S<R(*;7-G<W1R("*0K(SW(@H*(SH@861M:6XO=7-E<BYP:'`Z
M.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB
M)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@@LV#5H-8@V6#
M@(+)DL>)P8*S@NJ"W(*U@KV!0B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A
M(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(EPB
M)7-<(B""JH-6@UB#98.`@JF"YXWMCYR"LX+J@MR"M8*]@4(B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB
M+B(*;7-G<W1R(")<(B5S7"(@@JJ-[8^<@K."ZH+<@K6"O8%"(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@
M(EPB)7-<(B""JH-6@UB#98.`@JF"YXWMCYR"LX+J@MR"M8*]@4(B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@
M<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S
M+B(*;7-G<W1R("*0W9+H@LV0LX_M@LF6WX*S@NJ"W(*U@KV!0H.*@XV!6X-H
M@K6"Q(IME$:"Q8*K@MR"MX%"(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED(")3=6-C97-S
M9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(I#=
MDNB"S(-O@V*#3H-!@V*#=H+-D+./[8+)E=N1MH*S@NJ"W(*U@KV!0B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO
M;B!F:6QE("5S+B(*;7-G<W1R("*0W9+H@W2#0(-#@XN"S(-O@V*#3H-!@V*#
M=B`E<R""S9"SC^V"R97;D;:"LX+J@MR"M8*]@4(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P
M9&%T960@7"(E<UPB(@IM<V=S='(@(EPB)7-<(B""S9"SC^V"R8U8D%:"LX+J
M@MR"M8*](@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(B5S((+-D+./[8+)CY&"JXV>@MR"
MZH+<@K6"O2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@
M(H-8@5N#7X.3BZ2888V1(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R
M("**5)=V(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3
M=6X@4FES92(*;7-G<W1R("*3^H+,CV\B"@HC.B!L:6(O0FQO8VLO<W5N<FES
M92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T<B`BD_J"S)/\@N@B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I
M9"`B4W5N;GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(P-0IM<V=I9"`B4W5N<FES92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*
M;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(I/Z@LR/;R^3^H+,D_R"
MZ"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#0*;7-G:60@
M(E-U;G)I<V4Z("(*;7-G<W1R("*3^H+,CV^!1B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,#@*;7-G:60@(E-U;G-E="(*;7-G<W1R("*3
M^I9V(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-PIM<V=I
M9"`B4W5N<V5T.B`B"FUS9W-T<B`BD_J6=H%&(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I
M<'0B"FUS9W-T<B`BC^.5=(*K(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,X,`IM<V=I9"`B4W5P<&]R="(*;7-G<W1R("*#5(-\@5N#9R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(H-8@XJ#:8.`
MBZ2888V1(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S4*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`BD*DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U
M"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(H-8@Y2#
M0(%;@XN#;X.+@4&#A(.3@WV#0X-'@Y./E).'(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM
M<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(H-8@X^#5X.)@Y.#:(FDC9$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS9W-T<B`B@UB#18-&@5N#
M9H.3B:2-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G
M<W1R("*#6(-#@UB8099-(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-0IM<V=I9"`B4WEN8TU,(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY-PIM
M<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*
M;7-G<W1R("*#5H.*@T&!18-!@XF#=8NDF&&-D2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8S"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I
M9"`B5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-C8*
M;7-G:60@(E135B!F:6QE(@IM<V=S='(@(E135H-T@T"#0X.+(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM
M<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R("*57)&ND*LB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS9VED
M(")486)L92!3970B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O
M<&5R=&EE<R(*;7-G<W1R("*57)&ND*LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q
M"FUS9VED(")486EW86XB"FUS9W-T<B`BD>28<"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I
M;F-E(&]F($-H:6YA(@IM<V=S='(@(I'DF'"!:9*&C9&"S(CJE92!:B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B@UZ#5X-,
M@UB#7H.3BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L
M(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R("*#7H.3@U6#:H-!F$&638ND
MF&&-D2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,S(@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P
M-#D*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X.0IM<V=I9"`B5&%S
M:W,B"FUS9W-T<B`B@UZ#6(-.(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-S0*;7-G:60@(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T
M<B`BDV288I34C88B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-PIM<V=I
M9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,C$*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3(*;7-G:60@
M(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(X,@HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A
M='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-CDU"B,L('!H
M<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM
M<V=S='(@(H-E@Y.#=H.,@5N#9R!<(B5S7"(@@JJ"H(+H@MR"N8+Q@4(B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B@V6#DX-V@XR!6X-G@LR*QY>=(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(P."!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,S(T"FUS9VED(")497AT(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-SD*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R
M("*#98-,@UB#9X+,@MTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S
M='(@(I6VCIJ4>I)U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R("*5MHZ:@LR/
MXR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-3D*;7-G:60@(E1H(@IM<V=S='(@(I;8(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.30*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(H->@T.)I(V1
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G:60@(E1H
M92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D94
M4""*9Y*C@JJ"H(+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO2&ES=&]R>2](
M:7-T;W)Y+G!H<#HU-0IM<V=I9"`B5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I
M<V%B;&5D+B(*;7-G<W1R("*7FI?P@U:#6(-E@X""S9:SC/B"R8+(@L&"Q(*B
M@MR"MX%"(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N
M(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]";V]K+G!H<#HQ,CDX"FUS9VED
M(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@
M(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S
M9G5L;'DB"FUS9W-T<B`B36%I;G1E;F%N8V4@@TZ#B8-8@LR3QXV>@MV"JI"S
MC^V"R8US@J:"W(*Y@O&"Q8*U@KTB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L
M;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S
M(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B@TF#=H-6@X>#DX-%@T*#DX-H
M@T6"\)7"@K:"W(*U@KV!0H])E[F"M8+<@K>!0B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D
M<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N
M9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@
M(B(*(H-!@TZ#6H-8C*""\)=,C/B"R8*W@NF"R8+-BL>7G8[2@JJ"NX+,@V^#
M8H-.@T>#DX-H@O"0W9+H@K>"Z8*Q@L:"JI5+EW:"Q8*W@4(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS
M9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I
M9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D
M+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B
M87-E+B(*;7-G<W1R("(B"B*809>-D.9)1)34C8:"JHYWDNB"LX+J@LB"J8+!
M@KV"J8%!B_."OH+!@KV"J8%!@J""Z8*B@LV#9H%;@UZ#>(%;@UB2AH+)C*F5
M=(*I(@HB@NB"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS
M9W-T<B`BF$&7C9#F@LV"H(+(@KV"S(-!@VB#C(-8DJ""R9+'B<&"LX+J@MR"
MM8*]@4(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3<R
M"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I
M<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G
M<W1R("*39(YQCY"6O(*S@NJ"O8.!@V*#6H%;@U>"\(R?C]B"MX+I@LF"S8%!
M4$=0((^0EKR"JI5+EW:"Q8*W@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G
M<W1R("(B"B*1EY!-D.9)1)34C8:"JHYWDNB"LX+J@LB"J8+!@KV"J8%!B_."
MOH+!@KV"J8%!@J""Z8*B@LV#9H%;@UZ#>(%;@UB2AH+)C*F5=(*I(@HB@NB"
MW(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI
M<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(I&7D$V0YDE$E-2-AH*J
MCG>2Z(*S@NJ"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="YP:'`Z,3$V"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R
M97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("*(PXV&
MB;N"R8+-B,"14X+(@T6#1H-UD-J1L8*JE4N7=H+%@K>!0B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,3@V(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z-3(X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H
M;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B@W2#0(-#@XL@
M)7,@@LF"S2`E<R""S)#=DNB"JI5+D'N"Q8*W@4(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C4Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R("*#=(-`@T.#BR`E
M<R""R8+-("5S((+,D-V2Z(*JE4N0>X+%@K>!0B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(R-@IM<V=I9"`B5&AE(&9I;&4@8V%N;F]T(&)E
M(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B@W2#0(-#@XN"S8ZIE:J.
MJ9!G@LF#4H-S@5N"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO1&%T82]$
M871A+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A
M+B(*;7-G<W1R("*#=(-`@T.#BX*J@V:!6X->@O"*W(+Q@L6"HH+<@KF"\8%"
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV
M-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H
M:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`BB,B)NH+-@K&"
MS(.!@V*#6H%;@U>!:5)&0S@R,H%J@LR#=X-B@U^"Q8*W@4(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B
M"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B
M;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E
M<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9
M;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@
M;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A
M<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V
M97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T
M96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA
M=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T
M:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S
M='(@(B(*(I*-B-.!22"#=(.+@UB#3H.*@5N#DX."@5N#:(+-($EN=&5R;F5T
M($5X<&QO<F5R((+%@LV6XI'H@JJ4K9"V@K>"Z8*Q@L:"JH*@@N@B"B*"W(*W
M@6F#=8.)@T6#58+,@V^#3X+%@K>!:H%"B>:6RH+)@U.#?H*JE5R.IH*S@NJ"
MO8+H@4%7:6YD;W=S((*J@TZ#B8-B@U:#A8*U(@HB@KV"Z(*W@NF"J8+@@K6"
MZH+<@KF"\8%"7&XB"B*#=(.+@UB#3H.*@5N#DX."@5N#:(+)@K>"Z8+(@N<@
M3TL@@O")GX*U@L2)NH*S@J*!0B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ
M,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H
M87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("))1"!<(B5S7"(@@LV-[8^<@K."
MZH+<@K6"O8%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I
M;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB
M"FUS9W-T<B`B(@HB1VYU4$<@@V^#0X-I@XJ"S(-P@UB"JB!#<GEP=%]P9W`@
M@TZ#B8-8@LF0W9+H@K."ZH+$@J*"Z95+EW:"JH*@@NB"W(*W@4(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`R"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S
M=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES
M(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@
M;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@W-`IM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN
M:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0W-`IM<V=I9"`B5&AE(&YU;6)E<B!O
M9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R("*"L8+,@W2#0H%;
M@XN#:(+-D)2.FH+%@LB"KX+J@LZ"R(+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S(*;7-G:60@(E1H92!O<&5N
M<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M
M:6UE.CH@8VQA<W,N(@IM<V=S='(@(DAO<F1E7T-R>7!T7W-M:6UE@TZ#B8-8
M@LF"S6]P96YS<VR#@H-7@X6!6X.+@JJ52Y=V@L6"MX%"(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B
M96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W
M86)L92!S:7IE(@IM<V=S='(@(B(*(H-V@XR#=(-`@XR#DX-87"(E<UPB@LV#
M9H%;@UZ"JH-4@T.#69"GC,""\(EZ@J:"O8*]@M^5VY&V@L6"JX+<@KF"\8+%
M@K6"O2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N<&AP
M.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H
M<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R<&]I
M;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R
M9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<G!M+G!H
M<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N<&AP
M.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL:71E
M+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X8V5L
M+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U
M<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD
M(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*(H*Q@LR#9H%;@UZ,7B@E<RF"
M\)5<CJ:"MX+I@KV"WX+,@W:#C8-/@XF#@(*J@K&"S(-6@UB#98.`@LF"W8+"
M@JF"Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M-#@W"FUS9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I
M;F=L92!C:&%R86-T97(N(@IM<V=S='(@(HCXEW"5A(+-@E"5MHZ:@L6"R(*O
M@NJ"SH+(@NB"W(*Y@O&!0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@
M;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R
M:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HT-SD*;7-G:60@(E1H92!S97!A<F%T;W(@;75S
M="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`BB^:0V(+HE82"
MS8)0E;:.FH+%@LB"KX+J@LZ"R(+H@MR"N8+Q@4(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("*#5(%;
M@V\@7"(E<UPB((+-C>V/G(*S@NJ"W(*U@KV!0B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S
M97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R("*#5(%;@V\@
M7"(E<UPB((+-E=N1MH*S@NJ"W(*U@KV!0B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@
M9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#<P"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!S<&5C:69I960@<F]W("@E9"D@9&]E<R!N
M;W0@97AI<W0N(@IM<V=S='(@(HYWDNB"M8*]E_&!:25D@6J"JH*@@NB"W(*Y
M@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3<Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E
M<R!N;W0@97AI<W0N(@IM<V=S='(@(HCJCIZ#=(-`@T.#BR!<(B5S7"(@@JJ"
MH(+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,CDY
M"FUS9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H
M92!T97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@
M(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D
M(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S
M='(@(H-!@V*#=H.-@5N#:(-F@5N#7H*JDKR13X+,@UB#98-B@W:"Q8_!CKB"
MM8+<@K6"O8%"(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V
M,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@
M=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(H-!
M@V*#=H.-@5N#:(-F@5N#7H+PE=N1MH+%@JN"W(*Y@O&"Q8*U@KV!0B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT.2!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3$P"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO
M8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D
M:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B@V6!6X-]@V:#
M0H.,@TZ#9X.*@5L@7"(E<UPB((*J@J""Z(+<@KF"\8%"(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N
M;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`BCG>2Z(+%@JN"Z8-)@W:#
M5H.'@Y."S8*@@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C,T.`IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H
M870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(H-#@Y.#B8-#
M@Y.57(ZF@L6"JX+IE925JH+-@J""Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3,Y.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9
M;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N
M=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@HBE;:.FI"4@JJ"L8+,@W2#
M0H%;@XN#:(+)D;V)WX*L@MR"MRX@)7,@@LR5MHZ:@JJ3_)?-@K."ZH+$@J*"
MW(*W+B`E<R"(R(FZ@L6"R"(*(H*M@L2"S8*B@J^"W(*Y@O&!0B(*"B,Z('-I
M9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H
M92!S>7-T96TZ("5S(@IM<V=S='(@(EPB)7-<(B""\(-6@UB#98.`@M:2QXG!
MDH:"R9;BD>B"JI2MD+:"M8+<@K6"O3H@)7,B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T
M96TZ("(*;7-G<W1R("*#AH%;@U4@7"(E<UPB((+,@V:!6X->@O"#5H-8@V6#
M@(*I@N>/P8N.DH:"R9;BD>B"JI2MD+:"M8+<@K6"O3HB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@
M<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS
M9W-T<B`B7"(E<UPB((+P@U:#6(-E@X""J8+GC>V/G)*&@LF6XI'H@JJ4K9"V
M@K6"W(*U@KTZ(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB
M.B`E<R(*;7-G<W1R(")<(B5S7"(@@O"-6)!6DH:"R9;BD>B"JI2MD+:"M8+<
M@K6"O3H@)7,B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY
M,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G
M<W1R("(B"B*#=(-`@T.#BX-!@V*#=H.-@5N#:(+)EN*1Z(*JE*V0MH*U@MR"
MM8*].B`E<R""S8-!@V*#=H.-@5N#:(*S@NJ"Q(*B@MR"N8+Q@4(B"@HC.B!F
M<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B
M"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HB@W2#0(-#
M@XN#08-B@W:#C8%;@VB"R9;BD>B"JI2MD+:"M8+<@K6"O3H@)7,@@LV#=(-`
M@T.#BX+,@U2#0X-9D*>,P))L*"5D@V^#0R(*(H-G*8+PB7J"IH+$@J*"W(*W
M@4(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U
M<&QO861E9"XB"FUS9W-T<B`B(@HB@W2#0(-#@XN#08-B@W:#C8%;@VB"R9;B
MD>B"JI2MD+:"M8+<@K6"O3H@)7,@@LV(ZI64@LR"W8-!@V*#=H.-@5N#:(*S
M@NJ"W(*U(@HB@KV!0B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P
M;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(H*Q@LR#<(%;@V>"
M\)5<CJ:2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KTB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@
M(IA!EXV0YH-F@5N#7H+,@T.#DX-\@5N#9Y*&@LF#1X.)@5N"JI2MD+:"M8+<
M@K6"O8%"(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,Q"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD
M87(@9&%T82XB"FUS9W-T<B`B:4-A;&5N9&%R((+,@T.#DX-\@5N#9Y*&@LF#
M1X.)@5N"JI2MD+:"M8+<@K6"O2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C@R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O
M;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R
M97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@HBD-V2Z(-T@TB!6X.`DH:"R8-'
M@XF!6X*J@J""Z(+<@K6"O8%"@KV"U(+Q@4&52Y![C8"6VH*JB_.4DH*^@L&"
MO8+,@L6"M8+E@J2!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R
M;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC
M=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB
MCG>2Z(*S@NJ"O8-!@VB#C(-8DJ""S)&`C>R2AH+)@T>#B8%;@JJ4K9"V@K6"
MW(*U@KV!0HSC@L6-Q)-XCL"-<X*U@L2"K8*^@K,B"B*"HH%"(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G
M:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C
M="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("*8
M09>-D.:"S(_:C=>"\(U8D%:2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0HSC
M@L6-Q)-XCL"-<X*U@L2"K8*^@K."HH%"(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A
M<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(I&7D$V0YH.*@UB#9X+,
MC5B05I*&@LF#1X.)@5N"JI2MD+:"M8+<@K6"O8%"C.."Q8W$DWB.P(US@K6"
MQ(*M@KZ"LX*B@4(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@
M<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(H*Q@LP@24U!4""#
M5(%;@V^"S8NDETR#=(-(@XN#7X+P@U2#?(%;@V>"M8+$@J*"W(*Y@O&!0B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G
M:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R
M8VAI=F4N(@IM<V=S='(@(H*Q@NJ"S9=,C/B"R"!R87(@@T&!6X-*@T.#=8+%
M@LV"R(*B@N:"I(+%@K>!0B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O
M(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(H*Q@NJ"S9=,C/B"R"!Z
M:7`@@W2#0(-#@XN"Q8+-@LB"HH+F@J2"Q8*W@4(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3(T"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@
M=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B@K&"ZH+-ETR,
M^(+(@TJ!6X-HE-2-AH+%@LV"R(*B@N:"I(+%@K>!0B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B
M(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M
M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@
M(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL
M('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G
M:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS
M9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E
M=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N
M(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO
M+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY-S4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`U-`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@S(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q,3(*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$W.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4S"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S,#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y-0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-34T(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X,S8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU
M-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`R"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P,C8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`W
M-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,30V(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R,3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C0P-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#0W"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(V,S0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@P-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$V(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,R.30*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S@P,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#$P"FUS9VED(")4
M:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R("*"L8+,@W2#0H%;@XN#
M:(+-E4N0>X+%@K>!0B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P
M-C(*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R
M<RXB"FUS9W-T<B`B@K&"S(-T@T*!6X.+@VB"S9"ND)2"Q8+(@JV"Q(+-@J*"
MKX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q,PIM
M<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD
M('1H92!C;VQO;BXB"FUS9W-T<B`B@K&"S(-T@T*!6X.+@VB"S9"4CIJ"QH-2
M@XV#DX+%@LB"K8+$@LV"HH*O@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,#DQ"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O
M;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R("*"L8+,@W2#0H%;@XN#:(+-
M.)!ID)2"Q8+(@JV"Q(+-@J*"KX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$R,`IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@
M8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS
M9W-T<B`B(@HB@K&"S(-T@T*!6X.+@VB"S8-2@Y.#?8+<@KV"S8OSE)*"Q8OF
MD-B"YX+J@KV0KI"4@LR#BH-8@V>"Q8+(@JV"Q(+-@J*"KX+<@KDB"B*"\8%"
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@V"FUS9VED(")4:&ES
M(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(H*Q@LR#
M=(-"@5N#BX-H@LV0E(Z:@L6"R(*O@NJ"SH+(@NB"W(*Y@O&!0B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*;7-G:60@(B(*(E1H:7,@9FEE
M;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F
M;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B@K&"
MS(-T@T*!6X.+@VB"S3$VD&E21T*57(M,@LR01H-2@5N#:(+(@JV"Q(+-@J*"
MKX+<@KF"\8%"E^$Z)R,Q,C,T868G+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C4U.`IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@
M<')O8V5S<V5D+B(*;7-G<W1R("*"L8+,@W2#2(%;@X""S8KY@LF/B)>=@K."
MZH+$@J*"W(*W@4(B"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0V.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@
M5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*
M(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@
M9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P
M;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z-3DW"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S
M*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"B*"L8+,@X&#8H-:
M@5N#5X+-@J""R(*]@JJ.9Y=P@K>"Z8+,@L:(V8+(@NF5MHZ:@UJ#8H-G@6DE
M<X%J@L6/D8*I@NJ"Q(*B@MR"MX%"(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@
M;&5A<W0@;VYE+B(*;7-G<W1R("*"L8+,E-2-AH+-C<6/K(+%@N`Q@L6"R(*M
M@L2"S8*B@J^"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC
M;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(H*Q@LR#5(%;
M@V^"Q8+->FEP@L9G>FEP@W2#0(-#@XN"\)-7BDJ"Q8*K@MR"N8+Q@4(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I
M9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G
M<W1R("*"L8+,@U:#6(-E@X""S8CJCIZ328+)EK.,^(+)@LB"P8+$@J*"W(*W
M@4(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I
M9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R("*"L8+,
MDFR"S9"4CIJ"Q8+(@J^"ZH+.@LB"Z(+<@KF"\8%"(@H*(SH@<V5R=FEC97,O
M:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@
M;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R
M("*"L8+,@T6#0H.3@VB#18+-@TF#=H-6@X>#DX-%@T*#DX-H@T6"J8+GC,2/
M;X*S@NJ"Z95+EW:"JH*@@NB"W(*W@4(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,V"FUS9VED(")4
M:6-K971S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(T,C(@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")4
M:6UE(@IM<V=S='(@(HZ>BM0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S@X"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(H->@T.#@(-6
M@5N#9R(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F
M;W)M870B"FUS9W-T<B`BCIZ*U(^1CJXB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-3(X"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R("*3
MC(-E@T*#@H%;@XN6KX[EBZ2888V1(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR
M,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B@UZ#0X-G@XLB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L
M92`H=&]O;'1I<"DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-30*
M;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N
M('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI
M;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*(I6AD)2"S(V`EMJ"\)%)D?""MX+I
M@LF"S8%!4$."Q8+-0V]N=')O;(-,@T.!04UA8X+(@N=#;VUM86YD@TR#0X+P
MB9^"M8+(@JJ"YX-.(@HB@XJ#8H-.@K6"W(*W@4(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S`P"FUS9VED(")4;V1A>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(X
M"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B2%1-3(-<@5N#
M6)5<CJ:0V)'6(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G;R(*;7-G<W1R
M("*#9X%;@U.+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U
M(@IM<V=S='(@(H-G@U"#B8-%CY23AR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,#(*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S='(@(H-G@Y.#2XFDC9$B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMO;&%B+G!H<#HQ,#0*;7-G:60@
M(E1O;R!M86YY(&EN=F%L:60@;&]G:6YS(&1U<FEN9R!T:&4@;&%S="!M:6YU
M=&5S+B(*;7-G<W1R("*"L8+,D)25JHK4@LF)O9-X@N"#C8-/@T.#DX*JCHZ-
M<X*S@NJ"W(*U@KV!0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G
M:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*
M;7-G<W1R("*#9X.*@VJ#7X%;@VB!18-G@V^#4XNDF&&-D2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$W.#<*;7-G:60@(E1R=64@;W(@9F%L<V4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`BB<XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(H-@@X6#:H-7@T&+I)AAC9$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B@V>#BX-2
MBZ2888V1(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E1U
M<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*
M;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R("*#9X.+@TZ#@8-J@UB#7H.3
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA
M;F1S(@IM<V=S='(@(H->@5N#3H-8@46#2H-#@U*#6(^4DX<B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B@V.#;X.+(@H*(SH@9G)A
M;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC
M93H@(@IM<V=S='(@(I%)D?"!1B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-3@*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI
M8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A
M='5S(')E<&]R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G<W1R("*#18-+@Y.#
M7XNDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B"FUS9W-T
M<B`B@T6#3H.)@T.#:2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C0Q.0IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*
M;7-G<W1R(")61E,@@V:#0H.,@TZ#9X.*@LF#08-.@UJ#6(+%@JN"W(*Y@O&!
M0B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I
M9"`B56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@
M<VEG;FEN9R!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HS.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H
M86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(E9&4R"#=(-`@T.#BR!<(B5S7"(@@LR#08-.@UJ#6(R@@LV5SXU8@L6"JX+<
M@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,SDR(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL
M92`E<R\E<RXB"FUS9W-T<B`B5D93((-T@T"#0X.+("5S+R5S((+,@T&#3H-:
M@UB,H(+-E<^-6(+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-S@V"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M:&%N9V4@=&\@)7,N(@IM<V=S='(@(B5S((+)E<^-6(+%@JN"W(*Y@O&!0B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,W"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB
M+B(*;7-G<W1R("*#=(-`@T.#BR!<(B5S7"(@@LR#5(-#@UF"JH-@@T:#8H-.
M@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Y
M-2!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,C@*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@U,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS
M9W-T<B`B@W2#0(-#@XL@7"(E<R\E<UPB((+,@U2#0X-9@JJ#8(-&@V*#3H+%
M@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HT
M,SD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM
M<V=S='(@(E-13""#5(%;@V^"R9#:D;&"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C@W,`IM<V=I9"`B56YA8FQE('1O(&-O
M;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(E-33"""Q9#:D;&"Q8*K@MR"N8+Q
M@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S(@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,W"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HR,#0@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C(P.0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C$W
M"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B5D93
M((-T@T"#0X.+@O"#4H-S@5N"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C,W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")6
M1E,@@V:#0H.,@TZ#9X.*(%PB)7-<(B""\(WLD*R"Q8*K@MR"N8+Q@4(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-C$@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,C8T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(E9&4R"#9H-"@XR#3H-G@XJ"\(WLD*R"Q8*K@MR"
MN8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T"FUS
M9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@
M@W2#0(-#@XN"\(WLD*R"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")61E,@@V:#
M0H.,@TZ#9X.*(%PB)7-<(B""\(WLD*R"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-S(*;7-G:60@(E5N86)L92!T;R!C
M<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(HOS@LP@5D93((-T@T"#
M0X.+@O"-[)"L@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+W1A<BYP:'`Z-S8*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S
M<R!D871A+B(*;7-G<W1R("*#9H%;@UZ"\(BSCVN"Q8*K@MR"N8+Q@4(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R."!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C,P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN
M(@IM<V=S='(@(EPB)7-<(H+PC>V/G(+%@JN"W(*Y@O$N((-F@T*#C(-.@V>#
MBH*JB_."Q8+-@J""Z(+<@KF"\8%"(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW
M."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B7"(E
M<UPB@O"-[8^<@L6"JX+<@KF"\3H@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,S,X(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,SDU
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,3$@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E
M;7!T>2(*;7-G<W1R("(E<X+PC>V/G(+%@JN"W(*Y@O$N((-F@T*#C(-.@V>#
MBH*JB_."Q8+-@J""Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,U-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,S8P"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@
M<F5C=7)S:79E;'DN(@IM<V=S='(@(E9&4R"#9H-"@XR#3H-G@XJ"\(W$BT&3
M28+)C>V/G(+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C,T-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,S4@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(E9&4R"#9H-"@XR#3H-G@XJ"\(WMCYR"Q8*K@MR"
MN8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0R,"!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0S,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R
M(")61E,@@V:#0H.,@TZ#9X.*@O"-[8^<@L6"JX+<@KF"\8%&)7,B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Q,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T
M<B`B5D93((-T@T"#0X.+(%PB)7-<(B""\(WMCYR"Q8*K@MR"N8+Q@4(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,3`@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HR.3$*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,Y,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,SDY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE
M+B(*;7-G<W1R(")61E,@@W2#0(-#@XN"\(WMCYR"Q8*K@MR"N8+Q@4(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(T.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*
M;7-G<W1R(")61E,@@V:#0H.,@TZ#9X.*(%PB)7-<(B""\(WMCYR"Q8*K@MR"
MN8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0P.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I
M=F5L>3H@)7,N(@IM<V=S='(@(E9&4R""\(W$BT&328+)C>V/G(+%@JN"W(*Y
M@O&!1B5S(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,S0*;7-G
M:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM
M<V=S='(@(HR[C=V"S(-F@T*#C(-.@V>#BH%;@JJ3P9+H@L6"JX+<@KF"\8%"
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#0*;7-G
M:60@(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS
M9W-T<B`BC]B6OH^1@LR/VHW7@JJ.YH+HCV^"N8+<@KF"\2(*"B,Z(&9R86UE
M=V]R:R].971?24U34"])35-0+G!H<#HT,S<@9G)A;65W;W)K+TYE=%])35-0
M+TE-4U`O075T:"YP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("(E<R""
MS)+HBV""JH.-@5N#:(+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(P,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M,#@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W-"!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<Y"FUS9VED(")5;F%B;&4@
M=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`B5D93((-T@T"#0X.+@JJ(VI.N
M@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY
M,R!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P-@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C8U,B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.CDX"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B5D93((-T@T"#0X.+(%PB)7-<(B""JHI*
M@J^"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X
M-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#$*;7-G:60@(E5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R(")61E,@@W2#
M0(-#@XN"\(^1@JN-GH+=EW""R8I*@J^"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C@S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C$S-PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S8*
M;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@
M@W2#0(-#@XN"JHI*@J^"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O
M;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`BB+./:X^1C,F#=(-`@T.#BX+P
MBDJ"KX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@U-@IM
M<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I
M;&5D*2XB"FUS9W-T<B`B5D93((-T@T"#0X.+@JJ3QX+?@MR"N8+Q@6EF:6QE
M<VEZ92@I((-'@XF!6X%J@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M.#@W"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I
M>F4H*2!F86EL960I+B(*;7-G<W1R(")61E,@@W2#0(-#@XN"JI/'@M^"W(*Y
M@O&!:6=E=$9I;&53:7IE*"D@@T>#B8%;@6J!0B(*"B,Z(&9R86UE=V]R:R]3
M97-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I
M9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(E9&4R"#=(-`@T.#
MBX*JD\>"WX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z-C<V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E
M8W1O<GDN(@IM<V=S='(@(G9F<W)O;W0@@V:#0H.,@TZ#9X.*@O"3QX+?@MR"
MN8+Q@4(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q,#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@
M9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(I:\
MD4\@)7,@@O`@)7,@@LF5SXU8@L6"JX+<@KF"\8%&@W2#2(.+@U^!6X+-BOF"
MR9&VC=V"M8+<@K<B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN
M(@IM<V=S='(@(E9&4R"#9H-"@XR#3H-G@XJ!6X+,EKR13X+PE<^-6(+%@JN"
MW(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S,R"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C
M=&]R>3H@)7,N(@IM<V=S='(@(E9&4R"#9H-"@XR#3H-G@XJ!6X+,EKR13X+P
ME<^-6(+%@JN"W(*Y@O&!1B5S(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HR-S$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(E9&4R"#=(-`@T.#BR!<(B5S7"(@@LR6O)%/@O"5SXU8
M@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M-C$W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB
M"FUS9W-T<B`B5D93((-T@T"#0X.+("5S+R5S((+,EKR13X+PE<^-6(+%@JN"
MW(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(V(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,3,*(SH@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C0U,B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,CDS"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS
M,#D*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@
M(E9&4R"#=(-`@T.#BX+,EKR13X+PE<^-6(+%@JN"W(*Y@O&!0B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU
M,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*
M;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT
M(@IM<V=S='(@(H*Q@LP@5V]R9""5MH^1@O"6?);S@L6"JX+<@KF"\8%"(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-30@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HQ-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B5D93((-T@T"#
M0X.+(%PB)7-<(B""R8^1@J^"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C$X-@IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F
M:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B5D93((-T@T"#0X.+@LF/
MD8*O@MR"N8+Q@6EC;W!Y*"F.N)1S@6J!0B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(X."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,30V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-3$*
M;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R
M(")61E,@@W2#0(-#@XN"R8^1@J^"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HX-C(*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL
M92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS9W-T<B`B5D93((-T@T"#
M0X.+@LF/D8*O@MR"N8+Q@4)Q=6]T82""\)*TB=^"M8*]@N:"I(+%@K>!0B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*
M;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R("*)NI#\(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@
M(I7/C5B"\([F@NB/P8*W(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I
M;VXB"FUS9W-T<B`BC<6,XX+,D8"-[(+PC+."R9;?@K<B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C$*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@X"FUS9VED(")5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G
M<W1R("*0VI&QCIZ"S(-4@5N#;X%;@JF"YX+,EUR*^H*U@LB"HHF>DYJ!1B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q-PHC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,SD*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<V"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,@IM<V=I9"`B
M56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@
M(H-4@5N#;X%;@JF"YX+,EUR*^H*U@LB"HHF>DYJ!1B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED(")5
M;F9I;&5D(@IM<V=S='(@(I:BD*Z7G2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3DV"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@
M(H-!@XF#=8[QDK>-D9A!EDTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E
M9"!+:6YG9&]M(@IM<V=S='(@(HEPC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED
M(")5;FET960@4W1A=&5S(@IM<V=S='(@(I7$C9$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S
M"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',B
M"FUS9W-T<B`BE<27S)&^E;V7;8^4DX<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HW.`IM<V=I9"`B
M56YI=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#(Y(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S,`HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C4X"FUS9VED
M(")5;FMN;W=N(@IM<V=S='(@(I5SEKXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@
M87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS
M9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#<*
M;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS
M9W-T<B`B@X:!6X-5EKR"J8-P@UB#CX%;@VB"JI5SEKZ"Q8*W@4(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R"FUS
M9VED(")5;FYA;65D(@IM<V=S='(@(I:SEKPB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I
M;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R
M;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K
M($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H
M:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C
M97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*(H-:@TR#A8.*@V6#0H%;
MC^."S)>=EU*"J8+GD\&,H(+,EK."HH-8@TZ#BH-V@V>"S2!#=70O0V]P>2]0
M87-T92""Q8*K@MR"N8+Q@4(B"B)/2R""\(-.@XJ#8H-.@K>"Z8+&@4&"QX*D
M@N*"P8+$@TZ#BH-B@W:#>X%;@VB"R8-!@TZ#6H-8@K>"Z8*I@L:"HH*D(&UO
M>FEL;&$N(@HB;W)G((+,BUJ/<)6VCY&"\(RI@NF"L8+&@JJ"Q8*K@MR"MX%"
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#<@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C<*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HY,S,*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO
M;B(*;7-G<W1R("*#5(-\@5N#9X*U@L2"HH+(@J**9Y*CCG&"Q8*W(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R("*-
M6)!6(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B)7,@@O"-
M6)!6@K>"Z8%"(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHW-@IM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B@X:!6X-5@O"-6)!6
M@K>"Z2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E<FUS+V5D
M:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L('!H
M<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R(")<(B5S
M7"(@@O"-6)!6@K6"W(*U@KV!0B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R
M("*-6)!6@UB#3H.*@W:#9X+PC>V/G(*U@MR"M8*]@4(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ.3@*;7-G:60@(E5P;&]A9"(*;7-G<W1R("*#08-B@W:#
MC8%;@V@B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5
M<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E
M<G9E<BXB"FUS9W-T<B`BD5."Q(+,@T&#=H.*@U"!6X-6@X>#DX+,D-V2Z(-T
M@T"#0X.+@O"#5(%;@V^"R8-!@V*#=H.-@5N#:(*U@MR"M8*]@4(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(H.)@V6#
MDY6VCIJ!:9'EE;:.FH%J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@
M;G5M8F5R<R(*;7-G<W1R("*#C8%;@WV0E(Z:@6F1Y96VCIJ!:B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B@T6#BX-/@T&#0Y.,
ME?N+I)AAC9$B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-
M86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N
M=#H@)7,B"FUS9W-T<B`BC+N-W8+,DFR"\(YGEW"!1B5S(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@
M(E5S92!34TPB"FUS9W-T<B`B4U-,((+PCF>7<"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,C<*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES
M(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(DE-4U`@@U2!
M6X-O@LR#AH%;@U66O(%>@W"#6(./@5N#:(*JB-F"R(+IC^J-AX+)CF>7<(*U
M@MR"MX%"(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR
M,0IM<V=I9"`B57-E<B(*;7-G<W1R("*#AH%;@U4B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<W-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T
M<B`B@X:!6X-5("5S((+-("5S((+%E$:/V(*S@NJ"Q(*B@MR"N8+Q@4(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B@X:!6X-5BL>7G2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,C0U"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B
M@X:!6X-5@TF#=H-6@X>#DR(*"B,Z('-I9VYU<"YP:'`Z-C(*;7-G:60@(E5S
M97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(H.&@5N#59-OF%XB"@HC.B!S:6=N
M=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D
M:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R("*#AH%;@U6"S)-OF%Z"
MS8*Q@LR#5(-#@V>"Q8+-B]:.?H*S@NJ"Q(*B@MR"MX%"(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C0V.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F
M;W5N9"(*;7-G<W1R("*#AH%;@U6!6X-!@TJ#18.3@V>"JH*@@NB"W(*Y@O&!
M0H%"(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I
M=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS
M9W-T<B`B@X:!6X-5EKPB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<
M(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B@X:!6X-5EKP@7"(E<UPB((+-
MBOF"R8*@@NB"W(*W@4(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R("*#AH%;@U66O#HB"@HC
M.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5<V5R;F%M
M93H@(@IM<V=S='(@(H.&@5N#59:\.B`B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*
M;7-G<W1R("*#5H-8@V6#@)*&@LR#AH%;@U6!1B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*
M;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B@T6#68-X@TR#6(->@Y.+I)AA
MC9$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-S`@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8R"FUS9VED(")61E,@9&ER96-T;W)Y
M(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3(P"FUS9VED(")686-A=&EO;B(*;7-G<W1R("*+>(G)
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8S"FUS9VED(")686QI
M9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(")686QI
M9&ET>2(*;7-G<W1R("*73(SXD*LB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN
M(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C@U,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<T
M"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM
M=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C0Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C,*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q,R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.3`W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T
M86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`V(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q.#,*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM<V=S='(@
M(H-O@VN#08-CBZ2888V1(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(S,PIM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(H-X@VR#68-'@XF!18-[
M@XJ#;X.+BZ2888V1(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE
M<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R("*,
MGX_8CKB4<R`M((*Q@LR#@8-B@UJ!6X-7@LV)_.*"@K."ZH+$@J*"Z8+F@J2"
MQ8*W@4(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P
M,0IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R("*4Q2(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR,C@*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G
M<W1R("*#;X%;@U>#AX.3BL>7G2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L
M:6=N(@IM<V=S='(@(H]CB,J2=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")6
M97)Y($AI9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FEE
M="!.86TB"FUS9W-T<B`B@WB#9X-I@X".T(GOCN6+8(NDF&&-D2(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DW"FUS9VED(")6:65T;F%M97-E("A625-#
M24DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.CDV.0HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S
M='(@(B5S((+PC*F"Z2(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G
M:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T<B`BBD^5E(+,
M('=E8B"#>8%;@U>"\)5<CJ8B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L
M86YD<RP@0G)I=&ES:"(*;7-G<W1R("*)<)?,@V^!6X-7@Y./E).'(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T
M<B`BE<27S(-O@5N#5X.3CY23AR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C$V"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-3(*;7-G:60@(E9I<VEB:6QI='DZ("(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I
M=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--
M5%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]612!30U))4%0@34%.
M54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%144"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U
M='5N82(*;7-G<W1R("*#18-(@XJ#6(%%@W2#9X-$@5N#:8^4DX<B"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S
M=&%T=7,N<&AP.C(Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT
M;6PN<&AP.C$R-R!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@(E=A
M<FYI;F<B"FUS9W-T<B`BC'B-D"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(I"%(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T
M:&5R($9O<F5C87-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HT,38*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.#D*
M;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0S.0IM<V=I9"`B5V5B(%-I=&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H
M<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(I:(CU0B"@HC.B!S97)V:6-E
M<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R
M("*"YH*D@K&"NR(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(B5S((+)@N:"I(*Q@KLB"@HC
M.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R
M=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@
M)7,B"FUS9W-T<B`B)7,@@K."\8%!@N:"I(*Q@KLB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y.`IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3D*;7-G:60@(E=E
M<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM
M<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`BD+R#5(-N@XDB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G
M:6X_(@IM<V=S='(@(B5S@XV#3X-#@Y.,XX+'@LR#08-V@XJ#4(%;@U:#AX.3
M@O"57(ZF@K6"W(*W@JF!2"(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R
M/R(*;7-G<W1R("*+YI#8@NB5MHZ:@LV)O8+%@K>"J8%((@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U
M;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`BB/B7<)6VCIJ"S8F]@L6"MX*I@4@B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V
M-0IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S8*;7-G:60@
M(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D
M:71O<BXB"FUS9W-T<B`B@V6#3(-8@V>#1X-F@T*#7H%;@LR#=H.)@T^#0X.3
M@O"129'P@K6"W(*W@4(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R("*5
MG2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#0*;7-G:60@(E=I
M9'1H(&EN($-34R!U;FET<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S8Q"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H
M92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L
M;V<M:6XI.B(*;7-G<W1R("*-MH+)DG6"K25S@X&#:H.%@5N"S)6=@6F.GXGQ
M@LR#C8-/@T.#DX*I@N>73(SX@6HZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T
M86)L92(*;7-G<W1R("*57(+,E9TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G
M<W1R("*5G8+,DE"(RB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`BE9V!1B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,34*;7-G:60@(E=I:VDB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X
M.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I
M9"`B5VEN9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@W"FUS9VED(")7:6YD('-P965D
M(&EN(&MN;W1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,38S"FUS9VED(")7:6YD.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y.`IM<V=I
M9"`B5VES:&QI<W0B"FUS9W-T<B`BEWZ"M8*B@N""S(CJEY<B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-`HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS
M9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`BB\Z6L9#F@LR/6H^*(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I
M9"`B5V]R:R!0:&]N92(*;7-G<W1R("*+SI:QD.:"S)-DF&*4U(V&(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3DS(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N
M=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N
M9"`E9"XB"FUS9W-T<B`B)60@C7.6VH+%BM2(X8+!@KV-@);:D)2!0I"S@K6"
MK8+-("5D@4&.=Y+H@K."ZH*]@LR"S2`E9(%"(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG
M(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS
M9W-T<B`BBM2(X8+!@KV-@);:D)2!0I"S@K6"K8+-("5D@4&.=Y+H@K."ZH*]
M@LR"S2`E9(%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3(Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R
M96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(E9&4X-T@T"#0X.+@LR3QX+=
MCV^"M9*&@LF5<Y"S@LB#28-T@UJ#8H-G("5D((*JCG>2Z(*S@NJ"W(*U@KV!
M0B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#4*;7-G:60@(E@M
M4F5F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS
M9W-T<B`B6#4P.78S((KNEGN0IXS`(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@
M57-A9V4B"FUS9W-T<B`B6#4P.78S((RNCF>7<)9`(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J
M96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B6#4P.78S(([ED<R.TH+,
ME<J6O"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV
M"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R
M(")8-3`Y=C,@CN61S([2@LR,KHZOE<J.<2(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C@S"FUS9VED(")8-3`Y=C,@97AT96YS:6]N
M<R(*;7-G<W1R(")8-3`Y=C,@BF>2HXM`E%PB"@HC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`BE$XB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$T"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-38*;7-G:60@(EE965DB"FUS
M9W-T<B`BE$XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$Q,0IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED
M(")996%R;'DB"FUS9W-T<B`BEHB43B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@
M(EEE;65N(@IM<V=S='(@(H-#@T>#@8.3BZ2888V1(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-@IM<V=I9"`B665S(@IM
M<V=S='(@(H+-@J(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(I.O
MB-."M8+<@K<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T
M:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS
M9W-T<B`BC:&"S8-E@TR#6(-G@X*!6X-H@L6"MX%"6SP^78-[@UZ#DX+%5UE3
M25=91X."@5N#:(+)EM^"Z(+<@K>!0B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z,C,V"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E
M9"!B;&]C:W,N(@IM<V=S='(@(B5D((C(C^."S(-U@XV#8H-.@O"-[)"L@K>"
MZ8*Q@L:"S8N6B<*"LX+J@L2"HH+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-#(T"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT
M:6-A=&5D+B(*;7-G<W1R("*"H(+(@KV"S91&C]B"LX+J@L2"HH+<@KF"\8%"
M(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#@*;7-G
M:60@(EEO=2!C86YN;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U
M<B!F=6QL(&YA;64N(@IM<V=S='(@(I:\D4^"S)*&@LD@)UQ<)R""QH*B@J25
MMHZ:@LV.9X*F@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#4R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S(*;7-G:60@(EEO
M=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T
M<B`BETR,^(+(DV2.<8.!@5N#BX-!@VB#C(-8@L6"S8*@@NB"W(*Y@O&!0B(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE
M(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*
M(FEN("5S+B(*;7-G<W1R("(B"B*#0X.3@WR!6X-G@K."ZH*]@W2#0(-#@XN"
MS(-T@T*!6X.+@VB"\"5SD^""S)'.B9Z"MX+I@W2#0H%;@XN#:(+)@WV#8H-V
M@K6"Q(+<(@HB@KF"\2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.#<*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B
M@XV#3X-!@T6#9X*U@MR"M8*]+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R-3@*;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@
M8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA
M;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX
M+B(*;7-G<W1R("(B"B*0LX*U@J*39)ABE-2-AH+PD_R7S8*W@NF"YH*D@LF2
MC8C3@K6"Q(FZ@K."HH%"D)2.FH*^@J^"JHYGEW""Q8*K@MR"MX*J@4&-D8W;
M(@HBDV288H+(@N>0YI.J@LF!>X+PE72"KX+<@K>!0B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Q.#4*;7-G:60@(EEO=2!H879E('1O(&5N=&5R
M(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(I"S@K6"HI)L@O"3_)?-@K6"Q(FZ
M@K."HH%"(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W
M"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD
M('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("(B"B*#5(-#@Y.#08-B@W:"\)>8
MEW""MX+I@KV"WX+)@LT@1&%T851R964@@V^#8H-.@T>#DX-H@O"0W9+H@K>"
MZ95+EW:"JH*@@NB"W"(*(H*W@4(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C0W,0IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A
M8VME;F0N(@IM<V=S='(@(E9&4R"#;X-B@TZ#1X.3@VB"\)#=DNB"MX+IE4N7
M=H*J@J""Z(+<@K>!0B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B
M969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T
M<B`BC^&*48+,D^"798+PBTR/<8*U@L2"J8+G@4&/X8I1@XR#?(%;@V>"\)&7
MD$V"M8+$@JV"OH*S@J*!0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!5
M4DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R("*"L8*Q@LF#
MBH.3@TZ"MX+I55),@O"3_)?-@K6"Q(FZ@K."HB(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@
M<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(HWMCYR"MX+I@U2!6X-O
M@O".=Y+H@K6"Q(*M@KZ"LX*B@4(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*
M;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O
M=70N(@IM<V=S='(@(H_!BXZ"MX+I@X:!6X-5EKR"\(YWDNB"M8+$@JV"OH*S
M@J*!0B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`BC>V/G(*W
M@NF#AH%;@U66O(+PCG>2Z(*U@L2"K8*^@K."HH%"(@H*(SH@861M:6XO=7-E
M<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM
M<V=S='(@(I+'B<&"MX+I@X:!6X-5EKR"\(YWDNB"M8+$@JV"OH*S@J*!0B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R("*-6)!6@K>"Z8.&
M@5N#59:\@O".=Y+H@K6"Q(*M@KZ"LX*B@4(B"@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P
M96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`BCL"-<X*W
M@NF#08-.@U:#AX.3@O".=Y+H@K6"Q(*M@KZ"LX*B@4(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B
M66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R("*0
M5H*U@J*5JI?>EKR"\)/\E\V"M8+$B;J"LX*B@4(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B
M66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D
M+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(B5S((-:@V*#5H.'@Y."
MS)=,C/B*^HS`@JJ0V(+J@L2"HH+<@K>!0H.-@T^#0X.3@K62O(*U@L2"K8*^
M@K."HH%"(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*
M;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R("*39(YQ@X&!6X.+
M@T&#:(.,@U@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$U"FUS9VED
M(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(H*@@LB"O8+,($9R;VTZ
M((-!@VB#C(-8(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR"FUS9VED(")9;W5R($EN9F]R
M;6%T:6]N(@IM<V=S='(@(H*@@LB"O8+,@T.#DX-T@TB#@8%;@U:#AX.3(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S
M:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB
M<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB
M"FUS9W-T<B`B(@HB@UJ#8H-6@X>#DR`E<R""S(K4@LF"H(+(@KV"S(-!@VB#
MC(-8@JJ5SXU8@K."ZH+<@K6"O8%"@UJ#3(.%@XJ#98-"@5N5VXSL@LR"O2(*
M(H+?@LF#C8-/@T.#DX*UDKR"MX+7@JN"Q8*W@4(B"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.86UE(@IM<V=S
M='(@(H*@@LB"O8+,EKR13R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M861D+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H
M('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L
M('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B
M86-K96YD+B(*;7-G<W1R("(B"B*"L8+,E$:/V(-O@V*#3H-'@Y.#:(+%@LV!
M08.&@5N#58+,DL>)P8*J@U2#?(%;@V>"LX+J@L2"HH+<@KF"\8%"@N""M2!(
M;W)D92""Q2(*(H.&@5N#58-!@TJ#18.3@V>"\(K'EYV"M8*]@J*"S(+(@N>!
M09&\@LR41H_8@V^#8H-.@T>#DX-H@O".9X*D@M>"JX+%@K>!0B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U
M<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES
M=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L
M960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"B*"L8+,E$:/
MV(-O@V*#3H-'@Y.#:(+%@LV!08.&@5N#58+,@XJ#6(-G@JJ#5(-\@5N#9X*S
M@NJ"Q(*B@LB"HH*I@4&"H(+I@J*"S8F](@HB@N>"J8+,EYV74H+%@K&"S(M`
ME%R"JI:SC/B"R8+(@L&"Q(*B@MR"MX%"(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z.3@S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O
M=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN
M:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E
M8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB@UJ#
M8H-6@X>#DR`E<R""S(K4@LF"H(+(@KV"S(-U@XF#18-5@JJ5SXU8@K."ZH*]
M@N:"I(+(@LR"Q8%!@UJ#3(.%@XJ#98-"@5N5VR(*(HSL@LR"O8+?@LF#C8-/
M@T.#DX*UDKR"MX+7@JN"Q8*W@4(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H
M<#HU-PIM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI
M<R!F96%T=7)E+B(*;7-G<W1R("*"J(YG@J*"S(-U@XF#18-5@LV"L8+,BT"4
M7(+P@U2#?(%;@V>"M8+$@J*"W(*Y@O&!0B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E
M<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O
M;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@HB@JB.9X*B
M@LR#=8.)@T6#58+-@K&"S(CSC?R#28-V@U:#AX.3@O"#5(-\@5N#9X*U@L2"
MHH+<@KF"\8%"0V]N=')O;"]#;VUM86YD("(*(BL@4"""Q8CSC?R"M8+$B;J"
MLX*B@4(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8Q"FUS9VED(")9
M;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R("*#7H-#@X"#78%;@Y.!
M1B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,3<*;7-G:60@(EEO=7(@9&5F
M875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R("*"H(+(
M@KV"S(-F@W2#2(.+@V=)1(+-E<^-6(*S@NJ"W(*U@KV!0B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-C$*;7-G:60@(EEO=7(@9&5F875L="!I9&5N
M=&ET>3HB"FUS9W-T<B`B@J""R(*]@LR#9H-T@TB#BX-G240Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(P-`IM<V=I9"`B66]U<B!F=6QL(&YA;64Z
M(@IM<V=S='(@(H*@@LB"O8+,CH&6O"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDY.0IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS
M9W-T<B`B@XV#3X-#@Y."S8KZC,"0V(+J@L6"MX%"(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U
M<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R("*05H*U@J(@
M)7,@EW""S(-P@UB#CX%;@VB!1B5S(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@
M=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS
M9W-T<B`B@J""R(*]@LR#28-V@U:#AX.3@LV,NXW=@LR#6H-B@U:#AX.3DH:"
MR97/C5B"LX+J@MR"M8*]@4(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A
M=&5D+B(*;7-G<W1R("*#28-V@U:#AX.3@O"-6)!6@K6"W(*U@KTB"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S
M=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R("*#<(-8@X^!6X-H@LV#BH-:
M@V*#9X*S@NJ"W(*U@KV!0B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T
M+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B
M"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HB@W"#6(./@5N#:(+-@XJ#6H-B@V>"
MLX+J@MR"M8*]@LR"Q8%!D%:"M8*B@W"#6(./@5N#:(+%@XV#3X-#@Y."M8+$
M@MV"Q(FZ@K,B"B*"HH%"(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M-S,S"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R
M("*#<(-8@X^!6X-H@JJ*^HS`D-B"ZH+%@K>!0B(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R
M<SHB"FUS9W-T<B`B@XJ#@H%;@V>#5(%;@V\Z(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R("*#AH%;@U.#6(.)@W*#
M02(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@
M(EIA:7)E(@IM<V=S='(@(H-5@T.!6X.+BZ2888V1@6F#4H.3@U.6KX[EBZ28
M88V1@6HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T<B`B
M@U6#DX-R@T&+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W
M92(*;7-G<W1R("*#5X.3@V^#=8-'BZ2888V1(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z
M,3<T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R
M"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<')O8FQE;2YP:'`Z.#D*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB
M"FUS9W-T<B`B@6V/X8I1E?&-D(%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT
M("TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E
M<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(P-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B6XUS.B5S+R5S72(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34U-"!T96UP;&%T97,O
M<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B7T&*QY>=(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A=&%4
M<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS
M9W-T<B`B7T2-<X+PC>V/G"(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B
M7T=R;W5P<R(*;7-G<W1R(")?1X-/@XN!6X-V(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`B
M7TB#=X.+@W8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN
M(@IM<V=S='(@(E])B>:1G(-V@XV#<(-E@T(N+BXB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM<V=S
M='(@(E],@XV#3X-#@Y,B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N
M=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*;7-G<W1R(")?3(.-@T^#08-%
M@V<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R(")?
M38.*@Y.#3I7/C5@B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP
M:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R(")?3X-)@W:#5H.'@Y,B
M"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G
M<W1R(")?4(-!@TZ#6H-8C*`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN
M:RXN+B(*;7-G<W1R(")?4H.*@Y.#3HWMCYPB"@HC.B!L:6(O87!I+G!H<#HQ
M,C4*;7-G:60@(E]3971U<"(*;7-G<W1R(")?4X-:@V*#9X-!@V*#=B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B7U25
M7)&ND*LB"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G
M<W1R(")?58.&@5N#52(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3(U"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B@T&#:(.,@UB2H"(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,T"FUS9VED
M(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R("*5<Y:^@LB#08-H@XR#6"(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$W"FUS9VED(")C86QE
M;F1A<B(*;7-G<W1R("*77)+HE5PB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$W.2!L:6(O0FQO8VLO;65T87(N<&AP.C,V-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")C86QM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F
M:6QE(@IM<V=S='(@(H]OE\V#=(-`@T.#BX*JC>R0K(+%@JN"W(*Y@O$B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B
M8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T<B`BD_R7S8-T@T"#0X.+@JJ*2H*O
M@MR"N8+Q(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M-3DX"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(H*Q@K&"\(-.@XJ#8H-.
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G
M:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R("*#4H-]@Y.#
M:(USCF>7<(+,@T>#B8%;(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-S@*;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T
M<B`BD-V2Z(-'@XF!6R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG
M(@IM<V=S='(@(H]DEW:"R(-6@UB#98.`@W2#0(-#@XN"S(R'EXXB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T
M82!F;W)M870@97)R;W(B"FUS9W-T<B`B@V:!6X->C&".KH-'@XF!6R(*"B,Z
M('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,S`*;7-G:60@(F5D:70B"FUS
M9W-T<B`BE=*/5R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3@R"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`BC8"6VH*J
M@J""Z(+<@KF"\2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C<S"FUS9VED(")F86QL:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y.`IM<V=I9"`B9FEL92(*;7-G
M<W1R("*#=(-`@T.#BR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@Q(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S8W(&QI8B]";&]C:R]M971A<BYP:'`Z,SDS
M"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@
M)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(S.0IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4P"FUS9VED(")H.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S4Y"FUS9VED(")H:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO
M=VXB"FUS9W-T<B`B@WJ#6(-GEKR"JI5SEKXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(FEM
M;65D:6%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV
M-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38R
M"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`BD_R/;Y?-@T>#
MB8%;(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#8*
M;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(H-<@W2#
M9X-%@T:#09/@E92"S(-'@XF!6R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N
M<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D
M92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<P"FUS9VED(")M;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(X
M-2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HR-#$*;7-G:60@(FYA;64B"FUS9W-T<B`B
MEKR13R(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C0*;7-G:60@(FYO
M="!I;7!L96UE;G1E9"(*;7-G<W1R("*.P)&5@K."ZH+$@J*"W(*Y@O$B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,C`*;7-G:60@
M(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`B@MR"OH[`D96"LX+J@L2"
MHH+<@KF"\2(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`Y"FUS
M9VED(")N;W1E<&%D(@IM<V=S='(@(H.!@X*2H"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E
M<F-E;G0B"FUS9W-T<B`B@W"!6X-:@Y.#9R(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E;FEE
M9"(*;7-G<W1R("*#08-.@UJ#6(+-BY&4VX*S@NJ"W(*U@KTB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS
M9VED(")P:7AE;',B"FUS9W-T<B`B@W.#3H-:@XLB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R<F]R
M(&EN('!R;W1O8V]L(@IM<V=S='(@(H.*@X*!6X-G@L6"S(-V@XV#9X-2@XN#
M1X.)@5LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW-0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V:6-E('5N879A
M:6QA8FQE(@IM<V=S='(@(H-4@5N#<H-8E7.47"(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z,3`Q"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S
M='(@(HVWE:J"\)5<CJ8B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HS.#<*;7-G:60@(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<T"FUS9VED(")S=&5A9'DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R("*#5H-8@V6#@(-'
M@XF!6R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,S"FUS9VED
M(")T87-K(&QI<W0B"FUS9W-T<B`B@UZ#6(-.@XJ#6(-G(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R
M>2!F86EL=7)E(@IM<V=S='(@(HCJCIZ328+(@T>#B8%;(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W
M,`IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*
M;7-G<W1R("**;91&@LR"O8+?@W"#6(./@5N#:#*3>)/\E\V"M8+$B;J"LX*B
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G
M<W1R("*6LY:\(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,S4*;7-G:60@(G9#87)D(@IM<V=S='(@(G9#87)D(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T,@IM<V=I9"`B=SHB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G
M:60@(G=E871H97(N8V]M(@IM<V=S='(@(B(*````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!O+VMM7TM(+G!O````````````````````````````````````````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`V-#`W,C0`,3`U,34T,S,W-30`,#$W-C0S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````",@4T]-12!$
M15-#4DE05$E612!4251,12X*(R!#;W!Y<FEG:'0@*$,I(%E%05(@2&]R9&4@
M4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@
M<V%M92!L:6-E;G-E(&%S('1H92!004-+04=%('!A8VMA9V4N"B,@3&5A;F<@
M0VAU;7-O8F5N(#QS;V)E;D!K:&UE<F]S+FEN9F\^+"`R,#`V+@HC"FUS9VED
M("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!)35!<;B(*(E!/
M5"U#<F5A=&EO;BU$871E.B`R,#`T+3$R+3`X(#$P.C(X*S`Q,#!<;B(*(E!/
M+5)E=FES:6]N+41A=&4Z(#(P,#4M,#8M,34@,3$Z-3,K,#<P,%QN(@HB3&%S
M="U4<F%N<VQA=&]R.B!,96%N9R!#:'5M<V]B96X@/'-O8F5N0&MH;65R;W,N
M:6YF;SY<;B(*(DQA;F=U86=E+51E86TZ($MH;65R(#QS=7!P;W)T0&MH;65R
M;W,N:6YF;SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y
M<&4Z('1E>'0O<&QA:6X[(&-H87)S970]=71F+3A<;B(*(D-O;G1E;G0M5')A
M;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G
M;RDB"FUS9W-T<B`B("@E<R#AGI#AGY+AGH3AGX/B@(OAGH#AGI/AGY+AGIOA
MGH3B@(OAGI'AGX4I(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M,S@V"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G
M<W1R("(@*.&>@N&?DN&>FN&>MN&>E.&?B^*`B^&>A>&>N^&>A>*`B^&>E>&?
MDN&>F^&>O.&>G.*`B^&>@.&>MN&>C^&?BR`E<RDB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S@U"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@
M)7,@9&%Y<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,X,0IM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B("CAGI#AGY+AGH3A
MGX/B@(OAGI/AGX'AGX<I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,X,PIM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B("CAGI#AGY+AGH3A
MGX/B@(OAGI_AGY+AGJ+AGX+AGH`I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,W.0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B`HX9Z8
MX9^2X9Z?X9ZWX9Z;X9Z8X9^)X9ZWX9Z)*2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-3`@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,U,PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDY"FUS9VED
M("(@870@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D
M:7)E8W1O<GDN(@IM<V=S='(@(EPB)7-<(B#AGICAGK?AGI/B@(OAGICAGX+A
MGI/B@(OAGH?AGK;B@(OAGI#AGH_B@(OAGJ'AGK[AGIG"H.&?E"(*"B,Z(&9R
M86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B7"(E<UPB
M(.&>F.&>M^&>D^*`B^&>F.&?@N&>D^*`B^&>A^&>MN*`B^&>A^&>F.&?DN&>
MFN&>ON&>G^*`B^&>C^&?DN&>FN&>N>&>F.&>C^&?DN&>FN&>O.&>G.*`B^&>
MH>&>ON&>F<*@X9^4(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES
M=')Y+G!H<#HW,#,*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y
M+G!H<#HQ,#<R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@
M8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE('!E
M<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR
M9B4E*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C,Q"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G
M<W1R("(E9"`E<R#AGI/AGK?AGH0@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C(V-R!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L
M('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R
M9"!E>'!I<F5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C<X"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E
M8V%S="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0R(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T.`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@T,"!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HX-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@34(B
M"FUS9W-T<B`B)7,@X9Z8X9^!X9Z`X9ZVX9Z4X9^#(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA
M:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR
M-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#,R(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z-#DT"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M-C@R(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4P"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$W,2!L:6(O0FQO8VLO;65T87(N<&AP.C$W
M-R!L:6(O0FQO8VLO;65T87(N<&AP.C(U,0HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,U-R!L:6(O0FQO8VLO;65T87(N<&AP.C,V,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M
M86EN=&5N86YC92YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@
M:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E
M<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S0X"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDX"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@
M)7,@;V8@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O
M;VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(E<R#AGY8@
M)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HQ
M,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M
M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O
M9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN
M9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4W
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#(*;7-G:60@(BP@9W5S
M=&EN9R`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#`@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C$S"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O
M;2`E<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(Y-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T
M.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<W(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q,S8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C<T-@IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@
M(BTM(.&>A^&?DN&>FN&>ON&>GR`M+2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HR-0IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`BX9Z1X9^2X9Z:
MX9Z$X9^+X9Z1X9^2X9Z:X9ZVX9Z9(.&?H>&?HB#AGICAGXGAGX3AGH0B"@HC
M.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C0*;7-G:60@(C(T($AO=7(@1F]R;6%T
M(@IM<V=S='(@(N&>D>&?DN&>FN&>A.&?B^&>D>&?DN&>FN&>MN&>F2#AGZ+A
MGZ0@X9Z8X9^)X9^$X9Z$(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z
M,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(N&?HN&?I"#AGICAGXGAGX3A
MGH0B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y"FUS9VED("(\
M4')E=FEO=7,B"FUS9W-T<B`B/.&>F.&>N^&>DR(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3,Q"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q
M=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,38R"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA
M<R!O8V-U<G)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO
M261E;G1I='DN<&AP.C0P-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!(&UE
M<W-A9V4@:&%S(&)E96X@<V5N="!T;R!<(B5S7"(@=&\@=F5R:69Y('1H870@
M=&AI<R!I<R!R96%L;'D@>6]U<B`B"B)A9&1R97-S+B!4:&4@;F5W(&5M86EL
M(&%D9')E<W,@:7,@86-T:79A=&5D(&%S('-O;VX@87,@>6]U(&-O;F9I<FT@
M=&AI<R`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@
M:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C@*;7-G:60@
M(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG
M;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$P.3D*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$V"FUS9VED("(B"B)!('!U
M8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#8*;7-G
M:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@
M82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME
M>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U
M8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B
M04T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3
M:&]W97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC
M.C(Y"FUS9VED(")!32]032(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)
M1"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,PIM<V=I9"`B06)O
M=70N+BXB"FUS9W-T<B`BX9ZBX9^&X9Z6X9ZXXH"++BXN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S
M8F]T=&]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!
M8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@
M(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"FUS9VED(")!8V-O=6YT($EN
M9F]R;6%T:6]N(@IM<V=S='(@(N&>EN&?D.&>C^&?C.&>F.&>MN&>D^*`B^&>
MHN&?AN&>EN&>N.&>@N&>CN&>D^&>N"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW.`IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"FUS9VED(")!8V-O=6YT:6YG(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X
M('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B061D(@IM<V=S='(@
M(N&>E.&>D^&?DN&>D.&?@N&>F"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY
M."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY"FUS9VED(")!9&0@
M0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS
M9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,30W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I
M;VX@=&\@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P
M"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-`IM<V=I9"`B061D
M(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D
M('!A:7(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-
M;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D<F5S
M<R!B;V]K.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O
M;VLB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D
M9"!U<V5R(@IM<V=S='(@(N&>E.&>D^&?DN&>D.&?@N&>F.*`B^*`B^*`B^&>
MHN&?DN&>D^&>@.*`B^&>E.&?DN&>FN&>OB(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T
M:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU
M<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP
M:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H
M92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN
M9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T-#D*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`BX9ZBX9ZV
MX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$T.`IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(N&>G^&?
M@.&>G.&>E^&?A>*`B^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>DR(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS9VED
M(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R
M<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB
M"FUS9W-T<B`BX9Z`X9ZVX9Z:XH"+X9Z"X9^2X9Z:X9Z4X9^+XH"+X9Z"X9^2
MX9Z:X9Z$(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U-PIM<V=I
M9"`B061S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES
M=&%N(@IM<V=S='(@(N&>HN&>MN&>H.&?DN&>@N&>MN&>D^&>N.&>G^&?DN&>
MD.&>MN&>DR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B
MX9ZBX9ZVX9Z;X9^+X9Z4X9ZVX9Z3X9ZX(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B
M06QG97)I82(*;7-G<W1R("+AGJ+AGK;AGIOAGXOAGJ#AGY+AGI_AGX'AGIKA
MGK@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R("+AGHCAGY+AGICAGX3AGX?B@(OA
MGH#AGY+AGIOAGX+AGH3AGH#AGY+AGIOAGK;AGIDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED(")!
M;&EG;B(*;7-G<W1R("+AGH_AGICAGY+AGIKAGKGAGI@B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG
M;FUE;G0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY
M,@IM<V=I9"`B06QL(@IM<V=S='(@(N&>D>&>MN&?AN&>A.*`B^&>HN&>G^&?
MBR(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C`W('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A
M=&5D(%5S97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@
M861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY,2!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U"FUS9VED(")!;&P@
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@
M<VED97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3@W.0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S@*;7-G:60@(D%L;&]W
M('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4Q.`IM<V=I
M9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$R-@IM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q,0IM<V=I9"`B
M06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4P,PIM<V=I9"`B06QT97)N871E($E-4U`@57-E
M<FYA;64B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z,S4*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@
M(N&>E.&?DN&>BN&>O.&>FN*`B^&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>
MD^*`B^&>HN&?BN&>N.&>F.&?@N&>FR(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(N&>
MG^&>MN&>F.&>O.&>HN&>MB#AGJ+AGK;AGICAGX'AGIKAGK?AGH`B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A
M<R!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-C`*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C
M8W5R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%N9&]R<F$B
M"FUS9W-T<B`BX9ZBX9Z$X9^+X9Z*X9Z\X9Z:X9^)X9ZV(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.`IM<V=I9"`B06YG;VQA(@IM<V=S='(@(N&>HN&>A.&?B^&>H.&?DN&>@N&?
MA.&>H>&>MB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@
M(N&>HN&>A.&?B^&>H.&?DN&>G^&?BN&>N.&>H>&>MB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X
M>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT
M.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@
M(D%N=&%R8W1I8V$B"FUS9W-T<B`BX9Z7X9ZVX9Z"XH"+X9Z!X9ZVX9Z$XH"+
MX9Z/X9^2X9Z4X9Z\X9Z$(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A
M;F0@0F%R8G5D82(*;7-G<W1R("+AGJ+AGH3AGXOAGI'AGKCAGJ#AGY+AGH+A
MGK8@X9Z3X9ZWX9Z$(.&>E.&>MN&>E.&?BN&>N^&>F>&>BN&>MB(*"B,Z(&%D
M;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S+V%D
M;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS
M9W-T<B`BX9Z`X9Z8X9^2X9Z8X9Z<X9ZWX9Z2X9ZX(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P
M<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA
M<F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T,"!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX-#(*;7-G:60@(D%P<')O>&EM871E(%-I
M>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(N&>F.&?@>&>G^&>
MMB(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Q"FUS9VED(")!<F%B:6,@
M*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`BX9ZBX9ZVX9Z:X9^)X9ZVX9Z4X9^+
M("A7:6YD;W=S+3$R-38I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M-S@*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C<W"FUS9VED(")!<F-H:79E($YA;64B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E
M=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@
M/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T
M92YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R
M("+AGJ+AGK;AGJ#AGY+AGI_AGH3AGXOAGI'AGKCAGI,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W
M"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(N&>HN&>MN&>F.&?@>&>D^&>N"(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<R"FUS9VED(")!<FUE;FEA;B`H
M05)-4T-)22TX*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S,*;7-G:60@(D%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED
M(")!<G5B82(*;7-G<W1R("+AGJ+AGK;AGIKAGKSAGI3AGK8B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L
M86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM
M<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(Y"FUS9VED
M(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$P-@IM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@
M=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T
M;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP
M="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,PIM<V=I9"`B071T<FEB=71E
M<R(*;7-G<W1R("+AGH+AGKOAGH[AGIOAGH#AGY+AGH'AGH[AGX@B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B
M075G=7-T(@IM<V=S='(@(N&>G^&>N.&>H.&>MB(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G
M:60@(D%U<W1R86QI82(*;7-G<W1R("+AGJ+AGKSAGI_AGY+AGH_AGY+AGIKA
MGK;AGIOAGK@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S='(@
M(N&>HN&>O.&>D>&?DN&>FN&>N.&>GR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER<W%L+G!H<#HS,38*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E
M9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S,0IM<V=I9"`B075T:%]C
M>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI
M=&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HR,S0*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]F='`N<&AP.C4V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER
M960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@
M=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`T"FUS9VED(")!=71H7VEM
M87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,PIM<V=I
M9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,S`Q"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@
M<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4V"FUS9VED(")!=71H
M7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C
M=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HY,@IM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,
M1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,X"B,L('!H<"UF;W)M870*;7-G
M:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES
M('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E
M('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HT,#0*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@
M:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HV,@IM<V=I
M9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H
M<#HX-@IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O061M:6XN<&AP.C$P-@IM<V=I9"`B075T:&5N=&EC871I;VX@
M870@24U!4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@
M(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R("+AGH#AGK;AGIKB@(OA
MGI7AGY+AGI'AGX#AGH3B@(OAGI7AGY+AGI'AGK;AGH_AGXOB@(OAGI?AGK;A
MGI;B@(OAGH_AGY+AGIKAGKGAGICB@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3A
MGK;AGI/B@(OAGI3AGIKAGK;AGH?AGY#AGIDB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ.#(*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#@R
M"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,`IM
M<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U
M"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(N&>HN&>MN&>H.&?DN&>
MG^&?BN&?@N&>FN&>E.&?@N&>H.&?DN&>G^&>A.&?BR(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`BX9Z5X9^2X9Z1
MX9^#XH"+X9Z!X9ZVX9Z$XH"+X9Z`X9^2X9Z:X9^$X9Z9(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C
M:V=R;W5N9"!#;VQO<B(*;7-G<W1R("+AGI;AGH[AGXSB@(OAGI7AGY+AGI'A
MGX/B@(OAGH'AGK;AGH3B@(OAGH#AGY+AGIKAGX3AGIDB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VMR8C4N<&AP.C@R"FUS9VED(")"860@:V5R8F5R;W,@
M<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:W)B-2YP:'`Z.#0*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R("+A
MGI3AGK;AGJ#AGK;AGICAGXGAGK;AGI\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"
M86AR86EN(@IM<V=S='(@(N&>E.&>MN&>FN&?B>&?@N&>DR(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3<S"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM
M<V=S='(@(N&>E.&>A.&?B^&>@.&?DN&>F^&>MN&>BN&?@>&>G^&?DN&>H"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(N&>E.&>MN&>
MFN&>E.&>MN&>BN&>O.&>GR(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S(&1I<F5C=&]R
M>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A
M<V5L:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B
M"FUS9W-T<B`BX9Z4X9^!X9ZAX9ZVX9Z:X9Z[X9Z?X9^2X9Z?(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,`IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R("+AGI3AGX+AGIOB@(OAGJ#A
MGY+AGI_AGXKAGK?AGH`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QI>F4B"FUS
M9W-T<B`BX9Z4X9^!X9Z;X9ZXX9Z@X9^2X9Z?(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0F5N:6XB"FUS9W-T<B`BX9Z4X9^!X9Z.X9ZVX9^&X9Z$(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R("+AGI3AGXKAGX'AGIKAGICA
MGKSAGHKAGK8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B
MX9Z4X9^*X9Z\X9Z/X9ZVX9Z3(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B
MX9Z0X9^2X9Z$X9^#X9Z`X9^&X9Z.X9Z^X9Z/(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N
M:6YC.CDP"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S(*;7-G:60@(D)L;V-K(%1Y
M<&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(N&>BN&>M^&>CR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`BX9Z4X9Z\X9Z;
MX9ZXX9Z<X9ZX(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R,0IM
M<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(N&>@.&>D^&?DN&>F^&?@N&>A.*`
MB^&>A>&?AN&>CN&>MN&?AB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*;7-G:60@(D)O<F1E<B(*;7-G<W1R
M("+AGI_AGXKAGKOAGI@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(Q"FUS9VED(")";W)D97)S(@IM<V=S='(@(N&>G^&?BN&>
MN^&>F.*`BR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G
M;W9I;F$B"FUS9W-T<B`BX9Z4X9Z\X9Z?X9^2X9Z3X9^*X9ZX(.&>D^&>M^&>
MA"#AGJ#AGKKAGJ#AGY+AGI_AGXKAGX'AGJ#AGY+AGH+AGX3AGISAGKCAGH[A
MGK8B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,3`Q"FUS9VED(")";W1H
M(@IM<V=S='(@(N&>D>&>MN&?AN&>A.*`B^&>EN&>N.&>FN*`BR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM<V=S='(@(N&>E.&>N^&>C^&>G^&?
MDN&>G.&>MN&>CN&>MB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(N&>
ME.&>MN&>CR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS
M9W-T<B`BX9Z`X9^$X9^'XH"+X9Z4X9^*X9Z\X9Z<X9^)X9^"(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,@IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(N&>E.&?DN&>FN&?@>&>G^&?
MBN&>N.&>FR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H($EN9&EA;B!/
M8V5A;B!497)R:71O<GDB"FUS9W-T<B`BX9ZBX9ZVX9Z.X9ZVX9Z%X9Z`X9^2
MX9Z:XH"+X9Z?X9Z8X9Z[X9Z1X9^2X9Z:XH"+X9ZEX9Z.X9^2X9Z,X9ZV(.&>
MHN&>A.&?B^&>@N&?DN&>F^&?@>&>GR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R
M=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(N&>E.&?DN&>FN&?BN&>N^&>F>&>
MCN&?@>*`B^&>BN&>MN&>FN&?BN&>N^&>F>&>G^&>MN&>H>&>MN&>F"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(N&>E.&?BN&>N^&>
MF^&>H.&?DN&>@N&>MN&>FN&>N"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S
M='(@(N&>E.&?BN&>O.&>FN&>@N&>N.&>CN&>MN&>H.&?DN&>G.&>MN&>G^&>
MO"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`BX9Z4X9^*
MX9Z\X9Z:X9Z[X9Z3X9Z,X9ZX(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0V,`IM<V=I9"`B0TU3(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R
M(")#4D,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y
M.`IM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-38*;7-G:60@(D-A
M8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#,@8V]N9FEG
M+VAO;VMS+G!H<"YD:7-T.C$P-34*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$V-`IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`BX9Z4X9^2X9Z:X9Z/
MX9ZWX9Z1X9ZWX9Z3(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(T,`IM<V=I9"`B0V%L;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I
M9"`B0V%M8F]D:6$B"FUS9W-T<B`BX9Z`X9Z8X9^2X9Z6X9Z[X9Z'X9ZV(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`BX9Z`X9ZVX9Z8
MX9^)X9ZVX9Z:X9Z\X9Z3(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC
M86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,U,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@
M861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR-#$@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,S,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V%N861A(@IM<V=S='(@(N&>
M@.&>MN&>CN&>MN&>BN&>MB(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI
M;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E
M+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I9"`B0V%N
M8V5L(@IM<V=S='(@(N&>E.&?A.&?A^&>E.&>A.&?BR(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE
M;2!297!O<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HS,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T
M<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@
M=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T
M('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E
M92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP
M.C8Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E+"`E9"!C
M:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4
M<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C(R"FUS9VED("(B"B)#86YN;W0@<F5O
M<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@
M9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@
M;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E
M<F1E(@IM<V=S='(@(N&>@.&>MN&>E.&>G.&?@N&>FB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*;7-G:60@
M(D-A<'1I;VXB"FUS9W-T<B`BX9Z%X9^&X9Z.X9Z$X9Z'X9Z^X9Z$(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS
M9VED(")#87)R:65R(@IM<V=S='(@(N&>G.&>C^&?DN&>D.&>N^*`B^&>BN&>
MN>&>@.*`B^&>A^&>B>&?DN&>A^&>O.&>DR(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,PIM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G
M<W1R("+AGH#AGX3AGX?B@(OAGH#AGX/AGICAGXGAGK;AGI,B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#
M96QL(%!H;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@4')O<&5R
M=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*
M;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(W.`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<T"FUS9VED(")#96QT:6,@
M*$E33RTX.#4Y+3$T*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#96YT97(B
M"FUS9W-T<B`BX9Z`X9Z.X9^2X9Z/X9ZVX9Z;(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I
M9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(N&>G^&>MN&>
MDN&>MN&>FN&>CN&>FN&>BN&?DN&>B^*`B^&>HN&>MN&>H.&?DN&>G.&?DN&>
MFN&>M^&>@.*`B^&>@.&>CN&?DN&>BN&>MN&>FR(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3<U"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U
M.2TR*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,@IM
M<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-E<G1I9FEC
M871E(%!O;&EC:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B
M0VAA9"(*;7-G<W1R("+AGH;AGK;AGHHB"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV
M"FUS9VED(")#:&%N9V4B"FUS9W-T<B`BX9Z5X9^2X9Z;X9ZVX9Z?X9^+XH"+
MX9Z4X9^2X9Z/X9Z\X9Z:(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C,Q"FUS9VED(")#:&%N9V4@66]U<B!087-S=V]R9"(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-CD*;7-G:60@(B(*(D-H86YG
M92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T
M:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G:60@
M(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W
M:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T('EO
M=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6QE(@IM<V=S='(@(N&>
MB.&>N.&>F^&>N"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@
M(N&>A>&>M^&>DR(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED
M(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D-H:6YE<V4@5')A9&ET
M:6]N86P@*$)I9S4I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]A
M<'`N:6YC.C<*;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,0IM<V=I
M9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B0VAO;W-E(&$@=7-E
M<FYA;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P
M,@IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF
M;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I
M9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R("+AGH#AGX3AGX?B@(OAGH+A
MGY+AGIKAGKCAGI_AGY+AGH_AGICAGXGAGK;AGI\B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.3$T
M"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B0VQE87(B"FUS9W-T<B`BX9Z'
MX9Z8X9^2X9Z:X9^'(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS9VED(")#;&5A
M<B!1=65R>2(*;7-G<W1R("+AGH?AGICAGY+AGIKAGX?B@(OAGI_AGX;AGH[A
MGKWAGIHB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS
M9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@
M(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI
M8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB
M;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G
M:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R("+AGI3AGK?AGI'B@(OAGI3AGH3A
MGY+AGJ+AGKWAGH4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U-@IM<V=I
M9"`B0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED
M(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("+AGH#AGX3AGX?B
M@(OAGH#AGKSAGH#AGKP@*.&>@^&>N.&>F^&>N.&>A"DB"@HC.B!T96UP;&%T
M97,O<&]R=&%L+W-I9&5B87(N:6YC.C(T"FUS9VED(")#;VQL87!S92!3:61E
M8F%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S
M='(@(N&>@.&>O.&>H>&>N^&?AN&>E.&?BN&>N"(*"B,Z(&QI8B]";&]C:R]C
M;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED
M(")#;VQO<B(*;7-G<W1R("+AGI;AGH[AGXPB"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,P"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,S$*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,2!S97)V:6-E<R]I;6%G97,O8V]L
M;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@S.0IM<V=I9"`B0V]L
M;W5R('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU-`IM<V=I9"`B
M0V]L=6UN('1I=&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C@P"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO8VUD<VAE;&PN<&AP.C(U"FUS9VED(")#;VUM86YD(@IM<V=S='(@(N&>
MEN&>MN&>@.&?DN&>F>*`B^&>E.&>B>&?DN&>A^&>MB(*"B,Z(&%D;6EN+V-M
M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@
M(D-O;6UE;G0B"FUS9W-T<B`BX9Z?X9^!X9Z%X9Z`X9^2X9Z/X9ZXXH"+XH"+
MX9ZBX9Z2X9ZWX9Z4X9^2X9Z4X9ZVX9Z9(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S
M='(@(N&>B.&?DN&>F.&?A.&?A^*`B^&>DN&>F.&?DN&>F.&>C^&>MB(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(N&>@.&>N^&?AN&>
MF.&?B>&>O.&>FN&?B>&>O.&>GR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B
MX9Z`X9^2X9Z:X9Z[X9Z8X9Z@X9^*X9Z[X9Z3(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,V"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`BX9Z`X9Z[
MX9^&X9Z6X9^2X9Z9X9Z\X9Z1X9^0X9Z:(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(Y,`IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(N&>
MF^&>@.&?DN&>@>&>@>&>CN&?DN&>C"(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C8Q"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(N&>F^&>@.&?DN&>
M@>&>@>&>CN&?DN&>C"(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS
M9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#8*;7-G:60@(D-O;F9I9W5R871I
M;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T
M;&]O:RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S
M-0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O8V]N9FER;2YP:'`Z,S@*;7-G:60@(D-O;F9I<FT@16UA:6P@061D<F5S
M<R(*;7-G<W1R("+AGJ+AGX?AGJ+AGK;AGH3B@(OAGJ+AGK;AGI_AGIGAGHKA
MGY+AGHOAGK;AGI/B@(OAGJ+AGXKAGKCAGICAGX+AGILB"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A
M<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N
M=&ET>2YP:'`Z,S@U"FUS9VED(")#;VYF:7)M(&YE=R!E;6%I;"!A9&1R97-S
M(@IM<V=S='(@(N&>HN&?A^&>HN&>MN&>A.*`B^&>HN&>MN&>G^&>F>&>BN&?
MDN&>B^&>MN&>D^*`B^&>HN&?BN&>N.&>F.&?@N&>F^*`B^&>D.&?DN&>F.&>
MN"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-34@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S='(@(N&>@.&>N^&>
MA.&>H.&?DN&>@N&?A"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@
M1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N
M;F5C=&EO;B!F86EL960N(@IM<V=S='(@(N&>@.&>MN&>FN*`B^&>C^&>E^&?
MDN&>A^&>MN&>E.&?B^*`B^&>E.&>MN&>D^*`B^&>E.&>FN&>MN&>A^&?D.&>
MF>*`B\*@X9^4(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@
M(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#<V"FUS9VED
M(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3$P,`IM<V=I9"`B0V]N=&%C
M=',B"FUS9W-T<B`B0V]N=&%C=',B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C8P
M"FUS9VED(")#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HU-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B
MX9Z4X9Z3X9^2X9Z/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S
M(@IM<V=S='(@(N&>@.&?A.&?A^*`B^&>@.&>O.&>@"(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B0V]O:VEE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R("+AGH7AGICAGY+AGIOAGH0B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0W,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P
M>2!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R("+AGH#AGKSA
MGI_AGY+AGH_AGK;AGIKAGKCAGH#AGK8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#
M;W1E(&0G279O:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T
M(&UE<W-A9V4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,#4U"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S
M<V%G93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@
M;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M
M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C$R,0IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!
M4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HT-3<*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C0T,0IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@
M;&1A<"!S97)V97(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T
M('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,3(X"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP
M="!01U`@9&%T83H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3(S"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3
M+TU)344@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N
M;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T
M92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI
M<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T
M96=Y+G!H<#HV.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP
M:'`Z,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@
M9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N
M(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0R,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC
M95]487-K(&UO9'5L92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER
M96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR
M,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-CDY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(T
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G
M:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R
M97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@
M87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS,#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S0P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W
M-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"FUS
M9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S
M(&)O;VLN("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E
M=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U
M;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y
M"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF
M:6=U871I;VXZ("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E
M('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@
M=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E
M(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@
M;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ
M-#,*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N
M=&%C="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<
M(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-S`*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A
M<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E
M<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<
M(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30R-PIM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")#;W5N=')Y
M(@IM<V=S='(@(N&>E.&?DN&>FN&>D>&?@>&>GR(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR.#D*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`BX9Z4X9Z$X9^2X9Z`
MX9Z^X9Z/(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.30*
M;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T
M92!S=6(@9F]L9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C(S"FUS
M9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-SD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`BX9Z`X9^2X9Z:X9Z\X9ZBX9ZV
MX9Z/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R("+AGH+AGKOA
MGIGAGI3AGK8B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*;7-G:60@(D-U
M<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C4P"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS-0IM
M<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(N&>EN&?@>&>F^*`B^&>G.&?
M@>&>F^&>MN*`B^&>E.&>A>&?DN&>A>&>N^&>E.&?DN&>E.&>D^&?DN&>DR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5S<VEO;G,N<&AP.C,U"FUS9VED(")#=7)R96YT(%5S97)S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`*;7-G:60@(D-U
M<G)E;G0@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C8Y"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`BX9Z:X9Z%
MX9Z3X9ZVX9Z4X9^0X9Z1X9^2X9Z8XH"+X9Z4X9Z%X9^2X9Z%X9Z[X9Z4X9^2
MX9Z4X9Z3X9^2X9Z3XH"+(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N
M('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(N&>E.&?DN&>C^&>O.&>FN*`
MB^&>E^&>MN&>FN&>@.&>M^&>A>&?DN&>A>*`B^&>BN&?@N&>F^*`B^&>C^&?
MDN&>FN&>O.&>G.*`B^&>FN&>C^&?B^*`B^&>C^&>MN&>F.*`B^&>E.&?AN&>
MCN&>A"#AGJ+AGK;AGI_AGY+AGIKAGY#AGIGB@(OAGIOAGK[B@(OAGH#AGK;A
MGIKB@(OAGH7AGKSAGIOB@(OAGI'AGX7B@(L@)7,@X9^4(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS
M9VED(")#=70B"FUS9W-T<B`BX9Z`X9ZVX9Z/X9^+(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E
M;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R=7,B
M"FUS9W-T<B`BX9Z?X9^*X9ZXX9Z6X9Z:X9^-(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ-S@*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@
M(N&>G^&?BN&>N.&>FN&>N.&>F^&>N.&>@"`H2T])."U2*2(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ
M,C4Q*2(*;7-G<W1R("+B@(OB@(OAGI_AGXKAGKCAGIKAGKCAGIOAGKCAGH`@
M*%=I;F1O=W,M,3(U,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM
M<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(N&>
MG^&>MN&>DN&>MN&>FN&>CN*`B^&>FN&>BN&?DN&>B^*`B^&>AN&?@>&>@"(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(D1$
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,PIM<V=I9"`B(@HB
M1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G
M92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED
M(")$86EL>2(*;7-G<W1R("+AGIKAGK;AGIOAGXOB@(OAGI#AGY+AGH3AGX,B
M"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R
M;W=S97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S(X,0IM<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C0P-@IM<V=I9"`B1&%T92(*;7-G<W1R("+A
MGH#AGK;AGIOB@(OB@(OAGI3AGIKAGK?AGH7AGX'AGY+AGH;AGI$B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T
M92!296-E:79E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#`P"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@U(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS,30*;7-G:60@(D1A>2(*;7-G<W1R("+AGI#A
MGY+AGH3AGX,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R("+AGI+AGY+AGI/AGKPB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I
M9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(N&>E.&>D^&?DN&>D.&>F2#A
MGH7AGKSAGIOB@(OAGI3AGI/AGY+AGI'AGK;AGH_AGXLB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PIM
M<V=I9"`B1&5F875L="(*;7-G<W1R("+AGIOAGX;AGI/AGK;AGX;AGHKAGK[A
MGI@B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHW-PIM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.CDV"FUS9VED(")$969A=6QT
M($ED96YT:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HV-PIM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,SD*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3,@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V1E;&5T92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R("+AGIOAGKOAGI3B@(LB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S(*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS9VED(")$96QE
M=&4@1W)O=7`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C0Y"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`BX9Z;X9Z[X9Z4XH"+
MX9Z'X9Z]X9Z:XH"+X9Z(X9Z:(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT
M,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O
M<B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI
M<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`BX9Z;
MX9Z[X9Z4XH"+X9Z'X9Z]X9Z:X9Z*X9^!X9Z`(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B1&5L971E('-E;&5C
M=&5D(&ED96YT:71Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E
M('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@
M(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR-3,*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R("+AGHKAGK;A
MGH[AGKKAGICAGXGAGK;AGH`B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.30R('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*;7-G:60@
M(D1E<V-R:7!T:6]N(@IM<V=S='(@(N&>@.&>MN&>FN&>EN&>M^&>EN&>CN&?
MC.&>D^&>MB(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DW"FUS
M9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,C`Q"FUS9VED
M(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A
M=&]R+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C,U"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R("+B@(OAGJ+AGI?AGK?A
MGISAGHSAGY+AGHTB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R.0IM<V=I
M9"`B1&5W(%!O:6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S`V"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C$*;7-G
M:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L
M969T('1O(')I9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H
M="!T;R!L969T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`BX9Z0X9Z/(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(W,`IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R
M('1I;65S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3`P"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.CDT"FUS9VED(")$:7-P;&%Y(&1E
M=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z.3<*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,`IM<V=I9"`B
M1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM
M<V=S='(@(N&>H.&?DN&>G^&?BN&>N.&>E.&>O.&>D>&>N"(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N;W0@9&5L
M971E(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR
M-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP
M:'`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z
M,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@
M=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S
M+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I
M9"`B1&]M:6YI8V$B"FUS9W-T<B`BX9Z*X9Z\X9Z8X9ZXX9Z3X9ZXX9Z`X9ZV
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S
M='(@(N&>G^&>MN&>DN&>MN&>FN&>CN&>FN&>BN&?DN&>B^*`B^&>BN&>O.&>
MF.&>N.&>D^&>N.&>@.&?@N&>DR(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z.#@*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U
M<"XB"FUS9W-T<B`BX9Z8X9ZWX9Z3XH"+X9Z8X9ZVX9Z3XH"+X9Z"X9Z.X9Z3
MX9ZXPJ`_(.&>G^&>O.&>F.*`B^&>A>&>N^&?A^&>B.&?DN&>F.&?A.&?A\*@
MX9^4(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#4X
M"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R("+AGI'AGK;AGHGAGIGAGH`B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q-0IM<V=I9"`B1')O<"!D
M;W=N(&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,Y"FUS9VED(")$<G5G<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z.#,*;7-G:60@(D1Y;F%M:6,@36%I;"(*;7-G<W1R("+A
MGI_AGX;AGI3AGKOAGH_AGY+AGIKB@(OAGI#AGK;AGICAGISAGI/AGY+AGH\B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@
M(D4M36%I;"(*;7-G<W1R("+AGJ+AGXKAGKCAGICAGX+AGILB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B
M14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI
M8V@@<')O=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS
M9VED(")%8W5A9&]R(@IM<V=S='(@(N&>HN&?@>&>@.&?DN&>G.&>MN&>C.&?
MD.&>FB(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(U('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@IM<V=I9"`B161I="(*
M;7-G<W1R("+AGH#AGX+B@(OAGI_AGICAGY+AGIKAGKWAGILB"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P"FUS9VED(")%9&ET($)L;V-K
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R
M;W5P<RYP:'`Z,C(V"FUS9VED(")%9&ET($=R;W5P(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS
M9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I
M="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E
M<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@
M)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS
M9VED(")%9'5C871I;VXB"FUS9W-T<B`BX9Z`X9ZVX9Z:XH"+X9ZBX9Z4X9^+
MX9Z:X9^&(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`BX9ZB
MX9^!X9Z@X9^2X9Z?X9^*X9ZXX9Z4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%
M;"!386QV861O<B(*;7-G<W1R("+AGJ+AGX+AGIOAGI_AGK;AGIOAGXOAGISA
MGXGAGK;AGHSAGY#AGIHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@W-PIM<V=I9"`B16UA:6PB"FUS9W-T<B`BX9ZBX9^*X9ZX
MX9Z8X9^"X9Z;(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-C8@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"FUS9VED(")%;6%I
M;"!!9&1R97-S(@IM<V=S='(@(N&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>
MD^*`B^&>HN&?BN&>N.&>F.&?@N&>FR(*"B,Z('-E<G9I8V5S+V-O;F9I<FTN
M<&AP.C,P"FUS9VED(")%;6%I;"!A9&1R97-S97,@:&%V92!B965N(&QO8VME
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW
M,0IM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@
M(N&>HN&>MN&>G^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>HN&?BN&>N.&>F.&?
M@N&>F^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>C^&?@N*`B^&>BN&>O.&>A>&>
M@N&?DN&>D^&>ML*@X9^4(@H*(SH@<V5R=FEC97,O8V]N9FER;2YP:'`Z,C,*
M;7-G:60@(D5M86EL(&%D9')E<W-E<R!T;R!C;VYF:7)M(&YO="!F;W5N9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DY-PIM
M<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G
M:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR.3<*;7-G:60@(D5M
M;W1I8V]N<R(*;7-G<W1R("+AGI_AGHGAGY+AGHGAGK;B@(OAGJ+AGK;AGIKA
MGICAGY+AGICAGH[AGXTB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR
M-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B
M16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU-#<*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA
M9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C(*;7-G:60@(D5N86)L92!R
M:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(U.38@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@P-`IM<V=I9"`B16YD('EE87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL
M87)G92!%9&ET;W(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(R-`IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W
M:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y
M;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO
M=7(@<&5T/R<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@
M=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HX.3`*;7-G:60@(D5N=&5R('1H
M92!L971T97)S(&)E;&]W.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED
M(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R("+AGJ#AGY+AGH+AGKCAGH[A
MGX'B@(OAGJ+AGX'AGH#AGY+AGISAGK;AGI'AGY#AGIHB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q
M"FUS9VED(")%<FET<F5A(@IM<V=S='(@(N&>HN&?@>&>FN&>N.&>D>&?DN&>
MFN&>MB(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="]6:65W+G!H<#HY-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-3,*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HT,0IM<V=I9"`B17)R
M;W(B"FUS9W-T<B`BX9Z`X9^&X9Z@X9Z[X9Z?(@H*(SH@9G)A;65W;W)K+U1E
M;7!L871E+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M
M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(N&>
MHN&?@>&>G^&?DN&>C^&>O.&>D^&>N"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T
M:&EO<&EA(@IM<V=S='(@(N&>HN&?@>&>C^&?DN&>F>&>O.&>EN&>N"(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B171H;FEC(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I
M9"`B175R;W!E(@IM<V=S='(@(N&>HN&>NN&>FN&?B>&>N^&>E"(*"B,Z('1E
M;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,#$@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T,PIM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R("+A
MGIKAGX#AGH3B@(OAGIKAGK;AGIOAGXOB@(L@X9^AX9^E(.&>D^&>MN&>D>&>
MN"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3,*;7-G:60@(D5V97)Y
M(#(@;6EN=71E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA
M>6]U="YI;F,Z.3@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,`HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")%=F5R>2`S,"!S96-O;F1S
M(@IM<V=S='(@(N&>FN&?@.&>A.*`B^&>FN&>MN&>F^&?B^*`BR#AGZ/AGZ`@
MX9Z<X9ZWX9Z3X9ZVX9Z1X9ZX(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC.C$P,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0R"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.30*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*
M;7-G<W1R("+AGIKAGX#AGH3B@(OAGIKAGK;AGIOAGXL@X9^E(.&>D^&>MN&>
MD>&>N"(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP
M:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,#(@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,T-`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(N&>FN&?
M@.&>A.*`B^&>FN&>MN&>F^&?B^*`B^&>@.&>D^&?DN&>F^&?A^*`B^&>F.&?
MB>&?A.&>A"(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,#,*
M;7-G:60@(D5V97)Y(&AO=7(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.CDY(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,@IM<V=I9"`B179E<GD@;6EN
M=71E(@IM<V=S='(@(N&>FN&?@.&>A.*`B^&>FN&>MN&>F^&?B^&>D^&>MN&>
MD>&>N"(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED
M(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE
M;&PN<&AP.C@Q(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3(W"FUS9VED(")%>&5C=71E(@IM<V=S='(@(N&>E.&?DN&>FN&>
MC^&>M^&>E.&>C^&?DN&>C^&>MR(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z-#8V"FUS9VED(")%>'!A;F0B"FUS9W-T
M<B`BX9Z4X9Z3X9^2X9Z;X9ZVX9Z9(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S
M:61E8F%R+FEN8SHS,0IM<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I
M9"`B17AP96-T960@)RDG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO
M4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R
M9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T:6]N
M($1A=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-S<*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@(N&>HN&?BN&>
MM^&>A>&>G^&?DN&>E.&>O.&>CN&>A.&?B^&>G^&?@N&>FR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G
M:60@(D9'($-O;&]R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-S<*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z,C0U"FUS9VED
M(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<U(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN
M96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-M8BYP:'`Z,3`Q"FUS9VED(")&86EL960@=&\@8V]N;F5C
M="!T;R!334(@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@
M=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HW,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-A<VPN<&AP.C@Y"FUS9VED(")&86EL960@=&\@8W)E
M871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-3`Q(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-S4U"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E
M('1O(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HT-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E
M=')I979E.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB
M"FUS9W-T<B`BX9Z`X9^$X9^'XH"+X9Z@X9^2X9Z<X9^)X9Z`X9ZAX9Z$X9^+
M("CAGICAGXGAGK;AGIOAGXOAGISAGKCAGH[AGK8I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM
M<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("+AGH#AGX3AGX?AGJ#AGY+A
MGISAGK;AGJ+AGX'AGIKAGKPB"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z
M,C,X"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X
M(@IM<V=S='(@(N&>D>&>O.&>FN&>G^&>MN&>FB(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-C4*;7-G:60@(D9A>&5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#$*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED
M(")&96)R=6%R>2(*;7-G<W1R("+AGH#AGKOAGICAGY+AGI?AGX@B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(S,@IM<V=I9"`B1F5E;',@3&EK92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(U"FUS
M9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-3(*;7-G:60@(D9I96QD
M(&UA=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,S,V"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S0P"FUS9VED(")&:6=L970@9F]N
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@
M(N&>H.&?DN&>G.&>N.&>H.&?DN&>G^&?BN&>N"(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B1FEL92(*;7-G<W1R("+AGJ_A
MGH#AGI_AGK;AGIHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C,*;7-G:60@(D9I;&4@
M36%N86=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HX,@IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(N&>B.&?DN&>F.&?A.&?
MA^*`B^&>K^&>@.&>G^&>MN&>FB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Y.#@*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.30*;7-G:60@(D9I;&4@=7!L
M;V%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N
M<&AP.C@X-0IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY.`IM<V=I
M9"`B1FEL=&5R<R(*;7-G<W1R("+AGH_AGICAGY+AGIKAGH0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S='(@(N&>H.&?DN&>G.&>MN&?AN&>
MA.&>H>&>A.&?BR(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@
M(D9I<G-T($AA;&8B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C4U"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,`IM<V=I
M9"`B1FQI<"(*;7-G<W1R("+AGH_AGY+AGIKAGJ'AGI3AGXLB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS
M9VED(")&;&]A="(*;7-G<W1R("+AGI'AGI_AGI?AGK;AGH(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C8P
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*
M;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`BX9Z6X9Z.X9^,XH"+X9Z6X9Z[
MX9Z8X9^2X9Z6XH"+X9ZBX9Z`X9^2X9Z?X9Z:(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0R"FUS9VED(")&;V]D(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M-@IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G
M97,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#8*;7-G
M:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HW-PIM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H
M;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@
M9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R
M97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.CDT"FUS9VED(")&;W)G;W0@>6]U<B!P87-S
M=V]R9#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0W.`IM<V=I9"`B1F]R;7,B"FUS9W-T<B`BX9Z?X9^&X9Z.X9Z[X9^&XH"+
MXH"+X9Z4X9^"X9Z4X9Z4X9Z1(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C(V"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HQ,#0*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(D9O<G1U;F5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I
M9"`B1F]R='5N97,@,B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#8Y"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B1F]R=V%R9',B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A
M;65S(@IM<V=S='(@(N&>G^&?BN&>N^&>F"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@
M(D9R86YC92(*;7-G<W1R("+AGI3AGK;AGIKAGK;AGX;AGH0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T
M<F]P;VQI=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC
M:"!'=6EA;F$B"FUS9W-T<B`BX9Z@X9^2X9Z"X9Z\X9ZBX9^*X9ZXX9Z9X9^)
MX9ZVX9Z.X9ZV(.&>E.&>MN&>FN&>MN&?AN&>A"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS
M9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(N&>E.&?B>&>O.&>F^&>
MN.&>D^&?@>&>G^&?BN&>N.*`B^&>E.&>MN&>FN&>MN&?AN&>A"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@IM
M<V=S='(@(N&>HN&>MN&>CN&>A>&>@.&?DN&>FN*`B^&>@>&>MN&>A.*`B^&>
MC^&?DN&>E.&>O.&>A"#AGI3AGK;AGIKAGK;AGX;AGH0B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M
M(@IM<V=S='(@(N&>EN&>N"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-#(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U,@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDX"FUS9VED(")&<F]M('1H
M92`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z-#@*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*
M;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV
M,`IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(N&>B.&?DN&>F.&?A.&?A^*`
MB^&>EN&?@>&>B2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@
M(N&>H.&?DN&>@N&>MN&>E.&>N^&>A"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L
M;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y
M"FUS9VED(")'86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED
M(")'86UB:6$B"FUS9W-T<B`BX9Z@X9^2X9Z`X9ZVX9^&X9Z4X9^*X9ZX(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'
M96YE<F%T960@0V]D92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'
M96]R9VEA(@IM<V=S='(@(N&>H.&?DN&>G^&>@.&>H.&?DN&>G^&?BN&>N"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`BX9ZBX9ZVX9Z;
MX9^2X9Z;X9ZZX9Z8X9^)X9Z$X9^+(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA
M;F$B"FUS9W-T<B`BX9Z@X9^2X9Z`X9ZVX9Z.X9ZV(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM
M<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(N&>H.&?DN&>@N&>N.&>E.&?DN&>
MFN&>MN&>F^&?B^&>C^&>MB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3<V"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(N&>D^&>
MMN&>F.&>@>&?DN&>F^&>O>&>DR(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HQ-S4@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3`*(SH@=&5M
M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*;7-G:60@(D=L;V)A;"!/<'1I;VYS
M(@IM<V=S='(@(N&>A^&>F.&?DN&>FN&>ON&>G^*`B^&>G^&>@.&>FR(*"B,Z
M('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$W"FUS9VED(")';R(*;7-G<W1R
M("+AGI'AGX4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@
M(D=O961E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3$R.0IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O
M9VQE(%-E87)C:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C,V"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T
M<B`BX9Z8X9ZVX9Z/X9^2X9Z:X9Z*X9^2X9Z+X9ZVX9Z3XH"+X9Z4X9^2X9Z:
MX9Z5X9^!X9^'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R
M("+AGH#AGY+AGIKAGK?AGH`B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(N&>@.&?DN&>
MFN&>M^&>@"`H25-/+3@X-3DM-RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5E
M;FQA;F0B"FUS9W-T<B`BX9Z"X9^2X9Z:X9ZXX9ZAX9Z$X9^+(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R("+AGJ#AGY+AGH+AGY+AGIKA
MGKCAGH[AGK;AGHKAGK8B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I
M9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE
M;7!T>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,S`W"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N
M86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ
M,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E
M(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@
M=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'<F]U
M<',B"FUS9W-T<B`BX9Z`X9^2X9Z:X9Z[X9Z8(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I
M9"`B1W5A9&5L;W5P92(*;7-G<W1R("+AGJ#AGY+AGH+AGKSAGJ+AGK;AGHKA
MGKKAGIOAGKSAGI3AGXGAGX$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*
M;7-G<W1R("+AGJ#AGY+AGH+AGK;AGX;AGI@B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I
M9"`B1W5A=&5M86QA(@IM<V=S='(@(N&>H.&?DN&>@N&>MN&>C^&?@>&>F.&?
MB>&>MN&>H>&>MB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*
M;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M.#@*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#8*;7-G:60@(D=U97-T8F]O:R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B
MX9Z@X9^2X9Z"X9ZXX9Z.X9^!(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=6EN
M96$M0FES<V%U(@IM<V=S='(@(N&>H.&?DN&>@N&>N.&>CN&?@>&>E.&?BN&>
MN.&>G^&?A2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@
M(N&>H.&?DN&>@N&>N.&>F>&?B>&>MN&>CN&>MB(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.CDV-`IM<V=I9"`B2%1-3"(*;7-G<W1R(")(5$U,(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE
M=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G
M:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B
M2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@
M<F]W(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VAT='`N<&AP.C$U-`IM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2&%I
M=&DB"FUS9W-T<B`BX9Z@X9^#X9Z1X9ZX(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR,@IM<V=I9"`B2&%Z92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HY,C,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR-0IM
M<V=I9"`B2&5A9&5R(@IM<V=S='(@(N&>E.&>B^&>F.&>@.&>D.&>MN*`BR(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-C$*
M;7-G:60@(DAE861E<G,B"FUS9W-T<B`BX9Z4X9Z+X9Z8X9Z`X9Z0X9ZV(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD
M($ES;&%N9',B"FUS9W-T<B`BX9Z`X9^$X9^'XH"+X9Z@X9^*X9Z^X9Z*(.&>
MD^&>M^&>A"#AGH#AGX3AGX?B@(OAGICAGXGAGK;AGH#AGHKAGKSAGH[AGK;A
MGIOAGXLB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX
M+4DI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R("+A
MGH#AGICAGY+AGI;AGI_AGXLB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M2&5L<"YP:'`Z,3@Q(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ
M.#(*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S+VAE
M;'`O:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T<B`BX9Z'X9^&X9Z3
MX9Z]X9Z9(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W.0IM<V=I9"`B2&5L<&5R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B
M2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I
M;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`IM<V=I
M9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW
M,`IM<V=I9"`B2&EG:"(*;7-G<W1R("+AGH'AGY+AGI;AGI_AGXLB"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O
M;6UO;BUH96%D97(N:6YC.C4*;7-G:60@(DAO7VUE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A
M=&4I(@IM<V=S='(@(N&>H.&>O.&>F^&>N.&>G^&?BN&>N"`HX9Z:X9Z*X9^2
MX9Z+XH"+X9Z`X9^2X9Z:X9Z[X9Z$XH"+X9Z<X9^)X9ZVX9Z1X9ZXX9Z`X9Z$
MX9^+*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34U-0IM<V=I
M9"`B2&]M92(*;7-G<W1R("+AGH+AGX'AGJ#AGI'AGX;AGI;AGY#AGIHB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G
M:60@(DAO;64@061D<F5S<R(*;7-G<W1R("+AGJ+AGK;AGI_AGIGAGHKAGY+A
MGHOAGK;AGI/B@(OAGI7AGY+AGI'AGX<B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-C0*;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(N&>D.&>
MC^&>E>&?DN&>D>&?AR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`BX9Z1
MX9Z\X9Z:X9Z?X9^0X9Z6X9^2X9Z1XH"+X9Z5X9^2X9Z1X9^'(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R("+AGJ#AGKOAGH3AGHSA
MGKSAGIKAGXGAGK;AGI_AGXLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@
M2V]N9R(*;7-G<W1R("+AGJ#AGKOAGH3AGH#AGKOAGH0B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-C<*;7-G:60@(DAO<F1E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#0R"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N
M8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M-#,U"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE
M8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@
M)7,@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N
M(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4P,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R
M96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E
M<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C0W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA
M8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,3DR"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$S,S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R
M97,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN
M;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L
M(%)U;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T
M(2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W
M;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD
M<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED
M(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDS(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C0R"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4S"FUS9VED
M(")(=6UI9&ET>3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT-@IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R("+AGJ#AGKOAGH3AGH+AGY+A
MGIKAGK@B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S`@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR
M,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HQ-S<@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@
M9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,S(P"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(N&>HN&>MN&>
MG^&>F>&>BN&?DN&>B^&>MN&>D^*`BR!)4"(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I
M<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L
M;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L
M;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B
M25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM
M<V=I9"`B26-E;&%N9"(*;7-G<W1R("+AGJ+AGXKAGKCAGI_AGY+AGIOAGH3A
MGXLB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@P"FUS9VED("))8V]N
M<R!/;FQY(@IM<V=S='(@(N&>C^&?@N*`B^&>FN&>O.&>E.&>C^&?AN&>CN&>
MMN&>A"(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,X,0IM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3,*;7-G:60@
M(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z-3DU"B,L('!H<"UF;W)M870*;7-G:60@
M(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N
M(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0U.0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A
M;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E
M9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P
M87)E;F-Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3<R"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@
M;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U
M<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G92!0<F5V:65W.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Y"FUS9VED("));6%G
M92!U<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R("+AGIKAGKSAGI3AGI?AGK;AGI8B
M"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E<R]D
M871A+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHU-"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L('!H<"UF;W)M
M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED
M("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N
M<&AP.C$S-`IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S,@IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N9"]O
M<B!P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A
M;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B
M"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(N&>E.&>
MA.&?DN&>@.&>ON&>D^*`B^&>@.&>MN&>FN*`B^&>A>&>O.&>F^*`B^&>E.&>
MD^&?DN&>D>&>MN&>C^&?BR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B
M"FUS9W-T<B`BX9ZEX9Z.X9^2X9Z,X9ZV(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`BX9ZEX9Z.X9^2X9Z,
MX9Z\X9Z3X9^!X9Z?X9^*X9ZX(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*;7-G<W1R("+AGI;A
MGY#AGH_AGXSAGICAGK;AGI,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C<S"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("+AGI;AGY#AGH_A
MGXSAGICAGK;AGI,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S(R"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM86=E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("+AGI3AGHGA
MGY+AGH7AGKSAGIOB@(OAGH_AGK;AGIKAGK;AGH0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@
M5V5B($QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O
M;'5M;B!"969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@
M82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H
M92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R
M="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U
M<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@
M<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C
M=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T,@IM<V=I9"`B26YS
M97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E
M('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN
M<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R
M="!C96QL(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@
M8V]L=6UN(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C
M;VQU;6X@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("));G-E<G0@;65S<V%G97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F
M=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P
M:"!B969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(')O=R!A
M9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R
M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,S"FUS
M9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I
M='D@<75E<W1I;VXZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@
M26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E
M;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM
M<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W.0IM<V=I9"`B26YT96=E<B(*;7-G
M<W1R("+AGH7AGX;AGI/AGKWAGI/B@(OAGH+AGH_AGXLB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3,W"FUS9VED("));G1E9V5R(&QI<W0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(
M96%D97(I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O>FEP+G!H<#HQ-C<*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+WII<"YP:'`Z,3DT"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]Z:7`N<&AP.C(Q,@IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A
M;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L
M:60@8F%T8V@@240N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P.34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$V-@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0P(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S,#<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE
M<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E
M<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]D8G@N<&AP.C$P.0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M9&)X+G!H<#HQ,SD*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B
M>"YP:'`Z,C0Q"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S`*;7-G:60@
M(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C0*;7-G:60@(DEN=F%L:60@;&]C871I
M;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M
M<V=?='EP92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI
M<W-I;F<@87!I7VED+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@
M;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E
M<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-C8*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V.`IM<V=I
M9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I
M9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P-S4@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HQ,C4X"FUS9VED("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S,*;7-G
M:60@(DEN=F5N=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<V"FUS9VED("));G9E<G0@<V5L96-T
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L
M86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G
M:60@(DER87$B"FUS9W-T<B`BX9ZBX9^*X9ZXX9Z:X9^)X9ZVX9Z`X9^+(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@(N&>HN&?@.&>
MFN&>H>&>A.&?BR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U
M"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@
M5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A
M96PB"FUS9W-T<B`BX9ZBX9^*X9ZXX9Z?X9^2X9Z:X9ZVX9ZBX9^"X9Z;(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C8*;7-G:60@
M(DES<W5E<B(*;7-G<W1R("+AGJ+AGY+AGI/AGH#B@(OAGH7AGX'AGHDB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G
M:60@(DET86QI8R(*;7-G<W1R("+AGI'AGY+AGIKAGX'AGH\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#(*;7-G:60@(DET86QY(@IM<V=S='(@(N&>HN&?BN&>N.&>C^&>MN&>
MF^&>N"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R("+A
MGH7AGK;AGICAGXGAGX/AGH#AGK8B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R("+A
MGICAGH#AGIKAGK8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S
M='(@(N&>A^&>E.&?B>&>N^&>DR(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@S"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(N*`
MB^&>A^&>E.&?B>&>N^&>DR`H25-/+3(P,C(M2E`I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R("+AGJ#AGY+A
MGI_AGXKAGH#AGHKAGK;AGI/AGK@B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R("+AGH#A
MGH#AGY+AGH#AGHKAGK8B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R("+AGICAGK?AGI#A
MGKOAGI/AGK8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(N&>C^&>
MF.&?DN&>FN&>N>&>F.*`B^&>G^&>A.*`B^&>@>&>MN&>A"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS
M9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B
M2G5S=&EF>2!&=6QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y
M($QE9G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM
M<V=S='(@(N&>@.&>MN&>H.&?DN&>G^&>MN&>@.&?B^&>G^&?DN&>C^&>A.&?
MBR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M-C,*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`BX9Z`X9^"X9Z3X9Z9X9^)X9ZV
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-@IM<V=I9"`B
M2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@(DME
M<FYE;"!.97=B:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I
M9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G
M<W1R("+AGI3AGY+AGIKAGISAGX+AGH3B@(OAGH#AGKSAGI/AGI_AGX0B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME
M>2!4>7!E(@IM<V=S='(@(N&>E.&?DN&>FN&>E^&?@>&>D>*`B^&>@N&?DN&>
MFN&>MN&>E.&?B^*`B^&>A>&>N^&>A2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DY"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED
M(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I
M9"`B2VED<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB
M871I(@IM<V=S='(@(N&>@N&>M^&>FN&>M^&>E.&>MN&>D>&>N"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E
M82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#0*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R("+B@(OA
MGH#AGKSAGIKAGXGAGX$@*$550RU+4BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@
M(DMU=V%I="(*;7-G<W1R("+AGH+AGKOAGIGB@(OAGISAGXGAGX+AGH\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`BX9Z"X9^`
MX9Z:X9Z@X9^2X9Z"X9ZXX9Z?X9^2X9Z/X9Z$X9^+(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S4*;7-G:60@(DQA;F=U
M86=E(@IM<V=S='(@(N&>E^&>MN&>G^&>MB(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I
M9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B
MX9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9Z:X9Z*X9^2X9Z+XH"+X9Z4X9^2X9Z:X9Z'
MX9ZVX9Z2X9ZWX9Z4X9Z/X9^!X9Z9X9^2X9Z9XH"+X9Z4X9^2X9Z:X9Z'X9ZV
MX9Z8X9ZVX9Z3X9ZWX9Z/XH"+X9ZAX9ZVX9Z<(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HW-@IM<V=I9"`B3&%S="!087-S=V]R9"!#
M:&%N9V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI
M8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38S"FUS9VED("),87-T
M(%5P9&%T960Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,30*;7-G:60@
M(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM
M<V=I9"`B3&%T=FEA(@IM<V=S='(@(N&>H>&>MN&>C^&>G.&>N.&>F>&?B>&>
MMB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0IM<V=I9"`B3&%W(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(N&>E.&?DN&>
MF^&>A.&?B^*`BR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S
M='(@(N&>F^&>N.&>E.&>A.&?BR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R
M("+AGH;AGY+AGISAGX'AGH0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,3$R"FUS9VED("),969T(&AE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`X"FUS9VED("),969T('9A;'5E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE<V]T:&\B"FUS9W-T
M<B`BX9ZAX9^!X9Z?X9Z\X9Z/X9Z\(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C4U"FUS9VED("),979E;"(*;7-G<W1R("+AGH#AGICAGY+A
MGIKAGK?AGH\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T
M<B`BX9Z;X9ZXX9Z4X9^!X9Z:X9ZXX9Z9X9^)X9ZV(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y
M"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(N&>A>&>
MMN&>F.&?B>&>MN&>HN&?BN&>M^&>FN&>N.&>F>&?B>&>MN*`B^&>HN&>MN&>
MFN&?B>&>MN&>E.&?BR#AGIOAGKCAGI3AGXKAGK@B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*
M;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`BX9Z;X9ZWX9Z%X9Z1X9^!
MX9Z3X9Z?X9^2X9Z/X9^"X9Z3(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C8*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A
M:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR.0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@
M(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H
M="!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@(DQI
M;65R:6-K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X,C(*;7-G:60@(DQI;FLB"FUS9W-T<B`BX9Z/X9^&X9Z.(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W
M"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@X,PIM<V=I9"`B3&EN:R!T:&4@96UA:6P@
M861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT
M;6PR=&5X="YP:'`Z,3@R"FUS9VED("),:6YK<R(*;7-G<W1R("+AGH_AGX;A
MGHXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DQI;G5X
M($-O;VMI92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T
M:&4@9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,S,*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+VAE;'`O:6YD97@N<&AP.C4Q"FUS9VED("),:7-T($AE;'`@5&]P:6-S
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S(*;7-G:60@
M(DQI<W0@5&%B;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O2&5A9&5R<RYP:'`Z-3`Y"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU,#0*
M;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TAE861E<G,N<&AP.C4Q,0IM<V=I9"`B3&ES="U)9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4P-PIM
M<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TAE861E<G,N<&AP.C4P.`IM<V=I9"`B3&ES="U0;W-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3`V
M"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4P-0IM<V=I9"`B3&ES="U5;G-U
M8G-C<FEB92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z
M("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR
M"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*;7-G:60@(DQI=&5R871U
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:71H=6%N:6$B
M"FUS9W-T<B`BX9Z;X9ZXX9Z1X9Z[X9Z9X9ZBX9ZVX9Z3X9ZX(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6UA9V5S+G!H<#HW-PIM<V=I9"`B
M3&]A9&EN9RXN+B(*;7-G<W1R("+AGH#AGX;AGI;AGKOAGH3B@(OAGI7AGY+A
MGI'AGKOAGH`N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C`U"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@V"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8R"B,Z(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C<W"FUS9VED
M("),;V-A=&EO;B(*;7-G<W1R("+AGI'AGKCAGH_AGK;AGX;AGH0B"@HC.B!L
M;V=I;BYP:'`Z,3@Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,#`@
M=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G
M:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@R
M"FUS9VED("),;V<@:6XB"FUS9W-T<B`BX9Z%X9Z\X9Z;(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@;V8@<')E=FEO
M=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HQ.30*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`BX9Z%
MX9^!X9Z)(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"FUS9VED("),
M;V=I;B(*;7-G<W1R("+AGH7AGKSAGILB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$P"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R("+AGI?AGK;A
MGIKAGH#AGK?AGH7AGY+AGH7B@(OAGH7AGKSAGILB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY.34*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E
M('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R
M96-T;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.CDY,0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<S"FUS9VED("),;VYG('1E>'0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED("),
M;W9E(@IM<V=S='(@(N&>G^&?@>&>A>&>@.&?DN&>C^&>N.*`B^&>G^&?DN&>
MFN&>H>&>MN&>B>&?BR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8X"FUS9VED("),;W<B"FUS9W-T<B`BX9Z1X9ZVX9Z4(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@
M(N&>F^&>N^&>A>&>H.&?DN&>G^&?AN&>E.&>O>&>FB(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.3D*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S-R!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,CDW"FUS9VED(")-3U1$(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS
M9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@(N&>F.&?
MB>&>MN&>@.&>MN&>G"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA
M+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R("+AGICA
MGXGAGK;AGHKAGK;AGJ#AGY+AGH#AGK;AGI_AGY+AGH#AGK;AGIHB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*;7-G:60@(DUA9VEC(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY,`IM<V=I9"`B36%I
M;"(*;7-G<W1R("+AGI_AGX;AGI3AGKOAGH_AGY+AGIHB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-3,X"FUS9VED(")-86EL($%D;6EN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&%W:2(*;7-G<W1R("+AGICAGXGA
MGK;AGJ'AGK;AGISAGX,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA
M(@IM<V=S='(@(N&>F.&?B>&>MN&>H>&?@>&>G^&?BN&>N"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`BX9Z8X9^)X9ZVX9Z;X9^+
MX9Z,X9ZXX9Z<(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86QI(@IM<V=S='(@
M(N&>F.&?B>&>MN&>F^&>N"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L=&$B
M"FUS9W-T<B`BX9Z8X9^)X9ZVX9Z;X9^+X9Z/X9ZV(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDT"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@
M8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@
M8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$U-`IM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#@U"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,38Y"FUS9VED
M(")-87!1=65S="!M87`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8W"FUS9VED(")-87)C:"(*;7-G<W1R("+AGICAGKCAGI/AGK8B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q
M"FUS9VED(")-87)G:6XB"FUS9W-T<B`BX9Z:X9ZYX9Z8XH"+X9Z1X9^&X9Z6
MX9^0X9Z:(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R
M=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED
M(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(N&>@.&?A.&?AR!-87)S:&%L
M;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R("+A
MGICAGXGAGK;AGIKAGI'AGKCAGI/AGKCAGH(B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G<W1R
M("+AGICAGXGAGKSAGIKAGKCAGH_AGK;AGI/AGK@B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*
M;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R("+AGICAGXGAGKSAGIKAGKCAGI'A
MGKOAGI\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3@*;7-G:60@
M(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,Q,`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO
M=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA
M>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3`R(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(T,PIM
M<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G
M<W1R("+AGJ?AGI_AGI?AGK8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-87EO
M='1E(@IM<V=S='(@(N&>F.&?@^&>HN&>O.&>C^&?@2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B
M365M8F5R<R(*;7-G<W1R("+AGI_AGICAGK;AGH?AGK?AGH`B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S@R"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@(N&>G^&>MN&>FB(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-
M97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S
M(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$P"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C`R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR-C`*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H
M97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HT,@IM<V=I
M9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C0*;7-G:60@(B(*(DUE=&%R(&)L;V-K
M(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@
M=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-3@*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O
M;FYE8W1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`BX9Z<X9ZWX9Z2X9ZX
MX9Z?X9ZVX9Z?X9^2X9Z:X9^2X9Z/(@H*(SH@9G)A;65W;W)K+U)00R]24$,O
M>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)00R]P:'!G=RYP:'`Z.#@*
M(SH@9G)A;65W;W)K+U)00R]24$,O<&AP9W<N<&AP.C@Y(&9R86UE=V]R:R]2
M4$,O4E!#+W-O87`N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-971H
M;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@
M(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<R(&QI8B]"
M;&]C:R]M971A<BYP:'`Z.#<*;7-G:60@(DUE=')I8R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R("+AGICAGXGAGK?A
MGH7AGI_AGXKAGK?AGH`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I
M82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*;7-G:60@
M(DUI9&1L92(*;7-G<W1R("+AGH#AGH[AGY+AGH_AGK;AGILB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM
M92!4>7!E(@IM<V=S='(@(N&>E.&?DN&>FN&>E^&?@>&>D2!-:6UE(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C(*;7-G:60@(DUI;B!T96UP(&QA<W0@
M,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,Q-`IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,S@*;7-G:60@
M(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(S,PIM<V=I9"`B36ER<F]R(@IM<V=S='(@(N&>AN&?DN&>F^&>N^&?
MAR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B36ES8V5L
M;&%N96]U<R(*;7-G<W1R("+AGI7AGY+AGI_AGX'AGH3AGY?B@(LB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-3`*
M;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B
M(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@;75S="!G96YE<F%T92!I
M="!B969O<F4@=7-I;F<@=&AI<R!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP
M.C4X"FUS9VED(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C<V"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M.0IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#4*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<T"FUS9VED(")-;V1U
M;'5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V82P@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-
M;VYA8V\B"FUS9W-T<B`BX9Z8X9^)X9Z\X9Z.X9ZVX9Z`X9Z\(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R("+AGICAGXGAGKOAGH3A
MGJ#AGY+AGH+AGX3AGIOAGK@B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-3DR"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R("+AGH'AGX(@
MX9Z3X9ZWX9Z$(.&>AN&?DN&>D^&>MN&?AB(*"B,Z(&9R86UE=V]R:R]-86EN
M=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS
M9W-T<B`BX9Z:X9ZVX9Z;X9^+XH"+X9Z!X9^"(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS
M9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(N&>F.&?B>&>N^&>A.&>G^&?@>&>
MFN&?B>&>MB(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3DV(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I
M96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T
M<B`BX9Z8X9^)X9ZVX9Z:X9^)X9Z[X9Z`(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B
M36]S=&QY(%-U;FYY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z-3`P"FUS9VED(")-;W9E($1O=VXB
M"FUS9W-T<B`BX9Z5X9^2X9Z;X9ZVX9Z?X9^+XH"+X9Z1X9ZXXH"+X9Z%X9Z[
MX9^'XH"+X9Z`X9^2X9Z:X9^$X9Z8(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HU,#0*;7-G:60@(DUO=F4@3&5F="(*
M;7-G<W1R("+AGI7AGY+AGIOAGK;AGI_AGXOB@(OAGI'AGKCB@(OAGI'AGX7B
M@(OAGH;AGY+AGISAGX'AGH0B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C4P.`IM<V=I9"`B36]V92!2:6=H="(*;7-G
M<W1R("+AGI7AGY+AGIOAGK;AGI_AGXOB@(OAGI'AGKCB@(OAGI'AGX7B@(OA
MGI_AGY+AGH_AGK;AGX8B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C0Y-@IM<V=I9"`B36]V92!5<"(*;7-G<W1R("+A
MGI7AGY+AGIOAGK;AGI_AGXOB@(OAGI'AGKCB@(OAGJ'AGK[AGH3B@(OAGIOA
MGKXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3(T"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`BX9Z%X9Z[X9^'XH"+X9Z`
MX9^2X9Z:X9^$X9Z8(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4R,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E('5P(@IM<V=S='(@(N&>H>&>ON&>
MA.*`B^&>F^&>OB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*
M;7-G<W1R("+AGICAGXGAGKSAGJ#AGY+AGI_AGK;AGX;AGI3AGXKAGK?AGH`B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3DR"FUS9VED(")-=6QT
M:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-38*;7-G:60@(DUU
M;'1I;6%P(%5+(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,C4P"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Q-@IM<V=I9"`B
M37D@06-C;W5N="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z,C@*;7-G:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HV-@IM<V=I9"`B37D@
M4&]R=&%L(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H
M<#HQ,S4*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(N&>F.&>N.&>F>&?
MB>&>MN&>D^&?B^&>F.&?B>&>MB(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R
M964B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*
M;7-G:60@(DYA;64B"FUS9W-T<B`BX9Z(X9^2X9Z8X9^$X9^'(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@(N&>CN&>MN&>F.&>N.&>
ME.&?BN&>N"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B
MX9Z.X9Z\X9Z:X9Z[(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G
M<W1R("+AGI/AGX'AGI3AGXGAGK;AGIOAGXLB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G
M:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(N*`B^&>H.&>N^&>F^&?DN&>F^&>
MA.&?BR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE
M<R(*;7-G<W1R("+AGJ+AGH3AGXOAGI'AGKCAGIGAGXWB@(OAGJ#AGKSAGIOA
MGY+AGIOAGH3AGXLB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@
M(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S
M8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!296YE
M=V%L(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.#<*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X.`IM
M<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I
M9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8W"FUS9VED(").971W;W)K(@IM
M<V=S='(@(N&>E.&>CN&?DN&>C^&>MN&>B2(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0R-2!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z.3<*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,SDP"FUS9VED(").979E<B(*;7-G<W1R("+AGH#AGKOA
MGX8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T
M<B`BX9Z3X9Z\X9Z<X9^"X9Z;X9Z`X9ZVX9Z;X9^!X9Z*X9Z\X9Z3X9ZX(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#0*(SH@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@X"B,Z(&9R86UE
M=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HQ,3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`BX9Z?
MX9ZVX9Z:XH"+X9Z0X9^2X9Z8X9ZXXH"+X9Z1X9^%("5S(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").
M97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3@*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(N&>D^&>O.&>G.&?@N&>
MF^&>H.&?BN&?DN&>G^&?@>&>H>&>A.&?BR(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HS-PIM<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@
M(N&>EN&>MN&>@.&?DN&>F>*`B^&>G^&>F.&?DN&>A.&>MN&>C^&?B^*`B^&>
MD.&?DN&>F.&>N"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HR
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@97AP
M:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z-3(*;7-G:60@(DYE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4W"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#4*
M;7-G:60@(DYE=W,B"FUS9W-T<B`BX9Z6X9^0X9Z/X9^,X9Z8X9ZVX9Z3(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R,0IM<V=I9"`B3F5W<V=R
M;W5P<R(*;7-G<W1R("+AGISAGX'AGI'AGK?AGH#AGK;B@(OAGI;AGY#AGH_A
MGXSAGICAGK;AGI,B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ
M-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R("+AGI3AGI/AGY+AGI'AGK;AGI3A
MGXLB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0
M:&%S97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HS-C<@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S$*;7-G
M:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO4&%G97(N<&AP.C$P,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`BX9Z3X9ZXX9Z`
MX9ZVX9Z:X9^)X9ZVX9Z@X9^2X9Z"X9^0X9Z:(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS
M9VED(").:6=E<B(*;7-G<W1R("+AGI/AGKCAGJ#AGY+AGI_AGX'AGIHB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`BX9Z3X9ZXX9Z@
MX9^2X9Z?X9^!X9Z:X9ZXX9Z9X9^)X9ZV(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,W,@IM<V=I9"`B3FEG:'0B"FUS9W-T<B`BX9Z9X9Z4
MX9^+(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").:75E(@IM<V=S='(@(N&>D^&>
MN.&>G"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HY-C0*;7-G:60@(DYO(@IM<V=S='(@(N&>D>&?@2(*"B,Z('1E;7!L871E
M<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A:6QA8FQE
M(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+G!H<#HQ,#8*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@
M;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@
M8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-S8*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HR,S<*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HR-3D*;7-G:60@(DYO
M(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-C<*;7-G
M:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP
M.C4T"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C
M86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V.2!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C4R,`HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U-0IM<V=I9"`B3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-CDX"FUS9VED
M(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C<R-0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G
M:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,#,*;7-G:60@(DYO(&9I
M;&4@=7!L;V%D960B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N
M<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R,2!L:6(O0FQO8VLO<W5N
M<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,S4*;7-G:60@
M(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V,@IM<V=I9"`B3F\@;&]C871I;VX@<')O
M=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L
M:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@
M(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#<*;7-G:60@(B(*(DYO('!A
M=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-3
M3"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R
M(&1A=&$N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C<V-@IM<V=I9"`B3F\@
M<75O=&$@<V5T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT.#(*
M;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-3@W"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$S,0IM<V=I
M9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C(R,0IM<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W
M;W)D('-E;G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM
M;')P8RYP:'`Z,30P(&9R86UE=V]R:R]24$,O4E!#+W!H<&=W+G!H<#HQ-S4*
M;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-S(*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX,@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DS"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#$P"FUS
M9VED(").;R!V86QU97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA
M;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@
M(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E
M;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P
M<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*;7-G:60@(DYO;F4B"FUS9W-T
M<B`BX9Z"X9^2X9Z8X9ZVX9Z3(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET
M*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I
M9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDV"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R("+AGH#AGX3AGX?B
M@(OAGH[AGXGAGJ#AGY+AGISAGXGAGH`B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(
M96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R
M=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(N&>@.&?A.&?A^*`B^&>
MF.&?B>&>MN&>FN&?@.&>CN&>MN*`B^&>E^&>MN&>@N*`B^&>@>&>MN&>A.*`
MB^&>A^&>ON&>A"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S
M='(@(N&>D^&?D.&>FN&>G.&?@N&>GR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C0Q"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G
M:60@(DYO="!"969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z-#$X"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H
M<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+G!H<#HX-`HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-0HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L
M96UE;G1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N
M<&AP.C$T-0HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(N<&AP.C$V,`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S
M<VEO;DAA;F1L97(N<&AP.C$W-0HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X.0HC.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,#@@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C(S-`HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,C4R(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-CD*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C(X-2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S`Q"B,Z
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,38@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C,S,PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8V(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HT,C8*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4P
M-2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<T"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HU.3$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V.0HC.B!F<F%M
M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z.#(@9G)A;65W;W)K+U9&4R]61E,O
M:&]R9&4N<&AP.C$S,0HC.B!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z
M,34Q(&9R86UE=V]R:R]61E,O5D93+VAO<F1E+G!H<#HQ-S`*(SH@9G)A;65W
M;W)K+U9&4R]61E,O:&]R9&4N<&AP.C$X.2!F<F%M97=O<FLO5D93+U9&4R]H
M;W)D92YP:'`Z,C`W"B,Z(&9R86UE=V]R:R]61E,O5D93+VAO<F1E+G!H<#HR
M,C<@9G)A;65W;W)K+U9&4R]61E,O:&]R9&4N<&AP.C,S,`IM<V=I9"`B3F]T
M('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z
M,3`X-0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@W"FUS9VED(").
M;W1E<R(*;7-G<W1R("+AGH7AGX;AGH[AGK;AGX8B"@HC.B!S97)V:6-E<R]O
M8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E
M+"!G;R!B86-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B
MX9Z<X9ZWX9Z%X9^2X9Z&X9ZWX9Z`X9ZV(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3`U,`IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(N&>F^&?@>&>
M@2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,S,*;7-G:60@(DYU
M;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(N&>A>&?AN&>D^&>O>&>D^*`
MB^&>C^&>O>&>HN&>@.&?DN&>G^&>FB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S-S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30S,0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#4S('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L
M=6UN<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S<U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,CD*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30U,2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D
M871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B
M3TLB"FUS9W-T<B`BX9Z9X9Z;X9^+X9Z6X9^2X9Z:X9Z8(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,0IM<V=I9"`B3V)J
M96-T(@IM<V=S='(@(N&>G.&>C^&?DN&>D.&>NR(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`X"FUS9VED
M(")/8W1A;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R("+AGH_A
MGKOAGIOAGK8B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3<*;7-G:60@
M(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS-#(*;7-G:60@(D]F9FEC92(*;7-G<W1R("+AGH#AGK;A
MGIKAGK?AGIGAGK;AGIOAGY#AGIDB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T
M(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C,V"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B
MX9Z6X9ZVX9Z`X9^2X9Z9XH"+X9Z?X9Z8X9^2X9Z$X9ZVX9Z/X9^+XH"+X9Z%
MX9ZVX9Z?X9^+(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V
M"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R("+AGJ+AGKSA
MGICAGX+AGI,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R
M960@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C$P,`IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U.2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.3<Y"FUS9VED(")/;FQY(&]N92!E;6%I;"!A
M9&1R97-S(&%L;&]W960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E
M<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES
M=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N
M97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,SD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M-#`*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(N&>E.&>
MON&>@.*`B^*`B^&>@.&?DN&>D^&>N^&>A.*`B^*`B^&>E.&>A.&?DN&>HN&>
MO>&>A>*`B^&>D.&?DN&>F.&>N"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N
M;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE
M=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4X"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(N&>E.&?DN&>
MFN&>EN&?D.&>D^&?DN&>DN*`B^&>E.&?DN&>FN&>C^&>M^&>E.&>C^&?DN&>
MC^&>M^&>@.&>MN&>FB(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`BX9Z'X9Z8X9^2X9Z:X9Z^
MX9Z?XH"+(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,R('1E;7!L871E<R]P
M<F5F<R]A<'`N:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@
M9F]R("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM
M<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")/<F=A;FES871I;VYA
M;"!5;FET(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ-#$*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N
M('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I
M;B`E<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R
M(@IM<V=S='(@(N&>E>&?DN&>G^&?@>&>A.&?ER(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Y"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,38@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$R-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-#0*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@
M(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<&%M+G!H<#HX,`IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N
M(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ
M36%I;"!B86-K96YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$R-S8*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,S(R"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W-`IM<V=I9"`B
M4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3,U-@IM<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T
M960@1&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-C@*
M;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL
M+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,
M:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!286EN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS
M9VED(")032!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3;F]W(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0Q"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-
M(%-U;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,PIM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W-`IM<V=I9"`B4$]325@@97AT
M96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z
M,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@
M(E!A9&1I;F<B"FUS9W-T<B`BX9Z%X9Z3X9^2X9Z;X9^$X9^'(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R("+AGI3AGXGAGK;AGH+A
MGKCAGI_AGY+AGI#AGK;AGI,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QA
M=2(*;7-G<W1R("+AGI3AGXGAGK;AGJ'AGKPB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS
M9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@(N&>E.&?
MB>&>MN&>CN&>MN&>F.&?B>&>MB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P
M=6$@3F5W($=U:6YE82(*;7-G<W1R("+AGI3AGXGAGK;AGI;AGKSAGHGAGKSA
MGISAGJ#AGY+AGH+AGKCAGH[AGX$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")0
M87)A9W5A>2(*;7-G<W1R("+AGI3AGXGAGK;AGIKAGXGAGK;AGJ#AGY+AGH+A
MGK;AGIDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS-@IM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y
M.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(V"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z-CD@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Y"FUS9VED(")0
M87-S=V]R9"(*;7-G<W1R("+AGI;AGK;AGH#AGY+AGIGB@(OAGI_AGICAGY+A
MGH3AGK;AGH_AGXLB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S
M,C,*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,34W"FUS9VED(")087-S
M=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Q"FUS9VED
M(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D
M.B(*;7-G<W1R("+AGI;AGK;AGH#AGY+AGIGB@(OAGI_AGICAGY+AGH3AGK;A
MGH_AGXO"H.&?EB(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q
M"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#0R"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D
M<R!M=7-T(&UA=&-H+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3$Y('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`BX9Z4X9ZWX9Z1X9Z7
MX9^2X9Z'X9ZVX9Z4X9^+(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R("+AGI7AGY+AGIOAGKSA
MGIPB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B
M4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3D*;7-G:60@(E!E;W!L92(*;7-G<W1R("+AGICAGI/AGKOA
MGI_AGY+AGI\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R("+AGI?AGK;AGH+A
MGIKAGIDB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N
M:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,3`*;7-G
M:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B
M"FUS9W-T<B`BX9Z2X9^2X9Z<X9Z^XH"+X9Z4X9^2X9Z:X9Z/X9ZWX9Z4X9Z/
MX9^2X9Z/X9ZWX9Z`X9ZVX9Z:XH"+X9Z/X9^&X9Z@X9^"X9Z1X9ZVX9^&(.&>
MEN&?@>&>F^*`B^&>A>&>O.&>FR`_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`BX9Z?
MX9ZWX9Z1X9^2X9Z2X9ZW(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@
M9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HU.3`*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*
M;7-G<W1R("+AGI_AGK?AGI'AGY+AGI+AGK<B"@HC.B!A9&UI;B]P97)M<R]E
M9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D
M;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C4X"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@*;7-G:60@(E!E<G-O
M;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(N&>EN&?D.&>C^&?C.&>F.&>MN&>
MD^*`B^&>E>&?DN&>D>&>MN&>F^&?B^*`B^&>@>&?DN&>F^&>O>&>DR(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R("+AGI3AGXGAGX'AGIKA
MGXGAGKPB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E!E
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE
M<R(*;7-G<W1R("+AGJ#AGY+AGISAGKCAGIOAGKCAGI;AGKCAGI,B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED
M(")0:&]N92(*;7-G<W1R("+AGI'AGKSAGIKAGI_AGY#AGI;AGY+AGI$B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DT"FUS9VED(")0:&]T;W,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS
M9W-T<B`BX9Z6X9ZXX9Z/X9Z!X9ZVX9Z9X9Z:X9ZWX9Z3(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I
M>&5L<R(*;7-G<W1R("+AGI?AGKCAGH#AGI_AGX+AGILB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@
M=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C4W,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N
M=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E
M<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#4*;7-G:60@(E!L96%S92!E
M;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3$*;7-G:60@(E!L96%S92!E;G1E<B!A
M('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@
M;6]N=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(T-34*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G
M:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O
M=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S
M92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET
M:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP
M.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD(@IM<V=S
M='(@(N&>E.&?B>&>O.&>H>&>O.&>B2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,@IM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C4P,PIM<V=I9"`B4&]L;',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`BX9Z6
MX9^0X9Z:X9Z1X9Z[X9Z9X9Z@X9^2X9Z"X9ZVX9Z;X9^+(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W
M"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q
M"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS
M9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!
M4"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E
M8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,0IM<V=I9"`B4')E
M8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O;&1A<"YP:'`Z,3,S"FUS9VED(")0<F5F<U]L9&%P
M.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C,W"FUS9VED(")0<F5S<W5R
M92(*;7-G<W1R("+AGI_AGICAGY+AGI;AGK;AGI(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(W,0IM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R
M.0IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`T"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I
M9"`B4')E=FEE=R(*;7-G<W1R("+AGICAGK[AGIOB@(OAGH?AGK;B@(OB@(OB
M@(OAGICAGKOAGI,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM
M86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C,U-R!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C,V,0IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q
M"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H
M<#HQ-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<')O8FQE;2YP:'`Z,3(W"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#4*;7-G
M:60@(E!R;VIE8W1S(@IM<V=S='(@(N&>@N&>F.&?DN&>FN&?A.&>A"(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3D@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@W
M"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS
M9W-T<B`BX9Z`X9Z\X9Z3X9Z?X9^$XH"+X9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9^(
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#8*;7-G
M:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@
M2V5Y($EN9F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO
M="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`P"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R("+AGI;AGY#AGIKA
MGH_AGKSAGIKAGKCAGH#AGKPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1871A
M<B(*;7-G<W1R("+AGH#AGK;AGH_AGK8B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@(N&>G^&?AN&>CN&>O>&>FN*`
MBR(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B475O=&$B
M"FUS9W-T<B`BX9Z`X9Z\X9Z/X9ZV(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U
M8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(W,@IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0T"FUS9VED(")286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN($5A<FQY(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0V"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@
M4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y
M"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B
M4F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T<B`BX9ZBX9ZVX9Z3(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*;7-G
M:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E
M86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R
M+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E
M<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C
M=&EO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G
M<W1R("+AGI+AGY+AGISAGK[B@(OAGK+AGY+AGIGB@(OAGI_AGY+AGIKAGI_A
MGXLB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDU"FUS9VED(")2969R
M97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,T-0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@
M5FEE=SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N
M:6YC.CDT"FUS9VED(")2969R97-H(')A=&4Z(@IM<V=S='(@(N&>HN&>C^&?
MDN&>FN&>MN*`B^&>DN&?DN&>G.&>ON*`B^&>LN&?DN&>F>*`B^&>G^&?DN&>
MFN&>G^&?B\*@X9^6(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(T,@IM<V=I9"`B4F5L871I;VYS
M:&EP($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM
M<V=I9"`B4F5L;V%D(@IM<V=S='(@(N&>E>&?DN&>D>&>N^&>@.*`B^&>H>&>
MON&>A.*`B^&>G.&>M^&>B2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,X
M"FUS9VED(")296UA<FMS(@IM<V=S='(@(N&>@.&?AN&>CN&>C^&?B^*`B^&>
MG^&>F.&?DN&>@N&>MN&>F^&?BR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,3<*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%52
M3"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHX('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,C(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E<75E=65D+FEN8SHQ,PIM<V=I9"`B4F5M;W9E(@IM<V=S='(@(N&>F>&>
M@.*`B^&>A>&?@>&>B2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HU-3<*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M,`IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G
M:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A
M<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@(E)E;6]V
M92!T:&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N
M;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U<V5R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI
M;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ,S@@
M9G)A;65W;W)K+U)00R]24$,O<&AP9W<N<&AP.C$W,PIM<V=I9"`B4F5Q=65S
M="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U
M,`IM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W
M-B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4S,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C<P-"!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@V,0HC
M.B!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z-#$@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C<S,0HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M97%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z
M-S<V"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@
M<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-`IM<V=I9"`B4F5Q
M=6ER960@1FEE;&0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S0S"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTO4F5N9&5R97(N<&AP.C,Q.2!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(N&>@.&?AN&>CN&>C^&?B^*`B^&>
MH>&>ON&>A.*`B^&>G.&>M^&>B2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C0V"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@
M66]U<B!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3,P"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR
M."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T
M<B`BX9Z;X9Z1X9^2X9Z2XH"+X9Z5X9Z;(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS
M9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R("+AGH_AGY+AGIKAGJ'A
MGI3AGXOB@(OAGI'AGX7B@(OAGH?AGICAGY+AGIKAGK[AGI\B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N97<@
M<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U
M;FEO;B(*;7-G<W1R("+AGIKAGKCAGJ+AGKOAGIGAGI/AGKCAGIGAGXGAGKOA
MGH0B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@
M(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R("+B@(OAGI_AGY+AGH_AGK;A
MGX8B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$T"FUS9VED(")2
M:6=H="!H96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S$Q,`IM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G
M:60@(E)O;&4B"FUS9W-T<B`BX9Z/X9Z]X9Z3X9ZVX9Z1X9ZX(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R("+AGIKAGKSAGICAGXGA
MGK;AGI/AGK@B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C(T"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C$*;7-G:60@
M(E)O=&%T92!,969T(@IM<V=S='(@(N&>E.&>A.&?DN&>G.&>M^&>F^*`B^&>
MD>&?A>*`B^&>AN&?DN&>G.&?@>&>A"(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR,C<*;7-G:60@(E)O=&%T92!2:6=H="(*
M;7-G<W1R("+AGI3AGH3AGY+AGISAGK?AGIOB@(OAGI'AGX7B@(OAGI_AGY+A
MGHKAGK;AGX8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM
M<V=I9"`B4F]W<SHB"FUS9W-T<B`BX9Z'X9Z]X9Z:XH"+X9Z*X9^!X9Z`PJ#A
MGY8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED
M(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU
M;6YS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@
M(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*;7-G:60@(E)U;B(*;7-G
M<W1R("+AGIKAGH_AGXOB@(LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S
M:6%N($9E9&5R871I;VXB"FUS9W-T<B`BX9Z?X9Z@X9Z6X9^0X9Z3X9^2X9Z2
MXH"+X9Z:X9Z[X9Z?X9^2X9Z?X9^*X9ZX(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I
M9"`B4G=A;F1A(@IM<V=S='(@(N&>FN&>G.&?B>&>MN&>D^&?B^&>BN&>MB(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED
M(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@
M(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@R"FUS9VED(")305-,(&%U=&AE
M;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C`*;7-G:60@(E--4R!-97-S86=I
M;F<B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED
M(")344P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(X-0IM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O
M:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#0W"FUS9VED(")34T@B"FUS9W-T<B`B4U-((@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS
M-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ
M-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM
M<V=S='(@(N&>G^&>A.&?B^*`B^&>H.&?@>&>H>&?@>&>CN&>MB(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@
M(N&>G^&>A.&?B^&>@^&>N.&>CR#AGI/AGK?AGH0@X9Z3X9^!X9Z<X9ZXX9Z?
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,SD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@W"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R("+A
MGI_AGH3AGXOAGIOAGKSAGI_AGXKAGKCAGIGAGXGAGK8B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@
M(N&>G^&>A.&?B^*`B^&>EN&?DN&>F>&?@N&>FB#AGI/AGK?AGH0@X9Z8X9ZX
MX9Z"X9Z[X9Z9X9ZBX9^!X9ZAX9Z[X9Z$(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I
M9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B
MX9Z?X9Z$X9^+X9Z<X9ZVX9^&X9Z$X9Z?X9Z$X9^+(.&>D^&>M^&>A"#B@(OA
MGJ#AGY+AGH+AGY+AGIKAGKCAGH[AGK;AGHSAGKCAGI,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE
M(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I
M9"`B4V%M;V$B"FUS9W-T<B`BX9Z?X9ZVX9Z8X9Z\X9ZBX9ZV(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R("+AGI_AGK;AGI/A
MGXOAGICAGXGAGK;AGIKAGKCAGH[AGKPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED
M(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B4V%O(%1O;64@86YD
M(%!R:6YC:7!E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I82(*;7-G<W1R("+AGJ+AGK;A
MGIKAGXGAGK;AGI3AGXOB@(OAGI3AGXKAGKCAGI_AGK;AGJ+AGKSAGHSAGK@B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$U"FUS9VED(")3
M879E(@IM<V=S='(@(N&>FN&>@.&?DN&>G^&>MN*`B^*`B^&>D>&>N^&>@.*`
MB^*`BR(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E
M9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`BX9Z:
MX9Z`X9^2X9Z?X9ZVXH"+X9Z1X9Z[X9Z`XH"+(.&>A^&>F.&?DN&>FN&>ON&>
MGR(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A
M=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O
M('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3`*;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E-C:65N
M8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI
M;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@
M(E-E87)C:"(*;7-G<W1R("+AGI_AGY+AGISAGX+AGH3AGIKAGH`B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,V"FUS9VED(")396%R8V@@16YG
M:6YE<R(*;7-G<W1R("+AGICAGXGAGK;AGI_AGXKAGKCAGI/B@(OAGI_AGY+A
MGISAGX+AGH3AGIKAGH`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.38V"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X,PIM<V=I9"`B4V5L
M96-T(&$@9&%T92(*;7-G<W1R("+AGH?AGY+AGIKAGK[AGI_B@(OAGH#AGK;A
MGIOAGI3AGIKAGK?AGH7AGY+AGH;AGX'AGI$B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@861D
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*
M;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E
M<G9E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-`IM
M<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R("+AGH?AGY+AGIKAGK[AGI_B@(OA
MGI'AGK;AGX;AGH3AGJ+AGI_AGXLB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-C4T"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C@W,0IM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<U
M"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R("+AGH?AGY+AGIKAGK[AGI_B
M@(OAGH+AGY+AGICAGK;AGI,B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z
M,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F
M<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*
M(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H
M92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C
M="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@
M=&\@8VAA;F=E.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE
M+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@
M(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T
M8VAI;F<@9FEE;&1S+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S$P"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3(*;7-G:60@
M(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E
M;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-#`*;7-G:60@(E-E;F0@4TU3
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS
M9W-T<B`BX9Z?X9^!X9Z.X9^!X9Z@X9^2X9Z"X9ZVX9Z;X9^+(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,C@*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S
M"FUS9VED(")397!T96UB97(B"FUS9W-T<B`BX9Z`X9Z)X9^2X9Z)X9ZV(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@
M(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R("+AGI_AGX+AGI3AGXKA
MGK@@X9Z3X9ZWX9Z$(.&>F.&?B>&>N^&>A.&>C^&?@>&>CN&?@>&>H.&?DN&>
M@.&?DN&>FN&>O"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-S`R"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(N&>F^&?@>&>
M@>*`B^&>G^&>F.&?DN&>@N&>MN&>F^&?BR(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-30*;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS
M+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*
M;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+V%P:2YP:'`Z,30U"FUS9VED(")397-S:6]N<R(*;7-G<W1R("+AGI_AGICA
MGY#AGIDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S(R"FUS9VED
M(")3970B"FUS9W-T<B`BX9Z`X9^&X9Z.X9Z/X9^+(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<Y"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y
M;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@
M:70N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3@*
M;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O
M(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#<*;7-G:60@(E-E="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,0IM<V=I9"`B(@HB
M4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P
M86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*;7-G
M:60@(E-E='5P(@IM<V=S='(@(N&>BN&?AN&>H>&>ON&>A"(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U
M<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.#`*;7-G:60@(E-E=F5R86P@;&]C
M871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B
MX9Z?X9ZXX9Z?X9^2X9Z@X9^"X9Z;(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C4Q,@IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U
M;6UA<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U
M,`IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO
M<W0@;&EN:W,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(N&>E.&>A.&?
MDN&>H.&>MN&>B2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G
M:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V
M960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y-`IM<V=I
M9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S<S"FUS9VED
M(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#8*;7-G:60@(E-H;W<@<&EC
M:V5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S`*
M;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O
M<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED(")3:&]W
M('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO
M9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R
M;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$W-S$*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS
M9VED(")3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S($5A<FQY(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4S"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-H
M;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#<Q"FUS9VED(")3
M:')I;FLB"FUS9W-T<B`BX9Z4X9Z$X9^2X9Z:X9Z]X9Z)(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HW-C(*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HX,C0*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HY,3`*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HY
M-S(*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HQ,#,U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z,3`W-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C$Q,#0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HQ,3,W"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG
M:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S
M='(@(N&>G^&?@>&>FN&?B>&>MN&>H>&?@>&>HN&>O.&>DR(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C<*;7-G:60@(E-I9VX@=7`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HW,3,*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R("+AGJ#AGH_AGY+AGI#A
MGIOAGX'AGH'AGK8B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`BX9Z?
MX9ZYX9Z$X9^2X9Z@X9Z4X9Z[X9Z:X9ZX(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3`P"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3D@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(T,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C4T(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C,*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$Q-@IM<V=I9"`B4VEZ92(*;7-G<W1R("+AGI'AGX;AGJ#A
MGX8B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M
M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`U"FUS9VED(")3;&]V86MI82(*;7-G<W1R("+AGI_AGY+AGIOA
MGKSAGISAGXGAGK;AGH+AGK@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V
M96YI82(*;7-G<W1R("+AGI_AGY+AGIOAGKSAGISAGXGAGK;AGI/AGK@B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I
M9"`B4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*
M;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W
M97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,`IM<V=I9"`B
M4VYO=R!D97!T:#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,CDT"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B
M"FUS9W-T<B`BX9Z`X9^$X9^'XH"+X9Z?X9Z\X9ZAX9Z\X9Z8X9^)X9Z\X9Z3
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R("+AGI_A
MGKSAGICAGXGAGK;AGIOAGK@B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C4*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,CDQ.0IM<V=I9"`B4V]R="!O<F1E<B!S96QE
M8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C$X.0IM<V=I9"`B4V]U<F-E(&%D9')E
M<W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R
M:6-A(@IM<V=S='(@(N&>HN&>MN&>H.&?DN&>FN&>M^&>@.*`B^*`B^&>@>&>
MMN&>A.*`B^&>C^&?DN&>E.&>O.&>A"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@V"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N
M9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R("+AGJ#AGY+A
MGI_AGH#AGJ#AGY+AGI_AGXKAGKCB@(OAGH'AGK;AGH3B@(OAGH_AGY+AGI3A
MGKSAGH0@X9Z3X9ZWX9Z$(.&>@.&?A.&?A^&>G^&>MN&?AN&>A.&>G.&>M^&>
MA>*`B^&>@>&>MN&>A.*`B^&>C^&?DN&>E.&>O.&>A"(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O
M=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E
M='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E
M(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$Y"FUS9VED(")3<&%C
M97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(N&>
M@N&>F.&?DN&>F^&>MN&>CR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A
M9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM
M<V=S='(@(N&>HN&?@>&>G^&?B>&?DN&>E.&>MN&>B2(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ,#<*;7-G:60@(E-P86TB"FUS9W-T<B`BX9Z?
MX9ZVX9Z:XH"+X9ZEX9Z/XH"+X9Z4X9ZVX9Z3XH"+X9Z`X9ZVX9Z:(@H*(SH@
M<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A
M8W1E<B!);G!U="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")3<&]R=',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`BX9Z?
MX9^2X9Z:X9ZXX9Z;X9Z$X9^2X9Z`X9ZV(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C<Q(&QI8B]";&]C:R]M971A<BYP:'`Z.#8*;7-G:60@
M(E-T86YD87)D(@IM<V=S='(@(N&>@>&?DN&>D^&>MN&>C^*`B^&>@N&?AN&>
MFN&>O"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-PIM<V=I9"`B4W1A
M<B!4<F5K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(U.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P,@IM<V=I9"`B4W1A
M<G0@>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4W,0IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*
M;7-G:60@(E-T871U<R(*;7-G<W1R("+AGI_AGY+AGI#AGK;AGI/AGI?AGK;A
MGI8B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`X"FUS9VED(")3
M=&]R86=E(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B4W1R965T($%D9')E<W,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R("+AGI3AGI/A
MGY+AGI'AGK;AGH_AGXOB@(OAGH;AGKSAGH\B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C,W"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#@Q"FUS9VED(")3=')I
M<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS
M9VED(")3='EL92!;0U-372(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R
M("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`BX9Z4X9^2X9Z:X9Z2X9ZV
MX9Z3XH"+X9Z4X9Z1(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,V
M(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-@IM<V=I9"`B
M4W5B;6ET(@IM<V=S='(@(N&>BN&>MN&>@.&?B^*`B^&>G^&?DN&>D^&>OB(*
M"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B
M;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9
M;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E
M96X@87!P<F]V960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G
M<W1R("+AGJ+AGH#AGY+AGI_AGIKB@(OAGH_AGKSAGH7B@(OAGH#AGY+AGIKA
MGX3AGI@B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`T"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP
M:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`BX9Z'X9^$X9Z"X9Z'X9^0
MX9Z9(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<
M(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I
M;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C4W"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H
M92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R
M("+AGI_AGXKAGKSAGHKAGH3AGXLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y(@IM
M<V=S='(@(N&>G^&>A.&?DN&>@>&?@>&>E"(*"B,Z(&QI8B]";&]C:R]S=6YR
M:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P
M"FUS9VED(")3=6YN>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C$P"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P.0IM<V=I9"`B4W5N<FES93H@
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,3,*;7-G:60@(E-U;G-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C$R"FUS9VED(")3=6YS970Z("(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S
M"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R("+AGJ+AGH#AGY+AGI_AGIKB
M@(OAGH_AGKSAGH7B@(OAGIOAGKXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,SDT"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(N&>@N&>MN&?AN&>
MD>&?DN&>FB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM<V=S
M='(@(N&>G^&?BN&>O.&>FN&>N.&>CN&>MN&>F.&>N"(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")3=7)N86UE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*
M86X@36%Y96XB"FUS9W-T<B`BX9Z?X9^2X9Z<X9ZVX9Z;X9^+X9Z4X9ZVX9Z/
M(.&>D^&>M^&>A"#AGJ#AGY+AGI_AGH3AGXOAGICAGXGAGK;AGIGAGX'AGI,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`BX9Z?
MX9^2X9Z<X9ZVX9Z@X9^2X9Z?X9^*X9ZXX9ZAX9Z$X9^+(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(N&>G^&?BN&>N^&>F>&>HN&?
M@N&>BB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R
M("+AGI_AGY+AGISAGXKAGKCAGI\B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30U"FUS9VED(")3>6YC34PB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP
M.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B
M;&EC(@IM<V=S='(@(N&>G^&>MN&>DN&>MN&>FN&>CN&>FN&>BN&?DN&>B^*`
MB^&>HN&>MN&>FN&?B>&>MN&>E.&?BR#AGI_AGXKAGKCAGIKAGK@B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B
M5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C,*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4+5-T;W)M
M<R!%87)L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+W1S
M=BYP:'`Z,38V"FUS9VED(")44U8@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S-`IM<V=I9"`B5&%B;&4B"FUS9W-T
M<B`BX9Z/X9ZVX9Z:X9ZVX9Z$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R
M=&EE<R(*;7-G<W1R("+AGIOAGH#AGY+AGH'AGH[AGXCB@(OAGI_AGICAGY+A
MGI3AGH_AGY+AGH_AGK?B@(OAGH_AGK;AGIKAGK;AGH0B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS9VED(")486)L
M92!3970B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE
M<R(*;7-G<W1R("+AGIOAGH#AGY+AGH'AGH[AGXCB@(OAGI_AGICAGY+AGI3A
MGH_AGY+AGH_AGK?B@(OAGIKAGI3AGI_AGXOB@(OB@(OAGH_AGK;AGIKAGK;A
MGH0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-"!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS9W-T
M<B`BX9Z/X9^#X9Z<X9^)X9ZVX9Z3X9^+(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@
M;V8@0VAI;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J
M:6MI<W1A;B(*;7-G<W1R("+AGH_AGK;AGHKAGJ#AGY+AGI_AGXKAGKCAGH+A
MGKCAGI_AGY+AGH_AGH3AGXLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ
M86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A
M<F=E=#HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P
M-S`@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5&%S:W,B
M"FUS9W-T<B`BX9Z7X9ZVX9Z:X9Z`X9ZWX9Z%X9^2X9Z%(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*;7-G:60@(E1E;&5P:&]N
M92!.=6UB97(B"FUS9W-T<B`BX9Z;X9^!X9Z!XH"+X9Z1X9Z\X9Z:X9Z?X9^0
MX9Z6X9^2X9Z1(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#(*;7-G:60@
M(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C(V"FUS9VED(")496UP97)A='5R92(*;7-G<W1R("+A
MGI_AGKCAGH_AGKOAGH[AGY+AGJ#AGI?AGK;AGI8B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C$W"FUS9VED(")496UP97)A='5R93H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S
M+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M
M<&QA=&4O5&5M<&QA=&4N<&AP.C8Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M96UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R
M871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X"FUS9VED(")497AT
M(@IM<V=S='(@(N&>HN&>C^&?DN&>D.&>E.&>D2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-SD*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R("+AGH_A
MGX+AGJ+AGH_AGY+AGI#AGI3AGI$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B
M5&@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G
M:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*
M;7-G:60@(E1H86EL86YD(@IM<V=S='(@(N&>D.&?@R(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#4Q"FUS9VED(")4:&4@1E10(&5X=&5N<VEO
M;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&ES=&]R>2](:7-T;W)Y+G!H<#HV,PIM<V=I9"`B5&AE($AI<W1O<GD@<WES
M=&5M(&ES(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDS,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R
M9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@
M7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0
M+T)O;VLN<&AP.C$R.3@*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@
M8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@
M9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T
M:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C0@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI
M;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M
M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S
M:6]N<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E
M(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$
M(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@
M;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS9VED
M(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@
M861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,3<R"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0
M('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I
M9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I
M<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@
M;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A
M<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C;VYF
M:7)M+G!H<#HR.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@96UA:6P@
M861D<F5S<R`E<R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R(&ED96YT:71I97,N
M(%EO=2!C86X@8VQO<V4@=&AI<R`B"B)W:6YD;W<@;F]W+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q-@IM<V=I9"`B5&AE
M(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N
M;F5C=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-S<@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E
M<R!S971T:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C$W,"!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4R,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S
M;VUE("5S('-E='1I;F=S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR,CD*;7-G:60@(E1H92!F:6QE(&-A;FYO="!B92!C
M;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO
M(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H
M92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN
M;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L
M(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@
M=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A
M9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R
M86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@
M5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A
M("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E
M8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P
M<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R
M965N(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP
M.C$R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB
M(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H
M92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T
M:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@
M0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O341.+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E
M<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N
M=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T
M;V]D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#@U"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H
M92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N
M<&AP.CDT"FUS9VED(")4:&4@;F5W(&9R;VT@861D<F5S<R!C86XG="!B92!V
M97)I9FEE9"P@=')Y(&%G86EN(&QA=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#<T"FUS9VED(")4:&4@;G5M8F5R
M(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,@IM<V=I9"`B5&AE
M(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y
M<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+G!H<#HR.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E
M(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S
M:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O96YS
M8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS
M<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E
M8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<W)C
M:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P
M<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N
M;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#@W"FUS9VED(")4:&4@<75O=&4@8VAA
M<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@
M;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HT-SD*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE
M(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P
M8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<
M(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S<&5C:69I
M960@<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C`R"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,3,*
M;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE
M('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B
M5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T1A=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@
M9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M
M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D
M960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-"!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,3$U"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@
M:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R
M;W=S97(N<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E
M8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O8V]N9FER;2YP:'`Z,3<@<V5R=FEC97,O8V]N9FER;2YP:'`Z,C$*;7-G
M:60@(E1H97)E(&%R92!N;R!E;6%I;"!A9&1R97-S97,@=&\@8V]N9FER;2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ
M-S@*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M,S0U"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES
M<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30P.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A
M<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V
M92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE
M<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI
M;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@
M=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E
M;3H@(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG(%PB
M)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O
M=W-E<BYP:'`Z.3$P"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO
M861E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.3$U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R
M9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E
M<RDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N
M<&AP.CDQ-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@
M<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G
M<W1R("+AGICAGK;AGI/B@(OAGH#AGX;AGJ#AGKOAGI_B@(OAGICAGKWAGID@
MX9Z`X9^2X9Z3X9Z[X9Z$XH"+X9Z`X9ZVX9Z:XH"+X9Z4X9Z$X9^2X9Z@X9ZV
MX9Z)XH"+X9Z5X9^2X9Z3X9^"X9Z`XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9ZV
MX9Z:XH"+X9Z3X9^!X9^'(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@R"FUS9VED("(B"B)4:&5R
M92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R
M:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M
M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A
M<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E
M=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"FUS
M9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R
M:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S
M:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@
M87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G
M:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I
M;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,S@*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A
M<F0@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I
M=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L
M:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@
M=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R
M:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!7
M24X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E
M;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG
M('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@
M=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T
M;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O
M=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET
M*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@R
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C$*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3`Y,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$Y
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#8@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(V,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S`Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#8*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,34V-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#0W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C8@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#8*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,C(Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,38@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C0U.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-C0X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,C$*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S,"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,S`X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,38@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R-`IM<V=I9"`B5&AI<R!F:65L9"!I
M<R!R97%U:7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3`V.0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&EN=&5G97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-#(T"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#DX"FUS9VED(")4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(W"FUS9VED(")4:&ES(&9I96QD(&UU
M<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E
M9V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY
M.3,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R.0IM
M<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E
M(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T
M868G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU
M-C4*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N
M(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B
M"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E
M(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@
M<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C4Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E
M<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R
M(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@
M<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN
M<&AP.C$X,@IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T
M:79A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R
M+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N
M<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M
M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")4:'5N9&5R(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3`*;7-G
M:60@(E1I8VME=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C0S,R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G
M:60@(E1I;64B"FUS9W-T<B`BX9Z6X9^!X9Z;XH"+X9Z<X9^!X9Z;X9ZVXH"+
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,@IM<V=I9"`B5&EM
M92!4<F%C:VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z
M,C(*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(N&>D>&?DN&>FN&>A.&?
MB^*`B^&>D>&?DN&>FN&>MN&>F>*`B^*`B^*`B^*`B^&>EN&?@>&>F^*`B^*`
MB^&>G.&?@>&>F^&>MN*`BR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(U,SD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(N&>A>&?
MAN&>CN&>A.*`B^&>A^&>ON&>A"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`BX9Z1X9^%(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U,@IM<V=I9"`B
M(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O
M;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC
M:VEN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,P,PIM<V=I9"`B5&]D87DB"FUS9W-T<B`BX9Z0X9^2X9Z$X9^#XH"+
MX9Z3X9^!X9^'(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T<B`BX9Z/X9Z\
MX9Z@X9^2X9Z"X9^$(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*
M;7-G<W1R("+AGH_AGKSAGH#AGX'AGJ'AGK;AGJ+AGXKAGKPB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`U"FUS9VED(")4;VUO<G)O=R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R
M("+AGH_AGKOAGH3AGJ#AGY+AGH+AGX0B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G
M<W1R("+AGH#AGX;AGI;AGKSAGILB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV.`IM<V=I
M9"`B5')A;G-L871I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G
M:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`BX9Z1X9^2X9Z:X9ZX
MX9Z3X9ZXX9Z*X9ZVX9Z*(.&>D^&>M^&>A.*`B^*`BR#AGH_AGKSAGI3AGK;A
MGJ#AGY+AGH+AGX0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDX
M"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T
M<B`BX9Z1X9Z[X9Z9X9Z.X9^!X9Z?X9^*X9ZX(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM
M<V=I9"`B5'5R:V5Y(@IM<V=S='(@(N&>D>&>O>&>FN&>@N&>N"(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")4=7)K:7-H("A)4T\M.#@U
M.2TY*2(*;7-G<W1R("+AGI'AGKWAGIKAGH+AGK@@*$E33RTX.#4Y+3DI(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(N&>
MD>&>O>&>@N&>F.&?@>&>D^&>N.&>G^&?DN&>C^&>A.&?BR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R
M("+AGH#AGX3AGX?B@(OAGI'AGKWAGH`@X9Z3X9ZWX9Z$XH"+(.&>@.&?@^&>
M@.&>O.&>GR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R
M("+AGI'AGKOAGIGAGISAGXGAGK;AGIOAGKOAGIDB"@HC.B!F<F%M97=O<FLO
M0TQ)+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V,PIM
M<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B
M55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T<B`B55),.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G<W1R("+AGJ+AGXKAGKSAGJ#AGY+A
MGH+AGH3AGXOAGHKAGK8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A:6YE
M(@IM<V=S='(@(N&>HN&?BN&>N^&>F>&>@.&?DN&>FN&?@N&>DR(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0R,@IM<V=I9"`B56YA8FQE('1O
M(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,SDU(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!6
M1E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HW.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Y."!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C$P-C,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C@U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@
M9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HX-S`*;7-G:60@(E5N86)L92!T;R!C;VYN
M96-T('=I=&@@4U-,+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR,S4@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C0P
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#0@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P.0HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,C$W"FUS9VED(")5;F%B;&4@=&\@8V]P>2!6
M1E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HS-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,S8T(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C(V-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Y,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M-S4*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N
M<&AP.C<V"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H
M<#HW.0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,C@@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HS,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T
M(&5M<'1Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-#$@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HT,3@*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C,Q,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0R"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E
M8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS-38@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C,V,`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER
M96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HS-#<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C0T,R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0U
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GDZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C(Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,S$S(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,S$T"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ-C<@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X,`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HS.3$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,Y.0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HT,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@S-`IM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN
M92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#0*;7-G:60@(E5N86)L92!T;R!E
M>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0S-R!F<F%M97=O<FLO3F5T7TE-
M4U`O24U34"]!=71H+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P-B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR,3$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$W-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,3<Y"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C$P-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C8U,B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@W
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T,0IM<V=I9"`B56YA8FQE('1O
M(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@Q(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C@V"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$T
M,"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S8*;7-G:60@(E5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@
M=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HX-38*;7-G:60@(E5N86)L92!T;R!R96%D
M(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HX.#<*;7-G:60@(E5N86)L92!T;R!R
M96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE
M<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8W.0IM
M<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q,#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E
M<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G
M:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS-34*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M-S$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-#@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8R,"!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S0Y(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,3,*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C0U,B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,CDS"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,#D*
M;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S
M+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP
M:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O
M8W5M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,34T(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34W"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$X
M.0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I
M;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,CDQ(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#8*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$U,0IM<V=I9"`B56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HX-C(*;7-G:60@(E5N86)L92!T;R!W<FET
M92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(N&>@N&>O.&>G^*`B^&>E.&>
MD^&?DN&>D>&>MN&>C^&?B^*`B^&>@.&?DN&>FN&?A.&>F"(*"B,Z('1E;7!L
M871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR
M,C,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP
M"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O
M;FYE8W1I;VXZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,W.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS.#0*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O
M;2!S97)V97(@=&\Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*
M;7-G<W1R("+AGICAGK?AGI/B@(OAGI3AGK;AGI/B@(OAGIKAGX#AGI3AGH7A
MGX8B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B56YI8V]D
M92`H551&+3@I(@IM<V=S='(@(N&>F>&>O.&>D^&>N.&>@.&>O.&>BB`H551&
M+3@I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S
M(@IM<V=S='(@(N&>HN&>MN&>FN&?B>&>MN&>E.&?B^*`B^&>FN&>O>&>F"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B
MX9Z%X9Z`X9^2X9Z:XH"+X9Z7X9Z6XH"+X9ZBX9Z$X9^+X9Z"X9^2X9Z;X9^!
MX9Z?(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G
M<W1R("+AGI_AGJ#AGIKAGHKAGY+AGHOAGJ+AGK;AGICAGX'AGIKAGK?AGH`B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U
M=&QY:6YG($ES;&%N9',B"FUS9W-T<B`BX9Z`X9^$X9^'XH"+X9Z&X9^2X9Z$
MX9ZVX9Z9X9^7XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9Z@X9Z:X9Z*X9^2X9Z+
MXH"+X9ZBX9ZVX9Z8X9^!X9Z:X9ZWX9Z`(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C8W(&QI8B]";&]C:R]M971A<BYP:'`Z.#,*;7-G:60@
M(E5N:71S(@IM<V=S='(@(N&>K^&>@.&>C^&>MB(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0R.2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HU.`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R("+AGICAGK?AGI/B@(OA
MGI_AGY+AGH+AGK;AGIOAGXLB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G
M:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5
M;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3(*;7-G:60@
M(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM
M<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP
M.C,P,@IM<V=I9"`B56YN86UE9"(*;7-G<W1R("+AGH+AGY+AGICAGK;AGI/B
M@(OAGHCAGY+AGICAGX3AGX<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R
M:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC
M86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E
M92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H
M;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C
M;&EP8F]A<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C@W(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3(W"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3,S"FUS9VED(")5
M;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R("+AGI+AGY+AGISA
MGK[B@(OAGK+AGY+AGIGB@(OAGI'AGK;AGI/AGXOB@(OAGI_AGICAGY#AGIDB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@
M=7-E<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI
M;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@
M(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$Y.`IM<V=I9"`B57!L;V%D(@IM<V=S='(@(N&>E>&?
MDN&>D>&>N^&>@.*`B^&>H>&>ON&>A"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U
M<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS
M9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*
M;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R("+AGJ+AGXKAGKOAGIGA
MGIKAGXGAGK;AGJ#AGY+AGH+AGK;AGIDB"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S
M92!34TPB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M-PIM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O
M<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHR,0IM<V=I9"`B57-E<B(*;7-G<W1R("+AGJ+A
MGY+AGI/AGH#B@(OAGI3AGY+AGIKAGKXB"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O4F5G:7-T<GDN<&AP.C<V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(N&>@.&>MN&>FN*`B^&>@N&?DN&>FN&>E.&?B^&>@N&?
MDN&>FN&>A.*`B^&>HN&?DN&>D^&>@.*`B^&>E.&?DN&>FN&>OB(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C0U"FUS9VED(")5<V5R($]P
M=&EO;G,B"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E
M<B!296=I<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HR,@IM
M<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R
M('1H:7,@<VET92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C0V.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET
M86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS
M,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C8T('1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G
M<W1R("+AGHCAGY+AGICAGX3AGX?B@(OAGJ+AGY+AGI/AGH#B@(OAGI3AGY+A
MGIKAGKXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(U
M"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y
M(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`BX9Z(X9^2X9Z8
MX9^$X9^'XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z4X9^2X9Z:X9Z^PJ#AGY8B"@HC
M.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5<V5R;F%M
M93H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`BX9ZB
MX9^*X9Z\X9Z@X9^2X9Z?X9Z4X9^!X9Z"X9ZXX9Z?X9^2X9Z/X9Z$X9^+(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3<S(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(V-0IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S
M(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$R-PIM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#<P"FUS9VED(")686QI9"!L;V-A=&EO
M;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(")686QI9&ET>2(*;7-G
M<W1R("+AGI_AGKOAGI;AGIOAGI?AGK;AGI8B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E9A
M;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C@V,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3@Q"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE
M(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,C4R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R-S0*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,R-"!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.3(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO
M5'EP92]T86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R("+A
MGH_AGICAGY+AGIOAGX,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,3$W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.30*;7-G:60@(E9A;'5E
M<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS
M9VED(")686YU871U(@IM<V=S='(@(N&>G.&?B>&>MN&>D^&>N^&>F>&>HN&>
MMN&>D>&>N^&>F2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,S@*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(N&>HN&>D.&?@>&>FB(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R("+AGISAGX'A
MGH[AGX'AGJ#AGY+AGI_AGKOAGIGAGJ+AGX'AGJ'AGK8B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T
M:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E
M<F5D('=I=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-S`Q"FUS9VED(")697)S:6]N(@IM<V=S='(@(N&>@.&?
MAN&>CN&?@B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#(*;7-G
M:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R("+AGH#AGK;AGIKB@(OAGH_A
MGY+AGIKAGKWAGH_B@(OAGI;AGK?AGI/AGK?AGH_AGY+AGIGB@(OAGH#AGX;A
MGH[AGX(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T
M"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E
M<G1I8V%L.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I970@3F%M(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")6:65T;F%M97-E("A6
M25-#24DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.CDW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM
M<V=S='(@(N&>F.&>ON&>FR`E<R(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(W"B,L
M('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L
M(%4N4RXB"FUS9W-T<B`BX9Z`X9^$X9^'XH"+X9Z<X9ZXX9Z'X9ZXX9Z3(.&>
MG^&>H.&>FN&>BN&?DN&>B^*`B^&>HN&>MN&>F.&?@>&>FN&>M^&>@"(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C(Q"FUS9VED(")6:7-I8FEL:71Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3<*
M;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B
M5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'
M(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*
M;7-G:60@(E=)3B!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W
M"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R("+AGISAGXGAGK;A
MGIOAGKCAGI\@X9Z3X9ZWX9Z$(.&>H.&?DN&>G.&?BN&>O.*`B^&>D>&>N^&>
MF>&>CN&>MB(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:'1M;"YP:'`Z,3(T(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HX,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R("+AGI;AGY+AGIKAGICAGK;A
MGI,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C4X"FUS9VED(")792(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S0*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q.0IM<V=I
M9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-@IM<V=I9"`B5V5A=&AE<BYC;VTB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@
M(E=E8B(*;7-G<W1R("+AGISAGK?AGI0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#4S"FUS9VED(")796(@4VET92(*;7-G<W1R("+AGH_AGX;A
MGI3AGI/AGXOAGI3AGH[AGY+AGH_AGK;AGHDB"@HC.B!F<F%M97=O<FLO36%I
M;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS
M9W-T<B`BX9Z:X9ZVX9Z;X9^+XH"+X9Z?X9Z4X9^2X9Z*X9ZVX9Z@X9^-(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@(E=E;&-O
M;64B"FUS9W-T<B`BX9Z?X9Z\X9Z8XH"+X9Z?X9^2X9Z<X9ZVX9Z"X9Z8X9Z3
MX9^-(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H<"UF;W)M870*;7-G:60@(E=E
M;&-O;64@=&\@)7,B"FUS9W-T<B`BX9Z?X9Z\X9Z8XH"+X9Z?X9^2X9Z<X9ZV
MX9Z"X9Z8X9Z3X9^-XH"+X9Z8X9Z`XH"+X9Z`X9ZVX9Z3X9^+("5S(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A
M;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED
M(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R
M82(*;7-G<W1R("+AGI_AGK;AGJ#AGK;AGIKAGXGAGK;B@(OAGH'AGK;AGH3B
M@(OAGIOAGK?AGH4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S
M(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI
M;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA
M<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`V,@IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@
M;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I
M9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S8*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O
M<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I
M9"`B5VED=&@B"FUS9W-T<B`BX9Z1X9Z1X9ZYX9Z$XH"+(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q.`IM<V=I9"`B5VED=&@@:6X@0U-3('5N
M:71S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@
M=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*
M;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*
M;7-G<W1R("+AGI'AGI'AGKGAGH0@X9^6(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C4R.0IM<V=I9"`B5VEK:2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDS(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")7:6YD(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS
M9VED(")7:6YD($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z.3(*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C@*;7-G:60@(E=I;F0Z(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S8*
M;7-G:60@(E=I;F0Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-CD*;7-G:60@(E=I<V1O;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C$R"FUS9VED(")7:7-H;&ES="(*;7-G<W1R
M("+AGI3AGHGAGY+AGH?AGKCB@(OAGI3AGY+AGIKAGK;AGI#AGY+AGI/AGK8B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-S`*;7-G:60@(E=O<FLB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`BX9ZBX9ZVX9Z?
MX9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+X9Z`X9Z3X9^2X9Z;X9^"X9Z$XH"+X9Z2
MX9^2X9Z<X9Z^XH"+X9Z`X9ZVX9Z:(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G
M<W1R("+AGI'AGKSAGIKAGI_AGY#AGI;AGY+AGI'B@(OB@(OB@(OAGH#AGI/A
MGY+AGIOAGX+AGH3B@(OB@(OB@(OAGI+AGY+AGISAGK[AGH#AGK;AGIHB"@HC
M.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ.3,@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG
M(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O
M=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F
M(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@
M9FEL92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(U.0IM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!"87-I8R!#
M;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5
M<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@
M3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4Y-@IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV.#,*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R(")9
M62(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U
M-`IM<V=I9"`B65E962(*;7-G<W1R(")965E9(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,#D*;7-G:60@(EEA:&]O(2!M
M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT
M96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(N&>E.&?DN&>
MFN&>A>&>MN&?AN&>AN&?DN&>D^&>MN&?AB(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G
M:60@(EEE;65N(@IM<V=S='(@(N&>F>&?@>&>F.&?@N&>DR(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C0*;7-G:60@(EEE
M<R(*;7-G<W1R("+AGI3AGK;AGI$OX9Z%X9ZVX9Z?(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@
M22!!9W)E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$
M12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE3
M25=91RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP
M.C@Q"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@
M=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,30R-0IM<V=I9"`B66]U(&%R
M92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#@*;7-G:60@(EEO=2!C86YN;W0@
M:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W!H<&=W+G!H<#HQ,3<*
M;7-G:60@(EEO=2!D:60@;F]T(&%U=&AE;G1I8V%T92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V,R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.3@S"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A
M;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@
M9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@
M=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#<*;7-G:60@(EEO
M=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS-S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB66]U(&AA=F4@<F5Q=65S=&5D('1O(&%D9"!T:&4@96UA:6P@
M861D<F5S<R!<(B5S7"(@=&\@=&AE(&QI<W0@;V8@>6]U<B`B"B)P97)S;VYA
M;"!E;6%I;"!A9&1R97-S97,N7&XB"B)<;B(*(D=O('1O('1H92!F;VQL;W=I
M;F<@;&EN:R!T;R!C;VYF:7)M('1H870@=&AI<R!I<R!R96%L;'D@>6]U<B!A
M9&1R97-S.EQN(@HB)7-<;B(*(EQN(@HB268@>6]U(&1O;B=T(&MN;W<@=VAA
M="!T:&ES(&UE<W-A9V4@;65A;G,L('EO=2!C86X@9&5L971E(&ET+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8U"FUS9VED
M("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB
M97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T
M:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Y,@IM<V=I9"`B66]U(&AA
M=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S
M="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0W
M-`IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q
M"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@
M>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM
M<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@
M<&]I;G1S('1O(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S
M=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O
M(&)E(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q
M.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R
M(&]U="XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED
M(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE
M('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!U<&1A=&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W
M:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B
M66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P
M+G!H<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N
M('!H;VYE(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S
M:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED
M(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(Q-0IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-0HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(*;7-G:60@(EEO=7(@26YF;W)M
M871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M.3<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D
M<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@
M)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@
M;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R
M("+AGHCAGY+AGICAGX3AGX?B@(OAGIKAGI3AGI_AGXOAGJ+AGY+AGI/AGH`B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-0IM<V=I9"`B
M(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O
M<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@
M=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D
M:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHU"FUS9VED
M("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E
M;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG
M960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*
M(E1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A
M:6XN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4U"FUS
M9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U
M<F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT
M+FIS.C0R"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R
M="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@
M4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(V,0IM<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$R-@IM<V=I9"`B66]U
M<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C$*;7-G:60@(EEO=7(@
M9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(P-`IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY.0IM<V=I9"`B66]U
M<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U
M<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`IM<V=I9"`B66]U<B!O
M<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@
M=&AI<R!S97-S:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E
M;B!U<&1A=&5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E
M="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW
M.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE
M8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S
M<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.C<S,PIM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED
M(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@(N&>F>&>O.&>
MH.&?DN&>@N&?A.&>G^&?DN&>F^&>MN&>G.&>N"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(N&>
MG^&?@R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("+A
MGJ#AGY+AGI_AGK;AGX;AGI3AGXKAGK@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED
M(")::6UB86)W92(*;7-G<W1R("+AGJ#AGY+AGI_AGXKAGKCAGICAGI3AGK;A
MGISAGXGAGX$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-S$*;7-G:60@
M(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E
M9"!497AT72(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX
M.0IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H
M;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X
M=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,L('!H
M<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DU
M"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U-C$@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*
M;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S
M='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U
M"FUS9VED(")?2&5L<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G
M92!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92]-96YU+G!H<#HQ.30*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I
M9"`B7TQO9R!O=70B"FUS9W-T<B`B7TSAGH7AGX'AGHD@(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS
M9VED(")?36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B"FUS
M9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(V"FUS9VED(")?4F5M;W9E($QI;FLN+BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN
M+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@(E]5<V5R
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR
M,`IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R97-S964@
M=6YK;F]W;B(*;7-G<W1R("+AGICAGK?AGI/B@(OAGI_AGY+AGH+AGK;AGIOA
MGXOB@(OAGJ+AGY+AGI/AGH#B@(OAGI'AGI'AGKWAGIOB@(OAGI_AGX;AGI3A
MGKOAGH_AGY+AGIHB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ
M,@IM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ.#0@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T92!O
M=71P=70@9FEL92(*;7-G<W1R("+AGICAGK?AGI/B@(OAGJ+AGK;AGH7B@(OA
MGI3AGH3AGY+AGH#AGK[AGH_B@(OAGJ_AGH#AGI_AGK;AGIKB@(OAGIOAGI'A
MGY+AGI+AGI7AGILB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T<B`BX9Z8
MX9ZWX9Z3XH"+X9ZBX9ZVX9Z%XH"+X9Z4X9Z^X9Z`XH"+X9Z6X9^0X9Z/X9^,
MX9Z8X9ZVX9Z3XH"+X9Z4X9Z)X9^2X9Z%X9Z\X9Z;(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DU"FUS9VED(")C;&EC:R!H97)E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T
M<B`BX9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z`X9ZVX9Z:XH"+X9Z4X9^2X9Z:X9Z^
MXH"+X9Z4X9Z3X9^2X9Z1X9ZVX9Z/X9^+XH"+X9Z6X9ZVX9Z`X9^2X9Z9X9Z4
MX9Z)X9^2X9Z'X9ZV(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-S@*;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B
MX9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z`X9ZVX9Z:XH"+X9Z`X9^&X9Z.X9Z/X9^+
MXH"+X9Z:X9Z%X9Z3X9ZVX9Z?X9Z8X9^2X9Z6X9^0X9Z3X9^2X9Z2(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R
M:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`BX9Z4X9ZVX9Z/
MX9^+XH"+X9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z4X9^2X9Z:X9Z6X9^0X9Z3X9^2
MX9Z2XH"+X9Z?X9^&X9Z!X9ZVX9Z3X9^+XH"+X9Z4X9^&X9Z5X9Z[X9Z/(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C8*;7-G:60@
M(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(N&>@.&?AN&>H.&>N^&>G^*`
MB^&>D>&?DN&>FN&>A.&?B^&>D>&?DN&>FN&>MN&>F>*`B^&>D>&>M^&>D^&?
MDN&>D^&>D^&?D.&>F2(*"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z
M,C@*;7-G:60@(F5D:70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ.#(*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*
M;7-G<W1R("+AGIKAGH#B@(OAGICAGK?AGI/B@(OAGH/AGK[AGHGB@(OAGI+A
MGK;AGH_AGKOB@(OAGI3AGHGAGY+AGH7AGKSAGILB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B9F%L;&EN9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX
M.#$*;7-G:60@(F9I;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ.#8@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-S(@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@
M*"5S*2!A="`E<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C0T"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-#@*;7-G
M:60@(F@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HS-3<*;7-G:60@(FAH(@IM<V=S='(@(FAH(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO
M<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(N&>F.&>M^&>D^*`B^&>G^&?DN&>
M@N&>MN&>F^&?B^*`B^&>B.&?DN&>F.&?A.&?A^*`B^&>F.&?B>&>MN&>G^&?
MBN&>N.&>DR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U
M="!E<G)O<B(*;7-G<W1R("+AGH#AGX;AGJ#AGKOAGI_B@(OAGI3AGHGAGY+A
MGH7AGX'AGHDOX9Z4X9Z)X9^2X9Z%X9Z\X9Z;(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W
M87)E(&5R<F]R(@IM<V=S='(@(N&>@.&?AN&>H.&>N^&>G^*`B^&>@.&>F.&?
MDN&>F.&>G.&>M^&>DN&>N.*`B^&>@>&>MN&>A.*`B^&>@.&?DN&>FN&?A2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS
M9VED(")L:6YE<UTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*
M;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S8X"FUS9VED(")M;2(*;7-G<W1R("+AGI@NX9Z8+B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C@V('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C(T,0IM<V=I9"`B;F%M92(*;7-G<W1R("+AGHCAGY+AGICAGX3A
MGX<B"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(T"FUS9VED(")N;W0@
M:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HQ,C(P"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`T
M"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E
M;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-S0*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(N&>
MG^&>M^&>D>&?DN&>DN&>M^*`B^&>C^&?DN&>FN&>O.&>G.*`B^&>E.&>MN&>
MD^*`B^&>E.&>BN&>M^&>G^&?@>&>DB(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*
M;7-G<W1R("+AGI?AGKCAGH#AGI_AGX+AGILB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN
M('!R;W1O8V]L(@IM<V=S='(@(N&>@.&?AN&>H.&>N^&>G^*`B^&>EN&>N.*`
MB^&>A>&>F.&?DN&>A.&>MN&>F>*`B^&>@.&?DN&>D^&>N^&>A.*`B^&>EN&>
MM^&>DN&>N.&>@.&>MN&>FB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<T"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E
M<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`BX9Z8X9ZWX9Z3XH"+X9ZBX9ZV
MX9Z%XH"+X9Z:X9Z`XH"+X9Z?X9^!X9Z<X9ZVXH"+X9Z4X9ZVX9Z3(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HQ,#(*;7-G:60@(G-H;W<@9&EF9F5R
M96YC97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%14
M4"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S@U"FUS9VED(")S<R(*;7-G<W1R(")S<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS9VED(")S=&5A
M9'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R("+AGH#AGX;A
MGJ#AGKOAGI_B@(OAGI3AGY+AGIKAGI;AGY#AGI/AGY+AGI(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.`IM<V=I9"`B=&%S:R!L:7-T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("+AGI3AGIKA
MGK;AGH?AGY#AGIGB@(OAGI3AGH[AGY+AGHKAGX3AGX?AGJ+AGK;AGI_AGI/A
MGY+AGI,B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z,C<Q"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T
M=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")U;FEF
M:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VAO<F1E+G!H
M<#HR-SD*;7-G:60@(G5N:VYO=VX@97)R;W(B"FUS9W-T<B`BX9Z8X9ZWX9Z3
MXH"+X9Z?X9^2X9Z"X9ZVX9Z;X9^+XH"+X9Z`X9^&X9Z@X9Z[X9Z?(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE
M9"(*;7-G<W1R("+AGH+AGY+AGICAGK;AGI/B@(OAGHCAGY+AGICAGX3AGX<B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B
M=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C0P"FUS9VED(")W.B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE
M<BYC;VTB"FUS9W-T<B`B(@H`````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O
M:V]?2U(N<&\`````````````````````````````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#8U,#`P,P`Q,#4Q-30S,S<U-0`P,3<V-#<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````(R!+;W)E86X@=')A
M;G-L871I;VYS(&9O<B!H;W)D92!P86-K86=E"B,@:&]R9&4@QM#%L,'VOZ$@
MM.O'T2#'T;&YONX@N?B_JKFN+@HC($-O<'ER:6=H="`H0RD@,C`P-2!(;W)D
M92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H
M92!S86UE(&QI8V5N<V4@87,@=&AE(&AO<F1E('!A8VMA9V4N"B,*;7-G:60@
M(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,"UC
M=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N
M;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP
M,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`Q+3$Q+3`Y(#$V.C(Y*S`Y
M,#!<;B(*(DQA<W0M5')A;G-L871O<CH@2FEN:'EO:R!(96\@/&YO=F5M8G)E
M0&]U<FYA='5R92YO<F<^7&XB"B),86YG=6%G92U496%M.B!I,3AN0&QI<W1S
M+FAO<F1E+F]R9UQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M
M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U%54,M2U)<;B(*(D-O;G1E;G0M
M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES
M(&%G;RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ,S<P"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*
M;7-G<W1R("(@*+3<P^#%L"`E<RDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S<W"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,PIM
M<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B("B_P+3#*2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H=&]M;W)R;W<I(@IM<V=S
M='(@(B`HL[O`SRDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<Q
M"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B("B^[L&F*2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-38@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,V,0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-#`W"FUS9VED("(@870@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,C$U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R("*U\+>ZQ>2X
MKB(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N
M(@IM<V=S='(@(K_#N=FXI2"PR[OV(+G\P=:XIB#`U+?"Q\^\O+_D+B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-C4Y"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`T,@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D
M(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B)7,GP,PHL*$I($AO
M<F1E(+>YP?:]NL:NN*Z_H;RM(+RSP:2UQ[[N(,#6P?8@OLJ]P+3/M-DN(@H*
M(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y
M<W1E;2XB"FUS9W-T<B`B)R5S)["A(+W#O;K%V[^A(,/?L*&UQ[[ZO<"TS[39
M+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R
M;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R("(G)7,GL*$@O<.]NL7;OZ$@P]^P
MH;7'OOJ]P+3/M-DN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F
M34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B)60@
M+R`E9"`HN-Z]P\'V.B`E9"DB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L('!H<"UF
M;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I
M<F5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@
M(L+\P;8B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S,@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,U"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN
M=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S
M(,"OP?:P_+BN(,#;OO<@+2#(KL#.(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HR-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@4VEG;B!5<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R
M965M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-#(X(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DP"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z-C4Q(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI
M<W1S+B(*;7-G<W1R(")<(B5S7"*TPB#`S+G,(,#6O<"TS[39+B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,34Y(&QI8B]";&]C:R]M971A<BYP:'`Z,38U
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C,Y"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S0U(&QI8B]";&]C:R]M971A<BYP:'`Z,S4Q"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(E9"`O("5D("BX
MWKW#P?8Z("5D*2(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@
M<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E
M;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO
M=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("+!]K'=
M(+SVQ^#'TB#`V[[WP+L@O+'%P\?/O+R_Y"XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S0P"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E
M<75I<F5D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@V
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S
M='(@(C6ZT""XMK39(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE
M8W1I;VXN<&AP.C$R,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M;F]T(&9O=6YD+B(*;7-G<W1R("+%Z\'V(+BNO;JSRB`E<\"[*+BF*2##H\"[
M(+SV(+[XO<"TS[39+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F
M("5S(@IM<V=S='(@(B5D("\@)60@*+C>O</!]CH@)60I(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(L'6O-*WSR(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(K3>M\(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(L#0P?8@OLK`
MNB"XWL#/(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S`*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T
M<B`BO/:]Q;#%NLXB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]H=&UL+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C
M;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS
M(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E
M<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S8U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HT,3`*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*
M;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y-"!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,#8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,C@*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T.0HC+"!F=7IZ
M>0IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(K'4Q*(HM_PI(+RQQ<,@
MO\"W^2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`HC+"!F=7IZ>0IM<V=I
M9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`BP:2ZN"(*"B,Z(&QI8B]";&]C
M:R]T:6UE+G!H<#HQ.0HC+"!F=7IZ>0IM<V=I9"`B,C0@2&]U<B!&;W)M870B
M"FUS9W-T<B`BP:2ZN"(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X
M"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-""]P["C(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0HC+"!F=7IZ>0IM<V=I9"`B/%!R979I
M;W5S(@IM<V=S='(@(L#,P/P@QN3`S,'V(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ,3D*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E
M9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-C`*(RP@9G5Z>GD*;7-G:60@(D$@9F%T86P@97)R
M;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(CQB/L2AN.W`^\#.(+_`M_D@N=^[
M_3H\+V(^(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3,U
M"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y
M<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,38U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES
M(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#DW"FUS
M9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3`Q-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T
M92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG
M;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3`U"FUS9VED("(B"B)!('!U8FQI8R!3+TU)
M344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G
M:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M
M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E
M<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"B,L(&9U>GIY
M"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`BNKF[YR(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"B,L(&9U>GIY"FUS9VED
M(")!32!,:6=H="!286EN(@IM<V=S='(@(K?.L=?`SB(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"B,L(&9U>GIY"FUS9VED
M(")!32!286EN(@IM<V=S='(@(K"AP.7`VKBN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS
M9W-T<B`BO\#`_"^_P,C$(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`BP,P@OZ&U\,7-
MM,(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,@IM<V=I9"`B06)O
M=70N+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW-`HC+"!F=7IZ>0IM<V=I9"`B06)S8F]T=&]M(@IM
M<V=S='(@(K[&MZ$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<R"B,L(&9U>GIY"FUS9VED(")!8G-M:61D;&4B"FUS9W-T
M<B`BL*&_[K6E(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(W
M,`HC+"!F=7IZ>0IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R(")V9G-R;V]T(+7PM[K%Y+BNN*8@P-#`NR"\
M]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,3,V"B,L(&9U>GIY"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&
M4R!F:6QE+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@
MO/8@OOB]P+3/M-DN(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*(RP@
M9G5Z>GD*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`BP:2Z
MN"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-0HC+"!F=7IZ>0IM<V=I
M9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R("*^S\BC(,BNP,XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*
M(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R("*_P+BG
MPO>\^"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S,*(RP@9G5Z
M>GD*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`BO\"XI\+WO/@B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T96UP;&%T97,O<&]R
M=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C
M:&EL9"YI;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R("+#W["A(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@
M(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM
M<V=S='(@(K"SP,X@N-[`SR(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN
M8SHU"B,L(&9U>GIY"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`BN^>_Z\#:
M(,/?L*$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N
M<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.#@*(RP@9G5Z>GD*;7-G:60@(D%D9"!.97<@4&5R
M;6ES<VEO;B(*;7-G<W1R("*PL\#.(+C>P,\B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")!9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B
M3$1!4""\K;GV(,&BO-,@O<?&T"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,30W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@
M82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R("(E<R"QQ\?1
M(+SVP:0B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W
M('5S97(Z(@IM<V=S='(@(KOUM\Z_[B"[Y[_KP-H@P]^PH3HB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34T"B,L(&9U>GIY
M"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(K^M(+K0Q](B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"B,L(&9U>GIY"FUS9VED
M(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`BN_6WSK_N(+OGO^O`VB##W["A
M.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D
M9"!P86ER(@IM<V=S='(@(L;DONXH<&%I<BD@P]^PH2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H
M92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0HC+"!F
M=7IZ>0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B*"5S
M*;BF(,'6O-*WS[^A(,/?L*$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z-S@*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!M>2!A
M9&1R97-S(&)O;VLB"FUS9W-T<B`B*"5S*;BF(,'6O-*WS[^A(,/?L*$B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`B
MN^>_Z\#:(,/?L*$B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T
M(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ
M("(*(B5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF
M;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@
M8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES
M86)L960N(@IM<V=S='(@(KOGO^O`VB##W["A(+OGO^N^R,?4(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T-#$*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B
MP=:\TB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,SD*;7-G:60@
M(D%D9')E<W,@0F]O:R(*;7-G<W1R("+!UKS2M\\B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E
M<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(K#\
MN*XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Q"B,L(&9U>GIY
M"FUS9VED(")!9',B"FUS9W-T<B`BP]^PH2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*(RP@9G5Z
M>GD*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(K3<P[PB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4W"B,L(&9U>GIY"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(K[SMO/`S+[N
MO;HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")!;&=E<FEA(@IM<V=S
M='(@(K[SMO/`S+[NO;HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R("*^\[;SP,R^
M[KVZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB"FUS9W-T<B`BP:2WQ"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@
M(D%L:6=N;65N=#HB"FUS9W-T<B`BP:2WQ#HB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R("*X\+7.(+RQQ<,B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C8U"B,L(&9U>GIY"FUS9VED(")!;&P@075T:&5N
M=&EC871E9"!5<V5R<R(*;7-G<W1R("*XWL#/(,#\M-X@O\"W^3HB"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"B,L(&9U
M>GIY"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(KOHP:8B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDQ(&9R86UE=V]R:R]097)M<R]0
M97)M<R]D871A=')E92YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(D%L;"!097)M
M:7-S:6]N<R(*;7-G<W1R("+%Y+?0(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@
M<VED97,B"FUS9W-T<B`BN/"UYR`TN.DB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#<Q"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S-`IM<V=I
M9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z
M-3`T"B,L(&9U>GIY"FUS9VED(")!;')E861Y(&5X:7-T<R(*;7-G<W1R(")<
M(B5S7"*TPB#`S+G,(,#6O<"TS[39+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,C,*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#<*(RP@9G5Z>GD*;7-G
M:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(K[/R*,@R*[`
MSB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3D*;7-G:60@(D%L=&5R
M;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C,U"B,L(&9U>GIY"FUS9VED(")!;'1E<FYA=&4@
M96UA:6P@861D<F5S<R(*;7-G<W1R("+`W[CXM<@@P,RXWL#/(,'6O-(B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@HC+"!F=7IZ>0IM<V=I9"`B06QT
M97)N871E('1E;7!L871E<R(*;7-G<W1R("*TZ\.\(+';(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(U
M"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`BM.O#O""QVR(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@
M=V%S('-P96-I9FEE9"XB"FUS9W-T<B`BP-^X^+7((+FNP-JPH2#`UKW`M,^T
MV2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38W"B,L(&9U
M>GIY"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G
M<W1R("(\8C[$H;CMP/O`SB"_P+?Y(+G?N_TZ/"]B/B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*
M;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B
M06YG;VQA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0HC+"!F=7IZ>0IM<V=I9"`B06YS
M=V5R(@IM<V=S='(@(LBXO<7'T2"XWL#/(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B
M06YT87)C=&EC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I
M9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN
M9&5X+FAT;6PZ-@HC+"!F=7IZ>0IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T
M<B`BO<?'X"(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@HC+"!F=7IZ
M>0IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R("*]Q\?@(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`HC+"!F=7IZ>0IM<V=I9"`B07!P
M;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(KW'Q^`B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@
M4VAA<F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S,PIM<V=I9"`B07!P
M<F]X:6UA=&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B
M-+_Y(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S4*;7-G:60@(D%R86)I
M8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HX,0IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU
M."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#`*(RP@9G5Z>GD*
M;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R("+'RK7EP,RXIR(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T
M;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@
M(K#HO-,@P?C'X,?/O<.PVKW`M,^Q[C\B"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@86YD
M(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R("+`S""XWKW#P?:XIB"_M;_XR/<@
MN^C!IL?/O<.PVKW`M,^Q[C\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"B,L(&9U>GIY"FUS9VED
M(")!<F=E;G1I;F$B"FUS9W-T<B`BOO.V\\#,ONZ]NB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*
M;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-S8*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N
M<VEO;B!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF:6,@
M4F5G:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M,C4*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M
M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R("+`K\'VL/RXKKW'Q^#`
M_"#(KL#.Q\^QXB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3,*
M(RP@9G5Z>GD*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R("*_
MK2"ZT,?2(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP
M="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@
M=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@V"FUS9VED(")!='1R:6)U
M=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B.+_Y(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(CB_
M^2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(D%U<W1R:6$B"FUS9W-T
M<B`B.+_Y(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C$V
M.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O
M97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B
M075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z
M,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N
M(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB
M9G1P('-W:71C:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q
M=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T
M:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T
M:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U
M<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*
M;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C,S.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L
M9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60Z("(*;7-G<W1R("+`T[W#NKBP_,?4(,#ZP.4@O\"W^2X@
MO*VY]L#'(+_`M_D@N-Z]P\'V.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A
M<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DY"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E
M<B`E<R(*;7-G<W1R("+`T[W#NKBP_,?4(,#ZP.4@O\"W^2X@O*VY]L#'(+_`
MM_D@N-Z]P\'V.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO
M="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U
M=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z-C`*
M;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*(RP@9G5Z>GD*;7-G:60@
M(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R("*[Z,&F(+W'QM`B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HW-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I
M;VX@9F%I;&5D+B`E<R(*;7-G<W1R("*XWL#/(,#\M-X@O\"W^3HB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,3<V"B,L(&9U>GIY"FUS
M9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R
M+B(*;7-G<W1R(")F='`@O*VY]B"_K+#A(+_`M_DN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HX-3$*(RP@9G5Z>GD*;7-G:60@(D%U=&AE;G1I
M8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")F='`@O*VY
M]B"_K+#A(+_`M_DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW
M,`HC+"!F=7IZ>0IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S
M97)V97(@9F%I;&5D+B(*;7-G<W1R(")F='`@O*VY]B"_K+#A(+_`M_DN(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA
M8FQE(&9I96QD<SHB"FUS9W-T<B`BL*&TR<?1(,?*M>4Z(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(KGHL.8B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED
M(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(KGHL.8@N_:Q\B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B
M97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")"86AA
M;6%S(@IM<V=S='(@(L#,N*<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"B,L(&9U>GIY"FUS9VED
M(")"86AR86EN(@IM<V=S='(@(L"EN-[`SR(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3<W"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(B(*"B,Z('5T
M:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N
M9"XB"FUS9W-T<B`BQ>O!]B"XKKVZL\H@)7/`NRBXIBD@PZ/`NR"\]B"^^+W`
MM,^TV2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S,*(RP@9G5Z>GD*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@
M(L6IL>(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C`*(RP@9G5Z>GD*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B
MQ:FQXB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(D)E;&EZ92(*;7-G
M<W1R("+%J;'B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD
M87DB"FUS9W-T<B`BN_W`SR(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#
M;VQL96-T:6]N+G!H<#HS-3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R("+%Z\'V(+BNO;JSRB`E<\"[*+BF*2##H\"[(+SV(+[XO<"T
MS[39+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHX.0IM<V=I
M9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.`IM<V=I9"`B0F]L9"(*;7-G<W1R("*QO;#4(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I
M9"`B0F]L:79I82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C`U"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM
M<V=I9"`B0F]R9&5R(@IM<V=S='(@(K#FL.@B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI
M8VMN97-S.B(*;7-G<W1R("*PYK#H(+7.LK(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Q"FUS9VED(")";W)D
M97)S(@IM<V=S='(@(K#FL.@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@
M86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R("*X\+7.(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")"
M;W1T;VTB"FUS9W-T<B`BOL:WH2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O=79E
M="!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@HC+"!F=7IZ>0IM<V=I
M9"`B0G)A>FEL(@IM<V=S='(@(L"EN-[`SR(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED
M(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T
M<B`BOO.V\\#,ONZ]NB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`B
ML>+(HR"XKKVZQJXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0T"B,L(&9U>GIY
M"FUS9VED(")#35,B"FUS9W-T<B`B0U93(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED
M(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*
M;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B7V6\OR"\T[RZ
M+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,PIM<V=I
M9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-"!C
M;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ-34*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(K3>M\(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0V"B,L(&9U>GIY"FUS
M9VED(")#86QM(@IM<V=S='(@(L/KO-(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B
M0V%M8F]D:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I
M9"`B0V%M97)O;VXB"FUS9W-T<B`BL+/`SB"XWL#/(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S
M<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C,Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET
M92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF
M*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C(R"FUS9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@
M:&%N9&QE<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C(S-2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z
M,S$Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T
M('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R("),1$%0(+RMN?8@P:*\TR"]
MQ\;0(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#$S"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]
MP+3/M-DN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-`HC+"!F=7IZ>0IM<V=I9"`B0V%N861A(@IM
M<V=S='(@(K3>M\(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E
M<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z
M,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*
M;7-G<W1R("+#Z[S2(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("*_
MP+?Y(+JXL.W'S['B(,/KO-(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C,Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E
M;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`NRBX
MIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT
M-@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U
M='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A
M('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO
M="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,30*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T
M;W)Y(%PB)7-<(BXB"FUS9W-T<B`B36%I;G1E;F%N8V5?5&%S:R"X\+7B("5S
MP+LHN*8I(+^M(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]$871A5')E
M92]$871A5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$871A5')E
M92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M
M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#
M86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R
M(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S
M<&5C:69I960@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED
M(")#87!E(%9E<F1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*;7-G:60@(D-A<'1I;VXB
M"FUS9W-T<B`BQ+B\QR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE
M<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`*;7-G:60@(D-A=&5G;W)I97,@
M86YD($QA8F5L<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y
M;6%N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G
M<W1R("+(WK3KQODB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(U"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS
M9W-T<B`BO+\@O-.\NB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@
M(KR_(,;DM?DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T
M<B`BO+\@O-.\NB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(KR_
M(+"CL-TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C<T"FUS9VED
M(")#96QL<&AO;F4B"FUS9W-T<B`BR-ZTZ\;Y(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R("*PH;_NM:4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-E
M;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-CDY"FUS9VED(")#97)T
M:69I8V%T92!$971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C$Q"FUS9VED(")#97)T:69I8V%T92!/=VYE
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4Y-@IM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED(")#:&%D(@IM<V=S='(@
M(G9#87)D(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B0VAA;F=E(@IM
M<V=S='(@(KJOL.8B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,S$*(RP@9G5Z>GD*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S
M='(@(K[/R*,@R*[`SB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@HC
M+"!F=7IZ>0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S
M('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@
M>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(KC>P,_`NR"ZN+.^MJ<@N^>_Z\?2
M(,#,N*<L(,'6O-(L(+RMN.W`NR"ZK[#FQ]6TS[39+B(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U
M<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@
M8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(W"B,L(&9U>GIY"FUS9VED(")#:&%R(@IM<V=S
M='(@(G9#87)D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G
M<W1R(")?:[BUQ:D@L,N[YRXN+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G
M:60@(D-H:6QE(@IM<V=S='(@(L&FN/$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#
M:&EN82(*;7-G<W1R("+!W[&Y(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0VAI;F5S
M92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0HC+"!F=7IZ>0IM<V=I9"`B0VAO
M;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`BOL_(HR#(KL#.(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.`HC+"!F=7IZ>0IM<V=I9"`B
M0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`BN-Z]P\'V(,#;O+HB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDX"FUS9VED(")#:&]O<V4@:&]W('1O
M(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H
M;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G
M<W1R("*\^+RM(+BNO;K&KB#!OK?Y(+RQQ<,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED
M(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O5D93+G!H<#HX.3,*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@
M;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R("+%Z\'V(+BNO;JSRB`E<\"[*+BF
M*2##H\"[(+SV(+[XO<"TS[39+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$T"B,L(&9U>GIY"FUS9VED(")#;&5A<B(*;7-G
M<W1R("*TWK?"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R
M(")-4[_`Q\>]NB#%U['7(,'VO^RQXB(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,C@*(RP@9G5Z>GD*;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@(K#+
MN_;'U[CQ(,/*L>+(K2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R
M+FEN8SHU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@
M=7-E<CH@)7,B"FUS9W-T<B`BL,N[]L?7N/$@P\JQXLBM(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")#
M;&5A<B!U<V5R(@IM<V=S='(@(K#+N_;'U[CQ(,/*L>+(K2(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"B,L(&9U>GIY"FUS9VED(")#
M;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`BL,N[]L?7N/$@P\JQXLBM(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*(RP@9G5Z
M>GD*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`BL,N[]L?7N/$@P\JQ
MXLBM(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT
M;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X
M-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R("+#HB"TW;'B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#0*(RP@9G5Z>GD*;7-G:60@
M(D-L;W5D<R(*;7-G<W1R("*ZN;OG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,38*(RP@9G5Z>GD*;7-G:60@(D-L;W5D<R!%
M87)L>2(*;7-G<W1R("*ZN;OG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3<*(RP@9G5Z>GD*;7-G:60@(D-L;W5D>2(*;7-G
M<W1R("*ZN;OG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I
M($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E
M8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R("*_
MWL+*N+>TZR"TW;'B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B
M"FUS9W-T<B`BQ]7#Q,'X(+#FL.@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY"FUS
M9VED(")#;VQO;6)I82(*;7-G<W1R("*[]K'R(@H*(SH@;&EB+T)L;V-K+V-O
M;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@
M(D-O;&]R(@IM<V=S='(@(KOVL?(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO0V]L;&5C=&EO;BYP:'`Z,S(T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R]#;VQL96-T:6]N+G!H<#HS,C4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C4P,"!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K
M97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@T-@HC+"!F=7IZ>0IM<V=I9"`B
M0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R("*\L<7#N^?'USHB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B
M0V]L<SHB"FUS9W-T<B`BOZTZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DT-@IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8T"FUS9VED(")#;VUI8W,B"FUS
M9W-T<B`B0V]M:6-S(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"B,L(&9U
M>GIY"FUS9VED(")#;VUM86YD(@IM<V=S='(@(LBXN^<B"@HC.B!A9&UI;B]C
M;61S:&5L;"YP:'`Z,C`*(RP@9G5Z>GD*;7-G:60@(D-O;6UA;F0@4VAE;&PB
M"FUS9W-T<B`BR+B[YR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B0V]M;65N="(*;7-G<W1R("+(N+OG
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8*(RP@
M9G5Z>GD*;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S='(@(L#,N*<Z(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#0*(RP@9G5Z>GD*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`BN_4@
MN-[`SR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`BR+B[YR(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B0V]M<'5T97)S
M(@IM<V=S='(@(KOU(+C>P,\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,CDW"B,L(&9U>GIY"FUS9VED(")#;VYD:71I;VXB"FUS9W-T<B`B
ML.&WT"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y"B,L(&9U>GIY"FUS
M9VED(")#;VYD:71I;VYS(@IM<V=S='(@(K#AM]`B"@HC.B!A9&UI;B]S971U
M<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30S"FUS
M9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA
M<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T
M(&]F(&1A=&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3$*
M;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`BOL_(HR#(KL#.(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-@HC+"!F=7IZ>0IM<V=I9"`B0V]N9V\B"FUS9W-T<B`BN=ZT
MPB"[Y[;W(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A
M=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")#
M;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`BN^C!IB"]Q\;0(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`HC+"!F=7IZ>0IM
M<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R("*[Z,&F(+W'QM`B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3`*(RP@9G5Z
M>GD*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BXB"FUS9W-T<B`B9G1P(+RMN?8@OZRPX2"_P+?Y+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B9G1P(+RM
MN?8@OZRPX2"_P+?Y+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#0U"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@
M9F%I;&5D+B(*;7-G<W1R(")F='`@O*VY]B"_K+#A(+_`M_DN(@H*(SH@8V]N
M9FEG+VAO;VMS+G!H<"YD:7-T.C$P,30*;7-G:60@(D-O;G1A8W1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HU,PHC+"!F=7IZ>0IM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(L?7N/$@
M7"(E<UPBL*$@P=:\TK?/OZ$@P]^PH;7'OOJ]P+3/M-DN(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU-B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z-S@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R("(G)7,GP,<@L[N_ZR(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HS,PHC+"!F=7IZ>0IM<V=I9"`B0V]N=&EN=64B
M"FUS9W-T<B`BL.&WT"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*(RP@
M9G5Z>GD*;7-G:60@(D-O;VMI92(*;7-G<W1R("*[]2"XWL#/(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q
M"FUS9VED(")#;W!Y(@IM<V=S='(@(KJYN^<B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C0V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]P>2!F86EL960Z("5S(@IM<V=S='(@(KOHP:8@O<?&T"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O
M<'D@<V5L96-T:6]N(@IM<V=S='(@(KJYN^<B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3<V"B,L(&9U>GIY
M"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T
M<B`B,;"SP,<@N_6WSK_N(+C>O</!]K"A(,#6O<"TS[39+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-3,*(RP@9G5Z>GD*;7-G:60@
M(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+B(*;7-G<W1R("(QL+/`QR"[
M];?.O^X@N-Z]P\'VL*$@P-:]P+3/M-DN(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HS.3,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO
M="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("*XWKW#P?8@P/R\
MVR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"B,L
M(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB
M"FUS9W-T<B`B,;"SP,<@N_6WSK_N(+C>O</!]K"A(,#6O<"TS[39+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O
M;G1A8W0N("5S(@IM<V=S='(@(B5SN*8@O[&TS[39/R(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C$R,0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@
M=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DQ$05`@O*VY]B#!HKS3(+W'QM`B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#4W"B,L(&9U>GIY"FUS9VED
M(")#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<B(*;7-G<W1R("),1$%0
M(+RMN?8@P:*\TR"]Q\;0(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B
M)7.XIB"_L;3/M-D_(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0HC
M+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V
M97(B"FUS9W-T<B`B3$1!4""\K;GV(,&BO-,@O<?&T"(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z
M("5S(@IM<V=S='(@(DQ$05`@O*VY]B#!HKS3(+W'QM`B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B"FUS9W-T<B`BOK*QXK"AM,G'T2#!UKS2M\_`S""^
M^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,3(U"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C(*
M;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C(T-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R(")(;W)D9;"A(+G9N*.PU""\
ML\&DM<?!]B"^RK[2O<"TS[39+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<R(*;7-G<W1R(")(;W)D9;"A(+G9N*.PU""\L\&DM<?!]B"^RK[2O<"TS[39
M+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HY-3,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE
M(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R("+`W[CXM<@@
MP,RXWL#/(,'6O-(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C(X,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`BOK*QXK"AM,G'
MT2#!UKS2M\_`S""^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PHC+"!F=7IZ>0IM<V=I9"`B0V]U
M;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G
M<W1R(")-86EN=&5N86YC95]487-K(+CPM>(@)7/`NRBXIBD@OZT@O/8@OOB]
MP+3/M-DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE
M=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<
M(BXB"FUS9W-T<B`B)7.XIB"_L;3/M-D_(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C$Q,`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@
M(B5SN*8@O[&TS[39/R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C<Q.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L
M:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B3$1!4""\K;GV
M(,&BO-,@O<?&T"(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@
M=W)I=&EN9RXB"FUS9W-T<B`B)7.XIB"_L;3/M-D_(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T
M<B`B)7.XIB"_L;3/M-D_(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA
M:6YT96YA;F-E+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B
M36%I;G1E;F%N8V5?5&%S:R"X\+7B("5S(+BF(+^M(+SV(+[XO<"TS[39+B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T
M<B`B36%I;G1E;F%N8V5?5&%S:R"X\+7B("5SP+LHN*8I(+^M(+SV(+[XO<"T
MS[39+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0HC+"!F=7IZ>0IM<V=I9"`B
M0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3$1!
M4""\K;GV(,&BO-,@O<?&T"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B:F5C
M="YP:'`Z,C,X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<F5A9"`E<RXB"FUS9W-T<B`B)7.XIB"_L;3/M-D_(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z.#4*(RP@9G5Z>GD*;7-G:60@(B(*(D-O
M=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@
M=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C
M;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B+#
MW["AQ\^TPK6E(+_`M_FPH2"YW[O]Q]^]P+3/M-DN(+W#O;K%V[#\N*[`VK^A
ML-0@M;6_\L"[(+_DP[O'S[W#L>(@N=FV^+3/M-DN(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,X.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@
M;F]T(')E=')I979E($%#3"(*;7-G<W1R("*^LK'BL*&TR<?1(,'6O-*WS\#,
M(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,C<T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R("*^
MLK'BL*&TR<?1(,'6O-*WS\#,(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S(@IM<V=S='(@(KZRL>*PH;3)Q]$@P=:\TK?/P,P@OOB]
MP+3/M-DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HT,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@
M(KZRL>*PH;3)Q]$@P=:\TK?/P,P@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*(RP@9G5Z>GD*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T
M<B`BOK*QXK"AM,G'T2#!UKS2M\_`S""^^+W`M,^TV2XB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@
M<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DAO<F1EL*$@N=FXH[#4
M(+RSP:2UQ\'V(+[*OM*]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@
M7"(E<UPB+B(*;7-G<W1R("(E<[BF(+^QM,^TV3\B"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HW,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B5D93
M(+RSP:0@P:2ZN+^AO*T@)W!O<G0GP,P@OOB]P+3/M-DN(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y
M"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF
M:6=U871I;VXN(@IM<V=S='(@(E9&4R"\L\&D(,&DNKB_H;RM("=P;W)T)\#,
M(+[XO<"TS[39+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K
M=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R(")61E,@O+/!I"#!I+JXOZ&\
MK2`G<&]R="?`S""^^+W`M,^TV2XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S
M971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R
M871I;VX@9FEL92`E<RXB"FUS9W-T<B`B5D93(+RSP:0@P:2ZN+^AO*T@)W!O
M<G0GP,P@OOB]P+3/M-DN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW
M-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE
M(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E
M<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T,PHC
M+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V
M97(N(@IM<V=S='(@(DQ$05`@O*VY]B#!HKS3(+W'QM`B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R("(E<[BF(+^QM,^TV3\B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T
M92!C;VYT86-T+B`E<R(*;7-G<W1R("(E<[BF(+^QM,^TV3\B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B36%I;G1E;F%N8V5?5&%S:R"X
M\+7B("5SP+LHN*8I(+^M(+SV(+[XO<"TS[39+B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS
M9W-T<B`B2&]R9&6PH2"YV;BCL-0@O+/!I+7'P?8@OLJ^TKW`M,^TV2XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8V"FUS9VED(")#;W5L9&XG="!F
M:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A
M<B!I<R!O<&5N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT
M<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3D*(RP@9G5Z>GD*;7-G:60@(D-O
M=6YT960@=&5X="(*;7-G<W1R("*QL\&DM<@@N:[`VK^M(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*(RP@9G5Z>GD*;7-G:60@
M(D-O=6YT<GDB"FUS9W-T<B`BN_4@N-[`SR(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR-S,*(RP@9G5Z>GD*;7-G:60@(D-O=7)S97,B"FUS9W-T
M<B`BN_4@N-[`SR(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR
M,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@
M(KBXM>FQXB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R
M("*XM<6I(+BXM>FQXB(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E
M;&5C="YI;F,Z.30*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B
M"FUS9W-T<B`BR-[!]L7K(+OUM\X@N+BUZ;'B(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(D-R
M96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R("*[]<;ZM/4@N+BUZ;'B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*(RP@9G5Z>GD*;7-G
M:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`BN^>_Z\#:(+''Q]$B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,P"B,L(&9U>GIY"FUS
M9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`BO/W`VB(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(KBXM>FQ
MXB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C(V"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(#0@
M4&AA<V5S(@IM<V=S='(@(L?VP.<@O;K%N,#/(@H*(SH@861M:6XO<V5S<VEO
M;G,N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM
M<V=S='(@(L?VP.<@55),P+HB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L
M:6(O0FQO8VLO=&EM92YP:'`Z,S`*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@
M5&EM92(*;7-G<W1R("*QL\&DM<@@N:[`VK^M(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")#
M=7)R96YT(%523"!I<R(*;7-G<W1R("+']L#G(%523,"Z(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C,S"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%5S97)S
M(@IM<V=S='(@(L?VP.<@O;K%N,#/(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-0HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@
M(L?VP.<@O;K%N,#/(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(W-0HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G
M<W1R("*PX;?0(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R("+']L#G
M(+VZQ;C`SR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#@*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@
M=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B24U0(+?.L=>_PKW#(+W#P-NU
MQ[3"(,#;OO?`NR"\L\&DQ]6TS[39+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM
M<V=S='(@(L#:N*.QXB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B
MP-JXH['B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED(")#>7)I;&QI8R`H
M2T])."U2*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,PIM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-Y<FEL;&EC+U5K
M<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"B,L(&9U
M>GIY"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R("*TZ\?1N<ZQN2(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3$@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(D1$
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,0IM<V=I9"`B(@HB
M1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G
M92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED
M(")$86EL>2(*;7-G<W1R("+`S[JP(@H*(SH@861M:6XO9&%T871R964N<&AP
M.C8U"B,L(&9U>GIY"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@
M(L#/P-HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<Y"FUS9VED
M(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,SDY"FUS9VED(")$871E(@IM<V=S='(@(K.OPJ4B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PHC+"!F=7IZ>0IM
M<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R("*\]KW%(+.OPJ4Z(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P-PHC+"!F=7IZ>0IM<V=I9"`B
M1&%T92!S96QE8W1I;VXB"FUS9W-T<B`BP-JXH['B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Y,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S(R"B,L(&9U>GIY"FUS9VED(")$87DB"FUS9W-T<B`BP,^ZL"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B7VR_K2"[
MZ,&F(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#4P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(C$RO_DB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS
M9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`BO/W`VB(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E
M8W)E87-E($EN9&5N="(*;7-G<W1R("*SN[[NOK*QXB(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI8B]P<F5F<RYP:'`Z,3$W"FUS
M9VED(")$969A=6QT(@IM<V=S='(@(K'BNKLB"@HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PHC+"!F=7IZ>0IM<V=I9"`B
M1&5F875L="!#;VQO<B(*;7-G<W1R("*QXKJ[L*H@N^>_ZR(*"B,Z(&9R86UE
M=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z.3$*;7-G:60@(D1E9F%U;'0@
M261E;G1I='DB"FUS9W-T<B`BL>*ZNR"]Q+JPP-HB"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@4VAE;&PB
M"FUS9W-T<B`BL>*ZNR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PHC
M+"!F=7IZ>0IM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`BL=3$HB#!I,#'
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R
M,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L
M971E+FEN8SHQ,"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM
M<V=I9"`B1&5L971E(@IM<V=S='(@(KOHP:8B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*(RP@9G5Z>GD*
M;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(KR_(+OHP:8B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R-PHC+"!F=7IZ
M>0IM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(KOHP:8B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*(RP@9G5Z>GD*;7-G:60@(D1E
M;&5T92!,;V<B"FUS9W-T<B`BQ^`@N^C!IB(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z-S<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ,#$*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S
M='(@(KC>O</!]B"[Z,&F(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.3,*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!A;F0@<'5R
M9V4@;65S<V%G97,B"FUS9W-T<B`BN^C!IK7((+C>P,\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED
M(")$96QE=&4@8V5L;"(*;7-G<W1R("*\OR"[Z,&F(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B
M1&5L971E(&-O;'5M;B(*;7-G<W1R("*_K2"[Z,&F(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA
M=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HT,C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E
M;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(B5S(+''Q]$@
MO/;!I"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(T"B,L
M('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E
M<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W
M"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(L?@(+OHP:8B"@HC.B!T96UP
M;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"B,L(&9U>GIY"FUS
M9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`BO<2ZL,#:
M(+RQQ<,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU
M;6XB"FUS9W-T<B`BQ_;`YR"_K2#!]K_R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE
M=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@(L?VP.<@Q^`@P?:_\B(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L('!H<"UF;W)M870*;7-G
M:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C4S"B,L(&9U>GIY"FUS9VED(")$96QI=F5R
M>2!T:6UE(@IM<V=S='(@(KOHP:8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM
M87)K(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R("*_
MP+?Y(+RSN.TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,S@@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`IM
M<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`BO+.X[3HB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-0IM<V=I9"`B1&5T86EL<R`H86QS;R!I
M;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$Y.0IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@
M;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`BO+RZSL&D
MNKBPH2"P_+BNP-JXIB#`I\?8(+'BM\^UQ[[NP;.]P+3/M-DN(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q.0IM<V=I9"`B1&5V96QO<&UE;G0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3<*;7-G:60@
M(D1E=R!0;VEN="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(Y-`IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(W"FUS9VED
M(")$97<@<&]I;G0Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F
M="!T;R!R:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@
M=&\@;&5F="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(K7PM[K%Y+BN(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(V-@HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA
M>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R("+(K;CI(+RSP:0B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*
M;7-G<W1R("+(K;CI(+RSP:0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@9&5T86EL960@9F]R
M96-A<W0B"FUS9W-T<B`BR*VXZ2"\L\&D(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HX-0HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&
M*2(*;7-G<W1R("+(K;CI(+RSP:0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#$W"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G
M<W1R("+(K;CI(+RSP:0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP
M:'`Z,3DP"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*(RP@9G5Z>GD*
M;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`BNKFQN"(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY
M(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B;6%I;G1E;F%N8V4N
M<&APOZ$@P??!HB#!HK'9Q\_!]B"XMKR\O^0N(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L
M9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`BP[FY
M^,*P(,?@P+H@Q]>X\2#`S+BGP+L@L*ZP[2#`UKW`M,^Q[C\@L=>WN+39N.DL
M(+^IL>*XIB##O,6IQ\^\O+_D.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1O;6EN
M:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(D1O
M;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R("*TZ\?1N<ZQN2(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@
M86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z.#0T"FUS9VED(")$;W=N;&]A9"(*;7-G
M<W1R("*SN[?!N=ZQXB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C@T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*
M;7-G<W1R("(E<R"SN[?!N=ZQXB(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N
M(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Q,#<*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`HC+"!F=7IZ>0IM<V=I
M9"`B1')U9W,B"FUS9W-T<B`BN?JWN;7I(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$S"B,L(&9U>GIY"FUS9VED(")%+4UA:6PB"FUS
M9W-T<B`BP*6XWL#/(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R
M:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R
M:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="(*;7-G<W1R("*\]L&D(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU,"!T96UP;&%T97,O<&]R
M=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V
M"B,L(&9U>GIY"FUS9VED(")%9&ET($=R;W5P(@IM<V=S='(@(KOHP:8B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,3`P"B,L(&9U>GIY"FUS9VED(")%9&ET(%!E
M<FUI<W-I;VXB"FUS9W-T<B`BL+/`SB"XWL#/(@H*(SH@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C(S-PHC+"!F=7IZ>0IM<V=I9"`B161I="!097)M:7-S
M:6]N<R(*;7-G<W1R("(E<R"QQ\?1(+SVP:0B"@HC.B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R
M;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(B5S(+''Q]$@O/;!I"(*"B,Z('1E
M;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F
M;W(Z(@IM<V=S='(@(KRQQ<.[Y\?7(+SVP:0Z(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HS-C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("(E<R"Q
MQ\?1(+SVP:0B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O
M<B`E<R(*;7-G<W1R("(E<R"QQ\?1(+SVP:0B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R
M("*\TK"S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B16ET:&5R(&5N86)L92!I="!T:&5N.B`E<RP@;W(@=7-E('1H
M92!B87-I8R!(5$U,('9E<G-I;VXZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM
M<V=I9"`B16QE;65N="XN+B(*;7-G<W1R("*_Y+S2+BXN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M
M(@IM<V=S='(@(F5M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8Y"FUS
M9VED(")%;6%I;"(*;7-G<W1R("+`S+C>P,\B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4V-2!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-C@*(RP@9G5Z>GD*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B
MP,RXWL#/(,'6O-(Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV
M,PHC+"!F=7IZ>0IM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N
M(@IM<V=S='(@(K[/R*.PH2#`S\2AQ\_!]B"^RKW`M,^TV2XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@Y"B,L(&9U>GIY"FUS9VED(")%;6%I
M;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("*QXL6X(,&DNK@B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I
M9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.`IM<V=I9"`B16UO
M=&EC;VYS(@IM<V=S='(@(L#,N/#&O,3<(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"B,L(&9U>GIY"FUS9VED
M(")%;7!T>2!M97-S86=E+B(*;7-G<W1R("+!W[_DQ]$@N-[`SR(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HW,#4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G
M:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`BL.&P^B"^^,"](@H*(SH@9G)A
M;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@
M<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU-#,*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R
M;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3@*;7-G:60@(D5N86)L92!R:6=H="!C
M;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(U.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q
M,0HC+"!F=7IZ>0IM<V=I9"`B16YD('EE87(B"FUS9W-T<B`BO]["RKBWM.L@
MR*[`Y2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(L;MP?VQXB#(
MKK3K(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,0IM<V=I9"`B(@HB
M16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A
M<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E
M+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E
M(@IM<V=S='(@(K'7N+(@55),(,#4M\(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DQ"FUS9VED(")%;G1E<B!T:&4@;&5T
M=&5R<R!B96QO=SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U
M871O<FEA;"!'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B
M17)I=')E82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-2!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-34*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E
M<R]P;W)T86PO:6YD97@N<&AP.C@R"FUS9VED(")%<G)O<B(*;7-G<W1R("*_
MP+?Y(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R
M"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC
M:&]R.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S
M>6YC(&QO9SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E
M+U1E;7!L871E+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I
M9"`B17)R;W(@=VET:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED
M(")%<W1O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO
M<&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM
M<V=I9"`B171H;FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*;7-G:60@(D5V97)Y(#$U(&UI;G5T
M97,B"FUS9W-T<B`B,36ZT""XMK39(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,X.0HC+"!F=7IZ>0IM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S
M='(@(C6ZT""XMK39(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`S,"!S96-O
M;F1S(@IM<V=S='(@(C,PP\H@N+:TV2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS,S@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,`IM<V=I9"`B179E
M<GD@-2!M:6YU=&5S(@IM<V=S='(@(C6ZT""XMK39(@H*(SH@9G)A;65W;W)K
M+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@
M3&]G:6XB"FUS9W-T<B`BN/"UYR"WSK'7P,XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S0P"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B
M,S"ZT""XMK39(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-R!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S@X"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS
M9W-T<B`BN,6ZT"(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(T
M"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`BO[DZ(@H*(SH@861M
M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3(W"FUS9VED(")%>&5C=71E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0W-0HC+"!F
M=7IZ>0IM<V=I9"`B17AP86YD(@IM<V=S='(@(KCPM<X@R*[`Y2(*"B,Z('1E
M;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N9"!3
M:61E8F%R(@IM<V=S='(@(K_>PLJXM[3K(,BNP.4B"@HC.B!F<F%M97=O<FLO
M4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP
M.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R
M8V@@=&5R;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-@HC+"!F
M=7IZ>0IM<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`BOZ*]NL;WQJXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q
M"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R("+`_+#FN_8B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN<&AP
M.C(Q-@IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N(@IM
M<V=S='(@(LBOL.:\L\&D(,#0L>(@O\"W^2XB"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V
M97(N(@IM<V=S='(@(DQ$05`@O*VY]B#!HKS3(+W'QM`B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-M8BYP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(D9A:6QE
M9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(DQ$05`@O*VY
M]B#!HKS3(+W'QM`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X
M-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@
M9G)O;2!<(B5S7"(N(@IM<V=S='(@(DQ$05`@O*VY]B#!HKS3(+W'QM`B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8Y,0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G
M<W1R("),1$%0(+RMN?8@P:*\TR"]Q\;0(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S87-L+G!H<#HX-PHC+"!F=7IZ>0IM<V=I9"`B1F%I;&5D('1O(&-R
M96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R("),1$%0(+^LL.$@
M)7,@O<?&T"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DW(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@
M(DQ$05`@O*VY]B#!HKS3(+W'QM`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C0V,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D
M('1O(')E=')I979E.B`E<R(*;7-G<W1R("),1$%0(+RMN?8@P:*\TR"]Q\;0
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*
M(RP@9G5Z>GD*;7-G:60@(D9A:7(B"FUS9W-T<B`BQ\K%S2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")&87)O92!)<VQA;F1S
M(@IM<V=S='(@(L#0P?8@OLK`NB"XWL#/(@H*(SH@9G)A;65W;W)K+T-,22]#
M3$DN<&AP.C(S.`HC+"!F=7IZ>0IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S
M='(@(L#0ONZ_P+'B*,#3QO?&KBD@O\"W^3H@(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S
M='(@(L;1O;HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"B,L
M(&9U>GIY"FUS9VED(")&87AE<R(*;7-G<W1R("+&T;VZ(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U
M87)Y(@IM<V=S='(@(C*_^2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(P
M"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3
M;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3DT-`IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S0*;7-G:60@(D9I9VQE="!#
M05!40TA!(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S,S@*;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")&:6QE(@IM<V=S='(@
M(L&FN/$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*
M;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#<*;7-G:60@(D9I;&4@36%N86=E
M<B(*;7-G<W1R("+&Q,#/(+#\N*[`VB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C@U"B,L(&9U>GIY"FUS9VED(")&:6QE($YA;64B"FUS9W-T<B`B
MQ\JUY<#,N*<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3DU"B,L
M(&9U>GIY"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R("*QU,2B*+?\
M*2"\L<7#(+_`M_DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#@V
M"B,L(&9U>GIY"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R("+'RK7E(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4Y"FUS9VED(")&
M:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Y"FUS9VED(")&:6QT97)S(@IM<V=S
M='(@(L?*Q<TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")&:6YL86YD
M(@IM<V=S='(@(L.CL>(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"B,L
M(&9U>GIY"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(L.YQN3`S,'V(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW
M-@HC+"!F=7IZ>0IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R("+#N<;D
MP,S!]B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-38*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Q"FUS9VED(")&;&EP
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED
M(")&;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HR,S0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R("*QV\#:(+OVL?(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(V"B,L(&9U>GIY"FUS9VED(")&;W(@8G)O=W-E<G,@
M=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R("*ZZK;SO^S`^K"A
M(,#,(+'BM,G`NR#!]K_XQ\_!]B"^RKW`M,^TV2XB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,S-`IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<Y"FUS9VED("(B
M"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C
M87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU
M;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"B,L(&9U
M>GIY"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`BOL_(
MHR#(KL#.(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V,@HC+"!F
M=7IZ>0IM<V=I9"`B1F]R;7,B"FUS9W-T<B`BP*?$H2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HR,0HC+"!F=7IZ>0IM<V=I9"`B1F]R='5N92(*;7-G
M<W1R("+"_,&V(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"B,L(&9U
M>GIY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`BPOS!MB(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B1F]R='5N
M97,B"FUS9W-T<B`BPOS!MB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M.0HC+"!F=7IZ>0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R("+"_,&V(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U,PHC+"!F=7IZ>0IM<V=I
M9"`B1F]R=6US(@IM<V=S='(@(KC>P,_'U"(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ,#D*(RP@9G5Z>GD*;7-G:60@(D9O<G=A<F1S(@IM<V=S
M='(@(L#\M-XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8P"B,L(&9U>GIY"FUS9VED(")&<B(*;7-G<W1R("+`I\2A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@(L?!M[G`TR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S,*(RP@9G5Z>GD*;7-G:60@(D9R86YC92(*;7-G<W1R("+#Z[S2(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L
M($UE=')O<&]L:71A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&
M<F5N8V@@1W5I86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")&
M<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I
M9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G
M:60@(D9R;VTB"FUS9W-T<B`BP*?$H2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-#@@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V
M,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`V"B,L(&9U>GIY
M"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`BP*?$H2(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"B,L(&9U>GIY"FUS9VED(")&=6QL
M($1E<V-R:7!T:6]N(@IM<V=S='(@(L#\P[P@O+.X[3HB"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-@IM<V=I9"`B
M1G5L;"!-;V]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HV,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"B,L(&9U
M>GIY"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`BP,RXISHB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<S"FUS9VED(")'86)O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@
M(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM
M<V=I9"`B1V%M8FEA(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E
M("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`BN-[`SR"\K;GV(,&DNKB[Y\?7
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G
M:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G
M:60@(D=E;W)G:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R
M;6%N>2(*;7-G<W1R("*UML#/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0HC+"!F=7IZ>0IM<V=I
M9"`B1VAA;F$B"FUS9W-T<B`BP=^QN2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I
M8G)A;'1A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4W-0HC+"!F=7IZ>0IM<V=I9"`B1VEV96X@3F%M92(*;7-G
M<W1R("+'RK7EP,RXIR(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R
M"FUS9VED(")';R(*;7-G<W1R("*PH;'B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,C@*(RP@9G5Z>GD*
M;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(K#+N_;'U[CQ(,/*L>+(K2(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*(RP@9G5Z>GD*;7-G:60@
M(D=O;V=L92!396%R8V@B"FUS9W-T<B`BL,N[]L?7N/$@P\JQXLBM(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-PIM<V=I
M9"`B1W)A>7-C86QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'
M<F5E8V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*
M;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<U"B,L(&9U>GIY"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`BP-#!]B"^
MRL"Z(+C>P,\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")'<F5N861A
M(@IM<V=S='(@(L#0P?8@OLK`NB"XWL#/(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HQ-SD*(RP@9G5Z>GD*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(K#\N*XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R
M;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O
M=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R
M("+`T[W#NKBP_,?4(,#ZP.4@O\"W^2X@O*VY]L#'(+_`M_D@N-Z]P\'V.B`E
M<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S
M(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`
MM,^TV2XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S,X
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U
M<"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S<*(RP@9G5Z>GD*;7-G:60@(D=U86TB"FUS9W-T<B`B-K_Y(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")'
M=65R;G-E>2(*;7-G<W1R("*UML#/(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`HC
M+"!F=7IZ>0IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`BN-Z]
MP\'V(+OHP:8B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<P"B,L
M(&9U>GIY"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`BP=:\TK?/(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@(C:_^2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.`HC+"!F=7IZ>0IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*
M;7-G<W1R("(VO_DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*(RP@9G5Z>GD*;7-G:60@(D=U
M>6%N82(*;7-G<W1R("(VO_DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HY-C`*;7-G:60@(DA434PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L
M;"!I;B!R;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O
M=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T
M86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D
M;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.C$U
M-PHC+"!F=7IZ>0IM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(KOHP:8@O<?&T"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B
M2&%I=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@HC+"!F
M=7IZ>0IM<V=I9"`B2&%Z92(*;7-G<W1R("+'[+7EMO/`SB(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.CDQ.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.3,R"B,L(&9U>GIY"FUS9VED(")(96%D97(B"FUS9W-T<B`BQ^RUY;;S
MP,XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP
M.C8Q"B,L(&9U>GIY"FUS9VED(")(96%D97)S(@IM<V=S='(@(L?LM>6V\\#.
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N
M86QD($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C,*;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(DAE
M8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(
M96EG:'0B"FUS9W-T<B`BL_3`S"(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92](96QP+G!H<#HQ-SD@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP
M.C$X-@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T96UP;&%T97,O
M:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*;7-G<W1R("*UM;_RN+LB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q
M"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R("*UM;_RN+LB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q"B,L(&9U>GIY"FUS9VED
M(")(96QP97(B"FUS9W-T<B`BM;6_\KB[(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C(Y"B,L(&9U>GIY"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@(K6U
MO_*XNR(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B
M96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(L;$P,_`QR"]P\#;P,P@
MM-G`O;#Z(+"PO<"TS[39.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8Y"B,L(&9U>GIY"FUS9VED(")(:6=H(@IM<V=S='(@
M(K/TP,PB"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA
M=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*(RP@9G5Z>GD*;7-G:60@
M(DAO7VUE(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B
M2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-3,U"B,L(&9U>GIY"FUS9VED
M(")(;VUE(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS
M9W-T<B`BP?T@P=:\TB(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`HC
M+"!F=7IZ>0IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`BM?"WNL7D
MN*XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(L'](,#\R*VY^,BC(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C4*;7-G:60@(DAO<F1E(@IM<V=S='(@
M(DAO<F1E(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,
M(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T
M;R!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C4P"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S
M<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(KC>P,_'U"!<(B5S
M7"+`S"!<(B5S7"*WSB"ZK[#FM<>^^KW`M,^TV2XB"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I
M;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E
M>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0W"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE
M('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(KC>P,_'U"!<(B5S
M7"+`S"!<(B5S7"*WSB"ZK[#FM<>^^KW`M,^TV2XB"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C0W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P
M87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,3DS"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@
M)7,B"FUS9W-T<B`B7"(E<UPB(+C>P,_'U,"[(+OGO^O'U;3/M-DN(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,V"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N
M:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B7"(E<UPB(+C>P,_'U,"[(+OGO^O'
MU;3/M-DN(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@
M7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G
M<W1R("*\]L;RO+$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T
M<B`BL*&WSB##I+_R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`BL*&W
MSCHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE
M87-E(')E<&]R="$I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY
M(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(L?5
MQ*&P[2"]S<"Z(+^MP,<@O/8B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@
M=&AE<F4_(@IM<V=S='(@(L?7N/$HOZTIP,<@O/8_(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B
M2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T
M<B`BQ]7$H;#M(+W-P+H@Q^#`QR"\]B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S`*;7-G:60@
M(DAU;6ED:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-3D*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES=',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W,B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,U"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E
M<R(*;7-G<W1R("*XWL#/(,#\M-X@O\"W^3HB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G5S+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S
M<6PN<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@
M9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G5S+G!H<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)S<6PN<&AP.C(T,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B24U!
M4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B
MN-[`SR#`_+3>(+_`M_DZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,Q-@HC+"!F=7IZ>0IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("+!UKS2
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PHC+"!F
M=7IZ>0IM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R
M("+`S+_KL*&TR<?1(+RQQ<.[Y\?7P,P@OOB]P+3/M-DN(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S
M<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(E]N
MOM6_H2#'X"##W["A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"B,L(&9U>GIY"FUS9VED("))
M8V5L86YD(@IM<V=S='(@(L#0P?8@OLK`NB"XWL#/(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,W-@IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R("*^
MQL#,Q-PB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R("(E<[^A
ML-0@O-*PLR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S<*;7-G:60@
M(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R("*^QL#,Q-RP^B"YKL#:(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B261E;G1I='DG<R!N
M86UE.B(*;7-G<W1R("*]Q+JPP-H@P,RXISHB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@
M:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#4U"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N
M>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D
M('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A
M<F5N8WDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ-S,*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M
M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P
M;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E(%!R979I97<Z(@IM
M<V=S='(@(K'7N+(@N<RXKKJXL>(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),
M(@IM<V=S='(@(K'7N+(@55),(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!5
M4DPZ(@IM<V=S='(@(K'7N+(@55),.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA
M9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B
M26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-S8Q"B,L(&9U>GIY"FUS9VED("));6%G92!U<&QO
M860B"FUS9W-T<B`BQ\JUY2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W
M"B,L(&9U>GIY"FUS9VED("));6%G97,B"FUS9W-T<B`BL=>XLB!54DPB"@HC
M.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A
M+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU
M-"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`BL*'!KK_`
ML>(L(+3<L.@@)7,B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS
M9W-T<B`BL*'!KK_"(,?7N/$Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R("*P
MH<&NO\(@Q]>X\3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R
M(@IM<V=S='(@(E]SM-G`O;^A(,?@(,/?L*$B"@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S4*;7-G:60@(DEN8V]R<F5C="!A
M8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*(RP@9G5Z>GD*;7-G
M:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S
M='(@(KOGO^O`VL#,N*>P^B"^S\BCN*8@P-2WPL?/O+R_Y"(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"B,L(&9U>GIY"FUS9VED("(B"B))
M;F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A
M9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@
M;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(L/?L*''S[3"M:4@O\"W
M^;"A(+G?N_W'W[W`M,^TV2X@O<.]NL7;L/RXKL#:OZ&PU""UM;_RP+L@O^3#
MN\?/O<.QXB"YV;;XM,^TV2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B"FUS
M9W-T<B`BM>F_J;ZRL>(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*(RP@9G5Z>GD*;7-G:60@
M(DEN9&EA(@IM<V=S='(@(K[XP+TB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM
M<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#`*(RP@9G5Z>GD*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("*^^,"](@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PHC
M+"!F=7IZ>0IM<V=I9"`B26YF;R(*;7-G<W1R("*YJ[W#(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(U-PHC+"!F=7IZ>0IM<V=I9"`B26YF;W)M
M871I;VXB"FUS9W-T<B`BP:2ZN"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,S`*(RP@9G5Z>GD*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO
M;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(L#,O^NPH;3)Q]$@O+'%P[OGQ]?`
MS""^^+W`M,^TV2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F
M=&5R(@IM<V=S='(@(E]OM-G`O;^A(+^M(,/?L*$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G
M:60@(DEN<V5R="!);6%G92(*;7-G<W1R("*QU[BR(,/?L*$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("))
M;G-E<G0@5&%B;&4B"FUS9W-T<B`BQZ4@P]^PH2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!7
M96(@3&EN:R(*;7-G<W1R("+`I2"XM<6I(,/?L*$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@
M(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R(")?8[[5OZ$@OZT@P]^P
MH2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T
M:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`BQ_;`YR"_K2"UVK^A(+OU(+^M(,/?
ML*$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E
M('1H92!C=7)R96YT(&]N92(*;7-G<W1R("+']L#G(+^M(+[5OZ$@N_4@OZT@
MP]^PH2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T
M:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`BQ_;`YR#'X""UVK^A(+OU(,?@(,/?
ML*$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H
M92!C=7)R96YT(&]N92(*;7-G<W1R("+']L#G(,?@(+[5OZ$@N_4@Q^`@P]^P
MH2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H
M92!C=7)R96YT(&YO9&4B"FUS9W-T<B`BQ_;`YR#!]L&A(+7:OZ$@M-RV]"##
MW["A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E
M('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`BQ_;`YR#!]L&A(+[5OZ$@M-RV
M]"##W["A(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*(RP@9G5Z>GD*
M;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`BM.O#
MO""QVR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,SD*;7-G:60@(DEN
M<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV
M92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED("))
M;G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R("*UVK^A(+R_(,/?L*$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y
M"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`BOM6_H2"\OR##
MW["A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R
M("*UVK^A(+^M(,/?L*$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E
M9F]R92(*;7-G<W1R("*^U;^A(+^M(,/?L*$B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`HC+"!F=7IZ>0IM<V=I9"`B26YS
M97)T(&UE<W-A9V5S(@IM<V=S='(@(LBXO<7'T2"XWL#/(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS
M9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(K7:OZ$@M-RV
M]"##W["A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R
M92(*;7-G<W1R("*^U;^A(+3<MO0@P]^PH2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R
M="!R;W<@869T97(B"FUS9W-T<B`BM=J_H2#'X"##W["A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I
M9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`BOM6_H2#'X"##W["A(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,`IM<V=I9"`B26YS97)T('1H
M92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@
M(K'7N+(@P]^PH2^\]L&D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM
M<V=S='(@(KBUQ:D@P]^PH2^\]L&D(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N
M="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U"B,L(&9U
M>GIY"FUS9VED("));G1E9V5R(@IM<V=S='(@(K"AO^ZUI2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,S,*;7-G:60@(DEN=&5G97(@;&ES="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A
M($AE861E<BDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]Z:7`N<&AP.C$W,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O>FEP+G!H<#HR,#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+WII<"YP:'`Z,C$P"B,L(&9U>GIY"FUS9VED("));G9A;&ED(%I)4"!D
M871A(@IM<V=S='(@(L#?N/BUR"#`S+BG+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z,S0*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@87!P;&EC871I
M;VXN(@IM<V=S='(@(L#?N/BUR"#`S+BG+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@HC+"!F=7IZ>0IM<V=I
M9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T<B`BP-^X^+7((,#,N*<N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,34X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R
M,S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(Y.0HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"B,L(&9U>GIY"FUS9VED
M("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R("+`W[CXM<@@P,RX
MIRXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#`*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@
M861D<F5S<RXB"FUS9W-T<B`BP-^X^+7((,#,N-[`SR#!UKS2(@H*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z.#$*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3`P"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(R,`HC+"!F=7IZ>0IM<V=I
M9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R("+`W[CXM<@@P,RXIRXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<W"B,L(&9U>GIY
M"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R("+`W[CXM<@@
MP,RXIRXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<Q"B,L
M(&9U>GIY"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G
M<W1R("+`W[CXM<@@P,RXIRXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*(RP@9G5Z>GD*;7-G:60@(DEN=F%L
M:60@;7-G7W1Y<&4N(@IM<V=S='(@(L#?N/BUR"#`S+BG+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PHC+"!F
M=7IZ>0IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T
M<B`BP-^X^+7((,#,N*<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDV"B,L(&9U>GIY"FUS9VED("));G9A;&ED
M(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`BP-^X^+7((,#,N*<N
M(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W"B,L(&9U>GIY"FUS
M9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R("+`W[CX
MM<@@P=:\TK?/(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W
M,PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R
M("+`W[CXM<@@P=:\TK?/(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$W-0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N
M(@IM<V=S='(@(L#?N/BUR"#!UKS2M\\B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*(RP@9G5Z>GD*;7-G:60@
M(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(L#?N/BUR"#!UKS2M\\B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`W-B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$R-C(*(RP@9G5Z>GD*;7-G:60@(DEN=F%L
M:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(L#?N/BUR"#`S+BG+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0HC
M+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T
M<B`BP-^X^+7((,#,N-[`SR#!UKS2(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"B,L(&9U>GIY"FUS9VED("))
M;G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`BP-^X^+7((,#,N*<N(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U-PIM<V=I9"`B26YV96YT
M;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-SD*(RP@9G5Z>GD*;7-G:60@(DEN=F5R="!S96QE8W1I
M;VXB"FUS9W-T<B`BP-JXH['B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"B,L(&9U>GIY"FUS
M9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(K3KQ]&Y
MSK&Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,`HC+"!F=7IZ>0IM<V=I9"`B27)E;&%N9"(*;7-G<W1R("+`
MT,'V(+[*P+H@N-[`SR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T
M960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"B,L(&9U>GIY
M"FUS9VED("))<W)A96PB"FUS9W-T<B`BP-#!]B"^RL"Z(+C>P,\B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-0IM<V=I9"`B27-S
M=65R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(K'BO^_`S+'B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@R"B,L(&9U>GIY"FUS9VED("))=&%L>2(*;7-G<W1R
M("+`S[JP(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U
M"FUS9VED(")*86YU87)Y(@IM<V=S='(@(C&_^2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM
M<V=I9"`B2F%P86XB"FUS9W-T<B`BP,^ZNR(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@W"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S
M='(@(L#/NKN^[B`H25-/+3(P,C(M2E`I(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HS,3`*;7-G:60@(B(*(DIA=F%S8W)I<'0@:&%S(&)E96X@
M9&ES86)L960@;VX@>6]U<B!B<F]W<V5R(&%N9"!T:&ES('!A9V4@;6%Y(&YO
M="!B92`B"B)D:7-P;&%Y:6YG(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`W"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M,0IM<V=I9"`B2G5L>2(*;7-G<W1R("(WO_DB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R
M("(VO_DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(L&DM\0B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`BL*&_[K6E(,&D
MM\0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(K[GPLH@
MP:2WQ"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`BO]["
MRB#!I+?$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B
MO\"XI<+*(,&DM\0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(V-`IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+97)B97)O<R!S
M97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#$Q"B,L(&9U>GIY"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B
MQ+B\QR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM
M<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DX"B,L(&9U>GIY"FUS9VED(")+97D@
M57-A9V4B"FUS9W-T<B`BN-Z]P\'V(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-S0P"B,L(&9U>GIY"FUS9VED(")+97D@86QR96%D>2!E
M>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(F9T<""\
MK;GV(+^LL.$@O\"W^2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*
M;7-G:60@(DMI9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+
M:7)I8F%T:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*(RP@9G5Z>GD*;7-G
M:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(K3KQ]&YSK&Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`BM.O'T;G.L;DB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X.`IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@
M(L?1L;F^[B`H155#+4M2*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*(RP@
M9G5Z>GD*;7-G:60@(DQA7WEO=70B"FUS9W-T<B`BM\ZQU[[&O_0B"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG=6%G92(*
M;7-G<W1R("*^\+[N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE
M)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,38Y"B,L(&9U>GIY"FUS9VED("),87-T($AA;&8B"FUS
M9W-T<B`BN+;!]KBW(,;DP,S!]B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HW-@HC+"!F=7IZ>0IM<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS
M9W-T<B`BOL_(HR(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z.#@*(RP@9G5Z>GD*;7-G:60@(DQA<W0@475A<G1E<B(*
M;7-G<W1R("*XML'VN+<@QN3`S,'V(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-3$*(RP@9G5Z>GD*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B
MN+;!]KBW(,;DP,S!]B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R
M("*XML'VN+<@M\ZQU\#..B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.C<R,0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F
M<F]M("5S(@IM<V=S='(@(KBVP?:XMR"WSK'7P,XZ("5S+"#!HKS3(,"GQ*$Z
M("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$V"FUS9VED("),
M87-T(&QO9VEN.B!.979E<B(*;7-G<W1R("*XML'VN+<@M\ZQU\#..B"^^,"]
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@Y"B,L(&9U>GIY"FUS9VED("),871V:6$B"FUS9W-T
M<B`BN+BUZ;'B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED
M("),87<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO=70B"FUS9W-T<B`B
MM[G`S+[&O_0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`BO]["RB(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3D*(RP@9G5Z>GD*;7-G:60@(DQE9G0@
M:&5A9&5R(@IM<V=S='(@(K^Y.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,34*(RP@9G5Z>GD*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@
M(K^Y.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*
M;7-G:60@(DQE=F5L(@IM<V=S='(@(L#,M;\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G
M:60@(DQI8F5R:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),
M:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0HC+"!F=7IZ>0IM<V=I
M9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R("*WSK'7P,XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@HC+"!F=7IZ>0IM<V=I
M9"`B3&EG:'0@4F%I;B(*;7-G<W1R("*WSK'7P,XB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B
M3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R("*WSK'7P,XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`HC+"!F=7IZ>0IM<V=I
M9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(K?.L=?`SB(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"B,L(&9U>GIY"FUS
M9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R("*WSK'7P,XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`HC+"!F=7IZ
M>0IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`BM\ZQ
MU\#.(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S$*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`BM\ZQU\#.
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*
M;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-`HC+"!F=7IZ>0IM
M<V=I9"`B3&EN:R(*;7-G<W1R("*WSK'7P,XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI
M;FL@<&]I;G1S('1O.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O
M('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H
M<#HQ.#,*(RP@9G5Z>GD*;7-G:60@(DQI;FMS(@IM<V=S='(@(K?.L=?`SB"]
MP\#;P-N^]R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@HC+"!F=7IZ
M>0IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(KOU(+C>P,\B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B
M3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*(RP@9G5Z>GD*;7-G:60@(DQI<W0@
M1&%T86)A<V5S(@IM<V=S='(@(KBVP?:XMR#&Y,#,P?8B"@HC.B!S97)V:6-E
M<R]H96QP+VEN9&5X+G!H<#HU,`IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*
M;7-G<W1R("*UM;_ROLL@N/'"]R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,S(*(RP@9G5Z>GD*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(KBVP?:X
MMR#&Y,#,P?8B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP
M.C4Y-`HC+"!F=7IZ>0IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S='(@(KOG
MO^O'S\'V(+[*M,(@N-[`S\?4(+S[L>@B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4X.0HC+"!F=7IZ>0IM<V=I9"`B3&ES="U(96QP
M(@IM<V=S='(@(K6UO_*^RR"X\<+W(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12](96%D97)S+G!H<#HU.38*(RP@9G5Z>GD*;7-G:60@(DQI<W0M260B"FUS
M9W-T<B`BM;6_\K[+(+CQPO<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE
M861E<G,N<&AP.C4Y,@HC+"!F=7IZ>0IM<V=I9"`B3&ES="U/=VYE<B(*;7-G
M<W1R("*UM;_ROLL@N/'"]R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3$*(RP@9G5Z>GD*
M;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(KOGO^O'S\'V(+[*M,(@
MN-[`S\?4(+S[L>@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N
M<&AP.C4Y,`HC+"!F=7IZ>0IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G
M<W1R("*[Y[_KQ\_!]B"^RK3"(+C>P,_'U""\^['H(@H*(SH@861M:6XO<V5S
M<VEO;G,N<&AP.C4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("),:7-T
M:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`BN^>_Z\?2(+SV(+[X
MM,(@N^>_Z\#:(+CQM\\N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE
M9#H@)7,B"FUS9W-T<B`BN^>_Z\?2(+SV(+[XM,(@N^>_Z\#:(+CQM\\N(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),
M:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("*[Y[_KQ](@O/8@
MOOBTPB"[Y[_KP-H@N/&WSRXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#<*(RP@9G5Z>GD*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`BO*VX[3HB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#D*(RP@9G5Z>GD*;7-G:60@(DQI=&AU86YI82(*;7-G
M<W1R("*SRKKQ(+3<P*<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I;6%G97,N<&AP.C@S"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3$*(RP@9G5Z>GD*
M;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R("*]Q\?@(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@S"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8T"B,Z(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C8U"B,L(&9U
M>GIY"FUS9VED("),;V-A=&EO;B(*;7-G<W1R("*]Q\?@(@H*(SH@;&]G:6XN
M<&AP.C$W,B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3DQ('1E;7!L
M871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I
M9"`B3&]G(&EN(@IM<V=S='(@(K?.L=?`SB(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@
M<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A
M<BYP:'`Z,3@U"FUS9VED("),;V<@;W5T(@IM<V=S='(@(K?.L=>^QK_T(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"B,L(&9U>GIY"FUS9VED("),
M;V=I;B(*;7-G<W1R("*WSK'7P,XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3`W"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R("*WSK'7P,X@O</`
MV\#;OO<B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.38*(RP@9G5Z
M>GD*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@
M;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@
M(B(*(K[NMK(@P,S`K[?.(+?.L=?`SL#,(+W'QM#'W[W`M,^TV2X@M.NZSKK0
MP,<@L.:_[""[Y[_KP-H@P,RXIR"VQ[3"(+[/R*.PH2#`WR(*(KCX(,#4M\*U
MR""PYK_L(+G?N_W'U;3/M-DN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z.3DR"B,L(&9U>GIY"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@
M(KOHP:8@O<?&T"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C4*
M(RP@9G5Z>GD*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R("*WSK'7OL:_]"(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B
M3&]V92(*;7-G<W1R("+`S+6_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(DQO=R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(K'7N*Z]
MNB"\TKFNP-HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T97)S
M(@IM<V=S='(@(K;SQKX@O-*YKL#:(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@
M<F]M86X@;G5M8F5R<R(*;7-G<W1R("*WSKBV(+S2N:[`VB"\_<#:(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#`*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S."!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Q"FUS9VED(")-3U1$(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP
M.C,V"B,L(&9U>GIY"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I
M;F5D(&YO(&1A=&$N(@IM<V=S='(@(L;$P,^_H2"^QKFKM[$@P-JWX;"A(+[X
MO<"TS[39+B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(DU3
M1R(*;7-G<W1R(")#5E,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@
M(DUA8V%O(@IM<V=S='(@(C._^2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C
M961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*(RP@9G5Z>GD*;7-G
M:60@(DUA9VEC(@IM<V=S='(@(L"EN-[`SR(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HX,0IM<V=I9"`B36%I;"(*;7-G<W1R("*XWL#/(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R,@IM<V=I9"`B36%I;"!!9&UI
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS
M9W-T<B`B7VNXM<6I(+BXM>FQXBXN+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ
M>0IM<V=I9"`B36%L87=I(@IM<V=S='(@(L"EN-[`SR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-0HC+"!F=7IZ>0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`BP*6XWL#/(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-86QD:79E<R(*;7-G<W1R
M("*XWL#/(,?*Q<TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(DUA
M;&DB"FUS9W-T<B`BP*6XWL#/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS
M9VED(")-86QT82(*;7-G<W1R("+`I;C>P,\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3$*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E
M9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO
M<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,34S"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#0*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-C@*;7-G:60@(DUA
M<%%U97-T(&UA<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*
M;7-G:60@(DUA<F-H(@IM<V=S='(@(C._^2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*;7-G:60@(DUA<F=I
M;B(*;7-G<W1R("*PH<#EP-JXKB(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E
M96X@9FQA9W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G
M<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3,*(RP@9G5Z>GD*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T
M<B`BL*'`Y<#:N*XB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P
M,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(L#/Q*''S[3"(,?7
MN/$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3,*(RP@9G5Z>GD*;7-G:60@(DUA=7)I=&%N:6$B
M"FUS9W-T<B`BL*'`Y<#:N*XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I
M=&EU<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I
M="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`X"B,L(&9U>GIY"FUS9VED(")-87@@;65S<V%G
M92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`BN-Z]P\'V(,?7N/$B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,P-@IM<V=I9"`B36%X('1E;7`@;&%S="`R
M-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,CDX"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@
M4&]R=&%L($)L;V-K<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-87AI;75M(&QE
M;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(C6_^2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B-;_Y
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"B,L(&9U>GIY"FUS9VED
M(")-961I8VEN92(*;7-G<W1R("*[Z,&FM<@@N-[`SR(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(DUE
M;6)E<G,B"FUS9W-T<B`B,3&_^2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-S@*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`BN-ZTNB"X\+7E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`BO+\@Q]7$H;'B(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`BN-Z]P\'V(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE
M<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@
M8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS
M9W-T<B`BN-Z]P\'V(,?7N/$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"B,L(&9U>GIY"FUS
M9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`BN-Z]P\'V(,#/P-HB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PHC+"!F=7IZ>0IM
M<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`BP,R_
MZ["AM,G'T2"\L<7#N^?'U\#,(+[XO<"TS[39+B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3$R"B,L(&9U>GIY"FUS9VED("(B"B)-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("*\O+K.P:2ZN+"A(+#\N*[`VKBF
M(,"GQ]@@L>*WS[7'ON[!L[W`M,^TV2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,38U"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]2
M4$,O4E!#+WAM;')P8RYP:'`Z.#$@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP
M:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@
M;F]T(&1E9FEN960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O
M<F5S="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D
M969I;F5D+B!#86QL960@;65T:&]D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S0@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HW-0IM<V=I9"`B365T<FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM
M<V=I9"`B365X:6-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-
M:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M-@IM<V=I9"`B36ED9&QE(@IM<V=S='(@(K"AO^ZUI2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y
M<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3`*;7-G
M:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B36EN('1E;7`@;&%S="`V
M(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N
M;W0@>65T(&5X<&ER960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-`HC+"!F=7IZ>0IM<V=I9"`B36ER
M<F]R(@IM<V=S='(@(K_`M_DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED
M(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@(B(*(DUI
M<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@
M;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#0*(RP@9G5Z>GD*;7-G:60@(DUI<W-I;F<@;65S<V%G
M92!)1"XB"FUS9W-T<B`BN-Z]P\'V(,#,M;_'S['B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@
M(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y-`HC+"!F=7IZ>0IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$+B(*
M;7-G<W1R("*XWKW#P?8@P,RUO\?/L>(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"B,L(&9U>GIY"FUS9VED(")-;R(*
M;7-G<W1R("+`S+6_(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<T
M"B,L(&9U>GIY"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R("*[]2"XWL#/
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*
M;7-G:60@(DUO9&5R871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HW,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C@X"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R(")54DP@O/;!I"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<S"B,L(&9U
M>GIY"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(K^JQ](B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3`*(RP@9G5Z>GD*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(K3KQ]&YSK&Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"B,L(&9U>GIY"FUS9VED(")-
M;VYA8V\B"FUS9W-T<B`B,[_Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG
M;VQI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-3DT"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-
M;VYT:&QY(@IM<V=S='(@(KC%O_DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUO
M;G1S97)R870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-S(@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C4S"B,L('!H<"UF;W)M870*;7-G
M:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP
M96-T960@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R
M;V-C;R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"B,L
M(&9U>GIY"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(KJYN^<B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I
M9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C4P.0IM<V=I9"`B36]V92!$;W=N(@IM<V=S
M='(@(K[&MZ&WSB#`S+6_(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z-3$S"B,L(&9U>GIY"FUS9VED(")-;W9E($QE9G0B"FUS9W-T
M<B`BP*>WSB#`S+6_(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z-3$W"B,L(&9U>GIY"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@
M(K_`N*7"RB(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C4P-0IM<V=I9"`B36]V92!5<"(*;7-G<W1R("+`I[?.(,#,M;\B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"B,L(&9U
M>GIY"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`BOL:WH;?.(,#,M;\B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(S"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*(RP@
M9G5Z>GD*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`BP*>WSB#`S+6_(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#0*;7-G:60@(DUU;'1I+6QE=F5L
M(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U-0IM<V=I9"`B375L=&EM87`@
M54L@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R-#(*(RP@9G5Z>GD*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G
M<W1R("*QU,2B*+?\*2"\L<7#(+_`M_DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#`P"B,L(&9U>GIY"FUS9VED(")->2!!8V-O=6YT(@IM<V=S
M='(@(K_`N*?"][SX(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"B,L
M(&9U>GIY"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@
M(L&DNK@B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C4T"FUS9VED
M(")->2!0;W)T86PB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D
M:70N<&AP.C$S-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(DUY86YM87(B"FUS9W-T
M<B`BP,RXIR(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC
M92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B
M"FUS9W-T<B`BP,RXIR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-PHC+"!F=7IZ>0IM<V=I9"`B3F5P86PB"FUS9W-T
M<B`BN_4@N-[`SR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PHC+"!F=7IZ>0IM<V=I9"`B3F5T
M:&5R;&%N9',B"FUS9W-T<B`BN_4@N-[`SR(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED
M(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@
M0F%S92!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@
M55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3@U"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T
M"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T
M<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E(%-3
M3"!S97)V97(@;F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A
M=&4@8V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4X,`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@
M='EP92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C4Q"FUS9VED(").971W;W)K(@IM<V=S='(@(K/7QJZ_]L6I(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,S4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-@IM<V=I
M9"`B3F5V97(B"FUS9W-T<B`BN^>_Z[[(Q]0B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G
M:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#
M871E9V]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+V5M86EL<RYP:'`Z.#$*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(O96UA:6QS+G!H<#HY-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT
M97(O1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(").97<@365S<V%G92!T;R`E<R(*;7-G<W1R("*XWKW#P?8@P-N\
MNB`H)7,I(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M
M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"B,L(&9U>GIY"FUS
M9VED(").97<@36]O;B(*;7-G<W1R("*[]2"XWL#/(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0HC+"!F=7IZ>0IM<V=I9"`B3F5W
M(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`BM;6_\KB[(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDX"B,L(&9U>GIY"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R("*[
M]2"XWL#/(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W"B,L
M(&9U>GIY"FUS9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`BOL_(HR(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*(RP@
M9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S
M='(@(K[/R*.PH2#`S\2AQ\_!]B"^RKW`M,^TV2XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN
M9&]W("A?8FQA;FLI(@IM<V=S='(@(KOU(,.B*%]B;&%N:RDB"@HC.B!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X.0HC+"!F=7IZ>0IM<V=I
M9"`B3F5W<R(*;7-G<W1R("*[]2"XWL#/(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,P-0IM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-2!T96UP;&%T97,O9&%T
M82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-0IM<V=I9"`B3F5X
M="(*;7-G<W1R("*TV<"](@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"B,L
M(&9U>GIY"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(K39P+T@QN3`
MS,'V(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S(@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S8*(RP@9G5Z>GD*;7-G:60@
M(DYE>'0@;W!T:6]N<R(*;7-G<W1R("*_R;S'P+BWSB"UN;[&L*&QXB(*"B,Z
M(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z,3`S"B,L(&9U>GIY"FUS9VED
M(").97AT/B(*;7-G<W1R("*TV<"](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").
M:6-A<F%G=6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"B,L(&9U>GIY"FUS
M9VED(").:6=E<B(*;7-G<W1R("*[Y[_KOLC'U"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@HC
M+"!F=7IZ>0IM<V=I9"`B3FEG97)I82(*;7-G<W1R("*[Y[_KOLC'U"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.#`*(RP@9G5Z>GD*;7-G
M:60@(DYI9VAT(@IM<V=S='(@(K_`N*7"RB(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PHC+"!F
M=7IZ>0IM<V=I9"`B3FEU92(*;7-G<W1R("+"_,&V(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B3F\B"FUS
M9W-T<B`BOL:TS[_`(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N
M:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A
M('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C$P-0IM<V=I9"`B
M3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M-SD@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C0U"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(V-PIM<V=I9"`B3F\@
M8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HU,`HC+"!F
M=7IZ>0IM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!
M3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4U%,(,#.P?4@O+/!I,&DNKBP
MH2"^^+W`M,^TV2XB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`HC+"!F
M=7IZ>0IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R("*ZK[#FN^?'UR"UQ[6Y
MN*ZQXB(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS
M9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S
M:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$V-R!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,@HC.B!F<F%M97=O
M<FLO571I;"]5=&EL+G!H<#HW-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B`E<RXB"FUS9W-T<B`B4U%,(%9&4R"\L\&DP:2ZN+"A(+[XO<"TS[39+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(T"FUS9VED(").;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&
M4RXB"FUS9W-T<B`B1E10(%9&4[BF(,"GQ]$@O+/!I,&DNKBPH2"^^+W`M,^T
MV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8V.0IM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-1
M3"!61E,N(@IM<V=S='(@(E-13"!61E,@O+/!I,&DNKBPH2"^^+W`M,^TV2XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S$W"FUS9VED
M(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,+49I;&4@5D93+B(*;7-G<W1R(")344PM1FEL92!61E,@O+/!I,&DNKBP
MH2"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-`HC+"!F=7IZ>0IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P
M<&QI960N(@IM<V=S='(@(KOU(+C>P,\B"@HC.B!F<F%M97=O<FLO0G)O=W-E
M<B]"<F]W<V5R+G!H<#HX-S<*(RP@9G5Z>GD*;7-G:60@(DYO(&9I;&4@=7!L
M;V%D960B"FUS9W-T<B`BQ\JUY2(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H
M<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C@@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(S"FUS9VED(").
M;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(DYO(&QO8V%T
M:6]N('!R;W9I9&5D+B(*;7-G<W1R("+&^K3UN*8@O+'%P\?/O+R_Y"(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S
M"B,L(&9U>GIY"FUS9VED(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R
M("*[]2"XWL#/(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S8*(RP@9G5Z>GD*;7-G:60@(DYO(&YA;64@<W!E8VEF
M:65D+B(*;7-G<W1R("*YKL#:OZT@P-2WPB"_P+?Y(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*(RP@9G5Z>GD*
M;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(KFNP-J_K2#`
MU+?"(+_`M_DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@
M(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"B,L(&9U>GIY"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B4U%,(,#.P?4@O+/!I,&DNKBPH2"^^+W`M,^TV2XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C$P.`HC+"!F=7IZ>0IM<V=I9"`B
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(E-13"#`SL'U(+RSP:3!I+JXL*$@OOB]P+3/M-DN(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,@HC+"!F=7IZ>0IM<V=I
M9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R(")344P@P,[!]2"\L\&DP:2ZN+"A(+[XO<"TS[39
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<@9G)A;65W
M;W)K+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]P86TN<&AP.C<U"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E-1
M3"#`SL'U(+RSP:3!I+JXL*$@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]P87-S=V0N<&AP.C$S-0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B4U%,(,#.P?4@O+/!I,&DNKBPH2"^^+W`M,^TV2XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.#0*(RP@9G5Z>GD*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(E-13"#`SL'U(+RSP:3!I+JXL*$@OOB]P+3/M-DN(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@V"FUS9VED("(B"B).
M;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P
M96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#
M4R`Q,B!D871A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW-3`*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B
MP::X\2"^^,"](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT,PHC+"!F=7IZ>0IM<V=I9"`B3F\@<G5L97,B"FUS
M9W-T<B`BPOS!MB(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T
M.0HC+"!F=7IZ>0IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS
M9W-T<B`BN:[`VK^M(,#4M\(@O\"W^2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*(RP@9G5Z>GD*;7-G:60@
M(DYO('-I9&5S(@IM<V=S='(@(L+\P;8B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C4X,PHC+"!F=7IZ>0IM<V=I9"`B3F\@<W5C:"!F:6QE(@IM
M<V=S='(@(L+\P;8B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3,X"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F
M;W(@8V%C:&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"B,L(&9U>GIY"FUS9VED(").;R!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`BN^>_Z\#:P,RX
MI[#Z(+[/R*.XIB#`U+?"Q\^\O+_D(@H*(SH@9G)A;65W;W)K+U)00R]24$,O
M>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E='5R
M;F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HY-S$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.CDX,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.3DR"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#`Y"B,L(&9U>GIY"FUS9VED(").;R!V86QU97,B"FUS9W-T
M<B`BPOS!MB(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@
M(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@
M4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD
M(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE
M8W0N:6YC.CDS"FUS9VED(").;VYE(@IM<V=S='(@(KRQQ</'S\'V(+[*P+TB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP
M"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(").;W)D:6,@*$E33RTX.#4Y
M+3$P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@
M27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-
M87)I86YA($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"B,L(&9U
M>GIY"FUS9VED(").;W)W87DB"FUS9W-T<B`BP/RTWB(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0P"B,L(&9U>GIY"FUS9VED(").
M;W0@069T97(B"FUS9W-T<B`BP-.]P[JXL/RUQ\'V(+[*P+H@N-[`SR(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"B,L(&9U>GIY
M"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(L#3O<.ZN+#\M<?!]B"^RL"Z
M(+C>P,\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,#@*(RP@
M9G5Z>GD*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R("*U\+>ZQ>2X
MKB(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z
M-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.30*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"B,L(&9U>GIY"FUS9VED(").
M;W0@:6UP;&5M96YT960N(@IM<V=S='(@(KOHP::UQ\'V(+[*P+H@N-[`SR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*
M(RP@9G5Z>GD*;7-G:60@(DYO="!S970B"FUS9W-T<B`BP::X\2"^^,"](@H*
M(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H
M<#HQ-#,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+G!H<#HQ-3@*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I
M;VY(86YD;&5R+G!H<#HQ-S,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#<*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`U(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(T."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8U"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(Y-PHC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$R(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HS,CD*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V,B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z-#(R"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU,#$@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W,`HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-3@W(&9R86UE=V]R:R]61E,O5D93+G!H<#HV-C4*(RP@9G5Z>GD*
M;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(KOHP::UQ\'V(+[*P+H@
MN-[`SR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HR-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$W.`IM<V=I9"`B3F]T97,B"FUS9W-T<B`BPOS!
MMB(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B
M3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").
M;W9E;6)E<B(*;7-G<W1R("(Q,;_Y(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3`T-@HC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(C$Q
MO_DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U"B,L(&9U>GIY
M"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R("+'X,#'(+SV
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#(S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$T-#4@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(K^MP,<@O/8B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30T,R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`BQ^#`QR"\]B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T
M"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN
M(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HX-S,*(RP@9G5Z>GD*;7-G:60@(D]B:F5C="(*;7-G<W1R("+!IKCQ(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*(RP@9G5Z>GD*;7-G
M:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(L&FN/$B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3`T"B,L(&9U>GIY"FUS9VED(")/8W1A;"(*
M;7-G<W1R("+`S[JP(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B,3"_^2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT
M97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R
M-@HC+"!F=7IZ>0IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(L&FN/$B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@
M;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"B,L(&9U>GIY"FUS
M9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`BOL_(HR(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HT-@HC+"!F=7IZ>0IM<V=I9"`B3VQD('!A
M<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R("*^S\BC(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@
M<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS
M:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW,0HC+"!F
M=7IZ>0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*
M;7-G<W1R("+`W[CXM<@@P,RXWL#/(,'6O-(B"@HC.B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y
M<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W
M;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]I9G)A;64N<&AP.C,U"B,L(&9U>GIY"FUS9VED(")/<&5N
M(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("*[]2##HK^A(+BUQ:D@OZVQXB(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED
M(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@
M<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@
M(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`BN_4@
MPZ*_H2"XM<6I(+^ML>(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*
M;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G
M<W1R("*\L<7#N^?'UR(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP
M;&%T97,O<')E9G,O87!P+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")/
M<'1I;VYS(&9O<B`E<R(*;7-G<W1R("(E<R"\L<7#N^?'UR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R
M9&5R960@3&ES="(*;7-G<W1R("*\_<#:(+CQM\\B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B3W)G86YI<V%T:6]N
M(@IM<V=S='(@(K3<P[PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4V.`HC+"!F=7IZ>0IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI
M="(*;7-G<W1R("*TW,.\(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$S,@HC+"!F=7IZ>0IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R("*TW,.\
M(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*(RP@9G5Z>GD*;7-G:60@
M(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@(L#?N/BU
MR"#`S+BG+B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF
M;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!S97)V
M:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(K'B
MQ;@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$S,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q"FUS9VED(")/=&AE
M<B!);F9O<FUA=&EO;B(*;7-G<W1R("*QXL6X(,&DNK@B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,Q"B,L(&9U>GIY"FUS9VED(")/=VYE<B!0
M97)M:7-S:6]N<R(*;7-G<W1R("*[Y[_KP-H@L<?'T2(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<&%M+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B4$%-(&%U
M=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(KOHP:8@
MO<?&T"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N
M<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R-S,*(RP@9G5Z
M>GD*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R("*\K;CM
M.B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,3D*;7-G
M:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S<Q"FUS9VED(")01U`@4'5B;&EC
M($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HQ,S4S"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.`HC+"!F=7IZ>0IM
M<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!A9&UI;B]P:'!S
M:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PHC+"!F=7IZ
M>0IM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R("*WSK'7P,XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B
M4$T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`IM
M<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")032!3=6XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#(*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO
M;B!I<R!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM
M<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V"FUS9VED(")0861D
M:6YG(@IM<V=S='(@(L;DM?DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*(RP@9G5Z>GD*;7-G
M:60@(E!A:VES=&%N(@IM<V=S='(@(KK9P,RQXB(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*
M(RP@9G5Z>GD*;7-G:60@(E!A;&%U(@IM<V=S='(@(L"EN-[`SR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I
M960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"B,L(&9U>GIY"FUS9VED(")0
M86YA;6$B"FUS9W-T<B`BP,RXIR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P
M=6$@3F5W($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED
M(")087)A9W5A>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS-@HC+"!F=7IZ>0IM<V=I9"`B4&%R=&QY($-L
M;W5D>2(*;7-G<W1R("*ZN;OG(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C`Q.`HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<W('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0R,PIM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B
MOL_(HR(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I
M9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,@HC+"!F
M=7IZ>0IM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(K[/R*,B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,34R"B,L(&9U
M>GIY"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R(")344P@P,[!]2"\L\&DP:2ZN+"A(+[XO<"T
MS[39+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-3,*(RP@9G5Z
M>GD*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@
M(K'BQ;@@P:2ZN"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M,`HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(K[/R*,B"@HC
M.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I
M9"`B4&%S<W=O<F0Z("(*;7-G<W1R("*^S\BC(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S0*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S
M(&UU<W0@;6%T8V@N(@IM<V=S='(@(K[/R*.PH2#`S\2AQ\_!]B"^RKW`M,^T
MV2XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S
M=&4B"FUS9W-T<B`BNMG`S+'B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A
M<F0B"FUS9W-T<B`BQ:RXL[JXM>6_H;RM(+K9P,RQXB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B
M"FUS9W-T<B`BL.:WSB(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN
M8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B4&5O<&QE
M(@IM<V=S='(@(K^JQ](B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R("+&V[R^
MQJXB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M
M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM
M<V=S='(@(L"OP?8@L/RXKB#`V[[W(+W'Q^`B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#`V"B,L(&9U>GIY"FUS9VED(")097)F;W)M(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(L"OP?8@L/RXKB#`
MV[[W(+W'Q^`B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U
M-@HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R("*PL\#.(+C>
MP,\B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E
M9"XB"FUS9W-T<B`BO<2ZL,#:(%PB)7-<(B"PH2"[Z,&FM<>^^KW`M,^TV2XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X-@HC+"!F=7IZ>0IM
M<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`BL+/`SB"XWL#/(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C$@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G:60@(E!E<FUI
M<W-I;VYS(@IM<V=S='(@(L7DM]`B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H
M<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN+W!E
M<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"B,L
M(&9U>GIY"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G
M<W1R("*P_+BN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U"FUS9VED
M(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R("*PL\#.(,&DNK@B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4U"B,L(&9U>GIY"FUS9VED(")0971S(@IM<V=S
M='(@(L?(O+\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(L#\R*VY^,BC(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W.`IM<V=I9"`B4&AO=&]S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`BQ\B\OR(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T
M('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-3<Q"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@
M96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R("*[];?.O^X@P,RX
MI\"[(,#4M\+'S[R\O^0Z(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z,3(*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E;G1E
M<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(EQ<;KOU
MM\Z_[B"XWL#/Q]3`QR#`S+BGP+L@P-2WPL?/O+R_Y#I<7&XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Q"B,L(&9U>GIY"FUS9VED(")0;&5A
M<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R("*_P[G9N*4@
ML,N[]B"Y_,'6N*8@P-2WPL?/O+R_Y"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-C8P"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D871E
M+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4Q"B,L(&9U
M>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R
M("*_P[G9N*4@L,N[]B"Y_,'6N*8@P-2WPL?/O+R_Y"XB"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED
M92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(KFNP::_H2"T
MZ\?1(+_DON#`NR#`U+?"Q]@@P=:\O+_D+B(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM
M<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O
M<F0B"FUS9W-T<B`BN^>_Z\#:P,RXI[#Z(+[/R*.XIB#`U+?"Q\^\O+_D(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A
M<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I
M=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H
M<#HW,`HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E
M9V]R>2!N86UE.B(*;7-G<W1R("*[];?.O^X@P,RXI\"[(,#4M\+'S[R\O^0Z
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDY"B,L(&9U>GIY"FUS9VED(")0;VQA;F0B"FUS9W-T
M<B`BR+B[YR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B
M4&]L:71I8W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0X-PHC+"!F=7IZ>0IM<V=I9"`B4&]L;',B"FUS9W-T<B`BOZTZ(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$Q"B,L(&9U>GIY"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A
M8FQE(@IM<V=S='(@(L>EP,<@L\JZ\2(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L
M9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E
M<R!H;W5R*',I.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Y.`IM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP
M:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!2
M97%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(U"FUS9VED(")0<F5S<W5R
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U.0IM<V=I
M9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-0HC+"!F=7IZ>0IM<V=I9"`B
M4')E<W-U<F4Z("(*;7-G<W1R("*^S\BC(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P-0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R
M979I97<B"FUS9W-T<B`BN<RXKKJXL>(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R
M979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("*[]2##
MHK^A(+G,N*ZZN+'B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HS-C(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8*(RP@9G5Z
M>GD*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`BP,S`_""XWKW#
MP?8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R("*YKKRM(,#.O.(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@
M(E!R:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(E!R;V)L96TB"FUS
M9W-T<B`BN:[!IB"YW[O]/R(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R
M-@IM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R("*YKL&F(+RS
MN.TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S8Y"FUS9VED(")0
M<F]J96-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,3$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#@*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S(X-0HC+"!F=7IZ>0IM<V=I9"`B4')O;7!T
M('1E>'0B"FUS9W-T<B`BL;/!I+7((+FNP-J_K2(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T
M-0IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#0*;7-G:60@(E!U
M8FQI8R!+97D@26YF;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A
M:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#(*(RP@9G5Z>GD*;7-G:60@(E%A=&%R(@IM<V=S='(@(L#/
MP-HB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C,*;7-G:60@(E%U97)Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B
M475O=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+
M97D@*"5D(&)I="DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(V-`HC+"!F=7IZ>0IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM
M<V=S='(@(KW#L*,@O+/!I"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0S"B,L(&9U>GIY"FUS9VED(")286EN(@IM<V=S='(@
M(K"AP.7`VKBN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#0*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A
M:6X@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*
M;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@=&\@
M4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PHC
M+"!F=7IZ>0IM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`BPOS!MB(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-@HC+"!F=7IZ>0IM
M<V=I9"`B4F%T:6\B"FUS9W-T<B`BQ+B\QR(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3@P"B,L(&9U>GIY"FUS9VED(")296%D(@IM
M<V=S='(@(L#0P?8@OLK`NB"XWL#/(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.#<*(RP@9G5Z>GD*;7-G:60@(E)E860@;65S
M<V%G97,B"FUS9W-T<B`BN_4@N-[`SR(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@
M9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T
M82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N
M92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB
M"FUS9W-T<B`BN+;!]KBW(+CMM\D@N=VZN2(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2
M969R97-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.3$*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"B,L(&9U>GIY
M"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R("*XWL#/Q]0@
MN_6WSB#`T+'B.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-"!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$S"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R,S4*(RP@9G5Z>GD*;7-G:60@(E)E9V5X(@IM<V=S='(@
M(L#GO+/!I"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-#D*;7-G
M:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR,#@*(RP@9G5Z>GD*;7-G:60@(E)E;&]A9"(*;7-G<W1R("+`
MT,'V(+[*P+H@N-[`SR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V"FUS
M9VED(")296UA<FMS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,30*(RP@9G5Z>GD*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S
M='(@(KRQQ<.UR""XWL#/(+OHP:8B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA
M;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U
M975E9"YI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92(*;7-G<W1R("+&
MY+[N*'!A:7(I(+OHP:8B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R("*\
ML<7#M<@@N-[`SR"[Z,&F(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4U-PHC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&-O;'5M
M;B(*;7-G<W1R("*^QK>AM\X@P,RUOR(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*(RP@9G5Z>GD*;7-G:60@(E)E;6]V
M92!F;W)M871T:6YG(@IM<V=S='(@(K[&MZ&WSB#`S+6_(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM
M<V=S='(@(L;DONXH<&%I<BD@N^C!IB(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V
M97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*
M(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`BO+'%P[7((+C>
MP,\@N^C!IB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M
M('1H92!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")296UO=F4@=7-E
M<B(*;7-G<W1R("+&Y+[N*'!A:7(I(+OHP:8B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R("+&Y+[N*'!A:7(I(+OHP:8B
M"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B
M4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C
M;V1E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$U-PHC+"!F=7IZ>0IM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U
M;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R("*\K;CMP+L@NJ^PYL?2(+SV(+[X
MO<"TS[39+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<T(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$R"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E
M<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")61E,@O+/!I"#!I+JXOZ&\K2`G
M<&]R="?`S""^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C8W-2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S,`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I
M;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B5D93(+RSP:0@P:2ZN+^A
MO*T@)W!O<G0GP,P@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U5T:6PO571I
M;"YP:'`Z-S@Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E
M9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R(")61E,@O+/!I"#!I+JXOZ&\K2`G<&]R="?`S""^^+W`M,^TV2XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S4*;7-G:60@
M(E)E<75I<F5D($9I96QD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S.0HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C`@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R("+`U+?"(,/KO-(B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@HC+"!F=7IZ>0IM<V=I9"`B
M4F5S970@4&%S<W=O<F0B"FUS9W-T<B`BOL_(HR(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C(W"B,L(&9U>GIY"FUS9VED(")297-E="!9;W5R
M(%!A<W-W;W)D(@IM<V=S='(@(K[/R*,@R*[`SB(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,S`*(RP@9G5Z>GD*;7-G:60@(E)E<W1O<F4@3&%S="!1=65R
M>2(*;7-G<W1R("*XML'VN+<@QN3`S,'V(@H*(SH@861M:6XO<&AP<VAE;&PN
M<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP
M:'`Z-C8*(RP@9G5Z>GD*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`BL,N[]B"P
MX;#Z(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP
M;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N
M<R(*;7-G<W1R("*_R;S'P+BWSB"UN;[&L*&QXB(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B4F5T>7!E(&YE
M=R!P87-S=V]R9"(*;7-G<W1R("*^S\BC(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I
M9"`B4F5U;FEO;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*(RP@9G5Z>GD*;7-G
M:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(KC>P,\@O*VY]B#!
MI+JXN^?'UR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S(*(RP@9G5Z
M>GD*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R("*_
MR;S'P+BWSB"UN;[&L*&QXB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M.`HC+"!F=7IZ>0IM<V=I9"`B4FED9&QE<R(*;7-G<W1R("*PH;_NM:4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(K_`N*7"RB(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,C$*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$W"B,L(&9U
M>GIY"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`BO[DZ(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X
M"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B7W?'X""\T[RZ
M+BXN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R("*_JL?2(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(U"FUS9VED(")2;W1A=&4@,3@P
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,C(*(RP@9G5Z>GD*;7-G:60@(E)O=&%T92!,969T(@IM<V=S
M='(@(L"GM\X@P,RUOR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,C@*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R("+'X""\T[RZ
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`BQ^`@O-.\
MNB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R("+'X#HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"B,L(&9U>GIY
M"FUS9VED(")2=6QE<R(*;7-G<W1R("*_JL?2(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P"FUS9VED(")2=6XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(E)W86YD
M82(*;7-G<W1R("*TWK?"(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA
M='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C,R,PHC+"!F=7IZ>0IM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-
M97-S86=E(@IM<V=S='(@(KC>O</!]B#`_+S;(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S87-L+G!H<#HX,0HC+"!F=7IZ>0IM<V=I9"`B4T%33"!A=71H
M96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("*[Z,&F(+W'
MQM`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`T"B,L(&9U>GIY
M"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@(KC>O</!]B"ZN+'B(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,PIM<V=I
M9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Q"FUS9VED(")34T@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*
M;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@4VAE
M;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV,0HC+"!F=7IZ>0IM<V=I9"`B4V$B"FUS9W-T<B`BP/K`
MY2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R
M92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I
M9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(K"PP+H@Q\&W
MN<#3*%]S96QF*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*(RP@9G5Z>GD*;7-G:60@(E-A;B!-87)I
M;F\B"FUS9W-T<B`BL*'`Y<#:N*XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3
M86\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I
M9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R
M86)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`BP/K`Y2(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(K39N*7`S+BGP+BWSB#`
M^L#E(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`BM-FXI<#,
MN*?`N+?.(,#ZP.4B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS
M9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`BO+'%P[OGQ]<@P/K`Y2(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N
M97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@
M<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(E9&4R"\L\&D(,&DNKB_H;RM("=P;W)T)\#,(+[XO<"TS[39+B(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L('!H<"UF;W)M870*;7-G:60@
M(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0Y"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B
M"FUS9W-T<B`BL,N[]B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M,C`*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(K#+
MN_8@L.&P^B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-S,*(RP@
M9G5Z>GD*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R("*X\+7.(+RQQ<,B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T
M"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(KW$NK#`
MVB"\L<7#(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*(RP@
M9G5Z>GD*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R("*Y
MKL#:OZT@O+'%PSHB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S
M"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`B
MO+'%PR##Z[S2(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P
M"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`BN:[`
MVK^M(+RQQ<,Z(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*
M(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@
M(KFNP-J_K2"\L<7#.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-S<*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;&PB"FUS
M9W-T<B`BN/"USB"\L<7#(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C8V,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N
M=',N(@IM<V=S='(@(K.OP-H@Q_R]Q""\L<7#(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PHC+"!F=7IZ>0IM<V=I9"`B
M4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R("*\L<7#(,/KO-(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<X"B,L(&9U>GIY
M"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R("*\L<7#(,/KO-(B"@HC.B!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@
M8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U
M(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X
M="!A<F5A+B(*;7-G<W1R("*^QK>A(+OSP-J_H;RM(,?*O^3'T2"YKL#:N*8@
MO+'%P\?/L.T@NKF[Y\?/OZD@NMF_J;/6P+B\O+_D+B(*"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L
M:6UI=&5R.B(*;7-G<W1R("*SK\#:(+&XNM#'I;W#(+RQQ<,Z(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T
M92!F;W)M870Z(@IM<V=S='(@(K.OP-H@Q_R]Q""\L<7#(@H*(SH@=&5M<&QA
M=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`HC+"!F=7IZ>0IM<V=I
M9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM
M<V=S='(@(L#3QO?&KL?2(,"GQ*$@O+'%PSHB"@HC.B!T96UP;&%T97,O9&%T
M82]T:6UE+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!T:6UE
M(&1E;&EM:71E<CHB"FUS9W-T<B`BLZ_`VB"QN+K0QZ6]PR"\L<7#.B(*"B,Z
M('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE
M('1I;64@9F]R;6%T.B(*;7-G<W1R("*]P["C(,?\O<0@O+'%PR(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@
M;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R("*USK"SP,<@P,_$H<?/M,(@Q]>X
M\2"\L<7#(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P-@IM<V=I9"`B
M4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C0X"FUS9VED(")396QE8W0@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(L#:P=:[Y[_KQ\^TPB"^\+[NN*8@
MO+'%P\?/O+R_Y"XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("*YKL&F
MN=^[_2"ZN+#MO*T@P/R\V\?/L>(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3`S.0HC+"!F=7IZ>0IM<V=I9"`B4V5N9"!3
M35,B"FUS9W-T<B`BN-Z]P\'V(,#\O-LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED
M(")396YE9V%L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S$V"B,L(&9U>GIY"FUS9VED(")396YS;W(Z("(*;7-G<W1R("(@P::X\3H@
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*
M;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R("(YO_DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-
M;VYT96YE9W)O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-S`Q"B,L(&9U>GIY"FUS9VED(")397)I86P@3G5M8F5R
M(@IM<V=S='(@(KS]P-HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,38Q"B,L(&9U>GIY"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R("+`S+_KL*&TR<?1(+RQQ<.[Y\?7P,P@
MOOB]P+3/M-DN(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"B,L(&9U>GIY
M"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(K#\N*XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*(RP@
M9G5Z>GD*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`BN-Z]
MP\'V(,?7N/$B"@HC.B!L:6(O87!I+G!H<#HQ-#4*(RP@9G5Z>GD*;7-G:60@
M(E-E<W-I;VYS(@IM<V=S='(@(L7DM]`B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S$T"B,L(&9U>GIY"FUS9VED(")3970B"FUS9W-T<B`BN-Z]
MP\'V(+RQQ<,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@
M(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W
M;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S
M97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T
M86PN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`HC
M+"!F=7IZ>0IM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T
M:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R("+&Y,#,P?8@L+N]
MQ<'6L>(@N=<@L>+%N"#(K;CI(+RSP:3`NR#'S[R\O^0N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDX"B,L(&9U>GIY"FUS9VED("(B"B)3970@>6]U
M<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F
M<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T
M<B`BQN3`S,'V(+"[O<7!UK'B(+G7(+'BQ;@@R*VXZ2"\L\&DP+L@Q\^\O+_D
M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*(RP@9G5Z>GD*;7-G
M:60@(E-E='5P(@IM<V=S='(@(KC>O</!]B"\L<7#(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A
M9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$X-@IM<V=I9"`B4V5V97)A;"!L;V-A=&EO
M;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DV"B,L(&9U>GIY"FUS9VED
M(")3:&]P<&EN9R(*;7-G<W1R("*PQ;BN(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z-#,*(RP@9G5Z>GD*;7-G:60@(E-H;W)T(%-U;6UA
M<GDB"FUS9W-T<B`BL*.TW,?1(+_DON`Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0T-@IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN
M960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H
M;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H
M92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y,`HC+"!F=7IZ>0IM<V=I
M9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G
M<W1R("*WSK'7P,Z]PR##UL&^(+?.L=?`SB"]P["C(+JXOZG!UK'B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V-0IM<V=I9"`B4VAO=R!O<'1I
M;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#$S"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(V"B,L(&9U>GIY"FUS
M9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@
M(L>E(+S3O+K#HB"ZN+'B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N('1H
M92!L969T/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A
M8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`BO+\@O-.\NL.B
M(+JXL>(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I
M97,@9&EA;&]G(@IM<V=S='(@(L>E(+S3O+K#HB"ZN+'B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS
M9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS
M9W-T<B`BOZT@O-.\NL.B(+JXL>(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE
M(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(K'7N+(@O-.\NL.B
M(+JXL>(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8S"B,L(&9U
M>GIY"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R("*SN[?!N=ZQXB(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"B,L(&9U
M>GIY"FUS9VED(")3:&]W97)S(@IM<V=S='(@(L#0ONZ_P+'B*,#3QO?&KBDB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0HC
M+"!F=7IZ>0IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R("*PH[3<Q]$@
MO^2^X#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,@IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W
M97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT.#`*(RP@9G5Z>GD*;7-G:60@(E-H
M<FEN:R(*;7-G<W1R("*WSK'7P,XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HW-S0@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z.#,V"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.CDR,B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY.#0*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`T-R!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#@W"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C$Q,38@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z,3$T.0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I
M9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8U
M"B,L(&9U>GIY"FUS9VED(")3:6=N('5P(@IM<V=S='(@(KRMN.TZ(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*(RP@9G5Z>GD*
M;7-G:60@(E-I9VYA='5R92(*;7-G<W1R("*\K;CM.B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$Q"B,L(&9U>GIY"FUS9VED(")3
M:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(KRMN.TZ(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-`HC+"!F=7IZ>0IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(KRMN.TZ
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#<@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C0V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y
M,S`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,PIM<V=I9"`B4VEZ
M92(*;7-G<W1R("+%J;'B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA
M:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS
M9W-T<B`BP*_!]K#\N*X@N_VWJR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L
M;W9A:VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E
M;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4T"FUS9VED(")3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W
M(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W
M"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N
M;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C<X"B,L(&9U>GIY"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T
M<B`B(,&FN/$Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@R"FUS9VED
M(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,30@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR-@HC
M+"!F=7IZ>0IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B
MP:2WQ""YYKG](@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C$X.0HC+"!F=7IZ>0IM<V=I9"`B4V]U<F-E(&%D
M9')E<W,B"FUS9W-T<B`BP??`Y2#!UKS2(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I
M9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA
M(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R
M"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED
M(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(KR_L*.P
MW2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I
M;B!C96QL(@IM<V=S='(@(KR_(+#FL.B_S2"SN[_K(+OGP,S`QR"PH[#=(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$U"B,L(&9U>GIY"FUS9VED
M(")3<&%C97(B"FUS9W-T<B`BP/K`Y2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*
M;7-G<W1R("*PQ;BN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN
M9R(*;7-G<W1R("*PQ;BNO\T@PZ2_[+'B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*(RP@9G5Z
M>GD*;7-G:60@(E-P86EN(@IM<V=S='(@(K#%N*XB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z.3@*(RP@9G5Z>GD*;7-G:60@(E-P86TB"FUS9W-T
M<B`BP/K`Y2(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B
M4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`BQJ^\]B"YKL#:(,#4
MM\(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@(KR_(+K0Q](B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`BOZT@NM#'TB(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R("+'X""ZT,?2(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")3<&]R
M=',B"FUS9W-T<B`BP-"^[K_`L>(HP-/&]\:N*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM
M<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP.C<T"B,L(&9U
M>GIY"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R("*TWK?"(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#`Y"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P"FUS
M9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*(RP@
M9G5Z>GD*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(KC>P,\@O*VY
M]B#!I+JXN^?'UR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3<R"B,L(&9U>GIY"FUS9VED(")3=')E970@061D<F5S<R(*;7-G<W1R
M("+!]\#E(,'6O-(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(K"A
MO^ZUI<'9(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,PHC+"!F
M=7IZ>0IM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`BO/:]Q;#%NLXB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I<"!D
M;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED
M(")3='EL92!;0U-372(*;7-G<W1R("*]NL6XP,];0U-372(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U
M(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N
M;W0@9F]U;F0N(@IM<V=S='(@(L7KP?8@N*Z]NK/*("5SP+LHN*8I(,.CP+L@
MO/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R("+!IKCQ(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R(&9R86UE=V]R:R]&;W)M
M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@
M(L&FP^(B"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y
M<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S
M="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R
M:7!T(@IM<V=S='(@(K[&MZ'#M\#:(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$P-`HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@
M(KRZL/@B"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@
M<WES=&5M+B(*;7-G<W1R("(G)7,GL*$@O<.]NL7;OZ$@P]^PH;7'OOJ]P+3/
MM-DN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R
M(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B<E<R>PH2"]P[VZ
MQ=N_H;RM(+OHP::UQ[[ZO<"TS[39+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G
M<W1R("(G)7,GL*$@O<.]NL7;OZ$@P]^PH;7'OOJ]P+3/M-DN(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3`U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*
M;7-G<W1R("(G)7,GL*$@O<.]NL7;OZ&\K2"[Z,&FM<>^^KW`M,^TV2XB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L
M;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N
M9V5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(E-U
M8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B5D93(+RSP:0@P:2ZN+^AO*T@)W!O<G0GP,P@OOB]P+3/M-DN(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T
M960@7"(E<UPB(@IM<V=S='(@(B<E<R>PH2"]P[VZQ=N_H2##W["AM<>^^KW`
MM,^TV2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HW,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(B<E<R>PH2"]P[VZQ=N_
MH2##W["AM<>^^KW`M,^TV2XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=61A
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(K_D
MON`B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*(RP@9G5Z>GD*;7-G
M:60@(E-U;B!2:7-E(@IM<V=S='(@(L&FN/$B"@HC.B!L:6(O0FQO8VLO<W5N
M<FES92YP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B
MP::X\2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4Y"FUS9VED(")3=6YN>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C$V"B,L(&9U>GIY"FUS9VED(")3=6YR:7-E(@IM
M<V=S='(@(L&FN/$B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z,38*(RP@9G5Z>GD*;7-G:60@(E-U;G)I<V4O
M4W5N<V5T(@IM<V=S='(@(L&FN/$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C$U"B,L(&9U>GIY"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T
M<B`B(,&FN/$Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,3D*(RP@9G5Z>GD*;7-G:60@(E-U;G-E="(*;7-G<W1R("+!IKCQ(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.`HC+"!F=7IZ>0IM<V=I
M9"`B4W5N<V5T.B`B"FUS9W-T<B`B(,&FN/$Z("(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R
M:7!T(@IM<V=S='(@(L"MP[?`VB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS-S@*(RP@9G5Z>GD*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`BP-"^
M[K_`L>(HP-/&]\:N*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*(RP@9G5Z>GD*;7-G:60@
M(E-U<FEN86UE(@IM<V=S='(@(L#,N*<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4W-`HC+"!F=7IZ>0IM<V=I9"`B4W5R;F%M92(*
M;7-G<W1R("+`S+BG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@
M86YD($IA;B!-87EE;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"B,L(&9U
M>GIY"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`BPZ.QXB(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#0*(RP@9G5Z>GD*;7-G:60@(E-W961E;B(*;7-G<W1R("+`T,"Z(+C>
MP,\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*(RP@9G5Z>GD*
M;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`BNKFQN"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#(*;7-G:60@(E-Y;F--3"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G
M:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C`*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FT@
M86YD(%=I;F1Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")4+5-T;W)M<R(*
M;7-G<W1R("+`I\2A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-C8*(RP@9G5Z>GD*
M;7-G:60@(E135B!F:6QE(@IM<V=S='(@(L&FN/$B"@HC.B!F<F%M97=O<FLO
M54DO54DO5&%B;&4N<&AP.C$S-`HC+"!F=7IZ>0IM<V=I9"`B5&%B;&4B"FUS
M9W-T<B`BP::X\2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS
M9W-T<B`BQZ4@O-.\NB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T
M86)L97-E="YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(E1A8FQE(%-E="(*;7-G
M<W1R("+!IKCQ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G
M<W1R("+'I2"\T[RZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S0@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I
M=V%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B5&%N>F%N
M:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R("*TZ\?1N<ZQN2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*(RP@
M9G5Z>GD*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`BN-Z]P\'V(@H*(SH@8V]N
M9FEG+VAO;VMS+G!H<"YD:7-T.CDY-B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3@W"FUS9VED(")487-K<R(*;7-G<W1R("+`V[[W(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E1E;&5P:&]N
M92!.=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M.3`*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C$T"FUS9VED(")496UP97)A='5R92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(S
M"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8X
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB
M(&YO="!F;W5N9"XB"FUS9W-T<B`BQ>O!]B"XKKVZL\H@)7/`NRBXIBD@PZ/`
MNR"\]B"^^+W`M,^TV2XB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0HC
M+"!F=7IZ>0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T
M<B`BL/RXKB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-@IM<V=I9"`B5&5X="(*;7-G<W1R
M("*YKL#:OZTB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<U"FUS9VED
M(")497AT($]N;'DB"FUS9W-T<B`BN:[`VB(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E>'0@
M86QI9VXB"FUS9W-T<B`BN:[`VB#!I+?$(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0HC+"!F=7IZ>0IM<V=I9"`B5&5X
M='1O<"(*;7-G<W1R("*YKL#:OZTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B5&AA:2`H5$E3+38R
M,"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0HC+"!F=7IZ>0IM<V=I9"`B
M5&AA:6QA;F0B"FUS9W-T<B`BPZ.QXB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDX.`IM<V=I9"`B5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES
M=&5M+B(*;7-G<W1R("*[Y[_KQ]C!UKS%O*T@L*B[Y\?5M,^TV2XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R,`HC+"!F=7IZ>0IM<V=I9"`B
M5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
MP,R_Z["AM,G'T2"\L<7#N^?'U\#,(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P
M<&]R="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])35-0
M+TE-4U`O0F]O:RYP:'`Z,3(Y,@HC+"!F=7IZ>0IM<V=I9"`B5&AE($E-4U`@
M;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`BO*VX[<"[
M(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N
M;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@
M=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R
M871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO
M;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB
M97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F
M;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0HC+"!F=7IZ>0IM
M<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y
M;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`BQ]>X\2!<(B5S7"*PH2#!UKS2
MM\^_H2##W["AM<>^^KW`M,^TV2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,38Y"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I
M9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE
M9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N
M;W0@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0N<&AP.C$Q,PIM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@
M<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S4@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HU,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I
M;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V."!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,3D*(RP@
M9G5Z>GD*;7-G:60@(E1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@
M:71S96QF+B(*;7-G<W1R("+&Q,#/OZ$@OL:YJ[>Q(,#:M^&PH2"^^+W`M,^T
MV2XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.#`*;7-G:60@(E1H
M92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("+&Q,#/OZ$@OL:Y
MJ[>Q(,#:M^&PH2"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R
M92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E
M+B(*;7-G<W1R("*^QK>AM,(@P,P@;65S<V%G92]R9F,X,C(@QNW!]L#'(+C3
MN+2XN\#4M,^TV2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I
M<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO
M<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A
M8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G
M87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O
M;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M
M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G
M970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T
M;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@
M(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL
M('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S
M+G!H<#HY,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E
M<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(KW$NK#`VB!<(B5S7"(@
ML*$@N^C!IK7'OOJ]P+3/M-DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N
M9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE
M($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z
M.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G
M92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E
M96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T
M:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S<*;7-G:60@
M(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@
M<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HT-#$*(RP@9G5Z>GD*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU
M<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`BP,P@L*K`NB"\_<#:OZF^WR#'U;3/
MM-DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C,Q
M"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H
M92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A
M=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@
M86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A
M=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`BP,P@N-Z]P\'V(,?\Q<(H)7,IN*8@NKBQXB#`I\?1(,?!M\ZQU[>E
MP+L@PZ/`NR"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HT-30*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B
M92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I
M9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T-@IM<V=I9"`B
M5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@
M:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`BO<2ZL,#:(%PB)7-<(B"PH2"[
MZ,&FM<>^^KW`M,^TV2XB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H
M<#HT.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<
M(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(KW$NK#`VB!<(B5S7"(@
ML*$@P/K`Y;7'OOJ]P+3/M-DN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@
M9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(KW$NK#`VB!<(B5S
M7"(@L*$@P/K`Y;7'OOJ]P+3/M-DN(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z,S,P"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D
M;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HQ-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O
M<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Q,0IM<V=I9"`B5&AE('1E
M>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@
M<V-R965N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B
M;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@
M=&]P('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$
M871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T
M('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A+T1A
M=&$O='-V+G!H<#HQ-S(*(RP@9G5Z>GD*;7-G:60@(E1H92!U<&QO861E9"!F
M:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`BO*VX[<"[(+JOL.;'
MTB"\]B"^^+W`M,^TV2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-#8@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4V"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$Q.0HC+"!F=7IZ>0IM<V=I9"`B5&AE('=E871H97(N8V]M
M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(L#,O^NPH;3)Q]$@
MO+'%P[OGQ]?`S""^^+W`M,^TV2XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z,C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E
M8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BQ>O!]B"XKKVZL\H@
M)7/`NRBXIBD@PZ/`NR"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO
M;G,@879A:6QA8FQE+B(*;7-G<W1R("+`S+_KL*&TR<?1(+RQQ<.[Y\?7P,P@
MOOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z,S0R"B,L(&9U>GIY"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA
M="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`BP,R_Z["AM,G'
MT2"\L<7#N^?'U\#,(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E
M('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@
M96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S
M('1H86X@)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO
M=7-E<BYP:'`Z-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E
M<R(*;7-G<W1R("(G)7,GN*8@O<.]NL7;OZ$@P]^PH<?2(+SV(+[XO<"TS[39
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O
M<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(G)7,G
MN*8@O<.]NL7;OZ&\K2"[Z,&FQ](@O/8@OOB]P+3/M-DN(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3`S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T
M96TZ("(*;7-G<W1R("(G)7,GN*8@O<.]NL7;OZ&\K2"[Z,&FQ](@O/8@OOB]
MP+3/M-DN(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG(%PB
M)7-<(CH@)7,B"FUS9W-T<B`B)R5S)[BF(+W#O;K%V[^A(,/?L*''TB"\]B"^
M^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX
M.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G
M<W1R("+&Q,#/(+_#N*ZQXK^A(+FNP::PH2#`UKW`M,^TV2X@)7,@QL3`S\#,
M(+[WM\ZUY;7'P?8@OLJ^TKW`M,^TV2XB"@HC.B!F<F%M97=O<FLO0G)O=W-E
M<B]"<F]W<V5R+G!H<#HX.#D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E
M9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*(L;$P,\@OO>WSK7E(+_`
MM_DN(,#,QL3`S\"Z(+[WM\ZUY2#'X[_KM<@@P]:TZR#%J;'B*"5D($U"*;JX
MM-D@Q:NPS2"PL+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W
M<V5R+G!H<#HX.3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E
M<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(B(*(K[W
MM\ZUY2#&Q,#/OZ$@N:[!IK"A(,#6O<"TS[39+B#`S,;$P,_`NB"^][?.M>4@
MP]:TZ\?CO^O%J;'BN*8@P\JP^L?5M,^TV2XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"B,L(&9U>GIY"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R
M="(*;7-G<W1R("*XWKW#P?8@P/R\VR"_P+?Y(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*
M;7-G<W1R("*UI<#,Q;@@P-/&]\:N(+_`M_DB"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+VEM8RYP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R
M("*UI<#,Q;@@P-/&]\:N(+_`M_DB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C@P"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O
M=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`BO^3#N[7((+C>O</!
M]B#`T+'B(+_`M_DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S.`HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O
M;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S
M='(@(K_DP[NUR""XWKW#P?8@P-"QXB"_P+?Y(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*(RP@9G5Z>GD*;7-G
M:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C
M="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("*^
M][?.M>4@QL3`SR#`T\;WQJX@O\"W^2(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"B,L(&9U>GIY"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L
M:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("*_Y,.[M<@@
MN-Z]P\'V(,#0L>(@O\"W^2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$T.`HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!)34%0('-E
M<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T
M<B`BNNJV\[_LP/JPH2#`S""QXK3)P+L@P?:_^,?/P?8@OLJ]P+3/M-DN(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HT.`HC+"!F
M=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI
M9"!R87(@87)C:&EV92XB"FUS9W-T<B`BP,P@L*K`NB"\_<#:OZF^WR#'U;3/
MM-DN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HU
M,@HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`BP,P@L*K`NB"\_<#:OZF^WR#'
MU;3/M-DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$T-0HC+"!F
M=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@
M8V%R9"!N=6UB97(N(@IM<V=S='(@(L#,(+"JP+H@O/W`VK^IOM\@Q]6TS[39
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*
M(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC
M;VTI("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS
M,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N
M92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N
M($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N
M92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3,Y.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-34W
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,SD*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DU."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`U
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,CD@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`W.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,30Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C$*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C0Q,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-#4T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3<@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@R.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,3,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,#8*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS.#(R"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8U"FUS9VED(")4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3@*;7-G:60@(E1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L
M;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P
M.30*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V
M86QU97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P
M86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX.0HC+"!F=7IZ>0IM<V=I9"`B
M5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R("+`
MS""PJL"Z(+S]P-J_J;[?(,?5M,^TV2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#,V"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I
M;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA
M;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C4V,0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!F;W)M(&AA
M<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R("+`S+G,(,'6O-*W
MS[^A(+7NM\^UQ[[N(,#6O<"TS[39+B(*"B,Z('1E;7!L871E<R]H96QP+V%B
M;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#4Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A
M<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@
M86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B
M($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B
M"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C
M=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V"FUS9VED(")4
M:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`BP,P@
MO/W`VK3"(,/6O-+'T2`QP-JXKB#`S+OSP,R^[K[?(,?5M,^TV2XB"@HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@
M(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I
M;&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G
M:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY
M(&1E86-T:79A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@
M;G5M8F5R+B(*;7-G<W1R("+`S""PJL"Z(+S]P-J_J;[?(,?5M,^TV2XB"@HC
M.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4
M:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN
M9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8T"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S0*;7-G:60@(E1I8VME=',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R."!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(E1I
M;64B"FUS9W-T<B`BP::X\2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS.#8*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W1I;64N<&AP.C$W"B,L(&9U>GIY"FUS9VED(")4:6UE(&9O<FUA
M="(*;7-G<W1R("*]P["C(+RSP:0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-3,Y"B,L(&9U>GIY"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G
M<W1R("*]P["C(+RSP:0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,
M97-T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS9VED
M(")4:71L92(*;7-G<W1R("+!IKCQ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I
M.B(*;7-G<W1R("+%N,#,QK(HQ?C&P2DZ(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B
MN=ZTPB"[Y[;W(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US
M+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I
M(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0HC+"!F=7IZ>0IM<V=I9"`B5&]D
M87DB"FUS9W-T<B`BNKNYKB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*
M;7-G<W1R(")(5$U,(+S2O;H@NKBQXB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*(RP@9G5Z
M>GD*;7-G:60@(E1O9V\B"FUS9W-T<B`BN=ZTPB"[Y[;W(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S$S"B,L(&9U>GIY"FUS9VED(")4;VUO<G)O
M=R(*;7-G<W1R("(@*+.[P,\I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`HC+"!F=7IZ>0IM
M<V=I9"`B5&]N9V$B"FUS9W-T<B`BN=ZTPB"[Y[;W(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W"FUS9VED(")4
M;W`B"FUS9W-T<B`BP*<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S
M='(@(KOSP*<@Q\&WN<#3*%]T;W`I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8S"B,L(&9U>GIY"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B
MR*^PYKRSP:0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@
M5&]B86=O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$W.3`*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B
M5'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E1U<FMI
M<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G
M:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS
M9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#3$DO0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C8Y"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO
M:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS
M9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O
M<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY-PHC+"!F=7IZ>0IM<V=I9"`B55),.B(*;7-G<W1R(")5
M4DPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$R"B,L(&9U>GIY"FUS9VED(")59V%N9&$B"FUS
M9W-T<B`BM-ZWPB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(E5K
M<F%I;F4B"FUS9W-T<B`BN=C!V2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C0Q,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!6
M1E,@9&ER96-T;W)Y+B(*;7-G<W1R(")V9G-R;V]T(+7PM[K%Y+BNN*8@P-#`
MNR"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O
M<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,S@X"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`QR#&V[G,O,?`
MNR"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,S@U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S
M:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B5D93(,;$P,\@)7,O
M)7/`QR#&V[G,O,?`NR"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HW-34*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(E-13""\
MK;GVOZ$@P:*\T\?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,C,R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`B
M5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8X."!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C$P,38*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C@S-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S7"(N(@IM<V=S='(@(E9&
M4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z-#,U"FUS9VED(")5;F%B;&4@
M=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R(")344P@O*VY]K^A
M(,&BO-/'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C@S.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@
M=VET:"!34TPN(@IM<V=S='(@(E-13""\K;GVOZ$@P:*\T\?2(+SV(+[XO<"T
MS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-2!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR
M,#D*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*
M;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/
MM-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-C4*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I
M<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(G9F<W)O;W0@M?"WNL7DN*ZXIB#`
MT,"[(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C,U-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-38*(RP@9G5Z>GD*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M=F9S<F]O=""U\+>ZQ>2XKKBF(,#0P+L@O/8@OOB]P+3/M-DN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R-`HC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`B5D93(,;$P,\@
M)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,C@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G
M<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8U"B,L(&9U>GIY
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G
M<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN
M(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-S8*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G
M<W1R("+(K[#FO+/!I,"[(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R-"!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C(Y.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M+B(*;7-G<W1R(")V9G-R;V]T(+7PM[K%Y+BNN*8@P-#`NR"\]B"^^+W`M,^T
MV2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z-#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`
MNRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C,S,2!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,Y
M,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S$Q(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,S0*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@
M:7,@;F]T(&5M<'1Y(@IM<V=S='(@(G9F<W)O;W0@M?"WNL7DN*ZXIB#`T,"[
M(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS-#@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U,@HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M(')E8W5R<VEV96QY+B(*;7-G<W1R(")V9G-R;V]T(+7PM[K%Y+BNN*8@P-#`
MNR"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HS,S<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,T-`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R(")V9G-R;V]T(+7PM[K%Y+BNN*8@P-#`NR"\
M]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0Q
M-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0R.0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M.B`E<RXB"FUS9W-T<B`BM?"WNL7DN*X@L,N[]K_`M_DZ("5S(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,#<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/
MM-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S`S(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C@X"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HQ-C<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X
M,`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.#,*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,Y,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`NRBX
MIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z,C0T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")61E,@
MQL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,#8*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E
M<RXB"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[X
MO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#`S"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER
M96-T;W)Y+B(*;7-G<W1R(")V9G-R;V]T(+7PM[K%Y+BNN*8@P-#`NR"\]B"^
M^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8P,PIM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T
M86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP
M:'`Z-#4Q(&9R86UE=V]R:R].971?24U34"])35-0+T%U=&@N<&AP.C$Q.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI
M=&EO;B!O9B`E<RXB"FUS9W-T<B`B)7,@P:3`Q[BF(,#0P+L@O/8@OOB]P+3/
MM-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3DV(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,38V(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ-S$*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F
M:6QE+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@
MOOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P,@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C8T."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I
M(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR-S<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S
M,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,S"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN
M9RXB"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[X
MO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@P(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF
M*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HT-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R("+(K[#FO+/!I,"[
M(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z.#,U"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL
M92`H9FEL97-I>F4H*2!F86EL960I+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E
M<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C@V-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@
M5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B5D93
M(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R
M86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H
M<#HS.`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM
M<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^T
MV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV-CD*;7-G:60@
M(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B=F9S<F]O=""U\+>ZQ>2XKKBF(,#0P+L@O/8@OOB]P+3/M-DN(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3`U"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N
M(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(G9F<W)O
M;W0@M?"WNL7DN*ZXIB#`T,"[(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z,S(Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G
M<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-C<@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HS-#,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C$P(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B5D93(,;$
MP,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(S(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HR,3,*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U
M,B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C@U"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@(E9&4R#&Q,#/
M("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*(RP@
M9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R
M(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM
M<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B
M"FUS9W-T<B`BP,P@O_:UY;FNO*VXIB"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-#D@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HQ-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(E9&
M4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-SD*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM
M<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^T
MV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.#$@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,30S"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@
M=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B5D93(,;$P,\@)7,O
M)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HX-#$*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!W<FET
M92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS9W-T<B`B
M5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G
M:60@(E5N9&5R;&EN92(*;7-G<W1R("*YV,'9(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(KJO
ML.:[Y\?7(+7'M;FXKK'B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I
M;VXB"FUS9W-T<B`BN+;!]KBW(+CMM\D@P^N\TB(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PHC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*;7-G:60@(E5N97AP96-T960@
M<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q
M.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-`IM<V=I
M9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G
M97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C8Q"B,L(&9U>GIY"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(L#0
MP?8@OLK`NB"XWL#/(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G
M:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@HC
M+"!F=7IZ>0IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B
MN<RQN2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS
M9W-T<B`BO[6QN2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T
M97,B"FUS9W-T<B`BN<RQN2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E
M9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HW,0IM<V=I9"`B56YI=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0S,`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE
M;G0@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O
M=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y,0HC+"!F=7IZ>0IM<V=I9"`B56YK;F]W
M;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`BN^>_Z\#:P,RXI[#Z
M(+[/R*.XIB#`U+?"Q\^\O+_D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE
M(&-U<G)E;G0@96QE;65N="(*;7-G<W1R("+']L#G(+_DO-*_H2"XM<6I(,&F
ML,4B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C(Y-@IM
M<V=I9"`B56YN86UE9"(*;7-G<W1R("+`S+BG(+[XP+TB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5
M;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A
M<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@
M($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N
M;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@
M=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G
M:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(KOVL?(@P::PQ2(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@V(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z.3,R"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*(RP@9G5Z>GD*
M;7-G:60@(E5P9&%T92(*;7-G<W1R("+`S\#:(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B57!D871E("5S(@IM<V=S='(@(L#/P-HB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"B,L(&9U>GIY"FUS9VED(")5<&1A
M=&4@=7-E<B(*;7-G<W1R("*[Y[_KP-H@P]^PH2(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z,C,P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`BN^>_Z\#:(,/?L*$B"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I
M<'0@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$W."!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3DY"FUS9VED(")5<&QO860B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N
M('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`BMO/&OK[N
M(+3KN:[`VB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B
M"FUS9W-T<B`BM\ZXMB"TZ[FNP-H@O/W`VB(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G
M:60@(E5R=6=U87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R("+']L#G(+VZQ;C`
MSR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D
M(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*(RP@9G5Z>GD*
M;7-G:60@(E5S97(B"FUS9W-T<B`BN^>_Z\#:N.TB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<R,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S"B,L(&9U>GIY"FUS9VED(")5
M<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(DAO<F1E(+OGO^O`VB"P_+BN
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR-3$*;7-G:60@
M(E5S97(@3W!T:6]N<R(*;7-G<W1R("*[Y[_KP-H@O+'%P[OGQ]<B"@HC.B!S
M:6=N=7`N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")5<V5R(%)E9VES=')A=&EO
M;B(*;7-G<W1R(")(;W)D92"[Y[_KP-H@L/RXKB(*"B,Z('-I9VYU<"YP:'`Z
M,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D
M(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@86-C;W5N="!N;W0@9F]U;F0B"FUS
M9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B
M"FUS9W-T<B`BN^>_Z\#:N.TB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I
M9VYU<"YP:'`Z,3(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R
M;F%M92!<(B5S7"(@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(KC>P,_'U"!<
M(B5S7"*PH2#`S+G,(+OGO^O!W\#4M,^TV2XB"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.#<*(RP@9G5Z>GD*;7-G:60@(E5S97)N86UE.B(*
M;7-G<W1R("*[Y[_KP-JX[2(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`BN^>_
MZ\#:N.TB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS
M9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R("*]P[VZQ=O`QR"[
MY[_KP-HZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-C,@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")6
M1E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("+%Z\'V(+BN
MO;JSRB`E<\"[*+BF*2##H\"[(+SV(+[XO<"TS[39+B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ,3@*(RP@9G5Z>GD*;7-G:60@(E9A8V%T:6]N
M(@IM<V=S='(@(KW'Q^`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX
M-C8*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M,S@*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B
M5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4V(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T
M:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(V-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$V(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#D@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$X-@IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F
M<F]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T
M-`HC+"!F=7IZ>0IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`BP::X\2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R
M:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N
M('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-S`P"B,L(&9U>GIY"FUS9VED(")697)S:6]N
M(@IM<V=S='(@(K"SP,X@N-[`SR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR,C8*(RP@9G5Z>GD*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G
M<W1R("*PL\#.(+C>P,\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*
M;7-G<W1R("*\]L'W(,&DM\0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM
M<V=S='(@(KSVP?<@PZ2_\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#,*(RP@9G5Z>GD*;7-G:60@(E9E<G1I8V%L.B(*
M;7-G<W1R("*\]L'W(,&DM\0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,38*(RP@9G5Z>GD*;7-G:60@(E9I970@3F%M(@IM<V=S
M='(@(L?*M>7`S+BG(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G
M:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.38R"B,L('!H<"UF;W)M870*
M;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B)7,@NKBQXB(*"B,Z(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A
M9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#(Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&%S
M("5S(@IM<V=S='(@(B5S(+JXL>(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6
M:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.0IM<V=I9"`B5FES:6)I;&ET>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8S
M"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@
M(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.
M1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S
M"FUS9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HR.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL
M+G!H<#HR-S(@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N
M:6YG(@IM<V=S='(@(K#FL.TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@
M1F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C0R-PIM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y,@IM<V=I
M9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#,W"FUS9VED(")796(@4VET92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X
M"FUS9VED(")7965K;'DB"FUS9W-T<B`BN,7!UB(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC;VUE(@IM<V=S='(@(LBO
MO[4B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L
M8V]M92!T;R`E<R(*;7-G<W1R("+(K[^UQ]6TS[39(2`E<R#`U+3/M-DN(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O
M<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L
M("5S(@IM<V=S='(@(LBOO[7'U;3/M-DL("5S(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.34*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED(")797-T
M97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G
M:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L
M:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@
M(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(K&X
MNM`@N:[`VK3"(+FKOOG`U+3/L>X_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E
M<C\B"FUS9W-T<B`BP,Z_ZR"ZSLBCM,(@N:N^^<#4M,^Q[C\B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V,0IM<V=I9"`B
M5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@(E=H:6-H('!L
M=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`BL\JZ\2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C4*(RP@9G5Z>GD*;7-G:60@
M(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R("*SRKKQ(+3<P*<B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4W"B,L('!H<"UF;W)M870*;7-G:60@
M(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E
M8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@
M;V8@=&AE('1A8FQE(@IM<V=S='(@(L>EP,<@L\JZ\2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T
M:"!U;FET(@IM<V=S='(@(K/*NO$@M-S`IR(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS
M9W-T<B`BL\JZ\3HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$S
M"FUS9VED(")7:6MI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C4*(RP@9G5Z>GD*;7-G:60@(E=I;F0B"FUS9W-T<B`BPZ.QXB(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"B,L
M(&9U>GIY"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(L.CL>(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C@P"FUS9VED(")7:6YD('-P965D(&EN(&MN
M;W1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34V"B,L
M(&9U>GIY"FUS9VED(")7:6YD.B(*;7-G<W1R("+#H['B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(T,@HC+"!F=7IZ>0IM<V=I9"`B5VEN
M9#H@(@IM<V=S='(@(L.CL>(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C0*(RP@9G5Z>GD*;7-G:60@(E=I<V1O;2(*;7-G<W1R("+#H['B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5VES:&QI<W0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"B,L(&9U
M>GIY"FUS9VED(")7;W)K(@IM<V=S='(@(K;'M,(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D
M<F5S<R(*;7-G<W1R("+!]\#E(,'6O-(Z(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*
M;7-G<W1R("+!]\#E(,#\R*VY^,BC(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z,38Y(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(V,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN
M(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S`P"B,L('!H<"UF;W)M
M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D
M+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,3$T"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E
M="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#,*;7-G:60@(E@M4F5F(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3DS"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3(*;7-G
M:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U
M,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U
M,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@R"FUS9VED(")8-3`Y
M=C,@97AT96YS:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`B65DB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-34*(RP@9G5Z>GD*;7-G:60@(EE9
M65DB"FUS9W-T<B`B65DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3$P.`IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V
M"FUS9VED(")996%R;'DB"FUS9W-T<B`BN,6SXB(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*
M(RP@9G5Z>GD*;7-G:60@(EEE;65N(@IM<V=S='(@(L#0P+H@N-[`SR(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G
M:60@(EEE<R(*;7-G<W1R("*_N2(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")997,L($D@06=R964B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE
M(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S
M='(@(E1%6%2X\+7EP-2TS[39+B!;/#Y=(+GVQK#`NR"TJ;BCN.D@5UE325=9
M1R"X\+7EM\X@M;F^QK"IM,^TV2XB"@HC.B!S97)V:6-E<R]P;W)T86PO961I
M="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL
M;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#$Q"FUS9VED(")9
M;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P,@IM<V=I9"`B66]U(&-A
M;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA
M;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW-0HC+"!F=7IZ>0IM<V=I
M9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*
M;7-G<W1R("+`W[CXM<@@P,RXWL#/(,'6O-(B"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+G!H<#HR.3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*
M(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@
M9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM
M<V=S='(@(L#3QO?&KK7((,;$P,_`QR"^[K:R(,?7N/&UM2!4=7)B8<#'(,?7
MN/&_H2"XPK#4(+RSP:3'S\'V(+[*OM*]P+3/M-DN(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E
M9"!O=70N(@IM<V=S='(@(K?.L=>^QK_T(,?/O[2]P+3/M-DN(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL
M>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N
M86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q.#@*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E('1O
M(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(L#?N/BUR"#`S+C>P,\@
MP=:\TB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HS-PIM
M<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T
M;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HT-38*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&
M4R!B86-K96YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R
M;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N
M(@IM<V=S='(@(KFNP:8@NKBP[;RMN*8@NKBSN['BP/R_H2#`S+FNP::_H2"T
MZ\?1(+RSN.W`NR#`U+?"Q]B^WR#'U;3/M-DN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@
M96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S
M='(@(L#,(+BUQ:FPH2"PH;BNQ*&TPB!54DS`NR#`U+?"Q]B^WR#'U;3/M-DN
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*(RP@9G5Z>GD*
M;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E
M9"XB"FUS9W-T<B`BN-7`^B"[Z,&FQ](@O<2ZL,#:N*8@O+'%P\?8OM\@Q]6T
MS[39+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0HC+"!F=7IZ>0IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS
M9W-T<B`BN^C!IL?2(+OGO^O`VB#`S+BGP+L@P-2WPL?8OM\@Q]6TS[39+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`BN^C!IL?2(+OGO^O`
MVB#`S+BGP+L@P-2WPL?8OM\@Q]6TS[39+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R
M("+#W["AQ](@N^>_Z\#:(,#,N*?`NR#`U+?"Q]B^WR#'U;3/M-DN(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,30V"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(L/?L*''
MTB"[Y[_KP-H@P,RXI\"[(,#4M\+'V+[?(,?5M,^TV2XB"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*(RP@9G5Z>GD*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB
M"FUS9W-T<B`BO/:]Q<#.P,P@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*(RP@9G5Z>GD*;7-G
M:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T
M<B`BN^C!IL?2(+OGO^O`VB#`S+BGP+L@P-2WPL?8OM\@Q]6TS[39+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP
M.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO
M;F4@;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@
M:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B)7,@
MO+R\Q\#,(+BXM^&UQ[[ZO<"TS[39+B"TV;W#(+?.L=?`SL?/O+R_Y"XB"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`IM<V=I9"`B66]U
M<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(L#,N-[`SR#!UKS2.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3(*;7-G:60@(EEO=7(@1G)O;3H@861D
M<F5S<SHB"FUS9W-T<B`BN-[`SR#!UKS2.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM
M<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R("+!I+JX(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3@P"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T
M:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C
M="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G
M:60@(EEO=7(@3F%M92(*;7-G<W1R("+`S+BG.B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VYO861D+FEN8SHU"B,L(&9U>GIY"FUS9VED("(B"B)9;W5R
M(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I
M;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI
M;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N
M="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"B*TY[W%
MP,<@P,[!]<6LMO/`S+[PQJZPH2"[Y[_KP-JXIB##W["AQ](@O/8@OOB]P+3/
MM-DN(+;'M,(@M-FXI2#`S,"OM\X@N^>_Z\#:("(*(L/?L*&QXK3)P+L@N^>_
MZ\?2(+SV(+[XO<"TS[39+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E
M871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A
M<V]N+B(*;7-G<W1R("(B"B*TY[W%P,<@P,[!]<6LMO/`S+[PQJZPH2"[Y[_K
MP-H@N/&WS[JXL>*XIB#!]K_XQ\_!]B"^RKW`M,^TV2X@ML>TPB"TV;BE(,#,
MP*\B"B*WSB"[Y[_KP-H@N/&WS[JXL>*XIB"[Y[_KQ](@O/8@OOB]P+3/M-DN
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@T"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA
M;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@
M(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A
M9V%I;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*
M;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A
M='5R92XB"FUS9W-T<B`BNNJV\[_LP/JPH2#`S""QXK3)P+L@P?:_^,?/P?8@
MOLJ]P+3/M-DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z
M-#(*(RP@9G5Z>GD*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S
M=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA
M;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"B*[Y[_KQ\^P[2"PZ+W%
M(+KJMO._[,#ZM,(@P,Z\XB"_R;S'P+L@P?:_^,?/P?8@OLJ]P+3/M-DN(,#.
MO.+'S['B(,"GQ]B\K;3"(,3!(@HBQJZWT2^_R;S'Q;"_S2!0N*8@M*FXH[R\
MO^0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-PIM<V=I9"`B66]U
M<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`BQ_;`YR"]P["CM.LZ(@H*
M(SH@<V5R=FEC97,O<')E9G,N<&AP.CDV"B,L(&9U>GIY"FUS9VED(")9;W5R
M(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`B
ML>*ZNR"]Q+JPP-HZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U.`IM
M<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R("*QXKJ[(+W$
MNK#`VCHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`Q"FUS9VED(")9
M;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`BP/S#O"#`S+BG.B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.C$P,#`*(RP@9G5Z>GD*;7-G:60@(EEO=7(@
M;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S='(@(K_)O,?`S"#`^L#EM<>^^KW`
MM,^TV2XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@
M9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(L#,
M(+R\O,<@M;^^R""_R;S'P,P@P/K`Y;7+M,^TV2XB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA
M=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R("*_R;S'P,P@P/K`Y;7'OOJ]P+3/
MM-DN(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G:60@
M(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD
M(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,S(*;7-G:60@(EEO=7(@
M<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!R
M96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`BN-[`SR#!UKS2.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4T(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`HC+"!F=7IZ>0IM<V=I
M9"`B6F%I<F4B"FUS9W-T<B`BQ\K%S2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@
M(EIA;6)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB
M86)W92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*
M;7-G:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I
M;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E
M(%%U;W1E9"!497AT72(*;7-G<W1R(");P,Z_ZR"\^['BL>)=(@H*(SH@<V5R
M=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB
M"FUS9W-T<B`B6[_`M_D@NKBP[<?/L>)=(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!4
M97AT("TB"FUS9W-T<B`B6\#.O^L@NKBQXB`M(@H*(SH@9G)A;65W;W)K+U1E
M>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S
M72(*;7-G<W1R(");P,Z_ZR"ZN+'B("T@)7,@P=E=(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI
M;F4@)7,@;V8@)7-=(@IM<V=S='(@(ENV\\#.("5S("\@)7-=(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-30Q('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")?
M0;#\N*XB"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T
M<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"B,L(&9U>GIY"FUS9VED(")?1&%T
M851R964B"FUS9W-T<B`BP,_`VB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2
M;W<B"FUS9W-T<B`B7T3'X"#!]K_R(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS
M9VED(")?1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@(K6UO_*X
MNR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T
M<B`B7TFQU[BR(+S3O+HN+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M365N=2YP:'`Z,3DT"B,L(&9U>GIY"FUS9VED(")?3&]G(&EN(@IM<V=S='(@
M(K?.L=?`SB(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ
M.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(E],M\ZQU[[&O_0B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R(")?;;BUQ:D@O/;!
MI"XN+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0*
M;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(E]/O+'%P[OGQ]<B"@HC.B!L:6(O
M87!I+G!H<#HQ,S<*(RP@9G5Z>GD*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G
M<W1R("+%Y+?0(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(V"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS
M9W-T<B`B7W*XM<6I(+OHP:8N+B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0HC+"!F
M=7IZ>0IM<V=I9"`B7U-E='5P(@IM<V=S='(@(KC>O</!]B"\L<7#(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")?=,>E
M(+S3O+HN+BXB"@HC.B!L:6(O87!I+G!H<#HQ,CD*(RP@9G5Z>GD*;7-G:60@
M(E]5<V5R<R(*;7-G<W1R("*[Y[_KP-JX[2(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3(Q"B,L(&9U>GIY"FUS9VED(")A9&1R97-S(&)O;VLB
M"FUS9W-T<B`BP=:\TK?/(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ,S0*(RP@9G5Z>GD*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N
M(@IM<V=S='(@(L'6O-*WSR(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3$S"B,L(&9U>GIY"FUS9VED(")C86QE;F1A<B(*;7-G<W1R("*TWK?"
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS
M9W-T<B`BP^N\TB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,34X"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,P
M"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*;7-G:60@(F-L:6-K
M(&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$W.`HC+"!F=7IZ>0IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G
M<W1R("*XWL#/(+RMN?8@P:2ZN+OGQ]<B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I
M;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M.#(*(RP@9G5Z>GD*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R("+%
MZ\'V(+BNO;JSRB`E<\"[*+BF*2##H\"[(+SV(+[XO<"TS[39+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")F
M86QL:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S
M97(N<&AP.C@U-0HC+"!F=7IZ>0IM<V=I9"`B9FEL92(*;7-G<W1R("+!IKCQ
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-C`@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4P"B,L(&9U>GIY
M"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(CB_^2(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR-#D*;7-G:60@(F@Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HS-3@*;7-G:60@(FAH(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D
M:69F+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(K[X
MP+TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V,@IM
M<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA
M;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S
M='(@(L'972(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S
M(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V.0IM
M<V=I9"`B;6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HR.3$@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC
M.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C,R"FUS9VED(")N86UE
M(@IM<V=S='(@(L#,N*<B"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(Q
M"B,L(&9U>GIY"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`BN^C!
MIK7'P?8@OLK`NB"XWL#/(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HQ,C$Y"B,L(&9U>GIY"FUS9VED(")N;W0@>65T(&EM<&QE;65N
M=&5D(@IM<V=S='(@(KOHP::UQ\'V(+[*P+H@N-[`SR(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3`U"B,L(&9U>GIY"FUS9VED(")N;W1E<&%D
M(@IM<V=S='(@(L#0P?8@OLK`NB"XWL#/(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N
M="(*;7-G<W1R("+&V[R^QJXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$W-`HC+"!F=7IZ>0IM<V=I9"`B<&5R;6ES<VEO;B!D96YI
M960B"FUS9W-T<B`BL+/`SB"XWL#/(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM
M<V=S='(@(L?(O+\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C<S"B,L(&9U>GIY"FUS9VED(")R:7-I;F<B"FUS9W-T<B`BL.:P[2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30R"FUS9VED(")S
M97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(G-H;W<@9&EF9F5R96YC
M97,B"FUS9W-T<B`BN^>_Z\#:(,BOL.8B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL
M('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HS.#4*;7-G:60@(G-S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"B,L(&9U
M>GIY"FUS9VED(")S=&5A9'DB"FUS9W-T<B`BP-#!]B"^RL"Z(+C>P,\B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P.0IM<V=I9"`B<W=I=&-H
M(&]F9B!J879A<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T96T@97)R;W(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,CD*(RP@
M9G5Z>GD*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R("*\]KW%L,6ZSB(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38V"FUS9VED(")T
M96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C,P-0HC+"!F=7IZ>0IM<V=I9"`B=')Y(&%G86EN(@IM
M<V=S='(@(KCPM><@M\ZQU\#.(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A
M;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B='EP92!T
M:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW
M.0HC+"!F=7IZ>0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R("+`T,'V(+[*P+H@
MN-[`SR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<*;7-G
M:60@(G5N;F%M960B"FUS9W-T<B`BP,RXIR"^^,"](@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"B,L(&9U
M>GIY"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R("*QU,2B*+?\*2"\L<7#
M(+_`M_DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@(G9#87)D(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T,0HC+"!F=7IZ>0IM
M<V=I9"`B=SHB"FUS9W-T<B`BP/RTWCHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O;'1?
M3%0N<&\`````````````````````````````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#<R,3<W-@`Q,#4Q-30S,S<U-``P,3<V-S<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````(R!,:71H=6%N:6%N('1R
M86YS;&%T:6]N<R!F;W(@2&]R9&4@<&%C:V%G92X*(R!#;W!Y<FEG:'0@*$,I
M(#(P,#0@2&]R9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E
M9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!(;W)D92!P86-K86=E
M+@HC($1A<FEU<R!-871U;&EA=7-K87,@/&1A<FEU<T!L;FLN;'0^+"`R,#`R
M+@HC(%9I;&EU<R!3=6US:V%S(#QV:6QI=7-`;&YK+FQT/BP@,C`P,RP@,C`P
M-"X*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@
M2&]R9&4@,RXP+6-V<UQN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L
M:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P
M+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#0M,3$M
M,CD@,3(Z-3(K,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!6:6QI=7,@4W5M
M<VMA<R`\=FEL:75S0&QN:RYL=#Y<;B(*(DQA;F=U86=E+51E86TZ($QI=&AU
M86YI86X@/'9I;&EU<T!L;FLN;'0^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN
M(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y
M+3$S7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H<')I9?`@)7,@9&EE
M;F%S*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B("AM
M>6=T=6MA<R`E<RDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<W
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM
M<V=S='(@(B`H<')I9?`@)7,@9&EE;F%S*2(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S-S,*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B`H\&EA
M;F1I96XI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-0HC+"!F
M=7IZ>0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B4GET;VHB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<Q"FUS9VED("(@*'EE<W1E<F1A
M>2DB"FUS9W-T<B`B("AV86MA<BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C4V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C$*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-PIM<V=I9"`B(&%T
M("(*;7-G<W1R("(@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M,34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@
M82!D:7)E8W1O<GDN(@IM<V=S='(@(DYE(&MA=&%L;V=A<R(*"B,Z(&9R86UE
M=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(B<E
M<R<@>7)A(&YE;&5I<W1I;F$@<F5I:_!MZRXB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C8U.0HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O4F5G:7-T<GDN<&AP.C$P-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@
M4F5G:7-T<GDN(@IM<V=S='(@(B<E<R<@;F5S=6MO;F9I9_MR=6]T87,@2&]R
M9&4@<F5G:7-T<F4N(@H*(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R96YD
M97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(D[K<F$@)R5S)R!M963^:6\@9V5N
M97)A=&]R:6%U<RXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4V"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G
M<F]U<',@<WES=&5M+B(*;7-G<W1R(")'<G5PZR`G)7,G('-U:W5R=&$N(@H*
M(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S
M:6]N<R!S>7-T96TN(@IM<V=S='(@(E1E:7/K("<E<R<@<W5K=7)T82XB"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N
M;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(B<E<R<@;F5B=79O('-U:W5R=&$Z
M("5S+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR
M9B4E*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G
M<W1R("(E9"`E<R!I<B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER
M97,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM
M<V=S='(@(B5D+61I96[X('!R;V=N;WKK(@H*(SH@<V5R=FEC97,O;6%I;G1E
M;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E
M(@IM<V=S='(@(B5S("T@<&%S=&%B82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-S`T"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I
M;F=E<G!R:6YT(@IM<V=S='(@(B5S(&%N='-P875D87,B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S,@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.#,U"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M($M"(@IM<V=S='(@(B5S($M"(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P
M97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@<')O9FEL86MT
M:6MO<R!V96EK<VUA:2`M('!A='9I<G1I;FEM87,B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(E]+
M;VYF:6?[<F%C:6IA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S
M='(@(B5S(')E9VES=')A8VEJ82(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E
M96UE;G0B"FUS9W-T<B`B)7,@;G5O<W1A=&]S(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HT,C@@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT
M.3`*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV-3$@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B5S(&IA=2!E9WII<W1U;VIA+B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Y(&QI8B]";&]C:R]M971A<BYP
M:'`Z,38U(&QI8B]";&]C:R]M971A<BYP:'`Z,C,Y"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S0U(&QI8B]";&]C:R]M971A<BYP:'`Z,S4Q"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S("5S("5S(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M
M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H
M92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R
M9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(E!A_GEMZVMI=&4L(&MU<FEA
M<R!O<&5R86-I:F%S(&YO<FET92!A=&QI:W1I+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@
M<F5Q=6ER960B"FUS9W-T<B`B)7,@>7)A('!R:79A;&]M87,B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M
M:6YU=&5S(@IM<V=S='(@(B5S(&UI;G5TZW,B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@;F5R87-T87,N(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R(")N=6\@)7,@:6MI("5S
M(&GP("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B
M)7,@861R97/X(&MN>6=E;.LB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDQ-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM
M<V=S='(@(B5S(&MA;&5N9&]R:75S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D
M(@IM<V=S='(@(B5S('7^<F'P^"!K;GEG96SK(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!4
M87-K;&ES="(*;7-G<W1R("(E<R!D87)B^"!SX')A\&%S(@H*(SH@9G)A;65W
M;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B
M)7,Z("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP
M:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A
M9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A
M<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V
M:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,V-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$P"B,L(&9U>GIY
M"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@9_MS:6%I("5S("5S(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM
M<V=S='(@(BP@9_MS:6%I("5S("5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F<F]M("5S
M('1O("5S(@IM<V=S='(@(BP@:VEN=&$@;G5O("5S(&EK:2`E<R(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,CDT(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,S0X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(P-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$R.`HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0Y"FUS9VED("(M+2!S
M96QE8W0@+2TB"FUS9W-T<B`B+2T@<&%S:7)I;FMI=&4@+2TB"@HC.B!L:6(O
M0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S
M='(@(C$R('9A;&%N9/@@9F]R;6%T87,B"@HC.B!L:6(O0FQO8VLO=&EM92YP
M:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(C(T('9A;&%N
M9/@@9F]R;6%T87,B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM
M<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@=F%L86YD;W,B"@HC.B!F<F%M
M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y"B,L(&9U>GIY"FUS9VED("(\4')E
M=FEO=7,B"FUS9W-T<B`B06YK<W1E<VYI<R!P=7-L87!I<R(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@
M:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(M!I86T@8FQO
M:W5I(')E:6MA;&EN9V$@=FEE=&$@9'5O;65N^"!B87KK:F4N(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C`*;7-G:60@(D$@9F%T86P@97)R
M;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(L%V>6MO(')I;71A(&ML86ED82(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B
M02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S
M<V%G92XB"FUS9W-T<B`B3F]RZV1A;6D@=?YK;V1U;W1I(&QA:?!KX"!P<FEV
M86QO=&4@='5RZW1I('9I9?#@:N$@4$=0(')A:W3@+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C4*;7-G:60@(D$@<'5B;&EC(%!'
M4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N
M(@IM<V=S='(@(B(*(DYO<NMD86UI('!A=&EK<FEN=&D@<&%S:7)A\'ETX"!L
M86GP:^`@<')I=F%L;W1E('1U<NMT:2!V:67PX&KA(%!'4"!R86MTX"XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#DW"FUS9VED("(B
M"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB
M"FUS9W-T<B`B(@HB3F]RZV1A;6D@871K;V1U;W1I(&QA:?!KX"!P<FEV86QO
M=&4@='5RZW1I('9I9?#@:N$@:7(@<VQA<'3@:N$@4$=0(')A:W1U<RP@(@HB
M8F5I(/YI;F]T:2!S;&%P=.!JX"!F<F%ZYBXB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,#$U"FUS9VED("(B"B)!('!U8FQI8R!01U`@
M:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB3F]RZV1A
M;6D@<&%S:7)A\'ET:2!L86GP:^`@<')I=F%L;W1E('1U<NMT:2!V:67PX&KA
M(&ER('-L87!TX&KA(%!'4"!R86MT=7,L("(*(F)E:2#^:6YO=&D@<VQA<'3@
M:N`@9G)A>N8N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU,#4*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@
M4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*
M(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B).;W+K9&%M:2!A=&MO
M9'5O=&D@;&%I\&O@('!R:79A;&]T92!T=7+K=&D@=FEE\.!JX2!I<B!S;&%P
M=.!JX2!3+TU)344@(@HB<F%K='5S+"!B96D@_FEN;W1I('-L87!TX&K@(&9R
M87KF+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q
M"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*
M(F$@;65S<V%G92XB"FUS9W-T<B`B(@HB3F]RZV1A;6D@<&%S:7)A\'ET:2!L
M86GP:^`@<')I=F%L;W1E('1U<NMT:2!V:67PX&KA(&ER('-L87!TX&KA(%,O
M34E-12`B"B)R86MT=7,L(&)E:2#^:6YO=&D@<VQA<'3@:N`@9G)A>N8N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@
M(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@
M;65S<V%G92XB"FUS9W-T<B`B3F]RZV1A;6D@=?YK;V1U;W1I(&QA:?!KX"!P
M<FEV86QO=&4@='5RZW1I('9I9?#@:N$@4R]-24U%(')A:W3@+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*(RP@9G5Z>GD*
M;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R(")$96)E<W5O=&$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`HC+"!F=7IZ>0IM
M<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R(")032!L96YG=F%S(&QI971U
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q
M"B,L(&9U>GIY"FUS9VED(")!32!286EN(@IM<V=S='(@(DQI971U<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED
M(")!32!3:&]W97)S(@IM<V=S='(@(D%-(')O9'EM87,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PHC+"!F=7IZ>0IM<V=I
M9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(E#[9V$B"@HC.B!T96UP;&%T
M97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B04TO
M4$TB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R(")!4$D@240B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED
M(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R(")!<&EE(/#A(')E9&%K=&]R
M:?@B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,@IM<V=I9"`B06)O
M=70N+BXB"FUS9W-T<B`B07!I92XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G
M<W1R(")6:7-I\&MA:2!A<&'H:6]J92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G
M<W1R(")6:7-I\&MA:2!P97(@=FED=7+A(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN
M9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")3:7-T96UA(&YE='5R:2!T96ES
M:?@@<W5K=7)T:2!61E,@:V%T86QO9^`N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN
M9R!61E,@9FEL92XB"FUS9W-T<B`B4VES=&5M82!N971U<FD@=&5I<VGX('-U
M:W5R=&D@5D93(&9A:6S@+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS
M"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@
M(DEN9F]R;6%C:6IA(&%P:64@2G5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<U"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(E-L87!T
M8?YO9&ES(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B
M4^!S:V%I=&$@=?[P86QD>71A+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS,S,*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`B07!S:V%I=&$B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T96UP;&%T
M97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R(")3=6MU<G1I
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR
M,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R(")3=6MU<G1I('!O
M9W)U<.$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL
M9"!097)M:7-S:6]N(@IM<V=S='(@(E-U:W5R=&D@<&]T96ES97,B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM
M<V=S='(@(D)L;VMO(.%T97)P:6UA<SHB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'<F]U
M<"(*;7-G<W1R(")3=6MU<G1I(&YA=6K@(&=R=7#F(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS9W-T<B`B
M4W5K=7)T:2!N875J87,@=&5I<V5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]A9&1C:&EL9"YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(E!O9W)U
M<&EO(&=R=7!E:2`G)7,G('-U:_MR:6UA<R(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,30W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R(")0
M;W1E:7/K<R!T96ES96D@)R5S)R!S=6O[<FEM87,B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@(DYA=6IO
M('9A<G1O=&]J;R!S=6O[<FEM87,Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4U-`IM<V=I9"`B061D(&-O;'5M;B(*;7-G
M<W1R(")0<FEDZW1I('-T=6QP96SA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S
M='(@(DYA=6KX(&YA<FGX('!R:63K:FEM87,B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R(")3=6MU
M<G1I('!O<N`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8W"B,L('!H
M<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@
M4VED96)A<B(*;7-G<W1R(")0<FEDZW1I("5S(&UE;FEU('!R:64@36]Z:6QO
M<R#A<F%N:VGX(&IU;W-T;W,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ
M(@IM<V=S='(@(L%T<F%U:W1I(.$@861R97/X(&MN>6=E;.8Z(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"FUS9VED(")!
M9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(L%T<F%U:W1I(.$@;6%N
M;R!A9')E<_@@:VYY9V5LYCHB"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I
M9"`B061D('5S97(B"FUS9W-T<B`B4W5K=7)T:2!V87)T;W1O:N`B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HW.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@
M861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS
M9W-T<B`B(@HB5F%R=&]T;VIA<R`G)7,G('-U:W5R=&%S+"!T8>AI874@<&%P
M:6QD;VUA(')E9VES=')A8VEJ;W,@:6YF;W)M86-I:F$@;F5B=79O("(*(FGP
M<V%U9V]T83H@)7,N(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO
M=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B5F%R=&]T;VIA<R`G)7,G('-U
M:W5R=&%S+B!'86QI=&4@<')I<VEJ=6YG=&DN(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D
M:7-A8FQE9"XB"FUS9W-T<B`B5F%R=&]T;VKX(&O[<FEM87,@:?!J=6YG=&%S
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$W
M,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q"FUS9VED(")!9&1R97-S
M(@IM<V=S='(@(D%D<F5S87,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3,Y"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B061R97-A:2(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS
M9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U
M<V5R<R(*;7-G<W1R(")!9&UI;FES=')U;W1I("T@9V%L:2!N=7-T871Y=&D@
M=&5I<V5S(&MI=&EE;7,@=F%R=&]T;VIA;7,B"@HC.B!A9&UI;B]I;F1E>"YP
M:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B
M061M:6YI<W1R871I;VXB"FUS9W-T<B`B5F%L9'EM87,B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S0Q"FUS9VED(")!9',B"FUS9W-T<B`B0F%N
M97)I86DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R
M(")!9F=A;FES=&%N87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;&)A;FEA(@IM
M<V=S='(@(D%L8F%N:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG97)I82(*
M;7-G<W1R(")!;/YY<F%S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B4')A=F%R
M9.LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R("),>6=I=6]T:2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G
M:60@(D%L:6=N;65N=#HB"FUS9W-T<B`B3'EG:6%V:6UA<SHB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R(")6:7-O
M<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C`W('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A
M=&5D(%5S97)S(@IM<V=S='(@(E9I<VD@<')I<VEJ=6YGYB!V87)T;W1O:F%I
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R
M,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R(")6:7-O<R!G<G5PZW,B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDQ(&9R86UE=V]R:R]0
M97)M<R]097)M<R]D871A=')E92YP:'`Z-S4*;7-G:60@(D%L;"!097)M:7-S
M:6]N<R(*;7-G<W1R(")6:7-O<R!T96ESZW,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@
M9F]U<B!S:61E<R(*;7-G<W1R(")6:7-O<R!K971U<FEO<R!P=7/K<R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S$*;7-G:60@(D%L;&]W(&UU
M;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R("),96ES=&D@:V5L973@(&%D<F5S
M^"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S0*;7-G:60@(D%L;&]W
M('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(DQE:7-T
M:2!N875D;W1I('-U<OOP:75O=.`@<^!R8?#@/R(*"B,Z(&9R86UE=V]R:R]$
M871A5')E92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E
M>&ES=',B"FUS9W-T<B`B2F%U(&5G>FES='5O:F$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3(S"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*
M;7-G<W1R(")!;'1E<FYA='EV=7,@24U34"!P<FES:6IU;F=I;6%S(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-PIM<V=I9"`B06QT97)N871E($E-
M4U`@4&%S<W=O<F0B"FUS9W-T<B`B06QT97)N871Y=G5S($E-4U`@<VQA<'1A
M_F]D:7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DY"FUS9VED(")!
M;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R(")!;'1E<FYA='EV=7,@
M24U34"!V87)T;W1O:F\@=F%R9&%S(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z,S4*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM
M<V=S='(@(D%L=&5R;F%T>79U<R!E;"X@<&'P=&\@861R97-A<R(*"B,Z(&%D
M;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA
M=&5S(@IM<V=S='(@(D%L=&5R;F%T>7;[<R#P86)L;VYA:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(D%L=&5R;F%T>79U
M<R!T96MS=&%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B
M"FUS9W-T<B`B06UE<FEK;W,@4V%M;V$B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM
M<V=S='(@(L%V963K=&4@;F5L96ES=&ENX"!R96EK\&WF+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C<*(RP@9G5Z>GD*;7-G:60@(D%N
M('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(L%V>6MO(')I
M;71A(&ML86ED82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%N9&]R<F$B"FUS9W-T
M<B`B06YD;W)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM<V=S='(@
M(D%N9V]L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@
M(D%N9VEL86DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y
M"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B06YO;FEM:6YI<R!P
M<F]X>2!S97)V97)I<R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B071S86MY;6%S(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R(")!;G1A<FMT:61A(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R
M(")!;G1I9W5A(&ER($)A<F)U9&$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-0HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO54DN<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH
M=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(DUO9'5L:7,B"@HC
M.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*(RP@9G5Z>GD*;7-G:60@(D%P
M<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B36]D=6QI<R(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y
M+B(*;7-G<W1R(")-;V1U;&ES('9E:6MI82!G97)A:2XB"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@
M4VAA<F5S(@IM<V=S='(@(E!R:71A:6MY=&D@:7(@<&_P86MI86US(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P
M<')O=F4B"FUS9W-T<B`B4&%T=FER=&EN=&DB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX,S,*;7-G:60@(D%P<')O>&EM871E(%-I
M>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(D)A;&%N9&ES(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S4*;7-G:60@(D%R86)I8R`H5VEN
M9&]W<RTQ,C4V*2(*;7-G<W1R(")!<F%B:?!K82`H5VEN9&]W<RTQ,C4V*2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E
M($9I;&4@4VEZ92(*;7-G<W1R(")!<F-H>79O(&9A:6QO(&1Y9&ES(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU."!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#`*;7-G:60@(D%R8VAI=F4@3F%M
M92(*;7-G<W1R(")!<F-H>79O(&9A:6QO('!A=F%D:6YI;6%S(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E
M('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R(")!<B!T:6MR
M86D@;F]R:71E(&GP=')I;G1I("5S(')E9VES=')A8VEJ;W,@<')A\'EMX#\B
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H
M('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R
M(")!<B!T:6MR86D@;F]R:71E(&GP=')I;G1I("<E<R<@:7(@=FES=7,@<&]G
M<G5P:75S/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R
M(")!<F=E;G1I;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S
M='(@(D%R;>MN:6IA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S8*;7-G
M:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(D%R;>MN:?!K82`H
M05)-4T-)22TX*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I
M9"`B07)T(@IM<V=S='(@(DUE;F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U
M8F$B"FUS9W-T<B`B07)U8F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(DMR:7-T
M875S(/YE;F=I;6\@X2!D86YG^"!S86QA(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B06-S:6D@;65N
M87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@
M(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B07II:F$O4F%M:6]J;R!V
M86YD96YY;F\@<F5G:6]N87,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#(U"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B07(@<')A\'ET:2!P
M871V:7)T:6YT:2!P<F]F:6QA:W1I:V]S('9E:6MS;75S/R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3,*;7-G:60@(D%S<VEG;FUE;G0@8V]L
M=6UN<R(*;7-G<W1R(")0<FES:WER:6UO('-T=6QP96QI86DB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B0F%N9&]T92!I\'1R:6YT:2!N
M965G>FES='5O:F%NZ&G@(&=R=7#F+B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(D)A;F1O=&4@:?!T<FEN=&D@;F5E
M9WII<W1U;VIA;NAI87,@=&5I<V5S+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N
M<&AP.C@W"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@
M<&5R;6ES<VEO;BXB"FUS9W-T<B`B0F%N9&]T92!R961A9W5O=&D@;F5E9WII
M<W1U;VIA;NAI87,@=&5I<V5S+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT
M('-H87)E+B(*;7-G<W1R(")"86YD;W1E(')E9&%G=6]T:2!N965G>FES='5O
M:F%N=.$@96QE;65N=.`N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M.#8*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B071R:6)U=&%I(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@
M(D%U9W5S="(*;7-G<W1R(")2=6=P:OMT:7,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED
M(")!=7-T<F%L:6$B"FUS9W-T<B`B075S=')A;&EJ82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*
M;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B075S=')I:F$B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q
M;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!=71H7V-Y<G-Q;#H@;F5R87-T87,@<F5I:V%L:6YG87,@24U!4"!M;V1U
M;&ES+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S-0IM
M<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I
M<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!C>7)U<R!N
M971U<FD@<F5I:VEA;?@@9V%L:6UY8FGX+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER
M960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y
M<G5S.B!N97)A<W1A<R!R96EK86QI;F=A<R!)34%0(&UO9'5L:7,N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H
M7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I
M;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S
M='(@(B(*(D%U=&A?9G1P.B!N97)A<W1A<R!R96EK86QI;F=A<R!&5%`@;6]D
M=6QI<RX@4W5K;VUP:6QI=6]K:71E(%!(4"!S=2`M+65N86)L92TB"B)F='`N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B
M075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(D%U=&A?:6UA<#H@;F5R87-T87,@<F5I:V%L:6YG87,@24U!
M4"!M;V1U;&ES+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z
M-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VMR8C4Z(&YE<F%S=&%S(')E:6MA
M;&EN9V%S(&MR8C4@;6]D=6QI<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@
M:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,U-PIM<V=I
M9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D
M(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@4F5Q
M=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H
M7VQD87`Z(&YE<F%S=&%S(')E:6MA;&EN9V%S($Q$05`@;6]D=6QI<RXB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(D%U=&A?
M;&1A<#H@<W5K=7)T:2!V87)T;W1O:N`@)7,@;F5P879Y:V\N(%-E<G9E<FEO
M('!R86YE\&EM87,Z("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE
M('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@:?!T<FEN
M=&D@=F%R=&]T;VK@("5S(&YE<&%V>6MO(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B075T:%]L
M9&%P.B!A=&YA=6II;G1I('9A<G1O=&]JX"`E<R!N97!A=GEK;R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD
M87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV
M92!$:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!
M3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VUC86PZ(&YE
M<F%S=&%S(')E:6MA;&EN9V%S($U#04P@;6]D=6QI<RXB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@
M4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!=71H7W-M8F%U=&@Z(&YE<F%S=&%S(')E:6MA;&EN9V%S('-M8F%U=&@@
M;6]D=6QI<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*
M;7-G<W1R(")0<FES:6IU;F=T:2!N97!A=GEK;R(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF
M;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T
M<B`B4')I<VEJ=6YG=&D@;F5P879Y:V\N("5S(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC871I;VX@
M<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`B4D%$2553('-E
M<G9E<FES(&YE;&5I9/YI82!A=71E;G1I9FEK=6]T:7,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G:60@(D%U=&AE;G1I8V%T:6]N
M('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")0<FES:6IU;F=T:2!P
M<FEE($944"!S97)V97)I;R!N97!A=GEK;RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")!=71H96YT:6-A=&EO
M;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM<V=S='(@(E!R:7-I:G5N
M9W1I('!R:64@1E10('-E<G9E<FEO(&YE<&%V>6MO+B(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z
M(@IM<V=S='(@(D=A;&EM:2!L875K86DZ(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B
M07IE<F)A:6IA;B(*;7-G<W1R(")!>F5R8F%I9/YA;F%S(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T
M<B`B0D]&2"!A='-I<')A\'EM86DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD
M(@IM<V=S='(@(D9O;F%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G
M<W1R(")&;VYO('-P86QV82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B
M-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T
M<B`B3F5T96ES:6YG87,@:V5R8F5R;W,@<VQA<'1A_F]D:7,N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E
M<F]S('5S97)N86UE+B(*;7-G<W1R(").971E:7-I;F=A<R!K97)B97)O<R!V
M87)T;W1O:F\@=F%R9&%S+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B
M"FUS9W-T<B`B0F%H86UA:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)A:')A:6XB
M"FUS9W-T<B`B0F%H<F5I;F%S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M-S<*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(D)A;'1I
M\&MA("A)4T\M.#@U.2TQ,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D
M97-H(@IM<V=S='(@(D)A9VQA9&7P87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"
M87)B861O<R(*;7-G<W1R(")"87)B861O<V%S(@H*(SH@=71I;"]I8V]N7V)R
M;W=S97(N<&AP.C,Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")"87-E
M(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M(")+;&%SZW,@)7,@;NMR82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S
M='(@(E!A9W(N(&QI;FEJ;VIE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HT.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U
M<R(*;7-G<W1R(")"86QT87)U<VEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E
M;&=I=6TB"FUS9W-T<B`B0F5L9VEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E
M;&EZ92(*;7-G<W1R(")"96QI>F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N
M:6XB"FUS9W-T<B`B0F5N:6YA<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU
M9&$B"FUS9W-T<B`B0F5R;75D86DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T
M86XB"FUS9W-T<B`B0G5T86YA<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@
M(D=I;71A9&EE;FES(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE
M8W1I;VXN<&AP.C,U,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0FQO
M8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM
M<V=S='(@(DML87/K<R`E<R!NZW)A+B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B
M0FQO:V\@<&%R86UE=')A:2(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R(")";&]K;R!T:7!A
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.`IM<V=I9"`B0F]L9"(*;7-G<W1R(")087-T;W)I;G1I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R(")";VQI=FEJ82(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR,#4*;7-G:60@(D)O;VMM87)K<R(*;7-G
M<W1R(")!=/YY;6]S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(DMR
M8?!T87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R(")+<F'P
M=&\@<W1O<G5M87,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")+
M<F'P=&%I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O
M=FEN82(*;7-G<W1R(")";W-N:6IA(&ER($AE<F-E9V]V:6YA(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@(E9I
M<V]S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B0F]T
M<W9A;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R(")!<&'H:6]J92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B0G5V
M970@<V%L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R87II;"(*;7-G<W1R(")"
M<F%Z:6QI:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@
M3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(D)R:73X($EN9&EJ;W,@=F%N9&5N
M>6YO('1E<FET;VIA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S
M<V%L86TB"FUS9W-T<B`B0G)U;NMJ875S(&1A<G5S86QE;6%S(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B0G5L9V%R:6IA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I
M9"`B0G5L;&5T960@3&ES="(*;7-G<W1R(")3=?YY;>MT87,@<^!R8?!A<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R(")"=7)K
M:6YA<R!&87-A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T
M<B`B0G5R=6YD:6IA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T
M-`IM<V=I9"`B0TU3(@IM<V=S='(@(E164R(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R(")#
M4D,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM
M<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B0U),('!A
M<VMI<G-T>6UO('!U;FMT86DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E
M<G1I97,N+BXB"FUS9W-T<B`B7T-E;.MS(&YU<W1A='EM86DN+BXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38S"B,L(&9U>GIY"FUS9VED
M(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R(").9>%R
M8?#K=&4@9&ES=')I8G5C:6IO<R!SX')A\&\N(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-"!C;VYF:6<O:&]O:W,N<&AP
M+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-34*;7-G
M:60@(D-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9&]R:75S(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-@IM<V=I9"`B0V%L;2(*;7-G<W1R
M(")286UU(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@
M(DMA;6)O9/YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T
M<B`B2V%M97+[;F%S(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL
M>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(DYE
M=F5I:VEA(&%U=&]M871I;FES('-L87!T8?YO9/YI;R!P86ME:71I;6%S+"!S
M=7-I<VEE:VET92!S=2`B"B)A9&UI;FES=')A=&]R:75M:2XB"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,3@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T
M<B`B3F5G86QI=2!I\'1R:6YT:2!F86EL;R!<(B5S7"(N(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R
M;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S-2!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G-Q;"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&-O
M;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(DYE9V%L:74@<')I
M<VEJ=6YG=&D@<')I92!)34%0('-E<G9E<FEO.B`E<R(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C0Q,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F5G86QI
M=2!I\'1R:6YT:2!F86EL;R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B
M0V%N861A(@IM<V=S='(@(DMA;F%D82(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P
M,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M9&5L971E+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I
M9"`B0V%N8V5L(@IM<V=S='(@(D%T\&%U:W1I(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E
M<&]R="(*;7-G<W1R(")!=/!A=6MT:2!P<F]B;&5M;W,@<')A;F7P:6W@(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M3F5G86QI=2!I\'1R:6YT:2!F86EL;R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO
M="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F5G86QI
M=2!R87-T:2!L86EK:6YO:F\@:V%T86QO9V\N(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R
M;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R
M(").96=A;&EU(&%P9&]R;W1I("=T87)G971&:6QE)R!P87)A;65T<F\N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G
M<W1R(").96=A;&EU(&GP=')I;G1I(&MA=&%L;V=O(%PB)7-<(BXB"@HC.B!F
M<F%M97=O<FLO1&%T851R964O1&%T851R964N<&AP.C$R."!F<F%M97=O<FLO
M1&%T851R964O1&%T851R964O<W%L+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S
M='(@(DYE9V%L:74@:?!T<FEN=&DN($5G>FES='5O:F$@)60@<&_P86MI86DN
M(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X
M"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@
M<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*
M(G-T;W)E9"XB"FUS9W-T<B`B(@HB3F5G86QI=2!P97)R^_!I=6]T:2X@P79E
M<W1A<R#A<F'P^"!S:V%IZ&EU<R!N97-U=&%M<&$@<W4@X7)A\/@@<VMA:>AI
M=6UI("(*(F1U;VUE;O@@8F%ZZVIE+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O
M=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B3F5G
M86QI=2!N=6MR96EP=&D@_FEN=73K<R#A(&YU<F]D>73@(&YU;65RX2XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(DME:7!V97)D
M:7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(T"FUS9VED(")#87!T:6]N(@IM<V=S='(@(E!A=F%D:6YI;6%S
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z
M,3`T"FUS9VED(")#87)R:65R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,`IM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM
M<V=S='(@(DMA=&5G;W)I:F]S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA
M;B!)<VQA;F1S(@IM<V=S='(@(DMA:6UA;O@@<V%L;W,B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL
M(%!H;VYE(@IM<V=S='(@(DUO8FEL=7,@=&5L969O;F%S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I
M9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(D-E;.MS(&YU<W1A='EM86DB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R(")487)P86D@8V5LZW-E
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R(")#96SK
M<R!N=7-T871Y;6%I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B
M5&%R<&%I('1A<G`@8V5L:?@Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(W-`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(DUO8FEL=7-I<R!T
M96QE9F]N87,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B
M0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B2V5L=/@@*$E33RTX.#4Y
M+3$T*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R(")#96YT<F4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS
M9W-T<B`B0V5N=')I;NMS($%F<FEK;W,@4F5S<'5B;&EK82(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)
M4T\M.#@U.2TR*2(*;7-G<W1R(")#96YT<FENZW,@175R;W!O<R`H25-/+3@X
M-3DM,BDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Y
M.0IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R(")397)T:69I
M:V%T;R!D971A;.MS(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV,3$*(RP@9G5Z>GD*;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM
M<V=S='(@(E-E<G1I9FEK871O(&1E=&%LZW,B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B0V5R=&EF:6-A=&4@4&]L
M:6-I97,B"FUS9W-T<B`B4V5R=&EF:6MA=&\@=&5I<^MS(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`X"FUS9VED(")#:&%D(@IM<V=S='(@(LAA9&%S(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHY-@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(E!A:V5I<W1I(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"B,L(&9U>GIY"FUS9VED
M(")#:&%N9V4@66]U<B!087-S=V]R9"(*;7-G<W1R(")3;&%P=&'^;V3^:6\@
M:V5I=&EM87,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@
M(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S
M964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS
M+B(*;7-G<W1R("(B"B)*^W/X('9A<F1O(&ER(&%D<F5S;RP@:W5R:75O<R!M
M871Y<R#^;6]NZW,L('-K86ET86YT>7,@:7(@871S86MI;NMJ86YT>7,@X2`B
M"B)*^W/X(&QA:?!K=7,L(&ME:71I;6%S+B(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S
M=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG
M=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(E-I;6)O;&ES(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R(")085]T:6MR
M:6YT:2!N=6]R;V3@+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;&4B"FUS
M9W-T<B`BR&ELZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@
M(DMI;FEJ82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")#
M:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B2VEN:65T:?!K
M82!P87!R87-T82`H1T(R,S$R*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@Q"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R
M(")+:6YI971I\&MA('1R861I8VENZR`H0FEG-2DB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!P87-S
M=V]R9"(*;7-G<W1R(")087-I<FEN:VET92!S;&%P=&'^;V3A(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.`IM<V=I9"`B0VAO;W-E
M(&$@=7-E<FYA;64B"FUS9W-T<B`B4&%S:7)I;FMI=&4@=F%R=&]T;VIO('9A
M<F3@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y.`IM<V=I9"`B0VAO
M;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R(")087-I<FEN:VET
M92!K86EP('9A:7ID=6]T:2!D871A<SHB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O
M<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T
M<B`B4&%S:7)I;FMI=&4@<W5R^_!I=6]T;R!SX')A\&\@<W1I;&GX(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R(")+86SK
M9/@@<V%L82(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HX.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(DML
M87/K<R`E<R!NZW)A+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*;7-G<W1R(")':65D<F$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS
M9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(DGP=')I;G1I($U3
M($]F9FEC92#^>6UE<R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*(RP@
M9G5Z>GD*;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@(DGP=F%L>71I('9A
M<G1O=&]J;R!D=6]M96YI<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L
M96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R
M.B`E<R(*;7-G<W1R(")687)T;W1O:F\@9'5O;65N^"!V86QY;6%S.B`E<R(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B
M0VQE87(@=7-E<B(*;7-G<W1R("))\'9A;'ET:2!V87)T;W1O:F\@9'5O;65N
M:7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I
M9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(DGP=F%L>71I('9A<G1O=&]J
M;R!D=6]M96YI<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$U"B,L(&9U>GIY"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S
M='(@(DQI971U<R!V86MA<F4B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M;6%I;G1E;F%N8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B
M"FUS9W-T<B`B5.9S=&DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A4
M5%`B"FUS9W-T<B`B0VQI8VMA=&5L;"!P97(@2%144"(*"B,Z('-E<G9I8V5S
M+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(E7^9&%R>71I(&QA;F?@
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#0*;7-G:60@(D-L;W5D<R(*
M;7-G<W1R(")$96)E<W5O=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ-@HC+"!F=7IZ>0IM<V=I9"`B0VQO=61S($5A<FQY
M(@IM<V=S='(@(D1E8F5S=6]T82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B1&5B
M97-U;W1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES
M;&%N9',B"FUS9W-T<B`B2V]K;W-O("A+>6QI;F=O*2!S86QO<R(*"B,Z('1E
M;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*(RP@9G5Z>GD*;7-G:60@
M(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B5'7PZ&GX(&-E;&GX(&MR8?!T
M^"!R;V1Y;6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS
M9W-T<B`B5'7PZ&GX(&-E;&GX(&MR8?!T^"!R;V1Y;6%S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-PIM<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`B2V]L=6UB:6IA(@H*(SH@;&EB
M+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(E-P86QV82(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C0*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`P('-E<G9I8V5S+VEM86=E
M<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G
M<W1R(")087-I<FEN:VET92!S<&%L=N`B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#0V"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@
M(E-P86QV;W,@<&%S:7)I;FMI;6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@
M(E-T=6QP96QI86DZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT
M-@IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R(")3='5L<&5L:?@@<&%V
M861I;FEM86DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8T"FUS
M9VED(")#;VUI8W,B"FUS9W-T<B`B2V]M:6MS86DB"@HC.B!A9&UI;B]C;61S
M:&5L;"YP:'`Z,C4*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B2V]M86YD82(*
M"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L
M;"(*;7-G<W1R(")+;VUA;F1I;NL@96EL=73K(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")#;VUM96YT(@IM<V=S='(@
M(DMO;65N=&%R87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4V-@IM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B5F%R9&%S+W!A
M=F%R9.LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R(")+
M;VUO<F%I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R(")+;VUP86YI:F$B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*
M;7-G<W1R(")+;VUP:75T97)I86DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,CDW"B,L(&9U>GIY"FUS9VED(")#;VYD:71I;VXB"FUS9W-T
M<B`B4^!L>6=O<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y"FUS9VED
M(")#;VYD:71I;VYS(@IM<V=S='(@(E/@;'EG;W,B"@HC.B!A9&UI;B]S971U
M<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E
M<R(*;7-G<W1R(").=7-T871Y;?@@<&%K96ET:6UA:2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-#,*;7-G:60@(D-O;F9I9W5R871I;VX@9F]R('-Y
M;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0HC+"!F=7IZ
M>0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T
M<B`B4F5I:VEA(&%T;F%U:FEN=&D@:V]N9FEG^W)A8VENX2!F86ELX"XB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R(")+;VYF:6?[<G5O=&D@)7,B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED(")#
M;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(E-L87!T8?YO9&ES(&1A<B!K87)T
MX"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-34@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S='(@(DMO;F=A<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U
M8FQI8R!O9B!T:&4B"FUS9W-T<B`B1&5M;VMR871I;NL@2V]N9V\@4F5S<'5B
M;&EK82(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R(")0<FES:6IU
M;F=T:2!N97!A=GEK;RXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S
M='(@(E!R:7-I:G5N9W1I(&YE<&%V>6MO.B`B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E
M9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B4')I<VEJ=6YG
M=&D@<')I92!V:67P^&KX(')A:W3X('-E<G9E<FEO(&YE<&%V>6MO+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K
M97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R(")0<FES:6IU;F=T
M:2!P<FEE('9I9?#X:O@@<F%K=/@@<V5R=F5R:6\@;F5P879Y:V\L(&YE<SH@
M)7,@*"5S*2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#0U"FUS
M9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R
M(")0<FES:6IU;F=T:2!P<FEE($944"!S97)V97)I;R!N97!A=GEK;RXB"@HC
M.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`Q-`IM<V=I9"`B0V]N=&%C=',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B2V]N:V%K=&%I
M('/K:VUI;F=A:2#A=')A=6MT:2#A($K[<_@@861R97/X(&MN>6=E;.8B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(B<E<R<@
M='5R:6YY<R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B
M"FUS9W-T<B`B5.9S=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N
M9',B"FUS9W-T<B`B2W5K;R!S86QO<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(DQA:6WK<R#^:6YU=.MS
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@(DMO<&EJ=6]T:2(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8X"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B4')I<VEJ
M=6YG=&D@;F5P879Y:V\Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S
M='(@(DMO<&EJ=6]T:2!P87-I<FEN:VEMX"(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B2V]S
M=&$@4FEK82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS
M9W-T<B`B1')A;6)L:6\@2V%U;&\@2W)A;G1A<R(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.CDW-@IM<V=I9"`B0V]U;&0@;F]T(%!'4"!E
M;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(DYE<&%V>6MO('7^:V]D=6]T:2!0
M1U`@;&%I\&MO+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$P-3,*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+B(*;7-G
M<W1R(").97!A=GEK;R!P87-I<F'P>71I(%!'4"!L86GP:V\N(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD
M(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R(").97!A=GEK
M;R!U_FMO9'5O=&D@4R]-24U%(&QA:?!K;RXB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-
M12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(DYE<&%V>6MO('!A<VER8?!Y=&D@
M4R]-24U%(&QA:?!K;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@(DYE<&%V>6MO('!R:63K
M=&D@:V]N=&%K=&\N("5S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"FUS
M9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B
M3F5P879Y:V\@875T96YT:69I:W5O=&ES(.$@3$1!4"!S97)V97+A+B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*(RP@9G5Z>GD*;7-G:60@(D-O
M=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(DYE<&%V>6MO
M(&%U=&5N=&EF:6MU;W1I<R#A($Q$05`@<V5R=F5RX2XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S
M(@IM<V=S='(@(DYE<&%V>6MO('!A=&EK<FEN=&D@8F%L86YS;RX@)7,B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q"B,L(&9U>GIY"FUS9VED(")#
M;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<B(*;7-G<W1R(").97!A
M=GEK;R!P<FES:6IU;F=T:2!P<FEE(%--0B!S97)V97)I;RXB"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@
M1E10.B`E<R(*;7-G<W1R(").97!A=GEK;R!P<FES:6IU;F=T:2!P<FEE("<E
M<R<@<V5R=F5R:6\@<&5R($944#H@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R(").97!A=GEK;R!S=6MU<G1I(&1I<W1R:6)U8VEJ;W,@<^!R8?!O
M+B`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,C4*
M;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+B(*;7-G<W1R(").
M97!A=GEK;R!A=&MO9'5O=&D@4$=0(&1U;VUE;O@N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C(*;7-G:60@(D-O=6QD(&YO="!D
M96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R(").97!A=GEK;R!A=&MO9'5O
M=&D@4R]-24U%(&1U;VUE;O@N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R(").97!A=GEK
M;R!I\'1R:6YT:2!K;VYT86MT;RX@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R(").97!A=GEK;R!I\'1R:6YT:2!D:7-T<FEB=6-I:F]S('/@<F'P
M;RX@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U
M<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(DYE<&%V>6MO(&GP=')I
M;G1I(&%T;F%U:FEN:6UO('-K<FEP=&\@)R5S)RXB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE
M(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R(").97!A=GEK
M;R!N=7-T871Y=&D@9V%VZVIO(&5L+B!P8?!T;R!A9')E<V\N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G
M:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM
M<V=S='(@(E!A=GEK;R!G875T:2!V:7-O<R!A9')E<_@@:VYY9V5LZW,N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT
M.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I
M;VX@;&ES="XB"FUS9W-T<B`B3F5P879Y:V\@9V%U=&D@=FES;R!D:7-T<FEB
M=6-I:F]S('/@<F'P;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H
M92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T
M<B`B3F5P879Y:V\@9V%U=&D@=FES;R!D:7-T<FEB=6-I:F]S('/@<F'P^"!S
MX')A\&\N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R
M871E9WD@7"(E<UPB+B(*;7-G<W1R(").97!A=GEK;R!U_FMR875T:2!S=')A
M=&5G:6IO<R`G)7,G+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]D:7)E8W0N<&AP.C,P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R(").97!A=GEK;R!S
M=6MU<G1I(&MA=&%L;V=O("<E<R<N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI
M8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R(").97!A=GEK;R!G
M875T:2!V:67P;VIO(')A:W1O(&GP(')A:W3X('-E<G9E<FEO+B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B
M3F5P879Y:V\@871I9&%R>71I("<E<R<@<F'P>6UU:2XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(DYE
M<&%V>6MO(&%T:61A<GET:2`E<RXB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N
M8V4O36%I;G1E;F%N8V4N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G
M<W1R(").97!A=GEK;R!A=&ED87)Y=&D@36%I;G1E;F%N8V5?5&%S:R!M;V1U
M;&EO("5S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB
M+B(*;7-G<W1R(").97!A=GEK;R!A=&ED87)Y=&D@:V%T86QO9V\@)R5S)RXB
M"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HU,38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HV.3D*(RP@9G5Z>GD*;7-G:60@(D-O=6QD
M(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DYE<&%V>6MO
M('!A:67P:V$@3$1!4"!S97)V97)Y:F4N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O3V)J96-T+G!H<#HR,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(')E860@)7,N(@IM<V=S='(@(DYE<&%V>6MO('-K86ET>71I("5S+B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#
M;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D
M('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@
M8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB
M3F5P879Y:V\@<&%K96ES=&D@<VQA<'1A_F]D_FEO(/!I86T@=F%R=&]T;VIU
M:2X@2V%I(&MU<FD@87)B82!V:7-A("(*(FEN9F]R;6%C:6IA('ER82!N971I
M:W-L:2X@4&%B86YD>6MI=&4@9&%R(&MA<G3@(&%R8F$@<W5S:7-I96MI=&4@
M<W4@<V%V;R`B"B)A9&UI;FES=')A=&]R:75M:2!J96EG=2!R96EK86QI;F=A
M('!A9V%L8F$N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S`Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,T,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S@S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X
M.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R(").97!A
M=GEK;R!G875T:2!!0TPB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R(").97!A
M=GEK;R!G875T:2!A9')E<_@@:VYY9V5LZW,N("5S(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<R(*;7-G<W1R(").97!A=GEK;R!G875T:2!D:7-T<FEB=6-I:F]S
M('/@<F'P;RX@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R(").
M97!A=GEK;R!G875T:2!D:7-T<FEB=6-I:F]S('/@<F'P^"X@)7,B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PIM<V=I9"`B0V]U
M;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R
M(").97!A=GEK;R!N=7-T871Y=&D@<V5R=F5R:6\@9V%L:6UY8FGX(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T(')E
M=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").97!A=GEK;R!A=&ME:7-T
M:2!N=7-T871Y;?@N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*
M;7-G<W1R(").97!A=GEK;R!I\'1R:6YT:2!K871A;&]G;R`G)7,G+B(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(DYE<&%V>6MO(&GP<V%U9V]T:2`E<R!N=7-T871Y;?@N(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y
M"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN
M(@IM<V=S='(@(DYE<&%V>6MO('!A9&%R>71I(&%T<V%R9VENZW,@;G5S=&%T
M>6WX(&MO<&EJ;W,N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A
M8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(DYE<&%V>6MO('!A9&%R
M>71I(&%T<V%R9VENZW,@)7,@;G5S=&%T>6WX(&MO<&EJ;W,N(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O
M.B!<(B5S7"(N(@IM<V=S='(@(DYE<&%V>6MO(&GP<V%U9V]T:2!A=&YA=6II
M;FEM;R!S:W)I<'0@X3H@)R5S)RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C8T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T
M<B`B3F5P879Y:V\@<&%D87)Y=&D@871S87)G:6[K<R`E<R!N=7-T871Y;?@@
M:V]P:6IO<RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE
M(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E
M<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G
M<W1R("(B"B).97!A=GEK;R!U_G)A\'ET:2X@2OMS(&=A;&ET92!A<F)A(&YA
M=61O=&ES(&%T;F%U:FEN:6UO('-K<FEP='4@87)B82!P871Y<R`B"B)N=6MO
M<&EJ=6]T:2!K;V3@(&%P8>AI;VIE(.$@)7,N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HQ-#,*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@
M=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(").97!A=GEK;R!P86EE\&MA($Q$
M05`@<V5R=F5R>6IE+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N
M(@IM<V=S='(@(DYE<&%V>6MO(&YU=')A=6MT:2!R>?#A("<E<R<N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T
M+B`E<R(*;7-G<W1R(").97!A=GEK;R!A=&YA=6II;G1I(&MO;G1A:W1O+B`E
M<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYE<&%V>6MO(&%T;F%U
M:FEN=&D@9&ES=')I8G5C:6IO<R!SX')A\&\N("5S(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*
M;7-G<W1R(").97!A=GEK;R!U_G)A\'ET:2`G)7,G(&YU<W1A='EM^#H@)7,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8V"FUS9VED(")#;W5L9&XG
M="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED
M96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B"B).97!A=GEK;R!R87-T:2!-;WII
M;&]S(.%R86YK:?@@:G5O<W1O<RX@P7-I=&EK:6YK:71E+"!K860@:FD@871I
M9&%R>71A+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C$U-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N
M)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@
M=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(DYE<&%V>6MO('-U=&5I
M:W1I(/!I^"!T96ES:?@@=F%R=&]T;VIU:2`G)7,G(&MA=&5L;V=E("<E<R<Z
M("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q.0IM<V=I9"`B
M0V]U;G1E9"!T97AT(@IM<V=S='(@(E)I8F]T87,@=&5K<W1A<R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")#;W5N
M=')Y(@IM<V=S='(@(E9A;'-T>6+K(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(W,PIM<V=I9"`B0V]U<G-E<R(*;7-G<W1R(")+=7)S86DB"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R(")3=6MU<G1I(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(E-U:W5R=&D@;G5O
M<F]DX"(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z
M.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B4W5K=7)T:2!N
M875JX"!A<')A\.`B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@
M(E-U:W5R=&D@<&%K871A;&]G:75S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B4V%V:6YI;FMO('1E:7/K<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R,S`*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R
M(")+<F5D:71I;NMS(&MO<G1E;.MS(&YU;65R:7,B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM
M<V=I9"`B0W)O871I82(*;7-G<W1R(")+<F]A=&EJ82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*
M;7-G:60@(D-U8F$B"FUS9W-T<B`B2W5B82(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G
M<W1R(")$86)A<G1I;NL@9F%ZZR(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HT
M.`HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R(")3
M879I;FEN:V\@=&5I<^MS(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB
M+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T
M<B`B1&%B87)T:6YI<R!L86EK87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@
M55),(&ES(@IM<V=S='(@(M!I=6\@;65T=2!54DP@>7)A(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C,S"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%5S97)S
M(@IM<V=S='(@(D1A8F%R=&ENZR!F87KK(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(D1A8F%R
M=&ENZW,@;W)O('/@;'EG;W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C<U"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@
M(D1A8F%R=&ENZW,@<^!L>6=O<SH@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*
M;7-G<W1R(")$86)A<G1I;FES('-T:6QI=7,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3`X"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T
M87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B5F5I:W-M
M^"P@871L:65K86WX('!R:7-I:G5N9W5S('!R:64@)7,L(&YU<W1A='EM87,N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B4&5R:V5L=&DB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED
M(")#=70@<V5L96-T:6]N(@IM<V=S='(@(E!E<FME;'1I('!A<VER:6YK:6W@
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S='(@(DMI<')A<R(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED(")#>7)I;&QI8R`H
M2T])."U2*2(*;7-G<W1R(")+:7)I;&EC82`H2T])."U2*2(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ
M,C4Q*2(*;7-G<W1R(")+:7)I;&EC82`H5VEN9&]W<RTQ,C4Q*2(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI
M86X@*$M/23@M52DB"FUS9W-T<B`B2VER:6QI8V$O56MR86EN:65T:?!K82`H
M2T])."U5*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM
M<V=S='(@(LAE:VEJ;W,@4F5S<'5B;&EK82(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-3$@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(D1$(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S(X,0IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E
M87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R
M;RUD<VXN<&AP*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N
M8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R(")+
M87-D:65N(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$871A
M5')E92!"<F]W<V5R(@IM<V=S='(@(D1U;VUE;O@@;65D_FEO(&YA<O!Y:VSK
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W.0IM<V=I9"`B1&%T
M86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,Y.0IM<V=I9"`B1&%T92(*;7-G<W1R(")$871A(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C
M96EV960B"FUS9W-T<B`B1V%U=&$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#`W"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R(")$871O
M<R!P87-I<FEN:VEM87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,CDR(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,C(*;7-G:60@
M(D1A>2(*;7-G<W1R(")$:65N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B1&5?;&5T92!#
M;VQU;6XB"FUS9W-T<B`B2?!T<FEN=&D@7W-T=6QP96SA(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M
M8F5R(@IM<V=S='(@(D=R=6]D:7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED(")$96-I;6%L
M(&YU;6)E<G,B"FUS9W-T<B`B1&7P:6UT86EN:6%I('-K86GH:6%I(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I
M9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(E-U;6'^:6YT:2!A=&ET<F%U
M:VEMX"(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI
M8B]P<F5F<RYP:'`Z,3$W"B,L(&9U>GIY"FUS9VED(")$969A=6QT(@IM<V=S
M='(@(E-T86YD87)T:6[K('-P86QV82(*"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O;&]R
M(@IM<V=S='(@(E-T86YD87)T:6[K('-P86QV82(*"B,Z(&9R86UE=V]R:R])
M9&5N=&ET>2])9&5N=&ET>2YP:'`Z.3$*;7-G:60@(D1E9F%U;'0@261E;G1I
M='DB"FUS9W-T<B`B4W1A;F1A<G1I;FES(&%P<F'P87,B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@4VAE
M;&PB"FUS9W-T<B`B4W1A;F1A<G1I;NL@<W!A;'9A(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R(")!
M<&EB<NO^:6UA:2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,SD*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R("))\'1R:6YT:2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS,@HC+"!F=7IZ>0IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`B2?!T
M<FEN=&D@8V5LYB(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D;6EN+V=R
M;W5P<RYP:'`Z,C(W"FUS9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B2?!T
M<FEN=&D@9W)U<.8B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-#D*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`B2?!T<FEN
M=&D@96EL=73F(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW
M-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L
M971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B2?!T<FEN=&D@=&5I<^8B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B
M1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R(")6:7-I\&MA:2!I
M\'1R:6YT:2!L86GP:W5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB"FUS
M9W-T<B`B2?!T<FEN=&D@8V5LYB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU
M;6XB"FUS9W-T<B`B2?!T<FEN=&D@<W1U;'!E;.$B"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T
M92!T96UP;&%T92(*;7-G<W1R("))\'1R:6YT:2!E9WII<W1U;VIA;G3A(&%L
M=&5R;F%T>7;X(/!A8FQO;N`B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C0R,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E
M('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B)R5S)R!T96ES:?@@
M=')Y;FEM87,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I
M;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S
M='(@(D%R('1I:W)A:2!N;W)I=&4@:?!T<FEN=&D@)R5S)R!T96ES97,@:7(@
M=FES87,@<&]T96ES97,_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O=R(*;7-G
M<W1R("))\'1R:6YT:2!E:6QU=.8B"@HC.B!T96UP;&%T97,O<')E9G,O9&5L
M971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@:61E
M;G1I='DB"FUS9W-T<B`B2?!T<FEN=&D@<&%S:7)I;FMTX"!A<')A\.`B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T
M<B`B2?!T<FEN=&D@\.$@<W1U;'!E;.$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T
M92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B2?!T<FEN=&D@\&G@(&5I;'5T
MYB(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T
M(%PB)7-<(BXB"FUS9W-T<B`B071N875J:6YI;6\@<VMR:7!T87,@)R5S)R!I
M\'1R:6YT87,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PIM<V=I9"`B1&5L:79E<GD@=&EM
M92(*;7-G<W1R(")0<FES=&%T>6UO(&QA:6MA<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G
M:60@(D1E;FUA<FLB"FUS9W-T<B`B1&%N:6IA(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B
M;&5M(@IM<V=S='(@(E!R;V)L96UO<R!A<')A\'EM87,B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HY,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS
M9W-T<B`B07!R8?!Y;6%S(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ.34*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE
M*3HB"FUS9W-T<B`B1&5T86QI874@*'1A:7`@<&%T(/YI^W+K:VET92!(;W)D
M92!L;V<@9F%I;&4I.B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,3DY"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R(")!9&UI;FES=')A=&]R:75I(&GP<VGX
M<W1A<R!D971A;'5S(&%P<F'P>6UA<RXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C$Y"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R(")6>7-T
M>6UA<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$W"FUS9VED(")$97<@
M4&]I;G0B"FUS9W-T<B`B1'+K9VYU;6%S(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR.30*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS
M9W-T<B`B1'+K9VYU;6%S('!A<VMU=&ENYB!V86QA;F3@.B`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(W"FUS9VED(")$97<@<&]I;G0Z
M("(*;7-G<W1R(")$<NMG;G5M87,Z("(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T
M('1O(')I9VAT(@IM<V=S='(@(DMR>7!T:7,@:?`@:V%I<NMS(.$@9&7P:6[F
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B2W)Y
M<'1I<R!I\"!D9?!I;NMS(.$@:V%I<N8B"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(DMA=&%L;V=A<R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C8*;7-G:60@(D1I<W!L87D@
M,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B4F]D>71I(#(T+6GX('9A;"X@9F]R
M;6%TX#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D1I
M<W!L87D@3W!T:6]N<R(*;7-G<W1R(")686EZ9&%V:6UO(&YU<W1A='EM86DB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.38*(RP@9G5Z>GD*
M;7-G:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B4F]D
M>71I('!R;V=R;V[F("A4048I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX
M-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R(")2;V1Y
M=&D@<')O9W)O;N8@*%1!1BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.#$W"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R(")686EZ9&%V
M:6UO(&9O<FUA=&%S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP
M.C$Y,`IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@
M(DQA:?!K;R!P<FES=&%T>6UO('!R86YE\&EM86DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS
M9VED(")$:FEB;W5T:2(*;7-G<W1R(")$_FEB=71I<R(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N;W0@9&5L971E
M(@IM<V=S='(@(DYE=')I;G1I(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA
M;F-E+G!H<"(*;7-G<W1R(").97-I:W)E:7!K:71E('1I97-I;V=I86D@X2!M
M86EN=&5N86YC92YP:'`B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN
M8SHQ,B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E
M<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y
M97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R(")!<B!P:7)M87,@X7)A\&%S
M('ER82!L875K;R!V87)D86D_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI
M8V$B"FUS9W-T<B`B1&]M:6YI:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$;VUI
M;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B1&]M:6YI:V]S(%)E<W!U8FQI:V$B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED(")$;VXG
M="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-`IM<V=I9"`B1&]W
M;FQO860B"FUS9W-T<B`B071S:7-I^'-T:2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C@T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$
M;W=N;&]A9"`E<R(*;7-G<W1R(")!='-I<VGX<W1I("5S(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B071S:7-I
M^'-T:2!S=6=E;F5R=6]T=7,@;G5S=&%T>6UU<R!K86EP(%!(4"!S:W)I<'3@
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#<*;7-G:60@(D1R
M;W`@9&]W;B!L:7-T(@IM<V=S='(@(DGP<VES:VQE:63^:6%N=&ES('/@<F'P
M87,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S
M(@IM<V=S='(@(E9A:7-T86DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3,*;7-G:60@(D4M36%I;"(*;7-G<W1R(")%;"X@<&'P=&\@
M861R97-A<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M
M='`N<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L
M(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@
M(D524B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B16MV
M861O<F%S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R"B,Z('1E;7!L871E
M<R]P;W)T86PO961I="YI;F,Z,C4*;7-G:60@(D5D:70B"FUS9W-T<B`B2V5I
M<W1I(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU,"!T96UP
M;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET($)L;V-K(@IM
M<V=S='(@(DME:7-T:2!B;&]K;R!P87)A;65T<G5S(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D:70@
M1W)O=7`B"FUS9W-T<B`B4F5D86=U;W1I(&=R=7#F(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$P,`IM<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(E)E
M9&%G=6]T:2!T96ES97,B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(E)E9&%G=6]T
M:2!T96ES97,B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM
M<V=S='(@(B5S('1E:7-I^"!R961A9V%V:6UA<R(*"B,Z('1E;7!L871E<R]P
M<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S
M='(@(DME:7-T:2!N=7-T871Y;75S.B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,S8W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%
M9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B)7,@=&5I<VGX
M(')E9&%G879I;6%S(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E
M<R(*;7-G<W1R("(E<R!T96ES:?@@<F5D86=A=FEM87,B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R(")5
M9V1Y;6%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B16=I
M<'1A<R(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"B,L('!H
M<"UF;W)M870*;7-G:60@(D5I=&AE<B!E;F%B;&4@:70@=&AE;CH@)7,L(&]R
M('5S92!T:&4@8F%S:6,@2%1-3"!V97)S:6]N.B`E<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R(")386QV
M861O<F%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(D5L
M96UE;G1A<RXN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R(")%;2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@V.0IM<V=I9"`B16UA:6PB"FUS9W-T<B`B16PN
M('!A\'1A<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-38U('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV.`IM<V=I9"`B16UA:6P@
M061D<F5S<R(*;7-G<W1R(")%;"X@<&'P=&\@861R97-A<R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C,*;7-G:60@(D5M86EL(&%D9')E<W-E
M<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")%;"X@<&'P=&\@861R97-A:2!T=7)I
M('-U=&%P=&DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX.0IM
M<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B16PN('!A
M\'1O(&%D<F5S87,@<W4@<&%T=FER=&EN:6UU(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O
M+5--4R!'871E=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR.3@*;7-G:60@(D5M;W1I8V]N<R(*;7-G
M<W1R("+0>7!S96[K;.MS(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED(")%;7!T>2!M97-S86=E+B(*
M;7-G<W1R("+>:6YU=.L@='7PZ&EA+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C8R
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L
M="XB"FUS9W-T<B`B4F5Z=6QT871A<R!T=?#H:6%S+B(*"B,Z(&9R86UE=V]R
M:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C
M:"!T97)M<R(*;7-G<W1R(").96YU<F]DZW1E('!A:67P:V]S('1E<FUI;O@B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30S"FUS9VED(")%;F%B;&4@
M:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T
M97AT/R(*;7-G<W1R("),96ES=&D@=&5K<W1E(.%T97)P=&D@<&%V96EK<VSK
M;&EU<R!I\"!.=6]T<F%U:_@@9V%L97)I:F]S/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,3@*;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT
M97AT(&UE;G4_(@IM<V=S='(@(L%J=6YG=&D@9&7P:6YI;VIO('!E;.MS(&UY
M9W1U:V\@;65N:74_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y
M."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$Q"FUS9VED(")%;F0@>65A
M<B(*;7-G<W1R(")'86QI;FEA:2!M971A:2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I
M=&]R(@IM<V=S='(@(DGP<&SK<W1I(')E9&%K=&]R:?@B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C(Q"FUS9VED("(B"B)%;G1E<B!A('-E8W5R:71Y
M('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D
M('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE
M(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@HBP7)A\'EK:71E(&ML
M875S:6W@+"!K=7)I<R!J=6US(&)U<R!U_F1U;W1A<R!J96EG=2!P86UI<O!I
M=&4@<V%V;R!S;&%P=&'^;V3A+"`B"B)P=GHN.B`G:V]K<R!Y<F$@2OMS^"!G
M>7;[;F\@=F%R9&%S/R<Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@
M:6UA9V4@55),(&AE<F4B"FUS9W-T<B`BP79E<VMI=&4@<&%V96EK<VSK;&EO
M(%523"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HX.3$*;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDY(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G
M<W1R(")%:W9A=&]R:6[K($=V:6[K:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%
M<FET<F5A(@IM<V=S='(@(D5R:71RZVIA(@H*(SH@9G)A;65W;W)K+TYO=&EF
M:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#4@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C4U"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S8@
M<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HX,@IM<V=I9"`B17)R;W(B"FUS
M9W-T<B`B2VQA:61A(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E
M+G!H<#HT-C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-R
M96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R(")+;&%I9&$@<VEU;NAI86YT(&%T
M<V%K>6W@.B`E<RXB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N
M8VAO<CH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z.#,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E
M;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R(")+;&%I9&$@<VEU;NAI86YT
M(&%T<V%K>6W@.B`E<RXB"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA
M=&4N<&AP.C0V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R(")+;&%I9&$@<VEU;NAI86YT
M(&%T<V%K>6W@.B`E<RXB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z-S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T
M:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R(")+;&%I9&$@<VEU;NAI86YT(&%T
M<V%K>6W@.B`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S
M<V%G92XB"FUS9W-T<B`B2VQA:61A(&QA:?!K92XB"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z,30R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W
M<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B2VQA:61A(')A\&%N="`G)7,G+B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B17-T:6IA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B171I;W!I:F$B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*
M;7-G<W1R(")%=&YI;NMS(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B175R;W!A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,S.0IM<V=I9"`B179E<GD@,34@;6EN=71E
M<R(*;7-G<W1R(")+87,@,34@;6EN=>AI^"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.#D*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R(")+
M87,@,B!M:6YU=&5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`S,"!S96-O
M;F1S(@IM<V=S='(@(DMA<R`S,"!S96MU;F3^:?@B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S,X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G
M:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")+87,@-2!M:6YU=&5S(@H*
M(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HV,`IM
M<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B2VEE:W9I96YO('!R:7-I:G5N
M9VEM;R!M971U(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,`IM<V=I
M9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(DMA<R!P=7-V86QA;F3A(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-R!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S@X"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B2V%S(&UI
M;G5TYB(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED
M(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B4&%V>7ID_FEU:3HB"@HC.B!A
M9&UI;B]P:'!S:&5L;"YP:'`Z.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,C<*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B
M5GEK9'ET:2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C0W-0IM<V=I9"`B17AP86YD(@IM<V=S='(@(DGP<VML96ES=&DB"@HC.B!T
M96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"B,L(&9U>GIY"FUS9VED
M(")%>'!A;F0@4VED96)A<B(*;7-G<W1R(")'86QI;FEA:2!M971A:2(*"B,Z
M(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X
M<&5C=&5D("<I)R(*;7-G<W1R(")296EK86QI;F=A<R`G*2<B"@HC.B!F<F%M
M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E
M9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(E)E
M:6MA;&EN9V%S(/YO9&ES(&%R8F$@:V%B=73K<V4@X7)A\'ET87,@<&%I9?!K
M;W,@:W)I=&5R:6IU<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(D=A;&EO
M:FEM;R!D871A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-S8*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@(D5K<W!O;F5N=.LB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R(")496MS=&\@<W!A;'9A(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A
M9"!O9B!S971U<"(*;7-G<W1R(").=7-T871Y;?@@<VEU;G1I;6%S('!E<B!&
M5%`N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z,C$V"FUS
M9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B
M2VQA:61A(&YU<VMA:71A;G0@;G5S=&%T>6UU<RXB"@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S
M97)V97(N(@IM<V=S='(@(DYE<&%V>6MO('!R:7-I:G5N9W1I('!R:64@3$1!
M4"!S97)V97)I;RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z
M.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM
M<V=S='(@(DYE<&%V>6MO('!R:7-I:G5N9W1I('!R:64@4TU"('-E<G9E<FEO
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@V"B,L('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G
M<W1R(").97!A=GEK;R!N=6MO<&EJ=6]T:2!I\"!<(B5S7"(N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.3$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R(").97!A=GEK
M;R!N=6MO<&EJ=6]T:2#A(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!3
M05-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(DYE<&%V>6MO('-U:W5R=&D@;F%U
M:F\@4T%33"!R>?!I;RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C0Y-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@
M(DYE<&%V>6MO('!E<FME;'1I(.$@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-#8Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(DYE<&%V>6MO('!E
M<FME;'1I(.$@7"(E<UPB+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER(@IM<V=S='(@(M!V96QN=7,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA
M<RDB"FUS9W-T<B`B1F]L:VQA;F3X('-A;&]S("A-86QV:6YA:2DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<S"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S='(@(D9A<F5R^"!S
M86QO<R(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR,S@*(RP@9G5Z>GD*
M;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R(")+<FET:6[K(&ML86ED82$B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W
M"FUS9VED(")&87@B"FUS9W-T<B`B1F%K<V%S(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,T.0HC+"!F=7IZ>0IM<V=I9"`B1F%X97,B"FUS9W-T
M<B`B1F%K<V%S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(E9A<V%R:7,B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK92(*
M;7-G<W1R(")!=')O9&\@;'EG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(S,0IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(D%T<F]D
M;R!L>6<Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R(")4<G5M<&%L86EK
M:7,@;&EE='5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C`*(RP@9G5Z>GD*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS
M9W-T<B`B4/MG82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0*
M;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,S,T"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X"FUS9VED
M(")&:6=L970@9F]N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&
M:6II(@IM<V=S='(@(D9I9/YI<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B1FEL92(*;7-G<W1R(")F86EL
M87,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(D9A:6SX
M('-K86GH:75S.B`E<R!F86EL87,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F
M:6QE<R(*;7-G<W1R(")&86EL^"!S:V%IZ&EU<SH@)7,@9F%I;&%I*/@I(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P-PIM<V=I9"`B1FEL92!-
M86YA9V5R(@IM<V=S='(@(D9A:6SX('1V87)K>6UA<R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C@U"FUS9VED(")&:6QE($YA;64B"FUS9W-T<B`B
M1F%I;&\@<&%V861I;FEM87,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.3DU"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R(")&86EL;R!P
M87-I<FEN:VEM87,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#@V
M"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R(")&86EL;R!S:75N=&EM87,B
M"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-3D*;7-G:60@
M(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R(").87+P>6ML
MZR!N97!A;&%I:V\@9F%I;/@@<VEU;G1I;6\N(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C@Y"FUS9VED(")&:6QT97)S(@IM<V=S='(@(D9I;'1R
M86DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S='(@(E-U;VUI
M:F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S="!(
M86QF(@IM<V=S='(@(E!I<FUO:FD@<'5SZR(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U
M87)T97(B"FUS9W-T<B`B4&ER;6%S:7,@:V5T=FER=&ES(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-@IM<V=I9"`B1FEX
M(')A=&EO(@IM<V=S='(@(DYU<W1A='ET87,@:V]E9FEC:65N=&%S(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,0IM<V=I
M9"`B1FQI<"(*;7-G<W1R(")!='9I<FOPZ&EA<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L
M;V%T(@IM<V=S='(@(DGP9.MS='EM87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(E+[
M:V%S(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,S0@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B2V%T86QO9V%S
M("5S(&YE96=Z:7-T=6]J82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B
M5&5K<W1O('-P86QV82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM
M<V=I9"`B1F]O9"(*;7-G<W1R(")-86ES=&%S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"FUS9VED
M(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G
M<W1R(").87+P>6MLZVUS+"!K=7)I;W,@;F5P86QA:6MO('!A=F5I:W-LZVQI
M^"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,T"FUS9VED(")&;W)E8V%S
M="`H5$%&*2(*;7-G<W1R(")/<O@@<')O9VYO>NL@*%1!1BDB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-SD*;7-G:60@(B(*(D9O<F5C87-T
M($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N
M<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@
M8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@HB3W+X
M('!R;V=N;WKK<R!A<&EM=&ES("CA<VEDZVWK:VET92P@:V%D(/!I(&9U;FMC
M:6IA(&=R8?YI;F$@:7(@9&EE;F]S(&ER("(*(FYA:W1I97,@<')O9VYO>N8[
M('!E<B!D:61E;&ES('-K86GH:75S(&=A;&D@<W5D87)K>71I(&1I>F%I;N`I
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O
M<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R(")086UI<O!O=&4@<V%V;R!S
M;&%P=&'^;V3A/R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C(*
M;7-G:60@(D9O<FUS(@IM<V=S='(@(D9O<FUO<R(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R(")&<F%ZZR(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T
M>7!E(@IM<V=S='(@(D9R87II^"!T:7!A<R(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS.`IM<V=I9"`B1F]R='5N97,B"FUS9W-T<B`B1G)A>NMS(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")&;W)T=6YE<R`R
M(@IM<V=S='(@(D9R87KK<R`R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0U,PIM<V=I9"`B1F]R=6US(@IM<V=S='(@(D1I<VMU<VEJ;W,B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`Y"FUS9VED(")&;W)W87)D
M<R(*;7-G<W1R(")097)S:75N=&EM86DB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R(")0
M96YK+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S,*;7-G:60@(D9R86UE<R(*;7-G<W1R(")+<F'P=&ENZW,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B4')A;F/[>FEJ
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B
M1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B4')A;F/[>FEJ82P@365T
M<F]P;VQI<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS
M9W-T<B`B4')A;F/[>FEJ;W,@1W9I86YA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@
M(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B4')A;F/[>FEJ;W,@4&]L:6YE
M>FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E
M<G)I=&]R:65S(@IM<V=S='(@(E!R86YC^WII:F]S('!I971I;NMS('1E<FET
M;W)I:F]S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R(").=6\B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS-C`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P
M-@IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(DYU;R`B"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP
M=&EO;B(*;7-G<W1R(")0:6QN87,@87!R8?!Y;6%S(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U
M;&P@36]O;B(*;7-G<W1R(")0:6QN871I<R(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P
M"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B4&EL;F%S('9A<F1A<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(D=A8F]N87,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S
M='(@(D=A;&5R:6IA(&GP(&MU<FEO<R!I\"!K=7)I;W,@8G5S(')O9&]M87,@
M<&%V96EK<VSK;&ES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G
M<W1R(")'86QE<FEJ83HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB:6$B"FUS
M9W-T<B`B1V%M8FEJ82(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO
M;B(*;7-G<W1R(")'96YE<G5O=&D@)7,@;G5S=&%T>6UU<R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T
M960@0V]D92(*;7-G<W1R(")3=6=E;F5R=6]T87,@:V]D87,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(D=R=7II:F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@(E9O:VEE=&EJ82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S4*;7-G:60@(D=H86YA(@IM<V=S='(@(D=A;F$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U
M"FUS9VED(")':6)R86QT87(B"FUS9W-T<B`B1VEB<F%L=&%R87,B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B1VEV
M96X@3F%M92(*;7-G<W1R(")687)D87,B"@HC.B!T96UP;&%T97,O<')E9G,O
M87!P+FEN8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`B4F]D>71I(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B
M1V%D96QI<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,3(X"B,L(&9U>GIY"FUS9VED(")';V]G;&4@36%P<R(*;7-G<W1R
M(")';V]G;&4@<&%I9?!K82(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B1V]O9VQE('!A:67P
M:V$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C,W"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B3F5S<&%L=F]T87,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@(D=R86EK:6IA(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@(D=R965K("A)4T\M
M.#@U.2TW*2(*;7-G<W1R(")'<F%I:VGP:V$@*$E33RTX.#4Y+3<I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(D=R96YL86YD:6IA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R(")'<F5N861A
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G:60@(D=R;W5P($%D;6EN
M:7-T<F%T:6]N(@IM<V=S='(@(D=R=7!I^"!A9&UI;FES=')A=FEM87,B"@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@
M8F4@;F]N+65M<'1Y(@IM<V=S='(@(D=R=7#K<R!V87)D87,@='5R:2!B^W1I
M(&YE='7PZ&EA<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HS,#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z
M(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60Z("(*;7-G<W1R(")!=71H7VQD87`Z('-U:W5R=&D@=F%R=&]T
M;VK@("5S(&YE<&%V>6MO+B!397)V97)I;R!P<F%N9?!I;6%S.B`B"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C0Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R
M(")!=71H7VQD87`Z(&%T;F%U:FEN=&D@=F%R=&]T;VK@("5S(&YE<&%V>6MO
M(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S."!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R
M;W5P("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@871N875J:6YT:2!V87)T;W1O
M:N`@)7,@;F5P879Y:V\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(D=R
M=7#K<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B
M1W9A9&5L=7#K(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B
M1W5A;6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@
M(D=V871E;6%L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*
M;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(D=E<FYS:7,B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C@X"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R(")3
M=F7H:?@@=&5I<^MS(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W
M,`IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(E-V9>AI^"!K;GEG82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G<W1R(")'=FENZVIA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<X"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(D)I<W-A
M=2U'=FENZVIA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T
M<B`B1V%J86YA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.38P"FUS
M9VED(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN
M(')O=RXB"FUS9W-T<B`B2%1-3$%R96$@;F5G86QI(&GP=')I;G1I('!A<VMU
M=&ENZW,@8V5LZW,@96EL=73K:F4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN
M('1A8FQE+B(*;7-G<W1R(")(5$U,07)E82!N96=A;&D@:?!R:6YT:2!P87-K
M=71I;FEO('-T=6QP96QI;R!L96YT96SK:F4N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W
M(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,07)E82!N96=A;&D@:?!T<FEN=&D@
M<&%S:W5T:6[K<R!E:6QU=.MS(&QE;G1E;.MJ92XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H96YT:6-A
M=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E)E:6MA;&EN9V$@2%144"!A=71E
M;G1I9FEK86-I:F$N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*;7-G
M<W1R(")(86ET:7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(DAA<V@M06QG
M;W)I=&UA<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(DUI9VQA(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Y,S(*;7-G:60@(DAE861E<B(*;7-G<W1R(")!;G1R8?!TZR(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-C$*(RP@9G5Z
M>GD*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B06YT<F'P=.LB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD
M<R(*;7-G<W1R(")(97)D;R!S86QA(&ER($UA:V1O;F%L9&\@<V%L;W,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PHC+"!F
M=7IZ>0IM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R(")4+6%U9')A(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(DAE8G)E=R`H25-/
M+3@X-3DM."U)*2(*;7-G<W1R(")(96)R86KX("A)4T\M.#@U.2TX+4DI(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(D%U:_!T:7,B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D
M92](;W)D92](96QP+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP
M:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G:60@(DAE;'`B
M"FUS9W-T<B`B4&%G86QB82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM
M<V=S='(@(E)E9&%K=&]R:6%U<R!N875D;VII;6]S:2!P86=A;&)A(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W,0IM<V=I9"`B2&5L<&5R(@IM
M<V=S='(@(E!A9V%L8FEN:6YK87,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B2&5M:7-F97)A(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O
M9B!T:&4@9FEL93HB"FUS9W-T<B`BT'1A:2#H:6$@>7)A(&9A:6QO('!R863^
M:6$Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-CD*;7-G:60@(DAI9V@B"FUS9W-T<B`B4W9A<F)U(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A
M9&5R+FEN8SHU"FUS9VED(")(;U]M92(*;7-G<W1R(")?4&]R=&%L87,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T
M871E*2(*;7-G<W1R("+0=F5N=&%S:7,@4V]S=&%S("A6871I:V%N;R!V86QS
M=&EJ82DB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U,S4*;7-G
M:60@(DAO;64B"FUS9W-T<B`B4&]R=&%L87,B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S
M<R(*;7-G<W1R(").86WX(&%D<F5S87,B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-C0*(RP@9G5Z>GD*;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S
M='(@(DMA=&%L;V=A<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B3F%M
M^"!T96QE9F]N87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM
M<V=S='(@(DAO;F3[<F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO
M;F<B"FUS9W-T<B`B2&]N:V]N9V%S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C8U"FUS9VED(")(;W)D92(*;7-G<W1R(")0;W)T86QA<R(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#0R"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U
M;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(&YE
M=&5I<VEN9VD@)7,@6$U,(&1U;VUE;GES(/YI;G5TZVIE("5S(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J
M96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!O8FIE:W1O("5S(&YE871I
M=&EN:V$@:F]K:6$@_FEN=73K(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO
M(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z(&]B:F5K=&\@=&EP87,@)7,@;F5R87-T87,@_FEN
M=73K:F4@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL
M>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@)7,@
M7"(E<UPB('/K:VUI;F%I(&GP=')I;G1A(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R
M871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS
M:6]N(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!I;G1E9W)A8VEJ;W,@=F%R:6ML
M:75K=6D@<F5I:V%L:6YG87,@)V1O;7AM;"<@4$A0(&UO9'5L:7,B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R
M964@9F]R(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@;F5P879Y
M:V\@<W5K=7)T:2!N875J;R!834P@;65D_FEO(&]B:F5K='5I("5S(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0W"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<
M(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(&YE<&%V>6MO(&GP=')I;G1I
M("5S(%PB)7-<(CH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C0W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE
M('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B
M"FUS9W-T<B`B2&]R9&4O2V]L86(Z(&YE<&%V>6MO(&=A=71I($U)344@240@
M9&%L:6%I("5S('1I<&\B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$Q.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E
M+TMO;&%B.B!N97!A=GEK;R!S=7-I;F-H<F]N:7IU;W1I("5S(%PB)7-<(CH@
M)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$S,S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O
M;FES92!S:&%R97,Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!N97!A=GEK
M;R!S=7-I;F-H<F]N:7IU;W1I(&5L96UE;G3X.B`E<R(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R(")(;W)D
M92]+;VQA8CH@;F7^:6YO;6%S(&5L96UE;G1A<R!<(B5S7"(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(
M;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B2&]R:7IO;G1A;&D@;&EN:6IA(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM
M<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(DAO<FEZ;VYT86QU
M<R!T87)P87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R(")(;W)I>F]N
M=&%L:6%I.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_
M("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B2V%I<"#H:6$@<&%T96MO=&4_
M("A0<F%N9?!K:71E(2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS
M('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")+:65K('-T=6QP
M96QI^"!N;W)I=&4@<W5J=6YG=&D_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@
M87)E('1H97)E/R(*;7-G<W1R(")+:65K(&QA=6OX("AS='5L<&5L:?@I('1E
M;B!Y<F$_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@
M;&EK92!T;R!M97)G93\B"FUS9W-T<B`B2VEE:R!E:6QUZ&GX(&YO<FET92!S
M=6IU;F=T:3\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C,P"FUS9VED(")(=6UI9&ET>2(*;7-G
M<W1R(")$<NMG;G5M87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C4Y"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(D1RZV=N=6UA<SH@
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES
M=',B"FUS9W-T<B`B2G5M;W)E<VMO<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B
M2'5N9V%R>2(*;7-G<W1R(")696YG<FEJ82(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER=7,N<&AP.C$W,B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q
M;"YP:'`Z,C,U"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C
M<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DYE<&%V>6MO('-U:W5R=&D@
M24U!4"!P8?!T;R!DZ_YU=.MS.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP
M:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE
M=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DYE<&%V>6MO(&GP=')I;G1I($E-
M05`@<&'P=&\@9.O^=73K<SH@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP
M.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@
M8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(").97!A=GEK;R!N=7-T871Y
M=&D@24U!4"!P8?!T;R!DZ_YU=.MS(&1Y9/YI;SH@)7,B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S$V"FUS9VED("))4"!!9&1R97-S(@IM<V=S
M='(@(DE0(&%D<F5S87,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S
M:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(DYE<&%V>6MO(&=A=71I($E0(&%D<F5S;RXB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S
M(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("))4"!A
M9')E<V%S(&YE=&5I<VEN9V%M92!#2412(&)L;VME+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B
M25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R("))4"!U_G)A:VEN=&%S
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@
M(E_!=&5R<'1I(&5I;'5TYB!V:7+P=6IE(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED
M("))8V5L86YD(@IM<V=S='(@(DES;&%N9&EJ82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-S8*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B5&EK
M('!I:W1O9W)A;6]S(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T
M<B`B)7,@;G5S=&%T>6UA:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-S<*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R(")0:6MT;V=R86UO
M<R!S=2!T96MS='4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DP"FUS
M9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(D%P<F'P;R!P879A9&EN
M:6UA<SHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU
M.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE
M9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*
M;7-G<W1R(")*96D@;F5G86QI=&4@<&5R<VMA:71Y=&D@\&EO(&QA:?!K;RP@
M)7,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U-0IM<V=I9"`B(@HB
M268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP
M;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T
M=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<S"FUS9VED("(B
M"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I
M;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D
M(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@HB2F5I9W4@;6%T;W1E(/!I
MX"#^:6YU=.8@=FEE=&]J('!A=F5I:W-LZVQI;RP@:W5RX2!N;W)I=&4@X6ME
M;'1I+"!T86D@2OMS^"`B"B)N87+P>6MLZR!N96=A;&D@:F\@871V86EZ9'5O
M=&DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R
M(")0879E:6MS;.ML:6\@<&5R_FG[<F$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!5
M4DPB"FUS9W-T<B`B4&%V96EK<VSK;&EO(%523"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I
M9"`B26UA9V4@55),.B(*;7-G<W1R(")0879E:6MS;.ML:6\@55),.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(E!A
M=F5I:W-LZVQI<R!I\"!G86QE<FEJ;W,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM
M86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B4&%V96EK<VSK;&ES(&GP(&=A
M;&5R:6IO<SHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Q"FUS
M9VED("));6%G92!U<&QO860B"FUS9W-T<B`B4&%V96EK<VSK;&EO(.%KZVQI
M;6%S(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E
M<R(*;7-G<W1R(")686EZ9&%I(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF
M;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHW"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0L(%-T97`@)60B
M"FUS9W-T<B`BP6OK;&EM87,L("5D(/YI;F=S;FES(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP
M;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(DQA=6MA<R#A:V5L=&%S.B`E<R(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R
M=&5D(&9I96QD<SHB"FUS9W-T<B`BP6ME;'1I(&QA=6MA:3HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*
M;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(L%?=&5R<'1I(&5I
M;'5TYB!A<&'H:6]J92(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]Z:7`N<&AP.C$S-0IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I
M=F5N+B(*;7-G<W1R(").971E:7-I;F=A<R!V96EK<VUO(&MO9&%S+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R
M"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*
M;7-G<W1R(").971E:7-I;F=A<R!V87)T;W1O:F\@=F%R9&%S(&ER+V%R8F$@
M<VQA<'1A_F]D:7,N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@
M861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES
M=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB
M3F5I=&5I<VEN9V%S('9A<G1O=&]J;R!V87)D87,@87)B82!A;'1E<FYA='EV
M=7,@96PN('!A\'1O(&%D<F5S87,N($)A;F1Y:VET92`B"B)D87(@:V%R=.`@
M87)B82!S=7-I<VEE:VET92!S=2!S879O(&%D;6EN:7-T<F%T;W)I=6UI(&IE
M:6=U(')E:6MA;&EN9V$@(@HB=&]L97-NZR!P86=A;&)A+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN
M8W)E87-E($EN9&5N="(*;7-G<W1R(")0861I9&EN=&D@871I=')A=6MI;>`B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#$*;7-G:60@(DEN9&EA(@IM<V=S='(@(DEN9&EJ82(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C4T('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S
M(@IM<V=S='(@(DEN9&EV:61U86S[<R!V87)T;W1O:F%I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B26YD;VYE>FEJ82(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G
M:60@(DEN9F\B"FUS9W-T<B`B26YF;W)M86-I:F$B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C4W"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R
M("));F9O<FUA8VEJ82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS,S`*(RP@9G5Z>GD*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A
M=F%I;&%B;&4N(@IM<V=S='(@(DYU<W1A='EM^"!NZW)A+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM
M<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`BP71R875K=&D@
M<W1U;'!E;.$@7V1E\&ENZVIE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E<G0@
M26UA9V4B"FUS9W-T<B`BP71E<G!T:2!P879E:6MS;.MLX2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN
M<V5R="!486)L92(*;7-G<W1R("+!=&5R<'1I(&QE;G1E;.8B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("))
M;G-E<G0@5V5B($QI;FLB"FUS9W-T<B`BP71E<G!T:2!N=6]R;V3@(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,T"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`BP71E
M<G!T:2!S='5L<&5LX2!?:V%I<NMJ92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T
M(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B
MP71E<G!T:2!N875JX"!S='5L<&5LX2!E<V%M;R!S='5L<&5L:6\@9&7P:6[K
M:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E
M('1H92!C=7)R96YT(&]N92(*;7-G<W1R("+!=&5R<'1I(&YA=6K@('-T=6QP
M96SA(&5S86UO('-T=6QP96QI;R!K86ERZVIE(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("))
M;G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R
M("+!=&5R<'1I(&YA=6K@(&5I;'5TYB!E<V%M;W,@96EL=73K<R!A<&'H:6]J
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE
M(&-U<G)E;G0@;VYE(@IM<V=S='(@(L%T97)P=&D@;F%U:N`@96EL=73F(&5S
M86UO<R!E:6QU=.MS('9I<O!U:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A
M('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(L%T
M97)P=&D@<&%R86=R86;@(&5L96UE;G1O(&%P8>AI;VIE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS
M9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO
M9&4B"FUS9W-T<B`BP71E<G!T:2!P87)A9W)A9^`@96QE;65N=&\@=FER\'5J
M92(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@
M86QT97)N871E('1E;7!L871E(@IM<V=S='(@(L%T97)P=&D@86QT97)N871Y
M=O@@\&%B;&]NX"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,SD*;7-G
M:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@
M<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("+!<F'P>6MI=&4@
M96PN('!A\'1O(&%D<F5SX"P@X2!K=7+A(&YO<FET92!G875T:2!N875JX"!S
M;&%P=&'^;V3A.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM
M<V=S='(@(L%T97)P=&D@8V5LYB!P;R!T;R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R
M="!C96QL(&)E9F]R92(*;7-G<W1R("+!=&5R<'1I(&-E;.8@<')I9?`@=&%I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R("+!
M=&5R<'1I('-T=6QP96SA(&1E\&ENZVIE(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T
M(&-O;'5M;B!B969O<F4B"FUS9W-T<B`BP71E<G!T:2!S='5L<&5LX2!K86ER
MZVIE(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.3`*;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R("+!=&5R<'1I(&QA
M:?!K=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B
M"FUS9W-T<B`BP71E<G!T:2!P87)A9W)A9N`@<&\@=&\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G
M:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(L%T97)P=&D@
M<&%R86=R86;@('!R:67P('1A:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@
M869T97(B"FUS9W-T<B`BP71E<G!T:2!E:6QU=.8@<&\@=&\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS
M9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R("+!=&5R<'1I(&5I;'5T
MYB!P<FEE\"!T86DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,P"FUS
M9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I
M='D@<75E<W1I;VXZ(@IM<V=S='(@(L%R8?!Y:VET92!R96EK:6%MX"!A='-A
M:WEMX"#A(&ML875S:6W@('9I<O!U:F4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS97)T+TUO9&EF
M>2!);6%G92(*;7-G<W1R("+!=&5R<'1I+W)E9&%G=6]T:2!P879E:6MS;.ML
MX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R("+!=&5R<'1I
M+U)E9&%G=6]T:2!N=6]R;V3@(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C
M<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S
M='(@(D1I<W1R:6)U8VEJ;W,@<^!R8?!U:2!N=7-I^'-T:2!N977^=&5N:V$@
M:W)E9&ET;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS
M9W-T<B`B3F5U_G1E;FMA(&MR961I=&\N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3`W-0IM<V=I9"`B26YT96=E<B(*;7-G<W1R(")3:V%IZ&EU
M<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,S,*;7-G:60@(DEN
M=&5G97(@;&ES="(*;7-G<W1R(")3:V%IZ&GX('/@<F'P87,B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G
M:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@
M(DYE=&5I<VEN9V%S(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$W,`HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,#$*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C$P"B,L(&9U>GIY"FUS
M9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@(DYE=&5I<VEN9VD@=6YI
M:V]D;R!D=6]M96YY<RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T
M"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R(").971E:7-I
M;F=A<R!M;V1U;&ES+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB
M"FUS9W-T<B`B3F5T96ES:6YG87,@240N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B
M;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*
M;7-G<W1R("+!=F5S=&D@;F5T96ES:6YG:2!D=6]M96YY<RXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G
M:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`B3F5T
M96ES:6YG87,@861R97-A<RXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O9&)X+G!H<#HX,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O9&)X+G!H<#HQ,#`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+V1B>"YP:'`Z,C(P"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S
M='(@(DYE=&5I<VEN9V%S(&9A:6QO(&9O<FUA=&%S(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$W-PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI
M9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B3F5T96ES:6YG87,@;6]D=6QI<RXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<Q"B,L(&9U>GIY
M"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(").
M971E:7-I;F=A<R!M;V1U;&ES+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?
M='EP92XB"FUS9W-T<B`B3F5T96ES:6YG87,@;7-G7W1Y<&4N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"FUS
M9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R(").971E
M:7-I;F=A<R!A<F)A(&[K<F$@87!I7VED+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI
M9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(E!A<F%M971R86D@
M;F5T96ES:6YG:2!A<F)A(&KX(&[K<F$N(@H*(SH@861M:6XO<&5R;7,O861D
M8VAI;&0N<&AP.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N
M+B(*;7-G<W1R(").971E:7-I;F=O<R!P879E;&1I;6]S('1E:7/K<RXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<S"B,L(&9U>GIY"FUS
M9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(DYE=&5I<VEN9V]S
M('!A=F5L9&EM;W,@=&5I<^MS+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-S4*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<')O9'5C="!C
M;V1E+B(*;7-G<W1R(").971E:7-I;F=A<R!P<F]T;VMO;&%S+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM
M<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B3F5T96ES:6YG87,@
M<')O=&]K;VQA<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HX,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I
M<&EE;G0Z(%PB)7-<(B(*;7-G<W1R(").971E:7-I;F=A<R!G87;K:F%S.B`G
M)7,G(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,#<V(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(V,@IM<V=I9"`B26YV86QI9"!S:&%R
M92!O8FIE8W0B"FUS9W-T<B`B3F5T96ES:6YG87,@;V)J96MT87,B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*
M;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(DYE=&5I
M<VEN9V%S('-I=6YTZVIO(&%D<F5S87,N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED
M('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B3F5T96ES:6YG:2!U;FEK;V1O(&1U
M;VUE;GES+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3<*;7-G
M:60@(DEN=F5N=&]R>2(*;7-G<W1R("));G9E;G1O<FEU<R(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-SD*(RP@9G5Z>GD*
M;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B4&5R:V5L=&D@<&%S
M:7)I;FMI;>`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B27-L86UI\&MA($ER86YO(%)E<W!U8FQI
M:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T<B`B27)A:V%S
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@(D%I<FEJ
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))
M<VQE(&]F($UA;B(*;7-G<W1R(")-96YO('-A;&$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@
M5"U3=&]R;7,B"FUS9W-T<B`B27IO;&EU;W1O<R!4+6%U9')O<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,`IM<V=I9"`B27-R865L(@IM<V=S='(@(DEZ<F%E;&ES(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C4*;7-G:60@(DES
M<W5E<B(*;7-G<W1R("))\&1A=NMJ87,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R
M(")+=7)S>79A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B271A;'DB"FUS9W-T
M<B`B271A;&EJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G
M<W1R(")*86UA:6MA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B4V%U<VES(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@S"FUS9VED(")*87!A;B(*;7-G<W1R(")*87!O;FEJ82(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")*87!A;F5S92`H
M25-/+3(P,C(M2E`I(@IM<V=S='(@(DIA<&]N:?!K82`H25-/+3(P,C(M2E`I
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*;7-G:60@(B(*
M(DIA=F%S8W)I<'0@:&%S(&)E96X@9&ES86)L960@;VX@>6]U<B!B<F]W<V5R
M(&%N9"!T:&ES('!A9V4@;6%Y(&YO="!B92`B"B)D:7-P;&%Y:6YG(&-O<G)E
M8W1L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R(")$_F5R<VES(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B2F]R9&%N:6IA(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@
M(DIU;'DB"FUS9W-T<B`B3&EE<&$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R(")":7+^
M96QI<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B4&EL;F%I(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(DQY9VEU;W1I
M(&-E;G1R92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B
M3'EG=6]T:2!P:6QN86DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM
M<V=S='(@(DQY9VEU;W1I(&MA:7+K:F4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF
M>2!2:6=H="(*;7-G<W1R("),>6=I=6]T:2!D9?!I;NMJ92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R(")+87IA:W-T86YA<R(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-C0*
M;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(DGP<V%U9V]T:2!O<FEG
M:6YA;.`_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R(")+
M96YI:F$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U"FUS
M9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(DYE<&%V>6MO('!R:7-I:G5N9W1I('!R:64@2V5R8F5R;W,@
M<V5R=F5R:6\N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED
M(")+97)N96P@3F5W8FEE<R(*;7-G<W1R(")"<F%N9'5O;&EO(&YA=6IO:V%I
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED
M(")+97D@0W)E871I;VXB"FUS9W-T<B`B4F%K=&\@:_MR:6UA<R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I
M;F=E<G!R:6YT(@IM<V=S='(@(E)A:W1O(&%T<W!A=61A<R(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T
M:"(*;7-G<W1R(")286MT;R!I;&=I<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B4F%K
M=&\@=&EP87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4Y.`IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(E)A:W1O('!A;F%U9&]J
M:6UA<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM
M<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+B(*;7-G<W1R(")286MT87,@:F%U('ER82!V:67P^&KX(')A:W3X('-E
M<G9E<GEJ92XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@
M(DMI9',B"FUS9W-T<B`B5F%I:V%I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+
M:7)I8F%T:2(*;7-G<W1R(")+:7)I8F%T:7,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G
M:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(D1E;6]K<F%T:6[K($MO<NMJ;W,@3&EA=61I97,@4F5S<'5B;&EK
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(DMO<NMJ;W,@4F5S<'5B;&EK82(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@X"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B2V]R
MZVII971I\&MA("A%54,M2U(I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A
M:70B"FUS9W-T<B`B2W5V96ET87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY
M<F=Y>G-T86XB"FUS9W-T<B`B2VER9VEZ:6IA(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@(E])\&3K
M<W1Y;6%S(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I
M9"`B3&%N9W5A9V4B"FUS9W-T<B`B2V%L8F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G
M:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@
M(DQA;W-O($1E;6]K<F%T:6[K($QI875D:65S(%)E<W!U8FQI:V$B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T
M<B`B06YT<F$@<'5SZR(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-@HC
M+"!F=7IZ>0IM<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B
M4&%K96ES=&D@<VQA<'1A_F]DX2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX
M-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*
M;7-G<W1R(")087-K=71I;FES(&ME='9I<G1I<R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,34Q"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(D%T
M;F%U:FEN=&$Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L
M('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(E!A
M<VMU=&EN:7,@<')I<VEJ=6YG:6UA<SH@)7,B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HW,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I
M;CH@)7,@9G)O;2`E<R(*;7-G<W1R(")087-K=71I;FES('!R:7-I:G5N9VEM
M87,Z("5S(&GP(&%D<F5S;R`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.C<Q-@IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B4')I
M<VEJ=6YGZW1E('!I<FW@(&MA<G3@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),
M871V:6$B"FUS9W-T<B`B3&%T=FEJ82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(E1E:7/K(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"FUS9VED
M("),87EO=70B"FUS9W-T<B`B2?!DZW-T>6UA<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M
M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B2F5I9W4@;F5N;W)I=&4@;F5N
M875D;W1I(&MR8?!T^"P@<&%L:6MI=&4@='7PZ&G@(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W
M"FUS9VED("),96)A;F]N(@IM<V=S='(@(DQI8F%N87,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@
M(DQE9G0B"FUS9W-T<B`B2V%I<NMJ92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,Q,3D*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(DMA:7)I
M;VII(&%N=')A\'3K(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q
M-0IM<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`B2V%I<FEO<VEO<R!R96EK
M\&WK<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("),
M97-O=&%S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L
M(&9U>GIY"FUS9VED("),979E;"(*;7-G<W1R(")-96ELZR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R("),:6)E<FEJ82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R
M("),:6)I:F]S($%R86+X($5M>7)A=&%I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED
M("),:65C:'1E;G-T96EN(@IM<V=S='(@(DQI8VAT96[P=&5I;F%S(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@
M(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B4VUU;&MU<R!L:65T=7,B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@IM<V=I9"`B
M3&EG:'0@4F%I;B(*;7-G<W1R(").961I9&5L:7,@;&EE='5S(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI
M9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B3F5D:61E;&ES(&QI971U<R!R>71E
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*
M;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R(").961I9&5L:7,@;&EE
M='5S('9A:V%R92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R(").
M961I9&5LZR!L:?MT:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B
M"FUS9W-T<B`B3F5D:61E;&ES(&QI971U<R!S=2!P97)K^VYI:F$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B
M3&EG:'0@4VYO=R(*;7-G<W1R(").961I9&5L:7,@<VYI96=A<R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),
M:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R(").961I9&5LZR#P;&%P9')I8F$B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K
M(@IM<V=S='(@(DQI;65R:6MA<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X,30*;7-G:60@(DQI;FLB"FUS9W-T<B`B3G5O<F]D82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(DYU;W)O9&$@X3HB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK
M('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D
M:7-P;&%Y:6YG(@IM<V=S='(@(E!A9&%R>71I(&5L+B!P8?!T;R!A9')E<^`@
M;G5O<F]D82#A(&QA:?!K;R!R8?!Y;6\@<'5S;&%PX2(*"B,Z(&9R86UE=V]R
M:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#,*;7-G:60@
M(DQI;FMS(@IM<V=S='(@(DYU;W)O9&]S(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B3&EN=7@@
M;&%I;>MS(/YI;G5TZW,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@
M9F]L9&5R(@IM<V=S='(@(E)O9'ET:2`M('9A<G1O=&]J87,@9V%L:2!M871Y
M=&D@:V%T86QO9V\@='5R:6[A(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S
M,PIM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B4F]D>71I(&1U;VUE
M;O@@8F%Z:?@@<^!R8?#@(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z
M-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B4F]D>71I('!A
M9V%L8F]S('1E;6%S(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM<V=I
M9"`B3&ES="!486)L97,B"FUS9W-T<B`B4F]D>71I(&QE;G1E;&GX('/@<F'P
MX"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT"FUS
M9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B2V]N9F5R96YC:6IO<R!A<F-H
M>79A<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3@Y
M"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`B2V]N9F5R96YC:6IO<R!P86=A
M;&)A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.38*
M;7-G:60@(DQI<W0M260B"FUS9W-T<B`B2V]N9F5R96YC:6IO<R!)1"(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),
M:7-T+4]W;F5R(@IM<V=S='(@(DMO;F9E<F5N8VEJ;W,@<V%V:6YI;FMA<R(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED
M("),:7-T+5!O<W0B"FUS9W-T<B`B4F'P>71I(.$@:V]N9F5R96YC:6K@(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@
M(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(E!R:7-I:G5N9W1I('!R:64@:V]N
M9F5R96YC:6IO<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(D%T<VEJ
M=6YG=&D@;G5O(&MO;F9E<F5N8VEJ;W,B"@HC.B!A9&UI;B]S97-S:6]N<RYP
M:'`Z-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@<V5S
M<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R(")687)T;W1O:O@@<^!R8?!A<R!U
M_F1R875S=&%S+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!F86EL960Z("5S
M(@IM<V=S='(@(E9A<G1O=&]J^"!SX')A\&%S('7^9')A=7-T87,N(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T
M:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")687)T;W1O:O@@<^!R
M8?!A<R!U_F1R875S=&%S+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("),:71E<F%T^W)A(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@Y"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B3&EE='5V82(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.#,*
M;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B2W)A=6YA+BXN(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,0IM<V=I9"`B3&]C86P@=&EM
M93H@(@IM<V=S='(@(E9I971I;FES(&QA:6MA<SH@(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@S"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T
M<B`B3&]K86SK(&ER(&QA:6MA<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3<Q(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV
M-`HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HV-0IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B5FEE=&$B"@HC.B!L
M;V=I;BYP:'`Z,3<R('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.3$@
M=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G
M:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP
M"FUS9VED("),;V<@:6XB"FUS9W-T<B`B4')I<VEJ=6YG=&DB"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V
M:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-I9&5B87(N<&AP.C$X-0IM<V=I9"`B3&]G(&]U="(*;7-G<W1R(")!
M='-I:G5N9W1I(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"B,L(&9U
M>GIY"FUS9VED("),;V=I;B(*;7-G<W1R(")0<FES:6IU;F=T:2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G:60@(DQO9VEN(%1A<VMS(@IM
M<V=S='(@(E!R:7-I:G5N9VEM;R!D87)B86DB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HY.38*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO
M=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T
M;'DN(@IM<V=S='(@(B(*(E!R:7-I:G5N9W1I(&YE<&%V>6MO+B!.971E:7-I
M;F=A<R!*^W/X(&YU<F]D>71A<R!V87)T;W1O:F\@=F%R9&%S(&ER+V%R("(*
M(G-L87!T8?YO9&ES+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY
M,@IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R(")0<FES:6IU;F=T:2!N
M97!A=GEK;RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8U"FUS
M9VED("),;VYG('1E>'0B"FUS9W-T<B`B26QG87,@=&5K<W1A<R(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R(")-
M96ELZR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8W"FUS9VED("),;W<B"FUS9W-T<B`B3F5S=F%R8G4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS
M9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(DUA_F]S:6]S(&=R
M86EK:?!K;W,@<F%I9.MS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@
M;&5T=&5R<R(*;7-G<W1R(")-8?YO<VEO<R!L;W1Y;FGP:V]S(')A:63K<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B
M36'^:65J:2!R;VWK;FGP:VD@<VMA:>AI86DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G
M:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B3&EU:W-E;6)U<F=A<R(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#`*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S."!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Q"FUS9VED(")-3U1$(@IM<V=S
M='(@(DU/5$0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F
M+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N
M;R!D871A+B(*;7-G<W1R(")0<FEK86)I;G1A;64@35,M5$Y%1B!F86EL92!N
MZW)A(&1U;VWK;O@N(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM
M<V=S='(@(DU31R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T
M<B`B36%K86\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE
M($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R(")-86ME9&]N
M:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@
M(DUA9&%G87-K87)A<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0IM
M<V=I9"`B36%G:6,B"FUS9W-T<B`B36%G:6IA(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C@Q"FUS9VED(")-86EL(@IM<V=S='(@(E!A\'1A<R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C(*;7-G:60@(DUA:6P@
M061M:6XB"FUS9W-T<B`B4&'P=&\@=F%L9'EM87,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@
M(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B4W5K=7)T:2!?;G5O<F]DX"XN+B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L87=I(@IM<V=S='(@(DUA;&%V:7,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(DUA;&%I
M>FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B
M36%L9'EV86DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA;&DB"FUS9W-T<B`B
M36%L:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;'1A(@IM<V=S='(@(DUA
M;'1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ"FUS9VED("(B"B)-
M86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E
M;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T
M:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"B)+871E9V]R:6KX('/@<F'P
M;RP@:W5R:6]M<R!P<FES:VER:6%M:2!O8FIE:W1A:2P@:7(@<W4@:F]M:7,@
M<W5S:6IU<VGX("(*(G-P86QV^"!K96ET:6UA<RXB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U,PIM<V=I9"`B36%P,C0@
M;6%P(@IM<V=S='(@(DUA<#(T(/YE;>ML87!I<R(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#@T"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ,38X"FUS9VED(")-87!1=65S
M="!M87`B"FUS9W-T<B`B36%P475E<W0@_F5MZVQA<&ES(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G<W1R(")+;W9A<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")087)A\'3K(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@
M=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R(")08?YY;>MT:2!K86EP
M('-K86ET>71U<R]N97-K86ET>71U<R(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@
M9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R(")08?YY
M;>MT:2!K:71A:7,@871R:6)U=&%I<R`H<'9Z+B!S=F%R8G4O871S86MY=&$I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S
M='(@(DUA<O!A;&\@<V%L;W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I
M;FEQ=64B"FUS9W-T<B`B36%R=&EN:6MA(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R
M(")3=6IU;F=T:2!L875K86DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA=7)I
M=&%N:6$B"FUS9W-T<B`B36%U<FET86YI:F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G
M:60@(DUA=7)I=&EU<R(*;7-G<W1R(")-875R:6-I:G5S(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED
M(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(DUA:W-I;6%L=7,@:W)E
M9&ET87,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E
M9"XB"FUS9W-T<B`B36%K<VEM86QU<R#^:6YUZ&GX(&1A;&GX(&MI96MI<R!I
M\&5I:W9O=&%S+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`V"FUS9VED
M(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B36%K<RX@=&5M
M<"X@<&%S:RX@,C0@=F%L.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y
M.`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B36%K
M<RX@=&5M<"X@<&%S:RX@-B!V86PZ("(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS
M9VED(")-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R,SD*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(DUA:W-I;6%L
M=7,@:6QG:7,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(D=E9W7^ZR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3<*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B36]J;W3K(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R
M(")-961I8VEN82(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI
M;F,Z,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B3F%R:6%I(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,W.`IM<V=I9"`B365N=2!M;V1E.B(*;7-G
M<W1R(")-96YI=2!R9?YI;6%S.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS
M(@IM<V=S='(@(E-U:G5N9W1I(&-E;&5S(@H*(SH@9G)A;65W;W)K+TYO=&EF
M:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A
M9V4B"FUS9W-T<B`BWFEN=73K(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C
M8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@
M;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B),86GP:V%S('!A=FER
M=&EN=&%S+"!T8>AI874@;F5P871V:7)T:6YT87,@<&%S:7)A\&EU<VEO(&%S
M;65N<R!S97)T:69I:V%T87,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED(")-97-S86=E(&5X<&ER
M960N(@IM<V=S='(@(MYI;G5TZR!N96GP<VGX<W1A+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-C`*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R("+>:6YU=.MS('1I<&%S
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T
M:&5R(@IM<V=S='(@(D]R;R!S86QY9V]S(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B3W)O('/@;'EG^"!B;&]K;R!NZW)A+B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3$R"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA
M8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R(")/<F\@<^!L>6?X(&)L;VMO(&[K<F$N($%D;6EN
M:7-T<F%T;W)I=6D@:?!S:?AS=&%S(&1E=&%L=7,@87!R8?!Y;6%S+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DUE=&%R
M1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`B
M365T;V1A<R(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z.#$@
M9G)A;65W;W)K+U)00R]24$,O<V]A<"YP:'`Z,3$W"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM
M<V=S='(@(DUE=&]D87,@)R5S)R!N96%P<F'P>71A<R(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(DUE
M=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<T(&QI8B]";&]C
M:R]M971A<BYP:'`Z-S4*;7-G:60@(DUE=')I8R(*;7-G<W1R(")-871A:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S='(@(DUE:W-I:V$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D(%-T
M871E<R!O9B(*;7-G<W1R(")-:6MR;VYE>FEJ;W,@1F5D97)A8VENZW,@5F%L
M<W1I:F]S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<V"FUS9VED(")-:61D;&4B"FUS9W-T<B`B5FED=7)Y:F4B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM
M<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(DU)344@=&EP87,B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,Q,`IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H
M;W5R<SH@(@IM<V=S='(@(DUI;BX@=&5M<"X@<&%S:RX@,C0@=F%L.B`B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B36EN('1E;7`@;&%S
M="`V(&AO=7)S.B`B"FUS9W-T<B`B36EN+B!T96UP+B!P87-K+B`V(&AO=7)S
M.B`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0S.0IM<V=I
M9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C,T"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B071S<&EN9'ES(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL86YE
M;W5S(@IM<V=S='(@(DMI=&]S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@
M<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(DYE<F%S=&%S(%!%05(@
M2%144%]297%U97-T('!A:V5T87,N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$Q-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@
M:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H
M:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*(DYU<W1A='EM^"!NZW)A
M+B!*96EG=2!N;W)I=&4@;F%U9&]T:2#PX2!M;V1U;.$L('1U<FET92!JX2!S
M=6MO;F9I9_MR=6]T:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)
M1"XB"FUS9W-T<B`B3NMR82#^:6YU=.MS($E$+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-
M:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R(").
M97)A<W1A<R!R96EK86QI;F=A<R!014%2($UA:6P@<&%K971A<RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*
M;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B3NMR82!S97-I
M:F]S($E$+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(E!I<FTN(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C<T"FUS9VED(")-;V)I;&4@36%I;"(*;7-G
M<W1R(")-;V)I;'5S('!A\'1A<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")-;V1E<F%T92(*;7-G<W1R(")6
M:61U=&EN:7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX.`IM<V=I
M9"`B36]D:69I960@1&%T92(*;7-G<W1R(")2961A9V%V:6UO(&1A=&$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B2V5I<W1I(%523"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<S"FUS9VED
M(")-;V1U;'5S(@IM<V=S='(@(DUO9'5L:7,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G
M:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUO;&1O=F]S(%)E
M<W!U8FQI:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R
M(")-;VYA:V%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G
M<W1R(")-;VYG;VQI:F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-3DT"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R(")-ZVYE<VEA:2!I
M<B!M971A:2(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC
M92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B2V%S(&WK;F5SX2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R(")-;VYS
M97)A=&%S(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R(")-ZVYU;&EO
M(&9A>NMS(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3<R(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(U,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X
M<&5C=&5D("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO
M<F]C8V\B"FUS9W-T<B`B36%R;VMA<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE87(B"FUS
M9W-T<B`B1&%U9VEA=7-I82!G:65D<F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*
M;7-G<W1R(")$875G:6%U<VEA(&%P<VEN875KYB(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N
M;GDB"FUS9W-T<B`B1&%U9VEA=7-I82!S875LZW1A(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`Y"FUS9VED(")-;W9E($1O=VXB
M"FUS9W-T<B`B4&5R:V5L=&D@_F5M:6%U(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z-3$S"FUS9VED(")-;W9E($QE9G0B"FUS9W-T
M<B`B4&5R:V5L=&D@:V%I<FEA=2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C4Q-PIM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R(")0
M97)K96QT:2!D9?!I;FEA=2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C4P-0IM<V=I9"`B36]V92!5<"(*;7-G<W1R(")097)K96QT
M:2!A=6OPZ&EA=2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R(")097)KZVQI
M;6%S(/YE;7EN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4R,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-3(T"FUS9VED(")-;W9E('5P(@IM<V=S='(@(E!E<FOK;&EM87,@
M875K\'1Y;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G
M<W1R(")-;WIA;6)I:V%S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$X-`IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S
M='(@(DME;&5T;R!L>6=I^"!I\'-I<VML96ED_FEA;G1I<R!SX')A\&%S(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-34*
M;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,C0R"FUS9VED(")-=6QT:7!L92!S96QE8W1I
M;VXB"FUS9W-T<B`B2V5L971A<R!P87-I<FEN:VEM^"(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT,#`*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T
M<B`B36%N;R!SX'-K86ET82(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR
M.`HC+"!F=7IZ>0IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G
M<W1R("));F9O<FUA8VEJ82!A<&EE($IU<R(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]I;F1E>"YP:'`Z-30*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R(")-86YO
M('!O<G1A;&%S(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C$S-@IM
M<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R(")-86YO('!O<G1A;&\@
M:?!DZW-T>6UA<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G
M<W1R(")-86EN;6%R87,B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I
M;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM
M<V=S='(@(DY%+"!.15-55$E.2U4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3$@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F
M+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R(")687)D87,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B3F%M:6)I:F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(DYA=7)A<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B3F5P86QA<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B3GED97)L86YD
M86DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B
M"FUS9W-T<B`B3GED97)L86YD^"!!;G1I;&%I(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E($)A<V4@
M55),(@IM<V=S='(@(DYE='-C<&%P92!B87II;FES(%523"(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P
M92!#02!2979O8V%T:6]N(%523"(*;7-G<W1R(").971S8W!A92!S97)I9FEK
M871O(&%T\&%U:VEM;R!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*
M;7-G<W1R(").971S8W!A92!S97)T:69I:V%T;R!T96ES:?@@55),(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE
M='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(DYE='-C87!E(&%T;F%U:FEN
M;VUO(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@R"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R(").
M971S8V%P92!A=/!A=6MI;6\@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@
M;F%M92(*;7-G<W1R(").971S8V%P92!34TP@<V5R=F5R:6\@=F%R9&%S(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@
M(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B3F5T<V-A
M<&4@<V5R=&EF:6MA=&\@87!R8?!Y;6%S(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.#`*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC
M871E('1Y<&4B"FUS9W-T<B`B3F5T<V-A<&4@<V5R=&EF:6MA=&\@=&EP87,B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Q"FUS9VED(").971W
M;W)K(@IM<V=S='(@(E1I;FML87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-0HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS9VED(").979E<B(*;7-G<W1R
M(").:65K861A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").97<@0V%L961O;FEA
M(@IM<V=S='(@(DYA=6IO:FD@2V%L961O;FEJ82(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@
M0V%T96=O<GDB"FUS9W-T<B`B3F%U:F$@:V%T96=O<FEJ82(*"B,Z(&9R86UE
M=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX,0HC.B!F<F%M
M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@9G)A
M;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.CDW"B,Z(&9R
M86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O("5S(@IM
M<V=S='(@(E)A\'ET:2!L86GP:^`@*"5S*2(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B3F%U:F%S(&WK;G5L
M:7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS
M9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R(").875J87,@
M=F%R=&]T;VIO('9A<F1A<R`H;F5B^W1I;F%S*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM
M<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B3F%U:F]J:2!:96QA;F1I:F$B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*(RP@9G5Z>GD*
M;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R(")3;&%P=&'^;V1I<R(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*(RP@
M9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S
M='(@(E-L87!T8?YO9/YI86D@='5R:2!S=71A<'1I+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W
M:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B3F%U:F%M92!L86YG92`H7V)L86YK
M*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y"FUS
M9VED(").97=S(@IM<V=S='(@(DYA=6II96YO<R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS,#4*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B
M3F%U:FEE;O@@9W)U<.MS(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI
M;F,Z,34@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,C4*;7-G:60@(DYE>'0B"FUS9W-T<B`B4V5K86YT:7,B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(DYE>'0@-"!0
M:&%S97,B"FUS9W-T<B`B4V5K86YT:2!F87KK(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HS-S(@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HS-S8*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R(")396MA;G1Y
M<R!N=7-T871Y;6%I(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ
M,#,*(RP@9G5Z>GD*;7-G:60@(DYE>'0^(@IM<V=S='(@(E-E:V%N=&ES(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B3FEK87)A
M9W9A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<B(*;7-G<W1R(").:6=E
M<FES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM<V=S='(@(DYI
M9V5R:6IA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,X,`IM
M<V=I9"`B3FEG:'0B"FUS9W-T<B`B3F%K=&ES(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS
M9VED(").:75E(@IM<V=S='(@(DYI=6KK(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B3F\B"FUS9W-T<B`B
M3F4B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G
M:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D
M:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(DYE=?YT96YK82!D=6]M96[X('-K
M:7)T=6WX('!A<F]D>6UU:2XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(N<&AP.C$P-0IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T
M96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B3F5N=7)O9'ET
M82!S=')A=&5G:6IA($E33R!R8?!Y;75I+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T
M8V@@=&5M<&QA=&4N(@IM<V=S='(@(D[K<F$@<W5DZW1I;FEO(/!A8FQO;F\N
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-SD@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C0U"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(V-PIM<V=I9"`B3F\@8FQO8VL@
M97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B3G5R
M;V1Y=&]J92!P;WII8VEJ;VIE(&)L;VMO(&[K<F$B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A<B!N86UE
M('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").
M9>%V963K=&4@:V%L96YD;W)I875S('9A<F1O($U#04P@875T96YT:69I:V%C
M:6IO:F4N(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO
M(&-H86YG92XB"FUS9W-T<B`B4VMI<G1U;?@@;NMR82XB"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@
M8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`BT&EO
M<R!T96ESZW,@;F5G86QI('1U<NMT:2!P;W1E:7-I^"XB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$V-R!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C4P,@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-S,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R("5S+B(*;7-G<W1R(").ZW)A(&EN9F]R;6%C:6IO<R!A
M<&EE("5S(&MO;F9I9_MR86-I:N`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX,C0*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R(").ZW)A(&EN9F]R
M;6%C:6IO<R!A<&EE($944"!61E,@:V]N9FEG^W)A8VEJX"XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8V.0IM<V=I9"`B3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S
M='(@(D[K<F$@:6YF;W)M86-I:F]S(&%P:64@4U%,(%9&4R!K;VYF:6?[<F%C
M:6K@+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,3<*
M;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(D[K<F$@:6YF;W)M86-I:F]S
M(&%P:64@4U%,+49I;&4@5D93(&MO;F9I9_MR86-I:N`N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED
M(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B2W)E9&ET87,@:?!E:6MV;W1A
M<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S
M='(@(DYEX79E<W1A<R!G87;K:F%S+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R
M+T)R;W=S97(N<&AP.C@W-PIM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G
M<W1R(")&86EL87,@;F5N=7-I^'-T87,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G
M<W1R("(E<R!N97)A<W1A<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3(X(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$R,PIM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*
M;7-G<W1R(").96YU<W1A='ET82!V:65T;W;K+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(DYO(&QO8V%T
M:6]N('!R;W9I9&5D+B(*;7-G<W1R(").96YU<W1A='ET82!V:65T;W;K+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R(").9>%R
M8?#K=&4@_FEN=73K<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N
M(@IM<V=S='(@(DYEX7)A\.MT92!V87)D;RXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M
M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B3F7A<F'PZW1E(&YU;65R:6\N(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED(").;R!O9F9E;G-I
M=F4@9F]R='5N97,B"FUS9W-T<B`B3F5R;V1Y=&D@X?YE:63^:6%NZ&GX(&9R
M87II^"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R(").9>%V963K=&4@<VQA<'1A_F]D_FEO($A45%`@875T
M96YT:69I:V%C:6IA:2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N
M<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYEX79E9.MT92!S;&%P=&'^;V3^
M:6\@24U!4"!A=71E;G1I9FEK86-I:F%I+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F7A=F5D
MZW1E('-L87!T8?YO9/YI;R!+97)B97)O<R!A=71E;G1I9FEK86-I:F%I+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<@9G)A;65W;W)K
M+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]P86TN<&AP.C<U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYEX79E9.MT92!S;&%P
M=&'^;V3^:6\@3&]G:6X@875T96YT:69I:V%C:6IA:2XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M(").9>%V963K=&4@<VQA<'1A_F]D_FEO(%!!4U-71"!A=71E;G1I9FEK86-I
M:F%I+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`IM<V=I
M9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B3F7A=F5DZW1E('-L87!T8?YO9/YI;R!334(@875T96YT
M:69I:V%C:6IA:2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C$R.#8*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN
M87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y
M('1O("(*(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*(DYE
MX79E<W1A<R!K96QI87,@:6MI($]P96Y34TP@<&%G<FEN9&EN:?@@9F%I;/@N
M($]P96Y34TP@<F5I:V%L:6YG82!D87)B=6D@<W4@(@HB4$M#4R`Q,B!D=6]M
M96YI;6ES+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC
M.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`B3F5P871V
M:7)T:6YT^"!R96=I<W1R86-I:O@@;NMR82XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z-S4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").;R!Q
M=6]T82!S970N(@IM<V=S='(@(DYE;G5R;V1Y=&$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S"FUS9VED(").
M;R!R=6QE<R(*;7-G<W1R(").96YA=61O=&D@<VMI<G1U:_@B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#D*(RP@9G5Z>GD*;7-G:60@(DYO
M('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@(DYEX7)A\.MT92!N=6UE
M<FEO+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(D[K('9I96YO
M:F4@<'5SZVIE(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#,*
M(RP@9G5Z>GD*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R(").ZR!V:65N
M;VIE('!U<^MJ92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M,S@*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O
M<B!C86-H92XB"FUS9W-T<B`B4W!A<G1I;FEM=6D@;NMR82!L86EK:6YO:F\@
M:V%T86QO9V\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HR,C$*;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R
M9"!S96YT+B(*;7-G<W1R(")687)T;W1O:F\@=F%R9&%S(&ER+V%R8F$@<VQA
M<'1A_F]D:7,@;F5N=7-I^'-T87,N(@H*(SH@9G)A;65W;W)K+U)00R]24$,O
M>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E='5R
M;F5D(@IM<V=S='(@(E1E:7-I;F?X(%A-3"!D=6]M96[X(&[K<F$B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3<Q"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY.#$*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY,@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`P.0IM<V=I9"`B
M3F\@=F%L=65S(@IM<V=S='(@(D[K<F$@<F5I:_!M:?@B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN
M(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B2V]N9FEG^W)A8VEN:6%M92!F86EL92!NZW)A('9E
M<G-I:F]S+B!097)G96YE<G5O:VET92!N=7-T871Y;75S+B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@
M:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(DMO;F9I9_MR86-I;FEA;64@9F%I;&4@;NMR82!V97)S
M:6IO<RX@4&5R9V5N97)U;VMI=&4@;G5S=&%T>6UU<RXB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O
M<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"FUS9VED(").;VYE(@IM<V=S
M='(@(DYE;G5R;V1Y=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM
M<V=S='(@(D[K<F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I
M9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`BT&EA=7+K<R`H25-/
M+3@X-3DM,3`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N
M9"(*;7-G<W1R(").;W)F;VQK;R!S86QO<R(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N
M($AE;6ES<&AE<F4B"FUS9W-T<B`BT&EA=7)I;NL@:&5M:7-F97)A(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS
M9W-T<B`BT&EA=7)I;NMS($UA<FEJ86[X('-A;&]S(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW
M"FUS9VED(").;W)W87DB"FUS9W-T<B`B3F]R=F5G:6IA(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!!9G1E
M<B(*;7-G<W1R(").92!P;R!T;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C,Y"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(DYE
M('!R:67P('1A:2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0P
M.`IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(DYE(&MA=&%L;V=A
M<R(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z
M-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.30*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M
M96YT960N(@IM<V=S='(@(DYE<F5A;&EZ=6]T82XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X"FUS9VED(").;W0@<V5T
M(@IM<V=S='(@(DYE;G5R;V1Y=&$B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA
M;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T,PHC.B!F<F%M97=O<FLO4V5S
M<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$U.`HC.B!F<F%M97=O
M<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W,PHC.B!F
M<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X
M-PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N
M<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DP"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HR,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S,`HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C0X(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HR-C4*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X,2!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z,CDW"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS
M,3(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,R.0HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z,S8R(&9R86UE=V]R:R]61E,O5D93+G!H<#HT,C(*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C4P,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M-3<P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU.#<@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C8V-0IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B
M3F5P86QA:6MO;6%S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$W.`IM<V=I9"`B3F]T97,B"FUS
M9W-T<B`B5?YR8?!A:2(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H
M<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S
M='(@(D[K<F$@:^`@<&5R_FG[<NMT:2P@96EK:71E(&%T9V%L+B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").
M;W9E;6)E<B(*;7-G<W1R("),87!K<FET:7,B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,#0V"FUS9VED(").=6UB97(B"FUS9W-T<B`B3G5M97)I
M<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C4*;7-G:60@(DYU
M;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(E-I;6)O;&GX('-K86GH:75S
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#(S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$T-#4@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(E-T=6QP96QI
M^"!S:V%IZ&EU<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C<@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#0S('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R(")%
M:6QUZ&GX('-K86GH:75S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I
M9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S
M='(@(DYEX79E<W1I(&1I<W1R:6)U8VEJ;W,@<^!R8?!O(&%T;F%U:FEN:6UO
M('-K86GH:6%I+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`B3TLB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE
M8W0B"FUS9W-T<B`B3V)J96MT87,B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`B3V)J
M96MT;R!S879I;FEN:V%S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3$P-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B0?!T=6YT86EN:7,B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B
M3V-T;V)E<B(*;7-G<W1R(")3<&%L:7,B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(MYI875R
M=6UO(&9I;'1R87,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(V
M"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B3V9I<V%S(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S
M=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@HC+"!F=7IZ>0IM<V=I9"`B3VQD
M('!A<W-W;W)D(@IM<V=S='(@(E-L87!T8?YO9&ES(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C0V"B,L(&9U>GIY"FUS9VED(")/;&0@<&%S
M<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@(E-L87!T8?YO9&ES(&YE
M=&5I<VEN9V%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@
M(D]M86YA<R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E
M9"!F;VQD97)S+B(*;7-G<W1R(")+871A;&]G^"!D86QI:FEMX'-I('!A;&%I
M:V\@=&EK($E-05`@<V5R=F5R:6%I+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T
M<B`B5&EK(.'^96ED_FEA;NAI;W,@9G)A>NMS(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q
M"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S
M='(@(DQE:63^:6%M87,@=&EK('9I96YA<R!E;"X@<&'P=&\@861R97-A<RXB
M"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N
M;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N
M9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H
M87)E(@IM<V=S='(@(B(*(D5L96UE;G1O('-A=FEN:6YK;R!T96ES97,@9V%L
M:2!K96ES=&D@=&EK(&IO('-A=FEN:6YK87,@87)B82!S:7-T96UO<R`B"B)A
M9&UI;FES=')A=&]R:75S(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,S4*
M;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D%T:61A<GET
M:2!N875J86UE(&QA;F=E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E
M>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I
M;F1O=R(*;7-G<W1R(")!=&ED87)Y=&D@\&G@(&YU;W)O9.`@;F%U:F%M92!L
M86YG92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E
M<F%T:6YG(%-Y<W1E;2(*;7-G<W1R(")/<')A8VENZW,@<VES=&5M;W,B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I
M;VYS(@IM<V=S='(@(DYU<W1A='EM86DB"@HC.B!S97)V:6-E<R]P<F5F<RYP
M:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B)7,@;G5S=&%T>6UA
M:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G<W1R(")3=7+[\&EU;W1A<R!S
MX')A\&%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-C<*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R(")/<F=A;FEZ86-I:F$B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I
M9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R(")0861A;&EN>7,B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,R"FUS9VED(")/<F=A;FEZ
M:6YG(@IM<V=S='(@(E-I<W1E;6EN:6UA<R(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T
M92(*;7-G<W1R(")/<FEG:6YA;'5S(&%P;&EK86-I:F]S(/!A8FQO;F%S(@H*
M(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R(")/<FEG:6YA
M;/AS(/!A8FQO;F%I("5S.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE
M<B(*;7-G<W1R(")+:71A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(R"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,S$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T
M,0IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B2VET82!I;F9O
M<FUA8VEJ82(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G
M:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(E-A=FEN:6YI:V\@=&5I
M<^MS(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y"FUS9VED
M(")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T
M<B`B3NMR82!004T@875T96YT:69I:V%C:6IO<R!M96-H86YI>FUO+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM
M<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R-S,*;7-G:60@(E!'4"!$:6=I
M=&%L(%-I9VYA='5R92(*;7-G<W1R(")01U`@<VMA:71M96YI;FES('!A<F'P
M87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S$Y"FUS
M9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B4$=0('7^:V]D=6]T
M82!I;F9O<FUA8VEJ82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$S-S$*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(E!'4"!V
M:67P87-I<R!R86MT87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HQ,S4S"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM
M<V=S='(@(E!'4"!P87-I<F'P>71I+W7^:V]D=6]T:2!D=6]M96YY<R(*"B,Z
M(&%D;6EN+W!H<'-H96QL+G!H<#HV.`IM<V=I9"`B4$A0($-O9&4B"FUS9W-T
M<B`B4$A0(&MO9&%S(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED
M(")02%`@4VAE;&PB"FUS9W-T<B`B4$A0($-,22(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,:6=H="!2
M86EN(@IM<V=S='(@(E!-(&QE;F=V87,@;&EE='5S(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%-H;W=E
M<G,B"FUS9W-T<B`B4$T@;&G[=&ES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,SD*(RP@9G5Z>GD*;7-G:60@(E!-(%-N;W<B
M"FUS9W-T<B`B4$T@;&G[=&ES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#`*(RP@9G5Z>GD*;7-G:60@(E!-(%-N;W<@4VAO
M=V5R<R(*;7-G<W1R(")0^V=A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-U;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I
M9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B4$T@5"UA=61R82(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I
M<R!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I
M9"`B4%](4"!3:&5L;"(*;7-G<W1R(")07TA0($-,22(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@
M(E!A9&1I;F<B"FUS9W-T<B`B5&%R<&%I(&-E;.MS92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B4&%K:7-T86YA<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(E!A;&%U(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE
M9"(*;7-G<W1R(")5_FEM=&]J:2!086QE<W1I;F]S('1E<FET;W)I:F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G<W1R(")086YA;6$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B
M4&%P=6$@3F%U:F]J:2!'=FENZVIA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B
M4&%R86=U87DB"FUS9W-T<B`B4&%R86=V86IU<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")087)T;'D@0VQO
M=61Y(@IM<V=S='(@(D1A;&EN86D@9&5B97-U;W1A(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q.`HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C<W('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R,PIM<V=I9"`B4&%S<W=O
M<F0B"FUS9W-T<B`B4VQA<'1A_F]D:7,B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S
M<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C$S,C(*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G
M<W1R(")3;&%P=&'^;V1I<R!N971E:7-I;F=A<R(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I
M<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E)!1$E5
M4R!A=71E;G1I9FEK86-I:F%I(')E:6MI82!S;&%P=&'^;V3^:6\N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,PIM<V=I9"`B4&%S<W=O<F0@
M=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B4VQA<'1A_F]D:7,@<W4@<&%T
M=FER=&EN:6UU(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP
M"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`B4VQA<'1A_F]D:7,Z(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D
M.B`B"FUS9W-T<B`B4VQA<'1A_F]D:7,Z("(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M
M=7-T(&UA=&-H+B(*;7-G<W1R(")3;&%P=&'^;V3^:6%I('1U<FD@<W5T87!T
M:2XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S
M=&4B"FUS9W-T<B`BP6ME;'1I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A
M<F0B"FUS9W-T<B`BP6ME;'1I(&GP(&QA:6MI;F]S:6]S('-A=6=Y:VQO<R`H
M8VQI<&)O87)D*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B2V5L:6%S(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@
M4VEG;G5P<SHB"FUS9W-T<B`B3F5P871V:7)T:6YT;W,@<F5G:7-T<F%C:6IO
M<SHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*;7-G:60@(E!E;W!L
M92(*;7-G<W1R("+>;6]NZW,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R(")0
M<F]C96YT86DB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N
M8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I
M;VYS(@IM<V=S='(@(D%T;&EK=&D@<')O9FEL86MT:6YI=7,@=F5I:W-M=7,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`V"FUS9VED(")097)F;W)M
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(D%R
M(&%T;&EK=&D@<')O9FEL86MT:6YI=7,@=F5I:W-M=7,@<')I<VEJ=6YG:6UO
M(&UE='4_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*
M;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B5&5I<^MS(@H*(SH@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HU,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S='(@(E1E
M:7/K<R`G)7,G(&YE:?!T<FEN=&]S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z-3@V"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N($1E;FEE
M9"(*;7-G<W1R(")496ESZW,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`HC
M+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B7U1E:7/K<R(*
M"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M<R]A9&1C
M:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN
M:7-T<F%T:6]N(@IM<V=S='(@(E1E:7-I^"!A9&UI;FES=')A=FEM87,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*;7-G:60@(E!E<G-O;F%L($EN
M9F]R;6%T:6]N(@IM<V=S='(@(D%S;65N:6[K(&EN9F]R;6%C:6IA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDX"FUS9VED(")097)U(@IM<V=S='(@(E!E<G4B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`B1WEV
M^VYA:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T
M<B`B1FEL:7!I;F%I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B"FUS9W-T<B`B5&5L969O;F%S
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W.`IM<V=I9"`B4&AO
M=&]S(@IM<V=S='(@(DYU;W1R875K;W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED
M(")0:71C86ER;B(*;7-G<W1R(")0:71K<F%N87,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS
M(@IM<V=S='(@(E!I:W-E;&EA:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R(")"86YA;'EBZW,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T
M<B`B2?!S:7)I;FMI=&4@:W5R:>`@;F]R<R!C96SF(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED
M(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES
M(&5L96UE;G0Z(@IM<V=S='(@(E!A='9I<G1I;FMI=&4L(&%R('1I:W)A:2!N
M;W)I=&4@:?!T<FEN=&D@\.$@96QE;65N=.`Z(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L
M96UE;G0N(@IM<V=S='(@(E!A='9I<G1I;FMI=&4L(&%R('1I:W)A:2!N;W)I
M=&4@:?!T<FEN=&D@\&EO(&5L96UE;G1O(&YU;W)O9.`N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C4W,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`BP79E<VMI=&4@;>MN97/A(&ER
M(&UE='5S+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@
M;F5W(&-A=&5G;W)Y.B(*;7-G<W1R("+!=F5S:VET92!N875J;W,@:V%T96=O
M<FEJ;W,@<&%V861I;FEMX#HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,S`Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S
M+B(*;7-G<W1R("+!=F5S:VET92!T96ES:6YGX"!)4"!A9')E<^`N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,`IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN
M('1H92!M;VYT:"XB"FUS9W-T<B`BP79E<VMI=&4@=&5I<VEN9^`@9&%TX"P@
M<&%T:6MR:6YK:71E(&1I96[X('-K86GH:?@@;>MN97-Y:F4N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,0IM<V=I9"`B4&QE87-E(&5N=&5R
M(&$@=F%L:60@=&EM92XB"FUS9W-T<B`BP79E<VMI=&4@=&5I<VEN9^`@;&%I
M:^`N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I
M9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*
M;7-G<W1R(")!<')A\'EK:71E('!R;V)L96W@+B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR
M-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S
M<W=O<F0B"FUS9W-T<B`B3G5R;V1Y:VET92!S879O('9A<G1O=&]J;R!V87)D
MX"!B96D@<VQA<'1A_F]DX2(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HU.`HC+"!F=7IZ>0IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO
M=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U
M<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@HB4')A\&]M92!P97)S:V%I
M='ET:2#PX2!T96MS=.`N($K[<R!04DE604Q/5$4@<W5T:6MT:2!S=2!SX&QY
M9V]M:7,L(&IE:2`B"B)N;W)I=&4@;F%U9&]T:7,@<VES=&5M82XB"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM
M<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G
M<W1R("+!=F5S:VET92!N875JX"!K871E9V]R:6IO<R!P879A9&EN:6W@.B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD(@IM<V=S='(@(DQE;FMI:F$B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S
M(@IM<V=S='(@(E!O;&ET:6MA:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT.#<*;7-G:60@(E!O;&QS(@IM<V=S='(@(D)A;'-A=FEM86DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R(")0;W)T=6=A
M;&EJ82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I
M;6%G92(*;7-G<W1R(")0879E:6MS;.ML:6\@<&]Z:6-I:F$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B
M4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R("),96YT96SK<R!P
M;WII8VEJ82(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C
M960@8GD@24U!4"DB"FUS9W-T<B`B2?!S875G;W1I(/!I86UE(&MA=&%L;V=E
M("AN96=A;&EO:F$@24U!4"DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V
M-B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R
M(")+<FET=6QI86D@<&%S:RX@)7,@=F%L86YDX"AA<RDZ("(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3@*;7-G:60@(E!R96-I<&ET871I
M;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E
M9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7VQD
M87`Z(&YE<F%S=&%S(')E:6MA;&EN9V%S($Q$05`@;6]D=6QI<RXB"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R
M969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B4')E9G-?<V5S<VEO;CH@;F5R87-T87,@<F5I:V%L
M:6YG87,@<V5S:6KX(&UO9'5L:7,N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR,C4*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(E-LZV=I<R(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C4Y"FUS9VED(")0<F5S<W5R92!A="!S96$@
M;&5V96PZ("(*;7-G<W1R(")3;.MG:7,@:OMR;W,@;'EG>6IE.B`B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")0<F5S<W5R
M93H@(@IM<V=S='(@(E-LZV=I<SH@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(P-0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I
M97<B"FUS9W-T<B`B4&5R_FG[<F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I
M97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")097+^:?MR
MZW1I('!A=F5I:W-LZVSA(&YA=6IA;64@;&%N9V4B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C,V,B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C,V-@IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")!
M;FMS=&5S;FD@;G5S=&%T>6UA:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM
M<V=S='(@(D%T<W!A=7-D:6YT:2!D;VMU;65N=.`B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM
M<V=S='(@(E-L87!T87-I<R!R86MT87,B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O365N=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(E!R
M;V)L96UA(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(V"FUS9VED(")0
M<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(E!R;V)L96UO<R!A<')A\'EM
M87,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S8Y"FUS9VED(")0
M<F]J96-T<R(*;7-G<W1R(")0<F]J96MT86DB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#@*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X-0IM<V=I9"`B4')O;7!T
M('1E>'0B"FUS9W-T<B`B4')A\'EM87,@=&5K<W1U:2(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*
M;7-G<W1R(")6:67P87-I<R!R86MT87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET
M:&TB"FUS9W-T<B`B5FEE\&]J;R!R86MT;R!A;&=O<FET;6%S(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#0*(RP@9G5Z>GD*;7-G
M:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R(")6:67P87-I<R!R86MT87,B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@
M(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S
M9G5L;'DN(@IM<V=S='(@(E9I9?!O:F\O<VQA<'1O:F\@<F%K=/@@<&]R82!N
M97-U9V5N97)U;W1A+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2
M:6-O(@IM<V=S='(@(E!U97)T;R!2:6MA<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G
M:60@(E%A=&%R(@IM<V=S='(@(DMA=&%R87,B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@(E-A:VEN>7,B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(E%U;W1A
M(@IM<V=S='(@(DMA=&%R87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC
M($ME>2`H)60@8FET*2(*;7-G<W1R(")24T$@=FEE\&%S:7,@<F%K=&%S("@E
M9"!B:71A:2DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8T"FUS
M9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B)U)A9&EO)R!P87-I<FEN
M:VEM87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT,PIM<V=I9"`B4F%I;B(*;7-G<W1R("),:65T=7,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B!%
M87)L>2(*;7-G<W1R("),:65T=7,@<GET92(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN($QA=&4B"FUS
M9W-T<B`B3&EE='5S('9A:V%R92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R
M("),:?MT:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT-PHC+"!F=7IZ>0IM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R
M("),:65T=7,O4VYI96=A<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")286EN('1O(%-N;W<B
M"FUS9W-T<B`B3&EE='5S+U-N:65G87,B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B071S:71I
M:W1I;NL@9G)A>NLB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(E-A;G1Y:VES(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS
M9W-T<B`B4VMA:71Y=&DB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HX-PIM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R(")0
M97)S:V%I='ET:2!L86GP:V%I(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE
M=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S
M='(@(E1I:W)A:2!I\'1R:6YT:2`E<S\@1W)A_FEN=&D@871G86P@;F5B96=A
M;.MS:71E+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX
M"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A
M(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE
M+B(*;7-G<W1R(")4:6MR86D@:?!T<FEN=&D@=F%R=&]T;VIO("5S(&1U;VUE
M;FES/R!'<F'^:6YT:2!A=&=A;"!N96)E9V%LZW-I=&4N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D
M;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B4&%K87)T;W1I(&%N:W-T
M97-NX2!V96EK<VW@(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B4F5F
M<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S='(@(D%T;F%U:FEN
M=&D@:V%I<FEO:F\@;65N:74@96QE;65N='5S.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-#$*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM
M<V=S='(@(D%T;F%U:FEN=&D@<&]R=&%L;R!V86EZ9.`Z(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.#DT(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R,3,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-0IM<V=I9"`B
M4F5G97@B"FUS9W-T<B`B4F5G97@B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,C0Y"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R
M(")3X')Y\&GX(&YA<O!Y:VSK(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC+"!F
M=7IZ>0IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(E-K86ET>71I(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,C8*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B
M4&%S=&%B;W,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$T"FUS9VED
M(")296UO=&4@4V5R=F5R<R(*;7-G<W1R(").=71O;.8@<V5R=F5R:6%I(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO
M=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T
M<B`B3G5T;VSF<R!54DP@*&AT='`Z+R]W=W<N<&%V>7ID>7,N8V]M+VAO<F1E
M*3HB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*;7-G:60@(E)E;6]V
M92(*;7-G<W1R("))\'1R:6YT:2(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHQ,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(E!A\&%L
M:6YT:2!B;&]KX"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HU-3<*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B4&%N
M86EK:6YT:2!S='5L<&5LX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM
M<V=S='(@(E!A;F%I:VEN=&D@9F]R;6%T879I;>`B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T
M<B`B2?!T<FEN=&D@<&]RX"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR
M,#(*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T
M96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("))\'1R:6YT:2!A=&YA=6II
M;FEM;R!S:W)I<'3@(&GP('-E<G9E<FEO(&QA:6MI;F]J;R!K871A;&]G;RXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-#(*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B4&'P86QI;G1I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O
M8W5M96YT(@IM<V=S='(@(E!A\&%L:6YT:2#PX2!E;&5M96YTX"!I\"!D;VMU
M;65N=&\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q
M"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R("))\'1R:6YT:2!V87)T;W1O
M:N`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(E9A
M<G1O=&]J;R!T<GEN:6UA<SH@)7,B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X
M;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W
M97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`B3F5G86QI=2!A
M='-A:WET:2#A('7^:VQA=7/@+B!+;&%I9&]S(&MO9&%S.B`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"B,L(&9U>GIY"FUS9VED(")2
M97%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@
M(DYE9V%L:74@:?!S875G;W1I(&YU<VGX<W1O(&9A:6QO+B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,3<T(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z-3$R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E
M9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R(")087)A;65T<F%S("<E<R<@;F5N=7)O9'ET87,@)7,@:V]N9FEG
M^W)A8VEJ;VIE+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C<U
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,P"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HW,C,*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")087)A;65T<F%S("<E<R<@;F5N=7)O
M9'ET87,@5D93(&MO;F9I9_MR86-I:F]J92XB"@HC.B!F<F%M97=O<FLO571I
M;"]5=&EL+G!H<#HW.#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E
M<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(E!A<F%M971R87,@)R5S)R!N96YU<F]D>71A<R!K;VYF:6?[
M<F%C:6IO:F4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP
M:'`Z,S,U"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SD*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(P('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B2?`@
M;F%U:F\B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@IM<V=I
M9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B4&%K96ES=&D@<VQA<'1A_F]D
MX2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED(")2
M97-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(E-L87!T8?YO9/YI;R!K96ET
M:6UA<R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S`*(RP@9G5Z>GD*;7-G
M:60@(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G<W1R(")087-K=71I;FES(&ME
M='9I<G1I<R(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI;B]C;61S
M:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP.C8V"FUS9VED(")297-U
M;'1S(@IM<V=S='(@(E)E>G5L=&%T86DB"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G
M:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(D=RX?YT:2#A(&YU<W1A
M='EM=7,B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*(RP@
M9G5Z>GD*;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B"FUS9W-T<B`B4&%K
M96ES=&D@<VQA<'1A_F]DX2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI
M;VXB"FUS9W-T<B`B4F5J^VYI:F$B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R
M="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(D%T<W1A='ET:2!K;VYF:6?[<F%C
M:6K@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,@IM<V=I9"`B4FEC
M:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(DA434P@<F5D86MT;W)I
M875S(&YU<W1A='EM86DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*
M;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B3>%S;.MS(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P"FUS9VED(")2
M:6=H="(*;7-G<W1R(")$9?!I;NMJ92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,Q,C$*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R(")$9?!I
M;FEO:FD@86YT<F'P=.LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3$W"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`B1&7P:6YI;W-I;W,@
M<F5I:_!MZW,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*
M;7-G<W1R(")?16EL=73K<R!N=7-T871Y;6%I+BXN(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*
M;7-G<W1R(")2;VSK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*
M;7-G<W1R(")2=6UU;FEJ82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,C4*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B
M4&%S=6MT:2`Q.#`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C(R"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R(")087-U
M:W1I(&MA:7+K;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,C@*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R(")087-U
M:W1I(&1E\&ENZVXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G
M<W1R(")%:6QU=.MS(&YU<W1A='EM86DB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O
M<&5R=&EE<R(*;7-G<W1R(")%:6QU=.MS(&YU<W1A='EM86DB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B
M4F]W<SHB"FUS9W-T<B`B16EL=73K<SHB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"FUS9VED(")2=6QE<R(*
M;7-G<W1R(")3:VER='5K86DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(E-K
M:7)T=6MA:2!T87)P('9I<_@@96EL=>AI^"!I<B!S='5L<&5L:?@B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q
M"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL
M>2(*;7-G<W1R(")3:VER='5K86D@=&EK('1A<G`@<W1U;'!E;&GX(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB
M"FUS9W-T<B`B4VMI<G1U:V%I('1I:R!T87)P(&5I;'7H:?@B"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3(P"FUS9VED(")2=6XB"FUS9W-T<B`B5GEK9'ET
M:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*
M;7-G<W1R(")2=7-I:F]S($9E9&5R86-I:F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS
M9VED(")2=V%N9&$B"FUS9W-T<B`B4G5A;F1A(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G
M<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R(")3+TU)344@<&%R8?!A<R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3
M+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B4R]-24U%('7^:V]D
M=6]T87,@;&%I\&MA<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP
M:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B3NMR82!305-,(&%U=&5N=&EF:6MA8VEJ;W,@;65C
M:&%N:7IM;RXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`T"FUS
M9VED(")335,@365S<V%G:6YG(@IM<V=S='(@(E--4R#^:6YU=.MS(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T
M<B`B4U%,($-,22(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#,*
M;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,0IM<V=I9"`B
M4U-((@IM<V=S='(@(E-32"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-5
M0T-%4U,B"FUS9W-T<B`B4$%664M/(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS
M9VED(")37U%,(%-H96QL(@IM<V=S='(@(E-?44P@0TQ)(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B
M"FUS9W-T<B`BT&7P="XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")386EN="!(
M96QE;F$B"FUS9W-T<B`BT'9E;G1O:FD@2&5L96YA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T
M"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B4V%I;G0@
M2VET<V%S(&ER($YE=FES87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT
M($QU8VEA(@IM<V=S='(@(E-A:6YT($QI=6-I:F$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P
M"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@(M!V
M96YT87-I<R!0971R87,@:7(@36EG96QO;F%S(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM
M<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T
M<B`B4V%I;G0@5FEN8V5N=&%S(&ER($=R96YA9&EN86DB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE
M(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B5&%M92!P8>AI86UE(&QA;F=E("A?
M<V5L9BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")386UO82(*;7-G<W1R(")3
M86UO82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T
M<B`B4V%N($UA<FEN87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")386\@5&]M
M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B4V%O(%1O;64@:7(@4')I;F-I<.LB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3
M871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B4&%L>61O=F%S(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(E-A=61O($%R
M86)I:F$B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3@*;7-G
M:60@(E-A=F4B"FUS9W-T<B`B2?!S875G;W1I(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B2?!S875G;W1I("5S(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4V%V92`E<R(*;7-G<W1R("))\'-A=6=O=&D@)7,B"@HC.B!T96UP
M;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS
M9W-T<B`B2?!S875G;W1I(&YU<W1A='EM=7,B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U
M<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O
M<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*(DGP<V%U9V]T:2!S=6=E
M;F5R=6]T=7,@;G5S=&%T>6UU<R!K86EP(%!(4"!S:W)I<'3@(&K[<_@@<V5R
M=F5R:6\@;&%I:VEN86IA;64@(@HB:V%T86QO9V4N(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@
M)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B)7,@;G5S=&%T>6UA:2!I\'-A
M=6=O=&DN(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R
M:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(D%T;F%U:FEN:6UO('-K<FEP=&%S
M(&GP<V%U9V]T87,@X3H@)R5S)RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT.0HC+"!F=7IZ>0IM<V=I9"`B4V-A='1E<F5D
M(%0M4W1O<FUS(@IM<V=S='(@(DEZ;VQI=6]T;W,@5"UA=61R;W,B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T
M<B`B36]K<VQA<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")3
M96%R8V@B"FUS9W-T<B`B267P:V]T:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS,C`*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(E!A
M:67P:V$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3<S"FUS9VED
M(")396QE8W0@1FEL97,B"FUS9W-T<B`B4&%S:7)I;FMI=&4@9F%I;'5S(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-`IM
M<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")087-I<FEN:VET92!D873@
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E
M;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R(")087-I<FEN:VET92!G<G5P
MYB(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E
M;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R(")087-I<FEN:VET92!N875JX"!S
M879I;FEN:^`B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*
M;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R(")087-I<FEN:VET92!S
M97)V97+A(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G
M:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@(E!A<VER:6YK:71E
M('9A<G1O=&]JX"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HV-S<*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T
M<B`B4&%S:7)I;FMI=&4@9F%I;'5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C8V,PIM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N
M(@IM<V=S='(@(E!A<VER:6YK:71E('9I<W5S(&1A=&]S(&MO;7!O;F5N='5S
M+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX
M-S,*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B4&%S:7)I;FMI
M=&4@;V)J96MTX"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HV-S@*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S
M='(@(E!A<VER:6YK:71E(&YA=6K@('-A=FEN:6YKX"(*"B,Z('-E<G9I8V5S
M+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H92!C:&%R86-T
M97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H
M96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N
M(@IM<V=S='(@(B(*(DGP(/YE;6EA=2!E<V%NZ&GX('/@<F'P^"!P87-I<FEN
M:VET92!R96EK:6%M=7,@<VEM8F]L:75S+B!6ZVQI874@9V%L:71E(&IU;W,@
M(@HB;G5K;W!I:G5O=&D@X2!L86GP:^`N(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z
M(@IM<V=S='(@(E!A<VER:6YK:71E(&1A=&]S('-K:7)T=6O@.B(*"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A
M=&4@9F]R;6%T.B(*;7-G<W1R(")087-I<FEN:VET92!D871O<R!F;W)M873@
M.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*
M;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E
M.B(*;7-G<W1R(")087-I<FEN:VET92!A<')A\.`@:W5RX2!N;W)I=&4@<F5D
M86=U;W1I.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED
M(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R(")087-I<FEN
M:VET92!L86EK;R!S:VER='5KX#HB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE
M+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T
M<B`B4&%S:7)I;FMI=&4@;&%I:V\@9F]R;6%TX#HB"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG
M(&9I96QD<RXB"FUS9W-T<B`B4&%S:7)I;FMI=&4@9'4@871I=&EN:V%NZ&EU
M<R!L875K=7,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P-@IM<V=I
M9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R(")087-I<FEN
M:VET92!S<&%L=O@@9&5R:6[A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-#@*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB
M"FUS9W-T<B`B4&%S:7)I;FMI=&4@;F]R:6W@(&MA;&+@.B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L
M96T@4F5P;W)T(@IM<V=S='(@(E-I^'-T:2!P<F]B;&5M;W,@<')A;F7P:6W@
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M,SD*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(E-I^'-T:2!335,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S='(@(E-E;F5G86QA<R(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$V"FUS9VED(")396YS;W(Z("(*
M;7-G<W1R(")396YS;W)I=7,Z("(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B
M4G5G<^MJ:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(E-E
M<F)I:F$@:7(@36]N=&5N96=R87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R
M(")397)I:F]S(&YU;65R:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,38Q"B,L(&9U>GIY"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O
M<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")/<F\@<^!L>6?X(&)L;VMO(&[K
M<F$N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"B,L(&9U>GIY"FUS9VED
M(")397-S:6]N($%D;6EN(@IM<V=S='(@(E1E:7-I^"!A9&UI;FES=')A=FEM
M87,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`B
M4V5S:6IO<R!)1"!P87-I8F%I9^LN(@H*(SH@;&EB+V%P:2YP:'`Z,30U"B,L
M(&9U>GIY"FUS9VED(")397-S:6]N<R(*;7-G<W1R(")?5&5I<^MS(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-`IM<V=I9"`B4V5T(@IM<V=S
M='(@(E)I;FMI;GES(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V"FUS
M9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P
M87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*(DYU
M<W1A='EM86D@;&5I9/YI86YT>7,@2G5M<R!P87-I:V5I<W1I('-L87!T8?YO
M9.$L(&IE:6=U(&KA(&MA9&$@;F]R<R`B"B)P86UI<O!I=&4N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S
M97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T
M86PN(@IM<V=S='(@(DYU=&]L=7-I^"!S97)V97)I^"P@:W5R:75O<R!N;W)I
M=&4@;6%T>71I(&GP('!O<G1A;&\L(&YU<W1A='EM86DN(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@T"FUS9VED(")3970@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@
M(DMA;&)O<RP@;&%I:V\@>F]N;W,@:7(@9&%T;W,@;G5S=&%T>6UA:2XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*;7-G:60@(B(*(E-E="!Y;W5R
M('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R
M97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R
M("(B"B)0=7-L87!I;R!S<&%L=O@L(&%T<VEN875J:6YI;6\@9&'^;G5M;R!I
M<B!K:73X('9A:7ID879I;6\@<&%R86UE='+X("(*(FYU<W1A='EM86DN(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B
M4V5T=7`B"FUS9W-T<B`B7TMO;F9I9_MR86-I:F$B"@HC.B!T96UP;&%T97,O
M861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D
M92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R(")287-T87,@871N875J:6YI
M;6\@<VMR:7!T87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3@V"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H
M92!P87)A;65T97(Z("(*;7-G<W1R(")3=2#P:75O('!A<F%M971R=2!G86QI
M;6]S(&ME;&EO<R!V:65T;W;K<SH@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B
M4V5Y8VAE;&QE<R(*;7-G<W1R(")396GP96QA:2(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT.38*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(E!A
M<F1U;W1U=NLB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT
M,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R(")4<G5M<&%S(&%P<F'P
M>6UA<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#8*;7-G:60@(E-H
M;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*
M;7-G<W1R(")!<B!N875D;W1I(&ML879I873[<F]S(&UY9W1U:W5S('9A;&1Y
M;75I/R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(S('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y
M"FUS9VED(")3:&]W(@IM<V=S='(@(E)O9'ET:2(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T
M=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@
M(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB4&%R;V1Y=&D@<VMI<G1U
M;75S('1A<G`@:?!S875G;W1O(&ER(&O@('1I:R!S=6=E;F5R=6]T;R!K;VYF
M:6?[<F%C:6YI;R!F86EL;RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#DP"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@
M:6X_(@IM<V=S='(@(E)O9'ET:2!P87-K=71I;FEO('!R:7-I:G5N9VEM;R!L
M86EKX#\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8U"FUS9VED
M(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(E)O9'ET
M:2!G86QI;7EBYB!P86QI:W1I(&]R:6=I;F%LX"(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(X,3,*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@
M(E)O9'ET:2!P87)I<VEN:VEMX"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,C8*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B
M"FUS9W-T<B`B4F]D>71I(&QE;G1E;.MS(&]P97)A8VEJ^"!M96YI=3\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(E)O
M9'ET:2`E<R!M96YI=2!K86ERZVIE/R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T
M:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")2;V1Y
M=&D@8V5LZW,@;G5S=&%T>6WX(&QA;F?@(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED(")3:&]W
M('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")2;V1Y=&D@
M;&5N=&5LZW,@;G5S=&%T>6WX(&QA;F?@(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED(")3:&]W
M('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B4F]D
M>71I(&5I;'5TZW,@;G5S=&%T>6WX(&QA;F?@(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3
M:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")2;V1Y
M=&D@<&%V96EK<VSK;&EO(&YU<W1A='EM^"!L86YGX"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$W-C,*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S
M='(@(E)O9'ET:2!F86EL^"#A:^ML:6W@(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E-H;W=E<G,B"FUS9W-T
M<B`B3&G[=&ES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3$*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B3&G[=&ES
M(')Y=&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,@IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(DQI^W1I<R!V86MA
M<F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M,PIM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#@P"FUS9VED
M(")3:')I;FLB"FUS9W-T<B`B4W5M8?YI;G1I(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z-S<T(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C@S-@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HY,C(@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M.3@T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P-#<@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`X-PHC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,3$V(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C$Q-#D*;7-G:60@(E-H<FEN:R!O<B!M
M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S
M="(*;7-G<W1R(")3=6UA_FEN=&D@87)B82!P87-T=6UT:2!K86EM>6YI;FEU
M<R!B;&]K=7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B
M"FUS9W-T<B`B4VEE<F$@3&5O;NLB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,C8U"FUS9VED(")3:6=N('5P(@IM<V=S='(@(E)E9VES
M=')A8VEJ82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-S$R"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`B4&%R8?!A<R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$Q"FUS9VED(")3:6=N
M871U<F4@06QG;W)I=&AM(@IM<V=S='(@(E!A<F'P;R!A;&=O<FET;6%S(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(E-I;F=A
M</MR87,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8U(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HX.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,CDS,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(S"FUS9VED
M(")3:7IE(@IM<V=S='(@(D1Y9&ES(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N
M8V4B"FUS9W-T<B`B4')A;&5I<W1I('!R;V9I;&%K=&EKX"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(E-L;W9A:VEJ82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(E-L;W;K;FEJ
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T
M"B,L(&9U>GIY"FUS9VED(")3;F]W(@IM<V=S='(@(E)O9'ET:2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3
M;F]W(%-H;W=E<B(*;7-G<W1R(")0^V=A(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*(RP@9G5Z>GD*;7-G:60@(E-N;W<@
M4VAO=V5R<R(*;7-G<W1R(")0^V=A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(E-N;W<@4VAO
M=V5R<R!%87)L>2(*;7-G<W1R("),:?MT:7,@<GET92(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"B,L(&9U>GIY"FUS9VED
M(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R("),:?MT:7,@=F%K87)E(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*;7-G:60@(E-N;W<@9&5P=&@Z
M("(*;7-G<W1R(")3;FEE9V\@9WEL:7,Z("(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C@R"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*
M;7-G<W1R(")3;FEE9V\@:VEE:VES('9A;F1E;FEU.B`B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B4V]L;VUO;F\@
M<V%L;W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM<V=S='(@
M(E-O;6%L:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@
M(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B1&%I;F]S(&ER($5I;.MR8?#H:6%I
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR-@IM<V=I9"`B4V]R
M="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B4OOP:6%V:6UO('1V87)K;W,@
M<&%S:7)I;FMI;6%S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C$X.0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B
M"FUS9W-T<B`B4VEU;G3K:F\@861R97-A<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G
M:60@(E-O=71H($%F<FEC82(*;7-G<W1R(")0:65T^"!!9G)I:V$B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B4V]U=&@@175R;W!E86X@
M*$E33RTX.#4Y+3,I(@IM<V=S='(@(E!I973X($5U<F]P;W,@*$E33RTX.#4Y
M+3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T
M:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R(")0:65T^"!$_F]R
M9/YI:F]S(&ER(%!I973X(%-A;F1V:>AO('-A;&]S(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U
M=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")0:65T:6[K(&AE;6ES9F5R82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S
M"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@
M(E1A<G!A<R!T87)P(&-E;&GX(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N
M=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B5&%R<&%S('1A<G`@
M8V5LZW,@='5R:6YI;R!I<B!K<F'P=&ENZW,B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HX,34*;7-G:60@(E-P86-E<B(*;7-G<W1R(")487)P87,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B5&%R<&%I('1A<G`@8V5L
M:?@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@
M(E1A<G!A:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R("))
M<W!A;FEJ82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY.`IM<V=I
M9"`B4W!A;2(*;7-G<W1R(")3<&%M87,B"@HC.B!S97)V:6-E<R]K97EB;V%R
M9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S
M='(@(E-P96-I9FEN:?@@<VEM8F]L:?@@X71E<G!I;6%S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I
M9"`B4W!L:70@8V5L;"(*;7-G<W1R(")097)S:V5L=&D@8V5LYB(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*
M;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R(")097)S:V5L=&D@<W1U;'!E
M;.$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B4&5R<VME;'1I
M(&5I;'5TYB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM<V=I9"`B
M4W!O<G1S(@IM<V=S='(@(E-P;W)T87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@
M(E-R:2!,86YK82(*;7-G<W1R("+0<FD@3&%N:V$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-S,@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-`IM
M<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B4W1A;F1A<G1A<R(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@
M(E-T87(@5')E:R=A<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U
M.38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P.0IM<V=I9"`B4W1A<G0@
M>65A<B(*;7-G<W1R(")0<F%D:6YI86D@;65T86DB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B4W1A=&4@;W(@4')O
M=FEN8V4B"FUS9W-T<B`B4F%J;VYA<R!A<F)A('!R;W9I;F-I:F$B"@HC.B!T
M96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A
M='5S(@IM<V=S='(@(D+[<V5N82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(X,34*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(E-A=6=O
M:FEM;R!F;W)M871A<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3<R"FUS9VED(")3=')E970@061D<F5S<R(*;7-G<W1R(")'871V
MZW,@861R97-A<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B5?YB
M<F%U:W1I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,PIM<V=I
M9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`BWF]D_FGX('/@<F'P87,B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I<"!D;VUA
M:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R(").=6EM=&D@9&]M96[@(&YU
M;R!A9')E<V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R(")3
M=&EL:75S(%M#4U-=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B4V5K;2XB"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M("(E<R!N97)A<W1A<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(E1E;6$B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W;W)K+T9O
M<FTO1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3=6)M:70B"FUS9W-T
M<B`BP79E<W1I(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<
M(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U
M<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B"B)6
M87)T;W1O:F%S("<E<R<@<W5K=7)T87,@<VES=&5M;VIE+B!+;VP@:FES(&YE
M<&%T=FER=&EN=&%S+"!P<FES:6IU;F=T:2`B"B)N96=A;.MS:71E+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G
M:60@(E-U8G-C<FEP="(*;7-G<W1R("));F1E:W-A<R(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S
M<R(*;7-G<W1R(")3ZVMM:6YG82(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@
M7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@(B<E<R<@<^MK;6EN9V%I
M('-U:W5R=&%S('-I<W1E;6]J92XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A
M<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B5F%R=&]T;VIO("<E<R<@9'5O;65N>7,@<^MK;6EN9V%I(&GP=')I
M;G1I(&GP('-I<W1E;6]S+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#`@861M
M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R("(G
M)7,G('/K:VUI;F=A:2!I\'1R:6YT82XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R
M96UO=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B<E<R<@
M<^MK;6EN9V%I(&GP=')I;G1A<R!I\"!S:7-T96UO<RXB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T
M960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G
M<W1R("(B"B)+;VYF:6?[<F%C:6IA(&%T<W1A='ET82!SZVMM:6YG86DN(%!E
M<FMR875K:71E('!U<VQA<.$L(&MA9"!P86UA='ET=6WK=&4@(@HB<&%K96ET
M=6UU<RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B
M86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B071S87)G:6[K(&MO;F9I
M9_MR86-I:F]S(&MO<&EJ82!SZVMM:6YG86D@:?!S875G;W1A+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R
M871I;VX@9FEL92`E<RXB"FUS9W-T<B`B071S87)G:6[K(&MO;F9I9_MR86-I
M:F]S(&MO<&EJ82!SZVMM:6YG86D@:?!S875G;W1A(.$@)7,N(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,38X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B)R5S)R!SZVMM
M:6YG86D@871N875J:6YT87,N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(B<E<R<@<^MK
M;6EN9V%I('7^<F'P>71A<RXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=61A
M;B(*;7-G<W1R(")3=61A;F%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*;7-G
M<W1R(")4=7)I;GES(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS
M9VED(")3=6X@4FES92(*;7-G<W1R(")3875LZW1E:VES(@H*(SH@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(E-A
M=6SK;'EG:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU.0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B4V%U;.MT82(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(E-U;G)I<V4B
M"FUS9W-T<B`B4V%U;.MT96MI<R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3
M=6YS970B"FUS9W-T<B`B4V%U;.MT96MI<R]3875LZVQY9&ES(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-0IM<V=I9"`B4W5N<FES93H@
M(@IM<V=S='(@(E-A=6SK=&5K:7,Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,3D*;7-G:60@(E-U;G-E="(*;7-G<W1R(")3875LZVQY
M9VES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.`IM<V=I
M9"`B4W5N<V5T.B`B"FUS9W-T<B`B4V%U;.ML>6=I<SH@(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P
M97)S8W)I<'0B"FUS9W-T<B`B3&%I<'-N:7,B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S<X"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(D%P=&%R
M;F%V:6UA<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM<V=S
M='(@(E-U<FEN86UA<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3<T"FUS9VED(")3=7)N86UE(@IM<V=S='(@(E!A=F%R9.LB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM
M<V=S='(@(E-V86QB87)D87,@:7(@1/YA;FUA:6YA<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R(")3=F%Z:6QA;F1A<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R("+0=F5D:6IA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(M!V96EC
M87)I:F$B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@HC+"!F
M=7IZ>0IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R(").971R:6YT
M:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#(*;7-G:60@(E-Y;F--
M3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP
M:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS
M9W-T<B`B4VEN=&%K<^MS(&ML86ED82!P86EE\&MO<R!K<FET97)I:G5J92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM
M<V=S='(@(E-I<FEJ;W,@07)A8O@@4F5S<'5B;&EK82(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")4+5-T;W)M
M(@IM<V=S='(@(E0M875D<F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C(*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(E0M875D<F]S(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*(RP@9G5Z
M>GD*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@(DQI^W1I<R!R>71E
M(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$V-@IM<V=I9"`B
M5%-6(&9I;&4B"FUS9W-T<B`B5%-6(&9A:6QA<R(*"B,Z(&9R86UE=V]R:R]5
M22]522]486)L92YP:'`Z,3,T"FUS9VED(")486)L92(*;7-G<W1R("),96YT
M96SK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R("),
M96YT96SK<R!N=7-T871Y;6%I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4
M>7!E+W1A8FQE<V5T+G!H<#HU-PHC+"!F=7IZ>0IM<V=I9"`B5&%B;&4@4V5T
M(@IM<V=S='(@(DQE;G1E;.LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T
M:65S(@IM<V=S='(@(DQE;G1E;.MS(&YU<W1A='EM86DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS9W-T<B`B5&%I=F%N87,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B
M5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R(")486EV86YA<RP@
M2VEN:6IO<R!P<F]V:6YC:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J
M:6MI<W1A;B(*;7-G<W1R(")4863^:6MI<W1A;F%S(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R
M(")*=6YG=&ENZR!486YZ86YI:F]S(%)E<W!U8FQI:V$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")487)G
M970Z(@IM<V=S='(@(E1A:6MI;GES.B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N
M9&ES=#HY.38@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X-PIM<V=I9"`B
M5&%S:W,B"FUS9W-T<B`B1&%R8F%I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E1E;&5P:&]N92!.=6UB97(B"FUS
M9W-T<B`B5&5L969O;F\@;G5M97)I<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,CDP"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")4
M96UP+B!P87-K+B!V86QA;F3@.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(Q-`IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B5&5M<&5R873[<F$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(S"FUS9VED(")4
M96UP97)A='5R93H@(@IM<V=S='(@(E1E;7!E<F%T^W)A.B`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDS"B,L('!H<"UF;W)M870*;7-G
M:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H
M<#HV.#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB
M)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DYE<F%S=&%S("<E<R<@\&%B;&]N
M87,N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L
M871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(M!A8FQO;O@@861M:6YI<W1R
M879I;6%S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,V"FUS9VED(")497AT(@IM<V=S='(@
M(E1E:W-T87,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<U"FUS9VED
M(")497AT($]N;'DB"FUS9W-T<B`B5&EK('1E:W-T87,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED
M(")497AT(&%L:6=N(@IM<V=S='(@(DQY9VEU;W1I('1E:W-TX"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@
M(E1E>'1T;W`B"FUS9W-T<B`B5&5K<W1O('9I<O!U:F4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*
M;7-G<W1R(")+971V+B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS
M9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R(")486EL86YD:65T:?!K82`H
M5$E3+38R,"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G
M<W1R(")486EL86YD87,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.#@*;7-G:60@(E1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B0>AI^R!K860@;F%U9&]J873K<R!S:7-T96UA+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(P"FUS9VED(")4:&4@1E10(&5X=&5N
M<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(").ZW)A($944"!M;V1U
M;&EO+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,T"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E
M;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O
M2V]L86(@:6YT96=R86-I:F]S('9A<FEK;&EU:V%S(&YE<&%L86EK;R!<(B5S
M7"(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]";V]K+G!H<#HQ,CDR
M"B,L(&9U>GIY"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN
M:71I86QI>F5D+B(*;7-G<W1R(").96=A;&EU(&GP<V%U9V]T:2!N=7-I^'-T
M;R!F86EL;RXB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G
M:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C
M97-S9G5L;'DB"FUS9W-T<B`B3F5P879Y:V\@=?YK<F%U=&D@36%I;G1E;F%N
M8V4Z.B!K;&%SZW,B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N
M<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@
M17AI=&EN9RXB"FUS9W-T<B`B3G5S=&%T>6WX(&QA;F=A<R!U_F1A<GET87,N
M($GP96EN=2XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X.2!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C(Q,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R
M,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C(V-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PIM<V=I9"`B
M(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R
M;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@
M=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"B)*96EG=2!N;W)I=&4@;F%U
M9&]T:2!N=7-T871Y;75S+"!P87!R8?!Y:VET92!K860@861M:6YI<W1R871O
M<FEU<R`B"B)S=6MO;F9I9_MR=6]T^"!P87-T;W9IX"!D=6]M96[X(&)A>N8@
M;G5S=&%T>6UA;7,@<V%U9V]T:2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M
M('-I9&4@;VYL>2(*;7-G<W1R(")4:6L@87!A=&ENZVIE('!U<^MJ92(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y
M"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C
M:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB
M9&%T86)A<V4N(@IM<V=S='(@(DYEX7)A\.MT92!C;VYT86MT;R!)1"!N=6UE
M<FEO(&%R8F$@:FES(&YE<F%S=&%S(&1U;VUE;O@@8F%ZZVIE+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B
M5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D
M9')E<W,@8F]O:RXB"FUS9W-T<B`B2V]N=&%K=&%S('/K:VUI;F=A:2#A=')A
M=6MT87,@X2!*^W/X(&%D<F5S^"!K;GEG96SF+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$Q-CD*;7-G:60@(B(*(E1H92!D971A8VAE
M9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T
M:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(DYO<NMD86UI('!A=&EK<FEN
M=&D@;&%I\&O@('!R:79A;&]T92!T=7+K=&D@871S:VERX"!01U`@<&%R8?!O
M(&)L;VO@+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@
M240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO
M="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(DYEX7)A\.MT
M92!D:7-T<FEB=6-I:F]S('/@<F'P;R!)1"!A<F)A(&II<R!N97)A<W1A<R!D
M=6]M96[X(&)A>NMJ92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L
M:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R(").9>%R8?#K=&4@9&ES
M=')I8G5C:6IO<R!SX')A\&\N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+G!H<#HQ,3,*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I
M<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*(E!'4"!U
M_FMO9&%V:6UO(&=A;&EM>6+K(')E:6MA;&%U:F$@<V%U9V%U<R!P<FES:6IU
M;F=I;6\N($)A;F1Y:VET92!R8?!Y=&D@(@HB:'1T<',Z+R\@861R97-O('!R
M863^:6]J92XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-2!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N
M(@IM<V=S='(@(D9A:6QA<R`E<R!P<FEV86QO('1U<NMT:2`E<R!P87)A;65T
M<N`N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C@@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB
M"FUS9W-T<B`B1F%I;&%S("5S('!R:79A;&\@='5RZW1I(&MA:2!K=7)I=6]S
M("5S('!A<F%M971R=7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C$Y"FUS9VED(")4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O
M(&ET<V5L9BXB"FUS9W-T<B`B1F%I;&%S(&YE9V%L:2!B^W1I(&YU:V]P:6IU
M;W1A<R!A;G0@<V%VYG,N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z
M,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T
M<B`B1F%I;&4@;NMR82!D=6]M96[X+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@
M87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A
M9V4N(@IM<V=S='(@(E)&0S@X,B!L86GP:V\@86YT<F'P=.MS+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@
M(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R
M;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W
M<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@
M(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C
M:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C
M<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S
M('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R
M;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@
M:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@
M<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS
M9W-T<B`B(@HB2F5I9W4@9&ER8F%T92!);G1E<FYE="!%>'!L;W)E<B!N87+P
M>6ML92P@<&EL;F%E:W)A;FES(')E9&%K=&]R:6%U<R!R9?YI;6%S("(*(F=A
M;&D@<W5K96QT:2!P<F]B;&5M^"P@9.ML(/!I;W,@;F%R\'EK;.MS(&ML86ED
M^"X@1V%L:71E(&YE;6%T>71I(&MA:2!K=7)I^"`B"B)R961A:W1O<FEA=7,@
M96QE;65N=/@N($IE:6=U(&YA=61O:F%T92!7:6YD;W=S(#EX($]3(&=R96GH
M:6%U<VEA:2!J^W/X("(*(FMO;7!I=71E<FES('!A<')A\.AI875S:6%I(&YU
M;'7P('!A<VME;&)D86UA<R!A<&EE('!A9W)I;F1I;N8@:VQA:63@+EQ<;B(*
M(EQ<;DK[<R!B=79O=&4@<&5R<W#K=&%S+B!*96EG=2!V:7-T:65K(&YO<FET
M92!I\&)A;F1Y=&D@<&EL;F%E:W)A;N$@<F7^:6W@("(*(G-P875S:VET92!/
M2RXB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*
M;7-G<W1R(")!<')A\&%S(%PB)7-<(B!I\'1R:6YT87,N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I
M9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B5&EK(&MA:7+K
M:F4@<'5SZVIE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R
M>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS
M9W-T<B`B0W)Y<'1?<'%P.CH@:VQA<V5I(')E:6MI82!N=7)O9'ET:2!K=7(@
M>7)A($=N=5!'(&9A:6QA:2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$
M3BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E
M('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E
M;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H
M92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T
M<B`B(@HB3&%I\&MA<R!I\'-I^'-T87,@)7,@861R97-A='5I("5S('1E;6$@
M7"(E<UPB(&)U=F\@<&%R;V1Y=&%S+EQN(@HB5&'H:6%U('1A:2!N96=A<F%N
M='5O:F$@:V%D(&QA:?!K87,@8G5V;R!P97)S:V%I='ET87,@87)B82!S=7!R
M87-T87,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM<V=I
M9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S
M92!P86=E(@IM<V=S='(@(E!A=F%D:6YI;6%S(&MU<N$@;F%U9&]S:71E(&YU
M;W)O9&]J92#A(&QA:?!K;R!R8?!Y;6\@<'5S;&%PX2(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I9"`B5&AE(&YU
M;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R("+0:2!R
M96EK\&WK('1U<FD@8OMT:2!S:V%IZ&EU<RXB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S$*;7-G:60@(E1H92!O<&5N<W-L(&UO
M9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@
M8VQA<W,N(@IM<V=S='(@(DAO<F1E7T-R>7!T7W-M:6UE.CH@:VQA<V5I(')E
M:6MA;&EN9V%S($]P96Y34TP@;6]D=6QI<RXB"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@
M<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@
M:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE('-I
M>F4B"FUS9W-T<B`B(@HB3F5G86QI=2!I\'-A=6=O=&D@;G5S=&%T>6UO(%PB
M)7-<(BP@;F5S(&1U;VUE;O@@9'ED:7,@=FER\'EJ82!L96ES=&ENX"!R:6+@
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS,@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H
M<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP
M.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z
M,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z
M,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T
M;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T
M:&4@<WES=&5M+B(*;7-G<W1R(")0<F]G<F%M82P@<VMI<G1A('!E<OYI^W+K
M=&D@\.$@9'5O;65N^"!T:7#@("@E<RDL(&YE<F%S=&$@<VES=&5M;VIE+B(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0U-`IM<V=I9"`B5&AE
M('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@
M<VED97,@;VYL>2(*;7-G<W1R(")4:6L@:V%I<NMJ92!I<B!D9?!I;NMJ92!P
M=7/K<V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB
M"FUS9W-T<B`B5&EK(&1E\&ENZVIE('!U<^MJ92(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C0T-@IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T
M(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R
M(")397)V97)I<R!<(B5S7"(@:?!T<FEN=&%S+B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S
M97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R(")397)V97)I
M<R!<(B5S7"(@:?!S875G;W1A<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E
M<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("(E<R!R96=I<W1R86-I:F]S
M('!R8?!Y;6%S(&GP=')I;G1A<RXB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S<&5C:69I960@<F]W(&1O
M97,@;F]T(&5X:7-T+B(*;7-G<W1R(").=7)O9'ET82!E:6QU=.L@;F5E9WII
M<W1U;VIA+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3<W"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@
M7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(").=7)O9'ET82!E:6QU
M=.L@;F5E9WII<W1U;VIA+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S,3$*;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T
M8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM
M<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B
M5&EK('9I<O!U=&ENZVIE(&ER(&%P871I;NMJ92!P=7/K<V4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS
M9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R(")4:6L@87!A=&ENZVIE
M('!U<^MJ92(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I
M9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I
M;W5S('-T97`N(@IM<V=S='(@(DYU<VGX<W1I(&1U;VUE;GES('!R87)A<W1I
M+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W
M;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D
M(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R(").96=A;&EU(&GP
M<V%U9V]T:2!N=7-I^'-T;R!F86EL;RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4V
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$Q.0IM<V=I9"`B5&AE('=E871H97(N8V]M
M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E=E871H97(N8V]M
M(&)L;VMO(&[K<F$N(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y(%PB
M)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DYE<F%S=&%S("<E<R<@\&%B;&]N
M87,N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-S@*;7-G
M:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`B
M3G5S=&%T>6WX(&[K<F$N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z,S0R"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C
M86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B1&%L:?@L(&MU<FEA
M<R!G86QI;6$@<F]D>71I(&QA:?!K;R!T96MS=&4L(&[K<F$N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I
M96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M
M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@HBT&EA;64@;&%U
M:V4@X79E<W1A('!E<B!D875G('-I;6)O;&GX+B!*^W,@X79E9.MT92`E<RP@
M;R!M86MS:6UA;'5S('-K86GH:75S("(*(BT@)7,@<VEM8F]L:6%I+B(*"B,Z
M('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB
M)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R(")3=6MU<G1I("<E<R<@
M;F5P879Y:V\Z("5S(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R
M:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM
M<V=S='(@(DYE<&%V>6MO(&GP=')I;G1I('9A<G1O=&]J;R`G)7,G(&1U;VUE
M;O@@:?`@<VES=&5M;W,Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R
M96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B2?!T
M<FEN=&D@)R5S)R!N97!A=GEK;SH@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B
M;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B071N875J:6YT:2`G
M)7,G(&YE<&%V>6MO.B`E<R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S
M97(N<&AP.C@X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D
M960N(@IM<V=S='(@(E!R;V)L96UO<R!S=2!F86EL^"!S:75N=&EM=3H@)7,@
M;F5N=7-I^'-T87,N(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP
M:'`Z.#@Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R
M;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R
M('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN
M(@IM<V=S='(@(B(*(DYU<VGX<W1I(&9A:6QO(&YE<&%V>6MO+B!&86EL87,@
M)7,@>7)A(&1I9&5S;FES(&YE9W4@;&5I9/YI86UA<R!D>61I<R`H)60@(@HB
M8F%I=&%I*2XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX
M.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I
M86QL>2!U<&QO861E9"XB"FUS9W-T<B`B3G5S:?AS=&D@9F%I;&\@;F5P879Y
M:V\N($9A:6QA<R`E<R!T:6L@9&%L:6YA:2!N=7-I^'-T87,N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A
M<G0B"FUS9W-T<B`B3F5G86QI=2!P87)O9'ET:2#P:6]S(&QA:?!K;R!D86QI
M97,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT
M86-T(&1A=&$N(@IM<V=S='(@(DML86ED82#A:V5L:6%N="!K;VYT86MT:6YI
M=7,@9'5O;65N:7,N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP
M.C,Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I
M0V%L96YD87(@9&%T82XB"FUS9W-T<B`B2VQA:61A(.%K96QI86YT(&E#86QE
M;F1A<B!D=6]M96YI<RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@P
M"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R
M871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E
M9"!F:65L9"XB"FUS9W-T<B`B(@HB2VQA:61A(&MO;F9I9_MR86-I:F]S(&9O
M<FUO:F4N($=R96GH:6%U<VEA:2!N977^<&EL9.MT92!R96EK:6%M^"!L875K
M^"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI
M;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S
M92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(DML86ED82!A=&QI
M96MA;G0@;G5R;V1Y=.`@861R97/X(&MN>6=E;.MS(&9U;FMC:6K@+B!086)A
M;F1Y:VET92!VZVQI874N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E
M<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y
M(&%G86EN(&QA=&5R+B(*;7-G<W1R(")+;&%I9&$@871N875J:6YA;G0@:V]N
M=&%K=&EN:75S(&1U;VUE;FES+B!086)A;F1Y:VET92!VZVQI874N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G
M:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I
M8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@
M(DML86ED82!A=&YA=6II;F%N="!D:7-T<FEB=6-I:F]S('/@<F'PX"X@4&%B
M86YD>6MI=&4@=NML:6%U+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S
M(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`BT&ES($E-
M05`@<V5R=F5R:7,@;F5P86QA:6MO(&MA=&%L;V?X(&1A;&EJ:6UO<VDN(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HT.`IM<V=I
M9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C
M:&EV92XB"FUS9W-T<B`B071R;V1O+"!K860@=&%I(&YE='9A<FMI;F=A<R!2
M05(@87)C:'EV87,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B071R;V1O+"!K860@=&%I(&YE
M='9A<FMI;F=A<R!:25`@87)C:'EV87,N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$T-0IM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E
M(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(D%T<F]D;RP@:V%D('1A
M:2!N971E:7-I;F=A<R!K;W)T96SK<R!N=6UE<FES+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B
M(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M
M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HBT&D@
M='9A<FMY:VSK(&QE:63^:6$@<VGX<W1I(/YI;G5T97,@<&5R($-L:6-K871E
M;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@(@HB<&%S:6YA=61O:F%N="!(
M5%10('!R;W1O:V]L=2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,3,T"B,L(&9U>GIY"FUS9VED("(B"B)4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT
M='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$DB"FUS9W-T<B`B(@HBT&D@='9A<FMY:VSK(&QE:63^:6$@<VGX<W1I(/YI
M;G5T97,@<&5R('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI("(*
M(G!A<VEN875D;VIA;G0@2%144"!P<F]T;VMO;'4B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G
M:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(M!I('1V87)K
M>6MLZR!L96ED_FEA('-I^'-T:2#^:6YU=&5S('!E<B!S;7,R96UA:6P@*&AT
M='`Z+R]S;7,R96UA:6PN8V]M*2`B"B)P87-I;F%U9&]J86YT($A45%`@<')O
M=&]K;VQU(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F
M;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R
M<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F
M;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*(M!I
M('1V87)K>6MLZR!L96ED_FEA('-I^'-T:2#^:6YU=&5S(%--5%`@<')O=&]K
M;VQU('!E<B!6;V1A9F]N92!)=&%L:6IO<R`B"B)V87)T=7,L('1I:R!6;V1A
M9F]N92!N=6UE<FEA;7,N($II(')E:6MA;&%U:F$@96PN('!A\'1O(&%D<F5S
M;R!6;V1A9F]N92`B"B))=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDW."!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,#4W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#8@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-38*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,SDX"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U
M-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@S.0HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.34X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M,#4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#<X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q-#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R,0HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-#$P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(T-30*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U-R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P-@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#$T(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,X,C(*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S
M='(@(M!I<R!L875K87,@<')I=F%L;VUA<RXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O
M;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(M!I86UE(&QA=6ME(&=A;&D@8OMT
M:2!T:6L@<W9E:6MI96II('-K86GH:6%I+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T,3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(M!I86UE(&QA
M=6ME(&=A;&D@8OMT:2!T:6L@<VMA:>AI86D@:7(@9'9I=&'P:VEA:2XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DT"FUS9VED(")4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R("+0
M:6%M92!L875K92!G86QI(&+[=&D@=&EK(&'P='5N=&%I;FEA:2!S:V%IZ&EA
M:2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S"FUS9VED(")4
M:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@
M;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"B+0:6%M92!L875K92!T=7)I
M(&+[=&D@:V%B;&5L:6%I<R!A<F)A('1A<G!A:7,@871S:VER=&D@<W9E:6MI
M96II('-K86GH:6%I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@Y
M"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM
M<V=S='(@(M!I(')E:6OP;>L@='5R:2!B^W1I('-K86GH:75S+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,S8*;7-G:60@(B(*(E1H:7,@9FEE
M;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F
M;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@HB
MT&EA;64@;&%U:V4@9V%L:2!B^W1I('1I:R!S<&%L=F]S(&MO9&%S(%)'0B!(
M97@@9F]R;6%T92P@<&%V>7ID_FEU:2`B"B(G(S$R,S1!1B<N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O<FT@:&%S
M(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(M!I(&9O<FUA(&IA
M=2!A<&1O<F]T82XB"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R(")486D@
M)7,N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O
M8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E
M;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O
M=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L
M:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*(E1A:2!+;VQA8B!'
M<F]U<'=A<F4@;V)J96MT87,N($YO<NMD86UI('!E<OYI^W+K=&D@;V)J96MT
MX"!P<FEV86QO=&4@='5RZW1I("(*(F5L+B!P8?!T;R!K;&EE;G3@+"!K=7)I
M<R!S=7!R86YTX"#PX2!F;W)M873@+B!4;VMI^"!E;"X@<&'P=&\@:VQI96YT
M^"!SX')A\.`@(@HB9V%L:71E(')A<W1I(&%P<VEL86YKYB`E<R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R
M86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B
MT&ES(&QA:?!K87,@8G5V;R!P87)A\'ET87,@)7,@:V]D=6]T92X@2OMS(&YA
M=61O:F%T92!K:71O:VG@(&MO9'5O=.8N(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@
M870@;&5A<W0@;VYE+B(*;7-G<W1R("+0:7,@<VMA:>AI=7,@='5R:2!B^W1I
M(&1I9&5S;FES('7^(&YU;.$N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U
M;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`BT&ES('-E
M<G9E<FES(&YE9V%L:2!I\&%R8VAY=G5O=&D@>FEP(&ER(&=Z:7`@9F%I;/@N
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ.#D*
M;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB
M"FUS9W-T<B`BT&D@<VES=&5M82!D86)A<B!I\&IU;F=T82XB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU
M92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R("+0:2!R96EK\&WK('1U<FD@
M8OMT:2!S:V%IZ&EU<RXB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K
M97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F
M<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(M#A(&QA;F?@(')E:6MI
M82!A=&ED87)I;NMT:2!I\"!N=7-T871Y;?@@;&%N9V\B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B5&AU;F1E
M<B(*;7-G<W1R(")097)K^VYI:F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C,T"FUS9VED(")4:6-K971S(@IM<V=S='(@(D)I;&EE=&%I(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R."!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(E1I;64B"FUS9W-T<B`B3&%I:V%S
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X-@IM<V=I9"`B5&EM
M92!4<F%C:VEN9R(*;7-G<W1R("),86EK;R!A<'-K86ET82(*"B,Z(&QI8B]"
M;&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B
M3&%I:V\@9F]R;6%T87,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-3,Y"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R("),86EK;R!P87-I
M<FEN:VEM87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*
M;7-G<W1R(")4:6UO<FQE<W3K(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM
M<V=I9"`B5&ET;&4B"FUS9W-T<B`B4&%R96EG;W,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H
M=&]O;'1I<"DZ(@IM<V=S='(@(E!A=F%D:6YI;6%S.B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM
M<V=S='(@(DMA;2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M
M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C
M*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*(DYO<NMD86UI
M('!A<VER:6YK=&D@:V5L973@(&5L96UE;G3X+"!L86EK>6MI=&4@0V]N=')O
M;"`H4$,I(&%R8F$@0V]M;6YA9"`B"B(H36%C*2!K;&%V:?#@+"!I<B!P87-I
M<FEN:VET92!P96QE+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS,3$*;7-G:60@(E1O9&%Y(@IM<V=S='(@(M!I86YD:65N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B
M5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(E)O9'ET:2!(5$U,(&MO9.`B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4;V=O(@IM<V=S='(@(E1O9V%S(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R(")4;VME;&%U
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,PIM<V=I9"`B
M5&]M;W)R;W<B"FUS9W-T<B`B4GET;VHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED
M(")4;VYG82(*;7-G<W1R(")4;VYG82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S
M='(@(E9I<O!U:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@
M(E9I<O!U=&EN:6%M92!L86YG92`H7W1O<"DB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R(")697)T
M:6UA:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A
M9V\B"FUS9W-T<B`B5')I;FED861A<R!I<B!4;V)A9V%S(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B5')U92!O<B!F86QS92(*
M;7-G<W1R(")486EP(&%R8F$@;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R(")!;G1R
M+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B5'5N
M:7-A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R(")4
M=7)K:6IA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E1U
M<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(E1U<FMI\&MA("A)4T\M.#@U
M.2TY*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G
M<W1R(")4=7)K;>MN:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@
M86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@(E1U<FMS;R!I<B!+86EK;W-O
M('-A;&]S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@
M(E1U=F%L=2(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-C0*;7-G:60@
M(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R("+!=F5S:VET92!S879O('!A
M<VER:6YK:6W@.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C8Y"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B52Y6+B!I;F1E:W-A
M<SH@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S
M='(@(E523"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV
M97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B4VMR:7!T;R!P<FES=&%T>6UO
M('-T871U<V\@<F%P;W)T;R!54DPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(E52
M3#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`B56=A
M;F1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G<W1R(")5
M:W)A:6YA(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$R"FUS
M9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@
M(DYE<&%V>6MO('!E<G-K86ET>71I(%9&4R!K871A;&]G;RXB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T
M;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N
M(@IM<V=S='(@(DYE<&%V>6MO('!R:63K=&D@<&%P:6QD;VUO<R!V87)T;W1O
M:F\@<F5G:7-T<F%C:6IO<R!I;F9O<FUA8VEJ;W,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HS.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(DYE<&%V>6MO('!A:V5I<W1I(%9&4R!F86EL;R!<(B5S7"(@
M=&5I<VGX+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,X-2!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I
M;&4@)7,O)7,N(@IM<V=S='(@(DYE<&%V>6MO('!A:V5I<W1I('1E:7-I^"!6
M1E,@9F%I;'5I("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-S4U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@
M=&\@)7,N(@IM<V=S='(@(DYE<&%V>6MO('!E<F5I=&D@X2`E<RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S,@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S
M7"(N(@IM<V=S='(@(DYE<&%V>6MO(&%T:61A<GET:2!61E,@9F%I;&\@7"(E
M<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8X."!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S7"(N(@IM
M<V=S='(@(DYE<&%V>6MO('!E<G9A9&EN=&D@5D93(&9A:6QO("5S+R5S+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HT,S4*;7-G:60@(E5N
M86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(DYE<&%V
M>6MO('!R:7-I:G5N9W1I('!R:64@4U%,('-E<G9E<FEO+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,Y"FUS9VED(")5;F%B;&4@=&\@8V]N
M;F5C="!W:71H(%-33"XB"FUS9W-T<B`B3F5P879Y:V\@<')I<VEJ=6YG=&D@
M4U-,(')E_FEM=2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M,C4@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,P"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,C`Y"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS
M9W-T<B`B3F5P879Y:V\@;G5K;W!I:G5O=&D@5D93(&9A:6QO+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S8U"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM
M<V=S='(@(DYE<&%V>6MO('-U:W5R=&D@5D93(&MA=&%L;V=O(%PB)7-<(BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-30@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,C4V"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(DYE<&%V>6MO('-U:W5R=&D@5D93(&MA=&%L
M;V=O+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(DYE<&%V
M>6MO('-U:W5R=&D@5D93(&9A:6QO+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z,C@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(").97!A
M=GEK;R!P97)V861I;G1I(%9&4R!F86EL;R!<(B5S7"(N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8U"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R(").97!A=GEK;R!S=6MU<G1I
M('1U\.AI;R!61E,@9F%I;&\N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+W1A<BYP:'`Z-S8*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+V=Z:7`N<&AP.C<Y"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D
M871A+B(*;7-G<W1R(").97!A=GEK;R!I\&%R8VAY=G5O=&D@9'5O;65N^"XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R-"!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C(Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP
M='DN(@IM<V=S='(@(DYE<&%V>6MO(&GP=')I;G1I(%PB)7-<(BP@:V%T86QO
M9V%S(&YE='7PZ&EA<R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HT-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R(").97!A
M=GEK;R!I\'1R:6YT:2`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HS,S$@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS.3(*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S,T"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M
M<'1Y(@IM<V=S='(@(DYE<&%V>6MO(&GP=')I;G1I("5S+"!K871A;&]G87,@
M;F5T=?#H:6%S(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,T."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN
M(@IM<V=S='(@(DYE<&%V>6MO(')E:W5R<VGP:V%I(&GP=')I;G1I(%9&4R!K
M871A;&]G;RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S<@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T
M-`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G
M<W1R(").97!A=GEK;R!I\'1R:6YT:2!61E,@:V%T86QO9V\N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,3<@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HT,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B3F5P879Y:V\@:?!T
M<FEN=&D@5D93(&MA=&%L;V=O.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C(P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F5P879Y:V\@:?!T
M<FEN=&D@5D93(&9A:6QO(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR.#@*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,X
M,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R(").97!A=GEK
M;R!I\'1R:6YT:2!61E,@9F%I;&\N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HR-#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(DYE<&%V
M>6MO(&GP=')I;G1I(%9&4R!F86EL;R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HT,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R(").
M97!A=GEK;R!R96MU<G-I\&MA:2!I\'1R:6YT:2!61E,Z("5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#`S"FUS9VED(")5;F%B;&4@=&\@
M9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R(").97!A=GEK
M;R!N=7-T871Y=&D@9&%B87)T:6YI;R!K871A;&]G;RXB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8P,PIM<V=I9"`B56YA8FQE('1O
M(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R(").97!A=GEK
M;R!G875T:2!S97)T:69I:V%T;R!A<')A\'EM;R(*"B,Z(&9R86UE=V]R:R].
M971?24U34"])35-0+G!H<#HT-3$@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O
M075T:"YP:'`Z,3$X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L
M;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R(").97!A=GEK;R!U
M_FMR875T:2`E<R!A<')A\'EM;RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`Q"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-C8@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W,0IM<V=I9"`B56YA8FQE('1O(&UO
M=F4@5D93(&9I;&4N(@IM<V=S='(@(DYE<&%V>6MO('!E<FME;'1I(%9&4R!F
M86EL;RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`R"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z-C0X(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R(").97!A=GEK;R!A=&ED87)Y=&D@5D93(&9A:6QO(%PB
M)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-S<@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,S"FUS9VED(")5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B3F5P879Y:V\@871I
M9&%R>71I(%9&4R!F86EL;R!R8?!Y;75I+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C@P(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S
M,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(*;7-G:60@
M(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R(").97!A=GEK;R!A
M=&ED87)Y=&D@5D93(&9A:6QO+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R
M97-S960@87)C:&EV92XB"FUS9W-T<B`B3F5P879Y:V\@871I9&%R>71I('-U
M<W!A=7-T;R!A<F-H>79O+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX
M,S4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF
M:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(DYE<&%V>6MO(.%R8?!Y=&D@
M5D93(&9A:6QO("AC;W!Y*"D@:VQA:61A*2XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z.#8V"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5A9"!6
M1E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G<W1R(").97!A
M=GEK;R#A<F'P>71I(%9&4R!F86EL;R`H8V]P>2@I(&ML86ED82DN(@H*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N
M<&AP.C,X"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B
M"FUS9W-T<B`B3F5P879Y:V\@<&5R=F%D:6YT:2!61E,@9F%I;&\N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C8Y"FUS9VED(")5;F%B;&4@
M=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(DYE<&%V
M>6MO('!E<G-K86ET>71I('9F<W)O;W0@:V%T86QO9V\N(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3`U"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E
M<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R(").97!A=GEK;R!P97)V861I;G1I
M("5S(.$@)7,Z('1O:W,@:V%T86QO9V%S(&IA=2!E9WII<W1U;VIA(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Y,PIM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").97!A=GEK
M;R!P97)V861I;G1I(%9&4R!K871A;&]G;RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C,R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(").97!A=GEK
M;R!P97)V861I;G1I(%9&4R!K871A;&]G;SH@)7,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HR-C<@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!6
M1E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYE<&%V>6MO('!E<G9A9&EN=&D@
M5D93(&9A:6QO(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HV,3`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S
M+R5S+B(*;7-G<W1R(").97!A=GEK;R!P97)V861I;G1I(%9&4R!F86EL;R`E
M<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R,R!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C(X-0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R(").
M97!A=GEK;R!P97)V861I;G1I(%9&4R!F86EL;RXB"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@
M(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R(").97!A=GEK;R!P
M86QE:7-T:2`G;6MI<V]F<R<N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T
M92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B3F5P879Y:V\@:?!V97)S
M=&D@\&EO(%=O<F0@9&]K=6UE;G1O(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HQ-#D@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-3(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B3F5P879Y:V\@X7)A\'ET:2!61E,@9F%I;&\@7"(E
M<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W.0IM<V=I
M9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB
M"FUS9W-T<B`B3F5P879Y:V\@X7)A\'ET:2!61E,@9F%I;&\@*&-O<'DH*2!K
M;&%I9&$I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X,2!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#,*;7-G:60@(E5N86)L92!T;R!W
M<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R(").97!A=GEK;R#A<F'P>71I
M(%9&4R!F86EL;R!D=6]M96[X+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HX-#$*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL
M92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS9W-T<B`B3F5P879Y:V\@
MX7)A\'ET:2!61E,@9F%I;&\@*&-O<'DH*2!K;&%I9&$I+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N
M9&5R;&EN92(*;7-G<W1R(")086)R875K=&DB"@HC.B!T96UP;&%T97,O<')E
M9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B073P
M875K=&D@<&%K96ET:6UU<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T
M:6]N(@IM<V=S='(@(D%T\&%U:W1I(&%N:W-T97-NX2!V96EK<VW@(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y,`IM<V=I9"`B
M56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N
M.B`B"FUS9W-T<B`B3F5T:6OK=&$@<V5R=F5R:6\@:VQA:61A.B`B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W.`HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*;7-G:60@(E5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R(").971I
M:^MT82!S97)V97)I;R!K;&%I9&$Z("(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM
M<V=S='(@(DYE;G5R;V1Y=&$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M,PIM<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(E5N:6MO9&%S("A5
M5$8M."DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T
M97,B"FUS9W-T<B`B2G5N9W1I;FEA:2!!<F%B^"!%;7ER871A:2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B2G5N9W1I
M;NL@2V%R86QY<W3K(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T
M871E<R(*;7-G<W1R(")*=6YG=&ENZW,@5F%L<W1I:F]S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA
M;F1S(@IM<V=S='(@(DIU;F=T:6YI^"!686QS='EJ^"!!=&]K97-NZW,@<V%L
M;W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HW,0IM<V=I9"`B56YI=',B"FUS9W-T<B`B5FEE;F5T
M86DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N
M(@IM<V=S='(@(DYE_FEN;VUA<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM
M<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R(").9?YI;F]M87,@87!I
M;7-G:60@*$%022!-97-S86=E($E$*2XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@
M8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B3F7^:6YO
M;6%S(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.0HC+"!F=7IZ>0IM<V=I9"`B56YK
M;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B3F5N=7-T871Y=&$@
M=FEE=&]VZRXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S
M<W=O<F0N(@IM<V=S='(@(DYE_FEN;VUA<R!V87)T;W1O:F\@=F%R9&%S(&ER
M+V%R8F$@<VQA<'1A_F]D:7,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE
M(&-U<G)E;G0@96QE;65N="(*;7-G<W1R(")086YA:6MI;G1I(&YU;W)O9.`@
M\&EA;2!E;&5M96YT=6DB"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I
M='DN<&AP.C(Y-@IM<V=I9"`B56YN86UE9"(*;7-G<W1R(").9>%V87)D:6YT
M87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C
M97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C
M=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N
M;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@
M86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S
M='(@(B(*(E-A=6=U;6\@<W5M971I;6%I<R!N97!R:79I;&5G:6IU;W1I('-K
M<FEP=&%I(&YE9V%L:2!A=&QI:W1I(%!E<FOK;&EM;R\B"B)+;W!I:F%V:6UO
M+\%KZVQI;6\@<')O9W)A;6GP:V%I+B!.;W+K9&%M:2!P97+^:?MRZW1I('1E
M8VAN:6YE<R!D971A;&5S("(*(FUO>FEL;&$N;W)G('1I;FML87!Y:F4L(&ER
M('-U_FEN;W1I(&MA:7`@<VMR:7!T86US(&QE:7-T:2!P<FEE:71I('!R:64@
M(@HB;&%I:VEN;W-I;W,@<V%U9WEK;&]S+"!P87-P875S:VET92!/2RXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R(").96YA=61O=&D@<W!A
M;'9O<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@V
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3,R"FUS9VED(")5;G-U<'!O
M<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B4&SK=&EN>7,@;F5P86QA:6MO;6%S
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G
M<W1R(")!=&YA=6II;G1I(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS
M9W-T<B`B071N875J:6YT:2`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z-S8*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(D%T
M;F%U:FEN=&D@=F%R=&]T;VK@(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@
M861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HR,S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@
M7"(E<UPB+B(*;7-G<W1R("(G)7,G(&%T;F%U:FEN=&$N(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E
M;&5T960N(@IM<V=S='(@(D%T;F%U:FEN:6UO('-K<FEP=&%S(&GP=')I;G1A
M<RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3D*;7-G:60@(E5P;&]A9"(*
M;7-G<W1R(").=7-I^'-T:2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE
M<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R(")6:7-I(&UO9'5L:?@@871N875J
M:6YI;6\@9F%I;&%I(.%K96QT:2#A('-E<G9E<N$N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I
M9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R(")$:63^:6]S:6]S(&QO
M=&EN:?!K;W,@<F%I9.MS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@
M;G5M8F5R<R(*;7-G<W1R(")$:61I96II(')O;>MN:?!K:2!S:V%IZ&EA:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B57)U9W9A
M:G5S(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E
M<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S
M(@IM<V=S='(@(DYA=61O=&D@9&%B87)T:6[F.B`E<R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5
M<V4@4U-,(@IM<V=S='(@(DYA=61O=&D@4U-,(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$R-`IM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@
M9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B3F%U9&]T:2!J
M96EG=2!V87)T;W1O:F\@=F%R9&%S+W-L87!T8?YO9&ES($E-4U`@<V5R=F5R
M:75I('ER82!K:71O:W,N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8SHR,0HC+"!F=7IZ>0IM<V=I9"`B57-E<B(*;7-G<W1R(")687)T
M;W1O:F%I(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H
M<#HW,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T
M:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(E9A<G1O=&]J87,@)7,@;F5A=71O
M<FEZ=6]T87,@<')IZVII;75I('!R:64@)7,N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E9A
M<G1O=&]J^"!A9&UI;FES=')A=FEM87,B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C(U,0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@
M(E9A<G1O=&]J;R!N=7-T871Y;6%I(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I
M9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B5F%R=&]T;VKX(')E9VES
M=')A8VEJ82(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T
M<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S
M='(@(E9A<G1O=&]J^"!R96=I<W1R86-I:F$@:?!J=6YG=&$N(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C0V.0HC+"!F=7IZ>0IM<V=I9"`B57-E<B!A
M8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R("(E<R!N97)A<W1A<RXB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N
M<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R(")687)T
M;W1O:F\@=F%R9&%S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@
M7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R(")687)T;W1O:F\@=F%R
M9&%S("<E<R<@:F%U(&5G>FES='5O:F$N(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B5F%R
M=&]T;VIO('9A<F1A<SHB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHX"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(E9A<G1O=&]J;R!V87)D
M87,Z("(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G
M:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(E9A<G1O=&]J86D@
M\&EO:F4@<VES=&5M;VIE.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K
M:7-T86XB"FUS9W-T<B`B57IB96MI<W1A;F%S(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,38S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(U-0IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS
M9W-T<B`B5D93(&MA=&%L;V=A<R!N965G>FES='5O:F$N(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C871I;VXB"FUS9W-T
M<B`B071O<W1O9V]S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V
M"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S
M='(@(E)A<W1O<R!T96ES:6YG;W,@=FEE=&]VZW,Z("(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,X"FUS9VED(")686QI9&ET>2(*
M;7-G<W1R(")'86QI;VII;6%S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS9VED(")686QU92!I;B!M
M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R(")296EK\&WK(&UI;G5TZVUI<R!N
M=6\@9&%B87(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4V(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#0@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S$V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C@*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I
M9"`B5F%L=65S(@IM<V=S='(@(E)E:6OP;>MS(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$P.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@V
M"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B4F5I:_!M
MZW,@:?`@:W5R:?@@9V%L:6UA('!A<VER:6YK=&DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W
M"FUS9VED(")686YU871U(@IM<V=S='(@(E9A;G5A='4B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0T"FUS9VED(")687)I86)L92(*;7-G
M<W1R(")+:6YT86YT:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E
M;&$B"FUS9W-T<B`B5F5N97-U96QA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@
M+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*
M;7-G<W1R(")0871V:7)T:6YI;6%S(&YE8F%I9W1A<R`M(/!I<R!L86GP:V%S
M('-U9V%D:6YT87,N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HW,#`*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B5F5R<VEJ82(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C8*;7-G:60@(E9E<G-I;VX@
M0V]N=')O;"(*;7-G<W1R(")697)S:6KX(&MO;G1R;VSK(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I
M9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B3'EG:75O=&D@=F5R=&EK86QI
M86DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(E9E<G1I:V%L
M=7,@=&%R<&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(E9E<G1I:V%L
M=7,Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S`*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R("),86)A:2!D:61E;&ES(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B5FEE=&YA
M;6%S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@(E9I971N
M86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B5FEE=&YA;6EE=&GP:V$@*%9)4T-)
M22DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HY-C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R(")097+^:?MR
MZW1I("5S(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE
M=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R(")2;V1Y=&D@:?!O<FEN
MX2!P=7-L87#A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z.#(Q"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T
M<B`B4&5R_FG[<NMT:2!K86EP("5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B
M5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B0G)I=/@@5FER9/YI
M;FEJ;W,@<V%L;W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L
M86YD<RP@52Y3+B(*;7-G<W1R(")*058@5FER9/YI;FEJ;W,@<V%L;W,B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.0IM<V=I9"`B5FES:6)I;&ET>2(*
M;7-G<W1R(")-871O;75M87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C8S"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B36%T;VUU
M;6%S.B`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B
M"FUS9W-T<B`B5F]D869O;F4@271A;&EJ82!P97(@4TU44"(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B5T%23B(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!
M4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G
M<W1R(")$RTU%4TE/(2$A(%!!5%E3($G05%))3DM)5$4@4TM225!4P"!)T"`E
M<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S
M,PHC+"!F=7IZ>0IM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(G-M<S)E
M;6%I;"!P97(@2%144"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A
M;F0@1G5T=6YA(@IM<V=S='(@(E9A;&ES(&ER($9U='5N82(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U
M<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP
M:'`Z,C<R(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN
M9R(*;7-G<W1R(")$ZVUE<VEO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B5')EZ"XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E
M871H97(@1F]R96-A<W0B"FUS9W-T<B`B3W+X('!R;V=N;WKK(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0R-PIM<V=I9"`B5V5A=&AE<B!D
M871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(D]R^"!P<F]G;F]ZZR!P86=A;"(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A=&AE
M<BYC;VTB"FUS9W-T<B`B5V5A=&AE<BYC;VTB"@HC.B!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(E=75R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT,S<*;7-G:60@(E=E8B!3:71E(@IM<V=S
M='(@(E=75R!P=7-L87!I<R(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-
M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R(")+87,@
M<V%V86ETYB(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS
M9VED(")796QC;VUE(@IM<V=S='(@(E-V96EK:2(*"B,Z('1E;7!L871E<R]L
M;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@
M(E-V96EK:2!A='9Y:^8@X2`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I
M;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R("),86)A<RP@)7,B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5V5S=&5R;B`H
M25-/+3@X-3DM,2DB"FUS9W-T<B`B5F%K87+X("A)4T\M.#@U.2TQ*2(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED(")797-T97)N("A)4T\M
M.#@U.2TQ-2DB"FUS9W-T<B`B5F%K87+X("A)4T\M.#@U.2TQ-2DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B5F%K87+X
M(%-A8VAA<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,W"B,L('!H
M<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I
M<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(DMO:^$@;6]D=6SA("5S('1U
M<FD@<F]D>71I('!O('!R:7-I:G5N9VEM;S\B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R
M(&-H87)A8W1E<C\B"FUS9W-T<B`B2V]K<R!S:VER='5K;R!S:6UB;VQI<S\B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA
M="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R(")+;VMS(&MA8G7H
M:?@@<VEM8F]L:7,_(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$P-C$*(RP@9G5Z>GD*;7-G:60@(E=H97)E:7,@075S=')A
M;&EA(&UA<"(*;7-G<W1R(")!=7-T<F%L:6IA(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B2W5R:6]S
M(&9A>NMS(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PIM<V=I9"`B
M5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I
M=&]R+B(*;7-G<W1R(")(5$U,(')E9&%K=&]R:6%U<R!M;V1U;&GX(.%J=6YG
M:6UA<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R(")0;&]T:7,B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(U"FUS9VED(")7:61T:"!I
M;B!#4U,@=6YI=',B"FUS9W-T<B`B4&QO=&ES($-34R!M871A:7,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4W"B,L('!H<"UF;W)M870*;7-G:60@
M(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E
M8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("(E<R!K86ER:6]J;R!M96YI
M=2!P;&]T:7,@*'!A:V5I=&EM86D@8G5S(&UA='ET:2!P;R!K:71O('!R:7-I
M:G5N9VEM;RDZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R
M("),96YT96SK<R!P;&]T:7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R
M(")0;&_H:6\@;6%T87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(E!L;W1I
M<SHB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$S"FUS9VED(")7
M:6MI(@IM<V=S='(@(E=I:VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S`P(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8U"B,L(&9U>GIY"FUS9VED(")7:6YD(@IM<V=S='(@(E;K:F%S.B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"B,L(&9U
M>GIY"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(DQI971U<R!R>71E(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,`IM<V=I9"`B5VEN9"!S<&5E9"!I
M;B!K;F]T<R(*;7-G<W1R(")6ZVIO(&=R96ET:7,@;6%Z9V%I<R(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,34V"FUS9VED(")7:6YD.B(*;7-G<W1R(")6
MZVIA<SHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0R"FUS
M9VED(")7:6YD.B`B"FUS9W-T<B`B5NMJ87,Z("(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(DGP;6EN=&ES
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y-@HC+"!F=7IZ>0IM
M<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B4&%G96ED879I;6%I(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S='(@(D1A
M<F)A<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(D1A<F)O(&%D<F5S
M87,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(D1A<F)O('1E;&5F;VYA
M<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$V.2!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E
M9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C,P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB
M97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Q-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E
M861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B4VES=&5M82!N971U<FD@=&5I
M<VGX('-U:W5R=&D@5D93(&9A:6S@+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR-#,*;7-G:60@(E@M4F5F(@IM<V=S='(@(E@M4F5F(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U
M,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R(")8-3`Y=C,@<&%G<FEN
M9&EN:6%I(&YU<W1A='EM86DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G
M92(*;7-G<W1R(")8-3`Y=C,@:?!P;.MS=&\@<F%K=&\@<&%N875D;VII;6%S
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G
M:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B
M6#4P.78S(&%L=&5R;F%T>79U<R!V87)D87,B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@
M2V5Y($ED96YT:69I97(B"FUS9W-T<B`B6#4P.78S(')A:W1O(&ED96YT:69I
M:V%T;W)I=7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8X,@IM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B6#4P.78S
M(&UO9'5L:6%I(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9
M(@IM<V=S='(@(EE9(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0Q,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#4U"FUS9VED(")965E9(@IM<V=S='(@(EE965DB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$P.`IM<V=I
M9"`B66%H;V\A(&UA<"(*;7-G<W1R(")986AO;R$@_F5MZVQA<&ES(@H*(SH@
M9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I
M9"`B665A<FQY(@IM<V=S='(@(DMA<VUE="(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G
M:60@(EEE;65N(@IM<V=S='(@(DIE;65N87,B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(")997,B"FUS9W-T
M<B`B5&%I<"(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC
M92YH=&UL.C4V"FUS9VED(")997,L($D@06=R964B"FUS9W-T<B`B5&%I<"P@
M8?`@<W5T:6YK=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E
M('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*
M;7-G<W1R("(B"B)*^W,@97-A=&4@5$5+4U1)3DE!344@4D7>24U%+B!.;W+K
M9&%M:2!G<N'^=&D@X2!765-)5UE'('-P875S:VET92!;/#Y=+B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@
M8FQO8VMS+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$T,3$*;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM
M<V=S='(@(DK[<R!N97!R:7-I:G5N9^8N(@H*(SH@9G)A;65W;W)K+TED96YT
M:71Y+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(EEO=2!C86X@;F]T(&AA=F4@
M=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R
M(")3879O('9A<F1E(&YE9V%L:71E(&YA=61O=&D@<VEM8F]L:6\@)UQ<)RXB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4U(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Y-S4*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@
M=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`BP79E9.MT92!N971E:7-I
M;F?@(&5L+B!P8?!T;R!A9')E<^`N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T
M82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@
M;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@
M8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(DYE<')I
M:G5N9^MT92!J;VMI^"!L875K^"!I\"#A:V5L:6%M;R!F86EL;R!P<FEE("5S
M(&%T:71I;FMA;?@@;&%U:_@N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z.3@X"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S
M='(@(DK[<R!A='-I:G5N9^MT92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED
M(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N
M86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I
M>"XB"FUS9W-T<B`B(@HB5'5R:71E(.%V97-T:2!T96ES:6YGX"!T96QE9F]N
M;R!N=6UE<N$@*'1I:R!S:V%IZ&EU<R!I<B`G*R<L(&IE:6=U(&YO<FET92`B
M"B)N=7)O9'ET:2!T87)P=&%U=&ENX2!K;V3@*2XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A
M('9A;&ED('9A;'5E+B(*;7-G<W1R("+!=F5DZW1E(&YE=&5I<VEN9^`@<F5I
M:_!MYBXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*
M;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@
M=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*(DYO<NMD86UI(&YA=6=O=&ES
M(')E9VES=')A8VEJ;W,@<VES=&5M82P@='5R:71E('-U:V]N9FEG^W)U;W1I
M(&1U;VUE;O@@(@HB;65D_FEO('!O<VES=&5MYBXB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C0U-@HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@
M8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(B(*(DYO<NMD86UI
M(&YA=6=O=&ES(')E9VES=')A8VEJ;W,@<VES=&5M82P@='5R:71E('-U:V]N
M9FEG^W)U;W1I(&1U;VUE;O@@(@HB;65D_FEO('!O<VES=&5MYBXB"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU
M<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T
M:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(E!R:67P('-I^'-D86UI('!R
M86YE\&EMX"P@87!R8?!Y:VET92!P<F]B;&5MX"XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S
M="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS
M9W-T<B`BP7)A\'EK:71E(&YU;W)O9&]S(%523"(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@
M<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(E1U<FET92!P87-I<FEN
M:W1I('-E<G9E<N$L(&MU<N$@;F]R:71E(&GP=')I;G1I+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B3G5R;V1Y:VET92!V87)T;W1O
M:F\@=F%R9.`L(&MU<FEO(&1U;VUE;FES('1R:6YA=&4N(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA
M;64@=&\@<F5M;W9E+B(*;7-G<W1R(").=7)O9'EK:71E('9A<G1O=&]J;R!V
M87)DX"!T<GEN:6UU:2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P
M96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B3G5R;V1Y:VET
M92!K=7)I86UO('9A<G1O=&]J;R!V87)DX"XB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O
M('5P9&%T92XB"FUS9W-T<B`B3G5R;V1Y:VET92!A=&YA=6II;F%M;R!V87)T
M;W1O:F\@=F%R9.`N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T
M:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(DYU<F]D>6MI=&4@=F5I:W-MX"XB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H
M<#HW,0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE
M+B(*;7-G<W1R(")*^W,@='5R:71E(.%V97-T:2!N875J;W,@:V%T96=O<FEJ
M;W,@<&%V861I;FEMX"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O
M=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@
M86=A:6XN(@IM<V=S='(@(B5S('-E<VEJ82!B86EGZW-I+B!0<F'P;VUE('!R
M:7-I:G5N9W1I(&GP(&YA=6IO+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C,X"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T
M<B`B2OMS^"!E;"X@<&'P=&\@861R97-A<SHB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C$R"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S
M='(@(D5L+B!P8?!T;R!A9')E<V%S.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I
M9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA8VEJ82!A<&EE
M($IU<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H
M86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN
M(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@
M86=A:6XN(@IM<V=S='(@(B(*(DYU;R`E<R!S97-I:F]S('!R863^:6]S(&K[
M<_@@25`@861R97-A<R!P87-I:V5I=.LN(%1U<FET92!P<FES:6IU;F=T:2!I
M\"`B"B)N875J;RXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHS,PIM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(DK[<_@@=F%R9&%S+W!A
M=F%R9.LB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-0HC
M+"!F=7IZ>0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD
M(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T
M;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y
M;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C
M:V5N9"XB"FUS9W-T<B`B(@HB2OMS^"!S:7-T96UO<R!A=71E;G1I9FEK879I
M;6\@<&]S:7-T96WK(&YE<&%L86EK;R!V87)T;W1O:O@@:_MR:6UO+"!A<F)A
M(/!I("(*(F=A;&EM>6+K(&GP:G5N9W1A(&3K;"!T86T@=&EK<O@@<')I9?YA
M<^AI^"XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*
M;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO
M="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA
M<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T
M<B`B(@HB2OMS^"!A=71E;G1I9FEK879I;6\@<VES=&5M82!N97!A;&%I:V\@
M=F%R=&]T;VKX('/@<F'P;RP@87)B82#P:2!F=6YK8VEJ82`B"B)U_F1R875S
M=&$@9.ML('1A;2!T:6MR^"!P<FEE_F%SZ&GX+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.CDX-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R
M(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E
M9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U
M<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*
M(DYU;R`E<R!S97-I:F]S('!R863^:6]S(&K[<_@@;F%R\'EK;.MS('1I<&%S
M('!A<VEK96ETZRX@5'5R:71E('!R:7-I:G5N9W1I("(*(FGP(&YA=6IO+B(*
M"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4P"FUS9VED(")9;W5R(&)R;W=S
M97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S='(@(DK[
M<_@@;F%R\'EK;.L@;F5P86QA:6MO(/!I;W,@9V%L:6UY8NMS+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"B,L(&9U>GIY"FUS9VED
M("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT
M(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN
M="XB"FUS9W-T<B`B(@HB2OMS^"!N87+P>6MLZR!N97!A;&%I:V\@\&EO('-P
M875S9&EN:6UO(&YU<W1A='EM;RX@3F]RZV1A;6D@871S<&%U<V1I;G1I("(*
M(G-P875S:VET92!#;VYT<F]L+T]P=&EO;B`K(%`N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(U-PIM<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N
M93HB"FUS9W-T<B`B2OMS^"!L86EK;R!J=6]S=&$Z(@H*(SH@<V5R=FEC97,O
M<')E9G,N<&AP.CDV"B,L(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@:61E
M;G1I='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`B2OMS^"!S=&%N9&%R
M=&EN:7,@87!R8?!A<SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X
M"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(DK[<_@@
M<W1A;F1A<G1I;FES(&%P<F'P87,Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(P,0IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(DK[<_@@
M=F%R9&%S+W!A=F%R9.LZ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M,3`P,`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB
M"FUS9W-T<B`B2OMS^"!N=7-T871Y;6%I(&%T;F%U:FEN=&DN(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R(")*
M^W/X(&YA=6IA<R`E<R!S;&%P=&'^;V1I<R!Y<F$Z("5S(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*(RP@9G5Z>GD*;7-G:60@(EEO
M=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N
M(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B2OMS^"!N=7-T871Y;6%I(&%T
M;F%U:FEN=&DN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ
M-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS
M9W-T<B`B2OMS^"!N=7-T871Y;6%I(&%T;F%U:FEN=&DN(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@
M:&%S(&)E96X@<F5S970B"FUS9W-T<B`B2OMS^"!S;&%P=&'^;V1I<R!P86ME
M:7-T87,B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I
M9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U
M<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N
M(@IM<V=S='(@(B(*(DK[<_@@<VQA<'1A_F]D:7,@<&%K96ES=&%S+B!087-I
M=&EK<FEN:VET92!S879O('!A\'3@(&ER('!R:7-I:G5N:VET92!S=2`B"B)N
M875J=2!S;&%P=&'^;V3^:74N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z-S,R"B,L(&9U>GIY"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!E>'!I
M<F5D+B(*;7-G<W1R(")*^W/X('-L87!T8?YO9&ES('!A:V5I<W1A<R(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R
M96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B2OMS^"!N=71O;.8@<V5R=F5R:6%I
M.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4T(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU9V]S;&%V:6$B"FUS
M9W-T<B`B2G5G;W-L879I:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R("):86ER87,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T<B`B6F%M8FEJ82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(EII;6)A8G;K
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*
M;7-G<W1R(")%;F5R9VEN9V]S(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O
M=&5D(%1E>'1=(@IM<V=S='(@(EM087-LZW!T:2!C:71U;VIA;>`@=&5K<W3@
M72(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C@X"FUS9VED(");4')O8FQE
M;2!297!O<G1=(@IM<V=S='(@(EM0<F]B;&5M;W,@<')A;F7P:6UA<UTB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I
M9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R(");4F]D>71I(&-I='5O
M:F%MX"!T96MS=.`@+2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B6U)O
M9'ET:2!C:71U;VIA;>`@=&5K<W3@("T@)7,@96EL=71E<UTB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B6V5I;'5TZR`E<R!I\"`E<UTB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U-#$@=&5M<&QA=&5S
M+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(E]686QD>6UA<R(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B
M7T-,22(*;7-G<W1R(")?0TQ)(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED
M(")?1&%T851R964B"FUS9W-T<B`B7T1U;VUE;O@@;65D:7,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*
M;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(E])\'1R:6YT:2!E:6QU=.8B
M"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B
M1U]R=7#K<R(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ
M-S4*;7-G:60@(E](96QP(@IM<V=S='(@(E!A7V=A;&)A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS
M9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")?4&%V96EK<VSK
M;&EO(&YU<W1A='EM86DN+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M365N=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(E!R:7-I7VIU
M;F=T:2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.3`*
M;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(D%T<VE?:G5N9W1I(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T
M"FUS9VED(")?36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B7TME:7-T:2!N=6]R
M;V3@+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T
M"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R(")?3G5S=&%T>6UA:2(*"B,Z(&QI
M8B]A<&DN<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(E]4
M96ESZW,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R
M(")?2?!T<FEN=&D@;G5O<F]DX"XN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM
M<V=I9"`B7U-E='5P(@IM<V=S='(@(E]+;VYF:6?[<F%C:6IA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S
M"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")?3&5N=&5L
MZW,@;G5S=&%T>6UA:2XN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R.0IM<V=I9"`B
M7U5S97)S(@IM<V=S='(@(E9?87)T;W1O:F%I(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,C$*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R
M(")A9')E<_@@:VYY9V5LZR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3,T"B,L(&9U>GIY"FUS9VED(")A9&1R97-S964@=6YK;F]W
M;B(*;7-G<W1R(")A9')E<_@@:VYY9V5LZR(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3$S"FUS9VED(")C86QE;F1A<B(*;7-G<W1R(")+86QE
M;F1O<FEU<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS
M9W-T<B`B<F%M=7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S
M,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DR"FUS9VED(")C;&EC
M:R!H97)E(@IM<V=S='(@(G-P875S:VET92#H:6$B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE
M('5S86=E(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3<X"B,L(&9U>GIY"FUS9VED(")C;VYF:6=U<F%T
M:6]N(&5R<F]R(@IM<V=S='(@(B5S(&YU<W1A='EM86DB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@
M<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@
M97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ.#(*(RP@9G5Z>GD*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*
M;7-G<W1R("(E<R!N97)A<W1A<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R(")K
M<F5N=&$B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-34*
M;7-G:60@(F9I;&4B"FUS9W-T<B`B9F%I;&%S(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C`@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@
M)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R(")N=6\@)7,@*"5S*2`E<R`E<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3`*(RP@9G5Z>GD*
M;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B+"!G^W-I86D@)7,@)7,B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Y"FUS9VED
M(")H.B(*;7-G<W1R(")A.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HS-3@*;7-G:60@(FAH(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T
M(&YA;64@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(FEM;65D
M:6%T92(*;7-G<W1R(")T=6]J874@<&%T(@H*(SH@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN;&EN
M92(*;7-G<W1R(")P87!R87-T:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS
M9VED(")L:6YE<UTB"FUS9W-T<B`B96EL=71E<UTB"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA
M:VEN9R!)4T\N(@IM<V=S='(@(FUK:7-O9G,@:VQA:61O<R!K;V1A<R`E9"!B
M961A<F%N="!)4T\N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,V.0IM<V=I9"`B;6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HR.3$@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,C,R"FUS9VED(")N86UE(@IM<V=S='(@(G9A<F1A<R(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+G!H<#HQ,C$*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G
M<W1R(")N97)E86QI>G5O=&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C$R,3D*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS
M9W-T<B`B9&%R(&YE<F5A;&EZ=6]T82(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3`U"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(G7^<F'P^"!K
M;GEG96SK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R(")P<F]C96YT
M86DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W-`HC
M+"!F=7IZ>0IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`B5&5I
M<^MS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(G!I:W-E;&EA:2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED
M(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*;7-G:60@(G)I
M<VEN9R(*;7-G<W1R(")K>6QA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-#(*(RP@9G5Z>GD*;7-G:60@(G-E<G9I8V4@=6YA=F%I
M;&%B;&4B"FUS9W-T<B`B3W)O('/@;'EG^"!B;&]K;R!NZW)A+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z.3D*;7-G:60@(G-H;W<@9&EF9F5R96YC
M97,B"FUS9W-T<B`B<F]D>71I('-K:7)T=6UU<R(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R
M96UA:6P@=FEA($A45%`B"FUS9W-T<B`B<VUS,F5M86EL('!E<B!(5%10(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-0IM
M<V=I9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-S(*;7-G:60@(G-T96%D>2(*;7-G<W1R(")S=&%B
M:6QI(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#D*;7-G:60@
M(G-W:71C:"!O9F8@:F%V87-C<FEP="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R
M<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3(Y"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B9&%R8O@@<^!R8?!A<R(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38V"FUS9VED
M(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C,P-0HC+"!F=7IZ>0IM<V=I9"`B=')Y(&%G86EN
M(@IM<V=S='(@(DMI96MV:65N;R!P<FES:6IU;F=I;6\@;65T=2(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HR-CD*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I
M<FTB"FUS9W-T<B`B<VQA<'1A_F]DX2!T=7)I=&4@X7)A\'ET:2!D=2!K87)T
M=7,B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D
M:69F+G!H<#HW.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R(")U;FEF:6MU;W1I
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I9"`B
M=6YN86UE9"(*;7-G<W1R(")D86QI<R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S
M96QE8W0B"FUS9W-T<B`B=F%R=&]T;VIO('!A<VER:6YK:6UA<R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B
M=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C0Q"FUS9VED(")W.B(*;7-G<W1R(")P.B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T
M:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O;2(*```N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!O+VQV7TQ6+G!O````````````````````````````
M````````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`V,3$S-3(`,3`U,34T,S,W-30`
M,#$W-C8W`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````",@3&%T=FEA;B!T<F%N<VQA=&EO;B!F;W(@2&]R9&4N"B,@2V%S<&%R
M<R!+87!E;FEE:W,@/&MA<W!A<G-`<F-C+FQV/BP@,C`P,BX*(PIM<V=I9"`B
M(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,BXQ7&XB
M"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN
M(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN
M(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P,BTQ,2TR."`Q-#HP,"LP,C`P7&XB
M"B),87-T+51R86YS;&%T;W(Z($MA<W!A<G,@2V%P96YI96MS(#QK87-P87)S
M0')C8RYL=CY<;B(*(DQA;F=U86=E+51E86TZ($QA='9I86X@/&DQ.&Y`;&ES
M=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E
M;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U#4#$R-3=<;B(*(D-O;G1E
M;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET7&XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S8Y"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@
M9&%Y<R!A9V\I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3,W,`HC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E
M<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S,*;7-G:60@(B`H
M=&]D87DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S-S4*;7-G:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S$*;7-G:60@(B`H>65S=&5R9&%Y*2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4V
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C$*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C0P-PIM<V=I9"`B(&%T("(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z
M-C4Y"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`T
M,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C
M;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B)R5S
M)R!N878@;F]RXF3N=',@2&]R9&4@<F7L:7-T<N(B"@HC.B!F<F%M97=O<FLO
M5')E92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB
M('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W
M87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T
M96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR
M9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL
M('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T
M:6-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-S`T"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@S,R!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS
M9W-T<B`B)7,@57IT=7+G\&%N87,@;W!E<N)C:6IA<R`M(&%P<W1I<')I;N)J
M=6US(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HR-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#(X(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-#DP"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-C4Q(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.2!L:6(O0FQO8VLO;65T87(N<&AP
M.C$V-2!L:6(O0FQO8VLO;65T87(N<&AP.C(S.0HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,T-2!L:6(O0FQO8VLO;65T87(N<&AP.C,U,0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F
M;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H
M:7,@=&EM92XB"FUS9W-T<B`B071Z[FWG:FEE="!D87)B[F)A<RP@:V\@=N=L
M871I97,@=F5I:W0N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,T
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R(")+871R87,@-2!M
M:6[[=&5S(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN
M<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM
M<V=S='(@(EMR:6YD82`E<R!N;R`E<UTB"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDR,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G
M<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B2V]N=&%K=&DB"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDQ-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R(")+86QE;F3B<G,B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!4
M87-K;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO
M;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY
M(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@
M86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8U(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HT,3`*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Q"B,L('!H<"UF
M;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y-"!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,C@*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T.0IM
M<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T
M:6UE+G!H<#HR,`HC+"!F=7IZ>0IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS
M9W-T<B`B2OMS=2!I;F9O<FWB8VEJ82(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HQ.0HC+"!F=7IZ>0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B
M2OMS=2!I;F9O<FWB8VEJ82(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC
M.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"!S='5N9&%S(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED
M(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO
M8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,38P"B,L(&9U>GIY"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E
M9"(*;7-G<W1R("(\8CY)<B!N;W1I:W5S:2!K<FET:7-K82!K[_MM93H\+V(^
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED
M(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M
M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,38U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#DW"FUS9VED("(B
M"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3`Q-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*
M(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3`U"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y
M+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*
M(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D
M('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"FUS9VED(")!32!#;&]U
M9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G
M:60@(D%-(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B
M04TO4$TB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!
M8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]H96QP
M+VEN9&5X+G!H<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I
M9"`B06)S8F]T=&]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS
M9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8*
M;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"B,L(&9U>GIY"FUS
M9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(DK[<W4@:6YF;W)M
MXF-I:F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4*(RP@9G5Z>GD*
M;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B4&%R;VQE(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS
M"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,S,PIM<V=I9"`B06-C;W5N=&EN9R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T
M96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(D%D9"(*
M;7-G<W1R(")!9')E<V4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI
M;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3@@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD
M(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A
M9&0N:6YC.C4*(RP@9G5Z>GD*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R(")!
M9')E<V4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N
M<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD
M+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P
M('1O(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL
M9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-30*
M;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M96UB97)S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*
M;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(E!I979I96YO="!PXG)I(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C<Q"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G
M<W1R(")+;VYT86MT:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HW.`HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&UY(&%D9')E
M<W,@8F]O:R(*;7-G<W1R(")+;VYT86MT:2(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,Q"B,L(&9U>GIY"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R(")0:65V:65N
M;W0@<.)R:2(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U
M;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB
M)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@
M;&]G(&EN(&YO=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#$*;7-G
M:60@(D%D9')E<W,B"FUS9W-T<B`B061R97-E(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$S.0HC+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!";V]K
M(@IM<V=S='(@(DMO;G1A:W1I(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R
M;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S
M"FUS9VED(")!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S0Q"B,L(&9U>GIY"FUS9VED(")!9',B"FUS
M9W-T<B`B061R97-E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G:&%N:7-T86XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PHC+"!F=7IZ>0IM<V=I9"`B06QB86YI
M82(*;7-G<W1R(")!:7IS=.)J=N)R9',B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"B,L(&9U>GIY
M"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(D%I>G-TXFIVXG)D<R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@
M(D%L:6%S(@IM<V=S='(@(D%I>G-TXFIVXG)D<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*(RP@9G5Z>GD*
M;7-G:60@(D%L:6=N(@IM<V=S='(@(D%I>G-TXFIVXG)D<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L
M:6=N;65N=#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C@W"FUS9VED(")!;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV
M-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM
M<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.CDQ(&9R86UE=V]R:R]097)M<R]097)M<R]D871A
M=')E92YP:'`Z-S4*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<Q"FUS9VED(")!;&QO=R!M=6QT
M:7!L92!A9&1R97-S97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4S-`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI
M<W0@='EP93\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A
M=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!;')E861Y(&5X:7-T<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(S"FUS9VED(")!
M;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3`W"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R
M9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DY"FUS
M9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B
M06QT97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T<B`B2OMS=2!E+7!A<W1A
M(&%D<F5S93HB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B
M06QT97)N871E('1E;7!L871E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G
M:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS
M9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I
M960N(@IM<V=S='(@(DYO<N)D[G1A(&YE9&5R[F=A(';G<G3N8F$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38W"B,L(&9U>GIY"FUS9VED
M(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R("(\8CY)
M<B!N;W1I:W5S:2!K<FET:7-K82!K[_MM93H\+V(^(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM
M<V=I9"`B06YD;W)R82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!
M;F=O;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE
M;&PN<&AP.C,U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P
M;&EC871I;VXB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP
M.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES
M(')E861Y+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS
M9VED(")!<'!R;W9E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C@S,PIM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ-S4*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,0IM<V=I
M9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU."!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#`*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC
M.C$P"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHW
M"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T
M;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I
M9"`B07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R=6)A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G
M:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA
M+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT,C4*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R
M92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$S"FUS9VED(")!<W-I9VYM
M96YT(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW
M-`IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O
M=7`N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*
M;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI
M<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W
M"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES
M<VEO;BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA
M<F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@V
M"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T
M:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@
M<F5Q=6ER960@8V%P86)I;&ET97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@
M4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*
M(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@
M0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HV
M-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I
M;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C,U-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@
M<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?
M;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,S.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@
M=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S@U"B,L
M('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V
M92!U<V5R("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@
M56YA8FQE('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z
M(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q
M=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3`*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HV-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F
M86EL960N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D
M(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z.#4Q"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&
M5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE
M(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*
M;7-G<W1R(")0:65E:F%M:64@;&%U:VDZ(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B
M07IE<F)A:6IA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS
M9VED(")"86-K9W)O=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@
M0V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U
M+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED
M(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0F%H<F%I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W-PIM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8P"FUS9VED(")"87)B861O<R(*;7-G<W1R("(B"@HC.B!U=&EL+VEC
M;VY?8G)O=W-E<BYP:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G
M<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<S"FUS9VED(")"87-E;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S
M"FUS9VED(")"96QA<G5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@
M(D)E;&=I=6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L:7IE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H
M9&%Y(@IM<V=S='(@(D1Z:6WP86YA<R!D:65N82(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-3,*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S
M7"(@;F]T(&9O=6YD+B(*;7-G<W1R(").878@<W1R;V1A;7,@<&%Z:?)O:G5M
M=2!K;&%U<^YTXFIS("5S(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N
M:6YC.C@Y"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y
M<&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(P-0IM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(D)O<F1E<B(*;7-G<W1R(")(;W)D92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*
M;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*(RP@
M9G5Z>GD*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS
M9VED(")";W5V970@27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*(RP@
M9G5Z>GD*;7-G:60@(D)R87II;"(*;7-G<W1R(")087-T<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@Q"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#0T"B,L(&9U>GIY"FUS9VED(")#35,B"FUS9W-T<B`B
M0U93(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW
M-0IM<V=I9"`B0U)#(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O
M:6YT<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I
M97,N+BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$V,PIM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0X-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ-34*;7-G:60@(D-A;&5N9&%R(@IM<V=S
M='(@(DMA;&5N9.)R<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-#8*;7-G:60@(D-A;&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(D-A;6)O9&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A
M;65R;V]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I
M8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,3@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T
M(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z
M("5S(@IM<V=S='(@(DYE:7ID97;B<R!P:65S;.=G=&EE<R!,1$%0('-E<G9E
M<FEM+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0Q,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8T"B,L(&9U>GIY"FUS9VED(")#86YA9&$B"FUS
M9W-T<B`B2V%L96YDXG)S(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN
M+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N
M:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R"FUS9VED(")#86YC
M96PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")!
M=&-E;'0@<')O8FSG;6%S('!I971E:6MU;74B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@
M9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B0V%N;F]T
M(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.CDQ"FUS9VED
M(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T
M97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,S$T"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T
M;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E
M+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E
M+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO
M=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A
M;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@
M<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P
M96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@
M(D-A<&4@5F5R9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`HC+"!F=7IZ>0IM<V=I9"`B
M0V%P=&EO;B(*;7-G<W1R(")/<&-I:F%S(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I9"`B
M0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V
M"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL
M(%!H;VYE(@IM<V=S='(@(DUO8FEL86ES('3B;')U;FES(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0HC+"!F
M=7IZ>0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(DUO8FEL86ES
M('3B;')U;FES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED
M(")#96QL('-P86-I;F<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R-S0*(RP@9G5Z>GD*;7-G:60@(D-E;&QP:&]N92(*;7-G
M<W1R(")-;V)I;&%I<R!TXFQR=6YI<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3<X"FUS9VED(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HU-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM
M<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#96YT<F%L($5U<F]P
M96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8Y.0IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T
M86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8Q,0IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G
M:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P.`HC+"!F=7IZ>0IM<V=I9"`B0VAA9"(*;7-G<W1R(")V0V%R9"(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.38*(RP@9G5Z>GD*;7-G:60@(D-H86YG92(*;7-G
M<W1R(")!=&-E;'0@:7IM86GR87,B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z,S$*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I9"`B(@HB
M0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W
M:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM
M<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R
M=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A
M8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W"B,L(&9U
M>GIY"FUS9VED(")#:&%R(@IM<V=S='(@(G9#87)D(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED
M(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"B,L(&9U
M>GIY"FUS9VED(")#:&EL92(*;7-G<W1R(")6:7)S<F%K<W1S(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-PIM<V=I9"`B0VAI;F$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R
M*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I
M9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO
M;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C(V.`IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y.`IM<V=I
M9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D
M97)E9"!L:7-T<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR
M:7-T;6%S($ES;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#DS"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S
M(&YO="!F;W5N9"XB"FUS9W-T<B`B3F%V('-T<F]D86US('!A>FGR;VIU;74@
M:VQA=7/N=.)J<R`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C$T"B,L(&9U>GIY"FUS9VED(")#;&5A<B(*;7-G<W1R(")+
M86QE;F3B<G,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@(D-L96%R(%%U
M97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R
M+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI
M;F,Z,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S97(@
M9&%T82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV
M,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS
M9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(D%I>G;G<G0@;&]G
M=2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0T"FUS9VED(")#;&]U9',B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PIM<V=I9"`B
M0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-O8V]S("A+
M965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP
M.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C0*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`P('-E<G9I8V5S+VEM86=E
M<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#0V"FUS9VED
M(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30V"FUS
M9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-C0*;7-G:60@(D-O;6EC<R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*(RP@9G5Z>GD*;7-G:60@(D-O;6UA
M;F0B"FUS9W-T<B`B57KRYVUU;7,B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z
M,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")#;VUM96YT(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-38V"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM
M<V=S='(@(E5Z\N=M=6US(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q
M"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Y-PIM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y"FUS9VED(")#;VYD:71I
M;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS
M9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#,*;7-G:60@(D-O;F9I9W5R871I
M;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T
M;&]O:RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S
M-0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0HC+"!F=7IZ>0IM<V=I9"`B
M0V]N9FER;2!087-S=V]R9"(*;7-G<W1R(")087)O;&4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V
M"FUS9VED(")#;VYG;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#
M;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y
M.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*
M;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN
M96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D
M('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HX-#4*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10
M('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]H;V]K<RYP
M:'`N9&ES=#HQ,#$T"FUS9VED(")#;VYT86-T<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@
M(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HW.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@
M;V8@7"(E<UPB(@IM<V=S='(@(B<E<R<@<V%T=7)S(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C,S"FUS9VED(")#;VYT:6YU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V
M"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#;V]K:64B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(Q"B,L(&9U>GIY"FUS9VED(")#;W!Y(@IM<V=S='(@(E5Z\N=M=6US(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C@*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R("))96SB
M9.=T86ES(&QA=6MS.B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,3<P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3DU
M"FUS9VED(")#;W-T($E$(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@
M(D-O<W1A(%)I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T
M92!D)TEV;VER92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HY-S8*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M
M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,#4S"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z,3(Q"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T
M;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3F5I>F1E=N)S('!I97-LYV=T:65S
M($Q$05`@<V5R=F5R:6TN(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0U
M-PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C
M:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-#0Q"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C
M="!T;R!L9&%P('-E<G9E<B(*;7-G<W1R(").96EZ9&5VXG,@<&EE<VSG9W1I
M97,@3$1!4"!S97)V97)I;2XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@
M<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$Q,C4*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'
M4"!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4R,@IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%
M(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I
M;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T
M92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U;&0@;F]T(&1E
M=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D
M<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T
M-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F
M(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP
M:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@
M=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S
M7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT,3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S
M:R!M;V1U;&4@)7,B"FUS9W-T<B`B3F5I>F1E=N)S(&%T=N=R="!-86EN=&5N
M86YC95]487-K(&UO9'5L:2`E<R(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER
M96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B3F5I>F1E=N)S(&%T=N=R="!-86EN
M=&5N86YC95]487-K(&UO9'5L:2`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y
M.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E
M<G9E<BXB"FUS9W-T<B`B3F5I>F1E=N)S('!I97-LYV=T:65S($Q$05`@<V5R
M=F5R:6TN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR,S@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED
M("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q
M=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R
M92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S`Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T
M,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.0IM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B
M;V]K+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*(RP@9G5Z>GD*;7-G
M:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M2&]R9&4@;F%V(&MO<F5K=&D@:V]N9FEG=7+G=&$B"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED(")#
M;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ
M("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDU
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P('5P
M9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I
M9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T
M:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@
M8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,*(RP@9G5Z
M>GD*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*
M;7-G<W1R(").96EZ9&5VXG,@<&EE<VSG9W1I97,@3$1!4"!S97)V97)I;2XB
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C8*;7-G
M:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S
M=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F
M;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q.0IM<V=I
M9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")#;W5N=')Y(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S,*;7-G:60@(D-O
M=7)S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.30*
M;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T
M92!S=6(@9F]L9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,P"FUS
M9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-SD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I
M9"`B0W5B82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*
M;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C0X"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE
M+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C,S"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@
M5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C<U"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T
M;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S
M96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED
M(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@
M(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Q('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")$1"(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#$*;7-G:60@(B(*(D133B`H
M<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T
M86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I
M;'DB"FUS9W-T<B`B26MD:65N87,B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z
M-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W.0IM<V=I9"`B1&%T86)A<V4@3&]O
M:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y.0IM
M<V=I9"`B1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`W"FUS9VED(")$
M871E('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,CDR(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,C(*(RP@9G5Z>GD*;7-G:60@(D1A>2(*;7-G<W1R(")):V1I96YA<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E
M8V5M8F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M
M8F5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@;&EB
M+W!R969S+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B"FUS9W-T
M<B`B4&%R87-TXB!I9&5N=&ETXG1E(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U
M;'0@0V]L;W(B"FUS9W-T<B`B27IM86YT;W0@;F]K;'5SYW1O(';G<G3N8G4B
M"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.CDQ"FUS9VED
M(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@(E!A<F%S=.(@:61E;G1I=.)T
M92(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-PHC+"!F=7IZ>0IM<V=I
M9"`B1&5F875L="!3:&5L;"(*;7-G<W1R(")087)A<W3B(&ED96YT:73B=&4B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I
M;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT
M,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*
M;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS9VED(")$96QE=&4@
M1W)O=7`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C0Y"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*
M;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA
M=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E
M<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R
M;6ES<VEO;G,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R;W<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y
M+FEN8SHQ-0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E('-E;&5C=&5D(&ED96YT
M:71Y(@IM<V=S='(@(E!A<F%S=.(@:61E;G1I=.)T92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I
M9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*;7-G:60@(D1E;&EV97)Y('1I;64B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM<V=I
M9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B07!R86MS=&EE="!P
M<F]B;.=M=2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDS."!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"B,L
M(&9U>GIY"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")0:6QN<R!A<')A
M:W-T<SHB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-0IM<V=I
M9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y.0IM<V=I9"`B
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B4^YKXFMA(&EN9F]R;>)C:6IA(&ER(&YO<_MT[G1A(&%D
M;6EN:7-T<F%T;W)A;2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C$Y"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(Q-PIM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDT"FUS9VED(")$97<@4&]I;G0@
M9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,C<*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*
M;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V-@IM<V=I9"`B
M1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G
M<W1R(")%:W+B;F$@:65S=&%T[FIU;6DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@9&5T86EL
M960@9F]R96-A<W0B"FUS9W-T<B`B16MRXFYA(&EE<W1A=.YJ=6UI(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HX-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S
M="`H5$%&*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.#$W"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R
M(")%:W+B;F$@:65S=&%T[FIU;6DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TU$3BYP:'`Z,3DP"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*;7-G
M:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S
M(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R(").878@=&EE\&%S('!I965J87,@
M;6%I;G1E;F%N8V4N<&AP(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI
M;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O
M97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@
M>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM
M<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B
M1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N
M=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z.#0T"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N
M97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O
M<"!D;W=N(&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*(RP@9G5Z>GD*;7-G:60@(D4M36%I
M;"(*;7-G<W1R(")087-T<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G
M96YE<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A
M>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R
M=FEC92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R"B,Z('1E;7!L871E<R]P
M;W)T86PO961I="YI;F,Z,C4*;7-G:60@(D5D:70B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU,"!T96UP;&%T97,O<&]R
M=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V
M"FUS9VED(")%9&ET($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N
M<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C871I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B16ET:&5R(&5N86)L92!I="!T:&5N.B`E<RP@;W(@
M=7-E('1H92!B87-I8R!(5$U,('9E<G-I;VXZ("5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,PIM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8Y"FUS9VED
M(")%;6%I;"(*;7-G<W1R(")%+7!A<W1S(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C8X"B,L(&9U>GIY"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(DK[
M<W4@92UP87-T82!A9')E<V4Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DV,PIM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#D*(RP@
M9G5Z>GD*;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@
M(D-I=&$@:6YF;W)MXF-I:F$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W
M87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(Y.`HC+"!F=7IZ>0IM<V=I9"`B16UO=&EC;VYS(@IM<V=S
M='(@(D]P8VEJ87,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#(*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(&UE<W-A
M9V4N(@IM<V=S='(@(E1U:_!S(')E>G5L=.)T<RXB"@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T
M>2!R97-U;'0N(@IM<V=S='(@(E1U:_!S(')E>G5L=.)T<RXB"@HC.B!F<F%M
M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S
M96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4T,PIM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O
M;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4Q.`IM<V=I9"`B16YA8FQE(')I9VAT(&-L
M:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C4Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$Q
M"FUS9VED(")%;F0@>65A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D
M:71O<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q
M"FUS9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO
M=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB
M<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_
M)SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA
M9V4@55),(&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,0IM<V=I9"`B16YT97(@=&AE(&QE='1E
M<G,@8F5L;W<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T
M;W)I86P@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R
M:71R96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#4@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C4U"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S8@<V5R=FEC97,O
M<&]R=&%L+VEN9&5X+G!H<#HX,@IM<V=I9"`B17)R;W(B"FUS9W-T<B`B2^_[
M9&$B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H
M;W(Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y
M;F,@;&]G.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O
M5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G
M971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED
M(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@
M(D5S=&]N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P
M:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS
M9VED(")%=&AN:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,S.0IM<V=I9"`B179E<GD@,34@;6EN=71E
M<R(*;7-G<W1R(")+871R87,@,34@;6EN^W1E<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.#D*(RP@9G5Z>GD*;7-G:60@(D5V97)Y(#(@;6EN=71E
M<R(*;7-G<W1R(")+871R87,@-2!M:6[[=&5S(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,S-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@W"FUS9VED
M(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(DMA=')A<R`S,"!S96MU;F1E
M<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,Y,`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@
M(DMA=')A<R`U(&UI;OMT97,B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O
M36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R
M(")+871RXB!P:65S;.=G\&%NXG,@<F5I>N<B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S0P"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B
M2V%T<G4@<'5S<W1U;F1U(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S
M-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@X"FUS9VED(")%=F5R>2!M:6YU
M=&4B"FUS9W-T<B`B2V%T<G4@;6EN^W1I(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R
M(")087)A=6=VYW)T[F)A<R(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A
M9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R-PIM
M<V=I9"`B17AE8W5T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HT-S4*;7-G:60@(D5X<&%N9"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS9VED(")%
M>'!A;F0@4VED96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-1
M3"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM
M<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R
M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-@IM<V=I9"`B17AP
M;VYE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B1E10
M('5P;&]A9"!O9B!S971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O<W%L+G!H<#HR,38*;7-G:60@(D9A:6QE9"!R971R:65V:6YG
M('!R969E<F5N8V5S+B(*;7-G<W1R(").96EZ9&5VXG,@<V'R96UT(&EE<W1A
M=.YJ=6UU<RXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I
M;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DYE:7ID
M97;B<R!P:65S;.=G=&EE<R!,1$%0('-E<G9E<FEM+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<VUB+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B1F%I;&5D
M('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B3F5I>F1E=N)S
M('!I97-LYV=T:65S($Q$05`@<V5R=F5R:6TN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HV.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D
M('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z-CDQ"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(DYE:7ID
M97;B<R!P:65S;.=G=&EE<R!,1$%0('-E<G9E<FEM+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<*;7-G:60@(D9A:6QE9"!T;R!C<F5A
M=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HT.3<@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HW,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T
M;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B3F5I>F1E=N)S('!I97-LYV=T
M:65S($Q$05`@<V5R=F5R:6TN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HT-C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T
M;R!R971R:65V93H@)7,B"FUS9W-T<B`B3F5I>F1E=N)S('-A\F5M="!I97-T
M873N:G5M=7,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM
M<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S.`HC+"!F=7IZ>0IM<V=I9"`B
M1F%T86P@17)R;W(Z(@IM<V=S='(@(DEE;.)D97,@:VS[9&$Z(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B
M1F%X(@IM<V=S='(@(D9A:W-S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,T.0HC+"!F=7IZ>0IM<V=I9"`B1F%X97,B"FUS9W-T<B`B1F%K<W,B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM
M<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,C`*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B1F5E;',@;&EK
M93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I
M9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.30T"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-`IM<V=I9"`B
M1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S,S.`IM<V=I9"`B1FEG;&5T(&9O;G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(D9I;&4B
M"FUS9W-T<B`B5FER<W)A:W-T<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I
M;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P-PIM<V=I
M9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HW,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C@U"B,L(&9U>GIY"FUS9VED(")&:6QE($YA;64B"FUS9W-T
M<B`B5N)R9',B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3DU"FUS
M9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#@V"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-3D*;7-G
M:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G:60@(D9I;'1E<G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S="!(
M86QF(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(U-@IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S$*;7-G:60@(D9L:7`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@
M(D9O9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C(S-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L('!H<"UF
M;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@
M:6UA9V5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,T
M"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-SD*;7-G:60@(B(*(D9O<F5C87-T($1A
M>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B
M;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U
M;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R
M('!A<W-W;W)D/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#8R"FUS9VED(")&;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y
M<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"B,L
M(&9U>GIY"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R(")0:65Z[FUE<R(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4S"FUS
M9VED(")&;W)U;7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$P.0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B
M1G(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS,PHC+"!F=7IZ>0IM<V=I9"`B1G)A;65S(@IM
M<V=S='(@(E;B<F1S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I
M9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-#@@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,V,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`V"FUS
M9VED(")&<F]M('1H92`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z-#@*(RP@9G5Z>GD*;7-G:60@(D9U;&P@1&5S8W)I
M<'1I;VXB"FUS9W-T<B`B4&EL;G,@87!R86MS=',Z(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U
M;&P@36]O;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV,`HC+"!F=7IZ
M>0IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(DK[<W4@=N)R9',Z(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS
M9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S
M($-O;F9I9W5R871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")':&%N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS
M9VED(")':6)R86QT87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3(*;7-G:60@(D=O
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I
M9"`B1V]E9&5L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,3(X"FUS9VED(")';V]G;&4@36%P<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")'
M;V]G;&4@4V5A<F-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR,S<*;7-G:60@(D=R87ES8V%L92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")'<F5E:R`H25-/
M+3@X-3DM-RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W)E96YL
M86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=R96YA9&$B"FUS
M9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G:60@(D=R;W5P
M($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,P
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C$Q."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T
M92!G<F]U<"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'=65S="!097)M:7-S
M:6]N<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#<P"B,L(&9U>GIY"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B2V]N=&%K
M=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<X"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.CDV,`IM<V=I9"`B2%1-3"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM
M<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE
M(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED
M(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(
M86ET:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED
M(")(87IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.CDQ.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,R"FUS9VED(")(96%D
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A
M8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B2&5B<F5W("A)
M4T\M.#@U.2TX+4DI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z
M,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@<V5R
M=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD97@N
M:6YC.C,*;7-G:60@(DAE;'`B"FUS9W-T<B`B4&%L[F1Z[F)A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B
M2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,W,0HC+"!F=7IZ>0IM<V=I9"`B2&5L<&5R(@IM<V=S
M='(@(E!A;.YD>NYB82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I
M9"`B2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T
M<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`IM
M<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV.0IM<V=I9"`B2&EG:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N
M:6YC.C4*(RP@9G5Z>GD*;7-G:60@(DAO7VUE(@IM<V=S='(@(DAO<F1E(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3
M=&%T92DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ-3,U"B,L(&9U>GIY"FUS9VED(")(;VUE(@IM<V=S='(@(DAO<F1E(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS
M9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`B3>)J87,@861R97-E(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"FUS9VED(")(;VUE($1I<F5C=&]R
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(DWB:F%S
M('1E;&5F;VYS(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C4*;7-G:60@(DAO
M<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HT-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN
M=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C
M;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE
M<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HQ,C4P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3
M=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO
M;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M
M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J
M96-T("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,3(T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA
M8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#<T"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F
M;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$Q.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3,S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE
M('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@R"FUS9VED(")(
M;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A
M;#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G970@
M:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED
M(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM
M<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U
M(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S`*;7-G
M:60@(DAU;6ED:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-3D*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES=',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W,B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,U"B,L('!H<"UF;W)M
M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q
M-"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF
M;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP
M.C$W.2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C0R"B,L('!H
M<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F
M86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$S,38*(RP@9G5Z>GD*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B
M061R97-E(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW
M-PIM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED
M("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S8*;7-G:60@(DEC
M;VYS($]N;'DB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP
M.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<W"FUS9VED("))8V]N
M<R!W:71H('1E>'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Y,`IM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T
M;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4U"FUS9VED("(B"B))9B!Y
M;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E
M<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@
M;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S,*;7-G:60@(B(*(DEF
M('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E
M('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@
M>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM
M86=E(%!R979I97<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%52
M3"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE
M<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W
M-C$*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("))96SB9.=T
M86ES(&QA=6MS.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC
M.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*
M;7-G<W1R("))96SB9.=T86ES(&QA=6MS.B`E<R(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS
M9W-T<B`B265LXF3G=&EE(&QA=6MI.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R
M="!2;W<@069T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED("));F-O<G)E8W0@86-T:6]N
M(&-O9&4@9VEV96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"B,L(&9U>GIY"FUS9VED("))
M;F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R("),
M^V1Z=2!N;W+B9&EE="!S879U(&QI971O=.)J82!VXG)D=2!U;B!P87)O;&DB
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB
M26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@
M86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U
M(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S
M92!);F1E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("));F1I
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD
M:79I9'5A;"!5<V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@
M(DEN9&]N97-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3<*(RP@9G5Z>GD*;7-G
M:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@(DK[<W4@:6YF;W)MXF-I:F$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S,P"FUS9VED("));F9O
M<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM86=E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@
M(DEN<V5R="!486)L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B($QI
M;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M;B!"
M969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@
M8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R
M96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE
M=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M,0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@
M;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R
M87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y
M"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT
M(&YO9&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*
M;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S.0IM<V=I9"`B26YS97)T(&%N
M(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N
M97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C
M96QL(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL
M(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN
M(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@
M8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDP"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O
M<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,P"FUS9VED("))
M;G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E
M<W1I;VXZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@
M=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B
M26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`W-0IM<V=I9"`B26YT96=E<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,S"FUS9VED("));G1E
M9V5R(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@
M*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ-S`*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q,`IM<V=I9"`B26YV86QI9"!:25`@
M9&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T
M"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*
M;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$U.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C,R(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R.3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U
M8FUI='1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED(&1E<W1I
M;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O9&)X+G!H<#HR,C`*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M
M870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$W-PIM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,0IM<V=I9"`B26YV
M86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED
M("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN
M=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I
M9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI
M9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$W,PIM<V=I9"`B26YV86QI9"!P87)T;F5R
M(&ED+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3<U"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`W-B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$R-C(*;7-G:60@(DEN=F%L:60@<VAA<F4@
M;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@
M861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N:6-O
M9&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,U-PIM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-SD*;7-G:60@(DEN
M=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED
M("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*
M;7-G:60@(DER96QA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS
M9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8R-0IM<V=I9"`B27-S=65R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@HC+"!F
M=7IZ>0IM<V=I9"`B271A;'DB"FUS9W-T<B`B26MD:65N87,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*87!A;B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM<V=I9"`B2F%P86YE
M<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C,Q,`IM<V=I9"`B(@HB2F%V87-C<FEP="!H87,@8F5E
M;B!D:7-A8FQE9"!O;B!Y;W5R(&)R;W=S97(@86YD('1H:7,@<&%G92!M87D@
M;F]T(&)E("(*(F1I<W!L87EI;F<@8V]R<F5C=&QY+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G
M:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*
M=7-T:69Y($9U;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@
M3&5F="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(V-`IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V
M97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$Q"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R
M<')I;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y
M<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.3@*(RP@9G5Z>GD*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R("):
M:?)A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S0P"FUS
M9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V
M97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM
M<V=I9"`B2VED<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI
M<FEB871I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L
M($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(DMO<F5A
M;B`H155#+4M2*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU
M=V%I="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T
M86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX
M"FUS9VED("),85]Y;W5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(E9A;&]D
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T
M:6,@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HW-@IM<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]";&]C
M:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Q"FUS9VED("),87-T(%5P9&%T
M960Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,C$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,38*;7-G:60@(DQA<W0@
M;&]G:6XZ($YE=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B
M3&%T=FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M-`IM<V=I9"`B3&%W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0HC+"!F=7IZ>0IM<V=I9"`B
M3&%Y;W5T(@IM<V=S='(@(DEZ:65T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R
M(&YO(&)O<F1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE
M8F%N;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8Y"FUS9VED("),969T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3D*;7-G:60@(DQE9G0@
M:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,34*(RP@9G5Z>GD*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(E!A
M<F%U9W;G<G3N8F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC
M+"!F=7IZ>0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B3F5K860B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y
M"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I
M9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B3&EG
M:'0@4F%I;B(*;7-G<W1R(")0:65S;.=G=&EE<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN
M($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),
M:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@
M4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE
M<FEC:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#$T"B,L(&9U>GIY"FUS9VED("),:6YK(@IM<V=S='(@(E!I97-LYV=T:65S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B3&EN:R!T
M:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES
M<&QA>6EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED("),:6YK<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X
M($-O;VMI92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T
M:&4@9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,S,*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+VAE;'`O:6YD97@N<&AP.C4P"FUS9VED("),:7-T($AE;'`@5&]P:6-S
M(@IM<V=S='(@(E!A<N)D[G0@<&%L[F1Z[F)A<R!T96UA='5S(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$S,@IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.30*
M;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4X.0HC+"!F=7IZ>0IM<V=I9"`B3&ES
M="U(96QP(@IM<V=S='(@(E!A<N)D[G0@<&%L[F1Z[F)A<R!T96UA='5S(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.38*;7-G:60@
M(DQI<W0M260B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.3(*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3,*;7-G:60@
M(DQI<W0M4&]S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3`*
M;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@
M<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R
M<R!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W
M"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM
M<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.#,*;7-G:60@(DQO861I;F<N+BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q
M,0IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX,PIM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-`HC.B!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV-0IM<V=I9"`B
M3&]C871I;VXB"FUS9W-T<B`B(@H*(SH@;&]G:6XN<&AP.C$W,B!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,3DQ('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S
M='(@(E!I97-LYV=T:65S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C0U"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.#4*
M;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B27II970B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(@IM<V=S='(@
M(E!I97-LYV=T:65S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-PHC
M+"!F=7IZ>0IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B57ID979U;6DB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.38*(RP@9G5Z>GD*;7-G
M:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S
M<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(E!I97-L
MYV=T:65S(&YE:7ID97;B<VDN3F5P87)E:7IS(&QI971O=.)J82!VXG)D<R!V
M86D@<&%R;VQE+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,@IM
M<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S8U"B,L(&9U>GIY"FUS9VED("),;VYG('1E>'0B
M"FUS9W-T<B`B27II970B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*
M;7-G:60@(DQO=F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(DQO=R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,X
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")-
M32(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#$*;7-G:60@(DU/
M5$0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN
M960@;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I
M9"`B35-'(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H
M92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT.0HC+"!F=7IZ>0IM<V=I9"`B36%G:6,B
M"FUS9W-T<B`B4&%S=',B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M.#$*;7-G:60@(DUA:6PB"FUS9W-T<B`B4&%S=',B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-3(R"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA;&%W:2(*;7-G<W1R(")0
M87-T<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(DUA;&DB"FUS9W-T<B`B4&%S
M=',B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA;'1A(@IM<V=S
M='(@(E!A<W1S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ"FUS9VED
M("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T
M;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@
M=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U,PIM<V=I9"`B36%P
M,C0@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#@T"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,38X"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED
M(")-87!P:6YG<R!S=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0Q"B,L(&9U>GIY"FUS9VED(")-87)G:6XB"FUS9W-T<B`B
M0G+N9&ENXFIU;7,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@
M26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*
M;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDS"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F:65L9',B
M"FUS9W-T<B`B4V%S:V%N;_!I92!L875K:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I
M9"`B36%U<FET86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@
M(DUA=7)I=&EU<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D
M(&-R961I="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P
M87)T<R!E>&-E961E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y.`IM<V=I9"`B36%X
M('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP
M:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*
M;7-G:60@(DUA>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-
M87EO='1E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B365M8F5R
M<R(*;7-G<W1R(")496MS=&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S<X"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@
M(DUE<F=E(&-E;&QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E
M(@IM<V=S='(@(EII\F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S
M9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@
M8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I
M9"`B365S<V%G92!E>'!I<F5D+B(*;7-G<W1R(")::?)A(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(V,`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(EII
M\F$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E
M871H97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM
M<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(B(*
M(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(E/N:^)K
M82!I;F9O<FWB8VEJ82!I<B!N;W/[=.YT82!A9&UI;FES=')A=&]R86TN(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B365T
M87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q(&9R86UE
M=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*
M;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<T
M(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*;7-G:60@(DUE=')I8R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E
M<R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S8*(RP@9G5Z>GD*;7-G:60@(DUI9&1L92(*
M;7-G<W1R(")087-T<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3`*;7-G:60@(DUI;B!T96UP(&QA<W0@
M,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,P,@IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@
M(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(S-`HC+"!F=7IZ>0IM<V=I9"`B36ER<F]R(@IM<V=S='(@(DOO^V1A
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL
M86YE;W5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A
M8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I
M;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T
M;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS
M9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS
M9VED(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C<T"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I
M9"`B36]D97)A=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#@*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<S"FUS9VED(")-;V1U;'5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DT"FUS9VED
M(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I
M;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM
M<V=S='(@(DMA=')U(&WG;F5S:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N
M='-E<G)A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$W,B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E
M8W1E9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O
M8V-O(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G
M:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!3=6YN
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HU,#D*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3,*;7-G:60@(DUO=F4@
M3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HU,3<*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`U"FUS9VED(")-
M;W9E(%5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(S
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*
M;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED
M(")-;WIA;6)I<75E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q.#0*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`U-0IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#(*;7-G:60@(DUU
M;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#`P"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.`HC+"!F=7IZ>0IM<V=I9"`B
M37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")*^W-U(&EN9F]R;>)C
M:6IA(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HU-`IM<V=I9"`B
M37D@4&]R=&%L(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET
M+G!H<#HQ,S8*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED
M(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`B5N)R9',B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDW"FUS9VED(").875R=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I
M9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@
M(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!"
M87-E(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!5
M4DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#4*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0*
M;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S
M8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@4U-,
M('-E<G9E<B!N86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P92!C97)T:69I8V%T
M92!C;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@P"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!T
M>7!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-3$*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M,S4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-@IM<V=I9"`B3F5V97(B
M"FUS9W-T<B`B3F5K860B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE
M9&]N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL
M<RYP:'`Z.#$*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I
M;',N<&AP.C@W"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA
M:6QS+G!H<#HY-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M
M86EL<RYP:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E
M('1O("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM
M<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I
M;VYA;"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(").97<@6F5A
M;&%N9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R(")0
M87)O;&4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z,C(W"B,L
M('!H<"UF;W)M870*;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O
M;B`E>"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C4R"FUS9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y"B,L(&9U
M>GIY"FUS9VED(").97=S(@IM<V=S='(@(E!I97KN;65S(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,P-0IM<V=I9"`B3F5W<V=R;W5P<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-2!T96UP
M;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-0IM
M<V=I9"`B3F5X="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S(@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HS-S8*(RP@9G5Z>GD*;7-G:60@(DYE>'0@;W!T:6]N<R(*
M;7-G<W1R(")!=&=R:65Z=&EE<R!P:64@;W!C:6KB;2(*"B,Z(&9R86UE=V]R
M:R]522]522]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(DYI9V5R(@IM<V=S='(@(DYE
M:V%D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.#`*;7-G:60@(DYI
M9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3FEU92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.38S"FUS9VED(").;R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF
M:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP
M:'`Z,3`U"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN
M9R!)4T\@:6UA9V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H
M('1E;7!L871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HW.2!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HR-#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M,C8W"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P
M;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC
M86PN<&AP.C4P"B,L(&9U>GIY"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R
M;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")344P@
M875T96YT:69I:^)C:6IA:2!N878@;F]RXF3N=&$@:V]N9FEG=7+B8VEJ87,@
M:6YF;W)MXF-I:F$N(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*(RP@
M9G5Z>GD*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`B071C96QT(&EZ;6%I
M\F%S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G
M:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I
M;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,38W(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`R"B,Z(&9R86UE=V]R
M:R]5=&EL+U5T:6PN<&AP.C<W,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M("5S+B(*;7-G<W1R(")344P@:V%T96=O<FEJXFT@;F%V(&YO<N)D[G1A(&MO
M;F9I9W5RXF-I:F%S(&EN9F]R;>)C:6IA+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z.#(T"B,L(&9U>GIY"FUS9VED(").;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T
M<B`B3$1!4"!I97-T873N:G5M;W,@;F%V(&YO<N)D[G1A(&MO;F9I9W5RXF-I
M:F%S(&EN9F]R;>)C:6IA+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z-C8Y"B,L(&9U>GIY"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B4U%,(&MA
M=&5G;W)I:N)M(&YA=B!N;W+B9.YT82!K;VYF:6=U<N)C:6IA<R!I;F9O<FWB
M8VEJ82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S$W
M"B,L(&9U>GIY"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R(")344P@:V%T
M96=O<FEJXFT@;F%V(&YO<N)D[G1A(&MO;F9I9W5RXF-I:F%S(&EN9F]R;>)C
M:6IA+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<W"FUS9VED
M(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C@@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(S
M"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-CD*;7-G:60@(DYO(&QO8V%T
M:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G
M92!S=7!P;&EE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E
M8VEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I
M9FEE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT
M"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X"FUS
M9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U
M+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E
M<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H+T%U=&@O;&]G
M:6XN<&AP.C@T"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW-0HC
M+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")344P@875T96YT:69I:^)C:6IA
M:2!N878@;F]RXF3N=&$@:V]N9FEG=7+B8VEJ87,@:6YF;W)MXF-I:F$N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]P87-S=V0N<&AP.C$S-0HC+"!F=7IZ
M>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B4U%,(&%U=&5N=&EF:6OB8VEJ86D@;F%V
M(&YO<N)D[G1A(&MO;F9I9W5RXF-I:F%S(&EN9F]R;>)C:6IA+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`HC+"!F=7IZ>0IM<V=I9"`B
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B4U%,(&%U=&5N=&EF:6OB8VEJ86D@;F%V(&YO<N)D[G1A(&MO
M;F9I9W5RXF-I:F%S(&EN9F]R;>)C:6IA+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T
M:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R
M>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S4P"B,L('!H<"UF;W)M870*;7-G
M:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PHC+"!F=7IZ>0IM
M<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`B4&EE>NYM97,B"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HT-#D*;7-G:60@(DYO('-E<&%R871O<B!S
M<&5C:69I960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*(RP@9G5Z>GD*;7-G:60@(DYO
M('-I9&5S(@IM<V=S='(@(E!I97KN;65S(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HU.#,*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3,X"FUS9VED(").
M;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,C(Q"B,L(&9U>GIY"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@
M<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B3/MD>G4@;F]RXF1I970@<V%V=2!L
M:65T;W3B:F$@=N)R9'4@=6X@<&%R;VQI(@H*(SH@9G)A;65W;W)K+U)00R]2
M4$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E
M='5R;F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HY-S$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDX,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.3DR"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,#`Y"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO
M;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*
M(RP@9G5Z>GD*;7-G:60@(DYO;F4B"FUS9W-T<B`B5.)L<G5N:7,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED
M(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@Y"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA
M($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").;W)W
M87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV-#`*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B3F]T($)E
M9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HT,#@*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDN<&AP.C@S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDT"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z
M-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C8X"B,L(&9U>GIY"FUS9VED(").;W0@<V5T(@IM<V=S='(@(E!I
M97KN;65S(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(
M86YD;&5R+G!H<#HQ-#,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E
M<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD
M;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S,*(SH@9G)A;65W;W)K+U-E<W-I
M;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#<*(SH@9G)A;65W;W)K
M+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S0@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,C`U(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C(T."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8U"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(Y-PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$R(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HS,CD*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V,B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(R"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HU,#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W,`HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z-3@W(&9R86UE=V]R:R]61E,O5D93+G!H<#HV-C4*
M;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG+VAO;VMS
M+G!H<"YD:7-T.C$P,#4*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$W
M.`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B4&EE>NYM97,B"@HC.B!S97)V:6-E
M<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O
M=W-E+"!G;R!B86-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0HC+"!F=7IZ>0IM<V=I9"`B3F]V96UB
M97(B"FUS9W-T<B`B3F5K860B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,#0V"B,L(&9U>GIY"FUS9VED(").=6UB97(B"FUS9W-T<B`B5N)R9',B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U"FUS9VED(").=6UB
M97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C,*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T-2!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F
M(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R
M('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G
M:60@(D]+(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T
M($-R96%T;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED
M(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S(V"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD
M(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@HC+"!F=7IZ>0IM
M<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(E!A<F]L92(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D
M(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G
M:60@(D]M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U
M<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U
M,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q"FUS9VED(")/;FQY(&]N
M92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N
M97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H
M:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,S4*;7-G:60@(D]P96X@
M:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#
M;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I
M;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@(D]P
M=&EO;G,B"FUS9W-T<B`B3W!C:6IA<R(*"B,Z('-E<G9I8V5S+W!R969S+G!H
M<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B3W!C:6IA
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B3W)G86YI<V%T
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S(*;7-G:60@(D]R
M9V%N:7II;F<B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M
M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E
M<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3`V"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3,@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$R,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,Q
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#$*;7-G:60@(D]T:&5R($EN9F]R
M;6%T:6]N(@IM<V=S='(@(D-I=&$@:6YF;W)MXF-I:F$B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z
M-SD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I
M8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<S
M"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,Q.0IM<V=I9"`B4$=0
M($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$S-S$*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S
M-3,*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"B,L(&9U>GIY"FUS9VED(")0
M2%`@0V]D92(*;7-G<W1R(")(;W)D92(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H
M<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,:6=H
M="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS
M9VED(")032!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3;F]W(%-H;W=E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#$*;7-G:60@(E!-(%-U;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@5"U3
M=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W
M-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Q"FUS9VED(")086QA=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS
M9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I
M9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PHC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS9VED(")087-S=V]R9"(*
M;7-G<W1R(")087)O;&4B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C$S,C(*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G
M<W1R(")087)O;&4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP
M:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#4S"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.3`*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R(")087)O;&4B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0HC+"!F=7IZ>0IM
M<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R(")087)O;&4B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S-`HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S
M=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$Q.2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@
M(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C<*
M;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")096]P;&4B"FUS
M9W-T<B`B3&]M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED
M(")097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B27IP
M:6QD[G0@=7IT=7+G\&%N87,@;W!E<N)C:6IA<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT,#8*(RP@9G5Z>GD*;7-G:60@(E!E<F9O<FT@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B27IP:6QD[G0@
M=7IT=7+G\&%N87,@;W!E<N)C:6IA<R(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,34V"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@V"FUS9VED(")0
M97)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U"B,L
M(&9U>GIY"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R(")#
M:71A(&EN9F]R;>)C:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B
M4&5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H:6QI<'!I
M;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(E3B;')U;FES
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W.`IM<V=I9"`B4&AO
M=&]S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L
M;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H
M870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT
M('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(U-S$*;7-G:60@(E!L96%S92!E;G1E<B!A
M(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@
M96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Q"FUS9VED(")0;&5A
M<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8P"FUS9VED(")0;&5A<V4@96YT
M97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@
M=&AE(&UO;G1H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-#4Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW
M"FUS9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L
M96TN(@IM<V=S='(@(DS[9'IU(&YO<N)D:65T('!R;V)LYVUA<R!A;F]TXF-I
M:G4N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y
M;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R("),^V1Z=2!N;W+B
M9&EE="!S879U(&QI971O=.)J82!VXG)D=2!U;B!P87)O;&DB"@HC.B!S97)V
M:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S92!R96%D
M('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@
M=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"FUS
M9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X-PIM
M<V=I9"`B4&]L;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B
M4&]R='5G86PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO
M;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO
M;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H
M:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@
M;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Y.`IM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O
M/F-H86YC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S
M:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(U"FUS9VED(")0
M<F5S<W5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U
M.0IM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B4')E
M<W-U<F4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C`U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE=R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM86=E
M(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C,V,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C,V-@HC+"!F=7IZ>0IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G
M<W1R(")!=&=R:65Z=&EE<R!P:64@;W!C:6KB;2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O
M8W5M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0HC+"!F=7IZ>0IM
M<V=I9"`B4')O8FQE;2(*;7-G<W1R(");4')O8FSG;6%S('II\F]J=6US72(*
M"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-@IM<V=I9"`B4')O8FQE;2!$
M97-C<FEP=&EO;B(*;7-G<W1R(")0<F]B;.=M87,@87!R86MS=',B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S8Y"FUS9VED(")0<F]J96-T<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$Q(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#@*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S(X-0IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0
M=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8T-`IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC
M+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8S"FUS9VED(")1=65R>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@
M(E%U;W1A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C8S"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@
M2V5Y("@E9"!B:70I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R-C0*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM
M<V=I9"`B4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M-0IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")286EN(%-H;W=E
M<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT-PIM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I
M9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(T
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"B,L(&9U>GIY"FUS9VED(")2
M96%D(&UE<W-A9V5S(@IM<V=S='(@(EII\F$B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A
M;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N
M92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N
M:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R
M(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U
M;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T
M:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(E)E
M9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"B,L(&9U>GIY"FUS9VED(")2969R
M97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R(")!=&IA=6YO="!K;W!S879I;&MU
M;6$@<VMA='4Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(S-0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(T.0IM<V=I9"`B4F5L871I;VYS:&EP
M($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM<V=I
M9"`B4F5L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S(V"FUS9VED(")296UA<FMS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,30*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B
M4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z
M,C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PHC+"!F=7IZ
M>0IM<V=I9"`B4F5M;W9E(@IM<V=S='(@(DEZ9'KG<W0@<.)R:2(*"B,Z('1E
M;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B
M4F5M;W9E($)L;V-K(@IM<V=S='(@(DEZ9'KG<W0@<.)R:2(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-3<*;7-G:60@(E)E
M;6]V92!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E
M(&9O<FUA='1I;F<B"FUS9W-T<B`B27ID>N=S="!PXG)I(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM
M<V=S='(@(DEZ9'KG<W0@<.)R:2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HR,#(*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G
M<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*(RP@
M9G5Z>GD*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B27ID>N=S="!PXG)I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O
M8W5M96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V92YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S
M='(@(DEZ9'KG<W0@<.)R:2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V92YI;F,Z-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E
M('5S97(Z("5S(@IM<V=S='(@(DEZ9'KG<W0@<.)R:2(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD
M;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"FUS9VED
M(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<T(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z-3$R"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")0:65P<F%S[G1A:7,@)W5I9"<@;F%V
M(&YO<N)D[G1S(&EE<W1A=.YJ=6UU(&MO;F9I9W5RXF-I:N(N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-S4@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C<R,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E
M<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(E!I97!R87/N=&%I<R`G=6ED)R!N878@;F]RXF3N=',@:65S=&%T[FIU
M;74@:V]N9FEG=7+B8VEJXBXB"@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H
M<#HW.#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB
M)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(E!I97!R87/N=&%I<R`G=6ED)R!N878@;F]RXF3N=',@:65S=&%T[FIU;74@
M:V]N9FEG=7+B8VEJXBXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E
M<F5R+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C`@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@HC+"!F=7IZ
M>0IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B4&%R;VQE(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E<V5T(%EO
M=7(@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$S,`IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI;B]C;61S:&5L;"YP:'`Z,C@@
M861M:6XO<W%L<VAE;&PN<&AP.C8V"FUS9VED(")297-U;'1S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA
M=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B
M"FUS9W-T<B`B071G<FEE>G1I97,@<&EE(&]P8VEJXFTB"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N97<@<&%S
M<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO
M;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U
M<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S(*(RP@9G5Z>GD*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*
M;7-G<W1R(")!=&=R:65Z=&EE<R!P:64@;W!C:6KB;2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,C$*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$W"FUS9VED(")2:6=H
M="!V86QU97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E
M<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R("),;VUA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(U"FUS
M9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,C(*;7-G:60@(E)O=&%T92!,969T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,C@*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS
M9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU,PHC+"!F=7IZ>0IM<V=I9"`B4G5L97,B"FUS9W-T
M<B`B3&]M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I
M9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E
M;B!R;W=S(&]N;'DB"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$R,`IM<V=I9"`B4G5N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G
M:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`S"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G
M<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E
M9"!-97-S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C4P-`HC+"!F=7IZ>0IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G
M<W1R(")::?)A(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED(")3
M44P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S(X,PIM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Q
M"FUS9VED(")34T@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I
M9"`B4U5#0T534R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-3,*;7-G
M:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E
M(&%N9"!-:7%U96QO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED
M(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR
M"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W
M"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL
M:71E(%!R;W9I9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@
M(E-A=61I($%R86)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VQA>6]U="YI;F,Z.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4V%V92`E<R(*;7-G<W1R(")386=L86+B="!O<&-I:F%S(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM
M<V=S='(@(E-A9VQA8N)T(&]P8VEJ87,B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,38W"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R
M>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.CDS"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P
M9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")38V%T
M=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R,`IM<V=I9"`B4V5A<F-H($5N
M9VEN97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,CDW,PIM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0*(RP@9G5Z>GD*
M;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B27IVYVQI971I97,@9&%T
M=6UA(&9O<FWB='4Z(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED(")396QE8W0@
M82!N97<@;W=N97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E
M;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HV-S<*;7-G:60@(E-E;&5C="!A
M;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V
M,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N
M(@IM<V=S='(@(DEZ=N=L:65T:65S(&1A='5M82!F;W)MXG1U.B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@
M(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.`IM<V=I9"`B4V5L96-T(&YO
M;F4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"B,L
M(&9U>GIY"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE
M960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N
M9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B
M(@HB27IVYVQI971I97,@<VEM8F]L=7,@;F\@>F5MXFL@<F5D>F%M86KB;2!I
M>G;G;&[G;2X@4.=C('1A;2!J^W,@=FGR=7,@=F%R870@(@HB<.)R;F5S="!A
M<B!C;W!Y+W!A<W1E(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*
M;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(DEZ
M=N=L:65T:65S(&1A='5M82!A=&1A;.YTXFIU.B(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T
M.B(*;7-G<W1R("))>G;G;&EE=&EE<R!D871U;6$@9F]R;>)T=3HB"@HC.B!T
M96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")3
M96QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,38*(RP@9G5Z>GD*
M;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S='(@(DEZ
M=N=L:65T:65S(&1A='5M82!A=&1A;.YTXFIU.B(*"B,Z('1E;7!L871E<R]D
M871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R;6%T
M.B(*;7-G<W1R("))>G;G;&EE=&EE<R!L86EK82!F;W)MXG1U.B(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@
M;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R("))>G;G;&EE=&EE<R!D:79U<R!S
M861E<NYG=7,@;&%U:W5S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M,#8*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T.`IM<V=I9"`B4V5L96-T
M('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R("))>G;G;&EE=&EE
M<R!V86QO9'4Z(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B3F]S^W3N
M="!P<F]B;.=M87,@<&EE=&5I:W5M=2(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,#,Y"FUS9VED(")396YD(%--4R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$V"FUS9VED(")396YS;W(Z
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B
M:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E-E<FEA;"!.=6UB97(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V
M,0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"FUS9VED(")3
M97-S:6]N($%D;6EN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)
M1"!E>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#4*(RP@
M9G5Z>GD*;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@(E-A9VQA8N)T(&]P8VEJ
M87,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$T"FUS9VED(")3
M970B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V"FUS
M9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P
M87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(E-E="!U<"!R96UO
M=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@
M<&]R=&%L+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#0*(RP@9G5Z>GD*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G
M92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B265S=.)D
M[G0@;&%P=6%T:F%U;F_P86[B<R!U;B!C:71A<R!E:W+B;F$@;W!C:6IA<RXB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*(RP@9G5Z>GD*;7-G:60@
M(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M
M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I
M;VYS+B(*;7-G<W1R("))97-TXF3N="!L87!U871J875N;_!A;N)S('5N(&-I
M=&%S(&5K<N)N82!O<&-I:F%S+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-S4*;7-G:60@(E-E='5P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E
M('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ.#8*;7-G:60@(E-E=F5R86P@;&]C871I;VYS
M('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y-@IM<V=I9"`B4VAO<'!I;F<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M-#,*(RP@9G5Z>GD*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`BSG-A
M(&%N;W3B8VEJ83HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0V"FUS
M9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L
M:6YK<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E
M<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R
M871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#DP"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM
M92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$W-C4*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@
M;W)I9VEN86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@Q,PIM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4R-@IM<V=I9"`B4VAO=R!T86)L92!O<&5R
M871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S0Y"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S
M($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B
M4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@
M9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO=R!T:&4@5&%B
M;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM
M<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,PIM<V=I9"`B
M4VAO=R!U<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*
M;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,@
M3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z-#@P"FUS9VED(")3:')I;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-S<T(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C@S-@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HY,C(@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z.3@T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P
M-#<@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`X-PHC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,3$V(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q-#D*;7-G:60@(E-H<FEN:R!O
M<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F
M:7)S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@
M3&5O;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N
M=7`N<&AP.C(V-0IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T
M=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-S$Q"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8U(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HX.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q
M-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R-#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS
M,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(S"FUS9VED(")3:7IE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@
M(DEZ;&%I<W0@=7IT=7+G\&%N=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L
M;W9A:VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E
M;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4T"FUS9VED(")3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W
M(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W
M"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N
M;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C<X"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U:79A;&5N
M="!I;B!W871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@
M(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS
M9VED(")3;VUA;&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(V"FUS9VED(")3;W)T(&]R9&5R
M('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"B,L(&9U>GIY"FUS9VED
M(")3;W5R8V4@861D<F5S<R(*;7-G<W1R(")$87)B82!A9')E<V4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E-O=71H($5U<F]P96%N
M("A)4T\M.#@U.2TS*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@
M(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@
M8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#$U"FUS9VED(")3<&%C97(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"FUS
M9VED(")3<&%C:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@
M86YD('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P
M86EN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY
M.`IM<V=I9"`B4W!A;2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R
M9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S
M='(@(LYP8?!O('-I;6)O;'4@:65V861E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@
M8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B4W!O
M<G1S(@IM<V=S='(@(DEE;.)D92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I
M($QA;FMA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP.C<T"B,L(&9U>GIY"FUS9VED
M(")3=&%N9&%R9"(*;7-G<W1R(")+86QE;F3B<G,B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DV(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,#D*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@
M(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-0HC+"!F=7IZ
M>0IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B2OMS=2!I;F9O<FWB
M8VEJ82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<R
M"B,L(&9U>GIY"FUS9VED(")3=')E970@061D<F5S<R(*;7-G<W1R(")$87)B
M82!A9')E<V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S,*;7-G:60@(E-T<FEN9R!L
M:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M-S,*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G
M:60@(E-U(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB
M)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DYA=B!S=')O9&%M<R!P87II\F]J
M=6UU(&ML875S[G3B:G,@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*;7-G:60@(E-U8FUI="(*;7-G<W1R
M("(B"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E
M;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H
M87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#0*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R(")696EK<VUE(@H*
M(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@
M9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E
M;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM
M<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E
M;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS
M9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K
M=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY('5P9&%T960@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4V"B,L(&9U>GIY"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(DUA;G,@:V]P
M<V%V:6QK=6US(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED
M(")3=6X@4FES92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-U;FYY(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*
M;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR
M:7-E+U-U;G-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C$U"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.0IM<V=I9"`B4W5N<V5T
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,3@*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R
M:7!T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M-S@*(RP@9G5Z>GD*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B265LXF1E(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,34@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-@HC+"!F=7IZ>0IM<V=I9"`B4W5R:6YA;64B"FUS9W-T
M<B`B3&EE=&]TXFIA(';B<F1S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-S0*(RP@9G5Z>GD*;7-G:60@(E-U<FYA;64B"FUS9W-T
M<B`B3&EE=&]TXFIA(';B<F1S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A
M;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X
M"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM
M<V=I9"`B4W=E9&5N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3
M=VET>F5R;&%N9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30R"FUS9VED(")3>6YC34PB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP
M.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B
M;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8P"FUS9VED(")4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")4
M+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3=&]R;7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C,*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-C8*(RP@9G5Z>GD*;7-G:60@
M(E135B!F:6QE(@IM<V=S='(@(E9I<G-R86MS=',B"@HC.B!F<F%M97=O<FLO
M54DO54DO5&%B;&4N<&AP.C$S-`HC+"!F=7IZ>0IM<V=I9"`B5&%B;&4B"FUS
M9W-T<B`B5FER<W)A:W-T<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A
M8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@4V5T(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW
M86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDU"FUS9VED(")487)G970Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]H;V]K
M<RYP:'`N9&ES=#HY.38@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X-PIM
M<V=I9"`B5&%S:W,B"FUS9W-T<B`B57ID979U;6DB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B5&5L97!H;VYE($YU
M;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,`IM
M<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,30*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C,*;7-G
M:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP
M97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-C@W"B,L
M('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED
M(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,S,S8*;7-G:60@(E1E>'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,W-0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X
M='1O<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"B,L(&9U>GIY
M"FUS9VED(")4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN(@IM<V=S
M='(@(DK[<R!E<V%T(&EZ9^)J:7,@;F\@<VES=.=M87,N/&)R("\^4&%L9&EE
M<R!P87(@<VES=.=M87,@;&EE=&_P86YU+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z.#(P"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O
M2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E
M<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+T)O
M;VLN<&AP.C$R.3(*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@
M:6YI=&EA;&EZ960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED
M(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N
M<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR
M,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C0@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES
M=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S
M:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N
M<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU
M;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T
M(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4
M:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,38Y"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I
M9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE
M9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N
M;W0@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0N<&AP.C$Q,PIM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@
M<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S4@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HU,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I
M;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V."!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,3D*;7-G
M:60@(E1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.#`*;7-G
M:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS
M9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M
M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4
M:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M
M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B
M=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@
M;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@
M961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE
M<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y
M(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T
M:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@
M8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL
M('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O;FQY
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA
M<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR,#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E
M<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE
M9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@
M:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W"FUS9VED(")4:&4@;F%M92!T
M;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Q"B,L(&9U
M>GIY"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R
M:6,N(@IM<V=S='(@(M!A:2!VYW)T[F)A:2!I<B!JXF+[="!S:V%I=&QI;2XB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S$*;7-G
M:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO
M<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@
M8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO
M=V%B;&4@<VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]W96)C<'`N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S
M*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0U-`IM<V=I9"`B5&AE('%U
M;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED
M97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N
M9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z-#0V"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE
M('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S
M97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO
M=F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S<&5C:69I960@<F]W(&1O97,@;F]T
M(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I
M;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S$Q"FUS9VED(")4:&4@=&5X="!Y;W4@
M96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S
M:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED
M92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP
M.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@
M=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N
M<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E
M('-A=F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4V"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$Q.0IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K
M(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER
M96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X"B,L(&9U>GIY"FUS9VED(")4
M:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(DEE<W1A
M=.YJ=6UI(&YA=B!P:65E:F%M:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C,T,@IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H
M870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F
M:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@
M;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU
M<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S
M>7-T96TZ("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R
M:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F
M<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.
M;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M<F]W<V5R+T)R;W=S97(N<&AP.C@X.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4
M:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W960@
M<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O
M=W-E<B]"<F]W<V5R+G!H<#HX.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE
M("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S
M86=E('!A<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@P"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@
M4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F
M;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0
M;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T
M(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R
M"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I
M<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R
M="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*
M;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP
M(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q-#4*(RP@9G5Z>GD*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B
M92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R("+086D@=N=R=.YB86D@
M:7(@:N)B^W0@<VMA:71L:6TN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E
M<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC
M:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S
M:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.
M("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA
M:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T
M:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H
M<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@
M5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N
M="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDW."!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#4W"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$P.#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q-0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@R(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R-38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P
M-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,SDX"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$U-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@S
M.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34X(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P,#4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C`R.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<X"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q-#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C(R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$P(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(T-30*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C8U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#(X"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S,P-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#$T(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,X,C(*;7-G:60@(E1H:7,@9FEE;&0@:7,@
M<F5Q=6ER960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I
M;G1E9V5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C0Q.`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU
M;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`Y-`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL
M>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T
M(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E
M<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@Y
M"B,L(&9U>GIY"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N
M=6UB97(N(@IM<V=S='(@(M!A:2!VYW)T[F)A:2!I<B!JXF+[="!S:V%I=&QI
M;2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V"FUS9VED("(B
M"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE
M(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4V,0IM<V=I
M9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C0U.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE
M=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N
M="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T
M+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@
M=FES:70@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z-3DQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S
M<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE
M<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B
M92!A="!L96%S="!O;F4N(@IM<V=S='(@(M!I;2!S:V%I=&QI;2!I<B!JXF+[
M="!V:7-M87H@,2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E
M<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S
M>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI
M<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R("+086D@=N=R=.YB
M86D@:7(@:N)B^W0@<VMA:71L:6TN(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O
M;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C
M86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B
M5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C,T"FUS9VED(")4:6-K971S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(T,C@@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")4:6UE(@IM<V=S='(@(E9I<G-R86MS
M=',B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@V"FUS9VED(")4
M:6UE(%1R86-K:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C4S.0IM<V=I9"`B5&EM92!S96QE8W1I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET
M;&4B"FUS9W-T<B`B5FER<W)A:W-T<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP
M*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B(@HB
M5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R
M;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN
M9RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,Q,0IM<V=I9"`B5&]D87DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A4
M34P@4V]U<F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O
M9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$S
M"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS
M9VED(")4;VYG82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L871I;VYS(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4
M;V)A9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3<Y,`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4
M=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B5'5R:VES
M:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I
M9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G
M:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-CD*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G
M:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDW"B,L(&9U>GIY"FUS9VED(")54DPZ(@IM<V=S='(@(E52
M3"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$R"FUS9VED(")5:W)A:6YE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q,@HC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").878@
M:65S<.=J86US('!I97-LYV=T:65S(%-13"!S97)V97)I;2XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T
M;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S@X
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES
M<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS.#4@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U-0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB
M"FUS9W-T<B`B3F%V(&EE<W#G:F%M<R!P:65S;.=G=&EE<R!344P@<V5R=F5R
M:6TN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C8X."!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP
M.C0S-0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB
M"FUS9W-T<B`B3F%V(&EE<W#G:F%M<R!P:65S;.=G=&EE<R!344P@<V5R=F5R
M:6TN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,SD*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R
M(").878@:65S<.=J86US('!I97-LYV=T:65S(%-13"!S97)V97)I;2XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,C4@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P
M,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B
M3F%V(&EE<W#G:F%M<R!P:65S;.=G=&EE<R!344P@<V5R=F5R:6TN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S4T
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(U-@HC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").878@:65S
M<.=J86US('!I97-LYV=T:65S(%-13"!S97)V97)I;2XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R(").878@:65S<.=J86US
M('!I97-LYV=T:65S(%-13"!S97)V97)I;2XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-C4*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(DYA
M=B!I97-PYVIA;7,@<&EE<VSG9W1I97,@4U%,('-E<G9E<FEM+B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW.0IM<V=I9"`B56YA
M8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HR,C0@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HR.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!<(B5S7"(Z("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HS,S$@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS.3(*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S,T"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M
M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS-#@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U,@IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV
M96QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HS,S<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,T-`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R(").878@:65S<.=J86US('!I97-LYV=T:65S
M(%-13"!S97)V97)I;2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C0Q-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0R.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(P
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,S`S(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C@X"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ-C<@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C$X,`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3@W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.#,*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Y,0IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E
M;'DZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C@P,PHC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C
M=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F%V(&EE<W#G:F%M<R!S97-I
M:N(@<F7L:7-T<N=T(&EE<W1A=.YJ=6UU<RXB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8P,PIM<V=I9"`B56YA8FQE('1O(&5X=')A
M8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7TE-4U`O24U34"YP:'`Z-#4Q(&9R86UE=V]R:R].971?24U34"])
M35-0+T%U=&@N<&AP.C$Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,38V(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-S$*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G
M<W1R(").878@:65S<.=J86US('!I97-LYV=T:65S(%-13"!S97)V97)I;2XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,3`R"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-C0X(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.3@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-S<@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,S"FUS9VED(")5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#`@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HW,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N
M(@IM<V=S='(@(DYA=B!I97-PYVIA;7,@<&EE<VSG9W1I97,@4U%,('-E<G9E
M<FEM+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M-#4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@
M87)C:&EV92XB"FUS9W-T<B`B3F%V(&EE<W#G:F%M<R!P:65S;.=G=&EE<R!3
M44P@<V5R=F5R:6TN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@S-0IM
M<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I
M;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V
M-@IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE
M*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B
M;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z-C8Y"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@
M=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR
M96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C(Y,PHC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E
M;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").878@:65S<.=J86US('!I
M97-LYV=T:65S(%-13"!S97)V97)I;2XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C,R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(V-R!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,T,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z-C$P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HS,C,@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C(Q,PHC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#4R(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.#4*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,P,0IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED(")5;F%B;&4@
M=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O
M('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B3F%V(&EE
M<W#G:F%M<R!I;G1E<G!R973G="#P;R!7;W)D(&1O:W5M96YT=2(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,30Y(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,34R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W
M<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C$W.0IM<V=I9"`B56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$T,PIM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-#$*
M;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B
M92!E>&-E961E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N
M9&\@0VAA;F=E<R(*;7-G<W1R(")!=&-E;'0@:7IM86GR87,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5
M;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED(")5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S0Q"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W
M.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*
M;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-
M86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B56YI8V]D92`H551&+3@I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%
M;6ER871E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E
M9"!+:6YG9&]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N
M:71E9"!3=&%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B
M56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV.2!L:6(O0FQO
M8VLO;65T87(N<&AP.C<Q"FUS9VED(")5;FET<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@
M240I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@
M*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$U.0IM<V=I9"`B56YK;F]W;B!L;V-A=&EO
M;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S
M97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@
M(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,CDV"B,L(&9U>GIY"FUS
M9VED(")5;FYA;65D(@IM<V=S='(@(DQI971O=.)J82!VXG)D<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@
M(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O
M<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S
M;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z
M:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C
M<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M,@IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#8@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HY,C8*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HY,S(*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*;7-G
M:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DY"FUS9VED(")5<&QO860B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I9"`B
M57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S
M97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN
M(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M
M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5
M<G5G=6%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S
M92!#=7)R96YT.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED
M(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@
M<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C(Q"B,L(&9U>GIY"FUS9VED(")5<V5R(@IM<V=S='(@(DQI
M971O=.)J82!VXG)D<R(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I
M<W1R>2YP:'`Z-S(S"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@
M;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR-3$*;7-G
M:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R("),:65T;W3B:F$@;W!C:6IA<R(*
M"B,Z('-I9VYU<"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(E5S97(@4F5G:7-T
M<F%T:6]N(@IM<V=S='(@(DQI971O=.)J82!O<&-I:F%S(@H*(SH@<VEG;G5P
M+G!H<#HR,@IM<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES
M86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C0V.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N
M9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R
M;F%M92(*;7-G<W1R("),:65T;W3B:F$@=N)R9',B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@
M(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W"B,L(&9U>GIY"FUS
M9VED(")5<V5R;F%M93HB"FUS9W-T<B`B3&EE=&]TXFIA(';B<F1S(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B
M57-E<FYA;64Z("(*;7-G<W1R("),:65T;W3B:F$@=N)R9',B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T
M:&4@<WES=&5M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5
M>F)E:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C$V,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-34*;7-G
M:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3@*;7-G:60@(E9A8V%T
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V
M-@IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S
M.`IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS9VED(")6
M86QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX-38@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I<R!O=F5R('1H
M92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,C8V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,38@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,CDR.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3@V"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R
M;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0T
M"FUS9VED(")687)I86)L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS
M9VED(")696YE>G5E;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL
M960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C<P,`IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C(V"FUS9VED(")697)S:6]N($-O;G1R;VPB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED
M(")697)T:6-A;#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5FEE=&YA;65S
M92`H5DE30TE)*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HY-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED
M(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Y"FUS9VED(")6
M:7-I8FEL:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-C,*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%144"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VAT;6PN<&AP.C(W,B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#,*
M;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B0G+N9&ENXFIU;7,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")7
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0R-PIM<V=I9"`B5V5A=&AE<B!D
M871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,W"FUS9VED(")7
M96(@4VET92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O
M36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B2V%T
M<G4@;F5DY^]U(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*
M(RP@9G5Z>GD*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B3&%I<&YI(&S[9'IM
M+"`E<R(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7
M96QC;VUE('1O("5S(@IM<V=S='(@(DQA:7!N:2!L^V1Z86T@)7,B"@HC.B!S
M97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L
M+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B
M"FUS9W-T<B`B3&%I<&YI(&S[9'IM+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5V5S=&5R
M;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED
M(")797-T97)N(%-A:&%R82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC
M871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7
M:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I
M<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V,0IM<V=I9"`B5VAE
M<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@(E=H:6-H('!L=6=I
M;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-0IM<V=I9"`B5VED=&@@:6X@0U-3('5N
M:71S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@
M=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*
M;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$S"FUS
M9VED(")7:6MI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,#`@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C4*;7-G:60@(E=I;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I;F0@16%R;'DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,`IM<V=I9"`B
M5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$U-@IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T,@IM<V=I9"`B5VEN9#H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B
M5VES9&]M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ.38*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@
M(E=O<FL@061D<F5S<R(*;7-G<W1R(")$87)B82!A9')E<V4B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED(")7
M;W)K(%!H;VYE(@IM<V=S='(@(D1A<F)A('3B;')U;FES(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z,38Y(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@
M;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S`P
M"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N
M($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,3$T"B,L('!H<"UF;W)M870*;7-G:60@
M(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#,*;7-G
M:60@(E@M4F5F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.3(*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.30*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@R
M"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`B1T<B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-34*(RP@9G5Z
M>GD*;7-G:60@(EE965DB"FUS9W-T<B`B1T<B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$P.`IM<V=I9"`B66%H;V\A(&UA
M<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E
M;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`B2V%T<G4@9V%D
M=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G
M:60@(EEE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;
M/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z.#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R
M92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-#$Q"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT
M:6-A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E
M;G1I='DN<&AP.C,P,@IM<V=I9"`B66]U(&-A;B!N;W0@:&%V92!T:&4@)UQ<
M)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DW-0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI
M9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I
M9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O
M('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"B,L(&9U>GIY"FUS
M9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(DK[<W4@
M;W!C:6IA<R!I<B!S86=L86+B=&%S+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L
M:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I
M;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E
M9FEX+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3@X"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME
M;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z-#4V"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@
M82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H
M92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P
M;W)T+B(*;7-G<W1R(")!<')A:W-T:65T('!R;V)LYVUU('!I<FUS('!I971E
M:6MU;6$@<_MT[O!A;F%S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!5
M4DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@
M<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@
M82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(')E;6]V92XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z
M-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9
M;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*;7-G:60@
M(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-S$*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O
M<GD@;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O
M('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<V"B,L('!H<"UF;W)M870*
M;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO
M9VEN(&%G86EN+B(*;7-G<W1R(")*^W-U("5S('-E<VEJ82!I<B!B96EG=7-I
M97,N($S[9'IU('!I97-LYV1Z:65T:65S(&%T:^)R=&]T:2XB"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`HC+"!F=7IZ>0IM<V=I9"`B
M66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(DK[<W4@92UP87-T82!A9')E
M<V4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q,@HC+"!F=7IZ>0IM
M<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")*^W-U(&4M<&%S
M=&$@861R97-E.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-"!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B66]U<B!);F9O
M<FUA=&EO;B(*;7-G<W1R(")*^W-U(&EN9F]R;>)C:6IA(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z.3@P"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@
M8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y
M;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*(RP@9G5Z
M>GD*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R(")*^W-U(';B<F1S.B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"FUS9VED("(B"B)9
M;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A
M9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A
M9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E
M<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*
M(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I
M<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@T"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S
M:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@
M<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*;7-G:60@
M(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z
M-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H
M:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*
M(G1O('!R:6YT+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C4W"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.38*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G
M<W1R(")*^W-U(&]P8VEJ87,@:7(@<V%G;&%BXG1A<RXB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,34X"B,L(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U
M;'0@:61E;G1I='DZ(@IM<V=S='(@(E!A<F%S=.(@:61E;G1I=.)T92(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#$*(RP@9G5Z>GD*;7-G:60@(EEO
M=7(@9G5L;"!N86UE.B(*;7-G<W1R(")*^W-U(';B<F1S.B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.C$P,#`*(RP@9G5Z>GD*;7-G:60@(EEO=7(@
M;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S='(@(DK[<W4@;W!C:6IA<R!I<B!S
M86=L86+B=&%S+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V
M"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E
M<R!I<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HQ-30*(RP@9G5Z>GD*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO
M;BXB"FUS9W-T<B`B2OMS=2!O<&-I:F%S(&ER('-A9VQA8N)T87,N(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`B2OMS=2!O<&-I
M:F%S(&ER('-A9VQA8N)T87,N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*
M;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K
M('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W
M;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW
M,S(*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B
M66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL
M:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U
M;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G:60@(EM0
M<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B6U!R;V)LYVUA<R!Z:?)O:G5M<UTB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM
M<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z
M,3<R"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@
M)7,@;&EN97-=(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S
M72(*;7-G<W1R(");<FEN9&$@)7,@;F\@)7-=(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-30Q('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z
M,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O
M87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`B(@H*(SH@;&EB+V%P
M:2YP:'`Z,30Q"FUS9VED(")?1&%T851R964B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q
M"FUS9VED(")?1&5L971E(%)O=R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H
M<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0HC+"!F=7IZ>0IM<V=I9"`B7TAE
M;'`B"FUS9W-T<B`B4&%L[F1Z[F)A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@
M4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O365N=2YP:'`Z,3DT"B,L(&9U>GIY"FUS9VED(")?3&]G(&EN(@IM
M<V=S='(@(E!I97-LYV=T:65S(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TUE;G4N<&AP.C$Y,`HC+"!F=7IZ>0IM<V=I9"`B7TQO9R!O=70B"FUS9W-T
M<B`B27II970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T
M"B,L(&9U>GIY"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R(")/<&-I:F%S(@H*
M(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(V"B,L(&9U>GIY"FUS9VED(")?4F5M;W9E($QI;FLN+BXB
M"FUS9W-T<B`B27ID>N=S="!PXG)I(@H*(SH@;&EB+V%P:2YP:'`Z,3(U"FUS
M9VED(")?4V5T=7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@
M4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,CD*
M;7-G:60@(E]5<V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDR,0HC+"!F=7IZ>0IM<V=I9"`B861D<F5S<R!B;V]K(@IM
M<V=S='(@(DMO;G1A:W1I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$S"B,L(&9U>GIY
M"FUS9VED(")C86QE;F1A<B(*;7-G<W1R(")+86QE;F3B<G,B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN;W0@
M8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I
M;G!U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HU.3(*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O
M;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W.`IM<V=I9"`B8V]N9FEG=7)A
M=&EO;B!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@
M;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ.#(*
M;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B9F%L;&EN
M9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HX-34*(RP@9G5Z>GD*;7-G:60@(F9I;&4B"FUS9W-T<B`B5FER<W)A:W-T
M<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<T(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S8P(&QI8B]";&]C:R]M971A<BYP:'`Z,S@V"B,L('!H<"UF;W)M
M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,`IM<V=I9"`B
M9W5S=&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C0Y"FUS9VED(")H.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4X"FUS9VED
M(")H:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*
M;7-G:60@(FEN;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ
M,PIM<V=I9"`B;&EN97-=(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG
M($E33RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,V.0IM<V=I9"`B;6TB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR.3$@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP
M:'`Z,C,R"B,L(&9U>GIY"FUS9VED(")N86UE(@IM<V=S='(@(E;B<F1S(@H*
M(SH@9G)A;65W;W)K+U)00R]24$,N<&AP.C$R,0IM<V=I9"`B;F]T(&EM<&QE
M;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,3(Q.0IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-0IM<V=I
M9"`B;F]T97!A9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3<T"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y
M"FUS9VED(")P:7AE;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P
M<F]T;V-O;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B<FES:6YG(@IM<V=S
M='(@(D)R[F1I;N)J=6US(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-#(*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HY.0IM<V=I9"`B<VAO
M=R!D:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL
M('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HS.#4*;7-G:60@(G-S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED
M(")S=&5A9'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HS,#D*;7-G:60@(G-W:71C:"!O9F8@:F%V87-C<FEP="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U,`IM
M<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3(Y"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C8*;7-G
M:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,S`U"B,L(&9U>GIY"FUS9VED(")T<GD@86=A
M:6XB"FUS9W-T<B`B2V%T<N(@<&EE<VSG9_!A;N)S(')E:7KG(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C(V.0IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER
M;2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI
M;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U
M;FYA;65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-#$*;7-G:60@
M(G<Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HV"FUS9VED(")W96%T:&5R+F-O;2(*;7-G<W1R("(B"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]M:U]-2RYP;P``````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-C$Q-C0V`#$P
M-3$U-#,S-S4T`#`Q-S8U,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````C('1R86YS;&%T:6]N(&]F(&UK7TU++G!O('1O($UA
M8V5D;VYI86X*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE
M('-A;64@;&EC96YS92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*(R!#;W!Y<FEG
M:'0@*$,I(#(P,#,@175R96MA($EN9F]R;6%T:6MA"B,@4W1O:F%N(%!E<V]V
M(#QS<W!`975R96MA+F-O;2YM:SXL(#(P,#,*(PIM<V=I9"`B(@IM<V=S='(@
M(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@;6M?34M<;B(*(E)E<&]R="U-<V=I
M9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I
M;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO
M;BU$871E.B`R,#`S+3`V+3(V(#$U.C$X*S`R,#!<;B(*(DQA<W0M5')A;G-L
M871O<CH@4W1O:F%N(%!E<V]V(#QS<W!`975R96MA+F-O;2YM:SY<;B(*(DQA
M;F=U86=E+51E86TZ($UA8V5D;VYI86X@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G
M/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X
M="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TU7&XB"B)#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X8FET7&XB"B)8+4=E;F5R871O<CH@2T)A8F5L(#$N
M,"XQ7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@
M*&EN("5S(&1A>7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-S,*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H=&]M;W)R;W<I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S$*
M;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C4V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-C$*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-PIM
M<V=I9"`B(&%T("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T
M(&$@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,
M22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@
M82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92]296=I<W1R>2YP:'`Z-C4Y"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]296=I<W1R>2YP:'`Z,3`T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4V"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O
M('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R("(G)7,G(./AW]7HW=X@U-[4
MT-35W2#=T"#AV.'BU=S>XBXB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T
M;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E
M<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"B,L
M('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO
M=V5D("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@86YD
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S,@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.#,U"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M($M"(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I
M;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S(+[?U>#0YMC8(-?0(-[4
MX-;CTM#ZU2`M(+_>XM+@U-`B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3
M:6=N(%5P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE
M;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT
M,C@@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3`*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HV-3$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Y(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,38U(&QI8B]";&]C:R]M971A<BYP:'`Z,C,Y"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S0U(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S4Q"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T
M:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C
M:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O
M('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("*RVMOCY]@@T-K>(.'0
MVM#H(-30(-C7TN#HV.@@W=7:WM@@WM_5X-#FV-@@TMX@W-[<U=WBWM(N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,T,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU
M=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL
M96-T:6]N+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(R"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*
M;7-G<W1R("*PU.#5X=#@(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T
M(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL
M;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@
M<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8U(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,3`*;7-G:60@(BP@9W5S=&EN9R`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T
M:6YG("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T
M;R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C(Y-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q,C@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C<T.0IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M870B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"FUS9VED("(R
M-"!(;W5R($9O<FUA="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T
M:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@Y]#AT"(*
M"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z-CD*;7-G:60@(CQ0<F5V
M:6]U<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q.0IM
M<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES
M(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$V,`IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3,U
M"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y
M<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,38U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES
M(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#DW"FUS
M9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3`Q-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T
M92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG
M;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3`U"FUS9VED("(B"B)!('!U8FQI8R!3+TU)
M344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G
M:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M
M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E
M<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"FUS9VED(")!
M32!#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS
M9W-T<B`B04TO4$TB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS
M9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]H96QP+VEN9&5X+G!H<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O
M<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"FUS9VED
M(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW-0HC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!087-S
M=V]R9"(*;7-G<W1R("*_WN+2X-38(-O>U]C=VM`B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C
M8V]U;G0@9G)O>F5N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S,S"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X('1E;7!L871E<R]P
M;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D
M9&-H:6QD+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B061D(@IM<V=S='(@(K#4
MX-7AT"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP
M:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.CDY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0HC
M+"!F=7IZ>0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(K3>U-#4V"#:WN#8
MX=W8VB(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP
M:'`Z,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N
M:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@
M=&\@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD
M('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`BM-[4
MT-38(-W>TB#:WN#8X=W8VCHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-34T"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*(RP@
M9G5Z>GD*;7-G:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R("*TWM30U-@@
MW=[2(-K>X-CAW=C:.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(K3>U-#4V"#?T.`B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@
M(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M-S$*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S
M='(@(K#4X-7AT.`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-S@*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S
M(&)O;VLB"FUS9W-T<B`BL-3@U>'0X"(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q
M"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R("*TWM30U-@@VM[@V.'=V-HB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!
M9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@
M861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R
M("(B"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D
M9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN
M8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@
M(K3>U-#2T/K5XMX@W=`@VM[@V.'=V.;8(-4@WMW5TM[7W-[6U=W>+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q"FUS9VED(")!9&1R97-S(@IM<V=S
M='(@(K#4X-7AT"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,SD*
M(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R("*PU.#5X=#@
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*
M;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R
M('5S97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES=')A
M=&EO;B(*;7-G<W1R("*PU-S8W=CAXN#0YMCXT"(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-#$*(RP@9G5Z>GD*;7-G:60@(D%D<R(*;7-G<W1R
M("*PU.#5X=`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!9F=H86YI<W1A;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4W"B,L(&9U>GIY"FUS9VED(")!;&)A;FEA(@IM
M<V=S='(@(D%L:6%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B06QG
M97)I82(*;7-G<W1R(")!;&EA<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(D%L
M:6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHQ-@HC+"!F=7IZ>0IM<V=I9"`B06QI9VXB"FUS9W-T<B`B06QI
M87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O
M=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O9&%T871R964N<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,0IM<V=I
M9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S0*;7-G:60@(D%L;&]W('-E='1I;F<@
M;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D
M>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$R,PIM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-PIM<V=I9"`B06QT97)N871E
M($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0Y.0IM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*(RP@
M9G5Z>GD*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@
M(K+0Z-`@16UA:6P@T-3@U>'0.B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@
M=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$V-PIM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@
M;V-C=7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO
M;GEM;W5S(%!R;WAY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V
M"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S+V%D
M;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS
M9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!
M<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I
M9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@S,PIM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I
M9"`B07!R:6PB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M-S4*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,0IM<V=I9"`B07)C:&EV92!&
M:6QE(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#`*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L('!H<"UF
M;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@
M=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L('!H<"UF;W)M
M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E
M<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G
M:60@(D%R;65N:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ-S8*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO
M;B!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G
M:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,C4*
M;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN
M=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3$S"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T
M96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M
M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@V"FUS9VED(")!='1R
M:6)U=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E
M<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!
M=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P
M86)I;&ET97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA
M<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!2
M97%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@
M=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T
M:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-3$*
M;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@
M;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B
M075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O
M<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER
M960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*
M;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DY
M"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P
M9&%T92!U<V5R("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S
M97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-#8*
M;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M
M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T
M:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@
M(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ
M-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S
M97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.#4Q"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A
M:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HW,`IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@
M9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R("*TWN'B
MT-_=V"#?WMO8^M`Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@
M(D)/1D@@17AC=7-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O
M=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I
M9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R
M;W,@=7-E<FYA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A
M:&%M87,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B
M0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM
M<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED
M(")"87)B861O<R(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E
M8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"FUS9VED
M(")"87-E;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA
M<G5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L:7IE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I
M9"`B0FAU=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@
M(L#>U-7=U-7=(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I
M;VXN<&AP.C,U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@
M;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C@Y"FUS9VED(")";&]C
M:R!3971T:6YG<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA
M>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED
M(")";VQD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P-0IM
M<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G
M:60@(D)O<F1E<B(*;7-G<W1R(")(;W)D92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC
M:VYE<W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(D)O<F1E
M<G,B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@
M86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S
M"FUS9VED(")";W1S=V%N82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O
M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@27-L86YD
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(D)R87II
M;"(*;7-G<W1R("*_WNCBT"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H
M($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T
M960@3&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA
M($9A<V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0T"B,L
M(&9U>GIY"FUS9VED(")#35,B"FUS9W-T<B`B0U93(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW
M"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B0V%C
M:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-"!C;VYF:6<O
M:&]O:W,N<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ-34*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-#8*;7-G:60@(D-A;&TB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T
M('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T
M;R!F:6QE(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP
M:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO
M;B!H86YD;&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)U<RYP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H
M<#HS,3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&-O;FYE
M8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(KW5X^'?U>C=T"#:WMW5
MVN;8^-`@X=X@3$1!4"#AU>#2U>#>XBXB"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HT,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E
M;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B
M0V%N861A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI
M;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E
M+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I9"`B0V%N
M8V5L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B
MON+:T-;8(+_@WM';U=P@P-7?WN#B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T
M92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C0V"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD
M(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N
M;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A
M5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN
M<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E+"`E
M9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A
M=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@
M<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D
M97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I
M960@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E
M(%9E<F1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*(RP@9G5Z>GD*;7-G:60@(D-A<'1I
M;VXB"FUS9W-T<B`BM]#GX]+0^"#>W^;8V"(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`*;7-G:60@
M(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L
M;"!0:&]N92(*;7-G<W1R("*\WM'8V]7=(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0HC+"!F=7IZ>0IM<V=I
M9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(KS>T=C;U=TB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B
M0V5L;"!P861D:6YG.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R
M;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W-`HC+"!F
M=7IZ>0IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(KS>T=C;U=TB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B0V5L=&EC("A)4T\M.#@U
M.2TQ-"DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI
M8R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I
M9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.3D*;7-G:60@
M(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3$*;7-G:60@(D-E<G1I9FEC871E
M($]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DV"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHY-@HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E(@IM
M<V=S='(@(K[BVM#6V"#3V"#?X-[<U=W8XM4B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(D-H86YG92!9;W5R
M(%!A<W-W;W)D(@IM<V=S='(@(K_>XM+@U-@@V][7V-W:T"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE
M(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A
M;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I
M;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U
M<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B0VAI;&4B"FUS9W-T<B`BO=#A
MV][2(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;F$B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI
M9FEE9"`H1T(R,S$R*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X,0IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V
M.0HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B
MO][BTN#4V"#;WM?8W=K0(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N
M=7`N<&AP.C(V.`IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y.`IM<V=I9"`B0VAO;W-E
M(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS
M9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T
M<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES
M;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP
M.C(Y-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#DS"B,L('!H<"UF;W)M870*
M;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ-`IM<V=I9"`B0VQE87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/
M9F9I8V4@=&%G<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3(X"FUS9VED(")#;&5A<B!1=65R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T
M"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*;7-G:60@(D-L96%R
M:6YG($QA=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*
M;7-G<W1R("*WT.+2WN#8(-/>(-_@WM?>X-7FWN(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(T-`IM<V=I9"`B0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V"FUS9VED(")#
M;&]U9',@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S
M"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G
M:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*
M;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]C;VQO
M<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#
M;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L
M;&5C=&EO;BYP:'`Z,S(T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL
M96-T:6]N+G!H<#HS,C4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4P,"!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP
M.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@T-@IM<V=I9"`B0V]L;W5R('-E;&5C=&EO
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-@IM<V=I9"`B0V]L=6UN('1I=&QE
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8T
M"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B(@H*(SH@861M:6XO8VUD<VAE;&PN
M<&AP.C(U"B,L(&9U>GIY"FUS9VED(")#;VUM86YD(@IM<V=S='(@(L38X-S0
M(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H
M96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-@IM<V=I9"`B0V]M;6]N($YA
M;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(D-O;6]R;W,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R("+$V.#<T"(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3<*;7-G
M:60@(D-O;F1I=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(T.0IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F
M97)E;F-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,30S"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!
M<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I;VX@
M:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`BO][BTN#4
MV"#;WM?8W=K0(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E
M<'5B;&EC(&]F('1H92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G
M:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E
M9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#0U"FUS
M9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`Q-`IM<V=I9"`B0V]N
M=&%C=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F
M=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU-B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R("+!WM3@
MUMC=T"#=T"`G)7,G(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT
M:6YU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N
M9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"FUS
M9VED(")#;V]K:64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"B,L(&9U>GIY"FUS9VED
M(")#;W!Y(@IM<V=S='(@(L38X-S0(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HT-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O<'D@
M9F%I;&5D.B`E<R(*;7-G<W1R("*XW-_>X.+8X-#=WB#?WMO5.B`E<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G
M:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S8*;7-G:60@
M(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4S"FUS9VED(")#
M;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD
M(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U
M;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"B,L(&9U>GIY
M"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T
M<B`BO=7CX=_5Z-W0(-K>W=7:YMCXT"#AWB!,1$%0(.'5X-+5X-[B+B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*;7-G:60@(D-O=6QD(&YO="!B
M:6YD('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0HC+"!F=7IZ
M>0IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V97(B"FUS
M9W-T<B`BO=7CX=_5Z-W0(-K>W=7:YMCXT"#AWB!,1$%0(.'5X-+5X-[B+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG
M($944#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$R-0IM
M<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3(R"FUS9VED
M(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR
M-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT
M86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R
M:7!T(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HS.#$@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE
M;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O
M=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I
M8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@
M9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP
M.C@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T
M96=Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q
M,`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U
M='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N
M;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O
M<&5N("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O
M36%I;G1E;F%N8V4N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R
M("*\WM3CV][B(-W0(-?0U-#GT.+0(-?0(-[4X-;CTM#ZU2`E<R#=U2#<WM;5
M(-30(-'8U-4@WN+2WN#5W2(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T
M;W)Y(%PB)7-<(BXB"FUS9W-T<B`BO-[4X]O>XB#=T"#7T-30Y]#BT"#7T"#>
MU.#6X]+0^M4@)7,@W=4@W-[6U2#4T"#1V-35(-[BTM[@U=TB"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HV.3D*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R96%C
M:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(KW5X^'?U>C=T"#:WMW5VN;8
M^-`@X=X@3$1!4"#AU>#2U>#>XBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/
M8FIE8W0N<&AP.C(S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<F5A9"`E<RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O
M<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE
M("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE
M<B!H96QP+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS,#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S0P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,W-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS.#,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S@Y"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR
M,C,*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL
M:71I97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU
M-`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")(;W)D92#=U2#5(-_@T-+8V]W>(-K>W>38T^/@V.#0
MW2(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I
M9W5A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C
M:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I
M9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N
M;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I
M=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O
M9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W
M('1O("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C$T,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T
M:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(KW5X^'?U>C=T"#:WMW5VN;8^-`@
MX=X@3$1!4"#AU>#2U>#>XBXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U
M<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T
M:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-C8*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL
M;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C$U-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E
M('5S97(@7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L
M9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30Q.0IM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED
M(")#;W5N=')Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR-S,*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P
M"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A
M=&4@82!L:6YK(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N
M=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E
M871O<B!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,C,P"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,C8*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C0X"FUS9VED(")#=7)R
M96YT(%-E<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,S"FUS9VED(")#=7)R
M96YT(%5S97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<U"FUS9VED(")#=7)R96YT(&-O
M;F1I=&EO;CH@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G
M;VX@=&\@)7,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@R"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL
M:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#0*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI
M8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#4Q('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$
M1"(*;7-G<W1R(")$1"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M.#$*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N
M=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E
M+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`BM-W5TMW>(@H*(SH@861M
M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-SD*;7-G
M:60@(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S.3D*(RP@9G5Z>GD*;7-G:60@(D1A=&4B"FUS9W-T<B`B
MN-?1X-CHV"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC
M.C$S"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#<*;7-G:60@(D1A=&4@<V5L96-T:6]N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.3(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,R,@HC+"!F=7IZ>0IM
M<V=I9"`B1&%Y(@IM<V=S='(@(K3=U=+=WB(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@HC+"!F=7IZ>0IM
M<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`BN-?1X-CHV"(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$
M96-E;6)E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED(")$96-I;6%L(&YU
M;6)E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI
M8B]P<F5F<RYP:'`Z,3$W"B,L(&9U>GIY"FUS9VED(")$969A=6QT(@IM<V=S
M='(@(KC7T>#8Z-@B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHW-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!#;VQO<B(*
M;7-G<W1R("*ZWN#8X>+8(.'BT-W4T.#4W=`@TN#5U-W>X>(B"@HC.B!F<F%M
M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.CDQ"FUS9VED(")$969A=6QT
M($ED96YT:71Y(@IM<V=S='(@(L'BT-W4T.#4U=T@V-35W>+8XM7B(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")$969A
M=6QT(%-H96QL(@IM<V=S='(@(L'BT-W4T.#4U=T@V-35W>+8XM7B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z-#(R(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHW,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3@R"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]D96QE=&4N:6YC.C$P('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`BN-?1X-CHV"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M,@HC+"!F=7IZ>0IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`BN-?1X-CH
MV"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP:'`Z
M,C(W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`BN-?1
MX-CHV"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0HC+"!F
M=7IZ>0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R("*XU]'@V.C8(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&-E;&PB"FUS
M9W-T<B`BN-?1X-CHV"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C,*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!C
M;VQU;6XB"FUS9W-T<B`BN-?1X-CHV"(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L
M871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N
M<R!F;W(@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P
M97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS
M/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@<F]W
M(@IM<V=S='(@(KC7T>#8Z-@B"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E
M:61E;G1I='DN:6YC.C$U"B,L(&9U>GIY"FUS9VED(")$96QE=&4@<V5L96-T
M960@:61E;G1I='DB"FUS9W-T<B`BP>+0W=30X-35W2#8U-7=XMCBU>(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L('!H
M<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"B,L(&9U>GIY"FUS
M9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(KC7T>#8Z-@B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Y"FUS9VED(")$96YM87)K(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O
M8FQE;2(*;7-G<W1R("*^W]CA(-W0(-_@WM';U=S>XB(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.CDS."!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,P"B,L(&9U>GIY"FUS9VED(")$97-C<FEP
M=&EO;B(*;7-G<W1R("*ZWMS?V]7BU=T@WM_8X3HB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$Y-0IM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(
M;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$Y.0IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G
M9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q.0IM<V=I9"`B1&5V96QO<&UE;G0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3<*;7-G:60@
M(D1E=R!0;VEN="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(Y-`IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(W"FUS9VED
M(")$97<@<&]I;G0Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F
M="!T;R!R:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@
M=&\@;&5F="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-C8*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"B,L(&9U
M>GIY"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`BM]#GX]+0^"#>
MW^;8V"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY-@IM<V=I
M9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C@U"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T
M("A4048I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,3<*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O341.+G!H<#HQ.3`*;7-G:60@(D1I<W!O<VET
M:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED
M(")$:FEB;W5T:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C0R,@HC+"!F=7IZ>0IM<V=I9"`B1&\@;F]T(&1E;&5T92(*
M;7-G<W1R("*XU]'@V.C8(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E
M+G!H<"(*;7-G<W1R("*]U2#?X-CAXM#?X]+0^"#4V.#5VN+=WB#4WB!M86EN
M=&5N86YC92YP:'`B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ
M,B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T
M:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L
M(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED
M(")$;VUI;FEC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$;VUI
M;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3
M:6=N('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX-#0*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T
M960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`W"FUS9VED(")$<F]P(&1O
M=VX@;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B12U-86EL(@IM
M<V=S='(@(K_>Z.+0(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R
M:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R
M:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P('1E;7!L871E<R]P;W)T86PO
M961I="YI;F,Z,C4*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G
M:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C$P,`IM<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O
M<B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU
M"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%:71H97(@96YA8FQE(&ET('1H96XZ("5S+"!O<B!U<V4@
M=&AE(&)A<VEC($A434P@=F5R<VEO;CH@)7,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S
M"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD*;7-G:60@(D5M
M86EL(@IM<V=S='(@(M4MW][HXM`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4V-2!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C@*
M(RP@9G5Z>GD*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`BLM#HT"!%
M;6%I;"#0U.#5X=`Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV
M,PHC+"!F=7IZ>0IM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N
M(@IM<V=S='(@(KO>U]C=VMCBU2#<WN#0(-30(-'8U-#B(-CAXM@N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX.0IM<V=I9"`B16UA:6P@=VET
M:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--
M4R!'871E=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR.3@*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#(*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S
M='(@(K_@T-?5W2#@U=?CV^+0XBXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U;'0N
M(@IM<V=S='(@(K_@T-?5W2#@U=?CV^+0XBXB"@HC.B!F<F%M97=O<FLO4U%,
M+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R
M;7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T,PIM
M<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'
M86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4Q.`IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E
M>'0@;65N=3\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C4Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$Q"FUS9VED(")%
M;F0@>65A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q"FUS9VED("(B
M"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E
M(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L
M(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C@Y,0IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I
M;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4U
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S8@<V5R=FEC97,O<&]R=&%L+VEN
M9&5X+G!H<#HX,@IM<V=I9"`B17)R;W(B"FUS9W-T<B`BL^#5Z-K0(@H*(SH@
M9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E
M+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C
M;VYT96YT.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D871I
M;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@
M=VET:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O;FEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H
M;FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS,SD*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.0HC+"!F=7IZ>0IM
M<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(L'5VM[5(-_@V/C0TN/2
MT/K5(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Y,`HC+"!F=7IZ>0IM<V=I9"`B179E<GD@-2!M:6YU
M=&5S(@IM<V=S='(@(L'5VM[5(-_@V/C0TN/2T/K5(@H*(SH@9G)A;65W;W)K
M+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@
M3&]G:6XB"FUS9W-T<B`BP=7:WM4@W^#8^-#2X]+0^M4B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S0P"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-R!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S@X"B,L(&9U>GIY"FUS9VED(")%=F5R>2!M:6YU
M=&4B"FUS9W-T<B`BP=7:WM4@W^#8^-#2X]+0^M4B"@HC.B!T96UP;&%T97,O
M9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM
M<V=S='(@(K_@V-S5X#HB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z.#$@861M
M:6XO8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C<*;7-G
M:60@(D5X96-U=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z-#<U"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,@IM<V=I9"`B17AP
M86YD(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO
M2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G
M:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$R"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S8*;7-G:60@(D5X<&]N
M96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G:60@(D944"!U
M<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+W-Q;"YP:'`Z,C$V"B,L(&9U>GIY"FUS9VED(")&86EL960@<F5T
M<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`BO=4@W-[6U=(@U-`@T]@@
MV-?<U=W0W"#?WM35X>/2T/K0XM`N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*
M;7-G<W1R("*]U>/AW]7HW=`@VM[=U=KFV/C0(.'>($Q$05`@X=7@TM7@WN(N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.CDX"B,L(&9U>GIY
M"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G
M<W1R("*]U>/AW]7HW=`@VM[=U=KFV/C0(.'>($Q$05`@X=7@TM7@WN(N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-CDQ"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N
M(@IM<V=S='(@(KW5X^'?U>C=T"#:WMW5VN;8^-`@X=X@3$1!4"#AU>#2U>#>
MXBXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"B,L(&9U
M>GIY"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I
M;VXN(@IM<V=S='(@(DQ$05`@VM[=U=KFV/C0XM`@U-X@)7,@U2#=U>/AW]7H
MW=`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3<@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HW,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`BO=7C
MX=_5Z-W0(-K>W=7:YMCXT"#AWB!,1$%0(.'5X-+5X-[B+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD
M<R`H36%L=FEN87,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A
M<F]E($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN
M<&AP.C(S.`HC+"!F=7IZ>0IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@
M(K/@U>C:T"#?X-@@V-S?WN#B.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R("+$T-KA
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T.0HC+"!F=7IZ>0IM
M<V=I9"`B1F%X97,B"FUS9W-T<B`BQ-#:X2(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,`IM<V=I9"`B1F5E
M;',@3&EK92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,Q"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@
M(D9E=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0*
M;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,S,T"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X"FUS9VED
M(")&:6=L970@9F]N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&
M:6II(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(U-0HC+"!F=7IZ>0IM<V=I9"`B1FEL92(*;7-G<W1R("*]T.';WM(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I
M;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,#<*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8S
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-0HC+"!F=7IZ>0IM
M<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(KC<U2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Y.34*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.#8*;7-G:60@
M(D9I;&4@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R
M+T)R;W=S97(N<&AP.C@U.0IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P
M;W)T960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HX.0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS
M9VED(")&:6YL86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B
M1FER<W0@475A<G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4V"FUS9VED(")&:7@@<F%T:6\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(S,0IM<V=I9"`B1FQI<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&
M;&]A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O
M97,@;F]T(&5X:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")&
M;V]D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S
M('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,S0*;7-G:60@(D9O<F5C87-T("A4048I(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW.0IM
M<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE
M9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L
M87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K
M*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P
M,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C(*;7-G:60@(D9O<FUS(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B
M1F]R='5N92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(D9O<G1U;F5S(@IM
M<V=S='(@(K?0T=7;U>C:V"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#4S"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P.0IM<V=I9"`B1F]R=V%R
M9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PHC+"!F
M=7IZ>0IM<V=I9"`B1G)A;65S(@IM<V=S='(@(KC<U2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*
M;7-G:60@(D9R86YC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE
M<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C`*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C0P-@IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"B,L(&9U>GIY
M"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(KK>W-_;U>+5W2#>
MW]CA.B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R
M("*RT.C5(-C<U3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F
M<F]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B
M1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B
M1V5O<F=I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M86YY
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B
M1VEV96X@3F%M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O87!P
M+FEN8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,C@*;7-G:60@
M(D=O;V=L92!-87!S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-PIM<V=I
M9"`B1W)A>7-C86QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'
M<F5E8V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*
M;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM
M<V=I9"`B1W)E;F%D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C$W.0HC+"!F=7IZ>0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS
M9W-T<B`BL-3<V-W8X>+@T.;8^-`B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*
M;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G
M<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G
M:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S
M."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O
M=7`@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W
M"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,`HC
M+"!F=7IZ>0IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(K#4X-7AT.`B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<X"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.CDV,`IM<V=I9"`B2%1-3"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U
M"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B
M2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@
M8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@
M:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:'1T<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDQ.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,R"FUS9VED(")(96%D97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T
M+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U
M.2TX+4DI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3<Y(&9R
M86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@<V5R=FEC97,O
M:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*
M;7-G:60@(DAE;'`B"FUS9W-T<B`BO][<WN@B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG
M(&5D:71O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,S<Q"B,L(&9U>GIY"FUS9VED(")(96QP97(B"FUS9W-T<B`BO][<WN@B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@
M=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@
M=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DAI
M9V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV
M('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"B,L(&9U>GIY
M"FUS9VED(")(;U]M92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*
M;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34S-0HC+"!F=7IZ
M>0IM<V=I9"`B2&]M92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R
M97-S(@IM<V=S='(@(K3>W-#HW=`@T-3@U>'0.B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HV-`IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y
M,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R("*TWMS0Z-7=(.+5V]7DWMTB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-0IM<V=I9"`B2&]R9&4B"FUS9W-T
M<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0T,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!8
M34P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S
M('1O(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-3`*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C
M97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B)R5S)R#CX=_5
MZ-W>(-[BX>+@T-W5XB#>U"#AV.'BU=S>XBXB"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E
M9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E
M;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0W"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E
M("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HT-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O
M9B!T>7!E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,V"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI
M<V4@<VAA<F5S.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R
M:7IO;G1A;"!2=6QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D
M9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E
M(')E<&]R="$I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O
M;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N
M>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G
M93\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,P,"!L:6(O0FQO8VLO;65T87(N<&AP.C(S,`IM<V=I9"`B2'5M:61I='DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U
M.0IM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!
M4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q-@HC+"!F
M=7IZ>0IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("*PU.#5X=`B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!
M9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@
M;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM<V=I9"`B26-O;G,@3VYL>2(*;7-G
M<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-S<*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DP"FUS9VED
M("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@HC+"!P:'`M9F]R;6%T"FUS9VED
M("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E
M;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT-34*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@
M86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE
M960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS
M<&%R96YC>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$W,PIM<V=I9"`B(@HB268@>6]U('-E92!T:&ES
M(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@
M=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,0IM<V=I9"`B26UA
M9V4@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHW
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(KC<W][@XMC@T-W>(-_>V]4Z("5S
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(KC<W][@
MXMC@T-W>(-_>V]4Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R("*XW-_>X.+8
MX-#=V"#?WMO8^M`Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!9G1E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M>FEP+G!H<#HQ,S4*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E
M;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S(*(RP@9G5Z>GD*;7-G:60@(DEN8V]R<F5C="!U
M<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(K+5(-S>V]C<U2#=
MT-+5U-7BU2#2T.C5(-K>X-CAW=CGVMX@V-S5(-@@V][7V-W:T"(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E
M8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O
M<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F
M=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DEN9&EA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C4T('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L
M(%5S97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE
M<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U-PIM<V=I9"`B26YF;W)M871I;VXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,S
M,`IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!);6%G92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B
M26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS
M97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B
M26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E
M9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED
M("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E
M('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN
M<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R
M92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E;7!L871E
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,SD*;7-G
M:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@
M<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS
M9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y"FUS9VED
M("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B
M26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED("))
M;G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE
M<W-A9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G
M<F%P:"!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P
M87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R
M="!R;W<@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O
M=R!B969O<F4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(S,`IM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE
M('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O
M36]D:69Y($EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@
M3&EN:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I96YT(&-R961I
M="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-S4*;7-G:60@(DEN=&5G
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$S
M,PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B
M26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3<P"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(P,0HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,3`*;7-G:60@
M(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@W(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q-3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(S,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,CDY"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN
M=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B
M26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HX,0HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#`*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,C(P"FUS9VED("));G9A
M;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-S<*;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-S$*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.38*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*
M;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S,*;7-G:60@(DEN
M=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$W-0IM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O
M9&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB
M)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$P-S8@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C8R"FUS9VED("))
M;G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN
M=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B
M26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-3<*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C<Y"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA
M;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C4*;7-G:60@(DES
M<W5E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#(*(RP@9G5Z>GD*;7-G:60@(DET86QY(@IM<V=S='(@(K3=U=+=
MWB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,SD*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I
M9"`B2F%N=6%R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIA
M<&%N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS
M9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"FUS9VED("(B"B)*879A<V-R
M:7!T(&AA<R!B965N(&1I<V%B;&5D(&]N('EO=7(@8G)O=W-E<B!A;F0@=&AI
M<R!P86=E(&UA>2!N;W0@8F4@(@HB9&ES<&QA>6EN9R!C;W)R96-T;'DN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(R"FUS
M9VED(")*97)S97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*
M;W)D86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU
M;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I
M9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED(")*=7-T
M:69Y(%)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V%Z
M86MH<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C8T"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DME;GEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME
M<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N
M96P@3F5W8FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@
M(DME>2!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS
M9VED(")+97D@5'EP92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4Y.`HC+"!F=7IZ>0IM<V=I9"`B2V5Y(%5S86=E
M(@IM<V=S='(@(K_>X-#:T"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*
M;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X
M"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@V"FUS9VED(")+=7=A:70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS
M9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG=6%G92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$
M96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-S8*;7-G:60@(DQA<W0@4&%S<W=O<F0@
M0VAA;F=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U,0IM<V=I9"`B3&%S
M="!5<&1A=&5D.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S(Q"B,L
M('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$V"FUS9VED
M("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*
M;7-G:60@(DQA='9I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#0*;7-G:60@(DQA=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*(RP@9G5Z>GD*
M;7-G:60@(DQA>6]U="(*;7-G<W1R("*XU]O5UR(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M
M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS
M9VED("),96)A;F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$Y"FUS9VED
M("),969T(&AE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3$U"B,L(&9U>GIY"FUS9VED("),969T('9A;'5E<R(*;7-G
M<W1R("*_X-C<U>`Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM
M<V=I9"`B3&5V96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),
M:6)E<FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N
M($%R86(@2F%M86AI<FEY82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G
M:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT($1R:7IZ
M;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T
M<B`BN][3V.#0^M4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM
M<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!2
M86EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H
M=6YD97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G
M:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-`HC+"!F=7IZ>0IM<V=I
M9"`B3&EN:R(*;7-G<W1R("*[WM/8X-#ZU2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN
M:R!P;VEN=',@=&\Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X-S4*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@
M=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP
M.C$X,PIM<V=I9"`B3&EN:W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G
M:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS9VED("),:7-T($1A=&%B
M87-E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU
M,`IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R("*XU]O8X>+0^"#B
MU=S8(-?0(-_>W-[H(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM<V=I
M9"`B3&ES="!486)L97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12](96%D97)S+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4X
M.0HC+"!F=7IZ>0IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(KC7V]CAXM#X
M(.+5W-@@U]`@W][<WN@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E
M<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/
M=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E
M<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS9VED("),:7-T
M+5-U8G-C<FEB92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*
M;7-G<W1R("*[V.'BT/K5XMX@W=`@VM[@V.'=V.;8(-4@WMW5TM[7W-[6U=W>
M+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(@IM<V=S='(@
M(KO8X>+0^M7BWB#=T"#:WN#8X=W8YM@@U2#>W=72WM?<WM;5W=XN(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T
M:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("*[V.'BT/K5XMX@W=`@
MVM[@V.'=V.;8(-4@WMW5TM[7W-[6U=W>+B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C@S"FUS9VED("),
M;V%D:6YG+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,3$*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO8V%L92!A;F0@
M5&EM92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4W,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C0*(SH@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z
M-C4*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&QO9VEN+G!H<#HQ
M-S(@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y,2!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO
M9R!I;B(*;7-G<W1R("*[WM/8X-#ZU2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S
M<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP
M:'`Z,3@U"FUS9VED("),;V<@;W5T(@IM<V=S='(@(KC7V]77(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"B,L(&9U>GIY"FUS9VED("),;V=I;B(*
M;7-G<W1R("*[WM/8X-#ZU2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,#<*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.CDY-@IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U
M<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O
M<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z.3DR"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C4*(RP@9G5Z>GD*;7-G:60@(DQO
M;F<@=&5X="(*;7-G<W1R("*XU]O5UR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B3&]W(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,S@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM
M<V=S='(@(DU-(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,0IM
M<V=I9"`B34]41"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT
M(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED
M(")-86-A;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D
M;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"B,L(&9U>GIY"FUS9VED
M(")-86=I8R(*;7-G<W1R("*_WNCBT"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HX,0IM<V=I9"`B36%I;"(*;7-G<W1R("*_WNCBT"(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C(*;7-G:60@(DUA:6P@061M:6XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%L87=I(@IM
M<V=S='(@(K_>Z.+0(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-86QA>7-I82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B36%L:2(*;7-G
M<W1R("*_WNCBT"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%L
M=&$B"FUS9W-T<B`BO][HXM`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3$*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO
M=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S
M;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,34S"FUS
M9VED(")-87`R-"!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#0*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-C@*;7-G:60@(DUA<%%U97-T(&UA
M<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ
M,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,PHC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA
M<F-H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#$*(RP@9G5Z>GD*;7-G:60@(DUA<F=I;B(*
M;7-G<W1R("*RW=C<T-W8U2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E96X@
M9FQA9W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H
M92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I
M96QD<R(*;7-G<W1R("*ZWN#5X=_>W=38X-#GVM@@W][;V/K0(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B
M36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA
M>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,P-@IM<V=I9"`B36%X('1E;7`@;&%S="`R-"!H
M;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDX
M"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R
M=&%L($)L;V-K<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-87AI;75M(&QE;F=T
M:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3<*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB
M97)S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S@*
M;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R
M9V4@8V5L;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS
M9W-T<B`BO][@T-K0(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U
M;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E
M("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@
M(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`BO][@T-K0(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(V,`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(K_>
MX-#:T"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@
M5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W
M"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q,@IM<V=I9"`B(@HB365T87(@
M8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B365T87)$0B!I<R!N
M;W0@8V]N;F5C=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O
M4E!#+W-O87`N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@
M7"(E<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(DUE
M=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<T(&QI8B]";&]C
M:R]M971A<BYP:'`Z-S4*;7-G:60@(DUE=')I8R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S8*(RP@9G5Z>GD*;7-G:60@(DUI9&1L92(*;7-G<W1R("*_
MWNCBT"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP
M.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,3`*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I
M9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM=6T@
M<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-`HC
M+"!F=7IZ>0IM<V=I9"`B36ER<F]R(@IM<V=S='(@(K/@U>C:T"(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A4
M5%!?4F5Q=65S="XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$Q-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@
M:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H
M:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES
M<VEN9R!M97-S86=E($E$+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES
M<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*;7-G
M:60@(DUO(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HW-`IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DUO9&5R
M871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@X
M"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I
M9"`B36]D:69Y(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8W,PIM<V=I9"`B36]D=6QU<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-`IM<V=I9"`B36]N=&@@
M86YD('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R("*\
MU>'5Y]W>(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3<R(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C(U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD
M<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*
M;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L
M;W5D>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P.0IM<V=I
M9"`B36]V92!$;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C4Q,PIM<V=I9"`B36]V92!,969T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4Q-PIM
M<V=I9"`B36]V92!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#4*;7-G:60@(DUO=F4@57`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C4R-`IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C,*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V92!U
M<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-`IM
M<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#4U
M"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,@IM<V=I9"`B375L=&EP;&4@<V5L96-T
M:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,#`*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C(X"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T:6]N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-30*
M;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO961I="YP:'`Z,3,V"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU
M-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").86UE(@IM<V=S='(@
M(KC<U2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW
M"FUS9VED(").971H97)L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM
M<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C
M87!E($)A<V4@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!#02!2979O8V%T
M:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X-`IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@
M(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P
M92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(&-E<G1I
M9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.#`*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC
M871E('1Y<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(U,0IM<V=I9"`B3F5T=V]R:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,S-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS9VED(").
M979E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE
M9&]N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL
M<RYP:'`Z.#$*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I
M;',N<&AP.C@W"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA
M:6QS+G!H<#HY-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M
M86EL<RYP:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E
M('1O("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM
M<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I
M;VYA;"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(").97<@6F5A
M;&%N9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R("*[
MWM?8W=K0(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C(R-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@
M;VX@)7@N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HU,@HC+"!F=7IZ>0IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M
M871C:"XB"FUS9W-T<B`BN][7V-W:V.+5(-S>X-`@U-`@T=C4T.(@V.'BV"XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ
M"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y"B,L(&9U>GIY"FUS
M9VED(").97=S(@IM<V=S='(@(K?0T=7;U>C:V"(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS,#4*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA=&5S
M+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G:60@
M(DYE>'0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS
M9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,S<R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,S<V"B,L(&9U>GIY"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T
M<B`BO=#7T-0@VM[=(-[?YMC8XM4B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G
M97(N<&AP.C$P,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV
M"FUS9VED(").:6=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@
M(DYI9V5R:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,X,`IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDW"FUS9VED(").:75E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(DYO(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I
M9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I
M9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,#4*;7-G:60@(DYO(&%V86EL86)L
M92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<Y(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(T-0HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-C<*;7-G:60@(DYO(&)L;V-K(&5X:7-T
M<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@
M(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(KW5W-`@V-WDWN#<T.;8V"#7T"#?WM35X>/2T/K5
M(-W0(%-13"#8U-7=XMCBU>+8XM4N(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z-30*(RP@9G5Z>GD*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`BON+:
MT-;8(-/8(-_@WMS5W=CBU2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@
M=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$V-R!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P
M,@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-S,*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`BO=7<T"#8W>3>X-S0YMC8(-?0
M(-_>U-7AX]+0^M4@W=`@4U%,(-K0XM73WN#8V.+5+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#(T"B,L(&9U>GIY"FUS9VED(").;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RXB
M"FUS9W-T<B`BO=7<T"#8W>3>X-S0YMC8(-?0(-_>U-7AX]+0^M4@W=`@3$1!
M4"#<WM;=WN'BV.+5+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M-C8Y"B,L(&9U>GIY"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`BO=7<T"#8W>3>
MX-S0YMC8(-?0(-_>U-7AX]+0^M4@W=`@4U%,(-K0XM73WN#8V.+5+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,3<*(RP@9G5Z>GD*
M;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(KW5W-`@V-WDWN#<T.;8V"#7
MT"#?WM35X>/2T/K5(-W0(%-13"#:T.+5T][@V-CBU2XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@
M(DYO(&-R961I="!L969T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S
M=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M<F]W<V5R+T)R;W=S97(N<&AP.C@W-PIM<V=I9"`B3F\@9FEL92!U<&QO861E
M9"(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G
M:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3(X(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT
M,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R,PIM<V=I9"`B3F\@;&]C871I
M;VX@:7,@<V5T+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,38Y"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,V"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S<*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS
M:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H
M<#HW-R!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`BO=7<T"#8W>3>X-S0YMC8(-?0(-_>U-7AX]+0^M4@W=`@4U%,
M(-C4U=WBV.+5XMCBU2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A<W-W
M9"YP:'`Z,3,U"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("*]U=S0(-C=
MY-[@W-#FV-@@U]`@W][4U>'CTM#ZU2#=T"!344P@V-35W>+8XM7BV.+5+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`HC+"!F=7IZ>0IM
M<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`BO=7<T"#8W>3>X-S0YMC8(-?0(-_>U-7AX]+0^M4@
MW=`@4U%,(-C4U=WBV.+5XMCBU2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C$R.#8*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P
M96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@
M;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*
M;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C<U,`HC+"!P:'`M9F]R;6%T"FUS9VED(").
M;R!Q=6]T82!S970N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*(RP@9G5Z>GD*;7-G:60@
M(DYO(')U;&5S(@IM<V=S='(@(K?0T=7;U>C:V"(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C0T.0IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I
M9FEE9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`HC+"!F=7IZ>0IM<V=I9"`B3F\@<VED
M97,B"FUS9W-T<B`BM]#1U=O5Z-K8(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HU.#,*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3,X"FUS9VED(").;R!T
M96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,C(Q"B,L(&9U>GIY"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S
M<W=O<F0@<V5N="XB"FUS9W-T<B`BLM4@W-[;V-S5(-W0TM74U>+5(-+0Z-4@
MVM[@V.'=V.?:WB#8W-4@V"#;WM?8W=K0(@H*(SH@9G)A;65W;W)K+U)00R]2
M4$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E
M='5R;F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HY-S$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDX,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.3DR"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,#`Y"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO
M;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*
M(RP@9G5Z>GD*;7-G:60@(DYO;F4B"FUS9W-T<B`BPM7;U>3>W2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@
M(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C
M:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@
M27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8T,`IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(").;W0@0F5F
M;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C0P.`IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2YP:'`Z.#,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.30*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT
M.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(DYO="!S970B"FUS9W-T<B`BM]#1
MU=O5Z-K8(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(
M86YD;&5R+G!H<#HQ-#,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E
M<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD
M;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S,*(SH@9G)A;65W;W)K+U-E<W-I
M;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#<*(SH@9G)A;65W;W)K
M+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S0@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,C`U(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C(T."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8U"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(Y-PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$R(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HS,CD*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V,B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(R"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HU,#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W,`HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z-3@W(&9R86UE=V]R:R]61E,O5D93+G!H<#HV-C4*
M;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG+VAO;VMS
M+G!H<"YD:7-T.C$P,#4*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$W
M.`IM<V=I9"`B3F]T97,B"FUS9W-T<B`BM]#1U=O5Z-K8(@H*(SH@<V5R=FEC
M97,O;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R
M;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-#8*(RP@9G5Z
M>GD*;7-G:60@(DYU;6)E<B(*;7-G<W1R("*XW-4B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#(U"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C,*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30T-2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T-#,@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS
M9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I
M<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX
M-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$P-`IM<V=I9"`B
M3V-T86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E
M<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(V
M"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S=V]R9',@
M;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HS-@HC+"!F=7IZ>0IM<V=I9"`B3VQD('!A<W-W
M;W)D(@IM<V=S='(@(KO>U]C=VM`B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C
M="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F
M;VQD97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3$@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DW,0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S
M<R!A;&QO=V5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A
M9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*
M(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C,U"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O
M=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A
M8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I
M9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,34Q"B,L(&9U>GIY"FUS9VED(")/<'1I;VYS
M(@IM<V=S='(@(K?0Y^/2T/@@WM_FV-@B"@HC.B!S97)V:6-E<R]P<F5F<RYP
M:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D
M97)E9"!,:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-38W"B,L(&9U>GIY"FUS9VED(")/<F=A;FES871I;VXB
M"FUS9W-T<B`BL-3<V-W8X>+@T.;8^-`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI
M="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,R
M"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP
M;&%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q"FUS9VED(")/
M=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-SD*;7-G
M:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P
M+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<S"FUS9VED
M(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,Q.0IM<V=I9"`B4$=0($5N8W)Y
M<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$S-S$*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-3,*;7-G
M:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<&AP<VAE;&PN<&AP.C8X"B,L(&9U>GIY"FUS9VED(")02%`@0V]D
M92(*;7-G<W1R(")(;W)D92(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM
M<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,:6=H="!286EN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,X"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")0
M32!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#$*;7-G:60@(E!-(%-U;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@5"U3=&]R;7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W-`IM<V=I
M9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@
M;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY
M"FUS9VED(")086MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS
M9VED(")086QA=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0
M86QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R
M=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#$X"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS9VED(")087-S=V]R9"(*;7-G<W1R
M("*[WM?8W=K0(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R
M"FUS9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(R
M"B,L(&9U>GIY"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B
MN][7V-W:T"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ
M-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P-3,*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`HC
M+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(KO>U]C=VM`B"@HC
M.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I
M9"`B4&%S<W=O<F0Z("(*;7-G<W1R("*[WM?8W=K0(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S0*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O
M<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(KO>U]C=VMCBU2#<WN#0(-30(-'8
MU-#B(-CAXM@N(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q.2!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G
M:60@(E!A<W1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O
M87)D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG
M;G5P<SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T
M"B,L(&9U>GIY"FUS9VED(")096]P;&4B"FUS9W-T<B`BP]O>T]`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I
M9"`B4&5R8V5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N
M86YC92!/<&5R871I;VYS(@IM<V=S='(@(KC7TN#HV"#>W]7@T.;8V"#7T"#>
MU.#6X]+0^M4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`V"B,L(&9U
M>GIY"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@
M;&]G:6X_(@IM<V=S='(@(KC7TN#HV"#>W]7@T.;8V"#7T"#>U.#6X]+0^M4B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B
M4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB
M(&YO="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C4X-@IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C$@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@(E!E<FUI<W-I
M;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R;7,O:6YD
M97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*(RP@9G5Z>GD*
M;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(K#4
MW-C=V.'BX-#FV/C0(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U"FUS
M9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO
M;F4B"FUS9W-T<B`BPM7;U>3>W2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT-S@*;7-G:60@(E!H;W1O<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I
M9"`B4&QA=&ET=61E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@
M8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED
M(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES
M(&5L96UE;G0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O
M;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3<Q"FUS
M9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C
M871E9V]R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3,P,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V
M,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE
M(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,0IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S
M=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R("*RU2#<WMO8W-4@W=#2
MU=35XM4@T]X@W^#>T=O5W-[B+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B
M4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS
M9W-T<B`BLM4@W-[;V-S5(-W0TM74U>+5(-+0Z-4@VM[@V.'=V.?:WB#8W-4@
MV"#;WM?8W=K0(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS
M9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-
M55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C
M871E9V]R>2!N86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@
M(E!O;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT.#<*;7-G:60@(E!O;&QS(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y
M($E-05`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8V
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3@*;7-G:60@
M(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L
M9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS
M,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(R-0IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G:60@(E!R97-S=7)E(&%T('-E82!L
M979E;#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,S4*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P-0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED
M(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C(@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8*(RP@9G5Z>GD*;7-G:60@(E!R
M979I;W5S(&]P=&EO;G,B"FUS9W-T<B`BO=#7T-0@VM[=(-[?YMC8XM4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q"FUS
M9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ
M-CD*(RP@9G5Z>GD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B6[C7TM7HXM#X
M(-?0(-_@WM';U=S>XETB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C8*
M;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`BOM_8X2#=T"#?
MX-[1V]7<WN(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S8Y"FUS
M9VED(")0<F]J96-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#@*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X-0IM<V=I9"`B4')O;7!T('1E
M>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@
M2V5Y($%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8T-`IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C(T
M,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D
M('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I
M9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I
M9"`B46%T87(B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8S
M"FUS9VED(")1=65R>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8S"B,L('!H<"UF;W)M870*;7-G
M:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0*;7-G:60@(E)A9&EO('-E;&5C
M=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,PIM<V=I9"`B4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I
M;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS
M9VED(")286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I9"`B4F%I;B!A;F0@4VYO
M=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"B,L
M(&9U>GIY"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@(K_>X-#:T"(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO
M;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M96%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D
M;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#8*;7-G
M:60@(E)E9G)E<V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Y,0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$*;7-G
M:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C$S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S4*(RP@9G5Z
M>GD*;7-G:60@(E)E9V5X(@IM<V=S='(@(E)E<V5T(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S(T.0IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S
M97(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM<V=I9"`B4F5L
M;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V"FUS
M9VED(")296UA<FMS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,30*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E
M(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I
M9"`B4F5M;W9E(@IM<V=S='(@(K[4X>+@T-W8(-_0X"(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E
M($)L;V-K(@IM<V=S='(@(K[4X>+@T-W8(-_0X"(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HU-3<*;7-G:60@(E)E;6]V92!C
M;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHT,`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&9O<FUA
M='1I;F<B"FUS9W-T<B`BOM3AXN#0W=@@W]#@(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@
M(K[4X>+@T-W8(-_0X"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*
M;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP
M;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*(RP@9G5Z>GD*
M;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`BOM3AXN#0W=@@W]#@(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4P"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI
M;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(K[4
MX>+@T-W8(-_0X"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI
M;F,Z-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z
M("5S(@IM<V=S='(@(K[4X>+@T-W8(-_0X"(*"B,Z(&9R86UE=V]R:R]24$,O
M4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E
M(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"FUS9VED(")297%U
M97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<T(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z-3$R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("*QT.#0W=C>XB`G=6ED)R#=U2#5(-W0TM74U=T@
MTMX@W][4U>'CTM#ZT.+0+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z-C<U(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,P"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C,*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN
M(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("*QT.#0W=C>XB`G=6ED)R#=
MU2#5(-W0TM74U=T@TMX@W][4U>'CTM#ZT.+0+B(*"B,Z(&9R86UE=V]R:R]5
M=&EL+U5T:6PN<&AP.C<X,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`BL=#@T-W8WN(@)W5I9"<@W=4@U2#=T-+5U-7=(-+>(-_>
MU-7AX]+0^M#BT"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R
M+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S
M.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C`@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R(")2
M97-E="(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"B,L(&9U
M>GIY"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R("*[WM?8W=K0(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*(RP@9G5Z>GD*;7-G
M:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`BO][BTN#4V"#;WM?8
MW=K0(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,`IM<V=I9"`B4F5S=&]R
M92!,87-T(%%U97)Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H
M<#HW,2!A9&UI;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP
M.C8V"B,L(&9U>GIY"FUS9VED(")297-U;'1S(@IM<V=S='(@(E)E<V5T(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O
M<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G
M<W1R("*]T-?0U"#:WMT@WM_FV-CBU2(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,@HC+"!F=7IZ
M>0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(KW0
MU]#4(-K>W2#>W^;8V.+5(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X
M"FUS9VED(")2:61D;&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,0IM
M<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,3<*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(L/;WM/0(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(U"FUS9VED(")2;W1A=&4@,3@P
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,C(*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C@*;7-G
M:60@(E)O=&%T92!2:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@
M4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R
M=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M,PHC+"!F=7IZ>0IM<V=I9"`B4G5L97,B"FUS9W-T<B`BP]O>T]`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P
M"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N
M9"!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*
M;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*;7-G:60@(E)U
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E
M9&5R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A
M;F1A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q"FUS
M9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#0*(RP@
M9G5Z>GD*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`BO][@T-K0(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,PIM<V=I
M9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Q"FUS9VED(")34T@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*
M;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@4VAE
M;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC
M96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE
M(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I
M9"`B4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N
M($UA<FEN;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")386\@
M5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I
M82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E
M(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C(Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*
M;7-G<W1R("*WT.?CTM#X(-[?YMC8(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N
M9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(K?0Y^/2T/@@
MWM_FV-@B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B
M"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP
M="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L('!H<"UF
M;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")3
M8VEE;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS
M9VED(")396%R8V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,R,`IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW,PIM<V=I9"`B4V5L96-T
M($9I;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT.#0*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&1A
M=&4B"FUS9W-T<B`BN-?1U>#8(.3>X-S0XB#7T"#4T.+CW-[B.B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G
M<F]U<"!T;R!A9&0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B
M4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<W"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C,*(RP@9G5Z>GD*;7-G:60@(E-E
M;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R("*XU]'5X-@@Y-[@
MW-#B(-?0(-30XN/<WN(Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-C<X"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]K97EB;V%R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(B(*(E-E;&5C
M="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO
M=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T
M:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B*XU]'5X-@@VM[8(-K0X-#:XM7@
MV"#BV"#BX-71T-#B+B"\WM;5Z"#?WN+>T"#=V-(@U-`@T]@@V.':WM_8X-#H
M(-[4(-_>V]7BWB`B"B+7T"#BU=KAXBXB"@HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB
M"FUS9W-T<B`BN-?1U>#8(.'5W]#@T.+>X"#7T"#4T.+CW-[B.B(*"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A
M=&4@9F]R;6%T.B(*;7-G<W1R("*XU]'5X-@@Y-[@W-#B(-?0(-30XN/<WN(Z
M(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM
M<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G
M<W1R("*XU]'5X-@@X=7?T.#0XM[@(-?0(-30XN/<WN(Z(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F
M;W)M870Z(@IM<V=S='(@(KC7T=7@V"#DWN#<T.(@U]`@TN#5W-7BWCHB"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE8W0@
M='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`BN-?1U>#8(-32U2#>U-/>
MTM#@T.?:V"#?WMO8^M`N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P
M-@IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0X"FUS9VED(")396QE8W0@
M>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L
M96T@4F5P;W)T(@IM<V=S='(@(K_@T.+8(-C7TM7HXM#X(-?0(-_@WM';U=S>
MXB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#,Y"FUS9VED(")396YD(%--4R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V
M"FUS9VED(")396YE9V%L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S$V"FUS9VED(")396YS;W(Z("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P
M=&5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW
M,#$*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,0IM<V=I9"`B4V5R=F5R(&1A=&$@
M=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C(W"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R("(B
M"@HC.B!L:6(O87!I+G!H<#HQ-#4*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VYS
M(@IM<V=S='(@(K?0Y^/2T/@@WM_FV-@B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S$T"FUS9VED(")3970B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<V"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO
M=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G
M970@:70N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,34*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT
M('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0*;7-G:60@(E-E="!Y;W5R('!R969E
M<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX"FUS9VED("(B
M"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L
M('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N
M<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0IM
M<V=I9"`B4V5T=7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E
M='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T
M<R!A=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$X-@IM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB
M;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#DV"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PHC+"!F
M=7IZ>0IM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R("*ZX-#BVMX@X-77
MV-S5.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#8*;7-G:60@(E-H
M;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R,R!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E
M96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*
M(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT.3`*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@
M;&]G9VEN9R!I;C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3<V-0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA
M;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$S
M"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3(V"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@
M;65N=2!B87(_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O
M;B!T:&4@;&5F=#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H
M92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@
M4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3
M:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8S"FUS9VED(")3:&]W('5P
M;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU,`IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B
M4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R!,871E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4S"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT.#`*
M;7-G:60@(E-H<FEN:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HW-S0@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z.#,V"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.CDR,B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY.#0*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`T-R!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#@W"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q,38@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z,3$T.0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@
M;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M,C8U"FUS9VED(")3:6=N('5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW
M,3$*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@W(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$U(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(T-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,P"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*;7-G:60@(E-I>F4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT
M;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`BO^#5X=K>
MVMW8(-[4X-;CTM#ZU2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4T"FUS9VED(")3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W(%-H;W=E
M<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED
M(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N;W<@4VAO
M=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C<X"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W
M871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M
M;VX@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3
M;VUA;&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV
M,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.3(V"FUS9VED(")3;W)T(&]R9&5R('-E;&5C
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"B,L(&9U>GIY"FUS9VED(")3;W5R
M8V4@861D<F5S<R(*;7-G<W1R("*PU.#5X=`@W=`@X-#1WN+0(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H
M25-/+3@X-3DM,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3
M;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K
M+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O
M<F1E<B!I;B!C96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@Q-0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I
M9"`B4W!A8VEN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N
M9"!P861D:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")3<&%I
M;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3@*
M;7-G:60@(E-P86TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N
M<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R
M("*RW=7AX]+0^M4@W=`@X=_5YMCXT-O=V"#7W=#FV"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@
M(E-P;&ET(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L
M=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*(RP@9G5Z>GD*;7-G
M:60@(E-P;W)T<R(*;7-G<W1R("*XW-_>X.(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G
M:60@(E-R:2!,86YK82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-S,@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-`IM<V=I9"`B
M4W1A;F1A<F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C4Y-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#`Y"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")3=&%T92!O<B!0
M<F]V:6YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O
M:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*;7-G:60@(E-T;W)A9V4@9F]R
M;6%T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3<R"B,L(&9U>GIY"FUS9VED(")3=')E970@061D<F5S<R(*;7-G
M<W1R("*PU.#5X=`@W=`@X-#1WN+0(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,S"FUS
M9VED(")3=')I;F<@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@
M861D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?
M8G)O=W-E<BYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T
M;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE
M8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R
M(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PIM<V=I9"`B
M4W5B;6ET(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<
M(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U
M<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS
M9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$P-`HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S
M='(@(L/AW]7HW=XB"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T
M;R!T:&4@<WES=&5M+B(*;7-G<W1R("(G)7,G(./AW]7HW=X@U-[4T-35W2#=
MT"#AV.'BU=S>XBXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@
M9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B)R5S
M)R#CX=_5Z-W>(-[BX>+@T-W5XB#>U"#AV.'BU=S>XBXB"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB
M)7-<(BXB"FUS9W-T<B`B)R5S)R#CX=_5Z-W>(-3>U-#4U=T@W=`@X=CAXM7<
MWN(N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T
M:&4@<WES=&5M+B(*;7-G<W1R("(G)7,G(./AW]7HW=X@WN+AXN#0W=7B(-[4
M(.'8X>+5W-[B+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G
M:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO
M860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I
M9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P
M(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,38X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C
M97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B)R5S)R#CX=_5Z-W>
M(-3>U-#4U=T@W=`@X=CAXM7<WN(N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R
M("(G)7,G(./AW]7HW=X@U-[4T-35W2#=T"#AV.'BU=S>XBXB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"B,L(&9U>GIY
M"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(KK@T.+:WB#@U=?8W-4Z(@H*(SH@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U
M;B!3970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-U;FYY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(E-U;G)I<V4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$U"FUS
M9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(Q.0IM<V=I9"`B4W5N<V5T(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3@*;7-G:60@(E-U;G-E
M=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S@*(RP@9G5Z>GD*;7-G
M:60@(E-U<'!O<G0B"FUS9W-T<B`BN-S?WN#B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@HC
M+"!F=7IZ>0IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`BNM[@V.'=V.?:WB#8
MW-4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`HC
M+"!F=7IZ>0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R("*ZWN#8X=W8Y]K>(-C<
MU2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y
M96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*;7-G:60@
M(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$T,@IM<V=I9"`B4WEN8TU,(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X
M(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I
M9"`B5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED(")4+5-T
M;W)M<R!%87)L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A
M+W1S=BYP:'`Z,38V"B,L(&9U>GIY"FUS9VED(")44U8@9FEL92(*;7-G<W1R
M("*]T.';WM(B"@HC.B!F<F%M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S-`HC
M+"!F=7IZ>0IM<V=I9"`B5&%B;&4B"FUS9W-T<B`BO=#AV][2(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM
M<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS9VED(")486)L
M92!3970B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW
M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDY-B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3@W"FUS9VED(")487-K<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B
M5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(Y,`IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,30*;7-G:60@(E1E;7!E
M<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,C,*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G
M.R5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T
M92YP:'`Z-C@W"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<
M(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,38Y"B,L(&9U>GIY"FUS9VED(")496UP;&%T92!!9&UI;FES=')A=&EO
M;B(*;7-G<W1R("*PU-S8W=CAXN#0YMCXT"(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-@IM
M<V=I9"`B5&5X="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S<U"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I
M9"`B5&5X="!A;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DQ"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@(E1H86YK('EO=2!F
M;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HX,C`*;7-G:60@(E1H92!&5%`@97AT96YS:6]N
M(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(
M;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R
M="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-
M4U`O0F]O:RYP:'`Z,3(Y,@IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO
M="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S
M<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/
M<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X.2!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C(Q,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R,PHC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(V-"!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D
M;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E
M<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI
M<W-I;VYS+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I
M9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@
M240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A
M<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G
M:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U
M<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$Q-CD*;7-G:60@(B(*(E1H92!D971A8VAE9"!0
M1U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@
M<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@
M9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D
M+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@
M=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="YP:'`Z,3$S"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T
M=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-2!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38X(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(Q
M.0IM<V=I9"`B5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E
M;&8N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(X
M,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T
M:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@
M(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R
M;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W
M<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@
M(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C
M:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C
M<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S
M('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R
M;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@
M:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@
M<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDP"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E
M(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'
M(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP
M.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G92!S96YT
M(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES
M<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S
M<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S<*;7-G:60@(E1H92!N
M86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#$*
M;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HQ,C,Q"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@
M9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(Y,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T
M(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA
M>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T
M82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-30*;7-G
M:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H
M87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N
M9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE
M(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C0T-@IM<V=I9"`B5&AE('-E<&%R871O<B!M
M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S
M879E9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S
M(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z,S,P"FUS9VED(")4:&4@<W!E8VEF:65D(')O
M=R!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HQ-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E
M;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Q,0IM<V=I9"`B5&AE
M('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T
M:&4@<V-R965N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N
M9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4
M:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L
M;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A
M+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O
M=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C0V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HU-@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$U(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3D*;7-G:60@(E1H92!W96%T:&5R
M+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$W.`HC+"!F=7IZ
M>0IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G
M<W1R("*]U=S0(-3>X>+0W]W8(-_>U-7AX]+0^M`N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z,S0R"FUS9VED(")4:&5R92!A<F4@
M;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P,0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R
M<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E
M<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B
M(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I
M;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(KW0X>+0W=`@
MW^#>T=O5W"#?X-@@U-[4T-+0^M4@W=`@)7,@TMX@X=CAXM7<WN(N(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@
M7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(KW0X>+0W=`@W^#>
MT=O5W"#?X-@@WN+AXN#0W>/2T/K5(-W0("5S(-[4(.'8X>+5W-[B+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T
M:&4@<WES=&5M.B`B"FUS9W-T<B`BO=#AXM#=T"#?X-[1V]7<(-_@V"#>XN'B
MX-#=X]+0^M4@W=`@)7,@WM0@X=CAXM7<WN(N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,34Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`BO=#AXM#=
MT"#?X-[1V]7<(-_@V"#4WM30TM#ZU2#=T"`E<R#2WB#AV.'BU=S>XBXB"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B
M"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DQ"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG
M('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T
M82XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,`IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T
M:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@
M9FEE;&0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F
M=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T
M:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L
M871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@
M;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED(")4
M:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED('II<"!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,30U"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@
M8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC
M;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S-`IM<V=I
M9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A
M>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B
M"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*
M;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A
M=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@
M86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P
M.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.CDW."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#4W"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#8@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@R
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-38*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,P-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,SDX
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U-3<@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.34X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#4*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`R.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,#<X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-#D@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-#$P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-30*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C8U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.#(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,S<@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S,P-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS.#$T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,C(*;7-G:60@
M(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q.`IM<V=I9"`B5&AI<R!F:65L9"!M87D@
M;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y-`IM<V=I9"`B5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,PIM<V=I9"`B
M5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D
M(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.3@Y"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V
M86QI9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,S8*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN
M(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M
M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@
M8F5E;B!P<F]C97-S960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]H96QP
M+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#4Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U
M<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE
M960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO
M;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I
M;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA
M<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V"FUS9VED
M(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U
M"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@
M9WII<"!F:6QE<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+U)E9VES=')Y+G!H<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U
M<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S
M="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:6UA9V5S
M+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B
M92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I
M9"`B5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C,T"FUS9VED(")4:6-K971S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C@@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")4:6UE(@IM<V=S='(@(KW0X=O>
MTB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#8*;7-G:60@(E1I
M;64@5')A8VMI;F<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP
M.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-3,Y"FUS9VED(")4:6UE('-E;&5C=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L
M92(*;7-G<W1R("*]T.';WM(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E
M;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A0
M0RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*
M;7-G:60@(E1O9&%Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O
M=7)C92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4;V=O(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,PIM<V=I
M9"`B5&]M;W)R;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B
M5&]N9V$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM
M<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W.3`*
M;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E1U<FMI<V@@*$E3
M3RTX.#4Y+3DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U
M<FMM96YI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4
M=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M3$DO0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8Y"FUS
M9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE
M+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")5
M4DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY-PHC+"!F=7IZ>0IM<V=I9"`B55),.B(*;7-G<W1R(")54DPB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HT,3(*(RP@9G5Z>GD*;7-G:60@(E5N86)L
M92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BO=4@W-[6U=(@
MU-`@X=4@VM[=U=KBV.#0W"#AWB!344P@X=7@TM7@WN(N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@
M861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,X.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I
M;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@U(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H
M86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-34*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM
M<V=S='(@(KW5(-S>UM72(-30(.'5(-K>W=7:XMC@T-P@X=X@4U%,(.'5X-+5
MX-[B+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,R"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HV.#@@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ,#$V"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HX,S0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H
M<#HT,S4*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N
M(@IM<V=S='(@(KW5(-S>UM72(-30(.'5(-K>W=7:XMC@T-P@X=X@4U%,(.'5
MX-+5X-[B+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,Y"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS
M9W-T<B`BO=4@W-[6U=(@U-`@X=4@VM[=U=KBV.#0W"#AWB!344P@X=7@TM7@
MWN(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(U(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P
M.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM
M<V=S='(@(KW5(-S>UM72(-30(.'5(-K>W=7:XMC@T-P@X=X@4U%,(.'5X-+5
MX-[B+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S8U"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R
M>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C,U-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-38*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T
M<B`BO=4@W-[6U=(@U-`@X=4@VM[=U=KBV.#0W"#AWB!344P@X=7@TM7@WN(N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R-`HC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`B
MO=4@W-[6U=(@U-`@X=4@VM[=U=KBV.#0W"#AWB!344P@X=7@TM7@WN(N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR.#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8U
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F
M:6QE+B(*;7-G<W1R("*]U2#<WM;5TB#4T"#AU2#:WMW5VN+8X-#<(.'>(%-1
M3"#AU>#2U>#>XBXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M=&%R+G!H<#HW-@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII
M<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C(T(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,CDX"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES
M(&YO="!E;7!T>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW
M."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,Q(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,SDR"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HS,3$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,S-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@
M9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0X(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,W(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,S
M-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#0*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BO=4@W-[6
MU=(@U-`@X=4@VM[=U=KBV.#0W"#AWB!344P@X=7@TM7@WN(N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,3<@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HT,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HR,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,P,R!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C(X.`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,38W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#`*(SH@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X-R!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,S@S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HS.3$*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I
M;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M,C0T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z-#`V"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,#,*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S
M='(@(KW5X^'?U>C=WB#@U=/8X>+@V.#0^M4@W=`@W][4U>'CTM#ZT.+0(-+>
M(.'5X=CXT.+0+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C`S"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D
M971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0
M+G!H<#HT-3$@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T:"YP:'`Z,3$X
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I
M;FET:6]N(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`Q
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-C8@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W,0HC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(KW5(-S>UM72(-30
M(-/8(-C7W-7=T-P@W][4U>'CTM#ZT.+0+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z.3,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#(*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV-#@@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HY.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W-R!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ,S,*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W
M<FET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HX,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S`*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`BO=4@W-[6U=(@
MU-`@X=4@VM[=U=KBV.#0W"#AWB!344P@X=7@TM7@WN(N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT-0HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R
M("*]U2#<WM;5TB#4T"#3V"#8U]S5W=#<(-_>U-7AX]+0^M#BT"XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z.#,U"FUS9VED(")5;F%B;&4@=&\@<F5A
M9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8V"FUS9VED(")5;F%B;&4@=&\@
M<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L
M97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV-CD*
M;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3`U
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@=&\@
M)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN
M(@IM<V=S='(@(KW5(-S>UM72(-30(.'5(-K>W=7:XMC@T-P@X=X@4U%,(.'5
MX-+5X-[B+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C
M=&]R>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z,C8W(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S0S"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HV,3`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R
M,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C(X-0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M
M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@
M5V]R9"!D;V-U;65N="(*;7-G<W1R("*]U2#<WM;5TB#4T"#3WB#?X-72U=30
MW"#>TM[X(%=O<F0@U-[:X]S5W>(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HQ-#D@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-3(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH
M*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S
M.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30S"FUS9VED
M(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@T,0IM<V=I9"`B56YA8FQE('1O
M('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S
M='(@(K[BVM#6V"#3V"#?X-[<U=W8XM4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L
M87-T(&%C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HR,C,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E
M(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W.`HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*;7-G:60@(E5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU
M-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV
M,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y,PIM<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E
M<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV.2!L:6(O0FQO8VLO;65T87(N<&AP
M.C<Q"FUS9VED(")5;FET<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I
M9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S
M86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$U.0IM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A
M<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@
M8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N
M=&ET>2])9&5N=&ET>2YP:'`Z,CDV"B,L(&9U>GIY"FUS9VED(")5;FYA;65D
M(@IM<V=S='(@(KK>X-CAW=CGVMX@V-S5(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE
M9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G
M<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/
M2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC
M:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S
M<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E
M="!C;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8X-B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.CDR-@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,@IM
M<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-@HC+"!F=7IZ>0IM<V=I9"`B
M57!D871E('5S97(B"FUS9W-T<B`BM-[4T-38(-K>X-CAW=C:(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3D*;7-G:60@
M(E5P;&]A9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3@V"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL
M97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B
M57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED
M(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED
M(")5<V4@4U-,(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,C0*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N
M="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(E5S97(B
M"FUS9W-T<B`BNM[@V.'=V.?:WB#8W-4B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O4F5G:7-T<GDN<&AP.C<R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,C`S"B,L(&9U>GIY"FUS9VED(")5<V5R($%D
M;6EN:7-T<F%T:6]N(@IM<V=S='(@(DAO<F1E(+#4W-C=V.'BX-#BWN`B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,0HC+"!F=7IZ>0IM
M<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(K?0Y^/2T/@@WM_FV-@B"@HC
M.B!S:6=N=7`N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")5<V5R(%)E9VES=')A
M=&EO;B(*;7-G<W1R(")(;W)D92"PU-S8W=CAXN#0XM[@(@H*(SH@<VEG;G5P
M+G!H<#HR,@IM<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES
M86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C0V.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N
M9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R
M;F%M92(*;7-G<W1R("*ZWN#8X=W8Y]K>(-C<U2(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*(RP@9G5Z>GD*;7-G
M:60@(E5S97)N86UE.B(*;7-G<W1R("*ZWN#8X=W8Y]K>(-C<U2(*"B,Z('1E
M;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E5S
M97)N86UE.B`B"FUS9W-T<B`BNM[@V.'=V.?:WB#8W-4B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@
M<WES=&5M.B(*;7-G<W1R("*ZWN#8X=W8YM@@TMX@X=CAXM7<WN(Z(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-C,@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C4U"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T
M(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3$X"FUS9VED(")686-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HX-C8*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F
M;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV,S@*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3DW"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4V(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#0@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S$V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C@*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I
M9"`B5F%L=65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q,#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-@IM<V=I9"`B
M5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(T-`IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED
M(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E
M(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(E9E<G-I;VXB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R-@IM<V=I
M9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E
M<G1I8V%L(&%L:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I
M;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS9VED
M(")697)Y($AI9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B
M5FEE="!.86TB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.30*;7-G:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.38R"B,L('!H<"UF
M;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HX,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@
M0G)I=&ES:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G
M:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(P.0IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8S"FUS9VED(")6:7-I8FEL
M:71Y.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY
M('9I82!33510(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@
M(E=!4DXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-2
M25!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA
M($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES
M(&%N9"!&=71U;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM<V=S='(@(K+=
MV-S0W=C5(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,C<*
M;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3(*;7-G:60@(E=E871H97(N
M8V]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS
M9VED(")796(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0S-PIM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E
M:VQY(@IM<V=S='(@(KW5U-7;W=XB"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B
M:6QE+G!H<#HR.`HC+"!F=7IZ>0IM<V=I9"`B5V5L8V]M92(*;7-G<W1R("*T
MWM'@U=3>^-35+"`E<R(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R("*TWM'@U=3>
M^-35+"`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E
M;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")796QC;VUE+"`E<R(*;7-G<W1R("*TWM'@U=3>^-35+"`E<R(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U
M.2TQ*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM
M<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@
M(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G
M:6X_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM
M<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V
M,0IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@
M(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D
M:71O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-0IM<V=I9"`B5VED
M=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE
M("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO
M9RUI;BDZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G
M:60@(E=I9'1H.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-3$S"FUS9VED(")7:6MI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E=I;F0B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@
M(E=I;F0@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HX,`IM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U-@IM<V=I9"`B5VEN9#HB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T,@IM<V=I
M9"`B5VEN9#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ.38*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R("*PU.#5X=`@W=`@
MX-#1WN+0(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R("+"U=O5Y-[=(-W0
M(.#0T=[BT"(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$V.2!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E
M8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C,P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N
M9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Q-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A
M9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C0S"FUS9VED(")8+5)E9B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P
M.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED(")8-3`Y=C,@17AT
M96YD960@2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!
M;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+
M97D@261E;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9
M(@IM<V=S='(@(K.S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0Q,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#4U"B,L(&9U>GIY"FUS9VED(")965E9(@IM<V=S='(@(K.S
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q
M,#@*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY
M(@IM<V=S='(@(K/>U-CHW=XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")996UE
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.38S"FUS9VED(")997,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE
M<RP@22!!9W)E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@
M34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@
M5UE325=91RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N
M<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W
M960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,30Q,0IM<V=I9"`B66]U
M(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(EEO=2!C86X@
M;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4U
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S4*;7-G:60@(EEO=2!D:60@
M;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@
M:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB
M:6X@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.CDX.`IM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B
M"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L
M(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@
M:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C
M;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0U-@IM
M<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS
M9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U
M(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`BOM_8Z-7B
MU2#3WB#?X-[1V]7<WN(@W^#5U"#4T"#8X=_@T.+5XM4@V-?2U>CBT/@N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM
M<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@
M<&]I;G1S('1O(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S
M=6TN<&AP.C@P"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@
M<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(KW0TM74U>+5(-K>U2#:
MWN#8X=W8Y]K>(-C<U2#4T"#AU2#>XN'BX-#=V"XB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,3D*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U
M<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(KW0TM74U>+5(-K>U2#:
MWN#8X=W8Y]K>(-C<U2#4T"#AU2#>XN'BX-#=V"XB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!R96UO=F4N(@IM<V=S='(@(KW0TM74U>+5(-K>U2#:WN#8X=W8Y]K>(-C<
MU2#4T"#AU2#>XN'BX-#=V"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`BO=#2U=35
MXM4@VM[5(-K>X-CAW=CGVMX@V-S5(-30(.'5(-3>U-#4U2XB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ-#8*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`BO=#2U=35XM4@
MVM[5(-K>X-CAW=CGVMX@V-S5(-30(.'5(-3>U-#4U2XB"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*(RP@9G5Z>GD*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB
M"FUS9W-T<B`BO=#2U=35XM4@VM[5(-K>X-CAW=CGVMX@V-S5(-30(.'5(-[B
MX>+@T-W8+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!T>7!E(&$@
M;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(KW0TM74U>+5(-K>U2#:WN#8
MX=W8Y]K>(-C<U2#4T"#AU2#>XN'BX-#=V"XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U
M(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0
M;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C,X"B,L(&9U>GIY"FUS9VED(")9;W5R($5M
M86EL($%D9')E<W,B"FUS9W-T<B`BLM#HT"!%;6%I;"#0U.#5X=`Z(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q,@HC+"!F=7IZ>0IM<V=I9"`B66]U
M<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R("*RT.C0($5M86EL(-#4X-7AT#HB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(EEO=7(@26YF;W)M871I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@P"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@
M8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO
M;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I
M;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z,S,*(RP@9G5Z>GD*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R
M("*RT.C5(-C<U3HB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI
M;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B
M86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@
M=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U
M;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N=&EC871I
M;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@HBLM#HV-[B(-#2XM[@V-?0YMC>W=7=
M(-_@WN+>VM[;(-W5(-_>U.#6X]+0(-3>U-#2T/K5(-K>X-CAW=CFV"P@V-O8
M(.+0T"`B"B+<WM;=WN'B(-4@WMW5TM[7W-[6U=W0(-[4(-3@X]/8(-_@V.?8
MW=@N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHU"FUS
M9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@
M<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@
M8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@
M(B(*(K+0Z-C>XB#0TN+>X-C7T.;8WMW5W2#?X-[BWMK>VR#=U2#?WM3@UN/2
MT"#;V.'BT/K5(-K>X-CAW=CFV"P@V-O8(.+0T"`B"B+<WM;=WN'B(-4@WMW5
MTM[7W-[6U=W0(-[4(-3@X]/8(-_@V.?8W=@N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.3@T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@
M8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G
M:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R
M('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*;7-G:60@(EEO=7(@8G)O=W-E
M<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*;7-G:60@(B(*
M(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T
M:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4W"FUS9VED
M(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P<F5F<RYP:'`Z.38*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET
M>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,34X"B,L(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@
M:61E;G1I='DZ(@IM<V=S='(@(L'BT-W4T.#4U=T@V-35W>+8XM7B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,0HC+"!F=7IZ>0IM<V=I9"`B66]U
M<B!F=6QL(&YA;64Z(@IM<V=S='(@(K+0Z-4@V-S5.B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.C$P,#`*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X
M<&ER960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D
M(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ
M-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G
M:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO
M=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@
M86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,S(*;7-G:60@(EEO
M=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@
M<V5R=F5R<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-30@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I
M9"`B675G;W-L879I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP
M:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS
M.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G:60@(EM0<F]B;&5M(%)E<&]R
M=%TB"FUS9W-T<B`B6[C7TM7HXM#X(-?0(-_@WM';U=S>XETB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H
M;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X
M=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,L('!H
M<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DS
M"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U-#$@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B7T%D;6EN
M:7-T<F%T:6]N(@IM<V=S='(@(K#4W-C=V.'BX-#FV/C0(@H*(SH@;&EB+V%P
M:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN
M<&AP.C$T,0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0HC
M+"!F=7IZ>0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T<B`BN-?1X-CHV"(*
M"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U"B,L(&9U
M>GIY"FUS9VED(")?2&5L<"(*;7-G<W1R("*_WMS>Z"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I
M9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-`HC+"!F=7IZ>0IM<V=I9"`B
M7TQO9R!I;B(*;7-G<W1R("*[WM/8X-#ZU2(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92]-96YU+G!H<#HQ.3`*(RP@9G5Z>GD*;7-G:60@(E],;V<@;W5T
M(@IM<V=S='(@(KC7V]77(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN
M+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N
M<&AP.C$V-`HC+"!F=7IZ>0IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`BM]#G
MX]+0^"#>W^;8V"(*"B,Z(&QI8B]A<&DN<&AP.C$S-PIM<V=I9"`B7U!E<FUI
M<W-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@HC+"!F=7IZ>0IM<V=I9"`B7U)E
M;6]V92!,:6YK+BXN(@IM<V=S='(@(K[4X>+@T-W8(-_0X"(*"B,Z(&QI8B]A
M<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM
M<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C$*(RP@9G5Z>GD*;7-G:60@(F%D
M9')E<W,@8F]O:R(*;7-G<W1R("*PU.#5X=#@(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN
M;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3$S"FUS9VED(")C86QE;F1A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN;W0@8W)E871E
M(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HU.3(*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@
M;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$W.`IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E
M<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN
M9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ.#(*;7-G:60@
M(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B9F%L;&EN9R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-34*
M(RP@9G5Z>GD*;7-G:60@(F9I;&4B"FUS9W-T<B`BO=#AV][2(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C`@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4P"FUS9VED(")G=7-T:6YG(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR-#D*;7-G:60@(F@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HS-3@*;7-G:60@(FAH(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,X
M"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*
M;7-G:60@(FEM;65D:6%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D
M:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL
M:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G
M:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L
M:6YE<UTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@
M(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S8Y"FUS9VED(")M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C(Y,2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP
M:'`Z,3<P"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,S(*(RP@
M9G5Z>GD*;7-G:60@(FYA;64B"FUS9W-T<B`BN-S5(@H*(SH@9G)A;65W;W)K
M+U)00R]24$,N<&AP.C$R,0IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(Q
M.0IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-0IM<V=I9"`B;F]T97!A9"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<T"FUS9VED(")P
M97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE
M;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW,PHC+"!F=7IZ>0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(K+=V-S0W=C5
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G
M:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HY.0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HS.#4*;7-G:60@(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")S=&5A9'DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#D*;7-G:60@
M(G-W:71C:"!O9F8@:F%V87-C<FEP="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R
M<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3(Y"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F
M86EL=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,S`U"B,L(&9U>GIY"FUS9VED(")T<GD@86=A:6XB"FUS9W-T<B`BP=7:
MWM4@W^#8^-#2X]+0^M4B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")T>7!E('1H92!P
M87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS
M9VED(")U;FEF:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(S"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR-#$*;7-G:60@(G<Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*;7-G
M<W1R("(B"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O;F)?3D\N<&\`
M````````````````````````````````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#8V-30R-@`Q,#4Q-30S,S<U-0`P,3<V-30`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````(R!.;W)W96=I86X@2&]R9&4@5')A
M;G-L871I;VXN"B,@0V]P>7)I9VAT("A#*2`R,#`Q+3(P,#(@2&]R9&4@4')O
M:F5C="X*(R!/>7-T96EN(%-T96EM;&5R(#QO>7-T96EN0')E>'1A+FYE=#XL
M(#(P,#$N"B,@5&]R<W1E:6X@4RX@2&%N<V5N(#QH=6QE8F]E<D!T96-H8F5E
M+FYO/BP@,C`P,BX*(R!!;F1R96%S($=U;FQE:6MS:V%A<R`\86YD<F5A<T!G
M=6YL96EK<VMA87,N;F\^+"`R,#`S+@HC($=E:7(@3RX@2&]G8F5R9R`\:&]R
M9&5`<VMY9&EV97(N;F\^+"`R,#`U+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB
M4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`N-%QN(@HB4F5P;W)T+4US
M9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A
M=&EO;BU$871E.B`R,#`U+3`U+3$X(#$R.C0S*S`R,#!<;B(*(E!/+5)E=FES
M:6]N+41A=&4Z(#(P,#4M,#4M,3@@,30Z,S<K,#(P,%QN(@HB3&%S="U4<F%N
M<VQA=&]R.B!'96ER($\N($AO9V)E<F<@/&AO<F1E0'-K>61I=F5R+FYO/EQN
M(@HB3&%N9W5A9V4M5&5A;3H@3F]R=V5G:6%N("A";VMM86PI(#QI,3AN0&QI
M<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT
M96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,5QN(@HB
M0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C0Y"FUS9VED("(B"B(@("U-+"`M+6UE<W-A9V4]3453
M4T%'12`@57-E('1H:7,@8V]M;6ET(&UE<W-A9V4@:6YS=&5A9"!O9B!T:&4@
M9&5F875L="!O;F5S+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-3,*;7-G:60@(B(*(B`@+6$L("TM861D/49)3$4@("`@("`@($%D9"!T
M:&ES(%!/(&9I;&4@=&\@=&AE(&-O;7!E;F1I=6TN(%5S969U;"!T;UQN(@HB
M("`@("`@("`@("`@("`@("`@("`@("`@:6YC;'5D92!A(&-O;7!E;F1I=6T@
M9G)O;2!A(&1I9F9E<F5N="!B<F%N8V@@=&]<;B(*(B`@("`@("`@("`@("`@
M("`@("`@("`@('1H92!G96YE<F%T960@8V]M<&5N9&EU;2XB"FUS9W-T<B`B
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q,PIM<V=I9"`B(@HB("`M8BP@
M+2UB87-E/2]0051(("!&=6QL('!A=&@@=&\@=&AE("A(;W)D92D@8F%S92!D
M:7)E8W1O<GD@=&AA="!S:&]U;&0@8F5<;B(*(B`@("`@("`@("`@("`@("`@
M("`@=7-E9"XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8Y
M"FUS9VED("(B"B(@("UC+"`M+6-O;7!E;F1I=6T]1DE,12`@365R9V4@;F5W
M('1R86YS;&%T:6]N<R!T;R!T:&ES(&-O;7!E;F1I=6T@9FEL95QN(@HB("`@
M("`@("`@("`@("`@("`@("`@("`@(&EN<W1E860@;V8@=&AE(&1E9F%U;'0@
M;VYE("AC;VUP96YD:75M+G!O(&EN('1H95QN(@HB("`@("`@("`@("`@("`@
M("`@("`@("`@(&AO<F1E+W!O(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C8S('!O+W1R86YS;&%T:6]N+G!H<#HX,2!P
M;R]T<F%N<VQA=&EO;BYP:'`Z.#<*;7-G:60@(B(*(B`@+6,L("TM8V]M<&5N
M9&EU;3U&24Q%("!5<V4@=&AI<R!C;VUP96YD:75M(&9I;&4@:6YS=&5A9"!O
M9B!T:&4@9&5F875L=%QN(@HB("`@("`@("`@("`@("`@("`@("`@("`@(&]N
M92`H8V]M<&5N9&EU;2YP;R!I;B!T:&4@:&]R9&4O<&\@9&ER96-T;W)Y*2XB
M"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q-`IM<V=I9"`B
M("`M9"P@+2UD96)U9R`@("`@("!3:&]W(&5R<F]R(&UE<W-A9V5S(&9R;VT@
M=&AE(&5X96-U=&5D(&)I;F%R:65S+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-30*;7-G:60@(B`@+60L("TM9&ER96-T;W)Y/41)4B`@
M($-R96%T92!C;VUP96YD:75M(&EN('1H:7,@9&ER96-T;W)Y+B(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$U"FUS9VED("(@("UH+"`M
M+6AE;'`@("`@("`@(%-H;W<@=&AI<R!H96QP(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-C<@<&\O=')A;G-L871I;VXN<&AP.C<U"FUS9VED("(@("UL+"`M+6QO
M8V%L93UL;%]#0R`@("`@57-E(&]N;'D@=&AI<R!L;V-A;&4N(@IM<V=S='(@
M(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT-R!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-C$@<&\O=')A;G-L871I;VXN<&AP.C<Y"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HX-0IM<V=I9"`B("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S92!T
M:&ES(&QO8V%L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C4U"FUS9VED("(@("UL+"`M+6QO8V%L93UL;%]#0R`@("!5<V4@=&AI<R!L
M;V-A;&4N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV.`IM
M<V=I9"`B("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($)U:6QD($U/(&9I;&5S
M(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S='(@(B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HT,PIM<V=I9"`B("`M;2P@+2UM;V1U;&4]
M34]$54Q%("`@($-L96%N=7`@4$\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R
M9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C0X"FUS9VED("(B"B(@("UM+"`M+6UO9'5L93U-3T153$4@("`@0V]M;6ET
M('1R86YS;&%T:6]N<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+B(*
M;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C(*;7-G:60@(B`@
M+6TL("TM;6]D=6QE/4U/1%5,12`@("!#<F5A=&4@82!03R!F:6QE(&]N;'D@
M9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S='(@(B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HX,`IM<V=I9"`B("`M;2P@+2UM;V1U;&4]34]$54Q%
M("`@($UE<F=E(%!/(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U
M;&4N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW-@IM<V=I
M9"`B(@HB("`M;2P@+2UM;V1U;&4]34]$54Q%("`@(%5P9&%T92!H96QP(&9I
M;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S='(@(B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX-@IM<V=I9"`B("`M;2P@+2UM;V1U
M;&4]34]$54Q%("`@(%5P9&%T92!O;FQY('1H:7,@*$AO<F1E*2!M;V1U;&4N
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU.`IM<V=I9"`B
M("`M;2P@+2UM;V1U;&4]34]$54Q%("!'96YE<F%T92!03U0@9FEL92!O;FQY
M(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-S`*;7-G:60@(B(*(B`@+6XL("TM;F\M8V]M<&5N
M9&EU;2`@("!$;VXG="!M97)G92!N97<@=')A;G-L871I;VYS('1O('1H92!C
M;VUP96YD:75M+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-C0@<&\O=')A;G-L871I;VXN<&AP.C@R('!O+W1R86YS;&%T:6]N+G!H<#HX
M.`IM<V=I9"`B("`M;BP@+2UN;RUC;VUP96YD:75M("`@($1O;B=T('5S92!A
M(&-O;7!E;F1I=6TN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HW,0IM<V=I9"`B("`M<RP@+2US=&%T:7-T:6-S("`@("`@(%-A=F4@=')A
M;G-L871I;VX@<W1A=&ES=&EC<R!I;B!A(&QO8V%L(&9I;&4N(@IM<V=S='(@
M(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,38*;7-G:60@(B`@+70L("TM
M=&5S="`@("`@("`@4VAO=R!T:&4@97AE8W5T960@8V]M;6%N9',@8G5T(&1O
M;B=T(')U;B!A;GET:&EN9RXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C$P-0IM<V=I9"`B(@HB("!C;&5A;G5P("`@("!#;&5A;G,@=&AE
M(%!/(&9I;&5S('5P(&9R;VT@=6YT<F%N<VQA=&5D(&%N9"!O8G-O;&5T92!E
M;G1R:65S+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`X
M"FUS9VED("(@(&-O;6UI="`@("`@($-O;6UI="!T<F%N<VQA=&EO;G,@=&\@
M=&AE($-64R!S97)V97(N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HQ,#D*;7-G:60@(B`@8V]M;6ET+6AE;'`@0V]M;6ET(&AE;'`@9FEL
M97,@=&\@=&AE($-64R!S97)V97(N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HY.0IM<V=I9"`B(@HB("!C;VUP96YD:75M("!296)U:6QD
M('1H92!C;VUP96YD:75M(&9I;&4N(%=A<FYI;F<Z(%1H:7,@;W9E<G=R:71E
M<R!T:&5<;B(*(B`@("`@("`@("`@("`@8W5R<F5N="!C;VUP96YD:75M+B(*
M;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`P"FUS9VED("(@
M(&5X=')A8W0@("`@($=E;F5R871E(%!/('1E;7!L871E("@N<&]T*2!F:6QE
M<RXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.CDX"FUS9VED
M("(@(&AE;'`@("`@("`@(%-H;W<@=&AI<R!H96QP(&UE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#$*;7-G:60@(B(*(B`@
M:6YI="`@("`@("`@0W)E871E(&]N92!O<B!M;W)E(%!/(&9I;&5S(&9O<B!A
M(&YE=R!L;V-A;&4N(%=A<FYI;F<Z(%1H:7-<;B(*(B`@("`@("`@("`@("`@
M;W9E<G=R:71E<R!T:&4@97AI<W1I;F<@4$\@9FEL97,@;V8@=&AI<R!L;V-A
M;&4N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#8*;7-G
M:60@(B`@;6%K92`@("`@("`@0G5I;&0@8FEN87)Y($U/(&9I;&5S(&9R;VT@
M=&AE('-P96-I9FEE9"!03R!F:6QE<RXB"FUS9W-T<B`B(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C$P-PIM<V=I9"`B(@HB("!M86ME+6AE;'`@("!-87)K
M(&%L;"!E;G1R:65S(&EN('1H92!834P@:&5L<"!F:6QE(&)E:6YG('5P+71O
M+61A=&4@86YD7&XB"B(@("`@("`@("`@("`@('!R97!A<F4@=&AE(&9I;&4@
M9F]R('1H92!N97AT(&5X96-U=&EO;B!O9B!U<&1A=&4M:&5L<"X@66]U7&XB
M"B(@("`@("`@("`@("`@('-H;W5L9"!O;FQY(')U;B!M86ME+6AE;'`@0494
M15(@=7!D871E+6AE;'`@86YD(')E=FES:6YG('1H95QN(@HB("`@("`@("`@
M("`@("!H96QP(&9I;&4N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HQ,#(*;7-G:60@(B(*(B`@;65R9V4@("`@("`@365R9V4@=&AE(&-U
M<G)E;G0@4$\@9FEL92!W:71H('1H92!C=7)R96YT(%!/('1E;7!L871E(&9I
M;&4N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#,*;7-G
M:60@(B`@=7!D871E("`@("`@4G5N(&5X=')A8W0@86YD(&UE<F=E('-E<75E
M;G0N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#0*;7-G
M:60@(B(*(B`@=7!D871E+6AE;'`@17AT<F%C="!A;&P@;F5W(&%N9"!C:&%N
M9V5D(&5N=')I97,@9G)O;2!T:&4@16YG;&ES:"!834P@:&5L<%QN(@HB("`@
M("`@("`@("`@("!F:6QE(&%N9"!M97)G92!T:&5M('=I=&@@=&AE(&5X:7-T
M:6YG(&]N97,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]C;VYF:7)M7W1O<"YI;F,Z,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M("8C,34Q.R`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC
M92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N(@IM<V=S='(@(B(*(B`F(S$U
M,3L@)7,@97(@:VQA<B!F;W(@Y2!U=&;X<F4@=F5D;&EK96AO;&1S;W!E<F%S
M:F]N96YE('-O;2!E<B!V86QG="`B"B)N961E;F9O<BXB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C,U,@HC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A
M>7,@86=O*2(*;7-G<W1R("(@*"5S(&1A9V5R('-I9&5N*2(*"B,Z(&QI8B](
M;W)D92YP:'`Z,3(X,PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME
M>2`E<RDB"FUS9W-T<B`B("AH=7)T:6=T87-T("5S*2(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,S8P"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@
M9&%Y<RDB"FUS9W-T<B`B("AI;FYE;B`E<R!D86=E<BDB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C,U-@IM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B("AI
M(&1A9RDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,U.`IM<V=I9"`B("AT
M;VUO<G)O=RDB"FUS9W-T<B`B("AI(&UO<F=E;BDB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C,U-`IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B`H
M:2!GY7(I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-`IM
M<V=I9"`B(&%T("(*;7-G<W1R("(@9&5N("(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@
M86YD("5S(@IM<V=S='(@(B5D("5S(&]G("5S(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C$Q-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@8GET97,@=W)I
M='1E;BXB"FUS9W-T<B`B)60@8GET97,@<VMR979E="XB"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,3(V-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!O9B`E
M9"!E;G1R:65S(&UA<FME9"!A<R!U<"UT;RUD871E(@IM<V=S='(@(B5D(&%V
M("5D(&]P<&;X<FEN9V5R(&UA<FME="!S;VT@;W!P9&%T97)T(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T,0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B)60M9&%G97)S('9A<G-E
M;"(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]N;W1I8V5?=&]P+FEN8SHT
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S
M("T@5&EL(&EN9F\B"@HC.B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E
M<BYI;F,Z,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B)7,@861M:6YI<W1R87-J;VXB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C<R.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&
M:6YG97)P<FEN="(*;7-G<W1R("(E<R!&:6YG97)P<FEN="(*"B,Z(&QI8B](
M;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-3<@;&EB+TAO<F1E+TU)344O0V]N
M=&5N=',N<&AP.C@U.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G
M<W1R("(E<R!+0B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M
M7W1O<"YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC
M92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S('9E9&QI
M:V5H;VQD<V]P97)A<VIO;F5R("T@0F5K<F5F=&5L<V4B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B)7,@:6YS
M=&EL;&EN9V5R(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(E<R!R
M96=I<W1R97)I;F<B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O86=R965M
M96YT7W1O<"YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O
M9B!!9W)E96UE;G0B"FUS9W-T<B`B)7,@879T86QE=FEL:^5R(@H*(SH@;&EB
M+U9&4R]F='`N<&AP.C4Y-B!L:6(O5D93+V9T<"YP:'`Z-C8V"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(E<R!F
M:6YN97,@86QL97)E9&4N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3<@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C,@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,S<*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#,@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS
M9W-T<B`B)7,@<.4@)7,@)7,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HU,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S
M(&-A;F-E;&QE9"`E<RXB"FUS9W-T<B`B)7,@:&%R(&MA;G-E;&QE<G0@)7,N
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#(V
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R97!L:65D('1O(&$@9G)E
M92]B=7-Y(')E<75E<W0N(@IM<V=S='(@(B5S(&AA<B!B97-V87)T(&5N(&9O
M<F5S</AR<V5L(&]M(&EN9F]R;6%S:F]N(&%N9^5E;F1E(&QE9&EG+V]P<'1A
M='0N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-3(T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R97!L:65D('1O('1H
M92!I;G9I=&%T:6]N('1O("5S+B(*;7-G<W1R("(E<R!H87(@<W9A<G0@<.4@
M:6YV:71A<VIO;F5N('1I;"`E<RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HT,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M:&%S('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B
M)7,@:&%R('-E;F1T(&1E9R!I;F9O<FUA<VIO;B!O;2!L961I9R]O<'!T871T
M+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HR.#<@<&\O=')A;G-L871I;VXN
M<&AP.C,Q-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!N;W0@=W)I=&%B
M;&4N(@IM<V=S='(@(B5S(&5R('-K<FEV96)E<VMY='1E="XB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I
M<R!R97%U:7)E9"(*;7-G<W1R("(E<R!E<B!PY6MR979D(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN
M=71E<R(*;7-G<W1R("(E<R!M:6YU='1E<B(*"B,Z(&QI8B](;W)D92]";&]C
M:R]#;VQL96-T:6]N+G!H<#HQ,C,@<&\O=')A;G-L871I;VXN<&AP.C$S,S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(E
M<R!I:VME(&9U;FYE="XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-3@U"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N9"X@4G5N("=T<F%N<VQA
M=&EO;B!E>'1R86-T)R!F:7)S="XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#(Q"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(')E<75E<W1S('EO=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N
M+B(*;7-G<W1R("(E<R!F;W)E<W#X<B!I;F9O<FUA<VIO;B!O;2!NY7(@9'4@
M97(@;&5D:6<O;W!T=&%T="XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HU,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q
M=65S=',@>6]U<B!P<F5S96YC92!A="`E<RXB"FUS9W-T<B`B)7,@9F]R97-P
M^'(@9&EN(&1E;'1A9V5L<V4@<.4@)7,N(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E
M<R!O9B`E<R(*;7-G<W1R("(E<R`M("5S(&%V("5S(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3$S"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S('=I<VAE<R!T;R!A9&0@=&\@)7,N(@IM<V=S='(@(B5S(/AN
M<VME<B#E(&QE9V=E('1I;"`E<RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HU,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M=VES:&5S('1O(&UA:V4@>6]U(&%W87)E(&]F("5S+B(*;7-G<W1R("(E<R#X
M;G-K97(@Y2!G:OAR92!D96<@;W!P;65R:W-O;2!PY2`E<RXB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,3@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(')E8V5I=F4@=&AE(&QA=&5S="!I
M;F9O<FUA=&EO;B!A8F]U="`E<RXB"FUS9W-T<B`B)7,@^&YS:V5R(.4@;6]T
M=&$@9&5N('-I<W0@;W!P9&%T97)T92!I;F9O<FUA<VIO;F5N(&]M("5S+B(*
M"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3$R"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(D%D9')E<W-E8F]K(&9O
M<B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3`T"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B2V%L96YD97(@9F]R
M("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HX.38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(DYO=&%T8FQO:VL@9F]R
M("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,C`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R(")/<'!G879E;&ES=&4@
M9F]R("5S(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.CDW"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G
M<W1R("(E<SH@)7,B"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR-S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)R5S)R!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM
M<V=S='(@(B<E<R<@97(@:6MK92!E="!G>6QD:6<@=F%L9RXB"@HC.B!L:6(O
M2&]R9&4O4F5G:7-T<GDN<&AP.C4X,B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP
M.CDX,@HC+"!P:'`M9F]R;6%T"FUS9VED("(G)7,G(&ES(&YO="!C;VYF:6=U
M<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B)R5S)R!E<B!I
M:VME(&-O;F9I9W5R97)T(&D@2&]R9&4@4F5G:7-T97)E="XB"@HC.B!L:6(O
M2&]R9&4O5')E92YP:'`Z,38P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M("(G)7,G('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R("(E<R!I
M:VME(&9U;FYE="XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4W"B,L('!H<"UF
M;W)M870*;7-G:60@(B<E<R<@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES
M=&5M+B(*;7-G<W1R("(E<R!B;&4@;&%G="!T:6P@9W)U<'!E<WES=&5M970N
M(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C@U"B,L('!H<"UF;W)M
M870*;7-G:60@(B<E<R<@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S
M>7-T96TN(@IM<V=S='(@(B<E<R<@8FQE(&QA9W0@=&EL(')E='1I9VAE='-S
M>7-T96UE="XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4U(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED("(G)7,G('=A
M<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(B5S(&)L92!I:VME(&]P<')E
M='1E=#H@)7,N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#8@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ.3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(E<R!PY2`E<R`E<R(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3DY"B,L('!H<"UF;W)M870*;7-G:60@(BP@
M=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(L('9A<FEA8F5L(&UE
M;&QO;2`E<R!O9R`E<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#4S(&QI
M8B](;W)D92]&;W)M+G!H<#HR,3$R"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HV.3$*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R
M("(M+2!V96QG("TM(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S,#D@<&\O
M=')A;G-L871I;VXN<&AP.C$S,3$*;7-G:60@(BTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z
M,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@(C$R(%1I;65R<R!F
M;W)M870B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO
M=7(@1F]R;6%T(@IM<V=S='(@(C(T(%1I;65R<R!F;W)M870B"@HC.B!T96UP
M;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T
M<B`B,C0@=&EM97(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,S0T"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(CQG971T97AT/B!T86<@;F]T(&-L;W-E9"!I
M;B!F:6QE("5S+EQN(@HB3W!E;FEN9R!T86<@9F]U;F0@:6X@;&EN92`E9"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3<*;7-G:60@
M(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C
M:RXB"FUS9W-T<B`B16X@9&%T86)A<V5K;V)L:6YG(&5R('#E:W)E=F0@9F]R
M(&1E;FYE(&)L;VMK96XN(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-C8*;7-G:60@
M(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(D5N(&9A=&%L
M(&9E:6P@:&%R(&]P<'-TY71T(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z.30Q"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")%;B!O9F9E;G1L:6<@4$=0
M+6[X:VME;"!E<B!PY6MR979D(&9O<B#E(&MR>7!T97)E(&UE;&1I;F=E;BXB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,38W"FUS9VED(")!('!U
M8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M
M97-S86=E+B(*;7-G<W1R(")%;B!O9F9E;G1L:6<@4$=0+6[X:VME;"!E<B!P
MY6MR979D(&9O<B#E('9E<FEF:7-E<F4@<VEG;F5R="!M96QD:6YG+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P.3@*;7-G:60@(B(*(D$@<'5B
M;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R
M("(B"B)%;B!O9F9E;G1L:6<@4$=0+6[X:VME;"P@<')I=F%T(%!'4"UN^&MK
M96P@;V<@<&%S<W!H<F%S92!E<B!PY6MR979D(&9O<B#E("(*(F1E:W)Y<'1E
M<F4@96X@;65L9&EN9RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ
M,#$W"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB
M;65S<V%G92XB"FUS9W-T<B`B(@HB16X@;V9F96YT;&EG(%!'4"UN^&MK96PL
M('!R:79A="!01U`M;OAK:V5L(&]G('!A<W-P:')A<V4@97(@<.5K<F5V9"!F
M;W(@Y2`B"B)S:6=N97)E(&5N(&UE;&1I;F<N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU,C,*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K
M97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B)%
M;B!O9F9E;G1L:6<@4R]-24U%+6[X:VME;"P@<')I=F%T(%,O34E-12UN^&MK
M96PL(&]G('!A<W-P:')A<V4@97(@<.5K<F5V9"`B"B)F;W(@Y2!D96MR>7!T
M97)E(&5N(&UE;&1I;F<N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HT-#D*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@
M4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I
M9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"B)%;B!O9F9E;G1L:6<@4R]-
M24U%+6[X:VME;"P@<')I=F%T(%,O34E-12UN^&MK96PL(&]G('!A<W-P:')A
M<V4@97(@<.5K<F5V9"`B"B)F;W(@Y2!S:6=N97)E(&5N(&UE;&1I;F<N(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS.#(*;7-G:60@(D$@<'5B
M;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92XB"FUS9W-T<B`B16X@;V9F96YT;&EG(%,O34E-12UN^&MK96P@97(@<.5K
M<F5V9"!F;W(@Y2!K<GEP=&5R92!E;B!M96QD:6YG+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,C4*(RP@9G5Z>GD*;7-G:60@(D%-(%)A
M:6XB"FUS9W-T<B`B4F5G;B!PY2!F;W)M:61D86=E;B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,C8*(RP@9G5Z>GD*;7-G:60@(D%-(%-H
M;W=E<G,B"FUS9W-T<B`B4F5G;F)Y9V5R('#E(&9O<FUI9&1A9V5N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,R-PHC+"!F=7IZ>0IM<V=I
M9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(E-N^&)Y9V5R('#E(&9O<FUI
M9&1A9V5N(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@
M(D%-+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,#0*;7-G:60@(D%022!)1"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS
M9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R(")/;2!D96YN92!E9&ET
M;W)E;B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4R"FUS9VED(")!
M8F]U="XN+B(*;7-G<W1R(")/;2XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G
M<W1R(")!8G-O;'5T="!N961E<G-T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S
M='(@(D%B<V]L=71T(&UI9'0B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HV-#`*;7-G:60@(D%C8V5P="!R97%U97-T(@IM<V=S
M='(@(D=O9&MJ96YN(&9O<F5S</AR<V5L(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C@Q"FUS9VED(")!8V-E<'1E9"(*;7-G
M<W1R(")';V1T871T(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,C@U"FUS9VED
M(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(E1I;&=A;F<@;F5K=&5T('9E9"!O<'!R971T96QS92!A=B!61E,@:V%T
M86QO9RXB"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HQ,S@*;7-G:60@(D%C8V5S
M<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(E1I;&=A;F<@
M;F5K=&5T('9E9"!O<'!R971T96QS92!A=B!61E,@9FEL+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW-0IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*
M;7-G<W1R(")+;VYT;R!087-S;W)D(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G
M<W1R(")+;VYT;R!F<OAS970N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,R,`IM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R(")";VMH;VQD:6YG
M+T%C8V]U;G1I;F<B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HT-3$*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-C(U"FUS9VED(")!8W1I;VYS(@IM<V=S='(@(DAA;F1L:6YG97(B
M"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-30@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HQ,S8*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$V"FUS9VED
M(")!9&0B"FUS9W-T<B`B3&5G9R!T:6PB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C(Q-"!A9&UI;B]G<F]U<',N<&AP.C(Q-0IM<V=I9"`B061D($-H:6QD($=R
M;W5P(@IM<V=S='(@(DQE9V<@=&EL('5N9&5R9W)U<'!E(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HX,2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C@R
M"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R("),96=G('1I
M;"!U;F1E<G)E='1I9VAE=&5R(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N
M:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R("),96=G('1I;"!H97(Z
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,#@@861M:6XO9W)O=7!S+G!H<#HR
M,#D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B3&5G9R!T:6P@;GD@
M9W)U<'!E(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HW,"!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C<Q"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB
M"FUS9W-T<B`B3&5G9R!T:6P@;GD@<F5T=&EG:&5T(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!9&0@82!C:&EL9"!G<F]U<"!T;R`G)7,G(@IM<V=S='(@(DQE9V<@
M=&EL(&5N('5N9&5R9W)U<'!E('1I;"`G)7,G(@H*(SH@861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP.C4S(&QI8B](;W)D92]097)M<R]522YP:'`Z,3,U"B,L
M('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@
M)R5S)R(*;7-G<W1R("),96=G('1I;"!U;F1E<G)E='1I9VAE="!T:6P@)R5S
M)R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E
M<CHB"FUS9W-T<B`B3&5G9R!T:6P@;GD@8G)U:V5R.B(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HU,CD*;7-G:60@(D%D9"!C;VQU
M;6XB"FUS9W-T<B`B3&5G9R!T:6P@:V]L;VYN92(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,S4*;7-G:60@(D%D9"!N97<@;65M8F5R
M<R(*;7-G<W1R("),96=G('1I;"!N>64@;65D;&5M;65R(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(D%D9"!P86ER(@IM<V=S
M='(@(DQE9V<@=&EL('!A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@
M36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(DQE9V<@=&EL("5S(&UE;GEE;B!S
M;VT@36]Z:6QL82!3:61E8F%R(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-C,Q"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C8S-PIM<V=I9"`B061D('1H:7,@=&\@;7D@8V%L96YD
M87(B"FUS9W-T<B`B3&5G9R!T:6P@:2!M:6X@:V%L96YD97(B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C<T"FUS9VED(")!9&0@=&\@
M861D<F5S<R!B;V]K.B(*;7-G<W1R("),96=G('1I;"!I(&%D9')E<W-E8F]K
M.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z.#$*;7-G
M:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B3&5G9R!T:6P@
M:2!M:6X@861D<F5S<V5B;VLB"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I
M9"`B061D('5S97(B"FUS9W-T<B`B3&5G9R!T:6P@8G)U:V5R(@H*(SH@861M
M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@
M)R5S)R!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO
M;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)2(*(G,N(@IM<V=S='(@(B(*(DQA
M('1I;"`G)7,G(&D@<WES=&5M970L(&UE;B!K=6YN92!I:VME(&QE9V=E('1I
M;"!E:W-T<F$@<F5G:7-T<F5R:6YG<VEN9F\Z("4B"B)S+B(*"B,Z('-I9VYU
M<"YP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@)R5S)R!T;R!T
M:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(DQA("<E
M<R<@=&EL('-Y<W1E;65T+B!$=2!K86X@;&]G9V4@:6YN(&[E+B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HY-38*;7-G:60@(D%D9&EN9R!N97<@9FEL97,@
M=&\@<F5P;W-I=&]R>3HB"FUS9W-T<B`B3&$@=&EL(&YY92!F:6QE<B!I(')E
M<&]S:71O<GDZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC
M.C0*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B
M375L:6=H970@9F]R(.4@;&5G9V4@=&EL(&YY92!B<G5K97)E(&5R(&1E86MT
M:79E<G0N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,S@@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,CD*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ-S8*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B
M061R97-S92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S0*;7-G
M:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R(")!9')E<W-E($)O:R(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY-PIM<V=I9"`B061M:6YI
M<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T
M<B`B061M:6YI<W1R97(@+2!S971T(')E='1I9VAE=&5R(&9O<B!A;F1R92!B
M<G5K97)E(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(D%D;6EN:7-T<F%S:F]N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0P-@IM<V=I9"`B061S(@IM<V=S='(@(E)E:VQA;65R(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B
M069G:&%N:7-T86XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06QB86YI82(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S0@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<Q"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$P"FUS9VED(")!;&EA<R(*;7-G<W1R
M(")!;&EA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@(DIU<W1E<F4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W
M"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(DIU<W1E<FEN9SHB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R(")!
M;&QE(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3$X('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S
M97)S(@IM<V=S='(@(D%L;&4@875T96YT:7-E<G1E(&)R=6ME<F4B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C$R"FUS9VED
M(")!;&P@1W)O=7!S(@IM<V=S='(@(D%L;&4@1W)U<'!E<B(*"B,Z(&%D;6EN
M+W!E<FUS+V%D9&-H:6QD+G!H<#HS."!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C<T"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B06QL92!R961D
M:6=H971E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@
M(D%L;&4@9FER92!S:61E<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#4U
M"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B5&EL
M;&%T="!F;&5R92!A9')E<W-E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,C,*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y
M<&4_(@IM<V=S='(@(E1I;&QA='0@96YD<FEN9R!A=B!F;W)M871E="!PY2!N
M=6UM97)E<G1E(&QI<W1E<C\B"@HC.B!L:6(O2&]R9&4O1&%T851R964O<W%L
M+G!H<#HT,#,*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(D5K<VES
M=&5R97(@86QL97)E9&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(R
M"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R(")!;'1E<FYA
M=&EV($E-4U`@3&]G:6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DV
M"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R(")!;'1E
M<FYA=&EV="!)35-0('!A<W-O<F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#@X"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R
M(")!;'1E<FYA=&EV="!)35-0(&)R=6ME<FYA=FXB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D
M9')E<W,B"FUS9W-T<B`B06QT97)N871I=B!E+7!O<W0@861R97-S92(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@=&5M
M<&QA=&5S(@IM<V=S='(@(D%L=&5R;F%T:79E(&UA;&5R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(U
M"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B06QT97)N871I=B!T
M96MS=#HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4Y"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O4')E9G,O54DN<&AP.CDW(&QI8B](;W)D92]0<F5F<R]522YP
M:'`Z,3$W"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N
M(@IM<V=S='(@(D5N('5L;W9L:6<@=F5R9&D@=F%R(&]P<&=I='0N(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I
M9"`B06YD;W)R82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M.`IM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3(P"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T
M<B`B06YO;GEM(%!R;WAY(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R(")3=F%R(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B06YT
M87)C=&EC82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO
M<&AP<VAE;&PN<&AP.C,P(&QI8B](;W)D92]";&]C:R]522YP:'`Z-3D*(SH@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P
M;&EC871I;VXB"FUS9W-T<B`B4')O9W)A;2(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R(")0
M<F]G<F%M;&ES=&4B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,P"FUS
M9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B4')O9W)A;6UE
M="!E<B!K;&%R="XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q
M.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(D]P<&1A
M=&5R(&]G<^4@<F5K=7)S:79T(&YE9&]V97(@9F]R('5N9&5R;6%P<&5R+V9I
M;&5R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,S,*
M;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B1V]D:VIE;FXB"@HC.B!L:6(O2&]R
M9&4O34E-12]#;VYT96YT<RYP:'`Z.#4W"FUS9VED(")!<'!R;WAI;6%T92!3
M:7IE(@IM<V=S='(@(D]M=')E;G1L:6<@<W3X<G)E;'-E(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W-R!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$T"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Q"FUS9VED(")!<F%B:6,@
M*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C(@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C8*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#$*;7-G
M:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(D9I;'-T^')R96QS92!P
MY2!A<FMI=F5T(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C$@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#`*;7-G:60@(D%R8VAI=F4@3F%M
M92(*;7-G<W1R(")!<FMI=FYA=FXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F5Q=65U960N:6YC.CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E
M('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E
M<W0@9F]R("5S(#\B"FUS9W-T<B`B17(@9'4@4TE+2T52('#E(&%T(&1U('9I
M;"!F:F5R;F4@<F5G:7-T<F5R:6YG<V9O<F5S</AR<V5L96X@9F]R("5S/R(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHY"B,L('!H
M<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE
M=&4@)R5S)R!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(D5R(&1U('-I
M:VME<B!PY2!A="!D=2!V:6P@<VQE='1E("<E<R<@;V<@9&5N<R!U;F1E<F=R
M=7!P97(_(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(V(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HU.0IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R
M;65N:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S(*
M;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(DMU
M;G-T(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,P(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,`IM<V=I9"`B07)U8F$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@
M07)T(@IM<V=S='(@(D%S8VEI(&MU;G-T(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-38*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Q-0IM<V=I9"`B07-K
M(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,_(@IM<V=S='(@(D)E(&]M(&)E:W)E9G1E;'-E(&;X<B!G:F5N
M;F]M9OAR:6YG(&%V('9E9&QI:V5H;VQD<V]P97)A<VIO;F5R(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,P.3@*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN
M<R(*;7-G<W1R(")+;VQO;FYE86YV:7-N:6YG(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,38V"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C(T.0HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HS,3@*;7-G:60@(D%T=&%C:&5D(&ES(&%N
M(&E#86QE;F1A<B!F:6QE(')E<&QY('1O(&$@<F5Q=65S="!Y;W4@<V5N="(*
M;7-G<W1R(")6961L86=T(&D@<W9A<F5T(&5R(&5N(&E#86QE;F1A<B!F:6P@
M9F]R(&5N(&9O<F5S</AR<V5L(&1U('-E;F1T92(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-S4*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT(&=R;W5P+B(*;7-G<W1R(")&;W)S^&MT92#E('-L971T92!E;B!G<G5P
M<&4@<V]M(&EK:V4@96MS:7-T97)E<BXB"@HC.B!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C,X"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES
M=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")&;W)S^&MT92#E('-L971T92!E
M;B!R971T:6=H970@<V]M(&EK:V4@96MS:7-T97)E<BXB"@HC.B!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HY.`IM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N
M+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(D9O<G/X:W1E(.4@<F5D
M:6=E<F4@96X@<F5T=&EG:&5T('-O;2!I:VME(&5K<VES=&5R97(N(@H*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O
M(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(D9O<G/X:W1E
M(.4@<F5D:6=E<F4@96X@9&5L="!R97-S=7)S('-O;2!I:VME(&5K<VES=&5R
M97(N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-3<W"FUS9VED(")!='1E;F1E97,B"FUS9W-T<B`B1&5L=&%G97)E(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#8*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B071T<FEB
M=70B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@Q
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3@*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B
M075G=7-T(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P
M"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(MAS=&5R<FEK92(*"B,Z(&QI8B](
M;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,38S"FUS9VED(")!=71H7V-Y<G-Q;#H@
M4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!
M=71H7V-Y<G-Q;#H@2V%N(&EK:V4@9FEN;F4@9&5N(&[X9'9E;F1I9V4@24U!
M4"!U='9I9&5L<V5N+B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ
M,S<*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R
M97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B075T:%]C>7)U<SH@0F%C
M:V5N9"!I;FYE:&%R(&EK:V4@;OAD=F5N9&EG(&9U;FMS:F]N86QI=&5T+B(*
M"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ,C0*;7-G:60@(D%U=&A?
M8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B075T:%]C>7)U<SH@2V%N(&EK:V4@9FEN;F4@9&5N(&[X9'9E;F1I
M9V4@24U!4"!U='9I9&5L<V5N+B(*"B,Z(&QI8B](;W)D92]!=71H+V9T<"YP
M:'`Z-#`*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS
M:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M
M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@HB075T:%]F='`Z($MA;B!I:VME
M(&9I;FYE(&1E;B!N^&1V96YD:6=E($944"!U='9I9&5L<V5N+B!+;VUP:6QE
M<B!02%`@;65D("TM(@HB96YA8FQE+69T<"XB"@HC.B!L:6(O2&]R9&4O075T
M:"]I;6%P+G!H<#HV.`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA<#H@2V%N
M(&EK:V4@9FEN;F4@9&5N(&[X9'9E;F1I9V4@24U!4"!U='9I9&5L<V5N+B(*
M"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C4S"FUS9VED(")!=71H7VMR
M8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]K<F(U.B!+86X@:6MK92!F:6YN92!D96X@;OAD=F5N9&EG92!K
M<F(U('5T=FED96QS96XN(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z
M-C$*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VQD87`Z($MA;B!I:VME(&9I;FYE
M(&1E;B!N^&1V96YD:6=E($Q$05`@=71V:61E;'-E;BXB"@HC.B!L:6(O2&]R
M9&4O075T:"]L9&%P+G!H<#HQ.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T
M:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R(")!=71H7VQD87`Z($MU;FYE(&EK
M:V4@;&5G9V4@=&EL(&)R=6ME<B`E<RX@4V5R=F5R96X@<V$Z("(*"B,Z(&QI
M8B](;W)D92]!=71H+VQD87`N<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R
M(")!=71H7VQD87`Z($MU;FYE(&EK:V4@9FIE<FYE(&)R=6ME<F5N("5S(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,C@Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S(@IM
M<V=S='(@(D%U=&A?;&1A<#H@2W5N;F4@:6MK92!O<'!D871E<F4@8G)U:V5R
M("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'`Z-3`*;7-G:60@(D%U
M=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")!=71H7VUC86PZ($MA;B!I:VME(&9I;FYE(&1E;B!N^&1V96YD
M:6=E($U#04P@=71V:61E;'-E;BXB"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N
M<&AP.C8U"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]S;6)A=71H.B!+
M86X@:6MK92!F:6YN92!D96X@;OAD=F5N9&EG92!S;6)A=71H('5T=FED96QS
M96XN(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R(")!=71E;G1I
M<V5R:6YG(&9E:6QE="(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z-CD@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S
M(@IM<V=S='(@(D%U=&5N=&ES97)I;F<@9F5I;&5T+B`E<R(*"B,Z(&QI8B](
M;W)D92]!=71H+W)A9&EU<RYP:'`Z,3@Q"FUS9VED(")!=71H96YT:6-A=&EO
M;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R(")!=71E;G1I
M<V5R:6YG(&YE:W1E="!A=B!2041)55,@=&IE;F5R+B(*"B,Z(&QI8B]61E,O
M9G1P+G!H<#HX,#`*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V
M97(@9F%I;&5D+B(*;7-G<W1R(")!=71E;G1I<V5R:6YG(&UO="!&5%`@=&IE
M;F5R96X@9F5I;&5T+B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M.#,*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(E1I;&=J96YG
M96QI9V4@9F5L=#HB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HV,30*;7-G:60@(D%W86ET:6YG(%)E<W!O;G-E(@IM<V=S='(@
M(E9E;G1E<B!PY2!S=F%R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC
M=7-E<R(*;7-G<W1R(")"3T9(($5X8W5S97,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K
M9W)O=6YD(@IM<V=S='(@(D)A:V=R=6YN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#
M;VQO<B(*;7-G<W1R(")"86MG<G5N;G-F87)G92(*"B,Z(&QI8B](;W)D92]!
M=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N
M(@IM<V=S='(@(D9E:6P@:V5R8F5R;W,@<&%S<V]R9"XB"@HC.B!L:6(O2&]R
M9&4O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N
M86UE+B(*;7-G<W1R(")&96EL(&ME<F)E<F]S(&)R=6ME<FYA=FXN(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I
M9"`B0F%H86UA<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AR86EN(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<S"FUS9VED(")"86QT:6,@
M*$E33RTX.#4Y+3$S*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"86YG;&%D97-H(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C$*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR-3DS"FUS9VED(")"87)E(@IM<V=S='(@(D)L86YK
M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*
M;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("<E<R<@;F]T(&9O=6YD
M+B(*;7-G<W1R(")"87-E:V%T86QO9R!F;W(@9W)A9FEK:R`G)7,G(&)L92!I
M:VME(&9U;FYE="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(D=R
M=6YN;&EN:F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#D@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8T"FUS9VED(")"96QA<G5S(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HS-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E
M;&=I=6TB"FUS9W-T<B`B0F5L:6=A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C4P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0F5L:7IE(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)E;FEN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HT,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E<FUU9&$B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0V(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV-`IM<V=I9"`B0FAU=&%N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$T"FUS9VED(")":7)T:&1A>2(*
M;7-G<W1R(")"=7)S9&%G(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I
M;VXN<&AP.C,R-@HC+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@
M;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B0FQO
M:VL@7"(E<UPB(&%V('!R;V=R86UM970@7"(E<UPB(&)L92!I:VME(&9U;FYE
M="XB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.#D*;7-G:60@
M(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(D)L;VMK(&EN;G-T:6QL:6YG97(B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L
M;V-K(%1Y<&4B"FUS9W-T<B`B0FQO:VL@='EP92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G
M<W1R(")&970B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8S"FUS9VED(")";VQI=FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#8*;7-G:60@(D)O;VMM87)K<R(*;7-G
M<W1R(")";VMM97)K97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D97(B"FUS9W-T<B`B
M4F%M;64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R(")286UM
M971Y:VME;'-E.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B4F%M
M;65R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,0IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS
M9W-T<B`B0F5G9V4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8T"FUS9VED(")";W1S=V%N82(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*
M;7-G:60@(D)O='1O;2(*;7-G<W1R(")"=6YN(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C0W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS.0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0F]U=F5T($ES
M;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8S"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G
M:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C0R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S
M"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R("(B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D)U:6QD
M:6YG($U/(&9I;&5S(&9O<B!M;V1U;&4@)7,N+BXB"FUS9W-T<B`B(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C8W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")"
M=6EL9&EN9R!L;V-A;&4@)7,N+BX@(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HS-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)U;&=A
M<FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`B
M4'5N:W1L:7-T92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C(*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,SD@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C0U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS
M9VED(")"=7)U;F1I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS.3<*;7-G:60@(D--4R(*;7-G<W1R(")#35,B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S
M='(@(D-20R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C(Q"FUS
M9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R(")#4DP@1&ES
M=')I8G5S:F]N<W!U;FMT97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E
M<G1I97,N+BXB"FUS9W-T<B`B16=E;G-K87!E<B!F;W(@8U]E;&QE+BXN(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30S"FUS9VED(")#86QE;F1A<B(*;7-G
M<W1R(")+86QE;F1E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,#D*;7-G:60@(D-A;&TB"FUS9W-T<B`B4W1I;&QE(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$R."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(D-A
M;6)O9&EA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#86X@
M;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")+86X@:6MK92!N=6QL<W1I;&QE
M('!A<W-O<F0@875T;VUA=&ES:RP@:V]N=&%K="!D:6X@861M:6YI<W1R871O
M<BXB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,C0Q(&QI8B](;W)D
M92]!=71H+V-Y<G-Q;"YP:'`Z,S$R"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(DMA;B!I
M:VME(&MO8FQE('1I;"!)34%0('1J96YE<F5N.B`E<R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HU,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-A;F%D
M82(*;7-G<W1R(")+86YA9&$B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M
M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T
M92YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$W"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3<*;7-G:60@(D-A
M;F-E;"(*;7-G<W1R(")!=F)R>70B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM
M<V=S='(@(D%V8G)Y="!P<F]B;&5M<F%P<&]R="(*"B,Z(&QI8B]61E,O9G1P
M+G!H<#HR-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EK:V4@<VQE='1E(&9I;&5N(%PB
M)7-<(BXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HT-PHC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDO8V]P>2YP:'`Z-3,*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M
M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B2V%N(&EK:V4@9FEN;F4@96X@
M=&5M<"UK871A;&]G+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HY-PIM
M<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R
M86UE=&5R+B(*;7-G<W1R(")+86X@:6MK92!F;W)T<V5T=&4@=71E;B`G=&%R
M9V5T1FEL92<@<&%R86UE=&5R+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR-C4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@
M7"(E<UPB+B(*;7-G<W1R(")+86X@:6MK92!S;&5T=&4@:V%T86QO9V5N(%PB
M)7-<(BXB"@HC.B!L:6(O2&]R9&4O1&%T851R964N<&AP.C$Q,B!L:6(O2&]R
M9&4O1&%T851R964O<W%L+G!H<#HU-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(DMA
M;B!I:VME('-L971T92P@)60@8F%R;B!E:W-I<W1E<F5R+B(*"B,Z(&QI8B](
M;W)D92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B(@HB0V%N;F]T(')E
M;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R
M(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@(B(*
M(DMA;B!I:VME(&5N9')E(')E:VME9OAL9V5N+"!A;G1A;&QE="!O<'!F^')I
M;F=E<B!V86QG="!F;W(@;VUS;W)T97)I;F<@(@HB<W1E;6UE<B!I:VME(&UE
M9"!A;G1A;&QE="!L86=R961E(&]P<&;X<FEN9V5R+B(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$X"FUS9VED(")#86YN;W0@<F]U
M=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R(")+86X@
M:6MK92!S96YD92!M96QD:6YG96X@=&EL(&1E="!S<&5S:69I<V5R=&4@;G5M
M;65R970N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8U(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV.0IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"FUS
M9VED(")#87!T:6]N(@IM<V=S='(@(E5T9')A9R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,`IM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM
M<V=S='(@(DMA=&5G;W)I97(@;V<@971I:V5T=&5R(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$S-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(D-A>6UA
M;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3DW"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@(DUO
M8FEL=&5L969O;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G
M<W1R(")%9V5N<VMA<&5R(&9O<B!C96QL92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I
M;F<Z(@IM<V=S='(@(DQU9G0@<G5N9'0@:6YN:&]L9"!A=B!C96QL93HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B16=E;G-K87!E
M<B!F;W(@8V5L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("),
M=69T(')U;F1T(&-E;&QE;CHB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(V
M-@IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(DUO8FEL=&5L969O;B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<T"FUS9VED(")#96QT:6,@*$E33RTX
M.#4Y+3$T*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T
M<B`B4V5N=&5R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV-@IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<U"FUS9VED(")#
M96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<R,PIM<V=I9"`B0V5R=&EF:6-A
M=&4@1&5T86EL<R(*;7-G<W1R(")$971A;&IE<B!F;W(@<V5R=&EF:6MA="(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C(P"FUS9VED(")#97)T
M:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R(")2971T;FEN9W-L:6YJ97(@9F]R
M('-E<G1I9FEK870B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(Q(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D-H860B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3DV"FUS9VED(")#
M:&%I<B!097)S;VXB"FUS9W-T<B`B3W)D<W1Y<F5R(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHY-PIM<V=I9"`B0VAA;F=E(@IM<V=S='(@(D5N9')E(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA
M;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D
M(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@HB16YD
M<F4@;F%V;B!O9R!A9')E<W-E('-O;2!M;W1T86ME<F4@<V5R(&[E<B!D92!L
M97-E<B!O9R!S=F%R97(@<.4@<&]S=&5N(&1I;BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W"FUS9VED(")#
M:&%R(@IM<V=S='(@(E1E9VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK
M+BXN(@IM<V=S='(@(E-J96M?:R!L:6YK+BXN(@H*(SH@=&5M<&QA=&5S+VUA
M:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHQ,PIM<V=I9"`B0VAE8VL@=&AE
M(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M
M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B5F5L9R!D92!O<&5R87-J;VYE;F4@
M9'4@=FEL('5T9OAR92!NY2XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#:&EL92(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C4T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#:&EN82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W-@IM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS9VED(")#:&EN
M97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O075T:"]3:6=N=7`N<&AP.C(X,@IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O
M<F0B"FUS9W-T<B`B5F5L9R!E='0@<&%S<V]R9"(*"B,Z(&QI8B](;W)D92]!
M=71H+U-I9VYU<"YP:'`Z,C@Q"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*
M;7-G<W1R(")696QG(&5T="!B<G5K97)N879N(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#4R"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C8R-@IM<V=I9"`B0VAO;W-E(&%N(&%C
M=&EO;CHB"FUS9W-T<B`B5F5L9R!H86YD;&EN9SHB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C@X"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@
M9&%T97,Z(@IM<V=S='(@(E9E;&<@:'9O<F1A;B!D=2!V:6P@=FES92!D871O
M97(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H
M9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@(E9E;&<@<W1I;"!PY2!L:7-T
M971Y<&4@*&9O<B!N=6UM97)E<G1E(&QI<W1E<BDB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#:')I<W1M
M87,@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,N<&AP.C8U-2!L:6(O
M3F5T+U--4RYP:'`Z,S$Q"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E
M9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R(")+;&%S<V5D969I
M;FES:F]N(&9O<B`E<R!B;&4@:6MK92!F=6YN970N(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C@U-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A;FEN9R!U
M<"!03R!F:6QE<R!F;W(@;6]D=6QE("5S+BXN(@IM<V=S='(@(B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HX-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE
M86YI;F<@=7`@;&]C86QE("5S+BXN("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S(X"FUS9VED(")#;&5A<B(*;7-G<W1R
M(")+;&%R="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T<B`B
M1FIE<FX@35-/9F9I8V4@=&%G<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V-L96%R+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U
M<V5R.B`E<R(*;7-G<W1R(")&:F5R;B!B<G5K97(Z("5S(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$V"FUS9VED(")#;&5A<B!U<V5R
M(@IM<V=S='(@(D9J97)N(&)R=6ME<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C,W"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T
M<B`B1FIE<FX@8G)U:V5R9&%T82(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]N;W1I8V5?8F]T=&]M+FEN8SHV"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU
M92(*;7-G<W1R(")+;&EK:R!F;W(@Y2!F;W)T<V5T=&4B"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-@IM<V=I9"`B0VQI8VMA=&5L
M;"!V:6$@2%144"(*;7-G<W1R(")#;&EC:V%T96QL('9I82!(5%10(@H*(SH@
M<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B3'5K:R!V
M:6YD=2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0R"FUS9VED(")#;&]U
M9',B"FUS9W-T<B`B4VMY97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S(Y"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B4VMY970B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C4V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8U"FUS9VED
M(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C0*;7-G:60@(D-O;&QA<'-E(%-I
M9&5B87(B"FUS9W-T<B`B4VSE('-A;6UE;B!S:61E;&EN:F5N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM
M<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B4V%M;65N<VSE='0@
M<F%M;64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8X"FUS9VED(")#;VQO;6)I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM
M<V=I9"`B0V]L;W(B"FUS9W-T<B`B1F%R9V4B"@HC.B!L:6(O2&]R9&4O0FQO
M8VLO0V]L;&5C=&EO;BYP:'`Z,CDW(&QI8B](;W)D92]";&]C:R]#;VQL96-T
M:6]N+G!H<#HR.3@*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0W,B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4Q"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4R"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8X"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Y"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@U"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@V"FUS
M9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B1F%R9V5V96QG97(B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C@S-0IM<V=I9"`B0V]L;W5R('-E;&5C=&EO
M;B(*;7-G<W1R(")&87)G979A;&<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P,PHC+"!F=7IZ>0IM<V=I9"`B0V]L<SHB
M"FUS9W-T<B`B2V]L;VYN97(Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y
M,S`*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B2V]L;VYN92UT:71L
M97(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y"FUS9VED(")#
M;VUI8W,B"FUS9W-T<B`B5&5G;F5S97)I97(B"@HC.B!A9&UI;B]C;61S:&5L
M;"YP:'`Z,C4*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B2V]M;6%N9&\B"@HC
M.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB
M"FUS9W-T<B`B2V]M;6%N9&]V:6YD=2(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HS.`IM<V=I9"`B0V]M;6%N9"!O<'1I;VYS.B(*;7-G<W1R(")686QG(&9O
M<B!K;VUM86YD;SHB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.3<*;7-G:60@
M(D-O;6UA;F1S.B(*;7-G<W1R(")+;VUM86YD;V5R.B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C,Y.0IM<V=I9"`B0V]M;65N="(*;7-G<W1R(")+
M;VUM96YT87(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.3DU"FUS9VED(")#
M;VUM:71T:6YG.B(*;7-G<W1R(")3:F5K:R!I;FXZ(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU.3`*;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S
M='(@(E9A;FQI9R!N879N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#(*;7-G:60@
M(D-O;7!A;GDB"FUS9W-T<B`B1FER;6$B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HV.3<*;7-G:60@(D-O;7!L971E9"(*;7-G
M<W1R(")&97)D:6<B"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS
M+G!H<#HX,2!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HX-PHC
M.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HY-R!L:6(O2&]R
M9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]M<&]S92!-97-S86=E("@E<RDB"FUS9W-T<B`B4VMR:78@;65L
M9&EN9R`H)7,I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED
M(")#;VUP=71E<G,B"FUS9W-T<B`B1&%T86UA<VMI;F5R(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-#<*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B
M5FEL:^5R(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.#D*;7-G:60@(D-O
M;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B1F]R<VMJ96QL97(@
M:2!I;FYS=&EL;&EN9V5N92(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M,C4*;7-G:60@(D-O;F9I9W5R871I;VX@;F5E9',@=7!D871I;F<N(@IM<V=S
M='(@(DEN;G-T:6QL:6YG97(@8F5H^'9E<B!O<'!D871E<FEN9RXB"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]N9FEG=7)E("5S(@IM<V=S='(@(DMO;F9I9W5R97(@)7,B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,W"FUS9VED(")#;VYF:7)M
M(%!A<W-W;W)D(@IM<V=S='(@(D)E:W)E9G0@<&%S<V]R9"(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HU-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O
M;F=O(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!2
M97!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C(P-B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S$Y"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`B
M5&EL:V]B;&EN9R!M:7-L>6MT97,N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C(P-B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S$Y"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(E1I
M;&MO8FQI;F<@;6ES;'EK=&5S.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HW.3,*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B2V]B;&EN9V5N('1I;"!D96X@;V9F
M96YT;&EG92!N^&MK96QT:F5N97)E;B!F96EL970N(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z-SDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE
M8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N
M.B`E<R`H)7,I(@IM<V=S='(@(DMO8FQI;F=E;B!T:6P@9&5N(&]F9F5N=&QI
M9V4@;OAK:V5L=&IE;F5R96X@9F5I;&5T+B#%<G-A:SH@)7,@*"5S*2(*"B,Z
M(&QI8B]61E,O9G1P+G!H<#HW.30*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10
M('-E<G9E<B!F86EL960N(@IM<V=S='(@(DMO8FQI;F=E;B!T:6P@1E10('1J
M96YE<F5N(&UI<VQY:W1E<RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C4V"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL
M>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B2V]N=&%K
M=&5N92!B;&4@;&%G="!T:6P@861R97-S96)O:V5N(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C,*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z
M-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@)R5S)R(*;7-G
M<W1R("));FYH;VQD(&D@)R5S)R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C(Y"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(")&;W)T<V5T="(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*
M;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R(")#;V]K:64B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B2V]P:65R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B
M0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B2V]P:65R('9A;&=T(&]M<N5D92(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#<R"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O<'EI;F<@)7,@=&\@)7,B"FUS9W-T<B`B2V]P:65R97(@)7,@=&EL
M("5S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8S(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV.`IM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C8S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;W1E
M(&0G279O:7)E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N
M(@IM<V=S='(@(DMU;FYE(&EK:V4@4$=0+6MR>7!T97)E(&UE;&1I;F<B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#4U"FUS9VED(")#;W5L9"!N
M;W0@4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`B2W5N;F4@:6MK92!01U`M
M<VEG;F5R92!M96QD:6YG(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HT,3$*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E
M+B(*;7-G<W1R(")+=6YN92!I:VME(&MR>7!T97)E(&UE;&1I;F=E;B!M960@
M4R]-24U%+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-#@U"FUS
M9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B
M2W5N;F4@:6MK92!S:6=N97)E(&UE;&1I;F=E;B!M960@4R]-24U%+B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R
M(")+=6YN92!I:VME(&QE9V=E('1I;"!K;VYT86MT.B`E<R(*"B,Z(&QI8B](
M;W)D92]!=71H+VQD87`N<&AP.C$Q,PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@
M=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(E1I;&MO8FQI;F<@=&EL($Q$05`M
M<V5R=F5R(&9E:6QE="XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,34T(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E
M+B`E<R(*;7-G<W1R(")+=6YN92!I:VME('-J96MK92!T:6QG:F5N9V5L:6<@
M:W)E9&ET="X@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R
M("<E<R<@=7-I;F<@1E10.B`E<R(*;7-G<W1R(")+;&%R=&4@:6MK92#E(&MO
M8FQE('1I;"!T:F5N97)E;B`G)7,G('9E9"!B<G5K(&%V($944#H@)7,B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`W-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@8V]P>2`E<R!T;R`E<R(*;7-G<W1R(")+=6YN92!I:VME
M(&MO<&EE<F4@)7,@=&EL("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C,R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")+=6YN92!I
M:VME(&QA9V4@9&ES=')I8G5S:F]N<VQI<W1E+B`E<R(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HV.#$@<&\O=')A;G-L871I;VXN<&AP.C$P-C4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!L;V-A;&4@9&ER96-T
M;W)Y(&9O<B!L;V-A;&4@)7,Z(@IM<V=S='(@(DMU;FYE(&EK:V4@;W!P<F5T
M=&4@;&]C86QE(&MA=&%L;V<@9F]R(&QO8V%L92`E<SHB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HQ,3(V"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP
M="!01U`@9&%T82XB"FUS9W-T<B`B2W5N;F4@:6MK92!D96MR>7!T97)E(%!'
M4"!M96QD:6YG+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-30P
M"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T
M<B`B2W5N;F4@:6MK92!D96MR>7!T97)E(%,O34E-12!M96QD:6YG+B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G
M<W1R(")+;&%R=&4@:6MK92#E('-L971T92!K;VYT86MT+B`E<R(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-C4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,B"FUS9W-T<B`B2VQA<G1E(&EK:V4@Y2!S;&5T=&4@9&ES=')I8G5S:F]N
M<VQI<W1E+B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,W"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@)R5S)RXB"FUS9W-T<B`B2W5N;F4@:6MK92!S;&5T=&4@
M<V5T=7`@;W!P9W)A9&5R:6YG<W-C<FEP="`G)7,G+B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z,SDY(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.CDU.0IM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT
M)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(DMU;FYE(&EK:V4@9FEN;F4@
M;6]T=&%K97)S(&4M<&]S="!A9')E<W-E+B(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HR.#@*;7-G:60@(D-O=6QD(&YO="!F971C:"!C
M;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(DMU;FYE(&EK:V4@:&5N
M=&4@=70@:&5L92!A9')E<W-E8F]K96XN(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4Q,`IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O
M;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")+=6YN92!I:VME
M('5T(&AE;&4@9&ES=')I8G5S:F]N<VQI<W1E;BXB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#8Q"FUS9VED(")#;W5L9"!N;W0@9F5T
M8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*
M;7-G<W1R(")+=6YN92!I:VME(&AE;G1E('5T(&AE;&4@;&ES=&5N(&UE9"!D
M:7-T<FEB=7-J;VYS;&ES=&5R+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2YP:'`Z-CD*(SH@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDN<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y("<E<R<N(@IM<V=S='(@(DMU;FYE
M(&EK:V4@;&%S=&4@:6YN('-T<F%T96=I("<E<R<N(@H*(SH@;&EB+U9&4R])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$Q"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP
M.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B`G)7,G
M+B(*;7-G<W1R(")+=6YN92!I:VME(&]P<')E='1E(&MA=&%L;V=E;B`G)7,G
M+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<R,`IM<V=I9"`B0V]U
M;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB
M"FUS9W-T<B`B2W5N;F4@:6MK92!H96YT92!U="!O9F9E;G1L:6<@;OAK:V5L
M(&9R82!N^&MK96QT:F5N97)E;BXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-S`R(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S4T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S
M+B(*;7-G<W1R(")+=6YN92!I:VME(.5P;F4@)7,N(@H*(SH@;&EB+U9&4R])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30P"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("<E<R<@9F]R('=R:71I
M;F<N(@IM<V=S='(@(DMU;FYE(&EK:V4@Y7!N92`G)7,G(&9O<B!S:W)I=FEN
M9RXB"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C0Q-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K
M(&UO9'5L92`E<R(*;7-G<W1R(")+86X@:6MK92#E<&YE($UA:6YT96YA;F-E
M7U1A<VLM;6]D=6QE;B`E<R(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`G)7,G+B(*;7-G<W1R(")+=6YN
M92!I:VME(.5P;F4@:V%T86QO9V5N("<E<R<N(@H*(SH@;&EB+U9&4R]/8FIE
M8W0N<&AP.C(W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A
M9"`E<RXB"FUS9W-T<B`B2W5N;F4@:6MK92!L97-E("5S(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R
M97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M
M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U
M(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)+=6YN92!I:VME
M(&YU;&QS=&EL;&4@<&%S<V]R9&5T(&9O<B!D96X@9F]R97-P=7)T92!B<G5K
M97)E;BX@3F]E;B!E;&QE<B!A;&QE("(*(F1E=&%L:F5N92!E<B!U<FEK=&EG
M92X@1F]R<_AK(&EG:F5N(&5L;&5R(&MO;G1A:W0@861M:6YI<W1R871O<F5N
M(&AV:7,@9'4@(@HB=')E;F=E<B!Y='1E<FQI9V5R92!H:F5L<"XB"@HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$X(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS-#D*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,X-B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,SDR"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3@*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B2W5N;F4@
M:6MK92!H96YT92!U="!!0TPB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R
M971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@
M:&5N=&4@=70@861R97-S96)O:RX@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3`Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B
M2W5N;F4@:6MK92!H96YT92!U="!D:7-T<FEB=7-J;VYS;&ES=&4N("5S(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0U,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N
M(&QI<W1S+B`E<R(*;7-G<W1R(")+=6YN92!I:VME(&AE;G1E('5T(&1I<W1R
M:6)U<VIO;G-L:7-T92X@)7,B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,C`V(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR
M,C8*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(S,`IM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*
M;7-G<W1R(")+=6YN92!I:VME(&AE;G1E('5T(&EN9F]R;6%S:F]N(&]M('1J
M96YE<F5N<R!F=6YK<VIO;F%L:71E=&5R(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")+=6YN92!I:VME(')E=F5R=&5R92!K;VYF:6=U<F%S
M:F]N96YE+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R;61I<B`G)7,G+B(*;7-G<W1R(")+=6YN92!I:VME(&9J97)N92!K871A
M;&]G96X@)R5S)RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R(")+=6YN92!I:VME(&QA9W)E("5S(&MO;F9I9W5R
M87-J;VXN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C4W"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A
M8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(DMU;FYE(&EK:V4@;&%G<F4@
M96X@8F%C:W5P(&MO;F9I9W5R87-J;VXN(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E
M(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B2W5N;F4@:6MK
M92!L86=R92!E;B!B86-K=7`@8V]N9FEG=7)A<VIO;CH@)7,B"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HY,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@)R5S)RXB
M"FUS9W-T<B`B2W5N;F4@:6MK92!L86=R92!S971U<"!O<'!G<F%D97)I;F=S
M+7-C<FEP=&5T('1I;#H@)R5S)RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H
M92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(")+=6YN
M92!I:VME(&QA9W)E(&)A8VMU<"!K;VYF:6=U<F%S:F]N<V9I;&5N("5S+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL
M92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N
M<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL
M>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@HB2W5N;F4@:6MK
M92!L86=R92!K;VYF:6=U<F%S:F]N<V9I;&5N("5S+B!$=2!K86X@96YT96X@
M8F5N>71T92!D96<@878@96X@878@(@HB;75L:6=H971E;F4@9F]R(.4@;&%G
M<F4@9&%T82!T:6QB86ME('1I;"`E<R!E;&QE<B!K;W!I97)E(&MO9&5N('5N
M9&5R("(*(FUA;G5E;'0@=&EL("5S+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD
M87`N<&AP.C$R,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S
M97)V97(N(@IM<V=S='(@(DMU;FYE(&EK:V4@=71F^')E('/X:R!PY2!,1$%0
M('1J96YE<F5N+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C@W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!U;FQI;FL@)R5S)RXB"FUS9W-T<B`B2W5N;F4@:6MK92!F:F5R;F4@
M)R5S)RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C(Q
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C
M="X@)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!O<'!D871E<F4@:V]N=&%K="X@
M)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#`Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@;W!P9&%T97)E(&1I
M<W1R:6)U<VIO;G-L:7-T96XN("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C
M;VYF:6=U<F%T:6]N(&9O<B`G)7,G.B`E<R(*;7-G<W1R(")+=6YN92!I:VME
M('-K<FEV92!K;VYF:6=U<F%S:F]N(&9O<B`G)7,G.B`E<R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-38*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE
M($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P
M96XN(@IM<V=S='(@(DMU;FYE(&EK:V4@9FEN;F4@36]Z:6QL82!3:61E8F%R
M+B!3:F5K:R!A="!D96X@97(@Y7!E;BXB"@HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,34Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M;B=T(&=I=F4@=7-E<B`G)7,G('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T
M:&4@9F]L9&5R("<E<R<Z("5S(@IM<V=S='(@(D)R=6ME<F5N("<E<R<@8FQE
M(&=I='0@9OAL9V5N9&4@<F5T=&EG:&5T97(@=&EL(&UA<'!E;B`G)7,G.B`E
M<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#$V"FUS9VED(")#;W5N=&5D
M('1E>'0B"FUS9W-T<B`B5&%L="!T96MS="(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3DS"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(DQA;F0B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<S"FUS9VED(")#;W5R
M<V5S(@IM<V=S='(@(DMU<G-E<B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3<*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,0IM<V=I9"`B0W)E871E
M(@IM<V=S='(@(D]P<')E='0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D-R96%T92!A(&QI
M;FLB"FUS9W-T<B`B3W!P<F5T="!E;B!L:6YK(@H*(SH@=&5M<&QA=&5S+W!R
M969S+VED96YT:71Y<V5L96-T+FEN8SHX.0IM<V=I9"`B0W)E871E(&$@;F5W
M(&]N92(*;7-G<W1R(")/<'!R971T(&5N(&YY(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDU"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E
M<G,B"FUS9W-T<B`B3W!P<F5T="!U;F1E<FUA<'!E<B(*"B,Z(&%D;6EN+W!E
M<FUS+V5D:70N<&AP.C$S-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(R,@IM
M<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R(")2971T:6=H971E
M<B!F;W(@96EE<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C$U"FUS9VED
M(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B2W)E9&ET=&MO<G1N=6UM
M97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX,`IM<V=I9"`B0W)O871I82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#=6)A(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@IM<V=I9"`B0W5R
M<F5N="!0:&%S92(*;7-G<W1R(")':F5L9&5N9&4@9F%S92(*"B,Z(&QI8B]"
M;&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B
M0W5R<F5N="!4:6UE(@IM<V=S='(@(D=J96QD96YD92!T:60B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*
M(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(D=J96QD
M96YD92!54DP@97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED
M(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B1VIE;&1E;F1E(';F<B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S,*;7-G:60@(D-U<G)E
M;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B1VIE;&1E;F1E('5T<VEK=&5R.B`B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,R
M"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(D=J96QD96YD92!S=&EL
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@
M)7,N(@IM<V=S='(@(E1I;'!A<W,@;W!P9V%V97(@<V]M(&MJ^')E<R!V960@
M:6YN;&]G9VEN9R!T:6P@)7,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T
M<B`B2VQI<'`@=70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(DML
M:7!P('5T('9A;&=T(&]M<N5D92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HV-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Y<')U<R(*;7-G<W1R(")+
M>7!R;W,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B0WER
M:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-SD*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")#>7)I
M;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C8X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HV-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B0WIE
M8V@@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0R,R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM
M<V=I9"`B1$0B"FUS9W-T<B`B1$0B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N
M8V4N<&AP.C,X"FUS9VED(")$86EL>2(*;7-G<W1R(")$86=L:6<B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS9VED(")$871A(@IM<V=S
M='(@(D1A=&$B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A
M=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B1&%T851R92!U=&9O<G-K97(B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,X,B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW-PIM<V=I9"`B1&%T92(*;7-G<W1R(")$871O(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@
M(D1A=&4@4F5C96EV960B"FUS9W-T<B`B1&%T;R!-;W1T871T(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(W.38*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM
M<V=S='(@(D1A=&\@=F%L9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-S<*;7-G:60@(D1A>2(*;7-G<W1R(")$86<B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G
M:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(E-L971T(&MO;&]N;F4B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@U(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,C(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB
M97(B"FUS9W-T<B`B1&5S96UB97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED(")$96-I;6%L
M(&YU;6)E<G,B"FUS9W-T<B`B1&5S:6UA;'1A;&PB"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV.#4*;7-G:60@(D1E8VQI;F5D
M(@IM<V=S='(@(D%V<VSE='0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS
M9W-T<B`B4F5D=7-E<B!I;FYR>6MK(@H*(SH@;&EB+W!R969S+G!H<#HQ,#@@
M;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ.3$*;7-G:60@(D1E9F%U;'0B"FUS
M9W-T<B`B4W1A;F1A<F0B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHT-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHX,0IM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R
M(")3=&%N9&%R9"!F87)G92(*"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z
M.3(*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B4W1A;F1A<F1I
M9&5N=&ET970B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,3D@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HR,#0*;7-G:60@(D1E9F%U;'0@4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B4W1A;F1A<F0@<F5T=&EG:&5T97(B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C(P-0IM<V=I9"`B1&5F875L="!P97)M:7-S:6]N
M<R(*;7-G<W1R(")3=&%N9&%R9"!R971T:6=H971E<B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B
M1&5F:6YI<VIO;F5R(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-C0S"FUS9VED(")$96QE9V%T92!P;W-I=&EO;B(*;7-G<W1R
M(")$96QE9V5R('!O<VES:F]N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-CDS"FUS9VED(")$96QE9V%T960B"FUS9W-T<B`B
M1&5L96=E<G0B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<R(&%D;6EN+W!E<FUS
M+V1E;&5T92YP:'`Z-#8@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC.B!L
M:6(O2&]R9&4O4&5R;7,N<&AP.C(Y-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C,R-PHC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,T-R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-S`@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,PHC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q-B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.CDY('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E
M+FEN8SHQ,PHC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM
M<V=I9"`B1&5L971E(@IM<V=S='(@(E-L971T(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HQ.#D@861M:6XO9W)O=7!S+G!H<#HR,3<*;7-G:60@(D1E;&5T92!'
M<F]U<"(*;7-G<W1R(")3;&5T="!G<G5P<&4B"@HC.B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C8P(&QI8B](;W)D92]097)M<R]522YP:'`Z.#0*;7-G:60@
M(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@(E-L971T(')E='1I9VAE="(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY-@IM<V=I9"`B
M1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R(")3;&5T="!O9R!F
M:F5R;B!M96QD:6YG97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE=&4@8V5L;"(*;7-G
M<W1R(")3;&5T="!C96QL92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB
M"FUS9W-T<B`B4VQE='0@:V]L;VYN92(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L
M871E(@IM<V=S='(@(E-L971T(&5K<VES=&5R96YD92!A;'1E<FYA=&EV(&UA
M;"(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3`@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HS,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E
M<FUI<W-I;VYS(&9O<B`G)7,G(@IM<V=S='(@(D9J97)N(')E='1I9VAE=&5N
M92!T:6P@)R5S)R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,S(Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@)R5S
M)R!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B1FIE<FX@<F5T
M=&EG:&5T96YE('1I;"`G)7,G(&]G(&%L;&4@=6YD97(M<F5T=&EG:&5T97(_
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R(")3;&5T="!R860B
M"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS
M9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B4VQE='0@
M=F%L9W0@:61E;G1I=&5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED(")$96QE=&4@=&AE(&-U
M<G)E;G0@8V]L=6UN(@IM<V=S='(@(E-L971T(&=J96QD96YD92!K;VQO;FYE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8R"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S
M='(@(E-L971T(&=J96QD96YD92!R860B"@HC.B!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C0X"FUS9VED(")$96QE=&4@=&AI<R!P97)M:7-S:6]N(&%N9"!A
M;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R(")3;&5T=&4@9&5N;F4@<F5T
M=&EG:&5T96X@;V<@86QL92!U;F1E<BUR971T:6=H971E<C\B"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HS-0HC+"!P:'`M9F]R;6%T"FUS9VED(")$
M96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T("<E<R<N(@IM<V=S='(@(E-L
M971T('-E='5P(&]P<&=R861E<FEN9W,M<V-R:7!T("<E<R<N(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X-2!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C$Y"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C(W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C8Q"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(DQE=F5R:6YG
M<W1I9"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S`*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B1&%N;6%R:R(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8T,@IM<V=I9"`B
M1&5N>2!R97%U97-T(@IM<V=S='(@(D%V<VSE(&9O<F5S</AR<V5L(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#<Q"FUS9VED
M(")$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA=&EO;B(*;7-G
M<W1R(")!=G-LY2!F;W)E<W#X<G-E;"!F;W(@;&5D:6<O;W!P=&%T="UI;F9O
M<FUA<VIO;B(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.CDU('-E<G9I8V5S
M+W!R;V)L96TN<&AP.CDY('-E<G9I8V5S+W!R;V)L96TN<&AP.C$P.0IM<V=I
M9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B0F5S:W)I=B!P<F]B
M;&5M970B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3,S(&QI8B](;W)D92]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4V-0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"FUS9VED(")$97-C
M<FEP=&EO;B(*;7-G<W1R(")"97-K<FEV96QS92(*"B,Z(&QI8B](;W)D92YP
M:'`Z,C`Q"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL
M92DZ(@IM<V=S='(@(D1E=&%L:F5R("AO9W/E(&D@2&]R9&4G<R!L;V=G9FEL
M*3HB"@HC.B!L:6(O2&]R9&4N<&AP.C(P-0IM<V=I9"`B1&5T86EL<R!H879E
M(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B
M1&5T86QJ97(@:&%R(&)L:71T(&QO9V=E="!F;W(@861M:6YI<W1R871O<F5N
M+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.3,*;7-G:60@(D1E
M=F5L;W!M96YT(@IM<V=S='(@(E5T=FEK;&EN9R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C$U"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B1&]G9W!U
M;FMT(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3(*;7-G:60@(D1E=R!0
M;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B1&]G9W!U;FMT(&9O<B!D
M96X@<VES=&4@=&EM96XZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ.3`*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(D1O9V=P=6YK
M=#H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B
M4F5T;FEN9R!F<F$@=F5N<W1R92!M;W0@:/AY<F4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I
M;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R(")2971N:6YG(&9R82!H^'ER92!M
M;W0@=F5N<W1R92(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED
M(")$:7)E8W1O<GDB"FUS9W-T<B`B2V%T86QO9R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-38*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B
M"FUS9W-T<B`B5FES(#(T+71I;65R<R!T:61E<C\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R
M(")6:7-N:6YG<W9A;&<B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@S"FUS
M9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S='(@(E9I<R!F;W)V
M87)S96P@*%1!1BDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@P-@IM<V=I
M9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B5FES;FEN9W-F;W)M870B"@HC
M.B!L:6(O2&]R9&4O34E-12]-1$XN<&AP.C(P,PIM<V=I9"`B1&ES<&]S:71I
M;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(DUE;&1I;F<@;VT@;W)D;FEN9R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*
M;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-#8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS,C<*;7-G:60@
M(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B26MK92!S;&5T="(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HR-`IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY
M(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B26MK92#E<&YE(&UA
M:6YE;F%N8V4N<&AP(&1I<F5K=&4B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I
M;F9O+FEN8SHQ.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ.0IM<V=I
M9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S
M/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R(")+<GES<R!A=B!H
M97(@:'9I<R!D96X@9OAR<W1E(')A9&5N(&EN;F5H;VQD97(@9F5L="UN879N
M970Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW,`IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C<S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW
M,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1&]M:6YI
M8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+T-O
M;G1E;G1S+G!H<#HX-C@*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(DQA<W0@
M;F5D(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@V.`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B
M3&%S="!N960@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34V"FUS
M9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@
M<V-R:7!T+B(*;7-G<W1R("),87-T(&YE9"!G96YE<F5R="!K;VYF:6=U<F%S
M:F]N('-O;2!02%`@<V-R:7!T+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M,#DQ"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R(").961T<F5K:W-L
M:7-T92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U
M9W,B"FUS9W-T<B`B365D:7-I;F5R(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z,SDY"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B12UP;W-T(@H*(SH@
M;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W
M"FUS9VED(")%4E(B"FUS9W-T<B`B15)2(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C<U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B16-U861O<B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(Y-B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]E9&ET+FEN8SHR,@IM<V=I9"`B161I="(*;7-G<W1R(")2961I9V5R(@H*
M(SH@;&EB+TAO<F1E+T)L;V-K+U5)+G!H<#HU,2!T96UP;&%T97,O<&]R=&%L
M+V5D:70N:6YC.C(R"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@(E)E9&EG
M97)E(&)L;VMK(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.#@@861M:6XO9W)O
M=7!S+G!H<#HR,38*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B4F5D:6=E
M<B!'<G5P<&4B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C4Y(&QI8B](
M;W)D92]097)M<R]522YP:'`Z.#,*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*
M;7-G<W1R(")2961I9V5R(')E='1I9VAE=&5R(@H*(SH@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G
M<W1R(")2961I9V5R(')E='1I9VAT97(B"@HC.B!S97)V:6-E<R]S:&%R97,O
M961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES
M<VEO;G,@9F]R("5S(@IM<V=S='(@(E)E9&EG97(@<F5T=&EG:&5T97(@9F]R
M("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z.0IM<V=I9"`B161I
M="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B4F5D:6=E<B!V86QG(&9O<CHB"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M870*
M;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(E)E9&EG
M97(@<F5T=&EG:&5T97(@9F]R("5S(@H*(SH@861M:6XO<&5R;7,O961I="YP
M:'`Z,C`T(&QI8B](;W)D92]097)M<R]522YP:'`Z,C@X"B,L('!H<"UF;W)M
M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("<E<R<B"FUS9W-T<B`B
M4F5D:6=E<B!R971T:6=H971E<B!F;W(@)7,B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R(")/<'!LYG)I
M;F<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C<S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<Q"FUS9VED(")%9WEP="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D5L(%-A;'9A
M9&]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B16QE;65N="XN+B(*;7-G
M<W1R(")%;&5M96YT+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(D5M(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$X-3,@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR,C<*;7-G:60@(D5M86EL(@IM<V=S='(@(D4M<&]S="(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@Y('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHT,`IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R
M(")%+7!O<W1A9')E<W-E(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-#<*
M;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")%
M+7!O<W1A9')E<W-E(&WE('-T96UM92XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3DW,PIM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T
M<B`B12UP;W-T(&UE9"!B96MR969T96QS92(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR.#`*;7-G:60@(D5M;W1I8V]N<R(*;7-G
M<W1R(")&^&QE;'-E<B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$Q"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R(")4;VT@
M;65L9&EN9RXB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ,S$*;7-G
M:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B5&]M="!R97-U;'1A="XB"@HC
M.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ,30*;7-G:60@(D5M<'1Y
M('-E87)C:"!T97)M<R(*;7-G<W1R(")4^&T@<_AK96MR:71E<FEE<B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S(*;7-G:60@(D5N86)L92!I;G-E
M<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_
M(@IM<V=S='(@(D%K=&EV97(@;75L:6=H970@9F]R(.4@<V5T=&4@:6YN(&)I
M;&1E<B!F<F$@9V%L;&5R:65R(&D@=&5K<W1E;C\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3`W"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N
M=&5X="!M96YU/R(*;7-G<W1R(")!:W1I=F5R92!H^'ER96ML:6MK(&UE;GD_
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#0X
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4U,PIM
M<V=I9"`B16YD(@IM<V=S='(@(E-L=71T(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(U.3$@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#`*;7-G:60@(D5N9"!Y
M96%R(@IM<V=S='(@(L5R<W-L=71T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B
M"FUS9W-T<B`B1VKX<B!E9&ET;W)E;B!S=/AR<F4B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C$Q"FUS9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U
M97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O
M(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA
M;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@HB4VMR:78@:6YN(&5T="!S
M:6MK97)H971S<W#X<G-MY6P@<V]M(&1U('9I;"!B;&D@<W!U<G0@;VT@:'9I
M<R!D=2#X;G-K97(@Y2`B"B)N=6QL<W1I;&QE('!A<W-O<F1E="!D:71T+"!F
M+F5K<RX@)VAV82!E<B!N879N970@<.4@:VKF;&5D>7)E="!D:71T/R<Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS
M9W-T<B`B4VMR:78@:6YN(&%D<F5S<V5N('1I;"!B:6QD970@:&5R(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$Q-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M16YT<FEE<SH@)60@=&]T86PL("5D('5P+71O+61A=&4L("5D(&YE=RP@)60@
M8VAA;F=E9"P@)60@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W"FUS9VED(")%<75A=&]R
M:6%L($=U:6YE82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")%<FET<F5A(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S
M+G!H<#HR.0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4Q"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S8@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HW.`IM<V=I9"`B
M17)R;W(B"FUS9W-T<B`B1F5I;"(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C$Y-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HR-S@*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z,S0W"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('-E
M;F1I;F<@<F5P;'DZ("5S+B(*;7-G<W1R(")&96EL('9E9"!S96YD:6YG(&%V
M('-V87(Z("5S(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,30*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T
M<B`B1F5I;"!M960@92UP;W-T(&UE;&1I;F=E;BXB"@HC.B!L:6(O5D93+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R`G)7,G+B(*;7-G<W1R(")&
M96EL('9E9"!S:W)I=FEN9R!T:6P@)R5S)RXB"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z-#$S('!O+W1R86YS;&%T:6]N+G!H<#HU,C(@<&\O=')A;G-L871I
M;VXN<&AP.C$S-3@*(SH@<&\O=')A;G-L871I;VXN<&AP.C$T,3D@<&\O=')A
M;G-L871I;VXN<&AP.C$T.#(*;7-G:60@(D5R<F]R.B`B"FUS9W-T<B`B1F5I
M;#H@(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW,0IM<V=I9"`B17-T;VYI82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<X
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")%=&AI;W!I
M82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G
M:60@(D5T:&YI8R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HU-@IM<V=I9"`B175R;W!E(@IM<V=S='(@(D5U<F]P82(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,CD*;7-G:60@(D5V97)Y(#$U(&UI;G5T
M97,B"FUS9W-T<B`B2'9E<G0@,34N(&UI;G5T="(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-SD*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R
M(")(=F5R="`R+B!M:6YU='0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S(V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S<*;7-G:60@(D5V97)Y(#,P
M('-E8V]N9',B"FUS9W-T<B`B2'9E<G0@,S`N('-E:W5N9"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,C@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X
M,`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(DAV97)T(#4N(&UI
M;G5T="(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z,SD*;7-G:60@
M(D5V97)Y($QO9VEN(@IM<V=S='(@(DAV97(@:6YN;&]G9VEN9R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S`*;7-G:60@(D5V97)Y(&AA;&8@:&]U
M<B(*;7-G<W1R(")(=F5R(&AA;'9T:6UE(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,R-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X"FUS9VED(")%
M=F5R>2!M:6YU=&4B"FUS9W-T<B`B2'9E<G0@;6EN=71T(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C@*;7-G:60@(D5X86UP;&4@=F%L=65S
M.B(*;7-G<W1R(")%:W-E;7!E;'9E<F1I97(Z(@H*(SH@861M:6XO<&AP<VAE
M;&PN<&AP.C<V(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3,V"FUS9VED(")%>&5C=71E(@IM<V=S='(@(DMJ^'(B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,CDY('!O+W1R86YS;&%T:6]N+G!H<#HS,C`@
M<&\O=')A;G-L871I;VXN<&AP.C,V,@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-#0Q('!O+W1R86YS;&%T:6]N+G!H<#HU-#$@<&\O=')A;G-L871I;VXN<&AP
M.C8P,0HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S`R('!O+W1R86YS;&%T:6]N
M+G!H<#HW,S<@<&\O=')A;G-L871I;VXN<&AP.C<Y.`HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z.#<U('!O+W1R86YS;&%T:6]N+G!H<#HY.#D@<&\O=')A;G-L
M871I;VXN<&AP.C$P,3$*;7-G:60@(D5X96-U=&EN9SHB"FUS9W-T<B`B2VKX
M<F5R.B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C,X-@IM<V=I
M9"`B17AP86YD(@IM<V=S='(@(E5T=FED(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]S:61E8F%R+FEN8SHS,0IM<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T
M<B`B571V:60@4VED96)A<B(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N
M<&AP.C$V.0IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(D9O<G9E;G1E
M="`G*2<B"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ-S8*;7-G
M:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB
M"FUS9W-T<B`B1F]R=F5N=&5T(&)L86YK="!O<F0@96QL97(@<75O=&5T('/X
M:V5K<FET97)I92(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C,Y.`IM
M<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(E5T;/AP<V1A=&\B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B17AP;VYE
M;G0B"FUS9W-T<B`B16MS<&]N96YT(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%>'1R86-T:6YG(&9R;VT@)7,N
M+BX@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@
M(D9O<F=R=6YN<V9A<F=E(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W
M,0IM<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R(")/<'!L87-T
M:6YG(&%V('-E='5P('9I82!&5%`B"@HC.B!L:6(O2&]R9&4O4')E9G,O<W%L
M+G!H<#HR-#`*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S
M+B(*;7-G<W1R(")5=&AE;G1I;F<@878@:6YS=&EL;&EN9V5R(&9E:6QE="XB
M"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ,#,*;7-G:60@(D9A:6QE
M9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")4:6QK;V)L
M:6YG('1I;"!,1$%0+71J96YE<B!F96EL970N(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O<VUB+G!H<#HQ,#,*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--
M0B!S97)V97(N(@IM<V=S='(@(E1I;&MO8FQI;F<@=&EL(%--0BUT:F5N97(@
M9F5I;&5T+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HV,S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@
M(D9E:6QE="!V960@:V]P:65R:6YG(&9R82!<(B5S7"(N(@H*(SH@;&EB+U9&
M4R]F='`N<&AP.C8S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@
M8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(D9E:6QE="!V960@:V]P:65R:6YG
M('1I;"!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z.3(*
M;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB
M"FUS9W-T<B`B1F5I;&5T('9E9"!O<'!R971T96QS92!A=B!N>2!305-,(&MO
M8FQI;F<N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C8W,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(D9E
M:6QE="!V960@9FQY='1I;F<@=&EL(%PB)7-<(BXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S,P"FUS9VED(")&86ER(@IM<V=S='(@(E!E
M;G0@=N9R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@T(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW,PIM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S0*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T-,22YP:'`Z,C,U"FUS9VED(")&871A;"!%<G)O<CHB"FUS
M9W-T<B`B1F%T86P@1F5I;#H@(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.3`*;7-G:60@(D9A>"(*;7-G<W1R(")&87@B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<U(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B<G5A<GDB
M"FUS9W-T<B`B1F5B<G5A<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$X
M"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(D;X;&5S('-O;2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.30*;7-G:60@(D9E96QS(&QI
M:V4Z("(*;7-G<W1R(")&^&QE<R!S;VTZ("(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS,S$*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@
M(D;E(&)Y9V5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,S
M,@IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")&Y2!S;OAB>6=E
M<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.3(X"FUS9VED(")&:65L9"!M
M871R:7@B"FUS9W-T<B`B1F5L=&UA=')I<V4B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&:6II(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8S(&QI
M8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I
M;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B06YT86QL(&9I;&5R.B`E<R!F
M:6QE<B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8S(&QI
M8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I
M;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(D%N=&%L;"!F:6QE<CH@)7,@
M9FEL97(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"FUS9VED
M(")&:6QE($UA;F%G97(B"FUS9W-T<B`B1FEL8F5H86YD;&5R(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S`*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#4*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R(")&:6QN879N(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y.#`*;7-G:60@(D9I;&4@<V5L96-T
M:6]N(@IM<V=S='(@(D9I;'9A;&<B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,30X,PIM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B3&%S="!O<'`@9FEL
M97(B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.#<T"FUS9VED(")&:6QE
M('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B3W!P;&%S=&EN9R!A
M=B!F:6QE<B!S=/AT=&5S(&EK:V4N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C@V"FUS9VED(")&:6QT97)S(@IM<V=S='(@(D9I;'1E<B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G
M:60@(D9I;FQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C$W,0IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R(")&^')S=&4@:&%L=FWE
M;F4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN
M<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(D;X<G-T92!K
M=F%R=&WE;F4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C,Y"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B1F%S="!F;W)H;VQD
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Q-`IM
M<V=I9"`B1FQI<"(*;7-G<W1R(")3;G4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*
M;7-G<W1R(")&;'ET(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,S,PIM<V=I9"`B1F]G(@IM<V=S='(@(E3E:V4B"@HC.B!L:6(O5D93+W-Q
M;"YP:'`Z,38S(&QI8B]61E,O;75S<6PN<&AP.C$P.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B36%P
M<&5N("5S(&5K<VES=&5R97(@:6MK92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS
M9W-T<B`B1F]N=&9A<F=E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W
M"FUS9VED(")&;V]D(@IM<V=S='(@(DUA="(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B
M1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T
M<B`B1F]R(&YE='1L97-E<F4@<V]M(&EK:V4@<W3X='1E<B!B:6QD97(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S,@IM<V=I9"`B1F]R96-A<W0@*%1!
M1BDB"FUS9W-T<B`B1F]R=F%R<V5L("A4048I(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C<T"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN
M;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D
M87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E
M<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*(D%N=&%L;"!D86=E
M<G,@9F]R=F%R<V5L("AVYG(@;V)S('#E(&%T(&1E="!R971U<FYE<G1E(&9O
M<G9A<G-L970@:6YN96AO;&1E<B`B"B)BY61E(&1A9R!O9R!N871T.R!E;B!S
M=&]R('9E<F1I(&AE<B!K86X@<F5S=6QT97)E(&D@96X@<W1O<B!B;&]K:RDB
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDU"FUS9VED(")&;W)G
M;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B1VQE;70@<&%S<V]R9&5T/R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S$*;7-G:60@(D9O<FUS
M(@IM<V=S='(@(E-K:F5M865R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(E-K:F5B;F4O;'EK:V4B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP
M92(*;7-G<W1R(")4>7!E('-K:F5B;F4O;'EK:V4B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(E-K:F5B
M;F5R+VQY:VME(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED
M(")&;W)T=6YE<R`R(@IM<V=S='(@(E-K:F5B;F5R+VQY:VME(#(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#$T"FUS9VED(")&;W)U;7,B"FUS
M9W-T<B`B1F]R=6UE<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M-3@*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(E9I9&5R97-E;F1T92(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HQ-#,Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D9O=6YD(&%P<&QI8V%T:6]N<SH@)7,B"FUS9W-T<B`B1F%N="!P<F]G<F%M
M;65N93H@)7,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,30S,PIM<V=I9"`B
M1F]U;F0@9&ER96-T;W)I97,Z(@IM<V=S='(@(D9A;G0@:V%T86QO9V5N93HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P
M"FUS9VED(")&<B(*;7-G<W1R(")&<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@(D9R86UE<R(*
M;7-G<W1R(")286UM97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#<@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R86YC92P@365T
M<F]P;VQI=&%N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C0Q-PIM<V=I9"`B1G)E92]"=7-Y($EN9F]R;6%T
M:6]N(@IM<V=S='(@(DQE9&EG+V]P<'1A='0M:6YF;W)M87-J;VXB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT,C<*;7-G:60@
M(D9R964O0G5S>2!297!L>2(*;7-G<W1R("),961I9R]O<'!T871T('-V87(B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT,C(*
M;7-G:60@(D9R964O0G5S>2!297%U97-T(@IM<V=S='(@(DQE9&EG+V]P<'1A
M='0@9F]R97-P^')S96PB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HR-S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z,S0Q"FUS9VED(")&<F5E+T)U<WD@4F5Q=65S="!297-P;VYS
M92(*;7-G<W1R(")3=F%R('#E(&QE9&EG+V]P<'1A='0@9F]R97-P^')S96PB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C@T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U
M"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C@U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED(")&<F5N
M8V@@4&]L>6YE<VEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B1G)E;F-H(%-O=71H
M97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C<Y"FUS9VED(")&<F]M(@IM<V=S='(@(D9R
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3$*;7-G:60@
M(D9R;VT@=&AE("(*;7-G<W1R(")&<F$@(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z-#@*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS
M9W-T<B`B1G5L;"!B97-K<FEV96QS92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HX,B!L:6(O0FQO8VLO;6]O;BYP:'`Z,3@Q"FUS9VED(")&=6QL($UO;VXB
M"FUS9W-T<B`B1G5L;&WE;F4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C,Y"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B1G5L;'0@
M;F%V;B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV-3<*;7-G:60@(D9U>GIY
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX."!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S0*;7-G:60@(D=A8F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS
M,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B
M1V%L;&5R:2!D=2#X;G-K97(@Y2!H96YT92!B:6QD92!F<F$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(D=A;&QE<FDZ(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.CDV(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HX.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B
M1V%M8FEA(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A
M=&EO;B(*;7-G<W1R(")'96YE<F5R("5S(&MO;F9I9W5R87-J;VXB"@HC.B!T
M96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ,3`*;7-G:60@(D=E
M;F5R871E9"!#;V1E(@IM<V=S='(@(D=E;F5R97)T(&MO9&4B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-#<Y"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R
M871I;F<@<W1A='5S(&9O<B!M;V1U;&4@)7,N+BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDP(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HX.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I
M9"`B1V5O<F=I82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")'97)M86YY(@IM<V=S='(@
M(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S4R"FUS9VED(")'971O<'0@
M17)R;W(Z("(*;7-G<W1R(")'971O<'0@1F5I;#H@(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.CDS(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY
M,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1VAA;F$B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDT(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW-@IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DY"FUS9VED(")':79E;B!.86UE
M(@IM<V=S='(@(D=I='0@3F%V;B(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N
M:6YC.C$V"FUS9VED(")';R(*;7-G<W1R(")';R(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B
M"FUS9W-T<B`B4_AK('#E($=O;V=L92(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,C`*;7-G:60@(D=R87ES8V%L92(*;7-G<W1R
M(")'<N5T;VYE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S<*;7-G:60@(D=R965C92(*;7-G<W1R(")(96QL87,B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B1W)E96L@*$E33RTX
M.#4Y+3<I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R(")'
M<OAN;&%N9"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S4*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HQ-S`*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(D=R=7!P92!A9&UI;FES=')A<VIO;B(*"B,Z(&QI8B](;W)D92]'
M<F]U<"YP:'`Z-3<*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M
M<'1Y(@IM<V=S='(@(D=R=7!P96YA=FX@:V%N(&EK:V4@=N9R92!T;VUM92(*
M"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(P,2!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C(X-0IM<V=I9"`B1W)O=7`@<&5R;6ES<VEO;G,B"FUS9W-T<B`B
M1W)U<'!E<F5T=&EG:&5T97(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ
M-S8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR-3@@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G
M:60@(D=R;W5P<R(*;7-G<W1R(")'<G5P<&5R(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.CDX(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A9&5L;W5P
M92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`S(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5A;2(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3`R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HY.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B
M1W5A=&5M86QA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R
M;7,O961I="YP:'`Z,3(W(&QI8B](;W)D92]097)M<R]522YP:'`Z,C$S"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U97-T(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(E)E='1I9VAE=&5R(&9O<B!G:F5S="(*"B,Z
M(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$R."!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C(Q-`IM<V=I9"`B1W5E<W0@<&5R;6ES<VEO;G,B"FUS9W-T<B`B4F5T
M=&EG:&5T97(@9F]R(&=J97-T(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0S.0IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(D=J97-T96)O:R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*
M;7-G:60@(D=U:6YE82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3`T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(D=U:6YE82U":7-S
M874B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<Y"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,S,0IM<V=I9"`B
M2$@B"FUS9W-T<B`B2$@B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.34U"FUS
M9VED(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN
M(')O=RXB"FUS9W-T<B`B2%1-3$%R96$@;F5K=&5R(.4@<VQE='1E(&1E;B!S
M:7-T92!C96QL96X@:2!E;B!R860N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN
M('1A8FQE+B(*;7-G<W1R(")(5$U,07)E82!N96MT97(@Y2!S;&5T=&4@9&5N
M('-I<W1E(&MO;&]N;F5N(&D@=&%B96QL96XN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W
M(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,07)E82!N96MT97(@Y2!S;&5T=&4@
M9&5N('-I<W1E(')A9&5N(&D@=&%B96QL96XN(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O:'1T<"YP:'`Z,38T"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B2%144"!A=71E;G1I<V5R:6YG(&EK:V4@9G5N
M;F5T+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,0IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z,SDY"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G
M<W1R(")(87-H+6%L9V]R:71M92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,S0*;7-G:60@(DAA>F4B"FUS9W-T<B`B1&ES(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.CDQ-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDR,0IM
M<V=I9"`B2&5A9&5R(@IM<V=S='(@(DAO9&4B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3`W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#,*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAE87)D($ES
M;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX
M+4DI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R(")(
M^'ED92(*"B,Z(&QI8B](;W)D92](96QP+G!H<#HQ-SD@;&EB+TAO<F1E+TAE
M;'`N<&AP.C$X-B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-PHC.B!T96UP
M;&%T97,O:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*;7-G<W1R(")(
M:F5L<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(DAJ96QP
M('1I;"!B<G5K(&%V(&5D:71O<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,S8X"FUS9VED(")(96QP97(B"FUS9W-T<B`B2&IE;'!E<B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HY-0IM<V=I9"`B(@HB2&5L<&5R(&%P<&QI8V%T:6]N
M('1O(&-R96%T92!A;F0@;6%I;G1A:6X@=')A;G-L871I;VYS(&9O<B!T:&4@
M2&]R9&5<;B(*(F9R86UE=V]R:R!A;F0@:71S(&%P<&QI8V%T:6]N<RY<;B(*
M(D9O<B!A;B!I;G1R;V1U8W1I;VX@<F5A9"!T:&4@9FEL92!214%$344@:6X@
M=&AI<R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R(")(86QV:W5L92(*
M"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$W('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI
M;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(DAE<B!E<B!B96=Y;FYE;'-E;B!P
MY2!F:6QE;CHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S<V
M"FUS9VED(")(:6=H(@IM<V=S='(@(DCX>2(*"B,Z(&QI8B](;W)D92](:7-T
M;W)Y+G!H<#HS,C(*;7-G:60@(DAI<W1O<GD@96YT<GD@;F%M97,@;75S="!B
M92!N;VXM96UP='DB"FUS9W-T<B`B2&ES=&]R:65O<'!F^')I;F=E<B!PY2!H
M82!N879N('-O;2!I:VME(&5R('1O;6UE(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN
M8SHT"FUS9VED(")(;U]M92(*;7-G<W1R(")(:F5?;2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$P-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(DAO
M;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92YP:'`Z,30V-@IM<V=I9"`B2&]M92(*;7-G<W1R(")(:F5M(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C4@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-3@*;7-G:60@(DAO;64@061D
M<F5S<R(*;7-G<W1R(")(:F5M;65A9')E<W-E(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ.3,*;7-G:60@(DAO;64@4&AO;F4B"FUS
M9W-T<B`B5&5L969O;B!H:F5M;64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3`X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAO;F1U<F%S(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#8@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW.0IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HV,@IM<V=I9"`B2&]R9&4B"FUS9W-T<B`B
M2&]R9&4B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,Q,`IM<V=I9"`B2&]R
M9&4@=')A;G-L871I;VX@9V5N97)A=&]R(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z-#(P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE
M<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(%5G>6QD:6<@)7,@6$U,
M(&1A=&$@9G5N;F5T(&D@;65L9&EN9R`E<R(*"B,Z(&QI8B](;W)D92]+;VQA
M8BYP:'`Z,C<W"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.
M;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@26YG96X@;65L9&EN9R!P87-S97(@;65D(&]B:F5K=&5T
M("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT,3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O
M=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($EN=&5T
M(&]B:F5K="!A=B!T>7!E;B`E<R!F=6YN970@:2!M96QD:6YG("5S(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C,V"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B
M"FUS9W-T<B`B2&]R9&4O2V]L86(Z($9J97)N970@)7,@7"(E<UPB(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,3@R"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<WEN8VAR;VYI<V5D("5S(%PB
M)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@4WEN:W)O;FES97)T92`E<R!<
M(B5S7"(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R
M9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE
M("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M($EN=&5G<F%S:F]N<VUO=&]R96X@:W)E=F5R(%!(4"`G9&]M>&UL)R!U='9I
M9&5L<V4B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0X,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@
M6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@
M2W5N;F4@:6MK92!O<'!R971T92!N>71T(%A-3"!T<F4@9F]R(&]B:F5K=&5T
M("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C,S"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB
M)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($MU;FYE(&EK:V4@9FIE
M<FYE("5S(%PB)7-<(CH@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0U
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS
M9W-T<B`B2&]R9&4O2V]L86(Z($MU;FYE(&EK:V4@:&5N=&4@34E-12!)1"!F
M;W(@9&5L96X@878@='EP92`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M,3$W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE
M('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O
M2V]L86(Z($MU;FYE(&EK:V4@<WEN:W)O;FES97)E("5S(%PB)7-<(CH@)7,B
M"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$S,3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R
M97,Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!+=6YN92!I:VME('-Y;FMR
M;VYI<V5R92!D96QT92!R97-S=7)S97(Z("5S(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!5
M:VIE;G0@9&5L="!R97-S=7)S(%PB)7-<(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@
M4G5L92(*;7-G<W1R(")(;W)I<V]N=&%L(&QI;FIE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO
M;G1A;"!P861D:6YG(@IM<V=S='(@(DAO<FES;VYT86P@<&%D9&EN9R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G
M:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(DAO<FES;VYT86PZ(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P
M"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A
M*2(*;7-G<W1R(")(=F]R9&%N(&MO;2!D=2!H:70_("A696YN;&EG<W0@<F%P
M<&]R=&5R(2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD
M('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")(=F]R(&UA;F=E(&MO;&]N
M;F5R(/AN<VME<B!D=2#E('-LY2!S86UM96X_(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,C@*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L
M=6UN<RD@87)E('1H97)E/R(*;7-G<W1R(")(=F]R(&UA;F=E(&9E;'1E<B`H
M:V]L;VYN97(I(&5R(&1E=#\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S
M('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")(=F]R(&UA;F=E
M(')A9&5R(/AN<VME<B!D=2#E('-LY2!S86UM96X_(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,C@*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(D9U:W1I
M9VAE="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3<*;7-G
M:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B1G5K=&EG:&5T.B`B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R
M(")(=6UO<FES=&5R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@Q"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ-S8@;&EB+TAO<F1E+T%U=&@O
M8WER<W%L+G!H<#HR,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL
M8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B3W!P<F5T=&5L<V4@
M878@24U!4"!P;W-T8F]K<R!F96EL970Z("5S(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O8WER=7,N<&AP.C(R,"!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(X
M.`HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@
M9F%I;&5D.B`E<R(*;7-G<W1R(")3;&5T=&EN9R!A=B!)34%0('!O<W1B;VMS
M96X@9F5I;&5T.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ
M.#,@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR,S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B3W!P<F5T=&5L<V4@878@:W9O=&4@<.4@24U!4"!P;W-T
M8F]K<R!F96EL970Z("5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,3(*
M;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B25`@061R97-S92(*"B,Z(&QI
M8B](;W)D92]!=71H+VEP8F%S:6,N<&AP.C@R"FUS9VED("))4"!!9&1R97-S
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DE0($%D<F5S<V4@:6MK92!T:6QG
M:F5N9V5L:6<N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:7!B87-I8RYP:'`Z.30*
M;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO
M8VLN(@IM<V=S='(@(DE0($%D<F5S<V4@:6MK92!I;FYE;F9O<B!T:6QA='1E
M($-)1%(@8FQO:VLN(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#0*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T
M<B`B0G)U9&0@<.4@25`@;&]C:V1O=VXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS
M97)T(%)O=R!"969O<F4B"FUS9W-T<B`B4U]E='0@:6YN(&YY(')A9"!F^'(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#,*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,V-@IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R(")+=6X@
M:6MO;F5R(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF
M;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R(")):V]N97(@9F]R
M("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-PIM<V=I9"`B26-O
M;G,@=VET:"!T97AT(@IM<V=S='(@(DEK;VYE<B!M960@=&5K<W0B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@P"FUS9VED("))9&5N=&ET>2=S(&YA
M;64Z(@IM<V=S='(@(DED96YT:71E=&5N<R!N879N.B(*"B,Z(&QI8B](;W)D
M92]-24U%+T-O;G1E;G1S+G!H<#HV,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@
M:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R(")(=FES(&1E;B!I:VME('9I
M<V5S(')I:W1I9RP@)7,@9F]R(.4@Y7!N92!I(&YY='0@=FEN9'4N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T-0IM<V=I9"`B(@HB268@>6]U(&1O
M;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO
M=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!0
M3D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"B)(=FES(&1U(&EK:V4@<V5R
M(&YO96X@:6MO;F5R(&[E<B!D=2!B96YY='1E<B!);G1E<FYE="!%>'!L;W)E
M<BP@:V%N(&1E="`B"B)H96YD92!D=2!T<F5N9V5R(.4@:W)Y<W-E(&%V(&1E
M;FYE(&)O:W-E;B!F;W(@Y2!S:W)U(&%V('1R86YS<&%R96YT(%!.1RXB"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,34X"FUS9VED
M("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H
M92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA
M>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@HB2'9I<R!D=2!S97(@
M9&5N;F4@;65L9&EN9V5N(&UE;B!I;G1E="!B:6QD92P@:V%N(&1E="!H96YD
M92!A="!B:6QD970@9'4@=FEL("(*(FQA<W1E(&]P<"!I:VME(&MA;B!V:7-E
M<R!I(&1I;B!N971T;&5S97(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G92!0
M<F5V:65W.B(*;7-G<W1R(")&;W)HY6YD<W9I<VYI;F<@878@8FEL9&4Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(D)I;&1E861R97-S92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R(")":6QD96%D
M<F5S<V4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB
M"FUS9W-T<B`B0FEL9&4@9G)A(&=A;&QE<FDB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@
M(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B0FEL9&4@9G)A(&=A;&QE
M<FDZ(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-#D*;7-G:60@(DEM86=E
M('5P;&]A9"(*;7-G<W1R(")/<'!L87-T:6YG(&%V(&)I;&1E(@H*(SH@;&EB
M+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R(")"
M:6QD97(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP
M;&%T97,O9&%T82]D871E;6%P+FEN8SHQ,`HC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C4W('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P"B,L
M('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("))
M;7!O<G1E<FEN9RP@<W1E9R`E9"(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M
M87`N:6YC.C(P"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD
M.B`E<R(*;7-G<W1R("));7!O<G1E<G1E(&9E;'0Z("5S(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHW,PIM<V=I9"`B26UP;W)T960@9FEE;&1S
M.B(*;7-G<W1R("));7!O<G1E<G1E(&9E;'0Z(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-S`Q"FUS9VED("));B!0<F]C97-S
M(@IM<V=S='(@(E5N9&5R(&%R8F5I9"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R
M="!2;W<@069T97(B"FUS9W-T<B`B7U-E='0@:6YN(')A9"!E='1E<B(*"B,Z
M(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$T,0IM<V=I9"`B26YC;W)R
M96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R(")&96EL(&AA;F1L:6YG
M<VMO9&4@9VET="XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C4W"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W
M;W)D+B(*;7-G<W1R(")59WEL9&EG(&)R=6ME<FYA=FX@;V<O96QL97(@<&%S
M<V]R9"XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I
M9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S
M+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)&96EL(&)R
M=6ME<FYA=FX@96QL97(@86QT97)N871I=B!A9')E<W-E+B!696YN;&EG<W0@
M9F]R<_AK(&EG:F5N(&5L;&5R("(*(FMO;G1A:W0@<WES=&5M861M:6YI<W1R
M871O<F5N(&1I;B!F;W(@>71T97)L:6=E<F5R92!H:F5L<"XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("))
M;F-R96%S92!);F1E;G0B"FUS9W-T<B`BV&L@:6YN<GEK:R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$P.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B
M26YD:6$B"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,30Q
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("));F1I=FED
M=6%L(%5S97)S(@IM<V=S='(@(DEN9&EV:61U96QL92!B<G5K97)E(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS
M9VED("));F1O;F5S:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-S(*;7-G:60@(DEN9F\B"FUS9W-T<B`B26YF
M;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#D*;7-G:60@(DEN
M9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%S:F]N(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C4X,@HC+"!P:'`M9F]R;6%T"FUS9VED("));FET:6%L:7II
M;F<@;6]D=6QE("5S+BXN("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN
M<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(E-E='0@:6YN(&M?;VQO;FYE
M(&5T=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T
M<B`B4V5T="!I;FX@8FEL9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T
M<B`B4V5T="!I;FX@=&%B96QL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM
M<V=S='(@(E-E='0@:6YN('=E8FQI;FLB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(DEN<V5R
M="!?0V]L=6UN($)E9F]R92(*;7-G<W1R(")3971T(&EN;B!?:V]L;VYN92!F
M^'(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@
M=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(E-E='0@:6YN(&5N(&YY(&MO;&]N
M;F4@971T97(@9&5N(&=J96QD96YD92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T
M(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@
M(E-E='0@:6YN(&5N(&YY(&MO;&]N;F4@9OAR(&1E;B!G:F5L9&5N9&4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E
M;G0@;VYE(@IM<V=S='(@(E-E='0@:6YN(&5N(&YY(')A9"!E='1E<B!D96X@
M9VIE;&1E;F1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E
M9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B4V5T="!I;FX@96X@;GD@
M<F%D(&;X<B!D96X@9VIE;&1E;F1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@
M82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R(")3
M971T(&EN;B!L:6YJ97-K:69T(&5T=&5R(&1E;B!G:F5L9&5N9&4@;F]D96XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE
M(&-U<G)E;G0@;F]D92(*;7-G<W1R(")3971T(&EN;B!L:6YJ97-K:69T(&;X
M<B!D96X@9VIE;&1E;F1E(&YO9&5N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T
M<B`B4V5T="!I;FX@86QT97)N871I=B!M86PB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C(Y"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T
M;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS
M9W-T<B`B4V5T="!I;FX@96X@92UP;W-T(&%D<F5S<V4@9'4@^&YS:V5R(.4@
M;6]T=&$@9&5T(&YY92!P87-S;W)D970@<.4Z(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS
M97)T(&-E;&P@869T97(B"FUS9W-T<B`B4V5T="!I;FX@8V5L;&4@971T97(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B4V5T
M="!I;FX@8V5L;&4@971T97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN
M(&%F=&5R(@IM<V=S='(@(E-E='0@:6YN(&MO;&]N;F4@971T97(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U
M"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R(")3971T(&EN
M;B!K;VQO;FYE(&;X<B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HY,PIM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(E-E='0@
M:6YN(&UE;&1I;F=E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P
M:"!A9G1E<B(*;7-G<W1R(")3971T(&EN;B!L:6YJ97-K:69T(&5T=&5R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0S"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R
M(")3971T(&EN;B!L:6YJ97-K:69T(&;X<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R
M="!R;W<@869T97(B"FUS9W-T<B`B4V5T="!I;FX@<F%D(&5T=&5R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B4V5T="!I;FX@
M<F%D(&;X<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C`*;7-G:60@
M(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q
M=65S=&EO;CHB"FUS9W-T<B`B4V5T="!I;FX@9&5T('#E:W)E=F1E('-V87)E
M="!T:6P@9OAL9V5N9&4@<VEK:V5R:&5T<W-P^')S;>5L.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN
M<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B4V5T="!I;FXO<F5D:6=E<F4@
M8FEL9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@Y"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B4V5T
M="!I;FXO<F5D:6=E<F4@;&EN:R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-C@*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@
M<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(DEK:V4@
M;F]K(&MR961I='0@9F]R(.4@:W5N;F4@<V5N9&4@=&EL(&1I<W1R:6)U<VIO
M;G-L:7-T96XN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8V,`IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B26MK
M92!N;VL@:W)E9&ET="XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`W,`IM
M<V=I9"`B26YT96=E<B(*;7-G<W1R("));G1E9V5R(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Q,C@*(RP@9G5Z>GD*;7-G:60@(DEN=&5G97(@;&ES="(*
M;7-G<W1R("));G1E9V5R(&QI<W1E(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z,C@S"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C,U,@IM<V=I9"`B26YV86QI9"!!8W1I;VX@<V5L
M96-T960@9F]R('1H:7,@8V]M<&]N96YT+B(*;7-G<W1R(")59WEL9&EG(&AA
M;F1L:6YG('9A;&=T(&9O<B!D96YN92!K;VUP;VYE;G1E;BXB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI
M9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B56=Y;&1I9R!5
M1$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R
M(")59WEL9&EG('!R;V=R86TN(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,C$*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S
M='(@(E5G>6QD:6<@8F%T8V@@240B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C`W,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$T,B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C(Q-@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(X,0IM<V=I9"`B26YV
M86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B56=Y;&1I9R!D871A('-E
M;F1T+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y
M"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@
M(E5G>6QD:6<@;6]T=&%K97(@861R97-S92XB"@HC.B!L:6(O2&]R9&4O0V]M
M<')E<W,O9&)X+G!H<#HX-"!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HQ
M,#,*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,C(S"FUS9VED("))
M;G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(E5G>6QD:6<@9FEL9F]R;6%T
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,38*;7-G
M:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(E5G>6QD:6<@;65L9&EN
M9W-T>7!E(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,3(*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@
M(E5G>6QD:6<@96QL97(@;6%N9VQE;F1E(&%P:5]I9"XB"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B26YV86QI9"!O
M<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(E5G>6QD:6<@96QL97(@
M;6%N9VQE;F1E('!A<F%M971E<F4N(@H*(SH@861M:6XO<&5R;7,O861D8VAI
M;&0N<&AP.C0S"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*
M;7-G<W1R(")59WEL9&EG92!R971T:6=H971E<BXB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B26YV86QI9"!P<F]T
M;V-O;"XB"FUS9W-T<B`B56=Y;&1I9R!P<F]T;VMO;&PN(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.CDQ"B,L('!H<"UF;W)M870*;7-G
M:60@(DEN=F%L:60@<F5C:7!I96YT.B`G)7,G(@IM<V=S='(@(E5G>6QD:6<@
M;6]T=&%K97(Z("<E<R<B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$P-S$@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C0X"FUS9VED("));G9A;&ED('-H87)E
M(&]B:F5C="(*;7-G<W1R(")59WEL9&EG(&1E;'0@;V)J96MT(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DEN=F%L
M:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(E5G>6QD:6<@:VEL9&5A9')E
M<W-E(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,C`*
M;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R(")59WEL9&EG
M('5N:6-O9&4@9&%T82XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S(X"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B26YN:&]L9"(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Q,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I
M9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$X(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G
M:60@(DER87$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Q,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F5L86YD(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@
M;V8@36%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS,S4*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(DES
M;VQE<G1E('1O<F1E;BUS=&]R;65R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Q-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<W)A96PB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#D*;7-G:60@
M(DES<W5E<B(*;7-G<W1R(")5=&=I=F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T
M<B`B2W5R<VEV(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@S"FUS9VED("))=&%L>2(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3(S(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@
M(DIA;6%I8V$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,W-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#$Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B2F%N=6%R(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T"FUS
M9VED(")*87!A;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X,PIM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@T"FUS9VED(")*;W)D86XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,"!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T
M<B`B2G5L:2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HS-SD@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS
M9VED(")*=6YE(@IM<V=S='(@(DIU;FDB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y
M(@IM<V=S='(@(DIU<W1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E
M<B(*;7-G<W1R(")-:61T<W1I;&PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PHC+"!F=7IZ>0IM<V=I9"`B
M2G5S=&EF>2!&=6QL(@IM<V=S='(@(D)L;VMK:G5S=&5R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*(RP@
M9G5Z>GD*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R(")696YS=')E:G5S
M=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,38*(RP@9G5Z>GD*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS
M9W-T<B`B2/AY<F5J=7-T97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T
M-@IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B0F5H;VQD92!O<F=I
M;F%L/R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C8@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX-`IM<V=I9"`B2V5N>6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O:W)B-2YP:'`Z.#<*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE
M8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B2V5R8F5R;W,@=&IE;F5R
M96X@879V:7-T92!A=71E;G1I<V5R:6YG96XN(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R(")+
M97)N96P@3GEB96=Y;FYE<F4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HS.3<*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R(").^&MK96QG96YE
M<F5R:6YG(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`P"FUS9VED
M(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B3OAK:V5L(&9I;F=E<G!R:6YT
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,SDX"FUS9VED(")+97D@
M3&5N9W1H(@IM<V=S='(@(D[X:VME;"!L96YG9&4B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HS.3<*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(D[X
M:VME;"!T>7!E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,C(*
M;7-G:60@(DME>2!5<V%G92(*;7-G<W1R(").^&MK96QB<G5K(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S0S"FUS9VED(")+97D@86QR96%D>2!E
M>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(D[X:VME
M;"!E:W-I<W1E<F5R(&%L;&5R961E('#E(&1E;B!O9F9E;G1L:6=E(&[X:VME
M;'1J96YE<F5N+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I
M9"`B2VED<R(*;7-G<W1R(")"87)N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$R.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+:7)I8F%T:2(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,R(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#8*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E
M<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V]R96$L(%)E<'5B;&EC
M(&]F(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS
M9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$S-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W"FUS9VED(")+=7=A
M:70B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@T"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U
M="(*;7-G<W1R(")5=%]S965N9&4B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C<V('!O+W1R86YS;&%T:6]N+G!H<#HV-3<*;7-G:60@(DQA;F=U
M86=E(@IM<V=S='(@(E-P<N5K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$S-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED("),86\@4&5O<&QE)W,@1&5M
M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,3<T"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B4VES=&4@:&%L
M=&EM92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX."!L:6(O0FQO8VLO;6]O
M;BYP:'`Z.3`*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R(")3:7-T92!K
M=F%R=&5R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-#D*;7-G:60@(DQA
M<W0@57!D871E9#HB"FUS9W-T<B`B4VES=&4@;W!P9&%T97)I;F<Z(@H*(SH@
M;&EB+TAO<F1E+T%U=&@N<&AP.C8Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("),
M87-T(&QO9VEN.B`E<R(*;7-G<W1R(")3:7-T92!I;FYL;V=G:6YG.B`E<R(*
M"B,Z(&QI8B](;W)D92]!=71H+G!H<#HV.3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R(")3:7-T92!I;FYL
M;V=G:6YG.B`E<R!F<F$@)7,B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-C@X
M"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R(")3:7-T92!I;FYL
M;V=G:6YG.B!!;&1R:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@
M(DQO=B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(E5T<V5E;F1E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM
M<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R("+8;G-K
M97,@:6YG96X@<F%M;65R(&QA<B!D=2!F96QT970@=N9R92!T;VUT(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS
M9VED("),96)A;F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G
M<W1R(")696YS=')E(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#0*;7-G
M:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(E9E;G-T<F4@:&]D92(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HS,3`P"FUS9VED("),969T('9A;'5E<R(*;7-G
M<W1R(")696YS=')E('9E<F1I97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,30S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQE<V]T:&\B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@Y"FUS9VED("),:6)E<FEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$S,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B3&EB
M>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,30P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI96-H
M=&5N<W1E:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,S-@IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R("),971T
M(&1U<VMR96=N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,S
M-PIM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R("),971T(')E9VXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S,X"FUS9VED("),:6=H="!2
M86EN($5A<FQY(@IM<V=S='(@(DQE='0@9F]R;6ED9&%G<W)E9VXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S,Y"FUS9VED("),:6=H="!2
M86EN($QA=&4B"FUS9W-T<B`B3&5T="!E='1E<FUI9&1A9W-R96=N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,T,`IM<V=I9"`B3&EG:'0@
M4F%I;B!3:&]W97(B"FUS9W-T<B`B3&5T=&4@<F5G;F)Y9V5R(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,T,0IM<V=I9"`B3&EG:'0@4F%I
M;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B3&5T="!R96=N(&UE9"!T;W)D96XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0R"FUS9VED("),
M:6=H="!3;F]W(@IM<V=S='(@(DQE='0@<V[X9F%L;"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS-#,*;7-G:60@(DQI9VAT(%-N;W<@4VAO
M=V5R(@IM<V=S='(@(DQE='1E('-N^&)Y9V5R(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("),:6UE<FEC
M:R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#`R"FUS9VED("),:6YK(@IM
M<V=S='(@(DQI;FLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*
M;7-G<W1R("),:6YK('!E:V5R('1I;#HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3@U.0IM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@
M8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R("),:6YK(&4M
M<&]S="!A9')E<W-E;B!T:6P@)W-K<FEV(&YY)RUS:61E('9E9"!V:7-N:6YG
M(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@Q
M"FUS9VED("),:6YK<R(*;7-G<W1R("),:6YK97(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R("),
M:6YU>"!#;V]K:64B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.#D*;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*
M;7-G<W1R("),:7-T("T@8G)U:V5R96X@:V%N('-E(&UA<'!E;B(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,S@*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM
M<V=S='(@(DQI<W0@9&%T86)A<V5R(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E
M>"YP:'`Z-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B16UN
M97(@:2!(:F5L<"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S<*;7-G:60@
M(DQI<W0@5&%B;&5S(@IM<V=S='(@(DQI<W0@=&%B96QL97(B"@HC.B!L:6(O
M2&]R9&4O34E-12](96%D97)S+G!H<#HV,S<*;7-G:60@(DQI<W0M07)C:&EV
M92(*;7-G<W1R("),:7-T92UA<FMI=B(*"B,Z(&QI8B](;W)D92]-24U%+TAE
M861E<G,N<&AP.C8S,@IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(DQI<W1E
M:&IE;'`B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HV,SD*;7-G
M:60@(DQI<W0M260B"FUS9W-T<B`B3&ES=&4M260B"@HC.B!L:6(O2&]R9&4O
M34E-12](96%D97)S+G!H<#HV,S4*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T
M<B`B16EE<B!A=B!L:7-T92(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N
M<&AP.C8S-@IM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(DQI<W1E+7!O<W0B
M"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HV,S0*;7-G:60@(DQI
M<W0M4W5B<V-R:6)E(@IM<V=S='(@(D%B8F]N97(@<.4@;&ES=&4B"@HC.B!L
M:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HV,S,*;7-G:60@(DQI<W0M56YS
M=6)S8W)I8F4B"FUS9W-T<B`B4W1O<'`@86)B;VYN96UE;G0@<.4@;&ES=&4B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C0*;7-G:60@
M(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(DUU;&EG:&5T
M(&9O<B#E(&QI<W1E(&)R=6ME<F4@97(@9&5A:W1I=F5R="XB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T
M<B`B3&ET=&5R871U<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S$Y"FUS9VED("),;V%D:6YG(&QI
M8G)A<FEE<RXN+B(*;7-G<W1R("),87-T97(@8FEB;&EO=&5K97(N+BXB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6UA9V5S+G!H<#HX-@IM<V=I9"`B
M3&]A9&EN9RXN+B(*;7-G<W1R("),87-T97(N+BXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3<T"FUS9VED("),;V-A;"!T:6UE.B`B"FUS
M9W-T<B`B3&]K86P@=&ED.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M,PIM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(E-P<N5K(&]G('1I
M9"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DU(&QI8B](;W)D
M92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4W,`HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-C`@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z-C,*;7-G:60@(DQO8V%T:6]N(@IM
M<V=S='(@(DQO:V%S:F]N(@H*(SH@;&]G:6XN<&AP.C$U-2!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,38T('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&]G(&EN(@IM<V=S='(@
M(DQO9V<@:6YN(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U
M.`IM<V=I9"`B3&]G(&]U="(*;7-G<W1R("),;V=G('5T(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T
M<B`B26YN;&]G9VEN9W-O<'!G879E<B(*"B,Z(&QI8B](;W)D92]!=71H+G!H
M<#HY-3(*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA
M;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S
M='(@(DQO9VEN(&9E:6QE="!F;W)D:2!B<G5K97)N879N970@96QL97(@<&%S
M<V]R9&5T(&1U('-K<F5V(&EN;B!V87(@9F5I;"XB"@HC.B!L:6(O2&]R9&4O
M075T:"YP:'`Z.30X"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@(DQO
M9VEN(&9E:6QE="XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,V,@IM<V=I
M9"`B3&]N9R!T97AT(@IM<V=S='(@(DQA;F<@=&5K<W0B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS9W-T<B`B2VKF<FQI
M9VAE="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-S0*;7-G
M:60@(DQO=R(*;7-G<W1R("),878B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G
M<F5E:R!L971T97)S(@IM<V=S='(@(E-MY2!G<F5S:V4@8F]K<W1A=F5R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R(")3
M;>4@;&%T:6YS:V4@8F]K<W1A=F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@
M<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,30U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DQU>&5M8F]U<F<B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,T,B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<S
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(DU-(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U-@IM<V=I9"`B34]41"(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z
M,SD*;7-G:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T
M82XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C0P"B,L(&9U>GIY"FUS9VED(")-4T<B"FUS9W-T
M<B`B0U93(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDS"B,L(&9U>GIY"FUS9VED(")-86-A;R(*;7-G<W1R("),;VMA
M<VIO;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY,@IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%D86=A<V-A<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*(RP@9G5Z
M>GD*;7-G:60@(DUA9VEC(@IM<V=S='(@(D4M<&]S="(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HW,0IM<V=I9"`B36%I;"(*;7-G<W1R("));FYB
M;VMS(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q-`IM<V=I9"`B
M36%I;"!!9&UI;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*;7-G:60@(DUA:V4@;&EN
M7VLN+BXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S,S@*
M;7-G:60@(DUA:V4@<W5R92!T:&%T('EO=2!H879E(%!%05(@:6YS=&%L;&5D
M(&%N9"!I;B!Y;W5R(&EN8VQU9&4@<&%T:"XB"FUS9W-T<B`B(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C8W."!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`V,@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B36%K:6YG(&1I<F5C=&]R>2`E
M<R(*;7-G<W1R(")3;W)T97)I;F=S<F5K:V5F^&QG92(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$S.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0HC+"!F=7IZ>0IM
M<V=I9"`B36%L87=I(@IM<V=S='(@(D4M<&]S="(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S
M.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@HC+"!F=7IZ>0IM<V=I
M9"`B36%L87ES:6$B"FUS9W-T<B`B12UP;W-T(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$V-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"B,L(&9U>GIY"FUS9VED
M(")-86QD:79E<R(*;7-G<W1R(")0;W-T(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$U-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS"B,L(&9U>GIY"FUS9VED(")-
M86QI(@IM<V=S='(@(E!O<W0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,38R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.34*(RP@9G5Z>GD*;7-G:60@(DUA;'1A(@IM
M<V=S='(@(D4M<&]S="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,0IM
M<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA
M=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA
M=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-#`*;7-G:60@(DUA
M<#(T(&UA<"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.3<X"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#4U"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W-B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*(RP@9G5Z>GD*;7-G
M:60@(DUA<F-H(@IM<V=S='(@(E/X:R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*(RP@9G5Z>GD*;7-G:60@
M(DUA<F=I;B(*;7-G<W1R(")!9'9A<G-E;"(*"B,Z(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS
M965N(&9L86=S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HY,@IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE
M+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$U,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR"B,L(&9U>GIY
M"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(D]P<&1A=&5R(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT
M"B,L(&9U>GIY"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(D%D=F%R<V5L
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,3$*;7-G:60@(DUA
M=&-H:6YG(&9I96QD<R(*;7-G<W1R(")386US=F%R96YD92!F96QT(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"B,L
M(&9U>GIY"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(D%D=F%R<V5L(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU
M"B,L(&9U>GIY"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B061V87)S96PB
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,R-`IM<V=I
M9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-PHC+"!F=7IZ>0IM<V=I9"`B
M36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(DUE;&1I;F=E
M;B!B;&4@<VQE='1E="XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-`IM
M<V=I9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,CDV"FUS9VED(")-87@@=&5M<"!L87-T
M(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M.#DS(&QI8B](;W)D92]&;W)M+G!H<#HQ,C`Y(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,C,Q"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<X(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT,34*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0HC+"!F=7IZ>0IM<V=I9"`B
M36%Y(@IM<V=S='(@(D1A9VQI9R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*(RP@9G5Z>GD*;7-G:60@(DUA>6]T
M=&4B"FUS9W-T<B`B571S965N9&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(D%V<VSE
M='0B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU
M,S$*;7-G:60@(DUE971I;F<@0V%N8V5L;&%T:6]N(@IM<V=S='(@(DWX=&5A
M=FQY<VYI;F<B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HU,#,*;7-G:60@(DUE971I;F<@26YF;W)M871I;VXB"FUS9W-T<B`B
M3?AT96EN9F]R;6%S:F]N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-3`Y"FUS9VED(")-965T:6YG(%!R;W!O<V%L(@IM<V=S
M='(@(DWX=&5I;FYK86QL96QS92(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C4R-0IM<V=I9"`B365E=&EN9R!297!L>2(*;7-G
M<W1R(")-^'1E<W9A<B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C4Q-`IM<V=I9"`B365E=&EN9R!5<&1A=&4B"FUS9W-T<B`B
M3?AT96]P<&1A=&5R:6YG(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-3$Y"FUS9VED(")-965T:6YG(%5P9&%T92!297%U97-T
M(@IM<V=S='(@(D9O<F5S^')S96P@;VT@;?AT96]P<&1A=&5R:6YG(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ.0HC+"!F=7IZ>0IM
M<V=I9"`B365M8F5R<R(*;7-G<W1R(")-96UO(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,V.`IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R(")-96YY
M;6]D=7,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,`HC+"!F=7IZ>0IM<V=I9"`B365R9V4@8V5L;',B"FUS
M9W-T<B`B365L9&EN9W-F96QT(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C4R
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-97)G:6YG(&%L;"`E<RYP;R!F:6QE
M<R!T;R!T:&4@8V]M<&5N9&EU;2XN+B`B"FUS9W-T<B`B(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C0S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")-97)G:6YG
M(&QO8V%L92`E<RXN+B`B"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C<X.`HC+"!P:'`M9F]R;6%T"FUS9VED(")-97)G:6YG('1H92!03R!F
M:6QE(&9O<B`E<R!T;R!T:&4@8V]M<&5N9&EU;2XN+B`B"FUS9W-T<B`B(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C0R-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")-97)G:6YG('1R86YS;&%T:6]N(&9O<B!M;V1U;&4@)7,N+BXB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T
M=7,N<&AP.C,R"FUS9VED(")-97-S86=E(@IM<V=S='(@(DUE;&1I;F<B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(R-@IM<V=I9"`B(@HB365S
M<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C
M97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Y"B,L
M(&9U>GIY"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(DUE;&1I
M;F=S9F5L="(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M.3$@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8R-@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(S,R!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(V.`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G
M92!T>7!E(@IM<V=S='(@(DUE;&1I;F=S9&%T;R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G
M<W1R(")3=&%R="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*(RP@9G5Z
M>GD*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(D1E="!E<B!I;F=E;B!M96QD:6YG97(@:2!D96YN92!P;W-T8F]K<V5N+B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$P"B,L(&9U>GIY"FUS9VED("(B
M"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E
M;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")$971A
M;&IE<B!H87(@8FQI='0@;&]G9V5T(&9O<B!A9&UI;FES=')A=&]R96XN(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-S`@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(DUE=&AO
M9"(*;7-G<W1R("),879E<W0B"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP
M:'`Z.#(@;&EB+TAO<F1E+U)00R]S;V%P+G!H<#HQ,3<*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(DUE=&AO9"`G)7,G(&ES(&YO="!D969I;F5D(@IM
M<V=S='(@(DUA<'!E8G)U:R!E<B!I:VME('1I;&=J96YG96QI9RXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HW,PIM<V=I9"`B365T<FEC(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$T.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B365X
M:6-O(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<S"FUS9VED(")-:6-R;VYE<VEA+"!&961E<F%T960@
M4W1A=&5S(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@HC+"!F=7IZ>0IM<V=I9"`B36ED
M9&QE(@IM<V=S='(@(E-K:G5L="(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T;F5F+G!H<#HT,0IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S`X"FUS9VED(")-:6X@=&5M<"!L87-T
M(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS,#`*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,3<*
M(RP@9G5Z>GD*;7-G:60@(DUI<G)O<B(*;7-G<W1R(")&96EL(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM
M<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M.3<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#D*;7-G:60@
M(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P-0IM<V=I9"`B(@HB36ES
M<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N
M;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$S"B,L(&9U>GIY"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S
M='(@(D1E;FYE(&UE;&1I;F=E;B!T:6PB"@HC.B!L:6(O3F5T+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.C4W"FUS9VED(")-:7-S:6YG(')E<75I<F5D
M(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PHC+"!F=7IZ>0IM<V=I9"`B36ES
M<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R(")$96YN92!M96QD:6YG96X@=&EL
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU
M-@HC+"!F=7IZ>0IM<V=I9"`B36\B"FUS9W-T<B`B1FQY='0B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3(R"B,L(&9U>GIY"FUS9VED(")-;V)I
M;&4@36%I;"(*;7-G<W1R(").>2!P;W-T(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,W-0HC+"!F=7IZ>0IM<V=I9"`B36]D97)A=&4B"FUS
M9W-T<B`B4VES="!M;V1I9FES97)T(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-CD@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S,*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#@*(RP@9G5Z
M>GD*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B4VES="!M;V1I9FES
M97)T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4R"B,L(&9U>GIY"FUS9VED(")-;V1I9GD@55),(@IM<V=S
M='(@(D5N9')E(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8U-PHC+"!F=7IZ
M>0IM<V=I9"`B36]D=6QE(@IM<V=S='(@(E)O;&QE(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV.3<*(RP@9G5Z>GD*;7-G:60@(DUO9'5L=7,B
M"FUS9W-T<B`B4F]L;&4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#D@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY,0HC+"!F=7IZ>0IM<V=I9"`B36]N86-O(@IM<V=S='(@
M(DQO:V%S:F]N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDS"B,L(&9U>GIY"FUS9VED(")-;VYG;VQI82(*;7-G<W1R
M(")4:6PB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4X-PHC+"!F=7IZ>0IM
M<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B4VQU='0@<.4@;65L9&EN
M9V5N(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HS-@IM<V=I9"`B
M36]N=&AL>2(*;7-G<W1R(")-Y6YE9'1L:6<B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,38Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3,*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUO;G1S97)R
M870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L
M;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3$*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,T-`HC+"!F=7IZ>0IM<V=I9"`B36]S=&QY($-L
M96%R(@IM<V=S='(@(DMO<&EE<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS-#4*(RP@9G5Z>GD*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS
M9W-T<B`B2V]P:65R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,T-@HC+"!F=7IZ>0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(DMO
M<&EE<B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C0R,`HC+"!F
M=7IZ>0IM<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(F9L>71T(&YE9"(*"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C0R-`HC+"!F=7IZ>0IM<V=I
M9"`B36]V92!,969T(@IM<V=S='(@(F9L>71T(&]P<"(*"B,Z(&QI8B](;W)D
M92]";&]C:R],87EO=70N<&AP.C0R.`HC+"!F=7IZ>0IM<V=I9"`B36]V92!2
M:6=H="(*;7-G<W1R(")&;'ET="!T:6P@:/AY<F4B"@HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+G!H<#HT,38*(RP@9G5Z>GD*;7-G:60@(DUO=F4@57`B
M"FUS9W-T<B`B9FQY='0@;W!P(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0Y-PIM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(F9L
M>71T(&YE9"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT.38@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Y-PIM
M<V=I9"`B36]V92!U<"(*;7-G<W1R(")F;'ET="!O<'`B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,38X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*(RP@9G5Z>GD*
M;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B061V87)S96PB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C$V.`IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D
M;W=N(&QI<W1S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M,C(V"B,L(&9U>GIY"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T
M<B`B1FEL=&5R:6YN<W1I;&QI;F=E<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS,S0@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,0HC+"!F
M=7IZ>0IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R(")+;VY?=&]E<B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-3$*;7-G:60@(DUY(%!O<G1A
M;"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z,3(T
M"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$U-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PHC+"!F=7IZ
M>0IM<V=I9"`B37EA;FUA<B(*;7-G<W1R(")N879N(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+V%G<F5E;65N=%]B;W1T;VTN:6YC.C<*;7-G:60@(DY/
M+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HS.3<@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,#4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C0Q(&QI
M8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4X,PIM<V=I9"`B
M3F%M92(*;7-G<W1R(").879N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$V.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").86UI8FEA(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$U.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY.`IM<V=I9"`B3F%U<G4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-S`V"FUS9VED(").965D<R!!8W1I
M;VXB"FUS9W-T<B`B5')E;F=E<B!H86YD;&EN9R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U
M.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`HC+"!F=7IZ>0IM<V=I
M9"`B3F5P86PB"FUS9W-T<B`B3GD@<&]S="(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B
M3F5T:&5R;&%N9',B"FUS9W-T<B`B3GD@<&]S="(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"B,L(&9U>GIY"FUS9VED
M(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R(").>2!P;W-T(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,#4*;7-G:60@(DYE='-C87!E
M($)A<V4@55),(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-C`W"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8P.0IM
M<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8P.`IM<V=I9"`B3F5T<V-A<&4@
M4F5N97=A;"!54DPB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HV,#8*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C$P"FUS
M9VED(").971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,3$*(RP@9G5Z>GD*;7-G:60@
M(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B26YT970@
M<&5R<V]N;&EG('-E<G1I9FEK870@=&EL9VIE;F=E;&EG+B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-C`T"B,L(&9U>GIY"FUS9VED(").971S
M8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(E-E='0@:6YN('-E<G1I
M9FEK870@:&5R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T,@HC
M+"!F=7IZ>0IM<V=I9"`B3F5T=V]R:R(*;7-G<W1R(").>2(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C0Q,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S(U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S8*;7-G:60@(DYE=F5R
M(@IM<V=S='(@(D%L9')I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDV"B,L(&9U>GIY"FUS9VED(").97<@0V%L961O
M;FEA(@IM<V=S='(@(DQE9V<@=&EL(&5N(&YY(&MO;G1A:W0B"@HC.B!L:6(O
M2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,0HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-PHC+"!F=7IZ>0IM
M<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(D9I<FUA:V%T96=O<FDB"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X
M(&QI8B]";&]C:R]M;V]N+G!H<#HQ-SD*(RP@9G5Z>GD*;7-G:60@(DYE=R!-
M;V]N(@IM<V=S='(@(DYY('!O<W0B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L
M*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(DYE=R!:96%L86YD(@IM
M<V=S='(@(DYY('!O<W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C8T"FUS9VED(").97=S(@IM<V=S='(@(DYY:&5T97(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3`V"B,L(&9U>GIY"FUS9VED(").97=S9W)O
M=7!S(@IM<V=S='(@(D=R=7!P92(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN
M9F\N:6YC.C(Q('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0V"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3,W('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C,R"FUS9VED(").97AT(@IM<V=S='(@(DYE<W1E(@H*(SH@
M;&EB+TAO<F1E+U5)+U!A9V5R+G!H<#HQ,34@;&EB+TAO<F1E+U5)+U!A9V5R
M+G!H<#HQ,38*;7-G:60@(DYE>'0@4&%G92(*;7-G<W1R(").97-T92!S:61E
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"B,L(&9U>GIY"FUS9VED(").
M97AT(%!H87-E(@IM<V=S='(@(DYE<W1E('-I9&4B"@HC.B!L:6(O2&]R9&4O
M4')E9G,O54DN<&AP.C,V-B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,W,`HC
M+"!F=7IZ>0IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(E1I;&)A:V4@
M=&EL(%9A;&<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3<*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Q(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*(RP@
M9G5Z>GD*;7-G:60@(DYI9V5R(@IM<V=S='(@(D%L9')I(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$W,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"B,L(&9U>GIY
M"FUS9VED(").:6=E<FEA(@IM<V=S='(@(D%L9')I(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(X.0HC+"!F=7IZ>0IM<V=I9"`B3FEG:'0B
M"FUS9W-T<B`B2/AY97-T(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W
M.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDX"B,L(&9U>GIY"FUS9VED(").:75E(@IM<V=S
M='(@(D]B<R$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.#@X"FUS9VED(").;R(*;7-G<W1R(").96DB"@HC.B!T96UP;&%T97,O
M861M:6XO<V5T=7`O9&EF9BYH=&UL.C$V"FUS9VED(").;R!A=F%I;&%B;&4@
M8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*
M;7-G<W1R("(B"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z,3$Q"FUS9VED
M(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,R,@IM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C<X(&QI8B](;W)D92]"
M;&]C:R],87EO=70N<&AP.C(R-`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+G!H<#HR-#8*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S
M=&5D('!O<VET:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+VUC
M86PN<&AP.C4T"B,L(&9U>GIY"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R
M;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("));F=E
M;B!K;VYF:6=U<F%S:F]N(&5R('-P97-I9FES97)T(&9O<B!344PM875T96YT
M:7-E<FEN9RXB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-0HC+"!F=7IZ
M>0IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R(")!;F=R92!E;F1R:6YG97(B
M"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T-`IM<V=I9"`B3F\@8VAI
M;&0@<&5R;6ES<VEO;G,@87)E('1O(&)E(&%D9&5D(&)E;&]W('1H:7,@;&5V
M96PN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV
M,0HC+"!F=7IZ>0IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O
M('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B)R5S)R!B;&4@;&%G="!T:6P@
M<F5T=&EG:&5T<W-Y<W1E;65T+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,S4X"B,L(&9U>GIY"FUS9VED(").;R!C;VUM86YD('-P96-I9FEE9"XB"FUS
M9W-T<B`B26YG96X@8G)U:V5R('9A;&=T+B(*"B,Z(&QI8B](;W)D92YP:'`Z
M,3<S(&QI8B](;W)D92YP:'`Z-#DS(&QI8B](;W)D92]5=&EL+G!H<#HW-3,*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B26YG96X@
M:V]N9FEG=7)A<VIO;B!E<B!S<&5S:69I<V5R="!F;W(@4U%,+6MA=&5G;W)I
M97(N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<W,PHC+"!F=7IZ>0IM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($94
M4"!61E,N(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R87-J;VX@97(@<W!E<VEF
M:7-E<G0@9F]R($Q$05`M:6YS=&EL;&EN9V5N92XB"@HC.B!L:6(O5D93+W-Q
M;"YP:'`Z-3DU"B,L(&9U>GIY"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B26YG
M96X@:V]N9FEG=7)A<VIO;B!E<B!S<&5S:69I<V5R="!F;W(@4U%,+6MA=&5G
M;W)I97(N(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S4W"B,L(&9U>GIY
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("));F=E;B!K;VYF:6=U<F%S
M:F]N(&5R('-P97-I9FES97)T(&9O<B!344PM:V%T96=O<FEE<BXB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,R,PIM<V=I9"`B3F\@
M8W)E9&ET(&QE9G0N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-3D*(RP@9G5Z>GD*;7-G:60@(DYO(&1E<W1I;F%T
M:6]N('-U<'!L:65D+B(*;7-G<W1R("));F=E;B!M96QD:6YG97(B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,3(U,@HC+"!P:'`M9F]R;6%T"FUS9VED(").
M;R!E;G1R>2!W:71H('1H92!I9"`G)7,G(&5X:7-T<R!I;B!T:&4@;W)I9VEN
M86P@:&5L<"!F:6QE+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0G)O=W-E
M<BYP:'`Z.#DR"B,L(&9U>GIY"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM
M<V=S='(@(E9I<R!S;&5T=&5D92!E;&5M96YT97(B"@HC.B!U=&EL+VEC;VY?
M8G)O=W-E<BYP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(DYO(&EC;VYS(&9O=6YD
M+B(*;7-G<W1R("));F=E;B!V961L96=G(&9U;FYE="XB"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-#$S('!O+W1R86YS;&%T:6]N+G!H<#HU,C(*(RP@9G5Z
M>GD*;7-G:60@(DYO(&QO8V%L92!S<&5C:69I960N(@IM<V=S='(@(DEN9V5N
M(&)R=6ME<B!V86QG="XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3$V(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$R,0HC+"!F=7IZ>0IM<V=I9"`B3F\@;&]C871I;VX@:7,@
M<V5T+B(*;7-G<W1R(")3=F%R('1I;"!L:7-T96XB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C4X"B,L(&9U>GIY"FUS9VED(").;R!M
M97-S86=E('-U<'!L:65D+B(*;7-G<W1R("));F=E;B!M96QD:6YG97(B"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C8Q"B,L(&9U>GIY
M"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B26YG96X@8G)U
M:V5R('9A;&=T+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-C(*(RP@9G5Z>GD*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM
M<V=S='(@(DEN9V5N(&)R=6ME<B!V86QG="XB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T
M=6YE<R(*;7-G<W1R("));F=E;B!V961L96=G(&9U;FYE="XB"@HC.B!L:6(O
M2&]R9&4O075T:"]H='1P+G!H<#HY,PHC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(DEN9V5N(&MO;F9I9W5R87-J;VX@97(@<W!E<VEF:7-E<G0@9F]R(%-1
M3"UA=71E;G1I<V5R:6YG+B(*"B,Z(&QI8B](;W)D92]!=71H+VEM87`N<&AP
M.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R
M87-J;VX@97(@<W!E<VEF:7-E<G0@9F]R(%-13"UA=71E;G1I<V5R:6YG+B(*
M"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C<T"B,L(&9U>GIY"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R87-J;VX@97(@<W!E<VEF
M:7-E<G0@9F]R(%-13"UA=71E;G1I<V5R:6YG+B(*"B,Z(&QI8B](;W)D92]!
M=71H+VQD87`N<&AP.CDW"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@3$1!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YG
M96X@:V]N9FEG=7)A<VIO;B!E<B!S<&5S:69I<V5R="!F;W(@4U%,+6%U=&5N
M=&ES97)I;F<N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z.#(@;&EB
M+TAO<F1E+T%U=&@O;&]G:6XN<&AP.C@X"B,Z(&QI8B](;W)D92]!=71H+W!A
M;2YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YG96X@:V]N
M9FEG=7)A<VIO;B!E<B!S<&5S:69I<V5R="!F;W(@4U%,+6%U=&5N=&ES97)I
M;F<N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<&%S<W=D+G!H<#HQ,SD*(RP@9G5Z
M>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R87-J;VX@97(@
M<W!E<VEF:7-E<G0@9F]R(%-13"UA=71E;G1I<V5R:6YG+B(*"B,Z(&QI8B](
M;W)D92]!=71H+W-M8BYP:'`Z.#D*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(DEN9V5N(&MO;F9I9W5R87-J;VX@97(@<W!E<VEF:7-E<G0@9F]R(%-13"UA
M=71E;G1I<V5R:6YG+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M,3,Q.`IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@
M<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@
M(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3D*;7-G:60@(DYO('!E
M;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PHC+"!F=7IZ>0IM<V=I
M9"`B3F\@<G5L97,B"FUS9W-T<B`B3F]T871E<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*(RP@9G5Z>GD*
M;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(DEN9V5N(&UE;&1I;F=E<B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C8*;7-G:60@(DYO('1E
M;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8U-@HC
M+"!F=7IZ>0IM<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E
M;G0N(@IM<V=S='(@(E9E;FYL:7-T('-K<FEV(&EN;B!B<G5K97)N879N(&]G
M('!A<W-O<F0B"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z,30Q"B,L
M(&9U>GIY"FUS9VED(").;R!V86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G
M<W1R("));F=E;B!V0V%R9"!D871A(&9U;FYE="XB"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DV(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY,#8*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDQ-R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.3,T"B,L(&9U>GIY"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`B
M26YG96X@;65L9&EN9V5R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q
M,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U
M<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,3@*;7-G:60@(DYO('9E<G-I
M;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C8P-`IM<V=I9"`B3F]N(%!A<G1I8VEP86YT
M(@IM<V=S='(@(DEK:V4@9&5L=&%G97(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HT,3,@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-38P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T
M+FEN8SHX.`IM<V=I9"`B3F]N92(*;7-G<W1R("));F=E;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO
M;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#4*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY-PHC+"!F=7IZ>0IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T
M<B`B3W!P9&%T97(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L
M;V-K+VUO;VXN<&AP.C8P"B,L(&9U>GIY"FUS9VED(").;W)T:&5R;B!(96UI
M<W!H97)E(@IM<V=S='(@(DAJ96QP(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$U."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(").;W)T:&5R;B!-87)I
M86YA($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$W-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDX"B,L(&9U>GIY"FUS9VED(").;W)W
M87DB"FUS9W-T<B`B3F]R;6%L(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HV-C0*(RP@9G5Z>GD*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R("))
M:VME(&ML861D(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-C,*
M(RP@9G5Z>GD*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B26MK92!K;&%D
M9"(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S4V"B,L(&9U>GIY"FUS9VED(").
M;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B4V]R=&5R:6YG<W)E:VME9OAL9V4B
M"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z-C<@;&EB+U9&4R])4T]7<FET
M97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX-`HC.B!L:6(O5D93+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDU"B,Z(&QI8B]61E,O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.0HC.B!L:6(O5D93+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-C`*(RP@9G5Z>GD*;7-G
M:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B26MK92!S;&5T=&5T(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`HC
M+"!F=7IZ>0IM<V=I9"`B3F]T('-E="(*;7-G<W1R(")):VME('-L971T970B
M"@HC.B!L:6(O5D93+G!H<#HQ.#0@;&EB+U9&4RYP:'`Z,C`S(&QI8B]61E,N
M<&AP.C(R,2!L:6(O5D93+G!H<#HR,S@*(SH@;&EB+U9&4RYP:'`Z,C4U(&QI
M8B]61E,N<&AP.C(W,2!L:6(O5D93+G!H<#HR.#D@;&EB+U9&4RYP:'`Z,S(U
M"B,Z(&QI8B]61E,N<&AP.C,X."!L:6(O5D93+G!H<#HT-S(@;&EB+U9&4RYP
M:'`Z-30T(&QI8B]61E,N<&AP.C4V,@HC+"!F=7IZ>0IM<V=I9"`B3F]T('-U
M<'!O<G1E9"XB"FUS9W-T<B`B1&5N(&9O<F5S<'5R=&4@;W!P9V%V96X@97(@
M:6MK92!S=&]T=&5T+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C0W(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-3D*;7-G:60@
M(DYO=&5S(@IM<V=S='(@(DYO=&%T97(B"@HC.B!S97)V:6-E<R]O8G)O=W-E
M<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B
M86-K+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N
M9FER;5]T;W`N:6YC.C$P"FUS9VED(").;W1I8V4B"FUS9W-T<B`B3V)S(2(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS.#0@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R,0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"B,L(&9U>GIY"FUS
M9VED(").;W9E;6)E<B(*;7-G<W1R(")!;&1R:2(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,#0Q"B,L(&9U>GIY"FUS9VED(").=6UB97(B"FUS9W-T<B`B
M3F%V;B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(R"B,L(&9U>GIY"FUS
M9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R("(Q,#`@=&5G;B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S8V(&QI8B](;W)D92]&;W)M+G!H
M<#HQ-#(P(&QI8B](;W)D92]&;W)M+G!H<#HQ-#0R"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"B,L(&9U>GIY"FUS9VED
M(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R(")!;G1A;&P@:V]L;VYN97(@
M:2!O<'!S=6UM97)I;F=S=FES;FEN9V5N.B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,S8T(&QI8B](;W)D92]&;W)M+G!H<#HQ-#$X(&QI8B](;W)D92]&
M;W)M+G!H<#HQ-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`R"B,L(&9U>GIY"FUS9VED(").=6UB97(@;V8@<F]W<R(*
M;7-G<W1R(")!;G1A;&P@:V]L;VYN97(@:2!O<'!S=6UM97)I;F=S=FES;FEN
M9V5N.B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-CD*
M(RP@9G5Z>GD*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D
M871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(D1U(&QA9V5R
M(&5N(&1I<W1R:6)U<VIO;G,@;&ES=&4N(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#@S"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C8V,PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-C0@<&\O=')A;G-L871I;VXN<&AP.C$T.`HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,R.0IM<V=I9"`B3TLB"FUS9W-T<B`B
M3TLB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#$T
M"B,L(&9U>GIY"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B16UN92(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"B,L(&9U>GIY"FUS9VED(")/
M8FIE8W0@0W)E871O<B(*;7-G<W1R(")/8FIE:W1E="!B;&4@:6MK92!F=6YN
M970B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,S<@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HR,C,*(RP@9G5Z>GD*;7-G:60@(D]B:F5C="!C<F5A=&]R
M('!E<FUI<W-I;VYS(@IM<V=S='(@(D]R9'-T>7)E<B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,#DY"B,L(&9U>GIY"FUS9VED(")/8W1A;"(*;7-G<W1R
M(")$86=L:6<B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S@S(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,C`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM
M<V=I9"`B3V-T;V)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#0*;7-G:60@(D]F9FEC92(*
M;7-G<W1R(")+;VYT;W(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(D]M86XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C<V"B,L(&9U>GIY"FUS
M9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S
M+B(*;7-G<W1R(")$96YN92!T:F5N97)E;B!S=/AT=&5R(&EK:V4@9&5L:6YG
M(&%V(&UA<'!E<BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*(RP@
M9G5Z>GD*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@
M(DEN9V5N('9E9&QE9V<@9G5N;F5T+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ.#,U(&QI8B](;W)D92]&;W)M+G!H<#HQ.34U"B,L(&9U>GIY"FUS9VED
M(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(D5P
M;W-T861R97-S96X@9&EN.B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H
M<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN
M:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R
M;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VEF<F%M92YP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@(D]P96X@:6X@82!N97<@
M=VEN9&]W(@IM<V=S='(@(E9I<V4@:6YN:&]L9"!I(&5T(&5G970@=FEN9'4N
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR-3<*;7-G:60@(D]P
M96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N
M960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`HC+"!F=7IZ>0IM
M<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R
M(")(96YT92!N>64@;65L9&EN9V5R(&D@970@96=E="!V:6YD=3\B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T
M96TB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-C`P"FUS9VED(")/<'1I;VYA;"!087)T:6-I<&%N="(*;7-G
M<W1R(")686QG9G)I(&1E;'1A9V5R(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")686QG(@H*
M(SH@<V5R=FEC97,O<')E9G,N<&AP.C(Y('1E;7!L871E<R]P<F5F<R]A<'`N
M:6YC.C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R
M("5S(@IM<V=S='(@(E9A;&<B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$R
M"B,L(&9U>GIY"FUS9VED(")/<'1I;VYS.B(*;7-G<W1R(")686QG(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`HC+"!F
M=7IZ>0IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(E9E;&<@;&ES=&4B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y,0HC+"!F=7IZ>0IM
M<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(D]R9V%N:7-E<FEN9R(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DR"B,L(&9U>GIY"FUS9VED
M(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@(D]R9V%N:7-E<FEN9R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,C<*;7-G:60@(D]R9V%N
M:7II;F<B"FUS9W-T<B`B3W)G86YI<V5R:6YG(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ,S4*(RP@9G5Z>GD*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T
M:6]N('1E;7!L871E(@IM<V=S='(@(DAA;F1L:6YG97(B"@HC.B!A9&UI;B]T
M96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA
M;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$R,"!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G
M:60@(D]T:&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,0HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(Y"FUS9VED(")/=&AE<B!);F9O<FUA
M=&EO;B(*;7-G<W1R(")!;FYE;B!I;F9O<FUA<VIO;B(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,S$*(RP@9G5Z>GD*;7-G:60@(D]W;F5R(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(DQA9W)E(%9A;&<B"@HC.B!L:6(O2&]R9&4O
M075T:"]P86TN<&AP.C@S"B,L(&9U>GIY"FUS9VED(")004T@875T:&5N=&EC
M871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3VUA9')E<W-E<FEN
M9R!F96EL970N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3(W.0HC
M+"!F=7IZ>0IM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@
M(E-K>6=G96QE9V<@<VEG;F%T=7(_(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z,3,R.`HC+"!F=7IZ>0IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A
M(@IM<V=S='(@(E!'4"UK<GEP=&5R(&UE;&1I;F<B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HQ,S@W"B,L(&9U>GIY"FUS9VED(")01U`@4'5B;&EC
M($ME>2(*;7-G<W1R(")/9F9E;G1L:6<@4$=0+6[X:VME;')I;F<B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S8V"B,L(&9U>GIY"FUS9VED(")0
M1U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(E!'4"!S:6=N97(O
M:W)Y<'1E<B!M96QD:6YG(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8S"B,L
M(&9U>GIY"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")(;W)D92(*"B,Z(&%D
M;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#@*(RP@9G5Z
M>GD*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B3&]G9R!I;FXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0Y"B,L(&9U>GIY"FUS
M9VED(")032!3:&]W97)S(@IM<V=S='(@(E9I<W0B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S4P"B,L(&9U>GIY"FUS9VED(")032!3;F]W
M(@IM<V=S='(@(E9I<W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S4Q"B,L(&9U>GIY"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T
M<B`B5FES="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-3(*
M(RP@9G5Z>GD*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(D9R82(*"B,Z
M(&QI8B]A<&DN<&AP.C$R-@IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0V"B,L(&9U>GIY"FUS9VED(")0861D:6YG(@IM<V=S='(@(E5T=FED
M97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`P"B,L(&9U>GIY"FUS9VED(")086MI<W1A;B(*;7-G<W1R(")$871O
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,@HC+"!F=7IZ>0IM<V=I9"`B4&%L874B"FUS9W-T<B`B12UP;W-T(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M,@IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@R(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(E!A;F%M82(*;7-G<W1R(")N879N
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,`IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DU(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"B,L
M(&9U>GIY"FUS9VED(")087)A9W5A>2(*;7-G<W1R(")%+7!O<W0B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0W"B,L(&9U>GIY"FUS9VED
M(")087)T;'D@0VQO=61Y(@IM<V=S='(@(DMO<&EE<B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S0@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(P,#(*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4U-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,PHC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<P('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z,S8*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,V-PIM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B4&%S<V]R9"(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3,U-`HC+"!F=7IZ>0IM<V=I
M9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(E!A<W-O<F0B"@HC.B!L
M:6(O2&]R9&4O075T:"]R861I=7,N<&AP.C$U-PHC+"!F=7IZ>0IM<V=I9"`B
M4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B26YG96X@:V]N9FEG=7)A<VIO;B!E<B!S<&5S:69I<V5R="!F
M;W(@4U%,+6%U=&5N=&ES97)I;F<N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(P,S<*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T
M:6]N(@IM<V=S='(@(E9I<R!M86EL;&ES=&4@:6YF;W)M87-J;VXB"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*(RP@9G5Z>GD*;7-G:60@
M(E!A<W-W;W)D.B(*;7-G<W1R(")087-S;W)D(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D.B`B
M"FUS9W-T<B`B4&%S<V]R9"(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C`Q.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C$U"B,L(&9U>GIY"FUS9VED(")087-S=V]R9',@;75S="!M
M871C:"XB"FUS9W-T<B`B4&%S<W!H<F%S92!S=&5M;65R(&EK:V4@;W9E<F5N
M<R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"B,L(&9U>GIY"FUS
M9VED(")087-T92(*;7-G<W1R(")$871O(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C
M;&EP8F]A<F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHU,0HC+"!F=7IZ>0IM<V=I9"`B4&%T:"(*;7-G
M<W1R(")$871O(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z-"!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C0*
M;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")096]P;&4B"FUS
M9W-T<B`B4F]L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P-PHC+"!F=7IZ>0IM<V=I9"`B4&5R8V5N="(*;7-G<W1R
M(")3:W)I=B!U="(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M
M7V)O='1O;2YI;F,Z-@IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R
M871I;VYS(@IM<V=S='(@(E5T9OAR('9E9&QI:V5H;VQD<V]P97)A<VIO;F5R
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-@IM<V=I9"`B4&5R9F]R
M;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")5
M=&;X<B!V961L:6ME:&]L9'-O<&5R87-J;VYE<B!V960@:6YN;&]G9VEN9S\B
M"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C$@861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP.C8T"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV
M-PHC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R(")097)S;VYL
M:6<B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C8X"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N("<E<R<@;F]T(&1E;&5T960N
M(@IM<V=S='(@(D1E;B!F;W)E<W!U<G1E(&]P<&=A=F5N(&5R(&EK:V4@:6UP
M;&5M96YT97)T+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(R-"!A9&UI
M;B]P97)M<R]A9&1C:&EL9"YP:'`Z.3,*(SH@861M:6XO<&5R;7,O:6YD97@N
M<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-S0*(RP@9G5Z>GD*;7-G
M:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B5S(%!'
M4"!A9&UI;FES=')A<VIO;B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,30Y(&QI8B](;W)D92]097)M<R]522YP:'`Z,34R"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,34V"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N<R!F
M;W(B"FUS9W-T<B`B4&5R<V]N;&EG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8U"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R(")0
M97)S;VYL:6<@:6YF;W)M87-J;VXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3@S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!E<G4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#`*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DY"FUS9VED(")0
M:&]N92(*;7-G<W1R(")496QE9F]N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0T-PIM<V=I9"`B4&AO=&]S(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$X,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*(RP@9G5Z
M>GD*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(D1A=&\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX
M96QS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM
M<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A
M<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0X"B,L
M(&9U>GIY"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O
M(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(D5R(&1U(%-)2TM%4B!P
MY2!A="!D=2#X;G-K97(@Y2!S;&5T=&4@9&4@=F%L9W1E(&]P<&;X<FEN9V5N
M93\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-34*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!C;VYF:7)M('1H
M870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B
M17(@9'4@4TE+2T52('#E(&%T(&1U(/AN<VME<B#E('-L971T92!D92!V86QG
M=&4@;W!P9OAR:6YG96YE/R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-34V
M"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y
M96%R+B(*;7-G<W1R(")696YN;&EG<W0@<VMR:78@:6YN(&1E="!N>64@;F%V
M;F5T.B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C$R"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O
M<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R(")696YN;&EG<W0@<VMR:78@
M:6YN(&YA=FYE="!PY2!D96X@;GEE(&UA<'!E;CHB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3(Y.0HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B5F5N;FQI9W-T(')E='0@='9E
M='ED:6=E(&5L;&5R('5G>6QD:6=E(&%D<F5S<V5R+B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR-C4R"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D
M871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0S-`HC+"!F=7IZ
M>0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B
M5F5N;FQI9W-T('-K<FEV(&EN;B!D970@;GEE(&YA=FYE=#HB"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O
M=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(E9E;FYL
M:6=S="!G:2!E="!S86UM96YD<F%G(&%V('!R;V)L96UE="XB"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$X('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,C(*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@
M86YD('!A<W-W;W)D(@IM<V=S='(@(E9E;FYL:7-T('-K<FEV(&EN;B!B<G5K
M97)N879N(&]G('!A<W-O<F0B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M86=R965M96YT7W1O<"YI;F,Z,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B`@66]U($U54U0@86=R
M964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S
M='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ-PIM<V=I9"`B4&QE87-E
M(')E<&]R="!A;GD@8G5G<R!T;R!I,3AN0&QI<W1S+FAO<F1E+F]R9RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-30P"FUS9VED("(B"B)0;&5A<V4@<F5V:65W('1H92!F;VQL;W=I;F<@
M:6YF;W)M871I;VXL(&%N9"!T:&5N('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T
M:&4@(@HB;65N=2!B96QO=RXB"FUS9W-T<B`B(@HB5F5N;FQI9W-T('-E(&]V
M97(@9&5N(&;X;&=E;F1E(&EN9F]R;6%S:F]N96XL('9E;&<@<^4@96X@:&%N
M9&QI;F<@9G)A(&UE;GEE;B`B"B)N961E;G5N9&5R+B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0S-0IM<V=I9"`B4&QE87-E
M('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO=RXB"FUS9W-T
M<B`B5F5N;FQI9W-T('9E;&<@96X@:&%N9&QI;F<@9G)A(&UE;GEE;B!N961E
M;G5N9&5R+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C<R"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A
M=&5G;W)Y(&YA;64Z(@IM<V=S='(@(E9E;FYL:6=S="!S:W)I=B!I;FX@9&5T
M(&YY92!N879N970Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P,`HC+"!F=7IZ>0IM<V=I9"`B4&]L86YD(@IM<V=S
M='(@(D9I<FUA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W"B,L(&9U
M>GIY"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R(")3;.4@<V%M;65N(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U-@HC+"!F=7IZ>0IM<V=I9"`B
M4&]L;',B"FUS9W-T<B`B4VSE('-A;6UE;B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!O<G1U9V%L
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@
M=&AI<R!I;6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@
M=&AI<R!T86)L92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.30*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO
M="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(V-"!L:6(O0FQO8VLO;65T87(N<&AP.C(V.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H
M<RDZ("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O;&1A<"YP:'`Z
M.3D*(RP@9G5Z>GD*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;7`Z($MA;B!I
M:VME(&9I;FYE(&1E;B!N^&1V96YD:6=E($E-05`@=71V:61E;'-E;BXB"@HC
M.B!L:6(O2&]R9&4O4')E9G,O<V5S<VEO;BYP:'`Z,S8*(RP@9G5Z>GD*;7-G
M:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;7`Z($MA;B!I:VME(&9I;FYE
M(&1E;B!N^&1V96YD:6=E($E-05`@=71V:61E;'-E;BXB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,CDX"B,L(&9U>GIY"FUS9VED(")0<F5S96YT
M871I;VYS(@IM<V=S='(@(D9O<G)I9V4@;65L9&EN9R(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C(S"B,L(&9U>GIY"FUS9VED(")0<F5S<W5R92(*;7-G
M<W1R(")087-S;W)D(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3<*(RP@
M9G5Z>GD*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@
M(E!A<W-O<F0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3DX
M"B,L(&9U>GIY"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(E!A<W-O<F0B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3@X"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R(")&;W)HY6YD<W9I<VYI
M;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C0*(RP@9G5Z>GD*;7-G:60@(E!R979I97<@=&AE(&EM
M86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")6:7,@=F5D;&5G9R!I(&5T
M(&5G970@=FEN9'4B"@HC.B!L:6(O2&]R9&4O54DO4&%G97(N<&AP.C<Q(&QI
M8B](;W)D92]522]086=E<BYP:'`Z-S(*;7-G:60@(E!R979I;W5S(%!A9V4B
M"FUS9W-T<B`B1F]R<FEG92!S:61E(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)
M+G!H<#HS-38@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-C`*(RP@9G5Z>GD*
M;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B1F]R<FEG92!M96QD
M:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`Y"B,L(&9U>GIY"FUS9VED(")0<FEV
M871E($ME>2(*;7-G<W1R(")$:6X@<')I=F%T92!N^&MK96PB"@HC.B!L:6(O
M2&]R9&4O365N=2YP:'`Z,3<U"B,L(&9U>GIY"FUS9VED(")0<F]B;&5M(@IM
M<V=S='(@(EM0<F]B;&5M<F%P<&]R=%TB"@HC.B!S97)V:6-E<R]P<F]B;&5M
M+G!H<#HQ,3(*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B
M4')O8FQE;6)E<VMR:79E;'-E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(Q-@IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(P.34@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q-S(*(RP@
M9G5Z>GD*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(E)E='1E="!T96MS
M="(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0P.0HC+"!F=7IZ>0IM
M<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R(")$:6X@;V9F96YT;&EG92!N^&MK
M96PB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8V.0HC+"!F=7IZ
M>0IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS9W-T<B`B3V9F96YT
M;&EG(%!'4"UN^&MK96QR:6YG(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z,C(S"B,L(&9U>GIY"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER
M(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")097)S;VYL
M:6<@4$=0+6[X:VME;'!A<B!G96YE<F5R="XB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3DQ(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#,*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q"B,L(&9U>GIY"FUS9VED
M(")0=65R=&\@4FEC;R(*;7-G<W1R(")0<F]T;VMO;&PZ(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$Y-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PHC+"!F=7IZ
M>0IM<V=I9"`B46%T87(B"FUS9W-T<B`B4W1A<G0B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z-S`*;7-G:60@(E%U97)Y(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-C@W"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R(")/9F9E
M;G1L:6<@4$=0+6[X:VME;"!T96MS="(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,C0X"B,L(&9U>GIY"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T
M<B`B1FEL=&5R:6YN<W1I;&QI;F=E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS-3,*(RP@9G5Z>GD*;7-G:60@(E)A:6XB"FUS9W-T<B`B
M3&]K87-J;VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4T
M"B,L(&9U>GIY"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(D%V<VSE='0Z
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-34*(RP@9G5Z
M>GD*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R("),;V=G(&EN;B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-38*(RP@9G5Z>GD*;7-G:60@
M(E)A:6X@4VAO=V5R(@IM<V=S='(@(E9I<W0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S4W"B,L(&9U>GIY"FUS9VED(")286EN(&%N9"!3
M;F]W(@IM<V=S='(@(E9I<W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S4X"B,L(&9U>GIY"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T
M<B`B5FES="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"B,L(&9U>GIY
M"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R(").;W1A=&5R(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-S$@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S8*(RP@9G5Z>GD*;7-G:60@(E)A=&EO(@IM
M<V=S='(@(DQO:V%S:F]N(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR.34@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ.#`*(RP@9G5Z>GD*;7-G:60@(E)E860B"FUS9W-T<B`B3W!P9&%T97(B
M"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*(RP@9G5Z
M>GD*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B3GEE(&UE;&1I;F=E
M<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES
M(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"B,L(&9U
M>GIY"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R(")'
M:F5N;W!P=&$@<V5S:F]N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X
M,0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S$*(RP@9G5Z>GD*
M;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(D]P<&1A=&5R
M(&UA<'!E=FES;FEN9SHB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#@Y(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,C`U(&QI8B](;W)D92]&;W)M+G!H<#HQ,C(W
M"B,L(&9U>GIY"FUS9VED(")296=E>"(*;7-G<W1R(").=6QL<W1I;&PB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(S-`IM<V=I9"`B4F5L871I;VYS:&EP
M($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,C0*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#4W"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C0W-@IM<V=I9"`B4F5M96UB97(@=&AE
M(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B2'5S:R!L961I9R]O
M<'!T871T+6EN9F]R;6%S:F]N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,30*(RP@9G5Z>GD*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@
M(E1J96YE<B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM
M<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D
M92DZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I
M="YI;F,Z,C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-#`*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ-0HC
M+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(@IM<V=S='(@(D9J97)N('!A<B(*"B,Z
M('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I
M9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(D9J97)N(&MI;&1E(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4S,@HC+"!F=7IZ>0IM
M<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")&:F5R;B!K:6QD92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*(RP@
M9G5Z>GD*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(D9J97)N
M('!A<B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C8U.`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&9R;VT@;7D@8V%L96YD87(B
M"FUS9W-T<B`B4VQE='0@9G)A(&MA;&5N9&5R96X@;6EN(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,S8*;7-G:60@(E)E;6]V92!P86ER(@IM
M<V=S='(@(D9J97)N('!A<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M.38*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T
M96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*(RP@9G5Z
M>GD*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B1FIE<FX@:VEL9&4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#D*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE
M;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B
M1FIE<FX@:VEL9&4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N
M:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R
M.B`E<R(*;7-G<W1R(")&:F5R;B!K:6QD92(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C$Y-PHC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HR.#`*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z,S0Y"FUS9VED(")297!L>2!396YT+B(*;7-G
M<W1R(")3=F%R('-E;F1T+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C0U.0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HT-C@*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-#<X"FUS9VED(")297!L>2!W:71H($YO="!3=7!P;W)T960@
M365S<V%G92(*;7-G<W1R(")3=F%R(&%T(&UE;&1I;F=E;B!I:VME('-T^'1T
M97,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT
M-C8*;7-G:60@(E)E<&QY('=I=&@@9G)E92]B=7-Y(&9O<B!N97AT(#(@;6]N
M=&AS+B(*;7-G<W1R(")3=F%R(&UE9"!L961I9R]O<'!T871T(&9O<B!D92!N
M97-T92!T;R!MY6YE9&5N92XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HT-C4*;7-G:60@(E)E<&QY('=I=&@@<F5Q=65S=&5D
M(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B4W9A<B!M960@9&5N
M(&9O<F5S<'5R=&4@;&5D:6<O;W!P=&%T="UI;F9O<FUA<VIO;F5N+B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$X.0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5P;'DZ("5S(@IM<V=S='(@(E-V
M87(Z(@H*(SH@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C$S.0IM<V=I9"`B
M4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C
M;V1E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+G!H<#HQ.#`@;&EB+TAO
M<F1E+G!H<#HU,#,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I
M<F5D("<E<R<@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R(")0Y6MR979D("=U:60G(&5R(&EK:V4@<W!E<VEF:7-E<G0@:2!I
M;G-T:6QL:6YG<VMO;F9I9W5R87-J;VYE;BXB"@HC.B!L:6(O5D93+W-Q;"YP
M:'`Z-C`Q(&QI8B]61E,O9G1P+G!H<#HW-SD@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z-S8S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"`G
M)7,G(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(E#E:W)E=F0@)W5I9"<@97(@:6MK92!S<&5S:69I<V5R="!I(&EN<W1I
M;&QI;F=S:V]N9FEG=7)A<VIO;F5N+B(*"B,Z(&QI8B](;W)D92]5=&EL+G!H
M<#HW-C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D("<E
M<R<@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")0
MY6MR979D("=U:60G(&5R(&EK:V4@<W!E<VEF:7-E<G0@:2!I;G-T:6QL:6YG
M<VMO;F9I9W5R87-J;VYE;BXB"@HC.B!L:6(O2&]R9&4O1F]R;2]296YD97)E
M<BYP:'`Z,S(Y"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU.3(*;7-G
M:60@(E)E<75I<F5D(%!A<G1I8VEP86YT(@IM<V=S='(@(D]B;&EG871O<FES
M:R!D96QT86=E<B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&QI8B](;W)D92]&
M;W)M+G!H<#HS,SD@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,Q-@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#0*;7-G:60@(E)E<V5T(@IM<V=S='(@
M(DYU;&QS=&EL;"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V
M"B,L(&9U>GIY"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R(")087-S
M;W)D(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*(RP@9G5Z
M>GD*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B1VIE;F]P
M<'1A('-E<VIO;B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV-B!A9&UI;B]C
M;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP.C<S"B,L(&9U>GIY
M"FUS9VED(")297-U;'1S(@IM<V=S='(@(E/X:V5R97-U;'1A="(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HX,C$*;7-G:60@(E)E<W5L=',@*&EN8VQU9&EN
M9R!(;W)D92DZ(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX
M,3D*(RP@9G5Z>GD*;7-G:60@(E)E<W5L=',Z(@IM<V=S='(@(E/X:V5R97-U
M;'1A="(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#(@=&5M
M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO
M;G,B"FUS9W-T<B`B5&EL8F%K92!T:6P@5F%L9R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X
M-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G
M:60@(E)E=6YI;VXB"FUS9W-T<B`B3V)S97)V97(B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*(RP@
M9G5Z>GD*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(D)E
M(&]M(&QE=F5R:6YG<V)E:W)E9G1E;'-E(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S,`HC+"!F=7IZ>0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/
M<'1I;VYS(@IM<V=S='(@(E1I;&)A:V4@=&EL(%9A;&<B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(E)I9&1L97,B"FUS
M9W-T<B`B4VMJ=6QT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<P"B,L(&9U>GIY"FUS9VED(")2:6=H="(*;7-G
M<W1R(")(^'EE<W0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P-@HC+"!F
M=7IZ>0IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(D5K<V5M<&5L=F5R
M9&EE<CHB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P,@HC+"!F=7IZ>0IM
M<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(D5K<V5M<&5L=F5R9&EE<CHB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C@*(RP@9G5Z>GD*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*
M;7-G<W1R("),878@<')I;W)I=&5T(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,S<@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-3@S"FUS9VED(")2;VQE(@IM<V=S='(@(E)O;&QE(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PHC
M+"!F=7IZ>0IM<V=I9"`B4F]M86YI82(*;7-G<W1R(").;W)M86PB"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`X"B,L(&9U>GIY
M"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(F9L>71T(&]P<"(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,#4*(RP@9G5Z>GD*
M;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(F9L>71T(&]P<"(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,3$*(RP@9G5Z>GD*
M;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R(")&;'ET="!T:6P@:/AY<F4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0Y"B,L(&9U>GIY"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R
M("),878@<')I;W)I=&5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`HC+"!F=7IZ>0IM<V=I9"`B4F]W('!R
M;W!E<G1I97,B"FUS9W-T<B`B3&%V('!R:6]R:71E="(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"B,L(&9U>GIY"FUS
M9VED(")2;W=S.B(*;7-G<W1R(")3;.4@<V%M;65N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PHC+"!F=7IZ
M>0IM<V=I9"`B4G5L97,B"FUS9W-T<B`B4F]L;&4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U
M;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,CD*(RP@9G5Z>GD*;7-G:60@(E)U
M;B(*;7-G<W1R(")/8G-E<G9E<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E)U<W-I86X@1F5D97)A
M=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`T"B,L(&9U>GIY"FUS9VED(")2=V%N9&$B"FUS
M9W-T<B`B2V%L96YD97(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C,P,`IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S0Q"B,L
M(&9U>GIY"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T
M<B`B2W)Y<'1E<B!M960@4R]-24U%(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S
M;"YP:'`Z.#8*(RP@9G5Z>GD*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@
M:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3VUA9')E<W-E<FEN9R!F96EL
M970N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X,0HC+"!F=7IZ
M>0IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R(")-96QD:6YG<W9I<VYI
M;F<B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L
M;"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S4X"FUS9VED(")34R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S<U"FUS9VED(")34T@B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,X
M"FUS9VED(")354-#15-3(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$S
M,`IM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"B,L(&9U>GIY"FUS9VED
M(")382(*;7-G<W1R("),86=R92!S;VTB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C`W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")386EN="!(96QE
M;F$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@U"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@X"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q
M"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#0@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,38*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$X"B,L(&9U>GIY"FUS9VED(")386UO82(*;7-G<W1R("),86=R92!S;VTB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`W"B,L(&9U>GIY"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(D%D=F%R
M<V5L(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P.`IM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$R,`HC+"!F=7IZ>0IM
M<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(E-T870O1GEL:V4@
M*$%R8F5I9"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Q(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`T"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDX"FUS9VED(")3879E
M(@IM<V=S='(@(DQA9W)E('-O;2(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,C$V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E("5S
M(@IM<V=S='(@(DQA9W)E('-O;2(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z-#D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A
M=F4@)R5S)R(*;7-G<W1R("),86=R92!S;VTB"@HC.B!T96UP;&%T97,O<')E
M9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B3&%G
M<F4@5F%L9R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C$*;7-G:60@
M(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R
M:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-CD*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(E-E;F0@<VES=&4@:6YF;W)M87-J;VXB"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HY,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("<E<R<N(@IM
M<V=S='(@(DMU;FYE(&EK:V4@;&%G92!61E,M8F%C:V5N9#H@)7,B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(E-C:65N
M8V4B"FUS9W-T<B`B4VEG;F5R="(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C$U('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$W
M"FUS9VED(")396%R8V@B"FUS9W-T<B`B4_AK(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(X,0HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H($5N9VEN
M97,B"FUS9W-T<B`B4_AK("5S(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$T
M,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-E87)C:&EN9R!(;W)D
M92!A<'!L:6-A=&EO;G,@:6X@)7,B"FUS9W-T<B`B26YN<W1I;&QI;F=E<B!F
M;W(@<_AK(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R,PHC+"!F=7IZ>0IM
M<V=I9"`B4V5A<F-H:6YG(&=E='1E>'0@8FEN87)I97,N+BXB"FUS9W-T<B`B
M26YN<W1I;&QI;F=E<B!F;W(@<_AK(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(Y-3@*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R(")6
M96QG(&%L;&4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#4V"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(E9E;&<@96X@
M9&%T;R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"B,L(&9U
M>GIY"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B5F5L
M9R!E;B!K;VYT;R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*
M(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R(")6
M96QG(&EN9V5N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P
M"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B5F5L
M9R!E;B!D871O(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*
M(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@
M(E9E;&<@970@9F5L="(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-C4U"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS
M9W-T<B`B5F5L9R!E;B!D871O(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C@Q-`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%N(&]B
M:F5C="(*;7-G<W1R(")696QG(&EN9V5N(@H*(SH@<V5R=FEC97,O:V5Y8F]A
M<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A
M8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@
M=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E
M82XB"FUS9W-T<B`B(@HB5F5L9R!K87)A:W1E<F5N92!D=2!T<F5N9V5R(&9R
M82!B;VMS96X@=6YD97(N($1U(&MA;B!D97)E='1E<B!K;W!I97)E(&]G("(*
M(FQI;64@9&5M(&EN;B!F<F$@=&5K<W1F96QT970N(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI
M;6ET97(Z(@IM<V=S='(@(E9E;&<@9&%T;W-K:6QL971E9VXZ(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T
M92!F;W)M870Z(@IM<V=S='(@(E9E;&<@9&%T;V9O<FUA="(*"B,Z('1E;7!L
M871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.#4*;7-G:60@(E-E;&5C
M="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I
M9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B5F5L9R!D
M871O<VMI;&QE=&5G;CHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR
M-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B5F5L
M9R!T:61S9F]R;6%T.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M-C0*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R
M(")696QG('1O('-A;7-V87)E;F1E(&9E;'0N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(Y-@IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,X"FUS
M9VED(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@
M(E9E;&<@^&YS:V5T('-P<N5K.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C8U,PIM<V=I9"`B4V5N9"!,871E<W0@26YF;W)M
M871I;VXB"FUS9W-T<B`B4V5N9"!S:7-T92!I;F9O<FUA<VIO;B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R
M;V)L96T@4F5P;W)T(@IM<V=S='(@(E-E;F0@<')O8FQE;7)A<'!O<G0B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38T"B,L(&9U
M>GIY"FUS9VED(")396YD(%--4R(*;7-G<W1R(")396YD(&UE;&1I;F<B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W
M"FUS9VED(")396YE9V%L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S$T"B,L(&9U>GIY"FUS9VED(")396YS;W(Z("(*;7-G<W1R("(@
M("`@16UN93H@(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,X,B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*
M(RP@9G5Z>GD*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R(")-96UO(@H*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA
M(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-S(U"B,L(&9U>GIY"FUS9VED(")397)I86P@3G5M8F5R
M(@IM<V=S='(@(DYA=FXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P,0HC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D
M+B(*;7-G<W1R(")-96QD:6YG<V9E;'0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C(Y-@HC+"!F=7IZ>0IM<V=I9"`B4V5T(@IM<V=S='(@(E9E;&<B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS
M('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E
M=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@
M>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`HC+"!F=7IZ>0IM<V=I
M9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@
M9&%T92!O<'1I;VYS+B(*;7-G<W1R(")3971T('-I9&4@;W!P9&%T97)I;F<L
M(&]G('9I<VYI;F=S('9A;&<N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDX"B,L(&9U>GIY"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI
M8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T
M:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B4V5T="!S:61E(&]P
M<&1A=&5R:6YG+"!O9R!V:7-N:6YG<R!V86QG+B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(E-E='5P(@IM<V=S='(@
M(E9E;&<B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS
M.`IM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30Y"FUS
M9VED(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A
M;65T97(Z("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")397EC:&5L;&5S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S,*(RP@9G5Z
M>GD*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(E9I<W0B"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PHC+"!F=7IZ>0IM<V=I9"`B4VAO
M<G0@4W5M;6%R>2(*;7-G<W1R(")+;W)T('-A;6UE;F1R86<Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0S-@IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K
M97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]097)M<RYP:'`Z,CDT('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"B,L(&9U>GIY"FUS9VED
M(")3:&]W(@IM<V=S='(@(E9I<W0B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,30Y"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R
M<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT.#`*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN
M9R!I;C\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-3,*
M;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#(*(RP@9G5Z>GD*;7-G:60@
M(E-H;W<@<&EC:V5R(@IM<V=S='(@(E9I<W0B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3$U"B,L(&9U>GIY"FUS9VED(")3:&]W('1A8FQE(&]P97)A
M=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(E9I<V4@9FEL=&5R:6MO;F5T(&D@
M;65N>65N/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE
M(&QE9G0_(@IM<V=S='(@(E9I<V4@9FEL=&5R:6MO;F5T(&D@;65N>65N/R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU.`HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0
M<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")&;W)HY6YD<W9I<VYI;F<B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C,*(RP@9G5Z>GD*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I
M97,@9&EA;&]G(@IM<V=S='(@(D9O<FCE;F1S=FES;FEN9R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0HC
M+"!F=7IZ>0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@
M9&EA;&]G(@IM<V=S='(@(D9O<FCE;F1S=FES;FEN9R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0HC+"!F
M=7IZ>0IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B
M"FUS9W-T<B`B1F]R:.5N9'-V:7-N:6YG(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$W-3$*(RP@9G5Z>GD*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@
M(E9I<R!S;&5T=&5D92!E;&5M96YT97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S4Y"B,L(&9U>GIY"FUS9VED(")3:&]W97)S(@IM<V=S
M='(@(E9I<W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8P
M"B,L(&9U>GIY"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(E9I<W0B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Q"B,L(&9U>GIY
M"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B5FES="(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C(*;7-G:60@(E-H;W=E<G,@:6X@
M=&AE(%9I8VEN:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]";&]C:R],
M87EO=70N<&AP.C,Y,0HC+"!F=7IZ>0IM<V=I9"`B4VAR:6YK(@IM<V=S='(@
M(DQO9V<@:6YN(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-C@T
M(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C<T-@HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+G!H<#HX,#0@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP
M:'`Z.#8V"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.CDP,2!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HY,S@*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="YP:'`Z.38V(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.CDY
M-@IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I
M(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(P,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-I
M97)R82!,96]N92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N
M=7`N<&AP.C(W.`HC+"!F=7IZ>0IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R(")3
M:6=N97)T(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX.0IM<V=I
M9"`B4VEG;B!U<"!I9B!N;W0@<F5G:7-T97)E9"(*;7-G<W1R(")296=I<W1R
M97(@9&5G(&]M(&EK:V4@<F5G:7-T<F5R="(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-S,V"B,L(&9U>GIY"FUS9VED(")3:6=N871U<F4B"FUS
M9W-T<B`B1&EN('-I9VYA='5R.B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-S,U"B,L(&9U>GIY"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM
M(@IM<V=S='(@(D1I;B!S:6=N871U<CHB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C`V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"B,L(&9U>GIY"FUS9VED(")3
M:6YG87!O<F4B"FUS9W-T<B`B1&EN('-I9VYA='5R.B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HX.3$@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,#<@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$R,CD*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R,S`@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,3D@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q
M,#@*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#<*;7-G:60@(E-I>F4B"FUS9W-T<B`B4W3X<G)E
M;'-E(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?8F]T=&]M
M+FEN8SHY"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(DAO<'`@
M;W9E<B!V961L:6ME:&]L9"(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,S$@
M<&\O=')A;G-L871I;VXN<&AP.C0X-"!P;R]T<F%N<VQA=&EO;BYP:'`Z-C8V
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX-C`@<&\O=')A;G-L871I;VXN<&AP
M.C$R,#0*;7-G:60@(E-K:7!P960N+BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ
M>0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B3F]R;6%L(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(P."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ
M>0IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B3F]R;6%L(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,PHC+"!F=7IZ>0IM<V=I9"`B4VYO
M=R(*;7-G<W1R(")6:7-T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,V-`HC+"!F=7IZ>0IM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B
M5FES="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C4*(RP@
M9G5Z>GD*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R(")6:7-T(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V-@HC+"!F=7IZ>0IM<V=I
M9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(E9I<W0B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8W"B,L(&9U>GIY"FUS9VED(")3
M;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R(")6:7-T(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-S8*(RP@9G5Z>GD*;7-G:60@(E-N;W<@9&5P=&@Z("(*
M;7-G<W1R("(@("`@16UN93H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M.#`*;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(P-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#0*(RP@9G5Z>GD*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R
M(")/<'!D871E<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,30@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#<*(RP@9G5Z>GD*;7-G:60@(E-O;6%L:6$B"FUS9W-T
M<B`B3F]R;6%L(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED
M(")3;VYG<R`F(%!O96US(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR.3$U"B,L(&9U>GIY"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO
M;B(*;7-G<W1R(")3;W)T97)I;F=S<F5K:V5F^&QG92(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#$@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8Q,PHC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(R,R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U
M-0HC+"!F=7IZ>0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B1FER
M;6%A9')E<W-E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED(")3;W5T:"!%=7)O
M<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X"FUS9VED(")3;W5T:"!'
M96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN
M<&AP.C8R"B,L(&9U>GIY"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM
M<V=S='(@(DAJ96QP(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@
M8V5L;',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N=&5N
M="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C@Q-0HC+"!F=7IZ>0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@
M(DQA9W)E('-O;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX,`HC+"!F=7IZ>0IM<V=I9"`B4W!A8VEN9R(*;7-G
M<W1R(")5='9I9&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN
M9R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,@HC+"!F=7IZ>0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B
M571V:61E<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY-0HC+"!F
M=7IZ>0IM<V=I9"`B4W!A;2(*;7-G<W1R("),86=R92!S;VTB"@HC.B!S97)V
M:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R
M($EN<'5T(@IM<V=S='(@(E-P97-I86QT96=N:6YN=&%S=&EN9R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*
M(RP@9G5Z>GD*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B5F5L9R!A;&QE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV-@HC+"!F=7IZ>0IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@
M(E9E;&<@86QL92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S$*(RP@9G5Z>GD*;7-G:60@(E-P;&ET(')O=R(*
M;7-G<W1R(")696QG(&%L;&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C$*(RP@9G5Z>GD*;7-G:60@(E-P;W)T<R(*;7-G<W1R(")6:6MT:6<B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30Q(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*
M(RP@9G5Z>GD*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R("),;V=G(&EN;B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV."!L:6(O0FQO8VLO
M;65T87(N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R
M(")+86QE;F1E<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@HC+"!F
M=7IZ>0IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(E-T87)T(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#0S"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4T.`IM<V=I9"`B4W1A
M<G0B"FUS9W-T<B`B4W1A<G0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4X
M.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y.`HC+"!F=7IZ>0IM<V=I9"`B4W1A
M<G0@>65A<B(*;7-G<W1R(")3=&%R="(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3DT"B,L(&9U>GIY"FUS9VED(")3=&%T92!O<B!0<F]V:6YC
M92(*;7-G<W1R(")3=&%T+T9Y;&ME("A!<F)E:60I(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3@S('1E;7!L871E<R]A9&UI
M;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B
M4W1A='5S(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0Y,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=&%T=7,@9F]R(&QO8V%L92`E<RXN+B`B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#0*(RP@9G5Z>GD*;7-G:60@
M(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(D1I;B!I;F9O<FUA<VIO;B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DV"B,L(&9U>GIY"FUS9VED
M(")3=')E970@061D<F5S<R(*;7-G<W1R(")&<F$M861R97-S92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@
M(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$R,C4*(RP@9G5Z>GD*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@
M(E-V87)T96QI<W1E(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-3<*;7-G
M:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U
M(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y("<E<R<@;F]T
M(&9O=6YD+B(*;7-G<W1R(").;W1I<R!L>71T97(@)7,@:6MK92!F=6YN970N
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,S4@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S@*;7-G:60@(E-U8FIE8W0B"FUS
M9W-T<B`B16UN92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C8X
M"B,L(&9U>GIY"FUS9VED(")3=6)J96-T(%!U8FQI8R!+97D@26YF;R(*;7-G
M<W1R(")$:6X@;V9F96YT;&EG92!N^&MK96PB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S,R(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,3,*;7-G
M:60@(E-U8FUI="(*;7-G<W1R(")396YD(@H*(SH@<VEG;G5P+G!H<#HU,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A
M9&0@)R5S)R!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT
M:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R"B,L(&9U>GIY"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B4V5N9"(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,3,@;&EB+TAO<F1E+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"FUS9VED(")3=6-C97-S(@IM
M<V=S='(@(E-U:W-E<W,B"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D("<E<R<@
M=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B)7,@8FQE(&QA9W0@=&EL("5S+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`G)7,G
M(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B)7,@8FQE(&QA9W0@=&EL("5S
M+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#$@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HV,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY(&1E;&5T960@)R5S)RXB"FUS9W-T<B`B2&5N9&5L<V5N(&)L92!S;&5T
M=&5T+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@)R5S)R!F<F]M('1H
M92!S>7-T96TN(@IM<V=S='(@(B5S(&)L92!L86=T('1I;"`E<RXB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"B,L(&9U>GIY"FUS9VED(")3=6-C
M97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E
M92!C:&%N9V5S+B(*;7-G<W1R(")+=6YN92!I:VME(&QA9V4@5D93+6)A8VME
M;F0Z("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C4U"B,L(&9U>GIY"FUS9VED(")3=6-C97-S9G5L
M;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DMU;FYE
M(&EK:V4@;&%G92!61E,M8F%C:V5N9#H@)7,B"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C8R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C
M97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(@IM<V=S='(@(DMU;FYE(&EK:V4@;&%G92!61E,M8F%C:V5N9#H@)7,B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D("<E<R<B"FUS9W-T<B`B26YN
M<W1I;&QI;F=E;F4@8FQE(&]P<&1A=&5R="XB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM
M<V=S='(@(B5S(&)L92!L86=T('1I;"`E<RXB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C`T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3$*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"B,L(&9U>GIY"FUS9VED
M(")3=61A;B(*;7-G<W1R(")5='9I9&5R(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-34X"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C4V,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y(@IM
M<V=S='(@(E-A;6UE;F1R86<B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M-C8*(RP@9G5Z>GD*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(D5M;F4B"@HC
M.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(E-U
M;B!3970B"FUS9W-T<B`B16UN92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS-C@*;7-G:60@(E-U;FYY(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-SD*(RP@9G5Z>GD*;7-G:60@(E-U
M;G)I<V4B"FUS9W-T<B`B16UN92(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@HC+"!F=7IZ>0IM<V=I9"`B
M4W5N<FES92]3=6YS970B"FUS9W-T<B`B16UN92(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-S@*(RP@9G5Z>GD*;7-G:60@(E-U;G)I<V4Z
M("(*;7-G<W1R("(@("`@16UN93H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$X,@HC+"!F=7IZ>0IM<V=I9"`B4W5N<V5T(@IM<V=S='(@
M(D5M;F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@Q"B,L
M(&9U>GIY"FUS9VED(")3=6YS970Z("(*;7-G<W1R("(@("`@16UN93H@(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PHC
M+"!F=7IZ>0IM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`B0F5S:W)I=F5L
M<V4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8U"B,L(&9U>GIY
M"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(DEM<&]R=&5R(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(Q-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PHC+"!F=7IZ
M>0IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B;F%V;B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3DX"B,L(&9U>GIY"FUS9VED(")3=7)N86UE
M(@IM<V=S='(@(FYA=FXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA
M>65N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3D@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#D*(RP@9G5Z>GD*;7-G:60@(E-W87II;&%N9"(*
M;7-G<W1R(")3^&LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`U(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`U"B,L(&9U>GIY"FUS9VED(")3=V5D96XB"FUS9W-T
M<B`B3&5S="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R
M(")3^&LB"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HY.`HC+"!F
M=7IZ>0IM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G
M<W1R(")4^&T@<_AP<&5L:W5R=F5N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B4WER:6%N($%R86(@
M4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,V.0HC+"!F=7IZ>0IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R(")&
M<F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S<P"B,L(&9U
M>GIY"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R(")&<F$B"@HC.B!L:6(O2&]R
M9&4O1&%T82]T<W8N<&AP.C$W,0HC+"!F=7IZ>0IM<V=I9"`B5%-6(&9I;&4B
M"FUS9W-T<B`B5&ET=&5L(@H*(SH@;&EB+TAO<F1E+U5)+U1A8FQE+G!H<#HQ
M,S4*(RP@9G5Z>GD*;7-G:60@(E1A8FQE(@IM<V=S='(@(E1I='1E;"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S,*(RP@9G5Z>GD*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B
M1F]R:.5N9'-V:7-N:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@HC+"!F=7IZ>0IM<V=I9"`B5&%B;&4@
M<')O<&5R=&EE<R(*;7-G<W1R(")&;W)HY6YD<W9I<VYI;F<B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C,T(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@(E/X:R(*"B,Z
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A
M;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(R-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`HC+"!F=7IZ>0IM
M<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R(")$871O(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(S-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B5&%N
M>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"B,L(&9U>GIY
M"FUS9VED(")487)G970Z(@IM<V=S='(@(D)R=6ME<FYA=FXZ(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$V.`IM<V=I9"`B5&%S:W,B"FUS9W-T
M<B`B3W!P9V%V97(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y
M-PHC+"!F=7IZ>0IM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R(").
M879N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#@*;7-G:60@(E1E;7`@
M9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C$R"B,L(&9U>GIY"FUS9VED(")496UP97)A='5R92(*;7-G<W1R
M(")$:6X@<VEG;F%T=7(Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$X-@HC+"!F=7IZ>0IM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R
M(")$:6X@<VEG;F%T=7(Z(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HR
M,3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E("<E<R<@
M;F]T(&9O=6YD+B(*;7-G<W1R(")6961L96=G970@8FQE(&EK:V4@9G5N;F5T
M+B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"B,L(&9U>GIY"FUS9VED
M(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(E<R!01U`@861M
M:6YI<W1R87-J;VXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HV-#$*;7-G:60@(E1E;G1A=&EV96QY($%C8V5P="!R97%U97-T
M(@IM<V=S='(@(D=O9'1A(&9O<F5S</AR<V5L(&9O<F5L^'!I9R(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8X.0IM<V=I9"`B
M5&5N=&%T:79E;'D@06-C97!T960B"FUS9W-T<B`B1V]D=&$@9F]R96SX<&EG
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,#,*(RP@9G5Z>GD*;7-G:60@
M(E1E>'0B"FUS9W-T<B`B5&5?:W-T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,V-0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(DMU;B!T96MS="(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S0*(RP@9G5Z>GD*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B3F5S
M=&4@<VED92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S$*(RP@9G5Z>GD*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B5&5?
M:W-T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#<*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C0@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(R,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*
M(RP@9G5Z>GD*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(E/X:R(*"B,Z(&QI
M8B](;W)D92]!=71H+G!H<#HY-#0*(RP@9G5Z>GD*;7-G:60@(E1H86YK('EO
M=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`B1'4@:&%R(&)L:70@
M;&]G9V5T('5T+B`\8G(@+SX@5&%K:R!F;W(@870@9'4@8G)U:W1E('-Y<W1E
M;65T+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#4W"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92`E<R!H96QP(&9I;&4@9F]R("5S(&1O97-N)W0@>65T
M(&5X:7-T+B!#<F5A=&EN9R!A(&YE=R!O;F4N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]61E,O9G1P+G!H<#HW-CD*(RP@9G5Z>GD*;7-G:60@(E1H92!&5%`@97AT
M96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D1E="!E<B!I;F=E
M;B!M96QD:6YG97(@:2!D96YN92!P;W-T8F]K<V5N+B(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z.3(T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(;W)D
M92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<
M(B5S7"(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C(Y"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO
M860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VEM86=E
M<R]C;VQO<G!I8VME<BYP:'`Z,CD*(RP@9G5Z>GD*;7-G:60@(E1H92!/<'1I
M;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R(")-96QD
M:6YG96X@<V]M(&AA<B!B;&ET="!S:W)E=F5T(&AA<B!B;&ET="!S=&5N9W0N
M($%V<VQU='1E<BXB"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C$V,"!L:6(O
M2&]R9&4O4&5R;7,N<&AP.C$W,2!L:6(O2&]R9&4O4&5R;7,N<&AP.C$X,@HC
M.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C$Y-"!L:6(O2&]R9&4O4&5R;7,N<&AP
M.C(P-2!L:6(O2&]R9&4O4&5R;7,N<&AP.C(R,PHC.B!L:6(O2&]R9&4O4&5R
M;7,N<&AP.C(S-2!L:6(O2&]R9&4O4&5R;7,N<&AP.C(W-`IM<V=I9"`B(@HB
M5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N
M96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E
M(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T
M=&]M('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HT.0IM<V=I9"`B5&AE(&-A;&5N9&%R(&1A
M=&$@:7,@:6YV86QI9"(*;7-G<W1R(")+86QE;F1E<F1A=&$@97(@=6=Y;&1I
M9R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-C0*(RP@
M9G5Z>GD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T
M('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H
M92`B"B)D871A8F%S92XB"FUS9W-T<B`B1&5N(&9O<F5S<'5R=&4@;W!P9V%V
M96X@97(@:6MK92!S=&]T=&5T+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(E1H92!C;VYT86-T('=A
M<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM
M<V=S='(@(D]P<&;X<FEN9V5N(%PB)7-<(B!B;&4@;&%G="!T:6P@861R97-S
M96)O:V5N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$W,0HC+"!F
M=7IZ>0IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO
M8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB
M"FUS9W-T<B`B16X@;V9F96YT;&EG(%!'4"UN^&MK96P@97(@<.5K<F5V9"!F
M;W(@Y2!V97)I9FES97)E('-I9VYE<G0@;65L9&EN9RXB"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C8V"B,L(&9U>GIY"FUS9VED("(B
M"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E
M8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T
M86)A<V4N(@IM<V=S='(@(D1E;B!F;W)E<W!U<G1E(&]P<&=A=F5N(&5R(&EK
M:V4@<W1O='1E="XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C8W"B,L(&9U>GIY"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@
M=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(D1E;B!F;W)E<W!U<G1E(&]P
M<&=A=F5N(&5R(&EK:V4@<W1O='1E="XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0N
M<&AP.C$R-PHC+"!F=7IZ>0IM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R
M97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B
M4_AT=&4@9F]R('!E<G-O;FQI9R!01U`@;OAK:V5L<&%R(&MR979E<B!E;B!S
M:6MK97(@=V5B+71I;&MO8FQI;F<N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-S@*(RP@9G5Z>GD*;7-G:60@(E1H92!E=F5N
M="!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R+B(*;7-G<W1R(")(
M96YD96QS96X@8FQE(&QA9W0@=&EL(&D@9&EN(&MA;&5N9&5R+B(*"B,Z(&QI
M8B](;W)D92YP:'`Z,3@Q(&QI8B](;W)D92YP:'`Z-3`T"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T
M=&EN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-S0@;&EB+TAO
M<F1E+G!H<#HT.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@
M<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HQ-C0*;7-G:60@(E1H92!F:6QE(&-A;B!N
M;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O1&%T82YP:'`Z,C8T"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@
M;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S(*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H
M96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N
M('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U
M92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@
M=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@
M9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD
M;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN
M9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='
M96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O
M="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S
M<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N
M(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P
M.#4@<&\O=')A;G-L871I;VXN<&AP.C$R,38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&AE;'`@9FEL92`E<R!D:61N)W0@<W1A<G0@=VET:"`\/WAM;"(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.#@*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E
M96X@9&5L971E9"XB"FUS9W-T<B`B261E;G1I=&5T96X@7"(E<UPB(&)L92!S
M;&5T=&5T+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O;FQY
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S-@IM
M<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S
M="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]-24U%+TU$3BYP:'`Z,C$T"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET
M:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES
M(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E
M860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$X-C$*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI
M;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C$R-3D*;7-G:60@(E1H92!O<&5N<W-L(&UO
M9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@
M8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0<F5F<RYP:'`Z,CDQ
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<
M(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E
M9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O9&5B+G!H<#HS-2!L:6(O2&]R9&4O
M34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,W"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,U"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]M<W=O<F0N<&AP.C,U(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M<&TN<&AP.C,U"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]W96)C<'`N<&AP
M.C0P"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z
M,SD*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,U"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE
M=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y
M<W1E;2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L
M969T('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I
M9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C<X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R
M("))9&5N=&ET971E;B!<(B5S7"(@8FQE('-L971T970N(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G
M<W1R("))9&5N=&ET971E;B!<(B5S7"(@8FQE(&QA9W)E="XB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ.3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS
M9W-T<B`B261E;G1I=&5T96X@7"(E<UPB(&)L92!L86=R970N(@H*(SH@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,C@T"B,L(&9U>GIY"FUS9VED(")4
M:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B1&5N
M('-P97-I9FES97)T92!F:6QE;B!E:W-I<W1E<F5R(&EK:V4N(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3`X"FUS9VED(")4
M:&4@=&%S:R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R('1A<VML:7-T+B(*;7-G
M<W1R(")(86YD;&EN9V5N(&AA<B!B;&ET="!L86=T('1I;"!D:6X@;&ES=&4@
M;W9E<B!H86YD;&EN9V5R+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HQ,3$*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<
M(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D1E;B!S<&5S:69I<V5R
M=&4@9FEL96X@96MS:7-T97)E<B!I:VME+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T
M;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G
M:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]$871A+G!H<#HS,3$*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L
M;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O1&%T82]C<W8N<&AP.C(U,"!L:6(O2&]R9&4O1&%T82]T<W8N
M<&AP.C$W-PHC+"!F=7IZ>0IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U
M;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R(")3:6=N871U<F5N(&MU;FYE(&EK
M:V4@97)S=&%T=&5S+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.CDS"FUS9VED(")4:&4@=7-E<B=S(&9R964O8G5S>2!I;F9O
M<FUA=&EO;B!W87,@<W5C97-S9G5L;'D@<W1O<F5D+B(*;7-G<W1R(")"<G5K
M97)E;G,@;&5D:6<O;W!P=&%T="!I;F9O<FUA<VIO;B!B;&4@;&%G<F5T+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-3(*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$P,R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3`W"B,L
M(&9U>GIY"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B1&5T(&5R(&EN9V5N(&UE;&1I;F=E<B!I(&1E
M;FYE('!O<W1B;VMS96XN(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y
M("<E<R<@;F]T(&9O=6YD+B(*;7-G<W1R(")6961L96=G970@8FQE(&EK:V4@
M9G5N;F5T+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3@R"B,L(&9U
M>GIY"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM
M<V=S='(@(D1E="!E<B!I;F=E;B!M96QD:6YG97(@:2!D96YN92!P;W-T8F]K
M<V5N+B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HS-#`*(RP@
M9G5Z>GD*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D
M:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R(")$970@97(@:6YG96X@86QT97)N
M871I=F4@9&5L97(@<V]M(&MA;B!V:7-E<R!I;FQI;F4N(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$S.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U
M(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E
M<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HQ,#0X"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E(&1O97-N)W0@
M>65T(&5X:7-T(&$@:&5L<"!F:6QE(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@
M<VEG;G5P+G!H<#HU-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@)R5S)R!T;R!T:&4@<WES=&5M+B`E
M<RXB"FUS9W-T<B`B1&5T(&]P<'-T;V0@970@<')O8FQE;2!U;F1E<B!S;&5T
M=&EN9V5N(&%V("5S+B!-96QD:6YG(&9R82!S97)V97)E;B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@82!P<F]B;&5M(&%D9&EN9R`G)7,G('1O('1H92!S>7-T96TZ("5S
M(@IM<V=S='(@(D1E="!O<'!S=&]D(&5T('!R;V)L96T@=6YD97(@<VQE='1I
M;F=E;B!A=B`E<RX@365L9&EN9R!F<F$@<V5R=F5R96XB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`G)7,G(&9R
M;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*(D1E="!O<'!S=&]D(&5T('!R
M;V)L96T@=F5D(&9J97)N:6YG(&%V('!O<W1B;VMS96XN($UE;&1I;F<@9G)A
M('-E<G9E<F5N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG
M("<E<R<@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B1&5T(&]P<'-T;V0@
M970@<')O8FQE;2!U;F1E<B!S;&5T=&EN9V5N(&%V("5S+B!-96QD:6YG(&9R
M82!S97)V97)E;B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN
M9R`G)7,G.B`E<R(*;7-G<W1R(")$970@;W!P<W1O9"!E;B!F96EL('5N9&5R
M(&]P<&1A=&5R:6YG(&%V(&AE;F1E;'-E;CH@)7,B"@HC.B!L:6(O2&]R9&4O
M0G)O=W-E<BYP:'`Z.#DY"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U
M<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP
M.CDP-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B
M;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T
M:&%N('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3`V"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T
M:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L
M;V%D960N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C,X"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA
M>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R(")$970@;W!P<W1O9"!E
M;B!F96EL('5N9&5R(&9O<G/X:R!PY2#E('9I<V4@9&5N;F4@;65L9&EN9W-D
M96QE;B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#(@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0HC+"!F=7IZ>0IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C
M="!D871A+B(*;7-G<W1R(")$970@;W!P<W1O9"!E;B!F96EL('9E9"!I;7!O
M<G1E<FEN9R!A=B!H96YD96QS96XZ("5S+B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&5V96YT.B`E<RXB
M"FUS9W-T<B`B1&5T(&]P<'-T;V0@96X@9F5I;"!U;F1E<B!I;7!O<G1E<FEN
M9R!A=B!H96YD96QS96XZ("5S+B(*"B,Z(&QI8B](;W)D92]$871A+VEM8RYP
M:'`Z,S(*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(")$970@;W!P<W1O
M9"!E;B!F96EL('5N9&5R(&EM<&]R=&5R:6YG(&%V(&AE;F1E;'-E;CH@)7,N
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3`U
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@=&AE('1A<VLZ("5S+B(*;7-G<W1R(")$970@;W!P<W1O9"!E;B!F
M96EL('9E9"!I;7!O<G1E<FEN9R!A=B!H96YD96QS96XZ("5S+B(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.CDQ"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=7-E
M<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;CH@)7,N(@IM<V=S='(@(B(*(D1E
M="!O<'!S=&]D(&5N(&9E:6P@=F5D(&EM<&]R=&5R:6YG(&%V(&)R=6ME<F5N
M<R!L961I9R]O<'!T871T+6EN9F]R;6%S:F]N.B`E(@HB<R(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H
M87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R
M(")$970@;W!P<W1O9"!E;B!F96EL('5N9&5R(&]P<&1A=&5R:6YG(&%V(&AE
M;F1E;'-E;CH@)7,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`Y-2!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3$P,2!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(R-@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(S,@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@;W!E;FEN9R!T:&4@9FEL92`E<RX@
M5')Y(')U;FYI;F<@=')A;G-L871I;VXN<&AP('=I=&@@=&AE("(*(F9L86<@
M+60@=&\@<V5E(&%N>2!E<G)O<B!M97-S86=E<R!F<F]M('1H92!X;6P@<&%R
M<V5R+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C8S"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R
M;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC
M=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B1&5T
M(&]P<'-T;V0@96X@9F5I;"!U;F1E<B!O<'!D871E<FEN9R!A=B!H96YD96QS
M96XZ("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8V
M-0HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T
M:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N(@IM<V=S='(@(D1E="!O<'!S=&]D(&5N(&9E:6P@=6YD97(@;W!P9&%T
M97)I;F<@878@:&5N9&5L<V5N.B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-S`*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A
M<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(D1E="!O<'!S=&]D(&5N
M(&9E:6P@=6YD97(@;W!P9&%T97)I;F<@878@:&5N9&5L<V5N.B`E<R(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-3,*(RP@9G5Z>GD*
M;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R
M:6YG(&9O;&1E<G,N(@IM<V=S='(@(D1E;FYE('1J96YE<F5N('-T^'1T97(@
M:6MK92!D96QI;F<@878@;6%P<&5R+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C@R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.CDV"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C$Q,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HR,#`*;7-G:60@(E1H:7,@86-T:6]N(&ES(&YO="!S=7!P
M;W)T960N(@IM<V=S='(@(D1E;B!F;W)E<W!U<G1E(&]P<&=A=F5N(&5R(&EK
M:V4@<W1O='1E="XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HQ,3@*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z,S4Y"FUS9VED(")4:&ES(&%C=&EO;B!I<R!N;W0@>65T(&EM<&QE
M;65N=&5D+B(*;7-G<W1R(")$96X@9F]R97-P=7)T92!O<'!G879E;B!E<B!I
M:VME(&EM<&QE;65N=&5R="XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F%R+G!H<#HU,0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E
M87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B)7,@<V5R
M(&EK:V4@=70@<V]M(&5N(&=Y;&1I9R!P;W-T8F]K<RXB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O>FEP+G!H<#HU-0HC+"!F=7IZ>0IM<V=I9"`B5&AI
M<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS
M9W-T<B`B)7,@<V5R(&EK:V4@=70@<V]M(&5N(&=Y;&1I9R!P;W-T8F]K<RXB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$S,`HC+"!F=7IZ>0IM<V=I9"`B
M5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N
M(@IM<V=S='(@(B5S('-E<B!I:VME('5T('-O;2!E;B!G>6QD:6<@<&]S=&)O
M:W,N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#<*
M;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T
M96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@
M(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S0*;7-G
M:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC
M;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC
M.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@R"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V
M:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y
M+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M
M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W
M=RXQ.3`N:70I+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M.3<S(&QI8B](;W)D92]&;W)M+G!H<#HQ,#4R(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,#@Q"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3$P(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,3<T(&QI8B](;W)D92]&;W)M+G!H<#HQ,C0X"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,C@R(&QI8B](;W)D92]&;W)M+G!H<#HQ,SDU(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-30W"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.#(W(&QI8B](;W)D92]&;W)M+G!H<#HQ.30R(&QI8B](;W)D92]&;W)M+G!H
M<#HQ.3@Y"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#$S(&QI8B](;W)D92]&
M;W)M+G!H<#HR,#8R(&QI8B](;W)D92]&;W)M+G!H<#HR,3,S"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,C`U(&QI8B](;W)D92]&;W)M+G!H<#HR,SDS(&QI
M8B](;W)D92]&;W)M+G!H<#HR-#,W"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M-C0Y(&QI8B](;W)D92]&;W)M+G!H<#HR.#$W(&QI8B](;W)D92]&;W)M+G!H
M<#HS,3(R"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS-CDR(&QI8B](;W)D92]&
M;W)M+G!H<#HS-S`P"B,L(&9U>GIY"FUS9VED(")4:&ES(&9I96QD(&ES(')E
M<75I<F5D+B(*;7-G<W1R("(E<R!H87(@879S;.5T="XB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3`V,`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C
M;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C0P,0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$P.#D*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,3$X"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C
M;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3@T"B,L(&9U>GIY"FUS
M9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S
M='(@(D1E='1E(&WE(';F<F4@970@=&%L;"XB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C@R-0IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@
M82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP
M;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P
M<F]C97-S960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]H96QP+V%B;W5T
M+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#,W"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T
M+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@
M(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R
M92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S
M('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-
M12]#;VYT96YT<RYP:'`Z-C`W"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@
M;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O
M=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M4')E9G,O54DN<&AP.C$R.`IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A
M="!L96%S="!O;F4N(@IM<V=S='(@(D1E='1E('1A;&QE="!MY2!VYG)E(&UI
M;G-T(#$N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R.#4*(RP@9G5Z>GD*
M;7-G:60@(E1H:7,@<V-R:7!T(&UU<W0@8F4@<G5N(&9R;VT@=&AE(&-O;6UA
M;F0@;&EN92XB"FUS9W-T<B`B1&5T=&4@=FEN9'5E="!MY2!B;&D@Y7!N970@
M9G)A("=.>2!M96QD:6YG)R!V:6YD=65T(@H*(SH@;&EB+TAO<F1E+T-O;7!R
M97-S+V=Z:7`N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")4:&ES('-E<G9E<B!C
M86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B
M1&5N;F4@=&IE;F5R96X@<W3X='1E<B!I:VME(&1E;&EN9R!A=B!M87!P97(N
M(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HQ-#<*;7-G:60@(E1H:7,@
M<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@=F%L
M=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B1&5T=&4@;>4@=N9R92!E
M="!T86QL+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z
M,S4*(RP@9G5Z>GD*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D
M(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B1&5T=&4@=FEN9'5E
M="!MY2!B;&D@Y7!N970@9G)A("=.>2!M96QD:6YG)R!V:6YD=65T(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,W,0IM<V=I9"`B5&AU;F1E
M<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(U
M"FUS9VED(")4:6-K971S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR-#$Q"B,L(&9U>GIY"FUS9VED(")4:6UE(@IM<V=S='(@(E1I='1E
M;"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,3$*;7-G:60@(E1I
M;64@5')A8VMI;F<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP
M.C$W"B,L(&9U>GIY"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R(")&;W)M
M870@<.4@;F%V;B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3(R"B,L(&9U
M>GIY"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R(")&:6QT97)I;FYS
M=&EL;&EN9V5R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S(@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(E1I='1E
M;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z.#`*;7-G:60@(E1O(@IM
M<V=S='(@(E1I;"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HV,CD*(RP@9G5Z>GD*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L
M92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N
M9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*(D9O
M<B#E('9E;&=E(&9L97)E+"!H;VQD(&YE9&4@0V]N=')O;"`H4$,I(&5L;&5R
M($-O;6UA;F0@*$UA8RD@;65N<R!D=2!K;&EK:V5R(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(U,0HC+"!F=7IZ>0IM<V=I9"`B5&]D87DB
M"FUS9W-T<B`B365L9&EN9W-T96MS="(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O
M=7)C92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(S
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$P"B,L(&9U>GIY"FUS9VED(")4;V=O(@IM<V=S
M='(@(E1I;"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3$*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,PHC+"!F=7IZ>0IM<V=I9"`B
M5&]M;W)R;W<B"FUS9W-T<B`B3GD@;65L9&EN9R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R
M-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*(RP@9G5Z>GD*;7-G
M:60@(E1O;F=A(@IM<V=S='(@(E1I;"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PHC+"!F=7IZ>0IM<V=I9"`B
M5&]P(@IM<V=S='(@(E1I;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS
M9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8U-PHC+"!F=7IZ>0IM
M<V=I9"`B5')A;G-L871E9"(*;7-G<W1R(")58F5S=F%R="(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B5')A;G-L871I
M;VYS(@IM<V=S='(@(D]R9V%N:7-E<FEN9R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1R:6YI9&%D
M(&%N9"!4;V)A9V\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$W-S@*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B
M5'4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5N:7-I82(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,Q(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R
M"B,L(&9U>GIY"FUS9VED(")4=7)K97DB"FUS9W-T<B`B;OAK:V5L(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(E1U<FMI<V@@*$E33RTX
M.#4Y+3DI(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*(RP@9G5Z>GD*;7-G:60@(E1U<FMM96YI
M<W1A;B(*;7-G<W1R(")/8G-E<G9E<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1U<FMS(&%N9"!#
M86EC;W,@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C,S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")4=79A;'4B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z,C8R"FUS9VED(")4>7!E
M('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(R-PIM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C4R(&QI
M8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,0IM<V=I
M9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3<*(RP@9G5Z>GD*;7-G:60@(E523#HB"FUS9W-T<B`B55),
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q,PHC+"!F=7IZ>0IM<V=I9"`B56=A;F1A(@IM<V=S='(@(DMA;&5N9&5R
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q,PHC+"!F=7IZ>0IM<V=I9"`B56MR86EN92(*;7-G<W1R(")':F5N;W!P
M<F5T="(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S8P"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DMA
M;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC.B!L:6(O2&]R9&4O
M075T:"]3:6=N=7`N<&AP.C$P,`IM<V=I9"`B56YA8FQE('1O(&%D9"!E>'1R
M82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS9W-T<B`B
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,T-@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS
M97)V97)E;BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,S,"!L:6(O5D93+VUU
M<W%L+G!H<#HU,#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM
M<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC.B!L
M:6(O5D93+V9T<"YP:'`Z-S`T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R(")+86X@:6MK92!K
M;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+TAO<F1E+T%U=&@O<W%L
M+G!H<#HS-S4*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V
M97(N(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB
M"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S@X"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B2V%N(&EK:V4@:V]B
M;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3<P
M(&QI8B]61E,O9FEL92YP:'`Z,3<U(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$Y
M-PHC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,#(@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,C$P"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@
M9FEL92XB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N
M+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS,C`*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S
M7"(N(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB
M"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(Y-2!L:6(O5D93+VUU<W%L+G!H<#HR
M-S,@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C<P"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DMA;B!I
M:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC.B!L:6(O5D93+VUU<W%L
M+G!H<#HQ,C8*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93
M(&9I;&4N(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E
M;BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(Q,@HC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B2V%N
M(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B](;W)D92]#
M;VUP<F5S<R]T87(N<&AP.C<Y(&QI8B](;W)D92]#;VUP<F5S<R]G>FEP+G!H
M<#HX,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T
M82XB"FUS9W-T<B`B2VQA<G1E(&EK:V4@Y2!H96YT92!I;F9O<FUA<VIO;B!O
M;2!K=F]T92(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR-#D*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@
M9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B2V%N(&EK:V4@:V]B
M;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C<P
M(&QI8B]61E,O<W%L+G!H<#HS,C,@;&EB+U9&4R]M=7-Q;"YP:'`Z,S,U"B,Z
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,V,@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='DB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E
M<G9E<F5N+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-SD@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HU.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92`G)7,G.B`E<RXB"FUS9W-T<B`B2V%N(&EK:V4@:V]B
M;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C,W."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS.#(*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB
M"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z
M(&QI8B]61E,O9FEL92YP:'`Z,C<V(&QI8B]61E,O;75S<6PN<&AP.C,T."!L
M:6(O5D93+VUU<W%L+G!H<#HS-C$*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,S8Y
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,W-`HC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")+86X@:6MK
M92!K;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+U9&4R]S<6PN<&AP
M.C,T."!L:6(O5D93+W-Q;"YP:'`Z,S8P"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*
M;7-G<W1R(")+86X@:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@
M;&EB+U9&4R]F='`N<&AP.C$W.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C(T,B!L:6(O5D93+W-Q;"YP:'`Z,C$S(&QI8B]61E,O;75S
M<6PN<&AP.C$W,PHC.B!L:6(O5D93+VUU<W%L+G!H<#HQ.#8@;&EB+U9&4R]M
M=7-Q;"YP:'`Z,3DS(&QI8B]61E,O<W%L7V9I;&4N<&AP.C0Q,@HC.B!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HT,C`*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I
M;"!344QS97)V97)E;BXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,S,W"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R
M96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!3
M44QS97)V97)E;BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S4R"B,L(&9U>GIY
M"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y
M+B(*;7-G<W1R(")+86X@:6MK92!R96=I<W1R97)E(&EN<W1I;&QI;F=E;F4@
M:2#X:W1E;BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8R-PHC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@
M9&5T86EL<R(*;7-G<W1R(")3971T(&EN;B!S97)T:69I:V%T(&AE<B(*"B,Z
M(&QI8B].970O24U34"YP:'`Z-#8P(&QI8B].970O24U34"]!=71H+G!H<#HQ
M,3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D
M('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("(E<R!H87(@<W9A<G0@
M<.4@:6YV:71A<VIO;F5N('1I;"`E<RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP
M.C$S.2!L:6(O5D93+V9I;&4N<&AP.C$T-"!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HQ-C4*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3<P"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EK
M:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O9G1P+G!H
M<#HW.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P
M96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")+86X@:6MK92!K;V)L92!T
M:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,3D@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z,3(W(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$S
M,`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R
M('=R:71I;F<N(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V
M97)E;BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C<S(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@
M9FEL92XB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N
M+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C0W"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N
M(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC
M.B!L:6(O5D93+V9I;&4N<&AP.C8R,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE
M('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R(")+86X@
M:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HQ,#DU"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X
M:7-T<R(*;7-G<W1R("(B"@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS,38*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N+B(*
M"B,Z(&QI8B]61E,O<W%L+G!H<#HR-34*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM
M<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC.B!L
M:6(O5D93+V9T<"YP:'`Z,CDV"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O
M9FEL92YP:'`Z-38S(&QI8B]61E,O;75S<6PN<&AP.C(T,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E
M<R\E<RXB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N
M+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HR-#D@;&EB+U9&4R]M=7-Q;"YP:'`Z
M,C(R(&QI8B]61E,O;75S<6PN<&AP.C0X-0HC.B!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HS,#4@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S(W"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R(")+86X@
M:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+U9&4R])4T]7
M<FET97(O;6MI<V]F<RYP:'`Z-3$*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R(")+86X@:6MK92!K;V)L92!T:6P@
M4U%,<V5R=F5R96XN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS=V]R
M9"YP:'`Z-C(*;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D
M(&1O8W5M96YT(@IM<V=S='(@(DMA;B!I:VME(&]V97)S971T92!D971T92!7
M;W)D+61O:W5M96YT970B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,3(W(&QI8B]6
M1E,O9G1P+G!H<#HQ,S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DML87)T
M92!I:VME(.4@:&5N=&4@:6YF;W)M87-J;VX@;VT@:W9O=&4B"@HC.B!L:6(O
M5D93+V9I;&4N<&AP.C$R,`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B2VQA<G1E
M(&EK:V4@Y2!H96YT92!I;F9O<FUA<VIO;B!O;2!K=F]T92(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z,C(S(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$S-2!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HQ-#`*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R(")+;&%R=&4@:6MK92#E
M(&AE;G1E(&EN9F]R;6%S:F]N(&]M(&MV;W1E(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`HC+"!F=7IZ>0IM<V=I9"`B
M56YD97)L:6YE(@IM<V=S='(@(D=J96YO<'!R971T(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@
M(D%N9W)E(&5N9')I;F=E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S,*(RP@9G5Z>GD*;7-G:60@(E5N9&]E<R!Y;W5R
M(&QA<W0@86-T:6]N(@IM<V=S='(@(D=J96YO<'!T82!S97-J;VXB"@HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C,P(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS.3D*;7-G:60@(E5N97AP96-T960@<F5S
M<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C8@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,U,`HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S@W(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS.3,*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S
M97)V97(@=&\Z("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T
M96=O<GE-86YA9V5R+G!H<#HU.`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHV-`HC+"!F=7IZ>0IM<V=I9"`B56YF:6QE9"(*
M;7-G<W1R(")%+7!O<W0B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HS.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YH86YD;&5D
M(&-O;7!O;F5N="!O9B!T>7!E.B`E<R(*;7-G<W1R(")5:.5N9'1E<G0@:V]M
M<&]N96YT(&%V('1Y<&5N.B`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@Y"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@
M(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(S-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B56YI
M=&5D($MI;F=D;VTB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(T,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B56YI=&5D(%-T871E
M<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,Y(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$T"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U
M=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C8U(&QI8B]";&]C:R]M971A<BYP:'`Z-CD*;7-G:60@
M(E5N:71S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C0Q-2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,38*(RP@9G5Z>GD*;7-G
M:60@(E5N:VYO=VXB"FUS9W-T<B`B56MJ96YT(&1A=&\B"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B56YK;F]W;B!A
M<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B56YK;F]W
M;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,30X,@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B56YK;F]W;B!C;VUM86YD.B`E<R(*;7-G<W1R("),87-T(&YE
M9"!M87!P96XH92DB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P,`HC+"!F=7IZ>0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P
M87-S=V]R9"XB"FUS9W-T<B`B5F5N;FQI<W0@<VMR:78@:6YN(&)R=6ME<FYA
M=FX@;V<@<&%S<V]R9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PHC+"!F=7IZ>0IM<V=I9"`B56YL:6YK
M('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B4VQE='0@;N5VYG)E;F1E
M(&[X:VQE<B(*"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z,CDX"FUS9VED
M(")5;FYA;65D(@IM<V=S='(@(E5T96X@;F%V;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I
M=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@
M<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI
M8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@
M=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A
M8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@HC+"!F=7IZ
M>0IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`B4V5T="!I;FX@<V5R=&EF
M:6MA="!H97(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<Q,"!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.CDU,@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.CDU.`HC+"!F=7IZ>0IM<V=I9"`B56YS=7!P;W)T960@
M17AT96YS:6]N(@IM<V=S='(@(E5S=7!P;W)T97)T(&EN;FAO;&1S+71Y<&4N
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8U-PHC+"!F=7IZ>0IM<V=I9"`B
M56YT<F%N<VQA=&5D(@IM<V=S='(@(E5B97-V87)T(@H*(SH@861M:6XO<&5R
M;7,O961I="YP:'`Z,3`V(&QI8B](;W)D92]097)M<R]522YP:'`Z,3DQ"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,V"B,L(&9U>GIY"FUS
M9VED(")5<&1A=&4B"FUS9W-T<B`B4VES=&4@;W!P9&%T97)I;F<Z(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(E-I<W1E(&]P
M<&1A=&5R:6YG.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C8T.`IM<V=I9"`B57!D871E(')E<W!O;F1E;G0@<W1A='5S(@IM
M<V=S='(@(D]P<&1A=&5R('-T871U<R!PY2!A=G-E;F1E<F4B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,L(&9U>GIY"FUS9VED
M(")5<&1A=&4@=7-E<B(*;7-G<W1R(")3:7-T92!O<'!D871E<FEN9SHB"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C$S-R!A9&UI;B]P97)M<R]E9&ET+G!H<#HR
M,3<@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B57!D871E9"`G)7,G+B(*;7-G<W1R(")2961I9V5R
M("<E<R<B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`X,"!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,3(Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&EN9R`E
M<R!H96QP(&9I;&4@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HX,0IM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E
M9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W,B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3@R"FUS9VED(")5
M<&QO860B"FUS9W-T<B`B3&%S="!O<'`B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3@P"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T
M=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM
M<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X
M"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(S.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G
M:60@(E5R=6=U87DB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C,U('!O+W1R86YS;&%T:6]N+G!H<#HY,B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M.3,*(RP@9G5Z>GD*;7-G:60@(E5S86=E.B(*;7-G<W1R(")"<G5K97)N879N
M.B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0V
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B
M"FUS9W-T<B`B4VQE='0@;N5VYG)E;F1E(&[X:VQE<B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3@*;7-G:60@(E5S92!34TPB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,PIM<V=I9"`B
M57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E
M<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HV
M-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R
M:7-E9"!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P
M-`HC+"!F=7IZ>0IM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R
M("(E<R!01U`@861M:6YI<W1R87-J;VXB"@HC.B!L:6(O2&]R9&4O4')E9G,O
M54DN<&AP.C(U,0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(DQA9W)E
M(%9A;&<B"@HC.B!S:6=N=7`N<&AP.C8T"B,L(&9U>GIY"FUS9VED(")5<V5R
M(%)E9VES=')A=&EO;B(*;7-G<W1R("),86=R92!686QG(@H*(SH@<VEG;G5P
M+G!H<#HQ.0HC+"!F=7IZ>0IM<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S
M(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`B1FEL=&5R
M<W3X='1E(&5R(&%V<VSE='0@:2!D971T92!S>7-T96UE="XB"@HC.B!A9&UI
M;B]P97)M<R]E9&ET+G!H<#HQ-S(@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR
M-30*(RP@9G5Z>GD*;7-G:60@(E5S97(@<&5R;6ES<VEO;G,B"FUS9W-T<B`B
M3&%G<F4@5F%L9R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-S,*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4U-B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDW
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`R('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z-C4@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z
M,3$*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(D)R=6ME<FYA=FXB"@HC.B!L
M:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C$S,0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B57-E<FYA;64@)R5S)R!A;')E861Y(&5X:7-T<RXB"FUS
M9W-T<B`B36%P<&5N(%PB)7-<(B!F:6YN97,@86QL97)E9&4B"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*
M;7-G<W1R(")"<G5K97)N879N.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B
M0G)U:V5R;F%V;CHB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(R-PHC
M+"!F=7IZ>0IM<V=I9"`B57-E<G,B"FUS9W-T<B`B0G)U:V5R;F%V;B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*;7-G:60@(E5S97)S
M(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,34*(RP@9G5Z>GD*;7-G:60@
M(E5Z8F5K:7-T86XB"FUS9W-T<B`B1&%T;R(*"B,Z(&QI8B]61E,O9FEL92YP
M:'`Z,3`Y(&QI8B]61E,O9FEL92YP:'`Z,C`R"B,L(&9U>GIY"FUS9VED(")6
M1E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")$96X@<W!E
M<VEF:7-E<G1E(&9I;&5N(&5K<VES=&5R97(@:6MK92XB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S@S"B,L(&9U>GIY"FUS9VED(")686-A=&EO
M;B(*;7-G<W1R("),;VMA<VIO;B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX
M-C$*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-C(*;7-G
M:60@(E9A;&ED:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,C$@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR-C,*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C(X(&QI8B](;W)D
M92]&;W)M+G!H<#HR,C4P(&QI8B](;W)D92]&;W)M+G!H<#HR,CDX"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR.3$W"B,L(&9U>GIY"FUS9VED(")686QU97,B
M"FUS9W-T<B`B26YG96X@;65L9&EN9V5R(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(P.3,@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q-S`*;7-G:60@(E9A;'5E
M<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C0Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#`*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")686YU871U
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,#<*(RP@9G5Z>GD*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(E1I='1E;"(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#4@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,38*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C(R.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE
M9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S(T
M"B,L(&9U>GIY"FUS9VED(")697)S:6]N(@IM<V=S='(@(E!E<G-O;FQI9R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#`*(RP@9G5Z>GD*;7-G
M:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R(")097)S;VYL:6<B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S
M"B,L(&9U>GIY"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R(")&971C
M:&UA:6PZ("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#0*(RP@9G5Z>GD*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS
M9W-T<B`B1F5T8VAM86EL.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@S"B,L(&9U>GIY"FUS9VED(")697)T:6-A;#HB
M"FUS9W-T<B`B1F5T8VAM86EL.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S<W"B,L(&9U>GIY"FUS9VED(")697)Y($AI9V@B"FUS9W-T
M<B`B2/AY(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T."!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B
M3F%V;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")6:65T
M;F%M97-E("A625-#24DI(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%
M+T-O;G1E;G1S+G!H<#HY.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E
M<R(*;7-G<W1R(")6:7,@)7,B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS
M"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#4*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B5FES("5S
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-SD*
M;7-G:60@(E9I97<@979E;G0B"FUS9W-T<B`B5FES(&AE;F1E;'-E(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3`Y"FUS9VED
M(")6:65W('1A<VLB"FUS9W-T<B`B5FES(&AA;F1L:6YG97(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C0V(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR-#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C0W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR-#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(P-PIM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(Q"FUS9VED(")6
M:7-I8FEL:71Y.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<#HX,0IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA
M(%--5%`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.C,Y"FUS9VED(")705).(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"B,L('!H<"UF;W)M870*
M;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-
M("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")786QL:7,@86YD($9U='5N82(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+W-T871U<RYP:'`Z,S$*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B061V87)S
M96PB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,30U('!O+W1R86YS;&%T:6]N
M+G!H<#HV.#$@<&\O=')A;G-L871I;VXN<&AP.C<Q,0HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-S(U('!O+W1R86YS;&%T:6]N+G!H<#HQ,#0X('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,#4W"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#8U('!O
M+W1R86YS;&%T:6]N+G!H<#HQ,#<U('!O+W1R86YS;&%T:6]N+G!H<#HQ,#@U
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#DU('!O+W1R86YS;&%T:6]N+G!H
M<#HQ,3`Q('!O+W1R86YS;&%T:6]N+G!H<#HQ,C$V"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HQ,C(V('!O+W1R86YS;&%T:6]N+G!H<#HQ,C,R('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,C4R"B,L(&9U>GIY"FUS9VED(")787)N:6YG.B`B"FUS
M9W-T<B`B061V87)S96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4*;7-G:60@(E=E871H97(@1F]R
M96-A<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,P-0IM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX.#<*;7-G:60@(E=E871H
M97(N8V]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V
M"FUS9VED(")796(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,Y,`HC+"!F=7IZ>0IM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B
M5V5B<VED92!A9')E<W-E(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H
M<#HS-PIM<V=I9"`B5V5E:VQY(@IM<V=S='(@(E5K96YT;&EG(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@(E=E
M;&-O;64B"FUS9W-T<B`B5F5L:V]M;65N(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4P"B,L
M('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B5F5L
M:V]M;65N('1I;"`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP
M.C(Y('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R(")696QK;VUM96XL("5S(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(E=E<W1E<FX@*$E3
M3RTX.#4Y+3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DR"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*
M;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT,C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G
M:6X_(@IM<V=S='(@(E9I<VYI;F<@96QL97(@<&]S=&)O:W,@<V]M('-K86P@
M=FES97,@971T97(@:6YN;&]G9VEN9SHB"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHR,0IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H
M87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,C0*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7
M:&EC:"!P:&%S97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$S,0IM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H
M92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"B,L(&9U>GIY
M"FUS9VED(")7:61T:"(*;7-G<W1R(")3^&LB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S$Q,`IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A
M:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED
M(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*(RP@9G5Z>GD*;7-G
M:60@(E=I9'1H('5N:70B"FUS9W-T<B`B4_AK(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*(RP@9G5Z>GD*;7-G:60@
M(E=I9'1H.B(*;7-G<W1R(")3^&LB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#DP"FUS9VED(")7:6MI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS-S(*(RP@9G5Z>GD*;7-G:60@(E=I;F0B
M"FUS9W-T<B`B4_AK(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,W,PHC+"!F=7IZ>0IM<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R(")!=G-L
MY71T.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C<X"FUS9VED(")7:6YD
M('-P965D(&EN(&MN;W1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,34T"B,L(&9U>GIY"FUS9VED(")7:6YD.B(*;7-G<W1R(")3^&LB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`U"B,L(&9U>GIY
M"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B079S;.5T=#H@(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8T"B,L(&9U>GIY"FUS9VED(")7:7-D;VTB"FUS
M9W-T<B`B4_AK(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$W-PHC
M+"!F=7IZ>0IM<V=I9"`B5VES:&QI<W1S(@IM<V=S='(@(D)E=')O9&1E(&%D
M<F5S<V5R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"B,L(&9U>GIY
M"FUS9VED(")7;W)K(@IM<V=S='(@(F5L;&5R(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,C<@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ-C<*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")&
M:7)M86%D<F5S<V4B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y-0IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")&:7)M871E;&5F
M;VXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$U-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")7<FET:6YG('5P9&%T960@:&5L<"!F:6QE('1O("5S+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,T"FUS9VED
M(")8+5)E9B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C8Q-PIM<V=I9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C$V"FUS9VED
M(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C$X"FUS9VED(")8-3`Y=C,@4W5B
M:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-C$Y"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+
M97D@261E;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C<P-@IM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S
M='(@(N7E(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,X-B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(W"B,L
M(&9U>GIY"FUS9VED(")965E9(@IM<V=S='(@(N7E(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#(*;7-G:60@(EEA:&]O(2!M
M87`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HS
M-0IM<V=I9"`B665A<FQY(@IM<V=S='(@(N5R;&EG(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(U,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`HC+"!F=7IZ>0IM
M<V=I9"`B665M96XB"FUS9W-T<B`B3&5S="(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX.#@*;7-G:60@(EEE<R(*;7-G<W1R(")*
M82(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]A9W)E96UE;G1?8F]T=&]M
M+FEN8SHV"FUS9VED(")997,L($D@06=R964B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B
M66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O
M('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92YP:'`Z,3,R-@IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H<#HS,#0*
M;7-G:60@(EEO=2!C86X@;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN
M('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3@S.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DU.0HC+"!F=7IZ>0IM
M<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S
M+B(*;7-G<W1R(")696YN;&EG<W0@<F5T="!T=F5T>61I9V4@96QL97(@=6=Y
M;&1I9V4@861R97-S97(N(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C(W-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE
M;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I
M;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M075T:"YP:'`Z.30T"B,L(&9U>GIY"FUS9VED(")9;W4@:&%V92!B965N(&QO
M9V=E9"!O=70N(@IM<V=S='(@(D1I;F4@=F%L9R!H87(@8FQI='0@;W!P9&%T
M97)T(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-3,*;7-G:60@(B(*(EEO
M=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG
M:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E
M<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3$X,`HC+"!F=7IZ>0IM<V=I9"`B66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B5F5N;FQI9W-T('-K
M<FEV(&EN;B!D970@;GEE(&YA=FYE=#HB"@HC.B!L:6(O2&]R9&4O075T:"]3
M:6=N=7`N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!C;VYF:6=U
M<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R
M(")+=6YN92!I:VME(&QA9V4@5D93+6)A8VME;F0Z("5S(@H*(SH@;&EB+TAO
M<F1E+G!H<#HT-#<*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R
M92!A(%9&4R!B86-K96YD+B(*;7-G<W1R(")+=6YN92!I:VME(&QA9V4@5D93
M+6)A8VME;F0Z("5S(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E
M9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R
M(")$=2!MY2!B97-K<FEV92!P<F]B;&5M970@9OAR(&1U(&MA;B!S96YD92!E
M;B!P<F]B;&5M<F%P<&]R="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDX"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!E
M;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T
M<B`B1'4@;>4@:&$@;6EN<W0@Z6X@;6]T=&%K97(N(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W)P8W-U;2YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T
M('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B1'4@
M;>4@=F5L9V4@96X@:61E;G1I=&5T('-O;2!S:V%L('-L971T97,N(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3$Y"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S
M<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R(")$=2!M
MY2!S<&5S:69I<V5R92!E;B!M;W1T86ME<BXB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ,#`*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R
M;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(D1U(&WE('-P97-I9FES97)E(&5N
M(&UO='1A:V5R+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R(")$=2!M
MY2!F^')S="!S<&5S:69I<V5R92!F:6QE;B!S;VT@<VMA;"!L96=G97,@=F5D
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@HC+"!F=7IZ>0IM<V=I9"`B66]U
M(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R
M(")$=2!MY2!F^')S="!S<&5S:69I<V5R92!F:6QE;B!S;VT@<VMA;"!L96=G
M97,@=F5D+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$T-`HC
M+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T
M;R!P97)F;W)M+B(*;7-G<W1R(")$=2!MY2!S<&5S:69I<V5R92!E;B!M;W1T
M86ME<BXB"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H
M<#HW,PHC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E
M9V]R>2!N86UE+B(*;7-G<W1R(")$=2!MY2!S<&5S:69I<V5R92!E;B!M;W1T
M86ME<BXB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3,R"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E
M(&QO9VEN(&%G86EN+B(*;7-G<W1R(")$:6X@)7,@=&EL:V]B:6YG(&AA<B!G
MY71T('5T+B!696YN;&EG<W0@;&]G(&EN;B!I9VIE;BXB"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`HC+"!F=7IZ>0IM<V=I9"`B66]U
M<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(D5P;W-T861R97-S96X@9&EN.B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#(*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B17!O<W1A9')E<W-E;B!D
M:6XZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HW-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T:6]N
M(@IM<V=S='(@(D1I;B!I;F9O<FUA<VIO;B(*"B,Z(&QI8B](;W)D92]!=71H
M+G!H<#HY,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE
M="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@
M>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL
M('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.86UE(@IM
M<V=S='(@(D9U;&QT(&YA=FXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N
M;V%D9"YI;F,Z.0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+"!O<B!T:&4@9F5A
M='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S
M;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES
M="YI;F,Z.0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD
M(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U
M<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N
M+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.30P"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA
M=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S
M<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L
M;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP
M:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S
M=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B3F5T=&QE<V5R96X@9&EN
M('-T^'1T97(@:6MK92!V:7-N:6YG(&%V(&1E;FYE('1Y<&4@8FEL9&5R(&EN
M;&EN92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHR-PIM
M<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P
M<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO3W!T:6]N("L@4"!T;R`B"B)P
M<FEN="XB"FUS9W-T<B`B(@HB3F5T=&QE<V5R96X@9&EN('-T^'1T97(@:6MK
M92!D96YN92!U='-K:69T<V]P97)A<VIO;F5N+B!4<GEK:R!+;VYT<F]L;"\B
M"B)/<'-J;VX@*R!0(&9O<B#E('-K<FEV92!U="XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C0W"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE
M.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30X"B,L
M(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@
M(E-T86YD87)D:61E;G1I=&5T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Y,0HC+"!F=7IZ>0IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@
M(DYA=FYE="!D:71T.B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ-#4*;7-G
M:60@(B(*(EEO=7(@9V5T=&5X="!V97)S:6]N(&ES('1O;R!O;&0@86YD(&1O
M97,@;F]T('-U<'!O<G0@4$A0(&YA=&EV96QY+EQN(@HB3F]T(&%L;"!S=')I
M;F=S('=I;&P@8F4@97AT<F%C=&5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,34V"B,L(&9U>GIY"FUS9VED(")9
M;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO
M;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(D1I;F4@=F%L9R!H87(@8FQI
M='0@;W!P9&%T97)T(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-3@*
M;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T
M<B`B1&EN92!V86QG(&AA<B!B;&ET="!O<'!D871E<G0B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H
M87,@8F5E;B!R97-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U
M<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHU.`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!R96UO
M=&4@<V5R=F5R<SHB"FUS9W-T<B`B5&IE;F5R(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(U-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G
M:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$Y"B,L(&9U>GIY"FUS9VED("):86ER92(*;7-G<W1R(")&
M<F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$Y"FUS9VED("):86UB:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(U-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B6FEM
M8F%B=V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V
M"FUS9VED(")::7!P>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O5&5X="]&
M:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E
M9"!497AT72(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HU
M-@IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");4')O8FQE;7)A
M<'!O<G1=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N
M:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z
M,3<R"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@
M)7,@;&EN97-=(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92YP:'`Z,3DY"B,L
M('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R(");
M;&EN:F4@)7,@878@)7-=(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-#<R('1E;7!L
M871E<R]P;W)T86PO;65N=2YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E]!9&UI
M;FES=')A=&EO;B(*;7-G<W1R("(E<R!01U`@861M:6YI<W1R87-J;VXB"@HC
M.B!L:6(O87!I+G!H<#HQ,S0*;7-G:60@(E]#3$DB"FUS9W-T<B`B(@H*(SH@
M;&EB+V%P:2YP:'`Z,3(R"B,L(&9U>GIY"FUS9VED(")?1&%T851R964B"FUS
M9W-T<B`B1&%T;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS,0HC+"!F=7IZ>0IM<V=I9"`B7T1E;&5T92!2
M;W<B"FUS9W-T<B`B7U-L971T(@H*(SH@;&EB+V%P:2YP:'`Z,3$T"B,L(&9U
M>GIY"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(D=R=7!P92(*"B,Z(&QI8B](
M;W)D92]-96YU+G!H<#HQ.#$*;7-G:60@(E](96QP(@IM<V=S='(@(DAJ96QP
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(S"B,L(&9U>GIY"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN
M+B(*;7-G<W1R(")&;W)HY6YD<W9I<VYI;F<B"@HC.B!L:6(O2&]R9&4O365N
M=2YP:'`Z,C`P"B,L(&9U>GIY"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(DQO
M9V<@:6YN(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$Y-@IM<V=I9"`B7TQO
M9R!O=70B"FUS9W-T<B`B3&]G9R!U="(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`HC+"!F=7IZ>0IM<V=I
M9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(D9J97)N('!A<B(*"B,Z(&QI
M8B](;W)D92]-96YU+G!H<#HQ-S`*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@
M(E9A;&<B"@HC.B!L:6(O87!I+G!H<#HQ,3@*(RP@9G5Z>GD*;7-G:60@(E]0
M97)M:7-S:6]N<R(*;7-G<W1R(")097)S;VYL:6<B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*(RP@9G5Z
M>GD*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R(")&:F5R;B!P87(B
M"@HC.B!L:6(O87!I+G!H<#HQ,#8*(RP@9G5Z>GD*;7-G:60@(E]3971U<"(*
M;7-G<W1R(")696QG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,R"B,L(&9U>GIY"FUS9VED(")?5&%B;&4@
M4')O<&5R=&EE<RXN+B(*;7-G<W1R(")&;W)HY6YD<W9I<VYI;F<B"@HC.B!L
M:6(O87!I+G!H<#HQ,3`*(RP@9G5Z>GD*;7-G:60@(E]5<V5R<R(*;7-G<W1R
M(")"<G5K97)N879N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,3$*(RP@
M9G5Z>GD*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R(")!9')E<W-E8F]K
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C<Q,0HC+"!F=7IZ>0IM<V=I9"`B
M86X@97)R;W(@:&%S(&]C8W5R960Z(@IM<V=S='(@(CQB/D5N(&9A=&%L(&9E
M:6P@:&%R(&]P<'-TY71T.CPO8CXB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.CDP,PHC+"!F=7IZ>0IM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B2V%L96YD
M97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,"!L:6(O0FQO8VLO;65T
M87(N<&AP.C,U-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*
M;7-G<W1R(")!=F)R>70B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP
M:'`Z-C`X"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HT-#4@<&\O=')A;G-L871I;VXN<&AP.C4U,"!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-C$Q"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW-#D@
M<&\O=')A;G-L871I;VXN<&AP.C@Q,"!P;R]T<F%N<VQA=&EO;BYP:'`Z.#@W
M"B,L(&9U>GIY"FUS9VED(")D;VYE(@IM<V=S='(@(D9E<F1I9R(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HU-3(@<&\O=')A;G-L871I;VXN<&AP.C4X-"!P
M;R]T<F%N<VQA=&EO;BYP:'`Z-C$S"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW
M-S@@<&\O=')A;G-L871I;VXN<&AP.C@Q,B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M.#@Y"B,L(&9U>GIY"FUS9VED(")F86EL960B"FUS9W-T<B`B12UP;W-T(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,W.`IM<V=I9"`B9F%L
M;&EN9R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.#<P
M"B,L(&9U>GIY"FUS9VED(")F:6QE(@IM<V=S='(@(D9I;"(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,CD*(RP@9G5Z>GD*;7-G:60@(F9O=6YD.B`B"FUS
M9W-T<B`B079S;.5T=#H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E
M<RD@870@)7,@)7,B"FUS9W-T<B`B)7,@<.4@)7,@)7,B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,R"FUS9VED(")H.B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`X"FUS9VED
M(")I,3AN(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU.#<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M,CD*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]D:69F+G!H<#HV."!A9&UI;B]S971U<"]D:69F+G!H<#HW-@HC+"!F=7IZ
M>0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(DEN;&EN92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"B,L(&9U>GIY"FUS9VED
M(")L:6YE<UTB"FUS9W-T<B`B26YL:6YE(@H*(SH@;&EB+U9&4R])4T]7<FET
M97(O;6MI<V]F<RYP:'`Z-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F
M<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,C@X('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HR,#8*;7-G:60@(FYA;64B"FUS9W-T<B`B;F%V;B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HS-S@*(RP@9G5Z>GD*;7-G:60@(FYO
M="!C:&%N9V5D(@IM<V=S='(@(D%N9W)E(&5N9')I;F=E<B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,S$*(RP@9G5Z>GD*;7-G:60@(FYO="!F;W5N9"(*
M;7-G<W1R(")/8FIE:W1E="!B;&4@:6MK92!F=6YN970B"@HC.B!L:6(O2&]R
M9&4O4E!#+G!H<#HQ,C(*(RP@9G5Z>GD*;7-G:60@(FYO="!I;7!L96UE;G1E
M9"(*;7-G<W1R(")&97)D:6<B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C$R-#4*(RP@9G5Z>GD*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B
M"FUS9W-T<B`B1&5N(&9O<F5S<'5R=&4@;W!P9V%V96X@97(@:6MK92!I;7!L
M96UE;G1E<G0N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HX.34*(RP@9G5Z
M>GD*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B3F]T871B;&]K:R!F;W(@)7,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@X"B,L(&9U>GIY"FUS9VED(")P97)C96YT(@IM<V=S='(@(E-K<FEV
M('5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.#`*(RP@9G5Z>GD*;7-G:60@(G)I
M<VEN9R(*;7-G<W1R(")/<F=A;FES97)I;F<B"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.CDX"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S,*;7-G
M:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S<Y"B,L(&9U>GIY"FUS9VED(")S=&5A
M9'DB"FUS9W-T<B`B3W!P9&%T97(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.CDQ.0HC+"!F=7IZ>0IM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(E-V87)T
M96QI<W1E(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C<R-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B=&AE($AO<F1E(%!/(&9I;&4@9F]R('1H92!L
M;V-A;&4@)7,@9&]E<R!N;W0@97AI<W0Z(@IM<V=S='(@(D1E;B!S<&5S:69I
M<V5R=&4@9FEL96X@96MS:7-T97)E<B!I:VME+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,V(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C@R"B,L(&9U>GIY
M"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM
M<V=S='(@(E9I<R!M86EL;&ES=&4@:6YF;W)M87-J;VXB"@HC.B!A9&UI;B]S
M971U<"]D:69F+G!H<#HV."!A9&UI;B]S971U<"]D:69F+G!H<#HW-@HC+"!F
M=7IZ>0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R(")%+7!O<W0B"@HC.B!L:6(O
M2&]R9&4O34E-12]087)T+G!H<#HQ-PHC+"!F=7IZ>0IM<V=I9"`B=6YN86UE
M9"(*;7-G<W1R(")5=&5N(&YA=FXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,S<U"B,L(&9U>GIY"FUS9VED(")U<&1A=&5D(@IM<V=S='(@(E-I<W1E(&]P
M<&1A=&5R:6YG.B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU.#<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,CD*(RP@
M9G5Z>GD*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(FEN9V5N(&UA<'!E
M('9A;&=T(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HS
M.`IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(T"B,L(&9U>GIY"FUS9VED(")W
M.B(*;7-G<W1R(")&=V0Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(B(*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]N;%].3"YP;P``````````
M````````````````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-S,T-C$V
M`#$P-3$U-#,S-S4T`#`Q-S8V,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````C($AO<F1E($1U=&-H('1R86YS;&%T:6]N+@HC
M($-O<'ER:6=H="`H0RD@,C`P,2TR,#`V($IA;B!+=6EP97)S+@HC($IA;B!+
M=6EP97)S(#QJ<FMU:7!E<G-`;&%U=V5R<V-O;&QE9V4N;FP^+"`R,#`Q+3(P
M,#8N"B,@"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N
M.B!(;W)D92`S+C$N,2UC=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D
M979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P
M-BTP,RTQ,B`P,#HS,2LP,3`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`V
M+3`S+3$S(#(R.C0P*S`Q,#!<;B(*(DQA<W0M5')A;G-L871O<CH@2F%N($MU
M:7!E<G,@/&IR:W5I<&5R<T!L875W97)S8V]L;&5G92YN;#Y<;B(*(DQA;F=U
M86=E+51E86TZ($1U=&-H(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)
M344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[
M(&-H87)S970]25-/+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O
M9&EN9SH@.&)I=%QN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R
M("(@*"5S(&1A9V5N(&=E;&5D96XI(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ,S@S"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y
M("5S*2(*;7-G<W1R("(@*%-N96QT;V5T<R`E<RDB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S<W"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@
M)7,@9&%Y<RDB"FUS9W-T<B`B("AB:6YN96X@)7,@9&%G96XI(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,PIM<V=I9"`B("AT;V1A>2DB"FUS
M9W-T<B`B("AV86YD86%G*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S-S4*;7-G:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(B`H;6]R9V5N*2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S$*;7-G:60@(B`H>65S
M=&5R9&%Y*2(*;7-G<W1R("(@*&=I<W1E<F5N*2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,U,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDV"FUS
M9VED("(@870@(@IM<V=S='(@(B!O<"`B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@
M;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R(")<(B5S7"(@:7,@9V5E;B!D:7)E
M8W1O<GDN(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*
M;7-G<W1R(")<(B5S7"(@:7,@9V5E;B!G96QD:6=E(&ME=7IE+B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S$P"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`Y.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO
M<F1E(%)E9VES=')Y+B(*;7-G<W1R(")<(B5S7"(@:7,@;FEE="!G96-O;F9I
M9W5R965R9"!I;B!H970@2&]R9&4@<F5G:7-T97(N(@H*(SH@9G)A;65W;W)K
M+U1R964O5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B7"(E<UPB('1R
M964@=V5E<F=E=F5R(&YI970@9V5V;VYD96XN(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D
M('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@86%N(&AE
M="!G<F]E<&5N<WES=&5E;2!T;V5G979O96=D+B(*"B,Z(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@
M(EPB)7-<(B!A86X@:&5T(')E8VAT96YS>7-T965M('1O96=E=F]E9V0N(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E
M871E9#H@)7,N(@IM<V=S='(@(EPB)7-<(B!I<R!N:65T(&%A;F=E;6%A:W0Z
M("5S+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR
M9B4E*2(*;7-G<W1R("(E+C)F34(@9V5B<G5I:W0@=F%N("4N,F9-0B!T;V5G
M97-T86%N("@E+C)F)24I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(R-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS
M9W-T<B`B)60@)7,@96X@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3DT"B,L('!H<"UF
M;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I
M<F5S+B(*;7-G<W1R("(E9"!D86=E;B!T;W0@=7<@=V%C:'1W;V]R9"!V97)V
M86QT+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B5D
M+61A9R!V;V]R=6ET>FEC:'0B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T
M<B`B)7,@+2!/<&UE<FMI;F<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C<P-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P
M<FEN="(*;7-G<W1R("(E<R!V:6YG97)A9F1R=6LB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#(@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z.#0T"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"
M(@IM<V=S='(@(B5S($M"(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A
M=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@3VYD97)H;W5D<W=E
M<FMZ86%M:&5D96X@+2!"979E<W1I9VEN9R(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(E<R!);G-T96QL96XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8T"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B)7,@:6YS8VAR
M:6IV96XB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@
M(B5S(&=E8G)U:6ME<G-O=F5R965N:V]M<W0B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C8X,B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U
M,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0S,B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C0Y-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A
M;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B)7,@8F5S=&%A="!A;"XB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$V-B!L:6(O0FQO8VLO;65T87(N<&AP.C$W
M,B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,U,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(E<R!O<"`E<R`E<R(*"B,Z
M('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC
M92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B;W@@
M9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T
M:&ES('1I;64N(@IM<V=S='(@(B(*(B5S(&ES(&=E<F5E9"!O;2!O;F1E<G-T
M86%N9&4@9V5S96QE8W1E97)D92!O;F1E<FAO=61S=V5R:WIA86UH961E;B!U
M:70@=&4@(@HB=F]E<F5N+B!6:6YK(&1E(&)E=V5R:VEN9RAE;BD@86%N(&1I
M92!U(&]P(&1I="!M;VUE;G0@=VEL="!U:71V;V5R96XN(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!I<R!R97%U:7)E9"(*;7-G<W1R("(E<R!I<R!V97)E:7-T(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M;6EN=71E<R(*;7-G<W1R("(E<R!M:6YU=&5N(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$S,@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B5S(&YI970@9V5V;VYD96XN
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(E<R!T;W0@
M)7,@=F%N("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T
M<B`B)7,G<R!A9')E<V)O96LB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDQ.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM
M<V=S='(@(B5S)W,@86=E;F1A(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM
M<V=S='(@(B5S)W,@;F]T:71I96)O96LB"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML
M:7-T(@IM<V=S='(@(B5S)W,@=&%K96YL:6IS="(*"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z
M.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B5S.B`E
M<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA
M>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F
M(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG
M('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM
M<V=S='(@(B(*(B5S.B!$:70@8F5R:6-H="!K;VUT(&UI<W-C:&EE;B!N:65T
M('9A;B!D96=E;F4@9&EE(&AE="!B97=E97)T('1E('II:FXN(%=E97,@(@HB
M=F]O<GII8VAT:6<@8FEJ(&AE="!K;&EK:V5N(&]P(&QI;FMS(&EN(&AE="!B
M97)I8VAT(&]F(&1E(&%F>F5N9&5R("(*(G!E<G-O;VYL:6IK92!I;F9O<FUA
M=&EE('1E('-T=7)E;BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S4T(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.3D*;7-G:60@
M(BP@9W5S=&EN9R`B"FUS9W-T<B`B+"!W:6YD=FQA9V5N("(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3DU(&QI8B]";&]C:R]M971A<BYP:'`Z,C`P"B,L
M('!H<"UF;W)M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(L
M('=I;F1V;&%G96X@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P
M.`HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@
M)7,B"FUS9W-T<B`B+"!V87)I86)E;"!V86X@)7,@=&]T("5S(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T."!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y-`HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C,T."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Y
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,C@*;7-G:60@(BTM('-E
M;&5C="`M+2(*;7-G<W1R("(M+2!S96QE8W1E<F5N("TM(@H*(SH@;&EB+T)L
M;V-K+W1I;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R
M("(Q,B!U=7)S=V5E<F=A=F4B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*
M;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(C(T('5U<G-W965R9V%V
M92(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H
M;W5R<R(*;7-G<W1R("(R-"!U=7)S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A
M9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(CQ6;W)I9V4B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R-@IM<V=I9"`B02!D871A8F%S
M92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R
M(")%96X@9&%T86)A<V4@8F%C:V5N9"!I<R!V97)E:7-T('9O;W(@9&ET(&)L
M;VLN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S$*;7-G:60@
M(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(D5R(&AE969T
M('II8V@@965N(&9A=&%L92!F;W5T('9O;W)G961A86XB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'
M4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S
M='(@(D5E;B!O<&5N8F%R92!01U`@<VQE=71E;"!I<R!V97)E:7-T(&]M(&5E
M;B!B97)I8VAT('1E(&-O9&5R96XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3$V.`IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R
M97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B
M(@HB165N(&]P96YB87)E(%!'4"!S;&5U=&5L(&ES('9E<F5I<W0@;VT@965N
M(&]N9&5R=&5K96YD(&)E<FEC:'0@=&4@=F5R:69IZW)E;BXB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#DY"FUS9VED("(B"B)!('!U
M8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T
M<B`B(@HB165N(&]P96YB87)E(%!'4"!S;&5U=&5L+"!P<FEVZ2!01U`@<VQE
M=71E;"!E;B!W86-H='=O;W)D<F5G96P@>FEJ;B!V97)E:7-T("(*(F]M(&5E
M;B!B97)I8VAT('1E(&1E8V]D97)E;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,#$V"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y
M+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB165N(&]P96YB
M87)E(%!'4"!S;&5U=&5L+"!P<FEVZ2!01U`@<VQE=71E;"!E;B!W86-H='=O
M;W)D<F5G96P@>FEJ;B!V97)E:7-T("(*(F]M(&5E;B!B97)I8VAT('1E(&]N
M9&5R=&5K96YE;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4P-@IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T
M92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*(D5E;B!O<&5N8F%R
M92!3+TU)344@<VQE=71E;"P@<')I=ND@4R]-24U%('-L975T96P@96X@=V%C
M:'1W;V]R9')E9V5L('II:FX@(@HB=F5R96ES="!O;2!E96X@8F5R:6-H="!T
M92!D96-O9&5R96XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A
M=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"B)%96X@;W!E;F)A<F4@
M4R]-24U%('-L975T96PL('!R:7;I(%,O34E-12!S;&5U=&5L(&5N('=A8VAT
M=V]O<F1R96=E;"!Z:6IN("(*(G9E<F5I<W0@;VT@965N(&)E<FEC:'0@=&4@
M;VYD97)T96ME;F5N+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER
M960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(D5E;B!O<&5N8F%R
M92!334E-12!S;&5U=&5L(&ES('9E<F5I<W0@;VT@965N(&)E<FEC:'0@=&4@
M8V]D97)E;BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B0F5W;VQK:6YG('9O
M;W(@,3(N,#`@=75R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`B3&EC
M:'1E(')E9V5N('9O;W(@,3(N,#`@=75R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T
M<B`B4F5G96X@=F]O<B`Q,BXP,"!U=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G
M<W1R(")"=6EE;B!V;V]R(#$R+C`P('5U<B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H;W=E
M<G,B"FUS9W-T<B`B4VYE975W8G5I96X@=F]O<B`Q,BXP,"!U=7(B"@HC.B!T
M96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T
M<B`B04TO4$TB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R(")!4$D@240B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P
M"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R(")/=F5R(&1E>F4@
M961I=&]R(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3,*;7-G:60@
M(D%B;W5T+BXN(@IM<V=S='(@(D]V97(N+BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB
M"FUS9W-T<B`B06)S8F]T=&]M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@
M(D%B<VUI9&1L92(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR
M-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B5&]E9V%N9R!G97=E:6=E<F0@8FEJ(&AE="!M86ME;B!V
M86X@5D93(&1I<F5C=&]R>2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F
M:6QE+B(*;7-G<W1R(")4;V5G86YG(&=E=V5I9V5R9"!B:6H@:&5T(&UA:V5N
M('9A;B!61E,@8F5S=&%N9"XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M,PIM<V=I9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")!8V-O=6YT
M:6YF;W)M871I92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.`IM<V=I
M9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R(")!8V-O=6YT=V%C:'1W;V]R
M9"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(D%C8V]U
M;G0@8F5V<F]R96XN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S
M-0IM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R(")697)A;G1W;V]R9&EN9R(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X('1E;7!L871E
M<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B061D(@IM<V=S='(@(E1O979O96=E
M;B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z
M,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B0VAI;&0@9W)O
M97`@=&]E=F]E9V5N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HY."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY"FUS9VED(")!
M9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R(")#:&EL9"!R96-H="!T;V5V
M;V5G96XB"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B
M061D($AE<F4Z(@IM<V=S='(@(DAI97(@=&]E=F]E9V5N.B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED(")!
M9&0@3F5W($=R;W5P(@IM<V=S='(@(DYI975W92!G<F]E<"!T;V5V;V5G96XB
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES
M<VEO;B(*;7-G<W1R(").:65U=R!R96-H="!T;V5V;V5G96XB"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M
M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R
M(")%96X@7")C:&EL9&=R;V5P7"(@86%N(%PB)7-<(B!T;V5V;V5G96XB"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*
M;7-G<W1R(")%96X@7")C:&EL9')E8VAT7"(@86%N(%PB)7-<(B!T;V5V;V5G
M96XB"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S
M97(Z(@IM<V=S='(@(DYI975W92!G96)R=6EK97(@=&]E=F]E9V5N.B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-38*;7-G
M:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B2V]L;VT@=&]E=F]E9V5N(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D
M(&YE=R!M96UB97)S(@IM<V=S='(@(DYI975W92!L961E;B!T;V5V;V5G96XB
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@
M<&%I<B(*;7-G<W1R(")086%R('1O979O96=E;B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E
M<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(DAE="`E<R!M
M96YU('1O979O96=E;B!A;',@965N($UO>FEL;&$@4VED96)A<B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0IM<V=I9"`B
M061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B5F]E9R!T;V4@86%N(&%D
M<F5S8F]E:SHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T
M<B`B5F]E9R!T;V4@86%N(&UI:FX@861R97-B;V5K(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(D=E8G)U:6ME<B!T
M;V5V;V5G96XB"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O
M=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*
M(B5S+B(*;7-G<W1R("(B"B)<(B5S7"(@86%N(&AE="!S>7-T965M('1O96=E
M=F]E9V0L(&UA87(@:V]N(&=E96X@97AT<F$@(@HB:6YS8VAR:6IV:6YG<VEN
M9F]R;6%T:64@=&]E=F]E9V5N.B`E<RXB"@HC.B!S:6=N=7`N<&AP.C0U"B,L
M('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M
M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(EPB)7-<(B!A86X@:&5T
M('-Y<W1E96T@=&]E9V5V;V5G9"X@52!K=6YT(&YU(&%A;FUE;&1E;BXB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D
M:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")4;V5V;V5G96X@=F%N
M(&=E8G)U:6ME<G,@:7,@=6ET9V5S8VAA:V5L9"XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30T,0IM<V=I9"`B061D<F5S<R(*;7-G<W1R(")!9')E<R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-#$*;7-G:60@(D%D9')E
M<W,@0F]O:R(*;7-G<W1R(")!9')E<V)O96LB"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,T,S$T+G!H<#HU-@IM<V=I9"`B061M:6YI<W1E<B`M('-E
M="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B0F5H965R
M("T@<F5C:'1E;B!V;V]R(&%N9&5R92!G96)R=6EK97)S(&EN<W1E;&QE;B(*
M"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A
M<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES=')A=&EO;B(*;7-G<W1R(")"96AE
M97(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0S"FUS9VED(")!
M9',B"FUS9W-T<B`B061V97)T96YT:65S(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.`IM<V=I9"`B
M069G:&%N:7-T86XB"FUS9W-T<B`B069G86YI<W1A;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$*
M;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B06QB86YIZR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0*
M;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B06QG97)I:F4B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA
M<R(*;7-G<W1R(")!;&EA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@
M(E5I=&QI:FYE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`B56ET;&EJ
M;FEN9SHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L
M;"(*;7-G<W1R(")!;&QE(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B
M06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B06QL92!G96%U=&AE
M;G1I8V5E<F1E(&=E8G)U:6ME<G,B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S
M='(@(D%L;&4@9W)O97!E;B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]D
M871A=')E92YP:'`Z-S4@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY
M,0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(D%L;&4@<F5C:'1E
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(D%L;&4@
M=FEE<B!Z:6ID96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<Q
M"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B365E
M<F1E<F4@861R97-S96X@=&]E<W1A86XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3,X"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES
M="!T>7!E/R(*;7-G<W1R("));G-T96QL96X@=F%N(&=E;W)D96YD92!L:6IS
M="!T>7!E('1O97-T86%N/R(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A
M5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T
M<B`B0F5S=&%A="!A;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8*
M;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@(D%L=&5R;F%T
M:65V92!)35-0(&%A;FUE;&1I;F<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3$Q"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R
M(")!;'1E<FYA=&EE9B!)35-0('=A8VAT=V]O<F0B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3`S"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M
M92(*;7-G<W1R(")!;'1E<FYA=&EE=F4@24U34"!G96)R=6EK97)S;F%A;2(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E
M<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(")!;'1E<FYA=&EE9B!E+6UA
M:6QA9')E<R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!
M;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(D%L=&5R;F%T:65V92!S:F%B
M;&]N96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,C(*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G
M<W1R(")!;'1E<FYA=&EE=F4@=&5K<W0Z(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-PIM<V=I9"`B
M06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B06UE<FEK86%N<R!386UO82(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@
M=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B165N(&]N9V5L9&EG92!W86%R9&4@
M;W!G96=E=F5N+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-34*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S
M='(@(D5R(&AE969T('II8V@@965N(&]N8F5K96YD969O=70@=F]O<F=E9&%A
M;BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(D%N9&]R
M<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B06YG;VQA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,`IM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B06YG=6EL
M;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED
M(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B06YO;FEE;64@<')O>'DB"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R
M(@IM<V=S='(@(D%N='=O;W)D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-0IM<V=I9"`B06YT87)C
M=&EC82(*;7-G<W1R(")!;G1A<F-T:6-A(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.0IM<V=I9"`B
M06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R(")!;G1I9W5A(&5N($)A<F)U
M9&$B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,S8@861M:6XO=&5M<&QA=&5S
M+G!H<#HW-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4X('1E
M;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI
M8V%T:6]N(@IM<V=S='(@(E1O97!A<W-I;F<B"@HC.B!U=&EL+VEC;VY?8G)O
M=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B
M5&]E<&%S<VEN9V5N;&EJ<W0B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,30P"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B5&]E
M<&%S<VEN9R!I<R!G97)E960N(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R
M(")/<"!C:&EL9'-H87)E<R!T;V5P87-S96XB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R
M(")';V5D:V5U<F5N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#0R"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(D=E
M<V-H871T92!G<F]O='1E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(D%P<FEL(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D%R86)I8R`H5VEN
M9&]W<RTQ,C4V*2(*;7-G<W1R(")!<F%B:7-C:"`H5VEN9&]W<RTQ,C4V*2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8V"FUS9VED(")!<F-H:79E
M($9I;&4@4VEZ92(*;7-G<W1R(")!<F-H:65F8F5S=&%N9'-G<F]O='1E(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU."!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<W"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*;7-G:60@(D%R8VAI=F4@
M3F%M92(*;7-G<W1R(")!<F-H:65F;F%A;2(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P
M(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B5V5E="!U('IE:V5R(&1A="!U
M(&AE="!A86YM96QD:6YG<W9E<GIO96L@=F%N("5S('=I;'0@=F5R=VEJ9&5R
M96X_(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R(")7
M965T('4@>F5K97(@9&%T('4@7"(E<UPB(&5N(&%L;&4@<W5B9W)O97!E;B!W
M:6QT('9E<G=I:F1E<F5N/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8*;7-G:60@(D%R9V5N=&EN
M82(*;7-G<W1R(")!<F=E;G1I;FGK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,@IM<V=I9"`B07)M
M96YI82(*;7-G<W1R(")!<FUE;FGK(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ-SD*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(D%R
M;65E;G,@*$%235-#24DM."DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,C@*;7-G:60@(D%R="(*;7-G<W1R(")+=6YS="(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S`*;7-G
M:60@(D%R=6)A(@IM<V=S='(@(D%R=6)A(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R
M(")!<V-E;G-I;VX@96EL86YD(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B07-C:6D@:W5N<W0B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O
M4&%C:69I8R!296=I;VXB"FUS9W-T<B`B07IIZR]086-I9FES8VAE(%)E9VEO
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R.0IM<V=I9"`B07-K(&9O
M<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,_(@IM<V=S='(@(D]M(&)E=F5S=&EG:6YG('9R86=E;B!V;V]R(&AE
M="!U:71V;V5R96X@=F%N(&]N9&5R:&]U9'-W97)K>F%A;6AE9&5N/R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,P.34*;7-G:60@(D%S<VEG;FUE
M;G0@8V]L=6UN<R(*;7-G<W1R(")/<&1R86-H="!K;VQO;6UE;B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@
M;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R(")0;V=I;F<@;VT@965N(&YI
M970@8F5S=&%A;F1E(&=R;V5P('1E('9E<G=I:F1E<F5N+B(*"B,Z(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E!O9VEN9R!O
M;2!E96X@;FEE="!B97-T86%N9"!R96-H="!T92!V97)W:6ID97)E;BXB"@HC
M.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E!O9VEN
M9R!O;2!E96X@;FEE="!B97-T86%N9"!R96-H="!T92!B97=E<FME;BXB"@HC
M.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@
M=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B4&]G:6YG
M(&]M(&5E;B!N:65T(&)E<W1A86YD92!S:&%R92!T92!B97=E<FME;BXB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#,*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,0IM<V=I9"`B071T<FEB=71E
M<R(*;7-G<W1R(")!='1R:6)U=&5N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R(")!
M=6=U<W1U<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,CD*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R
M(")!=7-T<F%L:>LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X"FUS9VED(")!=7-T<FEA(@IM<V=S
M='(@(D]O<W1E;G)I:FLB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q
M;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G-Q;#H@=F5R
M96ES=&4@:6UA<"!E>'1E;G1I92!N:65T(&=E=F]N9&5N+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U
M<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S
M+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!B86-K96YD(&AE969T(&YI970@9&4@
M=F5R96ES=&4@8F5K=V%A;6AE9&5N+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@
M:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G5S
M.B!V97)E:7-T92!I;6%P(&5X=&5N=&EE(&YI970@9V5V;VYD96XN(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H
M7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I
M;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S
M='(@(B(*(D%U=&A?9G1P.B!V97)E:7-T92!&5%`@97AT96YT:64@;FEE="!G
M979O;F1E;BX@0V]M<&EL965R(%!(4"!M970@9&4@+2UE;F%B;&4M(@HB9G1P
M(&]P=&EE+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C0*
M;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM87`Z('9E<F5I<W1E($E-05`@97AT
M96YT:64@;FEE="!G979O;F1E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]K<F(U.B!V97)E
M:7-T92!K<F(U(&5X=&5N=&EE(&YI970@9V5V;VYD96XN(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@
M061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E
M8W1O<GDB"FUS9W-T<B`B(@HB075T:%]L9&%P.B!T;V5V;V5G96X@=F%N(&=E
M8G)U:6ME<G,@=V]R9'0@;FEE="!O;F1E<G-T975N9"!V;V]R($%C=&EV92`B
M"B)$:7)E8W1O<GDB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C,U-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@
M<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*(D%U
M=&A?;&1A<#H@5F5R=VEJ9&5R96X@=F%N(&=E8G)U:6ME<G,@=V]R9'0@;FEE
M="!O;F1E<G-T975N9"!V;V]R($%C=&EV92`B"B)$:7)E8W1O<GDB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD
M87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]L9&%P.B!V97)E:7-T92!,1$%0(&5X=&5N=&EE(&YI970@9V5V
M;VYD96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D
M('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G
M<W1R(")!=71H7VQD87`Z($YI970@:6X@<W1A870@9V5B<G5I:V5R("5S('1O
M92!T92!V;V5G96XN($1E('-E<G9E<B!M96QD=#H@(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B
M075T:%]L9&%P.B!.:65T(&EN('-T86%T(&=E8G)U:6ME<B`E<R!T92!V97)W
M:6ID97)E;B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DY
M"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P
M9&%T92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@3FEE="!I;B!S=&%A
M="!G96)R=6EK97(@)7,@8FEJ('1E('=E<FME;B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z(%5P9&%T
M:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O
M<GDN(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@0FEJ=V5R:V5N('9A;B!G96)R
M=6EK97)S('=O<F1T(&YI970@;VYD97)S=&5U;F0@=F]O<B!!8W1I=F4@(@HB
M1&ER96-T;W)Y+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z
M-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VUC86PZ('9E<F5I<W1E($U#04P@
M97AT96YT:64@;FEE="!G979O;F1E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@
M<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7W-M
M8F%U=&@Z('9E<F5I<W1E('-M8F%U=&@@97AT96YT:64@;FEE="!G979O;F1E
M;BXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%D;6EN+G!H<#HQ,#8*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"XB"FUS
M9W-T<B`B075T:&5N=&EC871I92!O<"!)34%0('-E<G9E<B!M:7-L=6MT+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(D%U
M=&AE;G1I8V%T:64@;6ES;'5K="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B075T:&5N
M=&EC871I92!M:7-L=6MT+B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D
M(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@(D%U=&AE;G1I8V%T:64@9V5W
M96EG97)D(&1O;W(@9&4@4D%$2553('-E<G9E<BXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@X,@IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@
M1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(D%U=&AE;G1I8V%T:64@;W`@
M1E10('-E<G9E<B!M:7-L=6MT+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R
M=F5R(&9A:6QE9"XB"FUS9W-T<B`B075T:&5N=&EC871I92!O<"!D92!334(@
M<V5R=F5R(&UI<VQU:W0N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B0F5S8VAI
M:V)A<F4@=F5L9&5N.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S$*;7-G:60@(D%Z97)B86EJ86XB
M"FUS9W-T<B`B07IE<F)A:61Z:F%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B0D]&2"!%>&-U
M<V5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R(")!8VAT97)G
M<F]N9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B06-H=&5R
M9W)O;F1K;&5U<B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z
M.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B1F]U
M="!K97)B97)O<W=A8VAT=V]O<F0N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*
M;7-G<W1R(")&;W5T92!K97)B97)O<V=E8G)U:6ME<G-N86%M+B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#4*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B0F%H86UA<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S@*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B0F%H<F5I;B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")"86QT:6,@*$E33RTX.#4Y
M+3$S*2(*;7-G<W1R(")"86QT:7-C:"`H25-/+3@X-3DM,3,I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS-`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R(")"86YG;&%D97-H(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS,PIM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B0F%R8F%D;W,B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N
M9"XB"FUS9W-T<B`B0F%S:7,@869B965L9&EN9V5N9&ER96-T;W)Y(%PB)7-<
M(B!N:65T(&=E=F]N9&5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0IM<V=I9"`B0F%S96QI;F4B"FUS9W-T
M<B`B0F%S:7-L:6IN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.0IM<V=I9"`B0F5L87)U<R(*;7-G
M<W1R(")7:70@<G5S;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4*;7-G:60@(D)E;&=I=6TB
M"FUS9W-T<B`B0F5L9VGK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,`IM<V=I9"`B0F5L:7IE(@IM
M<V=S='(@(D)E;&EZ92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`*;7-G:60@(D)E;FEN(@IM<V=S
M='(@(D)E;FEN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT,0IM<V=I9"`B0F5R;75D82(*;7-G<W1R
M(")"97)M=61A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-@IM<V=I9"`B0FAU=&%N(@IM<V=S='(@
M(D)H=71A;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(E9E<FIA87)D86<B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S8W
M"B,L('!H<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A
M=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")";&]K(%PB)7-<(B!V
M86X@=&]E<&%S<VEN9R!<(B5S7"(@;FEE="!G979O;F1E;BXB"@HC.B!T96UP
M;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3`*;7-G:60@(D)L;V-K(%-E='1I
M;F=S(@IM<V=S='(@(D)L;VMI;G-T96QL:6YG96XB"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T
M<B`B0FQO:W1Y<&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B5F5T(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT,PIM<V=I9"`B0F]L:79I82(*;7-G<W1R(")";VQI=FEA(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P-PIM<V=I9"`B0F]O:VUA<FMS(@IM
M<V=S='(@(D)O;VMM87)K<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*;7-G:60@(D)O<F1E<B(*;7-G<W1R
M(")286YD(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B4F%N
M9&1I:W1E.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B4F%N9&5N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS,@IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*
M;7-G<W1R(")";W-N:>L@96X@2&5R>F5G;W9I;F$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B0F5I9&5N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT.`IM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B0F]T<W=A;F$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C(*;7-G:60@(D)O='1O;2(*;7-G<W1R(")/;F1E<FMA;G0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0W"FUS9VED(")";W5V970@27-L86YD(@IM<V=S='(@(D)O=79E="!E
M:6QA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C0T"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)A
M>FEL:>LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q-PIM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E
M86X@5&5R<FET;W)Y(@IM<V=S='(@(D)R:71S($EN9&ES8VAE($]C96%A;B!4
M97)R:71O<FEU;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(*;7-G:60@(D)R=6YE:2!$87)U<W-A
M;&%M(@IM<V=S='(@(D)R=6YE:2!$87)U<W-A;&%M(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-PIM
M<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B0G5L9V%R:6IE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L
M;&5T960@3&ES="(*;7-G<W1R(")/;F=E;W)D96YD92!L:6IS="(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S8*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R(")"=7)K:6YA($9A
M<V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,Y"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(D)U<G5N
M9&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0V"FUS9VED(")#
M35,B"FUS9W-T<B`B0TU3(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-20R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DX"FUS9VED(")#4DP@
M1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R(")#4DP@1&ES=')I8G5T:65P
M=6YT96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS
M9W-T<B`B0U]E;&5I9V5N<V-H87!P96XN+BXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,34Q"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@
M8V]M<&QE=&5D+B(*;7-G<W1R(")#86-H92!I;FET:6%L:7-A=&EE(&ES(&YI
M970@869G97)O;F0N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0X-2!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ-@HC
M.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`T,"!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,34W"FUS9VED(")#86QE;F1A<B(*;7-G<W1R(")!9V5N9&$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")#
M86QM(@IM<V=S='(@(DMA;&TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.`IM<V=I9"`B0V%M8F]D
M:6$B"FUS9W-T<B`B0V%M8F]D:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8P"FUS9VED(")#86UE
M<F]O;B(*;7-G<W1R(")+86UE<F]E;B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U
M=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("(B"B)+86X@=V%C:'1W;V]R9"!N:65T(&%U=&]M871I<V-H(')E<V5T
M=&5N+"!N965M(&-O;G1A8W0@;W`@;65T(&1E("(*(G-Y<W1E96UB96AE97)D
M97(N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S4P"B,L('!H
M<"UF;W)M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B
M"FUS9W-T<B`B2V%N(&YI970@;F%A<B!B97-T86YD(%PB)7-<(B!S8VAR:6IV
M96XB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D
M;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B
M2V%N(&=E96X@97AT97)N92!S97-S:65H86YD;&5R(&)E:&5R96XN(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q.2!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G5S+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B2V%N
M(&YI970@=F5R8FEN9&5N(&UE="!)34%0('-E<G9E<CH@)7,B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&)E<W1A
M;F0@7"(E<UPB(&YI970@;W!E;F5N+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$*;7-G:60@(D-A
M;F%D82(*;7-G<W1R(")#86YA9&$B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@
M861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV-2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI
M;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$*;7-G:60@(D-A
M;F-E;"(*;7-G<W1R(")!9F)R96ME;B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B
M"FUS9W-T<B`B4')O8FQE96UR87!P;W)T(&%F8G)E:V5N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HS,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&)E<W1A
M;F0@7"(E<UPB(&YI970@=F5R=VEJ9&5R96XN(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y
M+G!H<#HU,@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*;7-G:60@(D-A;FYO="!F
M:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B2V%N(&=E96X@
M=&EJ9&5L:6IK92!D:7)E8W1O<GD@=FEN9&5N+B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P
M<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T
M<B`B2V%N(&YI970@9&]O<F=A86X@>F]N9&5R("=T87)G971&:6QE)R!P87)A
M;65T97(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E
M<UPB+B(*;7-G<W1R(")+86X@9&ER96-T;W)Y(%PB)7-<(B!N:65T('9E<G=I
M:F1E<F5N+B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92YP:'`Z
M,3(X(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8X,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E
M;B!E>&ES="XB"FUS9W-T<B`B2V%N(&YI970@=F5R=VEJ9&5R96X[("5D(&-H
M:6QD<F5N(&)E<W1A86XN(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4
M<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M
M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@
M;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@HB2V%N(&YI970@
M;W!N:65U=R!R86YG<V-H:6MK96XL(&AE="!A86YT86P@:6YV;V5R96X@;VT@
M;W!N:65U=R!T92`B"B)R86YG<V-H:6MK96X@:V]M="!N:65T(&]V97)E96X@
M;65T(&AE="!O<&=E<VQA9V5N(&%A;G1A;"XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO
M="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@
M(DMA;B!B97)I8VAT(&YI970@;F%A<B!H970@;W!G96=E=F5N(&YU;6UE<B!V
M97)S='5R96XN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV-0IM<V=I9"`B0V%P92!697)D92(*;7-G
M<W1R(")+86%P(%9E<F1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R
M(")/<'-C:')I9G0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I
M8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T<B`B1')A9V5R
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS"FUS9VED(")#871E9V]R
M:65S(&%N9"!,86)E;',B"FUS9W-T<B`B0V%T96=O<FEEZVX@96X@;&%B96QS
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S4*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@
M(D-A>6UA;B!E:6QA;F1E;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B
M5&5L+FYR+FUO8FEE;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*
M;7-G<W1R(")#96QE:6=E;G-C:&%P<&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN
M9SHB"FUS9W-T<B`B0V5L('9R:6IE(')U:6UT93HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#
M96QL('!R;W!E<G1I97,B"FUS9W-T<B`B0V5L96EG96YS8VAA<'!E;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS
M9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(D-E;'-P871IZW)I;F<Z(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W-`IM<V=I9"`B0V5L;'!H
M;VYE(@IM<V=S='(@(E1E;"YN<BYM;V)I96PB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X,0IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T
M<B`B2V5L=&ES8V@@*$E33RTX.#4Y+3$T*2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E
M<B(*;7-G<W1R(")-:61D96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T"FUS9VED(")#96YT<F%L
M($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B0V5N=')A86P@069R:6MA86YS
M92!297!U8FQI96LB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I
M9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B0V5N
M=')A86P@175R;W!E97,@*$E33RTX.#4Y+3(I(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(D-E<G1I9FEC871E($1E
M=&%I;',B"FUS9W-T<B`B0V5R=&EF:6-A871D971A:6QS(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3(*;7-G:60@(D-E<G1I9FEC
M871E($]W;F5R(@IM<V=S='(@(D-E<G1I9FEC86%T96EG96YA87(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0V5R
M=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B0V5R=&EF:6-A871B96QE:60B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,C$*;7-G:60@(D-H860B"FUS9W-T<B`B5'-J86%D(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(E=I
M:GII9V5N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"FUS
M9VED(")#:&%N9V4@66]U<B!087-S=V]R9"(*;7-G<W1R(")7:6IZ:6<@=7<@
M=V%C:'1W;V]R9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.0IM<V=I
M9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE
M('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I
M;',N(@IM<V=S='(@(B(*(E=I:GII9R!D92!N86%M+"!A9')E<R!E;B!O;F1E
M<G1E:V5N:6YG(&1I92!M96X@>FEE="!B:6H@:&5T(&QE>F5N(&5N("(*(F)E
M86YT=V]O<F1E;B!V86X@=7<@92UM86EL<RXB"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z,C0*;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S
M<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I
M9W5R871I;VXN("`B"B)#;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS
M9W-T<B`B(@HB5VEJ>FEG96X@=F%N('5W('=A8VAT=V]O<F0@=V]R9'0@;FEE
M="!O;F1E<G-T975N9"!D;V]R(&1E(&AU:61I9V4@(@HB8V]N9FEG=7)A=&EE
M+B!.965M(&-O;G1A8W0@;W`@;65T('5W('-Y<W1E96UB96AE97)D97(N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR-PIM<V=I9"`B0VAA<B(*;7-G<W1R(")+87)A:W1E<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM
M<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B0V]N=%]R;VQE97(@;&EN
M:RXN+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-3D*;7-G:60@(D-H:6QE(@IM<V=S='(@(D-H:6QI
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV,0IM<V=I9"`B0VAI;F$B"FUS9W-T<B`B0VAI;F$B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0VAI;F5S92!3:6UP
M;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(D-H:6YE97,@=F5R965N=F]U9&EG
M9"`H1T(R,S$R*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED
M(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R(")#:&EN965S
M('1R861I=&EO;F5E;"`H0FEG-2DB"@HC.B!T96UP;&%T97,O<')E9G,O87!P
M+FEN8SHW"FUS9VED(")#:&]O<V4@07!P;&EC871I;VXZ(@IM<V=S='(@(DMI
M97,@=&]E<&%S<VEN9SHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,C<P"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R(")+
M:65S(&5E;B!W86-H='=O;W)D(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3
M:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T
M<B`B2VEE<R!E96X@9V5B<G5I:V5R<VYA86TB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S`R"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T
M97,Z(@IM<V=S='(@(DMI97,@9&%T=6UW965R9V%V93HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS
M9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T
M<RDB"FUS9W-T<B`B2VEE<R!L:6IS='-T:6IL='EP92`H=F]O<B!G96]R9&5N
M9&4@;&EJ<W1E;BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V"FUS9VED(")#:')I<W1M87,@27-L
M86YD(@IM<V=S='(@(D-H<FES=&UA<R!E:6QA;F0B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z.3$T(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT
M"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@
M;F]T(&9O=6YD+B(*;7-G<W1R(")#;&%S<V1E9FEN:71I92!V86X@)7,@;FEE
M="!G979O;F1E;BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-`IM<V=I9"`B0VQE87(B"FUS9W-T<B`B2&5L9&5R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I
M9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R(")-4T]F9FEC92!T86=S
M('=I<W-E;B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,CD*;7-G:60@(D-L
M96%R(%%U97)Y(@IM<V=S='(@(E=I<R!Q=65R>2(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L
M96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R(")7:7,@9V5B<G5I:V5R.B`E<R(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B
M0VQE87(@=7-E<B(*;7-G<W1R(")7:7,@9V5B<G5I:V5R(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S97(@
M9&%T82(*;7-G<W1R(")7:7,@9V5B<G5I:V5R<V1A=&$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I
M;F<@3&%T92(*;7-G<W1R("),871E(&]P:VQA<FEN9V5N(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L
M:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(DML:6L@;VT@=F5R9&5R('1E(&=A
M86XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B
M0VQI8VMA=&5L;"!V:6$@2%144"(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H
M<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO
M<V4@5VEN9&]W(@IM<V=S='(@(E-L=6ET('-C:&5R;2(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C4Q"FUS9VED(")#;&]U9',B"FUS9W-T<B`B5V]L:V5N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*
M;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R(")6<F]E9V4@8F5W;VQK:6YG
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*
M;7-G:60@(D-L;W5D>2(*;7-G<W1R(")"97=O;&MT(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,@IM
M<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B0V]C;W,@
M*$ME96QI;F<I(&5I;&%N9&5N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E
M8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R("):
M:6IB86QK(&EN:VQA<'!E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D
M97)S(@IM<V=S='(@(DEN9V5K;&%P=&4@<F%N9&5N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,@IM
M<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`B0V]L;VUB:6$B"@HC.B!L:6(O0FQO
M8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM
M<V=I9"`B0V]L;W(B"FUS9W-T<B`B2VQE=7(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`S"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,S@*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,S.2!S97)V:6-E<R]I;6%G97,O8V]L
M;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B
M2VQE=7)E;FMI97IE<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,C@*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B2VQE=7)S96QE
M8W1I92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R(")+;VQO;6UE;CHB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30V"FUS9VED(")#;VQU;6X@=&ET
M;&5S(@IM<V=S='(@(DMO;&]M=&ET96QS(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(V-@IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(E-T<FEP<R(*
M"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-@IM<V=I9"`B0V]M;6%N9"(*;7-G
M<W1R(")/<&1R86-H="(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I
M9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R(")/<&1R86-H='-H96QL(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")#;VUM
M96YT(@IM<V=S='(@(D]P;65R:VEN9R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-38W"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R
M(")!;&=E;65N92!N86%M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S`*;7-G:60@(D-O;6]R;W,B
M"FUS9W-T<B`B0V]M;W)E;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B0F5D
M<FEJ9B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M
M<'5T97)S(@IM<V=S='(@(D-O;7!U=&5R<R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR.#8*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R(")#
M;VYD:71I92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4V"FUS9VED(")#
M;VYD:71I;VYS(@IM<V=S='(@(D-O;F1I=&EE<R(*"B,Z(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S
M(@IM<V=S='(@(E9E<G-C:&EL;&5N(&EN(&-O;F9I9W5R871I92(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#8*;7-G:60@(D-O;F9I9W5R871I;VX@
M9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O
M:RXB"FUS9W-T<B`B(@HB0V]N9FEG=7)A=&EE('9O;W(@:&5T('-Y;F-H<F]N
M:7-E<F5N(&UE="!01$$G<RP@4VUA<G1P:&]N97,@96X@3W5T;&]O:RXB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,U"FUS9VED(")#;VYF:6=U<F%T
M:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R(")#;VYF:6=U<F%T:64@:7,@
M=F5R;W5D97)D+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(B5S(&-O
M;F9I9W5R97)E;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B0F5V97-T
M:6<@=V%C:'1W;V]R9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-34*;7-G:60@(D-O;F=O(@IM<V=S
M='(@(DMO;F=O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU,PIM<V=I9"`B0V]N9V\L(%1H92!$96UO
M8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R(")+;VYG;RP@1&4@1&5M
M;V-R871I<V-H92!297!U8FQI96L@=F%N(&1E(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.`IM<V=I9"`B0V]N;F5C=&EO;B!F
M86EL960N(@IM<V=S='(@(E9E<F)I;F1I;F<@;6ES;'5K="XB"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`X"FUS9VED(")#;VYN
M96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(E9E<F)I;F1I;F<@;6ES;'5K=#H@
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED
M(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N
M(@IM<V=S='(@(E9E<F)I;F1I;F<L(&UE="!D92!O<&5N8F%R92!S;&5U=&5L
M<V5R=F5R+"!I<R!G97=E:6=E<F0N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I
M;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E
M<R`H)7,I(@IM<V=S='(@(B(*(E9E<F)I;F1I;F<L(&UE="!D92!O<&5N8F%R
M92!S;&5U=&5L<V5R=F5R+"!I<R!G97=E:6=E<F0N(%)E9&5N.B`E<R`H)7,I
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-S8*;7-G:60@(D-O
M;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(E9E<F)I
M;F1I;F<@;65T($944"!S97)V97(@;6ES;'5K="XB"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDR-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`V
M-PIM<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`B061R97-S96XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O
M;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S
M<R!B;V]K+B(*;7-G<W1R(")!9')E<W-E;B!Z:6IN(&UE="!S=6-C97,@86%N
M('5W(&%D<F5S8F]E:R!T;V5G979O96=D+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z-C`*;7-G:60@(D-O;G1E;G0@='EP92!O
M9B!C;VUP<F5S<V5D(&9I;&4Z("(*;7-G<W1R(")#;VYT96YT('1Y<&4@=F%N
M(&=E8V]M<')I;65E<F0@8F5S=&%N9#H@(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HU-B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T9WHN<&AP.C<U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@
M7"(E<UPB(@IM<V=S='(@(DEN:&]U9"!V86X@7"(E<UPB(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(")$;V]R9V%A;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-3@*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R(")#;V]K
M(&5I;&%N9&5N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"FUS9VED
M(")#;V]K:64B"FUS9W-T<B`B0V]O:VEE(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#;W!Y
M(@IM<V=S='(@(DMO<&GK<F5N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HT-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S
M(@IM<V=S='(@(DMO<&GK<F5N(&UI<VQU:W0Z("5S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S
M96QE8W1I;VXB"FUS9W-T<B`B2V]P:65E<B!S96QE8W1I92(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$
M(@IM<V=S='(@(DMO<W1E;B!)1"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,*;7-G:60@(D-O<W1A
M(%)I8V$B"FUS9W-T<B`B0V]S=&$@4FEC82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<*;7-G:60@
M(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B279O;W)K=7-T(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3<W"FUS9VED(")#;W5L9"!N;W0@
M4$=0(&5N8W)Y<'0@;65S<V%G93H@(@IM<V=S='(@(DMO;B!01U`@8F5R:6-H
M="!N:65T(&-O9&5R96XZ("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$P-34*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E
M.B`B"FUS9W-T<B`B2V]N(%!'4"!B97)I8VAT(&YI970@;VYD97)T96ME;F5N
M.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM
M<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S
M='(@(DMO;B!B97)I8VAT(&YI970@4R]-24U%(&-O9&5R96XN(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD
M(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R(")+;VX@8F5R:6-H
M="!N:65T(%,O34E-12!O;F1E<G1E:V5N96XN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R(")+
M;VX@861R97,@)7,@;FEE="!T;V5V;V5G96XN(@H*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,3(Q"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT.#(*;7-G:60@
M(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")+;VX@
M9V5E;B!V97)B:6YD:6YG(&UE="!D92!,1$%0+7-E<G9E<B!M86ME;BXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ
M-S,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HQ-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A
M;&%N8V4N("5S(@IM<V=S='(@(DMO;B!T96=O960@)7,@;FEE="!C;VYT<F]L
M97)E;BXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8V"FUS9VED(")#
M;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B2V]N
M(&YI970@=F5R8FEN9&5N(&UE="!,1$%0('-E<G9E<BXB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM
M<V=S='(@(DMO;B!N:65T('9E<F)I;F1E;B!M970@<V5R=F5R(%PB)7-<(B!M
M970@1E10.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DMO;B!G
M965N(&1I<W1R:6)U=&EE;&EJ<W0@)7,@;6%K96XN(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$R.`IM<V=I9"`B0V]U;&0@;F]T(&1E
M8W)Y<'0@4$=0(&1A=&$Z("(*;7-G<W1R(")+;VX@4$=0(&1A=&$@;FEE="!D
M96-O9&5R96XZ("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3(S"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB
M"FUS9W-T<B`B2V]N(%,O34E-12!D871A(&YI970@9&5C;V1E<F5N+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C
M="X@)7,B"FUS9W-T<B`B2V]N(&%D<F5S("5S(&YI970@=F5R=VEJ9&5R96XN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B2V]N(&1I<W1R:6)U=&EE
M;&EJ<W0@)7,@;FEE="!V97)W:6ID97)E;BXB"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B
M2V]N('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(B!N:65T('9E<G=I:F1E
M<F5N+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U
M;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E
M<W,N(@IM<V=S='(@(DMO;B!H970@92UM86EL861R97,@=F%N(&1E(&]N='9A
M;F=E<B!N:65T(&)E<&%L96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F971C
M:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(DMO;B!C;VUP;&5T
M92!A9')E<V)O96L@;FEE="!O<&AA;&5N+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@
M(DMO;B!C;VUP;&5T92!D:7-T<FEB=71I96QI:G-T(&YI970@;W!H86QE;BXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T
M(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B2V]N(&-O;7!L971E
M(&QI:G-T('9A;B!D:7-T<FEB=71I96QI:G-T96X@;FEE="!O<&AA;&5N+B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2YP:'`Z.#0*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*
M;7-G<W1R(")+;VX@<W1R871E9VEE(%PB)7-<(B!N:65T(&QA9&5N+B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDO9&ER96-T+G!H<#HS,`HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N
M(@IM<V=S='(@(DMO;B!D:7)E8W1O<GD@7"(E<UPB(&YI970@;6%K96XN(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#
M;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R
M+B(*;7-G<W1R(")+;VX@9&4@;W!E;F)A<F4@<VQE=71E;"!N:65T('9E<FMR
M:6IG96X@=F%N(&1E('-L975T96QS97)V97(N(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<
M(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(DMO;B!<(B5S7"(@;FEE="!O
M<&5N96X@=F]O<B!S8VAR:6IV96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R(")+;VX@)7,@;FEE="!O
M<&5N96XN(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E
M+G!H<#HT,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@
M36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B2V]N(&]N9&5R
M:&]U9'-T86ME;FUO9'5L92`E<R!N:65T(&]P96YE;B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E
M;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")+;VX@9&ER96-T;W)Y(%PB
M)7-<(B!N:65T(&]P96YE;BXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ
M-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(S-R!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV.3D*;7-G
M:60@(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@
M(DMO;B!D92!,1$%0+7-E<G9E<B!N:65T(&)E<F5I:V5N+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+T]B:F5C="YP:'`Z,C0P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R(")+;VX@)7,@;FEE="!L
M97IE;BXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I
M9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E
M<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A
M<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M
M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S
M='(@(B(*(DMO;B!H970@=V%C:'1W;V]R9"!V86X@9&4@9V5W96YS=&4@9V5B
M<G5I:V5R(&YI970@<F5S971T96XN(%-O;6UI9V4@;V8@86QL92`B"B)D971A
M:6QS('II:FX@;FEE="!J=6ES="X@4')O8F5E<B!O<&YI975W(&]F(&YE96T@
M8V]N=&%C="!O<"!M970@9&4@(@HB<WES=&5E;6)E:&5E<F1E<BP@=V%N;F5E
M<B!U('9E<F1E<F4@:'5L<"!N;V1I9R!H965F="XB"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#<*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S,X"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-0HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS.#$*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S@W"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@04-,(@IM<V=S='(@(DMO;B!!0TP@;FEE="!O<&AA;&5N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@
M8F]O:RX@)7,B"FUS9W-T<B`B2V]N(&%D<F5S8F]E:R`E<R!N:65T(&]P:&%L
M96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")+;VX@9&ES=')I
M8G5T:65L:6IS="`E<R!N:65T(&]P:&%L96XN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M<RX@)7,B"FUS9W-T<B`B2V]N(&1I<W1R:6)U=&EE;&EJ<W1E;B`E<R!N:65T
M(&]P:&%L96XN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,3DW"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C(Q-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HR,C$*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A
M8FEL:71I97,B"FUS9W-T<B`B2V]N('-E<G9E<F)E:W=A86UH961E;B!N:65T
M(&]P:&%L96XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS9VED
M(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DMO
M;B!C;VYF:6=U<F%T:64@;FEE="!T97)U9WIE='1E;BXB"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M
M9&ER(%PB)7-<(BXB"FUS9W-T<B`B2V]N(&1I<F5C=&]R>2!<(B5S7"(@;FEE
M="!V97)W:6ID97)E;BXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R(")+;VX@8V]N9FEG=7)A=&EE("5S(&YI970@
M;W!S;&%A;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S879E(&$@
M8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B2V]N(&=E96X@8F%C:W5P
M8V]N9FEG=7)A=&EE(&]P<VQA86XN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@
M8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B2V]N(&=E96X@8F%C
M:W5P8V]N9FEG=7)A=&EE(&]P<VQA86XZ("5S(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T
M<B`B2V]N('-E='5P('5P9W)A9&4@<V-R:7!T(&YI970@;W!S;&%A;B!A;',Z
M(%PB)7-<(BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(")+;VX@:&5T(&)A8VMU<&-O
M;F9I9W5R871I96)E<W1A;F0@;FEE="!O<'-L86%N("5S+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U
M(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E
M('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D
M92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@HB2V]N(&AE="!C;VYF:6=U<F%T
M:65B97-T86YD("5S(&YI970@;W!S;&%A;BX@52!K=6YT(&]F(.OK;B!V86X@
M9&4@;W!T:65S("(*(F=E8G)U:6ME;B!O;2!D92!C;V1E('1E<G5G(&]P('1E
M('-L86%N(&]P("5S(&]F(&]N9&5R<W1A86YD92!C;V1E(&AA;F1M871I9R`B
M"B)N86%R("5S(&MO<&GK<F5N+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0
M('-E<G9E<BXB"FUS9W-T<B`B2V]N(&1E($Q$05`M<V5R=F5R(&YI970@9&]O
M<GIO96ME;BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(DMO
M;B!<(B5S7"(@;FEE="!L;W-K;W!P96QE;BXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@
M(DMO;B!A9')E<R`E<R!N:65T(&)I:G=E<FME;BXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R(")+;VX@9&ES=')I8G5T:65L:6IS="`E<R!N:65T(&)I
M:G=E<FME;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@
M9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B2V]N(&-O;F9I9W5R871I92!V;V]R
M(%PB)7-<(B!N:65T('=E9W-C:')I:G9E;CH@)7,B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S<P"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII
M;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*
M;7-G<W1R("(B"B)+;VX@9&4@36]Z:6QL82!3:61E8F%R(&YI970@=FEN9&5N
M+B!:;W)G(&5R=F]O<B!D870@9&4@<VED96)A<B!O<&5N(&ES+B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H
M92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B(@HB2V]N(&=E8G)U:6ME<B!<(B5S7"(@9&4@=F]L9V5N9&4@
M<F5C:'1E;B!O<"!D92!M87`@7"(E<UPB(&YI970@9V5V96XZ("5S(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q.0IM<V=I9"`B0V]U;G1E9"!T
M97AT(@IM<V=S='(@(D=E=&5L9&4@=&5K<W0B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R
M("),86YD(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W-0IM<V=I
M9"`B0V]U<G-E<R(*;7-G<W1R(")#=7)S=7-S96XB"@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G
M:60@(D-R96%T92(*;7-G<W1R(")-86ME;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E
M871E(&$@;&EN:R(*;7-G<W1R(")-86%K(&5E;B!L:6YK(@H*(SH@=&5M<&QA
M=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E
M(&$@;F5W(&]N92(*;7-G<W1R(")-86%K(&5E;B!N:65U=V4B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,@IM<V=I9"`B0W)E871E
M('-U8B!F;VQD97)S(@IM<V=S='(@(DUA86L@<W5B;6%P<&5N(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B16EG96YA87)R96-H=&5N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(Q,@IM<V=I9"`B0W)E9&ET(&-A<F0@
M;G5M8F5R(@IM<V=S='(@(D-R961I=&-A<F1N=6UM97(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M.0IM<V=I9"`B0W)O871I82(*;7-G<W1R(")+<F]A=&GK(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M-`IM<V=I9"`B0W5B82(*;7-G<W1R(")#=6)A(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@(DAU
M:61I9V4@-"!F87-E;B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`IM<V=I
M9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R(")(=6ED:6=E('-E<W-I97,B
M"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z
M,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R(")(=6ED:6=E('1I:F0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(DAU:61I
M9V4@55),(&ES(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"FUS9VED(")#
M=7)R96YT(%5S97)S(@IM<V=S='(@(DAU:61I9V4@9V5B<G5I:V5R<R(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE
M<B(*;7-G<W1R(")(=6ED:6<@=V5E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-C0*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS
M9W-T<B`B2'5I9&EG92!C;VYD:71I93H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL
M92(*;7-G<W1R(")(=6ED:6=E('-T:6IL(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S
M:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(D%A;G!A<W-E
M;B!V86X@=&%K96X@=&EJ9&5N<R!A86YM96QD:6YG(&)I:B`E<RXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C`*;7-G:60@(D-U="(*;7-G<W1R(")+;FEP<&5N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E
M;&5C=&EO;B(*;7-G<W1R(")396QE8W1I92!K;FEP<&5N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M-PIM<V=I9"`B0WEP<G5S(@IM<V=S='(@(D-Y<')U<R(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@U"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G
M<W1R(")#>7)I;&QI<V-H("A+3TDX+5(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#8*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S
M='(@(D-Y<FEL;&ES8V@@*%=I;F1O=W,M,3(U,2DB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X-PIM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX
M+54I(@IM<V=S='(@(D-Y<FEL;&ES8V@O56MR86EN<R`H2T])."U5*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C@*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(E1S:F5C
M:&ES8VAE(%)E<'5B;&EE:R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-3(@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G
M:60@(D1$(@IM<V=S='(@(D1$(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S(W,@IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE
M="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP
M*2(*;7-G<W1R("(B"B)$4TX@*'II92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA
M;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@H*
M(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.0IM
M<V=I9"`B1&%I;'DB"FUS9W-T<B`B1&%G96QI:FMS(@H*(SH@861M:6XO9&%T
M871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@
M(D1A=&%4<F5E(&)R;W=S97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,C<P"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`B1&%T86)A
M<V4@9&]O<GIO96ME;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y.`IM
M<V=I9"`B1&%T92(*;7-G<W1R(")$871U;2(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I=F5D(@IM
M<V=S='(@(D1A='5M($]N='9A;F=E;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(W.#D*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@(D1A
M='5M('-E;&5C=&EE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(X,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q"FUS9VED(")$
M87DB"FUS9W-T<B`B1&%G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"FUS9VED(")$95]L971E($-O;'5M
M;B(*;7-G<W1R(")697)?=VEJ9&5R(&MO;&]M(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,PHC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Q"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM
M<V=S='(@(D1E8V5M8F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB
M97)S(@IM<V=S='(@(D1E8VEM86QE(&=E=&%L;&5N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A
M<V4@26YD96YT(@IM<V=S='(@(DEN<W!R:6YG96X@=F5R:VQE:6YE;B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI8B]P<F5F<RYP
M:'`Z,3$W"FUS9VED(")$969A=6QT(@IM<V=S='(@(E-T86YD86%R9"(*"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS
M9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(E-T86YD86%R9"!K;&5U<B(*
M"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z.38*;7-G:60@
M(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B4W1A;F1A87)D(&ED96YT:71E
M:70B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S4*;7-G:60@(D1E9F%U
M;'0@4VAE;&PB"FUS9W-T<B`B4W1A;F1A87)D('-H96QL(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R
M(")$969I;FET:65S(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,2!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S
M.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C,Q('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L
M971E+FEN8SHQ,`IM<V=I9"`B1&5L971E(@IM<V=S='(@(E9E<G=I:F1E<F5N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,R"FUS9VED(")$96QE=&4@0V5L;"(*;7-G<W1R(")697)W:6ID
M97(@8V5L(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S
M+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R(")'<F]E<"!V
M97)W:6ID97)E;B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T
M.0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R(")697)W:6ID97(@;&]G(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E<FUI<W-I
M;VXB"FUS9W-T<B`B4F5C:'0@=F5R=VEJ9&5R96XB"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E(&%N
M9"!P=7)G92!M97-S86=E<R(*;7-G<W1R(")697)W:6ID97(@96X@=VES(&)E
M<FEC:'1E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(E9E
M<G=I:F1E<B!C96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S
M='(@(E9E<G=I:F1E<B!K;VQO;2(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E
M(@IM<V=S='(@(D)E<W1A86YD(&%L=&5R;F%T:65F('-J86)L;V]N('9E<G=I
M:F1E<F5N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP
M:'`Z-30*;7-G:60@(D1E;&5T92!M97-S86=E<R(*;7-G<W1R(")697)W:6ID
M97(@8F5R:6-H=&5N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS
M(&9O<B!<(B5S7"(B"FUS9W-T<B`B4F5C:'1E;B!V86X@7"(E<UPB('9E<G=I
M:F1E<F5N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<
M(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(E)E8VAT
M96X@96X@979E;G1U96QE('-U8G)E8VAT96X@=F]O<B!<(B5S7"(@=F5R=VEJ
M9&5R96X_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R(")697)W
M:6ID97(@<FEJ(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y
M+FEN8SHQ-0IM<V=I9"`B1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S
M='(@(D=E<V5L96-T965R9&4@:61E;G1I=&5I="!V97)W:6ID97)E;B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4S"FUS9VED
M(")$96QE=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B5F5R=VEJ9&5R('-U8FUA
M<'!E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M
M;B(*;7-G<W1R(")697)W:6ID97(@9&4@:'5I9&EG92!K;VQO;2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R(")697)W
M:6ID97(@9&4@:'5I9&EG92!R:6HB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HS-@HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P
M9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B4V5T=7`@=7!G<F%D92!S
M8W)I<'0@7"(E<UPB('9E<G=I:F1E<F0N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0IM<V=I
M9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R(")!9FQE=F5R=&EJ9"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S$*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B1&5N96UA<FME;B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C
M<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R(")"97-C:')I:F8@:&5T('!R;V)L
M965M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*;7-G:60@
M(D1E<V-R:7!T:6]N(@IM<V=S='(@(D)E<V-H<FEJ=FEN9R(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,C`V"FUS9VED(")$971A:6QS("AA;'-O
M(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(D1E=&%I;',@*&]O:R!I
M;B!(;W)D92=S(&QO9V)E<W1A;F0I.B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,C$P"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")$971A:6QS('II:FX@
M9V5L;V=D('9O;W(@9&4@<WES=&5E;6)E:&5E<F1E<BXB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C(Q"FUS9VED(")$979E;&]P;65N="(*;7-G
M<W1R(")/;G1W:6MK96QI;F<B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R
M-`IM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(D1A=7=P=6YT(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,#$*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S
M="!H;W5R.B`B"FUS9W-T<B`B1&%U=W!U;G0@=F]O<B!H970@869G96QO<&5N
M('5U<CH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-@IM
M<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B1&%U=W!U;G0Z("(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@
M(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(E)I8VAT:6YG(&QI
M;FMS(&YA87(@<F5C:'0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F
M="(*;7-G<W1R(")2:6-H=&EN9R!R96-H=',@;F%A<B!L:6YK<R(*"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T
M<B`B1&ER96-T;W)Y(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W,`IM
M<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R("(R-"UU=7)S
M('1I:F1W965R9V%V93\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`P
M"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B5V5E<F=A=F5O<'1I
M97,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.#D*;7-G:60@
M(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B1V5D971A:6QL
M965R9&4@=V5E<G-V;V]R<W!E;&QI;F<@=&]N96XB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.CDR"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM
M<V=S='(@(E=E97)S=F]O<G-P96QL:6YG('1O;F5N("A4048I(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y.0IM<V=I9"`B1&ES<&QA>2!F;W)M
M870B"FUS9W-T<B`B5V5E<F=A=F5F;W)M86%T(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-1$XN<&AP.C$Y,0IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I
M8V%T:6]N(@IM<V=S='(@(E9O;W)B97)E:61I;F=S;F]T:69I8V%T:64B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<P"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R(")$:FEB;W5T:2(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R"FUS9VED(")$
M;R!N;W0@9&5L971E(@IM<V=S='(@(DYI970@=F5R=VEJ9&5R96XB"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E
M8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(FUA:6YT96YA
M;F-E+G!H<"!N:65T(&1I<F5C="!A86YS<')E:V5N(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI
M;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F
M:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B
M0F5V870@9&4@965R<W1E(')I:B!D92!V96QD;F%M96X_(%IO(&IA+"!D:70@
M:&]K:F4@86%N=FEN:V5N.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S(*;7-G:60@(D1O;6EN:6-A
M(@IM<V=S='(@(D1O;6EN:6-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,PIM<V=I9"`B1&]M:6YI
M8V%N(%)E<'5B;&EC(@IM<V=S='(@(D1O;6EN:6-A86YS92!297!U8FQI96LB
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED(")$;VXG
M="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(D=E96X@86-C
M;W5N=#\@4V-H<FEJ9B!U(&EN+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C@U,PIM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B1&]W
M;FQO861E;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C@U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R
M("(E<R!D;W=N;&]A9&5N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V
M,@IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@
M4$A0('-C<FEP="XB"FUS9W-T<B`B1&]W;FQO860@9V5G96YE<F5E<F1E(&-O
M;F9I9W5R871I92!A;',@4$A0('-C<FEP="XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,3`W"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R
M(")$<F]P(&1O=VX@;&EJ<W0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(D1R=6=S(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")%+4UA:6PB"FUS9W-T
M<B`B12U-86EL(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?
M<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E
M<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*
M;7-G<W1R("(B"B)%+6UA:6P@;F%A<B!335,@9V%T97=A>2!S='5U<G!R;V=R
M86UM82P@=F]O<B!D<F%G97)S(&1I92!D97IE('-E<G9I8V4@(@HB;VYD97)S
M=&5U;F5N+B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R
M(")%4E(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<U"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(D5C
M=6%D;W(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X
M,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*;7-G:60@(D5D:70B
M"FUS9W-T<B`B0F5W97)K96XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M54DN<&AP.C4P"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@(D)L;VL@8F5W
M97)K96XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N
M<&AP.C(R-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R(")'<F]E<"!B97=E
M<FME;B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R
M;6ES<VEO;B(*;7-G<W1R(")296-H="!B97=E<FME;B(*"B,Z('-E<G9I8V5S
M+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B4F5C:'1E;B!B97=E<FME;B(*"B,Z('-E<G9I8V5S+W-H87)E
M<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M
M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B4F5C:'1E;B!V86X@)R5S)R!B97=E
M<FME;B(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D
M:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(D]P=&EE<R!B97=E<FME;B!V;V]R
M.B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S8W"B,L('!H
M<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*
M;7-G<W1R(")296-H=&5N('9A;B!<(B5S7"(@8F5W97)K96XB"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@
M(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(E)E8VAT96X@=F%N
M("5S(&)E=V5R:V5N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"FUS
M9VED(")%9'5C871I;VXB"FUS9W-T<B`B3VYD97)W:6IS(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M-PIM<V=I9"`B16=Y<'0B"FUS9W-T<B`B16=Y<'1E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$W
M"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R(")%;"!386QV861O<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,PIM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R(")%;&5M96YT+BXN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*
M;7-G:60@(D5M(@IM<V=S='(@(D5M(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#8Y"FUS9VED(")%;6%I;"(*;7-G<W1R(")%+6UA:6PB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z,3`*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B
M12UM86EL861R97,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38S
M"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`B
M12UM86EL861R97-S96X@;6]E=&5N(&]V97)E96YK;VUE;BXB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@Y"FUS9VED(")%;6%I;"!W:71H(&-O
M;F9I<FUA=&EO;B(*;7-G<W1R(")%+6UA:6P@;65T(&)E=F5S=&EG:6YG(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*
M;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@(D4M;6%I;"!N
M86%R(%--4R!G871E=V%Y(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(Y.0IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(D5M
M;W1I8V]N<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P,@IM<V=I9"`B16UP='D@;65S<V%G92XB"FUS9W-T<B`B
M3&5E9R!B97)I8VAT+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0X-`HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C8R(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T
M<B`B1V5E;B!R97-U;'1A870N(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y
M=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S
M='(@(DQE9V4@>F]E:W1E<FUE;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU-#<*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@
M4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(DEN=F]E9V5N('9A
M;B!A9F)E96QD:6YG96X@=6ET(&9O=&]A;&)U;7,@:6X@=&5K<W0@:6YS8VAA
M:V5L96X_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R,@IM<V=I9"`B
M16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B4F5C
M:'1K;&EK:V5N(&-O;G1E>'0@;65N=2!I;G-C:&%K96QE;C\B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3@X(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(W.3,*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(D5I;F1J86%R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM
M<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`B5F5R9W)O;W0@961I=&]R
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R-`IM<V=I9"`B(@HB16YT
M97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME
M9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N
M("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*
M(D=E968@965N(&)E=F5I;&EG:6YG<W9R86%G(&1I92!U(&=E=G)A86=D('=O
M<F1T+"!W86YN965R(&AE="!N;V1I9R!I<R!O;2!U=R`B"B)W86-H='=O;W)D
M('1E(')E<V5T=&5N+"!B+G8N("=W870@:7,@9&4@;F%A;2!V86X@=7<@:'5I
M<V1I97(_)SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3D*;7-G:60@(D5N=&5R('1H92!I;6%G92!5
M4DP@:&5R92(*;7-G<W1R(")6;V5R(&1E(&%F8F5E;&1I;F<@55),(&AI97(@
M:6XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#DR"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B
M5F]E<B!O;F1E<G-T86%N9&4@;&5T=&5R<R!I;CHB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDY"FUS
M9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R(")%<75A=&]R:6%A;"!'
M=6EN964B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<Y"FUS9VED(")%<FET<F5A(@IM<V=S='(@(D5R
M:71R96$B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70O5FEE=RYP:'`Z.30@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#@*;7-G:60@(D5R
M<F]R(@IM<V=S='(@(D9O=70B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M
M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A
M=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B1F]U="!B:6H@;6%K96X@=F%N(&)L
M;VLZ("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z
M("5S(@IM<V=S='(@(D9O=70@8FEJ('9E<G=I:F1E<F5N('9A;B!S>6YC(&%N
M:V5R.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E
M<R(*;7-G<W1R(")&;W5T(&)I:B!V97)W:6ID97)E;B!V86X@<WEN8R!L;V<Z
M("5S(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E
M<R(*;7-G<W1R(")&;W5T(&)I:B!O<&AA;&5N('9A;B!I;FAO=60Z("5S(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R
M(")&;W5T(&)I:B!B:6IW97)K96X@=F%N('=A8VAT=V]O<F0Z("5S(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U
M"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(D9O
M=70@;65T(&4M;6%I;&)E<FEC:'0N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB
M"FUS9W-T<B`B1F]U="!B:6H@<V-H<FEJ=F5N('9A;B!<(B5S7"(N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW-@IM<V=I9"`B17-T;VYI82(*;7-G<W1R(")%<W1L86YD(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B171H:6]P:>LB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G
M<W1R(")%=&YI<V-H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B175R;W!A(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T,PIM<V=I9"`B179E<GD@,34@;6EN=71E<R(*
M;7-G<W1R(")%;&ME(#$U(&UI;G5T96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,SDS"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B16QK
M92`R(&UI;G5T96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0P(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(D5V97)Y(#,P('-E8V]N
M9',B"FUS9W-T<B`B16QK92`S,"!S96-O;F1E;B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-#(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-`IM<V=I
M9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(D5L:V4@-2!M:6YU=&5N(@H*
M(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HV,`IM
M<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B16QK92!A86YM96QD:6YG(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T-`IM<V=I9"`B179E<GD@:&%L
M9B!H;W5R(@IM<V=S='(@(D5L:R!H86QF('5U<B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,@IM<V=I
M9"`B179E<GD@;6EN=71E(@IM<V=S='(@(D5L:V4@;6EN=75T(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L
M=65S.B(*;7-G<W1R(")6;V]R8F5E;&1W86%R9&5N.B(*"B,Z(&%D;6EN+V-M
M9'-H96QL+G!H<#HU,2!A9&UI;B]P:'!S:&5L;"YP:'`Z.#(@861M:6XO<W%L
M<VAE;&PN<&AP.C$R.`IM<V=I9"`B17AE8W5T92(*;7-G<W1R(")5:71V;V5R
M96XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C8Q-`IM<V=I9"`B17AP86YD(@IM<V=S='(@(E5I=&ML87!P96XB"@HC
M.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS9VED(")%>'!A
M;F0@4VED96)A<B(*;7-G<W1R(")::6IB86QK('5I=&ML87!P96XB"@HC.B!F
M<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E
M8W1E9"`G*2<B"FUS9W-T<B`B5F5R=V%C:'1T92`G*2<B"@HC.B!F<F%M97=O
M<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B
M87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(E9E<G=A
M8VAT=&4@96YK96P@=V]O<F0@;V8@86%N9V5H86%L9&4@>F]E:W1E<FTB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X
M<&ER871I;VX@1&%T92(*;7-G<W1R(")697)V86QD871U;2(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<W"FUS9VED(")%>'!O;F5N
M="(*;7-G<W1R(")%>'!O;F5N="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM
M<V=S='(@(E9O;W)G<F]N9&ML975R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R(")&
M5%`@=7!L;V%D('9A;B!S971U<"(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]S<6PN<&AP.C(R,`IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R
M96YC97,N(@IM<V=S='(@(D]P:&%L96X@=F]O<FME=7)S:6YS=&5L;&EN9V5N
M(&UI<VQU:W0N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*;7-G:60@(D9A
M:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")697)B
M:6YD:6YG(&UE="!D92!,1$%0+7-E<G9E<B!I<R!M:7-L=6MT+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O
M(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B5F5R8FEN9&EN9R!M
M970@9&4@4TU"+7-E<G9E<B!I<R!M:7-L=6MT+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-S$W"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R(")+;W!IZW)E;B!U:70@
M7"(E<UPB(&ES(&UI<VQU:W0N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HW,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@
M=&\@7"(E<UPB+B(*;7-G<W1R(")+;W!IZW)E;B!N86%R(%PB)7-<(B!I<R!M
M:7-L=6MT+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<*
M;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB
M"FUS9W-T<B`B36%K96X@=F%N(&YI975W92!305-,('9E<F)I;F1I;F<@:7,@
M;6ES;'5K="XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U-2!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4P,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(E9E<G!L
M86%T<V5N(&YA87(@7"(E<UPB(&ES(&UI<VQU:W0N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HT-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R(")/<&AA;&5N('9A;B`E<R!I
M<R!M:7-L=6MT(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B36]O:2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#0*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R
M(")&86QK;&%N9"!E:6QA;F1E;B`H36%L=FEN87,I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-@IM
M<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R(")&87)OZW(@96EL86YD96XB
M"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X"FUS9VED(")&871A;"!%
M<G)O<CHB"FUS9W-T<B`B1F%T86QE(&9O=70Z(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S
M='(@(D9A>"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3$*;7-G
M:60@(D9A>&5S(@IM<V=S='(@(D9A>&5N(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S
M='(@(D9E8G)U87)I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C<*;7-G
M:60@(D9E96QS($QI:V4B"FUS9W-T<B`B5F]E;'0@86QS(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,`IM<V=I9"`B1F5E;',@;&EK93H@
M(@IM<V=S='(@(E9O96QT(&%L<SH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S
M='(@(D5N:V5L92!B=6EE;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S
M='(@(D5N:6=E('-N965U=V)U:65N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3DT-`IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(E9E;&1M
M871R:7@B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(U"FUS9VED
M(")&:6=L970@0T%05$-(02(*;7-G<W1R(")&:6=L970@0T%05$-(02(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,CD*;7-G:60@(D9I9VQE="!F
M;VYT(@IM<V=S='(@(D9I9VQE="!F;VYT(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,PIM<V=I9"`B
M1FEJ:2(*;7-G<W1R(")&:6II(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C4U"FUS9VED(")&:6QE(@IM<V=S='(@(D)E<W1A;F0B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(D%A;G1A;"!B97-T86YD
M96XZ("5S(&)E<W1A;F0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*
M;7-G<W1R(")!86YT86P@8F5S=&%N9&5N.B`E<R!B97-T86YD96XB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`Y"FUS9VED(")&:6QE($UA;F%G
M97(B"FUS9W-T<B`B0F5S=&%N9&)E:&5E<B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<P"FUS9VED(")&:6QE($YA;64B"FUS9W-T<B`B0F5S=&%N
M9'-N86%M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW-PIM<V=I
M9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B0F5S=&%N9"!K:65Z96XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#@V"FUS9VED(")&:6QE('5P
M;&]A9"(*;7-G<W1R(")"97-T86YD=7!L;V%D(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.3`R"FUS9VED(")&:6QE('5P;&]A9',@;F]T
M('-U<'!O<G1E9"XB"FUS9W-T<B`B0F5S=&%N9'5P;&]A9',@=V]R9&5N(&YI
M970@;VYD97)S=&5U;F0N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.CDQ"FUS9VED(")&:6QT97)S(@IM<V=S='(@(D9I;'1E<G,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@R"FUS9VED(")&:6YL86YD(@IM<V=S='(@(D9I;FQA;F0B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@
M(D5E<G-T92!H96QF="(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T
M<B`B165R<W1E(&MW87)T86%L(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(U-PIM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@
M(E9E<FAO=61I;F<@:&5R<W1E;&QE;B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR,S(*;7-G:60@(D9L:7`B"FUS9W-T<B`B
M3VUK97)E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(D1R:6IV96XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM
M<V=I9"`B1F]G(@IM<V=S='(@(DUI<W0B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,3`W(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C,W
M"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES
M="(*;7-G<W1R(")-87`@)7,@8F5S=&%A="!N:65T(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#
M;VQO<B(*;7-G<W1R(")&;VYT:VQE=7(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B5F]E9'-E;"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R,PIM<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I
M;6%G97,B"FUS9W-T<B`B5F]O<B!B<F]W<V5R<R!D:64@9V5E;B!A9F)E96QD
M:6YG96X@;VYD97)S=&5U;F5N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-#$*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@(E=E97)S=F]O<G-P
M96QL:6YG("A4048I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C<R"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E
M='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A
M("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@
M8FQO8VLI(@IM<V=S='(@(B(*(E9O;W)U:71Z:6-H=&1A9V5N("AM97)K(&]P
M(&1A="!H970@9V5G979E;B!V;V]R=6ET>FEC:'0@9&%G96X@96X@;F%C:'1E
M;B`B"B)G965F=#L@965N(&=R;V]T(&%A;G1A;"!K86X@<F5S=6QT97)E;B!I
M;B!E96X@8G)E960@8FQO:RDB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@
M(E5W('=A8VAT=V]O<F0@=F5R9V5T96X_(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0V-`IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B1F]R;75L:65R
M96XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U
M;F4B"FUS9W-T<B`B1F]R='5N92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(D9O<G1U;F5T>7!E
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED(")&;W)T=6YE
M<R(*;7-G<W1R(")&;W)T=6YE<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R(")&;W)T=6YE<R`R(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U-0IM<V=I9"`B1F]R=6US
M(@IM<V=S='(@(D9O<G5M<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ,3$*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(D1O;W)S='5R96XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS
M9VED(")&<B(*;7-G<W1R(")6<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@(D9R86UE<R(*;7-G
M<W1R(")&<F%M97,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W"FUS9VED(")&<F%N8V4B"FUS9W-T
M<B`B1G)A;FMR:6IK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R(")&<F%N
M:W)I:FLL($AO;V9D<W1E9&5L:6IK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,0IM<V=I9"`B1G)E
M;F-H($=U:6%N82(*;7-G<W1R(")&<F%N<R!'=7EA;F$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M-`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R(")&<F%N<R!0;VQY
M;F5S:>LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C(*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!4
M97)R:71O<FEE<R(*;7-G<W1R(")&<F%N<V4@6G5I9&5L:6IK92!497)R:71O
M<FEA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R(")686XB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C,W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-#D*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-0IM
M<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(E9A;B!D92`B"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP
M=&EO;B(*;7-G<W1R(")6;VQL961I9V4@8F5S8VAR:6IV:6YG(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G
M:60@(D9U;&P@36]O;B(*;7-G<W1R(")6;VQL92!M86%N(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C8U('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-C`*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R(")6;VQL961I9V4@
M;F%A;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#@*;7-G:60@(D=A8F]N(@IM<V=S='(@(D=A8F]N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O
M;2(*;7-G<W1R(")!;&)U;2!W86%R=6ET(&1E(&%F8F5E;&1I;F<@9V5H86%L
M9"!D:65N="!T92!W;W)D96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ
M(@IM<V=S='(@(D%L8G5M.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38*;7-G:60@(D=A;6)I82(*
M;7-G<W1R(")'86UB:6$B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R
M"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R871I
M;VXB"FUS9W-T<B`B1V5N97)E97(@)7,@8V]N9FEG=7)A=&EE(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R
M871E9"!#;V1E(@IM<V=S='(@(D=E9V5N97)E97)D92!C;V1E(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY,`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R(")'96]R9VGK(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R(")$=6ET<VQA;F0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDS"FUS9VED(")':&%N82(*;7-G<W1R(")':&%N82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.30*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R(")':6)R86QT87(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-@IM<V=I9"`B1VEV
M96X@3F%M92(*;7-G<W1R(")6;V]R;F%A;2(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HQ-S4@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3`*
M(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*;7-G:60@(D=L;V)A;"!/
M<'1I;VYS(@IM<V=S='(@(D=L;V)A;&4@;W!T:65S(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z,3<*;7-G:60@(D=O(@IM<V=S='(@(D=A(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T
M<B`B1V]E9&5L(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$Q,S$*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(D=O;V=L
M92!K86%R=&5N(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I
M9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R(")';V]G;&4@>F]E:V5N(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S.`IM<V=I
M9"`B1W)A>7-C86QE(@IM<V=S='(@(D=R:6IS<V-H86%L(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,#`*;7-G:60@(D=R965C92(*;7-G<W1R(")'<FEE:V5N;&%N9"(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")'<F5E:R`H25-/+3@X-3DM
M-RDB"FUS9W-T<B`B1W)I96MS("A)4T\M.#@U.2TW*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34*
M;7-G:60@(D=R965N;&%N9"(*;7-G<W1R(")'<F]E;FQA;F0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@Y"FUS9VED(")'<F5N861A(@IM<V=S='(@(D=R96YA9&$B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB
M"FUS9W-T<B`B1W)O97!S8F5H965R(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y
M"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R
M(")'<F]E<&YA;65N(&UO9V5N(&YI970@;&5E9R!Z:6IN(@H*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,P-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B1W)O=7!?;&1A
M<#H@3FEE="!I;B!S=&%A="!G<F]E<"`E<R!T;V4@=&4@=F]E9V5N+B!$92!S
M97)V97(@;65L9'0Z("(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L('!H<"UF
M;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O
M=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@3FEE="!I;B!S=&%A="!G<F]E
M<"`E<R!T92!V97)W:6ID97)E;B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@
M=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD87`Z($YI970@
M:6X@<W1A870@9W)O97`@)7,@8FEJ('1E('=E<FME;B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'
M<F]U<',B"FUS9W-T<B`B1W)O97!E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@*;7-G:60@(D=U
M861E;&]U<&4B"FUS9W-T<B`B1W5A9&5L;W5P92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S"FUS
M9VED(")'=6%M(@IM<V=S='(@(D=U86TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,@IM<V=I9"`B
M1W5A=&5M86QA(@IM<V=S='(@(D=U871E;6%L82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(D=U
M97)N<V5Y(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B1V%S="!R96-H=&5N(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0W,@IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@
M(D=A<W1E;F)O96LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW"FUS9VED(")'=6EN96$B"FUS9W-T
M<B`B1W5I;F5E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T"FUS9VED(")'=6EN96$M0FES<V%U
M(@IM<V=S='(@(D=U:6YE92U":7-S874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4*;7-G:60@
M(D=U>6%N82(*;7-G<W1R(")'=7EA;F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY-C`*;7-G:60@(DA434PB"FUS9W-T<B`B2%1-3"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*
M;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R(")(5$U,07)E82!W96EG97)T
M(&QA9B!O;2!D92!L86%T<W1E(&-E;"!I;B!D92!R:6H@=&4@=F5R=VEJ9&5R
M96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R(")(
M5$U,07)E82!W96EG97)T(&QA9B!O;2!D92!L86%T<W1E(&MO;&]M(&EN(&1E
M('1A8F5L('1E('9E<G=I:F1E<F5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T
M86)L92XB"FUS9W-T<B`B2%1-3$%R96$@=V5I9V5R="!L868@;VT@9&4@;&%A
M='-T92!R:6H@:6X@9&4@=&%B96P@=&4@=F5R=VEJ9&5R96XN(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@075T
M:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")(5%10(&%U=&AE;G1I
M8V%T:64@;FEE="!G979O;F1E;BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`*;7-G:60@(DAA
M:71I(@IM<V=S='(@(DAA:71I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G<W1R(")(
M87-H+6%L9V]R:71H;64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR,@IM<V=I9"`B2&%Z92(*;7-G<W1R(").979E;"(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDQ.2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.3$T"FUS9VED(")(96%D97(B"FUS9W-T<B`B2V]P(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0IM<V=I
M9"`B2&5A9&5R<R(*;7-G<W1R(")+;W!P96XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<*;7-G
M:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R
M(")(96%R9"!E:6QA;F0@96X@36-$;VYA;&0@96EL86YD96XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A
M=GD@5"U3=&]R;2(*;7-G<W1R("):=V%R92!O;G=E97)S8G5I(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM
M."U)*2(*;7-G<W1R(")(96)R965U=W,@*$E33RTX.#4Y+3@M22DB"@HC.B!L
M:6(O0FQO8VLO:69R86UE+G!H<#HR,B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS9W-T
M<B`B2&]O9W1E(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP
M.C$X-"!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@V"B,Z('-E
M<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L871E<R]H96QP+VEN9&5X
M+FEN8SHT"FUS9VED(")(96QP(@IM<V=S='(@(DAE;'`B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP
M('5S:6YG(&5D:71O<B(*;7-G<W1R(")(96QP(&)I:B!G96)R=6EK('9A;B!E
M9&ET;W(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q"FUS9VED
M(")(96QP97(B"FUS9W-T<B`B2&5L<&5R(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@(DAA;&9R;VYD(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A
M=&$O='-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN
M9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B2&EE<B!I<R!H970@8F5G:6X@=F%N
M(&AE="!B97-T86YD.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<Q"FUS9VED(")(:6=H(@IM<V=S='(@(DAO;V<B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O
M;6UO;BUH96%D97(N:6YC.C4*;7-G:60@(DAO7VUE(@IM<V=S='(@(DAO7VUE
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T,PIM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET
M>2!3=&%T92DB"FUS9W-T<B`B2&]L>2!3964@*%9A=&EC86%N<W1A9"DB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U-#@*;7-G:60@(DAO;64B
M"FUS9W-T<B`B2&]M92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D%D
M<F5S("AP<FEVZ2DB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G
M:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(DAO;65D:7)E8W1O<GDB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS
M9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(E1E;"YN<BX@*'!R:7;I*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P.`IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B2&]N9'5R87,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,#8*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R(")(;VYG
M($MO;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C<*;7-G:60@
M(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HT-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E
M<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3VYG96QD:6=E("5S(%A-3"!D871A
M('1E9V5N9V5K;VUE;B!I;B!B97)I8VAT("5S(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM
M<V=S='(@(DAO<F1E+TMO;&%B.B!'965N(&)E<FEC:'0@8V]R<F5S<&]N9&5E
M<G0@;65T(&]B:F5C="`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z-#0U"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O
M8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@
M(DAO<F1E+TMO;&%B.B!'965N(&]B:F5C="!V86X@='EP92`E<R!G979O;F1E
M;B!I;B!B97)I8VAT("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HQ,C4Q"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C
M97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L
M86(Z("5S(&UE="!S=6-C97,@=F5R=VEJ9&5R9"!<(B5S7"(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z
M(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG
M(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B2&]R9&4O2V]L86(Z($1E(&EN=&5R
M9W)A=&EE('9E<F5I<W0@9&4@)V1O;7AM;"<@97AT96YS:64B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C4Q,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@
M9F]R(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@2V%N(&=E96X@
M;FEE=7=E(%A-3"!B;V]M(&UA:V5N('9O;W(@;V)J96-T("5S(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0X"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@
M)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($MA;B`E<R!<(B5S7"(@;FEE="!V
M97)W:6ID97)E;CH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C0X,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE
M('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B
M"FUS9W-T<B`B(@HB2&]R9&4O2V]L86(Z($YI970@:6X@<W1A870@:&5T($U)
M344@240L('9O;W(@:&5T(&=E9&5E;'1E(&UE="!T>7!E("5S+"!O<"!T92`B
M"B)H86QE;B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$Y-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y
M;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M($MA;B`E<R!<(B5S7"(@;FEE="!S>6YC:')O;FES97)E;CH@)7,B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$S,S<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R
M97,Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!+86X@9V5D965L9&4@8G)O
M;FYE;B!N:65T('-Y;F-H<F]N:7-E<F5N.B`E<R(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@3VYB96ME;F1E(&=E9&5E;&1E(&)R;VX@7"(E<UPB(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B
M2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(DAO<FEZ;VYT86QE(&QI:FXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@R"FUS
M9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B2&]R:7IO;G1A;&4@
M=G)I:F4@<G5I;71E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B2&]R
M:7IO;G1A86PZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R
M93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R(")(;V4@:W=A;2!U(&AI97(_
M("A'<F%A9R!R87!P;W)T86=E(2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C
M;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")(;V5V
M965L(&MO;&]M;65N('=I;'0@=2!S86UE;G9O96=E;C\B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S
M("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(DAO979E96P@=F5L9&5N
M("AK;VQO;6UE;BD@>FEJ;B!E<C\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R
M;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")(;V5V965L
M(')I:F5N('=I;'0@=2!S86UE;G9O96=E;C\B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(S-R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y"FUS
M9VED(")(=6UI9&ET>2(*;7-G<W1R(")6;V-H=&EG:&5I9"(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@*;7-G:60@(DAU;6ED:71Y.B`B
M"FUS9W-T<B`B5F]C:'1I9VAE:60Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(DAU;6]R:7-T96XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3$*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B2&]N9V%R
M:6IE(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-2!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B36%K96X@=F%N($E-05`@;6%I;&)O>"!M:7-L=6MT.B`E<R(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.34@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T"B,L('!H<"UF;W)M870*;7-G:60@
M(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(E9E
M<G=I:F1E<F5N('9A;B!)34%0(&UA:6QB;W@@;6ES;'5K=#H@)7,B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C0R(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C$W.0HC+"!P:'`M9F]R;6%T"FUS9VED("))
M34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R
M(")-86ME;B!V86X@24U!4"!M86EL8F]X('%U;W1A(&UI<VQU:W0Z("5S(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q-@IM<V=I9"`B25`@061D
M<F5S<R(*;7-G<W1R("))4"!!9')E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B25`@861R97,@;FEE="!B97-C:&EK8F%A<BXB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))
M4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G
M<W1R("))4"!A9')E<R!V86QT(&YI970@8FEN;F5N(&AE="!T;V5G97-T86YE
M($-)1%(@8FQO:RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO
M;BXB"FUS9W-T<B`B25`@;&]C:V1O=VX@;W9E<G1R961I;F<N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y
M"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B4FEJ(&E?;G9O
M96=E;B!V;V]R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P"FUS9VED("))8V5L86YD(@IM<V=S
M='(@(DE*<VQA;F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@P"FUS
M9VED("))8V]N<R!/;FQY(@IM<V=S='(@(D%L;&5E;B!P:6-T;V=R86UM96XB
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(E!I8W1O9W)A;6UE;B!V;V]R
M("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,0IM<V=I9"`B26-O
M;G,@=VET:"!T97AT(@IM<V=S='(@(E!I8W1O9W)A;6UE;B!M970@=&5K<W0B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DS"FUS9VED("))9&5N=&ET
M>2=S(&YA;64Z(@IM<V=S='(@(DED96YT:71E:71S;F%A;3HB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HV,#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S
M('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("(B"B)786YN
M965R(&AE="!N:65T(&=O960@=V]R9'0@=V5E<F=E9V5V96XL("5S(&]M(&AE
M="!I;B!E96X@;FEE=7<@<V-H97)M('1E("(*(F]P96YE;BXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#4Y"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@
M<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA
M>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T
M<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*(D%L<R!U(&=E96X@<&EC=&]G<F%M
M;65N('II970L(&)I:B!G96)R=6EK('9A;B!);G1E<FYE="!%>'!L;W)E<BP@
M:V%N(&AE="`B"B)N;V1I9R!Z:6IN(&1I="!V86MJ92!A86X@=&4@=FEN:V5N
M(&]M(%!.1R!T<F%N<W!A<F%T:64@=6ET('1E('-C:&%K96QE;BXB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<R"FUS9VED
M("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H
M92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA
M>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@HB5V%N;F5E<B!U(&1I
M="!B97)I8VAT('II970L(&UA87(@9V5E;B!A9F)E96QD:6YG+"!D86X@:V%N
M(&1E(&%F8F5E;&1I;F<@9&EE("(*(G4@=VEL="!U<&QO861E;B!N:65T(&1O
M;W(@=7<@8G)O=W-E<B!W;W)D96X@=V5E<F=E9V5V96XN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U
M"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R(")!9F)E96QD:6YG<V)E
M;V]R9&5L:6YG.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R(")!
M9F)E96QD:6YG(%523"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`IM<V=I9"`B26UA9V4@55),.B(*
M;7-G<W1R(")!9F)E96QD:6YG(%523#HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM
M86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R(")!9F)E96QD:6YG('5I="!A;&)U
M;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G
M<W1R(")!9F)E96QD:6YG('5I="!A;&)U;3HB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-S8Q"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`B
M069B965L9&EN9W-U<&QO860B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(D%F8F5E;&1I;F=E;B(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHU-`HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHW('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(DEM<&]R=&5R96XL('-T87`@
M)60B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B1V5I
M;7!O<G1E97)D('9E;&0Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R(")'96EM
M<&]R=&5E<F1E('9E;&1E;CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W
M($%F=&5R(@IM<V=S='(@(E)I:B!I;G9O96=E;B!N82(*"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-`IM<V=I9"`B26YC;W)R
M96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R(")/;FIU:7-T92!B97=E
M<FMI;F=S8V]D92!O<&=E9V5V96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U
M<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(D]N:G5I<W1E(&=E
M8G)U:6ME<G-N86%M(&5N+V]F('=A8VAT=V]O<F0N(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R
M;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A
M8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@
M:&5L<"XB"FUS9W-T<B`B(@HB3VYJ=6ES=&4@9V5B<G5I:V5R<VYA86T@;V8@
M86QT97)N871I968@861R97,N(%!R;V)E97(@;W!N:65U=R!O9B!N965M("(*
M(F-O;G1A8W0@;W`@;65T(&1E('-Y<W1E96UB96AE97)D97(L('=A;FYE97(@
M=2!V97)D97)E(&AU;'`@;F]D:6<@:&5E9G0N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@
M26YD96YT(@IM<V=S='(@(E9E<F=R;V]T(&EN<W!R:6YG:6YG(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$V"FUS9VED("));F1I82(*;7-G<W1R("));F1I82(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@
M(DEN9&EV:61U96QE(&=E8G)U:6ME<G,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(*;7-G:60@
M(DEN9&]N97-I82(*;7-G<W1R("));F1O;F5S:>LB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM
M<V=S='(@(DEN9F\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Y
M"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA=&EE(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q.0IM<V=I9"`B26YF;W)M
M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`B26YF;W)M871I
M92!N:65T(&QA;F=E<B!B97-C:&EK8F%A<BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN
M<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(DMO;&]M(&EN=F]E9V5N(&YA
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$W"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`B069B
M965L9&EN9R!I;G9O96=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R
M(")486)E;"!I;G9O96=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G
M<W1R(")796)L:6YK(&EN=F]E9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@
M7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B7TMO;&]M(&EN=F]E9V5N('9O;W(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE
M(&-U<G)E;G0@;VYE(@IM<V=S='(@(D5E;B!N:65U=V4@:V]L;VT@:6YV;V5G
M96X@;F$@9&4@:'5I9&EG92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W
M(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(D5E;B!N
M:65U=V4@:V]L;VT@:6YV;V5G96X@=F]O<B!D92!H=6ED:6=E(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R
M"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N
M92(*;7-G<W1R(")%96X@;FEE=7=E(')I:B!I;G9O96=E;B!N82!D92!H=6ED
M:6=E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T
M:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B165N(&YI975W92!R:6H@:6YV;V5G
M96X@;F$@9&4@:'5I9&EG92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R
M86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B165N(&YI
M975W92!P87)A9W)A868@:6YV;V5G96X@;F$@9&4@:'5I9&EG92!N;V1E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C
M=7)R96YT(&YO9&4B"FUS9W-T<B`B165N(&YI975W92!P87)A9W)A868@:6YV
M;V5G96X@;F$@9&4@:'5I9&EG92!N;V1E(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS
M9W-T<B`B06QT97)N871I968@<VIA8FQO;VX@:6YV;V5G96XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C0R"FUS9VED("));G-E<G0@86X@96UA:6P@
M861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S
M=V]R9#HB"FUS9W-T<B`B165N(&4M;6%I;&%D<F5S(&EN=F]E9V5N+"!W86%R
M('4@:&5T(&YI975W92!W86-H='=O;W)D(&MA;B!O;G1V86YG96XZ(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`B0V5L(&EN=F]E
M9V5N(&YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S
M='(@(D-E;"!I;G9O96=E;B!V;V]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O
M;'5M;B!A9G1E<B(*;7-G<W1R(")+;VQO;2!I;G9O96=E;B!N82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*
M;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(DMO;&]M(&EN
M=F]E9V5N('9O;W(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T
M+G!H<#HU,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(D)E<FEC
M:'1E;B!I;G9O96=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G<F%P
M:"!A9G1E<B(*;7-G<W1R(")087)A9W)A868@:6YV;V5G96X@;F$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(E!A
M<F%G<F%A9B!I;G9O96=E;B!V;V]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(')O
M=R!A9G1E<B(*;7-G<W1R(")2:6H@:6YV;V5G96X@;F$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED
M("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R(")2:6H@:6YV;V5G96X@=F]O
M<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S,*;7-G:60@(DEN<V5R
M="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO
M;CHB"FUS9W-T<B`B2&5T(&=E=V5N<W1E(&%N='=O;W)D('9O;W(@9&4@8F5V
M96EL:6=I;F=S=G)A86<@:6YV;V5G96XZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS97)T+TUO9&EF
M>2!);6%G92(*;7-G<W1R(")!9F)E96QD:6YG(&EN=F]E9V5N+V%A;G!A<W-E
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R("),:6YK(&EN
M=F]E9V5N+V%A;G!A<W-E;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E
M9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R
M(")/;G9O;&1O96YD92!K<F5D:65T(&]M(&YA87(@9&4@9&ES=')I8G5T:65L
M:6IS="!T92!Z96YD96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D
M:70N(@IM<V=S='(@(D]N=F]L9&]E;F1E(&MR961I970B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#<U"FUS9VED("));G1E9V5R(@IM<V=S='(@
M(DEN=&5G97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,S"FUS
M9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B26YT96=E<B!L:6IS="(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS
M9W-T<B`B3VYG96QD:6=E(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$V-PHC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ.30*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C$R"FUS9VED("))
M;G9A;&ED(%I)4"!D871A(@IM<V=S='(@(D]N9V5L9&EG92!:25`@9&%T82(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@
M87!P;&EC871I;VXN(@IM<V=S='(@(D]N9V5L9&EG92!T;V5P87-S:6YG+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q,@IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T<B`B3VYG96QD
M:6<@8F%T8V@@240N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`X
M-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(Y
M.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W
M"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R(")/;F=E
M;&1I9V4@9&%T82!O<&=E9V5V96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED(&1E
M<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(D]N9V5L9&EG(&)E<W1E;6UI
M;F=A9')E<RXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X
M+G!H<#HQ,#D*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP
M:'`Z,3,Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP
M.C(T,0IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R(")/;F=E
M;&1I9R!T:6ID9F]R;6%A="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-C4*;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@
M(D]N9V5L9&EG92!L:6-E;G1I97-L975T96PN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$U.0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P
M<F]V:61E9"XB"FUS9W-T<B`B3VYG96QD:6=E(&QO8V%T:64@;W!G96=E=F5N
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B3VYG
M96QD:6<@;7-G7W1Y<&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I
M;F<@87!I7VED+B(*;7-G<W1R(")/;F=E;&1I9R!O9B!O;G1B<F5K96YD(&%P
M:5]I9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T
M97)S+B(*;7-G<W1R(")/;F=E;&1I9V4@;V8@;VYT8G)E:V5N9&4@<&%R86UE
M=&5R<RXB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@
M(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(D]N9V5L9&EG
M('!A<F5N="!R96-H="XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,38Q"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(D]N
M9V5L9&EG('!A<G1N97(@:60N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$V,PIM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S
M='(@(D]N9V5L9&EG92!P<F]D=6-T:65C;V1E+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV
M86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B3VYG96QD:6<@<')O=&]C;VPN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY
M,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C<Q(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R
M(")/;F=E;&1I9V4@;VYT=F%N9V5R.B!<(B5S7"(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C$P.#`@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HQ,C8S"FUS9VED("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R(")/
M;F=E;&1I9V4@9V5D965L9&4@8G)O;B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S
M;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B3VYG96QD:6<@8G)O;F%D<F5S+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(D]N
M9V5L9&EG92!U;FEC;V1E(&1A=&$N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,U.0IM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(DEN=F5N=&%R
M:7,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C<X"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(E-E;&5C=&EE
M(&]M:V5R96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D*;7-G:60@(DER86XL($ES;&%M:6,@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B27)A;BP@27-L86UI=&ES8VAE(%)E<'5B
M;&EE:R!V86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@*;7-G:60@(DER87$B"FUS9W-T<B`B
M27)A:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q,PIM<V=I9"`B27)E;&%N9"(*;7-G<W1R("))
M97)L86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G
M:60@(DES;&4@;V8@36%N(@IM<V=S='(@(D5I;&%N9"!-86XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O
M;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B1V5I<V]L965R9&4@;VYW965R<V)U
M:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$T"FUS9VED("))<W)A96PB"FUS9W-T<B`B27-R
M8>ML(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C8*
M;7-G:60@(DES<W5E<B(*;7-G<W1R(")5:71G979E<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC
M(@IM<V=S='(@(D-U<G-I968B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$*;7-G:60@(DET86QY
M(@IM<V=S='(@(DET86QIZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,PIM<V=I9"`B2F%M86EC
M82(*;7-G<W1R(")*86UA:6-A(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B2F%N
M=6%R:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R-0IM<V=I9"`B2F%P86XB"FUS9W-T<B`B2F%P
M86XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B2F%P86YE
M<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R(")*87!A;G,@*$E33RTR,#(R+4I0
M*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*
M97)S97DB"FUS9W-T<B`B2F5R<V5Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T"FUS9VED(")*
M;W)D86XB"FUS9W-T<B`B2F]R9&%N:>LB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R(")*
M=6QI(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B2G5N:2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU
M<W1I9GDB"FUS9W-T<B`B=6ET;&EJ;F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I
M9GD@0V5N=&5R(@IM<V=S='(@(D=E8V5N=')E97)D('5I=&QI:FYE;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B5F]L;&5D:6<@=6ET
M;&EJ;F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("),
M:6YK<R!U:71L:6IN96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*
M;7-G<W1R(")296-H=',@=6ET;&EJ;F5N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V"FUS9VED
M(")+87IA:VAS=&%N(@IM<V=S='(@(DMA>F%C:'-T86XB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8U"FUS9VED(")+965P
M(&]R:6=I;F%L/R(*;7-G<W1R(")/<FEG:6YE96P@8F5H;W5D96X_(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(V"FUS9VED(")+96YY82(*;7-G<W1R(")+96YI82(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S
M('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B2V5R
M8F5R;W,@<V5R=F5R('=E:6=E<F1E(&%U=&AE;G1I8V%T:64N(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*
M;7-G<W1R(")+97)N96P@3F5W8FEE<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@
M(E-L975T96P@;6%K96XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R(")3;&5U
M=&5L=FEN9V5R869D<G5K(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@(E-L975T96QL
M96YG=&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*
M;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(E-L975T96QT>7!E(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3D*;7-G:60@(DME>2!5
M<V%G92(*;7-G<W1R(")3;&5U=&5L9V5B<G5I:R(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI
M<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")$92!S;&5U
M=&5L(&)E<W1A870@86P@;W`@9&4@;W!E;F)A<F4@<VQE=71E;'-E<G9E<BXB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS
M9W-T<B`B2VEN9&5R96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD*;7-G:60@(DMI<FEB871I
M(@IM<V=S='(@(DMI<FEB871I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R"FUS9VED(")+;W)E
M82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R(")+
M;W)E82P@1&5M;V-R871I<V-H92!6;VQK<W)E<'5B;&EE:R!V86XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S,*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R(")+
M;W)E82P@4F5P=6)L:65K('9A;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DQ"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B2V]R96%A;G,@
M*$550RU+4BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S0*;7-G:60@(DMU=V%I="(*;7-G<W1R
M(")+;V5W96ET(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W"FUS9VED(")+>7)G>7IS=&%N(@IM
M<V=S='(@(DMY<F=I97-IZR(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI
M;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R(")/7W!M86%K(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS
M9W-T<B`B5&%A;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-PIM<V=I9"`B3&%O(%!E;W!L92=S
M($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B1&5M;V-R871I<V-H92!6
M;VQK<W)E<'5B;&EE:R!,86\B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y
M"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B3&%A='-T92!H96QF="(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX.`IM<V=I9"`B3&%S="!087-S=V]R
M9"!#:&%N9V4B"FUS9W-T<B`B3&%A='-T92!W86-H='=O;W)D=VEJ>FEG:6YG
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H
M<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(DQA871S=&4@:W=A
M<G1I97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.`IM<V=I9"`B3&%S
M="!5<&1A=&5D.B(*;7-G<W1R("),86%T<W0@8FEJ9V5W97)K=#HB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HW,3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`B3&%A='-T92!A86YM96QD:6YG
M.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@
M(DQA871S=&4@86%N;65L9&EN9SH@)7,@=F%N("5S(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z-S$T"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*
M;7-G<W1R("),86%T<W1E(&%A;FUE;&1I;F<Z($YO;VET(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30V"FUS9VED("),871V:6$B"FUS9W-T<B`B3&5T;&%N9"(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(E)E8VAT
M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,SD*;7-G:60@(DQA>6]U="(*;7-G<W1R(")/<&UA86LB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED
M("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(DQA870@;&5E
M9R!V;V]R(&=E96X@<F%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.`IM<V=I9"`B3&5B86YO
M;B(*;7-G<W1R("),:6)A;F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0P"FUS9VED("),969T(@IM<V=S='(@
M(DQI;FMS(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P,0IM<V=I
M9"`B3&5F="!H96%D97(B"FUS9W-T<B`B3&EN:W-E(&MO<"(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,P.3<*;7-G:60@(DQE9G0@=F%L=65S(@IM
M<V=S='(@(DQI;FMS92!W86%R9&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S"FUS9VED("),
M97-O=&AO(@IM<V=S='(@(DQE<V]T:&\B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR-34*;7-G:60@(DQE=F5L(@IM<V=S='(@(DYI=F5A=2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T,@IM<V=I9"`B3&EB97)I82(*;7-G<W1R("),:6)E<FEA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30W"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA
M(@IM<V=S='(@(DQI8FES8VAE($%R86)I<V-H92!*86UA:&ER:7EA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30P"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(DQI96-H
M=&5N<W1E:6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R("):86-H="!B
M=6ET:F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR-@IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R("),:6-H=&4@<F5G96XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM
M<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R(")6<F]E9R!L:6-H=&4@
M<F5G96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(DQI8VAT92!R
M96=E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R("),:6-H=&4@
M<F5G96YB=6DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T
M<B`B3&EC:'1E(')E9V5N(&UE="!O;G=E97(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*
M;7-G<W1R("),:6-H=&4@<VYE975W(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R
M(@IM<V=S='(@(DQI8VAT92!S;F5E=7=B=6DB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(DQI;65R:6-K
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-`IM<V=I9"`B3&EN
M:R(*;7-G<W1R("),:6YK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T
M;SHB"FUS9W-T<B`B3&EN:R!W:6IS="!N86%R.B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X-S4*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E
M<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T
M<B`B3&EN:R!H970@92UM86EL861R97,@86%N(&1E(&YI975W(&)E<FEC:'0@
M<&%G:6YA('1I:F1E;G,@=V5E<F=A=F4B"@HC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@R"FUS9VED("),:6YK<R(*
M;7-G<W1R("),:6YK<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM
M<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(DQI;G5X($-O;VMI92(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C0V"FUS9VED("),
M:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B3&EJ<W0@
M+2!G96)R=6EK97(@:V%N(&1E(&UA<"!Z:65N(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$S-`IM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B1&%T
M86)A<V5L:6IS="(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4Q"FUS
M9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(DQI:G-T('9A;B!H96QP
M(&]N9&5R9&5L96XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS9VED
M("),:7-T(%1A8FQE<R(*;7-G<W1R(")486)E;&QI:G-T(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.30*;7-G:60@(DQI<W0M07)C
M:&EV92(*;7-G<W1R("),:6IS="U!<F-H:65F(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12](96%D97)S+G!H<#HU.#D*;7-G:60@(DQI<W0M2&5L<"(*;7-G
M<W1R("),:6IS="U(96QP(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D
M97)S+G!H<#HU.38*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B3&EJ<W0M260B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I
M9"`B3&ES="U/=VYE<B(*;7-G<W1R("),:6IS="U%:6=E;F%A<B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T
M+5!O<W0B"FUS9W-T<B`B3&EJ<W0M4&]S="(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C<FEB92(*
M;7-G<W1R("),:6IS="U);G-C:')I:G9E;B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E
M(@IM<V=S='(@(DQI:G-T+55I='-C:')I:G9E;B(*"B,Z(&%D;6EN+W-E<W-I
M;VYS+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I
M;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`B5V5E<F=E=F5N('9A;B!S97-S:65L
M:6IS="!I<R!M:7-L=6MT.B`E<R(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B5V5E<F=E=F5N('9A;B!G96)R=6EK97)S;&EJ<W0@:7,@
M;6ES;'5K=#H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N
M:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S
M='(@(E=E97)G979E;B!V86X@9V5B<G5I:V5R<VQI:G-T(&ES('5I=&=E<V-H
M86ME;&0N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),
M:71E<F%T=7)E(@IM<V=S='(@(DQI=&5R871U=7(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#0*
M;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("),:71O=7=E;B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z-S<*;7-G:60@(DQO
M861I;F<N+BXB"FUS9W-T<B`B3&%D96XN+BXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C`P"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T
M<B`B3&]K86QE('1I:F0Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V
M"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B3&%N9&EN<W1E;&QI
M;F<@96X@=&EJ9"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3<R(&QI8B]";&]C:R]M971A<BYP:'`Z-S(*(SH@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-PIM
M<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B3&]C871I92(*"B,Z(&QO9VEN+G!H
M<#HQ.#D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(P,"!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.CDP"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C,@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34*;7-G:60@
M(DQO9R!I;B(*;7-G<W1R(")!86YM96QD96XB"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC
M('-E<W-I;VXB"FUS9W-T<B`B3&]G('9A;B!V;V]R9V%A;F1E('-Y;F,@<V5S
M<VEE(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y-`IM<V=I
M9"`B3&]G(&]U="(*;7-G<W1R(")!9FUE;&1E;B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HV,0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B06%N;65L9&5N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,`IM<V=I9"`B3&]G:6X@
M5&%S:W,B"FUS9W-T<B`B06%N;65L9'1A:V5N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.3DU"FUS9VED("),;V=I;B!F86EL960@8F5C875S92!Y
M;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C
M=&QY+B(*;7-G<W1R("(B"B)!86YM96QD:6YG(&UI<VQU:W0@;VUD870@=7<@
M9V5B<G5I:V5R<VYA86T@;V8@=V%C:'1W;V]R9"!O;FIU:7-T(&ES("(*(FEN
M9V5V;V5R9"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3$*;7-G
M:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B06%N;65L9&EN9R!M:7-L=6MT
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C4*;7-G:60@(DQO
M;F<@=&5X="(*;7-G<W1R("),86YG92!T96MS="(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R("),:65F9&4B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I
M9"`B3&]W(@IM<V=S='(@(DQA86<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G
M<F5E:R!L971T97)S(@IM<V=S='(@(D=R:65K<V4@:VQE:6YE(&QE='1E<G,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@
M(DQA=&EJ;G-E(&ML96EN92!L971T97)S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W
M97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(")+;&5I;F4@4F]M96EN<V4@9V5T
M86QL96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#4*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T
M<B`B3'5X96UB=7)G(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#,Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-
M32(*;7-G<W1R(")-32(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M.#,*;7-G:60@(DU/5$0B"FUS9W-T<B`B34]41"(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU43D5&($%T
M=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(DU3+51.148@
M8FEJ;&%G92!B979A='1E(&=E96X@9&%T82XB"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W
M"FUS9VED(")-4T<B"FUS9W-T<B`B35-'(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W"FUS9VED
M(")-86-A;R(*;7-G<W1R(")-86-A;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,PIM<V=I9"`B
M36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(DUA8V5D;VYIZRP@1&4@=G)O96=E<F4@2F]E9V]S;&%V:7-C:&4@
M4F5P=6)L:65K('9A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,0IM<V=I9"`B36%D86=A<V-A
M<B(*;7-G<W1R(")-861A9V%S8V%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0Y"FUS9VED(")-86=I8R(*;7-G<W1R(")-86=I92(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HX,PIM<V=I9"`B36%I;"(*;7-G<W1R(")%
M+6UA:6PB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(T"FUS9VED
M(")-86EL($%D;6EN(@IM<V=S='(@(DUA:6QB96AE97)D97(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*
M;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B36%A:R!L:6Y?:RXN+B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V-0IM<V=I9"`B36%L87=I(@IM<V=S='(@(DUA;&%W:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V-PIM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B36%L96ES
M:>LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C0*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(DUA
M;&%D:79E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-`IM<V=I9"`B36%L:2(*;7-G<W1R(")-
M86QI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38R"FUS9VED(")-86QT82(*;7-G<W1R(")-86QT
M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-`IM<V=I9"`B(@HB36%N
M86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@
M:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO
M<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@HB0F5H965R('5W(&QI:G-T(&UE
M="!C871E9V]R:67K;B!E;B!D92!C;W)R97-P;VYD97)E;F1E(&ML975R96XL
M('=A87)M964@(@HB;VYD97)D96QE;B!W;W)D96X@9V5L86)E;&0B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U-@IM<V=I
M9"`B36%P,C0@;6%P(@IM<V=S='(@(DUA<#(T(&MA87)T(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#<*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-S$*;7-G:60@(DUA
M<%%U97-T(&UA<"(*;7-G<W1R(")-87!1=65S=&MA87)T(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R
M960N(@IM<V=S='(@(DMO<'!E;&EN9V5N(&]P9V5S;&%G96XN(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-`HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA
M<F-H(@IM<V=S='(@(DUA87)T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN(@IM<V=S
M='(@(DUA<F=E(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.#@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP
M:'`Z-#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G
M<W1R(")-87)K965R(&UE="!'97II96XO3FEE="!'97II96X@=FQA9V=E;B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C0Y"FUS9VED
M(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E
M<F5D*2(*;7-G<W1R(")-87)K965R(&UE="!A;F1E<F4@=FQA9V=E;B`H8BYV
M+B!"96QA;F=R:6IK+T)E86YT=V]O<F0I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R"FUS9VED
M(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(DUA<F-H86QL(&5I;&%N9&5N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34Y"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(DUA
M<G1I;FEQ=64B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM
M<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(D]V97)E96YK;VUE;F1E
M('9E;&1E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,`IM<V=I9"`B36%U<FET86YI82(*;7-G
M<W1R(")-875R971A;FGK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S"FUS9VED(")-875R:71I
M=7,B"FUS9W-T<B`B36%U<FET:75S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E
M9"!C<F5D:70N(@IM<V=S='(@(DUA>&EM86%L('1O96=E<W1A86X@:W)E9&EE
M="XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*
M;7-G<W1R(")-87AI;75M(&)E<FEC:'1O;F1E<F1E;&5N(&]V97)S8VAR961E
M;BXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,PIM<V=I9"`B36%X('1E
M;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(DUA>&EM=6T@=&5M<&5R871U
M=7(@=F%N(&1E(&%F9V5L;W!E;B`R-"!U=7(Z("(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S`U"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*
M;7-G<W1R(")-87AI;75M('1E;7!E<F%T=75R('9A;B!D92!A9F=E;&]P96X@
M-B!U=7(Z("(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI;75M($YU
M;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(DUA>&EM=6T@86%N=&%L
M('!O<G1A86QB;&]K:V5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS
M9W-T<B`B36%X:6UU;2!L96YG=&4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(DUE:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-3,*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B36%Y;W1T
M92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I
M;F4B"FUS9W-T<B`B1V5N965S:W5N9&4B"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB97)S(@IM<V=S='(@(DQE
M9&5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,@IM<V=I9"`B365N
M=2!M;V1E.B(*;7-G<W1R(")-96YU(&UO9&4Z(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R
M9V4@8V5L;',B"FUS9W-T<B`B0V5L;&5N('-A;65N=F]E9V5N(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*
M;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B0F5R:6-H="(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E
M(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I
M9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@HB
M0F5R:6-H="!M970@<W5C8V5S(&=E=F5R:69I965R9"P@;6%A<B!H970@8V5R
M=&EF:6-A870@=F%N(&1E(&]N9&5R9V5T96ME;F1E("(*(FMO;B!N:65T('=O
M<F1E;B!G979E<FEF:65E<F0N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED(")-97-S86=E(&5X<&ER
M960N(@IM<V=S='(@(D)E<FEC:'0@=F5R;&]P96XN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P
M,@IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(D)E<FEC:'1T>7!E(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R
M(@IM<V=S='(@(DUE=&%R(%=E97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R
M(")-151!4B!B;&]K(&ES(&YI970@8F5S8VAI:V)A87(N(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(DU%5$%2(&)L;VL@:7,@;FEE="!B
M97-C:&EK8F%A<BX@1&5T86EL<R!Z:6IN(&=E;&]G9"!V;V]R(&1E('-Y<W1E
M96UB96AE97)D97(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$U,PIM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*;7-G<W1R
M(")-971A<D1"(&ES(&YI970@=F5R8F]N9&5N+B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@(DUE
M=&AO9&4B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<@9G)A
M;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(DUE
M=&AO9&4@7"(E<UPB(&ES(&YI970@9V5D969I;FEE97)D(@H*(SH@9G)A;65W
M;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<R(*;7-G<W1R
M(")-971H;V1E(&ES(&YI970@9V5D969I;FEE97)D+B!!86YG97)O97!E;B!M
M971H;V1E.B`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#(@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C8W"FUS9VED(")-971R:6,B"FUS9W-T
M<B`B365T<FES8V@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C8*;7-G:60@(DUE>&EC;R(*;7-G
M<W1R(")-97AI8V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-0IM<V=I9"`B36EC<F]N97-I82P@
M1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R(")-:6-R;VYE<VGK+"!&961E
M<F%L92!3=&%T96X@=F%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0R"FUS9VED(")-:61D;&4B"FUS9W-T<B`B
M36ED9&5N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP
M:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R(")-:6UE('1Y<&4B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-PIM<V=I9"`B36EN('1E;7`@;&%S
M="`R-"!H;W5R<SH@(@IM<V=S='(@(DUI;FEM=6T@=&5M<&5R871U=7(@=F%N
M(&1E(&%F9V5L;W!E;B`R-"!U=7(Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S`Y"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R
M(")-:6YI;75M('1E;7!E<F%T=75R('9A;B!D92!A9F=E;&]P96X@-B!U=7(Z
M("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED
M(")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM
M<V=S='(@(DUI;FEM=6T@=V%C:'1W;V]R9&QE969T:6ID(&ES(&YO9R!N:65T
M('9E<FQO<&5N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(S-0IM<V=I9"`B36ER<F]R(@IM<V=S='(@(DUI<G)O<B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U
M<R(*;7-G<W1R(")!;&QE<FAA;F1E(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%
M05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(D]N=&)R96ME;F1E
M(%!%05(@;6]D=6QE($A45%!?4F5Q=65S="XB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN
M(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U
M<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@HB3VYT8G)E:V5N
M9&4@8V]N9FEG=7)A=&EE+B!5(&1I96YT(&1E>F4@;G4@=&4@9V5N97)E<F5N
M+"!W86YN965R('4@9&5Z92`B"B)T;V5P87-S:6YG('=I;'0@9V5B<G5I:V5N
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R(")/
M;G1B<F5K96YD(&)E<FEC:'0@240N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@
M<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(D]N=&)R96ME
M;F1E+"!V97)E:7-T92P@4$5!4B!M;V1U;&4@36%I;"XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@
M(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B3VYT8G)E:V5N9"!S97-S
M:64@240N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B36$B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-S8*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@
M(DUO8FEE;&4@92UM86EL(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-S`*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(D=E;6ED
M9&5L9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C8@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"FUS9VED(")-
M;V1I9FEE9"!$871E(@IM<V=S='(@(E=I:GII9VEN9W-D871U;2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R(")7:6IZ:6<@55),(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S0*;7-G:60@(DUO
M9'5L=7,B"FUS9W-T<B`B36]D=6QU<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,`IM<V=I9"`B
M36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B36]L9&%V:>LL(%)E<'5B
M;&EE:R!V86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D*;7-G:60@(DUO;F%C;R(*;7-G<W1R
M(")-;VYA8V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38*;7-G:60@(DUO;F=O;&EA(@IM<V=S
M='(@(DUO;F=O;&GK(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4X
M-`IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B36%A;F0@96X@:F%A
M<B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z
M-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B36%A;F1E;&EJ:W,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C$*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B36]N='-E<G)A
M="(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H
M<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B36%A;F9A<V5N(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3DV(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E
M(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D
M+B(*;7-G<W1R(")-965R('9E;&1E;B!I;B!R96=E;"`E9"!G979O;F1E;BP@
M9&%N(&1E('9E<G=A8VAT=&4@)60N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X"FUS9VED(")-
M;W)O8V-O(@IM<V=S='(@(DUA<F]K:V\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM
M<V=S='(@(E9O;W)N86UE;&EJ:R!O;F)E=V]L:W0B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L
M;W5D>2(*;7-G<W1R(")6;V]R;F%M96QI:FL@8F5W;VQK="(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T
M;'D@0VQO=61Y(&%N9"!7:6YD>2(*;7-G<W1R(")6;V]R;F%M96QI:FL@8F5W
M;VQK="!E;B!W:6YD97)I9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B
M5F]O<FYA;65L:6IK('IO;FYI9R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z-C0X"FUS9VED(")-;W9E($1O=VXB"FUS
M9W-T<B`B3F%A<B!B96YE9&5N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HV-3(*;7-G:60@(DUO=F4@3&5F="(*;7-G
M<W1R(").86%R(&QI;FMS(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HV-38*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T
M<B`B3F%A<B!R96-H=',B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C8T-`IM<V=I9"`B36]V92!5<"(*;7-G<W1R(").
M86%R(&)O=F5N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4R-@IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(DYA87(@8F5N
M961E;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU,C4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C4R-@IM<V=I9"`B36]V92!U<"(*;7-G<W1R(").86%R(&)O=F5N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38X"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(DUO>F%M8FEQ
M=64B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@T"FUS9VED(")-
M=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B375L=&DM;&5V
M96P@9')O<"!D;W=N(&QI:G-T96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3`U.0IM<V=I9"`B375L=&EM87`@54L@;6%P
M(@IM<V=S='(@(DUU;'1I;6%P(%9+(&MA87)T(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(T,@IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM
M<V=S='(@(DUE97)V;W5D:6=E('-E;&5C=&EE(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0P,@IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R(")-
M:6IN(&%C8V]U;G0B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*;7-G
M:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B57<@86-C;W5N
M=&EN9F]R;6%T:64B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C0T
M"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B36EJ;B!P;W)T86%L(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C0R"FUS9VED(")->2!0;W)T86P@
M3&%Y;W5T(@IM<V=S='(@(DUI:FX@<&]R=&%A;&QA>6]U="(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U-0IM<V=I9"`B37EA;FUA<B(*;7-G<W1R(")":7)M82(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").
M3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B3F5E+"!I:R!A8V-E<'1E97(@
M9&4@=F]O<G=A87)D96X@3DE%5"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1N968N<&AP.C,X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ,#(@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#$Q"FUS9VED(").86UE(@IM<V=S='(@(DYA86TB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-CD*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B3F%M:6)IZR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W.`IM<V=I9"`B3F%U<G4B"FUS9W-T<B`B3F%U<G4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S<*;7-G:60@(DYE<&%L(@IM<V=S='(@(DYE<&%L(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U
M"FUS9VED(").971H97)L86YD<R(*;7-G<W1R(").961E<FQA;F0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B
M3F5D97)L86YD<R!!;G1I;&QE;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G
M<W1R(").971S8V%P92!"87-I<R!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A
M=&EO;B!54DPB"FUS9W-T<B`B3F5T<V-A<&4@0T$@:6YT<F5K:VEN9R!54DPB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I
M9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R(").971S8V%P92!#
M02!B96QE:60@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#4*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@
M(DYE='-C87!E('9E<FYI975W:6YG(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!2979O8V%T
M:6]N(%523"(*;7-G<W1R(").971S8V%P92!I;G1R96MK:6YG(%523"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").
M971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B3F5T<V-A<&4@4U-,
M('-E<G9E<FYA86TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X.`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*
M;7-G<W1R(").971S8V%P92!C97)T:69I8V%A=&-O;6UE;G1A87(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T
M<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R(").971S8V%P92!C97)T
M:69I8V%A='1Y<&4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4S
M"FUS9VED(").971W;W)K(@IM<V=S='(@(DYE='=E<FLB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,S.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(").
M979E<B(*;7-G<W1R(").;V]I="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,`IM<V=I9"`B3F5W
M($-A;&5D;VYI82(*;7-G<W1R(").:65U=R!#86QE9&]N:>LB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I
M9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(DYI975W92!C871E9V]R:64B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X
M(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S
M='(@(DYI975W92!M86%N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS
M9W-T<B`B3FEE=7=E(&=E8G)U:6ME<G-N86%M("AO<'1I;VYE96PI(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@P"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R(").:65U=R!:
M965L86YD(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W"FUS
M9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`B3FEE=7<@=V%C:'1W;V]R9"(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*
M;7-G<W1R(").:65U=R!W86-H='=O;W)D('IA;"!V97)L;W!E;B!O<"`E>"XB
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@(DYE
M=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(DYI975W92!786-H
M='=O;W)D96X@:V]M96X@;FEE="!O=F5R965N+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD
M;W<@*%]B;&%N:RDB"FUS9W-T<B`B3FEE=7<@<V-H97)M("A?8FQA;FLI(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C0P"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.3$*;7-G:60@
M(DYE=W,B"FUS9W-T<B`B3FEE=7=S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,P-PIM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R(").:65U=W-G
M<F]E<&5N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z-#$@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34*
M;7-G:60@(DYE>'0B"FUS9W-T<B`B5F]L9V5N9&4B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B5F]L
M9V5N9&4@-"!F87-E;B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,S8V(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<P"FUS9VED
M(").97AT(&]P=&EO;G,B"FUS9W-T<B`B5F]L9V5N9&4@;W!T:65S(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#,*;7-G:60@(DYE>'0^(@IM
M<V=S='(@(E9O;&=E;F1E/B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-`IM<V=I9"`B3FEC87)A
M9W5A(@IM<V=S='(@(DYI8V%R86=U82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,0IM<V=I9"`B
M3FEG97(B"FUS9W-T<B`B3FEG97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S,*;7-G:60@(DYI
M9V5R:6$B"FUS9W-T<B`B3FEG97)I82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS-CD*;7-G:60@(DYI9VAT(@IM<V=S='(@(DYA8VAT(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<Y"FUS9VED(").:75E(@IM<V=S='(@(DYI=64B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38V"FUS9VED
M(").;R(*;7-G<W1R(").964B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O
M9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N
M(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(D=E96X@
M8F5S8VAI:V)A<F4@8V]N9FEG=7)A=&EE9&%T82!O;2!V97)S8VAI;&QE;B!T
M92!L871E;B!Z:65N+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<BYP:'`Z,3`V"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@
M9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R(")'965N(&)E<V-H:6MB
M87)E('-T<F%T96=I92!V;V]R(&AE="!M86ME;B!V86X@25-/(&EM86=E<RXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R(")'965N
M(&)A=&-H<VIA8FQO;VXN(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HQ,#$*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HS.#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT,#<*;7-G:60@(DYO(&)L;V-K(&5X
M:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(D5R(&)E
M<W1A870@9V5E;B!B;&]K(&]P(&1E(&=E=G)A86=D92!P;W-I=&EE(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@8V%L
M96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B1V5E;B!A9V5N9&%N86%M(&]P9V5G979E;B!V;V]R($U#04P@
M875T:&5N=&EC871I92XB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`IM
M<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R(")'965N('=I:GII9VEN9V5N+B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(").
M;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*
M;7-G<W1R(")!86X@9&ET(')E8VAT(&MU;FYE;B!G965N(&-H:6QD(')E8VAT
M96X@=V]R9&5N('1O96=E=F]E9V0N(@H*(SH@9G)A;65W;W)K+U5T:6PO571I
M;"YP:'`Z-S8X(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<X"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$W"B,L('!H<"UF;W)M870*;7-G
M:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B`E<RXB"FUS9W-T<B`B1V5E;B!C;VYF:6=U<F%T:65I;F9O<FUA=&EE(&]P
M9V5G979E;B!V;V]R("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.#4U"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B1V5E;B!C;VYF:6=U<F%T
M:65I;F9O<FUA=&EE(&]P9V5G979E;B!V;V]R($944"!61E,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-S(*;7-G:60@(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G
M<W1R(")'965N(&-O;F9I9W5R871I96EN9F]R;6%T:64@;W!G96=E=F5N('9O
M;W(@4U%,(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z-S(U"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R(")'965N(&-O;F9I
M9W5R871I96EN9F]R;6%T:64@;W!G96=E=F5N('9O;W(@4U%,+6)E<W1A;F0@
M5D93+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(D=E
M96X@:W)E9&EE="!M965R+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S
M=7!P;&EE9"XB"FUS9W-T<B`B1V5E;B!B97-T96UM:6YG(&]P9V5G979E;BXB
M"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,C`*;7-G:60@
M(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B1V5E;B!B97-T86YD('5P;&]A
M9&5D(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I
M8V]N<R!F;W5N9"XB"FUS9W-T<B`B1V5E;B!P:6-T;V=R86UM96X@9V5V;VYD
M96XN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,S`@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M,38*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B17(@:7,@
M9V5E;B!L;V-A=&EE(&EN9V5S=&5L9"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,34W"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB
M"FUS9W-T<B`B1V5E;B!L;V-A=&EE(&]P9V5G979E;BXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B
M3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B1V5E;B!B97)I8VAT(&=E
M;&5V97)D+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T
M<B`B1V5E;B!N86%M(&]P9V5G979E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R
M('-P96-I9FEE9"XB"FUS9W-T<B`B1V5E;B!G971A;"!O<&=E9V5V96XN(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED(").;R!O9F9E;G-I
M=F4@9F]R='5N97,B"FUS9W-T<B`B1V5E;B!B96QE9&EG96YD92!F;W)T=6YE
M<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@
M(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R(")'965N('=A8VAT=V]O<F0@;W!G96=E=F5N('9O;W(@2%14
M4"!A=71H96YT:6-A=&EE+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA
M<"YP:'`Z,3`X"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!
M4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B1V5E;B!W86-H='=O;W)D(&]P
M9V5G979E;B!V;V]R($E-05`@875T:&5N=&EC871I92XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VMR8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(D=E96X@=V%C:'1W;V]R9"!O<&=E9V5V96X@=F%N($ME<F)E<F]S(&%U=&AE
M;G1I8V%T:64N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L;V=I;BYP:'`Z
M.#0@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<U"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B1V5E
M;B!W86-H='=O;W)D(&]P9V5G979E;B!V;V]R($QO9VEN(&%U=&AE;G1I8V%T
M:64N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P87-S=V0N<&AP.C$S-0IM
M<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B1V5E;B!W86-H='=O;W)D(&]P9V5G979E;B!V
M;V]R(%!!4U-71"!A=71H96YT:6-A=&EE+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B1V5E;B!W86-H='=O
M;W)D(&]P9V5G979E;B!V;V]R(%--0B!A=71H96YT:6-A=&EE+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-PIM<V=I9"`B(@HB
M3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/
M<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+
M0U,@,3(@9&%T82XB"FUS9W-T<B`B(@HB1V5E;B!P860@;F%A<B!D92!/<&5N
M4U-,(&)I;F%R>2!O<&=E9V5V96XN($1E($]P96Y34TP@8FEN87)Y(&ES(&YO
M9&EG(&]M('1E("(*(FMU;FYE;B!W97)K96X@;65T(%!+0U,@,3(@9&%T82XB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED
M(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@(D=E96X@:&%N9V5N9&4@
M:6YS8VAR:6IV:6YG96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C<V
M-@IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R(")'965N('%U;W1A(&EN
M9V5S=&5L9"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*;7-G<W1R(")'965N
M(&QI;FGK<FEN9R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0X
M,@IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B1V5E
M;B!S8VAE:61I;F=S=&5K96X@;W!G96=E=F5N+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*;7-G:60@(DYO
M('-I9&5S(@IM<V=S='(@(D=E96X@>FEJ9&5N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HU.#<*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R
M(")'965N(&1E<F=E;&EJ:R!B97-T86YD(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$R-@IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R
M>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R(")'965N('1I:F1E;&EJ
M:R!D:7)E8W1O<GD@8F5S8VAI:V)A87(@=F]O<B!C86-H92XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,0IM<V=I9"`B
M3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(D=E
M96X@9V5B<G5I:V5R<VYA86T@96XO;V8@=V%C:'1W;V]R9"!V97)Z;VYD96XN
M(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@
M(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(D=E96X@9V5L
M9&EG92!834P@9&%T82!T97)U9V=E<W1U=7)D(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW-`HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY.34*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,3(*;7-G:60@(DYO('9A;'5E<R(*
M;7-G<W1R(")'965N('=A87)D96XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O
M;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B(@HB1V5E;B!V97)S:64@9V5V;VYD96X@:6X@;W)I9VEN96QE(&-O;F9I
M9W5R871I92X@2&5R9V5N97)E97(@8V]N9FEG=7)A=&EE+B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@
M:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(D=E96X@=F5R<VEE(&=E=F]N9&5N(&EN('5W(&-O;F9I
M9W5R871I92X@2&5R9V5N97)E97(@8V]N9FEG=7)A=&EE+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-R!T96UP;&%T97,O<')E9G,O
M:61E;G1I='ES96QE8W0N:6YC.CDS"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*;7-G:60@(DYO;F4B"FUS9W-T
M<B`B1V5E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B
M1V5E;B`H=F5R<&QI8VAT*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR
M"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R(").;V]R9"!%
M=7)O<&5E<R`H25-/+3@X-3DM,3`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R"FUS9VED(").
M;W)F;VQK($ES;&%N9"(*;7-G<W1R(").;W)F;VQK(&5I;&%N9"(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G
M:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B3F]O<F1E;&EJ:R!H
M86QF<F]N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.`IM<V=I9"`B3F]R=&AE<FX@36%R:6%N
M82!)<VQA;F1S(@IM<V=S='(@(DUA<FEA;F5N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V"FUS
M9VED(").;W)W87DB"FUS9W-T<B`B3F]O<G=E9V5N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#$*;7-G:60@(DYO="!!9G1E<B(*
M;7-G<W1R(").:65T(&YA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B3FEE="!V
M;V]R(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$U"FUS9VED
M(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B1V5E;B!D:7)E8W1O<GDB"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2YP:'`Z-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU.0HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H
M<#HX-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+G!H<#HY-0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D
M+B(*;7-G<W1R(").:65T(&=E:6UP;&5M96YT965R9"XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X"FUS9VED(").;W0@
M<V5T(@IM<V=S='(@(DYI970@:6YG97-T96QD(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C$Y,R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`X"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(U,@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8Y(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR.#4*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,P,2!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$V"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HS,S,@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V-@HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z-#(V(&9R86UE=V]R:R]61E,O5D93+G!H<#HU,#4*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W-"!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-3DQ"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HV-CD@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#4*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ
M-C`*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R
M+G!H<#HQ-S4*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(
M86YD;&5R+G!H<#HQ.#D*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E
M<W-I;VY(86YD;&5R+G!H<#HR,S8*;7-G:60@(DYO="!S=7!P;W)T960N(@IM
M<V=S='(@(DYI970@;VYD97)S=&5U;F0N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDP.`HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`U."!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@P"FUS9VED(").;W1E<R(*;7-G<W1R
M(").;W1I=&EE<R(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS
M-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@
M(DYI971S('1E(&)L861E<F5N+"!G82!T97)U9RXB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B
M"FUS9W-T<B`B3F]V96UB97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,#0V"FUS9VED(").=6UB97(B"FUS9W-T<B`B1V5T86PB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U"FUS9VED(").=6UB97(@;V8@8VAA
M<F%C=&5R<R(*;7-G<W1R(")!86YT86P@:V%R86MT97)S(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#(S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#4@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU
M;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(D%A;G1A;"!K;VQO;6UE;B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C<@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0S
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS
M9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R(")!86YT86P@<FEJ96XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T
M-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I
M;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B1V5T86QL96X@;FEE="!O
M<&=E9V5V96X@=F]O<B!B:6IW97)K96X@:6X@965N(&1I<W1R:6)U=&EE;&EJ
M<W0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C8T"FUS9VED(")/2R(*;7-G<W1R(")/2R(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B:F5C="(*;7-G
M<W1R(")/8FIE8W0B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q
M,0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`B3V)J96-T96EG96YA
M87(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T"FUS9VED(")/
M8W1A;"(*;7-G<W1R(")/8W1A86PB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R(")/
M:W1O8F5R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/
M9F9E;G-E(&9I;'1E<B(*;7-G<W1R(")"96QE9&EG:6YG9FEL=&5R(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R.`IM<V=I9"`B3V9F:6-E(@IM
M<V=S='(@(DMA;G1O;W(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I
M9F9E<F5N="XB"FUS9W-T<B`B3W5D92!E;B!N:65U=V4@=V%C:'1W;V]R9&5N
M(&1I96YE;B!V97)S8VAI;&QE;F0@=&4@>FEJ;BXB"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z,S8*;7-G:60@(D]L9"!P87-S=V]R9"(*;7-G
M<W1R(")/=61E('=A8VAT=V]O<F0B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C
M="XB"FUS9W-T<B`B3W5D92!W86-H='=O;W)D(&ES(&YI970@:G5I<W0B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#$*;7-G:60@(D]M86XB"FUS9W-T<B`B3VUA;B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/
M;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G
M<W1R(")!;&QE96X@24U!4"!S97)V97)S(&]N9&5R<W1E=6YE;B!G961E96QD
M92!M87!P96XN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED
M(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(")!;&QE96X@8F5L
M961I9V5N9&4@9F]R='5N97,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#4Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S$*;7-G:60@(D]N
M;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B4VQE8VAT
M(.GI;B!E+6UA:6QA9')E<R!T;V5G97-T86%N+B(*"B,Z('-E<G9I8V5S+W-H
M87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@
M;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HB
M06QL965N(&1E(&5I9V5N86%R(&]F(&5E;B!S>7-T965M8F5H965R9&5R(&UA
M9R!D92!E:6=E;F%A<G)E8VAT96X@=F%N(&5E;B`B"B)S:&%R92!W:6IZ:6=E
M;B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C0Q(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C0R"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R
M(")/<&5N(&EN(&5E;B!N:65U=R!S8VAE<FTB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@
M0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R
M="XB"FUS9W-T<B`B(@HB3W!E;E-33"!F;W5T.B!K;VX@9V5E;B!D871A('5I
M="!H970@;VYD97)T96ME;F1E(%,O34E-12!O;F1E<F1E96P@:&%L96XN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W
M(@IM<V=S='(@(D]P96YT(&1E>F4@;&EN:R!I;B!E96X@;FEE=7<@<V-H97)M
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I
M;F<@4WES=&5M(@IM<V=S='(@(D)E<W1U<FEN9W-S>71E96TB"@HC.B!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM
M<V=S='(@(D]P=&EE<R(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP
M;&%T97,O<')E9G,O87!P+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED(")/
M<'1I;VYS(&9O<B`E<R(*;7-G<W1R(")/<'1I97,@=F]O<B`E<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@
M(D]R9&5R960@3&ES="(*;7-G<W1R(")'96]R9&5N9&4@;&EJ<W0B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G
M86YI<V%T:6]N(@IM<V=S='(@(D]R9V%N:7-T871I92(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")/<F=A;FES871I
M;VYA;"!5;FET(@IM<V=S='(@(D]R9V%N:7-A=&EE(&5E;FAE:60B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,T"FUS9VED(")/<F=A;FEZ:6YG
M(@IM<V=S='(@(D]R9V%N:7-E<F5N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM
M<V=S='(@(D]R:6=I;F5E;"!T;V5P87-S:6YG<W-J86)L;V]N(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I
M9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R(")/<FEG:6YE;&4@<VIA
M8FQO;F5N(&EN("5S.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*
M;7-G<W1R(")!;F1E<F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3D@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.0HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C4*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$S-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30T
M"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R(")!;F1E<F4@:6YF
M;W)M871I92(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G
M:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(D5I9V5N86%R<F5C:'1E
M;B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B
M4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(E!!32!A=71H96YT:6-A=&EE(&ES(&YI970@8F5S8VAI:V)A87(N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS
M9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS9W-T<B`B4$5!4CHZ36%I;"!B
M86-K96YD(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(W
M-@IM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(D1I9VET
M86QE(%!'4"!H86YD=&5K96YI;F<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,S(R"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS
M9W-T<B`B1V5C;V1E97)D92!01U`@9&%T82(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$S-S0*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM
M<V=S='(@(D]P96YB87)E(%!'4"!S;&5U=&5L(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3,U-@IM<V=I9"`B4$=0(%-I9VYE9"]%;F-R
M>7!T960@1&%T82(*;7-G<W1R(")/;F1E<G1E:V5N9&4O9V5C;V1E97)D92!0
M1U`@9&%T82(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.0IM<V=I9"`B4$A0
M($-O9&4B"FUS9W-T<B`B4$A0(&-O9&4B"@HC.B!A9&UI;B]P:'!S:&5L;"YP
M:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R(")02%`@<VAE;&PB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I
M9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R("),:6-H=&4@<F5G96X@;F$@,3(N
M,#`@=75R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,SD*;7-G:60@(E!-(%)A:6XB"FUS9W-T<B`B4F5G96X@;F$@,3(N,#`@
M=75R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#`*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B0G5I96X@;F$@,3(N,#`@
M=75R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#$*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B4VYE975W(&YA(#$R+C`P('5U
M<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R
M"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B4VYE975W8G5I96X@
M;F$@,3(N,#`@=75R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#,*;7-G:60@(E!-(%-U;B(*;7-G<W1R("):;VX@;F$@,3(N
M,#`@=75R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#0*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(D]N=V5E<G-B=6EE
M;B!N82`Q,BXP,"!U=7(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@V
M"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R(")0
M3U-)6"!E>'1E;G-I92!O;G1B<F5E:W0B"@HC.B!L:6(O87!I+G!H<#HQ-#D*
M;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B4$A0(%]3:&5L;"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*
M;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B5G)I:F4@<G5I;71E(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@W"FUS9VED(")086MI<W1A;B(*;7-G<W1R(")086MI<W1A;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.30*;7-G:60@(E!A;&%U(@IM<V=S='(@(E!A;&%U(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y,@IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U
M<&EE9"(*;7-G<W1R(")086QE<W1I:FYS(%1E<G)I=&]R:75M+"!"97IE="(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X,@IM<V=I9"`B4&%N86UA(@IM<V=S='(@(E!A;F%M82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X-0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R
M(")087!U82!.:65U=R!'=6EN96$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU"FUS9VED(")0
M87)A9W5A>2(*;7-G<W1R(")087)A9W5A>2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")087)T;'D@0VQO=61Y
M(@IM<V=S='(@(D=E9&5E;'1E;&EJ:R!B97=O;&MT(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q.`HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C<W('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R-0IM<V=I9"`B4&%S<W=O
M<F0B"FUS9W-T<B`B5V%C:'1W;V]R9"(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S
M9G5L;'DN(@IM<V=S='(@(E=A8VAT=V]O<F0@;65T('-U8V-E<R!G97=I:GII
M9V0N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(S
M"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B5V%C:'1W;V]R
M9"!O;FIU:7-T(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP
M.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B5V%C:'1W;V]R9"!I<R!V97)E:7-T('9O
M;W(@4D%$2553(&%U=&AE;G1I8V%T:64N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`U,PIM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I
M;VXB"FUS9W-T<B`B5V%C:'1W;V]R9"!M970@8F5V97-T:6=I;F<B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D
M.B(*;7-G<W1R(")786-H='=O;W)D.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M
M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(E=A8VAT
M=V]O<F0Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R
M(")786-H='=O;W)D96X@;6]E=&5N(&]V97)E96YK;VUE;BXB"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3(P('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B
M4&QA:VME;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@
M(E!L86MK96X@=F%N868@<')I:V)O<F0B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@
M(E!A9"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW"FUS9VED
M(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(DAA;F=E;F1E(&EN<V-H<FEJ
M=FEN9V5N.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B
M4&5O<&QE(@IM<V=S='(@(DUE;G-E;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S
M='(@(E!R;V-E;G0B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R
M871I;VYS(@IM<V=S='(@(D]N9&5R:&]U9'-W97)K>F%A;6AE9&5N('5I='9O
M97)E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,3`*;7-G:60@(E!E
M<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T
M<B`B3VYD97)H;W5D<W=E<FMZ86%M:&5D96X@=6ET=F]E<F5N(&)I:B!A86YM
M96QD:6YG/R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V
M"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(E)E8VAT(@H*(SH@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")097)M
M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B4F5C:'0@7"(E
M<UPB(&YI970@=F5R=VEJ9&5R9"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C4Y,`IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B
M4F5C:'0@9V5W96EG97)D(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ-C$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*;7-G
M:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(E)E8VAT96XB"@HC.B!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z-C`@861M:6XO<&5R;7,O9&5L971E+G!H<#HU
M.`HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O:6YD
M97@N<&AP.C(R"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*
M;7-G<W1R(")296-H=&5N8F5H965R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8X"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R(")0
M97)S;V]N;&EJ:V4@:6YF;W)M871I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,PIM<V=I9"`B
M4&5R=2(*;7-G<W1R(")097)U(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4U"FUS9VED(")0971S(@IM<V=S='(@(DAU:7-D:65R96XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#8*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(E!H:6QI<'!I:FYE
M;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(E1E;&5F;V]N(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0X,`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@
M(D9O=&\G<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`*;7-G:60@(E!I=&-A:7)N(@IM<V=S
M='(@(E!I=&-A:7)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R(")0:7AE;',B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D
M97,B"FUS9W-T<B`B4&QA=&ET=61E<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C
M;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R(")+;&EK(&EN(&5E;B!C96PL
M(&$N=2YB+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R(")"979E
M<W1I9RP@9&%T('4@9&ET(&5L96UE;G0@=VEL="!V97)W:6ID97)E;BP@82YU
M+F(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W
M86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(D)E=F5S=&EG
M+"!D870@=2!D:70@96QE;65N="!W:6QT(&QO<VMO<'!E;&5N+"!A+G4N8BXB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-38R"FUS9VED(")0;&5A
M<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R(")'965F(&5E
M;B!M86%N9"!E;B!E96X@:F%A<BP@82YU+F(N(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E
M;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(D5E
M;B!N86%M('9O;W(@9&4@;FEE=7=E(&-A=&5G;W)I92!I;G9O97)E;BP@82YU
M+F(N.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#$*;7-G:60@
M(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(D=E
M968@965N(&=E;&1I9R!)4"!A9')E<RP@82YU+F(N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C8T,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L
M:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT
M:"XB"FUS9W-T<B`B(@HB1V5E9B!E96X@9V5L9&EG92!D871U;2!A+G4N8BXL
M(&-O;G1R;VQE97(@:&5T(&%A;G1A;"!D86=E;B!I;B!D92!M86%N9"XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#0W"FUS9VED(")0;&5A<V4@
M96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R(")'965F(&5E;B!G96QD:6=E
M('1I:F0L(&$N=2YB+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@
M<')O8FQE;2XB"FUS9W-T<B`B1V5E9B!E96X@<V%M96YV871T:6YG('9A;B!H
M970@<')O8FQE96TL(&$N=2YB+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B
M4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS
M9W-T<B`B1V5E9B!U=R!G96)R=6EK97)S;F%A;2!E;B!W86-H='=O;W)D+"!A
M+G4N8BXB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@
M(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@
M86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM
M<V=S='(@(B(*(DQE97,@9&4@=F]L9V5N9&4@=&5K<W0L(&$N=2YB+B!5($U/
M150@9&4@=F]O<G=A87)D96X@=&4@86-C97!T97)E;B!O;2!H970@(@HB<WES
M=&5E;2!T92!K=6YN96X@9V5B<G5I:V5N+B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@
M='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(D=E968@9&4@
M;FEE=7=E(&-A=&5G;W)I96YA86TL(&$N=2YB+CHB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#@*
M;7-G:60@(E!O;&%N9"(*;7-G<W1R(")0;VQE;B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B4&]L:71I
M96LB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@Y"FUS9VED(")0
M;VQL<R(*;7-G<W1R(")096EL:6YG96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DS"FUS9VED
M(")0;W)T=6=A;"(*;7-G<W1R(")0;W)T=6=A;"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`IM<V=I
M9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R(")0;W-I=&EO
M;F5R:6YG('9A;B!D97IE(&%F8F5E;&1I;F<B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI
M;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R(")0;W-I=&EO;F5R:6YG('9A;B!D
M97IE('1A8F5L(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.3$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP
M:'`Z-3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E
M9"!B>2!)34%0*2(*;7-G<W1R(")3='5U<B!N86%R(&1E>F4@;6%P("AN:65T
M(&%F9V5D=V]N9V5N(&1O;W(@24U!4"DB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(W,R!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*
M;7-G<W1R(").965R<VQA9R!V86X@9&4@869G96QO<&5N("5S('5R96XZ("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#<*;7-G:60@(E!R
M96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B3F5E<G-L86<\8G(@
M+SYK86YS(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP.CDX
M"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7VQD87`Z('9E<F5I<W1E($Q$05`@
M97AT96YT:64@;FEE="!G979O;F1E;BXB"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E
M<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M4')E9G-?<V5S<VEO;CH@=F5R96ES=&4@<V5S<VEE(&5X=&5N=&EE(&YI970@
M9V5V;VYD96XN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S(*;7-G:60@
M(E!R97-S=7)E(@IM<V=S='(@(DQU8VAT9')U:R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C8V"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*
M;7-G<W1R("),=6-H=&1R=6L@;W`@>F5E;FEV96%U.B`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(T"FUS9VED(")0<F5S<W5R93H@(@IM
M<V=S='(@(DQU8VAT9')U:SH@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(P,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*;7-G:60@(E!R979I97<B
M"FUS9W-T<B`B0F5O;W)D96QE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0IM<V=I9"`B4')E=FEE
M=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D)E;V]R9&5E
M;"!D92!A9F)E96QD:6YG(&EN(&5E;B!N:65U=R!S8VAE<FTB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,U-B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C,V,`IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G
M<W1R(")6;W)I9V4@;W!T:65S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS
M9W-T<B`B1&]C=6UE;G0@869D<G5K:V5N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R
M(")0<FEV92!S;&5U=&5L(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE
M;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R(")0<F]B;&5E;2(*
M"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-PIM<V=I9"`B4')O8FQE;2!$
M97-C<FEP=&EO;B(*;7-G<W1R(")0<F]B;&5E;6)E<V-H<FEJ=FEN9R(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S$*;7-G:60@(E!R;VIE8W1S
M(@IM<V=S='(@(E!R;VIE8W1E;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X.`HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<V"FUS9VED(")0<F]M<'0@=&5X="(*
M;7-G<W1R(")0<F]M<'0@=&5K<W0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B3W!E
M;F)A<F4@<VQE=71E;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C0V"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R
M(")/<&5N8F%R92!S;&5U=&5L(&%L9V]R:71H;64B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!)
M;F9O(@IM<V=S='(@(D]P96YB87)E('-L975T96QI;F9O<FUA=&EE(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L
M:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY
M+B(*;7-G<W1R(")/<&5N8F%A<B]0<FEV92!S;&5U=&5L<&%A<B!N:65T(&=E
M9V5N97)E97)D+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$*;7-G:60@(E!U97)T;R!2:6-O
M(@IM<V=S='(@(E!U97)T;R!2:6-O(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-34*;7-G:60@(E!U<F=E(&UE<W-A9V5S(@IM
M<V=S='(@(E=I<R!B97)I8VAT96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DV"FUS9VED(")1
M871A<B(*;7-G<W1R(")1=6%T87(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M-C0*;7-G:60@(E%U97)Y(@IM<V=S='(@(E%U97)Y(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C@P"FUS9VED(")1=6]T82(*;7-G<W1R(")1=6]T82(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8T"B,L('!H
M<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S
M='(@(E)302!O<&5N8F%R92!S;&5U=&5L("@E9"!B:70I(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-`IM<V=I9"`B4F%D:6\@<V5L96-T:6]N
M(@IM<V=S='(@(DME=7IE<F]N9&IE('-E;&5C=&EE(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6XB"FUS
M9W-T<B`B4F5G96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R(")6<F]E9R!R
M96=E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0W"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`B3&%A="!R96=E;B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED
M(")286EN(%-H;W=E<B(*;7-G<W1R(")296=E;F)U:2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")286EN(&%N
M9"!3;F]W(@IM<V=S='(@(E)E9V5N(&5N('-N965U=R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"FUS9VED(")286EN('1O
M(%-N;W<B"FUS9W-T<B`B4F5G96X@;F%A<B!S;F5E=7<B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T
M<B`B4F%N9&]M($9O<G1U;F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(E9E<FAO=61I;F<B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B
M4F5A9"(*;7-G<W1R("),97IE;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C@W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S0S,30N<&AP.C0W"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@
M(DQE97,@8F5R:6-H=&5N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@
M)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@
M(B5S(&5C:'0@=F5R=VEJ9&5R96X_($1E>F4@8F5W97)K:6YG(&MA;B!N:65T
M(&]N9V5D86%N(&=E;6%A:W0@=V]R9&5N+B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL
M>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO
M;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"B)'96)R=6EK97)S9&%T
M82!V86X@9V5B<G5I:V5R("5S(&5C:'0@=F5R=VEJ9&5R96X_($1E>F4@8F5W
M97)K:6YG(&MA;B!N:65T("(*(F]N9V5D86%N(&=E;6%A:W0@=V]R9&5N+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*
M;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(DAE<FAA
M86QT('5W('9O<FEG92!B97=E<FMI;F<B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F
M<F5S:"(*;7-G<W1R(")697)V97)S96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,SDU"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT
M<SHB"FUS9W-T<B`B5F5R=F5R<R!D>6YA;6ES8VAE(&UE;G4@;VYD97)D96QE
M;CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0U"FUS9VED(")2969R
M97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R(")0;W)T86QW965R9V%V92!V97)V
M97)S96XZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(S-0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B4F5G97@B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,Q"FUS9VED(")296QA=&EO;G-H
M:7`@0G)O=W-E<B(*;7-G<W1R(")"971R96MK:6YG96X@8G)O=W-E<B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR,#@*;7-G:60@(E)E;&]A9"(*;7-G<W1R(")(97)L
M861E;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,S"FUS9VED(")296UA
M<FMS(@IM<V=S='(@(D]P;65R:VEN9V5N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q-PIM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B4V5R
M=F5R<R!O<"!A9G-T86YD(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*3HB"FUS9W-T<B`B55),(&]P(&%F<W1A;F0@*&AT='`Z+R]W
M=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V97%U975E9"YI;F,Z,3,@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHR,@IM<V=I9"`B4F5M;W9E(@IM<V=S='(@(E9E<G=I:F1E<F5N(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO
M=F4@0FQO8VLB"FUS9W-T<B`B0FQO:R!V97)W:6ID97)E;B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-3D*;7-G:60@(E)E
M;6]V92!C;VQU;6XB"FUS9W-T<B`B2V]L;VT@=F5R=VEJ9&5R96XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0P"FUS9VED
M(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R(")/<&UA86L@=F5R=VEJ9&5R
M96XB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B
M4F5M;W9E('!A:7(B"FUS9W-T<B`B4&%A<B!V97)W:6ID97)E;B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S879E9"!S
M8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G
M<W1R("(B"B)697)W:6ID97(@:&5T(&]P9V5S;&%G96X@<V-R:7!T('5I="!D
M92!T:6ID96QI:FME(&1I<F5C=&]R>2!O<"!D92!S97)V97(N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R
M"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(E9E<G=I:F1E<B!D92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N
M="(*;7-G<W1R(")697)W:6ID97(@9&5Z92!N;V1E('5I="!H970@9&]C=6UE
M;G0B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q"FUS
M9VED(")296UO=F4@=7-E<B(*;7-G<W1R(")'96)R=6EK97(@=F5R=VEJ9&5R
M96XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(E9E
M<G=I:F1E<B!G96)R=6EK97(Z("5S(@H*(SH@9G)A;65W;W)K+U)00R]24$,O
M>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS
M=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(E9E<GIO96L@
M:V]N(&YI970@=V]R9&5N(&)E86YT=V]O<F0N($=E<F5T;W5R;F5E<F1E(&9O
M=71C;V1E.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30U
M"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N
M(@IM<V=S='(@(D1E(&=E=G)A86=D92!S97)V:6-E(&MO;B!N:65T('=O<F1E
M;B!G979O;F1E;BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$X
M-2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4R-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")697)E:7-T92!<(B5S7"(@;FEE="!O
M<&=E9V5V96X@:6X@)7,@8V]N9FEG=7)A=&EE+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z.#8Q(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M-C<X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,S$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I
M960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E9E<F5I<W1E(%PB
M)7-<(B!N:65T(&]P9V5G979E;B!I;B!61E,@8V]N9FEG=7)A=&EE+B(*"B,Z
M(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<W-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R(")697)E:7-T92!<(B5S7"(@;FEE="!O<&=E9V5V
M96X@:6X@8V]N9FEG=7)A=&EE+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO
M4F5N9&5R97(N<&AP.C,S-@IM<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T
M<B`B5F5R96ES="!V96QD(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,SD@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD
M97)E<BYP:'`Z,S(Q"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ
M,#`@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B
M4F5S970B"FUS9W-T<B`B2&5R<W1E;&QE;B(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R
M(")297-E="!W86-H='=O;W)D(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z,C<*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B
M4F5S970@=7<@=V%C:'1W;V]R9"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,S$*;7-G:60@(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G<W1R(")6;V]R9V%A
M;F1E('%U97)Y(&AE<G-T96QL96XB"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z
M,CD@861M:6XO<&AP<VAE;&PN<&AP.C<R(&%D;6EN+W-Q;'-H96QL+G!H<#HV
M-PIM<V=I9"`B4F5S=6QT<R(*;7-G<W1R(")297-U;'1A=&5N(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O
M96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")4
M97)U9R!N86%R(&]P=&EE<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R(")4
M>7`@;FEE=7<@=V%C:'1W;V]R9"!O<&YI975W(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-PIM
M<V=I9"`B4F5U;FEO;B(*;7-G<W1R(")2975N:6]N(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS
M9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")#;VYF:6=U<F%T
M:64@=&5R=6=Z971T96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U
M"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B4FEC
M:"!497AT($5D:71O<B!O<'1I97,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B4F%A9'-E;',B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*
M;7-G:60@(E)I9VAT(@IM<V=S='(@(E)E8VAT<R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,#,*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R
M(")296-H='-E(&MO<"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,P
M.3D*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R(")296-H='-E('=A87)D
M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R
M(")2:5]J96EG96YS8VAA<'!E;BXN+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B
M4F]L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y.`IM<V=I9"`B4F]M86YI82(*;7-G<W1R(")2
M;V5M96YIZR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,C8*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B,3@P(&1R86%I
M96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C(S"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R(").86%R(&QI;FMS(&1R
M86%I96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C(Y"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B3F%A<B!R96-H
M=',@9')A86EE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S
M='(@(E)I:B!E:6=E;G-C:&%P<&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E
M<G1I97,B"FUS9W-T<B`B4FEJ(&5I9V5N<V-H87!P96XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W
M<SHB"FUS9W-T<B`B4FEJ96XZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T
M<B`B3&EN:>MR:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R("),:6YIZW)I
M;F<@>F%L('9E<G-C:&EJ;F5N('1U<W-E;B!A;&QE(')I:F5N(&5N(&MO;&]M
M;65N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C
M;VQU;6YS(&]N;'DB"FUS9W-T<B`B3&EN:>MR:6YG('IA;"!A;&QE96X@='5S
M<V5N(&MO;&]M;65N('9E<G-C:&EJ;F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@
M=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B3&EN:>MR
M:6YG('IA;"!A;&QE96X@='5S<V5N(')I:F5N('9E<G-C:&EJ;F5N(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$R,0IM<V=I9"`B4G5N(@IM<V=S='(@(E-T
M87)T96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DY"FUS9VED(")2=7-S:6%N($9E9&5R871I
M;VXB"FUS9W-T<B`B4G5S<VES8VAE($9E9&5R871I92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#`*;7-G:60@(E)W86YD82(*;7-G<W1R(")2=V%N9&$B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R
M>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(D-R>7!T;V=R869I<V-H
M92!3+TU)344@:&%N9'1E:V5N:6YG(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S
M<V%G92(*;7-G<W1R(")3+TU)344@9V5C;V1E97)D(&)E<FEC:'0B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q"FUS9VED(")305-,(&%U
M=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E-!4TP@
M875T:&5N=&EC871I92!I<R!N:65T(&)E<V-H:6MB86%R+B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HU,#8*;7-G:60@(E--4R!-97-S86=I;F<B
M"FUS9W-T<B`B4TU3('9E<G-T=7)E;B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(E-13"!S:&5L;"(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-S0*;7-G:60@(E-13"!S=&%T
M96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B4U%,('-T871E;65N
M="!V;V]R('=A87)D97IO96MO<&1R86-H=&5N(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0S,PIM<V=I9"`B4U-((@IM<V=S='(@(E-32"(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B4U5#0T53
M(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED(")37U%,(%-H96QL(@IM<V=S
M='(@(E-?44P@<VAE;&PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R("):82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#<*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R(")3="!(96QE
M;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S$*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I
M<R(*;7-G<W1R(")3="!+:71T<R!E;B!.979I<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.0IM
M<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B4W0@3'5C:6$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@Y"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S
M='(@(E-T(%!I97)R92!E;B!-:7%U96QO;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#0*;7-G
M:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@
M(E-T(%9I;F-E;G0@96X@9&4@1W)E;F%D:6YE<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A
M;64@*%]S96QF*2(*;7-G<W1R("):96QF9&4@9G)A;64@*%]S96QF*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-3$*;7-G:60@(E-A;6]A(@IM<V=S='(@(E-A;6]A(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q,@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R(")386X@36%R
M:6YO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q-@IM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC
M:7!E(@IM<V=S='(@(E-A;R!4;VUE(&5N(%!R:6YC:7!E(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R
M;W9I9&5R(@IM<V=S='(@(E-A=&5L;&EE='!R;W9I9&5R(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P,0IM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(E-A=61I($%R86)I
MZR(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.0IM<V=I9"`B
M4V%V92(*;7-G<W1R(")/<'-L86%N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB
M)7-<(B(*;7-G<W1R(")<(B5S7"(@;W!S;&%A;B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,C$V"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@
M)7,B"FUS9W-T<B`B)7,@;W!S;&%A;B(*"B,Z('1E;7!L871E<R]P<F5F<R]E
M;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R(")/<'1I97,@
M;W!S;&%A;B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@
M(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R
M:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@HB1V5G96YE<F5E<F1E(&-O;F9I9W5R871I92!A;',@4$A0
M('-C<FEP="!O<&=E<VQA9V5N(&EN(&1E('1I:F1E;&EJ:V4@(@HB9&ER96-T
M;W)Y('9A;B!U=R!S97)V97(N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B)7,@8V]N9FEG=7)A=&EE(&]P9V5S;&%G96XB"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*
M;7-G<W1R(")3971U<"!U<&=R861E('-C<FEP="!O<&=E<VQA9V5N(&YA87(Z
M(%PB)7-<(BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU,0IM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(D=E
M<W!R96ED92!O;G=E97)S8G5I96XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B5V5T96YS8VAA<"(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B
M6F]E:V5N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R,@IM<V=I
M9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B6F]E:VUA8VAI;F5S(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDU-0IM<V=I9"`B4V5L96-T($9I
M;&5S(@IM<V=S='(@(DMI97,@8F5S=&%N9&5N(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-0IM<V=I9"`B4V5L96-T(&$@
M9&%T92(*;7-G<W1R(")396QE8W1E97(@965N(&1A='5M(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P
M('1O(&%D9"(*;7-G<W1R(")396QE8W1E97(@965N(&=R;V5P(&]M('1O92!T
M92!V;V5G96XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"FUS
M9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`B4V5L96-T965R(&5E
M;B!N:65U=V4@96EG96YA87(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R(")396QE
M8W1E97(@965N('-E<G9E<B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R(")3
M96QE8W1E97(@965N(&=E8G)U:6ME<B!O;2!T;V4@=&4@=F]E9V5N(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-@IM<V=I
M9"`B4V5L96-T(&%L;"(*;7-G<W1R(")!;&QE<R!S96QE8W1E<F5N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8T,PIM<V=I9"`B4V5L96-T(&%L
M;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(E-E;&5C=&5E<B!A;&QE(&1A
M='5M8V]M<&]N96YT96XN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G
M<W1R(")396QE8W1E97(@965N(&]B:F5C="(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HV-S<*;7-G:60@(E-E;&5C="!N;VYE
M(@IM<V=S='(@(DYI971S('-E;&5C=&5R96XB"@HC.B!S97)V:6-E<R]K97EB
M;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y
M;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O
M<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G
M<W1R("(B"B)396QE8W1E97(@9&4@8F5N;V1I9V1E(&MA<F%K=&5R<R!U:70@
M9&4@;VYD97)S=&%A;F1E('9A:VIE<RX@52!K=6YT(&1E>F4@9&%N("(*(FMO
M<&GK<F5N(&5N('!L86MK96X@:6X@:&5T('1E:W-T9V5B:65D+B(*"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A
M=&4@9&5L:6UI=&5R.B(*;7-G<W1R(")396QE8W1E97(@:&5T(&1A='5M<V-H
M96ED:6YG<W1E:V5N.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0T
M"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R(")396QE
M8W1E97(@:&5T(&1A='5M9F]R;6%A=#HB"@HC.B!T96UP;&%T97,O<')E9G,O
M:61E;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")396QE8W0@=&AE(&ED96YT
M:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`B4V5L96-T965R(&1E
M(&ED96YT:71E:70@9&EE('4@=VEL="!W:6IZ:6=E;CHB"@HC.B!T96UP;&%T
M97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E
M;&EM:71E<CHB"FUS9W-T<B`B4V5L96-T965R(&AE="!T:6ID<V-H96ED:6YG
M<W1E:V5N.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED
M(")396QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R(")396QE8W1E97(@
M:&5T('1I:F1S9F]R;6%A=#HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS
M9W-T<B`B4V5L96-T965R('1W964@;W9E<F5E;FMO;65N9&4@=F5L9&5N+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,3`*;7-G:60@(E-E;&5C="!Y
M;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B4V5L96-T965R('5W(&ML975R
M<V-H96UA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3(*;7-G:60@
M(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B4V5L
M96-T965R('5W(&=E=V5N<W1E('1A86PZ(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B
M"FUS9W-T<B`B4')O8FQE96UR87!P;W)T('9E<GIE;F1E;B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#0R"FUS9VED(")3
M96YD(%--4R(*;7-G<W1R(")697)Z96YD(%--4R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,*
M;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B4V5N96=A;"(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S(S"FUS9VED(")396YS;W(Z("(*;7-G<W1R(")396YS
M;W(Z("(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B4V5P=&5M8F5R(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E
M<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R(")397)V:>L@96X@36]N=&5N
M96=R;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`R
M"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(E-E<FEE;G5M;65R(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T.0IM<V=I9"`B4V5R
M=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4V5R
M=F5R9&%T82!F;W5T(&]F(&YI970@8F5S8VAI:V)A87(N(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C(W"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@
M(E-E<W-I96)E:&5E<F1E<B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I
M<F5D+B(*;7-G<W1R(")397-S:64@240@=F5R;&]P96XN(@H*(SH@;&EB+V%P
M:2YP:'`Z,30U"FUS9VED(")397-S:6]N<R(*;7-G<W1R(")397-S:65S(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-`IM<V=I9"`B4V5T(@IM
M<V=S='(@(DEN<W1E;&QE;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M.0IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO
M=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R("(B
M"B));G-T96QL96X@=F%N(&]P=&EE<R!O;2!U('1O92!T92!S=&%A;B!U=R!W
M86-H='=O;W)D('1E(')E<V5T=&5N+"!W86YN965R('4@(@HB9&ET(&)E;G0@
M=F5R9V5T96XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q.`IM<V=I
M9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C
M97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(B(*(DEN<W1E;&QE;B!V
M86X@<V5R=F5R<R!O<"!A9G-T86YD(&1I92!U('=I;'0@8F5N861E<F5N('9A
M;G5I="!U=R!P;W)T86PN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@W
M"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE
M(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(DEN<W1E;&QE;B!V86X@=7<@
M9V5W96YS=&4@=&%A;"P@=&EJ9'IO;F4@96X@9&%T=6UO<'1I97,N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,0IM<V=I9"`B(@HB4V5T('EO=7(@
M<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E
M<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@
M(B(*(DEN<W1E;&QE;B!V86X@=7<@;W!S=&%R='1O97!A<W-I;F<L(&ML975R
M<V-H96UA+"!P86=I;F%V97)V97)S:6YG(&5N(&%N9&5R92`B"B)W965R9V%V
M96]P=&EE<RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W"FUS9VED
M(")3971U<"(*;7-G<W1R("));G-T96QL96XB"@HC.B!T96UP;&%T97,O861M
M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D92!S
M8W)I<'1S(&%V86EL86)L92(*;7-G<W1R(")3971U<"!U<&=R861E('-C<FEP
M=',@8F5S8VAI:V)A87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3<U"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H
M('1H92!P87)A;65T97(Z("(*;7-G<W1R(")697)S8VAI;&QE;F1E(&QO8V%T
M:65S(&UO9V5L:6IK(&UE="!D92!P87)A;6%T97(Z("(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#,*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B4V5Y8VAE;&QE;B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.3@*;7-G:60@(E-H;W!P:6YG
M(@IM<V=S='(@(E=I;FME;&5N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B2V]R
M=&4@<V%M96YV871T:6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U
M,`IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO
M<W0@;&EN:W,_(@IM<V=S='(@(D1I96YE;B!S;F5L=&]E='-E;B!V;V]R(&1E
M(&UE97-T92!L:6YK<R!G961E9FEN:65E<F0@=&4@=V]R9&5N/R(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W
M(@IM<V=S='(@(E=E97)G979E;B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R
M96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B(@HB5F5R<V-H:6QL96X@;&%T96X@>FEE;B!T
M=7-S96X@9&4@:'5I9&EG92!O<&=E<VQA9V5N(&-O;F9I9W5R871I92!E;B!D
M92`B"B)N:65U=V4@9V5G96YE<F5E<F1E(&-O;F9I9W5R871I92XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DT"FUS9VED(")3:&]W(&QA<W0@;&]G
M:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(DQA871S=&4@86%N
M;65L9&EN9W-T:6ID('=E97)G979E;B!B:6H@86%N;65L9&5N/R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C4*;7-G:60@(E-H;W<@;W!T:6]N
M('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B3W!T:64@=V5E<F=E=F5N(&]M
M(&]R:6=I;F5E;"!T92!B97=A<F5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C<Y-0IM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B2VEE>F5R
M('=E97)G979E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S`*;7-G
M:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B
M5&%B96QB97=E<FMI;F=S=&%A:V)A;&L@=V5E<F=E=F5N/R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO
M=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B)7,@;65N=2!A
M86X@9&4@;&EN:V5R:V%N="!W965R9V5V96X_(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3
M:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@
M(E1A8F5L8V5L96EG96YS8VAA<'!E;B!D:6%L;V]G=F5N<W1E<B!W965R9V5V
M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@
M9&EA;&]G(@IM<V=S='(@(E1A8F5L96EG96YS8VAA<'!E;B!D:6%L;V]G=F5N
M<W1E<B!W965R9V5V96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE
M(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")486)E;')I:F5I9V5N
M<V-H87!P96X@9&EA;&]O9W9E;G-T97(@=V5E<F=E=F5N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS
M9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R
M(")!9F)E96QD:6YG<V5I9V5N<V-H87!P96X@9&EA;&]O9W9E;G-T97(@=V5E
M<F=E=F5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,PIM<V=I
M9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B57!L;V%D('=E97)G979E;B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED
M(")3:&]W97)S(@IM<V=S='(@(D)U:65N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@16%R;'DB
M"FUS9W-T<B`B0G5I96X@=G)O96<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S
M='(@(D)U:65N(&QA870B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU-0IM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB
M"FUS9W-T<B`B0G5I96X@:6X@9&4@;F%B:6IH96ED(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV,3D*;7-G:60@(E-H
M<FEN:R(*;7-G<W1R(")697)K;&5I;F5N(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HY,3`*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HY-S(*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,#4X"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3$R,`HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q.#,*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ
M,C(S"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP
M:'`Z,3(U,@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C$R.#4*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN
M9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R(")697)K
M;&5I;B!O9B!V97)P;&%A=',@;F%B=7)I9V4@8FQO:VME;B!E97)S="(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3$*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R(")3:65R
M<F$@3&5O;F4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M,C8V"FUS9VED(")3:6=N('5P(@IM<V=S='(@(DEN=&5K96YE;B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$S"FUS9VED(")3:6=N
M871U<F4B"FUS9W-T<B`B2&%N9'1E:V5N:6YG(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92!!;&=O
M<FET:&TB"FUS9W-T<B`B2&%N9'1E:V5N:6YG(&%L9V]R:71H;64B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`V"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B4VEN9V%P;W)E
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@T"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S(@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C0V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y
M,3(*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P-0IM<V=I9"`B4VEZ
M92(*;7-G<W1R(")'<F]O='1E(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B
M"FUS9W-T<B`B3VYD97)H;W5D(&]V97)S;&%A;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`*
M;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(E-L;W=A:VEJ92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#@*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(E-L;W9E;FGK(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@
M(E-N;W<B"FUS9W-T<B`B4VYE975W(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S
M='(@(E-N965U=W9L86%G(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R(")3
M;F5E=7=B=6EE;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4Y"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B
M<VYE975W8G5I96X@=G)O96<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS
M9W-T<B`B4VYE975W8G5I96X@;&%A="(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C@U"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B4VYE975W9&EE
M<'1E.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X.0IM<V=I9"`B4VYO
M=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B4VYE975W97%U:79A
M;&5N="!I;B!W871E<CH@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,@IM<V=I9"`B4V]L;VUO
M;B!)<VQA;F1S(@IM<V=S='(@(E-O;&]M;VX@96EL86YD96XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$T"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(E-O;6%L:>LB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B
M"FUS9W-T<B`B3&EE9&5R96X@96X@9V5D:6-H=&5N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,CDP.`IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I
M;VXB"FUS9W-T<B`B4V]R=&5E<G9O;&=O<F1E('-E;&5C=&EE(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$V-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$X
M.0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B0G)O;F%D<F5S(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U-0IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(EIU
M:60@069R:6MA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@
M(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R("):=6ED($5U
M<F]P965S("A)4T\M.#@U.2TS*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,0IM<V=I9"`B4V]U
M=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS
M9W-T<B`B6G5I9"!'96]R9VGK(&5N(&1E(%IU:60@4V%N9'=I8V@@96EL86YD
M96XB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN
M<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(EIU
M:61E;&EJ:R!H86QF<F]N9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D:F%C
M96YT(&-E;&QS(@IM<V=S='(@(E-P871IZW)I;F<@='5S<V5N(&%A;F=R96YZ
M96YD92!C96QL96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N
M9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R(")3<&%T:>MR:6YG('1U<W-E;B!I
M;FAO=60@96X@<F%N9"!I;B!C96PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HX,34*;7-G:60@(E-P86-E<B(*;7-G<W1R(")38VAE:61I;F=S=&5K
M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-34*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B4W!A=&GK<FEN9R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B4W!A
M=&GK<FEN9R!E;B!V<FEJ92!R=6EM=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,`IM<V=I9"`B
M4W!A:6XB"FUS9W-T<B`B4W!A;FIE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$P,`IM<V=I9"`B4W!A;2(*;7-G<W1R(")3<&%M(@H*(SH@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E
M<B!);G!U="(*;7-G<W1R(")3<&5C:6%A;"!K87)A:W1E<B!I;G9O97(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@(D-E;"!O<'-P;&ET<V5N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(DMO;&]M(&]P
M<W!L:71S96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B4FEJ
M(&]P<W!L:71S96XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G
M:60@(E-P;W)T<R(*;7-G<W1R(")3<&]R="(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,0IM<V=I
M9"`B4W)I($QA;FMA(@IM<V=S='(@(E-R:2!,86YK82(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z.#$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8V
M"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R(")3=&%N9&%A<F0B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R
M(")3=&%R(%1R96LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3@V
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.3$*;7-G:60@(E-T87)T('EE
M87(B"FUS9W-T<B`B4W1A<G1J86%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S$*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM
M<V=S='(@(E-T86%T(&]F('!R;W9I;F-I92(*"B,Z('1E;7!L871E<R]A9&UI
M;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B
M4W1A='5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y-PIM<V=I
M9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B3W!S;&%G9F]R;6%A="(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")3
M=')E970@061D<F5S<R(*;7-G<W1R(")!9')E<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H
M<F]U9V@B"FUS9W-T<B`B1&]O<FAA;&5N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B4W1R
M:6YG;&EJ<W0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S"FUS
M9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R(")3
M=')I<"!D;VUE:6X@=F%N(&AE="!A9')E<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE
M(%M#4U-=(@IM<V=S='(@(E-T:6IL(%M#4U-=(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T
M<B`B6F\B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM
M<V=S='(@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;FEE="!G979O;F1E;BXB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS
M9VED(")3=6)J96-T(@IM<V=S='(@(D]N9&5R=V5R<"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S,B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E
M<F5R+G!H<#HS,3@*;7-G:60@(E-U8FUI="(*;7-G<W1R(")"979E<W1I9V5N
M(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3
M=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN
M(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@
M8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@HB5F5R>F]E:R!V97)S='5U<F0@
M;VT@7"(E<UPB(&%A;B!H970@<WES=&5E;2!T;V4@=&4@=F]E9V5N+B!5(&MU
M;G0@;FEE="`B"B)A86YM96QD96X@=&]T('5W('9E<GIO96L@:7,@9V]E9&=E
M:V5U<F0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(E-U8G-C<FEP="(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TYO=&EF
M:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM
M<V=I9"`B4W5C8V5S<R(*;7-G<W1R(")3=6-C97,B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D
M960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!M970@
M<W5C8V5S(&%A;B!H970@<WES=&5E;2!T;V5G979O96=D+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T
M96TN(@IM<V=S='(@(D1A=&$@=F%N(&=E8G)U:6ME<B!<(B5S7"(@;65T('-U
M8V-E<R!U:70@:&5T('-Y<W1E96T@=F5R=VEJ9&5R9"XB"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*
M;7-G<W1R(")<(B5S7"(@;65T('-U8V-E<R!V97)W:6ID97)D+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R
M(")<(B5S7"(@;65T('-U8V-E<R!U:70@:&5T('-Y<W1E96T@=F5R=VEJ9&5R
M9"XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C
M97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E
M92!C:&%N9V5S+B(*;7-G<W1R(")#;VYF:6=U<F%T:64@;65T('-U8V-E<R!T
M97)U9V=E>F5T+B!697)N:65U=R!O;2!W:6IZ:6=I;F=E;B!T92!Z:65N+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")"86-K=7!C;VYF:6=U<F%T:64@;65T
M('-U8V-E<W,@;W!G97-L86=E;BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E
M9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B
M0F%C:W5P8V]N9FEG=7)A=&EE8F5S=&%N9"`E<R!M970@<W5C8V5S<R!O<&=E
M<VQA9V5N+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B
M7"(E<UPB(&UE="!S=6-C97,@8FEJ9V5W97)K="(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R
M("(E<R!M970@<W5C8V5S(&=E<V-H<F5V96XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`T"FUS
M9VED(")3=61A;B(*;7-G<W1R(")3;V5D86XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM
M87)Y(@IM<V=S='(@(E-A;65N=F%T=&EN9R(*"B,Z(&QI8B]";&]C:R]S=6YR
M:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B6F]N<V]P9V%N
M9R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E
M="(*;7-G<W1R("):;VYS;VYD97)G86YG(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E-U;FYY(@IM<V=S='(@
M(EIO;FYI9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#4*
M;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B6F]N<V]P9V%N9R(*"B,Z(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM
M<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B6F]N<V]P9V%N9R]:;VYS
M;VYD97)G86YG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P
M-`IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(EIO;G-O<&=A;F<Z("(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#@*;7-G:60@(E-U;G-E
M="(*;7-G<W1R("):;VYS;VYD97)G86YG(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(P-PIM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B6F]N
M<V]N9&5R9V%N9SH@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`B4W5P
M97)S8W)I<'0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@P"FUS
M9VED(")3=7!P;W)T(@IM<V=S='(@(D]N9&5R<W1E=6YI;F<B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$U"FUS9VED(")3=7)I;F%M92(*;7-G<W1R(")3=7)I;F%M92(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")3
M=7)N86UE(@IM<V=S='(@(D%C:'1E<FYA86TB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y"FUS
M9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(E-P:71S8F5R
M9V5N(&5N($IA;B!-87EE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D*;7-G:60@(E-W87II
M;&%N9"(*;7-G<W1R(")3=V%Z:6QA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U"FUS9VED
M(")3=V5D96XB"FUS9W-T<B`B6G=E9&5N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38*;7-G:60@
M(E-W:71Z97)L86YD(@IM<V=S='(@(EIW:71S97)L86YD(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T
M960B"FUS9W-T<B`B4WEN8R!L;V<@=F5R=VEJ9&5R9"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-#4*;7-G:60@(E-Y;F--3"(*;7-G<W1R(")3>6YC
M34PB"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G
M:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B4WEN
M=&%X9F]U="!I;B!Z;V5K=&5R;65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.`IM<V=I9"`B
M4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B4WER:7-C:&4@07)A8FES
M8VAE(%)E<'5B;&EE:R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M(@IM<V=S='(@(D]N=V5E<G-B
M=6DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,PIM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B3VYW965R<V)U
M:65N(&5N('=I;F1E<FEG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(D]N=V5E
M<G-B=6EE;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8U"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R(")/;G=E97)S
M8G5I96X@=G)O96<B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z
M,38V"FUS9VED(")44U8@9FEL92(*;7-G<W1R(")44U8@8F5S=&%N9"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B5&%B96QE:6=E
M;G-C:&%P<&5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE
M<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@4V5T(@IM<V=S='(@(E1A8F5L<V5T
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R(")486)E
M;&5I9V5N<V-H87!P96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T"FUS9VED(")4
M86EW86XB"FUS9W-T<B`B5&%I=V%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@
M0VAI;F$B"FUS9W-T<B`B5&%I=V%N+"!0<F]V:6YC:64@=F%N($-H:6YA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R-0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R(")4861Z
M:FEK:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U"FUS9VED(")486YZ86YI82P@56YI
M=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(E1A;GIA;FEA+"!697)E;FEG9&4@
M4F5P=6)L:65K('9A;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B1&]E;#HB
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,B!C;VYF:6<O:&]O
M:W,N<&AP+F1I<W0Z,3`T.0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3@Y"FUS9VED(")487-K<R(*;7-G<W1R(")486ME;B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"FUS9VED(")496QE<&AO;F4@
M3G5M8F5R(@IM<V=S='(@(E1E;&5F;V]N;G5M;65R(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR.3<*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM
M<V=S='(@(E1E;7!E<F%T=75R('9A;B!H970@869G96QO<&5N('5U<CH@(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C$*;7-G:60@(E1E;7!E<F%T=7)E
M(@IM<V=S='(@(E1E;7!E<F%T=75R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Q,@IM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R(")4
M96UP97)A='5U<CH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(X,@HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R93QB<B`O/B@E
M<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(E1E;7!E<F%T=75R/&)R
M("\^*"5S2&]O9R5S+R5S3&%A9R5S*2`F9W)D.R5S(@H*(SH@9G)A;65W;W)K
M+U1E;7!L871E+U1E;7!L871E+G!H<#HV.34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B4VIA8FQO
M;VX@7"(E<UPB(&YI970@9V5V;VYD96XN(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(E-J86)L;V]N8F5H965R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(W"FUS9VED(")4
M97AT(@IM<V=S='(@(E1E:W-T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,W.0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(D%L;&5E;B!T96MS="(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B5&5K<W0@=6ET;&EJ
M;F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R(")496MS=&)O=F5N:V%N="(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*
M;7-G:60@(E1H(@IM<V=S='(@(D1O(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.30*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(E1H86ES("A4
M25,M-C(P*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0*;7-G:60@(E1H86EL86YD(@IM<V=S
M='(@(E1H86EL86YD(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX
M-3$*;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(D1E($944"!E>'1E;G1I92!I<R!N:65T(&)E<V-H:6MB86%R
M+B(*"B,Z(&9R86UE=V]R:R](:7-T;W)Y+TAI<W1O<GDN<&AP.C4U"FUS9VED
M(")4:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L960N(@IM<V=S='(@(DAE
M="!G97-C:&EE9&5N:7-S>7-T965M(&ES('5I=&=E<V-H86ME;&0N(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S
M(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R(")$92!(;W)D92]+;VQA8B!I
M;G1E9W)A=&EE(&]N9&5R<W1E=6YT(%PB)7-<(B!N:65T(@H*(SH@9G)A;65W
M;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP:'`Z,3(Y.`IM<V=I9"`B5&AE($E-
M4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B2&5T
M($E-4U`@;&]G(&MO;B!N:65T('=O<F1E;B!G96EN:71I86QI<V5E<F0N(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I
M;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM
M<V=S='(@(D1E($UA:6YT96YA;F-E.CH@8VQA<W,@=V5R9"!N:65T(&=E;&%D
M96XB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS
M9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB
M"FUS9W-T<B`B2&5T($]P=&EE<W-C:&5R;2!I<R!G97-L;W1E;BX@069S;'5I
M=&5N+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,C8T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4
M:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE
M;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@
M4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*(D1E(&)E:&5E<F1E<B!D:65N="!E
M96X@<&5R;6%N96YT(')E8VAT96YB86-K96YD('1E(&-O;F9I9W5R97)E;B!A
M;',@=2`B"B)R96-H=&5N('=I;'0@9V5B<G5I:V5N+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@
M(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(D%L;&5E;B!D92!O;F1E
M<FMA;G0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A
M<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@
M:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"B)(970@8V]N=&%C="!)
M1"!N=6UM97(@:7,@;FEE="!O<&=E9V5V96XL(&QE96<@9V5L871E;B!O9B!I
M<R!N:65T(&=E=F]N9&5N(&EN("(*(F1E(&1A=&%B87-E+B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE
M(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E
M<W,@8F]O:RXB"FUS9W-T<B`B2&5T(&%D<F5S(&ES(&UE="!S=6-C97,@86%N
M('5W(&%D<F5S8F]E:R!T;V5G979O96=D+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$Q-S(*;7-G:60@(B(*(E1H92!D971A8VAE9"!0
M1U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@
M<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*(DAE="!L;W-G96MO<'!E;&1E
M(%!'4"!O;F1E<G1E:V5N:6YG<V)L;VL@:7,@=F5R96ES="!O;2!H970@;VYD
M97)T96ME;F1E("(*(F)E<FEC:'0@=&4@=F5R:69IZW)E;BXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I
M9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T
M('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE
M(&1A=&%B87-E+B(*;7-G<W1R("(B"B)(970@9&ES=')U8G5T:65L:6IS="!)
M1"!I<R!N:65T(&]P9V5G979E;BP@;&5E9R!G96QA=&5N(&]F(&ES(&YI970@
M9V5V;VYD96X@(@HB:6X@9&4@9&%T86)A<V4N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H92!D
M:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B
M1&4@9&ES=')I8G5T:65L:6IS="!I<R!N:65T(&]P9V5G979E;BXB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q-@IM<V=I9"`B5&AE(&5N8W)Y
M<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO
M;BXB"FUS9W-T<B`B1&4@8V]D965R;6]G96QI:FMH961E;B!V97)E:7-E;B!E
M96X@8F5V96EL:6=D92!W96)V97)B:6YD:6YG+B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,3@V(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M-3(X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C
M;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B2&5T(&)E<W1A;F0@)7,@
M9&EE;G0@965N("5S(&EN<W1E;&QI;F<@=&4@8F5V871T96XN(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-SD@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HU,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@
M<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B2&5T
M(&)E<W1A;F0@)7,@9&EE;G0@96YI9V4@)7,@:6YS=&5L;&EN9V5N('1E(&)E
M=F%T=&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-@IM
M<V=I9"`B5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB
M"FUS9W-T<B`B2&5T(&)E<W1A;F0@:V%N(&YI970@;F%A<B!Z:6-H>F5L9B!G
M96MO<&EE97)D('=O<F1E;BXB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H
M<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G
M<W1R(")(970@8F5S=&%N9"!B979A='1E(&=E96X@9&%T82XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4
M:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E
M+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R(")(970@=F]L9V5N9&4@>FEJ;B!D
M92!K;W!P96X@=F%N(&1I="!M97-S86=E+W)F8S@R,B!B97)I8VAT+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G
M:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E
M('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B
M<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N
M9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@
M;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E
M<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I
M="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*
M(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9
M;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y
M;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB
M"FUS9W-T<B`B(@HB5F%N(&1E('9O;&QE9&EG('-C:&5R;2!M;V1E(&ES(&)E
M:V5N9"P@9&%T(&1I="!P<F]B;&5M96X@:V%N('9E<F]O<GIA:V5N(&UE="`B
M"B));G1E<FYE="!%>'!L;W)E<BP@=F%N=V5G92!B<F]W<V5R8G5G<R!W86%R
M('=I:B!N:65T(&]M:&5E;B!K=6YN96XN($AE="!I<R`B"B)M;V=E;&EJ:R!D
M870@=2!R;VUM96P@:6X@:&5T(&)E96QD<V-H97)M+"!G96)R96L@86%N(&5D
M:71O<F9U;F-T:65S(&5N+V]F("(*(G)A;F1O;2!B<F]W<V5R+2!C<F%S:&5S
M(&5R=F%A<G0N(%=A;FYE97(@=7<@<WES=&5E;2!7:6YD;W=S(#EX(&ES+"!I
M<R!H970@(@HB=V%A<G-C:&EJ;FQI:FL@9&%T('4@965N("=!;&=E;65N92!"
M979E:6QI9VEN9W,@1F]U="<@:W)I:F=T+"!E;B!O<&YI975W("(*(F1I96YT
M('1E(&AE<G-T87)T96XN7%QN7%QN52!B96YT(&=E=V%A<G-C:'5W9"X@1')U
M:R!O<"!/2R!W86YN965R('4@=&]C:"!D92`B"B)V;VQL961I9R!S8VAE<FT@
M961I=&]R('=I;'0@<')O8F5R96XN(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP
M.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB
M(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(D1E(&ED96YT:71E:70@7"(E
M<UPB(&ES('9E<G=I:F1E<F0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N
M9"!S:61E(&]N;'DB"FUS9W-T<B`B06QL965N(&1E(&QI;FME<FMA;G0B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*
M(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV
M96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B"B)$92!P
M;&%A=',@=F%N(&AE="!';G501R!P<F]G<F%M;6$@9&EE;G0@;W!G96=E=F5N
M('1E('=O<F1E;B!I;B!D92`B"B)#<GEP=%]P9W`Z.B!C;&%S<RXB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`R"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S
M=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES
M(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@
M;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@HB2&5T(&)E<FEC:'0@=F5R<W1U
M=7)D(&]P("5S(&%A;B`E<R!M970@;VYD97)W97)P(%PB)7-<(B!I<R!W965R
M9V5G979E;BY<;B(*(D1I="!I<R!G965N(&=A<F%N=&EE(&1A="!H970@8F5R
M:6-H="!I<R!G96QE>F5N(&]F(&)E9W)E<&5N+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X-S<*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N
M(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R(")$92!N86%M
M(&1I92!G96)R=6EK="!W;W)D="!B:6H@;&EN:V5N(&YA87(@9&4@;FEE=7<@
M8F5R:6-H="!P86=I;F$B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HT-S0*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M
M97)I8RXB"FUS9W-T<B`B2&5T(&%A;G1A;"!V96QD96X@9&EE;G0@;G5M97)I
M96L@=&4@>FEJ;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C$R,S(*;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E
M9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@
M(D1E(&]P96YS<VP@;6]D=6QE(&ES('9E<F5I<W0@=F]O<B!D92!(;W)D95]#
M<GEP=%]S;6EM93HZ(&-L87-S+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<RYP:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E
M;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T
M82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G
M<W1R("(B"B)$92!V;V]R:V5U<G-I;G-T96QL:6YG(%PB)7-<(B!K;VX@;FEE
M="!W;W)D96X@;W!G97-L86=E;BP@;VUD870@9&4@9&%T82!D92`B"B)M87AI
M;75M('1O96QA871B87)E(&=R;V]T=&4@;W9E<G-C:')I:F1T+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T
M:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E
M;2XB"FUS9W-T<B`B(@HB2&5T('!R;V=R86UM82!O;2!D:70@9&%T871Y<&4@
M*"5S*2!T92!B96MI:FME;BP@=V5R9"!N:65T(&]P(&AE="!S>7-T965M("(*
M(F=E=F]N9&5N+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0X
M-PIM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG
M;&4@8VAA<F%C=&5R+B(*;7-G<W1R(")(970@86%N:&%L:6YG<W1E:V5N(&1I
M96YT(.OK;B!E;FME;"!T96ME;B!T92!Z:6IN+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H
M92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(D%L;&5E;B!D
M92!R96-H=&5R+2!E;B!L:6YK97)K86YT(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I
M9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(D%L;&5E;B!D92!R96-H=&5R
M:V%N="(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0W.0IM<V=I
M9"`B5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R
M+B(*;7-G<W1R(")(970@<V-H96ED:6YG<W1E:V5N(&1I96YT(.OK;B!E;FME
M;"!T96ME;B!T92!Z:6IN+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN
M<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB
M(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(D1E('-E<G9E<B!<(B5S7"(@
M:7,@=F5R=VEJ9&5R9"XB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H
M<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H
M87,@8F5E;B!S879E9"XB"FUS9W-T<B`B1&4@<V5R=F5R(%PB)7-<(B!I<R!O
M<&=E<VQA9V5N+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N
M(')E;6]V960N(@IM<V=S='(@(DAE="!A86YM96QD:6YG<W9E<GIO96L@=F]O
M<B`E<R!I<R!V97)W:6ID97)D+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z-#<P"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!S<&5C:69I960@<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N(@IM<V=S
M='(@(D1E(&]P9V5G979E;B!R:6H@*"5D*2!B97-T86%T(&YI970N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ-SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES
M="XB"FUS9W-T<B`B2&5T('1I:F1E;&EJ:R!B97-T86YD(%PB)7-<(B!B97-T
M86%T(&YI970N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P,@IM
M<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@
M=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R(")$92!I;F=E=F]E<F1E('1E
M:W-T(&MO;70@;FEE="!O=F5R965N(&UE="!D92!T96MS="!O<"!H970@<V-H
M97)M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O
M;FQY(@IM<V=S='(@(D%L;&5E;B!D92!B;W9E;BT@96X@;VYD97)K86YT(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B06QL965N
M(&1E(&)O=F5N:V%N="(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C,R
M-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE
M('!R979I;W5S('-T97`N(@IM<V=S='(@(D1E('5P;&]A9&5D(&1A=&$@:7,@
M;F$@9&4@=F]O<F=A86YD92!S=&%P('9E<FQO<F5N(&=E9V%A;BXB"@HC.B!F
M<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A
M+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O
M=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B2&5T('5P;&]A9&5D(&)E<W1A
M;F0@:7,@;FEE="!O<&=E<VQA9V5N+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HT.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$P
M"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B2&5T('=E871H97(N8V]M(&)L;VL@:7,@;FEE="!B97-C
M:&EK8F%A<BXB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O
M=6YD+B(*;7-G<W1R(")4:&5M861I<F5C=&]R>2!<(B5S7"(@;FEE="!G979O
M;F1E;BXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$W.`IM
M<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R
M(")'965N(&]P=&EE<R!B97-C:&EK8F%A<BXB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HS-3`*;7-G:60@(E1H97)E(&%R92!N;R!P
M87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R(")%
M<B!Z:6IN(&=E96X@;VYD97)D96QE;BP@=V5L:V4@:6YL:6YE('=E97)G96=E
M=F5N(&MU;FYE;B!W;W)D96XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O
M(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E
M<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA
M;B`E<RXB"FUS9W-T<B`B(@HB17(@>FEJ;B!T92!V965L(&MA<F%K=&5R<R!I
M;B!D:70@=F5L9"X@52!H965F="`E<R!K87)A:W1E<G,@;W!G96=E=F5N.R!U
M("(*(F1I96YT(&UI;F1E<B!D86X@)7,@;W`@=&4@9V5V96XN(@H*(SH@<VEG
M;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE
M('-Y<W1E;3H@)7,B"FUS9W-T<B`B165N('!R;V)L965M(&UE="!H970@=&]E
M=F]E9V5N('9A;B!<(B5S7"(@86%N(&AE="!S>7-T965M.B`E<R(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*(D5E;B!P<F]B;&5E;2!M970@
M:&5T('9E<G=I:F1E<F5N('9A;B!D871A('9A;B!G96)R=6EK97(@7"(E<UPB
M('5I="!H970@(@HB<WES=&5E;3H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M
M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(D5E;B!P
M<F]B;&5E;2!M970@:&5T('9E<G=I:F1E<F5N('9A;B!<(B5S7"(@=6ET(&AE
M="!S>7-T965M.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S
M7"(Z("5S(@IM<V=S='(@(D5E;B!P<F]B;&5E;2!M970@:&5T(&)I:G=E<FME
M;B!V86X@7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S
M97(N<&AP.CDR-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D
M960N(@IM<V=S='(@(D5E;B!P<F]B;&5E;2!M970@9&4@8F5S=&%N9'-U<&QO
M860Z($=E96X@)7,@=V5R9"!G975P;&]A9"XB"@HC.B!F<F%M97=O<FLO0G)O
M=W-E<B]"<F]W<V5R+G!H<#HY,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE
M("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I
M>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HB165N('!R;V)L965M(&UE="!D
M92!B97-T86YD<W5P;&]A9#H@2&5T("5S(&ES(&=R;W1E<B!D86X@9&4@;6%X
M:6UU;2`B"B)T;V5L86%T8F%R92!G<F]O='1E("@E9"!B>71E<RDN(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3,T"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N
M(@IM<V=S='(@(B(*(D5E;B!P<F]B;&5E;2!M970@9&4@8F5S=&%N9'-U<&QO
M860Z($AE="`E<R!I<R!S;&5C:'1S(&=E9&5E;'1E;&EJ:R!G975P;&]A9"XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE
M<W-A9V4@<&%R="(*;7-G<W1R(")%96X@9F]U="!B:6H@:&5T(&)E:VEJ:V5N
M('9A;B!D:70@8F5R:6-H=&]N9&5R9&5E;"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B165N
M(&9O=70@8FEJ(&AE="!I;7!O<G1E<F5N('9A;B!D92!A9')E<V1A=&$N(@H*
M(SH@9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB
M"FUS9W-T<B`B165N(&9O=70@8FEJ(&AE="!I;7!O<G1E<F5N('9A;B!D92!I
M0V%L96YD87)D871A+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#(*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A
M=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D
M(&9I96QD+B(*;7-G<W1R("(B"B)%96X@9F]U="!I;B!H970@8V]N9FEG=7)A
M=&EE9F]R;75L:65R+B!-:7-S8VAI96X@8F5N="!U(&5E;B!V97)P;&EC:'0@
M=F5L9"`B"B)V97)G971E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@
M9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@
M(B(*(D5E;B!F;W5T(&)I:B!H970@=6ET=F]E<F5N('9A;B!D92!O<&=E9V5V
M96X@861R97-B;V5K9G5N8W1I92X@4')O8F5E<B!L871E<B`B"B)O<&YI975W
M+"!A+G4N8BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P
M9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N(@IM<V=S='(@(B(*(D5E;B!F;W5T(&UE="!H970@8FEJ=V5R:V5N
M('9A;B!D92!A9')E<V1E=&%I;',N(%!R;V)E97(@;&%T97(@;W!N:65U=RP@
M82YU+F(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N(@IM<V=S='(@(B(*(D5E;B!F;W5T(&UE="!H970@8FEJ=V5R:V5N('9A
M;B!D92!D:7-T<FEB=71I96QI:G-T+B!0<F]B965R(&QA=&5R(&]P;FEE=7<L
M(&$N(@HB=2YB+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S
M=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B1&5Z92!)34%0('-E
M<G9E<B!O;F1E<G-T975N="!G965N(&1E;&EN9R!V86X@;6%P<&5N+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@
M(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI
M=F4N(@IM<V=S='(@(D1I="!L:6IK="!N:65T(&5E;B!G96QD:6<@<F%R(&)E
M<W1A;F0@=&4@>FEJ;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B
M92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R(")$:70@;&EJ:W0@;FEE="!E
M96X@9V5L9&EG('II<"!B97-T86YD('1E('II:FXN(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$R-PIM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M
M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(D1I="!L:6IK
M="!N:65T(&5E;B!G96QD:6<@:V%A<G1N=6UM97(@=&4@>FEJ;BXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*
M;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T
M96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@
M(B(*(D1I="!S='5U<G!R;V=R86UM82!G965F="!D92!M;V=E;&EJ:VAE:60@
M;VT@8F5R:6-H=&5N('9I82!D92!#;&EC:V%T96QL("(*(BAH='1P.B\O8VQI
M8VMA=&5L;"YC;VTI(&=A=&5W87D@=&4@=F5R>F5N9&5N+"!D+FTN=BX@9&4@
M2%144"!!4$DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O
M;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*
M(D1I="!S='5U<G!R;V=R86UM82!G965F="!D92!M;V=E;&EJ:VAE:60@;VT@
M8F5R:6-H=&5N('9I82!D92!724X@*&AT='`Z+R\B"B)W:6YP;&,N8V]M*2!G
M871E=V%Y('1E('9E<GIE;F1E;BP@9"YM+G8N(&1E($A45%`@05!)(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*
M;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I
M;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B
M"B)$:70@<W1U=7)P<F]G<F%M;6$@9V5E9G0@9&4@;6]G96QI:FMH96ED(&]M
M(&)E<FEC:'1E;B!V:6$@9&4@<VUS,F5M86EL("(*(BAH='1P.B\O<VUS,F5M
M86EL+F-O;2D@9V%T97=A>2!T92!V97)Z96YD96XL(&0N;2YV+B!D92!(5%10
M($%022(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N
M92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N
M($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N
M92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"B)$:70@
M<W1U=7)P<F]G<F%M;6$@9V5E9G0@9&4@;6]G96QI:FMH96ED(&]M(&)E<FEC
M:'1E;B!V:6$@4TU44"!D+FTN=BX@9&4@(@HB5F]D869O;F4@271A;'D@9V%T
M97=A>2!T92!V97)Z96YD96X@;F%A<B!6;V1A9F]N92!N=6UM97)S+B!(:65R
M=F]O<B!I<R!E96X@(@HB5F]D869O;F4@271A;'D@92UM86EL861R97,@*&AT
M='`Z+R]W=W<N,3DP+FET*2!N;V]D>F%K96QI:FLN(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P
M-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$S.3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(T,#@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C,W(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,3`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,CDW"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,X,#4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q,PIM
M<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B1&ET('9E
M;&0@:7,@=F5R96ES="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P
M-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R
M<RXB"FUS9W-T<B`B1&ET('9E;&0@;6%G(&%L;&5E;B!I;G1E9V5R<R!B979A
M='1E;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$V"FUS9VED
M(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE
M(&-O;&]N+B(*;7-G<W1R(")$:70@=F5L9"!M86<@86QL965N(&=E=&%L;&5N
M(&5N(&1E(&1U8F)E;&4@<'5N="!B979A='1E;BXB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,#DT"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R(")$:70@=F5L9"!M86<@
M86QL965N(&]C=&%A;"!W86%R9&5N(&)E=F%T=&5N+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B
M92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S
M(@IM<V=S='(@(B(*(D1I="!V96QD(&1I96YT(&5E;B!K;VUM82!O9B!S<&%T
M:64@9V5S8VAE:61E;B!L:6IS="!M970@:6YT96=E<G,@=&4@>FEJ;B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX.0IM<V=I9"`B5&AI<R!F:65L
M9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R(")$97IE('=A87)D
M92!D:65N="!E96X@9V5L9&EG(&=E=&%L('1E('II:FXN(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q.`IM<V=I9"`B(@HB5&AI<R!F:65L9"!M
M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA
M="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"B)$:70@
M=F5L9"!D:65N="!E96X@:VQE=7)C;V1E(&EN(%)'0B!(15@M9F]R;6%A="!T
M92!B979A='1E;BP@8BYV+B`G(S$R,S1A9B<N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@
M8F5E;B!P<F]C97-S960N(@IM<V=S='(@(D1I="!F;W)M=6QI97(@:7,@<F5E
M9',@=F5R=V5R:W0N(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B1&ET
M(&ES("5S+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#8Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A
M<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@
M86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B
M($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B
M"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"B)$:70@:7,@
M965N($MO;&%B($=R;W5P=V%R92!O8FIE8W0N($]M(&1I="!O8FIE8W0@=V5E
M<B!T92!G979E;B!H965F="!U(&5E;B!E+2(*(FUA:6P@8VQI96YT(&YO9&EG
M(&1I92!H970@2V]L86(@1W)O=7!W87)E(&9O<FUA870@8F5G<FEJ<'0N(%9O
M;W(@965N(&QI:G-T("(*(FUE="!D97IE(&4M;6%I;&-L:65N=',L(&)E>F]E
M:R`E<RP@82YU+F(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z-3DY"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W
M87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N
M('EO=7(@;W=N+B(*;7-G<W1R("(B"B)$:70@8F5R:6-H="!I<R!I;B!E96X@
M86YD97)E(&MA<F%K=&5R<V5T("@E<RD@9V5S8VAR979E;BP@9&%N('5W(&5I
M9V5N+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V"FUS
M9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T
M<B`B1&ET(&=E=&%L(&1I96YT('1E;FUI;G-T92#IZ6X@=&4@>FEJ;BXB"@HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G
M:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP
M(&9I;&5S+B(*;7-G<W1R(")$97IE('-E<G9E<B!K86X@9V5E;B!Z:7`@96X@
M9WII<"!B97-T86YD96X@=6ET<&%K:V5N+B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I
M<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(DAE="!S>7-T965M
M(&ES(&UO;65N=&5E;"!U:71G97-C:&%K96QD+B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@
M8F4@82!N=6UB97(N(@IM<V=S='(@(D1E>F4@=V%A<F1E(&1I96YT(&5E;B!G
M971A;"!T92!Z:6IN+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME
M<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R
M;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B1&ET('-C:&5R;2!D:65N
M="!A86YG97)O97!E;B!T92!W;W)D96X@=F%N=6ET(&5E;B!/<'1I97-S8VAE
M<FTB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M-@IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R(")/;G=E97(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C,V"FUS9VED(")4:6-K971S(@IM<V=S='(@
M(E1I8VME=',B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(U('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B5&EM92(*;7-G
M<W1R(")4:6ID(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X.`IM
M<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R(")4:6ID<&QA;FYI;F<B"@HC
M.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM
M<V=S='(@(E1I:F1F;W)M86%T(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C4S,0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B5&EJ9'-E
M;&5C=&EE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS
M9W-T<B`B5&EM;W(M3&5S=&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS
M9VED(")4:71L92(*;7-G<W1R(")4:71E;"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L
M=&EP*3HB"FUS9W-T<B`B5&ET96P@*'1O;VQT:7`I.B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM
M<V=S='(@(D%A;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M
M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C
M*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*(D]M(&UE97)D
M97)E(&]N9&5R9&5L96X@=&4@<V5L96-T97)E;BP@:&]U9"!D92!#;VYT<F]L
M("A00RD@;V8@0V]M;6%N9"`H36%C*2`B"B)T;V5T<R!V87-T('1I:F1E;G,@
M:VQI:VME;BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P
M"FUS9VED(")4;V1A>2(*;7-G<W1R(")686YD86%G(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE
M($A434P@4V]U<F-E(@IM<V=S='(@(DA434P@8G)O;B!O;7-C:&%K96QE;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,C,*;7-G:60@(E1O9V\B"FUS9W-T<B`B5&]G;R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,C8*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B5&]K96QA=2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#(*;7-G:60@(E1O
M;6]R<F]W(@IM<V=S='(@(DUO<F=E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD*;7-G:60@
M(E1O;F=A(@IM<V=S='(@(E1O;F=A(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]K;VQA8BYP:'`Z,3`T"FUS9VED(")4;V\@;6%N>2!I;G9A;&ED(&QO9VEN
M<R!D=7)I;F<@=&AE(&QA<W0@;6EN=71E<RXB"FUS9W-T<B`B5&4@=F5E;"!O
M;F=E;&1I9V4@86%N;65L9&EN9V5N(&=E9'5R96YD92!D92!A9F=E;&]P96X@
M;6EN=71E;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#$*;7-G:60@(E1O<"(*;7-G<W1R(")";W9E;FMA;G0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS
M"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(D)O=F5N<W1E(&9R
M86UE("A?=&]P*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I
M9"`B5')A;G-L871I;VYS(@IM<V=S='(@(E9E<G1A;&EN9V5N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S,@IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R(")4
M<FEN:61A9"!E;B!4;V)A9V\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(E1R=64@;V8@
M9F%L<V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R(")$:2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C@*
M;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B5'5N97-IZR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S$*;7-G:60@(E1U<FME>2(*;7-G<W1R(")4=7)K:6IE(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI
M(@IM<V=S='(@(E1U<FMS("A)4T\M.#@U.2TY*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<*
M;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R(")4=7)K;65N:7-T86XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(P"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B
M"FUS9W-T<B`B5'5R:W,@96X@0V%I8V]S(&5I;&%N9&5N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S,PIM<V=I9"`B5'5V86QU(@IM<V=S='(@(E1U=F%L=2(*"B,Z(&9R86UE
M=V]R:R]#3$DO0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z
M("(*;7-G<W1R(")4>7`@=7<@:V5U>F4Z("(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-3@*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R
M(")5+E8N(&EN9&5X.B`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED
M(")54DPB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S
M8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R(")54DP@=F]O
M<B!U=R!A9FQE=F5R:6YG<W-T871U<W)A<'!O<G0@<V-R:7!T(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B
M55),.B(*;7-G<W1R(")54DPZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-PIM<V=I9"`B56=A
M;F1A(@IM<V=S='(@(D]E9V%N9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V"FUS9VED(")5
M:W)A:6YE(@IM<V=S='(@(D]E:W)A[VYE(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z-#$Y"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93(&1I<F5C=&]R
M>2!A86X@=&4@<W!R96ME;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I
M9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I
M;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(B(*(DYI970@
M:6X@<W1A870@97AT<F$@9V5B<G5I:V5R<VEN9F]R;6%T:64@=&]E('1E('9O
M96=E;B!B:6H@:6YS8VAR:6IV96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HS.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H
M86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(DYI970@:6X@<W1A870@9&4@<F5C:'1E;B!V86X@5D93(&)E<W1A;F0@7"(E
M<UPB('1E('=I:GII9V5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C,Y,B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F
M;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(DYI970@:6X@<W1A870@9&4@
M<F5C:'1E;B!V86X@5D93(&)E<W1A;F0@)7,O)7,@=&4@=VEJ>FEG96XN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW.#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B3FEE
M="!I;B!S=&%A="!T92!W:6IZ:6=E;B!N86%R("5S+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R(").
M:65T(&EN('-T86%T(&)E<W1A;F1S9W)O;W1T92!V86X@7"(E<UPB('1E(&-O
M;G1R;VQE<F5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Y
M-2!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,C@*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@U,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS
M9W-T<B`B3FEE="!I;B!S=&%A="!B97-T86YD<V=R;V]T=&4@=F%N(%PB)7,O
M)7-<(B!T92!C;VYT<F]L97)E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-Q;"YP:'`Z-#,Y"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@
M<V5R=F5R+B(*;7-G<W1R(").:65T(&EN('-T86%T(&UE="!D92!344P@<V5R
M=F5R('1E('9E<F)I;F1E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C@W,`IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN(@IM
M<V=S='(@(DYI970@:6X@<W1A870@;65T(%-33"!T92!V97)B:6YD96XN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,R(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(S-PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,C`T(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR
M,#D*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Q-PIM<V=I
M9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(DYI970@:6X@
M<W1A870@5D93(&)E<W1A;F0@=&4@:V]P:>MR96XN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HS-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B
M3FEE="!I;B!S=&%A="!61E,@9&ER96-T;W)Y(%PB)7-<(B!T92!M86ME;BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-C$@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,C8T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93(&1I<F5C=&]R
M>2!T92!M86ME;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R
M(").:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E(&UA:V5N+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S
M='(@(DYI970@:6X@<W1A870@5D93(&UA<"!<(B5S7"(@=&4@;6%K96XN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<R"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R(").:65T(&EN
M('-T86%T(&5E;B!L965G(%9&4R!B97-T86YD('1E(&UA:V5N+B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW.0HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H<#HW-@IM<V=I9"`B56YA
M8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B3FEE="!I;B!S=&%A
M="!D871A('5I="!T92!P86MK96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H
M92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R(").:65T(&EN('-T
M86%T(%PB)7-<(B!T92!V97)W:6ID97)E;BP@9&4@9&ER96-T;W)Y(&ES(&YI
M970@;&5E9R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HT-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(DYI970@:6X@<W1A870@7"(E
M<UPB.B`E<R!T92!V97)W:6ID97)E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HS,S@@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q
M,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,Y-2!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0R"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M
M<'1Y(@IM<V=S='(@(DYI970@:6X@<W1A870@)7,@=&4@=F5R=VEJ9&5R96XL
M(&1E(&1I<F5C=&]R>2!I<R!N:65T(&QE96<B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,S4V(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HS-C`*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!61E,@
M9&ER96-T;W)Y(')E8W5R<VEE9B!T92!V97)W:6ID97)E;BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-#0@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,S,U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").:65T(&EN('-T86%T
M(%9&4R!D:7)E8W1O<GD@=&4@=F5R=VEJ9&5R96XN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HT,C`@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HT,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!61E,@
M9&ER96-T;W)Y("5S('1E('9E<G=I:F1E<F5N+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,C$R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").:65T(&EN
M('-T86%T(%9&4R!B97-T86YD(%PB)7-<(B!T92!V97)W:6ID97)E;BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,3`@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C$V-PHC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3@P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR.3$@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,Y,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,SDY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE
M+B(*;7-G<W1R(").:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E('9E<G=I
M:F1E<F5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C0X"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E
M<B!<(B5S7"(N(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93(&UA<"!<(B5S
M7"(@=&4@=F5R=VEJ9&5R96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HT,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R(").:65T(&EN('-T86%T
M(%9&4R`E<R!R96-U<G-I968@=&4@=F5R=VEJ9&5R96XN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HX,S0*;7-G:60@(E5N86)L92!T;R!D971E
M<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(DYI970@:6X@<W1A
M870@:'5I9&EG92!D:7)E8W1O<GD@=&4@8F5P86QE;BXB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8P-`IM<V=I9"`B56YA8FQE('1O
M(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R(").:65T(&EN
M('-T86%T(&-E<G1I9FEC86%T9&5T86EL<R!U:70@=&4@9FEL=&5R96XB"@HC
M.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#,W(&9R86UE=V]R:R].
M971?24U34"])35-0+T%U=&@N<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T
M<B`B3FEE="!I;B!S=&%A="!O;2!D92!D969I;FET:64@=F%N("5S('1E(&QA
M9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P,R!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#@*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$W-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS
M9W-T<B`B3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T92!V97)P;&%A='-E
M;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z.3,*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HQ,#8@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV-3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R(").:65T(&EN('-T86%T(%9&4R!B97-T86YD(%PB)7-<(B!T
M92!O<&5N96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@T
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T,0IM<V=I9"`B56YA8FQE('1O
M(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(DYI970@:6X@
M<W1A870@5D93(&)E<W1A;F0@=&4@;W!E;F5N('9O;W(@<V-H<FEJ=F5N+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@S(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C$S-PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z-S8*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*
M;7-G<W1R(").:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E(&]P96YE;BXB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C0U"FUS
M9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S
M='(@(DYI970@:6X@<W1A870@:&5T(&EN9V5P86MT92!B97-T86YD('1E(&]P
M96YE;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#4V"FUS9VED(")5
M;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+B(*
M;7-G<W1R(").:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E(&QE>F5N("AF
M:6QE<VEZ92@I(&UI<VQU:W0I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HX.#<*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE
M4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93(&)E
M<W1A;F0@=&4@;&5Z96X@*&=E=$9I;&53:7IE*"D@;6ES;'5K="DN(@H*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N
M<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B
M3FEE="!I;B!S=&%A="!B97-T86YD('1E(&QE>F5N.B`B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HV-S8*;7-G:60@(E5N86)L92!T;R!R96%D
M('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B3FEE="!I;B!S=&%A
M="!V9G-R;V]T(&1I<F5C=&]R>2!T92!O<&5N96XN(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,3`Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A
M;')E861Y(&5X:7-T<R(*;7-G<W1R(").:65T(&EN('-T86%T(&]M("5S('1E
M(&AE<FYO96UE;B!N86%R("5S.B!B97-T96UM:6YG<VUA<"!B97-T86%T(&%L
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P,0IM<V=I
M9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").
M:65T(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@=&4@:&5R;F]E;65N+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S,R"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM
M<V=S='(@(DYI970@:6X@<W1A870@5D93(&1I<F5C=&]R>2`E<R!T92!H97)N
M;V5M96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-#@@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-S$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(DYI970@:6X@<W1A870@5D93(&)E<W1A;F0@7"(E<UPB('1E(&AE<FYO96UE
M;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV,3<@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(").
M:65T(&EN('-T86%T(%9&4R!B97-T86YD("5S+R5S('1E(&AE<FYO96UE;BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HT-3(*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HS,C8@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Y
M,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Y"FUS9VED
M(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R(").:65T(&EN
M('-T86%T(%9&4R!B97-T86YD('1E(&AE<FYO96UE;BXB"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G
M:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R(")+86X@)VUK
M:7-O9G,G(&YI970@=6ET=F]E<F5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T<F%N
M<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(DYI970@:6X@<W1A
M870@9&ET(%=O<F0@9&]C=6UE;G0@=&4@=F5R=&%L96XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C$U-"!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C$U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").:65T(&EN('-T86%T(%9&4R!B
M97-T86YD(%PB)7-<(B!T92!S8VAR:6IV96XN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,3@V"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R(").:65T(&EN('-T86%T
M(%9&4R!B97-T86YD('1E('-C:')I:G9E;B`H8V]P>2@I(&9A:6QE9"DN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@X(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#8*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C$U,0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F
M:6QE(&1A=&$N(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93(&)E<W1A;F1S
M9&%T82!T92!S8VAR:6IV96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C@V,@IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W
M:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R(").:65T(&EN('-T86%T(%9&4R!B
M97-T86YD('1E('-C:')I:G9E;BP@<75O=&$@=V]R9'0@;W9E<G-C:')E9&5N
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R(")/;F1E<G-T<F5P96XB"@HC
M.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG
M97,B"FUS9W-T<B`B2&5R<W1E;"!W:6IZ:6=I;F=E;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E
M<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(D1O970@=7<@;&%A='-T92!B
M97=E<FMI;F<@=&5N:65T(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,X.`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M
M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B3VYV97)W86-H="!A
M;G1W;V]R9"!V86X@9&4@<V5R=F5R(&]P('9E<F)I;F1I;F<Z("(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q-PHC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,SD*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<V"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,@IM<V=I9"`B56YE>'!E
M8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(D]N=F5R
M=V%C:'0@86YT=V]O<F0@=F%N('-E<G9E<B!A86XZ("(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED(")5
M;F9I;&5D(@IM<V=S='(@(D]N8F5N;V5M9"(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DV"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B56YI
M8V]D92`H551&+3@I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<*;7-G:60@(E5N:71E9"!!<F%B
M($5M:7)A=&5S(@IM<V=S='(@(E9E<F5N:6=D92!!<F%B:7-C:&4@16UI<F%T
M96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S@*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S
M='(@(E9E<F5N:6=D($MO;FEN9VMR:6IK(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,`IM<V=I
M9"`B56YI=&5D(%-T871E<R(*;7-G<W1R(")697)E;FEG9&4@4W1A=&5N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S.0IM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L
M>6EN9R!)<VQA;F1S(@IM<V=S='(@(E9E<F5N:6=D92!3=&%T96XL(&ML96EN
M92!B=6ET96X@;&EG9V5N9&4@96EL86YD96XB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C<X(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV,@IM<V=I
M9"`B56YI=',B"FUS9W-T<B`B165N:&5D96XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C4X(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0R.0HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,S`*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B3VYB96ME;F0B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*
M;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS
M9W-T<B`B3VYB96ME;F0@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$
M*2XB"FUS9W-T<B`B3VYB96ME;F0@8VQI;7-G:60@*$-L:65N="!-97-S86=E
M($E$*2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30W"FUS
M9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")/;F)E
M:V5N9&4@;&]C871I92!O<&=E9V5V96XN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N
M('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R(")/;F)E:V5N9&4@9V5B
M<G5I:V5R<VYA86T@;V8@=V%C:'1W;V]R9"XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N
M;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(DAE="!H=6ED:6=E
M(&5L96UE;G0@;&]S:V]P<&5L96XB"@HC.B!F<F%M97=O<FLO261E;G1I='DO
M261E;G1I='DN<&AP.C,P,@IM<V=I9"`B56YN86UE9"(*;7-G<W1R(")/;F)E
M;F]E;60B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@
M86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB
M<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A
M;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@
M=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM
M<V=S='(@(B(*(DYI970@9V5R96-H=&EG9&4@<V-R:7!T<R!K=6YN96X@<')O
M9W)A;6UA;6%T:6<@;FEE="!+;FEP<&5N+TMO<&GK<F5N+R(*(E!L86MK96XL
M('9A;G=E9V4@8F5V96EL:6=I;F=S<F5D96YE;BX@2VQI:R!O<"!/2R!O;2!E
M96X@=&5C:&YI<V-H92!O<&UE<FMI;F<@(@HB;W`@;6]Z:6QL82YO<F<@=&4@
M8F5K:6IK96X@:&]E('4@965N('-C<FEP="!T;V5S=&%A="!H970@<')I:V)O
M<F0@=&4@(@HB8F5N861E<F5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R
M(@IM<V=S='(@(DML975R('1E<G5G<W1E;&QE;B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C@W(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z.3(W"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z.3,S"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T
M<B`B3FEE="!O;F1E<G-T975N9&4@97AT96YT:64B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@(D)I:G=E<FME;B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(B5S(&)I:G=E<FME
M;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*;7-G
M:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(D=E8G)U:6ME<B!B:6IW97)K96XN
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP
M:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(EPB)7-<(B!B
M:6IG97=E<FMT+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS
M9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R(")5<&=R861E
M('-C<FEP="!V97)W:6ID97)D+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-S@@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y
M.`IM<V=I9"`B57!L;V%D(@IM<V=S='(@(E5P;&]A9"(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A
M=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R(")!;&QE
M('1O97!A<W-I;F<@<V5T=7!B97-T86YD96X@;F%A<B!D92!S97)V97(@9V5U
M<&QO860N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*
M;7-G<W1R("),871I:FYS92!H;V]F9&QE='1E<G,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED
M(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(D=R;W1E(%)O;65I;G-E
M(&=E=&%L;&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,0IM<V=I9"`B57)U9W5A>2(*;7-G
M<W1R(")5<G5G=6%Y(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U
M<G)E;G0Z("5S(@IM<V=S='(@(D=E8G)U:6L@:'5I9&EG93H@)7,B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM
M<V=I9"`B57-E(%-33"(*;7-G<W1R(")'96)R=6EK(%-33"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,C<*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W
M;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(D=E
M8G)U:6ME;B!W86YN965R(&YA86TO=V%C:'1W;V]R9"!V97)S8VAI;'0@;65T
M($E-4U`@<V5R=F5R+B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I
M="YI;F,Z,C$*;7-G:60@(E5S97(B"FUS9W-T<B`B1V5B<G5I:V5R(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW-S0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@
M)7,N(@IM<V=S='(@(D=E8G)U:6ME<B`E<R!I<R!N:65T(&=E875T;W)I<V5E
M<F0@=F]O<B`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S
M97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B1V5B<G5I:V5R<V)E:&5E<B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C0U"FUS9VED(")5
M<V5R($]P=&EO;G,B"FUS9W-T<B`B1V5B<G5I:V5R<V]P=&EE<R(*"B,Z('-I
M9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@
M(D=E8G)U:6ME<G-R96=I<W1R871I92(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G
M:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T
M:&ES('-I=&4N(@IM<V=S='(@(D=E8G)U:6ME<G-R96=I<W1R871I92!I<R!U
M:71G97-C:&%K96QD(&]P(&1E>F4@<VET92XB"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-#DT"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM
M<V=S='(@(D=E8G)U:6ME<G-A8V-O=6YT(&YI970@9V5V;VYD96XN(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ
M.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?
M<VUT<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HQ-3`@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B1V5B
M<G5I:V5R<VYA86TB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A
M;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B1V5B<G5I:V5R<VYA86T@7"(E<UPB
M(&)E<W1A870@86PN(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B1V5B<G5I:V5R<VYA86TZ
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E
M<FYA;64Z("(*;7-G<W1R(")'96)R=6EK97)S;F%A;3H@(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE
M('-Y<W1E;3HB"FUS9W-T<B`B1V5B<G5I:V5R<R!I;B!H970@<WES=&5E;3HB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0R"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(D]E
M>F)E:VES=&%N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3<P
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(V,@IM<V=I9"`B5D93(&1I
M<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B5D93(&1I<F5C=&]R
M>2!B97-T86%T(&YI970N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$R,`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B069W97II9VAE:60B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-C8*;7-G:60@(E9A;&ED(&QO
M8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B1V5V;VYD96X@9V5L
M9&EG92!L;V-A=&EE<R!B979A='1E;CH@(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@
M(D=E;&1I9VAE:60B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR-34*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU.3<*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@
M9G)O;2!N;W<N(@IM<V=S='(@(E=A87)D92!I;B!M:6YU=&5N('9A;F%F(&YU
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@U-B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E
M(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R(")7
M86%R9&4@;&EG="!B;W9E;B!D92!M87AI;75M(&QE;F=T92!V86X@)7,N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDQ,`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU97,B
M"FUS9W-T<B`B5V%A<F1E;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q,#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-@IM<V=I9"`B5F%L
M=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(E=A87)D96X@=V%A<G5I="!G
M97-E;&5C=&5E<F0@:V%N('=O<F1E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D*;7-G:60@
M(E9A;G5A='4B"FUS9W-T<B`B5F%N=6%T=2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,S,*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(E9A
M<FEA8F5L92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4*;7-G:60@(E9E;F5Z=65L82(*;7-G
M<W1R(")696YE>G5E;&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@
M;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@
M(E9E<FEF:6-A=&EE(&UI<VQU:W0@+2!E<B!K86X@;65T(&1I="!B97)I8VAT
M(&=E:VYO96ED('II:FXN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HW,#$*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B5F5R<VEE(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R.`IM<V=I9"`B5F5R<VEO
M;B!#;VYT<F]L(@IM<V=S='(@(E9E<G-I96-O;G1R;VQE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I
M9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B5F5R=&EK86%L('5I=&QI:FYE
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B5F5R=&EK86QE
M('9R:6IE(')U:6UT92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R(")697)T
M:6MA86PZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-S(*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R(")%<F<@:&]O9R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#@*;7-G:60@(E9I970@3F%M(@IM<V=S='(@(E9I971N86TB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-PIM<V=I9"`B5FEE=&YA;65S
M92`H5DE30TE)*2(*;7-G<W1R(")6:65T;F%M965S("A625-#24DI(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.3<Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B)7,@8F5K:6IK96XB"@HC
M.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R
M;F%L('=E8B!P86=E(@IM<V=S='(@(D)E:VEJ:R!E96X@97AT97)N92!W96)P
M86=I;F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX
M,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R(")"
M96MI:FME;B!A;',@)7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V"FUS9VED(")6:7)G:6X@
M27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R(")-86%G9&5N(&5I;&%N9&5N+"!"
M<FET<V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0W"FUS9VED(")6:7)G:6X@27-L86YD<RP@
M52Y3+B(*;7-G<W1R(")-86%G9&5N(&5I;&%N9&5N+"!6+E,N(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,38*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T
M<B`B6FEC:'0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4R
M"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B6FEC:'0Z("(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T
M"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R(")6;V1A
M9F]N92!)=&%L>2!V:6$@4TU44"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@
M(E=!4DXB"FUS9W-T<B`B5T%23B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%
M(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R(")704%24T-(55=)
M3D<A(2$@(%9%4E=)2D1%4B!30U))4%0@2$%.1$U!5$E'(%5)5"`E<RXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S,PIM<V=I
M9"`B5TE.('9I82!(5%10(@IM<V=S='(@(E=)3B!V:6$@2%144"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-3`*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(E=A
M;&QI<R!E;B!&=71U;F$B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R-R!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z.34*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B5V%A<G-C:'5W
M:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B5V\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS
M9W-T<B`B5V5E<G-V;V]R=6ET>FEC:'0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-#$V"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@
M8GDB"FUS9W-T<B`B5V5E<F)E<FEC:'0@9V5G979E;G,@9V5L979E<F0@9&]O
M<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A
M=&AE<BYC;VTB"FUS9W-T<B`B5V5A=&AE<BYC;VTB"@HC.B!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(E=E8B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,SD*;7-G:60@(E=E8B!3:71E(@IM
M<V=S='(@(E=E8G-I=&4B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I
M;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B5V5K96QI
M:FMS(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@
M(E=E;&-O;64B"FUS9W-T<B`B5V5L:V]M(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHU-R!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT"B,L
M('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B5V5L
M:V]M(&)I:B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y
M('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")796QC;VUE+"`E<R(*;7-G<W1R(")796QK;VTL("5S(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3@*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y
M+3$I(@IM<V=S='(@(E=E<W1E<G,@*$E33RTX.#4Y+3$I(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.3D*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U
M*2(*;7-G<W1R(")797-T97)S("A)4T\M.#@U.2TQ-2DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M.`IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B5V5S=&5L:6IK92!3
M86AA<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L
M87D@869T97(@;&]G:6X_(@IM<V=S='(@(E=E;&ME('1O97!A<W-I;F<@9&EE
M;G0@)7,@=V5E<B!T92!G979E;B!N82!A86YM96QD:6YG/R(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H92!D
M96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R(")7870@:7,@:&5T('-C:&5I
M9&EN9W-K87)A:W1E<C\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G
M<W1R(")7870@:7,@:&5T(&-I=&%A=&MA<F%K=&5R/R(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#8U"FUS9VED(")7:&5R
M96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`B5VAE<F5I<R!!=7-T<F%L:>L@
M:V%A<G0B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H
M('!H87-E<R(*;7-G<W1R(")796QK92!F87-E;B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,S8*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE
M(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B5V5L:V4@<&QU
M9VEN<R!V;V]R(&1E(%)I8V@@5&5X="!E9&ET;W(@:6YS8VAA:V5L96XN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B0G)E961T92(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#<*;7-G:60@(E=I9'1H(&EN($-34R!U
M;FET<R(*;7-G<W1R(")"<F5E9'1E(&EN($-34R!E96YH961E;B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C
M="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*(D)R965D=&4@=F%N(&AE
M="`E<R!M96YU(&%A;B!D92!L:6YK97)K86YT("AA:W1I968@8FEJ('9O;&=E
M;F1E(&%A;FUE;&1I;F<I.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B
M"FUS9W-T<B`B0G)E961T92!V86X@9&4@=&%B96PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@
M=6YI="(*;7-G<W1R(")"<F5E9'1E(&5E;FAE:60B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z
M(@IM<V=S='(@(D)R965D=&4Z(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C4Q-0IM<V=I9"`B5VEK:2(*;7-G<W1R(")7:6MI(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(X.2!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B5VEN9"(*;7-G<W1R(")7:6YD
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*
M;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B5VEN9"!V<F]E9R(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z.#<*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO
M=',B"FUS9W-T<B`B5VEN9'-N96QH96ED(&EN(&MN;W!E;B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,38S"FUS9VED(")7:6YD.B(*;7-G<W1R(")7:6YD
M.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@
M(E=I;F0Z("(*;7-G<W1R(")7:6YD.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R(")7:6IS:&5I9"(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.3@*;7-G:60@(E=I<VAL:7-T
M(@IM<V=S='(@(E=E;G-L:6IS="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R(")797)K(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D
M9')E<W,B"FUS9W-T<B`B5V5R:V%D<F5S(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*
M;7-G<W1R(")496PN;G(N("AW97)K*2(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C$Y,R!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR.30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I
M;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(E9E
M<FME97)D(&%A;G1A;"!V96QD96X@:6X@<F5G96P@)60N(%9E<G=A8VAT("5D
M+"!G979O;F1E;B`E9"XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I
M96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R(")697)K965R
M9"!A86YT86P@=F5L9&5N+B!697)W86-H="`E9"P@9V5V;VYD96X@)60N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3(Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93
M(&9I;&4N(@IM<V=S='(@(E9E<FME97)D92!O9F9S970@)60@8FEJ(&QE>F5N
M('9A;B!61E,@8F5S=&%N9"XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C0U"FUS9VED(")8+5)E9B(*;7-G<W1R(")8+5)E9B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@
M0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B6#4P.78S(&)A<VES8F5P97)K
M:6YG96XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y
M,PIM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R(")8
M-3`Y=C,@=6ET9V5B<F5I9"!S;&5U=&5L9V5B<G5I:R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B
M:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(E@U,#EV,R!A;'1E<FYA
M=&EE=F4@;VYD97)W97)P;F%A;2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DV"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E
M;G1I9FEE<B(*;7-G<W1R(")8-3`Y=C,@;VYD97)W97)P('-L975T96QI9&5N
M=&EF:6-A=&]R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV.#,*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(E@U,#EV
M,R!E>'1E;G1I97,B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B
M65DB"FUS9W-T<B`B2DHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-38*;7-G:60@(EE965DB"FUS9W-T<B`B2DI*2B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3$Q"FUS
M9VED(")986AO;R$@;6%P(@IM<V=S='(@(EEA:&]O(2!M87`B"@HC.B!F<F%M
M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")9
M96%R;'DB"FUS9W-T<B`B2F%A<FQI:FMS(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,@IM<V=I
M9"`B665M96XB"FUS9W-T<B`B2F5M96XB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38V"FUS9VED(")997,B"FUS9W-T<B`B
M2F$B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M
M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(DIA+"!I:R!A8V-E
M<'1E97(@9&4@=F]O<G=A87)D96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@
M34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@
M5UE325=91RXB"FUS9W-T<B`B(@HB52!B96YT(&EN(%1%2U-4($U/1$4N($=E
M8G)U:6L@9&4@6SP^72!K;F]P(&]M(&YA87(@5UE325=91R!T97)U9R!T92`B
M"B)S8VAA:V5L96XN(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HR,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R
M92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB
M"FUS9W-T<B`B2&5T(&ES('4@;FEE="!T;V5G97-T86%N(&]M(&UE97(@9&%N
M("5D(&)L;VMK96X@=&4@;6%K96XN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ-#(T"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D
M+B(*;7-G<W1R(")5(&)E;G0@;FEE="!G96%U=&AE;G1I9FEC965R9"XB"@HC
M.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P.`IM<V=I9"`B
M66]U(&-A;FYO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U
M;&P@;F%M92XB"FUS9W-T<B`B52!K=6YT(&=E96X@)UQ<)R!K87)A:W1E<B!I
M;B!U=R!V;VQL96=E(&YA86T@:&5B8F5N+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW-0IM
M<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S
M+B(*;7-G<W1R(")5(&AE969T(&=E96X@9V5L9&EG(&4M;6%I;&%D<F5S(&]P
M9V5G979E;BXB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD
M<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG
M(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@HB52!H965F="!G965N('9E
M;&1E;B!U:70@:&5T(&=E:6UP;W)T965R9&4@8F5S=&%N9"!G96MO<'!E;&0@
M;65T(&1E("(*(F]V97)E96YK;VUS=&EG92!V96QD96X@:6X@)7,N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@W"FUS9VED(")9;W4@:&%V92!B
M965N(&QO9V=E9"!O=70N(@IM<V=S='(@(E4@8F5N="!A9F=E;65L9"XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@
M:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET
M<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N
M871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@HB52!D:65N="!E
M96X@9V5L9&EG(&UO8FEE;"!N=6UM97(@:6X@=&4@=F]E<F5N+"!A;&QE96X@
M8VEJ9F5R<R!M970@965N("(*(F]P=&EO;F5L92`G*R<@=F]O<B!H970@:6YT
M97)N871I;VYA;&4@:VEE<W9O;W)V;V5G<V5L+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q.#@*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@=F%L=64N(@IM<V=S='(@(E4@9&EE;G0@965N(&=E;&1I9V4@=V%A
M<F1E(&]P('1E(&=E=F5N+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R
M964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B(@HB52!D:65N
M="!E96X@1&%T851R964@8F%C:V5N9"!T92!C;VYF:6=U<F5R96X@;VT@:6YS
M8VAR:6IV:6YG96X@=&4@:W5N;F5N("(*(F=E8G)U:6ME;BXB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0W,0IM<V=I9"`B66]U(&UU<W0@8V]N
M9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(E4@9&EE;G0@965N(%9&
M4R!B86-K96YD('1E(&-O;F9I9W5R97)E;BXB"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@
M=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R
M97!O<G0N(@IM<V=S='(@(B(*(E4@9&EE;G0@:&5T('!R;V)L965M('1E(&)E
M<V-H<FEJ=F5N+"!V;V]R9&%T('4@:&5T('!R;V)L965M<F%P<&]R="!K=6YT
M("(*(G9E<GIE;F1E;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),
M('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B52!D:65N="!E
M96X@55),(&EN('1E('9O97)E;B!W86%R;F%A<B!D97IE(&QI;FL@=F5R=VEJ
M<W0B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B
M66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G
M<W1R(")5(&1I96YT(&5E;B!S97)V97(@=&4@<V5L96-T97)E;B!O;2!T92!V
M97)W:6ID97)E;BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S
M='(@(E4@9&EE;G0@965N(&=E8G)U:6ME<G-N86%M(&]P('1E(&=E=F5N(&]M
M('1E('=I<W-E;BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@
M(E4@9&EE;G0@965N(&=E8G)U:6ME<G-N86%M(&]P('1E(&=E=F5N(&]M('1E
M('9E<G=I:F1E<F5N+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R(")5(&1I96YT(&5E
M;B!G96)R=6EK97)S;F%A;2!O<"!T92!G979E;B!O;2!T;V4@=&4@=F]E9V5N
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R(")5(&1I96YT
M(&5E;B!G96)R=6EK97)S;F%A;2!O<"!T92!G979E;B!O;2!B:6H@=&4@:W5N
M;F5N('=E<FME;BXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I
M;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B52!D:65N="!E96X@8F5W97)K:6YG
M(&]P('1E(&=E=F5N('=E;&ME('5I=&=E=F]E<F0@;6]E="!W;W)D96XN(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-S$*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB
M"FUS9W-T<B`B52!D:65N="!E96X@;FEE=7=E(&-A=&5G;W)I96YA86T@;W`@
M=&4@9V5V96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE
M:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@
M86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B52!D:65N="!E96X@
M271A;&EA86YS('1E;&5F;V]N;G5M;65R(&]P('1E(&=E=F5N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3<U"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G
M86EN+B(*;7-G<W1R(")5=R`E<R!S97-S:64@:7,@=F5R;&]P96XN($]P;FEE
M=7<@86%N;65L9&5N+"!A+G4N8BXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S
M='(@(E5W(&4M;6%I;&%D<F5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(Q-0IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")5=R!6
M86XZ(&%D<F5S.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-R!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@U
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,@IM<V=I9"`B66]U<B!);F9O
M<FUA=&EO;B(*;7-G<W1R(")5=R!I;F9O<FUA=&EE(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO
M=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G
M:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R
M('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB
M57<@:6YT97)N971A9')E<R!I<R!G97=I:GII9V0@<VEN9',@:&5T(&)E9VEN
M('9A;B!U=R`E<R!S97-S:64N($]M('5W("(*(G9E:6QI9VAE:60@=&4@8F5S
M8VAE<FUE;BP@9&EE;G0@=2!Z:6-H(&]P;FEE=7<@86%N('1E(&UE;&1E;BXB
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B
M66]U<B!.86UE(@IM<V=S='(@(E5W(&YA86TZ(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC
M871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@
M268@>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E
M<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*(DAE="!T;V5V;V5G96X@
M=F%N(&=E8G)U:6ME<G,@=V]R9'0@;FEE="!O;F1E<G-T975N9"!D;V]R('5W
M(&%U=&AE;G1I8V%T:64@(@HB8F%C:V5N9"X@5V%N;F5E<B!U($AO<F1E(&=E
M8G)U:6ME<G,@=VEL="!B96AE<F5N+"!D:65N="!U(&5E;B!A;F1E<B`B"B)A
M=71H96YT:6-A=&EE(&)A8VME;F0@=&4@9V5B<G5I:V5N+B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A
M=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN
M9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@
M9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"B)(970@=V5E<F=E
M=F5N('9A;B!E96X@9V5B<G5I:V5R<VQI:G-T('=O<F1T(&YI970@;VYD97)S
M=&5U;F0@9&]O<B!U=R`B"B)A=71H96YT:6-A=&EE(&)A8VME;F0L(&]F(&1E
M>F4@;W!T:64@:7,@;VT@86YD97)E(')E9&5N96X@=6ET9V5S8VAA:V5L9"XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N
M9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B
M"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G
M86EN+B(*;7-G<W1R("(B"B)5=R!B<F]W<V5R(&QI:FMT('1E('II:FX@9V5W
M:6IZ:6=D('-I;F1S(&AE="!B96=I;B!V86X@=7<@)7,@<V5S<VEE+B!/;2!U
M=R`B"B)V96EL:6=H96ED('1E(&)E<V-H97)M96XL(&1I96YT('4@>FEC:"!O
M<&YI975W(&%A;B!T92!M96QD96XN(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP
M:'`Z-3<*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H
M:7,@9F5A='5R92XB"FUS9W-T<B`B57<@8G)O=W-E<B!O;F1E<G-T975N="!D
M97IE(&UO9V5L:6IK:&5I9"!N:65T+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N
M;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#
M;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@HB57<@8G)O=W-E
M<B!O;F1E<G-T975N="!D97IE('!R:6YT;W!T:64@;FEE="X@1')U:R!O<"!#
M;VYT<F]L+T-O;6UA;F0@*R!0(&]M("(*(F%F('1E(&1R=6MK96XN(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V,0IM<V=I9"`B66]U<B!C=7)R96YT
M('1I;64@>F]N93HB"FUS9W-T<B`B57<@:'5I9&EG92!T:6ID>F]N93HB"@HC
M.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3$W"FUS9VED(")9;W5R(&1E9F%U;'0@
M:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`B57<@<W1A;F1A
M87)D(&ED96YT:71E:70@:7,@9V5W:6IZ:6=D+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-C$*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB
M"FUS9W-T<B`B57<@<W1A;F1A87)D(&ED96YT:71E:70Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(P-`IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM
M<V=S='(@(E5W('9O;&QE9&EG92!N86%M.B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDY.0IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB
M"FUS9W-T<B`B57<@86%N;65L9&EN9R!I<R!V97)L;W!E;BXB"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(E5W
M(&YI975W92!W86-H='=O;W)D('9O;W(@)7,@:7,Z("5S(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@;W!T:6]N
M<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@
M<V5S<VEO;BXB"FUS9W-T<B`B57<@;W!T:65S('II:FX@8FEJ9V5W97)K="!V
M;V]R(&1E(&1U=7(@=F%N(&1E>F4@<V5S<VEE+B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V
M92!B965N('5P9&%T960N(@IM<V=S='(@(E5W(&]P=&EE<R!Z:6IN(&)I:F=E
M=V5R:W0N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G
M:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B57<@
M=V%C:'1W;V]R9"!I<R!G97)E<V5T(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@
M<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@
M;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B"B)5=R!W86-H='=O;W)D(&ES
M('9E<FYI975W9"P@8V]N=')O;&5E<B!U=R!E+6UA:6P@96X@;65L9"!A86X@
M;65T('5W(&YI975W92`B"B)W86-H='=O;W)D+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.C<S,PIM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP
M:7)E9"XB"FUS9W-T<B`B57<@=V%C:'1W;V]R9"!I<R!V97)L;W!E;BXB"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@
M<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(E5W('-E<G9E<G,@;W`@869S=&%N
M9#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4T"FUS9VED(")9=6=O<VQA=FEA(@IM
M<V=S='(@(DIO96=O<VQA=FGK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B6F'O<F4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4V"FUS9VED("):86UB:6$B"FUS9W-T<B`B6F%M8FEA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(U-PIM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B6FEM8F%B=V4B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM
M<V=S='(@(EII<'!Y(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E
M<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E
M>'1=(@IM<V=S='(@(EM697)B97)G(&%A;F=E:&%A;&1E('1E:W-T72(*"B,Z
M('-E<G9I8V5S+W!R;V)L96TN<&AP.C@Y"FUS9VED(");4')O8FQE;2!297!O
M<G1=(@IM<V=S='(@(EM0<F]B;&5E;7)A<'!O<G1=(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U
M;W1E9"!497AT("TB"FUS9W-T<B`B6T%A;F=E:&%A;&1E('1E:W-T('=E97)G
M979E;B`M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H
M;&EG:'1Q=6]T97,N<&AP.C$W-`HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO
M=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");06%N9V5H86%L
M9&4@=&5K<W0@+2`E<R!R96=E;'-=(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HR,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@
M)7-=(@IM<V=S='(@(EMR96=E;"`E<R!V86X@)7-=(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ-34T('1E;7!L871E<R]P;W)T86PO;65N=2YI
M;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")"7V5H965R
M(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(E]#
M3$DB"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*;7-G
M<W1R(")?1&%T851R964B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM
M<V=S='(@(E9E<E]W:6ID97(@<FEJ(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS
M9VED(")?1W)O=7!S(@IM<V=S='(@(E]'<F]E<&5N(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0IM<V=I9"`B7TAE;'`B"FUS9W-T
M<B`B7TAE;'`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN
M(@IM<V=S='(@(E]!9F)E96QD:6YG<V5I9V5N<V-H87!P96XN+BXB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED(")?3&]G
M(&EN(@IM<V=S='(@(E]!86YM96QD96XB"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O365N=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*;7-G<W1R(")?
M069M96QD96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G
M<W1R(")?5VEJ>FEG(&QI;FLN+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R(")?3W!T
M:65S(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B7U)E8VAT96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN
M:RXN+B(*;7-G<W1R(")?5F5R=VEJ9&5R(&QI;FLN+BXB"@HC.B!L:6(O87!I
M+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R(")?26YS=&5L;&5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")?
M5&%B96QE:6=E;G-C:&%P<&5N+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS
M9VED(")?57-E<G,B"FUS9W-T<B`B1V5?8G)U:6ME<G,B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDR-0IM<V=I9"`B861D<F5S<R!B;V]K(@IM
M<V=S='(@(D%D<F5S8F]E:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R
M(")'96%D<F5S<V5E<F1E(&]N8F5K96YD(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,3<*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(DMA;&5N
M9&5R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-SD@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS-C4*;7-G:60@(F-A;&TB"FUS9W-T<B`B2V%L;2(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN
M;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(DMA;B!O=71P=71B97-T
M86YD(&YI970@;6%K96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B
M2V%N(&EN<'5T(&YI970@;W!E;F5N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z-C`P"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@
M(DML:6L@:&EE<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T
M<B`B0V]M;6%N9&]R96=E;"!G96)R=6EK<V9O=70B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$W.`IM<V=I9"`B8V]N9FEG=7)A=&EO
M;B!E<G)O<B(*;7-G<W1R(")#;VYF:6=U<F%T:65F;W5T(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L
M('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B2W)I=&ES8V@@<WES=&5E
M;6)E<W1A;F0@;VYT8G)E96MT(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S
M='(@(D1A=&%F;W)M86%T9F]U="(*"B,Z('1E;7!L871E<R]P;W)T86PO961I
M="YI;F,Z,S`*;7-G:60@(F5D:70B"FUS9W-T<B`B8F5W97)K96XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT
M<GD@;F]T(&9O=6YD(@IM<V=S='(@(FEN=F]E<B!N:65T(&=E=F]N9&5N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*;7-G
M:60@(F9A;&QI;F<B"FUS9W-T<B`B9&%L96YD(@H*(SH@9G)A;65W;W)K+T)R
M;W=S97(O0G)O=W-E<BYP:'`Z.#DX"FUS9VED(")F:6QE(@IM<V=S='(@(F)E
M<W1A;F0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X,2!L:6(O0FQO8VLO
M;65T87(N<&AP.C,V-R!L:6(O0FQO8VLO;65T87(N<&AP.C,Y,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S
M='(@(G9A;B!D92`E<R`H)7,I(&]P("5S("5S(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S.0IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R(")V
M;&%G97)I9R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR-3`*;7-G:60@(F@Z(@IM<V=S='(@(F@Z(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.0IM<V=I9"`B:&@B"FUS
M9W-T<B`B:&@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B:&]S=&YA
M86T@;VYB96ME;F0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-C4*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R
M(")O;FUI9&1E;&EJ:R(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B
M:6YL:6YE(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-C(*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R(")I;G!U="]O
M=71P=70@9F]U="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R
M(")I;G1E<FYE('-O9G1W87)E9F]U="(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B
M<F5G96QS72(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S
M(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B;6MI
M<V]F<R!F;W5T8V]D92`E9"!B:6H@:&5T(&%A;FUA:V5N('9A;B!)4T\N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W,`IM
M<V=I9"`B;6TB"FUS9W-T<B`B;6TB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C(X-2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR-#$*;7-G:60@(FYA
M;64B"FUS9W-T<B`B;F%A;2(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ
M,C0*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R(")N:65T('9A;B!T
M;V5P87-S:6YG(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HQ,C(P"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(DYO
M9R!N:65T('9A;B!T;V5P87-S:6YG(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,#D*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B;F]T:71I96)O
M96LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@(G!R;V-E;G0B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B
M<&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`B4F5C:'0@9V5W96EG97)D(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(G!I>&5L<R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@
M97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B4F5M;W1E(&9O=70@:6X@<')O
M=&]C;VPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW-0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(G-T:6IG96YD(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E<G9I
M8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B4V5R=FEC92!N:65T(&)E<V-H:6MB
M86%R(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HQ,#$*;7-G:60@(G-H
M;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B=&]O;B!V97)S8VAI;&QE;B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T
M"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T<B`B<VUS,F5M86EL
M('9I82!(5%10(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C,X-PIM<V=I9"`B<W,B"FUS9W-T<B`B<W,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW-`IM<V=I9"`B<W1E861Y
M(@IM<V=S='(@(G-T86)I96PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(G-Y
M<W1E96UF;W5T(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S,*
M;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R(")T86ME;FQI:G-T(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O
M<F%R>2!F86EL=7)E(@IM<V=S='(@(G1I:F1E;&EJ:V4@;6ES;'5K:VEN9R(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HR-S`*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O
M(&-O;F9I<FTB"FUS9W-T<B`B5F]E<BP@=&5R(&)E=F5S=&EG:6YG+"!H970@
M=V%C:'1W;V]R9"!T=V5E(&UA86P@:6XB"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B=6YI9FEE
M9"(*;7-G<W1R(")U;FEF:65D(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]0
M87)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R(")O;F)E;F]E;60B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-C4*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(D=E8G)U:6ME
M<G-E;&5C=&EE(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-#(*;7-G:60@
M(G<Z(@IM<V=S='(@(G<Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M
M(@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!O+VYN7TY/+G!O````````````````````````````````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`V,C0S,S<`,3`U,34T,S,W-30`,#$W-C8S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````",@
M2&]R9&4@3F]R=V5G:6%N($YY;F]R<VL@=')A;G-L871I;VX*(R!#;W!Y<FEG
M:'0@*$,I(#(P,#(@4&5R+5-T:6%N(%9A=&YE"B,@5&AI<R!F:6QE(&ES(&1I
M<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE($AO<F1E
M('!A8VMA9V4N"B,@4&5R+5-T:6%N(%9A=&YE(#QP<W9`;W)S=&$N;W)G/BP@
M,C`P,BX*(R`*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I
M;VXZ($AO<F1E(#,N,"UC=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D
M979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P
M-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`R
M+3`V+3`X(#(R.C,P*S`Q,#!<;B(*(DQA<W0M5')A;G-L871O<CH@4&5R+5-T
M:6%N(%9A=&YE(#QP<W9`;W)S=&$N;W)G/EQN(@HB3&%N9W5A9V4M5&5A;3H@
M3F]R=V5G:6%N($YY;F]R<VL@/&YY;F]R<VM`;W)S=&$N;W)G/EQN(@HB34E-
M12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@
M8VAA<G-E=#UI<V\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D
M:6YG.B`X8FET7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S-S,*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H=&]M
M;W)R;W<I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S-S$*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4V(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS-C$*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C0P-PIM<V=I9"`B(&%T("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0TQ)+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I
M<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-C4Y"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`T,@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(
M;W)D92!296=I<W1R>2XB"FUS9W-T<B`B)R5S)R!E<B!I:VMJ92!K;VYF:6=U
M<F5R="!I(')E9VES=&5R970@=&EL($AO<F1E+B(*"B,Z(&9R86UE=V]R:R]4
M<F5E+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z-38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@
M(B<E<R<@=F%R="!L86=T('1I;"!G<G5P<&5S>7-T96UE="XB"@HC.B!A9&UI
M;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y
M<W1E;2XB"FUS9W-T<B`B)R5S)R!V87)T(&QA9W0@=&EL('1I;&=A;F=S<WES
M=&5M970N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A
M9&1C:&EL9"YP:'`Z-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G<W1R("(G)7,G('9A<G0@
M:6MK:F4@;W!P<F5T=&$Z("5S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-
M0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@
M)7,@86YD("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X
M<&ER97,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(E<R`M
M($YO=&ES(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW
M,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M
M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E
M<R!V961L:6ME:&%L9'-O<&5R87-J;VYA<B`M(%-T861F97-T:6YG(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B5S(%9I;&OE<B!F
M;W(@879T86QE(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,C@@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3`*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HV-3$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW
M,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Y(&QI8B]";&]C
M:R]M971A<BYP:'`Z,38U(&QI8B]";&]C:R]M971A<BYP:'`Z,C,Y"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S0U(&QI8B]";&]C:R]M971A<BYP:'`Z,S4Q
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T
M:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E
M<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R(")+<GES<R!A=B!F;W(@;W!E
M<F%S:F]N*&%R*2!D=2!V:6P@:_AY<F4@;F\N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R
M97%U:7)E9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X
M-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G
M<W1R(")+=F%R="`U+B!M:6YU='0B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO0V]L;&5C=&EO;BYP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M=&\@)7,@;V8@)7,B"FUS9W-T<B`B6VQI;FIE("5S(&%V("5S72(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(R"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R(")!9')E<W-E
M8F]K(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,30*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B
M2V%L96YD97(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S
M='(@(B5S("T@3F]T:7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDS,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VAT;6PN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@
M5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T
M;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@
M;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@
M:6YF;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS-C4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q
M,`IM<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$X."!L:6(O0FQO8VLO;65T87(N<&AP.C$Y,PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,CDT(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,S0X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$R.`HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0Y"FUS9VED("(M+2!S96QE
M8W0@+2TB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"B,L
M(&9U>GIY"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R(")$:6X@:6YF
M;W)M87-J;VXB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*(RP@9G5Z>GD*
M;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(D1I;B!I;F9O<FUA<VIO
M;B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H
M;W5R<R(*;7-G<W1R("(R-"!T:6UA<B(*"B,Z(&9R86UE=V]R:R]522]522]0
M86=E<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B02!D871A8F%S92!B86-K
M96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V,`HC+"!F=7IZ>0IM<V=I
M9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B/&(^1&5T
M('-K:F5D9&4@96EN(&MA=&%S=')O9F%L(&9E:6PZ/"]B/B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@
M4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V
M-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I
M9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y-PIM<V=I9"`B(@HB02!P=6)L:6,@
M4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,34*;7-G:60@
M(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4P-0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3
M+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB
M9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3
M+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G
M:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO=61S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P
M"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!32!286EN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$R"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!
M32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P
M"FUS9VED(")!4$D@240B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E
M9&ET;W(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z
M-3(*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O
M;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S
M(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E
M<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B06-C;W5N
M="!);F9O<FUA=&EO;B(*;7-G<W1R(")$:6X@:6YF;W)M87-J;VXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4*(RP@9G5Z>GD*;7-G:60@(D%C8V]U
M;G0@4&%S<W=O<F0B"FUS9W-T<B`B4W1A9&9E<W0@<&%S<V]R9"(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM
M<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS,S,*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M
M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`B3&5G
M9R!T:6PB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N
M<&AP.C(R-0HC+"!F=7IZ>0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S
M='(@(DQE9V<@=&EL('5N9&5R;W)D;F$@;V)J96MT(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.CDY"B,L(&9U>GIY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO
M;B(*;7-G<W1R("),96=G('1I;"!U;F1E<F]R9&YA(&]B:F5K='1I;&=A;F<@
M=&EL("<E<R<B"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0HC+"!F
M=7IZ>0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(DQE9V<@=&EL(&)R=6MA
M<B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z
M,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HX.`HC+"!F=7IZ>0IM<V=I9"`B061D($YE=R!097)M:7-S
M:6]N(@IM<V=S='(@(E1I;&=A;F<B"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V%D9&-H:6QD+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B3&5G9R!T
M:6P@=6YD97)O<F1N82!O8FIE:W1G<G5P<&4@=&EL("<E<R<B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T-PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B
M"FUS9W-T<B`B3&5G9R!T:6P@=6YD97)O<F1N82!O8FIE:W1T:6QG86YG('1I
M;"`G)7,G(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE
M=R!U<V5R.B(*;7-G<W1R("),96=G('1I;"!N>2!B<G5K87(Z(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-`IM<V=I9"`B
M061D(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C,T"B,L(&9U>GIY"FUS9VED(")!9&0@;F5W(&UE;6)E
M<G,B"FUS9W-T<B`B3&5G9R!T:6P@;GET="!M961L96TB"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R
M("),96=G('1I;"!P87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8W
M"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO
M>FEL;&$@4VED96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(D%D9"!T
M;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(D%D<F5S<V5B;VLB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*(RP@9G5Z>GD*
M;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B061R97-S
M96)O:R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*
M;7-G<W1R("),96=G('1I;"!B<G5K87(B"@HC.B!A9&UI;B]U<V5R+G!H<#HW
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE
M('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@
M:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP
M.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@
M<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@
M=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(DQE9V<@=&EL(&)R=6MA<F%R
M(&5R('-LY71T(&%V+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q"FUS
M9VED(")!9&1R97-S(@IM<V=S='(@(D%D<F5S<V4B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3,Y"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T
M<B`B061R97-S96)O:R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")!9&UI;FES=&5R("T@<V5T
M('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R(")%;F1R92!T
M:6QG86YG(&9O<B`G)7,G(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(D%D;6EN:7-T<F5R:6YG(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,T,0HC+"!F=7IZ>0IM<V=I9"`B061S(@IM<V=S='(@
M(DQE9V<@=&EL(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G:&%N:7-T86XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-PHC+"!F=7IZ>0IM<V=I9"`B06QB86YI82(*
M;7-G<W1R(")!;&EA<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(D%L
M9V5R:6$B"FUS9W-T<B`B06QI87,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R(")!
M;&EA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,38*(RP@9G5Z>GD*;7-G:60@(D%L:6=N(@IM<V=S='(@(D%L
M:6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R
M<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R
M;W5P<RYP:'`Z,C(R"B,L(&9U>GIY"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S
M='(@(D=R=7!P97(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.CDQ(&9R86UE=V]R:R]097)M<R]097)M<R]D871A=')E92YP:'`Z-S4*(RP@
M9G5Z>GD*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R(")4:6QG86YG
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,0IM<V=I9"`B06QL;W<@;75L
M=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,S0*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L
M:7-T('1Y<&4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$
M871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,PIM<V=I9"`B
M06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4P-PIM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O
M<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y.0IM
M<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@
M(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(D1I(&4M<&]S=&%D
M<F5S<V4Z(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L
M=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(U"FUS9VED
M(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I
M9"`B06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HY-2!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C$Q-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D
M+B(*;7-G<W1R(")%:6X@=6QO=FQE9R!V97)D:2!V87)T('-P97-I9FES97)T
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C<*(RP@9G5Z
M>GD*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S
M='(@(CQB/D1E="!S:VIE9&1E(&5I;B!K871A<W1R;V9A;"!F96EL.CPO8CXB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4U"B,L(&9U>GIY"FUS9VED(")!;F1O<G)A(@IM<V=S='(@
M(D9N;W)R92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO
M=7,@4')O>'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X
M"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G
M:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O861M:6XO
M<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R
M("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI
M8V%T:6]N($QI<W0B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!
M<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M.#,S"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#0*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!
M<')I;"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM
M<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E($9I;&4@
M4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M,`IM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO
M=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(D5R(&1U
M('-I:VME<B!PY2!A="!D=2!V:6P@<VQE='1E("<E<R<_(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@
M7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`B17(@9'4@<VEK
M:V5R('#E(&%T(&1U('9I;"!S;&5T=&4@)R5S)S\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS
M9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B
M07)M96YI82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W
M-@IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES
M;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*
M;7-G:60@(D%S8VEI($%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R-0IM<V=I
M9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(E-P^'(@;VT@<W1A9&9E<W1I;F<@
M9OAR(&OX>7)I;F<@878@=F5D;&EK96AA;&1S;W!E<F%S:F]N87(_(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q,PIM<V=I9"`B07-S:6=N;65N
M="!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*
M;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P
M+B(*;7-G<W1R(")0<OAV9&4@Y2!S;&5T=&4@96D@:6MK:F4M96MS:7-T97)A
M;F1E(&=R=7!P92XB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS
M9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S
M:6]N+B(*;7-G<W1R(")0<OAV9&4@Y2!S;&5T=&4@96EN(&EK:VIE+65K<VES
M=&5R86YD92!T:6QG86YG+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W
M"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES
M<VEO;BXB"FUS9W-T<B`B4'+X=F1E(.4@96YD<F4@96EN(&EK:VIE+65K<VES
M=&5R86YD92!T:6QG86YG+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H
M<#HU,PHC+"!F=7IZ>0IM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X
M:7-T96YT('-H87)E+B(*;7-G<W1R(")0<OAV9&4@Y2!E;F1R92!E:6X@:6MK
M:F4M96MS:7-T97)A;F1E('1I;&=A;F<N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#8*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*(RP@9G5Z
M>GD*;7-G:60@(D%U9W5S="(*;7-G<W1R("),=7,B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS
M9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B
M075S=')I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA
M<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z
M($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($94
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M
M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E
M<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T
M:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R
M"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R
M=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z
M(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$
M:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@(D%U
M=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T
M:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T
M('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T
M:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV,`IM
M<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC
M871I;VX@9F%I;&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B
M075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P"FUS9VED
M(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G
M:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(E1I;&=J96YG96QE9V4@
M9F5L=#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%
M>&-U<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@
M:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R
M;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")"86AR86EN
M(@IM<V=S='(@(D)A<F)I92(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W
M"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H
M:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G
M:60@(D)E;&%R=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L
M9VEU;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QI>F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB
M"FUS9W-T<B`B0G5R<V1A9R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#
M;VQL96-T:6]N+G!H<#HS-3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R(")&86YN(&EK:VIE('9A<G-E;&QY='1A<B`E<RXB"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.#D*;7-G:60@(D)L;V-K(%-E
M='1I;F=S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O
M;&0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`U"FUS9VED
M(")";V]K;6%R:W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`HC+"!F=7IZ>0IM<V=I9"`B
M0F]R9&5R(@IM<V=S='(@(DAO<F1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S
M<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B0F]R9&5R<R(*
M;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@
M2&5R>F5G;W9I;F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*(RP@
M9G5Z>GD*;7-G:60@(D)O='-W86YA(@IM<V=S='(@(D)R=6XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G
M:60@(D)O='1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V
M970@27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*(RP@9G5Z>GD*;7-G
M:60@(D)R87II;"(*;7-G<W1R(")%+7!O<W0B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I
M9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G
M:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@
M(D)U<G5N9&DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0T-`HC+"!F=7IZ>0IM<V=I9"`B0TU3(@IM<V=S='(@(D-64R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@
M(D-20R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4Y-PIM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*
M;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M.#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDX-PHC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,34U"FUS9VED(")#86QE;F1A<B(*;7-G<W1R(")+86QE
M;F1E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#8*(RP@
M9G5Z>GD*;7-G:60@(D-A;&TB"FUS9W-T<B`B079B<GET(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G
M:60@(D-A;65R;V]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U
M=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB)7-<
M(B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@
M(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S
M97)V97(Z("5S(@IM<V=S='(@(DMU;FYE(&EK:VIE(&MO<&QE('1I;"!,1$%0
M+71E;F%R96XN(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#$S
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*(RP@9G5Z>GD*;7-G:60@(D-A;F%D
M82(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A
M9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L
M971E+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I9"`B
M0V%N8V5L(@IM<V=S='(@(D%V8G)Y="(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B
M"FUS9W-T<B`B079B<GET('!R;V)L96UR87!P;W)T(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A
M;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HY,0IM
M<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R
M86UE=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C,Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I
M<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A
M5')E92]$871A5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$871A
M5')E92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@
M<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B
M"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@
M9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T
M;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#87!E(%9E<F1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*(RP@9G5Z>GD*;7-G
M:60@(D-A<'1I;VXB"FUS9W-T<B`B06QT97)N871I=B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`HC+"!F=7IZ>0IM
M<V=I9"`B0V%R<FEE<B(*;7-G<W1R(")"87)B:64B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3`*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R(")-;V)I;'1E
M;&5F;VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(U"B,L(&9U>GIY"FUS9VED(")#96QL(%!R;W!E<G1I97,B
M"FUS9W-T<B`B36]B:6QT96QE9F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S0*(RP@9G5Z>GD*;7-G:60@(D-E
M;&QP:&]N92(*;7-G<W1R(")-;V)I;'1E;&5F;VXB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$W.`IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B0V5N=')A
M;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.3D*;7-G:60@(D-E<G1I9FEC
M871E($1E=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV,3$*;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3DV"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#@*(RP@9G5Z>GD*;7-G:60@(D-H860B"FUS9W-T<B`B=D-A
M<F0B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,L(&9U>GIY"FUS9VED(")#:&%N
M9V4B"FUS9W-T<B`B06YG<F4@96YD<FEN9V%R(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")#:&%N9V4@66]U
M<B!087-S=V]R9"(*;7-G<W1R(")3=&%D9F5S="!P87-S;W)D(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA
M;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D
M(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N
M9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@
M8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*(RP@9G5Z>GD*;7-G:60@(D-H
M87(B"FUS9W-T<B`B=D-A<F0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK
M+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D-H
M:6QE(@IM<V=S='(@(E1I='1E;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED
M(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-H:6YE<V4@5')A9&ET
M:6]N86P@*$)I9S4I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HR-CD*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A('!A
M<W-W;W)D(@IM<V=S='(@(E-T861F97-T('!A<W-O<F0B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8X"FUS9VED(")#:&]O<V4@82!U
M<V5R;F%M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,CDX"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@
M*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O5D93+G!H<#HX
M.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I
M;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R(")&86YN(&EK:VIE('9A<G-E
M;&QY='1A<B`E<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-`HC+"!F=7IZ>0IM<V=I9"`B0VQE87(B"FUS9W-T<B`B2V%L
M96YD97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@(D-L96%R(%%U97)Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN
M8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S97(@9&%T
M82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM
M<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B2VQI:VL@9F]R(.4@
M:&%L9&4@9G)A;2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*
M;7-G<W1R("),=6MK('9I;F1A=6=E="(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C0T"FUS9VED(")#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%
M87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G:60@
M(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L
M;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B
M0V]L;VUB:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ
M."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N
M+G!H<#HS,C0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN
M<&AP.C,R-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-3`P('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G
M:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.#0V"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.30V"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C0*;7-G:60@
M(D-O;6EC<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*
M(RP@9G5Z>GD*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B1FER;6$B"@HC.B!A
M9&UI;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S
M"FUS9VED(")#;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-38V"FUS9VED(")#;VUM;VX@3F%M92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y
M"FUS9VED(")#;VUP86YY(@IM<V=S='(@(D9I<FUA(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y-PIM<V=I9"`B0V]N
M9&ET:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y
M"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#,*;7-G
M:60@(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R
M='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$S-0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@
M;V8@9&%T92XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0IM
M<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R(")3=&%D9F5S="!P87-S
M;W)D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC
M(&]F('1H92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O
M;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS
M9W-T<B`B3W!P:V]P;&EN9R!M;W0@;V9F96YT;&5G(&[X:VME;'1E;F%R(&YE
M:W1A+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D
M('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS
M9W-T<B`B3W!P:V]P;&EN9R!M;W0@;V9F96YT;&5G(&[X:VME;'1E;F%R(&YE
M:W1A+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#0U"FUS9VED
M(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`Q-`IM<V=I9"`B0V]N=&%C
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL
M>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU-B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R("));FYH86QD
M(&D@)R5S)R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PHC+"!F=7IZ>0IM<V=I9"`B
M0V]N=&EN=64B"FUS9W-T<B`B2VQI:VL@9F]R(.4@:&%L9&4@9G)A;2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(D-O<'DB"FUS9W-T<B`B1FER
M;6$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@
M(DEM<&]R=&5R=&4@9F5L=#H@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$W,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#;W-T82!2:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@
M(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z.3<V"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y
M<'0@;65S<V%G92XB"FUS9W-T<B`B2W5N;F4@:6MK:F4@4$=0+6MO9&4@;65L
M9&EN9RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4S
M"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`B
M2W5N;F4@:6MK:F4@4$=0+7-I9VYE<F4@;65L9&EN9RXB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PHC+"!F=7IZ>0IM<V=I9"`B
M0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(DMU
M;FYE(&EK:VIE(%!'4"UK;V1E(&UE;&1I;F<N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<*(RP@9G5Z>GD*;7-G:60@(D-O=6QD
M(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R(")+=6YN92!I:VMJ
M92!01U`M<VEG;F5R92!M96QD:6YG+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@
M(DMU;FYE(&EK:VIE(&1E:V]D92!01U`M9&%T82XB"@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HQ,C$*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O
M($Q$05`@<V5R=F5R+B(*;7-G<W1R(")+=6YN92!I:VMJ92!K;W!L92!T:6P@
M3$1!4"UT96YA<F5N+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*
M(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R
M(@IM<V=S='(@(DMU;FYE(&EK:VIE('-K869F92!O9F9E;G1L96<@;OAK:V5L
M(&9RY2!N^&MK96QT96YA<F5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I9"`B
M0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B2W5N
M;F4@:6MK:F4@:V]P;&4@=&EL($Q$05`M=&5N87)E;BXB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C
M<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,C4*;7-G:60@(D-O=6QD
M(&YO="!D96-R>7!T(%!'4"!D871A+B(*;7-G<W1R(")+=6YN92!I:VMJ92!D
M96MO9&4@4$=0+61A=&$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU,C(*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T
M(%,O34E-12!D871A+B(*;7-G<W1R(")+=6YN92!I:VMJ92!D96MO9&4@4$=0
M+61A=&$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HR-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B2W5N;F4@:6MK:F4@
M9&5K;V1E(%!'4"UD871A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HY-3,*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N
M="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R(")+=6YN92!I:VMJ92!A=F=J
M97)E(&UO='1A:V%R96X@<VD@92UP;W-T861R97-S92XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PHC+"!F=7IZ
M>0IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O
M:RXB"FUS9W-T<B`B2W5N;F4@:6MK:F4@879G:F5R92!M;W1T86MA<F5N('-I
M(&4M<&]S=&%D<F5S<V4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C
M;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G
M:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T
M<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*
M;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K
M97ES97)V97(N(@IM<V=S='(@(DMU;FYE(&EK:VIE('-K869F92!O9F9E;G1L
M96<@;OAK:V5L(&9RY2!N^&MK96QT96YA<F5N+B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@
M7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R
M(")+=6YN92!I:VMJ92!01U`M:V]D92!M96QD:6YG+B(*"B,Z(&9R86UE=V]R
M:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-#$X"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D
M=6QE("5S(@IM<V=S='(@(DMU;FYE(&EK:VIE(&]P;F4@36%I;G1E;F%N8V5?
M5&%S:RUM;V1U;&5N("5S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O
M<GD@7"(E<UPB+B(*;7-G<W1R(")+=6YN92!I:VMJ92!O<&YE($UA:6YT96YA
M;F-E7U1A<VLM;6]D=6QE;B`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0HC
M+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E
M<BXB"FUS9W-T<B`B2W5N;F4@:6MK:F4@:V]P;&4@=&EL($Q$05`M=&5N87)E
M;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S.`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM
M<V=S='(@(B<E<R<@=F%R="!I:VMJ92!O<'!R971T83H@)7,B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T
M(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3
M;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N
M(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y
M;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.0HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#`*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<W"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,PHC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#D*;7-G:60@(D-O=6QD(&YO="!R
M971R:65V92!!0TPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S
M(@IM<V=S='(@(DMU;FYE(&EK:VIE(&%V9VIE<F4@;6]T=&%K87)E;B!S:2!E
M+7!O<W1A9')E<W-E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B
M0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")(;W)D
M92!E<B!I:VMJ92!O<F1E;G1L96<@:V]N9FEG=7)E<G0B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M
M9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED
M(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I
M;VXZ("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P
M('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O
M;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O
M9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@
M;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,*(RP@
M9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R
M+B(*;7-G<W1R(")+=6YN92!I:VMJ92!K;W!L92!T:6P@3$1!4"UT96YA<F5N
M+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(DMU
M;FYE(&EK:VIE(%!'4"US:6=N97)E(&UE;&1I;F<N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@
M)7,B"FUS9W-T<B`B2W5N;F4@:6MK:F4@9&5K;V1E(%!'4"UD871A+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I
M=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8V"FUS9VED(")#;W5L9&XG="!F
M:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A
M<B!I<R!O<&5N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT
M<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3D*;7-G:60@(D-O=6YT960@=&5X
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4V.0IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C<S"FUS9VED(")#;W5R<V5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS9VED(")#<F5A=&4@
M82!N97<@;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR
M-#`*(RP@9G5Z>GD*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T
M<B`B5&EL9V%N9R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,S`*
M;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW.0IM<V=I9"`B0W)O871I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#=6)A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR
M-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z-#@*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I
M;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,S,*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N
M="!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-S4*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF;W)M870*;7-G:60@(D-U
M<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T
M('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R
M=7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G
M:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q
M*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I
M9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3$@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(D1$(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,0IM<V=I9"`B(@HB1%-.
M("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD
M871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$
M86EL>2(*;7-G<W1R(")$86=L96<B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z
M-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W.0IM<V=I9"`B1&%T86)A<V4@3&]O
M:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y.0HC
M+"!F=7IZ>0IM<V=I9"`B1&%T92(*;7-G<W1R(")/<'!D871E<B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E
M(%)E8V5I=F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(X,#<*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3(@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,R,@HC+"!F=7IZ>0IM<V=I9"`B1&%Y(@IM<V=S
M='(@(D1A9VQE9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS-@HC+"!F=7IZ>0IM<V=I9"`B1&5?;&5T92!#
M;VQU;6XB"FUS9W-T<B`B4VQE='1E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S8*(RP@9G5Z>GD*;7-G:60@(D1E8V5M8F5R
M(@IM<V=S='(@(DUE9&QE;6UA<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@
M;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@
M;&EB+W!R969S+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B"FUS
M9W-T<B`B4VQE='1E(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-S<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@0V]L;W(B
M"FUS9W-T<B`B0G)U:R!S=&%N9&%R9'9E<F1I(@H*(SH@9G)A;65W;W)K+TED
M96YT:71Y+TED96YT:71Y+G!H<#HY,0IM<V=I9"`B1&5F875L="!)9&5N=&ET
M>2(*;7-G<W1R(")3=&%N9&%R9&ED96YT:71E="(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!3:&5L;"(*
M;7-G<W1R(")3=&%N9&%R9&ED96YT:71E="(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C,V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN
M8SHQ,"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B
M1&5L971E(@IM<V=S='(@(E-L971T92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@HC+"!F=7IZ>0IM<V=I
M9"`B1&5L971E($-E;&PB"FUS9W-T<B`B4VQE='1E(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*(RP@9G5Z>GD*;7-G
M:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R(")3;&5T=&4B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*(RP@9G5Z>GD*;7-G:60@(D1E;&5T
M92!,;V<B"FUS9W-T<B`B4VQE='1E(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P
M,0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B
M5&EL9V%N9R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S
M='(@(E-L971T92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C,*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!C;VQU
M;6XB"FUS9W-T<B`B4VQE='1E(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT
M,C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S
M:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(D5N9')E('1I;&=A;F<@9F]R("<E
M<R<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<
M(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PHC
M+"!F=7IZ>0IM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R(")3;&5T=&4B"@HC
M.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"B,L(&9U
M>GIY"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B
M4W1A;F1A<F1I9&5N=&ET970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@
M8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE
M=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C,V"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y
M-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C4S"B,L(&9U>GIY"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S
M='(@(E-L971T92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G
M:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(E-K:6QD<F4@<')O
M8FQE;65T(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*(RP@
M9G5Z>GD*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D9U;&P@<VMI;&1R
M:6YG.B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DU"FUS9VED
M(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DY"FUS9VED(")$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R(")$971A;&IA<B!E<B!L;V=G82!F;W(@861M:6YI<W1R871O
M<F5N+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,3D*;7-G:60@
M(D1E=F5L;W!M96YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C$W"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR.30*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H
M;W5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(R-PIM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B
M1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER
M96-T:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8V"FUS9VED(")$:7-P;&%Y(#(T
M+6AO=7(@=&EM97,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY-PIM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(E9I<VEN
M9W-A;'1E<FYA=&EV(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.CDV"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T
M(@IM<V=S='(@(E9I<VEN9W-A;'1E<FYA=&EV(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HX-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$W"B,L(&9U
M>GIY"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R(")6:7-I;F=S86QT
M97)N871I=B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HQ.3`*
M;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,@HC+"!F=7IZ>0IM<V=I9"`B
M1&\@;F]T(&1E;&5T92(*;7-G<W1R(")3;&5T=&4B"@HC.B!S97)V:6-E<R]M
M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E
M<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(DEK:VIE(&)R=6L@;6%I;G1E
M;F%N8V4N<&AP(&1I<F5K=&4N(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF
M;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@
M(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@
M268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I
M9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C
M;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.#0T"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@
M9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B
M1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,T"B,L(&9U>GIY"FUS9VED(")$<G5G<R(*;7-G<W1R("),=7,B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*(RP@9G5Z
M>GD*;7-G:60@(D4M36%I;"(*;7-G<W1R(")%+7!O<W0B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA
M:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@
M<')O=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP
M:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED
M(")%8W5A9&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW
M,@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET
M(@IM<V=S='(@(D5N9')E(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)
M+G!H<#HU,"!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%
M9&ET($)L;V-K(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"B,L(&9U>GIY"FUS9VED(")%9&ET($=R
M;W5P(@IM<V=S='(@(D=R=7!P97(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`P
M"B,L(&9U>GIY"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`B5&EL
M9V%N9R(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*(RP@9G5Z
M>GD*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B5&EL9V%N9R(*
M"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S
M='(@(D5N9')E('1I;&=A;F<@9F]R("<E<R<B"@HC.B!T96UP;&%T97,O<')E
M9G,O87!P+FEN8SHU"B,L(&9U>GIY"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R
M.B(*;7-G<W1R(")%;F1R92!T:6QG86YG(&9O<B`G)7,G(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R
M(")%;F1R92!T:6QG86YG(&9O<B`G)7,G(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B161I
M="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B16YD<F4@=&EL9V%N9R!F
M;W(@)R5S)R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B
M161U8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P
M"B,L('!H<"UF;W)M870*;7-G:60@(D5I=&AE<B!E;F%B;&4@:70@=&AE;CH@
M)7,L(&]R('5S92!T:&4@8F%S:6,@2%1-3"!V97)S:6]N.B`E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G
M:60@(D5M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V
M.0IM<V=I9"`B16UA:6PB"FUS9W-T<B`B12UP;W-T(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C8X"B,L(&9U>GIY"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S
M='(@(D1I(&4M<&]S=&%D<F5S<V4Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3DV,PHC+"!F=7IZ>0IM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU
M<W0@;6%T8V@N(@IM<V=S='(@(E!A<W-O<F1A(&WE('-A;7-V87)E+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#D*(RP@9G5Z>GD*;7-G:60@
M(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D%N;F%N(&EN9F]R
M;6%S:F]N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT
M<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M.3@*(RP@9G5Z>GD*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R(")!;'1E<FYA
M=&EV(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`R"B,L(&9U>GIY"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G
M<W1R(")4;VUT(')E<W5L=&%T+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C8R(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB
M"FUS9W-T<B`B5&]M="!R97-U;'1A="XB"@HC.B!F<F%M97=O<FLO4U%,+U-1
M3"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T,PIM<V=I
M9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL
M97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4Q.`IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@
M;65N=3\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C4Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$Q"FUS9VED(")%;F0@
M>65A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q"FUS9VED("(B"B)%
M;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S
M:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N
M9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C@Y,0IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4U"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S8@<V5R=FEC97,O<&]R=&%L+VEN9&5X
M+G!H<#HX,@IM<V=I9"`B17)R;W(B"FUS9W-T<B`B1F5I;"(*"B,Z(&9R86UE
M=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z
M-#8X"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N
M=#H@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG('!A
M<W-W;W)D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@
M96UA:6P@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*
M;7-G:60@(D5U<F]P92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S,Y"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(DMV
M87)T(#$U+B!M:6YU='0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Y
M"B,L(&9U>GIY"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B2W9A
M<G0@-2X@;6EN=71T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`S,"!S96-O
M;F1S(@IM<V=S='(@(DMV87)T(#,P+B!S96MU;F0B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S,X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G
M:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")+=F%R="`U+B!M:6YU='0B
M"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P
M"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R(")+=F%R(&EN;FQO9V=I;F<B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0P"FUS9VED(")%=F5R>2!H
M86QF(&AO=7(B"FUS9W-T<B`B2W9A<B!H86QV92!T:6UE(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,S-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@X
M"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B2W9A<G0@;6EN=71T(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP
M;&4@=F%L=65S.B(*;7-G<W1R(")%:W-E;7!E;'9E<F1I87(Z(@H*(SH@861M
M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3(W"FUS9VED(")%>&5C=71E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0W-0IM<V=I
M9"`B17AP86YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED
M96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@
M(D5X<&5C=&5D("<I)R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-1
M3"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@
M;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$
M871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C<V"FUS9VED(")%>'!O;F5N="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS
M9VED(")&1R!#;VQO<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(Q-@IM<V=I
M9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(DMU
M;FYE(&EK:VIE(&AE;G1E(&EN;G-T:6QL:6YG87(B"@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S
M97)V97(N(@IM<V=S='(@(DMU;FYE(&EK:VIE(&MO<&QE('1I;"!,1$%0+71E
M;F%R96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.CDX"B,L
M(&9U>GIY"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R
M+B(*;7-G<W1R(")+=6YN92!I:VMJ92!K;W!L92!T:6P@3$1!4"UT96YA<F5N
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@V"B,L('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8Y,0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E
M<UPB+B(*;7-G<W1R(")+=6YN92!I:VMJ92!K;W!L92!T:6P@3$1!4"UT96YA
M<F5N+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<*;7-G
M:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3<@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C0*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B
M2W5N;F4@:6MK:F4@:V]P;&4@=&EL($Q$05`M=&5N87)E;BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V,0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R(")+=6YN
M92!I:VMJ92!H96YT92!I;FYS=&EL;&EN9V%R(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L
M=FEN87,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E($ES
M;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S
M.`HC+"!F=7IZ>0IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(DEM<&]R
M=&9E:6PZ("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R(")&86MS(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,T.0HC+"!F=7IZ>0IM<V=I9"`B1F%X97,B
M"FUS9W-T<B`B1F%K<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS
M9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0*;7-G:60@(D9I96QD
M(&UA=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,S,T"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X"FUS9VED(")&:6=L970@9F]N
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ
M>0IM<V=I9"`B1FEL92(*;7-G<W1R(")4:71T96PB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O
M=6YT.B`E<R!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S
M(&9I;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,#<*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R(")&:6QH86YD<V%M
M:6YG(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV
M,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*(RP@9G5Z>GD*
M;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R(")&:6QH86YD<V%M:6YG(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDY-0IM<V=I9"`B1FEL92!S96QE
M8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30X-@IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4Y"FUS9VED(")&:6QE('5P;&]A
M9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C@Y"FUS9VED(")&:6QT97)S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP
M.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-38*;7-G:60@(D9I
M>"!R871I;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C,Q"FUS9VED(")&;&EP(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,S0@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&
M;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N
M="!#;VQO<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&
M;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S-`IM<V=I9"`B1F]R96-A
M<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C<Y"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@
M=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI
M9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A
M('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V,@IM<V=I
M9"`B1F]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C(Q"B,L(&9U>GIY"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(D9N;W)R92(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T
M>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`HC
M+"!F=7IZ>0IM<V=I9"`B1F]R='5N97,B"FUS9W-T<B`B3F]T871A<B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4S"FUS
M9VED(")&;W)U;7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$P.0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B
M1G(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS,PHC+"!F=7IZ>0IM<V=I9"`B1G)A;65S(@IM
M<V=S='(@(DYA;6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")&<F%N
M8V4B"FUS9W-T<B`B3W)A;G-J92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!4
M97)R:71O<FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,V,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-#`V"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*(RP@9G5Z>GD*;7-G
M:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B1G5L;"!S:VEL9')I;F<Z
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H
M<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHV,`HC+"!F=7IZ>0IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(D1I
M='0@;F%M;CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N
M97)A=&5D($-O9&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O
M<F=I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M86YY(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B1VEV
M96X@3F%M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN
M8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,C@*;7-G:60@(D=O
M;V=L92!-87!S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-PIM<V=I9"`B
M1W)A>7-C86QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"B,L(&9U>GIY"FUS
M9VED(")'<F5E8V4B"FUS9W-T<B`B1W+X;B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@U"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B1W)E96YL86YD(@IM<V=S
M='(@(D=R^&XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")'<F5N861A
M(@IM<V=S='(@(D=R^&XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I
M9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B1W)U<'!E861M:6YI
M<W1R97)I;F<B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P
M(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-#$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'
M<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@
M(DMU;FYE(&EK:VIE('-L971T92`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A
M<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM
M<V=I9"`B1W)O=7!S(@IM<V=S='(@(D=R=7!P97(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS
M9VED(")'=6%D96QO=7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED
M(")'=6%M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%T96UA
M;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M,@HC+"!F=7IZ>0IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B1W+E(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHX.`HC+"!F=7IZ>0IM<V=I9"`B1W5E<W0@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B5&EL9V%N9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-S`*(RP@9G5Z>GD*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R
M(")!9')E<W-E8F]K(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W5I;F5A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-C`*;7-G:60@(DA434PB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE
M=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H
M96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR,@IM<V=I9"`B2&%Z92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HY,3D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,@HC
M+"!F=7IZ>0IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(D]V97)S:W)I9G1E<B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-C$*
M(RP@9G5Z>GD*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B3W9E<G-K<FEF=&5R
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N
M86QD($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C,*;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(DAE
M8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(
M96EG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE
M;'`N<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@V
M"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L871E<R]H96QP
M+VEN9&5X+FEN8SHS"FUS9VED(")(96QP(@IM<V=S='(@(DAJ96QP(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I
M9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3,W,0HC+"!F=7IZ>0IM<V=I9"`B2&5L<&5R(@IM
M<V=S='(@(DAJ96QP(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED
M(")(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS
M9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8Y"FUS9VED(")(:6=H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI
M;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B2&]?;64B"FUS9W-T<B`B2&]R9&4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T
M871E*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$U,S4*(RP@9G5Z>GD*;7-G:60@(DAO;64B"FUS9W-T<B`B2&]R9&4B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G
M:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")!9')E<W-E+"!P<FEV870B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G:60@(DAO;64@1&ER96-T
M;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B5&5L
M969O;BP@<')I=F%T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C4*;7-G:60@
M(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HT-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G
M92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN
M(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HQ,C4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S
M='(@(D9J97)N82`G)7,G(&9RY2!S>7-T96UE="XB"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I
M;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E
M>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0W"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M
M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HT-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R
M="!O9B!T>7!E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,V"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR
M;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B
M2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@
M<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE
M87-E(')E<&]R="$I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY
M(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@
M;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M
M97)G93\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,P,"!L:6(O0FQO8VLO;65T87(N<&AP.C(S,`IM<V=I9"`B2'5M:61I
M='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(U.0IM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q-@HC
M+"!F=7IZ>0IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R(")!9')E<W-E(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B
M25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R
M97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S8*;7-G:60@(DEC;VYS($]N;'DB
M"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H
M<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<W"FUS9VED("))8V]N<R!W:71H('1E
M>'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM
M<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O
M(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#4U"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@
M<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA
M>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T
M<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ-S,*;7-G:60@(B(*(DEF('EO=2!S964@
M=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT
M('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W
M<V5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E(%!R979I
M97<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$*;7-G:60@
M(DEM86=E('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI
M;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("));7!O<G1E<G1E(&9E;'0Z
M("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(DEM
M<&]R=&5R=&4@9F5L=#H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(DEM<&]R
M=&5R=&4@9F5L=#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z
M:7`N<&AP.C$S-0IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S,@HC+"!F=7IZ>0IM<V=I9"`B26YC;W)R96-T('5S
M97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B4VMR:78@:6YN(&1I
M='0@8G)U:V%R;F%M;B!O9R!P87-S;W)D(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O
M<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U
M<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV
M-PIM<V=I9"`B26YF;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C4W"B,L(&9U>GIY"FUS9VED("));F9O<FUA=&EO;B(*;7-G
M<W1R(")$:6X@:6YF;W)M87-J;VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S,P"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A
M:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L
M=6UN($%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T
M($EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T
M"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R
M96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE
M=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E
M;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W
M(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW
M,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT
M(&YO9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A
M9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA
M=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(S.0IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI
M8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED
M("));G-E<G0@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("))
M;G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I
M9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM
M<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED
M("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C,P"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N
M<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G
M:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS
M97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I
M8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W-0IM
M<V=I9"`B26YT96=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3,S"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP
M+G!H<#HQ-S`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP
M:'`Z,C`Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP
M.C(Q,`IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI
M8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@
M240N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R
M.3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS
M-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`P"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP
M.C@Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P
M,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`*
M;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-PIM<V=I9"`B26YV86QI9"!L
M:6-E;G-E(&ME>2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$W,0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?
M:60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG
M('!A<F%M971E<G,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H
M:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W
M,PIM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED("));G9A;&ED
M('!R;V1U8W0@8V]D92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED
M('!R;W1O8V]L+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E
M8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,3`W-B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R
M-C(*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$Q"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U-PIM<V=I9"`B26YV96YT
M;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-SD*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@
M(DES;&4@;V8@36%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R
M-0IM<V=I9"`B27-S=65R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,@HC+"!F=7IZ>0IM<V=I9"`B271A;'DB"FUS
M9W-T<B`B1&%G;&5G(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0S.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#<*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*;7-G:60@
M(B(*(DIA=F%S8W)I<'0@:&%S(&)E96X@9&ES86)L960@;VX@>6]U<B!B<F]W
M<V5R(&%N9"!T:&ES('!A9V4@;6%Y(&YO="!B92`B"B)D:7-P;&%Y:6YG(&-O
M<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C(*(RP@9G5Z>GD*;7-G:60@(DIE<G-E>2(*;7-G<W1R(")'<N4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B
M2G5L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS
M9VED(")*=7-T:69Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y
M($-E;G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-C0*;7-G
M:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PHC
M+"!F=7IZ>0IM<V=I9"`B2V5N>6$B"FUS9W-T<B`B3F5K="(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E
M<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG
M97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"B,L(&9U>GIY"FUS
M9VED(")+97D@5'EP92(*;7-G<W1R(")-24U%+71Y<&4B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`HC+"!F=7IZ>0IM<V=I9"`B
M2V5Y(%5S86=E(@IM<V=S='(@(DUE;&1I;F<B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HW-#`*(RP@9G5Z>GD*;7-G:60@(DME>2!A;')E
M861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B
M3W!P:V]P;&EN9R!M;W0@;V9F96YT;&5G(&[X:VME;'1E;F%R(&YE:W1A+B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O
M<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS
M9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*
M;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(E-P<N5K(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W
M"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T
M($AA;&8B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V
M"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS
M9VED("),87-T(%%U87)T97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ-3$*(RP@9G5Z>GD*;7-G:60@(DQA<W0@57!D871E9#HB"FUS
M9W-T<B`B3W!P9&%T97(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW
M,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S(Q"B,L('!H<"UF
M;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$V"FUS9VED("),87-T
M(&QO9VEN.B!.979E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@
M(DQA='9I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#0*;7-G:60@(DQA=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*(RP@9G5Z>GD*;7-G:60@
M(DQA>6]U="(*;7-G<W1R("),;V=G('5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@
M9F]R(&YO(&)O<F1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@
M(DQE8F%N;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS9VED("),969T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3D*;7-G:60@(DQE
M9G0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,34*(RP@9G5Z>GD*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@
M(D5K<V5M<&5L=F5R9&EA<CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE<V]T
M:&\B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C4U"B,L(&9U>GIY"FUS9VED("),979E;"(*;7-G<W1R(")!;&1R:2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U
M"B,L(&9U>GIY"FUS9VED("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(DQY<R!B
M;.4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-@HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R("),;V=G(&EN
M;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W
M"FUS9VED("),:6=H="!286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H
M="!286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS,0HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R("),>7,@
M8FSE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-`HC+"!F=7IZ
M>0IM<V=I9"`B3&EN:R(*;7-G<W1R("),;V=G(&EN;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I
M9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X-S4*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E
M<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E
M>'0N<&AP.C$X,PIM<V=I9"`B3&EN:W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS9VED("),:7-T
M($1A=&%B87-E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X
M+G!H<#HU,`IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R(")6:7,@
M96UN92!F<N4@2&IE;'`B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,R"FUS
M9VED("),:7-T(%1A8FQE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3@Y"B,L(&9U>GIY"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`B5FES(&5M
M;F4@9G+E($AJ96QP(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S
M+G!H<#HU.38*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3(*;7-G:60@(DQI<W0M3W=N
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S
M+G!H<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3
M=6)S8W)I8F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B3&ES=&EN9R!A=B!B<G5K87)A<B!E<B!S;.5T="!A=BXB"@HC.B!A
M9&UI;B]S97-S:6]N<RYP:'`Z,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R("),:7-T:6YG
M(&%V(&)R=6MA<F%R(&5R('-LY71T(&%V+B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D
M:7-A8FQE9"XB"FUS9W-T<B`B3&ES=&EN9R!A=B!B<G5K87)A<B!E<B!S;.5T
M="!A=BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI
M=&5R871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:71H
M=6%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6UA9V5S+G!H<#HX,PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Q"FUS9VED("),
M;V-A;"!T:6UE.B`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@S"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C8T"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C8U"FUS9VED("),;V-A=&EO;B(*
M;7-G<W1R("(B"@HC.B!L;V=I;BYP:'`Z,3<R('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HQ.3$@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC
M.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS9W-T<B`B3&]G9R!I
M;FXB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@
M(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$X-0IM<V=I9"`B3&]G(&]U
M="(*;7-G<W1R("),;V=G('5T(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C4Y"B,L(&9U>GIY"FUS9VED("),;V=I;B(*;7-G<W1R("),;V=G(&EN;B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*(RP@9G5Z>GD*;7-G:60@
M(DQO9VEN(%1A<VMS(@IM<V=S='(@(D]P<&?E=F5R(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3DV"B,L(&9U>GIY"FUS9VED("),;V=I;B!F86EL
M960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E
M<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)+=6YN92!A=B!E:6X@96QL
M97(@86YN86X@9W)U;FX@:6MK:F4@;&]G9V4@:6YN+B!386YN<WEN;&5G=FES
M(&5R(&)R=6MA<FYA;6X@(@HB96QL97(@<&%S<V]R9"!T87-T82!I;FX@9F5I
M;"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3(*;7-G:60@(DQO
M9VEN(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,V-0HC+"!F=7IZ>0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@
M(DQO9V<@=70B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*(RP@9G5Z
M>GD*;7-G:60@(DQO=F4B"FUS9W-T<B`B1FIE<FXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B3&]W(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,S@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM
M<V=S='(@(DU-(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,0IM
M<V=I9"`B34]41"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT
M(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")-4RU43D5&+79E9&QE9V<@
M:6YN96AE;&1T(&EN9V5N(&1A=&$N(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I
M9"`B35-'(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H
M92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT.0HC+"!F=7IZ>0IM<V=I9"`B36%G:6,B
M"FUS9W-T<B`B12UP;W-T(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C@Q"FUS9VED(")-86EL(@IM<V=S='(@(D4M<&]S="(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HU,C(*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%L87=I(@IM<V=S='(@
M(D4M<&]S="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(DUA;&DB"FUS9W-T<B`B
M12UP;W-T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-86QT82(*
M;7-G<W1R(")%+7!O<W0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$*
M;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H
M879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I
M871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,34S"FUS9VED
M(")-87`R-"!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-C@*;7-G:60@(DUA<%%U97-T(&UA<"(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*
M;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,PHC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#$*(RP@9G5Z>GD*;7-G:60@(DUA<F=I;B(*;7-G
M<W1R("+%='9A<FEN9R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA
M9W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG
M+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD
M<R(*;7-G<W1R(")386US=F%R86YD92!F96QT(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS
M9VED(")-875R:71A;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I
M9"`B36%U<FET:75S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W
M960@8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E
M('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,P-@IM<V=I9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDX"FUS9VED(")-
M87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O87!I
M+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3@@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M.0IM<V=I9"`B36%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@
M(DUA>6]T=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB97)S(@IM<V=S
M='(@(DUE9&QE;6UA<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S@*
M;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R
M9V4@8V5L;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS
M9W-T<B`B365L9&EN9R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F
M=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B
M92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"B,L(&9U>GIY"FUS9VED
M(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(DUE;&1I;F<B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M,C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C8P"B,L(&9U>GIY"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B
M365L9&EN9R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T
M87(@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q,@HC+"!F=7IZ>0IM<V=I
M9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E
M(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B
M1&5T86QJ87(@97(@;&]G9V$@9F]R(&%D;6EN:7-T<F%T;W)E;BXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED(")-971A<D1"
M(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z.#$@9G)A;65W;W)K
M+U)00R]24$,O<V]A<"YP:'`Z,3$W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(DUE
M=&]D92`G)7,G(&EK:VIE(&1E9FEN97)T(@H*(SH@9G)A;65W;W)K+U)00R]2
M4$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO
M="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S0@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HW-0IM<V=I9"`B365T<FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-0IM<V=I9"`B365X:6-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED
M(")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW-@HC+"!F=7IZ>0IM<V=I9"`B36ED9&QE(@IM<V=S='(@(D4M<&]S="(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS
M9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B34E-12UT>7!E(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS,3`*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U
M<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM
M<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM
M=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S
M-`HC+"!F=7IZ>0IM<V=I9"`B36ER<F]R(@IM<V=S='(@(D9E:6PB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(
M5%107U)E<75E<W0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U
M(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T
M:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI
M<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI
M<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS
M9VED(")-;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-S0*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")-;V1E
M<F%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M.`IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G
M:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-S,*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.30*;7-G:60@(DUO;G1H
M(&%N9"!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC
M92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B
M3>5N861L96<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-S(@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z,C4S"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE
M;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@
M0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`Y"FUS
M9VED(")-;W9E($1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z-3$S"FUS9VED(")-;W9E($QE9G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$W
M"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C4P-0IM<V=I9"`B36]V92!5<"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-3(T"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PHC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E
M('5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@T
M"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M-34*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0R"FUS9VED(")-=6QT:7!L92!S96QE
M8W1I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0P,`IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@(DUY($%C8V]U;G0@
M26YF;W)M871I;VXB"FUS9W-T<B`B1&EN(&EN9F]R;6%S:F]N(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HU-`IM<V=I9"`B37D@4&]R=&%L(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HQ,S8*;7-G
M:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR
M"FUS9VED(")->6%N;6%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.
M3U0@06=R964B"FUS9W-T<B`B3D5)+"!E9R!E<B!)2TM*12!S86UD(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T
M<B`B3F%M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDW"FUS9VED(").971H97)L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE
M='-C87!E($)A<V4@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!#02!2979O
M8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%52
M3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G
M:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S
M8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(&-E
M<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#`*;7-G:60@(DYE='-C87!E(&-E<G1I
M9FEC871E('1Y<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(U,0IM<V=I9"`B3F5T=V]R:R(*;7-G<W1R(").971T=F5R:R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S,U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.#8*;7-G:60@(DYE=F5R(@IM<V=S='(@(D%L9')I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU
M"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").
M97<@0V%T96=O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL
M=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I
M;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?
M1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(").97<@365S<V%G92!T;R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C
M:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE
M=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M.`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED(").97<@<&%S
M<W=O<F0B"FUS9W-T<B`B4&%S<V]R9"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W
M;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*(RP@9G5Z>GD*;7-G:60@(DYE=R!P
M87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(E!A<W-O<F1A(&WE('-A
M;7-V87)E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#D*(RP@
M9G5Z>GD*;7-G:60@(DYE=W,B"FUS9W-T<B`B3F]T871A<B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS,#4*(RP@9G5Z>GD*;7-G:60@(DYE=W-G
M<F]U<',B"FUS9W-T<B`B1W)U<'!E<B(*"B,Z('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W,B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W-@HC+"!F=7IZ>0IM<V=I
M9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(E1I;&)A:V4@=&EL(&%L=&5R;F%T
M:78B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,PIM<V=I9"`B
M3F5X=#XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G
M=6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"B,L(&9U>GIY"FUS9VED(").
M:6=E<B(*;7-G<W1R(")!;&1R:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG
M97)I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S@P"FUS9VED(").:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*
M;7-G:60@(DYI=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B3F\B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").
M;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R
M96YC97,@9F]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(N<&AP.C$P-0IM<V=I9"`B3F\@879A:6QA8FQE('-T
M<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S
M"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-SD@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C0U"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C(V-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T
M('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]M8V%L+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B3F\@
M8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B26YG96X@:V]N9FEG=7)A<VIO;G-I;F9O<FUA<VIO;B!S
M<&5S:69I<V5R="!F;W(@4U%,+6%U=&5N=&ES97)I;F<N(@H*(SH@861M:6XO
M<V5T=7`O9&EF9BYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(DYO(&-H86YG92XB
M"FUS9W-T<B`B06YG<F4@96YD<FEN9V%R(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ-38*(RP@9G5Z>GD*;7-G:60@(DYO(&-H:6QD<F5N
M(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(B<E
M<R<@=F%R="!L86=T('1I;"!T:6QG86YG<W-Y<W1E;65T+B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,38W(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z-3`R"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<W,PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R("));F=E;B!K;VYF
M:6=U<F%S:F]N<VEN9F]R;6%S:F]N('-P97-I9FES97)T(&9O<B!344P@5D93
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(T"B,L(&9U>GIY
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B26YG96X@:V]N9FEG=7)A<VIO;G-I
M;F9O<FUA<VIO;B!S<&5S:69I<V5R="!F;W(@4U%,(%9&4RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8V.0IM<V=I9"`B3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S
M='(@(DEN9V5N(&MO;F9I9W5R87-J;VYS:6YF;W)M87-J;VX@<W!E<VEF:7-E
M<G0@9F]R(%-13"!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C<Q-PHC+"!F=7IZ>0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T
M<B`B26YG96X@:V]N9FEG=7)A<VIO;G-I;F9O<FUA<VIO;B!S<&5S:69I<V5R
M="!F;W(@4U%,(%9&4RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.C@W-PIM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R("(B"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3(X(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$R,PIM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Y"FUS9VED
M(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@
M(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").
M;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU
M;6)E<B!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N
M<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO075T
M:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A
M;2YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YG96X@:V]N
M9FEG=7)A<VIO;G-I;F9O<FUA<VIO;B!S<&5S:69I<V5R="!F;W(@4U%,+6%U
M=&5N=&ES97)I;F<N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P87-S=V0N
M<&AP.C$S-0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YG96X@:V]N
M9FEG=7)A<VIO;G-I;F9O<FUA<VIO;B!S<&5S:69I<V5R="!F;W(@4U%,+6%U
M=&5N=&ES97)I;F<N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP
M.C@T"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("));F=E;B!K;VYF:6=U<F%S
M:F]N<VEN9F]R;6%S:F]N('-P97-I9FES97)T(&9O<B!344PM875T96YT:7-E
M<FEN9RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R
M.#8*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R
M;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*
M(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I
M;F<@<VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C<U,`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!Q=6]T82!S970N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#,*(RP@9G5Z>GD*;7-G:60@(DYO(')U;&5S(@IM<V=S
M='(@(DYO=&%T87(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT
M-#D*;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#0*(RP@9G5Z>GD*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(DYO=&%T
M87(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X,PIM<V=I9"`B
M3F\@<W5C:"!F:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ,S@*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@
M879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$*(RP@9G5Z>GD*;7-G
M:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R
M(")3:W)I=B!I;FX@9&ET="!B<G5K87)N86UN(&]G('!A<W-O<F0B"@HC.B!F
M<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L
M:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B26YG96X@9WEL9&EG92!8
M34PM9&%T82!R971U<FYE<G0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.3<Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HY.#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDY,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3`P.0IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E<G-I
M;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T
M92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@
M8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS
M"B,L(&9U>GIY"FUS9VED(").;VYE(@IM<V=S='(@(E1E;&5F;VXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED
M(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@Y"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA
M($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").;W)W
M87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV-#`*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B3F]T($)E
M9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HT,#@*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDN<&AP.C@S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDT"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z
M-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C8X"B,L(&9U>GIY"FUS9VED(").;W0@<V5T(@IM<V=S='(@(DYO
M=&%T87(B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(N<&AP.C$T,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S
M<VEO;DAA;F1L97(N<&AP.C$U.`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W,PHC.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X-PHC.B!F<F%M97=O<FLO
M4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-"!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR
M,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z,C0X(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-C4*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,CDW"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,3(@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C,R.0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8R(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HT,C(*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C4P,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<P"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HU.#<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V-0IM
M<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N
M<&AP+F1I<W0Z,3`P-0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3<X
M"FUS9VED(").;W1E<R(*;7-G<W1R(").;W1A=&%R(@H*(SH@<V5R=FEC97,O
M;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S
M92P@9V\@8F%C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S4*(RP@9G5Z>GD*;7-G:60@(DYO=F5M8F5R
M(@IM<V=S='(@(DUE9&QE;6UA<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P-#8*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B(*;7-G<W1R(")-961L
M96UM87(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U"FUS9VED
M(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$T,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T-2!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M
M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R
M;W=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I
M960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-C0*;7-G:60@(D]+(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B
M3V)J96-T($-R96%T;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C
M=&]B97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR
M"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S(V"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/
M;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@HC+"!F
M=7IZ>0IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(E!A<W-O<F0B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P
M87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDX"B,L(&9U>GIY"FUS9VED(")/;6%N(@IM<V=S='(@(D]R86YS:F4B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I
M9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED
M(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y-S$*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E
M9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C8U
M"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R
M871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S
M:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R
M86UE+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*
M;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@
M9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM
M<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P97)A
M=&EN9R!3>7-T96TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")!;'1E<FYA
M=&EV(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I
M;VYS(&9O<B`E<R(*;7-G<W1R(")!;'1E<FYA=&EV(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E
M9"!,:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-38W"B,L(&9U>GIY"FUS9VED(")/<F=A;FES871I;VXB"FUS
M9W-T<B`B061M:6YI<W1R97)I;F<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,R"B,L
M(&9U>GIY"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(D]R86YS:F4B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P
M;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M
M<&QA=&5S(&EN("5S.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I
M9"`B3W1H97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDV(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Q,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(R"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S$@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$T,0IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B06YN86X@
M:6YF;W)M87-J;VXB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q
M"B,L(&9U>GIY"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R(")4
M:6QG86YG(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y"FUS
M9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT
M<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(W,PIM<V=I
M9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,3D*;7-G:60@(E!'4"!%;F-R
M>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,S<Q"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4S"FUS
M9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W!H<'-H96QL+G!H<#HV.`HC+"!F=7IZ>0IM<V=I9"`B4$A0($-O
M9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*
M;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@3&EG:'0@4F%I
M;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS.`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B
M4$T@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0Q"B,L(&9U>GIY"FUS9VED(")032!3=6XB"FUS9W-T<B`B4V]L(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@
M(E!-(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM
M<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L
M;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.30@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,0IM<V=I9"`B4&%L874B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.34@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U87DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S8*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q.`HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C<W('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-#,*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R,PIM<V=I9"`B4&%S
M<W=O<F0B"FUS9W-T<B`B4&%S<V]R9"(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S
M9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,3,R,@HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@:6YC;W)R
M96-T(@IM<V=S='(@(E!A<W-O<F0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W)A9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@
M4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,#4S"FUS9VED(")087-S=V]R9"!W:71H(&-O
M;F9I<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.3`*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R
M(")087-S;W)D(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*
M(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B4&%S<V]R9"(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*
M;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")087-S;W)D
M82!MY2!S86US=F%R92XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C
M;&EP8F]A<F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN
M9R!3:6=N=7!S.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-30*(RP@9G5Z>GD*;7-G:60@(E!E;W!L92(*;7-G<W1R(")2;VQL92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W
M"FUS9VED(")097)C96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA
M:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B2_AY<B!V961L:6ME:&%L
M9'-O<&5R87-J;VYA<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#8*
M;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I
M;C\B"FUS9W-T<B`B2_AY<B!V961L:6ME:&%L9'-O<&5R87-J;VYA<B!V960@
M:6YN;&]G9VEN9S\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C$U-@HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R(")4:6QG
M86YG(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#8*(RP@
M9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(E1I;&=A
M;F<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B5&EL9V%N9R(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP
M.C$P.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R
M;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G
M:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E1I;&=A
M;F=S861M:6YI<W1R97)I;F<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C4*(RP@9G5Z>GD*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S
M='(@(D%N;F%N(&EN9F]R;6%S:F]N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")0
M97)U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM
M<V=I9"`B4&5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H
M:6QI<'!I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(E1E
M;&5F;VXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<X"FUS9VED
M(")0:&]T;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET
M8V%I<FXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M
M92!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U
M('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4W,0IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L
M96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#$*;7-G:60@
M(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C`*;7-G:60@(E!L96%S
M92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y
M<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T-3$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I
M;64N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@
M<')O8FQE;2XB"FUS9W-T<B`B4VMR:78@:6YN(&5I="!S86UA;F1R86<@878@
M<')O8FQE;65T+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R
M;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B4VMR
M:78@:6YN(&1I='0@8G)U:V%R;F%M;B!O9R!P87-S;W)D(@H*(SH@<V5R=FEC
M97,O;6%I;G1E;F%N8V4N<&AP.C4X"B,L(&9U>GIY"FUS9VED("(B"B)0;&5A
M<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I
M=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B
M"B)697(@=F5N;&5G(&]G(&QE<R!F^&QG:F%N9&4@=&5K<W0N($1U($W%('9E
M<F4@<V%M9"!M960@=FEL:^5R82!F;W(@Y2!B<G5K92`B"B)S>7-T96UE="XB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H
M<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O
M;&ET:6-S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT.#<*;7-G:60@(E!O;&QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*
M;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B
M4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B
M4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S
M="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8V(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I
M;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3@*;7-G:60@(E!R96-I<&ET871I
M;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E
M9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E
M9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-0IM
M<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR-3D*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G
M:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P-0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R
M979I97<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H
M92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C(@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HS-C8*(RP@9G5Z>GD*;7-G:60@(E!R979I;W5S(&]P=&EO
M;G,B"FUS9W-T<B`B4')E<V5N=&%S:F]N87(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U
M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G
M:60@(E!R;V)L96TB"FUS9W-T<B`B6U!R;V)L96UR87!P;W)T72(*"B,Z('-E
M<G9I8V5S+W!R;V)L96TN<&AP.C$R-@IM<V=I9"`B4')O8FQE;2!$97-C<FEP
M=&EO;B(*;7-G<W1R(")3:VEL9')I;F<@878@<')O8FQE;65T(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,V.0IM<V=I9"`B4')O:F5C=',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q,2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@X"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R.#4*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B
M;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M-#0*;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0
M<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM
M<V=S='(@(D]F9F5N=&QE9R]P<FEV870@;OAK:V5L<&%R('9A<G0@:6MK:F4@
M9V5N97)E<G0N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8S"FUS9VED(")1=65R>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@
M(E%U;W1A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C8S"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@
M2V5Y("@E9"!B:70I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R-C0*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM
M<V=I9"`B4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M-0IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")286EN(%-H;W=E
M<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT-PIM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I
M9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(T
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(DQE<R(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"B,L(&9U>GIY"FUS9VED
M(")296%D(&UE<W-A9V5S(@IM<V=S='(@(DUE;&1I;F<B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E
M('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V
M92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA
M<W0@86-T:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G
M:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"B,L(&9U>GIY"FUS9VED
M(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R(")&<FES:R!O<'`@;W9E
M<G-I:W1V:7-I;F<Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(S-0HC+"!F=7IZ>0IM<V=I9"`B4F5G97@B"FUS9W-T
M<B`B3G5L;'-T:6QL(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(T
M.0IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(P.`HC+"!F=7IZ>0IM<V=I9"`B4F5L;V%D(@IM<V=S
M='(@(DQE<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V"FUS9VED(")2
M96UA<FMS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,30*(RP@9G5Z>GD*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(D9J
M97)N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED
M(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S"FUS9VED
M(")296UO=F4B"FUS9W-T<B`B1FIE<FXB"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VQA>6]U="YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!";&]C:R(*
M;7-G<W1R(")&:F5R;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HU-3<*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!C;VQU;6XB
M"FUS9W-T<B`B1FIE<FXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0P"B,L(&9U>GIY"FUS9VED(")296UO=F4@9F]R;6%T
M=&EN9R(*;7-G<W1R(")&:F5R;B!P87(B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B1FIE
M<FX@<&%R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B
M4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@HC+"!F=7IZ>0IM<V=I9"`B
M4F5M;W9E('1H92(*;7-G<W1R(")&:F5R;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M
M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q"B,L(&9U>GIY
M"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R(")&:F5R;B!P87(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R(")&:F5R
M;B!P87(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.`HC
M+"!F=7IZ>0IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@
M4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`B2W5N;F4@:6MK:F4@<W9A
M<F4@<.4@9OAR97-P=7)N860B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,34W"B,L(&9U>GIY"FUS9VED(")297%U97-T960@<V5R=FEC92!C
M;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(DMU;FYE(&EK:VIE('-V87)E
M('#E(&;X<F5S<'5R;F%D(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ-S0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3(*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF
M:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D[X9'9E;F1I9R`G
M=&%B;&4G(&EK:VIE('-P97-I9FES97)T(&D@:V]N9FEG=7)A<VIO;B!F;W(@
M5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C<U(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,P"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HW,C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R(").^&1V96YD:6<@)W1A8FQE)R!I:VMJ92!S<&5S
M:69I<V5R="!I(&MO;F9I9W5R87-J;VX@9F]R(%9&4RXB"@HC.B!F<F%M97=O
M<FLO571I;"]5=&EL+G!H<#HW.#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(D[X9'9E;F1I9R`G=&%B;&4G(&EK:VIE('-P97-I
M9FES97)T(&D@:V]N9FEG=7)A<VIO;B!F;W(@5D93+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER960@
M1FEE;&0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO
M4F5N9&5R97(N<&AP.C,R,"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G
M:60@(E)E<V5T(@IM<V=S='(@(DYU;&QS=&EL;"(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C0V"B,L(&9U>GIY"FUS9VED(")297-E="!087-S
M=V]R9"(*;7-G<W1R(")087-S;W)D(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O
M<F0B"FUS9W-T<B`B4W1A9&9E<W0@<&%S<V]R9"(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,S`*;7-G:60@(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE;&PN
M<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@HC+"!F=7IZ>0IM<V=I9"`B
M4F5S=6QT<R(*;7-G<W1R(").=6QL<W1I;&PB"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*
M;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(E1I;&)A:V4@=&EL
M(&%L=&5R;F%T:78B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,S@*;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S(*(RP@9G5Z>GD*;7-G:60@(E)I
M8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R(")4:6QB86ME('1I;"!A
M;'1E<FYA=&EV(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED
M(")2:61D;&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,0IM<V=I9"`B
M4FEG:'0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,Q,3<*(RP@9G5Z>GD*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G
M<W1R("),>7,@8FSE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N
M+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R(")2;VQL92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-0IM<V=I9"`B
M4F]T871E(#$X,"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C(R"FUS9VED(")2;W1A=&4@3&5F="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C(X"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM
M<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B
M4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3,*(RP@9G5Z>GD*;7-G:60@(E)U;&5S(@IM<V=S='(@(E)O
M;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A
M;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O
M=W,@;VYL>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P
M"B,L(&9U>GIY"FUS9VED(")2=6XB"FUS9W-T<B`B4V]L(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(E)W86YD82(*;7-G<W1R("),
M97,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM
M<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S"FUS
M9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A
M=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`T"B,L(&9U>GIY"FUS9VED
M(")335,@365S<V%G:6YG(@IM<V=S='(@(DUE;&1I;F<B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@S"FUS9VED(")344P@<W1A
M=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT,S$*;7-G:60@(E-32"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(B(*
M"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8Q"FUS9VED(")382(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED
M(")386EN="!(96QE;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED
M(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@W"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H
M92!'<F5N861I;F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S
M96QF*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")386UO82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0
M<FEN8VEP92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.`HC+"!F=7IZ
M>0IM<V=I9"`B4V%V92(*;7-G<W1R("),86=R92`G)7,G(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B3&%G<F4@)R5S)R(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(DQA9W)E("<E<R<B
M"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P
M=&EO;G,B"FUS9W-T<B`B3&%G<F4@86QT97)N871I=B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@
M=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V
M960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G
M:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(P"FUS9VED(")3
M96%R8V@@16YG:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.3<S"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-`HC
M+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")696P@9&%T
M;V9O<FUA=#HB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM
M<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE
M=R!O=VYE<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T
M(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PIM<V=I9"`B4V5L96-T(&%L;"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8S"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS
M9W-T<B`B5F5L(&1A=&]F;W)M870Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B:F5C
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-C<X"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(B(*
M(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE
M<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@
M9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B)696P@=&5I:VYA(&1U
M('1R96YG(&9RY2!B;VMS86YE('5N9&5R+B!$=2!K86X@<^4@:V]P:65R92!O
M9R!L:6UE(&1E:2!I;FX@9G+E("(*(G1E:W-T8F]K<V$N(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D
M96QI;6ET97(Z(@IM<V=S='(@(E9E;"!S:VEL:F5T96EK;B!F;W(@9&%T;SHB
M"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I9"`B4V5L96-T
M('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B5F5L(&1A=&]F;W)M870Z(@H*
M(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I
M9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"B,L(&9U
M>GIY"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R
M(")696P@<VMI;&IE=&5I:VX@9F]R(&1A=&\Z(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z
M(@IM<V=S='(@(E9E;"!T:61S9F]R;6%T.B(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE
M;&1S+B(*;7-G<W1R(")696P@=&\@<V%M<W9A<F%N9&4@9F5L="XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`V"FUS9VED(")396QE8W0@>6]U<B!C
M;VQO<B!S8VAE;64N(@IM<V=S='(@(E9E;"!F87)G97-K:F5M82XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0X"FUS9VED(")396QE8W0@>6]U<B!P
M<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(E9E;"#X;G-K82!S<'+E:SHB
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B
M4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")396YD('!R;V)L96UR87!P
M;W)T(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P,SD*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,38*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"B,L(&9U>GIY
M"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B365D;&5M;6%R(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I
M82!A;F0@36]N=&5N96=R;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q
M"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*(RP@9G5Z>GD*
M;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B5&EL9V%N9W-A9&UI;FES
M=')E<FEN9R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G
M<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#4*(RP@9G5Z>GD*;7-G:60@(E-E
M<W-I;VYS(@IM<V=S='(@(E1I;&=A;F<B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S$T"FUS9VED(")3970B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<V"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO
M=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G
M970@:70N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,34*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT
M('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0*(RP@9G5Z>GD*;7-G:60@(E-E="!Y
M;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T
M:6]N<RXB"FUS9W-T<B`B5F5L(/AN<VMA('-P<N5K.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY.`HC+"!F=7IZ>0IM<V=I9"`B(@HB4V5T('EO=7(@
M<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E
M<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@
M(E-E="!F87)G97-K:F5M82P@<VED96]P<&9R:7-K:6YG(&]G(&%N9')E('9I
M<VEN9W-A;'1E<FYA=&EV+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-S4*;7-G:60@(E-E='5P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C
M<FEP=',@879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ.#8*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O
M<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y-@IM<V=I9"`B4VAO<'!I;F<B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*
M(RP@9G5Z>GD*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B2V]R="!S
M86UA;F1R86<Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T-@IM<V=I
M9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN
M:W,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(E9I<R(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC
M97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE
M<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0Y,`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I
M;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P
M(&]R:6=I;F%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(X,3,*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C8*;7-G:60@(E-H;W<@=&%B;&4@;W!E
M<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E
M<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@
M(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S
M(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A
M8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*
M;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C,*;7-G:60@
M(E-H;W<@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4P"B,L(&9U>GIY"FUS9VED(")3:&]W97)S
M(@IM<V=S='(@(E9I<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4Q"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS
M9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@:6X@
M=&AE(%9I8VEN:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C0X,`IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<W-"!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HX,S8*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3(R(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.CDX-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HQ,#0W(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C$P.#<*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M,3$Q-B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,30Y"FUS
M9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T
M(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM
M<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HR-C4*;7-G:60@(E-I9VX@=7`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*
M;7-G:60@(E-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,0IM<V=I9"`B4VEG;F%T=7)E($%L9V]R
M:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#<@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0V(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Y,S`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R
M,PIM<V=I9"`B4VEZ92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N
M86YC92(*;7-G<W1R(")(;W!P(&]V97(@=F5D;&EK96AA;&0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`U"FUS9VED(")3;&]V86MI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`U"FUS9VED(")3;&]V96YI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B
M4VYO=R(*;7-G<W1R(")6:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*
M;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W
M97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`IM<V=I9"`B
M4VYO=R!D97!T:#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C@R"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,30@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O
M;F=S("8@4&]E;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,CDR-@IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$X.0HC+"!F=7IZ>0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B
M"FUS9W-T<B`B061R97-S92P@87)B96ED(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I
M9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA
M(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R
M"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED
M(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS
M9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q-0IM
M<V=I9"`B4W!A8V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@(E-P86TB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED
M(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R("));FYT87-T:6YG
M(&%V('-P97-I86QT96EK;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(E-P;W)T<R(*;7-G
M<W1R("));7!O<G0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S,@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B4W1A;F1A
M<F0B"FUS9W-T<B`B)7,@4W1A;F1A<F0B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(X,#D*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(E-T871E
M(&]R(%!R;W9I;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S
M971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-0HC+"!F=7IZ>0IM<V=I
M9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B1&EN(&EN9F]R;6%S:F]N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(*(RP@9G5Z
M>GD*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(D%D<F5S<V4L(&%R
M8F5I9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,PIM
M<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@HC+"!F=7IZ
M>0IM<V=I9"`B4W4B"FUS9W-T<B`B4V]L(@H*(SH@=71I;"]I8V]N7V)R;W=S
M97(N<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E
M8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B1F%N;B!I:VMJ92!V
M87)S96QL>71T87(@)7,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W;W)K+T9O<FTO
M1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3=6)M:70B"FUS9W-T<B`B
M(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3
M=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN
M(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S
M(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`T"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U
M<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B4W5K<V5S<R(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM
M<V=S='(@(DQA('1I;"`G)7,G('1I;"!S>7-T96UE="XB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`B1FIE<FYA("<E<R<@9G+E('-Y<W1E;65T+B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H
M<#HT-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R(")3;&5T=&$@)R5S)RXB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T96TN
M(@IM<V=S='(@(D9J97)N82`G)7,G(&9RY2!S>7-T96UE="XB"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V
M97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E
M9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C
M97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@7"(E
M<UPB(@IM<V=S='(@(E-L971T82`G)7,G+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS
M9W-T<B`B4VQE='1A("<E<R<N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`HC+"!F=7IZ>0IM
M<V=I9"`B4W5D86XB"FUS9W-T<B`B4V]L(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@HC+"!F=7IZ>0IM<V=I
M9"`B4W5M;6%R>2(*;7-G<W1R(")-:71T('-A;6%N9')A9R(*"B,Z(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X"B,L(&9U>GIY"FUS9VED
M(")3=6X@4V5T(@IM<V=S='(@(E-O;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"B,L(&9U>GIY"FUS9VED(")3=6YN>2(*
M;7-G<W1R(")3;VPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C$V"B,L(&9U>GIY"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(E-O;"(*"B,Z
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-0IM<V=I9"`B4W5N<FES93H@
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,3D*(RP@9G5Z>GD*;7-G:60@(E-U;G-E="(*;7-G<W1R(")3;VPB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$X"FUS9VED(")3=6YS970Z
M("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<X"B,L(&9U>GIY"FUS9VED
M(")3=7!P;W)T(@IM<V=S='(@(DEM<&]R="(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*(RP@
M9G5Z>GD*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(D)R=6MA<FYA;6XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`HC+"!F=7IZ
M>0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R(")"<G5K87)N86UN(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L;V<@
M9&5L971E9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,30R"FUS9VED(")3>6YC34PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-1
M3"]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@
M<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@
M(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")4+5-T;W)M
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM
M<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FUS($5A<FQY
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ
M-C8*(RP@9G5Z>GD*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(E1I='1E;"(*
M"B,Z(&9R86UE=V]R:R]522]522]486)L92YP:'`Z,3,T"B,L(&9U>GIY"FUS
M9VED(")486)L92(*;7-G<W1R(")4:71T96PB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED(")486)L
M92!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTO5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE(%-E="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM
M<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@
M;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3DV(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ.#<*;7-G:60@(E1A<VMS(@IM<V=S='(@(D]P<&?E=F5R(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E1E
M;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR.3`*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$T"FUS9VED(")496UP97)A
M='5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C(S"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N
M<&AP.C8X-PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$V.0HC+"!F=7IZ>0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB
M"FUS9W-T<B`B0G)U:V%R861M:6YI<W1R97)I;F<B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S
M,S8*;7-G:60@(E1E>'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,W-0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*
M;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y,0IM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"B,L(&9U>GIY"FUS9VED
M(")4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN(@IM<V=S='(@(D1U
M(&5R(&QO9V=A('5T+CQB<B`O/E1A:VL@9F]R(&%T(&1U(&)R=6MA<B!D971T
M92!S>7-T96UE="XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R
M,`IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T
M:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]";V]K+G!H<#HQ,CDR"FUS
M9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G
M:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C
M97-S9G5L;'DB"FUS9W-T<B`B2VQA<W-A($UA:6YT96YA;F-E.CH@=F%R="!I
M:VMJ92!L87-T82!I;FXB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K
M97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E
M9"X@17AI=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HQ.#D@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HR,C,*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR
M,S0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HR-C0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O
M;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO
M=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*
M;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I
M9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D
M871A8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38Y"FUS
M9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R
M97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A
M<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U
M;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B
M5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q,PIM<V=I
M9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W
M96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B2W)Y<'1E<FEN9W-F=6YK<VIO;F%N
M92!K<F5V(&5I('-I:VME<B!N971T;W!P:V]P;&EN9RXB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$W-2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C4Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U
M;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,38X(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H
M;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(Q.0IM<V=I9"`B5&AE(&9I
M;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(X,`HC+"!F=7IZ>0IM<V=I
M9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(DU3+51.
M148M=F5D;&5G9R!I;FYE:&5L9'0@:6YG96X@9&%T82XB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@
M9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F
M8S@R,B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S
M8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN
M=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@
M=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP
M97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U
M;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*
M(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T
M:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT
M)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N
M960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@
M=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!R969S+G!H<#HY,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$U-PIM<V=I
M9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B
M92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR,#$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W
M:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H
M:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@
M<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#<W"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE
M;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Q"B,L(&9U>GIY"FUS9VED
M(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S
M='(@(D1E;FYE('9E<F1I96X@;>4@=F5R92!E:70@=&%L+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,0IM<V=I9"`B5&AE(&]P
M96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?
M<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R
M969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET
M<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V1E
M8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O96YS8W)I
M<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS<&]W
M97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E8F-P
M<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<W)C:&EG
M:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS
M97AC96PN<&AP.C,R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W
M87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*(D9A;FX@
M:6MK:F4@<')O9W)A;6UE="!S;VT@8G)U:V%S="!T:6P@Y2!V:7-E(&1E;FYE
M('1Y<&5N(&UE;&1I;F=A<B`H)7,I+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C0U-`IM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T
M(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS
M9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V"FUS9VED
M(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B
M965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R
M<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@
M7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R
M97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@
M(E1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$W-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T
M(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,S$Q"FUS9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA
M=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*
M;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P
M;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR
M-C(@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE
M('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#8@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C4V"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ,34@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q.0IM
M<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3<X"B,L(&9U>GIY"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N
M<R!A=F%I;&%B;&4N(@IM<V=S='(@(DEN9V5N(&EN;G-T:6QL:6YG87(@97(@
M=&EL9VIE;F=E;&5G92XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HS-#(*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A
M;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N
M(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@
M96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP
M.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE
M('-Y<W1E;3H@)7,B"FUS9W-T<B`B4')O8FQE;2!M960@Y2!L96=G92!T:6P@
M)R5S)R!T:6P@<WES=&5M970N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E
M;3H@(@IM<V=S='(@(E!R;V)L96T@=F5D(&9J97)N:6YG(&%V("<E<R<@9G+E
M('-Y<W1E;65T+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN
M9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B4')O8FQE;2!V
M960@9FIE<FYI;F<@878@)R5S)R!F<N4@<WES=&5M970N(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,34Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B
M4')O8FQE;2!M960@Y2!L96=G92!T:6P@)R5S)R!T:6P@<WES=&5M970N(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@T"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@
M(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y,0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN
M9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#`*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A
M=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D
M(&9I96QD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@
M9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S
M(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B
M5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$T-0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO
M="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(D1E
M;FYE('9E<F1I96X@;>4@=F5R92!E:70@=&%L+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G
M:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@(B(*
M(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S
M:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T
M:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A
M>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V
M:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y
M+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M
M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W
M=RXQ.3`N:70I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`U-PHC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X,B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y.`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-34W(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU."!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`U"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(P,CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`W.`HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,30Y(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q
M,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4T"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(V-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R
M.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3,W(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,S,#8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S@Q-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#(R"FUS9VED(")4:&ES
M(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(T,3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@
M9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T
M(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.CDX.0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E
M(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R(")$96YN92!V97)D:65N(&WE('9E
M<F4@96ET('1A;"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V
M"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O
M9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R
M,S1A9B<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C4V,0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S
M<V5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0U.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C
M="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL
M("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A
M<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT
M<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z-3DQ"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@
M*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB
M97(@;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(D1E='1E('1A;&5T
M(&WE('9E<F4@;6EN<W0@96EN+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@
M=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED
M(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS
M9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(D1E
M;FYE('9E<F1I96X@;>4@=F5R92!E:70@=&%L+B(*"B,Z('-E<G9I8V5S+VEM
M86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU
M<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*
M;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(S-`IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(X('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B5&EM92(*;7-G<W1R(")4
M:71T96PB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@V"FUS9VED
M(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE
M+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S.0IM<V=I9"`B5&EM92!S96QE8W1I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S
M=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B
M5&ET;&4B"FUS9W-T<B`B5&ET=&5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C4T"FUS9VED("(B"B)4
M;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O
M;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S$Q"FUS9VED(")4;V1A>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-
M3"!3;W5R8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G
M;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3,*
M;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G
M:60@(E1O;F=A(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3,*;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")4<F%N<VQA
M=&EO;G,B"FUS9W-T<B`B4')E<V5N=&%S:F]N87(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q
M"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W.3`*;7-G:60@(E1R=64@;W(@9F%L
M<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q
M"B,L(&9U>GIY"FUS9VED(")4=7)K97DB"FUS9W-T<B`B1W+E(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y
M+3DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM96YI
M<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A
M;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM
M<V=I9"`B5'5V86QU(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)
M+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8Y"FUS9VED(")5
M+E8N(&EN9&5X.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ
M-PIM<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R
M('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M-PHC+"!F=7IZ>0IM<V=I9"`B55),.B(*;7-G<W1R(")54DPB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,@HC+"!F=7IZ>0IM<V=I9"`B56MR86EN92(*;7-G<W1R(")/<F%N<VIE(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$R"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@
M(DMA;B!I:VMJ92!K;W!L92!T:6P@4U%,+71E;F%R+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O(&%D
M9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS.#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N
M(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C,X-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N
M9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4U"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G
M<W1R(")+86X@:6MK:F4@:V]P;&4@=&EL(%-13"UT96YA<BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S,@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N
M(@IM<V=S='(@(DMU;FYE(&EK:VIE('-L971T92`G)7,G.B`E<RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV.#@@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HQ,#$V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HX,S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R(")+=6YN
M92!I:VMJ92!S;&5T=&4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S<6PN<&AP.C0S-0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@
M4U%,('-E<G9E<BXB"FUS9W-T<B`B2V%N(&EK:VIE(&MO<&QE('1I;"!344PM
M=&5N87(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,SD*(RP@
M9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G
M<W1R(")+86X@:6MK:F4@:V]P;&4@=&EL(%-13"UT96YA<BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,C4@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P,0HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EK
M:VIE(&MO<&QE('1I;"!344PM=&5N87(N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HS-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S4T(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C(U-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!6
M1E,@9&ER96-T;W)Y+B(*;7-G<W1R(")+86X@:6MK:F4@:V]P;&4@=&EL(%-1
M3"UT96YA<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*
M;7-G<W1R(")+86X@:6MK:F4@:V]P;&4@=&EL(%-13"UT96YA<BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(X-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<
M(BXB"FUS9W-T<B`B2W5N;F4@:6MK:F4@<VQE='1E("<E<R<Z("5S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(V-0HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B
M2V%N(&EK:VIE(&MO<&QE('1I;"!344PM=&5N87(N(@H*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-S8*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R(")+=6YN92!I:VMJ
M92!S;&5T=&4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HR,C0@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR.3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D
M:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB
M.B`E<RXB"FUS9W-T<B`B2W5N;F4@:6MK:F4@<VQE='1E("<E<R<Z("5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE
M(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T."!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S-R!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS
M,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0T"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DMU;FYE
M(&EK:VIE('-L971T92`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C0Q-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0R.0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B2W5N;F4@:6MK:F4@<VQE='1E
M("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C`W
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B2W5N;F4@:6MK:F4@<VQE='1E
M("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,P
M,R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(X.`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,38W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HQ.#`*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X-R!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S@S"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.3$*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@(DMU;FYE(&EK:VIE
M('-L971T92`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C(T-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B2W5N;F4@:6MK
M:F4@<VQE='1E("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z-#`V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(DMU;FYE
M(&EK:VIE('-L971T92`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C@P,PHC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E=&5R
M;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B2V%N(&EK:VIE(')E
M9VES=')E<F4@:6YN<W1I;&QI;F=A<B!I(/AK=&$N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#,*;7-G:60@(E5N86)L92!T;R!E
M>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0U,2!F<F%M97=O<FLO3F5T7TE-
M4U`O24U34"]!=71H+G!H<#HQ,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G
M<W1R(")+=6YN92!I:VMJ92!S;&5T=&4@)R5S)SH@)7,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,38V(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-S$*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R(")+
M86X@:6MK:F4@:V]P;&4@=&EL(%-13"UT96YA<BXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.CDS(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M,3`R"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C0X(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M2W5N;F4@:6MK:F4@<VQE='1E("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(W-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ
M,S,*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX
M,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EK:VIE(&MO<&QE
M('1I;"!344PM=&5N87(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HT-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&]P96X@
M8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R(")+86X@:6MK:F4@:V]P;&4@
M=&EL(%-13"UT96YA<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#,U
M"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F
M86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M.#8V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I
M>F4H*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R(")+=6YN92!I
M:VMJ92!S;&5T=&4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z-C8Y"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O
M="!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E
M>&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C(Y,PHC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!6
M1E,@9&ER96-T;W)Y+B(*;7-G<W1R(")+86X@:6MK:F4@:V]P;&4@=&EL(%-1
M3"UT96YA<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E
M8W1O<GDZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C(V-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z-C$P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4@)7,O)7,N(@IM<V=S='(@(DMU;FYE(&EK:VIE('-L971T92`G)7,G.B`E
M<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R,R!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C(X-0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP
M:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G
M+B(*;7-G<W1R(")+=6YN92!I:VMJ92!S;&5T=&4@)R5S)SH@)7,N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I
M9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS
M9W-T<B`B2V%N(&EK:VIE(&]M<V5T:F4@9&5T=&4@5V]R9"UD;VMU;65N=&5T
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,30Y(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,34R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M(")+=6YN92!I:VMJ92!S;&5T=&4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,30S"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T
M82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@T,0IM
M<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E
M(&5X8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD
M;R!#:&%N9V5S(@IM<V=S='(@(D%N9W)E(&5N9')I;F=A<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N
M9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PHC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*(RP@9G5Z>GD*;7-G:60@
M(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO
M;CH@(@IM<V=S='(@(E5G>6QD:6<@<W9A<B!F<N4@=&5N87(B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W.`HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*(RP@9G5Z>GD*;7-G:60@
M(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R
M(")59WEL9&EG('-V87(@9G+E('1E;F%R(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@
M(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I
M9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<T"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@
M27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-CD@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,0IM<V=I9"`B56YI=',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#(Y(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S,`IM<V=I9"`B
M56YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G
M:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5
M;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@
M(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM
M<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP
M.C(Y-@HC+"!F=7IZ>0IM<V=I9"`B56YN86UE9"(*;7-G<W1R(")"<G5K87)N
M86UN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C
M8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E
M8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@
M;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O
M(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.CDS,@IM<V=I9"`B56YS=7!P;W)T960@17AT
M96YS:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS
M9VED(")5<&1A=&4B"FUS9W-T<B`B3W!P9&%T97(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B3W!P9&%T97)T92`G)7,G+B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*(RP@9G5Z
M>GD*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(D]P<&1A=&5R(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R
M('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R(")/<'!D871E
M<G1E("<E<R<N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G
M:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Y.0IM<V=I9"`B57!L;V%D(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#8*;7-G:60@(E5P;&]A9&5D
M(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E
M<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-
M86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N
M=#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B57-E(&EF
M(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHR,0HC+"!F=7IZ>0IM<V=I9"`B57-E<B(*;7-G<W1R(")"<G5K87)A<B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S(S"B,L
M('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@
M9F]R("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G
M:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B0G)U:V%R861M:6YI
M<W1R97)I;F<B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(U
M,0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(D)R=6MA<F%L=&5R;F%T
M:78B"@HC.B!S:6=N=7`N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")5<V5R(%)E
M9VES=')A=&EO;B(*;7-G<W1R(")"<G5K87)A9&UI;FES=')E<FEN9R(*"B,Z
M('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B
M965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@86-C;W5N="!N
M;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHW,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I
M9"`B57-E<FYA;64B"FUS9W-T<B`B0G)U:V%R;F%M;B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*(RP@9G5Z>GD*
M;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(")"<G5K87)N86UN(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B57-E
M<FYA;64Z("(*;7-G<W1R(")"<G5K87)N86UN(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E
M;3HB"FUS9W-T<B`B0G)U:V%R87(@:2!S>7-T96UE=#HB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$T"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C$V,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR-34*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3@*
M;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C@V-@IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN
M8VQU9&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8S.`IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C4U"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-38@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")686QU
M92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR.`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P
M.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@V"FUS9VED(")686QU97,@
M=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I
M9"`B5F%N=6%T=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C0T"FUS9VED(")687)I86)L92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF
M:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T
M86UP97)E9"!W:71H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C<P,`HC+"!F=7IZ>0IM<V=I9"`B5F5R<VEO;B(*
M;7-G<W1R(")4:6QG86YG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(R-@IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*
M;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I
M8V%L('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C<P"FUS9VED(")697)Y($AI9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-@IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.30*;7-G:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.38R
M"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA
M;"!W96(@<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HX,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A
M<R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@
M27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS
M9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(P.0IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8S"FUS9VED
M(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F
M;VYE($ET86QY('9I82!33510(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z
M,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!2
M14U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED
M(")724X@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I
M9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H
M<#HR.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR
M-S(@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM
M<V=S='(@(L5T=F%R:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O
M<F5C87-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HT,C<*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3(*;7-G:60@
M(E=E871H97(N8V]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0S-PIM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.`IM
M<V=I9"`B5V5E:VQY(@IM<V=S='(@(DMV87(@=F5K92(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]M;V)I;&4N<&AP.C(X"B,L(&9U>GIY"FUS9VED(")796QC;VUE
M(@IM<V=S='(@(E9E;&MO;65N+"`E<R(*"B,Z('1E;7!L871E<R]L;V=I;B]M
M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(E9E;&MO
M;65N('1I;"`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y
M('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")796QC;VUE+"`E<R(*;7-G<W1R(")696QK;VUE;BP@)7,B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X
M-3DM,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*
M;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO
M9VEN/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*
M;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M-C$*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"FUS9VED
M(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E
M9&ET;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C4*;7-G:60@(E=I
M9'1H(&EN($-34R!U;FET<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S4W"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H
M92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L
M;V<M:6XI.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS
M9VED(")7:61T:#HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C4Q,PIM<V=I9"`B5VEK:2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")7:6YD(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED
M(")7:6YD($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-38*;7-G:60@(E=I;F0Z(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#(*;7-G
M:60@(E=I;F0Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3DV"FUS9VED(")7:7-H;&ES="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B061R97-S92P@
M87)B96ED(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")496QE9F]N+"!A
M<F)E:60B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-CD@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G
M:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T
M960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HS,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@
M;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I
M;F<@82!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(T,PIM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV
M,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P.78S($5X=&5N
M9&5D($ME>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT
M97)N871I=F4@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y
M($ED96YT:69I97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV.#(*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*
M;7-G<W1R("+%Q2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0U-0HC+"!F=7IZ>0IM<V=I9"`B65E962(*;7-G<W1R("+%Q2(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3`X
M"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*
M;7-G<W1R("+%<FQE9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@
M(EEE;65N(@IM<V=S='(@(D=R^&XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(")997,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*
M;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R(")*82P@96<@97(@<V%M9"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*
M;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U
M='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N
M("5D(&)L;V-K<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ-#$Q"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN
M<&AP.C,P,@IM<V=I9"`B66]U(&-A;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R
M86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DW-0HC+"!F=7IZ>0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V
M86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R(")+=6YN92!I:VMJ92!A=F=J
M97)E(&UO='1A:V%R96X@<VD@92UP;W-T861R97-S92XB"@HC.B!F<F%M97=O
M<FLO1&%T82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F
M:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"B,L(&9U
M>GIY"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@
M(D%L=&5R;F%T:79A(&1I;F4@:&%R(&)L:71T(&]P<&1A=&5R=&4N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA
M=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@
M;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T
M:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Q.#@*;7-G:60@(EEO=2!H879E('1O(&5N=&5R
M(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E
M(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-38*;7-G:60@(EEO
M=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U
M(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N
M9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(D1U(&WE('-K:6QD<F4@
M<')O8FQE;65T(&;X<B!D=2!K86X@<V5N9&4@<')O8FQE;7)A<'!O<G1E;BXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX
M"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN
M:R!P;VEN=',@=&\B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P
M8W-U;2YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A
M;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B1'4@;>4@<W!E<VEF
M:7-E<F4@96ET(&)R=6MA<FYA;6X@Y2!F:F5R;F4N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3$Y"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@
M=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R(")$=2!MY2!S<&5S:69I
M<V5R92!E:70@8G)U:V%R;F%M;B#E(&9J97)N92XB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!R96UO=F4N(@IM<V=S='(@(D1U(&WE('-P97-I9FES97)E(&5I="!B<G5K
M87)N86UN(.4@9FIE<FYE+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R(")$=2!MY2!S
M<&5S:69I<V5R92!E:70@8G)U:V%R;F%M;B#E(&QE9V=E('1I;"XB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ-#8*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P
M96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B1'4@;>4@
M<W!E<VEF:7-E<F4@96ET(&)R=6MA<FYA;6X@Y2!L96=G92!T:6PN(@H*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,X"B,L(&9U
M>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E
M<F9O<FTN(@IM<V=S='(@(D1U(&WE('-P97-I9FES97)E(&5I="!B<G5K87)N
M86UN(.4@9FIE<FYE+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E
M9V]R>4UA;F%G97(N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!T
M>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(D1U(&WE('-P97-I
M9FES97)E(&5I="!B<G5K87)N86UN(.4@9FIE<FYE+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED
M(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER
M960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`BV&MT82!D:2`H)7,I
M(&AA<B!GY71T('5T('#E('1I9"X@3&]G9R!I;FX@<.4@;GET="XB"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`HC+"!F=7IZ>0IM<V=I
M9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(D1I(&4M<&]S=&%D<F5S
M<V4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q,@HC+"!F=7IZ>0IM
M<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")$:2!E+7!O<W1A
M9')E<W-E.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-"!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B66]U<B!);F9O<FUA
M=&EO;B(*;7-G<W1R(")$:6X@:6YF;W)M87-J;VXB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U
M<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I
M;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@
M<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PHC+"!F=7IZ>0IM
M<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(D1I='0@;F%M;CHB"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B
M(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O
M<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@
M=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D
M:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B
M075T96YT:7-E<FEN9W-B86MD96QN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;F]L:7-T+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T
M:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE
M<B!R96%S;VXN(@IM<V=S='(@(B(*(DQI<W1I;F<@878@8G)U:V%R87(@97(@
M:6MK:F4@<W3X='1A(&%V(&)A:W)E(&%U=&5N=&ES97)I;F<L(&5L;&5R(&9U
M;FMS:F]N96X@(@HB:&%R(&%V(&5I;B!E;&QE<B!A;FYA;B!G<G5N;B!B;&ET
M="!S;.5T="!A=BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@
M=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E
M<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M
M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R
M86UE+G!H<#HU,`IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O
M97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R
M;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3<*;7-G:60@(EEO=7(@8W5R<F5N="!T
M:6UE('IO;F4Z(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY
M-@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B
M965N(&-H86YG960N(@IM<V=S='(@(D%L=&5R;F%T:79A(&1I;F4@:&%R(&)L
M:71T(&]P<&1A=&5R=&4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U
M.`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G
M<W1R(")3=&%N9&%R9&ED96YT:71E="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,#$*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G
M<W1R(")$:71T(&YA;6XZ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M,3`P,`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB
M"FUS9W-T<B`B06QT97)N871I=F$@9&EN92!H87(@8FQI='0@;W!P9&%T97)T
M92XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,34T"B,L(&9U>GIY"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P
M9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S
M='(@(D%L=&5R;F%T:79A(&1I;F4@:&%R(&)L:71T(&]P<&1A=&5R=&4N(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO
M=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`B06QT97)N
M871I=F$@9&EN92!H87(@8FQI='0@;W!P9&%T97)T92XB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H
M87,@8F5E;B!R97-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U
M<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.C<S,@IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP
M:7)E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G
M:60@(EIA:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA
M;6)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G
M:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U
M;W1E9"!497AT72(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H
M<#HX.`IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");4')O8FQE
M;7)A<'!O<G1=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C
M:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q
M=6]T97,N<&AP.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T
M960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN
M92`E<R!O9B`E<UTB"FUS9W-T<B`B6VQI;FIE("5S(&%V("5S72(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34T,2!T96UP;&%T97,O<&]R=&%L
M+VUE;G4N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")?061M:6YI<W1R871I;VXB
M"FUS9W-T<B`B061M:6YI<W1R97)I;F<B"@HC.B!L:6(O87!I+G!H<#HQ-3<*
M;7-G:60@(E]#3$DB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS
M9VED(")?1&%T851R964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"B,L(&9U>GIY"FUS
M9VED(")?1&5L971E(%)O=R(*;7-G<W1R(")3;&5T=&4B"@HC.B!L:6(O87!I
M+G!H<#HQ,S,*(RP@9G5Z>GD*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B1W)U
M<'!E<B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4*
M(RP@9G5Z>GD*;7-G:60@(E](96QP(@IM<V=S='(@(DAJ96QP(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S
M"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"B,L(&9U>GIY"FUS
M9VED(")?3&]G(&EN(@IM<V=S='(@(DQO9V<@:6YN(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`HC+"!F=7IZ>0IM<V=I9"`B7TQO
M9R!O=70B"FUS9W-T<B`B3&]G9R!U="(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF
M>2!,:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]-96YU+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G:60@(E]/<'1I;VYS(@IM<V=S
M='(@(D%L=&5R;F%T:78B"@HC.B!L:6(O87!I+G!H<#HQ,S<*(RP@9G5Z>GD*
M;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R(")4:6QG86YG(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V
M"B,L(&9U>GIY"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B1FIE
M<FX@<&%R(@H*(SH@;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*
M;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,CD*(RP@9G5Z>GD*;7-G:60@
M(E]5<V5R<R(*;7-G<W1R(")"<G5K87)A<B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3(Q"B,L(&9U>GIY"FUS9VED(")A9&1R97-S(&)O;VLB
M"FUS9W-T<B`B061R97-S96)O:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ,PHC+"!F
M=7IZ>0IM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B2V%L96YD97(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN
M;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E
M;B!I;G!U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HU.3(*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@
M(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W.`IM<V=I9"`B8V]N9FEG
M=7)A=&EO;B!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I
M;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M.#(*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B9F%L
M;&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R
M+G!H<#HX-34*(RP@9G5Z>GD*;7-G:60@(F9I;&4B"FUS9W-T<B`B5&ET=&5L
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-C`@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4P"FUS9VED(")G
M=7-T:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR-#D*;7-G:60@(F@Z(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-3@*;7-G:60@
M(FAH(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM
M<V=I9"`B:6YL:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S
M"B,L(&9U>GIY"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B3W9E<G-K<FEF=&5R
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O
M9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@
M8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8Y"FUS9VED(")M
M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C(Y,2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,S(*(RP@9G5Z>GD*;7-G:60@(FYA
M;64B"FUS9W-T<B`B3F%M;B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ
M,C$*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,3D*;7-G:60@(FYO="!Y
M970@:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,#4*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$W-`HC+"!F=7IZ>0IM<V=I9"`B<&5R;6ES
M<VEO;B!D96YI960B"FUS9W-T<B`B5&EL9V%N9R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I
M>&5L<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C<S"B,L(&9U>GIY"FUS9VED(")R:7-I;F<B"FUS9W-T<B`BQ71V87)I
M;F<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@IM
M<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.CDY"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,X-0IM<V=I9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(G-T
M96%D>2(*;7-G<W1R("),97,B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C,P.0IM<V=I9"`B<W=I=&-H(&]F9B!J879A<V-R:7!T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS
M9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,CD*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I
M9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HS,#4*(RP@9G5Z>GD*;7-G:60@(G1R>2!A9V%I
M;B(*;7-G<W1R(")+=F%R(&EN;FQO9V=I;F<B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS-B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED
M(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*
M;7-G:60@(G9#87)D(@IM<V=S='(@(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T,0IM<V=I9"`B=SHB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@
M(G=E871H97(N8V]M(@IM<V=S='(@(B(*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O<&Q?4$PN<&\`````````````
M````````````````````````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#8R,#`Q-0`Q
M,#4Q-30S,S<U-``P,3<V-#<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````(R!(3U)$12!0;VQI<V@@=')A;G-L871I;VXN"B,@
M0V]P>7)I9VAT("A#*2`R,#`Q($UA<FEU<WH@6GEN96P@/&UA<FEU<WI`;6EZ
M87(N;W)G/@HC($UA<FEU<WH@6GEN96P@/&UA<FEU<WI`;6%T:"YU=V(N961U
M+G!L/BP@,C`P,2X*(R!0:6]T<B!2;W-Z871Y8VMI(#QD97AT97)`9&5B:6%N
M+F]R9SXL(#(P,#$N"B,@2W)Z>7-Z=&]F($MO>FQO=W-K:2`\:V]Z:6LQ0&\R
M+G!L/BP@,C`P-2X*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M
M5F5R<VEO;CH@2&]R9&4@,RXP+6-V<UQN(@HB4F5P;W)T+4US9VED+4)U9W,M
M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E
M.B`R,#`U+3$Q+3(T(#(P.C4V*S`Q,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z
M(#(P,#4M,3$M,C0@,C$Z-#8K,#$P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!+
M<GIY<WIT;V8@2V]Z;&]W<VMI(#QK;WII:S%`;S(N<&P^7&XB"B),86YG=6%G
M92U496%M.B!0;VQI<V@@/'!L0&QI+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@
M,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O
M+3@X-3DM,EQN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:71<
M;B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI;F,Z
M,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB("8C,34Q.R`E<R!I<R!R96%D
M>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K
M960@8F5L;W<N(@IM<V=S='(@(B5S("T@9V]T;W=Y(&1O('=Y:V]N86YI82!C
M>6ML:6-Z;GEC:"!O<&5R86-J:2!Z87IN86-Z;VYY8V@@<&]N:;]E:BXB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,V.`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*"5S(&1N:2!T96UU*2(*"B,Z
M(&QI8B](;W)D92YP:'`Z,3(U-@HC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C
M8V5S<VME>2`E<RDB"FUS9W-T<B`B*&ML=6-Z(&1O<W3J<'4@)7,I(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M("AI;B`E<R!D87ES*2(*;7-G<W1R("(@*'<@8VFQ9W4@)7,@9&YI*2(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,S<R"FUS9VED("(@*'1O9&%Y*2(*;7-G
M<W1R("(@*&1Z:;8I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S0*;7-G
M:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(B`H:G5T<F\I(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(S-S`*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R
M("(@*'=C>F]R86HI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(T-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0Y"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.34*;7-G:60@(B!A="`B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@
M(EPB)7-<(B!N:64@:F5S="!P<F%W:62S;W=Y;2!W>6)O<F5M+B(*"B,Z(&QI
M8B](;W)D92]296=I<W1R>2YP:'`Z-34T(&QI8B](;W)D92]296=I<W1R>2YP
M:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N
M9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(EPB)7-<
M(B!N:64@:F5S="!S:V]N9FEG=7)O=V%N>2!W(')E:F5S=')Z92!(;W)D92XB
M"@HC.B!L:6(O2&]R9&4O5')E92YP:'`Z,38T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B5S(&YI97IN86QE>FEO;GDN(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O
M('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R(")59&&S;R!S:>H@9&]D8>8@
M7"(E<UPB(&1O(&=R=7`N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP
M.C@U"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@
M=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B561ALV\@<VGJ(&1O
M9&'F(%PB)7-<(B!D;R!U<')A=VYI9?$N(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HU-2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z.#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@
M(EPB)7-<(B!N:64@>F]S=&&S('5T=V]R>F]N>3H@)7,N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B)60@)7,@:2`E<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]N;W1I8V5?=&]P+FEN8SHT"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S("T@57=A9V$B"@HC.B!T96UP
M;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z,S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R
M86-J82`E<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`T"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B5S
M(&]D8VES:R!P86QC82(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H
M<#HX,S`@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@S,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!K0B(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI;F,Z-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER
M;6%T:6]N(@IM<V=S='(@(B5S("T@;W!E<F%C:F4@8WEK;&EC>FYE("T@<&]T
M=VEE<F1Z96YI92(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C(Q.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!3971U<"(*;7-G<W1R(")+;VYF:6=U<F%C:F$@)7,B"@HC.B!L:6(O2&]R
M9&4O075T:"]3:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!3:6=N(%5P(@IM<V=S='(@(E)E:F5S=')A8VIA("5S(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+V%G<F5E;65N=%]T;W`N:6YC.C0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B(*
M"B,Z(&QI8B]61E,O9G1P+G!H<#HU-C@@;&EB+U9&4R]F='`N<&AP.C8S-@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T
M<B`B)7,@:G6_(&ES=&YI96IE+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,34Y(&QI8B]";&]C:R]M971A<BYP:'`Z,38U(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C,Y"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S0U(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S4Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A
M="`E<R`E<R(*;7-G<W1R("(E<R!D;R`E<R!Z("5S(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(S,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q
M=6ER960B"FUS9W-T<B`B)7,@:F5S="!W>6UA9V%N>2(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C@V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T
M97,B"FUS9W-T<B`B)7,@;6EN=70B"@HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L
M;&5C=&EO;BYP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F
M;W5N9"XB"FUS9W-T<B`B)7,@;FEE>FYA;&5Z:6]N>2XB"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B5S(&1O("5S('H@)7,B"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.C@Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R(")+<VFQOVMA(&%D<F5S;W=A("5S
M(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HX.#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R(")+86QE;F1A<GH@)7,B"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.C@W-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R=S($YO=&5P860B"FUS9W-T<B`B3F]T871N:6L@)7,B"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.C@Y.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S
M(%1A<VML:7-T(@IM<V=S='(@(DQI<W1A('IA9&'Q("5S(@H*(SH@;&EB+TAO
M<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4S(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS.3@*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(BP@9W5S=&EN
M9R`E<R`E<R(*;7-G<W1R("(E<R!D;R`E<R!Z("5S(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L
M92!F<F]M("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,#<P(&QI8B](;W)D92]&;W)M+G!H<#HR,3(Y"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HV.#@*;7-G:60@(BTM('-E;&5C
M="`M+2(*;7-G<W1R("(M+2!W>6)I97)Z("TM(@H*(SH@;&EB+T)L;V-K+W1I
M;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R("(Q,BUG
M;V1Z:6YN>2!F;W)M870B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G
M:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(C(T+6=O9'II;FYY(&9O<FUA
M="(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H
M;W5R<R(*;7-G<W1R("(R-"!G;V1Z+B(*"B,Z(&QI8B](;W)D92]522]086=E
M<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(\4&]P<GIE9&YI
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*(RP@9G5Z>GD*;7-G:60@
M(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C
M:RXB"FUS9W-T<B`B0G)A:R!K;VYF:6=U<F%C:FD@=V5W;NIT<GIN96H@9&QA
M('1E9V\@:&]S=&$B"@HC.B!L:6(O2&]R9&4N<&AP.C$V,`IM<V=I9"`B02!F
M871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B3F%S=+%P:;,@8K.Q
M9"!K<GET>6-Z;GDB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY,C`*
M;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP
M="!A(&UE<W-A9V4N(@IM<V=S='(@(E!O=')Z96)N>2!J97-T(&ML=6-Z('!U
M8FQI8WIN>2!01U`@9&\@>F%S>GEF<F]W86YI82!W:6%D;VUOMF-I+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q-#4*;7-G:60@(D$@<'5B;&EC
M(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A
M9V4N(@IM<V=S='(@(B(*(E!O=')Z96)N>2!J97-T(&ML=6-Z('!U8FQI8WIN
M>2!01U`@9&\@<W!R87=D>F5N:6$@<&]D<&ES86YE:B!W:6%D;VUOMF-I+B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P-S<*;7-G:60@(B(*(D$@
M<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G
M<W1R("(B"B)0;W1R>F5B;F4@<[$@:VQU8WH@<'5B;&EC>FYY(%!'4"P@:VQU
M8WH@<')Y=V%T;GD@4$=0(&]R87H@:&%SLV\@9&\@(@HB;V1S>GEF<F]W86YI
M82!W:6%D;VUOMF-I+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDY
M-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE
M<W-A9V4N(@IM<V=S='(@(B(*(E!O=')Z96)N92!SL2!K;'5C>B!P=6)L:6-Z
M;GD@4$=0+"!K;'5C>B!P<GEW871N>2!01U`@;W)A>B!H87.S;R!D;R`B"B)P
M;V1P:7-A;FEA('=I861O;6^V8VDN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU,#4*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R
M:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B)0;W1R>F5B
M;F4@<[$@:VQU8WH@<'5B;&EC>FYY(%,O34E-12P@:VQU8WH@<')Y=V%T;GD@
M4R]-24U%(&]R87H@:&%SLV\@9&\@(@HB;V1S>GEF<F]W86YI82!W:6%D;VUO
MMF-I+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED
M("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S
M<V%G92XB"FUS9W-T<B`B(@HB4&]T<GIE8FYE('.Q(&ML=6-Z('!U8FQI8WIN
M>2!3+TU)344L(&ML=6-Z('!R>7=A=&YY(%,O34E-12!O<F%Z(&AA<[-O(&1O
M("(*(G!O9'!I<V%N:6$@=VEA9&]M;[9C:2XB"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES
M(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")0;W1R
M>F5B;GD@:F5S="!K;'5C>B!P=6)L:6-Z;GD@4TU)344@9&\@>F%S>GEF<F]W
M86YI82!W:6%D;VUOMF-I+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.CD*(RP@9G5Z>GD*;7-G:60@(D%-($-L;W5D<R(*;7-G
M<W1R("):86UK;FEJ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3`*(RP@9G5Z>GD*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS
M9W-T<B`B6F%L;V=U:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C$Q"B,L(&9U>GIY"FUS9VED(")!32!286EN(@IM<V=S='(@
M(D]S=')Z9;]E;FEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3(*(RP@9G5Z>GD*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T
M<B`B26UP;W)T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3,*(RP@9G5Z>GD*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G
M<W1R("));7!O<G0B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM
M<V=I9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(D\@='EM(&5D
M>71O<GIE(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3(*;7-G:60@
M(D%B;W5T+BXN(@IM<V=S='(@(D\@<')O9W)A;6EE+BXN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S
M8F]T=&]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S(*(RP@9G5Z>GD*;7-G:60@(D%B<VUI9&1L92(*
M;7-G<W1R(")3=&%N;W=I<VMO(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,C<P
M"B,L(&9U>GIY"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@
M>B!S97)W97)E;2!344PN(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3,V"B,L
M(&9U>GIY"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE
M+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R
M96T@4U%,+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-0IM<V=I9"`B
M06-C;W5N="!087-S=V]R9"(*;7-G<W1R(")(87.S;R!D;R!K;VYT82(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!
M8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B2V]N=&\@>F%B;&]K;W=A;F4N(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,Q-PIM<V=I9"`B06-C;W5N
M=&EN9R(*;7-G<W1R(")+;VYT82(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD
M+G!H<#HU-"!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$S,@HC.B!T96UP;&%T
M97,O<&]R=&%L+V%D9"YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A
M9&1C:&EL9"YI;F,Z,38*;7-G:60@(D%D9"(*;7-G<W1R(")$;V1A:B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,C$T(&%D;6EN+V=R;W5P<RYP:'`Z,C$U"B,L
M(&9U>GIY"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B1&]D86H@
M;F]WL2!G<G5PZB(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z.#0@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HX-0HC+"!F=7IZ>0IM<V=I9"`B061D($-H
M:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B1&]D86H@;F]W92!U<')A=VYI96YI
M92(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@
M2&5R93HB"FUS9W-T<B`B1&]D86H@='5T86HZ(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HR,#@@861M:6XO9W)O=7!S+G!H<#HR,#D*;7-G:60@(D%D9"!.97<@
M1W)O=7`B"FUS9W-T<B`B1&]D86H@;F]WL2!G<G5PZB(*"B,Z(&QI8B](;W)D
M92]097)M<R]522YP:'`Z-S,@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HW-`IM
M<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(D1O9&%J(&YO=V4@
M=7!R87=N:65N:64B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H
M:6QD+FEN8SHY"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C
M:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B3W!C:F4@)7,B"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3,@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HQ,S$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H
M:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(D]P8VIE("5S(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*
M;7-G<W1R(")$;V1A:B!N;W=E9V\@=;]Y=&MO=VYI:V$Z(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM<V=I9"`B061D(&-O
M;'5M;B(*;7-G<W1R(")$;V1A:B!K;VQU;6[J(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHS-0IM<V=I9"`B061D(&YE=R!M96UB97)S
M(@IM<V=S='(@(D1O9&%J(&YO=WEC:"!C>K-O;FOS=R(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R
M(")$;V1A:B!P87+J(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII
M;&QA(%-I9&5B87(B"FUS9W-T<B`B1&]D86H@;65N=2`E<R!D;R!P87-K82!-
M;WII;&QI(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HW
M,0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B1&]D86H@
M9&\@:W-IL;]K:2!A9')E<V]W96HZ(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HW.`IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O
M:R(*;7-G<W1R(")$;V1A:B!D;R!M;VIE:B!K<VFQ>FMI(&%D<F5S;W=E:B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R
M(")$;V1A:B!UOWET:V]W;FEK82(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@
M=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N
M=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R(")$;V1A;F\@7"(E<UPB
M(&1O('-Y<W1E;74N($UOOV5S>B!S:>H@>F%L;V=O=V'F+B(*"B,Z('-I9VYU
M<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O
M('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B1&]D
M86YO(%PB)7-<(B!D;R!S>7-T96UU+B!-;[]E<WH@<VGJ('IA;&]G;W=AYBXB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-`IM<V=I9"`B
M061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")$;V1A=V%N:64@
M=;]Y=&MO=VYI:_-W(&IE<W0@=WFS86-Z;VYE+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ-#0S(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3(V"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S"FUS
M9VED(")!9&1R97-S(@IM<V=S='(@(D%D<F5S(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$S.0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@
M(DMS:;&_:V$@861R97-O=V$B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(D%D;6EN:7-T97(@+2!S970@
M<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(D]P8VIE("5S
M(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D
M;6EN:7-T<F%C:F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,SDR
M"FUS9VED(")!9',B"FUS9W-T<B`B4F5K;&%M>2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES
M=&%N(@IM<V=S='(@(D%F9V%N:7-T86XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;&)A;FEA(@IM<V=S
M='(@(D%L8F%N:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S0@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(D%L9VEE<FEA
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G
M:60@(D%L:6%S(@IM<V=S='(@(D%L:6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R(")7
M<WIY<W1K;R(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$Q."!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E
M9"!5<V5R<R(*;7-G<W1R(")7<WIY<V-Y('5W:65R>GET96QN:65N:2!UOWET
M:V]W;FEC>2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S
M+G!H<#HR,3(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B5W-Z>7-T:VEE
M(&=R=7!Y(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C,X(&QI8B](
M;W)D92]097)M<R]522YP:'`Z-S<*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*
M;7-G<W1R(")7<WIY<W1K:64@=7!R87=N:65N:6$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"B,L(&9U>GIY
M"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R(")5=V%G:2(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ.#<R"FUS9VED(")!;&QO=R!M=6QT:7!L92!A
M9&1R97-S97,B"FUS9W-T<B`B4&]Z=_-L(&YA('=I96QE(&%D<F5S\W<B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(V"FUS9VED(")!;&QO=R!S971T
M:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O1&%T851R964O<W%L+G!H<#HT,#@*;7-G:60@(D%L<F5A9'D@97AI
M<W1S(@IM<V=S='(@(DIUOR!I<W1N:65J92(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,C,*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S
M='(@(D%L=&5R;F%T>7=N>2!L;V=I;B!)35-0(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0Y.0IM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B
M"FUS9W-T<B`B06QT97)N871Y=VYY(&AA<[-O($E-4U`B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#DQ"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R
M;F%M92(*;7-G<W1R(")!;'1E<FYA='EW;F$@;F%Z=V$@=;]Y=&MO=VYI:V$@
M24U34"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED
M(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(")!;'1E<FYA='EW
M;GD@861R97,@96UA:6PB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@HC
M+"!F=7IZ>0IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R(")4
M=_-J(&%D<F5S(&4M;6%I;#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T
M92!T97AT.B(*;7-G<W1R(")!;'1E<FYA='EW;GD@=&5K<W0Z(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B
M06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S
M+U5)+G!H<#HY-2!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B
M06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R("):;W-T
M8;-A('!O9&%N82!N:65P<F%W:62S;W=A('=A<G1OMN8N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-`HC+"!F=7IZ>0IM<V=I9"`B06X@
M=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B4')O<WKJ('!O
M9&'F(&YA>G?J('6_>71K;W=N:6MA(&D@:&%SLV\B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A
M(@IM<V=S='(@(D%N9&]R82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R(")!;F=O
M;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R(")!;F=U:6QL82(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R
M;WAY(@IM<V=S='(@(D%N;VYI;6]W92!0<F]X>2(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B3V1P
M;W=I962\(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R(")!;G1A<FMT>61A
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-2!L
M:6(O2&]R9&4O0FQO8VLO54DN<&AP.C4X"B,Z('1E;7!L871E<R]A9&UI;B]S
M971U<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@
M(D%P;&EK86-J82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,SD*;7-G
M:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R(")!<&QI:V%C:F$@
M9V]T;W=A(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G
M:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V
M92(*;7-G<W1R("):871W:65R9+PB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT
M96YT<RYP:'`Z.#,P"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS-S<@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!
M<')I;"(*;7-G<W1R(")+=VEE8VEE\2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-S@*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM
M<V=S='(@(E=I96QK;[;F(&%R8VAI=W5M(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-3@@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-S<*;7-G
M:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R(").87IW82!A<F-H:7=U;2(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z.0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT
M('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T
M<B`B0WIY(&YA('!E=VYO(&-H8V5S>B!U<W5NL>8@=.H@<F5G=;/J/R(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHY"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@
M9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(D-Z
M>2!N82!P97=N;R!C:&-E<WH@=7-U;K'F('3J(')E9W6SZC\B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!
M<F=E;G1I;F$B"FUS9W-T<B`B07)G96YT>6YA(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI82(*
M;7-G<W1R(")!<FUE;FEA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S8*
M;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*
M;7-G:60@(D%R=6)A(@IM<V=S='(@(D%R=6)A(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@
M07)T(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U
M"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT,3<*;7-G:60@(D%S:R!F;W(@8V]N9FER
M;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*
M;7-G<W1R(")0;W!R;[8@;R!P;W1W:65R9'IE;FEE('!R>F5D('=Y:V]N86YI
M96T@;W!E<F%C:FD@8WEK;&EC>FYY8V@_(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,Q,3(*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<U"FUS9VED(")!='1E;7!T('1O(&1E
M;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<&5R;7,O9&5L971E+G!H<#HS.`IM<V=I9"`B071T96UP="!T;R!D96QE
M=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<&5R;7,O961I="YP:'`Z.3@*;7-G:60@(D%T=&5M<'0@=&\@961I
M="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S$*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#,*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B071R>6)U='DB
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@Q(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3@*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G
M=7-T(@IM<V=S='(@(E-I97)P:67Q(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')A;&EA(@IM<V=S
M='(@(D%U<W1R86QI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B075S=')I
M82(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!
M=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!.:64@>FYA;&5Z:6]N;R!W>6UA9V%N
M96=O(')O>G-Z97)Z96YI82!I;6%P+B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y
M<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N
M;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U
M<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!=71H7V-Y<G5S.B!.:64@>FYA;&5Z:6]N;R!W>6UA9V%N96=O(')O>G-Z
M97)Z96YI82!I;6%P+B(*"B,Z(&QI8B](;W)D92]!=71H+V9T<"YP:'`Z,S8*
M;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO
M="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P
M('-W:71C:"XB"FUS9W-T<B`B(@HB075T:%]F='`Z($YI92!Z;F%L97II;VYO
M('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA($944"X@4VMO;7!I;'5J(%!(4"!Z
M("(*(G!A<F%M971R96T@+2UE;F%B;&4@+B(*"B,Z(&QI8B](;W)D92]!=71H
M+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;6%P.B!.:64@
M>FYA;&5Z:6]N;R!W>6UA9V%N96=O(')O>G-Z97)Z96YI82!)34%0+B(*"B,Z
M(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z
M(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M075T:%]K<F(U.B!.:64@>FYA;&5Z:6]N;R!W>6UA9V%N96=O(')O>G-Z97)Z
M96YI82!K<F(U+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C4X"FUS
M9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P.B!.:64@>FYA;&5Z:6]N;R!W>6UA
M9V%N96=O(')O>G-Z97)Z96YI82!,1$%0+B(*"B,Z(&QI8B](;W)D92]!=71H
M+VQD87`N<&AP.C$X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B075T
M:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("):87!I<WIA;FEE('-Z:VEC=2!N
M:65U9&%N92X@4V5R=V5R('IW<O-C:;,@;V1P;W=I962\.B`E<R(*"B,Z(&QI
M8B](;W)D92]!=71H+VQD87`N<&AP.C(R,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R
M(")!=71H7VQD87`Z($YI92!U9&&S;R!S:>H@=7-U;K'F('6_>71K;W=N:6MA
M("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,C@P"B,L('!H<"UF
M;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R
M("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@3FEE('5D8;-O('-IZB!U86MT=6%L
M;FGF('6_>71K;W=N:6MA("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O;6-A;"YP
M:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VUC86PZ($YI92!Z;F%L97II
M;VYO('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA($U#04PN(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U
M:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?<VUB875T:#H@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R
M>F5N:6$@<VUB875T:"XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S
M='(@(E5W:65R>GET96QN:65N:64@;FEE('!O=VEO9+-O('-IZB(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(E5W:65R>GET96QN
M:65N:64@;FEE('!O=VEO9+-O('-IZBX@)7,B"@HC.B!L:6(O2&]R9&4O075T
M:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T
M960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`B57=I97)Z>71E;&YI96YI
M92!O9')Z=6-O;F4@<')Z97H@<V5R=V5R(%)!1$E54RXB"@HC.B!L:6(O5D93
M+V9T<"YP:'`Z-S8X"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R
M=F5R(&9A:6QE9"XB"FUS9W-T<B`B57=I97)Z>71E;&YI96YI92!D;R!S97)W
M97)A($944"!N:64@<&]W:6]DLV\@<VGJ+B(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FUA<"YI;F,Z.#,*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S
M='(@(D1O<W3J<&YE('!O;&$Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C,Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R
M(")!>F5R8F5J9+]A;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM
M<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(E=Y;?-W:VD@0D]&2"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B5+-O(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C
M:V=R;W5N9"!#;VQO<B(*;7-G<W1R(")+;VQO<B!TLV$B"@HC.B!L:6(O2&]R
M9&4O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W
M;W)D+B(*;7-G<W1R("):LV4@:&%SLV\@2V5R8F5R;W-A+B(*"B,Z(&QI8B](
M;W)D92]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E
M<FYA;64N(@IM<V=S='(@(EJS82!N87IW82!UOWET:V]W;FEK82!+97)B97)O
M<V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#4@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@(E=Y<W!Y($)A:&%M82(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HS."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G
M:60@(D)A:')A:6XB"FUS9W-T<B`B0F%H<F%J;B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3<W"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G
M<W1R(")"8;-T>6-K:2`H25-/+3@X-3DM,3,I(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C,T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR.`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S
M:"(*;7-G<W1R(")"86YG;&%D97-Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C,S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<S"B,L(&9U>GIY"FUS9VED(")"87-E;&EN92(*;7-G<W1R(")/
M9')Z=6-O;F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#D@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8S"FUS9VED(")"96QA<G5S(@IM<V=S='(@(D)I8;-O<G6V(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,U(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HS,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM
M<V=I9"`B0F5L9VEU;2(*;7-G<W1R(")"96QG:6$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,R
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QI>F4B
M"FUS9W-T<B`B0F5L:7IE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B0F5N:6XB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C,T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R
M"FUS9VED(")"97)M=61A(@IM<V=S='(@(D)E<FUU9'DB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C,U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T
M86XB"FUS9W-T<B`B0FAU=&%N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(D1A=&$@
M=7)O9'IE;FEA(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP
M.C,R.`HC+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P
M;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C@Y"FUS9VED(")";&]C:R!3971T
M:6YG<R(*;7-G<W1R(")5<W1A=VEE;FEA(&)L;VMU(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S
M='(@(E1Y<"!B;&]K=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.`HC+"!F=7IZ>0IM<V=I9"`B0F]L9"(*;7-G<W1R(")4
M<F6VYB(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B0F]L:7=I82(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.3$*;7-G:60@(D)O;VMM87)K<R(*
M;7-G<W1R("):86NS861K:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(D)O<F1E
M<B(*;7-G<W1R(")(;W)D92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(D)O<F1E<G,B"FUS9W-T
M<B`B2&]R9&4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S(@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S
M='(@(D)OMFYI82!I($AE<F-E9V]W:6YA(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@(D]B82(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HT."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O
M='-W86YA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C,*(RP@9G5Z>GD*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B5WES
M<'D@3W=C>F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#0@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)A>GEL:6$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HT,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,0IM
M<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HS-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@
M(D)U;&=A<FEA(@IM<V=S='(@(D)ULV=A<FEA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0HC+"!F=7IZ>0IM<V=I9"`B
M0G5L;&5T960@3&ES="(*;7-G<W1R(")7>6)I97)Z(&QI<W3J(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HT-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B
M0G5R:VEN82!&87-O(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HS.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X,PIM<V=I9"`B
M0TU3(@IM<V=S='(@(D--4R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-23"!$:7-T<FEB=71I
M;VX@4&]I;G1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O
M<&5R=&EE<RXN+B(*;7-G<W1R(")7LV&V8VEW;[9C:2!K;VWS<FMI+BXN("A?
M8RDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34P"B,L(&9U
M>GIY"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G
M<W1R("):8;.Q8WIN:6L@;FEE('IO<W1ALR!Z;F%L97II;VYY+B(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-38@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$T.`IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B
M2V%L96YD87)Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S
M-`IM<V=I9"`B0V%L;2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3(X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS
M9W-T<B`B2V%M8F]DOV$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8W"FUS9VED(")#86UE<F]O;B(*;7-G<W1R(")+86UE
M<G5N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@
M(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(DYI92!U9&&S;R!S
M:>H@>G)E<V5T;W=AYB!H87.S82!A=71O;6%T>6-Z;FEE+"!S:V]N=&%K='5J
M('-IZB!Z("(*(F%D;6EN:7-T<F%T;W)E;2XB"@HC.B!L:6(O2&]R9&4O075T
M:"]C>7)U<RYP:'`Z,C,U(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,S$Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S
M97)V97(Z("5S(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@
M>B!S97)W97)E;2!)34%0.B`E<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HU,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G<W1R(")+
M86YA9&$B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z
M,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV
M-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,30@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$W"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3<*;7-G:60@(D-A;F-E;"(*;7-G<W1R
M(")!;G5L=6HB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU
M.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(D%N=6QU
M:B!R87!O<G0@;R!P<F]B;&5M:64B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C4V
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(DYI92!M;[]N82!S:V%S;W=AYB!P;&EK=2!<(B5S7"(B
M"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HT-@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E
M9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B3FEE('5D8;-O('-IZB!Z;F%L9;SF(&MA
M=&%L;V=U('1Y;6-Z87-O=V5G;RXB"@HC.B!L:6(O5D93+TE33U=R:71E<BYP
M:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I
M;&4G('!A<F%M971E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+U9&4R]F='`N<&AP
M.C(U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C
M=&]R>2!<(B5S7"(N(@IM<V=S='(@(DYI92!M;[]N82!S:V%S;W=AYB!K871A
M;&]G=2!<(B5S7"(B"@HC.B!L:6(O2&]R9&4O1&%T851R964N<&AP.C$Q,B!L
M:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HU.#0*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T
M+B(*;7-G<W1R(").:64@;6^_;F$@<VMA<V]W8>8@:V%T86QO9W4@7"(E<UPB
M(@H*(SH@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-3$R"FUS9VED("(B
M"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@
M9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE
M9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HV-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T
M<B`B5WES<'D@6FEE;&]N96=O(%!R>GELL61K82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*(RP@9G5Z>GD*
M;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B3W!C:F4B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3`*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*
M;7-G<W1R(")+871E9V]R:64@:2!O>FYA8WIE;FEA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$S-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*(RP@9G5Z>GD*;7-G
M:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(E=Y<W!Y(%-A;&]M;VYA(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@
M(D-E;&P@4&AO;F4B"FUS9W-T<B`B5&5L+B!K;VTN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I9"`B
M0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(E>S8;9C:7=OMF-I(&MO;?-R:VDB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED
M(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B5[-AMF-I=V^V8VD@:V]M\W)K
M:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,C<T"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B
M5&5L+B!K;VTN(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@
M(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(D-E;'1Y8VMI("A)4T\M
M.#@U.2TQ-"DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(V"B,L(&9U>GIY"FUS9VED(")#96YT97(B"FUS9W-T
M<B`B4W1W\W)Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM
M<V=S='(@(E)E<'5B;&EK82"F<F]D:V]W96H@069R>6MI(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E3
M3RTX.#4Y+3(I(@IM<V=S='(@(J9R;V1K;W=O975R;W!E:G-K:2`H25-/+3@X
M-3DM,BDB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8Y.0IM<V=I
M9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R(")3>F-Z96?SLWD@8V5R
M='EF:6MA='4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8Q,0IM
M<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B5[-AMF-I8VEE;"!C
M97)T>69I:V%T=2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DV
M"B,L(&9U>GIY"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R
M(")3>F-Z96?SLWD@8V5R='EF:6MA='4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C(Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS9W-T
M<B`B0WIA9"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3<*;7-G:60@(D-H86YG92(*
M;7-G<W1R("):;6EE\2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@IM
M<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O
M<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E
M;6%I;',N(@IM<V=S='(@(EIM:67Q(&EM:>HL(&YA>G=I<VMO(&D@861R97,L
M(&MT\W)Y(&EN;FD@=VED>K$@=R!4=V]I8V@@;&ES=&%C:"!E;6%I;"XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(W"B,L(&9U>GIY"FUS9VED(")#:&%R(@IM<V=S='(@(DMA;&5N9&%R>B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B4W!R87=D
MO"!L:6YK+BXN(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?
M=&]P+FEN8SHQ,PIM<V=I9"`B0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A
M=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS
M9W-T<B`B6F%Z;F%C>B!P;WIY8VKJ(&1L82!K=/-R96H@8VAC97-Z('=Y:V]N
M8>8@;W!E<F%C:NHN(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4Y(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;&4B"FUS9W-T<B`B0VAI;&4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C4T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#:&EN82(*;7-G<W1R(")#:&EN>2(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@P"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@
M(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!P
M87-S=V]R9"(*;7-G<W1R(")0;V1A:B!H87.S;R(*"B,Z(&QI8B](;W)D92]!
M=71H+U-I9VYU<"YP:'`Z,C8X"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*
M;7-G<W1R(")0;V1A:B!N87IWZB!UOWET:V]W;FEK82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR.3`*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA
M>2!D871E<SHB"FUS9W-T<B`B5WEB:65R>B!S<&]S\V(@=WFV=VEE=&QA;FEA
M(&1A=#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E
M("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C8V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU
M-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T
M;6%S($ES;&%N9"(*;7-G<W1R(")7>7-P82!";[]E9V\@3F%R;V1Z96YI82(*
M"B,Z(&QI8B]61E,N<&AP.C8Q-2!L:6(O3F5T+U--4RYP:'`Z,CDT"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S
M(&YO="!F;W5N9"XB"FUS9W-T<B`B6F&SL6-Z;FEK(&YI92!Z;W-T8;,@>FYA
M;&5Z:6]N>2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-`HC+"!F=7IZ>0IM<V=I9"`B0VQE87(B"FUS9W-T<B`B2V%L96YD
M87)Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@
M(EID86QN92!S97)W97)Y(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE
M87(N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@
M(DMA;&5N9&%R>B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C,T"B,L(&9U>GIY"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B
M2V%L96YD87)Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,34*(RP@9G5Z>GD*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T
M<B`B2V%L96YD87)Z(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VYO=&EC
M95]B;W1T;VTN:6YC.C8*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S
M='(@(DML:6MN:6H@8GD@:V]N='EN=6]W8>8B"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@
M2%144"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I
M;F1O=R(*;7-G<W1R("):86UK;FEJ(&]K;F\B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(T-`HC+"!F=7IZ>0IM<V=I9"`B0VQO=61S(@IM<V=S='(@(EIA
M;6MN:6HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ-@HC+"!F=7IZ>0IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(DMR
M\W1K:64@<W1R97-Z8WIE;FEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3<*(RP@9G5Z>GD*;7-G:60@(D-L;W5D>2(*;7-G
M<W1R(")+<F%J(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS
M9W-T<B`B5WES<'D@2V]K;W-O=V4@*$ME96QI;F=A*2(*"B,Z('1E;7!L871E
M<R]P;W)T86PO<VED96)A<BYI;F,Z-`IM<V=I9"`B0V]L;&%P<V4@4VED96)A
M<B(*;7-G<W1R(")38VAO=V%J('!A<V5K(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`HC+"!F=7IZ>0IM<V=I
M9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B6G=I\2!F;VQD97(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C4W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#;VQO;6)I82(*;7-G<W1R(")+;VQU;6)I82(*"B,Z(&QI8B]";&]C
M:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS
M9VED(")#;VQO<B(*;7-G<W1R(")+;VQO<B(*"B,Z(&QI8B](;W)D92]";&]C
M:R]#;VQL96-T:6]N+G!H<#HR.3D@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I
M;VXN<&AP.C,P,`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#<R('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3$*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3(*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C@*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-CD*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#4*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#8*;7-G
M:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R(")7>6)I97)Z(&MO;&]R(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(X-#4*;7-G:60@(D-O;&]U<B!S96QE8W1I
M;VXB"FUS9W-T<B`B5WEB\W(@:V]L;W)U(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*(RP@9G5Z>GD*;7-G:60@(D-O
M;',Z(@IM<V=S='(@(EIW:?$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DT
M-PIM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R(")4>71ULWD@:V]L=6UN
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X-@HC+"!F=7IZ>0IM
M<V=I9"`B0V]M:6-S(@IM<V=S='(@(E1W\W)Z(@H*(SH@861M:6XO8VUD<VAE
M;&PN<&AP.C(U"FUS9VED(")#;VUM86YD(@IM<V=S='(@(DMO;65N9&$B"@HC
M.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB
M"FUS9W-T<B`B4&]WLV]K82(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C0P,@IM<V=I9"`B0V]M;65N="(*;7-G<W1R(")+;VUE;G1A<GHB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V-@IM<V=I9"`B0V]M;6]N($YA
M;64B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#0*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B2V]M;W)Y
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G
M:60@(D-O;7!A;GDB"FUS9W-T<B`B1FER;6$B"@HC.B!L:6(O2&]R9&4O5&5X
M="]&:6QT97(O96UA:6QS+G!H<#HX,2!L:6(O2&]R9&4O5&5X="]&:6QT97(O
M96UA:6QS+G!H<#HX-PHC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS
M+G!H<#HY-R!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HQ,#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]M<&]S92!-97-S86=E("@E<RDB"FUS
M9W-T<B`B4W1W\W)Z('=I861O;6^VYB`H)7,I(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B2V]M<'5T
M97)Y(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-0HC+"!F
M=7IZ>0IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(E=A<G5N:VDB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(T.0IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G
M<W1R(")787)U;FMI(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G
M:60@(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-`IM<V=I9"`B0V]N9FEG=7)A=&EO
M;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.CDY"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E
M<R(*;7-G<W1R(")3:V]N9FEG=7)U:B`E<R(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z,S<*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B
M"FUS9W-T<B`B4&]T=VEE<F2\(&AA<[-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C4U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T
M<B`B2V]N9V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L
M:6,@;V8@=&AE(@IM<V=S='(@(D1E;6]K<F%T>6-Z;F$@4F5P=6)L:6MA($MO
M;F=O(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.2!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN
M96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`B4&^SL6-Z96YI92!N:64@<&]W:6]D
MLV\@<VGJ+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M.3D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B
M0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R(")0;[.Q8WIE;FEE(&YI92!P
M;W=I;V2S;R!S:>HZ("(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<W
M.0IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+B(*;7-G<W1R(")/9&WS=VEO;F\@<&^SL6-Z96YI82!D;R!P=6)L
M:6-Z;F5G;R!S97)W97)A+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C<X,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@
M=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G
M<W1R(")/9&WS=VEO;F\@<&^SL6-Z96YI82!D;R!P=6)L:6-Z;F5G;R!S97)W
M97)A+B!0;W?S9#H@)7,@*"5S*2(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW-C(*
M;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S
M='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!&5%`N
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I
M9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A
M9&1R97-S(&)O;VLN(@IM<V=S='(@(DMO;G1A:W1Y('IO<W1ALWD@<&]M>;9L
M;FEE(&1O9&%N92!D;R!4=V]J96H@:W-IL;]K:2!A9')E<V]W96HN(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-C`*;7-G:60@(D-O;G1E
M;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z("(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU-B!L:6(O2&]R9&4O34E-
M12]6:65W97(O>FEP+G!H<#HV,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=&=Z+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<
M(B5S7"(B"FUS9W-T<B`B6F%W87)T;[;F(%PB)7-<(B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C(Y"FUS9VED(")#;VYT:6YU92(*;7-G<W1R
M(")+;VYY;G5U:B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU."!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R(")7>7-P
M>2!#;V]K82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@HC+"!F=7IZ
M>0IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(E1W\W)Z(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED
M(")#;W!Y(@IM<V=S='(@(E-K;W!I=6HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO
M;B(*;7-G<W1R(")3:V]P:75J('=Y8O-R(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C8S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDU-@IM<V=I9"`B0V]U;&0@;F]T
M(%!'4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(DYI92!U9&&S;R!S:>H@
M>F%S>GEF<F]W8>8@*%!'4"D@=VEA9&]M;[9C:2XB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HQ,#,S"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@
M;65S<V%G92XB"FUS9W-T<B`B3FEE('5D8;-O('-IZB!P;V1P:7-AYB`H4$=0
M*2!W:6%D;VUOMF-I+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB
M"FUS9W-T<B`B3FEE('5D8;-O('-IZB!Z87-Z>69R;W=AYB`H4R]-24U%*2!W
M:6%D;VUOMF-I+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-#8W
M"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T
M<B`B3FEE('5D8;-O('-IZB!P;V1P:7-AYB`H4R]-24U%*2!W:6%D;VUOMF-I
M+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C
M="X@)7,B"FUS9W-T<B`B3FEE(&UOOVYA(&]T=V]R>GGF(&UO9'6S=2!-86EN
M=&5N86YC95]487-K("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z
M,3$P"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS
M9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M($Q$
M05`N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S
M(@IM<V=S='(@(DYI92!M;[]N82!O='=O<GIYYB`E<RXB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM
M<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!<
M(B5S7"(@<&]P<GIE>B!&5%`Z("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C,R,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`B2&]R9&4@;FEE(&IE<W0@=R!P9;-N:2!S:V]N9FEG=7)O=V%N92XB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,3`U"FUS9VED(")#;W5L9"!N
M;W0@9&5C<GEP="!01U`@9&%T82XB"FUS9W-T<B`B3FEE('5D8;-O('-IZB!O
M9'-Z>69R;W=AYB!D86YY8V@@4$=0+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3(R"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@
M9&%T82XB"FUS9W-T<B`B3FEE('5D8;-O('-IZB!O9'-Z>69R;W=AYB!D86YY
M8V@@4R]-24U%+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HR-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D
M96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B2&]R9&4@;FEE(&IE<W0@=R!P
M9;-N:2!S:V]N9FEG=7)O=V%N92XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,S4V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R
M(")(;W)D92!N:64@:F5S="!W('!ELVYI('-K;VYF:6=U<F]W86YE+B(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R
M:7!T(%PB)7-<(BXB"FUS9W-T<B`B3FEE(&UOOVYA(&]T=V]R>GGF(&UO9'6S
M=2!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HS.#$@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3,X"FUS9VED
M(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@
M861D<F5S<RXB"FUS9W-T<B`B3FEE('5D8;-O('-IZB!U<W1A;&GF(&%D<F5S
M=2!E+6UA:6P@;V1B:6]R8WDN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C(X,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H
M(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B3FEE(&UOOVYA(&]T
M=V]R>GGF(&UO9'6S=2!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PHC+"!F=7IZ>0IM<V=I9"`B
M0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*
M;7-G<W1R(").:64@;6^_;F$@;W1W;W)Z>>8@;6]D=;-U($UA:6YT96YA;F-E
M7U1A<VL@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-#0V"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L
M971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R(").:64@
M;6^_;F$@;W1W;W)Z>>8@;6]D=;-U($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC
M.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X
M"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@
M<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R(").:64@;6^_;F$@;W1W;W)Z>>8@
M;6]D=;-U($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O5D93+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@;&EB+U9&
M4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<
M(B5S7"(N(@IM<V=S='(@(DYI92!M;[]N82!U='=O<GIYYB!K871A;&]G=2!<
M(B5S7"(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW,#@*;7-G:60@
M(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V
M97(N(@IM<V=S='(@(DYI92!U9&&S;R!S:>H@=7IY<VMAYB!Z('-E<G=E<F$@
M:VQU8WIA('!B=6QI8WIN96=O+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S
M='(@(DYI92!U9&&S;R!S:>H@;W1W;W)Z>>8@7"(E<UPB(&1O('IA<&ES=2XB
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R(").:64@;6^_;F$@
M;W1W;W)Z>>8@)7,N(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HT
M,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E
M;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B3FEE(&UOOVYA(&]T=V]R
M>GGF(&UO9'6S=2!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+U9&4R])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<
M(BXB"FUS9W-T<B`B3FEE(&UOOVYA(&]T=V]R>GGF(&MA=&%L;V=U(%PB)7-<
M(B(*"B,Z(&QI8B]61E,O3V)J96-T+G!H<#HR,S@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R(").:64@
M;6^_;F$@;W1W;W)Z>>8@;6]D=;-U($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U
M;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U
M<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O
M<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O
M<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S<W(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS.#,*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X
M.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G
M<W1R(").:64@;6^_;F$@;W1W;W)Z>>8@;6]D=;-U($UA:6YT96YA;F-E7U1A
M<VL@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R(")(;W)D92!N:64@:F5S="!W
M('!ELVYI('-K;VYF:6=U<F]W86YE+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HT.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS
M9W-T<B`B2&]R9&4@;FEE(&IE<W0@=R!P9;-N:2!S:V]N9FEG=7)O=V%N92XB
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES
M=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R(")(;W)D92!N:64@:F5S="!W
M('!ELVYI('-K;VYF:6=U<F]W86YE+B(*"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HQ.3D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C(Q.0HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S
M"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@
M8V%P86)I;&ET:65S(@IM<V=S='(@(DAO<F1E(&YI92!J97-T('<@<&6S;FD@
M<VMO;F9I9W5R;W=A;F4N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU
M-`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")(;W)D92!N:64@:F5S="!W('!ELVYI('-K;VYF:6=U
M<F]W86YE+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.CDT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R(").:64@=61ALV\@<VGJ
M('-K87-O=V%N:64@:V%T86QO9W4@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C<Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")(;W)D
M92!N:64@:F5S="!W('!ELVYI('-K;VYF:6=U<F]W86YE+B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU
M-PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N
M9FEG=6%T:6]N+B(*;7-G<W1R(")(;W)D92!N:64@:F5S="!W('!ELVYI('-K
M;VYF:6=U<F]W86YE+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B
M86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R(")(;W)D92!N:64@:F5S
M="!W('!ELVYI('-K;VYF:6=U<F]W86YE+B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.CDR"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*
M;7-G<W1R(").:64@;6^_;F$@;W1W;W)Z>>8@;6]D=;-U($UA:6YT96YA;F-E
M7U1A<VL@)7,B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C
M:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B2&]R9&4@;FEE
M(&IE<W0@=R!P9;-N:2!S:V]N9FEG=7)O=V%N92XB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C<T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD
M(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@
M96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@
M8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L
M;W<@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N
M<&AP.C$R,`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@
M3$1!4"!S97)V97(N(@IM<V=S='(@(D*SL60@<&]D8WIA<R!P<GIE<WIU:VEW
M86YI82!Z('-E<G=E<F5M($Q$05`N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(DYI92!U
M9&&S;R!S:>H@<VMA<V]W8>8@<&QI:W4@7"(E<UPB+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T
M<B`B3FEE(&UOOVYA(&]T=V]R>GGF(&UO9'6S=2!-86EN=&5N86YC95]487-K
M("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3FEE(&UOOVYA(&]T=V]R
M>GGF(&UO9'6S=2!-86EN=&5N86YC95]487-K("5S(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*
M;7-G<W1R(")(;W)D92!N:64@:F5S="!W('!ELVYI('-K;VYF:6=U<F]W86YE
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3@*;7-G:60@(D-O=6QD
M;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S
M:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(DYI92!U9&&S;R!S:>H@>FYA;&6\
MYB!P87-K82!-;WII;&QI+B!5<&5W;FEJ('-IZBP@OV4@:F5S="!O;B!O='=A
M<G1Y+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@
M=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD
M97(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"B)5OWET:V]W;FEK(%PB)7-<(B!P
M<F%W:62S;W=O('ID969I;FEO=V&S('!R87=A(&1O<W3J<'4@9&\@9F]L9&5R
M82!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C$*(RP@9G5Z
M>GD*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R(")7>6QO9W5J(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D-O=6YT<GDB
M"FUS9W-T<B`B2W)A:B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-S`*(RP@9G5Z>GD*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`BK'+S9+-A(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHY-PHC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z,3`Q"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B4W1W\W)Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8W"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(E-T=_-R>B!L:6YK
M(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PIM
M<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R(")3='?S<GH@;F]WL2(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@HC+"!F=7IZ
M>0IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(E5T=_-R>B!N
M;W=Y(&9O;&1E<B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$S-B!L:6(O
M2&]R9&4O4&5R;7,O54DN<&AP.C(Q-`HC+"!F=7IZ>0IM<V=I9"`B0W)E871O
M<B!097)M:7-S:6]N<R(*;7-G<W1R(")$;VUYMFQN92!U<')A=VYI96YI82(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C(Y"FUS9VED(")#<F5D:70@8V%R
M9"!N=6UB97(B"FUS9W-T<B`B3G5M97(@:V%R='D@:W)E9'ET;W=E:B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C8T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y"FUS
M9VED(")#<F]A=&EA(@IM<V=S='(@(D-H;W)W86-J82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HV-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B
M"FUS9W-T<B`B2W5B82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@HC+"!F
M=7IZ>0IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R(")/8F5C;GD@
M8WIA<R(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE
M+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(D]B96-N>2!C
M>F%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4S"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%523"!I<R(*
M;7-G<W1R(")/8F5C;GD@8WIA<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C4*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R(")/
M8F5C;GD@8WIA<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-C,*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T
M<B`B3V)E8VYY(&MA=&%L;V<Z("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N
M="!S='EL92(*;7-G<W1R(")/8F5C;GD@8WIA<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE
M('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R(")3<&5R
M<V]N86QI>G5J('IA9&%N:6$@=7)U8VAA;6EA;F4@<')Z>2!L;V=O=V%N:74@
M9&\@)7,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B5WET;FEJ(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0HC
M+"!F=7IZ>0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R(")3:V%S=6H@
M=WEB<F%NL2!T;[]S86UOMN8B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B0WEP
M<B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED(")#>7)I;&QI
M8R`H2T])."U2*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X,PIM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-Y<FEL;&EC
M+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8W
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C:"!2
M97!U8FQI8R(*;7-G<W1R(")297!U8FQI:V$@0WIE8V@B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(S('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")$1"(*"B,Z(&QI8B](;W)D
M92]-86EN=&5N86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(D-O
M9'II96YN:64B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*(RP@9G5Z>GD*
M;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B1&%T82(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,SDX(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C<R"FUS9VED(")$871E(@IM<V=S='(@(D1A=&$B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PHC+"!F=7IZ>0IM
M<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R(")/=')Z>6UA;F4B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C@P-@HC+"!F=7IZ>0IM<V=I9"`B1&%T92!S
M96QE8W1I;VXB"FUS9W-T<B`B4VMA<W5J('=Y8G)A;K$@=&^_<V%M;[;F(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,"!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")$87DB"FUS
M9W-T<B`B0V]D>FEE;FYI92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B1&5?;&5T92!#;VQU
M;6XB"FUS9W-T<B`B7U5S=?$@:V]L=6UNZB(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HS.#4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R(")'<G5D
M>FEE\2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,38*(RP@9G5Z>GD*;7-G:60@(D1E8VEM86P@;G5M8F5R
M<R(*;7-G<W1R(")'<G5D>FEE\2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(D1E8W)E87-E
M($EN9&5N="(*;7-G<W1R(")287!O<G1U:B!J86MO(&YI97-Z:V]D;&EW>2(*
M"B,Z(&QI8B]P<F5F<RYP:'`Z,3$Q(&QI8B](;W)D92]0<F5F<R]522YP:'`Z
M,3@W"B,L(&9U>GIY"FUS9VED(")$969A=6QT(@IM<V=S='(@(D1O;7FV;&YY
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-#<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M.#$*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B1&]M>;9L;GD@:V]L
M;W(B"@HC.B!L:6(O2&]R9&4O261E;G1I='DN<&AP.CDQ"FUS9VED(")$969A
M=6QT($ED96YT:71Y(@IM<V=S='(@(D1O;7FV;&YA('1OOW-A;6^VYB(*"B,Z
M(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$Q.2!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C$Y-@IM<V=I9"`B1&5F875L="!097)M:7-S:6]N<R(*;7-G<W1R(")$
M;VUYMFQN92!U<')A=VYI96YI82(*"B,Z(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,3DW"FUS9VED(")$969A=6QT('!E<FUI<W-I;VYS(@IM<V=S='(@(D1O
M;7FV;&YE('5P<F%W;FEE;FEA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,S"B,L(&9U>GIY"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R(")09;-N
M>2!O<&ES.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S(@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HT-B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,Z(&QI
M8B](;W)D92]097)M<RYP:'`Z,CDU(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,S$U"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,S,R('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHW,"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3$V('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,PHC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z.3D@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N
M:6YC.C$S"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS
M9VED(")$96QE=&4B"FUS9W-T<B`B57-U\2(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,3@Y(&%D;6EN+V=R;W5P<RYP:'`Z,C$W"FUS9VED(")$96QE=&4@1W)O
M=7`B"FUS9W-T<B`B57-U\2!'<G5PZB(*"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z-C,@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX-PIM<V=I9"`B1&5L
M971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B57-U\2!U<')A=VYI96YI82(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B1&5L
M971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R(")5<W7Q(&D@=WEC>GFV
MYB!W:6%D;VUOMF-I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T
M<B`B57-U\2!K;VWS<FOJ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*
M;7-G<W1R(")5<W7Q(&MO;'5M;NHB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$T.`HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T
M92!T96UP;&%T92(*;7-G<W1R(")4=_-J(&%D<F5S(&4M;6%I;#HB"@HC.B!A
M9&UI;B]P97)M<R]D96QE=&4N<&AP.C4P(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,S$T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N
M<R!F;W(@7"(E<UPB(@IM<V=S='(@(E-K87-U:B!U<')A=VYI96YI82!D;&$@
M7"(E<UPB(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS,3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@
M86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(E-K87-O=V'F('5P
M<F%W;FEE;FEA(&1L82!<(B5S7"(@:2!W<WIY<W1K:64@<&]D+75P<F%W;FEE
M;FEA/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`B57-U\2!W
M:65R<WHB"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC
M.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B
M4VMA<W5J('=Y8G)A;K$@=&^_<V%M;[;F(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED(")$96QE
M=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(E5S=?$@86MT=6%L;K$@
M:V]L=6UNZB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O
M=R(*;7-G<W1R(")5<W7Q(&%K='5A;&YY('=I97)S>B(*"B,Z(&%D;6EN+W!E
M<FUS+V1E;&5T92YP:'`Z-#@*;7-G:60@(D1E;&5T92!T:&ES('!E<FUI<W-I
M;VX@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(E-K87-O=V'F
M('1O('5P<F%W;FEE;FEE(&D@=W-Z>7-T:VEE('!O9"UU<')A=VYI96YI83\B
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<
M(B5S7"(N(@IM<V=S='(@(DYI92!M;[]N82!O='=O<GIYYB!M;V1ULW4@36%I
M;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-C,@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y
M-0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,2!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PHC+"!F=7IZ>0IM<V=I
M9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R(")5<W7Q(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C<Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV
M.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R
M:R(*;7-G<W1R(")$86YI82(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$Q
M,"!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,30@<V5R=FEC97,O<')O8FQE;2YP
M:'`Z,3(T"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R(")/
M<&ES>B!P<F]B;&5M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDS."!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"B,L
M(&9U>GIY"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")09;-N>2!O<&ES
M.B(*"B,Z(&QI8B](;W)D92YP:'`Z,3DU"FUS9VED(")$971A:6QS("AA;'-O
M(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92YP:'`Z,3DY"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R
M('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")3>F-Z96?SLWD@>F]S=&&S
M>2!Z86QO9V]W86YE(&1L82!A9&UI;FES=')A=&]R82XB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3DX"B,L(&9U>GIY"FUS9VED(")$979E;&]P
M;65N="(*;7-G<W1R(")$>FEALR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C$W"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR.30*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Q-0IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER
M96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T
M:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R(")+871A;&]G
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U.`IM<V=I9"`B1&ES<&QA
M>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R(")7>;9W:65T;"!C>F%S('<@9F]R
M;6%C:64@,C0M9V]D>FEN;GEM/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-PIM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(E5S=&%W:65N
M:6$@=WEG;+%D=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HX
M.`HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*
M;7-G<W1R(")5<W1A=VEE;FEA('=Y9VRQ9'4B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C@U"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4
M048I(@IM<V=S='(@(E5S=&%W:65N:6$@=WEG;+%D=2(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR.#$V"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&9O<FUA
M="(*;7-G<W1R(")5<W1A=VEE;FEA('=Y9VRQ9'4B"@HC.B!L:6(O2&]R9&4O
M34E-12]-1$XN<&AP.C$Y,`HC+"!F=7IZ>0IM<V=I9"`B1&ES<&]S:71I;VX@
M3F]T:69I8V%T:6]N(@IM<V=S='(@(E)O>FUI97-Z8WIE;FEE(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C<P(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HV.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B
M1&II8F]U=&DB"FUS9W-T<B`B1+]I8G5T:2(*"B,Z(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-#8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS,34*;7-G:60@
M(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B3FEE(&MA<W5J(@H*(SH@<V5R=FEC
M97,O;6%I;G1E;F%N8V4N<&AP.C(T"FUS9VED(")$;R!N;W0@9&ER96-T;'D@
M86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R(")"<F%K(&)E>G!OMG)E
M9&YI96=O(&1O<W3J<'4@9&\@;6%I;G1E;F%N8V4N<&AP(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3D@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,3D*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H
M92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B1&]M:6YI:V$@*%=S</-L
M;F]T82!$;VUI;FEK:2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S,@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<P"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS
M9W-T<B`B1&]M:6YI:V%N82`H4F5P=6)L:6MA($1O;6EN:6MA\7-K82DB"@HC
M.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#0Q"FUS9VED(")$;W=N
M;&]A9"(*;7-G<W1R("*F8VFQ9VYI:B(*"B,Z(&QI8B](;W)D92]-24U%+T-O
M;G1E;G1S+G!H<#HX-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@
M)7,B"FUS9W-T<B`BIF-IL6=N:6H@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,38U"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C$P.`IM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*
M;7-G<W1R(").87)K;W1Y:VDB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HT,#(*;7-G:60@(D4M36%I;"(*;7-G<W1R(")%+6UA:6PB"@HC.B!L:6(O
M2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G
M:60@(D524B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(D5K
M=V%D;W(B"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(Y-"!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]E9&ET+FEN8SHR,@IM<V=I9"`B161I="(*;7-G<W1R(")%9'EC:F$B"@HC
M.B!L:6(O2&]R9&4O0FQO8VLO54DN<&AP.C4P('1E;7!L871E<R]P;W)T86PO
M961I="YI;F,Z,C(*(RP@9G5Z>GD*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T
M<B`B161Y='5J(&-Z87)NL2!L:7-TZB(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,3@X(&%D;6EN+V=R;W5P<RYP:'`Z,C$V"FUS9VED(")%9&ET($=R;W5P(@IM
M<V=S='(@(E5S=?$@1W)U<.HB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C8R(&QI8B](;W)D92]097)M<R]522YP:'`Z.#8*;7-G:60@(D5D:70@4&5R
M;6ES<VEO;B(*;7-G<W1R("):;6EE\2!U<')A=VYI96YI92(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B6FUI9?$@=7!R87=N:65N:6$B"@HC.B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@
M4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(EIM:67Q('5P<F%W;FEE;FEA
M(&1L82`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@
M(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(EIM:67Q('5S=&%W:65N:6$@
M9&QA.B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(P-"!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C(X,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(EIM:67Q('5P
M<F%W;FEE;FEA(&1L82`E<R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F
M;W(@)7,B"FUS9W-T<B`B6FUI9?$@=7!R87=N:65N:6$@9&QA("5S(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"B,L(&9U>GIY"FUS9VED(")%9'5C
M871I;VXB"FUS9W-T<B`B3W!C:F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G<W1R(")%
M9VEP="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B4V%L=V%D;W(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-#(*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@
M(D5M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<P(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T"FUS9VED(")%;6%I
M;"(*;7-G<W1R(")%;6%I;"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-38U('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3(*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,`IM<V=I9"`B16UA
M:6P@061D<F5S<R(*;7-G<W1R(")!9')E<R!E;6%I;"(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ.38T"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M
M871C:"XB"FUS9W-T<B`B061R97-Y(&5M86EL(&UU<WJQ(&1O('-I96)I92!P
M87-O=V'F+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.3DP"B,L(&9U>GIY
M"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")(87.S
M;R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR.#`*
M;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R(")%;6]T:6MO;GDB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B16UP='D@
M;65S<V%G92XB"FUS9W-T<B`B4'5S=&$@=VEA9&]M;[;F+B(*"B,Z(&QI8B](
M;W)D92]!=71H+VQD87`N<&AP.C$R.`IM<V=I9"`B16UP='D@<F5S=6QT+B(*
M;7-G<W1R(")"<F%K(')E>G5L=&%T\W<N(@H*(SH@;&EB+TAO<F1E+U-13"]+
M97EW;W)D<RYP:'`Z,3$S"B,L(&9U>GIY"FUS9VED(")%;7!T>2!S96%R8V@@
M=&5R;7,B"FUS9W-T<B`B3W!R\[]N:6H@9F]L9&5R(&MO<WIA(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4S-0IM<V=I9"`B16YA8FQE(&EN<V5R=&EO
M;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q,`IM<V=I9"`B
M16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B5[.Q
M8WIYYB!M96YU(&MO;G1E:W-T;W=E('!O9"!P<F%W>6T@<')Z>6-I<VMI96T@
M;7ES>GD_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.3<@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(X,3`*(RP@9G5Z>GD*;7-G:60@(D5N9"!Y96%R(@IM<V=S
M='(@(E)O>G=I\2!P87-E:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3,*;7-G:60@(B(*
M(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@
M87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@
M92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R
M92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3D@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R
M(")'=VEN96$@4O-W;FEK;W=A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C<Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G<W1R(")%
M<GET<F5A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0W(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S8*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W('-E<G9I8V5S+W!O<G1A;"]I;F1E
M>"YP:'`Z-SD*;7-G:60@(D5R<F]R(@IM<V=S='(@(D*SL60B"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0HC+"!F=7IZ>0IM<V=I
M9"`B17)R;W(@=VET:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R(")"<F%K(&9O
M;&1E<G4@>B!N;W=Y;6D@=VEA9&]M;[9C:6%M:2(*"B,Z(&QI8B]61E,O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B
M0K.Q9"!P<GIY('IA<&ES:64@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HW-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS
M9W-T<B`B17-T;VYI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(D5T:6]P
M:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*(RP@9G5Z>GD*;7-G
M:60@(D5T:&YI8R(*;7-G<W1R(")%<W1O;FEA(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R(")%=7)O<&$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Q"FUS9VED(")%=F5R>2`Q
M-2!M:6YU=&5S(@IM<V=S='(@(D-O(&MAOV1E(#$U(&UI;G5T(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,X,0IM<V=I9"`B179E<GD@,B!M:6YU=&5S
M(@IM<V=S='(@(D-O(&MAOV1E(#(@;6EN=71Y(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,R."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Y"FUS9VED
M(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(D-O(&MAOV1E(#,P('-E:W5N
M9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S`@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,X,@IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@
M(D-O(&MAOV1E(#4@;6EN=70B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N
M<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R(")#;R!K8;]D92!Z
M86QO9V]W86YI92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S(*;7-G
M:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")#;R!K8;]D92!P\[,@9V]D
M>FEN>2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,CD@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,X,`IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@
M(D-O(&MAOV2Q(&UI;G5TZB(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C(X"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B4')Z>6NS
M861O=V4@=V%R=&^V8VDZ(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,C@@861M:6XO<&AP<VAE;&PN<&AP.C@Q"FUS
M9VED(")%>&5C=71E(@IM<V=S='(@(E=Y:V]N86HB"@HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+G!H<#HS.30*;7-G:60@(D5X<&%N9"(*;7-G<W1R(")2
M;WIW:?$B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,Q"FUS
M9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R(")2;WIW:?$@<&%S96LB"@HC
M.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ-C@*(RP@9G5Z>GD*;7-G
M:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R(")7>6MO;F%J(@H*(SH@;&EB+TAO
M<F1E+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E
M('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C0P,0IM<V=I9"`B17AP:7)A=&EO;B!$
M871E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-C<V"B,L(&9U>GIY"FUS9VED(")%>'!O;F5N="(*;7-G<W1R(")%:W-P;W)T
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS,0HC+"!F=7IZ>0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B1&]M
M>;9L;GD@:V]L;W(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"B,L
M(&9U>GIY"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(E=G
M<GEW86YI92!P;&EK\W<@;FEE(&IE<W0@;V)SLW5G:7=A;F4N(@H*(SH@;&EB
M+TAO<F1E+U!R969S+W-Q;"YP:'`Z,C$V"B,L(&9U>GIY"FUS9VED(")&86EL
M960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B0K.Q9"!P;V1C
M>F%S('IM:6%N>2!U<W1A=VEE\2XB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P
M+G!H<#HQ,#`*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R
M=F5R+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R
M=V5R96T@3$1!4"XB"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP.CDX"B,L
M(&9U>GIY"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R
M+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R
M96T@3$1!4"XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-C`S"B,L('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R
M(")"L[%D('!O9&-Z87,@:V]P:6]W86YI82!Z(%PB)7-<(BXB"@HC.B!L:6(O
M5D93+V9T<"YP:'`Z-C`X"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T
M;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(&MO<&EO
M=V%N:6$@9&\@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]!=71H+W-A<VPN<&AP
M.C@W"B,L(&9U>GIY"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,
M(&-O;FYE8W1I;VXN(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S
M:>H@>B!S97)W97)E;2!,1$%0("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HV
M-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E
M<UPB+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@<')Z96YO<WIE;FEA(&1O(%PB
M)7-<(BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ.`HC+"!F=7IZ>0IM<V=I9"`B1F%I<B(*;7-G<W1R(")/9"(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HX-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@
M(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R(")&86QK;&%N
M9'D@*$UA;'=I;GDI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R(")7
M>7-P>2!/=V-Z92(*"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(S.`IM<V=I9"`B
M1F%T86P@17)R;W(Z(@IM<V=S='(@(D*SL60@:W)Y='EC>FYY.B`B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X
M(@IM<V=S='(@(D9A:W,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S<U(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,3(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B3'5T>2(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C(P"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3D*;7-G:60@
M(D9E96QS(&QI:V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0HC+"!F=7IZ>0IM<V=I9"`B1F5W(%-H
M;W=E<G,B"FUS9W-T<B`B26UP;W)T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C`*(RP@9G5Z>GD*;7-G:60@(D9E=R!3;F]W
M(%-H;W=E<G,B"FUS9W-T<B`B26UP;W)T(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Y-#4*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C@Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R"FUS9VED
M(")&:6II(@IM<V=S='(@(D9I9+]I(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C`@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV,"!L:6(O2&]R
M9&4O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O
M=6YT.B`E<R!F:6QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S0V"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B365N
M962_97(@<&QI:_-W(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C,@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*;7-G:60@(D9I;&4@3F%M
M92(*;7-G<W1R(").87IW82!P;&EK=2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR.3DT"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R(")7>6+S<B!P
M;&EK=2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#@X"FUS9VED(")&:6QE
M('5P;&]A9"(*;7-G<W1R(")79W)Y=V%N:64@<&QI:W4B"@HC.B!L:6(O2&]R
M9&4O0G)O=W-E<BYP:'`Z.#8S"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U
M<'!O<G1E9"XB"FUS9W-T<B`B5V=R>7=A;FEE('!L:6OS=R!N:64@:F5S="!O
M8G.S=6=I=V%N92XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#D*
M;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B1FEL=')Y(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C@R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX
M,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N
M9"(*;7-G<W1R(")&:6YL86YD:6$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,3<Q"B,L(&9U>GIY"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(DEM:>HB
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP
M.C<V"B,L(&9U>GIY"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(DEM
M:>HB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Y
M"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Q-`IM<V=I9"`B1FQI<"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM
M<V=S='(@(B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$P-R!L:6(O5D93+W-Q
M;"YP:'`Z,38P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@
M)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B5;]Y8VEE(&9O;&1E<G4@;FEE
M(&IE<W0@86MT>6YW92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(R"B,L(&9U>GIY"FUS9VED(")&;VYT($-O;&]R(@IM
M<V=S='(@(D1O;7FV;&YY(&MO;&]R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(DIE9'IE;FEE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(V"B,L(&9U>GIY"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S
M=7!P;W)T(&EM86=E<R(*;7-G<W1R(")7>6UA9V%N82!J97-T(&]B<[-U9V$@
M:49R86UE<RAPLWEW86JQ8WEC:"!R86UE:RD@<')Z97H@<')Z96=LL61A<FOJ
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S0*(RP@9G5Z>GD*;7-G:60@
M(D9O<F5C87-T("A4048I(@IM<V=S='(@(E5S=&%W:65N:6$@=WEG;+%D=2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,0IM<V=I9"`B(@HB
M1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S
M="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB
M97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDX"FUS9VED(")&
M;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B6F%P;VUN:6&S9;8@:&%S
MLV$_(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P.0HC+"!F=7IZ
M>0IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B57=A9VDB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,C$*(RP@9G5Z>GD*;7-G:60@(D9O<G1U;F4B"FUS9W-T
M<B`B57=A9VDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*(RP@9G5Z
M>GD*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R(")5=V%G:2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B1F]R='5N
M97,B"FUS9W-T<B`B57=A9VDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,SD*(RP@9G5Z>GD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B57=A9VDB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`P"B,L(&9U>GIY"FUS
M9VED(")&;W)U;7,B"FUS9W-T<B`B57=A9VDB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3`Y"B,L(&9U>GIY"FUS9VED(")&;W)W87)D<R(*;7-G
M<W1R(")0<GIE:V&_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV,`HC+"!F=7IZ>0IM<V=I9"`B1G(B"FUS9W-T<B`B3V0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,S"B,L(&9U>GIY"FUS9VED(")&<F%M97,B"FUS9W-T<B`B3F%Z=V$@
M=;]Y=&MO=VYI:V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B1G)A;F-J82(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L
M($UE=')O<&]L:71A;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA
M(@IM<V=S='(@(D=U:F%N82!&<F%N8W5S:V$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3@T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O
M;'EN97-I82(*;7-G<W1R(")0;VQI;F5Z:F$@1G)A;F-U<VMA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(R,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED
M(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B1G)A;F-U
M<VMI92!497)Y=&]R:6$@4&^S=61N:6]W92!I($%N=&%R:W1Y8WIN92(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&
M<F]M(@IM<V=S='(@(D]D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(S-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0X"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.30*(RP@9G5Z>GD*;7-G:60@
M(D9R;VT@=&AE("(*;7-G<W1R(")/9"(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C0X"B,L(&9U>GIY"FUS9VED(")&=6QL($1E<V-R:7!T
M:6]N(@IM<V=S='(@(E!ELVYY(&]P:7,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z.#(@;&EB+T)L;V-K+VUO;VXN<&AP.C$X,0IM<V=I9"`B1G5L;"!-;V]N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z,SD*(RP@9G5Z>GD*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R(")4=V]J
M92!I;6GJ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B1V%B;VXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDV(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HX.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I
M9"`B1V%M8FEA(@IM<V=S='(@(D=A;6)I82(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=E;F5R
M871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B2&]R9&4@;FEE(&IE<W0@
M=R!P9;-N:2!S:V]N9FEG=7)O=V%N92XB"@HC.B!T96UP;&%T97,O861M:6XO
M<V5T=7`O8V]N9FEG+FAT;6PZ,3`*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C8Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HY,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R
M;6%N>2(*;7-G<W1R(").:65M8WDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N82(*;7-G<W1R(")'
M:&%N82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R(")':6)R86QT87(B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-0HC+"!F=7IZ>0IM<V=I
M9"`B1VEV96X@3F%M92(*;7-G<W1R(")-96YE9+]E<B!P;&EK\W<B"@HC.B!T
M96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`B
M262\(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D
M96PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM
M<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R(")7>7-Z=6MI=V%R:V$@1V]O
M9VQE(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R
M,`IM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDS
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B
M"FUS9W-T<B`B1W)E8VIA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*
M(RP@9G5Z>GD*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R("*F
M<F]D:V]W;V5U<F]P96IS:VD@*$E33RTX.#4Y+3(I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.CDU(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY
M-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W)E96YL
M86YD(@IM<V=S='(@(D=R96YL86YD:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S
M='(@(D=R96YA9&$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W,`HC+"!F=7IZ
M>0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI
M<W1R86-J82(*"B,Z(&QI8B](;W)D92]'<F]U<"YP:'`Z-3@*;7-G:60@(D=R
M;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W!E<FUS+V5D:70N<&AP.C(P,2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C(W-PHC+"!F=7IZ>0IM<V=I9"`B1W)O=7`@<&5R;6ES<VEO;G,B"FUS9W-T
M<B`B1&]M>;9L;F4@=7!R87=N:65N:6$B"@HC.B!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HQ-S8@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HR-3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R(")'<G5P>2!D>7-K=7-Y:FYE(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDX(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HY-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM
M<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R(")'=V%D96QU<&$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HY-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B
M1W5A;2(*;7-G<W1R(")'=6%M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R
M(")'=V%T96UA;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3(*;7-G
M:60@(D=U97)N<V5Y(@IM<V=S='(@(D=U97)N<V5Y(@H*(SH@861M:6XO<&5R
M;7,O961I="YP:'`Z,3(W(&QI8B](;W)D92]097)M<R]522YP:'`Z,C`U"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*(RP@9G5Z>GD*;7-G:60@
M(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(D1O;7FV;&YE('5P<F%W;FEE
M;FEA(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3(X(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,C`V"B,L(&9U>GIY"FUS9VED(")'=65S="!P97)M:7-S
M:6]N<R(*;7-G<W1R(")$;VUYMFQN92!U<')A=VYI96YI82(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT,3<*;7-G:60@(D=U97-T8F]O:R(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B1W=I;F5A(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X"FUS9VED
M(")'=6EN96$M0FES<V%U(@IM<V=S='(@(D=W:6YE82!":7-S874B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G
M:60@(D=U>6%N82(*;7-G<W1R(")'=6IA;F$B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS
M9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L
M=6UN(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@
M=&%B;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+VAT='`N<&AP
M.C$U-PHC+"!F=7IZ>0IM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(E5W:65R>GET96QN:65N:64@;FEE('!O=VEO9+-O
M('-IZB(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B2&%I=&DB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#(*(RP@9G5Z>GD*;7-G:60@(DAA<V@M
M06QG;W)I=&AM(@IM<V=S='(@(D%L9V]R>71M('!O9'!I<W4B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B2&%Z
M92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3$Y(&QI8B](
M;W)D92]&;W)M+G!H<#HR.3,Q"B,L(&9U>GIY"FUS9VED(")(96%D97(B"FUS
M9W-T<B`B3F%GL_-W:VDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$
M;VYA;&0@27-L86YD<R(*;7-G<W1R(")7>7-P>2!(96%R9"!I($UC1&]N86QD
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S
M"B,L(&9U>GIY"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(E5W86=I
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*(RP@9G5Z>GD*;7-G:60@
M(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R("*F<F]D:V]W;V5U<F]P
M96IS:VD@*$E33RTX.#4Y+3(I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`HC+"!F=7IZ>0IM<V=I9"`B2&5I
M9VAT(@IM<V=S='(@(E=Y<V]K:2(*"B,Z(&QI8B](;W)D92](96QP+G!H<#HQ
M-SD@;&EB+TAO<F1E+TAE;'`N<&AP.C$X-B!S97)V:6-E<R]H96QP+VEN9&5X
M+G!H<#HQ-PHC.B!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B
M2&5L<"(*;7-G<W1R(")0;VUO8R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S<S"B,L(&9U
M>GIY"FUS9VED(")(96QP97(B"FUS9W-T<B`B4&]M;V,B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,CD*(RP@9G5Z>GD*;7-G:60@(DAE;6ES<&AE<F4B"FUS
M9W-T<B`B4&]M;V,B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ
M-R!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B2&5R92!I
M<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B
M2&EG:"(*;7-G<W1R(")7>7-O:VDB"@HC.B!L:6(O2&]R9&4O2&ES=&]R>2YP
M:'`Z,S(Q"FUS9VED(")(:7-T;W)Y(&5N=')Y(&YA;65S(&UU<W0@8F4@;F]N
M+65M<'1Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI
M;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-`IM<V=I
M9"`B2&]?;64B"FUS9W-T<B`B7U-T87)T(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(T,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@
M*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B5V%T>6MA;B`H4W1O;&EC
M82!!<&]S=&]L<VMA*2(*"B,Z(&QI8B](;W)D92YP:'`Z,30S-0IM<V=I9"`B
M2&]M92(*;7-G<W1R(")0;V-ZL71E:R(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3(R(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`B061R97,@
M9&]M;W=Y(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B5&5L+B!D;VTN(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y"FUS
M9VED(")(;VYD=7)A<R(*;7-G<W1R(")(;VYD=7)A<R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$P-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N
M9R!+;VYG(@IM<V=S='(@(DAO;F=+;VYG(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C8U"FUS9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z-#(P"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O
M=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(E5D8;-O('-IZB!U<W5N
ML>8@7"(E<UPB('H@<WES=&5M=2XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.C(W-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@
M(E5D8;-O('-IZB!U<W5NL>8@7"(E<UPB('H@<WES=&5M=2XB"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.C0Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G
M92`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$R,#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL
M>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@561A
MLV\@<VGJ('5S=6ZQYB`E<R!<(B5S7"(B"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.C$Q-30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!3=6-C97-S9G5L;'D@<WEN8VAR;VYI<V5D("5S(%PB)7-<(B(*;7-G
M<W1R(")59&&S;R!S:>H@=7-U;K'F(%PB)7-<(B!Z('-Y<W1E;74N(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4
M:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!0
M2%`@97AT96YS:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z-#@Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E
M<R(*;7-G<W1R(")59&&S;R!S:>H@=7-U;K'F(%PB)7-<(B!Z('-Y<W1E;74N
M(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C`U"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E
M<R!<(B5S7"(Z("5S(@IM<V=S='(@(E5D8;-O('-IZB!U<W5NL>8@7"(E<UPB
M('H@<WES=&5M=2XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0U,@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM
M<V=S='(@(E5D8;-O('-IZB!U<W5NL>8@7"(E<UPB('H@<WES=&5M=2XB"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$Q-3$*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@
M)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")59&&S;R!S:>H@=7-U;K'F(%PB)7-<
M(B!Z('-Y<W1E;74N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C@R"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE
M('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B561ALV\@<VGJ
M('5S=6ZQYB!<(B5S7"(@>B!S>7-T96UU+B(*"B,Z(&QI8B](;W)D92]+;VQA
M8BYP:'`Z,S$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B561ALV\@<VGJ
M('5S=6ZQYB!<(B5S7"(@>B!S>7-T96UU+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@
M4G5L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P
M"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A
M*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHR.`IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S
M("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@
M(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#@@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,S`*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#<*;7-G:60@
M(DAU;6ED:71Y.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$Q,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(
M=6YG87)Y(@IM<V=S='(@(E?J9W)Y(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER
M=7,N<&AP.C$W,B!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N
M(&9A:6QE9#H@)7,B"FUS9W-T<B`B4&^SL6-Z96YI92!N:64@<&]W:6]DLV\@
M<VGJ.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,30@;&EB
M+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM
M<V=S='(@(E!OL[%C>F5N:64@;FEE('!O=VEO9+-O('-IZCH@)7,B"@HC.B!L
M:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3<Y(&QI8B](;W)D92]!=71H+V-Y
M<G-Q;"YP:'`Z,C0R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("))34%0
M(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")5
M=VEE<GIY=&5L;FEE;FEE(&YI92!P;W=I;V2S;R!S:>HN("5S(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$S,3<*(RP@9G5Z>GD*;7-G:60@(DE0($%D9')E
M<W,B"FUS9W-T<B`B061R97,B"@HC.B!L:6(O2&]R9&4O075T:"]I<&)A<VEC
M+G!H<#HW-PHC+"!F=7IZ>0IM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA
M8FQE+B(*;7-G<W1R(")";&]K(%PB365T87)<(B!N:64@:F5S="!D;W-TZG!N
M>2XB"@HC.B!L:6(O2&]R9&4O075T:"]I<&)A<VEC+G!H<#HX.0HC+"!F=7IZ
M>0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B
M;&]C:RXB"FUS9W-T<B`B0FQO:R!<(DUE=&%R7"(@;FEE(&IE<W0@9&]S=.IP
M;GDN(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*
M;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(Y"B,L(&9U>GIY"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T
M<B`B5W!R;W=A9+P@:VQU8WH@='5T86HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3(P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS
M9W-T<B`B27-L86YD:6$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8X
M"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@(E1Y;&MO(&EK;VYY(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V.0IM<V=I9"`B26-O;G,@=VET:"!T
M97AT(@IM<V=S='(@(DEK;VYY('H@=&5K<W1E;2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ.#(*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T
M<B`B3F%Z=V$@=&^_<V%M;[9C:3HB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT
M96YT<RYP:'`Z-3@Y"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO
M="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W
M('=I;F1O=RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0T-PIM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I
M;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B
M"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,34X"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@
M:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@
M(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(X"B,L(&9U>GIY"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R
M(")0;V1G;+%D('!O8WIT>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*(RP@9G5Z>GD*;7-G:60@(DEM86=E
M(%523"(*;7-G<W1R(")'<F%F:6MA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Q"B,L(&9U>GIY"FUS
M9VED("));6%G92!54DPZ(@IM<V=S='(@(D=R869I:V$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*
M;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C(*(RP@9G5Z>GD*;7-G:60@(DEM86=E
M('5P;&]A9"(*;7-G<W1R(")79W)Y=V%N:64@<&QI:W4B"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(D=R869I
M:V$B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T
M97,O9&%T82]D871E;6%P+FEN8SHQ,`HC.B!T96UP;&%T97,O9&%T82]C<W9M
M87`N:6YC.C4W('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T
M<B`B26UP;W)T;W=A;F4@<&]L93H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]D
M871E;6%P+FEN8SHR,`HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F
M:65L9#H@)7,B"FUS9W-T<B`B26UP;W)T;W=A;F4@<&]L93H@)7,B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<S"FUS9VED("));7!O<G1E9"!F
M:65L9',Z(@IM<V=S='(@(DEM<&]R=&]W86YE('!O;&$Z(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"B,L
M(&9U>GIY"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R(")7<')O
M=V%DO"!K;'5C>B!T=71A:B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N
M<&AP.C$S-0IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*
M;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,R"B,L(&9U>GIY"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R
M('!A<W-W;W)D+B(*;7-G<W1R(")0<F]S>NH@<&]D8>8@;F%Z=^H@=;]Y=&MO
M=VYI:V$@:2!H87.S;R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E
M(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*
M(RP@9G5Z>GD*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R(")287!O
M<G1U:B!J86MO(&YI97-Z:V]D;&EW>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T
M<B`B26YD:64B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ-#$@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E
M<G,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B26YD
M;VYE>FIA(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`B26YF;R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-#8*(RP@9G5Z>GD*;7-G:60@(DEN9F]R;6%T:6]N
M(@IM<V=S='(@(E1W;VIE(&EN9F]R;6%C:F4B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S$X"B,L(&9U>GIY"FUS9VED("));F9O<FUA=&EO
M;B!N;R!L;VYG97(@879A:6QA8FQE+B(*;7-G<W1R("));F9O<FUA8VIE(&\@
M;W-O8FES='EM(&ML=6-Z=2!P=6)L:6-Z;GEM(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"B,L(&9U>GIY
M"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R(")7<')O=V%D
MO"!K;'5C>B!T=71A:B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM86=E
M(@IM<V=S='(@(E=K;&5J(&]B<F%Z96LB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"B,L(&9U>GIY"FUS9VED("));G-E
M<G0@5&%B;&4B"FUS9W-T<B`B4')Z>6NS861O=V4@=V%R=&^V8VDZ(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0HC+"!F
M=7IZ>0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(EIM:67Q(&QI
M;FLN+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S,*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!?0V]L=6UN
M($)E9F]R92(*;7-G<W1R(")7<')O=V%DO"!K;'5C>B!T=71A:B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M-0HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T
M:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B57-U\2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`HC+"!F=7IZ
M>0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE(@IM<V=S='(@(E5S=?$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*(RP@9G5Z>GD*;7-G:60@
M(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S
M='(@(E5S=?$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C`*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!A(&YE
M=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")5<W7Q(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8Y"B,L(&9U>GIY"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T
M97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R(")5<W7Q(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"B,L
M(&9U>GIY"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C
M=7)R96YT(&YO9&4B"FUS9W-T<B`B57-U\2(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,34P"B,L(&9U>GIY"FUS9VED("));G-E<G0@86QT97)N871E('1E
M;7!L871E(@IM<V=S='(@(E1W\VH@861R97,@92UM86EL.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,S$*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A
M9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W
M;W)D.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4X"B,L(&9U>GIY"FUS9VED("));G-E<G0@
M8V5L;"!A9G1E<B(*;7-G<W1R(")"<F%K(')E>G5L=&%T\W<N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0HC
M+"!F=7IZ>0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(E=P
M<F]W862\(&ML=6-Z('1U=&%J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`HC+"!F=7IZ>0IM<V=I9"`B26YS
M97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R(")"<F%K(')E>G5L=&%T\W<N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV-0HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS
M9W-T<B`B5W!R;W=A9+P@:VQU8WH@='5T86HB"@HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.3`*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!M
M97-S86=E<R(*;7-G<W1R(")"<F%K(')E>G5L=&%T\W<N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"B,L
M(&9U>GIY"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@
M(E=P<F]W862\(&ML=6-Z('1U=&%J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"B,L(&9U>GIY"FUS9VED
M("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R(")7<')O=V%DO"!K
M;'5C>B!T=71A:B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-CD*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!R;W<@
M869T97(B"FUS9W-T<B`B5W!R;W=A9+P@:VQU8WH@='5T86HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"B,L
M(&9U>GIY"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R(")7<')O
M=V%DO"!K;'5C>B!T=71A:B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,C(*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S
M96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@HC+"!F=7IZ>0IM<V=I9"`B
M26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("):;6EE\2!L:6YK+BXN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0HC
M+"!F=7IZ>0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@(EIM
M:67Q(&QI;FLN+BXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0S"B,L(&9U>GIY"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O
M('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").:64@
M;6^_;F$@;W1W;W)Z>>8@;6]D=;-U($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("))
M;G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3`W-0HC+"!F=7IZ>0IM<V=I9"`B26YT96=E<B(*;7-G<W1R
M(")/9'=R\^8B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$S,PHC+"!F=7IZ
M>0IM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(D]D=W+SYB(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A
M;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ-S`@;&EB+TAO<F1E+T-O;7!R
M97-S+WII<"YP:'`Z,C`Q"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP
M.C(Q,`HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R
M(")!9')E<R!D;VUO=WDB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T
M"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R
M(")$;VUYMFQN92!U<')A=VYI96YI82(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$R"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&)A
M=&-H($E$+B(*;7-G<W1R(").:65P;W!R87=N>2!)1"(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,#@X(&QI8B](;W)D92]&;W)M+G!H<#HR,34Y(&QI8B](
M;W)D92]&;W)M+G!H<#HR,C,S"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,CDX
M"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R(")7>7.S
M86YE(&YI97!R87=I9+-O=V4@9&%N92XB"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO
M;B!A9&1R97-S+B(*;7-G<W1R(").:65P<F%W:62S;W=Y(&%D<F5S(&1O8V5L
M;W=Y+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C@Q(&QI8B](
M;W)D92]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!L:6(O2&]R9&4O0V]M<')E
M<W,O9&)X+G!H<#HR,C`*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS
M9W-T<B`B3FEE<')A=VEDLV]W>2!F;W)M870@<&QI:W4B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38T"FUS9VED("));G9A;&ED(&QI8V5N
M<V4@:V5Y+B(*;7-G<W1R(").:65P<F%W:62S;W=Y(&ML=6-Z(&QI8V5N8VII
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3@*(RP@9G5Z
M>GD*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@
M(DYI97IN86YY(&%D<F5S870B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P-PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!M<V=?='EP
M92XB"FUS9W-T<B`B3FEE<&]P<F%W;F$@;F%Z=V$B"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PHC+"!F=7IZ>0IM<V=I9"`B26YV
M86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B1&]M>;9L;F4@=7!R
M87=N:65N:6$B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y-@HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M
M971E<G,N(@IM<V=S='(@(D1O;7FV;&YE('5P<F%W;FEE;FEA(@H*(SH@861M
M:6XO<&5R;7,O861D8VAI;&0N<&AP.C0S"B,L(&9U>GIY"FUS9VED("));G9A
M;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")$;VUYMFQN92!U<')A
M=VYI96YI82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C`*
M(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B
M1&]M>;9L;F4@=7!R87=N:65N:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,38R"B,L(&9U>GIY"FUS9VED("));G9A;&ED('!R;V1U8W0@
M8V]D92XB"FUS9W-T<B`B061R97,@9&]M;W=Y(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*(RP@9G5Z>GD*;7-G:60@(DEN=F%L
M:60@<')O=&]C;VPN(@IM<V=S='(@(DYI97!O<')A=VYY(&]B:F5C=$ED(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB
M(@IM<V=S='(@(DYI97!O<')A=VYY('=P:7,B"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.C$P-#,@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C(P"B,L(&9U>GIY
M"FUS9VED("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R(").:65P;W!R
M87=N>2!O8FIE8W1)9"(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`Q"B,L(&9U>GIY"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R
M97-S+B(*;7-G<W1R(")!9')E<R!D;VUO=WDB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q,0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI
M9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(D%D<F5S(&1O;6]W>2(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C4*(RP@9G5Z>GD*;7-G:60@(DEN
M=F5N=&]R>2(*;7-G<W1R(").:65P;W!R87=N>2!W<&ES(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$Q.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED("))
M<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(DER86XB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$X(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G
M:60@(DER87$B"FUS9W-T<B`B27)A:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G
M<W1R("))<FQA;F1I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,34*
M;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"B,L(&9U>GIY"FUS9VED("))
M<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R(")5=V%G:2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Q-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R
M865L(@IM<V=S='(@(DEZ<F%E;"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-C(U"FUS9VED("))<W-U97(B"FUS9W-T<B`B5WED87=C82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0HC+"!F
M=7IZ>0IM<V=I9"`B271A;&EC(@IM<V=S='(@(E>S;V-H>2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$Q-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B
M271A;'DB"FUS9W-T<B`B5[-O8VAY(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$R,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM<V=S
M='(@(DIA;6%J:V$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S<T(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,3$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R(")3='EC>F7Q(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$R-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*
M87!A;B(*;7-G<W1R(")*87!O;FEA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#<*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,@HC+"!F=7IZ>0IM<V=I
M9"`B2F5R<V5Y(@IM<V=S='(@(D=U97)N<V5Y(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$R-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*;W)D86XB
M"FUS9W-T<B`B2F]R9&%N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,X,"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B3&EP:65C(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W.2!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$V"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B
M0WIE<G=I96,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM
M<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*
M=7-T:69Y($QE9G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@
M4FEG:'0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@
M(DMA>F%C:'-T86XB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C0V"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(V(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*
M;7-G:60@(DME;GEA(@IM<V=S='(@(DME;FEA(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E
M9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#`*;7-G:60@(DME>2!#
M<F5A=&EO;B(*;7-G<W1R(")4=V]R>F5N:64@:VQU8WIA(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-#`S"FUS9VED(")+97D@1FEN9V5R<')I;G0B
M"FUS9W-T<B`B3V1C:7-K(&ML=6-Z82(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C0P,0IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R(")$LW5G;[;F
M(&ML=6-Z82(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0P,`IM<V=I
M9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B5'EP(&ML=6-Z82(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3DX"B,L(&9U>GIY"FUS9VED(")+97D@57-A
M9V4B"FUS9W-T<B`B5VEA9&]M;[;F(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z-S(Y"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U
M8FQI8R!K97ES97)V97(N(@IM<V=S='(@(DML=6-Z(&IUOR!I<W1N:65J92!N
M82!P=6)L:6-Z;GEM('-E<G=E<GIE(&ML=6-Z>2XB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B1'II96-I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T
M"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R(")+:7)I8F%T:2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$R,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B
M2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B2V]R96'Q<VMA(%)E<'5B;&EK82!,=61O=V\M1&5M;VMR871Y8WIN82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$R,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(E)E<'5B;&EK
M82!+;W)E:2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")+
M;W)E86X@*$550RU+4BDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$S-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS
M9W-T<B`B2W5W96IT(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(DMI
M<F=I<W1A;B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I
M9"`B3&%?>6]U="(*;7-G<W1R(")7>6=LL60@*%]Y*2(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z-SD*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@
M(DKJ>GEK(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U
M8FQI8R(*;7-G<W1R("),86]S(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$W
M-`HC+"!F=7IZ>0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(DYA>G=I<VMO
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@X(&QI8B]";&]C:R]M;V]N+G!H
M<#HY,`HC+"!F=7IZ>0IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(DYA
M>G=I<VMO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3$*(RP@9G5Z>GD*
M;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B3F%Z=VES:V\B"@HC.B!L
M:6(O2&]R9&4O075T:"YP:'`Z-C@V"B,L('!H<"UF;W)M870*;7-G:60@(DQA
M<W0@;&]G:6XZ("5S(@IM<V=S='(@(D]S=&%T;FEE(&QO9V]W86YI93H@)7,B
M"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-C@X"B,L('!H<"UF;W)M870*;7-G
M:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`B3W-T871N:64@
M;&]G;W=A;FEE.B`E<R!Z("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C8X
M,PIM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B3W-T871N:64@
M;&]G;W=A;FEE.B!N:6=D>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(J-O
M='=A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"B,L(&9U>GIY"FUS
M9VED("),87<B"FUS9W-T<B`B3FES:VDB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*(RP@9G5Z>GD*;7-G:60@
M(DQA>6]U="(*;7-G<W1R(")7>6QO9W5J(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@
M9F]R(&YO(&)O<F1E<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3,X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8Y"B,L(&9U>GIY"FUS9VED("),969T(@IM<V=S='(@(E!R
M>F5S=?$@=R!L97=O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,3@*(RP@
M9G5Z>GD*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(E!R>GEKLV%D;W=E
M('=A<G1OMF-I.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3$T"B,L(&9U
M>GIY"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R(")0<GIY:[-A9&]W92!W
M87)T;[9C:3HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30S(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#@*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B3&5S;W1H;R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$S,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R("),:6)E<FEA(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$T-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),
M:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(DQI8FEA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$T,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED
M("),:65C:'1E;G-T96EN(@IM<V=S='(@(DQI96-H=&5N<W1E:6XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0HC+"!F=7IZ
M>0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R("):86QO9W5J(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*(RP@9G5Z
M>GD*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B6F%L;V=U:B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"B,L(&9U>GIY
M"FUS9VED("),:6=H="!286EN($5A<FQY(@IM<V=S='(@(EIA;&]G=6HB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`HC+"!F
M=7IZ>0IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(EIA;&]G=6HB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0HC
M+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B6F%L
M;V=U:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,P"B,L(&9U>GIY"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*
M;7-G<W1R("):86QO9W5J(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%-N;W<B"FUS
M9W-T<B`B6F%L;V=U:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,R"B,L(&9U>GIY"FUS9VED("),:6=H="!3;F]W(%-H;W=E
M<B(*;7-G<W1R("):86QO9W5J(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0U"B,L(&9U>GIY"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("),:6)E<FEA
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X,34*(RP@9G5Z>GD*;7-G:60@
M(DQI;FLB"FUS9W-T<B`B6F%D86YI82!P<GIY(&QO9V]W86YI=2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M-@IM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.#<V"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R
M97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H=&UL,G1E>'0N<&AP
M.C$X,PHC+"!F=7IZ>0IM<V=I9"`B3&EN:W,B"FUS9W-T<B`B6F%D86YI82!P
M<GIY(&QO9V]W86YI=2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@HC
M+"!F=7IZ>0IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(E1W\W)Z(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),
M:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$S,`HC+"!F=7IZ>0IM<V=I9"`B3&ES="!$
M871A8F%S97,B"FUS9W-T<B`B4')Z>6NS861O=V4@=V%R=&^V8VDZ(@H*(SH@
M<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3`*;7-G:60@(DQI<W0@2&5L<"!4
M;W!I8W,B"FUS9W-T<B`B5WFV=VEE=&P@=&5M871Y('!O;6]C>2(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,CD*(RP@9G5Z>GD*;7-G:60@(DQI<W0@5&%B
M;&5S(@IM<V=S='(@(E!R>GEKLV%D;W=E('=A<G1OMF-I.B(*"B,Z(&QI8B](
M;W)D92]-24U%+TAE861E<G,N<&AP.C4Y-`HC+"!F=7IZ>0IM<V=I9"`B3&ES
M="U!<F-H:79E(@IM<V=S='(@(E5K<GEJ(&YI97-U8G-K<GEB;W=A;F4B"@HC
M.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.#D*(RP@9G5Z>GD*;7-G
M:60@(DQI<W0M2&5L<"(*;7-G<W1R(")7>;9W:65T;"!T96UA='D@<&]M;V-Y
M(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DV"B,L(&9U>GIY
M"FUS9VED("),:7-T+4ED(@IM<V=S='(@(E=YMG=I971L('1E;6%T>2!P;VUO
M8WDB"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3(*(RP@9G5Z
M>GD*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B5WFV=VEE=&P@=&5M871Y
M('!O;6]C>2(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,PHC
M+"!F=7IZ>0IM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(E=YMG=I971L('1E
M;6%T>2!P;VUO8WDB"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU
M.3$*(RP@9G5Z>GD*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(E5K
M<GEJ(&YI97-U8G-K<GEB;W=A;F4B"@HC.B!L:6(O2&]R9&4O34E-12](96%D
M97)S+G!H<#HU.3`*(RP@9G5Z>GD*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B
M"FUS9W-T<B`B56MR>6H@;FEE<W5B<VMR>6)O=V%N92(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-`IM<V=I9"`B3&ES=&EN9R!U<V5R
M<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B3&ES=&]W86YI92!UOWET:V]W;FEK
M\W<@:F5S="!W>;.Q8WIO;F4N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0W"B,L(&9U>GIY"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(E!O9'!I
M<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#0@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$S,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX.0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(DQI='=A(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.3(*;7-G:60@(DQO861I
M;F<N+BXB"FUS9W-T<B`BHV%D;W=A;FEE+BXN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$Y.0IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S
M='(@(D-Z87,@;&]K86QN>3H@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@S"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B57-T87=I96YI
M82!L;VMA;&YE(&D@8WIA<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HU-B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HV-2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,0HC
M+"!F=7IZ>0IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B3W!C:F4B"@HC.B!L
M;V=I;BYP:'`Z,38R('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-C0@
M=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G
M:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@V
M"FUS9VED("),;V<@:6XB"FUS9W-T<B`B6F%L;V=U:B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3@*;7-G:60@(DQO9R!O=70B"FUS9W-T
M<B`B5WEL;V=U:B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G
M:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(EIA9&%N:6$@<')Z>2!L;V=O=V%N
M:74B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3,Q"FUS9VED("),;V=I;B!F
M86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E
M;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"B),;V=O=V%N:64@;FEE
M('!O=VEO9+-O('-IZBP@<&]N:65W8;\@<&]D8;-EMB!N:65P<F%W:62S;W=E
M(&AA<[-O(&QU8B!N87IWZB`B"B)UOWET:V]W;FEK82XB"@HC.B!L:6(O2&]R
M9&4O075T:"YP:'`Z.3(W"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@
M(DQO9V]W86YI92!N:64@<&]W:6]DLV\@<VGJ+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,S8W"B,L(&9U>GIY"FUS9VED("),;VYG('1E>'0B"FUS9W-T
M<B`B5WEL;V=U:B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`HC+"!F
M=7IZ>0IM<V=I9"`B3&]V92(*;7-G<W1R("(B"B(C+2,M(RTC+2,@('!L7U!,
M+G!O("A);F=O(&@S+3$N,"XQ*2`@(RTC+2,M(RTC7&XB"B)0<GIE<W7Q7&XB
M"B(C+2,M(RTC+2,@('!L7U!,+G!O("A);7`@:#,M-"XP+C,I("`C+2,M(RTC
M+2-<;B(*(E!R>F5N:66V7&XB"B(C+2,M(RTC+2,@('!L7U!,+G!O("A4=7)B
M82!H,RTR+C`N,RD@(",M(RTC+2,M(UQN(@HB4')Z96YI9;8B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B3&]W
M(@IM<V=S='(@(DYI<VMI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@
M;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I
M;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*(RP@9G5Z>GD*;7-G:60@
M(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B1W)U9'II9?$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G
M:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B3'5K<V5M8G5R9R(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS-S,@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C4S"FUS9VED(")-3U1$(@IM<V=S='(@(DU/5$0B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3
M+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B35-'(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$U-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86-A
M;R(*;7-G<W1R(")-86MA=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R
M;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUA8V5D;VYI82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$S-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R(")-861A9V%S:V%R(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"B,L(&9U>GIY"FUS9VED(")-86=I
M8R(*;7-G<W1R(")0;V-Z=&$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z.#$*;7-G:60@(DUA:6PB"FUS9W-T<B`B4&]C>G1A(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0W-PIM<V=I9"`B36%I;"!!9&UI;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#`*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDT"FUS9VED(")-86QA=VDB"FUS9W-T<B`B36%L87=I(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$V-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-
M86QA>7-I82(*;7-G<W1R(")-86QE>FIA(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$V-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*
M;7-G<W1R(")-86QE9&EW>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%L:2(*;7-G<W1R(")-86QI
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDT"FUS9VED(")-86QT82(*;7-G<W1R(")-86QT82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F
M(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD
M(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB
M"FUS9W-T<B`B(@HB6F%R>K%D>F%J(&QI<W2Q(&MA=&5G;W)I:2P@:W3S<GEM
M:2!BZF1Z:65S>B!O>FYA8WIALR!P;WIY8VIE+"!I(&MO;&]R86UI('H@(@HB
M;FEM:2!Z=VFQ>F%N>6UI+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,#,Y"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW-PHC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U-`IM<V=I9"`B
M36%P475E<W0@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HS-S8@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0Q,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G<W1R(")-87)Z96,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0Q"FUS9VED(")-87)G:6XB"FUS9W-T<B`B36%R9VEN97,B"@HC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET
M:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE
M<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$T,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R(")7>7-P>2!-87)S
M:&%L;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34Y(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R='EN:6MA
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,3$*;7-G:60@(DUA
M=&-H:6YG(&9I96QD<R(*;7-G<W1R(")087-U:K%C92!P;VQA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$V,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS"FUS9VED
M(")-875R:71A;FEA(@IM<V=S='(@(DUA=7)E=&%N:6$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,38S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA
M=7)I=&EU<R(*;7-G<W1R(")-875R:71I=7,B"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E
M9&ET+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P.`HC+"!F=7IZ>0IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@
M97AC965D960N(@IM<V=S='(@(E=I861O;6^VYB(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S`V"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3@*;7-G:60@
M(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HX.3@@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,3<@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HS-S@@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS
M9VED(")-87DB"FUS9W-T<B`B36%J(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(U,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T92(*;7-G
M<W1R(")-86IO='1A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"B,L
M(&9U>GIY"FUS9VED(")-961I8VEN92(*;7-G<W1R(")/9')Z=6-O;F4B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$Y"B,L(&9U>GIY
M"FUS9VED(")-96UB97)S(@IM<V=S='(@(D=R=61Z:67Q(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,W,`IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R
M(")4<GEB(&UE;G4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T
M<B`B4&^SL6-Z(&MO;?-R:VDB"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*;7-G:60@(DUE<W-A9V4B"FUS9W-T
M<B`B5VEA9&]M;[;F(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR
M,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U
M="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E
M<FEF:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!E>'!I<F5D
M+B(*;7-G<W1R(")7:6%D;VUOMN8B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38Y(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,#(*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*(RP@9G5Z>GD*
M;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")7:6%D;VUOMN8B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(DUE=&%R(%=E
M871H97(B"FUS9W-T<B`B3V)E8VYY(&-Z87,B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R(")";&]K(%PB365T87)<(B!N:64@:F5S="!D;W-TZG!N>2XB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q,@IM<V=I9"`B(@HB365T87(@8FQO
M8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O
M<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB0FQO:R!<(DUE=&%R
M7"(@;FEE(&IE<W0@9&]S=.IP;GDN(%-Z8WIE9_.S>2!Z9&%R>F5N:6$@>F]S
M=&&S>2!Z86QO9V]W86YE(&1L82`B"B)A9&UI;FES=')A=&]R82XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34R"FUS9VED(")-971A<D1"
M(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R87(N<&AP.C8W(&QI8B](;W)D92]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")-971H;V0B"FUS9W-T<B`B3&5S
M;W1H;R(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HX,2!L:6(O2&]R
M9&4O4E!#+W-O87`N<&AP.C$Q-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R(")5OWEC
M:64@9F]L9&5R=2!N:64@:F5S="!A:W1Y;G=E+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HV-B!L:6(O0FQO8VLO;65T87(N<&AP.C<U"B,L
M(&9U>GIY"FUS9VED(")-971R:6,B"FUS9W-T<B`B365K<WEK(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$V-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED
M(")-97AI8V\B"FUS9W-T<B`B365K<WEK(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C@U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L
M($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"B,L(&9U>GIY
M"FUS9VED(")-:61D;&4B"FUS9W-T<B`B4W1A;F]W:7-K;R(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E
M(@IM<V=S='(@(E1Y<"!-:6UE(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,3`*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B36EN('1E;7`@
M;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(Q-PHC+"!F=7IZ>0IM<V=I9"`B36ER<F]R
M(@IM<V=S='(@(D*SL60B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*
M;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8W,B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,T,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@
M2%144%]297%U97-T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3$T"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO
M=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@
M=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*(RP@9G5Z>GD*;7-G:60@(DUI
M<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B5VEA9&]M;[;F(&1O(@H*(SH@
M;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B
M36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*(RP@
M9G5Z>GD*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B3FEE
M('ID969I;FEO=V%N;R!T96MS='4@=R!N;V-I92!W86MA8WEJ;F5J+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*;7-G
M:60@(DUO(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HW-`HC+"!F=7IZ>0IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B3F]W
M82!P;V-Z=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV.`HC+"!F=7IZ>0IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B3W-T
M871N:6$@;6]D>69I:V%C:F$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F%R+G!H<#HV-B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,PHC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B36]D
M:69I960@1&%T92(*;7-G<W1R(")/<W1A=&YI82!M;V1Y9FEK86-J82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU,@IM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R("):;6EE\2!L:6YK(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-S,*;7-G:60@(DUO9'5L
M=7,B"FUS9W-T<B`B36^S9&%W:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,34P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(E)E<'5B;&EK82!-;[-D87=I:2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$U,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B
M36]N86-O(@IM<V=S='(@(DUO;F%K;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS
M9W-T<B`B36]N9V]L:6$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y,PHC
M+"!F=7IZ>0IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B4F]Z=VGQ
M('!A<V5K(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I
M9"`B36]N=&AL>2(*;7-G<W1R(")#;R!M:65S:;%C(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$V,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-;VYT
M<V5R<F%T(@IM<V=S='(@(DUO;G1S97)R870B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA
M<V5S(@IM<V=S='(@(D9A>GD@:W-IZK]Y8V$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,30X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-30*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B
M"FUS9W-T<B`B36%R;VMO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`HC
M+"!F=7IZ>0IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R(")+<F%J(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G
M:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+G!H<#HT,C@*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R(")0
M<GIE<W7Q('<@9/.S(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z
M-#,R"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B4')Z97-U\2!W(&QE=V\B
M"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HT,S8*;7-G:60@(DUO
M=F4@4FEG:'0B"FUS9W-T<B`B4')Z97-U\2!W('!R87=O(@H*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="YP:'`Z-#(T"FUS9VED(")-;W9E(%5P(@IM<V=S
M='(@(E!R>F5S=?$@=R!G\W+J(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0Y-@IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(E!R
M>F5N:66V('<@9/.S(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Y-2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#DV"FUS9VED(")-;W9E('5P(@IM<V=S='(@(E!R>F5S=?$@=R!G\W+J(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU
M"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(DUO>F%M8FEK(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(Q.#4*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@
M9&]W;B!L:7-T<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C(T,PHC+"!F=7IZ>0IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S
M='(@(E-K87-U:B!W>6)R86ZQ('1OOW-A;6^VYB(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS,S$@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S
M.`IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R(")+;VYT;R(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-3$*;7-G:60@(DUY(%!O<G1A;"(*;7-G
M<W1R(")-\VH@<&]R=&%L(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP
M.C$R-`HC+"!F=7IZ>0IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R
M(")0;W)T=6=A;&EA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(D)I<FUA
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E;65N=%]B;W1T;VTN
M:6YC.C<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-#`P"FUS9VED(").86UE(@IM<V=S='(@(DYA>G=I<VMO(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU
M"FUS9VED(").86UI8FEA(@IM<V=S='(@(DYA;6EB:6$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3<X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA
M=7)U(@IM<V=S='(@(DYA=7)U(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$W-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R(").
M97!A;"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B2&]L86YD:6$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$V,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B06YT>6QE
M($AO;&5N9&5R<VMI92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3@Q"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@
M0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!5
M4DPB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M.#0*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P
M92!2979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N
M86UE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3@W"B,L(&9U>GIY"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM
M96YT(@IM<V=S='(@(D)R86L@;W-O8FES=&5G;R!C97)T>69I:V%T=2(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@P"B,L(&9U>GIY"FUS9VED
M(").971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(E=P<F]W862\
M(&ML=6-Z('1U=&%J(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S
M.0IM<V=I9"`B3F5T=V]R:R(*;7-G<W1R(")3:67F(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z-#$T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,C<*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.`IM<V=I9"`B3F5V97(B"FUS
M9W-T<B`B3FEG9'DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B
M3F]W82!+86QE9&]N:6$B"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-
M86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHR-PIM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(DYO
M=V$@:V%T96=O<FEA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]"
M;&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<Y"B,L(&9U
M>GIY"FUS9VED(").97<@36]O;B(*;7-G<W1R(").;W=Y(&MO;G1A:W0B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").
M97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-C,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE
M=R!:96%L86YD(@IM<V=S='(@(DYO=V$@6F5L86YD:6$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@
M=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C8Q"FUS9VED(").97=S(@IM<V=S='(@(E=I
M861O;6^V8VDB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,CDU"B,L
M(&9U>GIY"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(D=R=7!Y(&1Y<VMU
M<WEJ;F4B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHR,2!T96UP
M;&%T97,O9&%T82]D871E;6%P+FEN8SHT-@HC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C$S-R!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHS,@IM
M<V=I9"`B3F5X="(*;7-G<W1R(").87-TZG!N92(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G
M<W1R(").87-TZG!N82!S=')O;F$B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN
M<&AP.C,W,"!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,W-`IM<V=I9"`B3F5X
M="!O<'1I;VYS(@IM<V=S='(@(DYA<W3J<&YE(&]P8VIE(@H*(SH@;&EB+TAO
M<F1E+U5)+U!A9V5R+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(DYE>'0^(@IM
M<V=S='(@(DYA<W3J<&YE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B
M3FEK87)A9W5A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDV"FUS9VED(").:6=E<B(*;7-G<W1R(").:6=E<B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S,@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$V-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM
M<V=I9"`B3FEG97)I82(*;7-G<W1R(").:6=E<FEA(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,V.`HC+"!F=7IZ>0IM<V=I9"`B3FEG:'0B
M"FUS9W-T<B`B5WES;VMI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W
M.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").:75E(@IM<V=S='(@(DYI=64B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#@U"B,L
M(&9U>GIY"FUS9VED(").;R(*;7-G<W1R(").:64B"@HC.B!T96UP;&%T97,O
M861M:6XO<V5T=7`O9&EF9BYH=&UL.C$V"FUS9VED(").;R!A=F%I;&%B;&4@
M8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*
M;7-G<W1R("(B"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z,3`U"FUS9VED
M(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C<Y(&QI8B](;W)D92]"
M;&]C:R],87EO=70N<&AP.C(S,`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+G!H<#HR-3(*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S
M=&5D('!O<VET:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+VUC
M86PN<&AP.C4P"B,L(&9U>GIY"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R
M;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")"<F%K
M(&EN9F]R;6%C:FD@;R!S97)W97)Z92!344P@>B!UOWET:V]W;FEK86UI(@H*
M(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO(&-H86YG92XB
M"FUS9W-T<B`B0F5Z('IM:6%N+B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,30P"B,L(&9U>GIY"FUS9VED(").;R!C:&EL9"!P97)M:7-S:6]N<R!A
M<F4@=&\@8F4@861D960@8F5L;W<@=&AI<R!L979E;"XB"FUS9W-T<B`B561A
MLV\@<VGJ(&1O9&'F(%PB)7-<(B!D;R!U<')A=VYI9?$N(@H*(SH@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(").;R!C:&EL
M9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R
M(")59&&S;R!S:>H@9&]D8>8@7"(E<UPB(&1O('5P<F%W;FEE\2XB"@HC.B!L
M:6(O2&]R9&4N<&AP.C$V-R!L:6(O2&]R9&4N<&AP.C0W-R!L:6(O2&]R9&4O
M571I;"YP:'`Z-S<V"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B
M0G)A:R!K;VYF:6=U<F%C:FD@9&QA("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H
M<#HW-#$*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R(")"<F%K(&EN
M9F]R;6%C:FD@;R!S97)W97)Z92!,1$%0('H@=7-T87=I96YI86UI+B(*"B,Z
M(&QI8B]61E,O<W%L+G!H<#HU.3$*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*
M;7-G<W1R(")"<F%K(&EN9F]R;6%C:FD@;R!S97)W97)Z92!344P@>B!K871E
M9V]R:6%M:2XB"@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW,#0*(RP@9G5Z
M>GD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(D)R86L@:6YF;W)M86-J
M:2!O('-E<G=E<GIE(%-13"!Z(&MA=&5G;W)I86UI+B(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"B,L(&9U>GIY"FUS9VED(").
M;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B3FEE('=Y9V5N97)O=V%N;R"_861N
M96=O('-K<GEP='4N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S-`HC+"!F=7IZ>0IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI
M960N(@IM<V=S='(@(E=I861O;6^VYB(*"B,Z(&QI8B](;W)D92]"<F]W<V5R
M+G!H<#HX.#$*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B3FEE
M('=G<F%N;R!P;&EK=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ,34@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3(S"B,L(&9U>GIY"FUS9VED(").;R!L;V-A=&EO;B!I<R!S
M970N(@IM<V=S='(@(D%P;&EK86-J82!G;W1O=V$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,34V"B,L(&9U>GIY"FUS9VED(").;R!L;V-A
M=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B3FEE>FYA;GD@861R97-A="(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*(RP@9G5Z>GD*
M;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(E=I861O;6^V
MYB(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*(RP@
M9G5Z>GD*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R(").:64@
M=WEB<F%N;R!UOWET:V]W;FEK82XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,W"B,L(&9U>GIY"FUS9VED(").;R!N=6UB97(@<W!E
M8VEF:65D+B(*;7-G<W1R(").:64@=WEB<F%N;R!UOWET:V]W;FEK82XB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DYO
M(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(").:64@>FYA;&5Z:6]N;R!K
M;VYT86MT\W<B"@HC.B!L:6(O2&]R9&4O075T:"]H='1P+G!H<#HY,0IM<V=I
M9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(DYI92!P;V1A;F\@:&%SLV$@9&QA('5W:65R>GET96QN
M:65N:6$@2%144"XB"@HC.B!L:6(O2&]R9&4O075T:"]I;6%P+G!H<#HQ,#@*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R(").:64@<&]D86YO(&AA<[-A(&1L82!U=VEE<GIY
M=&5L;FEE;FEA($E-05`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z
M-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3FEE('!O9&%N;R!H87.S82!D;&$@
M=7=I97)Z>71E;&YI96YI82!+97)B97)O<RXB"@HC.B!L:6(O2&]R9&4O075T
M:"]L9&%P+G!H<#HY-`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($Q$05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYI92!P;V1A;F\@:&%S
MLV$@9&QA('5W:65R>GET96QN:65N:6$@3$1!4"XB"@HC.B!L:6(O2&]R9&4O
M075T:"]S87-L+G!H<#HW-R!L:6(O2&]R9&4O075T:"]L;V=I;BYP:'`Z.#0*
M(SH@;&EB+TAO<F1E+T%U=&@O<&%M+G!H<#HW-0IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M(").:64@<&]D86YO(&AA<[-A(&1L82!U=VEE<GIY=&5L;FEE;FEA($Q/1TE.
M+B(*"B,Z(&QI8B](;W)D92]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R(").:64@<&]D86YO(&AA<[-A(&1L82!U=VEE<GIY=&5L;FEE
M;FEA(%!!4U-71"XB"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP.C@T"FUS
M9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R(").:64@<&]D86YO(&AA<[-A(&1L82!U=VEE<GIY=&5L
M;FEE;FEA(%--0BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R
M.#8*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R
M;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*
M(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I
M;F<@<VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PHC+"!F=7IZ>0IM<V=I9"`B
M3F\@<G5L97,B"FUS9W-T<B`B57=A9VDB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T"B,L(&9U>GIY"FUS9VED
M(").;R!S:61E<R(*;7-G<W1R(")5=V%G:2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ,C4*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O
M<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC+"!F=7IZ>0IM<V=I9"`B
M3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(E!R
M;W-ZZB!P;V1AYB!N87IWZB!UOWET:V]W;FEK82!I(&AA<[-O(@H*(SH@;&EB
M+TAO<F1E+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,
M(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.3`S"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HY,30@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDS,0HC+"!F=7IZ>0IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(E5W86=I
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q.0IM<V=I9"`B3F\@=F5R
M<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ,C<*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U
M<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q-B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z
M('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3(*;7-G:60@
M(DYO;F4B"FUS9W-T<B`BKV%D;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC
M:70I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"B,L
M(&9U>GIY"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R("*F
M<F]D:V]W;V5U<F]P96IS:VD@*$E33RTX.#4Y+3(I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$W,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F
M;VQK($ES;&%N9"(*;7-G<W1R(").;W)F;VQK(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`HC+"!F=7IZ>0IM<V=I
M9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")0;VUO8R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$V.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I
M9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$W,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I
M9"`B3F]R=V%Y(@IM<V=S='(@(DYO<G=E9VEA(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HV-#`*(RP@9G5Z>GD*;7-G:60@(DYO="!!9G1E<B(*
M;7-G<W1R(")5=V%G:2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-C,Y"B,L(&9U>GIY"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(E5W86=I
M(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS,S$*(RP@9G5Z>GD*;7-G:60@(DYO
M="!A(&1I<F5C=&]R>2(*;7-G<W1R(")+871A;&]G(@H*(SH@;&EB+U9&4R])
M4T]7<FET97(N<&AP.C8S(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713
M=')A=&5G>2YP:'`Z.#,*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U
M=%-T<F%T96=Y+G!H<#HY-`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2YP:'`Z-#@*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM
M<V=S='(@(DYI92!Z86EM<&QE;65N=&]W86YO+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B
M"FUS9W-T<B`B3FEE=7-T87=I;VYE(@H*(SH@;&EB+U9&4RYP:'`Z,3<U(&QI
M8B]61E,N<&AP.C$Y,R!L:6(O5D93+G!H<#HR,3`@;&EB+U9&4RYP:'`Z,C(V
M"B,Z(&QI8B]61E,N<&AP.C(T,B!L:6(O5D93+G!H<#HR-3<@;&EB+U9&4RYP
M:'`Z,C<T(&QI8B]61E,N<&AP.C,P-PHC.B!L:6(O5D93+G!H<#HS-C<@;&EB
M+U9&4RYP:'`Z-#0V(&QI8B]61E,N<&AP.C4Q-2!L:6(O5D93+G!H<#HU,S(*
M(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#,@;&EB+TAO<F1E
M+U-E<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@;&EB+TAO<F1E+U-E<W-I;VY(
M86YD;&5R+G!H<#HQ-S,@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ
M.#<*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HR,S0*;7-G:60@
M(DYO="!S=7!P;W)T960N(@IM<V=S='(@(DYI96]B<[-U9VEW86YE(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$V-`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B57=A
M9VDB"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@
M(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$P"FUS9VED
M(").;W1I8V4B"FUS9W-T<B`B57=A9V$B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S@T(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B3&ES=&]P
M860B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`T-@HC+"!F=7IZ>0IM<V=I
M9"`B3G5M8F5R(@IM<V=S='(@(DQI<W1O<&%D(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$T,C<*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T
M97)S(@IM<V=S='(@(DQI8WIB82!W:65R<WIY(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$S-S$@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C4@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$T-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S
M='(@(DQI8WIB82!K;VQU;6XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,V
M.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R,R!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,30T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B3&EC>F)A('=I
M97)S>GDB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T
M"B,L(&9U>GIY"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P
M9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")3='=O<GIY
MLV6V(&QI<W3J(&1Y<W1R>6)U8WEJ;K$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R(")/
M2R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX,3$*
M(RP@9G5Z>GD*;7-G:60@(D]B:F5C="(*;7-G<W1R(")496UA="(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"B,L(&9U>GIY"FUS9VED(")/
M8FIE8W0@0W)E871O<B(*;7-G<W1R(")$;VUYMFQN92!U<')A=VYI96YI82(*
M"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$S-R!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C(Q-0HC+"!F=7IZ>0IM<V=I9"`B3V)J96-T(&-R96%T;W(@<&5R
M;6ES<VEO;G,B"FUS9W-T<B`B1&]M>;9L;F4@=7!R87=N:65N:6$B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,R!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C
M=&]B97(B"FUS9W-T<B`B4&&\9'II97)N:6LB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#$*;7-G:60@(D]F9FEC
M92(*;7-G<W1R(")":75R;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R(")/;6%N
M(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S"B,L(&9U
M>GIY"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F
M;VQD97)S+B(*;7-G<W1R(")496X@<V5R=V5R(&YI92!O8G.S=6=U:F4@=61O
M<W3J<&YI86YI82!F;VQD97+S=RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#4R(&QI8B](;W)D92]&;W)M
M+G!H<#HQ.3<R"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W
M960N(@IM<V=S='(@(E1W\VH@:F5D96X@861R97,@92UM86EL(&IE<W0@9&]Z
M=V]L;VYY+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I
M9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@
M;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@
M9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP
M:'`Z,S4*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D]T
M=_-R>B!W(&YO=WEM(&]K;FEE(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R
M86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-`HC+"!F=7IZ>0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@
M;F5W('=I;F1O=R(*;7-G<W1R(")0;V)R8>8@<&]C>G3J('<@;W-O8FYY;2!O
M:VYI93\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P
M97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")/<&-J
M92(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HR.2!T96UP;&%T97,O<')E9G,O
M87!P+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E
M<R(*;7-G<W1R(")/<&-J92`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3@*(RP@9G5Z>GD*;7-G:60@(D]R9&5R960@
M3&ES="(*;7-G<W1R(")7>6)I97)Z(&QI<W3J(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R
M(")/<F=A;FEZ86-J82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-38X"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@(DIE9&YO
M<W1K82!O<F=A;FEZ86-Y:FYA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$S,@IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R(")/<F=A;FEZ871O
M<B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"B,L(&9U>GIY"FUS9VED
M(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R(")$;VUY
MMFQN92!U<')A=VYI96YI82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W
M"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E
M<SHB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y
M('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T
M<B`B26YN92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,Q"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R
M("));FYE(&EN9F]R;6%C:F4B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R("));FYE
M('5P<F%W;FEE;FEA(@H*(SH@;&EB+TAO<F1E+T%U=&@O<&%M+G!H<#HW.0IM
M<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(E5W:65R>GET96QN:65N:64@4$%-(&YI92!J97-T(&1O<W3J<&YE
M+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$R-3,*;7-G:60@(E!'
M4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R(")#>69R;W=Y('!O9'!I<R!0
M1U`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,CDY"FUS9VED(")0
M1U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B5VEA9&]M;[;F('IA<WIY9G)O
M=V%N82!01U`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S4Q"FUS
M9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R(")+;'5C>B!P=6)L:6-Z;GD@
M4$=0(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,S,PIM<V=I9"`B
M4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R(")7:6%D;VUOMN8@
M>F%S>GEF<F]W86YA+W!O9'!I<V%N82!K;'5C>F5M(%!'4"(*"B,Z(&%D;6EN
M+W!H<'-H96QL+G!H<#HV.`IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B2V]D
M(%!(4"(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H
M96QL(@IM<V=S='(@(E!O=[-O:V$@4$A0(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(E!-($QI
M9VAT(%)A:6XB"FUS9W-T<B`B6F%L;V=U:B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")032!3
M:&]W97)S(@IM<V=S='(@(DEM<&]R="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"B,L(&9U>GIY"FUS9VED(")032!3;F]W
M(@IM<V=S='(@(E!O:V&_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#`*(RP@9G5Z>GD*;7-G:60@(E!-(%-N;W<@4VAO=V5R
M<R(*;7-G<W1R("));7!O<G0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"B,L(&9U
M>GIY"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R(")5=V%G:2(*"B,Z(&QI
M8B]A<&DN<&AP.C$R.`IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R(")0;W>S
M;VMA(%!?2%`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0V"B,L(&9U>GIY"FUS9VED(")0861D:6YG(@IM<V=S
M='(@(E)O>G=I:F%N:64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(E!A
M:VES=&%N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P,0IM<V=I9"`B4&%L874B"FUS9W-T<B`B4&%L874B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DR(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS
M9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$W-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@(E!A;F%M82(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$W-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B
M4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R(")087!U82U.;W=A($=W:6YE82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.34@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$W-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(E!A<F%G=V%J(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*(RP@9G5Z>GD*
M;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B2W)A:B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#,*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-R!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C`Q.2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<S"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S8@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,V,@IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B2&%SLV\B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$S,C(*;7-G:60@(E!A<W-W
M;W)D(&EN8V]R<F5C="(*;7-G<W1R(")(87.S;R!N:65P<F%W:62S;W=E(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O<F%D:75S+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G
M:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(D)R86L@:6YF;W)M86-J:2!O('-E<G=E<GIE(%-13"!Z
M('6_>71K;W=N:6MA;6DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`U-`IM
M<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B2&%S
MLV\@>B!P;W1W:65R9'IE;FEE;2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(DAA<[-O.B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S
M=V]R9#H@(@IM<V=S='(@(DAA<[-O.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M-3`@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,S4*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T
M8V@N(@IM<V=S='(@(DAA<[-O(&UU<VD@<&%S;W=AYBXB"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3(P('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B5VML
M96HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R(")7:VQE
M:B!Z92!S8VAO=VMA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHU,0HC+"!F=7IZ>0IM<V=I9"`B4&%T:"(*;7-G<W1R(")7
M:VQE:B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHT"FUS9VED
M(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B4&5O<&QE(@IM<V=S='(@
M(EM287!O<G0@;R!P<F]B;&5M:65=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*(RP@9G5Z>GD*;7-G:60@(E!E<F-E
M;G0B"FUS9W-T<B`B1')U:W5J(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+V-O;F9I<FU?8F]T=&]M+FEN8SHV"FUS9VED(")097)F;W)M($UA:6YT96YA
M;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B5WEK;VYA:B!C>6ML:6-Z;F4@;W!E
M<F%C:F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDX"FUS9VED(")0
M97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S
M='(@(E=Y:V]N86H@8WEK;&EC>FYE(&]P97)A8VIE('!O9&-Z87,@;&]G;W=A
M;FEA/R(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,2!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z-C0*(SH@861M:6XO<&5R;7,O861D8VAI;&0N
M<&AP.C8W"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(E5P<F%W;FEE;FEE
M(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HV.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N
M(@IM<V=S='(@(D)R86L@9&]S=.IP=2(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N
M<&AP.C(R-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z.3,*(SH@861M:6XO
M<&5R;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-S0*
M(RP@9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(D%D;6EN:7-T<F%C:F$B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C$T-2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T.`HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C$U,@IM<V=I9"`B4&5R;6ES<VEO;G,@9F]R(@IM
M<V=S='(@(E5P<F%W;FEE;FEA(&1L82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV-0IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B
M26YF;W)M86-J92!O<V]B:7-T92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R(")0
M97)U(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#8@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B1FEL
M:7!I;GDB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y
M-@IM<V=I9"`B4&AO;F4B"FUS9W-T<B`B5&5L969O;B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT,C4*;7-G:60@(E!H;W1O<R(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DP(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R(")0:71C86ER;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED
M(")0:7AE;',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@
M(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#@*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M
M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B3F$@<&5W;F\@=7-U;K'F('1E
M;B!W>6)R86YY(&5L96UE;G0Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")0;&5A<V4@8V]N
M9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM
M<V=S='(@(DYA('!E=VYO('5S=6ZQYB!W>6)R86YY(&5L96UE;G0Z(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(U-S`*(RP@9G5Z>GD*;7-G:60@(E!L96%S
M92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(E!R;W-ZZB!P
M;V1AYB!N;W>Q(&YA>G?J.B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C$R"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT
M97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R(")0<F]S
M>NH@<&]D8>8@;F%Z=^H@9&QA(&YO=V5G;R!F;VQD97)U.B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,S`Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI
M9"!)4"!A9&1R97-S+B(*;7-G<W1R(")0<F]S>NH@<&]D8>8@<&]P<F%W;GD@
M861R97,@25`N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-3D*;7-G:60@
M(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@
M;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR-#4P"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T
M:6UE+B(*;7-G<W1R(")0<F]S>NH@<&]D8>8@<&]P<F%W;GD@8WIA<RXB"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A
M<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@
M(E!R;W-ZZB!O<&ES8>8@<')O8FQE;2XB"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C$X('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(*;7-G
M:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D
M(@IM<V=S='(@(E!R;W-ZZB!P;V1AYB!N87IWZB!UOWET:V]W;FEK82!I(&AA
M<[-O(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E;65N=%]T;W`N
M:6YC.C$R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E!L96%S92!R96%D('1H
M92!F;VQL;W=I;F<@=&5X="X@(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E
M<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0HC+"!F=7IZ>0IM
M<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G
M<W1R(")-=7-I<WH@;VMR9;9L:>8@=;]Y=&MO=VYI:V$L(&MT\W)E9V\@8VAC
M97-Z('5S=6ZQYBXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@X(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R(")0;VQS:V$B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@
M(E!O;&ET:6-S(@IM<V=S='(@(EIW:?$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#,T"B,L(&9U>GIY"FUS9VED(")0;VQL<R(*;7-G<W1R("):
M=VGQ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B4&]R='5G86QI82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B
M>2!)34%0*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V
M-B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@V"FUS9VED
M(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]0<F5F<R]L9&%P+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B4')E
M9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")!=71H7VQD87`Z($YI92!Z;F%L97II;VYO('=Y;6%G86YE9V\@
M<F]Z<WIE<GIE;FEA($Q$05`N(@H*(SH@;&EB+TAO<F1E+U!R969S+W-E<W-I
M;VXN<&AP.C,S"B,L(&9U>GIY"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U
M:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?:6UP.B!7>6UA9V%N92!R;WIS>F5R>F5N:64@24U!4"!N:64@>FYA;&5Z
M:6]N92XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-0IM<V=I9"`B4')E
M<W-U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3D*
M;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C,*;7-G:60@(E!R97-S
M=7)E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$X.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T
M<B`B4&]D9VRQ9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`HC+"!F=7IZ>0IM<V=I9"`B4')E=FEE
M=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(E=YMG=I971L
M('IAL[%C>FYI:R!W(&]S;V)N>6T@;VMN:64B"@HC.B!L:6(O2&]R9&4O4')E
M9G,O54DN<&AP.C,V,"!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V-`HC+"!F
M=7IZ>0IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")0<F5Z96YT
M86-J92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B4')I=F%T92!+97DB
M"FUS9W-T<B`B2VQU8WH@<')Y=V%T;GDB"@HC.B!L:6(O2&]R9&4O365N=2YP
M:'`Z,38Y"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(E!R;V)L96TB"@HC.B!S
M97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C<*;7-G:60@(E!R;V)L96T@1&5S8W)I
M<'1I;VXB"FUS9W-T<B`B3W!I<R!P<F]B;&5M=2(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR,3,*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3$R(&QI8B](;W)D92]&;W)M+G!H
M<#HR,3@Y"B,L(&9U>GIY"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R(")7
M>6QO9W5J(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED
M(")0=6)L:6,@2V5Y(@IM<V=S='(@(DML=6-Z('!U8FQI8WIN>2(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y
M($%L9V]R:71H;2(*;7-G<W1R(")!;&=O<GET;2!K;'5C>F$@<'5B;&EC>FYE
M9V\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T-`IM<V=I9"`B
M4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(DEN9F]R;6%C:F4@;R!K;'5C>G4@
M<'5B;&EC>FYY;2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C(S,`IM
M<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U
M8V-E<W-F=6QL>2XB"FUS9W-T<B`B4&%R82!K;'5C>GD@;W-O8FES='EC:"!N
M:64@>F]S=&&S82!W>6=E;F5R;W=A;F$@<&]M>;9L;FEE+B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$X,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@
M(E!U97)T;R!2:6-O(@IM<V=S='(@(E!O<G1O<GEK;R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$X-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E%A
M=&%R(@IM<V=S='(@(DMA=&%R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8R
M"FUS9VED(")1=65R>2(*;7-G<W1R("):87!Y=&%N:64B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C8V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")2
M4T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R(")+;'5C>B!P=6)L:6-Z
M;GD@4E-!("@E9"!B:73S=RDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(V
M-0HC+"!F=7IZ>0IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(E-K
M87-U:B!W>6)R86ZQ('1OOW-A;6^VYB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0S"B,L(&9U>GIY"FUS9VED(")286EN(@IM
M<V=S='(@(D]S=')Z9;]E;FEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#0*(RP@9G5Z>GD*;7-G:60@(E)A:6X@16%R;'DB
M"FUS9W-T<B`B6F%L;V=U:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0U"B,L(&9U>GIY"FUS9VED(")286EN($QA=&4B"FUS
M9W-T<B`B6F%L;V=U:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0V"B,L(&9U>GIY"FUS9VED(")286EN(%-H;W=E<B(*;7-G
M<W1R("):86QO9W5J(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#<*(RP@9G5Z>GD*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS
M9W-T<B`B6F%L;V=U:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")286EN('1O(%-N;W<B"FUS
M9W-T<B`B6F%L;V=U:B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"B,L
M(&9U>GIY"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R(")5=V%G:2(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8X(&QI8B](;W)D
M92]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"B,L(&9U>GIY"FUS9VED(")2871I
M;R(*;7-G<W1R(")/<&-J92(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,CDS
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3@P"B,L(&9U>GIY"FUS9VED(")296%D(@IM<V=S='(@(E!R>F6S861U
M:B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PHC+"!F
M=7IZ>0IM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R(").;W=E('=I861O
M;6^V8VDB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R
M"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@
M;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@
M5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`HC
M+"!F=7IZ>0IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T
M<B`B5WIN\W<@<W=O:K$@<V5S:NHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S@S"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB
M"FUS9W-T<B`B3V2V=VEEOR!D>6YA;6EC>FYE(&5L96UE;G1Y(&UE;G4Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S,PIM<V=I9"`B4F5F<F5S:"!0
M;W)T86P@5FEE=SHB"FUS9W-T<B`B3V2V=VEEOR!W:61O:R!S97)W:7-U.B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX.30@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$R,3,@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,S4*;7-G:60@(E)E9V5X(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C0X"FUS9VED(")2
M96QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,R-@HC+"!F=7IZ>0IM<V=I9"`B4F5M87)K<R(*;7-G<W1R
M(")$86YI82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,30*;7-G:60@
M(E)E;6]T92!397)V97)S(@IM<V=S='(@(EID86QN92!S97)W97)Y(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@
M55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,2!T96UP
M;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$U"FUS9VED(")296UO=F4B
M"FUS9W-T<B`B57-U\2(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8SHQ,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(E5S=?$@8FQO:R(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,CD*;7-G
M:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B57-U\2!K;VQU;6[J(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`HC+"!F
M=7IZ>0IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`B57-U\2!P
M87+J(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,S8*;7-G:60@
M(E)E;6]V92!P86ER(@IM<V=S='(@(E5S=?$@<&%RZB(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HR,#4*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@
M9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-#$*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B57-U\2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT.0IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N
M:6YC.C$V"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R(")5<W7Q('6_>71K
M;W=N:6MA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHW
M"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R
M("):9&%L;F4@=;]Y=&MO=VYI:V$Z("5S(@H*(SH@;&EB+TAO<F1E+U)00R]X
M;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W
M97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-`HC+"!F=7IZ>0IM<V=I9"`B
M4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R
M("*O861A;GD@;V)J96MT(&YI97IN86QE>FEO;GDN(@H*(SH@;&EB+TAO<F1E
M+G!H<#HQ-S0@;&EB+TAO<F1E+G!H<#HT.#<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D)R86L@=WEM86=A;F5J(&]P8VII
M("=U:60G(&1L82!K;VYF:6=U<F%C:FD@=7-T87=I9?$N(@H*(SH@;&EB+U9&
M4R]F='`N<&AP.C<T-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW,3`@;&EB+U9&
M4R]S<6PN<&AP.C4Y-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q
M=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(D)R86L@=WEM86=A;F5J(&]P8VII("=U:60G(&1L82!K
M;VYF:6=U<F%C:FD@=7-T87=I9?$N(@H*(SH@;&EB+TAO<F1E+U5T:6PN<&AP
M.C<X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E
M<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M0G)A:R!W>6UA9V%N96H@;W!C:FD@)W5I9"<@9&QA(&MO;F9I9W5R86-J:2!U
M<W1A=VEE\2XB"@HC.B!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z,S(X
M"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,Y(&QI8B](;W)D92]&
M;W)M+U)E;F1E<F5R+G!H<#HS,34*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C$P,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0T
M"FUS9VED(")297-E="(*;7-G<W1R(")+87-U:B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E="!087-S=V]R9"(*;7-G
M<W1R(")7>6-Z>;;F(&AA<[-O(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z,C<*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B
M5WEC>GFVYB!4=V]J92!H87.S;R(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR
M."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C4@861M:6XO<&AP<VAE;&PN<&AP.C<Q
M"FUS9VED(")297-U;'1S(@IM<V=S='(@(E=Y;FEK:2(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#(@=&5M<&QA=&5S+W!R969S+V5N9"YI
M;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B4&]W<O-T
M(&1O(&]P8VII(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R(")2975N:6]N
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")2979E<G0@0V]N9FEG=7)A
M=&EO;B(*;7-G<W1R(")(;W)D92!N:64@:F5S="!W('!ELVYI('-K;VYF:6=U
M<F]W86YE+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S(*;7-G:60@
M(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R(")2;WIB=61O=V%N
M>2!E9'ET;W(@=&5K<W1U(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X
M"B,L(&9U>GIY"FUS9VED(")2:61D;&5S(@IM<V=S='(@(E-T86YO=VES:V\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S`*(RP@9G5Z>GD*;7-G:60@(E)I9VAT(@IM<V=S='(@(E=Y<V]K:2(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3(P"B,L(&9U>GIY"FUS9VED(")2
M:6=H="!H96%D97(B"FUS9W-T<B`B4')Z>6NS861O=V4@=V%R=&^V8VDZ(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,38*(RP@9G5Z>GD*;7-G:60@(E)I
M9VAT('9A;'5E<R(*;7-G<W1R(")0<GIY:[-A9&]W92!W87)T;[9C:3HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C@*(RP@9G5Z>GD*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G
M<W1R(")496PN(&MO;2XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R(")3=&%N;W=I<VMO(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R(")2=6UU;FEA(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P.`IM<V=I9"`B4F]T871E
M(#$X,"(*;7-G<W1R(")/8G+SYB!O(#$X,"!S=&]P;FDB"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`U"FUS9VED(")2;W1A=&4@
M3&5F="(*;7-G<W1R(")/8G+SYB!W(&QE=V\B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C$Q"FUS9VED(")2;W1A=&4@4FEG:'0B
M"FUS9W-T<B`B3V)R\^8@=R!P<F%W;R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*(RP@9G5Z>GD*;7-G:60@
M(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(E>S8;9C:7=OMF-I(')ZZF1U(%!R
M;W!E<G1I97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R
M(")7LV&V8VEW;[9C:2!R>NID=2!0<F]P97)T:65S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3,*(RP@9G5Z>GD*;7-G:60@(E)U;&5S(@IM<V=S
M='(@(E-T86YO=VES:V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O
M;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,C$*;7-G:60@(E)U;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3DY(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2
M=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B4F]S:F$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C`P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2
M=V%N9&$B"FUS9W-T<B`B4G5A;F1A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA
M='5R92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@
M(E=I861O;6^VYB!Z87-Z>69R;W=A;F$@4R]-24U%(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@
M:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B57=I97)Z>71E;&YI96YI92!3
M05-,(&YI92!J97-T(&1O<W3J<&YE+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-3D*(RP@9G5Z>GD*;7-G:60@(E--4R!-97-S86=I;F<B"FUS
M9W-T<B`B5WFV=VEE=&QA;FEE('=I861O;6^V8VDB"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R(")0;W=L;VMA
M(%-13"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S`*;7-G:60@
M(E-32"(*;7-G<W1R(")34T@B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T
M<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3,R"FUS9VED(")37U%,(%-H96QL(@IM
M<V=S='(@(E!O=[-O:V$@4U]13"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-C$*(RP@9G5Z>GD*;7-G:60@(E-A(@IM<V=S
M='(@(EIA<&ES>B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R("*F
M=VGJ=&$@2&5L96YA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B
M"FUS9W-T<B`B4V%I;G0@2VET=',@:2!.979I<R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y
M,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@
M3'5C:6$B"FUS9W-T<B`B4V%I;G0@3'5C:6$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3@Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3(*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0
M:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@(E-A:6YT+5!I97)R92!I($UI
M<75E;&]N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA
M9&EN97,B"FUS9W-T<B`B4V%I;G0@5FEN8V5N="!I($=R96YA9'EN>2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G
M:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C4Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")3
M86UO82(*;7-G<W1R(")386UO82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS
M9W-T<B`B4V%N($UA<FEN;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN
M8VEP92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3D*(RP@9G5Z>GD*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R
M(")7;VIE=_-DO'1W;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I82(*;7-G<W1R
M(")!<F%B:6$@4V%U9'EJ<VMA(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC.CDX"FUS9VED(")3879E(@IM<V=S='(@(EIA<&ES>B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L('!H<"UF;W)M870*;7-G
M:60@(E-A=F4@)7,B"FUS9W-T<B`B6F%P:7-Z("5S(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3879E(%PB)7-<(B(*;7-G<W1R("):87!I<WH@7"(E<UPB(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM
M<V=S='(@(EIA<&ES>B!O<&-J92(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-S`*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@
M87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*
M(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z-CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DAO<F1E(&YI92!J97-T('<@<&6S
M;FD@<VMO;F9I9W5R;W=A;F4N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z.3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P
M('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(DYI92!M;[]N
M82!O='=O<GIYYB!M;V1ULW4@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"B,L(&9U>GIY
M"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B57=A9VDB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(E-C
M:65N8V4B"FUS9W-T<B`B3F%D87=C82(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B4WIU:V%J(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(W.`HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H
M($5N9VEN97,B"FUS9W-T<B`B3W!C:F4@=WES>G5K:7=A;FEA(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(Y-S(*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G
M<W1R(")7>6)I97)Z('!L:6MI(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0U-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9&%T
M92(*;7-G<W1R(")7>6)I97)Z(&9O<FUA="!D871Y.B(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3DX"B,L(&9U>GIY"FUS9VED(")396QE8W0@
M82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B4W1W\W)Z(&YO=[$B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"B,L(&9U>GIY"FUS9VED(")396QE
M8W0@82!N97<@;W=N97(B"FUS9W-T<B`B4W1W\W)Z(&YO=[$B"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(E-E
M;&5C="!A('-E<G9E<B(*;7-G<W1R(")3='?S<GH@;F]WL2(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,34V"B,L(&9U>GIY"FUS9VED(")396QE
M8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R(")3='?S<GH@;F]WL2(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR-C8R"B,L(&9U>GIY"FUS9VED(")396QE8W0@
M86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B5WEB:65R>B!F;W)M870@
M9&%T>3HB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#$Q"B,L(&9U>GIY"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@
M(E-T=_-R>B!N;W>Q(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"B,L
M(&9U>GIY"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE
M960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N
M9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B
M(@HB5WEB:65R>B!Z;F%K:2!Z('!O;FF_<WIY8V@@</-L(&9O<FUU;&%R>F$N
M($UOOV5S>B!J92!S:V]P:6]W8>8@:2!W:VQE:>8@>B`B"B)P;VQA('1E:W-T
M;W=E9V\N(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@
M(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(E=Y8FEE<GH@
M>FYA:R!P;V1Z:6&S=2!D871Y.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R
M(")7>6)I97)Z(&9O<FUA="!D871Y.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I
M9&5N=&ET>7-E;&5C="YI;F,Z.#D*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I
M='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R(")7>6)I97)Z('1OOW-A
M;6^VYB!D;R!Z;6EA;GDZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z
M,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S='(@
M(E=Y8FEE<GH@>FYA:R!P;V1Z:6&S=2!D871Y.B(*"B,Z('1E;7!L871E<R]D
M871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R;6%T
M.B(*;7-G<W1R(")7>6)I97)Z(&9O<FUA="!C>F%S=3HB"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C8T"FUS9VED(")396QE8W0@='=O(&UA=&-H
M:6YG(&9I96QD<RXB"FUS9W-T<B`B5WEB:65R>B!D=V$@<&%S=6JQ8V4@<&]L
M82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDX"FUS9VED(")396QE
M8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(E=Y8FEE<GH@<V-H96UA
M="!K;VQO<O-W+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#`*;7-G
M:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B
M5WEB:65R>B!T=_-J('!R969E<F]W86YY(&KJ>GEK.B(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@
M4F5P;W)T(@IM<V=S='(@(E=YMFQI:B!R87!O<G0@;R!P<F]B;&5M:64B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38Q"FUS9VED
M(")396YD(%--4R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C$S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S
M='(@(E-E;F5G86PB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-@HC+"!F
M=7IZ>0IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B3F%Z=V$@=;]Y=&MO=VYI
M:V$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@R
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3D*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B
M4V5P=&5M8F5R(@IM<V=S='(@(E=R>F5S:67Q(@H*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE
M9W)O(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-S`Q"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(DYU;65R('-E<GEJ
M;GDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30X"B,L(&9U
M>GIY"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R(")";&]K(%PB365T87)<(B!N:64@:F5S="!D;W-TZG!N>2XB
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@HC+"!F
M=7IZ>0IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R(")7:6%D
M;VUOMN8B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,Q,PIM<V=I9"`B4V5T
M(@IM<V=S='(@(E5S=&%W(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V
M"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U
M<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(E-E="!U<"!R
M96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO
M=7(@<&]R=&%L+B(*;7-G<W1R(")5<W1A=R!Z9&%L;F4@<V5R=V5R>2P@9&\@
M:W3S<GEC:"!C:&-E<WH@;6EEYB!D;W-TZG`@>B!S97)W:7-U+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`IM<V=I9"`B4V5T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G
M<W1R(")5<W1A=R!P<F5F97)O=V%N>2!JZGIY:RP@<W1R96;J(&-Z87-O=[$@
M:2!O<&-J92!D871Y+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`IM
M<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@
M<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y
M(&]P=&EO;G,N(@IM<V=S='(@(B(*(E5S=&%W('5SLW5GZB!P;V-ZL71K;W>Q
M+"!S8VAE;6%T(&MO;&]R\W<L(&]DMG=I9;]A;FEE('-T<F]N>2!I(&EN;F4@
M;W!C:F4@(@HB=WFV=VEE=&QA;FEA(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HW-`IM<V=I9"`B4V5T=7`B"FUS9W-T<B`B2V]N9FEG=7)A8VIA(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,SD*(RP@9G5Z
M>GD*;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS
M9W-T<B`B3FEE(&UOOVYA(&]T=V]R>GGF(&UO9'6S=2!-86EN=&5N86YC95]4
M87-K("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-`IM
M<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R
M86UE=&5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(P,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G
M<W1R(")3>F5S>F5L92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M-3$*(RP@9G5Z>GD*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(DAI<WIP86YI
M82(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED
M(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(DMR\W1K:2!O<&ES(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0S.`IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K
M97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]097)M<RYP:'`Z,CDR('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM
M<V=S='(@(E!O:V&_(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U.`IM
M<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S
M879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#@R"FUS
M9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM
M<V=S='(@(E!O:V%Z>7=AYB!C>F%S(&]S=&%T;FEE9V\@>F%L;V=O=V%N:6$@
M<&\@;&]G;W=A;FEU/R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8V"FUS
M9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#$R"B,L(&9U>GIY"FUS9VED(")3
M:&]W('!I8VME<B(*;7-G<W1R("));7!O<G0B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3$X"B,L(&9U>GIY"FUS9VED(")3:&]W('1A8FQE(&]P97)A
M=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(E=YMG=I971L8>8@:6MO;NH@9FEL
M=&5R\W<@;F$@<&%S:W4@>F%D8?$_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU
M(&]N('1H92!L969T/R(*;7-G<W1R(")0;VMAOR!M96YU("5S('!O(&QE=V5J
M/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU.`HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L
M;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")496PN(&MO;2XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C,*(RP@9G5Z>GD*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@
M9&EA;&]G(@IM<V=S='(@(E1E;"X@:V]M+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0HC+"!F=7IZ>0IM
M<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM
M<V=S='(@(E1E;"X@:V]M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0HC+"!F=7IZ>0IM<V=I9"`B4VAO
M=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B5&5L+B!K
M;VTN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C0*(RP@9G5Z>GD*;7-G
M:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(E=G<GEW86YI92!P;&EK=2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"B,L(&9U
M>GIY"FUS9VED(")3:&]W97)S(@IM<V=S='(@(DEM<&]R="(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"B,L(&9U>GIY"FUS
M9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(DMR\W1K:64@<W1R97-Z8WIE
M;FEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3(*(RP@9G5Z>GD*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R("));7!O
M<G0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M,PIM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,SDY"B,L(&9U>GIY"FUS
M9VED(")3:')I;FLB"FUS9W-T<B`B0F%H<F%J;B(*"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70N<&AP.C8Y,B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H
M<#HW-30*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z.#$R(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C@W-`HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+G!H<#HY,#D@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z.30V
M"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.CDW-"!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+G!H<#HQ,#`T"FUS9VED(")3:')I;FL@;W(@;6]V92!N
M96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(E-I97)R
M82!,96]N92(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8U"B,L
M(&9U>GIY"FUS9VED(")3:6=N('5P(@IM<V=S='(@(E)E:F5S=')A8VIA("5S
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,@IM<V=I9"`B4VEG
M;B!U<"!I9B!N;W0@<F5G:7-T97)E9"(*;7-G<W1R("):87)E:F5S=')U:B!S
M:>HL(&IEMFQI(&IE<WIC>F4@=&5G;R!N:64@>G)O8FFS9;8B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E(@IM
M<V=S='(@(E!O9'!I<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-S$Q"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(D%L9V]R
M>71M('!O9'!I<W4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B4VEN
M9V%P=7(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DV(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,C$U(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,W"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,C0W(&QI8B](;W)D92]&;W)M+G!H<#HR.3(Y(&QI
M8B](;W)D92]&;W)M+G!H<#HS,3(R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R87(N<&AP.C8U(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<R
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@T"FUS9VED(")3
M:7IE(@IM<V=S='(@(E=I96QK;[;F(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+V-O;F9I<FU?8F]T=&]M+FEN8SHY"FUS9VED(")3:VEP($UA:6YT96YA
M;F-E(@IM<V=S='(@(E!O;6GQ(&]P97)A8VIE(&-Y:VQI8WIN92(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(P,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G
M:60@(E-L;W9A:VEA(@IM<V=S='(@(E.S;W=A8VIA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(P."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO
M=F5N:6$B"FUS9W-T<B`B4[-O=V5N:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B4VYO=R(*
M;7-G<W1R(")0;VMAOR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4U"B,L(&9U>GIY"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G
M<W1R("));7!O<G0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU-@HC+"!F=7IZ>0IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S
M='(@(DEM<&]R="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4W"B,L(&9U>GIY"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB
M"FUS9W-T<B`B2W+S=&MI92!S=')E<WIC>F5N:64B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B
M4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B26UP;W)T(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-S@*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM<V=I9"`B4VYO=R!E
M<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L
M;VUO;B!)<VQA;F1S(@IM<V=S='(@(E=Y<W!Y(%-A;&]M;VYA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@IM<V=I
M9"`B4V]M86QI82(*;7-G<W1R(")3;VUA;&EA(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.3(U"B,L(&9U>GIY"FUS9VED(")3
M;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R(")3:V%S=6H@=WEB<F%NL2!T
M;[]S86UOMN8B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-34Y(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*(RP@9G5Z>GD*;7-G:60@(E-O=7)C
M92!A9&1R97-S(@IM<V=S='(@(D%D<F5S(&1O;6]W>2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(P-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O
M=71H($%F<FEC82(*;7-G<W1R(")0;[-U9&YI;W=A($%F<GEK82(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H
M25-/+3@X-3DM,RDB"FUS9W-T<B`B4&^S=61N:6]W;V5U<F]P96IS:VD@*$E3
M3RTX.#4Y+3,I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U
M=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R(")'96]R9VEA(%!OLW5D;FEO
M=V$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN
M<&AP.C8R"B,L(&9U>GIY"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM
M<V=S='(@(E!O;6]C(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@
M8V5L;',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N=&5N
M="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C@Q-0HC+"!F=7IZ>0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@
M(DAI<WIP86YI82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX,`HC+"!F=7IZ>0IM<V=I9"`B4W!A8VEN9R(*;7-G
M<W1R(")(:7-Z<&%N:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D
M:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R(")(:7-Z<&%N
M:6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@(E-P
M86TB"FUS9W-T<B`B4W!A;2(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ
M-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B161Y
M8VIA('IN86OS=R!S<&5C:F%L;GEC:"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E
M;&PB"FUS9W-T<B`B4&]D>FEE;"!K;VWS<FOJ(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L
M:70@8V]L=6UN(@IM<V=S='(@(E!O9'II96P@:V]L=6UNZB(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G
M:60@(E-P;&ET(')O=R(*;7-G<W1R(")0;V1Z:65L('=I97)S>B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B4W!O<G1S
M(@IM<V=S='(@(DEM<&]R="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@
M(E-R:2!,86YK82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV
M-2!L:6(O0FQO8VLO;65T87(N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")3=&%N
M9&%R9"(*;7-G<W1R(")+86QE;F1A<GHB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R(")3
M=&%R="(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3DU(&QI8B](;W)D92]&
M;W)M+G!H<#HR.#`X"B,L(&9U>GIY"FUS9VED(")3=&%R="!Y96%R(@IM<V=S
M='(@(E-T87)T(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S`*
M;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(E=O:F5W\V2\='=O
M(&QU8B!S=&%N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT
M;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G<W1R(")3=&%T=7,B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C@Q-`HC+"!F=7IZ>0IM<V=I9"`B4W1O<F%G92!F
M;W)M870B"FUS9W-T<B`B1F]R;6%T(&-Z87-U(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU-S(*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S
M='(@(D%D<F5S(&1O;6]W>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,S,*(RP@9G5Z>GD*;7-G
M:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(E5S=&%W:65N:6$B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3@W-`IM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@
M=&AE(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-3
M4UTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B
M"FUS9W-T<B`B5&5M870B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,R(&QI
M8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,3(*;7-G:60@(E-U8FUI="(*
M;7-G<W1R(")7>;9L:6HB"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<(B5S7"(@
M=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL('EO=7(@
M(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@HC+"!F
M=7IZ>0IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(E!ELVYY(&]P:7,Z(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-2!L:6(O2&]R9&4O3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS
M9W-T<B`B4&]W;V1Z96YI92(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@
M=&AE('-Y<W1E;2XB"FUS9W-T<B`B561ALV\@<VGJ(&1O9&'F(%PB)7-<(B!D
M;R!S>7-T96UU+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R
M(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(E5D8;-O('-IZB!U
M<W5NL>8@7"(E<UPB('H@<WES=&5M=2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C@Q(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R(")5
M9&&S;R!S:>H@=7-U;K'F(%PB)7-<(BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@
M7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B561ALV\@<VGJ('5S
M=6ZQYB!<(B5S7"(@>B!S>7-T96UU+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-3$*(RP@9G5Z>GD*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E
M9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S
M='(@(DAO<F1E(&YI92!J97-T('<@<&6S;FD@<VMO;F9I9W5R;W=A;F4N(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C4U"B,L(&9U>GIY"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@
M8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DAO<F1E(&YI92!J97-T
M('<@<&6S;FD@<VMO;F9I9W5R;W=A;F4N(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HV,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+B(*;7-G<W1R(")(;W)D92!N:64@:F5S="!W('!ELVYI('-K;VYF:6=U<F]W
M86YE+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B561A
MLV\@<VGJ('5A:W1U86QN:>8@7"(E<UPB(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G
M<W1R(")59&&S;R!S:>H@9&]D8>8@7"(E<UPB(&1O('-Y<W1E;74N(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM
M<V=I9"`B4W5D86XB"FUS9W-T<B`B4W5D86XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"B,L(&9U>GIY"FUS
M9VED(")3=6UM87)Y(@IM<V=S='(@(DMR\W1K:64@<W1R97-Z8WIE;FEE.B(*
M"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-@HC+"!F=7IZ>0IM<V=I9"`B
M4W5N(%)I<V4B"FUS9W-T<B`B3F%Z=V$@=;]Y=&MO=VYI:V$B"@HC.B!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(E-U;B!3970B
M"FUS9W-T<B`B3F%Z=V$@=;]Y=&MO=VYI:V$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4W5N;GDB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-`HC+"!F
M=7IZ>0IM<V=I9"`B4W5N<FES92(*;7-G<W1R(").87IW82!UOWET:V]W;FEK
M82(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR
M:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B5W-C
M:/-D+WIA8VCS9"!SLV_Q8V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C`S"B,L(&9U>GIY"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B
M3F%Z=V$@=;]Y=&MO=VYI:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C`W"B,L(&9U>GIY"FUS9VED(")3=6YS970B"FUS9W-T<B`B3F%Z
M=V$@=;]Y=&MO=VYI:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C`V"B,L(&9U>GIY"FUS9VED(")3=6YS970Z("(*;7-G<W1R(").87IW
M82!UOWET:V]W;FEK82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3,*(RP@9G5Z>GD*;7-G:60@(E-U<&5R<V-R:7!T(@IM
M<V=S='(@(E!ELVYY(&]P:7,Z(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0T,PHC+"!F=7IZ>0IM<V=I9"`B4W5P<&]R="(*;7-G<W1R("));7!O
M<G0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$U(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`V"FUS9VED(")3=7)I;F%M92(*;7-G<W1R(")3=7)I;F%M(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S0*(RP@9G5Z>GD*;7-G:60@
M(E-U<FYA;64B"FUS9W-T<B`B3F%Z=V$@=;]Y=&MO=VYI:V$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED
M(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(Q-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@
M(E-W87II;&%N9"(*;7-G<W1R(")3=6%Z:2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*
M;7-G<W1R(")3>G=E8VIA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4V
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@
M(E-Z=V%J8V%R:6$B"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HY
M-PHC+"!F=7IZ>0IM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M
M<R(*;7-G<W1R(")/<'+SOVYI:B!F;VQD97(@:V]S>F$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3
M>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R(")3>7)I82(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"B,L(&9U>GIY"FUS
M9VED(")4+5-T;W)M(@IM<V=S='(@(E5W86=I(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FT@86YD
M(%=I;F1Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")4+5-T;W)M<R(*;7-G
M<W1R(")5=V%G:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G
M<W1R(")+<O-T:VEE('-T<F5S>F-Z96YI92(*"B,Z(&QI8B](;W)D92]$871A
M+W1S=BYP:'`Z,38V"B,L(&9U>GIY"FUS9VED(")44U8@9FEL92(*;7-G<W1R
M(")4>71ULR(*"B,Z(&QI8B](;W)D92]522]486)L92YP:'`Z,3,V"B,L(&9U
M>GIY"FUS9VED(")486)L92(*;7-G<W1R(")7L[%C>F]N92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*(RP@
M9G5Z>GD*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B5&5L+B!K
M;VTN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW,@HC+"!F=7IZ>0IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*
M;7-G<W1R(")496PN(&MO;2XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C,T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N
M(@IM<V=S='(@(E1A:G=A;B(*"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS
M9W-T<B`B5&%J=V%N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R(")4
M862_>6MI<W1A;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S4@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B5&%N>F%N:6$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDU"B,L(&9U>GIY"FUS9VED(")487)G
M970Z(@IM<V=S='(@(E=I861O;6^VYB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ-S,*;7-G:60@(E1A<VMS(@IM<V=S='(@(EIA9&%N:6$B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B5&5L97!H
M;VYE($YU;6)E<B(*;7-G<W1R(").=6UE<B!T96QE9F]N=2(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,CDP"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-`HC+"!F
M=7IZ>0IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B4&]D<&ES(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,0HC+"!F=7IZ>0IM<V=I
M9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R(")0;V1P:7,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HR,3<*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B5S(&YI97IN86QE>FEO;GDN(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(E1E;7!L871E($%D;6EN
M:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<F%C:F$B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3(Q,0HC+"!F=7IZ>0IM<V=I9"`B5&5X="(*;7-G<W1R
M(")4>6QK;R!T96MS="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C<*
M;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R(")4>6QK;R!T96MS="(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*
M(RP@9G5Z>GD*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B5'EL:V\@=&5K
M<W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<Q"B,L(&9U>GIY"FUS9VED(")497AT=&]P(@IM<V=S='(@(E1Y;&MO('1E
M:W-T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.3$*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C0@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(R,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*
M;7-G:60@(E1H86EL86YD(@IM<V=S='(@(E1A:FQA;F1I82(*"B,Z(&QI8B](
M;W)D92]!=71H+G!H<#HY,C,*;7-G:60@(E1H86YK('EO=2!F;W(@=7-I;F<@
M=&AE('-Y<W1E;2XB"FUS9W-T<B`B1'IIZFMU:F5M>2!Z82!K;W)Z>7-T86YI
M92!Z('-E<G=I<W4N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<S-PHC+"!F=7IZ
M>0IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B57=I97)Z>71E;&YI96YI92!N:64@<&]W:6]DLV\@<VGJ(@H*
M(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO
M="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+TE-4U`O
M0F]O:RYP:'`Z,3(Y-`HC+"!F=7IZ>0IM<V=I9"`B5&AE($E-4U`@;&]G(&-O
M=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B4&]D<&ES(&YI92!M
M;[]E(&)YYB!Z87-TL7!I;VYA+B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HR.0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO
M="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]I
M;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"B,L(&9U>GIY"FUS9VED(")4:&4@
M3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B
M5'=O<GIO;F$@=VEA9&]M;[;F('IO<W1ALV$@>F%M:VYIZG1A+B!7>6-H;V1Z
M96YI92XB"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C$U."!L:6(O2&]R9&4O
M4&5R;7,N<&AP.C$V.2!L:6(O2&]R9&4O4&5R;7,N<&AP.C$X,`HC.B!L:6(O
M2&]R9&4O4&5R;7,N<&AP.C$Y,B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(P,R!L
M:6(O2&]R9&4O4&5R;7,N<&AP.C(R,0HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP
M.C(S,R!L:6(O2&]R9&4O4&5R;7,N<&AP.C(W,@IM<V=I9"`B(@HB5&AE(&%D
M;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E
M<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI
M<W-I;VYS+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I
M9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@
M=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N
M9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*(RP@9G5Z>GD*;7-G:60@(E1H
M92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R
M97-S(&)O;VLN(@IM<V=S='(@(DMO;G1A:W1Y('IO<W1ALWD@<&]M>;9L;FEE
M(&1O9&%N92!D;R!4=V]J96H@:W-IL;]K:2!A9')E<V]W96HN(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$T.0HC+"!F=7IZ>0IM<V=I9"`B(@HB
M5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@HB4&]T
M<GIE8FYY(&IE<W0@:VQU8WH@<'5B;&EC>FYY(%!'4"!D;R!S<')A=V1Z96YI
M82!P;V1P:7-A;F5J('=I861O;6^V8VDN(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T,0HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE(&1I
M<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@
M;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*
M;7-G<W1R(")482!O<&5R86-J82!N:64@:F5S="!O8G.S=6=I=V%N82XB"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"B,L(&9U>GIY
M"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I
M960N(@IM<V=S='(@(E1A(&]P97)A8VIA(&YI92!J97-T(&]B<[-U9VEW86YA
M+B(*"B,Z(&QI8B](;W)D92]#<GEP="YP:'`Z,3$S"B,L(&9U>GIY"FUS9VED
M(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E
M8B!C;VYN96-T:6]N+B(*;7-G<W1R(")/8G.S=6=A(&]S;V)I<W1E9V\@:VQU
M8WIA(%!'4"!W>6UA9V$@8F5Z<&EE8WIN96=O('!OL[%C>F5N:6$@=W=W+B(*
M"B,Z(&QI8B](;W)D92YP:'`Z,3<U(&QI8B](;W)D92YP:'`Z-#@X"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(EIM:67Q('5S=&%W:65N:6$@
M=')A:W1O=V%N:6$@<&QI:_-W(&D@:V%T86QO9_-W+B(*"B,Z(&QI8B](;W)D
M92YP:'`Z,38X(&QI8B](;W)D92YP:'`Z-#<X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S
M('-E='1I;F=S+B(*;7-G<W1R("):;6EE\2!U<W1A=VEE;FEA('1R86MT;W=A
M;FEA('!L:6OS=R!I(&MA=&%L;V?S=RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP
M.C$U,@IM<V=I9"`B5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I
M='-E;&8N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]$871A+G!H<#HR-C`*
M;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I
M9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S
M<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE
M(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@
M=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G
M<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI
M9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D
M:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N
M("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L
M:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO
M;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E
M96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W
M86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G
M<W1R(")4;[]S86UOMN8@7"(E<UPB('IO<W1ALV$@=7-U;FGJ=&$N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,30V"FUS9VED("(B"B)4:&4@
M;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O
M('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TU)344O341.+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E
M<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N
M=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T
M;V]D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W.`IM
M<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M
M<&]S92!P86=E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z,3(S,0IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I
M<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+G!H<#HR.#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B
M92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI
M;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]D96(N<&AP.C,R(&QI8B](;W)D92]-24U%+U9I97=E<B]E
M;G-C<FEP="YP:'`Z,S4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS<&]W
M97)P;VEN="YP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS=V]R
M9"YP:'`Z,S(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T
M>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E
M(&]N;'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP
M:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@
M:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B4V5R=V5R(%PB)7-<(B!Z;W-T
M8;,@=7-U;FGJ='DN(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S
M(&)E96X@<V%V960N(@IM<V=S='(@(E-E<G=E<B!<(B5S7"(@>F]S=&&S('IA
M<&ES86YY+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@
M8F5E;B!R96UO=F5D+B(*;7-G<W1R(")+;VYT;R!<(B5S7"(@>F]S=&&S;R!Z
M87!I<V%N92XB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HR.3`*
M(RP@9G5Z>GD*;7-G:60@(E1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X
M:7-T+B(*;7-G<W1R(")/:W)EMFQO;GD@<&QI:R!N:64@:7-T;FEE:F4N(@H*
M(SH@;&EB+U9&4R]S<6PN<&AP.C$P.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES
M="XB"FUS9W-T<B`B3VMR9;9L;VYY('!L:6L@;FEE(&ES=&YI96IE+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]$871A+G!H<#HS,#<*;7-G:60@(E1H92!U<&QO
M861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1&%T82]C<W8N<&AP.C(T,"!L:6(O
M2&]R9&4O1&%T82]T<W8N<&AP.C$W,@HC+"!F=7IZ>0IM<V=I9"`B5&AE('5P
M;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R(")0;V1P
M:7,@;FEE(&UOOV4@8GGF('IA<W2Q<&EO;F$N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C0X(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ,#D*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R(")";&]K('=E871H97(N8V]M(&YI92!J97-T(&1O
M<W3J<&YY+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3<X"FUS9VED
M(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(DYI
M92!M82"_861N>6-H(&1O<W3J<&YY8V@@;W!C:FDN(@H*(SH@;&EB+TAO<F1E
M+TU)344O0V]N=&5N=',N<&AP.C,T,0HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@
M87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM
M<V=S='(@(DYI92!M82"_861N>6-H(&%L=&5R;F%T>7=N>6-H(&-ZZK9C:2P@
M:W3S<F4@;6]GLWEB>2!Z;W-T8>8@<&]K87IA;F4N(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$T,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@
M87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA
M=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L
M97-S('1H86X@)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M
M:6XO=7-E<BYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM
M<V=S='(@(E=Y<W2Q<&FS('!R;V)L96T@<')Z>2!D;V1A=V%N:74@7"(E<UPB
M(&1O('-Y<W1E;74Z("5S(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@
M9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T
M<B`B(@HB5WES=+%P:;,@<')O8FQE;2!P<GIY('5S=7=A;FEU(&1A;GEC:"!D
M;&$@=;]Y=&MO=VYI:V$@7"(E<UPB('<@<WES=&5M:64Z("(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*
M;7-G<W1R(")7>7-TL7!ILR!P<F]B;&5M('!R>GD@=7-U=V%N:74@7"(E<UPB
M('H@<WES=&5M=2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S
M7"(Z("5S(@IM<V=S='(@(E=Y<W2Q<&FS('!R;V)L96T@<')Z>2!U86MT=6%L
M;FEA;FEU(%PB)7-<(CH@)7,B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z
M.#@X"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.C@Y,PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE
M(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI
M;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.#DU"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO
M860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE
M<W-A9V4@<&%R="(*;7-G<W1R(")7>7-TL7!ILR!BL[%D('!O9&-Z87,@=WFV
M=VEE=&QA;FEA('1E:B!C>NJV8VD@=VEA9&]M;[9C:2(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R(")7
M>7-TL7!ILR!BL[%D('!O8WIA<R!I;7!O<G1O=V%N:6$@9&%N>6-H(&E#86QE
M;F1A<BXB"@HC.B!L:6(O2&]R9&4O1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T
M82XB"FUS9W-T<B`B5WES=+%P:;,@8K.Q9"!P;V-Z87,@:6UP;W)T;W=A;FEA
M(&1A;GEC:"!I0V%L96YD87(N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HW.0HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN
M('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T
M(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(E=Y<W2Q<&FS(&*SL60@
M<&]D8WIA<R!A:W1U86QI>F%C:FD@=&5G;R!W<&ES=3H@)7,B"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"B,L(&9U>GIY"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF
M:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I
M;B!L871E<BXB"FUS9W-T<B`B5WES=+%P:;,@8K.Q9"!P;V1C>F%S(&%K='5A
M;&EZ86-J:2!T96=O('=P:7-U.B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#`*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A
M<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A
M<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R(")7>7-TL7!ILR!BL[%D('!O
M9&-Z87,@86MT=6%L:7IA8VII('1E9V\@=W!I<W4Z("5S(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC+"!F=7IZ>0IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I
M;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B5WES
M=+%P:;,@8K.Q9"!P;V1C>F%S(&%K='5A;&EZ86-J:2!T96=O('=P:7-U.B`E
M<R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*(RP@
M9G5Z>GD*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R
M="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(E1E;B!S97)W97(@;FEE(&]B
M<[-U9W5J92!U9&]S=.IP;FEA;FEA(&9O;&1E<O-W+B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R(")0
M;&EK(&YI92!W>6=LL61A(&YA('!O<')A=VYE(&%R8VAI=W5M(%)!4BXB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI
M<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS
M9W-T<B`B4&QI:R!N:64@=WEG;+%D82!N82!P;W!R87=N92!A<F-H:7=U;2!:
M25`N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q-#0*(RP@9G5Z>GD*;7-G
M:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M
M8F5R+B(*;7-G<W1R(")F;VQD97(@)7,@;FEE(&IE<W0@<')A=VEDLV]W>2XB
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I
M9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN
M8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B
M(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&QI
M8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*
M(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!3
M3510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N
M;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@
M86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y
M,"YI="DN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY-S@@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$P-3<@;&EB+TAO<F1E+T9O<FTN<&AP.C$P
M.#8*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,34@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Q.#(@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-38*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$S,#4@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,#`@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$U-3D*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-#`@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-3D@;&EB+TAO<F1E+T9O<FTN<&AP.C(P
M,#8*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,S`@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(P-SD@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q-3`*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(R,C(@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,#D@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(T-3,*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-38@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(X,C<@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q
M,S8*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,W,C,@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,W,S$*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S
M='(@(E1O('!O;&4@:F5S="!W>6UA9V%N92XB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&EN=&5G97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C0Q-PIM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E
M<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,3(S"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O
M<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3@Y"FUS9VED(")4:&ES(&9I96QD
M(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(E1O('!O;&4@;75S
M:2!B>>8@<&]P<F%W;K$@;&EC>F*Q+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR.#,U"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O
M;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B
M"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E
M<W-E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC
M.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O
M('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C
M;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O
M<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE
M87-E('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+T-O
M;G1E;G1S+G!H<#HU.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S
M86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R
M('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(E=I861O;6^VYB!Z;W-T8;-A(&YA
M<&ES86YA('<@:6YN96H@;FF_('1W;VIA('-T<F]N:64@:V]D;W=E:B`H)7,I
M+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3(V"B,L(&9U>GIY"FUS
M9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T
M<B`B375S:7-Z('=P<F]W861Z:>8@<')Z>6YA:FUN:65J(&IE9&YE9V\@861R
M97-A=&$N(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS
M9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII
M<"!F:6QE<RXB"FUS9W-T<B`B5&5N('-E<G=E<B!N:64@<&]T<F%F:2!R;WIP
M86MO=WEW8>8@87)C:&EW\W<@>FEP(&D@9WII<"XB"@HC.B!L:6(O2&]R9&4O
M4F5G:7-T<GDN<&AP.C$T-PHC+"!F=7IZ>0IM<V=I9"`B5&AI<R!S>7-T96T@
M:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R(")3:W)Y<'0@9&5A
M:W1Y=V]W86YY('!O<')A=VYI92XB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN
M<&AP.C$R-`HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@
M;G5M8F5R+B(*;7-G<W1R(")-=7-I<WH@=W!R;W=A9'IIYB!L:6-Z8NHN(@H*
M(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0HC+"!F=7IZ
M>0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/
M<'1I;VYS('=I;F1O=R(*;7-G<W1R(")4;R!O:VYO(&UU<VD@>F]S=&'F('=Y
M=V^S86YE('!R>F5Z(&]K;F\@:V]M<&]Z>71O<F$@=VEA9&]M;[9C:2XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`HC+"!F
M=7IZ>0IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R(").861A=V-A(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R,@IM<V=I9"`B5&EC:V5T<R(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0R-PIM<V=I9"`B5&EM
M92(*;7-G<W1R(")#>F%S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,P.`IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@
M(D9O<FUA="!C>F%S=2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3,X"B,L
M(&9U>GIY"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R(")3:V%S=6H@
M=WEB<F%NL2!T;[]S86UOMN8B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C,P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HR,"!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(R.0IM<V=I9"`B5&ET;&4B"FUS9W-T
M<B`B5'ET=;,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED
M(")4;R(*;7-G<W1R(")$;R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HV,C8*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I
M=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H
M36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*(D%B>2!W
M>6)R8>8@=VEE;&]K<F]T;F4@<&]L82!P<GIY=')Z>6UA:B!P<GIY8VES:R!#
M=')L("A00RD@;'5B($-O;6UA;F0@*$UA8RD@(@HB<&]D8WIA<R!K;&EK86YI
M82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDY"FUS9VED
M(")4;V1A>2(*;7-G<W1R(")$>FFV(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U
M<F-E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C,@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T<B`B5&]G;R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(R-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B5&]K96QA=2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#$*;7-G:60@(E1O;6]R<F]W(@IM
M<V=S='(@(DIU=')O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B5&]N9V$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S<*(RP@9G5Z>GD*;7-G:60@(E1O<"(*;7-G<W1R(")$;R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@
M(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS
M9W-T<B`B4')E>F5N=&%C:F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C,R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@5&]B
M86=O(@IM<V=S='(@(E1R>6YI9&%D(&D@5&]B86=O(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$W.3$*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B
M4')A=V1A(&QU8B!F8;-S>B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(R-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G
M:60@(E1U;FES:6$B"FUS9W-T<B`B5'5N97IJ82(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R
M.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME
M>2(*;7-G<W1R(")4=7)C:F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M,@IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B5'5R96-K
M:2`H25-/+3@X-3DM.2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N:7-T86XB"FUS9W-T
M<B`B5'5R:VUE;FES=&%N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)
M<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R(")4
M=79A;'4B"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@
M>6]U<B!C:&]I8V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C4W"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR-#D*;7-G:60@(E523"(*;7-G<W1R(")54DPB
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED
M(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY-PIM<V=I9"`B55),.B(*;7-G<W1R(")54DPZ(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(S-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I
M9"`B56=A;F1A(@IM<V=S='(@(E5G86YD82(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B
M"FUS9W-T<B`B56MR86EN82(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S,U"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN
M(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E
M;2!344PN(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I
M9"`B56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@
M<VEG;FEN9R!U<"XB"FUS9W-T<B`B(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,R
M-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG
M92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D*S
ML60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@
M;&EB+U9&4R]F:6QE+G!H<#HS,#@@;&EB+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(")"L[%D('!O
M9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B]6
M1E,O9G1P+G!H<#HV-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S('IM:6%N>2!D
M;R`E<RXB"@HC.B!L:6(O2&]R9&4O075T:"]S<6PN<&AP.C,W,0IM<V=I9"`B
M56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B0K.Q
M9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L
M:6(O5D93+V9T<"YP:'`Z-S4V"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@
M8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE
M;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP
M.C$U."!L:6(O5D93+V9I;&4N<&AP.C$V,R!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HQ.#@*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3DS(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C(P,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-O<'D@
M5D93(&9I;&4N(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@
M>B!S97)W97)E;2!344PN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,P,PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@
M9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE
M;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP
M.C(W-R!L:6(O5D93+VUU<W%L+G!H<#HR-3@@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z,C0X"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@
M>B!S97)W97)E;2!344PN(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3(T"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G
M<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,
M+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3DX"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R(")"L[%D
M('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI
M8B](;W)D92]#;VUP<F5S<R]T87(N<&AP.C<V(&QI8B](;W)D92]#;VUP<F5S
M<R]G>FEP+G!H<#HW.0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T
M82XB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(')O>G!A:V]W>7=A;FEA(&1A;GEC
M:"XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C,V"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C
M=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z
M96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HW.2!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4Y"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM
M<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!3
M44PN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR-30@;&EB+U9&4R]M=7-Q;"YP
M:'`Z,S$Q(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,R-@HC.B!L:6(O5D93+W-Q
M;"YP:'`Z,S$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G
M<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,
M+B(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,T,"!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HS-#0*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B0K.Q9"!P;V1C
M>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C(V,"!L:6(O5D93+VUU<W%L+G!H<#HS,C(@;&EB+U9&4R]M
M=7-Q;"YP:'`Z,S,U"B,Z(&QI8B]61E,O;75S<6PN<&AP.C,T,R!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HS,S8*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q
M8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+W-Q;"YP
M:'`Z,S,Y(&QI8B]61E,O<W%L+G!H<#HS-3$*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N
M(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E
M;2!344PN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C$W,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W
M97)E;2!344PN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,C8@;&EB+U9&4R]M
M=7-Q;"YP:'`Z,38W(&QI8B]61E,O;75S<6PN<&AP.C$X,`HC.B!L:6(O5D93
M+VUU<W%L+G!H<#HQ.#<@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S<P(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C,W.`HC.B!L:6(O5D93+W-Q;"YP:'`Z,C$P"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G
M<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,
M+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HS,C@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E
M<RXB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E
M<F5M(%-13"XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S(P"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*
M;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@
M4U%,+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C`S"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A
M:6QS(@IM<V=S='(@(E-Z8WIE9_.S>2!C97)T>69I:V%T=2(*"B,Z(&QI8B].
M970O24U34"YP:'`Z-#4Q(&QI8B].970O24U34"]!=71H+G!H<#HQ,3<*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D
M969I;FET:6]N(&]F("5S+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N
M:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z
M,3(Y(&QI8B]61E,O9FEL92YP:'`Z,3,T(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C$U.`HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-C,*(RP@9G5Z>GD*;7-G
M:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R(")"L[%D('!O
M9&-Z87,@>FUI86YY('5S=&%W:67Q+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW
M-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N
M:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z
M,C`U(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$R,B!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HQ,C4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N
M:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z
M-C<@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@
ML[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]T9WHN<&AP.C0U"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@
M=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(D*SL60@<&]D
M8WIA<R!Z;6EA;GD@=7-T87=I9?$N(@H*(SH@;&EB+TAO<F1E+U-E<W-I;VY(
M86YD;&5R+VYO;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@
M<F5A9"!F:6QE.B`B"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-I
MZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C4Y,@HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER
M96-T;W)Y+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@
M<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3`V-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S
M.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B
M(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C@U"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(D*S
ML60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@
M;&EB+U9&4R]S<6PN<&AP.C(U,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T
M<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB
M"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C@Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-1
M3"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C4S,R!L:6(O5D93+VUU<W%L+G!H
M<#HR,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(D*SL60@<&]D8WIA<R"S
ML6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,C$S(&QI8B]61E,O;75S<6PN<&AP.C0U,B!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HR-S<*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,CDS(&QI8B]6
M1E,O<W%L+G!H<#HR-#4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4N(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S
M:>H@>B!S97)W97)E;2!344PN(@H*(SH@;&EB+U9&4R])4T]7<FET97(O;6MI
M<V]F<RYP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK
M:7-O9G,G+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@
M<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<W=O
M<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R
M9"!D;V-U;65N="(*;7-G<W1R(").:64@;6^_;F$@<')Z972S=6UA8WIYYB!T
M96=O(&1O:W5M96YT=2!7;W)D+6$B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,3(R
M(&QI8B]61E,O9G1P+G!H<#HQ,C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(E5N86)L
M92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@
M(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HR,#D@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M,3,P(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$S-0HC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(D*SL60@
M<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`HC+"!F=7IZ
M>0IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(D]D='?S<GHB"@HC.B!T96UP
M;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS
M9W-T<B`B0V]F;FEJ('IM:6%N>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S,*(RP@9G5Z>GD*;7-G:60@(E5N9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(E=Z;O-W('-W;VJQ('-E<VKJ(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,R!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED(")5;F5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W."!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S
M+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-C0*(RP@9G5Z>GD*;7-G:60@(E5N9FEL
M960B"FUS9W-T<B`B<&QI:R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS
M"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N
M:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(EIJ961N;V-Z;VYE($5M:7)A
M='D@07)A8G-K:64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,X(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@
M(E=I96QK82!"<GET86YI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS
M9W-T<B`B55-!(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L
M>6EN9R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HV,2!L:6(O0FQO8VLO;65T87(N<&AP.C<Q"FUS9VED(")5
M;FET<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z
M+G!H<#HU."!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3@*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-#$Y"FUS9VED(")5;FMN;W=N(@IM<V=S='(@
M(DYI97IN86YE(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$
M*2XB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S
M86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$T-@HC+"!F=7IZ>0IM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P
M<F]V:61E9"XB"FUS9W-T<B`B3FEE>FYA;GD@861R97-A="(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"B,L(&9U>GIY"FUS9VED
M(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R(")0<F]S
M>NH@<&]D8>8@;F%Z=^H@=;]Y=&MO=VYI:V$@:2!H87.S;R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PHC
M+"!F=7IZ>0IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS
M9W-T<B`B57-U\2(*"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z,CDV"FUS
M9VED(")5;FYA;65D(@IM<V=S='(@(D)E>B!N87IW>2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N
M<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S
M=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@
M0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO
M<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T
M;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@HC+"!F
M=7IZ>0IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`B1&]M>;9L;GD@:V]L
M;W(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8X-B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.CDR-@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.CDS,@IM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S
M='(@(DYI96]B<[-U9VEW86YE(')O>G-Z97)Z96YI92(*"B,Z(&%D;6EN+W!E
M<FUS+V5D:70N<&AP.C$P-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$X,PHC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D
M871E(@IM<V=S='(@(E5A:W1U86QN:6HB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C,Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5<&1A=&4@)7,B"FUS9W-T<B`B1&]D86H@=;]Y=&MO=VYI:V$B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,L(&9U>GIY"FUS
M9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R(")$;V1A:B!UOWET:V]W;FEK82(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3,W(&%D;6EN+W!E<FUS+V5D:70N<&AP
M.C(Q-R!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`B1&]D
M86H@=;]Y=&MO=VYI:V$B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX
M,0HC+"!F=7IZ>0IM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS
M9W-T<B`B3FEE('=Y9V5N97)O=V%N;R"_861N96=O('-K<GEP='4N(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,2!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3@R"FUS9VED(")5<&QO860B"FUS9W-T<B`B6F&S
M861U:B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#D*;7-G:60@(E5P
M;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R
M=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L
M971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*(RP@9G5Z>GD*;7-G:60@(E5P
M<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B1W)U9'II9?$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C0Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED
M(")5<G5G=6%Y(@IM<V=S='(@(E5R=6=W86HB"@HC.B!L:6(O2&]R9&4O4')E
M9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(E5S=?$@;V)E8VYE
M(&ML=6-Z92(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$R-`IM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@
M9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+U)E9VES=')Y+G!H<#HV,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PHC+"!F=7IZ>0IM<V=I9"`B57-E<B!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A8VIA('6_>71K;W=N
M:6OS=R!(;W)D92(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,C4Q"FUS
M9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B3W!C:F4@=;]Y=&MO=VYI:V$B
M"@HC.B!S:6=N=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*
M;7-G<W1R(")296IE<W1R86-J82!UOWET:V]W;FEK82(*"B,Z('-I9VYU<"YP
M:'`Z,C(*(RP@9G5Z>GD*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B
M965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(D]B<[-U9V$@
M9FEL='+S=R!J97-T('=YL[%C>F]N82!N82!T>6T@<WES=&5M:64N(@H*(SH@
M861M:6XO<&5R;7,O961I="YP:'`Z,3<R(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,C0V"B,L(&9U>GIY"FUS9VED(")5<V5R('!E<FUI<W-I;VYS(@IM<V=S
M='(@(D1O;7FV;&YE('5P<F%W;FEE;FEA(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3,V(&QI8B].970O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z.3@*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HQ.3@@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV."!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B3F%Z
M=V$@=;]Y=&MO=VYI:V$B"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP
M.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR
M96%D>2!E>&ES=',N(@IM<V=S='(@(E6_>71K;W=N:6L@;R!N87IW:64@7"(E
M<UPB(&IUOR!I<W1N:65J92XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(").87IW82!UOWET
M:V]W;FEK83HB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS
M9VED(")5<V5R;F%M93H@(@IM<V=S='(@(DYA>G=A('6_>71K;W=N:6MA.B`B
M"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(Q.0HC+"!F=7IZ>0IM<V=I
M9"`B57-E<G,B"FUS9W-T<B`B3F%Z=V$@=;]Y=&MO=VYI:V$B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T
M:&4@<WES=&5M.B(*;7-G<W1R(")5OWET:V]W;FEC>2!W('-Y<W1E;6EE.B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(S.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B57IB96MI<W1A;B(*"B,Z
M(&QI8B]61E,O9FEL92YP:'`Z,3`Q(&QI8B]61E,O9FEL92YP:'`Z,3@X"B,L
M(&9U>GIY"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*
M;7-G<W1R(")/:W)EMFQO;GD@<&QI:R!N:64@:7-T;FEE:F4N(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C871I;VXB"FUS
M9W-T<B`B5V%K86-J92(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX-C8*;7-G
M:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,S@*;7-G:60@(E9A
M;&ED:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU.3<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX-38@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T
M:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,C0U(&QI8B](;W)D92]&;W)M+G!H<#HR,C8W(&QI
M8B](;W)D92]&;W)M+G!H<#HR,S$U"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M.3(W"B,L(&9U>GIY"FUS9VED(")686QU97,B"FUS9W-T<B`B57=A9VDB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Q,"!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C$X-PIM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B5F%N=6%T=2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S(*(RP@9G5Z>GD*;7-G:60@(E9A
M<FEA8FQE(@IM<V=S='(@(E=YL[%C>F]N92(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L
M82(*;7-G<W1R(")796YE>G5E;&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@
M;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")6
M97)S:6]N(@IM<V=S='(@(E=E<G-J82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR,#4*(RP@9G5Z>GD*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*
M;7-G<W1R(")?57!R87=N:65N:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"B,L(&9U>GIY"FUS9VED(")6
M97)T:6-A;"!A;&EG;B(*;7-G<W1R(")4>6QK;R!T96MS="(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*(RP@9G5Z>GD*
M;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B5'EL:V\@=&5K<W0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S
M"B,L(&9U>GIY"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B5'EL:V\@=&5K
M<W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW
M,`HC+"!F=7IZ>0IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(E=Y<V]K:2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,38*;7-G:60@(E9I970@3F%M(@IM<V=S='(@(E=I971N86TB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)
M*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z
M.34Y"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B5VED
M;VL@)7,B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W
M(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(E!O:V&_('-T<F]NZB!7
M5U<B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#$X"B,L('!H
M<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B4&]K8;\@:F%K
M;R`E<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#8@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S
M='(@(D)R>71Y:G-K:64@5WES<'D@1'II97=I8WIE(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(T-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER
M9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B5WES<'D@1'II97=I8WIE(%-T
M86[S=R!::F5D;F]C>F]N>6-H(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,#D*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(U,0IM<V=I9"`B5FES:6)I;&ET>3H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'
M(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B5V%L;&ES
M(&D@1G5T=6YA(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]S=&%T=7,N<&AP.C(Y"FUS9VED(")787)N:6YG(@IM<V=S='(@(D]S=')Z
M9;]E;FEE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHU.`HC+"!F=7IZ>0IM<V=I9"`B5V4B"FUS9W-T<B`B5U=7(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R
M($9O<F5C87-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HT,34*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DR"FUS9VED(")7
M96%T:&5R+F-O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H
M<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(E=75R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-S8*(RP@9G5Z>GD*;7-G:60@(E=E8B!3:71E(@IM
M<V=S='(@(E523"!S=')O;GDB"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N
M<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B0V\@='ED>FEE\2(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC;VUE
M(@IM<V=S='(@(E=I=&%M>2(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(E=I=&%M>2!W("5S
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S
M+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O
M;64L("5S(@IM<V=S='(@(E=I=&%M>2P@)7,B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y-0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T
M<B`B6F%C:&]D;FD@*$E33RTX.#4Y+3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.38*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R
M("):86-H;V1N:2`H25-/+3@X-3DM,34I(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C<X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H
M87)A(@IM<V=S='(@(E-A:&%R82!:86-H;V1N:6$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#(Y"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P
M;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S
M='(@(DIA:[$@87!L:6MA8VKJ(&UA("5S('=YMG=I971L8>8@<&\@>F%L;V=O
M=V%N:74@<VGJ/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q
M"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-`IM<V=I
M9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"FUS9VED
M(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E
M9&ET;W(N(@IM<V=S='(@(DIA:VEE('=T>6-Z:VD@86MT>7=O=V'F('<@4F]Z
M8G5D;W=A;GEM(&5D>71O<GIE('1E:W-T=2XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"B,L(&9U>GIY"FUS
M9VED(")7:61T:"(*;7-G<W1R(")/<W1R>F6_96YI92(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HS,3(T"B,L(&9U>GIY"FUS9VED(")7:61T:"!I;B!#4U,@
M=6YI=',B"FUS9W-T<B`B3&ET=V$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S0Y"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M
M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI
M.B(*;7-G<W1R("(B"B)3>F5R;VMOMN8@;&5W96=O(&UE;G4@)7,@*'IM:6%N
M82!Z86-Z;FEE(&]B;W=IL7IY=V'F('!R>GD@;F%S=.IP;GEM("(*(FQO9V]W
M86YI=2DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M,`HC+"!F=7IZ>0IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("),:71W82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U
M"B,L(&9U>GIY"FUS9VED(")7:61T:#HB"FUS9W-T<B`B3W-T<GIEOV5N:64B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8X"FUS9VED(")7:6MI
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.#@@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*(RP@
M9G5Z>GD*;7-G:60@(E=I;F0B"FUS9W-T<B`B3W-T<GIEOV5N:64B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@HC+"!F=7IZ
M>0IM<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R(")/<W1R>F6_96YI92(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@:6X@
M:VYO=',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-38*
M(RP@9G5Z>GD*;7-G:60@(E=I;F0Z(@IM<V=S='(@(D]S=')Z9;]E;FEE(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,`HC+"!F=7IZ>0IM
M<V=I9"`B5VEN9#H@(@IM<V=S='(@(D]S=')Z9;]E;FEE(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X,@HC+"!F=7IZ>0IM<V=I
M9"`B5VES:&QI<W1S(@IM<V=S='(@(D)I8;-A(&QI<W1A(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8U"B,L(&9U>GIY"FUS9VED(")7;W)K(@IM<V=S
M='(@(FQU8B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3(T(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED
M(")7;W)K($%D9')E<W,B"FUS9W-T<B`B061R97,@9&\@<')A8WDB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R
M:R!0:&]N92(*;7-G<W1R(")496PN(&1O('!R86-Y(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(S,0IM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV
M,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME
M>2!5<V%G92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4Y-`IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M
M92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y
M-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.#(*;7-G:60@
M(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R(")24B(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HS.#8@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0R-PIM<V=I9"`B65E962(*;7-G<W1R(")2
M4E)2(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M,#$*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(D-O
M(')O:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(DIE;65N(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@X-0IM<V=I9"`B665S
M(@IM<V=S='(@(E1A:R(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]A9W)E
M96UE;G1?8F]T=&]M+FEN8SHV"FUS9VED(")997,L($D@06=R964B"FUS9W-T
M<B`B5&%K+"!Z9V%D>F%M('-IZB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-
M3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!7
M65-)5UE'+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4N<&AP.C$R.3<*;7-G
M:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")9;W4@8V%N(&YO
M="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-38@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$Y-S8*(RP@9G5Z>GD*;7-G:60@(EEO=2!D:60@;F]T
M(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`B5'?S:B!A
M9')E<R!E+6UA:6PZ(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C(W,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S
M(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@
M9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T
M:"YP:'`Z.3(S"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM
M<V=S='(@(E=Y;&]G;W=ALV6V('-IZBXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C
M96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L
M("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3@X"B,L(&9U
M>GIY"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*
M;7-G<W1R(")4=_-J(&%D<F5S(&4M;6%I;#HB"@HC.B!L:6(O2&]R9&4O075T
M:"]3:6=N=7`N<&AP.C,W"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!C;VYF
M:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G
M<W1R(")"<F%K(&MO;F9I9W5R86-J:2!W97=NZG1R>FYE:B!D;&$@=&5G;R!H
M;W-T82(*"B,Z(&QI8B](;W)D92YP:'`Z-#,Q"B,L(&9U>GIY"FUS9VED(")9
M;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B0G)A
M:R!K;VYF:6=U<F%C:FD@=V5W;NIT<GIN96H@9&QA('1E9V\@:&]S=&$B"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U
M(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N
M9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(DUU<VES>B!O<&ES8>8@
M<')O8FQE;2!Z86YI;2!G;R!W>;9L97-Z+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*(RP@9G5Z>GD*;7-G:60@(EEO
M=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T
M;R(*;7-G<W1R(")-=7-I<WH@=W!R;W=A9'IIYB!P<GIY;F%J;6YI96H@:F5D
M;F5G;R!A9')E<V%T82XB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H
M<#HX,`HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E
M<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R(")-=7-I<WH@;VMR9;9L:>8@=;]Y
M=&MO=VYI:V$L(&MT\W)E9V\@8VAC97-Z('5S=6ZQYBXB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,3D*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@
M82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(DUU<VES>B!O:W)E
MMFQIYB!UOWET:V]W;FEK82P@:W3S<F5G;R!C:&-E<WH@=7-U;K'F+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A
M('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B375S:7-Z(&]K<F6V;&GF
M('6_>71K;W=N:6MA+"!K=/-R96=O(&-H8V5S>B!U<W5NL>8N(@H*(SH@861M
M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A
M9&0N(@IM<V=S='(@(DUU<VES>B!O:W)EMFQIYB!UOWET:V]W;FEK82P@:W3S
M<F5G;R!C:&-E<WH@9&]D8>8N(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"B,L
M(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!U<&1A=&4N(@IM<V=S='(@(DUU<VES>B!O:W)EMFQIYB!UOWET:V]W;FEK
M82P@:W3S<F5G;R!C:&-E<WH@9&]D8>8N(@H*(SH@;&EB+TAO<F1E+T-O;7!R
M97-S+WII<"YP:'`Z,3,X"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(DUU<VES>B!O
M:W)EMFQIYB!UOWET:V]W;FEK82P@:W3S<F5G;R!C:&-E<WH@=7-U;K'F+B(*
M"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<R"B,L
M(&9U>GIY"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA
M;64N(@IM<V=S='(@(DUU<VES>B!O:W)EMFQIYB!UOWET:V]W;FEK82P@:W3S
M<F5G;R!C:&-E<WH@=7-U;K'F+B(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE
M:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@
M86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T%U=&@N<&AP.CDQ,0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S
M('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*
M;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R(")4=_-J(&%D<F5S
M(&4M;6%I;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#0*;7-G:60@
M(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B5'?S:B!A9')E<R!/9#HB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(EEO=7(@26YF;W)M871I;VXB"FUS
M9W-T<B`B5'=O:F4@:6YF;W)M86-J92(*"B,Z(&QI8B](;W)D92]!=71H+G!H
M<#HY,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!
M9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U
M<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO
M=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)4=_-J(&%D<F5S(&EN
M=&5R;F5T;W=Y('-IZB!Z;6EE;FFS(&]D('!O8WJQ=&MU('-E<VII("5S+B!7
M('IW:;%Z:W4@>B`B"B)B97IP:65C>F7Q<W1W96T@5'=O:F5G;R!K;VYT82!M
M=7-I<WH@>F%L;V=O=V'F('-IZB!P;VYO=VYI92XB"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.86UE(@IM<V=S
M='(@(E1W;VIE(&EM:>HB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D
M9"YI;F,Z.0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD
M(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+"!O<B!T:&4@9F5A='5R
M92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN
M(@IM<V=S='(@(B(*(E1E;B!S>7-T96T@875T96YT>6MA8VII(&YI92!O8G.S
M=6=U:F4@9&]D87=A;FEA('6_>71K;W=N:6OS=RP@;'5B('1A(&]P8VIA("(*
M(GIO<W1ALV$@=WFSL6-Z;VYA+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VYO;&ES="YI;F,Z.0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B
M86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE
M(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@
M<F5A<V]N+B(*;7-G<W1R("(B"B)496X@<WES=&5M(&%U=&5N='EK86-J:2!N
M:64@;V)SLW5G=6IE(&QI<W1O=V%N:6$@=;]Y=&MO=VYI:_-W+"!L=6(@=&$@
M;W!C:F$@(@HB>F]S=&&S82!W>;.Q8WIO;F$N(@H*(SH@;&EB+TAO<F1E+T%U
M=&@N<&AP.CDQ.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U
M<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B
M96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO
M=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B
M"B)4=_-J(&%D<F5S(&EN=&5R;F5T;W=Y('-IZB!Z;6EE;FFS(&]D('!O8WJQ
M=&MU('-E<VII("5S+B!7('IW:;%Z:W4@>B`B"B)B97IP:65C>F7Q<W1W96T@
M5'=O:F5G;R!K;VYT82!M=7-I<WH@>F%L;V=O=V'F('-IZB!P;VYO=VYI92XB
M"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B
M66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*
M;7-G<W1R("(B"B)4=V]J82!P<GIE9VRQ9&%R:V$@;FEE(&]B<[-U9W5J92!W
M>;9W:65T;&%N:6$@<&QI:_-W(&=R869I8WIN>6-H('1E9V\@='EP=2XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@HC+"!F=7IZ>0IM
M<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P
M<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@
M<')I;G0N(@IM<V=S='(@(B(*(E1W;VIA('!R>F5G;+%D87)K82!N:64@;V)S
MLW5G=6IE('1E:B!O<&-J:2!D<G5K;W=A;FEA+B!.86IC:;9N:6H@0W1R;"]/
M<&-J82`B"B(K(%`@86)Y('=Y9')U:V]W8>8N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(T.0IM<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB
M"FUS9W-T<B`B5'=O:F$@;V)E8VYA('-T<F5F82!C>F%S;W=A.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3`*;7-G:60@(EEO=7(@9&5F875L="!I
M9&5N=&ET>3HB"FUS9W-T<B`B1&]M>;9L;F$@=&^_<V%M;[;F.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3,*;7-G:60@(EEO=7(@9G5L;"!N86UE
M.B(*;7-G<W1R(")4=V]J92!P9;-N92!I;6GJ(&D@;F%Z=VES:V\Z(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R
M(")4=V]I;2!N;W=Y;2!H87.S96T@=R`E<R!J97-T.B`E<R(*"B,Z(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V
M92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I
M;VXN(@IM<V=S='(@(E1W;VIE('5S=&%W:65N:6$@>F]S=&&S>2!U86MT=6%L
M;FEO;F4@;F$@8WIA<R!T<G=A;FEA('1E:B!S97-J:2XB"@HC.B!L:6(O2&]R
M9&4O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@
M8F5E;B!U<&1A=&5D+B(*;7-G<W1R(")4=V]J92!U<W1A=VEE;FEA('IO<W1A
MLWD@=6%K='5A;&YI;VYE+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C<U"B,L(&9U>GIY"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N
M(')E<V5T(@IM<V=S='(@(E1W;VEM(&YO=WEM(&AA<[-E;2!W("5S(&IE<W0Z
M("5S(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@
M(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@
M96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*
M;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(E1W;VIE('ID
M86QN92!S97)W97)Y.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-30@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA
M(@IM<V=S='(@(DIU9V]SLV%W:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(EIA:7(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C4V(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR-#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED
M("):86UB:6$B"FUS9W-T<B`B6F%M8FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(U-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B
M"FUS9W-T<B`B6FEM8F%B=V4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]497AT
M+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O
M=&5D(%1E>'1=(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP
M.C4V"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EM287!O<G0@
M;R!P<F]B;&5M:65=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5"
M;&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E
M<RYP:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!4
M97AT("T@)7,@;&EN97-=(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92YP:'`Z
M,3DS"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E
M<UTB"FUS9W-T<B`B)7,@9&\@)7,@>B`E<R(*"B,Z(&QI8B](;W)D92YP:'`Z
M,30T,2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B7T%D;6EN:7-T<F%C:F$B"@HC.B!L:6(O
M87!I+G!H<#HQ,S8*;7-G:60@(E]#3$DB"FUS9W-T<B`B7T-,22(*"B,Z(&QI
M8B]A<&DN<&AP.C$R-`HC+"!F=7IZ>0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S
M='(@(D1A=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@
M(E]5<W7Q('=I97)S>B(*"B,Z(&QI8B]A<&DN<&AP.C$Q-@IM<V=I9"`B7T=R
M;W5P<R(*;7-G<W1R(")?1W)U<'DB"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z
M,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R(")?4&]M;V,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*(RP@
M9G5Z>GD*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E1E
M;"X@:V]M+B(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ.30*;7-G:60@(E],
M;V<@:6XB"FUS9W-T<B`B7UIA;&]G=6HB"@HC.B!L:6(O2&]R9&4O365N=2YP
M:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*;7-G<W1R(")?5WEL;V=U:B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(EIM:67Q(&QI
M;FLN+BXB"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T
M:6]N<R(*;7-G<W1R(")?3W!C:F4B"@HC.B!L:6(O87!I+G!H<#HQ,C`*;7-G
M:60@(E]097)M:7-S:6]N<R(*;7-G<W1R(")?57!R87=N:65N:6$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C8*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R(")5<W7Q(&QI;FLN
M+BXB"@HC.B!L:6(O87!I+G!H<#HQ,#@*;7-G:60@(E]3971U<"(*;7-G<W1R
M(")?2V]N9FEG=7)A8VIA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"B,L(&9U>GIY"FUS9VED(")?5&%B
M;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")496PN(&MO;2XB"@HC.B!L:6(O
M87!I+G!H<#HQ,3(*;7-G:60@(E]5<V5R<R(*;7-G<W1R(")?5;]Y=&MO=VYI
M8WDB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C@Y,`IM<V=I9"`B861D<F5S
M<R!B;V]K(@IM<V=S='(@(FMS:;&_:V$@861R97-O=V$B"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.C@X,@IM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B:V%L
M96YD87)Z(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z-3@Y"FUS
M9VED(")C;&EC:R!H97)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")F86QL:6YG(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX-3D*;7-G:60@(F9I
M;&4B"FUS9W-T<B`B<&QI:R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<T
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S8P(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H
M)7,I(&%T("5S("5S(@IM<V=S='(@(B5S(&1O("5S('H@)7,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,X"B,L(&9U>GIY"FUS9VED(")G
M=7-T:6YG(@IM<V=S='(@(E-I97)P:67Q(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(S,@IM<V=I9"`B:#HB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,S,0IM<V=I
M9"`B:&@B"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4V-2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R
M,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"B,L(&9U>GIY
M"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B3F%GL_-W:VDB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PHC+"!F=7IZ>0IM<V=I
M9"`B;&EN97-=(@IM<V=S='(@(DYA9[/S=VMI(@H*(SH@;&EB+U9&4R])4T]7
M<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI
M<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS-#(*
M;7-G:60@(FUM(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP
M:'`Z,C@X('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,#4*;7-G:60@
M(FYA;64B"FUS9W-T<B`B3F%Z=VES:V\B"@HC.B!L:6(O2&]R9&4O4E!#+G!H
M<#HQ,C$*(RP@9G5Z>GD*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R
M(")5:V_Q8WIO;F4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R
M,3D*(RP@9G5Z>GD*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T
M<B`B5&$@;W!C:F$@;FEE(&IE<W0@:F5S>F-Z92!Z8;.Q8WIO;F$N(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HX-S0*;7-G:60@(FYO=&5P860B"FUS9W-T
M<B`B;F]T871N:6LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@X"B,L(&9U>GIY"FUS9VED(")P97)C96YT(@IM
M<V=S='(@(D1R=6MU:B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PHC
M+"!F=7IZ>0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(D]R9V%N:7IA=&]R(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HY.`IM<V=I9"`B<VAO=R!D:69F
M97)E;F-E<R(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U
M.`IM<V=I9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(G-T96%D>2(*
M;7-G<W1R(").;W1A=&YI:R`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M.#DX"B,L(&9U>GIY"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B0WIA<FYA
M(&QI<W1A(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@;&EB+TAO<F1E+T%U=&@O
M4VEG;G5P+G!H<#HR-CD*(RP@9G5Z>GD*;7-G:60@(G1Y<&4@=&AE('!A<W-W
M;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B2&%SLV\B"@HC.B!A9&UI
M;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0HC
M+"!F=7IZ>0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R(")P;&EK(@H*(SH@;&EB
M+TAO<F1E+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T
M<B`B8F5Z(&YA>G=Y(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4V-2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PHC
M+"!F=7IZ>0IM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B5WEB\W(@:V]L
M;W)U(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM
M<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(T"B,L(&9U>GIY"FUS9VED(")W.B(*
M;7-G<W1R(")&=V0Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(B(*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&\O<'1?0E(N<&\`````````````````````
M````````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#<S,S<S-0`Q,#4Q-30S
M,S<U-``P,3<V-C4`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(R!T<F%N<VQA=&EO;B!O9B!H;W)D92YP;R!T;R!"<F%Z:6QI
M86X@4&]R='5G=65S90HC($-O<'ER:6=H="`H0RD@645!4B!(;W)D92!0<F]J
M96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE
M(&QI8V5N<V4@87,@=&AE($AO<F1E('!A8VMA9V4N"B,*(R!&86)I;R!';VUE
M<R`\9FQG;VUS0'5O;"YC;VTN8G(^+"`R,#`V+@IM<V=I9"`B(@IM<V=S='(@
M(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&5<;B(*(E)E<&]R="U-<V=I
M9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I
M;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO
M;BU$871E.B`R,#`V+3`R+3$U(#$V.C4P+3`R,#!<;B(*(DQA<W0M5')A;G-L
M871O<CH@1F%B:6\@1V]M97,@/&9L9V]M<T!U;VPN8V]M+F)R/EQN(@HB3&%N
M9W5A9V4M5&5A;3H@0G)A>FEL:6%N(%!O<G1U9W5E<V4@/&DQ.&Y`;&ES=',N
M:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M
M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ7&XB"B)#;VYT
M96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"B)8+4=E;F5R871O<CH@
M2T)A8F5L(#$N,RXQ7&XB"B)0;'5R86PM1F]R;7,Z("!N<&QU<F%L<STR.R!P
M;'5R86P]*&X@/B`Q*3M<;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS
M9W-T<B`B("@E<R!D:6%S(&%T<N%S*2(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3,W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME
M>2`E<RDB"FUS9W-T<B`B("A496-L82!D92!!=&%L:&\@)7,I(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,X,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B`H96T@)7,@9&EA<RDB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<W"FUS9VED("(@*'1O9&%Y*2(*
M;7-G<W1R("(@*&AO:F4I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,W.0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B("AA;6%N:.,I(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-0IM<V=I9"`B("AY97-T
M97)D87DI(@IM<V=S='(@(B`H;VYT96TI(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(T-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S4P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.38*;7-G:60@
M(B!A="`B"FUS9W-T<B`B(&$@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B7"(E<UPB($[C;R#I('5M(&1I<F5T\W)I
M;RXB"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S
M='(@(B<E<R<@;N-O(.D@=6UA(&5S8V]L:&$@=N%L:61A+B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S$P"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`Y.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E
M(%)E9VES=')Y+B(*;7-G<W1R("(G)7,G(&[C;R!E<W3A(&-O;F9I9W5R861O
M(&YO(%)E9VES=')O(&1O($AO<F1E+B(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R
M964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R
M96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(G)E;F1E<FEZ861O<B!D92#A
M<G9O<F4@7"(E<UPB(&[C;R!E;F-O;G1R861O+B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E
M9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB(&9O:2!A
M9&EC:6]N861O(&%O('-I<W1E;6$@9&4@9W)U<&]S+B(*"B,Z(&%D;6EN+W!E
M<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S
M='(@(EPB)7-<(B!F;VD@861I8VEO;F%D;R!A;R!S:7-T96UA(&1E('!E<FUI
M<W/U97,N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A
M9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A
M<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(EPB)R5S7"(@;N-O(&9O:2!C
M<FEA9&\Z("5S+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E
M9"`H)2XR9B4E*2(*;7-G<W1R("(E+C)F34(@=7-A9&]S(&1E)2XR9DU"('!E
M<FUI=&ED;W,@*"4N,F8E)2DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C(V"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*
M;7-G<W1R("(E9"`E<R!E("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP
M:7)E<RXB"FUS9W-T<B`B)60@9&EA<R!A=.D@<W5A('-E;FAA(&5X<&ER87(N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B)60@<')E
M=FESXV\@9&\@9&EA(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S
M("T@079I<V\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C<P-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G
M<W1R("));7!R97-SXV\@1&EG:71A;"!D92`E<R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@T,"!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HX-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B
M"FUS9W-T<B`B)7,@2T(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R!/<&5R8>?U97,@9&4@
M36%N=71E;N?C;R`M($-O;F9I<FUAY^-O(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(D-O;F9I9W5R8>?C;R!D
M92`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R(")#861A
M<W1R;R!D92`E<R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS
M9W-T<B`B)7,@5&5R;6]S(&1O($%C;W)D;R(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z-#,R(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DT
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@R(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-S4P"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L
M<F5A9'D@97AI<W1S+B(*;7-G<W1R("(E<R!JX2!E>&ES=&4N(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#8*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-3(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B)7,@82`E<R`E<R(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O
M<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B;W@@9F]R
M(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES
M('1I;64N(@IM<V=S='(@(B(*(B5S(&5S=.$@<')O;G1O('!A<F$@97AE8W5T
M87(@87,@;W!E<F'G]65S(&1E(&UA;G5T96[GXV\@;6%R8V%D87,@86)A:7AO
M+B`B"B)-87)Q=64@82!C86EX82!P87)A('%U86QQ=65R(&]P97)AY^-O('%U
M92!V;V/J('%U96ER82!E>&5C=71A<B!D97-T82!V97HN(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,T-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!I<R!R97%U:7)E9"(*;7-G<W1R("(E<R#I(&]B<FEG873S<FEO(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@;6EN=71E<R(*;7-G<W1R("(E<R!M:6YU=&]S(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B5S(&[C;R!E;F-O;G1R
M861O+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B)7,@
M82`E<R!D92`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Q
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S
M='(@(D-A=.%L;V=O(&1E($5N9&5R9>=O<R!D92`E<R(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3$S"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M)W,@0V%L96YD87(B"FUS9W-T<B`B06=E;F1A(&1E("5S(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,G<R!.;W1E<&%D(@IM<V=S='(@(D%N;W1AY_5E<R!D92`E<R(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B3&ES=&$@9&4@5&%R969A<R!D
M92`E<R(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VAT;6PN<&AP.C$R,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L
M86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@
M:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R
M<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*(B5S.B!%<W1A(&UE;G-A
M9V5M('!O9&4@;N-O('-E<B!D92!Q=65M(&5L82!D:7H@<V5R+B!4;VUE(&-U
M:61A9&\@8V]M("(*(G%U86QQ=65R(&QI;FL@<')E<V5N=&4@;F5L82!O=2!E
M;2!F;W)N96-E<B!A;R!R96UE=&5N=&4@<75A;'%U97(@:6YF;W)M8>?C;R`B
M"B)P97-S;V%L+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M-30@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y.0IM<V=I9"`B+"!G
M=7-T:6YG("(*;7-G<W1R("(L(&)R:7-A("(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3DU(&QI8B]";&]C:R]M971A<BYP:'`Z,C`P"B,L('!H<"UF;W)M
M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(L(&)R:7-A("5S
M("5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(BP@
M=F%R:>%V96P@9&4@)7,@<&%R82`E<R(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,CDT(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,S0X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-S,@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$S,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-S0V"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T
M<B`B+2T@<V5L96-I;VYE("TM(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P
M"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R(")&;W)M871O(#$R($AO
M<F%S(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R
M($9O<FUA="(*;7-G<W1R(")&;W)M871O(#(T($AO<F%S(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@
M(C(T(&AO<F%S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM
M<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(CQ0X6=I;F$@06YT97)I;W(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R-@IM<V=I9"`B02!D871A8F%S92!B
M86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R(")5
M;2!C;VYE8W1O<B!D92!B86YC;R!D92!D861O<R#I(&]B<FEG873S<FEO('!A
M<F$@97-T92!B;&]C;RXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$V,@IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T
M<B`B56T@97)R;R!F871A;"!O8V]R<F5U(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES
M(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")5;6$@
M8VAA=F4@</IB;&EC82!01U`@Z2!O8G)I9V%T\W)I82!P87)A(&-R:7!T;V=R
M869A<B!U;6$@;65N<V%G96TN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3$V.`IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U
M:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@HB
M56UA(&-H879E('#Z8FQI8V$@4$=0(.D@;V)R:6=A=/-R:6$@<&%R82!V97)I
M9FEC87(@=6UA(&UE;G-A9V5M(&%S<VEN861A+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$P.3D*;7-G:60@(B(*(D$@<'5B;&EC(%!'
M4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B)5
M;6$@8VAA=F4@<')I=F%D82!01U`@92!U;6$@<V5N:&$@<^-O(&]B<FEG873S
M<FEA<R!P87)A(&1E<V-R:7!T;V=R869A<B!U;6$@(@HB;65N<V%G96TN(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Q-@IM<V=I9"`B
M(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM
M<V=S='(@(B(*(E5M82!C:&%V92!P<FEV861A(%!'4"!E('5M82!S96YH82!S
MXV\@;V)R:6=A=/-R:6%S('!A<F$@87-S:6YA<B!U;6$@;65N<V%G96TN(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#8*;7-G:60@
M(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M
M97-S86=E+B(*;7-G<W1R("(B"B)5;6$@8VAA=F4@</IB;&EC82!3+TU)344L
M('5M82!C:&%V92!P<FEV861A(%,O34E-12!E('5M82!S96YH82!SXV\@(@HB
M;V)R:6=A=/-R:6%S('!A<F$@9&5S8W)I<'1O9W)A9F%R('5M82!M96YS86=E
M;2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0S,0IM
M<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A
M(&UE<W-A9V4N(@IM<V=S='(@(B(*(E5M82!C:&%V92!P^F)L:6-A(%,O34E-
M12P@=6UA(&-H879E('!R:79A9&$@4R]-24U%(&4@=6UA('-E;FAA('/C;R`B
M"B)O8G)I9V%T\W)I87,@<&%R82!A<W-I;F%R('5M82!M96YS86=E;2XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B
M02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M
M97-S86=E+B(*;7-G<W1R(")5;6$@8VAA=F4@</IB;&EC82!3+TU)344@Z2!O
M8G)I9V%T\W)I82!P87)A(&-R:7!T;V=R869A<B!U;6$@;65N<V%G96TN(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I
M9"`B04T@0VQO=61S(@IM<V=S='(@(DYU=F5N<R!M871U=&EN87,B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B
M04T@3&EG:'0@4F%I;B(*;7-G<W1R(")#:'5V82!&<F%C82!697-P97)T:6YA
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*
M;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B0VAU=F$@;6%T=71I;F$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B
M04T@4VAO=V5R<R(*;7-G<W1R(")#:'5V87,@;6%T=71I;F%S(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-
M(%-N;W<@4VAO=V5R<R(*;7-G<W1R(").979A<V-A<R!-871U=&EN87,B"@HC
M.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS
M9W-T<B`B04TO4$TB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R(")!4$D@
M240B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R(")3;V)R92!E
M<W1E(&5D:71O<B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4S"FUS
M9VED(")!8F]U="XN+B(*;7-G<W1R(")3;V)R92XN+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O
M='1O;2(*;7-G<W1R(")!8G-B;W1T;VTB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS
M9W-T<B`B06)S;6ED9&QE(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R(")!8V5S<V\@;F5G861O(&%O(&-R:6%R(&1I<F5T
M\W)I;R!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$S
M-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS
M9W-T<B`B06-E<W-O(&YE9V%D;R!A;R!C<FEA<B!A<G%U:79O(%9&4RXB"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PIM<V=I9"`B06-C;W5N="!);F9O
M<FUA=&EO;B(*;7-G<W1R(")3=6%S($EN9F]R;6'G]65S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<X"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM
M<V=S='(@(E-E;FAA(&1A($-O;G1A(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R
M;WIE;BXB"FUS9W-T<B`B0V]N=&$@9&5S871I=F%D82XB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S,U"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S
M='(@(D-O;G1A<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,30X('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B061D(@IM<V=S
M='(@(D%D:6-I;VYA<B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D;6EN
M+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T
M<B`B061I8VEO;F%R($=R=7!O(%-U8F]R9&EN861O(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.CDY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R
M(")!9&EC:6]N87(@4&5R;6ES<_5E<R!3=6)O<F1I;F%D87,B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S
M='(@(D%D:6-I;VYE($%Q=6DZ(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@
M861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS
M9W-T<B`B061I8VEO;F%R($YO=F\@1W)U<&\B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R(")!9&EC
M:6]N87(@3F]V82!097)M:7-SXV\B"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V%D9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A
M(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R(")!9&EC:6]N87(@=6T@
M9W)U<&\@<W5B;W)D:6YA9&\@82`G)7,G(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@
M8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B061I8VEO;F%R
M('5M82!P97)M:7-SXV\@<W5B;W)D:6YA9&$@82`G)7,G(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R(")!
M9&EC:6]N87(@=6T@;F]V;R!U<W7A<FEO.B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HU-30*;7-G:60@(D%D9"!C;VQU;6XB
M"FUS9W-T<B`B061I8VEO;F%R(&-O;'5N82(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O961I="YI;F,Z,S0*;7-G:60@(D%D9"!N97<@;65M8F5R<R(*
M;7-G<W1R(")!9&EC:6]N87(@;F]V;W,@;65M8G)O<R(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@
M(D%D:6-I;VYA<B!P87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Q
M"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO
M>FEL;&$@4VED96)A<B(*;7-G<W1R(")!9&EC:6]N87(@;R!-96YU("5S(&-O
M;6\@=6UA($)A<G)A($QA=&5R86P@9&\@36]Z:6QL82(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0IM<V=I9"`B061D('1O
M(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B061I8VEO;F%R(&%O(&-A=.%L;V=O
M(&1E(&5N9&5R9>=O<SHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB
M"FUS9W-T<B`B061I8VEO;F%R(&%O(&UE=2!C873A;&]G;R!D92!E;F1E<F7G
M;W,B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D('5S97(B"FUS
M9W-T<B`B061I8VEO;F%R('5S=>%R:6\B"@HC.B!A9&UI;B]U<V5R+G!H<#HW
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE
M('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@
M:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B"B(G)7,G(&%D:6-I;VYA
M9&\@86\@<VES=&5M82P@;6%S(&[C;R!P=61E(&EN8VQU:7(@:6YF;W)M8>?U
M97,@861I8VEO;F%I<R!D;R`B"B)C861A<W1R;SH@)7,N(@H*(SH@<VEG;G5P
M+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@
M=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R("(E<R!A
M9&EC:6]N861O(&%O('-I<W1E;6$N(%9O8^H@<&]D92!S92!C;VYE8W1A<B!A
M9V]R82XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM
M<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")!9&GG
MXV\@9&4@=7-UX7)I;W,@97-TX2!D97-A8FEL:71A9&$N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T-#4*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B16YD
M97)EYV\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30Q"FUS9VED
M(")!9&1R97-S($)O;VLB"FUS9W-T<B`B0V%TX6QO9V\@9&4@16YD97)EYV]S
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*
M;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R
M('5S97)S(@IM<V=S='(@(D%D;6EN:7-T<F%R("T@8V]N9FEG=7)A('!E<FUI
M<W/U97,@<&%R82!O=71R;W,@=7-UX7)I;W,B"@HC.B!A9&UI;B]I;F1E>"YP
M:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B
M061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R8>?C;R(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#,*;7-G:60@(D%D<R(*;7-G<W1R
M(")!;OIN8VEO<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM
M<V=S='(@(D%F96=A;FES=.-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB86YI
M82(*;7-G<W1R(")!;&+B;FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG97)I
M82(*;7-G<W1R(")!<F?I<FEA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B07!E
M;&ED;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@(D%L:6YH87(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS
M9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(D%L:6YH86UE;G1O.B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(E1O
M9&]S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I
M8V%T960@57-E<G,B"FUS9W-T<B`B5&]D;W,@57-UX7)I;W,@075T96YT:6-A
M9&]S(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP
M.C(R,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R(")4;V1O<R!'<G5P;W,B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDQ(&9R86UE=V]R
M:R]097)M<R]097)M<R]D871A=')E92YP:'`Z-S4*;7-G:60@(D%L;"!097)M
M:7-S:6]N<R(*;7-G<W1R(")4;V1A<R!097)M:7-S]65S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I
M9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B5&]D;W,@<75A=')O(&QA9&]S
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B06QL
M;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(E!E<FUI=&ER(&WZ;'1I
M<&QO<R!E;F1E<F7G;W,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,X
M"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*
M;7-G<W1R(")097)M:71I<B!C;VYF:6=U<F%R(&\@=&EP;R!D92!L:7-T87,@
M;W)D96YA9&%S/R(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S
M<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B2N$@
M97AI<W1E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-@IM<V=I9"`B
M06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B3&]G:6X@24U34"!!;'1E
M<FYA=&EV;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3$*;7-G:60@
M(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(E-E;FAA($E-4U`@
M06QT97)N871I=F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`S"FUS
M9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R(")5<W7A<FEO
M($E-4U`@06QT97)N871I=F\B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HS-0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T
M<B`B16YD97)EYV\@9&4@92UM86EL(&%L=&5R;F%T:79O(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B
M"FUS9W-T<B`B36]D96QO<R!A;'1E<FYA=&EV;W,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G
M:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R(")497AT;R!A;'1E<FYA=&EV
M;SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R
M(")386UO82!!;65R:6-A;F$B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3$U"FUS
M9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@
M(E5M('9A;&]R(&EL96=A;"!F;VD@97-P96-I9FEC861O+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-34*;7-G:60@(D%N('5N:VYO=VX@
M97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(D]C;W)R974@=6T@97)R;R!D
M97-C;VYH96-I9&\N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G
M<W1R(")!;F1O<G)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM<V=S
M='(@(D%N9V]L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S
M='(@(D%N9W5I;&QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(E!R;WAY(&%N
M]&YI;6\B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I
M9"`B06YS=V5R(@IM<V=S='(@(E)E<W!O<W1A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I
M9"`B06YT87)C=&EC82(*;7-G<W1R(")!;G3A<G1I9&$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V
M"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(D%N=&EG=6$@
M92!"87)B861O<R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO
M<&AP<VAE;&PN<&AP.C,U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP
M:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I
M9"`B07!P;&EC871I;VXB"FUS9W-T<B`B07!L:6-AY^-O(@H*(SH@=71I;"]I
M8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM
M<V=S='(@(DQI<W1A(&1E($%P;&EC8>?U97,B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS
M9W-T<B`B02!A<&QI8V'GXV\@97-TX2!P<F]N=&$N(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H
M87)E<R(*;7-G<W1R(")!<&QI8V%R(&%O<R!#;VUP87)T:6QH86UE;G1O<R!3
M=6)O<F1I;F%D;W,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R(")!<')O=F%R(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0P"FUS9VED(")!
M<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(E1A;6%N:&\@07!R;WAI;6%D;R(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#,*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS
M9VED(")!<')I;"(*;7-G<W1R(")!8G)I;"(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3<T"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T
M<B`B07+A8FEC;R`H5VEN9&]W<RTQ,C4V*2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C<X"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R
M(")486UA;FAO(&1O($%R<75I=F\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HW-PIM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(DYO;64@9&\@
M07)Q=6EV;R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E
M9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO
M=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B
M"FUS9W-T<B`B5F]CZB!T96T@8V5R=&5Z82!Q=64@<75E<B!R96UO=F5R(&$@
M<V]L:6-I=&'GXV\@9&4@8V%D87-T<F\@9&4@)7,_(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@86YD
M(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R(")6;V/J('1E;2!C97)T97IA('%U
M92!D97-E:F$@97AC;'5I<B`G)7,G(&4@<V5U<R!S=6)G<G5P;W,_(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(D%R9V5N=&EN82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B07)MZFYI82(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<U"FUS9VED(")!<FUE;FEA;B`H
M05)-4T-)22TX*2(*;7-G<W1R(")!<FWJ;FEO("A!4DU30TE)+3@I(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B
M07)T92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S='(@(D%R=6)A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C
M96YS:6]N($ES;&%N9"(*;7-G<W1R("));&AA($%S8V5N<^-O(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T
M<B`B07)T92!!<V-I:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R("+!<VEA
M+U)E9VGC;R!D;R!086/M9FEC;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT,CD*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN
M9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R(")3;VQI8VET87(@
M8V]N9FER;6'GXV\@86YT97,@9&4@97AE8W5T87(@87,@;W!E<F'G]65S(&1E
M(&UA;G5T96[GXV\_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P
M,@IM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(D-O;'5N87,@
M9&4@9&5S:6=N8>?C;R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@
M(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G
M<W1R(")496YT;W4@97AC;'5I<B!U;2!G<G5P;R!I;F5X:7-T96YT92XB"@HC
M.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")4
M96YT;W4@97AC;'5I<B!U;6$@<&5R;6ES<^-O(&[C;R!E>&ES=&5N=&4N(@H*
M(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")496YT
M;W4@961I=&%R('5M82!P97)M:7-SXV\@;N-O(&5X:7-T96YT92XB"@HC.B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B5&5N=&]U(&5D
M:71A<B!U;2!C;VUP87)T:6QH86UE;G1O(&[C;R!E>&ES=&5N=&4N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#,*;7-G:60@(D%T=')I8G5T97,B
M"FUS9W-T<B`B071R:6)U=&]S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R(")!9V]S
M=&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B075S
M='+A;&EA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')I82(*;7-G<W1R("+!
M=7-T<FEA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C$V
M.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)S<6PZ($[C;R!F;VD@96YC
M;VYT<F%D82!A(&5X=&5N<^-O(&EM87`@;F5C97-SX7)I82XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER
M=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E
M<RXB"FUS9W-T<B`B075T:%]C>7)U<SH@3R!C;VYE8W1O<B!NXV\@<&]S<W5I
M(&%S(&-A<&%C:61A9&5S(&YE8V5S<^%R:6%S+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q
M=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H
M7V-Y<G5S.B!.XV\@9F]I(&5N8V]N=')A9&$@82!E>'1E;G/C;R!I;6%P(&YE
M8V5S<^%R:6$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C,V
M"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T
M<"!S=VET8V@N(@IM<V=S='(@(B(*(D%U=&A?9G1P.B!.XV\@9F]I(&5N8V]N
M=')A9&$@82!E>'1E;G/C;R!&5%`@;F5C97-SX7)I82X@0V]M<&EL92!O(%!(
M4"!C;VT@82`B"B)O<.?C;R`M+65N86)L92UF='`N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U
M:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?
M:6UA<#H@3N-O(&9O:2!E;F-O;G1R861A(&$@97AT96YSXV\@:6UA<"!N96-E
M<W/A<FEA+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-3$*
M;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")!=71H7VMR8C4Z($[C;R!F;VD@96YC;VYT<F%D
M82!A(&5X=&5N<^-O(&MR8C4@;F5C97-SX7)I82XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I
M;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R
M>2(*;7-G<W1R(")!=71H7VQD87`Z($EN8VQU<^-O(&1E('5S=>%R:6]S(&[C
M;R#I('-U<&]R=&%D82!P87)A($%C=&EV92!$:7)E8W1O<GDB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P
M.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@
M1&ER96-T;W)Y(@IM<V=S='(@(D%U=&A?;&1A<#H@17AC;'5SXV\@9&4@=7-U
MX7)I;W,@;N-O(.D@<W5P;W)T861A('!A<F$@06-T:79E($1I<F5C=&]R>2(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U
M=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")!=71H7VQD87`Z($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N
M<^-O($Q$05`@;F5C97-SX7)I82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z
M(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@26UP;W-S[79E;"!A
M9&EC:6]N87(@;R!U<W7A<FEO("5S+B!)<W1O(&9O:2!O('%U92!O('-E<G9I
M9&]R("(*(G)E<&]R=&]U.B`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N
M86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z($EM
M<&]S<^UV96P@<F5M;W9E<B!O('5S=>%R:6\@)7,B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R(")!
M=71H7VQD87`Z($EM<&]S<^UV96P@871U86QI>F%R(&\@=7-UX7)I;R`E<R(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!
M=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R
M($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@071U
M86QI>F'GXV\@9&4@=7-UX7)I;W,@;N-O(.D@<W5P;W)T861A('!A<F$@06-T
M:79E($1I<F5C=&]R>2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN
M<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]M8V%L.B!.XV\@9F]I(&5N
M8V]N=')A9&$@82!E>'1E;G/C;R!-0T%,(&YE8V5S<^%R:6$N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U
M=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B075T:%]S;6)A=71H.B!.XV\@9F]I(&5N8V]N=')A9&$@82!E>'1E
M;G/C;R!S;6)A=71H(&YE8V5S<^%R:6$N(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!9&UI;BYP:'`Z,3`V"FUS9VED(")!=71H96YT:6-A=&EO;B!A="!)
M34%0('-E<G9E<B!F86EL960N(@IM<V=S='(@(D%U=&5N=&EC8>?C;R!N;R!S
M97)V:61O<B!)34%0(&9A;&AO=2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N(&9A:6QE9"(*;7-G<W1R(")&86QH82!N82!A=71E;G1I8V'GXV\B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL
M960N("5S(@IM<V=S='(@(D9A;&AA(&YA(&%U=&5N=&EC8>?C;SH@)7,B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!
M=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G
M<W1R(")!=71E;G1I8V'GXV\@<F5J96ET861A('!E;&\@<V5R=FED;W(@4D%$
M2553+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#@R"FUS9VED
M(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T
M<B`B02!A=71E;G1I8V'GXV\@;F\@<V5R=FED;W(@1E10(&9A;&AO=2XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P"FUS9VED(")!=71H96YT
M:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM<V=S='(@(D$@
M875T96YT:6-AY^-O(&YO('-E<G9I9&]R(%--0B!F86QH;W4N(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I
M96QD<SHB"FUS9W-T<B`B0V%M<&]S(&1I<W!O;NUV96ES.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B07IE<F)A:6KC;R(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S
M(@IM<V=S='(@(D1E<V-U;'!A<R!D;R!"3T9((@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C
M:V=R;W5N9"(*;7-G<W1R(")&=6YD;R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L
M;W(B"FUS9W-T<B`B0V]R(&1E($9U;F1O(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D
M+B(*;7-G<W1R(")396YH82!K97)B97)O<R!I;F-O<G)E=&$N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E
M<F]S('5S97)N86UE+B(*;7-G<W1R(")5<W7A<FEO(&ME<F)E<F]S(&EN8V]R
M<F5T;RXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@(D)A
M:&%M87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"86AR86EN(@IM<V=S='(@(D)A
M:')A:6XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-@IM<V=I9"`B0F%L
M=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B0N%L=&EC;R`H25-/+3@X-3DM
M,3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R(")"
M86YG;&%D97-H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T
M<B`B0F%R8F%D;W,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E
M<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B3N-O(&9O:2!E;F-O;G1R861O(&\@
M9&ER973S<FEO(&)A<V4@9&4@:6UA9V5N<R`G)7,G+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B
M0F%S96QI;F4B"FUS9W-T<B`B3&EN:&$@9&4@4&%R=&ED82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B0F5L;W+Z<W-I82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B0NEL9VEC82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R(")"96QI>F4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R(")"96YI;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*
M;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B0F5R;75D87,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S
M"FUS9VED(")":'5T86XB"FUS9W-T<B`B0G5TXV\B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A
M>2(*;7-G<W1R(")!;FEV97)SX7)I;R(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R]#;VQL96-T:6]N+G!H<#HS-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(D[C;R!F;VD@96YC;VYT<F%D;R!O(&)L;V-O(%PB)7-<(B!D
M82!A<&QI8V'GXV\@7"(E<UPB+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHY,`IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B0V]N
M9FEG=7)AY_5E<R!D;R!";&]C;R(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R(")4:7!O(&1E
M($)L;V-O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(DYE9W)I=&\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@(D)O;.UV:6$B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`W"FUS9VED(")";V]K;6%R:W,B"FUS
M9W-T<B`B1F%V;W)I=&]S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@
M(D)O<F1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B3&%R
M9W5R82!D82!B;W)D83HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(Q"FUS9VED(")";W)D97)S(@IM<V=S='(@
M(D)O<F1A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G
M;W9I;F$B"FUS9W-T<B`B0O-S;FEA(&4@2&5R>F5G;W9I;F$B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B06UB
M;W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R(")";W1S
M=6%N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(E)O9&%PZ2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B26QH82!"
M;W5V970B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)A
M<VEL(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N
M(%1E<G)I=&]R>2(*;7-G<W1R(")497)R:73S<FEO(&1O($]C96%N;R#-;F1I
M8V\@26YG;.IS(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L
M86TB"FUS9W-T<B`B0G)U;F5I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R
M:6$B"FUS9W-T<B`B0G5L9^%R:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"=6QL971E9"!,:7-T(@IM
M<V=S='(@(DQI<W1A(&-O;2!-87)C861O<F5S(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(D)U<FMI;F$@1F%S;R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B0G5R=6YD:2(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#8*;7-G:60@(D--4R(*;7-G<W1R
M(")#35,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(D-23"!$:7-T<FEB=71I
M;VX@4&]I;G1S(@IM<V=S='(@(E!O;G1O<R!D92!$:7-T<FEB=6GGXV\@0U),
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@
M(E!R;W!R:65D861E<R!D82!#Z5]L=6QA+BXN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$U,0IM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T
M(&-O;7!L971E9"XB"FUS9W-T<B`B02!L:7-T82!D92!D:7-T<FEB=6GGXV\@
M;N-O(&9O:2!E<W!E8VEF:6-A9&$N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0X,R!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z
M.3@W"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-3<*;7-G:60@(D-A
M;&5N9&%R(@IM<V=S='(@(D%G96YD82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,S4*;7-G:60@(D-A;&TB"FUS9W-T<B`B0V%L;6\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B0V%M8F]D:F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8W"FUS9VED(")#86UE<F]O;B(*;7-G<W1R(")#86UA<O5E
M<R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#
M86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@
M>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B).XV\@Z2!P;W-S[79E
M;"!G97)A<B!U;6$@;F]V82!S96YH82!A=71O;6%T:6-A;65N=&4L(&5N=')E
M(&5M(&-O;G1A=&\@8V]M(&\@(@HB861M:6YI<W1R861O<BXB"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS-3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R(").XV\@
M8V]N<VEG;R!G<F%V87(@;R!A<G%U:79O(%PB)7-<(B(*"B,Z(&%D;6EN+W-E
M<W-I;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA
M;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R(").XV\@Z2!P;W-S[79E;"!A
M9&UI;FES=')A<B!G97)E;F-I861O<F5S(&5X=&5R;F]S(&1E('-E<W/C;RXB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,S4@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R
M(").XV\@Z2!P;W-S[79E;"!C;VYE8W1A<B!A;R!S97)V:61O<B!)34%0.B`E
M<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M(").XV\@8V]N<VEG;R!A8G)I<B!O(&%R<75I=F\@7"(E<UPB+B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G<W1R(")#86YA9.$B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R(")#86YC96QA<B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC
M96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B0V%N8V5L87(@4F5L873S<FEO
M(&1E(%!R;V)L96UA(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS
M,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B3N-O(.D@<&]S<^UV96P@97AC;'5I<B!O(&%R<75I
M=F\@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+V-O<'DN<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D
M:7)E8W1O<GDN(@IM<V=S='(@(D[C;R#I('!O<W/M=F5L(&5N8V]N=')A<B!U
M;2!D:7)E=/-R:6\@=&5M<&]RX7)I;RXB"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E
M9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(D[C
M;R#I('!O<W/M=F5L(&-O;G1I;G5A<B!S96T@;R!P87+B;65T<F\@)W1A<F=E
M=$9I;&4G+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB
M)7-<(BXB"FUS9W-T<B`B3N-O(.D@<&]S<^UV96P@97AC;'5I<B!O(&1I<F5T
M\W)I;R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E
M+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z
M-C@P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H
M:6QD<F5N(&5X:7-T+B(*;7-G<W1R(").XV\@Z2!P;W-S[79E;"!E>&-L=6ER
M+"`E9"!P;W-S=6D@<W5B;W)D:6YA9&]S+B(*"B,Z(&9R86UE=V]R:R]$871A
M5')E92]$871A5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T(')E
M;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R
M(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@(B(*
M(D[C;R#I('!O<W/M=F5L(')E;W)D96YA<BP@;OIM97)O(&1E(')E9VES=')O
M<R!F;W)N96-I9&]S('!A<F$@<F5O<F1E;F%R(&[C;R`B"B)C;W)R97-P;VYD
M92!A;R!N^FUE<F\@87)M87IE;F%D;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R
M;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(D[C
M;R#I('!O<W/M=F5L(')O=&5A<B!M96YS86=E;2!P87)A(&\@;OIM97)O(&5S
M<&5C:69I8V%D;RXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM
M<V=S='(@(D-A8F\@5F5R9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(T"FUS9VED(")#87!T:6]N(@IM<V=S
M='(@(E3M='5L;R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC
M7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*;7-G<W1R(")/<&5R861O
M<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,*;7-G:60@(D-A=&5G
M;W)I97,@86YD($QA8F5L<R(*;7-G<W1R(")#871E9V]R:6%S(&4@3F]M97,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B
M26QH87,@0V%Y;6%N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R(")496QE
M9F]N92!#96QU;&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM
M<V=S='(@(E!R;W!R:65D861E<R!D82!#Z6QU;&$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P
M861D:6YG.B(*;7-G<W1R(")-87)G96T@9&$@8^EL=6QA.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G
M:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R(")0<F]P<FEE9&%D97,@9&$@
M0^EL=6QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B17-P8>=A
M;65N=&\@9&$@8^EL=6QA.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R-S@*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R(")496QE9F]N92!C96QU
M;&%R(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D-E;'1I
M8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(D/I;'1I8V\@*$E33RTX.#4Y+3$T
M*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R(")#96YT<F\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T
M<B`B4F5P^F)L:6-A(&1A(,%F<FEC82!#96YT<F%L(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX
M.#4Y+3(I(@IM<V=S='(@(D5U<F]P82!#96YT<F%L("A)4T\M.#@U.2TR*2(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED
M(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(D1E=&%L:&5S(&1O($-E
M<G1I9FEC861O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV,3(*;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S='(@(E!R;W!R
M:65TX7)I;R!D;R!#97)T:69I8V%D;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE
M<R(*;7-G<W1R(")0;VSM=&EC87,@9&\@0V5R=&EF:6-A9&\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#@*;7-G:60@(D-H860B"FUS9W-T<B`B5&-H861E(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHY-@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(D%L=&5R87(B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G:60@(D-H86YG
M92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(D%L=&5R92!3=6$@4V5N:&$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-CD*;7-G:60@(B(*(D-H86YG92!T
M:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y
M(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R("(B
M"B)!;'1E<F%R(&\@;F]M92!E(&\@96YD97)EYV\@<75E(&%S('!E<W-O87,@
M=NIE;2!Q=6%N9&\@96QA<R!LZF5M(&4@<F5S<&]N9&5M("(*(G-U87,@;65N
M<V%G96YS+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM
M<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R
M=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A
M8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)!;'1E<F'GXV\@
M9&4@<V5N:&$@;N-O(.D@<W5P;W)T861A(&YA(&-O;F9I9W5R8>?C;R!A='5A
M;"X@($5N=')E(&5M(&-O;G1A=&\@(@HB8V]M(&\@861M:6YI<W1R861O<BXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(D-H87(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G
M:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(E9E<FEF:6-A<B!,:6Y?:RXN
M+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6QE(@IM<V=S='(@(D-H:6QE(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-PIM<V=I9"`B0VAI;F$B"FUS9W-T<B`B0VAI;F$B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B0VAI;F5S92!3:6UP;&EF
M:65D("A'0C(S,3(I(@IM<V=S='(@(D-H:6[J<R!3:6UP;&EF:6-A9&\@*$="
M,C,Q,BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0VAI
M;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B0VAI;NIS(%1R861I
M8VEO;F%L("A":6<U*2(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C<*
M;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB"FUS9W-T<B`B17-C;VQH82!A
M($%P;&EC8>?C;SHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,C<P"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R(")%<V-O
M;&AA('5M82!S96YH82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P
M+G!H<#HR-CD*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(D5S
M8V]L:&$@=6T@=7-UX7)I;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M,#(*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T
M<B`B17-C;VQH82!C;VUO(&5X:6)I<B!D871A<SHB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED
M(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB
M"FUS9W-T<B`B17-C;VQH82!O('1I<&\@9&4@97-T:6QO(&1E(&QI<W1A<R`H
M<&%R82!L:7-T87,@;W)D96YA9&%S*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H
M<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B26QH87,@0VAR:7-T;6%S(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.CDQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET
M:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B3N-O(&9O:2!E;F-O;G1R
M861A(&$@9&5F:6YIY^-O(&1E(&-L87-S92!D92`E<RXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B0VQE87(B
M"FUS9W-T<B`B3&EM<&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*
M;7-G<W1R("),:6UP87(@=&%G<R!-4T]F9FEC92(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,C@*;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@(D5X8VQU
M:7(@=7-UX7)I;R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN
M8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*
M;7-G<W1R(")%>&-L=6ER('5S=>%R:6\Z("5S(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S
M='(@(D5X8VQU:7(@=7-UX7)I;R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B
M17AC;'5I<B!D861O<R!D;R!U<W7A<FEO(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B
M"FUS9W-T<B`B0^EU(&%B97)T;R!A(%1A<F1E(@H*(SH@=&5M<&QA=&5S+VUA
M:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O
M($-O;G1I;G5E(@IM<V=S='(@(D-L:7%U92!P87)A($-O;G1I;G5A<B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X
M-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R(")#;&EC:V%T
M96QL('9I82!(5%10(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD
M;W<B"FUS9W-T<B`B1F5C:&%R($IA;F5L82(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C4Q"FUS9VED(")#;&]U9',B"FUS9W-T<B`B3G5V96YS(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@
M(D-L;W5D<R!%87)L>2(*;7-G<W1R(").=6)L861O('!E;&$@36%N:.,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PIM<V=I
M9"`B0VQO=61Y(@IM<V=S='(@(DYU8FQA9&\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED
M(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("));&AA<R!D92!#
M;V-O<R(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G
M:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B0V]N=')A:7(@0F%R<F$@
M3&%T97)A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S
M='(@(D-O;G1R86ER(&)O<F1A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M
M8FEA(@IM<V=S='(@(D-O;/1M8FEA(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H
M<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R
M(@IM<V=S='(@(D-O<B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL
M96-T:6]N+G!H<#HS,C4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE
M8W1I;VXN<&AP.C,R-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-3`Q('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z
M,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R(")086QH971A(&1E($-O
M<F5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@S-0IM<V=I9"`B
M0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R(")396QEY^-O(&1E($-O<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS
M9VED(")#;VQS.B(*;7-G<W1R(")#;VQS.B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Y-3`*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B
M5.UT=6QO<R!D87,@0V]L=6YA<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR-C8*;7-G:60@(D-O;6EC<R(*;7-G<W1R(")1=6%D<FEN:&]S(@H*
M(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"FUS9VED(")#;VUM86YD(@IM<V=S
M='(@(D-O;6%N9&\B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@
M(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B3&EN:&$@9&4@0V]M86YD;R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B0V]M
M;65N="(*;7-G<W1R(")#;VUE;G1A<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-38W"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R
M(").;VUE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B
M0V]M;W)O<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B16UP<F5S82(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM
M<V=S='(@(D-O;7!U=&%D;W)E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.#8*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R(")#;VYD:>?C
M;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4V"FUS9VED(")#;VYD:71I
M;VYS(@IM<V=S='(@(D-O;F1IY_5E<R(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S
M='(@(D1I9F5R96[G87,@9&4@0V]N9FEG=7)AY^-O(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$T-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN
M8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G
M<W1R(")#;VYF:6=U<F'GXV\@9&4@<VEN8W)O;FEZ8>?C;R!C;VT@4$1!<RP@
M4VUA<G1P:&]N97,@92!/=71L;V]K+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N
M(@IM<V=S='(@(D-O;F9I9W5R8>?C;R!N96-E<W-I=&$@9&4@871U86QI>F'G
MXV\N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B0V]N9FEG=7)A<B`E
M<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3$*;7-G
M:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B0V]N9FER;64@82!396YH
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-34@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S='(@(D-O;F=O(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B
M;&EC(&]F('1H92(*;7-G<W1R(")#;VYG;RP@4F5P^F)L:6-A($1E;6]C<N%T
M:6-A(&1O(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@(D9A;&AA
M(&YA(&-O;F5XXV\N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R
M(")&86QH82!N82!C;VYE>.-O.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B0V]N97CC;R!R96-U<V%D
M82!P96QO('-E<G9I9&]R(&1E(&-H879E<R!P^F)L:6-A<RXB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B0V]N97CC;R!R96-U<V%D
M82!P96QO('-E<G9I9&]R(&1E(&-H879E<R!P^F)L:6-A<RX@36]T:79O.B`E
M<R`H)7,I(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-S8*;7-G
M:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@
M(D$@8V]N97CC;R!A;R!S97)V:61O<B!&5%`@9F%L:&]U+B(*"B,Z(&-O;F9I
M9R]H;V]K<RYP:'`N9&ES=#HQ,#$T"FUS9VED(")#;VYT86-T<R(*;7-G<W1R
M(")#;VYT871O<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@
M861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*(D]S(&-O
M;G1A=&]S(&9O<F%M(&%D:6-I;VYA9&]S(&-O;2!S=6-E<W-O(&%O('-E=2!C
M873A;&]G;R!D92!E;F1E<F7G;W,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HV,`IM<V=I9"`B0V]N=&5N="!T>7!E(&]F(&-O
M;7!R97-S960@9FEL93H@(@IM<V=S='(@(E1I<&4@9&4@8V]N=&7Z9&\@9&\@
M87)Q=6EV;R!C;VUP<FEM:61O.B`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S
M7"(B"FUS9W-T<B`B0V]N=&7Z9&\@9&4@)R5S)R(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B0V]N=&EN=6%R(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@(DEL:&%S($-O
M;VLB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI
M92(*;7-G<W1R(")#;V]K:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T
M<B`B0V]P:6%R(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@
M(D9A;&AA(&YA(&/S<&EA.B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM
M<V=S='(@(D-O<&EA<B!S96QEY^-O(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B240@
M9&4@0W5S=&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;W-T82!2:6-A(@IM<V=S
M='(@(D-O<W1A(%)I8V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;W1E(&0G279O
M:7)E(@IM<V=S='(@(D-O<W1A(&1O($UA<F9I;2(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!E
M;F-R>7!T(&UE<W-A9V4Z("(*;7-G<W1R("));7!O<W/M=F5L(&-R:7!T;V=R
M869A<B!A(&UE;G-A9V5M(&-O;2!01U`Z("(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$P-34*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG
M;B!M97-S86=E.B`B"FUS9W-T<B`B26UP;W-S[79E;"!A<W-I;F%R(&$@;65N
M<V%G96T@8V]M(%!'4#H@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M
M97-S86=E+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&-R:7!T;V=R869A
M<B!A(&UE;G-A9V5M(&-O;2!3+TU)344N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@
M<VEG;B!M97-S86=E+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&%S<VEN
M87(@82!M96YS86=E;2!C;VT@4R]-24U%+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B3N-O
M(&9O:2!P;W-S[79E;"!A9&EC:6]N87(@8V]N=&%T;RX@)7,B"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HQ,C$*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0U
M-PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S
M='(@(D[C;R!F;VD@<&]S<^UV96P@8V]N96-T87(@86\@<V5R=FED;W(@3$1!
M4"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C$U-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H
M96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@=F5R
M:69I8V%R(&\@<V%L9&\N("5S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C0T,0IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N
M(@IM<V=S='(@(DEM<&]S<^UV96P@8V]N96-T87(@86\@<V5R=FED;W(@3$1!
M4"XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U
M<VEN9R!&5%`Z("5S(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@8V]N96-T
M87(@86\@<V5R=FED;W(@)R5S)R!U=&EL:7IA;F1O($944#H@)7,B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&-R:6%R
M(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B`E<R(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$Q,C@*;7-G:60@(D-O=6QD(&YO="!D96-R
M>7!T(%!'4"!D871A.B`B"FUS9W-T<B`B26UP;W-S[79E;"!D97-C<FEP=&]G
M<F%F87(@;W,@9&%D;W,@4$=0.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4R,PIM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-
M24U%(&1A=&$N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@9&5S8W)I<'1O
M9W)A9F%R(&\@9&%D;R!3+TU)344N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R(").XV\@
M9F]I('!O<W/M=F5L(&5X8VQU:7(@;R!C;VYT871O+B`E<R(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@97AC;'5I<B!A
M(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,B"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B
M3N-O(&9O:2!P;W-S[79E;"!E>&-L=6ER(&\@<V-R:7!T(&1E(&%T=6%L:7IA
MY^-O(&1E(&-O;F9I9W5R8>?C;R`G)7,G+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.CDU,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C
M:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(D[C;R!F;VD@<&]S
M<^UV96P@9&5T97)M:6YA<B!O(&5N9&5R9>=O(&1E(&4M;6%I;"!D;R!D97-T
M:6YA=.%R:6\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T
M92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@;V)T
M97(@8V]M<&QE=&%M96YT92!O(&-A=.%L;V=O(&1E(&5N9&5R9>=O<RXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y
M,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO
M;B!L:7-T+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&]B=&5R(&-O;7!L
M971A;65N=&4@82!L:7-T82!D92!D:7-T<FEB=6GGXV\N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@
M(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB
M=71I;VX@;&ES=',N(@IM<V=S='(@(B(*(D[C;R!F;VD@<&]S<^UV96P@;V)T
M97(@8V]M<&QE=&%M96YT92!A(&QI<W1A(&1E(&QI<W1A<R!D92!D:7-T<FEB
M=6GGXV\N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<
M(B5S7"(N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@8V%R<F5G87(@82!E
M<W1R873I9VEA("<E<R<N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T
M<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E
M;"!C<FEA<B!O(&1I<F5T\W)I;R`G)7,G+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P
M=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B3N-O(&9O
M:2!P;W-S[79E;"!O8G1E<B!A(&-H879E('#Z8FQI8V$@82!P87)T:7(@9&\@
M<V5R=FED;W(@9&4@8VAA=F5S+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O
M<B!W<FET:6YG+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&%B<FER("<E
M<R<@<&%R82!G<F%V8>?C;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@
M86)R:7(@)7,N(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA
M;F-E+G!H<#HT,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B3N-O(&9O
M:2!P;W-S[79E;"!A8G)I<B!O(&WS9'5L;R`G36%I;G1E;F%N8V5?5&%S:R<@
M)7,B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B
M3N-O(&9O:2!P;W-S[79E;"!A8G)I<B!O(&1I<F5T\W)I;R`G)7,G+B(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q
M-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C8Y.0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H
M92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!P97-Q
M=6ES87(@;F\@<V5R=FED;W(@3$1!4"XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]/8FIE8W0N<&AP.C(T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<F5A9"`E<RXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!L97(@)7,N
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*
M(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T
M960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO
M="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B
M"B).XV\@9F]I('!O<W/M=F5L(&=E<F%R('5M82!N;W9A('-E;FAA('!A<F$@
M;R!U<W7A<FEO('-O;&EC:71A9&\N($%L9W5N<R!O=2`B"B)T;V1O<R!O<R!D
M971A;&AE<R!NXV\@97-TXV\@8V]R<F5T;W,N(%1E;G1E(&YO=F%M96YT92!O
M=2!E;G1R92!E;2!C;VYT871O("(*(F-O;2!O(&%D;6EN:7-T<F%D;W(@<V4@
M=F]CZB!N96-E<W-I=&$@9&4@;6%I<R!A:G5D82XB"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-PHC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@04-,(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@;V)T97(@82!!0TPB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&]B
M=&5R(&\@8V%TX6QO9V\@9&4@96YD97)EYV]S+B`E<R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!A(&QI
M<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E
M<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&]B=&5R(&%S(&QI<W1A<R!D
M92!D:7-T<FEB=6GGXV\N("5S(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V
M97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!O
M8G1E<B!A<R!C87!A8VED861E<R!D;R!S97)V:61O<B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!R979E<G1E
M<B!A(&-O;F9I9W5R8>?C;RXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS
M9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&\@9&ER973S<FEO("<E
M<R<N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!S86QV87(@82!C;VYF:6=U<F'G
MXV\@)7,N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A
M8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@
M<V%L=F%R('5M(&)A8VMU<"!D82!C;VYF:6=U<F'GXV\N(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B
M3N-O(&9O:2!P;W-S[79E;"!S86QV87(@=6T@8F%C:W5P(&1A(&-O;F9I9W5R
M8>?C;SH@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E
M('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"B).XV\@9F]I('!O<W/M
M=F5L('-A;'9A<B!O('-C<FEP="!D92!A='5A;&EZ8>?C;R!D92!C;VYF:6=U
M<F'GXV\@96TZ("<E<R<N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C
M:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B3N-O(&-O;G-E
M9W5I('-A;'9A<B!O(&)A8VMU<"!D;R!A<G%U:79O(&1E(&-O;F9I9W5R8>?C
M;R`E<RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T
M:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*
M(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@
M;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*(D[C
M;R!C;VYS96=U:2!S86QV87(@;R!A<G%U:79O(&1E(&-O;F9I9W5R8>?C;R`E
M<RX@5F]CZB!P;V1E(&]U('5T:6QI>F%R('5M82`B"B)D87,@;W#G]65S('!A
M<F$@<V%L=F%R(&\@8_-D:6=O(&1E('9O;'1A(&5M("5S(&]U(&-O<&EA<B!M
M86YU86QM96YT92!O("(*(F/S9&EG;R!A8F%I>&\@<&%R82`E<RXB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@
M;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(D[C;R!F;VD@
M<&]S<^UV96P@<&5S<75I<V%R(&YO('-E<G9I9&]R($Q$05`N(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(')E
M;6]V97(@;R!L:6YK("<E<R<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R(").XV\@9F]I
M('!O<W/M=F5L(&%T=6%L:7IA<B!O(&-O;G1A=&\N("5S(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!A='5A;&EZ87(@
M82!L:7-T82!D92!D:7-T<FEB=6GGXV\N("5S(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W
M<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(D[C
M;R!F;VD@<&]S<^UV96P@9W)A=F%R(&$@8V]N9FEG=7)AY^-O(&1E("<E<R<Z
M("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W,`IM<V=I9"`B0V]U
M;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE
M('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B(@HB3N-O(&9O:2!P;W-S[79E
M;"!E;F-O;G1R87(@82!"87)R82!,871E<F%L(&1O($UO>FEL;&$N($-E<G1I
M9FEQ=64M<V4@<75E(&5L82`B"B)E<W3A(&%B97)T82XB"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L
M;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S
M='(@(B(*(D[C;R!F;VD@<&]S<^UV96P@9&%R(&%O('5S=>%R:6\@)7,@;W,@
M<V5G=6EN=&5S(&1I<F5I=&]S('!A<F$@82!P87-T82`G)7,G.B`E(@HB<R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C,*;7-G:60@(D-O=6YT
M960@=&5X="(*;7-G<W1R(")497AT;R!C;VYT861O(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(D-O=6YT<GDB"FUS
M9W-T<B`B4&'M<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S4*
M;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B0W5R<V]S(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS
M9VED(")#<F5A=&4B"FUS9W-T<B`B0W)I87(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R
M96%T92!A(&QI;FLB"FUS9W-T<B`B0W)I87(@=6T@;&EN:R(*"B,Z('1E;7!L
M871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R96%T
M92!A(&YE=R!O;F4B"FUS9W-T<B`B0W)I87(@=6UA(&YO=F$B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E
M871E('-U8B!F;VQD97)S(@IM<V=S='(@(D-R:6%R('-U8B!P87-T87,B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E
M871O<B!097)M:7-S:6]N<R(*;7-G<W1R(")097)M:7-S]65S(&1O(&-R:6%D
M;W(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C$Y"FUS9VED(")#
M<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B3OIM97)O(&1O(&-A<G3C;R!D
M92!C<NED:71O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(D-R;V%T:6$B"FUS9W-T
M<B`B0W)OX6-I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B
M0W5B82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@IM<V=I9"`B0W5R<F5N
M="`T(%!H87-E<R(*;7-G<W1R("(T($9A<V5S($%T=6%I<R(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HU,`IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G
M<W1R(")397-S]65S($%T=6%I<R(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS
M(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM
M<V=S='(@(DAO<F$@071U86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),
M(&ES(@IM<V=S='(@(D$@55),(&%T=6%L(.DB"@HC.B!A9&UI;B]S97-S:6]N
M<RYP:'`Z,S4*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`B57-UX7)I
M;W,@;F\@;6]M96YT;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G
M:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R(")#;&EM82!!='5A;"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C0*;7-G:60@(D-U<G)E
M;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B0V]N9&GGXV\@871U86PZ("(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G
M:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B17-T:6QO(&%T=6%L(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM
M<V=S='(@(D-U<W1O;6EZ82!T87)E9F%S(&$@<V5R96T@97AE8W5T861A<R!A
M;R!C;VYE8W1A<B!A("5S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@
M(D-O<G1A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B0V]R=&%R
M('-E;&7GXV\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B
M0VAI<')E(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-Y
M<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(D-I<NUL:6-O("A+3TDX+5(I(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@(D-Y<FEL;&EC("A7
M:6YD;W=S+3$R-3$I(@IM<V=S='(@(D-I<NUL:6-O("A7:6YD;W=S+3$R-3$I
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-Y<FEL;&EC
M+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R(")#:7+M;&EC;R]58W)A;FEA
M;F\@*$M/23@M52DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI
M8R(*;7-G<W1R(")297#Z8FQI8V$@5&-H96-A(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,"!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B1$0B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,C<Y"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O
M<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN
M=')O+61S;BYP:'`I(@IM<V=S='(@(B(*(D133B`H=F5J82!H='1P.B\O<&5A
M<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O
M+61S;BYP:'`I(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA
M;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B1&EA<FEA;65N=&4B
M"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R
M;W=S97(B"FUS9W-T<B`B3F%V96=A9&]R(&1E($1A=&%4<F5E(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W-PIM<V=I9"`B1&%T86)A<V4@3&]O
M:W5P(@IM<V=S='(@(E!E<W%U:7-A(&YO($)A;F-O(&1E($1A9&]S(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#`R"FUS9VED(")$871E(@IM<V=S='(@
M(D1A=&$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ
M,PIM<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R(")$871A(&1E(%)E8V5B
M:6UE;G1O(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y-@IM<V=I
M9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`B4V5L9>?C;R!D92!D871A(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,2!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q"FUS9VED(")$87DB"FUS9W-T<B`B1&EA
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,V"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R(")%7WAC
M;'5I<B!#;VQU;F$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B1&5Z96UB<F\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B3OIM
M97)O<R!D96-I;6%I<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R
M(")296-U87(@261E;G1AY^-O(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*;7-G:60@(D1E9F%U;'0B
M"FUS9W-T<B`B4&%D<N-O(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-S<*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T
M<B`B0V]R(%!A9'+C;R(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET
M>2YP:'`Z.38*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B261E
M;G1I9&%D92!0861RXV\B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*
M;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B4VAE;&P@4&%D<N-O(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N
M<R(*;7-G<W1R(")$969I;FGG]65S(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(D5X
M8VQU:7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S(*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(D5X
M8VQU:7(@8^EL=6QA(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO
M9W)O=7!S+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R(")%
M>&-L=6ER($=R=7!O(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C0Y"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@(D5X8VQU:7(@3&]G(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E<FUI<W-I
M;VXB"FUS9W-T<B`B17AC;'5I<B!097)M:7-SXV\B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E(&%N
M9"!P=7)G92!M97-S86=E<R(*;7-G<W1R(")%>&-L=6ER(&4@<'5R9V%R(&UE
M;G-A9V5N<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(D5X
M8VQU:7(@8^EL=6QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G
M<W1R(")%>&-L=6ER(&-O;'5N82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E
M(@IM<V=S='(@(D5X8VQU:7(@;6]D96QO('-U8G-T:71U=&\@97AI<W1E;G1E
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B
M"FUS9W-T<B`B17AC;'5I<B!P97)M:7-S]65S('!A<F$@)R5S)R(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(T"B,L('!H<"UF;W)M870*
M;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@
M<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R(")%>&-L=6ER('!E<FUI<W/U97,@
M<&%R82`G)7,G(&4@<75A;'%U97(@;W5T<F$@<W5B+7!E<FUI<W/C;S\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8W"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(D5X8VQU:7(@;&EN:&$B
M"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS
M9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B17AC;'5I
M<B!I9&5N=&ED861E('-E;&5C:6]N861A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED(")$96QE
M=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(D5X8VQU:7(@82!C;VQU
M;F$@871U86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R
M;W<B"FUS9W-T<B`B17AC;'5I<B!A(&QI;FAA(&%T=6%L(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(E-C
M<FEP="!D92!A='5A;&EZ8>?C;R!D92!C;VYF:6=U<F'GXV\@)R5S)R!E>&-L
M=>UD;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS9VED(")$96QI=F5R>2!T:6UE(@IM
M<V=S='(@(DAO<F$@9&4@96YT<F5G82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E
M;FUA<FLB"FUS9W-T<B`B1&EN86UA<F-A(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M
M(@IM<V=S='(@(D1E<V-R979A(&\@<')O8FQE;6$B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HY-#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T
M<B`B1&5S8W)IY^-O(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M.3<*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB
M"FUS9W-T<B`B1&5T86QH97,@*'1A;6+I;2!N;R!R96=I<W1R;R!D92!A=&EV
M:61A9&5S(&1O($AO<F1E*3HB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C(P,0IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T
M:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B3W,@9&5T86QH97,@9F]R86T@
M9W)A=F%D;W,@96T@;&]G('!A<F$@;R!A9&UI;FES=')A9&]R+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C$*;7-G:60@(D1E=F5L;W!M96YT
M(@IM<V=S='(@(D1E<V5N=F]L=FEM96YT;R(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C(T"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B4&]N=&\@9&4@
M3W)V86QH;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`Q"FUS9VED(")$
M97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E!O;G1O(&1E($]R
M=F%L:&\@<&%R82!A(/IL=&EM82!H;W)A.B`B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R
M(")0;VYT;R!D92!/<G9A;&AO.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T
M;R!R:6=H="(*;7-G<W1R(")$:7)EY^-O(&1A(&5S<75E<F1A('!A<F$@9&ER
M96ET82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@
M(D1I<F7GXV\@9&$@9&ER96ET82!P87)A(&5S<75E<F1A(@H*(SH@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R(")$
M:7)E=/-R:6\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<P"FUS9VED
M(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(D5X:6)I<B!E;2!F
M;W)M871O(#(T(&AO<F%S/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,#`*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R(")/<.?U97,@9&4@
M17AI8FGGXV\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.#D*
M;7-G:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B17AI
M8FER('!R979I<^-O(&1E=&%L:&%D82(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z.3(*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B
M17AI8FER('!R979I<^-O("A4048I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@P-@IM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B17AI
M8FER(&9O<FUA=&\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z
M,3DQ"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B
M3F]T:69I8V'GXV\@9&4@1&ES<&]S:>?C;R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@
M(D1J:6)O=71I(@IM<V=S='(@(D1J:6)U=&DB"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G
M<W1R(").XV\@97AC;'5I<B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC
M92YP:'`B"FUS9W-T<B`B3N-O(&%C97-S92!D:7)E=&%M96YT92!M86EN=&5N
M86YC92YP:'`B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,B!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@
M9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H
M96-K('1H:7,@8F]X.B(*;7-G<W1R("(B"B)!('!R:6UE:7)A(&QI;FAA(&-O
M;G3I;2!O<R!N;VUE<R!D;W,@8V%M<&]S/R!392!S:6TL(&-L:7%U92!N97-T
M82!C86EX83HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R
M(")$;VUI;FEC86YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E
M<'5B;&EC(@IM<V=S='(@(E)E</IB;&EC82!$;VUI;FEC86YA(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A
M;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R(").XV\@=&5M('5M82!C;VYT
M83\@0V%D87-T<F4M<V4N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z.#4Q"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R(")"86EX87(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B0F%I>&%R
M("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W
M;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB
M"FUS9W-T<B`B0F%I>&%R(&$@8V]N9FEG=7)AY^-O(&=E<F%D82!C;VUO('5M
M('-C<FEP="!02%`N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q
M,0IM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B3&ES=&$@9&4@<V5L
M9>?C;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U
M9W,B"FUS9W-T<B`B1')O9V%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$S"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B0V]R<F5I;R(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDR
M"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R
M:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B(@HB
M0V]N96-T;W(@9&\@9V%T97=A>2!%36%I;"UP87)A+5--4RP@<&%R82!O<&5R
M861O<F%S('%U92!D:7-P;VYI8FEL:7IA;2!E<W1E("(*(G-E<G9IYV\N(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(D524B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B17%U861O<B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV
M.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@IM<V=I9"`B161I="(*;7-G<W1R(")%
M9&ET87(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P"FUS
M9VED(")%9&ET($)L;V-K(@IM<V=S='(@(D5D:71A<B!";&]C;R(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED
M(")%9&ET($=R;W5P(@IM<V=S='(@(D5D:71A<B!'<G5P;R(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R
M(")%9&ET87(@4&5R;6ES<^-O(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N
M<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R(")%9&ET
M87(@4&5R;6ES<_5E<R(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR
M,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@
M)7,B"FUS9W-T<B`B161I=&%R(%!E<FUI<W/U97,@<&%R82`E<R(*"B,Z('1E
M;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F
M;W(Z(@IM<V=S='(@(D5D:71A<B!O<.?U97,@9&4Z(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(D5D:71A<B!P
M97)M:7-S]65S('!A<F$@)7,B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@
M9F]R("5S(@IM<V=S='(@(D5D:71A<B!P97)M:7-S]65S('!A<F$@)7,B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*
M;7-G<W1R(")%9'5C8>?C;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM
M<V=S='(@(D5G:71O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%;"!386QV861O
M<B(*;7-G<W1R(")%;"!386QV861O<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N
M="XN+B(*;7-G<W1R(")%;&5M96YT;RXN+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R
M(")%;2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,PIM<V=I9"`B16UA
M:6PB"FUS9W-T<B`B12UM86EL(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-C8@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"FUS
M9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D5N9&5R9>=O(&1E($4M36%I
M;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C<*;7-G:60@(D5M
M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")/(&5N9&5R9>=O
M(&1E(&4M;6%I;"!D979E(&-O<G)E<W!O;F1E<BXB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.3DS"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA
M=&EO;B(*;7-G<W1R(")-96YS86=E;2!C;VT@8V]N9FER;6'GXV\B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I
M9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B1V%T97=A>2!D92!%
M36%I;"UP87)A+5--4R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR.3<*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R(")%;6]T
M:6-O;G,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(DUE
M;G-A9V5M(&5M(&)R86YC;RXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT
M.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U;'0N(@IM
M<V=S='(@(E)E<W5L=&%D;R!E;2!B<F%N8V\N(@H*(SH@9G)A;65W;W)K+U-1
M3"]344PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E
M<FUS(@IM<V=S='(@(E1E<FUO<R!D92!P97-Q=6ES82!E;2!B<F%N8V\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30W"FUS9VED(")%;F%B;&4@:6YS
M97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT
M/R(*;7-G<W1R(")(86)I;&ET87(@:6YS97+GXV\@9&4@:6UA9V5N<R!A('!A
M<G1I<B!D82!'86QE<FEA(&1E($EM86=E;G,@;F\@=&5X=&\_(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4R,@IM<V=I9"`B16YA8FQE(')I9VAT(&-L
M:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B2&%B:6QI=&%R(&UE;G4@9&4@
M8V]N=&5X=&\@8V]M(&\@8F]TXV\@9&ER96ET;S\B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-3DR(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,#`*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(D9I;F%L(&1O(&%N;R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G
M:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(D%U;65N=&%R($5D:71O<B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C0*;7-G:60@(B(*(D5N=&5R
M(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@
M:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G
M=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"B)&
M;W)N9>=A('5M82!P97)G=6YT82!D92!S96=U<F%NYV$@82!Q=6%L('9O8^H@
M<V5RX2!P97)G=6YT861O('-E('9O8^H@(@HB;F5C97-S:71A<B!G97)A<B!U
M;6$@;F]V82!S96YH82P@97@N("=Q=6%L(&\@;F]M92!D;R!S974@8V%C:&]R
M<F\_)SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@
M:&5R92(*;7-G<W1R(")&;W)N9>=A(&$@55),(&1A(&EM86=E;2!A<75I(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,`IM
M<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@(D1I9VET
M92!A<R!L971R87,@86)A:7AO.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T
M;W)I86P@1W5I;F5A(@IM<V=S='(@(D=U:6[I($5Q=6%T;W)I86PB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM<V=S='(@(D5R:71RZ6EA(@H*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M<W1A='5S+G!H<#HR-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+U9I97<N<&AP.CDT(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT.`HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V"FUS9VED(")%<G)O<B(*;7-G<W1R
M(")%<G)O(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT
M-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ
M("5S(@IM<V=S='(@(D5R<F\@86\@8W)I87(@8FQO8V\Z("5S(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(D5R
M<F\@86\@97AC;'5I<B#B;F-O<F$@9&4@<VEN8W)O;FEZ8>?C;SH@)7,B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B
M17)R;R!A;R!E>&-L=6ER(&QO9R!D92!S:6YC<F]N:7IAY^-O.B`E<R(*"B,Z
M(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8X"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T
M<B`B17)R;R!A;R!O8G1E<B!C;VYT9?ID;SH@)7,B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(D5R<F\@86\@871U
M86QI>F%R(&$@<V5N:&$Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M
M86EL(&UE<W-A9V4N(@IM<V=S='(@(D5R<F\@;F$@;65N<V%G96TN(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B17)R;R!G<F%V86YD;R`G)7,G
M+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B17-T]&YI
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(D5T:?-P
M:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI
M8R(*;7-G<W1R("+)=&YI8V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R(")%=7)O<&$B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0S"FUS9VED(")%=F5R>2`Q-2!M:6YU
M=&5S(@IM<V=S='(@(D-A9&$@,34@;6EN=71O<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.3,*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R
M(")#861A(#(@;6EN=71O<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-#`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B179E<GD@,S`@
M<V5C;VYD<R(*;7-G<W1R(")#861A(#,P('-E9W5N9&]S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDT
M"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B0V%D82`U(&UI;G5T
M;W,B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R(")#861A($-O;F5XXV\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0T"FUS9VED(")%=F5R>2!H
M86QF(&AO=7(B"FUS9W-T<B`B0V%D82!M96EA(&AO<F$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S0Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3(*
M;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")#861A(&UI;G5T;R(*"B,Z
M('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE
M('9A;'5E<SHB"FUS9W-T<B`B5F%L;W)E<R!D92!E>&5M<&QO.B(*"B,Z(&%D
M;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M
M:6XO<W%L<VAE;&PN<&AP.C$R-PIM<V=I9"`B17AE8W5T92(*;7-G<W1R(")%
M>&5C=71A<B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z-C$T"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B17AP86YD:7(B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS9VED(")%
M>'!A;F0@4VED96)A<B(*;7-G<W1R(")%>'!A;F1I<B!"87)R82!,871E<F%L
M(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I
M9"`B17AP96-T960@)RDG(@IM<V=S='(@(D5S<&5R861O("<I)R(*"B,Z(&9R
M86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C
M=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B
M17-P97)A9&\@=6UA('!A;&%V<F$@;W4@=&5R;6\@9&4@<&5S<75I<V$@96YT
M<F4@87-P87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R(")$871A(&1E($5X
M<&ER8>?C;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C<W"FUS9VED(")%>'!O;F5N="(*;7-G<W1R(")%>'!O96YT92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*
M;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(D-O<B!D;R!P<FEM96ER;R!P;&%N
M;R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G:60@(D944"!U
M<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B0V]N9FEG=7)AY^-O(&1E(&5N=FEO
M(&1E(&%R<75I=F]S($944"(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S
M<6PN<&AP.C(R-0IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC
M97,N(@IM<V=S='(@(D9A;&AA(&]B=&5N9&\@<')E9F5RZFYC:6%S+B(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C
M="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B1F%L:&$@86\@8V]N96-T87(@
M86\@<V5R=FED;W(@3$1!4"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M
M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V
M97(N(@IM<V=S='(@(D9A;&AA(&%O(&-O;F5C=&%R(&%O('-E<G9I9&]R(%--
M0BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Q-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS
M9W-T<B`B1F%L:&$@86\@8V]P:6%R(&1E(%PB)7-<(BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C<R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(D9A;&AA(&%O(&-O
M<&EA<B!P87)A(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A
M<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O
M;FYE8W1I;VXN(@IM<V=S='(@(D9A;&AA(&%O(&-R:6%R('5M82!N;W9A(&-O
M;F5XXV\@4T%33"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4P
M,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(D9A
M;&AA(&%O(&UO=F5R('!A<F$@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z-#8U"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T
M;R!R971R:65V93H@)7,B"FUS9W-T<B`B1F%L:&$@86\@;V)T97(Z("5S(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G
M:60@(D9A:7(B"FUS9W-T<B`B2G5S=&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&
M86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B26QH87,@1F%L
M:VQA;F0@*$UA;'9I;F%S*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E($ES
M;&%N9',B"FUS9W-T<B`B26QH87,@1F%R;V4B"@HC.B!F<F%M97=O<FLO0TQ)
M+T-,22YP:'`Z,C,X"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B17)R
M;R!&871A;#HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS9W-T<B`B1F%X(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,U,0IM<V=I9"`B1F%X97,B"FUS9W-T<B`B
M1F%X97,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B1F5V97)E:7)O(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C<*;7-G:60@(D9E96QS($QI:V4B"FUS
M9W-T<B`B4V5N<V'GXV\@5.ER;6EC82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,C`*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R(")3
M96YS8>?C;R!TZ7)M:6-A.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B
M4&%N8V%D87,@9&4@0VAU=F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G
M<W1R(").979E($9R86-A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3DT.`IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(DUA=')I>B!D;R!C
M86UP;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S(*;7-G:60@
M(D9I9VQE="!#05!40TA!(@IM<V=S='(@(D9I9VQE="!#05!40TA!(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-@IM<V=I9"`B1FEG;&5T(&9O
M;G0B"FUS9W-T<B`B1F]N=&4@1FEG;&5T(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B
M1FEJ:2(*;7-G<W1R(")&:6II(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C4U"FUS9VED(")&:6QE(@IM<V=S='(@(F%R<75I=F\B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(D-O;G1A9V5M(&1E($%R
M<75I=F]S.B`E<R!A<G%U:79O(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL
M97,B"FUS9W-T<B`B0V]N=&%G96T@9&4@07)Q=6EV;W,Z("5S(&%R<75I=F]S
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P.0IM<V=I9"`B1FEL
M92!-86YA9V5R(@IM<V=S='(@(D=E<F5N8VEA9&]R(&1E($%R<75I=F]S(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*;7-G:60@(D9I;&4@3F%M
M92(*;7-G<W1R(").;VUE(&1O($%R<75I=F\B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.3@T"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R
M(")396QEY^-O(&1E(&%R<75I=F\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#DP"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R(")%;G9I;R!D
M92!A<G%U:79O(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z
M.#@U"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T
M<B`B16YV:6\@9&4@87)Q=6EV;W,@;N-O(.D@<W5P;W)T861O+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY,0IM<V=I9"`B1FEL=&5R<R(*;7-G
M<W1R(")&:6QT<F]S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G
M<W1R(")&:6YLXFYD:6$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS
M9VED(")&:7)S="!(86QF(@IM<V=S='(@(E!R:6UE:7)A($UE=&%D92(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*
M;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T<B`B4')I;65I<F\@475A<G1O
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U
M-0IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(E1A>&$@9FEX82(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S`*;7-G:60@
M(D9L:7`B"FUS9W-T<B`B1VER87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G
M<W1R(")$:7-P;W-IY^-O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R(").Z79O82(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C,W(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R
M("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(E!A<W1A("5S(&[C;R!E>&ES
M=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(D-O<B!D82!&;VYT92(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G
M<W1R(")#;VUI9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T
M:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(E!A<F$@;F%V96=A
M9&]R97,@<75E(&[C;R!S=7!O<G1A;2!I;6%G96YS(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-#$*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@
M(E!R979I<^-O("A4048I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C<R"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE
M(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT
M.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I
M9&4@8FQO8VLI(@IM<V=S='(@(B(*(D1I87,@4')E=FES=&]S("A.;W1E('%U
M92!A('!R979I<^-O(')E=&]R;F%D82!E>&EB92!A;6)O<R!D:6$@92!N;VET
M93L@=6T@(@HB;OIM97)O(&UU:71O(&%L=&\@87%U:2!P;V1E(')E<W5L=&%R
M(&5M('5M(&)L;V-O(&5X=&5N<V\I(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G
M<W1R(")%<W%U96-E=2!A('-E;FAA/R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-C0*;7-G:60@(D9O<FUS(@IM<V=S='(@(D9O<FUU;.%R:6]S
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE
M(@IM<V=S='(@(E-O<G1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY
M"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B5&EP;R!D92!3;W)T92(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B1F]R='5N97,B
M"FUS9W-T<B`B4V]R=&5S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y
M"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(E-O<G1E<R`R(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U-0IM<V=I9"`B1F]R=6US(@IM<V=S
M='(@(D;S<G5N<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3$*
M;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(E)E9&ER96-I;VYA;65N=&]S(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM
M<V=I9"`B1G(B"FUS9W-T<B`B4V5X(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM
M<V=S='(@(E%U861R;W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4B"FUS
M9W-T<B`B1G)A;N=A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R(")&<F%N
MYV$@365T<F]P;VQI=&%N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'
M=6EA;F$B"FUS9W-T<B`B1W5I86YA($9R86YC97-A(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*
M;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B4&]L:6[I<VEA($9R
M86YC97-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@
M5&5R<FET;W)I97,B"FUS9W-T<B`B5&5R<FET\W)I;W,@1G)A;F-E<V5S(&1O
M(%-U;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`B1&4B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C,W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-#D*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-0IM
M<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(D1O*&$I(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*;7-G:60@(D9U;&P@1&5S8W)I<'1I
M;VXB"FUS9W-T<B`B1&5S8W)IY^-O($-O;7!L971A(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U
M;&P@36]O;B(*;7-G<W1R("),=6$@0VAE:6$B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV
M,`IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(DYO;64@0V]M<&QE=&\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R(")'86+C;R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T
M<B`B1V%L97)I82!D92!O;F1E(&]B=&5R(&%S(&EM86=E;G,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(D=A;&5R:6$Z(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(D?B;6)I82(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N
M97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")'97)A<B!A($-O;F9I
M9W5R8>?C;R!D92`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF
M:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R(")#\V1I
M9V\@1V5R861O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R
M(")'9?-R9VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R
M(")!;&5M86YH82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM<V=S='(@
M(D=A;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS9W-T<B`B
M1VEB<F%L=&%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-S8*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`B4')I;65I<F\@3F]M
M92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S4@=&5M<&QA
M=&5S+W!R969S+V%P<"YI;F,Z,3`*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z,3D*;7-G:60@(D=L;V)A;"!/<'1I;VYS(@IM<V=S='(@(D]PY_5E<R!'
M;&]B86ES(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3<*;7-G:60@
M(D=O(@IM<V=S='(@(DER(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P
M"FUS9VED(")';V5D96PB"FUS9W-T<B`B1V]E9&5L(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,CD*;7-G:60@(D=O;V=L
M92!-87!S(@IM<V=S='(@(D=O;V=L92!-87!A<R(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B
M4&5S<75I<V%R(&YO($=O;V=L92(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,S8*;7-G:60@(D=R87ES8V%L92(*;7-G<W1R
M(")%<V-A;&$@9&4@0VEN>F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C
M92(*;7-G<W1R(")'<NEC:6$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M-`IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(D=R96=O("A)
M4T\M.#@U.2TW*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*;7-G
M<W1R(")'<F]E;.)N9&EA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1W)E;F%D82(*
M;7-G<W1R(")'<F%N861A(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G
M:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<F'G
MXV\@9&4@1W)U<&]S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU
M.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'
M<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R(").;VUE<R!D
M92!G<G5P;W,@;N-O(&1E=F5M(&5S=&%R(&5M(&)R86YC;R(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*(D=R;W5P
M7VQD87`Z($EM<&]S<^UV96P@861I8VEO;F%R(&=R=7!O("5S+B!)<W1O(.D@
M;R!Q=64@;R!S97)V:61O<B!D:7-S93H@(@H*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C$Q."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT
M,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O
M(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%P.B!);7!O<W/M
M=F5L(&5X8VQU:7(@9W)U<&\@)7,B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE
M('1O('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%P.B!);7!O
M<W/M=F5L(&%T=6%L:7IA<B!G<G5P;R`E<R(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B
M"FUS9W-T<B`B1W)U<&]S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L;W5P
M92(*;7-G<W1R(")'=6%D86QU<&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A
M;2(*;7-G<W1R(")'=6%M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L
M82(*;7-G<W1R(")'=6%T96QA;6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*;7-G<W1R(")'=65R;G-E>2(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C(V('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(E!E<FUI<W/U97,@9&4@0V]N=FED861O(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0W,@IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S
M='(@(DQI=G)O(&1E(%9I<VET87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'=6EN
M96$B"FUS9W-T<B`B1W5I;NDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE
M82U":7-S874B"FUS9W-T<B`B1W5I;NDM0FES<V%U(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X
M"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B1W5I86YA(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.38T"FUS9VED(")(5$U,(@IM<V=S='(@(DA434PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B2%1-3$%R96$@
M<V4@;F5G82!C;W9A<F1E;65N=&4@82!E>&-L=6ER(&$@^FQT:6UA(&/I;'5L
M82!D82!L:6YH82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R
M969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM
M<V=S='(@(DA434Q!<F5A('-E(&YE9V$@8V]V87)D96UE;G1E(&$@97AC;'5I
M<B!A(/IL=&EM82!C;VQU;F$@9&$@=&%B96QA+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA4
M34Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O
M=R!I;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R96$@<V4@;F5G82!C;W9A<F1E
M;65N=&4@82!E>&-L=6ER(&$@^FQT:6UA(&QI;FAA(&1A('1A8F5L82XB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%14
M4"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&5N=&EC
M8>?C;R!(5%10(&[C;R!E;F-O;G1R861A+B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I
M9"`B2&%I=&DB"FUS9W-T<B`B2&%I=&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S
M='(@(D%L9V]R:71M;R!(87-H(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B3F5B;&EN
M82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDR,R!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.3(Q"FUS9VED(")(96%D97(B"FUS9W-T<B`B0V%B
M9>=A;&AO(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T
M+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R(")#86)EYV%L:&\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@
M27-L86YD<R(*;7-G<W1R("));&AA($AE87)D(&4@26QH87,@36-$;VYA;&0B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM
M<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R(")496UP97-T861E($9O<G1E
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@(DAE8G)E=R`H
M25-/+3@X-3DM."U)*2(*;7-G<W1R(")(96)R974@*$E33RTX.#4Y+3@M22DB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`B06QT=7)A(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X-"!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O2&5L<"YP:'`Z,3@V"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N
M<&AP.C$W('1E;7!L871E<R]H96QP+VEN9&5X+FEN8SHT"FUS9VED(")(96QP
M(@IM<V=S='(@(D%J=61A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS
M9W-T<B`B06IU9&$@9&\@961I=&]R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,W-0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(D%S<VES=&5N=&4B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B
M"FUS9W-T<B`B2&5M:7-FZ7)I;R(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN
M9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS9VED
M(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@
M(D%Q=6D@97-TX2!O(&EN[6-I;R!D;R!A<G%U:79O.B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS9VED(")(:6=H(@IM
M<V=S='(@(D%L=&$B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@
M=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*;7-G:60@(DAO
M7VUE(@IM<V=S='(@(DE?;NUC:6\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(
M;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R(")386YT82!3
MZ2`H0VED861E+45S=&%D;R!D;R!6871I8V%N;RDB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$U,SD*;7-G:60@(DAO;64B"FUS9W-T<B`B26[M
M8VEO(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$R,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`B16YD97)EYV\@4F5S
M:61E;F-I86PB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G:60@
M(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(D1I<F5T\W)I;R!097-S;V%L(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM
M<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R(")&;VYE(%)E<VED96YC:6%L(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R(")(;VYD=7)A
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(DAO
M;F<@2V]N9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-PIM<V=I
M9"`B2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E
M("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!$861O(%A-3"`E<R!I;G;A;&ED
M;R!E;F-O;G1R861O(&YA(&UE;G-A9V5M("5S(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM
M<V=S='(@(DAO<F1E+TMO;&%B.B!.96YH=6UA(&UE;G-A9V5M(&-O<G)E<W!O
M;F1E(&%O(&]B:F5T;R`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z-#,U"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O
M8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@
M(DAO<F1E+TMO;&%B.B!.96YH=6T@;V)J971O(&1O('1I<&\@)7,@9F]I(&5N
M8V]N=')A9&\@;F$@;65N<V%G96T@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$R-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@4F5M;W9I9&\@8V]M('-U8V5S<V\@)7,@7"(E<UPB(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E
M+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G
M9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!!
M(&5N9VEN92!D92!I;G1E9W)AY^-O(')E<75E<B!A(&5X=&5N<^-O(%!(4"`G
M9&]M>&UL)R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3`R"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E
M871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E
M+TMO;&%B.B!);7!O<W/M=F5L(&-R:6%R('5M82!N;W9A(.%R=F]R92!834P@
M<&%R82!O(&]B:F5T;R`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,3(T,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA
M8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B!);7!O<W/M=F5L(')E;6]V97(@)7,@7"(E<UPB.B`E<R(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#<S"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F
M;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R("(B"B)(;W)D92]+;VQA
M8CH@26UP;W-S[79E;"!O8G1E<B!A(&ED96YT:69I8V'GXV\@34E-12!P87)A
M(&$@<&%R=&4@9&\@=&EP;R`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3$Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B
M2&]R9&4O2V]L86(Z($EM<&]S<^UV96P@<VEN8W)O;FEZ87(@)7,@7"(E<UPB
M.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3,S,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H
M<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($EM<&]S
M<^UV96P@<VEN8W)O;FEZ87(@8V]M<&%R=&EL:&%M96YT;W,Z("5S(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S
M='(@(DAO<F1E+TMO;&%B.B!#;VUP87)T:6QH86UE;G1O(&1E<V-O;FAE8VED
M;R!<(B5S7"(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B3&EN
M:&$@2&]R:7IO;G1A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G
M<W1R(")-87)G96T@:&]R:7IO;G1A;"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM
M<V=S='(@(DAO<FEZ;VYT86PZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO
M=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R(")#;VUO('9O
M8^H@8VAE9V]U(&%Q=6D_("A0;W(@9F%V;W(@8V]M=6YI<75E(2DB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U
M"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/R(*;7-G<W1R(")1=6%N=&%S(&-O;'5N87,@=F]CZB!G;W-T87)I82!D
M92!M97-C;&%R/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q
M"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B
M"FUS9W-T<B`B475A;G1O<R!C86UP;W,@*&-O;'5N87,I(&5X:7-T96T_(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M
M97)G93\B"FUS9W-T<B`B475A;G1A<R!L:6YH87,@=F]CZB!G;W-T87)I82!D
M92!M97-C;&%R/R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.#D@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S<*;7-G:60@(DAU;6ED:71Y(@IM
M<V=S='(@(E5M:61A9&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C0X"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(E5M:61A9&4Z("(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S
M(@IM<V=S='(@(DAU;6]R:7-T87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU
M;F=A<GDB"FUS9W-T<B`B2'5N9W+M82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER=7,N<&AP.C$W,B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP
M:'`Z,C,U"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A
M=&EO;B!F86EL960Z("5S(@IM<V=S='(@(D9A;&AA(&%O(&-R:6%R(&-A:7AA
M('!O<W1A;"!)34%0.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU
M"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F
M86EL960Z("5S(@IM<V=S='(@(D9A;&AA(&%O(&5X8VQU:7(@8V%I>&$@<&]S
M=&%L($E-05`Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP
M:'`Z,3<Y(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N
M(&9A:6QE9#H@)7,B"FUS9W-T<B`B1F%L:&$@86\@8W)I87(@<75O=&$@9&$@
M8V%I>&$@<&]S=&%L($E-05`Z("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,R,`IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R(")%;F1E<F7G
M;R!)4"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*
M;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B16YD
M97)EYV\@25`@;N-O(&1I<W!O;NUV96PN(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET
M:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B16YD97)EYV\@25`@
M;N-O(&5S=.$@;F\@8FQO8V\@<&5R;6ET:61O($-)1%(N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED
M("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(E9I;VQAY^-O(&1O
M(&)L;W%U96EO($E0+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F
M;W)E(@IM<V=S='(@(DE?;G-I<F$@3&EN:&$@06YT97,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B27-LXFYD:6$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S@P"FUS9VED("))8V]N<R!/;FQY(@IM<V=S
M='(@(E-O;65N=&4@S6-O;F5S(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP
M.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R
M("+-8V]N97,@<&%R82`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.#$*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R("+-8V]N97,@92!T
M97AT;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3,*;7-G:60@(DED
M96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B3F]M92!D82!I9&5N=&ED861E.B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E
M8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@
M(E-E(&[C;R!F;W(@97AI8FED;R!C;W)R971A;65N=&4L("5S('!A<F$@86)R
M[2UL;R!E;2!U;6$@;F]V82!J86YE;&$N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0U.0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O
M;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C
M:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y
M+B(*;7-G<W1R("(B"B)392!V;V/J(&[C;R!VZB!N96YH=6T@[6-O;F4@86\@
M=71I;&EZ87(@;R!);G1E<FYE="!%>'!L;W)E<BP@=F]CZB!P;V1E("(*(F-H
M96-A<B!E<W1A(&-A:7AA('!A<F$@9&5S86)I;&ET87(@82!T<F%N<W!A<NIN
M8VEA(%!.1RXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3<R"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B
M=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N
M)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B
M(@HB4V4@=F]CZB!VZB!E<W1A(&UE;G-A9V5M(&UA<R!NXV\@82!I;6%G96TL
M(&$@:6UA9V5M('%U92!V;V/J('%U97(@96YV:6%R(&[C;R`B"B)P;V1E('-E
M<B!E>&EB:61A('!E;&\@<V5U(&YA=F5G861O<BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G
M:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(E!RZ2UV:7-U86QI>F'GXV\@
M9&$@26UA9V5M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R(")5
M4DP@9&$@26UA9V5M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM
M<V=S='(@(E523"!D82!);6%G96TZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G
M92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B26UA9V5M(&1A(&=A;&5R:6$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B
M26UA9V5M(&1A(&=A;&5R:6$Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3<V-0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(D5N=FEO(&1E
M($EM86=E;2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("))
M;6%G97,B"FUS9W-T<B`B26UA9V5N<R(*"B,Z('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P
M("5D(@IM<V=S='(@(DEM<&]R=&%R+"!087-S;R`E9"(*"B,Z('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM
M<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R(")#86UP;R!I;7!O<G1A9&\Z("5S
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP
M;W)T960@9FEE;&1S.B(*;7-G<W1R(")#86UP;W,@:6UP;W)T861O<SHB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(DEN7W-E
M<FER($QI;FAA($%P\W,B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O>FEP+G!H<#HQ,S0*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G
M:79E;BXB"FUS9W-T<B`B0_-D:6=O(&1E(&'GXV\@9F]R;F5C:61O(&5S=.$@
M:6YC;W)R971O+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,R"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD
M+V]R('!A<W-W;W)D+B(*;7-G<W1R(")5<W7A<FEO(&4O;W4@<V5N:&$@:6YC
M;W)R971O<RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM
M<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R
M97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)5<W7A
M<FEO(&]U(&5N9&5R9>=O(&%L=&5R;F%T:79O(&EN8V]R<F5T;W,N(%1E;G1E
M(&YO=F%M96YT92!O=2!E;G1R92!E;2`B"B)C;VYT871O(&-O;2!O(&%D;6EN
M:7-T<F%D;W(@<V4@=F]CZB!N96-E<W-I=&$@9&4@;6%I<R!A:G5D82XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS
M9VED("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B075M96YT87(@261E;G1A
MY^-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,38@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("));F1I82(*;7-G<W1R("+-;F1I
M82(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C4T('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L(%5S
M97)S(@IM<V=S='(@(E5S=>%R:6]S(&EN9&EV:61U86ES(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B26YD;V[I<VEA(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I
M9"`B26YF;R(*;7-G<W1R("));F9O<FUAY^-O(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(U.0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B
M26YF;W)M8>?C;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,3D*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM
M<V=S='(@(D[C;R!E>&ES=&5M(&]PY_5E<R!D:7-P;V[M=F5I<RXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(DEN<V5R
M:7(@0U]O;'5N82!!</-S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E<G0@26UA
M9V4B"FUS9W-T<B`B26YS97)I<B!);6%G96TB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B
M;&4B"FUS9W-T<B`B26YS97)I<B!486)E;&$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B
M($QI;FLB"FUS9W-T<B`B26YS97)I<B!,:6YK(&1A(%=E8B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM
M<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(DEN<V5R:7(@
M7T-O;'5N82!!;G1E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O
M;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B26YS97)I<B!U
M;6$@;F]V82!C;VQU;F$@87#S<R!A(&%T=6%L(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("))
M;G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`B26YS97)I<B!U;6$@;F]V82!C;VQU;F$@86YT97,@9&$@871U86PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U
M<G)E;G0@;VYE(@IM<V=S='(@(DEN<V5R:7(@=6UA(&YO=F$@;&EN:&$@87#S
M<R!A(&%T=6%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E
M9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B26YS97)I<B!U;6$@;F]V
M82!L:6YH82!A;G1E<R!D82!A='5A;"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T
M(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B
M26YS97)I<B!U;2!P87+A9W)A9F\@87#S<R!O(&%T=6%L(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS
M9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO
M9&4B"FUS9W-T<B`B26YS97)I<B!U;2!P87+A9W)A9F\@86YT97,@9&\@871U
M86PB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T
M(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("));G-E<FER('5M(&UO9&5L
M;R!A;'1E<FYA=&EV;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#(*
M;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C
M86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R(")&;W)N9>=A
M('5M(&5N9&5R9>=O(&1E(&4M;6%I;"!N;R!Q=6%L('9O8^H@<&]D92!R96-E
M8F5R(&$@;F]V82!S96YH83HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E<G0@8V5L;"!A
M9G1E<B(*;7-G<W1R("));G-E<FER(&/I;'5L82!A</-S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I
M9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(DEN<V5R:7(@8^EL=6QA
M(&%N=&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G
M<W1R("));G-E<FER(&-O;'5N82!A</-S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T
M(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B26YS97)I<B!C;VQU;F$@86YT97,B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM
M<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(DEN<V5R:7(@;65N<V%G
M96YS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM
M<V=S='(@(DEN<V5R:7(@<&%RX6=R869O(&%P\W,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@
M(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(DEN<V5R:7(@<&%R
MX6=R869O(&%N=&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*
M;7-G<W1R("));G-E<FER(&QI;FAA(&%P\W,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E
M<G0@<F]W(&)E9F]R92(*;7-G<W1R("));G-E<FER(&QI;FAA(&%N=&5S(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,PIM<V=I9"`B26YS97)T('1H
M92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*
M;7-G<W1R(")&;W)N9>=A(&$@<F5S<&]S=&$@;V)R:6=A=/-R:6$@<&%R82!A
M('!E<F=U;G1A(&1E('-E9W5R86[G83HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y
M($EM86=E(@IM<V=S='(@(DEN<V5R:7(O06QT97)A<B!);6%G96TB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED
M("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B26YS97)I<B]!;'1E<F%R
M($QI;FLB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD
M('1O('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B0W+I9&ET;R!I
M;G-U9FEC:65N=&4@<&%R82!E;G9I87(@<&%R82!A(&QI<W1A(&1E(&1I<W1R
M:6)U:>?C;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS
M9W-T<B`B0W+I9&ET;R!I;G-U9FEC:65N=&4N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3`W.0IM<V=I9"`B26YT96=E<B(*;7-G<W1R(").^FUE
M<F\@26YT96ER;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,S<*
M;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("),:7-T82!D92!);G1E:7)O
M<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R
M*2XB"FUS9W-T<B`B0T15("A#86)EYV%L:&\@9&4@1&%D;W,@9&4@57-UX7)I
M;RD@:6YVX6QI9&\N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+WII<"YP:'`Z,38W"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z
M:7`N<&AP.C$Y-`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP
M+G!H<#HR,3(*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B1&%D
M;W,@6DE0(&EN=N%L:61O<R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM<V=S='(@(D%P;&EC
M8>?C;R!I;G;A;&ED82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N
M(@IM<V=S='(@(DED96YT:69I8V'GXV\@9&\@8F%T8V@@:6YVX6QI9&$N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Y,2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,38R"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R
M,S8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,P,PHC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED
M(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R(")$861O<R!E;G9I861O<R!SXV\@
M:6YVX6QI9&]S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A
M9&1R97-S+B(*;7-G<W1R(")%;F1E<F7G;R!D92!D97-T:6YO(.D@:6YVX6QI
M9&\N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z
M,3`Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$S
M.0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR-#$*
M;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B1F]R;6%T;R!D
M;R!A<G%U:79O(.D@:6YVX6QI9&\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,38U"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G
M<W1R(").^FUE<F\@9&4@;&EC96[G82!I;G;A;&ED;RXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"FUS9VED("));G9A;&ED(&QO8V%T
M:6]N('!R;W9I9&5D+B(*;7-G<W1R("),;V-A;&EZ8>?C;R!F;W)N96-I9&$@
MZ2!I;G;A;&ED82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM
M<V=S='(@(E1I<&\@9&$@;65N<V%G96T@Z2!I;G;A;&ED;RXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G
M:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(D%P:5]I
M9"#I(&EN=N%L:61O(&]U(&5S=.$@9F%L=&%N9&\N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("))
M;G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B4&%RXFUE
M=')O<R!I;G;A;&ED;W,@;W4@9F%L=&%N9&\N(@H*(SH@861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S
M:6]N+B(*;7-G<W1R(")097)M:7-S]65S(&1O('!A:2!SXV\@:6YVX6QI9&%S
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*;7-G:60@
M(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B4&5R;6ES<_5E<R!D;R!P
M86D@<^-O(&EN=N%L:61A<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,38S"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T
M<B`B0_-D:6=O(&1O('!R;V1U=&\@Z2!I;G;A;&ED;RXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@
M(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(E!R;W1O8V]L;R!I;G;A;&ED
M;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M-S$@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM
M<V=S='(@(D1E<W1I;F%TX7)I;R!I;G;A;&ED;SH@)R5S)R(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`W-2!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$R-3@*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S
M='(@(D]B:F5T;R!C;VUP87)T:6QH861O(&EN=N%L:61O(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED
M("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R(")&;VYT92!D;R!E
M;F1E<F7G;R!I;G;A;&ED82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D
M92!D871A+B(*;7-G<W1R(")$861O<R!U;FEC;V1E(&EN=N%L:61O<RXB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4Y"FUS9VED("));G9E;G1O
M<GDB"FUS9W-T<B`B26YV96YTX7)I;R(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HV-S8*;7-G:60@(DEN=F5R="!S96QE8W1I
M;VXB"FUS9W-T<B`B26YV97)T97(@<V5L9>?C;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM
M<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("))<N,L
M(%)E</IB;&EC82!)<VSB;6EC82!D;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B
M27)A<2(*;7-G<W1R("))<F%Q=64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER
M96QA;F0B"FUS9W-T<B`B27)L86YD82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R("));&AA
M(&1O($AO;65M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(E1E
M;7!E<W1A9&5S($ES;VQA9&%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A
M96PB"FUS9W-T<B`B27-R865L(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV,C8*;7-G:60@(DES<W5E<B(*;7-G<W1R(")%;6ES<V]R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M"FUS9VED("))=&%L:6,B"FUS9W-T<B`B273A;&EC;R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,@IM<V=I9"`B271A;'DB"FUS9W-T<B`B273A;&EA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R
M"FUS9VED(")*86UA:6-A(@IM<V=S='(@(DIA;6%I8V$B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,S@*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R
M>2(*;7-G<W1R(")*86YE:7)O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*87!A
M;B(*;7-G<W1R(")*87#C;R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V
M"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(DIA<&]N
MZG,@*$E33RTR,#(R+4I0*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B2F5R<V5Y(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B2F]R9.)N:6$B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B
M2G5L>2(*;7-G<W1R(")*=6QH;R(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(DIU;FAO
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R(")*=7-T:69I8V%R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(D%L:6YH87(@
M86\@0V5N=')O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R
M(")*=7-T:69I8V%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G
M<W1R(")!;&EN:&%R(.`@17-Q=65R9&$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF
M>2!2:6=H="(*;7-G<W1R(")!;&EN:&%R(.`@1&ER96ET82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R(")#87IA<75I<W3C;R(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-C,*
M;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(DUA;G1E<B!O(&]R:6=I
M;F%L/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B477J
M;FEA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-0IM<V=I
M9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(")397)V:61O<B!K97)B97)O<R!R96IE:71O=2!A(&%U=&5N=&EC
M8>?C;RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME
M<FYE;"!.97=B:65S(@IM<V=S='(@(DYO=F%T;W,@9&4@2V5R;F5L(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@
M0W)E871I;VXB"FUS9W-T<B`B0W)I8>?C;R!D92!#:&%V92(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E
M<G!R:6YT(@IM<V=S='(@(DEM<')E<W/C;R!$:6=I=&%L(&1A($-H879E(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+
M97D@3&5N9W1H(@IM<V=S='(@(E1A;6%N:&\@9&$@0VAA=F4B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E
M(@IM<V=S='(@(E1I<&\@9&$@0VAA=F4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4Y.0IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@
M(E5S;R!D82!#:&%V92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")#:&%V92!JX2!E>&ES=&4@;F\@<V5R
M=FED;W(@9&4@8VAA=F5S('#Z8FQI8V%S+B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R(")#<FEA;N=A<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B2VER:6)A=&DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L
M92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(D-O<NEI82P@4F5P^F)L:6-A(%!O
M<'5L87(@1&5M;V-RX71I8V$@9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO
M<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R(")#;W+I:6$L(%)E</IB;&EC82!D
M82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")+;W)E86X@
M*$550RU+4BDB"FUS9W-T<B`B0V]R96%N;R`H155#+4M2*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(DMU=V%I="(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R(")1=6ER9W5I<W3C;R(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U
M="(*;7-G<W1R("),85]Y;W5T(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B261I;VUA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U
M8FQI8R(*;7-G<W1R("),86\@4F5P^F)L:6-A($1E;6]C<N%T:6-A(%!O<'5L
M87(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA
M;&8B"FUS9W-T<B`BVFQT:6UA($UE=&%D92(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HW-@IM<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T
M<B`B1V5R87(@3F]V82!396YH82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX
M-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*
M;7-G<W1R("+:;'1I;6\@475A<G1O(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-3@*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`BVFQT:6UA($%T
M=6%L:7IAY^-O.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-PHC
M+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R("+:
M;'1I;6\@;&]G:6XZ("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@
M)7,B"FUS9W-T<B`BVFQT:6UO(&QO9VEN.B`E<R#@('!A<G1I<B!D92`E<R(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-`IM<V=I9"`B3&%S="!L
M;V=I;CH@3F5V97(B"FUS9W-T<B`BVFQT:6UO(&QO9VEN.B!.=6YC82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(DQE=/1N:6$B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA=R(*;7-G<W1R
M("),96DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*;7-G<W1R("),87EO=70B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS
M9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(D1E:7AA
M('9A>FEO('-E('%U:7-E<B!S96T@8F]R9&$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G
M:60@(DQE8F%N;VXB"FUS9W-T<B`B3.UB86YO(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS9VED("),969T
M(@IM<V=S='(@(D5S<75E<F1A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S$P.`IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B0V%B9>=A;&AO
M(&5S<75E<F1O(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P-`IM
M<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`B5F%L;W)E<R!D82!E<W%U97)D
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("),97-O
M=&\B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@
M(DQE=F5L(@IM<V=S='(@(D%M;W(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI
M8F5R:6$B"FUS9W-T<B`B3&EBZ7)I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B
M3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("),[6)I82#!<F%B92!*
M86UA:&ER:7EA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C:'1E;G-T96EN
M(@IM<V=S='(@(DQI96-H=&5N<W1E:6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*
M;7-G<W1R(")#:&EV:7-C;T9R86-O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T
M<B`B0VAU=F$@1G)A8V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R
M(")#:'5V82!&<F%C82!-871U=&EN82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H="!286EN($QA=&4B
M"FUS9W-T<B`B0VAU=F$@1G)A8V$@5F5S<&5R=&EN82(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!2
M86EN(%-H;W=E<B(*;7-G<W1R("),979E<R!086YC861A<R!D92!#:'5V82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS
M9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R(")#:'5V87,@
M1G)A8V%S(&-O;2!4<F]V]65S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B
M3F5V92!&<F%C82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R(")"
M<F5V92!.979A<V-A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS
M9VED("),:6UE<FEC:R(*;7-G<W1R(")0;^IM87,B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#$X"FUS9VED("),:6YK(@IM<V=S='(@(DQI;FLB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G<W1R("),:6YK
M(&%P;VYT82!P87)A.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M-SD*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O
M<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B3&EG87(@;R!E;F1E
M<F7G;R!D92!E+6UA:6P@X"!PX6=I;F$@9&4@8V]M<&]S:>?C;R!A;R!E>&EB
M:7(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X
M="YP:'`Z,3@R"FUS9VED("),:6YK<R(*;7-G<W1R("),:6YK<R(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM
M<V=S='(@(D-O;VMI92!D;R!,:6YU>"(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@
M<V5E('1H92!F;VQD97(B"FUS9W-T<B`B3&ES=&%R("T@=7-UX7)I;R!P;V1E
M('9E<B!A('!A<W1A(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,PIM<V=I
M9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B3&ES=&%R($)A;F-O<R!D92!$
M861O<R(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4Q"FUS9VED("),
M:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(DQI<W1A<B!4\W!I8V]S(&1E($%J
M=61A(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM<V=I9"`B3&ES="!4
M86)L97,B"FUS9W-T<B`B3&ES=&%R(%1A8F5L87,B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E
M(@IM<V=S='(@(DQI<W0M07)C:&EV92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O2&5A9&5R<RYP:'`Z-3@Y"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`B
M3&ES="U(96QP(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.38*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B3&ES="U)9"(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T
M+4]W;F5R(@IM<V=S='(@(DQI<W0M3W=N97(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S
M='(@(DQI<W0M4&]S="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R
M<RYP:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("),:7-T
M+5-U8G-C<FEB92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(DQI<W0M
M56YS=6)S8W)I8F4B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM
M<V=S='(@(D$@;&ES=&%G96T@9&4@<V5S<_5E<R!F86QH;W4Z("5S(@H*(SH@
M861M:6XO<V5S<VEO;G,N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(DQI
M<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R(")!(&QI<W1A9V5M(&1E
M('5S=>%R:6]S(&9A;&AO=3H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L
M960N(@IM<V=S='(@(DQI<W1A9V5M(&1E('5S=>%R:6]S(&5S=.$@9&5S86)I
M;&ET861A+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I9"`B
M3&ET97)A='5R92(*;7-G<W1R("),:71E<F%T=7)A(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y
M"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B3&ET=>)N:6$B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C<W"FUS9VED("),
M;V%D:6YG+BXN(@IM<V=S='(@(D-A<G)E9V%N9&\N+BXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`P"FUS9VED("),;V-A;"!T:6UE.B`B
M"FUS9W-T<B`B2&]R82!L;V-A;#H@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@V"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B3&]C86QI
M>F'GXV\@92!(;W)A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-S(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4W"B,Z(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C<R
M"FUS9VED("),;V-A=&EO;B(*;7-G<W1R(")296=IXV\B"@HC.B!L;V=I;BYP
M:'`Z,3@Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,#`@=&5M<&QA
M=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B
M:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED
M("),;V<@:6XB"FUS9W-T<B`B0V]N96-T87(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC
M('-E<W-I;VXB"FUS9W-T<B`B3&]G(&1A('-E<W/C;R!D92!S:6YC<F]N:7IA
MY^-O(&%N=&5R:6]R(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M.C$Y-`IM<V=I9"`B3&]G(&]U="(*;7-G<W1R(")$97-C;VYE8W1A<B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU.0IM<V=I9"`B3&]G:6XB"FUS9W-T
M<B`B0V]N96-T87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$P"FUS
M9VED("),;V=I;B!487-K<R(*;7-G<W1R(")487)E9F%S(&1E($-O;F5XXV\B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.34*;7-G:60@(DQO9VEN
M(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S
M(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(D\@;&]G:6X@9F%L:&]U
M('!O<G%U92!S974@=7-UX7)I;R!O=2!S96YH82!E<W1A=F$@:6YC;W)R971A
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,0IM<V=I9"`B3&]G
M:6X@9F%I;&5D+B(*;7-G<W1R(")&86QH82!D92!,;V=I;BXB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y"FUS9VED("),;VYG('1E>'0B"FUS
M9W-T<B`B5&5X=&\@;&]N9V\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#@*;7-G:60@(DQO=F4B"FUS9W-T<B`B06UO<B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED("),;W<B"FUS9W-T
M<B`B0F%I>&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S
M(@IM<V=S='(@(D%L9F%B971O(&=R96=O(&5M(&UI;OIS8W5L;R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B06QF86)E
M=&\@;&%T:6YO(&5M(&UI;OIS8W5L;R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R
M(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B3OIM97)O<R!R;VUA;F]S(&5M(&UI
M;OIS8W5L;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G
M<W1R("),=7AE;6)U<F=O(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,Y.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#,W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED
M(")-32(*;7-G<W1R(")-32(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR.#,*;7-G:60@(DU/5$0B"FUS9W-T<B`B34]41"(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU43D5&
M($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(D\@86YE
M>&\@35,M5$Y%1B!NXV\@8V]N=.EM(&1A9&]S+B(*"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z
M,S<*;7-G:60@(DU31R(*;7-G<W1R(")-4T<B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G
M:60@(DUA8V%O(@IM<V=S='(@(DUA8V%O(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED
M(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B36%C961O;FEA+"!!;G1I9V$@4F5P^F)L:6-A($EU9V]S;.%V
M:6$@9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T
M<B`B36%D86=A<V-A<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0IM
M<V=I9"`B36%G:6,B"FUS9W-T<B`B3>%G:6-O(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C@S"FUS9VED(")-86EL(@IM<V=S='(@(D-O<G)E:6\B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(T"FUS9VED(")-86EL
M($%D;6EN(@IM<V=S='(@(D%D;6EN:7-T<F%D;W(@9&\@0V]R<F5I;R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R(")#<FEA<B!L:6Y?
M:RXN+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L87=I(@IM<V=S='(@(DUA
M;&%W:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B
M36%LX7-I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T
M<B`B36%L9&EV87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA;&DB"FUS9W-T
M<B`B36%L:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L=&$B"FUS9W-T<B`B
M36%L=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30*;7-G:60@(B(*
M(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA
M8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H
M('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(D=E<F5N8VEA(&$@;&ES=&$@
M9&4@8V%T96=O<FEA<R!E(&%S(&-O<F5S(&%S<V]C:6%D87,@82!E;&%S+B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,34T
M"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B36%P96%M96YT;R!-87`R-"(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#@U
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,38Y
M"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B36%P96%M96YT;R!-87!1
M=65S="(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I
M9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R(")-87!E86UE;G1O<R!G<F%V
M861O<RXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B36%RYV\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED
M(")-87)G:6XB"FUS9W-T<B`B36%R9V5M(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N
M+U5N<V5E;B!F;&%G<R(*;7-G<W1R(")-87)C87(@8V]M(&9L86=S($QI9&$O
M3N-O($QI9&$B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM
M<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B36%R8V%R(&-O;2!O=71R;W,@
M9FQA9W,@*&5X+B!);7!O<G1A;G1E+U)E<W!O;F1I9&$I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(DEL:&%S($UA
M<G-H86QL(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E(@IM<V=S
M='(@(DUA<G1I;FEC82(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M,3`S"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B0V%M<&]S(&-O
M<G)E<W!O;F1E;G1E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI
M82(*;7-G<W1R(")-875R:73B;FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-
M875R:71I=7,B"FUS9W-T<B`B36%U<NUC:6\B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A
M;&QO=V5D(&-R961I="XB"FUS9W-T<B`B0W+I9&ET;R!MX7AI;6\@<&5R;6ET
M:61O+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N
M(@IM<V=S='(@(D[Z;65R;R!MX7AI;6\@9&4@<&%R=&5S(&1A(&UE;G-A9V5M
M(&5X8V5D974N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3,*;7-G:60@
M(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")496UP97)A='5R
M82!MX7AI;6$@;F%S(/IL=&EM87,@,C0@:&]R87,Z("(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S`U"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z
M("(*;7-G<W1R(")496UP97)A='5R82!MX7AI;6$@;F%S(/IL=&EM87,@-B!H
M;W)A<SH@(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M
M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B3OIM97)O($WA>&EM;R!D
M92!";&]C;W,@9&4@4&]R=&%L(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.3`R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,C$*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(T,PIM<V=I9"`B36%X:6UU;2!L96YG=&@B
M"FUS9W-T<B`B5&%M86YH;R!MX7AI;6\B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(DUA
M:6\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@(DUA
M>6]T=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE
M9&EC:6YE(@IM<V=S='(@(DUE9&EC:6YA(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*;7-G<W1R(")-
M96UB<F]S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,@IM<V=I9"`B
M365N=2!M;V1E.B(*;7-G<W1R(")-;V1O(&1O(&UE;G4Z(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I
M9"`B365R9V4@8V5L;',B"FUS9W-T<B`B365S8VQA<B!CZ6QU;&%S(@H*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B365N<V%G96TB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S
M<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C
M97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@
M(B(*(DUE;G-A9V5M(%9E<FEF:6-A9&$@8V]M(%-U8V5S<V\@;6%S(&\@8V5R
M=&EF:6-A9&\@9&\@87-S:6YA;G1E(&[C;R!P]&1E('-E<B`B"B)V97)I9FEC
M861O+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q,`IM<V=I9"`B365S<V%G92!E>'!I<F5D+B(*;7-G<W1R(")-
M96YS86=E;2!E>'!I<F%D82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"FUS9VED(")-97-S
M86=E('1Y<&4B"FUS9W-T<B`B5&EP;R!D92!M96YS86=E;2(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G<W1R
M(")#;&EM82!-971A<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G
M:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D)L;V-O
M($UE=&%R(&[C;R!D:7-P;V[M=F5L+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3$Y"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R("(B"B)";&]C;R!-971A<B!NXV\@9&ES<&]N[79E;"X@1&5T
M86QH97,@9F]R86T@9W)A=F%D;W,@96T@;&]G('!A<F$@;R`B"B)A9&UI;FES
M=')A9&]R+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3,*
M;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B3R!-
M971A<D1"(&[C;R!E<W3A(&-O;F5C=&%D;RXB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R(")-Z71O
M9&\B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q(&9R86UE
M=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(DWI=&]D
M;R`G)7,G(&[C;R!E<W3A(&1E9FEN:61O(@H*(SH@9G)A;65W;W)K+U)00R]2
M4$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO
M="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<R(*;7-G<W1R(")-Z71O9&\@
M;N-O(&1E9FEN:61O+B!-Z71O9&\@8VAA;6%D;SH@)7,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HX
M,@IM<V=I9"`B365T<FEC(@IM<V=S='(@(DWI=')I8V$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R(")-Z7AI8V\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G
M<W1R(")-:6-R;V[I<VEA+"!%<W1A9&]S($9E9&5R861O<R!D82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@IM
M<V=I9"`B36ED9&QE(@IM<V=S='(@(DUE:6\B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM
M<V=S='(@(E1I<&\@36EM92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$W
M"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B5&5M
M<&5R871U<F$@;>UN:6UA(&YA<R#Z;'1I;6%S(#(T(&AO<F%S.B`B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,P.0IM<V=I9"`B36EN('1E;7`@;&%S="`V
M(&AO=7)S.B`B"FUS9W-T<B`B5&5M<&5R871U<F$@;>UN:6UA(&YA<R#Z;'1I
M;6%S(#8@:&]R87,Z("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE
M="!E>'!I<F5D(@IM<V=S='(@(DED861E(&WM;FEM82!D82!S96YH82!A:6YD
M82!NXV\@97AP:7)O=2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,S,*;7-G:60@(DUI<G)O<B(*;7-G<W1R(")%<W!E;&AO
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL
M86YE;W5S(@IM<V=S='(@(D1I=F5R<V]S(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG
M(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(E!A8V]T92!0
M14%2($A45%!?4F5Q=65S="!F86QT86YD;RXB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN
M(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U
M<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@HB0V]N9FEG=7)A
MY^-O(&9A;'1A;F1O+B!6;V/J('1E;2!Q=64@9V5R87(@96QA(&%G;W)A('-E
M('9O8^H@<75E<B!U=&EL:7IA<B`B"B)E<W1A(&%P;&EC8>?C;RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*
M;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B240@9&$@;65N
M<V%G96T@9F%L=&%N9&\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER
M960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(E!A8V]T92!O8G)I9V%T
M\W)I;R!014%2($UA:6P@9F%L=&%N9&\N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG
M('-E<W-I;VX@240N(@IM<V=S='(@(DE$(&1A('-E<W/C;R!F86QT86YD;RXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V
M"FUS9VED(")-;R(*;7-G<W1R(")396<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-S8*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@(D-O<G)E
M:6\@3?-V96PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV.0IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B36]D97)A<B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,PHC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U"FUS9VED(")-;V1I9FEE9"!$
M871E(@IM<V=S='(@(D1A=&$@36]D:69I8V%D82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B
M36]D:69Y(%523"(*;7-G<W1R(")!;'1E<F%R(%523"(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<T"FUS9VED(")-;V1U;'5S(@IM
M<V=S='(@(DWS9'5L;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V82P@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B36]L9&]V82P@4F5P^F)L:6-A(&1A(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B3?1N86-O(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R(")-;VYG\VQI
M82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.#@*;7-G:60@(DUO
M;G1H(&%N9"!Y96%R(@IM<V=S='(@(DWJ<R!E(&%N;R(*"B,Z(&9R86UE=V]R
M:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H
M;'DB"FUS9W-T<B`B365N<V%L;65N=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@
M(DUO;G1S97)R870B"FUS9W-T<B`B36]N='-E<G)A="(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O
M;B!0:&%S97,B"FUS9W-T<B`B1F%S97,@9&$@3'5A(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,3DV(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N
M9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R(")-
M86ES(&-A;7!O<R!E;F-O;G1R861O<R!N82!L:6YH82`E9"!Q=64@;R!N^FUE
M<F\@97-P97)A9&\@)60N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O
M(@IM<V=S='(@(DUA<G)O8V]S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R
M(")'<F%N9&4@4&%R=&4@3&EM<&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G
M<W1R(")'<F%N9&4@4&%R=&4@3G5B;&%D;R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB
M"FUS9W-T<B`B1W)A;F1E(%!A<G1E($5N<V]L87)A9&\B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T.`IM<V=I9"`B
M36]V92!$;W=N(@IM<V=S='(@(DUO=F5R($%B86EX;R(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4R"FUS9VED(")-
M;W9E($QE9G0B"FUS9W-T<B`B36]V97(@X"!%<W%U97)D82(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4V"FUS9VED
M(")-;W9E(%)I9VAT(@IM<V=S='(@(DUO=F5R(.`@1&ER96ET82(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0T"FUS
M9VED(")-;W9E(%5P(@IM<V=S='(@(DUO=F5R($%C:6UA(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V
M92!D;W=N(@IM<V=S='(@(D%B86EX;R(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU,C,*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V92!U<"(*;7-G<W1R
M(")!8VEM82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G
M<W1R(")-;^=A;6)I<75E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$X.`IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S
M='(@(DQI<W1A<R!D92!S96QEY^-O(&1E(&WZ;'1I<&QO<R!N[79E:7,B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U-@IM
M<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@(DUA<&%S($EN9VQE<V5S
M($UU;'1I;6%P(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-@IM
M<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(E-E;&7GXV\@;?IL
M=&EP;&$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`R"FUS9VED
M(")->2!!8V-O=6YT(@IM<V=S='(@(DUI;FAA($-O;G1A(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T
M:6]N(@IM<V=S='(@(E-U87,@26YF;W)M8>?U97,B"@HC.B!S97)V:6-E<R]P
M;W)T86PO:6YD97@N<&AP.C0U"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B
M365U(%!O<G1A;"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HT,PIM
M<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R(")-974@3&%Y;W5T(&1E
M(%!O<G1A;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R
M(")":7)MXFYI82(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T
M<B`B3L-/+"!%=2!.PT\@0V]N8V]R9&\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,3$@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R(").;VUE(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@(DYA;>UB:6$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(DYA=7)U(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R(").97!A;"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B2&]L86YD82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R
M(")!;G1I;&AA<R!(;VQA;F1E<V%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E($)A<V4@55),(@IM
M<V=S='(@(E523"!"87-E(&1O($YE='-C87!E(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E($-!(%)E
M=F]C871I;VX@55),(@IM<V=S='(@(E523"!D92!2979O9V'GXV\@9&4@0T$@
M9&\@3F5T<V-A<&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R
M(")54DP@9&4@<&]L[71I8V%S(&1E($-!(&1O($YE='-C87!E(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C
M87!E(%)E;F5W86P@55),(@IM<V=S='(@(E523"!D92!296YO=F'GXV\@9&\@
M3F5T<V-A<&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X,PIM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B
M55),(&1E(%)E=F]G8>?C;R!D;R!.971S8V%P92(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P92!34TP@
M<V5R=F5R(&YA;64B"FUS9W-T<B`B3F]M92!D;R!S97)V:61O<B!34TP@9&\@
M3F5T<V-A<&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X.`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G
M<W1R(")#;VUE;G3A<FEO(&1O(&-E<G1I9FEC861O(&1O($YE='-C87!E(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@
M(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B5&EP;R!D92!C
M97)T:69I8V%D;R!D;R!.971S8V%P92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR-3,*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`B4F5D92(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S,Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*
M;7-G:60@(DYE=F5R(@IM<V=S='(@(DYU;F-A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS
M9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(DYO=F$@0V%L963T;FEA(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R(").;W9A($-A=&5G;W)I
M82(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H
M<#HX,0HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP
M:'`Z.#<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N
M<&AP.CDW"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS
M+G!H<#HQ,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@
M)7,B"FUS9W-T<B`B3F]V82!-96YS86=E;2!P87)A("5S(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G<W1R("),=6$@
M3F]V82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*
M;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(DYO=F\@
M57-UX7)I;R`H;W!C:6]N86PI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(").97<@
M6F5A;&%N9"(*;7-G<W1R(").;W9A(%IE;.)N9&EA(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C,W"FUS9VED(").97<@<&%S<W=O<F0B"FUS
M9W-T<B`B3F]V82!S96YH82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L
M+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I
M;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R(").;W9A('-E;FAA(&5X<&ER87+A
M(&5M("5X+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU,@IM
M<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"XB"FUS9W-T<B`B07,@
M;F]V87,@<V5N:&%S(&[C;R!SXV\@:6=U86ES+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD
M;W<@*%]B;&%N:RDB"FUS9W-T<B`B3F]V82!J86YE;&$@*%]B;&%N:RDB"@HC
M.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Y,0IM<V=I9"`B
M3F5W<R(*;7-G<W1R(").;W3M8VEA<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS,#<*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B1W)U<&]S
M(&1E($YO=.UC:6%S(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z
M,34@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,C4*;7-G:60@(DYE>'0B"FUS9W-T<B`B4'+S>&EM82(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R
M(")0<O-X:6UA<R`T($9A<V5S(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HS-C8@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S`*
M;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R(")0<O-X:6UA<R!O<.?U97,B
M"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,PIM<V=I9"`B3F5X
M=#XB"FUS9W-T<B`B4'+S>&EM83XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI
M8V%R86=U82(*;7-G<W1R(").:6-A<N%G=6$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G
M:60@(DYI9V5R(@IM<V=S='(@(DYI9V5R(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED
M(").:6=E<FEA(@IM<V=S='(@(DYI9^ER:6$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S8Y"FUS9VED(").:6=H="(*;7-G<W1R(").;VET
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3FEU92(*;7-G<W1R(").:75E(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-`IM
M<V=I9"`B3F\B"FUS9W-T<B`B3N-O(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E
M='5P+V1I9F8N:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A
M=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R(").
M96YH=6T@9&%D;R!D92!C;VYF:6=U<F'GXV\@9&ES<&]N[79E;"!P87)A(&5X
M:6)I<B!A<R!D:69E<F5NYV%S+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<BYP:'`Z,3`V"FUS9VED(").;R!A=F%I;&%B;&4@<W1R
M871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R(").96YH=6UA
M(&5S=')A=.EG:6$@9&ES<&]N[79E;"!P87)A(&-R:6%R(&EM86=E;G,@25-/
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(DYE
M;FAU;2!M;V1E;&\@9&4@8F%T8V@N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,#$*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HS.#4*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT,#<*;7-G:60@(DYO(&)L
M;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@
M(DYE;FAU;2!B;&]C;R!E>&ES=&4@;F$@<&]S:>?C;R!S;VQI8VET861A(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@
M8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B3F5N:'5M(&YO;64@9&4@86=E;F1A(&9O<FYE8VED;R!P
M87)A(&$@875T96YT:6-AY^-O($U#04PN(@H*(SH@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z-30*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`B3F5N:'5M82!A
M;'1E<F'GXV\N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E
M<FUI<W-I;VXN(@IM<V=S='(@(DYE;FAU;2!S=6)O<F1I;F%D;R!P;V1E('-E
M<B!A9&EC:6]N861O(&$@97-T82!P97)M:7-SXV\N(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ-CD@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HU,#@*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S8X"B,L('!H<"UF
M;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B3F5N:'5M82!I;F9O<FUAY^-O(&1E
M(&-O;F9I9W5R8>?C;R!E<W!E8VEF:6-A9&$@<&%R82`E<RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U-0IM<V=I9"`B3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N(@IM<V=S
M='(@(DYE;FAU;6$@:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@97-P96-I
M9FEC861A('!A<F$@1E10(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C8W,@IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(DYE;FAU;6$@:6YF
M;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@97-P96-I9FEC861A('!A<F$@4U%,
M(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(U
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R(").96YH=6UA(&EN9F]R;6'G
MXV\@9&4@8V]N9FEG=7)AY^-O(&5S<&5C:69I8V%D82!P87)A(%-13"U&:6QE
M(%9&4RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R(").
M96YH=6T@8W+I9&ET;R!R97-T86YT92XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN
M871I;VX@<W5P<&QI960N(@IM<V=S='(@(DYE;FAU;2!D97-T:6YO(&9O<FYE
M8VED;RXB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,#,*
M;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B3F5N:'5M(&%R<75I
M=F\@96YV:6%D;R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I
M9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(DYE;FAU;2#M8V]N92!E;F-O
M;G1R861O+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,38@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3,P"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(DYE
M;FAU;6$@;&]C86QI>F'GXV\@8V]N9FEG=7)A9&$N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$U-PIM<V=I9"`B3F\@;&]C871I;VX@<')O
M=FED960N(@IM<V=S='(@(DYE;FAU;6$@;&]C86QI>F'GXV\@8V]N9FEG=7)A
M9&$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S,*;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@
M(DYE;FAU;6$@;65N<V%G96T@9F]R;F5C:61A+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N
M86UE('-P96-I9FEE9"XB"FUS9W-T<B`B3F5N:'5M(&YO;64@97-P96-I9FEC
M861O+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R
M(").96YH=6T@;OIM97)O(&5S<&5C:69I8V%D;RXB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*
M;7-G<W1R(")396T@<V]R=&5S(&]F96YS:79A<R(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").96YH=6UA
M('-E;FAA(&9O<FYE8VED82!P87)A(&$@875T96YT:6-AY^-O($A45%`N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(").96YH=6UA('-E;FAA(&9O<FYE8VED82!P87)A(&$@875T96YT
M:6-AY^-O($E-05`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H
M<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").96YH=6UA('-E;FAA(&9O<FYE
M8VED82!P87)A(&$@875T96YT:6-AY^-O($ME<F)E<F]S+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<@9G)A;65W;W)K+T%U=&@O075T
M:"]L;V=I;BYP:'`Z.#0*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP
M.C<U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(DYE;FAU;6$@<V5N:&$@9F]R;F5C:61A
M('!A<F$@82!A=71E;G1I8V'GXV\@3&]G:6XN(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]P87-S=V0N<&AP.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F5N
M:'5M82!S96YH82!F;W)N96-I9&$@<&%R82!A(&%U=&5N=&EC8>?C;R!005-3
M5T0N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C@T"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R(").96YH=6UA('-E;FAA(&9O<FYE8VED82!P87)A(&$@875T
M96YT:6-AY^-O(%--0BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C$R.#<*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@
M8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S
M87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*
M(DYE;FAU;2!P871H('!A<F$@;R!B:6[A<FEO(&1O($]P96Y34TP@9F]I(&9O
M<FYE8VED;RX@3R!B:6[A<FEO(&1O($]P96Y34TP@Z2`B"B)N96-E<W/A<FEO
M('!A<F$@;6%N:7!U;&%R(&]S(&1A9&]S(%!+0U,@,3(N(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN
M9R!S:6=N=7!S+B(*;7-G<W1R(").96YH=6T@8V%D87-T<F\@<&5N9&5N=&4N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C<V-@IM<V=I9"`B3F\@<75O
M=&$@<V5T+B(*;7-G<W1R(")1=6]T82!NXV\@8V]N9FEG=7)A9&$N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M,PIM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`B4V5M(&QI;FAA<R(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0X,@IM<V=I9"`B3F\@<V5P87)A
M=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B3F5N:'5M('-E<&%R861O<B!F;VD@
M97-P96-I9FEC861O+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@
M(E-E;2!L861O<R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@W
M"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T<B`B07)Q=6EV;R!I;F5X:7-T
M96YT92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C8*;7-G
M:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H
M92XB"FUS9W-T<B`B3F5N:'5M(&1I<F5T\W)I;R!T96UP;W+A<FEO(&1I<W!O
M;NUV96P@<&%R82!O(&-A8VAE+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M92!A;F0O
M;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B3F5N:'5M('5S=>%R:6\@92]O
M=2!S96YH82!F;W)N96-I9&]S+B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM
M;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI9"!834P@9&%T82!R971U<FYE
M9"(*;7-G<W1R(").96YH=6T@9&%D;R!834P@=N%L:61O(')E=&]R;F%D;R(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-S(*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX,@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DS"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#$P"FUS
M9VED(").;R!V86QU97,B"FUS9W-T<B`B4V5M('9A;&]R97,B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD
M(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B(@HB3F5N:'5M('9E<G/C;R!E;F-O;G1R861A
M(&YA(&-O;F9I9W5R8>?C;R!O<FEG:6YA;"X@1V5R92!N;W9A;65N=&4@82`B
M"B)C;VYF:6=U<F'GXV\N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R
M.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I
M;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB3F5N
M:'5M82!V97)SXV\@96YC;VYT<F%D82!N82!S=6$@8V]N9FEG=7)AY^-O+B!'
M97)E(&YO=F%M96YT92!A(&-O;F9I9W5R8>?C;RXB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E
M9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"FUS9VED(").;VYE(@IM<V=S='(@
M(DYE;FAU;6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@
M(DYE;FAU;6$@*'5S;R!I;7!L[6-I=&\I(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#@*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@
M(D[S<F1I8V\@*$E33RTX.#4Y+3$P*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B
M3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B26QH82!.;W)F;VQK(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I
M9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")(96UI<V;I<FEO($YO
M<G1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES
M;&%N9',B"FUS9W-T<B`B26QH87,@36%R:6%N82!D;R!.;W)T92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(DYO<G5E9V$B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,0IM<V=I9"`B3F]T
M($%F=&5R(@IM<V=S='(@(D[C;R!!</-S(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!"969O<F4B"FUS9W-T
M<B`B3N-O($%N=&5S(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M-#$U"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B3N-O(.D@=6T@
M9&ER973S<FEO(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX-`HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY
M-0HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G:60@(DYO
M="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B3N-O($EM<&QE;65N=&%D;RXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X"FUS
M9VED(").;W0@<V5T(@IM<V=S='(@(D[C;R!C;VYF:6=U<F%D;R(*"B,Z(&9R
M86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,30U
M"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP
M:'`Z,38P"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<BYP:'`Z,3<U"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<BYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,V(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HQ.3,*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(P."!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-3(@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V.0HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,C@U(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,#$*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C,Q-B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S,S
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS-C8@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C0R-@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3`U(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HU-S0*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C4Y,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-C8Y"FUS9VED(").;W0@<W5P
M<&]R=&5D+B(*;7-G<W1R(").XV\@<W5P;W)T861O+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG+VAO;VMS
M+G!H<"YD:7-T.C$P,#4*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X
M,`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B06YO=&'G]65S(@H*(SH@<V5R=FEC
M97,O;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R
M;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B3F%D82!P87)A(&5X:6)I<BP@=F]L
M=&4N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(DYO=F5M8G)O(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`U,`IM<V=I9"`B3G5M8F5R(@IM<V=S
M='(@(D[Z;65R;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,CD*
M;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(D[Z;65R;R!D
M92!C87)A8W1E<F5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W
M,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(W"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T-#D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S
M='(@(D[Z;65R;R!D92!C;VQU;F%S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,W,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#<@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S
M(@IM<V=S='(@(D[Z;65R;R!D92!L:6YH87,B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R
M<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@
M;&ES="XB"FUS9W-T<B`B3OIM97)O(&[C;R!E<W!E8VEF:6-A9&\@<&%R82!A
M='5A;&EZ8>?C;R!N82!L:7-T82!D92!D:7-T<FEB=6GGXV\N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/
M2R(*;7-G<W1R(")/2R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HX-S$*;7-G:60@(D]B:F5C="(*;7-G<W1R(")/8FIE=&\B
M"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J
M96-T($-R96%T;W(B"FUS9W-T<B`B0W)I861O<B!D;R!/8FIE=&\B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`X"FUS9VED(")/8W1A;"(*;7-G
M<W1R(")/8W1A;"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(D]U='5B<F\B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL
M=&5R(@IM<V=S='(@(D9I;'1R;R!O9F5N<VEV;R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS,C@*;7-G:60@(D]F9FEC92(*;7-G<W1R(")%<V-R
M:73S<FEO(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS
M9VED(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N
M(@IM<V=S='(@(E-E;FAA<R!A;G1I9V$@92!N;W9A(&1E=F5M('-E<B!D:69E
M<F5N=&5S+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@IM
M<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(E-E;FAA(&%N=&EG82(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A
M<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R(")396YH82!A;G1I9V$@
M;N-O(&5S=.$@8V]R<F5T82XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB
M"FUS9W-T<B`B3VWC(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@
M<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(E-O;65N=&4@<V5R=FED;W)E<R!)
M34%0('-U<&]R=&%M('!A<W1A<R!C;VUP87)T:6QH861A<RXB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O
M<G1U;F5S(@IM<V=S='(@(E-O;65N=&4@<V]R=&5S(&]F96YS:79A<R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DW-0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S<R!A
M;&QO=V5D+B(*;7-G<W1R(")3;VUE;G1E('5M(&5N9&5R9>=O(&1E(&4M;6%I
M;"!P97)M:71I9&\N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C8U
M"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R
M871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S
M:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"B)3;VUE;G1E(&\@<')O<')I
M973A<FEO(&]U(&\@861M:6YI<W1R861O<B!D;R!S:7-T96UA('!O9&5M(&%L
M=&5R87(@87,@(@HB<&5R;6ES<_5E<R!D92!P<F]P<FEE9&%D92!O=2!P<F]P
M<FEE=.%R:6\@9&4@=6T@8V]M<&%R=&EL:&%M96YT;R(*"B,Z(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C,Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C0P"FUS9VED
M(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")!8G)I<B!E;2!U;6$@
M;F]V82!J86YE;&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A
M8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B17)R
M;R!D;R!/<&5N4U-,.B!.XV\@<'5D92!E>'1R86ER(&1A9&]S(&1A('!A<G1E
M(&%S<VEN861A(%,O34E-12XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@
M;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B06)R92!E<W1E(&QI;FL@
M96T@=6UA(&YO=F$@:F%N96QA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(E-I<W1E;6$@
M3W!E<F%C:6]N86PB"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(D]PY_5E<R(*"B,Z('-E<G9I
M8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R(")/
M<.?U97,@9&4@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B3&ES
M=&$@3W)D96YA9&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(D]R9V%N:7IA
MY^-O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*
M;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B56YI9&%D92!/
M<F=A;FEZ86-I;VYA;"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M,S0*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B3W)G86YI>F%N9&\B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P
M;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B36]D96QO(&]R:6=I;F%L(&1E
M(&%P;&EC8>?C;R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H
M<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS
M9W-T<B`B36]D96QO(&]R:6=I;F%L(&5M("5S.B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT
M"FUS9VED(")/=&AE<B(*;7-G<W1R(")/=71R;R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Y"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,38@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$R-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-#0*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S
M='(@(D]U=')A<R!);F9O<FUAY_5E<R(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@
M(E!E<FUI<W/U97,@9&\@4')O<')I973A<FEO(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC871I;VX@
M:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B075T96YT:6-AY^-O(%!!32!N
MXV\@97-TX2!D:7-P;V[M=F5L+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K
M96YD(@IM<V=S='(@(D-O;F5C=&]R(%!%05(Z.DUA:6PB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<V"FUS9VED(")01U`@1&EG:71A
M;"!3:6=N871U<F4B"FUS9W-T<B`B07-S:6YA='5R82!$:6=I=&%L(%!'4"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,C(*;7-G:60@
M(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R(")$861O<R!#<FEP=&]G<F%F
M861O<R!C;VT@4$=0(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3,W-`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B0VAA=F4@
M4/IB;&EC82!01U`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,S4V"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S
M='(@(D1A9&]S($%S<VEN861O<R]#<FEP=&]G<F%F861O<R!C;VT@4$=0(@H*
M(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"FUS9VED(")02%`@0V]D92(*;7-G
M<W1R(")#\V1I9V\@4$A0(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS
M9VED(")02%`@4VAE;&PB"FUS9W-T<B`B3&EN:&$@9&4@0V]M86YD;R!02%`B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM
M<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R(")#:'5V82!&<F%C82!697-P
M97)T:6YA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S@*;7-G:60@(E!-(%)A:6XB"FUS9W-T<B`B0VAU=F$@5F5S<&5R=&EN
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y
M"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(D-H=79A<R!697-P97)T:6YA
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P
M"FUS9VED(")032!3;F]W(@IM<V=S='(@(DYE=F4@5F5S<&5R=&EN82(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED
M(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B3F5V87-C82!697-P97)T:6YA
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*
M;7-G:60@(E!-(%-U;B(*;7-G<W1R(").979E(%9E<W!E<G1I;F$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B
M4$T@5"U3=&]R;7,B"FUS9W-T<B`B5')O=F]A9&%S(%9E<W!E<G1I;F%S(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W-`IM<V=I9"`B4$]325@@97AT
M96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B17-TX2!F86QT86YD;R!A(&5X
M=&5N<^-O(%!/4TE8(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0
M(%-H96QL(@IM<V=S='(@(DQI;FAA(&1E($-O;6%N9&\@4%](4"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*
M;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B36%R9V5M(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY
M"FUS9VED(")086MI<W1A;B(*;7-G<W1R(")087%U:7-TXV\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`Q"FUS9VED(")086QA=2(*;7-G<W1R(")086QA=2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B
M"FUS9W-T<B`B4&%L97-T:6YO+"!497)R:73S<FEO($]C=7!A9&\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G<W1R(")086YA;>$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B4.%P
M=6$@3F]V82!'=6ENZ2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y
M(@IM<V=S='(@(E!A<F%G=6%I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T
M<B`B4&%R8VEA;&UE;G1E($YU8FQA9&\B"@HC.B!A9&UI;B]U<V5R+G!H<#HS
M-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#(R"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PHC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(U"FUS9VED(")087-S=V]R9"(*;7-G
M<W1R(")396YH82(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX
M,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S
M='(@(E-E;FAA(&%L=&5R861A(&-O;2!S=6-E<W-O+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,PIM<V=I9"`B4&%S<W=O<F0@
M:6YC;W)R96-T(@IM<V=S='(@(E-E;FAA(&EN8V]R<F5T82(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D
M(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(E-E;FAA(&]B<FEG873S<FEA('!A<F$@82!A=71E;G1I8V'GXV\@4D%$2553
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-3<*;7-G:60@(E!A
M<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(E-E;FAA(&-O;2!C
M;VYF:7)M8>?C;R(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(E-E;FAA.B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM
M<V=S='(@(E-E;FAA.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`S.`HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB
M"FUS9W-T<B`B4V5N:&%S(&1E=F5M('-E<B!I9W5A:7,N(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$Q.2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S='(@(D-O
M;&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`B0V]L
M87(@9&$@X7)E82!D92!T<F%N<V9E<NIN8VEA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G
M<W1R(")0871H(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C<*
M;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B0V%D87-T<F]S(%!E
M;F1E;G1E<SHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*;7-G:60@
M(E!E;W!L92(*;7-G<W1R(")097-S;V%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS
M9W-T<B`B4&]R8V5N=&%G96TB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC
M92!/<&5R871I;VYS(@IM<V=S='(@(D5X96-U=&%R($]P97)AY_5E<R!D92!-
M86YU=&5NY^-O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Q,`IM<V=I
M9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*
M;7-G<W1R(")%>&5C=71A<B!O<&5R8>?U97,@9&4@;6%N=71E;N?C;R!A;R!C
M;VYE8W1A<C\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U
M-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R(")097)M:7-SXV\B"@HC.B!A
M9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@
M(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R(")097)M
M:7-SXV\@7"(E<UPB(&[C;R!E>&-L=>UD82XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C4Y,`IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS
M9W-T<B`B4&5R;6ES<^-O($YE9V%D82(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,38T"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R(")097)M:7-S]65S(@H*
M(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H
M:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI
M<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R8>?C;R!D92!097)M:7-S]65S
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X"FUS9VED(")097)S;VYA
M;"!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUAY_5E<R!097-S;V%I<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R(")097)U(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@
M(D%N:6UA:7,@9&4@17-T:6UAY^-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0
M:&EL:7!P:6YE<R(*;7-G<W1R(")&:6QI<&EN87,B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*
M;7-G<W1R(")496QE9F]N92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT.#`*;7-G:60@(E!H;W1O<R(*;7-G<W1R(")&;W1O<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(E!I=&-A:7)N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G
M:60@(E!I>&5L<R(*;7-G<W1R(")0:7AE;',B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B0VQI8VCI
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM
M<V=S='(@(E!O<B!F879O<B!C;&EQ=64@96T@86QG=6UA(&/I;'5L82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R(")0;W(@9F%V;W(@8V]N9FER
M;64@<75E('9O8^H@<75E<B!R96UO=F5R(&5S=&4@96QE;65N=&\Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N
M;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(E!O<B!F879O<B!C;VYF:7)M
M92!Q=64@=F]CZB!Q=65R(')E;6]V97(@;R!L:6YK(&1E<W1E(&5L96UE;G1O
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U-C8*;7-G:60@(E!L
M96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(E!O<B!F
M879O<B!F;W)N9>=A('5M(&WJ<R!E('5M(&%N;RXB"@HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E
M(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B
M4&]R(&9A=F]R(&9O<FYEYV$@=6T@;F]M92!P87)A(&$@;F]V82!C871E9V]R
M:6$Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-0IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B4&]R
M(&9A=F]R(&9O<FYEYV$@=6T@96YD97)EYV\@25`@=N%L:61O+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-#<*;7-G:60@(E!L96%S92!E;G1E
M<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T
M:&4@;6]N=&@N(@IM<V=S='(@(E!O<B!F879O<B!F;W)N9>=A('5M82!D871A
M(';A;&ED82P@=F5R:69I<75E(&\@;OIM97)O(&1E(&1I87,@;F\@;>IS+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-3$*;7-G:60@(E!L96%S
M92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(E!O<B!F879O<B!F;W)N
M9>=A('5M82!H;W)A(';A;&ED82XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@
M;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(E!O<B!F879O<B!F;W)N9>=A('5M
M(')E<W5M;R!D;R!P<F]B;&5M82XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@
M(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM
M<V=S='(@(E!O<B!F879O<B!F;W)N9>=A('-E=2!U<W7A<FEO(&4@<V5N:&$B
M"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L
M96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@
M=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@
M(B(*(E!O<B!F879O<B!L96EA(&\@=&5X=&\@82!S96=U:7(N(%9O8^H@1$56
M12!C;VYC;W)D87(@8V]M(&]S('1E<FUO<R!D92!U<V\@9&\@(@HB<VES=&5M
M82XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N
M86UE.B(*;7-G<W1R(")0;W(@9F%V;W(@9&EG:71E(&\@;F]M92!D82!N;W9A
M(&-A=&5G;W)I83HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G
M<W1R(")0;VST;FEA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W"FUS
M9VED(")0;VQI=&EC<R(*;7-G<W1R(")0;VSM=&EC82(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT.#D*;7-G:60@(E!O;&QS(@IM<V=S='(@(D5N
M<75E=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R
M(")0;W)T=6=A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@
M=&AI<R!I;6%G92(*;7-G<W1R(")0;W-IY^-O(&1E<W1A(&EM86=E;2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS
M9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(E!O<VGG
MXV\@9&5S=&$@=&%B96QA(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO
M="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R(")%;G9I92!P87)A(&5S=&$@
M<&%S=&$@*&[C;R#I(&]B<FEG861O('!E;&\@24U!4"DB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(W,R!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO
M=7(H<RDZ("(*;7-G<W1R(")0<F5C:7!I=&'GXV\@<&%R82!A*',I(/IL=&EM
M82AS*2`E<R!H;W)A*',I.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C@W"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM
M<V=S='(@(E!R96-I<&ET8>?C;SQB<B`O/F-H86YC92(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@
M4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0
M<F5F<U]L9&%P.B!%>'1E;G/C;R!,1$%0(&]B<FEG873S<FEA(&[C;R!E;F-O
M;G1R861A+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H
M<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]S97-S:6]N.B!%
M>'1E;G/C;R!D92!S97-SXV\@;V)R:6=A=/-R:6$@;N-O(&5N8V]N=')A9&$N
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S(*;7-G:60@(E!R97-S=7)E
M(@IM<V=S='(@(E!R97-SXV\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V
M-@IM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B4')E
M<W/C;R!E;2!N[79E;"!D;R!M87(Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,C0*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B4')E
M<W/C;SH@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(P-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`B4'+I
M+79I<W5A;&EZ8>?C;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@
M:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(E!R979E<B!A(&EM86=E
M;2!E;2!U;6$@;F]V82!J86YE;&$B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C,U-B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V
M,`IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")/<.?U97,@86YT
M97)I;W)E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(DEM<')I
M;6ER(&1O8W5M96YT;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B0VAA=F4@4')I
M=F%D82(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-CD*
M;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B4')O8FQE;6$B"@HC.B!S97)V:6-E
M<R]P<F]B;&5M+G!H<#HQ,C<*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB
M"FUS9W-T<B`B1&5S8W)IY^-O(&1O(%!R;V)L96UA(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,W,0IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B
M4')O:F5T;W,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$U(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.3(*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S(X,PIM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B5&5X
M=&\@8G)E=F4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B0VAA=F4@4/IB;&EC82(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0V"FUS9VED
M(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R(")!;&=O<FET;6\@9&$@
M0VAA=F4@4/IB;&EC82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B0VAA
M=F4@4/IB;&EC82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A
M=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B4&%R(&1E(&-H879E<R!0^F)L
M:6-A+U!R:79A9&$@;N-O(&9O<F%M(&=E<F%D;W,@8V]M('-U8V5S<V\N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B4&]R
M=&\@4FEC;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DV(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E%A=&%R(@IM<V=S='(@
M(E%A=&%R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8S"FUS9VED(")1=65R
M>2(*;7-G<W1R(")#;VYS=6QT87(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S='(@(E%A=&%R(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B0VAA=F4@
M4/IB;&EC82!24T$@*"5D(&)I="DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,C8X"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B0F]T
M]65S(&1E('-E;&7GXV\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B(*;7-G<W1R(")#:'5V82(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED
M(")286EN($5A<FQY(@IM<V=S='(@(D-H=79A($UA='5T:6YA(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A
M:6X@3&%T92(*;7-G<W1R(")#:'5V82!697-P97)T:6YA(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@
M4VAO=V5R(@IM<V=S='(@(E!A;F-A9&%S(&1E($-H=79A(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@
M86YD(%-N;W<B"FUS9W-T<B`B0VAU=F$@92!.979E(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E)A:6X@=&\@
M4VYO=R(*;7-G<W1R(")#:'5V82!P87)A($YE=F4B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B
M4V]R=&4@06QE873S<FEA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<V"FUS9VED(")2871I;R(*;7-G<W1R(")296QAY^-O(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B
M"FUS9W-T<B`B3&5R(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.#<*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B3&5R
M(&UE;G-A9V5N<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI
M;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4
M:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R(")%>&-L
M=6ER(')E86QM96YT92`E<S\@17-T82!O<&5R8>?C;R!NXV\@<&]D92!S97(@
M9&5S9F5I=&$N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A
M=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N(@IM<V=S='(@(B(*(E)E;6]V97(@<F5A;&UE;G1E(&]S(&1A9&]S(&1O
M('5S=>%R:6\@)7,_($5S=&$@;W!E<F'GXV\@;N-O('!O9&4@<V5R("(*(F1E
M<V9E:71A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S
M='(@(E)E9F%Z('-U82#Z;'1I;6$@8>?C;R(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2
M969R97-H(@IM<V=S='(@(D%T=6%L:7IA<B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.34*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE
M;G1S.B(*;7-G<W1R(")!='5A;&EZ87(@365N=2!D92!%;&5M96YT;W,@1&EN
MXFUI8V]S.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#4*;7-G:60@
M(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(D%T=6%L:7IA<B!%>&EB
M:>?C;R!D;R!0;W)T86PZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B4F5G
M97@B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,X"FUS9VED(")2
M96QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R(").879E9V%D;W(@9&4@4F5L
M8>?U97,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"FUS9VED(")296QO860B"FUS
M9W-T<B`B3&5R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S,*;7-G:60@
M(E)E;6%R:W,B"FUS9W-T<B`B3V)S97)V8>?U97,B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3$W"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R
M(")397)V:61O<F5S(%)E;6]T;W,B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA
M;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R(")54DP@4F5M;W1A("AH='1P.B\O
M=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E
M9"YI;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R(")296UO=F5R(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@
M0FQO8VLB"FUS9W-T<B`B4F5M;W9E<B!";&]C;R(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HU-3<*;7-G:60@(E)E;6]V92!C
M;VQU;6XB"FUS9W-T<B`B4F5M;W9E<B!C;VQU;F$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0P"FUS9VED(")296UO=F4@
M9F]R;6%T=&EN9R(*;7-G<W1R(")296UO=F5R(&9O<FUA=&'GXV\B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A
M:7(B"FUS9W-T<B`B4F5M;W9E<B!P87(B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,C`R"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R
M=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B4F5M;W9E<B!S
M8W)I<'0@9W)A=F%D;R!N;R!D:7)E=/-R:6\@=&5M<&]RX7)I;R!D;R!S97)V
M:61O<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#(*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B4F5M
M;W9E<B!O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@
M=&AE(&1O8W5M96YT(@IM<V=S='(@(E)E;6]V97(@97-T92!N\R!D;R!D;V-U
M;65N=&\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q
M"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R(")296UO=F5R('5S=>%R:6\B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(E)E;6]V
M97(@=7-UX7)I;SH@)7,B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N
M<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@
M4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`B4V]L:6-I=&'GXV\@;N-O
M('#T9&4@<V5R(')E<W!O;F1I9&$N($/S9&EG;R!D92!E<G)O(')E=&]R;F%D
M;SH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-0IM<V=I
M9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G
M<W1R(")/('-E<G9IYV\@<F5Q=6ES:71A9&\@;N-O('!O9&4@<V5R(&5N8V]N
M=')A9&\N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S8@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B)R5S)R!O8G)I9V%T\W)I;R!NXV\@9F]I(&5S
M<&5C:69I8V%D;R!N82!C;VYF:6=U<F'GXV\@)7,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HV-S@@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX-C$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<S,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I
M9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B)R5S)R!O8G)I
M9V%T\W)I;R!NXV\@9F]I(&5S<&5C:69I8V%D;R!N82!C;VYF:6=U<F'GXV\@
M5D93+B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<W-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I
M;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(G)7,G(&]B<FEG873S<FEO(&[C
M;R!F;VD@97-P96-I9FEC861O(&YA(&-O;F9I9W5R8>?C;RXB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S4*;7-G:60@(E)E<75I
M<F5D($9I96QD(@IM<V=S='(@(D-A;7!O($]B<FEG873S<FEO(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S0S"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R,"!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(DQI;7!A
M<B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"FUS9VED(")2
M97-E="!087-S=V]R9"(*;7-G<W1R(")'97)A<B!.;W9A(%-E;FAA(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E<V5T(%EO
M=7(@4&%S<W=O<F0B"FUS9W-T<B`B1V5R87(@3F]V82!396YH82(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,S`*;7-G:60@(E)E<W1O<F4@3&%S="!1=65R
M>2(*;7-G<W1R("+:;'1I;6\@475A<G1O(@H*(SH@861M:6XO<&AP<VAE;&PN
M<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP
M:'`Z-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B4F5S=6QT861O<R(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R
M969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T
M<B`B4F5T;W)N87(@X"!/<.?U97,B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B"FUS9W-T
M<B`B1&EG:71E(&$@;F]V82!S96YH82!N;W9A;65N=&4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`R"FUS9VED(")2975N:6]N(@IM<V=S='(@(E)E=6YIXV\B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(E)E=F5R
M=&5R($-O;F9I9W5R8>?C;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S4*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R(")/
M<.?U97,@9&\@161I=&]R(%)I8V@@5&5X="(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R(")#:&%R861A<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B1&ER96ET82(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3`*;7-G:60@(E)I9VAT(&AE861E<B(*
M;7-G<W1R(")#86)EYV%L:&\@9&ER96ET;R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,#8*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R(")6
M86QO<F5S(&1A(&1I<F5I=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R
M=&EE<RXN+B(*;7-G<W1R(")0<F]P<FEE9&%D97,@9&$@7TQI;FAA+BXN(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`IM
M<V=I9"`B4F]L92(*;7-G<W1R(")&=6[GXV\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS
M9VED(")2;VUA;FEA(@IM<V=S='(@(E)O;>IN:6$B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(T"FUS9VED(")2;W1A=&4@
M,3@P(@IM<V=S='(@(D=I<F%R(#$X,"!G<F%U<R(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,C$*;7-G:60@(E)O=&%T92!,
M969T(@IM<V=S='(@(D=I<F%R('!A<F$@82!%<W%U97)D82(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C<*;7-G:60@(E)O
M=&%T92!2:6=H="(*;7-G<W1R(")':7)A<B!P87)A(&$@1&ER96ET82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(E!R;W!R:65D861E
M<R!D82!,:6YH82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T:65S(@IM<V=S
M='(@(E!R;W!R:65D861E<R!D82!L:6YH82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G
M<W1R("),:6YH87,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T<B`B3&EN
M:&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A
M;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R("),:6YH87,@87!A<F5C97+C
M;R!E;G1R92!T;V1A<R!A<R!L:6YH87,@92!C;VQU;F%S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I
M9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS
M9W-T<B`B3&EN:&%S(&%P87)E8V5RXV\@<V]M96YT92!E;G1R92!C;VQU;F%S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S
M(&]N;'DB"FUS9W-T<B`B3&EN:&%S(&%P87)E8V5RXV\@<V]M96YT92!E;G1R
M92!L:6YH87,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P"FUS9VED(")2
M=6XB"FUS9W-T<B`B17AE8W5T87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2
M=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B1F5D97)AY^-O(%)U<W-A(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@(E)U86YD82(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED
M(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B07-S
M:6YA='5R82!#<FEP=&]G<N%F:6-A(%,O34E-12(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@16YC<GEP
M=&5D($UE<W-A9V4B"FUS9W-T<B`B365N<V%G96T@0W)I<'1O9W)A9F%D82!C
M;VT@4R]-24U%(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX
M,0IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R(")!=71E;G1I8V'GXV\@4T%33"!NXV\@97-TX2!D:7-P;V[M
M=F5L+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#8*;7-G:60@
M(E--4R!-97-S86=I;F<B"FUS9W-T<B`B0V]R<F5I;R!335,B"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R("),
M:6YH82!D92!C;VUA;F1O(%-13"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,R.#$*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU
M<',B"FUS9W-T<B`B4V5N=&5NYV$@4U%,('!A<F$@<&5S<75I<V%S(&1E('9A
M;&]R97,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,S"FUS9VED
M(")34T@B"FUS9W-T<B`B4U-((@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B
M4U5#0T534R(*;7-G<W1R(")354-%4U-/(@H*(SH@;&EB+V%P:2YP:'`Z,34S
M"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(DQI;FAA(&1E(&-O;6%N9&\@
M4U]13"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(E-A8B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*
M;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R(")386YT82!(96QE;F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G
M<W1R(")3XV\@2VET=',@92!.979I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B
M4V%I;G0@3'5C:6$B"FUS9W-T<B`B4V%N=&$@3'5Z:6$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@
M(E/C;R!0961R;R!E($UI<75E;&]N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B
M4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B4^-O
M(%9I8V5N=&4@92!'<F%N861I;F%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E
M;&8I(@IM<V=S='(@(DUE<VUO('%U861R;R`H7W-E;&8I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B4V%M;V$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`V"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(E-A;B!-87)I;F\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`W"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS
M9W-T<B`B4^-O(%1O;>D@92!0<NUN8VEP92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*
M;7-G<W1R(")0<F]V961O<B!D92!3873I;&ET92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*
M;7-G:60@(E-A=61I($%R86)I82(*;7-G<W1R(")!<N%B:6$@4V%U9&ET82(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.0IM<V=I9"`B4V%V
M92(*;7-G<W1R(")386QV87(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@7"(E<UPB
M(@IM<V=S='(@(E-A;'9A<B`E<R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,C$V"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T
M<B`B4V%L=F%R("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM
M<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(E-A;'9A<B!/<.?U97,B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3879E(&=E
M;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R
M('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*
M(E-A;'9A<B!C;VYF:6=U<F'GXV\@9V5R861A(&-O;6\@=6T@<V-R:7!T(%!(
M4"!P87)A(&\@9&ER973S<FEO('1E;7!O<N%R:6\@9&\@(@HB<V5U('-E<G9I
M9&]R+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(D-O;F9I9W5R8>?C;R`E<R!S86QV82XB"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U
M<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")38W)I<'0@9&4@
M871U86QI>F'GXV\@9&4@8V]N9FEG=7)AY^-O('-A;'9O(&5M.B`G)7,G+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"FUS
M9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B5&5M<&5S=&%D97,@
M27-O;&%D87,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@
M(E-C:65N8V4B"FUS9W-T<B`B0VGJ;F-I82(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B4&5S<75I<V%R(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R,@IM<V=I9"`B4V5A<F-H($5N
M9VEN97,B"FUS9W-T<B`B16YG:6YE<R!D92!097-Q=6ES82`B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.38R"FUS9VED(")396QE8W0@1FEL97,B
M"FUS9W-T<B`B4V5L96-I;VYE(&]S($%R<75I=F]S(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X,PIM<V=I9"`B4V5L96-T
M(&$@9&%T92(*;7-G<W1R(")396QE8VEO;F4@=6UA(&1A=&$B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O
M=7`@=&\@861D(@IM<V=S='(@(E-E;&5C:6]N92!U;2!G<G5P;R!P87)A(&%D
M:6-I;VYA<B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G
M:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R(")396QE8VEO;F4@=6T@
M;F]V;R!M96UB<F\B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R(")396QE8VEO;F4@
M=6T@<V5R=FED;W(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U
M-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B4V5L96-I
M;VYE('5M('5S=>%R:6\@<&%R82!A9&EC:6]N87(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<T"FUS9VED(")396QE8W0@
M86QL(@IM<V=S='(@(E-E;&5C:6]N87(@=&]D;W,B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-C4P"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M
M<&]N96YT<RXB"FUS9W-T<B`B4V5L96-I;VYE('1O9&]S(&]S(&-O;7!O;F5N
M=&5S(&1E(&1A=&$N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C@W,0IM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R
M(")396QE8VEO;F4@=6T@;V)J971O(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C8W-0IM<V=I9"`B4V5L96-T(&YO;F4B"FUS
M9W-T<B`B3N-O('-E;&5C:6]N87(@;F5N:'5M(@H*(SH@<V5R=FEC97,O:V5Y
M8F]A<F0N<&AP.C,W"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@
M>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C
M;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS
M9W-T<B`B(@HB4V5L96-I;VYE(&]S(&-A<F%C=&5R97,@<75E('9O8^H@<')E
M8VES82!N82!C86EX82!A8F%I>&\N(%9O8^H@<&]D92!E;G3C;R`B"B)C;W!I
MX2UL;W,@92!C;VSA+6QO<R!N82#A<F5A(&1E('1E>'1O+B(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@
M9&5L:6UI=&5R.B(*;7-G<W1R(")396QE8VEO;F4@=6T@9&5L:6UI=&%D;W(@
M9&4@9&%T83HB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I
M9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B4V5L96-I;VYE
M(&\@9F]R;6%T;R!D92!D871A.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N
M=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@
M>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R(")396QE8VEO;F4@82!I9&5N
M=&ED861E('%U92!V;V/J('%U97(@86QT97)A<CHB"@HC.B!T96UP;&%T97,O
M9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM
M:71E<CHB"FUS9W-T<B`B4V5L96-I;VYE('5M(&1E;&EM:71A9&]R(&1E(&AO
M<F$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E
M;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(E-E;&5C:6]N92!O(&9O
M<FUA=&\@9&4@:&]R83HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T
M<B`B4V5L96-I;VYE(&1O:7,@8V%M<&]S(&-O<G)E<W!O;F1E;G1E<RXB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S$P"FUS9VED(")396QE8W0@>6]U
M<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(E-E;&5C:6]N92!S974@97-Q=65M
M82!D92!C;W)E<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4R"FUS
M9VED(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@
M(E-E;&5C:6]N92!S974@:61I;VUA('!R969E<FED;SHB"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M
M(%)E<&]R="(*;7-G<W1R(")%;G9I87(@4F5L873S<FEO(&1E(%!R;V)L96UA
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M-#`*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(D5N=FEA<B!335,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S='(@(E-E;F5G86PB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R,PIM<V=I9"`B4V5N<V]R.B`B"FUS
M9W-T<B`B4V5N<V]R.B`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(E-E=&5M
M8G)O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3D*
M;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R(")397)V:6$@
M92!-;VYT96YE9W)O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HW,#(*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B3OIM97)O
M(&1E(%/I<FEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T
M.0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B1&%D;W,@9&\@<V5R=FED;W(@97)R861O<R!O=2!NXV\@9&ES
M<&]N[79E:7,N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"FUS9VED(")3
M97-S:6]N($%D;6EN(@IM<V=S='(@(D%D;6EN:7-T<F%D;W(@9&4@4V5S<^-O
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(DE$
M(&1A(%-E<W/C;R!E>'!I<F]U+B(*"B,Z(&QI8B]A<&DN<&AP.C$T-0IM<V=I
M9"`B4V5S<VEO;G,B"FUS9W-T<B`B4V5S<_5E<R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S,3@*;7-G:60@(E-E="(*;7-G<W1R(")!:G5S=&%R
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS9VED(")3970@;W!T
M:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y
M;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*(D-O;F9I9W5R82!A<R!O
M<.?U97,@<&%R82!P97)M:71I<B!V;V/J(&=E<F%R('5M82!N;W9A('-E;FAA
M('-E('9O8^H@97-Q=65CZBTB"B)L82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$X"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y
M;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B
M(@HB0V]N9FEG=7)A(&]S('-E<G9I9&]R97,@<F5M;W1O<R!Q=64@=F]CZB!Q
M=65R(&%C97-S87(@X"!P87)T:7(@9&\@<&]R=&%L+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX-PIM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA
M;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R(")#
M;VYF:6=U<F$@<V5U(&ED:6]M82!P<F5F97)I9&\L(&9U<V\@:&]RX7)I;R!E
M(&]PY_5E<R!D92!D871A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,#$*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O
M;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES
M<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B"B)#;VYF:6=U<F$@<W5A(&%P;&EC
M8>?C;R!I;FEC:6%L+"!E<W%U96UA(&1E(&-O<F5S+"!A='5A;&EZ8>?C;R!D
M92!PX6=I;F%S(&4@(@HB;W5T<F%S(&]PY_5E<R!D92!E>&EB:>?C;RXB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W"FUS9VED(")3971U<"(*;7-G
M<W1R(")#;VYF:6=U<F'GXV\B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O
M:6YD97@N:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V
M86EL86)L92(*;7-G<W1R(")38W)I<'1S(&1E(&%T=6%L:7IAY^-O(&1E(&-O
M;F9I9W5R8>?C;R!D:7-P;V[M=F5I<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-S4*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I
M8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(D1I=F5R<V%S(&QO
M8V%L:61A9&5S('!O<W/M=F5I<R!C;VT@;R!P87+B;65T<F\Z("(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B4V5I8VAE;&5S
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y.`IM<V=I9"`B4VAO
M<'!I;F<B"FUS9W-T<B`B0V]M<')A<R(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@
M(E)E<W5M;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-3`*;7-G:60@
M(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS
M/R(*;7-G<W1R(")496-L87,@9&4@871A;&AO(&1E=F5RXV\@<V5R(&1E9FEN
M:61A<R!P87)A(&$@;6%I;W)I82!D;W,@;&EN:W,_(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T
M<B`B17AI8FER(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I
M9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E
M9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R(")%>&EB:7(@87,@9&EF97)E;N=A<R!E;G1R92!A(&-O;F9I9W5R
M8>?C;R!A='5A;"!E(&$@;F]V82!G97)A9&$N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0Y-`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE
M;B!L;V=G:6YG(&EN/R(*;7-G<W1R(")%>&EB:7(@9&%T82!E(&AO<F$@9&$@
M^FQT:6UA(&-O;F5XXV\@86\@<V4@8V]N96-T87(_(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3<V.0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E
M<"!O<FEG:6YA;"(*;7-G<W1R(")%>&EB:7(@82!O<.?C;R!D92!M86YT97(@
M;R!O<FEG:6YA;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#(*
M;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(D5X:6)I<B!S96QE=&]R(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S,`IM<V=I9"`B4VAO=R!T86)L
M92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R(")%>&EB:7(@8F%R<F$@
M9&4@;65N=2!C;VT@;W!E<F'G]65S(&1E('1A8F5L83\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S4S"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@
M=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(D5X:6)I<B!O($UE
M;G4@)7,@X"!E<W%U97)D83\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A
M8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B17AI8FER(&1I
MX6QO9V\@9&4@4')O<')I961A9&5S(&1E($/I;'5L87,@9&$@5&%B96QA(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO
M9R(*;7-G<W1R(")%>&EB:7(@9&GA;&]G;R!D92!0<F]P<FEE9&%D97,@9&$@
M5&%B96QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O
M<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B17AI8FER(&1IX6QO9V\@9&4@4')O
M<')I961A9&5S(&1E($QI;FAA<R!D82!486)E;&$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@
M(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(D5X
M:6)I<B!D:>%L;V=O(&1E('!R;W!R:65D861E<R!D92!I;6%G96TB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8W"FUS9VED(")3:&]W('5P;&]A
M9"(*;7-G<W1R(")%>&EB:7(@=7!L;V%D(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-H;W=E<G,B"FUS9W-T
M<B`B0VAU=F%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B0VAU=F%S
M(&UA=&EN86ES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R(")#:'5V87,@
M5F5S<&5R=&EN87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU-`IM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS
M9W-T<B`B0VAU=F%S(&YA<R!R961O;F1E>F%S(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV,3D*;7-G:60@(E-H<FEN
M:R(*;7-G<W1R(")2961U>FER(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HY,3`*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HY-S(*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,#4X"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3$R,`HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q.#,*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C(S"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(U
M,@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C$R.#4*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C
M:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R(")0<FEM96ER86UE
M;G1E(')E9'5Z82!O=2!T:7)E(&1O(&-A;6EN:&\@;RAS*2!B;&]C;RAS*2!A
M9&IA8V5N=&4H<RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O
M;F4B"FUS9W-T<B`B4V5R<F$@3&5O82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HR-C8*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B4F5G
M:7-T<F%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW
M,3,*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R(")!<W-I;F%T=7)A(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I
M9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B06QG;W)I=&UO(&1A($%S<VEN
M871U<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T
M<B`B0VEN9V%P=7)A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#0@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3`P"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R,3D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(T,0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C4P(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Y,3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q
M,@IM<V=I9"`B4VEZ92(*;7-G<W1R(")486UA;FAO(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@
M36%I;G1E;F%N8V4B"FUS9W-T<B`B26=N;W)A<B!-86YU=&5NY^-O(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B17-L;W;A<75I
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(D5S
M;&]V96YI82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4U"FUS9VED(")3;F]W(@IM<V=S='(@(DYE=F4B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3
M:&]W97(B"FUS9W-T<B`B3F5V87-C82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS
M9W-T<B`B3F5V87-C87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S
M='(@(D-H=79A<R!M871I;F%I<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T92(*
M;7-G<W1R(").979A<V-A<R!697-P97)T:6YA<R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C@U"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B4')O
M9G5N9&ED861E(&1A($YE=F4Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C@Y"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R
M(")%<75I=F%L96YT92!D92!N979E(&5M(.%G=6$Z("(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#,*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R("));&AA<R!386QO
M;>-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,30@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R(")3
M;VWA;&EA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3
M;VYG<R`F(%!O96US(@IM<V=S='(@(D-A;N?U97,@)B!0;V5M87,B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3$U"FUS9VED(")3;W)T(&]R9&5R
M('-E;&5C=&EO;B(*;7-G<W1R(")/<F1E;F%R('-E;&7GXV\B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y
M"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R(")%;F1E<F7G;R!D92!O
M<FEG96TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS
M9W-T<B`BP69R:6-A(&1O(%-U;"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@Y"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T
M<B`B4W5L($5U<F]P974@*$E33RTX.#4Y+3,I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS
M9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L
M86YD<R(*;7-G<W1R(")3=6P@9&$@1V5O<F=I82!E(%-U;"!D87,@26QH87,@
M4V%N9'7M8VAE(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C
M:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G
M<W1R(")(96UI<V;I<FEO(%-U;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D
M:F%C96YT(&-E;&QS(@IM<V=S='(@(D5S<&'G;R!E;G1R92!CZ6QU;&%S(&%D
M:F%C96YT97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B
M;W)D97(@:6X@8V5L;"(*;7-G<W1R(")%<W!AYV\@96YT<F4@;R!C;VYT9?ID
M;R!E(&)O<F1A(&1A(&/I;'5L82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C@Q.0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(D5S<&'G861O<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R(")%<W!AYV%M96YT;R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*
M;7-G:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B17-P8>=A;65N
M=&\@92!M87)G96TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B4W!A:6XB"FUS9W-T
M<B`B17-P86YH82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#`*
M;7-G:60@(E-P86TB"FUS9W-T<B`B4W!A;2(*"B,Z('-E<G9I8V5S+VME>6)O
M87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS
M9W-T<B`B16YT<F%D82!D92!#87)A8W1E<F5S($5S<&5C:6%I<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*
M;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B1&EV:61I<B!CZ6QU;&$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B1&EV:61I<B!C;VQU
M;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B1&EV:61I<B!L
M:6YH82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM<V=I9"`B4W!O
M<G1S(@IM<V=S='(@(D5S<&]R=&5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED(")3
M<FD@3&%N:V$B"FUS9W-T<B`B4W)I($QA;FMA(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C8V(&QI8B]";&]C:R]M971A<BYP:'`Z.#$*;7-G
M:60@(E-T86YD87)D(@IM<V=S='(@(E!A9'+C;R(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(E-T87(@
M5')E:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.3`@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y.`IM<V=I9"`B4W1A<G0@>65A<B(*;7-G
M<W1R(")!;F\@:6YI8VEA;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3<Q"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R
M(")%<W1A9&\@;W4@4')O=NUN8VEA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E
M='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G<W1R(")3:71U
M8>?C;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#0*;7-G:60@
M(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(D9O<FUA=&\@9&\@87)M87IE;F%M
M96YT;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S
M"FUS9VED(")3=')E970@061D<F5S<R(*;7-G<W1R(").;VUE(&1A(%)U82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*
M;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B5')AYV%D;R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*;7-G:60@(E-T<FEN9R!L:7-T
M(@IM<V=S='(@(DQI<W1A(&1E(&-A9&5I87,@9&4@8V%R86-T97)E<R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S<*;7-G:60@(E-T<FEP(&1O
M;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(E)E=&ER87(@82!P87)T
M92!D;R!D;VWM;FEO(&1O(&5N9&5R9>=O(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@
M6T-34UTB"FUS9W-T<B`B17-T:6QO(%M#4U-=(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T
M<B`B1&]M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R(")3=6)D:7)E=/-R:6\@)R5S)R!NXV\@96YC;VYT<F%D;RXB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS
M9VED(")3=6)J96-T(@IM<V=S='(@(D%S<W5N=&\B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,S8@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E
M<BYP:'`Z,S$W"FUS9VED(")3=6)M:70B"FUS9W-T<B`B16YV:6%R(@H*(SH@
M<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T
M960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C
M86YN;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A
M<'!R;W9E9"XB"FUS9W-T<B`B(@HB16YV:6%D82!A('-O;&EC:71AY^-O(&1E
M(&%D:6-I;VYA<B!<(B5S7"(@86\@<VES=&5M82X@5F]CZB!NXV\@<&]D92!C
M;VYE8W1A<BTB"B)S92!A=.D@<75E('-U82!S;VQI8VET8>?C;R!S96IA(&%P
M<F]V861A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R(")3=6)S8W)E=F5R
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-`HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X
M"FUS9VED(")3=6-C97-S(@IM<V=S='(@(E-U8V5S<V\B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M861D960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@(B<E<R<@861I
M8VEO;F%D;R!C;VT@<W5C97-S;R!A;R!S:7-T96UA+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN
M(@IM<V=S='(@(D]S(&1A9&]S(&1O('5S=>%R:6\@)R5S)R!F;W)A;2!R96UO
M=FED;W,@9&\@<VES=&5M82!C;VT@<W5C97-S;RXB"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G
M<W1R("(G)7,G(&5X8VQU[61O(&-O;2!S=6-E<W-O+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")%>&-L
M=>UD;R`G)7,G(&1O('-I<W1E;6$@8V]M('-U8V5S<V\N(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R
M=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS
M9W-T<B`B0V]N9FEG=7)AY^-O(')E=F5R=&ED82!C;VT@<W5C97-S;RX@071U
M86QI>F4@<&%R82!V97(@87,@86QT97)AY_5E<RXB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G
M:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B0F%C:W5P(&1A(&-O;F9I9W5R8>?C;R!S86QV82!C;VT@<W5C
M97-S;RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O
M;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B3R!B86-K=7`@9&\@87)Q
M=6EV;R!D92!C;VYF:6=U<F'GXV\@)7,@9F]I('-A;'9O(&-O;2!S=6-E<W-O
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B)R5S)R!A
M='5A;&EZ861O(&-O;2!S=6-E<W-O(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(B5S(&=R
M879A9&\@8V]M('-U8V5S<V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=61A
M;B(*;7-G<W1R(")3=63C;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T
M<B`B4F5S=6UO(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED
M(")3=6X@4FES92(*;7-G<W1R(")!;6%N:&5C97(B"@HC.B!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B4/1R+61O
M+5-O;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8P"FUS9VED(")3=6YN>2(*;7-G<W1R(")%;G-O;&%R861O(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-0IM<V=I9"`B4W5N<FES92(*
M;7-G<W1R(")!;6%N:&5C97(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N
M<V5T(@IM<V=S='(@(D%M86YH96-E<B]0]'(M9&\M4V]L(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-`IM<V=I9"`B4W5N<FES93H@(@IM
M<V=S='(@(D%M86YH96-E<CH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(P.`IM<V=I9"`B4W5N<V5T(@IM<V=S='(@(E#T<BUD;RU3;VPB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`W"FUS9VED(")3
M=6YS970Z("(*;7-G<W1R(")0]'(M9&\M4V]L.B`B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C
M<FEP="(*;7-G<W1R(")3;V)R97-C<F5V97(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S@P"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(E-U<&]R
M=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3=7)I;F%M92(*;7-G<W1R(")3
M=7)I;F%M92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3<U"FUS9VED(")3=7)N86UE(@IM<V=S='(@(E-O8G)E;F]M92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T
M<B`B4W9A;&)A<F0@92!*86X@36%Y96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED
M(")3=V%Z:6QA;F0B"FUS9W-T<B`B4W5A>FELXFYD:6$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`T"FUS9VED(")3=V5D96XB"FUS9W-T<B`B4W7I8VEA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(E-U[>=A(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E
M;&5T960B"FUS9W-T<B`B3N-O(&5X8VQU:7(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,30U"FUS9VED(")3>6YC34PB"FUS9W-T<B`B4WEN8TU,(@H*
M(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3
M>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(D5R<F\@9&4@
M<VEN=&%X92!N;W,@=&5R;6]S(&1A('!E<W%U:7-A(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B4F5P^F)L
M:6-A(,%R86)E(&1A(%/M<FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B5&5M
M<&5S=&%D92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8R"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R(")496UP
M97-T861E<R!E(%9E;G1A;FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(E1E
M;7!E<W1A9&5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C0*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@(E1E;7!E
M<W1A9&5S($UA=&EN86ES(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N
M<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B07)Q=6EV;R!44U8B
M"@HC.B!F<F%M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S-`IM<V=I9"`B5&%B
M;&4B"FUS9W-T<B`B5&%B96QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R
M=&EE<R(*;7-G<W1R(")0<F]P<FEE9&%D97,@9&$@5&%B96QA(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B
M5&%B;&4@4V5T(@IM<V=S='(@(E1A8F5L82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE
M('!R;W!E<G1I97,B"FUS9W-T<B`B4')O<')I961A9&5S(&1A('1A8F5L82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A;B(*;7-G<W1R(")4
M86EW86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R(")4
M86EW86XL(%!R;W;M;F-I82!D82!#:&EN82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G
M:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B5&%J:7%U:7-TXV\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(E1A;GKB;FEA+"!297#Z8FQI8V$@9&$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")487)G970Z
M(@IM<V=S='(@(D%L=F\Z(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDY
M-B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@Y"FUS9VED(")487-K<R(*
M;7-G<W1R(")487)E9F%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S0*;7-G:60@(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B
M3OIM97)O(&1E(%1E;&5F;VYE(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M.3<*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E1E;7!E
M<F%T=7)A('!A<F$@82#Z;'1I;6$@:&]R83H@(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,C$*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(E1E;7!E
M<F%T=7)A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,@IM
M<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R(")496UP97)A='5R83H@(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F
M9&5G.R5S(@IM<V=S='(@(E1E;7!E<F%T=7)A/&)R("\^*"5S06QT825S+R5S
M0F%I>&$E<RD@)F1E9SLE<R(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP
M;&%T92YP:'`Z-CDU"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB
M)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DUO9&5L;R`G)7,G(&[C;R!E;F-O
M;G1R861O+B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")4
M96UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')AY^-O
M(&1E($UO9&5L;W,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$U
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S0*;7-G:60@(E1E>'0B"FUS
M9W-T<B`B5&5X=&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Y"FUS
M9VED(")497AT($]N;'DB"FUS9W-T<B`B4V]M96YT92!497AT;R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*
M;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B06QI;FAA;65N=&\@9&4@5&5X
M=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(D)O<F1A('-U<&5R:6]R(&1O
M(%1E>'1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`B475I(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@
M(E1A:6QA;F3J<R`H5$E3+38R,"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4
M:&%I;&%N9"(*;7-G<W1R(")486ELXFYD:6$B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C@U,0IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`B02!E>'1E;G/C;R!&5%`@;N-O(&5S
M=.$@9&ES<&]N[79E;"XB"@HC.B!F<F%M97=O<FLO2&ES=&]R>2](:7-T;W)Y
M+G!H<#HU-0IM<V=I9"`B5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D
M+B(*;7-G<W1R(")/(&AI<W3S<FEC;R!D;R!S:7-T96UA(&5S=.$@9&5S86)I
M;&ET861O+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,S"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO
M;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B02!E
M;F=I;F4@9&4@:6YT96=R8>?C;R!(;W)D92]+;VQA8B!NXV\@<W5P;W)T82!<
M(B5S7"(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]";V]K+G!H<#HQ
M,CDX"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI
M>F5D+B(*;7-G<W1R(")/(&QO9R!)35-0(&[C;R!P;V1E('-E<B!I;FEC:6%L
M:7IA9&\N(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED
M(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S
M<V9U;&QY(@IM<V=S='(@(D$@8VQA<W-E(%PB36%I;G1E;F%N8V5<(B!NXV\@
M9F]I(&-A<G)E9V%D82!C;VT@<W5C97-S;R(*"B,Z('-E<G9I8V5S+VEM86=E
M<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O
M=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R(")!(&IA;F5L82!D92!/
M<.?U97,@9F]I(&9E8VAA9&$N(%-A:6YD;RXB"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C$X.2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P
M,`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(Q,2!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C(R,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C(S-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(U,@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(V-"!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@
M=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@
M:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B
M"B)/(&%D;6EN:7-T<F%D;W(@<')E8VES82!C;VYF:6=U<F%R('5M(&-O;F5C
M=&]R('!E<FUA;F5N=&4@9&4@4&5R;6ES<_5E<R!S92`B"B)V;V/J('%U97(@
M=71I;&EZ87(@4&5R;6ES<_5E<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M
M('-I9&4@;VYL>2(*;7-G<W1R(")3;VUE;G1E(&\@;&%D;R!D92!B86EX;R(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S
M<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@
M(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*(D\@;OIM97)O($E$(&1O(&-O;G1A
M=&\@;N-O(&9O:2!E<W!E8VEF:6-A9&\L(&1E:7AA9&\@96T@8G)A;F-O(&]U
M(&[C;R!F;VD@(@HB96YC;VYT<F%D;R!N;R!B86YC;R!D92!D861O<RXB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G
M:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U
M<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(D\@8V]N=&%T;R!F;VD@861I8VEO
M;F%D;R!C;VT@<W5C97-S;R!A;R!S974@8V%TX6QO9V\@9&4@96YD97)EYV]S
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-S(*;7-G
M:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E
M<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@
M(B(*(E!A<F$@=F5R:69I8V%R(&$@;65N<V%G96T@87-S:6YA9&$@Z2!N96-E
M<W/A<FEO('5M(&)L;V-O('-E<&%R861O(&1A("(*(F%S<VEN871U<F$@4$=0
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S
M(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N
M9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*(D\@240@9&$@;&ES
M=&$@9&4@9&ES=')I8G5IY^-O(&[C;R!F;VD@97-P96-I9FEC861O+"!D96EX
M861O(&5M(&)R86YC;R!O=2!NXV\@(@HB9F]I(&5N8V]N=')A9&\@;F\@8F%N
M8V\@9&4@9&%D;W,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES
M="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B02!L:7-T82!D92!D:7-T
M<FEB=6GGXV\@;N-O(&9O:2!E<W!E8VEF:6-A9&$N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+G!H<#HQ,38*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E
M871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S
M='(@(D%S(&9U;N?U97,@9&4@8W)I<'1O9W)A9FEA(')E<75E<F5M('5M82!C
M;VYE>.-O('=E8B!S96=U<F$N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-S<@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E
M<R!S971T:6YG+B(*;7-G<W1R(")/(&%R<75I=F\@)7,@9&5V97)I82!C;VYT
M97(@=6UA(&-O;F9I9W5R8>?C;R!D92`E<RXB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$W,"!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R(")/(&%R<75I=F\@)7,@
M9&5V97)I82!C;VYT97(@86QG=6UA<R!C;VYF:6=U<F'G]65S(&1E("5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-@IM<V=I9"`B5&AE
M(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B
M3R!A<G%U:79O(&[C;R!P;V1E('-E<B!C;W!I861O('!A<F$@96QE(&UE<VUO
M+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE
M(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(D\@87)Q=6EV;R!N
MXV\@8V]N=.EM(&1A9&]S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H
M92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM
M<V=S='(@(E-E9W5E;2!O<R!C86)EYV%L:&]S(&1E<W1A(&UE;G-A9V5M+VUE
M;G-A9V5M(')F8S@R,BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D
M92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X
M<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG
M="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B
M"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A
M;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES
M=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L
M;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E
M9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A
M<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F
M=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*(LD@<V%B:61O('%U92!O
M(&UO9&\@=&5L82!C:&5I82!C875S82!P<F]B;&5M87,@8V]M(&\@26YT97)N
M970@17AP;&]R97(L(&5M("(*(G9I<G1U9&4@9&4@8G5G<R!D;R!N879E9V%D
M;W(@<75E(&[S<R!NXV\@97-T86UO<R!A<'1O<R!A(&-O;G1O<FYA<BX@5F]C
MZB`B"B)P;V1E(&]B<V5R=F%R(&5R<F]S(&1E(&5X:6)IY^-O+"!F86QT82!D
M92!F=6[G]65S(&1O(&5D:71O<B!E+V]U('1R879A;65N=&]S("(*(F%L96%T
M\W)I;W,@9&\@;F%V96=A9&]R+B!392!S974@<VES=&5M82#I(%=I;F1O=W,@
M.7@@Z2!M=6ET;R!P<F]VX79E;"!Q=64@(@HB=F]CZB!R96-E8F$@=6T@97)R
M;R!D92`G1F%L:&$@1V5R86P@9&4@4')O=&7GXV\G(&4@<')E8VES87+A(')E
M:6YI8VEA<BX@7%QN(@HB7%QN(%9O8^H@9F]I(&%V:7-A9&\N(%!O<B!F879O
M<B!P<F5S<VEO;F4@3TL@<V4@=F]CZB!A:6YD82!Q=65R('1E;G1A<B!U<V%R
M("(*(F\@961I=&]R(&1E('1E;&$@8VAE:6$N(@H*(SH@<V5R=FEC97,O<')E
M9G,N<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@
M7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(D$@:61E;G1I9&%D
M92!<(B5S7"(@9F]I(&5X8VQU[61A+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T
M+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(E-O;65N=&4@;R!L861O(&5S<75E
M<F1O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS
M9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T
M(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B
M(@HB02!L;V-A;&EZ8>?C;R!D;R!B:6[A<FEO(&1O($=N=5!'(&1E=F4@<V5R
M(&9O<FYE8VED82#@(&-L87-S92!<(D-R>7!T7W!G<%PB+B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O341.+G!H<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE
M8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@
M9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U
M;F1E<G-T;V]D+B(*;7-G<W1R("(B"B)!(&UE;G-A9V5M(&5N=FEA9&$@96T@
M)7,@<&%R82`E<R!C;VT@;R!A<W-U;G1O(%PB)7-<(B!F;VD@97AI8FED82Y<
M;B(*(DES=&\@;N-O(&=A<F%N=&4@<75E(&$@;65N<V%G96T@9F]I(&QI9&$@
M;W4@96YT96YD:61A+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M.#$*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE
M(&-O;7!O<V4@<&%G92(*;7-G<W1R(")/(&YO;64@=71I;&EZ861O(&%O('9I
M;F-U;&%R(&$@<.%G:6YA(&1E(&-O;7!O<VGGXV\B"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HT-S0*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE
M;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`B3R!N^FUE<F\@9&4@8V%M
M<&]S(&1E=F4@<V5R(&YU;>ER:6-O+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,3(S,@IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE
M(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S
M<RXB"FUS9W-T<B`B3R!M\V1U;&\@;W!E;G-S;"#I(&]B<FEG873S<FEO('!A
M<F$@82!C;&%S<V4@7")(;W)D95]#<GEP=%]S;6EM95PB+B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,C@S"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@
M8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO
M=V%B;&4@<VEZ92(*;7-G<W1R("(B"B)!('!R969E<NIN8VEA(%PB)7-<(B!N
MXV\@<&]D92!S97(@<V%L=F$@<&]R<75E('-E=7,@9&%D;W,@97AC961E<F%M
M(&\@(@HB=&%M86YH;R!MX7AI;6\@<&5R;6ET:61O(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T
M82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G
M<W1R("(B"B)/('!R;V=R86UA('5T:6QI>F%D;R!P87)A('9I<W5A;&EZ87(@
M97-T92!T:7!O(&1E(&1A9&\@*"5S*2!NXV\@9F]I("(*(F5N8V]N=')A9&\@
M;F\@<VES=&5M82XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT
M.#<*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN
M9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B3R!C87)A8W1E<F4@<&%R82!C:71A
MY^-O(&1E('-E<B!A<&5N87,@=6TN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT
M(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B4V]M96YT92!O<R!L861O
M<R!D:7)E:71O(&4@97-Q=65R9&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M
M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B4V]M96YT92!O(&QA9&\@9&ER96ET
M;R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0W.0IM<V=I9"`B
M5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*
M;7-G<W1R(")/('-E<&%R861O<B!D979E('-E<B!U;2#Z;FEC;R!C87)A8W1E
M<F4N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L
M971E9"XB"FUS9W-T<B`B3R!S97)V:61O<B!<(B5S7"(@9F]I(&5X8VQU[61O
M+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D
M+B(*;7-G<W1R(")/('-E<G9I9&]R(%PB)7-<(B!F;VD@<V%L=F\N(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S
M:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T
M<B`B02!S;VQI8VET8>?C;R!D92!C861A<W1R;R!D92`E<R!F;VD@97AC;'7M
M9&$N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HT-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-P96-I9FEE9"!R
M;W<@*"5D*2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B02!L:6YH82!E<W!E
M8VEF:6-A9&$@*"5D*2!NXV\@97AI<W1E+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z,3<Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP
M;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D\@
M87)Q=6EV;R!T96UP;W+A<FEO(%PB)7-<(B!NXV\@97AI<W1E+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,#D*;7-G:60@(E1H92!T97AT('EO
M=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E
M;BXB"FUS9W-T<B`B3R!T97AT;R!Q=64@=F]CZB!D:6=I=&]U(&[C;R!C;W)R
M97-P;VYD92!A;R!T97AT;R!N82!T96QA+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T
M;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(E-O;65N=&4@;W,@
M;&%D;W,@9&4@8VEM82!E(&1E(&)A:7AO(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O
M<"!S:61E(&]N;'DB"FUS9W-T<B`B4V]M96YT92!O(&QA9&\@9&4@8VEM82(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P
M;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N
M(@IM<V=S='(@(D]S(&1A9&]S(&5N=FEA9&]S(&9O<F%M('!E<F1I9&]S(&1E
M<V1E(&\@<&%S<V\@86YT97)I;W(N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T
M82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,3<R
M"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N
M(@IM<V=S='(@(D\@87)Q=6EV;R!E;G9I861O(&[C;R!P]&1E('-E<B!S86QV
M;RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#D@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q,`IM<V=I9"`B5&AE('=E871H97(N
M8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D\@8FQO8V\@
M7")W96%T:&5R+F-O;5PB(&[C;R!E<W3A(&1I<W!O;NUV96PN(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B3R!D
M:7)E=/-R:6\@9&4@=&5M87,@)R5S)R!NXV\@9F]I(&5N8V]N=')A9&\N(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-S@*;7-G:60@(E1H
M97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`B3N-O(&5X
M:7-T96T@;W#G]65S(&1I<W!O;NUV96ES+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C,T.0IM<V=I9"`B5&AE<F4@87)E(&YO('!A
M<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(D[C
M;R!E>&ES=&5M('!A<G1E<R!Q=64@<&]S<V%M('-E<B!E>&EB:61A<R!I;F-O
M<G!O<F%D87,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA
M<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H
M87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS
M9W-T<B`B(@HB17AI<W1E;2!M=6ET;W,@8V%R86-T97)E<R!N97-T92!C86UP
M;RX@5F]CZB!P<F5E;F-H974@8V]M("5S(&-A<F%C=&5R97,[("(*(G9O8^H@
M9&5V92!P<F5E;F-H97(@8V]M("5S(&]U(&UE;F]S+B(*"B,Z('-I9VYU<"YP
M:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T
M96TZ("5S(@IM<V=S='(@(DAO=79E('5M('!R;V)L96UA(&%D:6-I;VYA;F1O
M("<E<R<@86\@<VES=&5M83H@)7,B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A
M<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*
M;7-G<W1R(")(;W5V92!U;2!P<F]B;&5M82!A;R!E>&-L=6ER(&1O('-I<W1E
M;6$@;W,@9&%D;W,@9&\@=7-UX7)I;R`G)7,G.B`B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T
M<B`B2&]U=F4@=6T@<')O8FQE;6$@86\@97AC;'5I<B`G)7,G(&1O('-I<W1E
M;6$Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B2&]U=F4@=6T@<')O8FQE;6$@86\@871U86QI>F%R("<E<R<Z
M("5S(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3$P"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T
M:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`B
M2&]U=F4@=6T@<')O8FQE;6$@8V]M(&\@96YV:6\@9&\@87)Q=6EV;SH@3F5N
M:'5M("5S(&9O:2!E;G9I861O+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R
M;W=S97(N<&AP.CDQ-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S
M(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@
M8GET97,I+B(*;7-G<W1R("(B"B)(;W5V92!U;2!P<F]B;&5M82!C;VT@;R!E
M;G9I;R!D;R!A<G%U:79O+B!/("5S(&5R82!M86EO<B!Q=64@;R!T86UA;FAO
M("(*(FWA>&EM;R!P97)M:71I9&\@*"5D(&)Y=&5S*2XB"@HC.B!F<F%M97=O
M<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T
M<B`B(@HB2&]U=F4@=6T@<')O8FQE;6$@8V]M(&\@96YV:6\@9&\@87)Q=6EV
M;RX@3R`E<R!F;VD@96YV:6%D;R!P87)C:6%L;65N=&4N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B
M"FUS9W-T<B`B2&]U=F4@=6T@97)R;R!A;R!E>&EB:7(@97-T82!P87)T92!D
M82!M96YS86=E;2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B2&]U=F4@=6T@97)R;R!A;R!I
M;7!O<G1A<B!O<R!D861O<R!D;R!C;VYT871O+B(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(DAO=79E
M('5M(&5R<F\@86\@:6UP;W)T87(@;W,@9&%D;W,@9&\@:4-A;&5N9&%R+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#(*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H
M87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R
M("(B"B)(;W5V92!U;2!E<G)O(&YO(&9O<FUU;.%R:6\@9&4@8V]N9FEG=7)A
MY^-O+B!486QV97H@=F]CZB!D96EX;W4@=6T@8V%M<&\@(@HB;V)R:6=A=/-R
M:6\@96T@8G)A;F-O+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R
M;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC
M=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB
M2&]U=F4@=6T@97)R;R!A;R!E>&5C=71A<B!A(&9U;N?C;R!D92!C873A;&]G
M;R!D92!E;F1E<F7G;W,@97-P96-I9FEC861A+B`B"B)0;W(@9F%V;W(@=&5N
M=&4@;F]V86UE;G1E(&UA:7,@=&%R9&4N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B)(;W5V92!U;2!E
M<G)O(&%O(&%T=6%L:7IA<B!O<R!D971A;&AE<R!D;R!C;VYT871O+B!0;W(@
M9F%V;W(@=&5N=&4@;F]V86UE;G1E("(*(FUA:7,@=&%R9&4N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G:60@
M(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T
M:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*
M(DAO=79E('5M(&5R<F\@86\@871U86QI>F%R(&$@;&ES=&$@9&4@9&ES=')I
M8G5IY^-O+B!0;W(@9F%V;W(@=&5N=&4@(@HB;F]V86UE;G1E(&UA:7,@=&%R
M9&4N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,30X"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@
M<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R(")%<W1E('-E<G9I9&]R($E-05`@
M;N-O('-U<&]R=&$@<&%S=&%S(&-O;7!A<G1I;&AA9&%S+B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@
M9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM
M<V=S='(@(D5S=&4@;N-O('!A<F5C92!S97(@=6T@87)Q=6EV;R!R87(@=N%L
M:61O+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@
M>FEP(&9I;&4N(@IM<V=S='(@(D5S=&4@;N-O('!A<F5C92!S97(@=6T@87)Q
M=6EV;R!Z:7`@=N%L:61O+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,S0*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED
M(&-A<F0@;G5M8F5R+B(*;7-G<W1R(")%<W1E(&[C;R!P87)E8V4@<V5R('5M
M(&[Z;65R;R!D92!C87)TXV\@=N%L:61O+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T
M:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E
M=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB17-T92!C;VYE
M8W1O<B!P97)M:71E(&5N=FEA<B!M96YS86=E;G,@871R87;I<R!D;R!#;&EC
M:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI+"!U=&EL:7IA;F1O
M(&$@05!)($A45%`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC
M+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@
M(B(*(D5S=&4@8V]N96-T;W(@<&5R;6ET92!E;G9I87(@;65N<V%G96YS(&%T
M<F%VZ7,@9&\@9V%T97=A>2!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA
M:6PN8V]M*2P@=71I;&EZ86YD;R!O($%022!(5%10(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*
M(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A
M=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)%<W1E(&-O
M;F5C=&]R('!E<FUI=&4@96YV:6%R(&UE;G-A9V5N<R!A=')A=NES(&1O(&=A
M=&5W87D@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2DL('5T
M:6QI>F%N9&\@;R!!4$D@2%144"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R
M:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O
M=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O
M9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@
M=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*
M;7-G<W1R("(B"B)%<W1E(&-O;F5C=&]R('!E<FUI=&4@96YV:6%R('5M82!M
M96YS86=E;2!V:6$@4TU44"!A=')A=NES(&1O(%9O9&%F;VYE("(*(DET86QI
M86YO+"!S;VUE;G1E('!A<F$@;OIM97)O<R!6;V1A9F]N92X@R2!O8G)I9V%T
M\W)I;R!P;W-S=6ER('5M82!C;VYT82!N;R`B"B)6;V1A9F]N92!)=&%L:6%N
M;R`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.CDX,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8Q"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.3`@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3$Q.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@V(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C`*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3,P.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`R"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U-C$@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@T,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38R
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#D*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`S,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@R
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-3,@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(R-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-#$R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-30*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C8T-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C8@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S,P-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS.#$R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,C`*;7-G:60@(E1H
M:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(D5S=&4@8V%M<&\@Z2!O
M8G)I9V%T\W)I;RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8Y
M"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N
M(@IM<V=S='(@(D5S=&4@8V%M<&\@<&]D92!C;VYT97(@87!E;F%S(&[Z;65R
M;W,@:6YT96ER;W,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R
M,`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@
M86YD('1H92!C;VQO;BXB"FUS9W-T<B`B17-T92!C86UP;R!P;V1E(&-O;G1E
M<B!A<&5N87,@;OIM97)O<R!E(';M<F=U;&$N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3`Y.`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C
M;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B17-T92!C86UP;R!P;V1E
M(&-O;G1E<B!A<&5N87,@=F%L;W)E<R!O8W1A:7,N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$R-PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E
M(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B
M"FUS9W-T<B`B(@HB17-T92!C86UP;R!D979E('-E<B!U;6$@;&ES=&$@9&4@
M;OIM97)O<R!I;G1E:7)O<R!S97!A<F%D82!P;W(@=NUR9W5L87,@;W4@(@HB
M97-P8>=O<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDY,PIM<V=I
M9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R
M(")%<W1E(&-A;7!O(&1E=F4@<V5R('5M(&[Z;65R;R!VX6QI9&\N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R-0IM<V=I9"`B(@HB5&AI<R!F
M:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X
M(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B
M"B)%<W1E(&-A;7!O(&1E=F4@8V]N=&5R('5M(&/S9&EG;R!D92!C;W(@96T@
M9F]R;6%T;R!21T(@2&5X82P@<&]R(&5X96UP;&\@(@HB)R,Q,C,T868G+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4V-0IM<V=I9"`B5&AI<R!F
M;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R(")%<W1E
M(&9O<FUU;.%R:6\@:N$@9F]I('!R;V-E<W-A9&\N(@H*(SH@=&5M<&QA=&5S
M+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I
M<R`E<RXB"FUS9W-T<B`B27-T;R#I("5S+B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z-#4Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@
M:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J
M96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD
M97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI
M<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*
M;7-G<W1R("(B"B)%<W1E(.D@=6T@;V)J971O($MO;&%B($=R;W5P=V%R92X@
M4&%R82!V:7-U86QI>F%R(&5S=&4@;V)J971O('9O8^H@<')E8VES87+A("(*
M(F1E('5M(&-L:65N=&4@9&4@8V]R<F5I;R!Q=64@96YT96YD82!O(&9O<FUA
M=&\@2V]L86(@1W)O=7!W87)E+B!087)A('5M82`B"B)L:7-T82!D92!C;&EE
M;G1E<R!D92!C;W)R96EO(&-O;2!E<W1A<R!F=6[G]65S('!O<B!F879O<B!V
M:7-I=&4@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HU.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W
M<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U
M<B!O=VXN(@IM<V=S='(@(B(*(D5S=&$@;65N<V%G96T@9F]I(&5S8W)I=&$@
M96T@=6T@8V]N:G5N=&\@9&4@8V%R86-T97)E<R`H)7,I('%U92!NXV\@Z2!O
M("(*(FUE<VUO('%U92!O('-E=2XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L
M96%S="!O;F4N(@IM<V=S='(@(D5S=&4@;OIM97)O(&1E=F4@<V5R('!E;&\@
M;65N;W,@=6TN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z
M:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S
M('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B17-T92!S97)V:61O<B!N
MXV\@<&]D92!D97-C;VUP<FEM:7(@87)Q=6EV;W,@>FEP(&4@9WII<"XB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I
M9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G
M<W1R(")%<W1E('-I<W1E;6$@97-TX2!A='5A;&UE;G1E(&1E<V%T:79A9&\N
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@
M(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B17-T92!V
M86QO<B!D979E('-E<B!U;2!N^FUE<F\N(@H*(SH@<V5R=FEC97,O:6UA9V5S
M+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B
M92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R(")%<W1A
M(&IA;F5L82!D979E('-E<B!C:&%M861A(&$@<&%R=&ER(&1A(&IA;F5L82!D
M92!/<.?U97,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV-0IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R(")286EO(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-@IM<V=I9"`B5&EC:V5T<R(*;7-G
M<W1R(")":6QH971E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T
M,CD@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")4:6UE
M(@IM<V=S='(@(DAO<F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S@X"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(D%C;VUP86YH86UE
M;G1O(&1E($AO<N%R:6\B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*;7-G
M:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(D9O<FUA=&\@9&4@:&]R82(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U,S4*;7-G:60@(E1I;64@<V5L
M96-T:6]N(@IM<V=S='(@(E-E;&7GXV\@9&4@:&]R82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(E1I;6]R($QE<W1E(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L
M:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B
M5.UT=6QO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R(")!<W-U
M;G1O("AD:6-A*3HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R(")087)A(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U,@IM<V=I9"`B
M(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O
M;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC
M:VEN9RXB"FUS9W-T<B`B(@HB4&%R82!S96QE8VEO;F%R(&WZ;'1I<&QO<R#M
M=&5N<RP@<V5G=7)E(&$@=&5C;&$@0V]N=')O;"`H4$,I(&]U($-O;6UA;F0@
M(@HB*$UA8RD@86\@8VQI8V%R+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,#`*;7-G:60@(E1O9&%Y(@IM<V=S='(@(DAO:F4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(X"FUS9VED
M(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B5')O8V%R('!A<F$@8_-D
M:6=O($A434PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4;V=O(@IM<V=S='(@
M(E1O9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U(@IM<V=S='(@
M(E1O:V5L874B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`R
M"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R(")!;6%N:.,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$P"FUS9VED(")4;VYG82(*;7-G<W1R(")4;VYG82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B
M5&]P(@IM<V=S='(@(E1O<&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM
M<V=S='(@(E%U861R;R!D;R!4;W!O("A?=&]P*2(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L871I;VYS(@IM<V=S='(@(E1R
M861UY_5E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4
M;V)A9V\B"FUS9W-T<B`B5')I;F1A9&4@92!4;V)A9V\B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-SDT"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM
M<V=S='(@(E9E<F1A9&5I<F\@;W4@9F%L<V\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R
M(")497(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@
M(E1U;NUS:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T
M<B`B5'5R<75I82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED
M(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G<W1R(")4=7)C;R`H25-/+3@X
M-3DM.2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N:7-T86XB"FUS
M9W-T<B`B5'5R8V]M96YI<W3C;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U
M<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("));&AA<R!4=7)K<R!E
M($-A:6-O<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R
M(")4=79A;'4B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C8T"FUS9VED
M(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B4')E96YC:&$@8V]M('-U
M82!E<V-O;&AA.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C4X"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`BS6YD:6-E(%4N5BXZ
M("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR
M-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R
M(")54DPB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4T,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R
M>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@(E523"!D;R!S974@<F5L873S<FEO
M(&1E('-I='5AY^-O(&1E(&5N=')E9V$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@
M(E523#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`B
M56=A;F1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G<W1R
M(")58W+B;FEA(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$Y
M"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(DEM<&]S<^UV96P@86-E<W-A<B!D:7)E=/-R:6\@5D93+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE
M('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U
M<"XB"FUS9W-T<B`B26UP;W-S[79E;"!A9&EC:6]N87(@:6YF;W)M8>?U97,@
M97AT<F%S(&1E('5S=>%R:6\@86\@<F5G:7-T<F%R+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,SDS"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R("));7!O<W/M=F5L(&%L=&5R87(@<&5R;6ES<^-O(&1O(&%R
M<75I=F\@5D93(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HS.3(@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@
M9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("));7!O<W/M=F5L(&%L=&5R
M87(@<&5R;6ES<^-O(&1O(&%R<75I=F\@5D93("5S+R5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z-S@V"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(DEM<&]S<^UV96P@
M86QT97)A<B!P87)A("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F
M:6QE('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R("));7!O<W/M=F5L('9E<FEF
M:6-A<B!O('1A;6%N:&\@9&\@87)Q=6EV;R!D92!<(B5S7"(N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-CDU(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z,3`R.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z.#4P"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F
M:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R("));7!O<W/M=F5L('9E
M<FEF:6-A<B!O('1A;6%N:&\@9&\@87)Q=6EV;R!D92!<(B5S+R5S7"(N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S.0IM<V=I9"`B56YA
M8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B26UP;W-S
M[79E;"!C;VYE8W1A<B!A;R!S97)V:61O<B!344PN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HX-S`*;7-G:60@(E5N86)L92!T;R!C;VYN96-T
M('=I=&@@4U-,+B(*;7-G<W1R("));7!O<W/M=F5L(&-O;F5C=&%R('5T:6QI
M>F%N9&\@4U-,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S
M,B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S<*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P-"!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,C`Y"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HR,3<*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G
M<W1R("));7!O<W/M=F5L(&-O<&EA<B!A<G%U:79O(%9&4RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C,W,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G
M<W1R("));7!O<W/M=F5L(&-R:6%R(&1I<F5T\W)I;R!61E,@7"(E<UPB+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,V,2!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HR-C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B26UP;W-S[79E;"!C<FEA<B!D:7)E=/-R:6\@
M5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(DEM<&]S
M<^UV96P@8W)I87(@87)Q=6EV;R!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S[79E
M;"!R96YO;65A<B!A<G%U:79O(%9&4R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C<R"FUS9VED(")5;F%B;&4@=&\@8W)E871E
M(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R("));7!O<W/M=F5L(&-R:6%R(&%R
M<75I=F\@5D93('9A>FEO+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]T87(N<&AP.C<V"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]G>FEP+G!H<#HW.0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T
M82XB"FUS9W-T<B`B26UP;W-S[79E;"!D97-C;VUP<FEM:7(@9&%D;W,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,C@@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HS,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M+B(*;7-G<W1R("));7!O<W/M=F5L(&5X8VQU:7(@7"(E<UPB+"!O(&1I<F5T
M\W)I;R!NXV\@97-TX2!V87II;RXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X
M(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R("));7!O
M<W/M=F5L(&5X8VQU:7(@7"(E<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HS,S@@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS
M.34*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0R"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T
M(&5M<'1Y(@IM<V=S='(@(DEM<&]S<^UV96P@97AC;'5I<B`E<RP@;R!D:7)E
M=/-R:6\@;N-O(&5S=.$@=F%Z:6\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,S4V(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS-C`*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R
M96-U<G-I=F5L>2XB"FUS9W-T<B`B26UP;W-S[79E;"!E>&-L=6ER(')E8W5R
M<VEV86UE;G1E(&\@9&ER973S<FEO(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HS-#0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@9&ER96-T;W)Y+B(*;7-G<W1R("));7!O<W/M=F5L(&5X8VQU:7(@9&ER
M973S<FEO(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0R
M,"!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0S,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*
M;7-G<W1R("));7!O<W/M=F5L(&5X8VQU:7(@9&ER973S<FEO(%9&4SH@)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(DEM<&]S<^UV96P@97AC;'5I<B!A<G%U:79O(%9&4R!<(B5S
M7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S$P(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,CDQ"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HQ-C<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X
M,`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.3$*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,Y.0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@9FEL92XB"FUS9W-T<B`B26UP;W-S[79E;"!E>&-L=6ER(&%R<75I=F\@
M5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C0X"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B!<
M(B5S7"(N(@IM<V=S='(@(DEM<&]S<^UV96P@97AC;'5I<B!A<G%U:79O(%9&
M4R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C
M=7)S:79E;'DZ("5S+B(*;7-G<W1R("));7!O<W/M=F5L(&5X8VQU:7(@5D93
M(')E8W5R<VEV86UE;G1E.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C@S-`IM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B26UP;W-S[79E;"!D971E<FUI;F%R(&\@
M9&ER973S<FEO(&%T=6%L+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C`T"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I
M8V%T92!D971A:6QS(@IM<V=S='(@(DEM<&]S<^UV96P@97AT<F%I<B!D971A
M;&AE<R!D;R!C97)T:69I8V%D;R(*"B,Z(&9R86UE=V]R:R].971?24U34"])
M35-0+G!H<#HT,S<@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T:"YP:'`Z
M,3(S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D
M969I;FET:6]N(&]F("5S+B(*;7-G<W1R("));7!O<W/M=F5L(&-A<G)E9V%R
M(&$@9&5F:6YIY^-O(&1E("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C(P,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#@*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W-"!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@;6]V
M92!61E,@9FEL92XB"FUS9W-T<B`B26UP;W-S[79E;"!M;W9E<B!O(&%R<75I
M=F\@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#8*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HV-3(@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HY.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(DEM<&]S<^UV96P@86)R:7(@87)Q=6EV;R!61E,@
M7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X-"!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#$*;7-G:60@(E5N86)L92!T;R!O
M<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R("));7!O<W/M=F5L
M(&%B<FER(&%R<75I=F\@5D93('!A<F$@9W)A=F'GXV\N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z.#,@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,3,W"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW
M-@IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(DEM
M<&]S<^UV96P@86)R:7(@87)Q=6EV;R!61E,N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P
M96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R("));7!O<W/M=F5L(&%B
M<FER(&%R<75I=F\@8V]M<')I;6ED;RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z.#4V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL
M97-I>F4H*2!F86EL960I+B(*;7-G<W1R("));7!O<W/M=F5L(&QE<B!A<G%U
M:79O(%9&4R`H9FEL97-I>F4H*2!F86QH;W4I+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HX.#<*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE
M("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(DEM<&]S<^UV96P@
M;&5R(&%R<75I=F\@5D93("AG971&:6QE4VEZ92@I(&9A;&AO=2DN(@H*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N
M<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B
M26UP;W-S[79E;"!L97(@;R!A<G%U:79O.B`B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HV-S8*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V
M9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B26UP;W-S[79E;"!L97(@82!R
M86EZ(&1O(&1I<F5T\W)I;R!61E,N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HQ,3`T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X
M:7-T<R(*;7-G<W1R("));7!O<W/M=F5L(')E;F]M96%R("5S('!A<F$@)7,Z
M(&$@<&%S=&$@9&4@9&5S=&EN;R!JX2!E>&ES=&4B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DEM<&]S<^UV96P@<F5N;VUE
M87(@;R!D:7)E=/-R:6\@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(DEM<&]S<^UV96P@<F5N
M;VUE87(@9&ER973S<FEO(%9&4SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HR-S$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<^UV96P@<F5N;VUE87(@87)Q=6EV
M;R!61E,@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C8Q-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N
M(@IM<V=S='(@(DEM<&]S<^UV96P@<F5N;VUE87(@87)Q=6EV;R!61E,@)7,O
M)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,C8@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q,PHC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z-#4R(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HR.3,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P.0IM
M<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`B26UP
M;W-S[79E;"!R96YO;65A<B!A<G%U:79O(%9&4RXB"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@
M(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R("));7!O<W/M=F5L
M(&5X96-U=&%R("=M:VES;V9S)RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L
M871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R("));7!O<W/M=F5L('1R
M861U>FER(&5S=&4@9&]C=6UE;G1O(%=O<F0B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C$U-"!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R("));7!O<W/M=F5L(&=R879A<B!A<G%U:79O
M(%9&4R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,3@V"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F
M86EL960I+B(*;7-G<W1R("));7!O<W/M=F5L(&=R879A<B!A<G%U:79O(%9&
M4R`H8V]P>2@I(&9A;&AO=2DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C@X(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#8*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$U,0IM<V=I9"`B
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(DEM<&]S
M<^UV96P@9W)A=F%R(&1A9&]S(&1O(&%R<75I=F\@5D93+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HX-C(*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS9W-T<B`B26UP
M;W-S[79E;"!G<F%V87(@87)Q=6EV;R!61E,L('%U;W1A(&5X8V5D97+A+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*
M;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R(")3=6)L:6YH861O(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM
M<V=S='(@(D1E<V9A>F5R($%L=&5R8>?U97,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U
M<B!L87-T(&%C=&EO;B(*;7-G<W1R(")$97-F87H@<W5A(/IL=&EM82!AY^-O
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y,`IM
M<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN
M96-T:6]N.B`B"FUS9W-T<B`B4F5S<&]S=&$@:6YE<W!E<F%D82!D;R!S97)V
M:61O<B!D=7)A;G1E(&$@8V]N97CC;SH@(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,T,0HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS-S@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E
M(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B4F5S<&]S=&$@:6YE<W!E<F%D
M82!D;R!S97)V:61O<B!P87)A.B`B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G
M<W1R(")396T@8V%T96=O<FEA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.3(*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R(")5;FEC;V1E("A5
M5$8M."DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T
M97,B"FUS9W-T<B`B16UI<F%D;W,@P7)A8F5S(%5N:61O<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B4F5I;F\@56YI
M9&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S
M='(@(D5S=&%D;W,@56YI9&]S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI
M=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(DEL
M:&%S(%!E<FEFZ7)I8V%S($UE;F]R97,@9&]S($5S=&%D;W,@56YI9&]S(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8R(&QI8B]";&]C:R]M
M971A<BYP:'`Z-S@*;7-G:60@(E5N:71S(@IM<V=S='(@(E5N:61A9&5S(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S,`HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C4X"FUS9VED(")5;FMN;W=N(@IM<V=S='(@
M(D1E<V-O;FAE8VED;R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H
M05!)($UE<W-A9V4@240I+B(*;7-G<W1R(")A<&EM<V=I9"!D97-C;VYH96-I
M9&\@*$%022!-97-S86=E($E$*2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI
M;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B8VQI;7-G:60@
M9&5S8V]N:&5C:61O("A#;&EE;G0@365S<V%G92!)1"DN(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-PIM<V=I9"`B56YK;F]W;B!L;V-A
M=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B3F5N:'5M82!L;V-A;&EZ8>?C;R!C
M;VYF:6=U<F%D82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@
M<&%S<W=O<F0N(@IM<V=S='(@(E5S=>%R:6\@;W4@<V5N:&$@9&5S8V]N:&5C
M:61O<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M
M96YT(@IM<V=S='(@(D1E<W9I;F-U;&%R(&\@96QE;65N=&\@871U86PB"@HC
M.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P,@IM<V=I9"`B
M56YN86UE9"(*;7-G<W1R(")396T@3F]M92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL
M96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O
M9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@
M3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI
M8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E
M<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@HB4V-R:7!T<R!NXV\@<')I
M=FEL96=I861O<R!NXV\@<&]D96T@=71I;&EZ87(@0V]R=&%R+T-O<&EA<B]#
M;VQA<B!P;W(@<F%Z]65S("(*(F1E('-E9W5R86[G82X@0VQI<75E(&5M($]+
M('!A<F$@=F5R(&$@;F]T82!TZ6-N:6-A(&5M(&UO>FEL;&$N;W)G(&$@<75A
M;"`B"B)E;G-I;F$@8V]M;R!P97)M:71I<B!S8W)I<'1S(&%C97-S87)E;2!A
M(.%R96$@9&4@=')A;G-F97+J;F-I82XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C
M;VQO<B(*;7-G<W1R(")$97-M87)C87(@8V]R(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#<@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HY,C<*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HY,S,*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R
M(")%>'1E;G/C;R!.XV\@4W5P;W)T861A(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI
M;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R(")!='5A;&EZ87(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R("(E<R!A='5A;&EZ861O(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-@IM<V=I9"`B
M57!D871E('5S97(B"FUS9W-T<B`B071U86QI>F%R('5S=>%R:6\B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`B)R5S)R!A='5A;&EZ861O
M+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R
M861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R(")38W)I<'0@9&4@871U86QI
M>F'GXV\@<F5M;W9I9&\N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W
M."!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DX"FUS
M9VED(")5<&QO860B"FUS9W-T<B`B16YV:6%R(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N
M('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(B(*(E1O9&]S
M(&%R<75I=F]S(&1E("!C;VYF:6=U<F'G]65S(&1A<R!A<&QI8V'G]65S(&9O
M<F%M(&5N=FEA9&]S(&%O('-E<G9I9&]R+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P
M<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B06QF86)E=&\@;&%T:6YO(&5M
M(&UA:?IS8W5L;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E
M<G,B"FUS9W-T<B`B3OIM97)O<R!R;VUA;F]S(&5M(&UA:?IS8W5L;R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B57)U9W5A:2(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP
M.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G
M<W1R(")5=&EL:7IA<B!!='5A;#H@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*
M;7-G<W1R(")5=&EL:7IA<B!34TPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3(W"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E
M;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R(")5=&EL:7IA<B!S92!O(&YO
M;64O<V5N:&$@Z2!D:69E<F5N=&4@;F\@<V5R=FED;W(@24U34"XB"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"FUS9VED(")5<V5R
M(@IM<V=S='(@(E5S=>%R:6]S(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+U)E9VES=')Y+G!H<#HW-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E
M<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(E5S=>%R:6\@
M)7,@;N-O(&5S=.$@875T;W)I>F%D;R!P87)A("5S+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R
M(")!9&UI;FES=')AY^-O(&1E(%5S=>%R:6]S(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HR-#4*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G
M<W1R(")/<.?U97,@9&4@57-UX7)I;W,B"@HC.B!S:6=N=7`N<&AP.C8R"FUS
M9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R(")296=I<W1R;R!D92!5
M<W7A<FEO<R(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T
M<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S
M='(@(E)E9VES=')O(&1E(%5S=>%R:6]S(&5S=.$@9&5S86)I;&ET861O(&YE
M<W1E('-I=&4N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V.0IM<V=I
M9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R(")#;VYT82!D92!U
M<W7A<FEO(&[C;R!E;F-O;G1R861A(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHW,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM
M<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B57-UX7)I;R(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R(")5
M<W7A<FEO("<E<R<@:N$@97AI<W1E+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(E5S=>%R
M:6\Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B
M57-E<FYA;64Z("(*;7-G<W1R(")5<W7A<FEO.B`B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES
M=&5M.B(*;7-G<W1R(")5<W7A<FEO<R!N;R!S:7-T96UA.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B57IB97%U:7-TXV\B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-S`@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C8R"FUS9VED(")61E,@9&ER96-T;W)Y(&1O
M97,@;F]T(&5X:7-T+B(*;7-G<W1R(")/(&1I<F5T\W)I;R!61E,@;N-O(&5X
M:7-T92XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3(P"FUS9VED
M(")686-A=&EO;B(*;7-G<W1R(")&Z7)I87,B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HX-S`*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I
M;F-L=61E.B`B"FUS9W-T<B`B3&]C86QI>F'G]65S(';A;&ED87,@96YC;VYT
M<F%D87,@:6YC;'5E;3H@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV,SD*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(E9A;&ED861E
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU.3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C4U"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*
M;7-G<W1R(")686QO<B!E;2!M:6YU=&]S(&$@<&%R=&ER(&1E(&%G;W)A+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V,"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,3@Q"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES
M(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R(")/('9A
M;&]R(&5S=.$@86-I;6$@9&\@=&%M86YH;R!MX7AI;6\@9&4@)7,N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T."!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,C<P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,C`@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDQ-PHC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU97,B"FUS
M9W-T<B`B5F%L;W)E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M,3,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Y,`IM<V=I9"`B5F%L=65S
M('1O('-E;&5C="!F<F]M(@IM<V=S='(@(E9A;&]R97,@<&%R82!S96QE8VEO
M;F%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R(")6
M86YU871U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,PIM
M<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B5F%R:>%V96PB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`B5F5N97IU96QA(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E
M<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E
M;B!T86UP97)E9"!W:71H+B(*;7-G<W1R(")&86QH82!N82!V97)I9FEC8>?C
M;R`M(&5S=&$@;65N<V%G96T@<&]D92!T97(@<VED;R!A9'5L=&5R861A+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED
M(")697)S:6]N(@IM<V=S='(@(E9E<G/C;R(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR,C@*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R
M(")#;VYT<F]L92!D92!697)SXV\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A
M;&EG;B(*;7-G<W1R(")!;&EN:&%M96YT;R!V97)T:6-A;"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E
M<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B36%R9V5M('9E<G1I8V%L(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I
M9"`B5F5R=&EC86PZ(@IM<V=S='(@(E9E<G1I8V%L.B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")697)Y($AI
M9V@B"FUS9W-T<B`B375I=&\@06QT82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@
M(E9I970@3F%M(@IM<V=S='(@(E9I971NXR(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DS"FUS9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S='(@
M(E9I971N86UI=&$@*%9)4T-)22DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HY-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E
M<R(*;7-G<W1R(")697(@)7,B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS
M"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(E9I
M<W5A;&EZ87(@=6UA('#A9VEN82!W96(@97AT97)N82(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")6:65W(&%S("5S(@IM<V=S='(@(E9I<W5A;&EZ87(@8V]M;R`E<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H
M(@IM<V=S='(@(DEL:&%S(%9I<F=E;G,L($)R:73B;FEC87,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R("))
M;&AA<R!6:7)G96YS+"!%+E4N02XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(Q-@IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R(")6:7-I8FEL:61A9&4B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4R"FUS9VED(")6
M:7-I8FEL:71Y.B`B"FUS9W-T<B`B5FES:6)I;&ED861E.B`B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM
M<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B5F]D869O
M;F4@271A;&EA;F\@=FEA(%--5%`B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED
M(")705).(@IM<V=S='(@(D%414['PT\B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%
M34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B051%3L?#
M3R$A(2!214U/5D$@3R!30U))4%0@34%.54%,345.5$4@1$4@)7,N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@
M(E=)3B!V:6$@2%144"(*;7-G<W1R(")724X@=FEA($A45%`B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R(")786QL
M:7,@92!&=71U;F$B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R,2!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B071E;N?C;R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G
M:60@(E=E(@IM<V=S='(@(E%U82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R(")0
M<F5V:7/C;R!D;R!496UP;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HT,38*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G
M<W1R(")$861O<R!D;R!#;&EM82!F;W)N96-I9&\@<&]R(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"FUS9VED(")796%T:&5R+F-O;2(*;7-G
M<W1R(")796%T:&5R+F-O;2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V
M"FUS9VED(")796(B"FUS9W-T<B`B5V5B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0S.0IM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B4VET92!7
M96(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B4V5M86YA;&UE;G1E(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@(E=E;&-O;64B
M"FUS9W-T<B`B0F5M+79I;F1O(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H<"UF
M;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B0F5M+79I;F1O
M(&%O("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M
M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@
M(E=E;&-O;64L("5S(@IM<V=S='(@(D)E;2UV:6YD;RP@)7,B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM
M,2DB"FUS9W-T<B`B3V-I9&5N=&%L("A)4T\M.#@U.2TQ*2(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ
M-2DB"FUS9W-T<B`B3V-I9&5N=&%L("A)4T\M.#@U.2TQ-2DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B4V%H87)A($]C
M:61E;G1A;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES
M<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B475E(&%P;&EC8>?C;R`E<R!D
M979E<FEA(&5X:6)I<B!A</-S(&$@8V]N97CC;S\B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI
M=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B475A;"!O(&-A<F%C=&5R92!D96QI
M;6ET861O<C\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM
M<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R(")1
M=6%L(&\@8V%R86-T97)E(&1E(&-I=&'GXV\_(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C(*;7-G:60@(E=H97)E:7,@
M075S=')A;&EA(&UA<"(*;7-G<W1R(")-87!A<R!!=7-T<F%L:6%N;W,@5VAE
M<F5I<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@
M<&AA<V5S(@IM<V=S='(@(E%U86ES(&9A<V5S(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S-@IM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@
M9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R(")1=6%I<R!P;'5G
M:6YS(&AA8FEL:71A<B!P87)A(&\@961I=&]R(%)I8V@@5&5X="XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T
M"FUS9VED(")7:61T:"(*;7-G<W1R("),87)G=7)A(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$Q-`IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S
M(@IM<V=S='(@(DQA<F=U<F$@96T@=6YI9&%D97,@0U-3(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T
M:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N
M(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`B3&%R9W5R82!D;R!M96YU("5S(&1O
M(&QA9&\@97-Q=65R9&\@*'1E<N$@969E:71O(&YA('!R\WAI;6$@8V]N97CC
M;RDZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R("),87)G
M=7)A(&1A('1A8F5L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@(E5N
M:61A9&4@9&4@3&%R9W5R82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`B3&%R
M9W5R83HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$U"FUS9VED
M(")7:6MI(@IM<V=S='(@(E=I:VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C@Y(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8V"FUS9VED(")7:6YD(@IM<V=S='(@(E9E;G1O(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(E=I;F0@
M16%R;'DB"FUS9W-T<B`B5F5N=&]S('!E;&$@;6%N:.,B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C@W"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM
M<V=S='(@(E9E;&]C:61A9&4@9&\@=F5N=&\@96T@;O-S(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ-C,*;7-G:60@(E=I;F0Z(@IM<V=S='(@(E9E;G1O
M.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@
M(E=I;F0Z("(*;7-G<W1R(")696YT;SH@(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T<B`B4V%B961O<FEA(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y.`IM<V=I9"`B5VES:&QI
M<W0B"FUS9W-T<B`B3&ES=&$@9&4@<&5D:61O<R(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R(")4<F%B86QH;R(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM
M<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(D5N9&5R9>=O($-O;65R8VEA
M;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B1F]N92!#;VUE<F-I86PB
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ.3,@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(E=R
M;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L
M(&9O=6YD("5D+B(*;7-G<W1R(").^FUE<F\@:6YC;W)R971O(&1E(&-A;7!O
M<R!N82!L:6YH82`E9"X@17-P97)A9&]S("5D+"!E;F-O;G1R861O<R`E9"XB
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@
M)60L(&9O=6YD("5D+B(*;7-G<W1R(").^FUE<F\@97)R861O(&1E(&-A;7!O
M<RX@17-P97)A9&]S("5D+"!E;F-O;G1R861O<R`E9"XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HQ,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS
M9W-T<B`B3V9F<V5T("5D(&EN8V]R<F5T;R!A;R!L97(@;R!A<G%U:79O(%9&
M4RXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C0U"FUS9VED(")8
M+5)E9B(*;7-G<W1R(")8+5)E9B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN
M=',B"FUS9W-T<B`B4F5S=')IY_5E<R!"X7-I8V%S(%@U,#EV,R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y
M=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(E5T:6QI>F'GXV\@9&4@
M0VAA=F4@17AT96YD:61A(%@U,#EV,R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E
M<FYA=&EV92!.86UE(@IM<V=S='(@(DYO;64@06QT97)N871I=F\@9&4@07-S
M=6YT;R!8-3`Y=C,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4Y-@IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B
M"FUS9W-T<B`B261E;G1I9FEC861O<B!D82!#:&%V92!D92!!<W-U;G1O(%@U
M,#EV,R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@S
M"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R(")%>'1E;G/U97,@
M6#4P.78S(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM
M<V=S='(@(D%!(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#4T"FUS9VED(")965E9(@IM<V=S='(@(D%!04$B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$P.0IM<V=I9"`B
M66%H;V\A(&UA<"(*;7-G<W1R(")-87!A(%EA:&]O(2(*"B,Z(&9R86UE=V]R
M:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L
M>2(*;7-G<W1R(")!;G5A;&UE;G1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B
M665M96XB"FUS9W-T<B`B3.IM96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.38T"FUS9VED(")997,B"FUS9W-T<B`B4VEM
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R(")3:6TL($5U($-O;F-O
M<F1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\
M/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@
M(B(*(E9O8^H@97-TX2!E;2!-3T1/(%1%6%1/+B`@571I;&EZ82!O(&)O=.-O
M(%L\/ET@<&%R82!V;VQT87(@<&%R82!O(&UO9&\@(@HB5UE325=91RXB"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C(S
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O
M(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R(")6;V/J(&[C
M;R!E<W3A(&%U=&]R:7IA9&\@82!C<FEA<B!M86ES(&1E("5D(&)L;V-O<RXB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,34*;7-G:60@(EEO
M=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(E9O8^H@;N-O(&5S
M=.$@875T96YT:6-A9&\N(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT
M:71Y+G!H<#HS,#@*;7-G:60@(EEO=2!C86YN;W0@:&%V92!T:&4@)UQ<)R!C
M:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(E9O8^H@;N-O
M('!O9&4@=&5R(&\@8V%R86-T97(@7%P@;F\@<V5U(&YO;64N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U.2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.3<Y"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M
M86EL(&%D9')E<W,N(@IM<V=S='(@(E9O8^H@;N-O(&9O<FYE8V5U('5M(&5N
M9&5R9>=O(&1E(&4M;6%I;"!VX6QI9&\N(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N
M)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T
M:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*
M(E9O8^H@;N-O(&UA<&5O=2!N96YH=6T@8V%M<&\@9&\@87)Q=6EV;R!I;7!O
M<G1A9&\@86]S(&-A;7!O<R!C;W)R97-P;VYD96YT97,@(@HB96T@)7,N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@W"FUS9VED(")9;W4@:&%V
M92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(E9O8^H@9F]I(&1E<V-O;F5C
M=&%D;RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8U"FUS9VED
M("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB
M97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T
M:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@HB
M5F]CZB!D979E('!R965N8VAE<B!U;2!N^FUE<F\@9&4@=&5L969O;F4@8V5L
M=6QA<B!VX6QI9&\L('-O;65N=&4@9.UG:71O<R`B"B)C;VT@=6T@;W!C:6]N
M86P@)RLG('!A<F$@9&ES8V%G96T@9&4@<')E9FEX;R!I;G1E<FYA8VEO;F%L
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.3(*;7-G:60@(EEO
M=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(E9O8^H@
M9&5V92!P<F5E;F-H97(@=6T@=F%L;W(@=N%L:61O+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N
M9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS
M9W-T<B`B5F]CZB!D979E(&-O;F9I9W5R87(@=6T@8V]N96-T;W(@1&%T851R
M964@<&%R82!U=&EL:7IA<B!#861A<W1R;W,N(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HT-C(*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A
M(%9&4R!B86-K96YD+B(*;7-G<W1R(")6;V/J(&1E=F4@8V]N9FEG=7)A<B!U
M;2!C;VYE8W1O<B!61E,N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M
M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G
M<W1R("(B"B)6;V/J(&1E=F4@9&5S8W)E=F5R(&\@<')O8FQE;6$@86YT97,@
M9&4@96YV:6%R(&\@<F5L873S<FEO(&1E('!R;V)L96UA+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO
M=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T
M;R(*;7-G<W1R(")6;V/J(&1E=F4@9F]R;F5C97(@82!54DP@;VYD92!O(&QI
M;FL@87!O;G1A(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*
M;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E
M9"XB"FUS9W-T<B`B5F]CZB!D979E('-E;&5C:6]N87(@=6T@<V5R=FED;W(@
M<&%R82!S97(@97AC;'7M9&\N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T
M+B(*;7-G<W1R(")6;V/J(&1E=F4@97-P96-I9FEC87(@=6T@=7-UX7)I;R!P
M87)A(&5X8VQU:7(N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9
M;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R
M(")6;V/J(&1E=F4@97-P96-I9FEC87(@=6T@=7-UX7)I;R!P87)A(')E;6]V
M97(N(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U
M<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(E9O8^H@9&5V92!E<W!E8VEF:6-A
M<B!U;2!U<W7A<FEO('!A<F$@861I8VEO;F%R+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@=7!D871E+B(*;7-G<W1R(")6;V/J(&1E=F4@97-P96-I9FEC87(@=6T@
M=7-UX7)I;R!P87)A(&%T=6%L:7IA<BXB"@HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B5F]CZB!D979E
M(&5S<&5C:69I8V%R('5M82!AY^-O('!A<F$@97AE8W5T87(N(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G
M:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T
M<B`B5F]CZB!D979E('!R965N8VAE<B!U;2!N;VUE('!A<F$@82!N;W9A(&-A
M=&5G;W)I82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I
M=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A
M;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R(")6;V/J('!R96-I<V$@
M9F]R;F5C97(@=6T@;OIM97)O(&1E('1E;&5F;VYE(&ET86QI86YO(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<U"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN
M(&%G86EN+B(*;7-G<W1R(")3=6$@<V5S<^-O("5S(&5X<&ER;W4N(%!O<B!F
M879O<BP@8V]N96-T92US92!N;W9A;65N=&4N(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G:60@(EEO=7(@16UA:6P@061D<F5S
M<R(*;7-G<W1R(")3974@16YD97)EYV\@9&4@12UM86EL(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(Q-0IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S
M.B(*;7-G<W1R(")3974@16YD97)EYV\@9&4@4F5M971E;G1E("A$93HI.B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-R!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@U"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY,@IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G
M<W1R(")3=6%S($EN9F]R;6'G]65S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.3<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N
M970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F
M('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y
M+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB4V5U($5N9&5R
M9>=O(&1E($EN=&5R;F5T(&UU9&]U(&1E<V1E(&\@:6[M8VEO(&1E('-U82!S
M97-SXV\@)7,N(%!A<F$@(@HB<')O=&5G97(@<W5A('-E9W5R86[G82!V;V/J
M(&1E=F4@8V]N96-T87(M<V4@;F]V86UE;G1E+B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R($YA;64B"FUS9W-T
M<B`B4V5U($YO;64B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI
M;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O
M97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B
M"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@
M;75S="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C:V5N
M9"XB"FUS9W-T<B`B(@HB4V5U(&)A8VME;F0@9&4@875T96YT:6-AY^-O(&[C
M;R!S=7!O<G1A(&%D:>?C;R!D92!U<W7A<FEO<RP@;W4@82!F=6[GXV\@9F]I
M("(*(F1E<V%B:6QI=&%D82!P;W(@86QG=6UA(&]U=')A(')A>N-O+B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB
M66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@
M;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES
M86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"B)3974@
M8F%C:V5N9"!D92!A=71E;G1I8V'GXV\@;N-O('-U<&]R=&$@;&ES=&%G96T@
M9&4@=7-UX7)I;W,L(&]U(&$@9G5NY^-O("(*(F9O:2!D97-A8FEL:71A9&$@
M<&]R(&%L9W5M82!O=71R82!R87KC;RXB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W
M<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI
M;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C
M=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)3974@
M;F%V96=A9&]R('!A<F5C92!T97(@86QT97)A9&\@9&5S9&4@;R!I;NUC:6\@
M9&4@<W5A('-E<W/C;R`E<RX@4&%R82`B"B)P<F]T96=E<B!S=6$@<V5G=7)A
M;N=A+"!V;V/J(&1E=F4@8V]N96-T87(M<V4@;F]V86UE;G1E+B(*"B,Z(&QI
M8B]";&]C:R]I9G)A;64N<&AP.C4U"FUS9VED(")9;W5R(&)R;W=S97(@9&]E
M<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S='(@(E-E=2!N879E
M9V%D;W(@;N-O('-U<&]R=&$@97-T82!F=6[GXV\N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E
M<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#
M;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"B)3
M974@;F%V96=A9&]R(&[C;R!S=7!O<G1A(&5S=&$@;W#GXV\@9&4@:6UP<F5S
M<^-O+B!0<F5S<VEO;F4@0V]N=')O;"]/<'1I;VX@(@HB*R!0('!A<F$@:6UP
M<FEM:7(N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V,0IM<V=I9"`B
M66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B4V5U(&9U<V\@:&]R
MX7)I;R!A='5A;#HB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3$Q"FUS9VED
M(")9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS
M9W-T<B`B4W5A(&ED96YT:61A9&4@<&%D<N-O(&9O:2!A;'1E<F%D82XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38Q"FUS9VED(")9;W5R(&1E9F%U
M;'0@:61E;G1I='DZ(@IM<V=S='(@(E-U82!I9&5N=&ED861E('!A9'+C;SHB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`T"FUS9VED(")9;W5R(&9U
M;&P@;F%M93HB"FUS9W-T<B`B4V5U(&YO;64@8V]M<&QE=&\Z(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3DY"FUS9VED(")9;W5R(&QO9VEN(&AA
M<R!E>'!I<F5D+B(*;7-G<W1R(")3=6$@8V]N97CC;R!E>'!I<F]U+B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*
M;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T
M<B`B4W5A(&YO=F$@<V5N:&$@<&%R82`E<R#I.B`E<R(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@
M:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E
M<W-I;VXN(@IM<V=S='(@(E-U87,@;W#G]65S(&9O<F%M(&%T=6%L:7IA9&%S
M('!O<B!C875S82!D82!D=7)AY^-O(&1E<W1A('-E<W/C;RXB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I
M;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R(")3=6%S(&]PY_5E<R!F
M;W)A;2!A='5A;&EZ861A<RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="(*
M;7-G<W1R(")3=6$@;F]V82!S96YH82!F;VD@9V5R861A(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I
M;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B"B)3=6$@
M;F]V82!S96YH82!F;VD@9V5R861A+"!V97)I9FEQ=64@<V5U(&4M;6%I;"!E
M(&-O;F5C=&4M<V4@8V]M('-U82!N;W9A("(*(G-E;FAA+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.C<S,PIM<V=I9"`B66]U<B!P87-S=V]R9"!H
M87,@97AP:7)E9"XB"FUS9W-T<B`B4W5A('-E;FAA(&5X<&ER;W4N(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E
M;6]T92!S97)V97)S.B(*;7-G<W1R(")3975S('-E<G9I9&]R97,@<F5M;W1O
M<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM
M<V=S='(@(DEU9V]S;.%V:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R("):86ER92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("):XFUB:6$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$X"FUS9VED(")::6UB86)W92(*;7-G<W1R(")::6UB86)W92(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS
M9W-T<B`B6FEP<'DB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X
M=%TB"FUS9W-T<B`B6T]C=6QT87(@5&5X=&\@0VET861O72(*"B,Z('-E<G9I
M8V5S+W!R;V)L96TN<&AP.C@Y"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM
M<V=S='(@(EM296QA=/-R:6\@9&4@4')O8FQE;6%=(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U
M;W1E9"!497AT("TB"FUS9W-T<B`B6T5X:6)I<B!497AT;R!#:71A9&\@+2(*
M"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O
M=&5S+G!H<#HQ-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D
M(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B6T5X:6)I<B!497AT;R!#:71A
M9&\@+2`E<R!L:6YH87-=(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM
M<V=S='(@(EML:6YH82`E<R!D92`E<UTB"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C$U-#4@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0IM
M<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E]!9&UI;FES=')AY^-O
M(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(E]#
M3$DB"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*;7-G
M<W1R(")$871A7U1R964B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM
M<V=S='(@(D5?>&-L=6ER($-O;'5N82(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM
M<V=I9"`B7T=R;W5P<R(*;7-G<W1R(")?1W)U<&]S(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0IM<V=I9"`B7TAE;'`B"FUS9W-T
M<B`B05]J=61A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN
M+B(*;7-G<W1R(")0<F]P<FEE9&%D97,@9&$@7TEM86=E;2XN+B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*;7-G:60@(E],;V<@
M:6XB"FUS9W-T<B`B7T-O;F5C=&%R(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B7T1E
M<V-O;F5C=&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB"FUS
M9W-T<B`B05]L=&5R87(@3&EN:RXN+B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(E]/
M<.?U97,B"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]097)M:7-S:6]N
M<R(*;7-G<W1R(")?4&5R;6ES<_5E<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E;6]V
M92!,:6YK+BXN(@IM<V=S='(@(E]296UO=F5R($QI;FLN+BXB"@HC.B!L:6(O
M87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R(")#;VYF:6=U<F%?
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T
M<B`B4')O<')I961A9&5S(&1A(%]486)E;&$N+BXB"@HC.B!L:6(O87!I+G!H
M<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G<W1R(")?57-UX7)I;W,B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,`IM<V=I9"`B861D<F5S<R!B
M;V]K(@IM<V=S='(@(F-A=.%L;V=O(&1E(&5N9&5R9>=O<R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R97-S
M964@=6YK;F]W;B(*;7-G<W1R(")C873A;&]G;R!D92!E;F1E<F7G;W,B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ,@IM<V=I9"`B8V%L96YD
M87(B"FUS9W-T<B`B86=E;F1A(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M-SD@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B8V%L;2(*;7-G<W1R(")C86QM;R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U
M="!F:6QE(@IM<V=S='(@(FEM<&]S<^UV96P@8W)I87(@87)Q=6EV;R!D92!D
M97-T:6YO(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(FEM<&]S<^UV
M96P@86)R:7(@82!O<FEG96TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HU.3D*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B8VQI
M<75E(&%Q=6DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@
M(F5R<F\@9&4@<VEN=&%X92!D82!L:6YH82!D92!C;VUA;F1O(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O;F9I
M9W5R871I;VX@97)R;W(B"FUS9W-T<B`B97)R;R!D92!C;VYF:6=U<F'GXV\B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I
M9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R(")U;2!A
M<G%U:79O(&-R[71I8V\@9&\@<VES=&5M82!E<W3A(&9A;'1A;F1O(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A
M=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(F5R<F\@;F\@9F]R;6%T;R!D;W,@
M9&%D;W,B"@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C,P"FUS9VED
M(")E9&ET(@IM<V=S='(@(F5D:71A<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3@R"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS
M9W-T<B`B<F5G:7-T<F\@;N-O(&5N8V]N=')A9&\B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B9F%L;&EN9R(*
M;7-G<W1R(")Q=65D82(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N
M<&AP.C@X,0IM<V=I9"`B9FEL92(*;7-G<W1R(")A<G%U:79O(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ.#$@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C<@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R(")A('!A<G1I<B!D
M92`E<R`H)7,I(.`@)7,@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,Y"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(F)R:7-A(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.`IM<V=I
M9"`B:#HB"FUS9W-T<B`B:#HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S4W"FUS9VED(")H:"(*;7-G<W1R(")H:"(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H
M;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R(")N;VUE(&1O(&AO<W0@Z2!D97-C
M;VYH96-I9&\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R(")I
M;65D:6%T;R(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B:6YC;W)P
M;W)A9&\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V
M,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(F5R<F\@9&4@
M96YT<F%D82]S8>UD82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G
M<W1R(")E<G)O(&EN=&5R;F\@9&\@<')O9W)A;6$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM
M<V=S='(@(FQI;FAA<UTB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S
M='(@(F/S9&EG;R!D92!E<G)O("5D(&1O(&UK:7-O9G,@96YQ=6%N=&\@9V5R
M879A(&$@25-/+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HS-C@*;7-G:60@(FUM(@IM<V=S='(@(FUM(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HR.#4@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,C0Q"FUS9VED(")N86UE(@IM<V=S='(@(FYO;64B"@HC.B!F<F%M97=O<FLO
M4E!#+U)00RYP:'`Z,3(T"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T
M<B`B;N-O(&EM<&QE;65N=&%D;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,3(R,`IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*
M;7-G<W1R(")NXV\@:6UP;&5M96YT861O(&%I;F1A(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,#0*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B
M8FQO8V\@9&4@;F]T87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@
M(G!O<F-E;G1A9V5M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-S0*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(E!E
M<FUI<W/C;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R(")P:7AE;',B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I
M9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(F5R<F\@<F5M
M;W1O(&YO('!R;W1O8V]L;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<T"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B;F%S8V5N
M=&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@IM
M<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R(")S97)V:>=O(&EN
M9&ES<&]N[79E;"(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,3`Q"FUS
M9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(F5X:6)I<B!D:69E<F5N
MYV%S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R(")S
M;7,R96UA:6P@=FEA($A45%`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S@U"FUS9VED(")S<R(*;7-G<W1R(")S<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS9VED
M(")S=&5A9'DB"FUS9W-T<B`B97-TX79E;"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T96T@97)R;W(B"FUS
M9W-T<B`B97)R;R!D92!S:7-T96UA(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,C@*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R(")L:7-T82!D
M92!T87)E9F%S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(F9A;&AA
M('1E;7!O<N%R:6$B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED(")T>7!E('1H92!P87-S
M=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(G!R965N8VAA('-U82!S
M96YH82!D=6%S('9E>F5S('!A<F$@8V]N9FER;6%R(@H*(SH@861M:6XO<V5T
M=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@
M(G5N:69I960B"FUS9W-T<B`B=6YI9FEC861O(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R(")S
M96T@;F]M92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B
M<V5L9>?C;R!D92!U<W7A<FEO(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R
M9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M-#`*;7-G:60@(G<Z(@IM<V=S='(@(G<Z(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(G=E
M871H97(N8V]M(@H`````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O<'1?4%0N<&\`````````
M````````````````````````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#<R,#4R
M,``Q,#4Q-30S,S<U-0`P,3<V-S(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````(R!(;W)D92!0;W)T=6=A;"!0;W)T=6=U97-E
M('1R86YS;&%T:6]N+@HC($UA;G5E;"!-96YE>F5S(&1E(%-E<75E:7)A(#Q-
M86YU96PN4V5Q=65I<F$^+"`R,#`U+@HC($)A<V5D(&]N(&$@<')E=FEO=7,@
M=')A;G-L871I;VX@8GD@3G5N;R!,;W5R96ER;R`\;G5N;T!E=&@N<'0^+"`R
M,#`R+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N
M.B!(;W)D92`S+C`M8W9S7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V
M0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M
M,3$M,C0@,#$Z,3@K,#`P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P,BTP
M,2TR,2`Q.#HR,BTP,#`P7&XB"B),87-T+51R86YS;&%T;W(Z($YU;F\@3&]U
M<F5I<F\@/&YU;F]`971H+G!T/EQN(@HB3&%N9W5A9V4M5&5A;3H@4&]R='5G
M86P@4&]R='5G=65S92`\9&5V0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M
M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H
M87)S970]:7-O+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN
M9SH@.&)I=%QN(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0Y"FUS9VED("(B
M"B(@("U-+"`M+6UE<W-A9V4]34534T%'12`@57-E('1H:7,@8V]M;6ET(&UE
M<W-A9V4@:6YS=&5A9"!O9B!T:&4@9&5F875L="!O;F5S+B(*;7-G<W1R("(B
M"B(@("U-+"`M+6UE<W-A9V4]345.4T%'14T@57-A<B!E<W1A(&UE;G-A9V5M
M(&1E(&-O;65T:6UE;G1O(&5M('9E>B!D85QN(@HB("`@("`@("`@("`@("`@
M("`@("`@("`@(&UE;G-A9V5M('!O<B!O;6ES<^-O+B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HU,PIM<V=I9"`B(@HB("`M82P@+2UA9&0]1DE,12`@("`@
M("`@061D('1H:7,@4$\@9FEL92!T;R!T:&4@8V]M<&5N9&EU;2X@57-E9G5L
M('1O7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("!I;F-L=61E(&$@8V]M
M<&5N9&EU;2!F<F]M(&$@9&EF9F5R96YT(&)R86YC:"!T;UQN(@HB("`@("`@
M("`@("`@("`@("`@("`@("`@=&AE(&=E;F5R871E9"!C;VUP96YD:75M+B(*
M;7-G<W1R("(B"B(@("UA+"`M+6%D9#U!4E%5259/("`@("!!9&EC:6]N87(@
M97-T92!A<G%U:79O(%!/(&%O(&-O;7#J;F1I;RX@571I;"!P87)A7&XB"B(@
M("`@("`@("`@("`@("`@("`@("`@("!I;F-L=6ER('5M(&-O;7#J;F1I;R!D
M92!U;2!R86UO(&1I9F5R96YT92!N;UQN(@HB("`@("`@("`@("`@("`@("`@
M("`@("`@8V]M<.IN9&EO(&=E<F%D;RXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,3$S"FUS9VED("(B"B(@("UB+"`M+6)A<V4]+U!!5$@@($9U;&P@<&%T
M:"!T;R!T:&4@*$AO<F1E*2!B87-E(&1I<F5C=&]R>2!T:&%T('-H;W5L9"!B
M95QN(@HB("`@("`@("`@("`@("`@("`@("!U<V5D+B(*;7-G<W1R("(@("UB
M+"`M+6)A<V4]+T-!34D@($-A;6EN:&\@<&%R82!O(&1I<F5C=/-R:6\@8F%S
M92`H2&]R9&4I(&$@=7-A<BXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-CD*
M;7-G:60@(B(*(B`@+6,L("TM8V]M<&5N9&EU;3U&24Q%("!-97)G92!N97<@
M=')A;G-L871I;VYS('1O('1H:7,@8V]M<&5N9&EU;2!F:6QE7&XB"B(@("`@
M("`@("`@("`@("`@("`@("`@("`@:6YS=&5A9"!O9B!T:&4@9&5F875L="!O
M;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE7&XB"B(@("`@("`@("`@("`@("`@
M("`@("`@("`@:&]R9&4O<&\@9&ER96-T;W)Y+B(*;7-G<W1R("(B"B(@("UC
M+"`M+6-O;7!E;F1I=6T]05)152`@26YT96=R87(@;F]V87,@=')A9'7G]65S
M(&$@97-T92!A<G%U:79O(&1E("(*(F-O;7#J;F1I;UQN(@HB("`@("`@("`@
M("`@("`@("`@("`@("`@(&4@;N-O(&%O(&-O;7#J;F1I;R!P;W(@;VUI<W/C
M;R`H8V]M<&5N9&EU;2YP;R!N85QN(@HB("`@("`@("`@("`@("`@("`@("`@
M("`@('!A<W1A(&AO<F1E+W!O+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV
M,R!P;R]T<F%N<VQA=&EO;BYP:'`Z.#$@<&\O=')A;G-L871I;VXN<&AP.C@W
M"FUS9VED("(B"B(@("UC+"`M+6-O;7!E;F1I=6T]1DE,12`@57-E('1H:7,@
M8V]M<&5N9&EU;2!F:6QE(&EN<W1E860@;V8@=&AE(&1E9F%U;'1<;B(*(B`@
M("`@("`@("`@("`@("`@("`@("`@("!O;F4@*&-O;7!E;F1I=6TN<&\@:6X@
M=&AE(&AO<F1E+W!O(&1I<F5C=&]R>2DN(@IM<V=S='(@(B(*(B`@+6,L("TM
M8V]M<&5N9&EU;3U!4E%5("!5<V%R(&5S=&4@87)Q=6EV;R!D92!C;VUPZFYD
M:6\@96T@=F5Z(&1O(&%R<75I=F]<;B(*(B`@("`@("`@("`@("`@("`@("`@
M("`@("!P;W(@;VUI<W/C;R`H8V]M<&5N9&EU;2YP;R!N82!P87-T82!H;W)D
M92]P;RXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$T"FUS9VED("(@("UD
M+"`M+61E8G5G("`@("`@(%-H;W<@97)R;W(@;65S<V%G97,@9G)O;2!T:&4@
M97AE8W5T960@8FEN87)I97,N(@IM<V=S='(@(B`@+60L("TM9&5B=6<@("`@
M("`@36]S=')A<B!M96YS86=E;G,@9&4@97)R;R!D;W,@8FENX7)I;W,@97AE
M8W5T861O<RXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-30*;7-G:60@(B`@
M+60L("TM9&ER96-T;W)Y/41)4B`@($-R96%T92!C;VUP96YD:75M(&EN('1H
M:7,@9&ER96-T;W)Y+B(*;7-G<W1R("(@("UD+"`M+61I<F5C=&]R>3U005-4
M02!#<FEA<B!U;2!C;VUPZFYD:6\@;F5S=&$@<&%S=&$N(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C$Q-0IM<V=I9"`B("`M:"P@+2UH96QP("`@("`@("!3
M:&]W('1H:7,@:&5L<"!M97-S86=E+B(*;7-G<W1R("(@("UH+"`M+6AE;'`@
M("`@("`@($UO<W1R87(@97-T82!M96YS86=E;2!D92!A:G5D82XB"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z-#(@<&\O=')A;G-L871I;VXN<&AP.C8W('!O
M+W1R86YS;&%T:6]N+G!H<#HW-0IM<V=I9"`B("`M;"P@+2UL;V-A;&4];&Q?
M0T,@("`@(%5S92!O;FQY('1H:7,@;&]C86QE+B(*;7-G<W1R("(@("UL+"`M
M+6QO8V%L93UL;%]#0R`@("`@57-A<B!A<&5N87,@97-T82!L;V-A;&EZ8>?C
M;RXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#<@<&\O=')A;G-L871I;VXN
M<&AP.C8Q('!O+W1R86YS;&%T:6]N+G!H<#HW.0HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z.#4*;7-G:60@(B`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V4@
M=&AI<R!L;V-A;&4N(@IM<V=S='(@(B`@+6PL("TM;&]C86QE/6QL7T-#("`@
M("!5<V%R(&5S=&$@;&]C86QI>F'GXV\N(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C4U"FUS9VED("(@("UL+"`M+6QO8V%L93UL;%]#0R`@("!5<V4@=&AI
M<R!L;V-A;&4N(@IM<V=S='(@(B`@+6PL("TM;&]C86QE/6QL7T-#("`@(%5S
M87(@97-T82!L;V-A;&EZ8>?C;RXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-C@*;7-G:60@(B`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!"=6EL9"!-3R!F
M:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B
M"B(@("UM+"`M+6UO9'5L93U-TT153$\@("`@0V]N<W1R=6ER(&%R<75I=F]S
M($U/(&%P96YA<R!P87)A(&5S=&4@;?-D=6QO7&XB"B(@("`@("`@("`@("`@
M("`@("`@("`@("`@*$AO<F1E*2XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-#,*;7-G:60@(B`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#;&5A;G5P(%!/
M(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S='(@
M(B(*(B`@+6TL("TM;6]D=6QE/4W31%5,3R`@("!,:6UP87(@87)Q=6EV;W,@
M4$\@87!E;F%S('!A<F$@97-T92!M\V1U;&]<;B(*(B`@("`@("`@("`@("`@
M("`@("`@("`@("`H2&]R9&4I+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT
M.`IM<V=I9"`B(@HB("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($-O;6UI="!T
M<F%N<VQA=&EO;G,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XB"FUS
M9W-T<B`B(@HB("`M;2P@+2UM;V1U;&4]3=-$54Q/("`@($-O;65T97(@87,@
M=')A9'7G]65S(&%P96YA<R!P87)A(&5S=&4@;?-D=6QO7&XB"B(@("`@("`@
M("`@("`@("`@("`@("`@("`@*$AO<F1E*2XB"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z-C(*;7-G:60@(B`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#<F5A
M=&4@82!03R!F:6QE(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM
M<V=S='(@(B(*(B`@+6TL("TM;6]D=6QE/4W31%5,3R`@("!#<FEA<B!O(&%R
M<75I=F\@4$\@87!E;F%S('!A<F$@97-T92!M\V1U;&]<;B(*(B`@("`@("`@
M("`@("`@("`@("`@("`@("`H2&]R9&4I+B(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HX,`IM<V=I9"`B("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($UE<F=E
M(%!/(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S
M='(@(B(*(B`@+6TL("TM;6]D=6QE/4W31%5,3R`@("!);G1E9W)A<B!A<G%U
M:79O<R!03R!A<&5N87,@<&%R82!E<W1E(&WS9'5L;UQN(@HB("`@("`@("`@
M("`@("`@("`@("`@("`@("A(;W)D92DN(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C<V"FUS9VED("(B"B(@("UM+"`M+6UO9'5L93U-3T153$4@("`@57!D
M871E(&AE;'`@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XB
M"FUS9W-T<B`B(@HB("`M;2P@+2UM;V1U;&4]3=-$54Q/("`@($%C='5A;&EZ
M87(@87)Q=6EV;W,@9&4@86IU9&$@87!E;F%S('!A<F$@97-T95QN(@HB("`@
M("`@("`@("`@("`@("`@("`@("`@(&WS9'5L;R`H2&]R9&4I+B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HX-@IM<V=I9"`B("`M;2P@+2UM;V1U;&4]34]$
M54Q%("`@(%5P9&%T92!O;FQY('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S
M='(@(B`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!!8W1U86QI>F%R(&%P96YA
M<R!E<W1E(&WS9'5L;R`H2&]R9&4I+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HU.`IM<V=I9"`B("`M;2P@+2UM;V1U;&4]34]$54Q%("!'96YE<F%T92!0
M3U0@9FEL92!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R
M("(B"B(@("UM+"`M+6UO9'5L93U-3T153$4@("`@1V5R87(@87)C:&EV;R!0
M3U0@87!E;F%S('!A<F$@97-T92!M\V1U;&]<;B(*(B`@("`@("`@("`@("`@
M("`@("`@("`@("`H2&]R9&4I+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW
M,`IM<V=I9"`B(@HB("`M;BP@+2UN;RUC;VUP96YD:75M("`@($1O;B=T(&UE
M<F=E(&YE=R!T<F%N<VQA=&EO;G,@=&\@=&AE(&-O;7!E;F1I=6TN(@IM<V=S
M='(@(B`@+6XL("TM;F\M8V]M<&5N9&EU;2`@("!.XV\@:6YT96=R87(@;F]V
M87,@=')A9'7G]65S(&YO(&-O;7#J;F1I;RXB"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z-C0@<&\O=')A;G-L871I;VXN<&AP.C@R('!O+W1R86YS;&%T:6]N
M+G!H<#HX.`IM<V=I9"`B("`M;BP@+2UN;RUC;VUP96YD:75M("`@($1O;B=T
M('5S92!A(&-O;7!E;F1I=6TN(@IM<V=S='(@(B`@+6XL("TM;F\M8V]M<&5N
M9&EU;2`@("!.XV\@=7-A<B!U;2!C;VUPZFYD:6\N(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C<Q"FUS9VED("(@("US+"`M+7-T871I<W1I8W,@("`@("`@
M4V%V92!T<F%N<VQA=&EO;B!S=&%T:7-T:6-S(&EN(&$@;&]C86P@9FEL92XB
M"FUS9W-T<B`B(@HB("`M<RP@+2US=&%T:7-T:6-S("`@("`@($=U87)D87(@
M97-T873M<W1I8V%S(&1E('1R861UY^-O(&YU;2!F:6-H96ER;R!L;V-A;"XB
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$V"FUS9VED("(@("UT+"`M+71E
M<W0@("`@("`@(%-H;W<@=&AE(&5X96-U=&5D(&-O;6UA;F1S(&)U="!D;VXG
M="!R=6X@86YY=&AI;F<N(@IM<V=S='(@(B`@+70L("TM=&5S="`@("`@("`@
M36]S=')A<B!O<R!P<F]G<F%M87,@82!E>&5C=71A<B!M87,@;N-O(&\@9F%Z
M97(N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P-0IM<V=I9"`B(@HB("!C
M;&5A;G5P("`@("!#;&5A;G,@=&AE(%!/(&9I;&5S('5P(&9R;VT@=6YT<F%N
M<VQA=&5D(&%N9"!O8G-O;&5T92!E;G1R:65S+B(*;7-G<W1R("(B"B(@(&-L
M96%N=7`@("`@($QI;7!A<B!O9B!A<G%U:79O<R!03R!D92!E;G1R861A<R!P
M;W(@=')A9'5Z:7(@;W4@;V)S;VQE=&%S+B(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HQ,#@*;7-G:60@(B`@8V]M;6ET("`@("`@0V]M;6ET('1R86YS;&%T
M:6]N<R!T;R!T:&4@0U93('-E<G9E<BXB"FUS9W-T<B`B("!C;VUM:70@("`@
M("!#;VUE=&5R(&%S('1R861UY_5E<R!N;R!S97)V:61O<B!#5E,N(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$P.0IM<V=I9"`B("!C;VUM:70M:&5L<"!#
M;VUM:70@:&5L<"!F:6QE<R!T;R!T:&4@0U93('-E<G9E<BXB"FUS9W-T<B`B
M("!C;VUM:70M:&5L<"!#;VUE=&5R(&%R<75I=F]S(&1E(&%J=61A(&YO('-E
M<G9I9&]R($-64RXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.3D*;7-G:60@
M(B(*(B`@8V]M<&5N9&EU;2`@4F5B=6EL9"!T:&4@8V]M<&5N9&EU;2!F:6QE
M+B!787)N:6YG.B!4:&ES(&]V97)W<FET97,@=&AE7&XB"B(@("`@("`@("`@
M("`@(&-U<G)E;G0@8V]M<&5N9&EU;2XB"FUS9W-T<B`B(@HB("!C;VUP96YD
M:75M("!296-O;G-T<G5I<B!O(&%R<75I=F\@9&4@8V]M<.IN9&EO+B!!=&5N
MY^-O.B!/(&YO=F\@87)Q=6EV;UQN(@HB("`@("`@("`@("`@("!S;V)R97#U
M92US92!A;R!A;G1I9V\N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P,`IM
M<V=I9"`B("!E>'1R86-T("`@("!'96YE<F%T92!03R!T96UP;&%T92`H+G!O
M="D@9FEL97,N(@IM<V=S='(@(B`@97AT<F%C="`@("`@1V5R87(@87)Q=6EV
M;W,@;6]D96QO(%!/("@N<&]T*2XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M.3@*;7-G:60@(B`@:&5L<"`@("`@("`@4VAO=R!T:&ES(&AE;'`@;65S<V%G
M92XB"FUS9W-T<B`B("!H96QP("`@("`@("!-;W-T<F%R(&5S=&$@;65N<V%G
M96T@9&4@86IU9&$N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P,0IM<V=I
M9"`B(@HB("!I;FET("`@("`@("!#<F5A=&4@;VYE(&]R(&UO<F4@4$\@9FEL
M97,@9F]R(&$@;F5W(&QO8V%L92X@5V%R;FEN9SH@5&AI<UQN(@HB("`@("`@
M("`@("`@("!O=F5R=W)I=&5S('1H92!E>&ES=&EN9R!03R!F:6QE<R!O9B!T
M:&ES(&QO8V%L92XB"FUS9W-T<B`B(@HB("!I;FET("`@("`@("!#<FEA<B!U
M;2!O=2!M86ES(&%R<75I=F]S(%!/('!A<F$@=6UA(&YO=F$@;&]C86QI>F'G
MXV\N7&XB"B(@("`@("`@("`@("`@($%T96[GXV\Z($]S(&YO=F]S(&%R<75I
M=F]S('-O<')E</5E;2US92!A;W,@86YT:6=O<RXB"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,3`V"FUS9VED("(@(&UA:V4@("`@("`@($)U:6QD(&)I;F%R
M>2!-3R!F:6QE<R!F<F]M('1H92!S<&5C:69I960@4$\@9FEL97,N(@IM<V=S
M='(@(B(*(B`@;6%K92`@("`@("`@0V]N<W1R=6ER(&%R<75I=F]S(&)I;N%R
M:6]S($U/(&$@<&%R=&ER(&1O<R!A<G%U:79O<UQN(@HB("`@("`@("`@("`@
M("!03R!E<W!E8VEF:6-A9&]S+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,#<*;7-G:60@(B(*(B`@;6%K92UH96QP("`@36%R:R!A;&P@96YT<FEE<R!I
M;B!T:&4@6$U,(&AE;'`@9FEL92!B96EN9R!U<"UT;RUD871E(&%N9%QN(@HB
M("`@("`@("`@("`@("!P<F5P87)E('1H92!F:6QE(&9O<B!T:&4@;F5X="!E
M>&5C=71I;VX@;V8@=7!D871E+6AE;'`N(%EO=5QN(@HB("`@("`@("`@("`@
M("!S:&]U;&0@;VYL>2!R=6X@;6%K92UH96QP($%&5$52('5P9&%T92UH96QP
M(&%N9"!R979I<VEN9R!T:&5<;B(*(B`@("`@("`@("`@("`@:&5L<"!F:6QE
M+B(*;7-G<W1R("(B"B(@(&UA:V4M:&5L<"`@($UA<F-A<B!T;V1A<R!A<R!E
M;G1R861A<R!N;R!A<G%U:79O(%A-3"!D92!A:G5D82!C;VUO(&5S=&%N9&]<
M;B(*(B`@("`@("`@("`@("`@86-T=6%L:7IA9&%S(&4@<')E<&%R87(@;R!A
M<G%U:79O('!A<F$@82!P<O-X:6UA(&5X96-UY^-O7&XB"B(@("`@("`@("`@
M("`@(&1E('5P9&%T92UH96QP+B!$979E+7-E(&5X96-U=&%R(&UA:V4M:&5L
M<"!$15!/25,@9&5<;B(*(B`@("`@("`@("`@("`@=7!D871E+6AE;'`@92!D
M92!R979E<B!O(&%R<75I=F\@9&4@86IU9&$N(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C$P,@IM<V=I9"`B(@HB("!M97)G92`@("`@("!-97)G92!T:&4@
M8W5R<F5N="!03R!F:6QE('=I=&@@=&AE(&-U<G)E;G0@4$\@=&5M<&QA=&4@
M9FEL92XB"FUS9W-T<B`B(@HB("!M97)G92`@("`@("!);G1E9W)A<B!O(&%R
M<75I=F\@4$\@8V]R<F5N=&4@8V]M(&\@87)Q=6EV;R!M;V1E;&\@4$\@(@HB
M8V]R<F5N=&4N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P,PIM<V=I9"`B
M("!U<&1A=&4@("`@("!2=6X@97AT<F%C="!A;F0@;65R9V4@<V5Q=65N="XB
M"FUS9W-T<B`B("!U<&1A=&4@("`@("!%>&5C=71A<B!E>'1R86-T(&4@;65R
M9V4@96T@<V5Q=>IN8VEA+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#0*
M;7-G:60@(B(*(B`@=7!D871E+6AE;'`@17AT<F%C="!A;&P@;F5W(&%N9"!C
M:&%N9V5D(&5N=')I97,@9G)O;2!T:&4@16YG;&ES:"!834P@:&5L<%QN(@HB
M("`@("`@("`@("`@("!F:6QE(&%N9"!M97)G92!T:&5M('=I=&@@=&AE(&5X
M:7-T:6YG(&]N97,N(@IM<V=S='(@(B(*(B`@=7!D871E+6AE;'`@17AT<F%I
M<B!T;V1A<R!A<R!E;G1R861A<R!N;W9A<R!E(&UO9&EF:6-A9&%S(&1O(&%R
M<75I=F\@9&5<;B(*(B`@("`@("`@("`@("`@86IU9&$@6$U,(&5M(&EN9VSJ
M<R!E(&EN=&5G<N$M;&%S(&-O;2!A<R!E>&ES=&5N=&4N(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHQ,0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B(@)B,Q-3$[("5S(&ES(')E861Y('1O('!E<F9O<FT@
M=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RXB"FUS
M9W-T<B`B(@HB("8C,34Q.R`E<R!E<W3A('!R;VYT;R!P87)A(&5F96-T=6%R
M(&%S(&]P97)AY_5E<R!D92!M86YU=&5NY^-O(&UA<F-A9&%S("(*(F%B86EX
M;RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,V.`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*"5S(&1I87,@871R
MX7,I(@H*(SH@;&EB+TAO<F1E+G!H<#HQ,C4V"B,L('!H<"UF;W)M870*;7-G
M:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(@*$-H879E(&1E(&%C97-S
M;R`E<RDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B`H9&5N=')O(&1E
M("5S(&1I87,I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S(*;7-G:60@
M(B`H=&]D87DI(@IM<V=S='(@(B`H:&]J92DB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C,W-`IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B("AA;6%N
M:.,I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S`*;7-G:60@(B`H>65S
M=&5R9&%Y*2(*;7-G<W1R("(@*&]N=&5M*2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-#0@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,T.0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDU"FUS9VED
M("(@870@(@IM<V=S='(@(B!C;VT@(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z
M,C<R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI
M9"!C:&]I8V4N(@IM<V=S='(@(EPB)7-<(B!NXV\@Z2!U;6$@97-C;VQH82!V
MX6QI9&$N(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HU-30@;&EB+TAO
M<F1E+U)E9VES=')Y+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB
M"FUS9W-T<B`B7"(E<UPB(&[C;R!E<W3A(&-O;F9I9W5R861O(&YO(%)E9VES
M=&\@9&\@2&]R9&4N(@H*(SH@;&EB+TAO<F1E+U1R964N<&AP.C$V-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U
M;F0N(@IM<V=S='(@(EPB)7-<(B!R97!R97-E;G1A9&]R(&1E(.%R=F]R92!N
MXV\@96YC;VYT<F%D;RXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4W"B,L('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P
M<R!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!F;VD@861I8VEO;F%D;R!A;R!S
M:7-T96UA(&1E(&=R=7!O<RXB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T
M;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(G(&9O
M:2!A9&EC:6]N861O(&%O('-I<W1E;6$@9&4@<&5R;6ES<_5E<RXB"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C4U(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HX
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D
M.B`E<RXB"FUS9W-T<B`B7"(E<UPB(&[C;R!F;VD@8W)I861O.B`E<RXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(U"B,L('!H<"UF;W)M
M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(E9"`E<R!E("5S(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q-S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)60@8GET97,@=W)I='1E;BXB"FUS9W-T<B`B)60@8GET97,@97-C<FET
M;W,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(X-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E9"!O9B`E9"!E;G1R:65S(&UA<FME9"!A<R!U<"UT;RUD871E
M(@IM<V=S='(@(B5D(&1E("5D(&5N=')A9&$@;6%R8V%D87,@8V]M;R!A8W1U
M86QI>F%D87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<S
M"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R
M(")P<F5V:7/C;R!D92`E9"!D:6%S(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+VYO=&EC95]T;W`N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M+2!.;W1I8V4B"FUS9W-T<B`B)7,@+2!.;W1I9FEC8>?C;R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHS,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(E<R!!9&UI;FES
M=')AY^-O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B)7,@
M26UP<F5S<^-O($1I9VET86PB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT
M<RYP:'`Z.#,P(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX,S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O
M;F9I<FUA=&EO;B(*;7-G<W1R("(E<R!/<&5R8>?U97,@9&4@36%N=71E;N?C
M;R`M($-O;F9I<FUAY^-O(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS
M,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$X"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(%-E='5P(@IM<V=S='(@(D-O;F9I9W5R87(@)7,B"@HC.B!L:6(O
M2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!3:6=N(%5P(@IM<V=S='(@(B5S(%-U8G-C<F5V97(B"@HC.B!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O86=R965M96YT7W1O<"YI;F,Z-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B
M)7,@5&5R;6]S(&1O($%C;W)D;R(*"B,Z(&QI8B]61E,O9G1P+G!H<#HU-C@@
M;&EB+U9&4R]F='`N<&AP.C8S-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A
M;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B)7,@:N$@97AI<W1E+B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,34Y(&QI8B]";&]C:R]M971A<BYP:'`Z,38U
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C,Y"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S0U(&QI8B]";&]C:R]M971A<BYP:'`Z,S4Q"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S(&5M("5S("5S(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C(X-R!P;R]T<F%N<VQA=&EO;BYP:'`Z,S$T
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(&YO="!W<FET86)L92XB"FUS
M9W-T<B`B;N-O('-E('!O9&4@97-C<F5V97(@96T@)7,N(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(S,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@
M<F5Q=6ER960B"FUS9W-T<B`B)7,@Z2!O8G)I9V%T\W)I;R(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C@V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&UI
M;G5T97,B"FUS9W-T<B`B)7,@;6EN=71O<R(*"B,Z(&QI8B](;W)D92]";&]C
M:R]#;VQL96-T:6]N+G!H<#HQ,C,@<&\O=')A;G-L871I;VXN<&AP.C$S-3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(E
M<R!NXV\@9F]I(&5N8V]N=')A9&\N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C4X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(%)U;B`G
M=')A;G-L871I;VX@97AT<F%C="<@9FER<W0N(@IM<V=S='(@(B5S(&[C;R!F
M;VD@96YC;VYT<F%D;RX@17AE8W5T87(@)W1R86YS;&%T:6]N(&5X=')A8W0G
M('!R:6UE:7)O+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T
M<B`B)7,@82`E<R!D92`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.#DQ
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S
M='(@(D-O;G1A8W1O<R!D92`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M.#@S"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T
M<B`B0V%L96YDX7)I;R!D92`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M.#<U"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R
M(").;W1A<R!D92`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.#DY"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B5&%R
M969A<R!D92`E<R(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N
M97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B
M"FUS9W-T<B`B)7,Z("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,U,R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDX"FUS9VED
M("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@8V]M(')A:F%D87,B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$X."!L:6(O0FQO8VLO;65T87(N<&AP.C$Y,PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B
M+"!C;VT@<F%J861A<R`E<R`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T
M;R`E<R(*;7-G<W1R("(L('9A<FGA=F5L(&1E("5S(&$@)7,B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C`W,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$R.0HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C@X"FUS9VED
M("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@97-C;VQH82`M+2(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HQ,S(X('!O+W1R86YS;&%T:6]N+G!H<#HQ,S,P
M"FUS9VED("(M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TB"FUS9W-T<B`B
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM(@H*(SH@;&EB+T)L;V-K+W1I
M;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R(")&;W)M
M871O(&1E(#$R(&AO<F%S("A!32]032DB"@HC.B!L:6(O0FQO8VLO=&EM92YP
M:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(D9O<FUA=&\@
M9&4@,C0@:&]R87,B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM
M<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@:&]R87,B"@HC.B!L:6(O2&]R
M9&4O54DO4&%G97(N<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`B
M/$%N=&5R:6]R(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C,T-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B(\9V5T=&5X=#X@=&%G(&YO="!C;&]S960@:6X@
M9FEL92`E<RY<;B(*(D]P96YI;F<@=&%G(&9O=6YD(&EN(&QI;F4@)60N(@IM
M<V=S='(@(B(*(F5T:7%U971A(#QG971T97AT/B!P;W(@9F5C:&%R(&YO(&9I
M8VAE:7)O("5S+EQN(@HB06)R:6YD;R!A(&5T:7%U971A(&5N8V]N=')A9&$@
M;F$@;&EN:&$@)60N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*;7-G
M:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B
M;&]C:RXB"FUS9W-T<B`B17-T92!B;&]C;R!E>&EG92!U;2!M96-A;FES;6\@
M=7-A;F1O(&)A<V5S(&1E(&1A9&]S+B(*"B,Z(&QI8B](;W)D92YP:'`Z,38P
M"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R(")/
M8V]R<F5U('5M(&5R<F\@9F%T86PB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HY,C`*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@
M=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(LD@;F5C97-SX7)I82!U
M;6$@8VAA=F4@</IB;&EC82!01U`@<&%R82!E;F-R:7!T87(@82!M96YS86=E
M;2XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,30U"FUS9VED(")!
M('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE
M9"!M97-S86=E+B(*;7-G<W1R("(B"B+)(&YE8V5S<^%R:6$@=6UA(&-H879E
M('#Z8FQI8V$@4$=0('!A<F$@=F5R:69I8V%R(&$@87-S:6YA='5R82!D92!U
M;6$@(@HB;65N<V%G96TB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ
M,#<W"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@
M(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB4&%R82!D96-I9G)A<B!U;6$@;65N
M<V%G96T@<^-O(&YE8V5S<^%R:6%S('5M82!C:&%V92!P^F)L:6-A(%!'4"P@
M=6UA(&-H879E("(*(G!R:79A9&$@4$=0(&4@=6UA(&9R87-E+7!A<W-E+B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDY-0IM<V=I9"`B(@HB02!P
M=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@
M(B(*(E!A<F$@87-S:6YA<B!U;6$@;65N<V%G96T@<^-O(&YE8V5S<^%R:6%S
M('5M82!C:&%V92!P^F)L:6-A(%!'4"P@=6UA(&-H879E("(*(G!R:79A9&$@
M4$=0(&4@=6UA(&9R87-E+7!A<W-E+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3`U"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P
M<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@HB4&%R82!D
M96-I9G)A<B!U;6$@;65N<V%G96T@<^-O(&YE8V5S<^%R:6%S('5M82!C:&%V
M92!P^F)L:6-A(%,O34E-12P@=6UA("(*(F-H879E('!R:79A9&$@4R]-24U%
M(&4@=6UA(&9R87-E+7!A<W-E+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV
M871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@HB4&%R82!A<W-I;F%R
M('5M82!M96YS86=E;2!SXV\@;F5C97-SX7)I87,@=6UA(&-H879E('#Z8FQI
M8V$@4R]-24U%+"!U;6$@(@HB8VAA=F4@<')I=F%D82!3+TU)344@92!U;6$@
M9G)A<V4M<&%S<V4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS
M-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`BR2!N96-E<W/A<FEA('5M82!C
M:&%V92!P^F)L:6-A(%,O34E-12!P87)A(&5N8W)I<'1A<B!U;6$@;65N<V%G
M96TN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M.0IM<V=I9"`B04T@0VQO=61S(@IM<V=S='(@(D[Z=F5N<R!D92!M86YHXR(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS
M9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(D-H=79I<V-O<R!D92!-86YH
MXR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q
M"FUS9VED(")!32!286EN(@IM<V=S='(@(D-H=79A(&1E(&UA;FCC(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@
M(D%-(%-H;W=E<G,B"FUS9W-T<B`B06=U86-E:7)O<R!D92!M86YHXR(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED
M(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B3F5V]65S(&1E(&UA;FCC(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM
M<V=S='(@(D%-+U!-(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R(")!4$D@240B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED
M(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R(")!8V5R8V$@9&5S=&4@961I
M=&]R(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3(*;7-G:60@(D%B
M;W5T+BXN(@IM<V=S='(@(D%C97)C82XN+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*
M;7-G<W1R(")"87-E<R!A;&EN:&%D87,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS
M9W-T<B`B0V5N=')O<R!A;&EN:&%D;W,B"@HC.B!L:6(O5D93+VUU<W%L+G!H
M<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B06-E<W-O(&YE9V%D;R!A;R!C<FEA<B!P87-T82!6
M1E,N(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@
M9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R(")!8V5S<V\@;F5G
M861O(&%O(&-R:6%R(&%R<75I=F\@5D93+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW-0IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R(")0
M86QA=G)A+5!A<W-E(&1A($-O;G1A(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G
M<W1R(")#;VYT82!C;VYG96QA9&$N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,Q-PIM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R(")#;VYT86)I
M;&ED861E(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4T(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,3,R"B,Z('1E;7!L871E<R]P;W)T86PO861D
M+FEN8SHQ-"!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ
M-@IM<V=I9"`B061D(@IM<V=S='(@(D%D:6-I;VYA<B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,C$T(&%D;6EN+V=R;W5P<RYP:'`Z,C$U"FUS9VED(")!9&0@
M0VAI;&0@1W)O=7`B"FUS9W-T<B`B061I8VEO;F%R($=R=7!O($9I;&AO(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX-"!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C@U"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R
M(")!9&EC:6]N87(@4&5R;6ES<^-O($9I;&AA(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R(")!8W)E
M<V-E;G1A<B!!<75I.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C`X(&%D;6EN
M+V=R;W5P<RYP:'`Z,C`Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@
M(D%D9&EC:6]N87(@3F]V;R!'<G5P;R(*"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z-S,@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HW-`IM<V=I9"`B061D
M($YE=R!097)M:7-S:6]N(@IM<V=S='(@(D%D:6-I;VYA<B!.;W9A(%!E<FUI
M<W/C;R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC
M.CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@
M7"(E<UPB(@IM<V=S='(@(D%D:6-I;VYA<B!U;2!G<G5P;R!F:6QH;R!A(%PB
M)7-<(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,R!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C$S,0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@
M82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R(")!9&EC:6]N
M87(@=6UA('!E<FUI<W/C;R!F:6QH82!A(%PB)7-<(B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B061I
M8VEO;F%R(&YO=F\@=71I;&EZ861O<CHB"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-3(V"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S
M='(@(D%D:6-I;VYA<B!C;VQU;F$B"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C,U"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T
M<B`B061I8VEO;F%R(&YO=F]S(&UE;6)R;W,B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B061D('!A:7(B"FUS9W-T<B`B061I
M8VEO;F%R('!A<F-E:7)O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-
M;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B061I8VEO;F%R(&\@365N=2`E<R!C
M;VUO($)A<G)A($QA=&5R86P@36]Z:6QL82(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O
M;VLZ(@IM<V=S='(@(D%D:6-I;VYA<B!A;W,@0V]N=&%C=&]S.B(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D9"!T
M;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B061I8VEO;F%R(&%O<R!M975S
M(&-O;G1A8W1O<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@
M=7-E<B(*;7-G<W1R(")!9&EC:6]N87(@=71I;&EZ861O<B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB
M)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO
M;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*(D%D
M:6-I;VYE:2!<(B5S7"(@86\@<VES=&5M82P@;6%S(&[C;R!P=61E(&%D:6-I
M;VYA<B!I;F9O<FUAY^-O(&1E('-U8G-C<FGGXV\@(@HB861I8VEO;F%L.B`E
M<RXB"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D
M9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N
M(@IM<V=S='(@(D%D:6-I;VYE:2!<(B5S7"(@86\@<VES=&5M82X@2N$@<&]D
M92!E;G1R87(N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.CDV,@IM<V=I9"`B
M061D:6YG(&YE=R!F:6QE<R!T;R!R97!O<VET;W)Y.B(*;7-G<W1R(")!9&EC
M:6]N86YD;R!N;W9O<R!A<G%U:79O<R!A;R!R97!O<VET\W)I;SHB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-`IM<V=I9"`B061D:6YG
M('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")!(&%D:>?C;R!D92!U=&EL
M:7IA9&]R97,@97-TX2!D97-A8W1I=F%D82XB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,30T,R!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R
M-@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,PIM<V=I
M9"`B061D<F5S<R(*;7-G<W1R(")%;F1E<F7G;R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ,SD*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R
M(")#;VYT86-T;W,B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R
M(&]T:&5R('5S97)S(@IM<V=S='(@(D%D;6EN:7-T<F%R("T@871R:6)U:7(@
M<&5R;6ES<_5E<R!A(&]U=')O<R!U=&EL:7IA9&]R97,B"@HC.B!A9&UI;B]I
M;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM
M<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R8>?C;R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.3(*;7-G:60@(D%D<R(*
M;7-G<W1R(")!;OIN8VEO<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@
M(D%F96=A;FES=.-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB86YI82(*;7-G<W1R(")!;&+B;FEA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<T(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M,`IM<V=I9"`B06QG97)I82(*;7-G<W1R(")!<F?I;&EA(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM
M<V=S='(@(D%L8W5N:&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R(")!
M;&EN:&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R(")!;&EN:&%M96YT
M;SHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*
M;7-G<W1R(")4=61O(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3$X('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT
M:6-A=&5D(%5S97)S(@IM<V=S='(@(E1O9&]S(&]S(%5T:6QI>F%D;W)E<R!!
M=71E;G1I8V%D;W,B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R
M;W5P<RYP:'`Z,C$R"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(E1O9&]S
M(&]S($=R=7!O<R(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HS."!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C<W"FUS9VED(")!;&P@4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B5&]D87,@87,@4&5R;6ES<_5E<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@
M(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(E1O9&]S(&]S("AQ=6%T<F\I(&QA
M9&]S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S(*;7-G:60@(D%L;&]W
M(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R(")097)M:71I<B!M^FQT:7!L
M;W,@96YD97)EYV]S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R-@IM
M<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS
M9W-T<B`B4&5R;6ET:7(@871R:6)U:>?C;R!D;R!T:7!O(&1E(&QI<W1A<R!O
M<F1E;F%D87,_(@H*(SH@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-#`X
M"FUS9VED(")!;')E861Y(&5X:7-T<R(*;7-G<W1R(")*X2!E>&ES=&4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(S"FUS9VED(")!;'1E<FYA=&4@
M24U34"!,;V=I;B(*;7-G<W1R(")%;G1R861A($E-4U`@06QT97)N871I=F$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DY"FUS9VED(")!;'1E<FYA
M=&4@24U34"!087-S=V]R9"(*;7-G<W1R(")086QA=G)A+5!A<W-E($E-4U`@
M06QT97)N871I=F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DQ"FUS
M9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R(").;VUE(&1E
M(%5T:6QI>F%D;W(@24U34"!!;'1E<FYA=&EV;R(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D
M<F5S<R(*;7-G<W1R(")%;F1E<F7G;R!I;G;A;&ED;R(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM
M<V=S='(@(DUO9&5L;W,@86QT97)N871I=F]S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(U"FUS9VED
M(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B5&5X=&\@86QT97)N871I=F\Z
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B4V%M;V$@06UE<FEC
M86YA(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HY-2!L:6(O2&]R9&4O
M4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W87,@
M<W!E8VEF:65D+B(*;7-G<W1R(")&;VD@97-P96-I9FEC861O('5M('9A;&]R
M(&EN=N%L:61O+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-30*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S
M='(@(D]C;W)R974@=6T@97)R;R!D97-C;VYH96-I9&\N(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD
M;W)R82(*;7-G<W1R(")!;F1O<G)A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM<V=S='(@
M(D%N9V]L82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@(D%N9W5I;&$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U
M<R!0<F]X>2(*;7-G<W1R(")%;G1R97!O<W1O("AP<F]X>2D@06[S;FEM;R(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W
M97(B"FUS9W-T<B`B4F5S<&]S=&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S
M='(@(D%N=.%R8W1I8V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3D@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM
M<V=S='(@(D%N=.UG=6$@92!"87)B=61A(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4@;&EB+TAO<F1E+T)L;V-K
M+U5)+G!H<#HU.`HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M
M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R(")!<&QI8V'GXV\B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,Y"FUS9VED(")!<'!L:6-A=&EO
M;B!I<R!R96%D>2XB"FUS9W-T<B`B07!L:6-AY^-O('!R;VYT82XB"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@
M0VAI;&0@4VAA<F5S(@IM<V=S='(@(D%P;&EC87(@82!087)T:6QH87,@1FEL
M:&%S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*
M;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B07!R;W9A<B(*"B,Z(&QI8B](;W)D
M92]-24U%+T-O;G1E;G1S+G!H<#HX,S`*;7-G:60@(D%P<')O>&EM871E(%-I
M>F4B"FUS9W-T<B`B5&%M86YH;R!!<')O>&EM861O(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W-R!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#$T"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(D%B
M<FEL(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S4*;7-G:60@(D%R86)I
M8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R(")!<N%B:6-O("A7:6YD;W=S+3$R
M-38I(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W1G>BYP:'`Z-S@*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE
M(@IM<V=S='(@(E1A;6%N:&\@9&\@1FEC:&5I<F\@9&4@07)Q=6EV;R(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4X(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T9WHN<&AP.C<W"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T<B`B3F]M
M92!D;R!!<G%U:79O(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M<75E=65D+FEN8SHY"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R
M92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E
M<R`_(@IM<V=S='(@(E1E;2!A(&-E<G1E>F$@<75E('%U97(@<F5M;W9E<B!O
M('!E9&ED;R!D92!S=6)S8W)IY^-O('!A<F$@)7,@/R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHY"B,L('!H<"UF;W)M870*;7-G
M:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N
M9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`B5&5M(&$@8V5R=&5Z82!Q=64@
M<75E<B!R96UO=F5R(%PB)7-<(B!E('%U86ES<75E<B!S=6(M9W)U<&]S/R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*
M;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R(")!<F=E;G1I;F$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!
M<FUE;FEA(@IM<V=S='(@(D%R;>EN:6$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$W-@IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B
M07)MZ6YI;R`H05)-4T-)22TX*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(D%R=&4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<G5B82(*
M;7-G<W1R(")!<G5B82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-0IM
M<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R("));&AA(&1E($%S8V5N
M<^-O(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I
M:2!!<G0B"FUS9W-T<B`B07)T92!!4T-)22(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S
M='(@(E)E9VGC;R#!<VEA+U!A8^UF:6-O(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0Q-PIM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E
M(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(E!E9&ER
M(&-O;F9I<FUAY^-O(&%N=&5S(&1E(')E86QI>F%R(&]P97)AY_5E<R!D92!M
M86YU=&5NY^-O/R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3$R"FUS9VED
M(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`B0V]L=6YA<R!D92!A=')I
M8G5IY^-O(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-0IM<V=I9"`B071T96UP
M="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(E1E
M;G1A=&EV82!D92!R96UOY^-O(&1E('5M(&=R=7!O(&EN97AI<W1E;G1E+B(*
M"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,S@*;7-G:60@(D%T=&5M<'0@
M=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@
M(E1E;G1A=&EV82!D92!R96UOY^-O(&1E('5M82!P97)M:7-SXV\@:6YE>&ES
M=&5N=&4N(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.3@*;7-G:60@(D%T
M=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G
M<W1R(")496YT871I=F$@9&4@961IY^-O(&1E('5M82!P97)M:7-SXV\@:6YE
M>&ES=&5N=&4N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS
M9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM
M<V=S='(@(E1E;G1A=&EV82!D92!E9&GGXV\@9&4@=6UA('!A<G1I;&AA(&EN
M97AI<W1E;G1E+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP
M.C8T(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@S"FUS9VED(")!='1R:6)U=&5S
M(@IM<V=S='(@(D%T<FEB=71O<R(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HS.#$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B06=O<W1O(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I
M9"`B075S=')A;&EA(@IM<V=S='(@(D%U<W1RX6QI82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R
M:6$B"FUS9W-T<B`BP75S=')I82(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G-Q
M;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G-Q;#H@02!E
M>'1E;G/C;R!I;6%P(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O;G1R861A+B(*
M"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?
M8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL
M:71E<RXB"FUS9W-T<B`B075T:%]C>7)U<SH@3R!M96-A;FES;6\@;N-O('1E
M;2!A<R!C87!A8VED861E<R!N96-E<W/A<FEA<RXB"@HC.B!L:6(O2&]R9&4O
M075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E
M9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER
M=7,Z($$@97AT96YSXV\@:6UA<"!N96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT
M<F%D82XB"@HC.B!L:6(O2&]R9&4O075T:"]F='`N<&AP.C,V"FUS9VED("(B
M"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N
M(@IM<V=S='(@(B(*(D%U=&A?9G1P.B!!(&5X=&5N<^-O($944"!N96-E<W/A
M<FEA(&[C;R!F;VD@96YC;VYT<F%D82X@0V]M<&EL92!O(%!(4"!C;VT@82`B
M"B)O<.?C;R`M+65N86)L92UF='`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:6UA
M<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM87`Z($$@97AT96YS
MXV\@24U!4"!N96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D82XB"@HC.B!L
M:6(O2&]R9&4O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!2
M97%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?:W)B-3H@02!E>'1E;G/C;R!K<F(U(&YE8V5S<^%R:6$@;N-O(&9O:2!E
M;F-O;G1R861A+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C4X"FUS
M9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P.B!!(&5X=&5N<^-O($Q$05`@;F5C
M97-SX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O;&1A<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A
M<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED.B`B"FUS9W-T<B`B(@HB075T:%]L9&%P.B!);7!O<W/M=F5L
M(&%D:6-I;VYA<B!U=&EL:7IA9&]R("5S+B!%:7,@;R!Q=64@;R!S97)V:61O
M<B!D:7-S93H@(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,C(R"B,L
M('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V
M92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@26UP;W-S[79E;"!R96UO
M=F5R(&\@=71I;&EZ861O<B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N
M<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L
M92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z($EM<&]S
M<^UV96P@86-T=6%L:7IA<B!O('5T:6QI>F%D;W(@)7,B"@HC.B!L:6(O2&]R
M9&4O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E
M9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;6-A
M;#H@02!E>'1E;G/C;R!-0T%,(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O;G1R
M861A+B(*"B,Z(&QI8B](;W)D92]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U
M=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")!=71H7W-M8F%U=&@Z($$@97AT96YSXV\@<VUB875T
M:"!N96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D82XB"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC
M871I;VX@9F%I;&5D(@IM<V=S='(@(D$@875T96YT:6-AY^-O(&9A;&AO=2(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(D$@875T
M96YT:6-AY^-O(&9A;&AO=2X@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]R861I
M=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@
M4D%$2553('-E<G9E<BXB"FUS9W-T<B`B02!A=71E;G1I8V'GXV\@9F]I(')E
M:F5I=&%D82!P96QO('-E<G9I9&]R(%)!1$E54RXB"@HC.B!L:6(O5D93+V9T
M<"YP:'`Z-S8X"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"XB"FUS9W-T<B`B02!A=71E;G1I8V'GXV\@;F\@<V5R=FED;W(@
M1E10(&9A;&AO=2XB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C@S
M"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R(")#86UP;W,@9&ES
M<&]N[79E:7,Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,Q(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R(")!>F5R8F%I
M:N-O(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(
M($5X8W5S97,B"FUS9W-T<B`B1&5S8W5L<&%S(%PB0D]&2%PB(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM
M<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R(")&=6YD;R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG
M<F]U;F0@0V]L;W(B"FUS9W-T<B`B0V]R(&1O($9U;F1O(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S
M=V]R9"XB"FUS9W-T<B`B4&%L879R82U087-S92!K97)B97)O<R!E<G)A9&$N
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K
M97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B3F]M92!D92!5=&EL:7IA9&]R
M(&ME<F)E<F]S(&5R<F%D;RXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@(D)A
M86UA<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C$*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B0F%RZ6TB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ
M,RDB"FUS9W-T<B`B0N%L=&EC;R`H25-/+3@X-3DM,3,I(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C,T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N
M9VQA9&5S:"(*;7-G<W1R(")"86YG;&%D96-H92(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HS,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S
M(@IM<V=S='(@(D)A<F)A9&]S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<S"FUS9VED(")"87-E;&EN92(*;7-G
M<W1R("),:6YH82!B87-E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R(")":65L
M;W)R^G-S:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S4@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@(D+I;&=I8V$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C,R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS
M9VED(")"96QI>F4B"FUS9W-T<B`B0F5L:7IE(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C0P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N:6XB"FUS
M9W-T<B`B0F5N:6TB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM<V=S='(@(D)E<FUU9&$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C,U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S
M"FUS9VED(")":'5T86XB"FUS9W-T<B`B0G5TXV\B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS
M9W-T<B`B06YI=F5R<^%R:6\B"@HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C
M=&EO;BYP:'`Z,S(X"B,L('!H<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<
M(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")/
M(&)L;V-O(%PB)7-<(B!D82!A<&QI8V'GXV\@7"(E<UPB(&[C;R!F;VD@96YC
M;VYT<F%D;RXB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.#D*
M;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(D-O;F9I9W5R8>?U97,@
M9&4@0FQO8V]S(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T
M"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(E1I<&\@9&4@0FQO8V\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G
M:60@(D)O;&0B"FUS9W-T<B`B3F5G<FET;R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HT,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS
M9W-T<B`B0F]L[79I82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M.3$*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R(")-87)C861O<F5S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(D)O<F1A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R
M('1H:6-K;F5S<SHB"FUS9W-T<B`B17-P97-S=7)A(&1A(&)O<F1A.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B0F]R9&%S(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C,R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HS-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S
M;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R(")"\W-N:6$M2&5R>F5G;W9I
M;F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B
M"FUS9W-T<B`B06UB87,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R(")";W1S
M=6%N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(D)A<V4B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED
M(")";W5V970@27-L86YD(@IM<V=S='(@(DEL:&$@0F]U=F5T(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C0T(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HT,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B
M0G)A>FEL(@IM<V=S='(@(D)R87-I;"(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H($EN9&EA
M;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B5&5R<FET\W)I;R!"<FETXFYI
M8V\@9&\@3V-E86YO(,UN9&EC;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HT,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M
M(@IM<V=S='(@(D)R=6YE:2!$87)U<W-A;&%M(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C8V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"=6EL9&EN9R!-3R!F
M:6QE<R!F;W(@;6]D=6QE("5S+BXN(@IM<V=S='(@(D-O;G-T<G5I;F1O(&%R
M<75I=F]S($U/('!A<F$@;R!M\V1U;&\@)7,N+BXB"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-C<S"B,L('!H<"UF;W)M870*;7-G:60@(D)U:6QD:6YG(&QO
M8V%L92`E<RXN+B`B"FUS9W-T<B`B0V]N<W1R=6EN9&\@;&]C86QI>F'GXV\@
M)7,N+BX@(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B0G5L9^%R:6$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS
M9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(DQI<W0@271E;6EZ861A(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,V(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HT-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM
M<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(D)U<G%U:6YA($9A<V\B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,SD@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C0U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS
M9VED(")"=7)U;F1I(@IM<V=S='(@(D)U<OIN9&DB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S@S"FUS9VED(")#35,B"FUS9W-T<B`B0TU3(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-2
M0R(*;7-G<W1R(")#4D,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4Y-PIM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B
M4&]N=&]S(&1E($1I<W1R:6)U:>?C;R!#4DPB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?
M96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4')O<')I961A9&5S(&1A*',I
M($/I7VQU;&$H<RDN+BXB"@HC(&,M9F]R;6%T"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-3`*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C
M;VUP;&5T960N(@IM<V=S='(@(DEN:6-I86QI>F'GXV\@9&$@7")C86-H95PB
M(&[C;R!F;VD@8V]N8VQU[61A+B(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-38@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$T
M.`IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B0V%L96YDX7)I;R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S0*;7-G:60@(D-A;&TB"FUS
M9W-T<B`B0V%L;6\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(X(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B0V%M8F]D
M:F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C0W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8W"FUS9VED(")#86UE<F]O;B(*;7-G<W1R(")#86UA<O5E<R(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E
M<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R+B(*;7-G<W1R("(B"B).XV\@<&]S<V\@<F5I;FEC:6%R(&$@
M<&%L879R82UP87-S92!A=71O;6%T:6-A;65N=&4L(&-O;G1A8W1E(&\@<V5U
M("(*(F%D;6EN:7-T<F%D;W(@9&4@<VES=&5M87,N(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O8WER=7,N<&AP.C(S-2!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP
M.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-
M05`@<V5R=F5R.B`E<R(*;7-G<W1R("));7!O<W/M=F5L(&-O;F5C=&%R(&%O
M('-E<G9I9&]R($E-05`Z("5S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C4Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V%N861A(@IM<V=S='(@(D-A
M;F%DX2(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ
M,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ-"!T96UP
M;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3<*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O<F5M;W9E+FEN8SHQ-PIM<V=I9"`B0V%N8V5L(@IM<V=S='(@
M(D-A;F-E;&%R(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")#86YC
M96QA<B!296QA=/-R:6\@9&4@4')O8FQE;6%S(@H*(SH@;&EB+U9&4R]F='`N
M<&AP.C(U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R(").XV\@8V]N<VEG;R!R96UO=F5R(&\@9FEC
M:&5I<F\@7"(E<UPB+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I
M;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(").XV\@8V]N<VEG
M;R!E;F-O;G1R87(@=6T@9&ER96-T\W)I;R!T96UP;W+A<FEO+B(*"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E960@
M=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R("));7!O
M<W/M=F5L(&-O;G1I;G5A<B!S96T@;R!P87+B;65T<F\@)W1A<F=E=$9I;&4G
M+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR-3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(").
MXV\@9F]I('!O<W/M=F5L(')E;6]V97(@82!P87-T82!<(B5S7"(N(@H*(SH@
M;&EB+TAO<F1E+T1A=&%4<F5E+G!H<#HQ,3(@;&EB+TAO<F1E+T1A=&%4<F5E
M+W-Q;"YP:'`Z-3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO
M=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R("));7!O<W/M=F5L(')E
M;6]V97(L(&5X:7-T96T@)60@9FEL:&]S+B(*"B,Z(&QI8B](;W)D92]$871A
M5')E92]S<6PN<&AP.C4Q,@IM<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU
M;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T
M(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@(B(*(D[C;R#I('!O
M<W/M=F5L(')E;W)D96YA<CH@;R!N^FUE<F\@9&4@96YT<F%D87,@9F]R;F5C
M:61A<R!NXV\@8V]R<F5S<&]N9&4@86\@(@HB;OIM97)O(&=U87)D861O+B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED
M(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*
M;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&5N8V%M:6YH87(@82!M96YS86=E
M;2!P87)A(&\@;OIM97)O(&EN9&EC861O+B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HV-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B
M"FUS9W-T<B`B4F5P^F)L:6-A(&1E($-A8F\@5F5R9&4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"FUS9VED
M(")#87!T:6]N(@IM<V=S='(@(DQE9V5N9&$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3`*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G
M<W1R(")#871E9V]R:6%S(&4@0V]R97,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3,U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N
M9',B"FUS9W-T<B`B26QH87,@0V%I;>-O(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T
M<B`B5&5L969O;F4@0V5L=6QA<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@4')O<&5R
M=&EE<R(*;7-G<W1R(")0<F]P<FEE9&%D97,@9&%S($/I;'5L87,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I
M9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R(")%;F-H:6UE;G1O(&1A<R!#Z6QU
M;&%S.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R(")0
M<F]P<FEE9&%D97,@9&%S(&/I;'5L87,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG
M.B(*;7-G<W1R(")%<W!AYV%M96YT;R!D87,@8^EL=6QA<SHB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3(W-`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@
M(E1E;&5M\W9E;"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED
M(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R(")#Z6QT:6-O("A)4T\M
M.#@U.2TQ-"DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T<B`B0V5N=')A
M<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R(")2
M97#Z8FQI8V$@0V5N=')O($%F<FEC86YA(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-SD*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I
M(@IM<V=S='(@(D5U<F]P82!#96YT<F%L("A)4T\M.#@U.2TR*2(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-CDY"FUS9VED(")#97)T:69I8V%T
M92!$971A:6QS(@IM<V=S='(@(E!O<FUE;F]R97,@9&\@0V5R=&EF:6-A9&\B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8Q,0IM<V=I9"`B0V5R
M=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B1&]N;R!D;R!#97)T:69I8V%D;R(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")#97)T
M:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R(")0;VSM=&EC87,@9&4@0V5R=&EF
M:6-A9&\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS9W-T<B`B4F5P^F)L:6-A(&1O($-H
M861E(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-PIM<V=I9"`B0VAA;F=E(@IM<V=S
M='(@(D%L=&5R87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G
M:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L
M92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA
M:6QS+B(*;7-G<W1R("(B"B)!;'1E<F4@;R!N;VUE(&4@96YD97)EYV\@<75E
M(&%S('!E<W-O87,@=F5RXV\@<75A;F1O(&QE<F5M(&4@<F5S<&]N9&5R96T@
MX',@(@HB<W5A<R!M96YS86=E;G,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA<B(*;7-G
M<W1R(")#87)A8W1E<F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN
M(@IM<V=S='(@(E9E<FE?9FEC87(@3&EG8>?C;RXN+B(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI;F,Z,3,*;7-G:60@(D-H96-K
M('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R
M9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(DUA<G%U92!A<R!O<&5R8>?U
M97,@<75E(&1E<V5J82!E>&5C=71A<B!N97-T92!M;VUE;G1O+B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HU.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@
M(D-H:6QE(@IM<V=S='(@(E)E</IB;&EC82!D;R!#:&EL92(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H
M:6YA(@IM<V=S='(@(E)E</IB;&EC82!0;W!U;&%R(&1A($-H:6YA(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI
M9FEE9"`H1T(R,S$R*2(*;7-G<W1R(")#:&ENZG,@4VEM<&QI9FEC861O<R`H
M1T(R,S$R*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#
M:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R(")#:&ENZG,@5')A
M9&EC:6]N86P@*$)I9S4I(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H
M<#HR-CD*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(D5S8V]L
M:&$@82!P86QA=G)A+7!A<W-E(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P
M+G!H<#HR-C@*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(D5S
M8V]L:&$@=6T@3F]M92!D92!5=&EL:7IA9&]R(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(Y,`IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A
M=&5S.B(*;7-G<W1R(")%<V-O;&AA(&-O;6\@;6]S=')A<B!A<R!D871A<SHB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@
M;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B17-C;VQH82!O(&5S=&EL;R!D87,@
M;&ES=&$@*'!A<F$@;&ES=&%S(&]R9&5N861A<RDB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#:')I<W1M
M87,@27-L86YD(@IM<V=S='(@(DEL:&$@9&\@3F%T86PB"@HC.B!L:6(O5D93
M+G!H<#HV,34@;&EB+TYE="]335,N<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T
M<B`B3N-O(&9O:2!E;F-O;G1R861A(&$@9&5F:6YIY^-O(&1A(&-L87-S92`E
M<RXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#4U"B,L('!H<"UF;W)M870*
M;7-G:60@(D-L96%N:6YG('5P(%!/(&9I;&5S(&9O<B!M;V1U;&4@)7,N+BXB
M"FUS9W-T<B`B3&EM<&%N9&\@;W,@87)Q=6EV;W,@4$\@9&\@;?-D=6QO("5S
M+BXN(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C@V-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;&5A;FEN9R!U<"!L;V-A;&4@)7,N+BX@(@IM<V=S='(@(DQI
M;7!A;F1O(&$@;&]C86QI>F'GXV\@)7,N+BX@(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G:60@(D-L96%R(@IM<V=S
M='(@(DQI;7!A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T
M<B`B3&EM<&%R(&5T:7%U971A<R!D;R!-4T]F9FEC92(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@
M(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R("),:6UP87(@9&%D;W,@9&\@
M=71I;&EZ861O<CH@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A
M<BYI;F,Z,38*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B3&EM<&%R(&1A
M9&]S(&1O('5T:6QI>F%D;W(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHS-`IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(DQI
M;7!A<B!D861O<R!D;R!U=&EL:7IA9&]R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B
M"FUS9W-T<B`B3&EM<&$@5&%R9&4B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O;F]T:6-E7V)O='1O;2YI;F,Z-@IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN
M=64B"FUS9W-T<B`B0VQI<75E('!A<F$@0V]N=&EN=6%R(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E
M;&P@=FEA($A45%`B"FUS9W-T<B`B0VQI8VMA=&5L;"!V:6$@2%144"(*"B,Z
M('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(D9E8VAA
M<B!J86YE;&$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-`IM<V=I9"`B
M0VQO=61S(@IM<V=S='(@(D[Z=F5N<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS
M9W-T<B`B3OIV96YS($UA=&EN86ES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R(")%
M;F5V;V%D;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S
M='(@(DEL:&%S($-O8V]S("A+965L:6YG*2(*"B,Z('1E;7!L871E<R]P;W)T
M86PO<VED96)A<BYI;F,Z-`IM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G
M<W1R(")#;VQA<'-A<B!"87)R82!,871E<F%L(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L
M;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B0F]R9&%S($-O;&%P<V%D87,B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C4W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#;VQO;6)I82(*;7-G<W1R(")297#Z8FQI8V$@9&$@0V]L]&UB:6$B
M"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP
M:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B0V]R97,B"@HC.B!L
M:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,CDY(&QI8B](;W)D92]"
M;&]C:R]#;VQL96-T:6]N+G!H<#HS,#`*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0W,B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K
M97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C4Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C4R"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C8X"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C8Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C@U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C@V"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B4&%L971E
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X-#4*;7-G:60@(D-O;&]U<B!S
M96QE8W1I;VXB"FUS9W-T<B`B4V5L96/GXV\@9&4@8V]R97(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B
M0V]L<SHB"FUS9W-T<B`B0V]L=6YA<SHB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3DT-PIM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R(")4[71U;&]S
M(&1A<R!C;VQU;F%S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X
M-@IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(D)$(@H*(SH@861M:6XO8VUD<VAE
M;&PN<&AP.C(U"FUS9VED(")#;VUM86YD(@IM<V=S='(@(D-O;6%N9&\B"@HC
M.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB
M"FUS9W-T<B`B0V]N<V]L82!D92!#;VUA;F1O<R(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HS.`IM<V=I9"`B0V]M;6%N9"!O<'1I;VYS.B(*;7-G<W1R(")/
M<.?U97,@9&\@8V]M86YD;SHB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.3<*
M;7-G:60@(D-O;6UA;F1S.B(*;7-G<W1R(")#;VUA;F1O<SHB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#(*;7-G:60@(D-O;6UE;G0B"FUS9W-T
M<B`B0V]M96YTX7)I;R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#`P"FUS
M9VED(")#;VUM:71T:6YG.B(*;7-G<W1R(")#;VUE=&5N9&\B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V-@IM<V=I9"`B0V]M;6]N($YA;64B
M"FUS9W-T<B`B3F]M92!#;VUU;2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@
M(D-O;6]R;W,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R(")%;7!R97-A(@H*(SH@;&EB
M+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.#$@;&EB+TAO<F1E+U1E
M>'0O1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@;&EB+TAO<F1E+U1E>'0O1FEL
M=&5R+V5M86EL<RYP:'`Z.3<@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL
M<RYP:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O;7!O<V4@365S<V%G
M92`H)7,I(@IM<V=S='(@(D5S8W)E=F5R("@E<RDB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R(")#;VUP
M=71A9&]R97,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@U
M"FUS9VED(")#;VYD:71I;VXB"FUS9W-T<B`B0V]N9&GGXV\B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(T.0IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R
M(")#;VYD:>?U97,B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I
M9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R(")$:69E<F5N
MYV%S(&1E($-O;F9I9W5R8>?C;R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ,S0*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM
M<V=S='(@(D$@8V]N9FEG=7)AY^-O(&5S=.$@9&5S86-T=6%L:7IA9&$B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z.3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(D-O;F9I9W5R87(@)7,B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,W"FUS9VED(")#;VYF
M:7)M(%!A<W-W;W)D(@IM<V=S='(@(D-O;F9I<FUE(&$@4&%L879R82U087-S
M92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C8*;7-G:60@(D-O;F=O(@IM<V=S='(@(E)E</IB;&EC82!$96UO8W+A=&EC
M82!D;R!#;VYG;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U
M8FQI8R!O9B!T:&4B"FUS9W-T<B`B4F5P^F)L:6-A($1E;6]C<N%T:6-A(&1O
M($-O;F=O(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y
M.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#
M;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`B0V]N97CC;R!F86QH;W4N(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.2!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N
M(&9A:6QE9#H@(@IM<V=S='(@(D-O;F5XXV\@9F%L:&]U.B`B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HW-SD*;7-G:60@(D-O;FYE8W1I;VX@<F5F
M=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B0V]N97CC
M;R!A;R!S97)V:61O<B!D92!C:&%V97,@</IB;&EC87,@<F5C=7-A9&$N(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S@Q"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(D-O;F5XXV\@86\@<V5R
M=FED;W(@9&4@8VAA=F5S('#Z8FQI8V%S(')E8W5S861A+B!287KC;SH@)7,@
M*"5S*2(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW-C(*;7-G:60@(D-O;FYE8W1I
M;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(D-O;F5XXV\@86\@
M<V5R=FED;W(@1E10(')E8W5S861A+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")#
M;VYT86-T;W,@861I8VEO;F%D;W,@8V]M('-U8V5S<V\@86\@<V5U(&QI=G)O
M(&1E(&5N9&5R9>=O<RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z
M+G!H<#HV,`IM<V=I9"`B0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL
M93H@(@IM<V=S='(@(E1I<&\@9&4@8V]N=&7Z9&\@9&\@87)Q=6EV;R!C;VUP
M<FEM:61O.B`B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU
M-B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=&=Z+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B0V]N=&7Z9&\@9&4@)7,B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.0IM<V=I9"`B0V]N
M=&EN=64B"FUS9W-T<B`B0V]N=&EN=6%R(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C4X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S
M(@IM<V=S='(@(DEL:&%S($-O;VLB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R(")";VQI;FAO(&-H:6[J<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R(")#;W!I87(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,V"FUS9VED(")#
M;W!Y('-E;&5C=&EO;B(*;7-G<W1R(")#;W!I87(@<V5L96/GXV\B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,3`X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W!Y:6YG("5S('1O("5S(@IM<V=S='(@(D-O<&EA;F1O(&1E("5S('!A<F$@
M)7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C8R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8W"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@(E)E</IB;&EC82!D82!#
M;W-T82!2:6-A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4W(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R(")297#Z
M8FQI8V$@9&$@0V]S=&$@9&\@36%R9FEM(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z.34V"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S
M<V%G92XB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!E;F-R:7!T87(@82!M
M96YS86=E;2!C;VT@4$=0+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C$P,S,*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+B(*;7-G
M<W1R(").XV\@9F]I('!O<W/M=F5L(&%S<VEN87(@82!M96YS86=E;2!C;VT@
M4$=0+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED
M(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B
M3N-O(&9O:2!P;W-S[79E;"!E;F-R:7!A<B!A(&UE;G-A9V5M(&-O;2!3+TU)
M344N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@
M(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R(").XV\@
M9F]I('!O<W/M=F5L(&%S<VEN87(@82!M96YS86=E;2!C;VT@4R]-24U%+B(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G
M<W1R(").XV\@9F]I('!O<W/M=F5L(&%D:6-I;VYA<B!O(&-O;G1A8W1O+B`E
M<R(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$Q,`IM<V=I9"`B0V]U
M;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(D9A;&AA(&YA
M(&QI9V'GXV\@*&)I;F0I(&%O('-E<G9I9&]R($Q$05`N(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S
M[79E;"!V97)I9FEC87(@;R!S86QD;RX@)7,B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O
M;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@
M(D[C;R!F;VD@<&]S<^UV96P@8V]N96-T87(@86\@<V5R=FED;W(@7"(E<UPB
M('5S86YD;R!&5%`Z("5S(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P.#<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O<'D@)7,@=&\@)7,B
M"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!C;W!I87(@)7,@<&%R82`E<R(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!L:7-T
M82!D92!D:7-T<FEB=6GGXV\N("5S(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C8X,2!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`W-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8W)E871E(&QO8V%L92!D:7)E8W1O<GD@9F]R(&QO
M8V%L92`E<SHB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!P87-T
M82!D92!L;V-A;&EZ8>?C;R!P87)A(&$@;&]C86QI>F'GXV\@)7,Z(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$P-0IM<V=I9"`B0V]U;&0@;F]T
M(&1E8W)Y<'0@4$=0(&1A=&$N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@
M9&5S96YC<FEP=&%R(&]S(&1A9&]S(&-O;2!O(%!'4"XB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4R,@IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y
M<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@9&5S
M96YC<FEP=&%R(&]S(&1A9&]S(&-O;2!3+TU)344N(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@(D[C;R!F
M;VD@<&]S<^UV96P@<F5M;W9E<B!C;VYT86-T;RX@)7,B"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM
M<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!L:7-T82!D92!D:7-T
M<FEB=6GGXV\N("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U
M<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV
M96P@<F5M;W9E<B!O(%PB<V-R:7!T7"(@9&4@86-T=6%L:7IAY^-O(%PB)7-<
M(BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,X,2!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HY,S@*;7-G:60@(D-O=6QD(&YO="!D971E<FUI
M;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R("(B
M"B).XV\@9F]I('!O<W/M=F5L(&1E=&5R;6EN87(@;R!E;F1E<F7G;R!D92!C
M;W)R96EO(&5L96-T<O-N:6-O(&1O("(*(F1E<W1I;F%TX7)I;RXB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L
M9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R(").
MXV\@9F]I('!O<W/M=F5L(&]B=&5R(&\@;&EV<F\@9&4@96YD97)EYV]S(&-O
M;7!L971O+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT
M.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I
M;VX@;&ES="XB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!A(&QI
M<W1A(&1E(&1I<W1R:6)U:>?C;R!C;VUP;&5T82XB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T
M8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*
M;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&]B=&5R(&$@;&ES=&$@8V]M<&QE
M=&$@9&%S(&QI<W1A<R!D92!D:7-T<FEB=6GGXV\N(@H*(SH@;&EB+U9&4R])
M4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!L:6(O5D93
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*
M;7-G<W1R("));7!O<W/M=F5L(&-A<G)E9V%R(&5S=')A=.EG:6$@7"(E<UPB
M+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C$Q,`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R("));7!O<W/M=F5L(&UK9&ER
M(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW,#@*;7-G
M:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES
M97)V97(N(@IM<V=S='(@(B(*(D[C;R!F;VD@<&]S<^UV96P@;V)T97(@82!C
M:&%V92!P^F)L:6-A(&$@<&%R=&ER(&1O('-E<G9I9&]R(&1E(&-H879E<R`B
M"B)P^F)L:6-A<RXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R(").XV\@
M9F]I('!O<W/M=F5L(&%B<FER(%PB)7-<(B!P87)A(&5S8W)I=&$N(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-R!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E
M;"!A8G)I<B`E<RXB"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C0Q
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N
M86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L
M(&%B<FER(&\@;?-D=6QO(&1E($UA;G5T96[GXV\@9&4@5&%R969A<R`E<R(*
M"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I
M<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@86)R
M:7(@<&%S=&$@7"(E<UPB+B(*"B,Z(&QI8B]61E,O3V)J96-T+G!H<#HR,S@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S
M='(@(D[C;R!F;VD@<&]S<^UV96P@;&5R("5S+B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@
M=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@
M86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G
M86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D
M("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB3N-O(&9O:2!P;W-S[79E
M;"!R96EN:6-I87(@82!P86QA=G)A+7!A<W-E(&1O('5T:6QI>F%D;W(@:6YD
M:6-A9&\N($%L9W5M(&]U("(*(G1O9&]S(&]S('!O<FUE;F]R97,@;N-O(&5S
M=&%V86T@8V]R<F5C=&]S+B!0;W(@9F%V;W(@=&5N=&4@9&4@;F]V;R!O=2`B
M"B)C;VYT86-T92!O('-E=2!A9&UI;FES=')A9&]R(&1E('-I<W1E;6%S('-E
M('!R96-I<V%R(&1E(&UA:7,@86IU9&$N(@H*(SH@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,P.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S0P"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M-S<@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,PHC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@;V)T
M97(@04-,(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D
M<F5S<R!B;V]K+B`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&]B=&5R
M(&QI=G)O(&1E(&5N9&5R9>=O<RX@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B
M3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!L:7-T82!D92!D:7-T<FEB=6GGXV\N
M("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I
M8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&]B
M=&5R(&QI<W1A<R!D92!D:7-T<FEB=6GGXV\N("5S(@H*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.2!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,C$Y"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C
M87!A8FEL:71I97,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!A
M<R!C;VUP973J;F-I87,@9&\@<V5R=FED;W(B"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@<F5V97)T97(@82!C
M;VYF:6=U<F'GXV\N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S[79E;"!R;61I
M<B!<(B5S7"(N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!G=6%R9&%R(&$@8V]N
M9FEG=7)AY^-O(&1E("5S+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV
M,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R(").XV\@9F]I
M('!O<W/M=F5L(&=U87)D87(@82!C;VYF:6=U<F'GXV\@9&4@<V%L=F%G=6%R
M9&$N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO
M;CH@)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!G=6%R9&%R(&$@8V]N
M9FEG=7)AY^-O(&1E('-A;'9A9W5A<F1A.B`E<R(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.CDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S
M='(@(D[C;R!F;VD@<&]S<^UV96P@9W5A<F1A<B!O(%PB<V-R:7!T7"(@9&4@
M86-T=6%L:7IAY^-O(&5M.B!<(B5S7"(N(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V
M92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B
M3N-O(&9O:2!P;W-S[79E;"!G=6%R9&%R(&$@8V]N9FEG=7)AY^-O(&1E('-A
M;'9A9W5A<F1A("5S+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O
M;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O
M9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@
M;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T
M<B`B(@HB3N-O(&9O:2!P;W-S[79E;"!G=6%R9&%R(&\@87)Q=6EV;R!D92!C
M;VYF:6=U<F'GXV\@)7,N(%!O9&4@=7-A<B!U;6$@9&%S("(*(F]PY_5E<R!P
M87)A(&=U87)D87(@;R!C\V1I9V\@96T@)7,@;W4@8V]P:6%R(&UA;G5A;&UE
M;G1E(&\@8_-D:6=O(&%B86EX;R`B"B)P87)A("5S+B(*"B,Z(&QI8B](;W)D
M92]!=71H+VQD87`N<&AP.C$R,`IM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T
M:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@<')O
M8W5R87(@;F\@<V5R=FED;W(@3$1!4"XB"@HC.B!L:6(O5D93+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B3N-O
M(&9O:2!P;W-S[79E;"!D97-L:6=A<B!<(B5S7"(N(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(D[C;R!F
M;VD@<&]S<^UV96P@86-T=6%L:7IA<B!C;VYT86-T;RX@)7,B"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S
M(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@86-T=6%L:7IA<B!A(&QI<W1A
M(&1E(&1I<W1R:6)U:>?C;RX@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O
M;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B3N-O(&9O:2!P
M;W-S[79E;"!E<V-R979E<B!A(&-O;F9I9W5R8>?C;R!P87)A(%PB)7-<(CH@
M)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4X"FUS9VED(")#;W5L
M9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@
M<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B"B).XV\@96YC;VYT<F5I(&$@
M0F%R<F$@3&%T97)A;"!D;R!-;WII;&QA+B!!<W-E9W5R92US92!Q=64@82!B
M87)R82!L871E<F%L("(*(F5S=.$@86)E<G1A+B(*"B,Z(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I
M9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*(D[C
M;R!F;VD@<&]S<^UV96P@871R:6)U:7(@86\@=71I;&EZ861O<B!<(B5S7"(@
M;W,@<V5G=6EN=&5S(&1I<F5I=&]S('-O8G)E(&$@(@HB<&%S=&$@7"(E<UPB
M.B`E<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(Q"FUS9VED(")#;W5N
M=&5D('1E>'0B"FUS9W-T<B`B5&5X=&\@0V]N=&%D;R(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")#;W5N=')Y(@IM<V=S='(@
M(E!A[7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<P"FUS9VED
M(")#;W5R<V5S(@IM<V=S='(@(D-U<G-O<R(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.3<*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,0IM<V=I9"`B
M0W)E871E(@IM<V=S='(@(D-R:6%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED(")#<F5A=&4@
M82!L:6YK(@IM<V=S='(@(D-R:6%R('5M82!L:6=AY^-O(@H*(SH@=&5M<&QA
M=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PIM<V=I9"`B0W)E871E
M(&$@;F5W(&]N92(*;7-G<W1R(")#<FEA<B!U;6$@;F]V82(*"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E('-U
M8B!F;VQD97)S(@IM<V=S='(@(D-R:6%R('-U8BUP87-T87,B"@HC.B!A9&UI
M;B]P97)M<R]E9&ET+G!H<#HQ,S8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR
M,30*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R;6ES
M<_5E<R!D;R!#<FEA9&]R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R,CD*
M;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R(").^FUE<F\@9&\@
M8V%R=.-O(&1E(&-RZ61I=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G<W1R(")2
M97#Z8FQI8V$@9&$@0W)OX6-I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HV-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B4F5P
M^F)L:6-A(&1E($-U8F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*;7-G
M:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B475A=')O(&9A<V5S(&-O
M<G)E;G1E<R(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T
M:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(D1A=&$O
M2&]R82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU,PIM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B
M55),(&-O<G)E;G1E(.DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS
M9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B17-T861O(&1O(%1E;7!O
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V,PIM<V=I9"`B
M0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R(")3:71U8>?C;R!A8W1U86PZ
M("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B17-T:6QO(&%C='5A
M;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O
M("5S+B(*;7-G<W1R(")097)S;VYA;&EZ87(@87,@=&%R969A<R!Q=64@<V5R
MXV\@97AE8W5T861A<R!A<75A;F1O(&\@;&]G:6X@;F\@)7,N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P
M"FUS9VED(")#=70B"FUS9W-T<B`B0V]R=&%R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C
M=&EO;B(*;7-G<W1R(")#;W)T87(@82!S96QE8^?C;R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U
M<R(*;7-G<W1R(")297#Z8FQI8V$@9&4@0VAI<')E(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#(*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S
M='(@(D-I<NUL:6-O("A+3TDX+5(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#,*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@
M(D-I<NUL:6-O("A7:6YD;W=S+3$R-38I(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#0*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*
M;7-G<W1R(")#:7+M;&EC;R]58W)A;FEA;F\@*$M/23@M52DB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C8W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#
M>F5C:"!297!U8FQI8R(*;7-G<W1R(")297#Z8FQI8V$@0VAE8V$B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(S('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")$1"(*"B,Z(&QI
M8B](;W)D92]-86EN=&5N86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S
M='(@(D1I87)I86UE;G1E(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS
M9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(DYA=F5G861O<B!D92#!
M<G9O<F4@9&4@1&%D;W,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,Y."!L
M:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,@IM<V=I9"`B1&%T
M92(*;7-G<W1R(")$871A(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B1&%T
M82!D92!296-E<.?C;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#`V"FUS
M9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R(")396QE8^?C;R!D92!D871A
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,"!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$P"FUS9VED(")$87DB"FUS9W-T<B`B
M1&EA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,U"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R(")2
M96UO=F5R($-O7VQU;F$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S@U(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B1&5Z96UB<F\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B3OIM97)O<R!D
M96-I;6%I<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R(")2961U
M>FER(&EN9&5N=&'GXV\B"@HC.B!L:6(O<')E9G,N<&AP.C$Q,2!L:6(O2&]R
M9&4O4')E9G,O54DN<&AP.C$X-PIM<V=I9"`B1&5F875L="(*;7-G<W1R(")0
M;W(@3VUI<W/C;R(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C0W"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C@Q"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(D-O
M<B!0;W(@3VUI<W/C;R(*"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z.3$*
M;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B261E;G1I9&%D92!0
M861RXV\B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,3D@;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<#HQ.38*;7-G:60@(D1E9F%U;'0@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B4&5R;6ES<_5E<R!0;W(@3VUI<W/C;R(*"B,Z(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,3DW"FUS9VED(")$969A=6QT('!E<FUI<W-I;VYS
M(@IM<V=S='(@(E!E<FUI<W/U97,@<&]R(&]M:7-SXV\B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@
M(D1E9FEN:>?U97,B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<R(&%D;6EN+W!E
M<FUS+V1E;&5T92YP:'`Z-#8@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC
M.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(Y-2!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C,Q-0HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,S,B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,V"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z-S`@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,PHC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.CDY('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L
M971E+FEN8SHQ,PHC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS
M,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(E)E;6]V97(B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C$X.2!A9&UI;B]G<F]U<',N<&AP.C(Q-PIM<V=I9"`B1&5L
M971E($=R;W5P(@IM<V=S='(@(E)E;6]V97(@1W)U<&\B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C8S(&QI8B](;W)D92]097)M<R]522YP:'`Z.#<*
M;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@(E)E;6]V97(@4&5R
M;6ES<^-O(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS
M"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(E)E
M;6]V97(@92!P=7)G87(@;65N<V%G96YS(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E
M(&-E;&PB"FUS9W-T<B`B4F5M;W9E<B!CZ6QU;&$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S"FUS9VED(")$
M96QE=&4@8V]L=6UN(@IM<V=S='(@(E)E;6]V97(@8V]L=6YA(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A
M;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B4F5M;W9E<B!M;V1E;&\@86QT
M97)N871I=F\@97AI<W1E;G1E(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H
M<#HU,"!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,Q-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R
M(")296UO=F5R('!E<FUI<W/U97,@9&4@7"(E<UPB(@H*(SH@;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<#HS,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E
M('!E<FUI<W-I;VYS(&9O<B`G)7,G(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS
M/R(*;7-G<W1R(")296UO=F5R('!E<FUI<W/U97,@<&%R82`G)7,G(&4@<75A
M:7-Q=65R('-U8BUP97)M:7-S]65S/R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R
M;W<B"FUS9W-T<B`B4F5M;W9E<B!L:6YH82(*"B,Z('1E;7!L871E<R]P<F5F
M<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E
M9"!I9&5N=&ET>2(*;7-G<W1R(")296UO=F5R(&ED96YT:61A9&4@<V5L96-C
M:6]N861A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8V"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L
M=6UN(@IM<V=S='(@(E)E;6]V97(@82!C;VQU;F$@8V]R<F5N=&4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C(*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B4F5M
M;W9E<B!A(&QI;FAA(&-O<G)E;G1E(@H*(SH@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HT.`IM<V=I9"`B1&5L971E('1H:7,@<&5R;6ES<VEO;B!A;F0@86YY
M('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B4F5M;W9E<B!E<W1A('!E<FUI
M<W/C;R!E('1O9&%S(&%S('-U87,@<W5B+7!E<FUI<W/U97,_(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@
M(EPB4V-R:7!T7"(@9&4@86-T=6%L:7IAY^-O(%PB)7-<(B!R96UO=FED;RXB
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR-3,*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B
M36]M96YT;R!D92!E;G1R96=A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C<Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R(")$
M:6YA;6%R8V$B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,3`@<V5R=FEC
M97,O<')O8FQE;2YP:'`Z,3$T('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-`IM
M<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B1&5S8W)E=F$@
M;R!0<F]B;&5M82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY,S@@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I
M9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B1&5S8W)IY^-O(@H*(SH@;&EB+TAO
M<F1E+G!H<#HQ.34*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L
M;V=F:6QE*3HB"FUS9W-T<B`B4&]R;65N;W)E<R`H=&%M8NEM(&YO(')E9VES
M=&\L(%PB;&]G7"(L(&1O($AO<F1E*3HB"@HC.B!L:6(O2&]R9&4N<&AP.C$Y
M.0IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B3W,@9&5T86QH97,@9F]R86T@96YV:6%D
M;W,@<&%R82!O(&%D;6EN:7-T<F%D;W(@9&\@<VES=&5M82XB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DX"FUS9VED(")$979E;&]P;65N="(*
M;7-G<W1R(")$97-E;G9O;'9I;65N=&\B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(Q-PIM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(E!O;G1O(&1E($]R
M=F%L:&\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I9"`B1&5W
M(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")0;VYT;R!D92!/<G9A
M;&AO(&YA(/IL=&EM82!H;W)A.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C$U"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R(")0;VYT
M;R!D92!O<G9A;&AO.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H
M="(*;7-G<W1R(")$:7)E8^?C;R!D82!E<W%U97)D82!P87)A(&$@9&ER96ET
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(D1I
M<F5CY^-O(&1A(&1I<F5I=&$@<&%R82!A(&5S<75E<F1A(@H*(SH@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R(")$
M:7)E8W3S<FEO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U.`IM<V=I
M9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R(")-;W-T<F%R('1E
M;7!O<R!C;VT@,C0@:&]R87,_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.CDW"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B3W#G]65S(&1E
M(%9I<W5A;&EZ8>?C;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HX.`IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R
M(")-;W-T<F%R('!R979I<^-O('!O<FUE;F]R:7IA9&$B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C@U"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I
M(@IM<V=S='(@(DUO<W1R87(@<')E=FESXV\@*%1!1BDB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C@Q-@IM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T
M<B`B1F]R;6%T;R!D92!V:7-U86QI>F'GXV\B"@HC.B!L:6(O2&]R9&4O34E-
M12]-1$XN<&AP.C$Y,`IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N
M(@IM<V=S='(@(DYO=&EF:6-AY^-O(&1E($1I<W!O<VGGXV\B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C8Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$
M:FEB;W5T:2(*;7-G<W1R(")$:FEB=71I(@H*(SH@861M:6XO<&5R;7,O9&5L
M971E+G!H<#HT-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,Q-0IM<V=I9"`B
M1&\@;F]T(&1E;&5T92(*;7-G<W1R(").XV\@<F5M;W9E<B(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HR-`IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY
M(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B3N-O('5T:6QI>F4@
M;R!M86EN=&5N86YC92YP:'`@9&ER96-T86UE;G1E(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O='-V:6YF;RYI;F,Z,3D@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,3D*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F
M:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B
M(@HB02!P<FEM96ER82!L:6YH82!C;VYTZ6T@;W,@;F]M97,@9&]S(&-A;7!O
M<S\@4V4@<VEM+"!A<W-I;F%L87(@97-T82!C86EX83HB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C<P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI
M;FEC82(*;7-G<W1R(")$;VUI;FEC82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HW,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!297!U
M8FQI8R(*;7-G<W1R(")297#Z8FQI8V$@1&]M:6YI8V%N82(*"B,Z(&QI8B](
M;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#$*;7-G:60@(D1O=VYL;V%D(@IM
M<V=S='(@(E)E8V5B97(B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP
M:'`Z.#0Q"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S
M='(@(E)E8V5B97(@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38U
M"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!0
M2%`@<V-R:7!T+B(*;7-G<W1R(")$97-C87)R96=A<B!A(&-O;F9I9W5R8>?C
M;R!G97)A9&$@8V]M;R!U;2!<(G-C<FEP=%PB(%!(4"XB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C$P.`IM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T
M<B`B3&ES=&$@9&4@9&5S96YR;VQA<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`B1')O9V%S(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`R"FUS9VED(")%+4UA:6PB"FUS9W-T
M<B`B0V]R<F5I;R!E;&5C='+S;FEC;R(*"B,Z(&QI8B](;W)D92].;W1I9FEC
M871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S
M='(@(D524B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B4F5P^F)L:6-A(&1O
M($5Q=6%D;W(B"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(Y-"!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]E9&ET+FEN8SHR,@IM<V=I9"`B161I="(*;7-G<W1R(")%9&ET87(B
M"@HC.B!L:6(O2&]R9&4O0FQO8VLO54DN<&AP.C4P('1E;7!L871E<R]P;W)T
M86PO961I="YI;F,Z,C(*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B161I
M=&%R($)L;V-O(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.#@@861M:6XO9W)O
M=7!S+G!H<#HR,38*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B161I=&%R
M($=R=7!O(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HV,B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C@V"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS
M9W-T<B`B161I=&%R(%!E<FUI<W/U97,B"@HC.B!S97)V:6-E<R]S:&%R97,O
M961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@
M(D5D:71A<B!097)M:7-S]65S(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N
M<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS
M(&9O<B`E<R(*;7-G<W1R(")%9&ET87(@<&5R;6ES<_5E<R!D92`E<R(*"B,Z
M('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N
M<R!F;W(Z(@IM<V=S='(@(D5D:71A<B!O<.?U97,@9&4Z(@H*(SH@861M:6XO
M<&5R;7,O961I="YP:'`Z,C`T(&QI8B](;W)D92]097)M<R]522YP:'`Z,C@P
M"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB
M)7-<(B(*;7-G<W1R(")%9&ET87(@<&5R;6ES<_5E<R!D92!<(B5S7"(B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M870*
M;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(D5D:71A
M<B!P97)M:7-S]65S(&1E("5S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B161U8V'GXV\B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C<S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED
M(")%9WEP="(*;7-G<W1R(")%9VEP=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R
M(@IM<V=S='(@(E)E</IB;&EC82!D92!%;"!386QV861O<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM
M<V=I9"`B16QE;65N="XN+B(*;7-G<W1R(")%;&5M96YT;RXN+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED
M(")%;2(*;7-G<W1R(")%;2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<P
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T"FUS9VED(")%
M;6%I;"(*;7-G<W1R(")#;W)R96EO($5L96-T<O-N:6-O(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C0P"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D5N9&5R9>=O
M(&1E($-O<G)E:6\@16QE8W1R\VYI8V\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3DV-`IM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM
M<V=S='(@(D]S(&5N9&5R9>=O<R!TZFT@<75E(&-O:6YC:61I<BXB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3DY,`IM<V=I9"`B16UA:6P@=VET:"!C;VYF
M:7)M871I;VXB"FUS9W-T<B`B365N<V%G96T@8V]M(&-O;F9I<FUAY^-O(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(X,`IM<V=I
M9"`B16UO=&EC;VYS(@IM<V=S='(@(E/M;6)O;&]S(&1E($5M;^?C;R(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED(")%
M;7!T>2!M97-S86=E+B(*;7-G<W1R(")-96YS86=E;2!V87II82XB"@HC.B!L
M:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ,C@*;7-G:60@(D5M<'1Y(')E<W5L
M="XB"FUS9W-T<B`B4V5M(')E<W5L=&%D;W,N(@H*(SH@;&EB+TAO<F1E+U-1
M3"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B
M"FUS9W-T<B`B4V5M('1E<FUO<R!D92!P<F]C=7)A(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4S-0IM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I
M;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B
M06-T:79A<B!I;G-E<N?C;R!D92!I;6%G96YS(&1E($=A;&5R:6%S($9O=&]G
M<N%F:6-A<R!N;R!T97AT;S\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3$P"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*
M;7-G<W1R(")!8W1I=F%R(&UE;G4@9&4@8V]N=&5X=&\@;F\@8F]TXV\@9&ER
M96ET;R!D;R!R871O/R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3DW(&QI
M8B](;W)D92]&;W)M+G!H<#HR.#$P"FUS9VED(")%;F0@>65A<B(*;7-G<W1R
M(")!;F\@9&4@9FEM(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`B
M075M96YT87(@161I=&]R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q
M,PIM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y
M;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*
M(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T
M/R<Z(@IM<V=S='(@(B(*(DEN=')O9'5Z82!U;6$@<&5R9W5N=&$@9&4@<V5G
M=7)A;N=A('%U92!S97+A(&-O;G9I9&%D;R!A(')E<W!O;F1E<B!S92`B"B)P
M<F5C:7-A<B!D92!R96EN:6-I87(@82!S=6$@<&%L879R82UP87-S92P@92YG
M+BP@)V-O;6\@<V4@8VAA;6$@;R!S974@86YI;6%L("(*(F1E(&5S=&EM8>?C
M;S\G.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H
M97)E(@IM<V=S='(@(DEN=')O9'5Z82!O(%523"!D82!I;6%G96T@87%U:2(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,38S"B,L('!H<"UF;W)M870*;7-G
M:60@(D5N=')I97,Z("5D('1O=&%L+"`E9"!U<"UT;RUD871E+"`E9"!N97<L
M("5D(&-H86YG960L("5D('5N:VYO=VXB"FUS9W-T<B`B(@HB16YT<F%D87,Z
M("5D('1O=&%L+"`E9"!A8W1U86QI>F%D87,L("5D(&YO=F%S+"`E9"!A;'1E
M<F%D87,L("5D(&1E<V-O;FAE8VED87,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U
M:6YE82(*;7-G<W1R(")'=6ENZ2!%<75A=&]R:6%L(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C<Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW
M-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E
M82(*;7-G<W1R(")%<W1A9&\@9&$@17)I=')E:6$B"@HC.B!L:6(O2&]R9&4O
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C0W(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S8*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HW.0IM<V=I9"`B17)R
M;W(B"FUS9W-T<B`B17)R;R(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N
M(@IM<V=S='(@(D5R<F\@;F$@;65N<V%G96T@9&4@8V]R<F5I;R!E;&5C='+S
M;FEC;RXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I
M=&EN9R!<(B5S7"(N(@IM<V=S='(@(D5R<F\@86\@97-C<F5V97(@7"(E<UPB
M+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,3,@<&\O=')A;G-L871I;VXN
M<&AP.C4R,B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,W-PHC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,30S."!P;R]T<F%N<VQA=&EO;BYP:'`Z,34P,0IM<V=I9"`B
M17)R;W(Z("(*;7-G<W1R(")%<G)O.B`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM<V=S
M='(@(E)E</IB;&EC82!D82!%<W3S;FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C@Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS
M9W-T<B`B4F5P^F)L:6-A($1E;6]C<N%T:6-A($9E9&5R86P@9&$@171I\W!I
M82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC
M(@IM<V=S='(@(LET:6-O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-34*;7-G:60@(D5U<F]P92(*;7-G<W1R(")%=7)O<&$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S,Q"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM
M<V=S='(@(D-A9&$@,34@;6EN=71O<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.#$*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R(")#861A
M(#(@;6EN=71O<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,C@@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,W.0IM<V=I9"`B179E<GD@,S`@<V5C;VYD
M<R(*;7-G<W1R(")#861A(#,P('-E9W5N9&]S(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,S,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@R"FUS9VED
M(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B0V%D82`U(&UI;G5T;W,B"@HC
M.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,
M;V=I;B(*;7-G<W1R(")#861A($5N=')A9&$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S,R"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B
M0V%D82!M96EA(&AO<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(Y
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#`*;7-G:60@(D5V97)Y(&UI;G5T
M92(*;7-G<W1R(")#861A(&UI;G5T;R(*"B,Z('1E;7!L871E<R]D871A+V1A
M=&5M87`N:6YC.C(X"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B
M5F%L;W)E<R!E>&5M<&QO.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A
M9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R.`IM
M<V=I9"`B17AE8W5T92(*;7-G<W1R(")%>&5C=71A<B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HR.3D@<&\O=')A;G-L871I;VXN<&AP.C,R,"!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,S8R"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT-#$@<&\O
M=')A;G-L871I;VXN<&AP.C4T,2!P;R]T<F%N<VQA=&EO;BYP:'`Z-C`Q"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HW,#(@<&\O=')A;G-L871I;VXN<&AP.C<S
M-R!P;R]T<F%N<VQA=&EO;BYP:'`Z-SDX"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HX-S4@<&\O=')A;G-L871I;VXN<&AP.CDY-"!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,3`Q-@IM<V=I9"`B17AE8W5T:6YG.B(*;7-G<W1R(")%>&5C=71A;F1O
M.B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C,Y-`IM<V=I9"`B
M17AP86YD(@IM<V=S='(@(D5X<&%N9&ER(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]S:61E8F%R+FEN8SHS,0IM<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T
M<B`B36]S=')A<B!"87)R82!,871E<F%L(@H*(SH@;&EB+TAO<F1E+U-13"]+
M97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B
M)RDG(&5S<&5R861O(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z
M,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C
M:"!T97)M(@IM<V=S='(@(D5S<&5R879A('5M82!S:6UP;&5S('!A;&%V<F$@
M;W4@=6T@=&5R;6\@9&4@<')O8W5R82!E;G1R92!A<W!A<R(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C0P,0IM<V=I9"`B17AP:7)A=&EO;B!$871E
M(@IM<V=S='(@(D1A=&$@9&4@17AP:7)AY^-O(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HV-S8*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@(D5X
M<&]E;G1E(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C(W,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%>'1R86-T:6YG(&9R;VT@)7,N+BX@(@IM<V=S='(@(D5X
M=')A:6YD;R!D92`E<RXN+B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G
M<W1R(")#;W(@9&\@4')I;65I<F\@4&QA;F\B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3@P"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S
M='(@(D-A<G)E9V%R(&-O;F9I9W5R8>?C;R!D92!I;G-T86QAY^-O('!O<B!&
M5%`B"@HC.B!L:6(O2&]R9&4O4')E9G,O<W%L+G!H<#HR,38*;7-G:60@(D9A
M:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R(").XV\@9F]I
M('!O<W/M=F5L('!U>&%R(&%S('!R969E<NIN8VEA<RXB"@HC.B!L:6(O2&]R
M9&4O075T:"]L9&%P+G!H<#HQ,#`*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T
M('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")&86QH82!N82!L:6=AY^-O(&%O
M('-E<G9I9&]R($Q$05`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HY
M.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS
M9W-T<B`B1F%L:&$@;F$@;&EG8>?C;R!A;R!S97)V:61O<B!334(N(@H*(SH@
M;&EB+U9&4R]F='`N<&AP.C8P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL
M960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B1F%L:&$@86\@8V]P
M:6%R(&1E(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-C`X"B,L('!H
M<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS
M9W-T<B`B1F%L:&$@86\@8V]P:6%R('!A<F$@7"(E<UPB+B(*"B,Z(&QI8B](
M;W)D92]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@8W)E871E
M(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(D9A;&AA(&%O(&-R:6%R
M('5M82!N;W9A(&-O;F5XXV\@4T%33"XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z
M-C0Q"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB
M)7-<(BXB"FUS9W-T<B`B1F%L:&$@86\@;6]V97(@<&%R82!<(B5S7"(N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G
M:60@(D9A:7(B"FUS9W-T<B`B0F]M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C@T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD
M<R`H36%L=FEN87,I(@IM<V=S='(@(DEL:&%S($9A;&ML86YD("A-86QV:6YA
M<RDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#8@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C@P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<S"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S='(@(DEL:&%S($9A<F]E
M(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z,C,X"FUS9VED(")&871A;"!%<G)O
M<CHB"FUS9W-T<B`B17)R;R!&871A;#HB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A>"(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS-S4@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R
M=6%R>2(*;7-G<W1R(")&979E<F5I<F\B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R(")!<&%R96YT82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3D*;7-G:60@(D9E
M96QS(&QI:V4Z("(*;7-G<W1R(")!<&%R96YT83H@(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W
M97)S(@IM<V=S='(@(D%L9W5N<R!!9W5A8V5I<F]S(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W
M(%-H;W=E<G,B"FUS9W-T<B`B06QG=6YS($YE=O5E<R(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ.30U"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T<B`B
M36%T<FEZ(&1E(&-A;7!O<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B1FEJ:2(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8P(&QI8B](;W)D
M92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U
M;G0Z("5S(&9I;&4B"FUS9W-T<B`B0V]N=&%G96T@9&4@07)Q=6EV;W,Z("5S
M(&%R<75I=F\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV
M,"!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R(")#;VYT86=E;2!D92!!
M<G%U:79O<SH@)7,@87)Q=6EV;W,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S0V"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B1V5S=.-O
M(&1E($9I8VAE:7)O<R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N
M<&AP.C8S(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@R"FUS9VED(")&:6QE($YA
M;64B"FUS9W-T<B`B3F]M92!D;R!!<G%U:79O(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(Y.30*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(E-E
M;&5CY^-O(&1O(&%R<75I=F\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30X
M.`IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B0V%R<F5G86UE;G1O(&1E
M(&%R<75I=F\B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.#8S"FUS9VED
M(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B0V%R<F5G
M86UE;G1O<R!D92!F:6-H96ER;W,@;N-O('/C;R!S=7!O<G1A9&]S+B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX.0IM<V=I9"`B1FEL=&5R<R(*
M;7-G<W1R(")&:6QT<F]S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R(")&:6YL
MXFYD:6$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<Q"FUS9VED(")&:7)S
M="!(86QF(@IM<V=S='(@(E%U87)T;R!#<F5S8V5N=&4B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&
M:7)S="!1=6%R=&5R(@IM<V=S='(@(E%U87)T;R!#<F5S8V5N=&4B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Y"FUS9VED(")&
M:7@@<F%T:6\B"FUS9W-T<B`B1FEX87(@<N%C:6\B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C$T"FUS9VED(")&;&EP(@IM<V=S
M='(@(DEN=F5R=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B1FQU
M='5A;G1E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R(").979O96ER;R(*"B,Z(&QI8B]6
M1E,O<W%L+G!H<#HQ-C`@;&EB+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L('!H<"UF
M;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R
M(")!('!A<W1A("5S(&[C;R!E>&ES=&4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*
M;7-G<W1R(")#;W(@9&\@5&5X=&\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B0V]M:61A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V
M"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E
M<R(*;7-G<W1R(")087)A(&YA=F5G861O<F5S('%U92!NXV\@<W5P;W)T86T@
M:6UA9V5N<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,T"FUS9VED(")&
M;W)E8V%S="`H5$%&*2(*;7-G<W1R(")0<F5V:7/C;R`H5$%&*2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,0IM<V=I9"`B(@HB1F]R96-A
M<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U
M<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R
M92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"B)$
M:6%S(&1E(%!R979I<^-O("AN;W1E+7-E('%U92!A<R!P<F5V:7/U97,@:6YC
M;'5E;2!T86YT;R!D:6%S(&-O;6\@;F]I=&5S.R`B"B)U;2!V86QO<B!D96UA
M<VEA9&\@9W)A;F1E('!O9&4@<F5S=6QT87(@;G5M(&)L;V-O(&UU:71O(&QA
M<F=O*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3@*;7-G:60@
M(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R(")%<W%U96-E=2US92!D
M82!P86QA=G)A+7!A<W-E/R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,#D*;7-G:60@(D9O<FUS(@IM<V=S='(@(DUO9&5L;W,B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B
M1&ET;W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O
M<G1U;F4@='EP92(*;7-G<W1R(")4:7!O(&1E(&1I=&]S(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R(")$
M:71O<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R
M='5N97,@,B(*;7-G<W1R(")$:71O<R`R(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0P,`IM<V=I9"`B1F]R=6US(@IM<V=S='(@(D;S<G5N<R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#D*;7-G:60@(D9O<G=A
M<F1S(@IM<V=S='(@(E)E96YV:6]S(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C$T-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]U;F0@87!P;&EC871I;VYS
M.B`E<R(*;7-G<W1R(")!<&QI8V'G]65S("AM\V1U;&]S*2!E;F-O;G1R861A
M<SH@)7,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,30U,@IM<V=I9"`B1F]U
M;F0@9&ER96-T;W)I97,Z(@IM<V=S='(@(E!A<W1A<R!E;F-O;G1R861A<SHB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P
M"FUS9VED(")&<B(*;7-G<W1R("(VJB(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@(D9R86UE<R(*
M;7-G<W1R(")-;VQD=7)A<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92(*;7-G<W1R(")297#Z
M8FQI8V$@1G)A;F-E<V$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B1G)A;N=A
M+"!-971R;W!O;&ET86YA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDQ
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R
M(")'=6EA;F$@1G)A;F-E<V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3@T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*
M;7-G<W1R(")0;VQI;NES:6$@1G)A;F-E<V$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C(R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3
M;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R(")497)R87,@075S=')A:7,@
M92!!;G3A<F-T:6-A<R!&<F%N8V5S87,B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R(")$92(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S8@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,T.`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,SDT"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B1&4@(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*;7-G:60@(D9U
M;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B1&5S8W)IY^-O($-O;7!L971A(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@R(&QI8B]";&]C:R]M;V]N+G!H<#HQ
M.#$*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R("),=6$@0VAE:6$B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,Y"FUS9VED(")&=6QL
M($YA;64B"FUS9W-T<B`B3F]M92!#;VUP;&5T;R(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HV-3<*;7-G:60@(D9U>GIY(@IM<V=S='(@(D1I9G5S87,B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C@W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS
M9VED(")'86)O;B(*;7-G<W1R(")297#Z8FQI8V$@1V%B;VYE<V$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S
M='(@(D=A;&5R:6$@9&4@;VYD92!R971I<F%R(&$@:6UA9V5M(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R(")'86QE<FEA.B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HY-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@
M(D=A;6)I82(*;7-G<W1R(")297#Z8FQI8V$@9&$@1^)M8FEA(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'
M96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(D=E<F%R($-O;F9I
M9W5R8>?C;R`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N
M:'1M;#HQ,`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B0_-D:6=O
M($=E<F%D;R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT-SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1V5N97)A=&EN9R!S=&%T=7,@9F]R(&UO9'5L92`E<RXN
M+B(*;7-G<W1R(")'97)A;F1O(&\@97-T861O(&1O(&WS9'5L;R`E<RXN+B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*
M;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B1V7S<F=I82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HV.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA
M;GDB"FUS9W-T<B`B4F5P^F)L:6-A($9E9&5R86P@9&$@06QE;6%N:&$B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,W,0IM<V=I9"`B1V5T;W!T($5R<F]R
M.B`B"FUS9W-T<B`B17)R;R!E;2!G971O<'0Z(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.CDS(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS
M9W-T<B`B4F5P^F)L:6-A(&1O($=A;F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS
M9W-T<B`B1VEB<F%L=&%R(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU-S4*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`B3F]M92!0<O-P<FEO
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3(*;7-G:60@(D=O(@IM
M<V=S='(@(DER(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED
M(")';V5D96PB"FUS9W-T<B`B1_9D96PB"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(E!E<W%U
M:7-A($=O;V=L92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,C`*;7-G:60@(D=R87ES8V%L92(*;7-G<W1R(").[79E:7,@9&4@
M8VEN>F5N=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@(D=RZ6-I82(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")'<F5E:R`H25-/+3@X
M-3DM-RDB"FUS9W-T<B`B1W)E9V\@*$E33RTX.#4Y+3<I(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.CDU(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HY-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W)E
M96YL86YD(@IM<V=S='(@(D=R;VYE;.)N9&EA(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C@Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1W)E;F%D82(*
M;7-G<W1R(")'<F%N861A(@H*(PHC.B!A9&UI;B]G<F]U<',N<&AP.C$W,`IM
M<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R
M8>?C;R!D92!'<G5P;W,B"@HC.B!L:6(O2&]R9&4O1W)O=7`N<&AP.C4X"FUS
M9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R(").
M;VUE<R!D92!G<G5P;W,@;N-O('!O9&5M(&5S=&%R('9A>FEO<R(*"B,Z(&%D
M;6EN+W!E<FUS+V5D:70N<&AP.C(P,2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C(W-PIM<V=I9"`B1W)O=7`@<&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R;6ES
M<_5E<R!D92!G<G5P;R(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$W-B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(U,"!L:6(O0FQO8VLO9V]O9VQE+G!H
M<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B
M1W)O=7!S(@IM<V=S='(@(D=R=7!O<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HY."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS
M9W-T<B`B1W5A9&%L=7!E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B1W5A;2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.CDX"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W
M"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B4F5P^F)L:6-A(&1A($=U871E
M;6%L82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E
M<FYS97DB"FUS9W-T<B`B1W5E<FYS97DB"@HC.B!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HQ,C<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR,#4*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B4&5R;6ES<_5E<R!D87,@5FES:71A<R(*"B,Z(&%D;6EN
M+W!E<FUS+V5D:70N<&AP.C$R."!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(P
M-@IM<V=I9"`B1W5E<W0@<&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R;6ES<_5E
M<R!D87,@5FES:71A<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,3<*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R("),:79R;R!D92!6:7-I=&%S
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDW(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HY.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M-0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@(D=U:6[I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=6EN
M96$M0FES<V%U(@IM<V=S='(@(D=U:6[I+4)I<W-A=2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$P,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y
M86YA(@IM<V=S='(@(E)E</IB;&EC82!#;RUO<&5R871I=F$@9&$@1W5I86YA
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDV,`IM<V=I9"`B2%1-3"(*;7-G
M<W1R(")(5$U,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@
M(D\@2%1-3$%R96$@<F5C=7-A+7-E(&-O8F%R9&5M96YT92!A(')E;6]V97(@
M82#Z;'1I;6$@8^EL=6QA(&1A(&QI;FAA+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!
M<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M
M;B!I;B!T86)L92XB"FUS9W-T<B`B3R!(5$U,07)E82!R96-U<V$M<V4@8V]B
M87)D96UE;G1E(&$@<F5M;W9E<B!A(/IL=&EM82!C;VQU;F$@9&$@=&%B96QA
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B3R!(5$U,
M07)E82!R96-U<V$M<V4@8V]B87)D96UE;G1E(&$@<F5M;W9E<B!A(/IL=&EM
M82!L:6YH82!D82!T86)E;&$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:'1T<"YP
M:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B075T96YT:6-AY^-O($A44%`@;N-O(&9O:2!E;F-O;G1R861A
M+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$P,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B4F5P^F)L:6-A(&1O($AA:71I
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`R"FUS9VED(")(87-H
M+4%L9V]R:71H;2(*;7-G<W1R(")!;&=O<FET;6\@9&4@7")(87-H7"(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I
M9"`B2&%Z92(*;7-G<W1R(").96)L:6YA(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.CDQ.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDS,0IM<V=I9"`B2&5A9&5R
M(@IM<V=S='(@(D-A8F7G86QH;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N
M9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(DEL:&%S($AE87)D(&4@36-$
M;VYA;&0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R(")496UP;W)A;"U4
M($9O<G1E(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(DAE
M8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R(")(96)R974@*$E33RTX.#4Y
M+3@M22DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`B06QT=7)A(@H*
M(SH@;&EB+TAO<F1E+TAE;'`N<&AP.C$W.2!L:6(O2&]R9&4O2&5L<"YP:'`Z
M,3@V('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W"B,Z('1E;7!L871E<R]H
M96QP+VEN9&5X+FEN8SHS"FUS9VED(")(96QP(@IM<V=S='(@(D%J=61A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM
M<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B06IU9&$@<V]B<F4@
M;R!E9&ET;W(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W,PIM<V=I9"`B
M2&5L<&5R(@IM<V=S='(@(D%J=61A(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.CDU"FUS9VED("(B"B)(96QP97(@87!P;&EC871I;VX@=&\@8W)E871E(&%N
M9"!M86EN=&%I;B!T<F%N<VQA=&EO;G,@9F]R('1H92!(;W)D95QN(@HB9G)A
M;65W;W)K(&%N9"!I=',@87!P;&EC871I;VYS+EQN(@HB1F]R(&%N(&EN=')O
M9'5C=&EO;B!R96%D('1H92!F:6QE(%)%041-12!I;B!T:&ES(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B(@HB07!L:6-AY^-O(&%U>&EL:6%R('!A<F$@8W)I87(@
M92!M86YT97(@=')A9'7G]65S(&1A('!L871A9F]R;6%<;B(*(DAO<F1E(&4@
M9&%S('-U87,@87!L:6-AY_5E<R`H;?-D=6QO<RDN7&XB"B)087)A('5M82!I
M;G1R;V1UY^-O(&QE<B!O(&9I8VAE:7)O(%)%041-12!N97-T82!P87-T82XB
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B
M"FUS9W-T<B`B2&5M:7-FZ7)I;R(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN
M9F\N:6YC.C$W('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED
M(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@
M(D%Q=6D@97-TX2!O(&EN[6-I;R!D;R!A<G%U:79O.B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")(:6=H(@IM
M<V=S='(@(D%L=&$B"@HC.B!L:6(O2&]R9&4O2&ES=&]R>2YP:'`Z,S(Q"FUS
M9VED(")(:7-T;W)Y(&5N=')Y(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM
M<V=S='(@(DYO;65S(&1A<R!E;G1R861A<R!H:7-T\W)I87,@;N-O('!O9&5M
M(&5S=&%R('9A>FEO<R(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z
M-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-`IM<V=I9"`B
M2&]?;64B"FUS9W-T<B`B0V%?<V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C0S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H5F%T
M:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R(")%<W1A9&\@9&$@0VED861E(&1O
M(%9A=&EC86YO(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-#,U"FUS9VED(")(;VUE
M(@IM<V=S='(@(D-A<V$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$R,B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$U
M-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D5N9&5R9>=O(&1E($-A
M<V$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM
M<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R(")496QE9F]N92!D92!#87-A(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y
M"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R(")297#Z8FQI8V$@9&%S($AO;F1U
M<F%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B2&]N9W5E8V]N9W5E
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8U"FUS9VED(")(;W)D
M92(*;7-G<W1R(")(;W)D92(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S(Y
M"FUS9VED(")(;W)D92!T<F%N<VQA=&EO;B!G96YE<F%T;W(B"FUS9W-T<B`B
M1V5R861O<B!D92!T<F%D=>?U97,@2&]R9&4B"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.C0R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!$861O<R!834P@)7,@:6YVX6QI9&]S
M(&YA(&UE;G-A9V5M("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HR-S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@
M8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B
M.B!.96YH=6UA(&UE;G-A9V5M(&-O<G)E<W!O;F1E(&%O(&]B:F5C=&\@)7,B
M"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0Q,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@
M:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3F5N:'5M(&]B
M:F5C=&\@9&\@=&EP;R`E<R!E;F-O;G1R861O(&YA(&UE;G-A9V5M("5S(@H*
M(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C`X"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S
M7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(%)E;6_GXV\@9&4@)7,@7"(E<UPB
M('1E=F4@<W5C97-S;R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3$U-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY
M('-Y;F-H<F]N:7-E9"`E<R!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M(%-I;F-R;VYI>F'GXV\@9&4@)7,@7"(E<UPB('1E=F4@<W5C97-S;R(*"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@
M5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@
M4$A0(&5X=&5N<VEO;B(*;7-G<W1R(")(;W)D92]+;VQA8CH@3R!M;W1O<B!D
M92!I;G1E9W)AY^-O(')E<75E<B!A(&5X=&5N<^-O(%!(4"`G9&]M>&UL)R(*
M"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#@Q"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E
M92!F;W(@;V)J96-T("5S(@IM<V=S='(@(B(*(DAO<F1E+TMO;&%B.B!.XV\@
M9F]I('!O<W/M=F5L(&-R:6%R('5M82!N;W9A(.%R=F]R97,@6$U,('!A<F$@
M;R!O8FIE8W1O("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C`U"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M
M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($[C;R!F
M;VD@<&]S<^UV96P@<F5M;W9E<B`E<R!<(B5S7"(Z("5S(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HT-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R
M="!O9B!T>7!E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.XV\@9F]I('!O
M<W/M=F5L(&]B=&5R(&\@240@34E-12!P87)A(&$@<&%R=&4@9&4@=&EP;R`E
M<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3$U,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S
M(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($[C;R!F;VD@<&]S
M<^UV96P@<VEN8W)O;FEZ87(@)7,@7"(E<UPB.B`E<R(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z,3(X,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z($[C;R!F;VD@<&]S<^UV96P@<VEN8W)O;FEZ87(@
M<&%R=&EL:&%S.B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,S$X"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E
M(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@4&%R=&EL:&$@7"(E<UPB
M(&1E<V-O;FAE8VED82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R
M(")4<F'G;R!(;W)I>F]N=&%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG
M(@IM<V=S='(@(D5N8VAI;65N=&\@:&]R:7IO;G1A;"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ
M;VYT86PZ(@IM<V=S='(@(DAO<FEZ;VYT86PZ(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")(
M;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R
M(")#;VUO(&-H96=O=2!A<75I/R`H4&]R(&9A=F]R(')E<&]R=&4M;R$I(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T
M;R!M97)G93\B"FUS9W-T<B`B475A;G1A<R!C;VQU;F%S('!R971E;F1E(&IU
M;G1A<C\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR.`IM<V=I
M9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S
M='(@(E%U86YT;W,@8V%M<&]S("AC;VQU;F%S*2!E>&ES=&5M/R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*
M;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_
M(@IM<V=S='(@(E%U86YT87,@;&EN:&%S('!R971E;F1E(&IU;G1A<C\B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@X(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C,P"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R(")(=6UI9&%D
M92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#<*;7-G:60@
M(DAU;6ED:71Y.B`B"FUS9W-T<B`B2'5M:61A9&4Z("(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(DAU
M;6]R:7-T87,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$Q(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B4F5P^F)L:6-A
M(&1A($AU;F=R:6$B"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3<R
M(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,C,U"B,L('!H<"UF;W)M870*
M;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S
M='(@(D$@8W)I8>?C;R!D82!C86EX82!P;W-T86P@24U!4"!F86QH;W4Z("5S
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C(Q-"!L:6(O2&]R9&4O
M075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0
M(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")296UOY^-O
M(&1A(&-A:7AA('!O<W1A;"!)34%0(&9A;&AO=3H@)7,B"@HC.B!L:6(O2&]R
M9&4O075T:"]C>7)U<RYP:'`Z,3<Y(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP
M:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T
M82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(D-R:6'GXV\@9&4@<75O
M=&$@9&4@8V%I>&$@<&]S=&%L($E-05`@9F%L:&]U.B`E<R(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,S$W"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@
M(D5N9&5R9>=O($E0(@H*(SH@;&EB+TAO<F1E+T%U=&@O:7!B87-I8RYP:'`Z
M-S<*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M16YD97)EYV\@25`@:6YD:7-P;V[M=F5L+B(*"B,Z(&QI8B](;W)D92]!=71H
M+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@
M86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R(")%;F1E<F7G;R!)4"!F;W)A
M(&1O(&)L;V-O($-)1%(@<&5R;6ET:61O+B(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L
M871I;VXN(@IM<V=S='(@(E9I;VQAY^-O(&1E(&)L;W%U96EO(&1E($E0(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B25]N
M<V5R:7(@3&EN:&$@06YT97,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3(P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B
M4F5P^F)L:6-A(&1A($ES;.)N9&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S8X"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@(D%P96YA<R#-8V]N
M97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8Y"FUS9VED("))8V]N
M<R!W:71H('1E>'0B"FUS9W-T<B`BS6-O;F5S(&-O;2!497AT;R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.#(*;7-G:60@(DED96YT:71Y)W,@;F%M
M93HB"FUS9W-T<B`B3F]M92!D82!I9&5N=&ED861E.B(*"B,Z(&QI8B](;W)D
M92]-24U%+T-O;G1E;G1S+G!H<#HU.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@
M:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R(")392!NXV\@9F]R(&UO<W1R
M861O(&-O<G)E8W1A;65N=&4L("5S('!A<F$@;R!A8G)I<B!N=6UA(&YO=F$@
M:F%N96QA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#<*;7-G:60@
M(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T
M($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@
M=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@HB4V4@
M;N-O('9I<B!Q=6%L<75E<B#M8V]N92!A;R!U<V%R(&\@26YT97)N970@17AP
M;&]R97(L('!O9&4@<')E8VES87(@9&4@(@HB<V5L96-C:6]N87(@97-T82!C
M86EX82!P87)A(&1E<VQI9V%R(&$@=')A;G-P87+J;F-I82XB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,34X"FUS9VED("(B"B))
M9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G
M92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y
M('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@HB4V4@=FER(&5S=&$@;65N<V%G
M96T@;FUA<R!NXV\@82!I;6%G96T@<')O<')I86UE;G1E(&1I=&$L(&$@:6UA
M9V5M('%U92`B"B)P<F5T96YD92!C87)R96=A<B!NXV\@<&]D92!S97(@;6]S
M=')A9&$@<&5L;R!S974@;F%V96=A9&]R+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B
M26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B4')E=FESXV\@9&$@26UA9V5M.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R(")54DP@9&$@:6UA9V5M
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(E523"!D
M82!I;6%G96TZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE
M<GDB"FUS9W-T<B`B26UA9V5M(&1E(&=A;&5R:6$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G
M:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B26UA9V5M(&1E(&=A
M;&5R:6$Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C(*;7-G:60@(DEM
M86=E('5P;&]A9"(*;7-G<W1R(")#87)R96=A;65N=&\@9&$@:6UA9V5M(@H*
M(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G
M<W1R("));6%G96YS(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z
M,3`@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,3`*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHU-R!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS
M9W-T<B`B26UP;W)T87(L(%!A<W-O("5D(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@
M9FEE;&0Z("5S(@IM<V=S='(@(D-A;7!O(&EM<&]R=&%D;SH@)7,B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<S"FUS9VED("));7!O<G1E9"!F
M:65L9',Z(@IM<V=S='(@(D-A;7!O<R!I;7!O<G1A9&]S.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM
M<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B26Y?<V5R:7(@3&EN
M:&$@1&5P;VES(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,U
M"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@
M(D/S9&EG;R!D92!A8^?C;R!I;G1R;V1U>FED;R!E<W3A(&EN8V]R<F5C=&\N
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@IM<V=I
M9"`B26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T
M<B`B3F]M92!D92!U=&EL:7IA9&]R(&]U('!A;&%V<F$M<&%S<V4@97)R861O
M<RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B
M(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@
M>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B).;VUE(&1E('5T
M:6QI>F%D;W(@;W4@96YD97)EYV\@86QT97)N871I=F\@97)R861O<RX@0V]N
M=&%C=&4@;R!S974@(@HB861M:6YI<W1R861O<B!D92!S:7-T96UA('!A<F$@
M;V)T97(@86IU9&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@
M(D%U;65N=&%R(&$@26YD96YT8>?C;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T
M<B`B4F5P^F)L:6-A(&1A(,UN9&EA(@H*(SH@861M:6XO<&5R;7,O961I="YP
M:'`Z,30Q('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("))
M;F1I=FED=6%L(%5S97)S(@IM<V=S='(@(E5T:6QI>F%D;W)E<R!);F1I=FED
M=6%I<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(E)E</IB;&EC82!D
M82!);F1O;NES:6$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HV-PIM<V=I9"`B26YF;R(*;7-G<W1R("));F9O<FUAY^-O(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T-@IM<V=I9"`B26YF;W)M871I
M;VXB"FUS9W-T<B`B26YF;W)M8>?C;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,3@*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A
M=F%I;&%B;&4N(@IM<V=S='(@(DEN9F]R;6'GXV\@:N$@;N-O(&5S=.$@9&ES
M<&]N[79E;"(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU.#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26YI=&EA;&EZ:6YG(&UO9'5L92`E<RXN+B`B"FUS9W-T
M<B`B26YI8VEA;&EZ86YD;R!O(&WS9'5L;R`E<RXN+B`B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G
M:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(DEN<V5R:7(@0U]O
M;'5N82!$97!O:7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!);6%G92(*
M;7-G<W1R("));G-E<FER($EM86=E;2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*
M;7-G<W1R("));G-E<FER(%1A8F5L82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!796(@3&EN
M:R(*;7-G<W1R("));G-E<FER($QI9V'GXV\@X"!796(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G
M:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("));G-E<FER(%]#
M;VQU;F$@06YT97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU
M;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN<VER:7(@=6UA
M(&YO=F$@8V]L=6YA(&1E<&]I<R!D82!C;W)R96YT92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I
M9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE
M(@IM<V=S='(@(DEN<VER:7(@=6UA(&YO=F$@8V]L=6YA(&%N=&5S(&1A(&-O
M<G)E;G1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R
M('1H92!C=7)R96YT(&]N92(*;7-G<W1R("));G-I<FER('5M82!N;W9A(&QI
M;FAA(&1E<&]I<R!D82!C;W)R96YT92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B26YS97)T
M(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN
M<VER:7(@=6UA(&YO=F$@;&EN:&$@86YT97,@9&$@8V]R<F5N=&4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N
M="!N;V1E(@IM<V=S='(@(DEN<V5R:7(@=6T@<&%RX6=R869O(&%P\W,@;R!N
M\R!C;W)R96YT92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H
M(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(DEN<V5R:7(@=6T@
M<&%RX6=R869O(&%N=&5S(&1O(&[S(&-O<G)E;G1E(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA
M=&4B"FUS9W-T<B`B26YS:7)I<B!M;V1E;&\@86QT97)N871I=F\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,Q"FUS9VED("));G-E<G0@86X@96UA
M:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P
M87-S=V]R9#HB"FUS9W-T<B`B(@HB26YT<F]D=7IA('5M(&5N9&5R9>=O(&1E
M(&-O<G)E:6\@96QE8W1R\VYI8V\@;VYD92!P;W-S82!R96-E8F5R(&$@;F]V
M82`B"B)P86QA=G)A+7!A<W-E.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL
M(&%F=&5R(@IM<V=S='(@(DEN<VER:7(@8^EL=6QA(&%P\W,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y"FUS
M9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B26YS97)I<B!CZ6QU
M;&%S(&%N=&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*
M;7-G<W1R("));G-E<FER(&/I;'5L82!D97!O:7,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED("))
M;G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R("));G-E<FER(&-O;'5N82!A
M;G1E<R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM
M<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(DEN<V5R:7(@;65N<V%G
M96YS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM
M<V=S='(@(DEN<V5R:7(@<&%RX6=R869O(&%N=&5S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED
M("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R("));G-E<FER('!A
M<N%G<F%F;R!A;G1E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B
M"FUS9W-T<B`B26YS97)I<B!L:6YH82!D97!O:7,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("))
M;G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R("));G-E<FER(&QI;FAA(&%N=&5S
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,@IM<V=I9"`B26YS97)T
M('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N
M.B(*;7-G<W1R("));G1R;V1U>F$@82!R97-P;W-T82!E>&EG:61A('!A<F$@
M82!P97)G=6YT82!D92!S96=U<F%NYV$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS97)T+TUO9&EF
M>2!);6%G92(*;7-G<W1R("));G-E<FER+TUO9&EF:6-A<B!);6%G96TB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS
M9VED("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B26YS97)I<B]-;V1I
M9FEC87(@3&EG8>?C;R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T
M;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(D-RZ61I=&\@:6YS
M=69I8VEE;G1E('!A<F$@96YV:6%R('!A<F$@82!L:7-T82!D92!D:7-T<FEB
M=6GGXV\N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B0W+I9&ET
M;R!I;G-U9FEC:65N=&4N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-S4*
M;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B26YT96ER;R(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,3,S"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B
M3&ES=&$@9&4@:6YT96ER;W,B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@
M2&5A9&5R*2XB"FUS9W-T<B`B541(("A5<V5R($1A=&$@2&5A9&5R*2!I;G;A
M;&ED;RXB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ-S`@;&EB
M+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,C`Q"B,Z(&QI8B](;W)D92]#;VUP
M<F5S<R]Z:7`N<&AP.C(Q,`IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G
M<W1R(")$861O<R!:25`@:6YVX6QI9&]S(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T
M<B`B07!L:6-AY^-O(&EN=N%L:61A+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*
M;7-G<W1R("))1"!D92!L;W1E("A<(F)A=&-H7"(I(&EN=N%L:61O+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,#@X(&QI8B](;W)D92]&;W)M+G!H<#HR
M,34Y(&QI8B](;W)D92]&;W)M+G!H<#HR,C,S"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,CDX"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G
M<W1R(")/<R!D861O<R!S=6)M971I9&]S('/C;R!I;G;A;&ED;W,N(@H*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN
M=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`B16YD97)EYV\@
M9&4@9&5S=&EN;R!I;G;A;&ED;RXB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O
M9&)X+G!H<#HX,2!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HQ,#`*(SH@
M;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,C(P"FUS9VED("));G9A;&ED
M(&9I;&4@9F]R;6%T(@IM<V=S='(@(D9O<FUA=&\@9&\@87)Q=6EV;R!I;G;A
M;&ED;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C0*;7-G
M:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(D-H879E(&1A(&QI
M8V5NYV$@:6YVX6QI9&$N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$U.`IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS
M9W-T<B`B3&]C86QI>F'GXV\@:6YVX6QI9&$@97-P96-I9FEC861A+B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("))
M;G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R(")M<V=?='EP92!I;G;A;&ED;RXB
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I
M9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B87!I7VED
M(&EN=N%L:61O(&]U(&5M(&9A;'1A+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@
M<&%R86UE=&5R<RXB"FUS9W-T<B`B4&%RXFUE=')O<R!I;G;A;&ED;W,@;W4@
M96T@9F%L=&$N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C0S"FUS
M9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")097)M
M:7-SXV\@<&%R96YT86P@:6YVX6QI9&$N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$V,`IM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*
M;7-G<W1R("))1"!D92!P87)C96ER;R!I;G;A;&ED;RXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38R"FUS9VED("));G9A;&ED('!R;V1U
M8W0@8V]D92XB"FUS9W-T<B`B0_-D:6=O(&1E('!R;V1U=&\@:6YVX6QI9&\N
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G
M:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(E!R;W1O8V]L;R!I;G;A
M;&ED;RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<
M(B(*;7-G<W1R(")$97-T:6YA=.%R:6\@:6YVX6QI9&\Z(%PB)7-<(B(*"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z,3`T,R!L:6(O2&]R9&4O2V]L86(N<&AP
M.C$R,C`*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(D]B
M:F5C=&\@9&4@<&%R=&EL:&$@:6YVX6QI9&\B"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@
M861D<F5S<RXB"FUS9W-T<B`B16YD97)EYV\@9&$@;W)I9V5M(&EN=N%L:61O
M+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS
M9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B1&%D;W,@=6YI
M8V]D92!I;G;A;&ED;W,N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,R-0IM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(DEN=F5N=.%R:6\B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*
M;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B4F5P
M^F)L:6-A($ES;.)M:6-A(&1O($ERXV\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T
M<B`B4F5P^F)L:6-A(&1O($ER87%U92(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G
M<W1R(")297#Z8FQI8V$@9&$@27)L86YD82(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@(DEL:&$@
M9&4@36%N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(E1E;7!O
M<F%I<RU4($ES;VQA9&]S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T<B`B17-T
M861O(&1E($ES<F%E;"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-C(U"FUS9VED("))<W-U97(B"FUS9W-T<B`B16UI<W-O<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A
M;&EC(@IM<V=S='(@(DETX6QI8V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3(Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DET86QY(@IM<V=S='(@
M(E)E</IB;&EC82!)=&%L:6%N82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R
M(")*86UA:6-A(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,W-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*
M;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B2F%N96ER;R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Q-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P
M86XB"FUS9W-T<B`B2F%PXV\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M-PIM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R(")*87!O
M;NIS("A)4T\M,C`R,BU*4"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B2F5R<V5Y(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$R-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*
M;W)D86XB"FUS9W-T<B`B4F5I;F\@2&%S:&5M:71A(&1A($IO<F3B;FEA(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,"!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB
M"FUS9W-T<B`B2G5L:&\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S<Y(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,38*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R(")*=6YH;R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@
M(DIU<W1I9GDB"FUS9W-T<B`B2G5S=&EF:6-A<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED(")*
M=7-T:69Y($-E;G1E<B(*;7-G<W1R(")#96YT<F%R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@
M(DIU<W1I9GD@1G5L;"(*;7-G<W1R(")*=7-T:69I8V%R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G
M:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R(")*=7-T:69I8V%R(.`@17-Q=65R
M9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R(")*=7-T
M:69I8V%R(.`@1&ER96ET82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R
M(")297#Z8FQI8V$@9&\@0V%Z87%U:7-TXV\B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0V"FUS9VED(")+965P(&]R:6=I;F%L
M/R(*;7-G<W1R(")0<F5S97)V87(@;R!O<FEG:6YA;#\B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3(V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DME
M;GEA(@IM<V=S='(@(E)E</IB;&EC82!D;R!1=>EN:6$B"@HC.B!L:6(O2&]R
M9&4O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E
M:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")/('-E<G9I9&]R($ME
M<F)E<F]S(')E:F5I=&]U(&$@875T96YT:6-AY^-O+B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T
M<B`B3F]V871O<R!N;R!<(DME<FYE;%PB(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-#`P"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B0W)I
M8>?C;R!D82!#:&%V92(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0P
M,PIM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(DEM<')E<W/C;R!D
M:6=I=&%L(&1A(&-H879E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M-#`Q"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@(D-O;7!R:6UE;G1O(&1A
M(&-H879E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`P"FUS9VED
M(")+97D@5'EP92(*;7-G<W1R(")4:7!O(&1A($-H879E(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(DME>2!5<V%G92(*;7-G
M<W1R(")5=&EL:7IAY^-O(&1A($-H879E(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-S(Y"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE
M('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(D$@8VAA=F4@:N$@97AI<W1E
M(&YO('-E<G9I9&]R(&1E(&-H879E<R!P^F)L:6-A<RXB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B36GZ9&]S
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R(")1=6ER:6)A=&DB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,R(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#4*;7-G
M:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(E)E</IB;&EC82!0;W!U;&%R($1E;6]C<N%T:6-A(&1A($-O<F5I
M82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$R,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(E)E</IB
M;&EC82!D82!#;W)E:6$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM
M<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(D-O<F5A;F\@*$550RU+
M4BDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,T(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R(")+=7=A:70B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3(W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@
M(DMY<F=Y>G-T86XB"FUS9W-T<B`B4F5P^F)L:6-A(%%U:7)G=6EZ92(*"B,Z
M('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*
M;7-G<W1R(")?1&ES<&]S:>?C;R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z-SD@<&\O=')A;G-L871I;VXN<&AP.C8U-PIM<V=I9"`B3&%N9W5A
M9V4B"FUS9W-T<B`B261I;VUA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$S-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@1&5M
M;V-R871I8R!297!U8FQI8R(*;7-G<W1R(")297#Z8FQI8V$@4&]P=6QA<B!$
M96UO8W+A=&EC82!,86\B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS
M9VED("),87-T($AA;&8B"FUS9W-T<B`B475A<G1O($1E8W)E<V-E;G1E(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@X(&QI8B]";&]C:R]M;V]N+G!H<#HY
M,`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(E%U87)T;R!$96-R97-C
M96YT92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Q"FUS9VED("),87-T
M(%5P9&%T960Z(@IM<V=S='(@(MIL=&EM82!!8W1U86QI>F'GXV\Z(@H*(SH@
M;&EB+TAO<F1E+T%U=&@N<&AP.C8X-@HC+"!P:'`M9F]R;6%T"FUS9VED("),
M87-T(&QO9VEN.B`E<R(*;7-G<W1R("+:;'1I;6$@96YT<F%D83H@)7,B"@HC
M.B!L:6(O2&]R9&4O075T:"YP:'`Z-C@X"B,L('!H<"UF;W)M870*;7-G:60@
M(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`BVFQT:6UA(&5N=')A
M9&$Z("5S(&1E("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C8X,PIM<V=I
M9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`BVFQT:6UA(&5N=')A9&$Z
M($YU;F-A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B4F5P^F)L:6-A(&1A
M($QE=/-N:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@
M(DQA=R(*;7-G<W1R("),96DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*;7-G<W1R
M(")$:7-P;W-IY^-O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E
M<B(*;7-G<W1R(")$96EX87(@=F%Z:6\@<&%R82!F:6-A<B!S96T@8F]R9&$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B3.UB86YO(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"FUS9VED
M("),969T(@IM<V=S='(@(D5S<75E<F1A(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,Q,3@*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(D-A8F7G86QH
M;R!D82!E<W%U97)D82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3$T"FUS
M9VED("),969T('9A;'5E<R(*;7-G<W1R(")686QO<F5S(.`@97-Q=65R9&$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#@*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B3&5S;W1O(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$T,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED("),
M:6)E<FEA(@IM<V=S='(@(DQI8NER:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,30W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B
M($IA;6%H:7)I>6$B"FUS9W-T<B`B1W)A;F1E($IA;6%H:7)I>6$@4V]C:6%L
M:7-T82!0;W!U;&%R(,%R86)E(&1A($SM8FEA(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$T,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C:'1E
M;G-T96EN(@IM<V=S='(@(DQI<W1E;G-T86EN92(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ
M>FQE(@IM<V=S='(@(D-H=79A(%PB36]L:&$M5&]L;W-<(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"FUS9VED("),:6=H
M="!286EN(@IM<V=S='(@(D-H=79I<V-O<R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN($5A
M<FQY(@IM<V=S='(@(D-H=79I<V-O<R!-871I;F%I<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H="!2
M86EN($QA=&4B"FUS9W-T<B`B0VAU=FES8V]S(%9E<W!E<G1I;F]S(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@
M(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(E!E<75E;F\@06=U86-E:7)O
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*
M;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(D-H=79I
M<V-O(&-O;2!4<F]V;V%D82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(E%U
M961A(&1E($YE=F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B
M3F5V92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM
M97)I8VLB"FUS9W-T<B`B7"),:6UE<FEC:UPB(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$X,34*;7-G:60@(DQI;FLB"FUS9W-T<B`B3&EG8>?C;R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU-@IM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(DQI9V'GXV\@
M87!O;G1A('!A<F$Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S8*;7-G
M:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G
M92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B(@HB3&EG87(@;R!E;F1E<F7G
M;R!D92!C;W)R96EO(&5L96-T<O-N:6-O(.`@<.%G:6YA(&1E(&-O;7!O<VGG
MXV\@86\@;6]S=')A<B(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H=&UL
M,G1E>'0N<&AP.C$X,PIM<V=I9"`B3&EN:W,B"FUS9W-T<B`B3&EG8>?U97,B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O
M;VMI92(*;7-G<W1R(")";VQI;FAO(&QI;G5XZG,B"@HC.B!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A
M;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("),:7-T82`M(&\@=71I;&EZ861O
M<B!P;V1E('9E<B!A('!A<W1A(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S
M,`IM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B3&ES=&%R($)A<V5S
M(&1E($1A9&]S(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3`*;7-G
M:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B36]S=')A<B!4\W!I8V]S
M(&1E($%J=61A(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.0IM<V=I9"`B
M3&ES="!486)L97,B"FUS9W-T<B`B3&ES=&%R(%1A8F5L87,B"@HC.B!L:6(O
M2&]R9&4O34E-12](96%D97)S+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV
M92(*;7-G<W1R("),:7-T86=E;2U!<G%U:79O(@H*(SH@;&EB+TAO<F1E+TU)
M344O2&5A9&5R<RYP:'`Z-3@Y"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`B
M3&ES=&%G96TM06IU9&$B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H
M<#HU.38*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B240@9&$@3&ES=&$B"@HC
M.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3(*;7-G:60@(DQI<W0M
M3W=N97(B"FUS9W-T<B`B3&ES=&%G96TM1&]N;R(*"B,Z(&QI8B](;W)D92]-
M24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@
M(DQI<W1A9V5M+5-U8FUI<W/U97,B"@HC.B!L:6(O2&]R9&4O34E-12](96%D
M97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(DQI
M<W1A9V5M+5-U8G-C<FET87,B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S
M+G!H<#HU.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B3&ES
M=&%G96TM3N-O('-U8G-C<FET87,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]N;VQI<W0N:6YC.C0*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L
M960N(@IM<V=S='(@(D$@;&ES=&%G96T@9&4@=71I;&EZ861O<F5S(&5S=.$@
M9&5S86-T:79A9&$N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS
M9VED("),:71E<F%T=7)E(@IM<V=S='(@(DQI=&5R871U<F$Z(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$T-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED
M("),:71H=6%N:6$B"FUS9W-T<B`B4F5P^F)L:6-A(&1A($QI='7B;FEA(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C$S,S@*;7-G:60@(DQO861I;F<@;&EB
M<F%R:65S+BXN(@IM<V=S='(@(D-A<G)E9V%N9&\@8FEB;&EO=&5C87,N+BXB
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6UA9V5S+G!H<#HY,@IM<V=I
M9"`B3&]A9&EN9RXN+B(*;7-G<W1R(")#87)R96=A;F1O+BXN(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Y.0IM<V=I9"`B3&]C86P@=&EM
M93H@(@IM<V=S='(@(E1E;7!O(&QO8V%L.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX,PIM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(DQO
M8V%L:7IAY^-O(&4@1G5S;R!(;W+A<FEO(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU-S$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4V
M"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N
M<&AP.C8U"FUS9VED("),;V-A=&EO;B(*;7-G<W1R("),;V-A;&EZ8>?C;R(*
M"B,Z(&QO9VEN+G!H<#HQ-C(@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M.C$V-"!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z.#8*;7-G:60@(DQO9R!I;B(*;7-G<W1R(")%;G1R87(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34X"FUS9VED("),;V<@;W5T(@IM
M<V=S='(@(E-A:7(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"FUS
M9VED("),;V=I;B!487-K<R(*;7-G<W1R(")487)E9F%S(&1E($5N=')A9&$B
M"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3,Q"FUS9VED("),;V=I;B!F86EL
M960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E
M<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)!(&%U=&5N=&EC8>?C;R!F
M86QH;W4@<&]R(&\@3F]M92!D92!5=&EL:7IA9&]R(&]U(&$@4&%L879R82U0
M87-S92!E<W1A<F5M("(*(FEN8V]R<F5C=&]S+B(*"B,Z(&QI8B](;W)D92]!
M=71H+G!H<#HY,C<*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B02!A
M=71E;G1I8V'GXV\@9F%L:&]U+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,S8W"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B5&5X=&\@;&]N9V\B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS9W-T
M<B`B06UO<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8W"FUS9VED("),;W<B"FUS9W-T<B`B0F%I>&\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS
M9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(DQE=')A<R!G<F5G
M87,@;6EN^G-C=6QA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE
M='1E<G,B"FUS9W-T<B`B3&5T<F%S(&QA=&EN87,@;6EN^G-C=6QA<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B3OIM
M97)O<R!R;VUA;F]S(&UI;OIS8W5L;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,30U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B
M"FUS9W-T<B`B3'5X96UB=7)G;R(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HS-S,@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q,`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB
M"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4S
M"FUS9VED(")-3U1$(@IM<V=S='(@(DU/5$0B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T86-H;65N
M="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B3R!A;F5X;R!-4RU43D5&
M(&[C;R!C;VYT:6YH82!D861O<RXB"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R
M(")-4T<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@(DUA8V%U(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$U,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDQ"FUS9VED
M(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B36%C963S;FEA+"!!;G1I9V$@4F5P^F)L:6-A($IU9V]S;&%V
M82!D82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R(")-861A9^%S8V%R
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"FUS9VED(")-86=I8R(*
M;7-G<W1R(")-86=I82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX
M,0IM<V=I9"`B36%I;"(*;7-G<W1R(")#;W)R96EO(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0W-PIM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R
M(")!9&UI;FES=')AY^-O(&1E($-O<G)E:6\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*;7-G:60@(DUA
M:V4@;&EN7VLN+BXB"FUS9W-T<B`B1F%Z97(@;&E?9V'GXV\N+BXB"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,3,U-PIM<V=I9"`B36%K92!S=7)E('1H870@
M>6]U(&AA=F4@4$5!4B!I;G-T86QL960@86YD(&EN('EO=7(@:6YC;'5D92!P
M871H+B(*;7-G<W1R("(B"B)!<W-E9W5R92US92!D92!Q=64@=&5M(&\@4$5!
M4B!I;G-T86QA9&\@92!N;R!C86UI;FAO(&1E(&EN8VQU<_5E<R`H:6YC;'5D
M92`B"B)P871H*2XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C<X('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,#<T"B,L('!H<"UF;W)M870*;7-G:60@(DUA:VEN
M9R!D:7)E8W1O<GD@)7,B"FUS9W-T<B`B0W)I86YD;R!A('!A<W1A("5S(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT
M"FUS9VED(")-86QA=VDB"FUS9W-T<B`B36%L875I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$V-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-86QA
M>7-I82(*;7-G<W1R(")-86SA<VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$V-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*;7-G
M<W1R(")-86QD:79A<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-30@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%L:2(*;7-G<W1R(")-86QI(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT
M"FUS9VED(")-86QT82(*;7-G<W1R(")-86QT82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A
M=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O
M;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS
M9W-T<B`B(@HB1VER82!A(&QI<W1A(&1E(&-A=&5G;W)I87,@<75E('!O9&4@
M871R:6)U:7(@86]S(&ET96YS+"!B96T@8V]M;R!A<R!C;W)E<R`B"B)Q=64@
M;&AE<R!E<W3C;R!A<W-O8VEA9&%S+B(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,#,Y"FUS9VED(")-87`R-"!M87`B"FUS9W-T
M<B`B36%P82!-87`R-"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HY-S<*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P-30*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R(")-87!A($UA
M<%%U97-T(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,W-B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G
M:60@(DUA<F-H(@IM<V=S='(@(DUA<N=O(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN
M(@IM<V=S='(@(DUA<F=E;2(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S
M(@IM<V=S='(@(DUA<F-A<B!C;VUO($QI9&$O3N-O(&QI9&$B"@HC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET
M:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S
M='(@(DUA<F-A<B!D92!O=71R87,@9F]R;6%S("AE+F<N+"!);7!O<G1A;G1E
M+U!O<B!R97-P;VYD97(I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM
M<V=S='(@(DEL:&%S($UA<G-H86QL(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$U.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E(@IM
M<V=S='(@(DUA<G1I;FEC82(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z,3$Q"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B0V%M<&]S
M('%U92!C;W)R97-P;VYD96TB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,38P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T
M<B`B36%U<FETXFYI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C,@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(DUA
M=7+M8VEO(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B3>%X:6UO
M(&-RZ61I=&\@<&5R;6ET:61O+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E
M961E9"XB"FUS9W-T<B`B3>%X:6UO(&[Z;65R;R!D92!P87)T97,@;G5M82!M
M96YS86=E;2!E>&-E9&ED;RXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P
M-@IM<V=I9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(E1E
M;7!E<F%T=7)A(&WA>&EM82!N87,@^FQT:6UA<R`R-"!H;W)A<SH@(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3@*;7-G:60@(DUA>"!T96UP(&QA<W0@
M-B!H;W5R<SH@(@IM<V=S='(@(E1E;7!E<F%T=7)A(&WA>&EM82!N87,@^FQT
M:6UA<R`V(&AO<F%S.B`B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DX(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,C$W(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,Y
M"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R(")#;VUP<FEM96YT;R!M
MX7AI;6\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,S<X(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,34*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I
M9"`B36%Y(@IM<V=S='(@(DUA:6\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C4S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S
M='(@(DUA>6]T=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G
M:60@(DUE9&EC:6YE(@IM<V=S='(@(DUE9&EC:6YA(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ.0IM<V=I9"`B365M8F5R<R(*;7-G
M<W1R(")-96UB<F]S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W,`IM
M<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R(")-;V1O(&1O(&UE;G4Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B56YI<B!CZ6QU;&%S(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C4R-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")-97)G:6YG(&%L;"`E<RYP;R!F:6QE<R!T;R!T:&4@8V]M<&5N9&EU;2XN
M+B`B"FUS9W-T<B`B26YT96=R86YD;R!T;V1O<R!O<R!F:6-H96ER;W,@)7,N
M<&\@8V]M(&\@8V]M<.IN9&EO+BXN(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C0S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")-97)G:6YG(&QO8V%L92`E<RXN
M+B`B"FUS9W-T<B`B26YT96=R86YD;R!A(&QO8V%L:7IAY^-O("5S+BXN("(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW.#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B365R9VEN9R!T:&4@4$\@9FEL92!F;W(@)7,@=&\@=&AE(&-O;7!E;F1I
M=6TN+BX@(@IM<V=S='(@(DEN=&5G<F%N9&\@;R!A<G%U:79O(%!/(&1E("5S
M(&-O;2!O(&-O;7#J;F1I;RXN+B`B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-#(U"B,L('!H<"UF;W)M870*;7-G:60@(DUE<F=I;F<@=')A;G-L871I;VX@
M9F]R(&UO9'5L92`E<RXN+B(*;7-G<W1R("));G1E9W)A;F1O(&$@=')A9'7G
MXV\@9&\@;?-D=6QO("5S+BXN(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"FUS9VED(")-97-S86=E(@IM<V=S
M='(@(DUE;G-A9V5M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR
M,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U
M="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E
M<FEF:65D+B(*;7-G<W1R("(B"B)-96YS86=E;B!697)I9FEC861A(&-O;2!3
M=6-E<W-O+"!M87,@;R!C97)T:69I8V%D;R!D;R!S=6)S8W)I=&]R(&[C;R!P
M]&1E("(*(G-E<B!V97)I9FEC861O+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM
M<V=S='(@(DUE;G-A9V5M(&5X<&ER;W4N(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V.2!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C`R"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"FUS9VED
M(")-97-S86=E('1Y<&4B"FUS9W-T<B`B5&EP;R!D92!M96YS86=E;2(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE<B(*
M;7-G<W1R(")-971E;W)O;&]G:6$@345405(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R(")";&]C;R!-151!4B!I;F1I<W!O;NUV96PN(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ,3(*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(D)L;V-O($U%5$%2(&EN9&ES<&]N
M[79E;"X@3W,@<&]R;65N;W)E<R!F;W)A;2!R96=I<W1A9&]S('!A<F$@;R`B
M"B)A9&UI;FES=')A9&]R+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-3(*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS
M9W-T<B`B02!-971A<D1"(&[C;R!E<W3A(&-O;F5C=&%D82XB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV-R!L:6(O2&]R9&4O34E-12]6
M:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@(DWI=&]D
M;R(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HX,2!L:6(O2&]R9&4O
M4E!#+W-O87`N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@
M7"(E<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(D\@;>ET;V1O(%PB)7-<
M(B!NXV\@97-TX2!D969I;FED;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HV-B!L:6(O0FQO8VLO;65T87(N<&AP.C<U"FUS9VED(")-971R
M:6,B"FUS9W-T<B`B3>ET<FEC;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S='(@
M(DWI>&EC;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S
M(&]F(@IM<V=S='(@(DUI8W)O;NES:6$L($5S=&%D;W,@1F5D97)A9&]S(&1A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<V"FUS9VED(")-:61D;&4B"FUS9W-T<B`B0V5N=')O(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y
M<&4B"FUS9W-T<B`B5&EP;R!-24U%(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS,3`*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R
M(")496UP97)A='5R82!M[6YI;6$@;F%S(/IL=&EM87,@,C0@:&]R87,B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B36EN('1E;7`@;&%S
M="`V(&AO=7)S.B`B"FUS9W-T<B`B5&5M<&5R871U<F$@;>UN:6UA(&YA<R#Z
M;'1I;6%S(#8@:&]R87,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C$W"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B17-P96QH;R(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N
M96]U<R(*;7-G<W1R(")-:7-C96SB;F5A(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8W,B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,T,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]2
M97%U97-T+B(*;7-G<W1R(")086-O=&4@2%144%]297%U97-T(&1O(%!%05(@
M96T@9F%L=&$N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-`IM<V=I
M9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE
M<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC
M871I;VXN(@IM<V=S='(@(B(*(D-O;F9I9W5R8>?C;R!E;2!F86QT82X@5&5R
MX2!D92!A(&=E<F%R(&%G;W)A('-E('%U:7-E<B!U<V%R(&5S=&$@87!L:6-A
MY^-O+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T
M"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(DE$(&1A(&UE
M;G-A9V5M(&5M(&9A;'1A+B(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P
M86-K86=E($UA:6PN(@IM<V=S='(@(E!A8V]T92!-86EL(&1O(%!%05(@96T@
M9F%L=&$N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B240@9&$@
M<V5S<^-O(&5M(&9A;'1A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(C*J(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<T"FUS9VED(")-;V)I;&4@36%I
M;"(*;7-G<W1R(")#;W)R96EO($WS=F5L(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DUO9&5R871E(@IM<V=S
M='(@(DUO9&5R861O(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C8@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*;7-G:60@(DUO9&EF:65D
M($1A=&4B"FUS9W-T<B`B1&%T82!D92!-;V1I9FEC8>?C;R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM
M<V=I9"`B36]D:69Y(%523"(*;7-G<W1R(")-;V1I9FEC87(@55),(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C8U-PIM<V=I9"`B36]D=6QE(@IM<V=S='(@
M(DWS9'5L;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C<S"FUS
M9VED(")-;V1U;'5S(@IM<V=S='(@(DWS9'5L;R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V
M82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B4F5P^F)L:6-A(&1A($UO;&1O=F$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30Y(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R(")0<FEN8VEP861O(&1O($WS;F%C
M;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-38@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$U,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B36]N9_-L:6$B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y,PIM<V=I9"`B36]N=&@@86YD('EE87(B
M"FUS9W-T<B`B3>IS(&4@86YO(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E
M+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R(")-96YS86QM96YT92(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$U,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R(")-;VYT<V5R<F%T(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS
M9VED(")-;V]N(%!H87-E<R(*;7-G<W1R(")&87-E(&1A($QU82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$U-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I
M9"`B36]R;V-C;R(*;7-G<W1R(")296EN;R!D92!-87)R;V-O<R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-
M;W-T;'D@0VQE87(B"FUS9W-T<B`B4V]B<F5T=61O($QI;7!O(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G:60@(DUO
M<W1L>2!#;&]U9'DB"FUS9W-T<B`B4V]B<F5T=61O($5N979O861O(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@
M(DUO<W1L>2!3=6YN>2(*;7-G<W1R(")3;V)R971U9&\@4V]L87)E;F=O(@H*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-#(X"FUS9VED(")-;W9E
M($1O=VXB"FUS9W-T<B`B1&5S8V5R(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="YP:'`Z-#,R"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B36]V97(@
M<&%R82!A($5S<75E<F1A(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP
M:'`Z-#,V"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(DUO=F5R('!A<F$@
M82!$:7)E:71A(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-#(T
M"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(E-U8FER(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Y-@IM<V=I9"`B36]V92!D;W=N
M(@IM<V=S='(@(D1E<V-E<B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT.34@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Y-@IM<V=I9"`B36]V92!U<"(*;7-G<W1R(")3=6)I<B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$U-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I
M9"`B36]Z86UB:7%U92(*;7-G<W1R(")297#Z8FQI8V$@9&4@36_G86UB:7%U
M92(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3@U"FUS9VED(")-=6QT:2UL
M979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B3&ES=&%S(&1E(&1E<V5N
M<F]L87(@;75L=&DM;NUV96PB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T
M,PIM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(E-E;&5CY^-O
M(&WZ;'1I<&QA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S,2!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,X"FUS9VED(")->2!!8V-O=6YT
M(@IM<V=S='(@(D$@36EN:&$@0V]N=&$B"@HC.B!S97)V:6-E<R]P;W)T86PO
M:6YD97@N<&AP.C4Q"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B3R!-974@
M4&]R=&%L(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C$R-`IM<V=I
M9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R(")$:7-P;W-IY^-O(&1O(%!O
M<G1A;"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-34@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R(")5;FGC;R!D92!->6%N
M;6%R(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E;65N=%]B;W1T
M;VTN:6YC.C<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R(").
MXV\L(&[C;R!C;VYC;W)D;R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C0P,"!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B
M"FUS9W-T<B`B3F]M92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-CD@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R(")297#Z
M8FQI8V$@9&$@3F%M[6)I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B3F%U
M<G4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(DYE<&%L(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$W-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").
M971H97)L86YD<R(*;7-G<W1R(")296EN;R!D;W,@4&'M<V5S($)A:7AO<R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W
M"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R(")!;G1I;&AA
M<R!(;VQA;F1E<V%S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M.#$*;7-G:60@(DYE='-C87!E($)A<V4@55),(@IM<V=S='(@(E523"!D92!"
M87-E($YE='-C87!E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M.#,*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@
M(E523"!D92!2979O9V'GXV\@0T$@3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y
M(%523"(*;7-G<W1R(")54DP@8V]M(&$@<&]L[71I8V$@9&4@0T$@3F5T<V-A
M<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I9"`B
M3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B55),(&1E(%)E;F]V8>?C
M;R!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@R
M"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R(")54DP@
M9&4@4F5V;V=AY^-O($YE='-C87!E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*
M;7-G<W1R(").;VUE(&1O('-E<G9I9&]R(%-33"!.971S8V%P92(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P92!C
M97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@(D-O;65N=.%R:6\@9&4@8V5R
M=&EF:6-A9&\@3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4X,`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G
M<W1R(")4:7!O(&1E(&-E<G1I9FEC861O($YE='-C87!E(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(S.0IM<V=I9"`B3F5T=V]R:R(*;7-G<W1R
M(")2961E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$T(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,C<*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,W.`IM<V=I9"`B3F5V97(B"FUS9W-T<B`B3G5N8V$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3<P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYE
M=R!#86QE9&]N:6$B"FUS9W-T<B`B3F]V82!#86QE9/-N:6$B"@HC.B!L:6(O
M2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-PIM<V=I9"`B3F5W
M($-A=&5G;W)Y(@IM<V=S='(@(DYO=F$@0V%T96=O<FEA(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,3<Y"FUS9VED(").97<@36]O;B(*;7-G<W1R("),=6$@
M3F]V82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*
M;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(DYO=F\@
M3F]M92!D92!5=&EL:7IA9&]R("AO<&-I;VYA;"DB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-C,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:
M96%L86YD(@IM<V=S='(@(DYO=F$@6F5LXFYD:6$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN
M9&]W("A?8FQA;FLI(@IM<V=S='(@(DYO=F$@:F%N96QA("A?8FQA;FLI(@H*
M(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C$*;7-G:60@
M(DYE=W,B"FUS9W-T<B`B3F]T[6-I87,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,CDU"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(D=R=7!O
M<R!D92!.;W3M8VEA<R(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C(Q('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0V"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z,3,W('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C,R"FUS9VED(").97AT(@IM<V=S='(@(E!R\WAI;6$B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T
M<B`B4'+S>&EM87,@-"!&87-E<R(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP
M:'`Z,S<P(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S<T"FUS9VED(").97AT
M(&]P=&EO;G,B"FUS9W-T<B`B4'+S>&EM87,@;W#G]65S(@H*(SH@;&EB+TAO
M<F1E+U5)+U!A9V5R+G!H<#HQ,#,*;7-G:60@(DYE>'0^(@IM<V=S='(@(E!R
M\WAI;6$^(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B4F5P^F)L:6-A
M(&1A($YI8V%RX6=U82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B4F5P^F)L
M:6-A(&1O($[M9V5R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM<V=S='(@(E)E</IB
M;&EC82!&961E<F%L(&1A($YI9V5R:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S8X"FUS9VED(").:6=H="(*;7-G<W1R(").;VET92(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-SD@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$V-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-PIM<V=I9"`B3FEU92(*;7-G<W1R(").:75E(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@X-0IM<V=I9"`B3F\B"FUS9W-T<B`B
M3N-O(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HQ-@IM
M<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W
M(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B(@HB3N-O(&CA(&1A9&]S(&1E
M(&-O;F9I9W5R8>?C;R!D:7-P;V[M=F5I<R!E;2!R96QAY^-O(&%O<R!Q=6%I
M<R!M;W-T<F%R("(*(F1I9F5R96[G87,N(@H*(SH@;&EB+U9&4R])4T]7<FET
M97(N<&AP.C$P-0IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M
M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B3N-O(&CA(&YE;FAU;6$@97-T
M<F%TZ6=I82!D:7-P;V[M=F5L('!A<F$@<F5A;&EZ87(@:6UA9V5N<R!)4T\N
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G
M:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R(").XV\@:.$@;6]D96QO
M(&1E(&QO=&4@7")B871C:%PB+B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70N<&AP.C<Y(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C(S,`HC.B!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HR-3(*;7-G:60@(DYO(&)L;V-K
M(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(D[C
M;R!E>&ES=&4@8FQO8V\@;F$@<&]S:>?C;R!I;F1I8V%D82(*"B,Z(&QI8B](
M;W)D92]!=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A<B!N86UE
M('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").
MXV\@9F]I(&9O<FYE8VED;R!U;2!N;VUE(&1E(&-A;&5N9.%R:6\@<&%R82!A
M(&%U=&5N=&EC8>?C;R!-0T%,+B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP
M.C4T"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@(E-E;2!M;V1I9FEC8>?U
M97,N(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-#`*;7-G:60@(DYO
M(&-H:6QD('!E<FUI<W-I;VYS(&%R92!T;R!B92!A9&1E9"!B96QO=R!T:&ES
M(&QE=F5L+B(*;7-G<W1R(").XV\@<V4@<&]D92!A9&EC:6]N87(@<&5R;6ES
M<_5E<R!D92!F:6QH;W,@86)A:7AO(&1E<W1E(&[M=F5L+B(*"B,Z(&%D;6EN
M+W!E<FUS+V%D9&-H:6QD+G!H<#HV,0IM<V=I9"`B3F\@8VAI;&1R96X@8V%N
M(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B3N-O('-E
M('!O9&4@861I8VEO;F%R(&9I;&AO<R!A(&5S=&$@<&5R;6ES<^-O+B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HQ,S<W"FUS9VED(").;R!C;VUM86YD('-P
M96-I9FEE9"XB"FUS9W-T<B`B3F5N:'5M(&-O;6%N9&\@97-P96-I9FEC861O
M+B(*"B,Z(&QI8B](;W)D92YP:'`Z,38W(&QI8B](;W)D92YP:'`Z-#<W(&QI
M8B](;W)D92]5=&EL+G!H<#HW-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*
M;7-G<W1R(").XV\@9F]I(&5S<&5C:69I8V%D82!A(&EN9F]R;6'GXV\@9&4@
M8V]N9FEG=7)AY^-O('!A<F$@)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<T
M,0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R($944"!61E,N(@IM<V=S='(@(B(*(D[C;R!F;VD@97-P96-I9FEC
M861A(&$@:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@<&%R82!61E,@8F%S
M96%D;R!E;2!&5%`N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C4Y,0IM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-1
M3"!61E,N(@IM<V=S='(@(B(*(D[C;R!F;VD@97-P96-I9FEC861A(&$@:6YF
M;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@;F5C97-SX7)I82!P87)A(&\@5D93
M("(*(F)A<V5A9&\@96T@4U%,+B(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C<P-`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B(@HB3N-O(&9O:2!E
M<W!E8VEF:6-A9&$@82!I;F9O<FUAY^-O(&1E(&-O;F9I9W5R8>?C;R!N96-E
M<W/A<FEA('!A<F$@;R!61E,@(@HB8F%S96%D;R!E;2!344PM1FEL92XB"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B
M3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(D-RZ61I=&\@97-G;W1O=2XB"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").
M;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B3F5N:'5M(&1E<W1I
M;F%TX7)I;R!F;VD@9F]R;F5C:61O+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HQ,C<Q"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&5N=')Y('=I=&@@=&AE
M(&ED(%PB)7-<(B!E>&ES=',@:6X@=&AE(&]R:6=I;F%L(&AE;'`@9FEL92XB
M"FUS9W-T<B`B(@HB3N-O(&5X:7-T92!Q=6%L<75E<B!E;G1R861A(&-O;2!O
M(&ED(%PB)7-<(B!N;R!A<G%U:79O(&1E(&%J=61A(&]R:6=I;F%L+B(*"B,Z
M(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX.#$*;7-G:60@(DYO(&9I;&4@=7!L
M;V%D960B"FUS9W-T<B`B3N-O('-E(&-A<G)E9V]U(&YA9&$N(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C0Q,R!P;R]T<F%N<VQA=&EO;BYP:'`Z-3(R"FUS
M9VED(").;R!L;V-A;&4@<W!E8VEF:65D+B(*;7-G<W1R(").96YH=6UA(&QO
M8V%L:7IAY^-O(&5S<&5C:69I8V%D82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,3$U(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$R,PIM<V=I9"`B3F\@;&]C871I;VX@:7,@
M<V5T+B(*;7-G<W1R(")&86QT82!I;F1I8V%R('5M82!L;V-A;&EZ8>?C;RXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34V"FUS9VED(").
M;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B02!L;V-A;&EZ8>?C;R!N
MXV\@9F]I(&5S<&5C:69I8V%D82XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L:65D+B(*
M;7-G<W1R(").96YH=6UA(&UE;G-A9V5M(&9O:2!F;W)N96-I9&$N(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@
M;F%M92!S<&5C:69I960N(@IM<V=S='(@(DYE;FAU;2!N;VUE(&5S<&5C:69I
M8V%D;RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W
M"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R(").96YH=6T@
M;OIM97)O(&5S<&5C:69I8V%D;RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(")3
M96T@9&ET;W,@;V9E;G-I=F]S(@H*(SH@;&EB+TAO<F1E+T%U=&@O:'1T<"YP
M:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").XV\@9F]I(&9O<FYE8VED82!P86QA
M=G)A+7!A<W-E('!A<F$@82!A=71E;G1I8V'GXV\@2%144"XB"@HC.B!L:6(O
M2&]R9&4O075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").XV\@
M9F]I(&9O<FYE8VED82!P86QA=G)A+7!A<W-E('!A<F$@82!A=71E;G1I8V'G
MXV\@24U!4"XB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HW,@IM<V=I
M9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R(").XV\@9F]I(&9O<FYE8VED82!P86QA=G)A+7!A
M<W-E('!A<F$@82!A=71E;G1I8V'GXV\@2V5R8F5R;W,N(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O;&1A<"YP:'`Z.30*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!,1$%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").XV\@9F]I
M(&9O<FYE8VED82!P86QA=G)A+7!A<W-E('!A<F$@82!A=71E;G1I8V'GXV\@
M3$1!4"XB"@HC.B!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HW-R!L:6(O2&]R
M9&4O075T:"]L;V=I;BYP:'`Z.#0*(SH@;&EB+TAO<F1E+T%U=&@O<&%M+G!H
M<#HW-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").XV\@9F]I(&9O<FYE8VED82!P86QA
M=G)A+7!A<W-E('!A<F$@82!A=71E;G1I8V'GXV\@3&]G:6XN(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(D[C;R!F;VD@9F]R;F5C:61A('!A;&%V<F$M<&%S<V4@<&%R82!A(&%U=&5N
M=&EC8>?C;R!005-35T0N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HX
M-`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B3N-O(&9O:2!F;W)N96-I9&$@<&%L879R82UP
M87-S92!P87)A(&$@875T96YT:6-AY^-O(%--0BXB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C$R.#8*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE
M($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@
M:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM
M<V=S='(@(B(*(D[C;R!F;VD@:6YD:6-A9&\@8V%M:6YH;R!P87)A(&\@8FEN
MX7)I;R!/<&5N4U-,+B!/(&)I;N%R:6\@3W!E;E-33"#I("(*(FYE8V5S<^%R
M:6\@<&%R82!T<F%B86QH87(@8V]M(&1A9&]S(%!+0U,@,3(N(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N
M9&EN9R!S:6=N=7!S+B(*;7-G<W1R(").XV\@:.$@<W5B<V-R:>?U97,@<&5N
M9&5N=&5S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(E-E;2!T
M<F'G;W,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0T"FUS9VED(").;R!S:61E<R(*;7-G<W1R(")396T@;&%D
M;W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(U"FUS9VED
M(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N
M(@IM<V=S='(@(D[C;R!HX2!P87-T82!T96UP;W+A<FEA(&1I<W!O;NUV96P@
M<&%R82!<(F-A8VAE7"(N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S,0IM<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D
M('-E;G0N(@IM<V=S='(@(D[C;R!F;W)A;2!E;G9I861O<R!O(&YO;64@9&\@
M=71I;&EZ861O<B!O=2!A('!A;&%V<F$M<&%S<V4N(@H*(SH@;&EB+TAO<F1E
M+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@
M<F5T=7)N960B"FUS9W-T<B`B3N-O(&9O<F%M(')E=&]R;F%D;W,@9&%D;W,@
M96T@6$U,(';A;&ED;W,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.#DS(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HY,#,*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDQ
M-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3,Q"FUS9VED
M(").;R!V86QU97,B"FUS9W-T<B`B4V5M('9A;&]R97,B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3$Y"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN
M(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B(@HB3N-O(&9O:2!E;F-O;G1R861A('9E<G/C;R!N
M82!C;VYF:6=U<F'GXV\@;W)I9VEN86PN(%)E9V5N97)A<B!C;VYF:6=U<F'G
MXV\N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R-PIM<V=I9"`B3F\@
M=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A
M=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3N-O(&9O:2!E;F-O;G1R861A
M('9E<G/C;R!N82!S=6$@8V]N9FEG=7)AY^-O+B!296=E;F5R87(@8V]N9FEG
M=7)AY^-O+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q-B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z
M('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3(*;7-G:60@
M(DYO;F4B"FUS9W-T<B`B3F5N:'5M82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L
M:6-I="DB"FUS9W-T<B`B3F5N:'5M("AU<V%R(&EM<&SM8VET;RDB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U
M.2TQ,"DB"FUS9W-T<B`B3O-R9&EC;R`H25-/+3@X-3DM,3`I(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$W,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED
M(").;W)F;VQK($ES;&%N9"(*;7-G<W1R("));&AA(&1E($YO<F9O;&LB"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P
M"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(DAE;6ES9NER
M:6\@3F]R=&4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*
M;7-G<W1R("));&AA<R!-87)I86YA<R!D;R!.;W)T92(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$W,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R
M=V%Y(@IM<V=S='(@(E)E:6YO(&1A($YO<G5E9V$B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@
M(DYU;F-A($1E<&]I<R!D92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-C,Y"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(DYU;F-A($%N=&5S
M(&1E(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS,S$*;7-G:60@(DYO="!A(&1I
M<F5C=&]R>2(*;7-G<W1R(").XV\@Z2!U;2!D:7)E8W3S<FEO(@H*(SH@;&EB
M+U9&4R])4T]7<FET97(N<&AP.C8S(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2YP:'`Z.#,*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+G!H<#HY-`HC.B!L:6(O5D93+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT
M960N(@IM<V=S='(@(D[C;R!I;7!L96UE;G1A9&$N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T('-E
M="(*;7-G<W1R(")0;W(@871R:6)U:7(B"@HC.B!L:6(O5D93+G!H<#HQ-S4@
M;&EB+U9&4RYP:'`Z,3DS(&QI8B]61E,N<&AP.C(Q,"!L:6(O5D93+G!H<#HR
M,C8*(SH@;&EB+U9&4RYP:'`Z,C0R(&QI8B]61E,N<&AP.C(U-R!L:6(O5D93
M+G!H<#HR-S0@;&EB+U9&4RYP:'`Z,S`W"B,Z(&QI8B]61E,N<&AP.C,V-R!L
M:6(O5D93+G!H<#HT-#8@;&EB+U9&4RYP:'`Z-3$U(&QI8B]61E,N<&AP.C4S
M,@HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$T,R!L:6(O2&]R
M9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$U.`HC.B!L:6(O2&]R9&4O4V5S<VEO
M;DAA;F1L97(N<&AP.C$W,R!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP
M.C$X-PHC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C(S-`IM<V=I
M9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B3N-O('-U<&]R=&%D;RXB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,38T"FUS9VED(").;W1E<R(*;7-G<W1R(").
M;W1A<R(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I
M9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(DYA9&$@
M<&%R82!N879E9V%R+"!V;VQT92!P87)A('1RX7,N(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHQ,`IM<V=I9"`B3F]T:6-E
M(@IM<V=S='(@(DYO=&$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S@T(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B3F]V96UB<F\B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3`T-@IM<V=I9"`B3G5M8F5R(@IM<V=S='(@
M(D[Z;65R;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(W"FUS9VED(").
M=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R(").^FUE<F\@9&4@8V%R86-T
M97)E<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S<Q(&QI8B](;W)D92]&
M;W)M+G!H<#HQ-#(U(&QI8B](;W)D92]&;W)M+G!H<#HQ-#0W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").
M=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R(").^FUE<F\@9&4@8V]L=6YA<R(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S8Y(&QI8B](;W)D92]&;W)M+G!H
M<#HQ-#(S(&QI8B](;W)D92]&;W)M+G!H<#HQ-#0U"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@
M;V8@<F]W<R(*;7-G<W1R(").^FUE<F\@9&4@;&EN:&%S(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N
M;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES
M="XB"FUS9W-T<B`B(@HB3F$@;&ES=&$@9&4@9&ES=')I8G5IY^-O(&CA(&[Z
M;65R;W,@<75E(&[C;R!F;W)A;2!E<W!E8VEF:6-A9&]S('!A<F$@(@HB86-T
M=6%L:7IAY^-O+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHV-"!P;R]T<F%N<VQA=&EO;BYP:'`Z,30X"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,S0X"FUS9VED(")/2R(*;7-G<W1R(")/2R(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX,3$*;7-G:60@(D]B
M:F5C="(*;7-G<W1R(")/8FIE8W1O(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(D-R
M:6%D;W(@9&\@3V)J96-T;R(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$S
M-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(Q-0IM<V=I9"`B3V)J96-T(&-R
M96%T;W(@<&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R;6ES<_5E<R!D;R!C<FEA
M9&]R(&1O(&]B:F5C=&\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$P-`IM
M<V=I9"`B3V-T86PB"FUS9W-T<B`B3V-T86PB"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@S(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R(")/=71U
M8G)O(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E
M;G-E(&9I;'1E<B(*;7-G<W1R(")&:6QT<F\@9&4@;6%T97)I86P@;V9E;G-I
M=F\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`Q"FUS9VED(")/
M9F9I8V4B"FUS9W-T<B`B1V%B:6YE=&4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3@Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T
M<B`B4W5L=&%N871O(&1O($]MXR(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R
M="!S:&%R960@9F]L9&5R<RXB"FUS9W-T<B`B4_,@;W,@<V5R=FED;W)E<R!)
M34%0('-U<&]R=&%M('!A<W1A<R!P87)T:6QH861A<RXB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U
M;F5S(@IM<V=S='(@(D%P96YA<R!D:71O<R!O9F5N<VEV;W,B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3@U,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW,@IM
M<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R
M(")3\R#I('!E<FUI=&ED;R!U;2!E;F1E<F7G;R!D92!C;W)R96EO(&5L96-T
M<O-N:6-O+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I
M9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@
M;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@
M9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HB07!E;F%S(&\@9&]N;R!O=2!U;2!A
M9&UI;FES=')A9&]R(&1E('-I<W1E;6%S('!O9&4@86QT97)A<B!A('1I='5L
M87)I9&%D92!D92`B"B)U;6$@<&%R=&EL:&$@;W4@87,@<&5R;6ES<_5E<R!D
M;R!S974@9&]N;R(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,U"FUS9VED
M(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")!8G)E(&YU;6$@;F]V
M82!J86YE;&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(T-0IM
M<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F
M<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B(@HB17)R;R!/<&5N
M4U-,.B!.XV\@9F]I('!O<W/M=F5L(&5X=')A:7(@9&%D;W,@9&4@=6UA('!A
M<G1E(&%S<VEN861A(&-O;2!3+R(*(DU)344N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")/
M<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D%B<F4@
M97-T82!L:6=AY^-O(&YU;6$@;F]V82!J86YE;&$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T
M<B`B4VES=&5M82!/<&5R871I=F\B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED
M96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(D]PY_5E<R(*
M"B,Z('-E<G9I8V5S+W!R969S+G!H<#HR.2!T96UP;&%T97,O<')E9G,O87!P
M+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*
M;7-G<W1R(")/<.?U97,@9&\@)7,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3$R"FUS9VED(")/<'1I;VYS.B(*;7-G<W1R(")/<.?U97,Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B
M3W)D97)E9"!,:7-T(@IM<V=S='(@(DQI<W1A($]R9&5N861A(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D]R9V%N:7-A=&EO
M;B(*;7-G<W1R(")/<F=A;FEZ8>?C;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S
M='(@(E5N:61A9&4@3W)G86YI>F%C:6]N86PB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3,R"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(D]R
M9V%N:7IAY^-O(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@
M(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@(DUO9&5L
M;R!O<FEG:6YA;"!D82!A<&QI8V'GXV\B"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T
M97,@:6X@)7,Z(@IM<V=S='(@(DUO9&5L;W,@;W)I9VEN86ES(&5M("5S.B(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB
M;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(D]U=')O(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,#8*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,R!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3(R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S$*
M;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D]U=')A<R!);F9O
M<FUAY_5E<R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G
M:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUI<W/U97,@9&\@
M1&]N;R(*"B,Z(&QI8B](;W)D92]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!
M32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")!
M=71E;G1I8V'GXV\@4$%-(&[C;R!E<W3A(&1I<W!O;NUV96PN(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3(U,PIM<V=I9"`B4$=0($1I9VET86P@
M4VEG;F%T=7)E(@IM<V=S='(@(D%S<VEN871U<F$@1&EG:71A;"!01U`B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,CDY"FUS9VED(")01U`@16YC
M<GEP=&5D($1A=&$B"FUS9W-T<B`B1&%D;W,@96YC<FEP=&%D;W,@4$=0(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,U,0IM<V=I9"`B4$=0(%!U
M8FQI8R!+97DB"FUS9W-T<B`B0VAA=F4@4/IB;&EC82!01U`B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S,S"FUS9VED(")01U`@4VEG;F5D+T5N
M8W)Y<'1E9"!$871A(@IM<V=S='(@(D1A9&]S($%S<VEN861O<R]%;F-R:7!T
M861O<R!C;VT@4$=0(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"FUS9VED
M(")02%`@0V]D92(*;7-G<W1R(")#\V1I9V\@4$A0(@H*(SH@861M:6XO<&AP
M<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B0V]M86YD
M;W,@4$A0(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B0VAU=FES8V]S
M('!E;&$@5&%R9&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS.`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R(")!9W5A8V5I
M<F]S(&1E(%1A<F1E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B3F5V92#@(%1A
M<F1E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#`*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(").97;U97,@X"!4
M87)D92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0Q"FUS9VED(")032!3=6XB"FUS9W-T<B`B4V]L(.`@5&%R9&4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B
M4$T@5"U3=&]R;7,B"FUS9W-T<B`B5&5M<&]R86ES+50@X"!487)D92(*"B,Z
M(&QI8B]A<&DN<&AP.C$R.`IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R(")#
M;VUA;F1O<R!07TA0(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R(")%
M;F-H:6UE;G1O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R(")297#Z8FQI
M8V$@27-LXFUI8V$@9&\@4&%Q=6ES=.-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Y-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L874B"FUS
M9W-T<B`B4F5P^F)L:6-A(&1E(%!A;&%U(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Y,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI
M86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R(")497)R:73S<FEO(%!A
M;&5S=&EN:6%N;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@(E!A;F%MX2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#4@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$W-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R(")087!U82!.;W9A
M($=U:6[I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B4F5P^F)L:6-A
M(&1O(%!A<F%G=6%I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S8*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B4&%R
M8VEA;&UE;G1E($5N8V]B97)T;R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#,@;&EB+TAO<F1E+T9O<FTN<&AP.C(P
M,3D*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-R!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C<S('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z,S8*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,V,@IM<V=I
M9"`B4&%S<W=O<F0B"FUS9W-T<B`B4&%L879R82U087-S92(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z,3,R,@IM<V=I9"`B4&%S<W=O<F0@:6YC
M;W)R96-T(@IM<V=S='(@(E!A;&%V<F$M4&%S<V4@:6YC;W)R96-T82(*"B,Z
M(&QI8B](;W)D92]!=71H+W)A9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R
M9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M(")086QA=G)A+5!A<W-E(&YE8V5S<^%R:6$@<&%R82!A=71E;G1I8V'GXV\@
M4D%$2553(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P-30*;7-G:60@(E!A
M<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(E!A;&%V<F$M4&%S
M<V4@8V]M(&-O;F9I<FUAY^-O(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.CDP"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`B4&%L879R82U0
M87-S93HB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I
M9"`B4&%S<W=O<F0Z("(*;7-G<W1R(")086QA=G)A+5!A<W-E.B`B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ-3`@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,S4*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S
M<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(D%S('!A;&%V<F%S+7!A<W-E
M('3J;2!D92!S97(@:6=U86ES+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,C`@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R(")#;VQA<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A
M<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(D-O;&%R(&1E(')E8V]R=&5S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU
M,0IM<V=I9"`B4&%T:"(*;7-G<W1R(")#86UI;FAO(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F5Q=65U960N:6YC.C0*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB
M"FUS9W-T<B`B4W5B<V-R:>?U97,@4&5N9&5N=&5S.B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(E!E<W-O
M87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R(")097)C96YT86=E;2(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M7V)O='1O;2YI;F,Z-@IM
M<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@
M(D5X96-U=&%R($]P97)AY_5E<R!D92!-86YU=&5NY^-O(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,Y.`IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC
M92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")%>&5C=71A<B!O<&5R
M8>?U97,@9&4@;6%N=71E;N?C;R!A<75A;F1O(&1A(&5N=')A9&$_(@H*(SH@
M861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8Q(&%D;6EN+W!E<FUS+V%D9&-H
M:6QD+G!H<#HV-`HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C<*;7-G
M:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B4&5R;6ES<^-O(@H*(R!C+69O<FUA
M=`HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C8X"B,L('!H<"UF;W)M870*
M;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R
M(")!('!E<FUI<W/C;R!<(B5S7"(@;N-O(&9O:2!R96UO=FED82XB"@HC.B!A
M9&UI;B]P97)M<R]E9&ET+G!H<#HR,C0@861M:6XO<&5R;7,O861D8VAI;&0N
M<&AP.CDS"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M
M<R]D96QE=&4N<&AP.C<T"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A
M=&EO;B(*;7-G<W1R(")!9&UI;FES=')AY^-O(&1E(%!E<FUI<W/U97,B"@HC
M.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T-2!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C$T.`HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$U,@IM<V=I
M9"`B4&5R;6ES<VEO;G,@9F]R(@IM<V=S='(@(E!E<FUI<W/U97,@9&4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*;7-G:60@(E!E<G-O;F%L($EN
M9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6'G]65S(%!E<W-O86ES(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS
M9VED(")097)U(@IM<V=S='(@(E!E<OHB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`B06YI;6%I<R!D92!%<W1I
M;6'GXV\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@V(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(D9I;&EP:6YA
M<R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS
M9VED(")0:&]N92(*;7-G<W1R(")496QE9F]N92(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,C4*;7-G:60@(E!H;W1O<R(*;7-G<W1R(")&;W1O
M9W)A9FEA<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3`@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(DEL:&%S(%!I
M=&-A:7)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R(")0[7AE:7,B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS
M9W-T<B`B4&QA=&ET=61E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I
M;G1O('-O;64@8V5L;"(*;7-G<W1R(")0;W(@9F%V;W(@8VQI<75E('-O8G)E
M('5M82!CZ6QU;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#@*;7-G:60@(E!L96%S92!C;VYF:7)M('1H
M870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B
M4&]R(&9A=F]R(&-O;F9I<FUE('-E(')E86QM96YT92!P<F5T96YD92!R96UO
M=F5R(&5S=&4@96QE;65N=&\Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")0;&5A<V4@8V]N
M9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM
M<V=S='(@(E!O<B!F879O<B!C;VYF:7)M92!S92!R96%L;65N=&4@<')E=&5N
M9&4@9&5S;&EG87(@97-T92!E;&5M96YT;RXB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C4W,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@
M>65A<BXB"FUS9W-T<B`B4&]R(&9A=F]R(&EN=')O9'5Z82!U;2!MZG,@92!U
M;2!A;F\N(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N
M97<@8V%T96=O<GDZ(@IM<V=S='(@(E!O<B!F879O<B!I;G1R;V1U>F$@;R!N
M;VUE(&1A(&YO=F$@8V%T96=O<FEA.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,S`Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S
M+B(*;7-G<W1R(")0;W(@9F%V;W(@:6YT<F]D=7IA('5M(&5N9&5R9>=O($E0
M(';A;&ED;RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8U.0IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O
M9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B(@HB4&]R(&9A=F]R(&EN
M=')O9'5Z82!U;6$@9&%T82!VX6QI9&$[('9E<FEF:7%U92!O(&[Z;65R;R!D
M92!D:6%S(&1O(&WJ<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0U,`IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B4&]R
M(&9A=F]R(&EN=')O9'5Z82!U;6$@:&]R82!VX6QI9&$N(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I
M9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R(")0;W(@9F%V
M;W(L(&9O<FYEYV$@=6UA(&)R979E(&1E<V-R:>?C;R!D;R!P<F]B;&5M82XB
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$X('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,C(*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@
M=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S='(@(E!O<B!F879O<BP@:6YT
M<F]D=7IA(&\@<V5U($YO;64@9&4@571I;&EZ861O<B!E(&$@<W5A(%!A;&%V
M<F$M4&%S<V4B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O86=R965M96YT
M7W1O<"YI;F,Z,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4&QE87-E(')E
M860@=&AE(&9O;&QO=VEN9R!T97AT+B`@66]U($U54U0@86=R964@=VET:"!T
M:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*(E!O
M<B!F879O<B!L96EA(&\@=&5X=&\@<V5G=6EN=&4N(%1E;2!D92!#3TY#3U)$
M05(@8V]M(&]S('1E<FUO<R!D97-T92!A8V]R9&\@(@HB<&%R82!U<V%R(&\@
M<VES=&5M82XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3<*;7-G:60@(E!L
M96%S92!R97!O<G0@86YY(&)U9W,@=&\@:3$X;D!L:7-T<RYH;W)D92YO<F<N
M(@IM<V=S='(@(E!O<B!F879O<B!R97!O<G1E(&]S(&5R<F]S('!A<F$@:3$X
M;D!L:7-T<RYH;W)D92YO<F<B"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C
M871E9V]R>2!N86UE.B(*;7-G<W1R(")0;W(@9F%V;W(@:6YT<F]D=7IA(&\@
M;F]M92!D82!N;W9A(&-A=&5G;W)I83HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G
M<W1R(")0;VSS;FEA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W"FUS
M9VED(")0;VQI=&EC<R(*;7-G<W1R(")0;VSM=&EC82(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT,S0*;7-G:60@(E!O;&QS(@IM<V=S='(@(E-O
M;F1A9V5N<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(E)E</IB;&EC
M82!0;W)T=6=U97-A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O
M9B!T:&ES(&EM86=E(@IM<V=S='(@(E!O<VEC:6]N86UE;G1O(&1E<W1A(&EM
M86=E;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S
M='(@(E!O<VEC:6]N86UE;G1O(&1E<W1A('1A8F5L82(*"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES
M(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(EPB4&]S
M=%PB('!A<F$@97-T82!P87-T82`H;N-O(.D@<F5Q=6ES:71O(&1O($E-05`I
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F
M;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B4')E8VEP:71AY^-O(&YA
M<R#Z;'1I;6%S("5S(&AO<F$H<RDZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR.#8*;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N
M8V4B"FUS9W-T<B`B4')O8F%B:6QI9&%D92!D93QB<B`O/E!R96-I<&ET8>?C
M;R(*"B,Z(&QI8B](;W)D92]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E
M9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")0<F5F<U]L9&%P.B!!(&5X=&5N<^-O($Q$05`@;F5C97-SX7)I
M82!NXV\@9F]I(&5N8V]N=')A9&$N(@H*(SH@;&EB+TAO<F1E+U!R969S+W-E
M<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S
M97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7W-E
M<W-I;VXZ($$@97AT96YSXV\@9&4@<V5S<^-O(&YE8V5S<^%R:6$@;N-O(&9O
M:2!E;F-O;G1R861A+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(U"FUS
M9VED(")0<F5S<W5R92(*;7-G<W1R(")0<F5S<^-O(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-3D*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@
M(@IM<V=S='(@(E!R97-SXV\@86\@;NUV96P@9&\@;6%R.B`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(S"FUS9VED(")0<F5S<W5R93H@
M(@IM<V=S='(@(E!R97-SXV\Z("(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ.#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM
M<V=S='(@(E!R979I<^-O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H
M92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B4')E=F5R(&$@:6UA
M9V5M(&YU;6$@;F]V82!J86YE;&$B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN
M<&AP.C,V,"!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V-`IM<V=I9"`B4')E
M=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")/<.?U97,@86YT97)I;W)E<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G
M:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(DEM<')I;6ER(&\@9&]C=6UE
M;G1O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")0
M<FEV871E($ME>2(*;7-G<W1R(")#:&%V92!0<FEV861A(@H*(SH@;&EB+TAO
M<F1E+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R(")0<F]B
M;&5M82(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-PIM<V=I9"`B4')O
M8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FGGXV\@9&\@4')O8FQE
M;6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$S"FUS9VED(")0
M<F]J96-T<R(*;7-G<W1R(")0<F]J96-T;W,B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C$Q,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$X.0IM<V=I9"`B4')O
M;7!T('1E>'0B"FUS9W-T<B`B365N<V%G96TM<')O;G1O(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S
M='(@(D-H879E(%#Z8FQI8V$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS9W-T<B`B
M06QG;W)I=&UO(&1E($-H879E(%#Z8FQI8V$B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C8T-`IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S
M='(@(DEN9F]R;6'GXV\@4V]B<F4@82!#:&%V92(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C(S,`IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I
M<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B3R!P87(@
M9&4@8VAA=F5S(%!U8FQI8V$O4')I=F%D82!NXV\@9F]I(&=E<F%D82!C;VT@
M<W5C97-S;RXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DQ(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R(")0;W)T
M;R!2:6-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B17-T861O(&1O(%%A
M=&%R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8R"FUS9VED(")1=65R>2(*
M;7-G<W1R(")0961I9&\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C8V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@
M8FET*2(*;7-G<W1R(")#:&%V92!0^F)L:6-A(%)302`H)60@8FET*2(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,C8U"FUS9VED(")2861I;R!S96QE8W1I
M;VXB"FUS9W-T<B`B4V5L96/GXV\@7")RX61I;UPB(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G:60@(E)A:6XB"FUS
M9W-T<B`B0VAU=F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R(")#:'5V82!-
M871I;F%L(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#4*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R(")#:'5V82!697-P97)T
M:6YA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#8*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(D%G=6%C96ER;R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED
M(")286EN(&%N9"!3;F]W(@IM<V=S='(@(D-H=79A(&4@3F5V92(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")2
M86EN('1O(%-N;W<B"FUS9W-T<B`B0VAU=F$@82!.979E(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S
M='(@(D1I=&\@06QE873S<FEO(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C@@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*
M;7-G:60@(E)A=&EO(@IM<V=S='(@(E)E;&'GXV\B"@HC.B!L:6(O2&]R9&4O
M4&5R;7,N<&AP.C(Y,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q
M-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R("),97(B
M"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*;7-G:60@
M(E)E860@;65S<V%G97,B"FUS9W-T<B`B3&5R(&UE;G-A9V5N<R(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N
M;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B475E<B!M97-M;R!R96UO=F5R("5S
M/R!%<W1A(&]P97)AY^-O(&[C;R!T96T@<F5G<F5S<V\N(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES
M(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"B)296UO
M=F5R(&UE<VUO(&]S(&1A9&]S(&1O('5T:6QI>F%D;W(@)7,_($5S=&$@;W!E
M<F'GXV\@;N-O('1E;2!R96=R97-S;RXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L
M87-T(&%C=&EO;B(*;7-G<W1R(")2969A>B!A('-U82#Z;'1I;6$@86/GXV\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@S"FUS9VED(")2969R97-H
M($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B4F5F<F5S8V%R($5L
M96UE;G1O<R!D92!-96YU($1I;N)M:6-O.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,S,*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S
M='(@(E)E9G)E<V-A<B!6:7-U86QI>F'GXV\@9&\@4&]R=&%L.B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HX.30@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,3,@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$R,S4*;7-G:60@(E)E9V5X(@IM<V=S='(@
M(D5X<')E<W/C;R!296=U;&%R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R
M-#@*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(DYA=F5G
M861O<B!D92!296QAY_5E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V
M"FUS9VED(")296UA<FMS(@IM<V=S='(@(D]B<V5R=F'G]65S(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Q-`IM<V=I9"`B4F5M;W1E(%-E<G9E<G,B
M"FUS9W-T<B`B4V5R=FED;W)E<R!296UO=&]S(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O
M=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B55),(%)E;6]T;R`H
M:'1T<#HO+W=W=RYE>&5M<&QO+G!T+VAO<F1E*3HB"@HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M97%U975E9"YI;F,Z,34*;7-G:60@(E)E;6]V92(*;7-G<W1R(")296UO=F5R
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")2
M96UO=F4@0FQO8VLB"FUS9W-T<B`B4F5M;W9E<B!";&]C;R(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,CD*;7-G:60@(E)E;6]V
M92!C;VQU;6XB"FUS9W-T<B`B4F5M;W9E<B!C;VQU;F$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0P"FUS9VED(")296UO
M=F4@9F]R;6%T=&EN9R(*;7-G<W1R(")296UO=F5R(&9O<FUA=&'GXV\B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$S-@IM<V=I9"`B4F5M;W9E
M('!A:7(B"FUS9W-T<B`B4F5M;W9E<B!P87(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,C`U"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@
M<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B4F5M;W9E
M<B!O(%PB<V-R:7!T7"(@9W5A<F1A9&\@9&$@<&%S=&$@=&5M<&]RX7)I82!D
M;R!S97)V:61O<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T
M<B`B4F5M;W9E<B!O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")296UO=F4@=&AI<R!N;V1E
M(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(E)E;6]V97(@97-T92!N\R!D
M;R!D;V-U;65N=&\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N
M:6YC.C$V"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R(")296UO=F5R(%5T
M:6QI>F%D;W(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC
M.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S
M='(@(E)E;6]V97(@=71I;&EZ861O<CH@)7,B"@HC.B!L:6(O2&]R9&4O4E!#
M+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N
M<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R(").XV\@9F]I
M('!O<W/M=F5L(')E<W!O;F1E<B!A;R!P961I9&\N($/S9&EG;R!D92!E<G)O
M(&1E=F]L=FED;SH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$T-`IM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O
M=6YD+B(*;7-G<W1R(")/('-E<G9IYV\@<&5D:61O(&[C;R!F;VD@96YC;VYT
M<F%D82XB"@HC.B!L:6(O2&]R9&4N<&AP.C$W-"!L:6(O2&]R9&4N<&AP.C0X
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P
M96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")<(B5S7"(@
M;V)R:6=A=/-R:6\@;N-O(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N9FEG=7)A
MY^-O(&1E("5S+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HU.3<@;&EB+U9&4R]F
M='`N<&AP.C<T-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW,3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@
M5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(EPB)7-<(B!O8G)I9V%T\W)I
M;R!NXV\@9F]I(&5S<&5C:69I8V%D;R!N82!C;VYF:6=U<F'GXV\@5D93+B(*
M"B,Z(&QI8B](;W)D92]5=&EL+G!H<#HW.#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B7"(E<UPB(&]B<FEG873S<FEO(&[C;R!F;VD@97-P
M96-I9FEC861O(&YA(&-O;F9I9W5R8>?C;RXB"@HC.B!L:6(O2&]R9&4O1F]R
M;2]296YD97)E<BYP:'`Z,S(X"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G
M<W1R(")#86UP;R!/8G)I9V%T\W)I;R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q
M(&QI8B](;W)D92]&;W)M+G!H<#HS,SD@;&EB+TAO<F1E+T9O<FTO4F5N9&5R
M97(N<&AP.C,Q-0HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#0*;7-G:60@(E)E
M<V5T(@IM<V=S='(@(DQI;7!A<B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C0V"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R(")296EN
M:6-I87(@4&%L879R82U087-S92(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C(W"FUS9VED(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@
M(E)E:6YI8VEE(&$@4W5A(%!A;&%V<F$M4&%S<V4B"@HC.B!A9&UI;B]P:'!S
M:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE;&PN<&AP.C(X(&%D;6EN+W-Q;'-H
M96QL+G!H<#HV-0IM<V=I9"`B4F5S=6QT<R(*;7-G<W1R(")297-U;'1A9&]S
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C@R,0IM<V=I9"`B4F5S=6QT<R`H
M:6YC;'5D:6YG($AO<F1E*3HB"FUS9W-T<B`B4F5S=6QT861O<R`H:6YC;'5I
M;F1O($AO<F1E*3HB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#$Y"FUS9VED
M(")297-U;'1S.B(*;7-G<W1R(")297-U;'1A9&]S.B(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#(@=&5M<&QA=&5S+W!R969S+V5N9"YI
M;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B5F]L=&%R
M(.!S($]PY_5E<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B4F5U;FGC
M;R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS
M9W-T<B`B4D5V97)T97(@0V]N9FEG=7)AY^-O(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S,@IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS
M(@IM<V=S='(@(D]PY_5E<R!D92!%9&GGXV\@4FEC82(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R(")!9&EV
M:6YH87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(D1I<F5I=&$B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$R,`IM<V=I9"`B4FEG:'0@:&5A9&5R
M(@IM<V=S='(@(D-A8F7G86QH;R!D82!D:7)E:71A(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C,Q,38*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R(")6
M86QO<F5S(.`@9&ER96ET82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T
M:65S+BXN(@IM<V=S='(@(E!R;W!R:65D861E<R!D82!,:6Y?:&$N+BXB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B
M4F]L92(*;7-G<W1R(")296=R82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T
M<B`B4F]MZ6YI82(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,#@*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B4F]D87(@,3@P
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P-0IM
M<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B4F]D87(@X"!%<W%U97)D82(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,3$*;7-G
M:60@(E)O=&%T92!2:6=H="(*;7-G<W1R(")2;V1A<B#@(&1I<F5I=&$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R(")0<F]P<FEE9&%D
M97,@9&$@3&EN:&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G
M<W1R(")0<F]P<FEE9&%D97,@9&$@;&EN:&$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS
M9W-T<B`B3&EN:&%S.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM<V=S='(@(E1R
M8>=O<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@
M86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B5')AYV]S(&%P87)E8V5R
MXV\@96YT<F4@=&]D87,@87,@;&EN:&%S(&4@8V]L=6YA<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G
M:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM
M<V=S='(@(E1R8>=O<R!A<&%R96-E<N-O(&%P96YA<R!E;G1R92!A<R!C;VQU
M;F%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R
M;W=S(&]N;'DB"FUS9W-T<B`B5')AYV]S(&%P87)E8V5RXV\@87!E;F%S(&5N
M=')E(&QI;FAA<R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C$*;7-G:60@
M(E)U;B(*;7-G<W1R(")%>&5C=71A<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D
M97)A=&EO;B(*;7-G<W1R(")&961E<F'GXV\@4G5S<V$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C`P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2
M=V%N9&$B"FUS9W-T<B`B4F5P^F)L:6-A(&1O(%)U86YD82(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O
M9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B07-S:6YA='5R82!#<FEP=&]G
M<N%F:6-A(%,O34E-12(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M,S(S"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B
M365N<V%G96T@16YC<FEP=&%D82!C;VT@4R]-24U%(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@
M:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B075T96YT:6-AY^-O(%-!4TP@
M:6YD:7-P;V[M=F5L+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M-3D*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`B365N<V%G96YS(%--
M4R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL
M(@IM<V=S='(@(D-O;6%N9&]S(%-13"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS-S`*;7-G:60@(E-32"(*;7-G<W1R(")34T@B"@HC.B!L:6(O
M2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G
M:60@(E-50T-%4U,B"FUS9W-T<B`B4U5#15-33R(*"B,Z(&QI8B]A<&DN<&AP
M.C$S,@IM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R(")#;VUA;F1O<R!37U%,
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M,0IM<V=I9"`B4V$B"FUS9W-T<B`B<^$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C`W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")386EN="!(96QE
M;F$B"FUS9W-T<B`B4V%N=&$@2&5L96YA(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$S,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T
M<R!A;F0@3F5V:7,B"FUS9W-T<B`B4^-O($MI='1S(&4@3F5V:7,B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G
M:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(E-A;G1A($SZ8VEA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$X.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DR"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I
M9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R(")3XV\@4&5D
M<F\@92!-:7%U96QO;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H
M92!'<F5N861I;F5S(@IM<V=S='(@(E/C;R!6:6-E;G1E(&4@1W)E;F%D:6YE
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R(")-97-M82!M
M;VQD=7)A("A?<V5L9BDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")386UO82(*;7-G<W1R(")%<W1A
M9&\@26YD97!E;F1E;G1E(&1A(%-A;6]A(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(Q,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN
M;R(*;7-G<W1R(")297#Z8FQI8V$@4V5R96[M<W-I;6$@9&4@4^-O($UA<FEN
M;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,38@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R(")3
MXV\@5&]MZ2!E(%!R[6YC:7!E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B1F]R
M;F5C961O<B!D;R!3873I;&ET92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I82(*
M;7-G<W1R(")!<N%B:6$@4V%U9&ET82(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHY.`IM<V=I9"`B4V%V92(*;7-G<W1R(")'=6%R9&%R(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R(")'=6%R9&%R("5S(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3879E("<E<R<B"FUS9W-T<B`B1W5A<F1A<B`G)7,G(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS
M(@IM<V=S='(@(D=U87)D87(@3W#G]65S(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$W,`IM<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A
M<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"B)'=6%R9&%R(&-O;F9I9W5R
M8>?C;R!G97)A9&$@8V]M;R!U;2!<(G-C<FEP=%PB(%!(4"!N;R!D:7)E8W3S
M<FEO('1E;7!O<N%R:6\@(@HB9&\@<V5U('-E<G9I9&]R+B(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C8Y"B,L('!H<"UF;W)M870*;7-G:60@(E-A
M=F5D("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D=U87)D96D@8V]N9FEG
M=7)AY^-O("5S+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDP"B,L
M('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T
M('1O.B!<(B5S7"(N(@IM<V=S='(@(D=U87)D96D@;R!<(G-C<FEP=%PB(&1E
M(&%C='5A;&EZ8>?C;R!E;3H@7"(E<UPB+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")38V%T=&5R960@5"U3
M=&]R;7,B"FUS9W-T<B`B5&5M<&]R86ES+50@1&ES<&5R<V]S(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S='(@
M(D-IZFYC:6$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ
M-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A
M<F-H(@IM<V=S='(@(E!R;V-U<F%R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(W.`IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B36]T
M;W)E<R!D92!0<F]C=7)A(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$T-#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4V5A<F-H:6YG($AO<F1E(&%P<&QI8V%T
M:6]N<R!I;B`E<R(*;7-G<W1R(")0<F]C=7)A;F1O(&%P;&EC8>?U97,@*&WS
M9'5L;W,I($AO<F1E(&5M("5S(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R
M,PIM<V=I9"`B4V5A<F-H:6YG(&=E='1E>'0@8FEN87)I97,N+BXB"FUS9W-T
M<B`B4')O8W5R86YD;R!O<R!B:6[A<FEO<R!D92!G971T97AT+BXN(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(Y-S(*;7-G:60@(E-E;&5C="!&:6QE<R(*
M;7-G<W1R(")396QE8V-I;VYA<B!!<G%U:79O<R(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-38*;7-G:60@(E-E;&5C="!A(&1A
M=&4B"FUS9W-T<B`B4V5L96-C:6]N92!U;6$@9&%T82(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T
M;R!A9&0B"FUS9W-T<B`B4V5L96-C:6]N92!U;2!G<G5P;R!A(&%C<F5S8V5N
M=&%R(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B
M4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(E-E;&5C8VEO;F%R('5M(&YO
M=F\@9&]N;R(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM
M<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(E-E;&5C8VEO;F4@=6T@
M<V5R=FED;W(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM
M<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B4V5L96-C:6]N
M92!U;2!U=&EL:7IA9&]R(&$@861I8VEO;F%R(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(V-C(*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S
M+B(*;7-G<W1R(")396QE8V-I;VYE('1O9&]S(&]S(&-O;7!O;F5N=&5S(&1A
M(&1A=&$N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@Q,0IM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R(")396QE8V-I
M;VYE('5M(&]B:F5C=&\B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*
M;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M
M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A
M<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B)396QE
M8V-I;VYE(&]S(&-A<F%C=&5R97,@;F%S(&-A:7AA<R!A8F%I>&\N(%!O9&5R
MX2!E;G3C;R!C;W!IX2UL;W,@92!C;VSA+2(*(FQO<R!N82#A<F5A(&1E('1E
M>'1O+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")3
M96QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R(")396QE8V-I;VYE
M(&\@9&5L:6UI=&%D;W(@9&$@9&%T83HB"@HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS
M9W-T<B`B4V5L96-C:6]N92!O(&9O<FUA=&\@9&$@9&%T83HB"@HC.B!T96UP
M;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.C@Y"FUS9VED(")396QE
M8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`B
M4V5L96-C:6]N92!A(&ED96YT:61A9&4@<75E('!R971E;F1E(&%L=&5R87(Z
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,38*;7-G:60@(E-E;&5C
M="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S='(@(E-E;&5C8VEO;F4@;R!D
M96QI;6ET861O<B!D87,@:&]R87,Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM
M92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S
M='(@(E-E;&5C8VEO;F4@;R!F;W)M871O(&1A(&AO<F$Z(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHV-`IM<V=I9"`B4V5L96-T('1W;R!M871C
M:&EN9R!F:65L9',N(@IM<V=S='(@(E-E;&5C8VEO;F4@9&]I<R!C86UP;W,@
M<F5L86-I;VYA9&]S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3@*
M;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B17-C
M;VQH82!O('-E=2!C;VYJ=6YT;R!D92!C;W)E<RXB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C0P"FUS9VED(")396QE8W0@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4Z(@IM<V=S='(@(E-E;&5C8VEO;F4@;R!S974@:61I;VUA('!R
M969E<FED;SHB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU
M.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")%;G9I87(@
M4F5L873S<FEO(&1E(%!R;V)L96UA<R(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY-C$*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@
M(D5N=FEA<B!335,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$S(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S='(@(E)E</IB
M;&EC82!D;R!396YE9V%L(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,38*
M;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@(B!396YS;W(Z("(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS.#(@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS
M9W-T<B`B4V5T96UB<F\B"@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B
M4^ER=FEA(&4@36]N=&5N96=R;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-S`Q"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(D[Z;65R
M;R!D92!3Z7)I92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-#@*;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(D1A9&]S(&1O('-E<G9I9&]R(&5R<F%D;W,@;W4@:6YD:7-P
M;V[M=F5I<RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R("))1"!D
M92!S97-SXV\@97AP:7)O=2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,Q
M,PIM<V=I9"`B4V5T(@IM<V=S='(@(D%T<FEB=6ER(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<V"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y
M;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@
M:70N(@IM<V=S='(@(B(*(D5S=&%B96QEYV$@;W#G]65S('%U92!L:&4@<&5R
M;6ET86T@<F5I;FEC:6%R(&$@<W5A('!A;&%V<F$M<&%S<V4@<V4@86QG=6UA
M("(*(G9E>B!D96QA('-E(&5S<75E8V5R+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,34*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T
M('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R
M(")%<W!E8VEF:6-A<B!S97)V:61O<F5S(')E;6]T;W,@<75E(&1E<V5J82!A
M8V5D97(@;F\@<V5U('!O<G1A;"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#0*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM
M97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B(@HB4V5L96-C:6]N
M92!O('-E=2!I9&EO;6$@<')E9F5R:61O+"!O('-E=2!F=7-O(&AO<N%R:6\@
M92!A<R!S=6%S(&]PY_5E<R!D92`B"B)D871A<RXB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3@*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P
M;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@
M;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B"B)%<V-O;&AA
M(&$@<W5A(&%P;&EC8>?C;R!I;FEC:6%L+"!O(&5S<75E;6$@9&4@8V]R97,L
M(&\@<F5F<F5S8V%M96YT;R!D92`B"B)PX6=I;F%S(&4@;W5T<F%S(&]PY_5E
M<R!D92!V:7-U86QI>F'GXV\N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HW-`IM<V=I9"`B4V5T=7`B"FUS9W-T<B`B0V]N9FEG=7)A<B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,Y"FUS9VED(")3971U
M<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(EPB4V-R:7!T
M<UPB(&1E(&%C='5A;&EZ8>?C;R!D:7-P;V[M=F5I<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S0*;7-G:60@(E-E=F5R86P@;&]C871I
M;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(E;A
M<FEA<R!L;V-A;&EZ8>?U97,@<&]S<^UV96ES(&-O;2!O('!A<N)M971R;SH@
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R(")396EC:&5L97,B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4Q"FUS9VED(")3:&]P<&EN
M9R(*;7-G<W1R(")#;VUP<F%S(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B0G)E
M=F4@4W5MX7)I;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,S@*;7-G
M:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI
M;FMS/R(*;7-G<W1R(")$979E;2US92!D969I;FER('1E8VQA<R!D92!A8V5S
M<V\@<&%R82!A(&UA:6]R:6$@9&%S(&QI9V'G]65S/R(*"B,Z(&QI8B](;W)D
M92]097)M<RYP:'`Z,CDR('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(DUO
M<W1R87(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34X"FUS9VED("(B
M"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N
M9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B(*(DUO<W1R87(@9&EF97)E;N=A<R!E;G1R92!A(&-O;F9I9W5R8>?C
M;R!G=6%R9&%D82!E(&%Q=64@9F]I(&%G;W)A(&=E<F%D82XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#@R"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@
M=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(DUO<W1R87(@;6]M96YT
M;R!D82#Z;'1I;6$@96YT<F%D82!N;R!S:7-T96UA/R(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ-S8V"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R
M:6=I;F%L(@IM<V=S='(@(DUO<W1R87(@;W#GXV\@<&%R82!P<F5S97)V87(@
M;R!O<FEG:6YA;"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#$R"FUS9VED
M(")3:&]W('!I8VME<B(*;7-G<W1R(")-;W-T<F%R('!A;&5T92(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3@*;7-G:60@(E-H;W<@=&%B;&4@;W!E
M<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B36]S=')A<B!A(&)A<G)A(&1E
M(&UE;G4@8V]M(&%S(&]P97)AY_5E<R!S;V)R92!T86)E;&%S/R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B36]S=')A
M<B!O($UE;G4@)7,@X"!E<W%U97)D83\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E-H;W<@
M=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B36]S
M=')A<B!A(&-A:7AA(&1E(&1IX6QO9V\@9&%S(%!R;W!R:65D861E<R!D92!#
MZ6QU;&%S(&1E(%1A8F5L83\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(E-H;W<@=&AE(%1A
M8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(DUO<W1R87(@82!C86EX
M82!D92!D:>%L;V=O(&1A<R!0<F]P<FEE9&%D97,@9&4@5&%B96QA<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA
M;&]G(@IM<V=S='(@(DUO<W1R87(@82!C86EX82!D92!D:>%L;V=O(&1A<R!0
M<F]P<FEE9&%D97,@9&4@3&EN:&%S(&1E(%1A8F5L82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I
M9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B
M36]S=')A<B!A(&-A:7AA(&1E(&1IX6QO9V\@9&%S(%!R;W!R:65D861E<R!D
M92!);6%G96TB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V-`IM<V=I9"`B
M4VAO=R!U<&QO860B"FUS9W-T<B`B36]S=')A<B!C87)R96=A;65N=&\B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I
M9"`B4VAO=V5R<R(*;7-G<W1R(")!9W5A8V5I<F]S(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-H;W=E<G,@
M16%R;'DB"FUS9W-T<B`B06=U86-E:7)O<R!-871I;F%I<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W
M97)S($QA=&4B"FUS9W-T<B`B06=U86-E:7)O<R!697-P97)T:6YO<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED
M(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R(")!9W5A8V5I<F]S
M(&YA(%9I>FEN:&%NYV$B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H
M<#HS.3D*;7-G:60@(E-H<FEN:R(*;7-G<W1R(")%;F-O;&AE<B(*"B,Z(&QI
M8B](;W)D92]";&]C:R],87EO=70N<&AP.C8Y,B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+G!H<#HW-30*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z
M.#$R(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C@W-`HC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+G!H<#HY,#D@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="YP:'`Z.30V"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.CDW-"!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HQ,#`T"FUS9VED(")3:')I;FL@
M;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@
M9FER<W0B"FUS9W-T<B`B16YC;VQH82!O=2!M;W9A(&\H<RD@8FQO8V\H<RD@
M=FEZ:6YH;RAS*2!P<FEM96ER;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*
M;7-G<W1R(")397)R82!,9>-O(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P
M+G!H<#HR-C4*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B4W5B<V-R979E<B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3(*;7-G:60@(E-I9VX@
M=7`@:68@;F]T(')E9VES=&5R960B"FUS9W-T<B`B4W5B<V-R979A+"!S92!A
M:6YD82!NXV\@97-TX2!R96=I<W1A9&\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(D%S<VEN
M871U<F$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<Q,0IM<V=I
M9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R(")!;&=O<FET;6\@9&4@
M07-S:6YA='5R82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#8@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R(")297#Z
M8FQI8V$@9&4@4VEN9V%P=7)A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y
M-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q-2!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3(S-PHC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T-R!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,CDR.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$R,@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O<F%R+G!H<#HV-2!L:6(O2&]R9&4O34E-12]6:65W
M97(O>FEP+G!H<#HW,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H
M<#HX-`IM<V=I9"`B4VEZ92(*;7-G<W1R(")486UA;FAO(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?8F]T=&]M+FEN8SHY"FUS9VED(")3
M:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(E-A;'1A<B!-86YU=&5NY^-O(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C0S,2!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-#@T('!O+W1R86YS;&%T:6]N+G!H<#HV-C8*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C@V,"!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(R,PIM<V=I9"`B4VMI<'!E
M9"XN+B(*;7-G<W1R(").XV\@<')O8V5S<V%D;RXN+B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(P,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L
M;W9A:VEA(@IM<V=S='(@(D5S;&]VX7%U:6$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C`X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#0*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI
M82(*;7-G<W1R(")297#Z8FQI8V$@9&$@17-L;W;I;FEA(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-N;W<B
M"FUS9W-T<B`B3F5V92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R(").97;C
M;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V
M"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`B3F5V]65S(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N
M;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R(").97;U97,@36%T:6YA:7,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I
M9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B3F5V]65S(%9E<W!E<G1I
M;F]S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*;7-G:60@(E-N;W<@
M9&5P=&@Z("(*;7-G<W1R(")!;'1U<F$@9&4@;F5V93H@(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W
M871E<CH@(@IM<V=S='(@(DUO<W1R87(@97%U:79A;&5N=&4@;F$@X6=U83H@
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(DEL:&%S(%-A
M;&]MXV\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$T(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(E-O;>%L:6$B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E
M;7,B"FUS9W-T<B`B0V%NY_5E<R!E(%!O96UA<R(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR.3(U"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G
M<W1R(")396QE8^?C;R!D;R!S96YT:61O(&1A(&]R9&5N8>?C;R(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Q-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(T-PIM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B16YD97)E
MYV\@9&4@;W)I9V5M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@
M(L%F<FEC82!D;R!3=6PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM
M<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(D5U
M<F]P82!D;R!3=6P@*$E33RTX.#4Y+3,I(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R
M9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R(")'
M9?-R9VEA(&1O(%-U;"!E($EL:&%S(%-A;F1W:6-H(&1O(%-U;"(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G
M:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B2&5M:7-FZ7)I;R!3
M=6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G
M<W1R(")%<W!AYV\@96YT<F4@8^EL=6QA<R!A9&IA8V5N=&5S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@
M(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS
M9W-T<B`B17-P8>=O(&5N=')E(&\@8V]N=&7Z9&\@92!A(&)O<F1A(&1E('5M
M82!CZ6QU;&$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#$U"FUS9VED(")3
M<&%C97(B"FUS9W-T<B`B17-P8>=A9&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"FUS9VED(")3<&%C:6YG
M(@IM<V=S='(@(D5S<&'G86UE;G1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A
M;F0@<&%D9&EN9R(*;7-G<W1R(")%<W!AYV%M96YT;R!E(&5N8VAI;65N=&\B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(P.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B4F5I;F\@9&4@17-P86YH82(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY.`IM<V=I9"`B4W!A;2(*;7-G
M<W1R(")#;W)R96EO(&[C;R!S;VQI8VET861O(@H*(SH@<V5R=FEC97,O:V5Y
M8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*
M;7-G<W1R("));G-E<FER($-A<F%C=&5R($5S<&5C:6%L(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I
M9"`B4W!L:70@8V5L;"(*;7-G<W1R(")$:79I9&ER(&/I;'5L82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*
M;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R(")!9&EC:6]N87(@8V]L=6YA
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(D1I=FED:7(@;&EN
M:&$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E-P;W)T
M<R(*;7-G<W1R(")$97-P;W)T;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,30Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G
M<W1R(")297#Z8FQI8V$@1&5M;V-RX71I8V$@4V]C:6%L:7-T82!D;R!3<FD@
M3&%N:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C4@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HW-`IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B
M4&%D<N-O(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3
M=&%R(%1R96LB"FUS9W-T<B`B4W1A<B!4<F5K(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(U.34@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#@*;7-G:60@(E-T
M87)T('EE87(B"FUS9W-T<B`B06YO(&1E(&EN[6-I;R(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")3=&%T92!O<B!0<F]V:6YC
M92(*;7-G<W1R(")%<W1A9&\@;W4@4')O=NUN8VEA(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G
M<W1R(")3=&%T=7,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#DQ"B,L('!H
M<"UF;W)M870*;7-G:60@(E-T871U<R!F;W(@;&]C86QE("5S+BXN("(*;7-G
M<W1R(")%<W1A9&\@9&$@;&]C86QI>F'GXV\@)7,N+BX@(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(X,30*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S
M='(@(D9O<FUA=&\@9&4@87)M87IE;F%M96YT;R(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3<R"FUS9VED(")3=')E970@061D<F5S<R(*;7-G
M<W1R(")%;F1E<F7G;R!D92!2=6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM
M<V=S='(@(E)A<W5R861O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,S,*
M;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(DQI<W1A(&1E(&-A9&5I87,@
M9&4@8V%R86-T97)E<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<T"FUS
M9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R(")2
M971I<F%R(&1O;>UN:6\@9&\@96YD97)EYV\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL
M92!;0U-372(*;7-G<W1R(")%<W1I;&\@6T-34UTB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G
M<W1R(")D;R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(D%S<W5N=&\B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S,R(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H
M<#HS,3(*;7-G:60@(E-U8FUI="(*;7-G<W1R(")3=6)M971E<B(*"B,Z('-I
M9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D
M(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N
M(&YO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P
M<')O=F5D+B(*;7-G<W1R("(B"B)&;VD@<W5B;65T:61O('!E9&ED;R!P87)A
M(&%D:6-I;VYA<B!<(B5S7"(@86\@<VES=&5M82X@3N-O('!O9&5RX2!E;G1R
M87(@(@HB96YQ=6%N=&\@;R!S974@<&5D:61O(&[C;R!F;W(@87!R;W9A9&\N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(DEN9F5R:6]R(.`@;&EN:&$B
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`U(&QI8B](;W)D92].;W1I9FEC
M871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*
M;7-G<W1R(")3=6-E<W-O(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T
M:&4@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@861I8VEO;F%D;R!C;VT@<W5C
M97-S;R!A;R!S:7-T96UA+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O
M<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B(*(DQI
M;7!E>F$@9&\@<VES=&5M82!D;W,@9&%D;W,@9&\@=71I;&EZ861O<B!<(B5S
M7"(@<F5A;&EZ861A(&-O;2!S=6-E<W-O+B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z.#$@861M:6XO<&5R;7,O9&5L971E+G!H<#HV,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S='(@
M(E)E;6_GXV\@9&4@7"(E<UPB(&-O;2!S=6-E<W-O+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")296UO
MY^-O(&1E(%PB)7-<(B!D;R!S:7-T96UA(&-O;2!S=6-E<W-O+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R
M979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N
M(@IM<V=S='(@(D-O;F9I9W5R8>?C;R!R979E<G1I9&$@8V]M('-U8V5S<V\N
M(%)E8V%R<F5G=64@<&%R82!V97(@87,@;75D86[G87,N(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4U
M"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(D-O;F9I9W5R8>?C;R!D92!S86QV86=U87)D82!G=6%R
M9&%D82!C;VT@<W5C97-S;RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T
M:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B1FEC
M:&5I<F\@9&4@8V]N9FEG=7)AY^-O(&1E('-A;'9A9W5A<F1A("5S(&=U87)D
M861O(&-O;2!S=6-E<W-O+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B
M"FUS9W-T<B`B7"(E<UPB(&%C='5A;&EZ861O(&-O;2!S=6-E<W-O(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E
M("5S(@IM<V=S='(@(B5S(&5S8W)I=&\@8V]M('-U8V5S<V\B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C`T(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED
M(")3=61A;B(*;7-G<W1R(")297#Z8FQI8V$@9&\@4W5DXV\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS
M9VED(")3=6UM87)Y(@IM<V=S='(@(E)E<W5M;R(*"B,Z(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HV-@IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B3F%S8V5R
M(&1O(%-O;"(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HW,0IM<V=I9"`B
M4W5N(%-E="(*;7-G<W1R(")0]'(@9&\@4V]L(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-U;FYY(@IM<V=S
M='(@(E-O;&%R96YG;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,#0*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B3F%S8V5R(&1O(%-O;"(*
M"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B3F%S8V5R
M+U#T<B!D;R!3;VPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C`S"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B3F%S8V5R(&1O(%-O;#H@
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-PIM<V=I9"`B
M4W5N<V5T(@IM<V=S='(@(E#T<B!D;R!3;VPB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C`V"FUS9VED(")3=6YS970Z("(*;7-G<W1R(")0
M]'(@9&\@4V]L.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R(")3=7!E
M<FEO<B#@(&QI;FAA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T
M,PIM<V=I9"`B4W5P<&]R="(*;7-G<W1R(")3=7!O<G1E(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(Q-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B
M4W5R:6YA;64B"FUS9W-T<B`B4W5R:6YA;64B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B4W5R;F%M92(*;7-G<W1R(")!<&5L
M:61O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R
M(")3=F%L8F%R9"!E($IA;B!-87EE;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*
M;7-G<W1R(")296EN;R!D82!3=6%Z:6SB;F1I82(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q
M-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E
M;B(*;7-G<W1R(")296EN;R!D82!3=>EC:6$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA
M;F0B"FUS9W-T<B`B4W7MYV$B"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S
M+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*
M;7-G<W1R(")%<G)O(&1E('-I;G1A>&4@;F]S('1E<FUO<R!D92!P<F]C=7)A
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B4F5P
M^F)L:6-A(,%R86)E(%/M<FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B5&5M
M<&]R86PM5"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8Q"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R(")496UP
M;W)A;"U4(&4@5F5N=&]S;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R(")496UP
M;W)A:7,M5"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8S"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R(")496UP;W)A
M:7,M5"!-871I;F%I<R(*"B,Z(&QI8B](;W)D92]$871A+W1S=BYP:'`Z,38V
M"FUS9VED(")44U8@9FEL92(*;7-G<W1R(")!<G%U:79O(%135B(*"B,Z(&QI
M8B](;W)D92]522]486)L92YP:'`Z,3,V"FUS9VED(")486)L92(*;7-G<W1R
M(")486)E;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S
M='(@(E!R;W!R:65D861E<R!D82!486)E;&$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L
M92!P<F]P97)T:65S(@IM<V=S='(@(E!R;W!R:65D861E<R!D82!T86)E;&$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,T(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@(D9O<FUO<V$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")4
M86EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(D9O<FUO<V$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(U(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y
M"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(E)E</IB;&EC82!D;R!4861J
M:7%U:7-TXV\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC
M(&]F(@IM<V=S='(@(E1A;GKB;FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R
M(")!;'9O.B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-S,*;7-G
M:60@(E1A<VMS(@IM<V=S='(@(E1A<F5F87,B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G
M<W1R(").^FUE<F\@9&4@5&5L969O;F4B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(Y,`IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B
M5&5M<&5R871U<F$@9&$@^FQT:6UA(&AO<F$Z(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,30*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(E1E;7!E
M<F%T=7)A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,0IM
M<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R(")496UP97)A='5R83H@(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F
M9&5G.R5S(@IM<V=S='(@(E1E;7!E<F%T=7)A/&)R("\^*"5S06QT825S+R5S
M0F%I>&$E<RD@)F1E9SLE<R(*"B,Z(&QI8B](;W)D92]496UP;&%T92YP:'`Z
M,C$W"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D\@;6]D96QO(%PB)7-<(B!NXV\@9F]I(&5N8V]N
M=')A9&\N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E
M;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<F'GXV\@
M9&4@36]D96QO<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$Q"FUS9VED
M(")497AT(@IM<V=S='(@(E1E>'1O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,V-PIM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(D%P96YA<R!497AT
M;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B06QI;FAA;65N
M=&\@9&\@=&5X=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(E1O<&\@9&\@
M=&5X=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R("(UJB(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DQ"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R(")4
M86EL86YDZG,@*%1)4RTV,C`I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(R-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T
M<B`B4F5I;F\@9&$@5&%I;.)N9&EA(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP
M.CDR,PIM<V=I9"`B5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+B(*
M;7-G<W1R(")/8G)I9V%D;R!P;W(@=7-A<B!E<W1E('-I<W1E;6$N(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$P-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE("5S(&AE;'`@9FEL92!F;W(@)7,@9&]E<VXG="!Y970@97AI<W0N($-R
M96%T:6YG(&$@;F5W(&]N92XB"FUS9W-T<B`B3R!A<G%U:79O(&1E(&%J=61A
M("5S('!A<F$@)7,@;N-O(&5X:7-T92!A:6YD82X@0W)I86YD;R!U;2!N;W9O
M+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW,S<*;7-G:60@(E1H92!&5%`@97AT
M96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D$@97AT96YSXV\@
M1E10(&[C;R!E<W3A(&1I<W!O;NUV96PN(@H*(SH@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HY,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B
M(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*
M;7-G<W1R(")/(&5N9V5N:&\@9&4@:6YT96=R8>?C;R!(;W)D92]+;VQA8B!N
MXV\@<W5P;W)T82!<(B5S7"(B"@HC.B!L:6(O3F5T+TE-4U`O0F]O:RYP:'`Z
M,3(Y-`IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L
M:7IE9"XB"FUS9W-T<B`B3R!R96=I<W1O("A<(FQO9UPB*2!)35-0(&[C;R!P
M]&1E('-E<B!I;FEC:6%L:7IA9&\N(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C(Y"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@
M;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(D$@8VQA<W-E($UA:6YT
M96YA;F-E.CH@;N-O(&9O:2!C87)R96=A9&$@8V]M('-U8V5S<V\B"@HC.B!S
M97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@
M3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B
M02!J86YE;&$@9&4@3W#G]65S(&9E8VAO=2X@4V'M;F1O+B(*"B,Z(&QI8B](
M;W)D92]097)M<RYP:'`Z,34X(&QI8B](;W)D92]097)M<RYP:'`Z,38Y(&QI
M8B](;W)D92]097)M<RYP:'`Z,3@P"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z
M,3DR(&QI8B](;W)D92]097)M<RYP:'`Z,C`S(&QI8B](;W)D92]097)M<RYP
M:'`Z,C(Q"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,C,S(&QI8B](;W)D92]0
M97)M<RYP:'`Z,C<R"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D
M<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N
M9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@
M(B(*(D\@861M:6YI<W1R861O<B!T96T@9&4@8V]N9FEG=7)A<B!U;2!M96-A
M;FES;6\@9&4@<&5R;6ES<_5E<R!P97)M86YE;G1E('-E("(*(G%U:7-E<B!U
M<V%R(%!E<FUI<W/U97,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E
M(&]N;'DB"FUS9W-T<B`B07!E;F%S(&\@;&%D;R!I;F9E<FEO<B(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H
M92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B
M;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS
M9W-T<B`B(@HB3R!N^FUE<F\@9&4@240@9&\@8V]N=&%C=&\@;N-O(&9O:2!E
M<W!E8VEF:6-A9&\L(&9O:2!D96EX861O(&5M(&)R86YC;R!O=2`B"B)NXV\@
M9F]I(&5N8V]N=')A9&\@;F$@8F%S92!D92!D861O<RXB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C
M="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K
M+B(*;7-G<W1R(")/(&-O;G1A8W1O(&9O:2!A9&EC:6]N861O(.`@;&ES=&$@
M9&4@8V]N=&%C=&]S(&-O;2!S=6-E<W-O+B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C$Q-#D*;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG
M;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D
M(&UE<W-A9V4N(@IM<V=S='(@(B(*(D\@8FQO8V\@9&4@87-S:6YA='5R82!0
M1U`@9&5S=&%C861O(.D@;F5C97-SX7)I;R!P87)A('9E<FEF:6-A<B!U;6$@
M;65N<V%G96T@(@HB87-S:6YA9&$N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L
M:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O
M<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"B)/
M($E$(&1A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;R!NXV\@9F]I(&5S<&5C:69I
M8V%D;RP@9F]I(&1E:7AA9&\@96T@8G)A;F-O(&]U("(*(F[C;R!F;VD@96YC
M;VYT<F%D;R!N82!B87-E(&1E(&1A9&]S+B(*"B,@8RUF;W)M870*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I
M<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R(")!
M(&QI<W1A(&1E(&1I<W1R:6)U:>?C;R!NXV\@9F]I(&5S<&5C:69I8V%D82XB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0N<&AP.C$Q,PIM<V=I9"`B5&AE(&5N8W)Y
M<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO
M;BXB"FUS9W-T<B`B07,@9G5N8VEO;F%L:61A9&5S(&1E(&5N8W)I<'1AY^-O
M(&5X:6=E;2!U;6$@;&EG8>?C;R!S96=U<F$N(@H*(SH@;&EB+TAO<F1E+G!H
M<#HQ-S4@;&EB+TAO<F1E+G!H<#HT.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G
M<W1R(")/(&%R<75I=F\@)7,@9&5V97)I82!C;VYT97(@=6T@871R:6)U=&\@
M)7,N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-C@@;&EB+TAO<F1E+G!H<#HT-S@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A
M:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B3R!A<G%U:79O("5S(&1E
M=F5R:6$@8V]N=&5R(&%L9W5N<R!A=')I8G5T;W,@)7,N(@H*(SH@;&EB+U9&
M4R]F:6QE+G!H<#HQ-3(*;7-G:60@(E1H92!F:6QE(&-A;B!N;W0@8F4@8V]P
M:65D(&]N=&\@:71S96QF+B(*;7-G<W1R(")/(&9I8VAE:7)O(&[C;R!P;V1E
M('-E<B!C;W!I861O('!A<F$@<VD@<'+S<')I;RXB"@HC.B!L:6(O2&]R9&4O
M1&%T82YP:'`Z,C8P"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T
M82XB"FUS9W-T<B`B3R!F:6-H96ER;R!NXV\@8V]N=.EM(&1A9&]S+B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4
M:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E
M+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R(")!8F%I>&\@97-TXV\@;W,@8V%B
M9>=A;&AO<R!D97-T82!M96YS86=E;2]M96YS86=E;2!R9F,X,C(N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I
M9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@
M<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R
M;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD
M+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L
M86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R
M(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET
M)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB
M4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO
M=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO
M=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*
M;7-G<W1R("(B"B)/(&UO9&\@9&4@96-RXR!I;G1E:7)O(&-A=7-A('!R;V)L
M96UA<R!N;R!);G1E<FYE="!%>'!L;W)E<BP@9&5V:61O(&$@97)R;W,@(@HB
M;F\@;F%V96=A9&]R('%U92!NXV\@8V]N<V5G=6EM;W,@=6QT<F%P87-S87(N
M("!0;V1E('-U<F=I<B!L:7AO+"!P;V1E;2`B"B)D97-A<&%R96-E<B!F=6YC
M:6]N86QI9&%D97,@9&\@961I=&]R(&4O;W4@;R!S974@;F%V96=A9&]R('!O
M9&4@86)O<G1A<BX@4V4@(@HB;R!S974@<VES=&5M82#I('5M(%=I;F1O=W,@
M.7@L(.D@;75I=&\@<')O=N%V96P@<75E(&]B=&5N:&$@=6T@)T=E;F5R86P@
M(@HB4')O=&5C=&EO;B!&875L="<@92!P<F5C:7-E(&1E(')E:6YI8VEA<B!O
M('-I<W1E;6$N7%QN7%QN1F]I(&%V:7-A9&\N("!0;W(@(@HB9F%V;W(@<')E
M<W-I;VYE($]+('-E(&%I;F1A(&%S<VEM('%U:7-E<B!E>'!E<FEM96YT87(@
M;R!E9&ET;W(@9&4@96-RXR`B"B)I;G1E:7)O+B(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HQ,#DW('!O+W1R86YS;&%T:6]N+G!H<#HQ,C,U"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!H96QP(&9I;&4@)7,@9&ED;B=T('-T87)T('=I
M=&@@/#]X;6PB"FUS9W-T<B`B3R!F:6-H96ER;R!D92!A:G5D82`E<R!NXV\@
M8V]M9>=A(&-O;2`\/WAM;"(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HX.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B
M965N(&1E;&5T960N(@IM<V=S='(@(D$@:61E;G1I9&%D92!<(B5S7"(@9F]I
M(')E;6]V:61A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O
M;FQY(@IM<V=S='(@(D%P96YA<R!O(&QA9&\@97-Q=65R9&\B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ-#8*;7-G:60@(B(*(E1H92!L;V-A=&EO
M;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R
M>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B"B)!(&QO8V%L:7IAY^-O(&1O
M(&%R<75I=F\@97AE8W5TX79E;"!D92!';G501R!T96T@9&4@<V5R(&EN9&EC
M861A(.`@8VQA<W-E("(*(D-R>7!T7W!G<#HZ+B(*"B,Z(&QI8B](;W)D92]-
M24U%+TU$3BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M
M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H
M87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T
M:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB
M"FUS9W-T<B`B(@HB02!M96YS86=E;2!E;G9I861A(&5M("5S('!A<F$@)7,@
M8V]M(&%S<W5N=&\@7"(E<UPB(&9O:2!M;W-T<F%D82Y<;B(*(D[C;R!HX2!G
M87)A;G1I82!D92!Q=64@82!M96YS86=E;2!T96YH82!S:61O(')E86QM96YT
M92!L:61A(&]U(&-O;7!R965N9&ED82XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3@W.`IM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T
M;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(D\@;F]M92!A('5S87(@<75A
M;F1O(&QI9V%N9&\@X"!PX6=I;F$@9&4@8V]M<&]S:>?C;R(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z,3(S,0IM<V=I9"`B5&AE(&]P96YS<VP@
M;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z
M.B!C;&%S<RXB"FUS9W-T<B`B3R!M\V1U;&\@;W!E;G-S;"#I(&YE8V5S<^%R
M:6\@<&%R82!A(&-L87-S92!(;W)D95]#<GEP=%]S;6EM93HZ+B(*"B,Z(&QI
M8B](;W)D92]0<F5F<RYP:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C
M875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B
M;&4@<VEZ92(*;7-G<W1R("(B"B)!(&]PY^-O(%PB)7-<(B!NXV\@</1D92!S
M97(@9W5A<F1A9&$L('!O:7,@;W,@<V5U<R!D861O<R!E>&-E9&5M(&$@9&EM
M96YSXV\@(@HB;>%X:6UA('!E<FUI=&ED82(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]D96(N<&AP.C,R(&QI8B](;W)D92]-24U%+U9I97=E<B]E;G-C
M<FEP="YP:'`Z,S4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS<&]W97)P
M;VEN="YP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS=V]R9"YP
M:'`Z,S(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E
M("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B
M"B)/('!R;V=R86UA('5S861O('!A<F$@=F5R(&5S=&4@=&EP;R!D92!D861O
M<R`H)7,I(&[C;R!F;VD@96YC;VYT<F%D;R!N;R`B"B)S:7-T96UA+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S
M='(@(D%P96YA<R!O<R!L861O<R!E<W%U97)D;R!E(&1I<F5I=&\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X
M"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B07!E
M;F%S(&\@;&%D;R!D:7)E:71O(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U
M;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S
M7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B3R!S97)V:61O<B!<(B5S
M7"(@9F]I(')E;6]V:61O+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN
M<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB
M(&AA<R!B965N('-A=F5D+B(*;7-G<W1R(")/('-E<G9I9&]R(%PB)7-<(B!F
M;VD@9W5A<F1A9&\N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E
M96X@<F5M;W9E9"XB"FUS9W-T<B`B3R!P961I9&\@9&4@<W5B<V-R:>?C;R!D
M92`E<R!F;VD@<F5M;W9I9&\N(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="YP:'`Z,CDP"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E
M>&ES="XB"FUS9W-T<B`B02!L:6YH82!I;F1I8V%D82!NXV\@97AI<W1E+B(*
M"B,Z(&QI8B]61E,O<W%L+G!H<#HQ,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS
M9W-T<B`B3R!A<G%U:79O('1E;7!O<N%R:6\@7"(E<UPB(&[C;R!E>&ES=&4N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB
M"FUS9W-T<B`B07!E;F%S(&]S(&QA9&]S('-U<&5R:6]R(&4@:6YF97)I;W(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R(")!<&5N
M87,@;R!L861O('-U<&5R:6]R(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C,P
M-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE
M('!R979I;W5S('-T97`N(@IM<V=S='(@(D]S(&1A9&]S(&-A<G)E9V%D;W,@
M<&5R9&5R86TM<V4@9&5S9&4@;R!P87-S;R!A;G1E<FEO<BXB"@HC.B!L:6(O
M2&]R9&4O1&%T82]C<W8N<&AP.C(T,"!L:6(O2&]R9&4O1&%T82]T<W8N<&AP
M.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A
M=F5D+B(*;7-G<W1R(")/(&%R<75I=F\@8V%R<F5G861O(&[C;R!P]&1E('-E
M<B!G=6%R9&%D;RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-#@@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$P.0IM<V=I9"`B5&AE
M('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(D\@8FQO8V\@=V5A=&AE<BYC;VT@;N-O(&5S=.$@9&ES<&]N[79E;"XB"@HC
M.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E
M(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R(").XV\@:.$@;W#G]65S
M(&1I<W!O;NUV96ES+B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H
M<#HS-#$*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D
M:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R(").XV\@:.$@<&%R=&5S('%U92!P
M;W-S86T@<V5R(&UO<W1R861A<R!E;2!L:6YH82XB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,30P,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A
M<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V
M92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE
M<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@HB2.$@9&5M87-I861O<R!C87)A8W1E
M<F5S(&YE<W1E(&-A;7!O+B!);G1R;V1U>FEU("5S(&-A<F%C=&5R97,[('1E
M;2!D92`B"B)I;G1R;V1U>FER(&UE;F]S(&1O('%U92`E<RXB"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3`V,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!D;V5S;B=T('EE="!E>&ES="!A(&AE;'`@9FEL92!F;W(@)7,N(@IM<V=S
M='(@(D[C;R!E>&ES=&4@86EN9&$@=6T@87)Q=6EV;R!D92!A:G5D82!P87)A
M("5S+B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@
M7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(D]C;W)R974@=6T@
M<')O8FQE;6$@;F$@861IY^-O(&1E(%PB)7-<(B!A;R!S:7-T96UA.B`E<R(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E
M<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*(D]C;W)R974@=6T@
M<')O8FQE;6$@86\@;&EM<&%R(&]S(&1A9&]S(&1O('5T:6QI>F%D;W(@7"(E
M<UPB(&1O('-I<W1E;6$N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@
M7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(D]C;W)R974@=6T@
M<')O8FQE;6$@;F$@<F5M;^?C;R!D92!<(B5S7"(@9&\@<VES=&5M82XB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@
M(D]C;W)R974@=6T@<')O8FQE;6$@86\@86-T=6%L:7IA<B!<(B5S7"(Z("5S
M+B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX.#@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P
M;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R("(B"B)(;W5V92!U
M;2!P<F]B;&5M82!C;VT@;R!C87)R96=A;65N=&\@9&\@9FEC:&5I<F\Z("5S
M(&[C;R!F;VD@8V%R<F5G861O+B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H
M<#HX.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@
M=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB
M"FUS9W-T<B`B(@HB3V-O<G)E=2!U;2!P<F]B;&5M82!C;VT@;R!C87)R96=A
M;65N=&\@9&\@87)Q=6EV;SH@3R`E<R!E>&-E9&4@;R!T86UA;FAO("(*(FWA
M>&EM;R!P97)M:71I9&\@*"5D(&)Y=&5S*2XB"@HC.B!L:6(O2&]R9&4O0G)O
M=W-E<BYP:'`Z.#DU"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@
M;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(B(*(D]C;W)R974@
M=6T@<')O8FQE;6$@8V]M(&\@8V%R<F5G86UE;G1O(&1O(&%R<75I=F\Z($\@
M)7,@9F]I(&%P96YA<R`B"B)P87)C:6%L;65N=&4@8V%R<F5G861O+B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R
M="(*;7-G<W1R(")/8V]R<F5U('5M(&5R<F\@86\@;6]S=')A<B!E<W1A('!A
M<G1E(&1A(&UE;G-A9V5M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HS.2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C0X
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT
M86-T(&1A=&$N(@IM<V=S='(@(D]C;W)R974@=6T@97)R;R!A;R!I;7!O<G1A
M<B!D861O<R!D92!C;VYT86-T;RXB"@HC.B!L:6(O2&]R9&4O1&%T82]I;6,N
M<&AP.C,Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B3V-O<G)E=2!U;2!E<G)O(&%O
M(&EM<&]R=&%R(&1A9&]S(&E#86QE;F1A<BXB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C<Y"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@
M=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@
M82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@HB3V-O<G)E=2!U;2!E
M<G)O(&YO(&9O<FUU;.%R:6\@9&4@8V]N9FEG=7)AY^-O+B!486QV97H@=&5N
M:&$@;VUI=&ED;R!U;2!C86UP;R`B"B)O8G)I9V%T\W)I;RXB"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3$P-R!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$Q,R!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,3(T-0HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3(U,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R
M;W(@;W!E;FEN9R!T:&4@9FEL92`E<RX@5')Y(')U;FYI;F<@=')A;G-L871I
M;VXN<&AP('=I=&@@=&AE("(*(F9L86<@+60@=&\@<V5E(&%N>2!E<G)O<B!M
M97-S86=E<R!F<F]M('1H92!X;6P@<&%R<V5R+B(*;7-G<W1R("(B"B)/8V]R
M<F5U('5M(&5R<F\@86\@86)R:7(@;R!A<G%U:79O("5S+B!%>'!E<FEM96YT
M92!E>&5C=71A<B!T<F%N<VQA=&EO;BYP:'`@(@HB8V]M(&$@;W#GXV\@+60@
M<&%R82!C;VYS96=U:7(@=F5R(&%S(&UE;G-A9V5N<R!D92!E<G)O(&1O(&%N
M86QI<V%D;W(@6$U,+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M
M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A
M<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B)/8V]R<F5U('5M
M(&5R<F\@86\@<F5A;&EZ87(@82!F=6[GXV\@9&4@;&EV<F\@9&4@96YD97)E
MYV]S(&5S<&5C:69I8V%D82X@4&]R("(*(F9A=F]R('1E;G1E(&1E(&YO=F\@
M;6%I<R!T87)D92XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB
M"FUS9W-T<B`B(@HB3V-O<G)E=2!U;2!E<G)O(&%O(&%C='5A;&EZ87(@;W,@
M<&]R;65N;W)E<R!D;R!C;VYT86-T;RX@4&]R(&9A=F]R('1E;G1E(&1E("(*
M(FYO=F\@;6%I<R!T87)D92XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0U"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN
M(&QA=&5R+B(*;7-G<W1R("(B"B)/8V]R<F5U('5M(&5R<F\@86\@86-T=6%L
M:7IA<B!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@4&]R(&9A=F]R('1E;G1E
M(&1E("(*(FYO=F\@;6%I<R!T87)D92XB"@HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O
M97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R(")%<W1E
M('-E<G9I9&]R($E-05`@;N-O('-U<&]R=&$@<&%R=&EL:&$@9&4@<&%S=&%S
M+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED
M(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H
M:79E+B(*;7-G<W1R(").XV\@<&%R96-E('-E<B!U;2!A<G%U:79O(')A<B!V
MX6QI9&\N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*
M;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP
M(&9I;&4N(@IM<V=S='(@(D[C;R!P87)E8V4@<V5R('5M(&%R<75I=F\@>FEP
M(';A;&ED;RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$T-`IM<V=I9"`B
M5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N
M(@IM<V=S='(@(D[C;R!P87)E8V4@<V5R('5M82!N^FUE<F\@9&4@8V%R=.-O
M(';A;&ED;RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L
M:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS
M9W-T<B`B(@HB17-T92!C;VYT<F]L861O<B!P97)M:71E(&\@96YV:6\@9&4@
M;65N<V%G96YS(&%T<F%VZ7,@9&\@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L
M:6-K871E;&PN8V]M*2P@=7-A;F1O(&$@05!)($A45%`B"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R
M:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S
M;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB17-T92!C;VYT<F]L861O
M<B!P97)M:71E(&\@96YV:6\@9&4@;65N<V%G96YS(&%T<F%VZ7,@9&\@<VUS
M,FUA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2P@=7-A;F1O(&$@05!)
M($A45%`B"@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP
M.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B
M"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I
M<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H
M:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"B)%<W1E(&-O;G1R;VQA
M9&]R('!E<FUI=&4@;R!E;G9I;R!D92!M96YS86=E;G,@=FEA(%--5%`@871R
M87;I<R!D82!6;V1A9F]N92`B"B))=.%L:6$@92!A<&5N87,@<&%R82!N^FUE
M<F]S(%9O9&%F;VYE+B!%>&EG92!U;6$@8V]N=&$@9&4@8V]R<F5I;R`B"B)E
M;&5C='+S;FEC;R!N82!6;V1A9F]N92!)=.%L:6$@*&AT='`Z+R]W=W<N,3DP
M+FET*2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3<X(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,#4W(&QI8B](;W)D92]&;W)M+G!H<#HQ,#@V"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,3$U(&QI8B](;W)D92]&;W)M+G!H<#HQ,3@R(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,C4V"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,S`U(&QI8B](;W)D92]&;W)M+G!H<#HQ-#`P(&QI8B](;W)D92]&;W)M+G!H
M<#HQ-34Y"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#0P(&QI8B](;W)D92]&
M;W)M+G!H<#HQ.34Y(&QI8B](;W)D92]&;W)M+G!H<#HR,#`V"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,#,P(&QI8B](;W)D92]&;W)M+G!H<#HR,#<Y(&QI
M8B](;W)D92]&;W)M+G!H<#HR,34P"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M,C(R(&QI8B](;W)D92]&;W)M+G!H<#HR-#`Y(&QI8B](;W)D92]&;W)M+G!H
M<#HR-#4S"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-C4V(&QI8B](;W)D92]&
M;W)M+G!H<#HR.#(W(&QI8B](;W)D92]&;W)M+G!H<#HS,3,V"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HS-S(S(&QI8B](;W)D92]&;W)M+G!H<#HS-S,Q"FUS
M9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R(")%<W1E(&-A
M;7!O(.D@;V)R:6=A=/-R:6\N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P
M-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R
M<RXB"FUS9W-T<B`B17-T92!C86UP;R!P;V1E(&-O;G1E<B!A<&5N87,@:6YT
M96ER;W,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,3<*;7-G:60@(E1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L
M;VXN(@IM<V=S='(@(D5S=&4@8V%M<&\@<&]D92!A<&5N87,@8V]N=&5R(&[Z
M;65R;W,@92!O('/M;6)O;&\@9&]I<RUP;VYT;W,N(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(D5S=&4@8V%M<&\@<&]D92!C
M;VYT97(@87!E;F%S('9A;&]R97,@;V-T86ES+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,3(S"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM
M82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R
M("(B"B)%<W1E(&-A;7!O('1E;2!D92!C;VYT97(@=6UA(&QI<W1A(&1E(&EN
M=&5I<F]S('-E<&%R861O<R!P;W(@97-P8>=O<R!O=2`B"B)V[7)G=6QA<RXB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3@Y"FUS9VED(")4:&ES(&9I96QD
M(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(D5S=&4@8V%M<&\@
M=&5M(&1E('-E<B!U;2!N^FUE<F\@=N%L:61O+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR.#,U"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I
M;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA
M;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*(D5S=&4@8V%M<&\@=&5M
M(&1E(&-O;G1E<B!U;2!C\V1I9V\@9&4@8V]R(&YO(&9O<FUA=&\@4D="(&AE
M>&%D96-I;6%L+"!P;W(@(@HB97AE;7!L;R`G(S$R,S1A9B<N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E
M861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R(")%<W1E(&UO9&5L;R!JX2!F
M;VD@<')O8V5S<V%D;RXB"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R("))
M<W1O(.D@)7,N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT,S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O
M8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E
M;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O
M=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L
M:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*(D5S=&4@Z2!U;2!O
M8FIE8W1O($MO;&%B($=R;W5P=V%R92X@4&%R82!V97(@97-T92!O8FIE8W1O
M('!R96-I<V$@9&4@=6T@(@HB8VQI96YT92!D92!C;W)R96EO(&5L96-T<O-N
M:6-O('%U92!C;VYH9>=A(&\@9F]R;6%T;R!+;VQA8B!'<F]U<'=A<F4N(%!A
M<F$@(@HB=6UA(&QI<W1A(&1E(&-L:65N=&5S(&1E(&-O<G)E:6\@96QE8W1R
M\VYI8V\@;F5S<V%S(&-I<F-U;G-TXFYC:6%S('9I<VET92`E<R(*"B,Z(&QI
M8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HU.#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R
M('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(D5S=&$@
M;65N<V%G96T@9F]I(&5S8W)I=&$@;G5M(&/S9&EG;R`H)7,I(&1I9F5R96YT
M92!D;R!S974N(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,C8*;7-G
M:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R
M(")%<W1E(&[Z;65R;R!P<F5C:7-A(&1E('-E<B!P96QO(&UE;F]S('5M+B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S`T"FUS9VED(")4:&ES('-C<FEP
M="!M=7-T(&)E(')U;B!F<F]M('1H92!C;VUM86YD(&QI;F4N(@IM<V=S='(@
M(D5S=&4@7")S8W)I<'1<(B!T96T@<V5R(&5X96-U=&%D;R!A('!A<G1I<B!D
M92!U;6$@;&EN:&$@9&4@8V]M86YD;W,N(@H*(SH@;&EB+TAO<F1E+T-O;7!R
M97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O
M;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B17-T92!S97)V
M:61O<B!NXV\@8V]N<V5G=64@9&5S8V]M<')I;6ER(&%R<75I=F]S('II<"!O
M=2!G>FEP+B(*"B,Z(&QI8B](;W)D92]296=I<W1R>2YP:'`Z,30W"FUS9VED
M(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S
M='(@(D5S=&4@<VES=&5M82!E;F-O;G1R82US92!D97-A8W1I=F%D;RXB"@HC
M.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU
M92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R(")%<W1A('9A;&]R('1E;2!D
M92!S97(@=6T@;OIM97)O+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I
M8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D
M(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B17-T82!J86YE;&$@
M=&5M(&1E('-E<B!C:&%M861A(&$@<&%R=&ER(&1E('5M82!J86YE;&$@9&4@
M3W#G]65S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C0*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B5')O=F]A9&$B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(R"FUS9VED(")4:6-K971S(@IM
M<V=S='(@(D)I;&AE=&5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,C<*
M;7-G:60@(E1I;64B"FUS9W-T<B`B1&%T82](;W)A(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,P.`IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G
M<W1R(")396=U:6UE;G1O(%1E;7!O<F%L(@H*(SH@;&EB+T)L;V-K+W1I;64N
M<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R(")&;W)M871O(&1O
M('1E;7!O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U,S@*;7-G:60@(E1I
M;64@<V5L96-T:6]N(@IM<V=S='(@(E-E;&5CY^-O(&1A=&$O:&]R82(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(R,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*
M;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(E1I;6]R+4QE<W1E(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K
M+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(E3M='5L;R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*
M;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B5.UT=6QO("AD:6-A
M*3HB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM
M<V=I9"`B5&\B"FUS9W-T<B`B4&%R82(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HV,C8*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT
M:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M
M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*
M(E!A<F$@<V5L96-C:6]N87(@;?IL=&EP;&]S(&ET96YS+"!C87)R96=U92!E
M;2!#;VYT<F]L("A00RD@;W4@0V]M;6%N9"`H36%C*2`B"B)E;G%U86YT;R!C
M;&EC87(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y.0IM
M<V=I9"`B5&]D87DB"FUS9W-T<B`B2&]J92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,
M(%-O=7)C92(*;7-G<W1R(")4<F]C87(@1F]N=&4@2%1-3"(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(R,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@
M(E1O9V\B"FUS9W-T<B`B4F5P^F)L:6-A(%1O9V]L97-A(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(R-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B
M5&]K96QA=2(*;7-G<W1R(")4;W%U96QA=2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS,#$*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(D%M
M86YHXR(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,CD@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S='(@(E)E:6YO(&1O(%1O;F=A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`B5&]P;R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F
M<F%M92`H7W1O<"DB"FUS9W-T<B`B36]L9'5R82!D92!T;W!O("A?=&]P*2(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV-3<*;7-G:60@(E1R86YS;&%T960B
M"FUS9W-T<B`B5')A9'5Z:61A<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV,PIM<V=I9"`B5')A;G-L871I;VYS(@IM<V=S='(@(E1R861UY_5E<R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(R-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B5')I;F1A
M9&4@92!4;V)A9V\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<Y,0IM<V=I
M9"`B5')U92!O<B!F86QS92(*;7-G<W1R(")697)D861E:7)O(&]U(&9A;'-O
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU
M-PIM<V=I9"`B5'4B"FUS9W-T<B`B,ZHB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C(X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA(@IM
M<V=S='(@(E)E</IB;&EC82!D82!4=6[M<VEA(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(S,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5R:V5Y
M(@IM<V=S='(@(E)E</IB;&EC82!D82!4=7)Q=6EA(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM
M<V=S='(@(E1U<F-O("A)4T\M.#@U.2TY*2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM96YI
M<W1A;B(*;7-G<W1R(")4=7)Q=65M96YI<W3C;R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS
M(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("));&AA<R!4=7)C87,@92!#
M86EC;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,S(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B5'5V86QU(@H*(SH@
M;&EB+TAO<F1E+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E
M.B`B"FUS9W-T<B`B17-C<F5V82!A('-U82!E<V-O;&AA.B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3<*;7-G:60@(E4N5BX@:6YD97@Z
M("(*;7-G<W1R("+-;F1I8V4@52Y6+CH@(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*
M;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T
M(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B55),(&1O('-E=2!R
M96QA=/-R:6\@9&4@97-T861O(&1O(&5N=FEO(&1E(%PB<V-R:7!T<UPB(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM
M<V=I9"`B55),.B(*;7-G<W1R(")54DPZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(S-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM
M<V=S='(@(E)E</IB;&EC82!D;R!59V%N9&$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S,*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A:6YE
M(@IM<V=S='(@(E5C<N)N:6$B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,S-0IM
M<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R
M(").XV\@9F]I('!O<W/M=F5L(&%C961E<B#@('!A<W1A(%9&4RXB"@HC.B!L
M:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@
M861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*
M;7-G<W1R("(B"B).XV\@9F]I('!O<W/M=F5L(&%D:6-I;VYA<B!I;F9O<FUA
MY^-O(&1E('5T:6QI>F%D;W(@97AT<F$@87%U86YD;R!D82`B"B)S=6)S8W)I
MY^-O+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS,C8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@;75D87(@87,@
M<&5R;6ES<_5E<R!D;R!A<G%U:79O(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&
M4R]F:6QE+G!H<#HS,#@@;&EB+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@
M5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@;75D
M87(@87,@<&5R;6ES<_5E<R!D;R!A<G%U:79O(%9&4R`E<R\E<RXB"@HC.B!L
M:6(O5D93+V9T<"YP:'`Z-C<R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@
M;75D87(@<&%R82`E<RXB"@HC.B!L:6(O2&]R9&4O075T:"]S<6PN<&AP.C,W
M,0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS
M9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!L:6=A<B!A;R!S97)V:61O<B!344PN
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<U-@IM<V=I9"`B56YA8FQE('1O(&-O
M;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@;&EG
M87(@=7-A;F1O(%-33"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$U."!L:6(O
M5D93+V9I;&4N<&AP.C$V,R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ.#@*(SH@
M;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3DS(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C(P,0IM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@
M(D[C;R!F;VD@<&]S<^UV96P@8V]P:6%R(&\@87)Q=6EV;R!61E,N(@H*(SH@
M;&EB+U9&4R]F='`N<&AP.C,P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(").
MXV\@9F]I('!O<W/M=F5L(&-R:6%R(&$@<&%S=&$@5D93(%PB)7-<(BXB"@HC
M.B!L:6(O5D93+V9I;&4N<&AP.C(W-R!L:6(O5D93+VUU<W%L+G!H<#HR-3@@
M;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C0X"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@
M8W)I87(@82!P87-T82!61E,N(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3(T
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R(").
MXV\@9F]I('!O<W/M=F5L(&-R:6%R(&\@87)Q=6EV;R!61E,N(@H*(SH@;&EB
M+U9&4R]F:6QE+G!H<#HQ.3@*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP
M='D@5D93(&9I;&4N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@8W)I87(@
M=6T@87)Q=6EV;R!61E,@=F%Z:6\N(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S
M+W1A<BYP:'`Z-S8@;&EB+TAO<F1E+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS
M9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R(").XV\@
M9F]I('!O<W/M=F5L(&1E<V-O;7!R:6UI<B!O<R!D861O<RXB"@HC.B!L:6(O
M5D93+V9T<"YP:'`Z,C,V"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB
M"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(%PB)7-<(BP@<&]I
M<R!A('!A<W1A(&[C;R!E<W3A('9A>FEA+B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z-SD@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@
M(D[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!<(B5S7"(Z("5S+B(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z,C4T(&QI8B]61E,O<W%L+G!H<#HS,30@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,S$Q"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,R-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@
M9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R(").XV\@9F]I('!O<W/M
M=F5L(')E;6]V97(@)7,L('!O:7,@82!P87-T82!NXV\@97-TX2!V87II82(*
M"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,T,"!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HS-#0*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R
M>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!R96UO
M=F5R(&$@<&%S=&$@5D93(')E8W5R<VEV86UE;G1E+B(*"B,Z(&QI8B]61E,O
M9FEL92YP:'`Z,C8P(&QI8B]61E,O;75S<6PN<&AP.C,R,B!L:6(O5D93+VUU
M<W%L+G!H<#HS,S4*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,S0S(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C,S-@IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(')E;6]V97(@
M82!P87-T82!61E,N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C,S.2!L:6(O5D93
M+W-Q;"YP:'`Z,S4Q"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(D[C;R!F;VD@<&]S
M<^UV96P@<F5M;W9E<B!A('!A<W1A(%9&4SH@)7,N(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C$W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E
M;"!R96UO=F5R(&\@87)Q=6EV;R!61E,@7"(E<UPB+B(*"B,Z(&QI8B]61E,O
M9FEL92YP:'`Z,C(V(&QI8B]61E,O<W%L+G!H<#HR,3`@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,38W"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$X,"!L:6(O5D93+VUU
M<W%L+G!H<#HQ.#<@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S<P"B,Z(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C,W.`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@9FEL92XB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&\@
M87)Q=6EV;R!61E,N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C,R.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L
M>3H@)7,N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!R96-U
M<G-I=F%M96YT93H@)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<R,`IM<V=I
M9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!D971E<FUI;F%R(&$@<&%S=&$@8V]R
M<F5N=&4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,#,*;7-G
M:60@(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS
M9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!E>'1R86ER(&]S('!O<FUE;F]R97,@
M9&\@8V5R=&EF:6-A9&\B"@HC.B!L:6(O3F5T+TE-4U`N<&AP.C0U,2!L:6(O
M3F5T+TE-4U`O075T:"YP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("))
M;7!O<W/M=F5L(&QE<B!A(&1E9FEN:>?C;R!D92`E<RXB"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C$R.2!L:6(O5D93+V9I;&4N<&AP.C$S-"!L:6(O5D93+W-Q
M;%]F:6QE+G!H<#HQ-3@*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,38S"FUS
M9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`B3N-O(&9O
M:2!P;W-S[79E;"!M;W9E<B!O(&%R<75I=F\@5D93+B(*"B,Z(&QI8B]61E,O
M9G1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@
M86)R:7(@;R!A<G%U:79O(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE
M+G!H<#HR,#4@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3(R(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C$R-0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@
M9F]R('=R:71I;F<N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@86)R:7(@
M;R!A<G%U:79O(%9&4R!P87)A(&5S8W)I=&$N(@H*(SH@;&EB+U9&4R]F:6QE
M+G!H<#HV-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW,@IM<V=I9"`B56YA8FQE
M('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@
M86)R:7(@;R!A<G%U:79O(%9&4RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E
M9"!A<F-H:79E+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&%B<FER(&\@
M87)Q=6EV;R!C;VUP<FEM:61O+B(*"B,Z(&QI8B](;W)D92]397-S:6]N2&%N
M9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@
M(@IM<V=S='(@(D[C;R!C;VYS:6=O(&QE<B!O(&%R<75I=F\Z("(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z-3DR"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@
M=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@
M;&5R(&$@<&%S=&$@=F9S<F]O="XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.C$P-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E
M<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM
M<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@<F5N;VUE87(@)7,@8V]M;R`E<SH@
M82!P87-T82!D92!D97-T:6YO(&KA(&5X:7-T92(*"B,Z(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C(X-0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(')E;F]M96%R(&$@
M<&%S=&$@5D93+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HR-3$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E
M<RXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!R96YO;65A<B!A('!A<W1A
M(%9&4SH@)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C(X,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!R96YO;65A<B!O(&%R<75I=F\@
M5D93(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C4S,R!L:6(O5D93
M+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S
M[79E;"!R96YO;65A<B!O(&%R<75I=F\@5D93("5S+R5S+B(*"B,Z(&QI8B]6
M1E,O<W%L+G!H<#HR-#4@;&EB+U9&4R]M=7-Q;"YP:'`Z,C$S(&QI8B]61E,O
M;75S<6PN<&AP.C0U,@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR-S<@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(')E;F]M96%R
M(&%R<75I=F\@5D93+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N
M<&AP.C4P"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T
M<B`B3N-O(&9O:2!P;W-S[79E;"!E>&5C=71A<B`G;6MI<V]F<R<N(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N
M86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@
M(D[C;R!F;VD@<&]S<^UV96P@8V]N=F5R=&5R(&5S=&4@9&]C=6UE;G1O(%=O
M<F0B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,3(R(&QI8B]61E,O9G1P+G!H<#HQ
M,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!E<V-R979E
M<B!A<G%U:79O(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ
M,3(*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A
M:6QE9"DN(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@97-C<F5V97(@;R!A
M<G%U:79O(%9&4R`H8V]P>2@I(&9A;&AO=2DN(@H*(SH@;&EB+U9&4R]F:6QE
M+G!H<#HR,#D@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3,P(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C$S-0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M(&1A=&$N(@IM<V=S='(@(D[C;R!C;VYS:6=O(')E;6]V97(@)R5S)SH@)7,N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(E-U8FQI;FAA9&\B"@HC.B!T
M96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B
M"FUS9W-T<B`B1&5S9F%Z97(@06QT97)AY_5E<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(D1E<V9A>B!A('-U82#Z;'1I;6$@
M86/GXV\B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*;7-G:60@(E5N
M97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@
M(@IM<V=S='(@(E)E<W!O<W1A(&EN97-P97)A9&$@9&\@<V5R=FED;W(@;F$@
M8V]N97CC;SH@(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(Q.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S@@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E9"!R97-P
M;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(E)E<W!O<W1A(&EN97-P
M97)A9&$@9&\@<V5R=FED;W(@83H@(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-C0*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B
M4V5M(&-A=&5G;W)I82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS
M9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B56YI8V]D92`H551&+3@I
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-38*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(D5M:7)A
M9&]S(,%R86)E<R!5;FED;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C,X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM
M<V=S='(@(E)E:6YO(%5N:61O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(T,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R(*
M;7-G<W1R(")%<W1A9&]S(%5N:61O<R!D82!!;>ER:6-A(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(S.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B
M56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@
M(DEL:&%S($UE;F]R97,@1&ES=&%N=&5S(&1O<R!%<W1A9&]S(%5N:61O<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV,2!L:6(O0FQO8VLO
M;65T87(N<&AP.C<Q"FUS9VED(")5;FET<R(*;7-G<W1R(")5;FED861E<R(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q."!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HT,3D*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-3@*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B1&5S8V]N:&5C:61O(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@
M(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B
M87!I;7-G:60@*$E$(&1E($UE;G-A9V5M(&1E($%022DN(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@
M8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B8VQI;7-G
M:60@9&5S8V]N:&5C:61O("A)1"!D92!-96YS86=E;2!D92!#;&EE;G1E*2XB
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,34P,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;FMN;W=N(&-O;6UA;F0Z("5S(@IM<V=S='(@(D-O;6%N9&\@9&5S
M8V]N:&5C:61O.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-#8*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S
M='(@(D9O:2!F;W)N96-I9&$@=6UA(&QO8V%L:7IAY^-O(&1E<V-O;FAE8VED
M82XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM
M<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B
M3F]M92!D92!U=&EL:7IA9&]R(&]U('!A;&%V<F$M<&%S<V4@97)R861O<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-PIM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS
M9W-T<B`B4F5M;W9E<B!L:6=AY^-O(&1O(&5L96UE;G1O(&-O<G)E;G1E(@H*
M(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H<#HR.38*;7-G:60@(E5N;F%M960B
M"FUS9W-T<B`B4V5M(&YO;64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R
M:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC
M86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E
M92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H
M;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C
M;&EP8F]A<F0N(@IM<V=S='(@(B(*(E!O<B!R87KU97,@9&4@<V5G=7)A;N=A
M+"!<(G-C<FEP='-<(B!S96T@<')I=FELZ6=I;R!NXV\@<&]D96T@86-E9&5R
M(&$@(@HB0V]R=&%R+T-O<&EA<B]#;VQA<B!P<F]G<F%M871I8V%M96YT92X@
M0V%R<F5G=64@96T@3TL@<&%R82!V97(@=6UA(&YO=&$@(@HB=.EC;FEC82!E
M;2!M;WII;&QA+F]R9R!Q=64@;&AE(&UO<W1R87+A(&-O;6\@875T;W)I>F%R
M('5M(%PB<V-R:7!T7"(@82`B"B)A8V5D97(@86]S(')E8V]R=&5S+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(E)E;6]V97(@8V]L;W)A
MY^-O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.#8@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HY,C8*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HY,S(*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G
M<W1R(")%>'1E;G/C;R!NXV\@4W5P;W)T861A(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C8U-PIM<V=I9"`B56YT<F%N<VQA=&5D(@IM<V=S='(@(E!O<B!T
M<F%D=7II<B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P-B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C$X,PHC.B!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@(DUO9&EF:6-A<B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(D%C='5A;&EZ87(@
M)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"FUS
M9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R(")!8W1U86QI>F%R('5T:6QI>F%D
M;W(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$S-R!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HR,3<@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB
M(&%C='5A;&EZ861O+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#DR('!O
M+W1R86YS;&%T:6]N+G!H<#HQ,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P
M9&%T:6YG("5S(&AE;'`@9FEL92!F;W(@)7,N(@IM<V=S='(@(D%C='5A;&EZ
M86YD;R!A<G%U:79O(&1E(&%J=61A("5S('!A<F$@)7,N(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z.#$*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E
M;&5T960N(@IM<V=S='(@(EPB4V-R:7!T7"(@9&4@86-T=6%L:7IAY^-O(')E
M;6]V:61O+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#$@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$X,@IM<V=I9"`B57!L;V%D
M(@IM<V=S='(@(E5P;&]A9"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M.#D*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE
M<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R(")#87)R96=A9&]S(&YO('-E<G9I
M9&]R('1O9&]S(&]S(&%R<75I=F]S(&1E(&EN<W1A;&'GXV\@9&4@87!L:6-A
MY_5E<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM
M<V=S='(@(DQE=')A<R!L871I;F%S(&5M(&UA:?IS8W5L87,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X
M"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(D[Z;65R;W,@
M<F]M86YO<R!E;2!M86GZ<V-U;&%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(T,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G
M<W1R(")297#Z8FQI8V$@3W)I96YT86P@9&\@57)U9W5A:2(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HS-2!P;R]T<F%N<VQA=&EO;BYP:'`Z.3(@<&\O=')A
M;G-L871I;VXN<&AP.CDS"FUS9VED(")5<V%G93HB"FUS9W-T<B`B571I;&EZ
M8>?C;SHB"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H
M<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS
M9W-T<B`B57-A<B!O($-O<G)E;G1E.B`E<R(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B
M57-A<B!34TPN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I
M9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0
M('-E<G9E<BXB"FUS9W-T<B`B(@HB57-A<B!S92!O(&YO;64@9&4@=71I;&EZ
M861O<B!O=2!A('!A;&%V<F$M<&%S<V4@9F]R96T@9&EF97)E;G1E<R!N;R!S
M97)V:61O<B`B"B))35-0+B(*"B,Z(&QI8B](;W)D92]296=I<W1R>2YP:'`Z
M-C$X"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO
M<FES960@9F]R("5S+B(*;7-G<W1R(")5=&EL:7IA9&]R("5S(&[C;R!E<W3A
M(&%U=&]R:7-A9&\@<&%R82`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*
M;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R
M8>?C;R!D92!5=&EL:7IA9&]R97,B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN
M<&AP.C(U,0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(D]PY_5E<R!D
M;R!5=&EL:7IA9&]R(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E<B!2
M96=I<W1R871I;VXB"FUS9W-T<B`B4F5G:7-T;R!D92!5=&EL:7IA9&]R97,B
M"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H
M87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R(")/(%)E
M9VES=&\@9&4@571I;&EZ861O<F5S(&5S=.$@:6YA8W1I=F\N(@H*(SH@861M
M:6XO<&5R;7,O961I="YP:'`Z,3<R(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,C0V"FUS9VED(")5<V5R('!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUI<W/U
M97,@9&\@=71I;&EZ861O<B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ.#(*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4S-B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N
M<&AP.CDX"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z-C@@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(DYO;64@9&4@571I
M;&EZ861O<B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L
M('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X
M:7-T<RXB"FUS9W-T<B`B3R!.;VUE(&1E(%5T:6QI>F%D;W(@7"(E<UPB(&KA
M(&5X:7-T92XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*
M;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(").;VUE(&1E(%5T:6QI>F%D;W(Z
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E
M<FYA;64Z("(*;7-G<W1R(").;VUE(&1E(%5T:6QI>F%D;W(Z("(*"B,Z(&QI
M8B](;W)D92]097)M<R]522YP:'`Z,C$Y"FUS9VED(")5<V5R<R(*;7-G<W1R
M(")5=&EL:7IA9&]R97,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R(")5
M=&EL:7IA9&]R97,@9&\@<VES=&5M83HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5>F)E:VES=&%N
M(@IM<V=S='(@(E)E</IB;&EC82!D;R!5>F)E<75I<W3C;R(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z,3`Q(&QI8B]61E,O9FEL92YP:'`Z,3@X"FUS9VED(")6
M1E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")!('!A<W1A
M(%9&4R!NXV\@97AI<W1E+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ,3@*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(D%U<^IN8VEA(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C@V-@IM<V=I9"`B5F%L:60@;&]C871I;VYS
M(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R(")!<R!L;V-A;&EZ8>?U97,@=N%L
M:61A<R!E;F-O;G1R861A<R!I;F-L=65M.B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-C,X"FUS9VED(")686QI9&ET>2(*;7-G<W1R(")686QI
M9&%D92XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS9VED(")6
M86QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R(")686QO<B!E;2!M
M:6YU=&]S(&$@<&%R=&ER(&1E<W1E(&EN<W1A;G1E+B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HX-38@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q-S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG
M=&@@;V8@)7,N(@IM<V=S='(@(E9A;&]R(&5X8V5D92!O(&-O;7!R:6UE;G1O
M(&WA>&EM;R!D92`E<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T-2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C(V-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,Q
M-0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDR-PIM<V=I9"`B5F%L=65S(@IM
M<V=S='(@(E9A;&]R97,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Q,"!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C$X-PIM<V=I9"`B5F%L=65S('1O('-E;&5C
M="!F<F]M(@IM<V=S='(@(E!O<W/M=F5L('9A;&]R97,@82!E<V-O;&AE<B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B5F%N=6%T=2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S(*;7-G:60@(E9A<FEA8FQE(@IM
M<V=S='(@(E9A<FGA=F5L(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@
M(E9E;F5Z=65L82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C$X
M"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA
M>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B5F5R:69I8V'G
MXV\@9F%L:&]U("T@97-T82!M96YS86=E;2!P;V1E('1E<B!S:61O(&%D=6QT
M97)A9&$N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G
M:60@(E9E<G-I;VXB"FUS9W-T<B`B5F5R<^-O(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(P-0IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S
M='(@(D-O;G1R;VQO(&1E(%9E<G/U97,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A
M;"!A;&EG;B(*;7-G<W1R(")!;&EN:&%M96YT;R!697)T:6-A;"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@
M(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B0V%LYV\@5F5R=&EC86PB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS
M9VED(")697)T:6-A;#HB"FUS9W-T<B`B5F5R=&EC86PZ(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(E9E<GD@
M2&EG:"(*;7-G<W1R(")-=6ET;R!!;'1O(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(T."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FEE="!.86TB
M"FUS9W-T<B`B4F5P^F)L:6-A(%-O8VEA;&ES=&$@9&\@5FEE=&YA;64B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5FEE=&YA;65S92`H
M5DE30TE)*2(*;7-G<W1R(")6:65T;F%M:71A("A625-#24DI(@H*(SH@;&EB
M+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.CDU.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")6:65W("5S(@IM<V=S='(@(E9I<W5A;&EZ87(@)7,B"@HC.B!L:6(O
M0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E
M8B!P86=E(@IM<V=S='(@(E9E<B!U;6$@<.%G:6YA(&5X=&5R;F$B"@HC.B!L
M:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#$X"B,L('!H<"UF;W)M870*
M;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B5FES=6%L:7IA<B!C;VUO("5S
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B
M26QH87,@5FER9V5N<R!"<FETXFYI8V%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(T-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES
M;&%N9',L(%4N4RXB"FUS9W-T<B`B26QH87,@5FER9V5N<R!!;65R:6-A;F%S
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI
M='DB"FUS9W-T<B`B5FES:6)I;&ED861E(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(U,0IM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@
M(E9I<VEB:6QI9&%D93H@(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B
M"FUS9W-T<B`B5F]D869O;F4@273A;&EA('9I82!33510(@H*(SH@;&EB+TAO
M<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED
M(")705).(@IM<V=S='(@(D%625,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]6
M12!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B051%3L?#3R$A
M(2!214U/5D$@3R!<(E-#4DE05%PB($U!3E5!3$U%3E1%($1%("5S+B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(T-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*
M;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(E=A;&QI<R!E($9U
M='5N82(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HR.0IM<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")!=FES;R(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HQ-#4@<&\O=')A;G-L871I;VXN<&AP.C8X
M,2!P;R]T<F%N<VQA=&EO;BYP:'`Z-S$Q"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HW,C4@<&\O=')A;G-L871I;VXN<&AP.C$P-C`@<&\O=')A;G-L871I;VXN
M<&AP.C$P-CD*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P-S<@<&\O=')A;G-L
M871I;VXN<&AP.C$P.#<@<&\O=')A;G-L871I;VXN<&AP.C$P.3<*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C$Q,#<@<&\O=')A;G-L871I;VXN<&AP.C$Q,3,@
M<&\O=')A;G-L871I;VXN<&AP.C$R,S4*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C$R-#4@<&\O=')A;G-L871I;VXN<&AP.C$R-3$@<&\O=')A;G-L871I;VXN
M<&AP.C$R-S$*;7-G:60@(E=A<FYI;F<Z("(*;7-G<W1R(")!=FES;SH@(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM
M<V=I9"`B5V4B"FUS9W-T<B`B-*HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B
M4')E=FESXV\@9&\@5&5M<&\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#$U"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS
M9W-T<B`B1&%D;W,@;65T96]R;VSS9VEC;W,@9F]R;F5C:61O<R!P;W(B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DR"FUS9VED(")796%T:&5R+F-O;2(*
M;7-G<W1R(")796%T:&5R+F-O;2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,V"FUS9VED(")796(B"FUS9W-T<B`B5V5B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,W-@IM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B4.%G
M:6YA(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B
M5V5E:VQY(@IM<V=S='(@(E-E;6%N86QM96YT92(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC;VUE(@IM<V=S='(@(D)E
M;2UV:6YD82AO*2(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(D)E;2UV:6YD82AO*2!A("5S
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S
M+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O
M;64L("5S(@IM<V=S='(@(D)E;2UV:6YD82AO*2P@)7,B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB
M"FUS9W-T<B`B3V-I9&5N=&%L("A)4T\M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DV"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB
M"FUS9W-T<B`B3V-I9&5N=&%L("A)4T\M.#@U.2TQ-2DB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(T-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S
M=&5R;B!386AA<F$B"FUS9W-T<B`B4V%A<F$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#(Y"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC
M871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@
M(E%U92!A<&QI8V'GXV\@9&5V92!O("5S(&UO<W1R87(@87#S<R!A(&5N=')A
M9&$_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@
M(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(E%U
M86P@Z2!O(&-A<F%C=&5R92!D96QI;6ET861O<C\B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHR-`IM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@
M8VAA<F%C=&5R/R(*;7-G<W1R(")1=6%L(.D@;R!C87)A8W1E<F4@9&4@8VET
M8>?C;S\B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H
M('!H87-E<R(*;7-G<W1R(")1=64@9F%S97,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,S"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F
M;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(E%U92!<(G!L=6=I
M;G-<(B!A8W1I=F%R('!A<F$@82!%9&GGXV\@4FEC82XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED
M(")7:61T:"(*;7-G<W1R("),87)G=7)A(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,Q,C0*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R("),
M87)G=7)A(&5M('5N:61A9&5S($-34R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S
M(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI
M;BDZ(@IM<V=S='(@(DQA<F=U<F$@9&\@365N=2`E<R#@(&5S<75E<F1A("AT
M96T@969E:71O(&YA('!R\WAI;6$@96YT<F%D82DZ(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H
M(&]F('1H92!T86)L92(*;7-G<W1R("),87)G=7)A(&1A('1A8F5L82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS
M9VED(")7:61T:"!U;FET(@IM<V=S='(@(E5N:61A9&4@9&4@;&%R9W5R82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U
M"FUS9VED(")7:61T:#HB"FUS9W-T<B`B3&%R9W5R83HB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#8X"FUS9VED(")7:6MI(@IM<V=S='(@(E=I
M:VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@X(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")7:6YD
M(@IM<V=S='(@(E9E;G1O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B5F5N
M=&\@36%T:6YA;"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#`*;7-G:60@
M(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B5F5L;V-I9&%D92!D;R!V
M96YT;R!E;2!N\W,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U-@IM<V=I
M9"`B5VEN9#HB"FUS9W-T<B`B5F5N=&\Z(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(S,`IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(E9E;G1O
M.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O
M;2(*;7-G<W1R(")386)E9&]R:6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,3@R"FUS9VED(")7:7-H;&ES=',B"FUS9W-T<B`B3&ES=&%S(&1E
M($1E<V5J;W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@
M(E=O<FLB"FUS9W-T<B`B5')A8F%L:&\B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$R-"!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(D5N9&5R
M9>=O("A%;7!R96=O*2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(E1E;&5F;VYE
M("A%;7!R96=O*2(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,38Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E=R:71I;F<@=7!D871E9"!H96QP(&9I;&4@=&\@
M)7,N(@IM<V=S='(@(D5S8W)E=F5N9&\@87)Q=6EV;R!D92!A:G5D82!A8W1U
M86QI>F%D;R!P87)A("5S+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,S$*;7-G:60@(E@M4F5F(@IM<V=S='(@(E)E9F5RZFYC:6%S(&-R=7IA
M9&%S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@
M(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R(")297-T<FGG]65S
M($+A<VEC87,@6#4P.78S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU.3(*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T
M<B`B571I;&EZ8>?C;R!D92!#:&%V92!%>'1E;F1I9&$@6#4P.78S(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!3
M=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B3F]M92!!;'1E<FYA
M=&EV;R!D92!3=6IE:71O(%@U,#EV,R(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I
M9FEE<B(*;7-G<W1R("))9&5N=&EF:6-A9&]R($-H879E(&1E(%-U:F5I=&\@
M6#4P.78S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.#(*;7-G
M:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(D5X=&5N<_5E<R!8-3`Y
M=C,B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T
M<B`B04$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,S@V(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,C<*;7-G
M:60@(EE965DB"FUS9W-T<B`B04%!02(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,#`Q"FUS9VED(")986AO;R$@;6%P(@IM<V=S
M='(@(DUA<&$@66%H;V\A(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H
M<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(D%N=6%L;65N=&4B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4R(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR-#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS
M9VED(")996UE;B(*;7-G<W1R("))Z6UE;B(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX.#4*;7-G:60@(EEE<R(*;7-G<W1R(")3
M:6TB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O86=R965M96YT7V)O='1O
M;2YI;F,Z-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(E-I;2P@0V]N
M8V]R9&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@
M6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T
M<B`B(@HB17-TX2!E;2!-3T1/(&1E(%1%6%0N("!5<V4@;R!B;W3C;R!;/#Y=
M('!A<F$@=')O8V%R('!A<F$@;R!M;V1O(%9)4U5!3"XB"@HC.B!L:6(O2&]R
M9&4N<&AP.C$R.3<*;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N
M(@IM<V=S='(@(D[C;R!E<W3A(&%U=&5N=&EC861O+B(*"B,Z(&QI8B](;W)D
M92])9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")9;W4@8V%N(&YO="!H879E('1H
M92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B
M3N-O('!O9&4@=&5R(&\@8V%R86-T97)E("=<7"<@;F\@<V5U(&YO;64@8V]M
M<&QE=&\N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-38@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Y-S8*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L
M:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`B3N-O(&EN=')O9'5Z:74@=6T@
M96YD97)EYV\@9&4@8V]R<F5I;R!E;&5C='+S;FEC;R!VX6QI9&\N(@H*(SH@
M;&EB+TAO<F1E+T1A=&$N<&AP.C(W,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D
M(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*
M;7-G<W1R("(B"B).XV\@;6%P96]U(&YE;FAU;2!C86UP;R!D;R!A<G%U:79O
M(&EM<&]R=&%D;R!P87)A(&]S(&-A;7!O<R!C;W)R97-P;VYD96YT97,@(@HB
M96T@)7,N(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDR,PIM<V=I9"`B66]U
M(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R(")!8V%B;W4@9&4@<V%I
M<BXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(V,0IM<V=I9"`B(@HB66]U
M(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I
M=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R
M;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*(E1E;2!D92!I
M;G1R;V1U>FER('5M(&[Z;65R;R!D92!T96QE;?-V96P@=N%L:61O+"!S\R!C
M;VT@9.UG:71O<RP@;6%S(&-O;2!U;2`B"B(G*R<@;W!C:6]N86P@<&%R82!O
M('!R969I>&\@:6YT97)N86-I;VYA;"XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU
M92XB"FUS9W-T<B`B5&5M(&1E(&EN=')O9'5Z:7(@=6T@=F%L;W(@=N%L:61O
M+B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO
M=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I
M9VYU<',N(@IM<V=S='(@(B(*(E1E;2!D92!C;VYF:6=U<F%R('5M(&UE8V%N
M:7-M;R!BX7-I8V\@<&%R82!$871A5')E92!S92!Q=6ES97(@=7-A<B`B"B)3
M=6)S8W)IY_5E<R(*"B,Z(&QI8B](;W)D92YP:'`Z-#,Q"FUS9VED(")9;W4@
M;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B5&5M(&1E
M(&-O;F9I9W5R87(@=6T@;65C86YI<VUO(&)A<V4@<&%R82!O(%9&4RXB"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U
M(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N
M9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(D1E=F4@9&5S8W)E=F5R
M(&\@<')O8FQE;6$@86YT97,@9&4@96YV:6%R(&\@<F5L873S<FEO+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G
M:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O
M:6YT<R!T;R(*;7-G<W1R(")496T@9&4@:6YT<F]D=7II<B!O(%523"!D;R!R
M96-U<G-O('%U92!E<W1A(&QI9V'GXV\@<V4@<F5F97)E(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M=7-T('-E;&5C
M="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B5&5M(&1E('-E
M;&5C8VEO;F%R('5M('-E<G9I9&]R(&$@<F5M;W9E<BXB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,3D*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M
M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(D1E=F4@97-P96-I9FEC87(@;R!U
M=&EL:7IA9&]R(&$@;&EM<&%R+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM
M<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB
M"FUS9W-T<B`B1&5V92!E<W!E8VEF:6-A<B!O(&YO;64@9&\@=71I;&EZ861O
M<B!A(')E;6]V97(N(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(E1E;2!D92!E<W!E
M8VEF:6-A<B!O(&YO;64@9&\@=71I;&EZ861O<B!A(&%D:6-I;VYA<BXB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@
M=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B5&5M(&1E(&5S<&5C
M:69I8V%R(&\@=71I;&EZ861O<B!A(&%C='5A;&EZ87(N(@H*(SH@;&EB+TAO
M<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(E1E;2!D92!E
M<W!E8VEF:6-A<B!A(&%CY^-O(&$@9&5S96UP96YH87(N(@H*(SH@;&EB+TAO
M<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S(*;7-G:60@(EEO=2!M
M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B5&5M(&1E
M(&EN=')O9'5Z:7(@=6T@;F]V;R!N;VUE(&1E(&-A=&5G;W)I82XB"@HC.B!L
M:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9
M;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM
M<V=S='(@(E1E;2!D92!F;W)N96-E<B!U;2!N^FUE<F\@9&4@=&5L969O;F4@
M:71A;&EA;F\B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3$Q"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE
M87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R(")!('-U82!S97-SXV\@)7,@97AP
M:7)O=2X@4&]R(&9A=F]R(&5N=')E(&1E(&YO=F\N(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G:60@(EEO=7(@16UA:6P@061D
M<F5S<R(*;7-G<W1R(")/('-E=2!%;F1E<F7G;R!D92!#;W)R96EO($5L96-T
M<O-N:6-O.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#0*;7-G:60@
M(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B3R!S974@96YD97)EYV\@
M7")$93I<(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-"!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B66]U<B!);F9O<FUA
M=&EO;B(*;7-G<W1R(")!('-U82!);F9O<FUAY^-O(@H*(SH@;&EB+TAO<F1E
M+T%U=&@N<&AP.CDQ-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN
M=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN
M9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U
M<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(D\@<V5U
M(&5N9&5R9>=O($E0('!A<F5C92!T97(@;75D861O(&1E<V1E(&\@:6[M8VEO
M(&1A('-E<W/C;R`E<RX@4&%R82`B"B)G87)A;G1I<B!A('-U82!S96=U<F%N
MYV$L(&1E=F4@875T96YT:6-A<BUS92!D92!N;W9O+B(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R($YA;64B"FUS
M9W-T<B`B3R!3974@3F]M92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M861D+FEN8SHY"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,L(&]R('1H92!F96%T
M=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O
M;BXB"FUS9W-T<B`B(@HB3R!S974@;65C86YI<VUO(&1E(&%U=&5N=&EC8>?C
M;R!NXV\@<W5P;W)T82!A9&GGXV\@9&4@=71I;&EZ861O<F5S(&]U(&5S=&$@
M(@HB;W#GXV\@9F]I(&1E<V%C=&EV861A('!O<B!A;&=U;2!O=71R;R!M;W1I
M=F\N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHY"FUS
M9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@
M<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@
M8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@
M(B(*(D\@<V5U(&UE8V%N:7-M;R!D92!A=71E;G1I8V'GXV\@;N-O('-U<&]R
M=&$@;&ES=&%G96T@9&4@=71I;&EZ861O<F5S(&]U(&5S=&$@(@HB;W#GXV\@
M9F]I(&1E<V%C=&EV861A('!O<B!A;&=U;2!O=71R;R!M;W1I=F\N(@H*(SH@
M;&EB+TAO<F1E+T%U=&@N<&AP.CDQ.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@
M=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E
M8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S
M='(@(B(*(D\@<V5U(&YA=F5G861O<B!P87)E8V4@=&5R(&UU9&%D;R!D97-D
M92!O(&EN[6-I;R!D82!S97-SXV\@)7,N(%!A<F$@9V%R86YT:7(@(@HB82!S
M=6$@<V5G=7)A;N=A+"!D979E(&%U=&5N=&EC87(M<V4@9&4@;F]V;RXB"@HC
M.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU,`IM<V=I9"`B66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R(")/('-E
M=2!N879E9V%D;W(@;N-O('-U<&]R=&$@97-T82!F=6YC:6]N86QI9&%D92XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B
M(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O
M<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N
M(@IM<V=S='(@(B(*(D\@<V5U(&YA=F5G861O<B!NXV\@<W5P;W)T82!E<W1A
M(&]PY^-O(&1E(&EM<')E<W/C;RX@4')E<W-I;VYE($-O;G1R;VPO(@HB0V]M
M;6%N9"`K(%`@<&%R82!I;7!R:6UI<BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C0Y"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G
M<W1R(")&=7-O(&AO<N%R:6\@86-T=6%L.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-3`*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS
M9W-T<B`B261E;G1I9&%D92!P861RXV\Z(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Y,PIM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(DYO
M;64@8V]M<&QE=&\B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,30U"FUS9VED
M("(B"B)9;W5R(&=E='1E>'0@=F5R<VEO;B!I<R!T;V\@;VQD(&%N9"!D;V5S
M(&YO="!S=7!P;W)T(%!(4"!N871I=F5L>2Y<;B(*(DYO="!A;&P@<W1R:6YG
M<R!W:6QL(&)E(&5X=')A8W1E9"XB"FUS9W-T<B`B(@HB02!S=6$@=F5R<^-O
M(&1O(&=E='1E>'0@Z2!D96UA<VEA9&\@86YT:6=A+"!NXV\@<W5P;W)T86YD
M;R!02%`@9&4@9F]R;6$@(@HB;F%T:79A+B!.96T@=&]D87,@87,@8V%D96EA
M<R!D92!C87)A8W1E<F5S('-E<N-O(&5X=')A[61A<RXB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(D$@<W5A
M(&YO=F$@<&%L879R82UP87-S92!P87)A("5S(.DZ("5S(@H*(SH@;&EB+TAO
M<F1E+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO
M;BXB"FUS9W-T<B`B07,@<W5A<R!O<.?U97,@9F]R86T@86QT97)A9&%S(&%T
MZ2!A;R!F:6YA;"!D97-T82!S97-SXV\N(@H*(SH@;&EB+TAO<F1E+U!R969S
M+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D
M871E9"XB"FUS9W-T<B`B07,@<W5A<R!O<.?U97,@9F]R86T@86-T=6%L:7IA
M9&%S+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED
M(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(D$@<W5A
M('!A;&%V<F$M<&%S<V4@9F]I(')E8W)I861A(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S
M(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H
M('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B"B)!('-U82!P86QA
M=G)A+7!A<W-E(&9O:2!R96-R:6%D82P@=F5R:69I<75E(&\@<V5U(&-O<G)E
M:6\@96QE8W1R\VYI8V\@92`B"B)E;G1R92!C;VT@82!S=6$@;F]V82!P86QA
M=G)A+7!A<W-E+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU
M.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B3W,@<V5U
M<R!S97)V:61O<F5S(')E;6]T;W,Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(U-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU
M9V]S;&%V:6$B"FUS9W-T<B`B2G5G;W-LX79I82(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B6F%I<F4B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR-#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$X"FUS9VED("):86UB:6$B"FUS9W-T<B`B6N)M8FEA(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(U-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B
M6FEM8F%B=V4B"FUS9W-T<B`B6FEM8F%B=>DB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@(EII<'!Y(@H*(SH@
M;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS
M9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B6T5S8V]N9&5R(%1E
M>'1O($-I=&%D;UTB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HU-@IM<V=I
M9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");4F5L873S<FEO(&1E(%!R
M;V)L96UA<UT@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C
M:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B
M6TUO<W1R87(@5&5X=&\@0VET861O("TB"@HC.B!L:6(O2&]R9&4O5&5X="]&
M:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B
M6TUO<W1R87(@5&5X=&\@0VET861O("T@)7,@;&EN:&%S72(*"B,Z(&QI8B](
M;W)D92YP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F
M("5S72(*;7-G<W1R(");;&EN:&$@)7,@9&4@)7-=(@H*(SH@;&EB+TAO<F1E
M+G!H<#HQ-#0Q('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*;7-G:60@
M(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")?061M:6YI<W1R8>?C;R(*"B,Z
M(&QI8B]A<&DN<&AP.C$S-@IM<V=I9"`B7T-,22(*;7-G<W1R(")?0V]N<V]L
M82(*"B,Z(&QI8B]A<&DN<&AP.C$R-`IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S
M='(@(L%R7W9O<F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S
M='(@(E]296UO=F5R($QI;FAA(@H*(SH@;&EB+V%P:2YP:'`Z,3$V"FUS9VED
M(")?1W)O=7!S(@IM<V=S='(@(E]'<G5P;W,B"@HC.B!L:6(O2&]R9&4O365N
M=2YP:'`Z,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R(")!7VIU9&$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E!R;W!R
M:65D861E<R!D82!?26UA9V5M(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$Y
M-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R(")?16YT<F%R(@H*(SH@;&EB+TAO
M<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B7U-A
M:7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R(")?
M36]D:69I8V%R($QI9V'GXV\B"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,38T
M"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R(")?3W#G]65S(@H*(SH@;&EB+V%P
M:2YP:'`Z,3(P"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B7U!E<FUI
M<W/U97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R
M(")?4F5M;W9E<B!,:6=AY^-O+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3`X"FUS
M9VED(")?4V5T=7`B"FUS9W-T<B`B7T-O;F9I9W5R8>?C;R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@IM
M<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4')O<')I961A
M9&5S(&1A(%]486)E;&$B"@HC.B!L:6(O87!I+G!H<#HQ,3(*;7-G:60@(E]5
M<V5R<R(*;7-G<W1R(")?571I;&EZ861O<F5S(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HX.3`*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R(")C;VYT
M86-T;W,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S$Q"FUS9VED(")A;B!E
M<G)O<B!H87,@;V-C=7)E9#HB"FUS9W-T<B`B;V-O<G)E=2!U;2!E<G)O.B(*
M"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.#@R"FUS9VED(")C86QE;F1A<B(*
M;7-G<W1R(")C86QE;F3A<FEO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B8V%L;2(*;7-G<W1R(")C86QM;R(*"B,Z(&QI8B](;W)D92]-24U%+T-O
M;G1E;G1S+G!H<#HU.#D*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B8VQI
M<75E(&%Q=6DB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#0U('!O+W1R86YS
M;&%T:6]N+G!H<#HU-3`@<&\O=')A;G-L871I;VXN<&AP.C8Q,0HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-S0Y('!O+W1R86YS;&%T:6]N+G!H<#HX,3`@<&\O
M=')A;G-L871I;VXN<&AP.C@X-PIM<V=I9"`B9&]N92(*;7-G<W1R(")F96ET
M;R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU-3(@<&\O=')A;G-L871I;VXN
M<&AP.C4X-"!P;R]T<F%N<VQA=&EO;BYP:'`Z-C$S"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HW-S@@<&\O=')A;G-L871I;VXN<&AP.C@Q,B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z.#DP"FUS9VED(")F86EL960B"FUS9W-T<B`B9F%L:&]U(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G
M:60@(F9A;&QI;F<B"FUS9W-T<B`B9&EM:6YU:6YD;R(*"B,Z(&QI8B](;W)D
M92]"<F]W<V5R+G!H<#HX-3D*;7-G:60@(F9I;&4B"FUS9W-T<B`B9FEC:&5I
M<F\B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(Y"FUS9VED(")F;W5N9#H@
M(@IM<V=S='(@(F5N8V]N=')A9&\Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3<T(&QI8B]";&]C:R]M971A<BYP:'`Z,S8P(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S@V"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E
M<RD@870@)7,@)7,B"FUS9W-T<B`B9&\@)7,@*"5S*2#@<R`E<R`E<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S@*;7-G:60@(F=U<W1I
M;F<B"FUS9W-T<B`B<F%J861A<R(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,S(*;7-G:60@(F@Z(@IM<V=S='(@(F@Z(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,S,0IM<V=I9"`B
M:&@B"FUS9W-T<B`B:&@B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-38U(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S
M"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B:6UE9&EA=&\B"@HC.B!A9&UI
M;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM
M<V=I9"`B:6YL:6YE(@IM<V=S='(@(F5M(&QI;FAA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*
M;7-G<W1R(")L:6YH87-=(@H*(SH@;&EB+U9&4R])4T]7<FET97(O;6MI<V]F
M<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C
M;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(D5R<F\@;6MI<V]F
M<R!C;VT@8_-D:6=O("5D(&%O(&-O;G-T<G5I<B!)4T\N(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,T,@IM<V=I9"`B;6TB"FUS
M9W-T<B`B;6TB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C(X."!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C`U"FUS9VED(")N86UE(@IM<V=S
M='(@(FYO;64B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,S<X"FUS9VED(")N
M;W0@8VAA;F=E9"(*;7-G<W1R(")S96T@86QT97)AY_5E<R(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,S$*;7-G:60@(FYO="!F;W5N9"(*;7-G<W1R(")N
MXV\@96YC;VYT<F%D;R(*"B,Z(&QI8B](;W)D92]24$,N<&AP.C$R,0IM<V=I
M9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(F[C;R!I;7!L96UE;G1A9&$B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R,3D*;7-G:60@(FYO
M="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`B86EN9&$@<&]R(&EM<&QE;65N
M=&%R(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HX-S0*;7-G:60@(FYO=&5P
M860B"FUS9W-T<B`B8V%D97)N;R!D92!N;W1A<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E
M<F-E;G0B"FUS9W-T<B`B<&5R8V5N=&%G96TB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE
M;',B"FUS9W-T<B`B<.UX96ES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-S,*;7-G:60@(G)I<VEN9R(*;7-G<W1R(")S=6)I
M;F1O(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HY.`IM<V=I9"`B<VAO
M=R!D:69F97)E;F-E<R(*;7-G<W1R(")M;W-T<F%R(&1I9F5R96[G87,B"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S
M;7,R96UA:6P@=FEA($A45%`B"FUS9W-T<B`B<VUS,F5M86EL('9I82!(5%10
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.`IM
M<V=I9"`B<W,B"FUS9W-T<B`B<W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B<W1E861Y(@IM<V=S='(@(F5S
M=.%V96PB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C@Y.`IM<V=I9"`B=&%S
M:R!L:7-T(@IM<V=S='(@(FQI<W1A(&1E('1A<F5F87,B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-S(U"B,L('!H<"UF;W)M870*;7-G:60@(G1H92!(;W)D
M92!03R!F:6QE(&9O<B!T:&4@;&]C86QE("5S(&1O97,@;F]T(&5X:7-T.B(*
M;7-G<W1R(")/(&9I8VAE:7)O(%!/('!A<F$@;R!L;V-A;&4@)7,@;N-O(&5X
M:7-T92XB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!L:6(O2&]R9&4O075T:"]3
M:6=N=7`N<&AP.C(V.0IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@
M=&\@8V]N9FER;2(*;7-G<W1R(")I;G1R;V1U>F$@82!P86QA=G)A+7!A<W-E
M(&1U87,@=F5Z97,L('!A<F$@8V]N9FER;6'GXV\B"@HC.B!A9&UI;B]S971U
M<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B
M=6YI9FEE9"(*;7-G<W1R(")U;FEF:6-A9&\B"@HC.B!L:6(O2&]R9&4O34E-
M12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R(")S96T@;F]M
M92(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HS-S4*;7-G:60@(G5P9&%T960B
M"FUS9W-T<B`B86-T=6%L:7IA9&\B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38U(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C(S"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R(")S96QE8V-I;VYA
M9&$@<&5L;R!U=&EL:7IA9&]R(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(T"FUS9VED
M(")W.B(*;7-G<W1R(")2965N8SHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B=V5A=&AE
M<BYC;VTB"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]214%$344`````````
M````````````````````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(R
M-S<R`#$P-3$U-#,S-S4T`#`Q-S$V-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````]/3T]/3T]/3T]/3T]/3T]/3T]"B!4<F%N
M<VQA=&EO;B!'=6ED92`*/3T]/3T]/3T]/3T]/3T]/3T]/0H*.D1A=&4Z("`@
M("`D1&%T93H@,C`P-B\P-R\R-B`Q-#HP-CHU,2`D"CI2979I<VEO;CH@)%)E
M=FES:6]N.B`Q+C(Y+C0N,2`D"CI!=71H;W)S.B`@2F%N(%-C:&YE:61E<@HZ
M0V]N=&%C=#H@(&DQ.&Y`;&ES=',N:&]R9&4N;W)G"@HN+B!C;VYT96YT<SHZ
M"BXN('-E8W1I;VXM;G5M8F5R:6YG.CH*"E1R86YS;&%T:6]N(%1O;VP*/3T]
M/3T]/3T]/3T]/3T]/0H*8&!T<F%N<VQA=&EO;BYP:'!@8"!I<R!A('-M86QL
M(%!(4"!S8W)I<'0@=&AA="!S:&]U;&0@:&5L<"!T<F%N<VQA=&]R<R!D;VEN
M9PIT:&5I<B!W;W)K+@I!;GD@9F5E9&)A8VLL(&)U9R!R97!O<G1S(&%N9"!F
M96%T=7)E(')E<75E<W1S('-H;W5L9"!B92!S96YD('1O('1H92!@:3$X;@IM
M86EL:6YG(&QI<W1@7RX@5&AI<R!I<R!A;'-O('1H92!R:6=H="!P;&%C92!F
M;W(@;F5W('1R86YS;&%T:6]N<R!A;F0@9V5N97)A;`ID:7-C=7-S:6]N<R!O
M9B!I,3AN(&%N9"!L,3!N('%U97-T:6]N<R!A;F0@<')O8FQE;7,N"@I&;W(@
M82!L:7-T(&]F(&%V86EL86)L92!C;VUM86YD<R!R=6XZ.@H*("`N+W1R86YS
M;&%T:6]N+G!H<"!H96QP"@I&;W(@9&5T86EL960@:&5L<"!O;B!A(&-E<G1A
M:6X@8V]M;6%N9"!R=6XZ.@H*("`N+W1R86YS;&%T:6]N+G!H<"!H96QP(&-O
M;6UA;F0*"D%D9&ET:6]N86P@:6YF;W)M871I;VX@86)O=70@8W)E871I;F<@
M=')A;G-L871I;VYS(&%N9"!F:7AI;F<@<')O8FQE;7,@8V%N(&)E"F9O=6YD
M(&EN('1H92!F:6QE(&!@:&]R9&4O9&]C<R]44D%.4TQ!5$E/3F!@+@H*+BX@
M7VDQ.&X@;6%I;&EN9R!L:7-T.B!H='1P.B\O:&]R9&4N;W)G+VUA:6PO"@I0
M<F5R97%U:7-I=&5S"GY^?GY^?GY^?GY^?GX*"E1O(')U;B!T:&ES('-C<FEP
M="!Y;W4G;&P@;F5E9"!A(%!(4"!E>&5C=71A8FQE(&QI:V4@=&AE($-,22!O
M<B!T:&4@0T=)('9E<G-I;VX*=VET:"!@9V5T=&5X="!S=7!P;W)T8%\@8V]M
M<&EL960@:6X@86YD('1H92!B87-I8R!@4$5!4F!?(&QI8G)A<FEE<RX@5&AE
M"G-C<FEP="!E>'!E8W1S('EO=7(@4$A0(&5X96-U=&%B;&4@=&\@8F4@870@
M8&`O=7-R+VQO8V%L+W!S82]A9&UI;B]B:6XO<&AP8&`N($EF('EO=7(*97AE
M8W5T86)L92!I<R!A="!A;F]T:&5R('!L86-E+"!E:71H97(@961I="!T:&4@
M9FER<W0@;&EN92!O9@I@8'1R86YS;&%T:6]N+G!H<&!@('1O(')E9FQE8W0@
M>6]U<B!L;V-A=&EO;B!O<B!C86QL('1H92!S8W)I<'0@;&EK93HZ"@H@("]U
M<W(O;&]C86PO<'-A+V%D;6EN+V)I;B]P:'`@+68@=')A;G-L871I;VXN<&AP
M+@H*66]U)VQL(&YE960@8&=E='1E>'1@7R`P+C$Q(&]R(&=R96%T97(L(&)U
M="!V97)S:6]N(#`N,3(@;W(@9W)E871E<B!I<R!S=')O;F=L>0IR96-O;6UE
M;F1E9"!A<R!T:&ES(&ES('1H92!F:7)S="!V97)S:6]N('1H870@<W5P<&]R
M=',@4$A0(&YA=&EV96QY+B!/;&1E<@IV97)S:6]N<R!M87D@;F]T(&5X=')A
M8W0@86QL('1R86YS;&%T96%B;&4@<W1R:6YG<R!C;W)R96-T;'DN"D$@=VEN
M9&]W<R!V97)S:6]N(&]F('1H92!G971T97AT(&)I;F%R:65S(&-A;B!B92!F
M;W5N9"!O;B!E=F5R>2!@1TY5(&9T<`IM:7)R;W)@7R!A<R!O9B!V97)S:6]N
M(#`N,3(N"@I9;W4G;&P@;F5E9"!T:&4@4$5!4B!P86-K86=E<R!@0V]N<V]L
M95]'971O<'1@7R`P+C$Q(&]R(&=R96%T97(L"F!#;VYS;VQE7U1A8FQE8%\@
M86YD(&!&:6QE7T9I;F1@7RX@5&\@:6YS=&%L;"!A;&P@;F5E9&5D('!A8VMA
M9V5S+"!R=6XZ.@H*("!P96%R('5P9W)A9&4@4$5!4B!#;VYS;VQE7T=E=&]P
M=`H@('!E87(@:6YS=&%L;"!#;VYS;VQE7U1A8FQE($9I;&5?1FEN9`H*;W(@
M9&]W;FQO860@=&AE(&YE=V5S="!P86-K86=E(&9R;VT@=&AE(&!014%28%\@
M<V5R=F5R(&%N9"!I;G-T86QL('1H96T*;6%N=6%L;'D@:6X@>6]U<B!014%2
M(&1I<F5C=&]R>2X*"BXN(%]G971T97AT.B!H='1P.B\O=W=W+F=N=2YO<F<O
M<V]F='=A<F4O9V5T=&5X="\*+BX@7V=E='1E>'0@<W5P<&]R=#H@:'1T<#HO
M+W=W=RYP:'`N;F5T+V=E='1E>'0O"BXN(%]'3E4@9G1P(&UI<G)O<CH@:'1T
M<#HO+W=W=RYG;G4N;W)G+W!R97`O9G1P+FAT;6P*+BX@7U!%05(Z(&AT='`Z
M+R]P96%R+G!H<"YN970O"BXN(%]#;VYS;VQE7T=E=&]P=#H@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+T-O;G-O;&5?1V5T;W!T+PHN+B!?0V]N<V]L
M95]486)L93H@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T-O;G-O;&5?
M5&%B;&4O"BXN(%]&:6QE7T9I;F0Z(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]&:6QE7T9I;F0O"@I#<F5A=&EN9R!A(&YE=R!T<F%N<VQA=&EO;@I^
M?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?@H*5&\@8W)E871E(&$@;F5W('1R
M86YS;&%T:6]N('EO=2!F:7)S="!H879E('1O(&5X=')A8W0@86QL(&=E='1E
M>'0@;65S<V%G97,@9G)O;0IT:&4@4$A0('-O=7)C97,N(%1H97)E(&%R92!A
M;')E861Y('1E;7!L871E(&9I;&5S('=I=&@@=&AE(&!@+G!O=&!@('-U9F9I
M>"!I;@IT:&4@8&!P;V!@(&1I<F5C=&]R:65S('1H870@>6]U(&-A;B!U<V4@
M:68@>6]U(&AA=F4@=')O=6)L97,@97AT<F%C=&EN9R!T:&4*;65S<V%G97,@
M8G5T('1H97D@;6EG:'0@8F4@;W5T9&%T960N"E)U;CHZ"@H@("XO=')A;G-L
M871I;VXN<&AP(&5X=')A8W0*"EEO=2!N;W<@:&%V92!T;R!C<F5A=&4@82!N
M97<@4$\@9FEL92!F;W(@>6]U<B!L;V-A;&4N($$@;&]C86QE(&AA<R!T:&4@
M9F]R;0I@8&QL7T-#8&`@=VAE<F4@8&!L;&!@(&ES('1H92!T=V\@;&5T=&5R
M(&!)4T\@-C,Y8%\@8V]D92!O9B!T:&4@;&%N9W5A9V4@86YD"F!@0T-@8"!T
M:&4@='=O(&QE='1E<B!@25-/(#,Q-C9@7R!C;V1E(&]F('1H92!C;W5N=')Y
M+"!E+F<N(&!@9&5?1$5@8"P*8&!E;E]54V!@(&]R(&!@<'1?0E)@8"X*8&!T
M<F%N<VQA=&EO;BYP:'!@8"!I<R!A8FQE('1O(&=U97-S('1H92!L;V-A;&4@
M9G)O;2!T:&4@8&!,04Y'8&`@96YV:7)O;FUE;G0*=F%R:6%B;&4@8G5T(&ET
M(&ES('-A9F5R('1O('-P96-I9GD@=&AE(&QO8V%L92!W:71H('1H92!@8"UL
M8&`@<&%R86UE=&5R+@I4;R!C<F5A=&4@=&AE(%!/(&9I;&4@<G5N.CH*"B`@
M+B]T<F%N<VQA=&EO;BYP:'`@:6YI="`M;"!L;%]#0PH*3F]W('EO=2!C86X@
M<W1A<G0@=&AE('1R86YS;&%T:6]N(&)Y(&5D:71I;F<@=&AE(&-R96%T960@
M8&!L;%]#0RYP;V!@"F9I;&5S+B!)="!I<R!I;7!O<G1A;G0@=&\@<V5T('1H
M92!C;W)R96-T(&-H87)S970@9F]R('1H92!L;V-A;&4@:6X@=&AE"F!@0V]N
M=&5N="U4>7!E.F!@(&AE861E<BX*66]U('-H;W5L9"!F:6QL(&]U="!T:&4@
M=&AE(&-O;7!L971E(&AE861E<B!O9B!T:&4@8W)E871E9"!@8&QL7T-#+G!O
M8&`@9FEL92P*92YG+CHZ"@H@(",@1'5T8V@@=')A;G-L871I;VX@9F]R($AO
M<F1E+@H@(",@0V]P>7)I9VAT("A#*2`R,#`T($AO<F1E(%!R;VIE8W0*("`C
M(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E
M;G-E(&%S('1H92!(;W)D92!P86-K86=E+@H@(",@2F]R:7,@0G)A86MM86X@
M/&IB<F%A:VUA;D!Y86AO;RYC;VT^+"`R,#`T+@H@(",*("!M<V=I9"`B(@H@
M(&US9W-T<B`B(@H@(")0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#(N,UQN
M(@H@(")297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R
M9UQN(@H@(")03U0M0W)E871I;VXM1&%T93H@,C`P-"TP-"TQ-"`Q,#HS,"LP
M,C`P7&XB"B`@(E!/+5)E=FES:6]N+41A=&4Z(#(P,#0M,#0M,30@,3<Z,3<K
M,#(Z,#!<;B(*("`B3&%S="U4<F%N<VQA=&]R.B!*;W)I<R!"<F%A:VUA;B`\
M:F)R86%K;6%N0'EA:&]O+F-O;3Y<;B(*("`B3&%N9W5A9V4M5&5A;3H@:3$X
M;D!L:7-T<RYH;W)D92YO<F=<;B(*("`B34E-12U697)S:6]N.B`Q+C!<;B(*
M("`B0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y
M+3%<;B(*("`B0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:71<;B(*
M"E1O(&-O;7!I;&4@=&AE('1R86YS;&%T:6]N<R!T;R!A(&)I;F%R>2!F;W)M
M870@<G5N.CH*"B`@+B]T<F%N<VQA=&EO;BYP:'`@;6%K90H*069T97(@>6]U
M(&-R96%T960@=&AE(&YE=R!T<F%N<VQA=&EO;B!Y;W4@:&%V92!T;R!A9&0@
M96YT<FEE<R!F;W(@=&AI<R!L;V-A;&4*:6X@=&AE(&-O;F9I9W5R871I;VX@
M9FEL92!H;W)D92]C;VYF:6<O;FQS+G!H<"X*"E1/1$\Z(&9I;&QI;F<@;F5W
M('!O(&9I;&5S('=I=&@@<W1R:6YG<R!F<F]M('1H92!C;VUP96YD:75M+@H*
M+BX@7TE33R`V,SDZ(&AT='`Z+R]W=W<N;&]C+F=O=B]S=&%N9&%R9',O:7-O
M-C,Y+3(O"BXN(%])4T\@,S$V-CH@:'1T<#HO+W=W=RYI<V\N8V@O:7-O+V5N
M+W!R;V1S+7-E<G9I8V5S+VES;S,Q-C9M82]I;F1E>"YH=&UL"@I-86EN=&%I
M;FEN9R!T<F%N<VQA=&EO;G,*?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^"@I4
M:&ES('1O;VP@:7,@9&5S:6=N960@=&\@:&5L<"!Y;W4@=')A;G-L871O<G,@
M9&]I;F<@>6]U<B!G<F5A="!W;W)K+B!)="!C:&%N9V5S"F$@;&]T(&-O;7!A
M<F5D('1O('1H92!O;&0@;65T:&]D<R!C<F5A=&EN9R!A;F0@;6%I;G1A:6YI
M9R!Y;W5R('1R86YS;&%T:6]N<RX@5&\*;6%K92!T:&4@=')A;G-I=&EO;B!T
M;R!T:&4@=&]O;"!A<R!S;6]O=&@@87,@<&]S<VEB;&4@>6]U('-H;W5L9"!R
M96%D(&-H87!T97(*,RXQ(&)E9F]R92!U<VEN9R!T:&ES('1O;VP@=&AE(&9I
M<G-T('1I;64N"@I&:7)S="!T:6UE('5S92!O9B!T<F%N<VQA=&EO;BYP:'`*
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"@I4:&ES('1O;VP@
M:6YT<F]D=6-E<R!A(&YI8V4@9F5A='5R92!O9B!G971T97AT.B!C;VUP96YD
M:75M(&9I;&5S+B!!(&-O;7!E;F1I=6T*:7,@82!S<&5C:6%L(%!/(&9I;&4@
M8V]N=&%I;FEN9R!A('-E="!O9B!T<F%N<VQA=&EO;G,@<F5C=7)R:6YG(&EN
M(&UA;GD*9&EF9F5R96YT('!A8VMA9V5S+B!4:&5S92!C;VUP96YD:6$@=VEL
M;"!B92!U<V5D(&EN('1H92!B86-K9W)O=6YD('=I=&AO=70@;75C:`IF;W(@
M>6]U('1O(&-A<F4@86)O=70N($)U="!Y;W4@:&%V92!T;R!C<F5A=&4@86YD
M(&5D:70@82!C;VUP96YD:75M(&)E9F]R92!Y;W4*8V%N('5S92!I="X*"E1O
M(&-R96%T92!A(&-O;7!E;F1I=6T@;V8@86QL('EO=7(@97AI<W1I;F<@=')A
M;G-L871I;VYS(')U;CHZ"@H@("XO=')A;G-L871I;VXN<&AP(&-O;7!E;F1I
M=6T@+6P@;&Q?0T,*"E1H92!@8&-O;7!E;F1I=6TN<&]@8"!B96EN9R!C<F5A
M=&5D('=I;&P@8V]N=&%I;B!A;&P@;6]D=6QE<R<@=')A;G-L871I;VYS(&]F
M"G1H:7,@;&]C86QE(&UE<F=E9"!I;G1O(&$@<VEN9VQE(&9I;&4N(%EO=2!S
M:&]U;&0@=&%K92!A(&-L;W-E<B!L;V]K(&%T('1H:7,*9FEL92!B96-A=7-E
M('EO=2!M87D@9FEN9"!A(&QO="!O9B!S<&5C:6%L(&UA<FME9"!L:6YE<R!W
M:&5R92!Y;W4@=')A;G-L871E9`IC97)T86EN('-T<FEN9W,@9&EF9F5R96YT
M;'D@:6X@=&AE('9A<FEO=7,@;6]D=6QE<RX@270G<R!A(&=O;V0@:61E82!T
M;R!F:7@*=&AE(&UO9'5L97,G('1R86YS;&%T:6]N<R!N;W<@<V\@=&AA="!A
M;&P@;6]D=6QE<R!U<V4@=&AE('-A;64@=')A;G-L871I;VX@9F]R"G1H92!S
M86UE('-T<FEN9RX@66]U(&-A;B!A;'=A>7,@<F5C<F5A=&4@>6]U<B!C;VUP
M96YD:75M('=I=&@@=&AE(&%B;W9E"F-O;6UA;F0N"@I)9B!Y;W4G<F4@;6%I
M;G1A:6YI;F<@=')A;G-L871I;VYS(&9O<B!D:69F97)E;G0@8&)R86YC:&5S
M8%\@86YD(&%S<W5M960@=&AA=`IY;W4@:&%V92!A;&P@;6]D=6QE<R!O9B!T
M:&4@8&!(14%$8&`@8G)A;F-H97,@:6X@;VYE(&1I<F5C=&]R>2!A;F0@86QL
M(&]F('1H90I@8%)%3$5.1U\J8&`@8G)A;F-H97,@:6X@86YO=&AE<BP@>6]U
M('!R;V)A8FQY('=A;G0@=&\@<VAA<F4@82!C;VUP96YD:75M"F)E='=E96X@
M=&AE<V4@9&ER96-T;W)I97,N"@I9;W4@<VAO=6QD(&9I<G-T(&-R96%T92!A
M(&-O;7!E;F1I=6T@:6X@=&AE(&!@4D5,14Y'7RI@8"!B<F%N8V@L(')E=FEE
M=R!I="!A;F0*9FEX(&%L;"!T<F%N<VQA=&EO;G,@=6YT:6P@>6]U)W)E(&AA
M<'!Y('=I=&@@=&AE(')E<W5L="X@5&AE;B!C<F5A=&4@82!S96-O;F0*8V]M
M<&5N9&EU;2!I;B!T:&4@8&!(14%$8&`@8G)A;F-H(&%N9"!I;F-L=61E('EO
M=7(@9FER<W0@;VYE('=I=&@@=&AE("TM861D"F]P=&EO;BX*3F]W(&9I>"!T
M:&4@=')A;G-L871I;VYS(&EN('1H:7,@8G)A;F-H+B!)9B!Y;W4G<F4@<F5A
M9'D@>6]U(&-A;B!R96UO=F4@=&AE"F9I<G-T(&-O;7!E;F1I=6T@86YD(&9O
M<B!N;W<@;VX@=7-E('1H92!C;VUP96YD:75M(&EN('1H92!@8$A%041@8"!B
M<F%N8V@@9F]R"F)O=&@@8G)A;F-H97,N(%1O(&1O('-O('5S92!T:&4@8&`M
M+6-O;7!E;F1I=6U@8"!O<'1I;VX@=&\@<W!E8VEF>2!A('!A=&@@=&\*>6]U
M<B!C;VUP96YD:75M+@H*+BX@7V)R86YC:&5S.B!H='1P.B\O=W=W+FAO<F1E
M+F]R9R]S;W5R8V4O"@I5<&1A=&EN9R!T<F%N<VQA=&EO;G,*+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM"@I4:&4@<')O8V5S<R!O9B!U<&1A=&EN9R!T<F%N<VQA
M=&EO;G,@:7,@82!C>6-L92!W:&5R92!Y;W4@97AT<F%C="!N97<@9V5T=&5X
M=`IS=')I;F=S(&9R;VT@=&AE('-O=7)C97,L('1R86YS;&%T92!T:&]S92!N
M97<@<W1R:6YG<R!O<B!U<&1A=&4@=&AE(&%L<F5A9'D*=')A;G-L871E9"!S
M=')I;F=S(&%N9"!C;VUP:6QE('1H96T@869T97(N"@I4;R!U<&1A=&4@=&AE
M('1R86YS;&%T:6]N(&9O<B!A(&UO9'5L92P@<G5N.CH*"B`@+B]T<F%N<VQA
M=&EO;BYP:'`@=7!D871E("UM(&UO9'5L96YA;64@+6P@;&Q?0T,*"E1H:7,@
M97AT<F%C=',@=&AE(&YE=R!S=')I;F=S(&9R;VT@=&AE('-O=7)C97,@86YD
M('1R:65S('1O('5P9&%T92!T:&5M(&9R;VT*86QR96%D>2!E>&ES=&EN9R!T
M<F%N<VQA=&EO;G,@:6X@=&AE(&-O;7!E;F1I=6TN(%EO=2!J=7-T(&AA=F4@
M=&\@=')A;G-L871E"F%L;"!U;G-T<F%N<VQA=&5D('-T<FEN9W,@:6X@=&AE
M(&!@;&Q?0T,N<&]@8"!F:6QE(&EN('1H92!@8'!O8&`@9&ER96-T;W)Y(&]F
M"G1H92!M;V1U;&4@>6]U('5P9&%T960N"@I/;F-E('1H:7,@:7,@9&]N92P@
M>6]U(&-A;B!C;VUP:6QE('1H92!T<F%N<VQA=&EO;B!B>2!C86QL:6YG.CH*
M"B`@+B]T<F%N<VQA=&EO;BYP:'`@;6%K92`M;2!M;V1U;&5N86UE("UL(&QL
M7T-#"@I%>'1E;F1I;F<@97AI<W1E;G0@=')A;G-L871I;VYS"GY^?GY^?GY^
M?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GX*"E1O(&AA=F4@>6]U<B!O=VX@=&5X
M=',@*&%S('-U<'!L:65D(&EN(&-O;F9I9R!F:6QE<R!F;W(@97AA;7!L92D@
M9&ES<&QA>65D(&EN"G-E=F5R86P@;&%N9W5A9V5S+"!Y;W4@:&%V92!T;PH*
M("`Q+B!S<&5C:69Y('EO=7(@=&5X=',@87,@9V5T=&5X="!A<F=U;65N=',L
M(&EN($5N9VQI<V@L"B`@,BX@961I="!T:&4@=')A;G-L871I;VX@9FEL97,@
M9F]R('1H92!R97%U:7)E9"!N871I;VYA;"!L86YG=6%G97,L"B`@,RX@8V]M
M<&EL92!T:&]S92!T<F%N<VQA=&EO;B!F:6QE<RX*"D)E('-U<F4@=&\@:V5E
M<"!R96-O<F1S(&]F('EO=7(@97AT96YS:6]N<RP@87,@>6]U('=I;&P@<')O
M8F%B;'D@:&%V92!T;PIR97!E870@<W1E<',@,B!A;F0@,R!A9G1E<B!T:&4@
M;F5X="!U<&1A=&4N"@I%+F<N+"!Y;W4@<&QA;B!T;R!O9F9E<B!T=V\@24U!
M4"!S97)V97)S('1O('-E;&5C="!F<F]M(&EN('1H92!796)M86EL(&QO9VEN
M"G-C<F5E;CH*"B`@,2X@26X@8&!H;W)D92]I;7`O8V]N9FEG+W-E<G9E<G,N
M<&AP8&`L('EO=2!S<&5C:69Y.CH*"B`@("`@("`D<V5R=F5R<ULG0V5N=')A
M;"==(#T@87)R87DH"B`@("`@("`@("`G;F%M92<@/3X@7R@B0V5N=')A;"!-
M86EL(%-E<G9I8V4B*2P*("`@("`@("XN+@H@("`@("`@)'-E<G9E<G-;)T-O
M;7!38VDG72`](&%R<F%Y*`H@("`@("`@("`@)VYA;64G(#T^(%\H(DUA:6P@
M4V5R=FEC92!O9B!#;VUP=71E<B!38VEE;F-E($1P="XB*0H@("`@("`@+BXN
M"@H@(#(N($EN(&!@:&]R9&4O:6UP+W!O+V1E7T1%+G!O8&`@>6]U(&%D9"!T
M=V\@96YT<FEE<SHZ"@H@("`@("`@;7-G:60@(D-E;G1R86P@36%I;"!397)V
M:6-E(@H@("`@("`@;7-G<W1R("):96YT<F%L97(@36%I;'-E<G9E<B(*("`@
M("`@(&US9VED(")-86EL(%-E<G9I8V4@;V8@0V]M<'5T97(@4V-I96YC92!$
M<'0N(@H@("`@("`@;7-G<W1R(")-86EL<V5R=F5R($EN9F]R;6%T:6LB"@H@
M("`@($QI:V5W:7-E+"!Y;W4@86UE;F0@=&AE('1R86YS;&%T:6]N(&9I;&5S
M(&9O<B!O=&AE<B!L86YG=6%G97,L(&%S(&YE961E9"X*"B`@,RX@66]U(&-O
M;7!I;&4@=&AE('1R86YS;&%T:6]N<R!U<VEN9R!T:&4@8V]M;6%N9',Z.@H*
M("`@("`@("XO<&\O=')A;G-L871I;VXN<&AP(&UA:V4@+2UM;V1U;&4@:6UP
M("TM;F\M8V]M<&5N9&EU;0H*06-C97-S($ME>7,*/3T]/3T]/3T]/3T*"D%C
M8V5S<R!K97ES+"!A;'-O(&MN;W=N(&%S('-H;W)T8W5T(&ME>7,L(&%L;&]W
M(&5A<WD@86-C97-S('1O(&EM<&]R=&%N=`IF=6YC=&EO;G,L(&YO<FUA;&QY
M(&)Y(&AI='1I;F<@=&AE($%L="]-971A(&ME>2!I;B!C;VUB:6YA=&EO;B!W
M:71H(&%N;W1H97(*:V5Y+B!4:&ES(&ME>2!I<R!M87)K960@:6X@;6]S="!U
M<V5R(&EN=&5R9F%C97,@8GD@8F5I;F<@=6YD97)L:6YE9"X*"D%S('1H92!A
M8V-E<W,@:V5Y(&ES('!A<G0@;V8@=&AE('=O<F0@<F5P<F5S96YT:6YG('1H
M92!A8W1I;VX@8F5I;F<@97AE8W5T960L"FET(&ES(&EN('1H92!T<F%N<VQA
M=&]R<R!R97-P;VYS:6)I;&ET>2!T;R!S96QE8W0@86X@86-C97-S(&ME>2!W
M:&5N(&AE"G1R86YS;&%T97,@=&AE<V4@=V]R9',N(%1H92!A8W1I;VX@:7,@
M86QW87ES(&$@;&EN:R!I;B!(;W)D92X@5&AE(&%C8V5S<R!K97D*;V8@82!L
M:6YK(&ES('-E;&5C=&5D(&)Y('!R969I>&EN9R!I="!W:71H(&%N('5N9&5R
M<V-O<F4N"@I4:&4@:&5L<"!L:6YK(&EN('1H92!M96YU(&9O<B!E>&%M<&QE
M(&ES(&%L=V%Y<R`B7TAE;'`B+B!4:&ES(&UE86YS('1H870@=&AE"B)((B!O
M9B!T:&4@;&EN:R!W:6QL(&)E('5N9&5R;&EN960@86YD('1H92!H96QP(&-A
M;B!B92!O<&5N960@8GD@:&ET=&EN9PI!;'0K2"X@26X@=&AE(%!/(&9I;&4@
M=&AI<R!S=')I;F<@=VEL;"!A<'!E87(@87,Z.@H*("`C.B!T96UP;&%T97,O
M;65N=2]M96YU+FEN8SHU,PH@(&US9VED(")?2&5L<"(*("!M<V=S='(@(B(*
M"D$@4W!A;FES:"!T<F%N<VQA=&]R(&UI9VAT('=A;G0@=&\@=')A;G-L871E
M('1H:7,@=&\Z.@H*("`C.B!T96UP;&%T97,O;65N=2]M96YU+FEN8SHU,PH@
M(&US9VED(")?2&5L<"(*("!M<V=S='(@(E]!>75D82(*"E1R86YS;&%T;W)S
M(&]F(&UU;'1I8GET92!L86YG=6%G97,@;F5E9"!T;R!D;R!T:&ES(&$@8FET
M(&1I9F9E<F5N=&QY(&%S(&]N;'D*05-#24D@8VAA<F%C=&5R<R!A<F4@86QL
M;W=E9"!F;W(@86-C97-S(&ME>7,N($$@5')A9&ET:6]N86P@0VAI;F5S92!T
M<F%N<VQA=&]R"FUI9VAT('=A;G0@=&\@=7-E.CH*"B`@(SH@=&5M<&QA=&5S
M+VUE;G4O;65N=2YI;F,Z-3,*("!M<V=I9"`B7TAE;'`B"B`@;7-G<W1R(")?
M2.BJJN:8CB(*"E1H:7,@<F5N9&5R<R!T;R`BZ*JJYIB.*$@I(B!I;B!T:&4@
M:6YT97)F86-E(&%N9"!Y;W4@8V%N"F%C8V5S<R!T:&ES(&QI;FL@=VET:"`B
M2"(@87,@=&AE(&%C8V5S<R!K97DN"@```````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&\O<F]?4D\N<&\`````````````````````````````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#8Q,34R,0`Q,#4Q-30S,S<U-``P,3<V
M-C,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M(R!(;W)D92!2;VUA;FEA;B!T<F%N<VQA=&EO;BX*(R!#;W!Y<FEG:'0@*$,I
M(#(P,#(@2&]R9&4@4')O:F5C="X*(R!#;W)N96QI=2!-55-!5"`\8VUU<V%T
M0&ME>7-Y<RYR;SXL(#(P,#(N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J
M96-T+4ED+59E<G-I;VXZ($A/4D1%(#(N,5QN(@HB4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$
M871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A
M=&4Z(#(P,#(M,#@M,#$@,#DZ,S0K,#(Z,#!<;B(*(DQA<W0M5')A;G-L871O
M<CH@0V]R;F5L:74@3553050@/&-M=7-A=$!K97ES>7,N<F\^7&XB"B),86YG
M=6%G92U496%M.B!23TU!3DE!3B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB
M"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L
M86EN.R!C:&%R<V5T/4E33RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M
M16YC;V1I;F<Z(#AB:71<;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S<P"B,L
M('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<W"B,L('!H<"UF;W)M
M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-0IM<V=I9"`B
M("AT;VUO<G)O=RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,W,0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-38@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,V,0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#`W"FUS9VED("(@870@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HV-3D*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#0R"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@
M=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R("(G)7,G(&YU(&5S=&4@8V]N
M9FEG=7)A="!I;B!(;W)D92!296=I<W1R>2(*"B,Z(&9R86UE=V]R:R]4<F5E
M+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E
M92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A
M9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB
M"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB
M('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@
M=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W"B,L('!H<"UF;W)M
M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U
M<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M+61A>2!F;W)E8V%S="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HW,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M.#,S(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R
M("(E<R!/<&5R871I=6YI(&1E(&UE;G1E;F%N=&$@+2!#;VYF:7)M87)E(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#(X(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z-#DP"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C4Q
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$U.2!L:6(O0FQO8VLO;65T87(N<&AP.C$V-2!L
M:6(O0FQO8VLO;65T87(N<&AP.C(S.0HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,T-2!L:6(O0FQO8VLO;65T87(N<&AP.C,U,0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*
M(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY
M(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM
M92XB"FUS9W-T<B`B0FEF871I(&]P97)A=&EU;BAE82]I;&4I('!E(&-A<F4@
M9&]R:71I('-A(&QE(&9A8V5T:2!A8W5M+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q
M=6ER960B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#8*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T
M<B`B3&$@9FEE8V%R92`U(&UI;G5T92(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!T;R`E<R!O9B`E<R(*;7-G<W1R(");;&EN:6$@)7,@9&EN("5S72(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(R"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R(")!9V5N
M9&$B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R(")#
M86QE;F1A<B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`V"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP
M:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N
M;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O
M;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H
M92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C4@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q,`IM<V=I9"`B+"!G=7-T:6YG
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X."!L:6(O
M0FQO8VLO;65T87(N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U
M<W1I;F<@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F<F]M("5S
M('1O("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,CDT(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-CD@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$R.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-S0Y"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"B,L(&9U>GIY"FUS9VED("(Q,B!(
M;W5R($9O<FUA="(*;7-G<W1R("));F9O<FUA=&EI(&1E<W!R92!T:6YE(@H*
M(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"B,L(&9U>GIY"FUS9VED("(R-"!(
M;W5R($9O<FUA="(*;7-G<W1R("));F9O<FUA=&EI(&1E<W!R92!T:6YE(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S
M(@IM<V=S='(@(C(T(&1E(&]R92(*"B,Z(&9R86UE=V]R:R]522]522]086=E
M<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B02!D871A8F%S92!B86-K96YD
M(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V,`HC+"!F=7IZ>0IM<V=I9"`B
M02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B/&(^02!A<&%R
M=70@;R!E<F]A<F4@9F%T86QA.CPO8CXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@
M<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C4*;7-G:60@(D$@
M<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D
M(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$P.3<*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R
M:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$U"FUS9VED("(B"B)!('!U8FQI
M8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#4*;7-G:60@
M(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M
M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@
M<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI
M8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@
M3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM
M<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W
M97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y
M"FUS9VED(")!32]032(*;7-G<W1R(")!32]032(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)
M($E$(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4R"FUS9VED(")!
M8F]U="XN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@26YF;W)M871I
M;VXB"FUS9W-T<B`B26YF;W)M871I:2!D97-P<F4@=&EN92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW-0HC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!0
M87-S=V]R9"(*;7-G<W1R(")087)O;&$B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@
M9G)O>F5N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S,S"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO
M861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD
M+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B061D(@IM<V=S='(@(D%D<F5S82(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U
M"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.CDY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0HC+"!F=7IZ
M>0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(D%D<F5S82(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED(")!
M9&0@3F5W($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX
M.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30W"B,L
M('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@
M7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED
M(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-`IM<V=I9"`B061D(&-O;'5M
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B
M"FUS9W-T<B`B061A=6=A('!E<F5C:&5A(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE
M;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"B,L(&9U>GIY"FUS
M9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R(")!9V5N9&$B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*(RP@
M9G5Z>GD*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B
M06=E;F1A(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@
M(D%D9"!U<V5R(@IM<V=S='(@(D%D875G82!P97)E8VAE82(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB
M)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO
M;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*"B,Z
M('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E
M<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G
M:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#$*;7-G:60@(D%D9')E<W,B"FUS9W-T
M<B`B061R97-A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S.0HC
M+"!F=7IZ>0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D%G96YD82(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS
M9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U
M<V5R<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T
M,0HC+"!F=7IZ>0IM<V=I9"`B061S(@IM<V=S='(@(D%D<F5S82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3<*(RP@9G5Z>GD*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B06QI87,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(D%L
M:6%S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B06QI87,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V"B,L(&9U
M>GIY"FUS9VED(")!;&EG;B(*;7-G<W1R(")!;&EA<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N
M;65N=#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W
M"FUS9VED(")!;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM
M<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I
M9"`B06QL($=R;W5P<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.CDQ(&9R86UE=V]R:R]097)M<R]097)M<R]D871A=')E
M92YP:'`Z-S4*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<Q"FUS9VED(")!;&QO=R!M=6QT:7!L
M92!A9&1R97-S97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4S-`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@
M='EP93\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4
M<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!;')E861Y(&5X:7-T<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(S"FUS9VED(")!;'1E
M<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3`W"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DY"FUS9VED
M(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B06QT
M97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T<B`B061R97-A('1A(&1E($5M
M86EL.B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E
M<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B
M06QT97)N871E('1E>'0Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@
M(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB
M"FUS9W-T<B`B4RUA('-P96-I9FEC870@;R!V86QO87)E(&EN8V]R96-T82XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38W"B,L(&9U>GIY
M"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R
M("(\8CY!(&%P87)U="!O(&5R;V%R92!F871A;&$Z/"]B/B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-34*;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I
M9"`B06YG;VQA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I
M;&QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H
M<'-H96QL+G!H<#HS-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP
M.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@
M(D%P<&QI8V%T:6]N(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO
M;B!I<R!R96%D>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR
M,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX,S,*;7-G:60@(D%P<')O>&EM871E(%-I
M>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U
M-BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C8V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#$*
M;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@P"FUS9VED(")!<F-H:79E($YA;64B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D
M+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U
M('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI
M;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I
M<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED(")!<FUE;FEA;B`H05)-4T-)
M22TX*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*
M;7-G:60@(D%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<G5B
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B
M07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#(U"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B
M969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q,PIM<V=I9"`B07-S
M:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M(&=R;W5P+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H
M<#HX-PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E
M<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT
M('-H87)E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S$*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HX-@IM<V=I9"`B071T<FEB=71E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@
M(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N
M<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H
M879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER
M=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C,V"FUS9VED
M("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET
M8V@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP
M:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR
M8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@
M061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E
M8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@
M;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!
M=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS
M,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@
M861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R
M96UO=F4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD
M87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L
M9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I
M=F4@1&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#
M04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z
M(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I
M;VX@9F%I;&5D+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE
M8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C@U,0IM<V=I9"`B075T:&5N=&EC871I;VX@
M=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O
M('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD
M<SHB"FUS9W-T<B`B0VEM<'5R:2!D:7-P;VYI8FEL93HB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y
M"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C
M:V=R;W5N9"!#;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z
M.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Q"FUS9VED(")"86AR86EN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3<W"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(B(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")"87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,`IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED
M(")"96QI>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N:6XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I
M9"`B0FER=&AD87DB"FUS9W-T<B`B6FEU82!D92!N87-T97)E(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U,PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T
M:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DYO=&EF:6-A=&EO;B!L
M:7-T96YE<B`E<R!N;W0@9F]U;F0N("T@9&4@=')A9'5S(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]L87EO=70N:6YC.C@Y"FUS9VED(")";&]C:R!3971T:6YG
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P-0IM<V=I9"`B0F]O
M:VUA<FMS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(D)O<F1E
M<B(*;7-G<W1R(")(;W)D92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(D)O<F1E<G,B"FUS9W-T
M<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE
M9V]V:6YA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY
M-@IM<V=I9"`B0F]T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"
M;W1S=V%N82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@27-L86YD(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(D)R87II;"(*;7-G<W1R
M(")#;W)E<W!O;F1E;G1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@
M26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R
M"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"=6QL971E
M9"!,:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@
M1F%S;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U;F1I(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#0*(RP@
M9G5Z>GD*;7-G:60@(D--4R(*;7-G<W1R(")#5E,B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*
M;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38S"FUS9VED(")#86-H
M92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T(&-O;F9I9R]H
M;V]K<RYP:'`N9&ES=#HY.#<*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$U-0IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B0V%L96YD87(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0V"FUS9VED(")#86QM(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8W"FUS9VED(")#86UE<F]O;B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO
M="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B!N;W0@
M=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S
M<VEO;G,N<&AP.C(R"FUS9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L
M('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C(S-2!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G-Q;"YP:'`Z,S$Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86XG
M="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R(").=2!M82!P
M;W0@8V]N96-T82!L82!S97)V97)U;"!D92!,1$%0+B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C0Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#
M86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T
M"B,L(&9U>GIY"FUS9VED(")#86YA9&$B"FUS9W-T<B`B0V%L96YD87(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L
M(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(E)E;G5N=&$@;&$@4F%P;W)T(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z
M-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R
M9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C,Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN
M;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]$871A5')E92]$871A5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$
M871A5')E92]$871A5')E92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z
M-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I
M97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R
M("(*(G-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U
M=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*
M(RP@9G5Z>GD*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B3W!T:75N:2(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM
M<V=I9"`B0V%R<FEE<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3`*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R(")496QE9F]N($UO8FEL
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR-0HC+"!F=7IZ>0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S
M='(@(E1E;&5F;VX@36]B:6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(W-`HC+"!F=7IZ>0IM<V=I9"`B0V5L;'!H
M;VYE(@IM<V=S='(@(E1E;&5F;VX@36]B:6PB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$W.`IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B0V5N=')A;"!%
M=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.3D*;7-G:60@(D-E<G1I9FEC871E
M($1E=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV,3$*;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV
M"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#@*(RP@9G5Z>GD*;7-G:60@(D-H860B"FUS9W-T<B`B=D-A<F0@
M+2!D92!T<F%D=7,B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,L(&9U>GIY"FUS
M9VED(")#:&%N9V4B"FUS9W-T<B`B06YU;&5A>F$@4V-H:6UB87)I;&4B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G:60@(D-H86YG
M92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-@IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R
M97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@
M=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P
M87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N
M9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(W"B,L(&9U>GIY"FUS9VED(")#:&%R(@IM<V=S='(@
M(G9#87)D("T@9&4@=')A9'5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN
M:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")#
M:&EL92(*;7-G<W1R(")4:71L=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED
M(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-H:6YE<V4@5')A9&ET
M:6]N86P@*$)I9S4I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR
M-C@*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3@*;7-G:60@(D-H;V]S92!H;W<@=&\@
M9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO
M;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C@Y,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S
M='(@(DYO=&EF:6-A=&EO;B!L:7-T96YE<B`E<R!N;W0@9F]U;F0N("T@9&4@
M=')A9'5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,30*(RP@9G5Z>GD*;7-G:60@(D-L96%R(@IM<V=S='(@(D-A;&5N9&%R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS9VED(")#;&5A<B!1=65R>2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS
M9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@
M(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI
M8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB
M;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G
M:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R("));F-H:61E(&9E<F5A<W1R82(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0T"FUS9VED(")#;&]U9',B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PIM<V=I9"`B0VQO
M=61Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-O8V]S("A+965L
M:6YG*2!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C0*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-0HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`P('-E<G9I8V5S+VEM86=E<R]C
M;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#0V"FUS9VED(")#
M;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30V"FUS9VED
M(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR-C0*;7-G:60@(D-O;6EC<R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]C;61S:&5L;"YP:'`Z,C4*(RP@9G5Z>GD*;7-G:60@(D-O;6UA;F0B
M"FUS9W-T<B`B0V]M<&%N:6$B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*
M;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")#;VUM96YT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38V
M"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM
M<V=I9"`B0V]M;W)O<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S
M='(@(D-O;7!A;FEA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS
M9VED(")#;VUP=71E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(Y-PIM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y"FUS9VED(")#;VYD:71I;VYS
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED
M(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#,*;7-G:60@(D-O;F9I9W5R871I;VX@
M9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O
M:RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM
M<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0HC+"!F=7IZ>0IM<V=I9"`B0V]N
M9FER;2!087-S=V]R9"(*;7-G<W1R(")087)O;&$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS
M9VED(")#;VYG;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG
M;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G
M:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T
M:6]N(&9A:6QE9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HX-#4*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E
M<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N
M9&ES=#HQ,#$T"FUS9VED(")#;VYT86-T<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O
M;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S
M<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HW.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@
M7"(E<UPB(@IM<V=S='(@(D-O;G1I;G5T=6P@;'5I("<E<R<@+2!D92!T<F%D
M=7,B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(D-O<'DB"FUS
M9W-T<B`B0V]M<&%N:6$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C0V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z
M("5S(@IM<V=S='(@(D-I;7`@:6UP;W)T870Z("5S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S
M96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDW-@IM<V=I9"`B0V]U;&0@;F]T
M(%!'4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-3,*;7-G:60@(D-O=6QD(&YO="!0
M1U`@<VEG;B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-
M12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-
M24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ,C$*(RP@9G5Z>GD*;7-G:60@(D-O
M=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(").=2!M82!P
M;W0@8V]N96-T82!L82!S97)V97)U;"!D92!,1$%0+B(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HT-3<*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O(&QD
M87`@<V5R=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I9"`B
M0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B3G4@
M;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@9&4@3$1!4"XB"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,C4*;7-G:60@(D-O
M=6QD(&YO="!D96-R>7!T(%!'4"!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,@IM<V=I9"`B0V]U;&0@
M;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU,PIM
M<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM
M86EL(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@
M9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM
M<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L
M:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H
M92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I
M;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA
M;F-E+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B3G4@<&]T
M(&1E<V-H:61E(&UO9'5L=6P@9&4@365N=&5N86YT82`E<R(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B3G4@<&]T
M(&1E<V-H:61E(&UO9'5L=6P@9&4@365N=&5N86YT82`E<R(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT
M-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C8Y.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E86-H
M('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3G4@;6$@<&]T(&-O;F5C=&$@
M;&$@<V5R=F5R=6P@9&4@3$1!4"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/
M8FIE8W0N<&AP.C(S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<F5A9"`E<RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O
M<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE
M("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE
M<B!H96QP+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS,#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S0P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,W-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS.#,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S@Y"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR
M,C,*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL
M:71I97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU
M-`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")(;W)D92!N=2!E<W1E(&-O;F9I9W5R870@8V]R97-P
M=6YZ871O<B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P
M(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E
M(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P
M(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#
M;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@
M8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@
M=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E
M(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C$T,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T('-E
M87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DYU(&UA('!O="!C;VYE
M8W1A(&QA('-E<G9E<G5L(&1E($Q$05`N(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C@V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N
M(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N
M9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S8V"FUS9VED(")#;W5L9&XG="!F:6YD('1H
M92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O
M<&5N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N
M)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@
M=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T,3D*;7-G:60@(D-O=6YT960@=&5X="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V
M.0IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C<S"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I
M9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E
M9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS9VED(")#<F5A=&4@82!N97<@
M;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*;7-G
M:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S(S,`IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M
M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R96YT(#0@4&AA
M<V5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HT.`IM<V=I
M9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E
M;G0@5&EM92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),
M(&ES(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS,PIM<V=I
M9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(U"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W-0IM<V=I9"`B0W5R
M<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T
M>6QE(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U
M<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@
M(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@
M*$M/23@M52DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@
M4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0U,2!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM
M<V=I9"`B1$0B"FUS9W-T<B`B6EHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,C@Q"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N
M;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP
M:'`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(EII;&YI8R(*
M"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O
M=W-E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,C<Y"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,SDY"FUS9VED(")$871E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED
M(")$871E(%)E8V5I=F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,#<*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3(@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,R,@HC+"!F=7IZ>0IM<V=I9"`B1&%Y
M(@IM<V=S='(@(EII;&YI8R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU
M;6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$
M96-R96%S92!);F1E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*(RP@9G5Z>GD*
M;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B261E;G1I=&%T92!);7!L:6-I=&$B
M"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT
M-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHW
M-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R(")5=&EL
M:7IE87IA(%9A;&]R:2!);7!L:6-I=&4B"@HC.B!F<F%M97=O<FLO261E;G1I
M='DO261E;G1I='DN<&AP.CDQ"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM
M<V=S='(@(DED96YT:71A=&4@26UP;&EC:71A(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")$969A=6QT(%-H96QL(@IM
M<V=S='(@(DED96YT:71A=&4@26UP;&EC:71A(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,S(V"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW
M,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N
M:6YC.C$P('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED
M(")$96QE=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"FUS9VED(")$96QE=&4@0V5L
M;"(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G
M<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0IM<V=I9"`B1&5L
M971E($QO9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q"FUS
M9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E
M(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$
M96QE=&4@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@8V]L
M=6UN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS
M9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(Q"B,L
M('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E
M<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N
M<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*(RP@9G5Z>GD*
M;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R("))9&5N
M=&ET871E($EM<&QI8VET82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C
M=7)R96YT(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T
M92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!S
M971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR-3,*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE
M(%!R;V)L96TB"FUS9W-T<B`B1&5S8W)I92!P<F]B;&5M82(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.CDS."!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,P"B,L(&9U>GIY"FUS9VED(")$97-C
M<FEP=&EO;B(*;7-G<W1R(")$97-C<FEE<F4@8V]M<&QE=&$Z(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.34*;7-G:60@(D1E=&%I;',@*&%L
M<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3D*;7-G:60@(D1E=&%I;',@:&%V92!B
M965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(D1E
M=&%L:6D@:6YR96=I<W1R871E(&EN($Q/1R!P96YT<G4@861M:6YI<W1R871O
M<BXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$Y"FUS9VED(")$
M979E;&]P;65N="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(Q-PIM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,CDT"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U
M<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,C<*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I
M<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C
M=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V-@IM<V=I9"`B1&ES<&QA>2`R-"UH
M;W5R('1I;65S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3<*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R(")/<'1I=6YI
M(&1E($%F:7-A<F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M.38*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B
M"FUS9W-T<B`B3W!T:75N:2!D92!!9FES87)E(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HX-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$W"B,L(&9U
M>GIY"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R(")/<'1I=6YI(&1E
M($%F:7-A<F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DP
M"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*;7-G:60@(D1O(&YO="!D
M96QE=&4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E
M+G!H<"(*;7-G<W1R(")492!R;V<@;G4@86-C97-A(&1I<F5C="!M86EN=&5N
M86YC92YP:'`B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,B!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@
M9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H
M96-K('1H:7,@8F]X.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$
M;VUI;FEC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$;VUI;FEC
M86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N
M('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HX-#0*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@
M8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`W"FUS9VED(")$<F]P(&1O=VX@
M;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*
M;7-G:60@(D1R=6=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B12U-86EL(@IM<V=S
M='(@(D-O<F5S<&]N9&5N=&$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3(&=A=&5W
M87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E
M<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@(D52
M4B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(U('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@HC.B!T96UP;&%T97,O
M<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`@=&5M<&QA=&5S+W!O
M<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R
M-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,3`P"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!0
M97)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES<VEO
M;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N
M:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S8W"B,L('!H<"UF;W)M
M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF
M;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B161U8V%T
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"B,L('!H
M<"UF;W)M870*;7-G:60@(D5I=&AE<B!E;F%B;&4@:70@=&AE;CH@)7,L(&]R
M('5S92!T:&4@8F%S:6,@2%1-3"!V97)S:6]N.B`E<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V.0IM<V=I
M9"`B16UA:6PB"FUS9W-T<B`B16UA:6PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4V-2!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D
M:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-C@*(RP@9G5Z>GD*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B061R
M97-A('1A(&1E($5M86EL.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Y-C,*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@Y"B,L(&9U
M>GIY"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")!
M;'1E(&EN9F]R;6%T:6DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N
M97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(Y.`HC+"!F=7IZ>0IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@
M(D]P=&EU;FDB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#(*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(&UE<W-A9V4N
M(@IM<V=S='(@(D5M<'1Y(')E<W5L="X@+2!D92!T<F%D=7,B"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-S`U"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED
M(")%;7!T>2!R97-U;'0N(@IM<V=S='(@(D5M<'1Y(')E<W5L="X@+2!D92!T
M<F%D=7,B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S
M"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4T,PIM<V=I9"`B16YA8FQE(&EN<V5R=&EO
M;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q.`IM<V=I9"`B
M16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y."!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.#$Q"FUS9VED(")%;F0@>65A<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS
M9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C(Q"FUS9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U
M97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O
M(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA
M;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED
M(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,0IM<V=I9"`B
M16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H
M<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#4@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C4U"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S8@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HX,@IM<V=I9"`B17)R
M;W(B"FUS9W-T<B`B17)O87)E(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E
M;7!L871E+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E
M871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E
M;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S86=E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*;7-G:60@
M(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B3R!D871A(&QA(#$U(&UI;G5T
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#D*(RP@9G5Z>GD*;7-G
M:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R("),82!F:65C87)E(#4@;6EN
M=71E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S
M='(@(D\@9&%T82!L82`S,"!S96-U;F1E(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,S."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(")%
M=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B3&$@9FEE8V%R92`U(&UI;G5T92(*
M"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`*
M;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(DQA(&9I96-A<F4@0V]N96-T
M87)E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,`IM<V=I9"`B179E
M<GD@:&%L9B!H;W5R(@IM<V=S='(@(D\@9&%T82!L82`S,"!M:6YU=&4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,W(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.#@*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R("));B!F:65C
M87)E(&UI;G5T(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*
M;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R(")%>&5M<&QE(&1E('9A
M;&]R:3HB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z.#$@861M:6XO8VUD<VAE
M;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C<*;7-G:60@(D5X96-U
M=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z-#<U"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,@IM<V=I9"`B17AP86YD(%-I9&5B
M87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N
M<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C
M=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED
M(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S8*;7-G:60@(D5X<&]N96YT(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G:60@(D944"!U<&QO860@;V8@
M<V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-Q
M;"YP:'`Z,C$V"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E
M<RXB"FUS9W-T<B`B3G4@<&]T(&-I=&D@<')E9F5R:6YT96QE+B(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T
M;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3G4@;6$@<&]T(&-O;F5C=&$@;&$@
M<V5R=F5R=6P@9&4@3$1!4"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M
M8BYP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O
M(%--0B!S97)V97(N(@IM<V=S='(@(DYU(&UA('!O="!C;VYE8W1A(&QA('-E
M<G9E<G5L(&1E($Q$05`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HV.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O
M;2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-CDQ"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@
M=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(DYU(&UA('!O="!C;VYE8W1A
M(&QA('-E<G9E<G5L(&1E($Q$05`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%3
M3"!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C0Y-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R-`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@
M7"(E<UPB+B(*;7-G<W1R(").=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U
M;"!D92!,1$%0+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8Q
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE
M=F4Z("5S(@IM<V=S='(@(DYU('!O="!C:71I('!R969E<FEN=&5L92XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I
M9"`B1F%I<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N
M9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM
M<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0TQ)+T-,22YP:'`Z,C,X"B,L(&9U>GIY"FUS9VED(")&871A;"!%<G)O<CHB
M"FUS9W-T<B`B17)O87)E(&1E(&EN=')A<F4Z(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S
M='(@(D9A>"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#D*(RP@
M9G5Z>GD*;7-G:60@(D9A>&5S(@IM<V=S='(@(D9A>"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,`IM<V=I
M9"`B1F5E;',@3&EK92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*
M;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3
M:&]W97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Y-#0*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,T"FUS9VED(")&:6=L970@0T%05$-(
M02(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X
M"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS
M9VED(")&:6II(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B1FEL92(*;7-G<W1R(")4:71L
M=2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M
M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0P-PIM<V=I9"`B1FEL92!-86YA9V5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,`HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U"B,L(&9U
M>GIY"FUS9VED(")&:6QE($YA;64B"FUS9W-T<B`B3G5M92(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34*;7-G:60@(D9I;&4@<V5L96-T:6]N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.#8*
M;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M<F]W<V5R+T)R;W=S97(N<&AP.C@U.0IM<V=I9"`B1FEL92!U<&QO861S(&YO
M="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HX.0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM
M<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4V"FUS9VED(")&:7@@<F%T
M:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(S,0IM<V=I9"`B1FQI<"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS
M9VED(")&;&]A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C,T(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R
M("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L
M;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS
M9VED(")&;V]D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R
M;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S0*;7-G:60@(D9O<F5C87-T("A4
M048I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HW.0IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R
M971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@
M82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E
M(&)L;V-K*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C(*;7-G:60@(D9O
M<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM
M<V=I9"`B1F]R='5N92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(D9O<G1U
M;F5S(@IM<V=S='(@(DYO=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0U,PIM<V=I9"`B1F]R=6US(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#D*;7-G:60@(D9O<G=A
M<F1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*(RP@
M9G5Z>GD*;7-G:60@(D9R86UE<R(*;7-G<W1R(").=6UE(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T
M:&5R;B!497)R:71O<FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,`HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-#`V"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*(RP@9G5Z
M>GD*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B1&5S8W)I97)E
M(&-O;7!L971A.B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(D9U;&P@3F%M92(*
M;7-G<W1R(").=6UE;&4@=&%U.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME
M(&EM86=E(&9R;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL
M97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB:6$B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX
M"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T
M"FUS9VED(")'96]R9VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@
M(D=E<FUA;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U
M"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R
M.`IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C,W"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*
M;7-G:60@(D=R965C92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA
M;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z
M(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S."!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF;W)M870*;7-G:60@(D=R
M;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS
M9VED(")'=6%D96QO=7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED
M(")'=6%M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%T96UA
M;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,`HC+"!F=7IZ>0IM<V=I9"`B
M1W5E<W1B;V]K(@IM<V=S='(@(D%G96YD82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@
M(D=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE
M82U":7-S874B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA
M;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.38P
M"FUS9VED(")(5$U,(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@
M<F]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ-3<*;7-G
M:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#`*;7-G:60@(DAA:71I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!
M;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Y,S(*;7-G:60@(DAE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"FUS9VED(")(
M96%D97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@
M27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")(
M96%V>2!4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@V"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92](96QP+G!H<#HQ-SD@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+TAE;'`N<&AP.C$X-@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ
M-R!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*;7-G
M<W1R(")(96QP(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W,0HC+"!F=7IZ>0IM
M<V=I9"`B2&5L<&5R(@IM<V=S='(@(DAE;'`B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T
M:&4@9FEL93HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DAI9V@B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C
M;VUM;VXM:&5A9&5R+FEN8SHU"B,L(&9U>GIY"FUS9VED(")(;U]M92(*;7-G
M<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6
M871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,34S-0HC+"!F=7IZ>0IM<V=I9"`B2&]M92(*;7-G
M<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D%D<F5S
M82!D92!A8V%S82(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`IM<V=I
M9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N
M92(*;7-G<W1R(")496QE9F]N=6P@9&4@86-A<V$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*
M;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I
M9"`B2&]N9R!+;VYG(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HV-0IM<V=I9"`B2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT
M97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0S-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F
M('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB
M)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I
M;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,#,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@
M;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0W"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT
M-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$Y,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y
M;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,V"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C,T
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S
M:&%R92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G
M:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@
M>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O
M;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W
M(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO
M8VLO;65T87(N<&AP.C(S,`IM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.0IM<V=I9"`B2'5M
M:61I='DZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*
M;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)U<RYP:'`Z,3<R(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L
M+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R
M96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X
M(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL
M8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q-@HC+"!F=7IZ>0IM<V=I9"`B
M25`@061D<F5S<R(*;7-G<W1R(")!9')E<V$B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A
M;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@
M;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@
M(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*
M;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,W-@IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R("(B"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M26-O;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-S<*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DP"FUS9VED("))9&5N=&ET>2=S
M(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C4Y,@HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N
M;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE
M=R!W:6YD;W<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT-34*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S
M:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@
M(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$W,PIM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T
M(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T
M(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0IM
M<V=I9"`B26UA9V4@55),.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@
M(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G
M:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("))
M;6%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI
M;F,Z-R!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHW"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P
M("5D(@IM<V=S='(@(D-I;7`@:6UP;W)T870Z("5S(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP
M;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(D-I;7`@:6UP;W)T870Z("5S(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T
M960@9FEE;&1S.B(*;7-G<W1R(")#:6UP=7)I(&EM<&]R=&%T93HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-0IM<V=I9"`B
M26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@HC
M+"!F=7IZ>0IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S
M=V]R9"XB"FUS9W-T<B`B5&4@<F]G(&EN=')O9'4@=6X@;G5M92!D92!U=&EL
M:7IA=&]R('-I(&\@<&%R;VQA(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E
M<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A
M9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I
M9"`B26YF;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C4W"B,L(&9U>GIY"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("))
M;F9O<FUA=&EI(&1E<W!R92!T:6YE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,S,`IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V
M86EL86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O
M;'5M;B!!9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R
M="!);6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N
M97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R
M96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE
M=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N
M="!N;V1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R
M86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N
M871E('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,SD*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H
M:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4X"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I
M9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B
M26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G
M:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*
M;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I
M9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(S,`IM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A
M;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS
M9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN
M<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS=69F
M:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES
M="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-S4*
M;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3$S,PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII
M<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N
M<&AP.C(P,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H
M<#HR,3`*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L
M:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A=&-H
M($E$+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,#@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-3@*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(S,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,CDY"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z
M,S<*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H
M<#HX,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ
M,#`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,C(P
M"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S<*;7-G:60@(DEN=F%L:60@
M;&EC96YS92!K97DN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-S$*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I
M7VED+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN
M9R!P87)A;65T97)S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C
M:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-S,*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-0IM<V=I9"`B26YV86QI
M9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI
M9"!P<F]T;V-O;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R
M96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C$P-S8@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,C8R"FUS9VED("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3<*;7-G:60@(DEN=F5N
M=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-C<Y"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L86UI8R!297!U
M8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<F5L86YD(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED
M("))<VQE(&]F($UA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3=&]R
M;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M,C4*;7-G:60@(DES<W5E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#(*(RP@9G5Z>GD*;7-G:60@(DET86QY(@IM
M<V=S='(@(EII;&YI8R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@W"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"FUS9VED
M("(B"B)*879A<V-R:7!T(&AA<R!B965N(&1I<V%B;&5D(&]N('EO=7(@8G)O
M=W-E<B!A;F0@=&AI<R!P86=E(&UA>2!N;W0@8F4@(@HB9&ES<&QA>6EN9R!C
M;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V
M"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8T"FUS9VED(")+965P(&]R
M:6=I;F%L/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DME;GEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z
M.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R
M"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,
M96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`HC+"!F=7IZ>0IM<V=I
M9"`B2V5Y(%5S86=E(@IM<V=S='(@(DUE<V%J(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR96%D>2!E>&ES
M=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+
M;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#@*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@
M(DQA;F=U86=E(@IM<V=S='(@(DQI;6)A(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED
M("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"FUS9VED
M("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),
M87-T(%%U87)T97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-3$*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@
M(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.C<R,0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN
M.B`E<R!F<F]M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.C<Q-@IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),87<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<Y"B,L(&9U>GIY"FUS9VED("),87EO=70B"FUS9W-T<B`B1&5C;VYE
M8W1A<F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$Q.0IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-0HC+"!F=7IZ>0IM
M<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`B17AE;7!L92!D92!V86QO<FDZ
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I
M9"`B3&5V96PB"FUS9W-T<B`B3FEC:6]D871A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS
M9VED("),:6)E<FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B
M3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT
M($1R:7IZ;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%)A:6XB
M"FUS9W-T<B`B0V]N96-T87)E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B
M3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@
M=VET:"!4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,30*(RP@9G5Z
M>GD*;7-G:60@(DQI;FLB"FUS9W-T<B`B0V]N96-T87)E(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS
M9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D
M<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR
M=&5X="YP:'`Z,3@S"FUS9VED("),:6YK<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI
M<W0@1&%T86)A<V5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD
M97@N<&AP.C4P"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(DQI
M<W1A('-U8FEE8W1E;&]R(&1I;B!(96QP(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$S,@IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.30*;7-G:60@(DQI<W0M
M07)C:&EV92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE
M861E<G,N<&AP.C4X.0HC+"!F=7IZ>0IM<V=I9"`B3&ES="U(96QP(@IM<V=S
M='(@(DQI<W1A('-U8FEE8W1E;&]R(&1I;B!(96QP(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12](96%D97)S+G!H<#HU.38*;7-G:60@(DQI<W0M260B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU
M.3(*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12](96%D97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP
M.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3`*;7-G:60@(DQI<W0M
M56YS=6)S8W)I8F4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C4P"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I
M;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!F86EL960Z("5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI
M;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E
M<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&ET:'5A
M;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEM86=E<RYP:'`Z.#,*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,0IM<V=I9"`B3&]C
M86P@=&EM93H@(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX,PIM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HV-`HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV-0IM<V=I9"`B3&]C871I;VXB"FUS
M9W-T<B`B(@H*(SH@;&]G:6XN<&AP.C$W,B!S97)V:6-E<R]P;W)T86PO<VED
M96)A<BYP:'`Z,3DQ('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*(SH@
M=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(D-O;F5C=&%R
M92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B
M3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3@U"FUS9VED("),;V<@;W5T
M(@IM<V=S='(@(D1E8V]N96-T87)E(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C4Y"B,L(&9U>GIY"FUS9VED("),;V=I;B(*;7-G<W1R(")#;VYE8W1A
M<F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"B,L(&9U>GIY"FUS
M9VED("),;V=I;B!487-K<R(*;7-G<W1R(")387)C:6YI(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z.3DV"B,L(&9U>GIY"FUS9VED("),;V=I;B!F
M86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E
M;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)0<F]B;&5M82!C=2!#
M;VYE8W1A<F5A+B!0<F]B86)I;"!N=6UE;&4@9&4@571I;&EZ871O<B!S874O
M<VD@4&%R;VQA('-I;G0@(@HB9W)E<VET92XB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HY.3(*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-0HC+"!F=7IZ>0IM
M<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(D1E8V]N96-T87)E(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS
M9VED("),;W<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E
M96L@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L
M871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R
M(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED
M("),=7AE;6)O=7)G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#`*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0S."!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU
M,`IM<V=I9"`B34TB"FUS9W-T<B`B3$PB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C@Q"FUS9VED(")-3U1$(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU4
M3D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A
M<V-A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*
M(RP@9G5Z>GD*;7-G:60@(DUA9VEC(@IM<V=S='(@(D-O<F5S<&]N9&5N=&$B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#$*;7-G:60@(DUA:6PB
M"FUS9W-T<B`B0V]R97-P;VYD96YT82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HU,C(*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%L87=I(@IM<V=S='(@(D-O<F5S<&]N
M9&5N=&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")-86QI(@IM<V=S='(@(D-O
M<F5S<&]N9&5N=&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA
M;'1A(@IM<V=S='(@(D-O<F5S<&]N9&5N=&$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3$*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E
M9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO
M<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,34S"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#0*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-C@*;7-G:60@(DUA
M<%%U97-T(&UA<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*
M;7-G:60@(DUA<F-H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*(RP@9G5Z>GD*;7-G:60@
M(DUA<F=I;B(*;7-G<W1R(")!=&5N=&EE(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N
M+U5N<V5E;B!F;&%G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R
M(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T
M8VAI;F<@9FEE;&1S(@IM<V=S='(@(D-I;7!U<FD@<&]T<FEV:71E("T@9&4@
M=')A9'5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-@IM<V=I9"`B36%X
M('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,CDX"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU
M;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(Q-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS9VED
M(")-87AI;75M(&QE;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C$V"B,L(&9U>GIY"FUS9VED(")-96UB97)S(@IM<V=S='(@(DYO=&4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X"FUS9VED(")-96YU(&UO9&4Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@(DUE<V%J(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*
M(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R
M)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB
M"FUS9W-T<B`B365S86HB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"B,L(&9U>GIY"FUS9VED
M(")-97-S86=E('1Y<&4B"FUS9W-T<B`B365S86HB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(D1E=&%L:6D@:6YR96=I<W1R871E(&EN
M($Q/1R!P96YT<G4@861M:6YI<W1R871O<BXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN
M96-T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+WAM;')P8RYP:'`Z.#$@9G)A;65W;W)K+U)00R]24$,O<V]A
M<"YP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@
M:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]2
M4$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO
M="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S0@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HW-0IM<V=I9"`B365T<FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-0IM<V=I9"`B365X:6-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED
M(")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW-@HC+"!F=7IZ>0IM<V=I9"`B36ED9&QE(@IM<V=S='(@(D-O<F5S<&]N
M9&5N=&$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H
M<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S$P"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#(*;7-G
M:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M
M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S0*
M(RP@9G5Z>GD*;7-G:60@(DUI<G)O<B(*;7-G<W1R(")%<F]A<F4B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(
M5%107U)E<75E<W0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U
M(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T
M:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI
M<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI
M<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS
M9VED(")-;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-S0*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")-;V1E
M<F%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M.`IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G
M:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-S,*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.30*;7-G:60@(DUO;G1H
M(&%N9"!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC
M92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B
M3'5N87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-S(@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z,C4S"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S
M(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM
M<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO
M=61Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`Y"FUS9VED
M(")-;W9E($1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z-3$S"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$W"FUS
M9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C4P-0IM<V=I9"`B36]V92!5<"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3(T"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PHC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E('5P
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@T"FUS
M9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-34*
M;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,C0R"FUS9VED(")-=6QT:7!L92!S96QE8W1I
M;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P
M,`IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@(DUY($%C8V]U;G0@26YF
M;W)M871I;VXB"FUS9W-T<B`B26YF;W)M871I:2!D97-P<F4@=&EN92(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-30*;7-G:60@(DUY(%!O<G1A
M;"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z,3,V
M"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@
M1&\@3D]4($%G<F5E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q,2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3`R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N
M968N<&AP.C,X"FUS9VED(").86UE(@IM<V=S='(@(DYU;64B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW
M"FUS9VED(").875R=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@
M(DYE<&%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R
M;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA
M;F1S($%N=&EL;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!"87-E(%523"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X,PIM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*
M;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE
M='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!2979O
M8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N
M86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3@W"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3@P"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3$*;7-G:60@
M(DYE='=O<FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#(U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S4*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,X-@IM<V=I9"`B3F5V97(B"FUS9W-T<B`B
M3FEC:6]D871A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").97<@0V%L961O;FEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP
M.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H
M<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP
M:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N
M<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G92!T;R`E
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L
M;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@
M(DYE=R!-;V]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3F5W(%IE86QA;F0B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W
M"B,L(&9U>GIY"FUS9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`B4&%R;VQA
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU
M,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X.0HC+"!F=7IZ>0IM
M<V=I9"`B3F5W<R(*;7-G<W1R(").;W1E(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,P-0IM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-2!T96UP;&%T97,O9&%T
M82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-0IM<V=I9"`B3F5X
M="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*;7-G:60@
M(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HS-S(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HS-S8*(RP@9G5Z>GD*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R("))
M;F%P;VD@;&$@;W!T:75N:2(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP
M:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*
M;7-G:60@(DYI8V%R86=U82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*(RP@
M9G5Z>GD*;7-G:60@(DYI9V5R(@IM<V=S='(@(DYI8VEO9&%T82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S@P"FUS9VED(").:6=H="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYI=64B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I
M9"`B3F\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I
M9F8N:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D
M871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C$P-0IM<V=I
M9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z-SD@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C0U"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(V-PIM<V=I9"`B
M3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HU,`HC
M+"!F=7IZ>0IM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@
M34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3G4@97-T92!C;VYF:6=U
M<F%T82!A=71E;G1I9FEC87)E82!344PB"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R(")!
M;G5L96%Z82!38VAI;6)A<FEL92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@
M=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$V-R!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C4P,@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-S,*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B3G4@97-T92!C;VYF:6=U
M<F%T82!#871E9V]R:6$@4U%,(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX,C0*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R(").=2!S
M:6YT(&-O;F9I9W5R871E(%!R969E<FEN=&5L92!,1$%0(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HV-CD*(RP@9G5Z>GD*;7-G:60@(DYO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93
M+B(*;7-G<W1R(").=2!E<W1E(&-O;F9I9W5R871A($-A=&5G;W)I82!344PB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S$W"B,L(&9U
M>GIY"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R(").=2!E<W1E(&-O;F9I
M9W5R871A($-A=&5G;W)I82!344PB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L
M969T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P
M<&QI960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S
M97(N<&AP.C@W-PIM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R("(B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3(X(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$R,PIM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Y
M"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*
M;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS
M9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@
M(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z
M.3$*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HW-R!F<F%M97=O
M<FLO075T:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W!A;2YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3G4@
M97-T92!C;VYF:6=U<F%T82!A=71E;G1I9FEC87)E82!344PB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U"B,L(&9U>GIY"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R(").=2!E<W1E(&-O;F9I9W5R871A(&%U=&5N=&EF:6-A
M<F5A(%-13"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`HC
M+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3G4@97-T92!C;VYF:6=U<F%T82!A
M=71E;G1I9FEC87)E82!344PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C$R.#8*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y3
M4TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C
M97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G
M:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C<U,`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!Q
M=6]T82!S970N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*(RP@9G5Z>GD*;7-G:60@(DYO
M(')U;&5S(@IM<V=S='(@(DYO=&4B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HT-#D*;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#0*(RP@9G5Z>GD*;7-G:60@(DYO('-I9&5S(@IM<V=S
M='(@(DYO=&4B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X,PIM
M<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ,S@*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E
M8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$*(RP@9G5Z
M>GD*;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*
M;7-G<W1R(")492!R;V<@:6YT<F]D=2!U;B!N=6UE(&1E('5T:6QI>F%T;W(@
M<VD@;R!P87)O;&$B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP
M.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDW,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.3@Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY
M.3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M,#D*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R
M:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM
M<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN
M(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA
M=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PHC+"!F=7IZ>0IM<V=I
M9"`B3F]N92(*;7-G<W1R(")496QE9F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM
M<&QI8VET*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M.0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P
M"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED
M(").;W0@069T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#`X"FUS9VED(").
M;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX,PHC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U
M=%-T<F%T96=Y+G!H<#HY-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP
M:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`HC+"!F
M=7IZ>0IM<V=I9"`B3F]T('-E="(*;7-G<W1R(").;W1E(@H*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#,*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ
M-3@*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R
M+G!H<#HQ-S,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(
M86YD;&5R+G!H<#HQ.#<*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E
M<W-I;VY(86YD;&5R+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y
M,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`U(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(T."!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,C8U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR.#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(Y-PHC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,S$R(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,CD*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V,B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z-#(R"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU,#$@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C4W,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3@W
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HV-C4*;7-G:60@(DYO="!S=7!P;W)T
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$W.`IM<V=I9"`B3F]T97,B"FUS
M9W-T<B`B3F]T92(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS
M-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U
M"B,L(&9U>GIY"FUS9VED(").;W9E;6)E<B(*;7-G<W1R(").:6-I;V1A=&$B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V"B,L(&9U>GIY"FUS
M9VED(").=6UB97(B"FUS9W-T<B`B3G5M92(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T,C4*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-CD@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,PHC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-#0U('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30T,R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@
M(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I
M8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM
M<V=I9"`B3V)J96-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A
M;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C8*;7-G
M:60@(D]F9FEC92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T
M(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C,V"B,L(&9U>GIY"FUS9VED(")/;&0@<&%S<W=O<F0B
M"FUS9W-T<B`B4&%R;VQA(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C0V"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM
M<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R
M<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS
M9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-S$*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL
M;W=E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI
M<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M
M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M:69R86UE+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR
M-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A
M=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P
M97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")/<'1I
M=6YI(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I
M;VYS(&9O<B`E<R(*;7-G<W1R(")/<'1I=6YI(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,
M:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-38W"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R
M9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$S,@IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@
M87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@
M=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM
M<V=I9"`B3W1H97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDV(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Q,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(R"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S$@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$T,0IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B06QT
M92!I;F9O<FUA=&EI(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS
M,0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N
M=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED
M(")014%2.CI-86EL(&)A8VME;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(W,PIM<V=I9"`B4$=0($1I9VET86P@
M4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$S,3D*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S<Q
M"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4S"FUS9VED(")01U`@4VEG;F5D
M+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL
M+G!H<#HV.`HC+"!F=7IZ>0IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B2&]R
M9&4B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L
M;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS-PIM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I
M9"`B4$T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M,`IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")032!3
M=6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N
M<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T
M.0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V"FUS9VED(")0
M861D:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%K:7-T
M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L874B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R
M<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G
M:60@(E!A;F%M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A
M<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I
M9"`B4&%R86=U87DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS
M9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$X,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4S-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q.`HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<W('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-#,*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0R,PIM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B4&%R;VQA(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R
M9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(R"B,L(&9U>GIY"FUS9VED
M(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B4&%R;VQA(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S<W=O
M<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,PIM<V=I9"`B
M4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"B,L(&9U>GIY"FUS9VED(")0
M87-S=V]R9#HB"FUS9W-T<B`B4&%R;VQA(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VUO8FEL92YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D.B`B"FUS
M9W-T<B`B4&%R;VQA(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P,S0*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,3D@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED
M(")087-T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R
M9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O<F5M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU
M<',Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`HC
M+"!F=7IZ>0IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(E)O;&4@+2!D92!T<F%D
M=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R
M;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(D5X96-U=&$@3W!E
M<F%T:75N:6QE(&1E($UE;G1E;F%N=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#`V"B,L(&9U>GIY"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(D5X96-U=&$@3W!E<F%T
M:75N:6QE(&1E($UE;G1E;F%N=&$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G
M:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X-@IM<V=I9"`B4&5R
M;6ES<VEO;B!$96YI960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ-C$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ-C0*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M-C`*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-3@*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-0HC+"!F
M=7IZ>0IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B06QT
M92!I;F9O<FUA=&EI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(E1E;&5F;VXB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<X"FUS9VED(")0:&]T;W,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@
M=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C4W,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N
M=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E
M<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#$*;7-G:60@(E!L96%S92!E
M;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C`*;7-G:60@(E!L96%S92!E;G1E<B!A
M('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@
M;6]N=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(T-3$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G
M:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB
M"FUS9W-T<B`B5&4@<F]G('-P96-I9FEC82!U;B!S=6UA<B!A;"!P<F]B;&5M
M96DN(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y
M;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R(")492!R;V<@:6YT
M<F]D=2!U;B!N=6UE(&1E('5T:6QI>F%T;W(@<VD@;R!P87)O;&$B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S92!R
M96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T
M:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P
M"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I
M8W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X
M-PIM<V=I9"`B4&]L;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I
M9"`B4&]R='5G86PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I
M=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I
M=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O
M('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F
M;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Y.`IM<V=I9"`B4')E8VEP:71A=&EO;CQB
M<B`O/F-H86YC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$
M05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S
M97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(U"FUS9VED
M(")0<F5S<W5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(U.0IM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B
M4')E<W-U<F4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C`U"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE
M=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM
M86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C,V,B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C,V-@HC+"!F=7IZ>0IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*
M;7-G<W1R("));F%P;VD@;&$@;W!T:75N:2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M
M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0HC+"!F=7IZ>0IM<V=I
M9"`B4')O8FQE;2(*;7-G<W1R(");4F%P;W)T(%!R;V)L96UA72(*"B,Z('-E
M<G9I8V5S+W!R;V)L96TN<&AP.C$R-@IM<V=I9"`B4')O8FQE;2!$97-C<FEP
M=&EO;B(*;7-G<W1R(")$97-C<FEE<F5A('!R;V)L96UE:2(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS-CD*;7-G:60@(E!R;VIE8W1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3$@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$X.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,C@U"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI
M8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0T
M"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I
M=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@4FEC;R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1871A<B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B475O
M=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@
M*"5D(&)I="DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(V-`IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED
M(")286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS
M9VED(")286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@4VAO=V5R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0W"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")2
M86EN('1O(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M.#`*;7-G:60@(E)E860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*(RP@9G5Z>GD*;7-G:60@(E)E860@
M;65S<V%G97,B"FUS9W-T<B`B365S86HB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY
M(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A
M=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T
M-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(E)E9G)E
M<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"B,L(&9U>GIY"FUS9VED(")2969R97-H
M(%!O<G1A;"!6:65W.B(*;7-G<W1R(")296EM<')O<W!A=&5A>F$@4W5M87)U
M;"`M(&1E('1R861U<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y
M-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$S"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R,S4*;7-G:60@(E)E9V5X(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-#D*;7-G:60@(E)E;&%T:6]N
M<VAI<"!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*
M;7-G:60@(E)E;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,R-@IM<V=I9"`B4F5M87)K<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3$T"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G
M:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*(RP@
M9G5Z>GD*;7-G:60@(E)E;6]V92(*;7-G<W1R(")3=&5R9V4@<&5R96-H96$B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*(RP@9G5Z>GD*
M;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R(")3=&5R9V4@<&5R96-H96$B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34W
M"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*(RP@9G5Z>GD*;7-G
M:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(E-T97)G92!P97)E8VAE
M82(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")2
M96UO=F4@<&%I<B(*;7-G<W1R(")3=&5R9V4@<&5R96-H96$B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")296UO=F4@<V%V960@<V-R
M:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0R"B,L(&9U>GIY"FUS9VED(")296UO=F4@=&AE(@IM<V=S
M='(@(E-T97)G92!P97)E8VAE82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H
M:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q"B,L(&9U>GIY"FUS9VED
M(")296UO=F4@=7-E<B(*;7-G<W1R(")3=&5R9V4@<&5R96-H96$B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R(")3=&5R
M9V4@<&5R96-H96$B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP
M.C$S.`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T
M=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$U-PIM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@
M8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$W-"!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C4Q,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E
M<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B)W5I9"<@;F5S<&5C:69I8V%T(&EN(&-O;F9I9W5R871I82!D92!P<F5F
M97)I;G1E+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C<U(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,P"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HW,C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("(G=6ED)R!N97-P96-I9FEC870@:6X@8V]N
M9FEG=7)A=&EA(&1E('!R969E<FEN=&4N(@H*(SH@9G)A;65W;W)K+U5T:6PO
M571I;"YP:'`Z-S@Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U
M:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("(G=6ED)R!N97-P96-I9FEC870@:6X@8V]N9FEG=7)A=&EA(&1E
M('!R969E<FEN=&4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E
M<BYP:'`Z,S,U"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(P('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*(RP@9G5Z>GD*
M;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(E!A<F]L82(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED(")297-E="!9;W5R
M(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,S`*;7-G:60@(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE;&PN<&AP.C(X(&%D
M;6EN+W-Q;'-H96QL+G!H<#HV-@IM<V=I9"`B4F5S=6QT<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E
M<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM
M<V=S='(@(DEN87!O:2!L82!O<'1I=6YI(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,R"B,L(&9U
M>GIY"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B
M26YA<&]I(&QA(&]P=&EU;FDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P"FUS9VED(")2:6=H
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(Q
M"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$Q-PIM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B4F]L92`M(&1E('1R861U<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-0IM<V=I
M9"`B4F]T871E(#$X,"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(R"FUS9VED(")2;W1A=&4@3&5F="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C(X"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I
M9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3,*(RP@9G5Z>GD*;7-G:60@(E)U;&5S(@IM<V=S='(@
M(E)O;&4@+2!D92!T<F%D=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN
M<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,C`*;7-G:60@(E)U;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)
M344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-
M12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-A<VPN<&AP.C@Q"FUS9VED(")305-,(&%U=&AE;G1I8V%T
M:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HU,#0*(RP@9G5Z>GD*;7-G:60@(E--4R!-97-S
M86=I;F<B"FUS9W-T<B`B365S86HB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,C@S"FUS9VED(")344P@<W1A=&5M96YT(&9O<B!V
M86QU92!L;V]K=7!S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT,S$*;7-G:60@(E-32"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN
M<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")3
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")386EN="!(96QE
M;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T
M<R!A;F0@3F5V:7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED(")3
M86EN="!,=6-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")3
M86EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")386UO82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS
M9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.`IM<V=I9"`B4V%V92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L
M('!H<"UF;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(E-A;'9A>F$@3W!T:75N
M:2(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@
M3W!T:6]N<R(*;7-G<W1R(")386QV87IA($]P=&EU;FDB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C
M;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S
M('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A
M=F5D("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.CDS"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D
M('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS
M9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R,`IM<V=I9"`B
M4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,CDW,PIM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0*
M(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B1F]R;6%T
M=6P@9&4@869I<V%R92!A(&1A=&5I.B(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I
M9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V
M"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"FUS9VED
M(")396QE8W0@86QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(V-C,*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C
M;VUP;VYE;G1S+B(*;7-G<W1R(")&;W)M871U;"!D92!A9FES87)E(&$@9&%T
M96DZ(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<X"FUS9VED
M(")396QE8W0@;F]N92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R
M9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C
M=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T
M:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A
M+B(*;7-G<W1R("(B"B)!;&5G92!C87)A8W1E<F5L92!D92!C87)E(&%I(&YE
M=F]I92!D:6X@8V%S=71E;&4@9&4@;6%I(&IO<RX@5F5I('!U=&5A(&%P;VD@
M(@HB<V$@;&4@8V]P:65Z:2!I;B!Z;VYA(&1E('1E>'0N(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D
M96QI;6ET97(Z(@IM<V=S='(@(D1E;&EM:71A=&]R(&1E(&1A=&$Z(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@
M9&%T92!F;W)M870Z(@IM<V=S='(@(D9O<FUA='5L(&1E(&%F:7-A<F4@82!D
M871E:3HB"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC
M.CDP"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H
M86YG93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z
M,38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z
M(@IM<V=S='(@(D1E;&EM:71A=&]R(&1E(&1A=&$Z(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M
M870Z(@IM<V=S='(@(D9O<FUA='5L(&1E(&%F:7-A<F4@82!O<F5I.B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T
M=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R(")396QE8W1E87IA(&1O=6$@
M8VEM<'5R:2!P;W1R:79I=&4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,P-@IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0X"FUS9VED(")396QE
M8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(E-E;&5C=&5A
M>F$@;&EM8F$@<')E9F5R871A.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S
M='(@(E1R:6UI=&4@4F%P;W)T(&1E($5R;V%R92(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#,Y"FUS9VED(")396YD(%--
M4R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$V"FUS9VED(")3
M96YS;W(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED
M(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E-E<FEA;"!.
M=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$V,0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"FUS
M9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S
M<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ
M-#4*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@(E-A;'9A>F$@
M3W!T:75N:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,30*;7-G
M:60@(E-E="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-S8*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y
M;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B4V5T('5P
M(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@
M>6]U<B!P;W)T86PN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX-`HC+"!F=7IZ>0IM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA
M;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R(")!
M;&5G92!T:6UP=6P@9&4@<F5I;7!R;W-P871A<F4@82!P86=I;FEI('-I(&%L
M=&4@;W!T:75N:2!D92!A9FES87)E+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY.`HC+"!F=7IZ>0IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A
M<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N
M9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(D%L96=E('1I
M;7!U;"!D92!R96EM<')O<W!A=&%R92!A('!A9VEN:6D@<VD@86QT92!O<'1I
M=6YI(&1E(&%F:7-A<F4N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW
M-0IM<V=I9"`B4V5T=7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A9&4@<V-R
M:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$X-@IM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S
M<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DV"FUS9VED(")3:&]P<&EN9R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PHC
M+"!F=7IZ>0IM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R(")3=6UA<B!S
M8W5R=#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0V"FUS9VED(")3
M:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W
M965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B
M"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#DP"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N
M(&QO9V=I;F<@:6X_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$W-C4*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN
M86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q
M,PIM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4R-@IM<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS
M(&UE;G4@8F%R/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S0Y"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@
M;VX@=&AE(&QE9G0_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T
M:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W
M(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B
M4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,PIM<V=I9"`B4VAO=R!U
M<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@
M(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,@3&%T92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#@P
M"FUS9VED(")3:')I;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z-S<T(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C@S-@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HY,C(@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3@T
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P-#<@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`X-PHC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,3$V(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C$Q-#D*;7-G:60@(E-H<FEN:R!O<B!M;W9E
M(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C(V-0IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-S$Q"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HX-R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HX.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R-#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(S"FUS9VED(")3:7IE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH
M=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(E-A<FD@
M<&5S=&4@365N=&5N86YT82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A
M:VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4T"FUS9VED(")3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W(%-H
M;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS
M9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N;W<@
M4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C<X"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U:79A;&5N="!I
M;B!W871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O
M;&]M;VX@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED
M(")3;VUA;&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(V"FUS9VED(")3;W)T(&]R9&5R('-E
M;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"B,L(&9U>GIY"FUS9VED(")3
M;W5R8V4@861D<F5S<R(*;7-G<W1R(")!9')E<V$@;&$@4V5R=FEC:74B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E-O=71H($5U<F]P
M96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G
M:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L
M;',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A
M;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#$U"FUS9VED(")3<&%C97(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P
M"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I
M;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@
M(E-P86EN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HY.`IM<V=I9"`B4W!A;2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB
M;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM
M<V=S='(@(D-A<F%C=&5R92!3<&5C:6%L92`N+BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED(")3
M<&QI="!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"B,L(&9U>GIY"FUS9VED
M(")3<&]R=',B"FUS9W-T<B`B26UP;W)T(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED
M(")3<FD@3&%N:V$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C<S(&QI8B]";&]C:R]M971A<BYP:'`Z-S0*(RP@9G5Z>GD*
M;7-G:60@(E-T86YD87)D(@IM<V=S='(@(D-A;&5N9&%R(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#`Y"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P"FUS
M9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*(RP@
M9G5Z>GD*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(DEN9F]R;6%T
M:6D@9&5S<')E('1I;F4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4W,@HC+"!F=7IZ>0IM<V=I9"`B4W1R965T($%D9')E<W,B"FUS
M9W-T<B`B061R97-A(&QA(%-E<G9I8VEU(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G
M:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,S
M"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T
M:&4@861D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-3
M72(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R("(B"@HC.B!U=&EL+VEC
M;VY?8G)O=W-E<BYP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(").;W1I
M9FEC871I;VX@;&ES=&5N97(@)7,@;F]T(&9O=6YD+B`M(&1E('1R861U<R(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*
M;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S,R(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP
M.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@
M=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@
M:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$P-`HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3
M=6-C97-S(@IM<V=S='(@(E-U8V-E<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S
M7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A
M<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D
M96QE=&4N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO
M=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R
M979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U;&QY('-A
M=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL
M92`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C
M97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM
M<V=I9"`B4W5D86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@HC+"!F=7IZ>0IM<V=I9"`B
M4W5M;6%R>2(*;7-G<W1R(")3=6UA<G5L($UE=2(*"B,Z(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4Y"FUS9VED(")3=6YN>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-0IM<V=I9"`B4W5N<FES
M93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,3D*;7-G:60@(E-U;G-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C$X"FUS9VED(")3=6YS970Z("(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S<X"B,L(&9U>GIY"FUS9VED(")3=7!P;W)T
M(@IM<V=S='(@(DEM<&]R="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*(RP@9G5Z>GD*;7-G
M:60@(E-U<FEN86UE(@IM<V=S='(@(E5T:6QI>F%T;W(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`HC+"!F=7IZ>0IM<V=I9"`B
M4W5R;F%M92(*;7-G<W1R(")5=&EL:7IA=&]R(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM
M<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V
M"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30R"FUS9VED
M(")3>6YC34PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y
M=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E
M<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!
M<F%B(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")4+5-T;W)M(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q
M"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3
M=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-C8*(RP@9G5Z
M>GD*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(E1I=&QU(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U1A8FQE+G!H<#HQ,S0*(RP@9G5Z>GD*;7-G:60@(E1A8FQE
M(@IM<V=S='(@(E1I=&QU(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B
M;&5S970N<&AP.C4W"FUS9VED(")486)L92!3970B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-"!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A
M;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R
M"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VAO;VMS
M+G!H<"YD:7-T.CDY-B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@W"FUS
M9VED(")487-K<R(*;7-G<W1R(")387)C:6YI(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E1E;&5P:&]N92!.=6UB
M97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3`*;7-G
M:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C$T"FUS9VED(")496UP97)A='5R92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(S"FUS9VED
M(")496UP97)A='5R93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&5R
M871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8X-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B
M5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,S,V"FUS9VED(")497AT(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-S4*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T
M;W`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`HC+"!F=7IZ>0IM
M<V=I9"`B5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+B(*;7-G<W1R
M(")!:2!F;W-T(&1E8V]N96-T870N/&)R("\^375L='5M97-C(&-A(&9O;&]S
M97-T:2!S:7-T96UU;"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C@R,`IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G
M<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]";V]K+G!H<#HQ,CDR
M"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D
M+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*
M;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S
M=6-C97-S9G5L;'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O
M;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA
M<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D
M<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N
M9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO
M="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T
M:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@
M=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3$V.0IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO
M8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES
M="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@
M;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*
M;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+G!H<#HQ
M,3,*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S
M96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,3<U(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z-3$S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L
M9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C@@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO
M=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C$Y"FUS9VED(")4:&4@9FEL
M92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL
M92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O
M;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X
M,C(@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R
M965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E
M<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E
M('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R
M:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC
M=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y
M;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA
M="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@
M86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D
M+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R
M>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P<F5F<RYP:'`Z.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED
M96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@
M(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@
M9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`Q"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET
M:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES
M(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E
M860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@W-PIM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@
M;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I9"`B
M5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R
M(")!8V5A<W1A('9A;&]A<F4@=')E8G5I92!S82!F:64@;G5M97)I8V$N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C,Q"FUS9VED
M(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D
M95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E
M8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A
M8FQE('-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@
M=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-30*;7-G:60@(E1H92!Q=6]T
M92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S
M(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@
M<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C0T-@IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S
M:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R
M=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,S,P"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E
M>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HQ-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE
M(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S,Q,0IM<V=I9"`B5&AE('1E>'0@>6]U(&5N
M=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED
M97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@
M;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HS
M,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H
M92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H
M<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S
M879E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C0V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$U(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ,3D*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O
M=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C
M=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$W.`HC+"!F=7IZ>0IM<V=I9"`B5&AE
M<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R(").=2!E>&ES
M=&$@<')E9F5R:6YT92!D:7-P;VYI8FEL92XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HS-#(*;7-G:60@(E1H97)E(&%R92!N;R!P
M87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN
M('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@
M(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"@HC
M.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB)7-<(B!T
M;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T
M96TZ("(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<
M(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,34Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P
M;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P
M;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A
M;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DQ"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO
M860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H
M:7,@;65S<V%G92!P87)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N
M(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE
M;&0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R
M;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC
M=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@
M8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG
M('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E
M<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T
M('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES
M(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A
M;&ED('II<"!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,30U"B,L(&9U>GIY"FUS9VED(")4:&ES(&1O97,@;F]T('-E
M96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B06-E87-T
M82!V86QO87)E('1R96)U:64@<V$@9FEE(&YU;65R:6-A+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I
M9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN
M8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G
M:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W
M87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B
M(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G
M871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S
M(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T
M<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`U-PHC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X
M,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y
M.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-34W(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3DU."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`U"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P,CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C`W.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,30Y(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(R,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C0Q,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4T"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@R.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3,W(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,S,#8*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S@Q-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#(R"FUS9VED
M(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C,*;7-G:60@
M(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E
M9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.CDX.0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!F:65L9"!M
M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R(")!8V5A<W1A('9A;&]A
M<F4@=')E8G5I92!S82!F:64@;G5M97)I8V$N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@S-@IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O
M;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R
M(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR
M96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I
M<R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HT-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B
M($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I
M;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T
M:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H
M(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@
M82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C8*
M;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G
M<W1R(")686QO87)E82!M:6YI;6$@97-T92`Q(@H*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E
M<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ
M.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS
M9W-T<B`B06-E87-T82!V86QO87)E('1R96)U:64@<V$@9FEE(&YU;65R:6-A
M+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G
M:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N
M<R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-`IM<V=I9"`B5&EC:V5T
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(X
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I
M9"`B5&EM92(*;7-G<W1R(")4:71L=2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS.#8*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,Y"FUS
M9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P
M"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R(")4:71L=2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@
M(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD
M(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B
M"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B5&]D87DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM
M<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM
M<V=I9"`B5&]K96QA=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S$S"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*;7-G
M:60@(E1O<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B
M5')A;G-L871I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@
M(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS
M9VED(")4=6YI<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@
M(E1U<FME>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M,@IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP
M92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-CD*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T
M<B`B55),(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E
M<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"B,L(&9U>GIY"FUS9VED(")5
M4DPZ(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A:6YE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q,@HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y
M+B(*;7-G<W1R(").=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U;"!344PN
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED
M(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S
M:6=N:6YG('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,X.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA
M;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@U(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW
M-34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N
M9V4@=&\@)7,N(@IM<V=S='(@(DYU(&UA('!O="!C;VYE8W1A(&QA('-E<G9E
M<G5L(%-13"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE
M(&]F(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z-C@X(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`Q-@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#,T"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E
M<R\E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q
M;"YP:'`Z-#,U"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R
M=F5R+B(*;7-G<W1R(").=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U;"!3
M44PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,SD*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R
M(").=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U;"!344PN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(U(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#$*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P.0HC+"!F=7IZ>0IM
M<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(DYU(&UA
M('!O="!C;VYE8W1A(&QA('-E<G9E<G5L(%-13"XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C,V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-30@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,C4V"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYU(&UA('!O="!C;VYE8W1A
M(&QA('-E<G9E<G5L(%-13"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3(T"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&
M4R!F:6QE+B(*;7-G<W1R(").=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U
M;"!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR.#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C8U"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M
M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R(").=2!M82!P;W0@8V]N96-T82!L82!S
M97)V97)U;"!344PN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+W1A<BYP:'`Z-S8*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z
M:7`N<&AP.C<Y"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R-"!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Y.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='DN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE
M(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T."!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S-R!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS
M,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0T"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYU(&UA
M('!O="!C;VYE8W1A(&QA('-E<G9E<G5L(%-13"XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C0Q-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C0R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C(P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S`S(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z,C@X"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ
M-C<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X,`HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HS.#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,Y,0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HT,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C@P,PHC+"!F=7IZ>0IM<V=I9"`B56YA8FQE
M('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B3G4@
M<&]T(&EN<F5G:7-T<F$@<')E9F5R:6YT96QE(&EN('-E<VEU;F4@+2!D92!T
M<F%D=7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8P
M,PIM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z
M-#4Q(&9R86UE=V]R:R].971?24U34"])35-0+T%U=&@N<&AP.C$Q.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO
M;B!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P,0HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38V(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HQ-S$*(RP@9G5Z>GD*;7-G:60@(E5N86)L
M92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R(").=2!M82!P;W0@8V]N96-T
M82!L82!S97)V97)U;"!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HY,R!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P,@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C8T."!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.CDX"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C<W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S
M,PIM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@P
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(E5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R(").=2!M82!P;W0@8V]N96-T
M82!L82!S97)V97)U;"!344PN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HT-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&]P
M96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R(").=2!M82!P;W0@8V]N
M96-T82!L82!S97)V97)U;"!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C@S-0IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S
M:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C@V-@IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E
M=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"FUS
M9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C8Y"FUS9VED(")5;F%B;&4@=&\@
M<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$P-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F
M;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Y,PHC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").=2!M82!P
M;W0@8V]N96-T82!L82!S97)V97)U;"!344PN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HS,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-C<@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Q,"!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z,S(S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HR,3,*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C@U"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA
M8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L
M92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(DYU
M('!O="!T<F%D=6-E(&%C97-T(&1O8W5M96YT(%=O<F0@+2!D92!T<F%D=7,B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$T.2!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C$U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-SD*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X,2!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HQ-#,*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@
M9FEL92!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z.#0Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A
M('=I;&P@8F4@97AC965D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS
M9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B06YU;&5A>F$@4V-H:6UB87)I
M;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS
M9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE
M8W1I;VXZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S0Q"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,W.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS.#0*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S
M97)V97(@=&\Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B56YI
M8V]D92`H551&+3@I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5
M;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*
M;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HV.2!L:6(O0FQO8VLO;65T87(N<&AP.C<Q"FUS9VED(")5;FET<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN
M;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H
M05!)($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO
M=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.0IM<V=I9"`B56YK
M;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED
M(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,CDV
M"B,L(&9U>GIY"FUS9VED(")5;FYA;65D(@IM<V=S='(@(E5T:6QI>F%T;W(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y
M"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S
M($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I
M='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E
M(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL
M;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@V(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z.3,R"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@
M(E5P9&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC
M97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.0IM<V=I9"`B57!L
M;V%D(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#8*
M;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T
M;R!T:&4@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E
M<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P
M<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM
M<V=I9"`B57)U9W5A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S
M92!34TPB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M-`IM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O
M<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHR,0HC+"!F=7IZ>0IM<V=I9"`B57-E<B(*;7-G
M<W1R(")5=&EL:7IA=&]R(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E
M9VES=')Y+G!H<#HW,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I
M<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,0IM
M<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(D]P=&EU;FD@571I;&EZ871O
M<B(*"B,Z('-I9VYU<"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(E5S97(@4F5G
M:7-T<F%T:6]N(@IM<V=S='(@(D]P=&EU;FD@571I;&EZ871O<B(*"B,Z('-I
M9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N
M(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@86-C;W5N="!N;W0@
M9F]U;F0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW
M,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B
M57-E<FYA;64B"FUS9W-T<B`B571I;&EZ871O<B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*(RP@9G5Z>GD*;7-G
M:60@(E5S97)N86UE.B(*;7-G<W1R(")5=&EL:7IA=&]R(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B57-E<FYA
M;64Z("(*;7-G<W1R(")5=&EL:7IA=&]R(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-C,@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C4U"FUS9VED(")61E,@9&ER
M96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3$X"FUS9VED(")686-A=&EO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-C8*;7-G:60@(E9A
M;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,S@*;7-G:60@(E9A
M;&ED:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN
M=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#4V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L
M96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R-#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$V(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Y,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE
M<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$X-@IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-`IM<V=I9"`B5F%R
M:6%B;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU
M96QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M
M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G
M:60@(E9E<G-I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(R-@IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@
M(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C<P"FUS9VED(")697)Y($AI9V@B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-@IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@(E9I971N86UE<V4@*%9)4T-)22DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z.38R"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E
M>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5FEE=R!A<R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6
M:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.0IM<V=I9"`B5FES:6)I;&ET>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8S
M"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@
M(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.
M1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S
M"FUS9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HR.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL
M+G!H<#HR-S(@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N
M:6YG(@IM<V=S='(@(D%T96YT:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H
M97(@1F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C0R-PIM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y,@IM
M<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#,W"FUS9VED(")796(@4VET92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B4V%P=&%M:6YA;"(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"B,L(&9U>GIY"FUS9VED(")7
M96QC;VUE(@IM<V=S='(@(D)I;F4@86D@=F5N:70L("5S(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C4W"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS
M9W-T<B`B0FEN92!A:2!V96YI="!I;B!S:7-T96UU;"`E<R(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO;65N
M=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*;7-G
M<W1R(")":6YE(&%I('9E;FET+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5V5S=&5R;B`H
M25-/+3@X-3DM,34I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")7
M97-T97)N(%-A:&%R82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I
M;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T
M(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T
M:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V,0IM<V=I9"`B5VAE<F5I
M<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@(E=H:6-H('!L=6=I;G,@
M=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$R-0IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE
M(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G
M:60@(E=I9'1H('5N:70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$S"FUS9VED
M(")7:6MI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS,#`@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C4*;7-G:60@(E=I;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I;F0@16%R;'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,`IM<V=I9"`B5VEN
M9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$U-@IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(T,@IM<V=I9"`B5VEN9#H@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES
M9&]M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M.38*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O
M<FL@061D<F5S<R(*;7-G<W1R(")!9')E<V$@;&$@4V5R=FEC:74B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED
M(")7;W)K(%!H;VYE(@IM<V=S='(@(E1E;&5F;VX@;&$@4V5R=FEC:74B"@HC
M.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-CD@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG
M(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O
M=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HS,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F
M(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@
M9FEL92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(T,PIM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!"87-I8R!#
M;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5
M<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@
M3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV.#(*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R(")!
M02(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U
M-0HC+"!F=7IZ>0IM<V=I9"`B65E962(*;7-G<W1R(")!02(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3`X"FUS9VED(")9
M86AO;R$@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC
M92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R(")!
M;G5A;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*
M;7-G:60@(EEE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H
M92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z.#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@
M;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ-#$Q"FUS9VED(")9;W4@87)E(&YO="!A=71H
M96YT:6-A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO
M261E;G1I='DN<&AP.C,P,@IM<V=I9"`B66]U(&-A;B!N;W0@:&%V92!T:&4@
M)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DW-0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V
M86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1&%T82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U
M(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE
M('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"B,L(&9U>GIY
M"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(D]P
M=&EU;FEL92!A=2!F;W-T('-A;'9A=&4N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P
M=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P
M<F5F:7@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q.#@*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C
M:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HT-38*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R
M92!A(%9&4R!B86-K96YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@
M=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R
M97!O<G0N(@IM<V=S='(@(E1R96)U:64@<V$@9&5S8W)I:2!P<F]B;&5M82!I
M;F%I;G1E(&1E(&$@=')I;6ET92!R87!O<G1U;"XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S
M="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G
M:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB
M"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P
M96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@
M861D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@
M(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP
M:'`Z,3,X"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O
M('!E<F9O<FTN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED(")9;W4@;75S="!T>7!E
M(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED
M(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER
M960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B4V5S:75N96$@=&$@
M9&4@)7,@82!E>'!I<F%T+B!492!R;V<@<V$@9F%C:2!,;V<@26X@9&EN(&YO
M=2XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`HC+"!F
M=7IZ>0IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(D%D<F5S
M82!T82!D92!%;6%I;#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$R
M"B,L(&9U>GIY"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@
M(D%D<F5S82!T82!D92!%;6%I;#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@
M(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M871I:2!D97-P<F4@
M=&EN92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H
M86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN
M(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@
M86=A:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C,S"B,L(&9U>GIY"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B
M3G5M96QE('1A=3HB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI
M;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O
M97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B
M"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@
M;75S="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C:V5N
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T
M+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@
M9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R
M92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T
M;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S
M('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C4P"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R
M="!T:&ES(&9E871U<F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E
M<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O
M;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(U-PIM<V=I9"`B66]U<B!C=7)R96YT('1I
M;64@>F]N93HB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDV
M"B,L(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E
M96X@8VAA;F=E9"XB"FUS9W-T<B`B3W!T:75N:6QE(&%U(&9O<W0@<V%L=F%T
M92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X"B,L(&9U>GIY"FUS
M9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(DED96YT:71A
M=&4@26UP;&EC:71A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,0HC
M+"!F=7IZ>0IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(DYU;65L
M92!T874Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z,3`P,`HC+"!F
M=7IZ>0IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B
M3W!T:75N:6QE(&%U(&9O<W0@<V%L=F%T92XB"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE
M=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34T"B,L(&9U>GIY"FUS9VED(")9
M;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO
M;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(D]P=&EU;FEL92!A=2!F;W-T
M('-A;'9A=&4N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ
M-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS
M9W-T<B`B3W!T:75N:6QE(&%U(&9O<W0@<V%L=F%T92XB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H
M87,@8F5E;B!R97-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U
M<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.C<S,@IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP
M:7)E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G
M:60@(EIA:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA
M;6)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G
M:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U
M;W1E9"!497AT72(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H
M<#HX.`IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");4F%P;W)T
M(%!R;V)L96UA72(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO
M8VMS+FIS.C$S"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT
M<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O
M=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI
M;F4@)7,@;V8@)7-=(@IM<V=S='(@(EML:6YI82`E<R!D:6X@)7-=(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-30Q('1E;7!L871E<R]P;W)T
M86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R
M("(B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?1&%T851R964B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O=R(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0HC+"!F=7IZ
M>0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`B2&5L<"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B
M7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-`HC+"!F=7IZ>0IM<V=I9"`B7TQO
M9R!I;B(*;7-G<W1R(")#;VYE8W1A<F4B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O365N=2YP:'`Z,3DP"B,L(&9U>GIY"FUS9VED(")?3&]G(&]U="(*
M;7-G<W1R(")$96-O;F5C=&%R92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,
M:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-
M96YU+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@
M(D]P=&EU;FDB"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]097)M:7-S
M:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G:60@(E]296UO
M=F4@3&EN:RXN+B(*;7-G<W1R(")3=&5R9V4@<&5R96-H96$B"@HC.B!L:6(O
M87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*
M;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]A<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Q"B,L(&9U>GIY"FUS9VED(")A
M9&1R97-S(&)O;VLB"FUS9W-T<B`B06=E;F1A(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN
M;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3$S"B,L(&9U>GIY"FUS9VED(")C86QE;F1A<B(*;7-G<W1R(")#86QE;F1A
M<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G
M:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A
M;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C4Y,@IM<V=I9"`B8VQI8VL@:&5R92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R
M,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<X"FUS9VED
M(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S
M>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E
M<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS
M9VED(")F86QL:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R
M+T)R;W=S97(N<&AP.C@U-0HC+"!F=7IZ>0IM<V=I9"`B9FEL92(*;7-G<W1R
M(")4:71L=2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<T(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S8P(&QI8B]";&]C:R]M971A<BYP:'`Z,S@V"B,L('!H
M<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,`IM
M<V=I9"`B9W5S=&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Y"FUS9VED(")H.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4X
M"FUS9VED(")H:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T
M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K
M<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@
M;6%K:6YG($E33RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C,V.0IM<V=I9"`B;6TB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR.3$@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T86PO<VED
M96)A<BYP:'`Z,C,R"B,L(&9U>GIY"FUS9VED(")N86UE(@IM<V=S='(@(DYU
M;64B"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(Q"FUS9VED(")N;W0@
M:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HQ,C$Y"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`U
M"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E
M;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-S0*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R<F]R
M(&EN('!R;W1O8V]L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")R:7-I;F<B
M"FUS9W-T<B`B071E;G1I92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,30R"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.3D*;7-G:60@(G-H
M;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I
M;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S@U"FUS9VED(")S<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I
M9"`B<W1E861Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,S`Y"FUS9VED(")S=VET8V@@;V9F(&IA=F%S8W)I<'0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3`*
M;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDR.0IM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38V"FUS
M9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C,P-0HC+"!F=7IZ>0IM<V=I9"`B=')Y(&%G
M86EN(@IM<V=S='(@(DQA(&9I96-A<F4@0V]N96-T87)E(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V
M.0IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S
M971U<"]D:69F+G!H<#HW.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA
M;65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"`M(&1E('1R861U
M<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M-#$*;7-G:60@(G<Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*;7-G<W1R("(B"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!O+W)U7U)5+G!O````````````````````
M````````````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`V-C4S,C0`,3`U,34T
M,S,W-30`,#$W-S$Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````",@2&]R9&4@4G5S<VEA;B!T<F%N<VQA=&EO;BX*(R!#;W!Y
M<FEG:'0@*$,I"B,@26=N870@26MR>6%N;W8@/&EI9VYA=$!N97=M86EL+G)U
M/BP@,C`P,0HC($9E9&]R($$N($9E=&ES;W8@/&9A9D!S<V,N<G4^+"`R,#`R
M"B,@06QE>&5Y(%IA:VAA<F]V(#QB86)E<D!M;W-G82YN970^+"`R,#`V"B,*
M;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E
M('8S+C$M4D,S7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S
M+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#(M,#<@
M,3$Z,3`K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP,BTQ-R`Q
M-SHP,"LP,C`P7&XB"B),87-T+51R86YS;&%T;W(Z($%L97AE>2!:86MH87)O
M=B`\8F%B97)`;6]S9V$N;F5T/EQN(@HB3&%N9W5A9V4M5&5A;3H@4G5S<VEA
M;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N
M,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4-0,3(U
M,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHQ,0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB("8C,34Q.R`E<R!I<R!R96%D
M>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K
M960@8F5L;W<N(@IM<V=S='(@(B(*(L_PZ.ONYN7MZ.4@)7,@X^[R[N+N(.H@
M[O'S^>7Q\N+KY>WH_B#N[^7PX/;HZ2#O[N3DY?#FZN@L(.[R[.7WY>WM^_4@
M[>CFY2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4N<&AP.C$S-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K
M97D@)7,I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S@Q
M"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S<*;7-G:60@(B`H=&]D87DI
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S<Y"FUS9VED
M("(@*'1O;6]R<F]W*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C,W-0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#4@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,U,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,SDV"FUS9VED("(@870@(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,O<VUB
M+G!H<#HR,3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I
M<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@(LK@\N#K[N,B"@HC.B!L:6(O
M2&]R9&4O0TQ)+G!H<#HR-S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(MWR[B#G
M[>#WY>WHY2#D[NOF[>X@X?OR_"#WZ/'K[NPN(@H*(SH@;&EB+TAO<F1E+U)E
M9VES=')Y+G!H<#HW,3`@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#DX"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I
M9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R("+/\.CK[N;E
M[>CE("<E<R<@[>4@\>KN[?3HX_/PZ/#NXN#M[B#B($AO<F1E(%)E9VES=')Y
M(@H*(SH@;&EB+TAO<F1E+U1R964N<&AP.C$W,0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*
M;7-G<W1R("+`Y/#E\>#R(//BY>3N[.OE[>C_("5S(.WE(.W@Z>3E[2XB"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N
M<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@
M861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T
M<B`B(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-
M4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M
M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC
M7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I
M("`C+2,M(RTC+2-<;B(*(L_@[^K@(%PB)7-<(B#A^^O@(//Q[^7X[>X@[^7P
MY>CLY>WNXN#MX"#B(%PB)7-<(BY<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@
M*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M(UQN(@HB6_'R\.[JX"`E<R#HYR`E
M<UU<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N-BD@(",M
M(RTC+2,M(UQN(@HB6_'R\.[JX"`E<R#HYR`E<UU<;B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M(UQN(@HB6_'R\.[J
MX"`E<R#HYR`E<UU<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S
M+C`N-BD@(",M(RTC+2,M(UQN(@HB6_'R\.[JX"`E<R#HYR`E<UU<;B(*(B,M
M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M(UQN
M(@HB6_'R\.[JX"`E<R#HYR`E<UTB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D
M(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(LCQ[^[K_.?N
MXN#M[CH@)2XR9LSA(.CG("4N,F;,X2`H)2XR9B4E*2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,C8*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R(");\?+P[NK@("5S(.CG("5S
M72(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@
M=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<T"B,L('!H<"UF;W)M870*
M;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z-C@@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VYO
M=&EC95]T;W`N:6YC.C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S
M("T@3F]T:6-E(@IM<V=S='(@(L?@[.7RZN@B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C<P-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG
M97)P<FEN="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT
M<RYP:'`Z.#0P(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O;6%I;G1E;F%N8V4N<&AP.C0Y('1E;7!L871E<R]M86EN=&5N86YC92]C
M;VYF:7)M7W1O<"YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN
M=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(L[O
MY?#@]NC_(._NY.3E\.;JZ"`E<R`M(,_NY/+BY?#FY.7MZ.4B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR
M,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M
M86EN=&5N86YC92YP:'`Z-3D@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E
M;65N=%]T;W`N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@
M;V8@06=R965M96YT(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HT
M,S(@;&EB+U9&4R]S;6(N<&AP.C0Y-"!L:6(O5D93+V9T<"YP:'`Z-C@R"B,Z
M(&QI8B]61E,O9G1P+G!H<#HW-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@
M;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE
M+B(*;7-G<W1R("+.\NSE\OSRY2#TZ^#FZN#LZ"#N[^7PX/;H_BCHZ"DL(.KN
M\N[P^^4@POL@]>[RZ/+E(.[Q\_GE\?+BZ/+\+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,S0T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I
M<F5D(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N
M+G!H<#HQ,C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F
M;W5N9"XB"FUS9W-T<B`BP.3PY?'@\B#SXN7D[NSKY>WH_R`E<R#MY2#MX.GD
MY>TN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T
M<B`B6_'R\.[JX"`E<R#HYR`E<UTB"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z.3(Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R("+`Y/#E\>W@_R#J
M[>CCX"(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3$S"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(LK@Z^7M
MY.#P_"(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3`U"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`BQ^#LY?+J
MZ"(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3(Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O:'1M;"YP:'`Z,3(Q"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@
M8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK
M<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P
M97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,U-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,SDY"B,L(&9U>GIY"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@
M(EOQ\O#NZN`@)7,@Z.<@)7-=(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P
M-S,@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,S(@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HR.30*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS-#@@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T-@HC+"!F=7IZ>0IM<V=I
M9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N
M<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+$Y>GQ\N+HY3HB"@HC
M(&9U>GIY"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U
M<B!&;W)M870B"FUS9W-T<B`B,3(M]^#Q[N+NZ2(*"B,@9G5Z>GD*(SH@;&EB
M+T)L;V-K+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G
M<W1R("(R-"WWX/'NXN[I(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z
M,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T(/?@\>`B"@HC.B!L:6(O
M2&]R9&4O54DO4&%G97(N<&AP.C8Y"B,L(&9U>GIY"FUS9VED("(\4')E=FEO
M=7,B"FUS9W-T<B`BS_#EY/OD\_G@_R#Q\O#@[>CVX"(*"B,Z(&QI8B](;W)D
M92YP:'`Z,38R"B,L(&9U>GIY"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O
M8V-U<G)E9"(*;7-G<W1R("(\8C[/\.[HY^[XZ^`@ZO#H\NCWY?'JX/\@[OCH
MX>K@.CPO8CXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G
M:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A
M(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C$Q-C@*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C$P.3D*;7-G:60@(B(*(D$@<'5B;&EC
M(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#$V"FUS9VED("(B"B)!
M('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU,#8*;7-G:60@
M(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M
M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T
M92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K97D@
M:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*(RP@
M9G5Z>GD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R("+*[NSOX.WH_R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"B,L(&9U
M>GIY"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(L+U[N0B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0HC+"!F=7IZ
M>0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"B,L(&9U>GIY"FUS
M9VED(")!32!3:&]W97)S(@IM<V=S='(@(LCL[^[P\B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"B,L(&9U>GIY"FUS9VED
M(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`BR.SO[O#R(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(D%-
M+U!-(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*
M;7-G:60@(D%022!)1"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D
M:71O<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU
M,PIM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`HC+"!F=7IZ>0IM<V=I9"`B
M06)S8F]T=&]M(@IM<V=S='(@(L+LY?'RY2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*(RP@9G5Z>GD*;7-G:60@(D%B
M<VUI9&1L92(*;7-G<W1R("))35`B"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HR
M-S`*(RP@9G5Z>GD*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93
M(&1I<F5C=&]R>2XB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q
M(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HQ,S8*(RP@
M9G5Z>GD*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N
M(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P
M[NPN(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*;7-G:60@(D%C8V]U
M;G0@26YF;W)M871I;VXB"FUS9W-T<B`BT_?E\NW@_R#GX._H\?PB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@*(RP@9G5Z>GD*;7-G:60@(D%C8V]U
M;G0@4&%S<W=O<F0B"FUS9W-T<B`BS^#P[NO\(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*(RP@9G5Z>GD*;7-G:60@(D%C8V]U
M;G0@9G)O>F5N+B(*;7-G<W1R("+3[_#@XNOE[>CE(/'WY?+@[.@B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,U"B,L(&9U>GIY"FUS9VED(")!
M8V-O=6YT:6YG(@IM<V=S='(@(L3P\^/HY2#_^>CJZ"(*"B,@9G5Z>GD*(SH@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A
M9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N
M:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`BQ.[AX.+H\OPB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B
M061D($-H:6QD($=R;W5P(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z.3@@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HY.0HC+"!F=7IZ
M>0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*
M(LOH]^W[Y2(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC
M.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R("+$[N'@XNCR_#HB"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I
M9"`B061D($YE=R!'<F]U<"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C@W(&QI8B](;W)D92]097)M<R]522YP:'`Z.#@*(RP@9G5Z
M>GD*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R("+-X/'R\.[I
MZN@@[^[K_.?NXN#RY>O_(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B
M"FUS9W-T<B`BS>#Q\O#NZ>KH(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T-PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS
M9W-T<B`BS>#Q\O#NZ>KH(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@
M(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34T"B,L(&9U>GIY"FUS9VED(")!9&0@
M8V]L=6UN(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E
M('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U
M<F)A('8Q+C$I("`C+2,M(RTC+2-<;B(*(N3NX>#BZ/+\(/'R[NOAY?8B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"B,L(&9U>GIY
M"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`BQ.[AX.+H\OP@[^#P
M\R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D
M9"!P86ER(@IM<V=S='(@(L3NX>#BZ/+\(._@\/,B"@HC('!H<"UF;W)M870*
M(R!F=7IZ>2P@<&AP+69O<FUA=`HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S$*;7-G:60@(D%D9"!T:&4@)7,@365N
M=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R("+$[N'@XNCR_"!-;WII
M;&QA(%-I9&5B87(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*
M;7-G<W1R("+`Y/#E\>W@_R#J[>CCX"(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z-S@*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!M>2!A
M9&1R97-S(&)O;VLB"FUS9W-T<B`BP.3PY?'MX/\@ZNWHX^`B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B061D('5S97(B"FUS9W-T
M<B`BQ.[AX.+H\OP@[^#P\R(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M
M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA
M=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN
M(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$T-#4@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,*;7-G:60@(D%D
M9')E<W,B"FUS9W-T<B`BP.3PY?$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,30Q"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`BP.3PY?'M
MX/\@ZNWHX^`B"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,@9G5Z>GD*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS9VED(")!9&UI;FES
M=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R
M("+-X/'R\.[IZN@@+2#S\?+@[>[BZN`@[_#@XB#DZ_\@Y/#SX^CU(._NZ_SG
M[N+@\N7KY>DB"@HC(&9U>GIY"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES=')A
M=&EO;B(*;7-G<W1R("+3[_#@XNOE[>CE(@H*(R`C+2,M(RTC+2,@(')U7U)5
M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC"B,@9G5Z>GD*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,T,PHC+"!F=7IZ>0IM<V=I9"`B061S(@IM
M<V=S='(@(L3NX>#BZ/+\(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HU-@HC+"!F=7IZ>0IM<V=I9"`B069G:&%N:7-T86XB
M"FUS9W-T<B`BS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*(RP@9G5Z>GD*;7-G
M:60@(D%L8F%N:6$B"FUS9W-T<B`BS_'EXN3N[>CL(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C<T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`HC+"!F=7IZ>0IM<V=I
M9"`B06QG97)I82(*;7-G<W1R("+/\>7BY.[MZ.PB"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T
M<B`BS_'EXN3N[>CL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ-@HC+"!F=7IZ>0IM<V=I9"`B06QI9VXB"FUS
M9W-T<B`BS_'EXN3N[>CL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV-PHC+"!F=7IZ>0IM<V=I9"`B06QI9VYM96YT.B(*
M;7-G<W1R("+/\>7BY.[MZ.PB"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G
M:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(L+QY2#B[OCE
MY/CHY2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H
M<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`BPO'E(./P\^_O^R(*
M"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HY,2!L:6(O2&]R
M9&4O4&5R;7,O9&%T871R964N<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES<VEO
M;G,B"FUS9W-T<B`BPO'E(._PX.+@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PHC+"!F=7IZ>0IM<V=I9"`B
M06QL(&9O=7(@<VED97,B"FUS9W-T<B`BQ^#LY?+JZ"(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ.#<U"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S
M97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S.`IM
M<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS
M9W-T<B`BT.#G\.7XZ/+\(.[OY?#@]NCH(/'N(/'OZ/'JX.SH(@H*(SH@;&EB
M+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!;')E861Y(&5X
M:7-T<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(V
M"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R("+`Z_SRY?#M
MX/+HXNW[Z2!)4TU0(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3$Q"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R
M("+/X/#NZ_PZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P,PIM<V=I
M9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS9W-T<B`BR.S_(._NZ_SG
M[N+@\N7K_R!)4TU0.B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C,U"B,L(&9U>GIY"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*
M;7-G<W1R("+"X/@@16UA:6PZ(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(U"B,L(&9U>GIY"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T
M<B`BPN#X($5M86EL.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z.34@;&EB+TAO<F1E+U!R
M969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P
M96-I9FEE9"XB"FUS9W-T<B`BP?OK[B#SZN#GX.WN(.WEZN[P\.7J\NWNY2#G
M[>#WY>WHY2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34U
M"B,L(&9U>GIY"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D
M+B(*;7-G<W1R("(\8C[/\.[HY^[XZ^`@ZO#H\NCWY?'JX/\@[OCHX>K@.CPO
M8CXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X
M>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT
M.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R
M("(B"@HC(&9U>GIY"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO
M<&AP<VAE;&PN<&AP.C,U(&QI8B](;W)D92]";&]C:R]522YP:'`Z-3@*(SH@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P
M;&EC871I;VXB"FUS9W-T<B`BS_#HZ^[FY>WHY2(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HT,@HC+"!F=7IZ>0IM<V=I9"`B07!P;&EC871I;VX@3&ES
M="(*;7-G<W1R("+-X/'R\.[IZN@B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B
MS>#Q\O#NY>WN(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*
M;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P
M<F]V92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP
M:'`Z.#0P"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#,@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-`IM<V=I9"`B
M07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&QI8B](;W)D92]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8V"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP
M.C<X"B,L(&9U>GIY"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R
M("+([/\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU."!L
M:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=&=Z+G!H<#HW-PHC+"!F=7IZ>0IM<V=I9"`B07)C:&EV
M92!.86UE(@IM<V=S='(@(LCL_R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E
M('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E
M<W0@9F]R("5S(#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]D96QE=&4N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A
M;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`BPOL@\^+E\.7M^RP@]_+N(/7N\NCR
MY2#N]^CQ\NCR_"#]\O,@[^#OZO,_(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B07)G96YT
M:6YA(@IM<V=S='(@(L_QY>+D[NWH["(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(D%R;65N
M:6$B"FUS9W-T<B`BS_'EXN3N[>CL(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ-S4*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*
M;7-G:60@(D%R=6)A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I
M9FEC(%)E9VEO;B(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT,CD*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E
M9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R("+'
MX._PX/CHXN#R_"#O[N3RXN7PYN3E[>CE(._E\.7D(.+[[^[K[>7MZ.7L(.[O
MY?#@]NCI(.[A\>OSYNCBX.WH_S\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S$P,@HC+"!F=7IZ>0IM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S
M='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M
M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C
M+2,M(RTC+2-<;B(*(N3NX>#BZ/+\(/'R[NOAY?8B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES
M=&5N="!G<F]U<"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E
M;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`BS^[O^_+JX"#SY.#KZ/+\(.WE\?/Y
MY?'RXO/^^>CE(._PX.+@(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*
M;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S
M:6]N+B(*;7-G<W1R("+/[N_[\NK@(/#EY.#J\NCP[N+@\OP@[>7Q\_GE\?+B
M\_[YZ.4@[_#@XN`B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*
M;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C0@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#,*;7-G:60@(D%T=')I8G5T97,B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P-R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*
M;7-G:60@(D%U9W5S="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HU.0IM<V=I9"`B075S=')I82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E
M<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C
M>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI
M=&5S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z
M,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+V9T
M<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT
M96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B
M;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E
M9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!
M9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C
M=&]R>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS
M-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U
M<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!2
M97%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@
M)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#`U
M"FUS9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P
M;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]!=71H+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E
M<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A
M=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92])34%0+T%D;6EN+G!H<#HQ,#8*(RP@
M9G5Z>GD*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A
M:6QE9"XB"FUS9W-T<B`BS>7SY.#W[>[E(/'NY>3H[>7MZ.4@\2#QY?#BY?#N
M["!,1$%0+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDP"B,L(&9U>GIY"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS
M9W-T<B`BP.3PY?'@\B#SXN7D[NSKY>WH_R`E<R#MY2#MX.GDY>TN(@H*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-R!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(L#D
M\.7QX/(@\^+EY.[LZ^7MZ/\@)7,@[>4@[>#IY.7M+B(*"B,Z(&QI8B](;W)D
M92]!=71H+W)A9&EU<RYP:'`Z,3<V"B,L(&9U>GIY"FUS9VED(")!=71H96YT
M:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R("+-
MY?/DX/?M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N(@H*(SH@;&EB
M+U9&4R]F='`N<&AP.C@X,@HC+"!F=7IZ>0IM<V=I9"`B075T:&5N=&EC871I
M;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(LWE\^3@]^WNY2#Q
M[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"XB"@HC.B!L:6(O5D93+W-M8BYP
M:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O('1H92!3
M34(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`BS>7SY.#W[>[E(/'NY>3H[>7M
MZ.4@\2#QY?#BY?#N["!,1$%0+B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(L3N
M\?+S[^W[Y2#O[NO_.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHQ.`HC+"!F=7IZ>0IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R("+(\>_N
MZ_SG[N+@\OP@Y^W@]^7MZ.4@[^X@\^SNZ_?@[>C^(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PHC+"!F=7IZ>0IM<V=I
M9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R("+(\>_NZ_SG[N+@\OP@Y^W@
M]^7MZ.4@[^X@\^SNZ_?@[>C^(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP
M:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K
M97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C0U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B
M0F%H86UA<R(*;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")"
M86AR86EN(@IM<V=S='(@(DE-4"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3<V"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S0@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS
M9VED(")"86YG;&%D97-H(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HS,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM
M<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BP.3PY?'@\B#SXN7D[NSKY>WH
M_R`E<R#MY2#MX.GDY>TN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<S"B,L(&9U>GIY"FUS9VED(")"87-E;&EN
M92(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N
M,2D@(",M(RTC+2,M(UQN(@HBT^3@Z^7M[?OE(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C0Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S4@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8P"B,L(&9U>GIY"FUS9VED(")"96QG:75M(@IM<V=S='(@(M#@
MY^SE\"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(D)E;&EZ92(*;7-G<W1R("+0X.?LY?`B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C,S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q
M"B,L(&9U>GIY"FUS9VED(")"96YI;B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBT^3@Z^7M
M[?OE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0Q(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"B,L(&9U>GIY"FUS9VED
M(")":'5T86XB"FUS9W-T<B`B24U0(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(L3E
M[?P@\.[FY.7MZ/\B"@HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP
M:'`Z,S4T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S
M7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
MP.3PY?'@\B#SXN7D[NSKY>WH_R`E<R#MY2#MX.GDY>TN(@H*(R!F=7IZ>0HC
M.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3`*;7-G:60@(D)L;V-K
M(%-E='1I;F=S(@IM<V=S='(@(LW@\?+P[NGJX#HB"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T
M<B`BT.#Q^.CPY>WHY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.`HC+"!F=7IZ>0IM<V=I9"`B0F]L9"(*;7-G<W1R(")(
M;W)D92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(P-PIM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(D)O<F1E<B(*;7-G<W1R(")(;W)D
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*
M(RP@9G5Z>GD*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B2&]R9&4B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C,W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED
M(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HT."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O
M='-W86YA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0HC+"!F=7IZ>0IM<V=I9"`B0F]T=&]M
M(@IM<V=S='(@(L+LY?'RY2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0T(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,@HC+"!F=7IZ>0IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(DE-4"(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C0Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS
M9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HT,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C,W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HT,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0HC+"!F=7IZ
M>0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`BS_'EXN3N[>CL(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B
M0G5L;&5T960@3&ES="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0V"FUS9VED(")#35,B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@
M(D-20R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4Y.`IM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(W"B,L(&9U>GIY"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN
M(@IM<V=S='(@(LKKY?+N]^W@_R#PX.3H[O'B_^?\(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$U,0HC+"!F=7IZ>0IM<V=I9"`B0V%C:&4@
M:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B(@HB(RTC+2,M(RTC
M("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(LWNXN[E
M(/'N[N'YY>WHY2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT.#,@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDX-PHC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,34W"FUS9VED(")#86QE;F1A<B(*;7-G<W1R
M("+*X.OE[>3@\/PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C,U"B,L(&9U>GIY"FUS9VED(")#86QM(@IM<V=S='(@(L[R[.7MX"(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C0V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"B,L
M(&9U>GIY"FUS9VED(")#86UB;V1I82(*;7-G<W1R("+*X.OE[>3@\/PB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C0W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"B,L
M(&9U>GIY"FUS9VED(")#86UE<F]O;B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBR^CW[?OE
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A
M;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&QI8B]&:6QE+T-3
M5BYP:'`Z,S4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T
M('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[E
MY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C(R"FUS9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I
M;VX@:&%N9&QE<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y
M<G5S+G!H<#HR,S4@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!
M4"!S97)V97(Z("5S(@IM<V=S='(@(LWE\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@
M\>7PXN7P[NP@3$1!4"XB"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0T-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#B
MY?#N["XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8T"B,L(&9U>GIY"FUS9VED(")#86YA9&$B"FUS9W-T<B`BRN#KY>WD
MX/#\(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R
M,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L
M871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`B
MSO+LY>W@(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*
M;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("+.\NSE[>`@
M[O+WY?+@(.X@[_#NX>OE[.4B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S(S"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@
M7"(E<UPB+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,
M(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@HC+"!F=7IZ>0IM<V=I9"`B0V%N
M;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("+-Y2#L
M[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L
M:6(O5D93+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D
M('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+U9&4R]F='`N<&AP.C,Q.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R
M("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B
M"@HC.B!L:6(O2&]R9&4O1&%T851R964N<&AP.C$R."!L:6(O2&]R9&4O1&%T
M851R964O<W%L+G!H<#HV.#`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R("+-
MY2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC
M.B!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A
M;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@
M<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G
M<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU
M;6)E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8U
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(T"B,L(&9U>GIY"FUS9VED(")#87!T:6]N(@IM<V=S='(@(LW@\?+P
M[NGJZ"(*"B,Z(&QI8B].970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS
M9VED(")#87)R:65R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY,PIM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@
M(LK@\N7C[O#HZ"#H(.SE\NKH(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$S-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3DT"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@(LKKY?+N]^W@_R#PX.3H
M[O'B_^?\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR-0HC+"!F=7IZ>0IM<V=I9"`B0V5L;"!0<F]P97)T:65S
M(@IM<V=S='(@(LKKY?+N]^W@_R#PX.3H[O'B_^?\(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@
M<&%D9&EN9SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0HC+"!F=7IZ>0IM<V=I9"`B0V5L
M;"!P<F]P97)T:65S(@IM<V=S='(@(LKKY?+N]^W@_R#PX.3H[O'B_^?\(@H*
M(R`C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(PHC
M(&9U>GIY"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$R"B,L(&9U>GIY"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@
M(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC
M7&XB"B+1[O7PX.WH\OP@ZN#J7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4
M=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+1[O7PX.WH\OPB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3(W.`HC+"!F=7IZ>0IM<V=I9"`B0V5L;'!H;VYE
M(@IM<V=S='(@(LKKY?+N]^W@_R#PX.3H[O'B_^?\(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G:60@(D-E;G1E<B(*;7-G<W1R
M("+1[N?DX/+\(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")#
M96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A
M=&4@1&5T86EL<R(*;7-G<W1R("(B"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,@
M9G5Z>GD*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,3(*(RP@9G5Z
M>GD*;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S='(@(LCQZN#R_"#B
M(,[RXN7R\?+BY>WM^_4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4Y-PIM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X
M"B,L(&9U>GIY"FUS9VED(")#:&%D(@IM<V=S='(@(G9#87)D(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHY-@HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E(@IM<V=S='(@
M(L[R[.7MZ/+\(.CG[.7MY>WH_R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O
M<F0B"FUS9W-T<B`BS^#P[NO\(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8Y"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA
M="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R
M("(*(F5M86EL<RXB"FUS9W-T<B`BS>#Q\O#NZ>KH(.CLY>WH+"#@Y/#E\>`L
M(._NY._H\>@N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T
M"FUS9VED("(B"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P
M;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*(RP@
M9G5Z>GD*;7-G:60@(D-H87(B"FUS9W-T<B`B=D-A<F0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*(RP@
M9G5Z>GD*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(M/DX.OH\OP@
M[^#P\R(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI
M;F,Z,3,*;7-G:60@(D-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH
M<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@
M(L[R[.7R_/+E(/3KX.;JX.SH(.[OY?#@]NC^*.CH*2P@ZN[R[O#[Y2#"^R#U
M[O+H\N4@[O'S^>7Q\N+H\OPN(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C4Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B0VAI;&4B"FUS
M9W-T<B`BQ^#C[NONXN[J(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B0VAI;F$B"FUS9W-T
M<B`B=D-A<F0B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B
M0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")#:&EN97-E(%1R861I=&EO
M;F%L("A":6<U*2(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z('1E;7!L871E<R]P
M<F5F<R]A<'`N:6YC.C<*;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB"FUS
M9W-T<B`BPOOAY?#H\N4@[_#HZ^[FY>WHY3HB"@HC.B!L:6(O2&]R9&4O075T
M:"]3:6=N=7`N<&AP.C(W,`HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&$@<&%S
M<W=O<F0B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@
M=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0
M('8S+C$I("`C+2,M(RTC+2-<;B(*(L3EZ?'RXNCE.B(*"B,Z(&QI8B](;W)D
M92]!=71H+U-I9VYU<"YP:'`Z,C8Y"B,L(&9U>GIY"FUS9VED(")#:&]O<V4@
M82!U<V5R;F%M92(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(
M;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O
M("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBQ.7I\?+BZ.4Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,P,@IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D
M:7-P;&%Y(&1A=&5S.B(*;7-G<W1R("+4[O#LX/(@[O+NX?#@YN7MZ/\@Y.#R
M^SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF
M;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C8V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S
M($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O5D93+G!H<#HY,30@;&EB+TYE
M="]335,N<&AP.C(Y-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0VQA
M<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(L#D\.7Q
MX/(@\^+EY.[LZ^7MZ/\@)7,@[>4@[>#IY.7M+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"B,L(&9U>GIY"FUS9VED(")#
M;&5A<B(*;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC
M92!T86=S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*
M(RP@9G5Z>GD*;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@(LK@Z^7MY.#P
M_"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS
M9W-T<B`BT^3@Z^CR_"#OX/#S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M8VQE87(N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S
M='(@(LK@Z^7MY.#P_"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C,T"B,L(&9U>GIY"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T
M<B`BRN#KY>WDX/#\(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,34*(RP@9G5Z>GD*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS
M9W-T<B`BPO7NY"(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]N;W1I8V5?
M8F]T=&]M+FEN8SHV"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL.C8P"B,L(&9U>GIY"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU
M92(*;7-G<W1R("+-X/'R\.[IZN@B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*
M;7-G<W1R("+'X.KP^_+\(.[J[>XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ-@HC+"!F=7IZ>0IM<V=I9"`B0VQO=61S($5A
M<FQY(@IM<V=S='(@(LKN[._@[>C_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3<*(RP@9G5Z>GD*;7-G:60@(D-L;W5D>2(*
M;7-G<W1R("+*[NSOX.WH_R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W!O<G1A;"]S
M:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R
M("+3X?#@\OP@[.7M_B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C@*(RP@9G5Z>GD*;7-G:60@(D-O;&QA<'-E
M9"!B;W)D97)S(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO
M<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@
M*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+0X.?BY?#M\_+\(.+QY2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*(RP@
M9G5Z>GD*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(LK@Z^7MY.#P_"(*"B,Z
M(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(Y"B,L(&9U>GIY"FUS9VED(")#;VQO<B(*;7-G<W1R("+*X.OE[>3@
M\/PB"@HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(U(&QI
M8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C8*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,2!S97)V:6-E<R]I;6%G97,O
M8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C@R"B,L(&9U>GIY"FUS9VED(")#;VQO<B!0:6-K
M97(B"FUS9W-T<B`BR.SO[O#R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X
M,S4*(RP@9G5Z>GD*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M
M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC
M+2-<;B(*(L3EZ?'RXNCE.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`S"B,L(&9U>GIY"FUS9VED(")#;VQS.B(*;7-G
M<W1R("+*X.OE[>3@\/PB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DU,`IM
M<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C8V"B,L(&9U>GIY"FUS9VED(")#;VUI8W,B"FUS
M9W-T<B`BRN#KY>WDX/#\(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"B,L
M(&9U>GIY"FUS9VED(")#;VUM86YD(@IM<V=S='(@(LKN[._@[>C_(@H*(SH@
M861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,PHC+"!F
M=7IZ>0IM<V=I9"`B0V]M;65N="(*;7-G<W1R("+*[NSOX.WH_R(*"B,@9G5Z
M>GD*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C<*(RP@9G5Z>GD*
M;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S='(@(L+@^.4@Z.S_.B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C4X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T"B,L(&9U
M>GIY"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(LK@Z^7MY.#P_"(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP
M86YY(@IM<V=S='(@(LKN[._@[>C_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(X-@HC+"!F=7IZ>0IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S
M='(@(LW@\?+P[NGJZ"(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS
M9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#8*;7-G:60@(D-O;F9I9W5R871I
M;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T
M;&]O:RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S
M-0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T
M<B`BRN[M].CC\_#@]NC_(//Q\N#PY>O@(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHU,0HC+"!F=7IZ>0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R
M("+/X/#NZ_PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-34@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8V"B,L(&9U>GIY"FUS9VED(")#;VYG;R(*;7-G<W1R("+*[NSS
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HV,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H
M92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,3DY(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*(RP@
M9G5Z>GD*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R("+-Y?/D
MX/?M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N(@H*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.2!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N
M(&9A:6QE9#H@(@IM<V=S='(@(LWE\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@\>7P
MXN7P[NP@3$1!4"XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW.3`*
M;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S
M='(@(B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX-S8*(RP@9G5Z>GD*;7-G:60@
M(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(LWE
M\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"XB"@HC.B!C;VYF
M:6<O:&]O:W,N<&AP+F1I<W0Z,3`Q-`HC+"!F=7IZ>0IM<V=I9"`B0V]N=&%C
M=',B"FUS9W-T<B`BS^[JX.?@\OP@RN[M\N#J\OLB"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-C`*
M;7-G:60@(D-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z("(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU-B!L
M:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=&=Z+G!H<#HW-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(M'NY.7PYN#MZ.4@
M)7,B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,*(RP@9G5Z>GD*;7-G:60@(D-O;G1I
M;G5E(@IM<V=S='(@(LW@\?+P[NGJZ"(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HU."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(D-O<'DB"FUS9W-T
M<B`BRN[L[^#MZ/\B"@HC.B!L:6(O5D93+W-M8BYP:'`Z-#<R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B
M(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@
M(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(
M,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(L[XZ.'JX"#O\.@@\^3@Z^7MZ.A<
M;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$YA9R!(,R`H,BXP+C,I*2`@(RTC
M+2,M(RTC7&XB"B+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$
M05`N7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A.86<@2#,@*#(N,"XS*2D@
M(",M(RTC+2,M(UQN(@HBS>7SY.#W[>[E(/'NY>3H[>7MZ.4@\2#QY?#BY?#N
M["!,1$%0+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S8*(RP@9G5Z>GD*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S
M='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M
M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC
M+2,M(RTC7&XB"B+$Y>GQ\N+HY3HB"@HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T
M<"YP:'`Z,3<P(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@
M(D-O<W0@240B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C8S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C8S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.CDW-PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@
M;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z("(*;7-G<W1R("+-Y2#L[N/S(.[R
MZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HQ,#4U"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N
M;W0@4$=0('-I9VX@;65S<V%G93H@(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR
M_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z,SDS"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@
M4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`BS>4@[.[C\R#N\NKP
M^_+\(.SNY//K_"!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HT-C<*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO
M="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[
M\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@(LWE
M(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z
M(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HY-B!L:6(O2&]R9&4O075T:"]L
M9&%P+G!H<#HQ,C$*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0U-PHC+"!F
M=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM
M<V=S='(@(LWE\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"XB
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS
M9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N86YC95]487-K
M("5S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0HC+"!F=7IZ>0IM
M<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S
M='(@(LWE\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"XB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@
M=7-I;F<@1E10.B`E<R(*;7-G<W1R("+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q
M(/'E\.+E\.[L($Q$05`N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C,R,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B2&]R
M9&4@[>4@[_#@XNCK_.WN(.W@\?+P[N7M(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z,3$R.`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y
M<'0@4$=0(&1A=&$Z("(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\
M($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4R,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@
M4R]-24U%(&1A=&$N(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@
M36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HR-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B2&]R9&4@[>4@
M[_#@XNCK_.WN(.W@\?+P[N7M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C,U-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B
M2&]R9&4@[>4@[_#@XNCK_.WN(.W@\?+P[N7M(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z,S@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*
M;7-G<W1R(")(;W)D92#MY2#O\.#BZ.O\[>X@[>#Q\O#NY>TB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,X,2!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HY-3,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@
M=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R("+"X/@@
M16UA:6PZ(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X
M,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D
M9')E<W,@8F]O:RXB"FUS9W-T<B`BP.3PY?'MX/\@ZNWHX^`B"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"B,L(&9U>GIY"FUS9VED
M(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N
M(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?
M5&%S:R`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT
M-#8*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE
M=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(LWE(.SN
MX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@
M;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A
M=&5G>2!<(B5S7"(N(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@
M36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!L:6(O5D93+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB
M"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N86YC95]4
M87-K("5S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S$Y"B,L(&9U
M>GIY"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T
M:&4@:V5Y<V5R=F5R+B(*;7-G<W1R("+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q
M(/'E\.+E\.[L($Q$05`N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM
M<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S
M:R`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@;&EB+TYE
M="]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(LWE(.SNX_,@[O+J
M\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B](;W)D
M92]-86EN=&5N86YC92YP:'`Z-#(P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S
M='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E
M<R(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("+-Y2#L[N/S(.[R
MZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O2&]R
M9&4O1W)O=7`O;&1A<"YP:'`Z,3$Q(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H
M<#HQ-#0*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C(S-R!L:6(O2&]R
M9&4O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HU,38@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-C4V(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HV.3D*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@
M3$1!4"!S97)V97(N(@IM<V=S='(@(LWE\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@
M\>7PXN7P[NP@3$1!4"XB"@HC.B!L:6(O5D93+T]B:F5C="YP:'`Z,C0P"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB
M"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N86YC95]4
M87-K("5S(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G
M:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R
M97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@
M87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#`*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-R!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS.#D*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R971R:65V
M92!!0TPB"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N
M86YC95]487-K("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C(W-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`BP.3PY?'MX/\@
MZNWHX^`B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DAO<F1E(.WE(._P
MX.+HZ_SM[B#MX/'R\.[E[2(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HT,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@
M(DAO<F1E(.WE(._PX.+HZ_SM[B#MX/'R\.[E[2(*"B,Z(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C(Q.0HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,C(S"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R
M=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(DAO<F1E(.WE(._PX.+HZ_SM
M[B#MX/'R\.[E[2(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*(RP@
M9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B2&]R9&4@[>4@[_#@XNCK_.WN(.W@\?+P[N7M(@H*(SH@;&EB
M+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<
M(B5S7"(N(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E
M;F%N8V5?5&%S:R`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@
M;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E
M('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T
M:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*
M(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@
M;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$T,PHC+"!F=7IZ>0IM<V=I9"`B
M0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(LWE
M\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"XB"@HC.B!L:6(O
M5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<
M(B5S7"(N(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E
M;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HR,3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\
M(.SNY//K_"!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B
M"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N86YC95]4
M87-K("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A
M=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92#MY2#O\.#BZ.O\
M[>X@[>#Q\O#NY>TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<P"FUS
M9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@
M<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO
M=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R,PHC+"!F=7IZ>0IM<V=I
M9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(L+[]>[D(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU-S`*(RP@9G5Z>GD*;7-G:60@(D-O=6YT<GDB
M"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@
M(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I
M("`C+2,M(RTC+2-<;B(*(LWNXN[E(/'N[N'YY>WHY2(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR-S4*(RP@9G5Z>GD*;7-G:60@(D-O=7)S97,B
M"FUS9W-T<B`BT_'OY?CM[B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM
M<V=S='(@(M'NY^3@\OPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(D-R96%T
M92!A(&QI;FLB"FUS9W-T<B`BT>[GY.#R_"(*"B,@9G5Z>GD*(SH@=&5M<&QA
M=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E
M(&$@;F5W(&]N92(*;7-G<W1R("+1[N?DX/+\(.WNXOOI(._P[O3HZ_PB"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R
M96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I
M;VYS(@IM<V=S='(@(M'NY^3@\N7K_"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HS,C$Y"B,L(&9U>GIY"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS
M9W-T<B`BR.S_(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B
MT>[GY.#R_"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@
M-"!0:&%S97,B"FUS9W-T<B`BTN7J\_G@_R(*"B,@9G5Z>GD*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C4P"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%-E<W-I
M;VYS(@IM<V=S='(@(M'NY^3@\N7K_"(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE
M(@IM<V=S='(@(M+EZO/YY>4@XO#E[/\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*(RP@9G5Z>GD*;7-G
M:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(M+EZO/YY>4@XO#E[/\B"@HC
M(&9U>GIY"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0HC+"!F=7IZ>0IM<V=I
M9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R("+2Y>KS^>#_(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(V-`HC+"!F=7IZ>0IM<V=I9"`B0W5R
M<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R("+-X/'R\.[IZN@B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,R"B,L(&9U>GIY
M"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(M+EZO/YY>4@XO#E[/\B
M"@HC('!H<"UF;W)M870*(R!F=7IZ>2P@<&AP+69O<FUA=`HC(&9U>GIY+"!P
M:'`M9F]R;6%T"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO
M9V]N('1O("5S+B(*;7-G<W1R("+'X.3@]^@L(.?@[_/QZN#E[/OE(._PZ"#B
M]>[DY2#B("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(P"B,L(&9U>GIY"FUS9VED(")#=70B"FUS9W-T
M<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC
M+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M
M(RTC+2-<;B(*(LWNXN[E(/'N[N'YY>WHY2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*(RP@9G5Z>GD*;7-G:60@(D-U
M="!S96QE8W1I;VXB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP
M;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(L3EZ?'RXNCE.B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@
M(D-Y<')U<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,0IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S
M+3$R-3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S
M"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HV-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,"!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`BQ,0B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S(W.0IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E
M87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R
M;RUD<VXN<&AP*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N
M8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R("+%YN7D[>7B[>XB"@HC
M.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S
M97(B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S<*;7-G
M:60@(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C0P,B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HW,@IM<V=I9"`B1&%T92(*;7-G<W1R("+$X/+@(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV
M960B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(W.38*(RP@
M9G5Z>GD*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@(L_NZ^WNY2#N
M[^CQX.WHY3HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*(RP@9G5Z>GD*;7-G
M:60@(D1A>2(*;7-G<W1R("+%YN7D[>7B[>XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*(RP@9G5Z>GD*
M;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(M/DX.OH\OPB"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@HC+"!F=7IZ>0IM<V=I9"`B
M1&5C96UB97(B"FUS9W-T<B`BQ^#LY?+JZ"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*(RP@9G5Z>GD*
M;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R("+([/\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$
M96-R96%S92!);F1E;G0B"FUS9W-T<B`B(@H*(SH@;&EB+W!R969S+G!H<#HQ
M,3<@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ.#<*(RP@9G5Z>GD*;7-G:60@
M(D1E9F%U;'0B"FUS9W-T<B`BT^3@Z^CR_"(*"B,@9G5Z>GD*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*;7-G:60@(D1E
M9F%U;'0@0V]L;W(B"FUS9W-T<B`BUN+E\B#O[B#S[.[K]^#MZ/XB"@HC.B!L
M:6(O2&]R9&4O261E;G1I='DN<&AP.CDV"FUS9VED(")$969A=6QT($ED96YT
M:71Y(@IM<V=S='(@(L_P[O3HZ_P@[^X@\^SNZ_?@[>C^(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")$969A=6QT(%-H
M96QL(@IM<V=S='(@(M/DX.OH\OPB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q
M(&QI8B](;W)D92]097)M<RYP:'`Z,S(V(&QI8B](;W)D92]097)M<R]522YP
M:'`Z-#(R"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-#,Y('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHW,"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3$V('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,PHC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.3@@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE
M=&4N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q
M"FUS9VED(")$96QE=&4B"FUS9W-T<B`BT^3@Z^CR_"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@HC+"!F
M=7IZ>0IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`BT^3@Z^CR_"(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS
M9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C0Y"B,L(&9U>GIY"FUS9VED(")$96QE=&4@3&]G
M(@IM<V=S='(@(M/DX.OH\OPB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C<W(&QI8B](;W)D92]097)M<R]522YP:'`Z,3`Q"B,L(&9U>GIY"FUS9VED
M(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R("+-X/'R\.[IZN@@[^[K_.?N
MXN#RY>O_(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS
M"B,L(&9U>GIY"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM
M<V=S='(@(M'N[N'YY>WHY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T
M92!C96QL(@IM<V=S='(@(M/DX.OH\OPB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S"B,L(&9U>GIY"FUS9VED
M(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N
M<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*%1U<F)A('8Q+C$I("`C+2,M(RTC+2-<;B(*(O/A\.#R_"#Q\N[K
MX>7V(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T
M92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C$*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S
M='(@(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_\B"@HC.B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C0R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES
M<VEO;G,_(@IM<V=S='(@(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W
M"B,L(&9U>GIY"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(M/DX.OH\OPB
M"@HC(&9U>GIY"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI
M;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R
M("+3Y.#KZ/+\(.+[X?#@[>W[Z2#O\.[TZ.O\(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"B,L(&9U>GIY
M"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<
M;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C+2,M(RTC
M+2-<;B(*(O/A\.#R_"#Q\N[KX>7V(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"B,L(&9U>GIY"FUS9VED
M(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@(M/DX.OH\OPB"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S
M7"(N(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N
M8V5?5&%S:R`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-C,@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,2!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PHC+"!F=7IZ>0IM<V=I9"`B1&5L
M:79E<GD@=&EM92(*;7-G<W1R("+3Y.#KZ/+\(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C<Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV.`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR
M.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`BSN_H^.CR
MY2#O\.[AZ^7L\R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY-#(@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`HC+"!F
M=7IZ>0IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`BS^[K[>[E(.[OZ/'@
M[>CE.B(*"B,Z(&QI8B](;W)D92YP:'`Z,3DW"FUS9VED(")$971A:6QS("AA
M;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92YP:'`Z,C`Q"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("+/[N3P[N'M[O'RZ"#A
M^^OH(.?@[^CQX.W[(.(@YO/P[>#K(.3K_R#@Y.SH[>CQ\O#@\N[PX"XB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(Q"FUS9VED(")$979E;&]P
M;65N="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C$V"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$
M:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E
M8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(LK@\N#K
M[N,B"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-S`*;7-G
M:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`BSO+NX?#@YN#R
M_"#B\.7L_R#B(#(T+??@\>[B[NP@].[P[.#RY3\B"@HC(&9U>GIY"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#`*;7-G:60@(D1I<W!L87D@3W!T:6]N
M<R(*;7-G<W1R("+$\//CZ.4@[>#Q\O#NZ>KH(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C@Y"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&1E
M=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@(LW@\?+P[NGJZ"#NX>[K[O?JZ"(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#`V"B,L(&9U>GIY"FUS9VED(")$
M:7-P;&%Y(&9O<FUA="(*;7-G<W1R("+-X/'R\.[IZN@@[N'NZ^[WZN@B"@HC
M.B!L:6(O2&]R9&4O34E-12]-1$XN<&AP.C$Y,0IM<V=I9"`B1&ES<&]S:71I
M;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HW,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(R"B,L(&9U
M>GIY"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(M/DX.OH\OPB"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D
M:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(LWE(.+[
MY_OBX.GRY2!M86EN=&5N86YC92YP:'`@[>7O[O'PY>3Q\N+E[>WN(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT
M86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB
M"FUS9W-T<B`BPB#OY?#B[ND@\?+P[NKE(//JX.?@[?L@Z.SE[>`@[^[KY>D_
M(,7QZ^@@Y.`L(._N\?+@XOSRY2#CX.ON]^KS.B`B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<P
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"B,L(&9U>GIY"FUS9VED
M(")$;VUI;FEC82(*;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<Q
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$;VUI;FEC
M86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N
M('5P+B(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]-24U%+T-O
M;G1E;G1S+G!H<#HX-3$*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(L?@X_#S
MY^CR_"(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`BQ^#C\//G
MZ/+\("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B
M1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP
M="XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,3$*;7-G
M:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B12U-86EL(@IM<V=S
M='(@(DE-4"(*"B,Z(&QI8B].970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*
M;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I
M97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z
M,S0*;7-G:60@(D524B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@IM<V=I9"`B161I="(*;7-G<W1R
M("+0Y>3@ZO+H\.[BX.WHY2(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+T)L;V-K
M+U5)+G!H<#HU,`IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R("+0Y>3@ZO+H
M\.[BX/+\(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S
M+G!H<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HW-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C$P,`HC+"!F=7IZ>0IM<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@
M(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_\B"@HC.B!S97)V:6-E<R]S:&%R97,O
M961I="YP:'`Z,C,W"B,L(&9U>GIY"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_\B"@HC(&9U>GIY+"!P
M:'`M9F]R;6%T"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E
M<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("+3\?+@[>[BZN`@[_#@XB#DZ_\@
M)7,B"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,@9G5Z>GD*(SH@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS
M9W-T<B`BS>#Q\O#NZ>KH(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!L:6(O
M2&]R9&4O4&5R;7,O54DN<&AP.C,V-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(LW@
M\?+P[NGJZ"(*"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`BS>#Q\O#NZ>KH(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HW,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM
M<V=I9"`B16=Y<'0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(Q-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%;"!386QV861O<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#D*;7-G:60@(D5M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ.#<S(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T"FUS
M9VED(")%;6%I;"(*;7-G<W1R(")%;6%I;"(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-38V('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI
M;F,Z,3`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV.`HC
M+"!F=7IZ>0IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R("+"X/@@16UA
M:6PZ(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-C<*(RP@9G5Z>GD*;7-G
M:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R("+"X/@@
M16UA:6PZ(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y.3,*(RP@9G5Z>GD*
M;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(L_P[O?@
M_R#H[?3N\.S@]NC_(@H*(SH@;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H
M<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y-PHC+"!F
M=7IZ>0IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(LW@\?+P[NGJZ"(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"B,L(&9U>GIY
M"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R("+-\^OEXN[I(/#EY_/K
M_/+@\BXB"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,C0S(&QI8B](
M;W)D92]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@;&EB+TAO<F1E+T=R;W5P+VQD
M87`N<&AP.C8V,B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&QI
M8B](;W)D92]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT
M+B(*;7-G<W1R("+-\^OEXN[I(/#EY_/K_/+@\BXB"@HC.B!L:6(O2&]R9&4O
M4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30W"FUS
M9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A
M;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3(R"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X
M="!M96YU/R(*;7-G<W1R("+*[NWRY>KQ\NWNY2#LY>W^(._N(.W@YN#RZ.@@
M[_#@XN[I(.KM[N_JZ"#L^_CH(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U
M.3(@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#`*(RP@9G5Z>GD*;7-G:60@(D5N
M9"!Y96%R(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E
M('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-
M4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+0X.?BY?#M\_+\(.+QY2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@
M(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,C0*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I
M;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S
M970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O
M9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N
M=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DP"FUS9VED(")%;G1E<B!T
M:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.CDY(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA
M;"!'=6EN96$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C<Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP
M:'`Z,C<*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]6:65W+G!H<#HY-"!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#@*;7-G:60@(D5R<F]R(@IM
M<V=S='(@(L[XZ.'JX"(*"B,Z(&QI8B](;W)D92]496UP;&%T92YP:'`Z-#8S
M"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E
M<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N
M8VAO<CH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@
M<WEN8R!L;V<Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]496UP;&%T
M92YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@
M8V]N=&5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T
M:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I
M;"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O5D93+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HW-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@
M(D5S=&]N:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C@Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P
M92(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#,*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`BRN#FY/OE
M(#$U(.SH[?/R(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,SDS"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`BRN#FY/OE(#(@
M[.CM\_+[(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,"!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM
M<V=S='(@(LK@YN3[Y2`S,"#QY>KS[>0B"@HC(&9U>GIY"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-#(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-`IM
M<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(LK@YN3[Y2`U(.SH[?/R
M(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E
M<GD@3&]G:6XB"FUS9W-T<B`BRN#FY/OI(/#@YR#O\.@@XO7NY.4B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0T"FUS9VED(")%=F5R>2!H86QF(&AO
M=7(B"FUS9W-T<B`BRN#FY/OE(._NZ_?@\>`B"@HC(&9U>GIY"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y
M,@IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(LK@YN3S_B#LZ.WS\O,B
M"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA
M;7!L92!V86QU97,Z(@IM<V=S='(@(L_PZ.SE\"#G[>#WY>WHZ3HB"@HC.B!A
M9&UI;B]P:'!S:&5L;"YP:'`Z.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,C<*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B
M(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HT-S4@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV,30*;7-G:60@
M(D5X<&%N9"(*;7-G<W1R("+0X/'XZ/#H\OPB"@HC.B!T96UP;&%T97,O<&]R
M=&%L+W-I9&5B87(N:6YC.C,R"B,L(&9U>GIY"FUS9VED(")%>'!A;F0@4VED
M96)A<B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V
M,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@
M=C,N,2D@(",M(RTC+2,M(UQN(@HBT.#GXN7P[?/R_"#B\>4B"@HC.B!L:6(O
M2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I
M)R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ
M-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H
M('1E<FTB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M-#$R"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-S<*;7-G:60@(D5X<&]N96YT(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S$*(RP@9G5Z>GD*;7-G:60@(D9'($-O;&]R(@IM<V=S
M='(@(LCQ[^[K_.?NXN#R_"#G[>#WY>WHY2#O[B#S[.[K]^#MZ/XB"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F
M('-E='5P(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]S<6PN<&AP
M.C(R-0IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N(@IM
M<V=S='(@(L+N\?'RX.WNXNOE[>CE(.W@\?+P[N7J(.WE(//DX.ON\?PN(@H*
M(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C<U(&QI8B](;W)D92]!=71H
M+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0
M('-E<G9E<BXB"FUS9W-T<B`BS>7SY.#W[>[E(/'NY>3H[>7MZ.4@\2#QY?#B
MY?#N["!,1$%0+B(*"B,Z(&QI8B](;W)D92]!=71H+W-M8BYP:'`Z.3@*(RP@
M9G5Z>GD*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N
M(@IM<V=S='(@(LWE\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!
M4"XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S$W"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T
M<B`BS>7SY.#W[>[E(/'NY>3H[>7MZ.4@\2#QY?#BY?#N["!,1$%0+B(*"B,Z
M(&QI8B]61E,O9G1P+G!H<#HW,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`BS>7SY.#W
M[>[E(/'NY>3H[>7MZ.4@\2#QY?#BY?#N["!,1$%0+B(*"B,Z(&QI8B](;W)D
M92]!=71H+W-A<VPN<&AP.C@W"B,L(&9U>GIY"FUS9VED(")&86EL960@=&\@
M8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(LWEXN[G[.[F
M[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]S
M;6(N<&AP.C4P,2!L:6(O5D93+V9T<"YP:'`Z-S4U"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S
M='(@(LWE\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"XB"@HC
M.B!L:6(O5D93+W-M8BYP:'`Z-#8U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(M3@Z>L@[_#H
M[?_R.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ.`HC+"!F=7IZ>0IM<V=I9"`B1F%I<B(*;7-G<W1R("(B"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBSO(@ZN[C
M[EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC
M+2,M(UQN(@HBSO(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#0@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA
M<RDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B1F%R;V4@27-L86YD<R(*
M;7-G<W1R("+*[NSOX.WH_R(*"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(S.`HC
M+"!F=7IZ>0IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(L[XZ.'JX"#H
M[._N\/+@.B`B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(M3@ZO$B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S4Q"B,L(&9U>GIY"FUS9VED(")&87AE<R(*;7-G
M<W1R("+4X.KQ(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P,2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*
M;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,C`*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M.0HC+"!F=7IZ>0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`BR.SO[O#R
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*
M(RP@9G5Z>GD*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`BR.SO
M[O#R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-#@*;7-G:60@(D9I96QD
M(&UA=')I>"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,S
M,@IM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,S,S8*;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(D9I;&4B"FUS9W-T<B`B
MU.#IZR(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8P(&QI
M8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I
M;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C`@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII
M<"YP:'`Z-C<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS
M9W-T<B`B(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#`Y"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`BU?#@[>CKZ/G@(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#(*(RP@9G5Z>GD*;7-G:60@(D9I;&4@3F%M92(*;7-G
M<W1R("+([/\B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.3@T
M"B,L(&9U>GIY"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R("+/[NOM
M[N4@[N_H\>#MZ.4@[_#NX>OE[/LZ(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$T.3`*(RP@9G5Z>GD*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(LCL
M_R(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX.#4*(RP@9G5Z>GD*;7-G
M:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN
M(@HBS>[B[N4@\>[NX?GE[>CE(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z.3$*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`BU.CK_/+P
M^R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S$*(RP@9G5Z>GD*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`BRN[L[^#MZ/\B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"B,L(&9U>GIY"FUS9VED(")&
M:7)S="!(86QF(@IM<V=S='(@(L_PZ.SE\"#G[>#WY>WHZ3HB"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED
M(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR-34*;7-G:60@(D9I>"!R871I;R(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C,P"FUS9VED(")&;&EP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B(@H*(SH@;&EB+U9&4R]S
M<6PN<&AP.C(S-R!L:6(O5D93+VUU<W%L+G!H<#HQ,#<*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G
M<W1R("+`Y/#E\>#R(//BY>3N[.OE[>C_("5S(.WE(.W@Z>3E[2XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R"B,L(&9U
M>GIY"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(LCQ[^[K_.?NXN#R_"#G
M[>#WY>WHY2#O[B#S[.[K]^#MZ/XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G
M:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM
M<V=S='(@(L+@^"#A\.[SY^7P(.WE(._NY.3E\.;HXN#E\B#N[_;H_B#OY??@
M\N@N(,3K_R#OY??@\N@@[>#F[.CRY2!#5%),*U`N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C<R"FUS9VED("(B"B)&;W)E8V%S="!$87ES
M("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T
M:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD
M(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"B,L(&9U>GIY"FUS9VED(")&;W)G
M;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`BS^#P[NO\(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0V-`HC+"!F=7IZ>0IM<V=I9"`B1F]R;7,B
M"FUS9W-T<B`BR.S_(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U
M-0HC+"!F=7IZ>0IM<V=I9"`B1F]R=6US(@IM<V=S='(@(L?@[.7RZN@B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$Q"B,L(&9U>GIY"FUS9VED
M(")&;W)W87)D<R(*;7-G<W1R("+/Y?#E\>O@\OPB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"B,L(&9U>GIY"FUS9VED
M(")&<B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N
M,2D@(",M(RTC+2,M(UQN(@HBSO(@ZN[C[EQN(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN(@HBSO(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"B,L
M(&9U>GIY"FUS9VED(")&<F%M97,B"FUS9W-T<B`BR.S_(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C@W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HX,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PHC+"!F=7IZ>0IM
M<V=I9"`B1G)A;F-E(@IM<V=S='(@(LCL_R(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C@U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED
M(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@V
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H
M(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")&
M<F]M(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ
M*2`@(RTC+2,M(RTC7&XB"B+.\B#J[N/N7&XB"B(C+2,M(RTC+2,@(')U7U)5
M+G!O("A4=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+.\B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,T.0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,SDU"B,L(&9U>GIY"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(L[R
M(.KNX^Y<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C
M+2,M(RTC+2-<;B(*(L[R(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G
M<W1R("+/[NOM[N4@[N_H\>#MZ.4@[_#NX>OE[/LZ(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U
M;&P@36]O;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV,`HC+"!F=7IZ
M>0IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(L+@^.4@Z.S_.B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HX."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*(RP@9G5Z
M>GD*;7-G:60@(D=A8F]N(@IM<V=S='(@(G9#87)D(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS
M9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HY-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=A
M;6)I82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R
M"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R871I
M;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I
M9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G
M:60@(D=E;W)G:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C8Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<U"B,L(&9U>GIY"FUS9VED(")':&%N82(*;7-G<W1R(")V0V%R9"(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G
M:60@(D=I8G)A;'1A<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4W-@HC+"!F=7IZ>0IM<V=I9"`B1VEV96X@3F%M92(*;7-G
M<W1R("+([/\B"@HC(&9U>GIY"B,@9G5Z>GD*(SH@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$W-2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,`HC
M.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ.0IM<V=I9"`B1VQO8F%L($]P
M=&EO;G,B"FUS9W-T<B`BS^[P\N#K(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P
M<"YI;F,Z,3<*;7-G:60@(D=O(@IM<V=S='(@(L_E\.7I\N@B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R.0HC+"!F=7IZ>0IM
M<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`BS^[H\>H@XB!';V]G;&4B"@HC
M.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A
M<F-H(@IM<V=S='(@(L_NZ/'J(.(@1V]O9VQE(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-@IM<V=I9"`B1W)A>7-C86QE(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#`@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.34@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<U"B,L(&9U>GIY"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B
MRN#KY>WDX/#\(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B1W)E;F%D82(*;7-G<W1R("+*
MX.OE[>3@\/PB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B1W)O
M=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T=R
M;W5P+G!H<#HU.2!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED
M(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P
M("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B
MS_#NX>OE[.`@[_#H(._N[_ORZN4@XOOWY?#J[?/R_"`E<RX@T>7PXN7P(/'J
MX.?@ZR(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ,3@@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A
M<"YP:'`Z-#$X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(B(*(B,M
M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M
M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92!V,BXQ*2`@
M(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E
M('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B+-Y>+NY^SNYNWN
M(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+EQN(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B+-Y>+NY^SN
MYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+EQN(@HB(RTC+2,M(RTC
M("!R=5]252YP;R`H2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B+-Y>+N
MY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+EQN(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B+-
MY>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI
M8B](;W)D92]'<F]U<"]L9&%P+G!H<#HS,S@@;&EB+TAO<F1E+T=R;W5P+VQD
M87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5
M;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,@9G5Z>GD*
M(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G
M:60@(D=R;W5P<R(*;7-G<W1R("+#\//O[_LB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.CDX"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'
M=6%T96UA;&$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.CDR"FUS9VED(")'=65R;G-E>2(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&QI
M8B](;W)D92]097)M<R]522YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z.#@*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(L/N
M\?+\(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,@IM<V=I9"`B
M1W5E<W1B;V]K(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HY-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(D=U:6YE82(*
M;7-G<W1R("+2Y>S@(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#4@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$P,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW.`HC+"!F=7IZ>0IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(G9#87)D(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDV-`IM<V=I9"`B2%1-3"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O
M(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS
M9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!
M=71H+VAT='`N<&AP.C$U-PHC+"!F=7IZ>0IM<V=I9"`B2%144"!!=71H96YT
M:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[LZ^7M
MZ/\@)7,@[>4@[>#IY.7M+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,`HC+"!F=7IZ>0IM<V=I9"`B2&%I=&DB"FUS
M9W-T<B`BS>#Q\O#NZ>KH(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M-#$S"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@HC+"!F=7IZ>0IM
M<V=I9"`B2&%Z92(*;7-G<W1R("+/[N3QZN#GZN`B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z.3(S(&QI8B](;W)D92]&;W)M+G!H<#HR.3(Q"B,L(&9U>GIY
M"FUS9VED(")(96%D97(B"FUS9W-T<B`BS^[D\>K@Y^K@(@H*(SH@;&EB+TAO
M<F1E+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-C$*;7-G:60@(DAE861E<G,B
M"FUS9W-T<B`BQ^#C[NONXNKH(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$P-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD
M($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*(RP@9G5Z>GD*;7-G:60@(DAE
M879Y(%0M4W1O<FTB"FUS9W-T<B`BR.SO[O#R(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#4*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,T"B,L(&9U>GIY"FUS9VED(")(96EG:'0B"FUS9W-T<B`B
MS>CJ[N/DX"(*"B,Z(&QI8B](;W)D92](96QP+G!H<#HQ.#0@;&EB+TAO<F1E
M+TAE;'`N<&AP.C$X-B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-PHC.B!T
M96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z-`IM<V=I9"`B2&5L<"(*;7-G<W1R
M("+/[N3QZN#GZN`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W-0HC+"!F=7IZ>0IM<V=I
M9"`B2&5L<&5R(@IM<V=S='(@(L_NY/'JX.?JX"(*"B,@9G5Z>GD*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@
M(L_NZ_/XX/#HY2(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS9VED(")(97)E(&ES
M('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(LWHYN4@[_#E
MY/'RX.+KY>W@(.CM].[P[.#VZ/\@Z.<@\>#L[N/N(.W@]^#KX"#TX.GKX#HB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`HC
M+"!F=7IZ>0IM<V=I9"`B2&EG:"(*;7-G<W1R("+-Z.KNX^3@(@H*(R!F=7IZ
M>0HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D
M;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*;7-G:60@(DAO7VUE(@IM<V=S='(@
M(L_N\/+@ZR(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A
M=&4I(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+G!H<#HQ-3,Y
M"FUS9VED(")(;VUE(@IM<V=S='(@(L_N\/+@ZR(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`B
MQ.[LX/CMZ.D@X.3PY?$B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*
M(RP@9G5Z>GD*;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(LK@\N#K
M[N,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM
M<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R("+$[NS@^.WHZ2#RY>OE].[M(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y
M"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3`V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#8*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N
M9R(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HV-PIM<V=I9"`B2&]R9&4B"FUS9W-T<B`BS^[P\N#K(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HT-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@
M;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S
M<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE
M<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ
M,C0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(B(*(B,M
M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB
M"B+/\.[AZ^7LX"#O\.@@[_#N\>SN\O#E(.?@[_#N^.7M[>[C[B#OZ/'\[.`N
M(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO
M;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M
M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+
M;VQA8BYP:'`Z-3`R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(T,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V
M92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA
M8BYP:'`Z-#<S"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP
M92`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$Q.3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S
M>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z,3,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@R
M"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B
M2&]R:7IO;G1A;#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED
M('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O
M(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@
M=&AE<F4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@
M=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D*;7-G:60@(DAU;6ED:71Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@*
M;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Q,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ-S(@
M;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S
M(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[LZ^7MZ/\@)7,@[>4@[>#IY.7M+B(*
M"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,30@;&EB+TAO<F1E+T%U
M=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M
M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$W.2!L:6(O2&]R9&4O075T:"]C>7)S
M<6PN<&AP.C(T,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M
M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`BP.3P
MY?'@\B#SXN7D[NSKY>WH_R`E<R#MY2#MX.GDY>TN(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$S,C`*(RP@9G5Z>GD*;7-G:60@(DE0($%D9')E<W,B"FUS
M9W-T<B`BP.3PY?$B"@HC.B!L:6(O2&]R9&4O075T:"]I<&)A<VEC+G!H<#HW
M-PHC+"!F=7IZ>0IM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R("+-Y?(@Y.[Q\O/O[?OU(.W@\?+P[N7J+B(*"B,Z(&QI8B](;W)D
M92]!=71H+VEP8F%S:6,N<&AP.C@Y"B,L(&9U>GIY"FUS9VED("))4"!!9&1R
M97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("+-
MY?(@Y.[Q\O/O[?OU(.W@\?+P[N7J+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I
M;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F
M;W)E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX,@HC+"!F=7IZ>0IM<V=I9"`B26-E;&%N9"(*;7-G
M<W1R("+*[NSOX.WH_R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#`*
M;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`BTN[K_.KN(.CJ[NWJZ"(*"B,@
M9G5Z>GDL('!H<"UF;W)M870*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS
M9W-T<B`BS>#Q\O#NZ>KH(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X
M,0IM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@(LCJ[NWJZ"#Q(/+E
MZO'R[NPB"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3,*
M;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`BR.S_(._P[O3HZ_\Z
M(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4Y.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L
M>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-3D*;7-G:60@(B(*(DEF('EO
M=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R
M+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O
M9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,@IM<V=I9"`B(@HB268@>6]U
M('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U
M('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R
M(&)R;W=S97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`HC+"!F=7IZ>0IM<V=I
M9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(LW@Y^#D(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I
M9"`B26UA9V4@55),.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM
M86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@
M(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$W-C4*(RP@9G5Z>GD*;7-G:60@(DEM86=E('5P;&]A9"(*
M;7-G<W1R("+([/\B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I
M9"`B26UA9V5S(@IM<V=S='(@(LK@\/+H[>KH(@H*(R!F=7IZ>2P@<&AP+69O
M<FUA=`HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHU-"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L('!H<"UF
M;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("+([._N\/(L
M(/C@XR`E9"(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L
M('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R
M("+([._N\/+H\.[BX.WN(._NZ^4Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R
M("+([._N\/+H\.[BX.W[(._NZ_\Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"B,L(&9U>GIY"FUS9VED
M("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R("+1[N[A^>7MZ.4B"@HC.B!L
M:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ,S0*;7-G:60@(DEN8V]R<F5C
M="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@HC+"!F=7IZ>0IM<V=I9"`B26YC
M;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`BS^[F
MX.OSZ?'RX"P@XN+EY.CRY2#"X/CH(.CL_R#O[NO\Y^[BX/+EZ_\@Z"#OX/#N
MZ_PB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B
M(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@
M>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R
M96%S92!);F1E;G0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Q-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"B,L(&9U>GIY"FUS9VED("));F1I
M82(*;7-G<W1R("+2Y>OE].[M(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN
M9&EV:61U86P@57-E<G,B"FUS9W-T<B`BS^[K_.?NXN#RY>OH(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"B,L(&9U
M>GIY"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`BTN7KY?3N[2(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"B,L(&9U>GIY"FUS
M9VED("));F9O(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO
M<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@
M*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+(X^WN\.CP[N+@\OPB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Y"B,L(&9U>GIY"FUS9VED("))
M;F9O<FUA=&EO;B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(
M;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B+/\.[WX/\@Z.WT[O#LX/;H_UQN
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<
M;B(*(LCM].[P[.#VZ/\@[B#QY?#BY?#E(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,Q.0HC+"!F=7IZ>0IM<V=I9"`B26YF;W)M871I;VX@
M;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`BS>7R(.3N\?+S[^W[]2#M
MX/'R\.[EZBXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S4*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!#7V]L
M=6UN($%F=&5R(@IM<V=S='(@(M'N[N'YY>WHY2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`HC+"!F
M=7IZ>0IM<V=I9"`B26YS97)T($EM86=E(@IM<V=S='(@(M'N[N'YY>WHY2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*
M(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("+/\.CLY?`@
MY^W@]^7MZ.DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR-0HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM
M<V=S='(@(M/DX.OH\OP@[^#P\R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#
M;VQU;6X@0F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T
M(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T
M:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"B,L(&9U>GIY"FUS
M9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*
M;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@
M(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!V,2XQ
M*2`@(RTC+2,M(RTC7&XB"B+SX?#@\OP@\?+NZ^'E]B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I
M9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F
M=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED
M("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B
M"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@
M(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(T,@IM<V=I9"`B26YS97)T(&%N(&5M86EL
M(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S
M<W=O<F0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*(RP@9G5Z>GD*;7-G:60@(DEN<V5R
M="!C96QL(&%F=&5R(@IM<V=S='(@(M'N[N'YY>WHY2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*(RP@9G5Z
M>GD*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("+1[N[A^>7M
MZ.4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8T"B,L(&9U>GIY"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R
M(@IM<V=S='(@(M'N[N'YY>WHY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*(RP@9G5Z>GD*;7-G:60@(DEN
M<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(M'N[N'YY>WHY2(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`HC+"!F=7IZ>0IM<V=I
M9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(M'N[N'YY>WHY2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M-0HC+"!F=7IZ>0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G
M<W1R("+1[N[A^>7MZ.4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A
M<&@@8F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*(RP@9G5Z>GD*;7-G:60@(DEN
M<V5R="!R;W<@869T97(B"FUS9W-T<B`BT>[NX?GE[>CE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`HC+"!F
M=7IZ>0IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`BS_#H[.7P
M(.?MX/?E[>CI.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S,*;7-G
M:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET
M>2!Q=65S=&EO;CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@HC+"!F=7IZ>0IM<V=I9"`B26YS97)T
M+TUO9&EF>2!);6%G92(*;7-G<W1R("+1[N[A^>7MZ.4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"B,L(&9U>GIY"FUS
M9VED("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`BT^3@Z^CR_"#OX/#S
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PHC+"!F
M=7IZ>0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H
M92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\
M(.SNY//K_"!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R
M961I="XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-SD*
M(RP@9G5Z>GD*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`BT>[GY.#R_"(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,3,W"B,L(&9U>GIY"FUS9VED("));G1E
M9V5R(&QI<W0B"FUS9W-T<B`BT>[GY.#R_"(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S
M97(@1&%T82!(96%D97(I+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0V]M
M<')E<W,O>FEP+G!H<#HQ-C<@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z
M,3DT"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C(Q,@HC+"!F=7IZ
M>0IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R("+0X.'N]^CI(.#D
M\.7Q(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV
M86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@
M240N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#DQ(&QI
M8B](;W)D92]&;W)M+G!H<#HR,38R(&QI8B](;W)D92]&;W)M+G!H<#HR,C,V
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S`S(&QI8B](;W)D92]&;W)M+U1Y
M<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET
M=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P,`HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO
M;B!A9&1R97-S+B(*;7-G<W1R("+0X.'N]^CI(.#D\.7Q(@H*(SH@;&EB+TAO
M<F1E+T-O;7!R97-S+V1B>"YP:'`Z,3`Y(&QI8B](;W)D92]#;VUP<F5S<R]D
M8G@N<&AP.C$S.0HC.B!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HR-#$*
M(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B
MT^3@Z^CR_"#OX/#S(@H*(R!F=7IZ>0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,38U"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&QI8V5N<V4@
M:V5Y+B(*;7-G<W1R("+-Y>KN\/#EZO+M[N4@Z.S_+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*(RP@9G5Z>GD*;7-G:60@(DEN=F%L
M:60@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(M#@X>[WZ.D@X.3PY?$B
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I
M9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*(RP@9G5Z>GD*;7-G:60@(DEN
M=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(M#@X>[WZ.D@X.3P
MY?$B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@HC
M+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N
M(@IM<V=S='(@(M#@X>[WZ.D@X.3PY?$B"@HC.B!A9&UI;B]P97)M<R]A9&1C
M:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-C$*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T
M<B`BS>#Q\O#NZ>KH(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$V,PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM
M<V=S='(@(LW@\?+P[NGJZ"(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`V"B,L(&9U>GIY"FUS9VED("));G9A;&ED('!R;W1O8V]L
M+B(*;7-G<W1R("+-X/'R\.[IZN@B"@HC(&9U>GIY"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HY,R!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP
M:'`Z-S$*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C@P"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB
M(@IM<V=S='(@(LWEZN[P\.7J\NWNY2#H[/\N(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HQ,#<U(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(U.`HC+"!F=7IZ
M>0IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`BT.#A[O?H
MZ2#@Y/#E\2(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`Q"B,L(&9U>GIY"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*
M;7-G<W1R("+0X.'N]^CI(.#D\.7Q(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,3$*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@=6YI
M8V]D92!D871A+B(*;7-G<W1R("+0X.'N]^CI(.#D\.7Q(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,U.0HC+"!F=7IZ>0IM<V=I9"`B26YV96YT
M;W)Y(@IM<V=S='(@(LWEZN[P\.7J\NWNY2#H[/\N(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-@HC+"!F=7IZ>0IM<V=I9"`B
M26YV97)T('-E;&5C=&EO;B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5
M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBQ.7I\?+BZ.4Z(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R
M"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Q,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,0IM<V=I9"`B27)A<2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3$S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(DER
M96QA;F0B"FUS9W-T<B`BRN[L[^#MZ/\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B
M27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Q-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"B,L(&9U>GIY"FUS9VED
M("))<W)A96PB"FUS9W-T<B`BRN[L[^#MZ/\B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C8R-@IM<V=I9"`B27-S=65R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0HC+"!F
M=7IZ>0IM<V=I9"`B271A;&EC(@IM<V=S='(@(L7FY>3MY>+M[B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Q-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@HC+"!F
M=7IZ>0IM<V=I9"`B271A;'DB"FUS9W-T<B`BQ>;EY.WEXNWN(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$R,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED
M(")*86UA:6-A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#`@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0S.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$Q-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PHC+"!F=7IZ
M>0IM<V=I9"`B2F%P86XB"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0
M*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(R"FUS
M9VED(")*97)S97DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$R-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M-B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@
M(DIU;'DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S`*(RP@9G5Z>GD*;7-G:60@(DIU;F4B"FUS9W-T<B`BTN7LX"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S@*(RP@9G5Z>GD*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`BT>[GY.#R_"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$U"B,L(&9U>GIY"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R
M("+1[N?DX/+\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3<*(RP@9G5Z>GD*;7-G:60@(DIU<W1I9GD@1G5L
M;"(*;7-G<W1R("+1[N?DX/+\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*(RP@9G5Z>GD*;7-G:60@(DIU
M<W1I9GD@3&5F="(*;7-G<W1R("+1[N?DX/+\(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*(RP@9G5Z>GD*
M;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`BT>[GY.#R_"(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Q.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-@HC+"!F
M=7IZ>0IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R("+$X/+@(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V,PIM<V=I9"`B2V5E
M<"!O<FEG:6YA;#\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$R-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R
M8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3$*(RP@9G5Z>GD*
M;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R("+-X/'R\.[IZN@B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P
M<FEN="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT
M,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y.0HC+"!F=7IZ>0IM
M<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(M'N[N'YY>WHY2(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI
M<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G
M:60@(DMI<FEB871I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C
M<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$S,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@U"FUS9VED
M(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#<*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,T(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3(W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y
M>G-T86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN
M8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@(M#@\>KKX.3JX"(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM
M<V=S='(@(M_G^^HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC
M(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ
M-CD*(RP@9G5Z>GD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R("+/\.CLY?`@
MY^W@]^7MZ.DZ(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"B,L(&9U
M>GIY"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R("+/X/#N
MZ_PB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN
M<&AP.C@X"B,L(&9U>GIY"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`B
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M
M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC
M+2-<;B(*(L'[\?+P^^D@\?+@\/(B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z
M-S$W"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S
M='(@(L_PY>3[Y//YZ.D@XO7NY"#A^^LZ("5S(@H*(SH@;&EB+TAO<F1E+T%U
M=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E
M<R!F<F]M("5S(@IM<V=S='(@(L_PY>3[Y//YZ.D@XO7NY"#A^^LZ("5S(/$@
MZN[L[_S^\N7PX"`E<R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,30*;7-G
M:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(L_PY>3[Y//YZ.D@XO7N
MY"#MY2#GX/3HZO'H\.[BX.TB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,30V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#D*(RP@9G5Z>GD*;7-G:60@(DQA='9I82(*
M;7-G<W1R("+1[N?DX/+\(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*
M;7-G<W1R("+"^_7NY"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D
M97(B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV
M.0HC+"!F=7IZ>0IM<V=I9"`B3&5F="(*;7-G<W1R("(B"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HB[^7PY>SE
M\?+H\OP@XN+E\/4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P.`HC+"!F
M=7IZ>0IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`BS_#H[.7P(.?MX/?E
M[>CI.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3`T"B,L(&9U>GIY"FUS
M9VED("),969T('9A;'5E<R(*;7-G<W1R("+/\.CLY?`@Y^W@]^7MZ.DZ(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X
M"FUS9VED("),97-O=&AO(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B3&5V96PB"FUS9W-T
M<B`BT^3@Z^CR_"#OX/#S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@X"B,L(&9U>GIY"FUS9VED("),:6)E<FEA(@IM
M<V=S='(@(LWHZN[CY.`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I
M>6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U
M"B,L(&9U>GIY"FUS9VED("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(L+U[N0B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@HC
M+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R("+"]>[D(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*(RP@9G5Z
M>GD*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`BPO7NY"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"B,L(&9U
M>GIY"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T<B`BPO7NY"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"B,L(&9U
M>GIY"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R("+"]>[D(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*(RP@
M9G5Z>GD*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@
M(L+U[N0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS,0HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R("+"]>[D
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*
M(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(L+U
M[N0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@Q.`HC+"!F=7IZ>0IM<V=I
M9"`B3&EN:R(*;7-G<W1R("+"]>[D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O
M:6YT<R!T;SHB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X
M-SD*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O
M<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+U1E>'0O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@R"B,L(&9U>GIY"FUS
M9VED("),:6YK<R(*;7-G<W1R("+"]>[D(@H*(SH@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E
M('1H92!F;VQD97(B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$S,PIM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3$*;7-G:60@(DQI<W0@2&5L<"!4;W!I
M8W,B"FUS9W-T<B`BT>_H\>[J(/#@Y^3EZ^[B(._NY/'JX.?JZ"(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,S(*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S
M='(@(B(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z
M-3DT"B,L(&9U>GIY"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`BR/'J
MX/+\(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3@Y"B,L(&9U
M>GIY"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`BT>_H\>[J(/#@Y^3EZ^[B
M(._NY/'JX.?JZ"(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y
M-@HC+"!F=7IZ>0IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("+1[^CQ[NH@\.#G
MY.7K[N(@[^[D\>K@Y^KH(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP
M:'`Z-3DR"B,L(&9U>GIY"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@(M'O
MZ/'NZB#PX.?DY>ONXB#O[N3QZN#GZN@B"@HC.B!L:6(O2&]R9&4O34E-12](
M96%D97)S+G!H<#HU.3,*(RP@9G5Z>GD*;7-G:60@(DQI<W0M4&]S="(*;7-G
M<W1R("+1[^CQ[NH@\.#GY.7K[N(@[^[D\>K@Y^KH(@H*(R!F=7IZ>0HC.B!L
M:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3$*(RP@9G5Z>GD*;7-G:60@
M(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(LCQZN#R_"(*"B,@9G5Z>GD*(SH@
M;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DP"B,L(&9U>GIY"FUS9VED
M("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(LCQZN#R_"(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HU,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(B(*(B,M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M
M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT
M*2`@(RTC+2,M(RTC7&XB"B+.^.CAZN`@[_#H(//DX.OE[>CH7&XB"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A.86<@2#,@*#(N,"XS*2D@(",M(RTC+2,M(UQN
M(@HBS>7SY.#W[>[E(/'NY>3H[>7MZ.4@\2#QY?#BY?#N["!,1$%0+EQN(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H3F%G($@S("@R+C`N,RDI("`C+2,M(RTC
M+2-<;B(*(LWE\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"XB
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R("+/
M[NCQZB(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM
M<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y
M"B,L(&9U>GIY"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`BPNWH[.#MZ.4B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6UA9V5S+G!H<#HW-PIM<V=I
M9"`B3&]A9&EN9RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C`P"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B
M(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8*;7-G:60@
M(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R("++[NK@Z^CGX/;H_R(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<R(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HU-PHC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(*;7-G
M:60@(DQO8V%T:6]N(@IM<V=S='(@(M#@\>_NZ^[FY>WHY2(*"B,Z(&QO9VEN
M+G!H<#HQ.#D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(P,"!T96UP
M;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M
M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G
M:60@(DQO9R!I;B(*;7-G<W1R("+"]>[D(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S
M97-S:6]N(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$Y-`IM<V=I9"`B3&]G(&]U="(*;7-G<W1R("+"^_7N
MY"(*"B,@9G5Z>GD*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"FUS9VED
M("),;V=I;B(*;7-G<W1R("+3]^7R[>#_(.?@[^CQ_"(*"B,@9G5Z>GD*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,`IM<V=I9"`B3&]G:6X@5&%S:W,B
M"FUS9W-T<B`BPO7NY"(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY.34*(RP@
M9G5Z>GD*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA
M;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S
M='(@(B(*(L_N(.K@ZNCL+?+N(._PZ/?H[>#L(.+U[N0@XB#QZ/'RY>SS(.WE
M(//DX.OQ_RX@PN7P[O_R[>7E(.+QY>/N+"#"X/CH(.CL_R`B"B+O[NO\Y^[B
MX/+EZ_\@Z.OH(._@\.[K_"#A^^OH(.+BY>3E[?L@[>7BY?#M[BXB"@HC.B!L
M:6(O2&]R9&4O075T:"YP:'`Z.3DQ"B,L(&9U>GIY"FUS9VED("),;V=I;B!F
M86EL960N(@IM<V=S='(@(DE-4"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,S8Y"B,L(&9U>GIY"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`BPOOU[N0B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM
M<V=I9"`B3&]W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R
M965K(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@
M;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"B,L(&9U>GIY"FUS
M9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(LCL_R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$S-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I
M9"`B3'5X96UB;W5R9R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,SDY(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,S<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@
M(DU-(@IM<V=S='(@(LS,(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(X,PIM<V=I9"`B34]41"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T86-H;65N
M="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-
M4T<B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")-86-A;R(*;7-G<W1R
M("))35`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34S(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA
M=B!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,34Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B
M"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z.#,*;7-G:60@(DUA:6PB"FUS9W-T<B`BS^[W\N`B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-3(T"FUS9VED(")-86EL($%D;6EN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.30*(RP@9G5Z>GD*;7-G:60@(DUA;&%W:2(*;7-G<W1R("))35`B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38W(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*(RP@
M9G5Z>GD*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(DE-4"(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$T,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ
M>0IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B24U0(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$U-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR"B,L(&9U>GIY"FUS
M9VED(")-86QI(@IM<V=S='(@(DE-4"(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%L
M=&$B"FUS9W-T<B`B24U0(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT
M"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@
M:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C
M:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("+-X/'R\.[I
MZN`@\>_H\>K@(.K@\N7C[O#HZ2#H(/;BY?+NXB#H]2#N\N[A\.#FY>WH_R(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,34T"FUS
M9VED(")-87`R-"!M87`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#4*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q-CD*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G
M:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-C<*(RP@9G5Z>GD*;7-G:60@(DUA<F-H(@IM
M<V=S='(@(L_NZ/'J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT,0HC+"!F=7IZ>0IM<V=I9"`B36%R9VEN(@IM
M<V=S='(@(L+MZ.S@[>CE(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T
M86YT+T%N<W=E<F5D*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,34R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES
M;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U
M.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDS"B,L(&9U>GIY"FUS9VED(")-87)T:6YI<75E
M(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R("+1[N+O
MX.3@_OGHY2#O[NO_(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDS"B,L(&9U>GIY"FUS9VED(")-875R:71A;FEA(@IM
M<V=S='(@(L+MZ.S@[>CE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-875R:71I=7,B
M"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G
M<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M.`HC+"!F=7IZ>0IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N
M(@IM<V=S='(@(M'N[N'YY>WHY2(*"B,Z(&QI8B]A<&DN<&AP.C@V"B,L(&9U
M>GIY"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM
M<V=S='(@(LS@ZO'H[.#K_.WNY2#J[NOH]^7Q\N+N(/'R\.#MZ/8B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z.3`R(&QI8B](;W)D92]&;W)M+G!H<#HQ,C(Q
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,C0S"FUS9VED(")-87AI;75M(&QE;F=T
M:"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`T(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M.0HC+"!F=7IZ>0IM<V=I9"`B36%Y(@IM<V=S='(@(L7FY>3MY>+M[B(*"B,@
M9G5Z>GD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B36%Y;W1T92(*;7-G<W1R("+"^_7N
MY"(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*(RP@
M9G5Z>GD*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`BQ^#LY?+JZ"(*"B,@9G5Z
M>GD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,@IM<V=I9"`B365N=2!M
M;V1E.B(*;7-G<W1R("+0Y>;H["#LY>W^.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*(RP@9G5Z>GD*;7-G
M:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(M/DX.OH\OPB"@HC.B!L:6(O2&]R
M9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM
M<V=S='(@(M'N[N'YY>WHY2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL
M>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B
M"B)V97)I9FEE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@97AP
M:7)E9"XB"FUS9W-T<B`BT>[NX?GE[>CE(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V.2!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C`R"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"B,L(&9U
M>GIY"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`BT>[NX?GE[>CE(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,PIM<V=I9"`B365T
M87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O<F%R+G!H<#HV-R!L:6(O2&]R9&4O34E-12]6:65W
M97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]24$,O>&UL<G!C+G!H<#HX,2!L:6(O2&]R9&4O4E!#+W-O87`N
M<&AP.C$Q-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(%PB
M)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R("+`Y/#E\>#R(//BY>3N[.OE
M[>C_("5S(.WE(.W@Z>3E[2XB"@HC.B!L:6(O2&]R9&4O4E!#+W)E<W0N<&AP
M.C@R"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@
M0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C8W"FUS9VED(")-971R:6,B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU
M"FUS9VED(")-97AI8V\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C@U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L
M($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"B,L(&9U>GIY
M"FUS9VED(")-:61D;&4B"FUS9W-T<B`B24U0(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-
M:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,S,*(RP@9G5Z>GD*;7-G:60@(DUI<G)O<B(*;7-G<W1R("+.^.CAZN`B"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&QI8B].970O4TU3+W=I
M;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A4
M5%!?4F5Q=65S="XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$Q-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@
M:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H
M:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A
M9V4@240N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P
M86-K86=E($UA:6PN(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HW-@IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-CD*(RP@9G5Z>GD*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(LCL[^[P\B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8V(&QI8B](;W)D
M92]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]T9WHN<&AP.C@U"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU,PHC+"!F=7IZ>0IM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R
M("+3Y.#KZ/+\(._@\/,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C8W-`HC+"!F=7IZ>0IM<V=I9"`B36]D=6QU<R(*;7-G<W1R("+1]N7MX/#H
MZ2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$U,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP
M"B,L(&9U>GIY"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B24U0(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$U-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR"B,L(&9U
M>GIY"FUS9VED(")-;VYG;VQI82(*;7-G<W1R("+*[NSS(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(U.#@*(RP@9G5Z>GD*;7-G:60@(DUO;G1H(&%N9"!Y
M96%R(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R
M+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V
M,RXQ*2`@(RTC+2,M(RTC7&XB"B+0X.?BY?#M\_+\(.+QY2(*"B,Z(&QI8B](
M;W)D92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T
M<B`BQ>;E[.7Q__?M[B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(M3@Y_L@R_/M^R(*"B,Z
M(&QI8B]&:6QE+T-35BYP:'`Z,3DV(&QI8B]&:6QE+T-35BYP:'`Z,C@P"B,L
M('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@
M)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$U-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`HC+"!F=7IZ
M>0IM<V=I9"`B36]R;V-C;R(*;7-G<W1R("))35`B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PHC+"!F=7IZ>0IM<V=I9"`B
M36]S=&QY($-L96%R(@IM<V=S='(@(LKN[._@[>C_(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*(RP@9G5Z>GD*;7-G:60@
M(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`BRN[L[^#MZ/\B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0HC+"!F=7IZ>0IM<V=I
M9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(LKN[._@[>C_(@H*(R!F=7IZ>0HC
M.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HU,#D@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#@*;7-G:60@(DUO=F4@1&]W;B(*
M;7-G<W1R("+OY?#E[.7Q\NCR_"#B[>CG(@H*(R!F=7IZ>0HC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+G!H<#HU,3,@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HV-3(*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R("+O
MY?#E[.7Q\NCR_"#BZ^7B[B(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="YP:'`Z-3$W(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z-C4V"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(N_E\.7LY?'R
MZ/+\(.+O\.#B[B(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="YP:'`Z-3`U(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M-C0T"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(N_E\.7LY?'RZ/+\(.+BY?#U
M(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-3(T"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B[^7PY>SE\?+H\OP@
MXNWHYR(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4R,R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3(T"FUS9VED(")-;W9E('5P(@IM<V=S='(@(N_E\.7LY?'RZ/+\(.+BY?#U
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDU"B,L(&9U>GIY"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(L+MZ.S@
M[>CE(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.#@*;7-G:60@(DUU;'1I
M+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U-@IM<V=I9"`B375L=&EM
M87`@54L@;6%P(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(R-#8*(RP@9G5Z>GD*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO
M;B(*;7-G<W1R("+/[NOM[N4@[N_H\>#MZ.4@[_#NX>OE[/LZ(@H*(R!F=7IZ
M>0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`R"FUS9VED(")->2!!
M8V-O=6YT(@IM<V=S='(@(M/WY?+MX/\@Y^#OZ/'\(@H*(R!F=7IZ>0HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*;7-G:60@(DUY($%C8V]U;G0@26YF
M;W)M871I;VXB"FUS9W-T<B`BPN#XX"#H[?3N\.S@]NC_(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+VEN9&5X+G!H<#HT-0IM<V=I9"`B37D@4&]R=&%L(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HT,PIM<V=I9"`B
M37D@4&]R=&%L($QA>6]U="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,34U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-38*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@
M(DUY86YM87(B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@=&5M<&QA=&5S+VUA
M:6YT96YA;F-E+V%G<F5E;65N=%]B;W1T;VTN:6YC.C<*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)
M($1O($Y/5"!!9W)E92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HT,3$@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,#(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED
M(").86UE(@IM<V=S='(@(LCL_R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<X(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U
M.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDW"B,L(&9U>GIY"FUS9VED(").971H97)L86YD<R(*;7-G
M<W1R("+*X.OE[>3@\/PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#(*
M;7-G:60@(DYE='-C87!E($)A<V4@55),(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!#02!2
M979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-0IM
M<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E(%)E
M=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P92!34TP@<V5R=F5R(&YA;64B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#@*
M;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE
M='-C87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(U,PHC+"!F=7IZ>0IM<V=I9"`B3F5T=V]R
M:R(*;7-G<W1R("+-[N+[Y2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C0R-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.3`*;7-G:60@(DYE=F5R(@IM<V=S='(@(LWHZN[CY.`B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.34*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#
M871E9V]R>2(*;7-G<W1R("+-[N+@_R#JX/+EX^[PZ/\B"@HC.B!L:6(O2&]R
M9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HX,2!L:6(O2&]R9&4O5&5X="]&
M:6QT97(O96UA:6QS+G!H<#HX-PHC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O
M96UA:6QS+G!H<#HY-R!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H
M<#HQ,#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E
M('1O("5S(@IM<V=S='(@(LWNXOOE(/'N[N'YY>WH_R(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K
M+VUO;VXN<&AP.C$W-`HC+"!F=7IZ>0IM<V=I9"`B3F5W($UO;VXB"FUS9W-T
M<B`BPN7P[?/R_/'_(.H@[>#Q\O#NZ>K@["(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T
M:6]N86PI(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B3F5W(%IE86QA
M;F0B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED(").97<@<&%S<W=O<F0B"FUS
M9W-T<B`BS^#P[NO\(@H*(SH@;&EB+TAO<F1E+T%U=&@O<W%L+G!H<#HR,C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E
M(&]N("5X+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z-3(*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9',@9&]N)W0@
M;6%T8V@N(@IM<V=S='(@(L+@^"!%;6%I;#HB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W
M("A?8FQA;FLI(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z-#`@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Y,0IM<V=I
M9"`B3F5W<R(*;7-G<W1R("+-[N+N\?+H(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,P-PHC+"!F=7IZ>0IM<V=I9"`B3F5W<V=R;W5P<R(*;7-G
M<W1R("+3Y.#KZ/+\(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z
M,34@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,C4*;7-G:60@(DYE>'0B"FUS9W-T<B`BQ.#KY>4B"@HC(&9U>GIY"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B3F5X="`T
M(%!H87-E<R(*;7-G<W1R("+1Z^7D\_[YX/\B"@HC(&9U>GIY"B,Z(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,S8V(&QI8B](;W)D92]0<F5F<R]522YP:'`Z
M,S<P"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`BT>OEY//^^>#_(/'R
M\.#MZ/;@(@H*(SH@;&EB+TAO<F1E+U5)+U!A9V5R+G!H<#HQ,#,*(RP@9G5Z
M>GD*;7-G:60@(DYE>'0^(@IM<V=S='(@(L3@Z^7E(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$W-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"B,L(&9U>GIY"FUS
M9VED(").:6-A<F%G=6$B"FUS9W-T<B`B24U0(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$W,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"B,L(&9U>GIY"FUS9VED
M(").:6=E<B(*;7-G<W1R("+-Z.KNX^3@(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$W,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"B,L(&9U>GIY"FUS9VED(").
M:6=E<FEA(@IM<V=S='(@(LWHZN[CY.`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S8Y"B,L(&9U>GIY"FUS9VED(").:6=H="(*;7-G<W1R
M("+-Z.KNX^3@(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDW"B,L(&9U>GIY"FUS9VED(").:75E(@IM<V=S='(@(LWH
MZN[CY.`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.38T"FUS9VED(").;R(*;7-G<W1R("+-Y?(B"@HC.B!T96UP;&%T97,O861M
M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF
M:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HQ,#8*;7-G:60@(DYO
M(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM
M<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-SD@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="YP:'`Z,C0U"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP
M.C(V-R!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P,0HC
M.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C,X-0HC.B!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0P-PIM<V=I9"`B
M3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'`Z-3`*(RP@9G5Z
M>GD*;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(LWE\B#MX/'R\.[EZB#DZ_\@[_#N
M]N7D\_#[(.#S\N7M\NCTZ.K@]NCH(._N(%-13"(*"B,Z(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C4T"B,L(&9U>GIY"FUS9VED(").;R!C:&%N9V4N(@IM<V=S
M='(@(L[R[.7MZ/+\(.CG[.7MY>WH_R(*"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@
M=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4N<&AP
M.C$V.2!L:6(O2&]R9&4N<&AP.C4P."!L:6(O2&]R9&4O571I;"YP:'`Z-S8X
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(LWE(.'[
MZ^X@\^K@Y^#M[B#Q[N[RXN7R\?+B\_[YY>D@Z.WT[O#LX/;HZ"#DZ_\@ZN#R
MY>/N\.CI(%-13"XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#4U"B,L(&9U>GIY
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`BQ.O_(.W@\?+P[N7J($Q$05`@[>4@
MX?OK[B#SZN#GX.WN(/'N[O+BY?+Q\N+S_OGEZ2#H[?3N\.S@]NCH+B(*"B,Z
M(&QI8B]61E,O<W%L+G!H<#HV-S(*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*
M;7-G<W1R("+-Y2#A^^ON(//JX.?@[>X@\>[N\N+E\O'RXO/^^>7I(.CM].[P
M[.#VZ.@@Y.O_(.K@\N7C[O#HZ2!344PN(@H*(SH@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z-S(U"B,L(&9U>GIY"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R
M("+-Y2#A^^ON(//JX.?@[>X@\>[N\N+E\O'RXO/^^>7I(.CM].[P[.#VZ.@@
MY.O_(.K@\N7C[O#HZ2!344PN(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R
M("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"B,L
M(&9U>GIY"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T
M<B`BT>[NX?GE[>CE(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDP,PHC
M+"!F=7IZ>0IM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R("+([/\B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@
M(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R("+`Y/#E\>#R(//BY>3N[.OE[>C_
M("5S(.WE(.W@Z>3E[2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3$V(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC+"!F=7IZ>0IM<V=I
M9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R("+-X/'R\.[IZN@B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"B,L(&9U>GIY"FUS
M9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`BS>#Q\O#NZ>KH
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PHC+"!F
M=7IZ>0IM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`BT>[N
MX?GE[>CE(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M-@HC+"!F=7IZ>0IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@
M(L'[Z^X@\^K@Y^#M[B#MY>KN\/#EZO+M[N4@Y^W@]^7MZ.4N(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PHC+"!F=7IZ>0IM<V=I
M9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`BP?OK[B#SZN#GX.WN
M(.WEZN[P\.7J\NWNY2#G[>#WY>WHY2XB"@HC.B!L:6(O2&]R9&4O075T:"]H
M='1P+G!H<#HY,0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(LWE\B#MX/'R
M\.[EZB#DZ_\@[_#N]N7D\_#[(.#S\N7M\NCTZ.K@]NCH(._N(%-13"(*"B,Z
M(&QI8B](;W)D92]!=71H+VEM87`N<&AP.C$P.`HC+"!F=7IZ>0IM<V=I9"`B
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(LWE\B#MX/'R\.[EZB#DZ_\@[_#N]N7D\_#[(.#S\N7M\NCT
MZ.K@]NCH(._N(%-13"(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C<R
M"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R
M8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(LWE\B#MX/'R\.[EZB#D
MZ_\@[_#N]N7D\_#[(.#S\N7M\NCTZ.K@]NCH(._N(%-13"(*"B,Z(&QI8B](
M;W)D92]!=71H+W-A<VPN<&AP.C<W(&QI8B](;W)D92]!=71H+VQO9VEN+G!H
M<#HX-`HC.B!L:6(O2&]R9&4O075T:"]P86TN<&AP.C<U"B,L(&9U>GIY"FUS
M9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(LWE\B#MX/'R\.[EZB#DZ_\@[_#N]N7D\_#[(.#S
M\N7M\NCTZ.K@]NCH(._N(%-13"(*"B,Z(&QI8B](;W)D92]!=71H+W!A<W-W
M9"YP:'`Z,3,U"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+-Y?(@[>#Q
M\O#NY>H@Y.O_(._P[O;EY//P^R#@\_+E[?+H].CJX/;HZ"#O[B!344PB"@HC
M.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP.C@T"B,L(&9U>GIY"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R("+-Y?(@[>#Q\O#NY>H@Y.O_(._P[O;EY//P^R#@\_+E[?+H].CJ
MX/;HZ"#O[B!344PB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R
M.#<*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R
M;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*
M(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I
M;F<@<VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@;&EB+U9&4RYP:'`Z-S8V"B,L
M(&9U>GIY"FUS9VED(").;R!Q=6]T82!S970N(@IM<V=S='(@(L?@[.7RZN@B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0S"B,L(&9U>GIY"FUS9VED(").;R!R=6QE<R(*;7-G<W1R("+'X.SE
M\NKH(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT.#(*(RP@9G5Z>GD*;7-G:60@
M(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@(L+[(.WE(//JX.?@
MZ^@@[^#OZN@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0T"B,L(&9U>GIY"FUS9VED(").;R!S:61E<R(*;7-G
M<W1R("+'X.SE\NKH(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C4X-PHC+"!F=7IZ
M>0IM<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(L?@[.7RZN@B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(V"FUS9VED(").;R!T96UP
M;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@
M(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$@;&EB
M+TYE="]335,O=VEN7VAT='`N<&AP.C(R,0HC+"!F=7IZ>0IM<V=I9"`B3F\@
M=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(L_NYN#K
M\^GQ\N`L(.+BY>3H\N4@PN#XZ"#H[/\@[^[K_.?NXN#RY>O_(.@@[^#P[NO\
M(@H*(SH@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@
M=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3<R(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY.#(*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY,PHC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`Q,`IM<V=I9"`B3F\@=F%L=65S(@IM
M<V=S='(@(LWE(.[O\.7DY>OE[>XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O
M;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@
M=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A
M=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C<@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O
M:61E;G1I='ES96QE8W0N:6YC.CDS"FUS9VED(").;VYE(@IM<V=S='(@(BWM
MY2#B^^'PX.TM(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B3F]R9&EC
M("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$W,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES
M;&%N9"(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE
M;6ES<&AE<F4B"FUS9W-T<B`BT>7BY?#M[N4@[^[K\_C@\.CE(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$U."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS"FUS9VED
M(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$W-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED
M(").;W)W87DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HV-#$*(RP@9G5Z>GD*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R("+'
MX.SE\NKH(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#`*(RP@
M9G5Z>GD*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`BQ^#LY?+JZ"(*"B,Z
M(&QI8B]61E,O9FEL92YP:'`Z-#$U"B,L(&9U>GIY"FUS9VED(").;W0@82!D
M:7)E8W1O<GDB"FUS9W-T<B`BRN#RX.ONXR(*"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+G!H<#HV,R!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E
M9WDN<&AP.C@T"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2YP:'`Z.34*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDN<&AP.C0X"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D
M+B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N
M,2D@(",M(RTC+2,M(UQN(@HBS>[B[N4@\>[NX?GE[>CE(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`HC+"!F=7IZ>0IM
M<V=I9"`B3F]T('-E="(*;7-G<W1R("+'X.SE\NKH(@H*(SH@;&EB+U9&4RYP
M:'`Z,3DS(&QI8B]61E,N<&AP.C(P."!L:6(O5D93+G!H<#HR,S0@;&EB+U9&
M4RYP:'`Z,C4R"B,Z(&QI8B]61E,N<&AP.C(V.2!L:6(O5D93+G!H<#HR.#4@
M;&EB+U9&4RYP:'`Z,S`Q(&QI8B]61E,N<&AP.C,Q-@HC.B!L:6(O5D93+G!H
M<#HS,S,@;&EB+U9&4RYP:'`Z,S8V(&QI8B]61E,N<&AP.C0R-B!L:6(O5D93
M+G!H<#HU,#4*(SH@;&EB+U9&4RYP:'`Z-3<T(&QI8B]61E,N<&AP.C4Y,2!L
M:6(O5D93+G!H<#HV-CD*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H
M<#HQ-#4@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-C`*(SH@;&EB
M+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S4@;&EB+TAO<F1E+U-E<W-I
M;VY(86YD;&5R+G!H<#HQ.#D*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R
M+G!H<#HR,S8*(RP@9G5Z>GD*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S
M='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M
M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC
M+2,M(RTC7&XB"B+-[N+NY2#Q[N[A^>7MZ.4B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z
M,3`P-0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@P"FUS9VED(").
M;W1E<R(*;7-G<W1R("+'X.SE\NKH(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O
M:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C
M:RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I
M<FU?=&]P+FEN8SHQ,`HC+"!F=7IZ>0IM<V=I9"`B3F]T:6-E(@IM<V=S='(@
M(L?@[.7RZN@B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$P(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0HC
M+"!F=7IZ>0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`BS>CJ[N/DX"(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,#4P"B,L(&9U>GIY"FUS9VED(").=6UB
M97(B"FUS9W-T<B`BR.S_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,CD*
M(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@
M(LCL_R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S<S(&QI8B](;W)D92]&
M;W)M+G!H<#HQ-#(W(&QI8B](;W)D92]&;W)M+G!H<#HQ-#0Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"B,L(&9U>GIY
M"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R("(B"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A4=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+S
MX?#@\OP@\?+NZ^'E]B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S<Q(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-#(U(&QI8B](;W)D92]&;W)M+G!H<#HQ-#0W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R
M"B,L(&9U>GIY"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R("+([/\B
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"B,L(&9U
M>GIY"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG
M(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[
M\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S
M='(@(D]+(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@W,0HC+"!F=7IZ>0IM<V=I9"`B3V)J96-T(@IM<V=S='(@(M+E[.`B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0HC+"!F=7IZ>0IM<V=I
M9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`BS>#Q\O#NZ>KH(._NZ_SG[N+@
M\N7K_R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3`X"B,L(&9U>GIY"FUS
M9VED(")/8W1A;"(*;7-G<W1R("+%YN7D[>7B[>XB"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(X"B,L(&9U>GIY"FUS
M9VED(")/9F9I8V4B"FUS9W-T<B`BQ^#C[NONXN[J(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S
M=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@HC+"!F=7IZ>0IM<V=I9"`B3VQD
M('!A<W-W;W)D(@IM<V=S='(@(L_@\.[K_"(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HT-@HC+"!F=7IZ>0IM<V=I9"`B3VQD('!A<W-W;W)D
M(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R("+/X/#NZ_PB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3@Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M
M86XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C<S"B,L(&9U>GIY"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P
M;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R("+"X/@@X?#N\^?E\"#MY2#O
M[N3DY?#FZ.+@Y?(@[N_VZ/X@[^7WX/+H+B#$Z_\@[^7WX/+H(.W@YNSH\N4@
M0U123"M0+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#4U(&QI8B](;W)D
M92]&;W)M+G!H<#HQ.3<U"B,L(&9U>GIY"FUS9VED(")/;FQY(&]N92!E;6%I
M;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(L+@^"!%;6%I;#HB"@HC.B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE
M(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N
M97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,Y(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C0P"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(T-0IM
M<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F
M<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS
M9VED(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@
M(D]P=&EO;G,B"FUS9W-T<B`BS>#Q\O#NZ>KH(@H*(R!F=7IZ>2P@<&AP+69O
M<FUA=`HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z('-E<G9I8V5S+W!R969S+G!H
M<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R("+-X/'R\.[IZN@@Y.O_
M.B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V.`HC+"!F=7IZ>0IM<V=I9"`B3W)G
M86YI<V%T:6]N(@IM<V=S='(@(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_\B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V.0HC+"!F=7IZ>0IM<V=I
M9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R("+-X/'R\.[IZN@@[^[K
M_.?NXN#RY>O_(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3,T"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(L[PX^#MX.GGY?`B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@
M87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@
M=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED
M(")/=&AE<B(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Y"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-#0*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@
M(L_P[O?@_R#H[?3N\.S@]NC_(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS,0HC+"!F=7IZ>0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS
M9W-T<B`BS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_R(*"B,Z(&QI8B](;W)D92]!
M=71H+W!A;2YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(E!!32!A=71H96YT:6-A
M=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("+-Y?(@Y.[Q\O/O[?OU
M(.W@\?+P[N7J+B(*"B,Z(&QI8B].970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z
M,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3(W-@IM<V=I9"`B4$=0($1I9VET
M86P@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C$S,C(*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S<T"FUS9VED(")0
M1U`@4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HQ,S4V"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.`HC+"!F=7IZ
M>0IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!A9&UI;B]P
M:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PHC+"!F
M=7IZ>0IM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R("+"]>[D(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*(RP@9G5Z
M>GD*;7-G:60@(E!-(%)A:6XB"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0HC+"!F=7IZ>0IM
M<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R("+([._N\/(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`HC+"!F=7IZ>0IM<V=I
M9"`B4$T@4VYO=R(*;7-G<W1R("+([._N\/(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0HC+"!F=7IZ>0IM<V=I9"`B4$T@
M4VYO=R!3:&]W97)S(@IM<V=S='(@(LCL[^[P\B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"B,L(&9U>GIY"FUS9VED(")0
M32!3=6XB"FUS9W-T<B`BR.SO[O#R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#,*(RP@9G5Z>GD*;7-G:60@(E!-(%0M4W1O
M<FUS(@IM<V=S='(@(LCL[^[P\B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S
M='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L;"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$W,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0HC
M+"!F=7IZ>0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`BQ.#RX"(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$W,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*(RP@
M9G5Z>GD*;7-G:60@(E!A;&%U(@IM<V=S='(@(DE-4"(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$W-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A
M;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"B,L
M(&9U>GIY"FUS9VED(")086YA;6$B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS
M9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$W-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*(RP@9G5Z>GD*
M;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(DE-4"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"B,L(&9U>GIY"FUS9VED(")0
M87)T;'D@0VQO=61Y(@IM<V=S='(@(LKN[._@[>C_(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,"!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C`R,@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3,W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z
M(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ-3$@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHW-PHC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C0S(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C4*;7-G:60@(E!A
M<W-W;W)D(@IM<V=S='(@(L_@\.[K_"(*"B,@9G5Z>GD*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C@R"B,L(&9U>GIY"FUS9VED(")087-S=V]R
M9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`BT>[NX?GE[>CE(//Q
M[^7X[>X@[O+O\.#BZ^7M[BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C$S,C,*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*
M;7-G<W1R("+/X/#NZ_PB"@HC.B!L:6(O2&]R9&4O075T:"]R861I=7,N<&AP
M.C$U,@HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!
M1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BS>7R(.W@\?+P[N7J(.3K
M_R#O\.[VY>3S\/L@X//RY>WRZ/3HZN#VZ.@@[^X@4U%,(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(P-3<*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D('=I
M=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(L_P[O?@_R#H[?3N\.S@]NC_(@H*
M(R!F=7IZ>0HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G
M:60@(E!A<W-W;W)D.B(*;7-G<W1R("+/X/#NZ_PB"@HC(&9U>GIY"B,Z('1E
M;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@
M(@IM<V=S='(@(L_@\.[K_"(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C`S.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C$U"B,L(&9U>GIY"FUS9VED(")087-S=V]R9',@;75S="!M
M871C:"XB"FUS9W-T<B`BPN#X($5M86EL.B(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(R"B,L(&9U>GIY"FUS9VED(")087-T92(*;7-G<W1R("+$
MX/+@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0HC
M+"!F=7IZ>0IM<V=I9"`B4&%T:"(*;7-G<W1R("+$X/+@(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P
M<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?8F]T=&]M+FEN8SHV"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS
M9VED(")097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B
MSO'S^>7Q\N+KY>WHY2#N[^7PX/;HZ2#O[N3DY?#FZN@B"@HC(&9U>GIY"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,3`*;7-G:60@(E!E<F9O<FT@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`BPOOO[NOM
MZ/+\(.[OY?#@]NCH(.[A\>OSYNCBX.WH_R#O\.@@XO7NY.4@XB#QZ/'RY>SS
M/R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,34V"FUS9VED(")097)M
M:7-S:6]N(@IM<V=S='(@(L_PX.+@(@H*(SH@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HU,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO
M;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M
M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+-[N+NY2#Q
M[N[A^>7MZ.4B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S
M('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M
M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@
M(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S
M('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M
M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@
M(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S
M('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M
M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@
M(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S
M('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M
M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@
M(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S
M('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M
M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@
M(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@<G5?4E4N<&\@*$UN96UO($@S("@R
M+C`N,BDI("`C+2,M(RTC+2,*(R!F=7IZ>0HC(",M(RTC+2,M(R`@<G5?4E4N
M<&\@*$UN96UO($@S("@R+C`N,BDI("`C+2,M(RTC+2,*(R!F=7IZ>0HC(",M
M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M(PHC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M
M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T
M+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M
M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T
M+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@<G5?4E4N
M<&\@*$UN96UO($@S("@R+C`N,BDI("`C+2,M(RTC+2,*(R!F=7IZ>0HC(",M
M(RTC+2,M(R`@<G5?4E4N<&\@*$UN96UO($@S("@R+C`N,BDI("`C+2,M(RTC
M+2,*(R!F=7IZ>0HC(",M(RTC+2,M(R`@<G5?4E4N<&\@*$UN96UO($@S("@R
M+C`N,BDI("`C+2,M(RTC+2,*(R!F=7IZ>0HC(",M(RTC+2,M(R`@<G5?4E4N
M<&\@*$UN96UO($@S("@R+C`N,BDI("`C+2,M(RTC+2,*(R!F=7IZ>0HC(",M
M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M(PHC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M
M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T
M+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M
M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T
M+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M24U0($@S('8T+C`N-"D@(",M(RTC+2,M(PHC(",M(RTC+2,M(R`@<G5?4E4N
M<&\@*$UN96UO($@S("@R+C`N,BDI("`C+2,M(RTC+2,*(R!F=7IZ>0HC(",M
M(RTC+2,M(R`@<G5?4E4N<&\@*$UN96UO($@S("@R+C`N,BDI("`C+2,M(RTC
M+2,*(R!F=7IZ>0HC.B!L:6(O5D93+W-M8BYP:'`Z-3DP"B,L(&9U>GIY"FUS
M9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("(B"B(C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*
M(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M
M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@
M=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN
M<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@
M8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC
M+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V
M-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M
M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T
M+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O
M("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O
M;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M
M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC
M+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N
M,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M
M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP
M+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC
M+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N
M-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)
M35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M
M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-
M4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(LW@\?+P[NGJZ"#O[NO\Y^[B
MX/+EZ_]<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$UN96UO($@S("@R+C`N
M,BDI("`C+2,M(RTC+2-<;B(*(LCG[.7MZ/+\(._PX.+@(.3N\?+S[^!<;B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$UN96UO($@S("@R+C`N,BDI("`C+2,M
M(RTC+2-<;B(*(LCG[.7MZ/+\(._PX.+@(.3N\?+S[^!<;B(*(B,M(RTC+2,M
M(R`@<G5?4E4N<&\@*$YA9R!(,R`H,BXP+C,I*2`@(RTC+2,M(RTC7&XB"B+(
MY^SE[>CR_"#O\.#BX"#D[O'R\^_@7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O
M("A.86<@2#,@*#(N,"XS*2D@(",M(RTC+2,M(UQN(@HBR.?LY>WH\OP@[_#@
MXN`@Y.[Q\O/OX%QN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5VAU<',@,2XP
M+6-V<RD@(",M(RTC+2,M(UQN(@HBS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_UQN
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5VAU<',@,2XP+6-V<RD@(",M(RTC
M+2,M(UQN(@HBS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_UQN(@HB(RTC+2,M(RTC
M("!R=5]252YP;R`H5VAU<',@,2XP+6-V<RD@(",M(RTC+2,M(UQN(@HBS>#Q
M\O#NZ>KH(._NZ_SG[N+@\N7K_UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M5VAU<',@,2XP+6-V<RD@(",M(RTC+2,M(UQN(@HBS>#Q\O#NZ>KH(._NZ_SG
M[N+@\N7K_UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5VAU<',@,2XP+6-V
M<RD@(",M(RTC+2,M(UQN(@HBS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_UQN(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XV*2`@(RTC+2,M(RTC
M7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C8I("`C+2,M
M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A($@S('8R+C`N
M-"D@(",M(RTC+2,M(UQN(@HBS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_UQN(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@2#,@=C(N,"XT*2`@(RTC+2,M
M(RTC7&XB"B+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_7&XB"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A4=7)B82!(,R!V,BXP+C0I("`C+2,M(RTC+2-<;B(*(LW@
M\?+P[NGJZ"#O[NO\Y^[BX/+EZ_]<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@
M*%1U<F)A($@S('8R+C`N-"D@(",M(RTC+2,M(UQN(@HBS>#Q\O#NZ>KH(._N
MZ_SG[N+@\N7K_UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@2#,@
M=C(N,"XT*2`@(RTC+2,M(RTC7&XB"B+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_
M7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!(,R!V,BXP+C0I("`C
M+2,M(RTC+2-<;B(*(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_]<;B(*(B,M(RTC
M+2,M(R`@<G5?4E4N<&\@*%1U<F)A($@S('8R+C`N-"D@(",M(RTC+2,M(UQN
M(@HBS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_UQN(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H2&]R9&4@=C,N,"XV*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A-;F5M;R!(,R`H,BXP+C(I*2`@(RTC+2,M(RTC7&XB"B+(
MY^SE[>CR_"#O\.#BX"#D[O'R\^_@7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O
M("A-;F5M;R!(,R`H,BXP+C(I*2`@(RTC+2,M(RTC7&XB"B+(Y^SE[>CR_"#O
M\.#BX"#D[O'R\^_@7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A.86<@2#,@
M*#(N,"XS*2D@(",M(RTC+2,M(UQN(@HBR.?LY>WH\OP@[_#@XN`@Y.[Q\O/O
MX%QN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@2#,@=C(N,"XT*2`@
M(RTC+2,M(RTC7&XB"B+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_7&XB"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C8I("`C+2,M(RTC+2-<;B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A($@S('8R+C`N-"D@(",M(RTC
M+2,M(UQN(@HBS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_UQN(@HB(RTC+2,M(RTC
M("!R=5]252YP;R`H5'5R8F$@2#,@=C(N,"XT*2`@(RTC+2,M(RTC7&XB"B+-
MX/'R\.[IZN@@[^[K_.?NXN#RY>O_7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O
M("A4=7)B82!(,R!V,BXP+C0I("`C+2,M(RTC+2-<;B(*(LW@\?+P[NGJZ"#O
M[NO\Y^[BX/+EZ_]<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A($@S
M('8R+C`N-"D@(",M(RTC+2,M(UQN(@HBS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K
M_R(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-C$@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@(E!E<FUI<W-I;VYS(@IM
M<V=S='(@(L_PX.+@(.3N\?+S[^`B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H
M<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN+W!E
M<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"FUS
M9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC
M(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.`IM<V=I9"`B4&5R
M<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`BR^CW[?OE(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$X,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")0
M97)U(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G
M:60@(E!H;VYE(@IM<V=S='(@(M+EZ^7T[NTB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#@P"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`HC
M+"!F=7IZ>0IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`BQ.#RX"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED
M(")0:7AE;',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K
M(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE
M87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M
M96YT.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M
M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U-C8*(RP@9G5Z>GD*;7-G
M:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@
M(L+@^"!%;6%I;#HB"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@
M=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`BPN+EY.CRY2#MX.?BX.WHY2#M
M[N+NZ2#JX/+EX^[PZ.@Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,#4*
M(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E
M<W,N(@IM<V=S='(@(L+@^"!%;6%I;#HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C8T-PIM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE
M8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T-3$*(RP@9G5Z>GD*;7-G:60@
M(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(L+@^"!%;6%I
M;#HB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED
M(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM
M<V=S='(@(L_NYN#K\^GQ\N`L(/'N[N'YZ/+E(/'S\OP@[_#NX>OE[/LN(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S
M97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R("+/[N;@Z_/I\?+@+"#BXN7D
MZ/+E(,+@^.@@Z.S_(._NZ_SG[N+@\N7K_R#H(._@\.[K_"(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]A9W)E96UE;G1?=&]P+FEN8SHQ,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E
M>'0N("!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE
M("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG
M('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T
M:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O
M0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE
M(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*(RP@9G5Z>GD*;7-G
M:60@(E!O;&%N9"(*;7-G<W1R("+*[NSOX.WH_R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT.#D*(RP@9G5Z>GD*;7-G:60@(E!O;&QS(@IM<V=S
M='(@(M'BY?#M\_+\(.+QY2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L
M92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E
M9"!B>2!)34%0*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C@W"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]L9&%P+G!H<#HY.`IM
M<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O<V5S<VEO
M;BYP:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I
M;VX@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-`HC+"!F=7IZ>0IM<V=I9"`B4')E
M<W-U<F4Z("(*;7-G<W1R("+/X/#NZ_PB"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C`T"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PHC+"!F=7IZ>0IM<V=I
M9"`B4')E=FEE=R(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(
M;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O
M("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBS>#GX.0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*
M;7-G:60@(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G
M<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S4V
M(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S8P"FUS9VED(")0<F5V:6]U<R!O
M<'1I;VYS(@IM<V=S='(@(L_PY>3[Y//YX/\@\?+PX.WH]N`B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0
M<FEN="!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,@
M9G5Z>GD*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE
M;2(*;7-G<W1R("+/\.[AZ^7LX#\B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H
M<#HQ,C<*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`BSN_H
M\>#MZ.4@[_#NX>OE[/LB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S<Q"FUS9VED(")0<F]J96-T<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C$Q-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Y,B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S(X,PHC+"!F=7IZ>0IM<V=I9"`B4')O;7!T('1E>'0B
M"FUS9W-T<B`BPOOU[N0B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT
M,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV-#8*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I
M=&AM(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-C0U"B,L(&9U>GIY"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B
MPN#XY2#O[NOM[N4@Z.S_.B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A
M=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Y,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O
M(%)I8V\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P,@HC+"!F=7IZ>0IM<V=I9"`B46%T87(B"FUS
M9W-T<B`B24U0(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8S"FUS9VED(")1
M=65R>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*
M(RP@9G5Z>GD*;7-G:60@(E%U;W1A(@IM<V=S='(@(DE-4"(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-C8T"B,L('!H<"UF;W)M870*;7-G:60@
M(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(B(*"B,@9G5Z>GD*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-C@*(RP@9G5Z>GD*;7-G:60@(E)A
M9&EO('-E;&5C=&EO;B(*;7-G<W1R("+/[NOM[N4@[N_H\>#MZ.4@[_#NX>OE
M[/LZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#0*(RP@9G5Z>GD*;7-G:60@(E)A:6XB"FUS9W-T<B`BPNWH[.#MZ.4B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-0HC+"!F
M=7IZ>0IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R("+"]>[D(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*(RP@9G5Z>GD*
M;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R("+"]>[D(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*(RP@9G5Z>GD*;7-G:60@
M(E)A:6X@4VAO=V5R(@IM<V=S='(@(L+U[N0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B4F%I
M;B!A;F0@4VYO=R(*;7-G<W1R("+"]>[D(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*(RP@9G5Z>GD*;7-G:60@(E)A:6X@
M=&\@4VYO=R(*;7-G<W1R("+"]>[D(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C@@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S8*(RP@9G5Z>GD*;7-G:60@(E)A=&EO(@IM<V=S='(@(LW@\?+P[NGJZ"(*
M"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G
M:60@(E)E860B"FUS9W-T<B`BU^CRX/+\(@H*(SH@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C@W"B,L(&9U>GIY"FUS9VED(")296%D(&UE<W-A
M9V5S(@IM<V=S='(@(M'N[N'YY>WHY2(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@
M9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T
M82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N
M92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS-`HC+"!F=7IZ>0IM<V=I9"`B4F5D;V5S('EO=7(@;&%S
M="!A8W1I;VXB"FUS9W-T<B`BT^3@Z^CR_"#OX/#S(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#8*;7-G
M:60@(E)E9G)E<V@B"FUS9W-T<B`BSN'M[N+H\OPB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,SDU"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%
M;&5M96YT<SHB"FUS9W-T<B`BSN'M[N+K__+\(.3H[>#LZ/?E\>KHY2#O\^WJ
M\OL@[.7M_CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0U"FUS9VED
M(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R("+.X>WNXNO_\OP@Z.WT
M[O#LX/;H_CHB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DX(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,C$W(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,Y"B,L(&9U
M>GIY"FUS9VED(")296=E>"(*;7-G<W1R("+1X?#N\>CR_"(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HS,C,X"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E
M<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ
M-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,L(&9U>GIY"FUS
M9VED(")296QO860B"FUS9W-T<B`BS_#N]^CRX.WM^^4B"@HC(&9U>GIY"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3<*;7-G:60@(E)E;6]T92!397)V
M97)S(@IM<V=S='(@(L_N]_+NXOOE(/'E\.+E\.`B"@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z
M+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R("+`Y/#E\2#QY?#B
MY?#@("CMX._PZ.SE\"!H='1P.B\O;6%I;"YR=2DB"@HC(&9U>GIY"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E<75E=65D+FEN8SHQ,PIM<V=I9"`B4F5M;W9E(@IM<V=S='(@
M(M/DX.OH\OPB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHQ,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(M/DX.OH\OP@
MX>ONZB(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU
M-3<*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M
M(UQN(@HB\^'PX/+\(/'R[NOAY?8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0P"B,L(&9U>GIY"FUS9VED(")296UO=F4@
M9F]R;6%T=&EN9R(*;7-G<W1R("+3Y.#KZ/+\(._@\/,B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS
M9W-T<B`BT^3@Z^CR_"#OX/#S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S
M('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@HC+"!F
M=7IZ>0IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R("+3Y.#KZ/+\(._@\/,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C
M=6UE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T
M<B`BT^3@Z^CR_"#OX/#S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E+FEN8SHU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@
M=7-E<CH@)7,B"FUS9W-T<B`BT^3@Z^CR_"#OX/#S(@H*(SH@;&EB+TAO<F1E
M+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B
M92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-0HC+"!F=7IZ>0IM
M<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*
M;7-G<W1R("+`Y/#E\>#R(//BY>3N[.OE[>C_("5S(.WE(.W@Z>3E[2XB"@HC
M.B!L:6(O2&]R9&4N<&AP.C$W-B!L:6(O2&]R9&4N<&AP.C4Q.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C
M:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BS>7NX?7NY.CL
M^^D@[^#PX.SE\O`@)W5I9"<@[>4@\^K@Y^#M(.(@ZN[M].CC\_#@]NCH(.W@
M\?+P[N7J+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HV-S@@;&EB+U9&4R]F='`N
M<&AP.C@V,2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW,S$*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D
M(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+-Y>[A]>[DZ.S[Z2#O
MX/#@[.7R\"`G=6ED)R#MY2#SZN#GX.T@XB#J[NWTZ./S\.#VZ.@@[>#Q\O#N
MY>HN(@H*(SH@;&EB+TAO<F1E+U5T:6PN<&AP.C<W-@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@
M:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BS>7NX?7NY.CL^^D@[^#PX.SE
M\O`@)W5I9"<@[>4@\^K@Y^#M(.(@ZN[M].CC\_#@]NCH(.W@\?+P[N7J+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,S4*;7-G:60@(E)E
M<75I<F5D($9I96QD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q
M(&QI8B](;W)D92]&;W)M+G!H<#HS-#,@;&EB+TAO<F1E+T9O<FTO4F5N9&5R
M97(N<&AP.C,R,`HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E
M<V5T(@IM<V=S='(@(M'A\.[QZ/+\(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-#8*(RP@9G5Z>GD*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM
M<V=S='(@(L_@\.[K_"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C(W"B,L(&9U>GIY"FUS9VED(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S
M='(@(L_@\.[K_"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S`*(RP@9G5Z
M>GD*;7-G:60@(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G<W1R("+3Y.#KZ/+\
M(._@\/,B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE
M;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@IM<V=I9"`B4F5S=6QT
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T
M;R!/<'1I;VYS(@IM<V=S='(@(L+E\.WS\OSQ_R#J(.W@\?+P[NGJX.PB"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*(RP@9G5Z>GD*;7-G
M:60@(E)E='EP92!N97<@<&%S<W=O<F0B"FUS9W-T<B`BS^#P[NO\(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@HC
M+"!F=7IZ>0IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBT^3@Z^7M
M[?OE(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*
M;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S4*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R("+-
MX/'R\.[IZN@@XNCG\^#K_.WNX^X@\.7DX.KR[O#@(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P"B,L(&9U>GIY
M"FUS9VED(")2:6=H="(*;7-G<W1R("+-Z.KNX^3@(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C,Q,3`*(RP@9G5Z>GD*;7-G:60@(E)I9VAT(&AE861E<B(*
M;7-G<W1R("+/\.CLY?`@Y^W@]^7MZ.DZ(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,Q,#8*(RP@9G5Z>GD*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R
M("+/\.CLY?`@Y^W@]^7MZ.DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"B,L(&9U>GIY"FUS9VED(")2
M;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`BRNOE\N[W[>#_(/#@Y.CN\>+_
MY_PB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`IM
M<V=I9"`B4F]L92(*;7-G<W1R("+1]N7MX/#HZ2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X
M-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*(RP@9G5Z>GD*;7-G
M:60@(E)O;6%N:6$B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-`HC+"!F=7IZ>0IM<V=I9"`B
M4F]T871E(#$X,"(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(
M;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O
M("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HB[^7PY>SE\?+H\OP@XN+E\/4B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(Q"B,L
M(&9U>GIY"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R("(B"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HB[^7P
MY>SE\?+H\OP@XN+E\/4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C(W"B,L(&9U>GIY"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS
M9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M
M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C
M+2,M(RTC+2-<;B(*(N_E\.7LY?'RZ/+\(.+BY?#U(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0HC+"!F=7IZ
M>0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`BRNOE\N[W[>#_(/#@
MY.CN\>+_Y_PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<P"B,L(&9U>GIY"FUS9VED(")2;W<@<')O<&5R=&EE
M<R(*;7-G<W1R("+*Z^7R[O?MX/\@\.#DZ.[QXO_G_"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"B,L(&9U>GIY"FUS
M9VED(")2;W=S.B(*;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"B,L(&9U>GIY
M"FUS9VED(")2=6QE<R(*;7-G<W1R("+1]N7MX/#HZ2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@
M(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M
M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,`IM<V=I9"`B4G5N(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3D@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`S"B,L(&9U>GIY"FUS9VED(")2=V%N9&$B"FUS9W-T<B`BRN#KY>WDX/#\
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O
M34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,R,PHC+"!F=7IZ>0IM<V=I9"`B
M4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(LWE(.SNX_,@[O+J
M\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B](;W)D
M92]!=71H+W-A<VPN<&AP.C@Q"B,L(&9U>GIY"FUS9VED(")305-,(&%U=&AE
M;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(LWE\B#D[O'R
M\^_M^_4@[>#Q\O#NY>HN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C4P-@HC+"!F=7IZ>0IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R("+.
M\N_PX.+H\OP@\>[NX?GE[>CE(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q
M"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,R.#$*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO
M;VMU<',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0S,PIM<V=I9"`B4U-((@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T53
M4R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@
M4VAE;&PB"FUS9W-T<B`B(@H*(R`C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@
M=C,N,2D@(",M(RTC+2,M(PHC(&9U>GIY"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*(RP@9G5Z>GD*;7-G:60@(E-A(@IM
M<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC
M+2,M(RTC7&XB"B+1[O7PX.WH\OP@ZN#J7&XB"B(C+2,M(RTC+2,@(')U7U)5
M+G!O("A4=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+1[O7PX.WH\OPB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T
M"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$S,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DP"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN
M="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$S.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W"B,L(&9U>GIY"FUS9VED
M(")386EN="!,=6-I82(*;7-G<W1R("+"]>[D(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$X.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@
M4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C0T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN
M="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED
M(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(U,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DT"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B4V%M
M;V$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ>0IM<V=I9"`B4V%N($UA<FEN;R(*
M;7-G<W1R("+"[>CLX.WHY2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN
M8VEP92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Q(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS
M9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B(@H*(R`C+2,M(RTC+2,@(')U
M7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(PHC(&9U>GIY"B,@9G5Z>GD*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDY"FUS9VED(")3879E
M(@IM<V=S='(@(M'N]?#@[>CR_"(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A
M=F4@7"(E<UPB(@IM<V=S='(@(M'N]?#@[>CR_"#MX/'R\.[IZN@B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R("+1[O7PX.WH\OP@[>#Q\O#N
MZ>KH(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V
M92!/<'1I;VYS(@IM<V=S='(@(M'N]?#@[>CR_"#MX/'R\.[IZN@B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3879E(&=E;F5R
M871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E
M<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB
M+B(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E
M7U1A<VL@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM
M<V=S='(@(LCL[^[P\B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED
M(")396%R8V@B"FUS9W-T<B`BS^[H\>HB"@HC(&9U>GIY+"!P:'`M9F]R;6%T
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C(*(RP@9G5Z>GD*;7-G
M:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(L_NZ/'J(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(Y-C(*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!&:6QE
M<R(*;7-G<W1R("+"^^'E\.CRY2#T[O#LX/(@Y.#R^SHB"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@S"B,L(&9U>GIY"FUS9VED
M(")396QE8W0@82!D871E(@IM<V=S='(@(L+[X>7PZ/+E(/3N\.S@\B#DX/+[
M.B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"B,L(&9U>GIY
M"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`BPOOAY?#H
M\N4@].[P[.#R(.3@\OLZ(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHT,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S
M='(@(L+[X>7PZ/+E(/3N\.S@\B#DX/+[.B(*"B,@9G5Z>GD*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V
M97(B"FUS9W-T<B`BPOOAY?#H\N4@\>7PXN7P(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ-38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A('5S
M97(@=&\@861D(@IM<V=S='(@(L+[X>7PZ/+E(/3N\.S@\B#DX/+[.B(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HV-S0*;7-G:60@
M(E-E;&5C="!A;&PB"FUS9W-T<B`BPOOA\.#R_"#B\>4B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C8U,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%L;"!D
M871E(&-O;7!O;F5N=',N(@IM<V=S='(@(L+[X>7PZ/+E(/3N\.S@\B#DX/+[
M.B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX-S$*
M(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`BPOOA
MY?#H\N4@].[P[.#R(.3@\OLZ(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C8W-0IM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B
MSO+LY>WH\OP@XOOA[O`B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*
M(RP@9G5Z>GD*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@
M;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@
M86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R
M("(B"B+"^^'E\.CRY2#M\^;M^^4@PN#L(/'H[.+NZ_L@Z.<@].[P["#B[>CG
M\RX@Q^#RY>P@POL@[.[FY?+E(/'J[N_H\.[BX/+\(.@@(@HBXO'RX.+H\OP@
MZ/4@XB#RY>KQ\BXB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM
M<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`BPOOA
MY?#H\N4@\.#GY.7KZ/+EZ_P@[^[KY>D@Y.#R^SHB"@HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA
M=#HB"FUS9W-T<B`BPOOAY?#H\N4@].[P[.#R(.3@\OLZ(@H*(SH@=&5M<&QA
M=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T
M('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(L+[
MX>7PZ/+E(._P[O3HZ_P@Y.O_(.W@\?+P[NGJZ#HB"@HC.B!T96UP;&%T97,O
M9&%T82]T:6UE+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!T
M:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`BPOOAY?#H\N4@\.#GY.7KZ/+EZ_P@
M[^[KY>D@Y.#R^SHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM
M<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`BPOOAY?#H
M\N4@[O+NX?#@YN7MZ/\@].[P[.#R(.+PY>SE[>@Z(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN
M9R!F:65L9',N(@IM<V=S='(@(L+[X>7PZ/+E(.3BX"#Q[N+OX.3@_OGH]2#O
M[NO_+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,3`*;7-G:60@(E-E
M;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`BPN#XX"#VXN7R[N+@
M_R#Q]>7LX"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3(*;7-G:60@
M(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`BW^?[
MZB#N\N[A\.#FY>WH_R(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(L_N
M\>O@\OP@\>[NX?GE[>CE(.X@[_#NX>OE[.4B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`T,`IM<V=I9"`B4V5N9"!335,B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PHC+"!F=7IZ>0IM<V=I9"`B4V5P
M=&5M8F5R(@IM<V=S='(@(L?@[.7RZN@B"@HC.B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#(*
M(RP@9G5Z>GD*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`BR.S_(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T.0HC+"!F=7IZ>0IM
M<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`BS>7R(.3N\?+S[^W[]2#MX/'R\.[EZBXB"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS
M9W-T<B`B(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N
M,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(LW@\?+P[NGJZ"#O[NO\
MY^[BX/+EZ_]<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$YA9R!(,R`H,BXP
M+C,I*2`@(RTC+2,M(RTC7&XB"B+(Y^SE[>CR_"#O\.#BX"#D[O'R\^_@7&XB
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A.86<@2#,@*#(N,"XS*2D@(",M(RTC
M+2,M(UQN(@HBR.?LY>WH\OP@[_#@XN`@Y.[Q\O/OX"(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"B,L(&9U>GIY"FUS9VED(")3
M97-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(M'N[N'YY>WHY2(*"B,Z(&QI
M8B]A<&DN<&AP.C$T-0HC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T
M<B`BQ^#LY>WH\OP@[>`B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,Q.`HC
M+"!F=7IZ>0IM<V=I9"`B4V5T(@IM<V=S='(@(M+E[.`B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-SD*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W
M('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E
M="!I="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M.`IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@
M=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(B(*(L3N[^[K
M[>CRY>O\[?OE(._N]_+NXOOE(/'E\.+E\.`L(.H@ZN[R[O#[["#B^R#U[O+H
M\N4@Z.SE\OP@Y.[Q\O/O(.CG(,_N\/+@Z^`N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@W"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A
M9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(M/Q\N#M
M[N+JX"#_Y_OJX"#B^^+NY.`L(.+PY>SE[>WNZ2#G[NW[(.@@].[P[.#RX"#N
M\N[A\.#FY>WH_R#B\.7LY>WH+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,#$*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL
M(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB
M9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B"B+3\?+@[>[BZN`@[_#HZ^[F
MY>WH_R#O[B#S[.[K]^#MZ/XL(/;BY?+NXN[I(/'UY>S[(.@@[_#N]^CU(.[O
M]NCI(.[R[N'PX.;E[>C_(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW
M-PIM<V=I9"`B4V5T=7`B"FUS9W-T<B`BS_#HZ^[FY>WH_R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W"B,L(&9U>GIY"FUS9VED
M(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(LWE
M(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@(E-E=F5R
M86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B(@H*(R`C
M+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(PHC(&9U
M>GIY"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.3@*(RP@9G5Z>GD*
M;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N
M<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+1[O7PX.WH\OP@ZN#J7&XB
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!V,2XQ*2`@(RTC+2,M(RTC
M7&XB"B+1[O7PX.WH\OPB"@HC(&9U>GIY"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@
M(LKPX/+J[N4@[N'NX?GE[>CE.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT-3`*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O
M<B!M;W-T(&QI;FMS/R(*;7-G<W1R("+.[_#EY.7KZ/+\(.'[\?+P^^4@ZNO@
MXNCXZ"#DZ_\@\?'[Z^[J/R(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+U!E<FUS
M+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`BS^[JX.?@\OPB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W
M(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@
M;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.30*;7-G:60@(E-H;W<@;&%S
M="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`BS^[JX.?[
MXN#R_"#H[?3N\.S@]NC^(.X@[_#EY/OD\_GE["#B]>[DY3\B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3<V.0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E
M<"!O<FEG:6YA;"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C@P,@HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`BR.SO
M[O#R(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,P"FUS
M9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@
M(L_NZN#GX/+\(.SE[?X@[N_E\.#VZ.D@\2#RX.'KZ/;@[.@B"@HC('!H<"UF
M;W)M870*(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S4S"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE
M;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(L[R[N'PX.;@\OP@[.7M_B`E<R#Q
MZ^7BX#\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3D*(RP@9G5Z>GD*;7-G:60@(E-H;W<@=&AE(%1A8FQE
M($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`BRNOE\N[W[>#_(/#@
MY.CN\>+_Y_PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C0*(RP@9G5Z>GD*;7-G:60@(E-H;W<@=&AE(%1A
M8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(LKKY?+N]^W@_R#PX.3H
M[O'B_^?\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8P"B,L(&9U>GIY"FUS9VED(")3:&]W('1H92!486)L
M92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`BRNOE\N[W[>#_(/#@
MY.CN\>+_Y_PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3(*(RP@9G5Z>GD*;7-G:60@(E-H;W<@=&AE(&EM
M86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(LKKY?+N]^W@_R#PX.3H
M[O'B_^?\(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C<*(RP@9G5Z>GD*
M;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(LCL_R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"B,L(&9U>GIY"FUS9VED
M(")3:&]W97)S(@IM<V=S='(@(LCL[^[P\B(*"B,@9G5Z>GD*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*(RP@9G5Z>GD*;7-G
M:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`BRO#@\NKNY2#NX>[A^>7MZ.4Z
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*
M(RP@9G5Z>GD*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R("+([._N\/(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM
M<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B(@H*(R!F
M=7IZ>0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HT.#`@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV,3D*;7-G:60@(E-H<FEN
M:R(*;7-G<W1R("+1\^?H\OPB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+G!H<#HW-S0@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z.#,V"B,Z(&QI
M8B](;W)D92]";&]C:R],87EO=70N<&AP.CDR,B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+G!H<#HY.#0*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z
M,3`T-R!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HQ,#@W"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C$Q,38@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="YP:'`Z,3$T.0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.CDQ,`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.CDW,@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C$P-3@*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ
M,3(P"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3$X
M,PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R,C,*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C4R"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(X-0IM<V=I
M9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O
M9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,
M96]N92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP
M.C(V-@IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C<Q,PIM<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3
M:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P
M,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A
M<&]R92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3`P(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,C$Y(&QI8B](;W)D92]&;W)M+G!H<#HQ,C0Q
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C4P(&QI8B](;W)D92]&;W)M+G!H
M<#HR.3$Y(&QI8B](;W)D92]&;W)M+G!H<#HS,3$R"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R87(N<&AP.C8U(&QI8B](;W)D92]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@T
M"FUS9VED(")3:7IE(@IM<V=S='(@(M#@Y^SE\"(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]C;VYF:7)M7V)O='1O;2YI;F,Z.0HC.B!T96UP;&%T97,O
M;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-
M86EN=&5N86YC92(*;7-G<W1R("+/\.[O\_'RZ/+\(._NY.3E\.;J\R(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(P,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*
M;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4U"B,L(&9U>GIY"FUS9VED(")3;F]W(@IM<V=S='(@(LCL[^[P
M\B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V
M"B,L(&9U>GIY"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R("+([._N\/(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PHC
M+"!F=7IZ>0IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(LCL[^[P\B(*
M"B,@9G5Z>GD*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G
M<W1R("+*\.#RZN[E(.[A[N'YY>WHY3HB"@HC(&9U>GIY"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"B,L(&9U>GIY"FUS9VED
M(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R("+*\.#RZN[E(.[A[N'YY>WH
MY3HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@HC
M+"!F=7IZ>0IM<V=I9"`B4V]M86QI82(*;7-G<W1R("+*X.OE[>3@\/PB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ-0HC+"!F=7IZ>0IM<V=I9"`B4V]R
M="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(L3EZ?'RXNCE.B(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Q-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(T-PHC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,38V
M(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ.#D*(RP@9G5Z>GD*;7-G:60@
M(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(M#@X>[WZ.D@X.3PY?$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS
M9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#D*;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS
M*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Q(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3
M;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM
M<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("+>YNWNY2#O[NOS
M^.#PZ.4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B
M;W)D97(@:6X@8V5L;"(*;7-G<W1R("(B"@HC(",M(RTC+2,M(R`@<G5?4E4N
M<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC"B,@9G5Z>GD*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C@Q.0HC+"!F=7IZ>0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@
M(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC
M7&XB"B+1[O7PX.WH\OP@ZN#J7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4
M=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+1[O7PX.WH\OPB"@HC(",M(RTC
M+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC"B,@9G5Z>GD*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@P"B,L(&9U>GIY"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(B(*(B,M(RTC
M+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+1[O7P
MX.WH\OP@ZN#J7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!V,2XQ
M*2`@(RTC+2,M(RTC7&XB"B+1[O7PX.WH\OPB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C
M:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")3
M<&%I;B(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ,#`*(RP@9G5Z>GD*;7-G:60@(E-P86TB"FUS9W-T<B`BPNWH
M[.#MZ.4B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P
M96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(M'OY?;HX.O\[?OE(/'H
M[.+NZ_LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8R"B,L(&9U>GIY"FUS9VED(")3<&QI="!C96QL(@IM<V=S
M='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M
M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C
M+2,M(RTC+2-<;B(*(N3NX>#BZ/+\(/'R[NOAY?8B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"B,L(&9U>GIY
M"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC
M("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN(@HBY.[AX.+H
M\OP@\?+NZ^'E]B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S$*(RP@9G5Z>GD*;7-G:60@(E-P;&ET(')O=R(*
M;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@
M(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!V,2XQ
M*2`@(RTC+2,M(RTC7&XB"B+D[N'@XNCR_"#Q\N[KX>7V(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$T,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"B,L(&9U>GIY
M"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`BPO7NY"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HV-@HC+"!F=7IZ>0IM<V=I9"`B4W1A;F1A
M<F0B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(U.3`@;&EB+TAO<F1E+T9O<FTN<&AP.C(W.3@*(RP@9G5Z>GD*;7-G:60@
M(E-T87)T('EE87(B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU-S$*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E
M(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G<W1R("+1\N#R\_$B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@P-`HC+"!F=7IZ>0IM<V=I9"`B
M4W1O<F%G92!F;W)M870B"FUS9W-T<B`BPN#XX"#H[?3N\.S@]NC_(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S,*(RP@9G5Z>GD*;7-G:60@
M(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(M#@X>[WZ.D@X.3PY?$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q"FUS9VED
M(")3=')I:V5T:')O=6=H(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,C,W"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3@W-PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R
M;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@
M6T-34UTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
MP.3PY?'@\B#SXN7D[NSKY>WH_R`E<R#MY2#MX.GDY>TN(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B
M"FUS9W-T<B`BTN7LX"(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,S-B!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3
M=6)M:70B"FUS9W-T<B`BR/'JX/+\(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@
M7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL
M('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B
M(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R"B,L(&9U>GIY"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B
MR/'JX/+\(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-"!L:6(O2&]R9&4O
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U
M8V-E<W,B"FUS9W-T<B`BT_'OY?CM[B(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D
M960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@(L_@[^K@(%PB)7-<
M(B#A^^O@(//Q[^7X[>X@[^7PY>CLY>WNXN#MX"#B(%PB)7-<(BXB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@
M<WES=&5M+B(*;7-G<W1R("(B"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,@9G5Z
M>GDL('!H<"UF;W)M870*(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S='(@(L?@[.7R
MZN`@)R5S)R#S\>_E^.WN(/'N]?#@[>7MX"(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$P-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<
M;B(*(L_P[N'KY>S@(._PZ"#O\.[Q[.[R\.4@Y^#O\.[XY>WM[N/N(._H\?SL
MX"XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C
M97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E
M92!C:&%N9V5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E
M<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U
M<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(M'RX/#@_R#J[NWTZ./S\.#VZ/\@
M\>[U\.#MY>W@(.(@].#IZSH@)7,B"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,@
M9G5Z>GDL('!H<"UF;W)M870*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<
M(B5S7"(B"FUS9W-T<B`BQ^#LY?+JX"`G)7,G(//Q[^7X[>X@\>[U\.#MY>W@
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M('=R;W1E("5S(@IM<V=S='(@(LWNXN#_(.KN[?3HX_/PX/;H_R#Q[O7PX.WE
M[>`@XCH@)7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`T"B,L(&9U>GIY"FUS9VED(")3=61A;B(*;7-G<W1R("+"
M[>CLX.WHY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-38*(RP@9G5Z>GD*;7-G:60@(E-U;6UA<GDB"FUS9W-T
M<B`BP^O@XNW@_R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-0HC+"!F
M=7IZ>0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`BR.S_(._NZ_SG[N+@\N7K
M_R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`HC+"!F=7IZ>0IM<V=I
M9"`B4W5N(%-E="(*;7-G<W1R("+2Y>S@(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E-U;FYY(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#4*(RP@9G5Z
M>GD*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`BR.S_(._NZ_SG[N+@\N7K_R(*
M"B,@9G5Z>GD*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K
M+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R
M("+"\.7L_R#B[O'U[N3@+^?@ZN#RX"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,#0*(RP@9G5Z>GD*;7-G:60@(E-U;G)I<V4Z("(*;7-G
M<W1R("+([/\@[^[K_.?NXN#RY>O_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(P.`HC+"!F=7IZ>0IM<V=I9"`B4W5N<V5T(@IM<V=S='(@
M(M+E[.`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`W"B,L
M(&9U>GIY"FUS9VED(")3=6YS970Z("(*;7-G<W1R("+2Y>S@(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PHC+"!F=7IZ
M>0IM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`BS^[K[>[E(.[OZ/'@[>CE
M.B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#`*(RP@9G5Z>GD*
M;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`BR.SO[O#R(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(Q-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ>0IM
M<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`BR.S_(._NZ_SG[N+@\N7K_R(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<U"B,L(&9U>GIY"FUS9VED
M(")3=7)N86UE(@IM<V=S='(@(LCL_R#O[NO\Y^[BX/+EZ_\B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED
M(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(Q-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@*(RP@9G5Z
M>GD*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R("+*[NSOX.WH_R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(Q-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G
M:60@(E-W961E;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*(RP@
M9G5Z>GD*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`BS^[JX.?@
M\OP@\^3@Z^7M[?OE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-0IM
M<V=I9"`B4WEN8TU,(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]344PO2V5Y
M=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E
M<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T
M;W)M(&%N9"!7:6YD>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;7,B"FUS9W-T
M<B`B(@H*(R!F=7IZ>0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV-`HC+"!F=7IZ>0IM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS
M9W-T<B`BRO#@\NKNY2#NX>[A^>7MZ.4Z(@H*(SH@;&EB+TAO<F1E+T1A=&$O
M='-V+G!H<#HQ-C8*(RP@9G5Z>GD*;7-G:60@(E135B!F:6QE(@IM<V=S='(@
M(L?@X^[K[N+NZB(*"B,Z(&QI8B](;W)D92]522]486)L92YP:'`Z,3,T"B,L
M(&9U>GIY"FUS9VED(")486)L92(*;7-G<W1R("+'X./NZ^[B[NHB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S
M"B,L(&9U>GIY"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(LKK
MY?+N]^W@_R#PX.3H[O'B_^?\(@H*(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T
M86)L97-E="YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(E1A8FQE(%-E="(*;7-G
M<W1R("+'X./NZ^[B[NHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<R"B,L(&9U>GIY"FUS9VED(")486)L92!P
M<F]P97)T:65S(@IM<V=S='(@(LKKY?+N]^W@_R#PX.3H[O'B_^?\(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-"!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3$*(RP@9G5Z>GD*;7-G:60@(E1A:7=A;B(*;7-G<W1R("+"[>CL
MX.WHY2(*"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G
M:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0HC
M+"!F=7IZ>0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R("+$X/+@(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM
M<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU
M"B,L(&9U>GIY"FUS9VED(")487)G970Z(@IM<V=S='(@(M'N[N'YY>WHY2(*
M"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.38@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$X.0IM<V=I9"`B5&%S:W,B"FUS9W-T<B`BQ^#DX/?H(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S0*(RP@9G5Z>GD*;7-G
M:60@(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`BR.S_(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,@IM<V=I9"`B5&5M<&5R871U<F4Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C@R"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S
M2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+U1E;7!L871E+G!H<#HV.34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(L#D\.7QX/(@
M\^+EY.[LZ^7MZ/\@)7,@[>4@[>#IY.7M+B(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q-2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S,S-`HC+"!F=7IZ>0IM<V=I9"`B5&5X="(*;7-G<W1R("+$
MX.OEY2(*"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.0IM
M<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(M+NZ_SJ[B#RY>KQ\B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*
M(RP@9G5Z>GD*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`BT>OEY//^^>7_
M(/'R\.#MZ/;@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW,0HC+"!F=7IZ>0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R("+$
MX.OEY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DP"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y
M"B,L(&9U>GIY"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R("+"[>CLX.WHY2(*
M"B,Z(&QI8B]61E,O9G1P+G!H<#HX-3$*(RP@9G5Z>GD*;7-G:60@(E1H92!&
M5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(LWE\B#D
M[O'R\^_M^_4@[>#Q\O#NY>HN(@H*(SH@;&EB+TAO<F1E+TAI<W1O<GDN<&AP
M.C4U"FUS9VED(")4:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L960N(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3,S"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I
M;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@;&EB
M+TYE="])35-0+T)O;VLN<&AP.C$R.3@*(RP@9G5Z>GD*;7-G:60@(E1H92!)
M35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(L_N
MY._H\?P@[>4@[.[FY?(@X?OR_"#GX.SE[>7MX"XB"@HC.B!S97)V:6-E<R]M
M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L
M87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE
M($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,3@Y(&QI8B](;W)D92]097)M
M<RYP:'`Z,C`P(&QI8B](;W)D92]097)M<RYP:'`Z,C$Q"B,Z(&QI8B](;W)D
M92]097)M<RYP:'`Z,C(S(&QI8B](;W)D92]097)M<RYP:'`Z,C,T(&QI8B](
M;W)D92]097)M<RYP:'`Z,C4R"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,C8T
M(&QI8B](;W)D92]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI
M<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES
M<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO
M;G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O
M;FQY(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@
M;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN
M('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$W,@IM<V=I
M9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I
M9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T
M('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE
M(&1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@
M=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#
M<GEP="YP:'`Z,3$V"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R
M97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4N<&AP.C$W-R!L:6(O2&]R9&4N<&AP.C4Q.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S
M('-E='1I;F<N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92YP:'`Z,3<P(&QI
M8B](;W)D92YP:'`Z-3`Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE
M("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C(V"FUS9VED(")4:&4@9FEL92!C
M86YN;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN
M960@;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H
M92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN
M;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L
M(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@
M=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A
M9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R
M86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@
M5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A
M("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E
M8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P
M<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R
M965N(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP
M.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB
M(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H
M92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F
M('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?
M<&=P.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+TU$
M3BYP:'`Z,C`R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E
M('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E
M;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H
M92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X.#$*;7-G:60@(E1H92!N
M86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*
M;7-G<W1R("(B"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0W-`HC+"!F=7IZ>0IM
M<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*
M;7-G<W1R("+=\NX@Y^W@]^7MZ.4@Y.[KYNWN(.'[\OP@]^CQZ^[L+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(S,@IM<V=I9"`B5&AE(&]P
M96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?
M<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S
M+G!H<#HR.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N
M8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A
M(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]D96(N<&AP.C,R(&QI
M8B](;W)D92]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W)P;2YP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W=E
M8F-P<"YP:'`Z,S<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W-R8VAI9VAL
M:71E+G!H<#HS-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O;7-E>&-E;"YP
M:'`Z,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E
M9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O
M;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!L:6(O1FEL92]#4U8N<&AP
M.C0X-PIM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S
M:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@
M<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS
M9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T9I;&4O0U-6+G!H<#HT-SD*;7-G:60@(E1H92!S97!A<F%T;W(@;75S
M="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T
M<B`BT>7PXN7P("5S(.'[ZR#SY.#KY>TB"@HC.B!S97)V:6-E<R]P;W)T86PO
M<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R
M(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`BT>7PXN7P("5S(.'[
MZR#Q[N?DX.TB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R
M96UO=F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C0W,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="XB"FUS9W-T
M<B`BP.3PY?'@\B#SXN7D[NSKY>WH_R`E<R#MY2#MX.GDY>TN(@H*(SH@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,S,P"B,L(&9U>GIY"FUS9VED(")4
M:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`BP.3P
MY?'@\B#SXN7D[NSKY>WH_R`E<R#MY2#MX.GDY>TN(@H*(SH@;&EB+U9&4R]S
M<6PN<&AP.C$W.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E
M;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B
MP.3PY?'@\B#SXN7D[NSKY>WH_R`E<R#MY2#MX.GDY>TN(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,S,#D*;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D
M(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C,R-PIM<V=I9"`B
M5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S
M('-T97`N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]$871A+V-S=BYP:'`Z
M,C8R(&QI8B](;W)D92]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L
M;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT.2!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3$P"B,L(&9U>GIY"FUS9VED(")4:&4@=V5A=&AE
M<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`BS>7R(.3N
M\?+S[^W[]2#MX/'R\.[EZBXB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M,C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O
M<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BP.3PY?'@\B#SXN7D[NSK
MY>WH_R`E<R#MY2#MX.GDY>TN(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O4')E
M9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A
M:6QA8FQE+B(*;7-G<W1R("+-Y?(@Y.[Q\O/O[?OU(.W@\?+P[N7J+B(*"B,@
M9G5Z>GD*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C,T.0IM<V=I
M9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I
M;FQI;F4N(@IM<V=S='(@(M'N[N'YY>WHY2#B(.WEXN7P[>[L(/3N\.S@\N4@
MZ"#MY2#L[N;E\B#A^_+\(.[R[N'PX.;E[>XB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,30P-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@
M=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E
M;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@
M=&AA;B`E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U
M<V5R+G!H<#HW,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S
M(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I
M("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ
M*2`@(RTC+2,M(RTC7&XB"B+/\.[AZ^7LX"#O\.@@[_#N\>SN\O#E(.?@[_#N
M^.7M[>[C[B#OZ/'\[.`N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L
M96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@
M(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I
M("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ
M*2`@(RTC+2,M(RTC7&XB"B+/\.[AZ^7LX"#O\.@@[_#N\>SN\O#E(.?@[_#N
M^.7M[>[C[B#OZ/'\[.`N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E
M;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(B"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN
M(@HBS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@[^CQ_.S@
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z
M("5S(@IM<V=S='(@(L_PZ"#SY.#KY>WHZ"#GX.3@]^@@XN[G[>CJZ^@@[OCH
MX>KH+B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3$U"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E
M9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]"
M<F]W<V5R+G!H<#HY,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A
M<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM
M<V=S='(@(L[XZ.'JX"#O\.@@[O+NX?#@YN7MZ.@@_?+NZ2#WX/'RZ"#Q[N[A
M^>7MZ/\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*(RP@9G5Z>GD*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A
M8W0@9&%T82XB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R
M9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN(@HBSOCHX>K@(._PZ"#H[._N\/+E
M(.3@[>W[]2XB"@HC.B!L:6(O2&]R9&4O1&%T82]I;6,N<&AP.C,Q"B,L(&9U
M>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I
M0V%L96YD87(@9&%T82XB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP
M;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN(@HBSOCHX>K@(._PZ"#H
M[._N\/+E(.3@[>W[]2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@R
M"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R
M871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E
M9"!F:65L9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S.`HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@
M9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@
M(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC
M+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C+2,M
M(RTC+2-<;B(*(L[XZ.'JX"#O\.@@Z.SO[O#RY2#DX.WM^_4N(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`HC+"!F=7IZ>0IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T
M(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<
M;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C+2,M(RTC
M+2-<;B(*(L[XZ.'JX"#O\.@@Z.SO[O#RY2#DX.WM^_4N(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-2!L:6(O3F5T+U--4R]W:6Y?
M:'1T<"YP:'`Z,C(R"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@
M=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5
M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A4=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+.^.CAZN`@[_#H
M(.CL[^[P\N4@Y.#M[?OU+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ-#@*(RP@9G5Z>GD*;7-G:60@(E1H:7,@24U!4"!S97)V97(@
M9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(L+@
M^"#A\.[SY^7P(.WE(._NY.3E\.;HXN#E\B#N[_;H_B#OY??@\N@N(,3K_R#O
MY??@\N@@[>#F[.CRY2!#5%),*U`N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(E1H:7,@9&]E<R!N;W0@
M87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(MWR
M[B#G[>#WY>WHY2#D[NOF[>X@X?OR_"#WZ/'K[NPN(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*(RP@9G5Z>GD*;7-G:60@(E1H:7,@
M9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S
M='(@(MWR[B#G[>#WY>WHY2#D[NOF[>X@X?OR_"#WZ/'K[NPN(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,Q,S0*(RP@9G5Z>GD*;7-G:60@(E1H:7,@9&]E
M<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R
M("+=\NX@Y^W@]^7MZ.4@Y.[KYNWN(.'[\OP@]^CQZ^[L+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H
M92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W
M87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!L:6(O3F5T
M+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT
M='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$DB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB
M<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY
M("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q
M=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY
M("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HY.#(@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-C$@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$P.3`*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,3D@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Q.#8@;&EB+TAO<F1E+T9O<FTN<&AP.C$R
M-C`*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,#D@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$T,#(@;&EB+TAO<F1E+T9O<FTN<&AP.C$U-C$*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$X-#,@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-C(@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(P,#D*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,S,@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(P.#(@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q
M-3,*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R,C4@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(T,3(@;&EB+TAO<F1E+T9O<FTN<&AP.C(T-30*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(V-#0@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,3<@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,Q,C8*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,#0@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,X,3(@;&EB+TAO<F1E+T9O<FTN<&AP.C,X
M,C`*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#8Y"FUS9VED(")4:&ES(&9I96QD
M(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR-#(P"FUS9VED(")4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`Y.`IM<V=I9"`B5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,C<*;7-G:60@(E1H:7,@9FEE;&0@
M;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN
M=&5G97)S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY.3,*
M(RP@9G5Z>GD*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU
M;6)E<BXB"FUS9W-T<B`BW?+N(.?MX/?E[>CE(.3NZ^;M[B#A^_+\(/?H\>ON
M["XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@R-0IM<V=I9"`B(@HB5&AI
M<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@
M2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z-38U"FUS9VED(")4:&ES(&9O
M<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA
M8BYP:'`Z-#4Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+
M;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO
M=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N
M9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@
M<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z-3DX"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A
M(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B
M5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(MWR
M[B#WZ/'K[B#MY2#L[N;E\B#A^_+\(.SE[?SXY2#EY.CMZ/;[+B(*"B,Z(&QI
M8B](;W)D92]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V
M97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4
M:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3(T"FUS9VED(")4:&ES
M('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(MWR[B#G[>#WY>WH
MY2#D[NOF[>X@X?OR_"#WZ/'K[NPN(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O
M;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C
M86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B
M5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C,V"FUS9VED(")4:6-K971S(@IM<V=S='(@(L?@[_#N\?LB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C0R.2!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(E1I;64B"FUS9W-T<B`BQ^#C[NON
MXN[J(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X.`IM<V=I9"`B
M5&EM92!4<F%C:VEN9R(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B]";&]C
M:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`BU.[P
M[.#R(.[R[N'PX.;E[>C_(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C4S-0HC+"!F=7IZ>0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T
M<B`BS^[K[>[E(.[OZ/'@[>CE(._P[N'KY>S[.B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R
M,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R
M+4QE<W1E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS9VED(")4
M:71L92(*;7-G<W1R("+'X./NZ^[B[NHB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I
M<"DZ(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R("+*[NSS(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U,@IM<V=I9"`B(@HB5&\@
M<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@
M*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB
M"FUS9W-T<B`BU_+NX?L@XOOA\.#R_"#MY?'J[NO\ZNX@_>OE[.7M\N[B+"#S
MY.7PYNCBX.GRY2#MX.;@\N[I(.KKX.+HYO,@0W1R;"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`*(RP@9G5Z>GD*;7-G:60@(E1O9&%Y
M(@IM<V=S='(@(LKN[/,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P.0HC+"!F=7IZ>0IM<V=I9"`B5&]G;R(*;7-G<W1R("+*[NSS
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S`R"B,L(&9U>GIY"FUS9VED(")4;VUO<G)O
M=R(*;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C(Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"B,L(&9U>GIY"FUS9VED(")4;VYG
M82(*;7-G<W1R("+*[NSS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<W"B,L(&9U>GIY"FUS9VED(")4;W`B"FUS
M9W-T<B`BRN[L\R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<Y-`IM<V=I9"`B5')U92!O<B!F86QS
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C(X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4
M=6YI<VEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B5'5R:VES:"`H
M25-/+3@X-3DM.2DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(R-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`HC+"!F=7IZ>0IM<V=I9"`B5'5R
M:VUE;FES=&%N(@IM<V=S='(@(L_QY>+D[NWH["(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS
M(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C,S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A
M;'4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z,C8T"FUS9VED
M(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(U.`IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T
M<B`B55),(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T
M,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@
M<F5P;W)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3<*(RP@9G5Z>GD*;7-G:60@(E523#HB"FUS9W-T
M<B`B55),(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B56=A;F1A(@IM<V=S='(@(LK@
MZ^7MY.#P_"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B
MR.S_(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HT,3D*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BS>7B
M[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O
M2&]R9&4O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D
M(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G
M<W1R("(B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,SDS"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R
M(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH
M\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,Y
M,B!L:6(O5D93+VUU<W%L+G!H<#HT-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I
M;&4@)7,O)7,N(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!3
M44P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<X-@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB
M"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N
M["XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C,W"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<
M(BXB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#B
MY?#N["XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C8Y-2!L:6(O5D93+W-Q;"YP
M:'`Z,3`R."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HX-3`*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@
M7"(E<R\E<UPB+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@
M4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B](;W)D92]!=71H+W-Q;"YP:'`Z-#,Y
M"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G
M<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*
M"B,Z(&QI8B]61E,O9G1P+G!H<#HX-S`*(RP@9G5Z>GD*;7-G:60@(E5N86)L
M92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'N
MY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,O9FEL92YP
M:'`Z,C,R(&QI8B]61E,O9FEL92YP:'`Z,C,W(&QI8B]61E,O<W%L7V9I;&4N
M<&AP.C(P-`HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,#D@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z,C$W"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8V]P
M>2!61E,@9FEL92XB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q
M(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S<P"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D
M:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR
M_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S8Q
M(&QI8B]61E,O;75S<6PN<&AP.C(U."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR
M-C0*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#Q
MY?#BY?#N["XB"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HQ,C0*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(LWE
MXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB
M+U9&4R]S;6(N<&AP.C(Y,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B
MS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L
M:6(O5D93+V9I;&4N<&AP.C(W,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q
M[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O2&]R9&4O0V]M
M<')E<W,O=&%R+G!H<#HW-B!L:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z
M-SD*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N
M(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P
M[NPN(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C(R."!L:6(O5D93+V9T<"YP:'`Z
M,S`S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S
M='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C0T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC
M+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@=C(N,2D@
M(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N
M,"XS*2`@(RTC+2,M(RTC7&XB"B+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@
M4U%,(/'E\.+E\.[L+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@
M=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_
M(/$@4U%,(/'E\.+E\.[L+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R
M9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B+-Y>+NY^SNYNWN(/'NY>3H[>CR
M_/'_(/$@4U%,(/'E\.+E\.[L+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M2&]R9&4@=C,N,"XS*2`@(RTC+2,M(RTC7&XB"B+-Y>+NY^SNYNWN(/'NY>3H
M[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z
M,S,X(&QI8B]61E,O<W%L+G!H<#HS.34@;&EB+U9&4R]M=7-Q;"YP:'`Z,S$Q
M"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,T,@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R
M>2!I<R!N;W0@96UP='DB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ
M_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS
M-38@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S8P"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM
M<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN
M(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS-#0@;&EB+U9&4R]M=7-Q;"YP:'`Z
M,S(R(&QI8B]61E,O;75S<6PN<&AP.C,S-0HC.B!L:6(O5D93+VUU<W%L+G!H
M<#HS-#,@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(LWE
MXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB
M+U9&4R]S<6PN<&AP.C0R,"!L:6(O5D93+W-Q;"YP:'`Z-#,R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E
M8W1O<GDZ("5S+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@
M4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR,3(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@
M4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S$P(&QI8B]6
M1E,O<W%L+G!H<#HR.3$@;&EB+U9&4R]M=7-Q;"YP:'`Z,38W"B,Z(&QI8B]6
M1E,O;75S<6PN<&AP.C$X,"!L:6(O5D93+VUU<W%L+G!H<#HQ.#<@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,SDQ"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,Y
M.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB
M"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N
M["XB"@HC.B!L:6(O5D93+W-M8BYP:'`Z,C0X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB
M+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E
M\.[L+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HT,#D*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY
M.B`E<RXB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#Q
MY?#BY?#N["XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#,T"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*
M;7-G<W1R("+-Y>+NY^SNYNWN(/'N]?#@[>CR_"#S\?+@[>[BZN@@XB#QY?'Q
MZ.@N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,#0*;7-G:60@
M(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T
M<B`B(@H*(SH@;&EB+TYE="])35-0+G!H<#HT,S<@;&EB+TYE="])35-0+T%U
M=&@N<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A
M9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`BS>7B[N?L[N;M[B#G
MX./P\^?H\OP@[N_PY>3EZ^7MZ.4@)7,N(@H*(SH@;&EB+U9&4R]F:6QE+G!H
M<#HR,#,@;&EB+U9&4R]F:6QE+G!H<#HR,#@@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z,3<T"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$W.0HC+"!F=7IZ>0IM
M<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(LWEXN[G
M[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&
M4R]S;6(N<&AP.CDS(&QI8B]61E,O<VUB+G!H<#HQ,#8@;&EB+U9&4R]S;6(N
M<&AP.C8U,@HC.B!L:6(O5D93+V9T<"YP:'`Z.3@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N
M["XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(X-"!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HQ,S@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,30Q"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS
M9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB
M"@HC.B!L:6(O5D93+V9I;&4N<&AP.C@S(&QI8B]61E,O9FEL92YP:'`Z,3,W
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<V"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7D
MZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&=Z+G!H<#HT-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&]P
M96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'N
MY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,N<&AP.C@U
M-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I
M;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH
M\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+G!H<#HX.#<*(RP@
M9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE
M4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\
M\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD
M;&5R+VYO;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5A
M9"!F:6QE.B`B"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-1
M3"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C8W-@HC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y
M+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E
M\.[L+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3$P-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA
M=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(LWEXN[G[.[F[>X@
M\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]S<6PN
M<&AP.C,S,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`BS>7B[N?L[N;M
M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+W-M
M8BYP:'`Z,C<Q(&QI8B]61E,O9G1P+G!H<#HS-#@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E
M\.[L+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-C$W(&QI8B]61E,O;75S<6PN
M<&AP.C(R.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q
M[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+W-Q;"YP
M:'`Z,S(V(&QI8B]61E,O;75S<6PN<&AP.C(Q,R!L:6(O5D93+VUU<W%L+G!H
M<#HT-3(*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,CDS(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C,P.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92XB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q
M(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+TE33U=R:71E<B]M:VES;V9S
M+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F
M<R<N(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7P
MXN7P[NPN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z
M-3D*;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M
M96YT(@IM<V=S='(@(MWR[O(@Y.[J\^SE[?(@5V]R9"#MY2#L[N;E\B#A^_+\
M(._E\.7BY>3E[2XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,34T(&QI8B]61E,O
M9G1P+G!H<#HQ-3<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(LWEXN[G[.[F
M[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HQ.#8*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(LWEXN[G[.[F[>X@
M\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]F:6QE
M+G!H<#HR.#@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,30V(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C$U,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\
M\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4RYP:'`Z.#8R"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I
M;&P@8F4@97AC965D960N(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\
M\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,`HC+"!F=7IZ>0IM<V=I9"`B56YD97)L:6YE
M(@IM<V=S='(@(L?@X^[K[N+NZB(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N
M:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R("+.\NSE[>CR_"#H
MY^SE[>7MZ/\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,S"B,L(&9U>GIY"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C
M=&EO;B(*;7-G<W1R("+3Y.#KZ/+\(._@\/,B"@HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,C(S(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS.3`*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S
M97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,T,0HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S<X(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*
M;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*
M;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(L_S\?+N
MZ2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(")5;FEC;V1E
M("A55$8M."DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A
M=&5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$S"FUS
M9VED(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8R"FUS
M9VED(")5;FET<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HT,CD@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#,P"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C4X"FUS9VED(")5;FMN;W=N(@IM
M<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN
M(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G
M92!)1"DN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-#<*(RP@9G5Z>GD*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O
M=FED960N(@IM<V=S='(@(LW@\?+P[NGJZ"(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"B,L(&9U>GIY"FUS9VED(")5;FMN;W=N
M('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R("+/[N;@Z_/I\?+@+"#B
MXN7DZ/+E(,+@^.@@Z.S_(._NZ_SG[N+@\N7K_R#H(._@\.[K_"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M.`HC+"!F=7IZ>0IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B
M"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@
M(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N
M,2D@(",M(RTC+2,M(UQN(@HB\^'PX/+\(/'R[NOAY?8B"@HC.B!L:6(O2&]R
M9&4O261E;G1I='DN<&AP.C,P,@HC+"!F=7IZ>0IM<V=I9"`B56YN86UE9"(*
M;7-G<W1R("+([/\@[^[K_.?NXN#RY>O_(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE
M9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G
M<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/
M2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC
M:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S
M<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"B,L(&9U>GIY"FUS
M9VED(")5;G-E="!C;VQO<B(*;7-G<W1R("+(\>_NZ_SG[N+@\OP@Y^W@]^7M
MZ.4@[^X@\^SNZ_?@[>C^(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HV.#<@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HY,C<*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HY,S,*;7-G:60@(E5N<W5P<&]R=&5D($5X
M=&5N<VEO;B(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S
M"FUS9VED(")5<&1A=&4B"FUS9W-T<B`BS_#H[.7MZ/+\(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(M'N]?#@[>CR_"#MX/'R
M\.[IZN@B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V
M"B,L(&9U>GIY"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R("+$[N'@XNCR
M_"#OX/#S(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O
M961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*;7-G
M<W1R("+1[O7PX.WH\OP@[>#Q\O#NZ>KH(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.`HC+"!F=7IZ>0IM<V=I
M9"`B57!L;V%D(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M
M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T
M+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O
M("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B+/\.[WZ/+@[>W[Y5QN
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XV*2`@(RTC+2,M
M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C8I("`C
M+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N
M-BD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@
M=C,N,"XV*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(
M;W)D92!V,RXP+C8I("`C+2,M(RTC+2-<;B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S
M971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P
M"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,3@*(RP@9G5Z>GD*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T
M<B`BR.S_(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q,PHC+"!F=7IZ>0IM<V=I9"`B57)U9W5A>2(*;7-G<W1R("))
M35`B"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT
M-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S
M(@IM<V=S='(@(M+EZO/YY>4@XO#E[/\B"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C<*;7-G:60@(E5S92!I9B!N
M86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM
M<V=S='(@(B(*(LCQ[^[K_.?SY?+Q_R#E\>OH(.+@^.@@Z.S_+^_@\.[K_"#D
MZ_\@24U34"#QY?#BY?#@(.[RZ^CWX/[R\?\@[O(@\N7J\_GH]2(*"B,@9G5Z
M>GD*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0IM<V=I
M9"`B57-E<B(*;7-G<W1R("+/[NO\Y^[BX/+EZ_PB"@HC.B!L:6(O2&]R9&4O
M4F5G:7-T<GDN<&AP.C<W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S
M(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,C0U"FUS9VED
M(")5<V5R($]P=&EO;G,B"FUS9W-T<B`BS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K
M_R(*"B,Z('-I9VYU<"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(E5S97(@4F5G
M:7-T<F%T:6]N(@IM<V=S='(@(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_\B"@HC
M.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@
M8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8Y"B,L(&9U>GIY"FUS9VED(")5<V5R
M(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(L[R[.7MZ/+\(.CG[.7MY>WH
M_R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-SD*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-B!L
M:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX(&QI8B].970O4TU3+W=I
M;E]H='1P+G!H<#HQ-3`*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,S,@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS
M9W-T<B`BR.S_(._NZ_SG[N+@\N7K_R(*"B,Z(&QI8B](;W)D92]!=71H+U-I
M9VYU<"YP:'`Z,3(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R
M;F%M92!<(B5S7"(@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(L_@[^K@(%PB
M)7-<(B#SYN4@\?/YY?'RXO/E\B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B
MR.S_(._NZ_SG[N+@\N7K_R(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+VQO9VEN
M+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R("+([/\@
M[^[K_.?NXN#RY>O_(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI
M;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M-`HC+"!F=7IZ>0IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R("+$X/+@(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HQ-S`@;&EB+U9&4R]F:6QE+G!H<#HR-C(*
M(RP@9G5Z>GD*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N
M(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[LZ^7MZ/\@)7,@[>4@[>#IY.7M+B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,C`*(RP@9G5Z>GD*;7-G
M:60@(E9A8V%T:6]N(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@
M*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N
M<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+$Y>GQ\N+HY2(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HX-S`*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F
M;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV,SD*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN(&UI
M;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HX-C`@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q.#$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@
M)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C0X(&QI
M8B](;W)D92]&;W)M+G!H<#HR,C<P(&QI8B](;W)D92]&;W)M+G!H<#HR,S(P
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.3$W(&QI8B](;W)D92]&;W)M+U1Y
M<&4O=&%B;&5S970N<&AP.C4Y"B,L(&9U>GIY"FUS9VED(")686QU97,B"FUS
M9W-T<B`BQ^#LY?+JZ"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3$S(&QI
M8B](;W)D92]&;W)M+G!H<#HR,3DP"FUS9VED(")686QU97,@=&\@<V5L96-T
M(&9R;VTB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T
M.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,S"B,L(&9U>GIY
M"FUS9VED(")687)I86)L92(*;7-G<W1R("+'X./NZ^[B[NHB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C0U(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR-#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED
M(")696YE>G5E;&$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES
M(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,0HC+"!F=7IZ
M>0IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR,C@*(RP@9G5Z>GD*;7-G:60@(E9E<G-I
M;VX@0V]N=')O;"(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*(RP@9G5Z>GD*
M;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(M'KY>3S_OGE_R#Q\O#@
M[>CVX"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.#0*(RP@9G5Z>GD*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T
M<B`BT>OEY//^^>7_(/'R\.#MZ/;@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PHC+"!F=7IZ>0IM<V=I9"`B5F5R=&EC
M86PZ(@IM<V=S='(@(M'KY>3S_OGE_R#Q\O#@[>CVX"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"B,L(&9U>GIY"FUS9VED
M(")697)Y($AI9V@B"FUS9W-T<B`BS>CJ[N/DX"(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T
M,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38*(RP@9G5Z>GD*;7-G
M:60@(E9I970@3F%M(@IM<V=S='(@(LCL_R(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DS"FUS9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HY-CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R("+/\.[Q[.[R\"`E<R(*
M"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT
M97)N86P@=V5B('!A9V4B"FUS9W-T<B`BS^[JX.?@\OP@XN7A+?'R\.#MZ/;S
M(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@R.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R("+/\.[Q
M[.[R\"`E<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3(*;7-G
M:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L
M>2!V:6$@4TU44"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9
M($923TT@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W=I;E]H='1P
M+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR-#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS
M9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R,2!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`BPNWH[.#MZ.4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X
M"FUS9VED(")792(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q-@IM<V=I9"`B
M5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HX.38*;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS
M9W-T<B`BPN7A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S.0IM
M<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TUA:6YT
M96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(L7FY>WEY.7K
M_.WN(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*(RP@9G5Z
M>GD*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`BQ.[A\.X@[^[FX.ONXN#R_"P@
M)7,B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L
M8V]M92!T;R`E<R(*;7-G<W1R("+$[N'P[B#O[N;@Z^[BX/+\(.(@)7,B"@HC
M.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R
M=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@
M)7,B"FUS9W-T<B`BQ.[A\.X@[^[FX.ONXN#R_"P@)7,B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@
M(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(T-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S
M=&5R;B!386AA<F$B"FUS9W-T<B`B(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC
M(&9U>GIY+"!P:'`M9F]R;6%T"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0T,0IM<V=I9"`B5VAA="!A<'!L:6-A=&EO
M;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`BU_+N
M(.[R[N'PX.;@\OP@[^[QZ^4@XO7NY.`@XB#QZ/'RY>SS.B(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H92!D
M96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@
M8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`V,@IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@
M;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I
M9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(M3@Y^`B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3,V"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L
M92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(LK@ZNCE(.[O
M]NCH(.'SY//R(.3N\?+S[^W[(.(@XNCG\^#K_.WN["#PY>3@ZO+N\.4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@T"B,L(&9U>GIY"FUS9VED(")7:61T:"(*;7-G<W1R("+"[>CLX.WHY2(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3$T"FUS9VED(")7:61T:"!I;B!#
M4U,@=6YI=',B"FUS9W-T<B`B(@H*(R!P:'`M9F]R;6%T"B,@9G5Z>GDL('!H
M<"UF;W)M870*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F
M="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`BV.CP
MZ.W@(.SE[?X@)7,@\>OEXN`@*.'SY.7R(._PZ.SE[>7MX"#O\.@@\>OEY//^
M^>7L(.+U[N3E*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,3`*(RP@9G5Z>GD*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`BPNWH
M[.#MZ.4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P-0HC+"!F=7IZ>0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(L+MZ.S@
M[>CE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q-0IM<V=I9"`B
M5VEK:2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C@Y(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V
M"B,L(&9U>GIY"FUS9VED(")7:6YD(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*(RP@9G5Z
M>GD*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"B,L(&9U>GIY"FUS9VED
M(")7:6YD.B`B"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3DX"FUS9VED(")7:7-H;&ES="(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-"!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM<V=I9"`B5V]R:R!!9&1R
M97-S(@IM<V=S='(@(M#@X>[WZ.D@X.3PY?$B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G
M<W1R("+0X.'N]^CI(/+EZ^7T[NTB"@HC.B!L:6(O1FEL92]#4U8N<&AP.C$Y
M,R!L:6(O1FEL92]#4U8N<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D
M+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HS
M,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD
M<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!L:6(O
M5D93+V9I;&4N<&AP.C$R,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS
M9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C0U"FUS9VED(")8+5)E
M9B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y
M-`IM<V=I9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y
M=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!
M;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3DV"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E
M;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C8X,PIM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(L/#
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4T"B,L(&9U>GIY
M"FUS9VED(")965E9(@IM<V=S='(@(L/#(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,#D*;7-G:60@(EEA:&]O(2!M87`B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I
M9"`B665A<FQY(@IM<V=S='(@(L7FY>/NY.WN(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(U,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B665M96XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDV-`IM<V=I9"`B665S(@IM<V=S='(@(L3@(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+V%G<F5E;65N=%]B;W1T;VTN:6YC.C8*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE
M<RP@22!!9W)E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@
M34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@
M5UE325=91RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HR,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R
M92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-#$U"FUS9VED(")9;W4@
M87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O261E;G1I='DN<&AP.C,P.`IM<V=I9"`B66]U(&-A;FYO="!H879E('1H
M92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-3D@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Y-SD*(RP@9G5Z>GD*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@
M=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`BPN#X($5M86EL.B(*"B,Z
M(&QI8B](;W)D92]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E
M9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB
M"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3@W
M"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(L+[
M(.+[^.OH(.CG(/'H\?+E[/LN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R
M-C4*;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H
M;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@
M(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$Y,@HC+"!F=7IZ>0IM
M<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T
M<B`BPN#X($5M86EL.B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z
M,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME
M;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92YP
M:'`Z-#8R"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E
M9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R
M("(B"B+"^R#D[NOF[?L@[N_H\>#R_"#O\.[AZ^7L^RP@[_#EYN3E(/?E["#Q
M[.[FY?+E(.[R[O'KX/+\(/'N[N'YY>WHY2#N(.WEZ2XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@
M;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*
M;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E
M9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9
M;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@861D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,X
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O
M<FTN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C<Q"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G
M;W)Y(&YA;64N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE
M:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@
M86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T%U=&@N<&AP.CDW-0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S
M('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS
M9W-T<B`BPN#XX"`E<R#QY?'QZ/\@Y^#J[NWWZ.O@\?PN(,_NYN#K\^GQ\N`L
M(.+NZ>3H\N4@XB#QZ/'RY>SS(.?@[>[B[BXB"@HC(&9U>GIY"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9;W5R($5M86EL
M($%D9')E<W,B"FUS9W-T<B`BPN#X($5M86EL.B(*"B,@9G5Z>GD*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(Q-0IM<V=I9"`B66]U<B!&<F]M.B!A9&1R
M97-S.B(*;7-G<W1R("+"X/@@X.3PY?$@[O+O\.#BZ/+EZ_\Z(@H*(R!F=7IZ
M>0HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-R!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@U"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,@IM<V=I9"`B66]U<B!);F9O<FUA
M=&EO;B(*;7-G<W1R("+"X/C@(.CM].[P[.#VZ/\B"@HC.B!L:6(O2&]R9&4O
M075T:"YP:'`Z.3<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT
M97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG
M(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R
M:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(R!F=7IZ
M>0HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B
M66]U<B!.86UE(@IM<V=S='(@(L+@^.4@Z.S_.B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VYO861D+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N
M($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S
M97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H
M96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N
M=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E
M<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S
M;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U
M=&@N<&AP.CDX,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S
M97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN
M9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U
M<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]I9G)A;64N<&AP.C4U"B,L(&9U>GIY"FUS9VED(")9;W5R(&)R
M;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S='(@
M(L+@^"#A\.[SY^7P(.WE(._NY.3E\.;HXN#E\B#N[_;H_B#OY??@\N@N(,3K
M_R#OY??@\N@@[>#F[.CRY2!#5%),*U`N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O<')I;G0N:G,Z-#(*(RP@9G5Z>GD*;7-G:60@(B(*(EEO=7(@8G)O
M=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S
M<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("+"
MX/@@X?#N\^?E\"#MY2#O[N3DY?#FZ.+@Y?(@[N_VZ/X@[^7WX/+H+B#$Z_\@
M[^7WX/+H(.W@YNSH\N4@0U123"M0+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR-C$*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S
M='(@(M?@\>[B[ND@[^[_\2(*"B,@9G5Z>GD*(SH@<V5R=FEC97,O<')E9G,N
M<&AP.C$Q,0HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y
M(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@(L+@^"#O\.[TZ.O\(._N(//L
M[NOWX.WH_CHB"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-C$*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`BPN#X
M(._P[O3HZ_P@[^X@\^SNZ_?@[>C^.B(*"B,@9G5Z>GD*(R!F=7IZ>0HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`T"FUS9VED(")9;W5R(&9U;&P@;F%M
M93HB"FUS9W-T<B`BPN#XY2#H[/\Z(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP
M.CDY.0HC+"!F=7IZ>0IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB
M"FUS9W-T<B`BPN#XZ"#MX/'R\.[IZN@@X?OKZ"#NX>WNXNOE[?LN(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$U-`HC+"!F=7IZ>0IM
M<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@
M9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R("+"X/CH(.W@\?+P
M[NGJZ"#A^^OH(.[A[>[BZ^7M^RXB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN
M<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D
M+B(*;7-G<W1R("+"X/CH(.W@\?+P[NGJZ"#A^^OH(.[A[>[BZ^7M^RXB"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P
M87-S=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R
M9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN
M('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]!=71H+G!H<#HW,S,*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S
M(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T
M<B`BT?+N\.[M[>CI(/'E\.+E\#HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C4T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G
M;W-L879I82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3@*(RP@9G5Z>GD*;7-G:60@(EIA:7)E(@IM<V=S='(@(DAO<F1E(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H:6=H;&EG
M:'1Q=6]T97,N<&AP.C$W-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T
M94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C@Y"FUS9VED(");4')O
M8FQE;2!297!O<G1=(@IM<V=S='(@(EO1[N[A^>7MZ.4@[B#O\.[AZ^7LY5TB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM
M<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O5&5X="]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE
M<UTB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+G!H<#HQ.34*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(EOQ\O#NZN`@
M)7,@Z.<@)7-=(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4N<&AP.C$U-#4@=&5M
M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(M/O\.#BZ^7MZ.4B"@HC.B!L:6(O87!I+G!H<#HQ-3<*
M;7-G:60@(E]#3$DB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"B,L
M(&9U>GIY"FUS9VED(")?1&%T851R964B"FUS9W-T<B`BQ.#RX"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M,0HC+"!F=7IZ>0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T<B`BT^3@Z^CR
M_"(*"B,@9G5Z>GD*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS9VED(")?1W)O=7!S
M(@IM<V=S='(@(L/P\^_O^R(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+TUE;G4N
M<&AP.C$W-0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`BS^[L[OG\(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S
M"B,L(&9U>GIY"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R
M("+*Z^7R[O?MX/\@\.#DZ.[QXO_G_"(*"B,Z(&QI8B](;W)D92]-96YU+G!H
M<#HQ.30*(RP@9G5Z>GD*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`BPO7NY"(*
M"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO
M9R!O=70B"FUS9W-T<B`BPOOU[N0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*(RP@9G5Z>GD*;7-G:60@
M(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R("+3Y.#KZ/+\(._@\/,B"@HC(&9U
M>GIY"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS
M(@IM<V=S='(@(LW@\?+P[NGJZ"(*"B,@9G5Z>GD*(SH@;&EB+V%P:2YP:'`Z
M,3,W"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`BS_#@XN`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C8*(RP@9G5Z>GD*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R("+3
MY.#KZ/+\(._@\/,B"@HC(&9U>GIY"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I
M9"`B7U-E='5P(@IM<V=S='(@(L_PZ.ONYN7MZ/\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*(RP@9G5Z
M>GD*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(LKKY?+N
M]^W@_R#PX.3H[O'B_^?\(@H*(R!F=7IZ>0HC.B!L:6(O87!I+G!H<#HQ,CD*
M;7-G:60@(E]5<V5R<R(*;7-G<W1R("+/[NO\Y^[BX/+EZ^@B"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.CDR,`HC+"!F=7IZ>0IM<V=I9"`B861D<F5S<R!B
M;V]K(@IM<V=S='(@(L#D\.7Q[>#_(.KMZ./@(@H*(SH@;&EB+TAO<F1E+TU)
M344O365S<V%G92YP:'`Z,3,T"B,L(&9U>GIY"FUS9VED(")A9&1R97-S964@
M=6YK;F]W;B(*;7-G<W1R("+`Y/#E\>W@_R#J[>CCX"(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z.3$R"B,L(&9U>GIY"FUS9VED(")C86QE;F1A<B(*;7-G
M<W1R("+*X.OE[>3@\/PB"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H
M<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3,P"FUS9VED
M(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M34E-12]#;VYT96YT<RYP:'`Z-3DY"FUS9VED(")C;&EC:R!H97)E(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I
M9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W.`IM<V=I9"`B8V]N9FEG=7)A
M=&EO;B!E<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S
M86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I
M;F<B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z
M,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R("(B"@HC(&9U
M>GIY"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,S`*;7-G:60@(F5D
M:70B"FUS9W-T<B`BS_#@XNCR_"(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A
M9V4N<&AP.C$X,@HC+"!F=7IZ>0IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM
M<V=S='(@(L[R[.7MZ/+\(.CG[.7MY>WH_R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")F86QL:6YG(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX.#$*(RP@9G5Z>GD*
M;7-G:60@(F9I;&4B"FUS9W-T<B`BQ^#C[NONXN[J(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(S.0HC+"!F=7IZ>0IM<V=I9"`B9W5S=&EN
M9R(*;7-G<W1R(");\?+P[NK@("5S(.CG("5S72(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR-#@*;7-G:60@(F@Z(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS-3<*
M;7-G:60@(FAH(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A
M9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-2!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I
M871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,38R"FUS9VED(")I
M;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)
M344O365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E
M<G)O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T
M94)L;V-K<RYJ<SHQ,PHC+"!F=7IZ>0IM<V=I9"`B;&EN97-=(@IM<V=S='(@
M(L?@X^[K[N+NZB(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP
M.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E
M9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8X"FUS9VED(")M;2(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C(X-2!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HR-#$*(RP@9G5Z>GD*;7-G:60@(FYA;64B"FUS9W-T<B`BR.S_
M(@H*(SH@;&EB+TAO<F1E+U)00RYP:'`Z,3(T"B,L(&9U>GIY"FUS9VED(")N
M;W0@:6UP;&5M96YT960B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP
M;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(LWNXN[E(/'N[N'YY>WH
MY2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(R,`HC+"!F=7IZ
M>0IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HB
MS>[B[N4@\>[NX?GE[>CE(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,#0*
M(RP@9G5Z>GD*;7-G:60@(FYO=&5P860B"FUS9W-T<B`BQ^#LY?+JZ"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)
M344O365S<V%G92YP:'`Z,3<T"B,L(&9U>GIY"FUS9VED(")P97)M:7-S:6]N
M(&1E;FEE9"(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HBS>#Q
M\O#NZ>KH(._NZ_SG[N+@\N7K_UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M3F%G($@S("@R+C`N,RDI("`C+2,M(RTC+2-<;B(*(LCG[.7MZ/+\(._PX.+@
M(.3N\?+S[^!<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$YA9R!(,R`H,BXP
M+C,I*2`@(RTC+2,M(RTC7&XB"B+(Y^SE[>CR_"#O\.#BX"#D[O'R\^_@(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-
M24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R
M;W1O8V]L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")R:7-I;F<B"FUS9W-T
M<B`BPNWH[.#MZ.4B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ
M-#(*(RP@9G5Z>GD*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T
M<B`BS>7R(.3N\?+S[^W[]2#MX/'R\.[EZBXB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C$P,0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS
M9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-0IM<V=I9"`B<W,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(G-T96%D>2(*;7-G<W1R("+*X.OE[>3@
M\/PB"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-3`*(RP@9G5Z
M>GD*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R("+N\/3NX_#@].CWY?'J
MX/\@[OCHX>K@(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,C@*;7-G:60@
M(G1A<VL@;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S
M86=E+G!H<#HQ-C8*(RP@9G5Z>GD*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E
M(@IM<V=S='(@(L_NZ/'J(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@;&EB+TAO
M<F1E+T%U=&@O4VEG;G5P+G!H<#HR-S`*(RP@9G5Z>GD*;7-G:60@(G1Y<&4@
M=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`BS_#N]^#_
M(.CM].[P[.#VZ/\B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI
M;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R("(B
M"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]-24U%+U!A<G0N<&AP.C(W"FUS9VED
M(")U;FYA;65D(@IM<V=S='(@(O+EZO'R(/'N[N'YY>WH_R(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,C,*(RP@9G5Z>GD*;7-G:60@(G5S97(@<V5L
M96-T(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R
M+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V
M,RXQ*2`@(RTC+2,M(RTC7&XB"B+$Y>GQ\N+HY3HB"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R
M(")V0V%R9"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-#`*;7-G:60@(G<Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*;7-G<W1R("(B
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&\O<VM?4TLN<&\`````````````````````````````
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#<P,#`W,``Q,#4Q-30S,S<U-``P
M,3<V-3,`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````(R!(;W)D92!3;&]V86L@=')A;G-L871I;VXN"B,@0V]P>7)I9VAT("A#
M*2`R,#`R($QE;R!-<F%F:V\@/&QE;T!O96PN<VL^("AO<FEG:6YA;"!T<F%N
M<VQA=&]R*0HC("A#*2`R,#`R+"`R,#`S($EV86X@3F]R:7,@/'9I>$!V87IK
M82YS:SX*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO
M;CH@2&]R9&4@,RXQ7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI
M<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#$M
M,#8@,30Z,3`K,#$P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP,2TS
M,"`R,3HR-BLP,C`P7&XB"B),87-T+51R86YS;&%T;W(Z($EV86X@3F]R:7,@
M/'9I>$!V87IK82YS:SY<;B(*(DQA;F=U86=E+51E86TZ(%-L;W9A:R`\=FEX
M0'9A>FMA+G-K/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M
M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TR7&XB"B)#;VYT
M96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=%QN(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(S-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES
M(&%G;RDB"FUS9W-T<B`B("AP<F5D("5S(&3R86UI*2(*"B,Z(&QI8B](;W)D
M92YP:'`Z,3,W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E
M<RDB"FUS9W-T<B`B("A+;.%V97-O=N$@<VMR871K82`E<RDB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C,X,0HC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN
M("5S(&1A>7,I(@IM<V=S='(@(B`H;R`E<R!D;NTI(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(S-S<*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(BAD;F5S
M*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S<Y"FUS9VED("(@*'1O;6]R
M<F]W*2(*;7-G<W1R("(@*'IA:G1R82DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C,W-0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B`H=NAE<F$I
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-2!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4P"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS.38*;7-G:60@(B!A="`B"FUS9W-T<B`B('+]8VAL;W.[
M("(*"B,Z(&QI8B]61E,O<VUB+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B7"(E<UPB
M(&YI92!J92!A9')E<^%R+B(*"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(W,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO
M:6-E+B(*;7-G<W1R(")<(B5S7"(@;FEE(&IE('!L871NX2!V;[5B82XB"@HC
M.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C8U,B!L:6(O2&]R9&4O4F5G:7-T
M<GDN<&AP.C$P-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO
M="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B
M7"(E<UPB(&YI92!J92!N86MO;F9I9W5R;W9A;ND@=B!R96=I<W1R:2!(;W)D
M92XB"@HC.B!L:6(O2&]R9&4O5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T
M<B`B>F]B<F%Z;W9AZ"!S=')O;74@7"(E<UPB(&YE8F]L(&[A:F1E;OTN(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R
M(")3:W5P:6YA(%PB)7-<(B!B;VQA('!R:61A;N$@9&\@<WES=.EM=2XB"@HC
M.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES
M=&5M+B(*;7-G<W1R(")0<N%V;R!<(B5S7"(@8F]L;R!P<FED86[I(&1O('-Y
M<W3I;74N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A
M9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A
M<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(EPB)7-<(B!N96)O;&\@;6^^
M;ND@=GET=F]R:;LZ("5S+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@
M86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R(")0;W6^:73]8V@@)2XR9DU"('H@
M9&]V;VQE;OUC:"`E+C)F34(@*"4N,F8E)2DB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C(V"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S
M(&%N9"`E<R(*;7-G<W1R("(E9"`E<R!A("5S(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D
M(&5X<&ER97,N(@IM<V=S='(@(B5D(&1N[2!D;R!V>7!RN6%N:6$@<&QA=&YO
M<W1I(%;AN6AO(&AE<VQA+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T
M(@IM<V=S='(@(G!R961P;W9E[R!N82`E9"!D;NTB"@HC.B!S97)V:6-E<R]M
M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.
M;W1I8V4B"FUS9W-T<B`B)7,@+2!0;WINX6UK82(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-S`U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I
M;F=E<G!R:6YT(@IM<V=S='(@(D]D=&QAZ&]K("5S(@H*(SH@;&EB+TAO<F1E
M+TU)344O0V]N=&5N=',N<&AP.C@T,"!L:6(O2&]R9&4O34E-12]#;VYT96YT
M<RYP:'`Z.#0R"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@
M(B5S($M"(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#
M;VYF:7)M871I;VXB"FUS9W-T<B`B3W!E<N%C:64@^F1ROF)Y('!R92!A<&QI
M:^%C:74@)7,@+2!0;W1V<F1E;FEE(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(DYA<W1A=F5N:64@)7,B"@HC
M.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(E)E9VES=')O=F%N:64@9&\@
M87!L:6OA8VEE("5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*
M;7-G<W1R(")0;V1M:65N:WD@<&]UOFET:6$@)7,B"@HC.B!L:6(O5D93+W-M
M8BYP:'`Z-#,R(&QI8B]61E,O<VUB+G!H<#HT.30@;&EB+U9&4R]F='`N<&AP
M.C8W,0HC.B!L:6(O5D93+V9T<"YP:'`Z-S,Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(E<R!UOB!E>&ES='5J
M92XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.2!L:6(O0FQO8VLO;65T
M87(N<&AP.C$V-2!L:6(O0FQO8VLO;65T87(N<&AP.C(S.0HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,T-2!L:6(O0FQO8VLO;65T87(N<&AP.C,U,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(E<R!V;R!V
M_;EK92`E<R`E<R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M
M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H
M96-K('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@
M=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(B(*(D%P;&EKX6-I
M82`E<R!J92!P<FEP<F%V96[A(&YA('9Y:V]N86YI92!O<&5RX6-I[2#Z9'*^
M8GDN3WIN8>AT92"Y='9O<NAE:R!P<FD@(@HB;W!E<N%C:>%C:"P@:W1O<ND@
M8VAC971E('9Y:V]N8;L@=&5R87HN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(S-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS
M9W-T<B`B4&^^861U:F4@<V$@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@
M(B5S(&UI;OIT(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP
M.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S
M='(@(B5S(&YE8F]L(&[A:F1E;OTN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O
M9B`E<R(*;7-G<W1R("(E<R!AOB`E<R!Z("5S(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HY,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S
M($)O;VLB"FUS9W-T<B`B061R97/A<B!P;W6^[79A=&6U82`E<R(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z.3$S"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M)W,@0V%L96YD87(B"FUS9W-T<B`B2V%L96YDX7(@<&]UONUV871EM6$@)7,B
M"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDP-0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B4&]Z;N%M:WD@<&]UONUV871E
MM6$@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDR.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(EIO>FYA;2#Z;&]H
M('!O=;[M=F%T9;5A("5S(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M.B`E<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O:'1M;"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4
M:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O
M(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O
M<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I
M;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@HB)7,Z(%3A=&\@<W!RX79A(&YE;75S
M[2!B>;L@;V0@;V1O<VEE;&%T9;5A+"!K=&]R_2!S82!Z;V)R87IU:F4@86MO
M("(*(F]D;W-I96QA=&6U('-P<N%V>2X@6F%C:&]V86IT92!O<&%T<FYO<[L@
M<')I(&ML:6MA;NT@;F$@;&EN:WD@=B!S<'+A=F4@86QE8F\@(@HB<&]S:WET
M;W9A;NT@;W-O8F[]8V@@:6YF;W)MX6-I[2!O9&]S:65L871EM6]V:2XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4T(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS.3D*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T
M<B`B+"!NX7)A>F]V_2`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X."!L
M:6(O0FQO8VLO;65T87(N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L
M(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B+"!V(&[A<F%Z;V-H("5S("5S(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(BP@<')E;65N
M;N$@=B!R;WIS86AU("5S(&&^("5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(P-S,@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,S(@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HR.30*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS-#@@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T-0IM<V=I9"`B+2T@
M<V5L96-T("TM(@IM<V=S='(@(BTM('9Y8F5R=&4@<VD@+2TB"@HC.B!L:6(O
M0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S
M='(@(C$R+6AO9&EN;W;](&9O<FWA="(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B,C0M:&]D:6YO
M=OT@9F]R;>%T(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G
M:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T(&AO9.UN(@H*(SH@;&EB+TAO<F1E
M+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(CQ0
M<F5D8VCA9'IA:OIC82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS
M9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@
M8FQO8VLN(@IM<V=S='(@(E!R92!T96YT;R!B;&]K(&IE('!OOF%D;W9A;OT@
M9&%T86+A>F]V_2!B86-K96YD+B(*"B,Z(&QI8B](;W)D92YP:'`Z,38R"FUS
M9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R(")6>7-K
M>71L82!S82!ZX79AOF[A(&-H>6)A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D
M('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(").82!Z8;EI9G)O=F%N
M:64@<W!RX79Y(&IE('!OOF%D;W9A;OT@=F5R96IN_2!02%`@:[7ZZ"XB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,38X"FUS9VED(")!('!U8FQI
M8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S
M86=E+B(*;7-G<W1R(").82!O=F5R96YI92!P;V1P[7-A;F5J('-P<N%V>2!J
M92!P;[YA9&]V86[]('9E<F5J;OT@4$=0(&NU^N@N(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z,3`Y.0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME
M>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(DYA(&1E
MN6EF<F]V86YI92!S<'+A=GD@<_H@<&]T<F5B;NDZ('9E<F5J;OT@4$=0(&NU
M^N@L('!R:7;A=&YY(%!'4"!KM?KH(&$@(@HB:&5S;&\N(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z,3`Q-@IM<V=I9"`B(@HB02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(DYA('!O
M9'#M<V%N:64@<W!RX79Y('/Z('!OOF%D;W9A;NDZ('9R96IN_2!01U`@:[7Z
MZ"P@<')I=N%T;GD@4$=0(&NU^N@@82`B"B)H97-L;RXB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4P-@IM<V=I9"`B(@HB02!P=6)L:6,@4R]-
M24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@
M(B(*(DYA(&1EN6EF<F]V86YI92!S<'+A=GD@<_H@<&^^861O=F%NZ3H@=F5R
M96IN_2!3+TU)344@:[7ZZ"P@<')I=N%T;GD@4R]-24U%("(*(FNU^N@@82!H
M97-L;RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I
M9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE
M<W-A9V4N(@IM<V=S='(@(B(*(DYA('!O9'#M<V%N:64@<W!RX79Y('/Z('!O
MOF%D;W9A;NDZ('9E<F5J;OT@4R]-24U%(&NU^N@L('!R:7;A=&YY(%,O34E-
M12`B"B)KM?KH(&$@:&5S;&\N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E
M9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B3F$@>F&Y:69R;W9A
M;FEE('-P<N%V>2!J92!P;[YA9&]V86[]('9E<F5J;OT@4TU)344@:[7ZZ"XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"FUS
M9VED(")!32!#;&]U9',B"FUS9W-T<B`B4')E9'!O;'5D;NUM(&]B;&'H;F\B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM
M<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R(")0<F5D<&]L=61N[6T@M6%H
M:_T@9.&^[R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$Q"FUS9VED(")!32!286EN(@IM<V=S='(@(E!R961P;VQU9&[M;2!D
MX;[O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B4')E9'!O;'5D;NUM('!R
M96CA;FMY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")0<F5D<&]L
M=61N[6T@<VYE:&]VZ2!P<F5HX6YK>2(*"B,Z('1E;7!L871E<R]D871A+W1I
M;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R("(Q,B!H;V3M;B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!
M4$D@240B"FUS9W-T<B`B05!)($E$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET
M;W(B"FUS9W-T<B`B3R!T;VUT;R!E9&ET;W)E(@H*(SH@<V5R=FEC97,O:&5L
M<"]I;F1E>"YP:'`Z-3,*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(D\N+BXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T
M"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B06)S;VSZ=&YY('-P;V1O:R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*
M;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R(")!8G-O;/IT;GD@<W1R960B"@HC
M.B!L:6(O5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@
M8W)E871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B4')I('9Y=';A<F%N
M[2!61E,@861R97/A<F$@8F]L('IA;6EE=&YU=/T@<'+M<W1U<"XB"@HC.B!L
M:6(O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&9I;&4N(@IM<V=S='(@(E!R:2!V>71VX7)A;NT@5D93('/Z
M8F]R=2!B;VP@>F%M:65T;G5T_2!P<NUS='5P+B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HS"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S
M='(@(DEN9F]R;>%C:64@;R#ZZ'1E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<X"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(DAE<VQO
M('!R92#ZZ&5T(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R("+:Z&5T('IA
M8FQO:V]V86[]+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S4*
M;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`BVNAT;W9A;FEE(@H*(SH@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N
M:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC
M.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`B4')I9&&[(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#
M:&EL9"!'<F]U<"(*;7-G<W1R(")0<FED8;L@<&]D<FEA9&5N^B!S:W5P:6YU
M(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HY."!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.CDY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G
M<W1R(")0<FED8;L@<&]D<FEA9&5NZ2!P<N%V;R(*"B,Z('1E;7!L871E<R]P
M;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`B4')I
M9&&[.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP
M:'`Z,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(E!R:61ANR!S
M:W5P:6YU(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX-R!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB
M"FUS9W-T<B`B4')I9&&[(&YO=ND@<'+A=F\B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@
M(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R(")0<FED8;L@
M9&/I<G-K=2!S:W5P:6YU(&1O(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD
M('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(E!R:61ANR!D8^ER<VME
M('!RX79O(&1O(%PB)7-<(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED
M(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B4')I9&&[('!O=;[M=F%T9;5A
M.B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU-3,*
M;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B4')I9&&[('-TY7!E8R(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*;7-G:60@(D%D
M9"!N97<@;65M8F5R<R(*;7-G<W1R(")0<FED8;L@Z&QE;F]V(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS
M9W-T<B`B4')I9&&[('#A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@
M36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(E!R:61ANR!M96YU("5S(&%K;R!"
M;^AN_2!P86YE;"!-;WII;&QY(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HW,0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS
M9W-T<B`B4')I9&&[(&1O(&%D<F5SX7)A.B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S
M(&)O;VLB"FUS9W-T<B`B4')I9&&[(&1O(&WT:FAO(&%D<F5SX7)A(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(E!R
M:61ANR!P;W6^[79A=&6U82(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M
M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA
M=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*(EPB)7-<(B!B;VP@<')I9&%N_2!D
M;R!S>7-TZ6UU+"!A;&4@;F5M;[YN;R!P<FED8;L@[V%LN6EE('!R:6AL87-O
M=F%C:64@(@HB:6YF;W)MX6-I93H@)7,N(@H*(SH@<VEG;G5P+G!H<#HT-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E
M;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R(")<(B5S7"(@8F]L('!R
M:61A;OT@9&\@<WES=.EM=2X@5&5R87H@<V$@;?2^971E('!R:6ALX7-INRXB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B
M061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")0<FEDX79A;FEE
M('!O=;[M=F%T9;5O=B!J92!Z86OA>F%NZ2XB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,30T-2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R
M-@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,PIM<V=I
M9"`B061D<F5S<R(*;7-G<W1R(")!9')E<V$B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,30Q"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B
M061R97/A<B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H
M97(@=7-E<G,B"FUS9W-T<B`B061M:6YI<W1RX6-I82`M(&YA<W1A=F5N:64@
M<'+A=B!P<F4@:6[]8V@@<&]UONUV871EM6]V(@H*(SH@861M:6XO:6YD97@N
M<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@
M(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<N%C:6$B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0S"FUS9VED(")!9',B"FUS9W-T
M<B`B4F5K;&%M>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ."!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(D%F9V%N
M:7-T86XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4W"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(D%L8N%N<VMO(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<T(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I
M9"`B06QG97)I82(*;7-G<W1R(")!;+[M<G-K;R(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R
M(")!;&EA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@(EIA<F]V;F&[
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV
M-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R("):87)O=FYA;FEE.B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@
M(E:Y971K>2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,C`W('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A
M=&5D(%5S97)S(@IM<V=S='(@(E:Y971C:2!A=71E;G1I9FEK;W9A;NT@<&]U
MONUV871E;&EA(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U
M<',N<&AP.C(R,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R(")6N65T:WD@
M<VMU<&EN>2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z.3$@;&EB+TAO
M<F1E+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I
M;VYS(@IM<V=S='(@(E:Y971K>2!P<N%V82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F
M;W5R('-I9&5S(@IM<V=S='(@(E:Y971K>2"Y='ER:2!S=')A;GDB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3@W-0IM<V=I9"`B06QL;W<@;75L=&EP;&4@
M861D<F5S<V5S(@IM<V=S='(@(E!O=F]L:;L@=FEA8V5RZ2!A9')E<WDB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,X"FUS9VED(")!;&QO=R!S971T
M:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R(")0;W9O;&F[(&YA
M<W1A=F5N:64@='EP=2!Z;W)A9&5NZ6AO('IO>FYA;74_(@H*(SH@;&EB+TAO
M<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!;')E861Y(&5X:7-T
M<R(*;7-G<W1R(")5OB!E>&ES='5J92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,C8*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@
M(D%L=&5R;F%T[79N92!P<FEH;&%S;W9A8VEE(&UE;F\@24U34"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3$*;7-G:60@(D%L=&5R;F%T92!)35-0
M(%!A<W-W;W)D(@IM<V=S='(@(D%L=&5R;F%T[79N92!H97-L;R!)35-0(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P,PIM<V=I9"`B06QT97)N871E
M($E-4U`@57-E<FYA;64B"FUS9W-T<B`B06QT97)N873M=FYE('!O=;[M=F%T
M9;5S:^D@;65N;R!)35-0(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z,S4*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@
M(D%L=&5R;F%T[79N82!E+6UA:6QO=N$@861R97-A(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS
M9W-T<B`B06QT97)N873M=FYE(+EA8FSS;GDB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@
M(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R(")!;'1E<FYA=.UV;GD@=&5X=#HB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X
M"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R(")!;65R:6-KX2!386UO
M82(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z.34@;&EB+TAO<F1E+U!R
M969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P
M96-I9FEE9"XB"FUS9W-T<B`B0F]L82!Z861A;N$@;F5P;&%T;N$@:&]D;F]T
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-34*;7-G:60@
M(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(DYA<W1A
M;&$@;F5Z;N%M82!C:'EB82XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(D%N
M9&]R<F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B06YG;VQA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(P(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B
M06YG=6EL;&$B"FUS9W-T<B`B06YG=6EL;&$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R
M(")!;F]N>6UNZ2!P<F]X>2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B3V1P;W9E[R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@
M(D%N=&%R8W1I8V$B"FUS9W-T<B`B06YT87)K=&EK82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG
M=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B06YT:6=U82!A($)A<F)U9&$B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS
M-2!L:6(O2&]R9&4O0FQO8VLO54DN<&AP.C4X"B,Z('1E;7!L871E<R]A9&UI
M;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S
M='(@(D%P;&EKX6-I82(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM
M<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R("):;WIN86T@87!L:6OA
M8VGM(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P
M;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(D%P;&EKX6-I82!J92!P<FEP
M<F%V96[A+B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS
M9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B07!L:6MO=F&[
M(&YA('!O9')I861E;ND@>F1I9;5A;ND@<')I9>AI;FMY(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B
M"FUS9W-T<B`B4V-H=N%L:;LB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT
M<RYP:'`Z.#0P"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(E!R
M:6)L:;YNX2!V9;5K;W.[(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P,B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(D%P<NUL(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ-S$*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V
M*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H
M<#HU.2!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.`IM<V=I9"`B07)C:&EV92!&
M:6QE(%-I>F4B"FUS9W-T<B`B5F6U:V]SNR!A<F-H[79U(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-S<*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R(")-96YO(&%R8VCM
M=G4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC
M.C$P"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N
M="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S
M='(@(DYA;WIA:B!C:&-E=&4@=GEM87IANR"^:6%D;W.[(&\@<')I:&SA<V5N
M:64@)R5S)S\B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI
M;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I
M<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S
M='(@(DYA;WIA:B!C:&-E=&4@=GEM87IANR!<(B5S7"(@82!VN65T:WD@<&]D
M<VMU<&EN>3\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B07)G96YT[6YA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M-PIM<V=I9"`B07)M96YI82(*;7-G<W1R(")!<FWI;G-K;R(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3<R"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX
M*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G
M:60@(D%R="(*;7-G<W1R(")5;65N:64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R
M(")!<G5B82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B
M07-C96YS:6]N($ES;&%N9"(*;7-G<W1R(")/<W1R;W8@07-C96YS:6]N(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B
M"FUS9W-T<B`B07-C:6D@=6UE;FEE(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B
MP7II82]086-I9FEC:_T@<F5G:?-N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0R.0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O
M:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(E9YOF%D;W9A
MNR!P;W1V<F1E;FEE('!R960@=GEK;VYA;NUM(&]P97+A8VGM(/ID<KYB>3\B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P,@IM<V=I9"`B07-S:6=N;65N
M="!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*
M;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P
M+B(*;7-G<W1R(")0;VMU<R!O('9Y;6%Z86YI92!N965X:7-T=6KZ8V5J('-K
M=7!I;GDN(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B
M071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB
M"FUS9W-T<B`B4&]K=7,@;R!V>6UA>F%N:64@;F5E>&ES='5J^F-E:&\@<'+A
M=F$N(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M
M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R
M(")0;VMU<R!O(/IP<F%V=2!N965X:7-T=6KZ8V5H;R!P<N%V82XB"@HC.B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B4&]K=7,@;R#Z
M<')A=G4@;F5E>&ES='5J^F-E:&\@>F1I9;5A;NEH;R!O8FIE:W1U+B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8T(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T9WHN<&AP.C@S"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(D%T<FEB
M^G1Y(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M-B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@
M(D%U9W5S="(*;7-G<W1R(")!=6=U<W0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS
M9W-T<B`B075S='+A;&EA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(X
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')I82(*;7-G<W1R(")286OZ
M<VMO(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@
M(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D%U=&A?8WER<W%L.B!0;[YA9&]V86[I(')O>KGM<F5N
M:64@:6UA<"!N96)O;&\@;N%J9&5NZ2XB"@HC.B!L:6(O2&]R9&4O075T:"]C
M>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@
M;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM<V=S='(@(D%U=&A?
M8WER=7,Z(&)A8VME;F0@;F5MX2!P;[YA9&]V86[I('-C:&]P;F]S=&DN(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C
M>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R(")!=71H7V-Y<G5S.B!P;[YA9&]V86[I(')O>KGM<F5N:64@:6UA<"!N
M96)O;&\@;N%J9&5NZ2XB"@HC.B!L:6(O2&]R9&4O075T:"]F='`N<&AP.C,V
M"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T
M<"!S=VET8V@N(@IM<V=S='(@(B(*(D%U=&A?9G1P.B!P;[YA9&]V86[I(')O
M>KGM<F5N:64@1E10(&YE8F]L;R!NX6ID96[I+B!3:V]M<&EL=6IT92!02%`@
M<R`B"B)P<F5P[6YAZ&]M("TM96YA8FQE+69T<"XB"@HC.B!L:6(O2&]R9&4O
M075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)
M34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA<#H@
M<&^^861O=F%NZ2!R;WJY[7)E;FEE($E-05`@;F5B;VQO(&[A:F1E;NDN(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B
M-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!=71H7VMR8C4Z('!OOF%D;W9A;ND@<F]ZN>UR96YI92!K<F(U(&YE8F]L
M;R!NX6ID96[I+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C,P,@IM
M<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"B)!=71H7VQD87`Z
M('!R:63A=F%N:64@<&]UONUV871EM6]V(&YI92!J92!P;V1P;W)O=F%NZ2!P
M<F4@06-T:79E($1I<F5C=&]R>2(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N
M<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N
M;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*
M(D%U=&A?;&1A<#H@=GEM87KA=F%N:64@<&]UONUV871EM6]V(&YI92!J92!P
M;V1P;W)O=F%NZ2!P<F4@06-T:79E($1I<F5C=&]R>2(*"B,Z(&QI8B](;W)D
M92]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D
M($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P
M.B!P;[YA9&]V86[I(')O>KGM<F5N:64@3$1!4"!N96)O;&\@;N%J9&5NZ2XB
M"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R(")!=71H7VQD
M87`Z($YE<&]D87)I;&\@<V$@<')I9&&[('!O=;[M=F%T9;5A("5S+B!397)V
M97(@;V1P;W9E9&%L.B`B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS
M.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@
M<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!N97!O9&%R:6QO
M('-A(&]D<W1RX6YINR!P;W6^[79A=&6U82`E<R(*"B,Z(&QI8B](;W)D92]!
M=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD
M87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD
M87`Z(&YE<&]D87)I;&\@<V$@86MT=6%L:7IO=F&[('!O=;[M=F%T9;5A("5S
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H
M7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C
M=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@86MT=6%L
M:7KA8VEA('!O=;[M=F%T9;5O=B!N:64@:F4@<&]D<&]R;W9A;N$@<')E($%C
M=&EV92!$:7)E8W1O<GDB"@HC.B!L:6(O2&]R9&4O075T:"]M8V%L+G!H<#HT
M-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;6-A;#H@<&^^861O=F%NZ2!R;WJY
M[7)E;FEE($U#04P@;F5B;VQO(&[A:F1E;NDN(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S
M;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?<VUB
M875T:#H@<&^^861O=F%NZ2!R;WJY[7)E;FEE('-M8F%U=&@@;F5B;VQO(&[A
M:F1E;NDN(@H*(SH@;&EB+TAO<F1E+TE-05`O061M:6XN<&AP.C$P-@IM<V=I
M9"`B075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+B(*;7-G
M<W1R(")!=71E;G1I9FEKX6-I82!P;VUO8V]U($E-05`@<V5R=F5R82!Z;'EH
M86QA+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP
M"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B075T96YT
M:69I:^%C:6$@>FQY:&%L82(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z-C<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N
M("5S(@IM<V=S='(@(D%U=&5N=&EF:6OA8VEA('IL>6AA;&$N("5S(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I
M8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@(E-E
M<G9E<B!2041)55,@>F%M:65T;VP@875T96YT:69I:^%C:74N(@H*(SH@;&EB
M+U9&4R]F='`N<&AP.C@W,0IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10
M('-E<G9E<B!F86EL960N(@IM<V=S='(@(D%U=&5N=&EF:6OA8VEA('!O;6]C
M;W4@1E10('-E<G9E<F$@>FQY:&%L82XB"@HC.B!L:6(O5D93+W-M8BYP:'`Z
M-S`*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A
M:6QE9"XB"FUS9W-T<B`B075T96YT:69I:^%C:6$@<&]M;V-O=2!334(@<V5R
M=F5R82!Z;'EH86QA+B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(D1O<W1U<&[I
M('!O;&^^:WDZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,Q(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R(")!>F5R8F%J
M9+YA;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&
M2"!%>&-U<V5S(@IM<V=S='(@(D)/1D@@17AC=7-E<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@
M(D)A8VMG<F]U;F0B"FUS9W-T<B`B4&]Z861I92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U
M;F0@0V]L;W(B"FUS9W-T<B`B1F%R8F$@<&]Z861I82(*"B,Z(&QI8B](;W)D
M92]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O
M<F0N(@IM<V=S='(@(EILZ2!H97-L;R!P<F4@:V5R8F5R;W,N(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U
M<V5R;F%M92XB"FUS9W-T<B`B6FSI('!O=;[M=F%T9;5S:^D@;65N;R!P<F4@
M:V5R8F5R;W,N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R(")"86AA;7DB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS
M9VED(")"86AR86EN(@IM<V=S='(@(D)A:')A:FXB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$W,PIM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,T(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R(")"86YG;&%DZ;DB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P
M"FUS9VED(")"87)B861O<R(*;7-G<W1R(")"87)B861O<R(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E
M(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M(")0<FEEZ&EN;VL@<R!G<F%F:6MO=2!<(B5S7"(@;F5B;VP@;N%J9&5N_2XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(EKA:VQA9&[](')I861O
M:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B0FEE;&]R=7-K;R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HS-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@
M(D)E;&=I=6TB"FUS9W-T<B`B0F5L9VEC:V\B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QI>F4B"FUS
M9W-T<B`B0F5L:7IE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B0F5N:6XB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C,T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS
M9VED(")"97)M=61A(@IM<V=S='(@(D)E<FUU9'DB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB
M"FUS9W-T<B`B0G5TX6XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B3F%R;V1E;FEN
M>2(*"B,Z(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HS-30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N
M(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(D)L;VL@7"(E<UPB(&%P;&EK
MX6-I92!<(B5S7"(@;F5B;VP@;N%J9&5N_2XB"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VQA>6]U="YI;F,Z.3`*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S
M='(@(DYA<W1A=F5N:6$@8FQO:W4B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA
M>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B5'EP(&)L
M;VMU(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX"FUS9VED(")";VQD(@IM<V=S='(@(E1UZ&[I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C0S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS
M-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I
M82(*;7-G<W1R(")";VSM=FEA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(P-PIM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(EKA;&^^:WDB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(P"FUS9VED(")";W)D97(B"FUS9W-T<B`B3VMR86HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D
M97(@=&AI8VMN97-S.B(*;7-G<W1R("*I[7)K82!O:W)A:F$Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM
M<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")/:W)A:F4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,W
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@
M86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(D)O<VYA(&$@2&5R8V5G;W9I;F$B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS
M9W-T<B`B3V)E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B0F]T<W=A;F$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R(")";W1T;VTB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"
M;W5V970@27-L86YD(@IM<V=S='(@(D)O=79E="!)<VQA;F0B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C0P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"
M<F%Z:6PB"FUS9W-T<B`B0G)A>NUL:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I
M86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(D)R:71S:^D@^GIE;6EE('8@
M26YD:6-K;VT@;V-EX6YE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS
M9W-T<B`B0G)U;F5I($1A<G5S<V%L86TB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=6QG87)I82(*;7-G
M<W1R(")"=6QH87)S:V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Y"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@
M(EIO>FYA;2!S(&]D<N&^:V%M:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HS-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G
M<W1R(")"=7)K:6YA($9A<V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(D)U
M<G5N9&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0V"FUS9VED
M(")#35,B"FUS9W-T<B`B0TU3(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R(")#4D,B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM<V=I9"`B0U),($1I<W1R:6)U
M=&EO;B!0;VEN=',B"FUS9W-T<B`B1&ES=')I8G7H;ND@8F]D>2!#4DPB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B5FQA
M<W1N;W-T:2!?8G5N:WDN+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,34Q"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D
M+B(*;7-G<W1R("));F-I86QI>N%C:6$@=GER;W9NX79A8V5J('!A;>1T:2!N
M96)O;&$@9&]K;V[H96[A+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT.#(@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDX-PHC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34W"FUS9VED(")#86QE;F1A<B(*
M;7-G<W1R(")+86QE;F3A<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,S4*;7-G:60@(D-A;&TB"FUS9W-T<B`B0F5Z=F5T<FEE(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(D-A;6)O9&EA(@IM<V=S='(@(DMA;6)O9+YA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C8P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT
M-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O
M;VXB"FUS9W-T<B`B2V%M97)U;B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M
M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("(B"B).97!O9&%R:6QO('-A(&%U=&]M871I8VMY(&]B;F]V:;L@:&5S;&\L
M(&MO;G1A:W1U:G1E('-V;VIH;R!A9&UI;FES='+A=&]R82XB"@HC.B!L:6(O
M1FEL92]#4U8N<&AP.C,U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T
M('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@
M>F%P[7-ANR!D;R!S^F)O<G4@7"(E<UPB(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C(R"FUS9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I
M;VX@:&%N9&QE<G,N(@IM<V=S='(@(DYE;6^^;F\@861M:6ES=')O=F&[(&5X
M=&5R;ND@;W9LX61AZ&4@<V5D96[M+B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y
M<G5S+G!H<#HR,S4@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E
M<CH@)7,B"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!S<&]J:;L@<R!)34%0('-E
M<G9E<F]M.B`E<R(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#0V"B,L('!H<"UF
M;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(DYE<&]D87)I;&\@<V$@;W1V;W)INR!S^F)O<B!<(B5S7"(N(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C4Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HT.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B
M0V%N861A(@IM<V=S='(@(DMA;F%D82(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P
M,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M9&5L971E+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I
M9"`B0V%N8V5L(@IM<V=S='(@(EIR=;EINR(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O
M<G0B"FUS9W-T<B`B6G)UN6F[('-P<N%V=2!O('!R;V)LZ6UE(@H*(SH@;&EB
M+U9&4R]F='`N<&AP.C,R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@
M9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").97!O9&%R:6QO('-A('9Y
M;6%Z8;L@<_IB;W(@7"(E<UPB+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B0V%N
M;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(").97!O
M9&%R:6QO('-A(&[A:G.[(&1OZ&%S;OT@861R97/A<BXB"@HC.B!L:6(O5D93
M+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO
M=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B3F5M;[YN;R!P
M;VMR8>AO=F&[(&)E>B!P87)A;65T<F$@)W1A<F=E=$9I;&4G+B(*"B,Z(&QI
M8B]61E,O9G1P+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T
M(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(").97!O9&%R:6QO
M('-A(&]D<W1RX6YINR!A9')E<^%R(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O
M1&%T851R964N<&AP.C$R."!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HV
M.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI
M;&1R96X@97AI<W0N(@IM<V=S='(@(DYE;6^^;F\@;V1S='+A;FF[+"!E>&ES
M='5J92`E9"!N87-L961O=F[M:V]V+B(*"B,Z(&QI8B](;W)D92]$871A5')E
M92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E
M<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA
M=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@(B(*(DYE;6^^;F\@<')E
M=7-P;W)I861ANRP@<&_H970@<&]L;[YI96L@<')E('!R975S<&]R:6%D86YI
M92!N97/Z:&QA<^T@<R!P;^AT;VT@(@HB=6QOOF5N_6-H('!O;&^^:65K+B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED
M(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*
M;7-G<W1R(").97!O9&%R:6QO('-A('-M97)O=F&[('-P<N%V=2!N82!U<NAE
M;ND@Z.US;&\N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R(")+87!V97)D
M<VOI(&]S=')O=GDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(T"FUS9VED(")#87!T:6]N(@IM<V=S='(@(E1I
M='5L;VLB"@HC.B!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM
M<V=I9"`B0V%R<FEE<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3,*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R
M(")+871E9_-R:64@82!P;W!I<VMY(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$S-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S
M(@IM<V=S='(@(DMA:FUA;G-KZ2!O<W1R;W9Y(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS
M9W-T<B`B36]B:6QN_2!T96QE9O-N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P
M97)T:65S(@IM<V=S='(@(E9L87-T;F]S=&D@8G5N:WDB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L
M;"!P861D:6YG.B(*;7-G<W1R(")6>7!L;F5N:64@8G5N:WDZ(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM
M<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(E9L87-T;F]S=&D@8G5N
M:WDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R(")2;WIO<W1U<"!B
M=6YI96LZ(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-S@*;7-G:60@(D-E
M;&QP:&]N92(*;7-G<W1R(")-;V)I;&[]('1E;&5F\VXB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$W-`IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(D1O('-T
M<F5D=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R
M(")3=')E9&]A9G)I8VOA(')E<'5B;&EK82(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3<U"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR
M*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P
M,`IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R(")0;V1R;V)N
MZ2!I;F9O<FWA8VEE(&\@8V5R=&EF:6OA=&4B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C8Q,@IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS
M9W-T<B`B5FQA<W1N[6L@8V5R=&EF:6OA='4B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B
M"FUS9W-T<B`B4&]L:71I:WD@<')E(&-E<G1I9FEKX71Y(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(R,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")#
M:&%D(@IM<V=S='(@(LAA9"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*;7-G:60@
M(D-H86YG92(*;7-G<W1R("):;65N:;LB"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z,S$*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM
M<V=S='(@(EIM96YINR!68;EE(&AE<VQO(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8Y"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E
M<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T
M;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@HB3F%S=&%V96YI92!M96YA
M(&$@861R:65S+"!K=&]RZ2!V:61I82"U=61I82P@:V7O(.CM=&%J^B!A(&]D
M<&]V961A:OH@;F$@5F&Y92`B"B)E+6UA:6QY+B(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P
M87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N
M9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*
M;7-G<W1R("(B"B):;65N82!H97-L82!N:64@:F4@=B!A:W1UX6QN96H@:V]N
M9FEG=7+A8VEI('!O9'!O<F]V86[A+B`@2V]N=&%K='5J=&4@<W9O:FAO("(*
M(F%D;6EN:7-T<N%T;W)A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T<B`B
M6FYA:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B
M4U]K;VYT<F]L;W9ANR!L:6YK=2XN+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HU.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6QE(@IM<V=S='(@
M(D-H:6QE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV-PIM<V=I9"`B0VAI;F$B"FUS9W-T<B`BR.UN82(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@
M*$=",C,Q,BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M-S<*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C<*;7-G:60@(D-H;V]S
M92!!<'!L:6-A=&EO;CHB"FUS9W-T<B`B5GEB97)T92!A<&QI:^%C:74Z(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(D-H;V]S
M92!A('!A<W-W;W)D(@IM<V=S='(@(EIV;[5T92!S:2!H97-L;R(*"B,Z(&QI
M8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!U
M<V5R;F%M92(*;7-G<W1R("):=F^U=&4@<VD@<&]UONUV871EM7-KZ2!M96YO
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P,@IM<V=I9"`B0VAO;W-E
M(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R(")6>6)E<G1E('-P]'-O
M8B!Z;V)R87IO=F%N:6$@9.%T=6UO=CHB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O
M<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T
M<B`B5GEB97)T92!T>7`@N73];'4@>F]Z;F%M=2`H<')E('IO<F%D96[I('IO
M>FYA;7DI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8V(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R(")6:6%N
M;^AN_2!O<W1R;W8B"@HC.B!L:6(O5D93+G!H<#HY,3,@;&EB+TYE="]335,N
M<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N
M(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B1&5F:6[M8VEA('1R:65D>2`E
M<R!N96)O;&$@;N%J9&5NX2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B0VQE87(B"FUS9W-T<B`B2F%S;F\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R
M"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(D]D<W1RX6YI
MNR!P<NUK87IY($U33V9F:6-E(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R
M.`IM<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`B5GEM87IANR!D;W1A>B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF
M;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R(")/9'-T
M<N%N:;L@<&]UONUV871EM6$Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(D]D
M<W1RX6YINR!P;W6^[79A=&6U82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B
M5GEM87IANR!P;W6^[79A=&6U<VOI(/ID86IE(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG($QA
M=&4B"FUS9W-T<B`B3F5S:_1R('9Y:F%S;F5N:64B"@HC.B!T96UP;&%T97,O
M;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@
M=&\@0V]N=&EN=64B"FUS9W-T<B`B2VQI:VYI=&4@<')E('!O:W)AZ&]V86YI
M92(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS
M9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(D-L:6-K871E;&P@
M8V5Z($A45%`B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*
M;7-G<W1R("):871V;W)INR!O:VYO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-#0*;7-G:60@(D-L;W5D<R(*;7-G<W1R(")/8FQA:WDB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@IM<V=I9"`B0VQO
M=61S($5A<FQY(@IM<V=S='(@(E+A;F\@;V)L8>AN;R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")#;&]U9'DB
M"FUS9W-T<B`B3V)L8>AN;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA
M;F1S(@IM<V=S='(@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@
M4VED96)A<B(*;7-G<W1R("):8F%L:;L@0F_H;OT@<&%N96PB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS
M9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R("):8F%L96[I(&]K<F%J
M92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(DMO;'5M8FEA(@H*(SH@;&EB
M+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(D9A<F)A(@H*(SH@;&EB+TAO<F1E
M+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-2!L:6(O2&]R9&4O0FQO8VLO0V]L
M;&5C=&EO;BYP:'`Z,S(V"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HU,#`@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ
M-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT
M.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU
M,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV
M-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV
M-@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX
M,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX
M,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(E;]8F5R(&9A<F)Y(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,S4*;7-G:60@(D-O;&]U<B!S96QE
M8W1I;VXB"FUS9W-T<B`B5OUB97(@9F%R8GDB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS
M9W-T<B`B4W3E<&-E.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.34P"FUS
M9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(DYA9'!I<WD@<W3E<&-O=B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C8*;7-G:60@(D-O;6EC
M<R(*;7-G<W1R(")+;VUI:W,B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*
M;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B4'+M:V%Z(@H*(SH@861M:6XO8VUD
M<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(E!R
M[6MA>F]V_2!I;G1E<G!R971E<B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R(")+;VUE;G3A<B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38W"FUS9VED(")#;VUM;VX@
M3F%M92(*;7-G<W1R(")"9;YNZ2!M96YO(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$S,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(D-O;6]R;W,B"FUS
M9W-T<B`B2V]M;W)Y(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B4W!O;&_H;F]SNR(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S
M(@IM<V=S='(@(E!OZ.UT8>AE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(X-@IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(E-T878B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T.0IM<V=I9"`B0V]N9&ET:6]N<R(*
M;7-G<W1R(")3=&%V(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G
M:60@(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B4F]Z9&EE
M;'D@=B!K;VYF:6=U<N%C:6DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,30V"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!
M<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(B(*(DMO;F9I
M9W5RX6-I82!P<F4@<WEN8VAR;VYI>N%C:74@<R!01$$L(&EN=&5L:6=E;G1N
M_6UI('1E;&5F\VYM:2!A($]U=&QO;VMO;2XB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3,U"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D
M871E+B(*;7-G<W1R(")+;VYF:6=U<N%C:6$@<&]T<F5B=6IE(&%K='5A;&EZ
MX6-I=2XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R(")+;VYF:6=U<F]V
M8;L@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q
M"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(E!O='9R[W1E(&AE
M<VQO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4U(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B2V]N9V\B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C8P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG
M;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(D1E
M;6]K<F%T:6-KX2!R97!U8FQI:V$@2V]N9V\B"@HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,3DY(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R
M(")3<&]J96YI92!Z;'EH86QO+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ.3D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R(")3<&]J
M96YI92!Z;'EH86QO.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW
M.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BXB"FUS9W-T<B`B2[7ZZ"!B;VP@>F%M:65T;G5T_2!S97)V97)O
M;2!V97)E:F[]8V@@:[7ZZ&]V+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S
M960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*
M;7-G<W1R(")+M?KH(&)O;"!Z86UI971N=73]('-E<G9E<F]M('9E<F5J;OUC
M:"!KM?KH;W8N($3T=F]D.B`E<R`H)7,I(@H*(SH@;&EB+U9&4R]F='`N<&AP
M.C@V-0IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB
M"FUS9W-T<B`B4W!O:F5N:64@<R!&5%`@<V5R=F5R;VT@>FQY:&%L;RXB"@HC
M.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`Q-`IM<V=I9"`B0V]N=&%C=',B
M"FUS9W-T<B`B2V]N=&%K='DB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL
M>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B2V]N=&%K
M='D@8F]L:2#Z<W!EN6YE('9L;[YE;N$@9&\@5N&Y:&\@861R97/A<F$N(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-C`*;7-G:60@(D-O
M;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z("(*;7-G<W1R(")4>7`@
M:V]M<')I;6]V86[I:&\@<_IB;W)U.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]R87(N<&AP.C4V(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP
M.C8S"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<U"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R(")/
M8G-A:"!<(B5S7"(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR
M.2!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I
M;G5E(@IM<V=S='(@(E!O:W)AZ&]V8;LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B
M"FUS9W-T<B`B0V]O:V]V92!O<W1R;W9Y(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,R"FUS9VED(")#;V]K:64B"FUS9W-T<B`B0V]O:VEE(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@(DMO<.UR;W9ANR(*"B,Z(&QI8B]6
M1E,O<VUB+G!H<#HT-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL
M960Z("5S(@IM<V=S='(@(DMO<.UR;W9A;FEE('IL>6AA;&\Z("5S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I
M9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B2V]P[7)O=F&[(';]8F5R(@H*
M(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$W,"!L:6(O3F5T+U--4R]W
M:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G
M:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B2V]S=&%R:6MA(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C4W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HV,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T
M92!D)TEV;VER92(*;7-G<W1R(")0;V)R9;YI92!S;&]N;W9I;GDB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY-S<*;7-G:60@(D-O=6QD(&YO="!0
M1U`@96YC<GEP="!M97-S86=E.B`B"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!Z
M8;EI9G)O=F&[('-P<N%V=2!P;VUO8V]U(%!'4#H@(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z,3`U-0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N
M(&UE<W-A9V4Z("(*;7-G<W1R(").97!O9&%R:6QO('-A('!O9'#M<V&[('-P
M<N%V=2!P;VUO8V]U(%!'4#H@(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S
M86=E+B(*;7-G<W1R(").97!O9&%R:6QO('-A('IAN6EF<F]V8;L@<W!RX79U
M('!O;6]C;W4@4R]-24U%+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB
M"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!P;V1P[7-ANR!S<'+A=G4@<&]M;V-O
M=2!3+TU)344N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A
M8W0N("5S(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@<')I9&&[(&MO;G1A:W0N
M("5S+B(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HY-B!L:6(O2&]R
M9&4O075T:"]L9&%P+G!H<#HQ,C$*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O
M($Q$05`@<V5R=F5R+B(*;7-G<W1R(").97!O9&%R:6QO('-A('!R:7!O:FF[
M(&L@3$1!4"!S97)V97)U+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT
M-3<*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R(@IM<V=S
M='(@(DYE<&]D87)I;&\@<V$@<')I<&]J:;L@:R!,1$%0('-E<G9E<G4B"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R(").97!O
M9&%R:6QO('-A(&]V97)INR!Z;W-T871O:R!N82#ZZ'1E+B`E<R(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HT-#$*;7-G:60@(D-O=6QD(&YO="!C;VYN
M96-T('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@<')I
M('!R[7-T=7!E(&L@3$1!4"!S97)V97)U(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN
M96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R(").
M97!O9&%R:6QO('-A('!R:7!O:FF[(&L@<V5R=F5R=2!<(B5S7"(@<&]M;V-O
M=2!&5%`Z("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").97!O9&%R:6QO('-A('9Y
M='9O<FF[('IO>FYA;2!P<NUJ96UC;W8N("5S(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z,3$R.`IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0
M(&1A=&$Z("(*;7-G<W1R(").97!O9&%R:6QO('-A(&1EN6EF<F]V8;L@4$=0
M(/ID86IE.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4R,PIM
M<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@
M(DYE<&]D87)I;&\@<V$@9&6Y:69R;W9ANR!3+TU)344@^F1A:F4N(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S
M='(@(DYE<&]D87)I;&\@<V$@=GEM87IANR!K;VYT86MT+B`E<R(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,B"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!V>6UA>F&[('IO>FYA;2!P<NUJ
M96UC;W8N("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R
M861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@=GEM
M87IANR!S:W)I<'0@;F$@=7!G<F%D92!K;VYF:6=U<N%C:64@7"(E<UPB+B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S@Q(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T
M:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(DYE<&]D
M87)I;&\@<V$@=7+H:;L@92UM86EL;W;Z(&%D<F5S=2!P<NUJ96UC=2XB"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#
M;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R
M(").97!O9&%R:6QO('-A('-T:6%H;G6[(&-E;/T@861R97/A<BXB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L
M9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S
M='(@(DYE<&]D87)I;&\@<V$@>NUS:V&[(&MO;7!L971N_2!Z;WIN86T@<'+M
M:F5M8V]V+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT
M-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O
M9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@
M>NUS:V&[(&MO;7!L971N_2!Z;WIN86T@>F]Z;F%M;W8@<'+M:F5M8V]V+B(*
M"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z
M-C@*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP
M.C@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T
M96=Y(%PB)7-<(BXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!N8>CM=&&[('-T
M<F%TZ6=I=2!<(B5S7"(N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(DYE
M<&]D87)I;&\@<V$@<W!U<W1INR!M:V1I<B!<(B5S7"(N(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN
M('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R(").97!O
M9&%R:6QO('-A('KM<VMANR!V97)E:F[](&NU^N@@>F\@<V5R=F5R82!KM?KH
M;W8N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O
M<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S
M82!O='9O<FF[(%PB)7-<(B!P<F4@>N%P:7,N(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8W-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,T-0HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,C8R
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G
M<W1R(").97!O9&%R:6QO('-A(&]T=F]R:;L@)7,N(@H*(SH@;&EB+TAO<F1E
M+TUA:6YT96YA;F-E+G!H<#HT,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T
M<B`B3F5P;V1A<FEL;R!S82!O='9O<FF[(&UO9'5L($UA:6YT96YA;F-E7U1A
M<VL@)7,B"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(").97!O9&%R:6QO('-A
M(&]T=F]R:;L@861R97/A<B!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T=R;W5P
M+VQD87`N<&AP.C$Q,2!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z
M(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HR,S<@;&EB+TAO<F1E+T=R;W5P
M+VQD87`N<&AP.C0W.`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-3$V
M(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@;&EB+TAO<F1E+T=R
M;W5P+VQD87`N<&AP.C8U-B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-CDY
M"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G
M<W1R(").97!O9&%R:6QO('-A('!R:7!O:FF[(&YA($Q$05`@<V5R=F5R+B(*
M"B,Z(&QI8B]61E,O3V)J96-T+G!H<#HR-#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@
M<')EZ.UT8;L@)7,N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R
M('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E
M=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP
M+B(*;7-G<W1R("(B"B).97!O9&%R:6QO('-A(&]B;F]V:;L@:&5S;&\@>F%D
M86[I:&\@<&]UONUV871EM6$N($YI96MT;W+I(&%L96)O(':Y971K>2`B"B)P
M;V1R;V)N;W-T:2!N:64@<_H@<W!RX79N92X@4VOZ<W1E('1O('IN;W9U(&%L
M96)O(&MO;G1A:W1U:G1E(%;AN6AO("(*(F%D;6EN:7-T<N%T;W)A+"!A:R!P
M;W1R96)U:F5T92!P;VUO8RXB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S`Y(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M-#`*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-R!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS.#D*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!!0TPB"FUS9W-T<B`B3F5M;[YN;R!Z[7-K8;L@04-,(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*
M;7-G<W1R(").97!O9&%R:6QO('-A('KM<VMANR!A9')E<^%R+B`E<R(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<R(*;7-G<W1R(").97!O9&%R:6QO('-A('KM<VMANR!Z;WIN86T@
M<'+M:F5M8V]V+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B3F5P;V1A<FEL
M;R!S82!Z[7-K8;L@>F]Z;F%M>2!P<NUJ96UC;W8@)7,B"@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HR,3D*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C(R,PIM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S
M(&-A<&%B:6QI=&EE<R(*;7-G<W1R(").96UOOFYO('KM<VMANR!I;F9O<FWA
M8VEE(&\@=FQA<W1N;W-T:6%C:"!S97)V97)A(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R(").97!O9&%R:6QO('-A('9RX71INR!K;VYF:6=U
M<N%C:74N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!S<'5S=&F[
M(')M9&ER(%PB)7-<(BXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R(").97!O9&%R:6QO('-A('5L;[YINR!K;VYF
M:6=U<N%C:74@)7,N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@<V%V
M92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(DYE<&]D87)I;&\@
M<V$@=6QOOFF[('KA;&]H=2!K;VYF:6=U<N%C:64N(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B3F5P
M;V1A<FEL;R!S82!U;&^^:;L@>N%L;VAU(&MO;F9I9W5RX6-I93H@)7,B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@
M7"(E<UPB+B(*;7-G<W1R(").97!O9&%R:6QO('-A('5L;[YINR!S:W)I<'0@
M;F$@=7!G<F%D92!N87-T879E;NT@9&\Z(%PB)7-<(BXB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*
M;7-G<W1R(").97!O9&%R:6QO('-A('5L;[YINR!ZX6QO:'4@:V]N9FEG=7+A
M8VEE("5S+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R
M871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@
M(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P
M>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@HB
M3F5P;V1A<FEL;R!S82!Z87#M<V&[(&MO;F9I9W5R8>AN_2!S^F)O<B`E<RX@
M3?2^971E('!O=;YINR!N:65K=&]R^B!Z("(*(FUOOFYO<W3M(&YA('KA<&ES
M(&OS9'4@;F$@)7,@86QE8F\@<VMO<.UR;W9ANR!R=>AN92!K\V0@=79E9&5N
M_2!N:;ZY:64@9&\@)7,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z
M,30S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB
M"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!HM6%D8;L@;F$@3$1!4"!S97)V97)I
M+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C@V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI
M;FL@7"(E<UPB+B(*;7-G<W1R(").97!O9&%R:6QO('-A('9Y;6%Z8;L@7"(E
M<UPB+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T
M+B`E<R(*;7-G<W1R(").97!O9&%R:6QO('-A(&%K='5A;&EZ;W9ANR!K;VYT
M86MT+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS
M.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!A:W1U
M86QI>F]V8;L@>F]Z;F%M('!R[6IE;6-O=BX@)7,B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B
M3F5P;V1A<FEL;R!S82!Z87#M<V&[(&MO;F9I9W5RX6-I=2!P<F4@7"(E<UPB
M.B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S`*;7-G:60@(D-O
M=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H
M92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(DYE;6^^;F\@;N%J<[L@0F_H
M;OT@<&%N96P@36]Z:6QL>2X@4VMO;G1R;VQU:G1E+""^92!J92!P86YE;"!O
M='9O<F5N_2XB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E
M<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@
M7"(E<UPB.B`E<R(*;7-G<W1R("(B"B)0;W6^[79A=&6U;W9I(%PB)7-<(B!S
M82!N97!O9&%R:6QO('!R:61ANR!P<N%V82!P<F4@<')I9>AI;F]K(%PB)7-<
M(CH@)7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R,PIM<V=I9"`B0V]U
M;G1E9"!T97AT(@IM<V=S='(@(E!OZ.UT86[]('1E>'0B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R
M(")+<F%J:6YA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W-0IM
M<V=I9"`B0V]U<G-E<R(*;7-G<W1R(")+=7)Z>2(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I
M9"`B0W)E871E(@IM<V=S='(@(E9Y='9O<FF[(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#
M<F5A=&4@82!L:6YK(@IM<V=S='(@(E9Y='9O<FF[(&QI;FMU(@H*(SH@=&5M
M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E
M871E(&$@;F5W(&]N92(*;7-G<W1R(")6>71V;W)INR!N;W;](@H*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@
M<W5B(&9O;&1E<G,B"FUS9W-T<B`B5GET=F]R:;L@<&]D<')I9>AI;F]K(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B4'+A=F$@='9O<F-U(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,R,3D*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*
M;7-G<W1R("+([7-L;R!K<F5D:71N96H@:V%R='DB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV
M-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I
M82(*;7-G<W1R(")#:&]R=N%T<VMO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C8T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R(")+
M=6)A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R96YT
M(#0@4&AA<V5S(@IM<V=S='(@(D%K='7A;&YE(#0@9N%Z>2(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HU,`IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G
M<W1R(")!:W1UX6QN92!S961E;FEA(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP
M.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B
M"FUS9W-T<B`B06MT=>%L;GD@Z&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT
M(%523"!I<R(*;7-G<W1R(")!:W1UX6QN82!54DP@:F4B"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z,S4*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`B
M06MT=>%L;FD@<&]UONUV871E;&EA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(D%K='7A;&YE
M('!OZ&%S:64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8T
M"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@(D%K='7A;&YE
M('!O9&UI96YK>3H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R(")!
M:W1UX6QN>2"Y=/UL(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P
M;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(DYA<W1A=F5N:64@^FQO:"P@:W1O
M<ND@<V$@<W#ZN;MA:OH@<')I('!R:6ALX7-E;NT@9&\@87!L:6OA8VEE("5S
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(E9Y<W1R:6AN^KLB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS
M9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(E9Y<W1R:6AN^KL@=OUB97(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C8V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X
M"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B0WEP<G5S(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#>7)I
M;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X,`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX
M+54I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@
M(LAE<VOA(')E<'5B;&EK82(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@
M(D1$(@IM<V=S='(@(D1$(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S`*
M;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L
M+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T
M<B`B(@HB1%-.("AP;WIR:2!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E
M;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@H*(SH@;&EB
M+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T
M<B`B1&5N;F4B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A
M=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B4')E>F5R8>@@9.%T;W;I:&\@<W1R
M;VUU("A$871A5')E92DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(V.`IM
M<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(E9Y:+5A9.%V86YI92!V
M(&1A=&%BX7IE(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,#(@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(*;7-G:60@(D1A=&4B"FUS
M9W-T<B`B1.%T=6TB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R(")$X71U;2!P
M<FEJ871I82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-SDV"FUS9VED(")$
M871E('-E;&5C=&EO;B(*;7-G<W1R(")6_6)E<B!DX71U;74B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,3$*;7-G:60@(D1A>2(*;7-G<W1R(")$9?(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(D]?9'-T<N%N:;L@
M<W3E<&5C(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G
M:60@(D1E8V5M8F5R(@IM<V=S='(@(D1E8V5M8F5R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I
M9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(D1E<VEA=&MO=ND@Z.US;&$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P
M"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B6FUE;KEINR!O9'-A
M9&5N:64B"@HC.B!L:6(O<')E9G,N<&AP.C$Q-R!L:6(O2&]R9&4O4')E9G,O
M54DN<&AP.C$X-PIM<V=I9"`B1&5F875L="(*;7-G<W1R(")0<F5D;F%S=&%V
M96[I(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-S<*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B4')E9&YA<W1A
M=F5NX2!F87)B82(*"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z.38*;7-G
M:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B5F&Y82!P<F5D;F%S=&%V
M96[A(&ED96YT:71A(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"FUS
M9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(E!R961N87-T879E;OT@<'+M
M:V%Z;W;](&EN=&5R<')E=&5R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,S"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R(")$969I;NUC:64B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&QI8B](;W)D92]097)M<RYP:'`Z,S(V
M(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(R"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z-#,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,"!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.CDS"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3@R('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHW,PHC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`B
M5GEM87IANR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`B
M5GEM87IANR!B=6YK=2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D;6EN
M+V=R;W5P<RYP:'`Z,C(W"FUS9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B
M5GEM87IANR!S:W5P:6YU(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C0Y"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@(E9Y;6%Z8;L@>N%Z
M;F%M(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HW-R!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS
M9W-T<B`B5GEM87IANR!P<N%V;R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E
M<R(*;7-G<W1R(")6>6UA>F&[(&$@;V1S='+A;FF[('-P<N%V>2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*
M;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(E9Y;6%Z8;L@8G5N:W4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8S"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(E9Y;6%Z8;L@<W3E
M<&5C(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T
M92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B5GEM87IA
MNR!E>&ES='5J^F-U(&%L=&5R;F%T[79N=2"Y86)L\VYU(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B5GEM87IANR!P
M<N%V82!P<F4@7"(E<UPB(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT
M,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O
M<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(D-H
M8V5T92!V>6UA>F&[(%PB)7-<(B!A(':Y971K>2!J96AO('!O9'!RX79A/R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`B5GEM87IANR!R:6%D
M;VLB"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U
M"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B5GEM
M87IANR!V>6)R86[Z(&ED96YT:71U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@
M=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(E9Y;6%Z8;L@86MT=>%L;GD@
M<W3E<&5C(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W
M(@IM<V=S='(@(E9Y;6%Z8;L@86MT=>%L;GD@<FEA9&]K(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(E-K
M<FEP="!N82!U<&=R861E(&MO;F9I9W5RX6-I92!<(B5S7"(@8F]L('9Y;6%Z
M86[]+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,2!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(U,PIM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G
M<W1R("+(87,@9&]R=>AE;FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C<Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R(")$
MX6YS:V\B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM
M<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B4&]P[;ET92!P
M<F]B;.EM(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDT,B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"FUS9VED(")$
M97-C<FEP=&EO;B(*;7-G<W1R(")0;W!I<R(*"B,Z(&QI8B](;W)D92YP:'`Z
M,3DW"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ
M(@IM<V=S='(@(E!O9')O8FYO<W1I("AT:66^('8@;&]G;W9A8V]M('/Z8F]R
M92!(;W)D92DB"@HC.B!L:6(O2&]R9&4N<&AP.C(P,0IM<V=I9"`B1&5T86EL
M<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS
M9W-T<B`B1&5T86EL>2!B;VQI('IA>FYA;65N86[I('!R92!A9&UI;FES='+A
M=&]R82XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(Q"FUS9VED
M(")$979E;&]P;65N="(*;7-G<W1R(")6_79O:B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C$W"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B4F]S;OT@
M8F]D(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.30*;7-G:60@(D1E=R!0
M;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B4F]S;OT@8F]D('IA('!O
M<VQE9&[Z(&AO9&EN=3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(Q-@IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B4F]S;OT@8F]D
M.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R(")3
M;65R('JU879A(&1O<')A=F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@
M;&5F="(*;7-G<W1R(")3;65R('-P<F%V82!D;[5A=F$B"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(D%D
M<F5SX7(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<P"FUS9VED(")$
M:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(EIO8G)A>F]V8;L@Z&%S
M('8@,C0M:&]D:6YO=F]M(&9O<FWA=&4_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(DYA
M<W1A=F5N:64@>F]B<F%Z96YI82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HX.0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*
M;7-G<W1R("):;V)R87IINR!P;V1R;V)N^B!P<F5D<&]V9>\B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C@U"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4
M048I(@IM<V=S='(@(EIO8G)A>FF[('!R961P;W9E[R`H5$%&*2(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR.#`V"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*
M;7-G<W1R(")&;W)MX70@>F]B<F%Z96YI82(*"B,Z(&QI8B](;W)D92]-24U%
M+TU$3BYP:'`Z,3DP"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB
M"FUS9W-T<B`B4&]T=G)D96YI92!O(&1O<G7H96[M(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C<P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV
M.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U
M=&DB"FUS9W-T<B`B1+YI8G5T<VMO(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HT,C(*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B3F5V>6UA
M>F&[(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$
M;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R
M(").97!O=;[M=F%J=&4@<')I86UO(&UA:6YT96YA;F-E+G!H<"(*"B,Z('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$R('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I
M;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM
M<V=S='(@(D]B<V%H=6IE('!R=OT@<FEA9&]K(&[A>G9Y('!O;.T_($%K(.%N
M;RP@>F&Y:W)T;FET92!P;VSMZ&MO.B`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G
M<W1R(")$;VUI;FEC82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G
M<W1R(")$;VUI;FEKX6YS:V$@<F5P=6)L:6MA(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT
M/R!3:6=N('5P+B(*;7-G<W1R(").96WA=&4@^NAE=#\@6F%R96=I<W1R=6IT
M92!S82XB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#4Q"FUS
M9VED(")$;W=N;&]A9"(*;7-G<W1R(")3=&EA:&YUNR(*"B,Z(&QI8B](;W)D
M92]-24U%+T-O;G1E;G1S+G!H<#HX-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1&]W;FQO860@)7,B"FUS9W-T<B`B4W1I86AN=;L@)7,B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@
M8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R(")3=&EA:&YU
MNR!V>6=E;F5R;W9A;OH@:V]N9FEG=7+A8VEU(&%K;R!02%`@<VMR:7!T+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3$Q"FUS9VED(")$<F]P(&1O=VX@
M;&ES="(*;7-G<W1R("):;WIN86T@<R!V_6)E<F]M(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R(")$<F]G>2(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B12U-86EL
M(@IM<V=S='(@(D4M;6%I;"(*"B,Z(&QI8B].970O4TU3+V=E;F5R:6-?<VUT
M<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@
M9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R(")%4E(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C<R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%
M8W5A9&]R(@IM<V=S='(@(D5K=N%D;W(B"@HC.B!L:6(O2&]R9&4O4&5R;7,N
M<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="(*
M;7-G<W1R(")5<')A=FF[(@H*(SH@;&EB+TAO<F1E+T)L;V-K+U5)+G!H<#HU
M,"!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET($)L
M;V-K(@IM<V=S='(@(E5P<F%V:;L@8FQO:R(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%9&ET($=R;W5P
M(@IM<V=S='(@(E5P<F%V:;L@<VMU<&EN=2(*"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z-S8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@
M(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R(")5<')A=FF[('!RX79O(@H*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M
M:7-S:6]N<R(*;7-G<W1R(")5<')A=FF[('!RX79A(@H*(SH@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET
M(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R(")5<')A=FF[('!RX79A('!R
M92`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D
M:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(E5P<F%V:;L@;F%S=&%V96YI82!P
M<F4Z(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S
M='(@(E5P<F%V:;L@<'+A=F$@<')E(%PB)7-<(B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P
M97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B57!R879INR!P<N%V82!P<F4@
M)7,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A
M=&EO;B(*;7-G<W1R(")6>F1E;.%V86YI92(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HW-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S
M='(@(D5G>7!T(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R(")386QV
MX61O<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R(")%;&5M
M96YT+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(D5M(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$X-S,@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HR,C0*;7-G:60@(D5M86EL(@IM<V=S='(@(D5M86EL(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C8@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C8X"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D5M86EL;W;A
M(&%D<F5S83HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DV-PIM<V=I9"`B
M16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(D4M;6%I;&]V
MZ2!A9')E<WD@;75S:6$@8GF[(')O=FYA:^DN(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$Y.3,*;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM
M<V=S='(@(D4M;6%I;"!S('!O='9R9&5N[6TB"@HC.B!L:6(O3F5T+U--4R]G
M96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A
M>2(*;7-G<W1R(")"<N%N82!%;6%I;"UN82U335,B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDW"FUS9VED(")%;6]T:6-O;G,B
M"FUS9W-T<B`B16UO=&EK;VYY(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@
M(E!RX7ID;F$@<W!RX79A+B(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H
M<#HR-#,@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!L:6(O2&]R
M9&4O1W)O=7`O;&1A<"YP:'`Z-C8R(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H
M<#HW,#4*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%
M;7!T>2!R97-U;'0N(@IM<V=S='(@(E!RX7ID;GD@=OUS;&5D;VLN(@H*(SH@
M;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S
M96%R8V@@=&5R;7,B"FUS9W-T<B`B4'+A>F1N92!P;V1M:65N:WD@:+5A9&%N
M:6$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30W"FUS9VED(")%;F%B
M;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I
M;B!T97AT/R(*;7-G<W1R(")0;W9O;&F[('9L;[YE;FEE(&]B<N%Z:V]V('H@
M1V%LZ7)I[2!D;R!T97AT=3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3(R"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*
M;7-G<W1R(")0;W9O;&F[(&MO;G1E>'1O=ND@;65N=2!P<F4@<')A=ND@=&QA
MZ&ED;&\_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.3(@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(X,#`*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(DMO;FEE
M8R!R;VMA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`B6G;DZ+EI
MNR!E9&ET;W(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(T"FUS9VED
M("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL
M(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O
M<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS
M9W-T<B`B(@HB6F%D86IT92!B97IP9>AN;W-T;OH@;W3A>FMU+"!N82!K=&]R
M^B!B=61E=&4@;75S:66[(&]D<&]V961ANR!A:R!Z86)U9&YE=&4@(@HB:&5S
M;&\L(&YA<'(N("=A:V\@<V$@=F]LX2!M;VIE('IV:65R871K;S\G.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S
M='(@(EIA9&%J=&4@55),(&]B<N%Z:V$B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.#@Y"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R
M<R!B96QO=SHB"FUS9W-T<B`B6F%D86IT92!P[7-M96[A('5V961E;ND@;FF^
MN6EE.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(E)O=F[M
M:V]VX2!'=6EN96$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-SD@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM<V=S='(@(D5R:71R96$B
M"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP
M:'`Z,C<*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0X(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S8*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H
M<#HX,@IM<V=I9"`B17)R;W(B"FUS9W-T<B`B0VAY8F$B"@HC.B!L:6(O2&]R
M9&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B0VAY8F$@<')I('9Y=';A
M<F%N[2!B;&]K=3H@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC
M(&%N8VAO<CH@)7,B"FUS9W-T<B`B0VAY8F$@<')I('9Y;6%ZX79A;NT@=6MO
M='9E;FEA('-Y;F-H<F]N:7KA8VEE.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E
M;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R(")#:'EB82!P<FD@=GEM87KA
M=F%N[2!ZX7IN86UU('-Y;F-H<F]N:7KA8VEE.B`E<R(*"B,Z(&QI8B](;W)D
M92]496UP;&%T92YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`B0VAY8F$@<')I('KM<VMA
M=F%N[2!O8G-A:'4Z("5S(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG('!A
M<W-W;W)D.B`E<R(*;7-G<W1R(")#:'EB82!P<FD@86MT=6%L:7KA8VEI(&AE
M<VQA.B`E<R(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@
M(D-H>6)A('8@92UM86EL;W9E:B!S<'+A=F4N(@H*(SH@;&EB+U9&4R])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R(")#
M:'EB82!P<FD@>F%P:7-O=F%N[2!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C<V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*
M;7-G<W1R(")%<W3S;G-K;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(D5T
M:?-P:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T
M:&YI8R(*;7-G<W1R(")%=&YI8VOI(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R(")%=7+S<&$B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0S"FUS9VED(")%=F5R>2`Q-2!M:6YU
M=&5S(@IM<V=S='(@(DMAOF3]8V@@,34@;6EN^G0B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,SDS"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T
M<B`B2V&^9.D@,B!M:6[Z='DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(D5V97)Y(#,P
M('-E8V]N9',B"FUS9W-T<B`B2V&^9/UC:"`S,"!S96OZ;F0B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S0R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.30*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")+8;YD_6-H(#4@
M;6EN^G0B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED
M(")%=F5R>2!,;V=I;B(*;7-G<W1R(")0<FD@:V&^9&]M('!R:6ALX7-E;NTB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0T"FUS9VED(")%=F5R>2!H
M86QF(&AO=7(B"FUS9W-T<B`B2V&^9/H@<&]L:&]D:6YU(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDR
M"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B2V&^9/H@;6EN^G1U(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP
M;&4@=F%L=65S.B(*;7-G<W1R(").87!R[6ML860Z(@H*(SH@861M:6XO<&AP
M<VAE;&PN<&AP.C@Q(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3(W"FUS9VED(")%>&5C=71E(@IM<V=S='(@(E-P=7-T:;LB
M"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HT-S4*;7-G:60@(D5X
M<&%N9"(*;7-G<W1R(")2;WIB86QINR(*"B,Z('1E;7!L871E<R]P;W)T86PO
M<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@
M(E)O>F)A;&F[($)OZ&[]('!A;F5L(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW
M;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B3^AA
M:^%V82!S82`G*2<B"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ
M-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H
M('1E<FTB"FUS9W-T<B`B3^AA:^%V82!S82!S;&]V;R!A;&5B;R!P;V1M:65N
M:V$@:+5A9&%N:6$@=B#Z=F]D>F]V:^%C:"(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@
M(D3A='5M(&5X<&ERX6-I92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-C<W"FUS9VED(")%>'!O;F5N="(*;7-G<W1R(")%>'!O;F5N="(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(D9A<F)A('1E>'1U(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A9"!O
M9B!S971U<"(*;7-G<W1R(").86AR8;L@:V]N9FEG=7+A8VEU(&YA($944"(*
M"B,Z(&QI8B](;W)D92]0<F5F<R]S<6PN<&AP.C(R-0IM<V=I9"`B1F%I;&5D
M(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(DYE<&]D87)I;&\@
M<V$@>NUS:V&[(&YA<W1A=F5N:6$N(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD
M87`N<&AP.C<U(&QI8B](;W)D92]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&
M86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3F%S
M=&%L82!C:'EB82!P<FD@<W!O:F5N[2!S($Q$05`@<V5R=F5R;VTN(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O
M;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P
M<FD@<'+M<W1U<&4@:R!334(@<V5R=F5R=2XB"@HC.B!L:6(O5D93+V9T<"YP
M:'`Z-S`V"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R
M;VT@7"(E<UPB+B(*;7-G<W1R(").97!O9&%R:6QO('-A(&MO<.UR;W9ANR!Z
M(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S$Q"B,L('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B
M3F5P;V1A<FEL;R!S82!K;W#M<F]V8;L@9&\@7"(E<UPB+B(*"B,Z(&QI8B](
M;W)D92]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@8W)E871E
M(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@
M=GET=F]R:;L@;F]VZ2!305-,('-P;VIE;FEE+B(*"B,Z(&QI8B]61E,O<VUB
M+G!H<#HU,#$@;&EB+U9&4R]F='`N<&AP.C<T-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(DYE<&]D
M87)I;&\@<V$@<')E<W5N^KL@9&\@7"(E<UPB+B(*"B,Z(&QI8B]61E,O<VUB
M+G!H<#HT-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E=')I
M979E.B`E<R(*;7-G<W1R(").97!O9&%R:6QO('-A('KM<VMANSH@)7,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I
M9"`B1F%I<B(*;7-G<W1R(")$;V)RZ2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HX-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N
M9',@*$UA;'9I;F%S*2(*;7-G<W1R(")&86QK;&%N9'-KZ2!O<W1R;W9Y("A-
M86QV[6YY*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B1F%E<G-K
MZ2!O<W1R;W9Y(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z,C,X"FUS9VED(")&
M871A;"!%<G)O<CHB"FUS9W-T<B`B6N%V8;YNX2!C:'EB83HB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM
M<V=S='(@(D9A>"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3$*
M;7-G:60@(D9A>&5S(@IM<V=S='(@(D9A>'DB"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`P(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B1F5B
M<G7A<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(P"FUS9VED(")&965L
M<R!,:6ME(@IM<V=S='(@(E!O8VET('1E<&QO='DB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C(P"FUS9VED(")&965L<R!L:6ME.B`B"FUS
M9W-T<B`B4&]C:70@=&5P;&]T>3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S
M='(@(DUA;.D@>G+AOFMY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T
M<B`B36%LZ2!S;F5H;W;I('!R96CA;FMY(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Y-#@*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R(")-871I8V$@
M<&]L[2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S(S"FUS9VED(")&:6=L
M970@0T%05$-(02(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S,R-PIM<V=I9"`B1FEG;&5T(&9O;G0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C@S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HX,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ
M:2(*;7-G<W1R(")&:62^:2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(U-0IM<V=I9"`B1FEL92(*;7-G<W1R(")3^F)O<B(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8P(&QI8B](;W)D92]-24U%+U9I
M97=E<B]Z:7`N<&AP.C8W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN
M<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I
M;&4B"FUS9W-T<B`B4&_H970@<_IB;W)O=CH@)7,@<_IB;W(B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV,"!L:6(O2&]R9&4O34E-12]6
M:65W97(O>FEP+G!H<#HV-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z
M+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F
M:6QE<R(*;7-G<W1R(")0;^AE="!S^F)O<F]V.B`E<R!S^F)O<F]V(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P.0IM<V=I9"`B1FEL92!-86YA
M9V5R(@IM<V=S='(@(E-P<N%V8V$@<_IB;W)O=B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R87(N<&AP.C8S(&QI8B](;W)D92]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<P"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@R
M"FUS9VED(")&:6QE($YA;64B"FUS9W-T<B`B365N;R!S^F)O<G4B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,CDX-`IM<V=I9"`B1FEL92!S96QE8W1I;VXB
M"FUS9W-T<B`B5OUB97(@<_IB;W)U(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$T.3`*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(DYA:')A=&EE('/Z
M8F]R=2(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX.#4*;7-G:60@(D9I
M;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R(").86ARX79A;FEE
M('/Z8F]R;W8@;FEE(&IE('!O9'!O<F]V86[I+B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HY,0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R(")&:6QT
M<F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C@R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S='(@(D;M;G-K;R(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B
M4')VX2!P;VQO=FEC82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T
M<B`B4')VX2"Y='9RNR(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HR-34*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R(")0979N_2!P
M;VUE<B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,S`*;7-G:60@(D9L:7`B"FUS9W-T<B`B3W1OZ&F[(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B
M1FQO870B"FUS9W-T<B`B4&SA=F%J^F-I('1E>'0B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S
M='(@(DAM;&$B"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,C,W(&QI8B]61E,O;75S
M<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E
M<R!N;W0@97AI<W0B"FUS9W-T<B`B4')I9>AI;F]K("5S(&YE97AI<W1U:F4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R
M"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(D9A<F)A('#M<VUA(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@
M(E!O=')A=F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T
M(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(E!R92!P<F5H;&EA9&'H
M92P@:W1O<ND@;F5P;V1P;W)U:OH@;V)RX7IK>2(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S,T"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R(")0
M<F5D<&]V9>\@*%1!1BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-S(*;7-G:60@(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@
M<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[
M(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED
M92!B;&]C:RDB"FUS9W-T<B`B(@HB4')E9'!O=F7O(&YA('5V961E;OT@<&_H
M970@9&[M("AP86WD=&%J=&4@;F$@=&\L(+YE('!R961P;W9E[R!J92!P<F4@
M9&YI(&%J("(*(FYO8VD@82!T86L@;?2^92!V9;5KZ2#H[7-L;R!V>71V;W)I
MNR!V9;5M:2"Y:7)O:_T@8FQO:RDB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S
M='(@(EIA8G5D;&D@<W1E(&AE<VQO/R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-C0*;7-G:60@(D9O<FUS(@IM<V=S='(@(D9O<FUU;.%R92(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*
M;7-G<W1R(")&;W)T=6YA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY
M"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B5'EP(&9O<G1U;GDB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM
M<V=S='(@(D9O<G1U;GDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*
M;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B1F]R='5N>2`R(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U-0IM<V=I9"`B1F]R=6US(@IM<V=S
M='(@(D;S<F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$Q"FUS
M9VED(")&;W)W87)D<R(*;7-G<W1R(")0<F5S;65R;W9A;FEA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B
M1G(B"FUS9W-T<B`B4&EA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@
M(E+A;6-E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(D9R86YC^GIS:V\B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-
M971R;W!O;&ET86XB"FUS9W-T<B`B1G)A;F/Z>G-K;R`H175R\W!A*2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G
M:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B1G)A;F/Z>G-K82!'=6%Y86YA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B1G)A;F/Z>G-K
M82!0;VQY;NEZ:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O
M<FEE<R(*;7-G<W1R(")&<F%N8_IZ<VME(&IUOF[I('1E<FET\W)IX2(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&
M<F]M(@IM<V=S='(@(D]D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(S-R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0Y"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.34*;7-G:60@(D9R;VT@=&AE
M("(*;7-G<W1R("):;R!S;65R=2`B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R
M("+:<&QN_2!P;W!I<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B
M4W!L;B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&=6QL($YA;64B"FUS
M9W-T<B`B0V5LZ2!M96YO.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(D=A8G5N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O
M;2(*;7-G<W1R(")'86SI<FEA+"!Z(&MT;W)E:B!C:&-E=&4@=GII8;L@;V)R
MX7IO:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B1V%L
MZ7)I83HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.38@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B1V%M8FEA(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'
M96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(D=E;F5R;W9ANR!K
M;VYF:6=U<N%C:74@<')E(&%P;&EKX6-I=2`E<R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D
M92(*;7-G<W1R(")'96YE<F]V86[](&OS9"(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HY,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS
M9W-T<B`B1V5O<F=I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B3F5M96-K
M;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S4*;7-G:60@(D=H86YA(@IM<V=S='(@(D=H86YA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.CDT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY
M,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L
M=&%R(@IM<V=S='(@(D=I8G)A;'3A<B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3<V"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(DMR<W1N
MZ2!M96YO(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3(*;7-G:60@
M(D=O(@IM<V=S='(@(D]D;W-L8;LB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R(")';V5D96PB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R.`IM<V=I9"`B1V]O
M9VQE($UA<',B"FUS9W-T<B`B1V]O9VQE($UA<',B"@HC.B!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C
M:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@
M(DBU861ANR!N82!';V]G;&4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C,V"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B3V1T
M:65N92"Y961E:B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B1W+I8VMO(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D=R965K("A)4T\M
M.#@U.2TW*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B
M1W+S;G-K;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B1W)E;F%D82(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A
M=&EO;B(*;7-G<W1R(")!9&UI;FES='+A8VEA('-K=7#M;B(*"B,Z(&QI8B](
M;W)D92]'<F]U<"YP:'`Z-3D@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$V
M.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T
M<B`B365NX2!S:W5P[6X@;F5S;?H@8GF[('!RX7ID;F4B"@HC.B!L:6(O2&]R
M9&4O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L('!H<"UF;W)M870*;7-G:60@(D=R
M;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R(")'<F]U<%]L9&%P.B!.97!O
M9&%R:6QO('-A('!R:61ANR!S:W5P:6YU("5S+B!397)V97(@;V1P;W9E9&%L
M.B`B"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,3$X(&QI8B](;W)D
M92]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N
M<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD87`Z(&YE
M<&]D87)I;&\@<V$@=GEM87IANR!S:W5P:6YU("5S(@H*(SH@;&EB+TAO<F1E
M+T=R;W5P+VQD87`N<&AP.C,S."!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z
M,S<Y"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T
M;R!U<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@;F5P;V1A
M<FEL;R!S82!A:W1U86QI>F]V8;L@<VMU<&EN=2`E<R(*"B,Z(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B
M"FUS9W-T<B`B4VMU<&EN>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B
M1W5A9&5L;W5P92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(D=U86TB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`R(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HY.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I
M9"`B1W5A=&5M86QA(@IM<V=S='(@(D=U871E;6%L82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B1W5E
M<FYS97DB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'=65S="!097)M:7-S:6]N
M<R(*;7-G<W1R(")0<N%V82!A;F]N>6UN_6-H('!O=;[M=F%T9;5O=B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S(*;7-G:60@(D=U97-T8F]O
M:R(*;7-G<W1R(")'=65S=&)O;VLB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B
M1W5I;F5A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<X"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(D=U:6YE
M82U":7-S874B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R(")'=7EA;F$B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.38T"FUS9VED(")(5$U,(@IM<V=S='(@
M(DA434PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B2%1-
M3$%R96$@;F5D;W9O;.T@=GEM87IANR!P;W-L961N^B!B=6YK=2!V(')I861K
M=2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O
M(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(DA4
M34Q!<F5A(&YE9&]V;VSM('9Y;6%Z8;L@<&]S;&5D;OT@<W3E<&5C('8@=&%B
M=;5K92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(DA4
M34Q!<F5A(&YE9&]V;VSM('9Y;6%Z8;L@<&]S;&5D;OT@<FEA9&]K('8@=&%B
M=;5K92XB"@HC.B!L:6(O2&]R9&4O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@
M(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")(5%10
M(&%U=&5N=&EF:6OA8VEA(&YE8F]L82!NX6ID96[A+B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$P,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2&%I
M=&DB"FUS9W-T<B`B2&%I=&DB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(D%L9V]R:71M
M=7,@:&%S:&]V86-E:B!F=6YK8VEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B3W!A
M<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY,C,@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(Y,C$*;7-G:60@(DAE861E<B(*;7-G<W1R(")(;&%V:>AK82(*"B,Z
M(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"FUS9VED(")(
M96%D97)S(@IM<V=S='(@(DAL879IZ&MY(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$P-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA
M;F0@86YD($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B2&5A<F1O=B!O<W1R
M;W8@82!-8T1O;F%L9&]V92!O<W1R;W9Y(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*;7-G:60@(DAE879Y(%0M4W1O<FTB
M"FUS9W-T<B`B4VEL;N$@8OIR:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X,@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R(")6_;EK82(*"B,Z(&QI8B](
M;W)D92](96QP+G!H<#HQ.#0@;&EB+TAO<F1E+TAE;'`N<&AP.C$X-B!S97)V
M:6-E<R]H96QP+VEN9&5X+G!H<#HQ-PHC.B!T96UP;&%T97,O:&5L<"]I;F1E
M>"YI;F,Z-`IM<V=I9"`B2&5L<"(*;7-G<W1R(")0;VUO8V[M:R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@
M(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(E!O;6]C;NUK('!R92!P;W6^
M[79A;FEE(&5D:71O<F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W-0IM
M<V=I9"`B2&5L<&5R(@IM<V=S='(@(E!O;6]C;NUK(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@(E!O;&]G
M=;5A(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E
M9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B5'4@:F4@>F'H:6%T;VL@
M<_IB;W)U.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8Y"FUS9VED(")(:6=H(@IM<V=S='(@(E9Y<V]KX2(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N
M+6AE861E<BYI;F,Z-0IM<V=I9"`B2&]?;64B"FUS9W-T<B`B1&]?;6]V(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T
M<B`B5F%T:6OA;B(*"B,Z(&QI8B](;W)D92YP:'`Z,34S.0IM<V=I9"`B2&]M
M92(*;7-G<W1R(")$;VUO=B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3(R(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`B1&]MX6-A(&%D<F5S
M82(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`IM<V=I9"`B2&]M92!$
M:7)E8W1O<GDB"FUS9W-T<B`B1&]MX6-I('!R:67H:6YO:R(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H
M;VYE(@IM<V=S='(@(E1E;&5F\VX@9&]M;W8B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3`X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#4*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S
M(@IM<V=S='(@(DAO;F1U<F%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$P-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T
M<B`B2&]N9R!+;VYG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8W
M"FUS9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z(&QI8B](;W)D92]+
M;VQA8BYP:'`Z-#0R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@
M)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z('8@<W!RX79E("5S(&)O;&D@;N%J
M9&5NZ2!N97!L871NZ2`E<R!834P@^F1A:F4B"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B
M2&]R9&4O2V]L86(Z(',@;V)J96MT;VT@)7,@;F5K;W)EN7!O;F1U:F4@OFEA
M9&YA('-P<N%V82XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0S-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y
M<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA
M8CH@=B!S<'+A=F4@)7,@;F5B;VP@;N%J9&5N_2"^:6%D96X@;V)J96MT('1Y
M<'4@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$R-#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D
M("5S(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@^G-P9;EN92!O9'-T
M<N%N96[I("5S(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,C(S
M"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R
M97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@:6YT96=RX6-I82!V>;YA9'5J92!02%`@<F]ZN>UR96YI
M92`G9&]M>&UL)R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-3`R"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E
M(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B!N97!O9&%R:6QO('-A('9Y='9O<FF[(&YO=OT@6$U,('-T<F]M('!R
M92!O8FIE:W0@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$R-#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO
M=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@;F5P;V1A
M<FEL;R!S82!O9'-T<N%N:;L@)7,@7"(E<UPB.B`E<R(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z-#<S"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@
M;V8@='EP92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@;F5P;V1A<FEL;R!S
M82!Z[7-K8;L@34E-12!)1"!P<F4@Z&%SNR!T>7!U("5S(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HQ,3DR"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*
M;7-G<W1R(")(;W)D92]+;VQA8CH@;F5P;V1A<FEL;R!S82!S>6YC:')O;FEZ
M;W9ANR`E<R!<(B5S7"(Z("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ
M,S,R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA
M8CH@;F5P;V1A<FEL;R!S82!S>6YC:')O;FEZ;W9ANR!Z9&EEM6%NZ2!O8FIE
M:W1Y.B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<
M(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@;F5Z;N%M>2!Z9&EEM6%N_2!O8FIE
M:W0@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(DAO
M<FEZ;VYTX6QN82#H:6%R82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*
M;7-G<W1R(")(;W)I>F]N=.%L;F4@=GEP;&YE;FEE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO
M;G1A;#HB"FUS9W-T<B`B2&]R:7IO;G3A;&YE.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B
M2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T
M<B`B06MO('-T92!S82!S96T@9&]S=&%L:3\@*%!R;W/M;2!N86ALX7-T92$I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\B"FUS9W-T<B`B2V^U:V\@<W3E<&-O=B!C:&-E=&4@>FSZ
MZ&F[/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED
M(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T
M<B`B6F%D86IT92!P;^AE="!P;VSM("AS=.5P8V]V*3\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED
M(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G
M<W1R(")+;[5K;R!R:6%D:V]V(&-H8V5T92!Z;/KH:;L_(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(X.2!L:6(O0FQO8VLO;65T87(N<&AP
M.C(S,`IM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B5FQH:V]SNR(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@*;7-G:60@(DAU;6ED:71Y
M.B`B"FUS9W-T<B`B5FQH:V]SNSH@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B2'5M;W)I<W1I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P
M"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(DUA[V%R<VMO(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O8WER=7,N<&AP.C$W,B!L:6(O2&]R9&4O075T:"]C>7)S<6PN
M<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E
M871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(").97!O9&%R:6QO('-A('9Y='9O
M<FF[($E-05`@<V-H<N%N:W4Z("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER
M=7,N<&AP.C(Q-"!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D
M.B`E<R(*;7-G<W1R(").97!O9&%R:6QO('-A('9Y;6%Z8;L@24U!4"!S8VAR
MX6YK=3H@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3<Y(&QI
M8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G
M:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM
M<V=S='(@(DYE<&]D87)I;&\@<V$@=GET=F]R:;L@24U!4"!K=O-T=3H@)7,B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,R,`IM<V=I9"`B25`@061D<F5S
M<R(*;7-G<W1R("))4"!A9')E<V$B"@HC.B!L:6(O2&]R9&4O075T:"]I<&)A
M<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R("))4"!A9')E<V$@;FEE(&IE(&1O<W1U<&[A+B(*"B,Z(&QI8B](
M;W)D92]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO
M="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("))4"!A9')E
M<V$@;FEE(&IE('8@<N%M8VD@9&]V;VQE;NEH;R!#2412(&)L;VMU+B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))
M4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(E!O<G6Y96YI92!P<F%V
M:61L82!O('!E=FYE:B!)4"!A9')E<V4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS
M97)T(%)O=R!"969O<F4B"FUS9W-T<B`B5FQOOFF[(&NU^N@@7W!R960B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(P(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*
M;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B27-L86YD(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,X,`IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R("))
M8F$@:6MO;GDB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(DEK;VYY('!R
M92`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#$*;7-G:60@(DEC
M;VYS('=I=&@@=&5X="(*;7-G<W1R(")):V]N>2!A('1E>'0B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3DS"FUS9VED("))9&5N=&ET>2=S(&YA;64Z
M(@IM<V=S='(@(D[A>F]V(&ED96YT:71Y.B(*"B,Z(&QI8B](;W)D92]-24U%
M+T-O;G1E;G1S+G!H<#HU.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@
M:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@
M82!N97<@=VEN9&]W+B(*;7-G<W1R(")!:R!S82!N97IO8G)A>NT@:V]R96MT
M;F4L("5S(&$@;W1V;W+M('-A('8@;F]V;VT@;VMN92XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#4Y"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E
M(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N
M965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N
M<W!A<F5N8WDN(@IM<V=S='(@(B(*(D%K(&YE=FED[71E('!R:2!P;W6^:73M
M($EN=&5R;F5T($5X<&QO<F5R82"^:6%D;F4@:6MO;GDL('!O=')E8G5J971E
M("(*(GIAN6MR=&[ZNR!T^G1O('9OM6)U('!R92!V>7!N=71I92!P<FEE<W9I
M=&YO<W1I(%!.1R!O8G+A>FMO=BXB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3<R"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@
M;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U
M<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB
M"FUS9W-T<B`B(@HB06L@=FED[71E('3Z=&\@<W!RX79U(&$@;F5V:63M=&4@
M;V)RX7IO:RP@;V)RX7IO:RP@:W1O<OT@<W1E(&-H8V5L:2!N86AR8;LL("(*
M(FYE;?2^92!B>;L@>F]B<F%Z96[]('9O(%9AN6]M('!R96AL:6%D8>AI+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B56OA
MOFMA(&]B<N%Z:V$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@
M(E523"!O8G+A>FMA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM
M<V=S='(@(E523"!O8G+A>FMA.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@
M9G)O;2!G86QL97)Y(@IM<V=S='(@(D]B<N%Z;VL@>B!G86SI<FEE(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(D]B
M<N%Z;VL@>B!G86SI<FEE.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8U
M"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`B3F%H<F%T:64@;V)RX7IK
M=2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B
M"FUS9W-T<B`B3V)RX7IK>2(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N
M:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM
M<V=S='(@(DEM<&]R="P@:W)O:R`E9"(*"B,Z('1E;7!L871E<R]D871A+V1A
M=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D(&9I
M96QD.B`E<R(*;7-G<W1R("));7!O<G1O=F%NZ2!P;VQE.B`E<R(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I
M96QD<SHB"FUS9W-T<B`B26UP;W)T;W9A;ND@<&]L:6$Z(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS
M9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R(")6;&^^:;L@:[7ZZ"!?
M>F$B"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ,S0*;7-G:60@
M(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B0F]L('IA
M9&%N_2!N97-P<N%V;GD@:_-D(&%K8VEE+B(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M
M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(DYE<W!RX79N92!P;W6^[79A
M=&6U<VOI(&UE;F\@82]A;&5B;R!H97-L;R(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@
M;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO
M=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N
M(@IM<V=S='(@(B(*(DYE<W!RX79N92!P;W6^[79A=&6U<VOI(&UE;F\@86QE
M8F\@86QT97)N873M=FYA(&%D<F5S82X@4VOZ<W1E('1O('IN;W9U("(*(F%L
M96)O(&MO;G1A:W1U:G1E('-P<N%V8W4@5N&Y:&\@<WES=.EM=2P@86L@<&]T
M<F5B=6IE=&4@<&]M;V,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S
M='(@(EIVY.BY:;L@;V1S861E;FEE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Q-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED("));F1I82(*;7-G<W1R
M("));F1I82(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,C4T('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L(%5S
M97)S(@IM<V=S='(@(DIE9&YO=&QI=NT@<&]UONUV871E;&EA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED
M("));F1O;F5S:6$B"FUS9W-T<B`B26YD;V[I>FEA(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T
M<B`B26YF;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3D*;7-G
M:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;>%C:64B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Y"FUS9VED("));F9O<FUA=&EO
M;B!N;R!L;VYG97(@879A:6QA8FQE+B(*;7-G<W1R("));F9O<FWA8VEE('6^
M(&YI92!S^B!D;W-T=7!NZ2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L
M=6UN($%F=&5R(@IM<V=S='(@(E9L;[YINR!?<W3E<&5C('IA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(P"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`B5FQOOFF[(&]B<N%Z
M;VLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`B5FQOOFF[('1A8G6U
M:W4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B5FQOOFF[(&QI
M;FMU(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS
M9W-T<B`B5FQOOFF[(%]S=.5P96,@<')E9"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS
M97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T
M<B`B5FQOOFF[(&YO=OT@<W3E<&5C('IA(&%K='7A;&YY(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS
M9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O
M;F4B"FUS9W-T<B`B5FQOOFF[(&YO=OT@<W3E<&5C('!R960@86MT=>%L;GDB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U
M<G)E;G0@;VYE(@IM<V=S='(@(E9L;[YINR!N;W;](')I861O:R!Z82!A:W1U
MX6QN>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@
M=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(E9L;[YINR!N;W;](')I861O:R!P
M<F5D(&%K='7A;&YY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A
M<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R(")6;&^^:;L@;V1S
M=&%V96,@>F$@86MT=>%L;GD@8F]D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@
M82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B
M5FQOOFF[(&]D<W1A=F5C('!R960@86MT=>%L;GD@8F]D(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M
M<&QA=&4B"FUS9W-T<B`B5FQOOFF[(&%L=&5R;F%T[79N=2"Y86)L\VYU(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T,@IM<V=I9"`B26YS97)T(&%N
M(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N
M97<@<&%S<W=O<F0Z(@IM<V=S='(@(EIA9&%J=&4@92UM86EL;W;Z(&%D<F5S
M=2P@;F$@:W1O<OH@9&]S=&%N971E(&YO=ND@:&5S;&\Z(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I
M9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`B5FQOOFF[(&)U;FMU('IA
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(E9L
M;[YINR!B=6YK=2!P<F5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A
M9G1E<B(*;7-G<W1R(")6;&^^:;L@<W3E<&5C('IA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B
M26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B5FQOOFF[('-TY7!E8R!P
M<F5D(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS
M9VED("));G-E<G0@;65S<V%G97,B"FUS9W-T<B`B5FQOOG1E('-P<N%V>2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R
M(")6;&^^:;L@;V1S=&%V96,@>F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P
M87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(E9L;[YINR!O9'-T879E8R!P<F5D
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV.0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R(")6;&^^
M:;L@<FEA9&]K('IA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B
M"FUS9W-T<B`B5FQOOFF[(')I861O:R!P<F5D(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(S,PIM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W
M97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R("):861A:G1E
M('!OOF%D;W9A;OH@;V1P;W9E[R!N82!B97IP9>AN;W-T;OH@;W3A>FMU.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*
M;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B5FQOOFF[+W5P
M<F%V:;L@;V)RX7IO:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G
M<W1R(")6;&^^:;LO=7!R879INR!L:6YK=2(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D
M:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@
M(DYA(&]D;W-I96QA;FEE('!R92!Z;WIN86T@<'+M:F5M8V]V(&YE;>%T92!D
M;W-T871OZ&[](&MR961I="XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G
M<W1R(").961O<W1A=&_H;OT@:W)E9&ET+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,#<Y"FUS9VED("));G1E9V5R(@IM<V=S='(@(D-E;.D@Z.US;&\B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$S-PIM<V=I9"`B26YT96=E<B!L
M:7-T(@IM<V=S='(@(EIO>FYA;2!C96S]8V@@Z&ES96PB"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!5
M1$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B3F5P;&%D;ND@541(
M("A5<V5R($1A=&$@2&5A9&5R+"!(;&%V:>AK82!P;W6^[79A=&6U<VO]8V@@
M^F1A:F]V*2XB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ-C<@
M;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3DT"B,Z(&QI8B](;W)D92]#
M;VUP<F5S<R]Z:7`N<&AP.C(Q,@IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*
M;7-G<W1R(").97!L871NZ2#Z9&%J92!F;W)MX71U(%I)4"XB"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T
M:6]N+B(*;7-G<W1R(").97!L871NX2!A<&QI:^%C:6$N(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@
M8F%T8V@@240N(@IM<V=S='(@(DYE<&QA=&[I($E$(&3A=FMY+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,#DQ(&QI8B](;W)D92]&;W)M+G!H<#HR,38R
M(&QI8B](;W)D92]&;W)M+G!H<#HR,C,V"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,S`S(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS
M9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R(")";VQI(&]D
M;W-L86[I(&YE<&QA=&[I(/ID86IE+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N
M(&%D9')E<W,N(@IM<V=S='(@(DYE<&QA=&[A(&-I9;5O=N$@861R97-A+B(*
M"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C$P.2!L:6(O2&]R9&4O
M0V]M<')E<W,O9&)X+G!H<#HQ,SD*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V1B
M>"YP:'`Z,C0Q"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@
M(DYE<&QA=&[](&9O<FWA="!S^F)O<G4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,38U"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*
M;7-G<W1R(").97!L871N_2!L:6-E;NAN_2!KM?KH+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@(DEN=F%L:60@;&]C871I
M;VX@<')O=FED960N(@IM<V=S='(@(D)O;&$@>F%D86[A(&YE<&QA=&[A(&QO
M:V%L:71A+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R(").97!L871N
MX2!H;V1N;W1A(&US9U]T>7!E+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I
M7VED+B(*;7-G<W1R(").97!L871NX2!A;&5B;R!C:/UB86KZ8V$@:&]D;F]T
M82!A<&E?:60N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.38*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(*
M;7-G<W1R(").97!L871NZ2!A;&5B;R!C:/UB86KZ8V4@<&%R86UE=')E+B(*
M"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI
M9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B3F5P;&%T;ND@<F]D:>AO
M=G-KZ2!P<N%V;RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,38Q"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(DYE<&QA
M=&[I(&ED('!A<G1N97)A+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-C,*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R
M(").97!L871N_2!K\V0@<')O9'5K='4N(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN
M(@IM<V=S='(@(DYE<&QA=&[]('!R;W1O:V]L(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.CDS(&QI8B].970O4TU3+W=I;E]H='1P+G!H
M<#HW,0HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R
M(").97!L871N_2!P<NUJ96UC83H@7"(E<UPB(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HQ,#<U(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(U.`IM<V=I9"`B
M26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B3F5P;&%T;OT@;V)J96MT
M('ID:66U86YI82(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`Q"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R
M(").97!L871NX2!Z9')O:F]VX2!A9')E<V$N(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D
M92!D871A+B(*;7-G<W1R(").97!L871NZ2#Z9&%J92!U;FEC;V1E+B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3D*;7-G:60@(DEN=F5N=&]R
M>2(*;7-G<W1R("));G9E;G3A<B(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HV-S4*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS
M9W-T<B`B26YV97)T;W9ANR!V_6)E<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L86UI
M8R!297!U8FQI8R!O9B(*;7-G<W1R("))<N%N(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM
M<V=S='(@(DER86LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$S(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`BS7)S:V\B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F
M($UA;B(*;7-G<W1R("))<VQE(&]F($UA;B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T
M;W)M<R(*;7-G<W1R(")/:F5D:6YE;.D@8OIR:WDB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3$T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E
M;"(*;7-G<W1R("))>G)A96PB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C8R-@IM<V=I9"`B27-S=65R(@IM<V=S='(@(E9Y9&%V871EM2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I
M9"`B271A;&EC(@IM<V=S='(@(DMU<GKM=F$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3(Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,34*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DET86QY(@IM
M<V=S='(@(E1A;&EA;G-K;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R(")*
M86UA:FMA(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,Y.2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G
M:60@(DIA;G5A<GDB"FUS9W-T<B`B2F%N=>%R(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$R-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*87!A;B(*
M;7-G<W1R(")*87!O;G-K;R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S
M"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G
M<W1R(")*97)S97DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(T(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R(")*;W)DX6XB
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L
M>2(*;7-G<W1R(")*^FPB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`T(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R(")*^FXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*
M=7-T:69Y(@IM<V=S='(@(EIA<F]V;F&[(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I
M9GD@0V5N=&5R(@IM<V=S='(@(EIA<F]V;F&[(&1O('-T<F5D=2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W
M"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B6F%R;W9N8;L@9&\@8FQO
M:W4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(EIA<F]V
M;F&[(':U879O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T
M<B`B6F%R;W9N8;L@=G!R879O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$S-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S
M='(@(DMA>F%C:'-T86XB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C8S"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G<W1R(")0
M;VYE8VAANR!O<FEG:6[A;#\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3(V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DME;GEA(@IM<V=S='(@(DME
M\F$B"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R
M8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M(")+97)B97)O<R!S97)V97(@>F%M:65T;VP@875T96YT:69I:^%C:74N(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W
M8FEE<R(*;7-G<W1R(")+97)N96PM;F]VX>AI:V]V:6$B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G
M<W1R(")6>71V;W)E;FEE(&NU^NAA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B1&EG
M:73A;&YY(&]D=&QAZ&]K(&NU^NAA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@(D3EOFMA(&NU
M^NAA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+
M97D@5'EP92(*;7-G<W1R(")4>7`@:[7ZZ&$B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4Y.0IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(E!O
M=;YI=&EE(&NU^NAA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S0P
M"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES
M97)V97(N(@IM<V=S='(@(DNU^N@@=;X@97AI<W1U:F4@;F$@<V5R=F5R:2!V
M97)E:F[]8V@@:[7ZZ&]V+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,PIM<V=I9"`B2VED<R(*;7-G<W1R(")$971I(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$R.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T
M:2(*;7-G<W1R(")+:7)I8F%T:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T
M:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`BI75D;W9O9&5M;VMR
M871I8VOA(')E<'5B;&EK82!+\W)E82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(DOS<F5J<VOA(')E<'5B;&EK82(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS9W-T<B`B2W5V86IT(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS
M9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(DMI<F=IN7-K;R(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R
M(")6>E]HM6%D(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM
M<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B2F%Z>6LB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3,W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!0
M96]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(DQA;W,B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS
M9W-T<B`B4&]S;&5D;N$@<&]L;W9I8V$B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-S8*;7-G:60@(DQA<W0@4&%S<W=O<F0@0VAA;F=E(@IM<V=S='(@
M(E!O<VQE9&[A('IM96YA(&AE<VQA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R
M(@IM<V=S='(@(E!O<VQE9&[A(+ET=G*[(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-3$*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B4&]S;&5D
M;N$@86MT=6%L:7KA8VEA.B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`B
M4&]S;&5D;ND@<')I:&SA<V5N:64Z("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@N
M<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F
M<F]M("5S(@IM<V=S='(@(E!O<VQE9&[I('!R:6ALX7-E;FEE.B`E<R!Z("5S
M(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C<Q-`IM<V=I9"`B3&%S="!L;V=I
M;CH@3F5V97(B"FUS9W-T<B`B4&]S;&5D;ND@<')I:&SA<V5N:64Z(&YI:V1Y
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B3&]T>;ES:V\B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA=R(*;7-G<W1R(")0<N%V
M;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(E9Z:+5A9"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@
M(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B3F5C:&%J=&4@
M<'+A>F1N92!P<F4@OFEA9&5N(&]K<F%J(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$S."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A;F]N(@IM
M<V=S='(@(DQI8F%N;VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B5K5A
M=F\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P.`IM<V=I9"`B3&5F="!H
M96%D97(B"FUS9W-T<B`B2&QA=FGH:V$@=K5A=F\B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S$P-`IM<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`B2&]D
M;F]T>2!VM6%V;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("),97-O=&AO
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED("),
M979E;"(*;7-G<W1R("+:<F]V9?(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,30R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T
M<B`B3&EBZ7)I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*
M;7-G<W1R("),[6)Y82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R
M("),:6-H=&5NN71A:FYS:V\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R
M("*E86AKZ2!M<FAO;&5N:64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR-@IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R("*E
M86AK_2!DX;[O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B4N%N
M;R"U86AK_2!DX;[O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R(").
M97-K]'(@M6%H:_T@9.&^[R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G
M<W1R("*E86AKZ2!D8;[O;W;I('!R96CA;FMY(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@
M=VET:"!4:'5N9&5R(@IM<V=S='(@(J5A:&O](&3AON\@<R!H<FUE;NUM(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G
M:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`BI6%H:^D@<VYEOF5N:64B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B
M3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`BI6%H:^D@<VYE:&]VZ2!P<F5H
MX6YK>2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM
M97)I8VLB"FUS9W-T<B`B3&EM97)I8VLB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3@Q.`IM<V=I9"`B3&EN:R(*;7-G<W1R("),:6YK82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM
M<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(DQI;FMA('5K87IU:F4@
M;F$Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-SD*;7-G:60@(DQI;FL@
M=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I
M<W!L87EI;F<B"FUS9W-T<B`B4')E<&]J:;L@92UM86EL;W;Z(&%D<F5S=2!S
M;R!S='+A;FMO=2!N82!P[7-A;FEE('!ON71Y(@H*(SH@;&EB+TAO<F1E+U1E
M>'0O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@R"FUS9VED("),:6YK<R(*;7-G
M<W1R("),:6YK>2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I
M9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(DQI;G5X($-O;VMI92(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M
M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(EIO>FYA;2`M('!O
M=;[M=F%T9;4@=79I9.T@<')I9>AI;F]K(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$S,PIM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B5GEP[7-A
MNR!Z;WIN86T@9&%T86+A>B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP
M.C4Q"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(EIO>FYA;2!T
MZ6T@4&]M;V-N[6MA(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM<V=I
M9"`B3&ES="!486)L97,B"FUS9W-T<B`B5GEP[7-ANR!Z;WIN86T@=&%B=6QI
M96LB"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.30*;7-G:60@
M(DQI<W0M07)C:&EV92(*;7-G<W1R("),:7-T+4%R8VAI=F4B"@HC.B!L:6(O
M2&]R9&4O34E-12](96%D97)S+G!H<#HU.#D*;7-G:60@(DQI<W0M2&5L<"(*
M;7-G<W1R("),:7-T+4AE;'`B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S
M+G!H<#HU.38*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B3&ES="U)9"(*"B,Z
M(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/
M=VYE<B(*;7-G<W1R("),:7-T+4]W;F5R(@H*(SH@;&EB+TAO<F1E+TU)344O
M2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B3&ES
M="U0;W-T(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS
M9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("),:7-T+5-U8G-C<FEB92(*
M"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES
M="U5;G-U8G-C<FEB92(*;7-G<W1R("),:7-T+55N<W5B<V-R:6)E(@H*(SH@
M861M:6XO<V5S<VEO;G,N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(DQI
M<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R("):;V)R87IE;FEE
M('-E9&5N[2!Z;'EH86QO.B`E<R(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B6F]B<F%Z96YI92!P;W6^[79A=&6U;W8@>FQY:&%L;SH@
M)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G
M:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(EIO8G)A
M>F]V86YI92!Z;WIN86UU('!O=;[M=F%T9;5O=B!J92!Z86OA>F%NZ2XB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B
M"FUS9W-T<B`B3&ET97)A=/IR82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S
M='(@(DQI='9A(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEM86=E<RYP
M:'`Z-S<*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B3F'H[71A=F$@<V$N
M+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`P"FUS9VED
M("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B36EE<W1N>2#H87,Z("(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX-@IM<V=I9"`B3&]C86QE(&%N9"!4:6UE
M(@IM<V=S='(@(DQO:V%L:7KA8VEA(&$@Z&%S(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU-S(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C4W"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T
M87(N<&AP.C8U"FUS9VED("),;V-A=&EO;B(*;7-G<W1R("),;VMA;&ET82(*
M"B,Z(&QO9VEN+G!H<#HQ.#8@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M.C$Y,2!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z.3`*;7-G:60@(DQO9R!I;B(*;7-G<W1R(")0<FEH;.%S96YI92(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F
M('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R("):X7IN86UY('!R961C
M:.%D>F%J^F-E:B!S>6YC:')O;FEZX6-I92(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HQ.#4*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B3V1H
M;.%S:;LB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*;7-G:60@(DQO
M9VEN(@IM<V=S='(@(E!R:6ALX7-E;FEE(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q,`IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`BVFQO:'D@
M<')I('!R:6ALX7-E;NTB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3DR"FUS
M9VED("),;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A
M<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)0
M<FEH;.%S96YI92!Z;'EH86QO+"!P<F5T;[YE('-T92!Z861A;&D@;F5S<'+A
M=FYE('!O=;[M=F%T9;5S:^D@;65N;R!A;&5B;R`B"B)H97-L;RXB"@HC.B!L
M:6(O2&]R9&4O075T:"YP:'`Z.3@X"FUS9VED("),;V=I;B!F86EL960N(@IM
M<V=S='(@(E!R:6ALX7-E;FEE('IL>6AA;&\N(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$S-CD*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R(")$;&C]('1E
M>'0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B
M"FUS9W-T<B`B3.%S:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV-PIM<V=I9"`B3&]W(@IM<V=S='(@(D[M>FMA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R(")-86SI
M(&=RZ6-K92!P[7-M96[A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@
M;&5T=&5R<R(*;7-G<W1R(")-86SI(&QA=&EN<VOI('#M<VUE;N$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(DUA;.D@
M<NUM<VME(.CM<VQI8V4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30U
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B
M3'5X96UB=7)S:V\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,SDX(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,S8*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@
M(DU-(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,PIM<V=I9"`B
M34]41"(*;7-G<W1R(")3<'+A=F$@9/)A(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@
M8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(E!R[6QO:&$@35,M5$Y%1B!N
M96]B<V%H;W9A;&$@OFEA9&YE(/ID86IE+B(*"B,Z(&QI8B](;W)D92].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM
M<V=S='(@(DU31R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T<B`B36%C86\B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3$*
M;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI
M8R!O9B(*;7-G<W1R(")-86-E9/-N<VMO(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$U,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R
M(@IM<V=S='(@(DUA9&%G87-K87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#D*;7-G:60@(DUA9VEC(@IM<V=S='(@(DWA9VEA(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C@S"FUS9VED(")-86EL(@IM<V=S='(@(E!O
MN71A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R-`IM<V=I9"`B
M36%I;"!!9&UI;B(*;7-G<W1R(")0;W-L8;L@92UM86EL(&%D;6EN:7-T<N%T
M;W)O=FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B
M5GET=F]R:;L@;&EN7VMU+BXN(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$V-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QA=VDB"FUS9W-T<B`B
M36%L87=I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R(")-86QA:GII82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C0@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$T,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B36%L961I=GDB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,34T(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@
M(DUA;&DB"FUS9W-T<B`B36%L:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L=&$B"FUS9W-T<B`B
M36%L=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30*;7-G:60@(B(*
M(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA
M8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H
M('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*(E-P<F%V;W9ANR!Z;WIN
M86T@:V%T96?S<FGM+"!S(&MT;W+];6D@;WIN8>AU:F5T92!P;VQOOFMY(&$@
M9F%R8GD@87-O8VEO=F%NZ2`B"B)S('3];6ET;R!K871E9_-R:6%M:2XB"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U,PIM<V=I
M9"`B36%P,C0@;6%P(@IM<V=S='(@(DUA<&$@36%P,C0B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-`HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$V.`IM<V=I9"`B36%P475E<W0@
M;6%P(@IM<V=S='(@(DUA<&$@36%P475E<W0B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS
M9W-T<B`B36%P;W9A;FEA('5L;[YE;NDN(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P,2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(DUA<F5C(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT,0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(D]K<F%J(@H*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@
M4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B3WIN8>AINR!P<NUZ;F%K;6D@
M4')EZ.UT86[I+TYE<')EZ.UT86[I(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@
M*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R(")/>FYAZ&F[(&EN
M_6UI('!R[7IN86MM:2`H;F%P<BX@1/1L9;YI=.DO6F]D<&]V961A;NDI(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDQ
M"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(DUA<G-H86QL;W9E
M(&]S=')O=GDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R=&EN
M:6LB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B
M36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(EIH;V1NZ2!P;VQI82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$T-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I
M9"`B36%U<FET86YI82(*;7-G<W1R(")-875R973A;FEA(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$V,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-
M875R:71I=7,B"FUS9W-T<B`B36%U<NUT:75S(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R
M961I="XB"FUS9W-T<B`B36%X:6WA;&YY('!O=F]L96[](&MR961I="XB"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B
M36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(D)O;"!P<F5K
M<F_H96[](&UA>&EMX6QN>2!P;^AE="#H87-T[2!S<'+A=GDN(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@
M:&]U<G,Z("(*;7-G<W1R(").86IV>;FY:6$@=&5P;&]T82!Z82!P;W-L961N
M_6-H(#(T(&AO9.UN.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y.`IM
M<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B3F%J=GFY
MN6EA('1E<&QO=&$@>F$@<&]S;&5D;OUC:"`V(&AO9.UN.B`B"@HC.B!L:6(O
M87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L
M;V-K<R(*;7-G<W1R(")-87AI;>%L;GD@<&_H970@8FQO:V]V('!O<G3A;'4B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3`R(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,C(Q(&QI8B](;W)D92]&;W)M+G!H<#HQ,C0S"FUS9VED(")-87AI;75M
M(&QE;F=T:"(*;7-G<W1R(")-87AI;>%L;F$@9.6^:V$B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(DWA
M:B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$T-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3<*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B36%Y;W1T92(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T
M<B`B365D:6/M;F$B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C$V"FUS9VED(")-96UB97)S(@IM<V=S='(@(LAL96YO=FEA(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,@IM<V=I9"`B365N=2!M;V1E.B(*
M;7-G<W1R("):;V)R87IE;FEE(&UE;G4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@
M8V5L;',B"FUS9W-T<B`B6FSZZ&F[(&)U;FMY(@H*(SH@;&EB+TAO<F1E+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R
M(")3<'+A=F$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM
M<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H
M92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I
M960N(@IM<V=S='(@(B(*(E-P<N%V82!B;VQA(/IS<&6Y;F4@;W9E<F5NX2P@
M86QE(&-E<G1I9FEKX70@<&]D<&ES=2!S82!N97!O9&%R:6QO(&]V97)INRXB
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I
M9"`B365S<V%G92!E>'!I<F5D+B(*;7-G<W1R(")0;&%T;F]SNR!S<'+A=GD@
M=GEP<KEA;&$N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4V.2!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"FUS9VED(")-97-S86=E('1Y<&4B
M"FUS9W-T<B`B5'EP('-P<N%V>2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,PIM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G<W1R(")0;^AA<VEE($UE=&%R
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO
M8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`BVF1A:F4@365T87(@;FEE('/Z
M(&1O<W1U<&[I+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$R"FUS9VED
M("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@
M8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B
M"B+:9&%J92!-971A<B!N:64@<_H@:R!D:7-P;WKM8VEI+B!$971A:6QY(&)O
M;&D@>F%Z;F%M96YA;ND@<')E(&%D;6EN:7-T<N%T;W)A+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3,*;7-G:60@(DUE=&%R1$(@:7,@
M;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B4WES=.EM($UE=&%R1$(@;FEE(&IE
M('!R:7!O:F5N_2XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H
M<#HV-R!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B
M365T:&]D(@IM<V=S='(@(DUE=/-D82(*"B,Z(&QI8B](;W)D92]24$,O>&UL
M<G!C+G!H<#HX,2!L:6(O2&]R9&4O4E!#+W-O87`N<&AP.C$Q-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM
M<V=S='(@(DUE=/-D82!<(B5S7"(@;FEE(&IE(&1E9FEN;W9A;N$B"@HC.B!L
M:6(O2&]R9&4O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@
M(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T
M<B`B3F5D969I;F]V86[A(&UE=/-D82X@5F]L86[I('H@;65T\V1Y.B`E<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-R!L:6(O0FQO8VLO
M;65T87(N<&AP.C<U"FUS9VED(")-971R:6,B"FUS9W-T<B`B365T<FEC:^DB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R(")-97AI8V\B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z.#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$T.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC
M<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R(")-:6MR;V[I
M>G-K92!F961E<F%T[79N92"Y=.%T>2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@IM<V=I9"`B36ED9&QE(@IM
M<V=S='(@(E-T<F5D(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N
M<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B5'EP($UI;64B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,`IM<V=I9"`B36EN('1E;7`@;&%S
M="`R-"!H;W5R<SH@(@IM<V=S='(@(DYA:FYIOKEI82!T97!L;W1A('IA('!O
M<VQE9&[]8V@@,C0@:&]D[6XZ("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S`R"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(").
M86IN:;ZY:6$@=&5P;&]T82!Z82!P;W-L961N_6-H(#8@:&]D[6XZ("(*"B,Z
M(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P
M87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R(")-:6YI
M;>%L;F$@9&]B82!P;&%T;F]S=&D@:&5S;&$@9;ET92!N979Y<'*Y86QA(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,PIM<V=I
M9"`B36ER<F]R(@IM<V=S='(@(EIR:V%D;&]V;R!O8G+A=&F[(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM
M<V=S='(@(E+T>FYE(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8W,B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC
M.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG
M(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(D-H_6)A(&)A
M;.UK(%!%05(@2%144%]297%U97-T+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U
M(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T
M:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"B)#:/UB82!K;VYF:6=U
M<N%C:6$N($%K(&-H8V5T92!P;W6^[79ANR!T^G1O(&%P;&EKX6-I=2P@;75S
M[71E('1E<F%Z("(*(G9Y9V5N97)O=F&[(&MO;F9I9W5RX6-I=2XB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES
M<VEN9R!M97-S86=E($E$+B(*;7-G<W1R(")#:/UB82!)1"!S<'+A=GDN(@H*
M(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I
M9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T
M<B`B0VC]8F$@<&^^861O=F%N_2!014%2(&)A;.UK($UA:6PN(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I
M;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B0VC]8F$@240@<F5LX6-I92XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS
M9VED(")-;R(*;7-G<W1R(")0;VXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-S8*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@(DUO8FEL;OT@
M;6%I;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8X"FUS9VED(")-;V1E<F%T92(*;7-G<W1R(")-:65R;GDB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV-B!L:6(O2&]R9&4O34E-12]6
M:65W97(O>FEP+G!H<#HW,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z
M+G!H<#HX-0IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R(")$X71U;2!P
M;W-L961N96H@>FUE;GDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS
M9W-T<B`B57!R879INR!54DPB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C8W-`IM<V=I9"`B36]D=6QU<R(*;7-G<W1R(")-;V1U;'5S(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS
M9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R(")-;VQD879S:V\B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30Y(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R(")-;VYA:V\B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,34V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO
M;F=O;&EA(@IM<V=S='(@(DUO;F=O;'-K;R(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR-3@X"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R(")-97-I
M86,@82!R;VLB"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4W"FUS
M9VED(")-;VYT:&QY(@IM<V=S='(@(DUE<V'H;F4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,38Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S
M97)R870B"FUS9W-T<B`B36]N='-E<G)A="(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S
M97,B"FUS9W-T<B`B365S8>ANZ2!FX7IY(@H*(SH@;&EB+T9I;&4O0U-6+G!H
M<#HQ.38@;&EB+T9I;&4O0U-6+G!H<#HR.#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E
M8W1E9"`E9"XB"FUS9W-T<B`B3F$@<FEA9&MU("5D(&)O;&\@;N%J9&5N_6-H
M('9I86,@<&]L[2!A:V\@;^AA:^%V86[]8V@@)60N(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$T."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O
M8V-O(@IM<V=S='(@(DUA<F]K;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T
M<B`B4')E=F&^;F4@:F%S;F\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R
M(")0<F5V8;YN92!O8FQAZ&YO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R
M(")0<F5V8;YN92!S;&YEZ&YO(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="YP:'`Z-3`Y"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B4')E<W5N^KL@
M9&]L=2(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C4Q,PIM<V=I
M9"`B36]V92!,969T(@IM<V=S='(@(E!R97-U;OJ[(':U879O(@H*(SH@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-3$W"FUS9VED(")-;W9E(%)I9VAT
M(@IM<V=S='(@(E!R97-U;OJ[('9P<F%V;R(*"B,Z(&QI8B](;W)D92]";&]C
M:R],87EO=70N<&AP.C4P-0IM<V=I9"`B36]V92!5<"(*;7-G<W1R(")0<F5S
M=6[ZNR!H;W)E(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C4R,PIM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(E!R97-U;OJ[(&1O
M;'4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(R
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,C,*;7-G:60@
M(DUO=F4@=7`B"FUS9W-T<B`B4')E<W5N^KL@:&]R92(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$U-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z
M86UB:7%U92(*;7-G<W1R(")-;WIA8FUI:R(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,3@X"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B
M"FUS9W-T<B`B5FEA8_IR;W;R;W;I('9Y8F5R86-I92!Z;WIN86UY(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-34*;7-G:60@
M(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C(T-@IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@
M(E9I86-NX7-O8F[](';]8F5R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0P,@IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R(")-;VIE(&MO;G1O
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED(")->2!!8V-O
M=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;>%C:64@;R!M;VIO;2#Z
MZ'1E(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HU-`IM<V=I9"`B
M37D@4&]R=&%L(@IM<V=S='(@(DWT:B!P;W)TX6PB"@HC.B!S97)V:6-E<R]P
M;W)T86PO961I="YP:'`Z,3,V"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM
M<V=S='(@(E9Z:+5A9"!M]&IH;R!P;W)TX6QU(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$U-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R
M(@IM<V=S='(@(DUY86YM87(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E
M(@IM<V=S='(@(DYI92P@3D53VDA,05/-32XB"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HT,3$@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,#(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS
M9VED(").86UE(@IM<V=S='(@(DUE;F\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,38Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS
M9W-T<B`B3F%M[6)I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B3F%U<G4B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(DYE<.%L(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$W-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").971H
M97)L86YD<R(*;7-G<W1R(")(;VQA;F1S:V\B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N
M9',@06YT:6QL97,B"FUS9W-T<B`B2&]L86YD<VOI($%N=&EL>2(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!"
M87-E(%523"(*;7-G<W1R("):X6ML861NX2!54DP@3F5T<V-A<&4B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@
M0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B55),('!R92!Z;F5P;&%T;F5N
M:64@8V5R=&EF:6OA=&]V($-!($YE='-C87!E(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!5
M4DPB"FUS9W-T<B`B55),('!R92!P;VQI=&EK=2!#02!.971S8V%P92(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P
M92!296YE=V%L(%523"(*;7-G<W1R(")54DP@<')E(&]B;F]V96YI92!P;&%T
M;F]S=&D@8V5R=&EF:6OA=&]V($YE='-C87!E(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@
M55),(@IM<V=S='(@(E523"!P<F4@>FYE<&QA=&YE;FEE(&-E<G1I9FEKX71O
M=B!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@W
M"FUS9VED(").971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B365N
M;R!34TP@<V5R=F5R82!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3@X"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM
M96YT(@IM<V=S='(@(DMO;65N=.%R(&-E<G1I9FEKX71U($YE='-C87!E(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C
M87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B5'EP(&-E<G1I9FEKX71U
M($YE='-C87!E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U,PIM
M<V=I9"`B3F5T=V]R:R(*;7-G<W1R(")3:66[(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,`IM<V=I9"`B3F5V97(B"FUS9W-T
M<B`B3FEK9'DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B3F]V
MX2!+86QE9/-N:6$B"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(DYO=N$@
M:V%T96?S<FEA(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP
M:'`Z.#$@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@
M;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.3<@;&EB+TAO<F1E
M+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G
M:60@(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@(DYO=N$@<W!RX79A('!R
M92`E<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO
M;VXB"FUS9W-T<B`B3F]V(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS
M9W-T<B`B3F]VZ2!P;W6^[79A=&6U<VOI(&UE;F\@*&YE<&]V:6YNZ2DB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@P(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-C,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*
M;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(DYO=OT@6NEL86YD(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W"FUS9VED(").97<@<&%S
M<W=O<F0B"FUS9W-T<B`B3F]VZ2!H97-L;R(*"B,Z(&QI8B](;W)D92]!=71H
M+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!P87-S=V]R
M9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B4&QA=&YO<[L@;F]VZ6AO
M(&AE<VQA('9Y<'*Y[2`E>"XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z-3(*;7-G:60@(DYE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM
M<V=S='(@(DYO=ND@:&5S;.$@;FEE('/Z(')O=FYA:^DN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W
M('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R(").;W;I(&]K;F\@*%]B;&%N:RDB
M"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Y,0IM<V=I
M9"`B3F5W<R(*;7-G<W1R(").97=S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,P-PIM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R(")$:7-K=7-N
MZ2!S:W5P:6YY(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@
M=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M,C4*;7-G:60@(DYE>'0B"FUS9W-T<B`BSV%L96HB"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B3F%S
M;&5D=6KZ8V4@-"!FX7IY(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS
M-S(@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-S8*;7-G:60@(DYE>'0@;W!T
M:6]N<R(*;7-G<W1R("+/86RY:64@;F%S=&%V96YI82(*"B,Z(&QI8B](;W)D
M92]522]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R(").87-L
M961U:OIC83XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R(").:6MA<F%G
M=6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Q(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.38*;7-G:60@(DYI9V5R(@IM<V=S='(@(DYI9V5R(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$W,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").
M:6=E<FEA(@IM<V=S='(@(DYI9^ER:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S8Y"FUS9VED(").:6=H="(*;7-G<W1R(").;V,B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*
M;7-G:60@(DYI=64B"FUS9W-T<B`B3FEU92(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(DYO(@IM<V=S='(@(DYI
M92(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I
M9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I
M9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B(@HB3FEE('/Z(&1O<W1U<&[I(+YI
M861N92!K;VYF:6=U<F'H;ND@^F1A:F4L('!R92!K=&]RZ2!B>2!S82!D86QI
M('IO8G)A>FF[("(*(G)O>F1I96QY+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+G!H<#HQ,#8*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K
M:6YG($E33R!I;6%G97,N(@IM<V=S='(@(E!R92!V>71VX7)A;FEE($E33R!O
M8G)A>F]V(&YI92!J92!K(&1I<W!O>NUC:6D@OFEA9&YA('-T<F%TZ6=I82XB
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I
M9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(DYE97AI<W1U:F4@N6%B
M;/-N82!P<F4@9.%V:W4N(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP
M:'`Z-SD@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,C0U"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C(V-PIM<V=I9"`B3F\@8FQO8VL@97AI
M<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B3F$@<&^^
M861O=F%N96H@<&]Z[6-I:2!N965X:7-T=6IE(+YI861E;B!B;&]K+B(*"B,Z
M(&QI8B](;W)D92]!=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A
M<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R(")0<F4@34-!3"!A=71E;G1I9FEKX6-I=2!N96)O;&\@>F%D86[I(&UE
M;F\@:V%L96YDX7)A+B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS
M9VED(").;R!C:&%N9V4N(@IM<V=S='(@(JYI861N82!Z;65N82XB"@HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@
M8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B2R!T
M;VUU=&\@<'+A=G4@;F5M;[YN;R!P<FED8;L@OFEA9&YE('!O9')I861E;ND@
M<'+A=F$N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-CD@;&EB+TAO<F1E+G!H<#HU
M,#@@;&EB+TAO<F1E+U5T:6PN<&AP.C<V.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M)7,N(@IM<V=S='(@(E!R92`E<R!N96)O;&$@=7+H96[A(&MO;F9I9W5RX6-I
M82XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#0T"FUS9VED(").;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS
M9W-T<B`B4')E($944"!61E,@;F5B;VQA('5RZ&5NX2!K;VYF:6=U<N%C:6$N
M(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C8W,@IM<V=I9"`B3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S
M='(@(E!R92!344P@5D93(&YE8F]L82!U<NAE;N$@:V]N9FEG=7+A8VEA+B(*
M"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<R-0IM<V=I9"`B3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&
M4RXB"FUS9W-T<B`B4')E(%-13"U&:6QE(%9&4R!N96)O;&$@=7+H96[A(&MO
M;F9I9W5RX6-I82XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(JYI861E
M;B!K<F5D:70N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@
M(DYE8F]L;R"Y<&5C:69I:V]V86[I(&UI97-T;R!U<NAE;FEA+B(*"B,Z(&QI
M8B](;W)D92]"<F]W<V5R+G!H<#HY,#,*;7-G:60@(DYO(&9I;&4@=7!L;V%D
M960B"FUS9W-T<B`B4_IB;W(@;F5B;VP@;F%H<F%N_2XB"@HC.B!U=&EL+VEC
M;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G
M<W1R(").96)O;&D@;N%J9&5NZ2"^:6%D;F4@:6MO;GDN(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-B!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C,*;7-G:60@(DYO(&QO
M8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B3FEE(&IE(&YA<W1A=F5NX2!L;VMA
M;&ET82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"FUS
M9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B3F5B;VQA('IA
M9&%NX2!L;VMA;&ET82XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R
M(").96)O;&$@>F%D86[A(+YI861N82!S<'+A=F$N(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C
M:69I960N(@IM<V=S='(@(DYE8F]L;R"Y<&5C:69I:V]V86[I(+YI861N92!M
M96YO+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*
M;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(DYE8F]L;R"Y
M<&5C:69I:V]V86[I(.CM<VQO+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(JYI
M861N92!U<N&^;&EVZ2!F;W)T=6YY(@H*(SH@;&EB+TAO<F1E+T%U=&@O:'1T
M<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")0<F4@2%144"!A=71E;G1I9FEK
MX6-I=2!N96)O;&\@>F%D86[I(&AE<VQO+B(*"B,Z(&QI8B](;W)D92]!=71H
M+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E!R92!)34%0(&%U=&5N
M=&EF:6OA8VEU(&YE8F]L;R!Z861A;ND@:&5S;&\N(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4')E($ME
M<F)E<F]S(&%U=&5N=&EF:6OA8VEU(&YE8F]L;R!Z861A;ND@:&5S;&\N(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z-S<@;&EB+TAO<F1E+T%U=&@O
M;&]G:6XN<&AP.C@T"B,Z(&QI8B](;W)D92]!=71H+W!A;2YP:'`Z-S4*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B4')E($QO9VEN(&%U=&5N=&EF:6OA8VEU(&YE8F]L
M;R!Z861A;ND@:&5S;&\N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<&%S<W=D+G!H
M<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(E!R92!005-35T0@875T96YT:69I
M:^%C:74@;F5B;VQO('IA9&%NZ2!H97-L;RXB"@HC.B!L:6(O2&]R9&4O075T
M:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")0<F4@4TU"(&%U=&5N=&EF
M:6OA8VEU(&YE8F]L;R!Z861A;ND@:&5S;&\N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HQ,C@W"FUS9VED("(B"B).;R!P871H('1O('1H92!/
M<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES
M(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G
M<W1R("(B"B).96)O;&$@>F%D86[A(&-E<W1A(&L@<')O9W)A;74@3W!E;E-3
M3"X@4')O9W)A;2!/<&5N4U-,(&IE('!O=')E8F[](&YA('!RX6-U("(*(G,@
M^F1A:FUI(%!+0U,@,3(N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R
M("*N:6%D;F4@<')E8FEE:&%J^F-E('!R:6ALX7-E;FEA+B(*"B,Z(&QI8B]6
M1E,N<&AP.C<V-0IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R(")+=O-T
M82!N:64@:F4@;F%S=&%V96[A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S(@IM
M<V=S='(@(D)E>B#H:6%R(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT.#(*;7-G
M:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@(DYE8F]L(+EP
M96-I9FEK;W9A;OT@;V1D9;5O=F'H+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S
M(@IM<V=S='(@(D)E>B!S='+A;B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HU.#<*
M;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R(")3^F)O<B!N96[A:F1E;OTB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(V"FUS9VED(").
M;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM
M<V=S='(@(E!R92!V>7)O=F[A=F%C:74@<&%MY+L@;FEE(&IE(&1O<W1U<&[]
M(+YI861E;B!D;^AA<V[]('!R:67H:6YO:RXB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q(&QI8B].970O4TU3+W=I;E]H='1P+G!H
M<#HR,C$*;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT
M+B(*;7-G<W1R(").96)O;&\@;V1O<VQA;ND@<&]UONUV871EM7-KZ2!M96YO
M(&$O86QE8F\@:&5S;&\N(@H*(SH@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP
M.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T
M<B`B3F5B;VQI('9RX71E;ND@<&QA=&[I(%A-3"#Z9&%J92(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY-S$@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX,0HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.3DR"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#`Y"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`B
MKFEA9&YE(&AO9&YO='DB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P
M"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R
M871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB
M5B!P]'9O9&YE:B!K;VYF:6=U<N%C:6D@;F5B;VQA(&[A:F1E;N$@OFEA9&YA
M('9E<GII82X@5GEG96YE<G5J=&4@>FYO=G4@(@HB:V]N9FEG=7+A8VEU+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I
M;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(E8@:V]N9FEG=7+A8VEI(&YE8F]L
M82!NX6ID96[A(+YI861N82!V97)Z:6$N(%9Y9V5N97)U:G1E('IN;W9U(&MO
M;F9I9W5RX6-I=2XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C<@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"FUS
M9VED(").;VYE(@IM<V=S='(@(JYI861E;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I
M;7!L:6-I="DB"FUS9W-T<B`BKFEA9&YE("AP;W6^:;L@:6UP;&EC:71N^B!H
M;V1N;W1U*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(").
M;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3<R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O
M;&L@27-L86YD(@IM<V=S='(@(D]S=')O=B!.;W)F;VQK(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B
M3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")3979E<F[A('!O;&]G=;5A
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B
M4V5V97)NZ2!-87)IX6YS:V4@;W-T<F]V>2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM
M<V=S='(@(D[S<G-K;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-C0Q"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B3F5P;&%T[2!P;R(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED(").;W0@0F5F
M;W)E(@IM<V=S='(@(DYE<&QA=.T@<')E9"(*"B,Z(&QI8B]61E,O9FEL92YP
M:'`Z-#$R"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B3FEE(&IE
M(&%D<F5SX7(B"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z-C,@;&EB+U9&
M4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX-`HC.B!L:6(O
M5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDU"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!L
M:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G
M:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B3FEE(&IE(&EM<&QE;65N
M=&]V86[I+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-C@*;7-G:60@(DYO="!S970B"FUS9W-T<B`B3F5N87-T879E;NDB
M"@HC.B!L:6(O5D93+G!H<#HQ.3,@;&EB+U9&4RYP:'`Z,C`X(&QI8B]61E,N
M<&AP.C(S,R!L:6(O5D93+G!H<#HR-3$*(SH@;&EB+U9&4RYP:'`Z,C8X(&QI
M8B]61E,N<&AP.C(X-"!L:6(O5D93+G!H<#HS,#`@;&EB+U9&4RYP:'`Z,S$U
M"B,Z(&QI8B]61E,N<&AP.C,S,B!L:6(O5D93+G!H<#HS-C4@;&EB+U9&4RYP
M:'`Z-#(U(&QI8B]61E,N<&AP.C4P-`HC.B!L:6(O5D93+G!H<#HU-S,@;&EB
M+U9&4RYP:'`Z-3DP(&QI8B]61E,N<&AP.C8V.`HC.B!L:6(O2&]R9&4O4V5S
M<VEO;DAA;F1L97(N<&AP.C$T-2!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N
M<&AP.C$V,`HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$W-2!L
M:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$X.0HC.B!L:6(O2&]R9&4O
M4V5S<VEO;DAA;F1L97(N<&AP.C(S-@IM<V=I9"`B3F]T('-U<'!O<G1E9"XB
M"FUS9W-T<B`B3FEE(&IE('!O9'!O<F]V86[I+B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R]H;V]K<RYP:'`N9&ES
M=#HQ,#`U"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#`*;7-G:60@
M(DYO=&5S(@IM<V=S='(@(E!O>F[A;6MY(@H*(SH@<V5R=FEC97,O;V)R;W=S
M97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@
M8F%C:RXB"FUS9W-T<B`B3FGH(&YA('!R97IE<F%N:64L('9RX;MT92!S82!S
M<.2[+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#D@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED
M(").;W9E;6)E<B(*;7-G<W1R(").;W9E;6)E<B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,#4P"FUS9VED(").=6UB97(B"FUS9W-T<B`BR.US;&\B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R.0IM<V=I9"`B3G5M8F5R(&]F(&-H
M87)A8W1E<G,B"FUS9W-T<B`B4&_H970@>FYA:V]V(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$S-S,@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C<@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$T-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM
M<V=S='(@(E!OZ&5T('-TY7!C;W8B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3,W,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R-2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,30T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B4&_H970@
M<FEA9&MO=B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@
M:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(E!R92!A:W1U86QI>N%C
M:74@>F]Z;F%M=2!P<NUJ96UC;W8@;F5B;VQI(+EP96-I9FEK;W9A;ND@Z.US
M;&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C8T"FUS9VED(")/2R(*;7-G<W1R(")/2R(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX-S`*;7-G:60@(D]B:F5C="(*;7-G<W1R
M(")/8FIE:W0B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM
M<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`B075T;W(@;V)J96MT=2(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3`X"FUS9VED(")/8W1A;"(*;7-G
M<W1R(")/<VUIZ&MO=OTB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`X(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R(")/:W3S8F5R(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*
M;7-G<W1R(")&:6QT97(@;F$@;F%DX79K>2(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS,C@*;7-G:60@(D]F9FEC92(*;7-G<W1R(")0<F%C;W9I
M<VMO(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED
M(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM
M<V=S='(@(E-T87+I(&$@;F]VZ2!H97-L;R!M=7-I82!B>;L@;V1L:;ENZ2XB
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*;7-G:60@(D]L
M9"!P87-S=V]R9"(*;7-G<W1R(")3=&%RZ2!H97-L;R(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D(&ES
M(&YO="!C;W)R96-T+B(*;7-G<W1R(")3=&%RZ2!H97-L;R!N96)O;&\@>F%D
M86[I('-P<N%V;F4N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@(D]MX6XB"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N
M;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S
M='(@(DEB82!)34%0('-E<G9E<GD@<&]D<&]R=6KZ('ID:66U86[I('!R:67H
M:6YK>2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N
M;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(DEB82!U<N&^;&EVZ2!F
M;W)T=6YY(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-34@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Y-S4*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@
M86QL;W=E9"XB"FUS9W-T<B`B2F4@<'+M<'5S=&[A(&EB82!J961N82!E+6UA
M:6QO=N$@861R97-A+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV
M-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T
M<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES
M<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HB5FQA<W1N[6MA(&%L96)O
M('!RX79A('9L87-T;NUK82!P<F4@>F1I9;5A;OT@;V)J96MT(&WTOF4@>FUE
M;FF[(&EB82!V;&%S=&[M:R`B"B)A;&5B;R!S>7-TZ6UO=OT@861M:6YI<W1R
MX71O<B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,Y(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C0P"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G
M<W1R(")/='9O<FF[('8@;F]V;VT@;VMN92(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N
M;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G
M<W1R(")#:'EB82!/<&5N4U-,.B!N97!O9&%R:6QO('-A('KM<VMANR#Z9&%J
M92!Z('!O9'#M<V%N96H@Z&%S=&D@4R]-24U%+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B
M3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")/='9O
M<FF[('3Z=&\@;&EN:W4@=B!N;W9O;2!O:VYE(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@
M(D]P97)AZ&[]('-Y<W3I;2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B3F%S=&%V96YI82(*
M"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P
M+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*
M;7-G<W1R(").87-T879E;FEA("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM
M<V=S='(@(EIO<F%D96[]('IO>FYA;2(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B3W)G
M86YI>N%C:6$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V.0IM
M<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R(")/<F=A;FEZ8>AN
MX2!J961N;W1K82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S0*
M;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B3W)G86YI>F]V86YI92(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L
M:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R(")0]'9O9&[A(+EA8FSS;F$@87!L
M:6OA8VEE(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R
M(")0]'9O9&[I(+EA8FSS;GD@=B`E<SHB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/
M=&AE<B(*;7-G<W1R("));NDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3D@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.0HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C4*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,30T"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R("+/86RY:64@
M:6YF;W)MX6-I92(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*
M;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(E!RX79A('9L87-T
M;NUK82(*"B,Z(&QI8B](;W)D92]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!
M32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")0
M04T@875T96YT:69I:^%C:6$@;FEE(&IE(&1O<W1U<&[A+B(*"B,Z(&QI8B].
M970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL
M(&)A8VME;F0B"FUS9W-T<B`B4$5!4CI-86EL(&)A8VME;F0B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,C<V"FUS9VED(")01U`@1&EG:71A;"!3
M:6=N871U<F4B"FUS9W-T<B`B1&EG:73A;&YY('!O9'!I<R!01U`B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S(R"FUS9VED(")01U`@16YC<GEP
M=&5D($1A=&$B"FUS9W-T<B`BVF1A:F4@>F&Y:69R;W9A;ND@<&]M;V-O=2!0
M1U`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S<T"FUS9VED(")0
M1U`@4'5B;&EC($ME>2(*;7-G<W1R(")01U`@=F5R96IN_2!KM?KH(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,U-@IM<V=I9"`B4$=0(%-I9VYE
M9"]%;F-R>7!T960@1&%T82(*;7-G<W1R("+:9&%J92!P;V1P[7-A;NDO>F&Y
M:69R;W9A;ND@<&]M;V-O=2!01U`B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z
M-C@*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(E!(4"!K\V0B"@HC.B!A9&UI
M;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R(")0
M2%`@4VAE;&PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS-PIM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R(")0;W!O;'5D
M;NT@M6%H:_T@9.&^[R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,X"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(E!O<&]L
M=61N[2!P<F5HX6YK>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,Y"FUS9VED(")032!3;F]W(@IM<V=S='(@(E!O<&]L=61N
M[2!S;F6^96YI92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0P"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B4&]P
M;VQU9&[M('-N96AO=ND@<')E:.%N:WDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@
M(E!O<&]L=61N[2!S;F6^96YI92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R
M(")0;W!O;'5D;NT@8OIR:WDB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M,C<T"FUS9VED(")03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R
M(")#:/UB82!R;WJY[7)E;FEE(%!/4TE8(@H*(SH@;&EB+V%P:2YP:'`Z,30Y
M"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(E!?2%`@4VAE;&PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V
M"FUS9VED(")0861D:6YG(@IM<V=S='(@(E9Y<&QN96YI92(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$W,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B
M4&%K:7-T86XB"FUS9W-T<B`B4&%K:7-T86XB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3DT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S,*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QA=2(*
M;7-G<W1R(")086QA=7-KZ2!O<W1R;W9Y(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Y,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI
M86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R(")086QE<W3M;G-K92#Z
M>F5M:64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@R(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G<W1R(")086YA;6$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G
M:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B4&%P=6$@3F]VX2!'=6EN
M96$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DU(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R(")087)A9W5A>2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED
M(")087)T;'D@0VQO=61Y(@IM<V=S='(@(LAI87-T;^AN92!O8FQAZ&YO(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X
M,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`R,@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3,W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3DY"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ-3$@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-PHC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C0S(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,C4*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(DAE<VQO(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N
M9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B2&5S;&\@8F]L;R#Z<W!EN6YE
M('IM96YE;NDN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,S(S
M"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B3F5S<'+A=FYE
M(&AE<VQO(@H*(SH@;&EB+TAO<F1E+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G
M:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(E!R92!A=71E;G1I9FEKX6-I=2!2041)55,@:F4@=GF^
M861O=F%NZ2!H97-L;RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`U-PIM
M<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B2&5S
M;&\@<R!P;W1V<F1E;NUM(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.CDP"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`B2&5S;&\Z(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D
M.B`B"FUS9W-T<B`B2&5S;&\Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C`S.`HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB
M"FUS9W-T<B`B2&5S;.$@;75S:6$@8GF[(')O=FYA:^DN(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$Q.2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S='(@(E9L
M;[YINR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(E9L
M;[YINR!Z;R!S8VARX6YK>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B0V5S=&$B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N
M9&EN9R!3:6=N=7!S.B(*;7-G<W1R(")0<F5B:65H86KZ8V4@<F5G:7-T<N%C
M:64Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"FUS9VED(")096]P
M;&4B"FUS9W-T<B`BI75D:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R(")0
M97)C96YT(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E
M+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<R(*;7-G<W1R(")6>6MO;F&[(&]P97+A8VEE(/ID<KYB>2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT,3`*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B5GEK;VYANR!O<&5R
MX6-I92#Z9'*^8GD@<')I('!R:6ALX7-E;NT_(@H*(SH@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B4'+A
M=F\B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M
M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G
M<W1R(")0<N%V;R!<(B5S7"(@;F5B;VQO('9Y;6%Z86[I+B(*"B,Z(&QI8B]6
M1E,O<VUB+G!H<#HU.3`*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S
M='(@(E!R[7-T=7`@>F%M:65T;G5T_2(*"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,38Q(&QI8B](;W)D92]097)M<R]522YP:'`Z,38T"FUS9VED(")0
M97)M:7-S:6]N<R(*;7-G<W1R(")0<N%V82(*"B,Z(&%D;6EN+W!E<FUS+V5D
M:70N<&AP.C$P.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M
M:6XO<&5R;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z
M-3@*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(D%D;6EN:7-T<N%C:6$@<'+A=B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV.`IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B3W-O
M8F[I(&EN9F]R;>%C:64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@S
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B4&5R=2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G
M<W1R(")$;VWA8V4@>G9I97)A=.$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3@V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM
M<V=S='(@(D9I;&EP[6YY(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(E1E;&5F\VXB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@P"FUS9VED(")0:&]T;W,B
M"FUS9W-T<B`B1F]T;V=R869I92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S
M='(@(E!I=&-A:7)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R(")";V1O=B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S
M;VUE(&-E;&PB"FUS9W-T<B`B2VQI:VYI=&4@<')O<^UM(&1O(&YE:F%K96H@
M8G5N:WDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U
M('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B4&]T=G+O
M=&4@<')O<^UM+""^92!C:&-E=&4@;V1S='+A;FF[('1E;G1O(&5L96UE;G0Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT
M('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(E!O='9R[W1E('!R
M;W/M;2P@OF4@8VAC971E(&]D<W1RX6YINR!L:6YK=2!Z('1O:'1O(&5L96UE
M;G1U+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-38V"FUS9VED(")0;&5A
M<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R("):861A:G1E
M('!R;W/M;2!M97-I86,@82!R;VLN(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A
M(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(EIA9&%J=&4@
M<')O<^UM(&UE;F\@<')E(&YO=OH@:V%T96?S<FEU.B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,S`U"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)
M4"!A9&1R97-S+B(*;7-G<W1R("):861A:G1E('!R;W/M;2!P;&%T;OH@25`@
M861R97-U+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-C0W"FUS9VED(")0
M;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F
M(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R("):861A:G1E('!R;W/M;2!P
M;&%T;OT@9.%T=6TL('-K;VYT<F]L=6IT92!P;^AE="!D;NT@=B!M97-I86-I
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#4Q"FUS9VED(")0;&5A<V4@
M96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R("):861A:G1E('!R;W/M;2!P
M;&%T;OT@Z&%S+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O
M8FQE;2XB"FUS9W-T<B`B4')O<^UM('5V9>]T92!Z:')N=71I92!P<F]B;.EM
M=2XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO
M=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S='(@(E!R;W/M;2!Z861A
M:G1E('-V;VIE('!O=;[M=F%T9;5S:^D@;65N;R!A(&AE<VQO(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A
M9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE
M('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"B)0<F7H
M[71A:G1E('-I('!R;W/M;2!N87-L961U:OIC:2!T97AT+B!-55/-5$4@<_IH
M;&%S:;L@<R!P;V1M:65N:V%M:2`B"B)P;W6^[79A;FEA('-Y<W3I;74N(@H*
M(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G
M:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T
M<B`B6F%D86IT92!P<F]S[6T@;65N;R!P<F4@;F]V^B!K871E9_-R:74Z(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY
M"FUS9VED(")0;VQA;F0B"FUS9W-T<B`B4&^U<VMO(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R(")0;VQI
M=&EK82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#D*;7-G:60@
M(E!O;&QS(@IM<V=S='(@(D%N:V5T>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ.3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U9V%L(@IM
M<V=S='(@(E!O<G1U9V%L<VMO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO
M;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(E5M:65S=&YE;FEE('1O:'1O
M(&]B<N%Z:W4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*
M;7-G<W1R(")5;6EE<W1N96YI92!T96IT;R!T86)UM6MY(@H*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H
M:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B3V1O
M<VQANR!D;R!T;VAT;R!P<FEEZ&EN:V$@*&YE=GEN=6-U:F4@24U!4"DB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L
M87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R("):<N&^:WD@>F$@<&]S;&5D;OUC
M:"`E<R!H;V3M;CH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(X-PIM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R
M(")0<F%V9&5P;V1O8FYO<[L\8G(@+SYZ<N&^;VLB"@HC.B!L:6(O2&]R9&4O
M4')E9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D
M($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?;&1A
M<#H@<&^^861O=F%NZ2!R;WJY[7)E;FEE($Q$05`@;F5B;VQO(&[A:F1E;NDN
M(@H*(SH@;&EB+TAO<F1E+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0
M<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(E!R969S7W-E<W-I;VXZ('!OOF%D;W9A;ND@<F]Z
MN>UR96YI92!S97-S:6]N(&YE8F]L;R!NX6ID96[I+B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C(U"FUS9VED(")0<F5S<W5R92(*;7-G<W1R(")4;&%K
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G:60@(E!R97-S=7)E
M(&%T('-E82!L979E;#H@(@IM<V=S='(@(E1L86L@;F$@^G)O=FYI(&UO<F$Z
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C0*;7-G:60@
M(E!R97-S=7)E.B`B"FUS9W-T<B`B5&QA:SH@(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P-`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R
M979I97<B"FUS9W-T<B`B56OAOFMA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V
M:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B6F]B<F%Z
M:;L@=6OAOFMU(&]B<N%Z:W4@=B!N;W9O;2!O:VYE(@H*(SH@;&EB+TAO<F1E
M+U!R969S+U5)+G!H<#HS-C(@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-C8*
M;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B4')E9&-HX61Z86KZ
M8V4@;F%S=&%V96YI82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@
M(E9Y=&QAZ&F[(&1O:W5M96YT(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-#(S"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R(")0<FEVX71N>2!K
MM?KH(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE
M;2(*;7-G<W1R(")0<F]B;.EM(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z
M,3(W"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(E!O<&ES
M('!R;V)LZ6UU(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W,0IM
M<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B4')O:F5K='DB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C$Q-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Y,B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S(W-`IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T
M<B`B5OUZ=F$@;F$@>F%D86YI92!T97AT=2(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R(")697)E
M:F[](&NU^N@B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T-@IM
M<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS9W-T<B`B06QG;W)I=&UU
M<R!V97)E:F[I:&\@:[7ZZ&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(DEN9F]R
M;>%C:64@;R!V97)E:FYO;2!KM?KH:2(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@
M9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B5F5R96IN_2]P<FEV
MX71N>2!KM?KH;W;]('#A<B!N96)O;"#Z<W!EN6YE('9Y9V5N97)O=F%N_2XB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DQ(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`P"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R(")0;W)T;W)I:V\B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DV(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R
M"FUS9VED(")1871A<B(*;7-G<W1R(")+871A<B(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HV,PIM<V=I9"`B475E<GDB"FUS9W-T<B`B1&]T87HB"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S='(@
M(DMV\W1A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS
M9W-T<B`B4E-!('9E<F5J;OT@:[7ZZ"`H)60@8FET;W8I(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(R-C@*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G
M<W1R(")0<F5P[6YAZ"!S(';]8F5R;VTB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4F%I;B(*;7-G<W1R(")$
MX;[O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#0*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B4N%N;R!DX;[O(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@
M(E)A:6X@3&%T92(*;7-G<W1R(").97-K]'(@9.&^[R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")286EN(%-H
M;W=E<B(*;7-G<W1R(")$8;[O;W;I('!R96CA;FMY(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@86YD
M(%-N;W<B"FUS9W-T<B`B1.&^[R!S;R!S;F5H;VTB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!T;R!3
M;F]W(@IM<V=S='(@(D3AON\@<')E8VCA9'IA:OIC:2!V('-N9;YE;FEE(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T
M=6YE(@IM<V=S='(@(D[A:&]D;N$@9F]R='5N82(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R87(N<&AP.C8X(&QI8B](;W)D92]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<V"FUS9VED(")2871I;R(*;7-G<W1R(")0;VUE<B(*"B,Z(&QI
M8B](;W)D92]097)M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S
M='(@(LCM=&&[(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C@W"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@(LCM=&&[('-P<N%V
M>2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A
M=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R(").86]Z86H@=GEM87IA
MNR`E<S\@5/IT;R!O<&5RX6-I=2!N96UOOFYO('9RX71INR!S<.2[+B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B
M"B).86]Z86H@=GEM87IANR!P;W6^[79A=&6U<VOI(/ID86IE('!R92!P;W6^
M[79A=&6U82`E<S\@5/IT;R!O<&5RX6-I=2!N96UOOFYO("(*(G9RX71INR!S
M<.2[+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@
M(E9RX71I('-PY+L@5F&Y=2!P;W-L961N^B!A:V-I=2(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS
M9VED(")2969R97-H(@IM<V=S='(@(D]B;F]V:;LB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,SDU"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%
M;&5M96YT<SHB"FUS9W-T<B`B3V)N;W9INR!E;&5M96YT>2!D>6YA;6EC:^EH
M;R!M96YU.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#4*;7-G:60@
M(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(D]B;F]V:;L@>F]B<F%Z
M96YI92!P;W)TX6QU.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX.3@@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$R,3<@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,SD*
M;7-G:60@(E)E9V5X(@IM<V=S='(@(E)E9W5LX7)N>2!V_7)A>B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HS,C,X"FUS9VED(")296QA=&EO;G-H:7`@0G)O
M=W-E<B(*;7-G<W1R(")0<F5H;&EA9&'H('9ZNV%H;W8B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C`X"FUS9VED(")296QO860B"FUS9W-T<B`B6FYO=G4@;F'H[71A
MNR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V"FUS9VED(")296UA<FMS
M(@IM<V=S='(@(E!O<W1R96AY(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q-PIM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B5GID:6%L96[I
M('-E<G9E<GDB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*
M;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R
M9&4I.B(*;7-G<W1R(")6>F1I86QE;N$@55),("AH='1P.B\O=W=W+F5X86UP
M;&4N8V]M+VAO<F1E*3HB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D
M:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*
M;7-G:60@(E)E;6]V92(*;7-G<W1R(")/9'-T<N%N:;LB"@HC.B!T96UP;&%T
M97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*;7-G:60@(E)E;6]V92!";&]C:R(*
M;7-G<W1R(")/9'-T<N%N:;L@8FQO:R(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HU-38*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS
M9W-T<B`B3V1S='+A;FF[('-TY7!E8R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T
M:6YG(@IM<V=S='(@(D]D<W1RX6YINR!F;W)MX71O=F%N:64B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B
M"FUS9W-T<B`B3V1S='+A;FF[('#A<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V
M97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(")/9'-T<N%N:;L@
M=6QOOF5N_2!S:W)I<'0@>B!D;^AA<V[I:&\@<')I9>AI;FMA(&YA('-E<G9E
M<FDN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0R"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(D]D<W1R
MX6YINR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H
M92!D;V-U;65N="(*;7-G<W1R(")/9'-T<N%N:;L@=&5N=&\@8F]D('H@9&]K
M=6UE;G1U(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ
M,0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B3V1S='+A;FF[('!O=;[M
M=F%T9;5A(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU
M"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R
M(")/9'-T<N%N:;L@<&]UONUV871EM6$Z("5S(@H*(SH@;&EB+TAO<F1E+U)0
M0R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A
M;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`B3F$@<&^^
M:6%D879K=2!N96)O;&\@;6^^;ND@;V1P;W9E9&&[+B!.X79R871O=OT@:_-D
M(&-H>6)Y.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30U
M"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N
M(@IM<V=S='(@(E!OOF%D;W9A;OH@<VQUOF)U('-A(&YE<&]D87)I;&\@;N%J
M<[LN(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-S8@;&EB+TAO<F1E+G!H<#HU,3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C
M:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B5B!K;VYF:6=U
M<N%C:6D@)7,@;FEE(&IE(+EP96-I9FEK;W9A;N$@<&^^861O=F%NX2!P;VQO
MOFMA(%PB)7-<(B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HV-S@@;&EB+U9&4R]F
M='`N<&AP.C@U,"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW,S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@
M5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E8@:V]N9FEG=7+A8VEI(%9&
M4R!N:64@:F4@N7!E8VEF:6MO=F%NX2!P;[YA9&]V86[A('!O;&^^:V$@7"(E
M<UPB(@H*(SH@;&EB+TAO<F1E+U5T:6PN<&AP.C<W-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R(")6(&MO;F9I9W5RX6-I:2!N:64@:F4@N7!E
M8VEF:6MO=F%NX2!P;[YA9&]V86[A('!O;&^^:V$@7"(E<UPB(@H*(SH@;&EB
M+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER960@
M1FEE;&0B"FUS9W-T<B`B4&]V:6YNZ2!P;VQE(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S$@;&EB+TAO<F1E+T9O<FTN<&AP.C,T,R!L:6(O2&]R9&4O1F]R;2]2
M96YD97)E<BYP:'`Z,S(P"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHQ,#`@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I
M9"`B4F5S970B"FUS9W-T<B`B5GEM87IANR!F;W)M=6SA<B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E="!087-S=V]R
M9"(*;7-G<W1R(")/8FYO=FF[(&AE<VQO(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS
M9W-T<B`B3V)N;W9INR!68;EE(&AE<VQO(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$S,`IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(D]B
M;F]V:;L@<&]S;&5D;OT@9&]T87HB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z
M-S$@861M:6XO8VUD<VAE;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV
M-@IM<V=I9"`B4F5S=6QT<R(*;7-G<W1R(")6_7-L961K>2(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N
M9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B3N%V
M<F%T(&YA(&YA<W1A=F5N:6$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B"FUS9W-T<B`B
M6F%D86IT92!N;W;I(&AE<VQO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Y-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R
M(")2975N:6]N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A
M=&EO;B(*;7-G<W1R(")6<N%T:;L@:V]N9FEG=7+A8VEU(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/
M<'1I;VYS(@IM<V=S='(@(DYA<W1A=F5N:6$@<F]ZN>UR96[I:&\@=&5X=&]V
MZ6AO(&5D:71O<G4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G
M:60@(E)I9&1L97,B"FUS9W-T<B`B2.%D86YK>2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG
M:'0B"FUS9W-T<B`B5G!R879O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q
M,3`*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R(")(;&%V:>AK82!V<')A
M=F\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P-@IM<V=I9"`B4FEG:'0@
M=F%L=65S(@IM<V=S='(@(DAO9&YO='D@=G!R879O(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED
M(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B5FQA<W1N;W-T:2!?<FEA
M9&MA+BXN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR
M,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B4F]L82(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X
M-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N
M:6$B"FUS9W-T<B`B4G5M=6YS:V\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C(T"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@
M(D]T;^AINR!O(#$X,"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,C$*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(D]T;^AI
MNR!VM6%V;R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,C<*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R(")/=&_H:;L@=G!R
M879O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B5FQA
M<W1N;W-T:2!R:6%D:V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*
M;7-G<W1R(")6;&%S=&YO<W1I(')I861K82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G
M<W1R(")2:6%D:WDZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T<B`BR&EA
M<GDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L
M;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(LAI87)Y('-A('IO8G)A>FEA
M(&UE9'II(':Y971K_6UI(')I861K86UI(&$@<W3E<&-A;6DB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS
M9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*
M;7-G<W1R("+(:6%R>2!S82!Z;V)R87II82!I8F$@;65D>FD@<W3E<&-A;6DB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@
M;VYL>2(*;7-G<W1R("+(:6%R>2!S82!Z;V)R87II82!I8F$@;65D>FD@<FEA
M9&MA;6DB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P"FUS9VED(")2=6XB
M"FUS9W-T<B`B4W!U<W1INR(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO
M;B(*;7-G<W1R(")2=7-KX2!F961E<N%C:6$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C`P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#@*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B
M"FUS9W-T<B`B4G=A;F1A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*
M;7-G<W1R(")3+TU)344@:W)Y<'1O9W)A9FEC:_T@<&]D<&ES(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R
M>7!T960@365S<V%G92(*;7-G<W1R(")3<'+A=F$@>F&Y:69R;W9A;N$@<&]M
M;V-O=2!3+TU)344B"@HC.B!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HX,0IM
M<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R(")305-,(&%U=&5N=&EF:6OA8VEA(&YI92!J92!D;W-T=7!NX2XB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`V"FUS9VED(")335,@
M365S<V%G:6YG(@IM<V=S='(@(E!O<VEE;&%N:64@4TU3(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B4U%,
M(%-H96QL(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S(*;7-G:60@(E-1
M3"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B4U%,('!R
M[6MA>B!P<F4@:+5A9&%N:64@:&]D;O1T(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0S,PIM<V=I9"`B4U-((@IM<V=S='(@(E-32"(*"B,Z(&QI
M8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM
M<V=I9"`B4U5#0T534R(*;7-G<W1R("+:4U!%0T@B"@HC.B!L:6(O87!I+G!H
M<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B4U]13"!3:&5L;"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*
M;7-G:60@(E-A(@IM<V=S='(@(E-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(P-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA
M(@IM<V=S='(@(E-VY'3A($AE;&5N82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@
M86YD($YE=FES(@IM<V=S='(@(E-VY'3]($MI='1S(&$@3F5V:7,B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G
M:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(E-VY'3A($QU8VEA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$X.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DR"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I
M9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R(")3=BX@4&EE
M<G)E(&$@36EQ=65L;VXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0T
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T
M:&4@1W)E;F%D:6YE<R(*;7-G<W1R(")3=N1T_2!6:6YC96YT(&$@1W)E;F%D
M:6YY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(E1E;B!I
M<W3]('+A;65C("A?<V5L9BDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C4Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")386UO82(*;7-G<W1R(")3
M86UO82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`B4V%N($UA<FEN
M;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,38@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R(")3
M86\@5&]M92!A(%!R:6YC:7!E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B4V%T
M96QI=&[]('!O<VMY=&]V871EM2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I82(*
M;7-G<W1R(")3875D<VOA($%RX6)I82(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHY.0IM<V=I9"`B4V%V92(*;7-G<W1R(")5;&^^:;LB"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L('!H<"UF
M;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(E5L;[YINR!<(B5S
M7"(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(E5L;[YINR`E<R(*"B,Z
M('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N
M<R(*;7-G<W1R(")5;&^^:;L@;F%S=&%V96YI82(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M
M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB56QOOFF[('9Y9V5N
M97)O=F%N^B!K;VYF:6=U<N%C:74@86MO(%!(4"!S:W)I<'0@9&\@9&_H87-N
MZ6AO('!R:67H:6YK82!6X;EH;R`B"B)S97)V97)A+B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D
M("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DMO;F9I9W5RX6-I82`E<R!B
M;VQA('5L;[YE;N$N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B4VMR:7!T(&YA('5P9W)A9&4@;F%S
M=&%V96[M(&)O;"!U;&^^96[](&1O.B!<(B5S7"(N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E-C871T97)E
M9"!4+5-T;W)M<R(*;7-G<W1R(")/:F5D:6YE;.D@8OIR:WDB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B
M5F5D82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B
M"FUS9W-T<B`B2+5A9&&[(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,R,@IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B5GEHM6%DX79A
MZ&4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDV,@IM<V=I9"`B4V5L96-T
M($9I;&5S(@IM<V=S='(@(E9Y8F5R=&4@<_IB;W)Y(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X,@IM<V=I9"`B4V5L96-T(&$@
M9&%T92(*;7-G<W1R(")6>6)E<G1E(&3A='5M(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D
M9"(*;7-G<W1R(")6>6)E<G1E('-K=7!I;G4@;F$@<')I9&%N:64B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED(")396QE8W0@82!N
M97<@;W=N97(B"FUS9W-T<B`B5GEB97)T92!N;W;I:&\@=FQA<W1N[6MA(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")396QE
M8W0@82!S97)V97(B"FUS9W-T<B`B5GEB97)T92!S97)V97(B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E
M<B!T;R!A9&0B"FUS9W-T<B`B5GEB97)T92!P;W6^[79A=&6U82!N82!P<FED
M86YI92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HV
M-S,*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B5GEB97)T92!VN65T:WDB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8U,`IM<V=I9"`B4V5L96-T(&%L
M;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(E9Y8F5R=&4@=KEE=&MY(&MO
M;7!O;F5N='D@9.%T=6UU(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C@W,`IM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R
M(")6>6)E<G1E(&]B:F5K="(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-S0*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(EIR
M=;EINR!V_6)E<B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I
M9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE
M(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@
M=&AE;2!F<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(B(*(E9Y8F5R=&4@
M>FYA:WDL(&MT;W+I('!O=')E8G5J971E+"!Z(&]K:65N;VL@;FF^N6EE+B!0
M;W1O;2!I8V@@;?2^971E("(*(G-K;W#M<F]V8;L@82!V;&^^:;L@>B!T97AT
M;W;I:&\@<&^U82XB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM
M<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B5GEB
M97)T92!O9&1EM6]V8>@@=F\@9F]R;>%T92!DX71U;74Z(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F
M;W)M870Z(@IM<V=S='(@(E9Y8F5R=&4@9F]R;>%T(&3A='5M=3HB"@HC.B!T
M96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")3
M96QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T
M<B`B5GEB97)T92!I9&5N=&ET=2P@:W1O<OH@8VAC971E('IM96YINSHB"@HC
M.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H
M92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B5GEB97)T92!O9&1EM6]V8>@@
M=F\@9F]R;>%T92#H87-U.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC
M.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R(")6
M>6)E<G1E(&9O<FWA="#H87-U.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*
M;7-G<W1R(")6>6)E<G1E(&1V92!Z:&]D;ND@<&]L:6$N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,Q,`IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@
M<V-H96UE+B(*;7-G<W1R(")6>6)E<G1E('-I(&9A<F5B;OH@<V-HZ6UU(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U,@IM<V=I9"`B4V5L96-T('EO
M=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R(")6>6)E<G1E(&IA>GEK
M.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED
M(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(E!O<VQANR!S<'+A=G4@
M;R!P<F]B;.EM92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,#,Y"FUS9VED(")396YD(%--4R(*;7-G<W1R(")0;W-L8;L@4TU3
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R(")396YE9V%L(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,38*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@
M(E-E;GIO<CH@(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P-R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*
M;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R(")397!T96UB97(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD
M($UO;G1E;F5G<F\B"FUS9W-T<B`B4W)B<VMO(&$@R&EE<FYA(&AO<F$B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,@IM<V=I9"`B4V5R:6%L
M($YU;6)E<B(*;7-G<W1R(")3Z7)I;W;I(.CM<VQO(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$T.0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O
M;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`BVF1A:F4@>F\@<V5R=F5R
M82!S^B!N97-P<N%V;F4@86QE8F\@;FEE('/Z(&1O<W1U<&[I+B(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G
M<W1R(")!9&UI;FES='+A8VEA('-E9&5N[2(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X<&ER
M960N(@IM<V=S='(@(E!L871N;W.[($E$('-E9&5N:6$@=GEP<KEA;&$N(@H*
M(SH@;&EB+V%P:2YP:'`Z,30U"FUS9VED(")397-S:6]N<R(*;7-G<W1R(")3
M961E;FEA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S,3@*;7-G:60@(E-E
M="(*;7-G<W1R(")-;F^^:6YA(&AO9&[T="(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HW.0IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O
M(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*
M;7-G<W1R(").87-T879T92!M;[YN;W-T:2!N82!O8FYO=F5N:64@5N&Y:&\@
M:&5S;&$@86L@:&\@>F%B=61N971E+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,3@*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO
M=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B
M"B).87-T879E;FEE('9Z9&EA;&5N_6-H('-E<G9E<F]V+"!K=2!K=&]R_6T@
M8VAC971E('!R:7-T=7!O=F&[('H@5N&Y:&\@(@HB<&]R=.%L=2XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<*;7-G:60@(E-E="!Y;W5R('!R969E
M<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS
M9W-T<B`B5GEB97)T92!J87IY:RP@Z&%S;W;Z('KS;G4@82!N87-T879E;FEA
M(&3A='5M=2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Q"FUS9VED
M("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE
M;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T
M:6]N<RXB"FUS9W-T<B`B(@HB3F%S=&%V96YI92!A<&QI:^%C:64@<W#ZN;MA
M;F5J('!R:2"Y=&%R=&4L(&9A<F5B;F5J('-C:.EM>2P@:6YT97)V86QU("(*
M(F]B;F]V;W9A;FEA('-T<N%N:WD@82!I;OUC:"!V;&%S=&YO<W3M('IO8G)A
M>F5N:6$N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0IM<V=I9"`B
M4V5T=7`B"FUS9W-T<B`B3F%S=&%V96YI92(*"B,Z('1E;7!L871E<R]A9&UI
M;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C
M<FEP=',@879A:6QA8FQE(@IM<V=S='(@(E/Z(&1O<W1U<&[I('-K<FEP='D@
M;F$@=7!G<F%D92!N87-T879E;NTB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,3<U"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L
M92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R(")$;R#Z=F%H>2!P<FEC
M:.%D>F$@;FEE:V^U:V\@;&]K86SM="!P;VUO8V]U('!A<F%M971R83H@(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R(")397EC:&5L>2(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.3@*;7-G:60@(E-H;W!P:6YG(@IM
M<V=S='(@(E-H;W!P:6YG(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B2W+A=&MY
M('/Z:')N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U,`IM<V=I9"`B
M4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_
M(@IM<V=S='(@(DUA:OH@<V$@<')E(';DZ+EI;G4@;&EN:65K('9Y='9O<FF[
M('-K<F%T:V]VZ2!K;.%V97-Y/R(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z
M,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(EIO8G)A>FF[(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D:69F
M97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY
M(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B):;V)R
M87IINR!R;WID:65L>2!M961Z:2!P<N%V92!U;&^^96YO=2!A(&YO=F]V>6=E
M;F5R;W9A;F]U(&MO;F9I9W5RX6-I;W4N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0Y-`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L
M;V=G:6YG(&EN/R(*;7-G<W1R(")-X2!S82!P<FD@<')I:&SA<V5N[2!Z;V)R
M87IINR#H87,@<&]S;&5D;NEH;R!P<FEH;.%S96YI83\B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3<V.0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O
M<FEG:6YA;"(*;7-G<W1R("):;V)R87IINR!M;[YN;W.[(&YA('!O;F5C:&%N
M:64@;W)I9VENX6QU(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#(*;7-G
M:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(EIO8G)A>FF[(&[A<W1R;VH@;F$@
M=OUB97(@9F%R:65B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S,`IM
M<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R
M("):;V)R87IINR!M96YU('!R92!O<&5RX6-I92!S('1A8G6U:V%M:3\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4S"B,L('!H<"UF;W)M870*;7-G
M:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(EIO
M8G)A>FF[(&UE;G4@)7,@;F$@M6%V96H@<W1R86YE/R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I
M9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G
M<W1R("):;V)R87IINR!D:6%L\V<@<R!V;&%S=&YO<[MA;6D@8G5N:WD@=&%B
M=;5K>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE
M<R!D:6%L;V<B"FUS9W-T<B`B6F]B<F%Z:;L@9&EA;/-G(',@=FQA<W1N;W.[
M86UI('1A8G6U:WDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O
M=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("):;V)R87IINR!D:6%L\V<@
M<R!V;&%S=&YO<[MA;6D@<FEA9&MU('1A8G6U:WDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@
M(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(EIO
M8G)A>FF[(&1I86SS9R!S('9L87-T;F]SNV%M:2!O8G+A>FMU(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$W-C<*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S
M='(@(EIO8G)A>FF[(&YA:')A;NDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R(")0
M<F5HX6YK>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4Q"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(E+A;F\@<')E
M:.%N:WDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,@IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(DYE<VOT<B!P<F5H
MX6YK>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4S"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("):
M<N&^:WD@=B!O:V]L[2(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP
M.C0X,`IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(EIM96ZY:;LB"@HC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HW-S0@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="YP:'`Z.#,V"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.CDR
M,B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HY.#0*(SH@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="YP:'`Z,3`T-R!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+G!H<#HQ,#@W"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C$Q,38@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,3$T.0IM<V=I9"`B4VAR:6YK
M(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y
M(&9I<G-T(@IM<V=S='(@(DYA:G!R=B!M=7/M=&4@>FUE;KEINR!A;&5B;R!P
M<F5S=6[ZNR!S=7-E9&[](&)L;VLH>2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C$Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O
M;F4B"FUS9W-T<B`B4VEE<G)A($QE;VYE(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M4VEG;G5P+G!H<#HR-C8*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B6F%R96=I
M<W1R;W9ANR!S82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S$S
M"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`B4&]D<&ES(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92!!;&=O
M<FET:&TB"FUS9W-T<B`B06QG;W)I=&UU<R!P;V1P:7-U(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(P-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B
M4VEN9V%P;W)E(@IM<V=S='(@(E-I;F=A<'5R(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.CDP,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q.2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3(T,0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(U,"!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,CDQ.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$Q,@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV-2!L:6(O2&]R9&4O
M34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=&=Z+G!H<#HX-`IM<V=I9"`B4VEZ92(*;7-G<W1R(")69;5K;W.[(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*
M;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B4')E<VMOZ&F[(/ID
M<KYB=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(E-L;W9E;G-K;R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(P-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(E-L;W9I;G-K;R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3
M;F]W(@IM<V=S='(@(E-N9;YE;FEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S
M='(@(E-N96AO=N$@<')E:.%N:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S
M='(@(E-N96AO=ND@<')E:.%N:WDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY
M(@IM<V=S='(@(E+A;F\@<VYE:&]VZ2!P<F5HX6YK>2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H
M;W=E<G,@3&%T92(*;7-G<W1R(").97-K]'(@<VYE:&]VZ2!P<F5HX6YK>2(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X"FUS9VED(")3;F]W(&1E<'1H
M.B`B"FUS9W-T<B`B2.5B:V$@<VYE:'4Z("(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C@R"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*
M;7-G<W1R(")-;F^^<W1V;R!V;V1Y(&5K=FEV86QE;G1NZ2!S;F5H=3H@(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(JEA;&%M^FYO=F4@
M;W-T<F]V>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,30@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B4V]MX6QS:V\B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@
M4&]E;7,B"FUS9W-T<B`B4&EE<VYE(&$@8N%S;F4B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,CDQ-0IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS
M9W-T<B`B5OUB97(@<VUE<G4@=')I961E;FEA(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4U.2!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3@Y"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C$W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z
M(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ-C8@;&EB+TYE="]335,O=VEN
M7VAT='`N<&AP.C$X.0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B
M6F1R;VIO=N$@861R97-A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S
M='(@(DIUOF[A($%F<FEK82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V
M"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I
M8V@@27-L86YD<R(*;7-G<W1R(")*=;YNX2!'96]R9VEA(&$@4V]U=&@@4V%N
M9'=I8V@@27-L86YD<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B
M"FUS9W-T<B`B2G6^;N$@<&]L;V=UM6$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E
M;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R(")-961Z97)A(&UE9'II('-U<V5D
M;OUM:2!B=6YK86UI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A
M;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B365D>F5R82!M961Z:2!O8G-A
M:&]M(&$@;VMR86IO;2!B=6YK>2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX
M,3D*;7-G:60@(E-P86-E<B(*;7-G<W1R(")/9&1EM6]V8>@B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G
M:60@(E-P86-I;F<B"FUS9W-T<B`B3V1S='5P(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A
M8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R(")/9'-T=7`@82!V>7!L;F5N:64B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(P.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`BJ7!A;FEE;'-K;R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#`*;7-G:60@(E-P86TB"FUS9W-T<B`B
M4W!A;2(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E
M8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B5FQOOF5N:64@N7!E8VGA
M;&YY8V@@>FYA:V]V(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R
M(")2;WID96QINR!B=6YK=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*
M;7-G<W1R(")2;WID96QINR!S=.5P96,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R
M;W<B"FUS9W-T<B`B4F]Z9&5L:;L@<FEA9&]K(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`BJ7!O<G1Y(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X
M"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B4W+M($QA;FMA(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8V(&QI8B]";&]C:R]M971A<BYP
M:'`Z-S0*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(JET86YD87)D;NDB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*
M;7-G<W1R(")3=&%R(%1R96LB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y
M,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y.`IM<V=I9"`B4W1A<G0@>65A<B(*
M;7-G<W1R(")0;^AI871OZ&[](')O:R(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3<Q"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R
M("*I=.%T(&%L96)O('!R;W9I;F-I82(*"B,Z('1E;7!L871E<R]A9&UI;B]S
M971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B4W1A
M=B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#`T"FUS9VED(")3=&]R86=E
M(&9O<FUA="(*;7-G<W1R(")&;W)MX70@=6QOOF5N:6$B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B4W1R965T($%D9')E<W,B
M"FUS9W-T<B`B0GED;&ES:V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S
M='(@(E!R9;EK<G1N=73I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,S<*
M;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(EIO>FYA;2!R9;MA>F-O=B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<W"FUS9VED(")3=')I<"!D;VUA
M:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R(")/9'-T<N%N:;L@9&]MZ6YU
M('H@861R97-Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B
MJ73];"!;0U-372(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(DYE(@H*(SH@=71I;"]I
M8V]N7V)R;W=S97(N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(E-U8F1I
M<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")0;V1P<FEEZ&EN
M;VL@7"(E<UPB(&YE8F]L(&[A:F1E;OTN(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B
M4')E9&UE="(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S8@;&EB+TAO<F1E
M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@
M(D]D;W-L8;LB"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE
M('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U
M97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B"B)0;[YI861A=FMA
M(&YA('!R:61A;FEE(%PB)7-<(B!D;R!S>7-TZ6UU(&)O;&$@;V1O<VQA;N$N
M($YE;?2^971E('-A("(*(G!R:6ALX7-INRP@:_UM(&YE8G5D92!68;EA('!O
MOFEA9&%V:V$@<V-H=N%L96[A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R
M(")$;VQN_2!I;F1E>"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#0@;&EB
M+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS
M9VED(")3=6-C97-S(@IM<V=S='(@(MIS<&5C:"(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E
M9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B4')I9&%N:64@7"(E
M<UPB(&1O('-Y<W3I;74@8F]L;R#Z<W!EN6[I+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE
M87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM
M<V=S='(@(E9Y;6%Z86YI92#Z9&%J;W8@>F\@<WES=.EM=2!P<F4@<&]UONUV
M871EM6$@7"(E<UPB(&)O;&\@^G-P9;ENZ2XB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R
M(")6>6UA>F%N:64@7"(E<UPB(&)O;&\@^G-P9;ENZ2XB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B5GEM
M87IA;FEE(%PB)7-<(B!Z;R!S>7-TZ6UU(&)O;&\@^G-P9;ENZ2XB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@
M<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S
M+B(*;7-G<W1R("(B"B).X79R870@:W4@:V]N9FEG=7+A8VEI(&)O;"#Z<W!E
MN6[]+B!0<F4@>F]B<F%Z96YI92!Z;6EE;B!Z;F]V=2!N8>CM=&%J=&4@(@HB
M<W1RX6YK=2XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E
M9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B6N%L;VAA(&MO;F9I
M9W5RX6-I92!B;VQA('5L;[YE;N$N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V
M960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@
M(EKA;&^^;OT@:V]N9FEG=7)AZ&[]('/Z8F]R("5S(&)O;"#Z<W!EN6YE('5L
M;[YE;OTN(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R(")!
M:W1U86QI>N%C:6$@7"(E<UPB(&)O;&$@^G-P9;ENX2XB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS
M9W-T<B`B6N%P:7,@)7,@8F]L(/IS<&6Y;OTB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C`T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3$*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*
M;7-G<W1R(")3=63A;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B
M4_IH<FXB"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@(E-U
M;B!2:7-E(@IM<V=S='(@(E;]8VAO9"!S;&YK82(*"B,Z(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R("):X7!A9"!S
M;&YK82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4Y"FUS9VED(")3=6YN>2(*;7-G<W1R(")3;&YEZ&YO(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-0IM<V=I9"`B4W5N<FES92(*;7-G
M<W1R(")6_6-H;V0@<VQN:V$B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N
M<V5T(@IM<V=S='(@(E;]8VAO9"]ZX7!A9"!S;&YK82(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,#0*;7-G:60@(E-U;G)I<V4Z("(*;7-G
M<W1R(")6_6-H;V0@<VQN:V$Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,#@*;7-G:60@(E-U;G-E="(*;7-G<W1R("):X7!A9"!S;&YK
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#<*;7-G:60@
M(E-U;G-E=#H@(@IM<V=S='(@(EKA<&%D('-L;FMA.B`B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E
M<G-C<FEP="(*;7-G<W1R(")(;W)N_2!I;F1E>"(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS.#`*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B4&]D
M<&]R82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,34@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(E-U<FEN86TB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B4W5R;F%M
M92(*;7-G<W1R(")0<FEE>G9I<VMO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(P.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD
M($IA;B!-87EE;B(*;7-G<W1R(")3=F%L8F%R9"!A($IA;B!-87EE;B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3D@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(Q-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@*
M;7-G:60@(E-W87II;&%N9"(*;7-G<W1R(")3=F%Z:6IS:V\B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C`U(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED
M(")3=V5D96XB"FUS9W-T<B`BJ7;I9'-K;R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HU-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N
M9"(*;7-G<W1R("*I=F%JZ&EA<G-K;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@
M(EKA>FYA;7D@;R!S>6YC:')O;FEZX6-I:2!V>6UA>F%NZ2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-#4*;7-G:60@(E-Y;F--3"(*;7-G<W1R(")3
M>6YC34PB"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I
M9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R(")3>6YT
M86MT:6-KX2!C:'EB82!V('!O9&UI96YK86-H(&BU861A;FEA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PIM<V=I
M9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B4_UR:6$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B
M5"U3=&]R;2(*;7-G<W1R(")"^G)K82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD
M>2(*;7-G<W1R(")"^G)K82!A('9E=&5R;F\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3=&]R;7,B"FUS
M9W-T<B`B0OIR:WDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B4N%N
M;R!B^G)K>2(*"B,Z(&QI8B](;W)D92]$871A+W1S=BYP:'`Z,38V"FUS9VED
M(")44U8@9FEL92(*;7-G<W1R(")44U8@<_IB;W(B"@HC.B!L:6(O2&]R9&4O
M54DO5&%B;&4N<&AP.C$S-`IM<V=I9"`B5&%B;&4B"FUS9W-T<B`B5&%B=;5K
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B5FQA
M<W1N;W-T:2!T86)UM6MY(@H*(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L
M97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R
M"FUS9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@(E9L87-T;F]S=&D@
M=&%B=;5K>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S0@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS9W-T<B`B
M5&%I=V%N(@H*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM
M<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R(")486EW
M86XL('!R;W9I;F-I82#([6YY(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(R-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G
M<W1R(")4862^:6MI<W1A;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B5&%N>N%N:6$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")487)G970Z
M(@IM<V=S='(@(D-I9;4Z(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDY
M-B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@Y"FUS9VED(")487-K<R(*
M;7-G<W1R("+:;&]H>2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3<T"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(E1E;&5F\VYN
M92#H[7-L;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP"FUS9VED(")4
M96UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")497!L;W1A('IA('!O<VQE
M9&[Z(&AO9&EN=3H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,30*;7-G
M:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(E1E<&QO=&$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$R"FUS9VED(")496UP97)A='5R93H@
M(@IM<V=S='(@(E1E<&QO=&$Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\
M8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R(")497!L;W1A
M/&)R("\^*"5S36%X)7,O)7--:6XE<RD@)F1E9SLE<R(*"B,Z(&QI8B](;W)D
M92]496UP;&%T92YP:'`Z-C@W"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!L
M871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(JEA8FSS;F$@7"(E<UPB
M(&YE8F]L82!NX6ID96[A+B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y
M"FUS9VED(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")3<'+A
M=F$@N6%B;/-N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,34@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,S,C4*;7-G:60@(E1E>'0B"FUS9W-T<B`B5&5X="(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-SD*;7-G:60@(E1E>'0@3VYL
M>2(*;7-G<W1R("))8F$@=&5X="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB
M"FUS9W-T<B`B6F%R;W9N86YI92!T97AT=2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS
M9W-T<B`B5&5X="!H;W)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`BJ70B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM<V=I9"`B5&AA:2`H5$E3+38R,"DB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B5&AA:G-K
M;R(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX-#`*;7-G:60@(E1H92!&5%`@97AT
M96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E)O>KGM<F5N:64@
M1E10(&YI92!J92!D;W-T=7!NZ2XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.CDS,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT
M96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S
M='(@(DEN=&5G<N%C:6$@2&]R9&4O2V]L86(@;F5P;V1P;W)U:F4@7"(E<UPB
M(@H*(SH@;&EB+TYE="])35-0+T)O;VLN<&AP.C$R.3@*;7-G:60@(E1H92!)
M35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(DE-
M4U`@>N%Z;F%M('-A(&YE<&]D87)I;&\@=6QOOFF[+B(*"B,Z('-E<G9I8V5S
M+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@
M8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R(")4<FEE
M9&$@36%I;G1E;F%N8V4Z.B!S82!N96YAZ.UT86QA(/IS<&6Y;F4B"@HC.B!S
M97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@
M3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B
M3VMN;R!S(&YA<W1A=F5N:6%M:2!S82!Z871V;W)I;&\N($MO;FEE8RXB"@HC
M.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C$X.2!L:6(O2&]R9&4O4&5R;7,N<&AP
M.C(P,"!L:6(O2&]R9&4O4&5R;7,N<&AP.C(Q,0HC.B!L:6(O2&]R9&4O4&5R
M;7,N<&AP.C(R,R!L:6(O2&]R9&4O4&5R;7,N<&AP.C(S-"!L:6(O2&]R9&4O
M4&5R;7,N<&AP.C(U,@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(V-"!L:6(O
M2&]R9&4O4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T
M;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS
M(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*
M;7-G<W1R("(B"B)!9&UI;FES='+A=&]R(&UU<^T@;F%K;VYF:6=U<F]V8;L@
M<&5R;6%N96YT;OT@8F%C:V5N9"!P<F4@4'+A=F$L(&%K(&-H8V5T92`B"B)P
M;W6^[79ANR!0<N%V82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@
M;VYL>2(*;7-G<W1R("))8F$@<W!O9&[A('-T<F%N82(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT
M86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O
M<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B
M(@HB240@Z.US;&\@:V]N=&%K='4@;F5B;VQO(+EP96-I9FEK;W9A;NDL(&)O
M;&\@<&]N96-H86[I('!RX7ID;F4@86QE8F\@;F5B;VQO("(*(F[A:F1E;ND@
M=B!D871A8N%Z92XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D
M9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")+;VYT86MT(&)O
M;"#Z<W!EN6YE('9L;[YE;OT@9&\@5N&Y:&\@861R97/A<F$N(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$W,@IM<V=I9"`B(@HB5&AE(&1E=&%C
M:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y
M('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@HB3F$@;W9E<F5N:64@
M<&]D<.US86YE:B!S<'+A=GD@:F4@<&^^861O=F%N_2!O9&1E;&5N_2!B;&]K
M(',@4$=0('!O9'!I<V]M+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)
M1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T
M(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B(@HB240@>F]Z
M;F%M=2!P<NUJ96UC;W8@8G7O(&YE8F]L;R"Y<&5C:69I:V]V86[I+"!A;&5B
M;R!B;VQO('!O;F5C:&%NZ2!P<N%Z9&YE("(*(F%L96)O(&YE8F]L;R!NX6ID
M96[I('8@9&%T86+A>F4N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N
M;W0@<W!E8VEF:65D+B(*;7-G<W1R(").96)O;"!U<NAE;OT@>F]Z;F%M('!R
M[6IE;6-O=BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0N<&AP.C$Q-@IM<V=I9"`B
M5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@
M8V]N;F5C=&EO;BXB"FUS9W-T<B`BJ6EF<F]V86YI92!V>;YA9'5J92!B97IP
M9>ANZ2!P<FEP;VIE;FEE("AH='1P<RDN(@H*(SH@;&EB+TAO<F1E+G!H<#HQ
M-S<@;&EB+TAO<F1E+G!H<#HU,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R
M(")3^F)O<B`E<R!B>2!M86P@;V)S86AO=F&[(&YA<W1A=F5N:64@)7,N(@H*
M(SH@;&EB+TAO<F1E+G!H<#HQ-S`@;&EB+TAO<F1E+G!H<#HU,#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M
M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B4_IB;W(@)7,@8GD@;6%L(&]B<V%H
M;W9ANR!N:65K=&]RZ2!N87-T879E;FEA("5S+B(*"B,Z(&QI8B]61E,O9FEL
M92YP:'`Z,C(S"FUS9VED(")4:&4@9FEL92!C86YN;W0@8F4@8V]P:65D(&]N
M=&\@:71S96QF+B(*;7-G<W1R("):9')O:F]V_2!A(&-I9;5O=OT@<_IB;W(@
M;75S:6$@8GF[(&]D;&FY;NDN(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C(X
M,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@
M(E/Z8F]R(&YE;V)S86AO=F%L(+YI861N92#Z9&%J92XB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO
M=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@
M;65S<V%G92XB"FUS9W-T<B`B3F%S;&5D=6KZ(&AL879IZ&MY('1E:G1O('-P
M<N%V>2!V;R!F;W)MX71E(&UE<W-A9V4O<F9C.#(R+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H
M92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US
M('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U
M9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M
M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E
M9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S
M+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@
M;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I
M;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B
M965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@
M=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B
M(@HB0V5L;V]B<F%Z;W9K;W;](')EOFEM('-P]'-O8G5J92!P<F]B;.EM>2!V
M($EN=&5R;F5T($5X<&QO<F5R:2!K=O1L:2!C:'EBX6T@(@HB<')E:&QI861A
MZ&$L(&MT;W+I('-A(&[A;2!N97!O9&%R:6QO(&]B[7.[+B!-]+YU('-A('!R
M96IA=FF[(&YE<W!RX79N>6T@(@HB>F]B<F%Z96[M;2P@8VC]8F%J^F-I;6D@
M9G5N:V-I86UI(&5D:71O<F$@82]A;&5B;R!NX6AO9&[];6D@<.%D;6D@(@HB
M<')E:&QI861AZ&$N($%K(&IE(%;AN2!S>7-TZ6T@5VEN9&]W<R`Y>"P@:F4@
M=F6U;6D@<')A=F1E<&]D;V)NZ2P@OF4@<V$@(@HB>F]B<F%Z[2!C:'EB82`G
M1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A(&)U9&5T92!M=7-I9;L@<F6Y
M=&%R=&]V8;L@<&_H[71AZ"XB"B)<7&Y<7&Y687)O=F%L:2!S;64@5N%S+B!3
M=&QAZ'1E('!R;W/M;2!/2R!A:R!N86]Z86H@8VAC971E('!O=;YINR!E9&ET
M;W(@=B`B"B)C96QO;V)R87IO=FMO=F]M(')EOFEM92XB"@HC.B!S97)V:6-E
M<R]P<F5F<RYP:'`Z.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT
M:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("))9&5N=&ET
M82!<(B5S7"(@8F]L82!V>6UA>F%NX2XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F
M="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("))8F$@M6%VX2!S=')A;F$B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L
M;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@
M=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R(")4<FEE9&$@0W)Y<'1?
M<&=P.CH@<&]T<F5B=6IE('!O>FYANR!U;6EE<W1N96YI92!P<F]G<F%M=2!'
M;G501RXB"@HC.B!L:6(O2&]R9&4O34E-12]-1$XN<&AP.C(P,0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S
M('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB
M5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E
M;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*(E-P<N%V82!O9&]S
M;&%NX2`E<R!P<F4@)7,@<R!P<F5D;65T;VT@7"(E<UPB(&)O;&$@>F]B<F%Z
M96[A+EQN(@HB3F5E>&ES='5J92!VN6%K('KA<G5K82P@OF4@<W!RX79A(&)O
M;&$@<')EZ.UT86[A(&%L96)O('!O8VAO<&5NX2XB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3@X,0IM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN
M:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(DUE;F\L(&MT;W+I
M('-A(&WA('!O=;YINR!P<FD@;&EN:V]V86[M(&YA('-T<N%N:W4@;F$@<.US
M86YI92!S<'+A=B`B"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0W-`IM<V=I9"`B
M5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R
M(")0;^AE="!P;VSM(&UU<^T@8GF[(.CM<VQO+B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z,3(S,@IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE
M(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S
M<RXB"FUS9W-T<B`B5')I961A($AO<F1E7T-R>7!T7W-M:6UE.CH@=GF^861U
M:F4@;6]D=6P@;W!E;G-S;"XB"@HC.B!L:6(O2&]R9&4O4')E9G,N<&AP.C(X
M,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S
M7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D
M960@=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@HB
M3F%S=&%V96YI92!<(B5S7"(@<V$@;F5P;V1A<FEL;R!U;&^^:;LL('!R971O
MOF4@:F5H;R#Z9&%J92!P<F5K<F'H=6KZ("(*(FUA>&EMX6QN=2!P;W9O;&5N
M^B!V9;5K;W.[(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+V1E8BYP:'`Z
M,S(@;&EB+TAO<F1E+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,B!L:6(O2&]R9&4O
M34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=V5B8W!P+G!H<#HS-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<W)C
M:&EG:&QI=&4N<&AP.C,W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<V5X
M8V5L+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A
M;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O
M=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*(E!R;V=R86T@<&]UONUV
M86[](&YA('IO8G)A>F5N:64@=&]H=&\@^F1A:F]VZ6AO('1Y<'4@*"5S*2!N
M96)O;"!NX6ID96[]+B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#@W"FUS9VED
M(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R
M86-T97(N(@IM<V=S='(@(EIN86L@8VETX6-I92!M=7/M(&)YNR!J961E;B!Z
M;F%K+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O
M;FQY(@IM<V=S='(@(DEB82!P<F%VX2!A(+5A=N$@<W1R86YA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM
M<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(DEB82!P
M<F%VX2!S=')A;F$B"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0W.0IM<V=I9"`B
M5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*
M;7-G<W1R(")/9&1EM6]V8>@@;75S[2!B>;L@:F5D96X@>FYA:RXB"@HC.B!S
M97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G
M<W1R(")397)V97(@7"(E<UPB(&)O;"!V>6UA>F%N_2XB"@HC.B!S97)V:6-E
M<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B4V5R
M=F5R(%PB)7-<(B!B;VP@=6QOOF5N_2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O
M<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("*N:6%D;W.[(&\@<')I
M:&SA<V5N:64@)7,@8F]L82!V>6UA>F%NX2XB"@HC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S<&5C:69I960@<F]W(&1O
M97,@;F]T(&5X:7-T+B(*;7-G<W1R("*I<&5C:69I:V]V86[](')I861O:R!N
M965X:7-T=6IE+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HQ-SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO
M="!E>&ES="XB"FUS9W-T<B`B1&_H87-N_2!S^F)O<B!<(B5S7"(@;F5E>&ES
M='5J92XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,P,`IM<V=I9"`B5&AE
M('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T
M:&4@<V-R965N+B(*;7-G<W1R("):861A;OT@=&5X="!N:64@:F4@<F]V;F%K
M_2!A:V\@=&5X="!N82!O8G)A>F]V:V4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O
M<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B26)A(&AO<F[A(&$@
M<W!O9&[A('-T<F%N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY
M(@IM<V=S='(@(DEB82!H;W)NX2!S=')A;F$B"@HC.B!L:6(O2&]R9&4O1&%T
M82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S
M:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B3F%H<F%NZ2#Z9&%J
M92!S82!O9"!P<F5D8VCA9'IA:OIC96AO(&MR;VMU('-T<F%T:6QI+B(*"B,Z
M(&QI8B](;W)D92]$871A+V-S=BYP:'`Z,C8R(&QI8B](;W)D92]$871A+W1S
M=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@
M8F4@<V%V960N(@IM<V=S='(@(DYA:')A;OT@<_IB;W(@<V$@;F5P;V1A<FEL
M;R!U;&^^:;LN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Y
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3`*;7-G:60@(E1H92!W
M96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")"
M;&]K('=E871H97(N8V]M(&YI92!J92!D;W-T=7!N_2XB"@HC.B!U=&EL+VEC
M;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S
M(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")0<FEEZ&EN
M;VL@=.EM(%PB)7-<(B!N96)O;"!NX6ID96[]+B(*"B,Z(&QI8B](;W)D92]0
M<F5F<R]522YP:'`Z,3<X"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A
M=F%I;&%B;&4N(@IM<V=S='(@(JYI861N92!N87-T879E;FEA(&YI92!S^B!D
M;W-T=7!NZ2XB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z,S0Y
M"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA
M>65D(&EN;&EN92XB"FUS9W-T<B`BKFEA9&YE(&%L=&5R;F%T[79N92#H87-T
M:2!N96UOOFYO('IO8G)A>FF[('8@=&5L92!S<'+A=GDN(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$T,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U
M(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E
M<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*(E8@=&]M=&\@<&]L:2!J92!P
M<NUL:;D@=F6U82!Z;F%K;W8N(%IA9&%L:2!S=&4@)7,@>FYA:V]V.R!M=7/M
M=&4@>F%D8;L@;65N96H@(@HB86MO("5S+B(*"B,Z('-I9VYU<"YP:'`Z-3,@
M861M:6XO=7-E<BYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S
M(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@<')I('!R:63A=F%N[2!<(B5S7"(@
M9&\@<WES=.EM=3H@)7,B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D
M871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R
M("(B"B).87-T86QA(&-H>6)A('!R:2!O9'-T<F'R;W9A;NT@<&]UONUV871E
MM7-K_6-H(/ID86IO=B!<(B5S7"(@>F\@<WES=.EM=3H@(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM
M<V=S='(@(DYA<W1A;&$@8VAY8F$@<')I(&]D<W1R8?)O=F%N[2!<(B5S7"(@
M>F\@<WES=.EM=3H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E
M<UPB.B`E<R(*;7-G<W1R(").87-T86QA(&-H>6)A('!R:2!A:W1U86QI>N%C
M:6D@7"(E<UPB.B`E<R(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R
M(")6>7-K>71O;"!S82!P<F]B;.EM(',@;F%H<N%V86[M;2!S^F)O<G4Z(*YI
M861E;B`E<R!N96)O;"!N86AR86[]+B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R
M+G!H<#HY,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G
M97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S
M*2XB"FUS9W-T<B`B(@HB5GES:WET;VP@<V$@<')O8FSI;2!S(&YA:'+A=F%N
M[6T@<_IB;W)U.B`E<R!B;VP@=N3HN>T@86MO(&YA:G;DZ+GM('!O=F]L96[]
M("(*(FQI;6ET("@E9"!B86IT;W8I+B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R
M+G!H<#HY,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY
M('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B5GES:WET;VP@<V$@<')O
M8FSI;2!S('5K;&%D86[M;2!S^F)O<G4Z("5S(&)O;"!N86AR86[](&QE;B#H
M:6%S=&_H;F4N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H
M:7,@;65S<V%G92!P87)T(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@<')I('IO
M8G)A>F]V86[M('1E:G1O(.AA<W1I('-P<N%V>2(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R(").87-T86QA(&-H>6)A
M('!R:2!I;7!O<G1E(/ID86IO=B!O(&MO;G1A:W1E+B(*"B,Z(&QI8B](;W)D
M92]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(").87-T86QA
M(&-H>6)A('!R:2!I;7!O<G1E(/ID86IO=B!I0V%L96YD87(N(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U
M(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*(DYA
M<W1A;&$@8VAY8F$@=B!K;VYF:6=U<F'H;F]M(&9O<FUU;.%R:2X@4')A=F1E
M<&]D;V)N92!S=&4@;F5V>7!L;FEL:2`B"B)P;[YA9&]V86[I('!O;&4N(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE
M9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@
M;&%T97(N(@IM<V=S='(@(B(*(DYA<W1A;&$@8VAY8F$@<')I('9Y:V]NX79A
M;NT@=7+H96YE:B!F=6YK8VEE(&%D<F5SX7)A+B!0<F]S[6T@<VOZ<W1E('1O
M("(*(FYE<VOT<BXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB
M"FUS9W-T<B`B(@HB3F%S=&%L82!C:'EB82!P<FD@86MT=6%L:7KA8VEI(&1E
M=&%I;&]V(&MO;G1A:W1U+B!0<F]S[6T@<VOZ<W1E('1O(&YE<VOT<BXB"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U(&QI8B].970O
M4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E
M<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(DYA<W1A;&$@8VAY8F$@<')I
M(&%K='5A;&EZX6-I:2!Z;WIN86UU('!R[6IE;6-O=BX@4')O<^UM('-K^G-T
M92!T;R!Z;F]V=2XB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,30X"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O
M<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R(")496YT;R!)34%0('-E<G9E
M<B!N97!O9'!O<G5J92!Z9&EEM6%N:64@<')I9>AI;FMO=BXB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S
M(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T
M<B`B5&]T;R!P<F%V9&5P;V1O8FYE(&YI92!J92!P;&%T;OT@87)C:.UV(')A
M<BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I
M9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL
M92XB"FUS9W-T<B`B5&]T;R!P<F%V9&5P;V1O8FYE(&YI92!J92!P;&%T;OT@
M87)C:.UV('II<"XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$S-`IM<V=I
M9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB
M97(N(@IM<V=S='(@(E1O=&\@<')A=F1E<&]D;V)N92!N:64@:F4@<&QA=&[I
M(.CM<VQO(&MA<G1Y+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O
M(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M22(*;7-G<W1R("(B"B)496YT;R!O=FSA9&'H('5M;[[R=6IE('!O<VEE;&%N
M:64@<W!RX78@8V5Z(&)RX6YU($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC
M:V%T96QL+F-O;2D@<&]M;V-O=2!(5%10($%022(*"B,Z(&QI8B].970O4TU3
M+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO
M+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*
M;7-G<W1R("(B"B)496YT;R!O=FSA9&'H('5M;[[R=6IE('!O<VEE;&%N:64@
M<W!RX78@8V5Z(&)RX6YU(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(G!O
M;6]C;W4@2%144"!!4$DB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B
M"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB
M"FUS9W-T<B`B(@HB5&5N=&\@;W9LX61AZ"!U;6^^\G5J92!P;W-I96QA;FEE
M('-P<N%V(&-E>B!B<N%N=2!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA
M:6PN8V]M*2!P;VUO8V]U($A45%`@05!)(@H*(SH@;&EB+TYE="]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@
M86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T
M:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N
M92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@
M(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T
M<B`B(@HB5&5N=&\@;W9LX61AZ"!U;6^^\G5J92!P;W-I96QANR!S<'+A=GD@
M8V5Z(%--5%`@8V5Z(&)RX6YU(%9O9&%F;VYE($ET86QY("(*(BAI8F$@;F$@
MZ.US;&$@5F]D869O;F4I+B!6>;YA9'5J92!E+6UA:6QO=OT@^NAE="!6;V1A
M9F]N92!)=&%L>2`H:'1T<#HO+R(*(G=W=RXQ.3`N:70I+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HY.#(@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-C$@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$P.3`*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q
M,3D@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q.#8@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$R-C`*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,#D@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$T,#(@;&EB+TAO<F1E+T9O<FTN<&AP.C$U-C$*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$X-#,@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-C(@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(P,#D*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P
M,S,@;&EB+TAO<F1E+T9O<FTN<&AP.C(P.#(@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(Q-3,*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R,C4@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(T,3(@;&EB+TAO<F1E+T9O<FTN<&AP.C(T-30*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(V-#0@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,3<@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,Q,C8*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R
M.34@;&EB+TAO<F1E+T9O<FTN<&AP.C,X,#,@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,X,3$*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@
M(E1O=&\@<&]L92!J92!P;W9I;F[I+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,#8Y"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT
M96=E<G,N(@IM<V=S='(@(E1O=&\@<&]L92!M]+YE(&]B<V%H;W9ANR!I8F$@
MZ.US;&$N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,C`*;7-G:60@(E1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L
M;VXN(@IM<V=S='(@(E1O=&\@<&]L92!M]+YE(&]B<V%H;W9ANR!I8F$@Z.US
M;&$@82!D=F]J8F]D:W4N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P.3@*
M;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU
M97,N(@IM<V=S='(@(E1O=&\@<&]L92!M]+YE(&]B<V%H;W9ANR!I8F$@;W-M
M:>AK;W;I(&AO9&YO='DN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,C<*
M;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E
M<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(E1O=&\@<&]L92!M
M=7/M(&)YNR!Z;WIN86T@Z.US96P@;V1D96QE;OUC:"#H:6%R:V]U(&%L96)O
M(&UE9'IE<F]U(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDY,PIM<V=I9"`B
M5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R(")4
M;W1O('!O;&4@;75S[2!B>;L@<&QA=&[I(.CM<VQO+B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR.#(U"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N
M=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@
M97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*(E1O=&\@<&]L92!M
M=7/M(&]B<V%H;W9ANR!K\V0@9F%R8GD@=B"Y97-T;N%S=&MO=F]M(&9O<FWA
M=&4@4D="+"!N87!R[6ML860@(@HB)R,Q,C,T868G+B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HU-C4*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B
M965N('!R;V-E<W-E9"XB"FUS9W-T<B`B5&5N=&\@9F]R;75LX7(@=;X@8F]L
M('-P<F%C;W9A;OTN(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B5&]T
M;R!J92`E<RXB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0U.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B
M:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M
M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U
M<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI
M96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@HB5&]T;R!J92!O8FIE
M:W0@2V]L86(@1W)O=7!W87)E+B!0<F4@>F]B<F%Z96YI92!T;VAT;R!O8FIE
M:W1U('!O=')E8G5J971E(&4M(@HB;6%I;&]VZ6AO(&ML:65N=&$L(&MT;W+]
M(')O>G5M:64@9F]R;>%T=2!+;VQA8B!'<F]U<'=A<F4N(%!R92!Z;WIN86T@
M(@HB=&%K_6-H=&\@:VQI96YT;W8@;F%VN73M=G1E('!R;W/M;2`E<R(*"B,Z
M(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HU.3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C
M=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*
M(E3A=&\@<W!RX79A(&)O;&$@;F%P[7-A;N$@=B!I;F5J(&%K;R!686UI('!O
M=;[M=F%N96H@>FYA:V]V96H@<V%D92`H)7,I+B(*"B,Z(&QI8B](;W)D92]0
M<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T
M(&QE87-T(&]N92XB"FUS9W-T<B`B5&]T;R#H[7-L;R!M=7/M(&)YNR!N86IM
M96YE:B`Q+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM
M<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z
M:7`@9FEL97,N(@IM<V=S='(@(E1E;G1O('-E<G9E<B!N961O:^&^92!D96MO
M;7!R:6UO=F&[('/Z8F]R>2!Z:7`@82!G>FEP+B(*"B,Z(&QI8B](;W)D92]2
M96=I<W1R>2YP:'`Z,3@R"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT
M;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(E-Y<W3I;2!J92!M;VUE;G3A;&YE
M(&1E86MT:79O=F%N_2XB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$R
M-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R
M(")4X71O(&AO9&YO=&$@;75S[2!B>;L@Z.US96QNX2XB"@HC.B!S97)V:6-E
M<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O
M=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S
M='(@(E1O=&\@;VMN;R!M=7/M(&)YNR!Z879O;&%NZ2!Z(&]K;F$@3F%S=&%V
M96[M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C0*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B2')M96YI92(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR,S8*;7-G:60@(E1I8VME=',B"FUS9W-T
M<B`B5&EC:V5T<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#(Y('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B5&EM92(*;7-G<W1R
M("+(87,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@X"FUS9VED
M(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(E1I;64@5')A8VMI;F<B"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S
M='(@(D9O<FWA="#H87-U(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U,S4*
M;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(E;]8F5R(.AA<W4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,P(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P
M"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R(")4:6UO<BU,97-T92(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R(")4:71U;&]K
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R(").861P:7,@*&)U
M8FQI;F]V_2!V_7!I<RDZ(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(E!R92(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HV-3$*;7-G:60@(B(*(E1O
M('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L
M("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N
M(@IM<V=S='(@(B(*(E!R92!V_6)E<B!V:6%C97+]8V@@<&]L;[YI96L@9'*^
M=&4@<&_H87,@:VQI:V%N:6$@:VSA=F5S=2!#;VYT<F]L("A00RD@86QE8F\@
M(@HB0V]M;6%N9"`H36%C*2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S`P"FUS9VED(")4;V1A>2(*;7-G<W1R(")$;F5S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B
M5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(E!R97!N^KL@>F]B<F%Z96YI
M92!Z9')O:F]VZ6AO(&OS9'4@2%1-3"(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T
M<B`B5&]G;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B5&]K96QA=2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#(*;7-G:60@(E1O
M;6]R<F]W(@IM<V=S='(@(EIA:G1R82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S
M='(@(E1O;F=A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`B5G)C:"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G
M:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B5G)C:&[]('+A;65C("A?
M=&]P*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A
M;G-L871I;VYS(@IM<V=S='(@(E!R96ML861Y(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(S,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED
M860@86YD(%1O8F%G;R(*;7-G<W1R(")4<FEN:61A9"!A(%1O8F%G;R(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ-SDT"FUS9VED(")4<G5E(&]R(&9A;'-E
M(@IM<V=S='(@(E!R879D82!A;&5B;R!N97!R879D82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM
M<V=S='(@(E5T(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R."!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R(")4=6YI<VMO
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(E1U<F5C:V\B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM
M.2DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@
M(E1U<FMM96YI<W1A;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L
M86YD<R(*;7-G<W1R(")4=7)K<R!A($-A:6-O<R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S
M,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L
M=2(*;7-G<W1R(")4=79A;'4B"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR-C0*
M;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R("):861A:G1E(%9A
MN74@=F^U8G4Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-3@*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R(")5+E8N(&EN9&5X.B`B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O
M0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(E523"(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@
M(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*
M;7-G<W1R(")54DP@5N&Y:&\@<VMR:7!T=2!P<F4@<W!RX79U(&\@9&]R=>AE
M;NTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(E523#HB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C,W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")59V%N
M9&$B"FUS9W-T<B`B56=A;F1A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(S-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G<W1R
M(")5:W)A:FEN82(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-#$V"FUS9VED(")5
M;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYE<&]D
M87)I;&\@<V$@=7-K=71OZ&YINR!P<NUS='5P(&L@5D93(&%D<F5SX7)U+B(*
M"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L
M92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@
M=7`N(@IM<V=S='(@(B(*(DYE<&]D87)I;&\@<V$@<')I9&&[(.]A;+EI92!I
M;F9O<FWA8VEE(&\@<&]UONUV871EM6]V:2!P<FD@<F5G:7-T<N%C:6DN(@H*
M(SH@;&EB+U9&4R]F='`N<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!Z;65N:;L@<'+A=F\@<')E(%9&
M4R!S^F)O<B!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS.#D@;&EB
M+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM
M<V=S='(@(DYE<&]D87)I;&\@<V$@>FUE;FF[('!RX79O('!R92!61E,@<_IB
M;W(@)7,O)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<W-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R(").
M97!O9&%R:6QO('-A('IM96YINR!N82`E<RXB"@HC.B!L:6(O5D93+V9T<"YP
M:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F
M:6QE('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R(").97!O9&%R:6QO('-A('-K
M;VYT<F]L;W9ANR!V9;5K;W.[('/Z8F]R=2!<(B5S7"(N(@H*(SH@;&EB+U9&
M4R]F:6QE+G!H<#HV.3(@;&EB+U9&4R]S<6PN<&AP.C$P,3D@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z.#0R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R(").97!O
M9&%R:6QO('-A('-K;VYT<F]L;W9ANR!V9;5K;W.[('/Z8F]R=2!<(B5S+R5S
M7"(N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<W%L+G!H<#HT,SD*;7-G:60@(E5N
M86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(DYE<&]D
M87)I;&\@<V$@<W!O:FF[(',@4U%,('-E<G9E<F]M+B(*"B,Z(&QI8B]61E,O
M9G1P+G!H<#HX-3D*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,
M+B(*;7-G<W1R(").97!O9&%R:6QO('-A('-P;VIINR!P;VUO8V]U(%-33"XB
M"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(R.2!L:6(O5D93+V9I;&4N<&AP.C(S
M-"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,#0*(SH@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,C`Y(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(Q-PIM<V=I9"`B56YA
M8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@
M<VMO<.UR;W9ANR!61E,@<_IB;W(N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,W
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D
M:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(").97!O9&%R:6QO('-A('9Y='9O
M<FF[(%9&4R!A9')E<^%R(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP
M.C,U."!L:6(O5D93+VUU<W%L+G!H<#HR-3@@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z,C8T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN
M(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@=GET=F]R:;L@5D93(&%D<F5SX7(N
M(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@
M8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R(").97!O9&%R:6QO('-A('9Y='9O
M<FF[(%9&4R!S^F)O<BXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z,CDP"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<
M(B5S7"(N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@=GET=F]R:;L@5D93('!R
M:67H:6YO:R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR-CD*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@
M(DYE<&]D87)I;&\@<V$@=GET=F]R:;L@<'+A>F1N>2!61E,@<_IB;W(N(@H*
M(SH@;&EB+TAO<F1E+T-O;7!R97-S+W1A<BYP:'`Z-S8@;&EB+TAO<F1E+T-O
M;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S
M<R!D871A+B(*;7-G<W1R(").97!O9&%R:6QO('-A(&1E:V]M<')I;6]V8;L@
M^F1A:F4N(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C(R."!L:6(O5D93+V9T<"YP
M:'`Z,S`S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B
M3F5P;V1A<FEL;R!S82!V>6UA>F&[(%PB)7-<(BP@861R97/A<B!N:64@:F4@
M<'+A>F1N>2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS
M+V1E;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R(").97!O9&%R:6QO('-A('9Y
M;6%Z8;L@7"(E<UPB.B`E<RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,S-2!L
M:6(O5D93+W-Q;"YP:'`Z,SDU(&QI8B]61E,O;75S<6PN<&AP.C,Q,0HC.B!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HS-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP
M='DB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!V>6UA>F&[("5S+"!A9')E<^%R
M(&YI92!J92!P<N%Z9&YY(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S4V
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,V,`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R(").97!O
M9&%R:6QO('-A(')E:W5R>NUV;F4@=GEM87IANR!61E,@861R97/A<BXB"@HC
M.B!L:6(O5D93+V9I;&4N<&AP.C,T,2!L:6(O5D93+VUU<W%L+G!H<#HS,C(@
M;&EB+U9&4R]M=7-Q;"YP:'`Z,S,U"B,Z(&QI8B]61E,O;75S<6PN<&AP.C,T
M,R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!V
M>6UA>F&[(%9&4R!A9')E<^%R+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HT,C`@
M;&EB+U9&4R]S<6PN<&AP.C0S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(").97!O
M9&%R:6QO('-A('9Y;6%Z8;L@5D93(&%D<F5SX7(Z("5S+B(*"B,Z(&QI8B]6
M1E,O9G1P+G!H<#HR,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYE<&]D87)I;&\@
M<V$@=GEM87IANR!61E,@<_IB;W(@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL
M92YP:'`Z,S`W(&QI8B]61E,O<W%L+G!H<#HR.3$@;&EB+U9&4R]M=7-Q;"YP
M:'`Z,38W"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$X,"!L:6(O5D93+VUU<W%L
M+G!H<#HQ.#<@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ"B,Z(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C,Y.0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9FEL92XB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!V>6UA>F&[(%9&4R!S^F)O
M<BXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z,C0X"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S
M='(@(DYE<&]D87)I;&\@<V$@=GEM87IANR!61E,@<')I9>AI;F]K(%PB)7-<
M(BXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z-#`Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS
M9W-T<B`B3F5P;V1A<FEL;R!S82!R96MU<GKM=FYE('9Y;6%Z8;L@5D93.B`E
M<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#(S"FUS9VED(")5;F%B;&4@=&\@
M9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R(").97!O9&%R
M:6QO('-A('5RZ&F[(&%K='7A;&YY(&%D<F5SX7(N(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV,#0*;7-G:60@(E5N86)L92!T;R!E>'1R86-T
M(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!Z
M:7-T:;L@<&]D<F]B;F]S=&D@;R!C97)T:69I:^%T92XB"@HC.B!L:6(O3F5T
M+TE-4U`N<&AP.C0S-R!L:6(O3F5T+TE-4U`O075T:"YP:'`Z,3(S"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N
M(&]F("5S+B(*;7-G<W1R(").96UOOF[I(&YA:')ANR!D969I;NUC:74@)7,N
M(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,#`@;&EB+U9&4R]F:6QE+G!H<#HR
M,#4@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3<T"B,Z(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C$W.0IM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM
M<V=S='(@(DYE<&]D87)I;&\@<V$@<')E<W5N^KL@5D93('/Z8F]R+B(*"B,Z
M(&QI8B]61E,O<VUB+G!H<#HY,R!L:6(O5D93+W-M8BYP:'`Z,3`V(&QI8B]6
M1E,O<VUB+G!H<#HV-3(*(SH@;&EB+U9&4R]F='`N<&AP.CDX"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!O='9O<FF[(%9&4R!S^F)O<B!<(B5S
M7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR.#$@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,3,X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$T,0IM<V=I9"`B56YA
M8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(DYE
M<&]D87)I;&\@<V$@;W1V;W)INR!61E,@<_IB;W(@;F$@>N%P:7,N(@H*(SH@
M;&EB+U9&4R]F:6QE+G!H<#HX,R!L:6(O5D93+V9I;&4N<&AP.C$S-"!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HW-@IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93
M(&9I;&4N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@;W1V;W)INR!61E,@<_IB
M;W(N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G
M:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T
M<B`B3F5P;V1A<FEL;R!S82!O='9O<FF[(&MO;7!R:6UO=F%N_2!A<F-H[78N
M(@H*(SH@;&EB+U9&4RYP:'`Z.#4U"FUS9VED(")5;F%B;&4@=&\@<F5A9"!6
M1E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+B(*;7-G<W1R(").97!O9&%R
M:6QO('-A('!R9>CM=&&[(%9&4R!S^F)O<B`H9G5N:V-I82!F:6QE<VEZ92@I
M('IL>6AA;&$I+B(*"B,Z(&QI8B]61E,N<&AP.C@X-@IM<V=I9"`B56YA8FQE
M('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS
M9W-T<B`B3F5P;V1A<FEL;R!S82!P<F7H[71ANR!61E,@<_IB;W(@*&9U;FMC
M:6$@9V5T1FEL95-I>F4H*2!Z;'EH86QA*2XB"@HC.B!L:6(O2&]R9&4O4V5S
M<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D
M(&9I;&4Z("(*;7-G<W1R(").97!O9&%R:6QO('-A('!R9>CM=&&[('/Z8F]R
M.B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-C<S"FUS9VED(")5;F%B;&4@=&\@
M<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(DYE<&]D87)I
M;&\@<V$@Z.UT8;L@861R97/A<B!V9G-R;V]T+B(*"B,Z(&QI8B](;W)D92]+
M;VQA8BYP:'`Z,3$P-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E
M>&ES=',B"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!P<F5M96YO=F&[("5S(&YA
M("5S.B!C:66U;W;]('!R:67H:6YO:R!UOB!E>&ES='5J92(*"B,Z(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C,P,0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!6
M1E,@9&ER96-T;W)Y+B(*;7-G<W1R(").97!O9&%R:6QO('-A('!R96UE;F]V
M8;L@5D93(&%D<F5SX7(N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C,S,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O
M<GDZ("5S+B(*;7-G<W1R(").97!O9&%R:6QO('-A('!R96UE;F]V8;L@5D93
M(&%D<F5SX7(Z("5S+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HR-S$@;&EB+U9&
M4R]F='`N<&AP.C,T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S
M82!P<F5M96YO=F&[(%9&4R!S^F)O<B!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HV,30@;&EB+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM
M<V=S='(@(DYE<&]D87)I;&\@<V$@<')E;65N;W9ANR!61E,@<_IB;W(@)7,O
M)7,N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C,R-B!L:6(O5D93+VUU<W%L+G!H
M<#HR,3,@;&EB+U9&4R]M=7-Q;"YP:'`Z-#4R"B,Z(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C(Y,R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS,#D*;7-G:60@(E5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@(DYE<&]D87)I;&\@
M<V$@<')E;65N;W9ANR!61E,@<_IB;W(N(@H*(SH@;&EB+U9&4R])4T]7<FET
M97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O
M9G,G+B(*;7-G<W1R(").97!O9&%R:6QO('-A('-P=7-T:;L@)VUK:7-O9G,G
M+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS
M9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*
M;7-G<W1R(").97!O9&%R:6QO('-A('!R96QOOFF[('1E;G1O(&1O:W5M96YT
M(%=O<F0B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,34T(&QI8B]61E,O9G1P+G!H
M<#HQ-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!Z87#M<V&[
M(%9&4R!S^F)O<B!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ.#,*
M;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE
M9"DN(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@>F%P[7-ANR!61E,@<_IB;W(@
M*&9U;FMC:6$@8V]P>2@I('IL>6AA;&$I+B(*"B,Z(&QI8B]61E,O9FEL92YP
M:'`Z,C@U(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$T-B!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HQ-3$*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D
M871A+B(*;7-G<W1R(").97!O9&%R:6QO('-A('IA<.US8;L@^F1A:F4@5D93
M('/Z8F]R=2XB"@HC.B!L:6(O5D93+G!H<#HX-C$*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS
M9W-T<B`B3F5P;V1A<FEL;R!S82!Z87#M<V&[(%9&4R!S^F)O<BP@:W;S=&$@
M:F4@<')E:W)OZ&5NX2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B4&]D
MZ&EA<FMN=73I(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I
M9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(EIR=;EINR!Z;65N>2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@
M(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(EIR=;GM('!O<VQE
M9&[Z(&%K8VEU(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(R,R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED
M(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I
M;VXZ("(*;7-G<W1R(").96_H86OA=F%NX2!O9'!O=F7O(&]D('-E<G9E<F$@
M<&_H87,@<W!O:F5N:6$Z("(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HR,3D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T
M,0HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*;7-G:60@(E5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R(").96_H86OA
M=F%NX2!O9'!O=F7O(&]D('-E<G9E<F$@;F$Z("(*"B,Z(&QI8B](;W)D92]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM
M<V=S='(@(DYE;F%S=&%V96[A(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#D*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(S-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B
M56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B4W!O:F5NZ2!A<F%B<VOI
M(&5M:7+A='DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(E9E
MM6OA($)R:73A;FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R
M(")3<&]J96[I(+ETX71Y($%M97)I8VOI(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(S.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T
M871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV,B!L:6(O0FQO8VLO;65T87(N
M<&AP.C<Q"FUS9VED(")5;FET<R(*;7-G<W1R(")*961N;W1K>2(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C0R.2!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HT,S`*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-3@*
M;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B3F5Z;N%M92(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P
M:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(DYE>F[A;64@87!I
M;7-G:60@*$%022!-97-S86=E($E$*2XB"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H
M0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R(").97INX6UE(&-L:6US9VED
M("A#;&EE;G0@365S<V%G92!)1"DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$T-PIM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E
M9"XB"FUS9W-T<B`B0F]L82!Z861A;N$@;F5P;&%T;N$@;&]K86QI=&$N(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G:60@
M(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(DYE>F[A
M;64@<&]UONUV871EM7-KZ2!M96YO(&%L96)O(&AE<VQO+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.`IM
M<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B3V1S
M='+A;FF[(&QI;FMU('H@86MT=>%L;F5H;R!E;&5M96YT=2(*"B,Z(&QI8B](
M;W)D92])9&5N=&ET>2YP:'`Z,S`Q"FUS9VED(")5;FYA;65D(@IM<V=S='(@
M(DYE<&]M96YO=F%NX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S
M(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY
M(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@
M=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@
M>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B
M;V%R9"XB"FUS9W-T<B`B(@HB3F5P<FEV:6QE9V]V86[I('-K<FEP='D@;F5M
M86KZ('H@8F5Z<&7H;F]S=&[]8V@@9/1V;V1O=B!P<NUS='5P(&L@=F^U8N%M
M("(*(E9Y<W1R:6AN^KLO2V]P[7)O=F&[+U9L;[YINRX@2VQI:VYI=&4@;F$@
M3TL@82!Z;V)R87KM('-A('1E8VAN:6-KX2`B"B)I;F9O<FWA8VEA(&YA('-T
M<N%N:V4@;6]Z:6QL82YO<F<L(&MT;W+A(%;A<R!I;F9O<FUU:F4L(&%K;R!U
M;6^^;FF[('-K<FEP='4@(@HB<'+M<W1U<"!K('-C:'+A;FME+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*
M;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(D]D<W1RX6YINR!F87)B=2(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C@W(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z.3(W"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z.3,S"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B
M3F5P;V1P;W)O=F%NZ2!R;WJY[7)E;FEE(@H*(SH@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*
M;7-G:60@(E5P9&%T92(*;7-G<W1R(")!:W1U86QI>N%C:6$B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R(")!:W1U86QI>F]V8;L@)7,B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5
M<&1A=&4@=7-E<B(*;7-G<W1R(")!:W1U86QI>F]V8;L@<&]UONUV871EM6$B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H
M<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`B06MT=6%L:7KA
M8VEA(%PB)7-<(B!B;VQA(/IS<&6Y;N$N(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM
M<V=S='(@(E-K<FEP="!N82!U<&=R861E(&)O;"!V>6UA>F%N_2XB"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ.3@*;7-G:60@(E5P;&]A9"(*;7-G<W1R(").86AR
M8;LB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO
M861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E
M<BXB"FUS9W-T<B`B5KEE=&MY('/Z8F]R>2!S(&MO;F9I9W5RX6-I;W4@8F]L
M:2!N86AR86[I(&YA('-E<G9E<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L
M871I;B!L971T97)S(@IM<V=S='(@(E9EM6OI(&QA=&EN<VOI('#M<VUE;N$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@
M(E9EM6OI('+M;7-K92#H[7-L:6-E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(T,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G
M<W1R(")5<G5G=6%Y(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z
M("5S(@IM<V=S='(@(E!O=;YINR!A:W1UX6QN93H@)7,B"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM
M<V=S='(@(E!O=;YINR!34TPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3(W"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@
M9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R(")0;W6^:71E('8@<'+M<&%D92P@
MOF4@:F4@;65N;R]H97-L;R!O9&QIN6[I('!R92!)35-0('-E<G9E<BXB"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"FUS9VED(")5
M<V5R(@IM<V=S='(@(E!O=;[M=F%T9;4B"@HC.B!L:6(O2&]R9&4O4F5G:7-T
M<GDN<&AP.C<Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO
M="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B4&]UONUV871EM2`E<R!N
M:64@:F4@875T;W)I>F]V86[](&YA("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")3<'+A
M=F$@<&]UONUV871EM6]V(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HR
M-3$*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R(")0;W6^[79A=&6U<VOI
M(&YA<W1A=F5N:6$B"@HC.B!S:6=N=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E
M9VES=')A=&EO;B(*;7-G<W1R(")296=I<W1RX6-I82!P;W6^[79A=&6U82(*
M"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA
M<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(E)E9VES
M='+A8VEA('!O=;[M=F%T9;5O=B!B;VQA('!R92!T96YT;R!S>7-TZ6T@>F%K
MX7IA;N$N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V.0IM<V=I9"`B
M57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R(")0;W6^[79A=&6U<VO]
M(/KH970@;F5B;VP@;N%J9&5N_2(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4S-B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M
M='`N<&AP.CDX"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3DX(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ-3`*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z,S,@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHW,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM
M<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B4&]UONUV871EM7-KZ2!M96YO(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G
M<W1R(")0;W6^[79A=&6U<VOI(&UE;F\@7"(E<UPB('6^(&5X:7-T=6IE+B(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E
M<FYA;64Z(@IM<V=S='(@(E!O=;[M=F%T9;5S:^D@;65N;SHB"@HC.B!T96UP
M;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5<V5R;F%M93H@(@IM
M<V=S='(@(E!O=;[M=F%T9;5S:^D@;65N;SH@(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E
M;3HB"FUS9W-T<B`B4&]UONUV871E;&EA('-Y<W3I;74Z(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(T,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B
M57IB96MI<W1A;B(*;7-G<W1R(")5>F)E:VES=&%N(@H*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HQ-C<@;&EB+U9&4R]F:6QE+G!H<#HR-3D*;7-G:60@(E9&4R!D
M:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(E9&4R!A9')E<^%R
M(&YE97AI<W1U:F4N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$R
M,`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B1&]V;VQE;FMA(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C@W,`IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O
M=6YD(&EN8VQU9&4Z("(*;7-G<W1R(")0;&%T;ND@=6UI97-T;F5N:6$@>F%H
MX/)A:OHZ("(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS
M9VED(")686QI9&ET>2(*;7-G<W1R(")0;&%T;F]SNR(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O
M;2!N;W<N(@IM<V=S='(@(E!L871N;W.[('8@;6EN^G1A8V@@;V1T97)A>BXB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#8P(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,3@Q"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE
M(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R(")(;V1N;W1A('!R96MR
M;^AI;&$@;6%X:6WA;&YU(&3EOFMU("5S+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,C0X(&QI8B](;W)D92]&;W)M+G!H<#HR,C<P(&QI8B](;W)D92]&
M;W)M+G!H<#HR,S(P"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.3$W(&QI8B](
M;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU97,B
M"FUS9W-T<B`B2&]D;F]T>2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3$S
M(&QI8B](;W)D92]&;W)M+G!H<#HR,3DP"FUS9VED(")686QU97,@=&\@<V5L
M96-T(&9R;VTB"FUS9W-T<B`B2&]D;F]T>2P@>B!K=&]R_6-H('-I(&WTOF5T
M92!V>6)R8;LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM<V=S='(@(E9A;G5A='4B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,S"FUS9VED(")6
M87)I86)L92(*;7-G<W1R(")0<F5M96YNX2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L
M82(*;7-G<W1R(")696YE>G5E;&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@
M;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@
M(D]V97)E;FEE('IL>6AA;&\@+2!TX71O('-P<N%V82!M;VAL82!B>;L@<V9A
M;+EO=F%NX2XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,0IM
M<V=I9"`B5F5R<VEO;B(*;7-G<W1R(")697)Z:6$B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C(X"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS
M9W-T<B`B36%N8;YM96YT('9E<GII[2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L
M(&%L:6=N(@IM<V=S='(@(E9E<G1I:^%L;F4@>F%R;W9N86YI92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@
M(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B5F5R=&EKX6QN92!V>7!L;F5N
M:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B5F5R=&EKX6QN93HB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I
M9"`B5F5R>2!(:6=H(@IM<V=S='(@(E9EM6UI('9Y<V]KX2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(T,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@
M(E9I970@3F%M(@IM<V=S='(@(E9I971N86TB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y,`IM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.38Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B6F]B<F%Z:;L@)7,B
M"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X
M=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(EIO8G)A>FF[(&5X=&5R;OH@=W=W
M('-T<N%N:W4B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#(X
M"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B6F]B
M<F%Z:;L@86MO("5S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I
M<V@B"FUS9W-T<B`B0G)I='-KZ2!086YE;G-KZ2!O<W1R;W9Y(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(T-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-@IM<V=I
M9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B06UE<FEC:^D@4&%N
M96YS:^D@;W-T<F]V>2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Y"FUS
M9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(E9I9&ET9;5N;W.[(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,@IM<V=I9"`B5FES:6)I;&ET
M>3H@(@IM<V=S='(@(E9I9&ET9;5N;W.[.B`B"@HC.B!L:6(O3F5T+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L
M>2!V:6$@4TU44"(*;7-G<W1R(")6;V1A9F]N92!)=&%L>2!C97H@4TU44"(*
M"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R(")605)/5D%.244B"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M05).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS
M9W-T<B`B55!/6D]23D5.244A(2$@3T135%+!TE1%(%-+4DE05"!:("5S(%)5
MR$Y%+B(*"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@
M(E=)3B!V:6$@2%144"(*;7-G<W1R(")724X@8V5Z($A45%`B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C4P(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR-#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")786QL:7,@86YD($9U='5N82(*;7-G<W1R(")786QL:7,@82!&=71U;F$B
M"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP
M:'`Z,CD*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R-"!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS9W-T
M<B`B5F%R;W9A;FEE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B4W0B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R
M96-A<W0B"FUS9W-T<B`B4')E9'!O=F7O('!OZ&%S:6$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$V"FUS9VED(")796%T:&5R(&1A=&$@
M<')O=FED960@8GDB"FUS9W-T<B`BVF1A:F4@;R!P;^AA<^T@<&]S:WET=6IE
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y-@IM<V=I9"`B5V5A=&AE<BYC
M;VTB"FUS9W-T<B`B5V5A=&AE<BYC;VTB"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(E=E8B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT,SD*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@
M(E=75R!S='+A;FMA(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU
M.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(E3]OF1E;FYE(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@(E=E;&-O;64B"FUS9W-T
M<B`B5FET86IT92(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(E;M=&$@5N%S("5S(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A
M;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S
M(@IM<V=S='(@(E9I=&%J=&4L("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.3$*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(")797-T97)N("A)
M4T\M.#@U.2TQ-2DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C<X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A
M(@IM<V=S='(@(EKA<&%D;N$@4V%H87)A(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T
M:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R(")+
M=&]R^B!A<&QI:^%C:74@;>$@)7,@>F]B<F%Z:;L@<&\@<')I:&SA<V5N[3\B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA
M="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B06O](&IE
M('IN86L@<')E(&]D9&6U;W9AZ#\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R
M/R(*;7-G<W1R(")!:_T@:F4@>FYA:R!P<F4@^G9O9'IO=FMU/R(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#8Q"FUS9VED(")7
M:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`B36%P82!!=7-T<N%L:64@
M<')E('-L=;YB=2!7:&5R96ES(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S
M"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B2W1O<ND@9N%Z>2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S8*;7-G:60@(E=H:6-H('!L=6=I
M;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T
M<B`B2W1O<ND@>N%S=79NZ2!M;V1U;'D@<&]V;VQINR!P<F4@<F]ZN>UR96[]
M('1E>'1O=OT@961I=&]R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@
M(JGM<FMA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,30*;7-G:60@(E=I
M9'1H(&EN($-34R!U;FET<R(*;7-G<W1R("*I[7)K82!V(&IE9&YO=&OA8V@@
M0U-3(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H
M=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`BJ>UR:V$@
M;65N=2`E<R!VM6%V;R`H<')E:F%V[2!S82!P<FD@[V%LN6]M('!R:6ALX7-E
M;NTI.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`BJ>UR
M:V$@=&%B=;5K>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@(DIE9&YO
M=&MA(+GM<FMY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R("*I[7)K83HB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$U"FUS9VED(")7:6MI(@IM
M<V=S='(@(E=I:VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C@Y(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS
M9VED(")7:6YD(@IM<V=S='(@(E9I971O<B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")7:6YD($5A<FQY(@IM
M<V=S='(@(E+A;F\@=FEE=&]R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX
M,`IM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R(")2_6-H;&]S
MNR!V971R82!V('5Z;&]C:"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34V
M"FUS9VED(")7:6YD.B(*;7-G<W1R(")6:65T;W(Z(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B5VEN9#H@(@IM<V=S='(@
M(E9I971O<CH@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED
M(")7:7-D;VTB"FUS9W-T<B`B3?ID<F]SNR(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ.3@*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(E=I<VAL
M:7-T(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K
M(@IM<V=S='(@(E!RX6-A(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,C0@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")!9')E<V$@9&\@<'+A
M8V4B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM
M<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")496QE9O-N(&1O('!RX6-E(@H*
M(SH@;&EB+T9I;&4O0U-6+G!H<#HQ.3,@;&EB+T9I;&4O0U-6+G!H<#HR.30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I
M;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(DYE
M<W!RX79N>2!P;^AE="!P;VSM(&YA(')I861K=2`E9"X@3^AA:^%V82!S82`E
M9"P@;F&Y;&\@<V$@)60N(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HS,S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP
M96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R(").97-P<N%V;GD@<&_H970@
M<&]L[2X@3^AA:^%V82!S82`E9"P@;F&Y;&\@<V$@)60N(@H*(SH@;&EB+U9&
M4R]F:6QE+G!H<#HQ,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F
M<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B6FS]
M(&]F9G-E="`E9"!P<FD@Z.UT86[M(%9&4R!S^F)O<G4N(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(T-0IM<V=I9"`B6"U2968B"FUS9W-T<B`B
M6"U2968B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I
M9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(EKA:VQA9&[I
M(&]B;65D>F5N:6$@6#4P.78S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS
M9W-T<B`B4&]UOFET:64@<F]ZN>UR96[I:&\@:[7ZZ&$@6#4P.78S(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3
M=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B06QT97)N873M=FYE
M(&UE;F\@<W5B:F5K='4@6#4P.78S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.38*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF
M:65R(@IM<V=S='(@(DED96YT:69I:^%T;W(@:[7ZZ&$@<W5B:F5K='4@6#4P
M.78S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.#,*;7-G:60@
M(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(E@U,#EV,R!R;WJY[7)E;FEA
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@
M(EE9(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q
M,2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4S"FUS9VED
M(")965E9(@IM<V=S='(@(EE965DB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3$P.`IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R
M(")986AO;R$@;6%P(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU
M-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(E)OZ&YE(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(U,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B665M
M96XB"FUS9W-T<B`B2F5M96XB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.38S"FUS9VED(")997,B"FUS9W-T<B`B06YO(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G
M:60@(EEE<RP@22!!9W)E92(*;7-G<W1R(")3^FAL87/M;2XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9
M;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@
M<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@HB4W1E('8@5$58
M5$]63TT@4D6N24U%+B!0;W6^:71E('1L8>AI9&QO(%L\/ET@;F$@<')E<&YU
M=&EE(&YA<W#DNR!D;R!765-)5UE'+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E
M9&ET+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A
M;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R
M(").96WTOF5T92!V>71V;W)INR!V:6%C(&%K;R`E9"!B;&]K;W8N(@H*(SH@
M;&EB+TAO<F1E+G!H<#HQ-#$U"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT
M:6-A=&5D+B(*;7-G<W1R(").:64@<W1E(&%U=&5N=&EF:6MO=F%N_2XB"@HC
M.B!L:6(O2&]R9&4O261E;G1I='DN<&AP.C,P-PIM<V=I9"`B66]U(&-A;FYO
M="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB
M"FUS9W-T<B`B5F\@5F&Y;VT@<&QN;VT@;65N92!N96WTOF5T92!P;W6^:;L@
M>FYA:R`G7%PG+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#4Y(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.3<Y"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A
M('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(DYE>F%D86QI('-T92!P
M;&%T;OH@92UM86EL;W;Z(&%D<F5S=2XB"@HC.B!L:6(O2&]R9&4O1&%T82YP
M:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P
M(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R
M<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*(DYE=7+H
M:6QI('-T92!V>KMA:"!M961Z:2"^:6%D;GEM:2!P;VQI86UI('H@:6UP;W)T
M;W9A;NEH;R!S^F)O<G4@82`B"B)Z;V1P;W9E9&%J^F-I;6D@<&^U86UI('8@
M)7,N(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDX-`IM<V=I9"`B66]U(&AA
M=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R(")";VQI('-T92!O9&ALX7-E
M;OTN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-C4*;7-G:60@(B(*(EEO
M=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG
M:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E
M<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"B)-=7/M=&4@
M>F%D8;L@<&QA=&[I(.CM<VQO(&UO8FEL;NEH;R!T96QE9O-N=2P@:W1O<ND@
M;V)S86AU:F4@:6)A(.CM<VQA(',@(@HB=F]L:71EM6[];2!P<F5F:7AO;2`G
M*R<@<')E(&UE9'II;N%R;V1N_2!F;W)MX70N(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$Q.3(*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@
M=F%L=64N(@IM<V=S='(@(DUU<^UT92!Z861ANR!P;&%T;OH@:&]D;F]T=2XB
M"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@
M;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N
M=7!S+B(*;7-G<W1R("(B"B)!8GD@<W1E(&UO:&QI('!O=;[M=F&[(%)E9VES
M='+A8VEE+"!M=7/M=&4@;F%J<VOT<B!N86MO;F9I9W5R;W9ANR!$871A5')E
M92`B"B)B86-K96YD+B(*"B,Z(&QI8B](;W)D92YP:'`Z-#8R"FUS9VED(")9
M;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B375S
M[71E(&YA:V]N9FEG=7)O=F&[(%9&4R!B86-K96YD+B(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C
M<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B
M;&5M(')E<&]R="XB"FUS9W-T<B`B375S[71E('!O<.US8;L@<')O8FSI;2!P
M<F5D=/UM+"!A:V\@;V1ON6QE=&4@<W!RX79U(&\@<')O8FSI;64N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I
M9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I
M;G1S('1O(@IM<V=S='(@(DUU<^UT92!Z861ANR!54DP@861R97-U+"!N82!K
M=&]R^B!TX71O(&QI;FMA('5K87IU:F4B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<G!C<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E
M<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R(")-=7/M=&4@=GEB<F&[('-E<G9E
M<BP@:W1O<OT@;>$@8GF[('9Y;6%Z86[]+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L
M96%R(&]U="XB"FUS9W-T<B`B375S[71E('5RZ&F[(&UE;F\@<&]UONUV871E
MM6$L(&MT;W+I:&\@8VAC971E('9Y;6%Z8;LN(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@
M<F5M;W9E+B(*;7-G<W1R(")-=7/M=&4@=7+H:;L@;65N;R!P;W6^[79A=&6U
M82P@:W1O<NEH;R!C:&-E=&4@=GEM87IANRXB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@
M(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T
M<B`B375S[71E('5RZ&F[(&UE;F\@<&]UONUV871EM6$L(&MT;W+I:&\@8VAC
M971E('!R:61ANRXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T
M<B`B375S[71E('5RZ&F[('!O=;[M=F%T9;5A+"!K=&]R_2!S82!MX2!A:W1U
M86QI>F]V8;LN(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,X
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O
M<FTN(@IM<V=S='(@(DUU<^UT92!U<NAINR!A:V-I=2P@:W1O<N$@<V$@;>$@
M=GEK;VYANRXB"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N
M86UE+B(*;7-G<W1R(")-=7/M=&4@>F%D8;L@;65N;R!N;W9E:B!K871E9_-R
M:64N(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW
M,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE
M(&YU;6)E<B(*;7-G<W1R(")-=7/M=&4@>F%D8;L@=&%L:6%N<VME('1E;&5F
M\VYN92#H[7-L;R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0
M;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(E!L871N;W.[(%9AN65J
M(')E;.%C:64@<')E(&%P;&EKX6-I=2`E<R!V>7!RN6%L82X@4')O<^UM('!R
M:6ALX7-T92!S82!Z;F]V=2XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@
M(E9AN6$@16UA:6QO=N$@861R97-A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(Q-0IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")6
M8;EA($5M86EL;W;A(&%D<F5S82!P;W6^:73A('!R92!O9&-HX61Z86KZ8W4@
M<&^Y='4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR"FUS9VED(")9;W5R($EN9F]R;6%T
M:6]N(@IM<V=S='(@(E9AN64@:6YF;W)MX6-I92(*"B,Z(&QI8B](;W)D92]!
M=71H+G!H<#HY-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E
M<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I
M='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)68;EA(&EN
M=&5R;F5T;W;A(&%D<F5S82!S82!Z;65N:6QA(&]D('IAZ&EA=&MU(%9AN65J
M(')E;.%C:64@)7,N(%!R92!68;EU("(*(F)E>G!EZ&YO<[L@<V$@;75S[71E
M('IN;W9U('!R:6ALX7-INRXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(E9AN64@;65N
M;R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"FUS9VED
M("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D
M92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A
M(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R
M("(B"B)6X;D@875T96YT:69I:V'H;OT@;6]D=6P@;F5P;V1P;W)U:F4@<')I
M9.%V86YI92!P;W6^[79A=&6U;W8N($%K('-I(+YE;.%T92`B"B)P;W6^:;L@
M2&]R9&4@;F$@<W!RX79U('!O=;[M=F%T9;5S:_UC:"#ZZ'1O=BP@;75S[71E
M('!O=;YINR!I;OT@(@HB875T96YT:69I:V'H;OT@8F%C:V5N9"XB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO
M=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI
M<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B
M;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@HB5N&Y(&%U
M=&5N=&EF:6MAZ&[](&UO9'5L(&YE<&]D<&]R=6IE('IO8G)A>F]V86YI92!Z
M;WIN86UU('!O=;[M=F%T9;5O=BP@(@HB86QE8F\@8F]L82!TX71O(&UOOFYO
M<[L@>B!N96IA:^EH;R!D]'9O9'4@>F%KX7IA;N$N(@H*(SH@;&EB+TAO<F1E
M+T%U=&@N<&AP.CDX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R
M;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN
M;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S
M96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(EID
MX2!S82P@OF4@5N&Y('!R96AL:6%D8>@@<V$@>FUE;FEL(&]D('IAZ&EA=&MU
M(%9AN65J(')E;.%C:64@)7,N(%!R92!68;EU("(*(F)E>G!EZ&YO<[L@<V$@
M;75S[71E('IN;W9U('!R:6ALX7-INRXB"@HC.B!L:6(O0FQO8VLO:69R86UE
M+G!H<#HU-0IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!F96%T=7)E+B(*;7-G<W1R(")6X;D@<')E:&QI861AZ"!N97!O9'!O
M<G5J92!T^G1O(&9U;FMC:74N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M<')I;G0N:G,Z-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S
M=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA
M;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"B)6X;D@<')E:&QI861A
MZ"!N97!O9'!O<G5J92!T^G1O(&9U;FMC:74@=&QAZ&4N(%-T;&'H=&4@0V]N
M=')O;"]#;VUM86YD("L@4"`B"B)P<F4@=&QAZ"XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C8Q"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE
M.B(*;7-G<W1R(")68;EA(&%K='7A;&YA(.AA<V]VX2!Z\VYA.B(*"B,Z('-E
M<G9I8V5S+W!R969S+G!H<#HY.`IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT
M:71Y(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@(E9AN6$@<')E9&YA<W1A
M=F5NX2!I9&5N=&ET82!B;VQA('IM96YE;N$N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$V,0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*
M;7-G<W1R(")0<F5D;F%S=&%V96[A(&ED96YT:71A.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,#0*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G
M<W1R(")68;EE(&UE;F\Z(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDY-@IM
M<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B4&QA=&YO
M<[L@5N&Y:&\@^NAT=2!V>7!RN6%L82XB"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P
M87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(E9AN64@;F]VZ2!H97-L
M;R!P<F4@)7,@:F4Z("5S(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ
M-30*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@
M=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B5F&Y92!N
M87-T879E;FEA(&)O;&D@86MT=6%L:7IO=F%NZ2!P<F4@=&]T;R!S961E;FEE
M+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R
M(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(E9AN64@;F%S
M=&%V96YI82!B;VQI(&%K='5A;&EZ;W9A;NDN(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E
M96X@<F5S970B"FUS9W-T<B`B5F&Y92!H97-L;R!B;VQO(&]B;F]V96[I(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO
M=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@
M86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R
M("(B"B)68;EE(&AE<VQO(&)O;&\@;V)N;W9E;NDL('-K;VYT<F]L=6IT92!S
M:2!P;[ET=2!A('!R:6ALX7-T92!S82!S(%9AN>UM(&YO=OUM("(*(FAE<VQO
M;2XB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-S,P"FUS9VED(")9;W5R('!A
M<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")0;&%T;F]SNR!6X;EH;R!H
M97-L82!V>7!RN6%L82XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(E9A
MN64@=GID:6%L96[I('-E<G9E<GDZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(U-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU
M9V]S;&%V:6$B"FUS9W-T<B`B2G5H;W-LX79I82(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B6F%I<B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-38@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("):86UB:6$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C4W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR-#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):
M:6UB86)W92(*;7-G<W1R(")::6UB86)W92(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B6FEP<'DB"@HC.B!L
M:6(O2&]R9&4O5&5X="]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G
M:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R(");4VMR>;L@8VET;W9A
M;OT@=&5X=%TB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX.0IM<V=I9"`B
M6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");4W!RX79A(&\@<')O8FSI;65=
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*
M;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B6UIO8G)A>FF[
M(&-I=&]V86[]('1E>'0@+2(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H
M:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC+"!P:'`M9F]R;6%T"FUS9VED(");
M4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");6F]B<F%Z
M:;L@8VET;W9A;OT@=&5X="`M("5S(')I861K;W9=(@H*(SH@;&EB+TAO<F1E
M+G!H<#HQ.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=
M(@IM<V=S='(@(EMR:6%D;VL@)7,@>B`E<UTB"@HC.B!L:6(O2&]R9&4N<&AP
M.C$U-#4@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D
M;6EN:7-T<F%T:6]N(@IM<V=S='(@(E]!9&UI;FES='+A8VEA(@H*(SH@;&EB
M+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(E]#3$DB"@HC.B!L
M:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*;7-G<W1R(")?1&%T
M851R964B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(E]6
M>6UA>F&[(')I861O:R(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R
M;W5P<R(*;7-G<W1R(")?4VMU<&EN>2(*"B,Z(&QI8B](;W)D92]-96YU+G!H
M<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@(E]0;VUO8V[M:R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B5FQA<W1N
M;W-T:2!?;V)RX7IK=2XN+B(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ.30*
M;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B7U!R:6ALX7-INR!S82(*"B,Z(&QI
M8B](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@
M(E]/9&ALX7-INR!S82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN
M(@IM<V=S='(@(E]5<')A=FF[(&QI;FMU+BXN(@H*(SH@;&EB+TAO<F1E+TUE
M;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`B7TYA<W1A=F5N
M:6$B"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]097)M:7-S:6]N<R(*
M;7-G<W1R(")?4'+A=F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN:RXN
M+B(*;7-G<W1R(")/9'-T7W+A;FF[(&QI;FMU+BXN(@H*(SH@;&EB+V%P:2YP
M:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B3F%?<W1A=F5N:64B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E9L
M87-T;F]S=&D@7W1A8G6U:WDN+BXB"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G
M:60@(E]5<V5R<R(*;7-G<W1R(")0;U]UONUV871E;&EA(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HY,C`*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R
M(")A9')E<^%R(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3,T
M"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R(")A9')E<^%T(&YE
M>F[A;7DB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDQ,@IM<V=I9"`B8V%L
M96YD87(B"FUS9W-T<B`B:V%L96YDX7(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")C86QM(@IM<V=S='(@(F)E>G9E=')I92(*"B,Z(&QI8B](;W)D
M92]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T92!O
M=71P=70@9FEL92(*;7-G<W1R(")N97!O9&%R:6QO('-A('9Y='9O<FF[(';]
M<W1U<&[]('/Z8F]R(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z
M,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R(")N97!O9&%R
M:6QO('-A(&]T=F]R:;L@=G-T=7`B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT
M96YT<RYP:'`Z-3DY"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(FML:6MN
M:71E('-E;2(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$R,@IM
M<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(F-H>6)A
M('!R:2!P;W6^:73M('!R[6MA>F]VZ6AO(')I861K=2(*"B,Z(&QI8B](;W)D
M92]-24U%+TUE<W-A9V4N<&AP.C$W.`IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E
M<G)O<B(*;7-G<W1R(")C:'EB82!K;VYF:6=U<N%C:64B"@HC.B!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E
M;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B8VC]8F$@9/1L9;YI=/T@<WES=.EM
M;W;]('/Z8F]R(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3(V
M"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R(")C:'EB82!F;W)M
MX71U(/ID86IO=B(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$X
M,@IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@(G!O;&^^:V$@;F5N
MX6ID96[A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-S$*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B:VQE<^$B"@HC.B!L:6(O
M2&]R9&4O0G)O=W-E<BYP:'`Z.#@Q"FUS9VED(")F:6QE(@IM<V=S='(@(G/Z
M8F]R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS-C`@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R
M(")Z;R!S;65R=2`E<R`H)7,I('+]8VAL;W.[;W4@)7,@)7,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Y"FUS9VED(")G=7-T:6YG(@IM
M<V=S='(@(F[A<F%Z;W;](@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(T.`IM<V=I9"`B:#HB"FUS9W-T<B`B=CHB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4W"FUS9VED(")H:"(*
M;7-G<W1R(")H:"(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$S
M.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B;F5Z;N%M92!M
M96YO(&AO<W1I=&6U82(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-C4@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*
M;7-G:60@(FEM;65D:6%T92(*;7-G<W1R(")O:V%MOFET92(*"B,Z(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS
M9VED(")I;FQI;F4B"FUS9W-T<B`B=B!S<'+A=F4B"@HC.B!L:6(O2&]R9&4O
M34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O
M<B(*;7-G<W1R(")C:'EB82!V<W1U<'4O=OUS='5P=2(*"B,Z(&QI8B](;W)D
M92]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A
M<F4@97)R;W(B"FUS9W-T<B`B:6YT97)NX2!C:'EB82!S;V9T=NER=2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED
M(")L:6YE<UTB"FUS9W-T<B`B<FEA9&MO=ETB"@HC.B!L:6(O5D93+TE33U=R
M:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES
M;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B
M<&_H87,@=GET=N%R86YI82!)4T\@;F%S=&%L82!C:'EB82!M:VES;V9S("5D
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V.`IM
M<V=I9"`B;6TB"FUS9W-T<B`B;6TB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN
M<&AP.C(Y,2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,S(*;7-G:60@(FYA;64B"FUS
M9W-T<B`B;65N;R(*"B,Z(&QI8B](;W)D92]24$,N<&AP.C$R-`IM<V=I9"`B
M;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(FYE:6UP;&5M96YT;W9A;NDB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R,C`*;7-G:60@(FYO="!Y
M970@:6UP;&5M96YT960B"FUS9W-T<B`B>F%T:6&U(&YE:6UP;&5M96YT;W9A
M;NDB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDP-`IM<V=I9"`B;F]T97!A
M9"(*;7-G<W1R(")P;WINX6UK;W;](&)L;VLB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C
M96YT(@IM<V=S='(@(G!E<F-E;G0B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S
M86=E+G!H<#HQ-S0*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@
M(G!R[7-T=7`@>F%M:65T;G5T_2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G
M<W1R(")B;V1O=B(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W
M,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(G9Z
M9&EA;&5NX2!C:'EB82!V('!R;W1O:V]L92(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS9VED(")R:7-I;F<B"FUS9W-T
M<B`B<W3Z<&$B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-#(*
M;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B<VQUOF)A(&YI
M92!J92!D;W-T=7!NX2(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.3D*
M;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B>F]B<F%Z:;L@<F]Z
M9&EE;'DB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T
M"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T<B`B<VUS,F5M86EL
M(&-E>B!(5%10(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,X-`IM<V=I9"`B<W,B"FUS9W-T<B`B<W,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B<W1E861Y(@IM
M<V=S='(@(G5S=.%L96[](@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP
M:'`Z,34P"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B<WES=.EM;W;A
M(&-H>6)A(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,C@*;7-G:60@(G1A
M<VL@;&ES="(*;7-G<W1R(")Z;WIN86T@^FQO:"(*"B,Z(&QI8B](;W)D92]-
M24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B
M"FUS9W-T<B`B9&_H87-NX2!C:'EB82(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V
M(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED(")T>7!E('1H
M92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(G!R92!P;W1V
M<F1E;FEE('IA9&%J=&4@:&5S;&\@9'9A:W+A="(*"B,Z(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")U
M;FEF:65D(@IM<V=S='(@(G5N:69I:V]V86[I(@H*(SH@;&EB+TAO<F1E+TU)
M344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`B;F5P;VUE
M;F]V86[A(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M-2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B
M=7-E<B!S96QE8W0B"FUS9W-T<B`B9&5F:6YU:F4@<&]UONUV871EM2(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#
M87)D(@IM<V=S='(@(G9#87)D(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(T,`IM<V=I9"`B=SHB"FUS9W-T<B`BN3HB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC
M;VTB"FUS9W-T<B`B=V5A=&AE<BYC;VTB"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&\O<VQ?4TDN<&\`````````````````````````````
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#8U-#0U-@`Q,#4Q-30S,S<U-``P
M,3<V-S(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````(R!3;&]V96YI86X@=')A;G-L871I;VYS(&9O<B!(;W)D92!P86-K86=A
M"B,@4VQO=F5N<VMI('!R979O9"!(;W)D92!P86ME=&$*(R!#;W!Y<FEG:'0@
M*$,I(#(P,#8@2&]R9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB
M=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!H;W)D92!P86-K
M86=E+@HC($%U=&]M871I8V%L;'D@9V5N97)A=&5D+"`R,#`V+@HC"FUS9VED
M("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B`N7&XB"B)297!O
M<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4
M+4-R96%T:6]N+41A=&4Z(#(P,#8M,#<M,C4@,3$Z,S`K,#(P,%QN(@HB4$\M
M4F5V:7-I;VXM1&%T93H@,C`P-BTP-"TS,"`Q,#HS,BLP,3`P7&XB"B),87-T
M+51R86YS;&%T;W(Z(&1U8VM`;V)A;&$N;F5T7&XB"B),86YG=6%G92U496%M
M.B!S;%]322`\9'5C:T!O8F%L82YN970^7&XB"B)-24U%+59E<G-I;VXZ(#$N
M,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/75T9BTX
M7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4W"B,L('!H<"UF;W)M870*;7-G
M:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H<')E9"`E<R!D;F5V:2DB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S-38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B`H1&]S=&]P
M;F$@=&EP:V$@)7,I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V
M-0HC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@
M(B`H=B`E<R!D;F5H*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V
M-C$*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(BAD86YE<RDB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8S"FUS9VED("(@*'1O;6]R<F]W*2(*
M;7-G<W1R(")*=71R:2`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-C4Y"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B*';$C65R86HI(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,"!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S4S"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS.3D*;7-G:60@(B!A="`B"FUS9W-T<B`B(&]B("(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$P"B,L('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@(EPB)7-<
M(B!N:2!I;65N:6LB"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I
M8V4N(@IM<V=S='(@(EPB)7-<(B!J92!N979E;&IA=FYA(&EZ8FER82(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!E;6%I;"!A9&1R
M97-S+B(*;7-G<W1R(").:7-T92!V<W1A=FEL:2!V96QJ879N96=A(&5L96MT
M<F]N<VME9V$@;F%S;&]V82XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M4F5G:7-T<GDN<&AP.C<P,`HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G
M:7-T<GDN<&AP.C$P-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES
M(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T
M<B`B7"(E<UPB(&YE('IA>FYA;2!V($AO<F1O=F5M(')E9VES=')U("(*"B,Z
M(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B<E<R<@;F4@;F%J9&5M(&1R979E<V$@>F$@:7IR:7,N(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HU-0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S
M(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R("(G)7,G(&IE
M(&)I;"!D;V1A;B!S:W5P:6YS:V5M=2!S:7-T96UU(@H*(SH@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.C4Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T
M<B`B)R5S)R!J92!B:6P@9&]D86X@:R!D;W!U<W1N96UU('-I<W1E;74N(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HU,R!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E
M871E9#H@)7,N(@IM<V=S='(@(B<E<R<@;FD@=7-T=F%R:F5N.B`E<R`B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS
M9W-T<B`B57!O<F%B;&IE;FEH("4N,F9-0B!O9"`E+C)F34(@9&]V;VQJ96YI
M:"`H)2XR9B4E*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@
M(B5D("5S(&EN("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HR-C<@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB
M"FUS9W-T<B`BQ:!E("5D(&1N:2!D;R!P;W1E:V$@9V5S;&$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<X"B,L('!H<"UF;W)M870*;7-G
M:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R("(E9"UD;F5V;F$@;F%P;W9E
M9"(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(E<R#B@),@0F]D:71E
M('!O>F]R;FDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C<P-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G
M<W1R("(E<R!/9'1I<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C@S-R!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX
M-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S4@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0Q"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!-0B(*;7-G<W1R("(E<R!+0B(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM
M<V=S='(@(B5S(%9Z9'+%OF5V86QN82!D96QA("T@4&]T<F1I=&5V(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,C$S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@
M(B5S("`@("`@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C(V-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S='(@
M(B5S('!R:6IA=F$B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM
M<V=S='(@(B5S(%!O9V]J:2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-#0S(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DY"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z-CDX(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-S8P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-S:#(N<&AP.C<P,"!F
M<F%M97=O<FLO5D93+U9&4R]S<V@R+G!H<#HW-C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B5S(,6^92!O8G-T
M86IA+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<Q(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3<W(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Q"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S4W(&QI8B]";&]C:R]M971A<BYP:'`Z,S8S"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S(&]B
M("5S("5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@
M=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P
M97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B(@HB)7,@:F4@<')I<')A
M=FQJ96X@;F$@:7IV86IA;FIE('9Z9'+%OF5V86QN:6@@;W!E<F%C:6HL('!R
M979E<FD@<W!O9&%J+E!R979E<FD@(@HB;F%B:7)A;&YI:R!Z82!V<V4@;W!E
M<F%C:6IE+"!K:2!B:2!J:6@@<F%D(&]P<F%V:6P@<V5D86HN(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8R.`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R(")0;W1R96)U:F5M("5S("(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,CDX"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(&UI;G5T97,B"FUS9W-T<B`B)7,@;6EN=70B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3,U"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@;F4@;F%J9&5M(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(E<R!O8B`E<R!O
M9"`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(V"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(DEM
M96YI:R`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$X"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B2V]L
M961A<B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$P"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R(")"96QE
MQ;YK82`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,T"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B)7,@
M3W!R879I;&$B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S.B`E<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I
M="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI
M;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY
M('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"B(E<SH@=&\@<W!O
M<F_$C6EL;R!M;V=OQ(UE(&YI(&]D('!OQ:%I;&IA=&5L:F$L(&MA=&5R:2!P
M<F%V:2!D82!J92X@4&%Z:71E('-E("(*(FMA=&5R:6AK;VQI('!O=F5Z878@
M=B!S<&]R;\2-:6QU(&%L:2!P;V1A:F%N:G4@:V%T97)I:"!K;VQI(&]S96)N
M:6@@(@HB:6YF;W)M86-I:B!N82!T82!N87-L;W8N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,U-R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#`R"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@9V]S=&EM
M("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`P(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C`U"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E
M<R(*;7-G<W1R("(L(&=O<W1I;2`E<R`E<R(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C$S"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O
M;2`E<R!T;R`E<R(*;7-G<W1R("(L('-P<F5M96YL:FEV:V$@;V0@)7,@9&\@
M)7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y-"!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S4W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,38*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<U,`IM
M<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(BTM(&EZ8F5R:2`M+2(*"B,Z
M(&QI8B]";&]C:R]T:6UE+G!H<#HR-0IM<V=I9"`B,3(@2&]U<B!&;W)M870B
M"FUS9W-T<B`B,3(@=7(@9F]R;6%T(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP
M.C(T"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R("(R-"!U<B!F;W)M
M870B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@
M:&]U<G,B"FUS9W-T<B`B,C0@=7(B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G
M97(N<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`B4')E:L6A;FIA
M(&UOQ;YN;W-T(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,S$*;7-G:60@
M(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C
M:RXB"FUS9W-T<B`B6F$@=&$@8FQO:R!J92!P;W1R96)N82!P;W9E>F%V82!N
M82!P;V1A=&MO=FYI('-T<F7%OFYI:R(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3<Q"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E
M9"(*;7-G<W1R(")0;VIA=FEL82!S92!J92!H=61A(&YA<&%K82XB"@HC.B!F
M<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C0R.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)!(&UE<W-A9V4@:&%S(&)E96X@<V5N="!T;R!<(B5S
M7"(@=&\@=F5R:69Y('1H870@=&AI<R!I<R!R96%L;'D@>6]U<B`B"B)A9&1R
M97-S+B!4:&4@;F5W(&5M86EL(&%D9')E<W,@:7,@86-T:79A=&5D(&%S('-O
M;VX@87,@>6]U(&-O;F9I<FT@=&AI<R`B"B)M97-S86=E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@
M(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE
M<W-A9V4N(@IM<V=S='(@(EIA(&MO9&ER871I('-P;W)OQ(UI;&\@<&]T<F5B
M=6IE;2!J879N:2!01U`@:VQJ=<2-+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$Q-C@*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@
M<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@
M(DIA=FYI(%!'4"!K;&IUQ(T@:F4@<&]T<F5B96X@>F$@;V1K;&5P86YJ92!S
M<&]R;\2-:6QA+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$P.3D*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@
M82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B)*879N:2!01U`@:VQJ=<2-+"!Z
M87-E8FYI(%!'4"!K;&IUQ(T@:6X@9V5S;&\@<V\@<&]T<F5B;FD@>F$@;V1K
M;&5P86YJ92`B"B)S<&]R;\2-:6QA+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$P,38*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL
M('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B)*879N:2!01U`@
M:VQJ=<2-+"!Z87-E8FYI(%!'4"!K;&IUQ(T@:6X@9V5S;&\@<V\@<&]T<F5B
M;FD@>F$@<&]D<&ES('-P;W)OQ(UI;&$N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU,#8*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-
M12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B
M"B)*879N:2!3+TU)344@:VQJ=<2-+"!Z87-E8FYI(%,O34E-12!K;&IUQ(T@
M:6X@9V5S;&\@<V\@<&]T<F5B;FD@>F$@<&]D<&ES("(*(G-P;W)OQ(UI;&$N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G
M:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M
M97-S86=E+B(*;7-G<W1R("(B"B)*879N:2!3+TU)344@:VQJ=<2-+"!Z87-E
M8FYI(%,O34E-12!K;&IUQ(T@:6X@9V5S;&\@<V\@<&]T<F5B;FD@>F$@<&]D
M<&ES("(*(G-P;W)OQ(UI;&$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R
M97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B($IA=FYI
M(%--24U%(&ML:G5E(&IE('!O=')E8F5N('IA(&]D:VQE<&%N:F4@<W!O<F_$
MC6EL82`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B3V)L8<2-;F\B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B
M04T@3&EG:'0@4F%I;B(*;7-G<W1R(")*=71R86YJ:2!286AE;"!D9<6^(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G
M:60@(D%-(%)A:6XB"FUS9W-T<B`B2G5T<F%N:FD@9&7%OB(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3
M:&]W97)S(@IM<V=S='(@(DIU=')A;FII(&YA;&EV(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@
M4VAO=V5R<R(*;7-G<W1R(")*=71R86YJ:2!S;F7%OFYI(&UE=&7%OB(*"B,Z
M('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G
M<W1R(")!32]032(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(D%022!)
M1"(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4S"FUS9VED(")!8F]U
M="XN+B(*;7-G<W1R(")/<&ES+BXN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C(X,@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!6
M1E,@9&ER96-T;W)Y+B(*;7-G<W1R(")0<F5P;W9E9&%N(&1O<W1O<"!Z82!U
M<W1V87)J86YJ92!M87!E(%9&4RX@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!6
M1E,@9FEL92XB"FUS9W-T<B`B4')E<&]V961A;B!D;W-T;W`@>F$@=7-T=F%R
M:F%N:F4@9&%T;W1E:V4@5D93+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HS"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(E9AQ:%I
M('!O9&%T:VDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@*;7-G:60@
M(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B4&]T<F1I(&=E<VQO(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS
M"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B27IV86IA;2(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#D*;7-G:60@(D%C8V]U;G1I
M;F<B"FUS9W-T<B`B27IV86IA;2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B
M061D(@IM<V=S='(@(D1O9&%J(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C(@
M861M:6XO9W)O=7!S+G!H<#HR,C,*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*
M;7-G<W1R(")$;V1A:B!S:W5P:6YO(&]T<F]K(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.CDY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R(")$
M;V1A:B!D;W9O;&IE;FIA(&]T<F]K82(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I
M;F1E>"YP:'`Z-S`*;7-G:60@(D%D9"!#;VYT96YT(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB
M"FUS9W-T<B`B1&5D86H@<V5M.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$V
M(&%D;6EN+V=R;W5P<RYP:'`Z,C$W"FUS9VED(")!9&0@3F5W($=R;W5P(@IM
M<V=S='(@(D1O9&%J(&YO=F\@<VMU<&EN;R(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(D1O9&%J
M(&YO=F$@9&]V;VQJ96YJ82(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M861D8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI
M;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(D1O9&%J('-K=7!I;F\@;W1R
M;VL@7"(E<UPB(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO
M;B!T;R!<(B5S7"(B"FUS9W-T<B`B1&]D86H@9&]V;VQJ96YJ92!O=')O:V$@
M7"(E<UPB(@H*(SH@861M:6XO=7-E<BYP:'`Z,CD*;7-G:60@(D%D9"!A(&YE
M=R!U<V5R.B(*;7-G<W1R(")$;V1A:B!N;W9E9V$@=7!O<F%B;FEK83HB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34X"FUS
M9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(D1O9&%J('-T;VQP96,B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@
M;F5W(&UE;6)E<G,B"FUS9W-T<B`B1&]D86H@;F]V92#$C6QA;F4B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*
M;7-G<W1R(")$;V1A:B!P87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S<Q"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A
M($UO>FEL;&$@4VED96)A<B(*;7-G<W1R(")$;V1A:B`E<R!-96YU('8@36]Z
M:6QL82!3:61E8F%R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G
M<W1R(")$;V1A:B!V(&EM96YI:SHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S
M(&)O;VLB"FUS9W-T<B`B1&]D86H@=B!M;VH@:6UE;FEK.B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,P"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R(")$;V1A:B!U
M<&]R86)N:6MA(@H*(SH@861M:6XO=7-E<BYP:'`Z-S@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C
M;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B
M"B(E<RXB"FUS9W-T<B`B(@HB($1O9&%L("<E<R<@<VES=&5M=2P@=F5N9&%R
M(&)O(&YE;6]G;\2-92!D;V1A:F%N:F4@9&]D871N:6@@=G!I<VYI:"`B"B)I
M;F9O<FUA8VEJ.B`E<RXB"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M
M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N
M(&QO9R!I;B!N;W<N(@IM<V=S='(@(D1O9&%N("<E<R<@<VES=&5M=2X@4V5D
M86H@<V4@;&%H:V\@<')I:F%V:71E+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L
M960N(@IM<V=S='(@(D1O9&%J86YJ92!U<&]R86)N:6MO=B!J92!O;F5M;V=O
MQ(UE;F\N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-30*;7-G:60@(D%D
M9')E<W,B"FUS9W-T<B`B3F%S;&]V(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$T.`IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(DEM96YI
M:R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4V
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS
M9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U
M<V5R<R(*;7-G<W1R(")5<F5D:2!D;W9O;&IE;FIA('IA(&]S=&%L92!U<&]R
M86)N:6ME(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q-PIM
M<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B57!R879L:F%N:F4B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4W"FUS9VED(")!9',B"FUS
M9W-T<B`B4F5K;&%M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N
M(@IM<V=S='(@(D%F:&%N:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;&)A
M;FEA(@IM<V=S='(@(D%L8F%N:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG
M97)I82(*;7-G<W1R(")!;,6^:7)I:F$B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R
M(")/>FER;VUA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED
M(")!;&PB"FUS9W-T<B`B5G-E(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I
M9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B5G-I(&]V97)J
M96YI('5P;W)A8FYI:VDB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,R(&%D;6EN
M+V=R;W5P<RYP:'`Z,C(P"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(E9S
M92!S:W5P:6YE(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U"FUS9VED
M(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B5G-A($1O=F]L:F5N:F$B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`Y"FUS9VED(")!;&QO=R!M
M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B1&]V;VQI(&UN;V=O:W)A=&YE
M(&YA<VQO=F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(X"FUS9VED
M(")!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R
M(")$;W9O;&D@;F%S=&%V:71V92`@(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E
M+T1A=&%4<F5E+W-Q;"YP:'`Z-3$X"FUS9VED(")!;')E861Y(&5X:7-T<R(*
M;7-G<W1R("+#@L6]92!O8G-T86IA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$R-@IM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B
M3F%D;VUE<W1N;R!)35-0('5P;W)A8FYIQ:%K;R!I;64B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3`R"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S
M=V]R9"(*;7-G<W1R(").861O;65S=&YO($E-4U`@9V5S;&\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#DT"FUS9VED(")!;'1E<FYA=&4@24U34"!5
M<V5R;F%M92(*;7-G<W1R(").861O;65S=&YO($E-4U`@=7!O<F%B;FG%H6MO
M(&EM92(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED
M(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(").861O;65S=&YI
M(&5L96MT<F]N<VMI(&YA<VQO=B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,30Q"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(DYA9&]M
M97-T;FD@=GIO<F-I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M
M;V$B"FUS9W-T<B`B($%M97)IQ:%K82!386UO82`B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I
M960N(@IM<V=S='(@(DYA=F5D96YA(&IE(&)I;&$@;F5Z86MO;FET82!V<F5D
M;F]S="XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38P"FUS
M9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R(")P
M;VIA=FEL82!S92!J92!N87!A:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O
M<G)A(@IM<V=S='(@(D%N9&]R82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L
M82(*;7-G<W1R(")!;F=O;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U:6QL
M82(*;7-G<W1R(")!;F=U:6QL82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R(")!
M;F]N:6UE;B!0<F]X>2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B3V1G;W9O<B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B06YT87)K=&EC82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B
M06YT:6=U82!I;B!"87)B=61A(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW
M,R!A9&UI;B]P:'!S:&5L;"YP:'`Z,S0*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+U5)+G!H<#HU."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M
M;#HT"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R(")!<&QI:V%C:6IA(@H*
M(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO
M;B!,:7-T(@IM<V=S='(@(E-E>FYA;2!A<&QI:V%C:6HB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3,Y"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D
M>2XB"FUS9W-T<B`B07!L:6MA8VEJ82!J92!P<FEP<F%V;&IE;F$B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@
M0VAI;&0@4VAA<F5S(@IM<V=S='(@(E!R:6IA=FD@;W1R;VMO=F4@9&5L;FEC
M92`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM
M<V=I9"`B07!P<F]V92(*;7-G<W1R(")0;W1R9&DB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B07!R:6PB"FUS
M9W-T<B`B07!R:6PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I
M9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(D%R86)S:VD@*%=I
M;F1O=W,M,3(U-BDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.`IM
M<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B5F5L:6MO<W0@9&%T
M;W1E:V4@07)H:78@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C8U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S<*
M;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R("));64@07)H:79A(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M
M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R(")3=&4@
M<')E<')IQ(UA;FDL(&1A(,6^96QI=&4@<')E:VQI8V%T:2!Z86AT979O('IA
M('!R:6IA=F\@>F$@)7,@/R`B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V1E;&5T92YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U
M<F4@>6]U('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U
M<',_(@IM<V=S='(@(E-T92!P<F5P<FG$C6%N:2P@9&$@Q;YE;&ET92!I>F)R
M:7-A=&D@)R5S)R!I;B!O<W1A;&4@<&]D<VMU<&EN93\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X
M"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B07)G96YT:6YA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-PIM<V=I9"`B07)M96YI82(*;7-G<W1R(")!<FUE;FEJ82(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")!<FUE;FEA;B`H05)-4T-)
M22TX*2(*;7-G<W1R(")!<FUE;G-K:2`H05)-4T-)22TX*2(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B07)T(@IM<V=S='(@(E5M971N
M;W-T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B07)U8F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E
M;G-I;VX@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS-`IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(E5M971N;W-T:2#$
MC7)K(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED
M(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(D%Z:6$O4&%C:69IQ:%K
M92!R96=I:F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(Y"FUS9VED
M(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B5G!R8<6A86H@>F$@<&]T<F1I=&5V
M('!R960@:7IV86IA;FIE;2!V>F1RQ;YE=F%N:F$B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,S@R"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B
M"FUS9W-T<B`B1&]D96QJ96YE(&MO;&]N92(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z-S,*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M(&=R;W5P+B(*;7-G<W1R(")0;W-K=7,@:7IB<FES82!N96]B<W1O:F7$C64@
M<VMU<&EN92XB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(X"FUS9VED
M(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N
M+B(*;7-G<W1R(")0;W-K=7,@:7IB<FES82!N96]B<W1O:F7$C65G82!D;W9O
M;&IE;FIA+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@V"FUS9VED(")!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS
M9W-T<B`B4&]S:W5S('5R961I='9E(&YE;V)S=&]J9<2-96=A(&1O=F]L:F5N
M:F$N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4X"FUS9VED(")!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@
M(E!O<VMU<R!U<F5D:71V92!N96]B<W1O:F7$C64@9&5L;FEC92XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HX,PIM<V=I9"`B071T<FEB=71E<R(*
M;7-G<W1R("),87-T;F]S=&DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-3$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B075G=7-T(@IM<V=S='(@(D%V9W5S
M="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R(")!=G-T
M<F%L:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')I82(*;7-G<W1R(")!
M=G-T<FEJ82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS
M,38*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(B!!=71H7V-Y<G5S.B!:86AT979A;F\@
M:6UA<"#%H6ER:71E=B!N:7-E;2!N8<6A96PN(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)U<RYP:'`Z,3,Q"FUS9VED(")!=71H7V-Y<G5S.B!"86-K
M96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM<V=S
M='(@(D%U=&A?8WER=7,Z($)A8VME;F0@;FEM82!Z86AT979A;FEH('IM;\6^
M;F]S=&DN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,T
M"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER=7,Z(%IA:'1E=F%N;R!I;6%P
M(,6A:7)I=&5V(&YI<V5M(&YAQ:%E;"XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+V9T<"YP:'`Z-38*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&
M5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@
M+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@HB075T:%]F='`Z
M(%IA:'1E=F%N;R!&5%`@Q:%I<FET978@;FES96T@;F'%H65L+B!)>G!O;&YI
M(%!(4"!Z("UO;F5M;V=OQ(UE;F\M(&9T<"`B"B)Z86UE;FIA=F\N("(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`T"FUS9VED(")!=71H
M7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B075T:%]I;6%P:'1E=F%N;R!)34%0:71E=B!N:7-E;2!N8<6A96PN
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,PIM<V=I9"`B
M075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(D%U=&A?:W)B-3H@6F%H=&5V86YO(&MR8C4@Q:%I<FET978@
M;FES96T@;F'%H65L+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,S`Q"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@
M<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(D%U=&A?
M;&1A<#H@3FD@;6_%OFYO(&1O9&%J86YJ92!U<&]R86)N:6MO=B!V($%C=&EV
M92!$:7)E8W1O<GDB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C,U-@IM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@
M<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(D%U=&A?
M;&1A<#H@3FD@;6_%OFYO(&]D<W1R86YJ979A;FIE('5P;W)A8FYI:V]V('8@
M06-T:79E($1I<F5C=&]R>2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z.3(*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VQD87`Z(%IA:'1E=F%N
M;R!,1$%0(,6A:7)I=&5V(&YI<V5M(&YAQ:%E;"XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C,S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(D%U=&A?;&1A<#H@3F4@;6]R
M96T@9&]D871I('5P;W)A8FYI:V$@)7,N(%-P;W)OQ(UI;&\@<W1R9<6^;FEK
M83H@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E
M('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!.92!M;W)E;2!O9'-T<F%N
M:71I('5P;W)A8FYI:V$@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C0Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N
M86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z($YE
M(&UO<F5M(&YA9&=R861I=&D@=7!O<F%B;FEK82`E<R`B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C0P-`IM<V=I9"`B075T:%]L9&%P.B!5
M<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER
M96-T;W)Y+B(*;7-G<W1R(")!=71H7VQD87`Z(&YE(&UO<F5M(&YA9&=R86IE
M=F%T:2!U<&]R86)N:6MO=B!V($%C=&EV92!$:7)E<W1O<GDN(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HV,@IM<V=I9"`B075T:%]M8V%L
M.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(D%U=&A?;6-A;#H@6F%H=&5V86YO($U#04P@Q:%I<FET978@;FES96T@;F'%
MH65L+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-@IM<V=I
M9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?<VUB875T:#H@6F%H=&5V86YE9V$@
M<VUB875T:"!Z82#%H6ER:71E=B!N:7-E;2!N8<6A96PN(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!9&UI;BYP:'`Z,3`V"FUS9VED(")!=71H96YT:6-A
M=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N(@IM<V=S='(@(D]V97)J86YJ
M92!Z82!&5%`@<W1R9<6^;FEK(&YI('5S<&5L;RXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U
M=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R(")/=F5R:F%N:F4@;FD@=7-P
M96QO+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B3W9E<FIA;FIE(&YI('5S<&5L;RX@
M)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,3@R"FUS
M9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R
M+B(*;7-G<W1R(")/=F5R:F%N:F4@:F4@>F%V<FYI;"!2041)55,@<W1R9<6^
M;FEK+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#<S"FUS9VED
M(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T
M<B`B3W9E<FIA;FIE('IA($944"!S=')EQ;YN:6L@;FD@=7-P96QO+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-S:#(N<&AP.C@X.0HC+"!F=7IZ>0IM<V=I
M9"`B075T:&5N=&EC871I;VX@=&\@4U-(,B!S97)V97(@9F%I;&5D+B(*;7-G
M<W1R(")/=F5R:F%N:F4@>F$@1E10('-T<F7%OFYI:R!N:2!U<W!E;&\N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N
M=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")/
M=F5R:F%N:F4@>F$@4TU"('-T<F7%OFYI:R!N:2!U<W!E;&\N(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I
M96QD<SHB"FUS9W-T<B`B4&]L:F$@;F$@<F%Z<&]L86=O.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B07IE<F)A:F3%OF%N("(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B0D]&2"!%>&-U
M<V5S(@IM<V=S='(@(DYE=6UN:2!I>F=O=F]R:2(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:W)B-2YP:'`Z.#(*;7-G:60@(D)A9"!K97)B97)O<R!P87-S
M=V]R9"XB"FUS9W-T<B`B3F%P8<2-;F\@:V5R8F5R;W,@9V5S;&\N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-`IM<V=I9"`B0F%D(&ME
M<F)E<F]S('5S97)N86UE+B(*;7-G<W1R(").87!AQ(UN;R!K97)B97)O<R!U
M<&]R86)N:<6A:V\@:6UE+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B
M"FUS9W-T<B`B0F%H86UI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*
M;7-G<W1R(")"86AR86EN(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*
M;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(D)A;'1I:R`H
M25-/+3@X-3DM,3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*
M;7-G<W1R(")"86YG;&%D9<6A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D
M;W,B"FUS9W-T<B`B0F%R8F%D;W,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E
M8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B3FES96T@;F'%H65L
M(&]S;F]V;F5G82!G<F%F:<2-;F5G82!I;65N:6MA(%PB)7-<(BXB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8S"FUS9VED(")"96QA<G5S(@IM<V=S='(@(D)E;&]R=7-I:F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@(D)E;&=I:F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8S"FUS9VED(")"96QI>F4B"FUS9W-T<B`B0F5L:7IE(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B0F5N:6XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8R"FUS9VED(")"97)M=61A(@IM<V=S='(@(D)E<FUU9'-K:2!O=&]K:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R(")"=71A;B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G
M:60@(D)I<G1H9&%Y(@IM<V=S='(@(E)O:G-T;FD@9&%N(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,V.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC871I;VX@7"(E<UPB
M(&YO="!F;W5N9"XB"FUS9W-T<B`B3FES96T@;F'%H65L(&)L;VMA(%PB)7-<
M(BP@87!L:6MA8VEJ92!<(B5S7"(@+B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHY,`IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B
M6F%U<W1A=FD@3F%S=&%V:71V92(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHW,@IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R("):875S=&%V
M:2!4:7`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@(D)O
M;&EV:6IA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R,0IM<V=I
M9"`B0F]O:VUA<FMS(@IM<V=S='(@(E!R:6QJ=6)L:F5N92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B0F]S
M;F$@:6X@2&5R8V5G;W9I;F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,3`Q"FUS9VED(")";W1H(@IM<V=S='(@(D]B;VII(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM
M<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B0F]C=F%N82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*
M;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B0F]U=F5T;W9O(&]T;\2-
M:F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)A>FEL
M:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N
M(%1E<G)I=&]R>2(*;7-G<W1R("(@0G)I=&%N<VMO(&]Z96UL:F4@26YD:6IS
M:V5G82!O8V5A;F$@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S
M<V%L86TB"FUS9W-T<B`B0G)U;F5I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L
M9V%R:6$B"FUS9W-T<B`B0F]L9V%R:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B
M0G5R:VEN82!&87-O(@IM<V=S='(@(D)U<FMI;F$@1F%S;R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B0G5R=6YD:2(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT-C<*;7-G:60@(D--4R(*;7-G<W1R(")-
M4T<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U
M"FUS9VED(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@
M4&]I;G1S(@IM<V=S='(@(B!#4DP@<F%Z9&5L:71V96YE('1OQ(UK92`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34V"FUS9VED(")#86-H
M92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R(").87-T879L:F%N
M:F4@<')E9'!O;6YI;&YI:V$@;FD@9&]K;V[$C6%N;RXB"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDQ-B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#@Y"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ
M,#DR(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-C0*;7-G:60@(D-A;&5N
M9&%R(@IM<V=S='(@(DMO;&5D87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C0P"FUS9VED(")#86QM(@IM<V=S='(@(EIB<FG%H6DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B2V%M8F]DQ;YA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B2V%M97)U
M;B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,0IM<V=I9"`B0V%N)W0@861M
M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R(").
M92!M;W)E:F\@=7!R879L:F%T:2!Z=6YA;FII('5P<F%V;&IA;&-I(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C0Q(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER<W%L+G!H<#HS,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B3F4@
M;6]R96T@=GIP;W-T879I=&D@<&]V97IA=F4@>B!)34%0('-T<F7%OFYI:V]M
M.B`E<R`B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B3FD@;6]G;\2-92!O9'!R971I(%PB)7-<(B!D871O=&5K92XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8T"FUS9VED(")#86YA9&$B"FUS9W-T<B`B2V%N861A(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3`P(&%D;6EN+W5S97(N<&AP.C$Q.2!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O8VQE87(N:6YC.C$R('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R("):8G)IQ:%I(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3(*;7-G:60@(D-A
M;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")P;W)OQ(UI;&\@;R!T9<6^
M879A:"!Z(&)R:7-A;FIE;2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS
M,#0@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,C<*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C0X(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-C<W"B,Z(&9R86UE=V]R:R]61E,O5D93+W-S:#(N<&AP.C8W.2!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C$U"FUS9VED(")#86YN;W0@
M8V]P>2!F:6QE*',I("T@<V]U<F-E(&%N9"!D97-T:6YA=&EO;B!A<F4@=&AE
M('-A;64N(@IM<V=S='(@(DYE(&UO<F5M(&MO<&ER871I(&1A=&]T96L@*&4I
M("T@=FER(&EN(&-I;&IA('-T82!I<W1A+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,S(S(&9R86UE=V]R:R]61E,O5D93+W-S:#(N<&AP.C,Q
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R(").92!M;W)E;2!I>F)R:7-A=&D@9&%T;W1E:V4@7"(E
M<UPB+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O
M<GDN(@IM<V=S='(@(DYE(&YA:F1E;2!Z8<2-87-N92!D871O=&5K+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#@S(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(P-PHC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C<S.2!F<F%M97=O<FLO5D93+U9&4R]S<V@R+G!H<#HW-#,*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$V.0IM<V=I9"`B0V%N;F]T(&UO
M=F4@9FEL92AS*2`M(&1E<W1I;F%T:6]N(&ES('=I=&AI;B!S;W5R8V4N(@IM
M<V=S='(@(DYE(&UO<F5M('!R96UA:VYI=&D@9&%T;W1E:R`H92D@+2!C:6QJ
M(&IE('IN;W1R86H@=FER82XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H
M;W5T("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(DYE(&UO<F5M
M(&YA9&%L:F5V871I(&)R97H@<&%R86UE=')O=B`G8VEL:FYE(&1A=&]T96ME
M)RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.2!F<F%M97=O
M<FLO5D93+U9&4R]S<V@R+G!H<#HS,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")<(B5S
M7"(@26UE;FEK82!N92!M;W)E;2!Z8G)I<V%T:2XB"@HC.B!F<F%M97=O<FLO
M1&%T851R964O1&%T851R964N<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O
M1&%T851R964O<W%L+G!H<#HV.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(DYE(&UO
M<F5M(&]D<W1R86YI=&D[(&]B<W1A:F$@)60@<&]D=F5L:B(*"B,Z(&9R86UE
M=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8R,@IM<V=I9"`B(@HB
M0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O
M<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM
M<V=S='(@(B(*(DYE(&UO<F5M('!O;F]V;F\@=7)E9&ET:2P@Q:%T979I;&\@
M9&%N:6@@=FYO<V]V('-E(&YE('-K;&%D82!S(,6A=&5V:6QO;2`@(@HB<VAR
M86YJ96YI:"XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM
M<V=I9"`B0V%N;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R(").92!M;W)E;2!A
M=G1O;6%T<VMO('!O;F%S=&%V:71I(&=E<VQA+"!O8G)N:71E('-E(&YA('-K
M<F)N:6MA(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S
M<&5C:69I960@;G5M8F5R+B(*;7-G<W1R(").92!M;W)E;2!P<F5U<VUE<FET
M:2!S<&]R;\2-:6QA(&YA=F5D96YE;74@Q:%T979I;'4N(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S4P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-A;FYO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R(")#86YN;W0@
M=W)I=&4@=&\@9FEL92!<(B5S7"(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E
M(%9E<F1E(@IM<V=S='(@(DMA<'9E<F1S:VD@;W1O:VDB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A
M<G)I97(B"FUS9W-T<B`B4')I;F'%H6%L96,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3,*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G
M<W1R(")+871E9V]R:6IE(&EN('IN86UK92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED
M(")#87EM86X@27-L86YD<R(*;7-G<W1R(")+87EM86YS:VD@;W1O:VDB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS
M9VED(")#96QL(%!H;VYE(@IM<V=S='(@(DUO8FEL;FD@=&5L969O;B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R.#,*;7-G:60@(D-E;&QP:&]N
M92(*;7-G<W1R(")-;V)I;&YI('1E;&5F;VXB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X,0IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T
M<B`B2V5L='-K:2`H25-/+3@X-3DM,30I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B
M0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(D-E;G1R86QN;R!!
M9G)IQ:%K82!297!U8FQI:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,@IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T
M<B`B4W)E9&YJ965V<F]P<VMI("A)4T\M.#@U.2TR*2(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")#97)T:69I8V%T
M92!$971A:6QS(@IM<V=S='(@(E!O9')O8FYO<W1I('!O=')D:6QA(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3(*;7-G:60@(D-E
M<G1I9FEC871E($]W;F5R(@IM<V=S='(@(DQA<W1N:6L@<&]T<F1I;&$B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B
M0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B4')A=FEL82!P;W1R9&EL
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B0VAA9"(*;7-G<W1R(")%860B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B4W!R
M96UE;FDB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G
M:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(G-P<F5M96YI=&4@
M=F'%H64@9V5S;&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-CD*;7-G
M:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L
M92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA
M:6QS+B(*;7-G<W1R("(B"B)3<')E;65N:71E(&EM92!I;B!N87-L;W8@=F'%
MH65G82!E;&5K=')O;G-K96=A(&YA<VQO=F$L(&MI(&=A("(*(G9I9&EJ;W!R
M96IE;6YI:VD@;V(@8G)A;FIU(&EN(&]D9V]V87)J86YJ=2!N82!V8<6A;R!P
M;\6A=&\N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS
M9VED("(B"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T
M960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(E8@=')E;G5T;FD@
M:V]N9FEG=7)A8VEJ92!N92!M;W)E=&4@<W!R96UE;FET:2!G97-L82X@2V]N
M=&%K=&ER86IT92!V8<6A96=A("(*(G-K<F)N:6MA+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P,3<*(RP@9G5Z>GD*;7-G:60@(D-H87)A8W1E
M<B!T;R!S<&QI="!M=6QT:7!L92!A9&1R97-S97,@=VET:"(*;7-G<W1R(")$
M;W9O;&D@;6YO9V]K<F%T;F4@;F%S;&]V92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@
M(D-H:6QE(@IM<V=S='(@(L2-:6QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI
M;F$B"FUS9W-T<B`B2VET86IS:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X,PIM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S
M='(@(E!O96YO<W1A=FQJ96YA(&MI=&%JQ:'$C6EN82A'0C(S,3(I(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-H:6YE<V4@5')A9&ET
M:6]N86P@*$)I9S4I(@IM<V=S='(@(E1R861I8VEO;F%L;F$@:VET86K%H<2-
M:6YA("A":6<U*2(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C<*;7-G
M:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB"FUS9W-T<B`B27IB97)I(&%P;&EK
M86-I:F\Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W
M,0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B27IB97)I(&=E
M<VQO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,`IM
M<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B27IB97)I('5P;W)A
M8FYIQ:%K;R!I;64B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`R"FUS
M9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(DMA
M:V\@<')I:V%Z871I(&1A='5M93HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#:')I
M<W1M87,@27-L86YD(@IM<V=S='(@(D)OQ;YIQ(UN:2!O=&]K:2(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HY.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO
M;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(DYI<V5M(&YAQ:%E;"!D969I
M;FEC:6IE('9R<W1E('IA("5S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*;7-G<W1R(")*87-N
M;R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C<*;7-G:60@(D-L96%R(%%U
M97)Y(@IM<V=S='(@(E!R9<2-:7-T:2!P;VEZ=F5D8F4B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B3V1S=')A;FD@>G5N86YJ
M96=A('5P;W)A8FYI:V$Z("5S("(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R(")/9'-T
M<F%N:2!U<&]R86)N:6MA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,S0*;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R("))>F)R
M:<6A:2!P;V1A=&5K('5P;W)A8FYI:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*
M;7-G<W1R(")I>F)R:<6A:2!P;W1E;2(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT
M:6YU92(*;7-G<W1R(")+;&EK;FD@>F$@;F%D86QJ979A;FIE("(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM
M<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R(")#;&EC:V%T96QL
M('!R;W1O;2!(5%10(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD
M;W<B"FUS9W-T<B`B6F%P<FD@;VMN;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C4V"FUS9VED(")#;&]U9',B"FUS9W-T<B`B3V)L86MI(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L
M;W5D<R!%87)L>2(*;7-G<W1R(")::G5T<F%J($]B;&'$C6YO(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D-L
M;W5D>2(*;7-G<W1R(")/8FQAQ(UN;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-O
M8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(DMO:V]S;W9I(&]T;VMI
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR-`IM<V=I9"`B
M0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R("):9')UQ;YI('-T<F%N<VMO(&]K
M;F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;VQO;6)I82(*;7-G<W1R(")+;VQU
M;6)I:F$B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C
M;VQO<BYP:'`Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(D)A<G9A(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,T,`HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S0Q"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,#<@<V5R=FEC
M97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@4&EC
M:V5R(@IM<V=S='(@(DEZ8FER86QE8R!B87)V(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$Q-@IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G
M<W1R("(@27IB:7)A($)A<G9E("(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(R,S0*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B3F%S;&]V
M('-T;VQP:6-A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,`IM
M<V=I9"`B0V]M:6-S(@IM<V=S='(@(E-T<FEP:2(*"B,Z(&%D;6EN+V-M9'-H
M96QL+G!H<#HR-`IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")5:V%Z(@H*(SH@
M861M:6XO8VUD<VAE;&PN<&AP.C$X"FUS9VED(")#;VUM86YD(%-H96QL(@IM
M<V=S='(@(E5K87IN82!L=7!I;F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B2V]M96YT
M87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PIM
M<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B4VMU<&YO(&EM92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(DMO;6]R:2`B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED
M(")#;VUP86YY(@IM<V=S='(@(D1R=<6^8F$B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S8*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R(")28<2-=6YA
M;&YI:VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDP"FUS
M9VED(")#;VYD:71I;VXB"FUS9W-T<B`B3F%S=&%V:71E=B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C8Q"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@
M(DYA<W1A=FET=F4B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I
M9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R(")287IL:6ME
M(&YA<W1A=FET=F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS
M9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA
M<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(DYA<W1A=FET=F4@>F$@
M<VEN:W)O;FEZ86-I:F%O(&1L86[$C6YI:V]V(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$S-`IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@
M9&%T92XB"FUS9W-T<B`B3F%S=&%V:71V92!P;W1R96)U:F5J;R!AQ;YU<FER
M86YJ92(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(DYA<W1A=FD@)7,B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4R"FUS9VED
M(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(E!O=')D:2!G97-L;R(*"B,Z
M(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z-#`W"B,L(&9U>GIY
M"FUS9VED(")#;VYF:7)M(&YE=R!E;6%I;"!A9&1R97-S(@IM<V=S='(@(DYA
M9&]M97-T;FD@96QE:W1R;VYS:VD@;F%S;&]V(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I
M9"`B0V]N9V\B"FUS9W-T<B`B2V]N9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#
M;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@
M(DMO;F=O+"!$96UO:W)A=&G$C6YA(')E<'5B;&EK82(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#@*;7-G:60@(D-O;FYE8W1I
M;VX@9F%I;&5D+B(*;7-G<W1R(")0;W9E>F%V82!N:2!U<W!E;&$N(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.`IM<V=I9"`B
M0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R(")0;W9E>F%V82!N:2!U<W!E
M;&$Z(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"FUS
M9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V
M97(N(@IM<V=S='(@(EIA=G)N:F5N82!P;W9E>F%V82!Z(&IA=FYI;2!K;&IU
MQ(UN:6T@<W1R9<6^;FEK;VTN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@
M<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H
M)7,I(@IM<V=S='(@(EIA=G)N:F5N82!P;W9E>F%V82!Z(&IA=FYI;2!K;&IU
MQ(UN:6T@<W1R9<6^;FEK;VTN(%)A>FQO9SH@)7,@*"5S*2(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z.#8W"FUS9VED(")#;VYN96-T:6]N('1O
M($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")0;W9E>F%V82!S($944"!S
M=')EQ;YN:6MO;2!N:2!U<W!E;&$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W-H,BYP:'`Z.#@S"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N('1O(%-3
M2#(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B4&]V97IA=F$@<R!&5%`@<W1R
M9<6^;FEK;VT@;FD@=7-P96QA+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3(T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,3,W"FUS9VED(")#
M;VYT86-T<R(*;7-G<W1R(")3=&EK:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S
M=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S
M='(@(E-T:6L@:F4@8FEL('5S<&7%H6YO(&1O9&%N(&L@=F'%H6EM(&YA<VQO
M=F]M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M-C`*;7-G:60@(D-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z("(*
M;7-G<W1R(")4:7`@<W1I:V$@<W1I<VYJ96YE(&1A=&]T96ME.B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R(")6<V5B:6YE(&]D7"(E<UPB
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU92(*;7-G<W1R
M(").861A;&IU:B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*
M;7-G<W1R(")#;V]K;W9I(&]T;VMI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,W"FUS9VED(")#;V]K:64B"FUS9W-T<B`B4&G%H6MO=&5K(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(DMO<&ER86YJ92!N:2!U
M<W!E;&\Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B240@<W1R;\6A96LB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8W"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@(DMO<W1A<FEK
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B
M(%-L;VYO:V_%H<2-96YA(&]B86QA("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T
M(&UE<W-A9V4Z("(*;7-G<W1R(")01U`@;F4@;6]R92#%H6EF<FER871I('-P
M;W)OQ(UI;&$Z(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3`U-0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z("(*;7-G
M<W1R(").:2!M;V=O92!01U`@<&]D<&ES('-P;W)O96EL82XB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@
M;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(DYI(&UO9V_$
MC64@4R]-24U%(,6A:69R:7)A=&D@<W!O<F_$C6EL82XB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T
M(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(DYI(&UO9V_$C64@4R]-
M24U%('!O9'!I<R!S<&]R;\2-:6QA+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B3FD@;6]G
M;\2-92!D;V1A=&D@<W1I:V]V+B`E<RXB"@HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HQ,C$*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0X,@IM<V=I9"`B0V]U
M;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(E!O=F5Z879A
M('H@3$1!4"!S=')EQ;YN:6MO;2!N:2!M;V=OQ(UA+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B
M"FUS9W-T<B`B3FD@;6]G;\2-92!K;VYT<F]L:7)A=&D@/S\_/S\_("5S+B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-C8*;7-G:60@(D-O=6QD(&YO
M="!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")0;W9E>F%V82!Z
M($Q$05`@<W1R9<6^;FEK;VT@;FD@;6]G;\2-82XB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S
M='(@(DYE(&UO<F5M('9Z<&]S=&%V:71I('!O=F5Z879E(',@<W1R9<6^;FEK
M;VT@7"(E<UPB('H@=7!O<F%B;R!&5%`Z("5S(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,B"FUS9W-T<B`B3F4@;6]R96T@=7-T=F%R:71I('-E>FYA;6$@>F$@9&ES
M=')I8G5C:6IO+B`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$Q,C@*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B`B
M"FUS9W-T<B`B3FD@;6]G;\2-92!D9<6A:69R:7)A=&D@4$=0('!O9&%T:V]V
M.B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3(S"FUS
M9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T<B`B
M3FD@;6]G;\2-92!D9<6A:69R:7)A=&D@4R]-24U%('!O9&%T:V4N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T
M+B`E<R(*;7-G<W1R(").92!M;W)E;2!I>F)R:7-A=&D@<W1I:V]V+B`E<R(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYE(&UO<F5M(&EZ8G)I<V%T
M:2!D:7-T<FEB=6-I:G-K96=A('-E>FYA;6$N("5S(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S
M='(@(DYE(&UO<F5M(&EZ8G)I<V%T:2!N87-T879I='9E;F4@8<6^=7)A8VEJ
M<VME('-K<FEP=&4@7"(E<UPB(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HS.#$@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M.34S"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G
M<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B3FD@;6]G;\2-92!D;VQOQ(UI
M=&D@96QE:W1R;VYS:V5G82!N87-L;W9A('!R96IE;6YI:V$N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G
M:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM
M<V=S='(@(DYI(&UO9V_$C64@9&]L;\2-:71I(&-E;&]T;F5G82!I;65N:6MA
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I
M8G5T:6]N(&QI<W0N(@IM<V=S='(@(DYI(&UO9V_$C64@9&]L;\2-:71I(&-E
M;&]T;F5G82!D:7-T<FEB=6-I:G-K96=A('-E>FYA;6$N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@
M(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB
M=71I;VX@;&ES=',N(@IM<V=S='(@(DYI(&UO9V_$C64@9&]L;\2-:71I(&-E
M;&]T;F5G82!S97IN86UA(&1I<W1R:6)U8VEJ<VMI:"!S97IN86UO=B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G
M<W1R(").:2!M;V=OQ(UE(&YA;&_%OFET:2!S=')A=&5G:6IE(%PB)7-<(BXB
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H
M<#HS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E
M<UPB+B(*;7-G<W1R(").92!M;W)E;2!T=F]R:71I(&UA<&4@7"(E<UPB+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B
M0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E
M<BXB"FUS9W-T<B`B3FD@;6]G;\2-92!D;V)I=&D@:F%V;F5G82!K;&IUQ(UA
M(&]D(&ML:G7$C6YE9V$@<W1R9<6^;FEK82XB"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB
M)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B3FD@;6]G;\2-92!O9'!R971I
M(%PB)7-<(B!Z82!P:7-A;FIE+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B3FD@;6]G;\2-92!O9'!R
M971I("5S+B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC
M92YP:'`Z-#(P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N
M($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(DYI(&UO9V_$
MC64@;V1P<F5T:2!M;V1U;&$@;R!O<')A=FEL=5]V>F1RQ;YE=F%N:F$@)7,@
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DYI
M(&UO9V_$C64@<')E8G)A=&D@:6UE;FEK(%PB)7-<(BXB"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#<X
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HV.3D*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S
M97)V97(N(@IM<V=S='(@(DYI(&UO9V_$C64@9&]S9<2-:2!,1$%0('-T<F7%
MOFYI:V$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR-#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S
M='(@(DYI(&UO9V_$C64@<')E8G)A=&D@)7,N(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T
M:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A
M;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A
M:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@
M(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B).:2!M;\6^;F\@<&]N87-T
M879I=&D@9V5S;&$@>F$@>F%H=&5V86YE9V$@=7!O<F%B;FEK82X@3F5K871E
M<F4@86QI("(*(G9S97!O9')O8FYO<W1I(&YI<V\@<')A=FEL;F4N(%!O<VMU
M<VET92!Z;F]V82!A;&D@:V]N=&%K=&ER86IT92`B"B)V8<6A96=A=7!R879I
M=&5L:F$L(,2-92!P;W1R96)U:F5T92!N861A;&IN:F\@<&]M;\2-+B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P-PHC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,S@*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<U"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,0HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#<*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B3FD@=7-P96QO('9Z<&]S=&%V
M:71I.B`E<R`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R(").:2!U<W!E;&\@
M=GIP;W-T879I=&D@:6UE;FEK83H@)7,@(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<R(*;7-G<W1R(").:2!U<W!E;&\@=GIP;W-T879I=&D@9&ES=')I8G5C:6IS
M:V5G82!S97IN86UA.B`E<R`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G
M<W1R(").:2!U<W!E;&\@=GIP;W-T879I=&D@9&ES=')I8G5C:6IS:V5G82!S
M97IN86UA.B`E<R`B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,C$W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C(R,0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A
M<&%B:6QI=&EE<R(*;7-G<W1R(").:2!U<W!E;&\@=GIP;W-T879I=&DZ("5S
M("(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD
M(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B6F%H=&5V86YI
M("<E<R<@;FD@<&]D<F]B;F\@;V)L:6MO=F%N('8@)7,@<&]D;V)I+B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R(").92!M;W)E;2!I>F)R:7-A
M=&D@;6%P92!<(B5S7"(N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B)7,@:V]N9FEG=7)A8VEJ92!N:2!M;V=O
MQ(UE('-H<F%N:71I+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T('-A
M=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R(")+;VYF:6=U<F%C
M:6IE('9A<FYO<W1N92!K;W!I:F4@;FD@;6]G;\2-92!S:')A;FET:2XB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*
M;7-G<W1R(")+;VYF:6=U<F%C:6IE('9A<FYO<W1N92!K;W!I:F4@;FD@;6]G
M;\2-92!S:')A;FET:3H@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HQ,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B3F4@;6]R
M96T@<VAR86YI=&D@;F%S=&%V:71V96YE(&'%OG5R86-I:G-K92!S:W)I<'1E
M(&YA.B!<(B5S7"(N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P
M(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B3F4@;6]R96T@<VAR
M86YI=&D@:V]N9FEG=7)A8VEJ<VMO(&1A=&]T96MO("5S+"!V87)N;W-T;F4@
M:V]P:6IE+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R
M871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@
M(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P
M>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@HB
M3F4@;6]R96T@<VAR86YI=&D@(&MO;F9I9W5R86-I:G-K92!D871O=&5K92`E
M<RX@3&%H:V\@=7!O<F%B:71E(&%L:2!E;F\@;V0@(@HB;W!C:6H@>F$@<VAR
M86YI=&D@:V]D;R!Z861A:B!N82`E<R!A;&D@<F_$C6YO(&MO<&ER871E('-P
M;V1N:F\@:V]D;R!N82`E<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S
M97)V97(N(@IM<V=S='(@(DYI(&UO9V_$C64@:7-K86YJ92!,1$%0('-T<F7%
MOFYI:V$N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R(").:2!M
M;V=OQ(UE(&]D<W1R86YI=&D@<&]V97IA=F4@>B!<(B5S7"(N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E
M<R(*;7-G<W1R(").:2!M;V=OQ(UE(&'%OG5R:7)A=&D@<W1I:RX@)7,N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS
M.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3FD@;6]G;\2-92!AQ;YU<FER
M871I(&1I<W1R:6)U8VEJ<VMI('-E>FYA;2X@)7,B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B
M3FD@;6]G;\2-92!N87!I<V%T:2!K;VYF:6=U<F%C:6IE('IA(%PB)7-<(CH@
M)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<P"FUS9VED(")#;W5L
M9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@
M<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R(").92!N86ID96T@36]Z:6QL82!3
M:61E8F%R+B!0<F5V97)I(&%L:2!J92!O9'!R="XB"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W
M:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@
M(EPB)7-<(B!U<&]R86)N:6MU(&YE(&UO<F5M(&1O9&5L:71I('-L961EQ(UI
M:"!P<F%V:6,@>F$@;6%P;R!<(B5S7"(Z("5S(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30S,@IM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@
M(E!R9<6A=&5T;R!B97-E9&EL;R`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R(")$<L6^
M879A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X.0IM<V=I9"`B
M0V]U<G-E<R(*;7-G<W1R(")49<2-86II(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#
M<F5A=&4B"FUS9W-T<B`B57-T=F%R:2(*"B,Z('1E;7!L871E<R]P<F5F<R]I
M9&5N=&ET>7-E;&5C="YI;F,Z.38*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B
M"FUS9W-T<B`B57-T=F%R:2!N;W9O(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-3(*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*
M;7-G<W1R(")5<W1V87)I('!O9&UA<&4B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*
M;7-G<W1R(")!=G1O<B!D;W9O;&IE;FHB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS-#DY"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T
M<B`BQ:!T979I;&MA(&MR961I=&YE(&MA<G1I8V4@(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*
M;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B2')V8<6A:V$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X
M"FUS9VED(")#=6)A(@IM<V=S='(@(DMU8F$B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,C8*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B4V5D
M86YJ92`T(')A>G9O:FYE('-T;W!N:F4B"@HC.B!A9&UI;B]S97-S:6]N<RYP
M:'`Z-#@*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`B4V5D86YJ
M92!S96IE(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I
M;64N<&AP.C,U"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B4V5D86YJ
M:2#$C6%S(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,S"FUS9VED(")#=7)R
M96YT(%5S97)S(@IM<V=S='(@(E-E9&%N:FD@=7!O<F%B;FEK:2(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*
M;7-G<W1R(")3961A;FIE('9R96UE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(V.0IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G
M<W1R(")3961A;FIE('-T86YJ93HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T
M;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B3F%S=&%V:71E(&%K
M=&EV;F]S=&DL(&MI('-E(&)O9&\@:7IV<L6A:6QE(&]B('!R:6IA=FD@;F$@
M)7,N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S='(@(D-I<&5R
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@(D-Y<FEL;&EC
M("A+3TDX+5(I(@IM<V=S='(@(D-I<FEL:6-A*$M/23@M4BDB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M
M,3(U,2DB"FUS9W-T<B`B0VER:6QI8V$@*%=I;F1O=W,M,3(U,2DB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM<V=I9"`B0WER:6QL:6,O56MR86EN
M:6%N("A+3TDX+54I(@IM<V=S='(@(D-I<FEL:6-A+U5K<F%J:6YS:VD@*$M/
M23@M52DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G
M<W1R("+$C67%H6MA(')E<'5B;&EK82(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-38@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-3`*;7-G:60@(D1$(@IM<V=S='(@(D1$(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S4U.0IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N
M<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD
M<VXN<&AP*2(*;7-G<W1R("(B"B)$3E,@*'!O9VQE:B!H='1P.B\O<&5A<BYP
M:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S
M;BYP:'`I(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E
M+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B1&YE=FYO(@H*(SH@861M
M:6XO9&%T871R964N<&AP.C8S"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM
M<V=S='(@(E!R96=L961O=F%L;FEK(&1R979E<VYE('-T<G5K='5R92(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,U-3<*;7-G:60@(D1A=&%B87-E
M($QO;VMU<"(*;7-G<W1R(")0;VEZ=F5D8F$@8F%Z92!P;V1A=&MO=B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C@@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8X-@IM<V=I9"`B1&%T92(*;7-G<W1R
M(")$871U;2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC
M.C$S"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@(D1A='5M('!R96IE
M;6$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,#<W"FUS9VED(")$
M871E('-E;&5C=&EO;B(*;7-G<W1R("))>F)I<F$@9&%T=6UA(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-2!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S$T"FUS9VED(")$87DB"FUS9W-T<B`B1&%N(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-PHC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4U"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S@*;7-G:60@
M(D1E8V5M8F5R(@IM<V=S='(@(D1E8V5M8F5R(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*;7-G:60@
M(D1E9F%U;'0B"FUS9W-T<B`B4')I=GIE=&\B"@HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PIM<V=I9"`B1&5F875L="!#
M;VQO<B(*;7-G<W1R(")0<FEV>F5T82!"87)V82(*"B,Z(&9R86UE=V]R:R])
M9&5N=&ET>2])9&5N=&ET>2YP:'`Z.38*;7-G:60@(D1E9F%U;'0@261E;G1I
M='DB"FUS9W-T<B`B4')I=GIE=&$@:61E;G1I=&5T82(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HW-0IM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R
M(")0<FEV>F5T82!L=7!I;F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S@*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(D]P<F5D96QI='9E(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HW,"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E
M+FEN8SHQ,"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I
M9"`B1&5L971E(@IM<V=S='(@(EIB<FG%H6DB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C$Y-R!A9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B1&5L971E($=R
M;W5P(@IM<V=S='(@(EIB<FG%H6D@<VMU<&EN;R(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(T.0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R
M("):8G)IQ:%I(&1N979N:6LB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q"FUS
M9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R("):8G)IQ:%I(&1O=F]L
M:F5N:F4B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HY,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R
M("))>F)R:<6A:2!I;B!P<F7$C6ES=&D@<W!O<F_$C6EL82(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,30W"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT
M97)N871E('1E;7!L871E(@IM<V=S='(@(DEZ8G)IQ:%I(&]B<W1O:F7$C6D@
M86QT97)N871I=FYI('9Z;W)E8R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S0S,30N<&AP.C4T"FUS9VED(")$96QE=&4@;65S<V%G97,B"FUS
M9W-T<B`B27IB<FG%H6D@<W!O<F_$C6EL82(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T
M92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(DEZ8G)IQ:%I(&1O
M=F]L:F5N:F$@>F$@7"(E<UPB(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI
M<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM
M<V=S='(@(DEZ8G)IQ:%E;2!D;W9O;&IE;FIE('IA(%PB)7-<(B!I;B!V<V$@
M<&]D9&]V;VQJ96YJ83\B"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E
M;G1I='DN:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB
M"FUS9W-T<B`B27IB<FG%H6D@:7IB<F%N;R!I9&5N=&ET971O(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3,*;7-G:60@(D1E
M;&5T92!S=6(@9F]L9&5R<R(*;7-G<W1R("))>F)R:<6A:2!P;V0@;6%P92(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L('!H<"UF;W)M870*
M;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*
M;7-G<W1R(").92!M;W)E;2!I>F)R:7-A=&D@;F%S=&%V:71V96YE(&'%OG5R
M86-I:G-K92!S:W)I<'1E(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS9VED
M(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(L2,87,@9&]S=&%V92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B1&%N<VMA(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,C<*;7-G:60@(D1E<V-R:6)E
M('1H92!0<F]B;&5M(@IM<V=S='(@(D]P:<6A:71E('1EQ;YA=F\B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-#<*;7-G:60@(D1E<V-R:7!T:6]N
M(@IM<V=S='(@(D]P:7,B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C(P-@IM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I
M.B(*;7-G<W1R(")0;V1R;V)N;W-T:2`H='5D:2!V($AO<F1O=FD@;&]G(&1A
M=&]T96MI*3HB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(Q,`IM
M<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`B4&]D<F]B;F]S=&D@<V\@8FEL92!P<FEJ879L
M:F5N92!Z82!U<')A=FQJ86QC82XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C,U"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R(")287IV;VHB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R.0IM<V=I9"`B1&5W(%!O:6YT
M(@IM<V=S='(@(E)O<VG%H<2-92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S`V"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@
M(E)O<VG%H<2-92!Z82!P<F5JQ:%N:F\@=7)O.B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,C$*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S
M='(@(E)O<VG%H<2-93HB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM
M<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(DEM96YI:R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR-S`*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE
M<S\B"FUS9W-T<B`B4')I:V'%OF5M(,2-87,@<&\@,C0@=7)N96T@<VES=&5M
M=3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`P"FUS9VED(")$:7-P
M;&%Y($]P=&EO;G,B"FUS9W-T<B`B3F%S=&%V:71V92!P<FEK87IO=F%N:F$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.30*;7-G:60@(D1I
M<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B4')I:V'%OFD@<&]D
M<F]B;F\@;F%P;W9E9"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.3<*;7-G
M:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B4')I:V'%OFD@
M;F%P;W9E9"`H5$%&*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,P
M.#<*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(E!R:6MAQ;YI('9E
M;&EK;W-T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,0IM
M<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(D]B=F5S
M=&EL;R!O(&1O<W1A=FQJ96YI('!OQ:%T:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@
M(D1J:6)O=71I(@IM<V=S='(@(D3%OFEB=71I(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HT,C(*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS
M9W-T<B`B3F4@>F)R:<6A:2(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC
M92YP:'`B"FUS9W-T<B`B3F4@9&]S=&]P86H@;F5P;W-R961N;R!D;R!O:')A
M;FIA;FIA+G!H<"`B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ
M,B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T
M:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L
M(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R(")!;&D@<')V82!V<G-T82!V<V5B
M=6IE(&EM96YA('!O;&H_(,2-92!J:6@L('!R979E<FD@;F%B:7)A;&YI:SHB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R(")$;VUI;FEC
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G
M<W1R(")$;VUI;FEK86YS:V$@4F5P=6)L:6MA(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHX.`IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT
M/R!3:6=N('5P+B(*;7-G<W1R(").:7-T92!R96=I<W1R:7)A;FD_(%)E9VES
M=')I<F%J=&4@<V4N("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C@U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*
M;7-G<W1R(")0<F5N97-I("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$V,0IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@
M87,@4$A0('-C<FEP="XB"FUS9W-T<B`B4')E;F5S:71E(&=E;F5R:7)A;F\@
M:V]N9FEG=7)A8VEJ;R!K;W0@4$A0('-K<FEP=&\N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,Y-0IM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS
M9W-T<B`B4&%D86IOQ(UI(&UE;FDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,SD*;7-G:60@(D1R=6=S(@IM<V=S='(@(EID<F%V:6QA(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@S"FUS9VED(")$>6YA;6EC($UA:6PB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$S"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B16QE:W1R;VYS:VD@;F%S;&]V
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z
M.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A
M<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R(")0
M<F5N;W,@96QE:W1R;VYS:VEH('-P;W)OQ(UI;"!V(%--4RUJ92!Z82!O<&5R
M871E<FIE+"!K:2!T;R!O;6]G;\2-86IO+B(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*
M;7-G:60@(D524B(*;7-G<W1R(")%4E(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%
M8W5A9&]R(@IM<V=S='(@(D5K=F%D;W(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q
M-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z-S(*;7-G:60@(D5D:70B"FUS9W-T<B`B57)E9&DB"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P"FUS9VED(")%9&ET($)L;V-K(@IM
M<V=S='(@(E5R961I('-T;VQP96,B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y
M-B!A9&UI;B]G<F]U<',N<&AP.C(R-`IM<V=I9"`B161I="!'<F]U<"(*;7-G
M<W1R(")5<F5D:2!S:W5P:6YO(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`IM
M<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(E5R961I(&1O=F]L:F5N
M:F4B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C0R"FUS9VED(")%
M9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(E5R961I(&1O=F]L:F5N:F$B"@HC
M.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C0T"B,L('!H<"UF;W)M870*
M;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(E5R961I
M(&1O=F]L:F5N:F$@>F$@)7,@(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B57)E9&D@
M;6_%OFYO<W1I('IA.B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@
M9F]R(%PB)7-<(B(*;7-G<W1R(")5<F5D:2!D;W9O;&IE;FIA('IA(%PB)7-<
M(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B
M57)E9&D@9&]V;VQJ96YJ82!Z82`E<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT,`IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(DEZ;V)R8<6^979A
M;FIE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B16=I<'0B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(E-A
M;'9A9&]R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`W"FUS9VED(")%
M;6%I;"(*;7-G<W1R(")%;&5K=')O;G-K82!P;\6A=&$B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-CD*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B16QE
M:W1R;VYS:VD@;F%S;&]V(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C(U,0IM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S
M='(@(D5L96MT<F]N<VMI(&YA<VQO=B!S92!M;W)A('5J96UA=&DN(@H*(SH@
M9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HT-3`*(RP@9G5Z>GD*
M;7-G:60@(D5M86EL(&%D9')E<W-E<R!T;R!C;VYF:7)M(&YO="!F;W5N9"XB
M"FUS9W-T<B`B16QE:W1R;VYS:VD@;F%S;&]V('-E(&UO<F$@=6IE;6%T:2XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C<W"FUS9VED(")%;6%I
M;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")%;&5K=')O;G-K82!P;\6A
M=&$@<R!P;W1R9&ET=FEJ;R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G
M96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A
M>2(*;7-G<W1R(")%;6%I;"U335,@4')E:&]D(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,P,PIM<V=I9"`B16UO=&EC;VYS
M(@IM<V=S='(@(E-M9<6A:VDB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N
M(@IM<V=S='(@(E!R87IE;F\@<W!O<F_$C6EL;RXB"@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T
M>2!R97-U;'0N(@IM<V=S='(@(E!R87IE;B!R97IU;'1A="XB"@HC.B!F<F%M
M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S
M96%R8V@@=&5R;7,B"FUS9W-T<B`B4')A>F5N(&ES:V%L;FEK(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4T-0IM<V=I9"`B16YA8FQE(&EN<V5R=&EO
M;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS
M9W-T<B`B27IK;&]P:6T@=G-T879L:F%N:F4@<VQI:R!I>B!&;W1O($=A;&5R
M:6IE('8@=&5K<W0_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q,@IM
M<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T
M<B`B27IK;&]P:6T@;65N:2!Z(&1E<VYI;2!K;&EK;VT_(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@W-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,#@Q"FUS9VED(")%;F0@>65A<B(*;7-G<W1R(")+;VYE8R!L971A(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R-`IM<V=I9"`B(@HB16YT97(@
M82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I
M9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W
M:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*(E9N
M97-I=&4@=F%R;F]S=&YO('9P<F'%H6%N:F4L(&MI(&)O('!O<W1A=FQJ96YO
M+"#$C64@8F]S=&4@(@HB<&]T<F5B;W9A;&EP;VYA<W1A=FET:2!V8<6A92!G
M97-L;RP@;G!R+B##@N*`GFEM92!V8<6A96=A(&QJ=6)L:F5NQ(UK82!J93\Z
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y
M,@IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@(E9N
M97-I=&4@<W!O9&YJ92#$C7)K93HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A
M=&]R:6%L($=U:6YE82(*;7-G<W1R(")%:W9A=&]R:6%L;F$@1W9I;F5J82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B17)I=')E:F$B
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70O5FEE=RYP:'`Z.30@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C4S"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z-#$*;7-G:60@(D5R<F]R(@IM
M<V=S='(@(DYA<&%K82(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T
M92YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-R96%T:6YG
M(&)L;V-K.B`E<R(*;7-G<W1R(").87!A:V$@<')I('5S='9A<FIA;FIU('-T
M;VQP83H@)7,N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H
M;W(Z("5S(@IM<V=S='(@(DYA<&%K82!P<FD@8G)I<V%N:G4@<&]V97IA=F4@
M<VEN:')O;B!I>F%C:6IE.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG
M('-Y;F,@;&]G.B`E<R(*;7-G<W1R(").87!A:V$@<')I(&)R:7-A;FIU(&1N
M979N:6MA('-I;FAR;VYI>F%C:6IE.B`E<RXB"@HC.B!F<F%M97=O<FLO5&5M
M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(DYA<&%K82!P<FD@
M<&]V97IO=F%N:G4Z("5S+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P
M87-S=V]R9#H@)7,B"FUS9W-T<B`B3F%P86MA('!R:2!AQ;YU<FER86YJ=2!G
M97-L83H@)7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A
M9V4N(@IM<V=S='(@(DYA<&%K82!Z(&5L96MT<F]N<VMI;2!S<&]R;\2-:6QO
M;2XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R(").87!A:V$@<')I
M('!I<V%N:G4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B
M"FUS9W-T<B`B17-T;VYI:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%=&AI;W!I
M82(*;7-G<W1R(")%=&EO<&EJ82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT,0IM<V=I9"`B171H;FEC(@IM<V=S='(@(D5S=&]N:6IA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS
M9W-T<B`B179R;W!A(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC
M.C$P,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0S"FUS9VED(")%=F5R>2`Q
M-2!M:6YU=&5S(@IM<V=S='(@(E9S86MI:"`Q-2!M:6YU="(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.3,*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*
M;7-G<W1R(")6<V%K:2`R(&UI;G5T:2(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHY."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0P"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(D5V97)Y(#,P('-E8V]N
M9',B"FUS9W-T<B`B5G-A:VEH(#,P('-E:W5N9"(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;&%Y;W5T+FEN8SHQ,#`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T
M,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDT"FUS9VED(")%=F5R>2`U
M(&UI;G5T97,B"FUS9W-T<B`B5G-A:VEH(#4@;6EN=70B"@HC.B!F<F%M97=O
M<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R
M>2!,;V=I;B(*;7-G<W1R(")6<V%K82!P<FEJ879A(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]L87EO=70N:6YC.C$P,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0T"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B5G-A:V4@<&]L
M('5R92(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,#,*(RP@
M9G5Z>GD*;7-G:60@(D5V97)Y(&AO=7(B"FUS9W-T<B`B5G-A:V4@<&]L('5R
M92(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.2!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S0Q"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.3(*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")6<V%K;R!M:6YU=&\B
M"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA
M;7!L92!V86QU97,Z(@IM<V=S='(@(E!R:6UE<B!V<F5D;F]S=&DZ(@H*(SH@
M861M:6XO<&AP<VAE;&PN<&AP.C@P(&%D;6EN+V-M9'-H96QL+G!H<#HT.2!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3(V"FUS9VED(")%>&5C=71E(@IM<V=S='(@
M(DEZ=F5D:2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z-C$T"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B4&]V9<2-86HB
M"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,Q"B,L(&9U>GIY
M"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R(")+;VYE8R!L971A(@H*
M(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B
M17AP96-T960@)RDG(@IM<V=S='(@(E!R:<2-86MO=F%N("<I)R(*"B,Z(&9R
M86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C
M=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B
M4')IQ(UA:V]V86YA(&IE(&)I;&$@8F5S961A(&%L:2!B97-E9&YA('IV97IA
M('8@;F%V961N:6-A:"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(D1A='5M
M('IA<&%D;&]S=&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8W-PIM<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`B6F%S=&]P;FEK(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-@IM<V=I9"`B1E10('5P;&]A
M9"!O9B!S971U<"(*;7-G<W1R(")&5%`@;F%L;\6^:71E=B!N86UE<W1I='9E
M+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(U,0IM<V=I
M9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(DYI
M('5S<&5L;R!V>G!O<W1A=FET:2!P<F5F97)E;F-E+B(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0
M('-E<G9E<BXB"FUS9W-T<B`B4&]V97IA=F$@>B!,1$%0('-T<F7%OFYI:V]M
M(&YI('5S<&5L82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z
M,3`Q"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*
M;7-G<W1R(")0;W9E>F%V82!S(%--0B!S=')EQ;YN:6MO;2!N:2!U<W!E;&$@
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3$@9G)A;65W;W)K
M+U9&4R]61E,O<W-H,BYP:'`Z-S$T"B,L('!H<"UF;W)M870*;7-G:60@(D9A
M:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R(")+;W!I<F%N:F4@
M:7H@7"(E<UPB+"!N:2!U<W!E;&\N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HW,38@9G)A;65W;W)K+U9&4R]61E,O<W-H,BYP:'`Z-S$Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB
M"FUS9W-T<B`B2V]P:7)A;FIE(&YA(%PB)7-<(BP@;FD@=7-P96QO+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#D*;7-G:60@(D9A:6QE
M9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B3FD@
M=7-P96QO('9Z<&]S=&%V:71I(&YO=F\@4T%33"!P;W9E>F%V;RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4P-B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C<V-0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<V@R+G!H<#HW
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E
M<UPB+B(*;7-G<W1R(").:2!U<W!E;&\@<')E;6%K;FET:2!K.B`E<R`B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0U-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(DYE;6]G
M;\2-92!P<F5B<F%T:3H@)7,@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B3V1D86QJ
M;F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV
M:6YA<RDB"FUS9W-T<B`B1F%L:VQA;F1S:VD@;W1O:VDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S
M"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S='(@(D9E<G-K:2!O=&]K:2`B
M"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X"FUS9VED(")&871A;"!%
M<G)O<CHB"FUS9W-T<B`B2'5D82!N87!A:V$A(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S
M='(@(D9A>"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-C4*;7-G
M:60@(D9A>&5S(@IM<V=S='(@(D9A>&DB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T
M<B`B1F5B<G5A<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C,R"FUS9VED
M(")&965L<R!,:6ME(@IM<V=S='(@(E!OQ(UU=&ET:2!S92!K;W0B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(U"FUS9VED(")&965L<R!L
M:6ME.B`B"FUS9W-T<B`B4&_$C75T:71I('-E(&MO=#HB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H
M;W=E<G,B"FUS9W-T<B`B3F5K86H@;F%L:79O=B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3
M:&]W97)S(@IM<V=S='(@(DYE:V%J('-N9<6^;FEH(&UE=&7%OF5V(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(S,@IM<V=I9"`B1FEE;&0@;6%T
M<FEX(@IM<V=S='(@(DUA=')I8V$@<&]L:F$B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS-C$R"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R
M(")&:6=L970@0T%05$-(02(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,V,38*;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(D9I9VQE="!P:7-A
M=F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@(D9I9,6^:2(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B1FEL
M92(*;7-G<W1R(")$871O=&5K82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I
M;&4B"FUS9W-T<B`BQ:!T971J92!$871O=&5K.B`E<R!D871O=&5K(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`BQ:!T971J92!$871O
M=&5K.B`E<R!D871O=&5K(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0S,`IM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(E5P<F%V:71E;&H@
M9&%T;W1E:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,`HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"FUS9VED
M(")&:6QE($YA;64B"FUS9W-T<B`B26UE(&1A=&]T96ME(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S(V-0IM<V=I9"`B1FEL92!S96QE8W1I;VXB
M"FUS9W-T<B`B27IB:7)A(&1A=&]T96ME+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T.3D*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(DYA
M;&_%OFD@9&%T;W1E:V\B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R
M+G!H<#HY,#<*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*
M;7-G<W1R(")$;V1A;F$@9&%T;W1E:V$@;FD@<&]D<')T82XB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@(D9I;'1E<G,B"FUS9W-T
M<B`B1FEL=')I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R
M(")&:6YS:V$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&
M:7)S="!(86QF(@IM<V=S='(@(E!R=F$@<&]L;W9I8V$B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&
M:7)S="!1=6%R=&5R(@IM<V=S='(@(E!R=F$@Q(UE=')T:6YA(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-PIM<V=I9"`B
M1FEX(')A=&EO(@IM<V=S='(@(E-T86QN92!V96QI:V]S=&DB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,R"FUS9VED(")&
M;&EP(@IM<V=S='(@(D]B<FYI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R(")-96=L82(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C8P(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L
M9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(B5S(&UA<&$@;F4@;V)S
M=&%J82`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(D9O
M;V0B"FUS9W-T<B`B2')A;F$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T
M-@IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B3F%P;W9E9"`H5$%&
M*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW-PIM<V=I9"`B
M(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E
M8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N
M=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G
M<W1R(")$;F5V:2!N87!O=F5D:2X@*$YA<&]V961A(&QE(&QA:&MO('IE;&\@
M9&]L9V$I(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-`IM<V=I
M9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(E-T92!P;WIA8FEL
M:2!V8<6A92!G97-L;S\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#@U"FUS9VED(")&;W)M<R(*;7-G<W1R(")O8FQI:V4B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,C8*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B4W)E
MQ(UA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C$P-`IM<V=I9"`B1F]R
M='5N92!T>7!E(@IM<V=S='(@(E-R9<2-92(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT,PIM<V=I9"`B1F]R='5N97,B"FUS9W-T<B`B4W)EQ(UE(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED(")&;W)T=6YE<R`R
M(@IM<V=S='(@(E-R9<2-92`R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0W-@IM<V=I9"`B1F]R=6US(@IM<V=S='(@(E1A8FQA('!O9V]V;W)O
M=B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3@*;7-G:60@(D9O
M<G=A<F1S(@IM<V=S='(@(E!R975S;65R:71E=F4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")&<B(*;7-G
M<W1R(")&<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92(*;7-G<W1R(")&
M<F%N8VEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM
M<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B1G)A;F-I:F$L
M($MO;&]N:6%L;F$@;65T<F]P;VQA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E
M;F-H($=U:6%N82(*;7-G<W1R(")&<F%N8V]S:V$@1W9A:F%N82`B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R(")&<F%N
M8V]S:V$@4&]L:6YE>FEJ82`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC
M:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R(")&<F%N8V]S:VD@:G7%
MOFYI('1E<FET;W)I:B`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<P"FUS9VED(")&<F]M(@IM<V=S='(@(D]D(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T,B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S4R"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS.3@*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R(")/9"`B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,@IM<V=I9"`B1G5L;"!$
M97-C<FEP=&EO;B(*;7-G<W1R(")0;VQN($]P:7,Z(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U
M;&P@36]O;B(*;7-G<W1R(")0;VQN82!L=6YA(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C8U('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-C$*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R(")0;VQN;R!I;64B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R(")'86)O;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R(")'86UB:6IA(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE
M<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(E5S='9A<FD@)7,@3F%S
M=&%V:71V92(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M
M;#HV"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R(")'96YE<FER86H@
M:V]D;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B1W)U
M>FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B3F5M
MQ(UI:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N82(*;7-G<W1R(")'86YA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(D=I8G)A
M;'1A<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<V
M"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(D1A;F\@:6UE(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W.2!T96UP;&%T97,O<')E9G,O
M87!P+FEN8SHQ,`HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ.0IM<V=I
M9"`B1VQO8F%L($]P=&EO;G,B"FUS9W-T<B`B4W!L;\6A;F4@36_%OFYO<W1I
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3<*;7-G:60@(D=O(@IM
M<V=S='(@(E!O:F1I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS
M9VED(")';V5D96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,S$*;7-G:60@(D=O;V=L92!-87!S(@IM
M<V=S='(@(D=O;V=L;W9E(&UA<&4B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H
M<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(DG%H<2-:2!Z
M($=O;V=L;VTB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C,X"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B3&5S='9I8V$@
M<VEV:6YE("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B
M1W+$C6EJ82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")'
M<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B1W+%H6MI("A)4T\M.#@U.2TW
M*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R(")'<F5N
M;&%N9&EJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B
M1W)E;F%D82(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<X"FUS9VED(")'<F]U
M<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")3:W5P:6YS:V$@861M:6YI<W1R
M86-I:F$B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA
M;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(DEM96YA(%-K=7!I;B!N
M92!S;65J;R!B:71I('!R87IN82(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HS,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A
M<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9#H@(@IM<V=S='(@(D%U=&A?;&1A<#H@3F4@;6]R96T@9&]D
M871I('-K=7!I;F4@)7,N(%-P;W)OQ(UI;&\@<W1R9<6^;FEK83H@(@H*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q."!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?
M;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R(")3:W5P
M7VQD87`Z($YE(&UO<F5M(&EZ8G)I<V%T:2!S:W5P:6YE("5S(@H*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S."!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF;W)M870*;7-G:60@(D=R
M;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B
M4VMU<%]L9&%P.B!.92!M;W)E;2!N861G<F%D:71I('-K=7!I;F4@)7,B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W
M-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(E-K=7!I;F4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V
M"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(D=U861E;&]U<&4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R(")'=6%M(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R(")'=6%T96UA;&$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*
M;7-G<W1R(")'=65R;G-E>2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@
M(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(D1O=F]L:F5N:F$@>F$@9V]S
M=&4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DS"FUS9VED(")'
M=65S=&)O;VLB"FUS9W-T<B`B2VYJ:6=A(&=O<W1O=B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=U:6YE82(*;7-G<W1R(")'=FEN96IA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X
M"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(D=V:6YE:F$M0FES<V%O
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B1W9A:F%N
M82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV.0IM<V=I9"`B2%1-
M3"(*;7-G<W1R(")(5$U,(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P
M+G!H<#HQ-30*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")/=F5R:F5N96=A($A45%`@3FES96T@;F'%H65L+B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B2&%I=&DB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M
M06QG;W)I=&AM(@IM<V=S='(@(DAA<V@@06QG;W)I=&5M(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4S-@IM<V=I9"`B(@HB2&%V92!A(&)U='1O;B!I
M;B!T:&4@=&]O;&)A<B!T:&%T('!O<',@=7`@82!W:6YD;W<@=VET:"!S<&5C
M:6%L(&-H87)A8W1E<G,_(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@
M(DUE9VQI8V$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,C@@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(P,@IM<V=I9"`B2&5A9&5R(@IM<V=S
M='(@(D=L879A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE
M<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R(")';&%V92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)
M<VQA;F1S(@IM<V=S='(@(DAE87)D(&]T;VL@:6X@36-$;VYA;&1O=F\@;W1O
MQ(UJ92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(S"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(DUOQ(UN82!N979I
M:'1A(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DAE8G)E
M=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R(")(96)R96IS:VD@*$E33RTX.#4Y
M+3@M22DB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HR,@IM<V=I9"`B2&5I
M9VAT(@IM<V=S='(@(E9IQ:%I;F$B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O2&5L<"YP:'`Z,3@Q(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H
M<#HQ.#(*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S
M+VAE;'`O:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T<B`B4&]M;\2-
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,X-`IM<V=I9"`B2&5L
M<&5R(@IM<V=S='(@(E!O;6_$C6QN:6LB"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B4&]L;V)L82(*"B,Z
M('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@
M;V8@=&AE(&9I;&4Z(@IM<V=S='(@(E1U:V%J(&IE('IAQ(UE=&5K(&1A=&]T
M96ME.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C<Q"FUS9VED(")(:6=H(@IM<V=S='(@(E9I<V]K;R(*"B,Z('1E;7!L871E
M<R]M96YU+VUE;G4N:6YC.C<*;7-G:60@(DAO7VUE(@IM<V=S='(@(D1O;6]V
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET
M>2!3=&%T92DB"FUS9W-T<B`B5F%T:6MA;B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S
M(@IM<V=S='(@(D1O;6'$C6D@;F%S;&]V(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C<P"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R("));65N
M:6LB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(D1O;6'$C6D@=&5L969O
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B2&]N
M9'5R87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R
M(")(;VYG($MO;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C<*
M;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HT-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S
M<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3F5V96QJ879E;B`E<R!8
M34P@<&]D871E:R!N86ID96X@=B!S<&]R;\2-:6QU("5S(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T
M("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.;V)E;F\@<W!O<F_$C6EL;R!S
M92!N92!U:F5M82!S('!R961M971O;2`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z-#0U"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!6('-P;W)OQ(UI;'4@)7,@;FD@;F%J
M9&5N(&YO8F5N('!R961M970@=&EP82`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,3(U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@
M(DAO<F1E+TMO;&%B.B!5<W!EQ:%N;R!O9'-T<F%N:F5N("5S(%PB)7-<(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D
M92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@
M)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R(")(;W)D92]+;VQA8CH@
M26YT96=R86-I:G-K82!N87!R879A('IA:'1E=F$@)V1O;7AM;"<@4$A0(&5K
M<W1E;GII:F\B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4Q,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R
M96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D
M92]+;VQA8CH@3F4@;6]R92!U<W1V87)I=&D@;F]V;R!834P@9')E=F\@>F$@
M)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@
M)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3F4@;6]R96T@
M;V1S=')A;FET:2`E<R!<(B5S7"(Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HT.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O
M9B!T>7!E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.92!M;W)E;2!P;VEZ
M=F5D971I('IA($U)344@240@>F$@9&5L(&]D('9R<W1E("5S(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DW"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E
M<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3F4@;6]R96T@<VEN:')O
M;FEZ:7)A=&D@)7,@7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3,S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B
M2&]R9&4O2V]L86(Z($YE(&UO<F5M('-I;FAR;VYI>FER871I(&1E;&4Z("5S
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.97IN86YA(&1E;&ET978@7"(E<UPB
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO
M=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R(")+
M;VQI:V\@<&]L:B`H<W1O;'!C978I:F4@=&%M/R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.3,@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#(*
M;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(E9L8<6^;F]S="(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3,*;7-G:60@(DAU;6ED:71Y.B`B
M"FUS9W-T<B`B5FQAQ;YN;W-T.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#8*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R(")(=6UO<FES=&DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B36%DQ;YA<G-K
M82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W,"!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,T"B,L('!H<"UF;W)M870*
M;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S
M='(@(E5S='9A<FIA;FIE($E-05`@;F%B:7)A;&YI:V$@;FD@=7-P96QO.B`E
M<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,CDV"B,L('!H<"UF;W)M870*
M;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S
M='(@(D)R:7-A;FIE($E-05`@;F%B:7)A;&YI:V$@;FD@=7-P96QO.B`E<R(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W-R!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C0Q"B,L('!H<"UF;W)M870*;7-G
M:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM
M<V=S='(@(E5S='9A<FIA;FIE(&MV;W1E($E-05`@;F%B:7)A;&YI:V$L(&YI
M('5S<&5L;SH@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S(U
M"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(DE0($YA<VQO=B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D
M9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B25`@3F%S;&]V(&YI(&YA
M(')A>G!O;&%G;RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N
M<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#
M2412(&)L;V-K+B(*;7-G<W1R("))4"!.87-L;W8@;FD@=B!D;W9O;&IE;FD@
M0TE$4B!S:W5P:6YI+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T
M:6]N+B(*;7-G<W1R("):86ML96YJ96X@25`N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS
M9VED("))8V5L86YD(@IM<V=S='(@(DES;&%N9&EJ82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.#`*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B
M4V%M;R!I:V]N92(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B26MO;F4@
M>F$@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Q"FUS9VED("))
M8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B26MO;F4@>B!B97-E9&EL;VTB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DS"FUS9VED("))9&5N=&ET>2=S
M(&YA;64Z(@IM<V=S='(@(DED96YT:69I:V%C:6IS:V\@:6UE.B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C8P,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@
M)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(B5S('IA
M(&]D<')E=&D@=B!N;W9E;2!O:VYU+"#$C64@;FD@<')A=FEL;F\@<')I:V%Z
M86YO+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ-S(*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N
M;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B
M92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"B+$
MC64@=FED:71E('1O('-P;W)OQ(UI;&\@:6X@<VQIQ(UI8V4@;F4L('!O;65N
M:2P@9&$@=F'%H2!B<G-K86QN:6L@;F4@;6]R92`B"B)O9'!R971I('-L:<2-
M:6-E+"!K:2!J;R#%OF5L:71E(&YA;&_%OFET:2XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-S<T"FUS9VED("));6%G92!U<&QO860B"FUS9W-T
M<B`B1&]D86H@<VQI:V\B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM
M<V=I9"`B26UA9V5S(@IM<V=S='(@(E-L:6ME(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHW
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0L
M(%-T97`@)60B"FUS9W-T<B`B5FYO<RP@2V]R86L@)60B"@HC.B!T96UP;&%T
M97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("))
M;7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B5FYEQ:%E;F\@<&]L:F4Z("5S
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP
M;W)T960@9FEE;&1S.B(*;7-G<W1R(")6;F7%H65N82!P;VQJ83HB"@HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S0*;7-G:60@
M(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B4&]S<F5D
M;W9A;B!N97!R879I;&5N('5K87HN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U
M<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(DYE<')A=FEL;F\@
M=7!O<F%B;FG%H6MO(&EM92!I;B]A;&D@9V5S;&\N(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R
M;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A
M8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@
M:&5L<"XB"FUS9W-T<B`B(@HB3F5P<F%V:6QN;R!U<&]R86)N:<6A:V\@:6UE
M(&%L:2!A;'1E<FYA=&EV96X@;F%S;&]V+B!0;W-K=7-I=&4@>FYO=F$@86QI
M("(*(FMO;G1A:W1I<F%J=&4@=F'%H65G82!S:W)B;FEK82P@Q(UE('!O=')E
M8G5J971E(&YA9&%L:FYJ;R!P;VUOQ(TN(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED
M("));F1I82(*;7-G<W1R("));F1I:F$B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S
M-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R(")0;W-A;65Z;FD@
M57!O<F%B;FEK:2`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N97-I82(*
M;7-G<W1R("));F1O;F5Z:6IA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(W,PIM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M86-I
M:F4@;R!S97-T86YK=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS,C(*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N
M(@IM<V=S='(@(DEN9F]R;6%C:6IE(&YI<V\@=F7$C2!D;W-E9VQJ:79E+B(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30Y"FUS9VED("));G-E<G0@86QT
M97)N871E('1E;7!L871E(@IM<V=S='(@(E9S=&%V:2!A;'1E<FYA=&EV96X@
M=GIO<F5C(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T,@IM<V=I9"`B
M26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E
M:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(E9S=&%V:71E(&5L96MT
M<F]N<VMI(&YA<VQO=B!N82!K871E<F5G82!L86AK;R!P<F5J;65T92!N;W9O
M(&=E<VQO.B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N
M<&AP.C4P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDP"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS9W-T<B`B5G-T879I=&4@
M<W!O<F_$C6EL;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S,*;7-G
M:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET
M>2!Q=65S=&EO;CHB"FUS9W-T<B`B5G!IQ:%I=&4@>F%H=&5V86X@;V1G;W9O
M<B!N82!V87)N;W-T;F\@=G!R8<6A86YJ93HB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS=69F
M:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES
M="XB"FUS9W-T<B`B4W1A;FIE(&YA(')AQ(UU;G4@;F4@>F%D;W-T=6IE('IA
M('!OQ:%I;&IA;FIE(&YA(,6^96QJ96X@<W!I<V5K+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("))
M;G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R(")3=&%N:F4@;F$@<F'$C75N
M=2!N92!Z861O<W1U:F4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3`X-`IM<V=I9"`B26YT96=E<B(*;7-G<W1R(")#96QO(,6A=&5V:6QO(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$T,@IM<V=I9"`B26YT96=E
M<B!L:7-T(@IM<V=S='(@(E-E>FYA;2!C96QI:"#%H71E=FEL(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS
M9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R
M(").979E;&IA=F5N(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$V-PHC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ.30*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C$R"FUS9VED("));G9A
M;&ED(%I)4"!D871A(@IM<V=S='(@(DYE=F5L:F%V96X@6DE0('!O9&%T96LN
M("(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L
M:60@87!P;&EC871I;VXN(@IM<V=S='(@(DYE=F5L:F%V;F$@87!L:6MA8VEJ
M82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(DYE
M=F5L:F%V;FD@240@<&%K970N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,W-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#0V"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(U,C`@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C4X-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R
M(").979E;&IA=FYI('!O9&%T:VD@<V\@8FEL:2!O9'!O<VQA;FDN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P
M"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@
M(DYE=F5L:F%V96X@;F%S;&]V(&YA<VQO=FYI:V$N(@H*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3`Y"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$S.0HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR-#$*;7-G:60@(DEN=F%L:60@9FEL
M92!F;W)M870B"FUS9W-T<B`B($YE=F5L:F%V;F$@;V)L:6MA(&1A=&]T96ME
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S`*;7-G:60@
M(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(DYE=F5L:F%V96X@;&EC
M96[$C6YI(&ML:G7$C2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,38T"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G
M<W1R(")/9')E:F5N(&YE=F5L:F%V96X@:W)A:BXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN
M=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(DYE=F5L:F%V96X@=&EP7VUS9RXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S
M='(@(DYE=F5L:F%V96X@86QI(&UA;FIK86IOQ(T@87!I7VED+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM
M<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@
M(DYE=F5L:F%V;FD@86QI(&UA;FIK86IOQ(UI('!A<F%M971R:2XB"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C8*;7-G:60@(DEN=F%L:60@<&%R
M96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(DYE=F5L:F%V;F\@9&]V;VQJ96YJ
M92!S=&%RQ:%E=BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,38V"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(DYE=F5L
M:F%V96X@<&%R=&YE<FIE=B!I9"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,38X"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS
M9W-T<B`B3F5V96QJ879N82!K;V1A(&%R=&EK;&$N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("))
M;G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R(").979E;&IA=F5N('!R;W1O:V]L
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HW
M,2!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C@P"B,L('!H
M<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS
M9W-T<B`B3F5V96QJ879E;B!N87-L;W9N:6LZ(%PB)7-<(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`X,"!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$R-C,*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S
M='(@(B!.979E;&IA=F5N(&]B:F5K="!D96QJ96YJ82`B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@
M(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(DYE=F5L:F%V96X@
M:7IV;W)N:2!N87-L;W8N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N:6-O9&4@
M9&%T82XB"FUS9W-T<B`B($YE=F5L:F%V96X@=6YI:V]D('!O9&%T96LB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<S"FUS9VED("));G9E;G1O
M<GDB"FUS9W-T<B`B26YV96YT=7)A+W!O<&ES(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8X,`IM<V=I9"`B26YV97)T('-E
M;&5C=&EO;B(*;7-G<W1R(")/8G)N:2!I>F)O<B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM
M<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("))<F%N
M+"!)<VQA;7-K82!297!U8FQI:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER
M87$B"FUS9W-T<B`B27)A:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N
M9"(*;7-G<W1R("))<G-K82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O
M;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B4&]S86UE>FYE(&YE=FEH=&4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R("))>G)A96PB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-@IM<V=I9"`B
M27-S=65R(@IM<V=S='(@(DEZ9&%J871E;&HB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G
M:60@(DET86QY(@IM<V=S='(@(DET86QI:F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G
M:60@(DIA;6%I8V$B"FUS9W-T<B`B2F%M86IK82(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")*86YU87)Y(@IM
M<V=S='(@(DIA;G5A<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS
M9W-T<B`B2F%P;VYS:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM
M<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R(")*87!O;G-K
M:2`H25-/+3(P,C(M2E`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R(")*97)S97DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R(")*;W)D86YI:F$B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B
M2G5L>2(*;7-G<W1R(")*=6QI:B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")*=6YE(@IM<V=S='(@(DIU;FEJ
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(DMA
M>F%H<W1A;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR-C4*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(D]B9'+%
MOFEM(&EZ=FER;FEK/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS
M9W-T<B`B2V5N:6IA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H
M<#HX-@IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R(")+97)B97)O<R!S=')EQ;YN:6L@>F%V<FYI;"!O
M=F5R:71E=BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@
M(DME<FYE;"!.97=B:65S(@IM<V=S='(@(DME<FYE;"!N;W9I;F-I(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@
M0W)E871I;VXB"FUS9W-T<B`B57-T=F%R:2!+;&IUQ(T@(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R
M<')I;G0B"FUS9W-T<B`B3V1T:7,@2VQJ=<2-82(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G
M<W1R(")$;VS%OFEN82!+;&IUQ(UA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R(")4:7`@
M2VQJ=<2-82`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4Y.0IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(E5P;W)A8F$@2VQJ=<2-
M82`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G
M:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BXB"FUS9W-T<B`B2VQJ=<2-(,6^92!O8G-T86IA(&YA(&IA=FYE;2!K;&IU
MQ(UN96T@<W1R9<6^;FEK=2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#@*;7-G:60@(DMI9',B"FUS9W-T<B`B3W1R;V-I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T
M"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R(")+:7)I8F%T:2`B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(DMO<F5J82P@1&5M;VMR871IQ(UN82!L:G5D<VMA
M(')E<'5B;&EK82`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U
M8FQI8R!O9B(*;7-G<W1R(")+;W)E:F$L(%)E<'5B;&EK82`B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM
M<V=S='(@(DMO<F5J<VMI("A%54,M2U(I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED
M(")+=7=A:70B"FUS9W-T<B`B2W5V86IT("(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I
M9"`B2WER9WEZ<W1A;B(*;7-G<W1R(")+:7)G:7II:F$@(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHW-0IM<V=I9"`B3&%N9W5A9V4B"FUS9W-T
M<B`B2F5Z:6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$
M96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(DQA;W,@;&IU9'-K82!D96UO
M:W)A=&G$C6YA(')E<'5B;&EK82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ
M-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R("):861N:F$@<&]L;W9I8V$B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#@*;7-G:60@(DQA<W0@4&%S
M<W=O<F0@0VAA;F=E(@IM<V=S='(@(EIA9&YJ82!S<')E;65M8F$@9V5S;&$Z
M("(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R("):861N:F$@Q(UE
M=')T:6YA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C,*;7-G:60@(DQA
M<W0@57!D871E9#HB"FUS9W-T<B`B6F%D;FIE(&'%OG5R:7)A;FIE.B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R("):861N:F$@<')I:F%V83H@
M)7,@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF
M;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`B
M6F%D;FIA('!R:6IA=F$Z("5S(&EZ("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z-S$T"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R
M("):861N:F$@<')I:F%V83H@3FEK;VQI(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED
M("),871V:6$B"FUS9W-T<B`B3&%T=FEJ82`B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#D*;7-G:60@(DQA=R(*;7-G<W1R(")0<F%V;R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("),:6)A;F]N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,X.`IM<V=I9"`B3&5F="!H96%D
M97(B"FUS9W-T<B`B3&5V;R!O9VQA=FQJ92(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,S.#0*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(E9R
M961N;W-T:2!N82!L979I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO
M(@IM<V=S='(@(DQE<V]T;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(U-0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B4F%V96XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B3&EB97)I:F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T
M<B`B3&EB:6IA("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I
M;B(*;7-G<W1R("),:65C:'1E;G-T96EN("(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ>FQE
M(@IM<V=S='(@(E)A:&5L('!RQ:%E8R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(V"FUS9VED("),:6=H="!286EN(@IM<V=S
M='(@(E)A:&5L(&1EQ;XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R
M("):9V]D86H@<F%H96P@9&7%OB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H="!286EN($QA=&4B"FUS
M9W-T<B`B4&]Z;F\@<F%H96P@9&7%OB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E
M<B(*;7-G<W1R(")0;&]H82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E
M<B(*;7-G<W1R(")0;&]H82!Z(&=R;65N:F5M(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B
M"FUS9W-T<B`B4F%H96P@<VYE9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*
M;7-G<W1R(")3;F7%OFYI(&UE=&7%OB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B3&EB
M97)I:F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#(W"FUS9VED
M("),:6YK(@IM<V=S='(@(E!O=F5Z879A(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`Q,PIM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T
M;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R(")0
M;W9EQ;YI(&4M;F%S;&]V(',@;V)R87IC96T@>F$@<V5S=&%V;R!N;W9E('!O
MQ:%T;R!M92!P<FEK87IO=F%N:F5M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL
M=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,@IM<V=I9"`B3&EN:W,B"FUS
M9W-T<B`B4&]V97IA=F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*
M;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R("),:6YU>"!P:<6A:V]T96LB
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT-@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I
M9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(E-E
M>FYA;2`M('5P;W)A8FYI:R!L86AK;R!V:61I(&UA<&\B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3,R"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R
M(")397IN86T@<&]D871K;W9N:6@@8F%Z(@H*(SH@<V5R=FEC97,O:&5L<"]I
M;F1E>"YP:'`Z-3$*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B
M4V5Z;F%M(%1E;2!0;VUOQ(UI("(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,S$*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(E-E>FYA;2!T86)E;"(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3$V"FUS9VED
M("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B(%-E>FYA;2!!<FAI=F$@(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU,3$*;7-G:60@(DQI
M<W0M2&5L<"(*;7-G<W1R(")397IN86T@4&]M;\2-:2`B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Q.`IM<V=I9"`B3&ES="U)9"(*
M;7-G<W1R(")397IN86T@261E;G1I=&5T("(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3$T"FUS9VED("),:7-T+4]W;F5R(@IM<V=S
M='(@(E-E>FYA;2!,87-T;FEK;W8@(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12](96%D97)S+G!H<#HU,34*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R(")3
M97IN86T@4&_%H71E("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R
M<RYP:'`Z-3$S"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R(")397IN
M86T@4')I:F%V("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3$R"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(E-E>FYA
M;2!/9&IA=B`B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S
M='(@(E-P:7-E:R!S97IN86UA('-E:B!N:2!U<W!E;#H@)7,N(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C,U"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I
M;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R(")397IN86T@=7!O<F%B;FEK
M;W8@;FD@;6]G;\2-93H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N
M;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N
M(@IM<V=S='(@(E-E>FYA;2!U<&]R86)N:6MO=B!N:2!M;V=OQ(TN(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"FUS9VED("),:71E<F%T=7)E(@IM
M<V=S='(@(DQI=&5R871U<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU
M86YI82(*;7-G<W1R("),:71V82`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I;6%G97,N<&AP.C<W"FUS9VED("),;V%D:6YG+BXN(@IM<V=S
M='(@(DYA;&%G86TN+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C`U"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B3&]K86QN:2#$
MC6%S.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-@IM<V=I9"`B3&]C
M86QE(&%N9"!4:6UE(@IM<V=S='(@(DQO:V%L:7IA8VEJ82(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<R(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HV,@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HW-PIM<V=I9"`B3&]C871I;VXB"FUS9W-T
M<B`B365S=&\B"@HC.B!L;V=I;BYP:'`Z,3@X('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HR,#0@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC
M.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C@R"FUS9VED("),;V<@:6XB"FUS9W-T<B`B4')I:F%V
M82(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B
M3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R(")/9&IA=F$@
M<R!P<F5D:&]D;F4@<WEN8R!S96IE("(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HQ.3@*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B3V1J879A
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q"FUS9VED("),;V=I;B(*
M;7-G<W1R(")0<FEJ879A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M,`IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B4')I:F%V82!N82!O<')A
M=FEL82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY-0IM<V=I9"`B
M3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R
M9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B4')I:F%V82!N
M:2!U<W!E;&$N(%5P;W)A8FYIQ:%K;R!I;64@86QI(&=E<VQO(&YE<')A=FEL
M;F\@=FYEQ:%E;F\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3$*
M;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B4')I:F%V82!N:2!U<W!E
M;&$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<X"FUS9VED("),
M;VYG('1E>'0B"FUS9W-T<B`B1&]L9V\@0F5S961I;&\B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(DQO=F4B"FUS9W-T<B`B3&IU8F5Z
M96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M.0IM<V=I9"`B3&]W(@IM<V=S='(@(DYI>F5K(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS
M9VED("),=7AE;6)O=7)G(@IM<V=S='(@(DQU:W-E;6)U<F<B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#,@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(DU-(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Y-PIM<V=I9"`B34]41"(*;7-G<W1R
M(")3<&]R;\2-:6QO(&1N979A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T86-H;65N="!C
M;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B35,M5$Y%1B!0<FEP;VYK82!N
M:2!V<V5B;W9A;&$@<&]D871K;W8N(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I
M9"`B35-'(@IM<V=S='(@(DU31R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C
M86\B"FUS9W-T<B`B36%C874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D
M;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R
M(")-86ME9&]N:6IA+"!F;W)M86QN82!*=6=O<VQO=F%N<VMA(')E<'5B;&EK
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R(")-
M861A9V%S:V%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"FUS9VED
M(")-86=I8R(*;7-G<W1R("+$C6%R;V)E;B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HY,`IM<V=I9"`B36%I;"(*;7-G<W1R(")%;&5K=')O;G-K
M:2!N87-L;W8B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-30V"FUS
M9VED(")-86EL($%D;6EN(@IM<V=S='(@(D%D;6EN:7-T<F%T;W(@<&_%H71E
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QA=VDB"FUS9W-T<B`B36%L879I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R(")-86QE
M>FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B
M36%L9&EV:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%L:2(*;7-G<W1R(")-
M86QI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QT82(*;7-G<W1R(")-86QT
M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-`IM<V=I9"`B(@HB36%N
M86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@
M:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO
M<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@HB57)E9&ET92!S97IN86T@:V%T
M96=O<FEJ(',@:V%T97)I;6D@8F]S=&4@;WIN8<2-:6QI('!O<W1A=FME(&EN
M('!R:7!A9&%J;\2-92`B"B)B87)V92!Z82!T92!K871E9V]R:6IE+B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,34V"FUS
M9VED(")-87`R-"!M87`B"FUS9W-T<B`B6F5M;&IE=FED($UA<#(T(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#<*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-S$*;7-G
M:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R("):96UL:F5V:60@36%P47)E<W0B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA
M<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B4VAR86YJ96YE('!O=F5Z879E(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G
M:60@(DUA<F-H(@IM<V=S='(@(DUA<F5C(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#@*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N
M<V5E;B!F;&%G<R(*;7-G<W1R(")/>FYAQ(UI('H@>F%S=&%V:6-A;6D@5FED
M96YO+TYE=FED96YO(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M-#,Q-"YP:'`Z-#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!)
M;7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(D]Z;F'$C6D@>B!O<W1A;&EM
M:2!Z87-T879I8V%M:2AN<'(N(%!O;65M8FYO+T]D9V]V;W)J96YO*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R(")-
M87)S:&%L;&]V;R!O=&_$C6IE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T
M:6YI<75E(@IM<V=S='(@(DUA<G1I;FEQ=64B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S
M='(@(E5J96UA;FIE('!O;&HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA=7)I
M=&%N:6$B"FUS9W-T<B`B36%V<F5T86YI:F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G
M:60@(DUA=7)I=&EU<R(*;7-G<W1R(")-879R:6-I=7,B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@
M(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B3F5J=F7$C2!D;W9O;&IE
M;FD@>FYE<V5K(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E
M961E9"XB"FUS9W-T<B`B36%K<VEM86QN:2!D96QI('-P;W)OQ(UI;&$@<')E
M:V]R8<2-96YI+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$X"FUS9VED
M(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B36%K<VEM86QN
M82!T96UP97)A='5R82!Z861N:FEH(#(T('5R.B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S$P"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*
M;7-G<W1R(")-86MS:6UA;&YA('1E;7!E<F%T=7)A('IA9&YJ:6@@-B!U<CHB
M"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@
M4&]R=&%L($)L;V-K<R(*;7-G<W1R(")-86MS:6UA;&YO(,6A=&5V:6QO(&)L
M;VMO=B!P;W)T86QA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3`W
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,C8*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(T.`IM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T
M<B`B36%K<VEM86QN82!D;VS%OFEN82(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")-87DB"FUS9W-T<B`B36%J
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R(")-87EO
M='1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")-961I
M8VEN92(*;7-G<W1R("):9')A=FEL;R`H365D:6-I;F$I(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*
M;7-G<W1R("+$C6QA;FDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@R
M"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(E1I<"!M96YI:F$Z(@H*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B4W!O<F_$C6EL;R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-
M97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S
M(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T
M<B`B(@HB4W!O<F_$C6EL;R!J92!B:6QO('5S<&7%H6YO('!R979E<FIE;F\L
M('1O9&$@<&]D<&ES;FEK;W9E9V$@<&]T<F1I;&$@;FD@8FEL;R`B"B)M;V=O
MQ(UE('!R979E<FET:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB
M"FUS9W-T<B`B4W!O<F_$C6EL;R!J92!P;W1E:VQO+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-C`*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")4:7`@4W!O<F_$C6EL
M82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A
M=&AE<B(*;7-G<W1R(")-971A<B!V<F5M92(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z-#(*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(DUE=&%R(&)L;VL@;FD@;F$@<F%Z<&]L86=O+B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3(T"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@
M879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R(")0;V1R;V)N;W-T:2!S;R!B:6QE('!R
M:6IA=FQJ96YE('IA('5P<F%V;&IA;&-A+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-3@*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE
M8W1E9"XB"FUS9W-T<B`B365T87)$0B!N:2!P;W9E>F%N+B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S
M='(@(E!O<W1O<&5K(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H
M<#HX,2!F<F%M97=O<FLO4E!#+U)00R]P:'!G=RYP:'`Z.#@*(SH@9G)A;65W
M;W)K+U)00R]24$,O<&AP9W<N<&AP.C@Y(&9R86UE=V]R:R]24$,O4E!#+W-O
M87`N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB
M(&ES(&YO="!D969I;F5D(@IM<V=S='(@(B<E<R<@<&]S=&]P96L@;FD@9&]L
M;\2-96XN(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@
M;65T:&]D.B`E<R(*;7-G<W1R(")0;W-T;W!E:R!N:2!D;VQOQ(UE;BX@4&]S
M=&]P96L@8V5L:6-E.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HW,B!L:6(O0FQO8VLO;65T87(N<&AP.C@W"FUS9VED(")-971R:6,B
M"FUS9W-T<B`B365T<FG$C6YI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-97AI
M8V\B"FUS9W-T<B`B365H:6MA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O
M;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B36EK<F]N97II
M:F$L($9E9&5R871I=FYA(&1RQ;YA=F$B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S
M='(@(E1I<"!D871O=&5K92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(R
M"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B36EN
M:6UA;&YA('1E;7!E<F%T=7)A('IA9&YJ:6@@,C0@=7(Z(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS,30*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R
M<SH@(@IM<V=S='(@(DUI;FEM86QN82!T96UP97)A='5R82!Z861N:FEH(#8@
M=7(Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,S@*;7-G
M:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B
M"FUS9W-T<B`B36EN:6UA;&YA('-T87)O<W0@9V5S;&$@Q:%E(&YI('!O=&5K
M;&$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C,U"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B3V=L961A;&\B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS
M9W-T<B`B36YO9V]S=')A;G-K82(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2
M('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R(")0;V=R9<6A86X@4$5!
M4B!P86ME="P@2%144"!Z86AT979A;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3$T"B,L(&9U>GIY"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R
M871I;VXN(%EO=2!M=7-T(&=E;F5R871E(&ET(&)E9F]R92!U<VEN9R!T:&ES
M(&%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"B)0;V=R9<6A86YA(&MO;F9I9W5R
M86-I:F$N(,2-92#%OF5L:71E('5P;W)A8FQJ871I('1O(&%P;&EK86-I:F\L
M(&UO<F%T92`B"B)G96YE<FER871I(&MO;F9I9W5R86-I:F\N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS
M9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(E!O9W)EQ:%A;F\@
M240@<W!O<F_$C6EL;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E
M9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B4&]G<F7%H6%N;R!S<&]R
M;\2-:6QO(&\@>F%H=&5V86YE;2!014%2('!A:V5T=2XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@
M(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B4&]G<F7%H6%N82!)1"!S
M96IA+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-3@*;7-G:60@(DUO(@IM<V=S='(@(E!O(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C<V"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R(")-
M;V)I;&YA('!OQ:%T82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<P"FUS9VED(")-;V1E<F%T92(*;7-G<W1R("):;65R;F\B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B36]D:69I
M960@1&%T92(*;7-G<W1R(")$871U;2!S<')E;65M8F4B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-`IM<V=I9"`B36]D=6QU<R(*
M;7-G<W1R(")-;V1U;&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUO;&1A=FEJ82P@<F5P=6)L:6MA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B36]N86MO(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R(")-;VYG;VQI
M:F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#<R"FUS9VED(")-
M;VYT:"!A;F0@>65A<B(*;7-G<W1R(")-97-E8R!I;B!L971O(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B
M36]N=&AL>2(*;7-G<W1R(")-97-EQ(UN;R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I
M9"`B36]N='-E<G)A="(*;7-G<W1R(")-;VYT<V5R<F%T(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-
M;V]N(%!H87-E<R(*;7-G<W1R("),=6YI;F4@;65N92(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C$Y-B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HR.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U
M;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B
M5B!V<G-T:2`E9"!J92!N86ID96YI:"!V9<2-('!O;&H@;V0@<')E9'9I9&5N
M:6@@)60N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@
M(DUA<F]K;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B4')E=&7%OFYO
M(&IA<VYO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B4')E=&7%OFYO
M(&]B;&'$C6YO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!#;&]U9'D@86YD(%=I;F1Y(@IM<V=S
M='(@(E!R971EQ;YN;R!O8FQAQ(UN;R!I;B!V971R;W9N;R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")-;W-T
M;'D@4W5N;GDB"FUS9W-T<B`B4')E=&7%OFYO('-O;L2-;F\B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T.`IM<V=I
M9"`B36]V92!$;W=N(@IM<V=S='(@(E!O;6%K;FD@<V4@9&]L(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-3(*;7-G
M:60@(DUO=F4@3&5F="(*;7-G<W1R(")0;VUA:VYI('-E('8@;&5V;R(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4V
M"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(E!O;6%K;FD@<V4@=B!D97-N
M;R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP
M:'`Z-C0T"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(E!O;6%K;FD@<V4@9V]R
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4S
M,`IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(E!O;6%K;FD@<V4@9&]L(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R.0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3,P"FUS
M9VED(")-;W9E('5P(@IM<V=S='(@(E!O;6%K;FD@<V4@9V]R(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(DUO>F%M8FEK(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0W,@IM<V=I9"`B375L=&DM
M;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(E9EQ(T@;FEV;VIN:2!P
M861A:F_$C6D@<W!I<VMI(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$P-3D*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G
M<W1R(")-=6QT:6UA<"!52R!Z96UL:F5V:60N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C4S,`IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM
M<V=S='(@(DUN;V=O:W)A=&5N(&EZ8F]R(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0R,PIM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R(")-;VH@
M<F'$C75N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED(")-
M>2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(E!O9&%T:VD@;6]J96=A
M(')AQ(UU;F$B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C8T"FUS
M9VED(")->2!0;W)T86PB"FUS9W-T<B`B36]J('!O<G1A;"(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]E9&ET+G!H<#HS-`IM<V=I9"`B37D@4&]R=&%L($QA>6]U
M="(*;7-G<W1R(")/8FQI:V$@;6]J92!P<G9E('-T<F%N:2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R(")-:F%N;6%R(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@
M(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R(").92P@<V4@;F4@<W1R:6YJ
M86TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M
M92(*;7-G<W1R("));64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B
M"FUS9W-T<B`B3F%M:6)I:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U
M(@IM<V=S='(@(DYA=7)U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*
M;7-G<W1R(").97!A;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N
M9',B"FUS9W-T<B`B3FEZ;WIE;7-K82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(").
M971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R(").:7IO>F5M<VMI($%N=&EL
M:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS
M9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R(").971S8V%P92!O<VYO
M=FYI(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@T"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*;7-G<W1R
M("(@3F5T<V-A<&4@0T$@55),('IA('!R96ML:6,B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@0T$@
M<&]L:6-Y(%523"(*;7-G<W1R(").87-L;W8@3F5T<V-A<&4@8V5R=&EF:6MA
M=&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-0IM
M<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B($YE='-C87!E
M(&]B;F]V:71V96YI(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*
M;7-G<W1R("(@3F5T<V-A<&4@55),('IA('!R96ML:6,B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@
M4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(DYE='-C87!E(%-33"!I;64@<W1R
M9<6^;FEK82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@X"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S
M='(@(DYE='-C87!E('5R861N:2!K;VUE;G1A<B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!C97)T
M:69I8V%T92!T>7!E(@IM<V=S='(@(E1I<"!.971S8V%P92!C97)T:69I:V%T
M82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C<*;7-G:60@(DYE
M='=O<FLB"FUS9W-T<B`B3VUR9<6^:F4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,C4@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC
M.CDW"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,Y,`IM<V=I9"`B3F5V97(B"FUS9W-T<B`B3FEK;VQI(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDU"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(DYO
M=F$@2V%L961O;FEJ82(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E
M9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T
M<B`B3F]V82!K871E9V]R:6IA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V
M(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T
M"FUS9VED(").97<@36]O;B(*;7-G<W1R(").;W9A($QU;F$B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,V"FUS9VED(").97<@57-E
M<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R(").;W9O('5P;W)A8FYIQ:%K;R!I
M;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@
M(DYO=F$@6F5L86YD:6IA(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C,W"FUS9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`B3F]V;R!G97-L
M;R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HR-#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X
M+B(*;7-G<W1R(").;W9O(&=E<VQO(&)O('!O=&5K;&\@)7@N(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED(").97<@<&%S<W=O
M<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R(").;W9O(&=E<VQO('-E(&YE('5J
M96UA+B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU-PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`U
M"FUS9VED(").97=S(@IM<V=S='(@(DYO=FEC92(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS,C$*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B
M3F]V:<2-87)S:V$@<VMU<&EN82(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN
M9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@(DYA<VQE9&YJ:2(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H87-E
M<R(*;7-G<W1R(").87-L961N:F4@-"!S=&]P;FIE(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HS-C(@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HS-C8*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R(").87-L
M961N:F$@;6_%OFYO<W0B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP
M.C$P,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B3F%S;&5D;FII/B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(DYI:V%R86=V82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B3FEG97(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B3FEG97)I:F$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S<R"FUS9VED(").
M:6=H="(*;7-G<W1R(").:6=E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3FEU
M92(*;7-G<W1R(").:75E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDV-@IM<V=I9"`B3F\B"FUS9W-T<B`B3F]B961E;B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B
M3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E
M<F5N8V5S(&9O<BXB"FUS9W-T<B`B3FD@9&]S=&]P;FEH('!O9&%T:V]V(&\@
M:V]N9FEG=7)A8VEJ:2!D82!B:2!P;VMA>F%L(')A>FQI:V4N(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,#8*;7-G:60@
M(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N
M(@IM<V=S='(@(E-T<F%T96=I:F$@>F$@:7ID96QA=F\@25-/('-L:6LL(&YI
M(&1O<W1O<&YA+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM
M<V=S='(@(DYI('!A:V5T;F4@<')E9&QO9V4B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P,0HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C,X-0HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0P-PIM<V=I9"`B
M3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS
M9W-T<B`B3F$@Q;YE;&5N96T@;65S="!B96QEQ;YK82!N92!O8G-T86IA+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-C<*;7-G:60@(DYO
M(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(EIA($U#04P@;W9E<FET978@;FD@:V]L961A<G-K96=A
M(&EM96YA(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO
M(&-H86YG92XB"FUS9W-T<B`B;FD@<W!R96UE;FIE;F\B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@
M8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B3F$@
M=&5J('-T;W!N:FD@;F4@9&]D86IA;6\@;W1R;\6A:VEH(&1O=F]L:F5N:BXB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W."!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C4Q,PHC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H
M<#HW.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R("):82`E<R!N
M:2!S<&5C:69I8VER86YI:"!K;VYF:6=U<F%C:6IS:VEH(&EN9F]R;6%C:6HN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-#8*;7-G:60@(DYO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@
M5D93+B(*;7-G<W1R("):82!&5%`@5D93(&YI('!O<V5B;FEH(&EN9F]R;6%C
M:6HN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HW,3`*;7-G:60@
M(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44P@5D93+B(*;7-G<W1R("(@6F$@4U%,(%9&4R!N:2!P;W-E8FYI:"!I;F9O
M<FUA8VEJ+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW
M-S4*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(B!:82!D871O=&5K;RU3
M44P@5D93(&YI('!O<V5B;FEH(&EN9F]R;6%C:6HN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W-H,BYP:'`Z.#<P"B,L(&9U>GIY"FUS9VED(").;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U-(,B!61E,N
M(@IM<V=S='(@(B!:82!344P@5D93(&YI('!O<V5B;FEH(&EN9F]R;6%C:6HN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B3FD@<W1A
M;FIA(&YA(')AQ(UU;G4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U
M<'!L:65D+B(*;7-G<W1R(").:2!D97-T:6YA8VEJ92(*"B,Z(&9R86UE=V]R
M:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDR-0IM<V=I9"`B3F\@9FEL92!U<&QO
M861E9"(*;7-G<W1R(").:2!N86QOQ;YE;FEH(&1A=&]T96LN(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB
M"FUS9W-T<B`B3F4@;F%J9&5M(&EK;VXN(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$R,2!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,S4*;7-G:60@(DYO(&QO8V%T:6]N(&ES
M('-E="XB"FUS9W-T<B`B365S=&\@;FD@;F%S=&%V;&IE;F\N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,@IM<V=I9"`B3F\@;&]C871I
M;VX@<')O=FED960N(@IM<V=S='(@(DUE<W1O(&YI(&YA<W1A=FQJ96YO+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R(").;V)E
M;F\@<W!O<F_$C6EL;R!D;W-T879L:F5N;RXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M
M92!S<&5C:69I960N(@IM<V=S='(@(DYI('-P96-I9FEC:7)A;F\@;F]B96YO
M(&EM92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T
M<B`B3FD@<W!E8VEF:6-I<F%N;R!N;V)E;F\@Q:%T979I;&\N(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(").;R!O9F9E;G-I=F4@9F]R
M='5N97,B"FUS9W-T<B`B3F]B96YI:"!O9F5N>FEV;FEH('-R9<2-+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-PIM<V=I9"`B
M(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H
M92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H
M(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@HB4&]T(&1O(&)I;F%R;F4@9&%T
M;W1E:V4@3W!E;E-33"!N:2!B:6QA(&YA<W1A=FQJ96YA+B!/<&5N4U-,(&)I
M;F%R;F$@(@HB9&%T;W1E:V$@:F4@<&]T<F5B;F$@>F$@9&5L;R!S(%!+0U,@
M,3(@<&]D871K:2XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@(DYE
M('-P<F5J96UA;6\@>F'$C6%S;FEH('!R:6IA=B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HX,3@*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B
M2W9O=&$@;FD@;F%S=&%V;&IE;F$O9&]L;\2-96YA+B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C0X,@IM<V=I9"`B3F\@<V5P87)A=&]R('-P
M96-I9FEE9"XB"FUS9W-T<B`B3FD@<W!E8VEF:6-I<F%N;R!L;\2-:6QO+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3<V"FUS9VED(").;R!S
M=6-H(&9I;&4B"FUS9W-T<B`B3FD@=&%K92!D871O=&5K92(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,S$*;7-G:60@(DYO('1E;7!O<F%R
M>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B3F4@
M;F%J9&5M('IAQ(UA<VYE(&UA<&4@>F$@<')E9'!O;6YI;&YI:RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,0IM<V=I
M9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@
M(DYO8F5N;R!U<&]R86)N:<6A:V\@:6UE(&EN+V%L:2!G97-L;R!N:2!B:6QO
M('!O<VQA;F\N(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ
M-#`@9G)A;65W;W)K+U)00R]24$,O<&AP9W<N<&AP.C$W-0IM<V=I9"`B3F\@
M=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B4&]V<F%T;FEH('9E
M;&IA=FYI:"!834P@<&]D871K;W8@;FDB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3<T"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.CDY-0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3`Q,@IM<V=I9"`B3F\@=F%L=65S(@IM<V=S
M='(@(D)R97H@=G)E9&YO<W1I(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$Q.0IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF
M:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(B(*(E8@;W)I9VEN86QN:2!K;VYF:6=U<F%C:6II(&YE(&YA:F1E;2!N;V)E
M;F4@<F%Z;&G$C6EC92X@3V)N;W9I=&D@(@HB:V]N9FEG=7)A8VEJ;RXB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(W"FUS9VED(").;R!V97)S:6]N
M(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("(B"B)6('9AQ:%I(&MO;F9I9W5R86-I:FD@
M;F4@;F%J9&5M(&YO8F5N92!R87IL:<2-:6-E+B!/8FYO=FET92!K;VYF:6=U
M<F%C:6IO+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R
M-R!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDU"FUS9VED
M(").;VYE(@IM<V=S='(@(DYO8F5D96XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y,@IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B
M3F]R9&EJ<VMI("A)4T\M.#@U.2TQ,"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B
M3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B3F]R9F]LQ:%K:2!O=&]K:2(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*
M;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B4V5V97)N82!P
M;VQO8FQA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA
M($ES;&%N9',B"FUS9W-T<B`B4V5V97)N:2!-87)I86YS:VD@;W1O:VDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R(").;W)V9<6A:V$B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,0IM<V=I
M9"`B3F]T($%F=&5R(@IM<V=S='(@(DYE(&MA<VYE:F4B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($)E9F]R
M92(*;7-G<W1R(").92!P<F5J(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z-#0W"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B3FD@
M:6UE;FEK(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX-`HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-0HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I
M;7!L96UE;G1E9"XB"FUS9W-T<B`B3FD@:7IV961E;F\N(@H*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#4*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ
M-C`*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R
M+G!H<#HQ-S4*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(
M86YD;&5R+G!H<#HQ.#D*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E
M<W-I;VY(86YD;&5R+G!H<#HR,S8@9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y
M,PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`X(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HR,S0*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(U,B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,C8Y"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HS-C@@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,X-0HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z-#$X(&9R86UE=V]R:R]61E,O5D93+G!H<#HT-S@*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C4U-R!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z-C(V"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HV-#,@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C<R,0HC.B!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP
M:'`Z.#(@9G)A;65W;W)K+U9&4R]61E,O:&]R9&4N<&AP.C$S,0HC.B!F<F%M
M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z,34Q(&9R86UE=V]R:R]61E,O5D93
M+VAO<F1E+G!H<#HQ-S`*(SH@9G)A;65W;W)K+U9&4R]61E,O:&]R9&4N<&AP
M.C$X.2!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z,C`W"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VAO<F1E+G!H<#HR,C<@9G)A;65W;W)K+U9&4R]61E,O
M:&]R9&4N<&AP.C,S,`IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B
M3F4@<&]D<&ER86TB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP
M."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T"B,Z
M(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,3(R(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ.#<*;7-G:60@(DYO=&5S(@IM<V=S='(@(EIA<&ES:VDB"@HC
M.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI
M;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R(").:2!V<&ES86YI:"!B
M97-E9"!Z82!I<VMA;FIE+"!V<FYI=&4@<V4@;F%Z86HN(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4T"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S<*;7-G:60@(DYO=F5M
M8F5R(@IM<V=S='(@(DYO=F5M8F5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3`U-0IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(L6@=&5V:6QO(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30S.`IM<V=I9"`B3G5M8F5R
M(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`BQ:!T979I;&\@>FYA:V]V(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,X,B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-#,V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-3@*
M;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(L6@=&5V:6QO('-T
M;VQP8V5V(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,X,"!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#,T"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T-38*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(L6@
M=&5V:6QO('9R<W1I8R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I
M960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R
M(").:2!S<&5C:69I8VER86YI:"#%H71E=FEL:R!Z82!AQ;YU<FER86YJ92!I
M;B!D:7-T<FEB=6-I:G-K:2!S97IN86TN(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S
M='(@(EIA9&5V82(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q
M"FUS9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R(")5<W1V87)J86QE8R!P
M<F5D;65T;W8B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$S"FUS
M9VED(")/8W1A;"(*;7-G<W1R(")/<VUIQ:%K:2(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,34*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")/8W1O8F5R(@IM
M<V=S='(@(D]K=&]B97(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3<*
M;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-#(*;7-G:60@(D]F9FEC92(*;7-G<W1R(")0
M:7-A<FYA(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS
M9VED(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N
M(@IM<V=S='(@(E-T87)O(&EN(&YO=F\@9V5S;&\@;6]R871A(&)I=&D@<F%Z
M;&G$C6YA+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@IM
M<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(E-T87)O($=E<VQO(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@<&%S
M<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@(E-T87)O(&=E<VQO(&YI
M('!R879I;&YO+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R
M(")/;6%N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D
M(&9O;&1E<G,N(@IM<V=S='(@(DUA<&4@=B!S:W5P;FD@=7!O<F%B:2!P;V1P
M:7)A('-A;6\@24U!4"!S=')EQ;YN:6LN(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C$P,`IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS
M9W-T<B`B4V%M;R!N97-R86UN92!I>FIA=F4B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C4Y"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S
M(&%L;&]W960N(@IM<V=S='(@(D1O=F]L:F5N(&IE(&QE(&5N(&5L96MT<F]N
M<VMI(&YA<VQO=BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8W
M"B,L(&9U>GIY"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&ES(&%L
M;&]W960N(@IM<V=S='(@(D1O=F]L:F5N(&IE(&QE(&5N(&5L96MT<F]N<VMI
M(&YA<VQO=BXB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-S`*;7-G
M:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R
M(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS
M(&9O<B!A('-H87)E(@IM<V=S='(@(B(*(DQE(&QA<W1N:6L@86QI('5P<F%V
M;FEK('-I<W1E;6$@;&%H:V\@>F%M96YJ82!L87-T;FG%H71V;R!A;&D@;&%S
M=&YI:V]V;R`B"B)D;W9O;&IE;FIE('IA(&1E;&7%OBXB"@HC.B!L:6(O0FQO
M8VLO:69R86UE+G!H<#HS-@IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B
M"FUS9W-T<B`B3V1P<FD@=B!N;W9E;2!O:VYU(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z
M($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A
M<G0N(@IM<V=S='(@(D]D<')T85-33"!N87!A:V$Z($YE(&UO<F5M('!O=GIE
M=&D@9&%T=6UA(&EZ(&]Z;F'$C65N96=A(%,O34E-(&1E;&$N(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")/<&5R871I;F<@4WES=&5M
M(@IM<V=S='(@(D]P97)A=&EV;FD@<VES=&5M(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-I9&5B87(N<&AP.C$U-0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")-
M;\6^;F]S=&DB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S(@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N
M<R!F;W(@)7,B"FUS9W-T<B`B36_%OFYO<W1I('IA("5S(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A
M=&EO;B(*;7-G<W1R(")/<F=A;FEZ86-I:F$B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B3W)G86YI<V%T:6]N86P@
M56YI="(*;7-G<W1R(")/<F=A;FEZ86-I:G-K82!E;F]T82(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ-#$*;7-G:60@(D]R9V%N:7II;F<B"FUS
M9W-T<B`B3W)G86YI>F%C:6IA(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M,S0*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S
M='(@(DEZ=FER;F4@Q:%A8FQO;F4@87!L:6MA8VEJ(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@
M=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R("))>G9I<FYI(,6A86)L;VYE('8@
M)7,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!S97)V
M:6-E<R]K97EB;V%R9"YP:'`Z,3$W"FUS9VED(")/=&AE<B(*;7-G<W1R(")$
M<G5G;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3`Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,38@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-0HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#0*;7-G:60@(D]T
M:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D]S=&%L92!I;F9O<FUA8VEJ92(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(D1O=F]L:F5N:F$@;&%S=&YI:V$B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z.#`*;7-G:60@(E!!32!A
M=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")/=F5R
M:F5N:F4@;FD@=7-P96QO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E
M;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B
M"FUS9W-T<B`B4$5!4CHZ(&=O;FEL;FEK(%!OQ:%T92(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R-S8*;7-G:60@(E!'4"!$:6=I=&%L
M(%-I9VYA='5R92(*;7-G<W1R(")$:6=I=&%L96X@<&]D<&ES(%!'4"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,C(*;7-G:60@(E!'
M4"!%;F-R>7!T960@1&%T82(*;7-G<W1R(")+;V1I<F%N:2!01U`@<&]D871K
M:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-S0*;7-G
M:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(DIA=FYI(&ML:G5E(%!'4"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-38*;7-G:60@
M(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B4&]D<&ES86YI
M+VMO9&ER86YI(%!'4"!P;V1A=&MI(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP
M.C8W"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")02%`@:V]D82(*"B,Z(&%D
M;6EN+W!H<'-H96QL+G!H<#HQ.`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@
M(E!(4"!L=7!I;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS.`IM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R(")0;W!O
M;&1N92!R86AE;"!D9<6^(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%)A:6XB"FUS9W-T<B`B4&]P;VQD
M;F4@9&7%OB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0P"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(E!O<&]L9&YE(&YA
M;&EV:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0Q"FUS9VED(")032!3;F]W(@IM<V=S='(@(E!O<&]L9&YE('-N96<N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G
M:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")0;W!O;&1N92!S;F7%OFYI
M(&UE=&7%OFDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT,PIM<V=I9"`B4$T@4W5N(@IM<V=S='(@(E!O<&]L9&YE('-O;F-E
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*
M;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(E!O<&]L9&YE(&YE=FEH=&4B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@V"FUS9VED(")03U-)6"!E
M>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R(")0;V=R9<6A86YA(%!/4TE8
M(&5K<W1E;GII:F$B"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@
M4VAE;&PB"FUS9W-T<B`B4$A0(&QU<&EN82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I
M9"`B4&%K:7-T86XB"FUS9W-T<B`B4&%K:7-T86XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q
M"FUS9VED(")086QA=2(*;7-G<W1R(")086QA=2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*
M;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T
M<B`B4&%L97-T:6YK:2!O:W5P:7)A;FD@=&5R:71O<FEJ(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDX"FUS9VED(")086YA;6$B"FUS9W-T<B`B4&%N86UA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(E!A<'5A($YO
M=F$@1W9I;F5J82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM
M<V=S='(@(E!A<F%G=F%J(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S<*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B
M1&5L;F\@;V)L8<2-;F\B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S`V"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-CD@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT-`HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#0V"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")'97-L
M;R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B
M4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(D=E<VQO
M('5S<&7%H6YO('-P<F5M96YJ96YO(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HQ,S(S"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B
M"FUS9W-T<B`B3F5P<F%V:6QN;R!G97-L;R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<F%D:75S+G!H<#HQ-3<*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D
M(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(EIA(%)!1$E5
M4R!O=F5R:71E=B!J92!Z86AT979A;F\@9V5S;&\N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,T,0IM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF
M:7)M871I;VXB"FUS9W-T<B`B1V5S;&\@:6X@<&]T<F1I=&5V(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED(")087-S=V]R9#HB
M"FUS9W-T<B`B1V5S;&\Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI
M;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B1V5S;&\Z("(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$T.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S(R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G
M:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")'97-L;R!S92!M
M;W)A('5J96UA=&DN(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q.`IM<V=I
M9"`B4&%S=&4B"FUS9W-T<B`B4')I;&5P:2(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S
M='(@(DYE<&]T<FIE;F4@<')I:F%V92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU.0IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(DQJ=61J92(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED
M(")097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B27IV
M<L6A:2!V>F1RQ;YE=F%L;F$@9&5L82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT,3`*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<R!O;B!L;V=I;C\B"FUS9W-T<B`B27IV<L6A:6T@=GID<L6^979A;&YA(&1E
M;&$@;V(@<')I:F%V:3\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R(")$;W9O;&IE;FIE
M(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T
M<B`B7"(E<UPB(&1O=F]L:F5N:F4@;FD@:7IB<FES86YO+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-3<Y"FUS9VED(")097)M:7-S:6]N($1E
M;FEE9"(*;7-G<W1R(")$;W9O;&IE;FIE(&IE('IA=G)N:F5N;RXB"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T
M<B`B1&]V;VQJ96YJ82(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P."!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3D*(SH@861M:6XO<&5R;7,O:6YD
M97@N<&AP.C(Q(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3<*;7-G:60@(E!E
M<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E5P<F%V;FG%H6MA
M(&1O=F]L:F5N:F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@*;7-G
M:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(D]S96)N92!I;F9O
M<FUA8VEJ92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R(")0
M97)U(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")0971S
M(@IM<V=S='(@(DQJ=6)L:F5NQ(UK:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B
M4&AI;&EP<&EN97,B"FUS9W-T<B`B1FEL:7!I;FDB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*
M;7-G<W1R(")496QE9F]N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C4P,0IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(D9O=&]G<F%F:6IE(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B4&ET8V%I<FXB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E!L871I='5D
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@U
M,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS
M9W-T<B`B4')O<VEM;RP@9&$@=FYE<V5T92!M97-E8R!I;B!L971O+B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS
M9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y
M.B(*;7-G<W1R(")0<F]S:6UO+"!D82!V;F5S971E(&EM92!N;W9E(&MA=&5G
M;W)I:F4Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q,`IM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B
M4')O<VEM;RP@9&$@=FYE<V5T92!V96QJ879E;B!)4"!N87-L;W8N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR.`IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN
M('1H92!M;VYT:"XB"FUS9W-T<B`B4')O<VEM;RP@9&$@=FYE<V5T92!V96QJ
M879E;B!D871U;3H@<')E=F5R:71E(,6A=&5V:6QO(&1N:2!V(&UE<V5C=2XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-S,U"FUS9VED(")0;&5A
M<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R(")0<F]S:6UO+"!D82!V
M;F5S971E('!R879I;&5N(,2-87,N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y
M(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R(")0<F]S:6UO+"!D82!P<FEP<F%V
M:71E('!O=GIE=&5K('1EQ;YA=BXB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@
M(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM
M<V=S='(@(E!R;W-I;6\L(&1A('-I(&EZ8F5R971E('5P;W)A8FYIQ:%K;R!I
M;64@:6X@9V5S;&\N(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X
M"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO
M=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES
M=&5M+B(*;7-G<W1R("(B"B)0<F]S:6UO+"!P<F5B97)I=&4@<VQE9&7$C64@
M8F5S961I;&\N(,2-92#%OF5L:71E('5P;W)A8FQJ871I('1A('-I<W1E;2P@
M<V4@(@HB;6]R871E('-T<FEN:F%T:2!S('!O9V]J:2XB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B
M4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R(")0
M<F]S:6TL('9N97-I=&4@:6UE(&YO=F4@:V%T96=O<FEJ93HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R(")0;VQJ<VMA(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R
M(")0;VQI=&EK82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,3`*
M;7-G:60@(E!O;&QS(@IM<V=S='(@(D%N:V5T92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*
M;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(E!O<G1U9V%L<VMA(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3$*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@
M=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R
M(")/9&1A:B!V('1O(&UA<&\@*&YI('IA:'1E=F%N;R!O9"!)34%0*2(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C@S"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA
M<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(E!A9&%V:6YE('8@>F%D;FII:"`E
M<R!U<F%H.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3$*
M;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B4&%D
M879I;F4\8G(@+SYC:&%N8V4B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M;&1A<"YP:'`Z,3,Y"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B!0<F5F<U]L9&%P.B!Z
M86AT979A;F5G82!,1$%0(')A>G1E9V$@;F4@;F%J9&5M+B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C,W"FUS9VED(")0<F5S<W5R92(*;7-G<W1R(")4
M;&%K(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S$*;7-G:60@(E!R97-S
M=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@(E1L86L@;F$@;6]R<VMI('9I
MQ:%I;FDZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R.0IM
M<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R(")4;&%K.B`B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`S"FUS9VED(")0<F5V
M:65W(@IM<V=S='(@(E!R961O9VQE9"(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,S4R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,S4V"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(E!R96K%H6YJ
M92!M;\6^;F]S=&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(EIA<V5B96X@:VQJ
M=<2-(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0IM
M<V=I9"`B4')O8FQE;2(*;7-G<W1R(")0<F]B;&5M(@H*(SH@<V5R=FEC97,O
M<')O8FQE;2YP:'`Z,3(V"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM
M<V=S='(@(EH@;W!I<V]M('-O('1EQ;YA=F4N+B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS.#4*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(E!R
M;VIE:W1I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y.2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#<V"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,U-C,*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(E1A:V]J
MQ:%N:F4@8F5S961I;&\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B2F%V;FD@:VQJ
M=<2-(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#8*
M;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(D%L9V]R:71E
M;2!J879N96=A(&ML:G7$C6$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@
M(DEN9F]R;6%C:6IE(&IA=FYE9V$@:VQJ=<2-82(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@
M:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B
M2F%V;FDO>F%S96)N:2!P87(@:VQJ=<2-978@;FD@8FEL('5S<&7%H6YO(&=E
M;F5R:7)A;BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@4FEC;R(*
M;7-G<W1R(")0;W)T;W)I:V\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,T,S$T+G!H<#HU-0IM<V=I9"`B4'5R9V4@;65S<V%G97,B"FUS9W-T
M<B`B4')EQ(UI<W1I('-P;W)OQ(UI;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED
M(")1871A<B(*;7-G<W1R(")+871A<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HV,@IM<V=I9"`B475E<GDB"FUS9W-T<B`B4&]I>G9E9&)A(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C@P"FUS9VED(")1=6]T82(*;7-G<W1R(")+
M=F]T82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8T
M"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I
M(@IM<V=S='(@(E)302!J879N:2!K;&IUQ(T@*"5D(&)I=&]V*2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U-3(*;7-G:60@(E)A9&EO('-E;&5C
M=&EO;B(*;7-G<W1R("))>F)E<FET92!R861I;R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN(@IM<V=S
M='(@(D1EQ;XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT-@IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R(")$9<6^('IJ=71R
M86HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M-PIM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(D1EQ;X@<&]P;VQD;F4B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I
M9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B3F%L:78B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B4F%I;B!A;F0@
M4VYO=R(*;7-G<W1R(")$9<6^(&EN('-N96<B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4F%I;B!T;R!3;F]W
M(@IM<V=S='(@(D1EQ;X@=B!S;F5G(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(E-R9<2-82(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T
M:6\B"FUS9W-T<B`B4F%Z;65R:F4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R(")"97)I(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#<*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*;7-G:60@
M(E)E860@;65S<V%G97,B"FUS9W-T<B`B0F5R:2!S<&]R;\2-:6QO(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A
M;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(E-T92!P<F5P<FG$C6%N:2P@9&$@
MQ;YE;&ET92!Z8G)I<V%T:2`E<S\@27IB<FES82!N:2!M;V=OQ(UE('!R96ML
M:6-A=&DN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@
M9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N
M(@IM<V=S='(@(B(*(E-T92!P<F5P<FG$C6%N:2P@9&$@Q;YE;&ET92!Z8G)I
M<V%T:2!U<&]R86)N:6MO=F4@<&]D871K92!Z82!U<&]R86)N:6MA)7,_("(*
M(DEZ8G)I<V$@;FD@;6]G;\2-92!P<F5K;&EC871I+B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS
M9VED(")2969R97-H(@IM<V=S='(@(D]S=F7%OFDB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,SDU"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%
M;&5M96YT<SHB"FUS9W-T<B`B3W-V9<6^:2!D:6YA;6G$C6YI(&UE;FD@96QE
M;65N=&]V.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#4*;7-G:60@
M(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(D]S=F7%OFD@<&]R=&%L
M.B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY-`HC+"!F=7IZ
M>0IM<V=I9"`B4F5F<F5S:"!R871E.B(*;7-G<W1R(")/<W9EQ;YI('!O<G1A
M;#HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,#,@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(R,@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C0T"FUS9VED(")296=E>"(*;7-G<W1R(")296=E>"(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,U,3@*;7-G:60@(E)E;&%T:6]N<VAI<"!"
M<F]W<V5R(@IM<V=S='(@(DES:V%L;FEK(')A>FUE<FEJ(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(P.`IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(E!O;F]V;F\@;F%L
M;\6^:2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,X"FUS9VED(")296UA
M<FMS(@IM<V=S='(@(E!R:7!O;6)E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q-PIM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B3V1D86QJ
M96YI('-T<F7%OFYI:VDB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC
M;VTO:&]R9&4I.B(*;7-G<W1R(")/9&1A;&IE;B!54DP@*&AT='`Z+R]W=W<N
M97AA;7!L92YC;VTO:&]R9&4I.B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHX('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PIM<V=I9"`B
M4F5M;W9E(@IM<V=S='(@(D]D<W1R86YI(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4V,0IM<V=I9"`B4F5M;W9E(&-O;'5M
M;B(*;7-G<W1R(")/9'-T<F%N:2!S=&]L<&5C(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@
M(D]D<W1R86YI('!A<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#$*
M;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP
M;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(")/9'-T<F%N:2!S:')A;FIE;F\@
M<VMR:7!T;R!I>B!S=')EQ;YN:6MO=F4@>F'$C6%S;F4@;6%P92(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V
M92!U<V5R(@IM<V=S='(@(D]D<W1R86YI('5P;W)A8FYI:V$B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(D]D<W1R86YI('5P;W)A
M8FYI:V$Z("5S("(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z
M,3,X(&9R86UE=V]R:R]24$,O4E!#+W!H<&=W+G!H<#HQ-S,*;7-G:60@(E)E
M<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D
M93H@(@IM<V=S='(@(EIA:'1E=FD@;F4@;6]R96T@=6=O9&ET:2X@5G)N:F5N
M82!J92!N87!AQ(UN82!K;V1A.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,34P"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N
M;W0@8F4@9F]U;F0N(@IM<V=S='(@(DYE(&YA:F1E;2!Z86AT979A;F5G82!S
M97)V:7-A+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3@U(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3(S"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(EIA:'1E=F%N:2!<(B5S7"(@;FD@<&]D<F]B
M;F\@;V)L:6MO=F%N('8@)7,@:V]N9FEG=7)A8VEJ:2XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C<Q-B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C@U,@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<V@R+G!H<#HX-S8@9G)A
M;65W;W)K+U9&4R]61E,O:&]R9&4N<&AP.C0Q"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HW.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q
M=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(EIA:'1E=F%N:2!<(B5S7"(@;FD@<&]D<F]B;F\@;V)L
M:6MO=F%N('8@5DA3(&MO;F9I9W5R86-I:FDN(@H*(SH@9G)A;65W;W)K+U5T
M:6PO571I;"YP:'`Z-SDP"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D
M(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(EIA:'1E=F%N:2`G)7,G(&YI('!O9')O8FYO(&]B;&EK;W9A;BXB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S4*;7-G:60@
M(E)E<75I<F5D($9I96QD(@IM<V=S='(@(EIA:'1E=F%N82!D871O=&5K82(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,T.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C`*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,"!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S@*;7-G:60@(E)E<V5T(@IM<V=S='(@
M(E!O;F%S=&%V:2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V
M"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R(")0;VYA<W1A=FD@9V5S
M;&\B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B
M4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R(")0;VYA<W1A=FET92!V8<6A
M92!G97-L;R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,CD*;7-G:60@(E)E
M<W1O<F4@3&%S="!1=65R>2(*;7-G<W1R(")/8FYO=FET92!Z861N:F\@<&]I
M>G9E9&)O(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<P(&%D;6EN+V-M9'-H
M96QL+G!H<#HR-R!A9&UI;B]S<6QS:&5L;"YP:'`Z-C4*;7-G:60@(E)E<W5L
M=',B"FUS9W-T<B`B6F%D971K:2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B
M4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B5G)N:2!S92!N82!-;\6^;F]S
M=&DB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@
M(E)E='EP92!N97<@<&%S<W=O<F0B"FUS9W-T<B`B4&]N;W9N;R!V<&G%H6ET
M92!N;W9O(&=E<VQO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*
M;7-G<W1R(")0;VYO=FYO('ID<G7%OFDB"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E
M=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(E!O=G)N:2!K;VYF:6=U<F%C
M:6IO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-0IM<V=I9"`B4FEC
M:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(E9R;FD@<V4@;F$@;6_%
MOFYO<W1I('5R96IE=F%L;FEK82!B97-E9&EL82(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV,PIM<V=I9"`B4FED9&QE<R(*;7-G<W1R(")%;FEG;64B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SDP"FUS9VED(")2:6=H
M="!H96%D97(B"FUS9W-T<B`B1&5S;F\@;V=L879J92(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S.#8*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G
M<W1R(")$97-N92!V<F5D;F]S=&DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(D9U
M;FMC:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R
M(")2;VUU;FEJ82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,C8*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B3V)R;FD@
M>F$@,3@P(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(R,PIM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B3V)R;FD@;F$@
M;&5V;R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,CD*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R(")/8G)N:2!N82!D
M97-N;R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,3D*;7-G:60@(E)U;B(*
M;7-G<W1R("):8<6^96YI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA
M;B!&961E<F%T:6]N(@IM<V=S='(@(E)U<VEJ82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*
M;7-G:60@(E)W86YD82(*;7-G<W1R(")2=6%N9&$B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T
M;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(B!3+TU)344@:W)I<'1O9W)A
M9G-K:2!P;V1P:7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S
M='(@(E,O34E-12!K;V1I<F%N;R!S<&]R;\2-:6QO(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S87-L+G!H<#HX,@IM<V=I9"`B4T%33"!A=71H96YT:6-A
M=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")305-,($]V97)J86YJ
M92!N:2!U<W!E;&\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(X
M"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@(E--4R!S<&]R;\2-:6QO
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Y"FUS9VED(")344P@4VAE;&PB
M"FUS9W-T<B`B4U%,(&QU<&EN82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,U-C$*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU
M<',B"FUS9W-T<B`B4U%,('-T879E:R!Z82!P;VEZ=F5D8F\@=G)E9&YO<W1I
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U-`IM<V=I9"`B4U-(
M(@IM<V=S='(@(E-32"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%
M4U,B"FUS9W-T<B`B55-014@B"@HC.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@
M(E-?44P@4VAE;&PB"FUS9W-T<B`B4U%,(&QU<&EN82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C,*;7-G:60@(E-A(@IM
M<V=S='(@(E-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA
M(@IM<V=S='(@(E-V971A($AE;&5N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B
M4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(E-A:6YT($MI='1S(&%N
M9"!.979I<R`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM
M<V=S='(@(E-A:6YT($QU8VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I
M;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R(")386EN="!0:65R<F4@
M86YD($UI<75E;&]N("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I
M;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@(E-A:6YT(%9I;F-E
M;G0@:6X@1W)E;F%D:6YE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B
M"FUS9W-T<B`B4V%M;V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")386X@36%R
M:6YO(@IM<V=S='(@(E-A;B!-87)I;F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED
M(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B4V%O(%1O;64@:6X@
M4')I;F-I<&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y
M"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B4V%T96QI='-K
M:2!O<VMR8F]V86QE8R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R
M86)I82(*;7-G<W1R(")3875D<VMA($%R86)I:F$B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VQA>6]U="YI;F,Z,3$U"FUS9VED(")3879E(@IM<V=S='(@(E-H
M<F%N:2(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B4VAR
M86YI(%PB)7-<(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V
M"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B4VAR86YI
M("5S("(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A
M=F4@3W!T:6]N<R(*;7-G<W1R(")3:')A;FD@36_%OFYO<W1I(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$V-@IM<V=I9"`B(@HB4V%V92!G96YE<F%T
M960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V
M97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"B)3:')A
M;FET92!G96YE<FER86YO(&MO;F9I9W5R86-I:F\@:V]T(%!(4"!S:W)I<'1O
M(&YA('IAQ(UA<VYI(&UA<&D@(@HB=F'%H65G87-T<F7%OFYI:V%D:7)E8W1O
M<GDN(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M4VAR86YJ96YA("5S(&MO;F9I9W5R86-I:F$B"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HY.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U
M<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")3:')A;FIE
M;F$@;F%S=&%V:71V96YE('-K<FEP=&$@;F%D9W)A9&YJ92!N83H@7"(E<UPB
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q
M"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B4F%Z9&EV:F%N
M82!N979I:'1A('H@9W)M96YJ96TB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C0*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B6FYA;F]S="(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B2<6A
MQ(UI(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S-@IM<V=I9"`B
M4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B27-K86QN:6MI(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S(T,PIM<V=I9"`B4V5L96-T($9I;&5S(@IM
M<V=S='(@(DEZ8F5R:2!D871O=&5K;R(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT.#D*;7-G:60@(E-E;&5C="!A(&1A=&4B
M"FUS9W-T<B`B27IB97)I(&1A='5M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G
M<W1R("))>F)E<FD@<VMU<&EN;RP@:VD@:F\@Q;YE;&G%H2!D;V1A=&DN(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T
M(&$@;F5W(&]W;F5R(@IM<V=S='(@(DEZ8F5R:2!N;W9E9V$@;&%S=&YI:V$B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E
M;&5C="!A('-E<G9E<B(*;7-G<W1R("))>F)E<FD@<W1R9<6^;FEK(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A
M('5S97(@=&\@861D(@IM<V=S='(@(DEZ8F5R:2!U<&]R86)N:6MA+"!K:2!G
M82#%OF5L:<6A(&1O9&%T:2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HV-S@*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B
M27IB97)I('9S92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S$*
M;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R("))
M>F)E<FD@<&]P;VQN(&1A='5M(@H*(SH@<V5R=FEC97,O961I=&]R+WAI;FAA
M+W!L=6=I;G,O06YS96Q);6%G92]I;G-E<G1?:6UA9V4N<&AP.C$S,@HC+"!F
M=7IZ>0IM<V=I9"`B4V5L96-T(&%N(&EM86=E(@IM<V=S='(@(DEZ8F5R:2!D
M871U;2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HX-S,*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B27IB97)I
M('!R961M970B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<Y"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R(")/9&ML:G5K
M86H@=G-E(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B
M"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X
M97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M
M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@HB6FYA:V4L(&MI(&II
M:"!P;W1R96)U:F5T92!I>F)E<FET92!I>B!O:W9I<FIE=B!S<&]D86HN($YA
M=&\@:FEH(&QA:&MO("(*(FMO<&ER871E(&EN('!R:6QE<&ET92!V+VEZ(&)E
M<V5D:6QA+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED
M(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R(")$;VQOQ(UI
M(&MO;L2-;FD@9&%T=6TZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(DEZ
M8F5R:2!O8FQI:V\@9&%T=6UA.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N
M=&ET>7-E;&5C="YI;F,Z.3(*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@
M>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R("))>F)E<FET92!I9&5N=&ET
M971O+"!K871E<F\@Q;YE;&ET92!S<')E;65N:71I.B(*"B,Z('1E;7!L871E
M<R]D871A+W1I;64N:6YC.C$V"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L
M:6UI=&5R.B(*;7-G<W1R(")$;VQOQ(UI(&MO;L2-;F\@=7)O.B(*"B,Z('1E
M;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I
M;64@9F]R;6%T.B(*;7-G<W1R("))>F)E<FD@;V)L:6MO('5R93HB"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE8W0@='=O
M(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B27IB97)I(&1V92!U:F5M86IO
MQ(UI('-E('!O;&II.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,3`*
M;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B27IB
M97)I=&4@=F'%H64@8F%R=FYO(&MO;6)I;F%C:6IO(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(U,@IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D
M(&QA;F=U86=E.B(*;7-G<W1R("))>F)E<FET92!J97II:SHB"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU,0IM<V=I9"`B4V5N9"!0<F]B
M;&5M(%)E<&]R="(*;7-G<W1R(")0;\6A;&II('!O<F_$C6EL;R!O(&YA<&%K
M86@B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3`T,@IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B4&_%H6QJ:2!335,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S='(@(E-E;F5G86PB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R.`IM<V=I9"`B4V5N<V]R.B`B
M"FUS9W-T<B`B4V5N>F]R.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,30*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0U,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<U"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B4V5P
M<F5M8F5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R(")3<F)I
M:F$@:6X@Q(UR;F$@9V]R82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-S`R"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(E-E
M<FEJ<VMA(,6A=&5V:6QK82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-30*;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(E-T<F7%OFYI:V]V(&1A='5M(&IE(&YA<&'$C65N
M(&%L:2!N:2!N82!R87IP;VQA9V\N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C(V"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(D%D;6EN:7-T<F%C
M:6IA('-E:F4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS
M9W-T<B`B240@<V5J92!J92!P;W1E:VQA+B(*"B,Z(&QI8B]A<&DN<&AP.C$T
M-0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B4V5J92(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(V,#(*;7-G:60@(E-E="(*;7-G<W1R(").86UE
M<W1I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS9VED(")3970@
M;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I
M9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*(DYA<W1A=FD@;W!C
M:6IO+"!D82!V('!R:6UE<G4L(&1A('!O>F%B:71E('9AQ:%E(&=E<VQO+"!L
M86AK;R!P;VYA<W1A=FET92!L92TB"B)T;RXB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$X"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA
M="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T
M<B`B(@HB57)E9&ET92!O9&1A;&IE;F4@<W1R9<6^;FEK92!N82!K871E<F4@
MQ;YE;&ET92!D;W-T;W!A=&D@>B!V8<6A96=A('!O<G1A;&$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#<*;7-G:60@(E-E="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T
M<B`B3F%S=&%V:71E('!R:79Z970@:F5Z:6L@:6X@;F%S=&%V:71V92!D871U
M;6$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Q"FUS9VED("(B"B)3
M970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A
M9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB
M"FUS9W-T<B`B57)E9&D@>F'$C65T;F4@8F%R=FYE('-H96UE+"!A<&QI:V%C
M:6IE+"!O<W9EQ;YI='9E('-T<F%N:2XN+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-S<*;7-G:60@(E-E='5P(@IM<V=S='(@(DYA;65S=&DB"@HC
M.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-0IM<V=I9"`B
M4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R(").87-T
M879I('-K<FEP=&\@>F$@;W-V9<6^:71E=B!K;W0@<F%Z<&]L;\6^;&II=F\N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X,`IM<V=I9"`B
M4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R
M.B`B"FUS9W-T<B`B36_%OFYI:"!J92!V9<2-(&QO:V%C:6H@<R!P87)A;65T
M<F]M.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T
M<B`B4V5JQ:%E;&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$Y
M"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R(").86MU<&]V86YJ92(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")3:&]R="!3
M=6UM87)Y(@IM<V=S='(@(DMR871E:R!P;W9Z971E:R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT-3`*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B
M92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R(").871A=FEM('1I
M<&MA<G-K92!B;&G%OFYI8V4@;F$@<&]V97IA=F4_(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T
M<B`B4&]K8<6^:2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-30*;7-G
M:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V
M960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B(@HB4&]K8<6^:2!R87IL:6ME(&UE9"!S961A:B!S:')A;FIE
M;F\@:6X@;F%J;F]V96K%H6\@9V5N97)I<F%N;R!K;VYF:6=U<F%C:6IO+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.#4*;7-G:60@(E-H;W<@;&%S
M="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B4')I:V'%
MOFD@9&%T=6T@>F%D;FIE('!R:6IA=F4@<&\@=G-T;W!U/R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$W-S@*;7-G:60@(E-H;W<@;W!T:6]N('1O
M(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B4')I:V'%OFD@;W!C:6IE('IA(&]B
M9'+%OF%T:2!O<FEG:6YA;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,P.#,*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(E!O:V'%OFD@=&ES
M=&5G82P@:VD@<W!R96IE;6$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3(P"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM
M<V=S='(@(E!R:6MAQ;YI(&UE;FEJ<VMO('9R<W1I8V\@9&5L;W9A;FIA('1A
M8F5L92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS
M9W-T<B`B4')I:V'%OF5M("5S(&UE;FD@;F$@;&5V:2!S=')A;FD_(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<W-@IM<V=I9"`B4VAO=R!U<&QO
M860B"FUS9W-T<B`B1&]D86H@;F%L86=A;FIE(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,B"FUS
M9W-T<B`B4&QO:&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R(")::G5T
M<F%J('!L;VAE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-30*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R(")0;W!O;&1N
M92!P;&]H92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4U"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R
M(")6(&)L:<6^:6YI('!L;VAE(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HV,3D*;7-G:60@(E-H<FEN:R(*;7-G<W1R
M(")3:W+$C6DB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.CDQ,`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.CDW,@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C$P-3@*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HQ,3(P"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z,3$X,PHC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R,C,*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C4R"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(X-0IM<V=I
M9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O
M9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(DYA:G!R96H@<VMRQ(UI(&%L:2!P
M<F5M86MN:2!S;W-E9&YJ92!B96QEQ;YK92XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS
M9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B4VEE<G)A($QE;VYE(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-PIM<V=I9"`B4VEG
M;B!U<"(*;7-G<W1R(")0<FEJ879I('-E(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HW,3,*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R
M(")0;V1P:7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C<Q,@IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R(")!;&=O
M<FET;6G$C65N('!O9'!I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A
M<&]R92(*;7-G<W1R(")3:6YG87!U<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C@T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDP-0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R-#8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S-"!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C`P"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,S.3(*;7-G:60@(E-I>F4B"FUS9W-T<B`B5F5L:6MO<W0B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM
M<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R(")0<F5S:V_$C6D@=GID
M<L6^979A;FIE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS
M9W-T<B`B4VQO=F'%H6MA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N
M:6$B"FUS9W-T<B`B4VQO=F5N:6IA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-N;W<B"FUS9W-T<B`B4VYE
M9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W
M"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R(")3;F7%OFYA('!L;VAA(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G
M:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R(")3;F7%OFYE('!L;VAE(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@
M(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R(")::G5T<F%J('-N9<6^;F4@
M<&QO:&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV,`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B4&]P;VQD
M;F4@<VYEQ;YN92!P;&]H92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP
M"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B5FG%H6EN82!S;F5G83HB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I9"`B4VYO=R!E<75I
M=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B4VYE9W4@96MV:79A;&5N=&YA
M(&MO;&G$C6EN82!V;V1E.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M
M;VX@27-L86YD<R(*;7-G<W1R(")386QO;6]N;W9I(&]T;VMI(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,30@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R(")3;VUA;&EJ82(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B4V]N9W,@)B!0;V5M
M<R(*;7-G<W1R(")097-M:2!I;B!P;V5Z:6IE(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$Y-@IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB
M"FUS9W-T<B`B5G)S=&$@=7)E:F5N96=A(&EZ8F]R82(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-C8*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.#D*;7-G
M:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(DYA<VQO=B!V:7)A(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(DIUQ;YN
M82!!9G)I:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B
M4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(DIUQ;YN;RUE
M=G)O<'-K:2`H25-/+3@X-3DM,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O
M=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM
M<V=S='(@(DIUQ;YN82!'96]R9VEA(&EN(&]T;VMI($IUQ;YN:2!386YD=VEC
M:"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP
M:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B2G7%
MOFYA('!O;&]B;&$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,C0*
M;7-G:60@(E-P86-E<B(*;7-G<W1R(")0<F5S;&5D;FEC82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R("+%H'!A;FEJ82(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#<*;7-G:60@(E-P86TB"FUS9W-T<B`B
M3F5Z8<6^96QE;F$@<&_%H71A(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP
M.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R(")6
M:&]D('IA('!O<V5B;F4@>FYA:V4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C8*;7-G:60@(E-P;W)T<R(*;7-G<W1R("+%H'!O<G1I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`BQ:!R:2!,86YK82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,2!L:6(O0FQO8VLO
M;65T87(N<&AP.C@V"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R(")3=&%N9&%R
M9&5N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8W"FUS9VED(")3=&%R
M(%1R96LB"FUS9W-T<B`B6G9E>F1N92!S=&5Z92(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(X-S0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`W
M.0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R("):8<2-971N;R!L971O(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$*;7-G:60@
M(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(D1RQ;YA=F$@86QI('!R;W9I
M;F-A(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3`*
M;7-G:60@(E-T871U<R(*;7-G<W1R(")3=&%T=7,B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,#@U"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G
M<W1R(")/8FQI:V$@<&]M;FEL;FEK82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")3=')E970@061D<F5S<R(*;7-G
M<W1R(").87-L;W8@=6QI8V4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C0R"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R(")3<&ES96L@8F5S
M961N:6@@>G9E>B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3$*
M;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@
M(C\_/S\_/S\_/S]D;VUE;F$@:7H@;F%S;&]V82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C0*;7-G:60@(E-U(@IM<V=S
M='(@(DYE(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R(").92!N86ID96T@<&]D;6%P92!<(B5S7"(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8Y"FUS9VED(")3=6)J
M96-T(@IM<V=S='(@(EIA9&5V82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,T,2!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*
M;7-G:60@(E-U8FUI="(*;7-G<W1R(")0<F5D;&_%OFDB"@HC.B!S:6=N=7`N
M<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U
M97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L
M;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D
M+B(*;7-G<W1R("(B"B)3<')E:F5L:2!S;6\@>F%H=&5V96L@>F$@=G!I<R!<
M(B5S7"(N($YE(&UO<F5T92!S92!P<FEJ879I=&D@9&]K;&5R('9AQ:%A("(*
M(GIA:'1E=F5K(&YE('!O('!O=')J96XN(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$P,PHC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S
M='(@(E5S<&5H(@H*(SH@861M:6XO=7-E<BYP:'`Z.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES
M=&5M+B(*;7-G<W1R(")<(B5S7"(@<V5M('5S<&7%H6YO(&1O9&%L(&L@<VES
M=&5M=2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S
M7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(G)7,G('-E;2!U<W!EQ:%N
M;R!O9'-T<F%N:6P@:7H@<VES=&5M82XB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C<Y(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R(")<
M(B5S7"(@<V5M('5S<&7%H6YO(&EZ8G)I<V%L+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$P-`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M
M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@
M<V5M('5S<&7%H6YO(&]D<W1R86YI;"!I>B!S:7-T96UA+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E
M<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM
M<V=S='(@(B(*(E5S<&7%H6YO(&]B<FYJ96YA(&MO;F9I9W5R86-I:F$N(,2-
M92#%OF5L:<6A('9I9&5T:2!S<')E;65M8F4L('!O;F]V;F\@;F%L;\6^:2XB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B57-P9<6A;F\@<VAR86YJ96YA('9A
M<FYO<W1N82!K;W!I:F$@:V]N9FEG=7)A8VEJ92XB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB
M"FUS9W-T<B`B57-P9<6A;F\@<VAR86YJ96YA('9A<FYO<W1N82!K;W!I:F$@
M:V]F:6=U<F%C:6IE(&1A=&]T96ME("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E
M9"!<(B5S7"(B"FUS9W-T<B`B7"(E<UPB(&IE(&)I;"!U<W!EQ:%N;R!P;W-O
M9&]B;&IE;BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C
M97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B)7,@<V5M('5S<&7%H6YO('IA
M<&ES86PN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W5D86XB"FUS9W-T<B`B
M4W5D86XB"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@(E-U
M;B!2:7-E(@IM<V=S='(@(E-O;L2-;FD@=GIH;V0B"@HC.B!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B4V]NQ(UN
M:2!Z86AO9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8Q"FUS9VED(")3=6YN>2(*;7-G<W1R(")3;V[$C6YO(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,`IM<V=I9"`B4W5N<FES92(*
M;7-G<W1R(")3;V[$C6YI('9Z:&]D(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N
M<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E
M+U-U;G-E="(*;7-G<W1R(")3;V[$C6YI('9Z:&]D+WIA:&]D(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P.0IM<V=I9"`B4W5N<FES93H@
M(@IM<V=S='(@(E-O;L2-;FD@=GIH;V0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C$S"FUS9VED(")3=6YS970B"FUS9W-T<B`B4V]NQ(UN
M:2!Z86AO9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3(*
M;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(E-O;L2-;FD@>F%H;V0Z(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,Y-`IM<V=I9"`B4W5P<&]R="(*
M;7-G<W1R(")0;V1P;W)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4W5R:6YA
M;64B"FUS9W-T<B`B4W5R:6YA;2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3<U"FUS9VED(")3=7)N86UE(@IM<V=S='(@(E!R:6EM
M96LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA
M>65N(@IM<V=S='(@(E-V86QB87)D(&EN($IA;B!-87EE;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R(")3=F%Z:2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R("+%H'9E9'-K82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R("+%H'9I8V$B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN
M8R!L;V<@9&5L971E9"(*;7-G<W1R("))>F)R:7-A;B!S:6YK<F]N:7IA8VEJ
M<VMI(&1N979N:6LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30U"FUS
M9VED(")3>6YC34PB"FUS9W-T<B`B4VEN:W)O;FEZ86-I:F$B"@HC.B!F<F%M
M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E
M<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B3F%P86MA('8@<VEN=&%K
M<VD@:7-K86QN:6@@<&]G;VIE=B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y
M<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(E-I<FEJ<VMA(&%R86)S:V$@
M<F5P=6)L:6MA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B1W)M96YJ92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED
M(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R(").979I:'1A('H@9W)M96YJ
M96T@:6X@=F5T<F]M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C0*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(DYE=FEH=&$@
M>B!G<FUE;FIE;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8U"B,L(&9U>GIY"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G
M<W1R(")::G5T<F%J('!L;VAE(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T
M<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B5%-6(&1A=&]T
M96MA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H
M<#HU-PIM<V=I9"`B5&%B;&4@4V5T(@IM<V=S='(@(DYA<W1A=FET978@=&%B
M96QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S
M='(@(E1A:G9A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S
M='(@(E1A:7=A;BP@9&7%OF5L82!+:71A:G-K92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*
M;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B5&%DQ;YI:VES=&%N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O
M9B(*;7-G<W1R(")486YZ86YI:F$L(%ID<G7%OF5N82!R97!U8FQI:V$B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,B!C;VYF:6<O:&]O:W,N
M<&AP+F1I<W0Z,3$P-PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DV
M"FUS9VED(")487-K<R(*;7-G<W1R(")/<')A=FEL82(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"FUS9VED(")496QE<&AO;F4@
M3G5M8F5R(@IM<V=S='(@(E1E;&5F;VYS:V$@Q:%T979I;&MA(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,#(*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U
M<CH@(@IM<V=S='(@(E1E;7!E<F%T=7)A('8@>F%D;FII('5R:3HB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(R-@IM<V=I9"`B5&5M<&5R871U<F4B"FUS
M9W-T<B`B5&5M<&5R871U<F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C$W"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(E1E;7!E
M<F%T=7)A.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@V
M"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE
M<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B5&5M<&5R871U<F$\8G(@+SXH
M)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*"B,Z(&9R86UE=V]R:R]496UP;&%T
M92]496UP;&%T92YP:'`Z-CDU"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!L
M871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(EPB)7-<(B!V>F]R8V$@
M;F4@;F%J9&5M+B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38X"FUS9VED
M(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")5<F5J979A;&YI
M:R#%H6%B;&]N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(R,"!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS-C$T"FUS9VED(")497AT(@IM<V=S
M='(@(D)E<V5D:6QO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.0IM
M<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(E-A;6\@0F5S961I;&\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED
M(")4:"(*;7-G<W1R(")4;R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT
M"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R(")486IS:V$B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T,@IM<V=I9"`B5&AE($944"!E>'1E
M;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3W9E<FIE;FIE(&YI
M('5S<&5L;R(*"B,Z(&9R86UE=V]R:R](:7-T;W)Y+TAI<W1O<GDN<&AP.C8S
M"FUS9VED(")4:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L960N(@IM<V=S
M='(@(EIG;V1O=FEN82!J92!I>FML;W!L:F5N82XB"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O
M<G0@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B(&EN=&5G<F%C:6IA(&YE
M('!O9'!I<F$@7"(E<UPB(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O
M0F]O:RYP:'`Z,3(Y.`IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B
M92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B4&]S;V1O8FQJ96X@9&%T;W1E:V4@
M;F4@;6]R96T@<VAR86YI=&DN(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T
M(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(E9Z9'+%OF5V86YJ93H@<F%Z
M<F5D(&YI(&)I;"!U<W!EQ:%N;R!N86QOQ;YE;BXB"@HC.B!S97)V:6-E<R]I
M;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W
M:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B3VMN;R!-;\6^
M;F]S=&D@:F4@8FEL;R!Z87!R=&\N(%IA:VQJ=65U:F5M+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-S:#(N<&AP.C@V-@HC+"!F=7IZ>0IM<V=I9"`B5&AE
M(%-32#(@4$5#3"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T
M<B`B3W9E<FIE;FIE(&YI('5S<&5L;R(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C
M;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y
M;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(D%D;6EN
M:7-T<F%T;W(@;6]R82!N86IP<F5J(&YA<W1A=FET:2!S:7-T96T@>F$@<')A
M=FEC92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A
M<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@
M:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R(")+;VYT86MT;FD@240@;FD@
M8FEL('!O<W)E9&]V86X@86QI(&YI(&)I;"!N86ID978@=B!B87II('!O9&%T
M:V]V+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E
M9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B4W1I:R!J92!B:6P@
M=7-P9<6A;F\@9&]D86X@:R!V8<6A:6T@;F%S;&]V;VTN($ML:6MN:71E('-P
M;V1A:B!Z82!O9VQE9#HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HQ,3<R"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R
M92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S
M86=E+B(*;7-G<W1R("(B"B)0;W1R96)U:F5M(&QOQ(UE;F\@4$=0('!O9'!I
M<V%N;R!B96QEQ;YN:6-O+"!D82!P<F5V:7)I;2!P;V1P:7-A;F\@<W!O<F_$
MC6EL;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$
M('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@
M9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("))1"!S97IN86UA
M(&YI(&)I;"!P;W-R961O=F$@86QI(&YI(&)I;"!N86ID96X@=B!B87II('!O
M9&%T:V]V+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S
M(&YO="!S<&5C:69I960N(@IM<V=S='(@(E1O(&1E:F%N:F4@;FEM82!P;V1P
M;W)E+B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z-#8S
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!E;6%I;"!A9&1R97-S("5S
M(&AA<R!B965N(&%D9&5D('1O('EO=7(@:61E;G1I=&EE<RX@66]U(&-A;B!C
M;&]S92!T:&ES("(*(G=I;F1O=R!N;W<N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$V"FUS9VED(")4:&4@96YC<GEP=&EO
M;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*
M;7-G<W1R(")+;V1I<F%N82!V<V5B:6YA('IA:'1E=F$@=F%R;F\@:6YT97)N
M971N;R!P;W9E>F%V;RXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$X-B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4R-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E
M='1I;F<N(@IM<V=S='(@(B5S(&1A=&]T96MA(&)I(&UO<F%L82!V<V5B;W9A
M=&D@)7,@;F%S=&%V:71V<BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE
M("5S('-E='1I;F=S+B(*;7-G<W1R("(E<R!D871O=&5K82!B:2!M;W)A;&$@
M=G-E8F]V871I("5S(&YA<W1A=FET=F4N("(*"B,Z(&9R86UE=V]R:R]$871A
M+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A
M=&$N(@IM<V=S='(@(D1A=&]T96MA(&YE('9S96)U:F4@;F]B96YI:"!P;V1A
M=&MO=BXB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3(T"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E
M9"XB"FUS9W-T<B`B4W1R9<6^;FEK(%PB)7-<(B!J92!B:6P@:7IB<FES86XN
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED
M("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E
M(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B365S
M=&\@1VYU4$<@<')O9W)A;6$@;6]R82!B:71I('!O<W)E9&]V86YO(')A>G)E
M9'4@0W)Y<'1?<&=P+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H
M<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N
M="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I
M<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE
M<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B
M"B)3<&]R;\2-:6QO('!O<VQA;F\@9&YE("5S('IA("5S('H@;F%S;&]V;VT@
M7"(E<UPB(&IE(&)I;"!P<F5B<F%N+EQN(@HB3FD@>F%G;W1O=FEL82!D82!J
M92!B:6QO(&1E:F%N<VMO('!R96)R86YO(&%L:2!R87IU;6QJ96YO+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,34*;7-G:60@(E1H92!N86UE
M('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G
M<W1R("));64@>F$@<&]V97IA=F\@;F$@<W1R86X@>F$@<V5S=&%V;&IA;FIE
M('-P;W)OQ(UI;&$N(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$P-@IM<V=I
M9"`B5&AE(&YE=R!F<F]M(&%D9')E<W,@8V%N)W0@8F4@=F5R:69I960L('1R
M>2!A9V%I;B!L871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C0W-`IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@
M;75S="!B92!N=6UE<FEC+B(*;7-G<W1R(")482!V<F5D;F]S="!M;W)A(&)I
M=&D@Q:%T979I;&MA+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,3(S,@IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I
M<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T
M<B`B4&]T<F5B=6IE;2!O<&5N<W-L(&UO9'5L('IA($AO<F1E7T-R>7!T7W-M
M:6UE.CH@<F%Z<F5D+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z
M,CDV"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB
M)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E
M961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B
M"B).87-T879I96YE(&1A=&]T96ME(%PB)7-<(B!N92!M;W)E('-H<F%N:71I
M+"!K97(@;FIE;FD@<&]D871K:2`B"B)P<F5S96=A:F]N86IV9<2-:FD@9&]V
M;VQJ96X@;V)S96<N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N
M<&AP.C,P-2!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H<#HQ-#4*;7-G
M:60@(B(*(E1H92!P<F5F97)E;F-E<R!B86-K96YD(&ES(&-U<G)E;G1L>2!U
M;F%V86EL86)L92!A;F0@>6]U<B!P<F5F97)E;F-E<R!H879E("(*(FYO="!B
M965N(&QO861E9"X@66]U(&UA>2!C;VYT:6YU92!T;R!U<V4@=&AE('-Y<W1E
M;2!W:71H(&1E9F%U;'0@<V5T=&EN9W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES
M(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB
M"FUS9W-T<B`B4')O9W)A;6$L(&MI(&]D<&ER82!P;V1A=&ME('1E('9R<W1E
M("@E<RD@;F4@;F%J9&5M('8@<VES=&5M=2XB"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HT.#<*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@
M;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B4F%Z;65J
M:71E=B!M;W)A(&)I=&D@<V5S=&%V;&IE;F$@;&4@:7H@96YE9V$@>FYA:V$N
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#<Y"FUS9VED(")4
M:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM
M<V=S='(@(DQOQ(UI=&5V(&UO<F$@8FET:2!S97-T879L:F5N82!L92!I>B!E
M;F5G82!Z;F%K82XB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@
M8F5E;B!D96QE=&5D+B(*;7-G<W1R(")3=')EQ;YN:6L@7"(E<UPB(&IE(&)I
M;"!I>F)R:7-A;BXB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@
M8F5E;B!S879E9"XB"FUS9W-T<B`B4W1R9<6^;FEK(%PB)7-<(B!J92!S:')A
M;FIE;BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E
M96X@<F5M;W9E9"XB"FUS9W-T<B`B6F%H=&5V96L@>F$@<')I:F%V;R!J92!B
M:6P@;V1S=')A;FIE;BXB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C0W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("))
M>F)R86YA('9R<W1I8V$@*"5D*2!N92!O8G-T86IA+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z,C`R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T
M+B(*;7-G<W1R("):8<2-87-N82!D871O=&5K82!N92!O8G-T86IA+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,U.#D*;7-G:60@(E1H92!T97AT
M('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C
M<F5E;BXB"FUS9W-T<B`B5FYEQ:%E;F\@8F5S961I;&\@;F4@=7-T<F5Z82!B
M97-E9&EL;R!N82!E:W)A;G4N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP
M:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC
M92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B4&]S;V1O8FQJ96YI('!O
M9&%T:VD@<V\@8FEL:2!I>F=U8FQJ96YI('!R:2!P<F5JQ:%N:F5M(&MO<F%K
M=2XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE
M=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E
M9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B4&]S;V1O8FQJ
M96X@9&%T;W1E:V4@;F4@;6]R96T@<VAR86YI=&DN(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C4T(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ,34*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R(")W96%T:&5R+F-O;2!N:2!N82!V;VQJ;RXB
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R(").92!N86ID96T@;6%P92!O8FQI:R!<(B5S7"(N(@H*(SH@9G)A;65W
M;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HT-#0@9G)A;65W;W)K+TED96YT
M:71Y+TED96YT:71Y+G!H<#HT-#@*;7-G:60@(E1H97)E(&%R92!N;R!E;6%I
M;"!A9&1R97-S97,@=&\@8V]N9FER;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N
M;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`B3FD@;6_%OFYO<W1I(&YA
M(')A>G!O;&%G;RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HS-#0*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B
M92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R(")$96QI(&YE(&UO<F5J;R!B
M:71I('!R:6MA>F%N:2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#$T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N
M>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@
M)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S
M+B(*;7-G<W1R("(B"B)6('!O;&IU(&IE('!R979EQ(T@>FYA:V]V+B!6=&EP
M:V%L:2!S=&4@)7,@>FYA:V]V+B!6=&EP:V%T:2!M;W)A=&4@;6%N:B!K;W0@
M)2(*(G,@>FYA:V]V+B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP
M:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(E!R
M:<6A;&\@:F4@9&\@;F%P86ME('!R:2!D;V1A:F%N:G4@)R5S)R!K('-I<W1E
M;74Z("5S(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@
M=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B4')IQ:%L
M;R!J92!D;R!N87!A:V4@<')I(&]D<W1R86YJ86YJ=2`G)7,G(&EZ('-I<W1E
M;6$N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`R"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@
M=&AE('-Y<W1E;3H@(@IM<V=S='(@(E!R:<6A;&\@:F4@9&\@;F%P86ME('!R
M:2!O9'-T<F%N:F%N:G4@)R5S)R!I>B!S:7-T96UA+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P
M<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B4')IQ:%L;R!J
M92!D;R!N87!A:V4@<')I('!O<V]D86)L:F%N:G4@)R5S)SH@)7,@(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3,R"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`B4')I(&YA;&%G
M86YJ=2!D871O=&5K92!J92!P<FG%H6QO(&1O(&YA<&%K92X@3F]B961E;B`E
M<R!N:2!B:6P@;F%L;\6^96XN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O
M=W-E<BYP:'`Z.3,W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@
M;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B
M>71E<RDN(@IM<V=S='(@(B(*(E!R:2!N86QA9V%N:G4@9&%T;W1E:V4@:F4@
M<')IQ:%L;R!D;R!N87!A:V4N("5S('IA<V5D82!V9<2-('!R;W-T;W)A+"!K
M;W0@:F4@(@HB9&]V;VQJ96YO+B!$;W9O;&IE;F\@:F4@*"5D(&)Y=&]V*2XB
M"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO
M861E9"XB"FUS9W-T<B`B4')I(&YA;&%G86YJ=2!D871O=&5K92!J92!P<FG%
MH6QO(&1O(&YA<&%K92X@)7,@:F4@;&4@9&5L;F\@;F%L;\6^96YA+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G
M92!P87)T(@IM<V=S='(@(E8@<W!O<F]E:6QU('-E(&IE('!O:F%V:6QA(&YE
M>FYA;F$@;F%P86MA+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B4')I('-P<F5J96UA;FIU
M(&MO;G1A:W1A(&IE('!R:<6A;&\@9&\@;F%P86ME+B(*"B,Z(&9R86UE=V]R
M:R]$871A+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(E!R
M:2!S<')E:F5M86YJ=2!K;VYT86MT82!J92!P<FG%H6QO(&1O(&YA<&%K92XB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@R"FUS9VED("(B"B)4:&5R
M92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R
M:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T
M<B`B(@HB2V]N9FEG=7)A8VEJ<VMI(&]B<F%Z96,@=G-E8G5J92!N87!A:V\N
M(%9E<FIE=&YO('-T92!P;WIA8FEL:2!N87-T879I=&D@(@HB>F%H=&5V86YO
M('!O;&IE+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R
M9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@
M4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB4')IQ:%L
M;R!J92!D;R!N87!A:V4@<')I('!R;V-E<VER86YJ=2!I>F)R86YE9V$@:6UE
M;FEK82X@4')O<VEM;R!P;W-K=7-I=&4@(@HB>FYO=F%N96MO;&EK;R!K87-N
M96IE(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+B(*;7-G<W1R("(B"B)0<FD@<W!R96IE;6%N:G4@:V]N=&%K=&$@:F4@<')I
MQ:%L;R!D;R!N87!A:V4N(%!R;W-I;6\@<&]S:W5S:71E('IN;W9A("(*(FMA
M<VYE:F4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N(@IM<V=S='(@(B(*(E!R:2!S<')E:F5M86YJ=2!K;VYT86MT82!J92!P
M<FG%H6QO(&1O(&YA<&%K92X@4')O<VEM;R!P;W-K=7-I=&4@:V%S;F5J92XB
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*
M;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R
M:6YG(&9O;&1E<G,N(@IM<V=S='(@(E9AQ:$@8G)S:V%L;FEK(&YE('!O9'!I
M<F$@=&4@<&]T97IE+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E
M(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(E1O(&YI('9E;&IA=F5N
M(%)!4B!A<FAI=BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED('II<"!F:6QE+B(*;7-G<W1R(")4;R!N:2!V96QJ879N82!Z:7`@
M9&%T;W1E:V$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S0Q-`IM
M<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N
M=6UB97(N(@IM<V=S='(@(L2"XH":Q:!T979I;&MA(&MA<G1I8V4@;FD@=F5L
M:F%V;F$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P
M.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%022(*;7-G<W1R(")';VYI;&YI:R!O;6]G;\2-92!P;\6A:6QJ86YJ92!S
M<&]R;\2-:6P@<')E:V\@;W!E<F%T97)J82!#;&EC:V%T96QL+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B
M"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B1V]N:6QN:6L@;VUO9V_$C64@
M<&_%H6EL:F%N:F4@<W!O<F_$C6EL('!R96MO(&]P97)A=&5R:F$@5TE.+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R
M96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T
M<B`B1V]N:6QN:6L@;VUO9V_$C64@<&_%H6EL:F%N:F4@<W!O<F_$C6EL('!R
M96MO(&]P97)A=&5R:F$@<VUS,F5M86EL+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED("(B"B)4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU4
M4"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY
M('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C
M8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N
M:70I+B(*;7-G<W1R("(B"B)';VYI;&YI:R!O;6]G;\2-92!P;\6A:6QJ86YJ
M92!S<&]R;\2-:6P@<')E:V\@:71A;&IA;G-K96=A(&]P97)A=&5R:F$@5F]D
M;V%F;VYE+B(*(EIA('!OQ:%I;&IA;FIE(&UO<F5T92!I;65T:2!R96=I<W1R
M:7)A;FD@;F$@:'1T<#HO+W=W=RXQ.3`N:70B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HY.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DU(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q,C0*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Y
M,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8U"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S,30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q
M,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-3<P(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R-#8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C(Y,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$W"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S-C8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C0S-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3`Y(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(V.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C<S."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(U"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,P.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S0P-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS-3@T(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C0P.3(*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z-#$P,`IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS
M9W-T<B`B4&]T<F5B=6IE;2!T;R!P;VQJ92XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,#<T"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O
M;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(E1O('!O;&IE(&QA:&MO('9S96)U
M:F4@;&4@8V5L82#%H71E=FEL82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-S`T"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R(")4;R!P;VQJ92!L86AK
M;R!V<V5B=6IE(&QE(,6A=&5V:6QA(&EN('-T;VQP96,N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$P,PIM<V=I9"`B5&AI<R!F:65L9"!M87D@
M;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B5&\@<&]L:F4@
M;&%H:V\@=G-E8G5J92!L92#%H71E=FEL82XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,3,R"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C
M;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G
M<W1R(")0;VQJ92!M;W)A('9S96)O=F%T:2!S97IN86T@Q:%T979I;"P@;&_$
MC65N:6@@>B!V96II8V\@86QI('!R97-L961K;VTN(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.3DX"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@
M82!V86QI9"!N=6UB97(N(@IM<V=S='(@(E1A('9R961N;W-T(&UO<F$@8FET
M:2#%H71E=FEL:V$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P
M-@IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C
M;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q
M,C,T868G+B(*;7-G<W1R("(B"B)4;R!P;VQJ92!M;W)A('9S96)O=F%T:2!B
M87)V;F\@:V]D;R!V(%)'0B!(97@@9F]R;6%T=2P@;F$@<')I;65R("<C,3(S
M-&%F)RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-S$*;7-G:60@
M(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T
M<B`B5&$@;V)L:6MA(&IE(&)I;&$@Q;YE(&]B9&5L86YA+B(*"B,Z('1E;7!L
M871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M:7,@:7,@)7,N(@IM<V=S='(@(E1O(&IE("5S+B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z-#8Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@
M;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@
M=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A
M(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E
M<R(*;7-G<W1R("(B"B)4;R!J92!P;V1A=&5K('-K=7!I;G-K82!U<')A=FQJ
M86YJ92!+;VQA8BX@6F$@<')E9VQE9"!T96=A('!O9&%T:V$@(@HB<&]T<F5B
M=6IE=&5P<F5G;&5D;&]V86QN:6LL(&MI('!O9'!I<F$@;F'$C6EN('IA<&ES
M82!+;VQA8B!'<F]U<'=A<F4N(%IA("(*(G-E>FYA;2!O9&IE;6%L8V5V:VD@
M=&\@<&]D<&ER86IO(&]B:<6AQ(UI=&4@)7,B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HU.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H
M)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(E-P;W)OQ(UI;&\@
M:F4@8FEL;R!N87!I<V%N;R!V(&MO9&YI('1A8F5L:2!D<G5G8<2-;F4@;V0@
M=F'%H64@*"5S*2XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N
M(@IM<V=S='(@(E1O(,6A=&5V:6QO(&UO<F$@8FET:2!V<V%J(&5N82XB"@HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G
M:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP
M(&9I;&5S+B(*;7-G<W1R(")482!S=')EQ;YN:6L@;F4@;6]R92!O9'!R971I
M('II<"!I;B!G>FEP(&1A=&]T96LN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+U)E9VES=')Y+G!H<#HQ-SD*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U
M<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B4VES=&5M(&IE('1R96YU
M=&YO(&YE86MI=&EV96XN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB
M"FUS9W-T<B`B5&$@=G)E9&YO<W0@;6]R82!B:71I(,6A=&5V:6QK82XB"@HC
M.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4
M:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN
M9&]W(@IM<V=S='(@(E1O(&]K;F\@;6]R871E('!O9VYA=&D@>B!O:VYA($UO
MQ;YN;W-T:2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV-@IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R(")";&ES:R(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3`*;7-G:60@(E1I8VME=',B"FUS
M9W-T<B`B4')I:F%V92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W
M,3,@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")4:6UE
M(@IM<V=S='(@(L2-87,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#`R"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(E-L961N:F4@Q(UA
M<V$B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C(*;7-G:60@(E1I;64@9F]R
M;6%T(@IM<V=S='(@(D]B;&EK82#$C6%S82(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,3D*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@
M(DEZ8FER82!E87-A+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE
M<W1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@
M(E1I=&QE(@IM<V=S='(@(DYA<VQO=B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S$*;7-G:60@(E1O(@IM<V=S='(@(EIA
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U
M-@IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O
M=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W
M:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@HB9<2-(,6^96QI=&4@:7IB<F%T
M:2!V9<2-('!R961M971O=BP@<')I=&ES;FET92!#;VYT<F]L("A00RD@86QI
M($-O;6UA;F0@*$UA8RD@(@HB=&EP:V\L(&UE9'1E;2!K;R!N86YJ92!K;&EK
M871E+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#,*;7-G
M:60@(E1O9&%Y(@IM<V=S='(@(F1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@
M(E1O9V\B"FUS9W-T<B`B5&]G;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O
M:V5L874B"FUS9W-T<B`B5&]K96QA=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,#4*;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(DMO;6]R
M:2`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R(")4;VYG
M82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:V]L86(N<&AP.C$P-0IM<V=I
M9"`B5&]O(&UA;GD@:6YV86QI9"!L;V=I;G,@9'5R:6YG('1H92!L87-T(&UI
M;G5T97,N(@IM<V=S='(@(E!R979EQ(T@;F5U<W!E;&EH('!O=F5Z878@=B!Z
M861N:FEH(&UI;G5T86@N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8X
M"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B3W)G86YI>F%C:6IA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G
M<W1R(")4<FEN:61A9"!I;B!4;V)A9V\B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#`S"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(D1A
M(&%L:2!N92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-3D*;7-G:60@(E1U(@IM<V=S='(@(L2,92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B5'5N:7II:F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B5'5R96EJ82(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")4=7)K:7-H("A)4T\M.#@U
M.2TY*2(*;7-G<W1R(")4=7+%H6MI("A)4T\M.#@U.2TY*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R(")4=7)K;65N:7-T
M86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES
M;&%N9',B"FUS9W-T<B`B5'5RQ:%K:2!I;B!#86EC;W,@;W1O:VDB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B5'5V86QU(@H*(SH@
M9G)A;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H
M;VEC93H@(@IM<V=S='(@(E9T:7!K86IT92!V8<6A;R!I>F)I<F\Z("(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@(E4N5BX@
M:6YD97@Z("(*;7-G<W1R(")5+E8N(&EN9&5K<SHB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@
M(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*
M;7-G<W1R(")54DP@=F'%H64@<VMR:7!T92!Z82!P;W)OQ(UA;FIE('-T871U
M<V$@9&]S=&%V92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G
M<W1R(")59V%N9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A:6YE(@IM
M<V=S='(@(E5K<F%J:6YA(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z-#4Q"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN
M(@IM<V=S='(@(DYI;6%M(&1O<W1O<&$@9&\@5D93(&EM96YI:V$N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS.38@9G)A;65W;W)K+U9&4R]6
M1E,O<W-H,BYP:'`Z,S@Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R(").92!M;W)E;2!S<')E;65N:71I('!R879I8V4@>F$@5D93(&1A=&]T
M96MO(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT
M,C0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0X,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&
M4R!F:6QE("5S+R5S+B(*;7-G<W1R(")$;W9O;&IE;FIA('IA(%9&4R`E<R\E
M<R!N92!M;W)E;2!S<')E;65N:71I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-SDV(&9R86UE=V]R:R]61E,O5D93+W-S:#(N<&AP.C@Q,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*
M;7-G<W1R(").92!M;W)E;2!S<')E;65N:71I(&YA("5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,W(&9R86UE=V]R:R]61E,O5D93+W-S
M:#(N<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE
M8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`B3F4@;6]R96T@<W!R
M96UE;FET:2!N82!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z-S,S(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`W-0HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.3`P"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E
M<UPB+B(*;7-G<W1R(").92!M;W)E;2!P<F5I;65N;W9A=&D@5D93(&1A=&]T
M96ME("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#8Q
M"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B
M3F4@;6]R96T@<V4@<&]V97IA=&D@<R!34TPN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C8T(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(V.0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C,V(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-#$*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(T.0IM<V=I9"`B56YA8FQE('1O(&-O
M<'D@5D93(&9I;&4N(@IM<V=S='(@(E9&4R!D871O=&5K92!N92!M;W)E;2!K
M;W!I<F%T:2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,W,R!F
M<F%M97=O<FLO5D93+U9&4R]S<V@R+G!H<#HS-C8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB
M"FUS9W-T<B`B3F4@;6]R96T@=7-T879R:71I(&EM96YI:V$@7"(E<UPB+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,Y,R!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,C<P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HR.38*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B5D93(&EM96YI:V$@;F4@;6]R96T@=7-T879R
M:71I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(E9&4R!D
M871O=&5K92!N92!M;W)E;2!U<W1V87)I=&DN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HR.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B3F4@;7)O
M96T@=7-T=F%R:71I(&EM96YI:V$@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C,P-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E
M;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B5D93(&1A=&]T96ME(&YE(&UO<F5M
M('5S='9A<FET:2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M=&%R+G!H<#HW-@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII
M<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM
M<V=S='(@(E!O9&%T:V]V(&YE(&UO<F5M('-P<F]S=&ET:2XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q.2!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,P,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<V@R+G!H<#HR.38*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R(").92!M;W)E
M;2!I>F)R:7-A=&D@)7,L(&EM96YI:R!N:2!P<F%Z96XN(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HW-R!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0S"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB
M"FUS9W-T<B`B3F4@;6]R96T@:7IB<FES871I("<E<R<Z("5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,W,"!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C0S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,S(S(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C
M=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B3F4@;6]R96T@:7IB<FES871I
M("5S+"!I;65N:6L@;FD@<')A>F5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HT,#8@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C0Q,`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M(')E8W5R<VEV96QY+B(*;7-G<W1R(").92!M;W)E;2!I>F)R:7-A=&D@:6UE
M;FEK82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-S8@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,S-`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,S0W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HS-34*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C0P,@IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R
M(").92!M;W)E;2!I>F)R:7-A=&D@:6UE;FEK82XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C0U-2!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C0V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(").92!M;W)E;2!I>F)R:7-A=&D@
M5D93(&EM96YI:V$Z("5S("(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,C$R(&9R86UE=V]R:R]61E,O5D93+W-S:#(N<&AP.C(Q,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B3F4@;6]R96T@:7IB<FES871I(&1A=&]T96ME+EPB)7-<
M(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-#(@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HS,30*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C0T,0HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z-#0Y"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!F:6QE+B(*;7-G<W1R(").92!M;W)E;2!I>F)R:7-A=&D@5D93(&1A=&]T
M96ME+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C,Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B!<
M(B5S7"(N(@IM<V=S='(@(DYE(&UO<F5M(&EZ8G)I<V%T:2!D871O=&5K92!<
M(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT-#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S
M:79E;'DZ("5S+B(*;7-G<W1R(").92!M;W)E;2!I>F)R:7-A=&D@5D93.B`E
M<R`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R-0IM<V=I9"`B
M56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B3F4@;6]R96T@9&]L;\2-:71I('-E9&%N:F5G82!I;65N:6MA+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C`T"FUS9VED(")5
M;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@
M(DYE(&UO<F5M(&EZ<&ES871I('!O=')J96YI:"!P;V1R;V)N;W-T:2XB"@HC
M.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#,W(&9R86UE=V]R:R].
M971?24U34"])35-0+T%U=&@N<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T
M<B`B3F4@;6]R96T@<W!R96UE;FET:2!N82`E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR,C,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C(X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ.3`@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$Y-0IM<V=I9"`B56YA
M8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(DYE(&UO<F5M('!R96UA
M:VYI=&D@5D93(&1A=&]T96ME+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z.3,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#8*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV-#$@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HY.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<V@R+G!H<#HY-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(DYE(&UO<F5M(&]D<')E=&D@9&%T;W1E:V5<(B5S
M7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S$V(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C$T,0IM<V=I9"`B56YA8FQE('1O(&]P96X@
M5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(DYE(&UO<F5M(&]D<')E
M=&D@5D93(&1A=&]T96ME(&YA;65N:F5N92!P:7-A;FIU+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C@Q(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C@V"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$T,"!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S8*;7-G:60@(E5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R(").92!M;W)E;2!O9'!R971I
M(%9&4R!D871O=&5K92XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D
M(&%R8VAI=F4N(@IM<V=S='(@(DYE(&UO<F5M(&]D<')E=&D@>F=OQ:'$C65N
M96=A(&%R:&EV82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.3`X"FUS
M9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL
M960I+B(*;7-G<W1R(").92!M;W)E;2!P<F5I;65N;W9A=&D@5D93(&1A=&]T
M96ME("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HY,SD*(RP@
M9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE
M4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(DYE(&UO<F5M('!R96EM96YO=F%T
M:2!61E,@9&%T;W1E:V4@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B
M;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B3F4@;6]R96T@<')E:6UE;F]V
M871I(%9&4R!D871O=&5K92XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HW,30*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B3F4@;6]R96T@<')E8G)A=&D@5D93(&]S;F]V
M;F5G82!I;65N:6MA+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3$P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S
M('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS
M9W-T<B`B3F4@;6]R96T@<')E:6UE;F]V871I("5S('8@)7,Z(&UA<&$@Q;YE
M(&]S=&%J82(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS
M-#4*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B3F4@;6]R96T@<')E:6UE;F]V871I(%9&4R!I;65N:6MA+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S8W"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM
M<V=S='(@(DYE(&UO<F5M('!R96EM96YO=F%T:2!61E,@:6UE;FEK83H@)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-C4@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HS-3$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W-H
M,BYP:'`Z,S0T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").92!M;W)E;2!P<F5I;65N
M;W9A=&D@5D93(&1A=&]T96ME(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HV-34@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C(T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE("5S+R5S+B(*;7-G<W1R(").92!M;W)E;2!P<F5I;65N;W9A=&D@
M5D93(&1A=&]T96ME("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,S8Q(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,3,*(SH@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V-"!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,S,W"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HS-3D*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4N(@IM<V=S='(@(DYE(&UO<F5M('!R96EM96YO=F%T:2!61E,@9&%T;W1E
M:V4N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK
M:7-O9G,N<&AP.C4P"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB
M"FUS9W-T<B`B3F4@;6]R96T@<W!R96UE;FET:2!N82`E<RXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5
M;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R
M(").92!M;W)E;2!P<F5V97-T:2!T96=A(%=O<F1O=F5G82!D;VMU;65N=&$N
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ.#,Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!T<FEG9V5R(&9R964O8G5S>2!U<&1A
M=&4@9F]R("5S(@IM<V=S='(@(DYE(&UO<F5M('-P<F_%OFET:2!P<F]S=&\O
M>F%S961E;F\@<&]S;V1O8FET92!Z82`E<R(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,34T(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34W
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-S:#(N<&AP.C$T.2!F<F%M97=O<FLO
M5D93+U9&4R]S<V@R+G!H<#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F4@;6]R
M96T@;F%P:7-A=&D@5D93(&1A=&]T96ME(%PB)7-<(BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HQ.#D*;7-G:60@(E5N86)L92!T;R!W<FET
M92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(DYE(&UO<F5M
M(&YA<&ES871I(%9&4R!P;V1A=&MO=FYI:"!D871O=&5K+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C,R,"!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,30V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ-3$*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A
M+B(*;7-G<W1R(").92!M;W)E;2!N87!I<V%T:2!61E,@<&]D871K;W9N:6@@
M9&%T;W1E:RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.3$T"FUS9VED
M(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC
M965D960N(@IM<V=S='(@(DYE(&UO<F5M(&YA<&ES871I(%9&4R!D871O=&5K
M92P@:W9O=&$@8F\@<')E<V7%OF5N82XB"@HC.B!T96UP;&%T97,O<')E9G,O
M96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B4F%Z=F5L
M:F%V:2!S<')E;65M8F4B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HR,C$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S@X"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@
M<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R(").97!R:<2-86MO=F%N
M(&]D9V]V;W(@<R!S=')EQ;YN:6MA('8@<&]V97IO=F%N:G4Z(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$W"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,S.0HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S8*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@R"FUS9VED(")5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B3F5P<FG$
MC6%K;W9A;B!N97!R:<2-86MO=F%N(&]D9V]V;W(@<W1R9<6^;FEK82!Z83HB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H
M<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R(").96EZ<&]L;FIE;F\B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B56YI8V]D92`H551&
M+3@I(@IM<V=S='(@(E5N:6MO9"`H551&+3@I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G
M:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(EID<G7%OF5N:2!A
M<F%B<VMI(&5M:7)A=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+
M:6YG9&]M(@IM<V=S='(@(EID<G7%OF5N;R!K<F%L:F5S='9O(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R("):9')UQ;YE
M;F4@9'+%OF%V92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T
M97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R("):9')UQ;YE;F4@
M9'+%OF%V92!/=&]K:2!-:6YO<B!/=71L>6EN9R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HV-R!L:6(O0FQO8VLO;65T87(N<&AP.C@S"FUS
M9VED(")5;FET<R(*;7-G<W1R(")%;F]T92(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0R.2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HU.`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R(").97!O>FYA;F\B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*
M;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS
M9W-T<B`B3F5P;WIN86YA(&%P:6US9VED("A)1"!!4$D@<W!O<F_$C6EL82DN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G
M92!)1"DN(@IM<V=S='(@(DYE<&]Z;F%N82!C;&EM<V=I9"`H240@=7!O<F%B
M;FG%H6ME9V$@<W!O<F_$C6EL82DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,34R"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D
M+B(*;7-G<W1R(")-97-T;R!N:2!N87-T879L:F5N;RXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G:60@
M(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(DYE>FYA
M;F\@=7!O<F%B;FG%H6MO(&EM92!A;&D@9V5S;&\N(@H*(SH@9G)A;65W;W)K
M+TED96YT:71Y+TED96YT:71Y+G!H<#HS,3D*;7-G:60@(E5N;F%M960B"FUS
M9W-T<B`B0G)E>B!I;65N82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C@W(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M.3(W"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3,S"FUS
M9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B3F5P;V1P<G1A
M(')A>L6A:7)I=&5V(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@
M(E5P9&%T92(*;7-G<W1R(")0;W-O9&]B:2(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D
M871E("5S(@IM<V=S='(@(E!O<V]D;V)I("5S(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B57!D871E('5S97(B"FUS
M9W-T<B`B4&]S;V1O8FQJ96X@=7!O<F%B;FEK(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HQ-#,@861M:6XO<&5R;7,O961I="YP:'`Z,3`Q('-E<G9I8V5S+W-H
M87)E<R]E9&ET+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E
M9"!<(B5S7"(N(@IM<V=S='(@(E!O<V]D;V)L:F5N("<E<R<N(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#D*;7-G:60@(E5P9W)A9&4@<V-R:7!T
M(&1E;&5T960N(@IM<V=S='(@(DEZ8G)I<V%N82!S:W)I<'1A('IA(&YA9&=R
M861N:F\N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-R!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DX"FUS9VED(")5<&QO
M860B"FUS9W-T<B`B3F%L86=A;2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ.#4*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F
M:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R(").86QOQ;YI(&YA('-T<F7%
MOFYI:R!V<V4@;F%M97-T:71V96YE(&1A=&]T96ME(&%P;&EK86-I:BXB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(E5R=6=V86HB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H
M<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS
M9W-T<B`B57!O<F%B:2!S961A;FII.B`E<R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,
M(@IM<V=S='(@(E5P;W)A8FD@4U-,(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$R-PIM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R
M96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B57!O<F%B:2P@Q(UE(&IE
M('5P;W)A8FYIQ:%K;R!I;64O9V5S;&\@9')U9V'$C6YO(&]D($E-4U`@<W1R
M9<6^;FEK82(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z
M,C$*;7-G:60@(E5S97(B"FUS9W-T<B`B57!O<F%B;FEK(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW-C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM
M<V=S='(@(E5P;W)A8FYI:R`E<R!N:6UA(&1O<W1O<&$@9&\@)7,B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HR,#(*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB
M"FUS9W-T<B`B57!R879A('IA('5P;W)A8FYI:V4B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C(T-0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM
M<V=S='(@(E5P;W)A8FYIQ:%K92!N87-T879I='9E(@H*(SH@<VEG;G5P+G!H
M<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B4F5G:7-T
M<F%C:6IA('5P;W)A8FYI:V$B"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5
M<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S
M:71E+B(*;7-G<W1R(")296=I<W1R:7)A;FIE('5P;W)A8FYI:V]V(&IE(&YA
M('1E:B!S=')A;FD@;VYE;6]G;\2-96YO+B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HT.30*;7-G:60@(E5S97(@86-C;W5N="!N;W0@9F]U;F0B"FUS
M9W-T<B`B3F4@;F%J9&5M('5P;W)A8FYI:V]V(')AQ(UU;BXB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS-"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP
M.CDX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$U,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C8T('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R(")5<&]R86)N
M:<6A:V\@:6UE(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C$R-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR
M96%D>2!E>&ES=',N(@IM<V=S='(@(E5P;W)A8FYIQ:%K;R!I;64@7"(E<UPB
M(&IE(,6^92!V('5P;W)A8FDN(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B57!O<F%B;FG%
MH6MO(&EM93H@(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM
M<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(")5<&]R86)N:<6A:V\@:6UE.B`B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5
M<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R(")5<&]R86)N:6MI+"!K:2!S
M;R!V('-I<W1E;74Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A
M;B(*;7-G<W1R(")5>F)E:VES=&%N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,3<S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(Y-`IM
M<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B
M5D93(&EM96YI:R!N92!O8G-T86IA+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ,C<*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(D]D<V]T;F]S
M="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@W-0IM<V=I9"`B5F%L
M:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R(").86ID96YA
M('9E;&IA=FYA(&QO:V%C:6IA('IA:F5M83HB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B5F%L:61I='DB"FUS9W-T
M<B`B5F5L:F%V;F]S="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3DW"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E
M<R!F<F]M(&YO=RXB"FUS9W-T<B`B5G)E9&YO<W0@=B!M:6YU=&%H(&]D('-E
M9&%J(&1A;&IE+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V-2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@V"B,L('!H<"UF;W)M870*;7-G
M:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*
M;7-G<W1R(")6<F5D;F]S="!P<F5S96=A(&UA:W-I;6%L;F\@9&]LQ;YI;F\@
M)7,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S,B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-34T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(V,#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Y.`HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")6
M86QU97,B"FUS9W-T<B`B5G)E9&YO<W1I(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,Y-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#<T"FUS
M9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B5G)E9&YO<W1I
M(&]D(&MO9&5R(&EZ8FER871I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N
M=6%T=2(*;7-G<W1R(")686YU871U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(S.`IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B5F%R:6%B
M:6QN;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R
M(")696YE>G5E;&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S
M<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(E!R
M979E<FIA;FIE(&YE=7-P9<6A;F\@+2!M;V=OQ(UE(&IE(&)I;&\@<W!O<F_$
MC6EL;R!S<')E;65N:F5N;RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C<P,0IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R(")287IL:<2-
M:6-A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T,@IM<V=I9"`B
M5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(E)A>FQIQ(UI8V$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B5F5R
M>2!(:6=H(@IM<V=S='(@(EIE;&\@=FES;VMO(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM
M<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B5FEE=&YA;2(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DW"FUS9VED(")6:65T;F%M97-E("A625-#24DI(@IM
M<V=S='(@(E9I971N86US:VD@*%9)4T-)22DB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HY-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5FEE=R`E<R(*;7-G<W1R(")0;V=L96H@)7,B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX,C4*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E9I97<@)7,@6R5S72(*;7-G<W1R(")0;V=L96H@:V]T("5S(@H*
M(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E
M<FYA;"!W96(@<&%G92(*;7-G<W1R(")0;V=L960@;F$@>G5N86YJ;R!S<&QE
M=&YO('-T<F%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N
M9',L($)R:71I<V@B"FUS9W-T<B`B1&5V:<6A:VD@;W1O:VD@*&)R:71A;G-K
M:2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3
M+B(*;7-G<W1R(")$979IQ:%K:2!O=&]K:2`H6D1!*2(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C(Q"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(E9I
M9&QJ:79O<W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4W
M"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B5FED;&II=F]S=#HB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B
M5F]D869O;B!)=&%L:6IA('!R96MO(%--5%`B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V
M"FUS9VED(")705).(@IM<V=S='(@(D]03UI/4DE,3R(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.CDQ"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)
M3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R
M(")/4$]:3U))3$\A(2$@4D_$C4Y/($]$4U1204Y)32!32U))4%1/($E:("5S
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S
M"FUS9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B5TE.('!R96MO($A45%`B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G
M<W1R(")786QL:7,@:6X@1G5T=6YA(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C<@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.CDU"FUS9VED(")787)N:6YG(@IM<V=S='(@(D]P
M;WIO<FEL;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C`*;7-G:60@(E=E(@IM<V=S='(@(DUI(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,T"FUS9VED(")796%T:&5R($9O<F5C87-T
M(@IM<V=S='(@(E9R96UE;G-K82!N87!O=F5D(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C0Q.0IM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I
M9&5D(&)Y(@IM<V=S='(@(E9R96UE;G-K:2!P;V1A=&MI(',@<W!L971A(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3`Q"FUS9VED(")796%T:&5R
M+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O;2(*"B,Z(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B4W!L970B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8P"FUS9VED(")796(@4VET92(*;7-G
M<W1R(")3<&QE=&YA('-T<F%N(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(E1E
M9&5N<VMO(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G
M:60@(E=E;&-O;64B"FUS9W-T<B`B1&]B<F]D;\6A;&DB"@HC.B!T96UP;&%T
M97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G
M<W1R(")$;V)R;V1OQ:%L:2!N82!S<&QE=&YI:"!S=')A;F5H('!R;V=R86UA
M("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B1&]B<F]D;\6A
M;&DL("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3@*;7-G:60@(E=E
M<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(EIA:&]D;FD@*$E33RTX.#4Y
M+3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3D*;7-G:60@(E=E<W1E
M<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R("):86AO9&YI("A)4T\M.#@U.2TQ
M-2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R
M("):86AO9&YA(%-A:&%R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U
M;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B2V%T97)O(&%P
M;&EK86-I:F\@;F%J('!R:6MAQ;YE("5S+"!P;R!P<FEJ879I/R(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H
M92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R(")+86O%H65N(&IE(&QO
MQ(UI;&YI('IN86L_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T
M<B`B2V%KQ:%E;B!J92!N879E9&5N:2!Z;F%K/R(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#8U"FUS9VED(")7:&5R96ES
M($%U<W1R86QI82!M87`B"FUS9W-T<B`B6F5M;&IE=FED("!7:&5R96ES($%U
M<W1R86QI82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI
M8V@@<&AA<V5S(@IM<V=S='(@(E)A>G9O:FYA('-T;W!N:F$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3,V"FUS9VED(")7:&EC:"!P;'5G:6YS('1O
M(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(DMA
M=&5R92!D;V1A=&ME(&YA:B!O;6]G;\2-:6T@<')I('5R96IA;FIU(&)E<V5D
M:6PN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y-`IM<V=I9"`B
M5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(L6@:7)I;F$@=B!E;F]T86@@
M0U-3(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H
M=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`BQ:!I<FEN
M82`E<R!M96YI:F$@;F$@;&5V:2`H;V1R87II;&$@<V4@8F\@;V(@;F%S;&5D
M;FII('!R:6IA=FDI.B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU
M,S<*;7-G:60@(E=I:VDB"FUS9W-T<B`B5VEK:2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.3,@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C<*;7-G:60@(E=I;F0B"FUS9W-T<B`B5F5T97(Z("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS
M9VED(")7:6YD($5A<FQY(@IM<V=S='(@(DIU=')A;FII('9E=&5R.B`B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.CDR"FUS9VED(")7:6YD('-P965D(&EN
M(&MN;W1S(@IM<V=S='(@(DAI=')O<W0@=F5T<F$@=B!V;WIL:6@B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$V.`IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B
M5F5T97(Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-@IM
M<V=I9"`B5VEN9#H@(@IM<V=S='(@(E9E=&5R.B`B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-CD*;7-G:60@(E=I<V1O;2(*;7-G<W1R(")-;V1R;W-T
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q,@IM<V=I9"`B5VES
M:&QI<W0B"FUS9W-T<B`B3&ES=&$@Q;YE;&IA(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C<P"FUS9VED(")7;W)K(@IM<V=S='(@(E-L=<6^8F$B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G
M:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")3;'7%OF)E;FD@;F%S;&]V(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM
M<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")3;'7%OF)E;FD@=&5L969O;B(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$Y,R!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O
M;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@
M9F]U;F0@)60N(@IM<V=S='(@(DYA<&'$C6YO(,6A=&5V:6QO('!O;&H@=B`E
M9"!V<G-T:2X@4')IQ(UA:V]V86YI:"`E9"P@;F%J9&5N:6@@)60N(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S,R"B,L('!H<"UF;W)M870*
M;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F
M;W5N9"`E9"XB"FUS9W-T<B`B3F%P8<2-;F\@Q:%T979I;&\@<&]L:BX@4')I
MQ(UA:V]V86YI:"`E9"P@;F%J9&5N:6@@)60N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG
M(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@
M(DYA<&'$C65N(&]D;6EK("5D(&UE9"!B<F%N:F5M(&1A=&]T96ME(%9&4RXB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Y"FUS9VED(")8+5)E
M9B(*;7-G<W1R(")8+5)E9B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B
M"FUS9W-T<B`B6#4P.78S(&]S;F]V;F$@;VUE:FET978B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($5X
M=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R(")8-3`Y=C,@4F%ZQ:%I<FIE;F$@
M=7!O<F%B82!K;&IUQ(UA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E
M($YA;64B"FUS9W-T<B`B6#4P.78S(%IA9&5V82!A;'1E<FYA=&EV;F\@:6UE
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G
M:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(E@U
M,#EV,R!+:G5E('IA(&1O;&]E:71I('IA9&5V;R(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C@S"FUS9VED(")8-3`Y=C,@97AT96YS
M:6]N<R(*;7-G<W1R(")8-3`Y=C,@<F%ZQ:%I<FET978B"@HC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`B3$PB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$X"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-C`*;7-G:60@(EE9
M65DB"FUS9W-T<B`B3$Q,3"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,3$Q"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@
M(EEA:&]O(2!Z96UL:F5V:60B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O
M36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`B3&5T
M;F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")996UE;B(*;7-G<W1R(")*96UE
M;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY
M-C8*;7-G:60@(EEE<R(*;7-G<W1R(")$82XB"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G
M<F5E(@IM<V=S='(@(D1A+"!S92!S=')I;FIA;2XB"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C(S-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E
M('1H86X@)60@8FQO8VMS+B(*;7-G<W1R(").:6UA=&4@9&]V;VQJ96YJ82!U
M<W1V87)I=&D@=F7$C2!K;W0@)60@8FQO:V]V+B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,3,Y-0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N
M=&EC871E9"XB"FUS9W-T<B`B3FES=&4@<')I:F%V;&IE;FDB"@HC.B!F<F%M
M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,R-0IM<V=I9"`B66]U(&-A
M;FYO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M
M92XB"FUS9W-T<B`B5B!I;65N=2!N92!M;W)E=&4@:6UE=&D@>FYA:V]V("=<
M7"<B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]P:'!G=RYP:'`Z,3$W"B,L(&9U
M>GIY"FUS9VED(")9;W4@9&ED(&YO="!A=71H96YT:6-A=&4N(@IM<V=S='(@
M(DYI<W1E('!R:6IA=FQJ96YI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(V,PIM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I
M;"!A9&1R97-S+B(*;7-G<W1R(").:7-T92!V<W1A=FEL:2!V96QJ879N96=A
M(&5L96MT<F]N<VME9V$@;F%S;&]V82XB"@HC.B!F<F%M97=O<FLO1&%T82]$
M871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG
M="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H
M92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@HB
M365D('-P<F5J971I;6D@9&%T;W1E:V%M:2!N:7-T92!O>FYAQ(UI;&D@;F]B
M96YE9V$@<&]L:F$L(&MI('-E('5J96UA(',@<&]L:FD@(@HB=B5S+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX-PIM<V=I9"`B66]U(&AA=F4@
M8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R(")":6QI('-T92!O9&IA=FQJ96YI
M+B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,SDS"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!H879E(')E<75E<W1E9"!T;R!A
M9&0@=&AE(&5M86EL(&%D9')E<W,@7"(E<UPB('1O('1H92!L:7-T(&]F('EO
M=7(@(@HB<&5R<V]N86P@96UA:6P@861D<F5S<V5S+EQN(@HB7&XB"B)';R!T
M;R!T:&4@9F]L;&]W:6YG(&QI;FL@=&\@8V]N9FER;2!T:&%T('1H:7,@:7,@
M<F5A;&QY('EO=7(@861D<F5S<SI<;B(*(B5S7&XB"B)<;B(*(DEF('EO=2!D
M;VXG="!K;F]W('=H870@=&AI<R!M97-S86=E(&UE86YS+"!Y;W4@8V%N(&1E
M;&5T92!I="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(W,`IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C
M96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L
M("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N
M(@IM<V=S='(@(B(*(E9N97-T:2!M;W)A=&4@=F5L:F%V;F\@9W-M(,6A=&5V
M:6QK;RY$=F]L:F5N:2!Z;F%K:2!S;R!L92#%H71E=FEL:V4@:6X@)RLG(&MO
M="`B"B)P<F5D<&]N82!M961N87)O9&YI;2#%H71E:79L:V%M+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.3<*;7-G:60@(EEO=2!H879E('1O
M(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(E9S=&%V:71I(&UO<F%T
M92!V96QJ879N;R!V<F5D;F]S="XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A
M=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(D]B;&EK
M;W9A=&D@;6]R871E(%-I9VYU<"!B86-K96YD+"#%H65L92!N871O('-E(&QA
M:&MO('!R:6IA=FQJ871E+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z-#8W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N
M9"XB"FUS9W-T<B`B3V)L:6MO=F%T:2!M;W)A=&4@5D93(&)A8VME;F0N(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO
M=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E
M;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R(").86IP<F5J(&]P:<6A
M:71E('1EQ;YA=F4L(,6A96QE(&YA=&\@;&%H:V\@<&_%H6QJ971E('!O<F_$
MC6EL;R!O('1EQ;YA=F%H+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X.#@*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T(&5N=&5R(&%N(&5M86EL
M(&%D9')E<W,N(@IM<V=S='(@(DYI<W1E('9S=&%V:6QI('9E;&IA=FYE9V$@
M96QE:W1R;VYS:V5G82!N87-L;W9A+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X.#8*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T(&5N=&5R(&%T
M(&QE87-T(&]N92!E;6%I;"!A9&1R97-S+B(*;7-G<W1R(").:7-T92!V<W1A
M=FEL:2!V96QJ879N96=A(&5L96MT<F]N<VME9V$@;F%S;&]V82XB"@HC.B!S
M97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@
M<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R("))>F)R
M871I(&UO<F%T92!S=')EQ;YN:6LL(&MI(&)O(&EZ8G)I<V%N+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$Q.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S
M97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B3F%T86[$C6YE:F4@;F%V
M961I=&4@=7!O<F%B;FG%H6MO(&EM92P@:VD@9V$@Q;YE;&ET92!I>F)R:6%T
M:2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HY.0IM<V=I9"`B66]U(&UU<W0@<W!E
M8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B3F%T86[$C6YE
M:F4@;F%V961I=&4@=7!O<F%B;FG%H6MO(&EM92P@:VD@9V$@Q;YE;&ET92!O
M9'-T<F%N:71I+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8Q('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R(").871A;L2-;F5J92!N
M879E9&ET92!U<&]R86)N:<6A:V\@:6UE+"!K:2!G82#%OF5L:71E(&1O9&%T
M:2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#4*;7-G:60@(EEO=2!M=7-T('-P
M96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B3F%T86[$
MC6YE:F4@;F%V961I=&4@=7!O<F%B;FG%H6MO(&EM92P@:VD@9V$@Q;YE;&ET
M92!P;W-O9&]B:71I+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C
M=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R(").871A;L2-;F5J92!N879E9&ET
M92!K86H@Q;YE;&ET92!N87)E9&ET:2XB"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@
M='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R(")6=&EP:V%J=&4@
M:6UE(&YO=F4@:V%T96=O<FEJ92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE960@
M=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R(")6
M;F5S=&D@;6]R871E(&ET86QI:F%N<VMO('1E;&5F;VYS:V\@Q:%T979I;&MO
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<U"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E
M(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)68<6A82!P<FEJ879I='9E;F$@
M<V5J82`E<R!J92!P;W1E:VQA+B!0<F]S:6UO+"!D82!S92!P;VYO=FYO('!R
M:6IA=FET92XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS
M-`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(E9AQ:$@96QE
M:W1R;VYS:VD@;F%S;&]V.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,34*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B5F'%H2!N
M87-L;W8Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR"FUS9VED(")9;W5R($EN9F]R;6%T
M:6]N(@IM<V=S='(@(E9AQ:%I('!O9&%T:VDB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HY-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!)
M;G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI
M;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C
M=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)/9"!Z
M8<2-971K82`E<R!S96IE+"!S92!J92!V8<6A('-P;&5T;FD@;F%S;&]V('-P
M<F5M96YI;"X@27H@(@HB=F%R;F]S=&YI:')A>FQO9V]V+"!S92!M;W)A=&4@
M<&]N;W9N;R!P<FEJ879I=&DN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z,S`*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R(")68<6A92!I
M;64Z(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*;7-G
M:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S
M=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E($AO
M<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E
M(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S
M='(@(B(*(E9AQ:%E(&]Z861J92!Z82!O=F5R:F5N92!N92!P;V1P:7)A(&1O
M9&%J86YJ82!U<&]R86)N:6MO=BX@Q(UE(,6^96QI=&4@(@HB=7!O<F%B:71I
M2&]R9&4@>F$@861M:6YI<W1R:7)A;FIE('5P;W)A8FYIQ:%K:6@@<F'$C75N
M;W8L(&UO<F%T92!U<&]R86)I=&D@(@HB9')U9V\@;WIA9&IE('IA;W9E<FIA
M;FIE+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM
M<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T
M('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S
M(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R
M("(B"B)68<6A92!O>F%D:F4@>F$@;W9E<FIA;FIE(&YE('!O9'!I<F$@;F%V
M86IA;FIA('5P;W)A8FYI:V]V(&%L:2!P82!J92!B:6QA("(*(FUOQ;YN;W-T
M(&]N96UO9V_$C65N82!I>B!D<G5G:6@@<F%Z;&]G;W8N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z.3@S"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T
M:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C
M="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T
M<B`B(@HB2V'%OF4L(&1A('-E(&IE(&]D('IAQ(UE=&MA("4@<V5J92P@=F'%
MH2!B<G-K86QN:6L@<W!R96UE;FEL+B!)>G9A<FYO<W1N:6@@(@HB<F%Z;&]G
M;W8L('-E(&UO<F%T92!P;VYO=FYO('!R:6IA=FET:2XB"@HC.B!L:6(O0FQO
M8VLO:69R86UE+G!H<#HU,`IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T
M('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R(")68<6A(&)R<VMA;&YI
M:R!N92!P;V1P:7)A('1E(&9U;FMC:6IE+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E
M<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O
M;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@HB5F'%H2!B
M<G-K86QN:6L@;F4@<&]D<&ER82!D;VQOQ(UE;FEH(&UOQ;YN;W-T:2!P<FD@
M<')I;G1A;FIU+B!:82!P<FEN=&%N:F4@(@HB<')I=&ES;FET92!#;VYT<F]L
M+TUOQ;YN;W-T:2`K(%`N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V
M,0IM<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B5F'%
MH2!T<F5N=71N:2#$C6%S;W9N:2!P87,Z(@H*(SH@<V5R=FEC97,O<')E9G,N
M<&AP.C$S,`IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N
M(&-H86YG960N(@IM<V=S='(@(E9AQ:%A('!R:79Z971A(&ED96YT:71E=&$@
M:F4@8FEL82!S<')E;65N:F5N82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,38Q"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@
M(E!R:79Z971A(&ED96YT:71E=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C`T"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`B5F'%H64@
M:6UE.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY.0IM<V=I9"`B
M66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B5F'%H6$@<')I:F%V
M82!J92!P;W1E:VQA+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O
M<B`E<R!I<SH@)7,B"FUS9W-T<B`B5F'%H64@;F]V92!G97-L;R!Z82`E<R!J
M93H@)7,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`IM
M<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@
M9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")68<6A92!N87-T
M879I='9E('-O(&)I;&4@<&]S;V1O8FQJ96YE('IA(,2-87,@=&4@<V5J92XB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B
M66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R(")68<6A
M92!N87-T879I='9E('-O(&)I;&4@<&]S;V1O8FQJ96YE+B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D
M(&AA<R!B965N(')E<V5T(@IM<V=S='(@(E9AQ:%E(&=E<VQO(&IE(&)I;&\@
M<&]N87-T879L:F5N;RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@
M8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB
M<&%S<W=O<F0N(@IM<V=S='(@(B(*(E9AQ:%E(&=E<VQO(&IE(&)I;&\@<&]N
M87-T879L:F5N;RX@3F$@=F'%H2!E+6YA<VQO=B!S;6\@=F%M('!O<VQA;&D@
M;F]V;V=E<VQO("(*(G,@:V%T97)I;2!S92!P<FEJ879I=&4N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z-S,S"FUS9VED(")9;W5R('!A<W-W;W)D
M(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")68<6A92!G97-L;R!J92!P;W1E:VQO
M+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B
M66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B5F'%H6D@<&]S<F5D;FD@
M<W1R9<6^;FEK:3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O
M<VQA=FEA(@IM<V=S='(@(DIU9V]S;&%V:6IA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B6F%I
M<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("):86UB
M:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B
M6FEM8F%B=F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-S$*;7-G:60@
M(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E
M9"!497AT72(*;7-G<W1R(");4VMR:6H@8VET:7)A;F\@8F5S961I;&]=(@H*
M(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G:60@(EM0<F]B;&5M(%)E
M<&]R=%TB"FUS9W-T<B`B6W!O<F_$C6EL;R!O(&YA<&%K:5TB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H
M;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R(");4&]K8<6^:2!C:71I<F%N;R!B
M97-E9&EL;R`M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H
M:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC+"!P:'`M9F]R;6%T"FUS9VED(");
M4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");4&]K8<6^
M:2!C:71I<F%N;R!B97-E9&EL;R`M("5S('9R<W1I8UTB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C(P-`HC+"!P:'`M9F]R;6%T"FUS9VED(");
M;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B6R5S('9R<W1I8V$@;V0@)7-=(@H*
M(SH@;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(E]#3$DB
M"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*;7-G<W1R
M(")$<F5V97-N82`B"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U
M<',B"FUS9W-T<B`B7U-K=7!I;F4B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O365N=2YP:'`Z,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R(")0;VUOQ(TB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED
M(")?3&]G(&EN(@IM<V=S='(@(E!R:6IA=F$B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O365N=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*;7-G<W1R
M(")/9&IA=F$B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z
M,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R(")-;\6^;F]S=&DB"@HC.B!L
M:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R(")$
M;W9O;&IE;FIA(@H*(SH@;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B
M"FUS9W-T<B`B7TYA;65S=&DB"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@
M(E]5<V5R<R(*;7-G<W1R(")?57!O<F%B;FEK:2(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3(U"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T
M<B`B26UE;FEK(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(DYA<VQO
M=FYI:R!N97IN86XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ
M-PIM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B2V]L961A<B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3@T(&QI8B]";&]C:R]M971A<BYP:'`Z,S<P"B,L
M('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B36ER;F\B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N
M;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R(").92!M;W)E;2!U<W1V
M87)I=&D@:7IH;V1N92!D871O=&5K92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*
M;7-G<W1R(").92!M;W)E;2!O9'!R971I('9H;V1A(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z-C`P"FUS9VED(")C;&EC:R!H97)E
M(@IM<V=S='(@(FML:6MN:2!T=2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R
M;W(B"FUS9W-T<B`B;F%P86MA('8@=7!O<F%B;FD@=6MA>FYE('9R<W1I8V4B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W.`IM<V=I
M9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R(").87!A:V$@=B!K;VYF
M:6=U<F%C:6II(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS
M9W-T<B`B3F4@;F%J9&5M('IA:'1E=F%N92!S:7-T96US:V4@9&%T;W1E:V4B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I
M9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B3F%P8<2-;F$@;V)L:6MA
M(&1A='5M82(*"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,S`*;7-G
M:60@(F5D:70B"FUS9W-T<B`B57)E9&DB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM
M<V=S='(@(DYE(&YA:F1E;2!V;F5S96YI:"!P;V1A=&MO=B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS9VED(")F86QL
M:6YG(@IM<V=S='(@(E!A9&%V:6YE(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O
M0G)O=W-E<BYP:'`Z.3`S"FUS9VED(")F:6QE(@IM<V=S='(@(F1A=&]T96MA
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#8@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R(")I
M>B`E<R`H)7,I(&L@)7,@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C0T"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(F=O<W1I;2(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-3`*;7-G
M:60@(F@Z(@IM<V=S='(@(F@Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C,V,PIM<V=I9"`B:&@B"FUS9W-T<B`B:&@B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B
M:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B3F5Z;F%N;R!I;64@9V]S=&ET
M96QJ82(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(G1A:V]J
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R(")-960@=G)S=&EC86UI
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G
M:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R(")6:&]D;F$O:7IH;V1N
M82!N87!A:V$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B
M26YT97)N82!N87!A:V$@=B!P<F]G<F%M=2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T
M<B`B=G)S=&EC92(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES
M;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B
M;6MI<V]F<R!N87!A:V$@:V]D92`E9"P@;65D('!R:7!R879L:F%N:F5M($E3
M3RXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,S<T"FUS9VED(")M;2(*;7-G<W1R(")M;2(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,C@Q('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ-S0*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(T,PIM<V=I
M9"`B;F%M92(*;7-G<W1R(")I;64B"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP
M:'`Z,3(T"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B;FD@9&]K
M;V[$C6%N;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,3(R,`IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R("+%H64@
M;FD@<&]D<')T82(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`Y
M"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(D)E;&7%OFMA(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S0*;7-G:60@(G!E<FUI<W-I
M;VX@9&5N:65D(@IM<V=S='(@(D1O=F]L:F5N:F4@:F4@>F%V<FYJ96YO+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED
M(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B;F%P86MA('8@
M;V1D;&IE;F5M('!R;W1O:V]L=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C<U"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B=GIH
M86IA:F_$C64B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R(")397)V
M:7,@;FD@;F$@=F]L:F\N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HQ
M,#(*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B4&]K8<6^:2!R
M87IL:6ME(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R
M(")S;7,R96UA:6P@<')E:V\@2%144"(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HS.3$*;7-G:60@(G-S(@IM<V=S='(@(G-S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S0*
M;7-G:60@(G-T96%D>2(*;7-G<W1R(")3=&%B:6QN;R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T96T@97)R
M;W(B"FUS9W-T<B`B4VES=&5M<VMA(&YA<&%K82XB"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDS,PIM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@
M(E-E>FYA;2!O<')A=FEL+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R
M(")Z8<2-87-N82!O9'!O=F5D(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@9G)A
M;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,0IM<V=I9"`B='EP92!T
M:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R(")Z82!P;W1R
M9&ET978@=G1I<&MA:G1E(&=E<VQO(&1V86MR870B"@HC.B!A9&UI;B]S971U
M<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B
M=6YI9FEE9"(*;7-G<W1R(")E;F]T96XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]H;W)D92YP:'`Z,C<Y"B,L(&9U>GIY"FUS9VED(")U;FMN;W=N(&5R<F]R
M(@IM<V=S='(@(G!O:F%V:6QA('-E(&IE(&YA<&%K82(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T
M<B`B8G)E>B!I;65N82(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS
M9W-T<B`B27IB:7)A('5P;W)A8FYI:V$@(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R
M(")V($MA<G1I8V$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C0R"FUS9VED(")W.B(*;7-G<W1R(")W.B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*
M;7-G<W1R(")W96%T:&5R+F-O;2(*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]S=E]312YP;P``
M````````````````````````````````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`Q
M,3,Q,#<U`#$P-3$U-#,S-S4U`#`Q-S8V-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````C($AO<F1E(%-W961I<V@@=')A;G-L
M871I;VX*(R!#;W!Y<FEG:'0@*$,I(#(P,#(M,C`P-B!(;W)D92!0<F]J96-T
M"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI
M8V5N<V4@87,@=&AE($AO<F1E('!A8VMA9V4N"B,@2F]A<75I;2!(;VUR:6=H
M875S96X@/&IO:&]`=V5B8G!L871S96XN<V4^+"`R,#`V+@HC($%N9')E87,@
M1&%H;.EN(#QA;F1R96%S0&1A:&QE;BYW<SXL(#(P,#4N"B,*;7-G:60@(B(*
M;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,5QN(@HB
M4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*
M(E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`R+3$U(#$Q.C(Q*S`Q,#!<;B(*
M(E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,38@,#`Z,C8K,#$P,%QN(@HB
M3&%S="U4<F%N<VQA=&]R.B!*;V%Q=6EM($AO;7)I9VAA=7-E;B`\:F]H;T!W
M96)B<&QA='-E;BYS93Y<;B(*(DQA;F=U86=E+51E86TZ(%-W961I<V@@/&DQ
M.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*
M(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ
M7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$Q"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(B`F(S$U,3L@)7,@:7,@<F5A9'D@=&\@<&5R
M9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W
M+B(*;7-G<W1R("(B"B(@)B,Q-3$[("5S(&MO;6UE<B!A='0@=71F]G)A(&1E
M('5N9&5R:.5L;'-A:W1I=FET971E<FYA('-O;2!M87)K97)A=',@;F5D86XN
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C,W,PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@
M86=O*2(*;7-G<W1R("(@*"5S(&1A9V%R('-E9&%N*2(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,3,R-B!L:6(O2&]R9&4N<&AP.C$S-S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B`H
M<VYA8F)T86YG96YT("5S*2(*"B,Z('1E;7!L871E<R]L:6YK<R]L:6YK<RYI
M;F,Z-`IM<V=I9"`B("A296%D(&]N;'DI(@IM<V=S='(@(B`H4VMR:79S:WED
M9&%D*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S<@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(S.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E
M<R!D87ES*2(*;7-G<W1R("(@*&]M("5S(&1A9V%R*2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S-S,@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S<*
M;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B`H:61A9RDB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,S<U(&QI8B](;W)D92]&;W)M+G!H<#HR,S<Y
M"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@*&EM;W)G;VXI(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C,W-0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B`H:6?E<BDB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0U(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS-3`*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,Y-@IM<V=I9"`B(&%T("(*;7-G<W1R("(@:VP@(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,34@;&EB+U9&4R]S;6(N<&AP
M.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER
M96-T;W)Y+B(*;7-G<W1R("(G)7,G(.1R(&EN=&4@96X@:V%T86QO9RXB"@HC
M.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R(&QI8B](;W)D92]#3$DN<&AP
M.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L
M:60@8VAO:6-E+B(*;7-G<W1R("(G)7,G(.1R(&EN=&4@971T(&=O9&OD;G0@
M=F%L+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z
M-C4V"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`S
M.2!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C<Q,`HC.B!L:6(O2&]R9&4O4F5G
M:7-T<GDN<&AP.C$P.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES
M(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T
M<B`B)R5S)R#D<B!I;G1E(&MO;F9I9W5R97)A="!I($AO<F1E<F5G:7-T<F5R
M="XB"@HC.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$@;&EB+TAO<F1E
M+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E
M92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(E1RY&1H86YT97)A<F5N
M(&;V<B`E<R!S86MN87,N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U
M<',@<WES=&5M+B(*;7-G<W1R("(G)7,G(&QA9&5S('1I;&P@:2!G<G5P<'-Y
M<W1E;65T+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M
M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(B<E<R<@;&%D97,@=&EL;"!I(&)E
M:/9R:6=H971S<WES=&5M970N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(B<E<R<@
M<VMA<&%D97,@:6YT93H@)7,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-
M0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B4N,F9-0B!A;G;D;G0@878@
M)2XR9DU"('1I;&SE=&5T("@E,F8E)2DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C(V"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N
M9"`E<R(*;7-G<W1R("(E9"`E<R!O8V@@)7,B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C(V."!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HR
M-C@*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB
M"FUS9W-T<B`B1&ET="!L]G-E;F]R9"!U<'!H]G(@871T(&?D;&QA(&]M("5D
M(&1A9V%R+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@
M(B5D+61A9W-P<F]G;F]S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C8X('1E;7!L871E<R]M86EN=&5N86YC92]N;W1I8V5?=&]P+FEN8SHT"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S("T@
M1O9R(&OD;FYE9&]M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HW,#0@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B1FEN9V5R
M<')I;G0@9O9R("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#,R(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S
M-`HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#0Q(&QI8B](;W)D
M92]-24U%+T-O;G1E;G1S+G!H<#HX-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z-#D@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN
M8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A
M=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@56YD97)HY6QL<V9U
M;FMT:6]N("T@0F5K<N1F=&5L<V4B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B)7,@4V5T=7`B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8S(&QI8B](;W)D92]!=71H
M+U-I9VYU<"YP:'`Z,C8T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@
M57`B"FUS9W-T<B`B)7,@86YMY&QA;B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HU.2!T96UP;&%T97,O;6%I;G1E;F%N8V4O86=R965M96YT7W1O
M<"YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E
M96UE;G0B"FUS9W-T<B`B5&KD;G-T96%V=&%L(&;V<B`E<R(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-#(X(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-#DP"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C4Q(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$Y"B,Z(&QI8B]61E,O<VUB+G!H
M<#HT,S(@;&EB+U9&4R]S;6(N<&AP.C0Y-"!L:6(O5D93+V9T<"YP:'`Z-C@R
M"B,Z(&QI8B]61E,O9G1P+G!H<#HW-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B5S(&9I;FYS(')E9&%N+B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38V(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,C0V"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S4R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S(&ML("5S("5S
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HU,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&-A;F-E;&QE9"`E
M<RXB"FUS9W-T<B`B)7,@:&%R(&%N;G5L;&5R870@)7,N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT,C8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI960@=&\@82!F<F5E+V)U<WD@
M<F5Q=65S="XB"FUS9W-T<B`B)7,@:&%R('-V87)A="!PY2!E;B!B96?D<F%N
M(&]M(&EN9F]R;6%T:6]N(&%N9^5E;F1E(&QE9&EG+W5P<'1A9V5N+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3(T
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R97!L:65D('1O('1H92!I
M;G9I=&%T:6]N('1O("5S+B(*;7-G<W1R("(E<R!H87(@<W9A<F%T('#E(&EN
M8FIU9&%N('1I;&P@)7,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HT,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M:&%S('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B
M)7,@:&%R('-K:6-K870@9&EG(&EN9F]R;6%T:6]N(&]M(&QE9&EG+W5P<'1A
M9V5N+B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M
M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H
M92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R
M9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(B(*(B5S(&MO;6UE<B!A='0@
M=71F]G)A(&1E('5N9&5R:.5L;'-A:W1I=FET971E<FYA('-O;2!M87)K97)A
M=',@;F5D86XN($UA<FME<F$@(@HB9&4@86MT:79I=&5T97(@<V]M(&1U('9I
M;&P@=71F]G)A+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-#`@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(S-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B)7,@:W+D=G,B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU
M=&5S(@IM<V=S='(@(B5S(&UI;G5T97(B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(S(&QI8B](;W)D92]";&]C:R]#;VQL
M96-T:6]N+G!H<#HQ,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O
M=6YD+B(*;7-G<W1R("(E<R!S86MN87,N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I;VXN
M(@IM<V=S='(@(B5S(&5F=&5R9G+E9V%R(&EN9F]R;6%T:6]N(&]M(&[D<B!D
M=2#D<B!L961I9R]U<'!T86=E;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C4P.`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!R97%U97-T<R!Y;W5R('!R97-E;F-E(&%T("5S+B(*;7-G<W1R("(E
M<R!E9G1E<F9RY6=A<B!D:6X@;N1R=F%R;R!V:60@)7,N(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(E<R!T:6QL("5S(&%V("5S(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU
M,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(&%D9"!T;R`E
M<RXB"FUS9W-T<B`B)7,@=FEL;"!LY&=G82!T:6QL('1I;&P@)7,N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W
M87)E(&]F("5S+B(*;7-G<W1R("(E<R!V:6QL(&?V<F$@9&EG(&UE9'9E=&5N
M(&]M("5S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-3$X"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=I<VAE<R!T
M;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M871I;VX@86)O=70@)7,N(@IM
M<V=S='(@(B5S('9I;&P@97)HY6QL82!D96X@<V5N87-T92!I;F9O<FUA=&EO
M;F5N(&]M("5S+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(R
M(&QI8B](;W)D92]+;VQA8BYP:'`Z.3(V"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(D%D<F5S<V)O:R!F]G(@)7,B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ-"!L:6(O2&]R9&4O
M2V]L86(N<&AP.CDQ.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N
M9&%R(@IM<V=S='(@(DMA;&5N9&5R(&;V<B`E<R(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3`V(&QI8B](;W)D92]+;VQA8BYP:'`Z.3$P"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R(")!;G1E
M8VMN:6YG87(@9O9R("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,S`@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R(")5<'!G:69T97(@9O9R("5S
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O;6]B:6QE+G!H<#HY-@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VAT;6PN<&AP.C(W,B!L:6(O2&]R9&4O34E-12]6:65W97(O
M:'1M;"YP:'`Z,3(W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES
M(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E
M+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O
M9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O
M<FUA=&EO;BXB"FUS9W-T<B`B(@HB)7,Z($UE9&1E;&%N9&5T(&MA;G-K92!I
M;G1E(.1R(&9RY6X@9&5N('-O;2!D970@=F5R:V%R+B!687(@9O9R<VEK=&EG
M(&UE9"`B"B)A='0@9O9L:F$@;.1N:V%R(&5L;&5R('-K:6-K82!A=G/D;F1A
M<F5N('!E<G-O;FQI9R!I;F9O<FUA=&EO;BXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S4T(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS.3D*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B+"!S=&]R;6)Y87(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Y-2!L:6(O0FQO8VLO;65T87(N
M<&AP.C(P,`HC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B
M"FUS9W-T<B`B+"!S=&]R;6)Y87(@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(P.`HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R
M;VT@)7,@=&\@)7,B"FUS9W-T<B`B+"!V87)I97)A;F1E(&UE;&QA;B`E<R!O
M8V@@)7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y-"!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M,C@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<R
M,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`W,PHC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C$S,B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(Y-`HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C,T."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-S0X"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@
M=N1L:B`M+2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@
M2&]U<B!&;W)M870B"FUS9W-T<B`B,3(M=&EM;6%R<V9O<FUA="(*"B,Z(&QI
M8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS
M9W-T<B`B,C0M=&EM;6%R<V9O<FUA="(*"B,Z('1E;7!L871E<R]D871A+W1I
M;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"!T:6UM87(B
M"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y(&QI8B](;W)D92]5
M22]086=E<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(\1O9R
M96?E96YD92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(V"FUS9VED(")!
M(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN
M(@IM<V=S='(@(D5N(&1A=&%B87-K;W!P;&EN9R!K<N1V<R!F]G(@86MT=65L
M;'0@8FQO8VLN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C`@
M;&EB+TAO<F1E+G!H<#HQ-C(*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C
M8W5R<F5D(@IM<V=S='(@(D5T="!F871A;'0@9F5L(&AA<B!I;G1RY&9F870B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,C`@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y
M(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")%
M;B!P=6)L:6L@4$=0+6YY8VME;"!K<N1V<R!F]G(@871T(&MR>7!T97)A(&5T
M="!M961D96QA;F1E+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$Q-#4@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$V.`IM<V=I9"`B
M02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N
M960@;65S<V%G92XB"FUS9W-T<B`B16X@<'5B;&EK(%!'4"UN>6-K96P@:W+D
M=G,@9O9R(&%T="!V97)I9FEE<F$@971T('-I9VYE<F%T(&UE9&1E;&%N9&4N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`W-R!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#DY"FUS9VED("(B"B)!('!U8FQI8R!0
M1U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB
M16X@<'5B;&EK(&]C:"!P<FEV870@4$=0+6YY8VME;"!S86UT(&SV<V5N;W)D
M(&MRY'9S(&;V<B!A='0@9&5K<GEP=&5R82!E='0@(@HB;65D9&5L86YD92XB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY.34@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z,3`Q-@IM<V=I9"`B(@HB02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(D5N('!U
M8FQI:R!O8V@@<')I=F%T(%!'4"UN>6-K96P@<V%M="!L]G-E;F]R9"!K<N1V
M<R!F]G(@871T('-I9VYE<F$@971T("(*(FUE9&1E;&%N9&4N(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#4@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU,#8*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K
M97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B)%
M;B!P=6)L:6L@;V-H('!R:79A="!3+TU)344M;GEC:V5L('-A;70@;/9S96YO
M<F0@:W+D=G,@9O9R(&%T="!D96MR>7!T97)A("(*(F5T="!M961D96QA;F1E
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI
M8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T
M<B`B(@HB16X@<'5B;&EK(&]C:"!P<FEV870@4R]-24U%+6YY8VME;"!S86UT
M(&SV<V5N;W)D(&MRY'9S(&;V<B!A='0@<VEG;F5R82!E='0@(@HB;65D9&5L
M86YD92XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,V
M-"!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L
M:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E
M+B(*;7-G<W1R(")%;B!P=6)L:6L@4R]-24U%+6YY8VME;"!K<N1V<R!F]G(@
M871T(&MR>7!T97)A(&5T="!M961D96QA;F1E+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*
M;7-G<W1R(")&]G)M:61D86=S;6]L;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM
M<V=S='(@(DSD='0@9O9R;6ED9&%G<W)E9VXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G
M<W1R(")&]G)M:61D86=S<F5G;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@
M(D;V<FUI9&1A9W-S:W5R87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S
M='(@(D;V<FUI9&1A9W-S:W5R87(@;65D('-N]B(*"B,Z('1E;7!L871E<R]D
M871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R(")!32]032(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(P,`HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM
M<V=I9"`B05!)($E$(@IM<V=S='(@(D%022!)1"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H
M:7,@961I=&]R(@IM<V=S='(@(D]M(&5D:71O<FXB"@HC.B!S97)V:6-E<R]H
M96QP+VEN9&5X+G!H<#HU,PIM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B3VTN
M+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B0F]T=&5N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B
M06)S;6ED9&QE(@IM<V=S='(@(DUI='1E;B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C0P"FUS9VED(")!8V-E<'0@
M<F5Q=65S="(*;7-G<W1R(")!8V-E<'1E<F$@8F5GY')A;B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C@Q"FUS9VED
M(")!8V-E<'1E9"(*;7-G<W1R(")!8V-E<'1E<F%D(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C(W,"!L:6(O5D93+VUU<W%L+G!H<#HR-S`*
M;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B0F5H]G)I9VAE="!S86MN87,@871T('-K87!A(%9&4RUM87!P
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!F:6QE+B(*;7-G<W1R(")"96CV<FEG:&5T('-A:VYA<R!A='0@<VMA
M<&$@5D93+69I;"XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PIM<V=I
M9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")+;VYT;VEN9F]R;6%T
M:6]N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X"FUS9VED(")!8V-O
M=6YT(%!A<W-W;W)D(@IM<V=S='(@(DSV<V5N;W)D(&;V<B!K;VYT;R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M,PHC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I
M9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(DMO;G1O="!F<GES="(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S4*;7-G:60@(D%C8V]U;G1I
M;F<B"FUS9W-T<B`B0G5D9V5T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HT-3$*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HV,C4*;7-G:60@(D%C=&EO;G,B"FUS
M9W-T<B`BQ71GY')D97(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$T."!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T.`HC.B!T96UP;&%T
M97,O<&]R=&%L+V%D9"YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A
M9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R("),Y&=G('1I;&PB
M"@HC.B!T96UP;&%T97,O;&EN:W,O;&EN:W,N:6YC.C$S"B,L('!H<"UF;W)M
M870*;7-G:60@(D%D9"`E<R(*;7-G<W1R("),Y&=G('1I;&P@)7,B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I
M9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(DSD9V<@=&EL;"!U;F1E<F=R
M=7!P(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z.3@@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B
M061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B;.1G9R!T:6QL('5N9&5R
M8F5H]G)I9VAE="(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS
M9VED(")!9&0@2&5R93HB"FUS9W-T<B`B3.1G9R!T:6QL(&CD<CHB"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I
M9"`B061D($YE=R!'<F]U<"(*;7-G<W1R("),Y&=G('1I;&P@;GD@9W)U<'`B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z.#@*(SH@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HX-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@
M3F5W(%!E<FUI<W-I;VXB"FUS9W-T<B`B3.1G9R!T:6QL(&YY(&)E:/9R:6=H
M970B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW
M"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB
M)7-<(B(*;7-G<W1R("),Y&=G('1I;&P@=6YD97)G<G5P<"!T:6QL("<E<R<B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T-R!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@
M82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R("),Y&=G('1I
M;&P@=6YD97)B96CV<FEG:&5T('1I;&P@)R5S)R(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B3.1G9R!T
M:6QL(&5N(&YY(&%N=N1N9&%R93HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-3(Y"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HU-38*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B
M3.1G9R!T:6QL(&MO;'5M;B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z,S0*;7-G:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R("),
MY&=G('1I;&P@;GEA(&UE9&QE;6UA<B(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(DSD9V<@=&EL
M;"!P87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Q"B,L('!H<"UF
M;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED
M96)A<B(*;7-G<W1R("),Y&=G('1I;&P@;65N>6X@9O9R("5S('-O;2!-;WII
M;&QA(%-I9&5B87(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C8S,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C8S-PIM<V=I9"`B061D('1H:7,@=&\@;7D@8V%L
M96YD87(B"FUS9W-T<B`B3.1G9R!T:6QL(&D@;6EN(&MA;&5N9&5R(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D9"!T;R!A
M9&1R97-S(&)O;VLZ(@IM<V=S='(@(DSD9V<@=&EL;"!I(&%D<F5S<V)O:SHB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`IM<V=I9"`B061D
M('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R("),Y&=G('1I;&P@:2!M:6X@
M861R97-S8F]K(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U
M<V5R(@IM<V=S='(@(DSD9V<@=&EL;"!A;G;D;F1A<F4B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S
M7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA
M;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B"B),861E
M('1I;&P@)R5S)R!T:6QL('-Y<W1E;65T+"!M96X@:W5N9&4@:6YT92!LY&=G
M82!T:6QL(&5X=')A("!I;F9O<FUA=&EO;CH@)2(*(G,N(@H*(SH@<VEG;G5P
M+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@
M=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R("),861E
M('1I;&P@)R5S)R!T:6QL('-Y<W1E;65T+B!$=2!K86X@;&]G9V$@:6X@;G4N
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@
M(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B57!P;.1G9R!A
M=B!A;G;D;F1A<F4@Y'(@:6YA:W1I=F5R870N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T-#$*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#4@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ-S,*;7-G:60@(D%D9')E<W,B"FUS9W-T
M<B`B061R97-S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$T,0IM
M<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D%D<F5S<V)O:R(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT(&QI8B](;W)D
M92])34%0+T%#3"]R9F,T,S$T+G!H<#HU-@HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R
M;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(D%D;6EN:7-T<F%T
M:6]N("T@86YG92!B96CV<FEG:&5T(&;V<B!A;F1R82!A;G;D;F1A<F4B"@HC
M.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+VUE;G4N<&AP
M.C$Q,PHC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED
M(")!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A=&EO;B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#,*;7-G:60@(D%D<R(*;7-G
M<W1R(")296ML86TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S
M='(@(D%F9V%N:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T
M<B`B06QB86YI96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HW-`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B
M06QG97)I970B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3`W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R(")!;&EA<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@
M(D%L:6=N(@IM<V=S='(@(DIU<W1E<F$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM
M<V=S='(@(DIU<W1E<FEN9SHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.#<*;7-G:60@(D%L;"(*;7-G<W1R(")!;&QA(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HR,#<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR
M,#<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL
M($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B06QL82!A=71E;G1I<V5R
M861E(&%N=N1N9&%R92(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO
M9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B06QL
M82!G<G5P<&5R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U"B,Z(&QI
M8B](;W)D92]097)M<R]522YP:'`Z.3$@;&EB+TAO<F1E+U!E<FUS+V1A=&%T
M<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(D%L
M;&$@8F5H]G)I9VAE=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B
M"FUS9W-T<B`B06QL82!F>7)A('-I9&]R(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@W,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W-0IM<V=I9"`B
M06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(E1I;&SE="!F;&5R
M82!A9')E<W-E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S@*;7-G
M:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S
M='(@(E1I;&SE="!I;G-TY&QL;FEN9R!F]G(@<V]R=&5R860@;&ES=&$_(@H*
M(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T(&QI
M8B](;W)D92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E
M>&ES=',B"FUS9W-T<B`B1FEN;G,@<F5D86XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3(V"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G
M<W1R(")!;'1E<FYA=&EV($E-4U`M:6YL;V=G;FEN9R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,3$*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W
M;W)D(@IM<V=S='(@(D%L=&5R;F%T:79T(&SV<V5N;W)D(&;V<B!)35-0(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P,PIM<V=I9"`B06QT97)N871E
M($E-4U`@57-E<FYA;64B"FUS9W-T<B`B06QT97)N871I=G0@86YVY&YD87)N
M86UN(&;V<B!)35-0(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,S4*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(D%L
M=&5R;F%T:78@92UP;W-T(&%D<F5S<R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(D%L
M=&5R;F%T:78@;6%L;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E
M>'0Z(@IM<V=S='(@(D%L=&5R;F%T:78@=&5X=#HB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@
M(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(D%M97)I:V%N<VMA(%-A;6]A(@H*
M(SH@9G)A;65W;W)K+TQI;FMS+TQI;FMS+G!H<#HR-#<*(SH@9G)A;65W;W)K
M+U)E;&%T:6]N<VAI<"]296QA=&EO;G-H:7!-86YA9V5R+G!H<#HR-#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B06X@97)R;W(@;V-C=7)R960@9F]L;&]W:6YG
M('1H:7,@;&EN:SH@)7,B"FUS9W-T<B`B171T(&9E;"!U<'!S=&]D(&[D<B!L
MY&YK96X@*"5S*2!S:W5L;&4@86YVY&YD87,B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,3$U"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z.34@;&EB+TAO<F1E
M+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S
M('-P96-I9FEE9"XB"FUS9W-T<B`B171T(&9E;&%K=&EG="!VY')D92!A;F=A
M=G,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-0IM<V=I
M9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B171T
M(&]KY&YT(&9E;"!H87(@:6YT<N1F9F%T(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-2!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,38*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O
M<G)A(@IM<V=S='(@(D%N9&]R<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*
M;7-G<W1R(")!;F=O;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S
M='(@(D%N9W5I;&QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY
M;6]U<R!0<F]X>2(*;7-G<W1R(")!;F]N>6T@<')O>'DB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@
M(E-V87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4X(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-0HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B06YT
M87)K=&ES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3D*
M(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM
M<V=S='(@(D%N=&EG=6$@;V-H($)A<F)U9&$B"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-0HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO54DN<&AP.C4X(&QI8B](;W)D92]";&]C:R]522YP:'`Z
M-3@*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I
M9"`B07!P;&EC871I;VXB"FUS9W-T<B`B07!P;&EK871I;VXB"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B
M"FUS9W-T<B`B07!P;&EK871I;VYS;&ES=&$B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS
M9W-T<B`B07!P;&EK871I;VYE;B#D<B!K;&%R+B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R
M97,B"FUS9W-T<B`B5F5R:W-TY&QL('1I;&P@=6YD97)U=&1E;&YI;F=A<B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED
M(")!<'!R;W9E(@IM<V=S='(@(D=O9&OD;FXB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX,S(@;&EB+TAO<F1E+TU)344O0V]N=&5N
M=',N<&AP.C@T,0IM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R(")5
M;F=E9N1R;&EG('-T;W)L96LB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S@P"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,3<*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(F%P<FEL(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V
M*2(*;7-G<W1R(")!<F%B:7-K("A7:6YD;W=S+3$R-38I(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z.#$@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-3D*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C8@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*;7-G:60@(D%R8VAI
M=F4@1FEL92!3:7IE(@IM<V=S='(@(D%R:VEV9FEL<W1O<FQE:R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@P(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R87(N<&AP.C4X"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP
M.C8U(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<W"FUS9VED(")!
M<F-H:79E($YA;64B"FUS9W-T<B`B07)K:79F:6QN86UN(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H
M92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R("+$<B!D970@<^1K
M97)T(&%T="!D=2!V:6QL('1A(&)O<G0@8F5GY')A;B!F]G(@)7,_(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<
M(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R("+$<B!D970@<^1K
M97)T(&%T="!D=2!V:6QL(')A9&5R82`G)7,G(&]C:"!E=F5N='5E;&QA('5N
M9&5R9W)U<'!E<C\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R
M(")!<F=E;G1I;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B
M07)M86YI96XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B
M07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B07)M96YI<VL@*$%235-#
M24DM."DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R
M="(*;7-G<W1R(")+;VYS="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C,P"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T
M<B`B07)U8F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N
M9"(*;7-G<W1R(")!<V-E;G-I;VX@27-L86YD(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B07-C:6D@
M:V]N<W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!2
M96=I;VXB"FUS9W-T<B`B07-I96XO4W1I;&QA(&AA=G-R96=I;VYE;B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,CD*;7-G:60@(D%S:R!F;W(@8V]N
M9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS
M/R(*;7-G<W1R(")&<N5G82!E9G1E<B!B96MRY&9T96QS92!I;FYA;B!U;F1E
M<FCE;&QS86MT:79I=&5T97(@=71F]G)S/R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,3,@;&EB+TAO<F1E+T9O<FTN<&AP.C,P.3D*;7-G:60@
M(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R(")4:6QL9&5L;FEN9W-K;VQU
M;6XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C$V-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C(T.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C,Q.`IM<V=I9"`B071T86-H960@:7,@86X@:4-A;&5N9&%R
M(&9I;&4@<F5P;'D@=&\@82!R97%U97-T('EO=2!S96YT(@IM<V=S='(@(D)I
M9F]G860@Y'(@96X@:4-A;&5N9&5R(&9I;"!M960@971T('-V87(@<.4@96X@
M8F5GY')A;B!S;VT@9'4@<VMI8VMA="PB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G
M<F]U<"XB"FUS9W-T<B`B1O9R<_9K('1I;&P@871T(')A9&5R82!E;B!G<G5P
M<"!S;VT@:6YT92!F:6YN<RXB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+B(*;7-G<W1R(")&]G)S]FL@=&EL;"!A='0@<F%D97)A(&5N
M(&)E:/9R:6=H970@<V]M(&EN=&4@9FEN;G,N(@H*(SH@861M:6XO<&5R;7,O
M961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES
M=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")&]G)S]FL@871T(.1N9')A(&5N
M(&)E:/9R:6=H970@<V]M(&EN=&4@9FEN;G,N(@H*(SH@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM
M97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(D;V<G/V:R!A='0@Y&YD<F$@96X@
M=71D96QN:6YG('-O;2!I;G1E(&9I;FYS+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3<W"FUS9VED(")!='1E;F1E
M97,B"FUS9W-T<B`B1&5L=&%G87)E(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#8@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S$@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W1G>BYP:'`Z.#,*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T
M<B`B071T<FEB=70B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S@T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,C$*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P.2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*
M;7-G:60@(D%U9W5S="(*;7-G<W1R(")A=6=U<W1I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.2!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,CD*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED
M(")!=7-T<F%L:6$B"FUS9W-T<B`B075S=')A;&EE;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(X"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I
M9"`B075S=')I82(*;7-G<W1R("+6<W1E<G)I:V4B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X(&QI8B](;W)D92]!=71H+V-Y<G-Q
M;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G-Q;#H@24U!
M4"UE>'1E;G-I;VX@<V%K;F%S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C$S-2!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3,U"FUS
M9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER
M960@8V%P86)I;&ET97,N(@IM<V=S='(@(D%U=&A?8WER<W%L.B!+;W!P;&EN
M9V5N('-A:VYA<B!F=6YK=&EO;F5R('-O;2!K<N1V<RXB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(@;&EB+TAO<F1E+T%U=&@O8WER
M=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!)34%0
M+65X=&5N<VEO;B!S86MN87,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F
M='`N<&AP.C,V(&QI8B](;W)D92]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*
M(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@
M0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB
M"FUS9W-T<B`B075T:%]F='`Z($944"UT:6QLY&=G('-A:VYA<RX@2V]M<&EL
M97)A(%!(4"!M960@<W=I=&-H96X@+2UE;F%B;&4M9G1P+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C0@;&EB+TAO<F1E+T%U=&@O:6UA
M<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM87`Z($E-05`M97AT
M96YS:6]N('-A:VYA<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N
M<&AP.C4Q(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H
M7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B075T:%]K<F(U.B!K<F(U+65X=&5N<VEO;B!S86MN87,N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,#(@;&EB+TAO<F1E+T%U
M=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R
M<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S
M='(@(D%U=&A?;&1A<#H@1&5T(&?E<B!I;G1E(&%T="!LY&=G82!T:6QL(&%N
M=N1N9&%R92!I($%C=&EV92!$:7)E8W1O<GDB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C,U-R!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS
M-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U
M<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R(")!=71H7VQD
M87`Z($1E="!GY7(@:6YT92!A='0@<F%D97)A(&%N=N1N9&%R92!F<N5N($%C
M=&EV92!$:7)E8W1O<GDB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C8S(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H
M7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B075T:%]L9&%P.B!,1$%0+71I;&SD9V<@<V%K;F%S+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,Y(&QI8B](;W)D92]!=71H
M+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z
M(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@(@IM<V=S='(@(D%U=&A?;&1A<#H@2V%N(&EN=&4@;.1G9V$@
M=&EL;"!A;G;D;F1A<F4@)R5S)RX@4V5R=F5R;B!S=F%R861E.B`B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-2!L:6(O2&]R9&4O075T
M:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P
M.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P
M.B!+86X@:6YT92!R861E<F$@86YVY&YD87)E("5S(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HT.3D@;&EB+TAO<F1E+T%U=&@O;&1A<"YP
M:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE
M('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@2V%N(&EN
M=&4@=7!P9&%T97)A(&%N=N1N9&%R92`E<R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z-#`U(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C0P
M-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R(")!=71H7VQD
M87`Z($1E="!GY7(@:6YT92!A='0@=7!P9&%T97)A(&%N=N1N9&%R92!I($%C
M=&EV92!$:7)E8W1O<GDN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L
M+G!H<#HT-B!L:6(O2&]R9&4O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T
M:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%U=&A?;6-A;#H@34-!3"UE>'1E;G-I;VX@<V%K;F%S+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV,"!L:6(O2&]R9&4O075T
M:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M
M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]S;6)A
M=71H.B!S;6)A=71H+65X=&5N<VEO;B!S86MN87,N(@H*(SH@;&EB+TAO<F1E
M+TE-05`O061M:6XN<&AP.C$P-@IM<V=I9"`B075T:&5N=&EC871I;VX@870@
M24U!4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")!=71E;G1I<V5R:6YG('1I
M;&P@24U!4"US97)V97(@;6ES<VQY8VMA9&5S+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC
M871I;VX@9F%I;&5D(@IM<V=S='(@(D%U=&5N=&ES97)I;F<@;6ES<VQY8VMA
M9&5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z-S8*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HV-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H
M<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS
M9W-T<B`B075T96YT:7-E<FEN9R!M:7-S;'EC:V%D97,N("5S(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-B!L:6(O2&]R9&4O075T
M:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T
M960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`B075T96YT:7-E<FEN9R!A
M=G9I<V%D97,@878@4D%$2553+7-E<G9E<FXN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HX-3$@;&EB+U9&4R]F='`N<&AP.C@X,@IM<V=I9"`B
M075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@
M(D%U=&5N=&ES97)I;F<@=&EL;"!&5%`M<V5R=F5R(&UI<W-L>6-K861E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P(&QI8B]61E,O<VUB
M+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V
M97(@9F%I;&5D+B(*;7-G<W1R(")!=71E;G1I<V5R:6YG('1I;&P@4TU"+7-E
M<G9E<B!M:7-S;'EC:V%D97,N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B5&EL
M;&?D;F=L:6=A(&;D;'0Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HV,30*;7-G:60@(D%W86ET:6YG(%)E<W!O;G-E
M(@IM<V=S='(@(E;D;G1A<B!PY2!S=F%R(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.2!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,S$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R
M8F%I:F%N(@IM<V=S='(@(D%Z97)B86EJ86XB"@HC.B!C;VYF:6<O=&AE;65S
M+V%Z=7(N<&AP.C@*;7-G:60@(D%Z=7(B"FUS9W-T<B`B07IU<F)LY2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S
M(@IM<V=S='(@(D)/1D@M=7)SY&MT97(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O
M=6YD(@IM<V=S='(@(D)A:V=R=6YD(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO
M<B(*;7-G<W1R(")"86MG<G5N9'-FY')G(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]K<F(U+G!H<#HX,2!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX,0IM
M<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R(")&96QA:W1I
M9W0@;/9S96YO<F0@9O9R($ME<F)E<F]S(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]K<F(U+G!H<#HX,R!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX,PIM
M<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R(")&96QA:W1I
M9W0@86YVY&YD87)N86UN(&;V<B!+97)B97)O<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C0U"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B
M0F%H86UA<R(*;7-G<W1R(")"86AA;6%S(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,2!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,S@*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"86AR
M86EN(@IM<V=S='(@(D)A:')A:6XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X,`IM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B0F%L
M=&ES:R`H25-/+3@X-3DM,3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,"!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,S0*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(X
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H
M(@IM<V=S='(@(D)A;F=L861E<V@B"@HC.B!L:6(O0FQO8VLO8F%R=&EM92YP
M:'`Z-`IM<V=I9"`B0F%R(%1I;64B"FUS9W-T<B`B0F%R=&ED(@H*(SH@;&EB
M+T)L;V-K+V)A<G1I;64N<&AP.C,U"FUS9VED(")"87(@=&EM92(*;7-G<W1R
M(")2861T:60B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8P(&QI8B](;W)D92].3%,O=&QD+G!H<#HS
M,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(D)A
M<F)A9&]S(@H*(SH@8V]N9FEG+W1H96UE<R]B87)B:64N<&AP.C8*;7-G:60@
M(D)A<F)I92(*;7-G<W1R(")"87)B:64B"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D
M:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B0F%S:V%T86QO
M9R`G)7,G(&;V<B!B:6QD97(@:&ET=&%D97,@:6YT92XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@
M(D)A<V5L:6YE(@IM<V=S='(@(D)A<VQI;FIE(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,R!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-#D*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C,P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"
M96QA<G5S(@IM<V=S='(@(E9I=')Y<W-L86YD(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,"!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,S4*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C,Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"
M96QG:75M(@IM<V=S='(@(D)E;&=I96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HU,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&EZ
M92(*;7-G<W1R(")"96QI>F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HT,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM<V=S
M='(@(D)E;FEN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-#$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,T(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM<V=S='(@(D)E
M<FUU9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8S(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-@HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R(")":'5T86XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED
M(")":7)T:&1A>2(*;7-G<W1R(")&]F1E;'-E9&%G(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U,B!L:6(O2&]R9&4O0FQO
M8VLO0V]L;&5C=&EO;BYP:'`Z,S8P"B,L('!H<"UF;W)M870*;7-G:60@(D)L
M;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R(")";&]C:R`G)7,G(&;V<B!A<'!L:6MA=&EO;B`G)7,G('-A:VYA
M<RXB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3`*;7-G:60@
M(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(D)L;V-K:6YS=.1L;&YI;F=A<B(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO
M8VL@5'EP92(*;7-G<W1R(")";&]C:W1Y<"(*"B,Z(&-O;F9I9R]T:&5M97,O
M8FQU96UO;VXN<&AP.C8*;7-G:60@(D)L=64@36]O;B(*;7-G<W1R(")";.4@
M;>5N92(*"B,Z(&-O;F9I9R]T:&5M97,O8FQU97=H:71E+G!H<#HV"FUS9VED
M(")";'5E(&%N9"!7:&ET92(*;7-G<W1R(")";.5T="!O8V@@=FET="(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I
M9"`B0F]L9"(*;7-G<W1R(")&970B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HT,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B
M"FUS9W-T<B`B0F]L:79I82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,#<*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R(")";VMMY')K96XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(P"FUS9VED(")";W)D97(B"FUS9W-T<B`B4F%M(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R
M('1H:6-K;F5S<SHB"FUS9W-T<B`B4F%M8G)E9&0Z(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B
M0F]R9&5R<R(*;7-G<W1R(")286UA<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C,R"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HS-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA
M(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R(")";W-N:65N(&]C:"!(97)Z96=O
M=FEN82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T
M:"(*;7-G<W1R(")"Y61A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-#@*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,X(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G
M<W1R(")";W1S=V%N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(D)O
M='1E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C,@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0W"B,Z
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS.2!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R(")"
M;W5V970@27-L86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-#0*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0P(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B
M0G)A<VEL:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Q-PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C
M96%N(%1E<G)I=&]R>2(*;7-G<W1R(")"<FET=&ES:V$@=&5R<FET;W)I970@
M:2!);F1I<VMA(&]C96%N96XB"@HC.B!C;VYF:6<O=&AE;65S+V)R;W=N+G!H
M<#HV"FUS9VED(")"<F]W;B(*;7-G<W1R(")"<G5N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C0R(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED
M(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R(")"<G5N96DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Q(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-PHC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*
M;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(D)U;&=A<FEE;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U
M;&QE=&5D($QI<W0B"FUS9W-T<B`B4'5N:W1L:7-T82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,V"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HT-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(D)U<FMI;F$@1F%S;R(*"B,Z(&-O
M;F9I9R]T:&5M97,O8G5R;G1O<F%N9V4N<&AP.CD*;7-G:60@(D)U<FYT($]R
M86YG92(*;7-G<W1R(")"<N1N9"!/<F%N9V4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HS.0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U
M<G5N9&DB"FUS9W-T<B`B0G5R=6YD:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-#8*;7-G:60@(D--4R(*;7-G<W1R(")#35,B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B0U)#
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(D-23"!$:7-T<FEB
M=71I;VX@4&]I;G1S(@IM<V=S='(@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@
M(D-?96QL(&EN<W3D;&QN:6YG87(N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,34Q"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M
M<&QE=&5D+B(*;7-G<W1R(")#86-H96EN:71I97)I;F<@Y'(@:6YT92!F=6QL
M<W3D;F1I9RXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#4Y"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT.#4@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-#`*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$U-PIM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B
M2V%L96YD97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U
M"FUS9VED(")#86QM(@IM<V=S='(@(DQU9VYT(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$R.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@
M(D-A;6)O9&EA(@IM<V=S='(@(DMA;6)O9&IA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-R!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-C`*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C0W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#
M86UE<F]O;B(*;7-G<W1R(")+86UE<G5N(@H*(SH@8V]N9FEG+W1H96UE<R]C
M86UO=69L86=E+G!H<#HV"FUS9VED(")#86UO=69L86=E(@IM<V=S='(@(DMA
M;6]U9FQA9V4B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM
M<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C
M;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B2V%N(&EN=&4@
M;F]L;'-TY&QL82!L]G-E;F]R9"!A=71O;6%T:7-K="P@:V]N=&%K=&$@9&EN
M(&%D;6EN:7-T<F%T]G(N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z,S$X(&QI8B]&:6QE+T-35BYP:'`Z,S4P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B2V%N
M(&EN=&4@<VMR:79A('1I;&P@9FEL("<E<R<B"@HC.B!A9&UI;B]S97-S:6]N
M<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S
M<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B1&5T(&?E<B!I;G1E(&%T="!A9&UI
M;FES=')E<F$@97AT97)N82!S97-S:6]N<VAA;G1E<F%R92XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)S<6PN<&AP.C,Q.0HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP
M:'`Z,C,U(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S
M(@IM<V=S='(@(DMA;B!I;G1E(&MO;G1A:W1A($E-05`M<V5R=F5R;CH@)7,B
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT,3,@;&EB+T9I;&4O
M0U-6+G!H<#HT-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EN=&4@]G!P;F$@9FEL("<E<R<B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8T(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,0HC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G<W1R(")+86YA9&$B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R(")!=F)R>70B"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N
M8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(D%V8G)Y="!P<F]B;&5M<F%P
M<&]R="(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$X(&QI8B]6
M1E,O9G1P+G!H<#HS,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E
M;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EN=&4@<F%D97)A("<E
M<R<N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP
M:'`Z-3(*(SH@9G)A;65W;W)K+U9&4U])4T\O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C0W"B,Z(&9R86UE=V]R:R]61E-?25-/+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3,*(SH@;&EB
M+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*
M(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O
M<GDN(@IM<V=S='(@(DMA;B!I;G1E(&AI='1A(&5N('1E;7!RY'(@;6%P<"XB
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.CDQ
M(&9R86UE=V]R:R]61E-?25-/+TE33U=R:71E<BYP:'`Z.3<*(SH@;&EB+U9&
M4R])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H
M;W5T("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(DMA;B!I;G1E
M(&9O<G1SY'1T82!U=&%N("=MY6QF:6PG+7!A<F%M971E<BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q-"!L:6(O5D93+V9T<"YP:'`Z,S$Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y
M(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EN=&4@<F%D97)A(&UA<'`@)R5S)RXB
M"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964N<&AP.C$R."!F<F%M
M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV.#`*(SH@;&EB+TAO
M<F1E+T1A=&%4<F5E+G!H<#HQ,C@@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP
M:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D
M(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R(")+86X@:6YT92!R861E<F$[("5D
M(&)A<FX@97AI<W1E<F%R+B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A
M5')E92]S<6PN<&AP.C8P."!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HV
M,#@*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE
M<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@
M(@HB<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S
M86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(DMA;B!I;G1E(&1I
M<FEG97)A(&UE9&1E;&%N9&4@=&EL;"!A;F=I=F5T(&YU;6UE<BXB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8X(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-0HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#D@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B2V%P(%9E<F1E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R(")2=6)R:6LB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0@;&EB+TYE="]3
M35,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T
M<B`B3W!E<F%T]G(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,*;7-G
M:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R(")+871E9V]R:65R
M(&]C:"!R=6)R:6ME<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,S4*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4P(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#87EM86X@27-L86YD
M<R(*;7-G<W1R(")#87EM86X@27-L86YD<R(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T
M<B`B36]B:6QT96QE9F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S
M(@IM<V=S='(@(D-E;&QI;G-TY&QL;FEN9V%R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D
M9&EN9SHB"FUS9W-T<B`B0V5L;'5T9GEL;&YA9#HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#
M96QL('!R;W!E<G1I97,B"FUS9W-T<B`B0V5L;&EN<W3D;&QN:6YG87(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM
M<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R(")#96QL;65L;&%N<G5M.B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S0@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$R-S@*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R(")-;V)I;'1E
M;&5F;VXB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0V5L
M=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B0V5L=&ES:R`H25-/+3@X-3DM
M,30I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(D-E;G1R97)A9"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C4@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4T"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,2!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S
M='(@(D-E;G1R86QA9G)I:V%N<VMA(')E<'5B;&EK96XB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/
M+3@X-3DM,BDB"FUS9W-T<B`B0V5N=')A;&5U<F]P96ES:R`H25-/+3@X-3DM
M,BDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Y.2!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A
M=&4@1&5T86EL<R(*;7-G<W1R(")#97)T:69I:V%T9&5T86QJ97(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,2!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C8Q,@IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B
M"FUS9W-T<B`B0V5R=&EF:6MA=.1G87)E(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.38@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU.3<*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(D-E
M<G1I9FEK871P;VQI8VEE<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P."!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C(Q"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU
M,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS
M9W-T<B`B5&-H860B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C4Y-@IM<V=I9"`B0VAA:7(@4&5R<V]N(@IM<V=S='(@
M(D]R9&;V<F%N9&4B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N
M9V4B"FUS9W-T<B`BQ&YD<F$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,S$*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@
M(L1N9')A(&1I='0@;/9S96YO<F0B"@HC.B!T96UP;&%T97,O<')E9G,O8VAA
M;F=E9&5F875L=&ED96YT:71Y+FEN8SHQ,PIM<V=I9"`B0VAA;F=E(&1E9F%U
M;'0@:61E;G1I='DB"FUS9W-T<B`BQ&YD<F$@9O9R=F%L9"!I9&5N=&ET970B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-CD*;7-G:60@(B(*(D-H86YG
M92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T
M:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R
M("(B"B+$;F1R82!N86UN(&]C:"!A9')E<W,@<V]M(&UO='1A9V%R;F$@<V5R
M(&[D<B!D92!LY'-E<B!O8V@@<W9A<F%R('#E(&1I;F$@(@HB;65D9&5L86YD
M96XN(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED
M("(B"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@
M=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(D%T="!B>71A(&SV<V5N
M;W)D('-T]F1S(&EN=&4@;65D(&1E;B!N=79A<F%N9&4@:V]N9FEG=7)A=&EO
M;F5N+B`@5F%R(&=O9"`B"B)K;VYT86MT82!A9&UI;FES=')A=/9R96XN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR-PIM<V=I9"`B0VAA<B(*;7-G<W1R(")4:VXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@
M(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(DMO;G1R;VQL97)A(&SD;FLN+BXB
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$S
M"FUS9VED(")#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO
M=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R(")-87)K
M97)A(&1E(&%K=&EV:71E=&5R(&1U('9I;&P@=71F]G)A(&YU+B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4Y"B,Z(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HU,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M-PIM<V=I9"`B0VAI;&4B"FUS9W-T<B`B0VAI;&4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HV,0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-30@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@
M(D-H:6YA(@IM<V=S='(@(DMI;F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X,PIM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S
M='(@(DMI;F5S:7-K="!F]G)E;FML870@*$=",C,Q,BDB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H
M0FEG-2DB"FUS9W-T<B`B2VEN97-I<VMT('1R861I=&EO;F5L;'0@*$)I9S4I
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-PIM<V=I9"`B0VAO;W-E
M($%P<&QI8V%T:6]N.B(*;7-G<W1R(")6Y&QJ(&%P<&QI:V%T:6]N.B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD@;&EB+TAO<F1E
M+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D
M(@IM<V=S='(@(E;D;&H@;/9S96YO<F0B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z,C8X(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z
M,C8Y"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R(")6Y&QJ(&%N
M=N1N9&%R;F%M;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-#4R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-C(V"FUS9VED(")#:&]O<V4@86X@86-T:6]N.B(*
M;7-G<W1R(")6Y&QJ(.5T9^1R9#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S`R"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM
M<V=S='(@(E;D;&H@:'5R(&1A='5M('-K86QL('9I<V%S.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*
M;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI
M<W1S*2(*;7-G<W1R(")6Y&QJ(&QI<W1S=&EL("AF]G(@<V]R=&5R861E(&QI
M<W1O<BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8X(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-@HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-34@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T
M<B`B2G5L]FXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z.#DT(&QI8B]61E,N<&AP.CDQ-`HC.B!L
M:6(O3F5T+U--4RYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S
M(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R(")+;&%S<V1E
M9FEN:71I;VX@9O9R("5S('-A:VYA<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B0VQE87(B"FUS9W-T<B`B
M4F5N<V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(E)E
M;G-A($U33V9F:6-E+71A9V=A<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,C@*;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@(E)E;G-A(&9RY6=A(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(E)E;G-A
M(&%N=N1N9&%R93H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A
M<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B4F5N<V$@86YV
MY&1N87)E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*
M;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R(")296YS82!A;G;D;F1A
M<F1A=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R(")396YA<F4@=7!P
M:VQA<FYA;F1E(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VYO=&EC95]B
M;W1T;VTN:6YC.C8*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA
M;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@
M(DML:6-K82!F]G(@871T(&9O<G1SY'1T82(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V
M:6$@2%144"(*;7-G<W1R(")#;&EC:V%T96QL('9I82!(5%10(@H*(SH@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B4W3D;F<@9O9N
M<W1E<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Q"FUS9VED(")#;&]U
M9',B"FUS9W-T<B`B36]L;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B
M5&ED:6=A(&UO;&XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(DUO;&YI;F=T(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3(*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C4V(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R
M(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*"B,Z('1E;7!L871E<R]P;W)T
M86PO<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS
M9W-T<B`B2V]M<')I;65R82!S:61O9N1L=&5T(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L
M;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B2V]M<')I;65R861E(')A;6%R(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C(*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C4W(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8W"FUS9VED(")#;VQO;6)I82(*;7-G<W1R(")+;VQO;6)I82(*"B,Z
M(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R(")&Y')G(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R,PHC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(T"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-S4@;&EB+TAO<F1E+T)L
M;V-K+T-O;&QE8W1I;VXN<&AP.C,S,0HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L
M;&5C=&EO;BYP:'`Z,S,R(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HU,#,*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ
M-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT
M.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU
M,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV
M-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV
M-@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX
M,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX
M,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(D;D<F=H86YT97)A<F4B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#0V(&QI8B](;W)D92]&
M;W)M+G!H<#HR.#,R"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@
M(D;D<F=V86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B2V]L=6UN97(Z(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3DU,`IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R(")+;VQU
M;6X@<G5B<FEK97(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8V
M"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B3'5S=&EG:&5T97(B"@HC.B!A9&UI
M;B]C;61S:&5L;"YP:'`Z,C4*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B2V]M
M;6%N9&\B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA
M;F0@4VAE;&PB"FUS9W-T<B`B2V]M;6%N9&]F]FYS=&5R(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#`R(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R(")+;VUM96YT87(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B0V]M;6]N($YA;64B
M"FUS9W-T<B`B3F%M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,S`*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4X(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S
M='(@(D-O;6]R;W,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C,Y"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(D;V<F5T86<B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8Y-PIM
M<V=I9"`B0V]M<&QE=&5D(@IM<V=S='(@(E-L=71F]G)D(@H*(SH@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R86UE
M=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F<F%M
M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@9G)A
M;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC.B!F
M<F%M97=O<FLO5&5X="]497AT+T9I;'1E<B]E;6%I;',N<&AP.C@R"B,Z(&9R
M86UE=V]R:R]497AT+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.#@*(SH@9G)A
M;65W;W)K+U1E>'0O5&5X="]&:6QT97(O96UA:6QS+G!H<#HY.`HC.B!F<F%M
M97=O<FLO5&5X="]497AT+T9I;'1E<B]E;6%I;',N<&AP.C$P,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;VUP;W-E($UE<W-A9V4@*"5S*2(*;7-G<W1R(")3
M:W)I=B!M961D96QA;F1E("@E<RDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R(")$871O<F5R(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-@IM<V=I9"`B0V]N9&ET
M:6]N(@IM<V=S='(@(E;D9&5R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-38*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B5N1D97(B"@HC.B!A9&UI
M;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F
M97)E;F-E<R(*;7-G<W1R(")+;VYF:6=U<F%T:6]N<W-K:6QL;F%D97(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED(")#;VYF:6=U<F%T
M:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U
M=&QO;VLN(@IM<V=S='(@(B(*(DEN<W3D;&QN:6YG87(@9O9R(&%T="!S>6YK
M<F]N:7-E<F$@;65D(&AA;F1D871O<F5R+"!S;6%R=&$@=&5L969O;F5R(&]C
M:"`B"B)/=71L;V]K(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM
M<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B
M2V]N9FEG=7)A=&EO;B!B96CV=F5R('5P<&1A=&5R87,N(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF
M:6=U<F4@)7,B"FUS9W-T<B`B2V]N9FEG=7)E<F$@)7,B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A
M<W-W;W)D(@IM<V=S='(@(D)E:W+D9G1A(&SV<V5N;W)D(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-34*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C4Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS
M9VED(")#;VYG;R(*;7-G<W1R(")+;VYG;R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C4S"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N
M9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R(")+
M;VYG;R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M,3`@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`X"FUS9VED(")#;VYN96-T
M:6]N(&9A:6QE9"XB"FUS9W-T<B`B1O9R8FEN9&5L<V4@;6ES<VQY8VMA9&5S
M+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y
M.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`X"FUS9VED(")#;VYN96-T:6]N
M(&9A:6QE9#H@(@IM<V=S='(@(D;V<F)I;F1E;'-E(&UI<W-L>6-K861E<SH@
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S<Y(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U
M<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")&]G)B:6YD
M96QS92!M960@<'5B;&EK(&YY8VME;'-E<G9E<B!N96MA9&5S+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<X,2!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO
M;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S
M("@E<RDB"FUS9W-T<B`B1O9R8FEN9&5L<V4@;65D('!U8FQI:R!N>6-K96QS
M97)V97(@;F5K861E<SH@)7,@*"5S*2(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.#0U(&QI8B]61E,O9G1P+G!H<#HX-S8*;7-G:60@(D-O;FYE
M8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(D;V<F)I;F1E
M;'-E(&UE9"!&5%`M<V5R=F5R(&UI<W-L>6-K861E<RXB"@HC.B!C;VYF:6<O
M:&]O:W,N<&AP+F1I<W0Z,3`V-PIM<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`B
M2V]N=&%K=&5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C4S(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*
M;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO
M=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")+;VYT86MT97(@;&%D97,@=&EL
M;"!I(&1I;B!A9')E<W-B;VLN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W1G>BYP:'`Z-C`*;7-G:60@(D-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D
M(&9I;&4Z("(*;7-G<W1R("));FYE:.5L;'-T>7`@9O9R(&MO;7!R:6UE<F%D
M(&9I;#H@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HU-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8P"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-38*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+WII<"YP:'`Z-C,@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB
M(@IM<V=S='(@(DEN;F5HY6QL(&D@)R5S)R(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS
M,PIM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B1F]R='/D='0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8V(&QI8B](;W)D92].3%,O=&QD+G!H<#HU.`HC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*
M;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R(")#;V]K($ES;&%N9',B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G
M<W1R(")#;V]K:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B2V]P
M:65R82(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8X(&QI8B]6
M1E,O<VUB+G!H<#HT-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL
M960Z("5S(@IM<V=S='(@(DMO<&EE<FEN9R!M:7-S;'EC:V%D97,Z("5S(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM
M<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B2V]P:65R82!M87)K97)I
M;F<B"@HC.B!C;VYF:6<O=&AE;65S+V-O<FYF;&]W97(N<&AP.C8*;7-G:60@
M(D-O<FYF;&]W97(B"FUS9W-T<B`B36%J<V)L;VUM82(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3DU(&QI8B].970O4TU3+W=I;E]H
M='1P+G!H<#HQ-S`*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$Y-0IM
M<V=I9"`B0V]S="!)1"(*;7-G<W1R(")+;W-T;F%D<RU)1"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8S"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM
M<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R(")#;W-T82!2:6-A(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3<*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C8S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V
M"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(D5L9F5N8F5N<VMU<W1E
M;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU-@IM<V=I
M9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(DMA
M;B!I;G1E(%!'4"UK<GEP=&5R82!M961D96QA;F1E+B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R
M>7!T(&UE<W-A9V4Z("(*;7-G<W1R(")+86X@:6YT92!01U`M:W)Y<'1E<F$@
M;65D9&5L86YD93H@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3`S,PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N(@IM
M<V=S='(@(DMA;B!I;G1E(%!'4"US:6=N97)A(&UE9&1E;&%N9&4N(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`U-0IM<V=I9"`B0V]U;&0@;F]T
M(%!'4"!S:6=N(&UE<W-A9V4Z("(*;7-G<W1R(")+86X@:6YT92!01U`M<VEG
M;F5R82!M961D96QA;F1E.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C,Y,R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM
M<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S
M='(@(DMA;B!I;G1E(%,O34E-12UK<GEP=&5R82!M961D96QA;F1E+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%
M('-I9VX@;65S<V%G92XB"FUS9W-T<B`B2V%N(&EN=&4@4R]-24U%+7-I9VYE
M<F$@;65D9&5L86YD92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C$X-`HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A
M9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B2V%N(&EN=&4@;.1G9V$@=&EL;"!K
M;VYT86MT+B`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HY-B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$R,0HC.B!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z.38@;&EB+TAO<F1E+T%U=&@O;&1A<"YP
M:'`Z,3(Q"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*;7-G:60@(D-O
M=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")-:7-S;'EC
M:V%D97,@871T(&MO;G1A:W1A($Q$05`@<V5R=F5R+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R(")+86X@:6YT
M92!V97)I9FEE<F$@:V]N=&]S86QD;RX@)7,B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-#0Q"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0
M('-E<G9E<BXB"FUS9W-T<B`B2W5N9&4@:6YT92!A;G-L=71A('1I;&P@3$1!
M4"US97)V97(N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<
M(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R(")+86X@:6YT92!K;VYT86MT
M82!S97)V97(@)R5S)R!V:6$@1E10.B`E<R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`B2V%N(&EN=&4@<VMA<&$@9&ES=')I8G5T:6]N<VQI<W1A+B`E<R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,#4*;7-G:60@(D-O
M=6QD(&YO="!D96-R>7!T(%!'4"!D871A+B(*;7-G<W1R(")+86X@:6YT92!D
M96MR>7!T97)A(%!'4"UD871A+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C$Q,C@*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B`B
M"FUS9W-T<B`B2V%N(&EN=&4@9&5K<GEP=&5R82!01U`M9&%T83H@(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C(@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU,C,*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T
M(%,O34E-12!D871A+B(*;7-G<W1R(")+86X@:6YT92!D96MR>7!T97)A(%,O
M34E-12UD871A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,C0V"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T
M92!C;VYT86-T+B`E<R(*;7-G<W1R(")+86X@:6YT92!R861E<F$@:V]N=&%K
M="X@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C,U-@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DMA;B!I;G1E(')A9&5R82!D
M:7-T<FEB=71I;VYS;&ES=&$N("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T
M92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(DMA;B!I
M;G1E(')A9&5R82!U<'!G<F%D97)I;F=S<V-R:7!T('1I;&PZ("5S+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.CDS.`HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C,X,2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G
M:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I
M;"!A9&1R97-S+B(*;7-G<W1R(")+86X@:6YT92!B97-TY&UM82!M;W1T86=A
M<F5N<R!E4&]S="UA9')E<W,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L
M971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B2V%N(&EN=&4@:.1M=&$@:V]M
M<&QE='0@861R97-S8F]K+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T
M92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B2V%N(&EN=&4@:.1M=&$@
M:V]M<&QE='0@9&ES=')I8G5T:6]N<VQI<W1A+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F
M971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N
M(@IM<V=S='(@(DMA;B!I;G1E(&CD;71A(&MO;7!L971T(&QI<W1A(/9V97(@
M9&ES=')I8G5T:6]N<VQI<W1O<BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDN<&AP.C@T"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713
M=')A=&5G>2YP:'`Z-C@*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDN<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EN=&4@;&%D
M9&$@<W1R871E9VD@)R5S)RXB"@HC.B!F<F%M97=O<FLO5D937TE33R])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.0HC.B!F<F%M97=O<FLO
M5D937TE33R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@U"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y("<E
M<R<N(@IM<V=S='(@(DMA;B!I;G1E(&QA9&1A('-T<F%T96=I("<E<R<N(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z
M,S`*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z,3$P"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(DMA;B!I;G1E('-K87!A(&UA
M<'`@)R5S)RXB"@HC.B!F<F%M97=O<FLO5D937TE33R])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$Q"B,Z(&9R86UE=V]R:R]61E-?
M25-/+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@)R5S)RXB
M"FUS9W-T<B`B2V%N(&EN=&4@<VMA<&$@;6%P<"`G)7,G+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<P."!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME
M>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(DMA;B!I;G1E(&CD;71A
M('!U8FQI:R!N>6-K96P@9G+E;B!N>6-K96QS97)V97)N+B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HQ,SD*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B2V%N
M(&EN=&4@]G!P;F$@)R5S)R!F]G(@<VMR:79I;F<N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS-#4@;&EB+TYE="]335,O=VEN7VAT='`N<&AP
M.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB
M"FUS9W-T<B`B2V%N(&EN=&4@]G!P;F$@)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T\O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`G)7,G(&9O
M<B!W<FET:6YG+B(*;7-G<W1R(")+86X@:6YT92#V<'!N82`G)7,G(&;V<B!S
M:W)I=FEN9RXB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C0Q."!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C0R,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]4
M87-K(&UO9'5L92`E<R(*;7-G<W1R(")+86X@:6YT92#V<'!N82!-86EN=&5N
M86YC95]487-K(&UO9'5L("5S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C
M=&]R>2!<(B5S7"(N(@IM<V=S='(@(DMA;B!I;G1E(/9P<&YA(&UA<'!E;B`G
M)7,G(@H*(SH@9G)A;65W;W)K+U9&4U])4T\O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`G)7,G+B(*;7-G<W1R(")+86X@:6YT
M92#V<'!N82!M87!P("<E<R<B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ
M-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(S-R!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV.3D*(SH@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$Q,2!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z,30T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HR,S<@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!L:6(O2&]R9&4O1W)O
M=7`O;&1A<"YP:'`Z-3$V(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV,3(*
M(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8U-B!L:6(O2&]R9&4O1W)O
M=7`O;&1A<"YP:'`Z-CDY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$
M05`@<V5R=F5R+B(*;7-G<W1R(")+86X@:6YT92!K;VYT86MT82!,1$%0('-E
M<G9E<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S."!L
M:6(O5D93+T]B:F5C="YP:'`Z,C0P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R96%D("5S+B(*;7-G<W1R(")+86X@:6YT92!LY'-A("5S+B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#
M;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D
M('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@
M8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB
M1&5T(&=I8VL@:6YT92!A='0@Y71E<G-TY&QL82!L]G-E;F]R9&5T(&;V<B!D
M96X@86YG:79N82!A;G;D;F1A<F5N+B!.Y6=O;B`B"B)E;&QE<B!NY6=R82!A
M=B!U<'!G:69T97)N82#D<B!I;G1E(&MO<G)E:W1A+B!&]G)S]FL@:6=E;B!E
M;&QE<B!K;VYT86MT82`B"B)A9&UI;FES=')A=/9R96X@;VT@9'4@8F5H]G9E
M<B!H:N1L<"XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS,#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S0P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,W-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M.#,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#<*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,S."!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S<U"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS.#$@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X
M-PIM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R(")+86X@
M:6YT92!HY&UT82!!0TPB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C(W-`HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R
M971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(DMA;B!I;G1E(&CD
M;71A(&%D<F5S<V)O:RX@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B2V%N
M(&EN=&4@:.1M=&$@9&ES=')I8G5T:6]N<VQI<W1A+B`E<R(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M<RX@)7,B"FUS9W-T<B`B2V%N(&EN=&4@:.1M=&$@9&ES=')I8G5T:6]N<VQI
M<W1O<BX@)7,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(R,R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3<@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C(R,0IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R(")+86X@:6YT92!H
MY&UT82!D<V5R=F5R9G5N:W1I;VYE<B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B2V%N(&EN=&4@Y71E<G-TY&QL82!K;VYF:6=U<F%T:6]N
M96XN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(DMA
M;B!I;G1E(')A9&5R82!M87!P("<E<R<N(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T\O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDU"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B`G)7,G+B(*;7-G
M<W1R(")+86X@:6YT92!R861E<F$@;6%P<"`G)7,G+B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DMA;B!I;G1E
M('-P87)A(&MO;F9I9W5R871I;VX@9O9R("5S+B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G
M<W1R(")+86X@:6YT92!S<&%R82!B86-K=7`M:V]N9FEG=7)A=&EO;BXB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*
M;7-G<W1R(")+86X@:6YT92!S<&%R82!E;B!B86-K=7`M:V]N9FEG=7)A=&EO
M;CH@)7,N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EN=&4@<W!A<F$@=7!P
M9W)A9&5R:6YG<W-C<FEP="!T:6QL.B`E<RXB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S
M879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R
M(")+86X@:6YT92!S<&%R82!B86-K=7`M:V]N9FEG=7)A=&EO;B`E<RXB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@
M=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@
M=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*(DMA;B!I;G1E('-P
M87)A(&MO;F9I9W5R871I;VYS9FEL96X@)7,N($1U(&MA;B!A;G1I;F=E;B!A
M;G;D;F1A(&5N(&%V("(*(F%L=&5R;F%T:79E;B!A='0@<W!A<F$@:V]D96X@
M=&EL;"`E<R!E;&QE<B!K;W!I97)A(&MO9&5N(&YE9&%N('1I;&P@)7,N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,@;&EB+TAO<F1E
M+T%U=&@O;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H
M92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B2V%N(&EN=&4@<_9K82!I($Q$05`M
M:V%T86QO9V5N+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC.B!L:6(O5D93
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS
M9W-T<B`B2V%N(&EN=&4@<F%D97)A("<E<R<N(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T\O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@W
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@)R5S)RXB
M"FUS9W-T<B`B2V%N(&EN=&4@<F%D97)A("<E<R<N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(DMA
M;B!I;G1E('5P<&1A=&5R82!K;VYT86MT+B`E<R(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS
M9W-T<B`B2V%N(&EN=&4@=7!P9&%T97)A(&1I<W1R:6)U=&EO;G-L:7-T82X@
M)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB
M)7-<(CH@)7,B"FUS9W-T<B`B2V%N(&EN=&$@<W!A<F$@:V]N9FEG=7)A=&EO
M;B!F]G(@)R5S)SH@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<P
M"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA
M:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R(")+86X@:6YT
M92!H:71T82!-;WII;&QA<R!S:61O9N1L="X@5F5R:69I97)A(&%T="!S:61O
M9N1L=&5T(.1R(/9P<&5T+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$U-"!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@
M=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD
M97(@7"(E<UPB.B`E<R(*;7-G<W1R(")+86X@:6YT92!G92!A;G;D;F1A<F5N
M("<E<R<@86YG:79N82!RY'1T:6=H971E<B!T:6QL(&UA<'!E;B`G)7,G.B`E
M<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3D@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$T,C,*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R(")2
MY&MN860@=&5X="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-38Y(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")#
M;W5N=')Y(@IM<V=S='(@(DQA;F0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C<U"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(DMU<G-E<B(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(E-K87!A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X
M"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(E-K87!A(&SD;FLB"@HC
M.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS9VED
M(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(E-K87!A(&YY(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S0S,30N<&AP.C4R"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM
M<V=S='(@(E-K87!A('5N9&5R;6%P<"(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,C0P(&QI8B](;W)D92]097)M<R]522YP:'`Z,C0P"FUS
M9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(D)E:/9R:6=H971E
M<B!F]G(@Y&=A<F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,P
M(&QI8B](;W)D92]&;W)M+G!H<#HS,C$V"FUS9VED(")#<F5D:70@8V%R9"!N
M=6UB97(B"FUS9W-T<B`B2W)E9&ET:V]R='-N=6UM97(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M.2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Y"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HV-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM
M<V=I9"`B0W)O871I82(*;7-G<W1R(")+<F]A=&EE;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8T"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HV-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I
M9"`B0W5B82(*;7-G<W1R(")+=6)A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@(D%K='5E;&QA
M(#0@9F%S97(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*;7-G:60@(D-U
M<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`B06MT=65L;"!S97-S:6]N(@H*(SH@
M;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS
M9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B06MT=65L;"!T:60B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(D%K='5E;&P@55),
M(.1R(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"FUS9VED(")#=7)R96YT
M(%5S97)S(@IM<V=S='(@(D%K=&EV82!A;G;D;F1A<F4B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(U"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T
M<B`B06MT=65L;'0@=N1D97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C8T"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@
M(D%K='5E;&QA('9I;&QK;W(Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS
M9W-T<B`B06MT=65L;"!S=&EL(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@
M<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(E-K<N1D9&%R<WD@86MT
M:79I=&5T97(@<V]M(&OV<G,@=FED(&EN;&]G;FEN9R!T:6QL("5S+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(DML:7!P('5T(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T
M('-E;&5C=&EO;B(*;7-G<W1R(")+;&EP<"!U<G9A;"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8W"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HV-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I
M9"`B0WEP<G5S(@IM<V=S='(@(D-Y<&5R;B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@U"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R(")+
M>7)I;&QI<VL@*$M/23@M4BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M-@IM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B2WER
M:6QL:7-K("A7:6YD;W=S+3$R-3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#<*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G
M<W1R(")+>7)I;&QI<VLO56MR86EN<VL@*$M/23@M52DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HV.`HC.B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G
M:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(E1J96-K:65N(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R-@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4R('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")$1"(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#`@;&EB+TAO<F1E+T9O<FTN<&AP.C,R
M-S8*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N
M=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E
M+G!H<#HU.2!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$
M86EL>2(*;7-G<W1R(")$86=L:6<B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z
M-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B1&%T851R964@
M8FSD9&1R87)E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W."!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S(W-`IM<V=I9"`B1&%T86)A<V4@3&]O:W5P
M(@IM<V=S='(@(D1A=&%B87-U<'!S;&%G(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,SDY"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#`R(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R"FUS9VED(")$871E(@IM<V=S
M='(@(D1A='5M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B1&%T=6T@;6]T
M=&%G970B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`W(&QI8B](
M;W)D92]&;W)M+G!H<#HR-SDS"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G
M<W1R(")$871U;79A;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.#$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B
M1&%Y(@IM<V=S='(@(D1A9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU
M;6XB"FUS9W-T<B`B7U)A9&5R82!K;VQU;6XB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@X"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,C4*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#4Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(F1E8V5M
M8F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@
M(D1E8VEM86QE<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-C@U"FUS9VED(")$96-L:6YE9"(*;7-G<W1R(")!=F+V
M:G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B36EN<VMA(&EN
M9')A9R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI
M8B]P<F5F<RYP:'`Z,3$W"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3@W
M"FUS9VED(")$969A=6QT(@IM<V=S='(@(D;V<G9A;'0B"@HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PIM<V=I9"`B1&5F
M875L="!#;VQO<B(*;7-G<W1R(")&]G)V86QD(&;D<F<B"@HC.B!F<F%M97=O
M<FLO261E;G1I='DO261E;G1I='DN<&AP.CDQ(&QI8B](;W)D92])9&5N=&ET
M>2YP:'`Z.38*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B1O9R
M=F%L9"!I9&5N=&ET970B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*
M;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B1O9R=F%L="!S:V%L(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N
M<R(*;7-G<W1R(")$969I;FET:6]N97(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8T,PIM<V=I9"`B1&5L96=A=&4@
M<&]S:71I;VXB"FUS9W-T<B`B1&5L96=E<F$@<&]S:71I;VXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8Y,PIM<V=I
M9"`B1&5L96=A=&5D(@IM<V=S='(@(D1E;&5G97)A9"(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-S$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HT,SD*(SH@9G)A;65W;W)K+TQI;FMS+TQI;FMS
M+G!H<#HR-C,*(SH@9G)A;65W;W)K+U)E;&%T:6]N<VAI<"]296QA=&EO;G-H
M:7!-86YA9V5R+G!H<#HR-3@@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C8*(SH@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C(@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C<S('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R(")2861E
M<F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S(*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(E)A9&5R
M82!C96QL(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S
M+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R(")2861E<F$@
M9W)U<'`B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*;7-G
M:60@(D1E;&5T92!,;V<B"FUS9W-T<B`B4F%D97)A(&QO9V<B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,3`Q"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-S<@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T92!097)M
M:7-S:6]N(@IM<V=S='(@(E)A9&5R82!B96CV<FEG:&5T(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E
M(&UE<W-A9V5S(@IM<V=S='(@(E)A9&5R82!O8V@@<F5N<V$@;65D9&5L86YD
M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4W"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R(")2861E<F$@
M8V5L;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B4F%D
M97)A(&MO;'5M;B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED
M(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@
M(E)A9&5R82!B969I;G1L:6<@86QT97)N871I=FUA;&PB"@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-30*;7-G:60@(D1E;&5T92!M97-S
M86=E<R(*;7-G<W1R(")2861E<F%D92!M961D96QA;F1E;B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(Q(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S
M:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(E)A9&5R82!B96CV<FEG:&5T(&;V
M<B`G)7,G(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M
M<&5R;6ES<VEO;G,_(@IM<V=S='(@(E)A9&5R82!B96CV<FEG:&5T(&;V<B`G
M)7,G(&]C:"!U;F1E<F)E:/9R:6=H971E<C\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE
M=&4@<F]W(@IM<V=S='(@(E)A9&5R82!R860B"@HC.B!T96UP;&%T97,O<')E
M9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T
M960@:61E;G1I='DB"FUS9W-T<B`B4F%D97)A('9A;&0@:61E;G1I=&5T(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4S"FUS9VED(")$
M96QE=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B4F%D97)A('5N9&5R;6%P<&%R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8W"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM
M<V=S='(@(E)A9&5R82!A:W1U96QL(&MO;'5M;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B
M1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R(")2861E<F$@86MT=65L
M;"!R860B"@HC.B!F<F%M97=O<FLO3&EN:W,O3&EN:W,N<&AP.C(V,PHC.B!F
M<F%M97=O<FLO4F5L871I;VYS:&EP+U)E;&%T:6]N<VAI<$UA;F%G97(N<&AP
M.C(U.`IM<V=I9"`B1&5L971E('1H:7,@;&EN:R(*;7-G<W1R(")2861E<F$@
M9&5N(&CD<B!LY&YK96XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@
M<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B4F%D97)A9&4@=7!P9W)A9&5R:6YG
M<W-C<FEP=&5T("<E<R<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PHC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU.34*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,C$@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*
M;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B3&5V97)A;G-T:60B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Y(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,0HC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B1&%N;6%R:R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C0R"FUS
M9VED(")$96YY(')E<75E<W0B"FUS9W-T<B`B079S;.4@8F5GY')A;B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#<Q
M"FUS9VED(")$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA=&EO
M;B(*;7-G<W1R(")!=G-LY2!B96?D<F%N(&]M(&QE9&EG+W5P<'1A9V5N+6EN
M9F]R;6%T:6]N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(D)E<VMR
M:78@<')O8FQE;65T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HU-C4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY-#(@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I
M;VXB"FUS9W-T<B`B0F5S:W)I=FYI;F<B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C$Y-2!L:6(O2&]R9&4N<&AP.C$Y-PIM<V=I9"`B1&5T86EL
M<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R(")$971A;&IE
M<B`H;V-K<^4@:2!(;W)D97,@;&]G9V9I;"DZ(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ.3D@;&EB+TAO<F1E+G!H<#HR,#$*;7-G:60@(D1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(D1E=&%L:F5R(&AA<B!L;V=G871S(&;V<B!S>7-T96UA9&UI
M;FES=')A=/9R96XN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R
M,0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B571V96-K;&EN9R(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C(T"FUS9VED(")$97<@4&]I;G0B"FUS
M9W-T<B`B1&%G9W!U;FMT(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#$*
M;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B1&%G
M9W!U;FMT(&;V<B!S96YA<W1E('1I;6UE;CH@(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Q-@IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T
M<B`B1&%G9W!U;FMT.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H
M="(*;7-G<W1R(")2:6MT;FEN9R!VY&YS=&5R('1I;&P@:/9G97(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED
M(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R(")2:6MT;FEN9R!H
M]F=E<B!T:6QL(';D;G-T97(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(DMA=&%L;V<B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C<P"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@
M=&EM97,_(@IM<V=S='(@(E9I<V$@,C0M=&EM;6%R<R!K;&]C:V$_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,`IM<V=I9"`B1&ES<&QA>2!/<'1I
M;VYS(@IM<V=S='(@(E9I<VYI;F=S:6YS=.1L;&YI;F=A<B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HX.0IM<V=I9"`B1&ES<&QA>2!D971A
M:6QE9"!F;W)E8V%S="(*;7-G<W1R(")6:7-A(&1E=&%L:F5R860@9O9R=71S
MY&=E;'-E(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HY,@IM<V=I9"`B1&ES
M<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R(")6:7-A(&;V<G5T<^1G96QS
M92`H5$%&*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3<@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(X,#,*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM
M<V=S='(@(E9I<VYI;F=S9F]R;6%T(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-1$XN<&AP.C$Y,"!L:6(O2&]R9&4O34E-12]-1$XN<&AP.C$Y,0IM<V=I
M9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]D:79I9&5R+G!H<#HT(&QI8B]";&]C:R]D:79I9&5R+G!H<#HT
M-0IM<V=I9"`B1&EV:61E<B(*;7-G<W1R(")!=G-K:6QJ87)E(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S`*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C8Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y
M"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R(")$:FEB;W5T:2(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z-#(R"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(E)A9&5R
M82!I;G1E(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED
M(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G
M<W1R(")!;G;D;F0@:6YT92!M86EN=&5N86YC92YP:'`@9&ER96MT(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT
M86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB
M"FUS9W-T<B`B26YN96CE;&QE<B!F]G)S=&$@<F%D96X@9N1L=&YA;6YE;C\@
M3VT@)VIA)RP@;6%R:V5R82!HY'(Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-S(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C<P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HW,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI
M8R(*;7-G<W1R(")$;VUI;FEK86YS:V$@<F5P=6)L:6ME;B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@
M86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B2&%R(&1U(&EN9V5T(&MO;G1O
M/R!296=I<W1R97)A(&1I9RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX-#,@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@U
M,@IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B2.1M=&$B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#,@;&EB+TAO<F1E+TU)344O
M0V]N=&5N=',N<&AP.C@U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A
M9"`E<R(*;7-G<W1R(")(Y&UT82`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(DCD;71A(&=E;F5R97)A9"!K
M;VYF:6=U<F%T:6]N('-O;2!02%`M<VMR:7!T+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q,#<@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,3$*;7-G
M:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(D1R;W!P;&ES=&$B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@
M(D1R;V=E<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0P
M,B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D4M36%I;"(*
M;7-G<W1R(")%+7!O<W0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N
M97)I8U]S;71P+G!H<#HY,B!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP
M.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C
M87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B
M(@HB1')I=G)U=&EN(&;V<B!%+7!O<W0@=&EL;"!335,M8G)Y9V=A.R!F]G(@
M;W!E<F%T]G)E<B!S;VT@=&EL;&AA;F1A:.5L;&5R("(*(F1E;FYA('1JY&YS
M="XB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.C,T"B,Z(&QI8B](;W)D92].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@
M(D9%3"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S`@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<U"B,Z
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R(")%:W5A9&]R
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@;&EB+TAO<F1E
M+U!E<FUS+G!H<#HS,C4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS
M-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z.3(@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,34*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ.#$*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C<R"FUS9VED(")%9&ET(@IM<V=S='(@(L1N9')A(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU,"!L:6(O2&]R9&4O0FQO8VLO
M54DN<&AP.C4P"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@(L1N9')A(&)L
M;V-K(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H
M<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`BQ&YD<F$@9W)U<'`B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,3`P"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z-S8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D
M:70@4&5R;6ES<VEO;B(*;7-G<W1R("+$;F1R82!B96CV<FEG:&5T(@H*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M
M:7-S:6]N<R(*;7-G<W1R("+$;F1R82!B96CV<FEG:&5T97(B"@HC.B!S97)V
M:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(L1N9')A(&)E:/9R
M:6=H971E<B!F]G(@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU
M"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R("+$;F1R82!I;G-T
MY&QL;FEN9V%R(&;V<CHB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C,V-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T
M<B`BQ&YD<F$@8F5H]G)I9VAE=&5R(&;V<B`G)7,G(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET
M('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("+$;F1R82!B96CV<FEG:&5T
M97(@9O9R("<E<R<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G
M:60@(D5D=6-A=&EO;B(*;7-G<W1R(")5=&)I;&1N:6YG(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S<*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C<S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS
M9VED(")%9WEP="(*;7-G<W1R(")%9WEP=&5N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,3<*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C<T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PIM<V=I
M9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B16P@4V%L=F%D;W(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*
M;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B16QE;65N="XN+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED
M(")%;2(*;7-G<W1R(")%;2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V
M.0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W,R!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(R-`IM<V=I9"`B16UA:6PB"FUS9W-T<B`B12UP
M;W-T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C4@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C8*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,"!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C8X"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D4M
M<&]S=&%D<F5S<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C,@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-C<*;7-G:60@(D5M86EL(&%D9')E<W-E
M<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")%+7!O<W1A9')E<W-E<B!MY7-T92!S
M=.1M;6$@]G9E<G)E;G,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3DX.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DY,PIM<V=I9"`B16UA:6P@=VET
M:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B12UP;W-T;65D9&5L86YD92!M960@
M8F5K<N1F=&5L<V4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I
M8U]S;71P+G!H<#HY,2!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ
M"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A>2(*;7-G<W1R(")%+7!O<W0@
M=&EL;"!335,M8G)Y9V=A(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(X,0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,CDY"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T<B`B2^1N<VQO
M:6MO;F5R(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`R"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`R"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R(")4;VUT(&UE
M9&1E;&%N9&4N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C$U,"!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,C0S"B,Z
M(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT.#0@;&EB+TAO<F1E+T=R;W5P
M+VQD87`N<&AP.C8V,@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-S`U
M(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S
M=6QT+B(*;7-G<W1R(")4;VUT(')E<W5L=&%T+B(*"B,Z(&9R86UE=V]R:R]3
M44PO4U%,+TME>7=O<F1S+G!H<#HQ,3,@;&EB+TAO<F1E+U-13"]+97EW;W)D
M<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B
M5&]M="!S]FMK<FET97)I82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M-#<*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO
M=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,C(*;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C
M;VYT97AT(&UE;G4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#0X"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-34S"FUS9VED(")%;F0B"FUS
M9W-T<B`B4VQU="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.3@@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,0HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C4Y,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y-PIM<V=I9"`B16YD
M('EE87(B"FUS9W-T<B`B4VQU="#E<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R
M(@IM<V=S='(@(D;V<G-T;W)A(&5D:71O<B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,C0*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I
M;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S
M970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O
M9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N
M=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R(")!;F=E('/V:W;D9R`H
M55),*2!T:6QL(&)I;&1E;B!HY'(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.#8S"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HX.3(*;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E
M;&]W.B(*;7-G<W1R(")32W)I=B!B;VMS=.1V97)N82!N961A;CHB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<V(&QI8B](;W)D92].3%,O=&QD+G!H<#HY.0HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<Y"B,Z(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HW-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M,0IM<V=I9"`B17)I=')E82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W
M"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H
M<#HR-PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+U9I97<N<&AP.CDT(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT.`HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,V"FUS9VED(")%<G)O<B(*;7-G<W1R(")&96PB"@HC.B!F<F%M
M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,R!L:6(O2&]R9&4O5&5M
M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A
M=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B1F5L('9I9"!S:V%P86YD92!A=B!B
M;&]C:SH@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO
M<CH@)7,B"FUS9W-T<B`B1F5L('9I9"!R861E<FEN9R!A=B!S>6YK<F]N:7-E
M<FEN9W-MY')K93H@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC
M(&QO9SH@)7,B"FUS9W-T<B`B1F5L('9I9"!R861E<FEN9R!A=B!S>6YK<F]N
M:7-E<FEN9W-L;V=G.B`E<R(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP
M;&%T92YP:'`Z-#8X(&QI8B](;W)D92]496UP;&%T92YP:'`Z-#8X"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS
M9W-T<B`B1F5L(&[D<B!I;FYE:.5L(&CD;71A9&5S.B`E<R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3DU"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,C<X"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,S0W
M"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('-E;F1I;F<@<F5P;'DZ("5S
M+B(*;7-G<W1R(")&96P@=6YD97(@<^1N9&YI;F<@878@<W9A<G-M961D96QA
M;F1E.B`E<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@
M)7,B"FUS9W-T<B`B1F5L('9I9"!U<'!D871E<FEN9R!A=B!L]G-E;F]R9#H@
M)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#4*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC.B!L:6(O5D93+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(D9E;"!V
M:60@<VMR:79N:6YG("<E<R<N(@H*(SH@9G)A;65W;W)K+U9&4U])4T\O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG("<E<R<N(@IM<V=S='(@(D9E
M;"!V:60@<VMR:79N:6YG(&%V("<E<R<N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,"!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-S8*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C<W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O
M;FEA(@IM<V=S='(@(D5S=&QA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HX,0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA
M(@IM<V=S='(@(D5T:6]P:65N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B171N:7-K(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B175R;W!A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,T,PIM<V=I9"`B179E<GD@,34@;6EN=71E
M<R(*;7-G<W1R(")687(@,34Z92!M:6YU="(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.3,*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R(")6
M87)A;FYA;B!M:6YU="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B179E<GD@,S`@<V5C
M;VYD<R(*;7-G<W1R(")687(@,S`Z92!S96MU;F0B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S0R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.30*;7-G
M:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")687(@-3IE(&UI;G5T(@H*
M(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HV,"!L
M:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I
M;B(*;7-G<W1R(")687)J92!I;FQO9V=N:6YG(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T-`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@
M(E9A<FIE(&AA;'9T:6UM92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,@IM<V=I9"`B179E<GD@;6EN
M=71E(@IM<V=S='(@(E9A<FIE(&UI;G5T(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R
M(")%>&5M<&5L('#E(';D<F1E;CHB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z
M.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,C<*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B2_9R(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#<U(&QI8B](;W)D92]";&]C:R],
M87EO=70N<&AP.C0W-0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C8Q-`IM<V=I9"`B17AP86YD(@IM<V=S='(@(D5X<&%N9&5R82(*
M"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X
M<&%N9"!3:61E8F%R(@IM<V=S='(@(D5X<&%N9&5R82!S:61O9N1L="(*"B,Z
M(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-C@@;&EB+TAO<F1E
M+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS
M9W-T<B`B1O9R=N1N=&%D92`G*2<B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+
M97EW;W)D<RYP:'`Z,3<U(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$W
M-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@
M=&5R;2(*;7-G<W1R(")&]G)VY&YT861E(&5N<VMI;'0@;W)D(&5L;&5R(&-I
M=&5R870@<_9K8F5G<F5P<"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0P,2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@
M(D5X<&ER871I;VX@1&%T92(*;7-G<W1R(")&]G)F86QL;V1A='5M(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S8@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV-S<*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@
M(D5X<&]N96YT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B1O9R
M9W)U;F1S9N1R9R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G
M:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B3&%D9&$@=7!P(&MO
M;F9I9W5R871I;VX@=FEA($944"XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O<W%L+G!H<#HR,38@;&EB+TAO<F1E+U!R969S+W-Q;"YP:'`Z,C(U"FUS
M9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B
M36ES<VQY8VMA9&5S(&%T="!HY&UT82!I;G-TY&QL;FEN9V%R+B(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.CDX"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H
M<#HW-2!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D
M('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DUI<W-L>6-K
M861E<R!A='0@:V]N=&%K=&$@3$1!4"!S97)V97(N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S;6(N<&AP.CDX(&QI8B](;W)D92]!=71H+W-M8BYP:'`Z
M.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM
M<V=S='(@(DUI<W-L>6-K861E<R!A='0@:V]N=&%K=&$@4TU"('-E<G9E<BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X-B!L:6(O5D93+V9T
M<"YP:'`Z-S$W"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y
M(&9R;VT@7"(E<UPB+B(*;7-G<W1R(")-:7-S;'EC:V%D97,@871T(&MO<&EE
M<F$@9G+E;B`G)7,G+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M-CDQ(&QI8B]61E,O9G1P+G!H<#HW,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R(")-:7-S;'EC:V%D
M97,@871T(&MO<&EE<F$@=&EL;"`G)7,G+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<V%S;"YP:'`Z.#<@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z.#<*
M;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB
M"FUS9W-T<B`B36ES<VQY8VMA9&5S(&%T="!S:V%P82!N>2!305-,+6;V<F)I
M;F1E;'-E+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DW(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(T"B,Z(&QI8B]61E,O<VUB+G!H
M<#HU,#$@;&EB+U9&4R]F='`N<&AP.C<U-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(DUI<W-L>6-K
M861E<R!A='0@9FQY='1A('1I;&P@)R5S)RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C0V,2!L:6(O5D93+W-M8BYP:'`Z-#8U"B,L('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B
M36ES<VQY8VMA9&5S(&%T="!HY&UT83H@)7,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R
M(")"<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<R(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-`HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I
M;F%S*2(*;7-G<W1R(")&86QK;&%N9'/V87)N82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C@V"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B
M1F%R;V4@27-L86YD<R(*;7-G<W1R(")&Y'+V87)N82(*"B,Z(&9R86UE=V]R
M:R]#3$DO0TQ)+G!H<#HR,S@@;&EB+TAO<F1E+T-,22YP:'`Z,C,X"FUS9VED
M(")&871A;"!%<G)O<CHB"FUS9W-T<B`B1F%T86QT(&9E;#HB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS
M9W-T<B`B1F%X(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U,0IM
M<V=I9"`B1F%X97,B"FUS9W-T<B`B1F%X87(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<X"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,34*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P,R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(F9E8G)U
M87)I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C<*;7-G:60@(D9E96QS
M($QI:V4B"FUS9W-T<B`B2^1N;G,@<V]M(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(R,`IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@
M(DOD;FYS('-O;3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(D;E=&%L
M:6=A('-K=7)A<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(D;E
M=&%L:6=A('-N]G-K=7)A<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Y-#0@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-#@*;7-G:60@(D9I96QD(&UA
M=')I>"(*;7-G<W1R(")&Y&QT;6%T<FES(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S,S,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,R.0IM<V=I9"`B
M1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B1FEG;&5T($-!4%1#2$$B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,W(&QI8B](;W)D92]&;W)M+G!H
M<#HS,S,S"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R(")&:6=L971T>7!S
M;FET="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S(@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@S"B,Z
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,2!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G<W1R(")&:6II(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")&:6QE(@IM
M<V=S='(@(D9I;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV
M-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8P"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8W(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S
M(&9I;&4B"FUS9W-T<B`B06YT86P@9FEL97(Z("5S(&9I;"(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HV-`HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@R(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M87(N<&AP.C8P"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W
M(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(D%N=&%L
M(&9I;&5R.B`E<R!F:6QE<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,#D*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R(")&:6QH86YT97)A
M<F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8S
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-2!L:6(O2&]R9&4O
M34E-12]6:65W97(O<F%R+G!H<#HV,PHC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O>FEP+G!H<#HW,"!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX
M,@IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(D9I;&YA;6XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3DU(&QI8B](;W)D92]&;W)M+G!H<#HR
M.3@Q"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R(")&:6QV86PB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#@V(&QI8B](;W)D92]&;W)M
M+G!H<#HQ-#DP"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R(")&:6QU<'!L
M861D;FEN9R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U
M-"!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3`R"FUS9VED(")&:6QE('5P;&]A
M9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B1FEL=7!P;&%D9&YI;F<@<W3V
M9',@:6YT92XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3$*;7-G
M:60@(D9I;'1E<G,B"FUS9W-T<B`B1FEL=&5R(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,2!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.#(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C@R(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&
M:6YL86YD(@IM<V=S='(@(D9I;FQA;F0B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,38V"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(D;V<G-T82!H86QV
M86XB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN
M<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(D;V<G-T82!K
M=F%R=&5N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(S.0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C4W"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Q-`HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,R"FUS9VED(")&;&EP(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,S0@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P-PHC.B!L:6(O5D93+W-Q
M;"YP:'`Z,C,W(&QI8B]61E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B36%P
M<"`E<R!E>&ES=&5R87(@:6YT92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S
M='(@(D9O;G1FY')G(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS
M9VED(")&;V]D(@IM<V=S='(@(DUA="(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R
M(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B
M1O9R('=E8F)LY'-A<F4@<V]M(&EN=&4@<W3V9&5R(&)I;&1E<B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S0Q"FUS9VED(")&;W)E8V%S="`H5$%&*2(*
M;7-G<W1R(")0<F]G;F]S("A4048I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C<R"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H
M870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD
M(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I
M;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*(D%N=&%L(&1A9V%R(&;V<B!P
M<F]G;F]S("AV87)J92!D86<@8F5T>61E<B!E;B!P<F]G;F]S(&;V<B!D86<@
M;V-H(&5N(&;V<B`B"B)N871T*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T
M<B`B1VSV;70@9&ET="!L]G-E;F]R9#\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#8T"FUS9VED(")&;W)M<R(*;7-G<W1R(")&;W)M=6SD<B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*
M;7-G<W1R(")6:7-H971S;W)D(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B5'EP(&%V('9I<VAE
M='-O<F0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O
M<G1U;F5S(@IM<V=S='(@(E9I<VAE='-O<F0B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B5FES:&5T
M<V]R9"`R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U-0IM<V=I
M9"`B1F]R=6US(@IM<V=S='(@(D9O<G5M(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$Q,0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B5FED87)B
M969O<F1R87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R(")&<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@
M(D9R86UE<R(*;7-G<W1R(")286UA<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C@W"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HX,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E
M(@IM<V=S='(@(D9R86YK<FEK92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B
M1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B1G)A;FMR:6ME+"!-971R
M;W!O;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-#$W"FUS9VED(")&<F5E+T)U<WD@26YF;W)M871I;VXB"FUS9W-T
M<B`B3&5D:6<O57!P=&%G96X@:6YF;W)M871I;VXB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0R-PIM<V=I9"`B1G)E
M92]"=7-Y(%)E<&QY(@IM<V=S='(@(DQE9&EG+U5P<'1A9V5N('-V87(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0R
M,@IM<V=I9"`B1G)E92]"=7-Y(%)E<75E<W0B"FUS9W-T<B`B3&5D:6<O=7!P
M=&%G96XM9O9R9G+E9V%N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HR-S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HS-#$*;7-G:60@(D9R964O0G5S>2!297%U
M97-T(%)E<W!O;G-E(@IM<V=S='(@(E-V87(@<.4@;&5D:6<O=7!P=&%G96XM
M9O9R9G+E9V%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.3$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@T(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S
M='(@(D9R86YS:V$@1W5I86YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$X-`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0
M;VQY;F5S:6$B"FUS9W-T<B`B1G)A;G-K82!0;VQY;F5S:65N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`Y(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C(*(SH@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C@V(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S
M='(@(D9R86YS:V$@<_9D<F$@=&5R<FET;W)I97(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@
M(D9RY6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#D*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,Y-0IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@
M(D9RY6X@9&5N("(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(D9U;&QS=.1N
M9&EG(&)E<VMR:79N:6YG(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI
M8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R
M(")&=6QL;>5N92(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&=6QL($YA
M;64B"FUS9W-T<B`B1G5L;'-TY&YD:6=T(&YA;6XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HX.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@
M(D=A8F]N(@IM<V=S='(@(D=A8F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL
M97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R(")'86QL97)I(&%T="!T
M82!B:6QD(&9RY6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S
M='(@(D=A;&QE<FDZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.38*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@X(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B
M1V%M8FEA(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S
M='(@(D=E;F5R97)A(&MO;F9I9W5R871I;VX@9O9R("5S(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E
M9"!#;V1E(@IM<V=S='(@(D=E;F5R97)A9"!K;V0B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HY,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#D@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@
M(D=E;W)G:6$B"FUS9W-T<B`B1V5O<F=I96XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HV.0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E
M<FUA;GDB"FUS9W-T<B`B5'ES:VQA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HY,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA
M(@IM<V=S='(@(D=H86YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.30*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDR(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS
M9W-T<B`B1VEB<F%L=&%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S4@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S8*;7-G
M:60@(D=I=F5N($YA;64B"FUS9W-T<B`B1O9R;F%M;B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S4@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z,3`*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*;7-G:60@(D=L
M;V)A;"!/<'1I;VYS(@IM<V=S='(@(D=L;V)A;&$@:6YS=.1L;&YI;F=A<B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$W"FUS9VED(")';R(*;7-G
M<W1R(")/2R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B
M1V]E9&5L(@IM<V=S='(@(D=O961E;"(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,3`P"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,3,Q"FUS9VED(")';V]G;&4@36%P<R(*;7-G
M<W1R(")';V]G;&5K87)T;W(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(D=O;V=L97/V:VYI
M;F<B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C(P"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,S@*
M;7-G:60@(D=R87ES8V%L92(*;7-G<W1R(")'<N5S:V%L82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<V(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#`*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.CDS(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V
M"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B1W)E:VES:R`H25-/+3@X-3DM-RDB
M"@HC.B!C;VYF:6<O=&AE;65S+V=R965N+G!H<#HV"FUS9VED(")'<F5E;B(*
M;7-G<W1R(")'<O9N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.34*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDT(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T
M<B`B1W+V;FQA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HX.0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.34@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B
M1W)A;F%D82(*"B,Z(&-O;F9I9R]T:&5M97,O9W)E>2YP:'`Z-@IM<V=I9"`B
M1W)E>2(*;7-G<W1R(")'<N4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM
M<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B1W)U<'!A9&UI
M;FES=')A=&EO;B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`Z-3D@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$V.0HC.B!L:6(O2&]R
M9&4O1W)O=7`N<&AP.C4Y(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ-CD*
M;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<@;&EB
M+TAO<F1E+T=R;W5P+VQD87`N<&AP.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES
M('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B1W)O=7!?;&1A<#H@
M2V%N(&EN=&4@;.1G9V$@=&EL;"!G<G5P<"`G)7,G+B!397)V97)N('-V87)A
M9&4Z("(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HQ,3@*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$R-"!L
M:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G
M:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS
M9W-T<B`B1W)O=7!?;&1A<#H@2V%N(&EN=&4@<F%D97)A(&=R=7!P("<E<R<B
M"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S,X(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(SH@;&EB+TAO<F1E+T=R
M;W5P+VQD87`N<&AP.C,S."!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S<Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U
M<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@2V%N(&EN=&4@
M=7!P9&%T97)A(&=R=7!P("<E<R<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C,Q-"!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,Q-`HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS."!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(D=R=7!P97(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<V(&QI8B](;W)D92].3%,O=&QD+G!H<#HY.`HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.38@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,PHC.B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<*;7-G
M:60@(D=U86TB"FUS9W-T<B`B1W5A;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,#(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.CDX(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%T
M96UA;&$B"FUS9W-T<B`B1W5A=&5M86QA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY,B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@
M(D=U97)N<V5Y(@IM<V=S='(@(D=U97)N<V5Y(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HR,C8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR
M,C8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E
M<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B1^1S=&)E:/9R:6=H971E<B(*"B,Z
M('1E;7!L871E<R]G=65S="]G=65S="YI;F,Z,3$*;7-G:60@(D=U97-T(%-E
M<G9I8V5S(@IM<V=S='(@(E1JY&YS=&5R(&;V<B!GY'-T97(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<R"FUS9VED(")'=65S=&)O;VLB"FUS
M9W-T<B`B1^1S=&)O:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.CDW"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY.2!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@
M(D=U:6YE82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW."!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3`T"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#`@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS
M9W-T<B`B1W5I;F5A+4)I<W-A=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW."!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3`U"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,#$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N
M82(*;7-G<W1R(")'=6EN96$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HY-C`@;&EB+TAO<F1E+T9O<FTN<&AP.CDV-`IM<V=I9"`B2%1-3"(*;7-G
M<W1R(")(5$U,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@
M(DA434Q!<F5A(';D9W)A<B!A='0@<F%D97)A('-I<W1A(&-E;&QE;B!I(&5N
M(')A9"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@
M(DA434Q!<F5A(';D9W)A<B!A='0@<F%D97)A('-I<W1A(&MO;'5M;F5N(&D@
M96X@=&%B96QL+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T
M<B`B2%1-3$%R96$@=N1G<F%R(&%T="!R861E<F$@<VES=&$@<F%D96X@:2!E
M;B!T86)E;&PN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ
M-3<@;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10($%U
M=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B2%144"!!=71E;G1I
M<V5R:6YG('-A:VYA<RXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Q,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*;7-G
M<W1R(")(86ET:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0P,B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M
M06QG;W)I=&AM(@IM<V=S='(@(DAA<VAA;&=O<FET;2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM
M<V=S='(@(D1I;6UA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S(*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.CDR,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ.`IM<V=I9"`B2&5A
M9&5R(@IM<V=S='(@(E)U8G)I:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO
M5'EP92]T86)L97-E="YP:'`Z-C$*(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T
M86)L97-E="YP:'`Z-C$*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B4G5B<FEK
M97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-SD@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-PHC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N
M86QD($ES;&%N9',B"FUS9W-T<B`B2&5A<F0M(&]C:"!-8T1O;F%L9/9A<FYA
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*
M;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS9W-T<B`B2W)A9G1I9V$@Y7-K<VMU
M<F%R(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DAE8G)E
M=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R(")(96)R96ES:R`H25-/+3@X-3DM
M."U)*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R(")(]FID(@H*(SH@
M;&EB+T)L;V-K+V)A<G1I;64N<&AP.C(T(&QI8B]";&]C:R]D:79I9&5R+G!H
M<#HR-`IM<V=I9"`B2&5I9VAT("AI;B!P:7AE;',I(@IM<V=S='(@(DCV:F0@
M*'!I>&QA<BDB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z
M,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@;&EB
M+TAO<F1E+TAE;'`N<&AP.C$X-"!L:6(O2&]R9&4O2&5L<"YP:'`Z,3@V('-E
M<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W"B,Z('1E;7!L871E<R]H96QP+VEN
M9&5X+FEN8SHT"FUS9VED(")(96QP(@IM<V=S='(@(DAJY&QP(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B
M2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B2&KD;'`@;65D(&5D:71O<FXB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,S<U"FUS9VED(")(96QP97(B"FUS9W-T<B`B2&KD;'!F=6YK
M=&EO;B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P
M:&5R92(*;7-G<W1R(")(96UI<V;D<B(*"B,Z('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS
M9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S
M='(@(DCD<B#D<B!B]G)J86X@878@9FEL96XZ(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(DAI9V@B"FUS9W-T
M<B`B2/9G(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L
M871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"FUS9VED(")(;U]M92(*
M;7-G<W1R(")(95]M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-"!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0S"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#0@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H
M5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$T.3$@;&EB+TAO<F1E+G!H<#HQ-3,Y"FUS9VED
M(")(;VUE(@IM<V=S='(@(DAE;2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$U-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$R,B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D%D<F5S<RP@:&5M
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"FUS9VED(")(;VUE($1I
M<F5C=&]R>2(*;7-G<W1R(")(96UK871A;&]G(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G
M<W1R(")496QE9F]N+"!H96TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$P.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A
M<R(*;7-G<W1R(")(;VYD=7)A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW."!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3`V"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,#8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@
M2V]N9R(*;7-G<W1R(")(;VYG($MO;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-C<*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-#(@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HT-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN
M=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*
M;7-G<W1R(")(;W)D92]+;VQA8CH@3V=I;'1I9W0@)7,@6$U,+61A=&$@<.5T
M<N1F9F%D97,@:2!M961D96QA;F1E("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HR.3D@;&EB+TAO<F1E+TMO;&%B+G!H<#HR.3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S
M<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!);F=E
M="!M961D96QA;F1E(&UA=&-H87(@;V)J96MT970@)7,B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C0S-2!L:6(O2&]R9&4O2V]L86(N<&AP.C0T
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T
M(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D
M92]+;VQA;CH@26YG970@;V)J96MT(&%V('1Y<&5N("5S(&AI='1A9&5S(&D@
M;65D9&5L86YD970@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$R-3`@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C4Q"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<
M(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(%)A9&5R861E("5S("<E<R<B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,R!L:6(O2&]R9&4O
M2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A
M=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I
M;VXB"FUS9W-T<B`B2&]R9&4O2V]L86(Z($EN=&5G<F%T:6]N<VUO=&]R;B!K
M<N1V97(@)V1O;7AM;"<M=&EL;.1G9V5T(&;V<B!02%`B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C4P,R!L:6(O2&]R9&4O2V]L86(N<&AP.C4Q
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@2V%N(&EN=&4@<VMA<&$@;GET="!834PM='+D9"!F]G(@
M;V)J96MT("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0W
M(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(T.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!+86X@:6YT92!R861E<F$@)7,@)R5S
M)SH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W-"!L:6(O
M2&]R9&4O2V]L86(N<&AP.C0X,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P
M87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($MA;B!I;G1E
M(&CD;71A($U)341%+4E$(&;V<B!D96QE;B!M960@='EP("5S(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DS(&QI8B](;W)D92]+;VQA8BYP
M:'`Z,3$Y-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA
M8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z($MA;B!I;G1E('-Y;FMR;VYI<V5R82`E<R`G)7,G.B`E<R(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3,S-B!L:6(O2&]R9&4O
M2V]L86(N<&AP.C$S,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@
M(DAO<F1E+TMO;&%B.B!+86X@:6YT92!S>6YK<F]N:7-E<F$@=71D96QN:6YG
M87(Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(DAO<F1E
M+TMO;&%B.B!/:^1N9"!U=&1E;&YI;F<@)R5S)R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT
M86P@4G5L92(*;7-G<W1R(")(;W)I<V]N=&5L;"!L:6YJ92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO
M<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R(")(;W)I<V]N=&5L;"!U=&9Y;&QN
M860B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R(")(;W)I<V]N=&5L;#HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E
M(')E<&]R="$I(@IM<V=S='(@(DAU<B!H86UN861E(&1U(&CD<C\@*%9A<B!G
M;V0@<F%P<&]R=&5R82!D971T82$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@
M8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B2'5R
M(&WE;F=A(&MO;'5M;F5R('9I;&P@9'4@<VSE(&EH;W`_(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD
M<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R(")(=7(@;>5N9V$@9N1L
M="`H:V]L=6UN97(I(&9I;FYS(&1E=#\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N
M>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")(=7(@
M;>5N9V$@<F%D97(@=FEL;"!D=2!S;.4@<V%M;6%N/R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,S<*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(D9U:W1I9VAE="(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@*;7-G:60@(DAU;6ED:71Y
M.B`B"FUS9W-T<B`B1G5K=&EG:&5T.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(DAU;6]R:7-T97(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#`@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,0HC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(E5N9V5R;B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W,B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,U"B,Z(&QI8B](;W)D92]!=71H
M+V-Y<G5S+G!H<#HQ-S(@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B4VMA<&%N9&4@878@24U!4"UM87!P(&UI<W-L
M>6-K861E.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP
M.C(Q-"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,Z(&QI
M8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,30@;&EB+TAO<F1E+T%U=&@O8WER
M<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X
M(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B4F%D97)I;F<@878@24U!
M4"UM87!P(&UI<W-L>6-K861E<SH@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G5S+G!H<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN
M<&AP.C(T,@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3<Y(&QI8B](
M;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@
M(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S
M='(@(E-K87!A;F1E(&%V('%U;W1A(&;V<B!)34%0+6UA<'`@;6ES<VQY8VMA
M9&5S.B`E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,38@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$S,C`*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T
M<B`B25`M861R97-S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC
M+G!H<#HW-R!L:6(O2&]R9&4O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B
M25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("))4"UA9')E<W,@
MY'(@:6YT92!T:6QL9^1N9VQI9RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VEP8F%S:6,N<&AP.C@Y(&QI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP.C@Y
M"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L
M;V-K+B(*;7-G<W1R("))4"UA9')E<W,@Y'(@:6YT92!I;F]M(&=O9&OD;G0@
M0TE$4BUB;&]C:RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.34*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS
M9W-T<B`B1O9R<_9K(&%T="!K<FEN9V?E($E0+6SE<RXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G
M:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R("))7VYF;V=A(')A9"!F
M]G)E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@R(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C`*
M(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P."!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("))<VQA
M;F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@P"FUS9VED("))8V]N
M<R!/;FQY(@IM<V=S='(@(D5N8F%R="!I:V]N97(B"@HC.B!U=&EL+VEC;VY?
M8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R
M("5S(@IM<V=S='(@(DEK;VYE<B!F]G(@)7,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S@Q"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B
M26MO;F5R(&UE9"!T97AT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y
M,PIM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R("))9&5N=&ET971E
M;G,@;F%M;CHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HU.3$@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4Y.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L
M>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(D]M
M(&1E="!I;G1E('9I<V%S(&MO<G)E:W0L("5S(&;V<B!A='0@]G!P;F$@:2!N
M>71T(&;V;G-T97(N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U.0IM
M<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT
M97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES
M(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B
M"B)/;2!D=2!I;G1E('-E<B!NY6=R82!I:V]N97(@;N1R(&1U(&%N=N1N9&5R
M($EN=&5R;F5T($5X<&QO<F5R+"!SY2!K86X@9'4@(@HB8F5H]G9A(&UA<FME
M<F$@9&5N;F$@<G5T82!F]G(@871T('-TY&YG82!A=B!G96YO;7-K:6YL:6=A
M(%!.1RUB:6QD9FEL97(N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$U.`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3<R"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G
M92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@
M8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T
M<B`B(@HB3VT@9'4@<V5R(&1E;FYA('1E>'0@;65N(&EN9V5N(&)I;&0L('/E
M(&MA;B!I;G1E(&1I;B!W96)B;.1S87)E('9I<V$@9&5N("(*(F)I;&0@9'4@
M9O9R<_9K97(@;&%D9&$@=7!P+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@
M4')E=FEE=SHB"FUS9W-T<B`B1O9R:&%N9'-G<F%N<VMA(&)I;&0Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(D)I;&1A9')E<W,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B0FEL9&%D<F5S<SHB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R
M(")":6QD(&9RY6X@9V%L;&5R:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@
M9G)O;2!G86QL97)Y.B(*;7-G<W1R(")":6QD(&9RY6X@9V%L;&5R:3HB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Q(&QI8B](;W)D92]&;W)M
M+G!H<#HQ-S8U"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`B3&%D9&$@
M=7!P(&)I;&0B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B
M26UA9V5S(@IM<V=S='(@(D)I;&1E<B(*"B,Z('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P
M("5D(@IM<V=S='(@(DEM<&]R=&5R82P@<W1E9R`E9"(*"B,Z('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM
M<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("));7!O<G1E<F%D92!FY&QT.B`E
M<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM
M<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B26UP;W)T97)A9&4@9N1L=#HB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C<P
M,0IM<V=I9"`B26X@4')O8V5S<R(*;7-G<W1R(")0Y6?E96YD92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B26Y?9F]G82!R
M860@969T97(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP
M+G!H<#HQ,S4@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,T"FUS9VED
M("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(D9E;&%K
M=&EV(&%K=&EV:71E='-K;V0@<W!E8VEF:6-E<F%D+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C
M="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(D9E;&%K=&EG
M="!A;G;D;F1A<FYA;6X@;V-H+V5L;&5R(&SV<V5N;W)D+B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@
M=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C
M;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T
M:&5R(&AE;'`N(@IM<V=S='(@(B(*(D]G:6QT:6=T(&%N=N1N9&%R;F%M;B!E
M;&QE<B!A;'1E<FYA=&EV(&%D<F5S<RX@1O9R<_9K(&EG96X@96QL97(@:V]N
M=&%K=&$@(@HB861M:6YI<W1R873V<F5N(&]M(&1U(&)E:/9V97(@:&KD;'`N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(M9K82!I;F1R86<B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-@HC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@Q"FUS9VED("));F1I82(*;7-G<W1R("));F1I96XB"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C(U-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R("));F1I=FED
M=65L;&$@86YVY&YD87)E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,3(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q
M,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA
M(@IM<V=S='(@(DEN9&]N97-I96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C8W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(DEN9F\B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Y"FUS9VED("));F9O<FUA
M=&EO;B(*;7-G<W1R("));F9O<FUA=&EO;B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS,3D*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E
M<B!A=F%I;&%B;&4N(@IM<V=S='(@(DEN9F]R;6%T:6]N(.1R(&EN=&4@=&EL
M;&?D;F=L:6<@;.1N9W)E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU
M;6X@069T97(B"FUS9W-T<B`B26YF;V=A(&M?;VQU;6X@969T97(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C`*;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R("));F9O9V$@8FEL
M9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("));F9O9V$@=&%B96QL
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M-0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(DEN9F]G82!W96)B
M;.1N:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM
M<V=S='(@(DEN9F]G82!?:V]L=6UN(&;V<F4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN
M<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S
M='(@(DEN9F]G82!N>2!K;VQU;6X@969T97(@86MT=65L;"!K;VQU;6XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C
M=7)R96YT(&]N92(*;7-G<W1R("));F9O9V$@;GD@:V]L=6UN(&;V<F4@86MT
M=65L;"!K;VQU;6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@
M869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN9F]G82!R860@969T
M97(@86MT=65L;"!R860B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R
M;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("));F9O9V$@;GD@
M<F%D(&;V<F4@96MT=65L;"!R860B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A
M('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(DEN
M9F]G82!P87)A9W)A9B!E9G1E<B!A:W1U96QL(&YO9"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I
M9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E
M(@IM<V=S='(@(DEN9F]G82!P87)A9W)A9B!F]G)E(&%K='5E;&P@;F]D(@H*
M(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E
M<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B26YF;V=A(&%L=&5R;F%T:78@;6%L
M;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#(*;7-G:60@(DEN<V5R
M="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T
M:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E
M<G0@8V5L;"!A9G1E<B(*;7-G<W1R("));F9O9V$@8V5L;"!E9G1E<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3D*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("));F9O9V$@
M8V5L;"!F]G)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*
M;7-G<W1R("));F9O9V$@:V]L=6UN(&5F=&5R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS
M97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B26YF;V=A(&MO;'5M;B!F]G)E
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4P"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A
M9V5S(@IM<V=S='(@(DEN9F]G82!M961D96QA;F1E;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I
M9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R("));F9O9V$@<&%R
M86=R868@969T97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@
M8F5F;W)E(@IM<V=S='(@(DEN9F]G82!P87)A9W)A9B!F]G)E(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM
M<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("));F9O9V$@<F%D(&5F
M=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B
M26YF;V=A(')A9"!F]G)E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S
M,PIM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E
M8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R(")!;F=E(&5R9F]R9')A="!S=F%R
M('1I;&P@<^1K97)H971S9G+E9V%N.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@
M26UA9V4B"FUS9W-T<B`B26YF;V=A+\1N9')A(&)I;&0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E
M<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B26YF;V=A+\1N9')A(&SD;FLB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T
M,PHC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED
M("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U
M=&EO;B!L:7-T+B(*;7-G<W1R(")/=&EL;'+D8VML:6<@:W)E9&ET(&;V<B!A
M='0@<VMI8VMA('1I;&P@9&ES=')I8G5T:6]N<VQI<W1A+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F
M9FEC:65N="!C<F5D:70N(@IM<V=S='(@(D]T:6QL<N1C:VQI9R!K<F5D:70N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W-2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3`W.0IM<V=I9"`B26YT96=E<B(*;7-G<W1R(")(96QT86PB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,S(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,3,W"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B2&5L
M=&%L<VQI<W1A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HR.#,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HS-3(*;7-G:60@(DEN=F%L:60@06-T:6]N('-E;&5C
M=&5D(&9O<B!T:&ES(&-O;7!O;F5N="XB"FUS9W-T<B`B3V=I;'1I9R#E=&?D
M<F0@9O9R(&1E;B!HY'(@:V]M<&]N96YT96XN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$
M2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R(")/9VEL=&EG(%5$2"`H
M)W5S97(@9&%T82!H96%D97(G*2XB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O
M>FEP+G!H<#HQ-C<@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3DT"B,Z
M(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C(Q,@IM<V=I9"`B26YV86QI
M9"!:25`@9&%T82(*;7-G<W1R(")/9VEL=&EG="!:25`M87)K:79D871A(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A
M<'!L:6-A=&EO;BXB"FUS9W-T<B`B1F5L86MT:6<@87!P;&EK871I;VXN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$R"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS
M9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R(")&96QA:W1I9W0@8F%T
M8V@M240B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@W(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(S,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,CDY"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(P.3$*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q-C(@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(R,S8@;&EB+TAO<F1E+T9O<FTN<&AP.C(S
M,#,*(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G
M:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(D9E;&%K=&EG
M(&1A=&$@<VMI8VMA9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#`*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D
M<F5S<RXB"FUS9W-T<B`B1F5L86MT:6<@9&5S=&EN871I;VYS861R97-S+B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`@;&EB+TAO
M<F1E+T-O;7!R97-S+V1B>"YP:'`Z,3`Y"B,Z(&QI8B](;W)D92]#;VUP<F5S
M<R]D8G@N<&AP.C$S.2!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HR-#$*
M;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B1F5L86MT:6=T
M(&9I;&9O<FUA="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-C4*;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(D]G:6QT
M:6<@;&EC96YS;GEC:V5L+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-3D*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM
M<V=S='(@(D9E;&%K=&EG(&]R="!S<&5C:69I8V5R860N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A
M;&ED(&US9U]T>7!E+B(*;7-G<W1R(")&96QA:W1I9R!M961D96QA;F1E7W1Y
M<"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#,*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@
M(D9E;&%K=&EG(&5L;&5R('-A:VYA9"!A<&E?:60N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED
M(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B1F5L86MT:6=T(&5L
M;&5R('-A:VYA9"!P87)A;65T97(N(@H*(SH@861M:6XO<&5R;7,O861D8VAI
M;&0N<&AP.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*
M;7-G<W1R(")&96QA:W1I9R#V=F5R;&EG9V%N9&4@8F5H]G)I9VAE="XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"FUS9VED("));G9A
M;&ED('!A<G1N97(@:60N(@IM<V=S='(@(D9E;&%K=&EG="!P87)T;F5R+6ED
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@
M(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R(")&96QA:W1I9R!P<F]D
M=6MT:V]D+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P-@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B1F5L
M86MT:6=T('!R;W1O:V]L;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HX,`HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M.3,@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C<Q"B,Z(&QI8B].970O4TU3
M+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED
M(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@(D9E;&%K=&EG(&UO='1A9V%R
M93H@)R5S)R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`W-B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-C(*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HQ,#@P(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(V,PIM<V=I9"`B
M26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B1F5L86MT:6=T('5T9&5L
M;FEN9W-O8FIE:W0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#$*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM
M<V=S='(@(D9E;&%K=&EG(&%V<^1N9&%R861R97-S+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI
M9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(D9E;&%K=&EG="!U;FEC;V1E+61A
M=&$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4Y"FUS9VED("))
M;G9E;G1O<GDB"FUS9W-T<B`B26YV96YT87)I97(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C4T"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HV-S@*;7-G:60@(DEN=F5R="!S96QE
M8W1I;VXB"FUS9W-T<B`B26YV97)T97)A('5R=F%L(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3D*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Q,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM
M<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("))<F%N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@Q(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3@*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("))<F%K(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@P(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3,*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R("))<FQA;F0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-2!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R("))<VQE(&]F
M($UA;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R(")%;G-T86MA
M(.5S:W-K=7)A<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3$T"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,30@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R
M("))<W)A96PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8R-2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8R-@IM<V=I9"`B27-S
M=65R(@IM<V=S='(@(E5T9N1R9&%T(&%V(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T
M<B`B2W5R<VEV(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,C$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-2!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B271A;'DB"FUS9W-T<B`B
M271A;&EE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3(S"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,38@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B
M2F%M86EC82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HS-S<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Q-`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`R(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I
M9"`B2F%N=6%R>2(*;7-G<W1R(")J86YU87)I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,C4*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I
M9"`B2F%P86XB"FUS9W-T<B`B2F%P86XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y,`IM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R
M(")*87!A;G-K("A)4T\M,C`R,BU*4"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R,B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED
M(")*97)S97DB"FUS9W-T<B`B2F5R<V5Y(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,C0*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Q."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B
M2F]R9&%N(@IM<V=S='(@(DIO<F1A;FEE;B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS.#,*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R,`HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`X(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R(")J=6QI(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Y"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#<@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S
M='(@(FIU;FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(DIU<W1E
M<F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B0V5N
M=&5R:G5S=&5R82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T
M<B`B2G5S=&5R82!JY&UT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*
M;7-G<W1R(")6Y&YS=&5R:G5S=&5R82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED(")*=7-T:69Y
M(%)I9VAT(@IM<V=S='(@(DCV9V5R:G5S=&5R82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,V"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,3D@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G
M:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T-@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C8U"FUS9VED(")+965P(&]R:6=I;F%L/R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$R-@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R(")+
M96YY82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#4@;&EB
M+TAO<F1E+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E
M<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B2V5R8F5R;W-S
M97)V97)N(&%V=FES861E(&%U=&5N=&ES97)I;F=E;BXB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0P,"!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO
M;B(*;7-G<W1R(").>6-K96P@<VMA<&%D(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#`S(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q
M-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(D9I;F=E<G!R:6YT
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#`Q(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G
M<W1R(").>6-K96QLY&YG9"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0P,"!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@
M(DME>2!4>7!E(@IM<V=S='(@(DYY8VME;'1Y<"(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DX(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3DY"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`B3GEC:V5L86YV
MY&YD86YD92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<R
M.2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E
M861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B
M3GEC:V5L(&9I;FYS(')E9&%N('#E(&1E;B!P=6)L:6MA(&YY8VME;'-E<G9E
M<FXN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S
M(@IM<V=S='(@(D)A<FXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$R.0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*
M;7-G<W1R(")+:7)I8F%T:2(*"B,Z(&-O;F9I9R]T:&5M97,O:V]L86(N<&AP
M.CD*;7-G:60@(DMO;&%B(@IM<V=S='(@(DMO;&%B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S(*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$R,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-0IM
M<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B3F]R9&MO<F5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,S,*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$R,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(E-Y9&MO<F5A(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3$*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R
M(")+;W)E86YS:R`H155#+4M2*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3,T"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,C0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I
M="(*;7-G<W1R(")+=7=A:70B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$R-PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS
M=&%N(@IM<V=S='(@(DMI<F=I<W1A;B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R("),85]Y;W5T(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A
M9V4B"FUS9W-T<B`B4W!RY6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$S-PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O
M<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("),86]S(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S
M='(@(E-I<W1A(&AA;'9A;B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW
M-@IM<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B3/9S96YO
M<F0@Y&YD<F%D97,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L
M;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`B
M4VES=&$@:W9A<G1A;&5T(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3@*
M;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B4V5N87-T('5P<&1A=&5R
M860Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y(&QI8B](;W)D
M92]!=71H+G!H<#HW,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I
M;CH@)7,B"FUS9W-T<B`B4V5N87-T92!I;FQO9V=N:6YG.B`E<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C<R,2!L:6(O2&]R9&4O075T:"YP:'`Z
M-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@
M)7,B"FUS9W-T<B`B4V5N87-T92!I;FQO9V=N:6YG.B`E<R!F<N5N("5S(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$V(&QI8B](;W)D92]!=71H
M+G!H<#HW,30*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(E-E
M;F%S=&4@:6YL;V=G;FEN9SH@06QD<FEG(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-#8*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$R-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B
M3&%T=FEA(@IM<V=S='(@(DQE='1L86YD(@H*(SH@8V]N9FEG+W1H96UE<R]L
M879E;F1E<BYP:'`Z-@IM<V=I9"`B3&%V96YD97(B"FUS9W-T<B`B3&%V96YD
M97(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA=R(*
M;7-G<W1R("),86<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*;7-G<W1R("),87EO
M=70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@
M(DSD;6YA('1O;2!F]G(@871T('-TY&YG82!A=B!K86YT;&EN:F4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S.`HC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@(DQI8F%N;VXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*
M;7-G:60@(DQE9G0B"FUS9W-T<B`B5N1N<W1E<B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,3D@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#4*;7-G
M:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(E;D;G-T97)R=6)R:6LB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$U(&QI8B](;W)D92]&;W)M+G!H
M<#HS,3`Q"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R(")6Y&YS=&5R=N1R
M9&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@X(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#,*
M(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R.2!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("),97-O
M=&AO(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED
M("),979E;"(*;7-G<W1R(").:7;E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-#(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$S,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB
M97)I82(*;7-G<W1R("),:6)E<FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-#<*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$S,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB
M>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("),:6)Y96XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#@@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,`HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(DQI96-H=&5N<W1E
M:6XB"@HC.B!C;VYF:6<O=&AE;65S+VQI9VAT8FQU92YP:'`Z-@IM<V=I9"`B
M3&EG:'0@0FQU92(*;7-G<W1R("),:G5S8FSE(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT($1R:7IZ
M;&4B"FUS9W-T<B`B1'5G9W)E9VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR-@IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R
M("),Y'1T(')E9VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R("),
MY'1T(&;V<FUI9&1A9W-R96=N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G
M<W1R("),Y'1T(&5F=&5R;6ED9&%G<W)E9VXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B3&EG:'0@4F%I;B!3
M:&]W97(B"FUS9W-T<B`B3.1T="!R96=N<VMU<B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN
M('=I=&@@5&AU;F1E<B(*;7-G<W1R("),Y'1T(')E9VX@;65D(.5S:V$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I
M9"`B3&EG:'0@4VYO=R(*;7-G<W1R("),Y'1T('-N]B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3
M;F]W(%-H;W=E<B(*;7-G<W1R("),Y'1T('-N]G-K=7(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(DQI
M;65R:6-K(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-"!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3@Q.`IM<V=I9"`B3&EN:R(*;7-G<W1R("),Y&YK
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B3.1N
M:V5N('!E:V%R('#E.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M-S4@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-SD*;7-G:60@(DQI;FL@=&AE(&5M
M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI
M;F<B"FUS9W-T<B`B3.1N:V$@92UP;W-T861R97-S96X@=&EL;"!F=6YK=&EO
M;F5N(&;V<B!A='0@<VMA<&$@;GET="!M961D96QA;F1E(@H*(SH@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,PHC.B!F
M<F%M97=O<FLO5&5X="]497AT+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$U.`HC
M.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#(*;7-G
M:60@(DQI;FMS(@IM<V=S='(@(DSD;FMA<B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(DMA:V$B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#8*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C
M86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B3&ES=&$@+2!A;G;D;F1A<F4@
M:V%N('-E(&UA<'!E;B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G
M:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(E9I<V$@9&%T86)A<V5R(@H*
M(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3$*;7-G:60@(DQI<W0@2&5L
M<"!4;W!I8W,B"FUS9W-T<B`B5FES82!H:N1L<.1M;F5N(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$S,@IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B
M3&ES=&$@=&%B96QL97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E
M<G,N<&AP.C4Y-"!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.30*;7-G
M:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("),:7-T+4%R8VAI=F4B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4X.2!L:6(O2&]R9&4O
M34E-12](96%D97)S+G!H<#HU.#D*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R
M("),:7-T+4AE;'`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N
M<&AP.C4Y-B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.38*;7-G:60@
M(DQI<W0M260B"FUS9W-T<B`B3&ES="U)9"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DR(&QI8B](;W)D92]-24U%+TAE861E<G,N
M<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("),:7-T+4]W;F5R
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3,@;&EB
M+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B
M"FUS9W-T<B`B3&ES="U0;W-T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.3$@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DQ
M"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("),:7-T+5-U8G-C<FEB
M92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP(&QI
M8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U
M8G-C<FEB92(*;7-G<W1R("),:7-T+55N<W5B<V-R:6)E(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@
M<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R(")$970@9VEC:R!I;G1E(&%T
M="!L:7-T82!S97-S:6]N97(Z("5S(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C,W"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D
M.B`E<R(*;7-G<W1R(")$970@9VEC:R!I;G1E(&%T="!L:7-T82!A;G;D;F1A
M<F4Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR
M"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("),
M:7-T;FEN9R!A=B!A;G;D;F1A<F4@879A:W1I=F5R860N(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@
M(DQI='1E<F%T=7(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$T-`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:71H=6%N:6$B"FUS
M9W-T<B`B3&ET875E;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEM86=E<RYP:'`Z.#,*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEM86=E
M<RYP:'`Z-S<*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B3&%D9&%R+BXN
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P,`IM<V=I9"`B
M3&]C86P@=&EM93H@(@IM<V=S='(@(DQO:V%L('1I9#H@(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@V"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS
M9W-T<B`B4F5G:6]N86QT(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S$*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HU-S`@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S(*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4W(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HR,@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C<R"FUS9VED
M("),;V-A=&EO;B(*;7-G<W1R(")0;&%T<R(*"B,Z(&QO9VEN+G!H<#HQ.#D@
M<V5R=FEC97,O<&]R=&%L+VUE;G4N<&AP.C$V,R!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,C`P"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C,@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHY,"!T96UP;&%T97,O9W5E<W0O9W5E<W0N:6YC
M.C,P"FUS9VED("),;V<@:6XB"FUS9W-T<B`B3&]G9V$@:6XB"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V
M:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+VUE;G4N<&AP.C$U-R!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,3DT"FUS9VED("),;V<@;W5T(@IM<V=S='(@(DQO9V=A('5T(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"FUS9VED("),;V=I;B(*;7-G<W1R("),
M;V=I;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`*;7-G:60@(DQO
M9VEN(%1A<VMS(@IM<V=S='(@(DQO9VEN86MT:79I=&5T97(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.38@;&EB+TAO<F1E+T%U=&@N<&AP.CDY
M-0IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O
M<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B
M(@HB26YL;V=G;FEN9R!M:7-S;'EC:V%D97,N(%1R;VQI9W1V:7,@=F%R(&%N
M=N1N9&%R;F%M;B!E;&QE<B!L]G-E;F]R9"`B"B)F96QA:W1I9W0N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DR(&QI8B](;W)D92]!=71H+G!H
M<#HY.3$*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B26YL;V=G;FEN
M9R!M:7-S;'EC:V%D97,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,V-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,V.0IM<V=I9"`B3&]N9R!T97AT
M(@IM<V=S='(@(DSE;F<@=&5X="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R(")+Y')L96LB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B3&]W(@IM
M<V=S='(@(DSE9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E
M<G,B"FUS9W-T<B`B1W)E:VES:V$@9V5M96YE<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@
M(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B3&%T:6YS:V$@9V5M96YE
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T
M<B`B4VWE(')O;65R<VMA('-I9F9R;W(B"@HC.B!C;VYF:6<O=&AE;65S+VQU
M8RYP:'`Z-@IM<V=I9"`B3&]Y;VQA(@IM<V=S='(@(DQO>6]L82(*"B,Z(&-O
M;F9I9R]T:&5M97,O;'5C8FQU92YP:'`Z-@IM<V=I9"`B3&]Y;VQA($)L=64B
M"FUS9W-T<B`B3&]Y;VQA($)LY2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.2!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,30U"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,S0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M
M8F]U<F<B"FUS9W-T<B`B3'5X96UB=7)G(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W-@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0S.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B
M34TB"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C@S"FUS9VED(")-3U1$(@IM<V=S='(@(DU/5$0B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T86-H;65N="!C
M;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B35,M5$Y%1B!B:6QA9V$@:6YN
M96CV;&P@:6YG96X@9&%T82XB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"B,Z(&QI8B](
M;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I
M9"`B35-'(@IM<V=S='(@(DU31R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,34W"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,S4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA8V%O
M(@IM<V=S='(@(DUA8V%O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-3,*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S
M-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA
M+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUA
M8V5D;VYI96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$U,0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM<V=S
M='(@(DUA9V%G87-K87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*
M;7-G:60@(DUA9VEC(@IM<V=S='(@(DUA9VES:R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HX,PIM<V=I9"`B36%I;"(*;7-G<W1R(")%+7!O<W0B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(T"FUS9VED(")-86EL
M($%D;6EN(@IM<V=S='(@(D4M<&]S=&%D;6EN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-
M86ME(&QI;E]K+BXN(@IM<V=S='(@(E-K87!A(&SD;FLN+BXB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-0HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDT"FUS9VED(")-86QA=VDB"FUS9W-T<B`B36%L87=I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDU(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C<*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$S.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B36%L87ES:6$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-`HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30P(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDT"FUS9VED(")-86QD:79E<R(*;7-G<W1R(")-86QD:79E<FYA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDR(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-30*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,2!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY,@IM<V=I9"`B36%L:2(*;7-G<W1R(")-86QI(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDT(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C(*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$T,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-`IM<V=I9"`B36%L=&$B"FUS9W-T<B`B36%L=&$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.30*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C
M871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C
M;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM
M<V=S='(@(B(*(E5N9&5R:.5L;"!L:7-T86X@;65D(&MA=&5G;W)I97(@9'4@
M86YVY&YD97(@9O9R(&%T="!K871E9V]R:7-E<F$@<&]S=&5R(&UE9"`B"B)O
M8V@@9N1R9V5R;F$@<V]M('1I;&QH]G(@9&5S<V$@:V%T96=O<FEE<BXB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R-0HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U-@IM<V=I
M9"`B36%P,C0@;6%P(@IM<V=S='(@(DUA<#(T+6MA<G1A(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-38*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-#`*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#<*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-S$*;7-G:60@(DUA<%%U97-T
M(&UA<"(*;7-G<W1R(")-87!1=65S="UK87)T82(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*
M;7-G<W1R("+6=F5R<^1T=&YI;F=A<B!S<&%R861E+B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-SD*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B;6%R
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")-87)G:6YA;"(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X(&QI8B](
M;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HT.`HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N
M<V5E;B!F;&%G<R(*;7-G<W1R(")&;&%G9V$@<V]M(&SD<W0O;VSD<W0B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.2!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#D*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@
M9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R(")&;&%G
M9V$@;65D(&%N;F%N('-T871U<R`H="!E>"!V:6MT:6=T+V)E<W9A<F%T*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34R"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#,@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B
M36%R<VAA;&SV87)N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,R!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,34Y"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#0@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B
M"FUS9W-T<B`B36%R=&EN:7%U92(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B36%T
M8VAA;F1E(&;D;'0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$V,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM
M<V=S='(@(DUA=7)I=&%N:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-C,*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$T-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET
M:75S(@IM<V=S='(@(DUA=7)I=&EU<R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E
M9&ET+B(*;7-G<W1R(")-87@@=&EL;.5T96X@:W)E9&ET+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X
M(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(D=RY&YS(&;V<B!M
M87@@86YT86P@9&5L87(@:2!M961D96QA;F1E(/9V97)S:W)I9&5N+B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S$S"FUS9VED(")-87@@=&5M<"!L87-T
M(#(T(&AO=7)S.B`B"FUS9W-T<B`B2/9G<W1A('1E;7!E<F%T=7)E('-E;F%S
M=&4@,C0@=&EM;6%R;F$Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`U
M"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(")(]F=S
M=&$@=&5M<&5R871U<F4@<V5N87-T92`V('1I;6UA<FYA.B`B"@HC.B!L:6(O
M87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L
M;V-K<R(*;7-G<W1R(")-87AI;6%L="!A;G1A;"!P;W)T86QB;&]C:R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD@
M;&EB+TAO<F1E+T9O<FTN<&AP.CDP,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(R
M,0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(T,PIM<V=I9"`B36%X:6UU;2!L
M96YG=&@B"FUS9W-T<B`B36%X:6UA;"!LY&YG9"(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HS.#$*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q.`HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(FUA:B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,PHC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R(")-87EO='1E(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*
M;7-G<W1R(")-961I8VEN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HU,S$*;7-G:60@(DUE971I;F<@0V%N8V5L;&%T
M:6]N(@IM<V=S='(@(D%V8F]K82!M]G1E(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,#,*;7-G:60@(DUE971I;F<@
M26YF;W)M871I;VXB"FUS9W-T<B`B3?9T97-I;F9O<FUA=&EO;B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3`Y"FUS
M9VED(")-965T:6YG(%!R;W!O<V%L(@IM<V=S='(@(DWV=&5S9O9R9G+E9V%N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HU,C4*;7-G:60@(DUE971I;F<@4F5P;'DB"FUS9W-T<B`B3?9T97-S=F%R
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HU,30*;7-G:60@(DUE971I;F<@57!D871E(@IM<V=S='(@(DWV=&5S=7!P
M9&%T97)I;F<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C4Q.0IM<V=I9"`B365E=&EN9R!5<&1A=&4@4F5Q=65S="(*
M;7-G<W1R(")5<'!D871E<FEN9W-B96?D<F%N(&]M(&WV=&4B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB97)S
M(@IM<V=S='(@(DUE9&QE;6UA<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.#(*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B365N>6SD9V4Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B4VSE(&EH;W`@8V5L
M;&5R(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!L:6(O2&]R9&4O3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@(DUE9&1E
M;&%N9&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q
M-B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S
M<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C
M97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@
M(B(*(DUE9&1E;&%N9&5T('9E<FEF:65R861E<R!M96X@9&5N('-I9VYE<F%D
M97,@8V5R=&EF:6MA="!K=6YD92!I;G1E('9E<FEF:65R87,N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED(")-
M97-S86=E(&5X<&ER960N(@IM<V=S='(@(DUE9&1E;&%N9&4@9^1L;&5R(&EN
M=&4@;.1N9W)E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V.2!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C`R"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"FUS9VED
M(")-97-S86=E('1Y<&4B"FUS9W-T<B`B365D9&5L86YD971Y<"(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G
M<W1R(")-971A<G;D9&5R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM
M<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B365T
M87)B;&]C:V5T(.1R(&EN=&4@=&EL;&?D;F=L:70N(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ,3D*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I
M;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN
M:7-T<F%T;W(N(@IM<V=S='(@(B(*(DUE=&%R+6)L;V-K(&5J('1I;&QGY&YG
M;&EG="X@1&5T86QJ97(@:&%R(&QO9V=A=',@9O9R('-Y<W1E;6%D;6EN:7-T
M<F%T]G)E;BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34S
M"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@(DUE
M=&%R1$(@Y'(@:6YT92!A;G-L=71E;BXB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S$*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C<@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@
M(DUE=&AO9"(*;7-G<W1R(")-971O9"(*"B,Z(&9R86UE=V]R:R]24$,O4E!#
M+WAM;')P8RYP:'`Z.#$@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP:'`Z,3$W
M"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HX,2!L:6(O2&]R9&4O4E!#
M+W-O87`N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E
M<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(DUE=&]D96X@)R5S)R#D<B!I
M;G1E(&1E9FEN:65R860B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T+G!H
M<#HV,2!L:6(O2&]R9&4O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*
M;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B
M"FUS9W-T<B`B365T;V1E;B!H87(@:6YT92!D969I;F5R871S+B!!;G)O<&%D
M(&UE=&]D.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV
M-R!L:6(O0FQO8VLO;65T87(N<&AP.C@R"FUS9VED(")-971R:6,B"FUS9W-T
M<B`B365T<FES:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-2!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,38V"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#@@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R
M(")-97AI:V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.#4*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T.2!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A
M=&5D(%-T871E<R!O9B(*;7-G<W1R(")-:6MR;VYE<VEE;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@IM<V=I
M9"`B36ED9&QE(@IM<V=S='(@(DUI='1E;B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1N968N<&AP.C,X(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(DUI;65T
M>7`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-PIM<V=I9"`B36EN('1E
M;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(DSD9W-T82!T96UP97)A='5R
M('-E;F%S=&4@,C0@=&EM;6%R;F$Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S`Y"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R
M("),Y&=S=&$@=&5M<&5R871U<B!S96YA<W1E(#8@=&EM;6%R;F$Z("(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,Y(&QI8B](;W)D92]!
M=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@
M:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R(")-:6YS=&$@;/9S96YO<F1S
MY6QD97(@:&%R(&EN=&4@=7!P;N5T=',@Y&XB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C$W"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR,S4*;7-G:60@(DUI<G)O<B(*;7-G<W1R
M(")3<&5G;&$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@
M(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B1&EV97)S92(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(U,"!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S0P(&QI8B].970O4TU3+W=I;E]H='1P+G!H
M<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S
M="XB"FUS9W-T<B`B3V)L:6=A=&]R:7-K="!P86ME="!S86MN87,@*%!%05(@
M2%144%]297%U97-T*2XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U
M"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O
M(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A
M<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@HB2V]N9FEG=7)A=&EO;B!S86MN87,N
M($1U(&WE<W1E('-K87!A(&1E;B!N=2!O;2!D=2!V:6QL(&%N=N1N9&$@9&5N
M(&CD<B`B"B)A<'!L:6MA=&EO;F5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E
M($E$+B(*;7-G<W1R(")386MN87(@;65D9&5L86YD92U)1"XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`HC
M.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED
M(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R
M(")/8FQI9V%T;W)I<VMT('!A:V5T('-A:VYA<R`H4$5!4B!-86EL*2XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.30*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G
M:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B4V%K;F%R('-E<W-I
M;VYS+4E$+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(DWE(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C<V"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R
M(")-;V)I;"!E+7!O<W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV.0IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B36]D97)E
M<F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX."!L:6(O2&]R9&4O
M34E-12]6:65W97(O<F%R+G!H<#HV-@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O>FEP+G!H<#HW,R!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX
M-0IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R("+$;F1R860@9&%T=6TB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`BQ&YD<F$@;.1N
M:R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<S(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C<T"FUS9VED(")-;V1U;'5S(@IM
M<V=S='(@(DUO9'5L=7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$U,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!2
M97!U8FQI8R!O9B(*;7-G<W1R(")-;VQD879I96XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T.0HC.B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS
M9VED(")-;VYA8V\B"FUS9W-T<B`B36]N86-O(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-38*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$U,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I
M9"`B36]N9V]L:6$B"FUS9W-T<B`B36]N9V]L:65T(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C4Y-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4X.`IM
M<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B3>5N860@;V-H(.5R(@H*
M(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-R!L
M:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM
M<V=S='(@(DWE;F%T;&EG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-C$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U
M,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A
M="(*;7-G<W1R(")-;W1S97)R870B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM
M<V=S='(@(DWE;F9A<V5R(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z,3<R(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(U,PHC.B!L:6(O
M1FEL92]#4U8N<&AP.C$Y-B!L:6(O1FEL92]#4U8N<&AP.C(X,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H
M86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R(")&;&5R(&;D;'0@:&ET=&%D
M97,@<.4@<F%D("5D(.1N(&1E="!F]G)VY&YT861E("5D+B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30X"B,Z(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-30@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B36%R;V-K;R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T
M;'D@0VQE87(B"FUS9W-T<B`B365S=&%D96QS(&ML87)T(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G:60@(DUO<W1L
M>2!#;&]U9'DB"FUS9W-T<B`B365S=&%D96QS(&UO;&YI9W0B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S
M=&QY(%-U;FYY(@IM<V=S='(@(DUE<W1A9&5L<R!S;VQI9W0B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#D@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="YP:'`Z-3`Y"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z-C0X"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B1FQY
M='1A(&YE9"(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C4Q,R!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HU,3,*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-3(*;7-G:60@(DUO=F4@
M3&5F="(*;7-G<W1R(")&;'ET=&$@=N1N<W1E<B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C4Q-R!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+G!H<#HU,3<*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HV-38*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B1FQY='1A(&CV
M9V5R(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`U
M(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C4P-0HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T-`IM<V=I9"`B36]V92!5<"(*
M;7-G<W1R(")&;'ET=&$@=7!P(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0Y.0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-3(V"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B1FQY
M='1A(&YE9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT.3@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Y.0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3(U(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,C8*;7-G
M:60@(DUO=F4@=7`B"FUS9W-T<B`B1FQY='1A('5P<"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38X"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-34@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*
M;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B36_G86UB:7%U92(*"B,Z(&-O
M;F9I9R]T:&5M97,O;6]Z:6QL82YP:'`Z-@IM<V=I9"`B36]Z:6QL82(*;7-G
M<W1R(")-;WII;&QA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X
M-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$X.`IM<V=I9"`B375L=&DM;&5V96P@
M9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(D9L97)N:7;E<VQI<W1A(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,C<*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-3@*;7-G:60@
M(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R(")-=6QT:6UA<"!3=&]R8G)I=&%N
M;FEE;FMA<G1A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C(T-@IM<V=I9"`B375L=&EP;&4@<V5L96-T
M:6]N(@IM<V=S='(@(D9L97)V86PB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#`R"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(DUI='0@:V]N
M=&\B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*;7-G:60@(DUY($%C
M8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B36EN(&MO;G1O:6YF;W)M871I
M;VXB"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C0U"FUS9VED(")-
M>2!0;W)T86PB"FUS9W-T<B`B36EN('!O<G1A;"(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]E9&ET+G!H<#HT,PIM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G
M<W1R(")-:6X@<&]R=&%L;&%Y;W5T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-34*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$U-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA
M;FUA<B(*;7-G<W1R(")->6%N;6%R(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+V%G<F5E;65N=%]B;W1T;VTN:6YC.C<*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/
M5"!!9W)E92(*;7-G<W1R(").14HL($IA9R!A8V-E<'1E<F%R(&EN=&4B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,#`@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4X,R!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HT,3$*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,#(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS
M9VED(").86UE(@IM<V=S='(@(DYA;6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$V.0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(").
M86UI8FEA(@IM<V=S='(@(DYA;6EB:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$W.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").
M875R=2(*;7-G<W1R(").875R=2(*"B,Z(&-O;F9I9R]T:&5M97,O3F585&=R
M97DN<&AP.C8*;7-G:60@(DYE6%0B"FUS9W-T<B`B3F585"(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-S`V"FUS9VED
M(").965D<R!!8W1I;VXB"FUS9W-T<B`B0F5H]G9E<B#E=&?D<F0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-PHC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R(").97!A;"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<U"B,Z(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-C`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(DYE9&5R;.1N9&5R;F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,*(SH@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,2!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T
M<B`B3F5D97)LY&YD<VMA($%N=&EL;&5R;F$B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4X,2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B3F5S
M8V%P92!B87,M55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#,@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@
M(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P92!#02!P;VQI8WD@
M55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3@T(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED
M(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R(").971S8V%P92!F]G)N
M>65L<V4M55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.#(@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE
M='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(DYE='-C87!E(.5T97)K
M86QL96QS92U54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X-B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B
M3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(DYE='-C87!E(%-3
M3"US97)V97)N86UN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#<@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#@*;7-G:60@
M(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B3F5T<V%P
M92!C97)T:69I:V%T<VMO;6UE;G1A<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@P(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3@Q"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@
M(DYE='-A<&4@8V5R=&EF:6MA='-T>7`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C4S"FUS9VED(").971W;W)K(@IM<V=S='(@(D[D='9E<FLB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-#(U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,SD@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,`IM<V=I9"`B3F5V97(B
M"FUS9W-T<B`B06QD<FEG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-S`*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V
M,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D
M;VYI82(*;7-G<W1R(").>6$@2V%L961O;FEE;B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z(&QI8B](;W)D
M92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T
M96=O<GDB"FUS9W-T<B`B3GD@:V%T96=O<FDB"@HC.B!L:6(O2&]R9&4O5&5X
M="]&:6QT97(O96UA:6QS+G!H<#HX,2!L:6(O2&]R9&4O5&5X="]&:6QT97(O
M96UA:6QS+G!H<#HX-PHC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS
M+G!H<#HY-R!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HQ,#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T
M<B`B3GET="!M961D96QA;F1E('1I;&P@)7,B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(DYY;>5N92(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE
M=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(DYY='0@86YVY&YD87)N
M86UN("AV86QF<FET="DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$X,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(").97<@6F5A;&%N
M9"(*;7-G<W1R(").>6$@6F5E;&%N9"(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HS-PIM<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(DYY
M='0@;/9S96YO<F0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z
M,C(W(&QI8B](;W)D92]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*
M;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T
M<B`B3GET="!L]G-E;F]R9"!K;VUM97(@871T(&?E('5T("5X+B(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W
M;W)D<R!D;VXG="!M871C:"XB"FUS9W-T<B`B3/9S96YO<F0@;>5S=&4@=F%R
M82!S86UM82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@
M(DYY='0@9O9N<W1E<B`H7V)L86YK*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,CDQ"FUS9VED(").97=S(@IM<V=S='(@(DYY:&5T
M97(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`W"FUS9VED(").
M97=S9W)O=7!S(@IM<V=S='(@(DYY:&5T<V=R=7!P97(B"@HC.B!T96UP;&%T
M97,O9&%T82]T<W9I;F9O+FEN8SHQ-2!T96UP;&%T97,O9&%T82]D871E;6%P
M+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.2!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R
M(").Y'-T82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X
M="`T(%!H87-E<R(*;7-G<W1R(")+;VUM86YD92`T(&9A<V5R(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S`@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HS-S0*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS
M-C8@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-S`*;7-G:60@(DYE>'0@;W!T
M:6]N<R(*;7-G<W1R(").Y'-T82!I;G-TY&QL;FEN9V%R(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#,@;&EB+TAO<F1E+U5)+U!A9V5R+G!H
M<#HQ,#,*;7-G:60@(DYE>'0^(@IM<V=S='(@(D[D<W1A/B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<T"B,Z(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-C0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R(").:6-A<F%G=6$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.38@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,0HC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDV"FUS9VED(").:6=E<B(*;7-G<W1R(").:6=E<B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<S"B,Z(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-C8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.38*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B3FEG97)I82(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-CD*;7-G:60@(DYI9VAT(@IM<V=S
M='(@(DYA='0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$W.0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").:75E(@IM<V=S='(@(DYI
M=64B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.3,U"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY-C8*
M;7-G:60@(DYO(@IM<V=S='(@(DYE:B(*"B,Z('1E;7!L871E<R]A9&UI;B]S
M971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R
M871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B
M1&5T(&9I;FYS(&EN9V5T(&MO;F9I9W5R871I;VYS9&%T82!A='0@=FES82!S
M:VEL;&YA9&5R(&;V<BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(N<&AP.C$P-0HC.B!F<F%M97=O<FLO5D937TE33R])4T]7<FET
M97(N<&AP.C$Q,2!L:6(O5D93+TE33U=R:71E<BYP:'`Z,3`V"FUS9VED(").
M;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*
M;7-G<W1R("));F=E;B!T:6QL9^1N9VQI9R!S=')A=&5G:2!F]G(@871T('-K
M87!A($E33RUI;6%G92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,3,*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G
M<W1R("));G1E(&5N(&)A=&-H;6%L;"XB"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HW.2!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HR-#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z,C8W(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C<Y"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C(T-2!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+G!H<#HR-C<*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HQ,#$*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HS.#4*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT
M,#<*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O
M<VET:6]N(@IM<V=S='(@(D1E="!F:6YN<R!I;F=E="!B;&]C:R!PY2!D96X@
M8F5GY')D82!P;W-I=&EO;F5N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M
M8V%L+G!H<#HU,"!L:6(O2&]R9&4O075T:"]M8V%L+G!H<#HU,`IM<V=I9"`B
M3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B26YG970@:V%L96YD97)N86UN(&;V<B!-0T%,(&%U
M=&5N=&ES97)I;F<@86YG:79E="XB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H
M<#HU-`IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R("));F=E;B#D;F1R:6YG
M+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@
M8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R("));F=A('5N
M9&5R8F5H]G)I9VAE=&5R(&MA;B!LY&=G87,@=&EL;"!D96X@:.1R(&)E:/9R
M:6=H971E;BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V-R!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0X,@HC.B!F<F%M97=O<FLO571I
M;"]5=&EL+G!H<#HW-S,@;&EB+TAO<F1E+G!H<#HQ-CD@;&EB+TAO<F1E+G!H
M<#HU,#@*(SH@;&EB+TAO<F1E+U5T:6PN<&AP.C<V.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@)7,N(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R97)I;F=S:6YF;W)M
M871I;VX@86YG:79E;B!F]G(@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX,C0@;&EB+U9&4R]F='`N<&AP.C@U-0IM<V=I9"`B3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N
M(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R97)I;F=S:6YF;W)M871I;VX@86YG
M:79E;B!F]G(@1E10(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C8V.2!L:6(O5D93+W-Q;"YP:'`Z-C<R"FUS9VED(").;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS
M9W-T<B`B26YG96X@:V]N9FEG=7)E<FEN9W-I;F9O<FUA=&EO;B!A;F=I=F5N
M(&;V<B!344P@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HW,3<@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S(U"FUS9VED(").;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I
M;&4@5D93+B(*;7-G<W1R("));F=E;B!K;VYF:6=U<F5R:6YG<VEN9F]R;6%T
M:6]N(&%N9VEV96X@9O9R(%-13"UF:6P@5D93+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET
M(&QE9G0N(@IM<V=S='(@(DEN9V5N(&MR961I="!K=F%R+B(*"B,Z(&9R86UE
M=V]R:R],:6YK<R],:6YK<RYP:'`Z,C4V"B,Z(&9R86UE=V]R:R]296QA=&EO
M;G-H:7`O4F5L871I;VYS:&EP36%N86=E<BYP:'`Z,C4Q"FUS9VED(").;R!D
M97-C<FEP=&EO;B!F;W5N9"(*;7-G<W1R(")"97-K<FEV;FEN9R!S86MN87,N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S0*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM
M<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(DEN9V5N
M(&UO='1A9V%R92!A;F=I=F5N+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R
M;W=S97(N<&AP.C@W,B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3(P"FUS9VED
M(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(DEN9V5N(&9I;"!U<'!L861D
M860B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC
M;VYS(&9O=6YD+B(*;7-G<W1R("));F=A(&EK;VYE<B!H:71T861E<RXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$V(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$S,`IM<V=I
M9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R("));F=E;B!O<G0@86YG
M:79E;BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"FUS
M9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B26YG96X@;W)T
M(&%N9VEV96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S,*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B
M26YG970@;65D9&5L86YD92!B:69O9V%D97,N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C
M:69I960N(@IM<V=S='(@(DEN9V5T(&YA;6X@86YG:79E="XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PHC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N
M=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R("));F=E;B!N=6UM97(@86YG:79E
M="XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@(DYO(&]F
M9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("));F=A(&]F]G)S:^1M9&$@=FES
M:&5T<V]R9"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$@
M;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("))
M;F=E="!L]G-E;F]R9"!F]G(@2%144"UA=71E;G1I<V5R:6YG(&%N9VEV970N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ,#@@;&EB+TAO
M<F1E+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YG970@
M;/9S96YO<F0@9O9R($E-05`M875T96YT:7-E<FEN9R!A;F=I=F5T+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S(@;&EB+TAO<F1E+T%U
M=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YG970@;/9S
M96YO<F0@9O9R($ME<F)E<F]S+6%U=&5N=&ES97)I;F<@86YG:79E="XB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&]G:6XN<&AP.C@T"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<&%M+G!H<#HW-2!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HW-PHC.B!L:6(O
M2&]R9&4O075T:"]L;V=I;BYP:'`Z.#0@;&EB+TAO<F1E+T%U=&@O<&%M+G!H
M<#HW-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R("));F=E="!L]G-E;F]R9"!F]G(@3&]G
M:6XM875T96YT:7-E<FEN9R!A;F=I=F5T+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<&%S<W=D+G!H<#HQ,S4@;&EB+TAO<F1E+T%U=&@O<&%S<W=D+G!H
M<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(DEN9V5T(&SV<V5N;W)D(&;V<B!0
M05-35T0M875T96YT:7-E<FEN9R!A;F=I=F5T+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<VUB+G!H<#HX-"!L:6(O2&]R9&4O075T:"]S;6(N<&AP.C@T
M"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R("));F=E="!L]G-E;F]R9"!F]G(@4TU"+6%U=&5N
M=&ES97)I;F<@86YG:79E="XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C$R.#8@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C@W
M"FUS9VED("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V
M:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W
M;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG
M('-I9VYU<',N(@IM<V=S='(@(DEN9V$@=N1N=&%N9&4@<F5G:7-T<F5R:6YG
M87(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C<T.`IM<V=I9"`B3F\@
M<75O=&$@<V5T(@IM<V=S='(@(DEN9V5N(&MV;W1A(&%N9VEV96XB"@HC.B!L
M:6(O5D93+G!H<#HW-C8*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B
M26YG96X@:W9O=&$@86YG:79E;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*
M;7-G<W1R("));F=A(')E9VQE<B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C0T.2!L:6(O1FEL92]#4U8N<&AP.C0X,@IM<V=I9"`B3F\@<V5P
M87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B26YG96X@879G<N1N<V%R92!A
M;F=I=F5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(DEN9V$@
M<VED;W(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X,R!L:6(O
M5D93+W-M8BYP:'`Z-3@W"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T<B`B
M26YG96X@<^5D86X@9FEL(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$R-@IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B
M;&4@9F]R(&-A8VAE+B(*;7-G<W1R("));F=E;B!T96UP;W+D<FMA=&%L;V<@
M=&EL;&?D;F=L:6<@9O9R(&-A8VAE+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S$*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(R
M,0IM<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM
M<V=S='(@(DEN9V5T(&%N=N1N9&%R;F%M;B!O8V@O96QL97(@;/9S96YO<F0@
M<VMI8VMA="XB"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T
M,"!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI
M9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R("));F=E="!G:6QT:6<@6$U,
M+61A=&$@<F5T=7)N97)A9&5S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDT,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.34S"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HY-C0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDX,0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.3<T(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HY.#0*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY
M-0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`Q,@IM
M<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(DEN9V$@=N1R9&5N(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N
M9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(B(*(DEN9V5N('9E<G-I;VX@:&ET=&%D97,@
M:2!D96X@=7)S<')U;F=L:6=A(&MO;F9I9W5R871I;VYE;BX@Q71E<G-K87!A
M("(*(FMO;F9I9W5R871I;VYE;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG
M=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("))
M;F=E;B!V97)S:6]N(&AI='1A9&5S(&D@9&EN(&MO;F9I9W5R871I;VXN(,5T
M97)S:V%P82!K;VYF:6=U<F%T:6]N96XN(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV,#0*;7-G:60@(DYO;B!087)T
M:6-I<&%N="(*;7-G<W1R("))8VME+61E;'1A9V%R92(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4V,"!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HT,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES
M96QE8W0N:6YC.CDS"FUS9VED(").;VYE(@IM<V=S='(@(DEN9V5N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I
M9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R("));F=E;B`H86YVY&YD
M('5N9&5R9O9R<W3E9&0I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*
M;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<R"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-C@@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(DYO<F9O;&OV
M87)N82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B
M3F]R<F$@:&5M:7-FY')E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,R!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,34X"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-CD@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N
M($UA<FEA;F$@27-L86YD<R(*;7-G<W1R(").;W)R82!-87)I86YA]F%R;F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-@HC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDW"FUS9VED(").;W)W87DB"FUS9W-T<B`B3F]R9V4B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,"!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C8T,0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S
M='(@(DEN=&4@969T97(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8S.2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I
M9"`B3F]T($)E9F]R92(*;7-G<W1R("));G1E(&;V<F4B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HT,#@@;&EB+U9&4R]F:6QE+G!H<#HT,34*
M;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R("));G1E(&5N(&MA=&%L
M;V<B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP
M.C8S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M3W5T<'5T4W1R871E9WDN<&AP.C@S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDT"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2YP:'`Z-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU.0HC.B!F<F%M97=O<FLO5D93
M7TE33R])4T]7<FET97(N<&AP.C8W"B,Z(&9R86UE=V]R:R]61E-?25-/+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@T"B,Z(&9R86UE=V]R
M:R]61E-?25-/+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDU
M"B,Z(&9R86UE=V]R:R]61E-?25-/+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2YP:'`Z-#D*(SH@9G)A;65W;W)K+U9&4U])4T\O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+G!H<#HV,`HC.B!L:6(O5D93+TE33U=R:71E<BYP
M:'`Z-C,@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H
M<#HX-`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN
M<&AP.CDU"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+G!H<#HT.`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B16H@
M:6UP;&5M96YT97)A9"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C8X"FUS9VED(").;W0@<V5T(@IM<V=S='(@(D5J(&%N
M9VEV96XB"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(N<&AP.C$T,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S
M<VEO;DAA;F1L97(N<&AP.C$U.`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W,PHC.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X-PHC.B!F<F%M97=O<FLO
M4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-"!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR
M,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z,C0X(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-C4*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,CDW"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,3(@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C,R.0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8R(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HT,C(*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C4P,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<P"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HU.#<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V-2!L
M:6(O5D93+G!H<#HQ.3,*(SH@;&EB+U9&4RYP:'`Z,C`X(&QI8B]61E,N<&AP
M.C(S-"!L:6(O5D93+G!H<#HR-3(@;&EB+U9&4RYP:'`Z,C8Y"B,Z(&QI8B]6
M1E,N<&AP.C(X-2!L:6(O5D93+G!H<#HS,#$@;&EB+U9&4RYP:'`Z,S$V(&QI
M8B]61E,N<&AP.C,S,PHC.B!L:6(O5D93+G!H<#HS-C8@;&EB+U9&4RYP:'`Z
M-#(V(&QI8B]61E,N<&AP.C4P-2!L:6(O5D93+G!H<#HU-S0*(SH@;&EB+U9&
M4RYP:'`Z-3DQ(&QI8B]61E,N<&AP.C8V.2!L:6(O2&]R9&4O4V5S<VEO;DAA
M;F1L97(N<&AP.C$T-0HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP
M.C$V,"!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$W-0HC.B!L:6(O
M2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$X.2!L:6(O2&]R9&4O4V5S<VEO
M;DAA;F1L97(N<&AP.C(S-@IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T
M<B`B4W3V9',@:6YT92XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C0T"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C0T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#4X"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#`*;7-G:60@(DYO=&5S(@IM<V=S='(@
M(D%N=&5C:VYI;F=A<B(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H
M<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S
M='(@(DEN9V5N=&EN9R!A='0@=FES82P@9^4@=&EL;&)A:V$N(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHQ,`IM<V=I9"`B
M3F]T:6-E(@IM<V=S='(@(D]"4R(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HS.#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0R-`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$R(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B;F]V96UB97(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,#4P"FUS9VED(").=6UB97(B"FUS9W-T<B`B3G5M;65R(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R-2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,30R.0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B
M06YT86P@=&5C:V5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V
M.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(S"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T-#4@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-S,*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C<@;&EB+TAO<F1E+T9O<FTN<&AP.C$T
M-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(D%N=&%L(&MO
M;'5M;F5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T-#,@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-S$*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$T,C4@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G
M:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(D%N=&%L(')A9&5R(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B
M3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB
M=71I;VX@;&ES="XB"FUS9W-T<B`B3G5M;65R(&EN=&4@<W!E8VEF:6-E<F%D
M92!F]G(@871T('5P<&1A=&5R82!I(&1I<W1R:6)U=&EO;G-L:7-T86XN(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT
M.#,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HV-C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C8T"FUS9VED(")/2R(*;7-G<W1R(")/2R(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HX-#8*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@
M(D]B:F5K="(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS
M9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R(")/8FIE:W1S:V%P87)E(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$P-"!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3$P.`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B3VMT86PB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@V"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,C,*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,2!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS
M9W-T<B`B;VMT;V)E<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM
M<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B1FEL=&5R(&;V<B!O9O9R
M<VOD;61H971E<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C@*
M;7-G:60@(D]F9FEC92(*;7-G<W1R(")+;VYT;W(B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W
M;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B1V%M;6%L="!O8V@@
M;GET="!L]G-E;F]R9"!FY7(@:6YT92!V87)A('-A;6UA+B(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@IM<V=I9"`B3VQD('!A<W-W;W)D
M(@IM<V=S='(@(D=A;6UA;'0@;/9S96YO<F0B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@
M8V]R<F5C="XB"FUS9W-T<B`B1V%M;6%L="!L]G-E;F]R9"#D<B!F96QA:W1I
M9W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,0HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@(D]M86XB"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW,R!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!
M4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(D1E
M;&%D92!M87!P87(@<W3V9',@96YB87)T(&%V($E-05`M<V5R=G)A<B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I
M=F4@9F]R='5N97,B"FUS9W-T<B`B16YB87)T(&]F]G)S:^1M9&$@=FES:&5T
M<V]R9"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3$@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3DW,0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3@U-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW-0IM<V=I9"`B3VYL>2!O;F4@
M96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R(")%;F1A<W0@96X@92UP
M;W-T861R97-S('1I;&SE=&5N+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D
M;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB
M<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HB16YD87-T(.1G
M87)E(&5L;&5R('-Y<W1E;6%D;6EN:7-T<F%T]G(@:V%N(.1N9')A(.1G87)E
M(&5L;&5R(&)E:/9R:6=H971E<B!PY2`B"B)E;B!U=&1E;&YI;F<B"@HC.B!L
M:6(O0FQO8VLO:69R86UE+G!H<#HS.2!L:6(O0FQO8VLO:69R86UE+G!H<#HT
M,`IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`BUG!P;F$@
M:2!N>71T(&;V;G-T97(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C(T-2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I
M9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M
M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B(@HB3W!E;E-33"UF96PZ
M($1E="!G:6-K(&EN=&4@871T(&5X=')A:&5R82!D871A(&9RY6X@<VEG;F5R
M860@4R]-24U%+61E;"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN
M:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`BUG!P;F$@;.1N:R!I(&YY='0@
M9O9N<W1E<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B
M3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R(")/<&5R871I=G-Y<W1E;2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C`P
M"FUS9VED(")/<'1I;VYA;"!087)T:6-I<&%N="(*;7-G<W1R("))8VME(&]B
M;&EG871O<FES:V$@9&5L=&%G87)E(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUE
M;G4N<&AP.C$U,"!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS
M9VED(")/<'1I;VYS(@IM<V=S='(@(DEN<W3D;&QN:6YG87(B"@HC.B!S97)V
M:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B
M26YS=.1L;&YI;F=A<B!F]G(@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS
M9W-T<B`B4V]R=&5R860@;&ES=&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4V-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V
M.`IM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(D]R9V%N:7-A=&EO;B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")/<F=A;FES871I;VYA
M;"!5;FET(@IM<V=S='(@(D]R9V%N:7-A=&EO;G-E;FAE="(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S0*;7-G:60@(D]R9V%N:7II;F<B"FUS
M9W-T<B`B3W)G86YI<V5R82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U
M"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R
M(")5<G-P<G5N9VQI9R!A<'!L:6MA=&EO;G-M86QL(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@
M=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R(")5<G-P<G5N9VQI9V$@;6%L;&%R
M(&D@)7,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*(SH@<V5R=FEC97,O:V5Y8F]A
M<F0N<&AP.C$Q-R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R(")!;FYA;B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Y
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,38@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$R-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-#0*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N
M(@IM<V=S='(@(D%N9')A(&EN<W3D;&QN:6YG87(B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*
M;7-G<W1R("+$9V%R8F5H]G)I9VAE=&5R(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]P86TN<&AP.C<Y(&QI8B](;W)D92]!=71H+W!A;2YP:'`Z-SD*;7-G
M:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R(")004TM075T96YT:7-E<FEN9R#D<B!I;G1E('1I;&QGY&YG;&EG+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P
M-2!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!
M4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(E!%05(Z.DUA:6PM:V]P<&QI;F<B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C4S(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C$R-S8*;7-G:60@(E!'4"!$:6=I=&%L(%-I
M9VYA='5R92(*;7-G<W1R(")01U`@1&EG:71A;"!3:6=N871U<F4B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,CDY(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C$S,C(*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*
M;7-G<W1R(")01U`@16YC<GEP=&5D($1A=&$B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,S4Q(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C$S-S0*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(E!U8FQI:R!0
M1U`M;GEC:V5L(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3,S,R!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S4V"FUS9VED(")01U`@
M4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(E!'4"!3:6=N960O16YC
M<GEP=&5D($1A=&$B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-C@*;7-G:60@
M(E!(4"!#;V1E(@IM<V=S='(@(E!(4"UK;V0B"@HC.B!A9&UI;B]P:'!S:&5L
M;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R(")02%`M<VMA;"(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS
M9VED(")032!,:6=H="!286EN(@IM<V=S='(@(DSD='0@9O9R;6ED9&%G<W)E
M9VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M.`IM<V=I9"`B4$T@4F%I;B(*;7-G<W1R(")&]G)M:61D86=S<F5G;B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED
M(")032!3:&]W97)S(@IM<V=S='(@(D5F=&5R;6ED9&%G<W-K=7)A<B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED
M(")032!3;F]W(@IM<V=S='(@(D5F=&5R;6ED9&%G<W-N]B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")032!3
M;F]W(%-H;W=E<G,B"FUS9W-T<B`B169T97)M:61D86=S<VMU<F%R(&UE9"!S
M;O8B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M,@IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(D5F=&5R;6ED9&%G<W-O;"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED
M(")032!4+5-T;W)M<R(*;7-G<W1R("+%<VMS:W5R87(@<.4@969T97)M:61D
M86=E;B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@(E!/
M4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(E!/4TE8+71I;&SD
M9V<@<V%K;F%S(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H
M96QL(@IM<V=S='(@(E!?2%`M<VMA;"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B
M"FUS9W-T<B`B571F>6QL;F%D.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.2!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3@W"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-S(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES
M=&%N(@IM<V=S='(@(E!A:VES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,2!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3DT"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-S,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0
M86QA=2(*;7-G<W1R(")086QA=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Y,@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L
M97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R(")086QE<W1I
M;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,@HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B"FUS9W-T<B`B4&%N86UA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDY(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#4*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R
M(")087!U82U.>6$@1W5I;F5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3DU"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-S<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")087)A
M9W5A>2(*;7-G<W1R(")087)A9W5A>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")087)T;'D@0VQO=61Y(@IM
M<V=S='(@(D1E;'9I<R!M;VQN:6=T(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`Q.`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`R,B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY(&QI8B].970O4TU3+W=I;E]H='1P
M+G!H<#HQ-3$*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,C4*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(DSV
M<V5N;W)D(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS
M9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B
M3/9S96YO<F0@Y&YD<F%D97,N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HQ,S(R(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3,R
M,PIM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(DSV<V5N;W)D
M(&9E;&%K=&EG="(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H
M<#HQ-3(@;&EB+TAO<F1E+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A
M<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(DSV<V5N;W)D(&MRY'9S(&;V<B!2041)55,@875T96YT:7-E<FEN
M9RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#4S(&QI8B](;W)D
M92]&;W)M+G!H<#HR,#4W"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA
M=&EO;B(*;7-G<W1R("),]G-E;F]R9"!M960@8F5K<N1F=&5L<V4B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D
M.B(*;7-G<W1R("),]G-E;F]R9#HB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B
M:6QE+FEN8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R("),]G-E;F]R
M9#H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P,S0@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,S@*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S
M(&UU<W0@;6%T8V@N(@IM<V=S='(@(DSV<V5N;W)D(&WE<W1E('9A<F$@;&EK
M82XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S
M=&4B"FUS9W-T<B`B2VQI<W1R82!I;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI
M<&)O87)D(@IM<V=S='(@(DML:7-T<F$@:6X@9G+E;B!U<FML:7!P<VAA;G1E
M<F%R96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@(E/V:W;D9R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O<F5M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU
M<',Z(@IM<V=S='(@(E;D;G1A;F1E(')E9VES=')E<FEN9V%R.B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@
M(DWD;FYI<VMO<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@(E!R;V-E;G0B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]B;W1T;VTN:6YC
M.C8*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G
M<W1R(")5=&;V<B!U;F1E<FCE;&QS9G5N:W1I;VYE<B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT,3`*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B571F]G(@=6YD97)HY6QL
M<V%K=&EV:71E=&5R('9I9"!I;FQO9V=N:6YG/R(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,34V(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,34V"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(D)E:/9R:6=H970B"@HC
M.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G
M:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R(")"
M96CV<FEG:&5T("<E<R<@<F%D97)A9&5S(&EN=&4N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HU.#8@;&EB+U9&4R]S;6(N<&AP.C4Y,`IM<V=I
M9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`BQ71K;VUS="!N96MA9"(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,38T"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,38Q(&QI8B](;W)D92]097)M<R]522YP:'`Z,38T"FUS9VED(")0
M97)M:7-S:6]N<R(*;7-G<W1R(")B96CV<FEG:&5T97(B"@HC.B!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P
M"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C4X"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*
M;7-G<W1R(")"96CV<FEG:&5T<V%D;6EN:7-T<F%T:6]N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8X"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO
M;B(*;7-G<W1R(")097)S;VYL:6<@:6YF;W)M871I;VXB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3@@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,PHC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(")097)U(@IM<V=S='(@(E!E<G4B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`B2'5S9&IU<B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY.2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@V"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-SD@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(D9I;&EP<&EN
M97)N82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.38*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*
M;7-G:60@(E!H;VYE(@IM<V=S='(@(E1E;&5F;VXB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#@P"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B1F]T
M;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`P(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3`*
M(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,"!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(E!I
M=&-A:7)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R(")0:7AL87(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS
M9W-T<B`B2VQI8VCI97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT
M;R!S;VUE(&-E;&PB"FUS9W-T<B`B5F%R(&=O9"!K;&EC:V$@:2!E;B!C96QL
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT
M('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(D)E:W+D9G1A(&%T
M="!D=2!V:6QL(')A9&5R82!V86QD('!O<W0_(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L
M96UE;G0N(@IM<V=S='(@(D)E:W+D9G1A(&%T="!D=2!V:6QL(')A9&5R82!A
M:W1U96QL="!E;&5M96YT+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(U-S$@;&EB+TAO<F1E+T9O<FTN<&AP.C(U-C8*;7-G:60@(E!L96%S92!E
M;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(E9A<B!G;V0@86YG
M92!MY6YA9"!O8V@@Y7(N(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@
M9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(E9A<B!G;V0@86YG92!N
M86UN(&;V<B!K871E9V]R:6XZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3,P,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,P-0IM<V=I9"`B4&QE87-E
M(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B5F%R(&=O9"!A
M;F=E(&=O9&OD;F0@25`M861R97-S+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(V-C`@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-#0*;7-G:60@(E!L
M96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@
M9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(E9A<B!G;V0@86YG92!E='0@
M9VEL=&EG="!D871U;3L@:V]N=')O;&QE<F$@86YT86QE="!D86=A<B!I(&WE
M;F%D96XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C0U,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L
M:60@=&EM92XB"FUS9W-T<B`B5F%R(&=O9"!A;F=E(&5N(&=O9&OD;F0@=&ED
M+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@
M(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS
M9W-T<B`B5F%R(&=O9"!S=6UM97)A(&1I='0@<')O8FQE;2XB"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@
M86YD('!A<W-W;W)D(@IM<V=S='(@(D%N9V4@9&ET="!A;G;D;F1A<FYA;6X@
M;V-H(&SV<V5N;W)D+B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]A9W)E
M96UE;G1?=&]P+FEN8SHQ,@IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O
M;&QO=VEN9R!T97AT+B`@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@
M=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*(E9A<B!G;V0@;.1S
M(&EG96YO;2!F]FQJ86YD92!T97AT+B!$=2!-Q5-412!S86UT>6-K82!M960@
M=FEL;&MO<F5N(&;V<B!A='0@(@HB86YVY&YD82!S>7-T96UE="XB"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S92!R
M96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T
M:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*(E9A
M<B!G;V0@;.1S(&EG96YO;2!F]FQJ86YD92!T97AT+B!$=2!-Q5-412!S86UT
M>6-K82!M960@=FEL;&MO<F5N(&;V<B!A='0@(@HB86YVY&YD82!S>7-T96UE
M="XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C4T,`IM<V=I9"`B(@HB4&QE87-E(')E=FEE=R!T:&4@9F]L;&]W:6YG
M(&EN9F]R;6%T:6]N+"!A;F0@=&AE;B!S96QE8W0@86X@86-T:6]N(&9R;VT@
M=&AE("(*(FUE;G4@8F5L;W<N(@IM<V=S='(@(B(*(DMO;G1R;VQL97)A(&;V
M;&IA;F1E(&EN9F]R;6%T:6]N(&]C:"!VY&QJ('-E9&%N(&5N(&AA;F1L:6YG
M(&D@;65N>6Y<;B(*(FYE9&%N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#,U"FUS9VED(")0;&5A<V4@<V5L96-T
M(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+B(*;7-G<W1R(")6Y&QJ
M(&5N(&AA;F1L:6YG(&9RY6X@;65N>6X@;F5D86XN(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*(SH@;&EB+TAO
M<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S
M92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B06YG92!N
M>71T(&MA=&5G;W)I;F%M;CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$X.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0;VQA;F0B
M"FUS9W-T<B`B4&]L96XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*
M;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@(E!O;&ET:6LB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#@Y"FUS9VED(")0;VQL<R(*;7-G<W1R(")5
M;F1E<G/V:VYI;F=A<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Y,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB
M"FUS9W-T<B`B4&]R='5G86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N
M:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B4&]S:71I;VYE<FEN9R!A=B!B
M:6QD96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G
M<W1R(")0;W-I=&EO;F5R:6YG(&%V('1A8F5L;&5N(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S0S,30N<&AP.C4Q"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N
M9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(E-K<FEV('1I;&P@9&5N(&CD<B!M
M87!P96X@*&5J('1V:6YG870@878@24U!4"DB"@HC.B!C;VYF:6<O=&AE;65S
M+W!O<W1N=6ME+G!H<#HV"FUS9VED(")0;W-T;G5K92(*;7-G<W1R(")0;W-T
M;G5K92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<S(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C<X"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I
M;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(DYE9&5R8O9R9"!D
M92!S96YA<W1E("5S('1I;6UA<FYA.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C@W"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA
M;F-E(@IM<V=S='(@(D-H86YS('1I;&P\8G(O/FYE9&5R8O9R9"(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HY."!L:6(O2&]R9&4O4')E
M9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$
M05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P.B!,
M1$%0+71I;&SD9V<@<V%K;F%S+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]S97-S:6]N+G!H<#HS,R!L:6(O2&]R9&4O4')E9G,O<V5S<VEO;BYP:'`Z
M,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?<V5S<VEO;CH@3V)L
M:6=A=&]R:7-K="!S97-S:6]N<W1I;&SD9V<@:&ET=&%D97,@:6YT92XB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(S,@IM<V=I9"`B4')E<W-U<F4B"FUS
M9W-T<B`B5')Y8VLB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-@IM<V=I
M9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B3'5F='1R>6-K
M('9I9"!H879E=#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(R-`IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R("),=69T=')Y8VLZ("(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ.#@*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P,PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`B1O9R:&%N9'-V:7-N:6YG
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE
M=R!W:6YD;W<B"FUS9W-T<B`B1O9R:&%N9'-G<F%N<VMA(&)I;&0@:2!N>71T
M(&;V;G-T97(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V
M,"!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V-`HC.B!L:6(O2&]R
M9&4O4')E9G,O54DN<&AP.C,U-B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V
M,`IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")&]G)E9^5E;F1E
M(&EN<W3D;&QN:6YG87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R
M(")3:W)I=B!U="!D;VMU;65N="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0Q,B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G
M:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(E!R:79A=&$@;GEC:V5L(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.2!L:6(O2&]R9&4O
M365N=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(E!R;V)L96TB
M"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C<*;7-G:60@(E!R;V)L96T@
M1&5S8W)I<'1I;VXB"FUS9W-T<B`B4')O8FQE;6)E<VMR:79N:6YG(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W,0IM<V=I9"`B4')O:F5C=',B
M"FUS9W-T<B`B4')O:F5K="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X.`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,C@T(&QI8B](;W)D92]&;W)M+G!H<#HR,3$U
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3DR(&QI8B](;W)D92]&;W)M+G!H
M<#HS,C@P"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R(")497AT(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R(")0
M=6)L:6L@;GEC:V5L(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV-#4@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#8*;7-G:60@
M(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(E!U8FQI:R!N>6-K96QA
M;&=O<FET;2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C0T(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L
M:6,@2V5Y($EN9F\B"FUS9W-T<B`B4'5B;&EK(&YY8VME;&EN9F]R;6%T:6]N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C,P(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@
M:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B
M1F5L('9I9"!G96YE<F5R:6YG(&%V('!U8FQI:W0O<')I=F%T(&YY8VME;'!A
M<BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`P(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3$*
M(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,R!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@
M(E!U97)T;R!2:6-O(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N
M<&AP.C4U"FUS9VED(")0=7)G92!M97-S86=E<R(*;7-G<W1R(")296YS82!M
M961D96QA;F1E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DV
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Y-@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T
M<B`B46%T87(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C,*;7-G:60@(E%U
M97)Y(@IM<V=S='(@(D9RY6=A(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C<P"FUS9VED(")1=6]T82(*;7-G<W1R(")+=F]T82(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8S(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-C8T"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@
M2V5Y("@E9"!B:70I(@IM<V=S='(@(E!U8FQI:R!24T$M;GEC:V5L("@E9"!B
M:71A<BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8T(&QI8B](
M;W)D92]&;W)M+G!H<#HR,C8X"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS
M9W-T<B`B16YS:VEL="!V86PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B(*;7-G<W1R(")296=N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G
M:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B5&ED:6=T(')E9VXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I
M;B!,871E(@IM<V=S='(@(E-E;G0@<F5G;B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN(%-H;W=E<B(*
M;7-G<W1R(")296=N<VMU<F%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T
M<B`B4F5G;B!O8V@@<V[V(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R(")2
M96=N('1I;&P@<V[V(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G
M:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(E-L=6UP;>1S<VEG="!V:7-H
M971S;W)D(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8X(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2871I;R(*;7-G<W1R(")&
M]G)HY6QL86YD92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(T
M(&QI8B](;W)D92]097)M<RYP:'`Z,S(T"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,S0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.`HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM
M<V=S='(@(DSD<R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C@W(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HT-PHC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E
M860@;65S<V%G97,B"FUS9W-T<B`B3.1S(&UE9&1E;&%N9&5N(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N(@IM<V=S='(@(E/D:V5R="!A='0@9'4@=FEL;"!R861E
M<F$@)7,_(%)A9&5R:6YG96X@:V%N(&EN=&4@Y6YG<F%S+B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES
M(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"B)3Y&ME
M<G0@871T(&1U('9I;&P@<F%D97)A(&%N=N1N9&%R9&%T82!F]G(@)7,_(%)A
M9&5R:6YG96X@:V%N(&EN=&4@Y6YG<F%S+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R
M(&QA<W0@86-T:6]N(@IM<V=S='(@(D?V<B!O;2!D:6X@<V5N87-T92!I;FUA
M=&YI;F<B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R(")5<'!D
M871E<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDU"FUS9VED(")2
M969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B57!P9&%T
M97)A(&1Y;F%M:7-K82!M96YY96QE;65N=#HB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S0U"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G
M<W1R(")5<'!D871E<F$@<&]R=&%L=GDZ(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#DT(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z.#DX(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$W"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,C,Y"FUS9VED(")296=E>"(*;7-G<W1R(")296=E>"(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-#D@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,R,S4*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@
M(E9I<V$@9O9R:.5L;&%N9&5N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM<V=I
M9"`B4F5L;V%D(@IM<V=S='(@(DQA9&1A(&]M(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,S,*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B2V]M;65N=&%R
M97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C0U-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C0W-@IM<V=I9"`B4F5M96UB97(@=&AE(&9R964O8G5S>2!I;F9O
M<FUA=&EO;BXB"FUS9W-T<B`B2V]M(&EHY6<@:6YF;W)M871I;VX@;VT@;&5D
M:6<O=7!P=&%G96XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-PIM
M<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B1FKD<G)S97)V<F%R(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO
M=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T
M<B`B55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R
M(")482!B;W)T(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q
M"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B5&$@8F]R="!B;&]C:R(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,S(*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U.0IM<V=I
M9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")482!B;W)T(&MO;'5M;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*;7-G
M:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(E1A(&)O<G0@9F]R;6%T
M97)I;F<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C8U.`IM<V=I9"`B4F5M;W9E(&9R;VT@;7D@8V%L96YD87(B"FUS
M9W-T<B`B5&$@8F]R="!F<N5N(&UI;B!K86QE;F1E<B(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G
M<W1R(")482!B;W)T('!A<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR
M,#(*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T
M96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(")2861E<F$@<W!A<F%T('-K
M<FEP="!F<N5N('-E<G9E<FYS('1E;7!O<N1R:V%T86QO9RXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*
M;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B5&$@8F]R="(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM
M<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G
M<W1R(")2861E<F$@9&5N;F$@;F]D(&9RY6X@9&]K=6UE;G1E="(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V
M92!U<V5R(@IM<V=S='(@(E1A(&)O<G0@86YVY&YD87)E(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R(")482!B;W)T(&%N=N1N9&%R
M93H@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C$Y-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C(X,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C,T.0IM<V=I9"`B4F5P;'D@4V5N="XB"FUS9W-T<B`B
M4W9A<B!S:VEC:V%T+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-#4Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-#8X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#<X"FUS9VED(")297!L>2!W:71H($YO
M="!3=7!P;W)T960@365S<V%G92(*;7-G<W1R(")3=F%R82!A='0@8F5GY')A
M;B!I;G1E('-T]F1S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HT-C8*;7-G:60@(E)E<&QY('=I=&@@9G)E92]B=7-Y
M(&9O<B!N97AT(#(@;6]N=&AS+B(*;7-G<W1R(")3=F%R82!M960@:6YF;W)M
M871I;VX@;VT@;&5D:6<O=7!P=&%G96X@9O9R(&MO;6UA;F1E('1VY2!MY6YA
M9&5R+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-#8U"FUS9VED(")297!L>2!W:71H(')E<75E<W1E9"!F<F5E+V)U
M<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(E-V87)A(&UE9"!D96X@8F5GY')D
M82!L961I9R]U<'!T86=E;BUI;F9O<FUA=&EO;F5N+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3@Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E)E<&QY.B`E<R(*;7-G<W1R(")3=F%R.B`E<R(*"B,Z
M(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X(&QI8B](;W)D92]2
M4$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@
M86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(D)E9^1R
M86X@:W5N9&4@:6YT92!B97-V87)A<RX@4F5T=7)N97)A9"!F96QK;V0Z("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#4*;7-G:60@(E)E
M<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B
M1&5N(&5F=&5R9G+E9V%D92!T:N1N<W1E;B!K=6YD92!I;G1E(&AI='1A<RXB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-"!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C0Y,@HC.B!L:6(O2&]R9&4N<&AP.C$W-B!L:6(O
M2&]R9&4N<&AP.C4Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<
M(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R(")%<F9O9')A9"`G)7,G(.1R(&EN=&4@86YG:79E;B!I(&MO;F9I9W5R
M871I;VYE;B!A=B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C8W-2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S,`HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(S(&QI8B]61E,O<W%L+G!H<#HV
M-S@@;&EB+U9&4R]F='`N<&AP.C@V,0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HW,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO
M="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D5R
M9F]D<F%D("<E<R<@Y'(@:6YT92!A;F=I=F5N(&D@:V]N9FEG=7)E<FEN9V5N
M(&%V(%9&4RXB"@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW.#$@;&EB
M+TAO<F1E+U5T:6PN<&AP.C<W-@HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U
M:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R(")%<F9O9')A9"`G)7,G(.1R(&EN=&4@86YG:79E;B!I(&MO;F9I
M9W5R97)I;F=E;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R
M+G!H<#HS,S4@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I
M9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B3V)L:6=A=&]R:7-K='0@9N1L
M="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-3DR"FUS9VED(")297%U:7)E9"!087)T:6-I<&%N="(*;7-G<W1R(")/
M8FQI9V%T;W)I<VL@9&5L=&%G87)E(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTO4F5N9&5R97(N<&AP.C,R,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,S0S
M"B,Z(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,C`@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,`HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,3`P('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(L5T97)S=.1L;"(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E="!0
M87-S=V]R9"(*;7-G<W1R("+%=&5R<W3D;&P@;/9S96YO<F0B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!0
M87-S=V]R9"(*;7-G<W1R("+%=&5R<W3D;&P@;/9S96YO<F0B"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3,P"FUS9VED(")297-T;W)E($QA<W0@475E<GDB
M"FUS9W-T<B`BQ7-T97)TY&QL('-E;F%S=&4@9G+E9V%N(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S
M<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B4F5S=6QT
M870B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L
M871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS
M(@IM<V=S='(@(L5T97)VY&YD('1I;&P@:6YS=.1L;&YI;F=A<B(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE
M=R!P87-S=V]R9"(*;7-G<W1R(")!;F=E(&YY='0@;/9S96YO<F0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`R(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3<*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-2!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B4NEU;FEO;B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B
MQ71E<G-TY&QL(&MO;F9I9W5R871I;VXB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,U"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS
M9W-T<B`B26YS=.1L;&YI;F=A<B!F]G(@4FEC:"!497AT($5D:71O<B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G
M<W1R(")'Y71O<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B2/9G97(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(Q(&QI8B](;W)D92]&
M;W)M+G!H<#HS,3`W"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B2/9G
M97)R=6)R:6LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$W(&QI
M8B](;W)D92]&;W)M+G!H<#HS,3`S"FUS9VED(")2:6=H="!V86QU97,B"FUS
M9W-T<B`B2/9G97)VY')D96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R
M=&EE<RXN+B(*;7-G<W1R(")285]D:6YS=.1L;&YI;F=A<BXN+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU.#,*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O
M;&4B"FUS9W-T<B`B4F]L;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Y.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI
M82(*;7-G<W1R(")2=6WD;FEE;B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,#@*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(R-@IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R(")2
M;W1E<F$@,3@P(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(P-0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C(S"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R(")2;W1E<F$@=N1N
M<W1E<B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,3$*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R
M.0IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(E)O=&5R82!H]F=E<B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(E)A9&EN<W3D
M;&QN:6YG87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R
M(")2861I;G-TY&QL;FEN9V%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@(E)A
M9&5R.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM<V=S='(@(DQI;FIE<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@
M86YD(&-O;'5M;G,B"FUS9W-T<B`B3&EN:F5R('9I<V%S(&UE;&QA;B!A;&QA
M(')A9&5R(&]C:"!K;VQU;6YE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(DQI;FIE<B!V
M:7-A<R!E;F)A<G0@;65L;&%N(&MO;'5M;F5R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B3&EN
M:F5R('9I<V%S(&5N8F%R="!M96QL86X@<F%D97(B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3(P"FUS9VED(")2=6XB"FUS9W-T<B`B2_9R(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DY"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.#<@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B4GES
M<VQA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`S(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,#`*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X."!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)W86YD82(*;7-G<W1R(")2
M=V%N9&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X
M-2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%
M($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(E,O34E-12!S:6=N
M871U<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@
M16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B4R]-24U%+6MR>7!T97)A="!M
M961D96QA;F1E(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX
M,2!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H
M96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")305-,+6%U
M=&5N=&ES97)I;F<@Y'(@:6YT92!T:6QL9^1N9VQI9RXB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-3`V"FUS9VED(")335,@365S<V%G:6YG(@IM
M<V=S='(@(E--4R!M961D96QA;F1E;B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(E-13"US:V%L(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,S(W.`IM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P
M<R(*;7-G<W1R(")344PM<V5K=F5N<R!F]G(@=7!P<VQA9R!A=B!VY')D96XB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,S"FUS9VED(")34T@B
M"FUS9W-T<B`B4U-((@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0HC.B!L:6(O2&]R9&4O
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-5
M0T-%4U,B"FUS9W-T<B`B3%E#2T%4(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS
M9VED(")37U%,(%-H96QL(@IM<V=S='(@(E-?44PM<VMA;"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A
M(@IM<V=S='(@(DSV(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C`W"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#D@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")386EN="!(96QE
M;F$B"FUS9W-T<B`B4V%I;G0@2&5L96YA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,S$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Y,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B
M4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(E-A:6YT($MI='1S(&]C
M:"!.979I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3,Y"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3$@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S
M='(@(E-A:6YT($QU8VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,"!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3@Y"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.3(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0
M:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@(E-A:6YT+5!I97)R92!O8V@@
M36EQ=65L;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-#0*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,R!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@
M86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@(E-A:6YT(%9I;F-E;G0@;V-H
M($=R96YA9&EN97)N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G
M<W1R(")386UM82!R86T@*%]S96QF*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(U,0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DT(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B
M4V%M;V$B"FUS9W-T<B`B4V%M;V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,3(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$Y-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A
M;B!-87)I;F\B"FUS9W-T<B`B4V%N($UA<FEN;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-@HC.B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DV(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PIM
M<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(E-A;R!4;VUE
M(&]C:"!0<FEN8VEP92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3D@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E
M;&QI=&4@4')O=FED97(B"FUS9W-T<B`B4V%T=&5L:71L979E<F%N=/9R(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Q"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3<@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B4V%U
M9&EA<F%B:65N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDY
M"FUS9VED(")3879E(@IM<V=S='(@(E-P87)A(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M879E(%PB)7-<(B(*;7-G<W1R(")3<&%R82`G)7,G(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V
M92`E<R(*;7-G<W1R(")3<&%R82`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]E
M;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R(")3<&%R82!I
M;G-TY&QL;FEN9V%R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM
M<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(
M4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T
M;W)Y+B(*;7-G<W1R("(B"B)3<&%R82!G96YE<F5R860@:V]N9FEG=7)A=&EO
M;B!S;VT@4$A0+7-K<FEP="!T:6QL(&1I;B!S97)V97)S("!T96UP+6MA=&%L
M;V<N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M4W!A<F%D92!K;VYF:6=U<F%T:6]N(&;V<B`E<RXB"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S
M971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")3<&%R
M861E('5P<&=R861E<FEN9W-S8W)I<'0@=&EL;#H@)7,N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E-C871T
M97)E9"!4+5-T;W)M<R(*;7-G<W1R(")3<')I9&1A(.5S:W-K=7)A<B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G
M<W1R(")6971E;G-K87`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I
M9"`B4V5A<F-H(@IM<V=S='(@(E/V:R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS,C(*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(E/V
M:VUO=&]R97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3<S(&QI
M8B](;W)D92]&;W)M+G!H<#HR.34Y"FUS9VED(")396QE8W0@1FEL97,B"FUS
M9W-T<B`B5N1L:B!F:6QE<B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-3D*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0X-0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")6
MY&QJ(&5T="!D871U;2(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B5N1L
M:B!G<G5P<"!A='0@;.1G9V$@=&EL;"(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R
M(")6Y&QJ(&YY(.1G87)E(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B5N1L:B!S
M97)V97(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I
M9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B5N1L:B!A;G;D;F1A
M<F4@871T(&SD9V=A('1I;&PB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-C4R"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-S8*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B5N1L
M:B!A;&QA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,R!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C8T-PIM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O
M;7!O;F5N=',N(@IM<V=S='(@(E;D;&H@9&%T=6UK;VUP;VYE;G1E<BXB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#0V"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@
M(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B5N1L:B!E='0@;V)J96MT(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U,PHC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"FUS9VED
M(")396QE8W0@;F]N92(*;7-G<W1R(")6Y&QJ(&EN9V5N(@H*(SH@<V5R=FEC
M97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A
M8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@
M=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E
M82XB"FUS9W-T<B`B(@HB06YG92!D92!T96-K96X@9'4@8F5H]G9E<B!I(')U
M=&]R;F$@;F5D86XN($1U(&MA;B!S961A;B!K;W!I97)A(&]C:"!K;&ES=')A
M("(*(FEN(&1E;2!I('1E>'1A<G5T86XN(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z
M(@IM<V=S='(@(E;D;&H@879G<N1N<V%R92!F]G(@9&%T=6TZ(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T
M92!F;W)M870Z(@IM<V=S='(@(E;D;&H@9&%T=6UF;W)M870Z(@H*(SH@=&5M
M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L
M96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@
M(E;D;&H@:61E;G1I=&5T(&1U('9I;&P@Y&YD<F$Z(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O=&EM92YI;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI
M;6ET97(Z(@IM<V=S='(@(E;D;&H@879G<N1N<V%R92!F]G(@=&ED.B(*"B,Z
M('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE
M('1I;64@9F]R;6%T.B(*;7-G<W1R(")6Y&QJ('1I9'-F;W)M870Z(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W
M;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(E;D;&H@=';E(&UA=&-H86YD
M92!FY&QT.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,3`*;7-G:60@
M(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B5N1L:B!D:71T
M(&;D<F=S8VAE;6$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U,@IM
M<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R
M(")!;F=E(&1I='0@9O9R=F%L9&$@<W!RY6LZ(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-3,*;7-G:60@(E-E;F0@
M3&%T97-T($EN9F]R;6%T:6]N(@IM<V=S='(@(E-K:6-K82!S96YA<W1E(&EN
M9F]R;6%T:6]N96XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")3:VEC
M:V$@<')O8FQE;7)A<'!O<G0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`Q,0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3`T,@IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B4VMI
M8VMA(%--4R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(Q,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R
M(")396YE9V%L(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C,*;7-G:60@
M(E-E;G-O<CH@(@IM<V=S='(@(E-E;G-O<CH@(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-0HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(R"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,3`@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B<V5P
M=&5M8F5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R
M8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(E-E<F)I96X@;V-H($UO;G1E
M;F5G<F\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P
M,2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,@IM<V=I9"`B4V5R:6%L
M($YU;6)E<B(*;7-G<W1R(")397)I96YU;6UE<B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-#D*;7-G:60@(E-E<G9E<B!D871A('=R;VYG
M(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E-E<G9E<FEN<W3D;&QN:6YG
M87(@9F5L86MT:6=A(&5L;&5R(&EN86MT:78@<V5R=F5R+B(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R
M(")397-S:6]N<V%D;6EN:7-T<F%T:6]N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X
M<&ER960N(@IM<V=S='(@(E-E<W-I;VYS+4E$(&AA<B!GY71T('5T+B(*"B,Z
M(&QI8B]A<&DN<&AP.C$T-0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B4V5S
M<VEO;F5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-"!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C,Q.`IM<V=I9"`B4V5T(@IM<V=S='(@(E/D='0B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SD*;7-G:60@(E-E="!O<'1I
M;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO
M=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@HB2V]N9FEG=7)E<F$@86QT
M97)N871I=B!S;VT@;?9J;&EG9_9R(.5T97)S=.1L;&YI;F<@878@8F]R=&=L
M]FUT(&SV<V5N;W)D+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3@*
M;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O
M(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R(")+;VYF:6=U<F5R
M82!F:N1R<G-E<G9R87(@<V]M(&1U('9I;&P@:V]M;6$@Y70@9G+E;B!D:6X@
M<&]R=&%L+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-PIM<V=I9"`B
M4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T
M92!O<'1I;VYS+B(*;7-G<W1R(")!;F=E(&1I='0@9O9R=F%L9&$@<W!RY6LL
M('1I9'-Z;VX@8V]H(&1A='5M:6YS=.1L;&YI;F=A<BXB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3`Q"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P
M(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@
M86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HB4^1T
M="!D:71T(&EN:71I86QA(&%P<&QI:V%T:6]N+"!FY')G<V-H96UA+"!S:61U
M<'!D871E<FEN9R!O8V@@86YD<F$@(@HB=FES;FEN9W-I;G-TY&QL;FEN9V%R
M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*;7-G:60@(E-E='5P
M(@IM<V=S='(@(E-E='5P(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN
M9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I
M;&%B;&4B"FUS9W-T<B`B2V]N9FEG=7)A=&EO;G-U<'!G<F%D97)I;F=S<VMR
M:7!T(&9I;FYS('1I;&QGY&YG;&EG82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-S4*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I
M8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(D1E="!F:6YN<R!F
M;&5R82!O<G1E<B!M960@<&%R86UE=&5R;CHB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,#,*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(P,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G
M:60@(E-E>6-H96QL97,B"FUS9W-T<B`B4V5Y8VAE;&QE<FYA(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y.`IM<V=I9"`B4VAO<'!I;F<B"FUS
M9W-T<B`B2&%N9&5L(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z-#,*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B2V]R="!S=6UM
M97)I;F<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4P"FUS9VED(")3
M:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B
M"FUS9W-T<B`B4VMA;&P@9V5N=N1G<W1A;F=E;G1E<B!D969I;F5R87,@9O9R
M(&1E(&9L97-T82!LY&YK87(_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HS,C,@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C,*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C8W"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,3,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@
M(E-H;W<B"FUS9W-T<B`B5FES82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R
M96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B(@HB5FES82!S:VEL;&YA9&5R(&UE;&QA;B!D
M96X@86MT=65L;&$@;V-H(&1E;B!N>6QI9V5N('-K87!A9&4@:V]N9FEG=7)A
M=&EO;F5N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.30*;7-G:60@
M(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T
M<B`B5FES82!S96YA<W1E(&EN;&]G9VYI;F=S=&ED('9I9"!I;FQO9V=N:6YG
M/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C4@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$W-CD*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I
M9VEN86PB"FUS9W-T<B`B5FES82!I;G-TY&QL;FEN9R!F]G(@871T(&)E:.5L
M;&$@;W)I9VEN86PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$S
M(&QI8B](;W)D92]&;W)M+G!H<#HR-SDY"FUS9VED(")3:&]W('!I8VME<B(*
M;7-G<W1R(")6:7-A('!A;&5T="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,S`*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B
M"FUS9W-T<B`B5FES82`G=&%B96QL86MT:79I=&5T97(G(&D@;65N>6X_(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R(")6
M:7-A(&UE;GD@9O9R("5S('1I;&P@=N1N<W1E<C\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@
M(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T
M<B`B5&%B96QL8V5L;&EN<W3D;&QN:6YG87(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H
M;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(E1A8F5L
M;&EN<W3D;&QN:6YG87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE
M(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")486)E;&QI;G-TY&QL
M;FEN9V%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T
M:65S(&1I86QO9R(*;7-G<W1R(")6:7-A(&1I86QO9W)U=&$@9O9R(&)I;&1E
M9V5N<VMA<&5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,R!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3<V-PIM<V=I9"`B4VAO=R!U<&QO860B"FUS
M9W-T<B`B5FES82!U<'!L861D;FEN9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")3:&]W97)S(@IM<V=S='(@
M(E-K=7)A<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4R"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(E1I9&EG82!S
M:W5R87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,PIM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(E-E;F$@<VMU<F%R
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*
M;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(E-K=7)A
M<B!I(&[D<FAE=&5N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z-#@P(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C0X,`HC.B!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q.0IM<V=I9"`B
M4VAR:6YK(@IM<V=S='(@(D;V<FUI;G-K82(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C<W-"!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HX,S8*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z.3(R(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDX
M-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P.#<*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$Q-B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,30Y"B,Z(&QI8B](;W)D92]";&]C:R],
M87EO=70N<&AP.C<W-"!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HX,S8*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z.3(R(&QI8B](;W)D92]"
M;&]C:R],87EO=70N<&AP.CDX-`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+G!H<#HQ,#0W(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C$P.#<*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,3$Q-B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+G!H<#HQ,30Y"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z.3$P"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z.3<R"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z,3`U.`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C$Q,C`*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HQ,3@S"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M,3(R,PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R
M-3(*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C@U
M"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@
M;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B2W)Y;7`@96QL97(@9FQY
M='1A(&)O<G0@;N1R;&EG9V%N9&4@8FQO8VL@9O9R<W0B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`U(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3$*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(P,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R(")3:65R<F$@3&5O;F4B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8U(&QI8B](
M;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8V"FUS9VED(")3:6=N('5P(@IM<V=S
M='(@(E)E9VES=')E<F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<Q,B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<Q,PIM<V=I
M9"`B4VEG;F%T=7)E(@IM<V=S='(@(E-I9VYA='5R(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3$@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T
M<B`B4VEG;F%T=7)A;&=O<FET;2(*"B,Z(&-O;F9I9R]T:&5M97,O<VEM<&QE
M>"YP:'`Z-@IM<V=I9"`B4VEM<&QE>"(*;7-G<W1R(")3:6UP;&5X(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`V"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#(@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B4VEN9V%P;W)E
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8Y"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#<@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C0V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y
M,S`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,R!L:6(O2&]R9&4O
M1F]R;2YP:'`Z.3`P(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$Y"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,C0Q(&QI8B](;W)D92]&;W)M+G!H<#HR,C4P(&QI
M8B](;W)D92]&;W)M+G!H<#HR.3$V"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS
M,3`Y(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8U"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<R(&QI8B](;W)D92]-24U%+U9I
M97=E<B]T9WHN<&AP.C@T"FUS9VED(")3:7IE(@IM<V=S='(@(E-T;W)L96LB
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]B;W1T;VTN:6YC
M.CD*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B079B<GET('5N
M9&5R:.5L;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(Q,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T
M<B`B4VQO=F%K:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-2!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C`X"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#0@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI82(*
M;7-G<W1R(")3;&]V96YI96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R(*;7-G<W1R(")3;O8B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I
M9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B4V[V<VMU<B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H
M;W=E<G,B"FUS9W-T<B`B4V[V<VMU<F%R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N;W<@4VAO=V5R<R!%
M87)L>2(*;7-G<W1R(")4:61I9V$@<V[V<VMU<F%R(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-N;W<@4VAO
M=V5R<R!,871E(@IM<V=S='(@(E-E;F$@<V[V<VMU<F%R(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR.#4*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R
M(")3;O9D:G5P.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X.0IM<V=I
M9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B36]T<W9A
M<F%N9&4@<V[V(&D@=F%T=&5N.B`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,#(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(P-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O
M;&]M;VX@27-L86YD<R(*;7-G<W1R(")386QO;6]N]F%R;F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`V(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,30*(SH@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(P-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B4V]M86QI82(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*
M;7-G<W1R(")3Y6YG97(@;V-H(&1I:W1E<B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Y,C8@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,3(*;7-G:60@
M(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(E-O<G1E<FEN9W-I;W)D
M;FEN9W-V86PB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,3@Y(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-3D*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X
M.2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-PHC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-R!L:6(O3F5T+U--4R]W
M:6Y?:'1T<"YP:'`Z,38V"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ
M.#D*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(FOD;&QA9')E<W,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-34*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-R!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R(")3
M>61A9G)I:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B
M4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Q"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,#@@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD
M=VEC:"!)<VQA;F1S(@IM<V=S='(@(E/V9')A($=E;W)G:6$@;V-H(%-Y<W-A
M;F1W:6-H]F%R;F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L
M;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM
M<V=S='(@(E/D9')A(&AE;6ES9N1R96XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E
M;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R(")5=')Y;6UE(&UE;&QA;B!I;G1I
M;&QI9V=A;F1E(&-E;&QE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E
M;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(E5T<GEM;64@;65L;&%N
M(&EN;F5HY6QL(&]C:"!K86YT96X@:2!C96QL96XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HX,34@;&EB+TAO<F1E+T9O<FTN<&AP.C@Q.0IM<V=I
M9"`B4W!A8V5R(@IM<V=S='(@(DUE;&QA;G)U;2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A
M8VEN9R(*;7-G<W1R(")-96QL86YR=6TB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG
M(&%N9"!P861D:6YG(@IM<V=S='(@(DUE;&QA;G)U;2!O8V@@=71JY&UN:6YG
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@P"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#D@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S='(@(E-P86YI96XB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`P"FUS9VED(")3<&%M(@IM
M<V=S='(@(E-P86TB"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G
M:60@(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(DEN;6%T;FEN
M9R!A=B!S<&5C:65L;&$@=&5C:V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L
M;"(*;7-G<W1R(")$96QA(&-E;&PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU
M;6XB"FUS9W-T<B`B1&5L82!K;VQU;6XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R
M;W<B"FUS9W-T<B`B1&5L82!R860B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C$*;7-G:60@(E-P;W)T<R(*;7-G<W1R(")3<&]R=&5R(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@X(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#$*(SH@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(Q,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(E-R:2!,86YK82(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-B!L:6(O0FQO8VLO;65T
M87(N<&AP.C@Q"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R(")3=&%N9&%R9"(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K
M(@IM<V=S='(@(E-T87(@5')E:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#0S"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-30X"FUS9VED(")3=&%R="(*;7-G
M<W1R(")3=&%R="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.38@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P.0HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C4Y,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y-0IM<V=I9"`B4W1A
M<G0@>65A<B(*;7-G<W1R(")3=&%R=.5R(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-S`@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU-S$*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(E-T870@
M96QL97(@<F5G:6]N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HU.#,*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN
M9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G<W1R(")3=&%T=7,B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U(&QI8B](;W)D92]&;W)M
M+G!H<#HR.#`Q"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R("),86=R
M:6YG<V9O<FUA="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3<R(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")3
M=')E970@061D<F5S<R(*;7-G<W1R(")'871U861R97-S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R
M:6ME=&AR;W5G:"(*;7-G<W1R(")'96YO;7-T<G5K96XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C,S(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,W
M"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R(")3='+D;F=L:7-T82(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S,@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$X-S<*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S
M(@IM<V=S='(@(E1A(&)O<G0@9&]MY&X@9G+E;B!A9')E<W-E;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*
M;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(E-T:6P@6T-34UTB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED
M(")3=2(*;7-G<W1R(")3]B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B2V%N(&EN=&4@:&ET=&$@=6YD97)K871A;&]G
M("<E<R<N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HW,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW
M,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R("+$<F5N9&4B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD
M97)E<BYP:'`Z,S$W"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S8@;&EB+TAO
M<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S
M='(@(E-K:6-K82(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T
M:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E
M<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*(D1I;B!B96?D
M<F%N(&%T="!LY&=G82!T:6QL(%PB)7-<(B!T:6QL('-Y<W1E;65T(&AA<B!S
M:VEC:V%T<RX@1'4@:V%N(&EN=&4@(@HB;&]G9V$@:6X@:6YN86X@9&EN(&)E
M9^1R86X@:&%R(&%C8V5P=&5R871S+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G
M<W1R(").961SY&YK="(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#0*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M<W1A='5S+G!H<#HR.`HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B3'EC
M:V%T(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*
M;7-G<W1R("(G)7,G(&QA9&5S('1I;&P@:2!S>7-T96UE="XB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES
M=&5M+B(*;7-G<W1R(")2861E<F%D92!I;F9O<FUA=&EO;B!O;2!A;G;D;F1A
M<F4@)R5S)RXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS
M+V1E;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R("(G)7,G(')A9&5R861E<RXB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB
M"FUS9W-T<B`B)R5S)R!T;V=S(&)O<G0@9G+E;B!S>7-T96UE="XB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@
M<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S
M+B(*;7-G<W1R("(B"B)+;VYF:6=U<F%T:6]N96X@:&%R(.5T97)S=.1L;'1S
M+B!,861D82!O;2!S:61A;B!F]G(@871T('-E(&;V<N1N9')I;F=A<BXB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B4W!A<F%D92!B86-K=7!K;VYF:6=U<F%T
M:6]N+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(")3<&%R861E(&)A8VMU<&MO
M;F9I9W5R871I;VX@)7,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*
M;7-G<W1R("(G)7,G('5P<&1A=&5R861E<RXB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B
M4VMR978@)7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,#0*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,2!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@
M(E-U9&%N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HU-3@*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HU-C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R(")3
M86UM86YS=.1L;&YI;F<B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*
M;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(E-O;'5P<&?E;F<B"@HC.B!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B
M4V]L;F5D9^5N9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8P"FUS9VED(")3=6YN>2(*;7-G<W1R(")3;VQI9W0B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`U"FUS9VED(")3=6YR:7-E
M(@IM<V=S='(@(E-O;'5P<&?E;F<B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O
M4W5N<V5T(@IM<V=S='(@(E-O;'5P<&?E;F<O;F5D9^5N9R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#0*;7-G:60@(E-U;G)I<V4Z("(*
M;7-G<W1R(")3;VQU<'!GY6YG.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C`X"FUS9VED(")3=6YS970B"FUS9W-T<B`B4V]L;F5D9^5N
M9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#<*;7-G:60@
M(E-U;G-E=#H@(@IM<V=S='(@(E-O;&YE9&?E;F<Z("(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R
M<V-R:7!T(@IM<V=S='(@(E5P<&CV:F0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S@P"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(E-U<'!O<G0B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`V(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,34*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(E-U<FEN
M86UE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@(E-U<FYA;64B
M"FUS9W-T<B`B169T97)N86UN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-2!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C`Y"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,3,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L
M8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(E-V86QB87)D(&]C:"!*86X@
M36%Y96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`X(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,3D*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-"!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R
M(")3=V%Z:6QA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,#4*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-2!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G
M<W1R(")3=F5R:6=E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C4V"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,38@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM
M<V=S='(@(E-C:'=E:7HB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HX-@IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R(")3>6MR;VYI
M<V5R:6YG<VQO9V<@<F%D97)A9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-#4*;7-G:60@(E-Y;F--3"(*;7-G<W1R(")3>6YC34PB"@HC.B!F<F%M
M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<@;&EB+TAO<F1E+U-13"]+
M97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@
M=&5R;7,B"FUS9W-T<B`B4WEN=&%X9F5L(&D@<_9K:W)I=&5R:6$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`W(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3@*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-R!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@
M(E-Y<FEE;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8Q"FUS9VED(")4+5-T;W)M(@IM<V=S='(@(L5S:W-K=7(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B
M5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`BQ7-K<VMU<F%R(&]C:"!B;.5S
M:6=T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C,*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(L5S:W-K=7)A<B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4
M+5-T;W)M<R!%87)L>2(*;7-G<W1R(")4:61I9V$@Y7-K<VMU<F%R(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$V-B!L:6(O2&]R9&4O1&%T
M82]T<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B5%-6+69I
M;"(*"B,Z(&9R86UE=V]R:R]522]522]486)L92YP:'`Z,3,T(&QI8B](;W)D
M92]522]486)L92YP:'`Z,3,T"FUS9VED(")486)L92(*;7-G<W1R(")486)E
M;&PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(E1A
M8F5L;&EN<W3D;&QN:6YG87(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y
M<&4O=&%B;&5S970N<&AP.C4W"B,Z(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B
M;&5S970N<&AP.C4W"FUS9VED(")486)L92!3970B"FUS9W-T<B`B5&%B96QL
M=7!P<^1T=&YI;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S(@IM
M<V=S='(@(E1A8F5L;&EN<W3D;&QN:6YG87(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S0@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS9W-T<B`B5&%I=V%N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0
M<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R(")486EW86XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Y(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C4*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(Q.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B5&%J:6MI<W1A;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3(@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-0HC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O
M9B(*;7-G<W1R(")486YZ86YI82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B
M3>5L.B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#0Y(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ.#D*;7-G:60@(E1A<VMS(@IM<V=S='(@(E5P
M<&=I9G1E<B(*"B,Z(&-O;F9I9R]T:&5M97,O9V5N;F5V:6QL:65R<RYP:'`Z
M,30*;7-G:60@(E1E86PB"FUS9W-T<B`B5&5A;"(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3<T"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(E1E
M;&5F;VYN=6UM97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-PIM<V=I
M9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B2/9G<W1A('1E;7!E
M<F%T=7(@<V5N87-T92!T:6UM96XZ("(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C(Q"FUS9VED(")496UP97)A='5R92(*;7-G<W1R(")496UP97)A='5R
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,@IM<V=I9"`B
M5&5M<&5R871U<F4Z("(*;7-G<W1R(")496UP97)A='5R.B`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@R"B,L('!H<"UF;W)M870*;7-G
M:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B
M"FUS9W-T<B`B5&5M<&5R871U<CQB<B`O/B@E<TUA>"5S+R5S36EN)7,I("9D
M96<[)7,B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8X
M-R!L:6(O2&]R9&4O5&5M<&QA=&4N<&AP.C8Y-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")+86X@
M:6YT92!H:71T82!M86QL("5S+B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,38Y"FUS9VED(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!
M;G;D;F1A<F%D;6EN:7-T<F%T:6]N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-#$*;7-G:60@(E1E;G1A=&EV96QY
M($%C8V5P="!R97%U97-T(@IM<V=S='(@(D=O9&OD;FX@8F5GY')A;B!P<F5L
M:6UI;N1R="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-C@Y"FUS9VED(")496YT871I=F5L>2!!8V-E<'1E9"(*;7-G
M<W1R(")0<F5L:6UI;N1R="!A8V-E<'1E<F%T(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,U
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$U(&QI8B](;W)D92]&;W)M+G!H
M<#HS,S,Q"FUS9VED(")497AT(@IM<V=S='(@(E1E>'0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S<Y"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B
M16YB87)T('1E>'0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@
M(E1E>'1J=7-T97)I;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(E1E>'1T
M;W`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C4Y"FUS9VED(")4:"(*;7-G<W1R(")4;R(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DT"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R(")4:&%I
M("A425,M-C(P*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(R-`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS
M9W-T<B`B5&AA:6QA;F0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.#@*;7-G:60@(E1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B5&%C:R!F]G(@871T(&1U(&%N=N1N9&5R('-Y<W1E;65T+B(*"B,Z
M('-E<G9I8V5S+VQI;FMS+V1E;&5T92YP:'`Z,S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE("5S(&QI;FL@=&\@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS
M9W-T<B`B3.1N:V5N("5S('1I;&P@)7,@:&%R(')A9&5R871S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(P(&QI8B]61E,O9G1P+G!H<#HX
M-3$*;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(D944"UT:6QLY&=G970@Y'(@:6YT92!T:6QL9^1N9VQI9W0N
M(@H*(SH@;&EB+TAO<F1E+TAI<W1O<GDN<&AP.C4U"FUS9VED(")4:&4@2&ES
M=&]R>2!S>7-T96T@:7,@9&ES86)L960N(@IM<V=S='(@(DAI<W1O<FEK<WES
M=&5M970@Y'(@879A:W1I=F5R870N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,S0@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,S@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN
M92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA
M8BUI;G1E9W)A=&EO;G-G<N1N<W-N:71T970@<W3V9&5R(&EN=&4@7"(E<UPB
M(@H*(SH@;&EB+TYE="])35-0+T)O;VLN<&AP.C$R.3@*;7-G:60@(E1H92!)
M35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(DE-
M4U`M;&]G9V5N(&MU;F1E(&EN=&4@:6YI=&EE<F%S+B(*"B,Z('-E<G9I8V5S
M+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@
M8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R(")+;&%S
M<V5N($UA:6YT96YA;F-E.CH@:W5N9&4@:6YT92!L861D87,B"@HC.B!S97)V
M:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T
M:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B26YS
M=.1L;&YI;F=S9O9N<W1R970@:&%R('-TY&YG=',N($%V<VQU=&%R+B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"B,Z(&QI8B](;W)D92]097)M<RYP
M:'`Z,3@Y(&QI8B](;W)D92]097)M<RYP:'`Z,C`P(&QI8B](;W)D92]097)M
M<RYP:'`Z,C$Q"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,C(S(&QI8B](;W)D
M92]097)M<RYP:'`Z,C,T(&QI8B](;W)D92]097)M<RYP:'`Z,C4R"B,Z(&QI
M8B](;W)D92]097)M<RYP:'`Z,C8T(&QI8B](;W)D92]097)M<RYP:'`Z,S`S
M"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U
M<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB
M=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*(D%D;6EN:7-T
M<F%T]G)E;B!MY7-T92!K;VYF:6=U<F5R82!E;B!P97)M86YE;G0@0F5H]G)I
M9VAE=',M:V]P<&QI;F<@;VT@9'4@(@HB=FEL;"!A;G;D;F1A($)E:/9R:6=H
M971E<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G
M<W1R(")%;F)A<G0@;F5D<F4@<VED86XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0Y"FUS9VED(")4:&4@8V%L96YD
M87(@9&%T82!I<R!I;G9A;&ED(@IM<V=S='(@(DMA;&5N9&5R:6YF;W)M871I
M;VYE;B#D<B!F96QA:W1I9R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E
M<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O
M=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B2V]N=&%K=&5N<R!)
M1"!A;F=A=G,@:6YT92!E;&QE<B!K=6YD92!I;G1E(&AI='1A<R!I(&1A=&%B
M87-E;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z-3$@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I
M9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R
M(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B2V]N=&%K=&5N(&QA9&5S('1I;&P@
M:2!A9')E<W-B;VME;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HQ,30Y(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q-S(*;7-G:60@
M(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I
M<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*
M(D1E;B!L]G-G:F]R9&$@4$=0+7-I9VYA='5R96X@:W+D=G,@9O9R(&%T="!V
M97)I9FEE<F$@9&5T('-I9VYE<F%D92`B"B)M961D96QA;F1E="XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B
M"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E
M8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T
M86)A<V4N(@IM<V=S='(@(B(*(D1I<W1R:6)U=&EO;G-L:7-T86YS($E$(&%N
M9V%V<R!I;G1E(&5L;&5R(&MU;F1E(&EN=&4@:&ET=&%S(&D@9&%T86)A<V5N
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0R"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*
M;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE
M9"XB"FUS9W-T<B`B1&ES=')I8G5T:6]N<VQI<W1A;B!H87(@:6YT92!A;F=I
M=FET<RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q,R!L:6(O
M2&]R9&4O0W)Y<'0N<&AP.C$Q-@IM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A
M='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T
M<B`B2W)Y<'1E<FEN9W-F=6YK=&EO;F5R;F$@:W+D=F5R(&5N('/D:V5R('=E
M8F;V<F)I;F1E;'-E("A(5%104RDN(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HW.`IM<V=I9"`B5&AE(&5V96YT(&AA
M<R!B965N(&%D9&5D('1O('EO=7(@8V%L96YD87(N(@IM<V=S='(@(DCD;F1E
M;'-E;B!L861E<R!T:6QL(&D@:V%L96YD97)N+B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,3<U(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M-#DS"B,Z(&QI8B](;W)D92YP:'`Z,3<W(&QI8B](;W)D92YP:'`Z-3$Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN
M(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B1FEL96X@)7,@<VMA;&P@:6YN96CE
M;&QA(&5N(&EN<W3D;&QN:6YG(&;V<B`E<RXB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$V."!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0X
M,PHC.B!L:6(O2&]R9&4N<&AP.C$W,"!L:6(O2&]R9&4N<&AP.C4P.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S
M;VUE("5S('-E='1I;F=S+B(*;7-G<W1R(")&:6QE;B`E<R!S:V%L;"!I;FYE
M:.5L;&$@:6YS=.1L;&YI;F=A<B!F]G(@)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C$Y"FUS9VED(")4:&4@9FEL92!C86X@;F]T(&)E
M(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B1FEL96X@:V%N(&EN=&4@
M:V]P:65R87,@=&EL;"!S:6<@<VKD;'8N(@H*(SH@;&EB+U9&4R]F:6QE+G!H
M<#HR,C8*;7-G:60@(E1H92!F:6QE(&-A;FYO="!B92!C;W!I960@;VYT;R!I
M='-E;&8N(@IM<V=S='(@(D9I;&5N(&MA;B!I;G1E(&MO<&EE<F%S('1I;&P@
M<VEG('-JY&QV+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(X,"!L
M:6(O2&]R9&4O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN
M960@;F\@9&%T82XB"FUS9W-T<B`B1FEL96X@:6YN96CV;&P@:6YG96X@:6YF
M;W)M871I;VXN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HV-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R
M('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B2'5V=61F
MY&QT(&;V<B!D971T82!M961D96QA;F1E+W)F8S@R,FUE9&1E;&%N9&4@9O9L
M:F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@
M=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E
M("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W
M;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D
M:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O
M;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD
M;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E
M;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T
M+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S
M($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@
M961I=&]R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3$Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S
M(&)E96X@9&5L971E9"XB"FUS9W-T<B`B261E;G1I=&5T96X@)R5S)R!R861E
M<F%D97,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB
M"FUS9W-T<B`B0F%R82!VY&YS=&5R('-I9&$B"@HC.B!S97)V:6-E<R]L:6YK
M<R]D96QE=&4N<&AP.C,W"FUS9VED(")4:&4@;&EN:R!H87,@8F5E;B!R96UO
M=F5D(@IM<V=S='(@(DSD;FME;B!H87(@=&%G:71S(&)O<G0B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-#8@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N
M=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C
M;&%S<RXB"FUS9W-T<B`B(@HB4_9K=N1G96X@=&EL;"!';G501RUP<F]G<F%M
M;65T(&WE<W1E('9A<F$@86YG:79E;B!T:6QL(&ML87-S96X@0W)Y<'1?<&=P
M.CHN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C(P,2!L:6(O
M2&]R9&4O34E-12]-1$XN<&AP.C(P,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<
M(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R
M86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R
M<W1O;V0N(@IM<V=S='(@(B(*(DUE9&1E;&%N9&5T('-K:6-K870@)7,@=&EL
M;"`E<R!M960@Y')E;F1E(%PB)7-<(B!H87(@=FES871S+EQN(@HB1&5T=&$@
MY'(@:6YG96X@9V%R86YT:2!F]G(@871T(&UE9&1E;&%N9&5T(&AA<B!LY'-T
M<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W(&QI8B](;W)D
M92]&;W)M+G!H<#HQ.#@Q"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L
M:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B3F%M;F5T('-O
M;2!S:V%L;"!A;G;D;F1A<R!F]G(@871T(&SD;FMA('1I;&P@<VMA<&$M<VED
M86XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#$@;&EB+T9I
M;&4O0U-6+G!H<#HT-S0*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU
M<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`B06YT86P@9N1L="!MY7-T92!V87)A
M(&5T="!N=6UE<FES:W0@=N1R9&4N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HQ,C,Q(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M,3(S,@IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O
M<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B36]D
M=6QE;B!O<&5N<W-L(&MRY'9S(&%V(&ML87-S96X@2&]R9&5?0W)Y<'1?<VUI
M;64Z.BXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(Y,"!L:6(O
M2&]R9&4O4')E9G,N<&AP.C(X,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U
M<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE
M('-I>F4B"FUS9W-T<B`B(@HB26YS=.1L;&YI;F=E;B!<(B5S7"(@:W5N9&4@
M:6YT92!S<&%R87,@<.4@9W)U;F0@878@871T(&1A=&%MY&YG9&5N("(*(O9V
M97)S:W)I=F5R(&1E;B!M87AI;6%L="!T:6QLY71N82(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R(&QI8B](;W)D92]-
M24U%+U9I97=E<B]D96(N<&AP.C,R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]E;G-C<FEP="YP:'`Z,S4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS
M<&]W97)P;VEN="YP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS
M=V]R9"YP:'`Z,S(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T
M82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G
M<W1R("(B"B)0<F]G<F%M;65T('-O;2!A;G;D;F1S(&;V<B!A='0@=FES82!D
M96X@:.1R(&UE9&1E;&%N9&5T>7!E;B`H)7,I('-A:VYA<R!PY2`B"B)S>7-T
M96UE="XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-30@;&EB
M+T9I;&4O0U-6+G!H<#HT.#<*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@
M;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B5&5C:VYE
M="!F]G(@8VET97)I;F<@;>5S=&4@=F%R82!E='0@=&5C:V5N+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*
M;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@
M(D)A<F$@:/9G97(@;V-H(';D;G-T97(@<VED;W(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4
M:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B0F%R82!H]F=E<B!S
M:61A(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V(&QI8B]&
M:6QE+T-35BYP:'`Z-#<Y"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@
M;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(E-E<&%R871O<FX@;>5S
M=&4@=F%R82!E='0@=&5C:V5N+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S
M=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E
M<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(E-E<G9E<B`G)7,G(')A
M9&5R861E<RXB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E
M;B!S879E9"XB"FUS9W-T<B`B4V5R=F5R("<E<R<@<W!A<F%D97,N(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S
M:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T
M<B`B4')E;G5M97)A=&EO;G-B96?D<F%N(&;V<B`E<R!H87(@=&%G:71S(&)O
M<G0N(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@*"5D
M*2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B06YG:79E;B!R860@*"5D*2!F
M:6YN<R!I;G1E+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C,S,"!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@
M(E1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")!
M;F=I=F5N(')A9"!E>&ES=&5R87(@:6YT92XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$P.`IM<V=I9"`B5&AE('1A
M<VL@:&%S(&)E96X@861D960@=&\@>6]U<B!T87-K;&ES="XB"FUS9W-T<B`B
M57!P9VEF=&5N(&AA<B!L86=T<R!T:6QL(&D@9&EN('5P<&=I9G1S;&ES=&$N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ-S<@;&EB+U9&4R]S
M<6PN<&AP.C$W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y
M(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")496UP;W+D
M<B!F:6P@)R5S)R!F:6YN<R!I;G1E+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,S,3`@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,#8*;7-G:60@(E1H
M92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@
M=&AE('-C<F5E;BXB"FUS9W-T<B`B5&5X=&5N(&1U(&UA=&%T(&EN('-TY&UM
M97(@:6YT92#V=F5R96YS(&UE9"!T97AT96X@<.4@<VOD<FUE;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*
M;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@
M(D)A<F$@=&]P<"!O8V@@8F]T=&5N('-I9&$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@
M=&]P('-I9&4@;VYL>2(*;7-G<W1R(")"87)A('1O<'!S:61A(@H*(SH@9G)A
M;65W;W)K+T1A=&$O1&%T82YP:'`Z,S(W(&QI8B](;W)D92]$871A+G!H<#HS
M,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H
M92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R(")5<'!L861D870@9&%T82!F]G)S
M=F%N;B!S961A;B!F]G)E9^5E;F1E('-T96<N(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP
M:'`Z,3<R"B,Z(&QI8B](;W)D92]$871A+V-S=BYP:'`Z,C8R(&QI8B](;W)D
M92]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C
M;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(D1E;B!U<'!L861D861E(&9I
M;&5N(&MU;F1E(&EN=&4@<W!A<F%S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z.3,*;7-G:60@(E1H92!U<V5R)W,@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N('=A<R!S=6-E<W-F=6QL>2!S=&]R960N
M(@IM<V=S='(@(DQE9&EG+W5P<'1A9V5N+6EN9F]R;6%T:6]N(&;V<B!A;G;D
M;F1A<F5N(&AA<B!S<&%R871S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HT.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$P"FUS
M9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B5V5A=&AE<BYC;VTM8FQO8VME="#D<B!I;G1E('1I;&QGY&YG
M;&EG="XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R(")496UA:V%T86QO9R`G)7,G(&9I;FYS(&EN=&4N(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-S@@;&EB+TAO<F1E+U!R
M969S+U5)+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V
M86EL86)L92XB"FUS9W-T<B`B26YG82!I;G-TY&QL;FEN9V%R('1I;&QGY&YG
M;&EG82XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HS
M-#$@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C,T.0IM<V=I9"`B5&AE
M<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N
M(@IM<V=S='(@(D1E="!F:6YN<R!I;F=A(&%L=&5R;F%T:79A(&1E;&%R('-O
M;2!K86X@=FES87,@:6YL:6YE+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,#$@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@
M=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B
M"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*(D;V
M<B!MY6YG82!T96-K96X@:2!FY&QT970N($1U(&AA<B!A;F=E='0@)7,@=&5C
M:V5N.R!M87AI;6%L="!A;G1A;"!T96-K96X@Y'(@(@HB)7,N(@H*(SH@<VEG
M;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE
M('-Y<W1E;3H@)7,B"FUS9W-T<B`B4')O8FQE;2!M960@871T(&SD9V=A('1I
M;&P@)R5S)R!T:6QL('-Y<W1E;65T.B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E
M;3H@(@IM<V=S='(@(E!R;V)L96T@;65D(&%T="!R96YS82!I;F9O<FUA=&EO
M;B!O;2!A;G;D;F1A<F4@)R5S)R!F<N5N('-Y<W1E;65T.B`B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B
M"FUS9W-T<B`B4')O8FQE;2!M960@871T('1A(&)O<G0@)R5S)R!F<N5N('-Y
M<W1E;65T.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z
M("5S(@IM<V=S='(@(E!R;V)L96T@=FED('5P<&1A=&5R:6YG(&%V("<E<R<Z
M("5S(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<Y(&QI
M8B](;W)D92]"<F]W<V5R+G!H<#HY,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@
M)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R(")0<F]B;&5M('9I9"!U<'!L861D
M;FEN9R!A=B!F:6QE;BX@26YG82`E<R!L861D861E<R!U<'`N(@H*(SH@9G)A
M;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@T(&QI8B](;W)D92]"<F]W
M<V5R+G!H<#HY,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L
M87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y
M=&5S*2XB"FUS9W-T<B`B(@HB1&5T('5P<'-T;V0@<')O8FQE;2!V:60@=7!P
M;&%D9&YI;F<@878@9FEL96XZ("5S(.1R('-T]G)R92#D;B!M87AI;6%L="`B
M"B)T:6QLY71E;B!S=&]R;&5K("@E9"!B>71E<RDN(@H*(SH@9G)A;65W;W)K
M+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@V(&QI8B](;W)D92]"<F]W<V5R+G!H
M<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A
M<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@HB1&5T('5P<'-T;V0@<')O
M8FQE;2!V:60@=7!P;&%D9&YI;F<@878@9FEL96XZ("5S(&QA9&1A9&5S(&5N
M8F%R="!U<'`@9&5L=FES+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z,S4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y
M:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(D1E="!U<'!S=&]D(&5T
M="!F96P@=FED('9I<VYI;F<@878@;65D9&5L86YD961E;&5N+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(D9E;"!V:60@
M:6UP;W)T(&%V(&MO;G1A:W1D871A+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S
M+B(*;7-G<W1R(")&96P@=FED(&EM<&]R="!A=B!HY&YD96QS96XZ("5S+B(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,2!L:6(O2&]R9&4O
M1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B1F5L('9I9"!I
M;7!O<G0@878@:4-A;&5N9&%R(&1A=&$N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=&%S:SH@
M)7,N(@IM<V=S='(@(D9E;"!V:60@:6UP;W)T(&%V('5P<&=I9G1E;CH@)7,N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HY,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VXZ("5S+B(*
M;7-G<W1R(")&96P@=FED(&EM<&]R="!A=B!I;F9O<FUA=&EO;B!O;2!L961I
M9R]U<'!T86=E;CH@)7,N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX
M,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U
M<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER
M960@9FEE;&0N(@IM<V=S='(@(B(*(D5T="!F96P@<.5T<N1F9F%D97,@:2!F
M;W)M=6SD<F5T+B!+;VYT<F]L;&5R82!A='0@9'4@:6YT92!G;/9M="!F>6QL
M82!I(&5T="`B"B)O8FQI9V%T;W)I<VMT(&;D;'0N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S
M(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM
M<V=S='(@(B(*(D1E="!G:6-K(&EN=&4@871T('5T9O9R82!D96X@8F5GY')D
M82!A9')E<W-B;VMS9G5N:W1I;VYE;BX@5F%R(&=O9"!F]G)S]FL@(@HB<V5N
M87)E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0P"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@
M8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G
M<W1R(")&96P@=FED('5P<&1A=&5R:6YG(&%V(&MO;G1A:W1U<'!G:69T97(N
M($;V<G/V:R!I9V5N('-E;F%R92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C(R,B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0U"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR,C(*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES
M=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S
M='(@(D9E;"!V:60@=7!P9&%T97)I;F<@878@9&ES=')I8G5T:6]N<VQI<W1A
M;BX@1O9R<_9K(&EG96X@<V5N87)E+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$T."!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T
M('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R(")$:6X@24U!4"US
M97)V97(@<W3V9&5R(&EN=&4@9&5L861E(&UA<'!A<BXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C@R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z.38*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ,3(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HR,#`*
M;7-G:60@(E1H:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@
M(D1E;FYA(&AA;F1L:6YG('-T]F1S(&EN=&4N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ,3@*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HS-3D*;7-G:60@(E1H
M:7,@86-T:6]N(&ES(&YO="!Y970@:6UP;&5M96YT960N(@IM<V=S='(@(D1E
M;FYA(&9U;FMT:6]N(.1R(&EN=&4@:6UP;&5M96YT97)A9"#D;BXB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C0X(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R(")&
M:6QE;B!V97)K87(@:6YT92!V87)A(&5T="!G:6QT:6=T(%)!4BUA<FMI=BXB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C4R(&QI
M8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R
M(")&:6QE;B!V97)K87(@:6YT92!V87)A(&5T="!G:6QT:6=T(%I)4"UA<FMI
M=BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,30U(&QI8B](;W)D
M92]&;W)M+G!H<#HS,3,Q"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@
M8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B1F5L86MT:6=T(&MO
M<G1N=6UM97(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3@U"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O
M(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M22(*;7-G<W1R("(B"B)$96YN82!D<FEV<G5T:6X@9_9R(&1E="!M]FIL:6=T
M(&%T="!S:VEC:V$@;65D9&5L86YD96X@=FEA($-L:6-K871E;&PM(@HB8G)Y
M9V=A;B`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G96YO;2!A='0@86YVY&YD
M82!(5%10($%023IT+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,3,T(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G
M:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W
M87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)$96YN82!D<FEV
M<G5T:6X@9_9R(&1E="!M]FIL:6=T(&%T="!S:VEC:V$@;65D9&5L86YD96X@
M=FEA(%=)3BUB<GEG9V%N("(*(BAH='1P.B\O=VEN<&QC+F-O;2D@9V5N;VT@
M871T(&%N=N1N9&$@2%144"!!4$DZ="(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I
M;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H
M92!(5%10($%022(*;7-G<W1R("(B"B)$96YN82!D<FEV<G5T:6X@9_9R(&1E
M="!M]FIL:6=T(&%T="!S:VEC:V$@;65D9&5L86YD96X@=FEA('-M<S)E;6%I
M;"UB<GEG9V%N("(*(BAH='1P.B\O<VUS,F5M86EL+F-O;2D@9V5N;VT@871T
M(&%N=N1N9&$@2%144"!!4$DZ="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"B,Z(&QI8B].970O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@
M=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O
M;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H
M("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S
M='(@(B(*(D1E;FYA(&1R:79R=71I;B!G]G(@9&5T(&WV:FQI9W0@871T('-K
M:6-K82!M961D96QA;F1E;B!V:6$@4TU44"!G96YO;2`B"B)6;V1A9F]N92!)
M=&%L:65N+6)R>6=G86X@*&5N8F%R="!T:6QL(%9O9&%F;VYN=6UM97(I+B!$
M<FEV<G5T:6YE;B!K<N1V97(@971T("(*(F4M<&]S=&MO;G1O(&AO<R!6;V1A
M9F]N92!)=&%L:65N("AH='1P.B\O=W=W+C$Y,"YI="DN(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$S.3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T,3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4W(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S
M-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`U"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,X,3,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R
M,0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3@R(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,#8Q(&QI8B](;W)D92]&;W)M+G!H<#HQ,#DP"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,3$Y(&QI8B](;W)D92]&;W)M+G!H<#HQ,3@V(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,C8P"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S`Y(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-#`R(&QI8B](;W)D92]&;W)M+G!H<#HQ-38Q
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#0S(&QI8B](;W)D92]&;W)M+G!H
M<#HQ.38R(&QI8B](;W)D92]&;W)M+G!H<#HR,#`Y"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,#,S(&QI8B](;W)D92]&;W)M+G!H<#HR,#@R(&QI8B](;W)D
M92]&;W)M+G!H<#HR,34S"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C(U(&QI
M8B](;W)D92]&;W)M+G!H<#HR-#$R(&QI8B](;W)D92]&;W)M+G!H<#HR-#4T
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-C0Q(&QI8B](;W)D92]&;W)M+G!H
M<#HR.#$T(&QI8B](;W)D92]&;W)M+G!H<#HS,3(S"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HS,S`Q(&QI8B](;W)D92]&;W)M+G!H<#HS.#`Y(&QI8B](;W)D
M92]&;W)M+G!H<#HS.#$W"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D
M+B(*;7-G<W1R(")&Y&QT970@;>5S=&4@=F%R82!I9GEL;'0N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-2!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3`V.0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G
M97)S+B(*;7-G<W1R(")&Y&QT970@9N5R(&5N8F%R="!I;FYE:.5L;&$@:&5L
M=&%L+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3@@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(T,C`*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(D;D;'1E
M="!FY7(@96YB87)T(&EN;F5HY6QL82!S:69F<F]R(&]C:"!K;VQO;BXB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DT(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,#DX"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M;V-T86P@=F%L=65S+B(*;7-G<W1R(")&Y&QT970@9N5R(&5N8F%R="!I;FYE
M:.5L;&$@;VMT86QA('1A;"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3(S(&QI8B](;W)D92]&;W)M+G!H<#HQ,3(W"FUS9VED(")4:&ES(&9I
M96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O
M9B!I;G1E9V5R<R(*;7-G<W1R("(B"B)&Y&QT970@<VMA;&P@=F%R82!E;B!K
M;VUM82T@96QL97(@;65L;&%N<VQA9W-S97!A<F%R860@;&ES=&$@;65D(&AE
M;'1A;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX.2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z.3DS"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V
M86QI9"!N=6UB97(N(@IM<V=S='(@(D;D;'1E="!MY7-T92!V87)A(&5T="!G
M;V1KY&YT('1A;"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V
M(&QI8B](;W)D92]&;W)M+G!H<#HR.#(R"FUS9VED("(B"B)4:&ES(&9I96QD
M(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R
M;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*(D1E
M='1A(&;D;'0@;>5S=&4@:6YN96CE;&QA(&5N(%)'0BUFY')G:V]D(&D@:&5X
M861E8VEM86QT(&9O<FUA="P@="!E>"`B"B(G(S$R,S1A9B<N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z-38Q(&QI8B](;W)D92]&;W)M+G!H<#HU
M-C4*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E
M9"XB"FUS9W-T<B`B1&5T=&$@9F]R;75LY'(@:&%R(')E9&%N(&)E87)B971A
M=',N(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B1&5T(&CD<B#D<B`E
M<RXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0U.2!L:6(O2&]R
M9&4O2V]L86(N<&AP.C0V.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES
M(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B
M:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N
M9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L
M:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z-3DP(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HU.3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@
M8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S
M='(@(DUE9&1E;&%N9&5T('-K<F5V<R!I(&5N(&%N;F%N('1E8VME;G5P<'/D
M='1N:6YG("@E<RD@Y&X@9&EN(&5G96XN(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ,C8@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,C8*
M;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G
M<W1R(")$970@:.1R(&YU;7)E="!MY7-T92!V87)A(&UI;G-T(&5T="XB"@HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4@;&EB
M+TAO<F1E+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E
M<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T
M<B`B4V5R=F5R;B!K86X@:6YT92!P86-K82!U<'`@>FEP(&]C:"!G>FEP(&9I
M;&5R+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z
M,3@V(&QI8B](;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y
M<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(E-Y<W1E
M;65T(.1R(&;V<B!T:6QL9N1L;&5T(&%V86MT:79E<F%T+B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T(&QI8B](;W)D92]0<F5F<R]5
M22YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N
M(@IM<V=S='(@(D1E="!HY'(@=N1R9&5T(&WE<W1E('9A<F$@;G5M97)I<VMT
M+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G
M:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N
M<R!W:6YD;W<B"FUS9W-T<B`B1&5T=&$@9O9N<W1E<B!MY7-T92!A;G)O<&%S
M(&9RY6X@971T(&MO;F9I9W5R871I;VYS9O9N<W1E<B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")4:'5N9&5R
M(@IM<V=S='(@(L5S:V$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C,V"FUS9VED(")4:6-K971S(@IM<V=S='(@(L1R96YD96XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(X(&QI8B](;W)D92]&;W)M+G!H<#HR
M-#(Y"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B
M5&EM92(*;7-G<W1R(")4:60B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S@X"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(E1I9'-R961O
M=FES;FEN9R(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM
M92!F;W)M870B"FUS9W-T<B`B5&ED<V9O<FUA="(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(U,SD@;&EB+TAO<F1E+T9O<FTN<&AP.C(U,S4*;7-G
M:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(E1I9'-V86PB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$P(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S`*(SH@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(R,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(M9S='1I;6]R(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.0HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO
M8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B4G5B<FEK
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R(")2=6)R:6L@*'1O
M;VQT:7`I.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z-S4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-S4*;7-G:60@(E1O(@IM<V=S='(@(E1I;&PB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C(Y"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M
M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@
M0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@
M(B(*(D;V<B!A='0@;6%R:V5R82!F;&5R82!V86PL(&CE;&P@;F5D($-T<FP@
M*%!#*2!E;&QE<B!#;VUM86YD("A-86,I('1A;F=E;G1E;B`B"B)NY'(@9'4@
M:VQI8VMA<BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P
M"FUS9VED(")4;V1A>2(*;7-G<W1R("))9&%G(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A4
M34P@4V]U<F-E(@IM<V=S='(@(E9I<V$@2%1-3"UKY&QL82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#D@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,PHC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P.0IM<V=I9"`B5&]G;R(*;7-G<W1R(")4;V=O(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(V"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,C0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P
M"FUS9VED(")4;VME;&%U(@IM<V=S='(@(E1O:V5L874B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`R"FUS9VED(")4;VUO<G)O=R(*;7-G
M<W1R("));6]R9V]N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C(Y"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C4@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G
M<W1R(")4;VYG82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@(E1O<"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G
M:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B5&]P(&9R86UE("A?=&]P
M*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L
M871I;VYS(@IM<V=S='(@(M9V97)SY'1T;FEN9V%R(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,R"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,C8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q
M"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(E1R:6YI9&%D
M(&]C:"!4;V)A9V\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDP
M(&QI8B](;W)D92]&;W)M+G!H<#HQ-SDT"FUS9VED(")4<G5E(&]R(&9A;'-E
M(@IM<V=S='(@(E-A;G0@96QL97(@9F%L<VMT(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T
M<B`B5&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$P(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,C@*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-R!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B
M5'5N:7-I96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,S$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R."!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R
M(")4=7)K:65T(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@
M(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(E1U<FMI<VL@*$E33RTX
M.#4Y+3DI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C(W"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,CD@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N:7-T86XB"FUS
M9W-T<B`B5'5R:VUE;FES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P."!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C(P"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,S`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K
M<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B5'5R:W,M(&]C:"!#86EC
M;W/V87)N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(S,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@
M(E1U=F%L=2(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-C0@;&EB+TAO
M<F1E+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS
M9W-T<B`B06YG92!D:71T('9A;#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(U.`IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(E56
M+6EN9&5X.B`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C0Y"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T
M<B`B55),(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-#$*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4T,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T
M=7,@<F5P;W)T(@IM<V=S='(@(E523"!F]G(@9&ET="!L979E<F%N<W)A<'!O
M<G1E<FEN9W-S:W)I<'0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(E523#HB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$R(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S<*(SH@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G<W1R(")59V%N9&$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$R(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S8*(SH@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,R!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B56MR86EN82(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q,B!L:6(O5D93+V9I
M;&4N<&AP.C0Q.0IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T
M;W)Y+B(*;7-G<W1R(")+86X@:6YT92!LY'-A(%9&4RUM87!P+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-B!L:6(O2&]R9&4O075T
M:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S
M97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("(B"B)$
M970@9VEC:R!I;G1E(&%T="!LY&=G82!T:6QL('5T]FMA9"!A;G;D;F1A<FEN
M9F]R;6%T:6]N('9I9"!R96=I<W1E<FEN9RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C,X."!L:6(O5D93+V9T<"YP:'`Z,SDS"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")+86X@:6YT92#D;F1R82!B96CV
M<FEG:&5T(&;V<B!61E,M9FEL("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C,X-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#8X
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z,SDR(&QI8B]61E,O;75S<6PN<&AP.C0V
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(")+86X@:6YT92#D
M;F1R82!B96CV<FEG:&5T(&;V<B!61E,M9FEL("5S+R5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4U(&QI8B]61E,O9G1P+G!H<#HW.#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB
M"FUS9W-T<B`B2V%N(&EN=&4@Y&YD<F$@=&EL;"`E<RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HV.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92`E<R\E<R(*;7-G<W1R(")+86X@
M:6YT92!K;VYT<F]L;&5R82!F:6QS=&]R;&5K("5S+R5S(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HR,S(@;&EB+U9&4R]F='`N<&AP.C(S-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE
M(&]F(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EN=&4@:V]N=')O;&QE<F$@9FEL
M<W1O<FQE:R!PY2`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C$P,38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@S-`HC.B!L
M:6(O5D93+V9I;&4N<&AP.C8Y-2!L:6(O5D93+W-Q;"YP:'`Z,3`R."!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HX-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S7"(N(@IM<V=S='(@
M(DMA;B!I;G1E(&MO;G1R;VQL97)A(&9I;'-T;W)L96L@<.4@)7,O)7,N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S-2!L:6(O2&]R9&4O
M075T:"]S<6PN<&AP.C0S.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@
M4U%,('-E<G9E<BXB"FUS9W-T<B`B2V%N(&EN=&4@:V]N=&%K=&$@4U%,+7-E
M<G9E<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S.2!L:6(O
M5D93+V9T<"YP:'`Z.#<P"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H
M(%-33"XB"FUS9W-T<B`B2V%N(&EN=&4@:V]N=&%K=&$@=FEA(%-33"XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,C4@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P
M,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y(&QI8B]6
M1E,O9FEL92YP:'`Z,C,R"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C,W(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C(P-"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,#D*
M(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C$W"FUS9VED(")5;F%B;&4@=&\@
M8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EN=&4@:V]P:65R82!61E,M
M9FEL+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S8U(&QI8B]6
M1E,O9G1P+G!H<#HS-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EN
M=&4@<VMA<&$@5D93+6UA<'`@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,S4T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-3@*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(U-B!L:6(O5D93
M+V9I;&4N<&AP.C,V,0HC.B!L:6(O5D93+VUU<W%L+G!H<#HR-3@@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,C8T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(DMA;B!I;G1E('-K87!A(%9&4RUM87!P
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F
M:6QE+B(*;7-G<W1R(")+86X@:6YT92!S:V%P82!61E,M9FEL+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@V(&QI8B]61E,O<VUB+G!H<#HR
M.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@
M9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EN=&4@<VMA<&$@5D93+6UA
M<'`@)R5S)RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-C4@
M;&EB+U9&4R]F:6QE+G!H<#HR-S(*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@
M96UP='D@5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I;G1E('-K87!A('1O;2!6
M1E,M9FEL+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N
M<&AP.C<V"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H
M<#HW.2!L:6(O2&]R9&4O0V]M<')E<W,O=&%R+G!H<#HW-@HC.B!L:6(O2&]R
M9&4O0V]M<')E<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T;R!D96-O
M;7!R97-S(&1A=&$N(@IM<V=S='(@(DMA;B!I;G1E('!A8VMA('5P<"!D871A
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C(T(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,CDX"B,Z(&QI8B]61E,O<VUB+G!H<#HR,C@@
M;&EB+U9&4R]F='`N<&AP.C,P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP
M='DN(@IM<V=S='(@(DMA;B!I;G1E(')A9&5R82`E<RP@;6%P<&5N(.1R(&EN
M=&4@=&]M+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HT-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(DMA;B!I;G1E(')A9&5R82`G
M)7,G.B`E<R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS,S0*(SH@;&EB+U9&4R]F:6QE+G!H<#HS,S@@;&EB+U9&4R]S<6PN
M<&AP.C,Y-2!L:6(O5D93+VUU<W%L+G!H<#HS,3$*(SH@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,S0R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@
M(DMA;B!I;G1E(')A9&5R82`E<RP@;6%P<&5N(.1R(&EN=&4@=&]M+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#@@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U,@HC.B!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HS-38@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S8P"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S
M='(@(DMA;B!I;G1E(')A9&5R82!61E,M;6%P<"!R96MU<G-I=G0N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,W(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#0@;&EB+U9&4R]F:6QE
M+G!H<#HS-#0*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,S(R(&QI8B]61E,O;75S
M<6PN<&AP.C,S-2!L:6(O5D93+VUU<W%L+G!H<#HS-#,*(SH@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(DMA;B!I;G1E(')A9&5R82!61E,M;6%P<"XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0Q-R!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C0R.0HC.B!L:6(O5D93+W-Q;"YP:'`Z-#(P(&QI
M8B]61E,O<W%L+G!H<#HT,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B2V%N(&EN
M=&4@<F%D97)A(%9&4RUM87!P.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C(P-R!L:6(O5D93+V9T<"YP:'`Z,C$R"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R(")+86X@:6YT92!R861E<F$@5D93+69I;"`E<RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HR.#@*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V
M-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C,X,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,SDQ(&QI8B]61E,O9FEL92YP:'`Z,S$P(&QI8B]61E,O<W%L+G!H<#HR
M.3$*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,38W(&QI8B]61E,O;75S<6PN<&AP
M.C$X,"!L:6(O5D93+VUU<W%L+G!H<#HQ.#<*(SH@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,SDQ(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,Y.0IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EN=&4@<F%D
M97)A(%9&4RUF:6PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M-#0@;&EB+U9&4R]S;6(N<&AP.C(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")+
M86X@:6YT92!R861E<F$@5D93+6UA<'`@)R5S)RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C0P-B!L:6(O5D93+W-Q;"YP:'`Z-#`Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV
M96QY.B`E<RXB"FUS9W-T<B`B2V%N(&EN=&4@<F%D97)A(%9&4R!R96MU<G-I
M=G0Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#`S(&QI
M8B]61E,O9G1P+G!H<#HX,S0*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@
M8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(DMA;B!I;G1E(&%V9_9R82!A
M:W1U96QL(&UA<'`N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV,#,@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,#0*;7-G:60@
M(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T
M<B`B2V%N(&EN=&4@97AT<F%H97)A($-E<G1I9FEK871S9&5T86QJ97(B"@HC
M.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#4Q(&9R86UE=V]R:R].
M971?24U34"])35-0+T%U=&@N<&AP.C$Q.`HC.B!L:6(O3F5T+TE-4U`N<&AP
M.C0S-R!L:6(O3F5T+TE-4U`O075T:"YP:'`Z,3(S"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*
M;7-G<W1R(")+86X@:6YT92!L861D82!D969I;FET:6]N96X@878@)7,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,38V(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ
M-S$*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,#,@;&EB+U9&4R]F:6QE+G!H<#HR
M,#@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3<T"B,Z(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C$W.0IM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM
M<V=S='(@(DMA;B!I;G1E(&9L>71T82!61E,M9FEL+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z.3,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HQ,#(*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV-#@@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HY.`HC.B!L:6(O5D93+W-M8BYP:'`Z.3,@
M;&EB+U9&4R]S;6(N<&AP.C$P-B!L:6(O5D93+W-M8BYP:'`Z-C4R"B,Z(&QI
M8B]61E,O9G1P+G!H<#HY.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DMA;B!I;G1E(/9P
M<&YA(%9&4RUF:6P@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C<W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S`*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,R!L:6(O5D93+V9I
M;&4N<&AP.C(X-`HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ,S@@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,30Q"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@
M9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B2V%N(&EN=&4@]G!P;F$@5D93
M+69I;"!F]G(@<VMR:79N:6YG+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C@P(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S,`HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(@;&EB+U9&4R]F:6QE
M+G!H<#HX,R!L:6(O5D93+V9I;&4N<&AP.C$S-PHC.B!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HW-@IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM
M<V=S='(@(DMA;B!I;G1E(/9P<&YA(%9&4RUF:6PN(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT-2!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E
M<W-E9"!A<F-H:79E+B(*;7-G<W1R(")+86X@:6YT92#V<'!N82!K;VUP<FEM
M97)A="!A<FMI=BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#,V(&QI
M8B]61E,N<&AP.C@U-@IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@
M*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B2V%N(&EN=&4@;.1S82!6
M1E,M9FEL("AF:6QE<VEZ92@I(&UI<W-L>6-K861E<RDN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C@V-R!L:6(O5D93+G!H<#HX.#<*;7-G:60@(E5N
M86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN
M(@IM<V=S='(@(DMA;B!I;G1E(&SD<V$@5D93+69I;"`H9V5T1FEL95-I>F4H
M*2!M:7-S;'EC:V%D97,I+B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`HC.B!L:6(O2&]R9&4O4V5S
M<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D
M(&9I;&4Z("(*;7-G<W1R(")+86X@:6YT92!LY'-A(&9I;#H@(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C8Y(&QI8B]61E,O9FEL92YP:'`Z
M-C<V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O
M<GDN(@IM<V=S='(@(DMA;B!I;G1E(&SD<V$@:V%T86QO9V5N(&;V<B`G=F9S
M<F]O="<N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3`U(&QI
M8B](;W)D92]+;VQA8BYP:'`Z,3$P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@
M86QR96%D>2!E>&ES=',B"FUS9W-T<B`B2V%N(&EN=&4@8GET82!N86UN('#E
M("5S('1I;&P@)7,Z(&1E<W1I;F%T:6]N<VUA<'`@9FEN;G,@<F5D86XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C,P,0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R(")+86X@:6YT92!B>71A(&YA;6X@<.4@5D93
M+6UA<'`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,CD@;&EB
M+U9&4R]S<6PN<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(")+86X@:6YT
M92!B>71A(&YA;6X@<.4@5D93+6UA<'`Z("5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,C8W(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,S0S"B,Z(&QI8B]61E,O<VUB+G!H<#HR-S$@;&EB+U9&4R]F='`N<&AP.C,T
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EN=&4@8GET82!N86UN('#E(%9&
M4RUF:6P@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C$P
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HV,3<@;&EB+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM
M<V=S='(@(DMA;B!I;G1E(&)Y=&$@;F%M;B!PY2!61E,M9FEL("5S+R5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(S(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HR,3,*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C0U,B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C@U
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$@;&EB+U9&
M4R]S<6PN<&AP.C,R-@HC.B!L:6(O5D93+VUU<W%L+G!H<#HR,3,@;&EB+U9&
M4R]M=7-Q;"YP:'`Z-#4R(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(Y,PHC.B!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HS,#D*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I;G1E(&)Y=&$@;F%M;B!PY2!6
M1E,M9FEL+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]M:VES;V9S+G!H<#HU,`HC.B!F<F%M97=O<FLO5D937TE33R])4T]7<FET
M97(O;6MI<V]F<RYP:'`Z-3$@;&EB+U9&4R])4T]7<FET97(O;6MI<V]F<RYP
M:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R
M(")+86X@:6YT92!K]G)A("=M:VES;V9S)RXB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L
M871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R(")+86X@:6YT92#V=F5R
M<^1T=&$@5V]R9&1O:W5M96YT970B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C$T.2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U,@HC.B!L
M:6(O5D93+V9T<"YP:'`Z,34T(&QI8B]61E,O9G1P+G!H<#HQ-3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B2V%N(&EN=&4@<VMR:79A('1I;&P@5D93+69I;"`E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-SD@;&EB+U9&4R]F
M:6QE+G!H<#HQ.#8*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H
M8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(DMA;B!I;G1E('-K<FEV82!T:6QL
M(%9&4RUF:6P@*&-O<'DH*2!M:7-S;'EC:V%D97,I+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,3,X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ-#,@;&EB+U9&4R]F:6QE+G!H<#HR.#@*(SH@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,30V(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$U,0IM<V=I9"`B56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(DMA;B!I;G1E
M('-K<FEV82!D871A('1I;&P@5D93+69I;"XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z.#0R(&QI8B]61E,N<&AP.C@V,@IM<V=I9"`B56YA8FQE('1O
M('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G
M<W1R(")+86X@:6YT92!S:W)I=F$@=&EL;"!61E,M9FEL+"!K=F]T82!S:W5L
M;&4@]G9E<G-K<FED87,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(E5N
M9&5R<W1R=6ME;B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G
M:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R("+%;F=R82#D;F1R:6YG87(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS
M9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("+%;F=R87(@
M9&EN('-E;F%S=&4@Y71GY')D(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,C(S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,Y,"!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,C(Q"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#@*
M;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N
M;F5C=&EO;CH@(@IM<V=S='(@(D]VY&YT870@<W9A<B!F<N5N('-E<G9E<B!P
MY2!F]G)B:6YD96QS93H@(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,T,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS-S@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S@T(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3<*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,S.2!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<V"B,Z(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS.#(*;7-G:60@(E5N97AP96-T960@<F5S<&]N
M<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R(")/=N1N=&%T('-V87(@9G+E
M;B!S97)V97(@=&EL;#H@(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B16H@
M:V%T96=O<FES97)A9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z,S@T"B,L('!H<"UF;W)M870*;7-G:60@(E5N:&%N
M9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,B"FUS9W-T<B`B26-K92!H86YT
M97)A9"!K;VUP;VYE;G0@878@='EP.B`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DV"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B56YI
M8V]D92`H551&+3@I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$W"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S0@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M
M:7)A=&5S(@IM<V=S='(@(D;V<F5N861E($%R86)E;6ER871E;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,X"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,S4@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(E-T;W)B<FET
M86YN:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C0P"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S8@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM
M<V=S='(@(D;V<F5N=&$@4W1A=&5R;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,SD*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(S-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@
M(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R
M(")!;65R:6MA;G-K82!3=&EL;&%H879S]F%R;F$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HW.`IM
M<V=I9"`B56YI=',B"FUS9W-T<B`B16YH971E<B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q."!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3D*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(Y(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C0S,`HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&=Z+G!H<#HU.`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R(")/:^1N
M9"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y.`HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*
M;7-G<W1R(")/:^1N="!G<N1N<W-N:71T<VUE9&1E;&%N9&5I9"`H87!I;7-G
M:60I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y.0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@
M240I+B(*;7-G<W1R(")/:^1N="!K;&EE;G1M961D96QA;F1E:60@*&-L:6US
M9VED*2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30W"FUS
M9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")/:^1N
M9"!O<G0@<W!E8VEF:6-E<F%D+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O
M<B!P87-S=V]R9"XB"FUS9W-T<B`B3VOD;G0@86YVY&YD87)N86UN(&5L;&5R
M(&SV<V5N;W)D+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT
M(&5L96UE;G0B"FUS9W-T<B`B5&$@8F]R="!LY&YK96X@9G+E;B!N=79R86YD
M92!E;&5M96YT(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H
M<#HR.38@;&EB+TAO<F1E+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(E5N;F%M
M960B"FUS9W-T<B`B3F%M;FSV<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S
M8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T
M:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@
M<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB
M<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE
M(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@HB26-K92UP<FEV:6QI9V5R861E('-K
M<FEP="!K86X@:6YT92!K;VUM82#E="!+;&EP<"!U="]+;W!I97)A+TML:7-T
M<F$M(@HB9G5N:W1I;VYE<FYA(&%V('/D:V5R:&5T<W-KY&PN($ML:6-K82!/
M2R!F]G(@871T('-E(&5N('1E:VYI<VL@8F5S:W)I=FYI;F<@(@HB9G+E;B!M
M;WII;&QA+F]R9R!O;2!H=7(@9'4@:V%N('1I;&SE=&$@871T('-K<FEP="!K
M;VUM97(@Y70@=7)K;&EP<"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*
M;7-G<W1R(")482!B;W)T(&;D<F<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8X-B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.CDR-@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS
M,B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8X-PHC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.CDR-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.CDS,PIM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(E1I
M;&SD9V=E="!S=/9D<R!I;G1E(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ.3<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ.3<*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*
M;7-G<W1R(")5<'!D871E<F$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*
M;7-G<W1R(")5<'!D871E<F$@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C8T.`IM<V=I9"`B57!D871E(')E<W!O
M;F1E;G0@<W1A='5S(@IM<V=S='(@(E5P<&1A=&5R82!S=&%T=7,@<.4@<W9A
M<F%N9&4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V
M"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R(")5<'!D871E<F$@86YVY&YD
M87)E(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I
M="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(E5P<&1A
M=&5R861E("<E<R<N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*
M;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(E5P<&1A
M=&5R:6YG<W-C<FEP="!R861E<F%T+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$X,@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DX
M"FUS9VED(")5<&QO860B"FUS9W-T<B`B3&%D9&$@=7!P(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI
M8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(DQA
M9&1A9&4@=7!P(&%L;&$@:V]N9FEG=7)A=&EO;G-F:6QE<B!T:6QL('-E<G9E
M<FXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G
M<W1R(")697)S86QE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU
M;6)E<G,B"FUS9W-T<B`B4F]M97)S:V$@<VEF9G)O<B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3,@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,0HC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R(")5<G5G=6%Y(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(SH@;&EB
M+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(D%N=N1N9"!A
M:W1U96QL.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3,X"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B06YVY&YD(%-33"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C<*;7-G:60@(E5S92!I9B!N
M86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM
M<V=S='(@(D%N=N1N9"!O;2!N86UN+VSV<V5N;W)D(.1R(&%N;F]R;'5N9&$@
M9O9R($E-4U`M<V5R=F5R+B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z,C$*;7-G:60@(E5S97(B"FUS9W-T<B`B06YVY&YD87)E(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW,C`@;&EB
M+TAO<F1E+U)E9VES=')Y+G!H<#HW-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(D%N
M=N1N9&%R92`E<R#D<B!I;G1E(&)E:/9R:6<@9O9R("5S+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G
M<W1R(")!;G;D;F1A<F%D;6EN:7-T<F%T:6]N(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HR-3`@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HR
M-#4*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R(")!;G;D;F1A<FEN<W3D
M;&QN:6YG87(B"@HC.B!S:6=N=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E9VES
M=')A=&EO;B(*;7-G<W1R(")!;G;D;F1A<G)E9VES=')E<FEN9R(*"B,Z('-I
M9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N
M(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(D%N=N1N9&%R<F5G
M:7-T<F5R:6YG(&AA<B!A=F%K=&EV97)A=',N(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C0V.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*
M;7-G<W1R(")!;G;D;F1A<FMO;G1O="!H:71T861E<R!I;G1E(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<#HY.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ-3`@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!L
M:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&QI8B].970O4TU3+W=I
M;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T
M<B`B06YVY&YD87)N86UN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N
M=7`N<&AP.C$R-"!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C$R-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR96%D>2!E>&ES
M=',N(@IM<V=S='(@(D%N=N1N9&%R;F%M;B`E<R!F:6YN<R!R961A;BXB"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N
M86UE.B(*;7-G<W1R(")!;G;D;F1A<FYA;6XZ(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(")!
M;G;D;F1A<FYA;6XZ("(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(D%N
M=N1N9&%R92!I('-Y<W1E;65T.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(T,@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB
M96MI<W1A;B(*;7-G<W1R(")5>F)E:VES=&%N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,38S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(U-0HC.B!L:6(O5D93+V9I;&4N<&AP.C$W,"!L:6(O5D93+V9I;&4N<&AP
M.C(V,@IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS
M9W-T<B`B5D93+6UA<'`@97AI<W1E<F%R(&EN=&4N(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$R,`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B
M4V5M97-T97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-C8@;&EB
M+TAO<F1E+T9O<FTN<&AP.C@W,`IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O
M=6YD(&EN8VQU9&4Z("(*;7-G<W1R(")':6QT:6=A('!L871S97(@<V]M(&AI
M='1A9&5S(&EN:VQU9&5R87(Z("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C,X(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C,Y
M"FUS9VED(")686QI9&ET>2(*;7-G<W1R(")':6QT:6=H970B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-R!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@
M;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B36EN=71E<B!F<N5N(&YU(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4V(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q-S<*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@V,"!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3$X,0HC+"!P:'`M9F]R;6%T"FUS9VED(")686QU
M92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B
M5N1R9&5T(/9V97)S=&EG97(@9&5T(&CV9W-T82!T:6QLY71N82`H)7,I(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y(&QI8B](;W)D92]&;W)M
M+G!H<#HR,C0X"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C<P(&QI8B](;W)D
M92]&;W)M+G!H<#HR,S(P(&QI8B](;W)D92]&;W)M+G!H<#HR.3$T"B,Z(&QI
M8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU
M97,B"FUS9W-T<B`B5N1R9&5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$P.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@V"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,3$S(&QI8B](;W)D92]&;W)M+G!H<#HR,3DP"FUS
M9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B5N1R9&5N(&%T
M="!VY&QJ82!F<N5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0Y"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#`@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM
M<V=S='(@(E9A;G5T874B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C,S"FUS9VED(")687)I86)L92(*;7-G<W1R(")687)I86)E;"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,34@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-0HC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(E9E;F5Z=65L
M82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I
M;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R
M960@=VET:"XB"FUS9W-T<B`B5F5R:69I97)I;F<@;6ES<VQY8VMA9&5S("T@
M;65D9&5L86YD970@:V%N(&AA(&UA;FEP=6QE<F%T<RXB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,"!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C<P,0IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R(")697)S:6]N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R.`IM<V=I9"`B5F5R
M<VEO;B!#;VYT<F]L(@IM<V=S='(@(E9E<G-I;VYH86YT97)I;F<B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S
M"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R(")697)T:6MA;"!J=7-T
M97)I;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(E9E<G1I
M:V%L('5T9GEL;&YA9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R(")697)T
M:6MA;#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW,0IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(E;D;&1I9W0@:/9G(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0X"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#(@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*;7-G<W1R(")6:65T;F%M
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3<*;7-G:60@(E9I971N86UE
M<V4@*%9)4T-)22DB"FUS9W-T<B`B5FEE=&YA;65S:7-K("A625-#24DI(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.38Q(&QI8B](
M;W)D92]-24U%+T-O;G1E;G1S+G!H<#HY-S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5FEE=R`E<R(*;7-G<W1R(")6:7-A("5S(@H*(SH@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*
M;7-G<W1R(")6:7-A(&5N(&5X=&5R;B!W96)B<VED82(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R,"!L:6(O2&]R9&4O34E-12]#
M;VYT96YT<RYP:'`Z.#(Y"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@
M)7,B"FUS9W-T<B`B5FES82!S;VT@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C<Y"FUS9VED(")6:65W(&5V96YT
M(@IM<V=S='(@(E9I<V$@:.1N9&5L<V4B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$P.0IM<V=I9"`B5FEE=R!T87-K
M(@IM<V=S='(@(E9I<V$@=7!P9VEF="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(T-@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B
M5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B2G5N9V9R=?9A<FYA
M+"!"<FET=&ES:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR-#<*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-"!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA
M;F1S+"!5+E,N(@IM<V=S='(@(DIU;F=F<G7V87)N82P@06UE<FEK86YS:V$B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-@IM<V=I9"`B5FES:6)I;&ET
M>2(*;7-G<W1R(")3:6MT(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(U,@IM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(E-I:W0Z(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z.#0*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX
M-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B5F]D
M869O;F4@271A;&EE;B!V:6$@4TU44"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*(SH@
M;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V
M"FUS9VED(")705).(@IM<V=S='(@(E9!4DXB"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A
M(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B5D%2
M3DE.1R$A(2!2041%4D$@4TM225!4150@34%.545,3%0@1E+%3B`E<RXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S,R!L:6(O
M3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA($A45%`B
M"FUS9W-T<B`B5TE.('9I82!(5%10(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C4P"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR-#4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")7
M86QL:7,@86YD($9U='5N82(*;7-G<W1R(")786QL:7,@;V-H($9U='5N82(*
M"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:'1M;"YP:'`Z,C<R"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES
M=&5N97(O<W1A='5S+G!H<#HR.0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M:'1M;"YP:'`Z,3(W(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B
M5V%R;FEN9R(*;7-G<W1R(")687)N:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B
M3VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@
M(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B5N1D97)P<F]G;F]S(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q-@IM<V=I9"`B5V5A=&AE
M<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(E;D9&5R9&%T82!F<N5N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR(&QI8B](;W)D92]&;W)M
M+G!H<#HX.38*;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@(G=E871H97(N
M8V]M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*
M;7-G<W1R(")796)B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S
M.0IM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B5V5B8G!L871S(@H*(SH@8V]N
M9FEG+W1H96UE<R]W96)B<&QA='-E;BUS;V)E<BYP:'`Z,38*;7-G:60@(E=E
M8F)P;&%T<V5N("T@4V]B97(B"FUS9W-T<B`B5V5B8G!L871S96X@+2!3;V)E
M<B(*"B,Z(&-O;F9I9R]T:&5M97,O=V5B8G!L871S96XM<V]B97)?;F5W+G!H
M<#HV"FUS9VED(")796)B<&QA='-E;B`M(%-O8F5R($Y%5R(*;7-G<W1R(")7
M96)B<&QA='-E;B`M(%-O8F5R($Y9(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA
M;F-E+TUA:6YT96YA;F-E+G!H<#HU."!L:6(O2&]R9&4O36%I;G1E;F%N8V4N
M<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B5F5C:V]V:7,B"@HC.B!S
M97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*
M;7-G<W1R(")6Y&QK;VUM96XB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE
M+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R(")6Y&QK;VUM96X@
M=&EL;"`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E
M;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")796QC;VUE+"`E<R(*;7-G<W1R(")6Y&QK;VUM96XL("5S(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3@*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y
M+3$I(@IM<V=S='(@(E;D<W1E<FSD;F1S:R`H25-/+3@X-3DM,2DB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y.0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X
M-3DM,34I(@IM<V=S='(@(E;D<W1E<FSD;F1S:R`H25-/+3@X-3DM,34I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<X"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#8@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(E;D<W1R
M82!386AA<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I
M<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(E9I;&ME;B!A<'!L:6MA=&EO
M;B!S:V%L;"`E<R!V:7-A(&5F=&5R(&EN;&]G9VYI;F<_(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E
M;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(E9I;&ME;B#D<B!A=F=RY&YS
M;FEN9W-T96-K;F5T/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C$W"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S
M='(@(E9I;&ME="#D<B!T96-K;F5T(&;V<B!C:71E<F%D('1E>'0_(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,S,*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C0*;7-G:60@
M(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R(")7:&5R96ES($%U<W1R
M86QI96YK87)T82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B
M5VAI8V@@<&AA<V5S(@IM<V=S='(@(E9I;&MA(&9A<V5R(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E
M;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R(")6:6QK
M82!P;'5G:6X@<VMA;&P@86MT:79E<F%S(&;V<B!2:6-H(%1E>'0@961I=&]R
M;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R(")"<F5D9"(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C4@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,Q,3$*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R(")"<F5D
M9"!I($-34RUU;FET<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@
M=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S
M='(@(D)R961D('#E(&UE;GEN(&;V<B`G)7,G('1I;&P@=N1N<W1E<B`H9^1L
M;&5R(&9RY6X@;N1S=&$@:6YL;V=G;FEN9R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T
M:&4@=&%B;&4B"FUS9W-T<B`B5&%B96QL8G)E9&0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@
M=6YI="(*;7-G<W1R(")"<F5D9&5N:&5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G
M<W1R(")"<F5D9#HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$U
M"FUS9VED(")7:6MI(@IM<V=S='(@(E=I:VDB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C@Y(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8V"FUS9VED(")7:6YD(@IM<V=S='(@(E9I;F0B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B
M5VEN9"!%87)L>2(*;7-G<W1R(")4:61I9R!V:6YD(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HX-PIM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G
M<W1R(")6:6YD:&%S=&EG:&5T(&D@:VYO<"(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,38S"FUS9VED(")7:6YD.B(*;7-G<W1R(")6:6YD.B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@(E=I;F0Z("(*
M;7-G<W1R(")6:6YD.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*
M;7-G:60@(E=I<V1O;2(*;7-G<W1R(")6:7-D;VTB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3DX"FUS9VED(")7:7-H;&ES="(*;7-G<W1R("+6
M;G-K96QI<W1A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED
M(")7;W)K(@IM<V=S='(@(D%R8F5T92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$V-`HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$R-"!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(D%D<F5S<RP@
M87)B971E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y
M,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")496QE9F]N+"!A<F)E=&4B
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-CD@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,C8R"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,3DS
M(&QI8B]&:6QE+T-35BYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(E=R
M;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L
M(&9O=6YD("5D+B(*;7-G<W1R(")&96P@86YT86P@9N1L="!PY2!R860@)60N
M($;V<G;D;G1A9&4@)60L(&AI='1A9&4@)60N(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z,S`P(&QI8B]&:6QE+T-35BYP:'`Z,S,R"B,L('!H
M<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C
M=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B1F5L(&%N=&%L(&;D;'0N($;V
M<G;D;G1A9&4@)60L(&AI='1A9&4@)60N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,3$T(&QI8B]61E,O9FEL92YP:'`Z,3(Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@
M5D93(&9I;&4N(@IM<V=S='(@(D9E;"!P;W-I=&EO;B`E9"!V:60@;.1S;FEN
M9R!A=B!61E,M9FEL+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-#4*;7-G:60@(E@M4F5F(@IM<V=S='(@(E@M4F5F(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4Y,B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P
M.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R(")8-3`Y5C,@573V:V%D
M(&YY8VME;&%N=N1N9&YI;F<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y-"!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM
M<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-2!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B6#4P.78S(%-U
M8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#(@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HV.#,*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@
M(E@U,#E6,RUT:6QLY&=G(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G
M:60@(EE9(@IM<V=S='(@(EE9(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C,X.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#,P"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,30@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0U-@IM<V=I9"`B65E962(*;7-G<W1R(")965E9(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#`*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,3$*;7-G:60@(EEA:&]O
M(2!M87`B"FUS9W-T<B`B66%H;V\A(&UA<"(*"B,Z(&9R86UE=V]R:R]-86EN
M=&5N86YC92]-86EN=&5N86YC92YP:'`Z-38@;&EB+TAO<F1E+TUA:6YT96YA
M;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(L5R;&EG(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4R"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#<@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$W"FUS9VED(")996UE;B(*;7-G<W1R(")996UE;B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY,S4*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-@IM<V=I9"`B665S
M(@IM<V=S='(@(DIA(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E
M;65N=%]B;W1T;VTN:6YC.C8*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA
M:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R
M(")*82P@:F%G('-A;71Y8VME<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-
M3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!7
M65-)5UE'+B(*;7-G<W1R(")$=2!H87(@86MT:79E<F%T('1E>'1LY&=E+B!!
M;G;D;F0@6SP^72!F]G(@871T(.5T97)GY2!T:6QL(%=94TE764<N(@H*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HR,S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@
M;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B1'4@:&%R(&EN=&4@8F5H
M]G)I9VAE="!S:V%P82!F;&5R(.1N("5D(&)L;V-K+B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,3,V-R!L:6(O2&]R9&4N<&AP.C$T,34*;7-G
M:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(D1U(.1R
M(&EN=&4@875T96YT:7-E<F%D+B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])
M9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")9;W4@8V%N(&YO="!H879E('1H92`G
M7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B1'4@
M:V%N(&EN=&4@86YVY&YD82`G7%PG(&D@9&ET="!N86UN(@H*(SH@;&EB+TAO
M<F1E+TED96YT:71Y+G!H<#HS,#@*;7-G:60@(EEO=2!C86YN;W0@:&%V92!T
M:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@
M(D1U(&MA;B!I;G1E(&%N=N1N9&$@)UQ<)R!I(&1I='0@;F%M;B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3DW-0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@U.2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3DW.0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V
M86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R(")$=2!A;F=A=B!I;G1E(&5N
M(&=O9&OD;F0@92UP;W-T861R97-S+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A
M=&$N<&AP.C(Y,"!L:6(O2&]R9&4O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T
M:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@
M(@HB:6X@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDX."!L:6(O2&]R9&4O075T:"YP:'`Z.3@W"FUS9VED(")9;W4@:&%V
M92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(D1U(.1R('5T;&]G9V%D+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$R-C4*;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L
M:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I
M;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E
M9FEX+B(*;7-G<W1R("(B"B)$=2!MY7-T92!A;F=E(&5T="!G:6QT:6=T(&UO
M8FEL;G5M;65R.R!E;F)A<G0@<VEF9G)O<B!O8V@@971T("<K)R!F]G)E("(*
M(FEN=&5R;F%T:6]N96QL="!P<F5F:7@N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3$X."!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$Y,@IM<V=I9"`B
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B1'4@
M86YG878@:6YT92!E='0@9V]D:^1N="!VY')D92XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,S<@;&EB+TAO<F1E+T%U=&@O4VEG;G5P
M+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@
M8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B(@HB1'4@;>5S=&4@
M:V]N9FEG=7)E<F$@96X@1&%T851RY&1S+6MO<'!L:6YG(&;V<B!A='0@86YV
MY&YD82!R96=I<W1R97)I;F<B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C0S-B!L:6(O2&]R9&4N<&AP.C0V,@IM<V=I9"`B66]U(&UU<W0@8V]N
M9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(D1U(&WE<W1E(&MO;F9I
M9W5R97)A(&5N(%9&4RUK;W!P;&EN9R(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@
M<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R
M="XB"FUS9W-T<B`B1'4@;>5S=&4@8F5S:W)I=F$@<')O8FQE;65N+"!I;FYA
M;B!D=2!K86X@<F%P<&]R=&5R82!E='0@<')O8FQE;2XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@
M;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B
M"FUS9W-T<B`B1'4@;>5S=&4@86YG92!E;B!54DP@<V]M(&SD;FME;B!P96MA
M<B!PY2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED
M(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM
M<V=S='(@(D1U(&WE<W1E(&%N9V4@96X@<V5R=F5R('-O;2!S:V%L;"!R861E
M<F%S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B1'4@
M;>5S=&4@86YG92!E='0@86YVY&YD87)N86UN('-O;2!S:V%L;"!R96YS87,N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R(")$=2!MY7-T92!A
M;F=E(&5T="!A;G;D;F1A<FYA;6X@<V]M('-K86QL(')A9&5R87,N(@H*(SH@
M861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!A9&0N(@IM<V=S='(@(D1U(&WE<W1E(&%N9V4@971T(&%N=N1N9&%R;F%M
M;B!S;VT@<VMA;&P@;.1G9V%S('1I;&PN(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U
M<&1A=&4N(@IM<V=S='(@(D1U(&WE<W1E(&%N9V4@971T(&%N=N1N9&%R;F%M
M;B!S;VT@<VMA;&P@=7!P9&%T97)A<RXB"@HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@@;&EB+TAO<F1E+T-O;7!R97-S+WII
M<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N
M('1O('!E<F9O<FTN(@IM<V=S='(@(D1U(&WE<W1E(&%N9V4@96X@Y71GY')D
M('-O;2!S:V%L;"!U=&;V<F%S+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"B,Z(&QI8B](;W)D92]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED(")9;W4@;75S="!T>7!E(&$@
M;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(D1U(&WE<W1E(&%N9V4@971T
M(&YY='0@:V%T96=O<FEN86UN+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"B,Z(&QI8B].970O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R
M;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B1'4@;>5S
M=&4@86YG92!E='0@:71A;&EE;G-K="!T96QE9F]N;G5M;65R(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3<V(&QI8B](;W)D92]!=71H+G!H<#HY
M-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E
M>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(D1I;B`E<R!S
M97-S:6]N(&AA<B!U<'!H]G)T+B!687(@9V]D(&QO9V=A(&EN(&EG96XN(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G:60@(EEO
M=7(@16UA:6P@061D<F5S<R(*;7-G<W1R(")$:6X@92UP;W-T861R97-S(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q-0IM<V=I9"`B66]U<B!&<F]M
M.B!A9&1R97-S.B(*;7-G<W1R(")$:6X@1G+E;CH@861R97-S.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@U"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,@IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R(")$
M:6X@:6YF;W)M871I;VXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.#`@;&EB+TAO<F1E+T%U=&@N<&AP.CDW.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@
M=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E
M8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S
M='(@(B(*(D1I;B!I;G1E<FYE=&%D<F5S<R!H87(@Y&YD<F%T<R!E9G1E<B!A
M='0@9'4@;&]G9V%T(&EN('1I;&P@)R5S)RX@1O9R(&%T="`B"B)S:WED9&$@
M9&EG+"!MY7-T92!D=2!L;V=G82!I;B!I9V5N+B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R($YA;64B"FUS9W-T
M<B`B1&ET="!N86UN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N
M:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D
M;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@
M(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U
M(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0N(@IM<V=S='(@(B(*(D1I;B!A=71E;G1I<V5R:6YG<VMO<'!L:6YG('-T
M]F1E<B!I;G1E('5P<&SD9V<@878@86YVY&YD87)E+B!/;2!D=2!V:6QL("(*
M(F%N=N1N9&$@2&]R9&4@9O9R(&%T="!A9&UI;FES=')E<F$@86YVY&YD87)E
M('/E(&WE<W1E(&1U(&%N=N1N9&$@96X@86YN86X@(@HB875T96YT:7-E<FEN
M9W-K;W!P;&EN9RXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N
M:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D
M;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E
M("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB
M"FUS9W-T<B`B(@HB1&ET="!A=71E;G1I<V5R:6YG<VMO<'!L:6YG('-T]F1E
M<B!I;G1E(&QI<W1N:6YG(&%V(&%N=N1N9&%R92P@96QL97(@<^4@Y'(@(@HB
M9G5N:W1I;VYE;B!A=G-TY&YG9"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.#0@;&EB+TAO<F1E+T%U=&@N<&AP.CDX,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG
M960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*
M(E1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A
M:6XN(@IM<V=S='(@(B(*(D1I;B!W96)B;.1S87)E+VEN=&5R;F5T861R97-S
M(&AA<B#D;F1R871S(&5F=&5R(&%T="!D=2!L;V=G870@:6X@=&EL;"`G)7,G
M+B`B"B)&]G(@871T('-K>61D82!D:6<L(&WE<W1E(&1U(&QO9V=A(&EN(&EG
M96XN(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-34*;7-G:60@(EEO=7(@
M8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T
M<B`B1&EN('=E8F)LY'-A<F4@<W3V9&5R(&EN=&4@9&5N(&CD<B!F=6YK=&EO
M;F5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS
M9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R
M:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P
M<FEN="XB"FUS9W-T<B`B(@HB1&EN('=E8F)LY'-A<F4@<W3V9&5R(&EN=&4@
M=71S:W)I9G1S9G5N:W1I;VYE;BX@5')Y8VL@0W1R;"]/<'1I;VX@*R!0(&;V
M<B`B"B)A='0@<VMR:79A('5T+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-C$*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@
M(D1I;B!A:W1U96QL82!T:61S>F]N.B(*"B,Z('-E<G9I8V5S+W!R969S+G!H
M<#HQ,3<*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C
M:&%N9V5D+B(*;7-G<W1R(")$:6X@9O9R=F%L9&$@:61E;G1I=&5T(&AA<B#D
M;F1R871S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C$*;7-G:60@
M(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`B1&EN(&;V<G9A;&1A
M(&ED96YT:71E=#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`T"FUS
M9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`B1&ET="!F=6QL<W3D;F1I
M9V$@;F%M;CHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HQ,#`P(&QI
M8B](;W)D92]!=71H+G!H<#HY.3D*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X
M<&ER960N(@IM<V=S='(@(D1I;B!I;FQO9V=N:6YG(&AA<B!GY71T('5T+B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS
M9W-T<B`B1&ET="!N>6$@;/9S96YO<F0@9O9R("5S(.1R.B`E<R(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34T(&QI8B](;W)D92]0<F5F
M<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P
M9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S
M='(@(D1I;F$@:6YS=.1L;&YI;F=A<B!H87(@=7!P9&%T97)A=',@9O9R(&1E
M;B!HY'(@<V5S<VEO;F5N+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,34V(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9
M;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(D1I;F$@
M:6YS=.1L;&YI;F=A<B!H87(@=7!P9&%T97)A=',N(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S
M(&)E96X@<F5S970B"FUS9W-T<B`B1&ET="!L]G-E;F]R9"!H87(@8FQI=FET
M(.5T97)S=.1L;'0B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW
M.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE
M8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S
M<W=O<F0N(@IM<V=S='(@(B(*(D1I='0@;/9S;F]R9"!H87(@Y71E<G-TY&QL
M=',L(&MO;G1R;VQL97)A(&1I;B!E+7!O<W0@;V-H(&QO9V=A(&EN(&UE9"!D
M:71T("(*(FYY82!L]G-E;F]R9"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HW,S(@;&EB+TAO<F1E+T%U=&@N<&AP.C<S,PIM<V=I9"`B66]U<B!P
M87-S=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B1&ET="!L]G-E;F]R9"!H
M87(@9^5T="!U="XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(D1I;F$@
M9FKD<G)S97)V<F%R.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(U-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3@*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B2G5G;W-L879I96XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B6F%I<F4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-38*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T."!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("):86UB:6$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3<*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T.2!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(EII;6)A
M8G=E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P
M>2(*;7-G<W1R(")::7!P>2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+U1E
M>'0O5&5X="]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-CD*(SH@;&EB
M+TAO<F1E+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED
M(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B6T?V;2!C:71E<F%D('1E
M>'1=(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#D*;7-G:60@(EM0<F]B
M;&5M(%)E<&]R=%TB"FUS9W-T<B`B6T9E;')A<'!O<G1=(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W
M(%%U;W1E9"!497AT("TB"FUS9W-T<B`B6U9I<V$@8VET97)A9"!T97AT("TB
M"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U
M;W1E<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R]497AT+U1E>'0O1FEL=&5R+VAI
M9VAL:6=H='%U;W1E<RYP:'`Z,38Y"B,Z(&QI8B](;W)D92]497AT+T9I;'1E
M<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");5FES
M82!C:71E<F%D('1E>'0@+2`E<R!R861E<ETB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$Y,R!L:6(O2&]R9&4N<&AP.C$Y-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B6W)A9"`E<R!A
M=B`E<UTB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T.3<@;&EB
M+TAO<F1E+G!H<#HQ-30U"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z
M,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")?061M:6YI<W1R
M871I;VXB"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T
M<B`B7T-,22(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A=&%4<F5E
M(@IM<V=S='(@(E]$871A5'+D9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2
M;W<B"FUS9W-T<B`B7U)A9&5R82!R860B"@HC.B!L:6(O87!I+G!H<#HQ,S,*
M;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B7T=R=7!P97(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U(&QI8B](;W)D92]-96YU+G!H
M<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@(E](:N1L<"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM
M<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B7T)I;&1I;G-T
MY&QL;FEN9V%R+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N
M<&AP.C$Y-"!L:6(O2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN
M(@IM<V=S='(@(E],;V=G82!I;B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]-96YU+G!H<#HQ.3`@;&EB+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B
M7TQO9R!O=70B"FUS9W-T<B`B7TQO9V=A('5T(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?
M36]D:69Y($QI;FLN+BXB"FUS9W-T<B`BQ%]N9')A(&SD;FLN+BXB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T(&QI8B](;W)D92]-
M96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(E]);G-TY&QL
M;FEN9V%R(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B7T)E:/9R:6=H971E<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E
M;6]V92!,:6YK+BXN(@IM<V=S='(@(E]482!B;W)T(&SD;FLN+BXB"@HC.B!L
M:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R(")?4V5T=7`B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@
M(E]486)E;&QI;G-TY&QL;FEN9V%R+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y
M"FUS9VED(")?57-E<G,B"FUS9W-T<B`B7T%N=N1N9&%R92(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Q(&QI8B](;W)D92]+;VQA8BYP:'`Z
M.3(U"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B861R97-S8F]K(@H*
M(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R
M97-S964@=6YK;F]W;B(*;7-G<W1R(")O:^1N9"!M;W1T86=A<F4B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ,R!L:6(O2&]R9&4O2V]L86(N
M<&AP.CDQ-PIM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B:V%L96YD97(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W.2!L:6(O0FQO8VLO;65T87(N<&AP
M.C,V-0IM<V=I9"`B8V%L;2(*;7-G<W1R(")L=6=N="(*"B,Z(&QI8B](;W)D
M92]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T92!O
M=71P=70@9FEL92(*;7-G<W1R(")K86X@:6YT92!S:V%P82!U=&9I;"(*"B,Z
M(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T
M(&]P96X@:6YP=70B"FUS9W-T<B`B:V%N(&EN=&4@]G!P;F$@:6YD871A(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DQ(&QI8B](
M;W)D92]-24U%+T-O;G1E;G1S+G!H<#HU.3D*;7-G:60@(F-L:6-K(&AE<F4B
M"FUS9W-T<B`B:VQI8VMA(&CD<B(*"B,Z(&QI8B]";&]C:R]B87)T:6UE+G!H
M<#HU-@IM<V=I9"`B8VQO8VLB"FUS9W-T<B`B:VQO8VMA(@H*(SH@;&EB+TAO
M<F1E+TU)344O365S<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@
M=7-A9V4@97)R;W(B"FUS9W-T<B`B:V]M;6%N9&]R861S9F5L(@H*(SH@;&EB
M+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T
M:6]N(&5R<F]R(@IM<V=S='(@(FMO;F9I9W5R871I;VYS9F5L(@H*(SH@;&EB
M+TAO<F1E+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S
M>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(FMR:71I<VL@<WES=&5M9FEL
M('-A:VYA<R(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$R-@IM
M<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B9&%T869O<FUA=&9E
M;"(*"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,S`*;7-G:60@(F5D
M:70B"FUS9W-T<B`BY&YD<F$B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E
M+G!H<#HQ.#(*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R(")P;W-T
M96X@:W5N9&4@:6YT92!H:71T87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R(")F
M86QL86YD92(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U
M,"!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.#DX"FUS9VED(")F:6QE(@IM<V=S
M='(@(F9I;"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@Q(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S8W(&QI8B]";&]C:R]M971A<BYP:'`Z,SDS"B,L('!H
M<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS
M9W-T<B`B9G+E;B!D96X@)7,@*"5S*2!K;"`E<R`E<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,SD*;7-G:60@(F=U<W1I;F<B"FUS9W-T
M<B`B<W1O<FUB>6%R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(S,@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C4P"FUS9VED(")H.B(*;7-G<W1R(")H.B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS,S0*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.0IM<V=I9"`B:&@B"FUS9W-T
M<B`B:&@B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G
M:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(F]KY&YD(';D<F1D871O
M<B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(R,PHC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-38U(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED
M(")I;6UE9&EA=&4B"FUS9W-T<B`B9V5N87-T(@H*(SH@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN
M;&EN92(*;7-G<W1R(")I;FQI;F4B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S
M86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R
M(")B96%R8F5T;FEN9W-F96PB"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E
M+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S
M='(@(DEN=&5R;G0@87!P;&EK871I;VYS9F5L(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G
M<W1R(")R861E<ETB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O;6MI<V]F<RYP:'`Z-3,*(SH@9G)A;65W;W)K+U9&4U])4T\O25-/
M5W)I=&5R+VUK:7-O9G,N<&AP.C4T(&QI8B]61E,O25-/5W)I=&5R+VUK:7-O
M9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@
M8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R(")F96QK;V0@)60@
M9G+E;B!M:VES;V9S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,T-0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S<P"FUS9VED(")M;2(*;7-G<W1R(")M;2(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,CDP(&QI8B](;W)D92]0<F5F<R]522YP
M:'`Z,C@U"B,Z('-E<G9I8V5S+W!O<G1A;"]M96YU+G!H<#HR,3(@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,C0Q"FUS9VED(")N86UE(@IM<V=S='(@(FYA;6XB"@HC
M.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(Q(&QI8B](;W)D92]24$,N<&AP
M.C$R-`IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(FEN=&4@:6UP
M;&5M96YT97)A9"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,3(Q.2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R,C`*;7-G:60@
M(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`B:6YT92!I;7!L96UE;G1E
M<F%D(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#4@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HY,#D*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B86YT
M96-K;FEN9W-B;&]C:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B
M<')O8V5N="(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W-`IM
M<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`BY71K;VUS="!N96MA
M9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R(")P:7AL87(B"@HC.B!L
M:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E
M<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R(")P<F]T;VMO;&QF96PB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW-`IM<V=I9"`B
M<FES:6YG(@IM<V=S='(@(G-T:6=A;F1E(@H*(SH@;&EB+TAO<F1E+TU)344O
M365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM
M<V=S='(@(E1JY&YS=&5N(.1R(&5J('1I;&QGY&YG;&EG(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HQ,#$*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B
M"FUS9W-T<B`B=FES82!S:VEL;&YA9&5R(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(
M5%10(@IM<V=S='(@(G-M<S)E;6%I;"!V:6$@2%144"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-C$*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-PIM<V=I9"`B<W,B"FUS9W-T
M<B`B<W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW,PIM<V=I9"`B<W1E861Y(@IM<V=S='(@(G-T861I9W0B"@HC.B!L:6(O
M2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O
M<B(*;7-G<W1R(")S>7-T96UF96PB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDR.2!L:6(O2&]R9&4O2V]L86(N<&AP.CDS,PIM<V=I9"`B=&%S
M:R!L:7-T(@IM<V=S='(@(G5P<&=I9G1S;&ES=&$B"@HC.B!L:6(O2&]R9&4O
M34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E
M(@IM<V=S='(@(G1I;&QFY&QL:6=T(&9E;"(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*(SH@;&EB
M+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(G1Y<&4@=&AE('!A
M<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B86YG92!L]G-E;F]R
M9&5T('1VY2!GY6YG97(@9O9R(&%T="!B96MRY&9T82(*"B,Z(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED
M(")U;FEF:65D(@IM<V=S='(@(F5N860B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U!A<G0N<&AP.C(W(&QI8B](;W)D92]-24U%+U!A<G0N<&AP.C(W"FUS
M9VED(")U;FYA;65D(@IM<V=S='(@(FYA;6YL]G,B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-2!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS
M9W-T<B`B86YVY&YD87)V86PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,S4@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(T"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-#(*;7-G:60@(G<Z(@IM
M<V=S='(@(G<Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*
M;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M(@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]T<E]44BYP;P``````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-S(P,C<T`#$P
M-3$U-#,S-S4U`#`Q-S<P-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````C(%1U<FMI<V@@=')A;G-L871I;VYS(&9O<B!(;W)D
M92!P86-K86=E"B,@2&]R9&4@<&%K971I(&GG:6X@5/QR:^=E(,=E=FER:6QE
M<BX*(R!#;W!Y<FEG:'0@*$,I(#(P,#4@2&]R9&4@4')O:F5C=`HC(%1H:7,@
M9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S
M('1H92!(;W)D92!P86-K86=E+@HC($=E;F5R871E9"!B>0HC(%-E<G9E="!'
M_&YE>2`\<V=U;F5Y0&UE='4N961U+G1R/@HC($%H;65T(-9Z=/QR:R`\;V%H
M;65T0&UE='4N961U+G1R/@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C
M="U)9"U697)S:6]N.B!(;W)D978S+C`N-%QN(@HB4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$
M871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A
M=&4Z(#(P,#4M,#8M,C@@,30Z-#@K,#,P,%QN(@HB3&%S="U4<F%N<VQA=&]R
M.B!!=71O;6%T:6-A;&QY(&=E;F5R871E9%QN(@HB3&%N9W5A9V4M5&5A;3H@
M:3$X;D!L:7-T<RYH;W)D92YO<F=<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB
M"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM
M.5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@HB4&QU
M<F%L+49O<FUS.B!N<&QU<F%L<STQ.R!P;'5R86P],#M<;B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B("@E<R!G_&X@]FYC92DB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S-S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(BA%<FG^:6T@06YA:'1A
M<OT@)7,I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B`H)7,@
M9_QN9&4I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,PIM<V=I
M9"`B("AT;V1A>2DB"FUS9W-T<B`B("AB=6?\;BDB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S<U"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R
M("(@*'EA<OUN*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S$*
M;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(@*&3\;BDB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4V(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS-C$*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C0P-PIM<V=I9"`B(&%T("(*;7-G<W1R("(@9&4H9&$I("(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$U"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R(")$
M:7II;B!D9?!I;"(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI
M9"!C:&]I8V4N(@IM<V=S='(@(B<E<R<@:7,@9V7G97)L:2!B:7(@<V7G96YE
M:R!D9?!I;"XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN
M<&AP.C8U.0HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP
M.C$P-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N
M;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@
M(B<E<R<@2&]R9&4@2V%Y_71L87+];F1A('EA</UL86YD_7+];&UA;?W^+B(*
M"B,Z(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD
M+B(*;7-G<W1R("(G)7,G(&'P8><@YV5V:7)I8VES:2!B=6QU;F%M863]+B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN
M(@IM<V=S='(@(B<E<R<@9W)U<"!S:7-T96UI;F4@96ML96YD:2XB"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS
M('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R!I>FEN('-I<W1E;6EN92!E:VQE;F1I
M+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI
M;&0N<&AP.C4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B)R5S)WEA<F%T_6QA;6%D
M_3H@)7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N
M,F8E)2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS
M9W-T<B`B)60@)7,@=F4@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L('!H<"UF
M;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I
M<F5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*
M;7-G<W1R("(E9"UG_&YL_&L@:&%V82!T86AM:6YI(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@
M3F]T:6-E(@IM<V=S='(@(B5S("T@0FEL9&ER:6TB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(E<R!087)M86L@W7II(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S-0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N
M86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S($)A
M:_UM(-W^;&5M;&5R:2`M($]N87EL86UA(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B5S($%Y87)L87(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8S"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B)7,@1VER:?XB"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B5S($%N;&'^
M;6$@2V_^=6QL87+](@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT
M,C@@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3`*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HV-3$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N
M(@IM<V=S='(@(B5S('IA=&5N('9A<BXB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$U.2!L:6(O0FQO8VLO;65T87(N<&AP.C$V-2!L:6(O0FQO8VLO;65T
M87(N<&AP.C(S.0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T-2!L:6(O0FQO
M8VLO;65T87(N<&AP.C,U,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E
M<R`E<R(*;7-G<W1R("(E<R!D92`E<R`E<R(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@
M;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE
M+B(*;7-G<W1R("(B"B)'97+G:V7^=&ER:6QM97-I;FD@:7-T961I\&EN:7H@
M:?YL96UL97(@:>=I;B!O;F%Y(&MU='5L87+];OT@:?YA<F5T;&5Y:6XN(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,T,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(E<R!I<W1E;FUE:W1E
M9&ER+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@V"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B)7,@9&%K:6MA(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B5S(&)U
M;'5N86UA9/TN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R
M("(E<R`M("5S("\@)7,@(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB
M"FUS9W-T<B`B)7,@061R97,@1&5F=&5R:2(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3$T"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L
M96YD87(B"FUS9W-T<B`B)7,@5&%K=FEM(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E
M<&%D(@IM<V=S='(@(B5S($YO="!$969T97)I(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!4
M87-K;&ES="(*;7-G<W1R("(E<R!']G)E=B!,:7-T97-I(@H*(SH@9G)A;65W
M;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B
M)7,Z("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP
M:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A
M9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A
M<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V
M:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,V-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$P"B,L(&9U>GIY
M"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@9OUR=/UN86S]("5S("5S
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S
M(@IM<V=S='(@(BP@9OUR=/UN86S]("5S("5S(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F
M<F]M("5S('1O("5S(@IM<V=S='(@(BP@9&7P:?YI;2`E<R`M/B`E<R(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,CDT(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,S0X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$R.`HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0Y"FUS9VED("(M
M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@4V7G("TM(@H*(SH@;&EB+T)L;V-K
M+W1I;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R("(Q
M,B!386%T;&EK(%IA;6%N($)IYVEM:2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B,C0@4V%A=&QI
M:R!:86UA;B!":>=I;6DB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR
M.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@<V%A="(*"B,Z(&9R86UE
M=V]R:R]522]522]086=E<BYP:'`Z-CD*(RP@9G5Z>GD*;7-G:60@(CQ0<F5V
M:6]U<R(*;7-G<W1R("+6;F-E:VD@4V%Y9F$B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$Q.0IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I
M<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R(")"=2#V8F5K(&GG:6X@=F5R
M:71A8F%N_2!S;VX@=7IA;G3]<_T@9V5R96MM96MT961I<BXB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V,`IM<V=I9"`B02!F871A;"!E<G)O
M<B!H87,@;V-C=7)R960B"FUS9W-T<B`B3VYU;&UA>B!B:7(@:&%T82!O;'7^
M='4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G
M:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A
M(&UE<W-A9V4N(@IM<V=S='(@(MUL971I>6D@_FEF<F5L97EE8FEL;65K(&GG
M:6X@4$=0(&'G_6L@86YA:'1A<OT@9V5R96MM96MT961I<BXB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38U"FUS9VED(")!('!U8FQI
M8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S
M86=E+B(*;7-G<W1R("(B"B+=;7IA;&%N;?W^(&EL971I>6D@9&_P<G5L=?!U
M;G4@<V'P;&%M86L@:>=I;B!01U`@8>?]:R!A;F%H=&%R_2!G97)E:VUE:W1E
M9&ER+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P.3<*
M;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M
M97-S86=E+B(*;7-G<W1R("(B"B+=;&5T:6YI;B#^:69R97-I;FD@Y_9Z;65K
M(&GG:6X@8>?]:R!01U`@86YA:'1A<OTL]GIE;"!01U`@86YA:'1A<OT@=F4@
M9V7G:?X@(@HB=/QM8V5C:?!I(&=E<F5K;65K=&5D:7(N(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Q-0IM<V=I9"`B(@HB02!P=6)L
M:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*
M(MUL971I>6D@:6UZ86QA;6%K(&GG:6X@8>?]:R!01U`@86YA:'1A<OTL]GIE
M;"!01U`@86YA:'1A<OT@=F4@9V7G:?X@(@HB=/QM8V5C:?!I(&=E<F5K;65K
M=&5D:7(N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M,#4*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-
M24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E
M8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B+=;&5T:6YI;B#^:69R97-I
M;FD@Y_9Z;65K(&GG:6X@8>?]:R!3+TU)344@86YA:'1A<OTL(/9Z96P@4R]-
M24U%(&%N86AT87+]('9E("(*(F=EYVG^('3\;6-E8VGP:2!G97)E:VUE:W1E
M9&ER+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q
M"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*
M(F$@;65S<V%G92XB"FUS9W-T<B`B(@HBW6QE=&EY:2!I;7IA;&%M86L@:>=I
M;B!AY_UK(%,O34E-12!A;F%H=&%R_2P@]GIE;"!3+TU)344@86YA:'1A<OT@
M=F4@9V7G:?X@(@HB=/QM8V5C:?!I(&=E<F5K;65K=&5D:7(N(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B
M;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92XB"FUS9W-T<B`BW6QE=&EY:2#^:69R96QE>65B:6QM96L@:>=I;B!AY_UK
M(%--24U%(&%N86AT87+](&=E<F5K;65K=&5D:7(N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0HC+"!F=7IZ>0IM<V=I9"`B
M04T@0VQO=61S(@IM<V=S='(@(D)U;'5T;&%R(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*(RP@9G5Z>GD*;7-G:60@(D%-
M($QI9VAT(%)A:6XB"FUS9W-T<B`BUE,@2&%F:68@66'P;75R(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-
M(%)A:6XB"FUS9W-T<B`BUM8@66'P;75R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS
M9W-T<B`BUM8@4V'P;F%K(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R
M("+6UB!(869I9B!+87(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR
M.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`BUM8OUE,B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%0
M22!)1"(*;7-G<W1R(")!4$D@240B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O
M<B(*;7-G<W1R(")$_'IE;FQE>6EC:2!H86MK_6YD82(*"B,Z('-E<G9I8V5S
M+VAE;'`O:6YD97@N<&AP.C4R"FUS9VED(")!8F]U="XN+B(*;7-G<W1R(")(
M86MK_6YD82XN+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B16YA;'0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R
M"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B3W)T87EA(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE
M9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")61E,@9&EZ:6YI
M('EA<F%T_7)K96X@97)I_FEM(&5N9V5L;&5N9&DN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B5D93(&1I>FEN:2!Y87)A=/UL
M_7)K96X@97)I_FEM(&5N9V5L;&5N9&DN(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB
M"FUS9W-T<B`B0FEL9VEL97)I;FEZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<U"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(DAE<V%P
M(%!A<F%L;W/](@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T
M<B`B2&5S87`@1&]N9'5R=6QD=2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S,S"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(DAE<V%P;&%N
M_7EO<B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X('1E
M;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B061D(@IM<V=S='(@(D5K
M;&4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP
M.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(D%L="!'<G5P
M($5+;&4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL
M9"!097)M:7-S:6]N(@IM<V=S='(@(D%L="#=>FEN($5+;&4B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S
M='(@(D)U<F%Y82!%:VQE.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D
M;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S
M='(@(EEE;FD@1W)U<"!%:VQE(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HX-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@X"FUS
M9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS9W-T<B`B665N:2#=>FEN($5K
M;&4B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G<F]U
M<"!T;R!<(B5S7"(B"FUS9W-T<B`B06QT(&=R=6)U("<E<R<@:>=I;F4@96ML
M92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30W"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N
M('1O(%PB)7-<(B(*;7-G<W1R("(G)7,G(/QZ97)I;F1E(&%L="!I>FEN(&5K
M;&4B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S
M97(Z(@IM<V=S='(@(EEE;FD@:W5L;&%N_6/](&5K;&4Z(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-`IM<V=I9"`B061D
M(&-O;'5M;B(*;7-G<W1R(")+;VQO;B!%:VQE(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M96UB97)S
M(@IM<V=S='(@(EEE;FD@_'EE(&5K;&4B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R("+=:VEL:2!%
M:VQE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B
M87(B"FUS9W-T<B`B)7,@365N_'/\;OP@36]Z:6QL82!+96YA<B#'=6)U\'4@
M3VQA<F%K($5K;&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-S$*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S
M='(@(D%D<F5S(&1E9G1E<FEN92!E:VQE.B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`IM<V=I9"`B061D('1O(&UY(&%D
M9')E<W,@8F]O:R(*;7-G<W1R(")!9')E<R!D969T97)I;64@96ML92(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R(")+
M=6QL86[]8_T@16ML92(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y
M<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF
M;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(G)7,G('-I<W1E;64@96ML96YD
M:2P@86UA(&AE<FAA;F=I(&5K(&)I<B!G:7)I_B!B:6QG:7-I(&5K;&5N96UE
M9&DZ("5S(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@
M;&]G(&EN(&YO=RXB"FUS9W-T<B`B)R5S)R!S:7-T96UE(&5K;&5N9&DN(-YI
M;61I(&=I<FG^('EA<&%B:6QI<G-I;FEZ+B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES
M86)L960N(@IM<V=S='(@(DMU;&QA;OUC_2!E:VQE;64@<V7G:6QE;65Z(&O]
M;/UN9/TN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#$*;7-G:60@(D%D
M9')E<W,B"FUS9W-T<B`B061R97,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,3,Y"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B061R97,@
M1&5F=&5R:2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O
M<B!O=&AE<B!U<V5R<R(*;7-G<W1R(")9]FYE=&EM+2U$:?!E<B!K=6QL86[]
M;&%R(&GG:6X@:7II;FQE<FD@8F5L:7)L97EI;B(*"B,Z(&%D;6EN+VEN9&5X
M+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED
M(")!9&UI;FES=')A=&EO;B(*;7-G<W1R(")9]FYE=&EM(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,T,0IM<V=I9"`B061S(@IM<V=S='(@(D%D
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(D%F
M9V%N:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;&)A;FEA(@IM<V=S='(@
M(D%R;F%V=71L=6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S
M='(@(D-E>F%Y:7(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R("+6=&5K:2!A9"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@(DAI>F%L82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L
M:6=N;65N=#HB"FUS9W-T<B`B2&EZ86QA;6%K.B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(E3\;?PB"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R
M<R(*;7-G<W1R(")4_&T@1&_P<G5L86YM_?X@2W5L;&%N_6/];&%R(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I
M9"`B06QL($=R;W5P<R(*;7-G<W1R(")4_&T@1W)U<&QA<B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(E3\;2#=>FEN;&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED
M97,B"FUS9W-T<B`B5/QM(&3V<G0@>?QZ(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@W,0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S
M(@IM<V=S='(@(L=O:VQU(&%D<F5S;&5R92!I>FEN('9E<B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,S0*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@
M;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(E/]<F%L86YM_?X@;&ES=&4@
M=/QR_&[\(&%Y87)L86UA>6$@:7II;B!V97)I;'-I;B!M:3\B"@HC.B!F<F%M
M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HU,#0*;7-G:60@(D%L
M<F5A9'D@97AI<W1S(@IM<V=S='(@(EIA=&5N('9A<B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,C,*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN
M(@IM<V=S='(@(M9T96MI($E-4U`@1VER:?YI(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4P-PIM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B
M"FUS9W-T<B`BUG1E:VD@24U34"!087)O;&%S_2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT.3D*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE
M(@IM<V=S='(@(M9T96MI($E-4U`@2W5L;&%N_6/]($%D_2(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E<FYA=&4@96UA
M:6P@861D<F5S<R(*;7-G<W1R("+6=&5K:2!E;&5K=')O;FEK('!O<W1A(&%D
M<F5S:2(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E
M<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(M9T96MI('1A<VQA:VQA<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(M9T96MI
M(&UE=&EN.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM
M<V=S='(@(D%M97)I:V%N(%-A;6]A(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HY-2!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q
M-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G
M<W1R(")'9>=E<G-I>B!D9?!E<B!B96QI<G1I;&1I+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C<*(RP@9G5Z>GD*;7-G:60@(D%N('5N
M:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(F)I<B!H871A(&]L
M=?YT=3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(D%N
M9&]R82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R(")!;F=O
M;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R(")!;F=U
M:6QL82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G
M:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R(")!;F]N:6T@4')O>'DB"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R
M(@IM<V=S='(@(D-E=F%P(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC
M82(*;7-G<W1R(")!;G1A<G1I:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I
M9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(D%N=&EG=6$@=F4@0F%R8G5D82(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP
M.C,U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I
M;VXB"FUS9W-T<B`B57EG=6QA;6$B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B57EG=6QA
M;6$@3&ES=&5S:2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G
M:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R(")5>6=U;&%M82!(
M87K]<B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED
M(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B06QT('!A>6QA_OUM
M;&%R82!U>6=U;&$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R(")/;F%Y;&$B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S,*;7-G:60@(D%P
M<')O>&EM871E(%-I>F4B"FUS9W-T<B`B66%K;&'^_6L@0F]Y=70B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B
M07!R:6PB"FUS9W-T<B`B3FES86XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W-0IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(D%R
M87#G82`H5VEN9&]W<RTQ,C4V*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HV-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@Q"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R(")"96QG
M96QI:R!$;W-Y82!"=7EU='4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HX,`IM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(D)E;&=E;&EK($%D
M_2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z
M,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT
M('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T
M<B`B)7,@:>=I;B!G:7)I_B!I<W1E\&EN:2!K86QD_7)M86L@:7-T961I\&EN
M>F4@96UI;B!M:7-I;FEZ/R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M9&5L971E+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U
M8BUG<F]U<',_(@IM<V=S='(@(B<E<R<@=F4@=/QM(&%L="!G<G5P;&%R_6[]
M('-I;&UE:R!I<W1I>6]R(&UU<W5N=7H_(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B
M07)G96YT:6YA(@IM<V=S='(@(D%R:F%N=&EN(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I
M9"`B07)M96YI82(*;7-G<W1R(")%<FUE;FES=&%N(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM
M<V=S='(@(D5R;65N:6-E("A!4DU30TE)+3@I(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B4V%N870B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R(")!<G5B82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA
M;F0B"FUS9W-T<B`B07-C96YS:6]N($%D86QA<OTB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R(")!<V-I
M:2!386YA=/TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*
M;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B07-Y82]087-I
M9FEK($+V;&=E<VDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(U"FUS
M9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B0F%K_6T@:?YL96UL97)I;F1E
M;B#V;F-E(&1O\')U;&%M82!S;W)U;'-U;B!M=3\B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3$S"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B
M"FUS9W-T<B`B071A;6$@2V]L;VYL87+](@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HW-`IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@
M9W)O=7`N(@IM<V=S='(@(E9A<B!O;&UA>6%N(&)I<B!G<G5B=2!S:6QM92!G
M:7)I_FEM:2XB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED
M(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N
M+B(*;7-G<W1R(")687(@;VQM87EA;B!B:7(@:7IN:2!S:6QM92!G:7)I_FEM
M:2XB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP
M="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@
M(E9A<B!O;&UA>6%N(&)I<B!G<G5B=2!D_'IE;FQE;64@9VER:?YI;6DN(@H*
M(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(E9A<B!O
M;&UA>6%N(&)I<B!P87EL8?[];?T@9/QZ96YL96UE(&=I<FG^:6UI+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@V"FUS9VED(")!='1R:6)U=&5S
M(@IM<V=S='(@(M9Z;FET96QI:VQE<B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B
M0?!U<W1O<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R
M(")!=G5S='5R86QY82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS
M9W-T<B`B079U<W1U<GEA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S
M<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)S<6PZ(-US
M=&5N96X@:6UA<"!U>F%T873]<_T@8G5L=6YA;6%D_2XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z
M($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB
M"FUS9W-T<B`B075T:%]C>7)U<SH@W7-T96YE;B!Y971E;F5K;&5R92!S86AI
M<"!D9?!I;"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ
M,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)U<SH@W7-T96YE;B!I;6%P
M('5Z86YT_7/](&)U;'5N86UA9/TN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM
M96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*(D%U=&A?9G1P.B#=
M<W1E;F5N($944"!U>F%N=/US_2!B=6QU;F%M863]+B!02%`G>6D@+2UE;F%B
M;&4M9G1P('-W:71C:"`B"B)D9?!I_G1I<F=E<VEY;&4@9&5R;&5Y:6XN(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T
M:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%U=&A?:6UA<#H@W7-T96YE;B!)34%0('5Z86YT_7/](&)U;'5N
M86UA9/TN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU,0IM
M<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D%U=&A?:W)B-3H@W7-T96YE;B!K<F(U('5Z86YT
M_7/](&)U;'5N86UA9/TN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO
M="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U
M=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D
M($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P
M.B#=<W1E;F5N($Q$05`@=7IA;G3]<_T@8G5L=6YA;6%D_2XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(D%U=&A?:6UA<#H@
M)7,@:W5L;&%N_6/]<_T@96ML96YE;65D:2X@4W5N=6-U.B`B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G
M<W1R(")!=71H7VQD87`Z("5S(&MU;&QA;OUC_7/]('-I;&EN96UE9&DB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E
M<R(*;7-G<W1R(")!=71H7VQD87`Z("5S(&MU;&QA;OUC_7/](&?\;F-E;&QE
M;F5M961I(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,#4*
M;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O
M<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L
M.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(D%U=&A?;6-A;#H@W7-T96YE;B!-0T%,('5Z86YT_7/](&)U;'5N86UA9/TN
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!
M=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B075T:%]S;6)A=71H.B#=<W1E;F5N('-M8F%U=&@@
M=7IA;G3]<_T@8G5L=6YA;6%D_2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N(&9A:6QE9"(*;7-G<W1R(")$;_!R=6QA;6$@8F'^87+]<_UZ(&]L9'4N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@
M9F%I;&5D+B`E<R(*;7-G<W1R(")$;_!R=6QA;6$@8F'^87+]<_UZ(&]L9'4N
M("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM
M<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E
M<BXB"FUS9W-T<B`B1&_P<G5L86UA(%)!1$E54R!S=6YU8W5S=2!T87)A9OUN
M9&%N(&=E<FD@YV5V<FEL9&DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX-3$*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@
M9F%I;&5D+B(*;7-G<W1R(")&5%`@<W5N=6-U<W5N82!D;_!R=6QA;6$@8F'^
M87+]<_UZ(&]L9'4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW
M,`HC+"!F=7IZ>0IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S
M97)V97(@9F%I;&5D+B(*;7-G<W1R(")&5%`@<W5N=6-U<W5N82!D;_!R=6QA
M;6$@8F'^87+]<_UZ(&]L9'4N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B2W5L
M;&%N_6S]<B!A;&%N;&%R.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ
M86XB"FUS9W-T<B`B07IE<F)A>6-A;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(D)/1D@@0>?]
M:VQA;6%L87+](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R(")!
M<G1A;&%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R(")!<G1A
M;&%N(%)E;F=I(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX
M,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R(")+]G3\
M(&ME<F)E<F]S('!A<F]L87/]+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS
M9W-T<B`B2_9T_"!K97)B97)O<R!K=6QL86[]8_T@863]+B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B0F%H86UA;&%R(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R(")"86AR97EN(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM
M,3,I(@IM<V=S='(@(D)A;'3]:R`H25-/+3@X-3DM,3,I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R(")"86YG;&%D9?XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8P"FUS9VED(")"87)B861O<R(*;7-G<W1R(")"87)B861O<R(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B5&%B86X@9W)A9FEK(&1I>FEN:2`G)7,G(&)U;'5N
M86UA9/TN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<S"FUS9VED(")"87-E;&EN92(*;7-G<W1R(")486)A;B#G
M:7IG:7-I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R(")"
M97EA>B!2=7-Y82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T
M<B`B0F5LYVEK82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R
M(")"96QI>F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R(")"
M96YI;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B0F5R
M;75D82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R(")":'5T
M86XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R(")$;_!U;6?\;OPB"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4S"B,L('!H
M<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<
M(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")5>6=U;&%M82!<(B5S7"(@<V%H
M:7`@;VQD=?!U(%PB)7-<(B#V8F7P:2!B=6QU;F%M863]+B(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;&%Y;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN
M9W,B"FUS9W-T<B`BUF)E:R!!>6%R;&%R_2(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R("+6
M8F5K(%3\<OPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B2V]Y=2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B0F]L:79Y82(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR,#4*;7-G:60@(D)O;VMM87)K<R(*;7-G
M<W1R(")997(@W6UL97)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@
M(E/];OUR(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B4_UN
M_7(@2V%L_6YL_?#].B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B
M4_UN_7)L87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE
M9V]V:6YA(@IM<V=S='(@(D)O<VYA($AE<G-E:R(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R(")(97(@26MI<VDB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R(")";W1S=F%N
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(D%L="(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B0F]U=F5T($%D86QA
M<OTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)E>FEL
M>6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@
M5&5R<FET;W)Y(@IM<V=S='(@(D)R:71A;GEA($AI;G0@3VMY86YU<W4@0O9L
M9V5S:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM
M<V=S='(@(D)R=6YE:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM
M<V=S='(@(D)U;&=A<FES=&%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G
M<W1R(")-861D92#=;6QI($QI<W1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R
M:VEN82!&87-O(@IM<V=S='(@(D)U<FMI;F$@1F%S;R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*
M;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B0G5R=6YD:2(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT-#0*;7-G:60@(D--4R(*;7-G<W1R(")#35,B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS
M9VED(")#4D,B"FUS9W-T<B`B0U)3(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I
M;G1S(@IM<V=S='(@(D-23"!$8?#]=/UM($YO:W1A;&%R_2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM
M<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")?2/QC<F4@UGIE
M;&QI:VQE<FDN+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,38S"B,L(&9U>GIY"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE
M=&5D+B(*;7-G<W1R(")$8?#]=/UM(&QI<W1E<VD@8F5L:7)L96YE;65D:2XB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T
M(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.#<*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$U-0IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B5&%K=FEM
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-@IM<V=I9"`B
M0V%L;2(*;7-G<W1R(")$=7)G=6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M
M8F]D:6$B"FUS9W-T<B`B2V%M8F_G>6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#
M86UE<F]O;B(*;7-G<W1R(")+86UE<G5N(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@
M875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(B(*(E!A<F]L82#V>F1E=FEN:6UL:2!O;&%R86L@<_UF_7)L86YA
M;6%M86MT863]<BP@;/QT9F5N('GV;F5T:6-I;FEZ;&4@9_9R_/[\;BXB"@HC
M.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,3@*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B
M"FUS9W-T<B`B7"(E<UPB(&1O<WEA<_T@<VEL:6YE;65D:2XB"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT
M97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER<W%L+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@
M8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B24U!4"!S=6YU
M8W5S=6YA(&)A\&QA;OUL863].B`E<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C0Q,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB(&1O<WEA<_T@
M<VEL:6YE;65D:2XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#86YA9&$B"FUS9W-T
M<B`B2V%N861A(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N
M<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-C4*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q
M('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS
M9W-T<B`BW7!T86PB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(E-O
M<G5N(%)A<&]R=6YU(-UP=&%L($5T(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T
M92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB(&1O<WEA<_T@<VEL:6YE
M;65D:2XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y
M+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T
M;W)Y+B(*;7-G<W1R(")'9>=I8VD@9&EZ:6X@8G5L=6YA;6%D_2XB"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.CDQ"FUS9VED
M(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T
M97(N(@IM<V=S='(@(B=T87)G971&:6QE)R!D9?!I_G1I<F=E<VD@;VQM861A
M;B!D979A;2!E9&EL96UE>BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C,Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I
M<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(EPB)7-<(B!D:7II;FD@:V%L9/UR
M_6QA;6%D_2XB"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964N<&AP
M.C$R."!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV.#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R
M96X@97AI<W0N(@IM<V=S='(@(DMA;&3]<OUL86UA9/T@+"5D(&%L="!Y87#]
M('9A<BXB"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H
M<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT
M<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB
M97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"B)996YI9&5N(&3\>F5N;&5M961I
M+"!Y96YI9&5N(&3\>F5N;&5M92!IYVEN('-A\&QA;F%N(&MA>?UT;&%R_6X@
M<V%Y_7/](&EL92`B"B)D97!O;&%N;?W^(&]L86YL87+];B!S87G]<_T@9?YL
M9?YM96UE:W1E9&ER+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A
M9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B0F5L:7)T:6QM:?X@
M;G5M87)A>6$@:6QE=&D@>?9N;&5N9&ER:6QE;65D:2XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X
M"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(D-A<&4@5F5R9&4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T
M"FUS9VED(")#87!T:6]N(@IM<V=S='(@(D)A_FS]:R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R
M<FEE<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`*
M;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R(")+871E9V]R
M:6QE<B!V92!%=&EK971L97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N
M($ES;&%N9',B"FUS9W-T<B`B0V%Y;6%N($%D86QA<OTB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL
M(%!H;VYE(@IM<V=S='(@(D-E<"!496QE9F]N=2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E
M;&P@4')O<&5R=&EE<R(*;7-G<W1R(")(_&-R92#6>F5L;&EK;&5R:2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS
M9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(DC\8W)E('EA<W3]:VQA;6%S
M_3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B2/QC
M<F4@UGIE;&QI:VQE<FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R
M(")(_&-R92!";_YL=6ML87+].B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R-S0*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R(")#97`@5&5L969O
M;G4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B0V5L=&EC
M("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B2V5L=&EK("A)4T\M.#@U.2TQ-"DB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T<B`B3W)T82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R(")/
M<G1A($%F<FEK82!#=6UH=7)I>65T:2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3<Y"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*
M;7-G<W1R(")/<G1A($%V<G5P82`H25-/+3@X-3DM,BDB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Y.0IM<V=I9"`B0V5R=&EF:6-A
M=&4@1&5T86EL<R(*;7-G<W1R(")/;F%Y($)E;&=E<VD@07ER_6YT_6QA<OTB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,0HC+"!F
M=7IZ>0IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B3VYA>2!"
M96QG97-I($%Y<OUN=/UL87+](@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.38*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM
M<V=S='(@(D]N87D@0F5L9V5S:2!+=7)A;&QA<OTB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*
M;7-G:60@(D-H860B"FUS9W-T<B`BQV%D(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M-@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(D1E\&G^=&ER(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")#:&%N
M9V4@66]U<B!087-S=V]R9"(*;7-G<W1R(")087)O;&%N_7K]('/]9OUR;&%Y
M_6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@(B(*(D-H
M86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE
M;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G
M<W1R("(B"B+=;G-A;FQA<OUN('-I>F1E;B!G96QE;B!E;&5K=')O;FEK('!O
M<W1A;&%R_2!O:W5R:V5N('9E(&-E=F%P;&%R:V5N("(*(F?V<F3\:VQE<FD@
M860@=F4@861R97-I;FEZ:2!D9?!I_G1I<FEN+B(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P
M87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N
M9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(DMA<F%K=&5R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R(")"8?!L
M86YT_7G]($1E7VYE=&QE+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;&4B
M"FUS9W-T<B`BWFEL:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S
M='(@(L=I;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")#
M:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B0F%S:71L9?YT
M:7)I;&UI_B#':6YC92`H1T(R,S$R*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@Q"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G
M<W1R(")'96QE;F5K<V5L(,=I;F-E("A":6<U*2(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(D-H;V]S92!A('!A<W-W
M;W)D(@IM<V=S='(@(E!A<F]L82!S9>=I;B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HR-C@*;7-G:60@(D-H;V]S92!A('5S97)N86UE
M(@IM<V=S='(@(DMU;&QA;OUC_2!A9/T@<V7G:6XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,CDX"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@
M9&%T97,Z(@IM<V=S='(@(E1A<FEH;&5R:6X@;F%S_6P@9_9S=&5R:6QE8V7P
M:6YI('-EYVEN.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE
M('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R("),:7-T92!":>=E
M;2!4_'+\;OP@4V7G:6X@*'/]<F%L86YM_?X@;&ES=&5L97(@:>=I;BDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(D-H
M<FES=&UA<R!!9&%L87/](@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H
M<#HR.30@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@Y,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS
M9W-T<B`B4_UN_68@=&%N_6W](&)U;'5N86UA9/TZ)7,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B0VQE87(B
M"FUS9W-T<B`B5&5M:7IL92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B
M"FUS9W-T<B`B35-/9F9I8V4@8FGG:6T@:6UL97)I;FD@=&5M:7IL92(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*(RP@9G5Z>GD*;7-G:60@(D-L96%R
M(%%U97)Y(@IM<V=S='(@(DMU;&QA;OUC_2!T96UI>FQE(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(DMU;&QA;OUC_7G]('1E
M;6EZ;&4Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(DMU;&QA;OUC_2!T96UI
M>FQE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G
M:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R(")+=6QL86[]8_T@=F5R:7-I
M('1E;6EZ;&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-0HC+"!F=7IZ>0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R
M(")'9><@4V%A=&QE<F1E(%EA\&UU<B(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT
M:6YU92(*;7-G<W1R(")$979A;2!E=&UE:R!IYVEN('3]:VQA>?UN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T
M"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(DA45%`@>6]L
M=7EL82!#;&EC:V%T96QL(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T
M-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7
M:6YD;W<B"FUS9W-T<B`B4&5N8V5R97EI($MA<&%T(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-#0*;7-G:60@(D-L;W5D<R(*;7-G<W1R(")"=6QU=&QA
M<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V
M"B,L(&9U>GIY"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B0G5L=71L
M=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W
M"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B0G5L=71L=2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*
M;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(D-O8V]S
M($%D86QA<OTB"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S
M"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(DME;F%R(,=U8G7P
M=6YU($1A<F%L="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM
M<V=S='(@(D1A<F%L=/UL;?W^(%/];OUR;&%R(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I
M9"`B0V]L;VUB:6$B"FUS9W-T<B`B2V]L;VUB:7EA(@H*(SH@;&EB+T)L;V-K
M+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G
M:60@(D-O;&]R(@IM<V=S='(@(E)E;FLB"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(T"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R]#;VQL96-T:6]N+G!H<#HS,C4*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4P,"!S97)V:6-E<R]I;6%G97,O8V]L;W)P
M:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B4F5N
M:R!39>=I8VDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#0V"FUS
M9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(E)E;FL@4V7G:6UI(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*
M;7-G:60@(D-O;',Z(@IM<V=S='(@(DMO;&]N;&%R.B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-#8*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS
M9W-T<B`B2V]L;VX@0F'^;/UK;&%R_2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR-C0*;7-G:60@(D-O;6EC<R(*;7-G<W1R(")+;VUI:R(*"B,Z
M(&%D;6EN+V-M9'-H96QL+G!H<#HR-0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R
M(")+;VUU="(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M
M;6%N9"!3:&5L;"(*;7-G<W1R(")+;VUU="!+86)U\'4B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B"FUS
M9W-T<B`B0>?]:VQA;6$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4V-@IM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B3W)T86L@
M063](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B0V]M
M;W)O<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`BWFER:V5T(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T
M<B`B0FEL9VES87EA<FQA<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.3<*(RP@9G5Z>GD*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R(")+
M;_YU;&QA<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y"FUS9VED(")#
M;VYD:71I;VYS(@IM<V=S='(@(DMO_G5L;&%R(@H*(SH@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B
M"FUS9W-T<B`B66%P_6QA;F3]<FUA($9A<FML87+](@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$T,PIM<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN
M8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,U"B,L(&9U>GIY
M"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R
M(")987#];&%N9/UR;6%N_6X@9_QN8V5L;&5N;65S:2!G97)E:VUE:W1E9&ER
M+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(EEA</UL86YD_7(Z)7,B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED
M(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(E!A<F%L;WG]($1O\')U;&$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R(")+;VYG;R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI
M8R!O9B!T:&4B"FUS9W-T<B`B1&5M;VMR871I:R!+;VYG;R!#=6UH=7)I>65T
M:2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y
M.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*
M;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R(")"8?!L86YT_2!B
M8?YA<OUS_7H@;VQD=2XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S
M='(@(D)A\&QA;G3](&)A_F%R_7/]>B!O;&1U.B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U
M<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")!Y_UK(&%N
M86AT87(@<W5N=6-U<W5N82!B8?!L86YT_2!R961D961I;&1I+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES
M97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R(")!Y_UK(&%N86AT87(@
M<W5N=6-U<W5N82!B8?!L86YT_2!R961D961I;&1I+B!396)E8CH@)7,@*"5S
M*2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#0U"FUS9VED(")#
M;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")&5%`@
M<W5N=6-U;F$@8F'P;&%N=/T@8F'^87+]<_UZ(&]L9'4N(@H*(SH@8V]N9FEG
M+VAO;VMS+G!H<"YD:7-T.C$P,30*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU
M,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@
M>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(MUL971I_FEM(&YO:W1A;&%R
M_2!B8?YA<OUY;&$@861R97,@9&5F=&5R:6YI>F4@96ML96YD:2XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(MWG97)I:SH@
M)R5S)R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS
M9W-T<B`B1&5V86TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B
M"FUS9W-T<B`B0V]O:R!!9&%L87+](@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,R"FUS9VED(")#;V]K:64B"FUS9W-T<B`BQV5R97HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C$*
M;7-G:60@(D-O<'DB"FUS9W-T<B`B2V]P>6%L82(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-#8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B0F'P;&%N=/T@8F'^87+]<_UZ
M(&]L9'4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B4V7G:6UI
M($MO<'EA;&$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$W,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#;W-T82!2:6-A(@IM<V=S='(@(DMO<W1A(%)I:V$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(D-O=&4@9"=)=F]I
M<F4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S8*;7-G
M:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("+=
M;&5T:2!01U`@:6QE(/YI9G)E;&5N96UE9&DN(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3`U,PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!S
M:6=N(&UE<W-A9V4N(@IM<V=S='(@(MUL971I(%!'4"!I;&4@:6UZ86QA;F%M
M863]+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,SDS
M"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS
M9W-T<B`BW6QE=&D@4R]-24U%(&EL92!S:69R96QE;F5M961I+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L
M9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`BW6QE=&D@4R]-
M24U%(&EL92!I;7IA;&%N86UA9/TN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R("+=;&5T:?YI
M;2!N;VMT87/](&5K;&5N96UE9&DN("5S(@H*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,3(Q"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB
M"FUS9W-T<B`B3$1!4"!S=6YU8W5S=6YA(&)A\&QA;OUL86UA9/TN(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0U-PHC+"!F=7IZ>0IM<V=I9"`B0V]U
M;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B3$1!4"!S=6YU
M8W5S=6YA(&)A\&QA;OUL86UA9/TN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R(")"
M86MI>64@9&5N971L96YE;65D:2X@)7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-#0Q"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T
M;R!L9&%P('-E<G9E<B(*;7-G<W1R(")334(@<W5N=6-U<W5N82!B8?!L86YT
M_2!B8?YA<OUS_7HN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T
M;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B)R5S)R!S
M=6YU8W5N82!&5%`@>6]L=7EL82!B8?!L86[];&%M863].B`E<R(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S(@IM<V=S='(@(D1A\/UT_6T@;&ES=&5S:2!Y87)A=/UL
M86UA9/TN("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3$R-0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N(@IM<V=S
M='(@(E!'4"!V97)I<VEN:6X@_FEF<F5S:2#G]GK\;&5M961I+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3(R"FUS9VED(")#;W5L
M9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T<B`B4R]-24U%('9E
M<FES:6YI;B#^:69R97-I(.?V>OQL96UE9&DN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R
M("+=;&5T:?YI;2!N;VMT87/]('-I;&EN96UE9&DN("5S(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,B"FUS9W-T<B`B1&'P_73];2!L:7-T97-I('-I;&EN96UE9&DN
M("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")!>6%R(&?\;F-E;&QE;64@
M8F5T:?!I("<E<R<@<VEL:6YE;65D:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.CDU,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I
M96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(D%L_6/];OUN(&5L96MT
M<F]N:6L@<&]S=&$@861R97-I(&)E;&ER;&5N96UE9&DN(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G:60@
M(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S
M='(@(D%D<F5S(&1E9G1E<FD@=&%M86UE;B!G971I<FEL96UE9&DN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*
M;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@
M;&ES="XB"FUS9W-T<B`B1&'P_73];2!L:7-T97-I('1A;6%M96X@9V5T:7)I
M;&5M961I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L
M971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R(")$8?#]
M=/UM(&QI<W1E;&5R:6YI;B!L:7-T97-I('1A;6%M96X@9V5T:7)L96UE9&DN
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@
M7"(E<UPB+B(*;7-G<W1R(")3=')A=&5J:2`G)7,G('G\:VQE;F5M961I+B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP
M.C,P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD
M:7(@7"(E<UPB+B(*;7-G<W1R(")M:V1I<B`G)7,G(&)A_F%R_7/]>B!O;&1U
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I
M9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E
M<G9E<BXB"FUS9W-T<B`B06YA:'1A<B!S=6YU8W5S=6YD86X@8>?]:R!A;F%H
M=&%R(&5D:6YI;&5M961I+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<
M(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B)R5S)R!Y87K];&UA:R!IYVEN(&'G
M_6QA;6%D_2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@)7,N(@IM<V=S='(@(B5S(&'G_6QA;6%D_2XB"@HC.B!F<F%M97=O
M<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0Q.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO
M9'5L92`E<R(*;7-G<W1R(")-86EN=&5N86YC95]487-K(&)I<FEM:2`E<R!A
MY_UL86UA9/TN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E
M<UPB+B(*;7-G<W1R("(G)7,G(&1I>FEN:2!AY_UL86UA9/TN(@H*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C0W.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-CDY"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5A
M8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("),1$%0('-U;G5C=7-U(&%R
M86YA;6%D_2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS
M9W-T<B`B)7,@;VMU;F%M863]+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W
M;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H
M92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H
M97(@:&5L<"XB"FUS9W-T<B`B(@HBW7-T96YE;B!K=6QL86YC_2!IYVEN('!A
M<F]L82!S_6;]<FQA;F%M863]+B!"87K]('EA9&$@=/QM(&%Y<OUN=/UL87(@
M9&_P<G4@(@HB9&7P:6PN(%EE;FED96X@9&5N97EI;B!Y861A(&1A:&$@9F%Z
M;&$@>6%R9/UM(&GG:6X@<VES=&5M('GV;F5T:6YI>FQE("(*(F?V<OS^_&XN
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.0IM<V=I9"`B
M0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R(")!0TP@97)I_FEL96UE
M9&DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`B061R97,@9&5F=&5R:6YE
M(&5R:?YI;&5M961I+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`B1&'P_73];2!L:7-T97-I;F4@97)I_FEL96UE9&DN("5S(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U
M=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B1&'P_73];2!L:7-T96QE<FEN92!E
M<FG^:6QE;65D:2X@)7,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C(R,PIM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S
M(&-A<&%B:6QI=&EE<R(*;7-G<W1R(")3=6YU8W5N=6X@>65T96YE:VQE<FEN
M92!E<FG^:6QE;65D:2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T
M"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(EEA</UL86YD_7)M82!G97)I(&3V;F3\<OQL96UE9&DN+B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HY-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B<FUD:7(@)7,@YV%L
M_?YT_7+];&%M863]+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(B5S('EA</UL86YD_7)M82!K87ED961I;&5M
M961I+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K
M=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R(")9961E:R!B:7(@>6%P_6QA;F3]
M<FUA(&MA>61E9&EL96UE9&DN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C
M:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B665D96L@8FER('EA</UL
M86YD_7)M82!K87ED961I;&5M961I.B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.CDU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*
M;7-G<W1R(")!>6%R(&?\;F-E;&QE;64@8F5T:?!I(&MA>61E9&EL96UE9&DZ
M("<E<R<N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I
M9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B665D96L@>6%P_6QA;F3]<FUA
M(&1O<WEA<_T@)7,@:V%Y9&5D:6QE;65D:2XB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO
M="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET
M:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D
M92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@
M=&\@)7,N(@IM<V=S='(@(B(*(EEA</UL86YD_7)M82!D;W-Y87/]("5S(&MA
M>61E9&EL96UE9&DN($)U(&1U<G5M9&$L(&MO9'4@=&5K<F%R("5S(&GG:6YE
M("(*(FMA>61E=&UE:R!Y861A('1A:VEP(&5D96X@:V]D=2!E;"!I;&4@)7,@
M:>=I;F4@:V]P>6%L86UA:RP@<V7G96YE:VQE<FEN:2`B"B)K=6QL86YA8FEL
M:7)S:6YI>BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T
M,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM
M<V=S='(@(DQ$05`@<W5N=6-U<W4@87)A;F%M863]+B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HX-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(D)A\"#G]GK\;&5M961I.B`G
M)7,G+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A
M=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`BW6QE=&G^:6T@;F]K=&%S_2!G_&YC
M96QL96YE;65D:2X@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")$
M8?#]=/UM(&QI<W1E<VD@9_QN8V5L;&5N96UE9&DN("5S(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E
M<R(*;7-G<W1R("(G)7,G(&GG:6X@>6%P_6QA;F3]<FUA('EA>OUL86UA9/TZ
M("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-@IM<V=I9"`B0V]U
M;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE
M('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B(@HB36]Z:6QL82!K96YA<B#G
M=6)U\'4@8G5L=6YA;6%D_2X@2V5N87(@YW5B=?!U;G5N(&'G_6L@;VQD=?!U
M;F1A;B!E;6EN(&]L=6XN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,34T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG
M:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`B)R5S)R!D
M:7II;FD@:>=I;B`G)7,G(&MU;&QA;OUC_7/]('1A:VEP(&5D96X@:&%K;&%R
M_2!V97)E;65D:3H@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B4V%Y_6QM_?X@;65T
M:6XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0IM
M<V=I9"`B0V]U;G1R>2(*;7-G<W1R("+<;&ME(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(W,PIM<V=I9"`B0V]U<G-E<R(*;7-G<W1R(")$97)S
M;&5R(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B66%R870B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B0F'P;&%N
M=/T@>6%R870B"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N
M:6YC.CDT"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(EEE;FD@
M66%R870B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(D%L="!D
M:7II;B!Y87)A="(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(EEA<F%T
M_6/](-UZ:6YL97)I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(S
M,`IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(DMR961I(&MA
M<G0@;G5M87)A<_TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G
M<W1R(")(_7)V871I<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS
M9W-T<B`B2_QB82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@HC+"!F=7IZ
M>0IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R("+>=2!!;F1A:VD@
M179R92(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HT.`HC+"!F=7IZ>0IM<V=I
M9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R(")987)A=/UC_2#=>FEN;&5R
M:2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H
M<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(MYU($%N9&%K:2!:
M86UA;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B
MWG4@86YD86MI(%523"(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS,PHC+"!F
M=7IZ>0IM<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R("+>=2!!;F1A:VD@
M179R92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E
M;G0@5V5A=&AE<B(*;7-G<W1R("+>=2!!;F1A:VD@2&%V82!$=7)U;74B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<U"FUS9VED(")#=7)R
M96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@(MYU($%N9&%K:2#>87)T;&%R.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*
M;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B6?QR_')L_&MT96MI('-I
M=&EL(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@
M=&\@)7,N(@IM<V=S='(@(B5S(&4@9VER:?YT92#G86S]_F%C86L@9_9R979L
M97)I(&MI_FES96QL9?YT:7)I;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S
M='(@(DME<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`BWF7G:6QI
M(&]L86YL87+](&ME<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G
M<W1R(")+_6)R_7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I
M9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B2VER:6P@*$M/23@M4BDB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL:6,@
M*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B2VER:6P@*%=I;F1O=W,M,3(U,2DB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0WER:6QL:6,O
M56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(DMI<FEL+U5K<F%Y;F$@*$M/
M23@M52DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G
M<W1R("+'96L@0W5M:'5R:7EE=&DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#4Q('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P
M"FUS9VED(")$1"(*;7-G<W1R(")'1R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R.#$*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H
M<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N
M+G!H<"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA
M:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B1_QN;/QK
M(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"
M<F]W<V5R(@IM<V=S='(@(E9E<FD@0?!A8_T@5&%R87G]8_US_2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-SD*;7-G:60@(D1A=&%B87-E($QO
M;VMU<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.3D*
M;7-G:60@(D1A=&4B"FUS9W-T<B`B5&%R:6@B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*
M;7-G<W1R(")'96QI_B!487)I:&DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#`W"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R(")487)I
M:"!39>=I;6DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDR
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,C(*;7-G:60@(D1A>2(*
M;7-G<W1R(")'_&XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM
M<V=S='(@(DM?;VQO;G4@4VEL(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(D%R
M86S]:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R
M(")/;F1A;/UK('-A>?UL87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS
M9W-T<B`B1VER:6YT:7EI($%Z86QT(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*;7-G:60@(D1E9F%U
M;'0B"FUS9W-T<B`BUFX@=&%N_6UL_2(*"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O;&]R
M(@IM<V=S='(@(M9N(%1A;OUM;/T@4F5N:R(*"B,Z(&9R86UE=V]R:R])9&5N
M=&ET>2])9&5N=&ET>2YP:'`Z.3$*;7-G:60@(D1E9F%U;'0@261E;G1I='DB
M"FUS9W-T<B`BUFX@5&%N_6UL_2!+:6UL:6LB"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS
M9W-T<B`BUFX@=&%N_6UL_2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B5&%N_6UL87(B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,S(V"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,`HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC
M.C$P('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$
M96QE=&4B"FUS9W-T<B`B4VEL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"B,L(&9U>GIY"FUS9VED(")$
M96QE=&4@0V5L;"(*;7-G<W1R(")(_&-R92!3:6PB"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L971E
M($=R;W5P(@IM<V=S='(@(D=R=7`@4VEL(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C0Y"B,L(&9U>GIY"FUS9VED(")$96QE=&4@3&]G(@IM
M<V=S='(@(E-A=/UR_2!S:6PB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q"FUS
M9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R("+=>FEN(%-I;"(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED
M(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(MUL971I;&5R
M:2!S:6P@=F4@=&5M:7IL92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM
M<V=S='(@(DC\8W)E(%-I;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB
M"FUS9W-T<B`B2V]L;VX@4VEL(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B
M"FUS9W-T<B`B5F%R;VQA;B#V=&5K:2!T87-L8?#]('-I;"(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(Q"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G
M<W1R("(G)7,G(&GG:6X@:7II;FQE<FD@<VEL(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B
M+7!E<FUI<W-I;VYS/R(*;7-G<W1R("(G)7,G(&GG:6X@:7II;FQE<B!V92!A
M;'0@:7II;FQE<B!S:6QI;G-I;B!M:3\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@
M<F]W(@IM<V=S='(@(E-A=/UR_2!S:6PB"@HC.B!T96UP;&%T97,O<')E9G,O
M9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@
M:61E;G1I='DB"FUS9W-T<B`B4V7G:6QM:?X@:VEM;&GP:2!S:6PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B
MWG4@86YD86MI(&MO;&]N=2!S:6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T
M:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`BWG4@86YD86MI('-A=/UR_2!S:6PB
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<
M(B5S7"(N(@IM<V=S='(@(DMU<G5L=6T@9_QN8V5L;&5M92!B971I\&D@)R5S
M)R!S:6QI;F1I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*;7-G:60@(D1E;&EV97)Y('1I
M;64B"FUS9W-T<B`B5&5S;&EM('IA;6%N_2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@
M(D1E;FUA<FLB"FUS9W-T<B`B1&%N:6UA<FMA(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B
M;&5M(@IM<V=S='(@(E-O<G5N=2!486[];6QA>?UN(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S
M='(@(D'G_6ML86UA(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M.34*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB
M"FUS9W-T<B`B07ER_6YT_6QA<B`H07EN_2!Z86UA;F1A($AO<F1E)W5N(&?\
M;FS\:R!D;W-Y87/];OUN(&GG:6YD92DZ(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ.3D*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(D%Y<OUN=/UL87(@
M>?9N971I8VD@:>=I;B!G_&YL_&L@;VQA<F%K(&MA>61E9&EL9&DN(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q.0IM<V=I9"`B1&5V96QO<&UE
M;G0B"FUS9W-T<B`B1V5L:?YI;2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C$W"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B3F5M($UI:W1A<OTB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I9"`B1&5W(%!O:6YT(&9O
M<B!L87-T(&AO=7(Z("(*;7-G<W1R(")3;VX@<V%A='1E:VD@;F5M(&UI:W1A
M<OTZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C<*;7-G
M:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(DYE;2!M:6MT87+].B`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED
M(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R(")3;VQD86X@<V'P
M82!Y]FYL_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S
M='(@(E-A\&1A;B!S;VQA('GV;FS\(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R(")$:7II;B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C8*;7-G:60@(D1I<W!L87D@,C0M:&]U
M<B!T:6UE<S\B"FUS9W-T<B`B,C0@<V%A=&QI:R!Z86UA;B!M_2!G]G-T97)I
M;'-I;C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D1I
M<W!L87D@3W!T:6]N<R(*;7-G<W1R(")']G+\;G3\;&5M92!39>=E;F5K;&5R
M:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY-@HC+"!F=7IZ
M>0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R(")(
M879A('1A:&UI;FEN:2!G]G+\;G3\;&4@*%1!1BDB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C@U"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM
M<V=S='(@(DAA=F$@=&%H;6EN:6YI(&?V<OQN=/QL92`H5$%&*2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3<*;7-G:60@(D1I<W!L87D@9F]R
M;6%T(@IM<V=S='(@(D?V<OQN=/QL96UE($)IYVEM:2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O341.+G!H<#HQ.3`*;7-G:60@(D1I<W!O<VET:6]N($YO
M=&EF:6-A=&EO;B(*;7-G<W1R(")$_'IE;B!":6QD:7)I;6DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R(")#:6)U=&DB"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,@IM<V=I9"`B1&\@;F]T(&1E
M;&5T92(*;7-G<W1R(")3:6QM97EI;B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN
M=&5N86YC92YP:'`B"FUS9W-T<B`B;6%I;G1E;F%N8V4N<&AP(&1O<WEA<_UN
M82!D;_!R=61A;B!E<FG^;65Y:6XN(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V
M:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G
M:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE
M<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`BW6QK('-A=/UR
M(&%L86X@861L87+];OT@:>=E<FEY;W(@;74_($5V970@:7-E(&)U(&MU='5Y
M=2!S9>=I;CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R
M(")$;VUI;FEK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B
M;&EC(@IM<V=S='(@(D1O;6EN:6L@0W5M:'5R:7EE=&DB"@HC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C
M8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C@T-`IM<V=I9"`B1&]W;FQO860B"FUS9W-T
M<B`BW6YD:7(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HX-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T
M<B`B)7,@W6YD:7(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS
M9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@
M<V-R:7!T+B(*;7-G<W1R(")/;'7^='5R=6QA;B!Y87#];&%N9/UR;6%Y_2!0
M2%`@8F5T:?!I(&]L87)A:R!I;F1I<BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3`W"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R(")!
M_F'P_2!AY_UL_7(@;&ES=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(MUL8>=L87(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D4M36%I;"(*;7-G
M<W1R(")%+5!O<W1A(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R
M:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R
M:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS
M9W-T<B`B15)2(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R
M(")%:W9A=&]R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R"B,Z('1E;7!L
M871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G:60@(D5D:70B"FUS9W-T<B`B
M1/QZ96YL92(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`@
M=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="!";&]C
M:R(*;7-G<W1R(")";&]K($3\>F5N;&4B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R-@IM<V=I9"`B161I="!'<F]U<"(*
M;7-G<W1R(")'<G5P($3\>F5N;&4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`P
M"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`BW7II;B!$_'IE;FQE
M(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I
M="!097)M:7-S:6]N<R(*;7-G<W1R("+=>FEN;&5R:2!$_'IE;FQE(@H*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(E<R#=YVEN
M(-UZ:6YL97)I($3\>F5N;&4B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN
M8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R(")39>=E;F5K
M;&5R:2!D_'IE;FQE.B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,S8W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI
M<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B)7,@:>=I;B!I>FEN;&5R:2!D
M_'IE;FQE(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G
M<W1R("(E<R!IYVEN(&EZ:6YL97)I(&3\>F5N;&4B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R(")%\&ET
M:6TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G<W1R(")-_7/]<B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"B,L('!H<"UF;W)M
M870*;7-G:60@(D5I=&AE<B!E;F%B;&4@:70@=&AE;CH@)7,L(&]R('5S92!T
M:&4@8F%S:6,@2%1-3"!V97)S:6]N.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R(")%;"!386QV861O
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R("+6\&4N+BXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M.0IM<V=I9"`B16TB"FUS9W-T<B`B16TB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X-CD*;7-G:60@(D5M86EL(@IM<V=S='(@(D5L96MT<F]N:6L@4&]S
M=&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-2!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C@*;7-G:60@(D5M86EL($%D9')E
M<W,B"FUS9W-T<B`B16QE:W1R;VYI:R!0;W-T82!!9')E<VDB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38S"FUS9VED(")%;6%I;"!A9&1R97-S
M97,@;75S="!M871C:"XB"FUS9W-T<B`B16QE:W1R;VYI:R!P;W-T82!A<W)E
M<VQE<FD@9?YL9?YM96QI+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Y.#D*;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@
M(D]N87EL_2!E;&5K=')O;FEK('!O<W1A(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--
M4R!'871E=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR.3@*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R
M(")$=7EG=2!S:6UG97)L97)I(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED(")%;7!T>2!M97-S86=E
M+B(*;7-G<W1R(")";_X@:6QE=&DN(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT
M+B(*;7-G<W1R(")";_X@<V]N=><N(@H*(SH@9G)A;65W;W)K+U-13"]344PO
M2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM
M<V=S='(@(D)O_B!A<F%M82!T97)I;6QE<FDB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-30S"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E
M<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B"B)&
M;W1O\')A9B!'86QE<FES:6YD96X@;65T:6YL97)I;B!IYV5R:7-I;F4@9_9R
M_&YT_"!E:VQE;64@971K:6YL9?YT:7)I;'-I;B`B"B)M:3\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3$X"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI
M8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R(")38?`@=/UK(&GG97)I:R!M96[\
M<_P@971K:6YL9?YT:7)I;'-I;B!M:3\B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3$*;7-G
M:60@(D5N9"!Y96%R(@IM<V=S='(@(D)I=&G^('G];/TB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA
M<F=E($5D:71O<B(*;7-G<W1R(")$_'IE;FQE>6EC:7EI($=E;FG^;&5T(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,0IM<V=I9"`B(@HB16YT97(@
M82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I
M9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W
M:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*(E!A
M<F]L86[]>OT@<_UF_7)L86UA:R!I<W1E9&GP:6YI>F1E('-O<G5L;6%K(/QZ
M97)E(&)I<B!G_'9E;FQI:R!S;W)U<W4@(@HB9VER:6XL(-9R+B`G179C:6P@
M:&%Y=F%N_6[]>OUN(&%D_2!N961I<C\G.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B
M16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(D?V<OQN=/P@861R
M97-I;FD@8G5R87EA(&=I<FEN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C@Y,0IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@
M8F5L;W<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I
M86P@1W5I;F5A(@IM<V=S='(@(D5K=F%T;W(@1VEN97-I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,0IM<V=I9"`B17)I=')E82(*;7-G<W1R(")%<FET<F4B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP.C(W"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-2!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-34*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C@R"FUS9VED(")%
M<G)O<B(*;7-G<W1R(")(871A(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E
M;7!L871E+G!H<#HT-C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R
M<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R(")986[]=/T@9_9N9&5R
M;65D92!H871A.B`E<RXB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC
M(&%N8VAO<CH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z.#,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R(")986[]=/T@9_9N9&5R
M;65D92!H871A.B`E<RXB"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA
M=&4N<&AP.C0V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R(")986[]=/T@9_9N9&5R;65D
M92!H871A.B`E<RXB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M-S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG
M('!A<W-W;W)D.B`E<R(*;7-G<W1R(")986[]=/T@9_9N9&5R;65D92!H871A
M.B`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB
M"FUS9W-T<B`B16QE=')O;FEK('!O<W1A(&3V;F1E<FUE9&4@:&%T82XB"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B)R5S)R!Y87IA
M<FME;B!H871A+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T
M<B`B17-T;VYY82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S
M='(@(D5T:7EO<'EA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS
M9VED(")%=&AN:6,B"FUS9W-T<B`B171N:6LB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R(")!=G)U
M<&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"FUS9VED(")%=F5R
M>2`Q-2!M:6YU=&5S(@IM<V=S='(@(DAE<B`Q-2!D86MI:V$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S@Y"FUS9VED(")%=F5R>2`R(&UI;G5T97,B
M"FUS9W-T<B`B2&5R(#(@9&%K:6MA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,S-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@W"FUS9VED(")%=F5R
M>2`S,"!S96-O;F1S(@IM<V=S='(@(DAE<B`S,"!S86YI>64B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S,X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.3`*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")(97(@-2!D86MI
M:V$B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R(")(97(@1VER:?YT92(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`*;7-G:60@(D5V97)Y(&AA
M;&8@:&]U<B(*;7-G<W1R(")(97(@>6%R_6T@<V%A="(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.`IM
M<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(DAE<B!D86MI:V$B"@HC.B!T
M96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V
M86QU97,Z(@IM<V=S='(@(M9R;F5K(&1E\&5R;&5R.B(*"B,Z(&%D;6EN+W!H
M<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L
M<VAE;&PN<&AP.C$R-PIM<V=I9"`B17AE8W5T92(*;7-G<W1R("+'86S]_G3]
M<B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0W-0IM
M<V=I9"`B17AP86YD(@IM<V=S='(@(D=E;FG^;&5T(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]S:61E8F%R+FEN8SHS,@IM<V=I9"`B17AP86YD(%-I9&5B87(B
M"FUS9W-T<B`B2V5N87(@QW5B=?!U;G4@1V5N:?YL970B"@HC.B!F<F%M97=O
M<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G
M*2<B"FUS9W-T<B`B)RDG($)E:VQE;FEY;W(B"@HC.B!F<F%M97=O<FLO4U%,
M+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O
M<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(E-A9&4@:V5L:6UE
M('9E>6$@86S];G3](&%R86UA('1E<FEM:2!B96ML96YI>6]R(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T
M:6]N($1A=&4B"FUS9W-T<B`B1V7G97)L:6QI:R!3;VX@5&%R:6AI(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S8*;7-G:60@(D5X
M<&]N96YT(@IM<V=S='(@(MQS="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM
M<V=S='(@(M9N($%L86X@4F5N9VDB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(D%Y
M87)L87(@:>=I;B!&5%`@>?QK;&5M97-I(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+W-Q;"YP:'`Z,C$V"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P
M<F5F97)E;F-E<RXB"FUS9W-T<B`B5&5R8VEH;&5R:6X@9V5T:6QM97-I(&)A
M_F%R_7/]>BXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I
M;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DQ$05`@
M<W5N=6-U<W5N82!B8?!L86YT_2!B8?YA<OUS_7HN(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S;6(N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C
M="!T;R!334(@<V5R=F5R+B(*;7-G<W1R(")334(@<W5N=6-U<W5N82!B8?!L
M86YT_2!B8?YA<OUS_7HN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HV.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O
M;2!<(B5S7"(N(@IM<V=S='(@(EPB)7-<(B!K;VYU;75N9&%N(&MO<'EA;&%M
M82!B8?YA<OUS_7HN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV
M.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E
M<UPB+B(*;7-G<W1R(")<(B5S7"(@:V]N=6UU;F$@:V]P>6%L86UA(&)A_F%R
M_7/]>BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"FUS
M9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM
M<V=S='(@(EEE;FD@4T%33"!B8?!L86YT_7/](&]L=?YT=7)U;&%M863]+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DW(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-S(T"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB(&MO;G5M=6YA
M('1A_OUM82!B8?YA<OUS_7HN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HT-C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T
M;R!R971R:65V93H@)7,B"FUS9W-T<B`B7"(E<UPB(&MO;G5M=6YA('1A_OUM
M82!B8?YA<OUS_7HN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B57EG=6X@2&%V82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S
M*2(*;7-G<W1R(")&86QK;&%N9"!!9&%L87+]("A-86QV:6YA*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B1F%R;V4@061A
M;&%R_2(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR,S@*;7-G:60@(D9A
M=&%L($5R<F]R.B(*;7-G<W1R(")/;G5L;6%Z($AA=&$Z(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X
M(@IM<V=S='(@(D9A:W,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S0Y"B,L(&9U>GIY"FUS9VED(")&87AE<R(*;7-G<W1R(")&86MS(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@
M(D9E8G)U87)Y(@IM<V=S='(@(MYU8F%T(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,C`*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B2&ES<V5D:6QI
M>6]R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,0IM<V=I
M9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(DAI<W-E9&EL:7EO<CH@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@
M(D9E=R!3:&]W97)S(@IM<V=S='(@(DAA9FEF(%-A\&%N86LB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W
M(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")(869I9B!+87(@4V'P86YA\/TB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30T"FUS9VED(")&:65L9"!M
M871R:7@B"FUS9W-T<B`B06QA;B!M871R:7-I(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S,S-`IM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S.`IM<V=I9"`B
M1FEG;&5T(&9O;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ
M:2(*;7-G<W1R(")&:6II(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")&:6QE(@IM<V=S='(@(F1O<WEA(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R(")$;W-Y82!387G]
M<_TZ("5S(&1O<WEA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS
M9W-T<B`B1&]S>6$@4V%Y_7/].B`E<R!D;W-Y82(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,#<*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R
M(")$;W-Y82!9]FYE=&EC:7-I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<P"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#4*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R(")$;W-Y82!!9/TB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3DU"FUS9VED(")&:6QE('-E
M;&5C=&EO;B(*;7-G<W1R(")$;W-Y82!S9>=I;6DB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#@V"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R
M(")$;W-Y82!Y_&ML96UE(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.#4Y"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB
M"FUS9W-T<B`B1&]S>6$@>?QK;&5M92!D97-T96ML96YM:7EO<BXB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G:60@(D9I;'1E<G,B"FUS
M9W-T<B`B4_QZ9V7G;&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*
M;7-G<W1R(")&:6YL86YD:7EA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V
M-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R("+=;&L@66%R_2(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G
M:60@(D9I<G-T(%%U87)T97(B"FUS9W-T<B`BW6QK(,=E>7)E:R(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-38*;7-G:60@
M(D9I>"!R871I;R(*;7-G<W1R(")/<F%N_2!S86)I=&QE(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,0IM<V=I9"`B1FQI
M<"(*;7-G<W1R("+'979I<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@
M(DMA>6%N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R(")3:7,B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO
M="!E>&ES="(*;7-G<W1R("(E<R!D:7II;FD@>6]K(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#
M;VQO<B(*;7-G<W1R(")987K](%)E;F=I(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(EEE;65K(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM
M86=E<R(*;7-G<W1R(")']G+\;G3\;&5R:2!D97-T96ML96UE>65N('1A<F%Y
M_6/];&%R(&GG:6XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S-`IM<V=I
M9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B5&%H;6EN("A4048I(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<Y"FUS9VED("(B"B)&;W)E
M8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E
M='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H
M97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*
M(E1A:&UI;B!'_&YL97)I("A.;W0Z($=E<FD@9/9N_&QE8V5K;&5R(&AE;2!G
M_&X@:&5M(&=E8V4@;VQA<F%K(&3V;OQL96-E:SL@*2(*(F+\>?QK(&)I<B!S
M87G](&=E;FG^(&)I<B#V8F5K;&4@<V]N=>=L86YA8V%K=/UR*2(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U
M<B!P87-S=V]R9#\B"FUS9W-T<B`B4&%R;VQA;OUZ_2!M_2!U;G1T=6YU>C\B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8R"FUS9VED(")&;W)M
M<R(*;7-G<W1R(")&;W)M;&%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(D1E>6G^(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T
M<B`B1&5Y:?X@=/QR_"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM
M<V=I9"`B1F]R='5N97,B"FUS9W-T<B`B1&5Y:?YL97(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B
M1&5Y:?YL97(@,B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-3,*
M;7-G:60@(D9O<G5M<R(*;7-G<W1R(")&;W)U;6QA<B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ,#D*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@
M(EGV;FQE;F1I<FUE;&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B0W4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S
M"FUS9VED(")&<F%M97,B"FUS9W-T<B`BQV5RYV5V96QE<B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S,*;7-G:60@(D9R86YC92(*;7-G<W1R(")&<F%N<V$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P
M;VQI=&%N(@IM<V=S='(@(D9R86YS82P@365R=&]P;VQI=&%N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R(")&<F%N<_UZ($=U
M>6%N87/](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B
M"FUS9W-T<B`B1G)A;G/]>B!0;VQI;F5Z>6%S_2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM
M<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(D9R
M86YS_7H@1_QN97D@0O9L9V5S:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`B2VEM
M9&5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T."!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8P"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT,#8*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R(")+
M:6UD96XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`IM
M<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R(")486T@0F5T:6UL96UE
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H
M<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R(")$;VQU;F%Y(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z-C`*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R(")!Y_UK
M($%D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B1V%B;VXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M
M(@IM<V=S='(@(D?V<OQN=/QL97)I;B!A;/UN86-A\/T@9V%L97)I(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R(")'86QE<FDZ(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(D=A;6)I>6$B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@
M(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B)7,@66%P_6QA
M;F3]<FUA<_UN_2!/;'7^='5R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@
M(D]L=?YT=7)U;&%N($MO9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B
M"FUS9W-T<B`B1_QR8VES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N
M>2(*;7-G<W1R(")!;&UA;GEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B
M"FUS9W-T<B`B1V%N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*
M;7-G<W1R(")#96)E;&ET87+]:R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3<U"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(E9E
M<FEL96X@060B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,@IM<V=I
M9"`B1V\B"FUS9W-T<B`B1VET(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B1V]E9&5L(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,C@*(RP@9G5Z>GD*
M;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(D=O;V=L92!!<F%M82(*"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R
M8V@B"FUS9W-T<B`B1V]O9VQE($%R86UA(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-PIM<V=I9"`B1W)A>7-C86QE(@IM
M<V=S='(@(E-I>6%H($)E>6%Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C
M92(*;7-G<W1R(")9=6YA;FES=&%N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#4*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R(")9=6YA
M;F-A("A)4T\M.#@U.2TW*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N
M9"(*;7-G<W1R(")'<O9N;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=R96YA
M9&$B"FUS9W-T<B`B1W)E;F%D82(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y
M"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")'<G5P(%GV
M;F5T:6UI(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N
M86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R(")'<G5P(&ES:6UL97)I
M(&1O;'4@;VQM86S]9/UR(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C,P-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?
M;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H
M92!S97)V97(@<V%I9#H@(@IM<V=S='(@(D%U=&A?:6UA<#H@)7,@:W5L;&%N
M_6/]<_T@96ML96YE;65D:2X@4W5N=6-U.B`B"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C0Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@
M56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R(")!=71H7VQD87`Z
M("5S(&MU;&QA;OUC_7/](&?\;F-E;&QE;F5M961I(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S."!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,S<Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'
M<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@
M(D%U=&A?;&1A<#H@)7,@:W5L;&%N_6/]<_T@9_QN8V5L;&5N96UE9&DB"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W
M-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(D=R=7!L87(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V
M"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(D=U861A;'5P(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B1W5A;2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W
M"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B1W5A=&5M86QA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS
M9W-T<B`B1W5E<FYS97DB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'
M=65S="!097)M:7-S:6]N<R(*;7-G<W1R(")+;VYU:R#=>FEN;&5R:2(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S`*;7-G:60@(D=U97-T8F]O
M:R(*;7-G<W1R(")+;VYU:R!$969T97)I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDY"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B
M1W5I;F5A(@IM<V=S='(@(D=I;F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U
M:6YE82U":7-S874B"FUS9W-T<B`B1W5I;F4@0FES<V%U(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B1W5Y86YA(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@(DA4
M34PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O
M(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B2%1-3$%R
M96$@<V%T_7)D86MI('-O;B!H_&-R97EI('-I;&UE>6D@<F5D9&5D:7EO<BXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!
M<F5A(.=I>F5L9V5D96MI('-O;B!K;VQO;G4@<VEL;65Y:2!R961D961I>6]R
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R
M96$@YVEZ96QG961E:VD@<V]N('-A=/UR_2!S:6QM97EI(')E9&1E9&EY;W(N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@
M(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")(5%10
M($MI;6QI:R!$96YE=&EM:2!B=6QA;F%M863]+B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM
M<V=I9"`B2&%I=&DB"FUS9W-T<B`B2&%I=&DB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM
M<V=S='(@(DAA<V@@06QG;W)I=&UA<_TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B2&%Z92(*;7-G<W1R(")(
M869I9B!3:7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,3D@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,@IM<V=I9"`B2&5A9&5R(@IM<V=S
M='(@(D)A_FS]:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L
M97-E="YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B
M0F'^;/UK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD
M($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B2&5A<F0@061A<_T@=F4@36-$
M;VYA;&0@061A;&%R_2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(S"B,L(&9U>GIY"FUS9VED(")(96%V>2!4+5-T;W)M(@IM
M<V=S='(@(D?V:R!G_'+\;'3\;/P@9OUR=/UN82(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@V"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS
M9W-T<B`BW6)R86YI8V4@*$E33RTX.#4Y+3@M22DB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(
M96EG:'0B"FUS9W-T<B`B6?QK<V5K;&EK(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TAE;'`N<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L
M<"YP:'`Z,3@V"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L
M871E<R]H96QP+VEN9&5X+FEN8SHS"FUS9VED(")(96QP(@IM<V=S='(@(EEA
M<F3];2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(D3\>F5N
M;&5Y:6-I(&MU;&QA<F%K('EA<F3];2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S-S$*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")987)D_6UC_2(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*
M;7-G<W1R(")987+]:_QR92(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N
M:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS9VED(")(
M97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(D1O
M<WEA;OUN(&)A_FQA;F?]8_TZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")(:6=H(@IM<V=S='(@(EG\:W-E
M:R(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T97,O
M861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0IM<V=I9"`B2&]?;64B"FUS9W-T
M<B`B7T%N87-A>69A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@
M*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B5F%T:6MA;B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34S-0IM<V=I9"`B2&]M92(*;7-G
M<W1R(")!;F%S87EF82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D5V
M($%D<F5S:2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`HC+"!F=7IZ
M>0IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B1&EZ:6XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED
M(")(;VUE(%!H;VYE(@IM<V=S='(@(D5V(%1E;&5F;VYU(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R(")(;VYD=7)A<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(DAO;F<@2V]N9R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-0IM<V=I9"`B2&]R9&4B
M"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI
M9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S
M='(@(B(*(DAO<F1E+TMO;&%B.B!"=2!M97-A:B!IYVEN9&4@9V7G97)S:7H@
M)7,@6$U,('9E<FES:2!I;&4@:V%R_OUL8?[];&3].B`E<R(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C
M="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@)7,@;F5S;F5S:2!I;&4@:6QG
M:6QI(&)I<B!I;&5T:2!B=6QU;F%M863](@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B
M"FUS9W-T<B`B2&]R9&4O2V]L86(Z("5S('3\<OQN9&4@:&GG(&)I<B!N97-N
M92`E<R!M97-A:OT@:>=I;F1E('EO:RXB"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$R-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@)7,@7"(E<UPB(&)A_F%R_2!I;&4@<VEL:6YD:2(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+
M;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O
M;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B"B)(;W)D92]+;VQA8CH@
M0OQT_&YL96UE(&UO=&]R=2`G9&]M>&UL)R!02%`@=7IA;G3]<_UN82!I:'1I
M>6'G(&1U>6UA:W1A9/UR(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z("5S(&YE<VYE<VD@:>=I;B!Y96YI(%A-3"!A\&%C
M_2!O;'7^='5R=6QA;?UY;W(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C$R-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@4VEL:6YE;65D:2`E<R!<(B5S7"(Z("5S(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HT-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@
M<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B`E<R!T_'+\
M;F1E:VD@:_US_6T@:>=I;B!-24U%($E$(&)U;'5N86UA9/TB"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q.3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S
M7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!%_FQE;F5M961I("5S(%PB
M)7-<(CH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$S,S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S
M>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(E!A>6QA_OUM;&%R(&7^
M;&5N96UE9&DZ("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS
M-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@
M<VAA<F4@7"(E<UPB(@IM<V=S='(@(D)I;&EN;65Y96X@<&%Y;&'^_6T@7"(E
M<UPB(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(EEA=&%Y(,=I
M>F=I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(EEA=&%Y
M('EA<W3]:VQA;6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R(")9871A
M>3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE
M87-E(')E<&]R="$I(@IM<V=S='(@(D)U<F%Y82!N87/];"!G96QD:6YI>C\@
M*$S\=&9E;B!R87!O<B!E9&EN(2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C
M;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")+8><@
M861E="!K;VQO;G4@8FER;&7^=&ER;65K(&ES=&EY;W)S=6YU>C\B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@
M9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(DMAYR!A;&%N
M("AK;VQO;BD@=F%R/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U
M;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(DMAYR!A9&5T('-A=/UR
M_2!B:7)L9?YT:7)M96L@:7-T:7EO<G-U;G5Z/R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S`*
M;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(DYE;2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-3D*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T
M<B`B3F5M.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@
M(DAU;6]R:7-T<R(*;7-G<W1R(")-:7IA:.?];&%R(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P
M"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(DUA8V%R:7-T86XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0
M(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("))34%0('!O
M<W1A(&MU='5S=2!O;'7^='5R=6QA;6%D_3H@)7,B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G5S+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)S<6PN<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB
M;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("))34%0('!O<W1A(&MU
M='5S=2!S:6QI;F5M961I.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z
M,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C
M<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DE-05`@<&]S=&$@:W5T=7-U
M(&MO=&%S_2!O;'7^='5R=6QA;6%D_3H@)7,B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S$V"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(DE0
M($%D<F5S:2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z
M-S<*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M25`@861R97-I(&UE=F-U="!D9?!I;"X@(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET
M:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B25`@061R97-I(&EZ
M:6X@=F5R:6QE;B!#2412(&)L;_!U(&GG:6YD92!D9?!I;"XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G
M:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B25`@:VEL:71L
M96UE(&EH;&%L:2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R
M92(*;7-G<W1R("+6;E]C97EE(%-A=/UR(%EE<FQE_G1I<B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("+=>FQA;F1A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM<V=I9"`B26-O;G,@3VYL>2(*;7-G
M<W1R(")3861E8V4@4VEM9V5L97(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S
M='(@(B5S(&GG:6X@<VEM9V5L97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S<W"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B365T:6X@
M:6QE(&)I<FQI:W1E('-I;6=E;&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Y,`IM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R(")+:6UL
M:?!I;B!A9/TZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z-3DR"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P
M;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O
M=RXB"FUS9W-T<B`B1?!E<B!D;_!R=2!G]G+\;G3\;&5N96UI>6]R<V$L('EE
M;FD@<&5N8V5R961E(&'G;6%K(&GG:6X@=/UK;&%Y_6X@)7,N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0U-0IM<V=I9"`B(@HB268@>6]U(&1O;B=T
M('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M
M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@
M=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"B)%\&5R($EN=&5R;F5T($5X<&QO
M<F5R(&EL92!S:6UG96QE<FD@9_9R96UI>6]R<V%N_7H@8G4@:W5T=7EU('-E
MYV5R96L@4$Y'("(*(G-A>61A;6S]\/UN_2!K87!A=&UA;OUZ(&=E<F5K:7(N
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W
M,PIM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM
M86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*
M(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*(D?V<OQN
M=/QL97)I(&?V<F5M:7EO<B!F86MA="!B=2!M97-A:OT@9_9R96)I;&ER>6]R
M<V%N_7HL('G\:VQE;65K("(*(FES=&5D:?!I;FEZ(&?V<OQN=/P@=&%R87G]
M8_UN_7H@=&%R86;];F1A;B!G]G-T97)I;&5M96UE:W1E9&ER+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B1_9R_&YT_"#6
M;FEZ;&5M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R(")']G+\
M;G3\(%523"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R
M(")']G+\;G3\(%523#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@
M9V%L;&5R>2(*;7-G<W1R(")397)G:61E;B!G]G+\;G3\(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q
M"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(E-E<F=I9&5N
M(&?V<OQN=/PZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,0IM
M<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(D?V<OQN=/P@>?QK;&5M96LB
M"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM
M<V=S='(@(D?V<OQN=/QL97(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O
M+FEN8SHW('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*
M;7-G<W1R("+=YV5R:2!!:W1A<BP@063];2`E9"(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R
M=&5D(&9I96QD.B`E<R(*;7-G<W1R("+=YV5R:2!A:W1A<OUL86X@86QA;CH@
M)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("))
M;7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(MWG97)I(&%K=&%R_6QA;B!A;&%N
M;&%R.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T
M<B`B4V]N7W)A>6$@4V%T_7(@16ML92(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-0IM<V=I9"`B26YC;W)R96-T(&%C=&EO
M;B!C;V1E(&=I=F5N+B(*;7-G<W1R(")986YL_?X@97EL96T@:V]D=2!G:7)I
M;&1I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,R"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A
M<W-W;W)D+B(*;7-G<W1R(")986YL_?X@:W5L;&%N_6/](&%D_2!V92]V97EA
M('!A<F]L82XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM
M<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R
M97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)986YL
M_?X@:W5L;&%N_6/](&%D_2!V97EA(/9T96MI(&%D<F5S+EEE;FED96X@9&5N
M97EI;B!V97EA(&1A:&$@9F%Z;&$@>6%R9/UM("(*(FGG:6X@>?9N971I8VEN
M:7IL92!G]G+\_OQN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R
M(")':7)I;G1I>6D@07)T=/UR(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("));F1I
M82(*;7-G<W1R(")(:6YD:7-T86XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM
M<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R(")":7)E>7-E;"!+=6QL
M86[]8_UL87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N97-I82(*;7-G
M<W1R(")%;F1O;F5Z>6$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(D)I;&=I(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U-PIM<V=I9"`B26YF;W)M
M871I;VXB"FUS9W-T<B`B0FEL9VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S,P"B,L(&9U>GIY"FUS9VED("));F9O<FUA=&EO;B!N;R!L
M;VYG97(@879A:6QA8FQE+B(*;7-G<W1R(")(:>=B:7(@<V7G96YE:R!M979C
M=70@9&7P:6PN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E
M<B(*;7-G<W1R(")3;VYR87EA($MO7VQO;B!%:VQE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS
M9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`B1_9R_&YT_"!997)L9?YT:7(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P
M"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`BQVEZ96QG92!997)L9?YT
M:7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B5V5B($)A\&QA
M;G3]<_T@665R;&7^=&ER(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M
M;B!"969O<F4B"FUS9W-T<B`BUFYC97EE($MO;&]?;B!%:VQE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V
M"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT
M(&]N92(*;7-G<W1R(")996YI(&MO;&]N=2#^=2!A;F1A:VD@:V]L;VYD86X@
M<V]N<F$@>65R;&7^=&ER(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@
M8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B665N:2!K
M;VQO;G4@_G4@86YD86MI(&MO;&]N9&%N(/9N8V5Y92!Y97)L9?YT:7(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E
M;G0@;VYE(@IM<V=S='(@(EEE;FD@<V%T_7+](/YU(&%N9&%K:2!S873]<F1A
M;B!S;VYR87EA('EE<FQE_G1I<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@
M;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(EEE;FD@
M<V%T_7+](/YU(&%N9&%K:2!S873]<F1A;B#V;F-E>64@>65R;&7^=&ER(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U
M<G)E;G0@;F]D92(*;7-G<W1R(")996YI('!A<F%G<F%F_2#^=2!A;F1A:VD@
M9/SP_&UD96X@<V]N<F%Y82!Y97)L9?YT:7(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN
M<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G
M<W1R(")996YI('!A<F%G<F%F_2#^=2!A;F1A:VD@9/SP_&UD96X@]FYC97EE
M('EE<FQE_G1I<B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED
M("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(M9T96MI('1A
M<VQA:R!Y97)L9?YT:7(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,Y
M"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@
M8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B665N:2!B
M:7(@<&%R86QO>?T@86QA8FEL96-E\&EN:7H@8FER(&5L96MT<F]N:6L@<&]S
M=&$@861R97-I(&=I<FEN.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F
M=&5R(@IM<V=S='(@(DC\8W)E>6D@<V]N<F%S_6YA('EE<FQE_G1I<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3D*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R(")(_&-R97EI
M(/9N8V5S:6YE('EE<FQE_G1I<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU
M;6X@869T97(B"FUS9W-T<B`B2V]L;VYU('-O;G)A<_UN82!Y97)L9?YT:7(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R(")+
M;VQO;G4@]FYC97-I;F4@>65R;&7^=&ER(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S86=E
M<R(*;7-G<W1R(")-97-A:B!G:7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P
M87)A9W)A<&@@869T97(B"FUS9W-T<B`B4&%R86=R86;]('-O;G)A<_UN82!Y
M97)L9?YT:7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F
M;W)E(@IM<V=S='(@(E!A<F%G<F%F_2#V;F-E<VEN92!Y97)L9?YT:7(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(E-A=/UR_2!S
M;VYR87/];F$@>65R;&7^=&ER(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B
M969O<F4B"FUS9W-T<B`B4V%T_7+](/9N8V5S:6YE('EE<FQE_G1I<B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@(DEN<V5R="!T:&4@
M<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS
M9W-T<B`B1_QV96YL:6L@<V]R=7-U;G5N(&-E=F%B_3HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E
M<G0O36]D:69Y($EM86=E(@IM<V=S='(@(D?V<OQN=/QY_"!997)L9?YT:7(O
M1&7P:?YT:7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B
M0F'P;&%N=/T@665R;&7^=&ER+T1E\&G^=&ER(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F
M9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI
M<W0N(@IM<V=S='(@(D1A\/UT_6T@;&ES=&5S:2!G]FYD97)M96L@:>=I;B!Y
M971E<G-I>B!K<F5D:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I
M="XB"FUS9W-T<B`B665T97)S:7H@:W)E9&DB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,#<U"FUS9VED("));G1E9V5R(@IM<V=S='(@(E1A;7-A
M>?TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,S"FUS9VED("))
M;G1E9V5R(&QI<W0B"FUS9W-T<B`B5&%M<V%Y_2!L:7-T97-I(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS
M9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R
M(")'9>=E<G-I>B!51$@N("A+=6QL86[]8_T@5F5R:2!"8?YL_6L@0FEL9VES
M:2DB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ
M-S`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C`Q
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q,`HC
M+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R(")'9>=E
M<G-I>B!U;FEC;V1E('9E<FES:2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R(")'
M9>=E<G-I>B!U>6=U;&%M82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@
M240N(@IM<V=S='(@(D=EYV5R<VEZ('G]\/UN(&MI;6QI\&DN(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,34X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@
M<W5B;6ET=&5D+B(*;7-G<W1R(")'9>=E<G-I>B!V97)I(&?V;F1E<FEL9&DN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`P"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM
M<V=S='(@(D=EYV5R<VEZ('1E<VQI;2!A9')E<VDB"@HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HX,0HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#`*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+V1B>"YP:'`Z,C(P"FUS9VED("));G9A;&ED(&9I;&4@
M9F]R;6%T(@IM<V=S='(@(D=EYV5R<VEZ(&1O<WEA(&)IYVEM:2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S<*(RP@9G5Z>GD*;7-G:60@
M(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(D=EYV5R<VEZ('5Y9W5L
M86UA+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S$*(RP@
M9G5Z>GD*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S
M='(@(D=EYV5R<VEZ('5Y9W5L86UA+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M
M<V=?='EP92XB"FUS9W-T<B`B1V7G97)S:7H@;7-G7W1Y<&4B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G
M:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(D=EYV5R
M<VEZ('EA9&$@871L86YM_?X@87!I7VED(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED
M(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B1V7G97)S:7H@>6%D
M82!A=&QA;FW]_B!D9?!I_G1I<F=E;&5R(@H*(SH@861M:6XO<&5R;7,O861D
M8VAI;&0N<&AP.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N
M+B(*;7-G<W1R(")'9>=E<G-I>B#\<W0@:7II;BXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3<S"B,L(&9U>GIY"FUS9VED("));G9A;&ED
M('!A<G1N97(@:60N(@IM<V=S='(@(D=EYV5R<VEZ(/QS="!I>FEN+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*(RP@9G5Z>GD*;7-G
M:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R(")'9>=E<G-I>B!I
M;&5T:?YI;2!K=7)A;&QA<OTB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@<')O=&]C
M;VPN(@IM<V=S='(@(D=EYV5R<VEZ(&EL971I_FEM(&MU<F%L;&%R_2(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C@P"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM
M<V=S='(@(D=EYV5R<VEZ(&%L_6/].B`G)7,G(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,#<V(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3(V,@IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B1V7G
M97)S:7H@<&%Y;&'^_6QA;B!N97-N92(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S
M;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B1V7G97)S:7H@:V%Y;F%K(&%D<F5S
M:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R
M(")'9>=E<G-I>B!U;FEC;V1E('9E<FES:2XB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S4W"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B4W1O
M:R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV
M-SD*(RP@9G5Z>GD*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B
MWF7G:6QI(&]L86YL87+](&ME<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A
M;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("+=<F%N(-US;&%M($-U
M;6AU<FEY971I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@
M(DER86LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B
MW7)L86YD82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS
M9VED("))<VQE(&]F($UA;B(*;7-G<W1R(")-86X@061A($1E=FQE=&DB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I
M9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B66%L_73];&W]_B!G]FL@
M9_QR_&QT_&S\(&;]<G3];F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E
M;"(*;7-G<W1R("+=<W)A:6PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8R-0IM<V=I9"`B27-S=65R(@IM<V=S='(@(L?]:V%R86XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*
M;7-G:60@(DET86QI8R(*;7-G<W1R("+==&%L:6LB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*
M;7-G:60@(DET86QY(@IM<V=S='(@(MUT86QY82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM
M<V=I9"`B2F%M86EC82(*;7-G<W1R(")*86UA:6MA(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB
M"FUS9W-T<B`B3V-A:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS
M9W-T<B`B2F%P;VYY82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS
M9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(DIA<&]N8V$@
M*$E33RTR,#(R+4I0*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,S$P"FUS9VED("(B"B)*879A<V-R:7!T(&AA<R!B965N(&1I<V%B;&5D(&]N
M('EO=7(@8G)O=W-E<B!A;F0@=&AI<R!P86=E(&UA>2!N;W0@8F4@(@HB9&ES
M<&QA>6EN9R!C;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B2F5R
M<V5Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`BW')D
M_&XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`W"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M,0IM<V=I9"`B2G5L>2(*;7-G<W1R(")496UM=7HB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G
M<W1R(")(87II<F%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R(")9
M87-L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R(")/
M<G1A>6$@66%S;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S
M='(@(E1A;6%M96X@66%S;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T
M(@IM<V=S='(@(E-O;&$@66%S;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2
M:6=H="(*;7-G<W1R(")38?!A(%EA<VQA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED
M(")+87IA:VAS=&%N(@IM<V=S='(@(DMA>F%K:7-T86XB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8T"FUS9VED(")+965P
M(&]R:6=I;F%L/R(*;7-G<W1R("+6>F?\;B!O;&%N('-A:VQA;G/];B!M_3\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(DME;GEA(@IM<V=S='(@(DME;GEA(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R
M8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M(")+97)B97)O<R!S=6YU8W4@9&_P<G5L86UA>?T@<F5D9&5T=&DN(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE
M<R(*;7-G<W1R("+'96MI<F1E:R!!8V5M:6QE<FDB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*
M;7-G<W1R(")!;F%H=&%R(%EA<F%T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T
M<B`B06YA:'1A<B!087)M86MI>FDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B06YA
M:'1A<B!5>G5N;'7P=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B06YA:'1A<B!4:7!I
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G
M:60@(DME>2!5<V%G92(*;7-G<W1R(")!;F%H=&%R($MU;&QA;OUM_2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y
M(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G
M<W1R(")!Y_UK(&%N86AT87(@<W5N=6-U<W5N9&$@86YA:'1A<B!Z871E;B!V
M87(N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S
M(@IM<V=S='(@(L=O8W5K;&%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I
M8F%T:2(*;7-G<W1R(")+:7)I8F%T:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B
M2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B2W5Z97D@2V]R92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E
M<'5B;&EC(&]F(@IM<V=S='(@(D?\;F5Y($MO<F4B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X.`IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@
M(DMO<F5C92`H975C+4M2*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET
M(@IM<V=S='(@(DMU=F5Y="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ
M<W1A;B(*;7-G<W1R(")+_7)G_7II<W1A;B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R(")387EF82!?
M1/QZ96YI(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I
M9"`B3&%N9W5A9V4B"FUS9W-T<B`B1&EL(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED
M("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("),
M86\@1&5M;VMR871I8R!(86QK($-U;6AU<FEY971I(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(E-O;B!$
M]G)D_&XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S8*(RP@9G5Z>GD*
M;7-G:60@(DQA<W0@4&%S<W=O<F0@0VAA;F=E(@IM<V=S='(@(E!A<F]L87G]
M('/]9OUR;&$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K
M+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`BWFG^
M:VEN($%Y(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3$*;7-G:60@(DQA
M<W0@57!D871E9#HB"FUS9W-T<B`B4V]N($?\;F-E;&QE;64Z(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@
M(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(E-O;B!':7)I_CH@)7,B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HW,C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R(")3;VX@1VER:?XZ
M("5S(/QZ97)I;F1E;B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.C<Q-@IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B4V]N($=I
M<FG^.B!!<VQA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T
M<B`B3&5T;VYY82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I
M9"`B3&%W(@IM<V=S='(@(EEA<V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*;7-G
M<W1R(")$_'IE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B
M"FUS9W-T<B`B2&GG8FER('/];OUR(&GG:6X@8F_^(&+]<F%K;6$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B3/QB;F%N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y
M"FUS9VED("),969T(@IM<V=S='(@(E-O;"(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,3D*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(E-O
M;"!B8?YL_6L@8FEL9VES:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,34*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(E-O;&1A:VD@9&7P
M97)L97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B
M3&5S;W1H;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC
M+"!F=7IZ>0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B0?YK(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@(DQI8F5R>6$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B
M3&EB>6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS
M9W-T<B`B3&EE8VAT96YS=&5I;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ>FQE(@IM<V=S
M='(@(L=I<V5L:7EO<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(V"FUS9VED("),:6=H="!286EN(@IM<V=S='(@(DAA9FEF
M(%EA\&UU<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(W"FUS9VED("),:6=H="!286EN($5A<FQY(@IM<V=S='(@(D5R:V5N
M(%-A871L97)D92!(869I9B!98?!M=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E
M(@IM<V=S='(@(D=EYR!386%T;&5R9&4@2&%F:68@66'P;75R(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI
M9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(DAA9FEF(%EA\&UU<B!38?!A;F'P
M_2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P
M"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R(")']FL@
M9_QR_&QT_&S\(&AA9FEF('EA\&UU<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S
M='(@(DAA9FEF($MA<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R
M(")(869I9B!+87(@4V'P86YA\/TB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(D[\:W1E;&D@WFEI<B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,30*;7-G:60@(DQI;FLB
M"FUS9W-T<B`B0F'P;&%N=/TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S
M('1O.B(*;7-G<W1R(")"8?!L86YT_2!N;VMT87/].B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X-S4*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D
M9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS
M9W-T<B`B1_9R_&YT_&QE<FME;B!E;&5K=')O;FEK('!O<W1A(&%D<F5S:6YI
M(&]L=?YT=7)M82!S87EF87/];F$@8F'P;&$B"@HC.B!F<F%M97=O<FLO5&5X
M=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED("),:6YK
M<R(*;7-G<W1R(")"8?!L86YT_6QA<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(DQI;G5X(,=E
M<F5Z:2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS
M9W-T<B`B3&ES=&5L92`M(&MU;&QA;OUC_2!D:7II;FD@9_9R96)I;&ER(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$871A8F%S
M97,B"FUS9W-T<B`B5F5R:2!486)A;FQA<OUN_2!,:7-T96QE(@H*(SH@<V5R
M=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I
M8W,B"FUS9W-T<B`B66%R9/UM($MO;G5L87+];OT@3&ES=&5L92(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,S(*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S
M='(@(L=I>F5L9V5L97)I($QI<W1E;&4B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S
M='(@(DQI<W1E;&4M07+^:78B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE
M861E<G,N<&AP.C4X.0IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(DQI<W1E
M;&4M66%R9/UM(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.38*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B3&ES=&5L92U)9"(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),
M:7-T+4]W;F5R(@IM<V=S='(@(DQI<W1E;&4M4V%H:7`B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T
M(@IM<V=S='(@(DQI<W1E;&4M1_9N9&5R:6QM:?X@UO!E;&5R(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M
M4W5B<V-R:6)E(@IM<V=S='(@(DQI<W1E;&4M4_QR9/QR_&UC_&QE<B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),
M:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(DQI<W1E;&4M4_QR9/QR_&UC_"!/
M;&UA>6%N;&%R(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B2W5L;&%N_6/](&QI<W1E;&5M92!S9>=I;&5M97H@:_UL
M_6YD_2XB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G
M<W1R(")+=6QL86[]8_T@;&ES=&5L96UE('-EYVEL96UE>B!K_6S];F3]+B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B
M3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B2W5L;&%N_6/]
M(&QI<W1E;&5M92!S9>=I;&5M97H@:_UL_6YD_2XB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B161E
M8FEY870B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R
M("),:71V86YY82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z.#,*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B6?QK;&5N
M:7EO<BXN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3$*
M;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R(")997)E;"!Z86UA;CHB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO8V%L92!A;F0@
M5&EM92(*;7-G<W1R(")997(@=F4@6F%M86XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4W,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-C0*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C
M:R]M971A<BYP:'`Z-C4*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(EEE<B(*
M"B,Z(&QO9VEN+G!H<#HQ-S(@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M.C$Y,2!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z.3`*;7-G:60@(DQO9R!I;B(*;7-G<W1R(")':7)I_B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I
M;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<VED96)A<BYP:'`Z,3@U"FUS9VED("),;V<@;W5T(@IM<V=S='(@(L?]
M:_W^(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"B,L(&9U>GIY"FUS
M9VED("),;V=I;B(*;7-G<W1R(")':7)I_B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,#<*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(D=I<FG^
M($?V<F5V;&5R:2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY-@IM
M<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P
M87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B2W5L
M;&%N_6/](&%D_2!V97EA('!O<F]L82!D;_!R=2!O;&UA9/WP_2!IYVEN(&=I
M<FG^(&)A_F%R_7/]>B!O;&1U+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDY,@IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R(")':7)I_B!B
M8?YA<OUS_7H@;VQD=2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S8U"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B57IU;B!M971I;B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R
M(")!_FLB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV-PIM<V=I9"`B3&]W(@IM<V=S='(@(D3\_OQK(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I
M9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R(")+_.?\:R!Y=6YA;B!H
M87)F;&5R:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B
M"FUS9W-T<B`B2_SG_&L@;&%T:6X@:&%R9FQE<FDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED
M("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(DO\Y_QK(')O;6$@<F%K
M86UL87+](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S
M='(@(DS\:W-E;6)U<F<B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,S@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@
M(DU-(@IM<V=S='(@(D%!(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(X,0IM<V=I9"`B34]41"(*;7-G<W1R(")-3U1$(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@
M071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B35,M5$Y%
M1B!%:VD@=F5R:2!IYV5R;65M96MT961I<BXB"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W
M"FUS9VED(")-4T<B"FUS9W-T<B`B35-'(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED
M(")-86-A;R(*;7-G<W1R(")-86-A;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B
M36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(DUA:V5D;VYY82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A
M<V-A<B(*;7-G<W1R(")-861A9V%S:V%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0Y"FUS9VED(")-86=I8R(*;7-G<W1R(")"_'G\(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Q"FUS9VED(")-86EL(@IM<V=S='(@
M(E!O<W1A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R,@IM<V=I
M9"`B36%I;"!!9&UI;B(*;7-G<W1R(")0;W-T82!9]FYE=&EC:7-I(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(D)A\&QA7VYT_2!9
M87)A="XN+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L87=I(@IM<V=S='(@
M(DUA;&%V:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T
M<B`B36%L97IY82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS
M9W-T<B`B36%L9&EV;&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86QI(@IM
M<V=S='(@(DUA;&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;'1A(@IM<V=S
M='(@(DUA;'1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ"FUS9VED
M("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T
M;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@
M=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"B+6\&5L97)I(&5T
M:6ME=&QE>65C9?!I;FEZ(&MA=&5G;W)I(&QI<W1E<VEN:2!V92!K871E9V]R
M:6QE<FD@(@HB:6QI_FMI;&5N9&ER96-E\&EN:7H@<F5N:VQE<FD@>?9N971I
M;BXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3$U,PIM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(DUA<#(T(&AA<FET87/]
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q
M-C@*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R(")-87!1=65S="!H87)I
M=&%S_2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I
M9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS
M9W-T<B`B36%R="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")+96YA
M<B!B;_YL=?!U(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*
M;7-G<W1R(")/:W5N;77^+T]K=6YM86W]_B!O;&%R86L@:?YA<F5T;&4B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I
M9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W
M97)E9"DB"FUS9W-T<B`B1&GP97(@:6QE=&D@:?YA<F5T;&5R:7EL92!I_F%R
M971L92`H]G)N96LZ(-9N96UL:2]#979A<&QA;FW]_BD@(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(DUA<G-H86QL
M($%D86QA<OTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS
M9W-T<B`B36%R=&EN:6LB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(D7^;&5L96X@
M86QA;FQA<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G
M<W1R(")-;W)I=&%N>6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU
M<R(*;7-G<W1R(")-875R:71U<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@
M8W)E9&ET+B(*;7-G<W1R("+=>FEN('9E<FEL96X@96X@>?QK<V5K(&MR961I
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM
M<V=S='(@(D5N('G\:W-E:R!M97-A:B!P87+G87/]('-A>?US_2!A_OUL9/TN
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP
M(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")3;VX@,C0@<V%A='1E:VD@96X@
M>?QK<V5K('/]8V%K;/UK.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y
M.`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B4V]N
M(#8@<V%A='1E:VD@96X@>?QK<V5K('/]8V%K;/UK.B`B"@HC.B!L:6(O87!I
M+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3@@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R
M(")%;B!Y_&MS96L@=7IU;FQU:R(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B36%Y_7,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@(DUA>6]T
M=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC
M:6YE(@IM<V=S='(@(E3]<"(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`BW'EE;&5R(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.`IM<V=I9"`B365N=2!M;V1E
M.B(*;7-G<W1R(")-96[\($MI<&DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L
M;',B"FUS9W-T<B`B2/QC<F5L97)I(&)I<FQE_G1I<B(*"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP
M:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED
M(")-97-S86=E(@IM<V=S='(@(MUL971I(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I
M960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@
M8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B+=;&5R:2!B
M8?YA<OUY;&$@9&_P<G5L86YD_2!A;6$@:6UZ86QA>?UC_6[];B!O;F%Y(&)E
M;&=E<VD@9&_P<G5L86YA;6%D_2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP
M:7)E9"XB"FUS9W-T<B`B365S86K];B!S_')E<VD@8FET=&DN(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(V,`IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(DUE<V%J('1I
M<&DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E
M871H97(B"FUS9W-T<B`B2&%V82!287!O<G4B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R(")(879A(')A<&]R=2#V8F7P:2!K=6QL86[];&%B:6QI<B!D9?!I
M;"XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q,@IM<V=I9"`B(@HB365T
M87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G
M9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB2&%V82!R
M87!O<G4@]F)E\&D@:W5L;&%N_6QA8FEL:7(@9&7P:6PN($%Y<OUN=/UL87(@
M>?9N971I8VD@:>=I;B!G_&YL_&ML96YD:2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE
M8W1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`B6?9N=&5M(@H*(SH@9G)A
M;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)0
M0R]S;V%P+G!H<#HQ,3<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUE
M=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B6?9N=&5M("<E
M<R<@=&%N_6UL86YM86W]_B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N
M<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE
M9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C<T(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*
M;7-G:60@(DUE=')I8R(*;7-G<W1R(")-971R:6LB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*
M;7-G:60@(DUE>&EC;R(*;7-G<W1R(")-96MS:6MA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*
M;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T
M<B`B36EK<F]N97-Y82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-@IM<V=I9"`B36ED9&QE(@IM<V=S='(@(D]R
M=&$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS
M.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(DUI;64@5/QR_"(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S$P"FUS9VED(")-:6X@=&5M<"!L87-T(#(T
M(&AO=7)S.B`B"FUS9W-T<B`B4V]N(#(T('-A871T96MI(&5N(&3\_OQK('/]
M8V%K;/UK.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B
M36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B4V]N(#8@<V%A='1E
M:VD@96X@9/S^_&L@<_UC86ML_6LZ("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H
M87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,S0*;7-G:60@(DUI<G)O<B(*
M;7-G<W1R(")986YS_2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM
M<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R(")-=6AT96QI9B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T
M,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(U,`IM
M<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G
M<W1R(")"=6QU;F%M87EA;B!014%2('!A:V5T:3H@2%144%]297%U97-T+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I
M;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W
M(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G
M<W1R("(B"B)!=&QA;FW]_B!Y87#];&%N9/UR;6$N($)U('5Y9W5L86UA>?T@
M:W5L;&%N;6%K(&ES=&EY;W)S86[]>B!Y87#];&%N9/UR;6%Y_2`B"B+\<F5T
M;65K('IO<G5N9&%S_6[]>BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G
M92!)1"XB"FUS9W-T<B`B071L86YM_?X@;65S86H@240N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G
M:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S
M='(@(D%T;&%N;?W^(&]L86X@9V5R96ML:2!014%2('!A:V5T:2!-86EL+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R(")!=&QA
M;FW]_B!O='5R=6UA(&%I="!)1"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R(")0>G0B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S0*;7-G:60@(DUO8FEL
M92!-86EL(@IM<V=S='(@(D=E>FEC:2!0;W-T82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")-;V1E<F%T92(*
M;7-G<W1R(")386MI;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@X
M"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@(D1E\&G^:6T@5&%R:6AI
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(D1E\&G^=&ER
M.E523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<S
M"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(DUO9"!486)A;OTB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUO
M;&1O=GEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B
M36]N86-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R
M(")-;_!O;&ES=&%N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y
M-`IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B07D@=F4@>?UL(@H*
M(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM
M<V=I9"`B36]N=&AL>2(*;7-G<W1R(")!>6S]:R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM
M<V=I9"`B36]N='-E<G)A="(*;7-G<W1R(")-;VYT<V5R<F%T(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED
M(")-;V]N(%!H87-E<R(*;7-G<W1R(")!>2!%=G)E;&5R:2(*"B,Z(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$W,B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HR-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@
M9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(D9A
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S
M"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B1V5N96QL:6ML92!!Y_UK
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*
M;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B1V5N96QL:6ML92!"=6QU
M=&QU(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S4*;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R(")'96YE;&QI:VQE($?\
M;F7^;&DB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU
M,#D*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R(")!_F'P_2!48?[](@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$S"FUS9VED(")-
M;W9E($QE9G0B"FUS9W-T<B`B4V]L82!48?[](@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$W"FUS9VED(")-;W9E(%)I9VAT(@IM
M<V=S='(@(E-A\&$@5&'^_2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C4P-0IM<V=I9"`B36]V92!5<"(*;7-G<W1R(")9=6MA<OT@
M5&'^_2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU,C0*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R(")!_F'P_2!T8?[](@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PHC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS
M9VED(")-;W9E('5P(@IM<V=S='(@(EEU:V%R_2!T8?[](@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(DUO>F%M8FEK(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-`IM<V=I9"`B375L=&DM;&5V
M96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(L=O:VQU(&3\>F5Y(&'^8?#]
M(&'G_6S]<B!L:7-T96QE<B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#4U"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,@IM<V=I
M9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(L=O:VQU(%-EYVEM(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,`IM<V=I9"`B37D@06-C
M;W5N="(*;7-G<W1R(")(97-A8OUM(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C(X"B,L(&9U>GIY"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T:6]N
M(@IM<V=S='(@(D)I;&=I;&5R:6YI>B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I
M;F1E>"YP:'`Z-30*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R(")0;W)T86S]
M;2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HQ,S8*;7-G:60@(DUY
M(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B4&]R=&%L($3\>F5N:6TB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B37EA;FUA<B(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS
M9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B2V%B=6P@151-25E/
M4E5-(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA
M;64B"FUS9W-T<B`B060B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B
M"FUS9W-T<B`B3F%M:6)Y82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B
M"FUS9W-T<B`B3F%U<G4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM
M<V=S='(@(DYE<&%L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").971H97)L86YD
M<R(*;7-G<W1R(")(;VQL86YD82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H
M97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R(")(;VQL86YD82!!;G1I;&QE<FDB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I
M9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B3F5T<V-A<&4@5&%B86X@
M55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*
M;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(DYE
M='-C87!E($-!(-UP=&%L(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),
M(@IM<V=S='(@(DYE='-C87!E($-!(&MU<F%L(%523"(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!2
M96YE=V%L(%523"(*;7-G<W1R(").971S8V%P92!996YI;&5M92!23"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").
M971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R(").971S8V%P92#=<'1A
M;"!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X
M-@IM<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(DYE
M='-C87!E(%-33"!S=6YU8W4@863](@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E
M(&-O;6UE;G0B"FUS9W-T<B`B3F5T<V-A<&4@;VYA>2!B96QG97-I(&'G_6ML
M86UA<_TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X
M,`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R(").
M971S8V%P92!O;F%Y(&)E;&=E<VD@=/QR_"(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR-3$*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`B0?`B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,S-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V
M"FUS9VED(").979E<B(*;7-G<W1R(")!<VQA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS
M9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(EEE;FD@2V%L961O;GEA(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R(")996YI($MA=&5G;W)I
M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP
M.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H
M<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP
M:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N
M<&AP.C$P,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A
M9V4@=&\@)7,B"FUS9W-T<B`BW6QE=&D@3VQU_G1U<B`H)7,I(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G<W1R(")9
M96YI($%Y(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS
M-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B665N
M:2!+=6QL86[]8_T@063]("A39>=I;6QI*2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I
M9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B665N:2!:96QL86YD82(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B
M3F5W('!A<W-W;W)D(@IM<V=S='(@(E!A<F]L82(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W
M('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*(RP@9G5Z>GD*;7-G:60@
M(DYE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(E!A<F]L86QA
M<B!E_FQE_FUE:R!Z;W)U;F1A9/UR+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B
M;&%N:RDB"FUS9W-T<B`B665N:2!096YC97)E("A?8F_^*2(*"B,Z(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y"FUS9VED(").97=S(@IM
M<V=S='(@(DAA8F5R;&5R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,P-0IM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R(")(86)E<B!'<G5P;&%R
M_2(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z,3(Y('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED
M(").97AT(@IM<V=S='(@(E-O;G)A:VDB"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B
M4V]N<F%K:2!%=G)E(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HS-S(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S8*;7-G:60@
M(DYE>'0@;W!T:6]N<R(*;7-G<W1R(")3;VYR86MI(%-EYV5N96ML97(B"@HC
M.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I
M9"`B3F5X=#XB"FUS9W-T<B`B4V]N<F%K:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I
M9"`B3FEC87)A9W5A(@IM<V=S='(@(DYI:V%R86=U82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B3FEJ97)Y82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R(").:6IE<GEA(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,X,`IM<V=I9"`B3FEG:'0B"FUS9W-T
M<B`B1V5C92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3FEU92(*;7-G<W1R(").
M:75E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDV,PIM<V=I9"`B3F\B"FUS9W-T<B`B2&%Y_7(B"@HC.B!T96UP;&%T97,O
M861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C
M;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM
M<V=S='(@(D9A<FML87+];B!G]G-T97)I;&5B:6QE8V7P:2!K=6QL86[];&%B
M:6QI<B!Y87#];&%N9/UR;6$@=F5R:7-I('EO:RXB"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C$P-0IM<V=I9"`B3F\@879A
M:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T
M<B`B25-/(&EM86IL87+](&]U_G1U<FUA:R!IYVEN(&MU;&QA;OUL86)I;&ER
M(&)I<B!Y]FYT96T@>6]K+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA
M=&4N(@IM<V=S='(@(EG]\/UN('1A<VQA\/T@>6]K+B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<Y(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C(T-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HR-C<*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@
M<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(MUS=&5N96X@:V]N=6UD82!H
M:>=B:7(@]F)E:R!B=6QU;FUA;6%K=&%D_7(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R
M;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")-0T%,
M(&1O\')U;&%M87/](&GG:6X@:&GG8FER('1A:W9I;2!A9/T@<V'P;&%N;6%M
M_?YT_7(N("(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED(").
M;R!C:&%N9V4N(@IM<V=S='(@(D1E\&G^:6ML:6L@66]K(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N
M(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(D)U
M(&EZ;F4@:&GG8FER(&%L="!I>FEN(&5K;&5N96UE>65C96MT:7(N(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C<@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HU,#(*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S<S
M"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B)7,@:>=I;B!H:>=B
M:7(@>6%P_6QA;F3]<FUA(&)I;&=I<VD@8F5L:7)T:6QM961I+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(T"FUS9VED(").;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS
M9W-T<B`B1E10(%9&4R!IYVEN(&AIYV)I<B!Y87#];&%N9/UR;6$@8FEL9VES
M:2!B96QI<G1I;&UE9&DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HV-CD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R(")344P@5D93(&GG:6X@:&GG
M8FER('EA</UL86YD_7)M82!B:6QG:7-I(&)E;&ER=&EL;65D:2XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S$W"FUS9VED(").;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I
M;&4@5D93+B(*;7-G<W1R(")344PM1FEL92!61E,@:>=I;B!H:>=B:7(@>6%P
M_6QA;F3]<FUA(&)I;&=I<VD@8F5L:7)T:6QM961I+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B
M3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(DMR961I('EO:RXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I
M9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(DAIYV)I<B!T
M97-L:6T@;F]K=&%S_2!B96QI<G1I;&UE;6G^=&ER+B(*"B,Z(&9R86UE=V]R
M:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@W-PIM<V=I9"`B3F\@9FEL92!U<&QO
M861E9"(*;7-G<W1R(")(:>=B:7(@9&]S>6$@>?QK;&5N96UE9&DB"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD
M+B(*;7-G<W1R(")(:>=B:7(@<VEM9V4@8G5L=6YA;6%D_2XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(X(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R,PIM<V=I9"`B3F\@
M;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R(")(:>=B:7(@>65R(&)E;&ER=&EL
M;65D:2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Y"B,L
M(&9U>GIY"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B
M2&GG8FER('EE<B!B96QI<G1I;&UE9&DN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE<W-A
M9V4@<W5P<&QI960N(@IM<V=S='(@(DAIYV)I<B!M97-A:B!S8?!L86YM863]
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,V"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B060@
M8F5L:7)T:6QM961I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D
M+B(*;7-G<W1R(").=6UA<F$@8F5L:7)T:6QM961I+B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S
M(@IM<V=S='(@(E-A;&3]<F=A;B!D97EI_B!K=6QL86YM82(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")(
M5%10(&1O\')U;&%M87/](&GG:6X@<&%R;VQA(&=I<FEL;65D:2XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(DE-05`@9&_P<G5L86UA<_T@:>=I;B!P87)O;&$@9VER:6QM961I+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B2V5R8F5R;W,@9&_P<G5L86UA<_T@:>=I;B!P87)O;&$@
M9VER:6QM961I+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z
M-S<@9G)A;65W;W)K+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]P86TN<&AP.C<U"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DQO
M9VEN(&1O\')U;&%M87/](&GG:6X@<&%R;VQA(&=I<FEL;65D:2XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(")005-35T0@9&_P<G5L86UA<_T@:>=I;B!P87)O;&$@9VER:6QM
M961I+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`IM<V=I
M9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B4TU"(&1O\')U;&%M87/](&GG:6X@<&%R;VQA(&=I<FEL
M;65D:2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R
M.#8*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R
M;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*
M(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*(D]P96Y34TP@
M:6MI;&ES:6YE(&AIYV)I<B!Y;VP@8G5L=6YA;6%D_2Y/<&5N4U-,(&EK:6QI
M<VD@4$M#4R`Q,B!V97)I<VEY;&4@(@HB8V%L_?YM86L@:>=I;B!G97)E:VQI
M+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G
M:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`BW'EE(&]L;6%K(&GG
M:6X@8F5K;&5Y96X@>6]K+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW
M-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO('%U;W1A('-E="XB
M"FUS9W-T<B`B0F5L:7)T:6QM96UI_B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S
M(@IM<V=S='(@(DMU<F%L('EO:R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C0T.0HC+"!F=7IZ>0IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I
M9FEE9"XB"FUS9W-T<B`B3G5M87)A(&)E;&ER=&EL;65D:2XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T"FUS
M9VED(").;R!S:61E<R(*;7-G<W1R(")986X@>6]K(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HU.#,*(RP@9G5Z>GD*;7-G:60@(DYO('-U8V@@
M9FEL92(*;7-G<W1R(")986X@>6]K(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$S.`IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A
M=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R("+6;F)E;&QE:R!IYVEN(&=E
MYVEC:2!D:7II;B!B=6QU;F%M863]+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M92!A
M;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B2W5L;&%N_6/](&%D_2!V
M92]V97EA('!A<F]L82!G]FYD97)I;&UE9&DN(@H*(SH@9G)A;65W;W)K+U)0
M0R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D871A
M(')E='5R;F5D(@IM<V=S='(@(D=EYV5R;&D@6$U,('9E<FES:2!G97)I(&3V
M;FUE9&DN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDW,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.3@Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HY.3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P,#D*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R(")$9?!E<B!Y;VLB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N
M(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BUGIG_&X@>6%P_6QA;F3]<FUA9&$@
M<_QR_&T@8G5L=6YA;6%D_2Y987#];&%N9/UR;6%Y_2!T96MR87(@_')E=&EN
M+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E
M<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(M9Z9_QN('EA</UL86YD_7)M86[]
M>F1A('/\<OQM(&)U;'5N86UA9/TN66%P_6QA;F3]<FUA>?T@=&5K<F%R(/QR
M971I;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS
M"FUS9VED(").;VYE(@IM<V=S='(@(DAIYV)I<FDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU
M<V4@:6UP;&EC:70I(@IM<V=S='(@(DAIYV)I<FD@*-9R=/QL_"!K=6QL86[]
M;BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B3F]R9&EC
M("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B2W5Z97D@079R=7!A;/T@*$E33RTX
M.#4Y+3$P*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B
M"FUS9W-T<B`B3F]R9F]L:R!!9&%S_2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE
M;6ES<&AE<F4B"FUS9W-T<B`B2W5Z97D@66%R_6UK_')E(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B
M2W5Z97D@36%R:6%N82!!9&%L87+](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").
M;W)W87DB"FUS9W-T<B`B3F]R=F7G(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R(")3
M;VYR87/];F1A($1E\&EL(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV,SD*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`BUFYC97-I
M;F1E($1E\&EL(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#`X
M"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B1&EZ:6X@9&7P:6PB
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T
M<'5T4W1R871E9WDN<&AP.C@S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDT"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2YP:'`Z-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N
M=&5D+B(*;7-G<W1R(")'97+G96ML9?YT:7)I;&UE;6G^(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T
M('-E="(*;7-G<W1R(")"96QI<G1I;&UE;6G^(@H*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#,*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ
M-S,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R
M+G!H<#HQ.#<*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(
M86YD;&5R+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y,`HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`U(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(T."!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C8U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.#$@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C(Y-PHC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,S$R(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,CD*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C,V,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(R
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU,#$@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C4W,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3@W(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HV-C4*;7-G:60@(DYO="!S=7!P;W)T960N(@IM
M<V=S='(@(D1E<W1E:VQE;FUI>6]R+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T
M.C$P,#4*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$W.`IM<V=I9"`B
M3F]T97,B"FUS9W-T<B`B3F]T;&%R(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O
M:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C
M:RXB"FUS9W-T<B`B1_9Z(&%T_6QA8V%K(&)I<OYE>2!Y;VLL(&=E<FD@9/9N
M_&XN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(DMA<_UM(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3`T-@IM<V=I9"`B3G5M8F5R(@IM<V=S='(@
M(E-A>?TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U"FUS9VED
M(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R(")+87)A:W1E<B!S87G]
M<_TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30T-2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B2V]L;VX@
M<V%Y_7/](@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T-#,@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(E-A=/UR
M('-A>?US_2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R
M('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")$8?#]
M=/UM(&QI<W1E;&5R:6YI;B!G_&YC96QL96YM97-I(&GG:6X@;G5M87)A;&%R
M(&)E;&ER=&EL;65M:?XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R(")%=F5T(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I
M9"`B3V)J96-T(@IM<V=S='(@(DYE<VYE(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@
M(DYE<VYE(%EA<F%T_6/]<_TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R(")396MI>FQI:R!3:7-T96TB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM
M<V=I9"`B3V-T;V)E<B(*;7-G<W1R(")%:VEM(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R(")3
M86QD_7)G86YL_6L@<_QZ9V5C:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS,C8*;7-G:60@(D]F9FEC92(*;7-G<W1R(")/9FES(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE
M=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@HC+"!F=7IZ>0IM<V=I
M9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(E!A<F]L82(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HT-@HC+"!F=7IZ>0IM<V=I9"`B3VQD('!A
M<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R(")986YL_?X@<&%R;VQA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@(E5M;6%N(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G
M:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N
M(@IM<V=S='(@(E-A9&5C92!)34%0('-U;G5C=6QA<OT@<&%Y;&'^_6QA;B!D
M:7II;FQE<FD@9&5S=&5K;&5M96MT961I<BXB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM
M<V=S='(@(E-A9&5C92!S86QD_7)G86X@9&5Y:?YL97(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Y-S$*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB
M"FUS9W-T<B`B4V%D96-E(&)I<B!E;&5K=')O;FEK('!O<W1A(&%D<F5S:6YE
M(&EZ:6X@=F5R:6QM96MT961I<BXB"@HC.B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A
M9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*
M(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*(D)I<B!P87EL
M8?[];?UN('-A:&EP;&GP:6YI('9E>6$@<V%H:6)I;FD@<V%D96-E('-I<WEE
M;2!Y]FYE=&EC:7-I('9E>6$@(@HB<V%H:6)I(&1E\&G^=&ER96)I;&ER+B(*
M"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,U"FUS9VED(")/<&5N(&EN(&$@
M;F5W('=I;F1O=R(*;7-G<W1R(")996YI('!E;F-E<F5D92!AYR(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N
M4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D
M(%,O34E-12!P87)T+B(*;7-G<W1R(")/<&5N4U-,(&AA=&%S_3K=;7IA;&%N
M;?W^(%,O34E-12!P87+G87/];F1A;B!V97)I('-EYVEP(.?]:V%T_6QA;6%D
M_2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W
M:6YD;W<B"FUS9W-T<B`B0G4@8F'P;&%N=/UY_2!Y96YI('!E;F-E<F5D92!A
MYR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T
M:6YG(%-Y<W1E;2(*;7-G<W1R("+=_FQE=&EM(%-I<W1E;6DB"@HC.B!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM
M<V=S='(@(E-EYV5N96ML97(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@
M=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B)7,@:>=I;B!S9>=E;F5K;&5R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(E/]<F%L86YM_?X@3&ES
M=&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PIM
M<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(DMU<G5L=?XB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI
M<V%T:6]N86P@56YI="(*;7-G<W1R(")+=7)U;7-A;"!":7)I;2(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S(*;7-G:60@(D]R9V%N:7II;F<B
M"FUS9W-T<B`B1/QZ96YL96UE(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S
M='(@(M9Z9_QN('5Y9W5L86UA('1A<VQA\/TB"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP
M;&%T97,@:6X@)7,Z(@IM<V=S='(@(B5S(&GG:6YD96MI(/9Z9_QN('1A<VQA
M:VQA<CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B
M1&GP97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q"FUS9VED(")/
M=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R(")$:?!E<B!":6QG:6QE<B(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(E-A:&EP(&EZ:6YL97)I(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC
M871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4$%-(&1O\')U;&%M
M87/](&UE=F-U="!D9?!I;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,C<S"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B
M4$=0(%-A>?US86P@W6UZ82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$S,3D*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R
M(")01U`@WFEF<F5L96YM:?X@5F5R:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$S-S$*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S
M='(@(E!'4"!!Y_UK($%N86AT87+](@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3,U,PIM<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@
M1&%T82(*;7-G<W1R(")01U`@:6QE(-UM>F%L86YM_?XOWFEF<F5L96YM:?X@
M5F5R:2(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.`IM<V=I9"`B4$A0($-O
M9&4B"FUS9W-T<B`B4$A0($MO9'4B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z
M,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R(")02%`@2V%B=?!U(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@
M(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`BUE,@2&%F:68@66'P;75R(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@
M(E!-(%-H;W=E<G,B"FUS9W-T<B`BUE,@4V'P86YA:VQA<OTB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@
M4VYO=R(*;7-G<W1R("+64R!+87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM
M<V=S='(@(M93($MA<B!38?!A;F%K;&%R_2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"B,L(&9U>GIY"FUS9VED(")032!3
M=6XB"FUS9W-T<B`BUE,@2V%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@
M(M93($?V:R!G_'+\;'3\;/P@9OUR=/UN82(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3
M:&5L;"(*;7-G<W1R(")07TA0($MA8G7P=2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I
M;F<B"FUS9W-T<B`B66%S=/UK;&%M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B
M4&%K:7-T86XB"FUS9W-T<B`B4&%K:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS
M9VED(")086QA=2(*;7-G<W1R(")086QA=2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G
M:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B
MW?YG86P@161I;&UI_B!&:6QI<W1I;B!"]FQG97-I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(")086YA;6$B"FUS9W-T<B`B4&%N86UA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY
M"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(E!A<'5A(%EE;FD@
M1VEN92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@
M(E!A<F%G=6%Y(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S8*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B2_US;65N
M($)U;'5T;'4B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#(S"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")087)O;&$B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W
M;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S,C(*;7-G:60@(E!A<W-W
M;W)D(&EN8V]R<F5C="(*;7-G<W1R(")986YL_?X@<&%R;VQA(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S<W=O
M<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B4D%$2553(&1O\')U;&%M87/](&GG:6X@<&%R;VQA(&=E<F5K;65K=&5D
M:7(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,PIM<V=I9"`B
M4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B3VYA>6S](%!A
M<F]L82(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I
M9"`B4&%S<W=O<F0Z(@IM<V=S='(@(E!A<F]L83HB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R
M(")087)O;&$Z(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P,S0*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S
M='(@(E!A<F]L86QA<B!E_FQE_FUE:R!Z;W)U;F1A9/UR+B(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R(")9
M87#]_G3]<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@
M(E!A;F]D86X@>6%P_?YT_7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@(EEO;"(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD
M:6YG(%-I9VYU<',Z(@IM<V=S='(@(D)E:VQE>65N(-QY96QI:VQE<CHB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*;7-G:60@(E!E;W!L92(*;7-G
M<W1R("+=;G-A;FQA<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@(EG\>F1E
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G
M<W1R(")"86O];2#=_FQE;6QE<FEN:2!'97+G96ML9?YT:7(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#`V"FUS9VED(")097)F;W)M(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(D)A:_UM(&G^;&5M
M;&5R:2!G:7)I_G1E(&=E<N=E:VQE_G1I<FEL<VEN(&UI/R(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(")097)M:7-S:6]N
M(@IM<V=S='(@(MUZ:6XB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<
M(B!N;W0@9&5L971E9"XB"FUS9W-T<B`BW7II;B`G)7,G('-I;&EN96UE9&DN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#8*(RP@9G5Z>GD*
M;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(MUZ:6XB"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$V-`HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B7TAA:VQA<B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP
M.C$P.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R
M;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G
M:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(MUZ:6X@
M6?9N971I;6DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*;7-G:60@
M(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(DMI_FES96P@0FEL9VEL
M97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B4&5R=2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G
M<W1R(")%=F-I;"!(87EV86YL87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H
M:6QI<'!I;F5S(@IM<V=S='(@(D9I;&EP:6YL97(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*
M;7-G<W1R(")496QE9F]N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0W.`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(D9O=&_P<F%F;&%R(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B4&ET8V%I<FXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(E)E<VEM($)I<FEM:2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G
M<W1R(")"97EL:6L@4_9Z;&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K
M(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(DS\=&9E;B!B:7)K8><@:/QC<F5Y
M92!T_6ML87G];B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA
M="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R("),
M_'1F96X@8G4@]O!E>6D@Y_UK87)M86L@:7-T961I\&EN:7II(&1O\')U;&%Y
M_6XZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W
M86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(DS\=&9E;B!B
M=2#V\&5N:6X@8F'P_6[](.?V>FUE:R!I<W1E9&GP:6YI>B!D;_!R=6QA>?UN
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U-S$*;7-G:60@(E!L
M96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(DS\=&9E
M;B!B:7(@87D@=F4@8FER('G];"!G:7)I;BXB"@HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B3/QT
M9F5N('EE;FD@:V%T96=O<FEN:6X@863];OT@9VER:6XZ(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,P,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B3/QT9F5N(&=EYV5R;&D@8FER
M($E0(&%D<F5S:2!G:7)I;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-C8P"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C
M:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R("),
M_'1F96X@9V7G97)L:2!B:7(@9_QN(&=I<FEN+"!A>61A:VD@9_QN('-A>?US
M_6[](&MO;G1R;VP@961I;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-#4Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G
M<W1R("),_'1F96X@9V7G97)L:2!B:7(@>F%M86X@9VER:6XN(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R
M;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R("),_'1F
M96X@<V]R=6YU;B!B:7(@]GIE=&EN:2!Y87#];BXB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A
M<W-W;W)D(@IM<V=S='(@(DS\=&9E;B!K=6QL86[]8_T@863]('9E('!A<F]L
M86[]>OT@9VER:6XB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*
M(RP@9G5Z>GD*;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@
M=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H
M92`B"B)S>7-T96TN(@IM<V=S='(@(B(*(DS\=&9E;B!M971N:2!O:W5Y=6XN
M(%-I<W1E;6D@:W5L;&%N86)I;&UE:R!IYVEN(&MU;&QA;OUM(&MO_G5L;&%R
M_6[]($M!0E5,("(*(F5T;65K('IO<G5N9&%S_6[]>BXB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B
M4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R("),
M_'1F96X@>65N:2!K871E9V]R:6YI(&%D_2!G:7)I;CHB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R(")0;VQO;GEA(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R(")0
M;VQI=&EK82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#<*;7-G
M:60@(E!O;&QS(@IM<V=S='(@(D]Y;&%M86QA<B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*
M;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(E!O<G1E:VEZ(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W
M"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(D?V
M<OQN=/P@:V]N=6UL86YD_7+];/UY;W(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@
M;V8@=&AI<R!T86)L92(*;7-G<W1R("+':7IE;&=E(&MO;G5M;&%N9/UR_6S]
M>6]R(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B
M>2!)34%0*2(*;7-G<W1R(")"=2!D:7II;F4@9_9N9&5R("A)34%0('1A<F%F
M_6YD86X@>F]R;&%N;6%M86MT863]<BDB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(V-B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*
M;7-G<W1R(")3;VX@)7,@<V%A='1E(&3\_F5N('EA\&UU<B!V92!K87(@;6EK
M=&%R_3HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDX"FUS
M9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E
M9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")0<F5F<U]L9&%P.B#=<W1E;F5N($Q$05`@=7IA;G3]<_T@8G5L
M=6YA;6%D_2XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP
M:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?<V5S<VEO;CH@
MW7-T96YE;B!O='5R=6T@=7IA;G3]<_T@8G5L=6YA;6%D_2XB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(R-0IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B
M0F%S_6[G(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G:60@(E!R
M97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@(D1E;FEZ('-E=FEY97-I
M;F1E:VD@8F%S_6[G.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,S4*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B0F%S_6[G.B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,#4*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(M9N:7IL96UE(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD
M;W<B"FUS9W-T<B`B1_9R_&YT_'G\('EE;FD@<&5N8V5R961E(/9N:7IL92(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8R(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V"FUS9VED(")0<F5V:6]U<R!O<'1I
M;VYS(@IM<V=S='(@(M9N8V5K:2!S9>=E;F5K;&5R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@
M9&]C=6UE;G0B"FUS9W-T<B`B0F5L9V5Y:2!Y87ID_7(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y
M(@IM<V=S='(@(M9Z96P@06YA:'1A<B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B4V]R
M=6XB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C8*;7-G:60@(E!R;V)L
M96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B4V]R=6X@5&%N_6UL86UA<_TB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S8Y"FUS9VED(")0<F]J96-T
M<R(*;7-G<W1R(")0<F]J96QE<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X.`HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@U"FUS9VED(")0<F]M<'0@=&5X="(*
M;7-G<W1R(")-971I;B!B:6QG:2!I<W1E;6DB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T
M<B`B0>?]:R!!;F%H=&%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S
M='(@(D'G_6L@06YA:'1A<B!A;&=O<FET;6%S_2(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C0T"B,L(&9U>GIY"FUS9VED(")0=6)L
M:6,@2V5Y($EN9F\B"FUS9W-T<B`B0>?]:R!!;F%H=&%R(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I
M=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G
M<W1R(")!Y_UK+]9Z96P@86YA:'1A<B!I:VEL:7-I(&)A_F%R_7EL82!Y87)A
M=/UL86UA9/TN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B
M"FUS9W-T<B`B4&]R=&\@4FEK;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E%A
M=&%R(@IM<V=S='(@(DMA=&%R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8S
M"FUS9VED(")1=65R>2(*;7-G<W1R(")3;W)G=2(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B475O=&$B"FUS9W-T<B`B
M2V%T87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET
M*2(*;7-G<W1R(")24T$@0>?]:R!!;F%H=&%R_2`H)60@8FET*2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0*;7-G:60@(E)A9&EO('-E;&5C
M=&EO;B(*;7-G<W1R(")2861Y;R!39>=I;6DB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4F%I;B(*;7-G<W1R
M(")98?!M=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT-`IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R(")%<FME;B!386%T
M;&5R9&4@66'P;75R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R(")'9><@4V%A
M=&QE<F1E(%EA\&UU<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0V"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R(")38?!A
M;F%K(%EA\/W^(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#<*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B66'P;75R
M('9E($MA<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0X"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T<B`B2V%R82!D]F[\
M_F5C96L@>6'P;75R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G
M:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(E)A<W1G96QE($1E>6G^(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2871I
M;R(*;7-G<W1R(")/<F%N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T<B`B3VMU;6$B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PIM<V=I9"`B
M4F5A9"!M97-S86=E<R(*;7-G<W1R("+=;&5T:6QE<FD@3VMU(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N(@IM<V=S='(@(B(*(E-I;&UE:R!I<W1E9&GP:6YI>F4@
M9V5RYV5K=&5N(&5M:6X@;6ES:6YI>C\H0G4@:?YL96T@9V5R:2#G979R:6QE
M;65Z*3HE<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX
M"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A
M(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE
M+B(*;7-G<W1R("(B"B)+=6QL86[]8_T@)7,@92!A:70@:W5L;&%N_6/]('9E
M<FEL97)I;FD@<VEL;65K(&ES=&5D:?!I;FEZ92!E;6EN(&UI<VEN:7HN($)U
M("(*(FG^;&5M(&=E<FD@YV5V<FEL96UE>BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U
M<B!L87-T(&%C=&EO;B(*;7-G<W1R(")3;VX@97EL96UI('1E:W)A<FQA(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE
M;G4@16QE;65N=',Z(@IM<V=S='(@(D1E=FEN9V5N($UE;OP@UO!E;&5R:6YI
M(%1A>F5L93HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"FUS9VED
M(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R(")0;W)T86P@1_9R_&[\
M;?QN_"!487IE;&4Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(S-0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B1/QZ96YL
M:2#=9F%D92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-#D*;7-G
M:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(MUL:?YK:2!487)A
M>?UC_2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(RP@9G5Z>GD*;7-G:60@(E)E
M;&]A9"(*;7-G<W1R(")/:W5M82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S(V"FUS9VED(")296UA<FMS(@IM<V=S='(@(D'G_6ML86UA;&%R(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-`IM<V=I9"`B4F5M;W1E(%-E<G9E
M<G,B"FUS9W-T<B`B57IA:W1A:VD@4W5N=6-U;&%R(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P
M.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B57IA:W1A:VD@
M55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W)E;6]V97%U975E9"YI;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R(")3
M:6PB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*;7-G:60@
M(E)E;6]V92!";&]C:R(*;7-G<W1R("+68F7P:2!3:6PB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34W"FUS9VED(")296UO
M=F4@8V]L=6UN(@IM<V=S='(@(DMO;&]N=2!3:6PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0P"FUS9VED(")296UO=F4@
M9F]R;6%T=&EN9R(*;7-G<W1R(")":>=I;6QE;65Y:2!3:6PB"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B
M"FUS9W-T<B`B26MI;&EY:2!3:6PB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,C`R"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R
M)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B2V%Y9&5D:6QM:?X@
M8F5T:?!I('-U;G5C=6YU(&=EYVEC:2!D:7II;FEN9&5N('-I;"XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#(*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B4VEL(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS
M9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S
M='(@(D)U('!A<N=A>?T@8F5L9V5D96X@Y_UK87)T(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M;W9E('5S97(B
M"FUS9W-T<B`B2W5L;&%N_6/](%-I;"(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V92YI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@
M=7-E<CH@)7,B"FUS9W-T<B`B2W5L;&%N_6/]>?T@<VEL.B`E<R(*"B,Z(&9R
M86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T
M(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*
M;7-G<W1R("+=<W1E:R!C979A<&QA;F%M863]+D3V;OQL96X@:&%T82!K;V1U
M.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"B,L(&9U
M>GIY"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U
M;F0N(@IM<V=S='(@(EG\:VQE;F5N(&1O<WEA(&MA>61E9&EL96UE9&DN(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S0@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HU,3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(D=E<F5K96X@)R5S)R`E<R!Y87#];&%N9/UR;6%S
M_6YD82!B96QI<G1I;&UE;6G^+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z-C<U(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,P"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C,*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D
M(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")'97)E:V5N("<E<R<@
M5D93('EA</UL86YD_7)M87/];F1A(&)E;&ER=&EL;65M:?XN(@H*(SH@9G)A
M;65W;W)K+U5T:6PO571I;"YP:'`Z-S@Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R(")'97)E:V5N("<E<R<@>6%P_6QA;F3]<FUA
M9&$@8F5L:7)T:6QM96UI_BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E
M;F1E<F5R+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@
M(D=E<F5K96X@06QA;B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E
M;F1E<F5R+G!H<#HS,C`@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P
M,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED
M(")297-E="(*;7-G<W1R(")496UI>FQE(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z-#8*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@
M(E!A<F]L87G]('/]9OUR;&$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R(")0
M87)O;&%N_7K]('/]9OUR;&%Y_6XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3,P"B,L(&9U>GIY"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T
M<B`BWFG^:VEN($%Y(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN
M+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C8*;7-G:60@
M(E)E<W5L=',B"FUS9W-T<B`B4V]N=>=L87(B"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*
M;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(E-EYV5N96ML97)E
M($3V;OQN(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"B,L
M(&9U>GIY"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(E!A
M<F]L87G]('/]9OUR;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N
M(@IM<V=S='(@(E)E=6YI;VXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#
M;VYF:6=U<F%T:6]N(@IM<V=S='(@(EEA</UL86YD_7)M87G]($=E<FD@1/9N
M9/QR(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,@IM<V=I9"`B4FEC
M:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(EIE;F=I;B!-971I;B!$
M_'IE;FQE>6EC:7-I(%-EYV5N96ML97)I(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@(D)I;&UE8V5L97(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(E-A\"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,C$*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G
M<W1R(")38?`@8F'^;/UK(&)I;&=I<VDB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3$W"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`B1&_P
M<G4@9&7P97)L97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN
M+B(*;7-G<W1R(")385]T_7(@UGIE;&QI:VQE<FDN+BXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE
M(@IM<V=S='(@(D?V<F5V(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI
M82(*;7-G<W1R(")2;VUA;GEA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(R-0IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R
M("(Q.#`@9&5R96-E(&3V;F3\<B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,C(*;7-G:60@(E)O=&%T92!,969T(@IM<V=S
M='(@(E-O;&$@1/9N9/QR(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(R.`IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@
M(E-A\&$@1/9N9/QR(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS
M9W-T<B`B4V%T_7(@UGIE;&QI:VQE<FDB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O
M<&5R=&EE<R(*;7-G<W1R(")3873]<B#V>F5L;&EK;&5R:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2
M;W=S.B(*;7-G<W1R(")3873]<FQA<CHB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"FUS9VED(")2=6QE<R(*
M;7-G<W1R("+':7IG:6QE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`BQVEZ
M9VEL97(@=/QM('-A=/UR('9E(&MO;&]N;&%R(&%R87/];F1A(&)E;&ER96-E
M:W1I<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@
M8V]L=6UN<R!O;FQY(@IM<V=S='(@(L=I>F=I;&5R('-A9&5C92!K;VQO;FQA
M<B!A<F%S_6YD82!B96QI<F5C96MT:7(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R("+':7IG:6QE
M<B!S861E8V4@<V%T_7)L87(@87)A<_UN9&$@8F5L:7)E8V5K=&ER(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$R,`IM<V=I9"`B4G5N(@IM<V=S='(@(L=A
M;/W^=/UR(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T
M:6]N(@IM<V=S='(@(E)U<WEA($9E9&5R87-Y;VYU(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@(E)U86YD82(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y
M<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B4R]-24U%(-YI9G)E;&5M
M92#=;7IA<_TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@
M(E,O34E-12!I;&4@WFEF<F5L96YM:?X@W6QE=&DB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-A<VPN<&AP.C@Q"FUS9VED(")305-,(&%U=&AE;G1I8V%T
M:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E-!4TP@9&_P<G5L86UA
M<_T@;65V8W5T(&1E\&EL+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HU,#0*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`B4TU3($UE<V%J
M;&'^;6$B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3
M:&5L;"(*;7-G<W1R(")344P@2V%B=?!U(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S(X,PIM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@
M;&]O:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#,Q"FUS9VED(")34T@B"FUS9W-T<B`B4U-((@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R(")"0=Y!4DE,22(*"B,Z(&QI
M8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R(")37U%,
M($MA8G7P=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(D-T<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R(")386EN="!(96QE;F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*
M;7-G<W1R(")386EN="!+:71T<R!V92!.979I<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM
M<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B4V%I;G0@3'5C:6$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM
M<V=S='(@(E-A:6YT(%!I97)R92!V92!-:7%U96QO;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM
M<V=S='(@(E-A:6YT(%9I;F-E;G0@=F4@1W)E;F%D:6YE<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A
M;64@9G)A;64@*%]S96QF*2(*;7-G<W1R(")!>6[](.=E<N=E=F4@*&ME;E]D
M:7-I*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(E-A
M;6]A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R
M(")386X@36%R:6YO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@
M86YD(%!R:6YC:7!E(@IM<V=S='(@(E-A;R!4;VUE('9E(%!R:6YC:7!E(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T
M96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(E5Y9'4@4V'P;&%Y_6/](@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(E-U=61I
M($%R86)I<W1A;B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY
M.`IM<V=I9"`B4V%V92(*;7-G<W1R(")+87ED970B"@HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R(")+87ED970@)7,B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3879E("5S(@IM<V=S='(@(DMA>61E="`E<R(*"B,Z('1E;7!L871E
M<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R
M(")39>=E;F5K;&5R:2!+87ED970B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,38W"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N
M(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B
M"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*(D]L=?YT=7)U;&%N('EA</UL86YD
M_7)M87G](%!(4"!B971I\&D@;VQA<F%K('-U;G5C=6YU;B!G9>=I8VD@9&EZ
M:6YI;F4@(@HB:V%Y9&5T+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(B5S('EA</UL86YD_7)M87/](&MA>61E9&EL9&DN(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<
M(B5S7"(N(@IM<V=S='(@(D%Y87(@9_QN8V5L;&5M92!B971I\&D@:V%Y9&5D
M:6QD:3H@)R5S)RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT.0HC+"!F=7IZ>0IM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS
M(@IM<V=S='(@(EEA;/UT_6QM_?X@9_9K(&?\<OQL=/QL_"!F_7)T_6YA(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM
M<V=S='(@(D)I;&EM(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI
M;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@
M(E-E87)C:"(*;7-G<W1R(")!<F%M82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS,C`*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(D%R
M86UA($UO=&]R;&%R_2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y
M-S,*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R(")$;W-Y86QA<OT@4V7G
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X
M-`IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")":7(@=&%R:6@@<V7G
M:6XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B
M4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(D5K;&5M96L@:>=I;B!B
M:7(@9W)U<"!S9>=I;B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R(")996YI('-A
M:&EB:2!S9>=I;B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV
M,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(D)I<B!S=6YU8W4@
M<V7G:6XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I
M9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B16ML96UE:R!IYVEN
M(&)I<B!K=6QL86[]8_T@<V7G:6XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-C<W"B,L(&9U>GIY"FUS9VED(")396QE8W0@
M86QL(@IM<V=S='(@(D1O<WEA;&%R_2!39><B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-C8S"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N
M96YT<RXB"FUS9W-T<B`B0OQT_&X@=&%R:6@@8FEL9?YE;FQE<FEN:2!S9>=I
M;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX
M-S,*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B0FER(&YE<VYE
M('-EYVEN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C8W.`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B
M665N:2!S86AI8FD@<V7G:6XB"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z
M,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F
M<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*
M(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B+=
M<W1E9&GP;FEZ(&MA<F%K=&5R;&5R:2!A_F'P_61A:VD@:W5T=6QA<F1A;B!S
M9>=I;BX@1&%H82!S;VYR82!M971I;B`B"B)A;&%N_6YD86X@:V]P>6%L87G]
M<"!Y87#]_G3]<F%B:6QI<G-I;FEZ+B(*"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*
M;7-G<W1R(")487)I:"!S_6[]<FQA>?UC_7/];OT@<V7G_6XZ(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T
M92!F;W)M870Z(@IM<V=S='(@(E1A<FEH(&)IYVEM:6YI('-EYVEN.B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@
M(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G
M<W1R(")$9?!I_G1I<FUE:R!I<W1E9&GP:6YI>B!K:6UL:?!I('-EYVEN.B(*
M"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED(")396QE8W0@
M=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R(")386%T('/];OUR;&%Y_6/]
M<_UN_2!S9>=I;CHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM
M<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B4V%A="!B
M:>=I;6EN:2!S9>=I;CHB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T
M<B`B1?YL9?YE;B!I:VD@86QA;OT@<V7G:6XN(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,P-@IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE
M+B(*;7-G<W1R(")296YK(&3\>F5N:6YI>FD@<V7G:6XN(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(T.`IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E.B(*;7-G<W1R(")497)C:6@@971T:?!I;FEZ(&1I;&D@
M<V7G:6XZ(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*
M;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B4V]R=6X@4F%P
M;W)U($?V;F1E<B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#,Y"FUS9VED(")396YD(%--4R(*;7-G<W1R(")335,@1_9N
M9&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R(")3
M96YE9V%L(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,38*;7-G:60@(E-E
M;G-O<CH@(@IM<V=S='(@(D%L9_UL87G]8_TZ(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*
M;7-G<W1R(")%>6S\;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T
M<B`B4_UR8FES=&%N('9E($UO;G1E;F5G<F\B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*
M;7-G<W1R(")397)I($YU;6%R87/](@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$V,0HC+"!F=7IZ>0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O
M;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B2&%V82!R87!O<G4@]F)E
M\&D@:W5L;&%N_6QA8FEL:7(@9&7P:6PN(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C(W"B,L(&9U>GIY"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@
M(MUZ:6X@6?9N971I;6DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E
M9"XB"FUS9W-T<B`B3W1U<G5M(&MI;6QI\&EN:6X@<_QR97-I(&1O;&1U+B(*
M"B,Z(&QI8B]A<&DN<&AP.C$T-0HC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;G,B
M"FUS9W-T<B`B7TAA:VQA<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S,30*;7-G:60@(E-E="(*;7-G<W1R(")"96QI<G0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W
M('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E
M="!I="XB"FUS9W-T<B`B(@HB4&%R;VQA;OUZ_6[]('5N=71U<G-A;OUZ('/]
M9OUR;&%M86[]>F$@:7II;B!V97)E8V5K('-EYV5N96ML97)I(&)E;&ER=&EN
M+B`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(")3970@
M=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O
M;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B56QA_FUA:R!I<W1E\&EN:7H@=7IA
M:W1A:VD@<W5N=6-U;&%R_2!B96QI<FQE>6EN+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX-`IM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U
M86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R(")497)C
M:6@@971T:?!I;FEZ(&1I;"P@<V%A="!D:6QI;6D@=F4@=&%R:6@@<V7G96YE
M:VQE<FEN:2!B96QI<FQE>6EN+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY.`IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@
M8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D
M:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*(D)A_FQA;F?]YR!U>6=U;&%M
M86[]>OTL(')E;FL@9/QZ96YI;FEZ:2P@<V%Y9F$@=&%Z96QE;64L('9E(&1I
M\&5R(&?V<OQN=/P@(@HB<V7G96YE:VQE<FEN:2!B96QI<FQE>6EN+B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*;7-G:60@(E-E='5P(@IM<V=S
M='(@(D%Y87)L87(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N
M:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L
M92(*;7-G<W1R(")+=7)U;'5M(&?\;F-E;&QE;64@8F5T:6ML97)I(&MU;&QA
M;OUL86)I;&ER(&1U<G5M9&$N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$X-@IM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@
M=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B1&7P:?YT:7)G92!I;&4@
M8FER9&5N(&9A>FQA('EE<B!M_&UK_&XZ("(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G
M:60@(E-E>6-H96QL97,B"FUS9W-T<B`B4V5Y_F5L(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0Y-@IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B
M06S]_B!V97)I_B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C0S"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(DO]<V$@UGIE="(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#8*;7-G:60@(E-H;W5L9"!A
M8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R
M("+';_!U(&)A\&QA;G3](&GG:6X@97)I_FEM(&%N86AT87+]('1A;OUM;&%N
M<_UN(&W]/R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(S('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(D?V<W1E<B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@
M8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T
M960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB2&%L96X@:V%Y_71L
M_2!O;&%N('EA</UL86YD_7)M82!I;&4@>65N:2!Y87)A=/UL86X@>6%P_6QA
M;F3]<FUA(&%R87/];F1A:VD@(@HB9F%R:VQA<OT@9_9S=&5R+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3`*;7-G:60@(E-H;W<@;&%S="!L;V=I
M;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B1VER:?YT92!E;B!S
M;VX@9VER:?X@=&%R:6AI(&?V<W1E<FEL<VEN(&UI/R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$W-C4*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME
M97`@;W)I9VEN86PB"FUS9W-T<B`BUGIG_&X@;VQA;OT@<V%K;&%M82!S9>=E
M;F7P:6YI(&?V<W1E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,3,*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(E-EYVEC:7EI(&?V<W1E
M<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C8*;7-G:60@(E-H;W<@
M=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`BQVEZ96QG92!I
M_FQE;6QE<FD@;65N_"#G=6)U\'5N9&$@9_9S=&5R:6QS:6X@;6D_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R("(E<R!-
M96[\<_P@<V]L9&$@9_9S=&5R:6QS:6X@;6D_(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3
M:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@
M(E1A8FQO($C\8W)E(-9Z96QL:6ML97)I($MU='5S=6YU(&?V<W1E<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B
M"FUS9W-T<B`B5&%B;&\@UGIE;&QI:VQE<FD@2W5T=7-U;G4@9_9S=&5R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B5&%B;&\@4V%T_7(@UGIE;&QI:VQE<FD@2W5T=7-U
M;G4@9_9S=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P
M97)T:65S(&1I86QO9R(*;7-G<W1R(")']G+\;G3\(/9Z96QL:6ML97)I(&MU
M='5S=6YU(&?V<W1E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W
M-C,*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(EG\:VQE;65Y:2!G]G-T
M97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M,`IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R(")38?!A;F%K(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-H;W=E
M<G,@16%R;'DB"FUS9W-T<B`B17)K96X@4V%A=&QE<F1E(%-A\&%N86LB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I
M9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(D=EYR!386%T;&5R9&4@4V'P86YA
M:R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S
M"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("+'979R
M961E(%-A\&%N86LB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HT.#`*;7-G:60@(E-H<FEN:R(*;7-G<W1R(")+_.?\;'0B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW-S0@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#,V"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.CDR,B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HY.#0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,3`T-R!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ
M,#@W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q,38@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$T.0IM<V=I9"`B
M4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T
M:&4@=V%Y(&9I<G-T(@IM<V=S='(@(MUL:R!O;&%R86L@:V]M_G4@]O!E;&5R
M(&O\Y_QL='/\;B!Y861A('1A_OUN<_UN(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I
M9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(E-I97)R82!,96]N92(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C4*;7-G:60@(E-I9VX@
M=7`B"FUS9W-T<B`BW'EE(&]L(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R("+=;7IA
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3$*;7-G
M:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`BW6UZ82!!;&=O<FET
M;6%S_2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R
M(")3:6YG87!U<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@W(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.3,P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*
M;7-G:60@(E-I>F4B"FUS9W-T<B`B0F]Y=70B"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN
M=&5N86YC92(*;7-G<W1R(")"86O];?T@071L82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*
M;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(E-L;W9A:WEA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-0IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B4VQO=F5N>6$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B
M4VYO=R(*;7-G<W1R(")+87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B
M2V%R(%-A\&%N8?#](@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-38*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R(")+87(@
M4V'P86YA:VQA<OTB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@
M(D5R:V5N(%-A871L97)D92!+87(@4V'P86YA:VQA<OTB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3
M:&]W97)S($QA=&4B"FUS9W-T<B`B1V7G(%-A871L97)D92!+87(@4V'P86YA
M:VQA<OTB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`IM<V=I9"`B4VYO
M=R!D97!T:#H@(@IM<V=S='(@(DMA<B!$97)I;FQI\&DZ("(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C@R"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@
M=V%T97(Z("(*;7-G<W1R(")98?!A;B!K87+];B!S=2!E_FET:3H@(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(E-O
M;&]M;VX@061A;&%R_2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B
M"FUS9W-T<B`B4V]M86QI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P
M"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(MYA<FO];&%R("8@WFEI
M<FQE<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C8*;7-G:60@
M(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(E/]<F%L86UA(&3\>F5N
M:2!S9>=I;6DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G
M<W1R(")+87EN86L@861R97-I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U
M=&@@069R:6-A(@IM<V=S='(@(D?\;F5Y($%F<FEK82(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X
M-3DM,RDB"FUS9W-T<B`B1_QN97D@079R=7!A("A)4T\M.#@U.2TS*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H
M(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B1_QN97D@1V5O<F=I82!V92!'
M_&YE>2!386YD=VEC:"!!9&%L87+](@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M
M:7-P:&5R92(*;7-G<W1R(")'_&YE>2!987+];6O\<F4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A
M8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R(")":71I_FEK(&C\
M8W)E;&5R(&%R87/];F1A:VD@8F_^;'5K(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E
M96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B2/QC<F5D
M96MI('/];OUR('9E(&GG97)I:R!A<F%S_6YD86MI(&)O_FQU:R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q-0IM<V=I9"`B4W!A8V5R(@IM<V=S
M='(@(D)O_FQU:R!!>6%R;&%Y_6/](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM
M<V=S='(@(D%R86S]:R!B_7)A:VUA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A
M;F0@<&%D9&EN9R(*;7-G<W1R(")!<F%L_6L@8OUR86MM82!V92!Y87-T_6ML
M86UA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S='(@(MUS<&%N
M>6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@(E-P
M86TB"FUS9W-T<B`BW7-T96YM97EE;B#=;&5T:2(*"B,Z('-E<G9I8V5S+VME
M>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B
M"FUS9W-T<B`BUGIE;"!+87)A:W1E<B!':7)I_FDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED(")3
M<&QI="!C96QL(@IM<V=S='(@(DC\8W)E>6D@8O9L(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B
M4W!L:70@8V]L=6UN(@IM<V=S='(@(DMO;&]N=2!B]FPB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED
M(")3<&QI="!R;W<B"FUS9W-T<B`B4V%T_7+](&+V;"(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV,0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(E-P;W)L
M87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R(")3
M<FD@3&%N:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S,@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HW-`IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T
M<B`B4W1A;F1A<G0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G
M:60@(E-T87(@5')E:R(*;7-G<W1R(")5>F%Y(%EO;'4B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,#D*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B0F'^;&%N9_WG('G]
M;/TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM
M<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B17EA;&5T('9E>6$@
MW6PB"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM
M<V=I9"`B4W1A='5S(@IM<V=S='(@(D1U<G5M(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@Q-0IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T
M<B`B1&5P;VQA;6$@8FGG:6UI(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-S(*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@
M(E-O:V%K($%D<F5S:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B
MW'-T_"#G:7IG:6QI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S
M,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B1&EZ9VD@;&ES=&5S:2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S,*;7-G:60@(E-T<FEP
M(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(D%D<F5S=&5N(&%L
M86X@863];OT@Y_UK87)T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS
M9W-T<B`B4VET:6P@6T-34UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R(")0>G(B"@HC
M.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R(")!;'1D:7II;B`G)7,G(&)U;'5N86UA9/TN(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C
M="(*;7-G<W1R(")+;VYU(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,R(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PIM<V=I
M9"`B4W5B;6ET(@IM<V=S='(@(D?V;F1E<B(*"B,Z('-I9VYU<"YP:'`Z-#D*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U
M97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@
M;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E
M9"XB"FUS9W-T<B`B(@HB)R5S)R!I;B!S:7-T96UE(&5K;&5N;65S:2!I<W1E
M\&EN:7H@9_9N9&5R:6QD:2X@W7-T9?!I;FEZ(&]N87EL86YA(&MA9&%R("(*
M(F=I<FG^('EA<&%M87IS_6[]>BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T
M<B`B06QT<VEM9V4B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`T"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T
M871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B0F'^87+](@H*
M(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB
M"FUS9W-T<B`B)R5S)R!B8?YA<OUY;&$@<VES=&5M92!E:VQE;F1I+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@
M9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(G)7,G(&GG:6X@;VQA;B!V97)I
M(&)A_F%R_7EL82!S:7-T96UD96X@=&5M:7IL96YM:?YT:7(N(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E
M9"!<(B5S7"(N(@IM<V=S='(@(D)A_F%R_7EL82!S:6QI;F1I("<E<R<N(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES
M=&5M+B(*;7-G<W1R(")3:7-T96UD96X@8F'^87+]>6QA('-I;&EN9&D@)R5S
M)RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C
M97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E
M92!C:&%N9V5S+B(*;7-G<W1R("(B"B)987#];&%N9/UR;6$@8F'^87+]>6QA
M(&=E<FD@9/9N9/QR_&QD_"X@1&7P:?YI:VQI:VQE<FD@9_9R;65K(&GG:6X@
M>65N:61E;B`B"B)Y_&ML97EI;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E
M<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M665D96L@>6%P_6QA;F3]<FUA(&)A_F%R_7EL82!K87ED961I;&1I+B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO
M;B!F:6QE("5S+B(*;7-G<W1R(")9961E:R!Y87#];&%N9/UR;6$@9&]S>6%S
M_2`E<R!B8?YA<OUY;&$@:V%Y9&5D:6QD:2XB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R("(G)7,G(&)A_F%R_7EL82!G_&YC
M96QL96YD:2(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R("(E<R!B8?YA<OUY;&$@>6%Z_6QD
M_2XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R(")3=61A
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`BUGIE="(*"B,Z(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T
M<B`B1_QN($1O\'5M=2(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM
M<V=I9"`B4W5N(%-E="(*;7-G<W1R(")'_&X@8F%T_6W](@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-U;FYY
M(@IM<V=S='(@(D?\;F7^;&DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C$V"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(D?\;B!D;_!U;74B
M"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES
M92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(D?\;B!D
M;_!U;74O1_QN(&)A=/UM_2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,34*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R(")'_&X@9&_P=6UU
M.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Y"FUS9VED
M(")3=6YS970B"FUS9W-T<B`B1_QN(&)A=/UM_2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,3@*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@
M(D?\;B!B873];?TZ("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(MQS
M='-I;6=E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W.`IM<V=I
M9"`B4W5P<&]R="(*;7-G<W1R(")$97-T96LB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS
M9VED(")3=7)I;F%M92(*;7-G<W1R(")3=7)I;F%M(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*;7-G:60@(E-U<FYA;64B"FUS
M9W-T<B`B4V]Y863](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@
M86YD($IA;B!-87EE;B(*;7-G<W1R(")3=F%L8F%R9"!V92!*86X@36%Y96XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B4W9A
M>FEL86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@
M(MUS=F7G(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S
M='(@(MUS=FGG<F4B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX
M-@HC+"!F=7IZ>0IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R(")3
M:6QM97EI;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#(*;7-G:60@
M(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW
M;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R
M;7,B"FUS9W-T<B`B07)A;6$@=&5R:6UL97)I;F1E('/V>F1I>FEM(&AA=&%S
M_2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC
M(@IM<V=S='(@(E-U<FEY92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")4+5-T;W)M(@IM<V=S='(@(D?V:R!G
M_'+\;'3\;/P@9OUR=/UN82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV,@IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B1_9K(&?\<OQL=/QL_"!F
M_7)T_6YA;&%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S
M='(@(D5R:V5N(%-A871L97)D92!38?!A;F%K(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82]T<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B
M5%-6(&1O<WEA<_TB"@HC.B!F<F%M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S
M-`IM<V=I9"`B5&%B;&4B"FUS9W-T<B`BQVEZ96QG92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@
M(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`BQTEZ96QG92#6>F5L;&EK;&5R
M:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z
M-3<*(RP@9G5Z>GD*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R("+':7IE;&=E
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R("+':7IE
M;&=E(/9Z96QL:6ML97)I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S0@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B
M5&%I=V%N(@IM<V=S='(@(E1A>79A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F
M($-H:6YA(@IM<V=S='(@(E1A>79A;BP@QVEN(&5Y86QE=&DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(E1A8VEK:7-T86XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(E1A;GIA;GEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G
M<W1R(")(961E9CHB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3DV(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#<*;7-G:60@(E1A<VMS(@IM<V=S
M='(@(D?V<F5V;&5R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-S,*;7-G:60@(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B5&5L
M969O;B!.=6UA<F%S_2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP"FUS
M9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")3;VX@<V%A="!I
MYVEN('/]8V%K;/UK.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-`IM
M<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B4_UC86ML_6LB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(S"FUS9VED(")496UP97)A='5R
M93H@(@IM<V=S='(@(E/]8V%K;/UK.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,CDS"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T
M=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HV.#<*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B<E<R<@=&%S;&'P_2!B=6QU;F%M863]+B(*"B,Z(&%D
M;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!9&UI;FES
M=')A=&EO;B(*;7-G<W1R(")487-L86L@6?9N971I;6DB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S,S8*;7-G:60@(E1E>'0B"FUS9W-T<B`B365T:6XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S<U"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B
M4V%D96-E($UE=&EN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R
M(")-971I;B!H:7IA;&%M87/](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R(")-
M971N:6X@W'-T_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(E!R_B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G
M<W1R(")486D@*%1)4RTV,C`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA
M:6QA;F0B"FUS9W-T<B`B5&%Y;&%N9"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDX.`IM<V=I9"`B5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES
M=&5M+B(*;7-G<W1R(")3:7-T96UI(&MU;&QA;OUD_?#];OUZ(&GG:6X@=&7^
M96MK_'(@961E<FEZ+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#(P"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R(")&5%`@=7IA;G3]<_T@:W5L;&%N_6QA8FEL:7(@9'5R=6UD
M82!D9?!I;"XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I
M;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(DAO
M<F1E+TMO;&%B(&+\=/QN;&7^=&ER;64@;6]T;W)U(&1E<W1E:VQE;65M96MT
M961I<CH@7"(E<UPB(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O
M:RYP:'`Z,3(Y,@HC+"!F=7IZ>0IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD
M(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B6?QK;&5N96X@9&]S>6$@
M:V%Y9&5D:6QE;65D:2XB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A
M9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B0F%K_6TZ.B!S_6[]9B!B8?YA<OUY
M;&$@>?QK;&5N96UE9&DN(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC
M:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S
M960N($5X:71I;F<N(@IM<V=S='(@(MYEYV5N96ML97(@<&5N8V5R97-I(&MA
M<&%N9/TNQ_UK_?X@>6%P_6S]>6]R+B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C
M;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y
M;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*(D7P
M97(@:7II;FQE<FD@:W5L;&%N;6%K(&ES=&EY;W)S86[]>B!Y]FYE=&EC:6YI
M>FEN(-UZ:6X@<VES=&5M:6YI("(*(GEA</UL86YD_7)M87/](&=E<F5K;65K
M=&5D:7(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS
M9W-T<B`B4V%D96-E(&%L="!T87)A9B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N
M=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@
M;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@
M(B(*(MUL971I_FEM(&YO:W1A<_UN_6X@240G<VD@8F5L:7)L96YE;65D:2P@
M8F_^(&+]<F%K_6QM_?X@=F5Y82!V97)I('1A8F%N_6YD82`B"B)B=6QU;F%M
M863]+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E
M9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`BW6QE=&G^:6T@;F]K
M=&%S_2!B8?YA<OUY;&$@861R97,@9&5F=&5R:6YI>F4@96ML96YD:2XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38Y"FUS9VED("(B
M"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"B+'
M_6MA<G3];&W]_B!01U`@:6UZ82#V8F7P:2!I;7IA;&%N;?W^(&EL971I;FEN
M(&1O\')U;'7P=6YU;B!S8?!L86YM87/](&GG:6X@(@HB9V5R96MM96MT961I
M<BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A
M<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U
M;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"B)$8?#]=/UM(&QI
M<W1E<VD@240G<VD@8F5L:7)L96YE;65D:2P@8F_^(&+]<F%K_6QM_?X@=F5Y
M82!V97)I('1A8F%N_6YD82`B"B)B=6QU;F%M863]+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4
M:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S
M='(@(D1A\/UT_6T@;&ES=&5S:2!B96QI<FQE;F5M961I+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$S"FUS9VED(")4:&4@96YC<GEP=&EO
M;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*
M;7-G<W1R("+>:69R96QE;64@]GIE;&QI:VQE<FD@9_QV96YL:2!B:7(@=V5B
M(&)A\&QA;G3]<_T@9V5R96MT:7)M96MT961I<BXB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$W-2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C4Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(B5S(&1O<WEA<_T@)7,@
M87EA<OT@:>=E<FUE;&ED:7(N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-C@@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M
M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B)7,@9&]S>6%S_2`E<R!A>6%R;&%R
M_2!IYV5R;65L:61I<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR,3D*;7-G:60@(E1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@
M:71S96QF+B(*;7-G<W1R(")$;W-Y82!K96YD:2#\>F5R:6YE(&MO<'EA;&%N
M86UA>BXB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.#`*;7-G:60@
M(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")$;W-Y82!V
M97)I(&GG97)M:7EO<BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@
M:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G
M<W1R(")486MI<"!E9&5N;&5R(&)U(&EL971I+W)F8S@R,B!I;&5T:7-I(&GG
M:6X@8F'^;/UK(&)I;&=I;&5R:61I<BXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S
M8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN
M=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@
M=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP
M97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U
M;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*
M(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T
M:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT
M)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N
M960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@
M=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*(D'^86UA
M9/WP_6W]>B!T87)A>?UC_2!H871A;&%R_2!S96)E8FEY;&4@=&%M(&5K<F%N
M(&MI<&EN:6X@26YT97)N970@(@HB17AP;&]R97(G;&$@8FER;&EK=&4@<V]R
M=6X@Y_UK87)D_?#](&)I;&EN;65K=&5D:7(N($%N;&%M<_UZ(&?V<OQN=/QL
M97)L92P@(@HBYV%L_?YM87EA;B!M971I;B!D_'IE;FQE>6EC:2!I_FQE<FEY
M;&4@=F4O=F5Y82!T87)A>?UC_6[];B!R87-T9V5L92`B"B+G]FMM97-I>6QE
M(&MA<O[];&'^86)I;&ER<VEN:7HN($7P97(@<VES=&5M:6YI>B!7:6YD;W=S
M(#EX(&ES92!Y_&MS96L@(@HB:6AT:6UA;"`G1V5N97)A;"!0<F]T96-T:6]N
M($9A=6QT)R!H871A<_T@86S]<"!S:7-T96UI('EE;FED96X@8F'^;&%T;6%N
M_7H@(@HB9V5R96ME8V5K+EQ<;EQ<;D)U(&)I<B!U>6%R_7ED_2X@1?!E<B!H
M86QA('1A;2!E:W)A;B!M971I;B!D_'IE;FQE>6EC:7-I;FD@(@HB9&5N96UE
M:R!I<W1I>6]R<V%N_7H@179E="=I('3]:VQA>?UN+B(*"B,Z('-E<G9I8V5S
M+W!R969S+G!H<#HY,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I
M='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(DMI;6QI:R!<
M(B5S7"(@<VEL:6YD:2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I
M9&4@;VYL>2(*;7-G<W1R(")3861E8V4@<V]L('1A<F%F(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C
M871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H
M92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B0W)Y<'1?<&=P.CH@<_UN
M_6;];F$@1VYU4$<@:6MI;&ES:6YI;B!K;VYU;74@=F5R:6QM96L@>F]R=6YD
M863]<BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`Q"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@
M=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N
M7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA
M<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@HB)7,@=&%R
M:6AI;F1E("5S(&4@9_9N9&5R:6QE;B!<(B5S7"(@:V]N=6QU(&EL971I(&?V
M<OQN=/QL96YD:2Y<;B(*(D)U(&EL971I;FEN(&]K=6YD=?!U('9E>6$@86YL
M8?[];&3]\/UN_2!G87)A;G1I;&5M96UE:W1E9&ER+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X-S<*;7-G:60@(E1H92!N86UE('1O('5S92!W
M:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R(")/;'7^
M='5R('!E;F-E<F5S:6YE(&)A\&QA;OUR:V5N(&MU;&QA;OUL86-A:R!I<VEM
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Q"B,L(&9U>GIY
M"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N
M(@IM<V=S='(@(D)U(&%L86X@9V7G97)L:2!B:7(@;G5M87)A(&]L;6%L_63]
M<BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S$*
M;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE
M($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(DAO<F1E7T-R
M>7!T7W-I;64Z.B!S_6[]9OT@;W!E;G-S;"!B:7)I;6D@:>=I;B!G97)E:VUE
M:W1E9&ER+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDP"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C
M;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T
M:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"B)<(B5S
M7"(@=&5R8VEH:2!V97)I<VD@:7II;B!V97)I;&5N(&5N('G\:W-E:R!B;WEU
M='4@9V7G=&GP:2!IYVEN("(*(FMA>61E9&EL96UE;65K=&5D:7(N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W
M('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES
M=&5M+B(*;7-G<W1R("(B"B)"=2!V97)I('EA<'/];OTH)7,I(&?V<W1E<FUE
M:R!IYVEN(&MU;&QA;OUL86X@<')O9W)A;2!S:7-T96UD92`B"B)B=6QU;FUA
M;6%K=&%D_7(N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#4T
M"FUS9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L
M92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H
M="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(E-A9&5C92!S;VP@=F4@
M<V'P('1A<F%F;&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED
M92!O;FQY(@IM<V=S='(@(E-A9&5C92!S8?`@=&%R868B"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HT-#8*;7-G:60@(E1H92!S97!A<F%T;W(@
M;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS
M9W-T<B`B7"(E<UPB('-U;G5C=7-U('-I;&EN9&DN(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(EPB)7-<
M(B!S=6YU8W5S=2!K87ED961I;&1I+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R
M("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(B5S(&GG:6X@;VQA;B#\
M>65L:6L@:7-T9?!I('-I;&EN9&DN(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z,S,P"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D
M;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B0F5L:7)T:6QE;B!S873]<B!B=6QU
M;FUA;6%K=&%D_7(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ
M-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB
M)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B1V7G:6-I(&1O<WEA(%PB
M)7-<(B!B=6QU;FUA;6%K=&%D_7(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S,Q,0IM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO
M="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G
M<W1R(")3861E8V4@_'-T('9E(&%L="!T87)A9FQA<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@
M(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(E-A9&5C92#\<W0@=&%R868B
M"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U
M<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P
M+B(*;7-G<W1R(")":7(@]FYC96MI(&%D_6T@<_UR87/];F1A('G\:VQE;F5N
M('9E<FD@:V%Y8F5D:6QD:2XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S
M=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*;7-G
M:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS
M9W-T<B`B6?QK;&5N96X@9&]S>6$@:V%Y9&5D:6QE;65D:2XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C4V"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M,34@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q.0IM<V=I9"`B5&AE
M('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(G=E871H97(N8V]M(&MU;&QA;OUL86)I;&ER(&1E\&EL+B(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M(")496UA(&1I>FEN:2`G)7,G(&)U;'5N86UA9/TN(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N;R!O
M<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`B2&GG8FER('-EYV5N96L@;65V
M8W5T(&1E\&EL+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C,T,@IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E
M(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(DUE=&YE(&?V;?QL_"!O;&%R
M86L@9_9S=&5R:6QE8FEL96-E:R!K_7/];2!Y;VLB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO
M=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT
M97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"B)"=2!A;&%N9&$@YV]K(&9A
M>FQA(&MA<F%K=&5R('9A<BXE<R!T86YE(&MA<F%K=&5R(&=I<F1I;FEZ.R`E
M<R!T86YE9&5N(&%Z("(*(F=I<FUE;FEZ(&=E<F5K:7)D:2XB"@HC.B!S:6=N
M=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@
M=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B)R5S)R!S:7-T96UE(&5K;&5N
M:7)K96X@8FER('-O<G5N(&]L=?YT=3H@)7,B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T
M:&4@<WES=&5M.B`B"FUS9W-T<B`B)R5S)R!K=6QL86[]8_UN_6X@=F5R:6QE
M<FEN:6X@<VES=&5M9&5N('-I;&EN;65S:6YD92!S;W)U;B!V87(Z("(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T
M:&4@<WES=&5M.B`B"FUS9W-T<B`B)R5S)R!K=6QL86[]8_US_6[]('-I<W1E
M;61E;B#G_6MA<G3];&UA<_UN9&$@<V]R=6X@=F%R.B`B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ-3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R("(G
M)7,G(&?\;F-E;&QE;FER:V5N('-O<G5N(&]L=?YT=3H@)7,B"@HC.B!F<F%M
M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R(")$;W-Y82`H:V%R_OUD
M86XI('G\:VQE;FUE<VEN9&4@<V]R=6X@=F%R.B`E<R!Y_&ML96YE;65D:2XB
M"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X
M:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HB
M1&]S>6$@>?QK;&5N:7)K96X@8FER('-O<G5N(&]L=?YT=3H@)7,@96X@8OQY
M_&L@:7II;B!V97)I;&5N(&)O>75T=&%N("@E9"`B"B)B>71E*2!D86AA(&+\
M>?QK+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y,0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY
M('5P;&]A9&5D+B(*;7-G<W1R(")$;W-Y82!Y_&ML96YI<FME;B!B:7(@<V]R
M=6X@;VQU_G1U.B`E<R!S861E8V4@:_US;6D@;VQA<F%K('G\:VQE;F1I+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S
M<V%G92!P87)T(@IM<V=S='(@(DEL971I;FEN(&)U(&O]<VW];OT@9_9R_&YT
M_&QE;FUE<VEN9&4@:&%T82!O;'7^='4N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R("+=;&5T
M:?YI;2!N;VMT87/];OUN('9E<FEL97)I("AIYV5R:2D@86MT87+];/UR:V5N
M(&AA=&$@;VQU_G1U+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H
M<#HS,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(FE#86QE;F1A<B!V97)I<VD@*&GG
M97)I*2!A:W1A<OUL_7)K96X@:&%T82!O;'7^='4N(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HX,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R
M(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@
M;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*(EEA</UL86YD
M_7)M82!F;W)M=6YD82!B:7(@:&%T82!V87(N($=E<F5K;&D@8FER(&%L86[]
M(&1O;&1U<FUA;?W^("(*(F]L86)I;&ER<VEN:7HN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*
M(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@
M861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA
M=&5R+B(*;7-G<W1R("(B"B)"96QI<G1I;&5N(&%D<F5S(&1E9G1E<FD@:?YL
M979I;FEN(&=E<N=E:VQE_G1I<FEL;65S:2!S_7)A<_UN9&$@<V]R=6X@(@HB
M;VQU_G1U+B!,_'1F96X@9&%H82!S;VYR82!T96MR87(@9&5N97EI;BXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T
M,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C
M;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S
M='(@(B(*(MUL971I_FEM(&YO:W1A<_UN_6X@87ER_6YT_6QA<OUN_2!G_&YC
M96QL97)K96X@:&%T82!O;'7^='4N($S\=&9E;B!D86AA("(*(G-O;G)A('1E
M:W)A<B!D96YE>6EN+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+B(*;7-G<W1R("(B"B)$8?#]=/UM(&QI<W1E<VEN:2!G_&YC
M96QL97)K96X@8FER(&AA=&$@;VQU_G1U+B!,_'1F96X@9&%H82!S;VYR82!T
M96MR87(@(@HB9&5N97EI;BXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E
M<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(D)U($E-
M05`@<W5N=6-U<W4@<&%Y;&'^_6QA;B!D:7II;FQE<FD@9&5S=&5K;&5M:7EO
M<BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C0X
M"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A
M<B!A<F-H:79E+B(*;7-G<W1R(")"=2!G9>=E<FQI(&)I<B!R87(@87+^:79I
M(&1E\&EL+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@>FEP(&9I;&4N(@IM<V=S='(@(D)U(&=EYV5R;&D@8FER('II<"!D;W-Y
M87/](&1E\&EL+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q-#4*
M;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@
M;G5M8F5R+B(*;7-G<W1R(")"=2!G9>=E<FQI(&)I<B!K87)T(&YU;6%R87/]
M(&1E\&EL+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T
M<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%14
M4"!!4$DB"FUS9W-T<B`B(@HB0G4@<_QR_&/\($-L:6-K871E;&P@*&AT='`Z
M+R]C;&EC:V%T96QL+F-O;2D@8?`@9V7G:61I(/QZ97)I;F1E;B!(5%10($%0
M22`B"B)K=6QL86YA<F%K(&UE<V%J(&%T;6%N_7IA(&EZ:6X@=F5R:7(N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S0*(RP@
M9G5Z>GD*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI
M("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)"
M=2!S_'+\8_P@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL*2!A\"!G9>=I
M9&D@_'IE<FEN9&5N($A45%`@05!)("(*(FMU;&QA;F%R86L@;65S86H@871M
M86[]>F$@:7II;B!V97)I<BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@
M86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M
M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@
M=&AE($A45%`@05!)(@IM<V=S='(@(B(*(D)U('/\<OQC_"!S;7,R96UA:6P@
M*&AT='`Z+R]S;7,R96UA:6PI(&'P(&=EYVED:2#\>F5R:6YD96X@2%144"!!
M4$D@(@HB:W5L;&%N87)A:R!M97-A:B!A=&UA;OUZ82!I>FEN('9E<FER+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N
M<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L
M>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E
M<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L
M>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"B)"=2!S_'+\8_P@
M4TU44"!Y;VQU>6QA(%9O9&%F;VYE($ET86QY(&'P(&=EYVED:2#\>F5R:6YD
M96XL('-A9&5C92!6;V1E9F]N92`B"B)N=6UA<F%L87+];F$@;65S86H@871M
M86[]>F$@:7II;B!V97)I<BX@5F]D969O;F4@271A;'D@*&AT='`Z+R]W=W<N
M,3DP+FET*2`B"B)E;&5K=')O;FEK('!O<W1A(&%D<F5S:2!G97)E:W1I<FUE
M:W1E9&ER+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDW."!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#4W"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$P.#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q-0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@R(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R-38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,SDX"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$U-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@S.0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34X(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(P,#4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R
M.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<X"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q-#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R
M,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$P(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(T-30*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C8U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#(X"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,P-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#$T(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,X,C(*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q
M=6ER960N(@IM<V=S='(@(D)U(&=E<F5K;&D@8FER(&%L86YD_7(N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R(")"=2!A;&%N
M('-A9&5C92!S87G](&GG97)M96QI9&ER+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T,3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(D)U(&%L86X@
M<V%D96-E('-A>?T@=F4@:6MI(&YO:W1A(/QS=/QS=&4@:?YA<F5T:2!IYV5R
M96)I;&ER+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30*;7-G
M:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N
M(@IM<V=S='(@(D)U(&%L86X@<V%D96-E('-E:VEZ;&EK('-A>?T@<VES=&5M
M:6YD96X@9&7P97)L92!IYV5R96)I;&ER+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O
M;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S
M='(@(D)U(&%L86X@=FER9_QL('9E>6$@8F_^;'5K;&$@87ER_6QM_?X@<V%Y
M_2!L:7-T92!O;&UA;/UD_7(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.3@Y"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB
M97(N(@IM<V=S='(@(D)U(&%L86X@9V7G97)L:2!B:7(@;G5M87)A(&]L;6%L
M_63]<BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V"FUS9VED
M("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@
M=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N
M(@IM<V=S='(@(D)U(&%L86X@4D="($AE>"!B:>=I;6EN9&4@8FER(')E;FL@
M:V]D=2!IYV5R;65L:61I<BP@]G)N96LZ("<C,3(S-&%F)R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A
M;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R(")"=2!F;W)M('IA=&5N
M(&G^;&5N9&DN(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B0G4@)7,N
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE
M8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I
M;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W
M87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N
M=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*(D)U(&)I<B!+;VQA8B!'
M<F]U<'=A<F4@;F5S;F5S:61I<BX@0G4@;F5S;F5Y:2!G]G)E8FEL;65K(&GG
M:6X@2V]L86(@(@HB1W)O=7!W87)E(&)IYVEM:6YI(&%N;&%Y86)I;&5N(&)I
M<B!E;&5K=')O;FEK('!O<W1A(&ES=&5M8VES:6YE(&=E<F5K('9A<BY"=2`B
M"B)E;&5K=')O;FEK(&ES=&5M8VD@;&ES=&5S:2!IYVEN("5S(&%D<F5S:6YE
M('7P<F%Y_6XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z-3DQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@
M=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO
M=7(@;W=N+B(*;7-G<W1R(")"=2!I;&5T:2!S:7II;B!K87)A:W1E<B!K_&UE
M;FEZ9&5N(&9A<FML_2!O;&%R86LH)7,I('EA>OUL;?W^=/UR+B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU
M;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B0G4@;G5M87)A
M(&5N(&%Z_6YD86X@8FER(&]L;6%L_63]<BXB"@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R
M(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R
M(")"=2!S=6YU8W4@>FEP('9E(&=Z:7`@9&]S>6%L87+];OT@8>=A;6%M86MT
M863]<BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP
M.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A
M=&5D+B(*;7-G<W1R(")3:7-T96UI;B!E=&MI;FQI\&D@:V%L9/UR_6QM_?YT
M_7(N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C0*;7-G
M:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B0G4@
M9&7P97(@8FER('-A>?T@;VQM86S]9/UR+B(*"B,Z('-E<G9I8V5S+VEM86=E
M<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@
M8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B0G4@
M<&5N8V5R92!39>=E;F5K;&5R('!E;F-E<F5S:6YD96X@YV'P<OUL;6%L_63]
M<BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M-`IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R(")']FL@9_QR_&QT_'/\(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-`IM<V=I9"`B5&EC:V5T<R(*
M;7-G<W1R(")":6QE=&QE<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(T,C@@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")4
M:6UE(@IM<V=S='(@(EIA;6%N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,X-@IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R("):86UA;B#=
M>FQE;64B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@
M9F]R;6%T(@IM<V=S='(@(EIA;6%N($)IYVEM:2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(U,SD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S
M='(@(EIA;6%N(%-EYVEM:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R
M+4QE<W1E(@IM<V=S='(@(E1I;6]R+4QE<W1E(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE
M+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B0F'^;/UK(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B
M5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R(")"8?YL_6L@*&'G_6ML86UA*3HB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U
M"FUS9VED(")4;R(*;7-G<W1R(")+:6UE(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T
M(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O
M<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T
M<B`B(@HBQV]K;'4@]O!E('-EYVEM:2!IYVEN+"!T_6ML87)K96X@0V]N=')O
M;"`H4$,I('9E>6$@0V]M;6%N9"`H36%C*2!T=?YU;F$@(@HB8F%S_6XN(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B5&]D
M87DB"FUS9W-T<B`B0G5G_&XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B
M"FUS9W-T<B`B2%1-3"!+87EN8?#];F$@1V7G:6XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y
M"FUS9VED(")4;V=O(@IM<V=S='(@(E1O9V\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS
M9VED(")4;VME;&%U(@IM<V=S='(@(E1O:V5L874B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S$S"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R
M(")987+];B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S='(@
M(E1O;F=A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`BW'-T(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B
M5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("+<<W0@QV5RYV5V92`HW%]S="DB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T
M:6]N<R(*;7-G<W1R("+'979I<FEL97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED
M(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(E1R:6YI9&%D('9E(%1O
M8F%G;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W.3`*;7-G:60@
M(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B1&_P<G4@=F5Y82!986YL_?XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS
M9VED(")4=2(*;7-G<W1R(")382(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U
M;FES:6$B"FUS9W-T<B`B5'5N=7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4
M=7)K97DB"FUS9W-T<B`B5/QR:VEY92(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3DR"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G<W1R(")4
M_')KYV4@*$E33RTX.#4Y+3DI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R
M:VUE;FES=&%N(@IM<V=S='(@(E3\<FMM96YI<W1A;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R(")4
M=7)K<R!V92!#86EC;W,@061A;&%R_2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@
M(E1U=F%L=2(*;7-G<W1R(")4=79A;'4B"@HC.B!F<F%M97=O<FLO0TQ)+T-,
M22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B
M4V7G:6UI;FEZ:2!G:7)I;CHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C8Y"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B52Y6+B!E
M;F1E:W,Z("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*
M;7-G<W1R(")54DPB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D
M96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@(D)E=&EK;&5R:6X@9'5R
M=6T@<F%P;W)L87+];OUN('1E<VQI;2!E9&EL96-E\&D@55),(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B
M55),.B(*;7-G<W1R(")54DPZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A
M;F1A(@IM<V=S='(@(E5G86YD82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5K
M<F%I;F4B"FUS9W-T<B`B56MR87EN82(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C0Q,@IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R(")61E,@9&EZ:6YI;F4@97)I_FEL96UE;6EY;W(N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED
M(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S
M:6=N:6YG('5P+B(*;7-G<W1R("+<>64@;VQU<FME;B!E:R!K=6QL86[]8_T@
M8FEL9VES:2!E:VQE;F5M:7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,X.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA
M;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M7"(E<UPB(%9&4R!D;W-Y87/];OUN(&EZ:6YL97)I(&1E\&G^=&ER:6QE;6EY
M;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@U(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E
M<R\E<RXB"FUS9W-T<B`B)7,O)7,@5D93(&1O<WEA<_UN_6X@:7II;FQE<FD@
M9&7P:?YT:7)I;&5M:7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C<U-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E
M('1O("5S+B(*;7-G<W1R("(E<R!D9?!I_G1I<FEL96UE9&DN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB
M+B(*;7-G<W1R(")61E,@9&]S>6%S_2!<(B5S7"(@8>?];&%M_7EO<BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV.#@@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HQ,#$V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HX,S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R("(E
M<R\E<R!61E,@9&]S>6%S_2!Y96YI9&5N(&%D;&%N9/UR_6QA;?UY;W(N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S-0IM<V=I9"`B56YA
M8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B4U%,('-U
M;G5C=7-U;F$@8F'P;&%N_6QA;?UY;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HX,SD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@
M4U-,+B(*;7-G<W1R(")34TP@:6QE(&)A\&QA;OUL86W]>6]R+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-2!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#D*;7-G:60@(E5N
M86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@9&]S>6%S_2!K
M;W!Y86QA;F%M_7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C,V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@5D93(&1I>FEN
M:2!Y87)A=/UL86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C,U-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-38*;7-G:60@(E5N86)L
M92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B5D93(&1I>FEN
M:2!Y87)A=/UL86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM
M<V=S='(@(E9&4R!D;W-Y87/]('EA<F%T_6QA;?UY;W(N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HR.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM
M<V=S='(@(E9&4R!D;W-Y87/](%PB)7-<(B!Y96YI9&5N(&%D;&%N9/UR_6QA
M;?UY;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8U"FUS
M9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R
M(")";_X@5D93(&1O<WEA<_T@>6%R873];&%M_7EO<BXB"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H<#HW-@HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T
M;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(E9E<FD@<_UK_?YT_7+];&%M
M_7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R-"!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Y.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N
M;W0@96UP='DN(@IM<V=S='(@(EPB)7-<(B!D:7II;FD@<VEL:6YE;6EY;W(L
M(&1I>FEN(&)O_B!D9?!I;"XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B
M)R5S)R!S:6QI;F5M:7EO<CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,S,Q(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,SDR"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,3$@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>2(*;7-G<W1R("(E<R!S:6QI;F5M:7EO<BP@9&EZ:6X@8F_^(&1E\&EL(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T."!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(E9&
M4R!D:7II;FD@]GIY:6YE;&D@;VQA<F%K('-I;&EN96UI>6]R+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S-R!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(E9&4R!D:7II;FD@
M<VEL:6YE;6EY;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT
M,3<@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,CD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB
M"FUS9W-T<B`B5D93(&1I>FEN:2!S:6QI;F5M:7EO<CH@)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(E9&4R!D;W-Y87/](%PB)7-<(B!S:6QI;F5M:7EO<BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HR.#@*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C,X,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,SDQ"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R
M(")61E,@9&]S>6%S_2!S:6QI;F5M:7EO<BXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C(T-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B
M5D93(&1O<WEA<_T@7"(E<UPB('-I;&EN96UI>6]R+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z-#`V"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B
M5D93(/9Z>6EN96QI(&]L87)A:R!S:6QI;F5M:7EO<CH@)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,#,*;7-G:60@(E5N86)L92!T;R!D
M971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(EG\<OQR;/QK
M=&5K:2!D:7II;F4@:V%R87(@=F5R:6QE;6EY;W(N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#,*;7-G:60@(E5N86)L92!T;R!E
M>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B3VYA>2!B96QG
M97-I(&%Y<OUN=/UL87+](.?]:V%R=/UL86W]>6]R(@H*(SH@9G)A;65W;W)K
M+TYE=%])35-0+TE-4U`N<&AP.C0U,2!F<F%M97=O<FLO3F5T7TE-4U`O24U3
M4"]!=71H+G!H<#HQ,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(E1A;OUM_2!Y
M_&ML96YE;6EY;W(Z("5S(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P,0HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38V(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ-S$*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&
M4R!F:6QE+B(*;7-G<W1R(")61E,@9&]S>6%S_2!T8?[];F%M_7EO<BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z,3`R"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M-C0X(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R(")61E,@9&]S>6%S_2!<(B5S7"(@8>?];&%M_7EO<BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-S<@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,3,S"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@
M=W)I=&EN9RXB"FUS9W-T<B`B5D93(&1O<WEA<_T@>6%M86L@:>=I;B!AY_UL
M86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@P(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z-S(*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&
M4R!F:6QE+B(*;7-G<W1R(")61E,@9&]S>6%S_2!AY_UL86W]>6]R+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@
M(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B
M4_UK_?YT_6S];?W^(&%R_FEV(&'G_6QA;?UY;W(N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C@S-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E
M860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B5D93
M(&1O<WEA<_T@>6%Z_6QA;?UY;W(@*&-O<'DH*2!B8?YA<OUS_7H@;VQD=2DN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V-@HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I
M;&5D*2XB"FUS9W-T<B`B5D93(&1O<WEA<_T@>6%Z_6QA;?UY;W(@*&-O<'DH
M*2!B8?YA<OUS_7H@;VQD=2DN(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD
M;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B5D93(&1O<WEA<_T@
M>65N:61E;B!A9&QA;F3]<OUL86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C8V.0IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F
M<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R(")69G-R;V]T(&1I>FEN:2!O:W5N
M86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$P-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S
M.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B
M)7,M/B5S(&]L87)A:R!Y96YI9&5N(&%D;&%N9/UR_6QA;?UY;W(Z(&AE9&5F
M(&1I>FEN('IA=&5N('9A<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,CDS"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(E9&4R!D:7II;FD@>65N:61E;B!A9&QA;F3]<OUL
M86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C
M=&]R>3H@)7,N(@IM<V=S='(@(E9&4R!D:7II;FD@>65N:61E;B!A9&QA;F3]
M<OUL86W]>6]R.B`E<R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M,C8W(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S0S"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R(")61E,@9&]S>6%S_2!<(B5S7"(@>65N:61E;B!A9&QA;F3]<OUL
M86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Q,"!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S
M='(@(B5S+R5S(%9&4R!D;W-Y87/]('EE;FED96X@861L86YD_7+];&%M_7EO
M<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R,R!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C(X-0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@
M9&]S>6%S_2!Y96YI9&5N(&%D;&%N9/UR_6QA;?UY;W(N(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS
M9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B)VUK:7-O
M9G,G(.=A;/W^=/UR_6QA;?UY;W(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS
M;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B0G4@5V]R9"!B96QG
M97-I(.=E=FER:6QI;&5M:7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C$T.2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R(")61E,@9&]S>6%S_2!<(B5S7"(@>6%Z_6QA;?UY;W(N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3<Y"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G
M<W1R(")61E,@9&]S>6%S_2!Y87K];&%M_7EO<B`H8V]P>2@I(&)A_F%R_7/]
M>B!O;&1U*2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.#$@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30S"FUS9VED(")5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B5D93(&1O<WEA('9E<FES
M:2!Y87K];&%M_7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#0Q
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U
M;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@(E9&4R!D;W-Y87/]('EA
M>OUL86W]>6]R("AC;W!Y*"D@8F'^87+]<_UZ(&]L9'4I+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N
M9&5R;&EN92(*;7-G<W1R(")!;'3];OT@YVEZ(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(D1E
M\&G^:6ML:6ML97)I($=E<FD@06PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T
M(&%C=&EO;B(*;7-G<W1R(")3;VX@97EL96UI(&=E<FD@86PB"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED(")5;F5X
M<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*
M;7-G<W1R(")"8?!L86YT_61A('-U;G5C=61A;B!B96ML96YM97EE;B!Y86[]
M=#H@(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T
M,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S@*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@T"FUS
M9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS
M9W-T<B`B4W5N=6-U9&%N(&)E:VQE;FUE>65N('EA;OUT.B`B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I
M9"`B56YF:6QE9"(*;7-G<W1R(")$;VQD=7)U;&UA;?W^(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G
M<W1R(")5;FEC;V1E("A55$8M."DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI
M=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B0FER;&7^:6L@07)A<"!%;6ER
M;&EK;&5R:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB
M"FUS9W-T<B`B0FER;&7^:6L@2W)A;&S]:R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G
M:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B06UE<FEK82!":7)L9?YI:R!$
M979L971L97)I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E
M<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(D%M97)I:V$@0FER
M;&7^:6L@1&5V;&5T;&5R:6YI;B!+_.?\:R!5>F%K($%D86QA<OTB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HW,0IM<V=I9"`B56YI=',B"FUS9W-T<B`B0FER:6UL97(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S='(@
M(D)I;&EN;65Y96XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%0
M22!-97-S86=E($E$*2XB"FUS9W-T<B`B0FEL:6YM97EE;B!A<&EM<V=I9"`H
M05!)($UE<V%J($E$*2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H
M0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R(")":6QI;FUE>65N(&-L:6US
M9VED("C=<W1E;6-I(&UE<V%J($E$*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-3D*(RP@9G5Z>GD*;7-G:60@(E5N:VYO=VX@;&]C871I
M;VX@<')O=FED960N(@IM<V=S='(@(DAIYV)I<B!Y97(@8F5L:7)T:6QM961I
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB
M"FUS9W-T<B`B0FEL:6YM97EE;B!K=6QL86[]8_T@863]('9E>6$@<&%R;VQA
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B
M"FUS9W-T<B`BWG4@86YK:2#V\&5N:6X@8F'P_6[](.?V>B(*"B,Z(&9R86UE
M=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,CDV"FUS9VED(")5;FYA;65D
M(@IM<V=S='(@(MUS:6US:7HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R
M:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC
M86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E
M92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H
M;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C
M;&EP8F]A<F0N(@IM<V=S='(@(B(*(D%Y<OUC86S]:W/]>B!B971I:VQE<B!P
M<F]G<F%M<V%L(&]L87)A:R!+97,O2V]P>6%L82]987#]_G3]<B=A(&?\=F5N
M;&EK("(*(FYE9&5N:7EL92!E<FG^96UE>FQE<BX@0F5T:6ML97)I;B!P86YO
M>6$@;F%S_6P@=6QA_F%C8?#];OT@9_9S=&5R96X@;6]Z:6QL82XB"B)O<F<@
M=&5K;FEK(&YO='5N=2!G]G)M96L@:>=I;B!%5D54(&D@=/UK;&%Y_6XN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX,@IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`B0F5L:7)T:6QM:?X@
M<F5N:W1E;B!V87IG9><B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8X-B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR
M-@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,@IM<V=I
M9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(D1E<W1E:VQE;FUE
M>65N(%5Z86YT_2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,3DW('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5
M<&1A=&4B"FUS9W-T<B`B1_QN8V5L;&4B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T
M92`E<R(*;7-G<W1R(")'_&YC96QL93H@)7,B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G
M<W1R(")+=6QL86[]8_UY_2!G_&YC96QL92(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z,C,P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`B1_QN8V5L;&5N9&DZ("<E<R<B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S
M8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B6?QK<V5L=&UE(&)E=&GP:2!S:6QI
M;&YD:2XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3D*;7-G:60@(E5P;&]A
M9"(*;7-G<W1R(")9_&ML92(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE
M<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R(")"_'3\;B!U>6=U;&%M86QA<OUN
M(&%Y87(@9&]S>6%L87+]('-U;G5C=7EA('G\:VQE;F1I+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*
M;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B0OQY_&L@;&%T
M:6X@:&%R9FQE<FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB
M97)S(@IM<V=S='(@(D+\>?QK(')O;6$@<F%K86UL87+](@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R(")5<G5G=6%Y(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(DMU
M;&QA;CH@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R(")34TP@:W5L
M;&%N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B57-E
M(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E
M<BXB"FUS9W-T<B`B2W5L;&%N_6/](&%D_6[]>B]P87)O;&%N_7H@24U34"!S
M=6YU8W4@:>=I;B!F87)K;/T@:7-E(&MU;&QA;OUN+B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(E5S
M97(B"FUS9W-T<B`B2W5L;&%N_6/];&%R(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+U)E9VES=')Y+G!H<#HW,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(B5S
M(&MU;&QA;OUC_7/]("5S(&GG:6X@9&_P<G5L86YA;6%D_2XB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B2W5L;&%N_6/](%GV;F5T:6UI(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HR-3$*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R
M(")+=6QL86[]8_T@4V7G96YE:VQE<FDB"@HC.B!S:6=N=7`N<&AP.C8R"FUS
M9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R(")+=6QL86[]8_T@2V%Y
M_70B"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO
M;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R(")"
M=2!S:71E(&GG:6X@:W5L;&%N_6/](&MA>63]('-EYVEL;65Z(&O];/UN;?W^
M=/UR+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-CD*(RP@9G5Z>GD*
M;7-G:60@(E5S97(@86-C;W5N="!N;W0@9F]U;F0B"FUS9W-T<B`B)7,@8G5L
M=6YA;6%D_2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M
M92(*;7-G<W1R(")+=6QL86[]8_T@063](@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R(")+
M=6QL86[]8_T@)R5S)R!Z871E;B!V87(N(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B2W5L
M;&%N_6/]($%D_3HB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX
M"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(DMU;&QA;OUC_2!A9/TZ("(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S
M97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(E-I<W1E;61E:VD@:W5L;&%N
M_6/];&%R.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS
M9W-T<B`BUGIB96MI<W1A;B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C$V,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-34*;7-G:60@
M(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(E9&4R!D
M:7II;FD@>6]K+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3@*
M;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(E1A=&EL(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U
M;F0@:6YC;'5D93H@(@IM<V=S='(@(D=EYV5R;&D@:V]N=6UL87+];B!IYV5R
M9&EK;&5R:3HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8S.`IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B1V7G97)L:6QI:R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T
M<B`BWG4@86YD86X@:71I8F%R96X@9&%K:6MA(&1E\&5R:2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C@U-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE
M(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,C0T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R-C8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.3(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO
M5'EP92]T86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R(")$
M9?!E<FQE<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#D@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-@IM<V=I9"`B5F%L=65S('1O('-E
M;&5C="!F<F]M(@IM<V=S='(@(D1E\&5R;&5R:6X@<V7G:6QE8V7P:2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B5F%N=6%T=2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0*;7-G:60@(E9A
M<FEA8FQE(@IM<V=S='(@(D1E\&G^:V5N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I
M9"`B5F5N97IU96QA(@IM<V=S='(@(E9E;F5Z=65L;&$B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T
M:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E
M<F5D('=I=&@N(@IM<V=S='(@(D1O\')U;&%M82!B8?YA<OUS_7H@;VQD=2`M
M(&)U(&EL971I(&MU<F-A;&%N;?W^(&]L86)I;&ER+B`@(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(E9E<G-I;VXB
M"FUS9W-T<B`B4_QR_&TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C(V"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B4_QR_&T@2V]N
M=&]L_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(D3\
M_F5Y($AI>F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(D3\
M_F5Y('EA<W3]:VQA;6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B1/S^
M97DZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S`*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R("+';VL@6?QK<V5K(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-@IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B5FEE=&YA;2(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")6:65T;F%M97-E
M("A625-#24DI(@IM<V=S='(@(E9I971N86UC82`H5DE30TE)*2(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDV,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(D?V<OQN=/QL92`E<R(*"B,Z
M(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N
M86P@=V5B('!A9V4B"FUS9W-T<B`B0FER(&3]_B!W96(@<V%Y9F%S_2!G]G+\
M;G3\;&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX
M,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R("(E
M<R!O;&%R86L@9_9R_&YT_&QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER
M9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B0G)I=&%N>6$G>6$@86ET
M(%9I<F=I;B!!9&%L87+](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN
M($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B06UE<FEK82!":7)L97+^:6L@1&5V
M;&5T;&5R:2=N92!A:70@5FER9VEN($%D86QA<OTB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(P.0IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R(")']G+\
M_B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@
M(E9I<VEB:6QI='DZ("(*;7-G<W1R(")']G+\_CHB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B
M5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B4TU44"!Y;VQU>6QA
M(%9O9&%F;VYE(-UT86QY82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!
M4DXB"FUS9W-T<B`B5T%23B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#
M4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R(")564%222$A(25S(-W'
MW4Y$14X@0D54W=#=($5,(-U,12#'24M!4E1)3BXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S,PHC+"!F=7IZ>0IM<V=I9"`B
M5TE.('9I82!(5%10(@IM<V=S='(@(DA45%`@>6]L=7EL82!S;7,R96UA:6PB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G
M<W1R(")786QL:7,@=F4@1G5T=6YA(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM<V=S='(@(E5Y
M87+](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`BQW+^(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM
M<V=S='(@(DAA=F$@5&%H;6EN:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HT,C<*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*
M;7-G<W1R(")(879A('9E<FES:2!S8?!L87G]8_US_2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T
M<B`B5V5A=&AE<BYC;VTB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM
M<V=I9"`B5V5B(@IM<V=S='(@(E=E8B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT,S<*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(E=E8B!3:71E
M<VDB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B2&%F=&%L_6LB"@HC.B!S97)V
M:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G
M<W1R(")(;_YG96QD:6YI>B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(B5S($AO_F=E;&1I
M;FEZ(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E
M;&-O;64L("5S(@IM<V=S='(@(DAO_F=E;&1I;FEZ+"`E<R(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ
M*2(*;7-G<W1R(")"873]("A)4T\M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DV"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS
M9W-T<B`B0F%T_2`H25-/+3@X-3DM,34I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@
M(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(D)A=/T@4V%H<F$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(E=H
M870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_
M(@IM<V=S='(@(B5S(&=I<FG^=&5N('-O;G)A(&AA;F=I('5Y9W5L86UA>?T@
M9_9R_&YT_&QE<VEN/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*
M;7-G<W1R(")3_6[]<FQA>?UC_2!K87)A:W1E<B!N961I<C\B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@
M<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R(")!:W1A<OUM(&MA<F%K=&5R:2!N
M961I<C\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3`V,0HC+"!F=7IZ>0IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P
M(@IM<V=S='(@(D%V=7-T=7)A;'EA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B2&%N9VD@179R92(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@(E=H:6-H('!L
M=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS
M9W-T<B`B(@HB6F5N9VEN($UE=&EN(&3\>F5N;&5Y:6-I<VD@:>=I;B!H86YG
M:2!U>75M;'4@96ML97(@<V7G:6QE8FEL:7(@:_UL_6YS_6XN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM
M<V=I9"`B5VED=&@B"FUS9W-T<B`B1V5N:?YL:6LB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3(U"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B
M"FUS9W-T<B`B0U-3(&)I<FEM:7EL92!G96YI_FQI:R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@
M;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N
M97AT(&QO9RUI;BDZ(@IM<V=S='(@(E-O;&1A:VD@)7,@;65N_'/\;OQN(&=E
M;FG^;&GP:2`H8FER('-O;G)A:VD@9VER:?YT92!E=&MI;B!O;&%C86LI.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V
M"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`BQVEZ96QG96YI
M;B!G96YI_FQI\&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R(")'96YI
M_FQI:R!B:7)I;6DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(D=E;FG^;&EK
M.B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,3,*;7-G:60@(E=I
M:VDB"FUS9W-T<B`B5VEK:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS,#`@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C4*;7-G:60@(E=I;F0B"FUS9W-T<B`B4OQZ9V%R(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I;F0@16%R
M;'DB"FUS9W-T<B`B17)K96X@4V%A=&QE<F1E(%+\>F=A<B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B
M"FUS9W-T<B`B2VYO="!B:7)I;6EN9&4@<OQZ9V%R(&C]>OTB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$U-@IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B4OQZ
M9V%R.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#(*;7-G
M:60@(E=I;F0Z("(*;7-G<W1R(")2_'IG87(Z("(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(D)I;&=E;&EK
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y-@HC+"!F=7IZ>0IM
M<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`BW7-T96L@3&ES=&5S:2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R("+=
M_B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$V
M-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(MW^($%D<F5S:2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G
M:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`BW?X@5&5L969O;G4B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-CD@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E
M<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS
M,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD
M<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,30*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93
M(&9I;&4N(@IM<V=S='(@(E9&4R!D:7II;FD@>6%R873];/UR:V5N(&5R:?YI
M;2!E;F=E;&QE;F1I+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-#,*;7-G:60@(E@M4F5F(@IM<V=S='(@(E@M4F5F(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!"87-I
M8R!#;VYS=')A:6YT<R(*;7-G<W1R(")8-3`Y=C,@5&5M96P@2_US_71L86UA
M;&%R_2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DR
M"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(E@U
M,#EV,R!'96YI_FQE=&EL;6G^($%N86AT87(@2W5L;&%N_6W](@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV
M,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B6#4P.78S(-9T
M96MI($MO;G4@063](@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R
M(@IM<V=S='(@(E@U,#EV,R!+;VYU($%N86AT87(@5&%N_73]8_US_2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@R"FUS9VED(")8
M-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R(")8-3`Y=C,@=7IA;G3];&%R_2(*
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R(")9
M62(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U
M-0IM<V=I9"`B65E962(*;7-G<W1R(")965E9(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,#@*;7-G:60@(EEA:&]O(2!M
M87`B"FUS9W-T<B`B66%H;V\A(&AA<FET87/](@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM
M<V=S='(@(EG];&S]:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM
M<V=S='(@(EEE;65N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.CDV,PIM<V=I9"`B665S(@IM<V=S='(@(D5V970B"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I
M9"`B665S+"!)($%G<F5E(@IM<V=S='(@(D5V970L($MA8G5L($5D:7EO<G5M
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU
M,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@
M8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*
M(DU%5-U.($U/1%5.1$%324Y)6BX@6SP^72!D_/!M96QE<FEN:2!K=6QL86YA
M<F%K(%=94TE764<@9_9R_&[\;?QN92!D]F[\;BXB"@HC.B!S97)V:6-E<R]P
M;W)T86PO961I="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R
M92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#$Q
M"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R(")$
M;_!R=6QA;F%M863];OUZ+B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N
M=&ET>2YP:'`Z,S`R"FUS9VED(")9;W4@8V%N(&YO="!H879E('1H92`G7%PG
M(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B)UQ<)R!K
M87)A:W1E<FD@=&%M(&%D_6[]>F1A(&)U;'5N86UA>BXB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#4U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Y-S4*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@
M861D<F5S<RXB"FUS9W-T<B`B1V7G97)L:2!B:7(@96QE:W1R;VYI:R!P;W-T
M82!A9')E<VD@9VER;65D:6YI>BXB"@HC.B!F<F%M97=O<FLO1&%T82]$871A
M+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M
M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C
M;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@HB)7,@
M:>=I;F1E(&MA<O[];/UK(&=E;&5N(&%L86YL87)L82`H:>=E<FDI(&%K=&%R
M_6QA;B!D;W-Y861A:VD@86QA;FQA<OT@(@HB9?YL9?YT:7)M961I;FEZ+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B66]U(&AA
M=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R("+'_6O]_B!Y87!M863];OUZ
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*
M(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@
M9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I
M;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"B)'9>=E
M<FQI(&)I<B!C97`@=&5L969O;G4@;G5M87)A<_T@9VER;65L:7-I;FEZ+"!S
M87G];&%R('9E('-EYV5N96ML:2!O;&%R86L@(@HB=6QU<VQA<F%R87/](&%R
M86UA(/9N96MI("<K)R`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3@X"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*
M;7-G<W1R(")'9>=E<FQI(&)I<B!D9?!E<B!G:7)M96QI<VEN:7HN(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@
M;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N
M=7!S+B(*;7-G<W1R("+<>64@:V%Y9/T@>6%P86)I;&UE:R!IYVEN(&)I<B!6
M97)I0?!A8_T@>6%P_6QA;F3]<FUA;/US_6[]>BXB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C0U-@IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E
M(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(E9&4R!S;VX@8?YA;6%S_6[]('EA
M</UL86YD_7)M86S]<_UN_7HN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B
M;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*
M;7-G<W1R(")0<F]B;&5M(')A<&]R=2!G]FYD97)M961E;B#V;F-E('-O<G5N
M=2!T87)F:2!E=&UE;&ES:6YI>BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T
M:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B0G4@
M8F'P;&%N=/UN_6X@9_9S=&5R9&GP:2!B:7(@55),(&=I<FUE;&ES:6YI>B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@
M;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@
M(E-I;&EN;65S:2!IYVEN(&)I<B!S=6YU8W4@<V7G;65L:7-I;FEZ+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A
M('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B5&5M:7IL96YM97-I
M;B!IYVEN(&)I<B!K=6QL86[]8_T@863](&)E;&ER=&UE;&ES:6YI>BXB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@
M82!U<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(E-I;&EN;65S:2!IYVEN
M(&)I<B!K=6QL86[]8_T@863](&)E;&ER=&UE;&ES:6YI>BXB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D
M9"XB"FUS9W-T<B`B16ML96YM97-I(&GG:6X@8FER(&MU;&QA;OUC_2!A9/T@
M8F5L:7)T;65L:7-I;FEZ+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*
M;7-G<W1R(")'_&YC96QL96YM97-I(&GG:6X@8FER(&MU;&QA;OUC_2!A9/T@
M8F5L:7)T;65L:7-I;FEZ+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T
M(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R(")'97+G96ML9?YT:7)I;&5C
M96L@8FER(&5Y;&5M(&)E;&ER=&UE;&ES:6YI>BXB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U
M(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R(")996YI
M(&MA=&5G;W)Y(&%D_2!G:7)M96QI<VEN:7HN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO
M=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<V"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@
M4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R("(E<R!O='5R=6UU;G5N('/\
M<F5S:2!D;VQD=2X@3/QT9F5N('1E:W)A<B!G:7)I_B!Y87#];BXB"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%
M;6%I;"!!9&1R97-S(@IM<V=S='(@(D5L96MT<F]N:6L@4&]S=&$@061R97-I
M;FEZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q,@IM<V=I9"`B66]U
M<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")+:6UD96XZ(&%D<F5S.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-"!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX.0IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R
M(")":6QG:6QE<FEN:7HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R
M97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E
M<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M
M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B(E<R!O='5R=6UU;G5Z=6X@
M8F'^;&%N9_UC_6YD82#=;G1E<FYE="!!9')E<VEN:6YI>B!D9?!I_G1I+B!'
M_'9E;FQI\&EN:7II("(*(FMO<G5M86L@:>=I;BP@>65N:61E;B!G:7)I_B!Y
M87!M86S]<_UN_7HN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R(")!9/UN_7HB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-0HC+"!F=7IZ>0IM<V=I
M9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U
M<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R
M9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@
M82!D:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T
M<B`B(@HB2VEM;&EK(&1E;F5T:6UI;FEZ(&MU;&QA;OUC_2!E:VQE;65Y:2!D
M97-T96ML96UE;65K=&5D:7(L('9E>6$@8G4@]GIE;&QI:R`B"B)B:7(@;F5D
M96X@>?QZ_&YD96X@<V7G:6QE;65Z(&O];/UN;?W^=/UR+B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A
M=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN
M9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@
M9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"B)+:6UL:6L@9&5N
M971I;6EN:7H@:W5L;&%N_6/](&QI<W1E;&5M97EI(&1E<W1E:VQE;65M96MT
M961I<B!V97EA(&)U(/9Z96QL:6L@(@HB8FER(&YE9&5N('G\>OQN9&5N('-E
MYVEL96UE>B!K_6S];FW]_G3]<BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R
M(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I
M='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B(E<R!O='5R
M=6UU;G5Z=6X@8F'^;&%N9_UC_6YD82!T87)A>?UC_6[]>B!D9?!I_G1I+B!'
M_'9E;FQI\&EN:7II(&MO<G5M86L@(@HB:>=I;BP@>65N:61E;B!G:7)I_B!Y
M87!M86S]<_UN_7HN(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*;7-G
M:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R
M92XB"FUS9W-T<B`B5&%R87G]8_UN_7H@8G4@]GIE;&QI\&D@9&5S=&5K;&5M
M96UE:W1E9&ER+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS
M.C0R"B,L(&9U>GIY"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@
M<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM
M86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@HB5&%R87G]8_UN_7H@
M8G4@>6%Z9/UR;6$@=&5R8VEH:6YI(&1E<W1E:VQE;65M96MT961I<BY987ID
M_7)M86L@:>=I;B!#;VYT<F]L+R(*(D]P=&EO;B`K(%`@='7^;&%R_6YA(&)A
M<_UN+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3<*;7-G:60@(EEO
M=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(EIA;6%N($1I;&EM:6YI
M>CHB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.38*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G
M<W1R("+6;B!T86[];6S](&MI;6QI\&EN:7HZ(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$U.`IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*
M;7-G<W1R("+6;B!T86[];6S](&MI;6QI\&EN:7HZ(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(P,0IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S
M='(@(E1A;2!!9/UN_7HZ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M,3`P,`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB
M"FUS9W-T<B`B4V7G96YE:VQE<FEN:7H@9_QN8V5L;&5N9&DN(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R("(E
M<R!IYVEN('EE;FD@<&%R;VQA;OUZ.B`E<R(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B
M965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN
M(@IM<V=S='(@(E-EYV5N96ML97)I;FEZ(&)U(&]T=7)U;75N('/\<F5S:2!I
MYVEN9&4@9_QN8V5L;&5N9&DN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D
M871E9"XB"FUS9W-T<B`B4V7G96YE:VQE<FEN:7H@9_QN8V5L;&5N9&DN(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B4&%R;VQA;OUZ('/]
M9OUR;&%N9/TN(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*
M;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K
M('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W
M;W)D+B(*;7-G<W1R("(B"B)087)O;&%N_7H@<_UF_7)L86YD_2P@96QE:W1R
M;VYI:R!P;W-T86[]>OT@:V]N=&]L(&5D:6X@=F4@>65N:2!P87)O;&%N_7IL
M82`B"B)G:7)I_B!Y87#];BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HW,S(*(RP@9G5Z>GD*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER
M960N(@IM<V=S='(@(E!A<F]L86[]>B!S_6;]<FQA;F3]+B(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@
M<V5R=F5R<SHB"FUS9W-T<B`B57IA:W1A:VD@<W5N=6-U;&%R_6[]>CHB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@
M(EEU9V]S;&%V>6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$X"FUS9VED("):86ER92(*;7-G<W1R("):86ER92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("):86UB:6$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$X"FUS9VED(")::6UB86)W92(*;7-G<W1R(")::6UB86)V92(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B
M2/UZ;/TB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL
M:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U
M;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS
M9W-T<B`B6T%L_6YT_2!-971N:2!386ML85TB"@HC.B!S97)V:6-E<R]P<F]B
M;&5M+G!H<#HX.`IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");
M4')O8FQE;2!287!O<G5=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O
M=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS
M9W-T<B`B6T%L_6YT_2!-971N:2!']G-T97(@+2(*"B,Z(&9R86UE=V]R:R]4
M97AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE
M<UTB"FUS9W-T<B`B6T%L_6YT_2!-971N:2!']G-T97(@+2`E<R!S873]<ETB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B)7,O)7,@<V%T
M_7(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U-#$@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N
M(@IM<V=S='(@(E]9]FYE=&EM(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS9VED
M(")?0TQ)(@IM<V=S='(@(E]#3$DB"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G
M:60@(E]$871A5')E92(*;7-G<W1R(")?5F5R:4'P86/](@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS
M9VED(")?1&5L971E(%)O=R(*;7-G<W1R(")3873]<OT@7U-I;"(*"B,Z(&QI
M8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R(")?1W)U<&QA
M<B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4*;7-G
M:60@(E](96QP(@IM<V=S='(@(EEA<E]D_6TB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E])
M;6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(D?V<OQN=/P@UE]Z96QL:6ML
M97)I+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y
M-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R(")':5]R:?XB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*
M;7-G<W1R("+'_5]K_?XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN
M+B(*;7-G<W1R(")?0F'P;&%N=/UY_2!$9?!I_G1I<BXN+B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS
M(@IM<V=S='(@(E]39>=E;F5K;&5R(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS
M9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B7TAA:VQA<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM
M<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(D)A\&QA7VYT_7G](%-I
M;"XN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S
M='(@(E]!>6%R;&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE
M<RXN+B(*;7-G<W1R("+':7IE7VQG92#6>F5L;&EK;&5R:2XN+B(*"B,Z(&QI
M8B]A<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(DM?=6QL86[]
M8_UL87(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,0IM<V=I
M9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(F%D<F5S(&1E9G1E<FDB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S-`HC+"!F=7IZ>0IM
M<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B861R97,@9&5F=&5R
M:2(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$S"FUS9VED(")C
M86QE;F1A<B(*;7-G<W1R(")T86MV:6TB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")C86QM(@IM<V=S='(@(OUL_6UL_2(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN;W0@8W)E871E
M(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HU.3(*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B8G5R87EA('3]:VQA
M>?UN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C(*
M;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W.`HC+"!F=7IZ
M>0IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R(")987#];&%N
M9/UR;6$@1F%R:VQA<OTB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN
M9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ.#(*(RP@9G5Z
M>GD*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R(")B=6QU;F%M863]
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*
M;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B9/S^_'EO<B(*"B,Z(&9R86UE=V]R
M:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U-0IM<V=I9"`B9FEL92(*;7-G<W1R
M(")D;W-Y82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<T(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S8P(&QI8B]";&]C:R]M971A<BYP:'`Z,S@V"B,L('!H
M<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS
M9W-T<B`B)7,@*"5S*2!D96X@)7,@)7,@9&4B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C4P"B,L(&9U>GIY"FUS9VED(")G=7-T:6YG(@IM
M<V=S='(@(BP@9OUR=/UN86S]("5S("5S(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.0IM<V=I9"`B:#HB"FUS9W-T<B`B
M:#HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,S4X"FUS9VED(")H:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B
M06-I;"(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B365T;F4@9_9M
M_&S\(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*
M;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N
M86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G
M<W1R(")S873]<FQA<ETB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S
M='(@(FUK:7-O9G,@25-/('EA<&%R:V5N(&AA=&$@:V]D=3HE9"XB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8Y"FUS9VED
M(")M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C(Y,2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,S(*;7-G:60@(FYA;64B"FUS
M9W-T<B`B860B"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(Q"FUS9VED
M(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B9V5RYV5K;&7^=&ER:6QM961I
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y"FUS
M9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(FAE;OQZ(&=E<N=E
M:VQE_G1I<FEL;65D:2(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3`U"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(FYO="!D969T97)I(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R(")Y_'ID92(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<T"B,L(&9U>GIY"FUS9VED(")P
M97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("+=>FEN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B
M<&EX96QS(@IM<V=S='(@(G)E<VEM(&)I<FEM:2(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@
M:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S,*;7-G:60@(G)I<VEN9R(*;7-G<W1R(")Y
M_&MS96QI>6]R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-#(*(RP@9G5Z>GD*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS
M9W-T<B`B2&%V82!R87!O<G4@]F)E\&D@:W5L;&%N_6QA8FEL:7(@9&7P:6PN
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HY.0IM<V=I9"`B<VAO=R!D
M:69F97)E;F-E<R(*;7-G<W1R(")F87)K;&%R_2!G]G-T97(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I
M9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(DA45%`@>6]L=7EL82!S
M;7,R96UA:6PB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S@U"FUS9VED(")S<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B<W1E861Y(@IM
M<V=S='(@(G-A8FET(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS
M,#D*;7-G:60@(G-W:71C:"!O9F8@:F%V87-C<FEP="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B
M<WES=&5M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3(Y"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B9_9R978@
M;&ES=&5S:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P-0HC+"!F=7IZ>0IM<V=I9"`B
M=')Y(&%G86EN(@IM<V=S='(@(DAE<B!':7)I_G1E(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM
M<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G
M<W1R(")P87)O;&%Y_2!D;_!R=6QA;6%K(&GG:6X@:6MI(&1E9F$@9VER:6XB
M"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F
M+G!H<#HW.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R(")B:7)L9?YT:7)I;&UI
M_B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@
M(G5N;F%M960B"FUS9W-T<B`B861L86YD_7+];&UA;?W^(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS
M9VED(")U<V5R('-E;&5C="(*;7-G<W1R(")K=6QL86[]8_T@<V7G:6UI(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS
M9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR-#$*;7-G:60@(G<Z(@IM<V=S='(@
M(G<Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@
M(G=E871H97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M(@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+W1R86YS;&%T:6]N+G!H<```
M````````````````````````````````````````````````````````````
M````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q-38R-S``
M,3`U,34T,S,W-30`,#(Q,S8R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````",A+W5S<B]L;V-A;"]P<V$O861M:6XO8FEN+W!H
M<"`M<0H\/W!H<`HO*BH*("H@5')A;G-L871I;VX@:&5L<&5R(&%P<&QI8V%T
M:6]N(&9O<B!T:&4@2&]R9&4@9G)A;65W;W)K+@H@*@H@*B!&;W(@=7-A9V4@
M:6YF;W)M871I;VX@8V%L;#H*("H@+B]T<F%N<VQA=&EO;BYP:'`@:&5L<`H@
M*@H@*B`D2&]R9&4Z(&AO<F1E+W!O+W1R86YS;&%T:6]N+G!H<"QV(#$N.3$N
M,BXQ-B`R,#`V+S`U+S(S(#`R.C$S.C0S('-E;'-K>2!%>'`@)`H@*B\*"F9U
M;F-T:6]N(&9O;W1E<B@I"GL*("`@(&=L;V)A;"`D8RP@)&-U<F1I<CL*"B`@
M("`D8RT^=W)I=&5L;B@I.PH@("`@)&,M/G=R:71E;&XH)U!L96%S92!R97!O
M<G0@86YY(&)U9W,@=&\@:3$X;D!L:7-T<RYH;W)D92YO<F<N)RD["@H@("`@
M8VAD:7(H)&-U<F1I<BD["B`@("!E>&ET.PI]"@IF=6YC=&EO;B!U<V%G92@I
M"GL*("`@(&=L;V)A;"`D;W!T:6]N<RP@)&,["@H@("`@:68@*&-O=6YT*"1O
M<'1I;VYS6S%=*2`F)@H@("`@("`@("@D;W!T:6]N<ULQ75LP72`]/2`G:&5L
M<"<@)B8@(65M<'1Y*"1O<'1I;VYS6S%=6S%=*2!\?`H@("`@("`@("%E;7!T
M>2@D;W!T:6]N<ULQ75LP72D@)B8@:6Y?87)R87DH)&]P=&EO;G-;,5U;,%TL
M(&%R<F%Y*"=C;VUM:70G+"`G8V]M<&5N9&EU;2<L("=E>'1R86-T)RP@)VEN
M:70G+"`G;6%K92<L("=M97)G92<I*2DI('L*("`@("`@("!I9B`H)&]P=&EO
M;G-;,5U;,%T@/3T@)VAE;'`G*2!["B`@("`@("`@("`@("1C;60@/2`D;W!T
M:6]N<ULQ75LQ73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8VUD
M(#T@)&]P=&EO;G-;,5U;,%T["B`@("`@("`@?0H@("`@("`@("1C+3YW<FET
M96QN*"=5<V%G93HG("X@)R!T<F%N<VQA=&EO;BYP:'`@6V]P=&EO;G-=("<@
M+B`D8VUD("X@)R!;8V]M;6%N9"UO<'1I;VYS72<I.PH@("`@("`@(&EF("@A
M96UP='DH)&-M9"DI('L*("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@
M("`@("`@("`@)&,M/G=R:71E;&XH)T-O;6UA;F0@;W!T:6]N<SHG*3L*("`@
M("`@("!]"B`@("`@("`@<W=I=&-H("@D8VUD*2!["B`@("`@("`@("`@(&-A
M<V4@)V-L96%N=7`G.@H@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@
M+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V4@;VYL>2!T:&ES(&QO8V%L92XG
M*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("UM+"`M+6UO9'5L
M93U-3T153$4@("`@0VQE86YU<"!03R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(
M;W)D92D@;6]D=6QE+B<I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@(&-A<V4@)V-O;6UI="<Z"B`@("`@("`@("`@(&-A<V4@)V-O;6UI
M="UH96QP)SH*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("UL+"`M
M+6QO8V%L93UL;%]#0R`@("`@57-E('1H:7,@;&]C86QE+B<I.PH@("`@("`@
M("`@("`@("`@)&,M/G=R:71E;&XH)R`@+6TL("TM;6]D=6QE/4U/1%5,12`@
M("!#;VUM:70@=')A;G-L871I;VYS(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M
M;V1U;&4N)RD["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G("`M32P@
M+2UM97-S86=E/4U%4U-!1T4@(%5S92!T:&ES(&-O;6UI="!M97-S86=E(&EN
M<W1E860@;V8@=&AE(&1E9F%U;'0@;VYE<RXG*3L*("`@("`@("`@("`@("`@
M("1C+3YW<FET96QN*"<@("UN+"`M+6YE=R`@("`@("`@("`@("`@5&AI<R!I
M<R!A(&YE=R!T<F%N<VQA=&EO;BP@8V]M;6ET(&%L<V\@0U)%1$E44RPG*3L*
M("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("`@("`@("`@("`@("`@
M("`@("`@("`@0TA!3D=%4R!A;F0@;FQS+G!H<"YD:7-T+B<I.PH@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)V-O;7!E;F1I=6TG
M.@H@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@+6$L("TM861D/49)
M3$4@("`@("`@($%D9"!T:&ES(%!/(&9I;&4@=&\@=&AE(&-O;7!E;F1I=6TN
M(%5S969U;"!T;R<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@
M("`@("`@("`@("`@("`@("`@("`@(&EN8VQU9&4@82!C;VUP96YD:75M(&9R
M;VT@82!D:69F97)E;G0@8G)A;F-H('1O)RD["B`@("`@("`@("`@("`@("`D
M8RT^=W)I=&5L;B@G("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&=E;F5R
M871E9"!C;VUP96YD:75M+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E
M;&XH)R`@+60L("TM9&ER96-T;W)Y/41)4B`@($-R96%T92!C;VUP96YD:75M
M(&EN('1H:7,@9&ER96-T;W)Y+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R
M:71E;&XH)R`@+6PL("TM;&]C86QE/6QL7T-#("`@(%5S92!T:&ES(&QO8V%L
M92XG*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E
M("=E>'1R86-T)SH*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("UM
M+"`M+6UO9'5L93U-3T153$4@($=E;F5R871E(%!/5"!F:6QE(&]N;'D@9F]R
M('1H:7,@*$AO<F1E*2!M;V1U;&4N)RD["B`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@8V%S92`G:6YI="<Z"B`@("`@("`@("`@("`@("`D
M8RT^=W)I=&5L;B@G("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S92!T:&ES
M(&QO8V%L92XG*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("UM
M+"`M+6UO9'5L93U-3T153$4@("`@0W)E871E(&$@4$\@9FEL92!O;FQY(&9O
M<B!T:&ES("A(;W)D92D@;6]D=6QE+B<I.PH@("`@("`@("`@("`@("`@)&,M
M/G=R:71E;&XH)R`@+6,L("TM8V]M<&5N9&EU;3U&24Q%("!5<V4@=&AI<R!C
M;VUP96YD:75M(&9I;&4@:6YS=&5A9"!O9B!T:&4@9&5F875L="<I.PH@("`@
M("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@("`@("`@("`@("`@("`@("`@
M("`@("!O;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE(&AO<F1E+W!O(&1I<F5C
M=&]R>2DN)RD["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G("`M;BP@
M+2UN;RUC;VUP96YD:75M("`@($1O;EPG="!U<V4@82!C;VUP96YD:75M+B<I
M.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)VUA
M:V4G.@H@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@+6PL("TM;&]C
M86QE/6QL7T-#("`@("!5<V4@;VYL>2!T:&ES(&QO8V%L92XG*3L*("`@("`@
M("`@("`@("`@("1C+3YW<FET96QN*"<@("UM+"`M+6UO9'5L93U-3T153$4@
M("`@0G5I;&0@34\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L
M92XG*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("UC+"`M+6-O
M;7!E;F1I=6T]1DE,12`@365R9V4@;F5W('1R86YS;&%T:6]N<R!T;R!T:&ES
M(&-O;7!E;F1I=6T@9FEL92<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E
M;&XH)R`@("`@("`@("`@("`@("`@("`@("`@("!I;G-T96%D(&]F('1H92!D
M969A=6QT(&]N92`H8V]M<&5N9&EU;2YP;R!I;B!T:&4G*3L*("`@("`@("`@
M("`@("`@("1C+3YW<FET96QN*"<@("`@("`@("`@("`@("`@("`@("`@("`@
M:&]R9&4O<&\@9&ER96-T;W)Y+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R
M:71E;&XH)R`@+6XL("TM;F\M8V]M<&5N9&EU;2`@("!$;VY<)W0@;65R9V4@
M;F5W('1R86YS;&%T:6]N<R!T;R!T:&4@8V]M<&5N9&EU;2XG*3L*("`@("`@
M("`@("`@("`@("1C+3YW<FET96QN*"<@("US+"`M+7-T871I<W1I8W,@("`@
M("`@4V%V92!T<F%N<VQA=&EO;B!S=&%T:7-T:6-S(&EN(&$@;&]C86P@9FEL
M92XG*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E
M("=M86ME+6AE;'`G.@H@("`@("`@("`@("!C87-E("=U<&1A=&4M:&5L<"<Z
M"B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G("`M;"P@+2UL;V-A;&4]
M;&Q?0T,@("`@(%5S92!O;FQY('1H:7,@;&]C86QE+B<I.PH@("`@("`@("`@
M("`@("`@)&,M/G=R:71E;&XH)R`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!5
M<&1A=&4@:&5L<"!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE
M+B<I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@
M)VUE<F=E)SH*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("UL+"`M
M+6QO8V%L93UL;%]#0R`@("`@57-E('1H:7,@;&]C86QE+B<I.PH@("`@("`@
M("`@("`@("`@)&,M/G=R:71E;&XH)R`@+6TL("TM;6]D=6QE/4U/1%5,12`@
M("!-97)G92!03R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE
M+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@+6,L("TM8V]M
M<&5N9&EU;3U&24Q%("!5<V4@=&AI<R!C;VUP96YD:75M(&9I;&4@:6YS=&5A
M9"!O9B!T:&4@9&5F875L="<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E
M;&XH)R`@("`@("`@("`@("`@("`@("`@("`@("!O;F4@*&-O;7!E;F1I=6TN
M<&\@:6X@=&AE(&AO<F1E+W!O(&1I<F5C=&]R>2DN)RD["B`@("`@("`@("`@
M("`@("`D8RT^=W)I=&5L;B@G("`M;BP@+2UN;RUC;VUP96YD:75M("`@($1O
M;EPG="!U<V4@82!C;VUP96YD:75M+B<I.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@(&-A<V4@)W5P9&%T92<Z"B`@("`@("`@("`@("`@
M("`D8RT^=W)I=&5L;B@G("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S92!T
M:&ES(&QO8V%L92XG*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@
M("UM+"`M+6UO9'5L93U-3T153$4@("`@57!D871E(&]N;'D@=&AI<R`H2&]R
M9&4I(&UO9'5L92XG*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@
M("UC+"`M+6-O;7!E;F1I=6T]1DE,12`@57-E('1H:7,@8V]M<&5N9&EU;2!F
M:6QE(&EN<W1E860@;V8@=&AE(&1E9F%U;'0G*3L*("`@("`@("`@("`@("`@
M("1C+3YW<FET96QN*"<@("`@("`@("`@("`@("`@("`@("`@("`@;VYE("AC
M;VUP96YD:75M+G!O(&EN('1H92!H;W)D92]P;R!D:7)E8W1O<GDI+B<I.PH@
M("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@+6XL("TM;F\M8V]M<&5N
M9&EU;2`@("!$;VY<)W0@=7-E(&$@8V]M<&5N9&EU;2XG*3L*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T@96QS92!["B`@("`@("`@
M)&,M/G=R:71E;&XH)U5S86=E.B<@+B`G('1R86YS;&%T:6]N+G!H<"!;;W!T
M:6]N<UT@8V]M;6%N9"!;8V]M;6%N9"UO<'1I;VYS72<I.PH@("`@("`@("1C
M+3YW<FET96QN*'-T<E]R97!E870H)R`G+"!3=')I;F<Z.FQE;F=T:"@G57-A
M9V4Z)RDI("X@)R!T<F%N<VQA=&EO;BYP:'`@6VAE;'!\+6A\+2UH96QP72!;
M8V]M;6%N9%TG*3L*("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@("1C
M+3YW<FET96QN*"=(96QP97(@87!P;&EC871I;VX@=&\@8W)E871E(&%N9"!M
M86EN=&%I;B!T<F%N<VQA=&EO;G,@9F]R('1H92!(;W)D92<I.PH@("`@("`@
M("1C+3YW<FET96QN*"=F<F%M97=O<FL@86YD(&ET<R!A<'!L:6-A=&EO;G,N
M)RD["B`@("`@("`@)&,M/G=R:71E;&XH)T9O<B!A;B!I;G1R;V1U8W1I;VX@
M<F5A9"!T:&4@9FEL92!214%$344@:6X@=&AI<R!D:7)E8W1O<GDN)RD["B`@
M("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("`D8RT^=W)I=&5L;B@G0V]M
M;6%N9',Z)RD["B`@("`@("`@)&,M/G=R:71E;&XH)R`@:&5L<"`@("`@("`@
M4VAO=R!T:&ES(&AE;'`@;65S<V%G92XG*3L*("`@("`@("`D8RT^=W)I=&5L
M;B@G("!C;VUP96YD:75M("!296)U:6QD('1H92!C;VUP96YD:75M(&9I;&4N
M(%=A<FYI;F<Z(%1H:7,@;W9E<G=R:71E<R!T:&4G*3L*("`@("`@("`D8RT^
M=W)I=&5L;B@G("`@("`@("`@("`@("!C=7)R96YT(&-O;7!E;F1I=6TN)RD[
M"B`@("`@("`@)&,M/G=R:71E;&XH)R`@97AT<F%C="`@("`@1V5N97)A=&4@
M4$\@=&5M<&QA=&4@*"YP;W0I(&9I;&5S+B<I.PH@("`@("`@("1C+3YW<FET
M96QN*"<@(&EN:70@("`@("`@($-R96%T92!O;F4@;W(@;6]R92!03R!F:6QE
M<R!F;W(@82!N97<@;&]C86QE+B!787)N:6YG.B!4:&ES)RD["B`@("`@("`@
M)&,M/G=R:71E;&XH)R`@("`@("`@("`@("`@;W9E<G=R:71E<R!T:&4@97AI
M<W1I;F<@4$\@9FEL97,@;V8@=&AI<R!L;V-A;&4N)RD["B`@("`@("`@)&,M
M/G=R:71E;&XH)R`@;65R9V4@("`@("`@365R9V4@=&AE(&-U<G)E;G0@4$\@
M9FEL92!W:71H('1H92!C=7)R96YT(%!/('1E;7!L871E(&9I;&4N)RD["B`@
M("`@("`@)&,M/G=R:71E;&XH)R`@=7!D871E("`@("`@4G5N(&5X=')A8W0@
M86YD(&UE<F=E('-E<75E;G0N)RD["B`@("`@("`@)&,M/G=R:71E;&XH)R`@
M=7!D871E+6AE;'`@17AT<F%C="!A;&P@;F5W(&%N9"!C:&%N9V5D(&5N=')I
M97,@9G)O;2!T:&4@16YG;&ES:"!834P@:&5L<"<I.PH@("`@("`@("1C+3YW
M<FET96QN*"<@("`@("`@("`@("`@(&9I;&4@86YD(&UE<F=E('1H96T@=VET
M:"!T:&4@97AI<W1I;F<@;VYE<RXG*3L*("`@("`@("`D8RT^=W)I=&5L;B@G
M("!C;&5A;G5P("`@("!#;&5A;G,@=&AE(%!/(&9I;&5S('5P(&9R;VT@=6YT
M<F%N<VQA=&5D(&%N9"!O8G-O;&5T92!E;G1R:65S+B<I.PH@("`@("`@("1C
M+3YW<FET96QN*"<@(&UA:V4@("`@("`@($)U:6QD(&)I;F%R>2!-3R!F:6QE
M<R!F<F]M('1H92!S<&5C:69I960@4$\@9FEL97,N)RD["B`@("`@("`@)&,M
M/G=R:71E;&XH)R`@;6%K92UH96QP("`@36%R:R!A;&P@96YT<FEE<R!I;B!T
M:&4@6$U,(&AE;'`@9FEL92!B96EN9R!U<"UT;RUD871E(&%N9"<I.PH@("`@
M("`@("1C+3YW<FET96QN*"<@("`@("`@("`@("`@('!R97!A<F4@=&AE(&9I
M;&4@9F]R('1H92!N97AT(&5X96-U=&EO;B!O9B!U<&1A=&4M:&5L<"X@66]U
M)RD["B`@("`@("`@)&,M/G=R:71E;&XH)R`@("`@("`@("`@("`@<VAO=6QD
M(&]N;'D@<G5N(&UA:V4M:&5L<"!!1E1%4B!U<&1A=&4M:&5L<"!A;F0@<F5V
M:7-I;F<@=&AE)RD["B`@("`@("`@)&,M/G=R:71E;&XH)R`@("`@("`@("`@
M("`@:&5L<"!F:6QE+B<I.PH@("`@("`@("1C+3YW<FET96QN*"<@(&-O;6UI
M="`@("`@($-O;6UI="!T<F%N<VQA=&EO;G,@=&\@=&AE($-64R!S97)V97(N
M)RD["B`@("`@("`@)&,M/G=R:71E;&XH)R`@8V]M;6ET+6AE;'`@0V]M;6ET
M(&AE;'`@9FEL97,@=&\@=&AE($-64R!S97)V97(N)RD["B`@("!]"B`@("`D
M8RT^=W)I=&5L;B@I.PH@("`@)&,M/G=R:71E;&XH)T]P=&EO;G,Z)RD["B`@
M("`D8RT^=W)I=&5L;B@G("`M8BP@+2UB87-E/2]0051(("!&=6QL('!A=&@@
M=&\@=&AE("A(;W)D92D@8F%S92!D:7)E8W1O<GD@=&AA="!S:&]U;&0@8F4G
M*3L*("`@("1C+3YW<FET96QN*"<@("`@("`@("`@("`@("`@("`@('5S960N
M)RD["B`@("`D8RT^=W)I=&5L;B@G("`M9"P@+2UD96)U9R`@("`@("!3:&]W
M(&5R<F]R(&UE<W-A9V5S(&9R;VT@=&AE(&5X96-U=&5D(&)I;F%R:65S+B<I
M.PH@("`@)&,M/G=R:71E;&XH)R`@+6@L("TM:&5L<"`@("`@("`@4VAO=R!T
M:&ES(&AE;'`@;65S<V%G92XG*3L*("`@("1C+3YW<FET96QN*"<@("UT+"`M
M+71E<W0@("`@("`@(%-H;W<@=&AE(&5X96-U=&5D(&-O;6UA;F1S(&)U="!D
M;VY<)W0@<G5N(&%N>71H:6YG+B<I.PI]"@IF=6YC=&EO;B!C:&5C:U]B:6YA
M<FEE<R@I"GL*("`@(&=L;V)A;"`D9V5T=&5X=%]V97)S:6]N+"`D8SL*"B`@
M("`D8RT^=W)I=&5L;B@G4V5A<F-H:6YG(&=E='1E>'0@8FEN87)I97,N+BXG
M*3L*("`@(')E<75I<F5?;VYC92`G4WES=&5M+G!H<"<["B`@("!F;W)E86-H
M("AA<G)A>2@G9V5T=&5X="<L("=M<V=A='1R:6(G+"`G;7-G8V%T)RP@)VUS
M9V-O;6TG+"`G;7-G9FUT)RP@)VUS9VEN:70G+"`G;7-G;65R9V4G+"`G>&=E
M='1E>'0G*2!A<R`D8FEN87)Y*2!["B`@("`@("`@96-H;R`D8FEN87)Y("X@
M)RXN+B`G.PH@("`@("`@("1'3$]"04Q36R1B:6YA<GE=(#T@4WES=&5M.CIW
M:&EC:"@D8FEN87)Y*3L*("`@("`@("!I9B`H)$=,3T)!3%-;)&)I;F%R>5TI
M('L*("`@("`@("`@("`@)&,M/G=R:71E;&XH)&,M/F=R965N*"=F;W5N9#H@
M)RD@+B`D1TQ/0D%,4ULD8FEN87)Y72D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&,M/G=R:71E;&XH)&,M/G)E9"@G;F]T(&9O=6YD)RDI.PH@
M("`@("`@("`@("!F;V]T97(H*3L*("`@("`@("!]"B`@("!]"B`@("`D8RT^
M=W)I=&5L;B@I.PH*("`@("1O=70@/2`G)SL*("`@(&5X96,H)$=,3T)!3%-;
M)V=E='1E>'0G72`N("<@+2UV97)S:6]N)RP@)&]U="P@)')E="D["B`@("`D
M<W!L:70@/2!E>'!L;V1E*"<@)RP@)&]U=%LP72D["B`@("!E8VAO("=G971T
M97AT('9E<G-I;VXZ("<@+B`D<W!L:71;8V]U;G0H)'-P;&ET*2`M(#%=.PH@
M("`@)&=E='1E>'1?=F5R<VEO;B`](&5X<&QO9&4H)RXG+"`D<W!L:71;8V]U
M;G0H)'-P;&ET*2`M(#%=*3L*("`@(&EF("@D9V5T=&5X=%]V97)S:6]N6S!=
M(#T](#`@)B8@)&=E='1E>'1?=F5R<VEO;ELQ72`\(#$R*2!["B`@("`@("`@
M)$=,3T)!3%-;)W!H<%]S=7!P;W)T)UT@/2!F86QS93L*("`@("`@("`D8RT^
M=W)I=&5L;B@I.PH@("`@("`@("1C+3YW<FET96QN*"1C+3YR960H)U=A<FYI
M;F<Z("<I("X@)UEO=7(@9V5T=&5X="!V97)S:6]N(&ES('1O;R!O;&0@86YD
M(&1O97,@;F]T('-U<'!O<G0@4$A0(&YA=&EV96QY+B<I.PH@("`@("`@("1C
M+3YW<FET96QN*"=.;W0@86QL('-T<FEN9W,@=VEL;"!B92!E>'1R86-T960N
M)RD["B`@("!](&5L<V4@>PH@("`@("`@("1'3$]"04Q36R=P:'!?<W5P<&]R
M="==(#T@=')U93L*("`@("`@("`D8RT^=W)I=&5L;B@D8RT^9W)E96XH)R`G
M("X@)T]+)RDI.PH@("`@?0H@("`@)&,M/G=R:71E;&XH*3L*?0H*9G5N8W1I
M;VX@<V5A<F-H7V9I;&4H)&9I;&4L("1D:7(@/2`G+B<L("1L;V-A;"`](&9A
M;'-E*0I["B`@("!S=&%T:6,@)&9F.PH@("`@:68@*"%I<W-E="@D9F8I*2![
M"B`@("`@("`@)&9F(#T@)FYE=R!&:6QE7T9I;F0H*3L*("`@('T*"B`@("!I
M9B`H<W5B<W1R*"1F:6QE+"`P+"`Q*2`A/2!$4RD@>PH@("`@("`@("1F:6QE
M(#T@(B\D9FEL92\B.PH@("`@?0H*("`@(&EF("@D;&]C86PI('L*("`@("`@
M("`D9FEL97,@/2`D9F8M/F=L;V(H)&9I;&4L("1D:7(L("=P97)L)RD["B`@
M("`@("`@)&9I;&5S(#T@87)R87E?;6%P*&-R96%T95]F=6YC=&EO;B@G)&9I
M;&4G+"`G<F5T=7)N("(G("X@)&1I<B`N($13("X@)R(@+B`D9FEL93LG*2P@
M)&9I;&5S*3L*("`@("`@("!R971U<FX@)&9I;&5S.PH@("`@?2!E;'-E('L*
M("`@("`@("!R971U<FX@)&9F+3YS96%R8V@H)&9I;&4L("1D:7(L("=P97)L
M)RD["B`@("!]"GT*"F9U;F-T:6]N('-E87)C:%]E>'0H)&5X="P@)&1I<B`]
M("<N)RP@)&QO8V%L(#T@9F%L<V4I"GL*("`@(')E='5R;B!S96%R8VA?9FEL
M92@B+BM<7"XD97AT7"0B+"`D9&ER+"`D;&]C86PI.PI]"@IF=6YC=&EO;B!G
M971?<&]?9FEL97,H)&1I<BD*>PH@("`@)&QA;F=S(#T@<V5A<F-H7V5X="@G
M<&\G+"`D9&ER*3L*("`@(&EF("@H)&ME>2`](&%R<F%Y7W-E87)C:"@D9&ER
M("X@1%,@+B`G;65S<V%G97,N<&\G+"`D;&%N9W,I*2`A/3T@9F%L<V4I('L*
M("`@("`@("!U;G-E="@D;&%N9W-;)&ME>5TI.PH@("`@?0H@("`@:68@*"@D
M:V5Y(#T@87)R87E?<V5A<F-H*"1D:7(@+B!$4R`N("=C;VUP96YD:75M+G!O
M)RP@)&QA;F=S*2D@(3T](&9A;'-E*2!["B`@("`@("`@=6YS970H)&QA;F=S
M6R1K97E=*3L*("`@('T*("`@(')E='5R;B`D;&%N9W,["GT*"F9U;F-T:6]N
M(&=E=%]L86YG=6%G97,H)&1I<BD*>PH@("`@9VQO8F%L("1C=7)D:7(["@H@
M("`@8VAD:7(H)&1I<BD["B`@("`D;&%N9W,@/2!G971?<&]?9FEL97,H)W!O
M)RD["B`@("`D;&%N9W,@/2!A<G)A>5]M87`H8W)E871E7V9U;F-T:6]N*"<D
M;&%N9R<L("=R971U<FX@<W1R7W)E<&QA8V4H(G!O(B`N($13+"`B(BP@<W1R
M7W)E<&QA8V4H(BYP;R(L("(B+"`D;&%N9RDI.R<I+"`D;&%N9W,I.PH@("`@
M8VAD:7(H)&-U<F1I<BD["B`@("!R971U<FX@)&QA;F=S.PI]"@IF=6YC=&EO
M;B!S96%R8VA?87!P;&EC871I;VYS*"D*>PH@("`@)&1I<G,@/2!A<G)A>2@I
M.PH@("`@)&AO<F1E(#T@9F%L<V4["B`@("!I9B`H0&ES7V1I<BA"05-%("X@
M1%,@+B`G<&\G*2D@>PH@("`@("`@("1D:7)S6UT@/2!"05-%.PH@("`@("`@
M("1H;W)D92`]('1R=64["B`@("!]"B`@("`D9&@@/2!`;W!E;F1I<BA"05-%
M*3L*("`@(&EF("@D9&@I('L*("`@("`@("!W:&EL92`H)&5N=')Y(#T@0')E
M861D:7(H)&1H*2D@>PH@("`@("`@("`@("`D9&ER(#T@0D%312`N($13("X@
M)&5N=')Y.PH@("`@("`@("`@("!I9B`H:7-?9&ER*"1D:7(I("8F"B`@("`@
M("`@("`@("`@("!S=6)S='(H)&5N=')Y+"`P+"`Q*2`A/2`G+B<@)B8*("`@
M("`@("`@("`@("`@(&9I;&5I;F]D92A(3U)$15]"05-%*2`A/2!F:6QE:6YO
M9&4H)&1I<BDI('L*("`@("`@("`@("`@("`@("1S=6(@/2!O<&5N9&ER*"1D
M:7(I.PH@("`@("`@("`@("`@("`@:68@*"1S=6(I('L*("`@("`@("`@("`@
M("`@("`@("!W:&EL92`H)'-U8F5N=')Y(#T@<F5A9&1I<B@D<W5B*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'-U8F5N=')Y(#T]("=P;R<@
M)B8@:7-?9&ER*"1D:7(@+B!$4R`N("1S=6)E;G1R>2DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1D:7)S6UT@/2`D9&ER.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"1E;G1R>2`]/2`G:&]R9&4G*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&AO<F1E(#T@=')U93L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@A)&AO<F1E*2!["B`@
M("`@("`@("`@(&%R<F%Y7W5N<VAI9G0H)&1I<G,L($A/4D1%7T)!4T4I.PH@
M("`@("`@('T*("`@('T*"B`@("!R971U<FX@)&1I<G,["GT*"F9U;F-T:6]N
M('-T<FEP7VAO<F1E*"1F:6QE*0I["B`@("!I9B`H:7-?87)R87DH)&9I;&4I
M*2!["B`@("`@("`@<F5T=7)N(&%R<F%Y7VUA<"AC<F5A=&5?9G5N8W1I;VXH
M)R1F:6QE)RP@)W)E='5R;B!S=')I<%]H;W)D92@D9FEL92D[)RDL("1F:6QE
M*3L*("`@('T@96QS92!["B`@("`@("`@<F5T=7)N('-T<E]R97!L86-E*$)!
M4T4@+B!$4RP@)R<L("1F:6QE*3L*("`@('T*?0H*9G5N8W1I;VX@>'1R86-T
M*"D*>PH@("`@9VQO8F%L("1C;61?;W!T:6]N<RP@)&%P<',L("1D:7)S+"`D
M9&5B=6<L("1T97-T+"`D8RP@)&=E='1E>'1?=F5R<VEO;BP@)'-I;&5N8V4L
M("1C=7)D:7(["@H@("`@9F]R96%C:"`H)&-M9%]O<'1I;VYS6S!=(&%S("1O
M<'1I;VXI('L*("`@("`@("!S=VET8V@@*"1O<'1I;VY;,%TI('L*("`@("`@
M("`@("`@8V%S92`G:"<Z"B`@("`@("`@("`@("`@("!U<V%G92@I.PH@("`@
M("`@("`@("`@("`@9F]O=&5R*"D["B`@("`@("`@("`@(&-A<V4@)VTG.@H@
M("`@("`@("`@("!C87-E("<M+6UO9'5L92<Z"B`@("`@("`@("`@("`@("`D
M;6]D=6QE(#T@)&]P=&EO;ELQ73L*("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@('T*("`@('T*("`@(')E<75I<F5?;VYC92`G2&]R9&4O07)R87DN
M<&AP)SL*("`@(&EF("@D1TQ/0D%,4ULG<&AP7W-U<'!O<G0G72D@>PH@("`@
M("`@("1L86YG=6%G92`]("=02%`G.PH@("`@?2!E;'-E('L*("`@("`@("`D
M;&%N9W5A9V4@/2`G0RLK)SL*("`@('T*("`@(&9O<B`H)&D@/2`P.R`D:2`\
M(&-O=6YT*"1D:7)S*3L@)&DK*RD@>PH@("`@("`@(&EF("@A96UP='DH)&UO
M9'5L92D@)B8@)&UO9'5L92`A/2`D87!P<ULD:5TI('L*("`@("`@("`@("`@
M8V]N=&EN=64["B`@("`@("`@?0H@("`@("`@('!R:6YT9B@G17AT<F%C=&EN
M9R!F<F]M("5S+BXN("<L("1A<'!S6R1I72D["B`@("`@("`@8VAD:7(H)&1I
M<G-;)&E=*3L*("`@("`@("!I9B`H)&%P<'-;)&E=(#T]("=H;W)D92<I('L*
M("`@("`@("`@("`@)&9I;&5S(#T@<V5A<F-H7V5X="@G<&AP)RP@)RXG+"!T
M<G5E*3L*("`@("`@("`@("`@9F]R96%C:"`H87)R87DH)V%D;6EN)RP@)V9R
M86UE=V]R:R<L("=L:6(G+"`G<V5R=FEC97,G+"`G=&5M<&QA=&5S)RP@)W5T
M:6PG+"`G8V]N9FEG)R`N($13("X@)W1H96UE<R<I(&%S("1S96%R8VA?9&ER
M*2!["B`@("`@("`@("`@("`@("`D9FEL97,@/2!A<G)A>5]M97)G92@D9FEL
M97,L('-E87)C:%]E>'0H)RAP:'!\:6YC?&IS*2<L("1S96%R8VA?9&ER*2D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&9I;&5S(#T@87)R87E?;65R
M9V4H)&9I;&5S+"!S96%R8VA?97AT*"=D:7-T)RP@)V-O;F9I9R<I*3L*("`@
M("`@("`@("`@)'-H(#T@)$=,3T)!3%-;)WAG971T97AT)UT@+B`G("TM;&%N
M9W5A9V4])R`N("1L86YG=6%G92`N"B`@("`@("`@("`@("`@("`@("<@+2UF
M<F]M+6-O9&4]:7-O+3@X-3DM,2`M+6ME>7=O<F0]7R`M+7-O<G0M;W5T<'5T
M("TM8V]P>7)I9VAT+6AO;&1E<CTB2&]R9&4@4')O:F5C="(G.PH@("`@("`@
M("`@("!I9B`H)&=E='1E>'1?=F5R<VEO;ELP72`^(#`@?'P@)&=E='1E>'1?
M=F5R<VEO;ELQ72`^(#$Q*2!["B`@("`@("`@("`@("`@("`D<V@@+CT@)R`M
M+6US9VED+6)U9W,M861D<F5S<STB9&5V0&QI<W1S+FAO<F1E+F]R9R(G.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1F:6QE(#T@)&1I<G-;)&E=("X@
M1%,@+B`G<&\G("X@1%,@+B`D87!P<ULD:5T@+B`G+G!O="<["B`@("`@("`@
M("`@(&EF("AF:6QE7V5X:7-T<R@D9FEL92D@)B8@(6ES7W=R:71A8FQE*"1F
M:6QE*2D@>PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)&,M/G)E9"AS
M<')I;G1F*"<E<R!I<R!N;W0@=W)I=&%B;&4N)RP@)&9I;&4I*2D["B`@("`@
M("`@("`@("`@("!F;V]T97(H*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D=&UP7V9I;&4@/2`D9FEL92`N("<N=&UP+G!O="<["B`@("`@("`@("`@
M("1S:"`N/2`G("UO("<@+B`D=&UP7V9I;&4@+B`G("<@+B!I;7!L;V1E*"<@
M)RP@)&9I;&5S*3L*("`@("`@("`@("`@:68@*$!F:6QE7V5X:7-T<R@D9&ER
M<ULD:5T@+B`G+W!O+W1R86YS;&%T:6]N+G!H<"<I*2!["B`@("`@("`@("`@
M("`@("`D<V@@+CT@)R!P;R]T<F%N<VQA=&EO;BYP:'`G.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&EF("@A)&1E8G5G*2!["B`@("`@("`@("`@("`@
M("`D<V@@+CT@)'-I;&5N8V4["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*"1D96)U9R!\?"`D=&5S="D@>PH@("`@("`@("`@("`@("`@)&,M/G=R
M:71E;&XH)T5X96-U=&EN9SHG*3L*("`@("`@("`@("`@("`@("1C+3YW<FET
M96QN*"1S:"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"$D=&5S
M="D@97AE8R@D<V@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F
M:6QE<R`]('-E87)C:%]E>'0H)RAP:'!\:6YC?&IS*2<I.PH@("`@("`@("`@
M("`D9FEL97,@/2!A<G)A>5]F:6QT97(H)&9I;&5S+"!C<F5A=&5?9G5N8W1I
M;VXH)R1F:6QE)RP@)W)E='5R;B!S=6)S='(H)&9I;&4L(#`L(#DI("$]("(N
M(B`N($13("X@(F-O;F9I9R(@+B!$4SLG*2D["B`@("`@("`@("`@("1F:6QE
M<R`](&%R<F%Y7VUE<F=E*"1F:6QE<RP@<V5A<F-H7V5X="@G9&ES="<L("=C
M;VYF:6<G*2D["B`@("`@("`@("`@("1S:"`]("1'3$]"04Q36R=X9V5T=&5X
M="==("X@)R`M+6QA;F=U86=E/2<@+B`D;&%N9W5A9V4@+@H@("`@("`@("`@
M("`@("`@("`G("TM:V5Y=V]R9#U?("TM<V]R="UO=71P=70@+2UF;W)C92UP
M;R`M+6-O<'ER:6=H="UH;VQD97(](DAO<F1E(%!R;VIE8W0B)SL*("`@("`@
M("`@("`@:68@*"1G971T97AT7W9E<G-I;VY;,%T@/B`P('Q\("1G971T97AT
M7W9E<G-I;VY;,5T@/B`Q,2D@>PH@("`@("`@("`@("`@("`@)'-H("X]("<@
M+2UM<V=I9"UB=6=S+6%D9')E<W,](F1E=D!L:7-T<RYH;W)D92YO<F<B)SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D9FEL92`]("=P;R<@+B!$4R`N
M("1A<'!S6R1I72`N("<N<&]T)SL*("`@("`@("`@("`@:68@*&9I;&5?97AI
M<W1S*"1F:6QE*2`F)B`A:7-?=W)I=&%B;&4H)&9I;&4I*2!["B`@("`@("`@
M("`@("`@("`D8RT^=W)I=&5L;B@D8RT^<F5D*'-P<FEN=&8H)R5S(&ES(&YO
M="!W<FET86)L92XG+"`D9FEL92DI*3L*("`@("`@("`@("`@("`@(&9O;W1E
M<B@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T;7!?9FEL92`]("1F
M:6QE("X@)RYT;7`N<&]T)SL*("`@("`@("`@("`@)'-H("X]("<@+6\@)R`N
M("1T;7!?9FEL92`N("<@)R`N(&EM<&QO9&4H)R`G+"`D9FEL97,I("X@*"1D
M96)U9R`_("<G(#H@)'-I;&5N8V4I.PH@("`@("`@("`@("!I9B`H)&1E8G5G
M('Q\("1T97-T*2!["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G17AE
M8W5T:6YG.B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)'-H*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(21T97-T*2!E>&5C*"1S
M:"D["B`@("`@("`@?0H@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D=&UP7V9I
M;&4I*2!["B`@("`@("`@("`@("1F:6QE<R`]('-E87)C:%]E>'0H)VAT;6PG
M+"`G=&5M<&QA=&5S)RD["B`@("`@("`@("`@(&EF("@A)'1E<W0I("1T;7`@
M/2!F;W!E;B@D9FEL92`N("<N=&5M<&QA=&5S)RP@)W<G*3L*("`@("`@("`@
M("`@9F]R96%C:"`H)&9I;&5S(&%S("1T96UP;&%T92D@>PH@("`@("`@("`@
M("`@("`@)&9P(#T@9F]P96XH)'1E;7!L871E+"`G<B<I.PH@("`@("`@("`@
M("`@("`@)&QI;F5N;R`](#`["B`@("`@("`@("`@("`@("!W:&EL92`H*"1L
M:6YE(#T@9F=E=',H)&9P+"`T,#DV*2D@(3T](&9A;'-E*2!["B`@("`@("`@
M("`@("`@("`@("`@)&QI;F5N;RLK.PH@("`@("`@("`@("`@("`@("`@("1O
M9F9S970@/2`P.PH@("`@("`@("`@("`@("`@("`@('=H:6QE("@H)&QE9G0@
M/2!S=')P;W,H)&QI;F4L("<\9V5T=&5X=#XG+"`D;V9F<V5T*2D@(3T](&9A
M;'-E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1L969T("L](#D["B`@
M("`@("`@("`@("`@("`@("`@("`@("1B=69F97(@/2`G)SL*("`@("`@("`@
M("`@("`@("`@("`@("`@)&QI;F5S<&%N(#T@,#L*("`@("`@("`@("`@("`@
M("`@("`@("`@=VAI;&4@*"@D96YD(#T@<W1R<&]S*"1L:6YE+"`G/"]G971T
M97AT/B<L("1L969T*2D@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D8G5F9F5R("X]('-U8G-T<B@D;&EN92P@)&QE9G0I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&QE9G0@/2`P.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&QI;F4@/2!F9V5T<R@D9G`L(#0P.38I
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&QI;F5S<&%N*RL["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&QI;F4@/3T](&9A;'-E
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&,M/G=R:71E
M;&XH)&,M/G)E9"AS<')I;G1F*"(\9V5T=&5X=#X@=&%G(&YO="!C;&]S960@
M:6X@9FEL92`E<RY<;D]P96YI;F<@=&%G(&9O=6YD(&EN(&QI;F4@)60N(BP@
M)'1E;7!L871E+"`D;&EN96YO*2DI.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K(#(["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`@("`@)&)U9F9E<B`N/2!S=6)S='(H)&QI;F4L("1L969T+"`D96YD
M("T@)&QE9G0I.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(21T97-T
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F=W)I=&4H)'1M<"P@
M(B,Z("1T96UP;&%T93HD;&EN96YO7&XB*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&9W<FET92@D=&UP+"`G;7-G:60@(B<@+B!S=')?<F5P;&%C
M92AA<G)A>2@G(B<L(")<;B(I+"!A<G)A>2@G7"(G+"`B7%QN7")<;EPB(BDL
M("1B=69F97(I("X@(EPB7&XB*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&9W<FET92@D=&UP+"`G;7-G<W1R("(B)R`N(")<;EQN(BD["B`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@
M)&]F9G-E="`]("1E;F0@*R`Q,#L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!F8VQO<V4H)'1M<"D["B`@("`@
M("`@("`@("1S:"`]("1'3$]"04Q36R=M<V=C;VUM)UT@+B`B("TM;6]R92UT
M:&%N/3`@+2US;W)T+6]U='!U="!<(B1T;7!?9FEL95PB(%PB)&9I;&4N=&5M
M<&QA=&5S7"(@+2UO=71P=70M9FEL92!<(B1T;7!?9FEL95PB(B`N("1S:6QE
M;F-E.PH@("`@("`@("`@("!I9B`H)&1E8G5G('Q\("1T97-T*2!["B`@("`@
M("`@("`@("`@("`D8RT^=W)I=&5L;B@G17AE8W5T:6YG.B<I.PH@("`@("`@
M("`@("`@("`@)&,M/G=R:71E;&XH)'-H*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H(21T97-T*2!["B`@("`@("`@("`@("`@("!E>&5C*"1S
M:"D["B`@("`@("`@("`@("`@("!U;FQI;FLH)&9I;&4@+B`G+G1E;7!L871E
M<R<I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AF:6QE7V5X:7-T
M<R@D9FEL92DI('L*("`@("`@("`@("`@("`@("1D:69F(#T@87)R87E?9&EF
M9BAF:6QE*"1T;7!?9FEL92DL(&9I;&4H)&9I;&4I*3L*("`@("`@("`@("`@
M("`@("1D:69F(#T@<')E9U]G<F5P*"<O7B)03U0M0W)E871I;VXM1&%T93HO
M)RP@)&1I9F8L(%!214=?1U)%4%])3E9%4E0I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(&EF("@A9FEL95]E>&ES=',H)&9I;&4I('Q\(&-O
M=6YT*"1D:69F*2D@>PH@("`@("`@("`@("!`=6YL:6YK*"1F:6QE*3L*("`@
M("`@("`@("`@<F5N86UE*"1T;7!?9FEL92P@)&9I;&4I.PH@("`@("`@("`@
M("`D8RT^=W)I=&5L;B@D8RT^9W)E96XH)W5P9&%T960G*2D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@0'5N;&EN:R@D=&UP7V9I;&4I.PH@("`@
M("`@("`@("`D8RT^=W)I=&5L;B@D8RT^8F]L9"@G;F]T(&-H86YG960G*2D[
M"B`@("`@("`@?0H@("`@("`@(&-H9&ER*"1C=7)D:7(I.PH@("`@?0I]"@IF
M=6YC=&EO;B!M97)G92@I"GL*("`@(&=L;V)A;"`D8VUD7V]P=&EO;G,L("1A
M<'!S+"`D9&ER<RP@)&1E8G5G+"`D=&5S="P@)&,["@H@("`@)&-O;7!E;F1I
M=6T@/2`G("TM8V]M<&5N9&EU;3TB)R`N($)!4T4@+B!$4R`N("=P;R<@+B!$
M4R`N("=C;VUP96YD:75M+G!O(B<["B`@("!F;W)E86-H("@D8VUD7V]P=&EO
M;G-;,%T@87,@)&]P=&EO;BD@>PH@("`@("`@('-W:71C:"`H)&]P=&EO;ELP
M72D@>PH@("`@("`@("`@("!C87-E("=H)SH*("`@("`@("`@("`@("`@('5S
M86=E*"D["B`@("`@("`@("`@("`@("!F;V]T97(H*3L*("`@("`@("`@("`@
M8V%S92`G;"<Z"B`@("`@("`@("`@(&-A<V4@)RTM;&]C86QE)SH*("`@("`@
M("`@("`@("`@("1L86YG(#T@)&]P=&EO;ELQ73L*("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("!C87-E("=M)SH*("`@("`@("`@("`@8V%S
M92`G+2UM;V1U;&4G.@H@("`@("`@("`@("`@("`@)&UO9'5L92`]("1O<'1I
M;VY;,5T["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S
M92`G8R<Z"B`@("`@("`@("`@(&-A<V4@)RTM8V]M<&5N9&EU;2<Z"B`@("`@
M("`@("`@("`@("`D8V]M<&5N9&EU;2`]("<@+2UC;VUP96YD:75M/2<@+B`D
M;W!T:6]N6S%=.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M(&-A<V4@)VXG.@H@("`@("`@("`@("!C87-E("<M+6YO+6-O;7!E;F1I=6TG
M.@H@("`@("`@("`@("`@("`@)&-O;7!E;F1I=6T@/2`G)SL*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*("`@(&EF("@A:7-S970H
M)&QA;F<I("8F("%E;7!T>2@D8V]M<&5N9&EU;2DI('L*("`@("`@("`D8RT^
M=W)I=&5L;B@D8RT^<F5D*"=%<G)O<CH@)R`N("=.;R!L;V-A;&4@<W!E8VEF
M:65D+B<I*3L*("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@('5S86=E
M*"D["B`@("`@("`@9F]O=&5R*"D["B`@("!]"@H@("`@8VQE86YU<"@I.PH*
M("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1D:7)S*3L@)&DK*RD@>PH@
M("`@("`@(&EF("@A96UP='DH)&UO9'5L92D@)B8@)&UO9'5L92`A/2`D87!P
M<ULD:5TI('L*("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@?0H@("`@
M("`@("1C+3YW<FET96QN*'-P<FEN=&8H)TUE<F=I;F<@=')A;G-L871I;VX@
M9F]R(&UO9'5L92`E<RXN+B<L("1C+3YB;VQD*"1A<'!S6R1I72DI*3L*("`@
M("`@("`D9&ER(#T@)&1I<G-;)&E=("X@1%,@+B`G<&\G("X@1%,["B`@("`@
M("`@:68@*&5M<'1Y*"1L86YG*2D@>PH@("`@("`@("`@("`D;&%N9W,@/2!G
M971?;&%N9W5A9V5S*"1D:7)S6R1I72D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@:68@*"%`9FEL95]E>&ES=',H)&1I<B`N("1L86YG("X@)RYP
M;R<I*2!["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G4VMI<'!E9"XN
M+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1L
M86YG<R`](&%R<F%Y*"1L86YG*3L*("`@("`@("!]"B`@("`@("`@9F]R96%C
M:"`H)&QA;F=S(&%S("1L;V-A;&4I('L*("`@("`@("`@("`@)&,M/G=R:71E
M;&XH<W!R:6YT9B@G365R9VEN9R!L;V-A;&4@)7,N+BX@)RP@)&,M/F)O;&0H
M)&QO8V%L92DI*3L*("`@("`@("`@("`@)'-H(#T@)$=,3T)!3%-;)VUS9VUE
M<F=E)UT@+B`G("TM=7!D871E("UV)R`N("1C;VUP96YD:75M("X@)R`B)R`N
M("1D:7(@+B`D;&]C86QE("X@)RYP;R(@(B<@+B`D9&ER("X@)&%P<'-;)&E=
M("X@)RYP;W0B)SL*("`@("`@("`@("`@:68@*"1D96)U9R!\?"`D=&5S="D@
M>PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)T5X96-U=&EN9SHG*3L*
M("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"1S:"D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*"$D=&5S="D@97AE8R@D<V@I.PH@("`@("`@
M("`@("`D8RT^=W)I=&5L;B@D8RT^9W)E96XH)V1O;F4G*2D["B`@("`@("`@
M?0H@("`@?0I]"@IF=6YC=&EO;B!S=&%T=7,H*0I["B`@("!R971U<FX["B`@
M("!G;&]B86P@)&-M9%]O<'1I;VYS+"`D87!P<RP@)&1I<G,L("1D96)U9RP@
M)'1E<W0L("1C.PH*("`@("1O=71P=70@/2`B<W1A='5S+FAT;6PB.PH@("`@
M9F]R96%C:"`H)&-M9%]O<'1I;VYS6S!=(&%S("1O<'1I;VXI('L*("`@("`@
M("!S=VET8V@@*"1O<'1I;VY;,%TI('L*("`@("`@("`@("`@8V%S92`G:"<Z
M"B`@("`@("`@("`@("`@("!U<V%G92@I.PH@("`@("`@("`@("`@("`@9F]O
M=&5R*"D["B`@("`@("`@("`@(&-A<V4@)VPG.@H@("`@("`@("`@("!C87-E
M("<M+6QO8V%L92<Z"B`@("`@("`@("`@("`@("`D;&%N9R`]("1O<'1I;VY;
M,5T["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G
M;2<Z"B`@("`@("`@("`@(&-A<V4@)RTM;6]D=6QE)SH*("`@("`@("`@("`@
M("`@("1M;V1U;&4@/2`D;W!T:6]N6S%=.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@(&-A<V4@)V\G.@H@("`@("`@("`@("!C87-E("<M
M+6]U='!U="<Z"B`@("`@("`@("`@("`@("`D;W5T<'5T(#T@)&]P=&EO;ELQ
M73L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@?0H@("`@?0H@("`@
M9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)&1I<G,I.R`D:2LK*2!["B`@("`@
M("`@:68@*"%E;7!T>2@D;6]D=6QE*2`F)B`D;6]D=6QE("$]("1A<'!S6R1I
M72D@>PH@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("!]"B`@("`@("`@
M)&,M/G=R:71E;&XH<W!R:6YT9B@G1V5N97)A=&EN9R!S=&%T=7,@9F]R(&UO
M9'5L92`E<RXN+B<L("1C+3YB;VQD*"1A<'!S6R1I72DI*3L*("`@("`@("!I
M9B`H96UP='DH)&QA;F<I*2!["B`@("`@("`@("`@("1L86YG<R`](&=E=%]L
M86YG=6%G97,H)&1I<G-;)&E=*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!I9B`H(4!F:6QE7V5X:7-T<R@D9&ER<ULD:5T@+B!$4R`N("=P;R<@
M+B!$4R`N("1L86YG("X@)RYP;R<I*2!["B`@("`@("`@("`@("`@("`D8RT^
M=W)I=&5L;B@G4VMI<'!E9"XN+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R
M:71E;&XH*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1L86YG<R`](&%R<F%Y*"1L86YG*3L*("`@("`@
M("!]"B`@("`@("`@9F]R96%C:"`H)&QA;F=S(&%S("1L;V-A;&4I('L*("`@
M("`@("`@("`@)&,M/G=R:71E;&XH<W!R:6YT9B@G4W1A='5S(&9O<B!L;V-A
M;&4@)7,N+BX@)RP@)&,M/F)O;&0H)&QO8V%L92DI*3L*("`@("`@("!]"B`@
M("!]"GT*"F9U;F-T:6]N(&-O;7!E;F1I=6TH*0I["B`@("!G;&]B86P@)&-M
M9%]O<'1I;VYS+"`D9&ER<RP@)&1E8G5G+"`D=&5S="P@)&,L("1S:6QE;F-E
M.PH*("`@("1D:7(@/2!"05-%("X@1%,@+B`G<&\G("X@1%,["B`@("`D861D
M(#T@)R<["B`@("!F;W)E86-H("@D8VUD7V]P=&EO;G-;,%T@87,@)&]P=&EO
M;BD@>PH@("`@("`@('-W:71C:"`H)&]P=&EO;ELP72D@>PH@("`@("`@("`@
M("!C87-E("=H)SH*("`@("`@("`@("`@("`@('5S86=E*"D["B`@("`@("`@
M("`@("`@("!F;V]T97(H*3L*("`@("`@("`@("`@8V%S92`G;"<Z"B`@("`@
M("`@("`@(&-A<V4@)RTM;&]C86QE)SH*("`@("`@("`@("`@("`@("1L86YG
M(#T@)&]P=&EO;ELQ73L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("!C87-E("=D)SH*("`@("`@("`@("`@8V%S92`G+2UD:7)E8W1O<GDG
M.@H@("`@("`@("`@("`@("`@)&1I<B`]("1O<'1I;VY;,5T["B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G82<Z"B`@("`@("`@
M("`@(&-A<V4@)RTM861D)SH*("`@("`@("`@("`@("`@("1A9&0@/2`G("<@
M+B`D;W!T:6]N6S%=.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M?0H@("`@?0H@("`@:68@*"%I<W-E="@D;&%N9RDI('L*("`@("`@("`D8RT^
M=W)I=&5L;B@D8RT^<F5D*"=%<G)O<CH@)R`N("=.;R!L;V-A;&4@<W!E8VEF
M:65D+B<I*3L*("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@('5S86=E
M*"D["B`@("`@("`@9F]O=&5R*"D["B`@("!]"B`@("!P<FEN=&8H)TUE<F=I
M;F<@86QL("5S+G!O(&9I;&5S('1O('1H92!C;VUP96YD:75M+BXN("<L("1L
M86YG*3L*("`@("1P;V9I;&5S(#T@87)R87DH*3L*("`@(&9O<B`H)&D@/2`P
M.R`D:2`\(&-O=6YT*"1D:7)S*3L@)&DK*RD@>PH@("`@("`@("1P;V9I;&4@
M/2`D9&ER<ULD:5T@+B!$4R`N("=P;R<@+B!$4R`N("1L86YG("X@)RYP;R<[
M"B`@("`@("`@:68@*&9I;&5?97AI<W1S*"1P;V9I;&4I*2!["B`@("`@("`@
M("`@("1P;V9I;&5S6UT@/2`D<&]F:6QE.PH@("`@("`@('T*("`@('T*("`@
M(&EF("@A96UP='DH)&1I<BD@)B8@<W5B<W1R*"1D:7(L("TQ*2`A/2!$4RD@
M>PH@("`@("`@("1D:7(@+CT@1%,["B`@("!]"B`@("`D<V@@/2`D1TQ/0D%,
M4ULG;7-G8V%T)UT@+B`G("TM<V]R="UO=71P=70@)R`N(&EM<&QO9&4H)R`G
M+"`D<&]F:6QE<RD@+B`D861D("X@)R`^("<@+B`D9&ER("X@)V-O;7!E;F1I
M=6TN<&\@)R`N("@D9&5B=6<@/R`G)R`Z("1S:6QE;F-E*3L*("`@(&EF("@D
M9&5B=6<@?'P@)'1E<W0I('L*("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@
M("`@("1C+3YW<FET96QN*"=%>&5C=71I;F<Z)RD["B`@("`@("`@)&,M/G=R
M:71E;&XH)'-H*3L*("`@('T*("`@(&EF("@D=&5S="D@>PH@("`@("`@("1R
M970@/2`P.PH@("`@?2!E;'-E('L*("`@("`@("!E>&5C*"1S:"P@)&]U="P@
M)')E="D["B`@("!]"B`@("!I9B`H)')E="`]/2`P*2!["B`@("`@("`@)&,M
M/G=R:71E;&XH)&,M/F=R965N*"=D;VYE)RDI.PH@("`@?2!E;'-E('L*("`@
M("`@("`D8RT^=W)I=&5L;B@D8RT^<F5D*"=F86EL960G*2D["B`@("!]"GT*
M"F9U;F-T:6]N(&EN:70H*0I["B`@("!G;&]B86P@)&-M9%]O<'1I;VYS+"`D
M87!P<RP@)&1I<G,L("1D96)U9RP@)'1E<W0L("1C+"`D<VEL96YC93L*"B`@
M("!F;W)E86-H("@D8VUD7V]P=&EO;G-;,%T@87,@)&]P=&EO;BD@>PH@("`@
M("`@('-W:71C:"`H)&]P=&EO;ELP72D@>PH@("`@("`@("`@("!C87-E("=H
M)SH*("`@("`@("`@("`@("`@('5S86=E*"D["B`@("`@("`@("`@("`@("!F
M;V]T97(H*3L*("`@("`@("`@("`@8V%S92`G;"<Z"B`@("`@("`@("`@(&-A
M<V4@)RTM;&]C86QE)SH*("`@("`@("`@("`@("`@("1L86YG(#T@)&]P=&EO
M;ELQ73L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E
M("=M)SH*("`@("`@("`@("`@8V%S92`G+2UM;V1U;&4G.@H@("`@("`@("`@
M("`@("`@)&UO9'5L92`]("1O<'1I;VY;,5T["B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("!]"B`@("!]"B`@("!I9B`H96UP='DH)&QA;F<I*2![
M("1L86YG(#T@9V5T96YV*"=,04Y')RD[('T*("`@(&9O<B`H)&D@/2`P.R`D
M:2`\(&-O=6YT*"1D:7)S*3L@)&DK*RD@>PH@("`@("`@(&EF("@A96UP='DH
M)&UO9'5L92D@)B8@)&UO9'5L92`A/2`D87!P<ULD:5TI('L@8V]N=&EN=64[
M('T*("`@("`@("`D<&%C:V%G92`]('5C9FER<W0H)&%P<'-;)&E=*3L*("`@
M("`@("`D<&%C:V%G95]U(#T@4W1R:6YG.CIU<'!E<B@D87!P<ULD:5TI.PH@
M("`@("`@($!I;F-L=61E("1D:7)S6R1I72`N("<O;&EB+W9E<G-I;VXN<&AP
M)SL*("`@("`@("`D=F5R<VEO;B`](&1E9FEN960H)'!A8VMA9V5?=2`N("=?
M5D524TE/3B<I(#\@8V]N<W1A;G0H)'!A8VMA9V5?=2`N("=?5D524TE/3B<I
M(#H@)S\_/R<["B`@("`@("`@<')I;G1F*"=);FET:6%L:7II;F<@;6]D=6QE
M("5S+BXN("<L("1A<'!S6R1I72D["B`@("`@("`@:68@*"%`9FEL95]E>&ES
M=',H)&1I<G-;)&E=("X@)R]P;R\G("X@)&%P<'-;)&E=("X@)RYP;W0G*2D@
M>PH@("`@("`@("`@("`D8RT^=W)I=&5L;B@D8RT^<F5D*"=F86EL960G*2D[
M"B`@("`@("`@("`@("1C+3YW<FET96QN*'-P<FEN=&8H)R5S(&YO="!F;W5N
M9"X@4G5N(%PG=')A;G-L871I;VX@97AT<F%C=%PG(&9I<G-T+B<L("1D:7)S
M6R1I72`N($13("X@)W!O)R`N($13("X@)&%P<'-;)&E=("X@)RYP;W0G*2D[
M"B`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@('T*("`@("`@("`D9&ER
M(#T@)&1I<G-;)&E=("X@1%,@+B`G<&\G("X@1%,["B`@("`@("`@)'-H(#T@
M)$=,3T)!3%-;)VUS9VEN:70G72`N("<@+2UN;RUT<F%N<VQA=&]R("UI("<@
M+B`D9&ER("X@)&%P<'-;)&E=("X@)RYP;W0@)R`N"B`@("`@("`@("`@("`@
M*"%E;7!T>2@D;&%N9RD@/R`G("UO("<@+B`D9&ER("X@)&QA;F<@+B`G+G!O
M("TM;&]C86QE/2<@+B`D;&%N9R`Z("<G*2`N"B`@("`@("`@("`@("`@*"1D
M96)U9R`_("<G(#H@)'-I;&5N8V4I.PH@("`@("`@(&EF("@A96UP='DH)&QA
M;F<I("8F("%/4U]724Y$3U=3*2!["B`@("`@("`@("`@("1P;V9I;&4@/2`D
M9&ER<ULD:5T@+B`G+W!O+R<@+B`D;&%N9R`N("<N<&\G.PH@("`@("`@("`@
M("`D<V@@+CT@(CL@<V5D("=S+U!!0TM!1T4@<&%C:V%G92\D<&%C:V%G92!P
M86-K86=E+R<@)'!O9FEL92`B("X*("`@("`@("`@("`@("`@("`@(")\('-E
M9"`G<R]004-+04=%(%9%4E-)3TXO)'!A8VMA9V4@)'9E<G-I;VXO)R`B("X*
M("`@("`@("`@("`@("`@("`@(")\('-E9"`G<R]M97-S86=E<R!F;W(@4$%#
M2T%'12]M97-S86=E<R!F;W(@)'!A8VMA9V4O)R`B("X*("`@("`@("`@("`@
M("`@("`@(")\('-E9"`G<R],86YG=6%G92U496%M.B!N;VYE+TQA;F=U86=E
M+51E86TZ(&DQ.&Y`;&ES=',N:&]R9&4N;W)G+R<@(B`N"B`@("`@("`@("`@
M("`@("`@("`B/B`D<&]F:6QE+G1M<"(["B`@("`@("`@?0H@("`@("`@(&EF
M("@D9&5B=6<@?'P@)'1E<W0I('L*("`@("`@("`@("`@)&,M/G=R:71E;&XH
M)T5X96-U=&EN9SHG*3L*("`@("`@("`@("`@)&,M/G=R:71E;&XH)'-H*3L*
M("`@("`@("!]"B`@("`@("`@:68@*"1T97-T*2!["B`@("`@("`@("`@("1R
M970@/2`P.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&5X96,H)'-H
M+"`D;W5T+"`D<F5T*3L*("`@("`@("!]"B`@("`@("`@<F5N86UE*"1P;V9I
M;&4@+B`G+G1M<"<L("1P;V9I;&4I.PH@("`@("`@(&EF("@D<F5T(#T](#`I
M('L*("`@("`@("`@("`@)&,M/G=R:71E;&XH)&,M/F=R965N*"=D;VYE)RDI
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C+3YW<FET96QN*"1C
M+3YR960H)V9A:6QE9"<I*3L*("`@("`@("!]"B`@("!]"GT*"F9U;F-T:6]N
M(&UA:V4H*0I["B`@("!G;&]B86P@)&-M9%]O<'1I;VYS+"`D87!P<RP@)&1I
M<G,L("1D96)U9RP@)'1E<W0L("1C+"`D<VEL96YC92P@)')E9&ER7V5R<CL*
M"B`@("`D8V]M<&5N9&EU;2`]($)!4T4@+B!$4R`N("=P;R<@+B!$4R`N("=C
M;VUP96YD:75M+G!O)SL*("`@("1S879E7W-T871S(#T@9F%L<V4["B`@("!F
M;W)E86-H("@D8VUD7V]P=&EO;G-;,%T@87,@)&]P=&EO;BD@>PH@("`@("`@
M('-W:71C:"`H)&]P=&EO;ELP72D@>PH@("`@("`@("`@("!C87-E("=H)SH*
M("`@("`@("`@("`@("`@('5S86=E*"D["B`@("`@("`@("`@("`@("!F;V]T
M97(H*3L*("`@("`@("`@("`@8V%S92`G;"<Z"B`@("`@("`@("`@(&-A<V4@
M)RTM;&]C86QE)SH*("`@("`@("`@("`@("`@("1L86YG(#T@)&]P=&EO;ELQ
M73L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=M
M)SH*("`@("`@("`@("`@8V%S92`G+2UM;V1U;&4G.@H@("`@("`@("`@("`@
M("`@)&UO9'5L92`]("1O<'1I;VY;,5T["B`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@8V%S92`G8R<Z"B`@("`@("`@("`@(&-A<V4@)RTM
M8V]M<&5N9&EU;2<Z"B`@("`@("`@("`@("`@("`D8V]M<&5N9&EU;2`]("1O
M<'1I;VY;,5T["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M8V%S92`G;B<Z"B`@("`@("`@("`@(&-A<V4@)RTM;F\M8V]M<&5N9&EU;2<Z
M"B`@("`@("`@("`@("`@("`D8V]M<&5N9&EU;2`]("<G.PH@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)W,G.@H@("`@("`@("`@
M("!C87-E("<M+7-T871I<W1I8W,G.@H@("`@("`@("`@("`@("`@)'-A=F5?
M<W1A=',@/2!T<G5E.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M?0H@("`@?0H@("`@)&AO<F1E(#T@87)R87E?<V5A<F-H*"=H;W)D92<L("1D
M:7)S*3L*("`@("1H;W)D95]M<V<@/2!A<G)A>2@I.PH@("`@)'-T871S7V%R
M<F%Y(#T@87)R87DH*3L*"B`@("!R97%U:7)E7V]N8V4@)T-O;G-O;&4O5&%B
M;&4N<&AP)SL*("`@("1S=&%T<R`](&YE=R!#;VYS;VQE7U1A8FQE*"D["B`@
M("`D<W1A=',M/G-E=$AE861E<G,H87)R87DH)TUO9'5L92<L("=,86YG=6%G
M92<L("=4<F%N<VQA=&5D)RP@)T9U>GIY)RP@)U5N=')A;G-L871E9"<I*3L*
M"B`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D9&ER<RD[("1I*RLI('L*
M("`@("`@("!I9B`H(65M<'1Y*"1M;V1U;&4I("8F("1M;V1U;&4@(3T@)&%P
M<'-;)&E=*2!C;VYT:6YU93L*("`@("`@("`D8RT^=W)I=&5L;BAS<')I;G1F
M*"="=6EL9&EN9R!-3R!F:6QE<R!F;W(@;6]D=6QE("5S+BXN)RP@)&,M/F)O
M;&0H)&%P<'-;)&E=*2DI.PH@("`@("`@(&EF("AE;7!T>2@D;&%N9RDI('L*
M("`@("`@("`@("`@)&QA;F=S(#T@9V5T7VQA;F=U86=E<R@D9&ER<ULD:5TI
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@A0&9I;&5?97AI
M<W1S*"1D:7)S6R1I72`N($13("X@)W!O)R`N($13("X@)&QA;F<@+B`G+G!O
M)RDI('L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"=3:VEP<&5D+BXN
M)RD["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@("`@
M("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&QA
M;F=S(#T@87)R87DH)&QA;F<I.PH@("`@("`@('T*("`@("`@("!F;W)E86-H
M("@D;&%N9W,@87,@)&QO8V%L92D@>PH@("`@("`@("`@("`D8RT^=W)I=&5L
M;BAS<')I;G1F*"="=6EL9&EN9R!L;V-A;&4@)7,N+BX@)RP@)&,M/F)O;&0H
M)&QO8V%L92DI*3L*("`@("`@("`@("`@)&1I<B`]("1D:7)S6R1I72`N($13
M("X@)VQO8V%L92<@+B!$4R`N("1L;V-A;&4@+B!$4R`N("=,0U]-15-304=%
M4R<["B`@("`@("`@("`@(&EF("@A:7-?9&ER*"1D:7(I*2!["B`@("`@("`@
M("`@("`@("!R97%U:7)E7V]N8V4@)U-Y<W1E;2YP:'`G.PH@("`@("`@("`@
M("`@("`@:68@*"1D96)U9RD@>PH@("`@("`@("`@("`@("`@("`@("1C+3YW
M<FET96QN*'-P<FEN=&8H)TUA:VEN9R!D:7)E8W1O<GD@)7,G+"`D9&ER*2D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(21T97-T
M("8F("%`4WES=&5M.CIM:V1I<B@B+7`@)&1I<B(I*2!["B`@("`@("`@("`@
M("`@("`@("`@)&,M/G=R:71E;&XH)&,M/G)E9"@G5V%R;FEN9SH@)RD@+B!S
M<')I;G1F*"=#;W5L9"!N;W0@8W)E871E(&QO8V%L92!D:7)E8W1O<GD@9F]R
M(&QO8V%L92`E<SHG+"`D;&]C86QE*2D["B`@("`@("`@("`@("`@("`@("`@
M)&,M/G=R:71E;&XH)&1I<BD["B`@("`@("`@("`@("`@("`@("`@)&,M/G=R
M:71E;&XH*3L*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@0V]N
M=F5R="!T;R!U;FEX(&QI;F5B<F5A:W,N("HO"B`@("`@("`@("`@("1P;V9I
M;&4@/2`D9&ER<ULD:5T@+B!$4R`N("=P;R<@+B!$4R`N("1L;V-A;&4@+B`G
M+G!O)SL*("`@("`@("`@("`@)&-O;G1E;G0@/2!F:6QE7V=E=%]C;VYT96YT
M<R@D<&]F:6QE*3L*"B`@("`@("`@("`@("1C;VYT96YT(#T@<W1R7W)E<&QA
M8V4H(EQR(BP@)R<L("1C;VYT96YT*3L*("`@("`@("`@("`@)&9P(#T@9F]P
M96XH)'!O9FEL92P@)W=B)RD["B`@("`@("`@("`@(&9W<FET92@D9G`L("1C
M;VYT96YT*3L*("`@("`@("`@("`@9F-L;W-E*"1F<"D["@H@("`@("`@("`@
M("`O*B!#:&5C:R!03R!F:6QE('-A;FET>2X@*B\*("`@("`@("`@("`@)'-H
M(#T@)$=,3T)!3%-;)VUS9V9M="==("X@(B`M+6-H96-K(%PB)'!O9FEL95PB
M)')E9&ER7V5R<B(["B`@("`@("`@("`@(&EF("@D9&5B=6<@?'P@)'1E<W0I
M('L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"=%>&5C=71I;F<Z)RD[
M"B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@D<V@I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&EF("@D=&5S="D@>PH@("`@("`@("`@("`@("`@
M)')E="`](#`["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!E>&5C*"1S:"P@)&]U="P@)')E="D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*"1R970@(3T@,"D@>PH@("`@("`@("`@("`@("`@)&,M/G=R
M:71E;&XH)&,M/G)E9"@G5V%R;FEN9SH@)RD@+B`G86X@97)R;W(@:&%S(&]C
M8W5R960Z)RD["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;BAI;7!L;V1E
M*")<;B(L("1O=70I*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"D[
M"B`@("`@("`@("`@("`@("!I9B`H)&%P<'-;)&E=(#T]("=H;W)D92<I('L*
M("`@("`@("`@("`@("`@("`@("!C;VYT:6YU92`R.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("\J($-O;7!I;&4@34\@9FEL92X@*B\*("`@("`@("`@
M("`@)'-H(#T@)$=,3T)!3%-;)VUS9V9M="==("X@)R`M+7-T871I<W1I8W,@
M+6\@(B<@+B`D9&ER("X@1%,@+B`D87!P<ULD:5T@+B`G+FUO(B`G.PH@("`@
M("`@("`@("!I9B`H)&%P<'-;)&E=("$]("=H;W)D92<I('L*("`@("`@("`@
M("`@("`@("1H;W)D95]P;R`]("1D:7)S6R1H;W)D95T@+B!$4R`N("=P;R<@
M+B!$4R`N("1L;V-A;&4@+B`G+G!O)SL*("`@("`@("`@("`@("`@(&EF("@A
M0&ES7W)E861A8FQE*"1H;W)D95]P;RDI('L*("`@("`@("`@("`@("`@("`@
M("`D8RT^=W)I=&5L;B@D8RT^<F5D*"=787)N:6YG.B`G*2`N('-P<FEN=&8H
M)W1H92!(;W)D92!03R!F:6QE(&9O<B!T:&4@;&]C86QE("5S(&1O97,@;F]T
M(&5X:7-T.B<L("1L;V-A;&4I*3L*("`@("`@("`@("`@("`@("`@("`D8RT^
M=W)I=&5L;B@D:&]R9&5?<&\I.PH@("`@("`@("`@("`@("`@("`@("1C+3YW
M<FET96QN*"D["B`@("`@("`@("`@("`@("`@("`@)'-H("X]("1D:7)S6R1I
M72`N($13("X@)W!O)R`N($13("X@)&QO8V%L92`N("<N<&\G.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<V@@/2`D
M1TQ/0D%,4ULG;7-G8V]M;2==("X@(B`M+6UO<F4M=&AA;CTP("TM<V]R="UO
M=71P=70@7"(D<&]F:6QE7"(@7"(D:&]R9&5?<&]<(B!\("1S:"`M(CL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1S:"`N/2`D<&]F:6QE.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1S:"`N/2`D<F5D:7)?97)R.PH@("`@("`@("`@("!I9B`H)&1E8G5G
M('Q\("1T97-T*2!["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G17AE
M8W5T:6YG.B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)'-H*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D;W5T(#T@)R<["B`@("`@("`@
M("`@(&EF("@D=&5S="D@>PH@("`@("`@("`@("`@("`@)')E="`](#`["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!P=71E;G8H)TQ!
M3D<]96XG*3L*("`@("`@("`@("`@("`@(&5X96,H)'-H+"`D;W5T+"`D<F5T
M*3L*("`@("`@("`@("`@("`@('!U=&5N=B@G3$%.1STG("X@)$=,3T)!3%-;
M)VQA;F=U86=E)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D
M<F5T(#T](#`I('L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"1C+3YG
M<F5E;B@G9&]N92<I*3L*("`@("`@("`@("`@("`@("1M97-S86=E<R`](&%R
M<F%Y*#`L(#`L(#`I.PH@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H
M)R\H7&0K*2!T<F%N<VQA=&5D+R<L("1O=71;,%TL("1M871C:"DI('L*("`@
M("`@("`@("`@("`@("`@("`D;65S<V%G97-;,%T@/2`D;6%T8VA;,5T["B`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1H;W)D95]M<V=;)&QO8V%L
M95TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1M97-S86=E<ULP72`M
M/2`D:&]R9&5?;7-G6R1L;V-A;&5=6S!=.PH@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H)&UE<W-A9V5S6S!=(#P@,"D@)&UE<W-A9V5S6S!=(#T@,#L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+RA<9"LI(&9U>GIY+R<L("1O
M=71;,%TL("1M871C:"DI('L*("`@("`@("`@("`@("`@("`@("`D;65S<V%G
M97-;,5T@/2`D;6%T8VA;,5T["B`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1H;W)D95]M<V=;)&QO8V%L95TI*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1M97-S86=E<ULQ72`M/2`D:&]R9&5?;7-G6R1L;V-A;&5=6S%=
M.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&UE<W-A9V5S6S%=(#P@
M,"D@)&UE<W-A9V5S6S%=(#T@,#L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C
M:"@G+RA<9"LI('5N=')A;G-L871E9"\G+"`D;W5T6S!=+"`D;6%T8V@I*2![
M"B`@("`@("`@("`@("`@("`@("`@)&UE<W-A9V5S6S)=(#T@)&UA=&-H6S%=
M.PH@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:&]R9&5?;7-G6R1L
M;V-A;&5=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;65S<V%G97-;
M,ET@+3T@)&AO<F1E7VUS9ULD;&]C86QE75LR73L*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"1M97-S86=E<ULR72`\(#`I("1M97-S86=E<ULR72`]
M(#`["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@:68@*"1A<'!S6R1I72`]/2`G:&]R9&4G*2!["B`@
M("`@("`@("`@("`@("`@("`@)&AO<F1E7VUS9ULD;&]C86QE72`]("1M97-S
M86=E<SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1S=&%T
M<U]A<G)A>5LD87!P<ULD:5U=6R1L;V-A;&5=(#T@)&UE<W-A9V5S.PH@("`@
M("`@("`@("`@("`@)'-T871S+3YA9&12;W<H87)R87DH)&%P<'-;)&E=+"`D
M;&]C86QE+"`D;65S<V%G97-;,%TL("1M97-S86=E<ULQ72P@)&UE<W-A9V5S
M6S)=*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M8RT^=W)I=&5L;B@D8RT^<F5D*"=F86EL960G*2D["B`@("`@("`@("`@("`@
M("!E>&5C*"1S:"P@)&]U="P@)')E="D["B`@("`@("`@("`@("`@("`D8RT^
M=W)I=&5L;BAI;7!L;V1E*")<;B(L("1O=70I*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H8V]U;G0H)&QA;F=S*2`^(#$I('L*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O
M*B!-97)G92!T<F%N<VQA=&EO;B!I;G1O(&-O;7!E;F1I=6TN("HO"B`@("`@
M("`@("`@(&EF("@A96UP='DH)&-O;7!E;F1I=6TI*2!["B`@("`@("`@("`@
M("`@("!P<FEN=&8H)TUE<F=I;F<@=&AE(%!/(&9I;&4@9F]R("5S('1O('1H
M92!C;VUP96YD:75M+BXN("<L("1C+3YB;VQD*"1A<'!S6R1I72DI.PH@("`@
M("`@("`@("`@("`@:68@*"%E;7!T>2@D9&ER*2`F)B!S=6)S='(H)&1I<BP@
M+3$I("$]($13*2!["B`@("`@("`@("`@("`@("`@("`@)&1I<B`N/2!$4SL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1S:"`]("1'3$]"
M04Q36R=M<V=C870G72`N("(@+2US;W)T+6]U='!U="!<(B1C;VUP96YD:75M
M7"(@7"(D<&]F:6QE7"(@/B!<(B1C;VUP96YD:75M+G1M<%PB(CL*("`@("`@
M("`@("`@("`@(&EF("@A)&1E8G5G*2!["B`@("`@("`@("`@("`@("`@("`@
M)'-H("X]("1S:6QE;F-E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@:68@*"1D96)U9R!\?"`D=&5S="D@>PH@("`@("`@("`@("`@("`@
M("`@("1C+3YW<FET96QN*"D["B`@("`@("`@("`@("`@("`@("`@)&,M/G=R
M:71E;&XH)T5X96-U=&EN9SHG*3L*("`@("`@("`@("`@("`@("`@("`D8RT^
M=W)I=&5L;B@D<V@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)&]U="`]("<G.PH@("`@("`@("`@("`@("`@:68@*"1T97-T*2!["B`@
M("`@("`@("`@("`@("`@("`@)')E="`](#`["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&5X96,H)'-H+"`D;W5T+"`D
M<F5T*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@($!U;FQI
M;FLH)&-O;7!E;F1I=6TI.PH@("`@("`@("`@("`@("`@<F5N86UE*"1C;VUP
M96YD:75M("X@)RYT;7`G+"`D8V]M<&5N9&EU;2D["B`@("`@("`@("`@("`@
M("!I9B`H)')E="`]/2`P*2!["B`@("`@("`@("`@("`@("`@("`@)&,M/G=R
M:71E;&XH)&,M/F=R965N*"=D;VYE)RDI.PH@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@D8RT^<F5D
M*"=F86EL960G*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("!]"B`@("!]"B`@
M("!I9B`H96UP='DH)&UO9'5L92DI('L*("`@("`@("`D8RT^=W)I=&5L;B@G
M4F5S=6QT<SHG*3L*("`@('T@96QS92!["B`@("`@("`@)&,M/G=R:71E;&XH
M)U)E<W5L=',@*&EN8VQU9&EN9R!(;W)D92DZ)RD["B`@("!]"B`@("`D8RT^
M=W)I=&5L;B@D<W1A=',M/F=E=%1A8FQE*"DI.PH@("`@:68@*"1S879E7W-T
M871S*2!["B`@("`@("`@)&9P(#T@0&9O<&5N*"=T<F%N<VQA=&EO;E]S=&%T
M<RYT>'0G+"`G=R<I.PH@("`@("`@(&EF("@D9G`I('L*("`@("`@("`@("`@
M9G=R:71E*"1F<"P@<V5R:6%L:7IE*"1S=&%T<U]A<G)A>2DI.PH@("`@("`@
M("`@("!F8VQO<V4H)&9P*3L*("`@("`@("!]"B`@("!]"GT*"F9U;F-T:6]N
M(&-L96%N=7`H)&ME97!?=6YT<F%N<VQA=&5D(#T@9F%L<V4I"GL*("`@(&=L
M;V)A;"`D8VUD7V]P=&EO;G,L("1A<'!S+"`D9&ER<RP@)&1E8G5G+"`D=&5S
M="P@)&,["@H@("`@9F]R96%C:"`H)&-M9%]O<'1I;VYS6S!=(&%S("1O<'1I
M;VXI('L*("`@("`@("!S=VET8V@@*"1O<'1I;VY;,%TI('L*("`@("`@("`@
M("`@8V%S92`G:"<Z"B`@("`@("`@("`@("`@("!U<V%G92@I.PH@("`@("`@
M("`@("`@("`@9F]O=&5R*"D["B`@("`@("`@("`@(&-A<V4@)VPG.@H@("`@
M("`@("`@("!C87-E("<M+6QO8V%L92<Z"B`@("`@("`@("`@("`@("`D;&%N
M9R`]("1O<'1I;VY;,5T["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@8V%S92`G;2<Z"B`@("`@("`@("`@(&-A<V4@)RTM;6]D=6QE)SH*
M("`@("`@("`@("`@("`@("1M;V1U;&4@/2`D;W!T:6]N6S%=.PH@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*("`@(&9O<B`H)&D@
M/2`P.R`D:2`\(&-O=6YT*"1D:7)S*3L@)&DK*RD@>PH@("`@("`@(&EF("@A
M96UP='DH)&UO9'5L92D@)B8@)&UO9'5L92`A/2`D87!P<ULD:5TI('L@8V]N
M=&EN=64[('T*("`@("`@("`D8RT^=W)I=&5L;BAS<')I;G1F*"=#;&5A;FEN
M9R!U<"!03R!F:6QE<R!F;W(@;6]D=6QE("5S+BXN)RP@)&,M/F)O;&0H)&%P
M<'-;)&E=*2DI.PH@("`@("`@(&EF("AE;7!T>2@D;&%N9RDI('L*("`@("`@
M("`@("`@)&QA;F=S(#T@9V5T7VQA;F=U86=E<R@D9&ER<ULD:5TI.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@A0&9I;&5?97AI<W1S*"1D
M:7)S6R1I72`N($13("X@)W!O)R`N($13("X@)&QA;F<@+B`G+G!O)RDI('L*
M("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"=3:VEP<&5D+BXN)RD["B`@
M("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@("`@("`@("`@
M8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&QA;F=S(#T@
M87)R87DH)&QA;F<I.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D;&%N
M9W,@87,@)&QO8V%L92D@>PH@("`@("`@("`@("`D8RT^=W)I=&5L;BAS<')I
M;G1F*"=#;&5A;FEN9R!U<"!L;V-A;&4@)7,N+BX@)RP@)&,M/F)O;&0H)&QO
M8V%L92DI*3L*("`@("`@("`@("`@)'!O9FEL92`]("1D:7)S6R1I72`N($13
M("X@)W!O)R`N($13("X@)&QO8V%L92`N("<N<&\G.PH@("`@("`@("`@("`D
M<V@@/2`D1TQ/0D%,4ULG;7-G871T<FEB)UT@+B`H)&ME97!?=6YT<F%N<VQA
M=&5D(#\@)R<@.B`G("TM=')A;G-L871E9"<I("X@(B`M+6YO+6]B<V]L971E
M("TM9F]R8V4M<&\@)'!O9FEL92`^("1P;V9I;&4N=&UP(CL*("`@("`@("`@
M("`@:68@*"$D9&5B=6<I('L*("`@("`@("`@("`@("`@("1S:"`N/2`D<VEL
M96YC93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&1E8G5G('Q\
M("1T97-T*2!["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@
M("`@("`@("`@("`@)&,M/G=R:71E;&XH)T5X96-U=&EN9SHG*3L*("`@("`@
M("`@("`@("`@("1C+3YW<FET96QN*"1S:"D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&]U="`]("<G.PH@("`@("`@("`@("!I9B`H)'1E<W0I('L*
M("`@("`@("`@("`@("`@("1R970@/2`P.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@97AE8R@D<V@L("1O=70L("1R970I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&EF("@D<F5T(#T](#`I('L*("`@("`@
M("`@("`@("`@($!U;FQI;FLH)'!O9FEL92D["B`@("`@("`@("`@("`@("!R
M96YA;64H)'!O9FEL92`N("<N=&UP)RP@)'!O9FEL92D["B`@("`@("`@("`@
M("`@("`D8RT^=W)I=&5L;B@D8RT^9W)E96XH)V1O;F4G*2D["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("!`=6YL:6YK*"1P;V9I;&4@
M+B`G+G1M<"<L("1P;V9I;&4I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E
M;&XH)&,M/G)E9"@G9F%I;&5D)RDI.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1C+3YW<FET96QN*"D["B`@("`@("`@?0H@("`@?0I]"@IF=6YC=&EO
M;B!C;VUM:70H)&AE;'!?;VYL>2`](&9A;'-E*0I["B`@("!G;&]B86P@)&-M
M9%]O<'1I;VYS+"`D87!P<RP@)&1I<G,L("1D96)U9RP@)'1E<W0L("1C.PH*
M("`@("1D;V-S(#T@9F%L<V4["B`@("!F;W)E86-H("@D8VUD7V]P=&EO;G-;
M,%T@87,@)&]P=&EO;BD@>PH@("`@("`@('-W:71C:"`H)&]P=&EO;ELP72D@
M>PH@("`@("`@("`@("!C87-E("=H)SH*("`@("`@("`@("`@("`@('5S86=E
M*"D["B`@("`@("`@("`@("`@("!F;V]T97(H*3L*("`@("`@("`@("`@8V%S
M92`G;"<Z"B`@("`@("`@("`@(&-A<V4@)RTM;&]C86QE)SH*("`@("`@("`@
M("`@("`@("1L86YG(#T@)&]P=&EO;ELQ73L*("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("!C87-E("=M)SH*("`@("`@("`@("`@8V%S92`G
M+2UM;V1U;&4G.@H@("`@("`@("`@("`@("`@)&UO9'5L92`]("1O<'1I;VY;
M,5T["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G
M;B<Z"B`@("`@("`@("`@(&-A<V4@)RTM;F5W)SH*("`@("`@("`@("`@("`@
M("1D;V-S(#T@=')U93L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("!C87-E("=-)SH*("`@("`@("`@("`@8V%S92`G+2UM97-S86=E)SH*
M("`@("`@("`@("`@("`@("1M<V<@/2`D;W!T:6]N6S%=.PH@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0H@("`@)&9I;&5S(#T@87)R
M87DH*3L*("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1D:7)S*3L@)&DK
M*RD@>PH@("`@("`@(&EF("@A96UP='DH)&UO9'5L92D@)B8@)&UO9'5L92`A
M/2`D87!P<ULD:5TI(&-O;G1I;G5E.PH@("`@("`@(&EF("@D87!P<ULD:5T@
M/3T@)VAO<F1E)RD@>PH@("`@("`@("`@("`D9&ER<UM=(#T@)&1I<G-;)&E=
M("X@1%,@+B`G861M:6XG.PH@("`@("`@("`@("`D87!P<UM=(#T@)VAO<F1E
M+V%D;6EN)SL*("`@("`@("`@("`@:68@*"%E;7!T>2@D;6]D=6QE*2D@>PH@
M("`@("`@("`@("`@("`@)&UO9'5L92`]("=H;W)D92]A9&UI;B<["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1L86YG*2D@
M>PH@("`@("`@("`@("!I9B`H)&AE;'!?;VYL>2D@>PH@("`@("`@("`@("`@
M("`@)&9I;&5S(#T@87)R87E?;65R9V4H)&9I;&5S+"!S=')I<%]H;W)D92AS
M96%R8VA?97AT*"=X;6PG+"`D9&ER<ULD:5T@+B!$4R`N("=L;V-A;&4G*2DI
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&9I;&5S
M(#T@87)R87E?;65R9V4H)&9I;&5S+"!S=')I<%]H;W)D92AG971?<&]?9FEL
M97,H)&1I<G-;)&E=("X@1%,@+B`G<&\G*2DI.PH@("`@("`@("`@("`@("`@
M)&9I;&5S(#T@87)R87E?;65R9V4H)&9I;&5S+"!S=')I<%]H;W)D92AS96%R
M8VA?9FEL92@G7EMA+7I=>S)]7UM!+5I=>S)])RP@)&1I<G-;)&E=("X@1%,@
M+B`G;&]C86QE)RP@=')U92DI*3L*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(&EF("@D:&5L<%]O;FQY*2!["B`@("`@("`@
M("`@("`@("!I9B`H(4!F:6QE7V5X:7-T<R@D9&ER<ULD:5T@+B!$4R`N("=L
M;V-A;&4G("X@1%,@+B`D;&%N9R`N($13("X@)VAE;'`N>&UL)RDI(&-O;G1I
M;G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:68@
M*"%`9FEL95]E>&ES=',H)&1I<G-;)&E=("X@)R]P;R\G("X@)&QA;F<@+B`G
M+G!O)RDI(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@)&9I;&5S6UT@/2!S
M=')I<%]H;W)D92@D9&ER<ULD:5T@+B!$4R`N("=P;R<@+B!$4R`N("1L86YG
M("X@)RYP;R<I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1F:6QE<UM=
M(#T@<W1R:7!?:&]R9&4H)&1I<G-;)&E=("X@1%,@+B`G;&]C86QE)R`N($13
M("X@)&QA;F<I.PH@("`@("`@('T*("`@("`@("!I9B`H)&1O8W,@)B8@(21H
M96QP7V]N;'D@)B8@)&%P<'-;)&E=*2!["B`@("`@("`@("`@("1F:6QE<UM=
M(#T@<W1R:7!?:&]R9&4H)&1I<G-;)&E=("X@1%,@+B`G9&]C<R<I.PH@("`@
M("`@("`@("!I9B`H)&%P<'-;)&E=(#T]("=H;W)D92<I('L*("`@("`@("`@
M("`@("`@("1H;W)D95]C;VYF(#T@)&1I<G-;87)R87E?<V5A<F-H*"=H;W)D
M92<L("1D:7)S*5T@+B!$4R`N("=C;VYF:6<G("X@1%,["B`@("`@("`@("`@
M("`@("`D9FEL97-;72`]('-T<FEP7VAO<F1E*"1H;W)D95]C;VYF("X@)VYL
M<RYP:'`N9&ES="<I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@
M("`@8VAD:7(H0D%312D["B`@("!I9B`H8V]U;G0H)&9I;&5S*2D@>PH@("`@
M("`@(&EF("@D9&]C<RD@>PH@("`@("`@("`@("`D8RT^=W)I=&5L;B@G061D
M:6YG(&YE=R!F:6QE<R!T;R!R97!O<VET;W)Y.B<I.PH@("`@("`@("`@("`D
M<V@@/2`G8W9S(&%D9"<["B`@("`@("`@("`@(&9O<F5A8V@@*"1F:6QE<R!A
M<R`D9FEL92D@>PH@("`@("`@("`@("`@("`@:68@*'-T<G-T<B@D9FEL92P@
M)VQO8V%L92<I('Q\('-T<G-T<B@D9FEL92P@)RYP;R<I*2!["B`@("`@("`@
M("`@("`@("`@("`@)'-H("X]("(@)&9I;&4B.PH@("`@("`@("`@("`@("`@
M("`@("1C+3YW<FET96QN*"1F:6QE*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D<V@@+CT@)SL@8W9S(&%D9"<["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1F:6QE<R!A<R`D9FEL92D@>PH@("`@("`@
M("`@("`@("`@:68@*'-T<G-T<B@D9FEL92P@)VQO8V%L92<I*2!["B`@("`@
M("`@("`@("`@("`@("`@:68@*"1H96QP7V]N;'DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'-H("X]("<@)R`N("1F:6QE("X@1%,@+B`G*BYX;6PG
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@D9FEL92`N
M($13("X@)RHN>&UL)RD["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'-H("X]("<@)R`N("1F:6QE("X@
M1%,@+B`G*BYX;6P@)R`N("1F:6QE("X@1%,@+B`G3$-?34534T%'15,G.PH@
M("`@("`@("`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@D9FEL92`N($13
M("X@(BHN>&UL7&XD9FEL92(@+B!$4R`N("=,0U]-15-304=%4R<I.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H(21H96QP7V]N;'DI('L*("`@("`@("`@
M("`@("`@("1S:"`N/2`G.R!C=G,@861D)SL*("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1F:6QE<R!A<R`D9FEL92D@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("AS=')S='(H)&9I;&4L("=L;V-A;&4G*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D861D(#T@)&9I;&4@+B!$4R`N("=,0U]-15-304=%4R<@
M+B!$4R`N("<J+FUO)SL*("`@("`@("`@("`@("`@("`@("`@("`@)'-H("X]
M("<@)R`N("1A9&0["B`@("`@("`@("`@("`@("`@("`@("`@("1C+3YW<FET
M96QN*"1A9&0I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D8RT^=W)I=&5L;B@I
M.PH@("`@("`@("`@("!I9B`H)&1E8G5G('Q\("1T97-T*2!["B`@("`@("`@
M("`@("`@("`D8RT^=W)I=&5L;B@G17AE8W5T:6YG.B<I.PH@("`@("`@("`@
M("`@("`@)&,M/G=R:71E;&XH)'-H*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!I9B`H(21T97-T*2!S>7-T96TH)'-H*3L*("`@("`@("`@("`@)&,M
M/G=R:71E;&XH*3L*("`@("`@("!]"B`@("`@("`@)&,M/G=R:71E;&XH)T-O
M;6UI='1I;F<Z)RD["B`@("`@("`@)&,M/G=R:71E;&XH:6UP;&]D92@G("<L
M("1F:6QE<RDI.PH@("`@("`@(&EF("@A96UP='DH)&QA;F<I*2!["B`@("`@
M("`@("`@("1L86YG(#T@)R`G("X@)&QA;F<["B`@("`@("`@?0H@("`@("`@
M(&EF("AE;7!T>2@D;7-G*2D@>PH@("`@("`@("`@("!I9B`H)&1O8W,I('L*
M("`@("`@("`@("`@("`@("1M<V<@/2`B061D)&QA;F<@=')A;G-L871I;VXN
M(CL*("`@("`@("`@("`@?2!E;'-E:68@*"1H96QP7V]N;'DI('L*("`@("`@
M("`@("`@("`@("1M<V<@/2`B57!D871E)&QA;F<@:&5L<"!F:6QE+B(["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D;7-G(#T@(E5P
M9&%T921L86YG('1R86YS;&%T:6]N+B(["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@)'-H(#T@)V-V<R!C;VUM:70@+6T@(B<@+B`D;7-G("X@
M)R(@)R`N(&EM<&QO9&4H)R`G+"`D9FEL97,I.PH@("`@("`@(&EF("@D9&5B
M=6<@?'P@)'1E<W0I('L*("`@("`@("`@("`@)&,M/G=R:71E;&XH)T5X96-U
M=&EN9SHG*3L*("`@("`@("`@("`@)&,M/G=R:71E;&XH)'-H*3L*("`@("`@
M("!]"B`@("`@("`@:68@*"$D=&5S="D@<WES=&5M*"1S:"D["B`@("!]"GT*
M"F9U;F-T:6]N('5P9&%T95]H96QP*"D*>PH@("`@9VQO8F%L("1C;61?;W!T
M:6]N<RP@)&1I<G,L("1A<'!S+"`D9&5B=6<L("1T97-T+"`D;&%S=%]E<G)O
M<E]M<V<L("1C.PH*("`@(&9O<F5A8V@@*"1C;61?;W!T:6]N<ULP72!A<R`D
M;W!T:6]N*2!["B`@("`@("`@<W=I=&-H("@D;W!T:6]N6S!=*2!["B`@("`@
M("`@("`@(&-A<V4@)V@G.@H@("`@("`@("`@("`@("`@=7-A9V4H*3L*("`@
M("`@("`@("`@("`@(&9O;W1E<B@I.PH@("`@("`@("`@("!C87-E("=L)SH*
M("`@("`@("`@("`@8V%S92`G+2UL;V-A;&4G.@H@("`@("`@("`@("`@("`@
M)&QA;F<@/2`D;W!T:6]N6S%=.PH@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@(&-A<V4@)VTG.@H@("`@("`@("`@("!C87-E("<M+6UO9'5L
M92<Z"B`@("`@("`@("`@("`@("`D;6]D=6QE(#T@)&]P=&EO;ELQ73L*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*("`@("1F:6QE
M<R`](&%R<F%Y*"D["B`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D9&ER
M<RD[("1I*RLI('L*("`@("`@("!I9B`H(65M<'1Y*"1M;V1U;&4I("8F("1M
M;V1U;&4@(3T@)&%P<'-;)&E=*2![(&-O;G1I;G5E.R!]"B`@("`@("`@:68@
M*"%I<U]D:7(H(B1D:7)S6R1I72]L;V-A;&4B*2D@8V]N=&EN=64["B`@("`@
M("`@:68@*"1A<'!S6R1I72`]/2`G:&]R9&4G*2!["B`@("`@("`@("`@("1D
M:7)S6UT@/2`D9&ER<ULD:5T@+B!$4R`N("=A9&UI;B<["B`@("`@("`@("`@
M("1A<'!S6UT@/2`G:&]R9&4O861M:6XG.PH@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1M;V1U;&4I*2!["B`@("`@("`@("`@("`@("`D;6]D=6QE(#T@)VAO
M<F1E+V%D;6EN)SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I
M9B`H96UP='DH)&QA;F<I*2!["B`@("`@("`@("`@("1F:6QE<R`]('-E87)C
M:%]F:6QE*"=H96QP+GAM;"<L("1D:7)S6R1I72`N($13("X@)VQO8V%L92<I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F:6QE<R`](&%R<F%Y
M*"1D:7)S6R1I72`N($13("X@)VQO8V%L92<@+B!$4R`N("1L86YG("X@1%,@
M+B`G:&5L<"YX;6PG*3L*("`@("`@("!]"B`@("`@("`@)&9I;&5?96X@(#T@
M)&1I<G-;)&E=("X@1%,@+B`G;&]C86QE)R`N($13("X@)V5N7U53)R`N($13
M("X@)VAE;'`N>&UL)SL*("`@("`@("!I9B`H(4!F:6QE7V5X:7-T<R@D9FEL
M95]E;BDI('L*("`@("`@("`@("`@)&,M/G=R:71E;&XH=V]R9'=R87`H)&,M
M/G)E9"@G5V%R;FEN9SH@)RD@+B!S<')I;G1F*"=4:&5R92!D;V5S;EPG="!Y
M970@97AI<W0@82!H96QP(&9I;&4@9F]R("5S+B<L("1C+3YB;VQD*"1A<'!S
M6R1I72DI*2D["B`@("`@("`@("`@("1C+3YW<FET96QN*"D["B`@("`@("`@
M("`@(&-O;G1I;G5E.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D9FEL
M97,@87,@)&9I;&5?;&]C*2!["B`@("`@("`@("`@("1L;V-A;&4@/2!S=6)S
M='(H)&9I;&5?;&]C+"`P+"!S=')R<&]S*"1F:6QE7VQO8RP@1%,I*3L*("`@
M("`@("`@("`@)&QO8V%L92`]('-U8G-T<B@D;&]C86QE+"!S=')R<&]S*"1L
M;V-A;&4L($13*2`K(#$I.PH@("`@("`@("`@("!I9B`H)&QO8V%L92`]/2`G
M96Y?55,G*2!C;VYT:6YU93L*("`@("`@("`@("`@:68@*"%`9FEL95]E>&ES
M=',H)&9I;&5?;&]C*2D@>PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH
M=V]R9'=R87`H)&,M/G)E9"@G5V%R;FEN9SH@)RD@+B!S<')I;G1F*"=4:&4@
M)7,@:&5L<"!F:6QE(&9O<B`E<R!D;V5S;EPG="!Y970@97AI<W0N($-R96%T
M:6YG(&$@;F5W(&]N92XG+"`D8RT^8F]L9"@D;&]C86QE*2P@)&,M/F)O;&0H
M)&%P<'-;)&E=*2DI*3L*("`@("`@("`@("`@("`@("1D:7)?;&]C(#T@<W5B
M<W1R*"1F:6QE7VQO8RP@,"P@+3DI.PH@("`@("`@("`@("`@("`@:68@*"%I
M<U]D:7(H)&1I<E]L;V,I*2!["B`@("`@("`@("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E("=3>7-T96TN<&AP)SL*("`@("`@("`@("`@("`@("`@("!I9B`H
M)&1E8G5G('Q\("1T97-T*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1C
M+3YW<FET96QN*'-P<FEN=&8H)TUA:VEN9R!D:7)E8W1O<GD@)7,G+"`D9&ER
M7VQO8RDI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!I9B`H(21T97-T("8F("%`4WES=&5M.CIM:V1I<B@B+7`@)&1I<E]L
M;V,B*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@D
M8RT^<F5D*"=787)N:6YG.B`G*2`N('-P<FEN=&8H)T-O=6QD(&YO="!C<F5A
M=&4@;&]C86QE(&1I<F5C=&]R>2!F;W(@;&]C86QE("5S.B<L("1L;V-A;&4I
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)&1I<E]L
M;V,I.PH@("`@("`@("`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@I.PH@
M("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I
M9B`H)&1E8G5G('Q\("1T97-T*2!["B`@("`@("`@("`@("`@("`@("`@)&,M
M/G=R:71E;&XH=V]R9'=R87`H<W!R:6YT9B@G0V]P>6EN9R`E<R!T;R`E<R<L
M("1F:6QE7V5N+"`D9FEL95]L;V,I*2D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!I9B`H(21T97-T("8F("%`8V]P>2@D9FEL95]E;BP@
M)&9I;&5?;&]C*2D@>PH@("`@("`@("`@("`@("`@("`@("1C+3YW<FET96QN
M*"1C+3YR960H)U=A<FYI;F<Z("<I("X@<W!R:6YT9B@G0V]U;&0@;F]T(&-O
M<'D@)7,@=&\@)7,G+"`D9FEL95]E;BP@)&9I;&5?;&]C*2D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)&,M/G=R:71E;&XH<W!R:6YT9B@G57!D871I;F<@)7,@:&5L<"!F:6QE
M(&9O<B`E<RXG+"`D8RT^8F]L9"@D;&]C86QE*2P@)&,M/F)O;&0H)&%P<'-;
M)&E=*2DI.PH@("`@("`@("`@("`D9G`@/2!F;W!E;B@D9FEL95]L;V,L("=R
M)RD["B`@("`@("`@("`@("1L:6YE(#T@9F=E=',H)&9P*3L*("`@("`@("`@
M("`@9F-L;W-E*"1F<"D["B`@("`@("`@("`@(&EF("@A<W1R<W1R*"1L:6YE
M+"`G/#]X;6PG*2D@>PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH=V]R
M9'=R87`H)&,M/G)E9"@G5V%R;FEN9SH@)RD@+B!S<')I;G1F*"=4:&4@:&5L
M<"!F:6QE("5S(&1I9&Y<)W0@<W1A<G0@=VET:"`\/WAM;"<L("1F:6QE7VQO
M8RDI*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"D["B`@("`@("`@
M("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M96YC;V1I;F<@/2`G)SL*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]E
M;F-O9&EN9STH6R)<)UTI*%M>7%PQ72LI7%PQ+R<L("1L:6YE+"`D;6%T8V@I
M*2!["B`@("`@("`@("`@("`@("`D96YC;V1I;F<@/2`D;6%T8VA;,ET["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&1O8U]E;B`](&1O;7AM;%]O<&5N
M7V9I;&4H)&9I;&5?96XI.PH@("`@("`@("`@("!I9B`H(6ES7V]B:F5C="@D
M9&]C7V5N*2D@>PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH=V]R9'=R
M87`H)&,M/G)E9"@G5V%R;FEN9SH@)RD@+B!S<')I;G1F*"=4:&5R92!W87,@
M86X@97)R;W(@;W!E;FEN9R!T:&4@9FEL92`E<RX@5')Y(')U;FYI;F<@=')A
M;G-L871I;VXN<&AP('=I=&@@=&AE(&9L86<@+60@=&\@<V5E(&%N>2!E<G)O
M<B!M97-S86=E<R!F<F]M('1H92!X;6P@<&%R<V5R+B<L("1F:6QE7V5N*2DI
M.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("`@("`@
M("`@(&-O;G1I;G5E(#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&1O
M8U]L;V,@/2!D;VUX;6Q?;W!E;E]F:6QE*"1F:6QE7VQO8RD["B`@("`@("`@
M("`@(&EF("@A:7-?;V)J96-T*"1D;V-?;&]C*2D@>PH@("`@("`@("`@("`@
M("`@)&,M/G=R:71E;&XH=V]R9'=R87`H)&,M/G)E9"@G5V%R;FEN9SH@)RD@
M+B!S<')I;G1F*"=4:&5R92!W87,@86X@97)R;W(@;W!E;FEN9R!T:&4@9FEL
M92`E<RX@5')Y(')U;FYI;F<@=')A;G-L871I;VXN<&AP('=I=&@@=&AE(&9L
M86<@+60@=&\@<V5E(&%N>2!E<G)O<B!M97-S86=E<R!F<F]M('1H92!X;6P@
M<&%R<V5R+B<L("1F:6QE7VQO8RDI*3L*("`@("`@("`@("`@("`@("1C+3YW
M<FET96QN*"D["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D9&]C7VYE=R`@/2!D;VUX;6Q?;F5W7V1O8R@G
M,2XP)RD["B`@("`@("`@("`@("1H96QP7V5N("`]("1D;V-?96XM/F1O8W5M
M96YT7V5L96UE;G0H*3L*("`@("`@("`@("`@)&AE;'!?;&]C(#T@)&1O8U]L
M;V,M/F1O8W5M96YT7V5L96UE;G0H*3L*("`@("`@("`@("`@)&AE;'!?;F5W
M(#T@)&AE;'!?;&]C+3YC;&]N95]N;V1E*"D["B`@("`@("`@("`@("1E;G1R
M:65S7VQO8R`](&%R<F%Y*"D["B`@("`@("`@("`@("1E;G1R:65S7VYE=R`]
M(&%R<F%Y*"D["B`@("`@("`@("`@("1C;W5N=%]U<'1O9&%T92`](#`["B`@
M("`@("`@("`@("1C;W5N=%]N97<@("`@("`](#`["B`@("`@("`@("`@("1C
M;W5N=%]C:&%N9V5D("`](#`["B`@("`@("`@("`@("1C;W5N=%]U;FMN;W=N
M("`](#`["B`@("`@("`@("`@(&9O<F5A8V@@*"1D;V-?;&]C+3YG971?96QE
M;65N='-?8GE?=&%G;F%M92@G96YT<GDG*2!A<R`D96YT<GDI('L*("`@("`@
M("`@("`@("`@("1E;G1R:65S7VQO8ULD96YT<GDM/F=E=%]A='1R:6)U=&4H
M)VED)RE=(#T@)&5N=')Y.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O
M<F5A8V@@*"1D;V-?96XM/F=E=%]E;&5M96YT<U]B>5]T86=N86UE*"=E;G1R
M>2<I(&%S("1E;G1R>2D@>PH@("`@("`@("`@("`@("`@)&ED(#T@)&5N=')Y
M+3YG971?871T<FEB=71E*"=I9"<I.PH@("`@("`@("`@("`@("`@:68@*&%R
M<F%Y7VME>5]E>&ES=',H)&ED+"`D96YT<FEE<U]L;V,I*2!["B`@("`@("`@
M("`@("`@("`@("`@:68@*"1E;G1R:65S7VQO8ULD:61=+3YH87-?871T<FEB
M=71E*"=M9#4G*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("!M9#4H)&5N
M=')Y+3YG971?8V]N=&5N="@I*2`A/2`D96YT<FEE<U]L;V-;)&ED72T^9V5T
M7V%T=')I8G5T92@G;60U)RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&-O;6UE;G0@/2`D9&]C7VQO8RT^8W)E871E7V-O;6UE;G0H(B!%;F=L:7-H
M(&5N=')Y.EQN(B`N('-T<E]R97!L86-E*"<M+2<L("<F(S0U.R8C-#4[)RP@
M)&1O8U]L;V,M/F1U;7!?;F]D92@D96YT<GDI*2D["B`@("`@("`@("`@("`@
M("`@("`@("`@("1E;G1R:65S7VQO8ULD:61=+3YA<'!E;F1?8VAI;&0H)&-O
M;6UE;G0I.PH@("`@("`@("`@("`@("`@("`@("`@("`D96YT<GE?;F5W(#T@
M)&5N=')I97-?;&]C6R1I9%TM/F-L;VYE7VYO9&4H=')U92D["B`@("`@("`@
M("`@("`@("`@("`@("`@("1E;G1R>5]N97<M/G-E=%]A='1R:6)U=&4H)W-T
M871E)RP@)V-H86YG960G*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&-O
M=6YT7V-H86YG960K*SL*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H(21E;G1R:65S7VQO8ULD:61=
M+3YH87-?871T<FEB=71E*"=S=&%T92<I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D8V]M;65N="`]("1D;V-?;&]C+3YC<F5A=&5?8V]M;65N
M="@B($5N9VQI<V@@96YT<GDZ7&XB("X@<W1R7W)E<&QA8V4H)RTM)RP@)R8C
M-#4[)B,T-3LG+"`D9&]C7VQO8RT^9'5M<%]N;V1E*"1E;G1R>2DI*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1E;G1R:65S7VQO8ULD:61=+3YA
M<'!E;F1?8VAI;&0H)&-O;6UE;G0I.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&5N=')Y7VYE=R`]("1E;G1R:65S7VQO8ULD:61=+3YC;&]N95]N
M;V1E*'1R=64I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5N=')Y
M7VYE=RT^<V5T7V%T=')I8G5T92@G<W1A=&4G+"`G=6YK;F]W;B<I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&-O=6YT7W5N:VYO=VXK*SL*("`@
M("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1E;G1R>5]N97<@/2`D96YT<FEE<U]L;V-;)&ED72T^
M8VQO;F5?;F]D92AT<G5E*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1C;W5N=%]U<'1O9&%T92LK.PH@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`D96YT<GE?;F5W(#T@)&5N=')Y+3YC
M;&]N95]N;V1E*'1R=64I.PH@("`@("`@("`@("`@("`@("`@("1E;G1R>5]N
M97<M/G-E=%]A='1R:6)U=&4H)W-T871E)RP@)VYE=R<I.PH@("`@("`@("`@
M("`@("`@("`@("1C;W5N=%]N97<K*SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1E;G1R:65S7VYE=UM=(#T@)&5N=')Y7VYE=SL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D9&]C7VYE=RT^87!P96YD7V-H:6QD
M*"1D;V-?;F5W+3YC<F5A=&5?8V]M;65N="@G("0G("X@)TAO<F1E)"`G*2D[
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1E;G1R:65S7VYE=R!A<R`D96YT<GDI
M('L*("`@("`@("`@("`@("`@("1H96QP7VYE=RT^87!P96YD7V-H:6QD*"1E
M;G1R>2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&,M/G=R:71E;&XH
M=V]R9'=R87`H<W!R:6YT9B@G16YT<FEE<SH@)60@=&]T86PL("5D('5P+71O
M+61A=&4L("5D(&YE=RP@)60@8VAA;F=E9"P@)60@=6YK;F]W;B<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]U;G1?=7!T;V1A
M=&4@*R`D8V]U;G1?;F5W("L@)&-O=6YT7V-H86YG960@*R`D8V]U;G1?=6YK
M;F]W;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C
M;W5N=%]U<'1O9&%T92P@)&-O=6YT7VYE=RP@)&-O=6YT7V-H86YG960L("1C
M;W5N=%]U;FMN;W=N*2DI.PH@("`@("`@("`@("`D9&]C7VYE=RT^87!P96YD
M7V-H:6QD*"1H96QP7VYE=RD["B`@("`@("`@("`@("1O=71P=70@/2`D9&]C
M7VYE=RT^9'5M<%]M96TH=')U92P@)&5N8V]D:6YG*3L*("`@("`@("`@("`@
M:68@*"1D96)U9R!\?"`D=&5S="D@>PH@("`@("`@("`@("`@("`@)&,M/G=R
M:71E;&XH=V]R9'=R87`H<W!R:6YT9B@G5W)I=&EN9R!U<&1A=&5D(&AE;'`@
M9FEL92!T;R`E<RXG+"`D9FEL95]L;V,I*2D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*"$D=&5S="D@>PH@("`@("`@("`@("`@("`@)&9P(#T@
M9F]P96XH)&9I;&5?;&]C+"`G=R<I.PH@("`@("`@("`@("`@("`@)&QI;F4@
M/2!F=W)I=&4H)&9P+"`D;W5T<'5T*3L*("`@("`@("`@("`@("`@(&9C;&]S
M92@D9G`I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1C+3YW<FET96QN
M*'-P<FEN=&8H)R5D(&)Y=&5S('=R:71T96XN)RP@<W1R;&5N*"1O=71P=70I
M*2D["B`@("`@("`@("`@("1C+3YW<FET96QN*"D["B`@("`@("`@?0H@("`@
M?0I]"@IF=6YC=&EO;B!M86ME7VAE;'`H*0I["B`@("!G;&]B86P@)&-M9%]O
M<'1I;VYS+"`D9&ER<RP@)&%P<',L("1D96)U9RP@)'1E<W0L("1C.PH*("`@
M(&9O<F5A8V@@*"1C;61?;W!T:6]N<ULP72!A<R`D;W!T:6]N*2!["B`@("`@
M("`@<W=I=&-H("@D;W!T:6]N6S!=*2!["B`@("`@("`@("`@(&-A<V4@)V@G
M.@H@("`@("`@("`@("`@("`@=7-A9V4H*3L*("`@("`@("`@("`@("`@(&9O
M;W1E<B@I.PH@("`@("`@("`@("!C87-E("=L)SH*("`@("`@("`@("`@8V%S
M92`G+2UL;V-A;&4G.@H@("`@("`@("`@("`@("`@)&QA;F<@/2`D;W!T:6]N
M6S%=.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@
M)VTG.@H@("`@("`@("`@("!C87-E("<M+6UO9'5L92<Z"B`@("`@("`@("`@
M("`@("`D;6]D=6QE(#T@)&]P=&EO;ELQ73L*("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@('T*("`@('T*("`@("1F:6QE<R`](&%R<F%Y*"D["B`@
M("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D9&ER<RD[("1I*RLI('L*("`@
M("`@("!I9B`H(65M<'1Y*"1M;V1U;&4I("8F("1M;V1U;&4@(3T@)&%P<'-;
M)&E=*2!C;VYT:6YU93L*("`@("`@("!I9B`H(6ES7V1I<B@B)&1I<G-;)&E=
M+VQO8V%L92(I*2!C;VYT:6YU93L*("`@("`@("!I9B`H)&%P<'-;)&E=(#T]
M("=H;W)D92<I('L*("`@("`@("`@("`@)&1I<G-;72`]("1D:7)S6R1I72`N
M($13("X@)V%D;6EN)SL*("`@("`@("`@("`@)&%P<'-;72`]("=H;W)D92]A
M9&UI;B<["B`@("`@("`@("`@(&EF("@A96UP='DH)&UO9'5L92DI('L*("`@
M("`@("`@("`@("`@("1M;V1U;&4@/2`G:&]R9&4O861M:6XG.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D;&%N9RDI('L*
M("`@("`@("`@("`@)&9I;&5S(#T@<V5A<F-H7V9I;&4H)VAE;'`N>&UL)RP@
M)&1I<G-;)&E=("X@1%,@+B`G;&]C86QE)RD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&9I;&5S(#T@87)R87DH)&1I<G-;)&E=("X@1%,@+B`G
M;&]C86QE)R`N($13("X@)&QA;F<@+B!$4R`N("=H96QP+GAM;"<I.PH@("`@
M("`@('T*("`@("`@("`D9FEL95]E;B`@/2`D9&ER<ULD:5T@+B!$4R`N("=L
M;V-A;&4G("X@1%,@+B`G96Y?55,G("X@1%,@+B`G:&5L<"YX;6PG.PH@("`@
M("`@(&EF("@A0&9I;&5?97AI<W1S*"1F:6QE7V5N*2D@>PH@("`@("`@("`@
M("!C;VYT:6YU93L*("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H)&9I;&5S
M(&%S("1F:6QE7VQO8RD@>PH@("`@("`@("`@("!I9B`H(4!F:6QE7V5X:7-T
M<R@D9FEL95]L;V,I*2!["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G
M4VMI<'!E9"XN+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1L;V-A;&4@/2!S=6)S='(H)&9I;&5?;&]C+"`P+"!S=')R<&]S
M*"1F:6QE7VQO8RP@1%,I*3L*("`@("`@("`@("`@)&QO8V%L92`]('-U8G-T
M<B@D;&]C86QE+"!S=')R<&]S*"1L;V-A;&4L($13*2`K(#$I.PH@("`@("`@
M("`@("!I9B`H)&QO8V%L92`]/2`G96Y?55,G*2!C;VYT:6YU93L*("`@("`@
M("`@("`@)&,M/G=R:71E;&XH<W!R:6YT9B@G57!D871I;F<@)7,@:&5L<"!F
M:6QE(&9O<B`E<RXG+"`D8RT^8F]L9"@D;&]C86QE*2P@)&,M/F)O;&0H)&%P
M<'-;)&E=*2DI.PH@("`@("`@("`@("`D9G`@/2!F;W!E;B@D9FEL95]L;V,L
M("=R)RD["B`@("`@("`@("`@("1L:6YE(#T@9F=E=',H)&9P*3L*("`@("`@
M("`@("`@9F-L;W-E*"1F<"D["B`@("`@("`@("`@(&EF("@A<W1R<W1R*"1L
M:6YE+"`G/#]X;6PG*2D@>PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH
M=V]R9'=R87`H)&,M/G)E9"@G5V%R;FEN9SH@)RD@+B!S<')I;G1F*"=4:&4@
M:&5L<"!F:6QE("5S(&1I9&Y<)W0@<W1A<G0@=VET:"`\/WAM;"<L("1F:6QE
M7VQO8RDI*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"D["B`@("`@
M("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D96YC;V1I;F<@/2`G)SL*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H
M)R]E;F-O9&EN9STH6R)<)UTI*%M>7%PQ72LI7%PQ+R<L("1L:6YE+"`D;6%T
M8V@I*2!["B`@("`@("`@("`@("`@("`D96YC;V1I;F<@/2`D;6%T8VA;,ET[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&1O8U]E;B`@(#T@9&]M>&UL
M7V]P96Y?9FEL92@D9FEL95]E;BD["B`@("`@("`@("`@(&EF("@A:7-?;V)J
M96-T*"1D;V-?96XI*2!["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;BAW
M;W)D=W)A<"@D8RT^<F5D*"=787)N:6YG.B`G*2`N('-P<FEN=&8H)U1H97)E
M('=A<R!A;B!E<G)O<B!O<&5N:6YG('1H92!F:6QE("5S+B!4<GD@<G5N;FEN
M9R!T<F%N<VQA=&EO;BYP:'`@=VET:"!T:&4@9FQA9R`M9"!T;R!S964@86YY
M(&5R<F]R(&UE<W-A9V5S(&9R;VT@=&AE('AM;"!P87)S97(N)RP@)&9I;&5?
M96XI*2D["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@
M("`@("`@("`@8V]N=&EN=64@,CL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D9&]C7VQO8R`@/2!D;VUX;6Q?;W!E;E]F:6QE*"1F:6QE7VQO8RD["B`@
M("`@("`@("`@(&EF("@A:7-?;V)J96-T*"1D;V-?;&]C*2D@>PH@("`@("`@
M("`@("`@("`@)&,M/G=R:71E;&XH=V]R9'=R87`H)&,M/G)E9"@G5V%R;FEN
M9SH@)RD@+B!S<')I;G1F*"=4:&5R92!W87,@86X@97)R;W(@;W!E;FEN9R!T
M:&4@9FEL92`E<RX@5')Y(')U;FYI;F<@=')A;G-L871I;VXN<&AP('=I=&@@
M=&AE(&9L86<@+60@=&\@<V5E(&%N>2!E<G)O<B!M97-S86=E<R!F<F]M('1H
M92!X;6P@<&%R<V5R+B<L("1F:6QE7VQO8RDI*3L*("`@("`@("`@("`@("`@
M("1C+3YW<FET96QN*"D["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D:&5L<%]L;V,@/2`D9&]C7VQO8RT^
M9&]C=6UE;G1?96QE;65N="@I.PH@("`@("`@("`@("`D;60U7V5N("`@/2!A
M<G)A>2@I.PH@("`@("`@("`@("`D8V]U;G1?86QL(#T@,#L*("`@("`@("`@
M("`@)&-O=6YT("`@("`](#`["B`@("`@("`@("`@(&9O<F5A8V@@*"1D;V-?
M96XM/F=E=%]E;&5M96YT<U]B>5]T86=N86UE*"=E;G1R>2<I(&%S("1E;G1R
M>2D@>PH@("`@("`@("`@("`@("`@)&UD-5]E;ELD96YT<GDM/F=E=%]A='1R
M:6)U=&4H)VED)RE=(#T@;60U*"1E;G1R>2T^9V5T7V-O;G1E;G0H*2D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@9F]R96%C:"`H)&1O8U]L;V,M/F=E
M=%]E;&5M96YT<U]B>5]T86=N86UE*"=E;G1R>2<I(&%S("1E;G1R>2D@>PH@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)&5N=')Y+3YC:&EL9%]N;V1E<R@I
M(&%S("1C:&EL9"D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D8VAI;&0M
M/FYO9&5?='EP92@I(#T](%A-3%]#3TU-14Y47TY/1$4@)B8@<W1R<W1R*"1C
M:&EL9"T^;F]D95]V86QU92@I+"`G16YG;&ES:"!E;G1R>2<I*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1E;G1R>2T^<F5M;W9E7V-H:6QD*"1C:&EL
M9"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)&-O=6YT7V%L;"LK.PH@("`@("`@("`@("`@("`@
M)&ED(#T@)&5N=')Y+3YG971?871T<FEB=71E*"=I9"<I.PH@("`@("`@("`@
M("`@("`@:68@*"%A<G)A>5]K97E?97AI<W1S*"1I9"P@)&UD-5]E;BDI('L*
M("`@("`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;BAW;W)D=W)A<"@D8RT^
M<F5D*"=787)N:6YG.B`G*2`N('-P<FEN=&8H)TYO(&5N=')Y('=I=&@@=&AE
M(&ED("(E<R(@97AI<W1S(&EN('1H92!O<FEG:6YA;"!H96QP(&9I;&4N)RP@
M)&ED*2DI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D96YT<GDM/G-E=%]A='1R:6)U=&4H)VUD-2<L("1M9#5?96Y;
M)&ED72D["B`@("`@("`@("`@("`@("`@("`@)&5N=')Y+3YS971?871T<FEB
M=71E*"=S=&%T92<L("=U<'1O9&%T92<I.PH@("`@("`@("`@("`@("`@("`@
M("1C;W5N="LK.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1O=71P=70@/2`D9&]C7VQO8RT^9'5M<%]M96TH=')U92P@
M)&5N8V]D:6YG*3L*("`@("`@("`@("`@:68@*"$D=&5S="D@>PH@("`@("`@
M("`@("`@("`@)&9P(#T@9F]P96XH)&9I;&5?;&]C+"`G=R<I.PH@("`@("`@
M("`@("`@("`@)&QI;F4@/2!F=W)I=&4H)&9P+"`D;W5T<'5T*3L*("`@("`@
M("`@("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1C+3YW<FET96QN*'-P<FEN=&8H)R5D(&]F("5D(&5N=')I97,@;6%R
M:V5D(&%S('5P+71O+61A=&4G+"`D8V]U;G0L("1C;W5N=%]A;&PI*3L*("`@
M("`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("!]"B`@("!]"GT*"B1C
M=7)D:7(@/2!G971C=V0H*3L*9&5F:6YE*"=$4R<L($1)4D5#5$]265]315!!
M4D%43U(I.PH*)&QA;F=U86=E(#T@9V5T96YV*"=,04Y')RD["FEF("AE;7!T
M>2@D;&%N9W5A9V4I*2!["B`@("`D;&%N9W5A9V4@/2!G971E;G8H)TQ!3D=5
M04=%)RD["GT*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,
M15]?*2`N("<O+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI
M8B]C;W)E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O0TQ)+G!H<"<["@HD
M8R`]("9N97<@2&]R9&5?0TQ)*"D["FEF("@A)&,M/G)U;FYI;F=&<F]M0TQ)
M*"DI('L*("`@("1C+3YF871A;"@G5&AI<R!S8W)I<'0@;75S="!B92!R=6X@
M9G)O;2!T:&4@8V]M;6%N9"!L:6YE+B<I.PI]"B1C+3YI;FET*"D["@HD8RT^
M=W)I=&5L;B@D8RT^8F]L9"@G+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M)RDI.PHD8RT^=W)I=&5L;B@D8RT^8F]L9"@G2&]R9&4@=')A;G-L871I;VX@
M9V5N97)A=&]R)RDI.PHD8RT^=W)I=&5L;B@D8RT^8F]L9"@G+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM)RDI.PH*+RH@4V%N:71Y(&-H96-K<R`J+PII
M9B`H(65X=&5N<VEO;E]L;V%D960H)V=E='1E>'0G*2D@>PH@("`@)&,M/G=R
M:71E;&XH)&,M/G)E9"@G1V5T=&5X="!E>'1E;G-I;VX@;F]T(&9O=6YD(2<I
M*3L*("`@(&9O;W1E<B@I.PI]"@HD8RT^=W)I=&5L;B@G3&]A9&EN9R!L:6)R
M87)I97,N+BXG*3L*)&QI8G-?9F]U;F0@/2!T<G5E.PH*9F]R96%C:"`H87)R
M87DH)T-O;G-O;&5?1V5T;W!T)R`]/B`G0V]N<V]L92]'971O<'0N<&AP)RP*
M("`@("`@("`@("`@("`@)T-O;G-O;&5?5&%B;&4G("`]/B`G0V]N<V]L92]4
M86)L92YP:'`G+`H@("`@("`@("`@("`@("`G1FEL95]&:6YD)R`@("`@(#T^
M("=&:6QE+T9I;F0N<&AP)RD*("`@("`@("`@87,@)&-L87-S(#T^("1F:6QE
M*2!["B`@("!E8VAO("1C;&%S<R`N("<N+BX@)SL*("`@($!I;F-L=61E("1F
M:6QE.PH@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@
M)&,M/G=R:71E;&XH)&,M/F=R965N*"=/2R<I*3L*("`@('T@96QS92!["B`@
M("`@("`@)&,M/G=R:71E;&XH)&,M/G)E9"AS<')I;G1F*"<E<R!N;W0@9F]U
M;F0N)RP@)&-L87-S*2DI.PH@("`@("`@("1L:6)S7V9O=6YD(#T@9F%L<V4[
M"B`@("!]"GT*"FEF("@A)&QI8G-?9F]U;F0I('L*("`@("1C+3YW<FET96QN
M*"D["B`@("`D8RT^=W)I=&5L;B@G36%K92!S=7)E('1H870@>6]U(&AA=F4@
M4$5!4B!I;G-T86QL960@86YD(&EN('EO=7(@:6YC;'5D92!P871H+B<I.PH@
M("`@)&,M/G=R:71E;&XH)VEN8VQU9&5?<&%T:#H@)R`N(&EN:5]G970H)VEN
M8VQU9&5?<&%T:"<I*3L*("`@(&9O;W1E<B@I.PI]"B1C+3YW<FET96QN*"D[
M"@HO*B!#;VUM86YD;&EN92!P87)A;65T97)S("HO"B1A<F=S("`@(#T@0V]N
M<V]L95]'971O<'0Z.G)E86102%!!<F=V*"D["B1O<'1I;VYS(#T@0V]N<V]L
M95]'971O<'0Z.F=E=&]P="@D87)G<RP@)V(Z9&AT)RP@87)R87DH)V)A<V4]
M)RP@)V1E8G5G)RP@)VAE;'`G+"`G=&5S="<I*3L*:68@*%!%05(Z.FES17)R
M;W(H)&]P=&EO;G,I("8F("1A<F=S6S!=(#T]("1?4T525D526R=02%!?4T5,
M1B==*2!["B`@("!A<G)A>5]S:&EF="@D87)G<RD["B`@("`D;W!T:6]N<R`]
M($-O;G-O;&5?1V5T;W!T.CIG971O<'0H)&%R9W,L("=B.F1H="<L(&%R<F%Y
M*"=B87-E/2<L("=D96)U9R<L("=H96QP)RP@)W1E<W0G*2D["GT*:68@*%!%
M05(Z.FES17)R;W(H)&]P=&EO;G,I*2!["B`@("`D8RT^=W)I=&5L;B@D8RT^
M<F5D*"='971O<'0@17)R;W(Z("<@+B!S=')?<F5P;&%C92@G0V]N<V]L95]'
M971O<'0Z)RP@)R<L("1O<'1I;VYS+3YG971-97-S86=E*"DI*2D["B`@("`D
M8RT^=W)I=&5L;B@I.PH@("`@=7-A9V4H*3L*("`@(&9O;W1E<B@I.PI]"FEF
M("AE;7!T>2@D;W!T:6]N<ULP75LP72D@)B8@96UP='DH)&]P=&EO;G-;,5U;
M,%TI*2!["B`@("`D8RT^=W)I=&5L;B@D8RT^<F5D*"=%<G)O<CH@)R`N("=.
M;R!C;VUM86YD('-P96-I9FEE9"XG*2D["B`@("`D8RT^=W)I=&5L;B@I.PH@
M("`@=7-A9V4H*3L*("`@(&9O;W1E<B@I.PI]"B1D96)U9R`](&9A;'-E.PHD
M=&5S="`@/2!F86QS93L*9F]R96%C:"`H)&]P=&EO;G-;,%T@87,@)&]P=&EO
M;BD@>PH@("`@<W=I=&-H("@D;W!T:6]N6S!=*2!["B`@("`@("`@8V%S92`G
M8B<Z"B`@("`@("`@8V%S92`G+2UB87-E)SH*("`@("`@("`@("`@:68@*'-U
M8G-T<B@D;W!T:6]N6S%=+"`M,2D@/3T@1%,I('L*("`@("`@("`@("`@("`@
M("1O<'1I;VY;,5T@/2!S=6)S='(H)&]P=&EO;ELQ72P@,"P@+3$I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&1E9FEN92@G0D%312<L("1O<'1I;VY;
M,5TI.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!C87-E("=D)SH*("`@
M("`@("!C87-E("<M+61E8G5G)SH*("`@("`@("`@("`@)&1E8G5G(#T@=')U
M93L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S92`G="<Z"B`@("`@
M("`@8V%S92`G+2UT97-T)SH*("`@("`@("`@("`@)'1E<W0@/2!T<G5E.PH@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("!C87-E("=H)SH*("`@("`@("!C
M87-E("<M+6AE;'`G.@H@("`@("`@("`@("!U<V%G92@I.PH@("`@("`@("`@
M("!F;V]T97(H*3L*("`@('T*?0II9B`H(21D96)U9RD@>PH@("`@:6YI7W-E
M="@G97)R;W)?<F5P;W)T:6YG)RP@9F%L<V4I.PI]"FEF("@A9&5F:6YE9"@G
M0D%312<I*2!["B`@("!D969I;F4H)T)!4T4G+"!(3U)$15]"05-%*3L*?0II
M9B`H)&]P=&EO;G-;,5U;,%T@/3T@)VAE;'`G*2!["B`@("!U<V%G92@I.PH@
M("`@9F]O=&5R*"D["GT*)'-I;&5N8V4@/2`D9&5B=6<@?'P@3U-?5TE.1$]7
M4R`_("<G(#H@)R`R/B`O9&5V+VYU;&PG.PHD<F5D:7)?97)R(#T@3U-?5TE.
M1$]74R`_("<G(#H@)R`R/B8Q)SL*)&]P=&EO;G-?;&ES="`](&%R<F%Y*`H@
M("`@)V-L96%N=7`G("`@(#T^(&%R<F%Y*"=H;#IM.B<L(&%R<F%Y*"=M;V1U
M;&4])RP@)VQO8V%L93TG*2DL"B`@("`G8V]M;6ET)R`@("`@/3X@87)R87DH
M)VAL.FTZ;DTZ)RP@87)R87DH)VUO9'5L93TG+"`G;&]C86QE/2<L("=N97<G
M+"`G;65S<V%G93TG*2DL"B`@("`G8V]M;6ET+6AE;'`G/3X@87)R87DH)VAL
M.FTZ;DTZ)RP@87)R87DH)VUO9'5L93TG+"`G;&]C86QE/2<L("=N97<G+"`G
M;65S<V%G93TG*2DL"B`@("`G8V]M<&5N9&EU;2<@/3X@87)R87DH)VAL.F0Z
M83HG+"!A<G)A>2@G;&]C86QE/2<L("=D:7)E8W1O<GD])RP@)V%D9#TG*2DL
M"B`@("`G97AT<F%C="<@("`@/3X@87)R87DH)VAM.B<L(&%R<F%Y*"=M;V1U
M;&4])RDI+`H@("`@)VEN:70G("`@("`@(#T^(&%R<F%Y*"=H;#IM.FYC.B<L
M(&%R<F%Y*"=M;V1U;&4])RP@)VQO8V%L93TG+"`G;F\M8V]M<&5N9&EU;2<L
M("=C;VUP96YD:75M/2<I*2P*("`@("=M97)G92<@("`@("`]/B!A<G)A>2@G
M:&PZ;3IC.FXG+"!A<G)A>2@G;6]D=6QE/2<L("=L;V-A;&4])RP@)V-O;7!E
M;F1I=6T])RP@)VYO+6-O;7!E;F1I=6TG*2DL"B`@("`G;6%K92<@("`@("`@
M/3X@87)R87DH)VAL.FTZ8SIN<R<L(&%R<F%Y*"=M;V1U;&4])RP@)VQO8V%L
M93TG+"`G8V]M<&5N9&EU;3TG+"`G;F\M8V]M<&5N9&EU;2<L("=S=&%T:7-T
M:6-S)RDI+`H@("`@)VUA:V4M:&5L<"<@(#T^(&%R<F%Y*"=H;#IM.B<L(&%R
M<F%Y*"=M;V1U;&4])RP@)VQO8V%L93TG*2DL"B`@("`G=7!D871E)R`@("`@
M/3X@87)R87DH)VAL.FTZ8SIN)RP@87)R87DH)VUO9'5L93TG+"`G;&]C86QE
M/2<L("=C;VUP96YD:75M/2<L("=N;RUC;VUP96YD:75M)RDI+`H@("`@)W5P
M9&%T92UH96QP)ST^(&%R<F%Y*"=H;#IM.B<L(&%R<F%Y*"=M;V1U;&4])RP@
M)VQO8V%L93TG*2DL"B`@("`G<W1A='5S)R`@("`@/3X@87)R87DH)VAL.FTZ
M;SHG+"!A<G)A>2@G;6]D=6QE/2<L("=L;V-A;&4])RP@)V]U='!U=#TG*2D*
M*3L*)&]P=&EO;G-?87)R(#T@)&]P=&EO;G-;,5T["B1C;60@("`@("`@("`]
M(&%R<F%Y7W-H:69T*"1O<'1I;VYS7V%R<BD["FEF("AA<G)A>5]K97E?97AI
M<W1S*"1C;60L("1O<'1I;VYS7VQI<W0I*2!["B`@("`D8VUD7V]P=&EO;G,@
M/2!#;VYS;VQE7T=E=&]P=#HZ9V5T;W!T*"1O<'1I;VYS7V%R<BP@)&]P=&EO
M;G-?;&ES=%LD8VUD75LP72P@)&]P=&EO;G-?;&ES=%LD8VUD75LQ72D["B`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VUD7V]P=&EO;G,I*2!["B`@("`@("`@
M)&,M/G=R:71E;&XH)&,M/G)E9"@G17)R;W(Z("<@+B!S=')?<F5P;&%C92@G
M0V]N<V]L95]'971O<'0Z)RP@)R<L("1C;61?;W!T:6]N<RT^9V5T365S<V%G
M92@I*2DI.PH@("`@("`@("1C+3YW<FET96QN*"D["B`@("`@("`@=7-A9V4H
M*3L*("`@("`@("!F;V]T97(H*3L*("`@('T*?0H*+RH@4V5A<F-H:6YG(&%P
M<&QI8V%T:6]N<R`J+PIC:&5C:U]B:6YA<FEE<R@I.PH*)&,M/G=R:71E;&XH
M<W!R:6YT9B@G4V5A<F-H:6YG($AO<F1E(&%P<&QI8V%T:6]N<R!I;B`E<R<L
M($)!4T4I*3L*)&1I<G,@/2!S96%R8VA?87!P;&EC871I;VYS*"D["@II9B`H
M)&1E8G5G*2!["B`@("`D8RT^=W)I=&5L;B@G1F]U;F0@9&ER96-T;W)I97,Z
M)RD["B`@("`D8RT^=W)I=&5L;BAI;7!L;V1E*")<;B(L("1D:7)S*2D["GT*
M"B1A<'!S(#T@<W1R:7!?:&]R9&4H)&1I<G,I.PHD87!P<ULP72`]("=H;W)D
M92<["B1C+3YW<FET96QN*'=O<F1W<F%P*'-P<FEN=&8H)T9O=6YD(&%P<&QI
M8V%T:6]N<SH@)7,G+"!I;7!L;V1E*"<L("<L("1A<'!S*2DI*3L*)&,M/G=R
M:71E;&XH*3L*"G-W:71C:"`H)&-M9"D@>PH@("`@8V%S92`G8VQE86YU<"<Z
M"B`@("!C87-E("=C;VUM:70G.@H@("`@8V%S92`G8V]M<&5N9&EU;2<Z"B`@
M("!C87-E("=M97)G92<Z"B`@("`@("`@)&-M9"@I.PH@("`@("`@(&)R96%K
M.PH@("`@8V%S92`G8V]M;6ET+6AE;'`G.@H@("`@("`@(&-O;6UI="AT<G5E
M*3L*("`@("`@("!B<F5A:SL*("`@(&-A<V4@)V5X=')A8W0G.@H@("`@("`@
M('AT<F%C="@I.PH@("`@("`@(&)R96%K.PH@("`@8V%S92`G:6YI="<Z"B`@
M("`@("`@:6YI="@I.PH@("`@("`@("1C+3YW<FET96QN*"D["B`@("`@("`@
M;65R9V4H*3L*("`@("`@("!B<F5A:SL*("`@(&-A<V4@)VUA:V4G.@H@("`@
M("`@(&-L96%N=7`H=')U92D["B`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@
M("`@("!M86ME*"D["B`@("`@("`@8G)E86L["B`@("!C87-E("=M86ME+6AE
M;'`G.@H@("`@("`@(&UA:V5?:&5L<"@I.PH@("`@("`@(&)R96%K.PH@("`@
M8V%S92`G=7!D871E)SH*("`@("`@("!X=')A8W0H*3L*("`@("`@("`D8RT^
M=W)I=&5L;B@I.PH@("`@("`@(&UE<F=E*"D["B`@("`@("`@8G)E86L["B`@
M("!C87-E("=U<&1A=&4M:&5L<"<Z"B`@("`@("`@=7!D871E7VAE;'`H*3L*
M("`@("`@("!B<F5A:SL*("`@(&-A<V4@)W-T871U<R<Z"B\O("`@("`@("!X
M=')A8W0H*3L*("`@("`@("!M97)G92@I.PHO+R`@("`@("`@<W1A='5S*"D[
M"B`@("`@("`@8G)E86L["B`@("!D969A=6QT.@H@("`@("`@("1C+3YW<FET
M96QN*"1C+3YR960H)T5R<F]R.B`G*2`N('-P<FEN=&8H)U5N:VYO=VX@8V]M
M;6%N9#H@)7,G+"`D8VUD*2D["B`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@
M("`@("!U<V%G92@I.PH@("`@("`@(&9O;W1E<B@I.PI]"@IF;V]T97(H*3L*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O=6M?
M54$N<&\`````````````````````````````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#8P-34V,P`Q,#4Q-30S,S<U-``P,3<V-C``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````(R!(;W)D92!5:W)A:6YI
M86X@2T])."U5('1R86YS;&%T:6]N"B,@0V]P>7)I9VAT("A#*2`R,#`R($%N
M9')I>2!+;W!Y<W1Y86YS:WDN"B,@06YD<FEY($MO<'ES='EA;G-K>2`\86YR
M:4!P;VQY;F5T+FQV:78N=6$^+"`R,#`R+@HC"FUS9VED("(B"FUS9W-T<B`B
M(@HB4')O:F5C="U)9"U697)S:6]N.B!(;W)D92!V,BXQ7&XB"B)297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V
M:7-I;VXM1&%T93H@,C`P,BTP,2TP-2`Q-CHQ-2LP,C`P7&XB"B),87-T+51R
M86YS;&%T;W(Z($%N9')I>2!+;W!Y<W1Y86YS:WD@/&%N<FE`<&]L>6YE="YL
M=FEV+G5A/EQN(@HB3&%N9W5A9V4M5&5A;3H@56MR86EN:6%N(#QW96)M87-T
M97)`<&]L>6YE="YL=FEV+G5A/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*
M(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U+3TDX+55<;B(*
M(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET7&XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,3,W,`HC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S
M<VME>2`E<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,W-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S,*;7-G
M:60@(B`H=&]D87DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-S4*;7-G:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S$*;7-G:60@(B`H>65S=&5R
M9&%Y*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C4V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C$*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-PIM<V=I9"`B(&%T("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R
M>2YP:'`Z-C4Y"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP
M:'`Z,3`T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O
M;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4V"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES
M=&5M+B(*;7-G<W1R("+UT]"FV\[/(,3/Q,'.SR`G)7,G(,3/(-/)T]3%S<DN
M(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS
M('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W"B,L
M('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@
M=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@U"B,L('!H<"UF;W)M870*
M;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M+2!.;W1I8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HW,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R
M<')I;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z.#,S(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C@S-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO
M;B(*;7-G<W1R("+OT,72P<.FT2#0TL_&ILS!R]3)WL[/Q\\@S\+3S-7'S]?5
MU\'.SM$@)7,@+2#PIL34U\72Q-;%SL[1(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@
M06=R965M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-#(X(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DP"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C4Q(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@
M97AI<W1S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U
M.2!L:6(O0FQO8VLO;65T87(N<&AP.C$V-2!L:6(O0FQO8VLO;65T87(N<&AP
M.C(S.0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T-2!L:6(O0FQO8VLO;65T
M87(N<&AP.C,U,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E
M<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO
M=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@
M=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B]Z;$S:;4
MV-3%(,_0Q=+#IL`HIRDL(-'+IB#3S*;$(-K$ILK3SLG4R2#7(,/%RB#>P=,N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,T,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M
M:6YU=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#
M;VQL96-T:6]N+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(R
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O
M:R(*;7-G<W1R("+AQ-+%T\[!(,O.R<?!(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE
M;F1A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDP-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H
M<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G
M92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R
M92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I
M9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S8U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,3`*;7-G:60@(BP@
M9W5S=&EN9R`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M.#@@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@
M9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C(Y-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C,T.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q,C@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C<T.0IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U
M<B!&;W)M870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y
M"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B
M,C0@Q\_$R<[)(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM
M<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3$Y"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER
M960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,38P"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O
M8V-U<G)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER
M960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C4*;7-G:60@(D$@<'5B;&EC
M(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$P.3<*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@
M4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y
M<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,#$U"FUS9VED("(B"B)!('!U8FQI8R!01U`@
M:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#4*;7-G:60@(B(*(D$@
M<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T
M92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-
M12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@
M4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B
M04T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED
M(")!32]032(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B
M<VUI9&1L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93
M(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS
M"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW-0HC+"!F=7IZ>0IM<V=I9"`B06-C;W5N
M="!087-S=V]R9"(*;7-G<W1R("+PIL34U\72Q-;%SL[1(-#!TL_,P"(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS,S,*;7-G:60@(D%C8V]U;G1I;F<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@
M=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")!9&0B
M"FUS9W-T<B`BX<32Q=/!(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M
M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL
M9"!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M861D+FEN8SHU"B,L(&9U>GIY"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`B
MY,_$P=3)(,O/TLG3U-77P=[!(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@
M861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W
M(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]A9&1C:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@
M82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R
M.B(*;7-G<W1R("+DS\3!U,D@SL_7S\?/(,O/TLG3U-77P=[!.B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-30*;7-G:60@
M(D%D9"!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHS-`HC+"!F=7IZ>0IM<V=I9"`B061D(&YE=R!M96UB
M97)S(@IM<V=S='(@(N3/Q,'4R2#.S]?/Q\\@R\_2R=/4U=?!WL$Z(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B
M"FUS9W-T<B`BY,_$P=3)(-#!TM4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A
M<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@
M(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(N'$TL73SL$@R\[)Q\$B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*
M(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T
M<B`BX<32Q=/.P2#+SLG'P2(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED
M(")!9&0@=7-E<B(*;7-G<W1R("+DS\3!U,D@R\_2R=/4U=?!WL$B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E
M9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D
M:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B
M"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D
M(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR
M"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(N3/
MQ,'7P<[.T2#+S]+)T]35U\'>IM<@VL'"S]+/SL7.Q2XB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30T,0IM<V=I9"`B061D<F5S<R(*;7-G<W1R("+AQ-+%
MT\$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,Y"B,L(&9U>GIY
M"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`BX<32Q=/.P2#+SLG'P2(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS
M9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U
M<V5R<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I
M;VXB"FUS9W-T<B`BX<3-ILZFT]32U=?!SL[1(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,T,0HC+"!F=7IZ>0IM<V=I9"`B061S(@IM<V=S='(@
M(N'$TL73P2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(D%L8F%N:6$B"FUS
M9W-T<B`B\-/%U\3/SJ;-(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B
M06QG97)I82(*;7-G<W1R("+PT\77Q,_.ILTB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G
M<W1R("+PT\77Q,_.ILTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C$V"B,L(&9U>GIY"FUS9VED(")!;&EG;B(*
M;7-G<W1R("+PT\77Q,_.ILTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C`W
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H
M96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U"FUS9VED
M(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL
M(&9O=7(@<VED97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@W,0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S0*;7-G:60@
M(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P
M-`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$R,PIM<V=I9"`B06QT97)N871E($E-4U`@3&]G
M:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-PIM
M<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y.0IM<V=I9"`B06QT97)N871E($E-
M4U`@57-E<FYA;64B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A
M9&1R97-S(@IM<V=S='(@(O?!V\$@P<32Q=/!(,4MT,_;U,DZ(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X
M=#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M
M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HY-2!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B
M06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38W"FUS9VED(")!;B!U
M;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G
M:60@(D%N9V]L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U
M:6QL82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B
M"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P
M:'!S:&5L;"YP:'`Z,S4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H
M<#HU."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED
M(")!<'!L:6-A=&EO;B(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC871I
M;VX@:7,@<F5A9'DN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z
M,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z.#,S"FUS9VED(")!<'!R;WAI;6%T92!3
M:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R
M-38I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HV-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@Q
M"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX,`IM<V=I9"`B07)C:&EV92!.86UE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E
M9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO
M=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N
M:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI82(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$W-@IM<V=I9"`B07)M96YI86X@*$%235-#
M24DM."DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X
M"FUS9VED(")!<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U
M8F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@
M(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0R-0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@
M8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3,*;7-G:60@(D%S
M<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N
M="!G<F]U<"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H
M<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@
M<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP
M:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N
M="!S:&%R92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#8*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')I82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED
M(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@
M:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y
M<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O9G1P+G!H<#HS-@IM<V=I
M9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I
M=&-H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N
M<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K
M<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD87`Z
M($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER
M96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B
M075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,S,Y"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O
M(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS
M.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@
M<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U=&A?
M;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T
M:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-
M0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H
M.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J
M96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G:60@(D%U=&AE;G1I8V%T:6]N
M('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C<P"FUS9VED(")!=71H96YT:6-A=&EO;B!T
M;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L
M9',Z(@IM<V=S='(@(N3/T]35T,ZF(-#/S-$Z(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I
M9"`B07IE<F)A:6IA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X
M"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U
M;F0@0V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K
M<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS
M9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C(*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM
M<V=I9"`B0F%H<F%I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$W-PIM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8P"FUS9VED(")"87)B861O<R(*;7-G<W1R("(B"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S
M92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<S"FUS9VED(")"87-E;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8S"FUS9VED(")"96QA<G5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G
M:60@(D)E;&=I=6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L
M:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I
M<G1H9&%Y(@IM<V=S='(@(N3%SM@@SL'2S\36Q<[.T2(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C
M:R!4>7!E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR,#4*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(P"B,L(&9U>GIY"FUS9VED(")";W)D97(B"FUS9W-T<B`B2&]R
M9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Q
M"B,L(&9U>GIY"FUS9VED(")";W)D97)S(@IM<V=S='(@(DAO<F1E(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<U"FUS9VED(")";W1T;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R
M"B,L(&9U>GIY"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B24U0+=#/TM3!S"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R
M:71O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A
M<G5S<V%L86TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R
M:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0T"B,L(&9U>GIY"FUS9VED(")#35,B
M"FUS9W-T<B`B0U93(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES=')I
M8G5T:6]N(%!O:6YT<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL
M(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O
M;7!L971E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0X-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3@W
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-34*;7-G:60@(D-A;&5N
M9&%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-#8*;7-G:60@(D-A;&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(D-A;6)O9&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A
M;65R;V]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I
M8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,3@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T
M(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#$S"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N
M8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(O>FQ,VFSLG4R2#0S]>FQ,_-
MS,7.SM$@T-+/PLS%S<DB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713
M=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP
M;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O
M8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H
M<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD
M<F5N(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O
M1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R
M+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S
M(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*
M;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB
M97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR-`HC+"!F=7IZ>0IM<V=I9"`B0V%P=&EO;B(*;7-G
M<W1R("+ZPL72Q<?4R2#/T,.FIR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`*;7-G:60@(D-A=&5G
M;W)I97,@86YD($QA8F5L<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I
M9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N
M92(*;7-G<W1R("+SU*;,V,[)R\_7R<H@U,7,Q<;/SB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*(RP@9G5Z
M>GD*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R("+SU*;,V,[)R\_7
MR<H@U,7,Q<;/SB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I
M9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C<T"B,L(&9U>GIY"FUS9VED(")#96QL<&AO;F4B"FUS
M9W-T<B`B\]2FS-C.R<O/U\G*(-3%S,7&S\XB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$W.`IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B0V5N=')A;"!%
M=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.3D*;7-G:60@(D-E<G1I9FEC871E
M($1E=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV,3$*;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV
M"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHY-@HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(O/+P=/5
MU\'4R2#:S:;.R2(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS
M,0HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T
M<B`B\*;$U-?%TL36Q<[.T2#0P=+/S,`B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C8*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S
M<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O
M('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z,C0*;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S
M<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I
M9W5R871I;VXN("`B"B)#;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*
M;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*
M(RP@9G5Z>GD*;7-G:60@(D-H:6QE(@IM<V=S='(@(O3)U-7,(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-PIM<V=I9"`B0VAI;F$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R
M*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I
M9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0HC+"!F=7IZ>0IM
M<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B\*;$U-?%TL36Q<[.
MT2#0P=+/S,`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M,C8X"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDX"FUS9VED(")#:&]O<V4@:&]W('1O
M(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H
M;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HX.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS
M9VED(")#;&5A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T
M86=S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G
M:60@(D-L96%R(%%U97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R
M(&]U="!U<V5R.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@
M(D-L96%R('5S97(@9&%T82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@
M(OK!R]+)U,D@UZ;+SL\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-`IM
M<V=I9"`B0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS
M9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S"FUS9VED(")#;VQL87!S
M92!3:61E8F%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B
M;W)D97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L
M;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(T
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C4*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,"!S
M97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO
M<B!0:6-K97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@T-@IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM
M<V=I9"`B0V]L<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3DT-@IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8T"FUS9VED(")#;VUI8W,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"B,L(&9U>GIY
M"FUS9VED(")#;VUM86YD(@IM<V=S='(@(NO/S=#!SJ;1(@H*(SH@861M:6XO
M8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I
M9"`B0V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4V-@IM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#0*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I
M9"`B0V]M<&%N>2(*;7-G<W1R("+KS\W0P<ZFT2(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3<*;7-G:60@(D-O;F1I
M=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T.0IM
M<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D
M:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30S"FUS9VED
M(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P
M:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F
M(&1A=&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3$*;7-G
M:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B\*;$U-?%TL36Q<[.T2#0
MP=+/S,`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L
M:6,@;V8@=&AE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B
M0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW
M.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-#4*;7-G:60@
M(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#$T"FUS9VED(")#;VYT86-T
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(O?-IM/4("<E
M<R<B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(D-O<'DB"FUS
M9W-T<B`BZ\_-T,'.IM$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C0V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z
M("5S(@IM<V=S='(@(K;-T,_2U,_7P<[%(-#/S,4Z("5S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P
M>2!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDW-@IM<V=I9"`B0V]U;&0@
M;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-3,*;7-G:60@(D-O=6QD(&YO
M="!01U`@<VEG;B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O
M34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@
M4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ,C$*;7-G:60@(D-O=6QD(&YO
M="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-#4W"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!L
M9&%P('-E<G9E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-#$*;7-G:60@(D-O=6QD(&YO
M="!C;VYN96-T('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$R-0IM<V=I9"`B0V]U
M;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3(R"FUS9VED(")#;W5L9"!N
M;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HS.#$@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S"FUS
M9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA
M:6P@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F
M971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS
M9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI
M<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE
M(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T
M96=Y+V1I<F5C="YP:'`Z,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN
M('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,C8R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E
M;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C0W.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-CDY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$
M05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/
M8FIE8W0N<&AP.C(S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<F5A9"`E<RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O
M<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE
M("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE
M<B!H96QP+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS,#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S0P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,W-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS.#,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S@Y"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR
M,C,*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL
M:71I97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU
M-`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")(;W)D92#.Q2#3R\_.QJ;'U=+/U\'.P2#0TL'7R<S8
MSL\B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF
M:6=U871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A
M8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@
M;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E
M:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C
M;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO
M=R!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HQ-#,*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@
M<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U
M<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T
M:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-C8*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL
M;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C$U-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E
M('5S97(@7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L
M9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30Q.0IM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED
M(")#;W5N=')Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR-S,*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P
M"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A
M=&4@82!L:6YK(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N
M=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E
M871O<B!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,C,P"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,C8*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C0X"FUS9VED(")#=7)R
M96YT(%-E<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,S"FUS9VED(")#=7)R
M96YT(%5S97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<U"FUS9VED(")#=7)R96YT(&-O
M;F1I=&EO;CH@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G
M;VX@=&\@)7,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@R"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL
M:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#0*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI
M8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#4Q('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$
M1"(*;7-G<W1R("+DY"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M.#$*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N
M=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E
M+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B_<_$Q<[.SR(*"B,Z(&%D
M;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<Y"FUS
M9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,SDY"B,L(&9U>GIY"FUS9VED(")$871E(@IM<V=S='(@
M(O?)U,72U,DB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN
M8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`W"FUS9VED(")$871E('-E;&5C=&EO
M;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,CDR(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,C(*(RP@9G5Z>GD*
M;7-G:60@(D1A>2(*;7-G<W1R("+]S\3%SL[/(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"B,L(&9U>GIY
M"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R("+WR=3%TM3)(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@
M(D1E8V5M8F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@
M;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@
M;&EB+W!R969S+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B"FUS
M9W-T<B`B]\G4Q=+4R2(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C<W"B,L(&9U>GIY"FUS9VED(")$969A=6QT($-O;&]R
M(@IM<V=S='(@(O?)R\_2R=/4S]?5U\'4R2#:SL'>Q<[.T2#:P2#:P<W/U][5
MU\'.SM'-(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HY
M,0IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R("+OT\[/U\[!(*;0
MS]/4P=/8(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"B,L(&9U>GIY
M"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(N_3SL_7SL$@IM#/T]3!
MT]@B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN
M:71I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R("+WR=3%TM3)
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,R"B,L(&9U>GIY"FUS9VED(")$96QE=&4@0V5L;"(*;7-G<W1R
M("+WR=3%TM3)(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O
M=7!S+G!H<#HR,C<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G
M<W1R("+WR=3%TM3)(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C0Y"B,L(&9U>GIY"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@(O?)U,72
MU,DB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE=&4@4&5R
M;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S
M86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@
M8V5L;"(*;7-G<W1R("+WR=3%TM3)(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PHC+"!F=7IZ>0IM<V=I9"`B
M1&5L971E(&-O;'5M;B(*;7-G<W1R("+WR=3%TM3)(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA
M=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E
M<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R
M;6ES<VEO;G,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E
M;&5T92!R;W<B"FUS9W-T<B`B]\G4Q=+4R2(*"B,Z('1E;7!L871E<R]P<F5F
M<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*(RP@9G5Z>GD*;7-G:60@(D1E;&5T
M92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R("+OT\[/U\[!(*;0S]/4P=/8
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8W"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O
M=R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R
M:7!T(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PHC+"!F=7IZ
M>0IM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R("+WR=3%TM3)(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE
M(%!R;V)L96TB"FUS9W-T<B`B[]#)VZ;4V"#0TL_"S,7-U2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.CDS."!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,P"B,L(&9U>GIY"FUS9VED(")$97-C
M<FEP=&EO;B(*;7-G<W1R("+PS]?.R<H@S]#)TSHB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$Y-0IM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(
M;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$Y.0IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G
M9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q.0IM<V=I9"`B1&5V96QO<&UE;G0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3<*;7-G:60@
M(D1E=R!0;VEN="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(Y-`IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(W"FUS9VED
M(")$97<@<&]I;G0Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F
M="!T;R!R:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@
M=&\@;&5F="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-C8*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"B,L(&9U
M>GIY"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B^L+%TL7'U,D@
MS]##IJ<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.38*;7-G
M:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HX-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S
M="`H5$%&*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.#$W"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DP"FUS9VED(")$:7-P;W-I
M=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I
M9"`B1&II8F]U=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HT,C(*(RP@9G5Z>GD*;7-G:60@(D1O(&YO="!D96QE=&4B
M"FUS9W-T<B`B]\G4Q=+4R2(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC
M92YP:'`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI
M;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O
M97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@
M>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM
M<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B
M1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N
M=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z.#0T"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N
M97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O
M<"!D;W=N(&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*(RP@9G5Z>GD*;7-G:60@(D4M36%I
M;"(*;7-G<W1R("))35`MT,_2U,',(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G
M871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI
M<R!S97)V:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED
M(")%4E(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P('1E;7!L871E
M<R]P;W)T86PO961I="YI;F,Z,C4*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T
M<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H
M<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$P,`IM<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D
M:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S
M+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI
M<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O
M87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D
M=6-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%:71H97(@96YA8FQE(&ET('1H96XZ("5S
M+"!O<B!U<V4@=&AE(&)A<VEC($A434P@=F5R<VEO;CH@)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED
M(")%;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD*
M;7-G:60@(D5M86EL(@IM<V=S='(@(N4MT,_;U,$B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-2!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-C@*(RP@9G5Z>GD*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T
M<B`B]\';P2#!Q-+%T\$@Q2W0S]O4R3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.38S"B,L(&9U>GIY"FUS9VED(")%;6%I;"!A9&1R97-S97,@
M;75S="!M871C:"XB"FUS9W-T<B`B\,'2S\S8(,W5T\G4V"#3T*;7T,'3U,DN
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX.0IM<V=I9"`B16UA
M:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL
M+71O+5--4R!'871E=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR.3@*;7-G:60@(D5M;W1I8V]N<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#(*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(&UE<W-A9V4N
M(@IM<V=S='(@(O#/TL_6SJ;*(-+%VM7,V-3!U"XB"@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T
M>2!R97-U;'0N(@IM<V=S='(@(O#/TL_6SJ;*(-+%VM7,V-3!U"XB"@HC.B!F
M<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T
M>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4T,PIM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@
M9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q.`IM<V=I9"`B16YA8FQE(')I9VAT
M(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C4Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#$Q"FUS9VED(")%;F0@>65A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E
M($5D:71O<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C(Q"FUS9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H
M('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@
M(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P
M970_)SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@
M:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,0IM<V=I9"`B16YT97(@=&AE(&QE
M='1E<G,@8F5L;W<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q
M=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@
M(D5R:71R96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#4@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C4U"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S8@<V5R=FEC
M97,O<&]R=&%L+VEN9&5X+G!H<#HX,@IM<V=I9"`B17)R;W(B"FUS9W-T<B`B
M\,_-R<S+P2(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z
M-#8S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K
M.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC
M(&%N8VAO<CH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I
M;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP
M;&%T92]496UP;&%T92YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(D5R
M<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*
M;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM
M<V=I9"`B17-T;VYI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%
M=&AI;W!I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"FUS9VED(")%=F5R>2`Q-2!M
M:6YU=&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.#D*(RP@9G5Z>GD*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R("+K
MS];.S\?/(-?(S\35(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`S,"!S96-O
M;F1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,`HC+"!F=7IZ>0IM<V=I9"`B179E
M<GD@-2!M:6YU=&5S(@IM<V=S='(@(NO/UL[/Q\\@U\C/Q-4B"@HC.B!F<F%M
M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%
M=F5R>2!,;V=I;B(*;7-G<W1R("+KS];.S\?/(-?(S\35(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T,`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S<@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,X.`HC+"!F=7IZ>0IM<V=I9"`B179E<GD@;6EN
M=71E(@IM<V=S='(@(NO/UL[/Q\\@U\C/Q-4B"@HC.B!T96UP;&%T97,O9&%T
M82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S
M='(@(N3!SJ8@Q,S1(-#2R<O,P<35.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H
M<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP
M.C$R-PIM<V=I9"`B17AE8W5T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT-S4*;7-G:60@(D5X<&%N9"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS
M9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP
M.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R
M8V@@=&5R;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-@IM<V=I
M9"`B17AP;VYE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I
M9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR,38*;7-G:60@(D9A:6QE9"!R971R
M:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S
M97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB
M+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E
M<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV
M.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-CDQ"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C
M;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C0Y-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8Q"B,L
M('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I
M9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S.`HC+"!F=7IZ>0IM<V=I9"`B1F%T
M86P@17)R;W(Z(@IM<V=S='(@(O#/S<G,R\$@MLW0S]+4U3H@(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B
M1F%X(@IM<V=S='(@(N;!R],B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S0Y"B,L(&9U>GIY"FUS9VED(")&87AE<R(*;7-G<W1R("+FP<O3(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G
M:60@(D9E8G)U87)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C(P"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@(D9E96QS(&QI:V4Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@
M(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DT-`IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S0*;7-G:60@(D9I
M9VQE="!#05!40TA!(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,S,S@*;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")&:6QE(@IM
M<V=S='(@(O3)U-7,(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`W"FUS9VED(")&:6QE
M($UA;F%G97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<P"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#4*(RP@9G5Z>GD*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R("*VS6#1
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDY-0IM<V=I9"`B1FEL
M92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30X-@IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4Y"FUS9VED(")&:6QE
M('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C@Y"FUS9VED(")&:6QT97)S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO
M;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-38*;7-G
M:60@(D9I>"!R871I;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Q"FUS9VED(")&;&EP(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,S0@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I
M9"`B1F]N="!#;VQO<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"FUS
M9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S-`IM<V=I9"`B
M1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C<Y"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E
M('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@
M86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L
M="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R
M9#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V
M,@IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`HC+"!F=7IZ>0IM
M<V=I9"`B1F]R='5N97,B"FUS9W-T<B`B[L_4P=3+R2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4S"FUS9VED(")&;W)U
M;7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P
M.0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS,PHC+"!F=7IZ>0IM<V=I9"`B1G)A;65S(@IM<V=S='(@(K;-
M8-$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L
M($UE=')O<&]L:71A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&
M<F5N8V@@1W5I86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")&
M<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I
M9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G
M:60@(D9R;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(T."!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8P"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#8*;7-G:60@(D9R;VT@
M=&AE("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHT.`HC+"!F=7IZ>0IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G
M<W1R("+PS]?.R<H@S]#)TSHB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"B,L(&9U>GIY"FUS9VED(")&=6QL
M($YA;64B"FUS9W-T<B`B]\';Q2"FS2?1.B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@
M(D=A8F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T
M;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED
M(")'86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB
M:6$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N
M:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*
M;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B
M1VAA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3<U"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3$R.`IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C,W"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,3<Y"B,L(&9U>GIY"FUS9VED(")'<F]U<"!!9&UI
M;FES=')A=&EO;B(*;7-G<W1R("+AQ,VFSJ;3U-+5U\'.SM$B"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N
M+65M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HS,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@
M56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L
M('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE
M=&4@9W)O=7`@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C,S."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,S<Y"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L
M92!T;R!U<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R
M;W5P<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS
M97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E
M<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0W,`HC+"!F=7IZ>0IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S
M='(@(N'$TL73SL$@R\[)Q\$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'=6EN96$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=6EN96$M0FES<V%U
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV,`IM<V=I9"`B
M2%1-3"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O
M(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10
M($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@P"FUS9VED(")(86ET:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.CDQ.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.3,R"FUS9VED(")(96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A
M;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3
M=&]R;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM
M<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*
M;7-G:60@(DAE:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O2&5L<"YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92](96QP
M+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA
M=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G:60@(DAE;'`B"FUS9W-T<B`BY,_0
MS\W/Q\$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q"B,L(&9U>GIY"FUS9VED
M(")(96QP97(B"FUS9W-T<B`BY,_0S\W/Q\$B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T
M:&4@9FEL93HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DAI9V@B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C
M;VUM;VXM:&5A9&5R+FEN8SHU"B,L(&9U>GIY"FUS9VED(")(;U]M92(*;7-G
M<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6
M871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,34S-0HC+"!F=7IZ>0IM<V=I9"`B2&]M92(*;7-G
M<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(N3/S<';
MSM$@P<32Q=/!(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"FUS9VED
M(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE
M(@IM<V=S='(@(N3/S<';SJ;*(-3%S,7&S\XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G
M:60@(DAO;F1U<F%S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B
M2&]N9R!+;VYG(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HV-0IM<V=I9"`B2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E
M9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0S-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y
M<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-3`*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E
M<R!<(B5S7"(B"FUS9W-T<B`B]=/0IMO.SR#7R<3!S,7.SR`G)7,G(-H@T\G3
MU,7-R2XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I
M9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER
M97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T
M<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,C0W"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-S0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V
M92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$Y,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E
M("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,S,V"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S
M7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED
M(")(;W)I>F]N=&%L.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D
M:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@
M=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R
M92!T:&5R93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO;65T87(N
M<&AP.C(S,`IM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.0IM<V=I9"`B2'5M:61I='DZ("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@
M(DAU;6]R:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU
M;F=A<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U
M<RYP:'`Z,3<R(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)U<RYP:'`Z,C$T(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR
M.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N
M(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)U<RYP:'`Z,3<Y(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H
M<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A
M(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3,Q-@HC+"!F=7IZ>0IM<V=I9"`B25`@061D<F5S
M<R(*;7-G<W1R("+AQ-+%T\$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP
M8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP
M:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)
M1%(@8FQO8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@
M=FEO;&%T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@
M4F]W($)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC
M96QA;F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W
M-@IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?
M8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R
M("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S<*
M;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3DP"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C4Y,@HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA
M>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-34*;7-G
M:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R
M;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B
M;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,PIM
M<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E
M+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I
M<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I
M9"`B26UA9V4@55),(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA
M9V4@55),.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R
M;VT@9V%L;&5R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E
M(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3<V,0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP
M;&%T97,O9&%T82]D871E;6%P+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z-30@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S
M='(@(K;-T,_2U,_7P<[%(-#/S,4Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@
M9FEE;&0Z("5S(@IM<V=S='(@(K;-T,_2U,_7P<[%(-#/S,4Z("5S(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@
M9FEE;&1S.B(*;7-G<W1R("*VS=#/TM3/U\'.IB#0S\S1.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM
M<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED("));F-O
M<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"B,L(&9U
M>GIY"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D
M+B(*;7-G<W1R("+BU<38+<S!T\O!+"#7R\'6IM38(,[!VM?5(,O/TLG3U-77
MP=[!(*8@T,'2S\S8(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@
M861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES
M=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM
M<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF
M;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4W
M"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S,P"FUS9VED("));F9O<FUA=&EO;B!N;R!L
M;VYG97(@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN
M<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I
M9"`B26YS97)T($EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R
M('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN
M<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@
M=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS
M97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H
M92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E
M<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T
M<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R
M="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(S.0IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E
M<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDP"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U
M"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV.0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,P"FUS9VED("));G-E<G0@=&AE(')E
M<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM
M<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED
M("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U
M=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT
M(&-R961I="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3`W-0IM<V=I9"`B26YT96=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3,S"FUS9VED("));G1E9V5R(&QI<W0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(
M96%D97(I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O>FEP+G!H<#HQ-S`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+WII<"YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]Z:7`N<&AP.C(Q,`IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A
M;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L
M:60@8F%T8V@@240N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R.3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE
M<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E
M<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]D8G@N<&AP.C@Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D
M8G@N<&AP.C$P,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X
M+G!H<#HR,C`*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-PIM<V=I9"`B
M26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$W,0IM<V=I9"`B26YV86QI9"!L;V-A=&EO
M;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US
M9U]T>7!E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES
M<VEN9R!A<&E?:60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O
M<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E
M<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R
M;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$W,PIM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED
M("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED
M("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("))
M;G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`W-B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$R-C(*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U-PIM<V=I
M9"`B26YV96YT;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HV-SD*;7-G:60@(DEN=F5R="!S96QE8W1I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA
M;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I
M9"`B27)A<2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA
M;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E
M9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES
M<F%E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8R-0IM<V=I9"`B27-S=65R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A
M;&EC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@HC+"!F=7IZ>0IM<V=I9"`B
M271A;'DB"FUS9W-T<B`B_<_$Q<[.SR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B
M2F%M86EC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M
M2E`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,S$P"FUS9VED("(B"B)*879A<V-R:7!T(&AA<R!B965N(&1I<V%B;&5D(&]N
M('EO=7(@8G)O=W-E<B!A;F0@=&AI<R!P86=E(&UA>2!N;W0@8F4@(@HB9&ES
M<&QA>6EN9R!C;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU
M;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I
M9"`B2G5S=&EF>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#
M96YT97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8T"FUS9VED
M(")+965P(&]R:6=I;F%L/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(DME;GEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME
M>2!#<F5A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G
M:60@(DME>2!,96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`HC+"!F
M=7IZ>0IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(NS)T]0B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E
M861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!0
M96]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*
M;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO
M=70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX
M,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS
M9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA
M;&8B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"FUS
M9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED
M("),87-T(%%U87)T97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-3$*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G
M:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.C<R,0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO
M9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.C<Q-@IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),87<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<Y"B,L(&9U>GIY"FUS9VED("),87EO=70B"FUS9W-T<B`B]\G*
MU,DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$Q.0IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-0HC+"!F=7IZ>0IM<V=I
M9"`B3&5F="!V86QU97,B"FUS9W-T<B`BY,'.IB#$S-$@T-+)R\S!Q-4Z(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B3&5V96PB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E
M:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*(RP@
M9G5Z>GD*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B]]>FRM3)(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@
M(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@
M3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR.0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS
M9VED("),:6=H="!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H
M;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*
M;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X,30*(RP@9G5Z>GD*;7-G:60@(DQI;FLB"FUS9W-T<B`B
M]]>FRM3)(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B
M3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H
M96X@9&ES<&QA>6EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED("),:6YK<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@
M(DQI;G5X($-O;VMI92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N
M('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,S,*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4P"FUS9VED("),:7-T($AE;'`@
M5&]P:6-S(@IM<V=S='(@(O#%TL7,ILL@TL_:Q*;,IM<@Y,_0S\W/Q\DB"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,R"FUS9VED("),:7-T(%1A8FQE<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP
M.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3@Y"B,L(&9U>GIY"FUS9VED
M("),:7-T+4AE;'`B"FUS9W-T<B`B\,72Q<RFRR#2S]K$ILRFUR#DS]#/S<_'
MR2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS
M9VED("),:7-T+4ED(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS
M9VED("),:7-T+5!O<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(O#%TL7'
MS-'$(-/0R=/+U2#+S]+)T]35U\'>IM<@VL'"S]+/SL7.R<HN(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M("),:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B\,72Q<?,T<0@
MT]#)T\O5(,O/TLG3U-77P=ZFUR#:P<+/TL_.Q<[)RBXB"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E
M<G,@:7,@9&ES86)L960N(@IM<V=S='(@(O#%TL7'S-'$(-/0R=/+U2#+S]+)
MT]35U\'>IM<@VL'"S]+/SL7.R<HN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX.0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.#,*;7-G:60@(DQO861I
M;F<N+BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(Q,0IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX,PIM<V=I9"`B3&]C86QE(&%N9"!4:6UE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3<Q(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-`HC.B!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV-0IM
M<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B(@H*(SH@;&]G:6XN<&AP.C$W,B!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3DQ('1E;7!L871E<R]L;V=I
M;B]M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z
M,34@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN
M(@IM<V=S='(@(O?7ILK4R2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3@U
M"FUS9VED("),;V<@;W5T(@IM<V=S='(@(O?)RM3)(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C4Y"B,L(&9U>GIY"FUS9VED("),;V=I;B(*;7-G<W1R
M("+WUZ;*U,DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"FUS9VED
M("),;V=I;B!487-K<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.38*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@
M=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,@IM
M<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S8U"B,L(&9U>GIY"FUS9VED("),;VYG('1E>'0B
M"FUS9W-T<B`B]\G*U,DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*
M;7-G:60@(DQO=F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(DQO=R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,X
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R("+M
M[2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#$*;7-G:60@(DU/
M5$0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN
M960@;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I
M9"`B35-'(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H
M92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT.0HC+"!F=7IZ>0IM<V=I9"`B36%G:6,B
M"FUS9W-T<B`B24U0+=#/TM3!S"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HX,0IM<V=I9"`B36%I;"(*;7-G<W1R("))35`MT,_2U,',(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R,@IM<V=I9"`B36%I;"!!9&UI
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-86QA=VDB
M"FUS9W-T<B`B24U0+=#/TM3!S"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36%L
M87ES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(DUA
M;&DB"FUS9W-T<B`B24U0+=#/TM3!S"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ
M>0IM<V=I9"`B36%L=&$B"FUS9W-T<B`B24U0+=#/TM3!S"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T
M(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@
M86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$Q-3,*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-`HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$V.`IM
M<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0HC+"!F=7IZ
M>0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(O77P<?!(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET
M:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H
M(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I
M9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(O>FQ-#/UZ;$SJ8@T,_,T2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*
M;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS
M9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA
M<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(Y.`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R
M(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU
M;2!L96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I
M9"`B365M8F5R<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S<X"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G
M:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S
M86=E(@IM<V=S='(@(NS)T]0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C
M97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N
M;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`HC+"!F=7IZ>0IM
M<V=I9"`B365S<V%G92!E>'!I<F5D+B(*;7-G<W1R("+LR=/4(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(V,`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@
M(NS)T]0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R
M(%=E871H97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-PIM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3(*;7-G:60@(B(*(DUE=&%R
M(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DUE=&%R1$(@:7,@
M;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#
M+U)00R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D
M(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-
M971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW-"!L:6(O0FQO
M8VLO;65T87(N<&AP.C<U"FUS9VED(")-971R:6,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU"FUS9VED(")-97AI8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<V"B,L(&9U>GIY"FUS9VED(")-:61D;&4B"FUS9W-T<B`B
M24U0+=#/TM3!S"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N
M968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,3`*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@
M:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P
M,@IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI
M;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(S-`HC+"!F=7IZ>0IM<V=I9"`B36ER<F]R(@IM<V=S='(@(O#/S<G,R\$B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA
M;F5O=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C
M:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO
M;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O
M('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G
M:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G
M:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C4V"FUS9VED(")-;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-S0*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED
M(")-;V1E<F%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HX.`IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S,*;7-G:60@(DUO9'5L=7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI
M8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.30*;7-G:60@
M(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN
M=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS
M9W-T<B`B_<_-IM/1P]$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R
M870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L
M;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-S(@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,C4S"B,L('!H<"UF;W)M870*;7-G:60@(DUO
M<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@
M)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-
M;W-T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M-3`Y"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$S"FUS9VED(")-;W9E($QE9G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z-3$W"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P-0IM<V=I9"`B36]V92!5
M<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PHC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED
M(")-;W9E('5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z
M86UB:7%U92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,3@T"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P-34*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0R"FUS9VED(")-=6QT:7!L
M92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0P,`IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*;7-G:60@(DUY($%C8V]U;G0@26YF
M;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X
M+G!H<#HU-`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]E9&ET+G!H<#HQ,S8*;7-G:60@(DUY(%!O<G1A;"!,87EO
M=70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC
M92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B
M"FUS9W-T<B`BMLU@T2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDW"FUS9VED(").971H97)L86YD<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G
M:60@(DYE='-C87!E($)A<V4@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!#
M02!2979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L
M:6-Y(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.#(*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED
M(").971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C
M87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#`*;7-G:60@(DYE='-C87!E
M(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(U,0IM<V=I9"`B3F5T=V]R:R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,S-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V
M"FUS9VED(").979E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@
M(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E
M9V]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL
M=&5R+V5M86EL<RYP:'`Z.#$*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O96UA:6QS+G!H<#HY-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G:60@(DYE
M=R!-97-S86=E('1O("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N
M86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED
M(").97<@6F5A;&%N9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9"(*
M;7-G<W1R("+PP=+/S-@B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP
M:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL
M(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C4R"B,L(&9U>GIY"FUS9VED(").97<@<&%S<W=O<F1S
M(&1O;B=T(&UA=&-H+B(*;7-G<W1R("+PP=+/S-@@S=73R=38(-/0IM?0P=/4
MR2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y"B,L(&9U>GIY
M"FUS9VED(").97=S(@IM<V=S='(@(N[/U,'4R\DB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S`U"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z,3(Y('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED
M(").97AT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM
M<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C,W,B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C,W-@HC+"!F=7IZ>0IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S
M='(@(O#/U\72SM74R=/1(,3/(._0PZ;*(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U!A9V5R+G!H<#HQ,#,*;7-G:60@(DYE>'0^(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS
M9VED(").:6=E<FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS.#`*;7-G:60@(DYI9VAT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-PIM<V=I9"`B3FEU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(").;R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*
M;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO
M=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`U"FUS9VED(").;R!A=F%I
M;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW.2!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-#4*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C8W"FUS9VED(").;R!B;&]C:R!E
M>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C
M86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`HC+"!F
M=7IZ>0IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R("+SR\'3U=?!U,D@VLVF
MSLDB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I
M9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO
M;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M-C<@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#(*(SH@9G)A;65W;W)K
M+U5T:6PO571I;"YP:'`Z-S<S"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C0*;7-G
M:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!&5%`@5D93+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C8V.0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,3<*;7-G:60@(DYO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!6
M1E,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z
M.#<W"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(B(*"B,Z('5T
M:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M,C@@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3(S"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-CD*;7-G:60@
M(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B
M3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO
M(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M
M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.CDT"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I
M9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP
M:'`Z,3`X"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&]G:6XN<&AP.C@T"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M
M+G!H<#HW-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X
M-@IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O
M=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB
M=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN
M9R!S:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z-S4P"B,L('!H<"UF;W)M870*;7-G:60@(DYO('%U;W1A('-E="XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT,PHC+"!F=7IZ>0IM<V=I9"`B3F\@<G5L97,B"FUS9W-T
M<B`B[L_4P=3+R2(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T
M.0IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT-`HC+"!F=7IZ>0IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B[L_4P=3+
MR2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@S"FUS9VED(").
M;R!S=6-H(&9I;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$S.`IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A
M=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,0HC+"!F=7IZ>0IM<V=I
M9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@
M(N+5Q-@MS,'3R\$L(-?+P=:FU-@@SL':U]4@R\_2R=/4U=?!WL$@IB#0P=+/
MS-@B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I
M9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW,0HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY.3(*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#D*;7-G:60@
M(DYO('9A;'5E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O
M;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@
M=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A
M=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S
M+VED96YT:71Y<V5L96-T+FEN8SHY,PHC+"!F=7IZ>0IM<V=I9"`B3F]N92(*
M;7-G<W1R("+TQ<S%QL_.(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B
M3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV
M"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").
M;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM
M<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED(").;W0@069T
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV,SD*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#`X"FUS9VED(").;W0@82!D:7)E
M8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX,PHC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+G!H<#HY-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G
M:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`HC+"!F=7IZ>0IM<V=I
M9"`B3F]T('-E="(*;7-G<W1R("+NS]3!U,O)(@H*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#,*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ
M-S,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R
M+G!H<#HQ.#<*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(
M86YD;&5R+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y,`HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`U(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(T."!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C8U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.#$@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C(Y-PHC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,S$R(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,CD*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C,V,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(R
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU,#$@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C4W,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3@W(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HV-C4*;7-G:60@(DYO="!S=7!P;W)T960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$W.`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B
M[L_4P=3+R2(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM
M<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS
M9VED(").;W9E;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,#0V"B,L(&9U>GIY"FUS9VED(").=6UB97(B"FUS9W-T<B`B
MMLU@T2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C4*;7-G:60@
M(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30R,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0U('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB
M97(@;V8@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,S8W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C$*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,R!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O
M=W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE
M9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV
M-`IM<V=I9"`B3TLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/
M8FIE8W0@0W)E871O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T
M;V)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*
M;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS,C8*;7-G:60@(D]F9FEC92(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L
M9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"B,L(&9U
M>GIY"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B\,'2S\S8(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@<&%S
M<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M.`IM<V=I9"`B3VUA;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E
M<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV92!F
M;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#4Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S$*;7-G:60@(D]N
M;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H
M92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W
M;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS-0IM<V=I9"`B
M3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R
M;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%
M('!A<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L
M:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U,0HC+"!F
M=7IZ>0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R("+ZPL72Q<?4R2#/T,.FIR(*
M"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P
M+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*(RP@9G5Z>GD*
M;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R("+AQ,VFSJ;3U-+5U\'.SM$B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I
M9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3,R"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG
M:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG
M:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP
M.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,C(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,2!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,30Q"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/
M=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA
M:6P@8F%C:V5N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,C<S"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3,Q.0IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-S$*;7-G:60@(E!'
M4"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$S-3,*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D
M($1A=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"B,L
M(&9U>GIY"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")(;W)D92(*"B,Z(&%D
M;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W
M"FUS9VED(")032!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!3:&]W
M97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,Y"FUS9VED(")032!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")0
M32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-U;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M,@IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C(W-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI
M<W-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")0
M7TA0(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QA=2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C
M8W5P:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U
M:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")087)A9W5A
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS-@IM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS
M9VED(")087-S=V]R9"(*;7-G<W1R("+PP=+/S-@B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@
M<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C$S,C(*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D
M(&EN8V]R<F5C="(*;7-G<W1R("+PP=+/S-@B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W)A9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E
M9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#4S"FUS9VED(")087-S=V]R9"!W
M:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.3`*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D.B(*
M;7-G<W1R("+PP=+/S-@B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R("+PP=+/
MS-@B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C`S-`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C$U"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B\,'2
MS\S8(,W5T\G4V"#3T*;7T,'3U,DN(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$Q.2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E
M(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@
M(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")096]P;&4B"FUS9W-T<B`B
M\L_,V"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F
M;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B]\G+S\[!U,D@
MT-+/QJ;,P<O4R=[.IB#/T,72P<.FIR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT,#8*(RP@9G5Z>GD*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B]\G+S\[!U,D@T-+/QJ;,
MP<O4R=[.IB#/T,72P<.FIR(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,34V"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@V"FUS9VED(")097)M:7-S
M:6]N($1E;FEE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V
M-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R
M;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC
M.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R
M871I;VXB"FUS9W-T<B`BX<3-ILZFT]32U=?!SL[1(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8U"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y-@IM<V=I9"`B4&AO;F4B"FUS9W-T<B`B],7,Q<;/SB(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S@*;7-G:60@(E!H;W1O<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W
M86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI
M;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-3<Q"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A
M;F0@82!Y96%R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P,0IM<V=I9"`B4&QE87-E(&5N=&5R
M(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C8V,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L
M:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT
M:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U
M,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B
M4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G
M<W1R("+BU<38+<S!T\O!+"#$P<K4Q2#+S]+/U,O)RB#/T,G3(-#2S\+,Q<W)
M+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U
M<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`BXM7$V"W,P=/+P2P@
MU\O!UJ;4V"#.P=K7U2#+S]+)T]35U\'>P2"F(-#!TL_,V"(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B(@HB4&QE87-E(')E860@
M=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T
M97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G
M:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0;VQA;F0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@W"FUS
M9VED(")0;VQL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0
M;W)T=6=A;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N
M:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N
M:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI
M<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L
M87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,CDX"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^
M8VAA;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L
M9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I
M;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C4*;7-G:60@(E!R
M97-S=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Y
M"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")0<F5S
M<W5R93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@
M:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,S8R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,S8V"B,L(&9U>GIY"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S
M='(@(O#/U\72SM74R=/1(,3/(._0PZ;*(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE
M;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#(S"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y"B,L(&9U>GIY"FUS9VED
M(")0<F]B;&5M(@IM<V=S='(@(EOPS]>FQ,_-S,7.SM$@\-+/PLS%S<E=(@H*
M(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(V"FUS9VED(")0<F]B;&5M($1E
M<V-R:7!T:6]N(@IM<V=S='(@(N_0R=,@T-+/PLS%S<DB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S8Y"FUS9VED(")0<F]J96-T<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q.#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S(X-0IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@
M2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-`IM
M<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A
M=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C8S"FUS9VED(")1=65R>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C8S"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E
M9"!B:70I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R-C0*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B
M4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I
M9"`B4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")286EN(%-H;W=E<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-PIM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I
M;B!T;R!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(T('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P
M"FUS9VED(")296%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C@W"B,L(&9U>GIY"FUS9VED(")296%D(&UE
M<W-A9V5S(@IM<V=S='(@(NS)T]0B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E
M;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@
M9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(E)E9G)E<V@@
M1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S0Q"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.30@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C,U"B,L(&9U>GIY"FUS9VED(")296=E>"(*;7-G<W1R
M("+OWLG3U,G4R2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-#D*
M;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR,#@*;7-G:60@(E)E;&]A9"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,R-@IM<V=I9"`B4F5M87)K<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$T"FUS9VED(")296UO
M=&4@4V5R=F5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA
M;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U
M975E9"YI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92(*;7-G<W1R("+W
MR=3%TM3)(-#!TM4B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M,3$*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R("+WR=3%
MTM3)(-#!TM4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-34W"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*(RP@
M9G5Z>GD*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(O?)U,72
MU,D@T,'2U2(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS
M9VED(")296UO=F4@<&%I<B(*;7-G<W1R("+WR=3%TM3)(-#!TM4B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")296UO=F4@<V%V960@
M<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0R"B,L(&9U>GIY"FUS9VED(")296UO=F4@=&AE(@IM
M<V=S='(@(O?)U,72U,D@T,'2U2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H
M:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q"B,L(&9U>GIY"FUS9VED
M(")296UO=F4@=7-E<B(*;7-G<W1R("+WR=3%TM3)(-#!TM4B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R("+WR=3%TM3)
M(-#!TM4B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.`IM
M<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@
M97)R;W)C;V1E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$U-PIM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@
M;F]T(&)E(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C$W-"!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I
M9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W-2!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C@S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M-S(S"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@
M<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW.#$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]2
M96YD97)E<BYP:'`Z,S,U"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z
M,S(P('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS
M9W-T<B`B[][)T]3)U,DB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HT-@HC+"!F=7IZ>0IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B
M\,'2S\S8(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*(RP@
M9G5Z>GD*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B\*;$
MU-?%TL36Q<[.T2#0P=+/S,`B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,P
M"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI
M;B]S<6QS:&5L;"YP:'`Z-C8*(RP@9G5Z>GD*;7-G:60@(E)E<W5L=',B"FUS
M9W-T<B`B[][)T]3)U,DB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R
M;B!T;R!/<'1I;VYS(@IM<V=S='(@(O#/U\72SM74R=/1(,3/(._0PZ;*(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y
M<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G
M:60@(E)E=6YI;VXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E
M<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,R"B,L(&9U>GIY"FUS9VED(")2:6-H(%1E>'0@161I=&]R
M($]P=&EO;G,B"FUS9W-T<B`B\,_7Q=+.U=3)T]$@Q,\@[]##ILHB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3(Q"FUS9VED(")2:6=H="!H96%D97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-PIM<V=I
M9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?
M=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T
M<B`B\L_,V"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(R-0IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(R"FUS9VED(")2;W1A
M=&4@3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C(X"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@
M(E)O=W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*(RP@9G5Z>GD*;7-G:60@(E)U;&5S
M(@IM<V=S='(@(O+/S-@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O
M;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,C`*;7-G:60@(E)U;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@
M0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%
M;F-R>7!T960@365S<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W-A<VPN<&AP.C@Q"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N
M(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HU,#0*(RP@9G5Z>GD*;7-G:60@(E--4R!-97-S86=I
M;F<B"FUS9W-T<B`B[,G3U"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM
M<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,R.#,*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E
M(&QO;VMU<',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0S,0IM<V=I9"`B4U-((@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z
M,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z
M,34S"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N
M9"!.979I<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT
M($QU8VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT
M(%!I97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@
M(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S
M"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]L87EO=70N:6YC.CDX"FUS9VED(")3879E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B^L+%TL7'U,D@S]##IJ<B"@HC
M.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO
M;G,B"FUS9W-T<B`B^L+%TL7'U,D@S]##IJ<B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U
M<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O
M<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.CDS"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P
M('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")3
M8V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R,`IM<V=I9"`B4V5A<F-H
M($5N9VEN97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,CDW,PIM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0*(RP@9G5Z
M>GD*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B]\G"Q=*FU-@@QL_2
MS<'4(,3!U,DZ(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*
M;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED(")396QE8W0@82!N
M97<@;W=N97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C
M="!A('5S97(@=&\@861D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HV-S<*;7-G:60@(E-E;&5C="!A;&PB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,PHC
M+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM
M<V=S='(@(O?)PL72IM38(,;/TLW!U"#$P=3).B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E;&5C="!A
M;B!O8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C8W.`IM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"B,L(&9U>GIY"FUS
M9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T
M:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T
M92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@HB]\G"Q=*F
MU-@@SL7/PLBFQ,ZF(/?!S2#3R<W7S\S)(-H@T,_,IM<@SLG6WL4N(/?)(-K-
MS];%U,4@T\O/T*;`U\'4R2"GR""F("(*(M?3U,'7R=3)(-H@T,_,T2#7U\_$
MU2#4Q<O3U-4N(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G
M:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(O?)PL72
MIM38(-+/VL2FS,#7P=X@Q,'4R3HB"@HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T
M<B`B]\G"Q=*FU-@@QL_2S<'4(,3!U,DZ(@H*(SH@=&5M<&QA=&5S+W!R969S
M+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I9&5N
M=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]D871A+W1I;64N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")396QE8W0@
M=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R("+WR<+%TJ;4V"#2S]K$ILS`
MU\'>(,3!U,DZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G
M:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(O?)PL72IM38
M(,;/TLW!U"#>P=/5.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M-3<*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S
M+B(*;7-G<W1R("+WIL30S]>FQ,ZF(-#/S-$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S`V"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#@*;7-G
M:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@
M(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B]Z;$IM/,P=3)(-#/UZ;$
MS\W,Q<[.T2#0TL\@T-+/PLS%S=4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3`S.0IM<V=I9"`B4V5N9"!335,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-@IM<V=I9"`B4V5N<V]R.B`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA
M(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED(")397)I86P@3G5M8F5R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*
M;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR-PIM<V=I9"`B4V5S
M<VEO;B!!9&UI;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@
M97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30U"B,L(&9U
M>GIY"FUS9VED(")397-S:6]N<R(*;7-G<W1R("+ZPL72Q<?4R2#/T,.FIR(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,30*;7-G:60@(E-E="(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@
M(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W
M;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S
M97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T
M86PN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`IM
M<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A
M;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3@*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC
M871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H
M97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C<U"FUS9VED(")3971U<"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B
M4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@V"FUS9VED(")3979E
M<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.38*;7-G
M:60@(E-H;W!P:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C0S"B,L(&9U>GIY"FUS9VED(")3:&]R="!3=6UM87)Y
M(@IM<V=S='(@(NO/TL_4R\G*(-K-IM/4(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0T-@IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN
M960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H
M;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H
M92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y,`IM<V=I9"`B4VAO=R!L
M87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P
M=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X,3,*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C8*;7-G:60@(E-H
M;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L
M92!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@
M(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@
M9&EA;&]G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$W-C,*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"FUS9VED(")3:&]W
M97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4Q"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS
M9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@:6X@
M=&AE(%9I8VEN:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C0X,`IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<W-"!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HX,S8*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3(R(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.CDX-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HQ,#0W(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C$P.#<*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M,3$Q-B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,30Y"FUS
M9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T
M(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM
M<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HR-C4*;7-G:60@(E-I9VX@=7`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*
M;7-G:60@(E-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,0IM<V=I9"`B4VEG;F%T=7)E($%L9V]R
M:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#<@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0V(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Y,S`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R
M,PIM<V=I9"`B4VEZ92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N
M86YC92(*;7-G<W1R("+PTL_0U=/4R=3)(-#2S\:FS,'+U,G+U2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3;F]W(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4U"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO
M=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3@*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X"FUS9VED(")3;F]W(&1E<'1H
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G
M:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(V
M"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X
M.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,3@Y"B,L(&9U>GIY"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R("+R
MS\+/WL$@P<32Q=/!(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R
M:6-A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS
M9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U
M=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T
M:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W
M965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B
M971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q-0IM<V=I9"`B4W!A8V5R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@(E-P86TB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H
M87)A8W1E<B!);G!U="(*;7-G<W1R("+WUZ;$(//0Q<.FP<S8SLG((-/)S=?/
MS*;7(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V
M"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B
M4W!L:70@<F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV,0HC+"!F=7IZ>0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(K;-T,_2U"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,R!L:6(O0FQO8VLO;65T
M87(N<&AP.C<T"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DV(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X,#D*;7-G:60@(E-T87)T('EE87(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*
M;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-0IM
M<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(*(RP@9G5Z>GD*;7-G:60@(E-T
M<F5E="!!9&1R97-S(@IM<V=S='(@(O+/PL_>P2#!Q-+%T\$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q"FUS9VED(")3
M=')I:V5T:')O=6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,S,*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S,*;7-G:60@(E-T<FEP(&1O
M;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@
M(E-T>6QE(%M#4U-=(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(B(*
M"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW
M,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,S(@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP
M:'`Z,S$W"FUS9VED(")3=6)M:70B"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H
M<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S
M="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO
M9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3`T"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@
M(E-U8V-E<W,B"FUS9W-T<B`B]=/0IMO.SR(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M861D960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@(O73T*;;SL\@
MQ,_$P<[/("<E<R<@Q,\@T\G3U,7-R2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C
M;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB
M"FUS9W-T<B`B]=/0IMO.SR#7R<3!S,7.SR`G)7,G(-H@T\G3U,7-R2XB"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z
M-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D
M96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B]=/0IMO.SR#$S\3!SL\@)R5S)R#$
MSR#3R=/4Q<W)+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB
M(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B]=/0IMO.SR#7R<3!S,7.SR`G
M)7,G(-H@T\G3U,7-R2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q
M"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@
M4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*
M;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S='(@(O73T*;;SL\@
MQ,_$P<[/("<E<R<@Q,\@T\G3U,7-R2XB"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S
M='(@(O73T*;;SL\@Q,_$P<[/("<E<R<@Q,\@T\G3U,7-R2XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"B,L(&9U>GIY
M"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(NO/TL_4R\G*(-K-IM/4(@H*(SH@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U
M;B!3970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-U;FYY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(E-U;G)I<V4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$U"FUS
M9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(Q.0IM<V=I9"`B4W5N<V5T(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3@*;7-G:60@(E-U;G-E
M=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S@*(RP@9G5Z>GD*;7-G
M:60@(E-U<'!O<G0B"FUS9W-T<B`BMLW0S]+4(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@HC
M+"!F=7IZ>0IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B[L':U\$@R\_2R=/4
MU=?!WL$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M-`HC+"!F=7IZ>0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R("+NP=K7P2#+S]+)
MT]35U\'>P2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*
M86X@36%Y96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A
M>FEL86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*
M;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$T,@IM<V=I9"`B4WEN8TU,(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B
M4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,`IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R;2!A;F0@
M5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED
M(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+W1S=BYP:'`Z,38V"B,L(&9U>GIY"FUS9VED(")44U8@9FEL92(*
M;7-G<W1R("+TR=35S"(*"B,Z(&9R86UE=V]R:R]522]522]486)L92YP:'`Z
M,3,T"B,L(&9U>GIY"FUS9VED(")486)L92(*;7-G<W1R("+TR=35S"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B
M5&%B;&4@4V5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E
M<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S0@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B
M5&%I=V%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N
M:71E9"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")487)G970Z(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.38@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$X-PIM<V=I9"`B5&%S:W,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G
M:60@(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR.3`*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$T"FUS9VED(")4
M96UP97)A='5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C(S"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@
M)F1E9SLE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M
M<&QA=&4N<&AP.C8X-PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<
M(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R
M871I;VXB"FUS9W-T<B`BX<3-ILZFT]32U=?!SL[1(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,S,V"FUS9VED(")497AT(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-S4*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T
M"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3$*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B5&AA;FL@
M>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R,`IM<V=I9"`B5&AE($944"!E>'1E
M;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S
M=7!P;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-
M4U`O24U34"]";V]K+G!H<#HQ,CDR"FUS9VED(")4:&4@24U34"!L;V<@8V]U
M;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ
M(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B
M5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,C8T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4
M:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE
M;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@
M4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T
M;VT@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N
M=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@
M;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU
M,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T
M;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V.0IM<V=I9"`B(@HB5&AE(&1E=&%C
M:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y
M('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*
M(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C
M:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A
M8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@
M;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,3,*;7-G:60@(E1H92!E;F-R>7!T:6]N
M(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<U(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$S"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C@@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T
M:6YG<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C$Y"FUS9VED(")4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O
M(&ET<V5L9BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP
M:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@
M9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM
M<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U
M<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O
M(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O
M=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y
M+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W
M<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX
M(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@
M(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<
M;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF
M('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R
M+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D
M96QE=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD
M('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@
M1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ
M(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$
M3BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E
M('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E
M;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H
M92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM<V=I9"`B
M5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P
M86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C0T,0IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE
M<FEC+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C$R,S$*;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U
M:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDP"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L
M9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@
M(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI
M<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0U
M-`IM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG
M;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG
M:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED
M(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V"FUS9VED(")4:&4@<V5P87)A
M=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B
M965N('-A=F5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E
M<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S<&5C:69I
M960@<F]W(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S$Q"FUS9VED
M(")4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT
M(&]N('1H92!S8W)E96XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T
M;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G
M:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@
M=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W;W)K
M+T1A=&$O1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I
M;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C4V"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q.0IM<V=I9"`B5&AE('=E
M871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*
M"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X"FUS
M9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T,@IM
M<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE
M9"!I;FQI;F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O
M;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT
M97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H
M86X@)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E
M<BYP:'`Z-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*
M;7-G<W1R("+TTL'0R<S!T]$@T-+/PLS%S<$@T-+)(,3/Q,'7P<[.IB`G)7,G
M(,3/(-/)T]3%S<DN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R
M:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM
M<V=S='(@(O32P=#)S,'3T2#0TL_"S,7-P2#0TLD@U\G$P<S%SLZF("<E<R<@
MVB#3R=/4Q<W)+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN
M9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B]-+!T,G,P=/1
M(-#2S\+,Q<W!(-#2R2#7R<3!S,7.SJ8@)R5S)R#:(-/)T]3%S<DN(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,34Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS
M9W-T<B`B]-+!T,G,P=/1(-#2S\+,Q<W!(-#2R2#$S\3!U\'.SJ8@)R5S)R#$
MSR#3R=/4Q<W)+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.C@X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M
M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N
M('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL
M>2!U<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D
M871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP
M:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M(&E#86QE;F1A<B!D871A+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C@P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@
M=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@
M82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*
M(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@
M861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA
M=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@
M86=A:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W87,@
M86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A
M<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!
M4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@
M87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q-#4*;7-G:60@(E1H:7,@9&]E
M<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B
M"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N
M8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M
M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O
M;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S
M+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O
M;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$P-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S.3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U
M-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Y-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P
M-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$T.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(T,3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C0U-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4W(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S$S-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`V"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,X,30@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S@R,@IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-0IM<V=I9"`B
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$X"FUS9VED(")4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O
M;&]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,#DT"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@
M=F%L=65S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3(S"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S
M<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY.#D*;7-G:60@(E1H:7,@9FEE
M;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@S-@IM<V=I9"`B(@HB5&AI<R!F:65L
M9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O
M<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R
M;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I
M<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE
M8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E
M<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES
M="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C4Y,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R
M:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R
M(&]W;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@
M;VYE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M
M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI
M<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B
M5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES
M('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8T"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR,S0*;7-G:60@(E1I8VME=',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R."!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(E1I;64B
M"FUS9W-T<B`B],G4U<PB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S@V"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S.0IM<V=I9"`B5&EM
M92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B
M5&EM;W(M3&5S=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR
M,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B],G4U<PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H
M=&]O;'1I<"DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-30*;7-G
M:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H
M92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@
M8VQI8VMI;F<N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,3$*;7-G:60@(E1O9&%Y(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O
M9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS
M9VED(")4;V=O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O
M:V5L874B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,Q,PIM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W"FUS9VED(")4;W`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T
M:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A
M9"!A;F0@5&]B86=O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$W.3`*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM
M<V=I9"`B5'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N
M:7-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@
M(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C
M:&]I8V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C8Y"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O
M0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(E523"(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U
M<R!R97!O<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY-PHC+"!F=7IZ>0IM<V=I9"`B55),.B(*;7-G
M<W1R(")54DPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,3(*;7-G:60@(E5N
M86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B
M;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG
M('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C,X.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@U(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-34*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O
M9B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C8X."!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN
M<&AP.C0S-0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E
M<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX
M,SD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,C4@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y
M"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-C4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,S4T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(U-@IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-C4*;7-G:60@(E5N86)L92!T;R!C
M<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW.0IM<V=I9"`B56YA8FQE('1O
M(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HR,C0@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR
M.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S
M7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z
M-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S
M7"(Z("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HS,S$@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS.3(*(SH@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,S,T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS
M-#@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S<@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T
M-`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0Q-R!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0R.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(P-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,S`S(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C@X"B,Z(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HQ-C<@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C$X,`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.#,*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Y,0IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HR-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@P,PIM
M<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV,#,*;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E
M=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N
M<&AP.C0U,2!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]!=71H+G!H<#HQ,3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN
M:71I;VX@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#$*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$V-B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<Q"FUS9VED(")5;F%B;&4@=&\@
M;6]V92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HY,R!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P,@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C8T."!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.CDX"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<W(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C$S,PIM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R
M:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C@P(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S,`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(*;7-G:60@(E5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E
M;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HX,S4*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F
M:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HX-C8*;7-G:60@(E5N86)L92!T;R!R96%D(%9&
M4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE
M+G!H<#HS.`IM<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8V.0IM<V=I9"`B
M56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q,#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S
M=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.3,*;7-G:60@(E5N
M86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-C<@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Q,"!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(S(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HR,3,*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C0U,B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C@U
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU
M,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*
M;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,30Y
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34R"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W.0IM<V=I
M9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@Q
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T,PIM<V=I9"`B56YA8FQE('1O
M('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HX-#$*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@
M9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I
M9"`B56YD97)L:6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]E
M;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R("+SR\'3U=?!
MU,D@VLVFSLDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HR,C,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,SDP"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N
M(&-O;FYE8W1I;VXZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,W.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS.#0*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@
M9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE
M9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I
M9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS
M9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN
M9R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HV.2!L:6(O0FQO8VLO;65T87(N<&AP.C<Q"FUS9VED(")5;FET
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,CD@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"FUS9VED
M(")5;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM
M<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@
M(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.0IM<V=I
M9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ
M"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP
M:'`Z,CDV"B,L(&9U>GIY"FUS9VED(")5;FYA;65D(@IM<V=S='(@(N[!VM?!
M(,O/TLG3U-77P=[!(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@
M8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@
M9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T
M96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y
M;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O
M87)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X
M-B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,@IM<V=I9"`B56YS=7!P
M;W)T960@17AT96YS:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5<&1A=&4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHW-@HC+"!F=7IZ>0IM<V=I9"`B57!D871E('5S97(B
M"FUS9W-T<B`BY,_$P=3)(,O/TLG3U-77P=[!(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H
M87)E<R]E9&ET+G!H<#HR,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E
M9"!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3D*;7-G:60@(E5P;&]A9"(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED
M(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE
M('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T
M:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R
M;VUA;B!N=6UB97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@
M(E5R=6=U87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G
M:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U3
M4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(E5S97(B"FUS9W-T<B`B
M[L':U\$@R\_2R=/4U=?!WL$B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M4F5G:7-T<GDN<&AP.C<R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S
M(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,C`S"B,L(&9U>GIY"FUS9VED(")5<V5R($%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(N'$S:;.IM/4TM77P<[.T2#+S]+)T]35U\'>IM<@
M2&]R9&4B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,0HC
M+"!F=7IZ>0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(OK"Q=+%Q]3)
M(,_0PZ:G(@H*(SH@<VEG;G5P+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B57-E
M<B!296=I<W1R871I;VXB"FUS9W-T<B`BX<3-ILZFT]32U=?!SL[1(,O/TLG3
MU-77P=ZFUR!(;W)D92(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@
M4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-CD*;7-G
M:60@(E5S97(@86-C;W5N="!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<#HY.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ-3`@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHW,B!T96UP;&%T97,O861M:6XO=7-E<B]A
M<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B[L':U\$@
MR\_2R=/4U=?!WL$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A
M;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C@W"B,L(&9U>GIY"FUS9VED(")5<V5R;F%M93HB"FUS
M9W-T<B`B[L':U\$@R\_2R=/4U=?!WL$B"@HC.B!T96UP;&%T97,O;&]G:6XO
M;6]B:6QE+FEN8SHX"B,L(&9U>GIY"FUS9VED(")5<V5R;F%M93H@(@IM<V=S
M='(@(N[!VM?!(,O/TLG3U-77P=[!(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS
M9W-T<B`BZ\_2R=/4U=?!WJ8@UR#3R=/4Q<VF.B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*
M;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,38S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(U-0IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I
M9"`B5F%C871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.#8V"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D
M93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C,X"FUS9VED(")686QI9&ET>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*
M;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@U-B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES
M(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0T(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R-C8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q
M-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(X"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`Y(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T;R!S
M96QE8W0@9G)O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")6
M86YU871U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-#0*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T
M:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E
M<F5D('=I=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-S`P"FUS9VED(")697)S:6]N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C8*;7-G:60@(E9E<G-I;VX@
M0V]N=')O;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B5F5R>2!(:6=H
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I970@3F%M(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")6
M:65T;F%M97-E("A625-#24DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.CDV,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")6:65W("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L
M(%4N4RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#D*
M;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(V,PIM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF
M;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,
M62!&4D]-("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HX,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R("+UU\''P2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@
M(E=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#(W"FUS9VED(")796%T:&5R
M(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#DR"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S<*;7-G:60@
M(E=E8B!3:71E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC
M92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R("+]
MS]3)UL[1(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*(RP@
M9G5Z>GD*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B]Z;4P<`@]\'3+"`E<R(*
M"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHU-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5V5L8V]M92!T;R`E<R(*;7-G<W1R("+WIM3!P"#WP=,L("5S(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M
M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM
M<V=S='(@(O>FU,'`(/?!TRP@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y-0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*;7-G:60@(E=E<W1E<FX@*$E3
M3RTX.#4Y+3$U*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S
M=&5R;B!386AA<F$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N
M('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I
M<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE
M('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C$*;7-G:60@(E=H97)E:7,@
M075S=')A;&EA(&UA<"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3,S"FUS9VED(")7:&EC:"!P;'5G:6YS('1O
M(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,C4*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4W"B,L('!H
M<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L
M969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED
M(")7:61T:"!U;FET(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q,PIM<V=I9"`B
M5VEK:2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S`P(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U
M"FUS9VED(")7:6YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")7:6YD($5A<FQY(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@
M<W!E960@:6X@:VYO=',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-38*;7-G:60@(E=I;F0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-#(*;7-G:60@(E=I;F0Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O
M;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DV
M"FUS9VED(")7:7-H;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K
M($%D9')E<W,B"FUS9W-T<B`B\L_"S][!(,'$TL73P2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@
M4&AO;F4B"FUS9W-T<B`B\L_"S][)RB#4Q<S%QL_.(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,38Y(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@
M9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S`P"B,L
M('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X
M<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,3$T"B,L('!H<"UF;W)M870*;7-G:60@(E=R
M;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#,*;7-G:60@
M(E@M4F5F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.3(*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*
M;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*
M;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@R"FUS
M9VED(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`B\O(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-34*(RP@9G5Z>GD*
M;7-G:60@(EE965DB"FUS9W-T<B`B\O(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$P.`IM<V=I9"`B66%H;V\A(&UA<"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`B_<_2IM[.SR(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(EEE
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*
M;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U
M='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N
M("5D(&)L;V-K<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ-#$Q"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN
M<&AP.C,P,@IM<V=I9"`B66]U(&-A;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R
M86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DW-0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I
M;"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A
M+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M
M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C
M;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED(")9;W4@:&%V92!B
M965N(&QO9V=E9"!O=70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O
M<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@
M<')E9FEX+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3@X"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A
M8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z-#4V"FUS9VED(")9;W4@;75S="!C;VYF:6=U
M<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E
M('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@
M<F5P;W)T+B(*;7-G<W1R("+WR2#0S]?)SLZF(,_0R=/!U,D@T-+/PLS%S=4L
M(-#%TML@SJ;6(->FQ-/)S,'4R2#0S]>FQ,_-S,7.SM$@T-+/(,[%IRXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS
M9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P
M;VEN=',@=&\B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U
M;2YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S
M97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B]\'-(-/,IL0@U\O!VL'4
MR2#.P=K7U2#+S]+)T]35U\'>P2#$S-$@U\G$P<S%SL[1+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$Q.0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B]\'-(-/,IL0@
MU\O!VL'4R2#.P=K7U2#+S]+)T]35U\'>P2#$S-$@U\G$P<S%SL[1+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A
M('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B]\'-(-/,IL0@U\O!VL'4
MR2#.P=K7U2#+S]+)T]35U\'>P2#$S-$@U\G$P<S%SL[1+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D
M+B(*;7-G<W1R("+WP<T@T\RFQ"#7R\':P=3)(,[!VM?5(,O/TLG3U-77P=[!
M(,3,T2#$S\3!U\'.SM$N(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"B,L(&9U
M>GIY"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U
M<&1A=&4N(@IM<V=S='(@(O?!S2#3S*;$(-?+P=K!U,D@SL':U]4@R\_2R=/4
MU=?!WL$@Q,S1(,3/Q,'7P<[.T2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O>FEP+G!H<#HQ,S@*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B]\'-
M(-/,IL0@U\O!VL'4R2#.P=K7U2#+S]+)T]35U\'>P2#$S-$@U\G$P<S%SL[1
M+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A
M=&5G;W)Y(&YA;64N(@IM<V=S='(@(O?!S2#3S*;$(-?+P=K!U,D@SL':U]4@
MR\_2R=/4U=?!WL$@Q,S1(-?)Q,',Q<[.T2XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U
M(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0
M;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C,X"B,L(&9U>GIY"FUS9VED(")9;W5R($5M
M86EL($%D9')E<W,B"FUS9W-T<B`B]\';P2#!Q-+%T\$@Q2W0S]O4R3HB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$R"B,L(&9U>GIY"FUS9VED(")9
M;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(O?!V\$@P<32Q=/!(,4MT,_;
MU,DZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HW-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T:6]N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@
M:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E
M<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@
M;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C,S"B,L(&9U>GIY"FUS9VED(")9;W5R($YA;64B"FUS
M9W-T<B`B]\';Q2"FS2?1.B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M861D+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H
M('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L
M('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B
M86-K96YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N
M;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C
M:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F
M96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E
M87-O;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M.3@T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E
M87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO
M=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y
M;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VEF<F%M92YP:'`Z-3`*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S
M=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E
M<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#
M;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4W"FUS9VED(")9;W5R(&-U<G)E
M;G0@=&EM92!Z;VYE.B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP
M:'`Z.38*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C
M:&%N9V5D+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,34X"B,L(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM
M<V=S='(@(N_3SL_7SL$@IM#/T]3!T]@B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C`Q"B,L(&9U>GIY"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS
M9W-T<B`B]\';Q2"FS2?1.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.C$P,#`*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF
M;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ
M-30*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@
M=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S
M(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H
M('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HW,S(*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S
M(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED("):86ER92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED
M("):86UB:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM
M8F%B=V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V
M"FUS9VED(")::7!P>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED
M92!1=6]T960@5&5X=%TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')O8FQE
M;2YP:'`Z.#@*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B6_#/
MUZ;$S\W,Q<[.T2#PTL_"S,7-R5TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@
M+2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G:60@
M(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DS"B,L('!H<"UF;W)M870*
M;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$U-#$@=&5M<&QA=&5S+W!O<G1A;"]M96YU
M+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(N'$S:;.IM/4TM77P<[.T2(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I
M9"`B7T-,22(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@
M(E]$871A5')E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*(RP@9G5Z>GD*;7-G:60@
M(E]$96QE=&4@4F]W(@IM<V=S='(@(O?)U,72U,DB"@HC.B!L:6(O87!I+G!H
M<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0HC+"!F=7IZ>0IM<V=I9"`B7TAE
M;'`B"FUS9W-T<B`BY,_0S\W/Q\$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0
M<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ.30*(RP@9G5Z>GD*;7-G:60@(E],;V<@:6XB"FUS
M9W-T<B`B]]>FRM3)(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N
M<&AP.C$Y,`HC+"!F=7IZ>0IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B]\G*
MU,DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T"B,L(&9U
M>GIY"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R("+ZPL72Q<?4R2#/T,.FIR(*
M"B,Z(&QI8B]A<&DN<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR-@HC+"!F=7IZ>0IM<V=I9"`B7U)E;6]V92!,:6YK+BXN
M(@IM<V=S='(@(O?)U,72U,D@T,'2U2(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM
M<V=I9"`B7U-E='5P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE
M(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y
M"FUS9VED(")?57-E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,C$*(RP@9G5Z>GD*;7-G:60@(F%D9')E<W,@8F]O:R(*
M;7-G<W1R("+AQ-+%T\[!(,O.R<?!(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$S"FUS
M9VED(")C86QE;F1A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")C86QM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U
M="!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*
M;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U
M<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$W.`IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R
M-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ.#(*;7-G:60@(F5N=')Y
M(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-34*(RP@9G5Z
M>GD*;7-G:60@(F9I;&4B"FUS9W-T<B`B],G4U<PB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$W-"!L:6(O0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO
M8VLO;65T87(N<&AP.C,X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H
M92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-3`*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T
M.0IM<V=I9"`B:#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C,U.`IM<V=I9"`B:&@B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@
M(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B
M:6UM961I871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP
M.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-C(*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT
M97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F
M<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-CD*
M;7-G:60@(FUM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,CDQ('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*
M(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(S,@HC+"!F=7IZ>0IM
M<V=I9"`B;F%M92(*;7-G<W1R("*VS6#1(@H*(SH@9G)A;65W;W)K+U)00R]2
M4$,N<&AP.C$R,0IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(Q.0IM<V=I
M9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDP-0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<T"FUS9VED(")P97)M:7-S
M:6]N(&1E;FEE9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PHC
M+"!F=7IZ>0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(O77P<?!(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E<G9I
M8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HY.0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.#4*;7-G
M:60@(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#D*;7-G:60@(G-W:71C:"!O
M9F8@:F%V87-C<FEP="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Y"FUS9VED
M(")T87-K(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`U"B,L
M(&9U>GIY"FUS9VED(")T<GD@86=A:6XB"FUS9W-T<B`BZ\_6SL_'SR#7R,_$
MU2(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HR-CD*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E
M('1O(&-O;F9I<FTB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N:69I960B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR
M-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S
M97(@<V5L96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T,0IM
M<V=I9"`B=SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(B(*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]Z:%]#3BYP;P``````````
M````````````````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P-C4Q-C<Q
M`#$P-3$U-#,S-S4T`#`Q-S8U-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````C($AO<F1E(%-I;7!L:69I960@0VAI;F5S92!4
M<F%N<VQA=&EO;@HC($-O<'ER:6=H="`H0RD@,C`P,2!786YG2&5N9U=E;BX*
M(R!786YG2&5N9U=E;B`\=VAW0&UY,38Y+F-O;3XL(#(P,#$N"B,@1&%V:60@
M0VAA;F<@/&1A=FED0'1M=BYG;W8N='<^+"`R,#`Q+@HC(&QI86]B:6X@/&QI
M86]B:6Y`:FET92YN970^+#(P,#0N"B,@"FUS9VED("(B"FUS9W-T<B`B(@HB
M4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`R+C!<;B(*(E)E<&]R="U-<V=I
M9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I
M;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO
M;BU$871E.B`R,#`Q+3`V+3$X(#(R.C`U*S`X,#!<;B(*(DQA<W0M5')A;G-L
M871O<CH@;&EA;V)I;B`\;&EA;V)I;D!J:71E+FYE=#Y<;B(*(DQA;F=U86=E
M+51E86TZ($-H:6YE<V4@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-
M12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@
M8VAA<G-E=#U'0C(S,3)<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z
M(#@M8FET7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H
M)7,@S.S'L"DB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S-S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@
M(B`HO^R]W;S\("5S*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M-S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB
M"FUS9W-T<B`B("@E<R#,[,>P*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S-S,*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B`HO?',["DB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<U"B,L(&9U>GIY"FUS9VED
M("(@*'1O;6]R<F]W*2(*;7-G<W1R("+#]\SL(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,W,0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@
M(B`HU_+,["DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4V
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C$*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C0P-PIM<V=I9"`B(&%T("(*;7-G<W1R("+3
MVB(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$U"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y
M+B(*;7-G<W1R("*RN\K'TKNX]L2_PKPB"@HC.B!F<F%M97=O<FLO0TQ)+T-,
M22YP:'`Z,C<R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R("(G)7,G(+*[RL?2N[CV
MT]#0I[7$T:'4\2XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T
M<GDN<&AP.C8U.0HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN
M<&AP.C$P-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I
M<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S
M='(@(B<E<R<@R=#.M-3:($A/4D1%(+7$UZ*RX<[$O/XH4F5G:7-T<GDIUM#%
MY-;#+B(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T
M(&9O=6YD+B(*;7-G<W1R("+5TK*[M;T@)7,N(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HU-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A
M<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R#2
MT;/)N::\T\CKM;W3P[NGU^G/M<VSUM`N(@H*(SH@861M:6XO<&5R;7,O861D
M8VAI;&0N<&AP.C4R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S
M='(@(B<E<R<@TM&\T\CKR*C/WL^US;,N(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*
M;7-G<W1R("(G)7,G(+*BSK2]J,&B.B`E<RXB"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@
M;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B5S(-+1R*'/^R`E
M<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C(V."!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@U"B,L('!H<"UF
M;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R("+7[KW\("5D
M(,SLQOC/\]2DL:@B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B)7,@
M+2"QN,W\PKPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C<P-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G
M<W1R("(E<R#6N,[&(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#,S(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S
M-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T
M:6]N(@IM<V=S='(@(B5S(,ZLNZ2RV=?W("T@R+?(SR(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8S"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B)7,@UZ*RX2(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B)7,@S:S2XL_NQ+\B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0R."!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C0Y,`HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C8U,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Q.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B)7,@
MTM&TYM3:(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3D@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,SD*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B)7,@
MU-H@)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E
M<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO
M=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@
M=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`BT:'4\<3Z
MS^O2JK+9U_>UQ,SUQ+\N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G
M<W1R("*QV-#HTJH@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(B5S(+?6
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R
M,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@
M(M72LKNUO2`E<RXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S
M='(@(B`E<R"UO2`E<R"YLB`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D
M9')E<W,@0F]O:R(*;7-G<W1R("+-J-&VLKXB"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDQ-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M)7,G<R!#86QE;F1A<B(*;7-G<W1R("+(U<#Z(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(B5S)W,@3F]T97!A9"(*;7-G<W1R("(E<R`M(+&XS?S"O"(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,P"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF
M:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7,Z("5S(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO
M="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L
M;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE
M('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V-2!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$P"B,L(&9U>GIY"FUS9VED("(L
M(&=U<W1I;F<@(@IM<V=S='(@(BP@U?.WYR`E<R`E<R(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3@X(&QI8B]";&]C:R]M971A<BYP:'`Z,3DS"B,L('!H
M<"UF;W)M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(L(-7S
MM^<@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P,0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T
M<B`B++'DNZ_!O[33("5S(+6]("5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HR.30@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS
M-#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`V.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3(X"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HW-#D*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R
M("(M+2#1H=3Q("TM(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"B,L(&9U
M>GIY"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R("+$^K7$T,7/HB(*
M"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0HC+"!F=7IZ>0IM<V=I9"`B,C0@
M2&]U<B!&;W)M870B"FUS9W-T<B`BQ/JUQ-#%SZ(B"@HC.B!T96UP;&%T97,O
M9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@
MT*'*L=;&(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0HC+"!F
M=7IZ>0IM<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(LG/TKO2LR(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED(")!(&1A=&%B87-E(&)A8VME
M;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(K3+Q_B_
MZ;'8T.O2JM:XMJC*_;[=O^*W_L[QMLLN(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-C`*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R
M<F5D(@IM<V=S='(@(K>BR?K!R]*[N/;1S];8M<2T[<[S(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!0
M1U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G
M<W1R("+3^[S3P]S3RKS^++NYT.C2JM/0TKNX]B!01U`@N:N_JL/<U+\N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V-0IM<V=I9"`B
M02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N
M960@;65S<V%G92XB"FUS9W-T<B`BT_O1Z=:DTM''J</[M<33RKS^++NYT.C2
MJM/0TKNX]B!01U`@N:N_JL/<U+\N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3`Y-PIM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@
M<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(M/[O>+#W-/*O/XL
MN[G0Z-*JT]#2N[CVN:N_JB!01U`@P]S4ORS+O</<(%!'4"##W-2_+-+4O+"_
MVL'N+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,34*
M;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S
M86=E+B(*;7-G<W1R("+3^]:TT-#3RKS^QZG#^RR[N=#HTJK3T-*[N/:YJ[^J
M(%!'4"##W-2_+,N]P]P@4$=0(,/<U+\LTM2\L+_:P>XN(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#4*;7-G:60@(B(*(D$@<'5B
M;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*
M;7-G<W1R("+3^[WBP]S3RKS^++NYT.C2JM/0TKNX]KFKOZH@4TU)344@P]S4
MORS+O</<(%--24U%(,/<U+\LTM2\L+_:P>XN(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O
M34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("+3
M^]:TT-#3RKS^QZG#^RR[N=#HTJK3T-*[N/:YJ[^J(%,O34E-12##W-2_+,N]
MP]P@4R]-24U%(,/<U+\LTM2\L+_:P>XN(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME
M>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B
MT_N\T\/<T\J\_BR[N=#HTJK3T-*[N/8@4TU)344@N:N_JL/<U+\N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0HC+"!F=7IZ
M>0IM<V=I9"`B04T@0VQO=61S(@IM<V=S='(@(M3&P;\B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG
M:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I
M9"`B04T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS
M9VED(")!32]032(*;7-G<W1R(")!32]032(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$
M(@IM<V=S='(@(D%022"QX+K%(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B
M"FUS9W-T<B`BN=C3VM7BN/:QX+RMQO<B"@HC.B!S97)V:6-E<R]H96QP+VEN
M9&5X+G!H<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`BN=C3VBXN+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*
M;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(W
M,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y
M+B(*;7-G<W1R("+(J,_>LKO7XRS.WK>HO:C!HB!61E,@Q+_"O"XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@
M9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R("+(J,_>LKO7XRS.
MWK>HO:C!HB!61E,@SL2\_BXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M,PHC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R
M("+$^K7$T,7/HB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-0HC+"!F
M=7IZ>0IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R("+(M\C/P]S"
MZR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(M7+NL72
MT;:SO>$N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S,PIM<V=I
M9"`B06-C;W5N=&EN9R(*;7-G<W1R("*]X=7*(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC
M.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q
M"FUS9VED(")!9&0B"FUS9W-T<B`BT,+4]B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@
M1W)O=7`B"FUS9W-T<B`BT,+4]L_"O+;7Z2(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`BT,+4
M]L_"O+;(J,_>(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G
M:60@(D%D9"!(97)E.B(*;7-G<W1R("+4VK3+T,+4]J.Z(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G:60@(D%D
M9"!.97<@1W)O=7`B"FUS9W-T<B`BT,+4]M/#NZ?7Z2(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@
M(M#"U/;(J,_>(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL
M9"YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI
M;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(M#"U/;/PKRVT\.[I]?I("<E
M<R<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T-PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO
M;B!T;R!<(B5S7"(B"FUS9W-T<B`BT,+4]L_"O+;(J,_>UL$@)R5S)R(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS
M9W-T<B`BT,+4]M*[N/;3P[NG.B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HU-30*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM
M<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(M#"U/;2N[CVL\G4L3HB
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@
M<&%I<B(*;7-G<W1R("+0PM3VMM0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A
M<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R("+0PM3V("5S(,ZJ($UO>FEL
M;&$@4VED96)A<B"RR[6E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@861D<F5S
M<R!B;V]K.B(*;7-G<W1R("+0PM3VM;W.TK7$S:C1MK*^(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"B,L(&9U>GIY"FUS
M9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(M#"U/:UO<[2
MM<3-J-&VLKXB"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D('5S
M97(B"FUS9W-T<B`BT,+4]M/#NZ<B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O
M('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG
M;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`BTM'0PM3V("<E<R<@
MM;W/M<VSUM`N(+6KSMZWJ-#"U/:V[LWBM<37HK+AT,7/HCH@)7,N(@H*(SH@
M<VEG;G5P+G!H<#HT-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D
M960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB
M"FUS9W-T<B`BTM'0PM3V("<E<R<@M;W/M<VSUM`N(,3ZS];4VK_)TM2]^-#0
MM<?"O,'++B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR
M"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(M#"
MU/;3P[NGM<2YIL3<M;''L+&[N=BQU2XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30T,0IM<V=I9"`B061D<F5S<R(*;7-G<W1R("*UV-:W(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S.0IM<V=I9"`B061D<F5S<R!";V]K
M(@IM<V=S='(@(LVHT;:ROB(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI
M<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R("*SR<ZJN=S`[=2Q("T@
MSJK&Y,O\T\.[I\7DUL/(J,_>(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(KG<P.TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S0Q"FUS9VED(")!9',B"FUS9W-T<B`BN>.XYKG<P.TB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4V"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R("*PHKB[NKDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4W"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(K"BMONPS<3AT<<B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(K"BMON\L,#[
MT<<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R("*Q\,/[(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@HC+"!F=7IZ
M>0IM<V=I9"`B06QI9VXB"FUS9W-T<B`BL?##^R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*(RP@9G5Z>GD*;7-G:60@
M(D%L:6=N;65N=#HB"FUS9W-T<B`BO\V[I[;+(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS
M9W-T<B`BR_G3T-+1T>G6I+7$T\.[IR(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS
M9W-T<B`BR_G3T-/#NZ?7Z2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW
M-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(LOYT]#(J,_>(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,0IM<V=I9"`B06QL;W<@;75L=&EP
M;&4@861D<F5S<V5S(@IM<V=S='(@(M3*T.VVX+CVM>?7T]/*O/ZUV-:W(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S-`IM<V=I9"`B06QL;W<@<V5T
M=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!
M;')E861Y(&5X:7-T<R(*;7-G<W1R("+2T;3FU-HB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3(S"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*
M;7-G<W1R("*QY+C\($E-4U`@M<?"O"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU,#<*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S
M='(@(K'DN/P@24U34"##W,+K(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0Y.0IM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS9W-T<B`B
ML>2X_"!)35-0(-/#NZ<B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HS-0HC+"!F=7IZ>0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B
M"FUS9W-T<B`BL>2X_,2CL.8B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T
M,@IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R("*QY+C\Q*.P
MYB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR-0HC+"!F=7IZ>0IM<V=I9"`B06QT97)N871E('1E>'0Z
M(@IM<V=S='(@(K'DN/S$H[#F(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC
M86X@4V%M;V$B"FUS9W-T<B`BP\#*],CXQ*;1QR(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE
M9"XB"FUS9W-T<B`BTKNX]K*[NL^WJ+7$UK6QN\JYT\,N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-PHC+"!F=7IZ>0IM<V=I9"`B06X@
M=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`BMZ+)^L'+TKNX
M]K3MSO,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G<W1R("*P
MLK7`MOLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`BL+*X
MY\"M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`BL+*Y
MY\"M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I
M9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(L3DP_NT^L#M(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@
M(L3/O*O6WB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U
M9&$B"FUS9W-T<B`BL++,X;G/O+"PS;;[LKRT[R(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`BTZ;3
MP[/,T/(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*(RP@9G5Z>GD*
M;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`BTZ;3P[/,T/(B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO
M;B!I<R!R96%D>2XB"FUS9W-T<B`BTZ;3P[/,T/+2T;[-T/<B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI
M;&0@4VAA<F5S(@IM<V=S='(@(M.FT\.UO<OYT]#/PKRVN;+/[2(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R
M;W9E(@IM<V=S='(@(L7ZU[PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX,S,*;7-G:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(LO$U,(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$W-0IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM
M<V=S='(@(K"BP*VRKL[$("A7:6YD;W=S+3$R-38I(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#$*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM
M<V=S='(@(M&YR_7.Q+S^M//0H2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HV-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@P"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T<B`BT;G+]<[$O/[#
M^[/&(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN
M8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A
M;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G
M<W1R("+$^LBWMJC2JLF^L_T@)7,@M<37HK+APO`@/R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB
M)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(L3ZR+>VJ-*JR;ZS
M_2`G)7,G(-+4O+#(SKK.U]/3P[NGU^D@/R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@
M(D%R9V5N=&EN82(*;7-G<W1R("*PHKCYS:(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED
M(")!<FUE;FEA(@IM<V=S='(@(M''P\#$X=''(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ-S8*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S
M='(@(M''P\#$X=''SL0@*$%235-#24DM."DB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y
M"FUS9VED(")!<G5B82(*;7-G<W1R("*PHL*SL,TB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM
M<V=S='(@(K"BR:W+R<BZM;HB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I
M;VXB"FUS9W-T<B`BT<?6WB_,J\:]T?.UV,?X(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0R-0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F
M;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(M:T
MT-#.K+NDLMG7]\>PS]3*OLBWR,^VU+NPO_(_(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$Q,PIM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M
M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R("+*
MU,V\R;ZS_=*[N/:RN[3FU-JUQ-/#NZ?7Z2XB"@HC.B!A9&UI;B]P97)M<R]D
M96QE=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE
M>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("+*U,V\R;ZS_=*[N/:RN[3F
MU-JUQ,BHS]XN(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@
M(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*
M;7-G<W1R("+*U,V\L>"\K=*[N/:RN[3FU-JUQ-/#NZ?7Z2XB"@HC.B!S97)V
M:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I
M="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`BRM3-O+'@O*W2N[CV
MLKNTYM3:M<2YLL_M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@V
M"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(LKTT-0B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T
M(@IM<V=S='(@(K#+U,(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B
M"FUS9W-T<B`BL,2T\\#[T<<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA
M(@IM<V=S='(@(K#"M=C`^R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8W)Y<W%L.B#5
MTK*[M;W+^=#HTJJUQ"!I;6%P(,"IU;G7Z;S^+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C
M:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G
M<W1R(")!=71H7V-Y<G5S.B"W_L[QMLNRHLZTS.&YJ;C#S^[6I[/6+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T
M:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")!=71H7V-R>75S.B#5TK*[M;W+^=#HTJJUQ"!I;6%P(,"IU;G7
MZ;S^+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O9G1P+G!H<#HS-@IM<V=I
M9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I
M=&-H+B(*;7-G<W1R("(B"B)!=71H7V9T<#H@U=*RN[6]R_G0Z-*JM<0@1E10
M(,"IU;G7Z;S^+L?KUMC0PK'@TNL@4$A0(+*BQ]*\T\CK("TM96YA8FQE+69T
M<"#1H2(*(L_N+,#]R.<@8V]N9FEG=7)E("TM96YA8FQE+69T<"(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA
M<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!=71H7VEM87`Z(-72LKNUO<OYT.C2JK7$($E-05`@P*G5N=?IO/XN(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T
M:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%U=&A?:W)B-3H@U=*RN[6]R_G0Z-*JM<0@:W)B-2#`J=6YU^F\
M_BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,P,@IM<V=I
M9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F
M;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P.B!296UO
M=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T
M;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VQD87`Z(-72LKNUO<OYT.C2
MJK7$($Q$05`@P*G5N=?IO/XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5
M;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60Z("(*;7-G<W1R(")!=71H7VQD87`Z(,[>MZC0PM3VT\.[IR`E<RX@
MM_[.\<;WN]C3ICHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T
M;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z(,[>MZC)OK/]
MT\.[IR`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DY
M"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P
M9&%T92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@SMZWJ+C\T,+3P[NG
M("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,#4*;7-G
M:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!2
M97%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?;6-A;#H@U=*RN[6]R_G0Z-*JM<0@34-!3"#`J=6YU^F\_BXB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB
M875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")!=71H7W-M8F%U=&@Z(-72LKNUO<OYT.C2JK7$('-M8F%U=&@@
MP*G5N=?IO/XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B
M"FUS9W-T<B`BT>G6I,JGL-PN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R("+1Z=:DRJ>P
MW"X@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,3<V
M"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R
M=F5R+B(*;7-G<W1R(")2041)55,@T>G6I+3MSO,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O
M($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")&5%`@T>G6I+3MSO,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,`HC+"!F=7IZ>0IM<V=I
M9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*
M;7-G<W1R(")&5%`@T>G6I+3MSO,N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B
MO\G3P[7$U]:VSCHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM
M<V=S='(@(K"BR/NPW;VN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P
M"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`HC+"!F=7IZ
M>0IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R("*QL[ZPT=7)JR(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@
M(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`BL;.^L-'5R:LB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R8F5R
M;W,@<&%S<W=O<F0N(@IM<V=S='(@(FME<F)E<F]S(,/<PNNT[<[S+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K
M97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B:V5R8F5R;W,@T\.[I\/[M.W.
M\RXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@(K#-N?["
M[<BZM;HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"86AR86EN(@IM<V=S='(@(K#-
MP=8B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B0F%L=&EC
M("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`BLJC"WK7$NJ/.Q"`H25-/+3@X-3DM
M,3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R("+#
MS[S3P*VY^B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@
M(K#-L,VVX,NY(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S(&1I<F5C=&]R
M>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("+5TK*[M;T@)7,@M<3`X+'P
MMJC2Y2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S,*(RP@9G5Z>GD*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@
M(K*NP/O7R"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B
ML->V[<+>R[DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@
M(K'(P/O*L2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R("*R
MKL#[U\@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R("*QM,3^
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R("*PV<2]M//(
MNK6Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(K*[M:0B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q
M"FUS9VED(")":7)T:&1A>2(*;7-G<W1R("+)^LC5(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U,PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB
M)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(M72LKNUO2`E<R"UQ,#@L?"VJ-+E
M+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHX.0IM<V=I9"`B
M0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`BQ_B_Z<7DUL,B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS
M9W-T<B`BQ_B_Z<#@T,TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`BM-;,Y2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`BLJ/`^\ZLT<<B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`U"FUS9VED(")";V]K;6%R
M:W,B"FUS9W-T<B`BRNG'J2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(D)O<F1E
M<B(*;7-G<W1R(")(;W)D92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(D)O<F1E<G,B"FUS9W-T
M<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE
M9V]V:6YA(@IM<V=S='(@(K*HR[G$X=''NLVZVLC[N.?.K,3'(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.CDV"B,L(&9U>GIY"FUS9VED(")";W1H(@IM
M<V=S='(@(M3"(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T
M<B`BLJFTQ,W?Q,DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8S"FUS9VED(")";W5V970@27-L86YD(@IM<V=S='(@(K*HSJS,
MV+6Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(K#-SO<B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R
M<FET;W)Y(@IM<V=S='(@(M.BRO33H;;(T?/![+78(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM
M<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`BSL3`LR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(K&CO-/`^]''(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I
M9"`B0G5L;&5T960@3&ES="(*;7-G<W1R("+/[L2_M_NZQ2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R("*RO+RJQ,FWJ,OW(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R("*RO,*AM<\B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0T"FUS9VED(")#35,B"FUS
M9W-T<B`BQ-K(W;G<P.W/M<VS(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-20R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#
M4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R(")#4DP@M]:RO+7C(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(D-A
M8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0@8V]N9FEG
M+VAO;VMS+G!H<"YD:7-T.CDX-PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,34U"FUS9VED(")#86QE;F1A<B(*;7-G<W1R("+(U<#Z(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-@IM<V=I9"`B0V%L;2(*;7-G
M<W1R("+!X[RVM^<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS
M9W-T<B`BO.W&TM6O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS
M9W-T<B`BOZ;"\\*A(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL
M>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,Q.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*
M;7-G<W1R("+.WK>HR;ZS_<[$O/X@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E<W-I
M;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S
M97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S
M<6PN<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T
M('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R("+.WK>HP:J[^M;!($E-05`@
MM_[.\<;W.B`E<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0Q
M,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`BSMZWJ,F^L_W.Q+S^(%PB)7-<(BXB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8T"FUS9VED(")#86YA9&$B"FUS9W-T<B`BO-/$P[3S(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U
M<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO
M=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`BR*'/^R(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@
M4')O8FQE;2!297!O<G0B"FUS9W-T<B`BR*'/^\[*S.*QJ+CF(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BSMZWJ,F^
ML_W.Q+S^(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]C;W!Y+G!H<#HU,@HC+"!F=7IZ>0IM<V=I9"`B0V%N;F]T(&9I;F0@
M82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("+.WK>HR;ZS_<2_PKP@
M7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E
M=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HS,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T
M(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("+.WK>HR;ZS_<2_
MPKP@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92YP
M:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8X
M,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@
M)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(L[>MZC)OK/].]/0S\*\MK3F
MU-H@*"5S*2(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN
M<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E
M;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU
M;6)E<B`B"B)S=&]R960N(@IM<V=S='(@(L[>MZC6V-?IH:/+^<SAN:FUQ+S'
MPKS*_<2_T^O/R,>PR_FQH[3FM<3*_;[=LKNW^RXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A
M;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S
M='(@(L[>MZBTJ\O-T,7/HK6]UKBVJ+7$NL7"ZRXB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#87!E(%9E<F1E(@IM<V=S='(@(K?PM<.]QR(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*(RP@9G5Z
M>GD*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`BT:'/[B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`HC+"!F=7IZ>0IM
M<V=I9"`B0V%R<FEE<B(*;7-G<W1R("*WV[KLR:LB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.3`*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B
M"FUS9W-T<B`BOZK"_,BZM;HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@
M(M+&MJ^UY[NP(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR-0HC+"!F=7IZ>0IM<V=I9"`B0V5L;"!0<F]P97)T
M:65S(@IM<V=S='(@(M+&MJ^UY[NP(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S0*(RP@9G5Z>GD*;7-G:60@(D-E
M;&QP:&]N92(*;7-G<W1R("+2QK:OM>>[L"(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3<X"FUS9VED(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R
M("+(^[;[S-C.Q"`H25-/+3@X-3DM,30I(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@HC+"!F=7IZ>0IM<V=I
M9"`B0V5N=&5R(@IM<V=S='(@(KVHP:(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#
M96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`BUM"WQ[FRNLVY^B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#96YT<F%L($5U
M<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R("+6T,6W("A)4T\M.#@U.2TR
M*2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-CDY"FUS
M9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(L:^UJ3/N+W:(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3$*(RP@9G5Z
M>GD*;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S='(@(L:^UJ3/N+W:
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G
M:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(L:^UJ2RW\+4(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`X"FUS9VED(")#:&%D(@IM<V=S='(@(M6GM<,B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`BN/RXQ"(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0HC+"!F=7IZ>0IM
M<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`BR+?(S\/<PNLB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@(B(*(D-H86YG
M92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T
M:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G:60@
M(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W
M:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T('EO
M=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PHC+"!F=7IZ>0IM
M<V=I9"`B0VAA<B(*;7-G<W1R("+5I[7#(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C
M7VL@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EL
M92(*;7-G<W1R("+6Q\#[(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;F$B"FUS
M9W-T<B`BUM"Y^B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED
M(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`BO/+,Y=;0
MSL0@*$=",C,Q,BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I
M9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`BM[',Y=;0
MSL0@*$)I9S4I(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C(V.0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`BT:'4\</<
MPNLB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8X"FUS
M9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R("+1H=3QTKNX]M/#NZ?#
M^R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3@*;7-G:60@(D-H;V]S
M92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`BR-7&VL_4RKZWO<J]
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O
M<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED
M(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(LJEM:ZUNB(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HX.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O
M9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(M72LKNUO2`E<R"UQ,#@L?"VJ-+E
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T
M"B,L(&9U>GIY"FUS9VED(")#;&5A<B(*;7-G<W1R("+(U<#Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B
M0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3(X"B,L(&9U>GIY"FUS9VED(")#;&5A<B!1=65R>2(*;7-G
M<W1R("+*_;[=O^*RZ=&O(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE
M87(N:6YC.C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U
M="!U<V5R.B`E<R(*;7-G<W1R("+)OK/]T\.[ISH@)7,B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,S0*(RP@9G5Z>GD*;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R("+1
MH=3QTKO.N]/#NZ?3P]+4T,+4]B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH
M=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R("*PM,KS
ML>J\_+S,T/@B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS
M9W-T<B`BN=BQU;2PO]HB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-`IM
M<V=I9"`B0VQO=61S(@IM<V=S='(@(M3&P;\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@HC+"!F=7IZ>0IM<V=I9"`B0VQO
M=61S($5A<FQY(@IM<V=S='(@(M3&P;\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PHC+"!F=7IZ>0IM<V=I9"`B0VQO=61Y
M(@IM<V=S='(@(M3&P;\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E
M;&EN9RD@27-L86YD<R(*;7-G<W1R("*_QK_&R[G(NK6Z(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@4VED
M96)A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;VQO;6)I82(*;7-G
M<W1R("*XY\+7L<C1QR(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB
M+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R
M("+1U<FK(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN
M<&AP.C,R-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP
M:'`Z,S(U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU,#`@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I
M9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(K7WR:O%S"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X-#8*(RP@9G5Z>GD*;7-G:60@(D-O;&]U<B!S
M96QE8W1I;VXB"FUS9W-T<B`BO/3'T-&AU/$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PHC+"!F=7IZ>0IM<V=I9"`B
M0V]L<SHB"FUS9W-T<B`BS;;&L2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y-#8*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-`IM<V=I9"`B0V]M:6-S(@IM
M<V=S='(@(K^HS:@B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*;7-G:60@
M(D-O;6UA;F0B"FUS9W-T<B`BP_S![B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H
M<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R("+#_,'NO<6QOB(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B
M0V]M;65N="(*;7-G<W1R("+&P,+;(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-C8*;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S='(@
M(LVHT\/#^R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@
M(K_&Q*;"WB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`BN:O+OB(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B0V]M<'5T
M97)S(@IM<V=S='(@(M+1S>JSR2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.3<*(RP@9G5Z>GD*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R
M("+,];S^(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#D*;7-G:60@(D-O
M;F1I=&EO;G,B"FUS9W-T<B`BS/6\_B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.CDV"B,L(&9U>GIY"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N
M8V5S(@IM<V=S='(@(L7DUL,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,30S"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!
M<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*(RP@9G5Z>GD*;7-G:60@(D-O;F9I
M9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(L7DUL,B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O;F9I9W5R92`E<R(*;7-G<W1R("+%Y-;#("5S(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!087-S
M=V]R9"(*;7-G<W1R("+(M\C/P]S"ZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O
M;F=O(@IM<V=S='(@(KC5N?LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG;RP@
M5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(KC5N?NY
MLKK-N?HB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S$P"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T
M<B`BP:R]T\JGL-PZ("(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T
M<B`BP:R]T\JGL-PZ("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C<Y,`HC+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("+!K+W3UL&YJ[^JP]S4
MO[?^SO'&]\JQU.*^W+[X+B#4K=+R.B`E<R`H)7,I(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@
M4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(L&LO=/6P;FKOZK#W-2_M_[.\<;W
MRK'4XK[<OO@N(-2MTO(Z("5S("@E<RDB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C@T-0IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"XB"FUS9W-T<B`BP:R]T];!($944"#.Q+S^M_[.\<;WRJ>PW"XB
M"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`Q-`IM<V=I9"`B0V]N=&%C
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C4S"B,L(&9U>GIY"FUS9VED(")#;VYT86-T<R!W97)E('-U
M8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T
M<B`BS:C1MLK]OMW2T;/)N::UQ-3VO-.UO<3ZM<3-J-&VLK[6T"[3P\KSL>JP
MM,_"P=#/[L2_TM2\[,K3.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-38@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HV,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C<X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<
M(B5S7"(B"FUS9W-T<B`B)R5S)R#.Q+S^Q-K(W2(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HS,PHC+"!F=7IZ>0IM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`BS/6\_B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R("*_XK_+
MR+JUNB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O
M:VEE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B0V]P>2(*
M;7-G<W1R("*YJ\N^(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT
M-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E
M<R(*;7-G<W1R("+!K+W3RJ>PW#H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB
M"FUS9W-T<B`BN+36QM&AU/$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$W,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8W"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@(KCGR[FT[\#HO-,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(K_&
MS-BUS\W?(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3<V
M"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T
M<B`BSMZWJ-+4(%!'4""\T\/<T\J\_BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,#4S"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@
M;65S<V%G92XB"FUS9W-T<B`BSMZWJ,ZJ(%!'4"#6M-#0T\J\_L>IP_LN(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@
M(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("+.
MWK>HTM0@4R]-24U%(+S3P]S3RKS^+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I
M9VX@;65S<V%G92XB"FUS9W-T<B`BSMZWJ,ZJ(%,O34E-12#3RKS^QZG#^RXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C$X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D
M9"!C;VYT86-T+B`E<R(*;7-G<W1R("+.WK>HM/*_JB`E<RXB"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HQ,C$*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$
M05`@<V5R=F5R+B(*;7-G<W1R("+.WK>HL/.VJ"!,1$%0(+?^SO'&]R(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*(RP@9G5Z>GD*;7-G:60@(D-O
M=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(L[>MZBP\[:H
M($Q$05`@M_[.\<;W(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`BSMZW
MJ+;!R*$@)7,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0HC+"!F
M=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V97(B
M"FUS9W-T<B`BSMZWJ,&LO=,@4TU"(+?^SO'&]RXB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E
M<R(*;7-G<W1R("+.WK>HP:R]T];!M_[.\<;W("<E<R<@RKG3PR!&5%`Z("5S
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HS,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C
M<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(L[>MZB]J,&B
ML;ZUV-/OT=0@)7,@R_G0Z-*JM<3$O\*\.B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$Q,C4*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T
M(%!'4"!D871A+B(*;7-G<W1R("+.WK>HO>+#W"!01U`@ROV^W2XB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,@IM<V=I9"`B0V]U
M;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(L[>MZB]XL/<
M(%,O34E-12#*_;[=+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,C0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@(L[>MZC)
MOK/]N/S0PK/,T/(@)R5S)RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B
M"FUS9W-T<B`BSMZWJ,F^L_VX_-#"L\S0\B`G)7,G+B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C,X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<
M(BXB"FUS9W-T<B`BSMZWJ,F^L_VX_-#"L\S0\B`G)7,G+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN
M92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(L[>
MMZB^]K:HRM6\_LC+M<2UY]?3T\J\_K78UK<N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*(RP@9G5Z>GD*;7-G
M:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM
M<V=S='(@(L[>MZB^]K:HRM6\_LC+M<2UY]?3T\J\_K78UK<N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*(RP@
M9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB
M=71I;VX@;&ES="XB"FUS9W-T<B`BSMZWJ+#\NJS7ULSEMJC2Y<[$O/XN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT
M-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O
M9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN
M<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T
M<B`BSMZWJ+;!R*$@)7,N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T
M<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(L[>MZBVP<BA
M("5S+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM
M<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME
M>7-E<G9E<BXB"FUS9W-T<B`BSMZWJ-?4P]S4O[?^SO'&]\BAM<.YJ[^JP]S4
MORXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N
M(@IM<V=S='(@(L[>MZBT\K^J("5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`BSMZWJ+3ROZH@)7,N
M(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT
M,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E
M;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`BSMZWJ+3ROZK.K+NDN:37
M]\2CO^D@)7,B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S
M7"(N(@IM<V=S='(@(L[>MZC)OK/]Q+_"O"!<(B5S7"(N(@H*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W
M.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-CDY"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@
M=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("+.WK>HLNG5TB!,1$%0(""W_L[Q
MQO<N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR,S@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@
M(L[>MZBVP<BA("5S+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O
M<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D
M971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@
M>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L
M<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S`Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,T,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S@S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,X.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R("+.
MWK>HML'(H;3FR*&_V-;&L>TH04-,*2(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E
M<R(*;7-G<W1R("+.WK>HML'(H;?^SO'&][7$S^"YV,S8T-0B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("+.WK>HML'(H;?^SO'&][7$
MS^"YV,S8T-0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C0S-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T
M<B`BSMZWJ+;!R*&W_L[QQO>UQ,_@N=C,V-#4(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`BSMZWJ+;!R*&W
M_L[QQO>UQ,_@N=C,V-#4(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU
M-`HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("+.WK>HL:.TYB`E<R"UQ,7DUL,N(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+V-O<'DN<&AP.CDT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R("+.WK>HML'(H2`E<RXB"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("+.WK>HL:.TYB`E<R"UQ,7DUL,N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"B,L(&9U>GIY"FUS
M9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM
M<V=S='(@(L[>MZBQH[3F("5S(+7$Q>36PRXB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B
MSMZWJ+&CM.8@)7,@M<3%Y-;#+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.CDU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R
M("+.WK>HL:.TYKC\T,*SS-#RM;TZ("<E<R<N(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HV-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M(@IM<V=S='(@(L[>MZBQH[3F("5S(+7$Q>36PRXB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C<U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9
M;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A
M=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C
M;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("+.WK>HT+3(ZRX@Q/J_R=+4RKG3
MP\C.NLZUQ,G]O+:SS-#RN_+*UK:ON+36QL_"P^:SS-#RM/K"Z[6]("5S+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30S"FUS9VED(")#
M;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`BSMZW
MJ++IU=(@3$1!4"`@M_[.\<;W+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<
M(B5S7"(N(@IM<V=S='(@(L[>MZBT\K^J("5S+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S
M(@IM<V=S='(@(L[>MZBT\K^J("5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R("+.WK>HL/RZK-?6S.6VJ-+ESL2\_BXB"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z
M("5S(@IM<V=S='(@(L[>MZBXLKC'("<E<R<Z("5S(+7$Q>36PRXB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8V"FUS9VED(")#;W5L9&XG="!F:6YD
M('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I
M<R!O<&5N+B(*;7-G<W1R("+5TK*[M;T@36]Z:6QL82!3:61E8F%R+B#'Z\BW
MR,\@<VED96)A<B#*Q[?QM/*_JBXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN
M9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R("+.
MWK>HN+/3Z-/#NZ<@)R5S)R#/PL'0R*C/WK6]SL2\_KS0("<E<R<Z("5S(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q.0HC+"!F=7IZ>0IM<V=I
M9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(LSARK[$VLC=(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D-O=6YT<GDB
M"FUS9W-T<B`BN?J\TB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-S,*(RP@9G5Z>GD*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`BT*'*L2(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(KVHP:(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*
M(RP@9G5Z>GD*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`BO:C!HB(*
M"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.30*(RP@
M9G5Z>GD*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`BT:'4\=*[
MSKO0PK7$T[73T-7?(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R
M("*]J,&BU]/.Q+S^O-`B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R("*]
MJ,&BU=^UQ,BHS]XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,P
M"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`BT,73P[^HNL7"
MZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(K_+PMZU
MV-''(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R("*YQ;#-(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"B,L(&9U>GIY"FUS9VED(")#=7)R
M96YT(#0@4&AA<V5S(@IM<V=S='(@(K6QQ[#/X,Z[(@H*(SH@861M:6XO<V5S
M<VEO;G,N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%-E<W-I;VYS
M(@IM<V=S='(@(KVHP:+5W[7$R*C/WB(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE
M(@IM<V=S='(@(K6QQ[#*L;SD(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"B,L(&9U>GIY"FUS9VED(")#
M=7)R96YT(%523"!I<R(*;7-G<W1R("*UL<>PRK&\Y"(*"B,Z(&%D;6EN+W-E
M<W-I;VYS+G!H<#HS,PHC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!5<V5R<R(*
M;7-G<W1R("*UL<>PS^#.NR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*
M;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R("*UL<>PS.S&^"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S4*;7-G:60@(D-U<G)E
M;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`BM;''L->TO_8Z("(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U
M<G)E;G0@<W1Y;&4B"FUS9W-T<B`BM;''L+?GN/$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ
M92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(P"B,L(&9U>GIY"FUS9VED(")#=70B"FUS9W-T<B`BN?J\TB(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G
M:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`BO/3'T-&AU/$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8X"FUS9VED(")#>7!R=7,B"FUS9W-T<B`BR/O&UL*WR[DB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB
M"FUS9W-T<B`BSO?`[[;[SL0@*$M/23@M4BDB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS
M9W-T<B`BSO?`[[;[SL0@*%=I;F1O=W,M,3(U,2DB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X-`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX
M+54I(@IM<V=S='(@(L[WP.^V^\[$+\[:O\O`O,[$("A+3TDX+54I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`BO=V_R[FR
MNLVY^B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-3$@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S
M='(@(LC5(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,0IM<V=I
M9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO
M<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y
M"FUS9VED(")$86EL>2(*;7-G<W1R("+#O\C5(@H*(SH@861M:6XO9&%T871R
M964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-SD*;7-G:60@(D1A=&%B
M87-E($QO;VMU<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S.3D*;7-G:60@(D1A=&4B"FUS9W-T<B`BR-7&VB(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I
M=F5D(@IM<V=S='(@(LK5M;W(U<;:(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@P-PIM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`BT:'4
M\<C5QMHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDR(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,C(*;7-G:60@(D1A>2(*;7-G
M<W1R("*PU\SL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,V"B,L(&9U>GIY"FUS9VED(")$95]L971E($-O
M;'5M;B(*;7-G<W1R("+)OK/]T\.[I]?I(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S
M='(@(LJNMO[4PB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,38*(RP@9G5Z>GD*;7-G:60@(D1E8VEM86P@
M;G5M8F5R<R(*;7-G<W1R("+0\KK%(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT
M(@IM<V=S='(@(KSUR=G+]<7%(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@
M(D1E9F%U;'0B"FUS9W-T<B`BR;ZS_2(*"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"B,L(&9U>GIY"FUS9VED(")$969A
M=6QT($-O;&]R(@IM<V=S='(@(M?6T,W1U<FK(@H*(SH@9G)A;65W;W)K+TED
M96YT:71Y+TED96YT:71Y+G!H<#HY,0IM<V=I9"`B1&5F875L="!)9&5N=&ET
M>2(*;7-G<W1R("+$K,C/R>VWW<JVL?`B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T
M<B`BQ*S(S\GMM]W*MK'P(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S
M"B,L(&9U>GIY"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R("+,];S^(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E
M+FEN8SHQ,"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM<V=I
M9"`B1&5L971E(@IM<V=S='(@(LF^L_TB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*(RP@9G5Z>GD*;7-G
M:60@(D1E;&5T92!#96QL(@IM<V=S='(@(LF^L_TB"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L971E
M($=R;W5P(@IM<V=S='(@(LF^L_W3P[NGU^DB"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-#D*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!,;V<B
M"FUS9W-T<B`BR;ZS_2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z-S<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@
M(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@(LF^L_W(J,_>(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E
M;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`BR;ZS_:&BQ^6_U=/*
MO/XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R
M("+)OK/](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&-O;'5M;B(*
M;7-G<W1R("+)OK/]T\.[I]?I(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M-#@*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@
M=&5M<&QA=&4B"FUS9W-T<B`BLN7(Z[_)S.:T^L2CL.8B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T
M<B`BR;ZS_2`G)7,GM<3(J,_>(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HT,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T
M92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I
M;VYS/R(*;7-G<W1R("+(M[:HTJK)OK/]("<E<R>UQ,BHS][2U+RPS\*\MLBH
MS]X@/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T
M<B`BR;ZS_=/#NZ?7Z2(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N
M=&ET>2YI;F,Z,34*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I
M9&5N=&ET>2(*;7-G<W1R("+1H=3QR-7&VB(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L
M971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G
M:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*
M;7-G<W1R("*X_-#"L\S0\B`G)7,G(-+1R;ZS_2XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S
M"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(K7=R\W*L;SD(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R("*UI,+S(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E
M('1H92!0<F]B;&5M(@IM<V=S='(@(L[*S.+#Z,KV(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S
M='(@(L/HRO8B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-0IM
M<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G
M<W1R("+/N+W:("C'Z[+.O[P@2&]R9&4@O,?"O,[$O/XI.B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,3DY"FUS9VED(")$971A:6QS(&AA=F4@
M8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("+/
MN+W:Q^NRSK^\S[7-L[G<P.VUQ\*\+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR,3D*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(M'0MZ(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-PIM<V=I9"`B1&5W(%!O:6YT
M(@IM<V=S='(@(L*VM>/.PK;((@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M.30*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B
MU^ZZ\]*[T*'*L;7$PK:UX\["ML@Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,C<*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(L*V
MM>/.PK;(.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G
M<W1R("*TT]?SUL'3TB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T
M(@IM<V=S='(@(K33T]+6P=?S(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R("+$O\*\(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(V-@IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I
M;65S/R(*;7-G<W1R("+2U"`R-"#0H<JQUL;/U,J^/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S
M='(@(L_4RK[1H<_N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.CDV"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T
M(@IM<V=S='(@(L_4RKZX\<J](@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX
M-0HC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G
M<W1R("+/U,J^N/'*O2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,3<*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(L_4RKZX\<J](@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B1&ES
M<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*
M;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(KRJLKS,X2(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N;W0@9&5L971E
M(@IM<V=S='(@(K*[R;ZS_2(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC
M92YP:'`B"FUS9W-T<B`BLKO2JM:QO=.TYLBA(&UA:6YT96YA;F-E+G!H<"(*
M"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$R('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@
M8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B
M;W@Z(@IM<V=S='(@(K7:TKNQRKS'PKS*Q[?QL/RZK-?6ML[#^[/&/R#(Y[G[
MRL?'Z]&AU/$N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T
M<B`BMN##U\3AO-,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$;VUI;FEC86X@4F5P
M=6)L:6,B"FUS9W-T<B`BMN##U\3AO-.YLKK-N?HB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U
M;G0_(%-I9VX@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C@T-`IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B
MS\+4V"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R("+/
MPM38("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B
M1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP
M="XB"FUS9W-T<B`BS\+4V,GZL\FUQ,7DUL/.Q+S^SJH@4$A0(+/,T/(N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O<"!D
M;W=N(&QI<W0B"FUS9W-T<B`BS\+`K;++M:4B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B12U-86EL(@IM
M<V=S='(@(K7GU]/3RKS^(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E
M;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y
M(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V
M:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B
M"FUS9W-T<B`BM.W.\R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS
M9W-T<B`BMO*YS[;@MOLB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="(*;7-G
M<W1R("*QX+RM(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU
M,"!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET($)L
M;V-K(@IM<V=S='(@(K'@O*W'^+_I(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ
M.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS
M9W-T<B`BL>"\K=/#NZ?7Z2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*;7-G
M:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R("*QX+RMR*C/WB(*"B,Z('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`BL>"\K<BHS]XB"@HC.B!S97)V:6-E<R]S:&%R97,O
M961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES
M<VEO;G,@9F]R("5S(@IM<V=S='(@(K'@O*T@)7,@M<3(J,_>(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O
M<CHB"FUS9W-T<B`BL>"\K=&AS^XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C,V-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B161I
M="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(K'@O*T@)7,@M<3(
MJ,_>(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R
M("*QX+RM("5S(+7$R*C/WB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M-0HC+"!F=7IZ>0IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(K78Q_@B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G<W1R("*PH[RP(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B16ET:&5R(&5N86)L92!I="!T:&5N.B`E<RP@;W(@=7-E('1H92!B87-I
M8R!(5$U,('9E<G-I;VXZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*
M;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(LCXMOO-W[;@(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S
M"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD*;7-G:60@(D5M
M86EL(@IM<V=S='(@(K7GU]/3RKS^(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X
M"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(K7GU]/3RKS^M=C6MR(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C,*;7-G:60@(D5M86EL
M(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R("*UY]?3T\J\_K78UK>Q
MV-#KSL>ZSRXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@Y"FUS
M9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("*UY]?3T\J\
M_LBWR,\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P
M+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y
M.`IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(K'MQ^FW^[K%(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS
M9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R("*_U;#7T,6\_BXB"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P"FUS
M9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@(K_5L->]X;G[+B(*"B,Z(&9R
M86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y
M('-E87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-30S"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F
M<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$X"FUS9VED(")%;F%B;&4@<FEG:'0@
M8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,3$*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(L3JM=<B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA
M<F=E($5D:71O<B(*;7-G<W1R("*WQ;3SL>"\K<;W(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(R,0IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q
M=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T
M;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N
M86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I
M9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX.3$*;7-G:60@
M(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<V"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R("*SX+7`O+C$
MVM''(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G<W1R("*V\L&B
MS-C`[]''(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4U
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S8@<V5R=FEC97,O<&]R=&%L+VEN
M9&5X+G!H<#HX,@IM<V=I9"`B17)R;W(B"FUS9W-T<B`BM.W.\R(*"B,Z(&9R
M86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS
M9W-T<B`BM*O+S;O8N+3*L;>BR?JT[<[S.B`E<RXB"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R
M("*TJ\O-N]BXM,JQMZ+)^K3MSO,Z("5S+B(*"B,Z(&9R86UE=V]R:R]496UP
M;&%T92]496UP;&%T92YP:'`Z-#8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(K2KR\V[
MV+BTRK&WHLGZM.W.\SH@)7,N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C<V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U
M<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`BM*O+S;O8N+3*L;>BR?JT
M[<[S.B`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM
M<V=S='(@(K2KR\V[V+BTRK&WHLGZM.W.\SH@)7,N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM
M<V=I9"`B17-T;VYI82(*;7-G<W1R("*PKLFSQ.'1QR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(K"CR/NV[;'(T<<B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S8*(RP@9G5Z>GD*;7-G:60@(D5T:&YI8R(*
M;7-G<W1R("*PKLFSQ.'1QR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(L6WUMXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S
M(@IM<V=S='(@(L._(#$U(+?6UM,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S@Y"B,L(&9U>GIY"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T
M<B`BP[\@-2"WUM;3(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`S,"!S96-O
M;F1S(@IM<V=S='(@(L._(#,P(,/KUM,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S,X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G:60@(D5V
M97)Y(#4@;6EN=71E<R(*;7-G<W1R("+#OR`U(+?6UM,B"@HC.B!F<F%M97=O
M<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R
M>2!,;V=I;B(*;7-G<W1R("+#O[3.M<?"O"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-#`*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R("+#
MOR`S,""WUM;3(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-R!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S@X"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS
M9W-T<B`BP[\@,2"WUM;3(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI
M;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R("*WML#]UK4Z
M(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D;6EN+V-M9'-H96QL+G!H
M<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(W"FUS9VED(")%>&5C=71E(@IM
M<V=S='(@(M:TT-`B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HT-S4*;7-G:60@(D5X<&%N9"(*;7-G<W1R("+5N;^J(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,@HC+"!F=7IZ>0IM<V=I9"`B
M17AP86YD(%-I9&5B87(B"FUS9W-T<B`BQ.JUUR(*"B,Z(&9R86UE=V]R:R]3
M44PO4U%,+TME>7=O<F1S+G!H<#HQ-C@*(RP@9G5Z>GD*;7-G:60@(D5X<&5C
M=&5D("<I)R(*;7-G<W1R("+6M-#0(@H*(SH@9G)A;65W;W)K+U-13"]344PO
M2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R
M('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T
M92(*;7-G<W1R("*UO<;:R-4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8W-@IM<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`BO>++M=2Q
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS,0HC+"!F=7IZ>0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`BU];0
MS='5R:LB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&
M5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(D944"#)S[2KQ>36PRXB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR,38*;7-G:60@(D9A
M:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R("*VP<BAQJNZ
MP\7DUL/*I[#<(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*;7-G:60@(D9A
M:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("+.WK>H
MP:R]TR!,1$%0(+?^SO'&]RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M
M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V
M97(N(@IM<V=S='(@(L[>MZC!K+W3(%--0B"W_L[QQO<N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HV.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(KBTUL;*I[#<
MU]0@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-CDQ
M"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<
M(BXB"FUS9W-T<B`BN+36QLJGL-RUO2!<(B5S7"(N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T
M92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R("+.WK>HO:C!HM*[N/;0
MPK7$(%-!4TP@P:R]TRXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C0Y-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@
M(M+&MJ^UO2!<(B5S7"+*I[#<+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-#8Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@
M=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(M+&MJ^UO2!<(B5S7"+*I[#<+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"B,L
M(&9U>GIY"FUS9VED(")&86ER(@IM<V=S='(@(M3ZTL&V^R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R
M("*WJ,"\O\NXH\BZM;H@*,+MMOO.K,3)R[G(NK6Z*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*
M;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`BMZC"WLBZM;HB"@HC.B!F
M<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X"B,L(&9U>GIY"FUS9VED(")&871A
M;"!%<G)O<CHB"FUS9W-T<B`BT<_6V+3MSO,A(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S
M='(@(K2KU>8B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"B,L
M(&9U>GIY"FUS9VED(")&87AE<R(*;7-G<W1R("*TJ]7F(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U
M87)Y(@IM<V=S='(@(K;^U,(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R
M,`IM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R("*XT+[US_'*QR(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@(D9E96QS(&QI
M:V4Z("(*;7-G<W1R("*XT+[US_'*QSH@(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0*;7-G:60@(D9I96QD(&UA
M=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,S,T"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X"B,L(&9U>GIY"FUS9VED(")&:6=L
M970@9F]N="(*;7-G<W1R("+5TK*[M;W.Q+S^(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I
M9"`B1FEJ:2(*;7-G<W1R("+LL[S#(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")&:6QE(@IM<V=S='(@(L[$
MO/XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(L[$O/[*
M_<2_.B`E<R"X]L[$O/XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*
M;7-G<W1R("+.Q+S^ROW$OSH@)7,@SL2\_B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT,#<*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R("+.
MQ+S^N=S`[<;W(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*;7-G
M:60@(D9I;&4@3F%M92(*;7-G<W1R("+.Q+S^P_NSQB(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Y.34*(RP@9G5Z>GD*;7-G:60@(D9I;&4@<V5L
M96-T:6]N(@IM<V=S='(@(LJQQ_C1H=3Q(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30X-@IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`BSL2\
M_LG/M*LB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-3D*
M;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("+.
MQ+S^R<^TJ[FFQ-S.M+&[UJ>SUBXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z.#D*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`BN?W"R\;W(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R("*WTL"\(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R
M("+)S[#KU,(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K
M+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(LG/
MS]+4PB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-38*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R("*YS+:HL<C`_2(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S$*;7-G
M:60@(D9L:7`B"FUS9W-T<B`BMZW7JB(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@
M97AI<W0B"FUS9W-T<B`BQ+_"O"`E<R"RN[3FU-HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O
M;&]R(@IM<V=S='(@(M?6T,W1U<FK(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@HC+"!F
M=7IZ>0IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I
M;6%G97,B"FUS9W-T<B`BQ/JUQ.2OP,#&][*BSK36I[/6U>*X]KFFQ-PN(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S0*;7-G:60@(D9O<F5C87-T("A4
M048I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HW.0IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R
M971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@
M82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E
M(&)L;V-K*2(*;7-G<W1R("(B"B+4I+&HS.S*_2`HU*2QJ,SLROVP_,"HL-?,
M[-+4O+#2N;SDM<3*_;[=.\CGN?O4I+&HS.S*_;W/LZ2]J]6\T\.QR+W/O^VW
M^;7$L.8B"B+#YBDB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P
M,@HC+"!F=7IZ>0IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S
M='(@(M&AU/'#W,+K(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V
M,@IM<V=I9"`B1F]R;7,B"FUS9W-T<B`BM+#,Y2(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R("++X\/\(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y
M<&4B"FUS9W-T<B`BR^/#_,#@T,TB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(LOCP_PB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,SD*(RP@9G5Z>GD*;7-G:60@(D9O<G1U;F5S
M(#(B"FUS9W-T<B`BR^/#_"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-3,*;7-G:60@(D9O<G5M<R(*;7-G<W1R("+"V\RS(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$P.0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T
M<B`BU]2VK]>JT,4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R("+0Q\;:SN4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S
M"B,L(&9U>GIY"FUS9VED(")&<F%M97,B"FUS9W-T<B`BM+#,Y2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S,*;7-G:60@(D9R86YC92(*;7-G<W1R("*WJ+GZ(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O
M<&]L:71A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@
M1W5I86YA(@IM<V=S='(@(K>HRO2YY]''Q,<B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I
M9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R("*WJ,KTLJ/`^\3ASO?1QR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R
M:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`BO,2\_LC+(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T."!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S8P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HT,#8*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R("*TTR(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS9VED(")&=6QL
M($1E<V-R:7!T:6]N(@IM<V=S='(@(LWJU?O#Z,KV(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U
M;&P@36]O;B(*;7-G<W1R("+"^M3"(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*;7-G
M:60@(D9U;&P@3F%M92(*;7-G<W1R("+(J\/[(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I
M9"`B1V%B;VXB"FUS9W-T<B`BO-/%[B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L
M;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y
M"FUS9VED(")'86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED
M(")'86UB:6$B"FUS9W-T<B`BN-2QR-''(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#
M;VYF:6=U<F%T:6]N(@IM<V=S='(@(K+ZR?H@)7,@M<3/M<VSQ>36PR(*"B,Z
M('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'
M96YE<F%T960@0V]D92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'
M96]R9VEA(@IM<V=S='(@(KCQPK.\JM''(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B
M1V5R;6%N>2(*;7-G<W1R("*UPKGZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA
M;F$B"FUS9W-T<B`BY<C$R2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A
M<B(*;7-G<W1R("+6L;*\PM[-TR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3<U"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(L/[
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3(*;7-G:60@(D=O(@IM
M<V=S='(@(M>JM;TB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G
M:60@(D=O961E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3$R.`HC+"!F=7IZ>0IM<V=I9"`B1V]O9VQE
M($UA<',B"FUS9W-T<B`B1V]O9VQE(,O1R_<B"@HC.B!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(D=O
M;V=L92#+T<OW(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(S-PIM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(KO2ML@B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@(L^CP+`B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y
M+3<I(@IM<V=S='(@(L^CP+#.Q"`H25-/+3@X-3DM-RDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U
M"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`BN/'!ZL"\(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R("*X\<'6Q,FT[R(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*
M;7-G<W1R("+3P[NGU^FYW,#M(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS
M9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R("+3
MP[NGU^G#^[/&LKNUP[_5L-<B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,S`W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U
M<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B075T:%]L9&%P.B#.WK>HT,+4
M]M/#NZ<@)7,N(+?^SO'&][O8TZ8Z(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C$Q."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,3(T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT,3@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L
M92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B075T:%]L9&%P.B#.WK>H
MN/S0PM/#NZ<@)7,B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T
M;R!U<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B075T:%]L9&%P.B#.WK>HN/S0
MPM/#NZ<@)7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q
M-"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(M/#NZ?7Z2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`BN<^UPL+>
MQM6UNB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(KG8M;HB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(LZCM=C"
M[<"M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,@IM<V=I9"`B
M1W5E<FYS97DB"FUS9W-T<B`BN/&V]\[WM;HB"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C@X"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R("*WP[_-R*C/
MWB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S`*;7-G:60@(D=U
M97-T8F]O:R(*;7-G<W1R("*WP[_-P?31U"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@
M(D=U:6YE82(*;7-G<W1R("*\N,3:T<<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@
M(D=U:6YE82U":7-S874B"FUS9W-T<B`BO+C$VM''L<C)W+FRNLVY^B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(KGGT<?$QR(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV,`IM<V=I9"`B2%1-3"(*;7-G
M<W1R(")(5$U,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE
M=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H
M96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(M72LKNUO2!(5%10(-'I
MUJ0N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*;7-G<W1R("*ZH[78
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED
M(")(87-H+4%L9V]R:71H;2(*;7-G<W1R("+4T[35+<OCMZ@B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@HC+"!F=7IZ>0IM
M<V=I9"`B2&%Z92(*;7-G<W1R("*Q[<VW(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.3$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S(*;7-G
M:60@(DAE861E<B(*;7-G<W1R("*Q[<VW(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B2&5A
M9&5R<R(*;7-G<W1R("*Q[<VW(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R
M9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`BNM6UPKK-
MPO2UL<#-R+JUNB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED(")(96)R97<@*$E33RTX
M.#4Y+3@M22DB"FUS9W-T<B`BSZ.RKL"TSL0@*$E33RTX.#4Y+3@M22DB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,T"B,L(&9U>GIY"FUS9VED(")(96EG:'0B"FUS9W-T<B`BS>W)SR(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ-SD@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X-@HC.B!S97)V:6-E<R]H96QP+VEN
M9&5X+G!H<#HQ-R!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B
M2&5L<"(*;7-G<W1R("*P[];Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B
M"FUS9W-T<B`BL>"\K<;WRKG3P[#OUOHB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,S<Q"FUS9VED(")(96QP97(B"FUS9W-T<B`BL._6^B(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HR.0HC+"!F=7IZ>0IM<V=I9"`B2&5M:7-P
M:&5R92(*;7-G<W1R("*QL;#KQ_(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I
M;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`IM<V=I
M9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R
M("+5XL#ORL?.Q+S^M<2_JLJ\.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8Y"B,L(&9U>GIY"FUS9VED(")(:6=H(@IM<V=S
M='(@(LWMR<\B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M
M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*(RP@9G5Z>GD*;7-G
M:60@(DAO7VUE(@IM<V=S='(@(LK7TK,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED
M(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R("+H\[79
MN-0B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U,S4*;7-G:60@
M(DAO;64B"FUS9W-T<B`BRM?2LR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S
M='(@(LK7TK.UV-:W(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"B,L
M(&9U>GIY"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R("+$O\*\(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM
M<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R("+*U]*SM>>[L"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`BNNFVO,"MR[DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R("+6T+GZS^.XVR(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-0IM<V=I9"`B2&]R9&4B
M"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI
M9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E
M<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G
M92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$R-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`BTM&S
MR;FFN+*XQR`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S
M"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R
M97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4P,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@
M6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$R-#<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<
M(CH@)7,B"FUS9W-T<B`B075T:%]L9&%P.B#.WK>HR;ZS_=/#NZ<@)7,B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@
M240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DS"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E
M<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C$S,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`BRZ[&O<_?
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M,@HC+"!F=7IZ>0IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@
M(LNNQKW/WR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#$*(RP@9G5Z>GD*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@
M(LNNQKW/WR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_
M("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0HC+"!F=7IZ>0IM
M<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G
M93\B"FUS9W-T<B`BU]:VSLK]Q+^YLKS&/R(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M
M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`BU]:VSLK]Q+^YLKS&/R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*
M;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,#`@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S`*;7-G:60@(DAU;6ED:71Y(@IM
M<V=S='(@(LJJML@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C4Y"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(LJJML@Z("(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R("+0
MV='`P/LB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*
M;7-G<W1R("))34%0(-/*S^2]J,&BRJ>PW#H@)7,B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G5S+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)S<6PN<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB
M;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("))34%0(-/*S^3)OK/]
MRJ>PW#H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ
M-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I
M;&5D.B`E<R(*;7-G<W1R("))34%0(-/*S^2TQ<7,Q>36P[VHP:+*I[#<.B`E
M<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,38*(RP@9G5Z>GD*
M;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`BM=C6MR(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E<W,@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`B25`@M=C6M\[>MZC*N=/#+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0
M($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S
M='(@(DE0(+78UK>RHK*[U-H@0TE$4B"UQ+W3RMS'^+_IUM`N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS
M9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("*Q^;6Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM<V=I9"`B26-O;G,@3VYL>2(*;7-G
M<W1R("+6N]/0S;RQZB(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S
M='(@(B5S(+7$T:'/[B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S<*
M;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R("+-O+'JO+#.Q-?6(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B261E;G1I='DG
M<R!N86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@
M;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N
M97<@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#4U"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U
M<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K
M("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ-S,*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U
M="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG
M="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C@*(RP@9G5Z>GD*;7-G:60@(DEM86=E(%!R979I97<Z(@IM
M<V=S='(@(M2DP,`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,W"B,L(&9U>GIY"FUS9VED("));6%G92!54DPB
M"FUS9W-T<B`BS;S&K"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B26UA
M9V4@55),.B(*;7-G<W1R("+-O,:L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G
M92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("))
M;6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R
M("+)S[2KS;S&K"(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED
M("));6%G97,B"FUS9W-T<B`BS;S&K"(*"B,Z('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P
M("5D(@IM<V=S='(@(KOCR.LL(+*]UN@@)60B"@HC.B!T96UP;&%T97,O9&%T
M82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E
M9"!F:65L9#H@)7,B"FUS9W-T<B`BN^/(Z]?6MLXZ("5S(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S
M.B(*;7-G<W1R("*[X\CKU]:VSCHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@
M4F]W($%F=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]Z:7`N<&AP.C$S-0IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C
M;V1E(&=I=F5N+B(*;7-G<W1R("+*Y,CKLKO5_<BWM<37]]/#PNLN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*
M(RP@9G5Z>GD*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S
M<W=O<F0N(@IM<V=S='(@(LZTUJJUQ-/#NZ?#^[ORP]S"ZRXB"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T
M('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@
M8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R
M=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E;G0B
M"FUS9W-T<B`BU/:\T\OUQ<4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DEN9&EA
M(@IM<V=S='(@(M.AML@B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B
M26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R("*X]K'PT\.[IR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(M.AMLC$X<[WT<<B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS
M9VED("));F9O(@IM<V=S='(@(M#%SZ(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C4W"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("+0Q<^B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,S,`IM<V=I9"`B
M26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!);6%G92(*;7-G
M<W1R("*RY<CKT\J\_B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("*R
MY<CKL>VX\2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("*RY<CK
MS?C"Y\&LO=,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU
M;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM
M<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@
M;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W(')O
M=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS
M9VED("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@
M869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G
M:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D
M92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I
M9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("*RY<CKO\G,
MYK3ZQ*.PYB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,SD*;7-G:60@
M(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C
M96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X"B,L(&9U
M>GIY"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R("*RY<CKT\J\
M_B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3D*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*
M;7-G<W1R("*RY<CKL>VX\2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@
M869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B
M969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R
M("*RY<CKT\J\_B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A
M9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A
M<&@@8F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*(RP@9G5Z>GD*;7-G:60@(DEN
M<V5R="!R;W<@869T97(B"FUS9W-T<B`BLN7(Z['MN/$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"B,L(&9U
M>GIY"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R("*RY<CKL>VX
M\2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@(DEN<V5R
M="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO
M;CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G
M<W1R("*RY<CK+['DN/S-O,:L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK
M(@IM<V=S='(@(K+ER.LOL>2X_,WXPN?!K+W3(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F
M9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI
M<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U
M"FUS9VED("));G1E9V5R(@IM<V=S='(@(M7[ROTB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3,S"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T
M<B`BU?O*_<'0(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T
M82!(96%D97(I+B(*;7-G<W1R("+.WM"GM<0@541(*-/#NZ?*_;[=L>W-MRDN
M(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3<P
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(P,0HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,3`*(RP@
M9G5Z>GD*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`BSM[0I[7$
MS?+3P\+KROV^W2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS
M9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R("+.WM"GM<33IM/#
ML\S0\BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@
M(L[>T*>UQ,7ZM,ZZQ<+K+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(P.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R.3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H
M<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B
MS.&]N[7$ROV^W<[>T*<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED(&1E<W1I;F%T
M:6]N(&%D9')E<W,N(@IM<V=S='(@(L[>T*>UQ,2_L>K7H=:W(@H*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z.#$*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3`P"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(R,`IM<V=I9"`B26YV86QI
M9"!F:6QE(&9O<FUA="(*;7-G<W1R("*RN[K/MZBUQ,[$O/ZX\<J](@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-PHC+"!F=7IZ>0IM<V=I
M9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`BSM[0I[7$TZ;3P[/,
MT/(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,0HC+"!F
M=7IZ>0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T
M<B`BSM[0I[7$TZ;3P[/,T/(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T
M>7!E+B(*;7-G<W1R("+.WM"GM<0@;7-G7W1Y<&4N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("))
M;G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R("+.WM"GM<2[\M72
MLKNUO2!A<&E?:60N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@
M<&%R86UE=&5R<RXB"FUS9W-T<B`BSM[0I[7$N_+5TK*[M;VRSLK]+B(*"B,Z
M(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI9"!P
M87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`BLKNZS[>HM<2XN,BHS]XN(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,PHC+"!F=7IZ>0IM
M<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R("*RN[K/MZBUQ+BX
MR*C/WBXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"B,L
M(&9U>GIY"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T<B`B
MSM[0I[7$S:C1MM"MTNDN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L
M+B(*;7-G<W1R("+.WM"GM<3-J-&VT*W2Z2XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R("+.WM"GM<2P
MYK&^NL7"ZR(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`W-B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-C(*(RP@9G5Z>GD*;7-G:60@
M(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(K*[NL^WJ+7$SL2\_KCQ
MRKTB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S
M='(@(L[>T*>UQ,"TU+37H=:W+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC
M;V1E(&1A=&$N(@IM<V=S='(@(L[>T*>UQ,WRT\/"Z\K]OMTN(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U-PIM<V=I9"`B26YV96YT;W)Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HV-SD*(RP@9G5Z>GD*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS
M9W-T<B`BO/3'T-&AU/$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES
M;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`BTL'`RM+!R[G`O+FRNLVY^B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("+2P<"MO\LB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`BL*ZV^\"\(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@
M;V8@36%N(@IM<V=S='(@(L+\M;HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T
M<B`BTM3)J\'0(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV,C4*;7-G:60@(DES<W5E<B(*;7-G<W1R("+'J;>BU=\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET
M86QI8R(*;7-G<W1R("+0L<SE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))=&%L
M>2(*;7-G<W1R("+2XK3SP/LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I
M8V$B"FUS9W-T<B`BT<#"\KS3(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`BTKO4
MPB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`B2F%P86X@
M*,C5L;XI(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(DIA
M<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`BR-7.Q"`H25-/+3(P,C(M
M2E`I(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*;7-G:60@
M(B(*(DIA=F%S8W)I<'0@:&%S(&)E96X@9&ES86)L960@;VX@>6]U<B!B<F]W
M<V5R(&%N9"!T:&ES('!A9V4@;6%Y(&YO="!B92`B"B)D:7-P;&%Y:6YG(&-O
M<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R("+4\\[WM;HB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R("+4O+6I(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU
M;'DB"FUS9W-T<B`BQM_4PB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(L'YU,(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,X"B,L(&9U>GIY"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(K^_U_.VU,;K
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(M;#UM`B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(M?ST]*VU,;K
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("*_O]?SMM3&
MZR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(K^_T]*V
MU,;K(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@
M(KG^R/B_R\NYS+DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C8T"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G<W1R("*Q
MH\'TU*W1^2`_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R
M("*_S\3AT<<B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U
M"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(DME<F)E<F]S(,C/UJ2T[<[S+B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS
M9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`BP]S4O[VHP:(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG
M97)P<FEN="(*;7-G<W1R("+#W-2_S-C5]R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R
M("+#W-2_LZ2VR"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`BP]S4O\#@T,TB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM<V=I9"`B2V5Y
M(%5S86=E(@IM<V=S='(@(L/<U+_3[[>H(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@
M;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(K6QQ["UQ+FKOZK#
MW-2_M_[.\<;WUM`LTM&^K;3FU-K$^K7$P]S4ORXB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R("*[^<#OL,W+N;FRNLVY
M^B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O
M<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`BLZ_/RB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(KJKN?HB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B2V]R96%N("A%54,M
M2U(I(@IM<V=S='(@(KJKSL0@*$550RU+4BDB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G
M:60@(DMU=V%I="(*;7-G<W1R("*_QLW^S-@B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`BO*JV^[RJR[G,N2(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;65N=2YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B3&%?>6]U
M="(*;7-G<W1R("*PYL/FQ>36PR(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(M/OT=0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B
M;&EC(@IM<V=S='(@(L#/SLXB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y
M"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`BS\*PZ]3"(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C<V"B,L(&9U>GIY"FUS9VED("),87-T(%!A<W-W
M;W)D($-H86YG92(*;7-G<W1R("+#W,+K.B`B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U
M87)T97(B"FUS9W-T<B`BS\+/TM3"(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-3$*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`BR<^TSKC\T,(Z
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M
M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(LG/TKNTSK7'PKPZ
M("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S(Q"B,L('!H<"UF
M;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`B
MR<_2N[3.M<?"O#H@)7,@U]0@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HW,38*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(LG/
MTKNTSK7'PKPZ(+7:TKNTSK7'PKPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQA
M='9I82(*;7-G<W1R("+`K<W1SJS1QR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y
M;W5T(@IM<V=S='(@(K#FP^;%Y-;#(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R
M(&YO(&)O<F1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE
M8F%N;VXB"FUS9W-T<B`BP.BPS<3;(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"B,L(&9U>GIY"FUS9VED("),
M969T(@IM<V=S='(@(M?STL8B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,3$Y"FUS9VED("),969T(&AE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$U"B,L(&9U>GIY"FUS9VED("),969T
M('9A;'5E<R(*;7-G<W1R("*_U;#7UK4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@
M(DQE<V]T:&\B"FUS9W-T<B`BP+/+]\W0(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED("),979E;"(*;7-G<W1R
M("*TT\ZT(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@
M(L#[L<C`[]''(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*
M86UA:&ER:7EA(@IM<V=S='(@(L#[L<C1QR(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I
M9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("+!T-:GMMC*O[7'(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*(RP@9G5Z>GD*
M;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`BM:W`MB(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"B,L(&9U>GIY"FUS
M9VED("),:6=H="!286EN(@IM<V=S='(@(K7'PKPB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I
M;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B
M3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*(RP@9G5Z>GD*;7-G
M:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`BM:W`MB(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W
M(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#4*(RP@9G5Z>GD*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(L#[L<C`[]''
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-`IM<V=I9"`B3&EN
M:R(*;7-G<W1R("+!K+W3(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T
M;SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W
M-0IM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S
M92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED
M("),:6YK<R(*;7-G<W1R("+!K+W3(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI
M<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("+!T+/V("T@
MT\.[I[_)TM2_M+6]U>*X]L[$O/Z\T"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,S,*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4P"FUS9VED("),:7-T($AE;'`@5&]P
M:6-S(@IM<V=S='(@(L'0L_;+M</WL>K,XB(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,S(*(RP@9G5Z>GD*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@
M(K+ER.NQ[;CQ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("+,UL+;T\.[I]?I
M+<[$O/ZY\2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3@Y"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`BS-;"V]/#NZ?7Z2W'\];Z
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.38*;7-G
M:60@(DQI<W0M260B"FUS9W-T<B`BS-;"V]/#NZ?7Z2W*MK'PNL7"ZR(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),
M:7-T+4]W;F5R(@IM<V=S='(@(LS6PMO3P[NGU^DMT[73T-7?(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M
M4&]S="(*;7-G<W1R("+,UL+;T\.[I]?I+;S$O/[(RR(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C
M<FEB92(*;7-G<W1R("+,UL+;T\.[I]?I+;:IU,0B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C
M<FEB92(*;7-G<W1R("+,UL+;T\.[I]?I+<BAS_NVJ=3$(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("),
M:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`BP="S]M/#NZ>U
MQ+FFQ-RQN[G8L=4B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E
M<R(*;7-G<W1R("+!T+/VT\.[I[7$N:;$W+&[N=BQU2(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R
M<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`BP="S]M/#NZ>UQ+FFQ-RQN[G8L=4B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R871U
M<F4B"FUS9W-T<B`BSL31IR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&ET:'5A
M;FEA(@IM<V=S='(@(L&BS-7-\"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEM86=E<RYP:'`Z.#,*(RP@9G5Z>GD*;7-G:60@(DQO861I;F<N
M+BXB"FUS9W-T<B`BU-C(Z[JORKV_XM;0+BXN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Q,0IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S
M='(@(K6QM=C*L;SD.B`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*
M;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R("*UV,?XT^O*L;SD(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C8T"B,Z(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C8U"FUS9VED("),;V-A=&EO
M;B(*;7-G<W1R("*UV,?X(@H*(SH@;&]G:6XN<&AP.C$W,B!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,3DQ('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@
M(K7'PKPB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G
M:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$X-0IM<V=I9"`B3&]G
M(&]U="(*;7-G<W1R("+7HL_Z(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C4Y"FUS9VED("),;V=I;B(*;7-G<W1R("*UQ\*\(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P-PHC+"!F=7IZ>0IM<V=I9"`B3&]G:6X@5&%S:W,B
M"FUS9W-T<B`BP:R]TR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY
M-@IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O
M<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B
MM<?"O,JGL-PL(,?KO.RRZ<3ZM<33P[NGP_NZS</<PNLL(,B[NO/6V,K4+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,@IM<V=I9"`B3&]G:6X@
M9F%I;&5D+B(*;7-G<W1R("*UQ\*\RJ>PW"XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S8U"B,L(&9U>GIY"FUS9VED("),;VYG('1E>'0B"FUS
M9W-T<B`BUZ+/^B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`HC+"!F
M=7IZ>0IM<V=I9"`B3&]V92(*;7-G<W1R("+)OK/](@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(DQO=R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B
M"FUS9W-T<B`BPJS)K;&D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#,X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED
M(")-32(*;7-G<W1R("+4PB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR.#$*;7-G:60@(DU/5$0B"FUS9W-T<B`BP[_(U=#%SZ(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M
M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")-
M4RU43D5&(+B]O-/.Q+S^UM##N]/0ROV^W2XB"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W
M"FUS9VED(")-4T<B"FUS9W-T<B`B35-'(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED
M(")-86-A;R(*;7-G<W1R("+6T+GZL,3#Q2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I
M9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(L+MQN2VV;FRNLVY^B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B
M36%D86=A<V-A<B(*;7-G<W1R("+"[;3OO-/+N;S3M;HB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#D*(RP@9G5Z>GD*;7-G:60@(DUA9VEC(@IM<V=S
M='(@(L+MP/LB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#$*;7-G
M:60@(DUA:6PB"FUS9W-T<B`BT\J\_B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HU,C(*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`BT\J\_KG<
MP.TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDT"FUS9VED(")-86QA=VDB"FUS9W-T<B`BPNW`K<W^(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R("+"[<"TSO?1
MQR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`BPNVV
M^[3ZM_(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA;&DB"FUS9W-T<B`BPNW`
M^R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L=&$B"FUS9W-T<B`BPNVV^LO[
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ"FUS9VED("(B"B)-86YA
M9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I
M=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S
M92!C871E9V]R:65S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U,PIM<V=I9"`B36%P,C0@;6%P(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,#@T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,38X"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG
M<R!S=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G<W1R("+(_=3"
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT,0HC+"!F=7IZ>0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(L+MS.'$
MX;_+M;HB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S
M='(@(K'JO,>SR2"_M+G]+\ZTO[2Y_2(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@
M9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R("*QZKS'
ML\G&Y,O\M<3*MK'P("C`_<CG+B#6V-*J+]+1N]BXM"DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3$*;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`BPNW)W+;[R+JU
MNB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R("+"
M[<SAQ.&_R[6Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*
M;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R("+5_=3:QJ7%Y-?6MLXB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`BPZO`
M[\O^Q.'1QR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S
M='(@(L.KP._'\\NY(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC
M965D960N(@IM<V=S='(@(KB]O/[*_<2_TM&SK+/VO=/*W,G/S]XN(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@
M,C0@:&]U<G,Z("(*;7-G<W1R("+7[KW\(#(T(-"ARK&UQ-?NN-_.PK;(.B`B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y.`IM<V=I9"`B36%X('1E;7`@
M;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`BU^Z]_"`V(-"ARK&UQ-?NN-_.PK;(
M.B`B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@
M;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-87AI;75M
M(&QE;F=T:"(*;7-G<W1R("*]T\K<U^ZT\[.DML@B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S
M='(@(L[EU,(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S
M='(@(L+MU+S,V,BZM;HB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*
M(RP@9G5Z>GD*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(M"[OO@B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB
M97)S(@IM<V=S='(@(K/)U+$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S<X"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(M&AM:7$H\J].B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP
M:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED
M(")-97-S86=E(@IM<V=S='(@(M/*O/XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE
M9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C
M;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(M/*O/[1Z=:DTM'-
MZK/)++6KRL?3P[NGM<3'J</[R+3.WK>HS:BY_='IUJ0N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED
M(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(M#%SZ+2T;G]QMHN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,#(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(V,`IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(M#%SZ+`
MX-#-(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"B,L(&9U>GIY"FUS9VED
M(")-971A<B!796%T:&5R(@IM<V=S='(@(K6QQ[#,[,;X(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B365T87(@Q_B_Z<[>MZC*N=/#+B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3$R"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@
M879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R(")-971A<B#'^+_ISMZWJ,JYT\,N(,^X
MO=K'Z[+.O[S/M<VSN=S`[;7'PKPN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$V-0IM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C=&5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R("*WO;>H(@H*(SH@9G)A;65W;W)K
M+U)00R]24$,O>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)00R]S;V%P
M+G!H<#HQ,3<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<
M(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`BM[VWJ"`G)7,G(,ZTL;NV
MJ-+E(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T
M:&]D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-0IM<V=I9"`B365T<FEC
M(@IM<V=S='(@(KFKUL8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*
M;7-G<W1R("+$J\[WN.<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I
M82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R("+#W+_+PM[$X<[WT<?!
MJK#NN?HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S8*(RP@9G5Z>GD*;7-G:60@(DUI9&1L92(*;7-G<W1R("+$
MH[_I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z
M,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R(")-:6UE(,#@T,TB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,Q,`IM<V=I9"`B36EN('1E;7`@;&%S="`R
M-"!H;W5R<SH@(@IM<V=S='(@(M?NO?P@,C0@T*'*L;7$U^ZUS<["ML@Z("(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`R"FUS9VED(")-:6X@=&5M<"!L
M87-T(#8@:&]U<G,Z("(*;7-G<W1R("+7[KW\(#8@T*'*L;7$U^ZXW\["ML@Z
M("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED
M(")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,S0*;7-G:60@(DUI<G)O<B(*;7-G<W1R("+3L\GD(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%14
M4%]297%U97-T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3$U"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H
M879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI
M<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`BQ>36P\[$O/[2Q<JG+B#(Y[G[
MTJK*N=/#U>*X]M.FT\.SS-#RQ/JQV-#KS];4VK[-LOK)^LO[+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM
M<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R("+5TK*[M;W0Q<^B
MM<0@240N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P
M86-K86=E($UA:6PN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S
M97-S:6]N($E$+B(*;7-G<W1R("+5TK*[M;V[X<;:M<0@240N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B
M36\B"FUS9W-T<B`BT,?&VM*[(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C<T"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R("+0T+:OT\J\_B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"B,L
M(&9U>GIY"FUS9VED(")-;V1E<F%T92(*;7-G<W1R("+#R<S8R/O`K<S8(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#@*;7-G:60@(DUO9&EF:65D
M($1A=&4B"FUS9W-T<B`BN/S0PLC5QMHB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF
M>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-S,*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`BQ*._Z2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`BQ*:V^[;@S=\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G
M<W1R("+$IL3)N.<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM
M<V=S='(@(L/)N<4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DT
M"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R("+4PKK-Q.HB"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED
M(")-;VYT:&QY(@IM<V=S='(@(L._U,(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@
M(DUO;G1S97)R870B"FUS9W-T<B`BP\G,V,C[P*W,V"(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O
M;B!0:&%S97,B"FUS9W-T<B`BU,+!P=.OO_<B"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HQ-S(@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M,C4S"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN
M(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R("+$IL+EN.<B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I
M9"`B36]S=&QY($-L96%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`Y"FUS9VED(")-
M;W9E($1O=VXB"FUS9W-T<B`BS\+2QB(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C4Q,PIM<V=I9"`B36]V92!,969T(@IM<V=S='(@
M(M?STL8B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU
M,3<*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`BT]+2QB(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P-0IM<V=I9"`B36]V92!5
M<"(*;7-G<W1R("+)S]+&(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(L_"
MTL8B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3(S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU
M,C0*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`BR<_2QB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R("+$JLFCL<B_RR(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#0*(RP@9G5Z>GD*;7-G:60@(DUU
M;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R("+/PL"MLLNUI2(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#4U
M"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,@IM<V=I9"`B375L=&EP;&4@<V5L96-T
M:6]N(@IM<V=S='(@(KBTT:$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#`P"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(L[2M<35R[K%(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"B,L(&9U>GIY"FUS9VED(")-
M>2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(L3ZM<30Q<^B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HU-`IM<V=I9"`B37D@4&]R=&%L
M(@IM<V=S='(@(L[2M<3#Q;NG(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N
M<&AP.C$S-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R("+.TK7$
MP\6[I]*SP^;%Y-;#(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM
M<V=S='(@(L/EM>DB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S
M='(@(K*[+,[2LKO-K-+B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z
M,S@*;7-G:60@(DYA;64B"FUS9W-T<B`BP_NSQB(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM
M<V=I9"`B3F%M:6)I82(*;7-G<W1R("+$R</7L<C1QR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`BZ*?"LR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM
M<V=I9"`B3F5P86PB"FUS9W-T<B`BQ.&RM+;[(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS
M9VED(").971H97)L86YD<R(*;7-G<W1R("*ZR<"\(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*
M;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(KK)RO2PLK78
MP=#+N2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q
M"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R("*[^=/:3F5T<V-A
M<&4@M<3-^-:W(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.#,*(RP@9G5Z>GD*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@
M55),(@IM<V=S='(@(KOYT]I.971S8V%P92"UQ,WXUK<B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-0HC+"!F=7IZ>0IM<V=I9"`B
M3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R("*[^=/:3F5T<V-A<&4@
MM<3-^-:W(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.#0*(RP@9G5Z>GD*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S
M='(@(KOYT]I.971S8V%P92"UQ,WXUK<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X,@HC+"!F=7IZ>0IM<V=I9"`B3F5T<V-A<&4@
M4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`BN_G3VDYE='-C87!E(+7$S?C6MR(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED
M(").971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B3F5T<V-A<&4@
M4U-,(+?^SO'&]\/[L\8B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N
M="(*;7-G<W1R(").971S8V%P92#(S]:DM<3%^M>B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#`*;7-G:60@(DYE='-C87!E(&-E
M<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B3F5T<V-A<&4@R,_6I,#@T,TB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Q"FUS9VED(").971W;W)K
M(@IM<V=S='(@(LWXPN<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-0HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S@V"FUS9VED(").979E<B(*;7-G<W1R("*TT\ZT
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDU"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S='(@
M(M#"OZ;`[[;@Q.'1QR(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E
M9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C(V"B,L(&9U>GIY"FUS9VED(").97<@0V%T96=O
M<GDB"FUS9W-T<B`BT,*_IL#OMN#$X=''(@H*(SH@9G)A;65W;W)K+U1E>'1?
M1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R86UE=V]R:R]497AT
M7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F<F%M97=O<FLO5&5X
M=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@9G)A;65W;W)K+U1E
M>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`BT,7/
MHL#@T,TB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO
M;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-
M;V]N(@IM<V=S='(@(M#"U,(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*
M;7-G<W1R("+0PM/#NZ?#^R`HM\>QV-*J*2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I
M9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`BT,+.]\"\(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED(").97<@<&%S
M<W=O<F0B"FUS9W-T<B`BP]S"ZR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D
M('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-3(*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S
M=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(L/<PNNQV-#KSL>ZSRXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS
M9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(M#"M+"_VB`H7V)L
M86YK*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y
M"FUS9VED(").97=S(@IM<V=S='(@(M#"SL4B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S`U"B,L(&9U>GIY"FUS9VED(").97=S9W)O=7!S(@IM
M<V=S='(@(M/#NZ?7Z2(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@(L_"TKNRO2(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B3F5X="`T(%!H87-E
M<R(*;7-G<W1R("+/PM*[TK,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C,W,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W-@IM
M<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(L_"TKNX]M&AS^XB"@HC.B!F
M<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I9"`B
M3F5X=#XB"FUS9W-T<B`BS\+2N[*](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").
M:6-A<F%G=6$B"FUS9W-T<B`BQ.&\T\"MN<\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G
M:60@(DYI9V5R(@IM<V=S='(@(L3AR-6V^R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I
M9"`B3FEG97)I82(*;7-G<W1R("+$X<C5P/O1QR(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS.#`*;7-G:60@(DYI9VAT(@IM<V=S='(@(LWM
MR<\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYI=64B"FUS9W-T<B`BQ::PH[6Z
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV
M,PHC+"!F=7IZ>0IM<V=I9"`B3F\B"FUS9W-T<B`BSMXB"@HC.B!T96UP;&%T
M97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L
M92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<BYP:'`Z,3`U"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R
M(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO
M(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HW.2!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HR-#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,C8W"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E
M<W1E9"!P;W-I=&EO;B(*;7-G<W1R("++^=:XMJBUQ,Z[UL/)S\.[T]#'^+_I
MM.;4VB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-3`*;7-G
M:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(L.[T]#,X;FIR-7`^L/[L\;2U+FI($U#04P@
MT>G6I"XB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`HC+"!F=7IZ>0IM
M<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R("+.M+'DN/PN(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*(RP@9G5Z>GD*;7-G:60@(DYO
M(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM
M<V=S='(@(K6QQ[#+^;2FM<35XKCVM<B\ML[>MZC4]KS3M,[(J,_>+B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38W(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z-3`R"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<W
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(L.[T]#6N+:HM<0@
M)7,@Q>36P]#%SZ(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX
M,C0*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R("+#N]/0UKBVJ+7$($944"!61E,@
MQ>36P]#%SZ(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-CD*
M;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B!344P@5D93+B(*;7-G<W1R("+#N]/0UKBVJ+7$(%-13"!61E/%Y-;#
MT,7/HBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S$W
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("+#N]/0UKBVJ+7$(%-13"U&
M:6QE(%9&4\7DUL/0Q<^B+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,T"B,L(&9U>GIY"FUS9VED(").;R!D97-T:6YA=&EO
M;B!S=7!P;&EE9"XB"FUS9W-T<B`BP[O3T,/HRO8B"@HC.B!F<F%M97=O<FLO
M0G)O=W-E<B]"<F]W<V5R+G!H<#HX-S<*;7-G:60@(DYO(&9I;&4@=7!L;V%D
M960B"FUS9W-T<B`BSL2\_LZTR<^TJR(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S
M='(@(L.[T]##Z,KV(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$R."!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ,C,*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T
M<B`BSKO6P]#%SZ+)T,ZTQ>36PR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I
M9&5D+B(*;7-G<W1R("+.N];#T,7/HLG0SK3%Y-;#(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*(RP@9G5Z>GD*
M;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(M#%SZ+2T;G]
MQMHN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S8*(RP@9G5Z>GD*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*
M;7-G<W1R("+.M-:XMJBUL;78T^_1U"XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PHC+"!F=7IZ>0IM<V=I9"`B
M3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`BSK36N+:HM;&UV-/OT=0N
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED(").;R!O9F9E
M;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(L.[T]#6N+:HP]S"
MZ]+4N:D@2%144"#1Z=:D+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA
M<"YP:'`Z,3`X"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!
M4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BP[O3T-:XMJC#W,+KTM2YJ2!)
M34%0(-'IUJ0N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW
M,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+#N]/0UKBVJ,/<PNO2U+FI($ME<F)E
M<F]S(-'IUJ0N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HW
M-R!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BP[O3
MT-:XMJC#W,+KTM2YJ2!,;V=I;B#1Z=:D+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(L.[T]#6
MN+:HP]S"Z]+4N:D@4$%34U=$(-'IUJ0N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+#N]/0UKBVJ,/<PNO2
MU+FI(%--0B#1Z=:D+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B
M:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A
M<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B
M3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R("+#N]/0M/W)\[7$UZ*RX<GJ
MQ^LN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C<U,`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R("+.N];#
MT,7/HLG0SK3%Y-;#(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT,PHC+"!F=7IZ>0IM<V=I9"`B3F\@<G5L97,B
M"FUS9W-T<B`BO]6PU]:U(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z-#0Y"B,L(&9U>GIY"FUS9VED(").;R!S97!A<F%T;W(@<W!E8VEF:65D
M+B(*;7-G<W1R("+.M-:XMJBUL;78T^_1U"XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T"B,L(&9U>GIY"FUS
M9VED(").;R!S:61E<R(*;7-G<W1R("*QN,W\PKPB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C4X,PIM<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,S@*;7-G
M:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H
M92XB"FUS9W-T<B`BSM[4W;3FQ+_"O+_)N:F_[,BA+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"B,L(&9U>GIY"FUS
M9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T
M<B`BSK36JK7$T\.[I\/[N_+#W,+K+B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#
M+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI9"!834P@9&%T82!R971U
M<FYE9"(*;7-G<W1R("+#N]/0NL^WJ+7$(%A-3"#*_;[=L;NTJ[O8(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW,0HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY.3(*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#D*;7-G:60@
M(DYO('9A;'5E<R(*;7-G<W1R("*_U;#7UK4B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I
M;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`BU*W*O,7DUL/.Q+S^UM#5TK*[M;VPYK&^T,7/HBX@UMC0PK+Z
MR?K%Y-;#SL2\_BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(X"FUS
M9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@
M4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+4VL3ZM<3%Y-;#
MSL2\_M;0U=*RN[6]L.:QOM#%SZ(N(-;8T,*R^LGZQ>36P\[$O/XN(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M
M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PIM<V=I9"`B3F]N
M92(*;7-G<W1R("+.WB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DYO
M<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(LC5MOK"_,[$("A)4T\M.#@U
M.2TQ,"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM
M<V=S='(@(L6UN*._R[6Z(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI
M8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R
M92(*;7-G<W1R("*QL;#KQ_(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H
M97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("*QL<+MP._1Q\3)R+JUNB(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(L6RS?XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B
M3F]T($%F=&5R(@IM<V=S='(@(K?'UJZZ\R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(").;W0@0F5F;W)E(@IM<V=S
M='(@(K?'UJ['L"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0P
M.`IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(K*[RL?2N[CVQ+_"
MO"(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z
M-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.30*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"B,L(&9U>GIY"FUS9VED(").
M;W0@:6UP;&5M96YT960N(@IM<V=S='(@(LG0SK3*M<_6+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*
M;7-G:60@(DYO="!S970B"FUS9W-T<B`BL;C-_,*\(@H*(SH@9G)A;65W;W)K
M+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#,*(SH@9G)A
M;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-3@*
M(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H
M<#HQ-S,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+G!H<#HQ.#<*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I
M;VY(86YD;&5R+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y,`HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`U(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(T."!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z,C8U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR
M.#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(Y-PHC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z,S$R(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,CD*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C,V,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M-#(R"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU,#$@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C4W,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3@W(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HV-C4*;7-G:60@(DYO="!S=7!P;W)T960N
M(@IM<V=S='(@(LZTL;O6I[/6(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`P
M-0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3<X"FUS9VED(").;W1E
M<R(*;7-G<W1R("*QN,W\PKPB"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E
M>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`BRJ[2N]3"(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`T-@IM<V=I9"`B3G5M8F5R(@IM
M<V=S='(@(LK]U]8B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U
M"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R("+7UK?[ROTB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30T-2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`BU]:VSLK]Q+\B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30T,R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`BL<K*_2(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS
M9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I
M<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@
M(D]+(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@W,PHC+"!F=7IZ>0IM<V=I9"`B3V)J96-T(@IM<V=S='(@(M;WUKPB"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T
M($-R96%T;W(B"FUS9W-T<B`BMM3/\[VHP:+5WR(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(K#+O?C.
MNR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T
M"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(LJNU,(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C8*;7-G:60@(D]F
M9FEC92(*;7-G<W1R("*P[+FKRM(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T
M(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C,V"B,L(&9U>GIY"FUS9VED(")/;&0@<&%S<W=O<F0B
M"FUS9W-T<B`BP]S"ZR(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`BL*+"
M_"(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S
M"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD
M97)S+B(*;7-G<W1R("+6N]/0($E-05`@M_[.\<;WUJ>SUL[$O/Z\T+FRS^VY
MIL3<+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL
M>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.3<Q"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM
M<V=S='(@(M:[O=/*W-*[N/;3RKS^M=C6MRXB"@HC.B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y
M<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W
M;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(M:[T]#3
MM=/0U=_3Z\^US;.YW,#MU+&_R=+4L>2X_+FRS^W(J,_>(@H*(SH@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z,S4*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W
M(@IM<V=S='(@(M3:T,*TL+_:UM"T\K^J(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O
M=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-0HC+"!F=7IZ>0IM<V=I9"`B3W!E;G,@=&AI
M<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("+4VM#"M+"_VM;0M/*_
MJB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T
M:6YG(%-Y<W1E;2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED
M96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(M&AS^XB"@HC
M.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS
M9W-T<B`B)7,@M<31H<_N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@
M(L_NQ+^QX+K%(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-C<*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R("+7Z=:O(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R
M9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`BU^G6K[6ESKLB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,R"B,L(&9U>GIY"FUS9VED(")/<F=A
M;FEZ:6YG(@IM<V=S='(@(M?IUJ\B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS
M9W-T<B`BU*W*O-.FT\.SS-#RQ*.PYB(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E
M<R!I;B`E<SHB"FUS9W-T<B`BU-H@)7,Z(-;0M<34K<J\Q*.PYBXB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O
M87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`BQN3+_"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3`V"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3,@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$R,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,Q(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#$*;7-G:60@(D]T:&5R($EN9F]R;6%T
M:6]N(@IM<V=S='(@(L;DR_S0Q<^B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B
MT[73T-7?R*C/WB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW
M.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(E!!32#1Z=:DSM[0IRXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@
M8F%C:V5N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,C<S"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS
M9W-T<B`B4$=0(,K]U];'J</[(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3,Q.0IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S
M='(@(E!'4""\T\/<U\K!SR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$S-S$*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(E!'
M4""YJ[^JP]S4OR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$S-3,*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T
M<B`B4$=0(-+1QZG#^R_2T;S3P]P@U\K!SR(*"B,Z(&%D;6EN+W!H<'-H96QL
M+G!H<#HV.`IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B4$A0(+/,T/*T^L+K
M(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB
M"FUS9W-T<B`B4$A0(+W%L;XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M.`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4VYO=R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT,`IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED
M(")032!3=6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@(E!/4TE8
M(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN
M<&AP.C$T.0HC+"!F=7IZ>0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R(")0
M2%`@O<6QOB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R("*PS;OYR[G,N2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(L7!P,TB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C
M8W5P:65D(@IM<V=S='(@(K#-P-7+N<RYL;O5O,'LQ_@B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3@*;7-G:60@(E!A;F%M82(*;7-G<W1R("*PS<3#PNTB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`BL,VRO-''T,*\
MN,3:T<<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R
M("*PS<"MN><B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS-@IM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U
M,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS9VED
M(")087-S=V]R9"(*;7-G<W1R("+#W,+K(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E
M<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HQ,S(R"B,L(&9U>GIY"FUS9VED(")087-S=V]R9"!I;F-O
M<G)E8W0B"FUS9W-T<B`BP]S"ZSH@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R
M(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BP[O3T-:XMJC#W,+K
MTM2YJ2!2041)55,@T>G6I"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#4S"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G
M<W1R("+#W,+KR+?(SR(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(L/<PNLZ(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B
M"FUS9W-T<B`BP]S"ZSH@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S0*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N
M(@IM<V=S='(@(L/<PNNQV-#KSL>ZSRXB"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3$Y('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`BS/G)SR(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@
M(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(LSYR<\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0
M871H(@IM<V=S='(@(L*WOK8B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A
M<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E
M9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R("*T_<GS
MM<?"O*.Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"B,L(&9U>GIY
M"FUS9VED(")096]P;&4B"FUS9W-T<B`BO<?)JR(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E($]P97)A
M=&EO;G,B"FUS9W-T<B`BUK30T,ZLNZ2RV=?W(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0P-@IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R
M871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R("*UQ\*\NO/6M-#0SJR[I++9U_<_
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@
M(E!E<FUI<W-I;VXB"FUS9W-T<B`BR*C/WB(*"B,Z(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E!E<FUI
M<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R("(G)7,G(+7$R*C/
MWLZTL;O)OK/]+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@V
M"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("*TYLBAU.*^W"(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*
M;7-G<W1R("+(J,_>(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D
M;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E
M>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R
M;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`BR*C/WKG<P.TB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*;7-G:60@(E!E<G-O;F%L($EN
M9F]R;6%T:6]N(@IM<V=S='(@(L[2M<0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@
M(E!E<G4B"FUS9W-T<B`BP]C"LR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU-0HC+"!F=7IZ>0IM<V=I9"`B4&5T<R(*;7-G<W1R("+7J+"X(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R("*WQL+)L?8B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV
M"FUS9VED(")0:&]N92(*;7-G<W1R("*UY[NP(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0W.`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(M75QJPB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R("+&I,S8
MO[6UNB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U
M('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N
M;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(U-S$*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H
M(&%N9"!A('EE87(N(@IM<V=S='(@(L?KRN3(Z]*[N/;4PK?=O+#$ZK?=+B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R
M"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@
M;F5W(&-A=&5G;W)Y.B(*;7-G<W1R("+'Z\KDR.O2N[CVU,*WW;RPQ.JWW2XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Q"B,L(&9U>GIY"FUS
M9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R
M("+'Z\KDR.NZS[>HM<3*L;SD+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(V-C`*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H
M96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@
M(L?KRN3(Z]*[N/:ZS[>HM<3(U<;:.]&AU/&TR]3"M]VUQ,C5QMHN(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,0IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`BQ^O*Y,CKNL^WJ+7$RK&\Y"XB
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0
M;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S
M='(@(L?KS.&YJ<[*S.*UQ-6JTJHN(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED
M(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*
M;7-G<W1R("+'Z\KDR.O$^K7$T\.[I\/[O+##W,+K(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C4X"B,L(&9U>GIY"FUS9VED("(B"B)0;&5A<V4@
M<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@
M=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("+'Z]3$
MML'/PL'0Q-K(W2[$^K'8T.O-K-+BU>+0J<K"S^ZRQ<3<RKG3P\^US;,N(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93HB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0;VQA;F0B"FUS9W-T
M<B`BLJC`O"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PHC+"!F=7IZ
M>0IM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`BS;;&L2(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT.#<*;7-G:60@(E!O;&QS(@IM<V=S='(@(LVV
MQK$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R("+&
MS\S1T<`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@
M:6UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@
M=&%B;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO
M="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R("*UW<O-T\J\_K6]U>*X]L[$
MO/Z\T"`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I
M.B`B"FUS9W-T<B`BU^Z]_"`E<R#0H<JQM<2]M=/JP;\Z("(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3@*;7-G:60@(E!R96-I<&ET871I
M;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E
M9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7VQD
M87`Z(-72LKNUO<OYT.C2JK7$($Q$05`@P*G5N=?IO/XN(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S
M97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(E!R969S7W-E<W-I;VXZ(-72LKNUO<OYT.C2JK7$('-E<W-I
M;VX@P*G5N=?IO/XN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C4*;7-G
M:60@(E!R97-S=7)E(@IM<V=S='(@(L;XT;DB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(U.0IM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS
M9W-T<B`BNJ/&O</FQOC1N3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(S-0IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R("+&^-&Y.B`B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`U
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R("+4I,#`(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(T"B,L(&9U>GIY"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A
M(&YE=R!W:6YD;W<B"FUS9W-T<B`BU-K0PK2PO]K6T+3ROZHB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V,B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C,V-@IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G
M<W1R("+)S]*[N/;1H<_N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS
M9VED(")0<FEV871E($ME>2(*;7-G<W1R("++O</<P]S4OR(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@
M(E!R;V)L96TB"FUS9W-T<B`BSLK,XC\B"@HC.B!S97)V:6-E<R]P<F]B;&5M
M+G!H<#HQ,C8*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B
MSLK,XL/HRO8B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S8Y"FUS
M9VED(")0<F]J96-T<R(*;7-G<W1R("+7J+"X(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@X
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#4*;7-G:60@(E!R;VUP
M="!T97AT(@IM<V=S='(@(LSARK[$VLC=(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@
M(KFKOZK#W-2_(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(KFK
MOZK#W-2_T=W+XR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C0T"B,L(&9U>GIY"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T
M<B`BN:N_JL/<U+\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HR-#$*;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R
M871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(KFKOZHOR[W#W,/<U+^VU+*B
MSK2QN[+ZR?HN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B
M"FUS9W-T<B`BLJBVX,#HN/<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1871A
M<B(*;7-G<W1R("*_J,O^MOLB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C,*
M(RP@9G5Z>GD*;7-G:60@(E%U97)Y(@IM<V=S='(@(LK]OMV_XK+IT:\B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(E%U
M;W1A(@IM<V=S='(@(K^HR_ZV^R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C8S"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L
M:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(E)302"YJ[^JP]S4OR`H)60@SKLI
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-`IM<V=I9"`B4F%D
M:6\@<V5L96-T:6]N(@IM<V=S='(@(K6ET:$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PHC+"!F=7IZ>0IM<V=I9"`B4F%I
M;B(*;7-G<W1R(")3<&%I;B`HSO>PX-'`*2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN($5A<FQY(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0U"B,L(&9U>GIY"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`BRJ7"
MK,[WT<>UNB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0V"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I9"`B4F%I
M;B!A;F0@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"B,L(&9U>GIY"FUS
M9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R("++X\/\(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2871I;R(*;7-G<W1R
M("*QR,+*(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M.#`*;7-G:60@(E)E860B"FUS9W-T<B`BML'(H2(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"FUS9VED(")296%D(&UE<W-A
M9V5S(@IM<V=S='(@(K;!R*'3RKS^(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D
M96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM
M<V=S='(@(M7FM<32JLF^L_T@)7,@PO`_(-7BS^ZRV=?WO:O.WK>HN]:XM"XB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@
M9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N
M(@IM<V=S='(@(M7FM<32JLF^L_T@)7,@PO`_(-7BS^ZRV=?WO:O.WK>HN]:X
MM"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("+(
MH<_[N+34K2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(E)E9G)E<V@@
M1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S0Q"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W
M.B(*;7-G<W1R("++HM#"P\6[I\K3S;PZ(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#DT(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-0IM<V=I9"`B4F5G97@B"FUS
M9W-T<B`BN>;4\K'MM._*O2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,R-#D*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR,#@*(RP@9G5Z>GD*;7-G:60@(E)E;&]A9"(*
M;7-G<W1R("*VP<BA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C8*;7-G
M:60@(E)E;6%R:W,B"FUS9W-T<B`BQL#"VR(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,30*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(M2V
ML\RW_L[QQO<B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*
M;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R
M9&4I.B(*;7-G<W1R("+4MK/,S?C6MR`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O
M;2]H;W)D92DZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S"FUS9VED
M(")296UO=F4B"FUS9W-T<B`BR;ZS_2(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHQ,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(LF^
ML_W'^+_I(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C4U-PHC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R
M("+)OK/]T\.[IR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#`*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!F;W)M871T:6YG
M(@IM<V=S='(@(LF^L_VVU"(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R("+)OK/]MM0B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")296UO=F4@<V%V
M960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB
M"FUS9W-T<B`BU]2W_L[QQO?4W;3FQ+_"O-;0R;ZS_=+1L:.TYK7$Q>36P[/,
MT/(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0R"B,L(&9U>GIY"FUS9VED(")296UO=F4@=&AE(@IM<V=S
M='(@(LF^L_W3P[NG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N;V1E
M(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U<V5R(@IM
M<V=S='(@(LF^L_W3P[NG(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E
M<R(*;7-G<W1R("+)OK/]T\.[ISH@)7,B"@HC.B!F<F%M97=O<FLO4E!#+U)0
M0R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A
M;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`BT.C'\\ZT
ML;O/[-.F.B"T[<[SNL7"ZSHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,34W"B,L(&9U>GIY"FUS9VED(")297%U97-T960@<V5R=FEC92!C
M;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(LG/M*O.Q+S^LJ+.M+&[L:.T
MYBXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-"!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B)3(D<R"UQ,7DUL.QV-#KUKBVJ"`G)3$D
M<R<B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W-2!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C@S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z-S(S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")2
M97%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B5D93(+7$Q>36P['8T.O6N+:H("<E<R<B"@HC.B!F
M<F%M97=O<FLO571I;"]5=&EL+G!H<#HW.#$*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(L7DUL/*_;[=L=C0Z]:XMJ@@)R5S)R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I
M9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R,"!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(M;8R>@B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@HC+"!F=7IZ>0IM<V=I9"`B4F5S
M970@4&%S<W=O<F0B"FUS9W-T<B`BP]S"ZR(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C(W"B,L(&9U>GIY"FUS9VED(")297-E="!9;W5R(%!A
M<W-W;W)D(@IM<V=S='(@(LBWR,_#W,+K(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$S,`HC+"!F=7IZ>0IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM
M<V=S='(@(L_"S]+4PB(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI
M;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP.C8V"FUS9VED
M(")297-U;'1S(@IM<V=S='(@(KWAN?LB"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G
M:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(K>UN]C1H<_N(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"B,L(&9U>GIY"FUS9VED
M(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(M&AU/'#W,+K(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R(")2975N:6]N("C!
M],3AS?JUNBDB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(E)E=F5R="!#
M;VYF:6=U<F%T:6]N(@IM<V=S='(@(K+ZR?H@)7,@M<3/M<VSQ>36PR(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S(*(RP@9G5Z>GD*;7-G:60@(E)I
M8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R("*WM;O8T:'/[B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S`*(RP@9G5Z>GD*;7-G:60@(E)I9VAT(@IM<V=S='(@(LWM
MR<\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(Q"FUS9VED(")2
M:6=H="!H96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S$Q-PHC+"!F=7IZ>0IM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S
M='(@(K6MP+8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(KW'R:LB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(E)O;6%N:6$@*,+>PNW$
MX=''*2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,C4*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`BT/W7JB`Q.#`@ML@B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(R
M"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R("+/\M?ST/W7JB(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C@*;7-G:60@
M(E)O=&%T92!2:6=H="(*;7-G<W1R("+/\M/2T/W7JB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@
M(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P
M<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4S"B,L(&9U>GIY"FUS9VED(")2=6QE<R(*;7-G<W1R("*]Q\FK(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W
M<R!A;F0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL
M>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P"FUS9VED
M(")2=6XB"FUS9W-T<B`BUK30T"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U
M<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R(")2=7-S:6%N($9E9&5R871I;VX@
M*+;MPM[+N2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B"FUS9W-T
M<B`B4G=A;F1A("C"K+"RM.\I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I
M9VYA='5R92(*;7-G<W1R(")3+TU)344@O-/#W,>IP_LB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N
M8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(M/*O/[2T<JYT\,@4R]-24U%(+S3
MP]PB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q"FUS9VED
M(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(E-!4TP@T>G6I,[>T*<N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C4P-`IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R("+0Q<^B(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS
M9W-T<B`BROV^W;_BO<6QOB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,R.#,*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,0IM
M<V=I9"`B4U-((@IM<V=S='(@(KS3P]S6U;;+N_HB"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(K/)N:8B"@HC.B!L:6(O87!I
M+G!H<#HQ-3,*(RP@9G5Z>GD*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B
MROV^W;_BO<6QOB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(M#'QMK!^2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R("+*I;K5P-7$
MP[6Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V
M:7,B"FUS9W-T<B`BRJ6[^;7"NLW!T,ZLR[DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G
M:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(LJEPJS.]]''M;HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S
M='(@(LJEQJ2PH[;[NLW"\[_+PM?(NK6Z(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I
M9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B
MRJ7.Q,FMS-BZS;CQP=;$R;3O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I
M(@IM<V=S='(@(LVLTKNX]K2PO]H@*%]S96QF*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*
M;7-G:60@(E-A;6]A(@IM<V=S='(@(LCXQ*;1QR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*
M;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`BRJ7"[<&FQ;4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`W"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B
MRJ6VX,/`NLW&U<'6SO>QR"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R("+.
MP-#'S.&YJ=7?(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA
M(@IM<V=S='(@(LFSS-BPHL"MLJXB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA
M>6]U="YI;F,Z.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`BL:.TYB(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(K&CM.8@)7,B
M"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(K&CM.8@)7,B"@HC.B!T96UP
M;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS
M9W-T<B`BL:.TYM&AS^XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W
M"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@
M4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E
M8W1O<GDN(@IM<V=S='(@(KVKLOK)^K7$Q>36P\[$O/[2U"!02%`@T^_1U+CQ
MRKVQH[3FM;W$^K7$M_[.\<;WU-VTYL2_PKS6T"XB"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E
M<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+%Y-;#("5S(-+1L:.TYBXB"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB
M)7-<(BXB"FUS9W-T<B`BN/S0PK/,T/+2T;&CM.:UO3H@)R5S)RXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B
M4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(LO1
MT;`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(P"B,L(&9U>GIY
M"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R("++T=&P(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW,PHC+"!F=7IZ>0IM<V=I9"`B4V5L
M96-T($9I;&5S(@IM<V=S='(@(M&AU/'2N[CVR-7&VB(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0*;7-G:60@(E-E;&5C
M="!A(&1A=&4B"FUS9W-T<B`BT:'4\=*[N/;(U<;:(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O
M(&%D9"(*;7-G<W1R("+1H=3QTKNX]M/#NZ?7Z=/#TM30PM3V(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W
M(&]W;F5R(@IM<V=S='(@(M&AU/'2N\Z[T,*UQ-.UT]#5WR(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R
M=F5R(@IM<V=S='(@(M&AU/'2N[*_M_[.\<;W(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D
M(@IM<V=S='(@(M&AU/'2N\Z[T\.[I]/#TM30PM3V(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PHC+"!F=7IZ>0IM<V=I
M9"`B4V5L96-T(&%L;"(*;7-G<W1R("+1H=3QTKNX]LC5QMHB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8S"FUS9VED(")396QE8W0@86QL(&1A
M=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`BT:'4\<OYT]#(U<;:U^F\_BXB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(M&AU/'2
MN\Z[T,*UQ-.UT]#5WR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-S@*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!N;VYE(@IM
M<V=S='(@(M&AU/'2N\Z[T,*UQ-.UT]#5WR(*"B,Z('-E<G9I8V5S+VME>6)O
M87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO
M=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P
M>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N(@IM<V=S
M='(@(M/:TM3/PK7$M+"_VM;0T:'(H<3ZTJJUQ-?6M_LNTM3*\['JN+36QLOY
MT:'.Q-?6+,B[NO/,^<G/SL2\_K'@O*W'^"XB"@HC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E
M<CHB"FUS9W-T<B`BT:'4\<C5QMJWUKCT.B(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*
M;7-G<W1R("+1H=3QR-7&VLC5QMJX\<J].B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E
M;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE
M(&1E;&EM:71E<CHB"FUS9W-T<B`BT:'4\<JQO.2WUKCT.B(*"B,Z('1E;7!L
M871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@
M9F]R;6%T.B(*;7-G<W1R("+1H=3QR-7&VLJQO.2X\<J].B(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T
M8VAI;F<@9FEE;&1S+B(*;7-G<W1R("+1H=3QS^"[I<:EQ>2UQ+;^N/;7UK;.
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#8*;7-G:60@(E-E;&5C
M="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`BT:'4\<3ZM<31U<FKQ>36
MPR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#@*;7-G:60@(E-E;&5C
M="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`BT:'4\<:KNL/3
M[]'4.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS
M9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(K2KR\W.RLSBM[33
MIB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#,Y"FUS9VED(")396YD(%--4R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V
M"FUS9VED(")396YE9V%L(@IM<V=S='(@(E-E;F5G86P@*,C[Q-J\T[;[*2(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$V"FUS9VED(")396YS;W(Z("(*
M;7-G<W1R("*TJ[C0QO<Z("(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T<B`BOL74
MPB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS
M9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B4V5R8FEA(&%N
M9"!-;VYT96YE9W)O("C(^[;[SJS1Q]/KP\G,V,3AN.?"WBDB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B4V5R:6%L
M($YU;6)E<B(*;7-G<W1R("+0\KK%(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$V,0HC+"!F=7IZ>0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O
M;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B365T87(@Q_B_Z<[>MZC*
MN=/#+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR-PHC+"!F=7IZ>0IM<V=I
M9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R("+(J,_>N=S`[2(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I
M9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R("*[X<;:($E$(-+1N?W&
MVBXB"@HC.B!L:6(O87!I+G!H<#HQ-#4*(RP@9G5Z>GD*;7-G:60@(E-E<W-I
M;VYS(@IM<V=S='(@(LBHS]XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S$T"FUS9VED(")3970B"FUS9W-T<B`BQ>36PR(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW-@IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@
M>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T
M(&ET+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U
M"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T
M;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`BQ>36P]2VL\RW
M_L[QQO?)S\KTT]K$^K7$N/;(R]6^S*@N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@T"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L
M('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(L7DUL/$^K7$
MQJNZP]/OT=0L(,JQQ_C2U+RPR-7&VKCQRKTN(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDX"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI
M8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T
M:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`BQ>36P\3ZM<3&],J\
MTZ;3P[/,T/(LT=7)J\7DUL,LTK/#YKC\T,+&M<+*++RPQN3+_,_4RK[1H<_N
M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*(RP@9G5Z>GD*;7-G
M:60@(E-E='5P(@IM<V=S='(@(L7DUL,B"@HC.B!T96UP;&%T97,O861M:6XO
M<V5T=7`O:6YD97@N:'1M;#HS-PHC+"!F=7IZ>0IM<V=I9"`B4V5T=7`@=7!G
M<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R("*X_-#"L\S0\M+1L:.T
MYK6].B`G)7,G+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M.#8*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE
M('!A<F%M971E<CH@(@IM<V=S='(@(M/0NL.\N+CVM=BUX[K-U>*X]K+.ROW3
MT+G8.B`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S
M='(@(E-E>6-H96QL97,@*,C[SO2V^RDB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#DV"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R("*YNL[O(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H
M;W)T(%-U;6UA<GDB"FUS9W-T<B`BO/*VS-6JTJHB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#0V"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@
M9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`BRL>W\<ZJM/.RO[?=
MM<3!K+W3MJC2Y;_LO=VYIL3<O/P_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`BS]3*OB(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@
M9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N
M97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y,`IM<V=I9"`B4VAO=R!L87-T
M(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R("+#O[3.M<?"
MO+KSS]3*OLG/TKNTSK7$M<?"O,JQO.0@/R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$W-C4*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I
M9VEN86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@Q,PIM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`BS]3*OK7CT:'&]R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C8*;7-G:60@(E-H;W<@=&%B
M;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W
M('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R("+3VM?SL=_/U,J^
M("5S(+++M:4_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL
M(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B
M4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G
M92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-S8S"B,L(&9U>GIY"FUS9VED(")3:&]W('5P;&]A
M9"(*;7-G<W1R("+.Q+S^R<^TJR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4P"B,L(&9U>GIY"FUS9VED(")3:&]W97)S(@IM
M<V=S='(@(L_4RKXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU,0HC+"!F=7IZ>0IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G
M<W1R("*\\K;,U:K2JB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G
M:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0X,`IM<V=I9"`B4VAR
M:6YK(@IM<V=S='(@(LK5R_4B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HW-S0@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z.#,V"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDR
M,B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY.#0*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`T-R!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#@W"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C$Q,38@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z,3$T.0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB
M;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R
M(")3:65R<F$@3&5O;F4@*,JHU]/)O;GZ*2(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HR-C4*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B
MUZ*RX2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R
M"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`BQZG#^R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$Q"FUS9VED(")3:6=N871U<F4@
M06QG;W)I=&AM(@IM<V=S='(@(L>IP_O1W<OC(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM
M<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(E-I;F=A<&]R92`HT,*\T\;"*2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@W(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$U
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,P
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*;7-G:60@(E-I>F4B
M"FUS9W-T<B`BM//0H2(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN
M=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S
M='(@(L+4N?W.K+ND(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B
M"FUS9W-T<B`B4VQO=F%K:6$@*,NYPN6WI;_+*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*
M;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(E-L;W9E;FEA("C+N<+EMZ7$X=''
M*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T
M"B,L(&9U>GIY"FUS9VED(")3;F]W(@IM<V=S='(@(L_4RKXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO
M=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M-PIM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3
M;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(W.`IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(KO]T:G)
M[K;(.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM<V=I9"`B4VYO
M=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(E-O;&]M;VX@
M27-L86YD<R`HR_?"WL/%R+JUNBDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3
M;VUA;&EA(@IM<V=S='(@(E-O;6%L:6$@*,OWPNW`^]''*2(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(V"FUS9VED
M(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R("+%Q<'0M[W/\M&AU/$B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R("+`M-2T
MM=C6MR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G
M<W1R(")3;W5T:"!!9G)I8V$@*,3/M\<I(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.3`*;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(*
M;7-G<W1R("+$S\6W("A)4T\M.#@U.2TS*2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I
M9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N
M9',B"FUS9W-T<B`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W
M:6-H($ES;&%N9',B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L
M;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM
M<V=S='(@(L3/L.O'\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT
M(&-E;&QS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E
M;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Q-0HC+"!F=7IZ>0IM<V=I9"`B4W!A8V5R(@IM
M<V=S='(@(L"LN_C3RKS^(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@P"B,L(&9U>GIY"FUS9VED(")3<&%C:6YG
M(@IM<V=S='(@(E-P86EN("C.][#@T<`I(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN
M9R!A;F0@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B
M4W!A:6XB"FUS9W-T<B`B4W!A:6X@*,[WL.#1P"DB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@(E-P86TB"FUS9W-T<B`BP*R[^-/*
MO/XB"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I
M86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(LS8RN+7UK?[RN3(ZR(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B
M4W!L:70@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O
M=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*(RP@
M9G5Z>GD*;7-G:60@(E-P;W)T<R(*;7-G<W1R("+6I[/6(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B4W)I($QA;FMA("C+N<#O
MP+R_J"DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S,@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HW-`IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B
ML>K7O"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@HC+"!F=7IZ>0IM
M<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(L;TRKS$ZK?=(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.#`Y"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(L;TRKS$ZK?=(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@
M(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(LJA(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G
M<W1R("+7M,RL(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-0IM
M<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`BL:.TYKCQRKTB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,@IM<V=I9"`B4W1R
M965T($%D9')E<W,B"FUS9W-T<B`BO=:UP"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U
M9V@B"FUS9W-T<B`BR;ZS_<_?(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`BU]:W^[2NP=`B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I
M<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS
M9VED(")3='EL92!;0U-372(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R
M("+0Q\;:S.PB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T
M(&9O=6YD+B(*;7-G<W1R("+5TK*[M;T@)7,N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*
M;7-G<W1R("+6]]:\(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R
M(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PIM<V=I9"`B
M4W5B;6ET(@IM<V=S='(@(LSAO;LB"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<
M(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL
M('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(L_"L>HB"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3`T"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E
M<W,B"FUS9W-T<B`BL\FYIB(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E
M<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@(K/)N::\T\CK("<E<R<@M;W/
MM<VSUM`N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U
M<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(K/)N:;7U,^U
MS;/6T,F^L_T@)R5S)R`N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI
M;B]P97)M<R]D96QE=&4N<&AP.C0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S='(@(K/)
MN:;)OK/]("<E<R<@+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E
M<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`BL\FYIM?4S[7-L];0R;ZS
M_2`G)7,G("XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED
M(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D
M('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*(RP@9G5Z
M>GD*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`BQ>36PR`E<R#2T;&CM.8N(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@7"(E<UPB
M(@IM<V=S='(@(K/)N::X_-#"("<E<R<B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`BTM&S
MR;FFN+*XQR`E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N(@IM<V=S
M='(@(E-U9&%N("C+U;6D*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T
M<B`BU:K2JB(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B
M4W5N(%)I<V4B"FUS9W-T<B`BR-6S]B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R("+(U<+D(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*(RP@9G5Z>GD*
M;7-G:60@(E-U;FYY(@IM<V=S='(@(E-U9&%N("C+U;6D*2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(E-U;G)I<V4B"FUS
M9W-T<B`BR-6S]B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS
M9W-T<B`BR-6S]B_(U<+D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(Q-0IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(LC5L_8Z("(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3D*;7-G:60@(E-U;G-E
M="(*;7-G<W1R("+(U<+D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(Q.`IM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`BR-7"Y#H@(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I
M9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`BR<^QZB(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-S@*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`BUJ>S
MUB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(E-U
M<FEN86UE("C+U<#[Q,\I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S0*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`BM,*ZQ2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS
M9W-T<B`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*
M;7-G:60@(E-W87II;&%N9"(*;7-G<W1R(")3=V%Z:6QA;F0@*,JWS=^\P\"\
M*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R(")3=V5D
M96X@*,CPM>0I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM
M<V=S='(@(E-W:71Z97)L86YD("C(\,J_*2(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C@V"B,L(&9U>GIY"FUS9VED(")3>6YC(&QO9R!D96QE
M=&5D(@IM<V=S='(@(K*[R;ZS_2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-#(*;7-G:60@(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I
M;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I
M9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B4WER:6%N($%R86(@
M4F5P=6)L:6,@*-#PP/O1QRDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I
M9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@
M(E0M4W1O<FUS(@IM<V=S='(@(K2PS.4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;7,@16%R;'DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$V
M-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B5$%"(+?6N/2X\<J]SL2\_B(*
M"B,Z(&9R86UE=V]R:R]522]522]486)L92YP:'`Z,3,T"B,L(&9U>GIY"FUS
M9VED(")486)L92(*;7-G<W1R(")496%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@
M4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS9VED(")486)L92!3970B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-"!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS9W-T<B`B
MS*C-Y2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X
M"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(LRH
MS>4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S='(@
M(E1A:FEK:7-T86X@*,O^O*K+N<RY*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@
M(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B5&%N>F%N
M:6$L(%5N:71E9"!297!U8FQI8R!O9B`HS+G)T,3AT<<I(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R
M9V5T.B(*;7-G<W1R("+$O['J.B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES
M=#HY.38@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X-PIM<V=I9"`B5&%S
M:W,B"FUS9W-T<B`BM/VP[,K"S^XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G
M<W1R("*UY[NPNL7"ZR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP"FUS
M9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("+7[KW\TKO0H<JQ
MM<3.PK;(.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-`IM<V=I9"`B
M5&5M<&5R871U<F4B"FUS9W-T<B`BSL*VR"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,C,*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T
M<B`BSL*VR#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI
M)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]4
M96UP;&%T92]496UP;&%T92YP:'`Z-C@W"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("+5
MTK*[M;W$H[#F("<E<R<N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*
M;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(L2CL.:Y
MW,#M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,S,V"FUS9VED(")497AT(@IM<V=S='(@(L3:
MR-TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<U"FUS9VED(")497AT
M($]N;'DB"FUS9W-T<B`BM+_.Q-?6(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`HC+"!F=7IZ>0IM<V=I9"`B
M5&5X="!A;&EG;B(*;7-G<W1R("*TO\[$U]8B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"B,L(&9U>GIY"FUS9VED(")4
M97AT=&]P(@IM<V=S='(@(L3:R-TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R("+0Q\;:
MR\0B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B5&AA:2`H
M5$E3+38R,"DB"FUS9W-T<B`BS*G.Q"`H5$E3+38R,"DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R(")4:&%I;&%N9"`HS*FY^BDB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@(E1H86YK
M('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`BT+O0N\3ZRKG3
MP[&^S[7-LRXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R,`IM
M<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B1E10(-'3R>PH97AT96YS:6]N*<[>T*<N(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P
M;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O
M24U34"]";V]K+G!H<#HQ,CDR"B,L(&9U>GIY"FUS9VED(")4:&4@24U34"!L
M;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R("+)S[2KSL2\
M_K*BSK2QN[&CM.8N(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q
M"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@
M<W5C8V5S<V9U;&QY(@IM<V=S='(@(DUA:6YT96YA;F-E(,#@L?"RHLZTL\FY
MIM38R.LB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y
M"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN
M9RXB"FUS9W-T<B`BT:'/[K2PO]K2U+G8L=4NP.N_JM;0+B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4R
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O
M<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@
M8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@
M=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N
M9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0HC+"!F=7IZ>0IM<V=I
M9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R
M(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`BS:C1MLK]OMW2T;/)N::UQ-3VO-.U
MO<3ZM<3-J-&VLK[6T"[3P\KSL>JPM,_"P=#/[L2_TM2\[,K3.B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-CD*;7-G:60@(B(*(E1H
M92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O
M('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(M'IUJ33RKS^
MQZG#^]#HTJK3T-*[N/;2T;WBOZJUQ"!01U`@Q_B_Z2XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B
M(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P
M96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A
M=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T,@HC+"!F=7IZ>0IM<V=I9"`B5&AE(&1I
M<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R("*T
MR]?WT\/.M+&[UJ>SUBXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP
M.C$Q,PIM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A
M('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`BT.C2JM*[N/:^K;G]
MO-/#W+7$S?C"Y\&LO=,N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ-S4@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S
M971T:6YG+B(*;7-G<W1R("+.Q+S^("5S(-.FN,.P_+JLTKNX]B`E<R#%Y-;#
M+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38X(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM
M<V=S='(@(L[$O/X@)7,@TZ:XP[#\NJS2N]"I("5S(,7DUL,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C$Y"B,L(&9U>GIY"FUS9VED(")4
M:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T
M<B`BM,O.Q+S^UM##N]/0ROV^W2XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A
M+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*
M;7-G<W1R("*TR\[$O/[6T,.[T]#*_;[=+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I
M;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE
M<W-A9V4N(@IM<V=S='(@(M+4S\+*QR!R9F,X,C(@T\J\_K7$L>W-MRXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS
M9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S
M92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@
M8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U
M;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL
M(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S
M97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@
M:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B
M"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN
M66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@
M>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY,`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@
M8F5E;B!D96QE=&5D+B(*;7-G<W1R("*TR[?^SO'&]R!<(B5S7"(@TM&QN\F^
ML_TN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W
M"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M
M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T
M<B`B1VYU4$<@MO[4JL[$O/ZUQ,*WOK:QV-#KMJC2Y=3:($-R>7!T7W!G<#HZ
M(,#@L?#6T"XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`Q
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@
M)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y
M960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E
M(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM<V=I9"`B5&AE(&YA;64@
M=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T,0HC+"!F
M=7IZ>0IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE
M<FEC+B(*;7-G<W1R("*QV-#KRL?2N[CVROW7UBXB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S$*;7-G:60@(E1H92!O<&5N<W-L
M(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE
M.CH@8VQA<W,N(@IM<V=S='(@(DAO<F1E7T-R>7!T7W-M:6UE.CH@P."Q\"RQ
MV-#HTJK3T"!O<&5N<W-L(,2CO^DN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E
M<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D
M871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM
M<V=S='(@(K3+QJNZPR!<(B5S7"(@ROV^W=+RSJJSK+G]U^ZT\[W3RMS6M2S+
M^=+4SMZWJ+&[L:.TYB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O96YS
M8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS
M<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E
M8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<W)C
M:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P
M<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N
M;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`BT\/2U+SLRM.TR\K]
MOMW`X-#-("@E<RD@M<2SS-#RLJ*RN[3FU-K3VL^US;/)SRXB"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-30*;7-G:60@(E1H92!Q=6]T92!C
M:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED
M92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C0T-@IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG
M;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R
M(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("*TR[?^SO'&]R!<
M(B5S7"(@TM&QN\F^L_TN(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP
M:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@
M:&%S(&)E96X@<V%V960N(@IM<V=S='(@(K3+M_[.\<;W(%PB)7-<(B#2T;&[
ML:.TYBXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO
M=F5D+B(*;7-G<W1R("(E<R"UQ->BLN'0Z,?STM&QN\F^L_TN(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,S,P"FUS9VED(")4:&4@
M<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`BUKBVJ+7$
MO,?"O+*BLKNTYM3:+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M,3<W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y
M(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("+6N+:HM<2\
MQ\*\LJ*RN[3FU-HN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Q
M,0IM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T
M:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED
M(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1&%T82]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E
M9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G
M<W1R("*TT\G/TKNX]K*]UNC6KKKSR<^TJ[7$ROV^W=+%RJ<N(@H*(SH@9G)A
M;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$
M871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L
M9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(LG/M*O.Q+S^LJ+.M+&[L:.TYBXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#8@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C4V"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ,34@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q.0IM
M<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(G=E871H97(N8V]M(,?XO^G.WK>HRKG3PRXB"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T
M<B`BU=*RN[6]Q*.PYB`G)7,G+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,3<X"B,L(&9U>GIY"FUS9VED(")4:&5R92!A<F4@;F\@;W!T
M:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(DUE=&%R(,?XO^G.WK>HRKG3PRXB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HS-#(*;7-G
M:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@
M:6YL:6YE+B(*;7-G<W1R("+.WKB]O/Z_R=:QO=.T\K^J+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L
M9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S
M="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(K3+U]:VSM;0L/RZK,RK
MMN"UQ-?6ROTNQ/K2T<KDR.L@)7,@N/;7ULK].\3ZRN3(Z[7$U];*_;'8T.O0
MH=/:("5S+B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L
M96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R("+0
MPM3V("<E<R<@M;W/M<VS.B`E<R#*L;>BR?K2N[CVSLK,XBXB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S
M7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`BU]3/M<VSR;ZS_2`G)7,G
M(,JQMZ+)^M*[N/;.RLSB.B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R
M96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`BU]3/
MM<VSR;ZS_2`G)7,G(,JQMZ+)^M*[N/;.RLSB.B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$U.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@(KC\T,(@
M)R5S)SH@)7,@RK&WHLGZTKNX]L[*S.(B"@HC.B!F<F%M97=O<FLO0G)O=W-E
M<B]"<F]W<V5R+G!H<#HX.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S
M('5P;&]A9&5D+B(*;7-G<W1R("+)S[2KSL2\_LJQMZ+)^M*[N/;.RLSB.B`E
M<R#.M+&[R<^TJRXB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HX.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@
M=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB
M"FUS9W-T<B`BR<^TJ\[$O/[*L;>BR?K2N[CVSLK,XCH@)7,@M//0H;.LN?V]
MT\K<U^ZT\]:U("@E9"!B>71E<RDN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O
M0G)O=W-E<BYP:'`Z.#DQ"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W
M87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(LG/M*O.Q+S^
MRK&WHLGZTKNX]L[*S.(Z(+WVLK^WUK7$("5S(,[$O/ZQN\G/M*LN(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E
M('!A<G0B"FUS9W-T<B`BO.S*T]/*O/[*L;>BR?K2N[CVM.W.\RXB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N
M(@IM<V=S='(@(KOCR.NTR\VHT;:ROLK]OMW*L;>BR?JT[<[S+B(*"B,Z(&9R
M86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A
M=&$N(@IM<V=S='(@(KOCR.NTR\VHT;:ROLK]OMW*L;>BR?JT[<[S+B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#`*;7-G:60@(B(*(E1H97)E('=A
M<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S
M('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("+4
MVL7DUL.TL,SEUM"WHLGZP<O2N[CVM.W.\R[3T+_)Q-S$^M+%PJG!R['8T.O,
M[M"TM<37UK;.+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO
M;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*
M(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+B(*;7-G<W1R("*[X\CKM,O-J-&VLK[*_;[=RK&WHLGZM.W.\RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,@HC+"!F
M=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H
M92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB
M"FUS9W-T<B`BN^/(Z[3+S:C1MK*^ROV^W<JQMZ+)^K3MSO,N(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4
M:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD
M97)S+B(*;7-G<W1R("*TRR!)34%0(+?^SO'&][*BSK36I[/6SL2\_KS0M];/
M[;FFQ-PN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI
M9"!R87(@87)C:&EV92XB"FUS9W-T<B`BU>++QKKULKO*Q]7]R+>UQ"!R87(@
MT;G+]<[$O/XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V
M86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`BU>++QKKULKO*Q]7]R+>UQ"!Z:7`@
MT;G+]<[$O/XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$T-0IM
M<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N
M=6UB97(N(@IM<V=S='(@(M7BR\:Z];*[RL?5_<BWM<30Q=/#OZBZQ<+K+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L
M:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI
M("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q
M-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M
M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M
M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)
M=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET
M(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)
M=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,Y.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-34W(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,SD*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DU."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`U"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,CD@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`W.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,30Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C$*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C0Q,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4T
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3<@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@R.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,#8*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S@Q-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M.#(R"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R("*T
MR]?6ML[*Q['8T.C2JK7$+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E
M9V5R<RXB"FUS9W-T<B`BM,O7UK;.Q-K(W=:[O=/*W-7[ROW*_=?6+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3@*;7-G:60@(E1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM
M<V=S='(@(K3+U]:VSL3:R-W6N[W3RMS*_=?6O+##L+K%+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(K3+U]:VSL3:
MR-W6N[W3RMRPR[WXUL;*_=:U+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R
M('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(K3+
MU]:VSL3:R-VQV-#KSJJVNKK%N_*_U;#7M]:X]+7$ROW7UB(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.CDX.0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T
M(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R("*QV-#KRL?2N[CVROW7UBXB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V"FUS9VED("(B"B)4
M:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'
M0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S
M='(@(K3+U]:VSL3:R-VQV-#KL/RZK-*[U^G*KL'YO?C6QK7$(%)'0B#1U<FK
MM/K"ZRS`_<CG("<C,3(S-&%F)RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R
M;V-E<W-E9"XB"FUS9W-T<B`BU>*X]K2PS.72T;&[M*;`[;G]+B(*"B,Z('1E
M;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H:7,@:7,@)7,N(@IM<V=S='(@(M7BRL<@)7,N(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI
M<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA
M="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R
M(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C4Y,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@
M=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA
M;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@
M;&5A<W0@;VYE+B(*;7-G<W1R("*TR\K]UK77[LG9L=C0Z\K'(#$N(@H*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED
M(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F
M:6QE<RXB"FUS9W-T<B`BM,NW_L[QQO?.WK>HMM0@>FEP(+RP(&=Z:7`@N/'*
MO<[$O/Z]^-#0O>+1N<OU(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E
M9VES=')Y+G!H<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L
M>2!D96%C=&EV871E9"XB"FUS9W-T<B`BM,O/M<VSM;''L,K'S:/3P[7$U[3,
MK"XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I
M9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R("*QV-#K
MRL?2N[CVROW7UBXB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N
M<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M
M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(K3+M+"_VK'8T.O2JM/)T:'/
M[K2PO]HH3W!T:6]N*<OYNO2]T"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S0*(RP@9G5Z>GD*;7-G
M:60@(E1I8VME=',B"FUS9W-T<B`BO\V[I[FDU_>UI2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(T,C@@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C4U"FUS9VED(")4:6UE(@IM<V=S='(@(LJQO.0B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S@V"FUS9VED(")4:6UE(%1R86-K:6YG(@IM
M<V=S='(@(LJQO.37M]?9(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS
M9VED(")4:6UE(&9O<FUA="(*;7-G<W1R("+*L;SDN/'*O2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(U,SD*;7-G:60@(E1I;64@<V5L96-T:6]N
M(@IM<V=S='(@(LJQQ_C1H=3Q(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM
M;W(M3&5S=&4B"FUS9W-T<B`B5&EM;W(M3&5S=&4B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R("*QZLSB(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B
M5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R
M("+*U;S^R,LB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C4T"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L
M(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@
M:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B+(Y[G[TJJXM-&A
M+,?KU-JUX]&ARO.QZK7$S:S*L;"T($-O;G1R;VR\_"BX]LC+O,;+X[OZ*2"[
M\B!#;VUM86YDO/PHQKNY^[S&R^,B"B*[^BDN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B5&]D87DB"FUS9W-T<B`BO?',
M["(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R(")(5$U,(-2M
MRKS.Q+S^(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G;R(*;7-G<W1R("*V
MX+CG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R("+-
MT+_+P,W(NK6Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q
M,PIM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`BP_?,["(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1O;F=A(@IM<V=S='(@(LS`O-,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*(RP@9G5Z>GD*
M;7-G:60@(E1O<"(*;7-G<W1R("+*U;S^R,LB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@
M*%]T;W`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV
M,PHC+"!F=7IZ>0IM<V=I9"`B5')A;G-L871I;VYS(@IM<V=S='(@(M?IUJ\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM
M<V=S='(@(LS8P:+$X;3ONLVVX+#-N.<B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(M7F
MN_*\V2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(M#'QMJV_B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`BS;O$X<NY(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(LW!MOK&Y"(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY
M*2(*;7-G<W1R("+-P;;ZQN3.Q"`H25-/+3@X-3DM.2DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$P"FUS9VED(")4=7)K;65N:7-T86XB"FUS9W-T<B`BS<&_XL+\R[G,N2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD
M<R(*;7-G<W1R("+,V+_+R[FZS;^MO\;+N<BZM;HB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q
M"FUS9VED(")4=79A;'4B"FUS9W-T<B`BS;S-W\*L(@H*(SH@9G)A;65W;W)K
M+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM
M<V=S='(@(LKDR.O$^K7$T:'4\3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(V.0IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(M?/
MS>+/W]:XROTZ("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E52
M3"(*;7-G<W1R("+-^-:W(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I
M<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"FUS9VED(")5
M4DPZ(@IM<V=S='(@(LWXUK<Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A
M;F1A(@IM<V=S='(@(L[:N,FT[R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5K
M<F%I;F4B"FUS9W-T<B`BSMJ_R\"\(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z-#$R"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(L[>MZBTYLBA(%9&4R#$O\*\+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O
M(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB
M"FUS9W-T<B`BUZ*RX<JQSMZWJ-3VO-.V[LWBM<33P[NGT,7/HBXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,X.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`BSMZWJ+C$L>0@5D93(,[$O/X@7"(E<UPB(+7$
MR*C/WBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS.#4@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE
M("5S+R5S+B(*;7-G<W1R("+.WK>HL>2X_"!61E,@SL2\_B`E<R\E<R"UQ,BH
MS]XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T
M<B`BSMZWJ+'DN/S.JB`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C(S,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(L[>MZBT\K^J
M(%9&4R#.Q+S^(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HV.#@@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ,#$V"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HX,S0*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@
M7"(E<R\E<UPB+B(*;7-G<W1R("+.WK>HL>2X_"!61E,@SL2\_B`E<R\E<R"U
MQ,/[L\8N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S-0IM
M<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T
M<B`BSMZWJ,&LO=/6P2!344P@M_[.\<;W+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z.#,Y"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H
M(%-33"XB"FUS9W-T<B`BSMZWJ,JYT\,@4U-,(,&LO=,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(U(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,3DV(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#$*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P.0IM<V=I9"`B56YA8FQE
M('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(L[>MZBXM-;&(%9&4R#.Q+S^
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S8U"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<
M(B5S7"(N(@IM<V=S='(@(L[>MZB]J,&B(%9&4R#$O\*\(%PB)7-<(BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-30@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,C4V"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(L[>MZB]J,&B(%9&4R#$O\*\+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C
M<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(L[>MZB]J,&B(%9&4R#.Q+S^+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@V"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@
M7"(E<UPB+B(*;7-G<W1R("+.WK>HL>2X_"!61E,@SL2\_B!<(B5S7"(@M<3#
M^[/&+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(V-0HC+"!F
M=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB
M"FUS9W-T<B`BSMZWJ+VHP:(@5D93(,[$O/XN(@H*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-S8*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED(")5;F%B;&4@=&\@9&5C
M;VUP<F5S<R!D871A+B(*;7-G<W1R("+.WK>HO:O*_;[=O>+1N<OU+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C(T(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,CDX"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@
M96UP='DN(@IM<V=S='(@(L[>MZC)OK/]("5S++3+Q+_"O+*BM\>_U;#7(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C0T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(L[>MZC)OK/]("<E<R<Z("5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE
M(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`BSMZWJ,F^L_T@)7,L
MM,O$O\*\LJ*WQ[_5L-<B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,S0X(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I
M=F5L>2XB"FUS9W-T<B`BSMZWJ+7=N>G)OK/]Q+_"O"XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HS,S<@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T-`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("+.WK>HR;ZS_2!61E,@Q+_"
MO"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0Q-R!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C0R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("+.
MWK>HR;ZS_2!61E,@Q+_"O#H@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HR,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(L[>MZC)OK/](%9&4R#.
MQ+S^(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS
M,#,@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR.#@*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,X,PHC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R("+.WK>HR;ZS_2!61E,@SL2\_BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(T-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R
M(%PB)7-<(BXB"FUS9W-T<B`BSMZWJ,F^L_T@5D93(,[$O/X@7"(E<UPB+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#`V"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E
M<RXB"FUS9W-T<B`BSMZWJ+7=N>G)OK/](%9&4SH@)7,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HX,#,*;7-G:60@(E5N86)L92!T;R!D971E
M<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(L[>MZC%T+;/M;''
ML+7$Q+_"O"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8P,PIM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T
M86EL<R(*;7-G<W1R("+.WK>HO>*_JL:^UJ3/N+W:(@H*(SH@9G)A;65W;W)K
M+TYE=%])35-0+TE-4U`N<&AP.C0U,2!F<F%M97=O<FLO3F5T7TE-4U`O24U3
M4"]!=71H+G!H<#HQ,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(L[>MZB\T]38
M("5S(+7$MJC2Y<K]OMTN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P,0HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38V(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ-S$*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&
M4R!F:6QE+B(*;7-G<W1R("+.WK>HTL:VKR!61E,@SL2\_BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z,3`R"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C0X(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+.
MWK>HM/*_JB!61E,@SL2\_B!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C<W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,PIM
M<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM
M<V=S='(@(L[>MZC0M,CK(%9&4R#.Q+S^+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C@P(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S
M,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(*;7-G:60@
M(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R("+.WK>HM/*_JB!6
M1E,@SL2\_BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI
M=F4N(@IM<V=S='(@(L[>MZBT\K^JT;G+]<[$O/XN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C@S-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E
M860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`BSMZW
MJ+'DN/P@5D93(,[$O/X@7"(E<UPB(+7$P_NSQBXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z.#8V"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5A
M9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G<W1R("+.
MWK>HT+3(ZR!61E,@SL2\_LK]OMTN(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`BSMZWJ+'DN/P@
M5D93(,[$O/ZUQ,/[L\8N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z-C8Y"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E
M8W1O<GDN(@IM<V=S='(@(L[>MZBVP<BA('9F<W)O;W0@Q+_"O"XB"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q,#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@
M9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.3,*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BSMZWJ+'DN/P@5D93(,2_
MPKRUQ,/[L\8N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER
M96-T;W)Y.B`E<RXB"FUS9W-T<B`BSMZWJ,F^L_T@5D93(,2_PKPZ("5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C8W(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+.WK>HL>2X
M_"!61E,@SL2\_B!<(B5S7"(@M<3#^[/&+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C8Q,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4@)7,O)7,N(@IM<V=S='(@(L[>MZBQY+C\(%9&4R#.Q+S^("5S+R5S
M(+7$P_NSQBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R,R!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C(X-0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,S`Q"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R
M("+.WK>HL>2X_"!61E,@SL2\_K7$P_NSQBXB"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R("+.WK>H
ML>2X_,ZJ("5S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS
M=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7
M;W)D(&1O8W5M96YT(@IM<V=S='(@(L[>MZC7JKN[(%=O<F0@SL2\_B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,30Y(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,34R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(L[>MZC0M,CK(%9&
M4R!<(B5S7"(@SL2\_BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HQ-SD*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL
M92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(L[>MZC0M,CK(%9&4R#.Q+S^
MROV^W2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.#$@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30S"FUS9VED(")5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`BSMZWJ-"TR.L@5D93(,[$O/[*
M_;[=+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-#$*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B
M92!E>&-E961E9"XB"FUS9W-T<B`BSMZWJ-"TR.L@5D93(,[$O/[*_;[=+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*
M;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R("+/PKNNS]\B"@HC.B!T96UP;&%T
M97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T
M<B`BR*'/^[C\N,0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*
M;7-G<W1R("*XM-2M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,C(S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,Y,`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`BM_[.\<;WP:R]T\JQMZ+)
M^LZTU*3&VK7$N]C3ICH@(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,T,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS-S@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R
M=F5R('1O.B`B"FUS9W-T<B`BMZ+)^LZTU*3&VK7$N]C3IBS3R;?^SO'&]SH@
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-C$*(RP@9G5Z>GD*;7-G:60@(E5N9FEL960B"FUS9W-T<B`BRJ>PW"(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")5;FEC;V1E("A5
M5$8M."DB"FUS9W-T<B`BS?+3P\+K("A55$8M."DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM
M<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`BL*+`K;*NP:JZ
MS\?ULZ2Y^B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB
M"FUS9W-T<B`BTZ*Y^B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3
M=&%T97,B"FUS9W-T<B`BP\"Y^B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N
M:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R(")5
M;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HW,0IM<V=I9"`B56YI=',B"FUS9W-T<B`BM:74JB(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R.2!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,S`*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`BSK36JK7$
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)
M1"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H
M0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"B,L(&9U>GIY"FUS9VED(")5;FMN;W=N
M(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("+.N];#T,7/HLG0SK3%Y-;#
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*
M;7-G<W1R("+.M-:JM<33P[NGP_N[\L/<PNLN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5
M;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C(Y-@HC+"!F=7IZ>0IM<V=I
M9"`B56YN86UE9"(*;7-G<W1R("+.M,/\P_LB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I
M;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R
M;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K
M($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H
M:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C
M97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*(RP@9G5Z>GD*
M;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(M?6T,W1U<FK(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#8@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C8*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HY,S(*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO
M;B(*;7-G<W1R("+.M-:GL]:UQ,"IU;G#^R(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`BL>2X_"(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B57!D871E("5S(@IM<V=S='(@(KC\T,(@)7,B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E
M<B(*;7-G<W1R("*X_-#"T\.[IR(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T
M(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z,C,P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D
M(%PB)7-<(BXB"FUS9W-T<B`BTM&X_-#"("<E<R<N(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T
M960N(@IM<V=S='(@(KC\T,*SS-#RTM')OK/]+B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$Y.0IM<V=I9"`B57!L;V%D(@IM<V=S='(@(LG/M*LB"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@
M87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T
M<B`BTM')S[2KR_G3T-.FT\.SS-#RM<3%Y-;#SL2\_K6]M_[.\<;W+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(L[:P*VY
MYR(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N
M=#H@)7,B"FUS9W-T<B`BM;''L,_@SKLB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED
M(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@
M<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C(Q"B,L(&9U>GIY"FUS9VED(")5<V5R(@IM<V=S='(@(M/#
MNZ<B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<R
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I
M<V5D(&9O<B`E<RXB"FUS9W-T<B`BT\.[IR`E<R#.M,VHN?T@)7,@M<3*VLBH
MT>G6I"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M
M:6YI<W1R871I;VXB"FUS9W-T<B`BT\.[I[G<P.TB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C(U,0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM
M<V=S='(@(M/#NZ?1H<_N(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E
M<B!296=I<W1R871I;VXB"FUS9W-T<B`BT\.[I]>BLN$B"@HC.B!S:6=N=7`N
M<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A
M8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R("*TR]6^S*BUQ-/#NZ?7HK+A
MS[7-L]+1S:/3PRXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8Y"B,L
M(&9U>GIY"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@
M(M72LKNUO2`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R
M;F%M92(*;7-G<W1R("+3P[NGP_LB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,3(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M<V5R;F%M92!<(B5S7"(@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(M/#NZ?#
M^R`G)7,G(-+1M.;4VBXB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R("+3P[NGP_LZ(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z
M("(*;7-G<W1R("+3P[NG.B`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R
M("+/M<VSUM"UQ-/#NZ<Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI
M<W1A;B(*;7-G<W1R("+.VM?(L?"_R\NYS+DB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HQ-C,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,C4U"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G
M<W1R(")61E,@Q+_"O+*BLKNTYM3:+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ,3@*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(KS9QMHB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-C8*;7-G:60@(E9A;&ED(&QO
M8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`BTM'5TK6]T]#0I[7$
MM=BUXSH@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M,S@*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(M/0T*?0U"(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM
M<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`BTM2W
MUM;3SJJUI<Z[*+33S];4VL;PR^,I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.#4V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG
M=&@@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(R-#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$V(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Y,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T
M+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(M:U(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$P.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,3@V"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R("+-W\*S
ML*+-O"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0*;7-G
M:60@(E9A<FEA8FQE(@IM<V=S='(@(K'DNZ\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS
M9VED(")696YE>G5E;&$B"FUS9W-T<B`BSJ_$VLCPP*TB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T
M:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E
M<F5D('=I=&@N(@IM<V=S='(@(M'IUJ3*I[#<("T@M,O3RKS^O\G$W-+1U.+(
MR\G#U]2TV[C$+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-S`P"FUS9VED(")697)S:6]N(@IM<V=S='(@(K#FL;XB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(V"FUS9VED(")697)S:6]N($-O;G1R
M;VPB"FUS9W-T<B`BL.:QOK_8UL8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A
M;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B5F5R>2!(
M:6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I970@3F%M
M(@IM<V=S='(@(M2]Q,\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM
M<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R("+4O<3/SL0@*%9)
M4T-)22DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HY
M-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R("*\[,K3
M("5S(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A
M;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R("+4VM#"M+"_VK3ROZHB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,C$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R("+2U"`E<R"RZ;^T
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I
M<V@B"FUS9W-T<B`BTZ+*],ZLMON^J<BZM;HB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS
M9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R("+#P,KTSJR^J<BZ
MM;HB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.0IM<V=I9"`B5FES:6)I
M;&ET>2(*;7-G<W1R("+$W+S[ML@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C8S"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`BQ-R\
M^[;(.B`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B
M"FUS9W-T<B`BTN*T\\#[M_RUPK?GM>?0Q;FKR[[-N+G](%--5%`B"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(KZON.8B"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB
M"FUS9W-T<B`BOJ^XYB$A(2"TTR`E<R#*UK:OR;ZS_;/,T/(N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)
M3B!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")7
M86QL:7,@86YD($9U='5N82(*;7-G<W1R("+-W\#[R[FZS;B[S;S(NK6Z(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]H=&UL+G!H<#HR-S(@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED
M(")787)N:6YG(@IM<V=S='(@(KZON.8B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R("+0
MQ\;:R/TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G
M:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`BS.S&^-2DLN(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#(W"FUS9VED(")796%T:&5R
M(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#DR"B,L(&9U>GIY"FUS9VED(")796%T:&5R+F-O;2(*
M;7-G<W1R(")W96%T:&5R+F-O;2#-^-6^(@H*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R("+-^-6^(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0S-PIM<V=I9"`B5V5B(%-I=&4B"FUS9W-T
M<B`BS?C5OB(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC
M92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R("+#O];<(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@(E=E;&-O;64B"FUS
M9W-T<B`BN[;3K2(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(KNVTZVUO2`E<R(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*
M;7-G<W1R("*[MM.M+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU
M"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R("+.]\6W("A)
M4T\M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED
M(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`BSO?%MR`H25-/+3@X
M-3DM,34I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM
M<V=S='(@(L[WR/:Y_L"M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L
M9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R("*UQ\*\NO/3IKC#
MS\C/U,J^("5S(,3$TKNX]M.FT\.SS-#R/R(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@
M8VAA<F%C=&5R/R(*;7-G<W1R("+7UK;.M<2WUKCTU]:W^S\B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@
M<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("+2_<KVM<3'L+6\M_L_(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C$*(RP@
M9G5Z>GD*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R("*P
MQ+3SP/O1QR(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI
M8V@@<&AA<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,S,*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@
M4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`HC+"!F=7IZ>0IM
M<V=I9"`B5VED=&@B"FUS9W-T<B`BM^?+V3HB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,3(U"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F
M="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*
M;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`HC+"!F=7IZ
M>0IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("+!HLS5S?`B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0HC+"!F=7IZ
M>0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(K?GR]DZ(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C4Q,PIM<V=I9"`B5VEK:2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"B,L(&9U>GIY"FUS9VED(")7
M:6YD(@IM<V=S='(@(K?GR]DZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C8*(RP@9G5Z>GD*;7-G:60@(E=I;F0@16%R;'DB
M"FUS9W-T<B`BM^?+V3H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,`IM
M<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R("*WY\O9*+W:*2(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34V"FUS9VED(")7:6YD.B(*;7-G
M<W1R("*WY\O9.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-#(*;7-G:60@(E=I;F0Z("(*;7-G<W1R("*WY\O9.B`B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DV"B,L(&9U>GIY"FUS9VED
M(")7:7-H;&ES="(*;7-G<W1R("+&VK3]S^[$OR(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O
M<FL@061D<F5S<R(*;7-G<W1R("*P[+FKRM*UV-:W(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0
M:&]N92(*;7-G<W1R("*P[+FKRM*UY[NP(@H*(SH@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z,38Y(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(V
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S
M(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S`P"B,L('!H<"UF
M;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D
M("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,3$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")7
M<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G
M<W1R("+(J,_>LKO7XRS.WK>HO:C!HB!61E,@SL2\_BXB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C0S"FUS9VED(")8+5)E9B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I
M9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED(")8-3`Y
M=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@4W5B
M:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B
M:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X=&5N
M<VEO;G,B"FUS9W-T<B`B6#4P.78S(,"IU;G#^R(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R("+$ZB(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-0IM<V=I9"`B65E962(*
M;7-G<W1R("+$ZB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,3`X"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(EEA:&]O
M("$@M=C-O"(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC
M92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R("+#O\3J(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-PIM<V=I9"`B665M96XB"FUS9W-T<B`BTK+#Q2(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(EEE
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(LK'
MM<0LSM+-K-+B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@
M=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N(@IM
M<V=S='(@(L3ZM;''L,JYT\.TO\[$U]:QX-"TQ*/*O2X@RKG3PR!;/#Y=(+"T
MQ:6_R<?0N[O.JLWXTK.QX-"TQ*/*O2XB"@HC.B!S97)V:6-E<R]P;W)T86PO
M961I="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@
M86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#$Q"FUS9VED
M(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P,@IM<V=I9"`B66]U
M(&-A;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL
M(&YA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW-0IM<V=I9"`B66]U
M(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R
M("+$^K*BSK3*Y,CKTKNX]KK/MZBUQ+7GU]/3RKS^M=C6MRXB"@HC.B!F<F%M
M97=O<FLO1&%T82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E
M9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB
M"FUS9W-T<B`BQ/JRHLZTT\FUO,CKM<3.Q+S^UM"VU-.SR,ZZSM?6MLZUO2`E
M<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B66]U
M(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R("+$^M+1OJW7HL_Z+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO
M=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG
M:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E
M<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V92!T;R!E
M;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R("+$^K'8T.O*Y,CKTKNX]KK/
MMZBUQ-:U+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HS
M-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N
M9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`BQ/JQV-#KS\BYYKNNNL/*_;[=
MRO<H1&%T851R964IM_[.\;;+LL7$W+S,T/C*N=/#T,+3P[NGUZ*RX;?^SO$N
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-38*(RP@9G5Z>GD*
M;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G
M<W1R("+$^K'8T.O/R+GFNZZZP\K]OMW*]RA$871A5')E92FW_L[QMLNRQ<3<
MO,S0^,JYT\,@2&]R9&4N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M
M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G
M<W1R("+'Z\/HRO;.RLSBHZS4VL3ZM*O+S<[*S.*QJ+CFUJ['L"XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED
M(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN
M=',@=&\B"FUS9W-T<B`BQ/JQV-#KRN3(Z[3+P:R]T\OYUKC/\K7$S?C6MR(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@
M;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@
M(L?KUKBVJ-*JR;ZS_;7$M_[.\<;W+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q
M.0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE
M('1O(&-L96%R(&]U="XB"FUS9W-T<B`BQ^O6N+:HTJK)OK/]M<33P[NG+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`BQ^O6N+:HTJK)OK/]
MM<33P[NG+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T
M:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R("+'Z]:XMJC2JM#"U/:UQ-/#
MNZ<N(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(L?KUKBV
MJ-*JN/S0PK7$T\.[IRXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A
M8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`BQ^O6N+:HTJK6M-#0M<37]]/#
M+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A
M=&5G;W)Y(&YA;64N(@IM<V=S='(@(L?KUKBVJ-*JR;ZS_;7$T\.[IRXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H
M;VYE(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N
M(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(L3Z
MM<0@)7,@N^'&VM+1N?W*L2['Z];8T,*UQ\*\+B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9;W5R($5M86EL($%D9')E
M<W,B"FUS9W-T<B`BQ/JUQ+7GU]/3RKS^M=C6MR(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,3(*(RP@9G5Z>GD*;7-G:60@(EEO=7(@1G)O;3H@861D
M<F5S<SHB"FUS9W-T<B`BQ/JUQ+7GU]/3RKS^M=C6MR(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S0@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX.0IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R("+$^K7$T,7/
MHB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG
M960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O
M("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A
M:6XN(@IM<V=S='(@(B(*(M?4M-/$^K7$("5S(+OAQMJ_JLJ\TM3`M,3ZM<32
M\LS8S?BUV-:WTM&QY+C\+B#.JK&CNZ3$^K7$L++(J\;PO/NCK,3ZL=C0Z];8
MT,(B"B*UQ\*\+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C,S"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`BQ/JUQ-#5P_LB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-0HC+"!F=7IZ>0IM<V=I
M9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U
M<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R
M9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@
M82!D:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T
M<B`BQ/JUQ-'IUJ2VR[*BSK36I[/6T,+4]M/#NZ>[\KC#N:;$W-+1L;NYV+'5
M+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I
M9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U
M<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E
M96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("+$
M^K7$T>G6I+;+LJ+.M-:GL];!T+/VT\.[I[ORN,.YIL3<TM&QN[G8L=4N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@T"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E
M9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB
M5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I
M;BXB"FUS9W-T<B`B(@HBU]2TT\3ZM<0@)7,@N^'&VK^JRKS2U,"TQ/JUQ.2O
MP,#&]\O&NO72T;'DN/PN(,ZJL:.[I,3ZM<2PLLBKQO"\^Z.LQ/JQV-#KUMC0
MPB(*(K7'PKPN(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*;7-G:60@
M(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB
M"FUS9W-T<B`BQ/JUQ.2OP,#&][*BSK36I[/6U>*X]KFFQ-PN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*(RP@9G5Z>GD*;7-G:60@
M(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@
M;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT
M+B(*;7-G<W1R("+$^K7$Y*_`P,;WLJ+.M-:GL]:T\M.AT:'/[B['Z["T($-4
M4DPK4"#2U+3RTZ$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-PIM
M<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`BQ/JUL<>P
MR_G%Y-;#M<3*L<?X.B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY-@HC+"!F
M=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H
M86YG960N(@IM<V=S='(@(L3ZM<31H<_NTM&X_-#"+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ-3@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L
M="!I9&5N=&ET>3HB"FUS9W-T<B`BQ*S(S\GMM]W*MK'P(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(P,0HC+"!F=7IZ>0IM<V=I9"`B66]U<B!F=6QL
M(&YA;64Z(@IM<V=S='(@(L3ZM<30U</[(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z,3`P,`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!L;V=I;B!H87,@
M97AP:7)E9"XB"FUS9W-T<B`BQ/JUQ-&AS^[2T;C\T,(N(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`HC+"!F=7IZ>0IM
M<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@
M9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R("+$^K7$T:'/[M+1
MN/S0PBXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM
M<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R
M("+$^K7$T:'/[M+1N/S0PBXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM
M<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@
M>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O
M<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<S
M,@IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9
M;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R("+$^K7$U+:SS+?^SO'&]SHB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S
M='(@(L3/R[G`K;?R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`BU/K2P;;[(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(M3>L<C1QR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(KWRL,VRO,ZD(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H
M='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E
M0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G:60@(EM0<F]B
M;&5M(%)E<&]R=%TB"FUS9W-T<B`B6\[*S.*QJ+CF72(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1
M=6]T960@5&5X="`M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I
M;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(EO.
MN]/:T-`@)7,@N;(@)7,@T-!=(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-30Q('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*(RP@9G5Z
M>GD*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R("*YW,#M(@H*(SH@
M;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(B(*"B,Z(&QI
M8B]A<&DN<&AP.C$T,0HC+"!F=7IZ>0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S
M='(@(LK]OMTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S$*(RP@9G5Z>GD*;7-G:60@(E]$96QE=&4@4F]W
M(@IM<V=S='(@(LF^L_TB"@HC.B!L:6(O87!I+G!H<#HQ,S,*(RP@9G5Z>GD*
M;7-G:60@(E]'<F]U<',B"FUS9W-T<B`BT\.[I]?I(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0HC+"!F=7IZ>0IM<V=I9"`B7TAE
M;'`B"FUS9W-T<B`BL._6^B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E
M<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TUE;G4N<&AP.C$Y-`HC+"!F=7IZ>0IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R
M("*UQ\*\(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y
M,`HC+"!F=7IZ>0IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`BUZ+/^B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR-`HC+"!F=7IZ>0IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@
M(K+ER.LOL>2X_,WXPN?!K+W3(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TUE;G4N<&AP.C$V-`HC+"!F=7IZ>0IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T
M<B`BT:'/[B(*"B,Z(&QI8B]A<&DN<&AP.C$S-PHC+"!F=7IZ>0IM<V=I9"`B
M7U!E<FUI<W-I;VYS(@IM<V=S='(@(LBHS]XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*
M;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R("+)OK/]MM0B"@HC.B!L
M:6(O87!I+G!H<#HQ,C4*(RP@9G5Z>GD*;7-G:60@(E]3971U<"(*;7-G<W1R
M("+%Y-;#(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*
M;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,CD*(RP@9G5Z>GD*;7-G:60@
M(E]5<V5R<R(*;7-G<W1R("+3P[NG(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,C$*(RP@9G5Z>GD*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G
M<W1R("+-J-&VLKXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3,*(RP@9G5Z>GD*;7-G
M:60@(F-A;&5N9&%R(@IM<V=S='(@(LC5P/HB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R("+!X[RVM^<B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N
M;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P
M96X@:6YP=70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z-3DR"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(R"FUS9VED
M(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S@*(RP@9G5Z>GD*;7-G
M:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`BQ>36PR(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET
M:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O
M<FUA="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$X,@HC+"!F=7IZ>0IM<V=I9"`B96YT<GD@;F]T(&9O
M=6YD(@IM<V=S='(@(M72LKNUO2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")F86QL:6YG(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U-0IM<V=I9"`B
M9FEL92(*;7-G<W1R("+.Q+S^(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C`@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A
M="`E<R`E<R(*;7-G<W1R("*TTR`E<R`H)7,I(-/:("5S("5S(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,`HC+"!F=7IZ>0IM<V=I9"`B
M9W5S=&EN9R(*;7-G<W1R("(L(-7SM^<@)7,@)7,B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Y"FUS9VED(")H.B(*;7-G
M<W1R("+*L3HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S4X"FUS9VED(")H:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N
M:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS
M9W-T<B`BP:*\M"(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")I;FQI;F4B"FUS
M9W-T<B`BS\*[KL_?(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I
M9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*(RP@9G5Z>GD*
M;7-G:60@(FQI;F5S72(*;7-G<W1R("*WUB(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG
M($E33RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,V.0IM<V=I9"`B;6TB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR.3$@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP
M:'`Z,C,R"FUS9VED(")N86UE(@IM<V=S='(@(L/[L\8B"@HC.B!F<F%M97=O
M<FLO4E!#+U)00RYP:'`Z,3(Q"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS
M9W-T<B`BR=#.M,JUS]8N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HQ,C$Y"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S
M='(@(LG0SK3*M<_6+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3`U"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E
M<F-E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-S0*(RP@9G5Z>GD*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D
M(@IM<V=S='(@(K3FR*'4XK[<(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P
M"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*(RP@
M9G5Z>GD*;7-G:60@(G)I<VEN9R(*;7-G<W1R("+(J,_>(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*(RP@9G5Z>GD*;7-G:60@
M(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B365T87(@Q_B_Z<[>MZC*
MN=/#+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.3D*;7-G:60@(G-H
M;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I
M;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S@U"FUS9VED(")S<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@HC+"!F
M=7IZ>0IM<V=I9"`B<W1E861Y(@IM<V=S='(@(K;!R*$B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C,P.0IM<V=I9"`B<W=I=&-H(&]F9B!J879A
M<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,34P"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,CD*(RP@9G5Z>GD*;7-G
M:60@(G1A<VL@;&ES="(*;7-G<W1R("+7UK?[M*[!T"(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@
M9F%I;'5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C,P-0HC+"!F=7IZ>0IM<V=I9"`B=')Y(&%G86EN(@IM<V=S='(@(L._
MM,ZUQ\*\(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@
M='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R("+4V;3.RN3(Z\3ZM<3#W,+KTM3(
MM\C/SM[.\R(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")U;FEF:65D(@IM<V=S
M='(@(LJGL-PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP.C(W
M"FUS9VED(")U;FYA;65D(@IM<V=S='(@(LZTP_S#^R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I
M9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`BT\.[I]&AU/$B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D
M(@IM<V=S='(@(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(T,0IM<V=I9"`B=SHB"FUS9W-T<B`BT,?&VCHB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE
M<BYC;VTB"FUS9W-T<B`B=V5A=&AE<BYC;VT@S?C5OB(*````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+WIH
M7U17+G!O````````````````````````````````````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`V-#`T,C,`,3`U,34T,S,W-30`,#$W-S`Q`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````",@2&]R9&4@5')A9&ET
M:6]N86P@0VAI;F5S92!4<F%N<VQA=&EO;BX*(R!#;W!Y<FEG:'0@*$,I(#(P
M,#$@1&%V:60@0VAA;F<N(+%IJ'VDY2RE>,97"B,@1&%V:60@0VAA;F<@/&1A
M=FED0'1M=BYG;W8N='<^+"`R,#`Q+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB
M4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`M8W9S7&XB"B)297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#8M,#$M,#4@,34Z,#0K,#@P,%QN(@HB4$\M4F5V
M:7-I;VXM1&%T93H@,C`P,2TQ,BTR,"`Q,CHP,"LP.#`P7&XB"B),87-T+51R
M86YS;&%T;W(Z($1A=FED($-H86YG(#QD879I9$!T;78N9V]V+G1W/EQN(@HB
M3&%N9W5A9V4M5&5A;3H@5')A9&ET:6]N86P@0VAI;F5S92`\:3$X;D!L:7-T
M<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N
M="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4))1S5<;B(*(D-O;G1E;G0M
M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET7&XB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C,W,PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O
M*2(*;7-G<W1R("(@*"5S(*31JV4I(@H*(SH@;&EB+TAO<F1E+G!H<#HQ,S<T
M"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R
M("(@**?6L;;!Y"`E<RDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,X,0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B`H
M)7,@I-&DNBDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W-PIM<V=I9"`B
M("AT;V1A>2DB"FUS9W-T<B`B("BDM:31*2(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,S<Y"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@**GZI-$I
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H>65S=&5R
M9&%Y*2(*;7-G<W1R("(@**Q1I-$I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(T-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4P
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.38*;7-G:60@(B!A
M="`B"FUS9W-T<B`BJ?,B"@HC.B!L:6(O5D93+W-M8BYP:'`Z,C$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM
M<V=S='(@(EPB)7-<(B"DHZQ/I$"MTZ78O_TB"@HC.B!L:6(O2&]R9&4O0TQ)
M+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A
M('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B7"(E<UPB(*2CK$^D0*W3IK.NQ*JZ
MO^^^W"XB"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C8U,B!L:6(O2&]R
M9&4O4F5G:7-T<GDN<&AP.C$P-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB
M"FUS9W-T<B`B7"(E<UPB(*E\I;RF8B!(3U)$12"JNK7YI57`R2A296=I<W1R
M>2FDI+-=J7<N(@H*(SH@;&EB+TAO<F1E+U1R964N<&AP.C$W,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N
M(@IM<V=S='(@(J?DI*.H["!<(B5S7"(@=')E92!R96YD97)E<BXB"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(EPB
M)7-<(J1WIJBE7*JZI5ND2JCLN'.RU:ATLLZDI"XB"@HC.B!A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB
M('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R
M(")<(B5S7"*D=Z5;I$K%=JVMJ'2RSBXB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B
M7"(E<UPBJ,.EO*O8I=\Z("5S+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F
M34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("*D=ZC/I<X@)2XR9DU"("RN
M9;9Q("4N,F9-0B`LL]&^;"`H)2XR9B4E*2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@
M86YD("5S(@IM<V=S='(@(B5D("5S(*5(I,X@)7,B"@HC.B!L:6(O2&]R9&4O
M075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O
M<F0@97AP:7)E<RXB"FUS9W-T<B`BL\RJ\:1`IKBQ2[U8Q=RG\ZGS("5D(*31
MJV4N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W-`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`BL\RJ
M\2`E9""DT:[PMDBY=[/X(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@
M(B5S("T@L\:GT;_](@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW
M,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T
M<B`B)7,@J_ROOB(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX
M-#`@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@T,@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z('-E<G9I8V5S
M+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-
M86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@
M(B5S(+K[Q4"^WJ=`("T@O52[>R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(E<R"S7:EW(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O4VEG;G5P+G!H<#HR-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@4VEG;B!5<"(*;7-G<W1R("(E<R"U^:55(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS
M(&]F($%G<F5E;65N="(*;7-G<W1R("(E<R"F4+=.MK6EV"(*"B,Z(&QI8B]6
M1E,O<VUB+G!H<#HT,S(@;&EB+U9&4R]S;6(N<&AP.C0Y-"!L:6(O5D93+V9T
M<"YP:'`Z-C<Q"B,Z(&QI8B]61E,O9G1P+G!H<#HW,SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B5S(*1WIG.F
M8B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Y(&QI8B]";&]C:R]M971A
M<BYP:'`Z,38U(&QI8B]";&]C:R]M971A<BYP:'`Z,C,Y"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S0U(&QI8B]";&]C:R]M971A<BYP:'`Z,S4Q"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S(*9B("5S
M("5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE
M("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F
M;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B)7,@I'>T3J15ID.HQK:UJKJZ
M^\5`OMZG0+1.NOPN(+W0J?.FN:[)I,2_[Z=!MU&M;K[>IT"JNK:UI=@N(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`BI;*[W:UN("5S(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M;6EN=71E<R(*;7-G<W1R("(E<R"DP"(*"B,Z(&QI8B](;W)D92]";&]C:R]#
M;VQL96-T:6]N+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T
M(&9O=6YD+B(*;7-G<W1R("*GY*2CJ.P@)7,N(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T
M;R`E<R!O9B`E<R(*;7-G<W1R("(@)7,@J.P@)7,@ID`@)7,B"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.CDR,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S
M($%D9')E<W,@0F]O:R(*;7-G<W1R("(E<ZJZLW&P5+_](@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HY,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#
M86QE;F1A<B(*;7-G<W1R("(E<ZJZIN:HQK[D(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HY,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D
M(@IM<V=S='(@(B5SJKJSQJ?1O_TB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.CDR.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S
M='(@(B5SJKJKW;_LPZ\B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z
M("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]H=&UL+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H
M:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@
M8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R
M(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN
M9F]R;6%T:6]N+B(*;7-G<W1R("(B"B(E<SH@LV^KRJM(I?.DHZ1`J7>O=:71
MJTBDI*JZL4BE\Z1(J=*Q2+5O+B"]T*I@MTZD5:9#J=*FLZJZNO2X]+-SM;*F
MLZ5IK^"LJKI\(@HBIT&JNJW3I$BXZJ[&+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS-30@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,Y.0IM<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(L(+!]K;<@(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S
M='(@(BP@L'VMMR`E<R`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Q
M"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E
M<R(*;7-G<W1R("(LQ=RDQK9QL7$@)7,@J.P@)7,B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C`W,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$S,B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C(Y-`HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C,T."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0U"FUS
M9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@O^^^W"`M+2(*"B,Z(&QI
M8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS
M9W-T<B`B,3(@I'"NR:CN(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"FUS
M9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R("(R-""D<*[)J.XB"@HC.B!T
M96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS
M9W-T<B`B,C0@I'"NR:CN(@H*(SH@;&EB+TAO<F1E+U5)+U!A9V5R+G!H<#HV
M.0IM<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(J17I$"MMB(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@
M:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(J:YL,^V]*6R
MMK>M;JO\J7>XZJ[&KG>F^*I!NMTN(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-C(*
M;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(K5O
MI<VD1J1`K=/$6:VKJKJ_^;M^(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O
M(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("*Q_:5;L4NV;*7S+,'9N]VM
M;J:SI$"MTR!01U`@I+VV?:KWQE\N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z,3$V.`IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`BL?W%Y\/2
MI'?#L;.YJKJV;*7S+,'9N]VM;J:SI$"MTR!01U`@I+VV?:KWQE\N(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`Y.0IM<V=I9"`B(@HB02!P=6)L
M:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@
M(K']N-&Q2[9LI?,LP=F[W:UNIK.D0*W3I+VV?2!01U`@JO?&7RRH<+%+(%!'
M4""J]\9?+*5(I,ZS<</VI&:E3RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HQ,#$V"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E
M(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N
M(&$@(@HB;65S<V%G92XB"FUS9W-T<B`BL?VP]:;FMFRE\\.QL[DLP=F[W:UN
MIK.D0*W3I+VV?2!01U`@JO?&7RRH<+%+(%!'4""J]\9?+*5(I,ZS<</VI&:E
M3RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4P-@IM<V=I9"`B
M(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE
M<W-A9V4N(@IM<V=S='(@(K']N-&Q2[9LI?,LP=F[W:UNIK.D0*W3I+VV?2!3
M34E-12"J]\9?+*APL4L@4TU)344@JO?&7RRE2*3.LW'#]J1FI4\N(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B
M;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G
M<W1R("(B"B*Q_;#UIN:V;*7SP[&SN2S!V;O=K6ZFLZ1`K=.DO;9](%,O34E-
M12"J]\9?+*APL4L@4R]-24U%(*KWQE\LI4BDSK-QP_:D9J5/+B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!3
M34E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM
M<V=S='(@(K']I5NQ2[9LI?,LP=F[W:UNIK.D0*W3(%--24U%(*2]MGVJ]\9?
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*
M;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R("*DR*MEIK.VLR(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,
M:6=H="!286EN(@IM<V=S='(@(J3(JV6D<*M"(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS
M9W-T<B`BI,BK9::SJT(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R("*DR*ME
ML'VK0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$S"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`BI,BK9;!]L[<B
M"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB
M"FUS9W-T<B`BI,BK92^DR*OA(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R(")!4$D@O7.X
MN2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(L/VJ?.S;ZW3
MO7._Z+ZY(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3,*;7-G:60@
M(D%B;W5T+BXN(@IM<V=S='(@(L/VJ?,N+BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB
M"FUS9W-T<B`BI;^D5:3H(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(J6_
MI*2EH2(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S
M(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("+%=JVM
MI*.HK"RU3*IKJ]BEWR!61E,@I=B__2XB"@HC.B!L:6(O5D93+VUU<W%L+G!H
M<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N
M(@IM<V=S='(@(L5VK:VDHZBL++5,JFNKV*7?(%9&4R#`R:[7+B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HS"FUS9VED(")!8V-O=6YT($EN9F]R;6%T
M:6]N(@IM<V=S='(@(K%BN+FXZK!4(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<X"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(K%BN+F[
M4+%+O5@B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(K%BN+FD=ZWAM;(N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S-0IM<V=I9"`B06-C
M;W5N=&EN9R(*;7-G<W1R("*ULK%B(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B
M"FUS9W-T<B`BMW.\5R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(T(&%D;6EN
M+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T
M<B`BMW.\5Z:XN'.RU2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z.3@@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD(%!E
M<FUI<W-I;VXB"FUS9W-T<B`BMW.\5Z1LQ7:MK2(*"B,Z('1E;7!L871E<R]P
M;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`BIF*F
MN;=SO%<Z(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S
M+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`BMW.\5[AS
MLM4B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C@W(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G
M<W1R("*W<[Q7Q7:MK2(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D
M8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@
M9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(K=SO%>FN+ASLM6H["!<(B5S7"(B
M"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G
M<W1R("*W<[Q7IKC%=JVMIMQ<(B5S7"(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS
M,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@(K=SO%>D0*W3J,^E
MSJK,.B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU
M-3,*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`BMW.\5\3FINPB"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@
M;F5W(&UE;6)E<G,B"FUS9W-T<B`BMW.\5Z1`K=.FJ*W[.B(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S
M='(@(K=SO%>Y[R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL
M82!3:61E8F%R(@IM<V=S='(@(K=SO%<@)7,@K+`@36]Z:6QL82"JNJ3`K;8B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"FUS9VED
M(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R("*W<[Q7J.RJNK-QL%2_
M_3HB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"FUS
M9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(K=SO%>H[*?:
MJKJS<;!4O_TB"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D('5S
M97(B"FUS9W-T<B`BMW.\5ZC/I<ZJS"(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@
M<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I
M;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(J1WMW.\5R!<(B5S7"(@J.RH
M=++.I*0N(*;]M4RJ:[=SO%?#0J5^JKJU^:55N.JP5#H@)7,N(@H*(SH@<VEG
M;G5P+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@
M=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R("*D
M=[=SO%<@7"(E<UPB(*CLJ'2RSJ2D+B"G0;)[IF*E::5(MFFFYK5NI$JD1BXB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B
M061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("*W<[Q7J,^ESJK,
MJKJE7*_@I=BK9;-1P_:SK"XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T
M-2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,PIM<V=I9"`B061D<F5S
M<R(*;7-G<W1R("*F8:=](@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$T,0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(K-QL%2__2(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M
M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS
M9W-T<B`BIJBLL+K>LGJM^R`M(*RPJ.2E3*C/I<ZJS+-=J7?%=JVM(@H*(SH@
M861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(KK>LGHB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0S"FUS9VED(")!9',B"FUS
M9W-T<B`BO'.G:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ."!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(D%F9VAA
M;FES=&%N("BJ_+1)IKTI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB86YI82(*;7-G<W1R(")!;&)A
M;FEA("BJ_+JXI-JEIZC(*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B06QG
M97)I82`HJORZN*3.IU&HR"DB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`BMFRE\Z=/IE<B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R("*Y[[OT(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI
M9VYM96YT.B(*;7-G<W1R("*Y[[OTI.BFH3HB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R("*ITJ:S(@H*(SH@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T
M<B`BJ=*FLZ1WQ>?#TJJZJ,^ESJK,(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS
M,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G
M<W1R("*ITJ:SN'.RU2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z.3$@
M;&EB+TAO<F1E+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(JG2IK/%=JVM(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL
M(&9O=7(@<VED97,B"FUS9W-T<B`BI7ZNV+UU(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$X-S4*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*
M;7-G<W1R("*DN;-<IFZT6*W3N7&D;+9LI?.F8:=](@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4S.`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E
M<F5D(&QI<W0@='EP93\B"FUS9W-T<B`BI+FS7,7<I_.VM:78O7.XN:JZJZRZ
M03\B"@HC.B!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HU,#0*;7-G:60@
M(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(J1WIG.F8B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,C8*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN
M(@IM<V=S='(@(L7<I_,@24U34""U;J1*(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4Q,0IM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS
M9W-T<B`BQ=RG\R!)35-0(+%+O5@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3`S"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R
M("+%W*?S($E-4U`@J,^ESJK,(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z,S4*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S
M='(@(L7<I_.Y<:1LMFRE\Z;MIWTB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$T,@IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R("+%W*?S
MO,NJ3R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S
M='(@(K3`I4ZDY:9R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B
M06UE<FEC86X@4V%M;V$@**S\Q%*P[<+$O*^HR"DB"@HC.B!L:6(O2&]R9&4O
M4')E9G,O54DN<&AP.CDU(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3$U"FUS
M9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@
M(J1`K=.U3*[$JKJMR+-1J,^ESBXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,34U"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U
M<F5D+B(*;7-G<W1R("*U;Z7-I$:D0*W3I;RJOJJZO_F[?BXB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!
M;F1O<G)A(@IM<V=S='(@(D%N9&]R<F$@**9WN42FU2DB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O
M;&$B"FUS9W-T<B`B06YG;VQA("BF=ZWTJ=0I(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B
M"FUS9W-T<B`B06YG=6EL;&$@**9WIF.IU*YQ*2(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S
M='(@(K#.IE>E3K)ZIG.H^B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`BM:JNUR(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N
M=&%R8W1I8V$B"FUS9W-T<B`B06YT87)C=&EC82`HJVZWI:1JL[`I(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I
M9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R(")!;G1I9W5A(&%N9"!"
M87)B=61A("BF=[2CI<JN<:3.I-JZN*6LN4:N<2DB"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-2!L:6(O2&]R9&4O
M0FQO8VLO54DN<&AP.C4X"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E
M>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(L"SI<ZU>Z:A
M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A
M=&EO;B!,:7-T(@IM<V=S='(@(L"SI<ZU>Z:ALDVSYB(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y
M+B(*;7-G<W1R("+`LZ7.M7NFH:1WM$ZZ_"(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B
M"FUS9W-T<B`BKDVESJCLJ=*FLZJZIKBF0*C)(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T
M<B`BI^6MXR(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#`*
M;7-G:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`BN7>F]*1JI'`B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB
M"FUS9W-T<B`BI7RDZR(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Q"FUS
M9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`BJORIU*="I.4@
M*%=I;F1O=W,M,3(U-BDB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R
M+G!H<#HU.2!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.`IM<V=I9"`B07)C:&EV
M92!&:6QE(%-I>F4B"FUS9W-T<B`BP*/!6<#)I&JD<"(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R87(N<&AP.C4X(&QI8B](;W)D92]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8U"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP
M.C<W"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T<B`BP*/!6<#)IE>ZV2(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O
M(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B
MIT&]5*EWK6ZG4K"C("5S(*JZM?FE5;;<(#\B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!
M<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY
M('-U8BUG<F]U<',_(@IM<V=S='(@(J=!O52I=ZUNIU*PHR!<(B5S7"(@I4BD
MSJ7TIO.JNJ:XN'.RU2`_(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(V
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(D%R
M9V5N=&EN82`HJORNVJ?**2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B07)M
M96YI82`HJ,BL_*6GJ,@I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S(*
M;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(JC(K/REIZC(
MI.4@*$%235-#24DM."DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*
M;7-G:60@(D%R="(*;7-G<W1R("+#P+-.(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C,P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T
M<B`B07)U8F$@**K\OGRDVJYQ*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R(")!<V-E;G-I
M;VX@27-L86YD(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED
M(")!<V-I:2!!<G0B"FUS9W-T<B`BI.6F<L/`LTXB"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*
M;7-G<W1R("*HR*QW+Z33I:VL=J9AL,\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#(Y"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@
M9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`BL/6FYK[>
MIT"Z^\5`JV7%XZ7<O52[>[GON-P_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,Q,#(*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R("*DP+!T
MQ.:F["(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@
M=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R("+`?+C5
MIU*PHZ1`K=.DHZ9SIF*JNKASLM4N(@H*(SH@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E
M;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`BP'RXU:=2L*.D0*W3I*.F<Z9BJKK%
M=JVM+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T
M<B`BP'RXU;USO^BD0*W3I*.F<Z9BJKJX<[+5+B(*"B,Z('-E<G9I8V5S+W-H
M87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N
M+65X:7-T96YT('-H87)E+B(*;7-G<W1R("+`?+C5O7._Z*1`K=.DHZ9SIF*J
MNJ9`J,DN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#,*;7-G:60@(D%T=')I8G5T97,B"FUS
M9W-T<B`BQ-VIRB(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#8@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R
M"FUS9VED(")!=6=U<W0B"FUS9W-T<B`BI$NDZR(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI
M82(*;7-G<W1R(")!=7-T<F%L:6$@*+]$I&JG4:C(*2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R
M:6$B"FUS9W-T<B`B075S=')I82`HMOBF8:=1*2(*"B,Z(&QI8B](;W)D92]!
M=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER
M960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-R
M>7-Q;#H@I^2DHZCLJ=*[W:UNJKH@:6UA<""IM:;YKDVE\RXB"@HC.B!L:6(O
M2&]R9&4O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"
M86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM
M<V=S='(@(D%U=&A?8WER=7,Z(*;XJD&ZW:C#I;RTHZC1N-.VM:3DM*DN(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C
M>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R(")!=71H7V-R>75S.B"GY*2CJ.RITKO=K6ZJNB!I;6%P(*FUIOFN3:7S
M+B(*"B,Z(&QI8B](;W)D92]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U
M=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M
M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS
M9W-T<B`B(@HB075T:%]F='`Z(*?DI*.H[*G2N]VM;JJZ($944""IM:;YKDVE
M\RZ]T*VKMW.]<\2V(%!(4""HPZ5"I5ND2B`M+65N86)L92UF='`@O^\B"B*V
MM2RHTJ9P(&-O;F9I9W5R92`M+65N86)L92UF='`B"@HC.B!L:6(O2&]R9&4O
M075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)
M34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA<#H@
MI^2DHZCLJ=*[W:UNJKH@24U!4""IM:;YKDVE\RXB"@HC.B!L:6(O2&]R9&4O
M075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K
M<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:W)B-3H@
MI^2DHZCLJ=*[W:UNJKH@:W)B-2"IM:;YKDVE\RXB"@HC.B!L:6(O2&]R9&4O
M075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG('5S
M97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS
M9W-T<B`B075T:%]L9&%P.B"W<[Q7J,^ESJK,LV^VM:5<K^"EV*MEJ,.DHZ3D
MM*FEV+_]JD&PR"(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C,U-PIM
M<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R
M=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(D%U=&A?;&1A<#H@
MIU*PHZC/I<ZJS+-OMK6E7*_@I=BK9:C#I*.DY+2II=B__:I!L,@B"@HC.B!L
M:6(O2&]R9&4O075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!2
M97%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?;&1A<#H@I^2DHZCLJ=*[W:UNJKH@3$1!4""IM:;YKDVE\RXB"@HC.B!L
M:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R(")!=71H7VQD87`Z(+5,
MJFNW<[Q7J,^ESJK,("5S+B"F^*I!OKFF7L"S.B(*"B,Z(&QI8B](;W)D92]!
M=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD
M87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD
M87`Z(+5,JFNROK"CJ,^ESJK,("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A
M<"YP:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA
M8FQE('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@M4RJ
M:Z?SMW.HSZ7.JLP@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HT
M,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U
M<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B075T:%]L
M9&%P.B"G\[=SJ,^ESJK,LV^VM:5<K^"EV*MEJ,.DHZ3DM*FEV+_]JD&PR"(*
M"B,Z(&QI8B](;W)D92]!=71H+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC
M86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]M8V%L.B"GY*2CJ.RITKO=K6ZJNB!-0T%,(*FUIOFN3:7S+B(*
M"B,Z(&QI8B](;W)D92]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB
M875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")!=71H7W-M8F%U=&@Z(*?DI*.H[*G2N]VM;JJZ('-M8F%U=&@@
MJ;6F^:Y-I?,N(@H*(SH@;&EB+TAO<F1E+TE-05`O061M:6XN<&AP.C$P-@IM
M<V=I9"`B075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+B(*
M;7-G<W1R("))34%0(*;XJD&^N<7GP]*_^;M^+B(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO
M;B!F86EL960B"FUS9W-T<B`BQ>?#TJ6BL=$N(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HV-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`BQ>?#TJ6BL=$N("5S(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@(E)!1$E5
M4R#%Y\/2O_F[?BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#<Q"FUS9VED(")!
M=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B
M1E10(,7GP]*_^;M^+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HW,`IM<V=I9"`B
M075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G
M<W1R(")334(@Q>?#TK_YNWXN(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`BI6FE
MSJJZQ.:F[#HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S$@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(D%Z97)B86EJ
M86X@**C(MNNK]+5-*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM
M<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A
M8VMG<F]U;F0B"FUS9W-T<B`BK4FTNB(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L
M;W(B"FUS9W-T<B`BK4FTNL-#IN(B"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U
M+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R
M(")K97)B97)O<R"Q2[U8O_F[?BXB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U
M+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R
M(")K97)B97)O<R"HSZ7.JLRF5[K9O_F[?BXB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM
M<V=S='(@(D)A:&%M87,@**3:JZ*PJ"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"86AR86EN(@IM<V=S
M='(@(D)A:')A:6X@**3:JDPI(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M-S,*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(JIIP[FJ
MNJ[\I.4@*$E33RTX.#4Y+3$S*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HS-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T
M<B`B0F%N9VQA9&5S:"`HJ7.E6ZG4*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HS,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S
M='(@(D)A<F)A9&]S("BDVJBIIF@I(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N
M<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER
M96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(J?DI*.H[+G/I=RE
MV+_](%PB)7-<(BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(K#R
MO74B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#D@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C,P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8S"FUS9VED(")"96QA<G5S(@IM<V=S='(@(D)E;&%R=7,B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C,Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"
M96QG:75M(@IM<V=S='(@(D)E;&=I=6T@**3QIU&NR2DB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C,R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QI
M>F4B"FUS9W-T<B`B0F5L:7IE("BHJ:B]M+4I(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C0P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N:6XB"FUS
M9W-T<B`B0F5N:6X@**BIN><I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C0Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R(")"
M97)M=61A("BFRKQ]N48I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0V
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(D)H=71A
M;B`HI*.DIBDB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`BI<VDZ2(*"B,Z(&QI8B](
M;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HS-30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@
M9F]U;F0N(@IM<V=S='(@(J?DI*.H[,"SI<ZU>Z:A7"(E,B1S7"*JNK#/MO1<
M(B4Q)'-<(BXB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3`*
M;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(K#/MO2S7:EW(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4
M>7!E(@IM<V=S='(@(K#/MO2KK+I!(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(K+*
MQ>DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C,V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@(D)O;&EV:6$@**S!IU&Z^ZC(
M*2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#<*;7-G:60@(D)O
M;VMM87)K<R(*;7-G<W1R("*NT<72(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM
M<V=S='(@(J[8O74B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R
M("*NV+UUI&JD<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`BKMB]
M=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B0F]S
M;FEA(&%N9"!(97)Z96=O=FEN82`HJFFD:*6GJ,BDSK;"P<FM]+K[J+HI(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")";W1H(@IM<V=S
M='(@(J7^LZ$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R(")";W1S=V%N82`H
MJFFEOJBZ*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(JFSLZ$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS
M9VED(")";W5V970@27-L86YD(@IM<V=S='(@(D)O=79E="!)<VQA;F0B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#0@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C0P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS
M9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)A>FEL("BDVJ;H*2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C0Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"
M<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B0G)I=&ES
M:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C0R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S
M<V%L86TB"FUS9W-T<B`B0G)U;F5I($1A<G5S<V%L86T@**A:M=PI(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,W(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HT,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0G5L9V%R:6$B"FUS9W-T<B`B0G5L9V%R:6$@**M/I5NG4:C(*2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G
M:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`BMK6EV++%N+DB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C0T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"
M=7)K:6YA($9A<V\B"FUS9W-T<B`B0G5R:VEN82!&87-O("BEK+18K\>J:Z_!
M*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B0G5R=6YD:2`HNUJVJ:9A*2(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#8*;7-G:60@(D--4R(*
M;7-G<W1R("*JJ:VQNMZR>B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(D-23"!$:7-T<FEB=71I
M;VX@4&]I;G1S(@IM<V=S='(@(D-23""DP+.APDDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@
M(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`BP'BF<Z[FI+JN92XN+E]E
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,0IM<V=I9"`B
M0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`BI]:H^JKL
MJ6RDQJE\I;RGN::H+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT.#(@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDX-PHC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34W"FUS9VED(")#86QE;F1A<B(*;7-G
M<W1R("*FYJC&ON0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C,U"FUS9VED(")#86QM(@IM<V=S='(@(KESK\6MMR(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C0V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")#86UB
M;V1I82(*;7-G<W1R(")#86UB;V1I82`HK%JN2+GK*2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R
M;V]N(@IM<V=S='(@(D-A;65R;V]N("BSV+/!MJDI(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S
M<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(N(@IM<V=S='(@(K5,JFNFV[#*K:NX;;%+O5@LO=#!<+6XIT&JNJATLLZZ
MWK)ZK?LN(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HS-3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R
M("*U3*IKO&>D2L#)KM<@7"(E<UPB(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C(R"FUS9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@
M:&%N9&QE<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S
M+G!H<#HR,S4@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@
M)7,B"FUS9W-T<B`BM4RJ:[-SO76FW"!)34%0(*;XJD&^N3H@)7,B"@HC.B!L
M:6(O1FEL92]#4U8N<&AP.C0T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG
M="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R("*U3*IKMGVQTL#)KM<@7"(E
M<UPB+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G<W1R(")#86YA9&$@**5;KK.D:BDB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R("*H^J[X
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@
M(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("*H^J[XL-W#1*9>L_@B
M"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S(S"B,L('!H<"UF;W)M870*;7-G:60@
M(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(K5,JFNG4K"C
MP,FNUR!<(B5S7"(N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#86YN;W0@9FEN
M9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(J?DI*.H[+S(IG.E
MV+_]+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N
M;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*
M;7-G<W1R("*ORJ36("=T87)G971&:6QE)R"PT;S&M4RJ:\1^Q/*S0K)Z+B(*
M"B,Z(&QI8B]61E,O9G1P+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("*U3*IK
MLKZPHZ78O_T@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]$871A5')E92YP:'`Z
M,3(X(&QI8B](;W)D92]$871A5')E92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB
M"FUS9W-T<B`BM4RJ:[*^L*,[("5D(*W3I&RVL*1WIG.F8BXB"@HC.B!L:6(O
M2&]R9&4O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R
M96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E
M<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("*U
M3*IKK:NRU:%#J=*THZC1JKJP3[_]O,:EV+M0I?VK9:G2P'BF<ZJZN.JNQJ2C
MLL4N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*
M;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB
M97(N(@IM<V=S='(@(K5,JFNVQ[!EPK*P5*CLJ_RI=ZJZN+F]6"XB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C0Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS9VED
M(")#87!E(%9E<F1E(@IM<V=S='(@(D-A<&4@5F5R9&4@*+K[O'>HI"DB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(T"FUS9VED(")#87!T:6]N(@IM<V=S='(@(KNAJ?JDY:9R(@H*(SH@;&EB
M+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*(RP@9G5Z>GD*;7-G:60@
M(D-A<G)I97(B"FUS9W-T<B`BK[NL]:;B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDS"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T
M<B`BI,##_KM0O-#%TB(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S4@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@V"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R
M(")#87EM86X@27-L86YD<R`HMGVPTKASKG$I(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS
M9W-T<B`BIN:PRKEQN-PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(U"FUS9VED(")#96QL(%!R;W!E<G1I97,B
M"FUS9W-T<B`BP'BF<Z[FI+JN92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM
M<V=S='(@(L!XIG.NYKG4I5(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T
M:65S(@IM<V=S='(@(L!XIG.NYJ2ZKF4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG
M.B(*;7-G<W1R("+`>*9SKN:VH;9:.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,C<X"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`BIN:PRKEQN-PB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-`IM<V=I9"`B0V5L=&EC("A)4T\M
M.#@U.2TQ-"DB"FUS9W-T<B`BMNNZN*]3I.4@*$E33RTX.#4Y+3$T*2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R("*X;:2D(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C4T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU
M,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A
M;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(D-E;G1R86P@069R:6-A;B!2
M97!U8FQI8R`HI*2K1*9`J4VPZBDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W-0IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS
M9W-T<B`BI*2\VB`H25-/+3@X-3DM,C`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G
M<W1R("*^S,/2LM.X8"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-C$R"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R("*^S,/2OM:F
MLZK,(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@
M(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(K[,P]*L1K6F(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS
M9VED(")#:&%D(@IM<V=S='(@(D-H860@**QDO'<I(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHY-@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(J?SI^\B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G:60@(D-H86YG92!9;W5R
M(%!A<W-W;W)D(@IM<V=S='(@(J?SI^^G0:JZL4N]6"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV.0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N
M9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@
M<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(J?SI^^G0:JZJKJE
M_J97I4BDSJ9>MFRF8:=]+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N
M;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@
M("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("*EV*ME
MJKJS7:EWJ,.EO*3DM*FQ2[U8Q=RG\RX@O=#!<+6XIT&JNKK>LGJM^RXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(J9RI+@B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@
M(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(L#+K&2S<[6R+BXN7VLB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C4S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED
M(")#:&EL92(*;7-G<W1R(")#:&EL92`HM+RG42DB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4T
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EN82(*
M;7-G<W1R(")#:&EN82`HI*2PZBDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W-@IM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S
M='(@(L*RQ>FDI*3E("A'0C(S,3(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ-S<*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S
M='(@(J6_Q>FDI*3E("A":6<U*2(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N
M:6YC.C<*;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB"FUS9W-T<B`BO^^^
MW,"SI<ZU>Z:A.B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C<P
M"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R("*_[[[<L4N]6"(*
M"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O
M<V4@82!U<V5R;F%M92(*;7-G<W1R("*_[[[<I$"MTZC/I<ZJS*97NMDB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`R"FUS9VED(")#:&]O<V4@:&]W
M('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(J3IM,'%XZ7<I.BFH3HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D
M97)E9"!L:7-T<RDB"FUS9W-T<B`BO^^^W+:UI=BKK+I!JKJMMZ[F(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HU-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I
M9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R(")#:')I<W1M87,@27-L86YD
M("BX=+W/KG$I(@H*(SH@;&EB+U9&4RYP:'`Z.3$S(&QI8B].970O4TU3+G!H
M<#HR.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O
M9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(J?DI*.H["`E<R"JNL/^IT^I=[AQ
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T
M"FUS9VED(")#;&5A<B(*;7-G<W1R("*TN"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F
M:6-E('1A9W,B"FUS9W-T<B`BLDVPH[=,LVX@3V9F:6-E(+S0Q=(B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS9VED(")#;&5A<B!1=65R>2(*;7-G
M<W1R("*R3;"CK&2XWR(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R
M+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E
M<R(*;7-G<W1R("*R3;"CJ,^ESJK,.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R
M("*R3;"CJ,^ESJK,(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI
M;F,Z,S0*;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R("*R3;"CJ,^E
MSJK,JKJXZJ[&(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`BL=_"X+2X
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(JOVM\:YJ\'D
MI4C$?L3R(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ
M.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B0VQI8VMA
M=&5L;""S>KE,($A45%`B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I
M;F1O=R(*;7-G<W1R("+#]K.LM?BUH2(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C0T"FUS9VED(")#;&]U9',B"FUS9W-T<B`BMK.V<2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V"FUS9VED(")#;&]U
M9',@16%R;'DB"FUS9W-T<B`BIJVF:+:S(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R
M("*SL2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@
M(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]S:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G
M<W1R("*GZ<5\N.JNQJ>H(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E
M<G,B"FUS9W-T<B`BI^G%?,/DK,DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;VQO;6)I82(*;7-G<W1R
M(")#;VQO;6)I82`HK?2MVZ3QJ,@I(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H
M<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R
M(@IM<V=S='(@(L-#IN(B"@HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO
M;BYP:'`Z,S(U(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C8*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,"!S97)V
M:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0
M:6-K97(B"FUS9W-T<B`BO=6FXKU,(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(X,S4*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B,3:V::;L
MPT.FXJ5.O5@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`BQ.8Z(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$Y-3`*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS
M9W-T<B`BQ.:F[+S0PT0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C8V"FUS9VED(")#;VUI8W,B"FUS9W-T<B`BI62S<2(*"B,Z(&%D;6EN+V-M
M9'-H96QL+G!H<#HR-0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R("*I4J5/(@H*
M(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL
M(@IM<V=S='(@(J?EIKBI4J5/(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-#$S"FUS9VED(")#;VUM96YT(@IM<V=S='(@(K7[O=<B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B0V]M;6]N($YA;64B
M"FUS9W-T<B`BNMFI22(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(D-O;6]R
M;W,@**SLO*_#N2DB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R("*DO:5Q(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T
M<B`BN7&XHR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#8*
M;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R("+`]+G2(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-#D*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`BL?BE
M\R(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U
M<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(JYTLJ<B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S
M>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM
M<V=S='(@(KM0(%!$02"T>*17JZRY<;BC++2\O'JKK*3BOO>E2*3.($]U=&QO
M;VL@JKJF4*A"LUVI=RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,U
M"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R
M("*S7:EWN.JNQKE,M,$N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B
MLUVI=R`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`BO52[>[%+O5@B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-34@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C4Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V
M"FUS9VED(")#;VYG;R(*;7-G<W1R(")#;VYG;R`HK>BJ1RDB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C8P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#
M;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@
M(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4@**WHJD>F
M0*E-L.HI(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y
M.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#
M;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`BLW.ULJ6BL=$N(@H*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.2!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE
M9#H@(@IM<V=S='(@(K-SM;*EHK'1.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`BLW.ULJ;<I+VV?:KWQE^F^*I!
MOKFNR;Y$J=HN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-SDR"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(K-S
MM;*FW*2]MGVJ]\9?IOBJ0;ZYKLF^1*G:+B"M[*9=.B`E<R`H)7,I(@H*(SH@
M;&EB+U9&4R]F='`N<&AP.C@V-0IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@
M<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`BLW.ULJ;<($944"#`R:[7IOBJ0;ZY
MI:*QT2XB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`Q-`IM<V=I9"`B
M0V]N=&%C=',B"FUS9W-T<B`BLW.UN*1((@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C
M97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@
M(K!/O_VD=Z:HI5RF8;=SO%>FW*=!JKJS<;!4O_VDI"XB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=&=Z+G!H<#HV,`IM<V=I9"`B0V]N=&5N="!T>7!E
M(&]F(&-O;7!R97-S960@9FEL93H@(@IM<V=S='(@(L"CP5G`R:[7JKJDNJYE
MJZRZ03H@(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W1G>BYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(EPB)7-<(B#`R:[7I+JN92(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B
MQ'[$\B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R(")#;V]K($ES;&%N
M9',@**SLITJX<ZYQ*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@HC
M+"!F=7IZ>0IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(L-#IN(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C$*
M;7-G:60@(D-O<'DB"FUS9W-T<B`BO<:[<R(*"B,Z(&QI8B]61E,O<VUB+G!H
M<#HT-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM
M<V=S='(@(KW&NW.EHK'1.B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM
M<V=S='(@(KW&NW,B"@HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3<P
M(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8S(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R(")#;W-T82!2
M:6-A("BM]+2UI&J^I*5;*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T
M<B`B0V]T92!D)TEV;VER92`HMDBD^J[\J:0I(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z.3<W"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@
M;65S<V%G93H@(@IM<V=S='(@(K5,JFNE2"!01U`@I5NQ2[9LI?,Z("(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P-34*;7-G:60@(D-O=6QD(&YO
M="!01U`@<VEG;B!M97-S86=E.B`B"FUS9W-T<B`BM4RJ:Z5((%!'4""P]:;F
MMFRE\\.QL[DZ("(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,SDS
M"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS
M9W-T<B`BM4RJ:Z5((%,O34E-12"E6[%+MFRE\RXB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S
M:6=N(&UE<W-A9V4N(@IM<V=S='(@(K5,JFNLL"!3+TU)344@MFRE\\.QL[DN
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM
M<V=S='(@(K5,JFNW<[Q7LW.UN*1(+B`E<R(*"B,Z(&QI8B](;W)D92]'<F]U
M<"]L9&%P+G!H<#HY-B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ,C$*;7-G
M:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("*U
M3*IKP[2ULB!,1$%0(*;XJD&^N2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HT-3<*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R(@IM
M<V=S='(@(K5,JFO#M+6R(&QD87`@IOBJ0;ZY(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C$U-B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`BM4RJ:\#+K&2W;*]Q+B`E<R(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-#$*;7-G:60@(D-O=6QD(&YO
M="!C;VYN96-T('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(K5,JFNS<[6RIMP@
M;&1A<""F^*I!OKDB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R
M(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(K5,JFNS<[6RIMRF^*I!
MOKD@7"(E<UPB(*C/I<X@1E10.B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`BM4RJ
M:ZO8I=^P=+AMN'.RU2X@)7,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HQ,3(X"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@(@IM
M<V=S='(@(K5,JFNXT;%+(%!'4""XZJ[&.B`B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C4R,PIM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-
M24U%(&1A=&$N(@IM<V=S='(@(K5,JFNXT;%+(%,O34E-12"XZJ[&+B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G
M<W1R("*U3*IKIU*PH[-SM;BD2"X@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(K5,
MJFNG4K"CL'2X;;)-L^8N("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S
M971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(K5,JFNG4K"C
MI_.W<[5[IJ$@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z,S@Q(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U
M;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E
M<W,N(@IM<V=S='(@(K5,JFNH3:EWIJRE\Z1(JKJY<:1LMFRE\Z;LIWTN(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B
M0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T
M<B`BM4RJ:\#RJ/JGN;[CJKJS<;!4O_TN(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O
M;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("*U3*IKP/*H^J>Y
MON.JNK!TN&VR3;/F+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@
M;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(K5,JFO`\JCZ
ML'2X;;)-L^:DI*JZN'.RU2XB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L
M3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(K5,JFNX
M_*1*M::RI"!<(B5S7"(N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(K5,
MJFNKV*7?I=B__2!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O
M;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R("*U3*IKIMNJ]\9?IOBJ0;ZYJ/JQ
M;Z2]MGVJ]\9?+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(K5,JFNV
M?;'2(%PB)7-<(B"E2+QGI$HN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8W-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,T-0HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("*U3*IK
MMGVQTB`E<RXB"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C0R,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC
M95]487-K(&UO9'5L92`E<R(*;7-G<W1R("*U3*IKMGVQTKK[Q4"D=:=`O-*R
MU2`E<R(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O
M<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(K5,JFNV?;'2I=B__2!<
M(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$Q,2!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HR,S<@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!L
M:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-3$V(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HV,3(*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8U-B!L
M:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-CDY"FUS9VED(")#;W5L9"!N;W0@
M<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("*U3*IKLW.QM2!,1$%0
M(""F^*I!OKDN(@H*(SH@;&EB+U9&4R]/8FIE8W0N<&AP.C(T,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`BM4RJ
M:\6JJ/H@)7,N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*
M;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H
M92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I
M;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*
M;7-G<W1R("(B"B*U3*IKK:NW<[-=J7>HSZ7.JLRJNK%+O5@N(+.AI,"JNK+3
MN&"DHZ6_O50N(+W0P7"UN*=!JKJH=++.NMZR>JW[I4BH\Z=5LT*R>BXB"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#`*(SH@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,W-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S@S"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M.#D*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`BM4RJ
M:\6JJ/JF<ZCZL;&H[JKM*$%C8V5S<R!#;VYT<F]L($QI<W0I(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*
M;7-G<W1R("*U3*IKQ:JH^K-QL%2__2X@)7,B"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`BM4RJ:\6JJ/JP=+AMLDVE52X@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@
M(K5,JFO%JJCZL'2X;;)-I54N("5S(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$Y.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,C$Y"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I
M97,B"FUS9W-T<B`BM4RJ:\6JJ/JF^*I!OKFJNJS;P_:O4ZG*(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T(')E=F5R
M="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("*U3*IKIEZT7[-=J7<N(@H*(SH@
M;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<
M(BXB"FUS9W-T<B`BM4RJ:Z=2L*.EV+_](%PB)7-<(BXB"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("*U3*IKP'BF
M<R`E<R"JNK-=J7<N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@<V%V
M92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(K5,JFO`>*9SL\:E
M][-=J7<N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A
M=&EO;CH@)7,B"FUS9W-T<B`BM4RJ:\!XIG.SQJ7WLUVI=SH@)7,N(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB
M)7-<(BXB"FUS9W-T<B`BM4RJ:\!XIG.G\[=SM7NFH:CL.B!<(B5S7"(N(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@
M9FEL92`E<RXB"FUS9W-T<B`BM4RJ:\!XIG.SQJ7WLUVI=R`E<RXB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@
M<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE
M(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*(K5,JFO`>*9SLUVI=\#)
M)7,N(*=!I6FE2*C/I<XE<Z2DJKJHY*5,I5ROX,!XIG.S7:EWJ<ZDXK#*O<:[
M<Z15K;&U>Z:AO5BH["`E<RXB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H
M<#HQ-#,*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R
M+B(*;7-G<W1R("*U3*IKMVJT32!,1$%0(""F^*I!OKDN(@H*(SH@;&EB+U9&
M4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM
M<V=S='(@(K5,JFNG4K"C(%PB)7-<(BXB"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`BM4RJ:Z?SMW.S<[6X
MI$@N("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("*U3*IKI_.W<[!TN&VR3:55+B`E
M<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E
M<UPB.B`E<R(*;7-G<W1R("*U3*IKPM"\9R!<(B5S7"(Z("5S(*JZLUVI=RXB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<P"FUS9VED(")#;W5L9&XG
M="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED
M96)A<B!I<R!O<&5N+B(*;7-G<W1R("*GY*2CJ.P@36]Z:6QL82"JNJ3`K;8N
M(+W0O52[>Z3`K;:L3Z=?MGVQTBXB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD
M;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R
M('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R("*U3*IKO>&DJ:C/I<ZJ
MS"!<(B5S7"(@I%6F0\5VK:VH[*M(I?.G6"!<(B5S7"(Z("5S(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$T,C,*;7-G:60@(D-O=6YT960@=&5X="(*;7-G
M<W1R("*GWK-.I7DB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W
M,`IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R("*PZJYA(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(W-0IM<V=I9"`B0V]U<G-E<R(*;7-G<W1R("*]
MTJKM(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`BJ]BEWR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R("*KV*7?I$"M
MT[-SM;(B"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC
M.CDT"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(JO8I=^D0*W3
MMW.JNB(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM
M<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(JO8I=^FN*M(I?.G
M6"(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A
M=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(JO8I=^JS*JZQ7:MK2(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HS,C$Y"FUS9VED(")#<F5D:70@8V%R9"!N=6UB
M97(B"FUS9W-T<B`BJTBESJ5DN+F]6"(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S
M='(@(D-R;V%T:6$@**=*P[FFZ*C(*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HV-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B
M0W5B82`HI6JDVBDB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*(RP@9G5Z
M>GD*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`BI=BK9:JZI.NL
MVR(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`IM<V=I9"`B0W5R<F5N="!3
M97-S:6]N<R(*;7-G<W1R("*EV*MEMWRTP2(*"B,Z(&QI8B]";&]C:R]T:6UE
M+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4
M:6UE(@IM<V=S='(@(J78JV6NR;:A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT
M(%523"!I<R(*;7-G<W1R("*EV*MENO2G?2(*"B,Z(&%D;6EN+W-E<W-I;VYS
M+G!H<#HS-0IM<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R("*EV*MEJKJH
MSZ7.JLPB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED(")#=7)R
M96YT(%=E871H97(B"FUS9W-T<B`BI=BK9:31KO`B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C8T"FUS9VED(")#=7)R96YT(&-O;F1I=&EO
M;CH@(@IM<V=S='(@(J78JV6JNJJLJG`Z("(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y
M;&4B"FUS9W-T<B`BI=BK9:JZK;>NYB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS
M('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R("*FVZUQI$"HQ[5N
MI$HE<ZOAJ=*M;K#UIN:JNJ1UIT`N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS
M9W-T<B`BL,6D52(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`BL,6D
M52(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R(")#>7!R=7,@*,')M+:PQ[2U*2(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")#>7)I;&QI8R`H
M2T])."U2*2(*;7-G<W1R("*FZ*B]NKBDY2`H2T])."U2*2(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ
M,C4Q*2(*;7-G<W1R("*FZ*B]NKBDY2`H5VEN9&]W<RTQ,C4Q*2(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI
M86X@*$M/23@M52DB"FUS9W-T<B`BINBHO;JXI.4OKU&G2L3UI.4@*$M/23@M
M52DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C8W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R(")#>F5C:"!297!U
M8FQI8R`HL;:G2J9`J4VPZBDB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED
M(")$1"(*;7-G<W1R("*DZ2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C<P
M"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A
M;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S
M='(@(B(*(KCJKL:HT[>]IE>ZV2`HO="PT:;2(&AT='`Z+R]P96%R+G!H<"YN
M970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M(@HB9'-N
M+G!H<"DB"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED
M(")$86EL>2(*;7-G<W1R("*H0Z3I(@H*(SH@861M:6XO9&%T871R964N<&AP
M.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(K[PJJRXZJ[&
MPG/$_2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C8X"FUS9VED(")$871A
M8F%S92!,;V]K=7`B"FUS9W-T<B`BN.JNQJYWMVJT32(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR-#`R(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C<R"FUS9VED(")$871E(@IM<V=S='(@(J3IM,$B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E
M:79E9"(*;7-G<W1R("*FK*CLI.FTP2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR-SDV"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R("*_[[[<I.FT
MP2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#$@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B1&%Y(@IM<V=S='(@
M(J75I-$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@
M(J=2L*/$YJ;L7VPB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#$P(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`BI%&D1Z3K(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM
M<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(J11MFFF[+S&IG(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS
M9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`BM.ZDUL%9L<8B"@HC.B!L
M:6(O<')E9G,N<&AP.C$Q-R!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$X-PIM
M<V=I9"`B1&5F875L="(*;7-G<W1R("*Y=[-=(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*;7-G:60@(D1E9F%U;'0@
M0V]L;W(B"FUS9W-T<B`BN7>S7<-#IN(B"@HC.B!L:6(O2&]R9&4O261E;G1I
M='DN<&AP.CDV"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@(KEW
MLUVJNJBMI??#T:=/(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"FUS
M9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(KEWLUVI4J5/N-&J4KZY*%-H
M96QL*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F
M:6YI=&EO;G,B"FUS9W-T<B`BJ7>X<2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-S$@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C8@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HT,C(*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,SD@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHS-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C<P('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3,*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHY."!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E
M;&5T92YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R("*G4K"C(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"FUS9VED
M(")$96QE=&4@0V5L;"(*;7-G<W1R("*G4K"CP'BF<Z[F(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*;7-G:60@(D1E
M;&5T92!'<F]U<"(*;7-G<W1R("*G4K"CN'.RU2(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(T.0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R
M("*G4K"CK/:__2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-S<@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T92!097)M:7-S
M:6]N(@IM<V=S='(@(J=2L*/%=JVM(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A
M9V5S(@IM<V=S='(@(J=2L*.A0K)-JL6V;*7S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L
M971E(&-E;&PB"FUS9W-T<B`BIU*PH\!XIG.NYB(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E
M;&5T92!C;VQU;6XB"FUS9W-T<B`BIU*PH\3FINPB"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T
M92!T96UP;&%T92(*;7-G<W1R("*G4K"CLGNF<ZJZM,"E3KS+JD\B"@HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("*G4K"C
M7"(E<UPBJKK%=JVM(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<
M(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(KU4J7>M
M;J=2L*-<(B5S7"*JNL5VK:VE2*3.IKC%=JVM(#\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$
M96QE=&4@<F]W(@IM<V=S='(@(J=2L*.F0R(*"B,Z('1E;7!L871E<R]P<F5F
M<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E
M9"!I9&5N=&ET>2(*;7-G<W1R("*G4K"CJ=*_[[[<JKJHK:7WP]&G3[CJKL8B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS
M9W-T<B`BIU*PHZ78JV6JNL3FINPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T
M:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`BIU*PHZ78JV6JNJ9#(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@
M(J?SMW.U>Z:A(%PB)7-<(B"D=Z=2L*,N(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V,R!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3DU"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(Q(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS9VED
M(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(KN\L&6NR;:A(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C<Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HV.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N
M;6%R:R(*;7-G<W1R(")$96YM87)K("BDIK/!*2(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O
M8FQE;2(*;7-G<W1R("*PW<-$M'FM>B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HY-#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`BM'FM>B(*"B,Z
M(&QI8B](;W)D92YP:'`Z,3DW"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO
M<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(K+3N&`@*+W0L-&FTB!(;W)D92"P
M3[_]P,FNURDZ(@H*(SH@;&EB+TAO<F1E+G!H<#HR,#$*;7-G:60@(D1E=&%I
M;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(K+3N&"]T+#1IM*H=++.NMZR>K5NO_TN(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(R,0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T
M<B`BK..U;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$W"FUS9VED(")$
M97<@4&]I;G0B"FUS9W-T<B`BQ5/"2;?%J]<B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(Y-`IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*
M;7-G<W1R("*SS*OAI$"D<*[)JKK%4\))M\6KUSH@(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Q-@IM<V=I9"`B1&5W('!O:6YT.B`B"FUS
M9W-T<B`BQ5/"2;?%J]<Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I
M9VAT(@IM<V=S='(@(K%QI:JFW*5K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT
M('1O(&QE9G0B"FUS9W-T<B`BL7&E:Z;<I:HB"@HC.B!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(J78O_TB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<P"FUS9VED(")$:7-P;&%Y(#(T
M+6AO=7(@=&EM97,_(@IM<V=S='(@(J5((#(T(*1PKLFH[L7CI=P_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,`IM<V=I9"`B1&ES<&QA>2!/<'1I
M;VYS(@IM<V=S='(@(L7CI=R_[[:U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C@Y"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T
M(@IM<V=S='(@(L7CI=RXU++3JKJY=[/X(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HX-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R
M("+%XZ7<N7>S^"`H5$%&*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#`V
M"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R("+%XZ7<KN:FH2(*"B,Z
M(&QI8B](;W)D92]-24U%+TU$3BYP:'`Z,3DP"FUS9VED(")$:7-P;W-I=&EO
M;B!.;W1I9FEC871I;VXB"FUS9W-T<B`BML>P9:9>L?@B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C8Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$:FEB
M;W5T:2(*;7-G<W1R(")$:FEB;W5T:2`HIDZEK*9A*2(*"B,Z(&QI8B](;W)D
M92]097)M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S
M='(@(J2CIU*PHR(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM
M<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B
M"FUS9W-T<B`BI*.M;JJ]L;6F<ZCZ(&UA:6YT96YA;F-E+G!H<"(*"B,Z('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$R('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I
M;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM
M<V=S='(@(K+$I$"UI[!/O_VL3Z=?I5VG=,3FINRF5[K9/R"F<*I'K$^]T*3$
MO^\N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B1&]M:6YI8V$@**9HJ?JE
MIZ5;*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R(")$;VUI
M;FEC86X@4F5P=6)L:6,@**9HJ?JEIZ5;ID"I3;#J*2(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C
M;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`BP=FH4Z:SL6*XN;;</R"U^:55+B(*
M"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-3$*;7-G:60@(D1O
M=VYL;V%D(@IM<V=S='(@(J15N/PB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT
M96YT<RYP:'`Z.#4Q"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S
M(@IM<V=S='(@(J15N/P@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A
M<R!02%`@<V-R:7!T+B(*;7-G<W1R("*D5;C\LUVI=\#)KM>E=*9SK+`@4$A0
M(+5[IJ$N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,3$*;7-G:60@(D1R
M;W`@9&]W;B!L:7-T(@IM<V=S='(@(J15J=2E7*_@JNTB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(L/$JWXB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D4M36%I
M;"(*;7-G<W1R("*Y<:1LMFRE\R(*"B,Z(&QI8B].970O4TU3+V=E;F5R:6-?
M<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E
M<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+VUO8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R("*_^;M^(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HW,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I
M9"`B16-U861O<B(*;7-G<W1R(")%8W5A9&]R("BDS*7*IFBZN"DB"@HC.B!L
M:6(O2&]R9&4O4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR
M-0IM<V=I9"`B161I="(*;7-G<W1R("*]<[_H(@H*(SH@;&EB+TAO<F1E+T)L
M;V-K+U5)+G!H<#HU,"!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS
M9VED(")%9&ET($)L;V-K(@IM<V=S='(@(KUSO^BPS[;T(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D
M:70@1W)O=7`B"FUS9W-T<B`BO7._Z+ASLM4B"@HC.B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C<V(&QI8B](;W)D92]097)M<R]522YP:'`Z,3`P"FUS9VED
M(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`BO7._Z,5VK:TB"@HC.B!S97)V
M:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I
M;VYS(@IM<V=S='(@(KUSO^C%=JVM(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D
M:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I
M;VYS(&9O<B`E<R(*;7-G<W1R("*]<[_H)7.JNL5VK:TB"@HC.B!T96UP;&%T
M97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*
M;7-G<W1R("*]<[_HO^^VM2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R
M(%PB)7-<(B(*;7-G<W1R("*]<[_H7"(E<UPBJKK%=JVM(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("*]<[_H)7.JNL5VK:TB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO
M;B(*;7-G<W1R("*QT*A\(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B16=Y<'0@
M**Y*I,XI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R(")%;"!386QV
M861O<B`HPL2ZN*7+IF@I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM
M<V=S='(@(J2XI?,N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$X-S,@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HR,C0*;7-G:60@(D5M86EL(@IM<V=S='(@(KEQI&RV;*7S(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C8@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C8X"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@
M(KEQI&RV;*7SINVG?2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.38W"FUS
M9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`BN7&D
M;+9LI?.F[:=]I;*VMZ=KIE@N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y
M.3,*;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(KEQ
MI&RV;*7SO52[>R(*"B,Z(&QI8B].970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z
M.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@(D5M86EL
M+71O+5--4R"Y:+E$OKDB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,CDW"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T<B`BJNVQH;+%
MN+DB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM
M<V=I9"`B16UP='D@;65S<V%G92XB"FUS9W-T<B`BJL6EU:M(I?,N(@H*(SH@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C(T,R!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z-#@T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV-C(@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!L:6(O2&]R9&4O075T
M:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B
MJL6EU;6RJD<N(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,3$S
M"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`BJL6EU;=JM$VV
MM:78(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T-PIM<V=I9"`B16YA
M8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@
M:6X@=&5X=#\B"FUS9W-T<B`BI+FS7*;;P\"T6;2AI$JWTZ3YJ.RK2*7SI*0H
MNO2MMKUSO&>\TJ:A*2`_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R
M,@IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS
M9W-T<B`BL=*PRK?&N:NE:\'DI5ROX*KM/R(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR-3DR(&QI8B](;W)D92]&;W)M+G!H<#HR.#`P"FUS9VED(")%;F0@
M>65A<B(*;7-G<W1R("*ULJ?TIGZE]R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R
M(@IM<V=S='(@(JGQI&J]<[_HOKDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C(T"FUS9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H
M:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO
M=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U
M<B!P970_)SHB"FUS9W-T<B`BIG"J1Z=!N]VM;JVKLUVQ2[U8++W0O^FD2J1`
MK=.F=Z7^L-VE>2RHTJ9P(">G0<-DJJNJNJ97NMD@/R<Z(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R
M"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`BIF*F
MN;_II$J\=KFSJKJZ]*=](@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C@X.0IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@
M(D5Q=6%T;W)I86P@1W5I;F5A("BHJKE$M%BDNJC(*2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HW.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R
M96$B"FUS9W-T<B`B17)I=')E82`HI,REWZ]3J+VF=RDB"@HC.B!L:6(O2&]R
M9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0X(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S8*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HX,@IM<V=I9"`B
M17)R;W(B"FUS9W-T<B`BO_F[?B(*"B,Z(&QI8B](;W)D92]496UP;&%T92YP
M:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L
M;V-K.B`E<R(*;7-G<W1R("*KV*7?L,^V]"5SKLFU;Z7-O_F[?B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R("*G
M4K"CIE"H0L'CPDDZ("5S(*[)M6^ES;_YNWXB"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D
M96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`BIU*PHZ90J$*P3[_].B`E
M<R"NR;5OI<V_^;M^(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HT-C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E
M<R(*;7-G<W1R("+%JJCZI+JN93HE<R"NR;5OI<V_^;M^(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R("*G\[=SL4N]
M6#H@)7,@KLFU;Z7-O_F[?B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`U"B,L(&9U>GIY"FUS9VED(")%<G)O<B!W:71H(&5M86EL
M(&UE<W-A9V4N(@IM<V=S='(@(KUSO^BD0*MHL%2NIR(*"B,Z(&QI8B]61E,O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T
M<B`BO&>D2B!<(B5S7"(@KLFU;Z7-O_F[?BXB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM
M<V=S='(@(D5S=&]N:6$@*+=2J$:EIZC(*2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HX,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM
M<V=S='(@(D5T:&EO<&EA("BFYZ_!I/&HR"DB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R("*ZV+':(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G
M<W1R(")%=7)O<&4@*+S:K'<I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,T,PIM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R("*H0R`Q-2"D
MP,3!(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,PIM<V=I9"`B179E
M<GD@,B!M:6YU=&5S(@IM<V=S='(@(JA#(#(@I,#$P2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-#`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM
M<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R("*H0R`S,""L[<3!(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,SDT"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`BJ$,@
M-2"DP,3!(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I
M9"`B179E<GD@3&]G:6XB"FUS9W-T<B`BJ$.FN+5NI$HB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S0T"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS
M9W-T<B`BJ$,@,S`@I,#$P2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,@IM<V=I9"`B179E<GD@;6EN
M=71E(@IM<V=S='(@(JA#(#$@I,#$P2(*"B,Z('1E;7!L871E<R]D871A+V1A
M=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B
MO62HTJW(.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S
M:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R-PIM<V=I9"`B17AE
M8W5T92(*;7-G<W1R("*P]:;F(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="YP:'`Z-#<U"FUS9VED(")%>'!A;F0B"FUS9W-T<B`BKFFV?2(*"B,Z('1E
M;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N9"!3
M:61E8F%R(@IM<V=S='(@(JYIMGVXZJ[&IZ@B"@HC.B!L:6(O2&]R9&4O4U%,
M+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R
M("*M;JA$("<I)R(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$W
M-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@
M=&5R;2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT
M,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("*H[+3!I.DB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8W-PIM<V=I9"`B17AP;VYE
M;G0B"FUS9W-T<B`BN-&[H:W[(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS
M9W-T<B`BJV6TNL-#IN(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W
M"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(D944""D5[;'
MLUVI=RXB"@HC.B!L:6(O2&]R9&4O4')E9G,O<W%L+G!H<#HR,C4*;7-G:60@
M(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R("+%JJCZ
ML+ZF;K-=J7>EHK'1(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C<U
M(&QI8B](;W)D92]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@
M8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`BM4RJ:[-SO76FW"!,
M1$%0(*;XJD&^N2XB"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP.CDX"FUS
M9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R
M("*U3*IKLW.]=:;<(%--0B"F^*I!OKDN(@H*(SH@;&EB+U9&4R]F='`N<&AP
M.C<P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M
M(%PB)7-<(BXB"FUS9W-T<B`BO<:[<Z6BL=&FVR!<(B5S7"(N(@H*(SH@;&EB
M+U9&4R]F='`N<&AP.C<Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@
M=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(KW&NW.EHK'1J.P@7"(E<UPB
M+B(*"B,Z(&QI8B](;W)D92]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL
M960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(K5,
MJFNKV*7?I$"MT[=SJKH@4T%33""S<[&U+B(*"B,Z(&QI8B]61E,O<VUB+G!H
M<#HU,#$@;&EB+U9&4R]F='`N<&AP.C<T-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(K=HLKZEHK'1
MJ.P@7"(E<UPB+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HT-C4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R("+"
M7JCZI:*QT3H@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R("*TMK-Q(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C@T(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HW.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B
M1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(D9A;&ML86YD
M($ES;&%N9',@JFO$]:=*NM:X<ZYQ("BPJ+JXNONOQ[2UN'.N<2DB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C@P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED
M(")&87)O92!)<VQA;F1S(@IM<V=S='(@(D9A<F]E($ES;&%N9',B"@HC.B!L
M:6(O2&]R9&4O0TQ)+G!H<#HR,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G
M<W1R("+$6:VKO_F[?CHB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(K;'KW4B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4Q"FUS9VED(")&87AE<R(*;7-G<W1R
M("*VQZ]U(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P,"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,X"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G
M:60@(D9E8G)U87)Y(@IM<V=S='(@(J1'I.LB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R("*W4,2Q(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,`IM<V=I9"`B1F5E
M;',@;&EK93H@(@IM<V=S='(@(K=0Q+$Z("(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*
M;7-G<W1R("*D\J3RJT(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R
M("*U=;S(L'VSMR(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.30X"FUS9VED
M(")&:65L9"!M871R:7@B"FUS9W-T<B`BQ.:F[+!]ID,B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S,R,PIM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,C<*(RP@9G5Z>GD*;7-G
M:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(K_OOMS`R:[7I4BVUZ1*.B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G
M:60@(D9I:FDB"FUS9W-T<B`B1FEJ:2`HM+3`V2DB"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(D9I;&4B"FUS
M9W-T<B`BP,FNUR(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP
M.C8P(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G
M:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`BP,FNU[S&I=@Z("5S
M(*W3P,FNUR(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8P
M(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(L#)KM>\QJ78.B`E<R#`
MR:[7(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P.0IM<V=I9"`B
M1FEL92!-86YA9V5R(@IM<V=S='(@(L#)KM?!8+K>(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S`*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z
M.#(*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R("+`R:[7IE>ZV2(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR.3@T"FUS9VED(")&:6QE('-E;&5C=&EO;B(*
M;7-G<W1R("+`R:[7O^^^W"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#DP
M"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R("+`R:[7I%>VQR(*"B,Z(&QI
M8B](;W)D92]"<F]W<V5R+G!H<#HX.#4*;7-G:60@(D9I;&4@=7!L;V%D<R!N
M;W0@<W5P<&]R=&5D+B(*;7-G<W1R("+`R:[7I%>VQZ5<K^"EO+-1I.2TJ2XB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3$*;7-G:60@(D9I;'1E
M<G,B"FUS9W-T<B`BN4S";[ZY(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C@R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R(")&
M:6YL86YD("BJXL3U*2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G
M:60@(D9I<G-T($AA;&8B"FUS9W-T<B`BI%>E8J3K(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER
M<W0@475A<G1E<B(*;7-G<W1R("*D5ZFV(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(U-0IM<V=I9"`B1FEX(')A=&EO(@IM<V=S
M='(@(JE4J7>D\:C2(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(S,`IM<V=I9"`B1FQI<"(*;7-G<W1R("*D5Z15Q$&MRR(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(J]"L,HB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S
M='(@(L/Z(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C(S-R!L:6(O5D93+VUU<W%L
M+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@
M;F]T(&5X:7-T(@IM<V=S='(@(J78O_T@)7,@I*.F<Z9B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N
M="!#;VQO<B(*;7-G<W1R("*F<JNLPT.FXB(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R("*MN:JK(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM
M86=E<R(*;7-G<W1R("*F7:RPPG/$_;ZYJ,.EO*3DM*F\=KFSI5ROX"XB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S-`IM<V=I9"`B1F]R96-A<W0@*%1!
M1BDB"FUS9W-T<B`BKO"V2+EWL_@@*%1!1BDB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-S(*;7-G:60@(B(*(D9O<F5C87-T($1A>7,@*&YO
M=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A
M>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S
M=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@HBN7>S^*31O,8@*+EW
ML_BDT;S&I5VL0:75I-&E2*3.J5VVH:JZN.JNQCNF<*I'N7>S^*31O,:X^ZKX
ML4ZF^Z7.I/&X^[QEM%2JNJJI(@HBK;$I(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*
M;7-G<W1R("*GT;!/L4N]6"`_(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0V-`IM<V=I9"`B1F]R;7,B"FUS9W-T<B`BJNVSYB(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R("*D
M<+MY(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T
M=6YE('1Y<&4B"FUS9W-T<B`BI'"[></^JZPB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(J1PNWDB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B
M"FUS9W-T<B`BI'"[>2`R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0U-0IM<V=I9"`B1F]R=6US(@IM<V=S='(@(KW7OL(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3$Q"FUS9VED(")&;W)W87)D<R(*;7-G<W1R
M("*FV[#*PN"K2"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(JQ0M,&DK2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*
M;7-G:60@(D9R86UE<R(*;7-G<W1R("*NV*Q;(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C@W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E(@IM
M<V=S='(@(D9R86YC92`HJFNPZBDB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B
M1G)A;F-E+"!-971R;W!O;&ET86XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM
M<V=S='(@(D9R96YC:"!'=6EA;F$@**IKQ-V[7*C(J+HI(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$X-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R
M96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B1G)E;F-H(%!O;'EN97-I82`HJFO$
MW:S!IU&EIZ;HJ,@I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET
M;W)I97,B"FUS9W-T<B`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@
M(D9R;VTB"FUS9W-T<B`BL4BE\Z1((@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(S-R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0Y
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.34*;7-G:60@(D9R
M;VT@=&AE("(*;7-G<W1R("*Q<2(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@
M(J>YON.T>:UZ(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C
M:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R("*ZH:3K
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-C`*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R
M("*E_J97(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B1V%B;VX@**5;M%XI(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@
M(L/`M%DZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDV(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(D=A;6)I82`HI<RD\:C(
M*2(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("*R
MHZ7-("5S(*W3J'2RSK-=J7<B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O
M8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B
MI'>RHZ7-JKJS7:EWN.JNQB(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B1V5O
M<F=I82`HL^RJ=JC(ID"I3;#J*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HV.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B
M1V5R;6%N>2`HO'>PZBDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3,@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N82(*;7-G<W1R(")':&%N82`H
MK7NOQRDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.30@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS9W-T<B`B1VEB<F%L=&%R("BJ
MO:6LP[FJ^RDB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-@IM
M<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R("*F5[K9(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z,3(*;7-G:60@(D=O(@IM<V=S='(@(JMEJ;DB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G
M<W1R("*M]+QWNK@B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$R.`IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B1V]O9VQE
M(*9AN<\B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")'
M;V]G;&4@4V5A<F-H(@IM<V=S='(@(D=O;V=L92"W:K1-(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-@IM<V=I9"`B1W)A>7-C
M86QE(@IM<V=S='(@(J;'MJ4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3`P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@(D=R
M965C92`HI\;#OBDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I
M9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(J?&P[ZDY2`H25-/+3@X
M-3DM-RDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.34@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B1W)E96YL86YD("BN
MYK.NQ/6N<2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#D@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@(F=R96YA9&$@**[F
MM^>OQ[E&*2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U
M<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R("*X<[+5NMZR>B(*"B,Z(&QI8B](
M;W)D92]'<F]U<"YP:'`Z-3D@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$V
M.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T
M<B`BN'.RU:97NMFDH[%OJL6EU2(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HS,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA
M8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9#H@(@IM<V=S='(@(D=R;W5P7VQD87`Z(+5,JFNW<[Q7N'.RU2`E<RX@
MIOBJ0;ZYIE[`LSH@(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$Q
M."!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&QI8B](;W)D92]'
M<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?
M;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R(")'<F]U
M<%]L9&%P.B"U3*IKIU*PH[ASLM4@)7,B"@HC.B!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z,S,X(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T
M92!G<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%P.B"U3*IKI_.W<[ASLM4@
M)7,B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W
M-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(KASLM4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDV
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO
M=7!E(@IM<V=S='(@(D=U861E;&]U<&4@**WTO'>LI;2V*2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.CDW"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'
M=6%M(@IM<V=S='(@(D=U86T@*,/VKG$I(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*
M;7-G<W1R(")'=6%T96UA;&$@**7*IF&PJ*G4*2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`BKN:NIJ;H
MKG$B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*
M;7-G<W1R("*HT[NKQ7:MK2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-S(*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R("*S6*O(KV2HI2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G
M:60@(D=U:6YE82(*;7-G<W1R(")'=6EN96$@*+18I+JHR"DB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3`T(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@
M(D=U:6YE82U":7-S874B"FUS9W-T<B`B1W5I;F5A+4)I<W-A=2`HM%BDNJC(
MI/&OP:9`J4VPZBDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`U(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R(")'=7EA;F$@
M*+M<J,BHNBDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.38T"FUS9VED(")(
M5$U,(@IM<V=S='(@(K97I.6S<[6RNWFHI2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!
M<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@
M:6X@<F]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A
M<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B
M;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY
M(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED
M(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`BI^2D
MHZCL($A45%`@Q>?#TBXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAA:71I(@IM<V=S='(@(DAA:71I
M("BN_*9A*2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I
M9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`BPOBTZBVZ=+KB(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA
M>F4B"FUS9W-T<B`BQD<B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3(S(&QI
M8B](;W)D92]&;W)M+G!H<#HR.3(Q"FUS9VED(")(96%D97(B"FUS9W-T<B`B
MJNW`62(*"B,Z(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q
M"FUS9VED(")(96%D97)S(@IM<V=S='(@(JKMP%DB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3`W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D
M($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R(")(96%R9"!)
M<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R
M;2(*;7-G<W1R("*D:KEPJT(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(J?&IT*H
MTZ3E("A)4T\M.#@U.2TX+4DI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S
M='(@(K"JJ]<B"@HC.B!L:6(O2&]R9&4O2&5L<"YP:'`Z,3@T(&QI8B](;W)D
M92](96QP+G!H<#HQ.#8@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<*(SH@
M=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T
M<B`BNZ&I^B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(KUS
MO^B^N:C/I<Z[H:GZ(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-S4*;7-G
M:60@(DAE;'!E<B(*;7-G<W1R("*[H:GZ(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@(J5BLGDB"@HC.B!T
M96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F
M('1H92!F:6QE.B(*;7-G<W1R("*S;[C,K$_`R:[7JKJV?:EL.B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")(
M:6=H(@IM<V=S='(@(K"J(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN
M8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"FUS9VED
M(")(;U]M92(*;7-G<W1R("*N85]M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(T,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A
M=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B2&]L>2!3964@*+'KO\VIHRDB
M"@HC.B!L:6(O2&]R9&4N<&AP.C$U,SD*;7-G:60@(DAO;64B"FUS9W-T<B`B
MKF$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M
M92!!9&1R97-S(@IM<V=S='(@(J;MKF&F8:=](@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C8T"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R("*N
M8:78O_TB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y
M,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R("*F[:YAN7&XW"(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$P-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I
M9"`B2&]N9'5R87,B"FUS9W-T<B`B2&]N9'5R87,@**>[LZ.IU+2U*2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#8@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$P-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.`IM
M<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(DAO;F<@2V]N9R`HK;NTY"DB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C<*;7-G:60@(DAO<F1E(@IM
M<V=S='(@(DAO<F1E(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT-#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,
M(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D
M92]+;VQA8CH@MFRE\R`E,B1S(*2DN4JH[+5,KL2JNB`E,21S(%A-3+CJKL8B
M"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O
M8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(+5,MFRE\[Y!IEBJJZ7S
M("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O
M=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(+9LI?,@
M)3(D<R"DI*?DI*.H[*JKI?.KK+I!("4Q)',B"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.C$R-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R(")(;W)D
M92]+;VQA8CH@I'>FJ*5<JKJROK"C("5S(%PB)7-<(B(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G
M<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N
M<VEO;B(*;7-G<W1R(")(;W)D92]+;VQA8CH@ON.F6*1UM7N[W:UN("=D;VUX
M;6PG(*JZ(%!(4""IM:;Y(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HU,#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C
M<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z(+5,JFNKV*7?("5S(*JKI?.JNB!834P@OO`B"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.C$R-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G
M<W1R(")(;W)D92]+;VQA8CH@M4RJ:[*^L*,@)7,@7"(E<UPB.B`E<R(*"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z-#<S"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@
M=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@M4RJ
M:\#RJ/JSH:7W("5S(*NLND&JNB!-24U%(,/1IT^XN;U8(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HQ,3DR"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*
M;7-G<W1R(")(;W)D92]+;VQA8CH@M4RJ:Z90J$(@)7,@7"(E<UPB.B`E<R(*
M"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3,S,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E
M<SH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(+5,JFNF4*A"I,"HR3H@)7,B
M"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z(*6\JKZJNJ3`J,D@7"(E<UPB(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R
M:7IO;G1A;"!2=6QE(@IM<V=S='(@(J3TI:V]=2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT
M86P@<&%D9&EN9R(*;7-G<W1R("*D]*6MN=2E4B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT
M86PZ(@IM<V=S='(@(J3TI:TZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO
M=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R("*G0:9PIO.H
M[*:Y(#\@*+W0L=2M>B$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`BIT&M;J98J-:F
M:*36K=/$YJ;LJ4\_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E
M/R(*;7-G<W1R("+$YJ;LO,:EV*9`K7`_(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA
M;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`BIT&M
M;J98J-:F:*36ID.I3S\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C@Y(&QI8B]";&]C:R]M971A<BYP:'`Z,C,P"FUS9VED(")(=6UI9&ET
M>2(*;7-G<W1R("*WPZO7(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(T.`IM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R("*WPZO7.B`B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*
M;7-G<W1R("*WQKU=I&JN=B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R(")(
M=6YG87)Y("BF2:3ZIU$I(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP
M.C$W,B!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*
M;7-G<W1R("))34%0(+9LO6.KV*7?I:*QT3H@)7,B"@HC.B!L:6(O2&]R9&4O
M075T:"]C>7)U<RYP:'`Z,C$T(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z
M,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO
M;B!F86EL960Z("5S(@IM<V=S='(@(DE-05`@MFR]8Z=2L*.EHK'1.B`E<R(*
M"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ-SD@;&EB+TAO<F1E+T%U
M=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M
M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B24U!
M4""V;+UCNL^ZT+!TN&VKV*7?I:*QT3H@)7,B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3,R,`IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("))4""F[*=]
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0
M($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B25`@INRG?;5,JFNH
MSZ7.+B(*"B,Z(&QI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED
M("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*
M;7-G<W1R("))4""F[*=]J,.DHZ9B($-)1%(@JKJDN;-<L,^V]*2D+B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))
M4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I
M9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(J9BJ^&ML;2AI$JF0U]N
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@(DEC96QA;F0@**9"KG$I(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,`IM<V=I9"`B26-O;G,@3VYL
M>2(*;7-G<W1R("*OPKG/I=PB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@
M(B5SJKJYSZ7<(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,0IM<V=I
M9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@(KG/I=RDSJ3EIG(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DS"FUS9VED("))9&5N=&ET>2=S(&YA
M;64Z(@IM<V=S='(@(JBMI??#T:=/JKJF5[K9.B(*"B,Z(&QI8B](;W)D92]-
M24U%+T-O;G1E;G1S+G!H<#HU.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@
M:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@
M:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("*F<*I'M4RJ:Z6_O52F8<7CI=PL
M("5S(*5(I72V?;'2MFRE\ZGSMW.U^+6AM^VDI"XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#4Y"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N
M>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D
M('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A
M<F5N8WDN(@IM<V=S='(@(B(*(JC/I<X@26YT97)N970@17AP;&]R97(@PG/$
M_;ZYKLFF<*I'J%.FLZS=J.RE]*;SJKJD<+G/I=PL(*=!I6FOX+O=K6ZDQ+_O
MLV^MT[:U(@HBI=BE2,/VLZP@4$Y'(+QVN;.JNL'TPL.NQ*I'+B(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S(*;7-G:60@(B(*
M(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM
M86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@
M8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("*F<*I'K-VH[+-OJVBH4Z:SO':Y
MLZJZL%2NIRRS;ZKMI=RG0:JZPG/$_;ZYM4RJ:\7CI=RD5[;'JKJ\=KFS+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`BO':Y
ML[EWQ/TZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(KQVN;.Z
M]*=](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(KQV
MN;.Z]*=].B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y
M(@IM<V=S='(@(KQVN;.HTZ;;P\"T62(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA
M9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R("*\=KFSJ-.FV\/`M%DZ(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C4*;7-G:60@(DEM86=E('5P;&]A9"(*
M;7-G<W1R("*D5[;'O':YLR(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W
M"FUS9VED("));6%G97,B"FUS9W-T<B`BO':YLR(*"B,Z('1E;7!L871E<R]D
M871A+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z
M-PHC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T
M+"!3=&5P("5D(@IM<V=S='(@(K;7I$HL(*A"QDH@)60B"@HC.B!T96UP;&%T
M97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("))
M;7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`BMM>D2L3FINPZ("5S(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@
M9FEE;&1S.B(*;7-G<W1R("*VUZ1*Q.:F[#HB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN
M7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(J9BJ^&ML;2AI$JF0U]S(@H*(SH@
M;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,T"FUS9VED("));F-O<G)E
M8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(K_II$JDHZ6_O52JNJ=`
MI<Z]6"XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R
M"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*
M;7-G<W1R("*]T,#+K&2G0:JZJ,^ESJK,IE>ZV:3.L4N]6"(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@
M=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C
M;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T
M:&5R(&AE;'`N(@IM<V=S='(@(JC/I<ZJS*97NMFDHZ6_O52ISJK,N7&D;+9L
MI?.F[:=]I'?%W*?S+KW0P7"UN*=!JKJH=++.NMZR>JW[I4BH\Z=5LT*R>BXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q
M"FUS9VED("));F-R96%S92!);F1E;G0B"FUS9W-T<B`BO%>E6\%9L<8B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$V(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*
M;7-G:60@(DEN9&EA(@IM<V=S='(@(DEN9&EA("BF3*O7*2(*"B,Z(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(JW3IT^H
MSZ7.JLPB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$R(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#`*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("));F1O;F5S:6$@
M**9,I:<I(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`BN.JP5"(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-3D*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@
M(KCJL%0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Y"FUS
M9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+B(*;7-G<W1R
M("*U3*5II<ZJNKCJL%0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M
M;B!!9G1E<B(*;7-G<W1R("*F8JOAK;&TH:1*Q.:F[%]O(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P
M"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`BM*&D2KG/I/DB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED
M("));G-E<G0@5&%B;&4B"FUS9W-T<B`BM*&D2JKMKN8B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("));G-E
M<G0@5V5B($QI;FLB"FUS9W-T<B`BM*&D2KKTN/2S<[6R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS
M9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`BIF*K9:VQM*&D
M2L3FINQ?0R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A
M9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`BIF*EV*MEQ.:F[*OAK;&T
MH:1*I$"MT[=SQ.:F["(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O
M;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(J9BI=BK9<3F
MINRK9:VQM*&D2J1`K=.W<\3FINPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A
M(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(J9BI=BK
M9:9#J^&ML;2AI$JD0*W3MW.F0R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@
M;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(J9BI=BK
M9:9#JV6ML;2AI$JD0*W3MW.F0R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@
M<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`BIF*E
MV*MEN&#"2:OAK;&TH:1*I$"MTZQQN*@B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R
M="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R
M("*F8J78JV6X8,))JV6ML;2AI$JD0*W3K'&XJ"(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E;7!L871E
M(@IM<V=S='(@(K2AI$JE:;3`I4Z\RZI/(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(T,@IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@
M=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S
M='(@(K=SL4N]6+%.L4BU;ZCLLV^MT[9LI?.F8:=].B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@
M(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(J9BJ^&ML;2AI$K`>*9SKN8B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`BIF*K
M9:VQM*&D2L!XIG.NYB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T
M97(B"FUS9W-T<B`BIF*KX:VQM*&D2L3FINPB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED("));G-E
M<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R("*F8JMEK;&TH:1*Q.:F["(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS
M97)T(&UE<W-A9V5S(@IM<V=S='(@(K2AI$JV;*7S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED
M("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(J9BJ^&ML;2AI$JL
M<;BH(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*
M;7-G<W1R("*F8JMEK;&TH:1*K'&XJ"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R
M;W<@869T97(B"FUS9W-T<B`BIF*KX:VQM*&D2J9#(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B
M26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`BIF*K9:VQM*&D2J9#(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,PIM<V=I9"`B26YS97)T('1H92!R
M97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G
M<W1R("*F=Z7^L-VE>:JZM:JNUSHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM
M86=E(@IM<V=S='(@(K2AI$HOQ=RG\[QVN;,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D
M:69Y($QI;FLB"FUS9W-T<B`BM*&D2B_%W*?SNO2X]+-SM;(B"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I
M8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T
M+B(*;7-G<W1R("+"2;S&I*.HK*5(IMRI\[5,JFNVQ[!EM;FP=+AMN'.RU2XB
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED
M("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R("+"2;S&I*.HK"XB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`W.0IM<V=I9"`B26YT96=E<B(*;7-G
M<W1R("*^X[S&(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,S<*;7-G:60@
M(DEN=&5G97(@;&ES="(*;7-G<W1R("*^X[S&ID,B"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N
M("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`BM4RNQ*JZ(%5$2"BHSZ7.
MJLRXZJ[&JNW`62DN(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z
M,38W(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$Y-`HC.B!L:6(O2&]R
M9&4O0V]M<')E<W,O>FEP+G!H<#HR,3(*;7-G:60@(DEN=F%L:60@6DE0(&1A
M=&$B"FUS9W-T<B`BM4RNQ*JZ(%I)4""XZJ[&+B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM
M<V=S='(@(K5,KL2JNL"SI<ZU>Z:A+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*
M;7-G<W1R("*U3*[$JKJGY::XN+F]6"XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C`Y,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$V,B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C(S-@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,P,R!L:6(O2&]R
M9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D
M871A('-U8FUI='1E9"XB"FUS9W-T<B`BL&6E6*JZN.JNQK5,KL0N(@H*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN
M=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`BM4RNQ*JZI=B\
MT*;MIWTB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HQ,#D@;&EB
M+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,3,Y"B,Z(&QI8B](;W)D92]#;VUP
M<F5S<R]D8G@N<&AP.C(T,0IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*
M;7-G<W1R("*U3*[$JKK`R:[7KN:FH2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM
M<V=S='(@(K5,KL2JNK'"Q7:]6"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,34Y"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D
M+B(*;7-G<W1R("*U3*[$JKJF8;#/+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*
M;7-G<W1R("*U3*[$JKH@;7-G7W1Y<&4N(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN
M9R!A<&E?:60N(@IM<V=S='(@(K5,KL2JNJG.I^2DHZCL(&%P:5]I9"XB"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B
M26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(K5,KL2J
MNJG.I^2DHZCLL-&\QBXB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M,C<*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@
M(K5,KL2JNJ3WQ7:MK2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,38Q"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(K5,
MKL2JNKG9IO'#T:=/O5@N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$V,PIM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@
M(K5,KL2JNK*CJWZ]6"XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B
MM4RNQ*JZLW&P5*CSJ7<N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.CDS(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HW,0HC.B!L:6(O
M3F5T+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R("*U3*[$JKJFK*7S
MI$@Z7"(E<UPB(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,#<U(&QI8B](
M;W)D92]+;VQA8BYP:'`Z,3(U.`IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE
M8W0B"FUS9W-T<B`BM4RNQ*JZI,"HR:JKI?,N(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E
M(&%D9')E<W,N(@IM<V=S='(@(K5,KL2JNJC3M[VF[:=]+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED
M('5N:6-O9&4@9&%T82XB"FUS9W-T<B`BM4RNQ*JZN%6PZKU8N.JNQBXB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4Y"FUS9VED("));G9E;G1O
M<GDB"FUS9W-T<B`BN.JRHR(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-S4*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T
M<B`BIEZT7[_OOMPB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$Y(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@
M;V8B"FUS9W-T<B`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B`HI>RNU"DB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#$*;7-G:60@(DER87$B"FUS9W-T<B`B27)A<2`HI>RIU*=**2(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Q,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I
M9"`B27)E;&%N9"(*;7-G<W1R("))<F5L86YD("BW4KJXQ/4I(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS
M9W-T<B`B27-L92!O9B!-86X@*+#2KG$I(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O
M<FUS(@IM<V=S='(@(J>]LZ&Y<*M"(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Q-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T
M<B`B27-R865L("BE2*;BID,I(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HV,C8*;7-G:60@(DES<W5E<B(*;7-G<W1R("+#L;5OJLPB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@
M(DET86QI8R(*;7-G<W1R("*QU\7I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$R,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED("))=&%L>2(*;7-G<W1R
M("))=&%L>2`HN'&D:J=1*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R(")*
M86UA:6-A("BD^K92I5LI(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,Y.2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`BI$"DZR(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$Q-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B
M2F%P86XB"FUS9W-T<B`B2F%P86X@**3II;LI(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#,*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS
M9W-T<B`BI.FDY2`H25-/+3(P,C(M2E`I(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(K]!INBN<2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C0@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Q.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM
M<V=I9"`B2F]R9&%N(@IM<V=S='(@(DIO<F1A;B`HK/FEN2DB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R
M("*D0Z3K(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G
M:60@(DIU;F4B"FUS9W-T<B`BI+NDZR(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB
M"FUS9W-T<B`BN>^[]"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*
M;7-G<W1R("*X;:2D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G
M<W1R("*EJJ5KN>^[]"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS
M9W-T<B`BOF&EJKGON_0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*
M;7-G<W1R("*^8:5KN>^[]"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R
M(")+87IA:VAS=&%N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(V,PIM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`BJT^O
M9*WLO,L@/R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B2V5N>6$@**K6J,@I
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E
M<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
M2V5R8F5R;W,@NWO#TK_YNWXN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R("*NUJ3?MW.DXB(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y($-R
M96%T:6]N(@IM<V=S='(@(JKWQE^KV*7?(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B
MJO?&7Z]3O'@B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G
M:60@(DME>2!,96YG=&@B"FUS9W-T<B`BJO?&7ZKXJ]<B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@
M(JKWQE^KK+I!(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3D*
M;7-G:60@(DME>2!5<V%G92(*;7-G<W1R("*J]\9?NWFJ:R(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI
M<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("*EV*MEJKJD
MO;9]JO?&7Z;XJD&^N:2D+*1WN&>F<Z9BIT&JNJKWQE\N(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(JC@M:,B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(Y(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@(DMI<FEB871I("BP\JB]I-JT
MM2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E
M<'5B;&EC(&]F("BE7\'Z*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(DMO<F5A+"!297!U8FQI8R!O9B`HJV[!^BDB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM
M<V=S='(@(L'ZI.4@*$550RU+4BDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3,T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R
M(")+=7=A:70@**SLJ\*O4RDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3(W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T
M<B`B2WER9WEZ<W1A;B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z
M.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R("*JJ:VQL'2X;5]Y(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS
M9W-T<B`BNWFHI2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@
M4F5P=6)L:6,B"FUS9W-T<B`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P
M=6)L:6,@*+QDL.HI(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0IM<V=I
M9"`B3&%S="!(86QF(@IM<V=S='(@(J15I6*DZR(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HW-@IM<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS
M9W-T<B`BL\RJ\:1`IKBQ2[U8Q=RG\ZGS(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R
M=&5R(@IM<V=S='(@(J15J;:DZR(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,34Q"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(J17IKBG\[=S.B(*
M"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`BI%>D0*:XM6ZD2CH@)7,B"@HC
M.B!L:6(O2&]R9&4O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@
M(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`BI%>D0*:XM6ZD2CH@
M)7,@IML@)7,B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-S$T"FUS9VED("),
M87-T(&QO9VEN.B!.979E<B(*;7-G<W1R("*D5Z1`IKBU;J1*.B"RQ*1`IKBU
M;J1*(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B3&%T=FEA("BIU++FNONH
MR"DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA=R(*
M;7-G<W1R("*J:ZO?(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO=70B"FUS9W-T<B`BJJFM
ML;!TN&TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("),96)A;F]N("B^I*3:
MN>`I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C8Y"FUS9VED("),969T(@IM<V=S='(@(J6JP^0B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S$P.`IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T
M<B`BI:K#Y*KMP%DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P-`IM<V=I
M9"`B3&5F="!V86QU97,B"FUS9W-T<B`BI:K#Y*W((@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$T,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O
M=&AO(@IM<V=S='(@(DQE<V]T:&\@*+_@K\&FJRDB"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(DQE=F5L(@IM
M<V=S='(@(K=2L:$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B3&EB97)I
M82`HO^"D\;?GJ,@I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA
M(@IM<V=S='(@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$@**=1I/&HR"DB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30P(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*
M;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B3&EE8VAT96YS=&5I;B`H
MID.DY+2PM+6U;BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R("*W3*M"
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*
M;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`BI'"K0B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!2
M86EN($5A<FQY(@IM<V=S='(@(J:MIK.D<*M"(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@
M3&%T92(*;7-G<W1R("*QWZ:SI'"K0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E
M<B(*;7-G<W1R("*D<+!]JT(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD
M97(B"FUS9W-T<B`BI'"K0J:SN7`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R
M("*D<+.W(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(J1PL'VS
MMR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I
M8VLB"FUS9W-T<B`BI;2J;[C6(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X
M,3@*;7-G:60@(DQI;FLB"FUS9W-T<B`BLW.ULB(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B
M3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(K-SM;+"2:CL.B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.#<Y"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R
M97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S
M='(@(L7CI=RNR;-SM;*V;*7SINVG?:CLO7.\9[9LI?.MMJVQ(@H*(SH@;&EB
M+TAO<F1E+U1E>'0O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@R"FUS9VED("),
M:6YK<R(*;7-G<W1R("*S<[6R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0V"B,L(&9U>GIY"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`BPT.F
MXB(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I
M9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(J9#
MI5@@+2"HSZ7.JLRE::5(K-VH[+-OK=.K2*7SIU@B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3,S"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R("*F
M0Z58N.JNQJYW(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3$*;7-G
M:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`BID.E6+NAJ?J\T,-$(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM<V=I9"`B3&ES="!486)L97,B
M"FUS9W-T<B`BID.E6*KMKN8B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S
M+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("*P4;W7N'.R
MU2W`R:[7PF0B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.#D*
M;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R("*P4;W7N'.RU2VH1*=5(@H*(SH@
M;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED
M(@IM<V=S='(@(K!1O=>X<[+5+</1IT^XN;U8(@H*(SH@;&EB+TAO<F1E+TU)
M344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@
M(K!1O=>X<[+5+;[6IK.JS"(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N
M<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(K!1O=>X<[+5+;%(
MI?.D2"(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,0IM<V=I
M9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`BL%&]U[ASLM4MK7&^7"(*"B,Z
M(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5
M;G-U8G-C<FEB92(*;7-G<W1R("*P4;W7N'.RU2VH^J[XK7&^7"(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T
M:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`BID.E6+=\M,&EHK'1
M.B`E<R(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`BID.E
M6*C/I<ZJS*6BL=$Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L
M:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*
M;7-G<W1R("*F0Z58J,^ESJK,JKJE7*_@LU'#]K.L(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(J3E
MOL<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30T(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("),:71H=6%N:6$@**7?
ML[.I>RDB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6UA9V5S+G!H<#HW
M-PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R("*X_*1*I*0N+BXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`P"FUS9VED("),;V-A;"!T
M:6UE.B`B"FUS9W-T<B`BM^VF8:[)MJ$Z("(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX-@IM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(J9A
ML,^[4*[)MJ$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-3<*(SH@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z-C4*;7-G:60@(DQO
M8V%T:6]N(@IM<V=S='(@(J9AL,\B"@HC.B!L;V=I;BYP:'`Z,3@V('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.3$@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS
M9W-T<B`BM6ZD2B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T
M-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3@U"FUS9VED
M("),;V<@;W5T(@IM<V=S='(@(K5NI5@B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-3D*;7-G:60@(DQO9VEN(@IM<V=S='(@(K5NI$HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3$P"FUS9VED("),;V=I;B!487-K<R(*;7-G
M<W1R("*U;J1*I'6G0"(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY.3(*;7-G
M:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S
M<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(K5NI$JE
MHK'1+""]T,#+K&2[U:15JKJESJ3AIE>I3;%+O5@L(+5-J^&MJ[C5+B(*"B,Z
M(&QI8B](;W)D92]!=71H+G!H<#HY.#@*;7-G:60@(DQO9VEN(&9A:6QE9"XB
M"FUS9W-T<B`BM6ZD2J6BL=$N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S
M-CD*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R("*J^*5Y(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@(K=2L:$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM
M<V=I9"`B3&]W(@IM<V=S='(@(J=#(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@
M9W)E96L@;&5T=&5R<R(*;7-G<W1R("*D<+QGI\;#OKS&IG(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y
M"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@(J1PO&>IU*1"
MO,:F<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS
M9W-T<B`BI'"\9\.YL*B\QJ9R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$T-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S
M='(@(DQU>&5M8F]U<F<@*+]CM,NS^2DB"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,SDX(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,S8*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@
M(DU-(@IM<V=S='(@(J3K(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(X,PIM<V=I9"`B34]41"(*;7-G<W1R("*H0Z3IL%2NIR(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!
M='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")-4RU43D5&
M(*K^I5O`R:[7I*2H4Z:SN.JNQBXB"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R
M(")-4T<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@(DUA8V%O("B_1*KY*2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$S-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA
M=B!297!U8FQI8R!O9B`HL*BHY+EYID"I3;#J*2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S
M-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A
M<V-A<B(*;7-G<W1R(")-861A9V%S8V%R("BPJ+E&I5NTM:5;*2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B
MQ5VS3B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,PIM<V=I9"`B
M36%I;"(*;7-G<W1R("*V;*7S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C4R-`IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R("*V;*7SNMZR>B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R("*KV*7?LW.U
MLE]K+BXN(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDT"FUS9VED(")-86QA=VDB"FUS9W-T<B`B36%L87=I("BPJ*G4
MJ\(I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R(")-86QA>7-I82`HL*BH
MTZ;HJ,@I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*;7-G<W1R(")-86QD:79E<R`H
ML*BZN*9AI-(I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDR"FUS9VED(")-86QI(@IM<V=S='(@(DUA;&D@*+"HIU$I
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDT"FUS9VED(")-86QT82(*;7-G<W1R(")-86QT82`HL*BZN*5,*2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-`IM<V=I9"`B(@HB36%N86=E('1H
M92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@
M=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T
M96=O<FEE<RXB"FUS9W-T<B`BNMZR>J=!JKJDP,/^+*C#I4*LL*3`P_ZS7:EW
MPT.FXBXB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3$U,PIM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(DUA<#(T(*9AN<\B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-`HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$V.`IM<V=I9"`B
M36%P475E<W0@;6%P(@IM<V=S='(@(DUA<%%U97-T(*9AN<\B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T
M;W)E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P,2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(J14I.LB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED
M(")-87)G:6XB"FUS9W-T<B`BP^2LR2(*"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N
M(&9L86=S(@IM<V=S='(@(KS0L$^FJ""LW;E,+Z6\K-VY3"(*"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H
M(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T
M<B`BO-"P3Z:HJ.2E3*JZP]&G3R`HJ-*F<"X@K:NM;B^D=Z9>PM`I(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDQ"FUS
M9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(DUA<G-H86QL($ES;&%N
M9',@*+"HKDRZN+ASKG$I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U
M.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@
M(DUA<G1I;FEQ=64@*+"HM*.EIZ=*KG$I(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R
M("*DQ[!TQ.:F[*2D(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(DUA
M=7)I=&%N:6$@**U4IU&V\*6GJ,@I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$V,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS
M9W-T<B`B36%U<FET:75S("B\KZB]INBTM2DB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E
M9&ET+B(*;7-G<W1R("*DN;-<JKJSS*1JPDF\QBXB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@
M<&%R=',@97AC965D960N(@IM<V=S='(@(JK^I?.\QJ78I'>V5Z58I+FS7*17
MK:TN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T
M96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("*SS*KQ(#(T(*1PKLFJNK/,
ML*JWQ:O7.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y.`IM<V=I9"`B
M36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`BL\RJ\2`V(*1PKLFJ
MNK/,L*JWQ:O7.B`B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU
M;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R("*PS[;TI%>MK;S&
MI=@B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3`R(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,C(Q(&QI8B](;W)D92]&;W)M+G!H<#HQ,C0S"FUS9VED(")-87AI
M;75M(&QE;F=T:"(*;7-G<W1R("*DN;-<L\RD:JKXJ]<B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(J2M
MI.LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4S(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@(DUA>6]T=&4@*+"HK/FO
M4ZYQ*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D
M:6-I;F4B"FUS9W-T<B`BPN6^QR(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`BIJBM^R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#(*;7-G:60@(DUE;G4@;6]D
M93HB"FUS9W-T<B`BO^^SYKS2IJ$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L
M;',B"FUS9W-T<B`BIEBHUL!XIG.NYB(*"B,Z(&QI8B](;W)D92].;W1I9FEC
M871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`BMFRE
M\R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B
M"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE
M<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS
M9W-T<B`BMFRE\\7GP]*D=Z>YIJ@LIOVL3ZC/I<ZJS*JZP[&SN:MOM4RJ:[-Q
MN4S%Y\/2+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$P"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(L*RL%2D=[E,
MM,$N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.2!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C8P"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T
M<B`BPK*P5*NLND$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*(RP@9G5Z
M>GD*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`BI=BK9:31KO`B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R(")-971A<B"PS[;TM4RJ:ZC/I<XN(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3(*;7-G:60@(B(*(DUE=&%R(&)L
M;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F
M;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(DUE=&%R(+#/MO2U3*IK
MJ,^ESBX@LM.X8+W0L-&FTJATLLZZWK)ZM6Z__2XB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,34S"FUS9VED(")-971A<D1"(&ES(&YO="!C
M;VYN96-T960N(@IM<V=S='(@(DUE=&%R1$(@J7REO+-SL;4N(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R("*DZ*IK
M(@H*(SH@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C@Q(&QI8B](;W)D92]2
M4$,O<V]A<"YP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<
M(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`BI.BJ:R!<(B5S7"(@I;RS
M4:EWN'$B"@HC.B!L:6(O2&]R9&4O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF
M;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO
M9#H@)7,B"FUS9W-T<B`BI.BJ:Z6\J7>X<2X@I4BI2:5SI.BJ:SH@)7,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C<@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HW-0IM<V=I9"`B365T<FEC(@IM<V=S='(@(J2]J.XB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G
M:60@(DUE>&EC;R(*;7-G<W1R(")-97AI8V\@*+ZEINBM]"DB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$T.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B
M36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R(")-:6-R
M;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F("BQ2Z=*P[FEIZ;HJ,@I(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<V"FUS9VED(")-:61D;&4B"FUS9W-T<B`BI*2VH2(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM
M<V=S='(@(DUI;64@JZRZ02(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$P
M"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`BL\RJ
M\2`R-""D<*[)JKJSS*=#M\6KUSH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS,#(*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@
M(K/,JO$@-B"D<*[)JKJSS+"JM\6KUSH@(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@
M;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(K/,M76Q2[U8KL2TP:E\I;RH[+3!
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,PIM
M<V=I9"`B36ER<F]R(@IM<V=S='(@(JQ-KF<B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`BPOBV
MM2(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@;&EB+TYE="]3
M35,O=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA
M9V4@2%144%]297%U97-T+B(*;7-G<W1R("*GY*2CJ.P@4$5!4B"E7;C+($A4
M5%!?4F5Q=65S="XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS
M9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E
M;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L
M:6-A=&EO;BXB"FUS9W-T<B`BLUVI=\#)O_*EHBX@IG"J1ZUNJ,^ESK-OK=/`
MLZ7.M7NFH:=!I;*VM[)[IF*T3K*CI<VE3"XB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E
M($E$+B(*;7-G<W1R("*GY*2CJ.S"LK!4JKH@240N(@H*(SH@;&EB+TYE="]3
M35,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R
M97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`BI^2DHZCLI;*V
MMZJZ(%!%05(@I5VXRR!-86EL+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM
M<V=S='(@(J?DI*.H[+=\M,&JNB!)1"XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R("*L
M4+3!I$`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S8*;7-G:60@
M(DUO8FEL92!-86EL(@IM<V=S='(@(J;FL,JV;*7S(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DUO9&5R871E
M(@IM<V=S='(@(K?%J4TB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R
M+G!H<#HV-B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,PHC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B36]D:69I
M960@1&%T92(*;7-G<W1R("*G\[=SI.FTP2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D
M:69Y(%523"(*;7-G<W1R("*MUZ?ONO2G?2(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-C<T"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(KS2LM4B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUO;&1O
M=F$L(%)E<'5B;&EC(&]F("B\K[JXIFBERRDB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,30Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3$*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*
M;7-G<W1R(")-;VYA8V\@*+ROK\>M]"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,34V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM
M<V=S='(@(DUO;F=O;&EA("B[6*5J*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR-3@X"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R("*DZZ3.IGXB
M"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT
M:&QY(@IM<V=S='(@(JA#I.LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,38Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T
M<B`BNUBVZZG4KU,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(J3K
MK-LB"@HC.B!L:6(O1FEL92]#4U8N<&AP.C$Y-B!L:6(O1FEL92]#4U8N<&AP
M.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I
M;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R("*F8K+$
M)62FYJ?DJ.RJNL3FINR\QJ78I'>V5Z58N7>TP25D+B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$U-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R
M;V-C;R(*;7-G<W1R("*\KZREK?0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S
M='(@(J9HMK.NR;2X(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`BIFBV
MLZ[)L[$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(K2XKLFF:+:S(@H*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-3`Y"FUS9VED(")-;W9E
M($1O=VXB"FUS9W-T<B`BI%6ROB(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70N<&AP.C4Q,PIM<V=I9"`B36]V92!,969T(@IM<V=S='(@(J6JLKXB"@HC
M.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HU,3<*;7-G:60@(DUO=F4@
M4FEG:'0B"FUS9W-T<B`BI6NROB(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70N<&AP.C4P-0IM<V=I9"`B36]V92!5<"(*;7-G<W1R("*D5[*^(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PIM<V=I9"`B
M36]V92!D;W=N(@IM<V=S='(@(J15LKXB"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-3(R(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HU,C,*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`BI%>ROB(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$U-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R(")-;WIA;6)I<75E("BR]J14
MI/&G2BDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$X.`IM<V=I9"`B375L
M=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(KW&O^^FH:15J=2E
M7*_@JNTB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3`U-0HC+"!F=7IZ>0IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@
M(J9HO':YLR(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C0V"FUS9VED(")-
M=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`BO<:_[R(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT,#(*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T
M<B`BI]JJNK%BN+DB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*;7-G
M:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`BI]JJNK%BN+FX
MZK!4(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HU-`IM<V=I9"`B
M37D@4&]R=&%L(@IM<V=S='(@(JW3I$BON*5X(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+V5D:70N<&AP.C$S-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G
M<W1R("*MTZ1(K[BE>*VVK;&P=+AM(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$U-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S
M='(@(DUY86YM87(@*+UQJ&PI(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E
M92(*;7-G<W1R("*DHRRGVJ2CIE"W3B(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C0Q,2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$P
M,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@
M(DYA;64B"FUS9W-T<B`BIE>ZV2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R
M(").86UI8FEA("BHNJ;,I/&HR"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3<X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@
M(DYA=7)U("B_U;Y\*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S<@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B3F5P86P@
M**6GJGFZN"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(DYE=&AE
M<FQA;F1S("BR_,3U*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*
M;7-G<W1R(").971H97)L86YD<R!!;G1I;&QE<R`HLOS$W:9WIF&F0[2U*2(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S
M8V%P92!"87-E(%523"(*;7-G<W1R(").971S8V%P92"LL+#RPJ:JNKKTIWTB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I9"`B3F5T
M<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B3F5T<V-A<&4@OLS#
MTJ=`O&^Z]*=](@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#8*
M;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B3F5T<V-A
M<&4@OLS#TJQ&M::Z]*=](@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU.#4*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(DYE
M='-C87!E(*?SMW.Z]*=](@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU.#,*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@
M(DYE='-C87!E(*=`O&^Z]*=](@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G
M<W1R(").971S8V%P92!34TP@IOBJ0;ZYIE>ZV2(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3@X"FUS9VED(").971S8V%P92!C97)T:69I8V%T
M92!C;VUM96YT(@IM<V=S='(@(DYE='-C87!E(+[,P]*JNK7YN-$B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@
M8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R(").971S8V%P92"^S,/2JZRZ02(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3,*;7-G:60@(DYE='=O
M<FLB"FUS9W-T<B`BNO2X]*1UJ.,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.0HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(").979E<B(*;7-G<W1R("*Q<:6\
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDU"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(DYE=R!#86QE9&]N
M:6$@*+=SL]BHO:9HI:>HR"DB"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@
M(K=SO%>DP,/^(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP
M:'`Z.#$@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@
M;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.3<@;&EB+TAO<F1E
M+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G
M:60@(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@(KQGJTBUN2`E<R(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T
M<B`BMW.DZR(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(K=S
MJ,^ESJK,IE>ZV2`HJT2ELJUN*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS
M9W-T<B`B3F5W(%IE86QA;F0@**_#INC$]2DB"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z,S<*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R
M("*W<[%+O5@B"@HC.B!L:6(O2&]R9&4O075T:"]S<6PN<&AP.C(R-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@
M)7@N(@IM<V=S='(@(K=SL4N]6+%.J?,E>*CLM,$N(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED(").97<@<&%S<W=O<F1S(&1O
M;B=T(&UA=&-H+B(*;7-G<W1R("*W<[%+O5BDH[+%IE@N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W
M('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R("*W<[7XM:$@*%]B;&%N:RDB"@HC
M.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Y,0IM<V=I9"`B
M3F5W<R(*;7-G<W1R("*W<[M$(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,P-PIM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R("*W<[M$N'.RU2(*
M"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D
M871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z,3(Y('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").
M97AT(@IM<V=S='(@(J15I$"H0B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR
M-PHC+"!F=7IZ>0IM<V=I9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R("*D5:W3
MI.NLVR(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S<R(&QI8B](;W)D
M92]0<F5F<R]522YP:'`Z,S<V"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T
M<B`BI%6D0*W3O^^VM2(*"B,Z(&QI8B](;W)D92]522]086=E<BYP:'`Z,3`S
M"FUS9VED(").97AT/B(*;7-G<W1R("*D5:1`K;8B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3<T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI8V%R
M86=U82(*;7-G<W1R(").:6-A<F%G=6$@**6GI5NIU*7**2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$V-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B
M3FEG97(B"FUS9W-T<B`B3FEG97(@**6GI.DI(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$W,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA
M(@IM<V=S='(@(DYI9V5R:6$@**E@I,ZG4:C(*2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS-CD*;7-G:60@(DYI9VAT(@IM<V=S='(@(K'?
MI%<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3<*;7-G:60@(DYI=64B"FUS9W-T<B`B3FEU92`HK\.N2JYQ*2(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@
M(DYO(@IM<V=S='(@(J=?(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I
M9F8N:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D
M871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R("*U3*5IJ-'%
MXZ7<KG2RIZJZLUVI=[CJKL8N(@H*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP
M.C$P-@IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@
M25-/(&EM86=E<RXB"FUS9W-T<B`BM4RE::7.JKJUIK*DJ]BS>2!)4T\@O':Y
MLRXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM
M<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(JA3IK.GY::XO,NF
MH2XB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HW.2!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+G!H<#HR-#4*(SH@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="YP:'`Z,C8W"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E
M<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R("*ITJO\J7>JNJ;LN&VD5ZA3IK.P
MS[;TIG.F8B(*"B,Z(&QI8B](;W)D92]!=71H+VUC86PN<&AP.C4P"FUS9VED
M(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R("*H4Z:SM*.HT:;FJ,:^Y*97NMFE2*C1($U#04P@
MQ>?#TBXB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`IM<V=I9"`B3F\@
M8VAA;F=E+B(*;7-G<W1R("*H4Z:SQ=RG\RXB"@HC.B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D
M('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`BM4RJ:Z9BI=BK9<5VK:VD
MI+Q7I5NFN,5VK:TN(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-CD@;&EB+TAO<F1E
M+G!H<#HU,#@@;&EB+TAO<F1E+U5T:6PN<&AP.C<V.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@)7,N(@IM<V=S='(@(JA3IK.K_*EWJKH@)7,@LUVI=[CJL%0N(@H*
M(SH@;&EB+U9&4R]F='`N<&AP.C@T-`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N(@IM<V=S='(@
M(JA3IK.K_*EWJKH@1E10(%9&4R"S7:EWN.JP5"XB"@HC.B!L:6(O5D93+W-Q
M;"YP:'`Z-C<R"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`BJ%.FLZO\J7>JNB!3
M44P@5D93LUVI=[CJL%0N(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S(U
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("*H4Z:SJ_RI=ZJZ(%-13"U&
M:6QE(%9&4[-=J7>XZK!4+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B
MM4RST;YLPDF\QBXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T
M<B`BI;RTHZC1I=BJNBXB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3`S
M"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(L#)KM>EO*17ML<B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS
M(&9O=6YD+B(*;7-G<W1R("*GY*2CJ.RYSZ7<+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ,38@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(S"FUS9VED(").;R!L;V-A=&EO
M;B!I<R!S970N(@IM<V=S='(@(J;LN&VXZK!4J7REO+-=J7<B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"FUS9VED(").;R!L;V-A=&EO
M;B!P<F]V:61E9"XB"FUS9W-T<B`BJ7REO+2CJ-&F[+AMN.JP5"XB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M
M97-S86=E('-U<'!L:65D+B(*;7-G<W1R("*EO+2CJ-'"LK!4+B(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA
M;64@<W!E8VEF:65D+B(*;7-G<W1R("*EO*O\J7>F5[K9+B(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU;6)E
M<B!S<&5C:69I960N(@IM<V=S='(@(J6\J_RI=[BYO5@N(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.CDT"B,L(&9U>GIY"FUS9VED(").;R!O9F9E;G-I
M=F4@9F]R='5N97,B"FUS9W-T<B`BI^2DHZCLN<^EW"XB"@HC.B!L:6(O2&]R
M9&4O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(JA3IK.K_*EW
ML4N]6*5(J-$@2%144"#%Y\/2+B(*"B,Z(&QI8B](;W)D92]!=71H+VEM87`N
M<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(JA3IK.K_*EWL4N]6*5(J-$@24U!
M4"#%Y\/2+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C<R"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(JA3IK.K_*EWL4N]6*5(J-$@2V5R8F5R;W,@Q>?#
MTBXB"@HC.B!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HW-R!L:6(O2&]R9&4O
M075T:"]L;V=I;BYP:'`Z.#0*(SH@;&EB+TAO<F1E+T%U=&@O<&%M+G!H<#HW
M-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("*H4Z:SJ_RI=[%+O5BE2*C1($QO9VEN(,7G
MP](N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@
M(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(JA3IK.K_*EWL4N]6*5(J-$@4$%34U=$(,7GP](N(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
MJ%.FLZO\J7>Q2[U8I4BHT2!334(@Q>?#TBXB"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C$R.#<*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P
M96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@
M;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S
M='(@(B(*(J6\O^FD2B!/<&5N4U-,(*1'I+BP]:;FP,FJNJ7^N/2N?"X@4$M#
M4R`Q,B"S5Z[FJKJE6[%+N.JNQKO=K6ZESJCLN-.U>Z:A+B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I
M;F<@<VEG;G5P<RXB"FUS9W-T<B`BJ%.FLZO=O&:JNK7YI56ET[W0+B(*"B,Z
M(&QI8B]61E,N<&AP.C<V-0IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R
M("*ZS[K0L'3#0J6\LUVI=R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S
M='(@(K5,KN:]=2(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#@R"FUS9VED(").
M;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G<W1R("*I?*6\J_RI=\3FINRD
MP+EJIG*DN"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0T"FUS9VED(").;R!S:61E<R(*;7-G<W1R("*U3*[8
MO74B"@HC.B!L:6(O5D93+W-M8BYP:'`Z-3@W"FUS9VED(").;R!S=6-H(&9I
M;&4B"FUS9W-T<B`BM4RFN<#)KM<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,3(V"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V
M86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(K5,O,BF<Z78O_VE::C1I]:H
M^BXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q(&QI
M8B].970O4TU3+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@(DYO('5S97)N86UE
M(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R("*EO+;'L&6HSZ7.JLRF
M5[K9J<ZQ2[U8+B(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HQ-#`*
M;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(K5,
MI6FESJJZ(%A-3""XZJ[&LU&VQZ9>(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDW,2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.3@Q"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HY.3(*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P,#D*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("*JQ:75K<@B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O
M=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`BK>RI;+-=J7?`R:2DI^2DHZCLJJFEN[CJ
ML%0N(*VKMW.RHZ7-LUVI=\#)+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U
M<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(J9B
MIT&JNK-=J7?`R:2DI^2DHZCLJJFEN[CJL%0N(*VKMW.RHZ7-LUVI=\#)+B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R-R!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E
M<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*;7-G:60@(DYO;F4B"FUS
M9W-T<B`BM4PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@
M(K5,("AU<V4@:6UP;&EC:70I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#4*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(J3IIM6P
MTJ3E("A)4T\M.#@U.2TQ,"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3<R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM
M<V=S='(@(DYO<F9O;&L@27-L86YD("B_U;K6ITJN<2DB"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").
M;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(J5?I6*R>2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$V.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B
M3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(DYO<G1H97)N($UA
M<FEA;F$@27-L86YD<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(DYO<G=A
M>2`HKK^KPBDB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T,0IM
M<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(JM$I*>KX2(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED(").;W0@0F5F;W)E(@IM<V=S
M='(@(JM$I*>K92(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-#$R"FUS9VED(").
M;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`BI*.L3Z1`K=.EV+_](@H*(SH@;&EB
M+U9&4R])4T]7<FET97(N<&AP.C8S(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2YP:'`Z.#0*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+G!H<#HY-0HC.B!L:6(O5D93+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT
M960N(@IM<V=S='(@(K5[IJ&I?*6\I[FFJ"XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X"FUS9VED(").;W0@<V5T(@IM
M<V=S='(@(J2CLUVI=R(*"B,Z(&QI8B]61E,N<&AP.C$Y,R!L:6(O5D93+G!H
M<#HR,#@@;&EB+U9&4RYP:'`Z,C,S(&QI8B]61E,N<&AP.C(U,0HC.B!L:6(O
M5D93+G!H<#HR-C@@;&EB+U9&4RYP:'`Z,C@T(&QI8B]61E,N<&AP.C,P,"!L
M:6(O5D93+G!H<#HS,34*(SH@;&EB+U9&4RYP:'`Z,S,R(&QI8B]61E,N<&AP
M.C,V-2!L:6(O5D93+G!H<#HT,C4@;&EB+U9&4RYP:'`Z-3`T"B,Z(&QI8B]6
M1E,N<&AP.C4W,R!L:6(O5D93+G!H<#HU.3`@;&EB+U9&4RYP:'`Z-C8X"B,Z
M(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,30U(&QI8B](;W)D92]3
M97-S:6]N2&%N9&QE<BYP:'`Z,38P"B,Z(&QI8B](;W)D92]397-S:6]N2&%N
M9&QE<BYP:'`Z,3<U(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,3@Y
M"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,C,V"FUS9VED(").
M;W0@<W5P<&]R=&5D+B(*;7-G<W1R("*EO+-1I.2TJ2(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R]H;V]K<RYP:'`N
M9&ES=#HQ,#`U"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#`*;7-G
M:60@(DYO=&5S(@IM<V=S='(@(K/&I]&__2(*"B,Z('-E<G9I8V5S+V]B<F]W
M<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O
M(&)A8VLN(@IM<V=S='(@(JA3IK.E:<)SQ/VJNBRF7J5H+B(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G
M<W1R("*D4:1`I.LB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`U,`IM<V=I
M9"`B3G5M8F5R(@IM<V=S='(@(KS&IG(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,30R.0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B
MIG*DN+S&(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-S,@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$T,C<@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#D*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@
M(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(J9RI+B\9:O7(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$S-S$@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C4@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S
M(@IM<V=S='(@(J;FO,8B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P
M9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("*G\[=SL'2X
M;;ASLM6NR:6\J_RI=[S&I=@N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R(")/2R(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX-S`*;7-G:60@
M(D]B:F5C="(*;7-G<W1R("*JJZ7S(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(JJK
MI?.KV*7?JLPB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$P.`IM<V=I9"`B
M3V-T86PB"FUS9W-T<B`BI$NV::;L(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`BI%&DZR(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT
M97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R
M.`IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(K_LI+VKQR(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S
M<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R("*W<[%+O5BELK:W
MNU#"PK%+O5BDHZ90+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HS-@IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(L+"L4N]6"(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A
M<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R("+"PK%+O5BDHZ6_O50B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B3VUA;B`HJORPTBDB"@HC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!
M4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(J5U
MIK,@24U!4""F^*I!OKFDY+2IJTBE\Z=8I,"HR:5<K^`N(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.CDU"B,L(&9U>GIY"FUS9VED(")/;FQY(&]F9F5N
M<VEV92!F;W)T=6YE<R(*;7-G<W1R("*GY*2CJ.RYSZ7<+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.#4U(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<U"FUS
M9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@
M(J5UI+FS7*1`K=.V;*7SINVG?2XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A
M9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*
M(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(J5UIK.^UJ:SJLR[
M4*ATLLZZWK)ZK?NE::5(Q=RG\Z9`J,G%=JVM(@H*(SH@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z,SD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-#`*;7-G:60@(D]P
M96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(J9BMW.JNK7XM:&V?;'2(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y3
M4TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@
M4R]-24U%('!A<G0N(@IM<V=S='(@(D]P96Y34TP@O_F[?CH@M4RJ:[%Q(%,O
M34E-12##L;.YJOZE\[C1MGVXZJ[&+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@
M=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("*F8K=SJKJU^+6A
MMGVQTK-SM;(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@
M(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`BIT"W?JATLLXB"@HC.B!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM
M<V=S='(@(K_OMK4B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA
M=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T
M:6]N<R!F;W(@)7,B"FUS9W-T<B`B)7._[[:U(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,
M:7-T(@IM<V=S='(@(K:UI=B]<[BY(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R("*RU<*T
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D]R
M9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`BLM7"M+/FINPB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,T"FUS9VED(")/<F=A;FEZ:6YG(@IM
M<V=S='(@(K+5PK0B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I
M9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`BK>RI
M;,"SI<ZU>Z:AO,NJ3R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L
M('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB
M"FUS9W-T<B`BIF(@)7,Z(*2DJKJM[*ELO,NJ3RXB"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS
M9VED(")/=&AE<B(*;7-G<W1R("*HY*5,(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDY(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#D*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(U
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S0@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$T-`IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B
MJ.2E3+CJL%0B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS
M9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R("*^UJ:SJLS%=JVM(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE
M;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E!!32#%Y\/2
MM4RNQ"XB"@HC.B!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM
M<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(E!%05(Z.K9LI?.F
M^*I!NMTB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,C<V"FUS9VED
M(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B4$=0(+S&INS#L;.Y
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,R,@IM<V=I9"`B4$=0
M($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(E!'4""E6[%+N.JNQB(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C$S-S0*;7-G:60@(E!'4"!0=6)L:6,@
M2V5Y(@IM<V=S='(@(E!'4""DO;9]JO?&7R(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C$S-38*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A
M=&$B"FUS9W-T<B`B4$=0(*1WP[&SN2^D=Z5;L4L@N.JNQB(*"B,Z(&%D;6EN
M+W!H<'-H96QL+G!H<#HV.`IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B4$A0
M(+5[IJ&]6"(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0
M(%-H96QL(@IM<V=S='(@(E!(4""O\[U:(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A:6XB
M"FUS9W-T<B`BI,BKX:1PJT(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R("*D
MR*OAL'VK0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,Y"FUS9VED(")032!3;F]W(@IM<V=S='(@(J3(J^&FL[.W(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@
M(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("*DR*OAL'VSMR(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")032!3
M=6XB"FUS9W-T<B`BI,BKX;2X(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@
M(J3(J^&Y<*M"(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W-`IM<V=I
M9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B4$]325@@
M97AT96YS:6]N(+_RI:(B"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?
M2%`@4VAE;&PB"FUS9W-T<B`B4$A0(*_SO5I?2"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A
M9&1I;F<B"FUS9W-T<B`BN=2E4B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T
M<B`B4&%K:7-T86X@**3:L/*TM:E:*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S
M='(@(E!A;&%U("BIK:];*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I
M=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B4&%L97-T:6YI86X@5&5R<FET;W)Y
M+"!/8V-U<&EE9"`HI-JPQ[2UJ5JF^[OBL,\I(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$X,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B
M"FUS9W-T<B`B4&%N86UA("BDVJZSL*@I(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$X-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.97<@
M1W5I;F5A(@IM<V=S='(@(E!A<'5A($YE=R!'=6EN96$@**3:I:RHR+=SM%BD
MNJC(*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.34@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(E!A<F%G=6%Y("BD
MVJG4IF,I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S8*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`BIFBVLR(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(P,C(*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4S-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C$Y.0HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,34Q('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHT,R!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(U
M"FUS9VED(")087-S=V]R9"(*;7-G<W1R("*Q2[U8(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D
M('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`BL4N]6,7<I_.GN::H+B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3,R,PIM<V=I9"`B4&%S<W=O<F0@
M:6YC;W)R96-T(@IM<V=S='(@(K%+O5BDHZ6_O50B"@HC.B!L:6(O2&]R9&4O
M075T:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@
M9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BJ%.FLZO\J7>Q
M2[U8I4BHT2!2041)55,@Q>?#TBXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C`U-PIM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T
M<B`BL4N]6+U4NWLB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.3`*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R("*Q2[U8.B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM
M<V=S='(@(K%+O5@Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C`S.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C$U"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T
M<B`BL4N]6*6RMK>G:Z98+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,3D@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(R"FUS9VED(")087-T92(*;7-G<W1R("*V2Z17(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@
M9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`BMDND5R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS
M9W-T<B`BN/2N?"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW
M"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(JO=O&:U;K_]H4<B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*;7-G:60@(E!E;W!L92(*
M;7-G<W1R("*FJ*W[(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`BILJDP*3Q
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G
M<W1R("*P]:;FNOO%0+[>IT`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#$P"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@
M;&]G:6X_(@IM<V=S='(@(K5NI$JKX;#UIN:Z^\5`OMZG0#\B"@HC.B!L:6(O
M2&]R9&4O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G
M<W1R("+%=JVM(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E
M9"XB"FUS9W-T<B`B7"(E<UPBJKK%=JVMI;RS4:=2L*,N(@H*(SH@;&EB+U9&
M4R]S;6(N<&AP.C4Y,`IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T
M<B`BIG.H^KY$J=HB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$V,2!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B
M"FUS9W-T<B`BQ7:MK2(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R;7,O:6YD
M97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G:60@(E!E
M<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(L5VK:VZWK)Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X"FUS9VED(")097)S;VYA;"!)
M;F9O<FUA=&EO;B(*;7-G<W1R("*GVJJZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$X,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U(@IM<V=S
M='(@(E!E<G4@**^UOGPI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U
M"FUS9VED(")0971S(@IM<V=S='(@(L-DJJLB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3@V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-SD*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H:6QI<'!I
M;F5S(@IM<V=S='(@(E!H:6QI<'!I;F5S("BUX:O?NZLI(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM
M<V=S='(@(KEQN-PB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@P
M"FUS9VED(")0:&]T;W,B"FUS9W-T<B`BP\"T62(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A
M:7)N(@IM<V=S='(@(E!I=&-A:7)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R
M("*YLZ_`(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0
M;&%T:71U9&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC
M:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R("*]T+9II$K`>*9SKN;"2;_O(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O
M(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(KW0O52I=ZUNLKZPHZ:Y
MI+BE\SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U
M('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`BO="]5*EW
MIT&M;J2DPE^FN:2XI?.JNK-SM;(N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(U-C8*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N
M(@IM<V=S='(@(KW0O^FD2J1`K=.DZZ7WI,ZF?J7W+B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED(")0;&5A
M<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R
M("*]T+_II$JW<[Q7I,##_JJZIE>ZV3HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3,P-0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S
M<RXB"FUS9W-T<B`BO="_Z:1*I$"MTZ:SKL2JNB!)4""F[*=](@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(V-#<*;7-G:60@(E!L96%S92!E;G1E<B!A('9A
M;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N
M=&@N(@IM<V=S='(@(KW0O^FD2J1`K=.FLZ[$JKJDZ;3!.Z3$O^^FN:3KI?>J
MNJ3IM,$N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T-3$*;7-G:60@(E!L
M96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(KW0O^FD2J1`K=.F
MLZ[$JKJNR;:A+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O
M8FQE;2XB"FUS9W-T<B`BO="THZC1L-W#1*JZNDNM;BXB"@HC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD
M('!A<W-W;W)D(@IM<V=S='(@(KW0O^FD2J=!JKJHSZ7.JLRF5[K9I,ZQ2[U8
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0
M;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E
M('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R
M("*]T+Y<Q:JD5:9#I+JN92ZG0:6RMK>F4+=.LV^HQZC&MK6D?J_@J,^ESJAT
MLLXN(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93HB
M"FUS9W-T<B`BO="_Z:1*MW.JNJ3`P_ZF5[K9.B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X
M,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD
M(@IM<V=S='(@(E!O;&%N9"`HJFG$]2DB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@(JQ&JG8B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@Y"FUS9VED(")0;VQL<R(*;7-G
M<W1R("*GZ[*\(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B4&]R='5G
M86P@*+BRM>6D^BDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F
M('1H:7,@:6UA9V4B"FUS9W-T<B`BO':YLZ;LN&TB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I
M;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R("*J[:[FINRX;2(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T
M;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@
M(KN\L&6V;*7SJ.RS;ZW3JTBE\Z=8("AN;W0@96YF;W)C960@8GD@24U!4"DB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O
M<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R("*SS*KQ("5S(*1PKLFJNJVP
MJT*V<3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-PIM
M<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R("*ML*M"
M/&)R("\^OO>R=B(*"B,Z(&QI8B](;W)D92]0<F5F<R]L9&%P+G!H<#HY.`IM
M<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L9&%P.B"GY*2CJ.RITKO=K6ZJNB!,
M1$%0(*FUIOFN3:7S+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]S97-S:6]N+G!H
M<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]S97-S:6]N.B"G
MY*2CJ.RITKO=K6ZJNB!S97-S:6]N(*FUIOFN3:7S+B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C(U"FUS9VED(")0<F5S<W5R92(*;7-G<W1R("*N\,"C
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G:60@(E!R97-S=7)E
M(&%T('-E82!L979E;#H@(@IM<V=S='(@(J[\I:VML:[PP*,Z("(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C0*;7-G:60@(E!R97-S=7)E
M.B`B"FUS9W-T<B`BKO#`HSH@(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(P-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS
M9W-T<B`BN7?$_2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA
M9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(J9BMW.JNK7XM:&Y=\3]O':Y
MLR(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S8R(&QI8B](;W)D92]0
M<F5F<R]522YP:'`Z,S8V"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S
M='(@(J17I$"MT[_OMK4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R
M("*F0Z9,I.6E\R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R,PIM
M<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`BJ'"Q2ZKWQE\B"@HC.B!L:6(O
M2&]R9&4O365N=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(K#=
MPT0B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C<*;7-G:60@(E!R;V)L
M96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`BL-W#1+1YK7HB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S<Q"FUS9VED(")0<F]J96-T<R(*;7-G<W1R
M("*Q3:[7(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,34@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(Q.3(@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S0*;7-G:60@
M(E!R;VUP="!T97AT(@IM<V=S='(@(K2CI=RDNJYE(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@
M(J2]MGVJ]\9?(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#8*
M;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(J2]MGVJ]\9?
MNG2ZXB(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED
M(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`BI+VV?:KWQE^XZK!4(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I
M=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G
M<W1R("*DO;9]+ZAPL4NJ]\9?N>^HPZ6\LU&RHZ7-+B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$X,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U
M97)T;R!2:6-O(@IM<V=S='(@(E!U97)T;R!2:6-O("BJ::9HOJ2F52DB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DV(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R
M"FUS9VED(")1871A<B(*;7-G<W1R(")1871A<B`HI62Y1BDB"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@(JQDN-\B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM
M<V=S='(@(KK/NM"P=+AM(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HV-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D
M(&)I="DB"FUS9W-T<B`B4E-!(*2]MGVJ]\9?("@E9""F[*2X*2(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,C8X"FUS9VED(")2861I;R!S96QE8W1I;VXB
M"FUS9W-T<B`BO^^^W+9S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#,*;7-G:60@(E)A:6XB"FUS9W-T<B`BJT(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B
M4F%I;B!%87)L>2(*;7-G<W1R("*FK::SJT(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!,871E(@IM
M<V=S='(@(K'?IK.K0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0V"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R("*P?:M"
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*
M;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`BJT*FL[.W(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A
M:6X@=&\@4VYO=R(*;7-G<W1R("*K0L+@L[<B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`BP$B^
M]Z1PNWDB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV."!L
M:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B
M"FUS9W-T<B`BI/&R=B(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,S(T('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3@P"FUS9VED(")296%D(@IM<V=S='(@(L6JJ/HB"@HC.B!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E860@;65S<V%G97,B
M"FUS9W-T<B`BQ:JH^K9LI?,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T
M92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T
M<B`BKW6JNJUNIU*PHR`E<R"VW#\@LV^VM;[>IT"Q3K5,JFNK[+1?+B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("*O
M=:JZK6ZR3;"CJ,^ESJK,("5S(*JZN.JNQK;<(#\@LV^VM;[>IT"Q3K5,JFNK
M[+1?+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@
M(JCZKOBT7ZWL(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B
MK:NW<[[CLGHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDU"FUS9VED
M(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`BK:NW
M<[[CLGJPRKI!I=B__:2XI?,Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,T-0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`BK:NW
M<[[CLGJMTZ1(K[BE>*2ZKF4Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y
M."!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q-R!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3(S.0IM<V=I9"`B4F5G97@B"FUS9W-T<B`BL6"S5ZKMI=RFH2(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HS,C,X"FUS9VED(")296QA=&EO;G-H:7`@0G)O
M=W-E<B(*;7-G<W1R("+#]L%PPG/$_;ZY(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P
M.`IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(JVKQ:HB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,R-@IM<V=I9"`B4F5M87)K<R(*;7-G<W1R("*U^[W7(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-PIM<V=I9"`B4F5M;W1E(%-E
M<G9E<G,B"FUS9W-T<B`BN[>ZW:;XJD&^N2(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W
M=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@(KNWNMVZ]*=]("AH='1P
M.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U
M975E9"YI;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R("*ROK"C(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@
M0FQO8VLB"FUS9W-T<B`BLKZPH[#/MO0B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-34V"FUS9VED(")296UO=F4@8V]L=6UN(@IM
M<V=S='(@(K*^L*/$YJ;L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHT,`IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS
M9W-T<B`BI6BPHZ[FIJ$B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`BLKZPH[GO(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D
M('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM
M<V=S='(@(J;;IOBJ0;ZYO,BF<Z78O_VDI+*^L*.D=\!XIG.JNK-=J7>U>Z:A
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT,@IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R("*ROK"C(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M
M96YT(@IM<V=S='(@(J;;I.6E\Z2DLKZPHZ:YI$"X8,))(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M;W9E('5S
M97(B"FUS9W-T<B`BLKZPHZC/I<ZJS"(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V92YI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@
M=7-E<CH@)7,B"FUS9W-T<B`BLKZPHZC/I<ZJS#H@)7,B"@HC.B!L:6(O2&]R
M9&4O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD;B=T
M(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R("*[
MW:A$I;RS4:9>P+,Z(+_YNWZXN;U8.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-#4*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD
M(&YO="!B92!F;W5N9"XB"FUS9W-T<B`BI^2DHZCLJ=*[W:JZJD&PR"XB"@HC
M.B!L:6(O2&]R9&4N<&AP.C$W-B!L:6(O2&]R9&4N<&AP.C4Q.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I
M;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(E,B1S(*JZLUVI=Z6RMK>K
M_*EW(%PB)3$D<UPB(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C8W."!L:6(O5D93
M+V9T<"YP:'`Z.#4P(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<S,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I
M;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B5D93(*JZLUVI=Z6RMK>K
M_*EW(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]5=&EL+G!H<#HW-S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@
M:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BLUVI=[CJKL:ELK:WJ_RI=R!<
M(B5S7"(B"@HC.B!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z,S,U"FUS
M9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("*ELK:WQ.:F["(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,Q(&QI8B](;W)D92]&;W)M+G!H<#HS-#,@;&EB+TAO
M<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,R,`HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,3`P('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(JVKLUTB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B
M"FUS9W-T<B`BK:NS7;%+O5@B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R("*M
MJ[-=IT&JNK%+O5@Z(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,`IM<V=I
M9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(J9>IG.SS*OAI$"MTZQD
MN-\B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE;&PN
M<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@IM<V=I9"`B4F5S=6QT<R(*
M;7-G<W1R("*ULJI'(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@
M=&\@3W!T:6]N<R(*;7-G<W1R("*J\*9>O^^VM2(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R
M9"(*;7-G<W1R("*F0::XO^FD2K=SL4N]6"(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB
M"FUS9W-T<B`B4F5U;FEO;B`HKV2EIZGTKG$I(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED
M(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("*F7K1?LUVI=R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E)I8V@@5&5X="!%
M9&ET;W(@3W!T:6]N<R(*;7-G<W1R("*Z]*VVO7._Z+ZYO^^VM2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R
M("+!O+MY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R("*E:\/D(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,3`*;7-G:60@(E)I9VAT(&AE861E<B(*
M;7-G<W1R("*E:\/DJNW`62(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3`V
M"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`BI6O#Y*W((@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X
M"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`BID.DNJYE7W<N
M+BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`IM
M<V=I9"`B4F]L92(*;7-G<W1R("*HI*;B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Y."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*
M;7-G<W1R(")2;VUA;FEA("C#N;"HI:>HR"DB"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(T"FUS9VED(")2;W1A=&4@,3@P(@IM
M<V=S='(@(K';PN`@,3@P(*O7(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(R,0IM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B
ML&:NR;!W(#DP(*O7L=O"X"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,C<*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R("*V
MMJ[)L'<@.3`@J]>QV\+@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B
M"FUS9W-T<B`BID.DNJYE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B
M"FUS9W-T<B`BID.DNJYE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@(J9#(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T<B`BKN:]=2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@
M(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M
M;G,B"FUS9W-T<B`BQ.:F[+M0ID.NYKUU(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@
M=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`BQ.:F
M[*[FO74B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(')O=W,@;VYL>2(*;7-G<W1R("*F0Z[FO74B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3(P"FUS9VED(")2=6XB"FUS9W-T<B`BL/6FYB(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$X-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@
M(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R(")2=7-S:6%N($9E9&5R871I
M;VX@**M8P[FTM2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B4G=A;F1A
M("B_8Z9WN48I(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR.#4*
M;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R
M(")3+TU)344@I5NQ2\.QL[DB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S
M='(@(K9LI?.D=ZC/I<X@4R]-24U%(*5;L4LB"@HC.B!L:6(O2&]R9&4O075T
M:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R(")305-,(,7GP]*U3*[$+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#8*;7-G:60@(E--4R!-97-S86=I
M;F<B"FUS9W-T<B`BPK*P5"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM
M<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(KCJKL:N=Z_SO5HB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S(W,@IM<V=I9"`B4U%,('-T871E;65N="!F;W(@
M=F%L=64@;&]O:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#,S"FUS9VED(")34T@B"FUS9W-T<B`BI5NQ2[+7NMV^]R(*
M"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R("*FJ*5<(@H*(SH@;&EB+V%P
M:2YP:'`Z,34S"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(KCJKL:N=Z_S
MO5I?42(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(JQ0M,&DNR(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$X.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A
M:6YT($AE;&5N82(*;7-G<W1R(")386EN="!(96QE;F$@*+ATNZZPQZ_'*2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(E-A:6YT
M($MI='1S(&%N9"!.979I<R`HN'2G2JB]M+6F:+K6I,ZEI[K[M+4I(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DQ"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W"FUS
M9VED(")386EN="!,=6-I82(*;7-G<W1R(")386EN="!,=6-I82`HN'3%4Z;H
MJ,@I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G
M<W1R(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(T-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DS"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I
M;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B4V%I;G0@
M5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,@*+ATI.6TRZ3.KN:WYZBZI$(I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(J90I$"MT[7X
MM:$@*%]S96QF*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(E-A;6]A("C"
MQ+ROJ,BX<ZYQ*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`B4V%N
M($UA<FEN;R`HN'2PJ*=1O]4I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(Q-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R
M:6YC:7!E(@IM<V=S='(@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92`HN'2F:*S\
MI,ZTMJI,INBD\2DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*
M;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R("*]PZQ0M*.HT:K,
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(E-A=61I($%R86)I
M82`HJ$:O4:9AJORIU*="*2(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHY.0IM<V=I9"`B4V%V92(*;7-G<W1R("+`>*9S(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3879E(%PB)7-<(B(*;7-G<W1R("+`>*9S(%PB)7-<(B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L('!H<"UF;W)M870*;7-G
M:60@(E-A=F4@)7,B"FUS9W-T<B`BP'BF<R`E<R(*"B,Z('1E;7!L871E<R]P
M<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R("+`
M>*9SO^^VM2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@
M(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R
M:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB
M"FUS9W-T<B`BL4ZRHZ7-JKJS7:EWP,FE2"!02%`@NWFHI:[FIJ'`>*9SJ.RG
M0:JZIOBJ0;ZYO,BF<Z78O_VDI"XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("*S7:EW("5S(*1WP'BF<RXB"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3879E
M9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("*G
M\[=SM7NFH:1WP'BF<ZCL.B!<(B5S7"(N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E-C871T97)E9"!4+5-T
M;W)M<R(*;7-G<W1R("*Y<ZQ0N7"K0B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R("*L[+['(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R("*W:K1-
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R,@IM<V=I9"`B4V5A
M<F-H($5N9VEN97,B"FUS9W-T<B`BMVJT3:3>P+HB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,CDV,@IM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(K_O
MOMS`R:[7(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0X,@IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R("*_[[[<I$"MTZ3I
MM,$B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B
M4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(K_OOMRD0*W3N'.RU:7.
MI4BW<[Q7(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I
M9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(K_OOMRD0*;LMW.JNK[6
MIK.JS"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I
M9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(K_OOMRD0+.AIOBJ0;ZY(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C
M="!A('5S97(@=&\@861D(@IM<V=S='(@(K_OOMRD0*;LJ,^ESJK,I<ZE2+=S
MO%<B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<S
M"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(K_OOMRITJ:S(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(V-3`*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C
M;VUP;VYE;G1S+B(*;7-G<W1R("*_[[[<J=*FLZ3IM,&DN*7S+B(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX-S`*;7-G:60@(E-E
M;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`BO^^^W*1`K=.JJZ7S(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-`IM<V=I9"`B4V5L
M96-T(&YO;F4B"FUS9W-T<B`BI*._[[[<(@H*(SH@<V5R=FEC97,O:V5Y8F]A
M<F0N<&AP.C,W"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U
M(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y
M(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T
M<B`BJ?.E2*15JKJU^+6AI*2_[ZCZIT&M;JJZIG*DN"ZE2+?&N:N]QKMSJ=*_
M[Z3EIG(LM4VKX;9+I%>DY:7SO7._Z+#/+B(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R
M.B(*;7-G<W1R("*_[[[<I.FTP:3`N6HZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM
M<V=S='(@(K_OOMRDZ;3!I.FTP:[FIJ$Z(@H*(SH@=&5M<&QA=&5S+W!R969S
M+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I9&5N
M=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(K_OOMRQ_<7<I_.J
MNJBMI??#T:=/.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS
M9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R("*_[[[<
MKLFVH:3`N6HZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G
M:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(K_OOMRDZ;3!
MKLFVH:[FIJ$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM
M<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(K_O
MOMRLVZ2LI,>P=*JZI$>MT\3FINPN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Q,`IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G
M<W1R("*_[[[<IT&JNL-#IN*P=+AM(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(U,@IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E
M.B(*;7-G<W1R("*_[[[<L+ZF;KMYJ*4Z(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B
M"FUS9W-T<B`BML>P9;#=PT2DS\"S(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$P,SD*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@
M(K;'L&7"LK!4(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R(")396YE9V%L
M("BVZZ2ZI5NZN"DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-@IM<V=I
M9"`B4V5N<V]R.B`B"FUS9W-T<B`BMU"T^KZY.B`B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@
M(J1%I.LB"@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS
M9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B4V5R8FEA(&%N
M9"!-;VYT96YE9W)O("BVZ[JXNONHR+M0NUBO4Z6GK?3#N2DB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,@IM<V=I9"`B4V5R:6%L($YU;6)E
M<B(*;7-G<W1R("*GQ[BY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$T.0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`BIOBJ0;ZYN.JNQK_YNWZISJK,M4RJ:ZC/I<XN(@H*
M(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"FUS9VED(")397-S:6]N($%D;6EN
M(@IM<V=S='(@(K=\M,&ZWK)Z(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS
M9W-T<B`BMWRTP2!)1""D=[E,M,$N(@H*(SH@;&EB+V%P:2YP:'`Z,30U"FUS
M9VED(")397-S:6]N<R(*;7-G<W1R("*W?+3!(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(S,3@*;7-G:60@(E-E="(*;7-G<W1R("*NUJCZI.BV]"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.0IM<V=I9"`B4V5T(&]P=&EO;G,@
M=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V
M97(@9F]R9V5T(&ET+B(*;7-G<W1R("*DN;-<IT&I\Z?1L$^Q2[U8JKJNR:W4
M+*5II4BFVZ;FK:NS7;%+O5@N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q.`IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A
M;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(K-=J7>[
MM[K=IOBJ0;ZYI%?$W:GSIT&JNJW3I$BON*5X+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX-PIM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U
M86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R("*S7:EW
MIT&JNK"^IFZ[>:BE+""NR;#/I4BDSJ3IM,&NYJ:A+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,#$*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@
M87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A
M;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("*S7:EWIT&J
MNK'2J6S`LZ7.M7NFH2S#0Z;BL'2X;2RMMJVQI_.W<\!7LG8LI,ZHY*5,Q>.E
MW+_OMK4N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0IM<V=I9"`B
M4V5T=7`B"FUS9W-T<B`BLUVI=R(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@
M879A:6QA8FQE(@IM<V=S='(@(J?SMW.U>Z:AM$ZZ_"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@(E-E=F5R86P@;&]C871I
M;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(J:S
MIFZT6*W3IF'"2:E-LV^MT[#1O,:FL\/V.B`B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#`*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L
M;&5S(@IM<V=S='(@(E-E>6-H96QL97,@*+;KJ?6ZN"DB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#DX"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R
M("+!RJJK(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*
M;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`BPK*U=;I+K6XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4P"FUS9VED(")3:&]U;&0@86-C97-S
M(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`BK$^G
M7ZRPI&JSH:7WJKJS<[6RJ7>X<:?6L;:E7*_@P>0_(@H*(SH@;&EB+TAO<F1E
M+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`BQ>.E
MW"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H
M;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H
M92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
MQ>.EW+=SLJ.ES;M0K>S`>*9SLUVI=\#)JKJN=+*G+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT.30*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE
M('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`BJ$.FN+5NI$JKX<7CI=RD5Z1`
MIKBJNK5NI$JNR;:A(#\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V.0IM
M<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@P,@IM<V=I9"`B4VAO=R!P:6-K
M97(B"FUS9W-T<B`BQ>.EW,))O^^^N2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU,S`*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A
M<C\B"FUS9W-T<B`BQ>.EW*KMKN:^WJ=`I5ROX*KM(#\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S4S"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@
M=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(JGSI:K#Y,7CI=P@
M)7,@I5ROX*KM/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L
M;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("+%XZ7<P'BF<Z[FI+JN9;GO
MN-RDZ+;T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T
M:65S(&1I86QO9R(*;7-G<W1R("+%XZ7<JNVNYJ2ZKF6Y[[C<I.BV]"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV,`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA
M;&]G(@IM<V=S='(@(L7CI=RF0Z2ZKF6Y[[C<I.BV]"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I
M9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B
MQ>.EW+QVN;.DNJYEN>^XW*3HMO0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3<V-PIM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`BQ>.EW*17ML<B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I
M9"`B4VAO=V5R<R(*;7-G<W1R("*K^<3RL'VK0B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")3:&]W97)S($5A
M<FQY(@IM<V=S='(@(J:MIK.P?:M"(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G
M<W1R("*QWZ:SL'VK0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*
M;7-G<W1R("*[MZ3HIK.P?:M"(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="YP:'`Z-#@P"FUS9VED(")3:')I;FLB"FUS9W-T<B`BIJS!62(*"B,Z(&QI
M8B](;W)D92]";&]C:R],87EO=70N<&AP.C<W-"!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+G!H<#HX,S8*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z
M.3(R(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.CDX-`HC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W(&QI8B](;W)D92]";&]C:R],87EO
M=70N<&AP.C$P.#<*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,3$Q
M-B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HQ,30Y"FUS9VED(")3:')I
M;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W
M87D@9FER<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(Q,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM
M<V=S='(@(E-I97)R82!,96]N92`HM^"D;*1SL.HI(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O4VEG;G5P+G!H<#HR-C8*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B
MM?FE52(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S$S"FUS9VED
M(")3:6=N871U<F4B"FUS9W-T<B`BP[&SN2(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM
M<V=S='(@(L.QL[FZ=+KB(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@
M(E-I;F=A<&]R92`HMW.E6ZE9*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY
M,#`@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,3D@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$R-#$*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-3`@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(Y,3D@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,3(*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#0*;7-G:60@(E-I>F4B"FUS9W-T<B`BI&JD<"(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP
M($UA:6YT96YA;F-E(@IM<V=S='(@(K*DN4RZ^\5`(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO
M=F%K:6$B"FUS9W-T<B`B4VQO=F%K:6$@*+2UK*6E[Z=**2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(P-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@
M(E-L;W9E;FEA(@IM<V=S='(@(E-L;W9E;FEA("BTM:REI>^EIZC(*2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS9VED
M(")3;F]W(@IM<V=S='(@(K.W(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@
M(K!]L[<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(K!]L[<B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B
M4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(J:MIK.P?;.W(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N
M;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(K'?IK.P?;.W(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-S@*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R
M("*_;K.WLF"KUSH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G
M:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(P-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*
M;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R(")3;VQO;6]N($ES;&%N
M9',@**_!P[FJ^;ASKG$I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R(")3
M;VUA;&EA("BOP;"HIU&HR"DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`BNG&[4+C6(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,34*;7-G:60@(E-O<G0@;W)D97(@<V5L
M96-T:6]N(@IM<V=S='(@(K'&ID.DZ*96O^^^W"(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4X.0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Q-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC
M.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,38V(&QI8B].970O4TU3+W=I
M;E]H='1P+G!H<#HQ.#D*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@
M(JC3M[VF8:=](@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(E-O
M=71H($%F<FEC82`HJVZK1"DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M-@IM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@
M(JMNO-H@*$E33RTX.#4Y+3,I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N
M9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R(")3;W5T:"!'
M96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G
M:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`BJVZE8K)Y(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G
M:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*
M;7-G:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E
M;&PB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Q.0IM<V=I
M9"`B4W!A8V5R(@IM<V=S='(@(JK%I=6FYB(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN
M9R(*;7-G<W1R("*VH;9:(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D
M9&EN9R(*;7-G<W1R("*VH;9:NU"YU*52(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S
M='(@(E-P86EN("BFZ*]:I/HI(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$P,`IM<V=I9"`B4W!A;2(*;7-G<W1R("*I5:>CMFRE\R(*"B,Z('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T
M97(@26YP=70B"FUS9W-T<B`BKU.N[:9RI+B_Z:1*(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B
M4W!L:70@8V5L;"(*;7-G<W1R("*DP+/.P'BF<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P
M;&ET(&-O;'5M;B(*;7-G<W1R("*DP+/.Q.:F["(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P
M;&ET(')O=R(*;7-G<W1R("*DP+/.ID,B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C$*;7-G:60@(E-P;W)T<R(*;7-G<W1R("*Y0K#*(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$T,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED
M(")3<FD@3&%N:V$B"FUS9W-T<B`B4W)I($QA;FMA("BTM:B]Q/6E9"DB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C8@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HW-`IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`BO-"WQR(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM
M<V=S='(@(JQ0N]JJI\51OM0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y
M,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y.`IM<V=I9"`B4W1A<G0@>65A<B(*
M;7-G<W1R("*QTJELIGZE]R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-3<Q"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R("*LV2(*
M"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED
M(")3=&%T=7,B"FUS9W-T<B`BJJRZ02(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR.#`T"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R("+`>*9SKN:F
MH2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")3
M=')E970@061D<F5S<R(*;7-G<W1R("*U\[E$(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR
M;W5G:"(*;7-G<W1R("*G4K"CO74B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3(S-PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`BIG*FZJ9#(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S<*;7-G:60@(E-T<FEP(&1O;6%I;B!F
M<F]M('1H92!A9&1R97-S(@IM<V=S='(@(J;;MFRE\Z9AIWVDI*5HL*.Z]+#L
MIE>ZV2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(KS+IJ$@
M6T-34UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R("*L4+3!I-$B"@HC.B!U=&EL+VEC
M;VY?8G)O=W-E<BYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER
M96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(J?DI*.H[*:XI=B_
M_2!<(B5S7"(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R("*E1*:N(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,S-B!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z
M,S$W"FUS9VED(")3=6)M:70B"FUS9W-T<B`BL&6E6"(*"B,Z('-I9VYU<"YP
M:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E
M<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO
M9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N
M(@IM<V=S='(@(KQ7I5L@7"(E<UPB(*CLJ'2RSJJZI=.]T*1WL&6E6"X@IT&E
MLK:WM:6H[+C3I=.]T+-1KM:MXZOAI'ZOX+5NI$HN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R
M:7!T(@IM<V=S='(@(J15O-`B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`T
M(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR
M.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R("*FJ*5<(@H*(SH@861M:6XO=7-E
M<BYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D
M9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R("*FJ*5<JKJE6Z1*
M(%PB)7-<(B"H[*ATLLZDI"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F
M;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("*FJ*5<
MJKJFVZATLLZDI+)-L*.HSZ7.JLP@7"(E<UPB(*JZN.JNQBXB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB
M+B(*;7-G<W1R(")<(B5S7"*D=Z=2L*.GN::H+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M
M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("*FJ*5<JKJF
MVZATLLZDI+*^L*,@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T
M:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(J1WIJBE7*JZ
MIEZT7[-=J7<N(+W0K:NW<[C\I$K`R[7XKG2RIRXB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G
M:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`BI'>FJ*5<JKJSQJ7WLUVI=[CJKL8N(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M(@IM<V=S='(@(J1WIJBE7*JZL\:E][-=J7>XZJ[&("5S+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`BIJBE7*JZI_.W<R!<(B5S7"(B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M=W)O=&4@)7,B"FUS9W-T<B`BI'>FJ*5<JKK"T+QG("5S(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B
M4W5D86XB"FUS9W-T<B`B4W5D86X@*,2LI*8I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M
M;6%R>2(*;7-G<W1R("*Z2ZUN(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP
M.C8U"FUS9VED(")3=6X@4FES92(*;7-G<W1R("*DZ:58(@H*(SH@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(J3I
MN*@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M.0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`BM+@B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C`U"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(J3I
MI5@B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N
M<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(J3I
MI5@OI.FXJ"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#0*
M;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R("*DZ:58.B`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`X"FUS9VED(")3=6YS970B"FUS9W-T
M<B`BI.FXJ"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#<*
M;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(J3IN*@Z("(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R
M<V-R:7!T(@IM<V=S='(@(J17O-`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S@P"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(J3DM*DB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS
M9VED(")3=7)I;F%M92(*;7-G<W1R(")3=7)I;F%M92`HQ*RG4:MN*2(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")3=7)N86UE
M(@IM<V=S='(@(KKON+DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA
M>65N(@IM<V=S='(@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C$Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED
M(")3=V%Z:6QA;F0B"FUS9W-T<B`B4W=A>FEL86YD("BE=J7+P-G$]2DB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`U(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T
M"FUS9VED(")3=V5D96XB"FUS9W-T<B`B4W=E9&5N("BWYZCE*2(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HU-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED
M(")3=VET>F5R;&%N9"(*;7-G<W1R(")3=VET>F5R;&%N9"`HM^>D:"DB"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L
M;V<@9&5L971E9"(*;7-G<W1R("*F4*A"L$^__:1WIU*PHR(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-#4*;7-G:60@(E-Y;F--3"(*;7-G<W1R("*F
M4*A"IN:PRKC+N&TB"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HY
M-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R
M("*W:K1-MK6EV*2DJKJ[>:IKO_F[?B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B
M(%)E<'5B;&EC(@IM<V=S='(@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC("BQU*=1
MJ,@I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C`*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`BN7"K0B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M
M(&%N9"!7:6YD>2(*;7-G<W1R("*Y<*M"IK.MMR(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M<R(*
M;7-G<W1R("*Y<*M"(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@(J:M
MIK.K^<3RN7"K0B(*"B,Z(&QI8B](;W)D92]$871A+W1S=BYP:'`Z,38V"FUS
M9VED(")44U8@9FEL92(*;7-G<W1R(")404(@I,"Y:J[FIJ'`R:[7(@H*(SH@
M;&EB+TAO<F1E+U5)+U1A8FQE+G!H<#HQ,S0*;7-G:60@(E1A8FQE(@IM<V=S
M='(@(JKML^8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S
M='(@(JKMKN:DNJYE(@H*(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E
M="YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R("*J
M[;/F(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R("*J
M[:[FI+JN92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S0@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS9W-T<B`B
MI7C&5R(*"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G
M:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`BI7C&5R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C4@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(Q.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B5&%J:6MI<W1A;B`HMO"F
M3K2UJ5HI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O
M9B(*;7-G<W1R(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F("BI6JE\
MI:>HR"DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDU"FUS9VED(")487)G970Z(@IM<V=S='(@(J78O-`Z(@H*(SH@8V]N
M9FEG+VAO;VMS+G!H<"YD:7-T.CDY-B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3@Y"FUS9VED(")487-K<R(*;7-G<W1R("*KW;_LJ,:VM2(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<T"FUS9VED(")496QE<&AO;F4@
M3G5M8F5R(@IM<V=S='(@(KEQN-RXN;U8(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR.3`*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@
M(K/,JO&D0*1PKLFJNK?%J]<Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C$T"FUS9VED(")496UP97)A='5R92(*;7-G<W1R("*WQ:O7(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,@IM<V=I9"`B5&5M<&5R871U
M<F4Z("(*;7-G<W1R("*WQ:O7.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C@R"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E
M/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`BM\6KUSQB
M<B`O/B@E<["J)7,O)7.G0R5S*2`F9&5G.R5S(@H*(SH@;&EB+TAO<F1E+U1E
M;7!L871E+G!H<#HV.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BI^2DHZCLO,NJ3R!<(B5S7"(N
M(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E
M($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(KS+JD^ZWK)Z(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$R,34@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,C4*;7-G
M:60@(E1E>'0B"FUS9W-T<B`BI+JN92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-SD*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R("*OPJ3EIG(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(KGON_2DY:9R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I
M9"`B5&5X='1O<"(*;7-G<W1R("*Y[[OTI.6F<K.[NMTB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*
M;7-G<W1R("*L4+3!I7PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM
M<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`BKO6DY2`H5$E3+38R,"DB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(T(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R(")4:&%I;&%N9"`HKO6PZBDB
M"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#0P"FUS9VED(")4:&4@1E10(&5X=&5N
M<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")&5%`@J;6F^2AE>'1E
M;G-I;VXIM4RNQ"XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDS,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@
M96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(DAO<F1E
M+TMO;&%B(+[CIEBD=;5[J,.EO*3DM*D@7"(E<UPB(@H*(SH@;&EB+TYE="])
M35-0+T)O;VLN<&AP.C$R.3@*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N
M;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(DE-4U`@K/:__;5,JFNS4:KL
MJ6PN(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4
M:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U
M;&QY(@IM<V=S='(@(DUA:6YT96YA;F-E(,/^IT^HPZ6\IJBE7+C\I$HB"@HC
M.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4
M:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T
M<B`BO^^VM;7XM:&E2,/VLZPNPO>V?:2D+B(*"B,Z(&QI8B](;W)D92]097)M
M<RYP:'`Z,3@Y(&QI8B](;W)D92]097)M<RYP:'`Z,C`P(&QI8B](;W)D92]0
M97)M<RYP:'`Z,C$Q"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,C(S(&QI8B](
M;W)D92]097)M<RYP:'`Z,C,T(&QI8B](;W)D92]097)M<RYP:'`Z,C4R"B,Z
M(&QI8B](;W)D92]097)M<RYP:'`Z,C8T(&QI8B](;W)D92]097)M<RYP:'`Z
M,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF
M:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@
M(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(J=!JKJH=++.
MNMZR>JW[I;*VMZ7]LUVI=Z9NI$"MT\5VK:VKX;K=I'ZOX,7]IT&HSZ7.Q7:M
MK:ATLLXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS
M9W-T<B`BJ;.NV+UU(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N
M;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@
M=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("+!<+6XN+F]6*6\J_RI=RRJQ:75
MJ<ZF8KCJKL:N=Z2DI^2DHZCL+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S
M9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(J1W
MIJBE7*JZL4[!<+6XI$BW<[Q7IMRS<;!4O_VDI"XB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HQ,3<R"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0
M('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I
M9VYE9"!M97-S86=E+B(*;7-G<W1R("+%Y\/2MFRE\\.QL[F[W:UNIK.D0*W3
MI'>XT;9]JKH@4$=0(+#/MO0N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T
M($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N
M;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("*P=+AMN'.R
MU:JZP]&G3[BYO5@H240II*.L3Z6\J_RI=RRT3JQ/JL6EU:G.JLRDHZ9BN.JN
MQJYWI*0N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T
M,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF
M:65D+B(*;7-G<W1R("*P=+AMN'.RU:6\J_RI=RXB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0N<&AP.C$Q-@IM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@
M<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`BN]VM
M;J1`K=.X9[E,I5NQ2ZJZNO2X]+-SM;(N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ
M-S<@;&EB+TAO<F1E+G!H<#HU,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R
M("+`R:[7("5S(,"SN-.E7:=TI$"MTR`E<R"S7:EW+B(*"B,Z(&QI8B](;W)D
M92YP:'`Z,3<P(&QI8B](;W)D92YP:'`Z-3`Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN
M9W,N(@IM<V=S='(@(L#)KM<@)7,@P+.XTZ5=IW2D0*C'("5S(+-=J7<N(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HR,C,*;7-G:60@(E1H92!F:6QE(&-A;FYO
M="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@(K5,JFN]QKMSJ.RF
MVZBMP,FNURXB"@HC.B!L:6(O2&]R9&4O1&%T82YP:'`Z,C@P"FUS9VED(")4
M:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`BIKG`R:[7I*2H
M4Z:SN.JNQBXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R
M('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`BI4BD5:Q/
M(')F8S@R,B"V;*7SJKJJ[<!9+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E
M;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N
M970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W
M97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE
M;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I
M;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U
M<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@
M>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N
M9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@
M(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@
M=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<')E9G,N<&AP.CDR"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N
M=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`BJ*VE]\/1
MIT\@)7,@I'>S4:=2L*,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S
M:61E(&]N;'DB"FUS9W-T<B`BI:JNV+UU(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N
M=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C
M;&%S<RXB"FUS9W-T<B`B1VYU4$<@I$>DN,#)JKJX]*Y\I;*VMZEWN'&F8B!#
M<GEP=%]P9W`Z.B##_J=/I*0N(@H*(SH@;&EB+TAO<F1E+TU)344O341.+G!H
M<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N
M="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I
M<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE
M<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B
M"B*G0;2_J?,@)7,@L4BUN2`E<R"D0*O*I42FKJRP(%PB)7-<(B"JNJM(I?.D
M=[-1MGVQTBY<;B(*(J;]LV^HPZ2CK^"K3\/2N-.K2*7SJKJDNJYEI'>GN:7^
MLU&FK*7SI$BLW:>YJ<ZD1KC1+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.#@Q"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H
M92!C;VUP;W-E('!A9V4B"FUS9W-T<B`BLW.ULJCLO7.\9[9LI?.MMJVQJ=*H
MSZ7.JKJF5[K9(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT-S0*;7-G:60@(E1H
M92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`B
MI;*VMZQ/I$"MT[S&IG(N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HQ,C,R"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@
M9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R(")(
M;W)D95]#<GEP=%]S;6EM93HZ(,/^IT\LI;*[W:UNIK,@;W!E;G-S;""\TK+5
M+B(*"B,Z(&QI8B](;W)D92]0<F5F<RYP:'`Z,C@S"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@
M<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU
M;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("*FN;"^IFX@7"(E<UPB(+CJKL:F
M7:RPME>Y3+/,I&JDN;-<K<@LJ=*E2+5,JFNS4<!XIG,B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O9&5B+G!H<#HS,B!L:6(O2&]R9&4O34E-12]6:65W
M97(O96YS8W)I<'0N<&AP.C,U"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M
M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M
M<W=O<F0N<&AP.C,R(&QI8B](;W)D92]-24U%+U9I97=E<B]R<&TN<&AP.C,R
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A
M=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`BI<ZE2,#+M?BFN;CJKL;#_JNL("@E<RD@JKJU>Z:AJ,.DHZ9SIF*I
M\ZATLLZD5RXB"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0X-PIM<V=I9"`B5&AE
M('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R
M+B(*;7-G<W1R("*DWJUZIG*ELK:WK+"SYJ1`IG*DN"XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED
M(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R("*EJJ5K
MKMB]=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*
M;7-G<W1R("*E:Z[8O74B"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0W.0IM<V=I
M9"`B5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R
M+B(*;7-G<W1R("+$YJ;LI,"Y:J9RI;*VMZRPL^:D0*9RI+@N(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T
M<B`BIKFF^*I!OKD@7"(E<UPB(*1WLU&G4K"C+B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S
M97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R("*FN:;XJD&^
MN2!<(B5S7"(@I'>S4<!XIG,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@
M:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B)7,@JKJU^:55N]VH1*1WLU&R
MOK"C+B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C,S,`IM<V=I
M9"`B5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@
M(JO\J7>JNK!/O_VHPZ2CIG.F8BXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,3<Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S
M7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(KS(IG/`R:[77"(E<UPBI*.F
M<Z9B+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S`P"FUS9VED(")4:&4@
M=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H
M92!S8W)E96XN(@IM<V=S='(@(J=!J=*_Z:1*JKJXZJ[&NU"U9:VQN.JNQJ2C
MLL4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N
M;'DB"FUS9W-T<B`BI%>D5:[8O74B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I
M9&4@;VYL>2(*;7-G<W1R("*D5Z[8O74B"@HC.B!L:6(O2&]R9&4O1&%T82YP
M:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC
M92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`BL7&D5Z1`K=.H0L9*I*>K
MX:17ML>JNKCJKL:_\J6B+B(*"B,Z(&QI8B](;W)D92]$871A+V-S=BYP:'`Z
M,C8R(&QI8B](;W)D92]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L
M;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(J17ML?`
MR:[7J,.EO+-1P'BF<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-#D@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q,`IM<V=I9"`B
M5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(G=E871H97(N8V]M(+#/MO2U3*IKJ,^ESBXB"@HC.B!U=&EL+VEC;VY?
M8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I
M<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("*GY*2CJ.R\RZ:A
ML'2X;:78O_T@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z
M,3<X"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM
M<V=S='(@(K5,I6FESJJZO^^VM2XB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT
M96YT<RYP:'`Z,S0Y"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C
M86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`BM4RJ_J7SI6FJO;&U
MMGVQTBXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30P-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I
M;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[
M("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`BIKG$
MYJ;LI*2E7:=TI-.F:*JZIG*\QBZG0:1WO^FD2B`E<R"MTZ9RO,8[IT&_Z:1*
MJKJF<KS&I;*VMZ1PJ?,@)7,N(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U
M<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P
M<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T
M<B`BMW.\5R!<(B5S7"(@J.RH=++..B`E<R"NR;5OI<VD0*W3L-W#1"XB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<
M(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("*FVZATLLZR3;"C(%PB)7-<
M(B"JNKCJKL:NR;5OI<VD0*W3L-W#1#HB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R
M96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`BIMNH
M=++.LKZPHR!<(B5S7"(@KLFU;Z7-I$"MT[#=PT0Z(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,34Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R("*G\[=S(%PB)7-<
M(CH@)7,@KLFU;Z7-I$"MT[#=PT0B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP
M:'`Z.3$P"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB
M"FUS9W-T<B`BI%>VQ\#)KM>NR;5OI<VD0*W3L-W#1#H@)7,@I;RS4:17ML<N
M(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDQ-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*
M(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("*D5[;'P,FNUZ[)
MM6^ES:1`K=.PW<-$.B`E<R"D:J1PME>Y3*2YLURSS*1JK<@@*"5D(&)Y=&5S
M*2XB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3$W"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N
M(@IM<V=S='(@(J17ML?`R:[7KLFU;Z7-I$"MT[#=PT0Z(+;(LZ&DP*JZ("5S
M(,#)KM>S4:17ML<N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG
M('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(L#+M?BV;*7SKLFU;Z7-I$"M
MT[_YNWXN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HS
M.2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N
M(@IM<V=S='(@(K;7I$JFN;-QL%2__;CJKL:NR;5OI<V_^;M^+B(*"B,Z(&QI
M8B](;W)D92]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R("*V
MUZ1*(&E#86QE;F1A<B"XZJ[&KLFU;Z7-I$"MT[_YNWXN(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HX,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R
M<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE
M9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(J9BLUVI=ZKM
ML^:DI+5OI<VD1J1`K=._^;M^+J:SI6FOX*=!O_*Z?*1&I;*VM[;QO&>JNL3F
MINPN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P
M96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@
M86=A:6X@;&%T97(N(@IM<V=S='(@(K#UIN:S<;!4O_VK_*EWI5ROX*[)M6^E
MS:1`K=._^;M^+B"]T+5YJ^&F0;C5I$"FN"XB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R
M>2!A9V%I;B!L871E<BXB"FUS9W-T<B`BI_.W<\%PM;BD2+CJKL:NR;5OI<VD
M1J1`K=._^;M^+B"]T+5YJ^&F0;C5+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#4@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(R
M,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D
M:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS
M9W-T<B`BI_.W<[!TN&VX<[+5KLFU;Z7-I$:D0*W3O_F[?BX@O="U>:OAID&X
MU2XB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS
M9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN
M9R!F;VQD97)S+B(*;7-G<W1R("*FN2!)34%0(*;XJD&^N:C#I;RDY+2IJTBE
M\Z=8I,"HR:5<K^`N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(K-OIORE1Z2CK$^EO[U4JKH@<F%R
M(,"CP5G`R:[7+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP
M.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED
M('II<"!F:6QE+B(*;7-G<W1R("*S;Z;\I4>DHZQ/I;^]5*JZ('II<"#`H\%9
MP,FNURXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$S-`IM<V=I9"`B5&AI
M<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM
M<V=S='(@(K-OIORE1Z2CK$^EO[U4JKJK2*7.I62XN;U8+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H
M92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W
M87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!L:6(O3F5T
M+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT
M='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$DB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB
M<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY
M("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q
M=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY
M("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HY.#(@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-C$@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$P.3`*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,3D@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Q.#8@;&EB+TAO<F1E+T9O<FTN<&AP.C$R
M-C`*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,#D@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$T,#(@;&EB+TAO<F1E+T9O<FTN<&AP.C$U-C$*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$X-#,@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-C(@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(P,#D*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,S,@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(P.#(@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q
M-3,*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R,C4@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(T,3(@;&EB+TAO<F1E+T9O<FTN<&AP.C(T-30*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(V-#0@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,3<@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,Q,C8*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R.34@
M;&EB+TAO<F1E+T9O<FTN<&AP.C,X,#,@;&EB+TAO<F1E+T9O<FTN<&AP.C,X
M,3$*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(J:Y
MQ.:F[*Q/I;*[W:UNJKHN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-CD*
M;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB
M"FUS9W-T<B`BIKG$YJ;LI+JN9:5UI+FS7+[CO,:\QJ9R+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR-#(P"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R("*FN<3F
MINRDNJYEI76DN;-<O,:F<J3.JU^XN2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3`Y.`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C
M=&%L('9A;'5E<RXB"FUS9W-T<B`BIKG$YJ;LI+JN9:5UI+FS7*1+MFFF[+S&
MK<@N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,C<*;7-G:60@(E1H:7,@
M9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T
M(&]F(&EN=&5G97)S(@IM<V=S='(@(J:YQ.:F[*2ZKF6ELK:WK+"S<KBYJ<ZJ
MQ:75I,"Y:JJZO,:F<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY.3,*;7-G
M:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T
M<B`BI;*VMZQ/I$"MT[S&IG(N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X
M,C4*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@
M8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C
M,3(S-&%F)RXB"FUS9W-T<B`BIKG$YJ;LI+JN9:6RMK>E7:=TI$"RU:11I+NV
M::;LJKH@4D="(,-#IN*E3KU8+*C2IG`@)R,Q,C,T868G+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HU-C4*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D
M>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`BLV^MTZKML^:D=[-1LT*R>KE,
M+B(*"B,Z('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(K-OK$\@)7,N(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@
M=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@
M=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@
M1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I
M<VET("5S(@IM<V=S='(@(B(*(K-OK$\@2V]L86(@N'.RU:JZI$"MTZJKI?,N
M(+']P,NU^*:YJJNE\[O=K6ZOX*3DM*E+;VQA8B"X<[+5KN:FH:JZN7&D;+9L
MI?.S;B(*(L7I+KW0L-&FTB`E<R"E2*1&N-&S;ZC'MFRE\[-NQ>DB"@HC.B!L
M:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z-3DX"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E
M<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("*S;ZO*
MMFRE\ZC#JT2E2*=!ND2ESJJZIG*DN+:PIM.L3ZC/I<X@*"5S*2"NT;QGIM.F
MJ"XB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI
M<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(J:YO,:M
MR+/,I-:ELK:WK$\@,2XB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP
M:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP
M(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R("*FN:;XJD&^N;5,JFNY[R!Z:7`@
MI,X@9WII<""NYJ:AP,FNU[9IIN:XT<"CP5DB"@HC.B!L:6(O2&]R9&4O4F5G
M:7-T<GDN<&AP.C$X,@IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY
M(&1E86-T:79A=&5D+B(*;7-G<W1R("*FN:ATLLZEV*MEK$^PL:7.JKJJK+I!
M+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3(T"FUS9VED(")4:&ES
M('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(J6RMK>L3Z1`K=.\
MQJ9R+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*
M;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T
M:6]N<R!W:6YD;W<B"FUS9W-T<B`BIKFU^+6AI;*VMZUNI=&_[[:UM?BUH2A/
M<'1I;VXIJ=*I2:5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C0*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`BN7`B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,V"FUS9VED(")4:6-K971S(@IM
M<V=S='(@(K#=PT2P;,+<(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,CD@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")4:6UE(@IM
M<V=S='(@(J[)MJ$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@X
M"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(J[)MJ&K_*MN(@H*(SH@
M;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G
M<W1R("*NR;:AKN:FH2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3,U"FUS
M9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R("*NR;#/O^^^W"(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(R,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G
M:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(E1I;6]R+4QE<W1E(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@(KS0PT0B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED
M(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(KS0PT0@*'1O;VQT:7`I.B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED
M(")4;R(*;7-G<W1R("*FK*7SI$@B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-C4Q"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP
M;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA
M;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B*F
M<*I'K6Z]QK_O++W0IF+"2;_OM\:YJZJZIE"NR:OV($-O;G1R;VS!Y"BMTZ1(
MN7&XHRD@J<X@0V]M;6%N9,'D*,2KJD>Y<;BC*2XB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S`P"FUS9VED(")4;V1A>2(*;7-G<W1R("*D
MM:31(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(DA434P@
MK>RI;,#)(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P.0IM<V=I9"`B5&]G;R(*;7-G<W1R(")4;V=O("BF:*WT*2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(R-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B5&]K96QA=2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#(*;7-G:60@(E1O;6]R<F]W(@IM
M<V=S='(@(JGZI-$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(Y(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R(")4;VYG82`H
MJD:E6RDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G<W1R("*SN[.A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B
M5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("*SS*17O&BNV*Q;("A?=&]P*2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B
M5')A;G-L871I;VYS(@IM<V=S='(@(L7<I,8B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C,R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C8*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A
M9"!A;F0@5&]B86=O(@IM<V=S='(@(J1DJ+VY1J3.IJNHJ:WT(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$W.30*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS
M9W-T<B`BKW6ISK"P(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`BK%"TP:1'(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM
M<V=I9"`B5'5N:7-I82(*;7-G<W1R(")4=6YI<VEA("BL\*6GINBHR"DB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,Q(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q
M"FUS9VED(")4=7)K97DB"FUS9W-T<B`B5'5R:V5Y("BD9Z;5J.0I(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(E1U<FMI<V@@*$E33RTX
M.#4Y+3DI(@IM<V=S='(@(J1GIM6HY*3E("A)4T\M.#@U.2TY*2(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(R.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G
M:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R(")4=7)K;65N:7-T86XB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS
M9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B5'5R:W,@
M86YD($-A:6-O<R!)<VQA;F1S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(S,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@
M(E1U=F%L=2`HI&>ER[Y\*2(*"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(V-`IM
M<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(K_II$JG0:JZO^^^
MW#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.`IM<V=I
M9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(K6UI7Z]=:O\O,8Z("(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`BNO2G?2(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F
M;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(KKTIWTZ(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(S-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A
M;F1A(@IM<V=S='(@(E5G86YD82`HKU&D>KE&*2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S
M,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5K<F%I
M;F4B"FUS9W-T<B`B56MR86EN92`HKU&G2L3U*2(*"B,Z(&QI8B]61E,O9FEL
M92YP:'`Z-#$V"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O
M<GDN(@IM<V=S='(@(K5,JFNF<ZCZ(%9&4R"EV+_]+B(*"B,Z(&QI8B](;W)D
M92]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT
M<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@
M(K7YI56NR;5,JFN\5Z5;PT*E?JJZJ,^ESJK,N.JP5"XB"@HC.B!L:6(O5D93
M+V9T<"YP:'`Z,SDS"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M("*U3*IKI^_%W"!61E,@P,FNUR!<(B5S7"(@JKK%=JVM+B(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z,S@Y(&QI8B]61E,O;75S<6PN<&AP.C0V.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R
M(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("*U3*IKQ=RG\R!61E,@P,FNUR`E
M<R\E<R"JNL5VK:TN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<W-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R
M("*U3*IKQ=RG\ZRP("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR,S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O
M9B!<(B5S7"(N(@IM<V=S='(@(K5,JFO`RZQDP,FNUZ1JI'`@7"(E<UPB+B(*
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z-CDR(&QI8B]61E,O<W%L+G!H<#HQ,#$Y
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C@T,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS
M9W-T<B`BM4RJ:\#+K&3`R:[7I&JD<"!<(B5S+R5S7"(N(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O<W%L+G!H<#HT,SD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T
M('1O(%-13"!S97)V97(N(@IM<V=S='(@(K5,JFNS<[6R(%-13""F^*I!OKDN
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@U.0IM<V=I9"`B56YA8FQE('1O(&-O
M;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(K5,JFNHSZ7.(%-33""S<[6R+B(*
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C(Y(&QI8B]61E,O9FEL92YP:'`Z,C,T
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(P-`HC.B!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HR,#D@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C$W"FUS9VED(")5;F%B
M;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`BM4RJ:[W&NW,@5D93(,#)
MKM<N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,W,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*
M;7-G<W1R("*U3*IKJ]BEWR!61E,@I=B__2!<(B5S7"(N(@H*(SH@;&EB+U9&
M4R]F:6QE+G!H<#HS-3@@;&EB+U9&4R]M=7-Q;"YP:'`Z,C4X(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C(V-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R("*U3*IKJ]BEWR!61E,@I=B__2XB"@HC.B!L
M:6(O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@
M5D93(&9I;&4N(@IM<V=S='(@(K5,JFNKV*7?(%9&4R#`R:[7+B(*"B,Z(&QI
M8B]61E,O<VUB+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`BM4RJ:ZO8
MI=\@5D93(*78O_T@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C8Y
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G
M<W1R("*U3*IKJ]BEWZK%I=6JNB!61E,@P,FNURXB"@HC.B!L:6(O2&]R9&4O
M0V]M<')E<W,O=&%R+G!H<#HW-B!L:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP
M:'`Z-SD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S
M='(@(K5,JFNQ3KCJKL:XT<"CP5DN(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C(R
M."!L:6(O5D93+V9T<"YP:'`Z,S`S"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E
M;7!T>2XB"FUS9W-T<B`BM4RJ:Z=2L*,@7"(E<UPB+*:YI=B__:C#JT2JQ:75
M+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HT-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%PB)7-<(CH@)7,N(@IM<V=S='(@(K5,JFNG4K"C(%PB)7-<(CH@)7,B"@HC
M.B!L:6(O5D93+V9I;&4N<&AP.C,S-2!L:6(O5D93+W-Q;"YP:'`Z,SDU(&QI
M8B]61E,O;75S<6PN<&AP.C,Q,0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS
M-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@
M=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`BM4RJ:Z=2L*,@
M)7,LIKFEV+_]J,.K1*K%I=4B"@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS
M-38@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S8P"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(K5,
MJFN[O+!JIU*PHZ78O_TN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS-#$@;&EB
M+U9&4R]M=7-Q;"YP:'`Z,S(R(&QI8B]61E,O;75S<6PN<&AP.C,S-0HC.B!L
M:6(O5D93+VUU<W%L+G!H<#HS-#,@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S4R
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(K5,JFNG4K"C(%9&4R"EV+_]+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HT
M,C`@;&EB+U9&4R]S<6PN<&AP.C0S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("*U
M3*IKIU*PHR!61E,@I=B__3H@)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C(Q
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`BM4RJ:Z=2L*,@5D93(,#)KM<@7"(E<UPB
M+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S`W(&QI8B]61E,O<W%L+G!H<#HR
M.3$@;&EB+U9&4R]M=7-Q;"YP:'`Z,38W"B,Z(&QI8B]61E,O;75S<6PN<&AP
M.C$X,"!L:6(O5D93+VUU<W%L+G!H<#HQ.#<@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z,SDQ"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,Y.0IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`BM4RJ:Z=2L*,@5D93
M(,#)KM<N(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C(T.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*
M;7-G<W1R("*U3*IKIU*PHR!61E,@I=B__2!<(B5S7"(N(@H*(SH@;&EB+U9&
M4R]S<6PN<&AP.C0P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(K5,JFN[O+!J
MIU*PHR!61E,Z("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX,C,*;7-G:60@
M(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S
M='(@(K5,JFNG4,)?I=BK9:JZI=B__2XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C8P-`IM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF
M:6-A=&4@9&5T86EL<R(*;7-G<W1R("*U3*IKN-&V?;[,P]*RT[A@(@H*(SH@
M;&EB+TYE="])35-0+G!H<#HT,S<@;&EB+TYE="])35-0+T%U=&@N<&AP.C$R
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F
M:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`BM4RJ:[C\I$HE<ZJZJ7>X<2XB"@HC
M.B!L:6(O5D93+V9I;&4N<&AP.C(P,"!L:6(O5D93+V9I;&4N<&AP.C(P-2!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-S0*(SH@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T
M<B`BM4RJ:[=HLKX@5D93(,#)KM<N(@H*(SH@;&EB+U9&4R]S;6(N<&AP.CDS
M(&QI8B]61E,O<VUB+G!H<#HQ,#8@;&EB+U9&4R]S;6(N<&AP.C8U,@HC.B!L
M:6(O5D93+V9T<"YP:'`Z.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("*U3*IKMGVQTB!6
M1E,@P,FNUR!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR.#$@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z,3,X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$T
M,0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N
M(@IM<V=S='(@(K5,JFN\9Z1*(%9&4R#`R:[7+B(*"B,Z(&QI8B]61E,O9FEL
M92YP:'`Z.#,@;&EB+U9&4R]F:6QE+G!H<#HQ,S0@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z-S8*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G
M<W1R("*U3*IKMGVQTB!61E,@P,FNURXB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E
M<W-E9"!A<F-H:79E+B(*;7-G<W1R("*U3*IKMGVQTL"CP5G`R2XB"@HC.B!L
M:6(O5D93+G!H<#HX-34*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE
M("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(K5,JFO%JJCZ(%9&4R#`
MR:[7("AF:6QE<VEZ92@I(&9A:6QE9"DN(@H*(SH@;&EB+U9&4RYP:'`Z.#@V
M"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H
M*2!F86EL960I+B(*;7-G<W1R("*U3*IKQ:JH^B!61E,@P,FNUR`H9V5T1FEL
M95-I>F4H*2!F86EL960I+B(*"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE
M<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM
M<V=S='(@(K5,JFO%JJCZP,FNUSH@(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HV
M-S,*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R
M>2XB"FUS9W-T<B`BM4RJ:\6JJ/H@=F9S<F]O=""EV+_]+B(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z,3$P-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR
M96%D>2!E>&ES=',B"FUS9W-T<B`BM4RJ:Z?SIE<@)7,@K+`@)7,Z(*9=K+"E
MV+S0JTBE\Z=8I'>F<Z9B(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(K5,JFO%W*?S(%9&4R"EV+_]JKJF5[K9+B(*"B,Z(&QI8B]61E,O<W%L
M+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`BM4RJ:[*^L*,@5D93(*78
MO_TZ("5S+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HR-S$@;&EB+U9&4R]F='`N
M<&AP.C,T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BM4RJ:\7<I_,@5D93(,#)KM<@
M7"(E<UPB(*JZIE>ZV2XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C8Q-"!L:6(O
M5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`BM4RJ:\7<I_,@
M5D93(,#)KM<@)7,O)7,@JKJF5[K9+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HS
M,C8@;&EB+U9&4R]M=7-Q;"YP:'`Z,C$S(&QI8B]61E,O;75S<6PN<&AP.C0U
M,@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR.3,@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,S`Y"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*
M;7-G<W1R("*U3*IKQ=RG\R!61E,@P,FNUZJZIE>ZV2XB"@HC.B!L:6(O5D93
M+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U
M;B`G;6MI<V]F<R<N(@IM<V=S='(@(K5,JFNP]:;F("=M:VES;V9S)RXB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B
M56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T
M<B`BM4RJ:\+@M*L@5V]R9""DY:7S(@H*(SH@;&EB+U9&4R]F='`N<&AP.C$U
M-"!L:6(O5D93+V9T<"YP:'`Z,34W"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(K5,JFN\
M9Z1*(%9&4R!<(B5S7"(@P,FNURXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$X
M,PIM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I
M;&5D*2XB"FUS9W-T<B`BM4RJ:[QGI$H@5D93(,#)KM<@*&-O<'DH*2!F86EL
M960I+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C@U(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C$T-B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-3$*;7-G:60@(E5N
M86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R("*U3*IKO&>D
M2B!61E,@P,FNU[CJKL8N(@H*(SH@;&EB+U9&4RYP:'`Z.#8Q"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D
M960N(@IM<V=S='(@(K5,JFN\9Z1*(%9&4R#`R:[7+""ZS[K0L'3#0J1WNJ$N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(JFSO74B"@HC.B!T96UP;&%T
M97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T
M<B`BJ/JN^*?SI^\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*
M;7-G<W1R("*T7ZWL(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C(R,R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS
M9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE
M8W1I;VXZ("(*;7-G<W1R("*F^*I!OKFS<[6RKLFU;Z7-I;RY=[3!JKJF7L"S
M.B`B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W."!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`BM6^ES:6\N7>TP:JZIE[`LRRET:;X
MJD&^N3H@(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`BI;RDP,/^(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*
M;7-G<W1R("*X5;#JO5@@*%541BTX*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%
M;6ER871E<R(*;7-G<W1R(")5;FET960@07)A8B!%;6ER871E<R`HJORIU*="
MP7"F6*1JI+VPZBDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,X(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@
M(E5N:71E9"!+:6YG9&]M("BM7K#J*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T
M97,B"FUS9W-T<B`B56YI=&5D(%-T871E<R`HK/RPZBDB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C,Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5
M;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B
M56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8R(&QI8B]";&]C:R]M971A<BYP
M:'`Z-S$*;7-G:60@(E5N:71S(@IM<V=S='(@(K/FINPB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HT,CD@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M-#,P"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C4X"FUS9VED
M(")5;FMN;W=N(@IM<V=S='(@(J6\JKZJNB(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED
M("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(J6\JKZJNB!!4$D@L%2NI[US
MN+D@*$%022!-97-S86=E($E$*2XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI
M96YT($UE<W-A9V4@240I+B(*;7-G<W1R("*EO*J^JKJKR*3AL%2NI[USN+D@
M*$%022!-97-S86=E($E$*2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,30W"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*
M;7-G<W1R("*EO*J^JKJF[+AMN.JP5"XB"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O
M<B!P87-S=V]R9"XB"FUS9W-T<B`BI;RJOJJZJ,^ESJK,IE>ZV:G.L4N]6"XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM
M<V=S='(@(J2DPE^EV*MEI+BE\ZJZLW.ULB(*"B,Z(&QI8B](;W)D92])9&5N
M=&ET>2YP:'`Z,S`Q"FUS9VED(")5;FYA;65D(@IM<V=S='(@(J6\J5*F5R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*
M;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@
M0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET
M>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@
M870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO
M=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B
M(@HBIEVF=Z7^Q56\>Z2CI+FS7*6\L<+%=JJZM7NFH;#UIN:PQ:15+[W&NW,O
MMDND5RX@PDF_[[U4J7>E2,#+M?@@;6]Z:6QL82YO<F<@J=(B"B*THZC1JKJL
MV\/VI]ZS3J3EI?,LQ?VG0:5II4BXT;"CIKFD0*VMJ.ZHPZ;;IN:V?:GQM7NF
MH:9SJ/JPQ;9+PZ\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T
M<B`BJ/JN^,-#IN(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8X
M-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.CDR-PHC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.CDS,PIM<V=I9"`B56YS=7!P;W)T960@17AT96YS
M:6]N(@IM<V=S='(@(J6\I.2TJ:JZL,;`R:97(@H*(SH@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R("+%W*?S(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5<&1A=&4@)7,B"FUS9W-T<B`BI_.W<R`E<R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*;7-G:60@(E5P9&%T92!U<V5R(@IM
M<V=S='(@(J?SMW.HSZ7.JLPB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A
M9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N
M<&AP.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB
M"FUS9W-T<B`B7"(E<UPBI'>G\[=S+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G
M<W1R("*G\[=SM7NFH:1WIU*PHRXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3<X(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3@*
M;7-G:60@(E5P;&]A9"(*;7-G<W1R("*D5[;'(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N
M('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(J1WI%>VQZG2
MIK/`LZ7.M7NFH:JZLUVI=\#)J.RF^*I!OKDN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B
M57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("*D:KQGJ=2D0KS&IG(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(J1J
MO&?#N;"HO,:F<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B57)U9W5A
M>2`HKU&IU*9C*2(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G
M97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E
M<R(*;7-G<W1R("*HSZ7.I=BK9:JZ.B`E<R(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B
MJ,^ESB!34TPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED
M(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@
M<V5R=F5R+B(*;7-G<W1R("*F<*I'IT&JNJC/I<ZJS*97NMDOL4N]6+M0($E-
M4U`@IOBJ0;ZYI*.F4"RE::9BIKFS7:EW+B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O961I="YI;F,Z,C$*;7-G:60@(E5S97(B"FUS9W-T<B`BJ,^E
MSJK,(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HW,38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N
M(@IM<V=S='(@(JC/I<ZJS"`E<R"EO+-QN4P@)7,@JKJQPL5VQ>?#TBXB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`BJ,^ESJK,NMZR>B(*"B,Z(&QI8B](;W)D92]0<F5F<R]5
M22YP:'`Z,C4Q"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`BJ,^ESJK,
MO^^VM2(*"B,Z('-I9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G:7-T<F%T
M:6]N(@IM<V=S='(@(JC/I<ZJS+7YI54B"@HC.B!S:6=N=7`N<&AP.C(R"FUS
M9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M=&AI<R!S:71E+B(*;7-G<W1R("*FN:^XI7BJNJC/I<ZJS+7YI56H=++.I'>P
ML:7.+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-CD*;7-G:60@(E5S
M97(@86-C;W5N="!N;W0@9F]U;F0B"FUS9W-T<B`BI^2DHZCLJ,^ESJK,L6*X
MN2(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-SD*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-B!L
M:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX(&QI8B].970O4TU3+W=I
M;E]H='1P+G!H<#HQ-3`*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,S,@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS
M9W-T<B`BJ,^ESJK,IE>ZV2(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP
M:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A
M;')E861Y(&5X:7-T<RXB"FUS9W-T<B`BJ,^ESJK,IE>ZV2!<(B5S7"(@I'>F
M<Z9B+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM<V=I
M9"`B57-E<FYA;64Z(@IM<V=S='(@(JC/I<ZJS*97NMDZ(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G
M<W1R("*HSZ7.JLPZ("(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(JAT
MLLZDI*JZJ,^ESJK,.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#(@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B
M57IB96MI<W1A;B`HKU&O]Z=/ITHI(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ
M-C<@;&EB+U9&4R]F:6QE+G!H<#HR-3D*;7-G:60@(E9&4R!D:7)E8W1O<GD@
M9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(E9&4R"EV+_]J,.DHZ9SIF(N(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$R,`IM<V=I9"`B5F%C871I
M;VXB"FUS9W-T<B`BL+*TP2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX-S`*
M;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T
M<B`BI'>GY*CLIK.NQ*JZIF'"23H@(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HV,SD*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(J:SKL2IRB(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN
M(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(J5(I,#$P:RPL^:F["BQ<;)[
MIF*P7[KB*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX-C`@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Q.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@
M;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,C0X(&QI8B](;W)D92]&;W)M+G!H<#HR
M,C<P(&QI8B](;W)D92]&;W)M+G!H<#HR,S(P"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR.3$W(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y
M"FUS9VED(")686QU97,B"FUS9W-T<B`BK<@B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C$Q,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Y,`IM<V=I9"`B5F%L
M=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(K_OJ/JMR*;;(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(T.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I
M9"`B5F%N=6%T=2(*;7-G<W1R(")686YU871U("BERZ6CJORYSRDB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,S"FUS9VED(")687)I86)L
M92(*;7-G<W1R("+%W*3&(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@
M(E9E;F5Z=65L82`HJ66DNK?GJ=0I(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES
M(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R
M("+%Y\/2I:*QT2`M(*:YMFRE\Z5IK^"D=[Y$I$B^U:;;OWFG[RXB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B5F5R<VEO;B(*
M;7-G<W1R("*JJ:6[(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R
M.`IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(JJII;NQL:CN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`BJZNJO;GON_0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T
M"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(JNKJKVYU*52(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM
M<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(JNKJKTZ(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(E9E<GD@2&EG
M:"(*;7-G<W1R("*K1+%@L*HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C0X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*;7-G<W1R
M(")6:65T($YA;2`HME:K;BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M,`IM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R("*V5JMNI.4@
M*%9)4T-)22DB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.38Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`BP,NU^"`E
M<R(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@
M97AT97)N86P@=V5B('!A9V4B"FUS9W-T<B`BIF*W<[7XM:&V?;'2(@H*(SH@
M;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@R.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(J5(("5S(,#+M?@B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR-#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS
M9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R(")6:7)G:6X@
M27-L86YD<RP@0G)I=&ES:"`HK5[$W;K[J,JX<ZYQ*2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(T-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I
M<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(E9I<F=I;B!)<VQA;F1S+"!5
M+E,N("BL_,3=NONHRKASKG$I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,#D*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`BK^"HHZO7(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,@IM<V=I9"`B5FES:6)I;&ET
M>3H@(@IM<V=S='(@(J_@J*.KUSH@(@H*(SH@;&EB+TYE="]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA
M(%--5%`B"FUS9W-T<B`BN'&D:J=1I?&\=ZVWN7&K2*2]I7&S>KE,(%--5%`B
M"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP
M:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`BQ+6G:2(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)
M3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R
M("+$M:=I(2$A(+%Q("5S(*3BL,JROK"CM7NFH2XB"@HC.B!L:6(O3F5T+U--
M4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA($A45%`B"FUS9W-T
M<B`B5TE.(+AGI=$@2%144"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA
M(@IM<V=S='(@(E=A;&QI<R!A;F0@1G5T=6YA(@H*(SH@;&EB+TAO<F1E+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C0@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C@S"FUS9VED(")787)N:6YG(@IM<V=S='(@(L2UIVDB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")7
M92(*;7-G<W1R("*L4+3!I%0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`BI-&N
M\+EWM/HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$V"FUS
M9VED(")796%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`BKO"V2+CJ
MKL:THZC1(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y-@IM<V=I9"`B5V5A
M=&AE<BYC;VTB"FUS9W-T<B`B=V5A=&AE<BYC;VT@NO2ON"(*"B,Z(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`BNO2ON"(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,SD*;7-G:60@(E=E8B!3
M:71E(@IM<V=S='(@(KKTK[@B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N
M<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`BJ$.V9R(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC;VUE(@IM<V=S
M='(@(L5WJN\B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R("+%=ZKOJ.P@)7,B"@HC.B!S97)V
M:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE
M;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS
M9W-T<B`BQ7>J[RP@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM
M<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`BINB\VB`H25-/
M+3@X-3DM,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B
M5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(J;HO-H@*$E33RTX.#4Y
M+3$U*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R(")797-T97)N
M(%-A:&%R82`HINB\NZNBJ=0I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H
M;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R("*U;J1*J^'`
ML[C3I?W%XZ7<("5S(*W^I$"MT\"SI<ZU>Z:A/R(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET
M97(@8VAA<F%C=&5R/R(*;7-G<W1R("+$YJ;LJKJDP+EJIG*DN#\B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T
M:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("*DWJUZJKJK9;AMIG*DN#\B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V,0IM
M<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(E=H97)E:7,@
M075S=')A;&EA(*9AN<\B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G
M:60@(E=H:6-H('!H87-E<R(*;7-G<W1R("*M_JW3I.NLVR(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,S8*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@
M96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`BNO2M
MMKUSO^B^N:JZM*&E\RAP;'5G:6YS*;'2L,JQL:CN+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@
M(E=I9'1H(@IM<V=S='(@(KQEJ]<B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S$Q-`IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(J5(($-3
M4R"LL+/FINRJNKQEJ]<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N
M('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G
M<W1R("*EJL/D)7.E7*_@JNVJNKQEJ]<HI%6FN+5NI$JI;*7-KL0I.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS
M9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`BJNVNYKQEJ]<B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM
M<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("*\9:O7L^:F["(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7
M:61T:#HB"FUS9W-T<B`BO&6KUSHB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-3$U"FUS9VED(")7:6MI(@IM<V=S='(@(K:PQ>FST*=`(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X.2!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5VEN9"(*;7-G<W1R
M("*MMR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8V"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(J:MIK.MMR(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO
M=',B"FUS9W-T<B`BK;>S="BX8"DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$U-@IM<V=I9"`B5VEN9#HB"FUS9W-T<B`BK;>S=#HB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")7:6YD.B`B"FUS9W-T
M<B`BK;>S=#H@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED
M(")7:7-D;VTB"FUS9W-T<B`BM+R\>B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ.3@*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(K3!J]W"IZJK
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM
M<V=S='(@(J1UIT`B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$R-"!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM
M<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(K_LI+VKQZ9AIWTB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R
M:R!0:&]N92(*;7-G<W1R("*_[*2]J\>Y<;C<(@H*(SH@;&EB+T9I;&4O0U-6
M+G!H<#HQ.3,@;&EB+T9I;&4O0U-6+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E
M8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(K+$)62FYJJZQ.:F[+S&I=BD
MHZ6_O50N(,"SN-.M;J:S)62MT\3FINPLI76GY*CL)62MT\3FINPN(@H*(SH@
M;&EB+T9I;&4O0U-6+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O
M;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*
M;7-G<W1R("+$YJ;LO,:EV*2CI;^]5"X@P+.XTZUNIK,E9*W3Q.:F["RE=:?D
MJ.PE9*W3Q.:F["XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$Q.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E
M861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`BM4RJ:\7<I_,@5D93(,#)KM>J
MNJ97NMDN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T-0IM<V=I
M9"`B6"U2968B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU.30*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I
M9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R(")8-3`Y=C,@
MJ;6F^:KWQE^[>:IK(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS
M9W-T<B`B6#4P.78S(*5$IJZTP*5.IE>ZV2(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3DV"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E
M;G1I9FEE<B(*;7-G<W1R(")8-3`Y=C,@I42FKJKWQE_#T:=/JLPB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8X,PIM<V=I9"`B6#4P.78S(&5X
M=&5N<VEO;G,B"FUS9W-T<B`B6#4P.78S(+#&P,FF5R(*"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R("*F?B(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,PIM<V=I9"`B65E962(*;7-G<W1R
M("*F?B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,3`X"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(EEA:&]O("$@IF&YSR(*
M"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L
M>2(*;7-G<W1R("*H0Z9^(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B665M96XB"FUS9W-T<B`B665M
M96X@*+BMJODI(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDV,PIM<V=I9"`B665S(@IM<V=S='(@(JQ/(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@
M22!!9W)E92(*;7-G<W1R("*L3ZJZ+*?:IE"W3B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@
M:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@
M8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("*G0:78JV6HSZ7.K\*DY:9RO7.\
M9[S2IJ$N(*C/I<X@6SP^72"K]K9SI6FDP;2KK+"Z]*VVO7.\9[S2IJ$N(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C@R"B,L('!H<"UF;W)M870*
M;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA
M;B`E9"!B;&]C:W,N(@IM<V=S='(@(J2CI+FS7*=!J]BEWR5DI4BD5ZJZL,^V
M]"XB"@HC.B!L:6(O2&]R9&4N<&AP.C$T,34*;7-G:60@(EEO=2!A<F4@;F]T
M(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(J=!I;RS4;'"Q78N(@H*(SH@;&EB
M+TAO<F1E+TED96YT:71Y+G!H<#HS,#<*;7-G:60@(EEO=2!C86YN;W0@:&%V
M92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S
M='(@(J=!JKJE_J97I*2DHZ5IIK,@)UQ<)R"S;[S+JKJF<J2X+B`B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3@U.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW
M.0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R
M97-S+B(*;7-G<W1R("*G0:C#I;R_Z:1*I$"MTZ:SKL2JNKEQI&RV;*7SINRG
M?2XB"@HC.B!L:6(O2&]R9&4O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@
M:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB
M:6X@)7,N(@IM<V=S='(@(J=!J,.EO*71MM>D2JJZP,FNUZ2DN>^L3:7TIO/$
MYJ;LJ.P@)7,B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3@T"FUS9VED(")9
M;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(J=!I'>X9[5NI5@N
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-C4*;7-G:60@(B(*(EEO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S
M(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA
M=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"B*]T+_II$JD0*W3
MIK.NQ*JZN7&XW+BYO5@LL.J[VKEQN-RXN;U8MLBE=:2YLUR\QJ9RN+F]6"RH
MP[7XL:&J<*5IJ?.K9:VQID&E6Z1`(@HBK=,@)RLG+B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,3DR"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A
M;&ED('9A;'5E+B(*;7-G<W1R("*G0:6RMK>_Z:1*I$"MTZ:SKL2JNJW(+B(*
M"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M
M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU
M<',N(@IM<V=S='(@(J=!I;*VMZ7]LU>YNJ9NOO"JK+CJKL8H1&%T851R964I
MIOBJ0;K=I'ZOX,1^Q/*HSZ7.MW.ESJ3AM?FE5:I!L,@N(@H*(SH@;&EB+TAO
M<F1E+G!H<#HT-C(*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B
M86-K96YD+B(*;7-G<W1R("*G0:6RMK>E_;-7N;JD0*W3M>K`P,#)KM>H=++.
M*%9&4RFF^*I!NMTN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E
M9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R
M("*]T+1YK7JPW<-$H4&F8J=!ML>P9;#=PT2S^*=II*>K92XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9
M;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@
M=&\B"FUS9W-T<B`BIT&ELK:WO^FD2J:YLW.ULJG2J_RF5JJZNO2G?2(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@;75S
M="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(KW0
MJ_RI=ZUNIU*PHZJZIOBJ0;ZY+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM
M<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U
M="XB"FUS9W-T<B`BO="K_*EWK6ZR3;"CJKJHSZ7.JLPN(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA
M;64@=&\@<F5M;W9E+B(*;7-G<W1R("*]T*O\J7>M;K*^L*.JNJC/I<ZJS"XB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N
M86UE('1O(&%D9"XB"FUS9W-T<B`BO="K_*EWK6ZW<[Q7JKJHSZ7.JLPN(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y
M('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(KW0J_RI=ZUNI_.W
M<ZJZJ,^ESJK,+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$S
M.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F
M;W)M+B(*;7-G<W1R("*]T*O\J7>M;K#UIN:JNJ=`I<XN(@H*(SH@;&EB+TAO
M<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO=2!M
M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`BIT&ELK:W
MO^FD2K=SI,##_JJZIE>ZV2XB"@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET
M86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N
M($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(J=!I;*VM[2CJ-&D0*W3
MN'&D:J=1N=*DNJJZN7&XW+BYO5@B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z
M.3<R"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@
M97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R("*G0:JZ("5S
M(+=\M,&D=[E,KLDNO="MJ[=SM6ZD2BXB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM
M<V=S='(@(J=!JKJY<:1LMFRE\Z;MIWTB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C$U"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@
M(J=!JKJQ2*7SI$BY<:1LMFRE\Z;MIWTZ(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-R!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR"FUS
M9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(J=!JKJXZK!4(@H*(SH@
M;&EB+TAO<F1E+T%U=&@N<&AP.CDW-@HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE
M(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@
M>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@
M(B(*(J;;L7&G0:JZ("5S(+=\M,&V?:ELI4BHTZ=!JKJZ]+O:NO2X]*;LIWVD
M=\7<I_,N(*RPJT_%0*=!JKJF=Z7^L%^HHZ%!IT&ELK:WK:LB"B*W<[5NI$HN
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@
M(EEO=7(@3F%M92(*;7-G<W1R("*G0:JZIE>ZV2(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VYO861D+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N
M($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S
M97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H
M96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"B*G0:JZQ>?#TJ;XJD&Z
MW:C#I*.DY+2IMW.\5ZC/I<ZJS"X@IG"J1Z=!I\:QYKK>LGJHSZ7.JLRQ8KBY
M+*=!I;*VMZ5TO^^HY*5,JKK%YR(*(L/2IOBJ0;K=+B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H
M96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U
M<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R
M('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("*G0:JZQ>?#TKK=J,.EO*3D
MM*FF0Z58J,^ESJK,J<ZXTZ5<K^"D=[-1P_:SK"XB"@HC.B!L:6(O2&]R9&4O
M075T:"YP:'`Z.3@P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O
M=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN
M:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E
M8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HBIMNQ
M<:=!JKH@)7,@MWRTP;9]J6RE2*C3IT&JNL)SQ/V^N:;\I4>D=\7<I_,N(*RP
MJT_%0*=!JKJF=Z7^L%^HHZ%!IT&ELK:WK:NW<R(*(K5NI$HN(@H*(SH@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z-34*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S
M(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`BIT&JNL)SQ/V^
MN:C#I;RDY+2ILV^MTZ5<K^`N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M<')I;G0N:G,Z-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S
M=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA
M;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("*G0:JZPG/$_;ZYJ,.EO*3D
MM*FF0Z9,O^^VM2Z]T*OV($-44DPO0V]M;6%N9"`K(%`@ID.F3"XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8Q"FUS9VED(")9;W5R(&-U<G)E;G0@
M=&EM92!Z;VYE.B(*;7-G<W1R("*G0:78JV6ITK-=J7>JNJ[)L,\Z(@H*(SH@
M<V5R=FEC97,O<')E9G,N<&AP.CDX"FUS9VED(")9;W5R(&1E9F%U;'0@:61E
M;G1I='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`BN]6D5;EWLUVJNJBM
MI??#T:=/I'?%W*?S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C$*
M;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`BN]6D5;EW
MLUVJNJBMI??#T:=/.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#0*
M;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R("*G0:JZI?ZF5SHB"@HC
M.B!L:6(O2&]R9&4O075T:"YP:'`Z.3DV"FUS9VED(")9;W5R(&QO9VEN(&AA
M<R!E>'!I<F5D+B(*;7-G<W1R("*G0:JZM6ZD2J1WJ.RTP2XB"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(J=!
MIF(@)7,@I*2JNK=SL4N]6*Q/.B`E<R(*"B,Z(&QI8B](;W)D92]0<F5F<R]5
M22YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@
M(J=!IF*U;J1*M,&VH:JZO^^VM:1WLU&G\[=S+B(*"B,Z(&QI8B](;W)D92]0
M<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N
M('5P9&%T960N(@IM<V=S='(@(J=!JKJ_[[:UI'>G\[=S+B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D
M(&AA<R!B965N(')E<V5T(@IM<V=S='(@(J=!JKJQ2[U8I'>MJ[=SLUVI=R(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9
M;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL
M(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T
M<B`BL4N]6*1WLU&MJ[=SLUVI=RRW<ZJZL4N]6*1WLWJY3+EQI&RV;*7SL4BU
M;[W0I4BXT[%+O5BU;J1*+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,S`*
M;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(J=!
MJKJQ2[U8I'>H[+3!+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`BIT&J
MNKNWNMVF^*I!OKDZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-"!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU9V]S;&%V:6$B
M"FUS9W-T<B`B675G;W-L879I82`HJVZTM:G4I-(I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R("):86ER
M92`HPL2E["DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T<B`B6F%M8FEA("BI
M?*3QJ,@I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B6FEM8F%B=V4@
M**BOI-JKPBDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@
M(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H
M:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=
M(@IM<V=S='(@(EO!],+#I-ZM>ETB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H
M<#HX.0IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");L-W#1*3/
MK$U=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z
M,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B6\7CI=RD
MWJUZ("TB"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O:&EG:&QI9VAT<75O
M=&5S+G!H<#HQ-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D
M(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B6\7CI=RDWJUZ("T@)7,@IN9=
M(@H*(SH@;&EB+TAO<F1E+G!H<#HQ.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(ENF[*GSIN8@)7,@ID`@)7,@IN9=
M(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-30U('1E;7!L871E<R]P;W)T86PO;65N
M=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R("*ZWK)Z
M7T$B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`B
MJ5*E3Z9#7T,B"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E
M92(*;7-G<W1R("*^\*JLN.JNQE]$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E
M(%)O=R(*;7-G<W1R("*G4K"CID-?1"(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM
M<V=I9"`B7T=R;W5P<R(*;7-G<W1R("*X<[+57T<B"@HC.B!L:6(O2&]R9&4O
M365N=2YP:'`Z,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R("*[H:GZ7T@B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(KQV
MN;.DNJYE7TDN+BXB"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED
M(")?3&]G(&EN(@IM<V=S='(@(K5NI$I?3"(*"B,Z(&QI8B](;W)D92]-96YU
M+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(K5NI5A?3"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(JW7I^^S<[6R
M7TTN+BXB"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T
M:6]N<R(*;7-G<W1R("*_[[:U7T\B"@HC.B!L:6(O87!I+G!H<#HQ,S<*;7-G
M:60@(E]097)M:7-S:6]N<R(*;7-G<W1R("+%=JVM7U`B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G
M:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R("*ROK"CN>^S<[6R7U(N+BXB
M"@HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R("*S
M7:EW7U,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM
M<V=S='(@(JKMKN:DNJYE7U0N+BXB"@HC.B!L:6(O87!I+G!H<#HQ,CD*;7-G
M:60@(E]5<V5R<R(*;7-G<W1R("*HSZ7.JLQ?52(*"B,Z(&QI8B](;W)D92]+
M;VQA8BYP:'`Z.3(P"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`BLW&P
M5+_](@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3,T"B,L(&9U
M>GIY"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R("*S<;!4O_TB
M"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDQ,@IM<V=I9"`B8V%L96YD87(B
M"FUS9W-T<B`BIN:HQK[D(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(F-A;&TB"FUS9W-T<B`BN7.OQ:VW(@H*(SH@;&EB+TAO<F1E+TU)
M344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U
M="!F:6QE(@IM<V=S='(@(K5,JFNKV*7?O^FE6,#)KM<B"@HC.B!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN
M<'5T(@IM<V=S='(@(K5,JFNV?;'2O^FD2B(*"B,Z(&QI8B](;W)D92]-24U%
M+T-O;G1E;G1S+G!H<#HU.3D*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B
MJ_:FN2(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I
M9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(K%+I4^F0[MY
MJFN_^;M^(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3<X"FUS
M9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(K-=J7>_^;M^(@H*
M(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET
M:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(K_RI:*MJZUNJKJH
M=++.P,FNUR(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$R-@IM
M<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`BN.JNQJ[FIJ&_^;M^
M(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3@R"FUS9VED(")E
M;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`BI^2DHZCLL$^__2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"B,L(&9U>GIY"FUS
M9VED(")F86QL:6YG(@IM<V=S='(@(K7[I,`B"@HC.B!L:6(O2&]R9&4O0G)O
M=W-E<BYP:'`Z.#@Q"FUS9VED(")F:6QE(@IM<V=S='(@(L#)KM<B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L:6(O0FQO8VLO;65T87(N<&AP.C,V
M,"!L:6(O0FQO8VLO;65T87(N<&AP.C,X-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(K%Q("5S("@E
M<RD@J?,@)7,@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C,Y"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(K!]K;<B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0X"FUS9VED(")H.B(*;7-G
M<W1R("*NR3HB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S4W"FUS9VED(")H:"(*;7-G<W1R("*NR2(*"B,Z(&QI8B](;W)D92]-
M24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB
M"FUS9W-T<B`BI;RJOJJZMFRE\Z5$OO>F5[K9(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4V-2!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(J7?IUDB
M"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F
M+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(JJ]L;7%XZ7<J?.ENZ3E
ML,\B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@
M(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("*_Z:1*+[_II5B_^;M^(@H*
M(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E
M<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R("*DNK.ALV[%Z;_YNWXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I
M9"`B;&EN97-=(@IM<V=S='(@(J;F72(*"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@
M97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8X"FUS9VED
M(")M;2(*;7-G<W1R("*DP"(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z
M,CDQ('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C(S,@IM<V=I9"`B;F%M92(*;7-G<W1R
M("*F5[K9(@H*(SH@;&EB+TAO<F1E+U)00RYP:'`Z,3(T"FUS9VED(")N;W0@
M:6UP;&5M96YT960B"FUS9W-T<B`BJ7REO+GJIT`N(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HQ,C(P"FUS9VED(")N;W0@>65T(&EM<&QE;65N
M=&5D(@IM<V=S='(@(JE\I;RYZJ=`+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z.3`T"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(K/&I]&__2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*
M;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`BILJDP*3Q(@H*(SH@;&EB+TAO<F1E
M+TU)344O365S<V%G92YP:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E;FEE
M9"(*;7-G<W1R("*F<ZCZOD2IVB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G
M<W1R("*YLZ_`(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3<P
M"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`BLW&K
M2*CSJ7>[M[K=O_F[?B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<S"FUS9VED(")R:7-I;F<B"FUS9W-T<B`BI%>DR2(*"B,Z
M(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC
M92!U;F%V86EL86)L92(*;7-G<W1R("*U3*5II<ZJNJI!L,@B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.CDY"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S
M(@IM<V=S='(@(L7CI=RN=+*G(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S
M='(@(G-M<S)E;6%I;""X9Z71($A45%`B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S@T"FUS9VED(")S<R(*;7-G<W1R("*L[2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS
M9VED(")S=&5A9'DB"FUS9W-T<B`BPZVI=R(*"B,Z(&QI8B](;W)D92]-24U%
M+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@
M(JATLLZ_^;M^(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,C@*;7-G:60@
M(G1A<VL@;&ES="(*;7-G<W1R("*KW;_LPZ\B"@HC.B!L:6(O2&]R9&4O34E-
M12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM
M<V=S='(@(KS(KLFIRJJZI:*QT2(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&QI
M8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED(")T>7!E('1H92!P
M87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(J9!IKB_Z:1*IT&J
MNK%+O5BE2+U4NWNU3+M^(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T
M<B`BON.F6"(*"B,Z(&QI8B](;W)D92]-24U%+U!A<G0N<&AP.C(W"FUS9VED
M(")U;FYA;65D(@IM<V=S='(@(J6\J5*F5R(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-C4@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(JC/I<ZJ
MS+_OOMPB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C,U
M"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR-#`*;7-G:60@(G<Z(@IM<V=S='(@
M(JQ0M,$Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G
M:60@(G=E871H97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M(+KTK[@B"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<G!C+G!H<```
M````````````````````````````````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-34U,P`Q,#4Q-30S,S<T,P`P,3<Q-C(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D
M93H@:&]R9&4O<G!C+G!H<"QV(#$N,S`N,3`N,R`R,#`V+S`Q+S`Q(#(Q.C(X
M.C`T(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($IA;B!3
M8VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D
M969I;F4H)T%55$A?2$%.1$Q%4B<L('1R=64I.PI`9&5F:6YE*"=(3U)$15]"
M05-%)RP@9&ER;F%M92A?7T9)3$5?7RDI.PIR97%U:7)E7V]N8V4@2$]21$5?
M0D%312`N("<O;&EB+V-O<F4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]2
M4$,N<&AP)SL*"B\J($QO;VL@870@=&AE($-O;G1E;G0M='EP92!O9B!T:&4@
M<F5Q=65S="P@:68@:70@:7,@879A:6QA8FQE+"!T;R!T<GD*("H@86YD(&1E
M=&5R;6EN92!W:&%T(&MI;F0@;V8@<F5Q=65S="!T:&ES(&ES+B`J+PHD:6YP
M=70@/2!N=6QL.PHD<&%R86US(#T@;G5L;#L*"FEF("@A96UP='DH)%]315)6
M15);)U!!5$A?24Y&3R==*2!\?`H@("`@:6Y?87)R87DH)%]315)615);)U)%
M455%4U1?34542$]$)UTL(&%R<F%Y*"=04D]01DE.1"<I*2D@>PH@("`@)'-E
M<G9E<E1Y<&4@/2`G=V5B9&%V)SL*?2!E;'-E:68@*&ES<V5T*"1?4T525D52
M6R=215%515-47TU%5$A/1"==*2`F)@H@("`@("`@("`@)%]315)615);)U)%
M455%4U1?34542$]$)UT@/3T@)T=%5"<@)B8*("`@("`@("`@(%5T:6PZ.F=E
M=$=E="@G<F5S=$-A;&PG*2D@>PH@("`@)'-E<G9E<E1Y<&4@/2`G<F5S="<[
M"GT@96QS96EF("@A96UP='DH)%]315)615);)T-/3E1%3E1?5%E012==*2D@
M>PH@("`@:68@*'-T<G!O<R@D7U-%4E9%4ELG0T].5$5.5%]465!%)UTL("=A
M<'!L:6-A=&EO;B]V;F0N<WEN8VUL*WAM;"<I("$]/2!F86QS92D@>PH@("`@
M("`@("1S97)V97)4>7!E(#T@)W-Y;F-M;"<["B`@("`@("`@+RH@4WEN8VUL
M(&1O97,@:71S(&]W;B!S97-S:6]N(&AA;F1L:6YG+B`J+PH@("`@("`@("1S
M97-S:6]N7V-O;G1R;VP@/2`G;F]N92<["B`@("!](&5L<V5I9B`H<W1R<&]S
M*"1?4T525D526R=#3TY414Y47U194$4G72P@)V%P<&QI8V%T:6]N+W9N9"YS
M>6YC;6PK=V)X;6PG*2`A/3T@9F%L<V4I('L*("`@("`@("`D<V5R=F5R5'EP
M92`]("=S>6YC;6Q?=V)X;6PG.PH@("`@("`@("\J(%-Y;F-M;"!D;V5S(&ET
M<R!O=VX@<V5S<VEO;B!H86YD;&EN9RX@*B\*("`@("`@("`D<V5S<VEO;E]C
M;VYT<F]L(#T@)VYO;F4G.PH@("`@?2!E;'-E:68@*'-T<G!O<R@D7U-%4E9%
M4ELG0T].5$5.5%]465!%)UTL("=T97AT+WAM;"<I("$]/2!F86QS92D@>PH@
M("`@("`@("1I;G!U="`]($AO<F1E7U)00SHZ9V5T26YP=70H*3L*("`@("`@
M("`O*B!#:&5C:R!F;W(@4T]!4"!N86UE<W!A8V4@55))+B`J+PH@("`@("`@
M(&EF("AS=')P;W,H)&EN<'5T+"`G:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO
M<F<O<V]A<"]E;G9E;&]P92\G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@
M)'-E<G9E<E1Y<&4@/2`G<V]A<"<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'-E<G9E<E1Y<&4@/2`G>&UL<G!C)SL*("`@("`@("!]"B`@("!]
M(&5L<V4@>PH@("`@("`@(&AE861E<B@G2%144"\Q+C`@-3`Q($YO="!);7!L
M96UE;G1E9"<I.PH@("`@("`@(&5X:70["B`@("!]"GT@96QS92!["B`@("`D
M<V5R=F5R5'EP92`]("=S;V%P)SL*?0H*:68@*"1S97)V97)4>7!E(#T]("=S
M;V%P)R`F)@H@("`@*"%I<W-E="@D7U-%4E9%4ELG4D5154535%]-151(3T0G
M72D@?'P*("`@("`D7U-%4E9%4ELG4D5154535%]-151(3T0G72`A/2`G4$]3
M5"<I*2!["B`@("`D<V5S<VEO;E]C;VYT<F]L(#T@)VYO;F4G.PH@("`@:68@
M*&ES<V5T*"1?1T546R=W<V1L)UTI*2!["B`@("`@("`@)'!A<F%M<R`]("=W
M<V1L)SL*("`@('T@96QS92!["B`@("`@("`@)'!A<F%M<R`]("=D:7-C;R<[
M"B`@("!]"GT*"B\J($QO860@8F%S92!L:6)R87)I97,N("HO"G)E<75I<F5?
M;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PH*+RH@3&]A9"!T
M:&4@4E!#(&)A8VME;F0@8F%S960@;VX@)'-E<G9E<E1Y<&4N("HO"B1S97)V
M97(@/2`F2&]R9&5?4E!#.CIS:6YG;&5T;VXH)'-E<G9E<E1Y<&4L("1P87)A
M;7,I.PH*+RH@3&5T('1H92!B86-K96YD(&-H96-K(&%U=&AE;G1I8V%T:6]N
M+B!">2!D969A=6QT+"!W92!L;V]K(&9O<B!(5%10"B`J(&)A<VEC(&%U=&AE
M;G1I8V%T:6]N(&%G86EN<W0@2&]R9&4L(&)U="!B86-K96YD<R!C86X@;W9E
M<G)I9&4@=&AI<PH@*B!A<R!N965D960N("HO"B1S97)V97(M/F%U=&AO<FEZ
M92@I.PH*+RH@1V5T('1H92!S97)V97(G<R!R97-P;VYS92X@5V4@8V%L;"`D
M<V5R=F5R+3YG971);G!U="@I('1O(&%L;&]W"B`J(&)A8VME;F1S('1O(&AA
M;F1L92!I;G!U="!P<F]C97-S:6YG(&1I9F9E<F5N=&QY+B`J+PII9B`H)&EN
M<'5T(#T]/2!N=6QL*2!["B`@("`D:6YP=70@/2`D<V5R=F5R+3YG971);G!U
M="@I.PI]"@HD;W5T(#T@)'-E<G9E<BT^9V5T4F5S<&]N<V4H)&EN<'5T+"`D
M<&%R86US*3L*"FEF("AI<U]A*"1O=70L("=014%27T5R<F]R)RDI('L*("`@
M(&AE861E<B@G2%144"\Q+C`@-3`P($EN=&5R;F%L(%-E<G9E<B!%<G)O<B<I
M.PH@("`@97AI=#L*?0H*+RH@4F5T=7)N('1H92!R97-P;VYS92!T;R!T:&4@
M8VQI96YT+B`J+PIH96%D97(H)T-O;G1E;G0M5'EP93H@)R`N("1S97)V97(M
M/F=E=%)E<W!O;G-E0V]N=&5N=%1Y<&4H*2D["FAE861E<B@G0V]N=&5N="UL
M96YG=&@Z("<@+B!S=')L96XH)&]U="DI.PIH96%D97(H)T%C8V5P="U#:&%R
M<V5T.B!55$8M."<I.PIE8VAO("1O=70["@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+P``````````````````````
M````````````````````````````````````````````````````````````
M`````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,S-S4V`#`Q-S,U,``@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O
M+FAT86-C97-S````````````````````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,38`,3`U,34T,S,W-34`,#(Q,30R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$1E;GD@9G)O;2!A;&P*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+V-O;VMI95]L;V=I
M;BYP:'``````````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-C$W
M`#$P-3$U-#,S-S4V`#`R,C4R-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]S
M8W)I<'1S+V-O;VMI95]L;V=I;BYP:'`L=B`Q+C(N,BXR(#(P,#8O,#$O,#$@
M,C$Z,CDZ,#D@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@
M2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M+PH*0&1E9FEN92@G05542%](04Y$3$52)RP@=')U92D["D!D969I;F4H)TA/
M4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXG*3L*<F5Q=6ER
M95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["@HD875T:"`]
M("9!=71H.CIS:6YG;&5T;VXH)&-O;F9;)V%U=&@G75LG9')I=F5R)UTI.PH*
M+R\@0VAE8VL@9F]R($-/3TM)12!A=71H+@II9B`H96UP='DH)%]#3T]+245;
M)W5S97(G72D@?'P@96UP='DH)%]#3T]+245;)W!A<W-W;W)D)UTI('Q\"B`@
M("`A)&%U=&@M/F%U=&AE;G1I8V%T92@D7T-/3TM)15LG=7-E<B==+"!A<G)A
M>2@G<&%S<W=O<F0G(#T^("1?0T]/2TE%6R=P87-S=V]R9"==*2DI('L*("`@
M(&AE861E<B@G3&]C871I;VXZ("<@+B!(;W)D93HZ87!P;&EC871I;VY5<FPH
M)VQO9VEN+G!H<#]L;V=O=71?<F5A<V]N/2<@+B!!551(7U)%05-/3E]"041,
M3T=)3BP@=')U92DI.PH@("`@97AI=#L*?0H*)'5R;"`](%5T:6PZ.F=E=$9O
M<FU$871A*"=U<FPG*3L*:68@*&5M<'1Y*"1U<FPI*2!["B`@("`D=7)L(#T@
M2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=I;F1E>"YP:'`G+"!T<G5E*3L*?0IH
M96%D97(H)TQO8V%T:6]N.B`G("X@)'5R;"D["@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+V-O=6YT
M7W-E<W-I;VYS+G!H<```````````````````````````````````````````
M`````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`T,34R`#$P-3$U-#,S-S4U`#`R,S$T,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````C(2]U<W(O8FEN+W!H<`H\/W!H<`HO
M*BH*("H@)$AO<F1E.B!H;W)D92]S8W)I<'1S+V-O=6YT7W-E<W-I;VYS+G!H
M<"QV(#$N-2XR+C,@,C`P-B\P-"\Q."`Q-CHR-#HU."!J86X@17AP("0*("H*
M("H@5&AI<R!S8W)I<'0@8V]U;G1S('1H92!N=6UB97(@;V8@86-T:79E(&%U
M=&AE;G1I8V%T960@=7-E<B!S97-S:6]N<RX*("H*("H@0V]M;6%N9"!L:6YE
M(&]P=&EO;G,Z"B`J("`@)RUL)R`@($QI<W0@=&AE('5S97)N86UE(&]F(&%C
M=&EV92!A=71H96YT:6-A=&5D('5S97)S"B`J("`@)RUL;"<@($QI<W0@=&AE
M('5S97)N86UE(&%N9"!L;V=I;B!T:6UE(&]F(&%C=&EV92!A=71H96YT:6-A
M=&5D('5S97)S"B`J+PH*+R\@3F\@875T:"X*0&1E9FEN92@G05542%](04Y$
M3$52)RP@=')U92D["@HO+R!&:6YD('1H92!B87-E(&9I;&4@<&%T:"!O9B!(
M;W)D92X*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I
M("X@)R\N+B<I.PH*+R\@1&\@0TQ)(&-H96-K<R!A;F0@96YV:7)O;FUE;G0@
M<V5T=7`@9FER<W0N"G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O
M8V]R92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T-,22YP:'`G.PH*+R\@
M36%K92!S=7)E(&YO(&]N92!R=6YS('1H:7,@9G)O;2!T:&4@=V5B+@II9B`H
M(4AO<F1E7T-,23HZ<G5N;FEN9T9R;VU#3$DH*2D@>PH@("`@97AI="@B375S
M="!B92!R=6X@9G)O;2!T:&4@8V]M;6%N9"!L:6YE7&XB*3L*?0H*+R\@3&]A
M9"!T:&4@0TQ)(&5N=FER;VYM96YT("T@;6%K92!S=7)E('1H97)E)W,@;F\@
M=&EM92!L:6UI="P@:6YI=`HO+R!S;VUE('9A<FEA8FQE<RP@971C+@I(;W)D
M95]#3$DZ.FEN:70H*3L*)&-L:2`]("9N97<@2&]R9&5?0TQ)*"D["@IR97%U
M:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*"B\J($UA
M:V4@<W5R92!T:&5R92=S(&YO(&-O;7!R97-S:6]N+B`J+PI`;V)?96YD7V-L
M96%N*"D["@HD='EP92`]("%E;7!T>2@D8V]N9ELG<V5S<VEO;FAA;F1L97(G
M75LG='EP92==*2`_"B`@("`D8V]N9ELG<V5S<VEO;FAA;F1L97(G75LG='EP
M92==(#H@)V)U:6QT:6XG.PH*:68@*"1T>7!E(#T]("=E>'1E<FYA;"<I('L*
M("`@($AO<F1E.CIF871A;"A014%2.CIR86ES945R<F]R*"=397-S:6]N(&-O
M=6YT:6YG(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(%PG97AT97)N86Q<)R!3
M97-S:6]N2&%N9&QE<B!A="!T:&ES('1I;64N)RDL(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@9F%L<V4I.PI](&5L<V4@>PH@("`@<F5Q=6ER95]O;F-E("=(;W)D
M92]397-S:6]N2&%N9&QE<BYP:'`G.PH@("`@)%]S97-S:6]N7VAA;F1L97(@
M/2`F4V5S<VEO;DAA;F1L97(Z.G-I;F=L971O;B@D8V]N9ELG<V5S<VEO;FAA
M;F1L97(G75LG='EP92==*3L*("`@(&EF("AI<U]A*"1?<V5S<VEO;E]H86YD
M;&5R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@2&]R9&4Z.F9A=&%L*%!%
M05(Z.G)A:7-E17)R;W(H<W!R:6YT9B@B2&]R9&4@:7,@=6YA8FQE('1O(&QO
M860@<V5S<VEO;B!H86YD;&5R(&]F('1Y<&4@7"(E<UPB+B(L("1T>7!E*2DL
M(%]?1DE,15]?+"!?7TQ)3D5?7RP@9F%L<V4I.PH@("`@?0H*("`@(&EF("@D
M87)G8R`\(#(@?'P@*"1A<F=V6S%=("$]("<M;"<@)B8@)&%R9W9;,5T@(3T@
M)RUL;"<I*2!["B`@("`@("`@)&-O=6YT(#T@)%]S97-S:6]N7VAA;F1L97(M
M/F-O=6YT075T:&5N=&EC871E9%5S97)S*"D["B`@("`@("`@:68@*&ES7V$H
M)&-O=6YT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIF
M871A;"@D8V]U;G0L(%]?1DE,15]?+"!?7TQ)3D5?7RP@9F%L<V4I.PH@("`@
M("`@('T*"B`@("`@("`@)&-L:2T^=W)I=&5L;B@D8V]U;G0I.PH@("`@?2!E
M;'-E('L*("`@("`@("`D=7-E<G,@/2`D7W-E<W-I;VY?:&%N9&QE<BT^;&ES
M=$%U=&AE;G1I8V%T9615<V5R<R@D87)G=ELQ72`]/2`G+6QL)RD["B`@("`@
M("`@:68@*&ES7V$H)'5S97)S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@($AO<F1E.CIF871A;"@D=7-E<G,L(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M9F%L<V4I.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)'5S97)S(&%S
M("1U<V5R*2!["B`@("`@("`@("`@("1C;&DM/G=R:71E;&XH)'5S97(I.PH@
M("`@("`@('T*("`@('T*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M8W)I<'1S+V-R96%T92US>6UL:6YK<RYP:'``````````````````````````
M`````````````````````````````````````#`P,#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#$W,S8R`#$P-3$U-#,S-S4U`#`R,S(P-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````C(2]U<W(O;&]C
M86PO<'-A+V%D;6EN+V)I;B]P:'`*/#]P:'`*+RHJ"B`J(%1H:7,@<V-R:7!T
M(&-R96%T97,@<V]F=&QI;FMS('1O('1H92!L:6)R87)Y(&9I;&5S('EO=2!R
M971R:65V960@9G)O;0H@*B!T:&4@0U93(")F<F%M97=O<FLB(&UO9'5L92X*
M("H*("H@270@8W)E871E<R!T:&4@<V%M92!D:7)E8W1O<GD@<W1R=6-T=7)E
M('1H92!P86-K86=E<R!W;W5L9"!H879E(&EF('1H97D*("H@=V5R92!I;G-T
M86QL960@=VET:"`B<&5A<B!I;G-T86QL('!A8VMA9V4N>&UL(BX*("H@1F]R
M(&-R96%T:6YG('1H:7,@<W1R=6-T=7)E(&ET('5S97,@=&AE(&EN9F]R;6%T
M:6]N(&=I=F5N(&EN('1H90H@*B!P86-K86=E+GAM;"!F:6QE<R!I;G-I9&4@
M96%C:"!P86-K86=E(&1I<F5C=&]R>2X*("H*("H@)$AO<F1E.B!H;W)D92]S
M8W)I<'1S+V-R96%T92US>6UL:6YK<RYP:'`L=B`Q+C$T+C$P+C<@,C`P-B\P
M,2\P,2`R,3HR.3HP.2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(@
M5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("H@0V]P
M>7)I9VAT(#(P,#,M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B!7;VQF<F%M($MR:65S:6YG
M(#QW;VQF<F%M0&MR:65S:6YG+F1E/@H@*B!`875T:&]R($IA;B!38VAN96ED
M97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92!(;W)D92`S+C`*("HO"@HO
M+R!&:6YD('1H92!B87-E(&9I;&4@<&%T:"!O9B!(;W)D92X*0&1E9FEN92@G
M2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I.PH*+R\@
M0V]N9FEG=7)A=&EO;BX*+R\@16YT97(@9&ER96-T;W)I97,@=VET:&]U="!T
M<F%I;&EN9R!S;&%S:&5S+@H*+R\@5&AE(&1I<F5C=&]R>2!W:71H('1H92!#
M5E,@8VAE8VMO=70N"B1S<F-$:7(@/2!(3U)$15]"05-%("X@)R]F<F%M97=O
M<FLG.PH*+R\@5&AE(&1I<F5C=&]R>2!W:&5R92!T:&4@<V]F=&QI;FMS(&%R
M92!C<F5A=&5D+@HO+R!4:&ES(&ES(&%L<V\@=&AE(&1I<F5C=&]R>2!W:&EC
M:"!Y;W4@<VAO=6QD('!U="!I;B!Y;W5R(&EN8VQU9&4@<&%T:`HO+R!A9G1E
M<B!C<F5A=&EN9R!T:&4@;&EN:W,N"B1D97-T1&ER(#T@2$]21$5?0D%312`N
M("<O;&EB<R<["@HD8V]P>2`](&9A;'-E.PH*:68@*&ES<V5T*"1A<F=V*2D@
M>PH@("`@+RH@1V5T(')I9"!O9B!T:&4@9FER<W0@87)G('=H:6-H(&ES('1H
M92!S8W)I<'0@;F%M92X@*B\*("`@(&%R<F%Y7W-H:69T*"1A<F=V*3L*("`@
M('=H:6QE("@D87)G(#T@87)R87E?<VAI9G0H)&%R9W8I*2!["B`@("`@("`@
M:68@*"1A<F<@/3T@)RTM:&5L<"<I('L*("`@("`@("`@("`@<')I;G1?=7-A
M9V4H*3L*("`@("`@("!](&5L<V5I9B`H)&%R9R`]/2`G+2UC;W!Y)RD@>PH@
M("`@("`@("`@("`D8V]P>2`]('1R=64["B`@("`@("`@?2!E;'-E:68@*'-T
M<G-T<B@D87)G+"`G+2US<F,G*2D@>PH@("`@("`@("`@("!L:7-T*"PD<W)C
M1&ER*2`](&5X<&QO9&4H)STG+"`D87)G*3L*("`@("`@("!](&5L<V5I9B`H
M<W1R<W1R*"1A<F<L("<M+61E<W0G*2D@>PH@("`@("`@("`@("!L:7-T*"PD
M9&5S=$1I<BD@/2!E>'!L;V1E*"<])RP@)&%R9RD["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<')I;G1?=7-A9V4H(E5N<F5C;V=N:7-E9"!O<'1I
M;VX@)&%R9R(I.PH@("`@("`@('T*("`@('T*?0H*+R\@1&\@0TQ)(&-H96-K
M<R!A;F0@96YV:7)O;FUE;G0@<V5T=7`@9FER<W0N"G)E<75I<F5?;VYC92`D
M<W)C1&ER("X@)R]#3$DO0TQ)+G!H<"<["@HO+R!-86ME('-U<F4@;F\@;VYE
M(')U;G,@=&AI<R!F<F]M('1H92!W96(N"FEF("@A2&]R9&5?0TQ).CIR=6YN
M:6YG1G)O;4-,22@I*2!["B`@("!E>&ET*")-=7-T(&)E(')U;B!F<F]M('1H
M92!C;VUM86YD(&QI;F5<;B(I.PI]"@HO+R!,;V%D('1H92!#3$D@96YV:7)O
M;FUE;G0@+2!M86ME('-U<F4@=&AE<F4G<R!N;R!T:6UE(&QI;6ET+"!I;FET
M"B\O('-O;64@=F%R:6%B;&5S+"!E=&,N"DAO<F1E7T-,23HZ:6YI="@I.PH*
M0&EN8VQU9&5?;VYC92`G5')E92]4<F5E+G!H<"<["FEF("@A8VQA<W-?97AI
M<W1S*"=4<F5E)RDI('L*("`@(&5X:70H(EEO=2!N965D('1H92!014%2("=4
M<F5E)R!P86-K86=E(&EN<W1A;&QE9%QN(BD["GT*"B1L:6YK97(@/2`F;F5W
M($QI;FME<B@D8V]P>2D["FEF("@D:&%N9&QE(#T@;W!E;F1I<B@D<W)C1&ER
M*2D@>PH@("`@=VAI;&4@*"1F:6QE(#T@<F5A9&1I<B@D:&%N9&QE*2D@>PH@
M("`@("`@(&EF("@D9FEL92`A/2`G+B<@)B8*("`@("`@("`@("`@)&9I;&4@
M(3T@)RXN)R`F)@H@("`@("`@("`@("`D9FEL92`A/2`G0U93)R`F)@H@("`@
M("`@("`@("!I<U]D:7(H(B1S<F-$:7(O)&9I;&4B*2D@>PH@("`@("`@("`@
M("`D;&EN:V5R+3YP<F]C97-S*"(D<W)C1&ER+R1F:6QE(BP@)&1E<W1$:7(I
M.PH@("`@("`@('T*("`@('T*("`@(&-L;W-E9&ER*"1H86YD;&4I.PH@?0H*
M96-H;R`B7&XB.PH*+R\@('!O<W-I8FQE('AM;"US=')U8W1S"B\O("`\9FEL
M96QI<W0^"B\O("`@("`@/&1I<B!N86UE/2(O(B!B87-E:6YS=&%L;&1I<CTB
M6$U,(CX*+R\@("`@("`@("`@/&9I;&4@<F]L93TB<&AP(CY087)S97(N<&AP
M/"]F:6QE/@HO+R`@("`@("`@("`\9FEL92!R;VQE/2)P:'`B(&YA;64](E)3
M4RYP:'`B("\^"B\O("`@("`@/"]D:7(^"B\O("`\+V9I;&5L:7-T/@HO+PHO
M+R`@/&9I;&5L:7-T/@HO+R`@("`@(#QF:6QE(')O;&4](G!H<"(@8F%S96EN
M<W1A;&QD:7(](B\B/D1"+G!H<#PO9FEL93X*+R\@("`@("`\9&ER(&YA;64]
M(D1"(CX*+R\@("`@("`@("`@/&9I;&4@<F]L93TB<&AP(CYC;VUM;VXN<&AP
M/"]F:6QE/@HO+R`@("`@(#PO9&ER/@HO+R`@/"]F:6QE;&ES=#X*8VQA<W,@
M3&EN:V5R('L*"B`@("!V87(@)%]S<F-$:7(["@H@("`@=F%R("1?8F%S94EN
M<W1A;&Q$:7(["@H@("`@=F%R("1?9FEL97)O;&5S(#T@87)R87DH)W!H<"<I
M.PH*("`@('9A<B`D7W)O;&4["@H@("`@=F%R("1?8V]P>3L*"B`@("!F=6YC
M=&EO;B!,:6YK97(H)&-O<'D@/2!F86QS92D*("`@('L*("`@("`@("`D=&AI
M<RT^7V-O<'D@/2`D8V]P>3L*("`@('T*"B`@("!F=6YC=&EO;B!P<F]C97-S
M*"1S<F-$:7(L("1D97-T1&ER*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<W)C
M1&ER(#T@)'-R8T1I<CL*("`@("`@("`D<&%C:V%G949I;&4@/2`D=&AI<RT^
M7W-R8T1I<B`N("<O<&%C:V%G92YX;6PG.PH@("`@("`@("1C;&D@/2`F2&]R
M9&5?0TQ).CIS:6YG;&5T;VXH*3L*"B`@("`@("`@:68@*"%I<U]F:6QE*"1P
M86-K86=E1FEL92DI('L*("`@("`@("`@("`@)&-L:2T^;65S<V%G92@G3F\@
M<&%C:V%G92YX;6P@:6X@)R`N("1T:&ES+3Y?<W)C1&ER+"`G8VQI+G=A<FYI
M;F<G*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@)'1R964@/2!4<F5E.CIS971U<$UE;6]R>2@G6$U,)RP@)'!A8VMA
M9V5&:6QE*3L*("`@("`@("`D=')E92T^<V5T=7`H*3L*"B`@("`@("`@+R\@
M<F5A9"!P86-K86=E(&YA;64*("`@("`@("`D<&%C:V%G94YA;64@/2!T<FEM
M*"1T<F5E+3YG971%;&5M96YT0V]N=&5N="@G+W!A8VMA9V4O;F%M92<L("=C
M9&%T82<I*3L*("`@("`@("`D8VQI+3YW<FET96QN*")0<F]C97-S:6YG('!A
M8VMA9V4@)'!A8VMA9V5.86UE+B(I.PH*("`@("`@("`O+R!L;V]K(&9O<B!F
M:6QE;&ES="!I;B`G+W!A8VMA9V4O<F5L96%S92]F:6QE;&ES="<*("`@("`@
M("`D9FEL96QI<W0@/2`D=')E92T^9V5T16QE;65N=$)Y4&%T:"@G+W!A8VMA
M9V4O<F5L96%S92]F:6QE;&ES="<I.PH*("`@("`@("!I9B`H)&9I;&5L:7-T
M*2!["B`@("`@("`@("`@("\O(&1O('1H:7,@8F5T=&5R+"!M86ME('1H92!T
M<F5E(&-L87-S('=O<FL@8V%S92!I;G-E;G-I=&EV90H@("`@("`@("`@("`D
M8F%S94EN<W1A;&Q$:7(@/2`D9FEL96QI<W1;)V-H:6QD)UU;)V%T=')I8G5T
M97,G75LG8F%S96EN<W1A;&QD:7(G73L*"B`@("`@("`@("`@("1T:&ES+3Y?
M8F%S94EN<W1A;&Q$:7(@/2`D9&5S=$1I<CL*("`@("`@("`@("`@:68@*"1B
M87-E26YS=&%L;$1I<B`A/2`G+R<I('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?8F%S94EN<W1A;&Q$:7(@+CT@)R\G("X@)&)A<V5);G-T86QL1&ER.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?8F%S94EN<W1A;&Q$
M:7(@/2!P<F5G7W)E<&QA8V4H)WPO*WPG+"`G+R<L("1T:&ES+3Y?8F%S94EN
M<W1A;&Q$:7(I.PH*("`@("`@("`@("`@:68@*"%I<U]D:7(H)'1H:7,M/E]B
M87-E26YS=&%L;$1I<BDI('L*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC
M92`G4WES=&5M+G!H<"<["B`@("`@("`@("`@("`@("!3>7-T96TZ.FUK9&ER
M*"<M<"`G("X@)'1H:7,M/E]B87-E26YS=&%L;$1I<BD["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1T:&ES+3Y?:&%N9&QE1FEL96QI<W1486<H)&9I
M;&5L:7-T*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8VQI+3YM
M97-S86=E*"=.;R!F:6QE;&ES="!T86<@9F]U;F0@:6YS:61E.B`G("X@)'!A
M8VMA9V5&:6QE+"`G8VQI+G=A<FYI;F<G*3L*("`@("`@("!]"B`@("!]"@H@
M("`@9G5N8W1I;VX@7VAA;F1L949I;&5L:7-T5&%G*"1E;&5M96YT+"`D8W5R
M1&ER(#T@)R<I"B`@("!["B`@("`@("`@9F]R96%C:"`H)&5L96UE;G1;)V-H
M:6QD<F5N)UT@87,@)&-H:6QD*2!["B`@("`@("`@("`@('-W:71C:"`H)&-H
M:6QD6R=N86UE)UTI('L*("`@("`@("`@("`@8V%S92`G9FEL92<Z"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7VAA;F1L949I;&5486<H)&-H:6QD+"`D8W5R
M1&ER*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E
M("=D:7(G.@H@("`@("`@("`@("`@("`@)'1H:7,M/E]H86YD;&5$:7)486<H
M)&-H:6QD+"`D8W5R1&ER*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@)&-L:2`]("9(;W)D
M95]#3$DZ.G-I;F=L971O;B@I.PH@("`@("`@("`@("`@("`@)&-L:2T^;65S
M<V%G92@G1V]T(&YO(&AA;F1L97(@9F]R('1A9SH@)R`N("1C:&EL9%LG;F%M
M92==+"`G8VQI+7=A<FYI;F<G*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@('T*"B`@("!F=6YC=&EO;B!?
M:&%N9&QE1&ER5&%G*"1E;&5M96YT+"`D8W5R1&ER*0H@("`@>PH@("`@("`@
M(&EF("@D96QE;65N=%LG871T<FEB=71E<R==6R=N86UE)UT@(3T@)R\G*2![
M"B`@("`@("`@("`@(&EF("AS=6)S='(H)&-U<D1I<BP@+3$I("$]("<O)RD@
M>PH@("`@("`@("`@("`@("`@)&-U<D1I<B`]("1C=7)$:7(@+B`G+R<["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&-U<D1I<B`]("1C=7)$:7(@+B`D
M96QE;65N=%LG871T<FEB=71E<R==6R=N86UE)UT["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(65M<'1Y*"1E;&5M96YT6R=A='1R:6)U=&5S)UU;)W)O;&4G
M72DI('L*("`@("`@("`@("`@)'1H:7,M/E]R;VQE(#T@)&5L96UE;G1;)V%T
M=')I8G5T97,G75LG<F]L92==.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I
M<U]D:7(H)'1H:7,M/E]B87-E26YS=&%L;$1I<B`N("1C=7)$:7(I*2!["B`@
M("`@("`@("`@(')E<75I<F5?;VYC92`G4WES=&5M+G!H<"<["B`@("`@("`@
M("`@(%-Y<W1E;3HZ;6MD:7(H)RUP("<@+B`D=&AI<RT^7V)A<V5);G-T86QL
M1&ER("X@)&-U<D1I<BD["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7VAA
M;F1L949I;&5L:7-T5&%G*"1E;&5M96YT+"`D8W5R1&ER*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!?:&%N9&QE1FEL951A9R@D96QE;65N="P@)&1I<BD*("`@
M('L*("`@("`@("!I9B`H(65M<'1Y*"1E;&5M96YT6R=A='1R:6)U=&5S)UU;
M)W)O;&4G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]R;VQE(#T@)&5L96UE
M;G1;)V%T=')I8G5T97,G75LG<F]L92==.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"%I;E]A<G)A>2@D=&AI<RT^7W)O;&4L("1T:&ES+3Y?9FEL97)O;&5S
M*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(65M<'1Y*"1E;&5M96YT6R=A='1R:6)U=&5S)UU;)VYA;64G72DI('L*
M("`@("`@("`@("`@)&9I;&5N86UE(#T@)&5L96UE;G1;)V%T=')I8G5T97,G
M75LG;F%M92==.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F:6QE
M;F%M92`]("1E;&5M96YT6R=C9&%T82==.PH@("`@("`@('T*("`@("`@("`D
M9FEL96YA;64@/2!T<FEM*"1F:6QE;F%M92D["@H@("`@("`@(&EF("@D=&AI
M<RT^7V-O<'DI('L*("`@("`@("`@("`@)&-M9"`](")C<"![)'1H:7,M/E]S
M<F-$:7)])&1I<B\D9FEL96YA;64@>R1T:&ES+3Y?8F%S94EN<W1A;&Q$:7)]
M)&1I<B\D9FEL96YA;64B.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1P87)E;G0@/2`D=&AI<RT^7V9I;F1#;VUM;VY087)E;G0H)'1H:7,M/E]S
M<F-$:7(@+B`D9&ER+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?8F%S94EN<W1A;&Q$:7(@+B`D9&ER
M*3L*("`@("`@("`@("`@)&1I<G,@/2!S=6)S=')?8V]U;G0H<W5B<W1R*"1T
M:&ES+3Y?8F%S94EN<W1A;&Q$:7(@+B`D9&ER+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@<W1R;&5N*"1P87)E;G0I*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R\G*3L*("`@("`@("`@
M("`@)'-R8R`]('-T<E]R97!E870H)RXN+R<L("1D:7)S*2`N"B`@("`@("`@
M("`@("`@("!S=6)S='(H)'1H:7,M/E]S<F-$:7(@+B`D9&ER+"!S=')L96XH
M)'!A<F5N="D@*R`Q*3L*("`@("`@("`@("`@)&-M9"`](")L;B`M<V8@)'-R
M8R\D9FEL96YA;64@>R1T:&ES+3Y?8F%S94EN<W1A;&Q$:7)])&1I<B\D9FEL
M96YA;64B.PH@("`@("`@('T*("`@("`@("!E>&5C*"1C;60I.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]F:6YD0V]M;6]N4&%R96YT*"1A+"`D8BD*("`@('L*
M("`@("`@("!F;W(@*"1C;VUM;VX@/2`G)RP@)&QA<W1P;W,@/2`P+"`D<&]S
M(#T@<W1R<&]S*"1A+"`G+R<L(#$I.PH@("`@("`@("`@("`@)'!O<R`A/3T@
M9F%L<V4@)B8@<W1R<&]S*"1B+"!S=6)S='(H)&$L(#`L("1P;W,I*2`]/3T@
M,#L*("`@("`@("`@("`@("1P;W,@/2!S=')P;W,H)&$L("<O)RP@)'!O<R`K
M(#$I*2!["B`@("`@("`@("`@("1C;VUM;VX@+CT@<W5B<W1R*"1A+"`D;&%S
M='!O<RP@)'!O<R`M("1L87-T<&]S*3L*("`@("`@("`@("`@)&QA<W1P;W,@
M/2`D<&]S.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&-O;6UO;CL*("`@
M('T*"GT*"F9U;F-T:6]N('!R:6YT7W5S86=E*"1M97-S86=E(#T@)R<I('L*
M"B`@("!I9B`H(65M<'1Y*"1M97-S86=E*2D@>PH@("`@("`@('!R:6YT(")C
M<F5A=&4M<WEM;&EN:W,N<&AP.B`D;65S<V%G95QN7&XB.PH@("`@?0H*("`@
M('!R:6YT(#P\/%5304=%"E5S86=E.B!C<F5A=&4M<WEM;&EN:W,N<&AP(%M/
M4%1)3TY="@I0;W-S:6)L92!O<'1I;VYS.@H@("TM8V]P>2`@("`@("`@1&\@
M;F]T(&-R96%T92!S>6UB;VQI8R!L:6YK<RP@8G5T(&%C='5A;&QY(&-O<'D@
M=&AE(&QI8G)A<FEE<RX*("`M+7-R8SU$25(@("`@(%1H92!S;W5R8V4@9&ER
M96-T;W)Y(&9O<B!T:&4@9G)A;65W;W)K(&QI8G)A<FEE<RX*("`M+61E<W0]
M1$E2("`@(%1H92!D97-T:6YA=&EO;B!D:7)E8W1O<GD@9F]R('1H92!F<F%M
M97=O<FL@;&EB<F%R:65S+@H*55-!1T4["B`@("!E>&ET.PI]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]C<F]N9```````````````````
M````````````````````````````````````````````````````````````
M```P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,38Q,0`Q,#4Q-30S
M,S<U-0`P,C`T,#$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(R$O=7-R+VQO8V%L+W!S82]A9&UI;B]B:6XO<&AP"CP_<&AP
M"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O8W)O;F0L=B`Q+C0N,3`N
M-2`R,#`V+S`V+S$V(#`X.C(T.C(Y(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,RTR,#`V($-H87)L97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D
M92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@IR97%U:7)E7V]N8V4@)TAO<F1E
M+T-,22YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+U-C:&5D=6QE<BYP:'`G
M.PH*+R\@36%K92!S=7)E(&YO(&]N92!R=6YS('1H:7,@9G)O;2!T:&4@=V5B
M+@II9B`H(4AO<F1E7T-,23HZ<G5N;FEN9T9R;VU#3$DH*2D@>PH@("`@97AI
M="@B375S="!B92!R=6X@9G)O;2!T:&4@8V]M;6%N9"!L:6YE7&XB*3L*?0H*
M+R\@3&]A9"!T:&4@0TQ)(&5N=FER;VYM96YT("T@;6%K92!S=7)E('1H97)E
M)W,@;F\@=&EM92!L:6UI="P@:6YI=`HO+R!S;VUE('9A<FEA8FQE<RP@971C
M+@I(;W)D95]#3$DZ.FEN:70H*3L*"B\O($=E="!A;B!I;G-T86YC92!O9B!T
M:&4@8W)O;B!S8VAE9'5L97(N"B1D865M;VX@/2`F2&]R9&5?4V-H961U;&5R
M.CIS:6YG;&5T;VXH)V-R;VXG*3L*"B\O($YO=R!A9&0@<V]M92!C<F]N(&IO
M8G,@=&\@9&\L(&]R(&%D9"!P87)S:6YG('1O(')E860@82!C;VYF:6<@9FEL
M92X*+R\@)&1A96UO;BT^861D5&%S:R@G;',G+"`G,"PU+#$P+#$U+#(P+#,P
M+#0P("H@*B`J("HG*3L*"B\O(%-T87)T('1H92!D865M;VX@9V]I;F<N"B1D
M865M;VXM/G)U;B@I.PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]G971?;&]G:6XN<&AP
M````````````````````````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3,W-0`Q
M,#4Q-30S,S<U-@`P,C(P,S8`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O<V-R
M:7!T<R]G971?;&]G:6XN<&AP+'8@,2XS+C$P+C,@,C`P-B\P,2\P,2`R,3HR
M.3HP.2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!*;V5L
M(%9A;F1A;"`\:G9A;F1A;$!I;F9O=&5C:RYQ8RYC83X*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J+PH*0&1E9FEN92@G05542%](04Y$3$52)RP@=')U92D["D!D969I;F4H
M)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXG*3L*<F5Q
M=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["@HD875T
M:"`]("9!=71H.CIS:6YG;&5T;VXH)&-O;F9;)V%U=&@G75LG9')I=F5R)UTI
M.PH*+R\@0VAE8VL@9F]R($=%5"!A=71H+@II9B`H96UP='DH)%]'151;)W5S
M97(G72D@?'P@(21A=71H+3YA=71H96YT:6-A=&4H)%]'151;)W5S97(G72P@
M87)R87DH)W!A<W-W;W)D)R`]/B`D7T=%5%LG<&%S<R==*2DI('L*("`@(&AE
M861E<B@G3&]C871I;VXZ("<@+B!(;W)D93HZ87!P;&EC871I;VY5<FPH)VQO
M9VEN+G!H<#]L;V=O=71?<F5A<V]N/6QO9V]U="<I*3L*("`@(&5X:70["GT*
M"FAE861E<B@G3&]C871I;VXZ("<@+B!(;W)D93HZ87!P;&EC871I;VY5<FPH
M)VEN9&5X+G!H<"<I*3L*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]H='1P7VQO
M9VEN7W)E9F5R+G!H<```````````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,3<Q-``Q,#4Q-30S,S<U-0`P,C,T,34`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R
M9&4O<V-R:7!T<R]H='1P7VQO9VEN7W)E9F5R+G!H<"QV(#$N,RXQ,BXS(#(P
M,#8O,#$O,#$@,C$Z,CDZ,#D@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q
M.3DY+3(P,#8@0VAA<FQE<R!*+B!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R
M9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@IR97%U:7)E7V]N8V4@)RXN+VQI
M8B]B87-E+G!H<"<["@HD875T:"`]("9!=71H.CIS:6YG;&5T;VXH)&-O;F9;
M)V%U=&@G75LG9')I=F5R)UTI.PH*+R\@0VAE8VL@9F]R($A45%`@875T:"X*
M:68@*&5M<'1Y*"1?4T525D526R=02%!?05542%]54T52)UTI('Q\"B`@("!E
M;7!T>2@D7U-%4E9%4ELG4$A07T%55$A?4%<G72D@?'P*("`@("$D875T:"T^
M875T:&5N=&EC871E*"1?4T525D526R=02%!?05542%]54T52)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<&%S<W=O<F0G(#T^("1?4T52
M5D526R=02%!?05542%]05R==*2DI('L*"B`@("!H96%D97(H)U=75RU!=71H
M96YT:6-A=&4Z($)A<VEC(')E86QM/2(G("X@)&%U=&@M/F=E=%!A<F%M*"=R
M96%L;2<I("X@)R(G*3L*("`@(&AE861E<B@G2%144"\Q+C`@-#`Q(%5N875T
M:&]R:7IE9"<I.PH@("`@97AI="@G1F]R8FED9&5N)RD["GT*"FEF("@D=7)L
M(#T@571I;#HZ9V5T1F]R;41A=&$H)W5R;"<I*2!["B`@("!H96%D97(H)TQO
M8V%T:6]N.B`G("X@)'5R;"D["GT@96QS92!["B`@("!H96%D97(H)TQO8V%T
M:6]N.B`G("X@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=L;V=I;BYP:'`G*2D[
M"GT*````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]L
M9&%P+P``````````````````````````````````````````````````````
M```````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#4Q-30S,S<U-0`P,C`R-C<`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]S8W)I<'1S+VQD87`O:&]R9&4N<V-H96UA````````````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,T-3`V`#$P-3$U-#,S-S4U`#`R,C4V
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````C
M("1(;W)D93H@:&]R9&4O<V-R:7!T<R]L9&%P+VAO<F1E+G-C:&5M82QV(#$N
M,C`N,3`N-2`R,#`U+S$P+S$X(#$Q.C,T.C`P(&IA;B!%>'`@)`HC"B,@5&AE
M(&]F9FEC86P@:&]R9&4@3TE$(&%S<VEG;F5D(&)Y($E!3D$@:7,@,3,P-#`N
M"B,*(R!4:&ES('-C:&5M82!D97!E;F1S(&]N.@HC"2T@8V]R92YS8VAE;6$*
M(PHC(`HC($AO<F1E(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P
M-#`N,BXQ+BH*(R!)35`@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ
M,S`T,"XS+C$N*@HC(%1U<F)A(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N-"XQ+BH*(R!+<F]N;VQI=&@@871T<FEB=71E(&)R86YC:"`Q
M+C,N-BXQ+C0N,2XQ,S`T,"XU+C$N*@HC($YA9R!A='1R:6)U=&4@8G)A;F-H
M(#$N,RXV+C$N-"XQ+C$S,#0P+C8N,2XJ"B,@1V]L;&5M(&%T=')I8G5T92!B
M<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N-RXQ+BH*(R!#:&]R82!A='1R:6)U
M=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C@N,2XJ"B,@36YE;6\@871T
M<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XY+C$N*@HC(%1R;VQL
M(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3`N,2XJ"B,@
M2VQU='H@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ,2XQ
M+BH*(R!*;VYA:"!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C$R+C$N*@HC($AE<FUE<R!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C$S+C$N*@HC($IU;F\@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ
M+C0N,2XQ,S`T,"XQ-"XQ+BH*(R!4<F5A;B!A='1R:6)U=&4@8G)A;F-H(#$N
M,RXV+C$N-"XQ+C$S,#0P+C$U+C$N*@HC(%=H=7!S(&%T=')I8G5T92!B<F%N
M8V@@,2XS+C8N,2XT+C$N,3,P-#`N,38N,2XJ"B,@26YG;R!A='1R:6)U=&4@
M8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$W+C$N*@HC($%N<V5L(&%T=')I
M8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3@N,2XJ"B,@1V5N:64@
M871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ.2XQ+BH*(R!3
M8W)Y(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C`N,2XJ
M"B,@5VEC:V5D(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N
M,C$N,2XJ"B,@06=O<F$@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ
M,S`T,"XR,BXQ+BH*(R!';V]P<R!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N
M-"XQ+C$S,#0P+C(T+C$N*@HC($UE<FL@871T<FEB=71E(&)R86YC:"`Q+C,N
M-BXQ+C0N,2XQ,S`T,"XR-2XQ+BH*(R!-:6UP(&%T=')I8G5T92!B<F%N8V@@
M,2XS+C8N,2XT+C$N,3,P-#`N,C8N,2XJ"B,@36]T=&QE(&%T=')I8G5T92!B
M<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C<N,2XJ"B,@3FEC(&%T=')I8G5T
M92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C@N,2XJ"B,@3V-C86T@871T
M<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR.2XQ+BH*(R!/9&EN
M(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,S`N,2XJ"B,@
M4F%K:6T@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS,2XQ
M+BH*(R!397-H82!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C,R+C$N*@HC(%-W;V]S:"!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C,S+C$N*@HC(%1H;W(@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ
M+C0N,2XQ,S`T,"XS-"XQ+BH*(R!5;&%F;W)M(&%T=')I8G5T92!B<F%N8V@@
M,2XS+C8N,2XT+C$N,3,P-#`N,S4N,2XJ"B,@5F]L;W,@871T<FEB=71E(&)R
M86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS-BXQ+BH*(R`*(R!(;W)D92!O8FIE
M8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,BXR+BH*(R!)35`@
M;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,N,BXJ"B,@
M5'5R8F$@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C0N
M,BXJ"B,@2W)O;F]L:71H(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N
M,2XQ,S`T,"XU+C(N*@HC($Y!1R!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N
M,2XT+C$N,3,P-#`N-BXR+BH*(R!';VQL96T@;V)J96-T8VQA<W,@8G)A;F-H
M(#$N,RXV+C$N-"XQ+C$S,#0P+C<N,BXJ"B,@0VAO<F$@;V)J96-T8VQA<W,@
M8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C@N,BXJ"B,@36YE;6\@;V)J96-T
M8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+CDN,BXJ"B,@5')O;&P@
M;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$P+C(N*@HC
M($ML=71Z(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ
M,2XR+BH*(R!*;VYA:"!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N
M,3,P-#`N,3(N,BXJ"B,@2&5R;65S(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N
M-BXQ+C0N,2XQ,S`T,"XQ,RXR+BH*(R!*=6YO(&]B:F5C=&-L87-S(&)R86YC
M:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ-"XR+BH*(R!4<F5A;B!O8FIE8W1C;&%S
M<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,34N,BXJ"B,@5VAU<',@;V)J
M96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$V+C(N*@HC($EN
M9V\@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$W+C(N
M*@HC($%N<V5L(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T
M,"XQ."XR+BH*(R!'96YI92!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N,3DN,BXJ"B,@4V-R>2!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS
M+C8N,2XT+C$N,3,P-#`N,C`N,BXJ"B,@5VEC:V5D(&]B:F5C=&-L87-S(&)R
M86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR,2XR+BH*(R!!9V]R82!O8FIE8W1C
M;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C(N,BXJ"B,@1V]O<',@
M;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(T+C(N*@HC
M($UE<FL@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(U
M+C(N*@HC($UI;7`@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S
M,#0P+C(V+C(N*@HC($UO='1L92!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N
M,2XT+C$N,3,P-#`N,C<N,BXJ"B,@3FEC(&]B:F5C=&-L87-S(&)R86YC:"`Q
M+C,N-BXQ+C0N,2XQ,S`T,"XR."XR+BH*(R!/8V-A;2!O8FIE8W1C;&%S<R!B
M<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,CDN,BXJ"B,@3V1I;B!O8FIE8W1C
M;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,S`N,BXJ"B,@4F%K:6T@
M;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,Q+C(N*@HC
M(%-E<VAA(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS
M,BXR+BH*(R!3=V]O<V@@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C,S+C(N*@HC(%1H;W(@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV
M+C$N-"XQ+C$S,#0P+C,T+C(N*@HC(%5L869O<FT@;V)J96-T8VQA<W,@8G)A
M;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,U+C(N*@HC(%9O;&]S(&]B:F5C=&-L
M87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS-BXR+BH*"B,*(R!(;W)D
M92!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(N,2XJ"B,*
M871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C(N,2XQ"@E.04U%
M("=H;W)D95!R969S)PH)1$530R`G2&]R9&4@4')E9F5R96YC97,G"@E%455!
M3$E462!C87-E26=N;W)E24$U36%T8V@*"5-93E1!6"`Q+C,N-BXQ+C0N,2XQ
M-#8V+C$Q-2XQ,C$N,2XR-GLQ,#(T?2`I"@HC"B,@24U0(&%T=')I8G5T92!B
M<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,RXQ+BH*(PIA='1R:6)U=&5T>7!E
M("@@,2XS+C8N,2XT+C$N,3,P-#`N,RXQ+C$*"4Y!344@)VEM<%!R969S)PH)
M1$530R`G24U0(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!
M-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[
M,3`R-'T@*0H*(PHC(%1U<F)A(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N-"XQ+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N
M,3,P-#`N-"XQ+C$*"4Y!344@)W1U<F)A4')E9G,G"@E$15-#("=4=7)B82!0
M<F5F97)E;F-E<R<*"45154%,2519(&-A<V5)9VYO<F5)035-871C:`H)4UE.
M5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V>S$P,C1]("D*"F%T
M=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XT+C$N,@H)3D%-12`G
M='5R8F%4>7!E)PH)1$530R`G5'5R8F$@3V)J96-T(%1Y<&4Z($-O;G1A8W0O
M3&ES="<*"45154%,2519(&-A<V5)9VYO<F5)035-871C:`H)4U5"4U12(&-A
M<V5)9VYO<F5)0353=6)S=')I;F=S36%T8V@*"5-93E1!6"`Q+C,N-BXQ+C0N
M,2XQ-#8V+C$Q-2XQ,C$N,2XR-GLX?2`I"@IA='1R:6)U=&5T>7!E("@@,2XS
M+C8N,2XT+C$N,3,P-#`N-"XQ+C,*"4Y!344@)W1U<F)A365M8F5R<R<*"41%
M4T,@)T5N8V]D960@;65M8F5R<R!O9B!A(%1U<F)A(&QI<W0G"@E355`@;F%M
M92`I"@IA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N-"XQ+C0*
M"4Y!344@)W1U<F)A4$=04'5B;&EC2V5Y)PH)1$530R`G4$=0+T=01R!0=6)L
M:6,@2V5Y)PH@("`@("`@($5154%,2519(&-A<V5)9VYO<F5)035-871C:`H)
M4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V>S0P,#!]("D*
M"B,*(R!+<F]N;VQI=&@@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ
M,S`T,"XU+C$N*@HC"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T
M,"XU+C$N,0H)3D%-12`G:W)O;F]L:71H4')E9G,G"@E$15-#("=+<F]N;VQI
M=&@@4')E9F5R96YC97,G"@E%455!3$E462!C87-E26=N;W)E24$U36%T8V@*
M"5-93E1!6"`Q+C,N-BXQ+C0N,2XQ-#8V+C$Q-2XQ,C$N,2XR-GLQ,#(T?2`I
M"@HC"B,@3F%G(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N
M-BXQ+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N-BXQ
M+C$*"4Y!344@)VYA9U!R969S)PH)1$530R`G3F%G(%!R969E<F5N8V5S)PH)
M15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT
M+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($=O;&QE;2!A='1R
M:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C<N,2XJ"B,*871T<FEB
M=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C<N,2XQ"@E.04U%("=G;VQL
M96U0<F5F<R<*"41%4T,@)T=O;&QE;2!0<F5F97)E;F-E<R<*"45154%,2519
M(&-A<V5)9VYO<F5)035-871C:`H)4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N
M,3$U+C$R,2XQ+C(V>S$P,C1]("D*"B,*(R!#:&]R82!A='1R:6)U=&4@8G)A
M;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C@N,2XJ"B,*871T<FEB=71E='EP92`H
M(#$N,RXV+C$N-"XQ+C$S,#0P+C@N,2XQ"@E.04U%("=C:&]R85!R969S)PH)
M1$530R`G0VAO<F$@4')E9F5R96YC97,G"@E%455!3$E462!C87-E26=N;W)E
M24$U36%T8V@*"5-93E1!6"`Q+C,N-BXQ+C0N,2XQ-#8V+C$Q-2XQ,C$N,2XR
M-GLQ,#(T?2`I"@HC"B,@36YE;6\@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ
M+C0N,2XQ,S`T,"XY+C$N*@HC"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N
M,2XQ,S`T,"XY+C$N,0H)3D%-12`G;6YE;6]0<F5F<R<*"41%4T,@)TUN96UO
M(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E3
M64Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*
M(PHC(%1R;VQL(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N
M,3`N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C$P
M+C$N,0H)3D%-12`G=')O;&Q0<F5F<R<*"41%4T,@)U1R;VQL(%!R969E<F5N
M8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS
M+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($ML=71Z
M(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3$N,2XJ"B,*
M871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C$Q+C$N,0H)3D%-
M12`G:VQU='I0<F5F<R<*"41%4T,@)TML=71Z(%!R969E<F5N8V5S)PH)15%5
M04Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N
M,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($IO;F%H(&%T=')I8G5T
M92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3(N,2XJ"B,*871T<FEB=71E
M='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C$R+C$N,0H)3D%-12`G:F]N86A0
M<F5F<R<*"41%4T,@)TIO;F%H(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S
M94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N
M,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($AE<FUE<R!A='1R:6)U=&4@8G)A;F-H
M(#$N,RXV+C$N-"XQ+C$S,#0P+C$S+C$N*@HC"F%T=')I8G5T971Y<&4@*"`Q
M+C,N-BXQ+C0N,2XQ,S`T,"XQ,RXQ+C$*"4Y!344@)VAE<FUE<U!R969S)PH)
M1$530R`G2&5R;65S(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R
M94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N
M,C9[,3`R-'T@*0H*(PHC($IU;F\@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ
M+C0N,2XQ,S`T,"XQ-"XQ+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT
M+C$N,3,P-#`N,30N,2XQ"@E.04U%("=J=6YO4')E9G,G"@E$15-#("=*=6YO
M(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E3
M64Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*
M(PHC(%1R96%N(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N
M,34N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C$U
M+C$N,0H)3D%-12`G=')E86Y0<F5F<R<*"41%4T,@)U1R96%N(%!R969E<F5N
M8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS
M+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC(%=H=7!S
M(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,38N,2XJ"B,*
M871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C$V+C$N,0H)3D%-
M12`G=VAU<'-0<F5F<R<*"41%4T,@)U=H=7!S(%!R969E<F5N8V5S)PH)15%5
M04Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N
M,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($EN9V\@871T<FEB=71E
M(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ-RXQ+BH*(PIA='1R:6)U=&5T
M>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N,3<N,2XQ"B`@("`@("!.04U%("=I
M;F=O4')E9G,G"B`@("`@("!$15-#("=);F=O(%!R969E<F5N8V5S)PH@("`@
M("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"B`@("`@("!364Y405@@
M,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($%N
M<V5L(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3@N,2XJ
M"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C$X+C$N,0H@
M("`@("`@3D%-12`G86YS96Q0<F5F<R<*("`@("`@($1%4T,@)T%N<V5L(%!R
M969E<F5N8V5S)PH@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H
M"B`@("`@("!364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[
M,3`R-'T@*0H*(PHC($=E;FEE(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N,3DN,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C$Y+C$N,0H)3D%-12`G9V5N:650<F5F<R<*"41%4T,@)T=E;FEE
M(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E3
M64Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*
M(PHC(%-C<GD@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR
M,"XQ+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N,C`N
M,2XQ"@E.04U%("=S8W)Y4')E9G,G"@E$15-#("=38W)Y(%!R969E<F5N8V5S
M)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N
M,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC(%=I8VME9"!A
M='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(Q+C$N*@HC"F%T
M=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR,2XQ+C$*"4Y!344@
M)W=I8VME9%!R969S)PH)1$530R`G5VEC:V5D(%!R969E<F5N8V5S)PH)15%5
M04Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N
M,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($%G;W)A(&%T=')I8G5T
M92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C(N,2XJ"B,*871T<FEB=71E
M='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C(R+C$N,0H@("`@("`@($Y!344@
M)V%G;W)A4')E9G,G"B`@("`@("`@1$530R`G06=O<F$@4')E9F5R96YC97,G
M"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@
M,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($=O
M;W!S(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C0N,2XJ
M"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C(T+C$N,0H@
M("`@("`@($Y!344@)V=O;W!S4')E9G,G"B`@("`@("`@1$530R`G1V]O<',@
M4')E9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA
M=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R
M-'T@*0H*(PHC($UE<FL@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ
M,S`T,"XR-2XQ+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P
M-#`N,C4N,2XQ"B`@("`@("`@3D%-12`G;65R:U!R969S)PH@("`@("`@($1%
M4T,@)TUE<FL@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG
M;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q
M+C$N,C9[,3`R-'T@*0H*(PHC($UI;7`@871T<FEB=71E(&)R86YC:"`Q+C,N
M-BXQ+C0N,2XQ,S`T,"XR-BXQ+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N
M,2XT+C$N,3,P-#`N,C8N,2XQ"B`@("`@("`@3D%-12`G;6EM<%!R969S)PH@
M("`@("`@($1%4T,@)TU)35`@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)
M5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V
M-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($UO='1L92!A='1R:6)U=&4@
M8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(W+C$N*@HC"F%T=')I8G5T971Y
M<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR-RXQ+C$*("`@("`@("!.04U%("=M
M;W1T;&50<F5F<R<*("`@("`@("!$15-#("=-;W1T;&4@4')E9F5R96YC97,G
M"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@
M,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($YI
M8R!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(X+C$N*@HC
M"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR."XQ+C$*("`@
M("`@("!.04U%("=N:6-0<F5F<R<*("`@("`@("!$15-#("=.24,@4')E9F5R
M96YC97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E3
M64Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*
M(PHC($]C8V%M(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N
M,CDN,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C(Y
M+C$N,0H@("`@("`@($Y!344@)V]C8V%M4')E9G,G"B`@("`@("`@1$530R`G
M3V-C86T@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R
M94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N
M,C9[,3`R-'T@*0H*(PHC($]D:6X@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ
M+C0N,2XQ,S`T,"XS,"XQ+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT
M+C$N,3,P-#`N,S`N,2XQ"B`@("`@("`@3D%-12`G;V1I;E!R969S)PH@("`@
M("`@($1%4T,@)T]D:6X@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@
M8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ
M,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC(%)A:VEM(&%T=')I8G5T92!B<F%N
M8V@@,2XS+C8N,2XT+C$N,3,P-#`N,S$N,2XJ"B,*871T<FEB=71E='EP92`H
M(#$N,RXV+C$N-"XQ+C$S,#0P+C,Q+C$N,0H@("`@("`@($Y!344@)W)A:VEM
M4')E9G,G"B`@("`@("`@1$530R`G4F%K:6T@4')E9F5R96YC97,G"B`@("`@
M("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N
M,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC(%-E<VAA(&%T
M=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,S(N,2XJ"B,*871T
M<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C,R+C$N,0H@("`@("`@
M($Y!344@)W-E<VAA4')E9G,G"B`@("`@("`@1$530R`G4V5S:&$@4')E9F5R
M96YC97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E3
M64Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*
M(PHC(%-W;V]S:"!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C,S+C$N*@HC"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS
M,RXQ+C$*("`@("`@("!.04U%("=S=V]O<VA0<F5F<R<*("`@("`@("!$15-#
M("=3=V]O<V@@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG
M;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q
M+C$N,C9[,3`R-'T@*0H*(PHC(%1H;W(@871T<FEB=71E(&)R86YC:"`Q+C,N
M-BXQ+C0N,2XQ,S`T,"XS-"XQ+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N
M,2XT+C$N,3,P-#`N,S0N,2XQ"B`@("`@("`@3D%-12`G=&AO<E!R969S)PH@
M("`@("`@($1%4T,@)U1H;W(@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)
M5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V
M-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC(%5L869O<FT@871T<FEB=71E
M(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS-2XQ+BH*(PIA='1R:6)U=&5T
M>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N,S4N,2XQ"B`@("`@("`@3D%-12`G
M=6QA9F]R;5!R969S)PH@("`@("`@($1%4T,@)U5L869O<FT@4')E9F5R96YC
M97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y4
M05@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC
M(%9O;&]S(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,S8N
M,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C,V+C$N
M,0H@("`@("`@($Y!344@)W9O;&]S4')E9G,G"B`@("`@("`@1$530R`G5F]L
M;W,@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!
M-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[
M,3`R-'T@*0H*(PHC($AO<F1E(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ
M+C0N,2XQ,S`T,"XR+C(N*@HC"F]B:F5C=&-L87-S("@@,2XS+C8N,2XT+C$N
M,3,P-#`N,BXR+C$*("`@($Y!344@)VAO<F1E4&5R<V]N)PH@("`@1$530R`G
M2&]R9&4@4')E9F5R96YC97,G"B`@("!355`@=&]P"B`@("!!55A)3$E!4ED*
M("`@($U!62`H(&UA:6P@)"!H;W)D95!R969S("0@:6UP4')E9G,@)"!T=7)B
M85!R969S("0*("`@("`@("!G;VQL96U0<F5F<R`D(&MR;VYO;&ET:%!R969S
M("0@;6YE;6]0<F5F<R`D"B`@("`@("`@=')O;&Q0<F5F<R`D(&YA9U!R969S
M("0@:VQU='I0<F5F<R`D"B`@("`@("`@:F]N86A0<F5F<R`D(&AE<FUE<U!R
M969S("0@:G5N;U!R969S("0*("`@("`@("!T<F5A;E!R969S("0@=VAU<'-0
M<F5F<R`D(&EN9V]0<F5F<R`D"B`@("`@("`@9V5N:650<F5F<R`D('-C<GE0
M<F5F<R`D(&%N<V5L4')E9G,@)`H@("`@("`@('=I8VME9%!R969S("0@8VAO
M<F%0<F5F<R`D(&%G;W)A4')E9G,@)`H@("`@("`@(&=O;W!S4')E9G,@)"!M
M97)K4')E9G,@)"!V;VQO<U!R969S("0*("`@("`@("!M:6UP4')E9G,@)"!M
M;W1T;&50<F5F<R`D(&YI8U!R969S("0*("`@("`@("!O8V-A;5!R969S("0@
M;V1I;E!R969S("0@<F%K:6U0<F5F<R`D"B`@("`@("`@<V5S:&%0<F5F<R`D
M('-W;V]S:%!R969S("0@=&AO<E!R969S("0*("`@("`@("!U;&%F;W)M4')E
M9G,*("`@("D@*0H*;V)J96-T8VQA<W,@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR
M+C(N,@H@("`@3D%-12`G:&]R9&5'<F]U<"<*("`@($1%4T,@)TAO<F1E($=R
M;W5P)PH@("`@4U50('1O<`H@("`@055824Q)05)9"B`@("!-05D@*"!M86EL
M("D@*0H*(PHC($E-4"!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N
M,3,P-#`N,RXR+BH*(PH*(R!4=7)B82!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS
M+C8N,2XT+C$N,3,P-#`N-"XR+BH*;V)J96-T8VQA<W,@*"`Q+C,N-BXQ+C0N
M,2XQ,S`T,"XT+C(N,0H@($Y!344@)W1U<F)A0V]N=&%C="<*("!$15-#("=4
M=7)B82!#;VYT86-T)PH@(%-54"!T;W`*("!!55A)3$E!4ED*("!-05D@*"!T
M=7)B851Y<&4@)"!T=7)B84UE;6)E<G,@*0H@*0H*(PHC($MR;VYO;&ET:"!O
M8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N-2XR+BH*(PH*
M(PHC($YA9R!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N
M-BXR+BH*(PH*(PHC($=O;&QE;2!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N
M,2XT+C$N,3,P-#`N-RXR+BH*(PH*(PHC($-H;W)A(&]B:F5C=&-L87-S(&)R
M86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XX+C(N*@HC"@HC"B,@36YE;6\@;V)J
M96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+CDN,BXJ"B,*"B,*
M(R!4<F]L;"!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N
M,3`N,BXJ"B,*"B,*(R!+;'5T>B!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N
M,2XT+C$N,3,P-#`N,3$N,BXJ"B,*"B,*(R!*;VYA:"!O8FIE8W1C;&%S<R!B
M<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3(N,BXJ"B,*"B,*(R!(97)M97,@
M;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$S+C(N*@HC
M"@HC"B,@2G5N;R!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P
M-#`N,30N,BXJ"B,*"B,*(R!4<F5A;B!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS
M+C8N,2XT+C$N,3,P-#`N,34N,BXJ"B,*"B,*(R!7:'5P<R!O8FIE8W1C;&%S
M<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,38N,BXJ"B,*"B,*(R!);F=O
M(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ-RXR+BH*
M(PH*(PHC($%N<V5L(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ
M,S`T,"XQ."XR+BH*(PH*(PHC($=E;FEE(&]B:F5C=&-L87-S(&)R86YC:"`Q
M+C,N-BXQ+C0N,2XQ,S`T,"XQ.2XR+BH*(PH*(PHC(%-C<GD@;V)J96-T8VQA
M<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(P+C(N*@HC"@HC"B,@5VEC
M:V5D(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR,2XR
M+BH*(PH*(PHC($%G;W)A(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N
M,2XQ,S`T,"XR,BXR+BH*(PH*(PHC($=O;W!S(&]B:F5C=&-L87-S(&)R86YC
M:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR-"XR+BH*(PH*(PHC($UE<FL@;V)J96-T
M8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(U+C(N*@HC"@HC"B,@
M36EM<"!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C8N
M,BXJ"B,*"B,*(R!-;W1T;&4@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N
M-"XQ+C$S,#0P+C(W+C(N*@HC"@HC"B,@3FEC(&]B:F5C=&-L87-S(&)R86YC
M:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR."XR+BH*(PH*(PHC($]C8V%M(&]B:F5C
M=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR.2XR+BH*(PH*(PHC
M($]D:6X@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,P
M+C(N*@HC"@HC"B,@4F%K:6T@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N
M-"XQ+C$S,#0P+C,Q+C(N*@HC"@HC"B,@4V5S:&$@;V)J96-T8VQA<W,@8G)A
M;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,R+C(N*@HC"@HC"B,@4W=O;W-H(&]B
M:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS,RXR+BH*(PH*
M(PHC(%1H;W(@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C,T+C(N*@HC"@HC"B,@56QA9F]R;2!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS
M+C8N,2XT+C$N,3,P-#`N,S4N,BXJ"B,*"B,*(R!6;VQO<R!O8FIE8W1C;&%S
M<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,S8N,BXJ"B,*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+VUI9W)A=&5?=7-E<E]C
M871E9V]R:65S+G!H<```````````````````````````````````````````
M`````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P-38U`#$P
M-3$U-#,S-S4U`#`R-#<V-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````C(2]U<W(O;&]C86PO<'-A+V%D;6EN+V)I;B]P:'`@
M+7$*/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O<V-R:7!T<R]M:6=R871E
M7W5S97)?8V%T96=O<FEE<RYP:'`L=B`Q+C4N,3`N,2`R,#`U+S$P+S$X(#$Q
M.C,T.C`P(&IA;B!%>'`@)`H@*@H@*B!!('-C<FEP="!T;R!U<&1A=&4@=7-E
M<G,@<')E9F5R96YC97,@=&\@8V]M8FEN92!T:&5I<B!C871E9V]R:65S"B`J
M(&%N9"!C871E9V]R>2!C;VQO<G,@9G)O;2!'96YI92P@2W)O;F]L:71H+"!-
M;F5M;RP@86YD($YA9R!I;G1O('1H90H@*B!N97<@2&]R9&4M=VED92!P<F5F
M97)E;F-E<RX@17AP96-T<R!T;R!B92!G:79E;B!A(&QI<W0@;V8@=7-E<G,@
M;VX*("H@4U1$24XL(&]N92!U<V5R;F%M92!P97(@;&EN92P@=&\@8V]N=F5R
M="X@57-E<FYA;65S(&YE960@=&\@;6%T8V@*("H@=&AE('9A;'5E<R!S=&]R
M960@:6X@=&AE('!R969E<F5N8V5S(&)A8VME;F0N"B`J+PH*+R\@1FEN9"!T
M:&4@8F%S92!F:6QE('!A=&@@;V8@2&]R9&4N"D!D969I;F4H)T%55$A?2$%.
M1$Q%4B<L('1R=64I.PI`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+RXN)RD["@HO+R!$;R!#3$D@8VAE8VMS(&%N9"!E;G9I
M<F]N;65N="!S971U<"!F:7)S="X*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@
M+B`G+VQI8B]C;W)E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O0TQ)+G!H
M<"<["@HO+R!-86ME('-U<F4@;F\@;VYE(')U;G,@=&AI<R!F<F]M('1H92!W
M96(N"FEF("@A2&]R9&5?0TQ).CIR=6YN:6YG1G)O;4-,22@I*2!["B`@("!E
M>&ET*")-=7-T(&)E(')U;B!F<F]M('1H92!C;VUM86YD(&QI;F5<;B(I.PI]
M"@HO+R!,;V%D('1H92!#3$D@96YV:7)O;FUE;G0@+2!M86ME('-U<F4@=&AE
M<F4G<R!N;R!T:6UE(&QI;6ET+"!I;FET"B\O('-O;64@=F%R:6%B;&5S+"!E
M=&,N"DAO<F1E7T-,23HZ:6YI="@I.PH*<F5Q=6ER95]O;F-E($A/4D1%7T)!
M4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O4')E
M9G,O0V%T96=O<GE-86YA9V5R+G!H<"<["B1C;&D@/2`F2&]R9&5?0TQ).CIS
M:6YG;&5T;VXH*3L*)&%U=&@@/2`F075T:#HZ<VEN9VQE=&]N*"1C;VYF6R=A
M=71H)UU;)V1R:79E<B==*3L*)&--86YA9V5R(#T@)FYE=R!0<F5F<U]#871E
M9V]R>4UA;F%G97(H*3L*)&%P<',@/2`D<F5G:7-T<GDM/FQI<W1!<'!S*&%R
M<F%Y*"=H:61D96XG+"`G;F]T;V]L8F%R)RP@)V%C=&EV92<L("=A9&UI;B<I
M*3L*"B\O(%)E860@:6X@=&AE(&QI<W0@;V8@=7-E<FYA;65S(&]N(%-41$E.
M+@HD=7-E<G,@/2!A<G)A>2@I.PIW:&EL92`H(69E;V8H4U1$24XI*2!["B`@
M("`D;&EN92`](&9G971S*%-41$E.*3L*("`@("1L:6YE(#T@=')I;2@D;&EN
M92D["B`@("!I9B`H(65M<'1Y*"1L:6YE*2D@>PH@("`@("`@("1U<V5R<UM=
M(#T@)&QI;F4["B`@("!]"GT*"B\O($QO;W`@=&AR;W5G:"!U<V5R<R!A;F0@
M8V]N=F5R="!P<F5F<R!F;W(@1V5N:64L($UN96UO+"!.86<L(&%N9`HO+R!+
M<F]N;VQI=&@N"F9O<F5A8V@@*"1U<V5R<R!A<R`D=7-E<BD@>PH@("`@96-H
M;R`G36EG<F%T:6YG('!R969S(&9O<B`G("X@)&-L:2T^8F]L9"@D=7-E<BD[
M"@H@("`@+R\@4V5T("1U<V5R(&%S('1H92!C=7)R96YT('5S97(N"B`@("`D
M875T:"T^<V5T075T:"@D=7-E<BP@87)R87DH*2P@)R<I.PH*("`@("\O($9E
M=&-H(&-U<G)E;G0@8V%T96=O<FEE<R!A;F0@8V]L;W)S+@H@("`@)&-O;&]R
M<R`]("1C36%N86=E<BT^8V]L;W)S*"D["@H@("`@+R\@1V5N:64N"B`@("!I
M9B`H:6Y?87)R87DH)V=E;FEE)RP@)&%P<',I*2!["B`@("`@("`@96-H;R`G
M("X@9V5N:64G.PH@("`@("`@("1R97-U;'0@/2`D<F5G:7-T<GDM/G!U<VA!
M<'`H)V=E;FEE)RP@9F%L<V4I.PH@("`@("`@(&EF("@A:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1G7V-A=&5G;W)I97,@
M/2!L:7-T0V%T96=O<FEE<R@G=VES:%]C871E9V]R:65S)RD["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1G7V-A=&5G;W)I97,@87,@)&-A=&5G;W)Y*2!["B`@
M("`@("`@("`@("`@("`D8TUA;F%G97(M/F%D9"@D8V%T96=O<GDI.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\O($UN96UO+@H@("`@
M:68@*&EN7V%R<F%Y*"=M;F5M;R<L("1A<'!S*2D@>PH@("`@("`@(&5C:&\@
M)R`N(&UN96UO)SL*("`@("`@("`D<F5S=6QT(#T@)')E9VES=')Y+3YP=7-H
M07!P*"=M;F5M;R<L(&9A;'-E*3L*("`@("`@("!I9B`H(6ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D;5]C871E9V]R:65S
M(#T@;&ES=$-A=&5G;W)I97,H)VUE;6]?8V%T96=O<FEE<R<I.PH@("`@("`@
M("`@("`D;5]C;VQO<G,@/2!L:7-T0V]L;W)S*"=M96UO7V-O;&]R<R<I.PH@
M("`@("`@("`@("!F;W)E86-H("@D;5]C871E9V]R:65S(&%S("1K97D@/3X@
M)&-A=&5G;W)Y*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&U?8V]L
M;W)S6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@("`@("1C;VQO<G-;)&-A
M=&5G;W)Y72`]("1M7V-O;&]R<ULD:V5Y73L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1C36%N86=E<BT^861D*"1C871E9V]R>2D["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+R\@3F%G+@H@("`@
M:68@*&EN7V%R<F%Y*"=N86<G+"`D87!P<RDI('L*("`@("`@("!E8VAO("<@
M+B!N86<G.PH@("`@("`@("1R97-U;'0@/2`D<F5G:7-T<GDM/G!U<VA!<'`H
M)VYA9R<L(&9A;'-E*3L*("`@("`@("!I9B`H(6ES7V$H)')E<W5L="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D;E]C871E9V]R:65S(#T@;&ES
M=$-A=&5G;W)I97,H)W1A<VM?8V%T96=O<FEE<R<I.PH@("`@("`@("`@("!F
M;W)E86-H("@D;E]C871E9V]R:65S(&%S("1C871E9V]R>2D@>PH@("`@("`@
M("`@("`@("`@)&--86YA9V5R+3YA9&0H)&-A=&5G;W)Y*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@('T*"B`@("`O+R!+<F]N;VQI=&@N"B`@("!I
M9B`H:6Y?87)R87DH)VMR;VYO;&ET:"<L("1A<'!S*2D@>PH@("`@("`@(&5C
M:&\@)R`N(&MR;VYO;&ET:"<["B`@("`@("`@)')E<W5L="`]("1R96=I<W1R
M>2T^<'5S:$%P<"@G:W)O;F]L:71H)RP@9F%L<V4I.PH@("`@("`@(&EF("@A
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1K
M7V-A=&5G;W)I97,@/2!L:7-T0V%T96=O<FEE<R@G979E;G1?8V%T96=O<FEE
M<R<I.PH@("`@("`@("`@("!I9B`H8V]U;G0H)&M?8V%T96=O<FEE<RDI('9A
M<E]D=6UP*"1K7V-A=&5G;W)I97,I.PH@("`@("`@("`@("`D:U]C;VQO<G,@
M/2!L:7-T0V]L;W)S*"=E=F5N=%]C;VQO<G,G*3L*("`@("`@("`@("`@9F]R
M96%C:"`H)&M?8V%T96=O<FEE<R!A<R`D:V5Y(#T^("1C871E9V]R>2D@>PH@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1K7V-O;&]R<ULD:V5Y72DI('L*
M("`@("`@("`@("`@("`@("`@("`D8V]L;W)S6R1C871E9V]R>5T@/2`D:U]C
M;VQO<G-;)&ME>5T["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D8TUA;F%G97(M/F%D9"@D8V%T96=O<GDI.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H*("`@("1C36%N86=E<BT^<V5T0V]L;W)S*"1C;VQO
M<G,I.PH@("`@)'!R969S+3YS=&]R92@I.PH@("`@)&-L:2T^=W)I=&5L;B@I
M.PI]"@HD8VQI+3YW<FET96QN*"D["B1C;&DM/G=R:71E;&XH)&-L:2T^9W)E
M96XH)T1/3D4G*2D["F5X:70["@IF=6YC=&EO;B!L:7-T0V%T96=O<FEE<R@D
M<')E9FYA;64I"GL*("`@(&=L;V)A;"`D<')E9G,["@H@("`@)'-T<FEN9R`]
M("1P<F5F<RT^9V5T5F%L=64H)'!R969N86UE*3L*("`@(&EF("AE;7!T>2@D
M<W1R:6YG*2D@>PH@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@?0H*("`@
M("1C871S(#T@97AP;&]D92@G?"<L("1S=')I;F<I.PH@("`@9F]R96%C:"`H
M)&-A=',@87,@)&-A="D@>PH@("`@("`@(&QI<W0H)&ME>2P@)'9A;"D@/2!E
M>'!L;V1E*"<Z)RP@)&-A="D["B`@("`@("`@)&-A=&5G;W)I97-;)&ME>5T@
M/2`D=F%L.PH@("`@?0H*("`@(')E='5R;B`D8V%T96=O<FEE<SL*?0H*9G5N
M8W1I;VX@;&ES=$-O;&]R<R@D<')E9FYA;64I"GL*("`@(&=L;V)A;"`D<')E
M9G,["@H@("`@)'-T<FEN9R`]("1P<F5F<RT^9V5T5F%L=64H)'!R969N86UE
M*3L*("`@(&EF("AE;7!T>2@D<W1R:6YG*2D@>PH@("`@("`@(')E='5R;B!A
M<G)A>2@I.PH@("`@?0H@("`@)&-O;',@/2!E>'!L;V1E*"=\)RP@)'-T<FEN
M9RD["B`@("`D8V]L;W)S(#T@87)R87DH*3L*("`@(&9O<F5A8V@@*"1C;VQS
M(&%S("1C;VPI('L*("`@("`@("!L:7-T*"1K97DL("1V86PI(#T@97AP;&]D
M92@G.B<L("1C;VPI.PH@("`@("`@("1C;VQO<G-;)&ME>5T@/2`D=F%L.PH@
M("`@?0H*("`@(')E='5R;B`D8V]L;W)S.PI]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W-C<FEP=',O<F5M;W9E7W!R969S+G!H<```````````
M````````````````````````````````````````````````````````,#`P
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0V,C(`,3`U,34T,S,W-34`
M,#(R-38S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````",A+W5S<B]L;V-A;"]P<V$O861M:6XO8FEN+W!H<`H\/W!H<`HO*BH*
M("H@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W)E;6]V95]P<F5F<RYP:'`L=B`Q
M+C,N,3`N-R`R,#`V+S`T+S$X(#$V.C(U.C,Q(&IA;B!%>'`@)`H@*@H@*B!4
M:&ES('-C<FEP="!R96UO=F5S(&$@<')E9B!F<F]M('5S97)S)R!S971T:6YG
M<RX@2&5L<',@=VAE;B!A('-E='1I;F<@:7,*("H@=&\@8F4@;6]V960@9G)O
M;2!L;V-K960@/2!F86QS92P@=&\@;&]C:V5D(#T@=')U92!A;F0@=&AE<F4@
M:&%V92!A;')E861Y"B`J(&)E96X@<')E9G,@<V5T(&)Y('1H92!U<V5R<RX*
M("HO"@HO*BH*("HJ(%-E="!T:&ES('1O('1R=64@:68@>6]U('=A;G0@1$(@
M;6]D:69I8V%T:6]N<R!D;VYE+@H@*BHO"B1L:79E(#T@9F%L<V4["@HO+R!.
M;R!A=71H+@I`9&5F:6YE*"=!551(7TA!3D1,15(G+"!T<G5E*3L*"B\O($9I
M;F0@=&AE(&)A<V4@9FEL92!P871H(&]F($AO<F1E+@I`9&5F:6YE*"=(3U)$
M15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["@HO+R!$;R!#
M3$D@8VAE8VMS(&%N9"!E;G9I<F]N;65N="!S971U<"!F:7)S="X*<F5Q=6ER
M95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]C;W)E+G!H<"<["G)E<75I<F5?
M;VYC92`G2&]R9&4O0TQ)+G!H<"<["@HO+R!-86ME('-U<F4@;F\@;VYE(')U
M;G,@=&AI<R!F<F]M('1H92!W96(N"FEF("@A2&]R9&5?0TQ).CIR=6YN:6YG
M1G)O;4-,22@I*2!["B`@("!E>&ET*")-=7-T(&)E(')U;B!F<F]M('1H92!C
M;VUM86YD(&QI;F5<;B(I.PI]"@HO+R!,;V%D('1H92!#3$D@96YV:7)O;FUE
M;G0@+2!M86ME('-U<F4@=&AE<F4G<R!N;R!T:6UE(&QI;6ET+"!I;FET"B\O
M('-O;64@=F%R:6%B;&5S+"!E=&,N"DAO<F1E7T-,23HZ:6YI="@I.PHD8VQI
M(#T@)FYE=R!(;W)D95]#3$DH*3L*"G)E<75I<F5?;VYC92!(3U)$15]"05-%
M("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T1A=&%4
M<F5E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O1W)O=7`N<&AP)SL*<F5Q
M=6ER95]O;F-E("=(;W)D92]3:&%R92YP:'`G.PH*+RH@36%K92!S=7)E('1H
M97)E)W,@;F\@8V]M<')E<W-I;VXN("HO"F]B7V5N9%]C;&5A;B@I.PH*"B1S
M8V]P92`]("1C;&DM/G!R;VUP="A?*")%;G1E<B!V86QU92!F;W(@<')E9E]S
M8V]P93HB*2D["B1N86UE(#T@)&-L:2T^<')O;7!T*%\H(D5N=&5R('9A;'5E
M(&9O<B!P<F5F7VYA;64Z(BDI.PH*+RH@3W!E;B!T:&4@9&%T86)A<V4N("HO
M"B1D8B`]("9$0CHZ8V]N;F5C="@D8V]N9ELG<W%L)UTI.PII9B`H:7-?82@D
M9&(L("=014%27T5R<F]R)RDI('L*("`@=F%R7V1U;7`H)&1B*3L@97AI=#L*
M?0H*+R\@4V5T($1"('!O<G1A8FEL:71Y(&]P=&EO;G,N"G-W:71C:"`H)&1B
M+3YP:'!T>7!E*2!["F-A<V4@)VUS<W%L)SH*("`@("1D8BT^<V5T3W!T:6]N
M*"=P;W)T86)I;&ET>2<L($1"7U!/4E1!0DE,25197TQ/5T520T%312!\($1"
M7U!/4E1!0DE,25197T524D]24R!\($1"7U!/4E1!0DE,25197U)44DE-*3L*
M("`@(&)R96%K.PID969A=6QT.@H@("`@)&1B+3YS971/<'1I;VXH)W!O<G1A
M8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?3$]715)#05-%('P@1$)?4$]25$%"
M24Q)5%E?15)23U)3*3L*?0H*:68@*"1L:79E*2!["B`@("`D<W%L(#T@)T1%
M3$5412!&4D]-(&AO<F1E7W!R969S(%=(15)%('!R969?<V-O<&4@/2`_($%.
M1"!P<F5F7VYA;64@/2`_)SL*("`@("1V86QU97,@/2!A<G)A>2@D<V-O<&4L
M("1N86UE*3L*("`@("1R97-U;'0@/2`D9&(M/F=E=$%L;"@D<W%L+"`D=F%L
M=65S*3L*("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("!V87)?9'5M<"@D<F5S=6QT*3L*("`@('T@96QS96EF("AE;7!T
M>2@D<F5S=6QT*2D@>PH@("`@("`@("1C;&DM/G=R:71E;&XH<W!R:6YT9BA?
M*").;R!P<F5F97)E;F-E(%PB)7-<(B!F;W5N9"!I;B!S8V]P92!<(B5S7"(N
M(BDL("1N86UE+"`D<V-O<&4I*3L*("`@('T@96QS92!["B`@("`@("`@)&-L
M:2T^=W)I=&5L;BAS<')I;G1F*%\H(E!R969E<F5N8V5S(%PB)7-<(B!D96QE
M=&5D(&EN('-C;W!E(%PB)7-<(BXB*2P@)&YA;64L("1S8V]P92DI.PH@("`@
M?0I](&5L<V4@>PH@("`@)'-Q;"`]("=314Q%0U0@*B!&4D]-(&AO<F1E7W!R
M969S(%=(15)%('!R969?<V-O<&4@/2`_($%.1"!P<F5F7VYA;64@/2`_)SL*
M("`@("1V86QU97,@/2!A<G)A>2@D<V-O<&4L("1N86UE*3L*("`@("1R97-U
M;'0@/2`D9&(M/F=E=$%L;"@D<W%L+"`D=F%L=65S*3L*("`@(&EF("AE;7!T
M>2@D<F5S=6QT*2D@>PH@("`@("`@("1C;&DM/G=R:71E;&XH<W!R:6YT9BA?
M*").;R!P<F5F97)E;F-E(%PB)7-<(B!F;W5N9"!I;B!S8V]P92!<(B5S7"(N
M(BDL("1N86UE+"`D<V-O<&4I*3L*("`@('T@96QS92!["B`@("`@("`@=F%R
M7V1U;7`H)')E<W5L="D["B`@("!]"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O4T-225!44P``````
M````````````````````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0T,C,`
M,3`U,34T,S,W-38`,#(P-#(U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B!(;W)D
M92!5=&EL:71Y(%-C<FEP=',*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"DEN
M=')O9'5C=&EO;@I^?GY^?GY^?GY^?GX*5&AI<R!D:7)E8W1O<GD@8V]N=&%I
M;G,@=F%R:6]U<R!U=&EL:71Y('-C<FEP=',@9F]R('1H92!(;W)D92!D:7-T
M<FEB=71I;VXN"E1H97D@87)E(&AE<F4@9F]R('EO=7(@8V]N=F5N:65N8V4N
M"@H*4V-R:7!T($EN9&5X"GY^?GY^?GY^?GY^?@IC;VUP87)E7W)E=FES:6]N
M<RYS:`H@("`@0V]M<&%R97,@9&EF9F5R96YT($-64R!R979I<VEO;G,@;V8@
M=&AE('-A;64@9FEL92X*"F-O;VMI95]L;V=I;BYP:'`*("`@($%L;&]W<R!T
M;R!L;V=I;B!W:71H('5S97(@8W)E9&5N=&EA;',@<')O=FED960@8GD@8V]O
M:VEE<RX*"F-R96%T92US>6UL:6YK<RYP:'`*("`@($-R96%T97,@<WEM8F]L
M:6,@;&EN:W,@;F5C97-S87)Y(&9O<B!D979E;&]P97)S('1O('=O<FL@9&ER
M96-T;'D@;VX@=&AE"B`@("!F:6QE<R!I;B!T:&4@9G)A;65W;W)K(&UO9'5L
M92!W:71H;W5T(&YE961I;F<@=&\@:6YS=&%L;"!T:&4@8VAA;F=E9`H@("`@
M<&%C:V%G97,N"@IC<F]N9`H@("`@=&)D"@IG971?;&]G:6XN<&AP"B`@("!!
M;&QO=W,@=&\@;&]G:6X@=VET:"!U<V5R(&-R961E;G1I86QS('!R;W9I9&5D
M(&)Y($=%5"!P87)A;65T97)S+@H*:&EG:&QI9VAT+G!H<`H@("`@2&EG:&QI
M9VAT<R!S;W5R8V4@9FEL97,@;VX@=&AE(&-O;G-O;&4N"@IH;W)D92UR<WEN
M8RYS:`H@("`@4&5R9F]R;7,@82!C:&5C:V]U="!O9B!T:&4@;&%T97-T($AO
M<F1E(&-V<R!S;W5R8V5S('5S:6YG(')S>6YC+@H*:'1T<%]L;V=I;E]R969E
M<BYP:'`*("`@('1B9`H*;6%K92US;F%P<RYP:'`*("`@('1B9`H*;6%K92UR
M96QE87-E+G!H<`H@("`@0G5I;&1S(&1I<W1R:6)U=&EO;B!T87)B86QL<R!F
M;W(@2&]R9&4@86YD($AO<F1E(&UO9'5L97,N"@IM97)G92YP:'`*("`@($UE
M<F=E<R!C;VUM:71S(&9R;VT@82!C;VUM:70@;65S<V%G92!I;G1O('1H92!#
M5E,@=')E92!O9B!T:&4@8W5R<F5N=`H@("`@9&ER96-T;W)Y+@H*;6EG<F%T
M95]C871E9V]R:65S+G!H<`H@("`@36EG<F%T97,@;VQD(&-A=&5G;W)I97,@
M=&\@=&AE(&YE=R!H;W)D95]C871E9V]R>5]A='1R:6)U=&5S('1A8FQE+@H*
M;6EG<F%T95]L:6YK<RYP:'`*("`@($UI9W)A=&5S(&]L9"!(;W)D95],:6YK
M<R!T;R!T:&4@:&]R9&5?8V%T96=O<GE?871T<FEB=71E<R!T86)L92X*"G!A
M8VMA9V4N9'1D"B`@("!4:&4@4$5!4B!P86-K86=E(&1E<V-R:7!T:6]N+@H*
M<G!C+71E<W0N<&AP"B`@("!0<F]V:61E<R!T97-T<R!F;W(@=&AE(%)00R!C
M;&EE;G0@86=A:6YS="!S979E<F%L("AI;F-L=61I;F<@;W5R(&]W;BD@4E!#
M"B`@("!S97)V97)S+@H*<V5T7W!E<FUS+G-H"B`@("!3971S(&9I;&4@;W=N
M97)S:&EP(&%N9"!P97)M:7-S:6]N<R!O;B!T:&4@2&]R9&4@=')E92!F;W(@
M:&EG:"!S96-U<FET>2X*"G-E='5P+G!H<`H@("`@5&AE(&UA:6X@2&]R9&4@
M<V5T=7`@<V-R:7!T('=H:6-H(&%L;&]W<R!F;W(@82!S=&5P(&)Y('-T97`@
M<V5T=7`@;W(*("`@(')E8V]N9FEG=7)A=&EO;B!O9B!A($AO<F1E(&EN<W1A
M;&QA=&EO;BX*"G1E;7`M8VQE86YU<"YC<F]N"B`@("!!;B!E>&%M<&QE(&-R
M;VX@:F]B('-H96QL('-C<FEP="!W:&EC:"!W:6QL(&-L96%N('5P(&%N>2!T
M96UP;W)A<GD@9FEL97,*("`@('=H:6-H(&UA>2!G970@<W1R86YD960@8GD@
M2&]R9&4@=7-E<G,@:6X@=&AE('=E8B!S97)V97(G<R!T96UP;W)A<GD*("`@
M(&1I<F5C=&]R>2X*"G5P9&%T95]H;W)D92YS:`H@("`@1F%C:6QI=&%T97,@
M=&AE('5P9&%T:6YG(&%N9"]O<B!I;G-T86QL871I;VX@;V8@:&]R9&4@86YD
M(&ET<PH@("`@87!P;&EC871I;VYS+@H*;6EM95]M87!P:6YG+PH@("`@5&AI
M<R!S8W)I<'0@8V]N=F5R=',@86X@07!A8VAE+7-T>6QE(&UI;64N='EP97,@
M9FEL92!I;G1O(&$*("`@(&UI;64N;6%P<&EN9RYP:'`@9')I=F5R(&9I;&4@
M<W5I=&%B;&4@9F]R('5S92!W:71H($AO<F1E+B`@270@:7,@=7-E9G5L"B`@
M("!F;W(@<WEN8VEN9R!!<&%C:&4@=7!D871E<R!T;R!T:&5I<B!-24U%('1Y
M<&5S('=I=&@@2&]R9&4N"@H*1&%T86)A<V4@4V-R:7!T<PI^?GY^?GY^?GY^
M?GY^?GY^"D1A=&%B87-E('1A8FQE('-C:&5M87,@86YD(&%S<V]C:6%T960@
M=71I;&ET>2!S8W)I<'1S(&%R92!L;V-A=&5D(&EN('1H92!S<6PO"G-U8F1I
M<F5C=&]R>2X*"@I,1$%0(%-C:&5M87,*?GY^?GY^?GY^?GY^"DQ$05`@<V-H
M96UA<R!A<F4@;&]C871E9"!I;B!T:&4@;&1A<"\@<W5B9&ER96-T;W)Y+@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O
M<V5T7W!E<FUS+G-H````````````````````````````````````````````
M````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#,V,#$`,3`U,34T,S,W-34`,#(Q-S`W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````",A+V)I;B]S:`HC"B,@<V5T
M7W!E<FUS+G-H("T@2F]N(%!A<FES92`\:F]N0&-S:"YR:70N961U/@HC"B,@
M)$AO<F1E.B!H;W)D92]S8W)I<'1S+W-E=%]P97)M<RYS:"QV(#$N-R`R,#`Q
M+S`T+S$U(#`Q.C4U.C,R(&-H=6-K($5X<"`D"@HC(")$86YG97)O=7,B(%!(
M4"!S8W)I<'1S"B,*1$%.1T523U537T9)3$53/2)T97-T+G!H<"(*"B,@1&5F
M875L="!N;VXM=V5B('-E<G9E<B!U<V5R('=H;R!W:6QL(&]W;B!T:&4@=')E
M92X*(PI/5TY%4CUR;V]T"@HC($EN=')O9'5C=&]R>2!T97AT"B,*8V%T(#P\
M($5/1@H*5&AI<R!S8W)I<'0@=VEL;"!S970@=&AE('!E<FUI<W-I;VYS(&]N
M('EO=7(@2&]R9&4*=')E92!S;R!T:&%T('1H92!F:6QE<R!W:6QL(&)E(&%C
M8V5S<VEB;&4@8GD@=&AE('=E8@IS97)V97(N"@I9;W4@8V%N(&-A;F-E;"!T
M:&ES('-C<FEP="!A="!A;GD@=&EM92!U<VEN9R!#=')L+4,N"@I%3T8*"B,@
M5F5R:69Y('1H870@=V4G<F4@870@=&AE('1O<"!O9B!T:&4@2&]R9&4@=')E
M92X*(PIP=V0*96-H;PIE8VAO("UN("))<R!T:&ES(&1I<F5C=&]R>2!T:&4@
M=&]P(&]F('EO=7(@2&]R9&4@:6YS=&%L;&%T:6]N/R!;>2Q.72`B"G)E860@
M4D534$].4T4@"FEF(%L@(B1215-03TY312(@(3T@(GDB("UA("(D4D534$].
M4T4B("$](")9(B!=.R!T:&5N"B`@("!E8VAO"B`@("!E8VAO("UN(")%;G1E
M<B!Y;W5R($AO<F1E(&1I<F5C=&]R>3H@(@H@("`@<F5A9"!$25(@(`H):68@
M6R`B>"1$25(B(#T@(G@B(%T[('1H96X*"0EE8VAO(")%>&ET:6YG+BXN(@H)
M"65X:70*"65L<V4*("`@(`EC9"`D1$E2"@EF:0IF:0IE8VAO"@HC($=E="!T
M:&4@=V5B('-E<G9E<B=S(&=R;W5P+@HC"F5C:&\@+6X@(E5N9&5R('=H870@
M9W)O=7`@9&]E<R!T:&4@=V5B('!R;V-E<W,@<G5N/R!;;F]B;V1Y72`B"G)E
M860@5T5"7T=23U50"FEF(%L@(G@D5T5"7T=23U50(B`](")X(B!=.R!T:&5N
M"B`@("!714)?1U)/55`](FYO8F]D>2(@"F9I"@HC($%S:R!B969O<F4@<')O
M8V5E9&EN9RX*(PIE8VAO"F5C:&\@+6X@(E!R;V-E960@=VET:"!C:&%N9VEN
M9R!O=VYE<G-H:7`@86YD('!E<FUI<W-I;VYS/R!;>2Q.72`B"G)E860@4D53
M4$].4T4@"FEF(%L@(B1215-03TY312(@(3T@)WDG("UA("(D4D534$].4T4B
M("$]("=9)R!=.R!T:&5N"B`@("!E8VAO(")%>&ET:6YG+BXN(@H@("`@97AI
M=`IF:0H*(R!3970@=&AE('5S97(@86YD(&=R;W5P(&]W;F5R<VAI<"!R96-U
M<G-I=F5L>2X*(PIE8VAO"F5C:&\@+6X@(E-E='1I;F<@;W=N97)S:&EP(')E
M8W5R<VEV96QY+BXN("(*8VAO=VX@+5(@)$]73D52("X*8VAG<G`@+5(@)%=%
M0E]'4D]54"`N"F5C:&\@(F1O;F4N(@H*(R!3970@=&AE('!E<FUI<W-I;VYS
M(&]N(&9I;&5S("@P-C0P*2!A;F0@9&ER96-T;W)I97,@*#`W-3`I+@HC"F5C
M:&\@+6X@(E-E='1I;F<@<&5R;6ES<VEO;G,@<F5C=7)S:79E;'DN+BX@(@IF
M:6YD("X@+71Y<&4@9B`M97AE8R!C:&UO9"`P-C0P('M](%P["F9I;F0@+B`M
M='EP92!D("UE>&5C(&-H;6]D(#`W-3`@>WT@7#L*96-H;R`B9&]N92XB"@HC
M($1I<V%B;&4@86YY(")D86YG97)O=7,B(%!(4"!S8W)I<'1S(&EN('1H92!D
M:7-T<FEB=71I;VX@*#`P,#`I+@HC"F5C:&\@+6X@(D1I<V%B;&EN9R!P;W1E
M;G1I86QL>2!<(F1A;F=E<F]U<UPB(%!(4"!S8W)I<'1S+BXN("(*9F]R($9)
M3$4@:6X@)$1!3D=%4D]54U]&24Q%4SL@9&\*"6EF(%L@+68@)$9)3$4@73L@
M=&AE;@H)"6-H;6]D(#`P,#`@)$9)3$4*"69I"F1O;F4*96-H;R`B9&]N92XB
M"@HC(%-A>2!G;V]D+6)Y92X*(PIE8VAO"F5C:&\@(DEF('EO=2!R96-E:79E
M9"!A;GD@97)R;W)S+"!Y;W4@;6%Y(&YO="!H879E('-U9F9I8VEE;G0@86-C
M97-S(@IE8VAO(")T;R!C:&%N9V4@9FEL92!O=VYE<G-H:7`@86YD('!E<FUI
M<W-I;VYS+B(*96-H;PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-E='5P
M+G!H<```````````````````````````````````````````````````````
M`````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`T-30T`#$P-3$U-#,S-S4U`#`R,3(S,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````C(2]U<W(O;&]C86PO<'-A+V%D;6EN
M+V)I;B]P:'`*/#]P:'`*+RHJ"B`J(%1H92!M86EN($AO<F1E('-E='5P('-C
M<FEP="!W:&EC:"!A;&QO=W,@9F]R(&$@<W1E<"!B>2!S=&5P('-E='5P"B`J
M(&]R(')E8V]N9FEG=7)A=&EO;B!O9B!A($AO<F1E(&EN<W1A;&QA=&EO;BX*
M("H*("H@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W-E='5P+G!H<"QV(#$N,C4N
M,3`N,3`@,C`P-B\P-2\Q."`Q-3HT-SHS,B!C:'5C:R!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC
M;VT^"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@0VAA<FQE<R!*+B!(86=E;F)U
M8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`875T:&]R
M("!#:&%R;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`
M<VEN8V4@("!(;W)D92`S+C`*("HO"@I`9&5F:6YE*"=!551(7TA!3D1,15(G
M+"!T<G5E*3L*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%
M7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB
M+V-O<F4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]#3$DN<&AP)SL*"B1C
M;&D@/2!N97<@2&]R9&5?0TQ)*"D["@HO*B!#:&5C:R!F;W(@8V]N9FEG(&9I
M;&5S+B`J+PHD9FEL97,@/2!A<G)A>2@G8V]N9BYP:'`G+`H@("`@("`@("`@
M("`@("`G;6EM95]D<FEV97)S+G!H<"<L"B`@("`@("`@("`@("`@("=N;',N
M<&AP)RP*("`@("`@("`@("`@("`@)W!R969S+G!H<"<L"B`@("`@("`@("`@
M("`@("=R96=I<W1R>2YP:'`G*3L*9F]R96%C:"`H)&9I;&5S(&%S("1F:6QE
M;F%M92D@>PH@("`@)&9I;&4@/2!(3U)$15]"05-%("X@)R]C;VYF:6<O)R`N
M("1F:6QE;F%M93L*("`@(&EF("AF:6QE7V5X:7-T<R@D9FEL92DI('L*("`@
M("`@("!C;&E?;&]G*'-P<FEN=&8H7R@B1FEL92!<(B5S7"(@:7,@879A:6QA
M8FQE+B(I+"`D9FEL96YA;64I+"`G;65S<V%G92<I.PH@("`@("`@(&-O;G1I
M;G5E.PH@("`@?0H*("`@(&-L:5]L;V<H<W!R:6YT9BA?*")&:6QE(%PB)7-<
M(B!I<R!M:7-S:6YG+B(I+"`D9FEL96YA;64I+"`G=V%R;FEN9R<I.PH*("`@
M("1D:7-T9FEL92`]("1F:6QE("X@)RYD:7-T)SL*("`@(&EF("AF:6QE7V5X
M:7-T<R@D9&ES=&9I;&4I*2!["B`@("`@("`@)&-R96%T95]C;VYF:6<@/2`D
M8VQI+3YP<F]M<'0H<W!R:6YT9BA?*")#<F5A=&4@7"(E<UPB(&9R;VT@9&5F
M875L=',@;F]W/R(I+"`D9FEL96YA;64I+"!A<G)A>2@G>2<@/3X@7R@B665S
M(BDL("=N)R`]/B!?*").;R(I*2D["B`@("`@("`@:68@*"1C<F5A=&5?8V]N
M9FEG(#T]("=Y)RD@>PH@("`@("`@("`@("!I9B`H(6-O<'DH)&1I<W1F:6QE
M+"`D9FEL92DI('L*("`@("`@("`@("`@("`@("1C;&DM/F9A=&%L*'-P<FEN
M=&8H7R@B0V]P>6EN9R!<(B4Q)',N9&ES=%PB('1O(%PB)3$D<UPB(&9A:6QE
M9"X@0VAE8VL@>6]U<B!I;G-T86QL871I;VXN(BDL("1F:6QE;F%M92DI.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&-L:5]L;V<H<W!R:6YT9BA?*")&
M:6QE("5S(&-R96%T960N(BDL("1F:6QE;F%M92DL("=S=6-C97-S)RD["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-L:2T^9F%T86PH<W!R:6YT
M9BA?*")9;W4@;F5E9"!T:&4@7"(E<UPB(&9I;&4@=&\@8V]N=&EN=64@<V5T
M=7`@86YD('1O('5S92!(;W)D92XB*2P@)&9I;&5N86UE*2D["B`@("`@("`@
M?0H@("`@?2!E;'-E('L*("`@("`@("`D8VQI+3YF871A;"AS<')I;G1F*%\H
M(D-A;FYO="!F:6YD(%PB)7-<(BP@8VAE8VL@>6]U<B!I;G-T86QL871I;VXN
M(BDL("1D:7-T9FEL92DI.PH@("`@?0I]"@IC;&E?;&]G*%\H(DEN:71I86P@
M<V5T=7`@8V]M<&QE=&5D+B!.;W<@8V]N=&EN=64@=&AE('-E='5P('=I=&@@
M>6]U<B!B<F]W<V5R+"!G;R!T;SH@:'1T<#HO+SQ9;W5R($AO<F1E(&EN<W1A
M;&P@55),/B]A9&UI;B\B*2P@)W-U8V-E<W,G*3L*97AI=#L*"B\J*@H@*B!7
M<F%P('1H92!M97-S86=E<R!W:71H(&%N(&EN9&5N="P@;F5A=&5R('-C<F5E
M;B!D:7-P;&%Y+@H@*B\*9G5N8W1I;VX@8VQI7VQO9R@D;65S<V%G92P@)'1Y
M<&4@/2`G;65S<V%G92<I"GL*("`@("1M97-S86=E(#T@=V]R9'=R87`H)&UE
M<W-A9V4L(#8Y+"`B7&X@("`@("`@("`@("(I.PH@("`@)$=,3T)!3%-;)V-L
M:2==+3YM97-S86=E*"1M97-S86=E+"`G8VQI+B<@+B`D='EP92D["GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M8W)I<'1S+W-Q;"\`````````````````````````````````````````````
M`````````````````````````````````````#`P,#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S4U`#`R,#$T-@`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+V-R96%T92YM<V1E+G-Q;```
M````````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8T,3``,3`U,34T,S,W
M-34`,#(S,#8R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"TM("1(;W)D93H@:&]R9&4O<V-R:7!T<R]S<6PO8W)E871E+FUS
M9&4N<W%L+'8@,2XQ+C(N-2`R,#`V+S`V+S(Y(#$V.C(Y.C`R(&IA;B!%>'`@
M)`H*55-%(&UA<W1E<@I'3PH*0U)%051%($1!5$%"05-%(&AO<F1E"D=/"@I%
M6$5#('-P7V%D9&QO9VEN("=H;W)D92<L("=H;W)D95]M9W(G+"`G:&]R9&4G
M"D=/"@I54T4@:&]R9&4*1T\*"D5814,@<W!?9W)A;G1D8F%C8V5S<R`G:&]R
M9&4G"D=/"@I#4D5!5$4@5$%"3$4@:&]R9&5?=7-E<G,@*`H@("`@=7-E<E]U
M:60@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=7-E<E]P87-S(%9!4D-(
M05(H,C4U*2!.3U0@3E5,3"P*"B`@("!04DE-05)9($M%62`H=7-E<E]U:60I
M"BD*1T\*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/
M3B!H;W)D95]U<V5R<R!43R!H;W)D90I'3PH*0U)%051%(%1!0DQ%(&AO<F1E
M7W!R969S("@*("`@('!R969?=6ED(%9!4D-(05(H,C`P*2!.3U0@3E5,3"P*
M("`@('!R969?<V-O<&4@5D%20TA!4B@Q-BD@3D]4($Y53$P@1$5&055,5"`G
M)RP*("`@('!R969?;F%M92!605)#2$%2*#,R*2!.3U0@3E5,3"P*("`@('!R
M969?=F%L=64@5$585"!.54Q,+`H*("`@(%!224U!4ED@2T59("AP<F5F7W5I
M9"P@<')E9E]S8V]P92P@<')E9E]N86UE*0HI"D=/"@I'4D%.5"!314Q%0U0L
M($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?<')E9G,@5$\@:&]R
M9&4*1T\*"D-214%412!)3D1%6"!P<F5F7W5I9%]I9'@@3TX@:&]R9&5?<')E
M9G,@*'!R969?=6ED*0I#4D5!5$4@24Y$15@@<')E9E]S8V]P95]I9'@@3TX@
M:&]R9&5?<')E9G,@*'!R969?<V-O<&4I"D=/"@I#4D5!5$4@5$%"3$4@:&]R
M9&5?9&%T871R964@*`H@("`@9&%T871R965?:60@24Y4($Y/5"!.54Q,+`H@
M("`@9W)O=7!?=6ED(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('5S97)?
M=6ED(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@(&1A=&%T<F5E7VYA;64@
M5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@9&%T871R965?<&%R96YT<R!6
M05)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!D871A=')E95]O<F1E<B!)3E0L
M"B`@("!D871A=')E95]D871A(%1%6%0L"B`@("!D871A=')E95]S97)I86QI
M>F5D(%--04Q,24Y4($1%1D%53%0@,"!.3U0@3E5,3"P*"B`@("!04DE-05)9
M($M%62`H9&%T871R965?:60I"BD*1T\*"D=204Y4(%-%3$5#5"P@24Y315)4
M+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]D871A=')E92!43R!H;W)D90I'
M3PH*0U)%051%($E.1$58(&1A=&%T<F5E7V1A=&%T<F5E7VYA;65?:61X($].
M(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]N86UE*0I#4D5!5$4@24Y$15@@
M9&%T871R965?9W)O=7!?:61X($].(&AO<F1E7V1A=&%T<F5E("AG<F]U<%]U
M:60I"D-214%412!)3D1%6"!D871A=')E95]U<V5R7VED>"!/3B!H;W)D95]D
M871A=')E92`H=7-E<E]U:60I"D-214%412!)3D1%6"!D871A=')E95]S97)I
M86QI>F5D7VED>"!/3B!H;W)D95]D871A=')E92`H9&%T871R965?<V5R:6%L
M:7IE9"D*1T\*"D-214%412!404),12!H;W)D95]D871A=')E95]A='1R:6)U
M=&5S("@*("`@(&1A=&%T<F5E7VED($E.5"!.3U0@3E5,3"P*("`@(&%T=')I
M8G5T95]N86UE(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@(&%T=')I8G5T
M95]K97D@5D%20TA!4B@R-34I($1%1D%53%0@)R<@3D]4($Y53$PL"B`@("!A
M='1R:6)U=&5?=F%L=64@5$585`HI"D=/"@I'4D%.5"!314Q%0U0L($E.4T52
M5"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?9&%T871R964@5$\@:&]R9&4*
M1T\*"D-214%412!)3D1%6"!D871A=')E95]A='1R:6)U=&5?:61X($].(&AO
M<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&1A=&%T<F5E7VED*0I#4D5!5$4@
M24Y$15@@9&%T871R965?871T<FEB=71E7VYA;65?:61X($].(&AO<F1E7V1A
M=&%T<F5E7V%T=')I8G5T97,@*&%T=')I8G5T95]N86UE*0I#4D5!5$4@24Y$
M15@@9&%T871R965?871T<FEB=71E7VME>5]I9'@@3TX@:&]R9&5?9&%T871R
M965?871T<FEB=71E<R`H871T<FEB=71E7VME>2D*1T\*"D-214%412!404),
M12!H;W)D95]T;VME;G,@*`H@("`@=&]K96Y?861D<F5S<R!605)#2$%2*#$P
M,"D@3D]4($Y53$PL"B`@("!T;VME;E]I9"!605)#2$%2*#,R*2!.3U0@3E5,
M3"P*("`@('1O:V5N7W1I;65S=&%M<"!"24=)3E0@3D]4($Y53$PL"@H@("`@
M4%))34%262!+15D@*'1O:V5N7V%D9')E<W,L('1O:V5N7VED*0HI"D=/"@I'
M4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?
M=&]K96YS(%1/(&AO<F1E"D=/"@I#4D5!5$4@5$%"3$4@:&]R9&5?=F9S("@*
M("`@('9F<U]I9"!"24=)3E0@3D]4($Y53$PL"B`@("!V9G-?='EP92!334%,
M3$E.5"!.3U0@3E5,3"P*("`@('9F<U]P871H(%9!4D-(05(H,C4U*2!.3U0@
M3E5,3"P*("`@('9F<U]N86UE(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@
M('9F<U]M;V1I9FEE9"!"24=)3E0@3D]4($Y53$PL"B`@("!V9G-?;W=N97(@
M5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7V1A=&$@5$585"P*"B`@
M("!04DE-05)9($M%62`@("AV9G-?:60I"BD*1T\*"D=204Y4(%-%3$5#5"P@
M24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]V9G,@5$\@:&]R9&4*
M1T\*"D-214%412!)3D1%6"!V9G-?<&%T:%]I9'@@3TX@:&]R9&5?=F9S("AV
M9G-?<&%T:"D*0U)%051%($E.1$58('9F<U]N86UE7VED>"!/3B!H;W)D95]V
M9G,@*'9F<U]N86UE*0I'3PH*0U)%051%(%1!0DQ%(&AO<F1E7VAI<W1O<FEE
M<R`H"B`@("!H:7-T;W)Y7VED("`@("`@($))1TE.5"!.3U0@3E5,3"P*("`@
M(&]B:F5C=%]U:60@("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@
M:&ES=&]R>5]A8W1I;VX@("!605)#2$%2*#,R*2!.3U0@3E5,3"P*("`@(&AI
M<W1O<GE?=',@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]D
M97-C("`@("!415A4+`H@("`@:&ES=&]R>5]W:&\@("`@("!605)#2$%2*#(U
M-2DL"B`@("!H:7-T;W)Y7V5X=')A("`@(%1%6%0L"@H@("`@4%))34%262!+
M15D@*&AI<W1O<GE?:60I"BD*1T\*"D=204Y4(%-%3$5#5"P@24Y315)4+"!5
M4$1!5$4L($1%3$5412!/3B!H;W)D95]H:7-T;W)I97,@5$\@:&]R9&4*1T\*
M"D-214%412!)3D1%6"!H:7-T;W)Y7V%C=&EO;E]I9'@@3TX@:&]R9&5?:&ES
M=&]R:65S("AH:7-T;W)Y7V%C=&EO;BD*0U)%051%($E.1$58(&AI<W1O<GE?
M='-?:61X($].(&AO<F1E7VAI<W1O<FEE<R`H:&ES=&]R>5]T<RD*0U)%051%
M($E.1$58(&AI<W1O<GE?=6ED7VED>"!/3B!H;W)D95]H:7-T;W)I97,@*&]B
M:F5C=%]U:60I"D=/"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]C<F5A=&4N;7ES<6PN<W%L
M````````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$R,S`W`#$P-3$U-#,S
M-S4U`#`R,S,P,0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L+V-R96%T92YM
M>7-Q;"YS<6PL=B`Q+C0N-BXY(#(P,#8O,#<O,#4@,34Z-3,Z,3`@:F%N($5X
M<"`D"BTM"BTM($EF('EO=2!A<F4@:6YS=&%L;&EN9R!(;W)D92!F;W(@=&AE
M(&9I<G-T('1I;64L('EO=2!C86X@<VEM<&QY"BTM(&1I<F5C="!T:&ES(&9I
M;&4@=&\@;7ES<6P@87,@4U1$24XZ"BTM"BTM("0@;7ES<6P@+2UU<V5R/7)O
M;W0@+2UP87-S=V]R9#T\37E344PM<F]O="UP87-S=V]R9#X@/"!C<F5A=&4N
M;7ES<6PN<W%L"BTM"BTM($EF('EO=2!A<F4@=7!G<F%D:6YG(&9R;VT@82!P
M<F5V:6]U<R!V97)S:6]N+"!Y;W4@=VEL;"!N965D('1O(&-O;6UE;G0*+2T@
M;W5T('1H92!T:&4@=7-E<B!C<F5A=&EO;B!S=&5P<R!B96QO=RP@87,@=V5L
M;"!A<R!T:&4@<V-H96UA<R!F;W(@86YY"BTM('1A8FQE<R!T:&%T(&%L<F5A
M9'D@97AI<W0N"BTM"BTM($EF('EO=2!C:&]O<V4@=&\@9W)A;G0@<&5R;6ES
M<VEO;G,@;6%N=6%L;'DL(&YO=&4@=&AA="!W:71H($UY4U%,+"!014%2($1"
M"BTM(&5M=6QA=&5S('-E<75E;F-E<R!B>2!A=71O;6%T:6-A;&QY(&-R96%T
M:6YG(&5X=')A('1A8FQE<R!E;F1I;F<@:6X@7W-E<2P*+2T@<V\@=&AE($UY
M4U%,(")H;W)D92(@=7-E<B!M=7-T(&AA=F4@0U)%051%('!R:79I;&5G92!O
M;B!T:&4@(FAO<F1E(@HM+2!D871A8F%S92X*+2T*+2T@268@>6]U(&%R92!U
M<&=R861I;F<@9G)O;2!(;W)D92`Q+G@L('1H92!(;W)D92!T86)L97,@>6]U
M(&AA=F4@9G)O;0HM+2!T:&%T('9E<G-I;VX@87)E(&YO(&QO;F=E<B!U<V5D
M.R!Y;W4@;6%Y('=I<V@@=&\@96ET:&5R(&1E;&5T92!T:&]S90HM+2!T86)L
M97,@;W(@<VEM<&QY(')E8W)E871E('1H92!D871A8F%S92!A;F5W+@H*55-%
M(&UY<W%L.PH*4D503$%#12!)3E1/('5S97(@*&AO<W0L('5S97(L('!A<W-W
M;W)D*0H@("`@5D%,5453("@*("`@("`@("`G;&]C86QH;W-T)RP*("`@("`@
M("`G:&]R9&4G+`H)4$%34U=/4D0H)T!714)-04E,7U!!4U-73U)$0"<I"BD[
M"@I215!,04-%($E.5$\@9&(@*&AO<W0L(&1B+"!U<V5R+"!S96QE8W1?<')I
M=BP@:6YS97)T7W!R:78L('5P9&%T95]P<FEV+`H@("`@("`@("`@("`@("`@
M(&1E;&5T95]P<FEV+"!C<F5A=&5?<')I=BP@9')O<%]P<FEV+"!I;F1E>%]P
M<FEV*0H@("`@5D%,5453("@*("`@("`@("`G;&]C86QH;W-T)RP*("`@("`@
M("`G:&]R9&4G+`H@("`@("`@("=H;W)D92<L"B`@("`@("`@)UDG+"`G62<L
M("=9)RP@)UDG+`H@("`@("`@("=9)RP@)UDG+"`G62<**3L*"BTM($UA:V4@
M<W5R92!T:&%T('!R:79I;&EG97,@87)E(')E;&]A9&5D+@I&3%532"!04DE6
M24Q%1T53.PH*+2T@37E344P@,RXR,RYX(&%P<&5A<G,@=&\@:&%V92`B0U)%
M051%($1!5$%"05-%($E&($Y/5"!%6$E35%,B(&%N9`HM+2`B0U)%051%(%1!
M0DQ%($E&($Y/5"!%6$E35%,B('=H:6-H('=O=6QD(&)E(&$@;FEC92!W87D@
M=&\@:&%N9&QE"BTM(')E:6YS=&%L;',@9W)A8V5F=6QL>2`H<V]M961A>2DN
M("!&;W(@;F]W+"!D<F]P('1H92!D871A8F%S90HM+2!M86YU86QL>2!T;R!A
M=F]I9"!#4D5!5$4@97)R;W)S+@I#4D5!5$4@1$%404)!4T4@:&]R9&4["@I5
M4T4@:&]R9&4["@I#4D5!5$4@5$%"3$4@:&]R9&5?=7-E<G,@*`H@("`@=7-E
M<E]U:60@("`@("`@("`@("`@("`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,
M3"P*("`@('5S97)?<&%S<R`@("`@("`@("`@("`@("`@("!605)#2$%2*#(U
M-2D@3D]4($Y53$PL"B`@("!U<V5R7W-O9G1?97AP:7)A=&EO;E]D871E("`@
M24Y4+`H@("`@=7-E<E]H87)D7V5X<&ER871I;VY?9&%T92`@($E.5"P*"B`@
M("!04DE-05)9($M%62`H=7-E<E]U:60I"BD["@I'4D%.5"!314Q%0U0L($E.
M4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?=7-E<G,@5$\@:&]R9&5`
M;&]C86QH;W-T.PH*0U)%051%(%1!0DQ%(&AO<F1E7W!R969S("@*("`@('!R
M969?=6ED("`@("`@("!605)#2$%2*#(P,"D@3D]4($Y53$PL"B`@("!P<F5F
M7W-C;W!E("`@("`@5D%20TA!4B@Q-BD@3D]4($Y53$P@1$5&055,5"`G)RP*
M("`@('!R969?;F%M92`@("`@("!605)#2$%2*#,R*2!.3U0@3E5,3"P*("`@
M('!R969?=F%L=64@("`@("!,3TY'5$585"!.54Q,+`H*("`@(%!224U!4ED@
M2T59("AP<F5F7W5I9"P@<')E9E]S8V]P92P@<')E9E]N86UE*0HI.PH*0U)%
M051%($E.1$58('!R969?=6ED7VED>"!/3B!H;W)D95]P<F5F<R`H<')E9E]U
M:60I.PI#4D5!5$4@24Y$15@@<')E9E]S8V]P95]I9'@@3TX@:&]R9&5?<')E
M9G,@*'!R969?<V-O<&4I.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%4
M12P@1$5,151%($].(&AO<F1E7W!R969S(%1/(&AO<F1E0&QO8V%L:&]S=#L*
M"D-214%412!404),12!H;W)D95]D871A=')E92`H"B`@("`@("!D871A=')E
M95]I9"!)3E0@3D]4($Y53$PL"B`@("`@("!G<F]U<%]U:60@5D%20TA!4B@R
M-34I($Y/5"!.54Q,+`H@("`@("`@=7-E<E]U:60@5D%20TA!4B@R-34I($Y/
M5"!.54Q,+`H@("`@("`@9&%T871R965?;F%M92!605)#2$%2*#(U-2D@3D]4
M($Y53$PL"B`@("`@("!D871A=')E95]P87)E;G1S(%9!4D-(05(H,C4U*2!.
M3U0@3E5,3"P*("`@("`@(&1A=&%T<F5E7V]R9&5R($E.5"P*("`@("`@(&1A
M=&%T<F5E7V1A=&$@5$585"P*("`@("`@(&1A=&%T<F5E7W-E<FEA;&EZ960@
M4TU!3$Q)3E0@1$5&055,5"`P($Y/5"!.54Q,+`H*("`@("`@(%!224U!4ED@
M2T59("AD871A=')E95]I9"D**3L*"D-214%412!)3D1%6"!D871A=')E95]D
M871A=')E95]N86UE7VED>"!/3B!H;W)D95]D871A=')E92`H9&%T871R965?
M;F%M92D["D-214%412!)3D1%6"!D871A=')E95]G<F]U<%]I9'@@3TX@:&]R
M9&5?9&%T871R964@*&=R;W5P7W5I9"D["D-214%412!)3D1%6"!D871A=')E
M95]U<V5R7VED>"!/3B!H;W)D95]D871A=')E92`H=7-E<E]U:60I.PI#4D5!
M5$4@24Y$15@@9&%T871R965?<V5R:6%L:7IE9%]I9'@@3TX@:&]R9&5?9&%T
M871R964@*&1A=&%T<F5E7W-E<FEA;&EZ960I.PH*0U)%051%(%1!0DQ%(&AO
M<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*`H@("`@9&%T871R965?:60@24Y4
M($Y/5"!.54Q,+`H@("`@871T<FEB=71E7VYA;64@5D%20TA!4B@R-34I($Y/
M5"!.54Q,+`H@("`@871T<FEB=71E7VME>2!605)#2$%2*#(U-2D@1$5&055,
M5"`G)R!.3U0@3E5,3"P*("`@(&%T=')I8G5T95]V86QU92!415A4"BD["@I#
M4D5!5$4@24Y$15@@9&%T871R965?871T<FEB=71E7VED>"!/3B!H;W)D95]D
M871A=')E95]A='1R:6)U=&5S("AD871A=')E95]I9"D["D-214%412!)3D1%
M6"!D871A=')E95]A='1R:6)U=&5?;F%M95]I9'@@3TX@:&]R9&5?9&%T871R
M965?871T<FEB=71E<R`H871T<FEB=71E7VYA;64I.PI#4D5!5$4@24Y$15@@
M9&%T871R965?871T<FEB=71E7VME>5]I9'@@3TX@:&]R9&5?9&%T871R965?
M871T<FEB=71E<R`H871T<FEB=71E7VME>2D["@I'4D%.5"!314Q%0U0L($E.
M4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?9&%T871R964@5$\@:&]R
M9&5`;&]C86QH;W-T.PI'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$
M14Q%5$4@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R!43R!H;W)D94!L
M;V-A;&AO<W0["@I#4D5!5$4@5$%"3$4@:&]R9&5?=&]K96YS("@*("`@('1O
M:V5N7V%D9')E<W,@("`@5D%20TA!4B@Q,#`I($Y/5"!.54Q,+`H@("`@=&]K
M96Y?:60@("`@("`@("!605)#2$%2*#,R*2!.3U0@3E5,3"P*("`@('1O:V5N
M7W1I;65S=&%M<"`@0DE'24Y4($Y/5"!.54Q,+`H*("`@(%!224U!4ED@2T59
M("AT;VME;E]A9&1R97-S+"!T;VME;E]I9"D**3L*"D=204Y4(%-%3$5#5"P@
M24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]T;VME;G,@5$\@:&]R
M9&5`;&]C86QH;W-T.PH*0U)%051%(%1!0DQ%(&AO<F1E7W9F<R`H"B`@("!V
M9G-?:60@("`@("`@($))1TE.5"!.3U0@3E5,3"P*("`@('9F<U]T>7!E("`@
M("`@4TU!3$Q)3E0@3D]4($Y53$PL"B`@("!V9G-?<&%T:"`@("`@(%9!4D-(
M05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]N86UE("`@("`@5D%20TA!4B@R
M-34I($Y/5"!.54Q,+`H@("`@=F9S7VUO9&EF:65D("!"24=)3E0@3D]4($Y5
M3$PL"B`@("!V9G-?;W=N97(@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*
M("`@('9F<U]D871A("`@("`@3$].1T),3T(L"@H@("`@4%))34%262!+15D@
M*'9F<U]I9"D**3L*"D-214%412!)3D1%6"!V9G-?<&%T:%]I9'@@3TX@:&]R
M9&5?=F9S("AV9G-?<&%T:"D["D-214%412!)3D1%6"!V9G-?;F%M95]I9'@@
M3TX@:&]R9&5?=F9S("AV9G-?;F%M92D["@I'4D%.5"!314Q%0U0L($E.4T52
M5"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?=F9S(%1/(&AO<F1E0&QO8V%L
M:&]S=#L*"D-214%412!404),12!H;W)D95]H:7-T;W)I97,@*`H@("`@:&ES
M=&]R>5]I9"`@("`@("!"24=)3E0@3D]4($Y53$PL"B`@("!O8FIE8W1?=6ED
M("`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@(&AI<W1O<GE?86-T
M:6]N("`@5D%20TA!4B@S,BD@3D]4($Y53$PL"B`@("!H:7-T;W)Y7W1S("`@
M("`@($))1TE.5"!.3U0@3E5,3"P*("`@(&AI<W1O<GE?9&5S8R`@("`@5$58
M5"P*("`@(&AI<W1O<GE?=VAO("`@("`@5D%20TA!4B@R-34I+`H@("`@:&ES
M=&]R>5]E>'1R82`@("!415A4+`H*("`@(%!224U!4ED@2T59("AH:7-T;W)Y
M7VED*0HI.PH*0U)%051%($E.1$58(&AI<W1O<GE?86-T:6]N7VED>"!/3B!H
M;W)D95]H:7-T;W)I97,@*&AI<W1O<GE?86-T:6]N*3L*0U)%051%($E.1$58
M(&AI<W1O<GE?='-?:61X($].(&AO<F1E7VAI<W1O<FEE<R`H:&ES=&]R>5]T
M<RD["D-214%412!)3D1%6"!H:7-T;W)Y7W5I9%]I9'@@3TX@:&]R9&5?:&ES
M=&]R:65S("AO8FIE8W1?=6ED*3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!5
M4$1!5$4L($1%3$5412!/3B!H;W)D95]H:7-T;W)I97,@5$\@:&]R9&5`;&]C
M86QH;W-T.PH*0U)%051%(%1!0DQ%(&AO<F1E7W-E<W-I;VYH86YD;&5R("@*
M("`@('-E<W-I;VY?:60@("`@("`@("`@("`@5D%20TA!4B@S,BD@3D]4($Y5
M3$PL"B`@("!S97-S:6]N7VQA<W1M;V1I9FEE9"`@($E.5"!.3U0@3E5,3"P*
M("`@('-E<W-I;VY?9&%T82`@("`@("`@("`@3$].1T),3T(L"@H@("`@4%))
M34%262!+15D@*'-E<W-I;VY?:60I"BD@14Y'24Y%(#T@26YN;T1".PH*1U)!
M3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7W-E
M<W-I;VYH86YD;&5R(%1/(&AO<F1E0&QO8V%L:&]S=#L*"D9,55-((%!2259)
M3$5'15,["@HM+2!$;VYE(0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I
M<'1S+W-Q;"]C<F5A=&4N;V-I."YS<6P`````````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#$S,3`U`#$P-3$U-#,S-S4U`#`R,C<W,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!S970@9&]C(&]F9CL*
M<V5T('-Q;&)L86YK;&EN97,@;VX["@HO*BH*("H@3W)A8VQE(%1A8FQE($-R
M96%T:6]N(%-C<FEP=',N"B`J(`H@*B`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O
M<W%L+V-R96%T92YO8VDX+G-Q;"QV(#$N-"XX+C$P(#(P,#8O,#8O,CD@,38Z
M,CDZ,#,@:F%N($5X<"`D"B`J(`H@*B!`875T:&]R($UI9W5E;"!787)D(#QM
M=V%R9$!A;'5A<BYC;VTN87(^"B`J(`H@*B!4:&ES('-Q;"!C<F5A=&5S('1H
M92!(;W)D92!344P@=&%B;&5S(&EN(&%N($]R86-L92`X+G@@9&%T86)A<V4N
M(%-H;W5L9`H@*B!W;W)K('=I=&@@3W)A8VQE(#DN>"`H86YD($]R86-L93<@
M=7-I;F<@=F%R8VAA<C(I+@H@*B`*("H@3F]T97,Z"B`J(`H@*B`@*B!/8G9I
M;W5S;'D@>6]U(&UU<W0@:&%V92!/<F%C;&4@:6YS=&%L;&5D(&]N('1H:7,@
M;6%C:&EN92!!3D0@>6]U(&UU<W0*("H@("`@:&%V92!C;VUP:6QE9"!02%`@
M=VET:"!/<F%C;&4@*'EO=2!I;F-L=61E9"`M+7=I=&@M;V-I."UI;G-T86YT
M"B`J("`@("TM=VET:"UO8VDX(&]R(&EN('1H92!B=6EL9"!A<F=U;65N=',@
M9F]R(%!(4"P@;W(@=6YC;VUM96YT960@=&AE(&]C:3@*("H@("`@97AT96YS
M:6]N(&EN('!H<"YI;FDI+@H@*B`*("H@("H@268@>6]U(&1O;B=T('5S92!T
M:&4@26YS=&%N="!#;&EE;G0L(&UA:V4@<W5R92!T:&%T('1H92!U<V5R('1H
M870@<W1A<G1S"B`J("`@('5P($%P86-H92`H=7-U86QL>2!N;V)O9'D@;W(@
M=W=W+61A=&$I(&AA<R!T:&4@9F]L;&]W:6YG(&5N=FER;VYM96YT"B`J("`@
M('9A<FEA8FQE<R!D969I;F5D.@H@*B`*("H@("`@97AP;W)T($]204-,15](
M3TU%/2]H;VUE+V]R86-L92]/<F%(;VUE,0H@*B`@("!E>'!O<G0@3U)!7TY,
M4STO:&]M92]O<F%C;&4O3W)A2&]M93$O;V-O;6UO;B]N;',O861M:6XO9&%T
M80H@*B`@("!E>'!O<G0@3U)!7TY,4S,S/2]H;VUE+V]R86-L92]/<F%(;VUE
M,2]O8V]M;6]N+VYL<R]A9&UI;B]D871A"B`J("`@(&5X<&]R="!,1%],24)2
M05)97U!!5$@])$]204-,15](3TU%+VQI8CHD3$1?3$E"4D%265]0051("B`J
M(`H@*B`@("!93U4@35535"!#55-43TU)6D4@5$A%4T4@5D%,5453(%1/($)%
M($%04%)/4%))051%(%1/(%E/55(@24Y35$%,3$%424]."B`J(`H@*B`@("!9
M;W4@8V%N(&EN8VQU9&4@=&AE<V4@=F%R:6%B;&5S(&EN('1H92!U<V5R)W,@
M;&]C86P@+G!R;V9I;&4@;W(@:6X*("H@("`@+V5T8R]P<F]F:6QE+"!E=&,N
M"B`J(`H@*B`@*B!.;R!G<F%N=',@87)E(&YE8V5S<V%R>2!S:6YC92!W92!C
M;VYN96-T(&%S('1H92!O=VYE<B!O9B!T:&4@=&%B;&5S+B!)9@H@*B`@("!Y
M;W4@=VES:"!Y;W4@8V%N(&%D87!T('1H92!C<F5A=&EO;B!O9B!T86)L97,@
M=&\@:6YC;'5D92!T86)L97-P86-E(&%N9`H@*B`@("!S=&]R86=E(&EN9F]R
M;6%T:6]N+B!3:6YC92!W92!I;F-L=61E(&YO;F4@:70@=VEL;"!U<V4@=&AE
M(&1E9F%U;'0*("H@("`@=&%B;&5S<&%C92!V86QU97,@9F]R('1H92!U<V5R
M(&-R96%T:6YG('1H97-E('1A8FQE<RX@4V%M92!W:71H('1H90H@*B`@("!I
M;F1E>&5S("AI;B!T:&5O<GD@=&AE<V4@<VAO=6QD('5S92!A(&1I9F9E<F5N
M="!T86)L97-P86-E*2X*("H@"B`J("`J(%1H97)E(&ES(&YO(&YE960@=&\@
M<VAU="!D;W=N(&%N9"!S=&%R="!U<"!T:&4@9&%T86)A<V4A"B`J+PH*<F5M
M(&-O;FX@:&]R9&4O)FAO<F1E7W!A<W-W;W)D0&1A=&%B87-E"@HO*BH*("H@
M5&AI<R!I<R!T:&4@2&]R9&4@=7-E<G,@=&%B;&4L(&YE961E9"!O;FQY(&EF
M('EO=2!A<F4@=7-I;F<@4U%,"B`J(&%U=&AE;G1I8V%T:6]N+B`@3F]T92!T
M:&%T('!A<W-O=W)D<R!I;B!T:&ES('1A8FQE(&YE960@=&\@8F4@;60U+65N
M8V]D960N"B`J+PH*0U)%051%(%1!0DQ%(&AO<F1E7W5S97)S("@*("`@('5S
M97)?=6ED("`@("`@("`@("`@("`@("`@("!605)#2$%2,B@R-34I($Y/5"!.
M54Q,+`H@("`@=7-E<E]P87-S("`@("`@("`@("`@("`@("`@(%9!4D-(05(R
M*#(U-2D@3D]4($Y53$PL"B`@("!U<V5R7W-O9G1?97AP:7)A=&EO;E]D871E
M("`@3E5-0D52*#$V*2P*("`@('5S97)?:&%R9%]E>'!I<F%T:6]N7V1A=&4@
M("!.54U"15(H,38I+`H*("`@(%!224U!4ED@2T59("AU<V5R7W5I9"D**3L*
M"@HO*BH*("H@5&AI<R!I<R!T:&4@2&]R9&4@<')E9F5R96YC97,@=&%B;&4L
M(&AO;&1I;F<@86QL(&]F('1H92!U<V5R+7-P96-I9FEC"B`J(&]P=&EO;G,@
M9F]R(&5V97)Y($AO<F1E('5S97(N"B`J(`H@*B!P<F5F7W5I9"`@(&ES('1H
M92!U<V5R;F%M92X*("H@<')E9E]S8V]P92!I<R!T:&4@87!P;&EC871I;VX@
M=&AE('!R968@8F5L;VYG<R!T;RX*("H@<')E9E]N86UE("!I<R!T:&4@;F%M
M92!O9B!T:&4@=F%R:6%B;&4@=&\@<V%V92X*("H@<')E9E]V86QU92!I<R!T
M:&4@=F%L=64@<V%V960@*&-A;B!B92!V97)Y(&QO;F<I+@H@*B`*("H@5V4@
M=7-E(&$@0TQ/0B!C;VQU;6X@<V\@=&AA="!L;VYG97(@8V]L=6UN('9A;'5E
M<R!A<F4@<W5P<&]R=&5D+@H@*B`*("H@268@<W1I;&P@=7-I;F<@3W)A8VQE
M(#<@=&AI<R!S:&]U;&0@=V]R:R!B=70@>6]U(&AA=F4@=&\@=7-E"B`J(%9!
M4D-(05(R*#(P,#`I('=H:6-H(&ES('1H92!L:6UI="!I;7!O<V5D(&)Y('-A
M:60@=F5R<VEO;BX*("HO"@I#4D5!5$4@5$%"3$4@:&]R9&5?<')E9G,@*`H@
M("`@<')E9E]U:60@("`@5D%20TA!4C(H,C4U*2!.3U0@3E5,3"P*("`@('!R
M969?<V-O<&4@(%9!4D-(05(R*#$V*2!.3U0@3E5,3"P*("`@('!R969?;F%M
M92`@(%9!4D-(05(R*#,R*2!.3U0@3E5,3"P*+2T@(%-E92!A8F]V92!N;W1E
M<R!O;B!#3$]"<RX*("`@('!R969?=F%L=64@($-,3T(L"@H@("`@4%))34%2
M62!+15D@*'!R969?=6ED+"!P<F5F7W-C;W!E+"!P<F5F7VYA;64I"BD["@I#
M4D5!5$4@24Y$15@@<')E9E]U:61?:61X($].(&AO<F1E7W!R969S("AP<F5F
M7W5I9"D["D-214%412!)3D1%6"!P<F5F7W-C;W!E7VED>"!/3B!H;W)D95]P
M<F5F<R`H<')E9E]S8V]P92D["@H*+RHJ"B`J(%1H92!$871A5')E92!T86)L
M97,@87)E('5S960@9F]R(&AO;&1I;F<@:&EE<F%R8VAI8V%L(&1A=&$@<W5C
M:"!A<R!'<F]U<',L"B`J(%!E<FUI<W-I;VYS+"!A;F0@9&%T82!F;W(@<V]M
M92!(;W)D92!A<'!L:6-A=&EO;G,N"B`J+PH*0U)%051%(%1!0DQ%(&AO<F1E
M7V1A=&%T<F5E("@*("`@(&1A=&%T<F5E7VED("`@("`@("`@($Y534)%4B@Q
M-BD@3D]4($Y53$PL"B`@("!G<F]U<%]U:60@("`@("`@("`@("!605)#2$%2
M,B@R-34I($Y/5"!.54Q,+`H@("`@=7-E<E]U:60@("`@("`@("`@("`@5D%2
M0TA!4C(H,C4U*2P*("`@(&1A=&%T<F5E7VYA;64@("`@("`@(%9!4D-(05(R
M*#(U-2D@3D]4($Y53$PL"B`@("!D871A=')E95]P87)E;G1S("`@("!605)#
M2$%2,B@R-34I+`H@("`@9&%T871R965?;W)D97(@("`@("`@3E5-0D52*#$V
M*2P*("`@(&1A=&%T<F5E7V1A=&$@("`@("`@($-,3T(L"B`@("!D871A=')E
M95]S97)I86QI>F5D("!.54U"15(H."D@1$5&055,5"`P($Y/5"!.54Q,+`H*
M("`@(%!224U!4ED@2T59("AD871A=')E95]I9"D**3L*"D-214%412!)3D1%
M6"!D871A=')E95]D871A=')E95]N86UE7VED>"!/3B!H;W)D95]D871A=')E
M92`H9&%T871R965?;F%M92D["D-214%412!)3D1%6"!D871A=')E95]G<F]U
M<%]I9'@@3TX@:&]R9&5?9&%T871R964@*&=R;W5P7W5I9"D["D-214%412!)
M3D1%6"!D871A=')E95]U<V5R7VED>"!/3B!H;W)D95]D871A=')E92`H=7-E
M<E]U:60I.PI#4D5!5$4@24Y$15@@9&%T871R965?;W)D97)?:61X($].(&AO
M<F1E7V1A=&%T<F5E("AD871A=')E95]O<F1E<BD["D-214%412!)3D1%6"!D
M871A=')E95]S97)I86QI>F5D7VED>"!/3B!H;W)D95]D871A=')E92`H9&%T
M871R965?<V5R:6%L:7IE9"D["@I#4D5!5$4@5$%"3$4@:&]R9&5?9&%T871R
M965?871T<FEB=71E<R`H"B`@("!D871A=')E95]I9"`@("`@($Y534)%4B@Q
M-BD@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?;F%M92`@(%9!4D-(05(R*#(U
M-2D@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?:V5Y("`@(%9!4D-(05(R*#(U
M-2DL"B`@("!A='1R:6)U=&5?=F%L=64@(%9!4D-(05(R*#0P,#`I"BD["@I#
M4D5!5$4@24Y$15@@9&%T871R965?871T<FEB=71E7VED>"!/3B!H;W)D95]D
M871A=')E95]A='1R:6)U=&5S("AD871A=')E95]I9"D["D-214%412!)3D1%
M6"!D871A=')E95]A='1R:6)U=&5?;F%M95]I9'@@3TX@:&]R9&5?9&%T871R
M965?871T<FEB=71E<R`H871T<FEB=71E7VYA;64I.PI#4D5!5$4@24Y$15@@
M9&%T871R965?871T<FEB=71E7VME>5]I9'@@3TX@:&]R9&5?9&%T871R965?
M871T<FEB=71E<R`H871T<FEB=71E7VME>2D["@H*0U)%051%(%1!0DQ%(&AO
M<F1E7W1O:V5N<R`H"B`@("!T;VME;E]A9&1R97-S("`@(%9!4D-(05(R*#$P
M,"D@3D]4($Y53$PL"B`@("!T;VME;E]I9"`@("`@("`@(%9!4D-(05(R*#,R
M*2!.3U0@3E5,3"P*("`@('1O:V5N7W1I;65S=&%M<"`@3E5-0D52*#$V*2!.
M3U0@3E5,3"P*"B`@("!04DE-05)9($M%62`H=&]K96Y?861D<F5S<RP@=&]K
M96Y?:60I"BD["@H*0U)%051%(%1!0DQ%(&AO<F1E7W9F<R`H"B`@("!V9G-?
M:60@("`@("`@($Y534)%4B@Q-BD@3D]4($Y53$PL"B`@("!V9G-?='EP92`@
M("`@($Y534)%4B@X*2!.3U0@3E5,3"P*("`@('9F<U]P871H("`@("`@5D%2
M0TA!4C(H,C4U*2P*("`@('9F<U]N86UE("`@("`@5D%20TA!4C(H,C4U*2!.
M3U0@3E5,3"P*("`@('9F<U]M;V1I9FEE9"`@3E5-0D52*#$V*2!.3U0@3E5,
M3"P*("`@('9F<U]O=VYE<B`@("`@5D%20TA!4C(H,C4U*2P*("`@('9F<U]D
M871A("`@("`@0DQ/0BP*"B`@("!04DE-05)9($M%62`@("AV9G-?:60I"BD[
M"@I#4D5!5$4@24Y$15@@=F9S7W!A=&A?:61X($].(&AO<F1E7W9F<R`H=F9S
M7W!A=&@I.PI#4D5!5$4@24Y$15@@=F9S7VYA;65?:61X($].(&AO<F1E7W9F
M<R`H=F9S7VYA;64I.PH*"D-214%412!404),12!H;W)D95]H:7-T;W)I97,@
M*`H@("`@:&ES=&]R>5]I9"`@("`@("!.54U"15(H,38I($Y/5"!.54Q,+`H@
M("`@;V)J96-T7W5I9"`@("`@("!605)#2$%2,B@R-34I($Y/5"!.54Q,+`H@
M("`@:&ES=&]R>5]A8W1I;VX@("!605)#2$%2,B@S,BD@3D]4($Y53$PL"B`@
M("!H:7-T;W)Y7W1S("`@("`@($Y534)%4B@Q-BD@3D]4($Y53$PL"B`@("!H
M:7-T;W)Y7V1E<V,@("`@($-,3T(L"B`@("!H:7-T;W)Y7W=H;R`@("`@(%9!
M4D-(05(R*#(U-2DL"B`@("!H:7-T;W)Y7V5X=')A("`@($-,3T(L"@H@("`@
M4%))34%262!+15D@*&AI<W1O<GE?:60I"BD["@I#4D5!5$4@24Y$15@@:&ES
M=&]R>5]A8W1I;VY?:61X($].(&AO<F1E7VAI<W1O<FEE<R`H:&ES=&]R>5]A
M8W1I;VXI.PI#4D5!5$4@24Y$15@@:&ES=&]R>5]T<U]I9'@@3TX@:&]R9&5?
M:&ES=&]R:65S("AH:7-T;W)Y7W1S*3L*0U)%051%($E.1$58(&AI<W1O<GE?
M=6ED7VED>"!/3B!H;W)D95]H:7-T;W)I97,@*&]B:F5C=%]U:60I.PH*"D-2
M14%412!404),12!H;W)D95]S97-S:6]N:&%N9&QE<B`H"B`@("!S97-S:6]N
M7VED("`@("`@("`@("`@(%9!4D-(05(R*#,R*2!.3U0@3E5,3"P*("`@('-E
M<W-I;VY?;&%S=&UO9&EF:65D("`@24Y4($Y/5"!.54Q,+`H@("`@<V5S<VEO
M;E]D871A("`@("`@("`@("!"3$]"+`H*("`@(%!224U!4ED@2T59("AS97-S
M:6]N7VED*0HI.PH*"F5X:70*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O
M<W%L+V-R96%T92YP9W-Q;"YS<6P`````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#<U,#4`,3`U,34T,S,W-34`,#(S,C8V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"TM("1(;W)D93H@:&]R9&4O
M<V-R:7!T<R]S<6PO8W)E871E+G!G<W%L+G-Q;"QV(#$N,2XQ,"XU(#(P,#8O
M,#@O,#0@,C`Z-#DZ-#,@:F%N($5X<"`D"BTM"BTM(%5N8V]M;65N="!T:&4@
M04Q415(@;&EN92!B96QO=RP@86YD(&-H86YG92!T:&4@<&%S<W=O<F0N("!4
M:&5N(')U;B!A<SH*+2T*+2T@)"!P<W%L("UD('1E;7!L871E,2`M9B!C<F5A
M=&4N<&=S<6PN<W%L"@I#4D5!5$4@1$%404)!4T4@:&]R9&4["@I<8R!H;W)D
M93L*"D-214%412!54T52(&AO<F1E.PH*+2T@04Q415(@55-%4B!H;W)D92!7
M251((%!!4U-73U)$("=P87-S)SL*"@I#4D5!5$4@5$%"3$4@:&]R9&5?=7-E
M<G,@*`H@("`@=7-E<E]U:60@("`@("`@("`@("`@("`@("`@(%9!4D-(05(H
M,C4U*2!.3U0@3E5,3"P*("`@('5S97)?<&%S<R`@("`@("`@("`@("`@("`@
M("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!U<V5R7W-O9G1?97AP:7)A
M=&EO;E]D871E("`@24Y414=%4BP*("`@('5S97)?:&%R9%]E>'!I<F%T:6]N
M7V1A=&4@("!)3E1%1T52+`HM+0H@("`@4%))34%262!+15D@*'5S97)?=6ED
M*0HI.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].
M(&AO<F1E7W5S97)S(%1/(&AO<F1E.PH*"D-214%412!404),12!H;W)D95]P
M<F5F<R`H"B`@("!P<F5F7W5I9"`@("`@("`@5D%20TA!4B@R-34I($Y/5"!.
M54Q,+`H@("`@<')E9E]S8V]P92`@("`@(%9!4D-(05(H,38I($1%1D%53%0@
M)R<@3D]4($Y53$PL"B`@("!P<F5F7VYA;64@("`@("`@5D%20TA!4B@S,BD@
M3D]4($Y53$PL"B`@("!P<F5F7W9A;'5E("`@("`@5$585"P*+2T*("`@(%!2
M24U!4ED@2T59("AP<F5F7W5I9"P@<')E9E]S8V]P92P@<')E9E]N86UE*0HI
M.PH*0U)%051%($E.1$58('!R969?=6ED7VED>"!/3B!H;W)D95]P<F5F<R`H
M<')E9E]U:60I.PI#4D5!5$4@24Y$15@@<')E9E]S8V]P95]I9'@@3TX@:&]R
M9&5?<')E9G,@*'!R969?<V-O<&4I.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L
M(%501$%412P@1$5,151%($].(&AO<F1E7W!R969S(%1/(&AO<F1E.PH*"D-2
M14%412!404),12!H;W)D95]D871A=')E92`H"B`@("!D871A=')E95]I9"!)
M3E0@3D]4($Y53$PL"B`@("!G<F]U<%]U:60@5D%20TA!4B@R-34I($Y/5"!.
M54Q,+`H@("`@=7-E<E]U:60@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@
M9&%T871R965?;F%M92!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!D871A
M=')E95]P87)E;G1S(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@(&1A=&%T
M<F5E7V]R9&5R($E.5"P*("`@(&1A=&%T<F5E7V1A=&$@5$585"P*("`@(&1A
M=&%T<F5E7W-E<FEA;&EZ960@4TU!3$Q)3E0@1$5&055,5"`P($Y/5"!.54Q,
M+`H*("`@(%!224U!4ED@2T59("AD871A=')E95]I9"D**3L*"D-214%412!)
M3D1%6"!D871A=')E95]D871A=')E95]N86UE7VED>"!/3B!H;W)D95]D871A
M=')E92`H9&%T871R965?;F%M92D["D-214%412!)3D1%6"!D871A=')E95]G
M<F]U<%]I9'@@3TX@:&]R9&5?9&%T871R964@*&=R;W5P7W5I9"D["D-214%4
M12!)3D1%6"!D871A=')E95]U<V5R7VED>"!/3B!H;W)D95]D871A=')E92`H
M=7-E<E]U:60I.PI#4D5!5$4@24Y$15@@9&%T871R965?;W)D97)?:61X($].
M(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]O<F1E<BD["D-214%412!)3D1%
M6"!D871A=')E95]S97)I86QI>F5D7VED>"!/3B!H;W)D95]D871A=')E92`H
M9&%T871R965?<V5R:6%L:7IE9"D["@H*0U)%051%(%1!0DQ%(&AO<F1E7V1A
M=&%T<F5E7V%T=')I8G5T97,@*`H@("`@9&%T871R965?:60@24Y4($Y/5"!.
M54Q,+`H@("`@871T<FEB=71E7VYA;64@5D%20TA!4B@R-34I($Y/5"!.54Q,
M+`H@("`@871T<FEB=71E7VME>2!605)#2$%2*#(U-2DL"B`@("!A='1R:6)U
M=&5?=F%L=64@5$585`HI.PH*0U)%051%($E.1$58(&1A=&%T<F5E7V%T=')I
M8G5T95]I9'@@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H9&%T871R
M965?:60I.PI#4D5!5$4@24Y$15@@9&%T871R965?871T<FEB=71E7VYA;65?
M:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&%T=')I8G5T95]N
M86UE*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V%T=')I8G5T95]K97E?:61X
M($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&%T=')I8G5T95]K97DI
M.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO
M<F1E7V1A=&%T<F5E(%1/(&AO<F1E.PI'4D%.5"!314Q%0U0L($E.4T525"P@
M55!$051%+"!$14Q%5$4@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R!4
M3R!H;W)D93L*"@I#4D5!5$4@5$%"3$4@:&]R9&5?=&]K96YS("@*("`@('1O
M:V5N7V%D9')E<W,@("`@5D%20TA!4B@Q,#`I($Y/5"!.54Q,+`H@("`@=&]K
M96Y?:60@("`@("`@("!605)#2$%2*#,R*2!.3U0@3E5,3"P*("`@('1O:V5N
M7W1I;65S=&%M<"`@0DE'24Y4($Y/5"!.54Q,+`HM+0H@("`@4%))34%262!+
M15D@*'1O:V5N7V%D9')E<W,L('1O:V5N7VED*0HI.PH*1U)!3E0@4T5,14-4
M+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7W1O:V5N<R!43R!H
M;W)D93L*"@I#4D5!5$4@5$%"3$4@:&]R9&5?=F9S("@*("`@('9F<U]I9"`@
M("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@("`@=F9S7W1Y<&4@("`@("!334%,
M3$E.5"!.3U0@3E5,3"P*("`@('9F<U]P871H("`@("`@5D%20TA!4B@R-34I
M($Y/5"!.54Q,+`H@("`@=F9S7VYA;64@("`@("!605)#2$%2*#(U-2D@3D]4
M($Y53$PL"B`@("!V9G-?;6]D:69I960@($))1TE.5"!.3U0@3E5,3"P*("`@
M('9F<U]O=VYE<B`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S
M7V1A=&$@("`@("!415A4+`H*("`@(%!224U!4ED@2T59("`@*'9F<U]I9"D*
M*3L*"D-214%412!)3D1%6"!V9G-?<&%T:%]I9'@@3TX@:&]R9&5?=F9S("AV
M9G-?<&%T:"D["D-214%412!)3D1%6"!V9G-?;F%M95]I9'@@3TX@:&]R9&5?
M=F9S("AV9G-?;F%M92D["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%
M+"!$14Q%5$4@3TX@:&]R9&5?=F9S(%1/(&AO<F1E.PH*"D-214%412!404),
M12!H;W)D95]S97-S:6]N:&%N9&QE<B`H"B`@("!S97-S:6]N7VED("`@("`@
M("`@("`@(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@<V5S<VEO;E]L87-T
M;6]D:69I960@("!)3E0@3D]4($Y53$PL"B`@("!S97-S:6]N7V1A=&$@("`@
M("`@("`@(%1%6%0L"B`@("!04DE-05)9($M%62`H<V5S<VEO;E]I9"D**3L*
M"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D
M95]S97-S:6]N:&%N9&QE<B!43R!H;W)D93L*"@I#4D5!5$4@5$%"3$4@:&]R
M9&5?:&ES=&]R:65S("@*("`@(&AI<W1O<GE?:60@("`@("`@0DE'24Y4($Y/
M5"!.54Q,+`H@("`@;V)J96-T7W5I9"`@("`@("!605)#2$%2*#(U-2D@3D]4
M($Y53$PL"B`@("!H:7-T;W)Y7V%C=&EO;B`@(%9!4D-(05(H,S(I($Y/5"!.
M54Q,+`H@("`@:&ES=&]R>5]T<R`@("`@("!"24=)3E0@3D]4($Y53$PL"B`@
M("!H:7-T;W)Y7V1E<V,@("`@(%1%6%0L"B`@("!H:7-T;W)Y7W=H;R`@("`@
M(%9!4D-(05(H,C4U*2P*("`@(&AI<W1O<GE?97AT<F$@("`@5$585"P*+2T*
M("`@(%!224U!4ED@2T59("AH:7-T;W)Y7VED*0HI.PH*0U)%051%($E.1$58
M(&AI<W1O<GE?86-T:6]N7VED>"!/3B!H;W)D95]H:7-T;W)I97,@*&AI<W1O
M<GE?86-T:6]N*3L*0U)%051%($E.1$58(&AI<W1O<GE?='-?:61X($].(&AO
M<F1E7VAI<W1O<FEE<R`H:&ES=&]R>5]T<RD["D-214%412!)3D1%6"!H:7-T
M;W)Y7W5I9%]I9'@@3TX@:&]R9&5?:&ES=&]R:65S("AO8FIE8W1?=6ED*3L*
M"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D
M95]H:7-T;W)I97,@5$\@:&]R9&4["@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W-C<FEP=',O<W%L+V-R96%T92YS<6P`````````````````
M````````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<T-C<`,3`U,34T,S,W-34`,#(R
M,34P`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"TM("1(;W)D93H@:&]R9&4O<V-R:7!T<R]S<6PO8W)E871E+G-Q;"QV(#$N
M,2XR+C,@,C`P-B\P-2\R,B`R,3HR-SHS,R!J86X@17AP("0*"D-214%412!4
M04),12!H;W)D95]U<V5R<R`H"B`@("!U<V5R7W5I9"`@("`@("`@("`@("`@
M("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=7-E<E]P87-S("`@
M("`@("`@("`@("`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('5S
M97)?<V]F=%]E>'!I<F%T:6]N7V1A=&4@("!)3E1%1T52+`H@("`@=7-E<E]H
M87)D7V5X<&ER871I;VY?9&%T92`@($E.5$5'15(L"BTM"B`@("!04DE-05)9
M($M%62`H=7-E<E]U:60I"BD["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$
M051%+"!$14Q%5$4@3TX@:&]R9&5?=7-E<G,@5$\@:&]R9&4["@H*0U)%051%
M(%1!0DQ%(&AO<F1E7W!R969S("@*("`@('!R969?=6ED("`@("`@("!605)#
M2$%2*#(U-2D@3D]4($Y53$PL"B`@("!P<F5F7W-C;W!E("`@("`@5D%20TA!
M4B@Q-BD@1$5&055,5"`G)R!.3U0@3E5,3"P*("`@('!R969?;F%M92`@("`@
M("!605)#2$%2*#,R*2!.3U0@3E5,3"P*("`@('!R969?=F%L=64@("`@("!4
M15A4+`HM+0H@("`@4%))34%262!+15D@*'!R969?=6ED+"!P<F5F7W-C;W!E
M+"!P<F5F7VYA;64I"BD["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%
M+"!$14Q%5$4@3TX@:&]R9&5?<')E9G,@5$\@:&]R9&4["@H*0U)%051%(%1!
M0DQ%(&AO<F1E7V1A=&%T<F5E("@*("`@(&1A=&%T<F5E7VED($E.5"!.3U0@
M3E5,3"P*("`@(&=R;W5P7W5I9"!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@
M("!U<V5R7W5I9"!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!D871A=')E
M95]N86UE(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@(&1A=&%T<F5E7W!A
M<F5N=',@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@9&%T871R965?;W)D
M97(@24Y4+`H*+2T@5&AE<F4@:7,@;F\@<&]R=&%B;&4@=V%Y('1O(&1O('1H
M:7,@87!P87)E;G1L>2X@268@>6]U<B!D8B!D;V5S;B=T"BTM(&%L;&]W(%1%
M6%0@8V]L=6UN<RP@=&AE;B!M87EB92!I="!A;&QO=W,@;&%R9V4@5D%20TA!
M4B!C;VQU;6YS+"!S;PHM+2!T<GD@=&AE('-E8V]N9"!L:6YE+@HM+0H@("`@
M9&%T871R965?9&%T82!415A4+`HM+2`@9&%T871R965?9&%T82!605)#2$%2
M*#0P.38I+`H*("`@(&1A=&%T<F5E7W-E<FEA;&EZ960@4TU!3$Q)3E0@1$5&
M055,5"`P($Y/5"!.54Q,+`H*("`@(%!224U!4ED@2T59("AD871A=')E95]I
M9"D**3L*"D-214%412!)3D1%6"!D871A=')E95]D871A=')E95]N86UE7VED
M>"!/3B!H;W)D95]D871A=')E92`H9&%T871R965?;F%M92D["D-214%412!)
M3D1%6"!D871A=')E95]G<F]U<%]I9'@@3TX@:&]R9&5?9&%T871R964@*&=R
M;W5P7W5I9"D["D-214%412!)3D1%6"!D871A=')E95]U<V5R7VED>"!/3B!H
M;W)D95]D871A=')E92`H=7-E<E]U:60I.PI#4D5!5$4@24Y$15@@9&%T871R
M965?;W)D97)?:61X($].(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]O<F1E
M<BD["D-214%412!)3D1%6"!D871A=')E95]S97)I86QI>F5D7VED>"!/3B!H
M;W)D95]D871A=')E92`H9&%T871R965?<V5R:6%L:7IE9"D["@I#4D5!5$4@
M5$%"3$4@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H"B`@("!D871A=')E
M95]I9"!)3E0@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?;F%M92!605)#2$%2
M*#(U-2D@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?:V5Y(%9!4D-(05(H,C4U
M*2P*("`@(&%T=')I8G5T95]V86QU92!415A4"BD["@I#4D5!5$4@24Y$15@@
M9&%T871R965?871T<FEB=71E7VED>"!/3B!H;W)D95]D871A=')E95]A='1R
M:6)U=&5S("AD871A=')E95]I9"D["D-214%412!)3D1%6"!D871A=')E95]A
M='1R:6)U=&5?;F%M95]I9'@@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E
M<R`H871T<FEB=71E7VYA;64I.PI#4D5!5$4@24Y$15@@9&%T871R965?871T
M<FEB=71E7VME>5]I9'@@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H
M871T<FEB=71E7VME>2D["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%
M+"!$14Q%5$4@3TX@:&]R9&5?9&%T871R964@5$\@:&]R9&4["D=204Y4(%-%
M3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]D871A=')E
M95]A='1R:6)U=&5S(%1/(&AO<F1E.PH*"D-214%412!404),12!H;W)D95]T
M;VME;G,@*`H@("`@=&]K96Y?861D<F5S<R`@("!605)#2$%2*#$P,"D@3D]4
M($Y53$PL"B`@("!T;VME;E]I9"`@("`@("`@(%9!4D-(05(H,S(I($Y/5"!.
M54Q,+`H@("`@=&]K96Y?=&EM97-T86UP("!"24=)3E0@3D]4($Y53$PL"BTM
M"B`@("!04DE-05)9($M%62`H=&]K96Y?861D<F5S<RP@=&]K96Y?:60I"BD[
M"@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R
M9&5?=&]K96YS(%1/(&AO<F1E.PH*"D-214%412!404),12!H;W)D95]V9G,@
M*`H@("`@=F9S7VED("`@("`@("!"24=)3E0@3D]4($Y53$PL"B`@("!V9G-?
M='EP92`@("`@(%--04Q,24Y4($Y/5"!.54Q,+`H@("`@=F9S7W!A=&@@("`@
M("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;F%M92`@("`@(%9!
M4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]M;V1I9FEE9"`@0DE'24Y4
M($Y/5"!.54Q,+`H@("`@=F9S7V]W;F5R("`@("!605)#2$%2*#(U-2D@3D]4
M($Y53$PL"B`@("!V9G-?9&%T82`@("`@($Q/3D="3$]"+`HM+2!/<BP@;VX@
M<V]M92!$0DU3('-Y<W1E;7,Z"BTM("!V9G-?9&%T82`@("`@($E-04=%+`H@
M("`@4%))34%262!+15D@("`H=F9S7VED*0HI.PH*0U)%051%($E.1$58('9F
M<U]P871H7VED>"!/3B!H;W)D95]V9G,@*'9F<U]P871H*3L*0U)%051%($E.
M1$58('9F<U]N86UE7VED>"!/3B!H;W)D95]V9G,@*'9F<U]N86UE*3L*"D=2
M04Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]V
M9G,@5$\@:&]R9&4["@H*0U)%051%(%1!0DQ%(&AO<F1E7VAI<W1O<FEE<R`H
M"B`@("!H:7-T;W)Y7VED("`@("`@($))1TE.5"!.3U0@3E5,3"P*("`@(&]B
M:F5C=%]U:60@("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@:&ES
M=&]R>5]A8W1I;VX@("!605)#2$%2*#,R*2!.3U0@3E5,3"P*("`@(&AI<W1O
M<GE?=',@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]D97-C
M("`@("!415A4+`H@("`@:&ES=&]R>5]W:&\@("`@("!605)#2$%2*#(U-2DL
M"B`@("!H:7-T;W)Y7V5X=')A("`@(%1%6%0L"BTM"B`@("!04DE-05)9($M%
M62`H:&ES=&]R>5]I9"D**3L*"D-214%412!)3D1%6"!H:7-T;W)Y7V%C=&EO
M;E]I9'@@3TX@:&]R9&5?:&ES=&]R:65S("AH:7-T;W)Y7V%C=&EO;BD["D-2
M14%412!)3D1%6"!H:7-T;W)Y7W1S7VED>"!/3B!H;W)D95]H:7-T;W)I97,@
M*&AI<W1O<GE?=',I.PI#4D5!5$4@24Y$15@@:&ES=&]R>5]U:61?:61X($].
M(&AO<F1E7VAI<W1O<FEE<R`H;V)J96-T7W5I9"D["@I'4D%.5"!314Q%0U0L
M($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?:&ES=&]R:65S(%1/
M(&AO<F1E.PH*"D-214%412!404),12!H;W)D95]S97-S:6]N:&%N9&QE<B`H
M"B`@("!S97-S:6]N7VED("`@("`@("`@("`@(%9!4D-(05(H,S(I($Y/5"!.
M54Q,+`H@("`@<V5S<VEO;E]L87-T;6]D:69I960@("!)3E0@3D]4($Y53$PL
M"B`@("!S97-S:6]N7V1A=&$@("`@("`@("`@($Q/3D="3$]"+`HM+2!/<BP@
M;VX@<V]M92!$0DU3('-Y<W1E;7,Z"BTM("!S97-S:6]N7V1A=&$@("`@("`@
M("`@($E-04=%+`H*("`@(%!224U!4ED@2T59("AS97-S:6]N7VED*0HI.PH*
M1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E
M7W-E<W-I;VYH86YD;&5R(%1/(&AO<F1E.PH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+V-R96%T
M92YS>6)A<V4N<W%L````````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3`Q
M-3<`,3`U,34T,S,W-34`,#(S-#(S`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"TM("1(;W)D93H@:&]R9&4O<V-R:7!T<R]S
M<6PO8W)E871E+G-Y8F%S92YS<6PL=B`Q+C$N,3`N-2`R,#`V+S`V+S(Y(#$V
M.C(Y.C`S(&IA;B!%>'`@)`HM+0HM+2!H;W)D92!T86)L97,@9&5F:6YI=&EO
M;G,@.B!S<6P@<V-R:7!T"BTM(#`Q+S(R+S(P,#,@+2!&+B!(96QL>2`\9G)A
M;F-O:7,N:&5L;'E`=V%N861O;RYF<CX*+2T@8V]M;6%N9"!L:6YE('-Y;G1A
M>"`Z("!I<W%L("UI:&]R9&5?<WEB87-E+G-Q;`HM+2!W87)N:6YG(#H@=7-E
M(&YV87)C:&%R(&]N;'D@:68@>6]U(&YE960@=6YI8V]D92!E;F-O9&EN9R!F
M;W(@<V]M92!S=')I;F=S"@IU<V4@:&]R9&4*9V\*"@I$4D]0(%1!0DQ%(&AO
M<F1E7V1A=&%T<F5E"F=O"@I$4D]0(%1!0DQ%(&AO<F1E7W!R969S"F=O"@I$
M4D]0(%1!0DQ%(&AO<F1E7W5S97)S"F=O"@I$4D]0(%1!0DQ%(&AO<F1E7W-E
M<W-I;VYH86YD;&5R"F=O"@HM+2!$4D]0(%1!0DQ%(&AO<F1E7V1A=&%T<F5E
M7W-E<0HM+2!G;PH*+2T@1%)/4"!404),12!H;W)D95]T;VME;G,*+2T@9V\*
M"BTM($123U`@5$%"3$4@:&]R9&5?=F9S"BTM(&=O"@HM+2!$4D]0(%1!0DQ%
M(&AO<F1E7VUU=F9S"BTM(&=O"@H*0U)%051%(%1!0DQ%(&AO<F1E7W5S97)S
M("@*("!U<V5R7W5I9"!V87)C:&%R*#(U-BD@3D]4($Y53$PL"B`@=7-E<E]P
M87-S('9A<F-H87(H,C4V*2!.3U0@3E5,3"P*("!U<V5R7W-O9G1?97AP:7)A
M=&EO;E]D871E(&YU;65R:6,H,3`L,"DL"B`@=7-E<E]H87)D7V5X<&ER871I
M;VY?9&%T92!N=6UE<FEC*#$P+#`I+`H@(%!224U!4ED@2T59("`H=7-E<E]U
M:60I"BD*9V\*"D-214%412!404),12!H;W)D95]D871A=')E92`H"B`@9&%T
M871R965?:60@;G5M97)I8R@Q,2PP*2!)1$5.5$E462!.3U0@3E5,3"P*("!G
M<F]U<%]U:60@=F%R8VAA<B@R-38I($Y/5"!.54Q,+`H@('5S97)?=6ED('9A
M<F-H87(H,C4V*2!.3U0@3E5,3"P*("!D871A=')E95]N86UE('9A<F-H87(H
M,C4V*2!.3U0@3E5,3"P*("!D871A=')E95]P87)E;G1S('9A<F-H87(H,C4V
M*2!.54Q,+`H@(&1A=&%T<F5E7V1A=&$@=&5X="!.54Q,+`H@(&1A=&%T<F5E
M7W-E<FEA;&EZ960@<VUA;&QI;G0@1$5&055,5"`P($Y/5"!.54Q,+`H@(%!2
M24U!4ED@2T59("`H9&%T871R965?:60I+`H@($9/4D5)1TX@2T59("AU<V5R
M7W5I9"D*("`@(%)%1D5214Y#15,@:&]R9&5?=7-E<G,H=7-E<E]U:60I"B`I
M"F=O"@I#4D5!5$4@5$%"3$4@:&]R9&5?<')E9G,@*`H@('!R969?=6ED('9A
M<F-H87(H,C4V*2!.3U0@3E5,3"P*("!P<F5F7W-C;W!E('9A<F-H87(H,38I
M($Y/5"!.54Q,+`H@('!R969?;F%M92!V87)C:&%R*#,R*2!.3U0@3E5,3"P*
M("!P<F5F7W9A;'5E('1E>'0@3E5,3"P*("!04DE-05)9($M%62`@*'!R969?
M=6ED+'!R969?<V-O<&4L<')E9E]N86UE*0HI"F=O"@I#4D5!5$4@5$%"3$4@
M:&]R9&5?<V5S<VEO;FAA;F1L97(@*`H@('-E<W-I;VY?:60@=F%R8VAA<B@S
M,BD@3D]4($Y53$PL"B`@<V5S<VEO;E]L87-T;6]D:69I960@;G5M97)I8R@Q
M,2PP*2!.3U0@3E5,3"P*("!S97-S:6]N7V1A=&$@:6UA9V4@3E5,3"P*("!0
M4DE-05)9($M%62`@*'-E<W-I;VY?:60I"BD*9V\*"@HM+2!#4D5!5$4@5$%"
M3$4@:&]R9&5?9&%T871R965?<V5Q("@*+2T@("!I9"!N=6UE<FEC*#$P+#`I
M($E$14Y42519($Y/5"!.54Q,+`HM+2`@(%!224U!4ED@2T59("`H:60I"BTM
M("D*+2T@9V\*"BTM($-214%412!404),12!H;W)D95]T;VME;G,@*`HM+2`@
M('1O:V5N7V%D9')E<W,@=F%R8VAA<B@Q,#`I($Y/5"!.54Q,+`HM+2`@('1O
M:V5N7VED('9A<F-H87(H,S(I($Y/5"!.54Q,+`HM+2`@('1O:V5N7W1I;65S
M=&%M<"!N=6UE<FEC*#(P+#`I($Y/5"!.54Q,+`HM+2`@(%!224U!4ED@2T59
M("`H=&]K96Y?861D<F5S<RQT;VME;E]I9"D*+2T@*0HM+2!G;PH*+2T@0U)%
M051%(%1!0DQ%(&AO<F1E7W9F<R`H"BTM("`@=F9S7VED(&YU;65R:6,H,C`L
M,"D@3D]4($Y53$PL"BTM("`@=F9S7W1Y<&4@;G5M97)I8R@X+#`I($Y/5"!.
M54Q,+`HM+2`@('9F<U]P871H('9A<F-H87(H,C4V*2!.3U0@3E5,3"P*+2T@
M("!V9G-?;F%M92!N=F%R8VAA<B@R-38I($Y/5"!.54Q,+`HM+2`@('9F<U]M
M;V1I9FEE9"!N=6UE<FEC*#(P+#`I($Y/5"!.54Q,+`HM+2`@('9F<U]O=VYE
M<B!V87)C:&%R*#(U-BD@3D]4($Y53$PL"BTM("`@=F9S7V1A=&$@:6UA9V4@
M3E5,3"P*+2T@("!04DE-05)9($M%62`@*'9F<U]I9"D*+2T@*0HM+2!G;PH*
M+2T@0U)%051%(%1!0DQ%(&AO<F1E7VUU=F9S("@*+2T@("!V9G-?:60@(&YU
M;65R:6,H,C`L,"D@3D]4($Y53$PL"BTM("`@=F9S7W1Y<&4@("`@("!N=6UE
M<FEC*#@L,"D@3D]4($Y53$PL"BTM("`@=F9S7W!A=&@@("`@("!V87)C:&%R
M*#(U-BD@3D]4($Y53$PL"BTM("`@=F9S7VYA;64@("`@("!V87)C:&%R*#(U
M-BD@3D]4($Y53$PL"BTM("`@=F9S7VUO9&EF:65D("!N=6UE<FEC*#@L,"D@
M3D]4($Y53$PL"BTM("`@=F9S7V]W;F5R("`@("!V87)C:&%R*#(U-BD@3D]4
M($Y53$PL"BTM("`@=F9S7W!E<FUS("`@("!S;6%L;&EN="!.3U0@3E5,3"P*
M+2T@("!V9G-?9&%T82`@("`@(&EM86=E($Y53$PL"BTM("`@4%))34%262!+
M15D@("`H=F9S7VED*0HM+2`@("D*+2T@9V\*"@I#4D5!5$4@24Y$15@@<')E
M9E]U:61?:61X($].(&AO<F1E7W!R969S("AP<F5F7W5I9"D*9V\*"D-214%4
M12!)3D1%6"!P<F5F7W-C;W!E7VED>"!/3B!H;W)D95]P<F5F<R`H<')E9E]S
M8V]P92D*9V\*"D-214%412!)3D1%6"!D871A=')E95]D871A=')E95]N86UE
M7VED>"!/3B!H;W)D95]D871A=')E92`H9&%T871R965?;F%M92D*9V\*"D-2
M14%412!)3D1%6"!D871A=')E95]G<F]U<%]I9'@@3TX@:&]R9&5?9&%T871R
M964@*&=R;W5P7W5I9"D*9V\*"D-214%412!)3D1%6"!D871A=')E95]U<V5R
M7VED>"!/3B!H;W)D95]D871A=')E92`H=7-E<E]U:60I"F=O"@I#4D5!5$4@
M24Y$15@@9&%T871R965?<V5R:6%L:7IE9%]I9'@@3TX@:&]R9&5?9&%T871R
M964@*&1A=&%T<F5E7W-E<FEA;&EZ960I"F=O"@HM+2!#4D5!5$4@24Y$15@@
M=F9S7W!A=&A?:61X($].(&AO<F1E7W9F<R`H=F9S7W!A=&@I"BTM(&=O"@HM
M+2!#4D5!5$4@24Y$15@@=F9S7VYA;65?:61X($].(&AO<F1E7W9F<R`H=F9S
M7VYA;64I"BTM(&=O"@HM+2!#4D5!5$4@24Y$15@@=F9S7W!A=&A?:61X($].
M(&AO<F1E7VUU=F9S("AV9G-?<&%T:"D*+2T@9V\*"BTM($-214%412!)3D1%
M6"!V9G-?;F%M95]I9'@@3TX@:&]R9&5?;75V9G,@*'9F<U]N86UE*0HM+2!G
M;PH*"F=R86YT('-E;&5C="P@:6YS97)T+"!D96QE=&4L('5P9&%T92!O;B!E
M9&ET;W(@=&\@:&]R9&4*9V\*9W)A;G0@<V5L96-T+"!I;G-E<G0L(&1E;&5T
M92P@=7!D871E(&]N(&AO<W0@=&\@:&]R9&4*9V\*9W)A;G0@<V5L96-T+"!I
M;G-E<G0L(&1E;&5T92P@=7!D871E(&]N(&1B87-E('1O(&AO<F1E"F=O"F=R
M86YT('-E;&5C="P@:6YS97)T+"!D96QE=&4L('5P9&%T92!O;B!S:71E('1O
M(&AO<F1E"F=O"F=R86YT('-E;&5C="P@:6YS97)T+"!D96QE=&4L('5P9&%T
M92!O;B!C;VYN96-T:6]N('1O(&AO<F1E"F=O"F=R86YT('-E;&5C="P@:6YS
M97)T+"!D96QE=&4L('5P9&%T92!O;B!H;W)D95]D871A=')E92!T;R!H;W)D
M90IG;PIG<F%N="!S96QE8W0L(&EN<V5R="P@9&5L971E+"!U<&1A=&4@;VX@
M:&]R9&5?<')E9G,@=&\@:&]R9&4*9V\*9W)A;G0@<V5L96-T+"!I;G-E<G0L
M(&1E;&5T92P@=7!D871E(&]N(&AO<F1E7W-E<W-I;VYH86YD;&5R('1O(&AO
M<F1E"F=O"@HM+2!G<F%N="!S96QE8W0L(&EN<V5R="P@9&5L971E+"!U<&1A
M=&4@;VX@:&]R9&5?9&%T871R965?<V5Q('1O(&AO<F1E"BTM(&=O"BTM(&=R
M86YT('-E;&5C="P@:6YS97)T+"!D96QE=&4L('5P9&%T92!O;B!H;W)D95]T
M;VME;G,@=&\@:&]R9&4*+2T@9V\*+2T@9W)A;G0@<V5L96-T+"!I;G-E<G0L
M(&1E;&5T92P@=7!D871E(&]N(&AO<F1E7W9F<R!T;R!H;W)D90HM+2!G;PHM
M+2!G<F%N="!S96QE8W0L(&EN<V5R="P@9&5L971E+"!U<&1A=&4@;VX@:&]R
M9&5?;75V9G,@=&\@:&]R9&4*+2T@9V\*"@H*+2T@861D('EO=2!A9&UI;E]U
M<V5R7W5I9"!A;F0@861M:6Y?=7-E<E]P87-S"@HM+2!I;G-E<G0@:6YT;R!H
M;W)D95]U<V5R<R!V86QU97,@*"=Y;W5R7V%D;6EN7W5S97)?=6ED)RP@)WEO
M=7)?861M:6Y?=7-E<E]P87-S7VUD-5]E;F-R>7!T960G*0HM+2!G;PH`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO8W)E871E+GAM;```````
M````````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q-S,U-0`Q,#4Q-30S
M,S<U-0`P,C(Q-#8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]X;6P@=F5R<VEO;CTB,2XP(B!E;F-O9&EN9STB25-/+3@X
M-3DM,2(@/SX*/&1A=&%B87-E/@H*(#QN86UE/CQV87)I86)L93YN86UE/"]V
M87)I86)L93X\+VYA;64^"B`\8W)E871E/CQV87)I86)L93YC<F5A=&4\+W9A
M<FEA8FQE/CPO8W)E871E/@H*(#QT86)L93X*"B`@/&YA;64^:&]R9&5?9&%T
M871R964\+VYA;64^"@H@(#QD96-L87)A=&EO;CX*"B`@(#QF:65L9#X*("`@
M(#QN86UE/F1A=&%T<F5E7VED/"]N86UE/@H@("`@/'1Y<&4^:6YT96=E<CPO
M='EP93X*("`@(#QN;W1N=6QL/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^
M"@H@("`\9FEE;&0^"B`@("`\;F%M93YG<F]U<%]U:60\+VYA;64^"B`@("`\
M='EP93YT97AT/"]T>7!E/@H@("`@/&QE;F=T:#XR-34\+VQE;F=T:#X*("`@
M(#QN;W1N=6QL/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^"@H@("`\9FEE
M;&0^"B`@("`\;F%M93YU<V5R7W5I9#PO;F%M93X*("`@(#QT>7!E/G1E>'0\
M+W1Y<&4^"B`@("`\;&5N9W1H/C(U-3PO;&5N9W1H/@H@("`@/&YO=&YU;&P^
M=')U93PO;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@(#QF:65L9#X*("`@(#QN
M86UE/F1A=&%T<F5E7VYA;64\+VYA;64^"B`@("`\='EP93YT97AT/"]T>7!E
M/@H@("`@/&QE;F=T:#XR-34\+VQE;F=T:#X*("`@(#QN;W1N=6QL/G1R=64\
M+VYO=&YU;&P^"B`@(#PO9FEE;&0^"@H@("`\9FEE;&0^"B`@("`\;F%M93YD
M871A=')E95]P87)E;G1S/"]N86UE/@H@("`@/'1Y<&4^=&5X=#PO='EP93X*
M("`@(#QL96YG=&@^,C4U/"]L96YG=&@^"B`@("`\;F]T;G5L;#YT<G5E/"]N
M;W1N=6QL/@H@("`\+V9I96QD/@H*("`@/&9I96QD/@H@("`@/&YA;64^9&%T
M871R965?;W)D97(\+VYA;64^"B`@("`\='EP93YI;G1E9V5R/"]T>7!E/@H@
M("`\+V9I96QD/@H*("`@/&9I96QD/@H@("`@/&YA;64^9&%T871R965?9&%T
M83PO;F%M93X*("`@(#QT>7!E/F-L;V(\+W1Y<&4^"B`@(#PO9FEE;&0^"@H@
M("`\9FEE;&0^"B`@("`\;F%M93YD871A=')E95]S97)I86QI>F5D/"]N86UE
M/@H@("`@/'1Y<&4^:6YT96=E<CPO='EP93X*("`@(#QL96YG=&@^,CPO;&5N
M9W1H/@H@("`@/&YO=&YU;&P^=')U93PO;F]T;G5L;#X*("`@/"]F:65L9#X*
M"B`@(#QI;F1E>#X*("`@(#QN86UE/F1A=&%T<F5E7V1A=&%T<F5E7VYA;64\
M+VYA;64^"B`@("`\9FEE;&0^"B`@("`@/&YA;64^9&%T871R965?;F%M93PO
M;F%M93X*("`@(#PO9FEE;&0^"B`@(#PO:6YD97@^"@H@("`\:6YD97@^"B`@
M("`\;F%M93YD871A=')E95]G<F]U<#PO;F%M93X*("`@(#QF:65L9#X*("`@
M("`\;F%M93YG<F]U<%]U:60\+VYA;64^"B`@("`\+V9I96QD/@H@("`\+VEN
M9&5X/@H*("`@/&EN9&5X/@H@("`@/&YA;64^9&%T871R965?=7-E<CPO;F%M
M93X*("`@(#QF:65L9#X*("`@("`\;F%M93YU<V5R7W5I9#PO;F%M93X*("`@
M(#PO9FEE;&0^"B`@(#PO:6YD97@^"@H@("`\:6YD97@^"B`@("`\;F%M93YD
M871A=')E95]S97)I86QI>F5D/"]N86UE/@H@("`@/&9I96QD/@H@("`@(#QN
M86UE/F1A=&%T<F5E7W-E<FEA;&EZ960\+VYA;64^"B`@("`\+V9I96QD/@H@
M("`\+VEN9&5X/@H*("`@/&EN9&5X/@H@("`@/&YA;64^<')I;6%R>3PO;F%M
M93X*("`@(#QP<FEM87)Y/G1R=64\+W!R:6UA<GD^"B`@("`\9FEE;&0^"B`@
M("`@/&YA;64^9&%T871R965?:60\+VYA;64^"B`@("`\+V9I96QD/@H@("`\
M+VEN9&5X/@H*("`\+V1E8VQA<F%T:6]N/@H*(#PO=&%B;&4^"@H@/'1A8FQE
M/@H*("`\;F%M93YH;W)D95]D871A=')E95]A='1R:6)U=&5S/"]N86UE/@H*
M("`\9&5C;&%R871I;VX^"@H@("`\9FEE;&0^"B`@("`\;F%M93YD871A=')E
M95]I9#PO;F%M93X*("`@(#QT>7!E/FEN=&5G97(\+W1Y<&4^"B`@("`\;F]T
M;G5L;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I96QD/@H*("`@/&9I96QD/@H@
M("`@/&YA;64^871T<FEB=71E7VYA;64\+VYA;64^"B`@("`\='EP93YT97AT
M/"]T>7!E/@H@("`@/&QE;F=T:#XR-34\+VQE;F=T:#X*("`@(#QN;W1N=6QL
M/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^"@H@("`\9FEE;&0^"B`@("`\
M;F%M93YA='1R:6)U=&5?:V5Y/"]N86UE/@H@("`@/'1Y<&4^=&5X=#PO='EP
M93X*("`@(#QL96YG=&@^,C4U/"]L96YG=&@^"B`@("`\;F]T;G5L;#YT<G5E
M/"]N;W1N=6QL/@H@("`\+V9I96QD/@H*("`@/&9I96QD/@H@("`@/&YA;64^
M871T<FEB=71E7W9A;'5E/"]N86UE/@H@("`@/'1Y<&4^8VQO8CPO='EP93X*
M("`@/"]F:65L9#X*"B`@(#QI;F1E>#X*("`@(#QN86UE/F1A=&%T<F5E7V%T
M=')I8G5T93PO;F%M93X*("`@(#QF:65L9#X*("`@("`\;F%M93YD871A=')E
M95]I9#PO;F%M93X*("`@(#PO9FEE;&0^"B`@(#PO:6YD97@^"@H@("`\:6YD
M97@^"B`@("`\;F%M93YD871A=')E95]A='1R:6)U=&5?;F%M93PO;F%M93X*
M("`@(#QF:65L9#X*("`@("`\;F%M93YA='1R:6)U=&5?;F%M93PO;F%M93X*
M("`@(#PO9FEE;&0^"B`@(#PO:6YD97@^"@H@("`\:6YD97@^"B`@("`\;F%M
M93YD871A=')E95]A='1R:6)U=&5?:V5Y/"]N86UE/@H@("`@/&9I96QD/@H@
M("`@(#QN86UE/F%T=')I8G5T95]K97D\+VYA;64^"B`@("`\+V9I96QD/@H@
M("`\+VEN9&5X/@H*("`\+V1E8VQA<F%T:6]N/@H*(#PO=&%B;&4^"@H@/'1A
M8FQE/@H*("`\;F%M93YH;W)D95]H:7-T;W)I97,\+VYA;64^"@H@(#QD96-L
M87)A=&EO;CX*"B`@(#QF:65L9#X*("`@(#QN86UE/FAI<W1O<GE?:60\+VYA
M;64^"B`@("`\='EP93YI;G1E9V5R/"]T>7!E/@H@("`@/&YO=&YU;&P^=')U
M93PO;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@(#QF:65L9#X*("`@(#QN86UE
M/F]B:F5C=%]U:60\+VYA;64^"B`@("`\='EP93YT97AT/"]T>7!E/@H@("`@
M/&QE;F=T:#XR-34\+VQE;F=T:#X*("`@(#QN;W1N=6QL/G1R=64\+VYO=&YU
M;&P^"B`@(#PO9FEE;&0^"@H@("`\9FEE;&0^"B`@("`\;F%M93YH:7-T;W)Y
M7V%C=&EO;CPO;F%M93X*("`@(#QT>7!E/G1E>'0\+W1Y<&4^"B`@("`\;&5N
M9W1H/C,R/"]L96YG=&@^"B`@("`\;F]T;G5L;#YT<G5E/"]N;W1N=6QL/@H@
M("`\+V9I96QD/@H*("`@/&9I96QD/@H@("`@/&YA;64^:&ES=&]R>5]T<SPO
M;F%M93X*("`@(#QT>7!E/FEN=&5G97(\+W1Y<&4^"B`@("`\;F]T;G5L;#YT
M<G5E/"]N;W1N=6QL/@H@("`\+V9I96QD/@H*("`@/&9I96QD/@H@("`@/&YA
M;64^:&ES=&]R>5]D97-C/"]N86UE/@H@("`@/'1Y<&4^8VQO8CPO='EP93X*
M("`@/"]F:65L9#X*"B`@(#QF:65L9#X*("`@(#QN86UE/FAI<W1O<GE?=VAO
M/"]N86UE/@H@("`@/'1Y<&4^=&5X=#PO='EP93X*("`@(#QL96YG=&@^,C4U
M/"]L96YG=&@^"B`@(#PO9FEE;&0^"@H@("`\9FEE;&0^"B`@("`\;F%M93YH
M:7-T;W)Y7V5X=')A/"]N86UE/@H@("`@/'1Y<&4^8VQO8CPO='EP93X*("`@
M/"]F:65L9#X*"B`@(#QI;F1E>#X*("`@(#QN86UE/FAI<W1O<GE?86-T:6]N
M/"]N86UE/@H@("`@/&9I96QD/@H@("`@(#QN86UE/FAI<W1O<GE?86-T:6]N
M/"]N86UE/@H@("`@/"]F:65L9#X*("`@/"]I;F1E>#X*"B`@(#QI;F1E>#X*
M("`@(#QN86UE/FAI<W1O<GE?=',\+VYA;64^"B`@("`\9FEE;&0^"B`@("`@
M/&YA;64^:&ES=&]R>5]T<SPO;F%M93X*("`@(#PO9FEE;&0^"B`@(#PO:6YD
M97@^"@H@("`\:6YD97@^"B`@("`\;F%M93YH:7-T;W)Y7W5I9#PO;F%M93X*
M("`@(#QF:65L9#X*("`@("`\;F%M93YO8FIE8W1?=6ED/"]N86UE/@H@("`@
M/"]F:65L9#X*("`@/"]I;F1E>#X*"B`@(#QI;F1E>#X*("`@(#QN86UE/G!R
M:6UA<GD\+VYA;64^"B`@("`\<')I;6%R>3YT<G5E/"]P<FEM87)Y/@H@("`@
M/&9I96QD/@H@("`@(#QN86UE/FAI<W1O<GE?:60\+VYA;64^"B`@("`\+V9I
M96QD/@H@("`\+VEN9&5X/@H*("`\+V1E8VQA<F%T:6]N/@H*(#PO=&%B;&4^
M"@H@/'1A8FQE/@H*("`\;F%M93YH;W)D95]P<F5F<SPO;F%M93X*"B`@/&1E
M8VQA<F%T:6]N/@H*("`@/&9I96QD/@H@("`@/&YA;64^<')E9E]U:60\+VYA
M;64^"B`@("`\='EP93YT97AT/"]T>7!E/@H@("`@/&QE;F=T:#XR,#`\+VQE
M;F=T:#X*("`@(#QN;W1N=6QL/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^
M"@H@("`\9FEE;&0^"B`@("`\;F%M93YP<F5F7W-C;W!E/"]N86UE/@H@("`@
M/'1Y<&4^=&5X=#PO='EP93X*("`@(#QL96YG=&@^,38\+VQE;F=T:#X*("`@
M(#QN;W1N=6QL/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^"@H@("`\9FEE
M;&0^"B`@("`\;F%M93YP<F5F7VYA;64\+VYA;64^"B`@("`\='EP93YT97AT
M/"]T>7!E/@H@("`@/&QE;F=T:#XS,CPO;&5N9W1H/@H@("`@/&YO=&YU;&P^
M=')U93PO;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@(#QF:65L9#X*("`@(#QN
M86UE/G!R969?=F%L=64\+VYA;64^"B`@("`\='EP93YC;&]B/"]T>7!E/@H@
M("`\+V9I96QD/@H*("`@/&EN9&5X/@H@("`@/&YA;64^<')I;6%R>3PO;F%M
M93X*("`@(#QP<FEM87)Y/G1R=64\+W!R:6UA<GD^"B`@("`\9FEE;&0^"B`@
M("`@/&YA;64^<')E9E]U:60\+VYA;64^"B`@("`\+V9I96QD/@H@("`@/&9I
M96QD/@H@("`@(#QN86UE/G!R969?<V-O<&4\+VYA;64^"B`@("`\+V9I96QD
M/@H@("`@/&9I96QD/@H@("`@(#QN86UE/G!R969?;F%M93PO;F%M93X*("`@
M(#PO9FEE;&0^"B`@(#PO:6YD97@^"@H@("`\:6YD97@^"B`@("`\;F%M93YP
M<F5F7W5I9#PO;F%M93X*("`@(#QF:65L9#X*("`@("`\;F%M93YP<F5F7W5I
M9#PO;F%M93X*("`@(#PO9FEE;&0^"B`@(#PO:6YD97@^"@H@("`\:6YD97@^
M"B`@("`\;F%M93YP<F5F7W-C;W!E/"]N86UE/@H@("`@/&9I96QD/@H@("`@
M(#QN86UE/G!R969?<V-O<&4\+VYA;64^"B`@("`\+V9I96QD/@H@("`\+VEN
M9&5X/@H*("`\+V1E8VQA<F%T:6]N/@H*(#PO=&%B;&4^"@H@/'1A8FQE/@H*
M("`\;F%M93YH;W)D95]S97-S:6]N:&%N9&QE<CPO;F%M93X*"B`@/&1E8VQA
M<F%T:6]N/@H*("`@/&9I96QD/@H@("`@/&YA;64^<V5S<VEO;E]I9#PO;F%M
M93X*("`@(#QT>7!E/G1E>'0\+W1Y<&4^"B`@("`\;&5N9W1H/C,R/"]L96YG
M=&@^"B`@("`\;F]T;G5L;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I96QD/@H*
M("`@/&9I96QD/@H@("`@/&YA;64^<V5S<VEO;E]L87-T;6]D:69I960\+VYA
M;64^"B`@("`\='EP93YI;G1E9V5R/"]T>7!E/@H@("`@/&YO=&YU;&P^=')U
M93PO;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@(#QF:65L9#X*("`@(#QN86UE
M/G-E<W-I;VY?9&%T83PO;F%M93X*("`@(#QT>7!E/F)L;V(\+W1Y<&4^"B`@
M(#PO9FEE;&0^"@H@("`\:6YD97@^"B`@("`\;F%M93YP<FEM87)Y/"]N86UE
M/@H@("`@/'!R:6UA<GD^=')U93PO<')I;6%R>3X*("`@(#QF:65L9#X*("`@
M("`\;F%M93YS97-S:6]N7VED/"]N86UE/@H@("`@/"]F:65L9#X*("`@/"]I
M;F1E>#X*"B`@/"]D96-L87)A=&EO;CX*"B`\+W1A8FQE/@H*(#QT86)L93X*
M"B`@/&YA;64^:&]R9&5?=&]K96YS/"]N86UE/@H*("`\9&5C;&%R871I;VX^
M"@H@("`\9FEE;&0^"B`@("`\;F%M93YT;VME;E]A9&1R97-S/"]N86UE/@H@
M("`@/'1Y<&4^=&5X=#PO='EP93X*("`@(#QL96YG=&@^,3`P/"]L96YG=&@^
M"B`@("`\;F]T;G5L;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I96QD/@H*("`@
M/&9I96QD/@H@("`@/&YA;64^=&]K96Y?:60\+VYA;64^"B`@("`\='EP93YT
M97AT/"]T>7!E/@H@("`@/&QE;F=T:#XS,CPO;&5N9W1H/@H@("`@/&YO=&YU
M;&P^=')U93PO;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@(#QF:65L9#X*("`@
M(#QN86UE/G1O:V5N7W1I;65S=&%M<#PO;F%M93X*("`@(#QT>7!E/FEN=&5G
M97(\+W1Y<&4^"B`@("`\;F]T;G5L;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I
M96QD/@H*("`@/&EN9&5X/@H@("`@/&YA;64^<')I;6%R>3PO;F%M93X*("`@
M(#QP<FEM87)Y/G1R=64\+W!R:6UA<GD^"B`@("`\9FEE;&0^"B`@("`@/&YA
M;64^=&]K96Y?861D<F5S<SPO;F%M93X*("`@(#PO9FEE;&0^"B`@("`\9FEE
M;&0^"B`@("`@/&YA;64^=&]K96Y?:60\+VYA;64^"B`@("`\+V9I96QD/@H@
M("`\+VEN9&5X/@H*("`\+V1E8VQA<F%T:6]N/@H*(#PO=&%B;&4^"@H@/'1A
M8FQE/@H*("`\;F%M93YH;W)D95]U<V5R<SPO;F%M93X*"B`@/&1E8VQA<F%T
M:6]N/@H*("`@/&9I96QD/@H@("`@/&YA;64^=7-E<E]U:60\+VYA;64^"B`@
M("`\='EP93YT97AT/"]T>7!E/@H@("`@/&QE;F=T:#XR-34\+VQE;F=T:#X*
M("`@(#QN;W1N=6QL/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^"@H@("`\
M9FEE;&0^"B`@("`\;F%M93YU<V5R7W!A<W,\+VYA;64^"B`@("`\='EP93YT
M97AT/"]T>7!E/@H@("`@/&QE;F=T:#XR-34\+VQE;F=T:#X*("`@(#QN;W1N
M=6QL/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^"@H@("`\9FEE;&0^"B`@
M("`\;F%M93YU<V5R7W-O9G1?97AP:7)A=&EO;E]D871E/"]N86UE/@H@("`@
M/'1Y<&4^:6YT96=E<CPO='EP93X*("`@/"]F:65L9#X*"B`@(#QF:65L9#X*
M("`@(#QN86UE/G5S97)?:&%R9%]E>'!I<F%T:6]N7V1A=&4\+VYA;64^"B`@
M("`\='EP93YI;G1E9V5R/"]T>7!E/@H@("`\+V9I96QD/@H*("`@/&EN9&5X
M/@H@("`@/&YA;64^<')I;6%R>3PO;F%M93X*("`@(#QP<FEM87)Y/G1R=64\
M+W!R:6UA<GD^"B`@("`\9FEE;&0^"B`@("`@/&YA;64^=7-E<E]U:60\+VYA
M;64^"B`@("`\+V9I96QD/@H@("`\+VEN9&5X/@H*("`\+V1E8VQA<F%T:6]N
M/@H*(#PO=&%B;&4^"@H@/'1A8FQE/@H*("`\;F%M93YH;W)D95]V9G,\+VYA
M;64^"@H@(#QD96-L87)A=&EO;CX*"B`@(#QF:65L9#X*("`@(#QN86UE/G9F
M<U]I9#PO;F%M93X*("`@(#QT>7!E/FEN=&5G97(\+W1Y<&4^"B`@("`\;F]T
M;G5L;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I96QD/@H*("`@/&9I96QD/@H@
M("`@/&YA;64^=F9S7W1Y<&4\+VYA;64^"B`@("`\='EP93YI;G1E9V5R/"]T
M>7!E/@H@("`@/&QE;F=T:#XQ/"]L96YG=&@^"B`@("`\;F]T;G5L;#YT<G5E
M/"]N;W1N=6QL/@H@("`\+V9I96QD/@H*("`@/&9I96QD/@H@("`@/&YA;64^
M=F9S7W!A=&@\+VYA;64^"B`@("`\='EP93YT97AT/"]T>7!E/@H@("`@/&QE
M;F=T:#XR-34\+VQE;F=T:#X*("`@(#QN;W1N=6QL/G1R=64\+VYO=&YU;&P^
M"B`@(#PO9FEE;&0^"@H@("`\9FEE;&0^"B`@("`\;F%M93YV9G-?;F%M93PO
M;F%M93X*("`@(#QT>7!E/G1E>'0\+W1Y<&4^"B`@("`\;&5N9W1H/C(U-3PO
M;&5N9W1H/@H@("`@/&YO=&YU;&P^=')U93PO;F]T;G5L;#X*("`@/"]F:65L
M9#X*"B`@(#QF:65L9#X*("`@(#QN86UE/G9F<U]M;V1I9FEE9#PO;F%M93X*
M("`@(#QT>7!E/FEN=&5G97(\+W1Y<&4^"B`@("`\;F]T;G5L;#YT<G5E/"]N
M;W1N=6QL/@H@("`\+V9I96QD/@H*("`@/&9I96QD/@H@("`@/&YA;64^=F9S
M7V]W;F5R/"]N86UE/@H@("`@/'1Y<&4^=&5X=#PO='EP93X*("`@(#QL96YG
M=&@^,C4U/"]L96YG=&@^"B`@("`\;F]T;G5L;#YT<G5E/"]N;W1N=6QL/@H@
M("`\+V9I96QD/@H*("`@/&9I96QD/@H@("`@/&YA;64^=F9S7V1A=&$\+VYA
M;64^"B`@("`\='EP93YB;&]B/"]T>7!E/@H@("`\+V9I96QD/@H*("`@/&EN
M9&5X/@H@("`@/&YA;64^<')I;6%R>3PO;F%M93X*("`@(#QP<FEM87)Y/G1R
M=64\+W!R:6UA<GD^"B`@("`\9FEE;&0^"B`@("`@/&YA;64^=F9S7VED/"]N
M86UE/@H@("`@/"]F:65L9#X*("`@/"]I;F1E>#X*"B`@(#QI;F1E>#X*("`@
M(#QN86UE/G9F<U]P871H/"]N86UE/@H@("`@/&9I96QD/@H@("`@(#QN86UE
M/G9F<U]P871H/"]N86UE/@H@("`@/"]F:65L9#X*("`@/"]I;F1E>#X*"B`@
M(#QI;F1E>#X*("`@(#QN86UE/G9F<U]N86UE/"]N86UE/@H@("`@/&9I96QD
M/@H@("`@(#QN86UE/G9F<U]N86UE/"]N86UE/@H@("`@/"]F:65L9#X*("`@
M/"]I;F1E>#X*"B`@/"]D96-L87)A=&EO;CX*"B`\+W1A8FQE/@H*/"]D871A
M8F%S93X*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O
M<W%L+VAO<F1E7V1A=&%T<F5E+FUS<W%L+G-Q;```````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(U-#<`,3`U,34T,S,W-34`,#(U,#`W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"TM("1(;W)D93H@:&]R9&4O
M<V-R:7!T<R]S<6PO:&]R9&5?9&%T871R964N;7-S<6PN<W%L+'8@,2XQ+C(N
M,B`R,#`V+S`U+S(R(#(Q.C(W.C,S(&IA;B!%>'`@)`H*0U)%051%(%1!0DQ%
M(&AO<F1E7V1A=&%T<F5E("@*("`@(&1A=&%T<F5E7VED($E.5"!.3U0@3E5,
M3"P*("`@(&=R;W5P7W5I9"!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!U
M<V5R7W5I9"!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!D871A=')E95]N
M86UE(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@(&1A=&%T<F5E7W!A<F5N
M=',@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@9&%T871R965?;W)D97(@
M24Y4+`H@("`@9&%T871R965?9&%T82!605)#2$%2*$U!6"DL"B`@("!D871A
M=')E95]S97)I86QI>F5D(%--04Q,24Y4($1%1D%53%0@,"!.3U0@3E5,3"P*
M"B`@("!04DE-05)9($M%62`H9&%T871R965?:60I"BD["@I#4D5!5$4@24Y$
M15@@9&%T871R965?9&%T871R965?;F%M95]I9'@@3TX@:&]R9&5?9&%T871R
M964@*&1A=&%T<F5E7VYA;64I.PI#4D5!5$4@24Y$15@@9&%T871R965?9W)O
M=7!?:61X($].(&AO<F1E7V1A=&%T<F5E("AG<F]U<%]U:60I.PI#4D5!5$4@
M24Y$15@@9&%T871R965?=7-E<E]I9'@@3TX@:&]R9&5?9&%T871R964@*'5S
M97)?=6ED*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V]R9&5R7VED>"!/3B!H
M;W)D95]D871A=')E92`H9&%T871R965?;W)D97(I.PI#4D5!5$4@24Y$15@@
M9&%T871R965?<V5R:6%L:7IE9%]I9'@@3TX@:&]R9&5?9&%T871R964@*&1A
M=&%T<F5E7W-E<FEA;&EZ960I.PH*"D-214%412!404),12!H;W)D95]D871A
M=')E95]A='1R:6)U=&5S("@*("`@(&1A=&%T<F5E7VED($E.5"!.3U0@3E5,
M3"P*("`@(&%T=')I8G5T95]N86UE(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*
M("`@(&%T=')I8G5T95]K97D@5D%20TA!4B@R-34I+`H@("`@871T<FEB=71E
M7W9A;'5E(%9!4D-(05(H34%8*0HI.PH*0U)%051%($E.1$58(&1A=&%T<F5E
M7V%T=')I8G5T95]I9'@@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H
M9&%T871R965?:60I.PI#4D5!5$4@24Y$15@@9&%T871R965?871T<FEB=71E
M7VYA;65?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&%T=')I
M8G5T95]N86UE*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V%T=')I8G5T95]K
M97E?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&%T=')I8G5T
M95]K97DI.PH*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$54
M12!/3B!H;W)D95]D871A=')E92!43R!H;W)D93L*1U)!3E0@4T5,14-4+"!)
M3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7V1A=&%T<F5E7V%T=')I
M8G5T97,@5$\@:&]R9&4["@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?9&%T871R964N;7ES
M<6PN<W%L```````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C4R-``Q,#4Q-30S,S<U
M-0`P,C4P,3``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]D871A
M=')E92YM>7-Q;"YS<6PL=B`Q+C$N,3`N,2`R,#`V+S`U+S(R(#(Q.C(W.C,S
M(&IA;B!%>'`@)`H*0U)%051%(%1!0DQ%(&AO<F1E7V1A=&%T<F5E("@*("`@
M("`@(&1A=&%T<F5E7VED($E.5"!.3U0@3E5,3"P*("`@("`@(&=R;W5P7W5I
M9"!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("`@("!U<V5R7W5I9"!605)#
M2$%2*#(U-2D@3D]4($Y53$PL"B`@("`@("!D871A=')E95]N86UE(%9!4D-(
M05(H,C4U*2!.3U0@3E5,3"P*("`@("`@(&1A=&%T<F5E7W!A<F5N=',@5D%2
M0TA!4B@R-34I($Y/5"!.54Q,+`H@("`@("`@9&%T871R965?;W)D97(@24Y4
M+`H@("`@("`@9&%T871R965?9&%T82!415A4+`H@("`@("`@9&%T871R965?
M<V5R:6%L:7IE9"!334%,3$E.5"!$149!54Q4(#`@3D]4($Y53$PL"B`@("`@
M("!04DE-05)9($M%62`H9&%T871R965?:60I"BD["@I#4D5!5$4@24Y$15@@
M9&%T871R965?9&%T871R965?;F%M95]I9'@@3TX@:&]R9&5?9&%T871R964@
M*&1A=&%T<F5E7VYA;64I.PI#4D5!5$4@24Y$15@@9&%T871R965?9W)O=7!?
M:61X($].(&AO<F1E7V1A=&%T<F5E("AG<F]U<%]U:60I.PI#4D5!5$4@24Y$
M15@@9&%T871R965?=7-E<E]I9'@@3TX@:&]R9&5?9&%T871R964@*'5S97)?
M=6ED*3L*0U)%051%($E.1$58(&1A=&%T<F5E7W-E<FEA;&EZ961?:61X($].
M(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]S97)I86QI>F5D*3L*"D-214%4
M12!404),12!H;W)D95]D871A=')E95]A='1R:6)U=&5S("@*("`@(&1A=&%T
M<F5E7VED($E.5"!.3U0@3E5,3"P*("`@(&%T=')I8G5T95]N86UE(%9!4D-(
M05(H,C4U*2!.3U0@3E5,3"P*("`@(&%T=')I8G5T95]K97D@5D%20TA!4B@R
M-34I($1%1D%53%0@)R<@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?=F%L=64@
M5$585`HI.PH*0U)%051%($E.1$58(&1A=&%T<F5E7V%T=')I8G5T95]I9'@@
M3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H9&%T871R965?:60I.PI#
M4D5!5$4@24Y$15@@9&%T871R965?871T<FEB=71E7VYA;65?:61X($].(&AO
M<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&%T=')I8G5T95]N86UE*3L*0U)%
M051%($E.1$58(&1A=&%T<F5E7V%T=')I8G5T95]K97E?:61X($].(&AO<F1E
M7V1A=&%T<F5E7V%T=')I8G5T97,@*&%T=')I8G5T95]K97DI.PH*1U)!3E0@
M4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7V1A=&%T
M<F5E(%1/(&AO<F1E0&QO8V%L:&]S=#L*1U)!3E0@4T5,14-4+"!)3E-%4E0L
M(%501$%412P@1$5,151%($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@
M5$\@:&]R9&5`;&]C86QH;W-T.PH`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S
M+W-Q;"]H;W)D95]D871A=')E92YS<6P`````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`S,#,T`#$P-3$U-#,S-S4U`#`R,S8T,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````M+2`D2&]R9&4Z(&AO<F1E
M+W-C<FEP=',O<W%L+VAO<F1E7V1A=&%T<F5E+G-Q;"QV(#$N,2XQ,"XQ(#(P
M,#8O,#4O,C(@,C$Z,C<Z,S,@:F%N($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R
M9&5?9&%T871R964@*`H@("`@9&%T871R965?:60@24Y4($Y/5"!.54Q,+`H@
M("`@9W)O=7!?=6ED(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('5S97)?
M=6ED(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@(&1A=&%T<F5E7VYA;64@
M5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@9&%T871R965?<&%R96YT<R!6
M05)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!D871A=')E95]O<F1E<B!)3E0L
M"@HM+2!4:&5R92!I<R!N;R!P;W)T86)L92!W87D@=&\@9&\@=&AI<R!A<'!A
M<F5N=&QY+B!)9B!Y;W5R(&1B(&1O97-N)W0*+2T@86QL;W<@5$585"!C;VQU
M;6YS+"!T:&5N(&UA>6)E(&ET(&%L;&]W<R!L87)G92!605)#2$%2(&-O;'5M
M;G,L('-O"BTM('1R>2!T:&4@<V5C;VYD(&QI;F4N"BTM"B`@("!D871A=')E
M95]D871A(%1%6%0L"BTM("!D871A=')E95]D871A(%9!4D-(05(H-#`Y-BDL
M"@H@("`@9&%T871R965?<V5R:6%L:7IE9"!334%,3$E.5"!$149!54Q4(#`@
M3D]4($Y53$PL"@H@("`@4%))34%262!+15D@*&1A=&%T<F5E7VED*0HI.PH*
M0U)%051%($E.1$58(&1A=&%T<F5E7V1A=&%T<F5E7VYA;65?:61X($].(&AO
M<F1E7V1A=&%T<F5E("AD871A=')E95]N86UE*3L*0U)%051%($E.1$58(&1A
M=&%T<F5E7V=R;W5P7VED>"!/3B!H;W)D95]D871A=')E92`H9W)O=7!?=6ED
M*3L*0U)%051%($E.1$58(&1A=&%T<F5E7W5S97)?:61X($].(&AO<F1E7V1A
M=&%T<F5E("AU<V5R7W5I9"D["D-214%412!)3D1%6"!D871A=')E95]O<F1E
M<E]I9'@@3TX@:&]R9&5?9&%T871R964@*&1A=&%T<F5E7V]R9&5R*3L*0U)%
M051%($E.1$58(&1A=&%T<F5E7W-E<FEA;&EZ961?:61X($].(&AO<F1E7V1A
M=&%T<F5E("AD871A=')E95]S97)I86QI>F5D*3L*"@I#4D5!5$4@5$%"3$4@
M:&]R9&5?9&%T871R965?871T<FEB=71E<R`H"B`@("!D871A=')E95]I9"!)
M3E0@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?;F%M92!605)#2$%2*#(U-2D@
M3D]4($Y53$PL"B`@("!A='1R:6)U=&5?:V5Y(%9!4D-(05(H,C4U*2P*("`@
M(&%T=')I8G5T95]V86QU92!415A4"BD["@I#4D5!5$4@24Y$15@@9&%T871R
M965?871T<FEB=71E7VED>"!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S
M("AD871A=')E95]I9"D["D-214%412!)3D1%6"!D871A=')E95]A='1R:6)U
M=&5?;F%M95]I9'@@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H871T
M<FEB=71E7VYA;64I.PI#4D5!5$4@24Y$15@@9&%T871R965?871T<FEB=71E
M7VME>5]I9'@@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H871T<FEB
M=71E7VME>2D["@H*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,
M151%($].(&AO<F1E7V1A=&%T<F5E(%1/(&AO<F1E.PI'4D%.5"!314Q%0U0L
M($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?9&%T871R965?871T
M<FEB=71E<R!43R!H;W)D93L*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO
M:&]R9&5?:&ES=&]R:65S+FUS<W%L+G-Q;```````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,3(V,@`Q,#4Q-30S,S<U-0`P,C4R,C``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+2T@)$AO<F1E.B!H;W)D92]S8W)I
M<'1S+W-Q;"]H;W)D95]H:7-T;W)I97,N;7-S<6PN<W%L+'8@,2XQ+C(N,2`R
M,#`V+S`Q+S$X(#$Y.C4X.C0R(&)E;B!%>'`@)`H*0U)%051%(%1!0DQ%(&AO
M<F1E7VAI<W1O<FEE<R`H"B`@("!H:7-T;W)Y7VED("`@("`@($))1TE.5"!.
M3U0@3E5,3"P*("`@(&]B:F5C=%]U:60@("`@("`@5D%20TA!4B@R-34I($Y/
M5"!.54Q,+`H@("`@:&ES=&]R>5]A8W1I;VX@("!605)#2$%2*#,R*2!.3U0@
M3E5,3"P*("`@(&AI<W1O<GE?=',@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@
M("`@:&ES=&]R>5]D97-C("`@("!605)#2$%2*$U!6"DL"B`@("!H:7-T;W)Y
M7W=H;R`@("`@(%9!4D-(05(H,C4U*2P*("`@(&AI<W1O<GE?97AT<F$@("`@
M5D%20TA!4BA-05@I+`HM+0H@("`@4%))34%262!+15D@*&AI<W1O<GE?:60I
M"BD["@I#4D5!5$4@24Y$15@@:&ES=&]R>5]A8W1I;VY?:61X($].(&AO<F1E
M7VAI<W1O<FEE<R`H:&ES=&]R>5]A8W1I;VXI.PI#4D5!5$4@24Y$15@@:&ES
M=&]R>5]T<U]I9'@@3TX@:&]R9&5?:&ES=&]R:65S("AH:7-T;W)Y7W1S*3L*
M0U)%051%($E.1$58(&AI<W1O<GE?=6ED7VED>"!/3B!H;W)D95]H:7-T;W)I
M97,@*&]B:F5C=%]U:60I.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%4
M12P@1$5,151%($].(&AO<F1E7VAI<W1O<FEE<R!43R!H;W)D93L*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T
M<R]S<6PO:&]R9&5?:&ES=&]R:65S+G-Q;```````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,3(S-``Q,#4Q-30S,S<U-0`P,C0P-C$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+2T@)$AO<F1E.B!H;W)D
M92]S8W)I<'1S+W-Q;"]H;W)D95]H:7-T;W)I97,N<W%L+'8@,2XQ+C(N,2`R
M,#`U+S$P+S$X(#$Q.C,T.C`P(&IA;B!%>'`@)`H*0U)%051%(%1!0DQ%(&AO
M<F1E7VAI<W1O<FEE<R`H"B`@("!H:7-T;W)Y7VED("`@("`@($))1TE.5"!.
M3U0@3E5,3"P*("`@(&]B:F5C=%]U:60@("`@("`@5D%20TA!4B@R-34I($Y/
M5"!.54Q,+`H@("`@:&ES=&]R>5]A8W1I;VX@("!605)#2$%2*#,R*2!.3U0@
M3E5,3"P*("`@(&AI<W1O<GE?=',@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@
M("`@:&ES=&]R>5]D97-C("`@("!415A4+`H@("`@:&ES=&]R>5]W:&\@("`@
M("!605)#2$%2*#(U-2DL"B`@("!H:7-T;W)Y7V5X=')A("`@(%1%6%0L"BTM
M"B`@("!04DE-05)9($M%62`H:&ES=&]R>5]I9"D**3L*"D-214%412!)3D1%
M6"!H:7-T;W)Y7V%C=&EO;E]I9'@@3TX@:&]R9&5?:&ES=&]R:65S("AH:7-T
M;W)Y7V%C=&EO;BD["D-214%412!)3D1%6"!H:7-T;W)Y7W1S7VED>"!/3B!H
M;W)D95]H:7-T;W)I97,@*&AI<W1O<GE?=',I.PI#4D5!5$4@24Y$15@@:&ES
M=&]R>5]U:61?:61X($].(&AO<F1E7VAI<W1O<FEE<R`H;V)J96-T7W5I9"D[
M"@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R
M9&5?:&ES=&]R:65S(%1/(&AO<F1E.PH`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<V-R:7!T<R]S<6PO:&]R9&5?;&]G+FUS<W%L+G-Q;```````````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#8U-P`Q,#4Q-30S,S<U-0`P,C,W-S<`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+2T@)$AO<F1E
M.B!H;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]L;V<N;7-S<6PN<W%L+'8@,2XQ
M+C(N,2`R,#`V+S`Q+S$X(#$Y.C4X.C0X(&)E;B!%>'`@)`H*0U)%051%(%1!
M0DQ%(&AO<F1E7VQO9R`H"B`@("!I9"`@("`@("`@("!)3E0@3D]4($Y53$PL
M"B`@("!L;V=T:6UE("`@("!424U%4U1!35`@3D]4($Y53$PL"B`@("!I9&5N
M="`@("`@("!#2$%2*#$V*2!.3U0@3E5,3"P*("`@('!R:6]R:71Y("`@($E.
M5"!.3U0@3E5,3"P*("`@("TM($9O<B!$0G,@=&AA="!D;VXG="!S=7!P;W)T
M('1H92!605)#2$%2*$U!6"D@9FEE;&0@='EP93H*("`@("TM(&UE<W-A9V4@
M(%9!4D-(05(H,C`T."DL"B`@("!M97-S86=E("`@("!605)#2$%2*$U!6"DL
M"B`@("!04DE-05)9($M%62`H:60I"BD["@I'4D%.5"!)3E-%4E0@3TX@:&]R
M9&5?;&]G(%1/(&AO<F1E.PH`````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L
M+VAO<F1E7VQO9RYS<6P`````````````````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`V,C<`,3`U,34T,S,W-34`,#(R-C,V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"TM("1(;W)D93H@:&]R9&4O<V-R
M:7!T<R]S<6PO:&]R9&5?;&]G+G-Q;"QV(#$N,2`R,#`T+S`Y+S$X(#$W.C(P
M.C4Y(&-H=6-K($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R9&5?;&]G("@*("`@
M(&ED("`@("`@("`@($E.5"!.3U0@3E5,3"P*("`@(&QO9W1I;64@("`@(%1)
M34535$%-4"!.3U0@3E5,3"P*("`@(&ED96YT("`@("`@($-(05(H,38I($Y/
M5"!.54Q,+`H@("`@<')I;W)I='D@("`@24Y4($Y/5"!.54Q,+`H@("`@+2T@
M1F]R($1"<R!T:&%T(&1O;B=T('-U<'!O<G0@=&AE(%1%6%0@9FEE;&0@='EP
M93H*("`@("TM(&UE<W-A9V4@(%9!4D-(05(H,C`T."DL"B`@("!M97-S86=E
M("`@("!415A4+`H@("`@4%))34%262!+15D@*&ED*0HI.PH*1U)!3E0@24Y3
M15)4($].(&AO<F1E7VQO9R!43R!H;W)D93L*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]M=79F
M<RYM<W-Q;"YS<6P`````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#4U`#$P
M-3$U-#,S-S4U`#`R-#,T-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L+VAO
M<F1E7VUU=F9S+FUS<W%L+G-Q;"QV(#$N,2XR+C$@,C`P-B\P,2\Q."`Q.3HU
M.#HU-"!B96X@17AP("0*"D-214%412!404),12!H;W)D95]M=79F<R`H"B`@
M("!V9G-?:60@("`@("`@($))1TE.5"!.3U0@3E5,3"P*("`@('9F<U]T>7!E
M("`@("`@4TU!3$Q)3E0@3D]4($Y53$PL"B`@("!V9G-?<&%T:"`@("`@(%9!
M4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]N86UE("`@("`@5D%20TA!
M4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VUO9&EF:65D("!"24=)3E0@3D]4
M($Y53$PL"B`@("!V9G-?;W=N97(@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,
M3"P*("`@('9F<U]P97)M<R`@("`@4TU!3$Q)3E0@3D]4($Y53$PL"B`@("!V
M9G-?9&%T82`@("`@(%9!4D))3D%262A-05@I+`H@("`@4%))34%262!+15D@
M("`H=F9S7VED*0HI.PH*0U)%051%($E.1$58('9F<U]P871H7VED>"!/3B!H
M;W)D95]M=79F<R`H=F9S7W!A=&@I.PI#4D5!5$4@24Y$15@@=F9S7VYA;65?
M:61X($].(&AO<F1E7VUU=F9S("AV9G-?;F%M92D["@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D
M95]M=79F<RYS<6P`````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q
M,3(U`#$P-3$U-#,S-S4U`#`R,S(P-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O
M<W%L+VAO<F1E7VUU=F9S+G-Q;"QV(#$N,2`R,#`T+S`Y+S$X(#$W.C(P.C4Y
M(&-H=6-K($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R9&5?;75V9G,@*`H@("`@
M=F9S7VED("`@("`@("!"24=)3E0@3D]4($Y53$PL"B`@("!V9G-?='EP92`@
M("`@(%--04Q,24Y4($Y/5"!.54Q,+`H@("`@=F9S7W!A=&@@("`@("!605)#
M2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;F%M92`@("`@(%9!4D-(05(H
M,C4U*2!.3U0@3E5,3"P*("`@('9F<U]M;V1I9FEE9"`@0DE'24Y4($Y/5"!.
M54Q,+`H@("`@=F9S7V]W;F5R("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL
M"B`@("!V9G-?<&5R;7,@("`@(%--04Q,24Y4($Y/5"!.54Q,+`H@("`@=F9S
M7V1A=&$@("`@("!,3TY'0DQ/0BP*+2T@3W(L(&]N('-O;64@1$)-4R!S>7-T
M96US.@HM+2`@=F9S7V1A=&$@("`@("!)34%'12P*("`@(%!224U!4ED@2T59
M("`@*'9F<U]I9"D**3L*"D-214%412!)3D1%6"!V9G-?<&%T:%]I9'@@3TX@
M:&]R9&5?;75V9G,@*'9F<U]P871H*3L*0U)%051%($E.1$58('9F<U]N86UE
M7VED>"!/3B!H;W)D95]M=79F<R`H=F9S7VYA;64I.PH`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q
M;"]H;W)D95]P<F5F<RYM<W-Q;"YS<6P`````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`Q,#$Q`#$P-3$U-#,S-S4U`#`R-#,Q-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````M+2`D2&]R9&4Z(&AO<F1E+W-C
M<FEP=',O<W%L+VAO<F1E7W!R969S+FUS<W%L+G-Q;"QV(#$N,2XR+C(@,C`P
M-B\P-B\R.2`Q-CHR.3HP,R!J86X@17AP("0*"D-214%412!404),12!H;W)D
M95]P<F5F<R`H"B`@("!P<F5F7W5I9"`@("`@("`@5D%20TA!4B@R-34I($Y/
M5"!.54Q,+`H@("`@<')E9E]S8V]P92`@("`@(%9!4D-(05(H,38I($Y/5"!.
M54Q,($1%1D%53%0@)R<L"B`@("!P<F5F7VYA;64@("`@("`@5D%20TA!4B@S
M,BD@3D]4($Y53$PL"B`@("!P<F5F7W9A;'5E("`@("`@5D%20TA!4BA-05@I
M+`HM+0H@("`@4%))34%262!+15D@*'!R969?=6ED+"!P<F5F7W-C;W!E+"!P
M<F5F7VYA;64I"BD["@I#4D5!5$4@24Y$15@@<')E9E]U:61?:61X($].(&AO
M<F1E7W!R969S("AP<F5F7W5I9"D["D-214%412!)3D1%6"!P<F5F7W-C;W!E
M7VED>"!/3B!H;W)D95]P<F5F<R`H<')E9E]S8V]P92D["@I'4D%.5"!314Q%
M0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?<')E9G,@5$\@
M:&]R9&4["@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I
M<'1S+W-Q;"]H;W)D95]P<F5F<RYS<6P`````````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P-S<T`#$P-3$U-#,S-S4U`#`R,S$W-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````M+2`D2&]R9&4Z(&AO
M<F1E+W-C<FEP=',O<W%L+VAO<F1E7W!R969S+G-Q;"QV(#$N,BXQ,"XQ(#(P
M,#8O,#8O,CD@,38Z,CDZ,#,@:F%N($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R
M9&5?<')E9G,@*`H@("`@<')E9E]U:60@("`@("`@(%9!4D-(05(H,C4U*2!.
M3U0@3E5,3"P*("`@('!R969?<V-O<&4@("`@("!605)#2$%2*#$V*2!.3U0@
M3E5,3"!$149!54Q4("<G+`H@("`@<')E9E]N86UE("`@("`@(%9!4D-(05(H
M,S(I($Y/5"!.54Q,+`H@("`@<')E9E]V86QU92`@("`@(%1%6%0L"BTM"B`@
M("!04DE-05)9($M%62`H<')E9E]U:60L('!R969?<V-O<&4L('!R969?;F%M
M92D**3L*"D-214%412!)3D1%6"!P<F5F7W5I9%]I9'@@3TX@:&]R9&5?<')E
M9G,@*'!R969?=6ED*3L*0U)%051%($E.1$58('!R969?<V-O<&5?:61X($].
M(&AO<F1E7W!R969S("AP<F5F7W-C;W!E*3L*"D=204Y4(%-%3$5#5"P@24Y3
M15)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]P<F5F<R!43R!H;W)D93L*
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R
M9&5?<V5S<VEO;FAA;F1L97(N;7-S<6PN<W%L````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#4V-P`Q,#4Q-30S,S<U-0`P,C8R,S<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S
M+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE<BYM<W-Q;"YS<6PL=B`Q+C$N,BXQ
M(#(P,#8O,#$O,3@@,3DZ-3DZ,3`@8F5N($5X<"`D"@I#4D5!5$4@5$%"3$4@
M:&]R9&5?<V5S<VEO;FAA;F1L97(@*`H@("`@<V5S<VEO;E]I9"`@("`@("`@
M("`@("!605)#2$%2*#,R*2!.3U0@3E5,3"P*("`@('-E<W-I;VY?;&%S=&UO
M9&EF:65D("`@24Y4($Y/5"!.54Q,+`H@("`@<V5S<VEO;E]D871A("`@("`@
M("`@("!605)"24Y!4EDH34%8*2P*"B`@("!04DE-05)9($M%62`H<V5S<VEO
M;E]I9"D**3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$54
M12!/3B!H;W)D95]S97-S:6]N:&%N9&QE<B!43R!H;W)D93L*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W-E<W-I;VYH
M86YD;&5R+FUY<W%L+G-Q;```````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`V,3,`,3`U,34T
M,S,W-34`,#(V,C,U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"TM("1(;W)D93H@:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?
M<V5S<VEO;FAA;F1L97(N;7ES<6PN<W%L+'8@,2XQ+C(N,2`R,#`V+S`S+S(R
M(#$X.C,P.C(S(&IA;B!%>'`@)`H*0U)%051%(%1!0DQ%(&AO<F1E7W-E<W-I
M;VYH86YD;&5R("@*("`@('-E<W-I;VY?:60@("`@("`@("`@("`@5D%20TA!
M4B@S,BD@3D]4($Y53$PL"B`@("!S97-S:6]N7VQA<W1M;V1I9FEE9"`@($E.
M5"!.3U0@3E5,3"P*("`@('-E<W-I;VY?9&%T82`@("`@("`@("`@3$].1T),
M3T(L"@H@("`@4%))34%262!+15D@*'-E<W-I;VY?:60I"BD@14Y'24Y%(#T@
M26YN;T1".PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%
M($].(&AO<F1E7W-E<W-I;VYH86YD;&5R(%1/(&AO<F1E0&QO8V%L:&]S=#L*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE<BYO8VDX
M+G-Q;````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-38P`#$P-3$U-#,S-S4U`#`R-3<S
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````M
M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W-E<W-I;VYH86YD
M;&5R+F]C:3@N<W%L+'8@,2XR+C$P+C$@,C`P-2\Q,"\Q."`Q,3HS-#HP,"!J
M86X@17AP("0*"D-214%412!404),12!H;W)D95]S97-S:6]N:&%N9&QE<B`H
M"B`@("!S97-S:6]N7VED("`@("`@("`@("`@(%9!4D-(05(R*#,R*2!.3U0@
M3E5,3"P*("`@('-E<W-I;VY?;&%S=&UO9&EF:65D("`@24Y4($Y/5"!.54Q,
M+`H@("`@<V5S<VEO;E]D871A("`@("`@("`@("!"3$]"+`HM+0H@("`@4%))
M34%262!+15D@*'-E<W-I;VY?:60I"BD["@I'4D%.5"!314Q%0U0L($E.4T52
M5"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?<V5S<VEO;FAA;F1L97(@5$\@
M:&]R9&4["@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R
M:7!T<R]S<6PO:&]R9&5?<V5S<VEO;FAA;F1L97(N<&=S<6PN<W%L````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#4U,0`Q,#4Q-30S,S<U-0`P,C8R,3<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+2T@)$AO<F1E.B!H
M;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE<BYP9W-Q;"YS
M<6PL=B`Q+C$@,C`P-"\P.2\Q."`Q-SHR,#HU.2!C:'5C:R!%>'`@)`H*0U)%
M051%(%1!0DQ%(&AO<F1E7W-E<W-I;VYH86YD;&5R("@*("`@('-E<W-I;VY?
M:60@("`@("`@("`@("`@5D%20TA!4B@S,BD@3D]4($Y53$PL"B`@("!S97-S
M:6]N7VQA<W1M;V1I9FEE9"`@($E.5"!.3U0@3E5,3"P*("`@('-E<W-I;VY?
M9&%T82`@("`@("`@("`@5$585"P*("`@(%!224U!4ED@2T59("AS97-S:6]N
M7VED*0HI.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%
M($].(&AO<F1E7W-E<W-I;VYH86YD;&5R(%1/(&AO<F1E.P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO
M<F1E7W-E<W-I;VYH86YD;&5R+G-A<&1B+G-Q;```````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`T-#8`,3`U,34T,S,W-34`,#(V,38U`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"TM("1(;W)D93H@:&]R9&4O<V-R:7!T
M<R]S<6PO:&]R9&5?<V5S<VEO;FAA;F1L97(N<V%P9&(N<W%L+'8@,2XQ(#(P
M,#0O,#DO,3@@,3<Z,C`Z-3D@8VAU8VL@17AP("0*"D-214%412!404),12!H
M;W)D95]S97-S:6]N:&%N9&QE<B`H"B`@("!S97-S:6]N7VED("`@("`@("`@
M("`@(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@<V5S<VEO;E]L87-T;6]D
M:69I960@("!)3E0@3D]4($Y53$PL"B`@("!S97-S:6]N7V1A=&$@("`@("`@
M("`@($Q/3D<@0EE412P*("`@(%!224U!4ED@2T59("AS97-S:6]N7VED*0HI
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]S97-S:6]N
M:&%N9&QE<BYS<6P`````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-C4P`#$P-3$U
M-#,S-S4U`#`R-3`W,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L+VAO<F1E
M7W-E<W-I;VYH86YD;&5R+G-Q;"QV(#$N,2`R,#`T+S`Y+S$X(#$W.C(P.C4Y
M(&-H=6-K($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R9&5?<V5S<VEO;FAA;F1L
M97(@*`H@("`@<V5S<VEO;E]I9"`@("`@("`@("`@("!605)#2$%2*#,R*2!.
M3U0@3E5,3"P*("`@('-E<W-I;VY?;&%S=&UO9&EF:65D("`@24Y4($Y/5"!.
M54Q,+`H@("`@<V5S<VEO;E]D871A("`@("`@("`@("!,3TY'0DQ/0BP*+2T@
M3W(L(&]N('-O;64@1$)-4R!S>7-T96US.@HM+2`@<V5S<VEO;E]D871A("`@
M("`@("`@("!)34%'12P*"B`@("!04DE-05)9($M%62`H<V5S<VEO;E]I9"D*
M*3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H
M;W)D95]S97-S:6]N:&%N9&QE<B!43R!H;W)D93L*````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?=&]K96YS+G-Q;```````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#4T,0`Q,#4Q-30S,S<U-0`P,C,S
M-3,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]T;VME;G,N<W%L
M+'8@,2XR+C$P+C(@,C`P-2\Q,"\Q."`Q,3HS-#HP,"!J86X@17AP("0*"D-2
M14%412!404),12!H;W)D95]T;VME;G,@*`H@("`@=&]K96Y?861D<F5S<R`@
M("!605)#2$%2*#$P,"D@3D]4($Y53$PL"B`@("!T;VME;E]I9"`@("`@("`@
M(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@=&]K96Y?=&EM97-T86UP("!"
M24=)3E0@3D]4($Y53$PL"BTM"B`@("!04DE-05)9($M%62`H=&]K96Y?861D
M<F5S<RP@=&]K96Y?:60I"BD["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$
M051%+"!$14Q%5$4@3TX@:&]R9&5?=&]K96YS(%1/(&AO<F1E.PH`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C
M<FEP=',O<W%L+VAO<F1E7W5S97)S+G-Q;```````````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`V,C(`,3`U,34T,S,W-34`,#(S,C$Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"TM("1(;W)D93H@
M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?=7-E<G,N<W%L+'8@,2XR+C$P+C(@
M,C`P-2\Q,"\Q."`Q,3HS-#HP,"!J86X@17AP("0*"D-214%412!404),12!H
M;W)D95]U<V5R<R`H"B`@("!U<V5R7W5I9"`@("`@("`@("`@("`@("`@("`@
M5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=7-E<E]P87-S("`@("`@("`@
M("`@("`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('5S97)?<V]F
M=%]E>'!I<F%T:6]N7V1A=&4@("!)3E1%1T52+`H@("`@=7-E<E]H87)D7V5X
M<&ER871I;VY?9&%T92`@($E.5$5'15(L"BTM"B`@("!04DE-05)9($M%62`H
M=7-E<E]U:60I"BD["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$
M14Q%5$4@3TX@:&]R9&5?=7-E<G,@5$\@:&]R9&4["@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H
M;W)D95]V9G,N;7-S<6PN<W%L````````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`Q,#<U`#$P-3$U-#,S-S4U`#`R-#`P-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP
M=',O<W%L+VAO<F1E7W9F<RYM<W-Q;"YS<6PL=B`Q+C$N,BXQ(#(P,#8O,#$O
M,3@@,3DZ-3DZ,38@8F5N($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R9&5?=F9S
M("@*("`@('9F<U]I9"`@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@("`@=F9S
M7W1Y<&4@("`@("!334%,3$E.5"!.3U0@3E5,3"P*("`@('9F<U]P871H("`@
M("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VYA;64@("`@("!6
M05)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;6]D:69I960@($))1TE.
M5"!.3U0@3E5,3"P*("`@('9F<U]O=VYE<B`@("`@5D%20TA!4B@R-34I($Y/
M5"!.54Q,+`H@("`@=F9S7V1A=&$@("`@("!605)"24Y!4EDH34%8*2P*("`@
M(%!224U!4ED@2T59("`@*'9F<U]I9"D**3L*"D-214%412!)3D1%6"!V9G-?
M<&%T:%]I9'@@3TX@:&]R9&5?=F9S("AV9G-?<&%T:"D["D-214%412!)3D1%
M6"!V9G-?;F%M95]I9'@@3TX@:&]R9&5?=F9S("AV9G-?;F%M92D["@I'4D%.
M5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?=F9S
M(%1/(&AO<F1E.PH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S
M+W-Q;"]H;W)D95]V9G,N;V-I."YS<6P`````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`Q,#4U`#$P-3$U-#,S-S4U`#`R,S4Q,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````M+2`D2&]R9&4Z(&AO<F1E
M+W-C<FEP=',O<W%L+VAO<F1E7W9F<RYO8VDX+G-Q;"QV(#$N,R`R,#`T+S`Y
M+S(Q(#`S.C,T.C`V(&-H=6-K($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R9&5?
M=F9S("@*("`@('9F<U]I9"`@("`@("`@3E5-0D52*#$V*2!.3U0@3E5,3"P*
M("`@('9F<U]T>7!E("`@("`@3E5-0D52*#@I($Y/5"!.54Q,+`H@("`@=F9S
M7W!A=&@@("`@("!605)#2$%2,B@R-34I+`H@("`@=F9S7VYA;64@("`@("!6
M05)#2$%2,B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VUO9&EF:65D("!.54U"
M15(H,38I($Y/5"!.54Q,+`H@("`@=F9S7V]W;F5R("`@("!605)#2$%2,B@R
M-34I+`H@("`@=F9S7V1A=&$@("`@("!"3$]"+`HM+0H@("`@4%))34%262!+
M15D@("`H=F9S7VED*0HI.PH*0U)%051%($E.1$58('9F<U]P871H7VED>"!/
M3B!H;W)D95]V9G,@*'9F<U]P871H*3L*0U)%051%($E.1$58('9F<U]N86UE
M7VED>"!/3B!H;W)D95]V9G,@*'9F<U]N86UE*3L*"D=204Y4(%-%3$5#5"P@
M24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]V9G,@5$\@:&]R9&4[
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M8W)I<'1S+W-Q;"]H;W)D95]V9G,N<&=S<6PN<W%L````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`Q,#8R`#$P-3$U-#,S-S4U`#`R,S<W,@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````M+2`D2&]R9&4Z
M(&AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W9F<RYP9W-Q;"YS<6PL=B`Q+C$@
M,C`P-"\P.2\Q."`Q-SHR,#HU.2!C:'5C:R!%>'`@)`H*0U)%051%(%1!0DQ%
M(&AO<F1E7W9F<R`H"B`@("!V9G-?:60@("`@("`@($))1TE.5"!.3U0@3E5,
M3"P*("`@('9F<U]T>7!E("`@("`@4TU!3$Q)3E0@3D]4($Y53$PL"B`@("!V
M9G-?<&%T:"`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]N
M86UE("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VUO9&EF
M:65D("!"24=)3E0@3D]4($Y53$PL"B`@("!V9G-?;W=N97(@("`@(%9!4D-(
M05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]D871A("`@("`@5$585"P*"B`@
M("!04DE-05)9($M%62`@("AV9G-?:60I"BD["@I#4D5!5$4@24Y$15@@=F9S
M7W!A=&A?:61X($].(&AO<F1E7W9F<R`H=F9S7W!A=&@I.PI#4D5!5$4@24Y$
M15@@=F9S7VYA;65?:61X($].(&AO<F1E7W9F<R`H=F9S7VYA;64I.PH*1U)!
M3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7W9F
M<R!43R!H;W)D93L*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]V9G,N<W%L````````````````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,34P`#$P-3$U-#,S-S4U`#`R,C8T,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````M+2`D
M2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W9F<RYS<6PL=B`Q+C$N
M,3`N,B`R,#`U+S$P+S$X(#$Q.C,T.C`P(&IA;B!%>'`@)`H*0U)%051%(%1!
M0DQ%(&AO<F1E7W9F<R`H"B`@("!V9G-?:60@("`@("`@($))1TE.5"!.3U0@
M3E5,3"P*("`@('9F<U]T>7!E("`@("`@4TU!3$Q)3E0@3D]4($Y53$PL"B`@
M("!V9G-?<&%T:"`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F
M<U]N86UE("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VUO
M9&EF:65D("!"24=)3E0@3D]4($Y53$PL"B`@("!V9G-?;W=N97(@("`@(%9!
M4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]D871A("`@("`@3$].1T),
M3T(L"BTM($]R+"!O;B!S;VUE($1"35,@<WES=&5M<SH*+2T@('9F<U]D871A
M("`@("`@24U!1T4L"B`@("!04DE-05)9($M%62`@("AV9G-?:60I"BD["@I#
M4D5!5$4@24Y$15@@=F9S7W!A=&A?:61X($].(&AO<F1E7W9F<R`H=F9S7W!A
M=&@I.PI#4D5!5$4@24Y$15@@=F9S7VYA;65?:61X($].(&AO<F1E7W9F<R`H
M=F9S7VYA;64I.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,
M151%($].(&AO<F1E7W9F<R!43R!H;W)D93L*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]214%$344`````````````````````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$R-34S`#$P-3$U-#,S-S4U`#`R
M,3`S-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@2&]R9&4@
M1&%T86)A<V4@26YS=&%L;&%T:6]N($=U:61E"CT]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]"@HZ3&%S="!U<&1A=&4Z("`@)$1A=&4Z(#(P
M,#4O,3`O,3@@,3$Z,S0Z,#`@)`HZ4F5V:7-I;VXZ("`@("`@)%)E=FES:6]N
M.B`Q+C(N,3`N,R`D"CI#;VYT86-T.B`@("`@("!H;W)D94!L:7-T<RYH;W)D
M92YO<F<*"@I0=7)P;W-E(&]F('1H:7,@9FEL90I^?GY^?GY^?GY^?GY^?GY^
M?GY^?@H*5&AI<R!F:6QE('=I;&P@:&]P969U;&QY(&5A<V4@=&AE(&EN<W1A
M;&QA=&EO;B!A;F0@8V]N9FEG=7)A=&EO;B!O9B!Y;W5R"F1A=&%B87-E(&9O
M<B!U<V4@=VET:"!(;W)D92X@(%1H92!S8V]P92!O9B!T:&4@9&]C=6UE;G0@
M9&5A;',@<')I;6%R:6QY('=I=&@*=7-I;F<@>6]U<B!D871A8F%S92!W:71H
M($AO<F1E(&%N9"!S:&]U;&0@;F]T(&)E(&-O;G-I9&5R960@82!R97-O=7)C
M92!F;W(*9V5N97)A;"!D871A8F%S92!T87-K<RX*"@I297%U:7)E;65N=',@
M9F]R($AO<F1E"GY^?GY^?GY^?GY^?GY^?GY^?GY^?GX*"DAO<F1E(&-U<G)E
M;G1L>2!S=7!P;W)T<R!A="!L96%S="`W(&1A=&%B87-E<SH*"B`@("`M($UY
M4U%,("`@("`@("`@:'1T<#HO+W=W=RYM>7-Q;"YC;VTO"B`@("`M(%!O<W1G
M<F5344P@("`@:'1T<#HO+W=W=RYP;W-T9W)E<W%L+F]R9R\*("`@("T@3W)A
M8VQE("`@("`@("!H='1P.B\O=W=W+F]R86-L92YC;VTO"B`@("`M(%-Y8F%S
M92`@("`@("`@:'1T<#HO+W=W=RYS>6)A<V4N8V]M+PH@("`@+2!344QI=&4@
M("`@("`@(&AT='`Z+R]W=W<N<W%L:71E+F]R9R\*("`@("T@35,@4U%,("`@
M("`@("!H='1P.B\O=W=W+FUI8W)O<V]F="YC;VTO<W%L+PH@("`@+2!-4T1%
M("`@("`@("`@(&AT='`Z+R]W=W<N;6EC<F]S;V9T+F-O;2]S<6PO;7-D92\*
M"DUY4U%,(&%N9"!0;W-T9W)E4U%,(&%R92!R96=U;&%R;'D@=7-E9"!B>2!T
M:&4@9&5V96QO<&UE;G0@=&5A;2P@86YD('=I;&P@=V]R:PIW:71H(&YO('!R
M;V)L96US+B`@3W)A8VQE(&%N9"!344QI=&4@<W5P<&]R="!H87,@8F5E;B!M
M=6-H(&EM<')O=F5D(')E8V5N=&QY"F%N9"!W;W)K<R!F:6YE('1O;RX@(%-Y
M8F%S92!W97)E(')E<&]R=&5D('=O<FMI;F<@:6X@=&AE('!R979I;W5S('9E
M<G-I;VX@;V8*2&]R9&4O24U0(&)Y('-O;64@;V8@;W5R('5S97)S+"!A;F0@
M87)E(&%S<W5M960@=&\@<W1I;&P@=V]R:RXN+B!B=70@=&AA=`IH87-N)W0@
M8F5E;B!V97)I9FEE9"!R96-E;G1L>2X*"@I"969O<F4@66]U($)E9VEN"GY^
M?GY^?GY^?GY^?GY^?GX*"EEO=2!W:6QL(&YE960@=&\@:&%V92!Y;W5R(&1A
M=&%B87-E('!R96-O;F9I9W5R960@86YD('=O<FMI;F<@;VX@>6]U<B!S>7-T
M96T*8F5F;W)E('EO=2!E=F5N(&=E="!T;R!T:&ES('-T86=E+B`@1F]R(&AE
M;'`@=VET:"!T:&ES+"!P;&5A<V4@8V]N<W5L="!Y;W5R"F1A=&%B87-E('-P
M96-I9FEC(&AE;'`@9FEL97,N"@I"969O<F4@=7-I;F<@86YY(&]F('1H92!S
M8W)I<'1S(&QI<W1E9"!B96QO=RP@<&QE87-E(&QO;VL@;W9E<B!T:&5M('1O
M(&5N<W5R90IT:&%T(&%N>2!S>7-T96TM<W!E8VEF:6,@<V5T=&EN9W,@*&]R
M('!E<G-O;F%L(&-H;VEC97,I(&%R92!S970@=&\@>6]U<@ID97-I<F5D('-E
M='1I;F=S("AE9RX@8&!U<V5R;F%M96!@+"!E=&,N*2X*"BHJ4$Q%05-%($Y/
M5$4J*B!T:&%T('1H92!D871A8F%S92!C;VYF:6=U<F%T:6]N('-T97!S(&QI
M<W1E9"!B96QO=R`J*DU54U0J*@IM871C:"!W:&%T(&ES(&-O;F9I9W5R960@
M=VET:&EN($AO<F1E+@H*4W!E8VEF:6-A;&QY+"!I9B!Y;W4@8VAA;F=E('1H
M92!D871A8F%S92!N86UE+"!U<V5R+"!O<B!P87-S=V]R9"!W:&EL90IC;VYF
M:6=U<FEN9R!T:&4@9&%T86)A<V4@*&)E;&]W*2P@>6]U('=I;&P@;F5E9"!T
M;R!M86ME('1H92!S86UE(&-H86YG97,@=&\*>6]U<B!(;W)D92!C;VYF:6=U
M<F%T:6]N(&9I;&5S(&%S('=E;&PN"@H*37E344P*?GY^?GX*"E1H92!M>7-Q
M;%]C<F5A=&4N<W%L('-C<FEP="!W:6QL(&-R96%T92!A(&1A=&%B87-E(&-A
M;&QE9"!@8&AO<F1E8&`L(&%N9"!A"G5S97(@8V%L;&5D(&!@:&]R9&5@8"`H
M=VET:"!P87-S=V]R9"!@8&AO<F1E8&`I('1H870@:&%S(&9U;&P@<FEG:'1S
M('1O('1H90ID871A8F%S92X@("I.;W1E('1H870@=VET:"!->5-13"P@4$5!
M4B!$0B!E;75L871E<R!S97%U96YC97,@8GD@875T;VUA=&EC86QL>0IC<F5A
M=&EN9R!E>'1R82!T86)L97,@96YD:6YG(&EN(%]S97$L('-O('1H92!->5-1
M3"!@8&AO<F1E8&`@=7-E<B!M=7-T(&AA=F4*8&!#4D5!5$5@8"!P<FEV:6QE
M9V4@;VX@=&AE(&!@:&]R9&5@8"!D871A8F%S92X*"E1H:7,@<V-R:7!T(&YE
M961S('1O(&)E(')U;B!A<R!T:&4@37E344P@<F]O="!U<V5R("AW:&EC:"!I
M<R`J3D]4*B!T:&4@<V%M92!A<PIT:&4@54Y)6"],:6YU>"!R;V]T('5S97(I
M.CH*"B`@)"!M>7-Q;"`M+75S97(]<F]O="`M+7!A<W-W;W)D/3Q->5-13"UR
M;V]T+7!A<W-W9#X@/"!C<F5A=&4N;7ES<6PN<W%L"@I!9G1E<B!R=6YN:6YG
M('1H:7,@<V-R:7!T+"!I="=S(&$@9V]O9"!I9&5A('1O(')E<W1A<G0@>6]U
M<B!->5-13"!S97)V97(Z.@H*("`D(&UY<W%L861M:6X@+2UU<V5R/7)O;W0@
M+2UP87-S=V]R9#T\37E344PM<F]O="UP87-S=V0^(')E;&]A9`H*5&\@8VAE
M8VL@=&AA="!T:&ES(&ES('=O<FMI;F<L('1H92!F;VQL;W=I;F<@8V]M;6%N
M9"!S:&]U;&0@8V]N;F5C="!W:71H;W5T"F5R<F]R<SHZ"@H@("0@;7ES<6P@
M+2UU<V5R/6AO<F1E("TM<&%S<W=O<F0]:&]R9&4@:&]R9&4*"E1Y<&4@8&!Q
M=6ET8&`@=&\@<75I="!->5-13"X*"@I0;W-T9W)E4U%,"GY^?GY^?GY^?GX*
M"B`@(R!S=2`M('!O<W1G<F5S("`H;W(@=VAA=&5V97(@>6]U<B!D871A8F%S
M92!R=6YS(&%S+BXN('5S=6%L;'D@<&]S=&=R97,I"B`@)"!P<W%L("UD('1E
M;7!L871E,2`M9B!C<F5A=&4N<&=S<6PN<W%L"@I4:&ES('-C<FEP="!W:6QL
M(&-R96%T92!A(&!@:&]R9&5@8"!D871A8F%S92!A;F0@82!@8&AO<F1E8&`@
M=7-E<BX@(%EO=2!S:&]U;&0*<V5T(&$@<&%S<W=O<F0@9F]R('1H:7,@=7-E
M<B!W:71H('1H:7,@8V]M;6%N9"`H:68@>6]U(&1I9&XG="!U;F-O;6UE;G0@
M=&AE"F]N92!I;B!P9W-Q;%]C<F5A=&4N<W%L*3HZ"@H@("0@<'-Q;"`M<6,@
M(D%,5$52(%5315(@:&]R9&4@5TE42"!005-35T]21"`G<&%S<R<[(B!T96UP
M;&%T93$@<&]S=&=R97,*"E1H96X@8W)E871E('1H92!T86)L97,@=VET:&EN
M('1H92!@8&AO<F1E8&`@9&%T86)A<V4Z.@H*("`D('!S<6P@+60@:&]R9&4@
M+68@:&]R9&5?=7-E<G,N<W%L"B`@)"!P<W%L("UD(&AO<F1E("UF(&AO<F1E
M7W!R969S+G-Q;`H@("0@<'-Q;"`M9"!H;W)D92`M9B!H;W)D95]D871A=')E
M92YS<6P*"E1H97-E('-C<FEP=',@=VEL;"!A;'-O(&=R86YT('1H92!@8&AO
M<F1E8&`@=7-E<B!T:&4@;F5C97-S87)Y('!R:79I;&5G97,@=&\*96%C:"!O
M9B!T:&4@=&%B;&5S+@H*"D]R86-L90I^?GY^?GX*"E)U;B!@8'-Q;'!L=7-@
M8"X@($QO9VEN+"!T:&5N(%MW92!N965D(&EN<W1R=6-T:6]N<R!F;W(@8W)E
M871I;F<@=&AE(&1A=&%B87-E"F%N9"!U<V5R(&AE<F5=+@H*5&AA="!S:&]U
M;&0@8F4@:70N("!297-T87)T($]R86-L92!J=7-T('1O(&)E('-U<F4L(&%N
M9"!T<GD@:70N("!4:&5N(&-R96%T90IT:&4@=&%B;&5S('=I=&AI;B!T:&4@
M8&!H;W)D96!@(&1A=&%B87-E.CH*"EM!;'-O(&YE960@=&AO<V4@:6YS=')U
M8W1I;VYS(&AE<F4N70H*"E-Y8F%S90I^?GY^?GX*"E1O(&-R96%T92!T:&4@
M9&%T86)A<V4L(&9R;VT@8&!I<W%L8&`@<G5N.CH*"B`@8W)E871E(&1A=&%B
M87-E(&AO<F1E"@I.97AT+"!Y;W4@<VAO=6QD("AR96-O;6UE;F1E9"D@8W)E
M871E(&$@;&]G:6X@=&\@=7-E('=I=&@@=&AI<R!D871A8F%S92X@(%1H90I@
M8&ES<6Q@8"!C;VUM86YD(&9O<B!T:&ES(&ES.CH*"B`@<W!?861D;&]G:6X@
M/'5S97)N86UE/B`\<&%S<W=O<F0^"@I.97AT('EO=2!N965D('1O(&-H86YG
M92!T:&4@;W=N97)S:&EP(&]F('1H92!D871A8F%S92!T;R!T:&ES(&YE=R!U
M<V5R+B`@5&AE"F!@:7-Q;&!@(&-O;6UA;F0@9F]R('1H:7,@:7,Z.@H*("!S
M<%]C:&%N9V5D8F]W;F5R(#QU<V5R;F%M93X*"D%F=&5R('1H870L('EO=2!J
M=7-T(&YE960@=&\@<V5T('5P('EO=7(@=&%B;&5S('=I=&AI;B!T:&4@9&%T
M86)A<V4N("!4;R!D;PIT:&%T+"!J=7-T(')U;B!T:&ES(&-O;6UA;F0@9G)O
M;2!T:&4@8V]M;6%N9"!L:6YE.CH*"B`@:7-Q;"`M:2!H;W)D95]U<V5R<RYS
M<6P@+54\=7-E<FYA;64^("U0/'!A<W-W;W)D/@H@(&ES<6P@+6D@:&]R9&5?
M<')E9G,N<W%L("U5/'5S97)N86UE/B`M4#QP87-S=V]R9#X*"@I-4T1%(#(P
M,#`@*&%N9"!P;W-S:6)L>2!-4R!344P@4V5R=F5R*0I^?GY^?GY^?GY^?GY^
M?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?@H*5&\@8W)E871E('5S97(@86YD
M(&1A=&%B87-E+"!U<V4@=&AE(&]S<6P@8V]M;6%N9#HZ"@H@($,Z7#YO<W%L
M("U5('-A("U0(&%D;6EN7W!A<W-W;W)D("U3(&QO8V%L:&]S="`M:2!C<F5A
M=&4N;7-D92YS<6P*"D)E('-U<F4@=&\@8VAA;F=E('1H92!P87-S=V]R9"!F
M;W(@=&AE(&AO<F1E('5S97(@:6X@=&AE('-C<FEP="!F:6QE+B`@5&\*<W!E
M8VEF>2!A('!A<G1I8W5L87(@:6YS=&%N8V4@;V8@=&AE(%-13"!S97)V97(@
M=7-E('1H90H\<V5R=F5R;F%M93XO/&EN<W1A;F-E/B!F;W(@=&AE("U3(&9L
M86<N("!)9B!Y;W4@87)E;B=T('5S:6YG(&UI>&5D(%-13`IA=71H96YT:6-A
M=&EO;BP@=&AE;B!Y;W4G;&P@;F5E9"!T;R!M;V1I9GD@=&AE('-C<FEP="!T
M;R!A<W-O8VEA=&4@=&AE(&AO<F1E"G5S97(@=VET:"!A('=I;F1O=W,@=7-E
M<B!A8V-O=6YT(&%N9"!R=6X@=&AE('-C<FEP="!I;B!T:&4@9F]L;&]W:6YG
M(&UA;FYE<B!A<PIT:&4@061M:6YI<W1R871O<CHZ"@H@($,Z7#YO<W%L("U%
M("U3(&QO8V%L:&]S="`M:2!C<F5A=&4N;7-D92YS<6P*"DEF('EO=2=R92!H
M879I;F<@<')O8FQE;7,@<G5N;FEN9R!T:&ES('-C<FEP="!O;B!A(%-13"!S
M97)V97(@;VX@=&AE(&YE='=O<FLL"F)E('-U<F4@=&AE('-E<G9E<B!I<R!S
M970@=7`@=&\@86QL;W<@;F5T=V]R:R!A8V-E<W,N"@H*061D:71I;VYA;"!.
M;W1E<PI^?GY^?GY^?GY^?GY^?GY^"@I4:&ES(&ES(&)Y(&9A<B!N;W0@82!C
M;VUP;&5T92!(3U=43RX@(%1H:7,@:7,@:G5S="!A(&-O;7!I;&5D(&QI<W0@
M;V8@=VAA=`IP96]P;&4@:&%V92!C;VYT<FEB=71E9"!S;R!F87(N("!)9B!Y
M;W4@:&%V92!T:7!S+"!I9&5A<RP@<W5G9V5S=&EO;G,@;W(*86YY=&AI;F<@
M96QS92!T:&%T('EO=2!T:&EN:R!C;W5L9"!H96QP(&]T:&5R<R!I;B!S971T
M:6YG('5P('1H96ER(&1A=&%B87-E"F9O<B!U<V4@=VET:"!(;W)D92P@<&QE
M87-E(&QE="!U<R!K;F]W+@H*/&1E=D!L:7-T<RYH;W)D92YO<F<^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q
M;"]214%$344N3T-).```````````````````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#(S-#,V`#$P-3$U-#,S-S4U`#`R,34S-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!&25)35"!/1B!!3$PZ"E1H:7,@
M:7,@;F]T(&UY(&9I<G-T(&1O8W5M96YT871I;VXA(&)U="!M>2!F:7)S="!I
M;B!E;F=L:7-H+@I&965L(&9R964@=&\@8V]N=&%C="!M92!A="!T;W)S=&5N
M0&9L86UM:6=E<BYO<F<@:68@>6]U(&AA=F4@"F%N>2!S=6=G97-T:6]N<R!O
M<B!P<F]B;&5M<R!R96QA=&5D('1O('1H:7,@9&]C<PH*06QL(&D@=VEL;"!W
M<FET92!A8F]U="!/<F%C;&4@=VET:"!(;W)D92!I<R!B87-E9"!O;B!/<F%C
M;&4@/CT@.&D*=&AO=6=H(&ET('-H;W5L9"!W;W)K('=I=&@@.6D@=&]O+B`*
M"DD@=&AI;FL@*&DG;2!S=7)E*2`G57`@=&\@9&%T92<@879A:6QA8FQE(&1I
M<W1R:6)U=&EO;G,*87)E(&-A<&%B;&4@=&\@<G5N($]R86-L92X@22!H879E
M('1E<W1E9"!I="!O;@I3;&%C:W=A<F4@-RXQ+S@N,"`H."XQ+C8I(&%N9"!H
M879E(')U;FYI;F<@:70@;VX@1V5N=&]O(#$N,B`H."XQ+C<N-"D*=VET:&]U
M="!A;GD@4')O8FQE;7,N(%-O;64@9&ES=')I8G5T:6]N<R!A<F4@8V5R=&EF
M:65D(&QI:V4@4W5312!O<B`*4F5D2&%T+B!/;B!$96)I86X@:70@<VAO=6QD
M(&%L<V\@<G5N+@H*1G5R=&AE<FUO<F4@:2=L;"!A<W-U;64L('1H870@;F\@
M(FYO<FUA;"(@=7-E<B!I<R!G;VEN9R!T;R!I;G-T86QL"F]R(&ES(&EN(&YE
M960@=&\@:6YS=&%L;"!A;B!/<F%C;&4@1$(@*&]F(&-O=7)S92!T:&5R92!A
M<F4@<V]M92!F<F5A:W,@.RD*<V\@:VYO=VQE9&=E(&%B;W5T('-E='1I;F<@
M=7`@86YD(&UA:6YT86EN(&%N($]R86-L90I$0B!I<R!I;F1I<W!E;G-A8FQE
M(2!-87EB92!T:&ES(&ES('1H92!R96%S;VX@=VAY(&YO($%D;6EN"FAA<R!E
M=F5R('!O<W1E9"!A;GD@9&]C<R!A8F]U="!G971T:6YG($AO<F1E('=O<FL@
M=VET:"!/<F%C;&4*"DY/5$4Z(&%L;"!D;V-S(&%R92!A=F%I;&%B;&4@9G)O
M;2!W=W<N;W)A8VQE+F-O;2!F;W(@9G)E92`H049!24LI"@I.;W<@;&5T)W,@
M8F5G:6XZ"@I#87-E(#$I(`I))VQL(&%S<W5M92!T:&%T('EO=2!D;R!N;W0@
M:&%V92!A;B!I;G-T86YC92!R=6YN:6YG(&%N9"!T:&5R969O<F4*87)E(&%B
M;W5T('1O(&EN<W1A;&P@82!F<F5S:"!I;G-T86YC92`B:&]R9&4B("X*"BTM
M"6-H96-K(&%N9"!I9B!N965D960@8VAA;F=E('-H87)E9"!M96UO<GD@<&%R
M86UE=&5R<PHM+0EC<F5A=&4@870@;&5A<W0@=&AE(&1B82!G<F]U<`HM+0EC
M<F5A=&4@>6]U<B!O<F%C;&4@=7-E<BP@;F%M92!I="!A<R!Y;W4@;&EK90H)
M;6%K92!S=7)E('EO=7(@;W)A+75S97(@:7,@:6X@=&AE(&=R;W5P(&1B80HM
M+0ES=2`M(#QY;W5R(&9R97-H(&]R86-L92!U<V5R/@HM+2`)<V5T('5P(&%L
M;"!T:&4@87!P<F]P<FEA=&4@96YV:7)O;FUE;G0@=F%R:6%B;&5S(&9O<B!O
M<F%C;&4*"71A:V4@82!C;&]S92!L;V]K(&%T('1H92!I;G-T86QL(&AO=W1O
M('!R;W9I9&5D(&)Y(&]R86-L90HM+0EM;W5N="!T:&4@0T0@*&EF(&ET(&ES
M('EO=7(@<V]U<F-E(&UE9&EA*0HM+0ER=6X@=&AE('-C<FEP="!R=6Y);G-T
M86QL97(@+2!B971T97(@=&\@:&%V92!8,3$@:6YS=&%L;&5D(#LI"@E!='1E
M;G1I;VXZ($EF('EO=2!A<F4@86)O=70@=&\@:6YS=&%L;"!/<F%C;&4@.6D*
M"61O($Y/5"!R=6X@=&AE(&EN<W1A;&QE<B!F<F]M(&1I<F5C=&QY(&9R;VT@
M>6]U<B!#1"$*"6QI:V4@8V0@+V-D<F]M(&%N9"!T:&5N('-T87)T(&ET(&)Y
M('1Y<&EN9R`N+W)U;DEN<W1A;&QE<@H)>6]U('=O;B=T(&)E(&%B;&4@=&\@
M=6YM;W5N="!T:&4@0T0@;&%T97(@;VX@8G5T('EO=2!H879E('1O"@EB96-A
M=7-E(#EI(&ES(&$@,T-$+5-E=`HM+0EF;VQL;W<@=&AE(&EN<W1R=6-T:6]N
M<R!G:79E;B!B>2!T:&4@:6YS=&%L;&%T:6]N('!R;V=R86UM"@EA="!T:&4@
M<&]I;G0@=VAE<F4@>6]U(&%R92!A<VME9"!F;W(@86X@:6YS=&%L;&%T:6]N
M(&UE=&AO9`H)8VAO;W-E(")U<V5R+61E9FEN960B+B!4:&ES(&ES="!E<W!E
M8VEA;&QY(%9%4ED@24U03U)414Y4(&EF('EO=0H)87)E(&%B;W5T('1O(&EN
M<W1A;&P@.&D@<VEN8V4@>6]U(&AA=F4@=&\@<&%T8V@@=&AE(&EN<W1A;&QA
M=&EO;@H)0D5&3U)%('EO=2!C<F5A=&4@>6]U<B!D871A8F%S92$@268@>6]U
M(&YO="!C:&]O<V4@(G5S97(M9&5F:6YE9"(*"71H92!P<F]G<F%M(")D8F%S
M<VES="(@=VEL;"!A=71O;6%T:6-A;&QY('-T87)T(&%T('1H92!E;F0@;V8*
M"71H92!I;G-T86QL871I;VX@<')O8V5S<R!A;F0@=VEL;"!H86YG(&%N9"]O
M<B!F86EL+@HM+0EA="!T:&4@96YD(&]F('EO=7(@:6YS=&%L;&%T:6]N('EO
M=2!H879E('1O(&-O;F9I9W5R92!Y;W5R(&QI<W1E;F5R+F]R82P*"71N<VYA
M;65S+F]R82!A;F0@>6]U<B!S<6QN970N;W)A(%1H:7,@:7,@86QL(&1O;F4@
M8GD@=&AE"@EI;G-T86QL871I;VX@<')O9W)A;6TN(`HM+0E.;W<Z(&EF('EO
M=2!U<V4@."XQ+C<@9V5T('1H92!P871C:"!G;&EB8RTR+C$N,RUS='5B<RYT
M87(N9WH@9G)O;2!/<F%C;&4N(`H)270G<R!A="!T:&4@<V%M92!P86=E(&QI
M:V4@=&AE(&1B+7-O=7)C92X@26YS=&%L;"!A<R!D97-C<FEB960@:6X@4D5!
M1$U%+G-T=6(*"2AI="=S(&EN('1H92!P86-K86=E('-O(&9I<G-T('5N=&%R
M(&ET('-O;65W:&5R92!E;'-E(&]R('5S92`G;6,G("D*+2T)3F]W(&-R96%T
M92!Y;W5R(&1A=&%B87-E+B!2=6X@(F1B87-S:7-T(@H)270G<R!N;W<@;VX@
M>6]U('1O(&1E8VED92!H;W<@8FEG('1H92!I;FET:6%L('1A8FQE<W!A8V5S
M(&%R92P@:&]W(&UA;GD*"6-O;G1R;VP@9FEL97,@>6]U(&QI:V4L(&]F(&-O
M=7)S92!H;W<@:70G<R!N86UE('=I;&P@8F4@86YD('=H870*"6]P=&EO;B!Y
M;W4@<&QA;B!T;R!U<V4@;&EK92!);G1E<DUE9&EA+B!)="=S(%EO=7(@1&5C
M:7-I;VX@(0H)*$)45SH@=&AE(&1E9F%U;'1S('=I;&P@=V]R:R!A;F0@87)E
M('9E<GD@=&EM92!C;VYS=6UI;F<@.RD*"4%T('1H92!E;F0@;&5T('1H92!D
M8F%S:7-T('!R;V=R86T@<V%V92!T:&4@8V]N9FEG=7)A=&EO;BX@66]U(&-A
M;B!C:&]O<V4*"6QO8V%T:6]N(&%N9"!N86UE+B!.;W<@>6]U(&-A;B!C;&]S
M92!D8F%S<VES="X*+2T)8VAA;F=E('1O('1H92!L;V-A=&EO;B!W:&5R92!Y
M;W4@<W1O<F5D('1H92!S8W)I<'1S(&%N9"!T86ME(&$@<VAO<G0@;&]O:PH)
M870@;&5A<W0@:6YT;R!O<F%C;&5R=6XN<V@@86YD(&]R86-L97)U;C$N<V@N
M($EF(&%L;"!I<R!/2R!C<F5A=&4@=&AE(&1A=&%B87-E.@H)<G5N("XO;W)A
M8VQE<G5N+G-H+B`*"5-I="!B86-K('1A:V4@82!C=7`@;V8@8V]F9F5E(&%N
M9"!H;W!E(&%L;"!W:6QL(&)E(&=O;V0@.RD*"@E)9B!Y;W4@8VAO;W-E9"!T
M:&4@26YT97)-961I82!O<'1I;VX@=&AE(&-R96%T:6]N('!R;V-E<W,@=VEL
M;"!T86ME"@EA8F]U="`R(&%N9"!A(&AA;&8@:&]U<B`H;VX@;7D@-3`P34AZ
M+5`S(#HM*2X@5VET:&]U="!*879A(&ET('=I;&P@=&%K90H)86)O=70@,2!H
M;W5R+B`H=&AI<R!B;W1H(&ES="!S:&]R="`M(#EI('1A:V5S(&%S(&UI;BX@
M='=I8V4@=&AA="!T:6UE("$I"@D*"4Y/5$4Z(&-H;V]S:6YG($EN=&5R365D
M:6$@=VEL;"!G:79E('EO=2!E;FAA;F-E9"!P;W-S:6)I;&ET:65S(&9O<B!S
M=&]R:6YG"@EA;F0@;6%N:7!U;&%T:6YG(&UE9&EA(&9I;&5S+B!,;V]K(&%T
M(&AT='`Z+R]I;G1E<FUE9&EA+F%S+61A=&%S97)V:6-E+F1E+PH)9F]R(&%N
M(&5X86UP;&4N+BX*"0H)04Y/5$A%4B!.3U1%.B!I9B!Y;W4@:6YS=&%L;&5D
M(#@N,2XW(&%N9"!A9G1E<G=A<F1S(&%P<&QI960@86X@=7`@=&\@9&%T90H)
M<&%T8VAS970@*&QI:V4@."XQ+C<N-"D@>6]U($U54U0@<F5P871C:"!Y;W5R
M(&EN<W1A;&QA=&EO;B!W:71H('1H92`*"6=L:6)C+7-T=6)S('!A=&-H(&]R
M('EO=7(@1$(@=V]N)W0@<G5N"@D*"5!23T),14U3(#\Z($QO;VL@870@=W=W
M+F]R869A<2YC;VT@9F]R('EO=7(@86YS=V5R"@I!;&P@=V5N="!F:6YE/R!'
M;V]D+"!L971S(&=O(&%H96%D(&%N9"!C<F5A=&4@82!N97<@=&%B;&5S<&%C
M92!C86QL960@:&]R9&4*"BTM"51H92!D871A8F%S92!S:&]U;&0@<G5N(&%F
M=&5R(&ET('=A<R!S=6-C97-F=6QL>2!C<F5A=&5D+B!,;V=I;B!A<R!U<V5R
M('-Y<W1E;0H);W(@<WES("AL:6ME('EO=2!P<F5F97(I+B!4:&4@<&%S<W=O
M<F1S('=H97)E('=R:71T96X@=&\@>6]U(&]N(%-41$]55"X*"5!L96%S92!C
M:&%N9V4@=&AE;2$@22!K;F]W(&1A=&%B87-E<R!R=6YN:6YG(&9O<B!Y96%R
M<R!S=&]R:6YG(&EM<&]R=&%N="!D871A"@EA;F0@<W1I;&P@:&%V92!T:&4@
M9&5F875L="!P87-S=V]R9"`A(0H)*&UA;F%G97(@9F]R('-Y<W1E;2!A;F0@
M8VAA;F=E7V]N7VEN<W1A;&P@9F]R('-Y<RD*"BTM"7-Q;'!L=7,@<WES+V-H
M86YG95]O;E]I;G-T86QL0#QY;W5R(%-)1#X*"6EF('EO=2!P<F]P97)L>2!S
M970@=&AE($]204-,15]3240@96YV:7)O;FUE;G0@=F%R:6%B;&4@>6]U(&-A
M;B!O;6UI="!T:&4*"71R86EL:6YG($`\>6]U<B!S:60^('=H96X@>6]U(&%R
M92!L;V=G960@;VX@=&\@=&AE(&UA8VAI;F4@=VAI8V@@:7,@<G5N;FEN9R!T
M:&4@1$(N"@HM+0EC<F5A=&4@=&AE('1A8FQE<W!A8V4@9F]R(&AO<F1E"@ES
M<6P^($-214%412!404),15-004-%($A/4D1%"B`@("`@("`@("`@("`@3$]'
M1TE.1PH@("`@("`@("`@("`@($1!5$%&24Q%("<\64]54B!0051(($A%4D4^
M+TA/4D1%+F1B9B<@4TE:12`\05,@64]5($Q)2T4^33L*"@E4:&ES(&ES(&EN
M9&5E9"!V97)Y('-I;7!L92!B=70@:70@=V]R:W,@86YD(&YO=&AI;F<@:&%S
M('1O(&)E(&EN('5P<&5R8V%S90H);&5T=&5R<RX@069T97(@82!F97<@<V5C
M;VYD<R!O<B!M:6YU=&5S("T@9&5P96YD<R!O;B!H;W<@;6%N>2!M96=A8GET
M97,*"7EO=2!G879E('1O('1H870@=&%B;&5S<&%C92`M(&$@;F5W(&1A=&%F
M:6QE(&AA<R!B965N(&-R96%T960N"@HM+0E792!C86X@;F]W(&-R96%T92!A
M('5S97(@=VET:"!D969A=6QT('1A8FQE<W!A8V4@2$]21$4L(&QE=',@;F%M
M92!H:6T@:&]R9&4Z"@H)0U)%051%(%5315(@2$]21$4@4%)/1DE,12!$149!
M54Q4($E$14Y4249)140@0ED@/'EO=7(@<&%S<W=O<F0@:&5R93X@"B`@("`@
M("`@5$%"3$534$%#12!(3U)$12!414U03U)!4ED@5$%"3$534$%#12!414U0
M(%%53U1!(%5.3$E-251%1"!/3B!414U0"@E154]402!53DQ)34E4140@3TX@
M2$]21$4@04-#3U5.5"!53DQ/0TL["@E'4D%.5"!#3TY.14-4(%1/($A/4D1%
M.PH*+2T)8V]M;6ET('EO=7(@=V]R:SH@/B!C;VUM:70["@EA;F0@;&]G(&]U
M=`HM+0EL;V=I;B!A<R!U<V5R(&AO<F1E.B!S<6QP;'5S(&AO<F1E+SQP87-S
M=V]R9#Y`/'EO=7(@<VED/B!A;F0@8W)E871E('1H92!T86)L97,*"2$\<&%T
M:"!T;R!H;W)D93XO<V-R:7!T<R]D8B]O<F%C;&5?8W)E871E+G-Q;"!A;F0@
M8V]M;6ET('EO=7(@86MT:6]N.B`^(&-O;6UI=#L*"71H92!T86)L97,@=VEL
M;"!B92!C<F5A=&5D(&EN('1H92!D969A=6QT('1A8FQE<W!A8V4@9F]R('EO
M=7(@:&]R9&4@=7-E<@H)"D]+(&YO=R!Y;W4@8V%N(&-O;F9I9W5R92!(;W)D
M92!T;R!U<V4@>6]U<B!I;G-T86YC92!B=70@869T97(@82!R96)O;W0@3W)A
M8VQE"G=I;&P@;F]T('-T87)T(&%U=&]M871I8VQY+B!4:&%T(&ES('=H870@
M=V4@87)E(&=O:6YG('1O(&-O;F9I9W5R92!N;W<N"@HM+0EL;V=O=70@;V8@
M;W)A8VQE+"!L;V=I;B!A<R!U<V5R('-Y<R!O<B`\>6]U<B!O<F%C;&4@=7-E
M<CX@"@EA;F0@<VAU=&1O=VX@>6]U<B!I;G-T86YC93H@*&AO<&4@>6]U<B!O
M<F%C;&4@=7-E<B!I<R!I;B!T:&4@9W)O=7`@9&)A("T*"6EF(&YO="!H92!C
M86XG="!S:'5T(&1O=VX@>6]U<B!I;G-T86YC92D*"3X@8V]N;F5C="!I;G1E
M<FYA;`H)/B!S:'5T9&]W;B!I;6UE9&EA=&4*"6%N9"!L;V=O=70N+BX*"0HM
M+0ET97-T('1H92!S8W)I<'0@(F1B<W1A<G0B(&EN("1/4D%#3$5?2$]-12]B
M:6X@268@=&AE($1"(&1O97,@;F]T('-T87)T"@EY;W4@:&%V92!T;R!E9&ET
M(&ET(&]R(&-R96%T92!A(&QI;FL@9G)O;2`D3U)!0TQ%7TA/344O9&)S+VEN
M:70\<VED+6YA;64^+F]R80H)=&\@)$]204-,15](3TU%+V%D;6EN+SQS:60@
M;F%M93XO<&9I;&4O:6YI=#QS:60M;F%M93XN;W)A"@DH(&1B<W1A<G0@=VEL
M;"!L;V]K(&9O<B!Y;W5R('-I9"UF:6QE<R!I;B!S=6)D:7(@(F1B<R(@8G5T
M('1H97-E(&%R92!S=&]R960*"75N9&5R("1/4D%#3$5?2$]-12]A9&UI;B\\
M<VED(&YA;64^+W!F:6QE+R`M('1H:7,@;6%Y8F4@:7,@82!B=6<@;W(@80H)
M9F5A='5R92!I;B!T:&4@;W)A8VQE(&EN<W1A;&QE<B`I"@ET97-T(")D8G-T
M87)T(B!A9V%I;B`M(&YO=R!I="!S:&]U;&0@=V]R:RP@:2!H;W!E"@HM+0EE
M9&ET('1H92!F:6QE("]E=&,O;W)A=&%B"@E#:&%N9V4@=&AE(&QI;F4*"3QS
M:60M;F%M93XZ/'EO=7(@3W)A8VQE($AO;64@+2!&=6QL('%U86QI9FEE9"!P
M871H/CI.("`@=&\*"3QS:60M;F%M93XZ/'EO=7(@3W)A8VQE($AO;64@+2!&
M=6QL('%U86QI9FEE9"!P871H/CI9"@HM+0EN;W<@8VAA;F=E(&]R(&-R96%T
M92!A('-T87)T=7`@<V-R:7!T('=H:6-H(&ES(&5X96-U=&5D(&%T(&)O;W0@
M=&EM92X@270@<VAO=6QD(&-O;G1A:6X*"7-O;65T:&EN9R!L:6ME('1H:7,Z
M"@D*"7-U("T@/'EO=7(@;W)A8VQE('5S97(^("UC("(\:&]U<B!P871H(&AE
M<F4^+V)I;B]L<VYR8W1L('-T87)T(@H)<W4@+2`\>6]U<B!O<F%C;&4@=7-E
M<CX@+6,@(CQY;W5R('!A=&@@:&5R93XO8FEN+V1B<W1A<G0B"@H)86YD(&]F
M(&-O=7)S92!Y;W5R(&EN<W1A;F-E('-H;W5L9"!B92!S=&]P<&5D(&$@<F5G
M=6QA<B!W87DN(%!L86-E('1H:7,*"6EN('1H92!A<'!R;W!R:6%T92!S8W)I
M<'0@=VAI8V@@:7,@97AE8W5T960@870@<VAU=&1O=VX@=&EM90H*"7-U("T@
M/'EO=7(@;W)A8VQE('5S97(^("UC("(\:&]U<B!P871H(&AE<F4^+V)I;B]L
M<VYR8W1L('-T;W`B"@ES=2`M(#QY;W5R(&]R86-L92!U<V5R/B`M8R`B/'EO
M=7(@<&%T:"!H97)E/B]B:6XO9&)S:'5T(@H*+2T)=&5S="!I=`H*16YD(&]F
M($-A<V4@,2D*"@I#87-E(#(I"@I0<F]B;&5M.B!9;W4@:&%V92!A;B!A;&QR
M96%D>2!R=6YN:6YG(&]R86-L92!D871A8F%S92!A;F0@=V]U;&0@;&EK90IT
M;R!A9&0@82!N97<@:6YS=&%N8V4N(%-O;'5T:6]N(&ES('%U:65T(&5A<WDN
M"D9O<B!N;W<L('1H92!N97<@9&%T86)A<V4G(&YA;64@=VEL;"!B92`M+3X@
M:&]R9&4*"D)E9F]R92!I('-T87)T(&DG;&P@;6%K92!S;VUE(&%S<W5M<'1I
M;VYS.@HH4$Q%05-%($-(04Y'12!42$4@4$%42$Y!3453($%3($Y%0T534T%2
M62`I"@HQ+@DD3U)!0TQ%7TA/344]+VAO;64O;W)A8VQE"C(N"21/4D%#3$5?
M0D%312`]("1/4D%#3$5?2$]-10HS+@E9;W5R(&5X:7-T:6YG($1A=&%B87-E
M(&ES(&EN<W1A;&QE9"!U;F1E<B`D3U)!0TQ%7TA/344O;W)A9&%T82\\>6]U
M<B!I;G-T86YC92!N86UE/@HT+@E9;W5R(&5X:7-T:6YG(%1R86-E+T1U;7`O
M<&9I;&4O8F1U;7`N+BX@+2!D:7)E8W1O<FEE<R!A<F4@:6YS=&%L;&5D('5N
M9&5R"@D@)$]204-,15](3TU%+V%D;6EN+SQY;W5R(&EN<W1A;F-E(&YA;64^
M+PH*"51H97)E9F]R92!Y;W5R(&YE=R!H;W)D92!D871A8F%S92!F:6QE<R!W
M:6QL(&=O(&EN=&\@86YO=&AE<B!D:7)E8W1O<GDZ"@DD3U)!0TQ%7TA/344O
M;W)A9&%T82]H;W)D92\*"@E4:&4@5')A8V4O1'5M<"]P9FEL92]B9'5M<"XN
M+B`M(&1I<G,@9V\@=&\Z"@DD3U)!0TQ%7TA/344O861M:6XO:&]R9&4O"@H)
M5&AE(&EN:71H;W)D92YO<F$@9FEL92!I;B`D3U)!0TQ%7TA/344O9&)S('-H
M;W5L9"!B92!A(&QI;FL@=&\Z"@DD3U)!0TQ%7TA/344O861M:6XO:&]R9&4O
M<&9I;&4O:6YI="YO<F$*"DQE=',@8F5G:6XZ"@HM+0EC<F5A=&4@=&AE(&1I
M<F5C=&]R:65S(&9O<B!Y;W5R(&YE=R!D8B`H87,@>6]U<B!/4D%#3$4@=7-E
M<BDZ"@DC/B!M:V1I<B`M<"`D3U)!0TQ%7TA/344O;W)A9&%T82]H;W)D92]A
M<F-H:79E"@DC/B!M:V1I<B`M<"`D3U)!0TQ%7TA/344O861M:6XO:&]R9&4O
M861H;V,@7`H)"2`@("`D3U)!0TQ%7TA/344O861M:6XO:&]R9&4O8F1U;7`@
M7`H)"2`@("`D3U)!0TQ%7TA/344O861M:6XO:&]R9&4O8V1U;7`@7`H)"2`@
M("`D3U)!0TQ%7TA/344O861M:6XO:&]R9&4O8W)E871E(%P*"0D@("`@)$]2
M04-,15](3TU%+V%D;6EN+VAO<F1E+V5X<"!<"@D)("`@("1/4D%#3$5?2$]-
M12]A9&UI;B]H;W)D92]P9FEL92!<"@D)("`@("1/4D%#3$5?2$]-12]A9&UI
M;B]H;W)D92]U9'5M<`H*+2T)8V]P>2!Y;W5R(&5X:7-T:6YG(&EN:70N;W)A
M(&9I;&4@9G)O;2`D3U)!0TQ%7TA/344O861M:6XO/&5X:7-T:6YG(&EN<W1A
M;F-E/B]P9FEL92\*"71O("1/4D%#3$5?2$]-12]A9&UI;B]H;W)D92]P9FEL
M92\@86YD(&UA:V4@=&AE(&%P<')O<')I871E(&-H86YG97,@:6X@:70*"4-(
M04Y'12!!5"!,14%35"!42$4@4$%42$Y!3453("$A(0H*+2T);6%K92!T:&4@
M;&EN:R!F<F]M("1/4D%#3$5?2$]-12]D8G,O:6YI=&AO<F1E+F]R82!T;PH)
M)$]204-,15](3TU%+V%D;6EN+VAO<F1E+W!F:6QE+VEN:70N;W)A"@H)(SX@
M;&X@+7,@)$]204-,15](3TU%+V%D;6EN+VAO<F1E+W!F:6QE+VEN:70N;W)A
M("1/4D%#3$5?2$]-12]D8G,O:6YI=&AO<F1E+F]R80H*+2T)<V5T($]204-,
M15]3240@=&\@:&]R9&4*"2,^($]204-,15]3240]:&]R9&4*"BTM"6QO9VEN
M(&%N9"!S=&%R='5P('1H92!I;G-T86YC90H)(SX@<W%L<&QU<R`O;F]L;V<*
M"7-Q;#X@<W1A<G1U<"!P9FEL93TO:&]M92]O<F%C;&4O861M:6XO:&]R9&4O
M<&9I;&4O:6YI="YO<F$@;F]M;W5N=`H*+2T)8W)E871E('1H92!D871A8F%S
M92!F<F]M(&-R96%T95]H;W)D95]D8BYS<6P@+2!Y;W4@<VAO=6QD(&]F(&-O
M=7)S92!H879E('-A=F5D(&ET('-O;7=H97)E(#LI"@ES<6P^("$O<&%T:"]T
M;R]C<F5A=&5?:&]R9&5?9&(N<W%L"@H)87,@=&5M<&QA=&4@:2!T;V]K('1H
M92!S8W)I<'0@9G)O;0H):'1T<#HO+W=W=RYA9'`M9VUB:"YC:"]O<F$O861M
M:6XO8W)E871I;F=D8FUA;G5A;&QY+FAT;6PC<V%M<&QE8W)E871E9&%T86)A
M<V4*"6%N9"!M861E('-O;64@;6EN;W(@8VAA;F=E<RX*"BTM"6-R96%T92!T
M:&4@9&%T82!D:6-T:6]N87)Y+"!E=&,N"@ES<6P^("$O:&]M92]O<F%C;&4O
M<F1B;7,O861M:6XO8V%T86QO9RYS<6P*"7-Q;#X@(2]H;VUE+V]R86-L92]R
M9&)M<R]A9&UI;B]C871P<F]C+G-Q;`H)<W%L/B`A+VAO;64O;W)A8VQE+W)D
M8FUS+V%D;6EN+V-A=&AS+G-Q;`H)<W%L/B!C;VUM:70["@ES<6P^(&5X:70*
M"BTM"6YO=R!A9&0@82!N97<@;&EN92!T;R`O971C+V]R871A8@H*"6]L9"`H
M(&]N;'D@,2!I;G-T86YC92`I.@H)/'EO=7(@:6YS=&%L;&5D(&EN<W1A;F-E
M(&YA;64^.B]H;VUE+V]R86-L93I9"@H);F5W("@@=VET:"!T:&4@;F5W(&]N
M92`I.@H)/'EO=7(@:6YS=&%L;&5D(&EN<W1A;F-E(&YA;64^.B]H;VUE+V]R
M86-L93I9"@EH;W)D93HO:&]M92]O<F%C;&4Z60H*+2T)861D('1H92!N97<@
M:6YS=&%N8V4@=&\@>6]U<B!T;G-N86UE<RYO<F$*"75S92!T:&4@:F%V82!G
M=6D@;F5T.&%S<VES="!O<B!C;W!Y(&%N9"!P87-T92!T:&4@<W1A=&5M96YT
M<R!B>2!Y;W5R<V5L9B!A;F0*"6UA:V4@=&AE(&-H86YG97,@87,@;F5E9&5D
M"@HM+0EA9G1E<B!A;&PL('1H92!S8W)I<'1S(&1B<W1A<G0@=6YD(&1B<VAU
M="!W:6QL('1H96X@875T;VUA=&EC;'D@<W1A<G0@86YD('-H=71D;W=N(&%L
M;`H):6YS=&%N8V5S(&%T(&]N8V4*"D-R96%T:6YG('1H92!486)L97-P86-E
M(&%N9"!R97%U:7)E9"!U<V5R(&ES('1H92!S86UE(&%S("!D97-C<FEB960@
M86)O=F4*"@I)(&AO<&4@=&AA="!T:&5R92!A<F4@;F]T('-O(&UA;GD@<W!E
M;&QI;F<@;6ES=&%K97,@*"!M>2!N871I=F4@;&%N9W5A9V4@:7,@9V5R;6%N
M("D@"F%N9"!T:&%T('1H:7,@=VEL;"!B92!H96QP9G5L;"!F;W(@<V]M96]N
M90H*16YD(&]F($-A<V4@,BD*"B1(;W)D93H@:&]R9&4O<V-R:7!T<R]S<6PO
M4D5!1$U%+D]#23@L=B`Q+C(@,C`P-"\P.2\R-2`Q.3HU-CHQ,B!C:'5C:R!%
M>'`@)`H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]S
M8W)I<'0N:6YI=&EA;%]H;W)D95]U<V5R+G-Q;```````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P-3,S`#$P-3$U-#,S-S4U`#`R-C`T,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP
M=',O<W%L+W-C<FEP="YI;FET:6%L7VAO<F1E7W5S97(N<W%L+'8@,2XQ(#(P
M,#0O,#DO,3@@,3<Z,C`Z-3D@8VAU8VL@17AP("0*+2T*+2T@5&AI<R!S8W)I
M<'0@=VEL;"!C<F5A=&4@86X@:6YI=&EA;"!U<V5R(&EN(&$@:&]R9&5?=7-E
M<G,@=&%B;&4N(%1H90HM+2!P87-S=V]R9"!B96EN9R!U<V5D(&ES("=A9&UI
M;B<L('=H:6-H('EO=2!S:&]U;&0@8VAA;F=E"BTM($E-345$24%414Q9+@H*
M24Y315)4($E.5$\@:&]R9&5?=7-E<G,@*'5S97)?=6ED+"!U<V5R7W!A<W,I
M(%9!3%5%4R`H)V%D;6EN)RP@)S(Q,C,R9C(Y-V$U-V$U83<T,S@Y-&$P931A
M.#`Q9F,S)RD["@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]T96UP+6-L96%N=7`N8W)O
M;@``````````````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S`P,P`Q,#4Q
M-30S,S<U-0`P,C(V,C``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````(R$O8FEN+W-H"@HC(%1H:7,@:7,@86X@97AA;7!L92!C
M<F]N(&IO8B!S:&5L;"!S8W)I<'0@=VAI8V@@=VEL;"!C;&5A;B!U<"!A;GD*
M(R!T96UP;W)A<GD@9FEL97,@=VAI8V@@;6%Y(&=E="!S=')A;F1E9"!B>2!(
M;W)D92!U<V5R<R!I;B!T:&4*(R!W96)S97)V97(G<R!T96UP;W)A<GD@9&ER
M96-T;W)Y+@HC"B,@66]U(&UA>2!H879E('1O(&-H86YG92`O=&UP('1O(&%N
M;W1H97(@;&]C871I;VX@9&5P96YD:6YG(&]N('EO=7(*(R!C;VYF:6=U<F%T
M:6]N+B`@3W1H97(@;6]D:69I8V%T:6]N<R!M87D@86QS;R!B92!R97%U:7)E
M9"X*(PHC(%1H:7,@<V-R:7!T(&ES('!R;W9I9&5D(&%S+6ES(&%N9"!I<R!T
M;R!B92!U<V5D(&%T('EO=7(@;W=N(')I<VLN(`HC($AO<F1E(&%N9"!T:&4@
M875T:&]R<R!A8V-E<'0@;F\@<F5S<&]N<VEB:6QI='D@9F]R(&%N>2!D86UA
M9V5S(&]R"B,@;&]S97,@8V%U<V5D(&)Y('1H:7,@<V-R:7!T('=H971H97(@
M:6YD:7)E8W0L(&EN8VED96YT86PL(&]R"B,@8V]N<V5Q=65N=&EA;"P@('=H
M971H97(@;W(@;F]T('-U8V@@9&%M86=E<R!C;W5L9"!B92!F;W)S965N+@HC
M"B,@2&]W('1O('5S92!T:&ES('-C<FEP="!W:6QL(&1E<&5N9"!O;B!Y;W5R
M('-Y<W1E;2X@($9O<B!S;VUE('-Y<W1E;7,L"B,@:70@:7,@87,@<VEM<&QY
M(&%S('!U='1I;F<@=&AI<R!F:6QE(&EN('1H92`O971C+V-R;VXN9&%I;'D@
M9&ER96-T;W)Y+@HC($9O<B!O=&AE<G,L(&UO<F4@;W(@9&EF9F5R96YT('-E
M='5P('=I;&P@8F4@<F5Q=6ER960N("!3964@=&AE"B,@9&]C=6UE;G1A=&EO
M;B!F;W(@>6]U<B!S>7-T96US(&IO8B!S8VAE9'5L97(@9F]R(&UO<F4@:6YF
M;W)M871I;VXN"B,*"B,@5&AE(&QO8V%T:6]N(&]F(%!(4"=S('1E;7!O<F%R
M>2!D:7)E8W1O<GD*5$U07T1)4CTO=&UP"@H*(R!-4U=O<F0@871T86-H;65N
M=',@*&=E;F5R871E9"!B>2!T:&4@35-W;W)D('9I97=E<BD*9F]R($U35T]2
M1%]&24Q%(&EN(&!F:6YD("1435!?1$E2("UT>7!E(&8@+6YA;64@;7-W;W)D
M7"H@+6-T:6UE("LR(&`[(&1O"@ER;2`M9B`D35-73U)$7T9)3$4*9&]N90H*
M(R!)35`@871T86-H;65N=',*9F]R($E-4%]&24Q%(&EN(&!F:6YD("1435!?
M1$E2("UT>7!E(&8@+6YA;64@:6UP871T7"H@+6-T:6UE("LR(&`[(&1O"@ER
M;2`M9B`D24U07T9)3$4*9&]N90H*(R!+;'5T>B!T96UP;W)A<GD@9FEL97,*
M9F]R($M,551:7T9)3$4@:6X@8&9I;F0@)%1-4%]$25(@+71Y<&4@9B`M;F%M
M92!+;'5T>EPJ("UC=&EM92`K,B!@.R!D;PH)<FT@+68@)$M,551:7T9)3$4*
M9&]N90H*(R!3<&5L;"!C:&5C:VEN9R!T96UP;W)A<GD@9FEL97,*9F]R(%-0
M14Q,7T9)3$4@:6X@8&9I;F0@)%1-4%]$25(@+71Y<&4@9B`M;F%M92!S<&5L
M;%PJ("UC=&EM92`K,B!@.R!D;PH)<FT@+68@)%-014Q,7T9)3$4*9&]N90H*
M(R!61E,@=&5M<&]R87)Y(&9I;&5S"F9O<B!)35!?1DE,12!I;B!@9FEN9"`D
M5$U07T1)4B`M='EP92!F("UN86UE('9F<UPJ("UC=&EM92`K,B!@.R!D;PH)
M<FT@+68@)$E-4%]&24Q%"F1O;F4*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O=&AE;65S7V-H96-K+G!H<```````
M````````````````````````````````````````````````````````````
M,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,30U-C8`,3`U,34T,S,W
M-34`,#(R-3(Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````",A+W5S<B]L;V-A;"]P<V$O861M:6XO8FEN+W!H<`H\/W!H<`HO
M*BH*("H@5&AI<R!S8W)I<'0@9&]E<R!S;VUE(&-H96-K:6YG(&]F('1H96UE
M<RP@=&\@;6%K92!S=7)E(&EM86=E<R!A<F4*("H@<WEN8VAR;VYI<V5D(&%C
M<F]S<R!T:&5M97,N"B`J"B`J("1(;W)D93H@:&]R9&4O<V-R:7!T<R]T:&5M
M97-?8VAE8VLN<&AP+'8@,2XS+C$P+C4@,C`P-B\P-"\Q."`Q-CHR-CHP-2!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!4:&4@2&]R9&4@
M4')O:F5C="`H:'1T<#HO+W=W=RYH;W)D92YO<F<O*0H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^
M"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B\*"D!D969I;F4H)T%55$A?2$%.
M1$Q%4B<L('1R=64I.PI`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+RXN)RD["@HO*B!#3$D@8VAE8VMS(&%N9"!E;G9I<F]N
M;65N="!S971U<"!F:7)S="X@*B\*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@
M+B`G+VQI8B]C;W)E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O0TQ)+G!H
M<"<["@HO*B!-86ME('-U<F4@;F\@;VYE(')U;G,@=&AI<R!F<F]M('1H92!W
M96(N("HO"FEF("@A2&]R9&5?0TQ).CIR=6YN:6YG1G)O;4-,22@I*2!["B`@
M("!E>&ET*")-=7-T(&)E(')U;B!F<F]M('1H92!C;VUM86YD(&QI;F5<;B(I
M.PI]"@HO*B!'970@86YY(&]P=&EO;G,N("HO"B1S:6UP;&4@/2!F86QS93L*
M)&EG;F]R92`](&%R<F%Y*"D["FEF("AI<W-E="@D87)G=BDI('L*("`@("\J
M($=E="!R:60@;V8@=&AE(&9I<G-T(&%R9R!W:&EC:"!I<R!T:&4@<V-R:7!T
M(&YA;64N("HO"B`@("!A<G)A>5]S:&EF="@D87)G=BD["B`@("!W:&EL92`H
M)&%R9R`](&%R<F%Y7W-H:69T*"1A<F=V*2D@>PH@("`@("`@(&EF("@D87)G
M(#T]("<M+6AE;'`G*2!["B`@("`@("`@("`@('!R:6YT7W5S86=E*"D["B`@
M("`@("`@?2!E;'-E:68@*"1A<F<@/3T@)RUS)RD@>PH@("`@("`@("`@("`D
M<VEM<&QE(#T@=')U93L*("`@("`@("!](&5L<V5I9B`H<W1R<&]S*"1A<F<L
M("<M:2<I(#T]/2`P*2!["B`@("`@("`@("`@(&QI<W0H+"1I9VYO<F5;72D@
M/2!E>'!L;V1E*"<])RP@)&%R9RD["B`@("`@("`@("`@("\O)&EG;F]R95M=
M(#T@)&D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<')I;G1?=7-A
M9V4H(E5N<F5C;V=N:7-E9"!O<'1I;VX@)&%R9R(I.PH@("`@("`@('T*("`@
M('T*?0H*+RH@4V5T('5P($-,22X@*B\*)&-L:2`]("9N97<@2&]R9&5?0TQ)
M*"D["@HO*B!#:&5C:R!I9B!A="!L96%S="!T:&4@<F5G:7-T<GD@:7,@879A
M:6%B;&4N("HO"FEF("@A0&9I;&5?97AI<W1S*$A/4D1%7T)!4T4@+B`G+V-O
M;F9I9R]R96=I<W1R>2YP:'`G*2D@>PH@("`@)&-L:2T^=W)I=&5L;B@D8VQI
M+3YR960H)TYO($AO<F1E(')E9VES=')Y(&9I;&4N)RDI.PH@("`@97AI=#L*
M?0H*+R\D8VQI+3YW<FET96QN*"1C;&DM/F=R965N*"=296%D:6YG+BXN)RDI
M.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*
M"B\J($=E="!T:&4@87!P<R!A;F0@<W1A<G0@9&]I;F<@8VAE8VMS+B`J+PHD
M87!P<R`]("1R96=I<W1R>2T^;&ES=$%P<',H87)R87DH)VAI9&1E;B<L("=N
M;W1O;VQB87(G+"`G86-T:79E)RP@)V%D;6EN)RDI.PH*+RH@1V5T(&$@;&ES
M="!O9B!T:&5M97,N("HO"B1T:&5M97,@/2!A<G)A>2@I.PHD=&AE;65S7V1I
M<B`]("1R96=I<W1R>2T^9V5T*"=T:&5M97-F<R<L("=H;W)D92<I.PII9B`H
M)&AA;F1L92`](&]P96YD:7(H)'1H96UE<U]D:7(I*2!["B`@("!W:&EL92`H
M)&9I;&4@/2!R96%D9&ER*"1H86YD;&4I*2!["B`@("`@("`@:68@*"1F:6QE
M(#T]("<N)R!\?"`D9FEL92`]/2`G+BXG('Q\("1F:6QE(#T]("=#5E,G('Q\
M"B`@("`@("`@("`@("1F:6QE(#T]("<N<W9N)R!\?`H@("`@("`@("`@("`A
M0&9I;&5?97AI<W1S*"(D=&AE;65S7V1I<B\D9FEL92]I;F9O+G!H<"(I('Q\
M"B`@("`@("`@("`@("%`9FEL95]E>&ES=',H(B1T:&5M97-?9&ER+R1F:6QE
M+V=R87!H:6-S(BDI('L*("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@
M?0H*("`@("`@("`O*B!$;VXG="!B;W1H97(@8VAE8VMI;F<@=6YL97-S('1H
M92!T:&5M92!E>'!L:6-I=&QY('-T871E<R!T:&%T"B`@("`@("`@("H@:6-O
M;G,@=VEL;"!B92!R97!L86-E9"!F;W(@=&AI<R!A<'!L:6-A=&EO;BX@*B\*
M("`@("`@("!I;F-L=61E("(D=&AE;65S7V1I<B\D9FEL92]I;F9O+G!H<"([
M"B`@("`@("`@:68@*"%I<W-E="@D=&AE;65?:6-O;G,I*2!["B`@("`@("`@
M("`@(&-O;G1I;G5E.PH@("`@("`@('T*"B`@("`@("`@+RH@4W1O<F4@=&AE
M(&%P<',@86YD('1H96ER('1H96UE(&1I<F5C=&]R:65S+B`J+PH@("`@("`@
M(&9O<F5A8V@@*"1T:&5M95]I8V]N<R!A<R`D87!P*2!["B`@("`@("`@("`@
M("1A<'!?=&AE;65S7V1I<B`]("1R96=I<W1R>2T^9V5T*"=T:&5M97-F<R<L
M("1A<'`I.PH@("`@("`@("`@("`D=&AE;65S6R1A<'!=6R1F:6QE72`]("(D
M87!P7W1H96UE<U]D:7(O)&9I;&4O9W)A<&AI8W,B.PH@("`@("`@('T*"B`@
M("`@("`@+RH@56YS970@=&AI<RP@=&\@;6%K92!S=7)E(&ET(&ES(&-H96-K
M960@=&AE(&YE>'0@=&EM92!A<F]U;F0N("HO"B`@("`@("`@=6YS970H)'1H
M96UE7VEC;VYS*3L*("`@('T*?0H*9F]R96%C:"`H)&%P<',@87,@)&%P<"D@
M>PH@("`@+RH@4V5T('5P('-O;64@9&ER<RX@*B\*("`@("1T:&5M97-?9&ER
M(#T@)')E9VES=')Y+3YG970H)W1H96UE<V9S)RP@)&%P<"D["B`@("`D:&]R
M9&5?=&AE;65?9&ER(#T@)'1H96UE<U]D:7(@+B`G+VAO<F1E)SL*("`@("1H
M;W)D95]I8V]N7V1I<B`]("1H;W)D95]T:&5M95]D:7(@+B`G+V=R87!H:6-S
M)SL*"B`@("`O*B!386YI='D@8VAE8VL@9F]R('1H92!D:7)E8W1O<FEE<RX@
M*B\*("`@(&EF("@A0&9I;&5?97AI<W1S*"1H;W)D95]T:&5M95]D:7(I('Q\
M("%`9FEL95]E>&ES=',H)&AO<F1E7VEC;VY?9&ER*2D@>PH@("`@("`@(&-O
M;G1I;G5E.PH@("`@?0H*("`@("\J($=E="!A(&QI<W0@;V8@86QL(&AO<F1E
M(&EM86=E<R!R96-U<G-I=F5L>2X@*B\*("`@("1H;W)D95]I8V]N7VQI<W0@
M/2!A<G)A>2@I.PH@("`@<F5A9$1I<E)E8W5R<VEV96QY*"1H;W)D95]I8V]N
M7V1I<BP@)&AO<F1E7VEC;VY?9&ER+"`D:&]R9&5?:6-O;E]L:7-T*3L*"B`@
M("`O*B!,;V]P('1H<F]U9V@@=&AE;65S('1H870@<F5P;&%C92!I8V]N<R!A
M;F0@8VAE8VL@9F]R(&1I9F9E<F5N8V5S+B`J+PH@("`@9F]R96%C:"`H)'1H
M96UE<ULD87!P72!A<R`D=&AE;64@/3X@)'1H96UE7VEC;VY?9&ER*2!["B`@
M("`@("`@)'1H96UE7VEC;VY?;&ES="`](&%R<F%Y*"D["B`@("`@("`@<F5A
M9$1I<E)E8W5R<VEV96QY*"1T:&5M95]I8V]N7V1I<BP@)'1H96UE7VEC;VY?
M9&ER+"`D=&AE;65?:6-O;E]L:7-T*3L*"B`@("`@("`@+RH@0VAE8VL@9F]R
M(&EC;VYS('1H870@87)E(&EN('1H92!(;W)D92!B87-E('1H96UE(&%N9"!N
M;W0@:6X@=&AE"B`@("`@("`@("H@8W5S=&]M('1H96UE+B`J+PH@("`@("`@
M("1D:69F(#T@87)R87E?9&EF9B@D:&]R9&5?:6-O;E]L:7-T+"`D=&AE;65?
M:6-O;E]L:7-T*3L*("`@("`@("`O*B!$;VXG="!B;W1H97(@<F5P;W)T:6YG
M(&%N>71H:6YG(&9O<B!T:&5M97,@=&AA="!H879E(&%L;"!T:&4@:&]R9&4*
M("`@("`@("`@*B!B87-E(&EC;VYS+B`J+PH@("`@("`@(&EF("AE;7!T>2@D
M9&EF9BDI('L*("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@?0H*("`@
M("`@("`D8VQI+3YW<FET96QN*"1C;&DM/G)E9"AS<')I;G1F*"=;)7-=("(E
M<R(@=&AE;64@;6ES<VEN9R!T:&5S92!I8V]N<SHG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('-T<G1O=7!P97(H)&%P<"DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H96UE*2DI.PH@("`@("`@(&9O
M<F5A8V@@*"1D:69F(&%S("1I8V]N*2!["B`@("`@("`@("`@("1C;&DM/G=R
M:71E;&XH)&EC;VXI.PH@("`@("`@('T*"B`@("`@("`@+RH@0VAE8VL@:68@
M;VYL>2!D;VEN9R!A($AO<F1E(&)A<V4@=&AE;64@=&\@8W5S=&]M('1H96UE
M(&-H96-K+B!3:VEP"B`@("`@("`@("H@=&AE(')E=F5R<V4@8VAE8VMI;F<@
M:68@=')U92X@*B\*("`@("`@("!I9B`H)'-I;7!L92D@>PH@("`@("`@("`@
M("!C;VYT:6YU93L*("`@("`@("!]"@H@("`@("`@("\J($-H96-K(&9O<B!I
M8V]N<R!T:&%T(&%R92!I;B!T:&4@2&]R9&4@8F%S92!T:&5M92!A;F0@;F]T
M(&EN('1H90H@("`@("`@("`J(&-U<W1O;2!T:&5M92X@*B\*("`@("`@("`D
M9&EF9B`](&%R<F%Y7V1I9F8H)'1H96UE7VEC;VY?;&ES="P@)&AO<F1E7VEC
M;VY?;&ES="D["B`@("`@("`@+RH@1&]N)W0@8F]T:&5R(')E<&]R=&EN9R!A
M;GET:&EN9R!F;W(@=&AE;65S('1H870@9&]N)W0@:&%V92!A;GD@:6-O;G,*
M("`@("`@("`@*B!M;W)E('1H86X@=&AE(&)A<V4@=&AE;64N("HO"B`@("`@
M("`@:68@*&5M<'1Y*"1D:69F*2D@>PH@("`@("`@("`@("!C;VYT:6YU93L*
M("`@("`@("!]"@H@("`@("`@("1C;&DM/G=R:71E;&XH)&-L:2T^8FQU92AS
M<')I;G1F*"=;)7-=("(E<R(@=&AE;64@:&%S('1H97-E(&5X=')A(&EC;VYS
M.B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R=&]U<'!E
M<B@D87!P*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AE
M;64I*2D["B`@("`@("`@9F]R96%C:"`H)&1I9F8@87,@)&EC;VXI('L*("`@
M("`@("`@("`@)&-L:2T^=W)I=&5L;B@D:6-O;BD["B`@("`@("`@?0H@("`@
M?0I]"@HD8VQI+3YW<FET96QN*"1C;&DM/F=R965N*"=$;VYE+B<I*3L*97AI
M=#L*"B\J*@H@*B!,;V]P<R!T:')O=6=H('1H92!D:7)E8W1O<GD@<F5C=7)S
M:79E;'D@86YD('-T;W)E<R!T:&4@9F]U;F0@9W)A<&AI8W,@:6YT;PH@*B!A
M;B!A<G)A>2X*("HO"F9U;F-T:6]N(')E861$:7)296-U<G-I=F5L>2@D<&%T
M:"P@)&)A<V5P871H+"`F)&QI<W0I"GL*("`@(&=L;V)A;"`D:6=N;W)E.PH*
M("`@(&EF("@D:&%N9&QE(#T@;W!E;F1I<B@D<&%T:"DI('L*("`@("`@("!W
M:&EL92`H)&9I;&4@/2!R96%D9&ER*"1H86YD;&4I*2!["B`@("`@("`@("`@
M(&EF("@D9FEL92`]/2`G+B<@?'P@)&9I;&4@/3T@)RXN)R!\?"`D9FEL92`]
M/2`G0U93)PH@("`@("`@("`@("`@("`@?'P@)&9I;&4@/3T@)RYS=FXG*2![
M"B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H:7-?9&ER*"(D<&%T:"\D9FEL92(I*2!["B`@("`@("`@
M("`@("`@("!R96%D1&ER4F5C=7)S:79E;'DH(B1P871H+R1F:6QE(BP@)&)A
M<V5P871H+"`D;&ES="D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!F;W)E86-H("@D:6=N;W)E(&%S("1P871T97)N*2!["B`@("`@
M("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)'!A='1E<FXL("1F:6QE
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU92`R.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1L:7-T6UT@/2!S=6)S='(H)'!A=&@L('-T<FQE;B@D8F%S97!A
M=&@I*2`N("(O)&9I;&4B.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(&-L;W-E9&ER*"1H86YD;&4I.PH@("`@?0H*?0H*9G5N8W1I;VX@<')I
M;G1?=7-A9V4H)&UE<W-A9V4@/2`G)RD@>PH*("`@(&EF("@A96UP='DH)&UE
M<W-A9V4I*2!["B`@("`@("`@<')I;G0@(G1H96UE<U]C:&5C:RYP:'`Z("1M
M97-S86=E7&Y<;B(["B`@("!]"@H@("`@<')I;G0@/#P\55-!1T4*57-A9V4Z
M('1H96UE<U]C:&5C:RYP:'`@6T]05$E/3ET*"E!O<W-I8FQE(&]P=&EO;G,Z
M"B`@+7,@("`@("`@("`@("!$;R!O;FQY(&$@<VEM<&QE(&-H96-K(&9O<B!A
M;GD@2&]R9&4@8F%S92!T:&5M92!G<F%P:&EC<R!T:&%T"B`@("`@("`@("`@
M("`@("!A<F4@;6ES<VEN9R!F<F]M('1H92!O=&AE<B!T:&5M97,L(&%N9"!N
M;R!C:&5C:R!O9B!T:&4*("`@("`@("`@("`@("`@(&]P<&]S:71E+@H@("UI
M/5!!5%1%4DX@("`@26YS97)T(&%N>2!V86QI9"!R96=E>"!P871T97)N('1O
M(&EG;F]R92!F:6QE<R!F<F]M(&)E:6YG"B`@("`@("`@("`@("`@("!C:&5C
M:V5D+B!9;W4@8V%N(&5N=&5R(&UU;'1I<&QE("UI(&]P=&EO;G,@=&\@:6YC
M;'5D92!M=6QT:7!L90H@("`@("`@("`@("`@("`@<&%T=&5R;G,N($9O<B!E
M>&%M<&QE.B`M:3TB+WAC9B0O('1O(&EG;F]R92!A;GD@;W)I9VEN86P*("`@
M("`@("`@("`@("`@($=)35`@9FEL97,N"@I54T%'13L*("`@(&5X:70["GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W5P9W)A9&5S
M+P``````````````````````````````````````````````````````````
M`````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-3$U-#,S-S4U`#`R,3$V,0`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W-C<FEP=',O=7!G<F%D97,O,BXR7W1O7S,N,"YM>7-Q;"YS<6P`````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#0V-S<`,3`U,34T,S,W-34`,#(T-#0W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"TM("1(;W)D
M93H@:&]R9&4O<V-R:7!T<R]U<&=R861E<R\R+C)?=&]?,RXP+FUY<W%L+G-Q
M;"QV(#$N,BXX+C(@,C`P-2\Q,"\Q."`Q,3HS-#HP,2!J86X@17AP("0*+2T*
M+2T@66]U(&-A;B!S:6UP;'D@97AE8W5T92!T:&ES(&9I;&4@:6X@>6]U<B!D
M871A8F%S92X*+2T*+2T@4G5N(&%S.@HM+0HM+2`D(&UY<W%L("TM=7-E<CUR
M;V]T("TM<&%S<W=O<F0]/$UY4U%,+7)O;W0M<&%S<W=O<F0^(#QD8B!N86UE
M/B`\(#(N,E]T;U\S+C`N;7ES<6PN<W%L"@I54T4@:&]R9&4["@I!3%1%4B!4
M04),12!H;W)D95]P<F5F<R!#2$%.1T4@0T],54U.('!R969?=6ED('!R969?
M=6ED(%9!4D-(05(H,C`P*2!.3U0@3E5,3#L*1$5,151%($923TT@:&]R9&5?
M<')E9G,@5TA%4D4@<')E9E]N86UE(#T@)VQA<W1?;&]G:6XG($%.1"!P<F5F
M7W-C;W!E(#T@)VEM<"<["@I#4D5!5$4@5$%"3$4@:&]R9&5?9&%T871R964@
M*`H@("`@("`@9&%T871R965?:60@24Y4($Y/5"!.54Q,+`H@("`@("`@9W)O
M=7!?=6ED(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@("`@('5S97)?=6ED
M(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@("`@(&1A=&%T<F5E7VYA;64@
M5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@("`@9&%T871R965?<&%R96YT
M<R!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("`@("!D871A=')E95]O<F1E
M<B!)3E0L"B`@("`@("!D871A=')E95]D871A(%1%6%0L"B`@("`@("!D871A
M=')E95]S97)I86QI>F5D(%--04Q,24Y4($1%1D%53%0@,"!.3U0@3E5,3"P*
M("`@("`@(&1A=&%T<F5E7W5P9&%T960@5$E-15-404U0+`H*("`@("`@(%!2
M24U!4ED@2T59("AD871A=')E95]I9"D**3L*"D-214%412!)3D1%6"!D871A
M=')E95]D871A=')E95]N86UE7VED>"!/3B!H;W)D95]D871A=')E92`H9&%T
M871R965?;F%M92D["D-214%412!)3D1%6"!D871A=')E95]G<F]U<%]I9'@@
M3TX@:&]R9&5?9&%T871R964@*&=R;W5P7W5I9"D["D-214%412!)3D1%6"!D
M871A=')E95]U<V5R7VED>"!/3B!H;W)D95]D871A=')E92`H=7-E<E]U:60I
M.PI#4D5!5$4@24Y$15@@9&%T871R965?<V5R:6%L:7IE9%]I9'@@3TX@:&]R
M9&5?9&%T871R964@*&1A=&%T<F5E7W-E<FEA;&EZ960I.PH*0U)%051%(%1!
M0DQ%(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*`H@("`@9&%T871R965?
M:60@24Y4($Y/5"!.54Q,+`H@("`@871T<FEB=71E7VYA;64@5D%20TA!4B@R
M-34I($Y/5"!.54Q,+`H@("`@871T<FEB=71E7VME>2!605)#2$%2*#(U-2D@
M1$5&055,5"`G)R!.3U0@3E5,3"P*("`@(&%T=')I8G5T95]V86QU92!415A4
M"BD["@I#4D5!5$4@24Y$15@@9&%T871R965?871T<FEB=71E7VED>"!/3B!H
M;W)D95]D871A=')E95]A='1R:6)U=&5S("AD871A=')E95]I9"D["D-214%4
M12!)3D1%6"!D871A=')E95]A='1R:6)U=&5?;F%M95]I9'@@3TX@:&]R9&5?
M9&%T871R965?871T<FEB=71E<R`H871T<FEB=71E7VYA;64I.PI#4D5!5$4@
M24Y$15@@9&%T871R965?871T<FEB=71E7VME>5]I9'@@3TX@:&]R9&5?9&%T
M871R965?871T<FEB=71E<R`H871T<FEB=71E7VME>2D["@I'4D%.5"!314Q%
M0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?9&%T871R964@
M5$\@:&]R9&5`;&]C86QH;W-T.PI'4D%.5"!314Q%0U0L($E.4T525"P@55!$
M051%+"!$14Q%5$4@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R!43R!H
M;W)D94!L;V-A;&AO<W0["@I#4D5!5$4@5$%"3$4@:&]R9&5?=&]K96YS("@*
M("`@('1O:V5N7V%D9')E<W,@("`@5D%20TA!4B@X*2!.3U0@3E5,3"P*("`@
M('1O:V5N7VED("`@("`@("`@5D%20TA!4B@S,BD@3D]4($Y53$PL"B`@("!T
M;VME;E]T:6UE<W1A;7`@($))1TE.5"!.3U0@3E5,3"P*"B`@("!04DE-05)9
M($M%62`H=&]K96Y?861D<F5S<RP@=&]K96Y?:60I"BD["@I'4D%.5"!314Q%
M0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?=&]K96YS(%1/
M(&AO<F1E0&QO8V%L:&]S=#L*"D-214%412!404),12!H;W)D95]V9G,@*`H@
M("`@=F9S7VED("`@("`@("!"24=)3E0@3D]4($Y53$PL"B`@("!V9G-?='EP
M92`@("`@(%--04Q,24Y4($Y/5"!.54Q,+`H@("`@=F9S7W!A=&@@("`@("!6
M05)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;F%M92`@("`@(%9!4D-(
M05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]M;V1I9FEE9"`@0DE'24Y4($Y/
M5"!.54Q,+`H@("`@=F9S7V]W;F5R("`@("!605)#2$%2*#(U-2D@3D]4($Y5
M3$PL"B`@("!V9G-?9&%T82`@("`@($Q/3D="3$]"+`H*("`@(%!224U!4ED@
M2T59("`@*'9F<U]I9"D**3L*"D-214%412!)3D1%6"!V9G-?<&%T:%]I9'@@
M3TX@:&]R9&5?=F9S("AV9G-?<&%T:"D["D-214%412!)3D1%6"!V9G-?;F%M
M95]I9'@@3TX@:&]R9&5?=F9S("AV9G-?;F%M92D["@I'4D%.5"!314Q%0U0L
M($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?=F9S(%1/(&AO<F1E
M0&QO8V%L:&]S=#L*````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W-C<FEP=',O=7!G<F%D97,O,BXR7W1O7S,N,"YO8VDX
M+G-Q;```````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0T-S,`,3`U,34T,S,W-34`
M,#(T,3,V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"TM("1(;W)D93H@:&]R9&4O<V-R:7!T<R]U<&=R861E<R\R+C)?=&]?
M,RXP+F]C:3@N<W%L+'8@,2XQ+C(N,2`R,#`V+S`T+S`V(#(R.C4S.C0P(&IA
M;B!%>'`@)`H*04Q415(@5$%"3$4@:&]R9&5?<')E9G,@34]$2499('!R969?
M=6ED(%9!4D-(05(R*#(U-2D["D%,5$52(%1!0DQ%(&AO<F1E7W!R969S($U/
M1$E&62!P<F5F7W-C;W!E(%9!4D-(05(R*#$V*3L*04Q415(@5$%"3$4@:&]R
M9&5?<')E9G,@34]$2499('!R969?;F%M92!605)#2$%2,B@S,BD["E501$%4
M12!H;W)D95]P<F5F<R!3150@<')E9E]U:60@/2!25%))32AP<F5F7W5I9"D[
M"E501$%412!H;W)D95]P<F5F<R!3150@<')E9E]S8V]P92`](%)44DE-*'!R
M969?<V-O<&4I.PI54$1!5$4@:&]R9&5?<')E9G,@4T54('!R969?;F%M92`]
M(%)44DE-*'!R969?;F%M92D["@I$14Q%5$4@1E)/32!H;W)D95]P<F5F<R!7
M2$5212!P<F5F7VYA;64@/2`G;&%S=%]L;V=I;B<@04Y$('!R969?<V-O<&4@
M/2`G:6UP)SL*"D-214%412!404),12!H;W)D95]D871A=')E92`H"B`@("!D
M871A=')E95]I9"`@("`@("`@("!.54U"15(H,38I($Y/5"!.54Q,+`H@("`@
M9W)O=7!?=6ED("`@("`@("`@("`@5D%20TA!4C(H,C4U*2!.3U0@3E5,3"P*
M("`@('5S97)?=6ED("`@("`@("`@("`@(%9!4D-(05(R*#(U-2DL"B`@("!D
M871A=')E95]N86UE("`@("`@("!605)#2$%2,B@R-34I($Y/5"!.54Q,+`H@
M("`@9&%T871R965?<&%R96YT<R`@("`@5D%20TA!4C(H,C4U*2P*("`@(&1A
M=&%T<F5E7V]R9&5R("`@("`@($Y534)%4B@Q-BDL"B`@("!D871A=')E95]D
M871A("`@("`@("!#3$]"+`H@("`@9&%T871R965?<V5R:6%L:7IE9"`@3E5-
M0D52*#@I($1%1D%53%0@,"!.3U0@3E5,3"P*("`@(&1A=&%T<F5E7W5P9&%T
M960@("`@($1!5$4L"@H@("`@4%))34%262!+15D@*&1A=&%T<F5E7VED*0HI
M.PH*0U)%051%($E.1$58(&1A=&%T<F5E7V1A=&%T<F5E7VYA;65?:61X($].
M(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]N86UE*3L*0U)%051%($E.1$58
M(&1A=&%T<F5E7V=R;W5P7VED>"!/3B!H;W)D95]D871A=')E92`H9W)O=7!?
M=6ED*3L*0U)%051%($E.1$58(&1A=&%T<F5E7W5S97)?:61X($].(&AO<F1E
M7V1A=&%T<F5E("AU<V5R7W5I9"D["D-214%412!)3D1%6"!D871A=')E95]O
M<F1E<E]I9'@@3TX@:&]R9&5?9&%T871R964@*&1A=&%T<F5E7V]R9&5R*3L*
M0U)%051%($E.1$58(&1A=&%T<F5E7W-E<FEA;&EZ961?:61X($].(&AO<F1E
M7V1A=&%T<F5E("AD871A=')E95]S97)I86QI>F5D*3L*"D-214%412!404),
M12!H;W)D95]D871A=')E95]A='1R:6)U=&5S("@*("`@(&1A=&%T<F5E7VED
M("`@("`@3E5-0D52*#$V*2!.3U0@3E5,3"P*("`@(&%T=')I8G5T95]N86UE
M("`@5D%20TA!4C(H,C4U*2!.3U0@3E5,3"P*("`@(&%T=')I8G5T95]K97D@
M("`@5D%20TA!4C(H,C4U*2P*("`@(&%T=')I8G5T95]V86QU92`@5D%20TA!
M4C(H-#`P,"D**3L*"D-214%412!)3D1%6"!D871A=')E95]A='1R:6)U=&5?
M:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&1A=&%T<F5E7VED
M*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V%T=')I8G5T95]N86UE7VED>"!/
M3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S("AA='1R:6)U=&5?;F%M92D[
M"D-214%412!)3D1%6"!D871A=')E95]A='1R:6)U=&5?:V5Y7VED>"!/3B!H
M;W)D95]D871A=')E95]A='1R:6)U=&5S("AA='1R:6)U=&5?:V5Y*3L*"D-2
M14%412!404),12!H;W)D95]T;VME;G,@*`H@("`@=&]K96Y?861D<F5S<R`@
M("!605)#2$%2,B@Q,#`I($Y/5"!.54Q,+`H@("`@=&]K96Y?:60@("`@("`@
M("!605)#2$%2,B@S,BD@3D]4($Y53$PL"B`@("!T;VME;E]T:6UE<W1A;7`@
M($Y534)%4B@Q-BD@3D]4($Y53$PL"@H@("`@4%))34%262!+15D@*'1O:V5N
M7V%D9')E<W,L('1O:V5N7VED*0HI.PH*0U)%051%(%1!0DQ%(&AO<F1E7W9F
M<R`H"B`@("!V9G-?:60@("`@("`@($Y534)%4B@Q-BD@3D]4($Y53$PL"B`@
M("!V9G-?='EP92`@("`@($Y534)%4B@X*2!.3U0@3E5,3"P*("`@('9F<U]P
M871H("`@("`@5D%20TA!4C(H,C4U*2P*("`@('9F<U]N86UE("`@("`@5D%2
M0TA!4C(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]M;V1I9FEE9"`@3E5-0D52
M*#$V*2!.3U0@3E5,3"P*("`@('9F<U]O=VYE<B`@("`@5D%20TA!4C(H,C4U
M*2P*("`@('9F<U]D871A("`@("`@0DQ/0BP*"B`@("!04DE-05)9($M%62`@
M("AV9G-?:60I"BD["@I#4D5!5$4@24Y$15@@=F9S7W!A=&A?:61X($].(&AO
M<F1E7W9F<R`H=F9S7W!A=&@I.PI#4D5!5$4@24Y$15@@=F9S7VYA;65?:61X
M($].(&AO<F1E7W9F<R`H=F9S7VYA;64I.PH*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O=7!G<F%D97,O,BXR
M7W1O7S,N,"YP9W-Q;"YS<6P`````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#0W,3``
M,3`U,34T,S,W-34`,#(T-#$T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"TM(%EO=2!C86X@<VEM<&QY(&5X96-U=&4@=&AI
M<R!F:6QE(&EN('EO=7(@9&%T86)A<V4N"BTM"BTM(%)U;B!A<SH*+2T*+2T@
M)"!P<W%L(#QD8B!N86UE/B`M9B`R+C)?=&]?,RXP+G!O<W1G<F5S<6PN<W%L
M"@I"14=)3CL*04Q415(@5$%"3$4@:&]R9&5?<')E9G,@041$($-/3%5-3B!P
M<F5F7W5I9%]N97<@5D%20TA!4B@R,#`I.PI54$1!5$4@:&]R9&5?<')E9G,@
M4T54('!R969?=6ED7VYE=R`]('!R969?=6ED.PI!3%1%4B!404),12!H;W)D
M95]P<F5F<R!$4D]0('!R969?=6ED.PI!3%1%4B!404),12!H;W)D95]P<F5F
M<R!214Y!344@<')E9E]U:61?;F5W(%1/('!R969?=6ED.PI!3%1%4B!404),
M12!H;W)D95]P<F5F<R!!3%1%4B!#3TQ534X@<')E9E]U:60@4T54($Y/5"!.
M54Q,.PI#3TU-250["D1%3$5412!&4D]-(&AO<F1E7W!R969S(%=(15)%('!R
M969?;F%M92`]("=L87-T7VQO9VEN)R!!3D0@<')E9E]S8V]P92`]("=I;7`G
M.PH*0U)%051%(%1!0DQ%(&AO<F1E7V1A=&%T<F5E("@*("`@("`@(&1A=&%T
M<F5E7VED($E.5"!.3U0@3E5,3"P*("`@("`@(&=R;W5P7W5I9"!605)#2$%2
M*#(U-2D@3D]4($Y53$PL"B`@("`@("!U<V5R7W5I9"!605)#2$%2*#(U-2D@
M3D]4($Y53$PL"B`@("`@("!D871A=')E95]N86UE(%9!4D-(05(H,C4U*2!.
M3U0@3E5,3"P*("`@("`@(&1A=&%T<F5E7W!A<F5N=',@5D%20TA!4B@R-34I
M($Y/5"!.54Q,+`H@("`@("`@9&%T871R965?;W)D97(@24Y4+`H@("`@("`@
M9&%T871R965?9&%T82!415A4+`H@("`@("`@9&%T871R965?<V5R:6%L:7IE
M9"!334%,3$E.5"!$149!54Q4(#`@3D]4($Y53$PL"B`@("`@("!D871A=')E
M95]U<&1A=&5D(%1)34535$%-4"P*"B`@("`@("!04DE-05)9($M%62`H9&%T
M871R965?:60I"BD["@I#4D5!5$4@24Y$15@@9&%T871R965?9&%T871R965?
M;F%M95]I9'@@3TX@:&]R9&5?9&%T871R964@*&1A=&%T<F5E7VYA;64I.PI#
M4D5!5$4@24Y$15@@9&%T871R965?9W)O=7!?:61X($].(&AO<F1E7V1A=&%T
M<F5E("AG<F]U<%]U:60I.PI#4D5!5$4@24Y$15@@9&%T871R965?=7-E<E]I
M9'@@3TX@:&]R9&5?9&%T871R964@*'5S97)?=6ED*3L*0U)%051%($E.1$58
M(&1A=&%T<F5E7W-E<FEA;&EZ961?:61X($].(&AO<F1E7V1A=&%T<F5E("AD
M871A=')E95]S97)I86QI>F5D*3L*"D-214%412!404),12!H;W)D95]D871A
M=')E95]A='1R:6)U=&5S("@*("`@(&1A=&%T<F5E7VED($E.5"!.3U0@3E5,
M3"P*("`@(&%T=')I8G5T95]N86UE(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*
M("`@(&%T=')I8G5T95]K97D@5D%20TA!4B@R-34I($1%1D%53%0@)R<@3D]4
M($Y53$PL"B`@("!A='1R:6)U=&5?=F%L=64@5$585`HI.PH*0U)%051%($E.
M1$58(&1A=&%T<F5E7V%T=')I8G5T95]I9'@@3TX@:&]R9&5?9&%T871R965?
M871T<FEB=71E<R`H9&%T871R965?:60I.PI#4D5!5$4@24Y$15@@9&%T871R
M965?871T<FEB=71E7VYA;65?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I
M8G5T97,@*&%T=')I8G5T95]N86UE*3L*0U)%051%($E.1$58(&1A=&%T<F5E
M7V%T=')I8G5T95]K97E?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T
M97,@*&%T=')I8G5T95]K97DI.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%50
M1$%412P@1$5,151%($].(&AO<F1E7V1A=&%T<F5E(%1/(&AO<F1E.PI'4D%.
M5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?9&%T
M871R965?871T<FEB=71E<R!43R!H;W)D93L*"D-214%412!404),12!H;W)D
M95]T;VME;G,@*`H@("`@=&]K96Y?861D<F5S<R`@("!605)#2$%2*#@I($Y/
M5"!.54Q,+`H@("`@=&]K96Y?:60@("`@("`@("!605)#2$%2*#,R*2!.3U0@
M3E5,3"P*("`@('1O:V5N7W1I;65S=&%M<"`@0DE'24Y4($Y/5"!.54Q,+`H*
M("`@(%!224U!4ED@2T59("AT;VME;E]A9&1R97-S+"!T;VME;E]I9"D**3L*
M"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D
M95]T;VME;G,@5$\@:&]R9&4["@I#4D5!5$4@5$%"3$4@:&]R9&5?=F9S("@*
M("`@('9F<U]I9"`@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@("`@=F9S7W1Y
M<&4@("`@("!334%,3$E.5"!.3U0@3E5,3"P*("`@('9F<U]P871H("`@("`@
M5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VYA;64@("`@("!605)#
M2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;6]D:69I960@($))1TE.5"!.
M3U0@3E5,3"P*("`@('9F<U]O=VYE<B`@("`@5D%20TA!4B@R-34I($Y/5"!.
M54Q,+`H@("`@=F9S7V1A=&$@("`@("!415A4+`H*("`@(%!224U!4ED@2T59
M("`@*'9F<U]I9"D**3L*"D-214%412!)3D1%6"!V9G-?<&%T:%]I9'@@3TX@
M:&]R9&5?=F9S("AV9G-?<&%T:"D["D-214%412!)3D1%6"!V9G-?;F%M95]I
M9'@@3TX@:&]R9&5?=F9S("AV9G-?;F%M92D["@I'4D%.5"!314Q%0U0L($E.
M4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?=F9S(%1/(&AO<F1E.PH*
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O
M=7!G<F%D97,O,C`P-2TP.2TR,E]H;W)D95]P<F5F<U]V87)C:&%R,BYO8VDX
M+G-Q;```````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#$Q-S,`,3`U,34T,S,W-34`,#(W-S4R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"TM(%5S92!T:&ES('-C<FEP
M="!T;R!C;VYV97)T($-(05(@8V]L=6UN<R!I;B!H;W)D95]P<F5F<R!T;R!6
M05)#2$%2,B!A;F0@=')I;0HM+2!T:&4@<W!A8V4@<&%D9&EN9RX@(%1H:7,@
M:7,@;VYL>2!N96-E<W-A<GD@:68@:&]R9&5?<')E9G,@=V%S(&-R96%T960@
M=7-I;F<*+2T@<V-R:7!T<R]S<6PO8W)E871E+F]C:3@N<W%L"BTM"BTM("1(
M;W)D93H@:&]R9&4O<V-R:7!T<R]U<&=R861E<R\R,#`U+3`Y+3(R7VAO<F1E
M7W!R969S7W9A<F-H87(R+F]C:3@N<W%L+'8@,2XQ+C(N,2`R,#`U+S$P+S$X
M(#$Q.C,T.C`Q(&IA;B!%>'`@)`HM+0I!3%1%4B!404),12!H;W)D95]P<F5F
M<R!-3T1)1ED@<')E9E]U:60@5D%20TA!4C(H,C4U*3L*04Q415(@5$%"3$4@
M:&]R9&5?<')E9G,@34]$2499('!R969?<V-O<&4@5D%20TA!4C(H,38I.PI!
M3%1%4B!404),12!H;W)D95]P<F5F<R!-3T1)1ED@<')E9E]N86UE(%9!4D-(
M05(R*#,R*3L*55!$051%(&AO<F1E7W!R969S(%-%5"!P<F5F7W5I9"`](%)4
M4DE-*'!R969?=6ED*3L*55!$051%(&AO<F1E7W!R969S(%-%5"!P<F5F7W-C
M;W!E(#T@4E1224TH<')E9E]S8V]P92D["E501$%412!H;W)D95]P<F5F<R!3
M150@<')E9E]N86UE(#T@4E1224TH<')E9E]N86UE*3L*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C
M<FEP=',O=7!G<F%D97,O,C`P-BTP-BTR.5]H;W)D95]P<F5F<U]I;F1E>&5S
M+G-Q;```````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`U-3$`,3`U,34T,S,W-34`,#(W,#0T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"TM(%1H:7,@<V-R
M:7!T(&%D9',@861D:71I;VYA;"!I;F1E>&5S('1O('1H92!H;W)D95]P<F5F
M<R!T86)L92!T:&%T('-H;W5L9`HM+2!I;7!R;W9E(&QO861I;F<@;V8@<')E
M9F5R96YC97,@9G)O;2!T:&4@<')E9F5R96YC92!T86)L92X*+2T*+2T@)$AO
M<F1E.B!H;W)D92]S8W)I<'1S+W5P9W)A9&5S+S(P,#8M,#8M,CE?:&]R9&5?
M<')E9G-?:6YD97AE<RYS<6PL=B`Q+C$N,BXQ(#(P,#8O,#8O,CD@,38Z,CDZ
M,#,@:F%N($5X<"`D"@I#4D5!5$4@24Y$15@@<')E9E]U:61?:61X($].(&AO
M<F1E7W!R969S("AP<F5F7W5I9"D["D-214%412!)3D1%6"!P<F5F7W-C;W!E
M7VED>"!/3B!H;W)D95]P<F5F<R`H<')E9E]S8V]P92D["@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W5P9W)A
M9&5S+S,N,%]T;U\S+C$N;7ES<6PN<W%L````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`Q-S(T`#$P-3$U-#,S-S4U`#`R-#0S-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP
M=',O=7!G<F%D97,O,RXP7W1O7S,N,2YM>7-Q;"YS<6PL=B`Q+C$N,BXQ(#(P
M,#8O,#$O,#8@,3`Z-#$Z,3,@:F%N($5X<"`D"BTM"BTM(%EO=2!C86X@<VEM
M<&QY(&5X96-U=&4@=&AI<R!F:6QE(&EN('EO=7(@9&%T86)A<V4N"BTM"BTM
M(%)U;B!A<SH*+2T*+2T@)"!M>7-Q;"`M+75S97(]<F]O="`M+7!A<W-W;W)D
M/3Q->5-13"UR;V]T+7!A<W-W;W)D/B`\9&(@;F%M93X@/"`S+C!?=&]?,RXQ
M+FUY<W%L+G-Q;`H*04Q415(@5$%"3$4@:&]R9&5?=7-E<G,@041$($-/3%5-
M3B!U<V5R7W-O9G1?97AP:7)A=&EO;E]D871E($E.5#L*04Q415(@5$%"3$4@
M:&]R9&5?=7-E<G,@041$($-/3%5-3B!U<V5R7VAA<F1?97AP:7)A=&EO;E]D
M871E($E.5#L*"D-214%412!404),12!H;W)D95]H:7-T;W)I97,@*`H@("`@
M:&ES=&]R>5]I9"`@("`@("!"24=)3E0@3D]4($Y53$PL"B`@("!O8FIE8W1?
M=6ED("`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@(&AI<W1O<GE?
M86-T:6]N("`@5D%20TA!4B@S,BD@3D]4($Y53$PL"B`@("!H:7-T;W)Y7W1S
M("`@("`@($))1TE.5"!.3U0@3E5,3"P*("`@(&AI<W1O<GE?9&5S8R`@("`@
M5$585"P*("`@(&AI<W1O<GE?=VAO("`@("`@5D%20TA!4B@R-34I+`H@("`@
M:&ES=&]R>5]E>'1R82`@("!415A4+`HM+0H@("`@4%))34%262!+15D@*&AI
M<W1O<GE?:60I"BD["@I#4D5!5$4@24Y$15@@:&ES=&]R>5]A8W1I;VY?:61X
M($].(&AO<F1E7VAI<W1O<FEE<R`H:&ES=&]R>5]A8W1I;VXI.PI#4D5!5$4@
M24Y$15@@:&ES=&]R>5]T<U]I9'@@3TX@:&]R9&5?:&ES=&]R:65S("AH:7-T
M;W)Y7W1S*3L*0U)%051%($E.1$58(&AI<W1O<GE?=6ED7VED>"!/3B!H;W)D
M95]H:7-T;W)I97,@*&]B:F5C=%]U:60I.PH*1U)!3E0@4T5,14-4+"!)3E-%
M4E0L(%501$%412P@1$5,151%($].(&AO<F1E7VAI<W1O<FEE<R!43R!H;W)D
M94!L;V-A;&AO<W0["@``````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S
M+W5P9W)A9&5S+S,N,%]T;U\S+C$N;V-I."YS<6P`````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`Q,S4T`#$P-3$U-#,S-S4U`#`R-#$S,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````M+2`D2&]R9&4Z(&AO<F1E
M+W-C<FEP=',O=7!G<F%D97,O,RXP7W1O7S,N,2YO8VDX+G-Q;"QV(#$N,2XR
M+C$@,C`P-B\P-"\P-B`R,CHU,SHU-"!J86X@17AP("0*"D%,5$52(%1!0DQ%
M(&AO<F1E7W5S97)S($%$1"!U<V5R7W-O9G1?97AP:7)A=&EO;E]D871E($Y5
M34)%4B@Q-BD["D%,5$52(%1!0DQ%(&AO<F1E7W5S97)S($%$1"!U<V5R7VAA
M<F1?97AP:7)A=&EO;E]D871E($Y534)%4B@Q-BD["@I#4D5!5$4@5$%"3$4@
M:&]R9&5?:&ES=&]R:65S("@*("`@(&AI<W1O<GE?:60@("`@("`@3E5-0D52
M*#$V*2!.3U0@3E5,3"P*("`@(&]B:F5C=%]U:60@("`@("`@5D%20TA!4C(H
M,C4U*2!.3U0@3E5,3"P*("`@(&AI<W1O<GE?86-T:6]N("`@5D%20TA!4C(H
M,S(I($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]T<R`@("`@("!.54U"15(H,38I
M($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]D97-C("`@("!#3$]"+`H@("`@:&ES
M=&]R>5]W:&\@("`@("!605)#2$%2,B@R-34I+`H@("`@:&ES=&]R>5]E>'1R
M82`@("!#3$]"+`H*("`@(%!224U!4ED@2T59("AH:7-T;W)Y7VED*0HI.PH*
M0U)%051%($E.1$58(&AI<W1O<GE?86-T:6]N7VED>"!/3B!H;W)D95]H:7-T
M;W)I97,@*&AI<W1O<GE?86-T:6]N*3L*0U)%051%($E.1$58(&AI<W1O<GE?
M='-?:61X($].(&AO<F1E7VAI<W1O<FEE<R`H:&ES=&]R>5]T<RD["D-214%4
M12!)3D1%6"!H:7-T;W)Y7W5I9%]I9'@@3TX@:&]R9&5?:&ES=&]R:65S("AO
M8FIE8W1?=6ED*3L*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M8W)I<'1S+W5P9W)A9&5S+S,N,%]T;U\S+C$N<W%L````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`Q,S,V`#$P-3$U-#,S-S4U`#`R,S(W,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````M+2`D2&]R9&4Z
M(&AO<F1E+W-C<FEP=',O=7!G<F%D97,O,RXP7W1O7S,N,2YS<6PL=B`Q+C$N
M,BXQ(#(P,#8O,#,O,CD@,C$Z,C<Z-3(@:F%N($5X<"`D"@I!3%1%4B!404),
M12!H;W)D95]U<V5R<R!!1$0@0T],54U.('5S97)?<V]F=%]E>'!I<F%T:6]N
M7V1A=&4@24Y4.PI!3%1%4B!404),12!H;W)D95]U<V5R<R!!1$0@0T],54U.
M('5S97)?:&%R9%]E>'!I<F%T:6]N7V1A=&4@24Y4.PH*0U)%051%(%1!0DQ%
M(&AO<F1E7VAI<W1O<FEE<R`H"B`@("!H:7-T;W)Y7VED("`@("`@($))1TE.
M5"!.3U0@3E5,3"P*("`@(&]B:F5C=%]U:60@("`@("`@5D%20TA!4B@R-34I
M($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]A8W1I;VX@("!605)#2$%2*#,R*2!.
M3U0@3E5,3"P*("`@(&AI<W1O<GE?=',@("`@("`@0DE'24Y4($Y/5"!.54Q,
M+`H@("`@:&ES=&]R>5]D97-C("`@("!415A4+`H@("`@:&ES=&]R>5]W:&\@
M("`@("!605)#2$%2*#(U-2DL"B`@("!H:7-T;W)Y7V5X=')A("`@(%1%6%0L
M"BTM"B`@("!04DE-05)9($M%62`H:&ES=&]R>5]I9"D**3L*"D-214%412!)
M3D1%6"!H:7-T;W)Y7V%C=&EO;E]I9'@@3TX@:&]R9&5?:&ES=&]R:65S("AH
M:7-T;W)Y7V%C=&EO;BD["D-214%412!)3D1%6"!H:7-T;W)Y7W1S7VED>"!/
M3B!H;W)D95]H:7-T;W)I97,@*&AI<W1O<GE?=',I.PI#4D5!5$4@24Y$15@@
M:&ES=&]R>5]U:61?:61X($].(&AO<F1E7VAI<W1O<FEE<R`H;V)J96-T7W5I
M9"D["@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]S8W)I<'1S+W5P9W)A9&5S+VUO=F5?:&ES=&]R>5]O=71?;V9?9&%T
M871R964N<&AP`````````````````````````````````#`P,#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-#0P`#$P-3$U-#,S-S4U`#`R-S8U-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````C(2]U
M<W(O8FEN+W!H<"`M<0H\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]S8W)I
M<'1S+W5P9W)A9&5S+VUO=F5?:&ES=&]R>5]O=71?;V9?9&%T871R964N<&AP
M+'8@,2XS+C(N,2`R,#`U+S$P+S$X(#$Q.C,T.C`Q(&IA;B!%>'`@)`H@*@H@
M*B!4:&ES(&ES(&$@<V-R:7!T('1O(&UI9W)A=&4@2&ES=&]R>2!I;F9O<FUA
M=&EO;B!O=70@;V8@=&AE(&1A=&%T<F5E"B`J('1A8FQE<R!A;F0@:6YT;R!I
M=',@;W=N(&1A=&%B87-E('1A8FQE+@H@*B\*"B\O($9I;F0@=&AE(&)A<V4@
M9FEL92!P871H(&]F($AO<F1E+@I`9&5F:6YE*"=!551(7TA!3D1,15(G+"!T
M<G5E*3L*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I
M("X@)R\N+B\N+B<I.PH*+R\@1&\@0TQ)(&-H96-K<R!A;F0@96YV:7)O;FUE
M;G0@<V5T=7`@9FER<W0N"G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L
M:6(O8V]R92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T-,22YP:'`G.PH*
M+R\@36%K92!S=7)E(&YO(&]N92!R=6YS('1H:7,@9G)O;2!T:&4@=V5B+@II
M9B`H(4AO<F1E7T-,23HZ<G5N;FEN9T9R;VU#3$DH*2D@>PH@("`@97AI="@B
M375S="!B92!R=6X@9G)O;2!T:&4@8V]M;6%N9"!L:6YE7&XB*3L*?0H*+R\@
M3&]A9"!T:&4@0TQ)(&5N=FER;VYM96YT("T@;6%K92!S=7)E('1H97)E)W,@
M;F\@=&EM92!L:6UI="P@:6YI=`HO+R!S;VUE('9A<FEA8FQE<RP@971C+@I(
M;W)D95]#3$DZ.FEN:70H*3L*)&-L:2`]($AO<F1E7T-,23HZ<VEN9VQE=&]N
M*"D["@HD8VQI+3YW<FET96QN*"1C;&DM/GEE;&QO=R@B0F5G:6YN:6YG(&UI
M9W)A=&EO;BX@5&AI<R!M87D@=&%K92!A('9E<GD@;&]N9R!T:6UE('1O(&-O
M;7!L971E+B(I*3L*)&-L:2T^=W)I=&5L;B@I.PH*<F5Q=6ER95]O;F-E($A/
M4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R
M9&4O1&%T851R964N<&AP)SL*"F-L87-S($1A=&%4<F5E3V)J96-T7TAI<W1O
M<GD@97AT96YD<R!$871A5')E94]B:F5C="!["@H@("`@9G5N8W1I;VX@7V9R
M;VU!='1R:6)U=&5S*"1A='1R:6)U=&5S*0H@("`@>PH@("`@("`@("\J($EN
M:71I86QI>F4@9&%T82!A<G)A>2X@*B\*("`@("`@("`D=&AI<RT^9&%T82`]
M(&%R<F%Y*"D["@H@("`@("`@(&9O<F5A8V@@*"1A='1R:6)U=&5S(&%S("1A
M='1R*2!["B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/F1A=&%;)&%T
M=');)VYA;64G75TI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^9&%T85LD
M871T<ELG;F%M92==72`](&%R<F%Y*"D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'1H:7,M/F1A=&%;)&%T=');)VYA;64G75U;)&%T=');)VME>2==
M72`]("1A='1R6R=V86QU92==.PH@("`@("`@('T*("`@('T*"GT*"B1D871A
M=')E92`]("9$871A5')E93HZ9F%C=&]R>2@G<W%L)RP@87)R87E?;65R9V4H
M2&]R9&4Z.F=E=$1R:79E<D-O;F9I9R@G9&%T871R964G+"`G<W%L)RDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)V=R;W5P)R`]/B`G:&]R9&4N:&ES=&]R>2<I*2D["B1D8B`]
M("8D9&%T871R964M/E]D8CL*"B1I<W%L(#T@)TE.4T525"!)3E1/(&AO<F1E
M7VAI<W1O<FEE<R`H:&ES=&]R>5]I9"P@;V)J96-T7W5I9"P@:&ES=&]R>5]A
M8W1I;VXL(&AI<W1O<GE?9&5S8RP@:&ES=&]R>5]W:&\L(&AI<W1O<GE?=',L
M(&AI<W1O<GE?97AT<F$I)R`N"B`@("`@("`@)R!604Q515,@*#\L(#\L(#\L
M(#\L(#\L(#\L(#\I)SL*"B1A;&P@/2`D9&%T871R964M/F=E="A$051!5%)%
M15]&3U)-051?1DQ!5"P@1$%40512145?4D]/5"P@=')U92D["G5N<V5T*"1A
M;&Q;1$%40512145?4D]/5%TI.PHD:61S(#T@87)R87E?:V5Y<R@D86QL*3L*
M"F9O<F5A8V@@*"1I9',@87,@)&ED*2!["B`@("`D;V(@/2`D9&%T871R964M
M/F=E=$]B:F5C=$)Y260H)&ED+"`G1&%T851R965/8FIE8W1?2&ES=&]R>2<I
M.PH@("`@9F]R96%C:"`H)&]B+3YG971$871A*"D@87,@)')O=RD@>PH@("`@
M("`@("1V86QU97,@/2!A<G)A>2@D9&(M/FYE>'1)9"@G:&]R9&5?:&ES=&]R
M:65S)RDL("`@("`@("`@("`@("`@("`@+R\@:&ES=&]R>5]I9`H@("`@("`@
M("`@("`@("`@("`@("`@("`D;V(M/F=E=$YA;64H*2P@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@;V)J96-T7W5I9`H@("`@("`@("`@
M("`@("`@("`@("`@("!I<W-E="@D<F]W6R=A8W1I;VXG72D@/R`D<F]W6R=A
M8W1I;VXG72`Z(&YU;&PL("`@+R\@:&ES=&]R>5]A8W1I;VX*("`@("`@("`@
M("`@("`@("`@("`@("`@:7-S970H)')O=ULG9&5S8R==*2`_("1R;W=;)V1E
M<V,G72`Z(&YU;&PL("`@("`@("\O(&AI<W1O<GE?9&5S8PH@("`@("`@("`@
M("`@("`@("`@("`@("!I<W-E="@D<F]W6R=W:&\G72D@/R`D<F]W6R=W:&\G
M72`Z(&YU;&PL("`@("`@("`@+R\@:&ES=&]R>5]W:&\*("`@("`@("`@("`@
M("`@("`@("`@("`@:7-S970H)')O=ULG=',G72D@/R`D<F]W6R=T<R==(#H@
M;G5L;"P@("`@("`@("`@("\O(&AI<W1O<GE?=',*("`@("`@("`@("`@("`@
M("`@("`@("`@*3L*"B`@("`@("`@=6YS970H)')O=ULG86-T:6]N)UTI.PH@
M("`@("`@('5N<V5T*"1R;W=;)V1E<V,G72D["B`@("`@("`@=6YS970H)')O
M=ULG=VAO)UTI.PH@("`@("`@('5N<V5T*"1R;W=;)W1S)UTI.PH@("`@("`@
M(&EF("AC;W5N="@D<F]W*2D@>PH@("`@("`@("`@("`D=F%L=65S6UT@/2!S
M97)I86QI>F4H)')O=RD[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@:&ES=&]R>5]E>'1R80H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1V86QU97-;72`](&YU;&P[("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!H:7-T;W)Y7V5X=')A"B`@("`@("`@
M?0H*("`@("`@("!C:&5C:R@D9&(M/G%U97)Y*"1I<W%L+"`D=F%L=65S*2D[
M"B`@("!]"@H@("`@8VAE8VLH)&1B+3YQ=65R>2@G1$5,151%($923TT@:&]R
M9&5?9&%T871R965?871T<FEB=71E<R!72$5212!D871A=')E95]I9"`](#\G
M+"!A<G)A>2@D:60I*2D["B`@("!C:&5C:R@D9&(M/G%U97)Y*"=$14Q%5$4@
M1E)/32!H;W)D95]D871A=')E92!72$5212!D871A=')E95]I9"`](#\G+"!A
M<G)A>2@D:60I*2D["GT*"B1C;&DM/G=R:71E;&XH)&-L:2T^9W)E96XH(D1O
M;F4N($UI9W)A=&5D("(@+B!C;W5N="@D:61S*2`N("(@;V)J96-T<RXB*2D[
M"@IF=6YC=&EO;B!C:&5C:R@D<F5S=6QT*0I["B`@("!I9B`H:7-?82@D<F5S
M=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@=F%R7V1U;7`H)')E<W5L
M="D["B`@("`@("`@97AI=#L*("`@('T*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<V5R=FEC97,O````````````````````````````````````````
M```````````````````````````````````````````````P,#`P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U-P`P,3<U,#4`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]C86-H979I97<N<&AP
M````````````````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-#<V`#$P
M-3$U-#,S-S4W`#`R,C$V-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]S97)V
M:6-E<R]C86-H979I97<N<&AP+'8@,2XY+C$P+C,@,C`P-B\P,2\P,2`R,3HR
M.3HQ,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N
M<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]#86-H92YP:'`G.PH*)&-I9"`]
M(%5T:6PZ.F=E=$9O<FU$871A*"=C:60G*3L*:68@*&5M<'1Y*"1C:60I*2![
M"B`@("!E>&ET.PI]"@HD8V%C:&4@/2`F2&]R9&5?0V%C:&4Z.G-I;F=L971O
M;B@D8V]N9ELG8V%C:&4G75LG9')I=F5R)UTL($AO<F1E.CIG971$<FEV97)#
M;VYF:6<H)V-A8VAE)RP@)&-O;F9;)V-A8VAE)UU;)V1R:79E<B==*2D["B1C
M9&%T82`]($!U;G-E<FEA;&EZ92@D8V%C:&4M/F=E="@D8VED+"`D8V]N9ELG
M8V%C:&4G75LG9&5F875L=%]L:69E=&EM92==*2D["FEF("@A)&-D871A*2![
M"B`@("!E>&ET.PI]"@HD8G)O=W-E<BT^9&]W;FQO861(96%D97)S*"=C86-H
M94]B:F5C="<L("1C9&%T85LG8W1Y<&4G72P@=')U92P@<W1R;&5N*"1C9&%T
M85LG9&%T82==*2D["F5C:&\@)&-D871A6R=D871A)UT["@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'``````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W
M,C4V`#$P-3$U-#,S-S4W`#`R,S(T,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D
M92]S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`L=B`Q+C$N,BXR(#(P,#8O
M,#$O,#$@,C$Z,CDZ,3`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`U
M+3(P,#8@0W)O;F]S>7,L($Q,0R`\:'1T<#HO+W=W=RYC<F]N;W-Y<RYC;VT^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N
M86UE*%]?1DE,15]?*2`N("<O+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!
M4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O1F]R
M;2YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP
M)SL*<F5Q=6ER95]O;F-E("=(;W)D92]687)I86)L97,N<&AP)SL*"FEF("@A
M075T:#HZ:7-!=71H96YT:6-A=&5D*"DI('L*("`@($AO<F1E.CIA=71H96YT
M:6-A=&EO;D9A:6QU<F52961I<F5C="@I.PI]"@HO+R!-86ME('-U<F4@875T
M:"!B86-K96YD(&%L;&]W<R!P87-S=V]R9',@=&\@8F4@<F5S970N"B1A=71H
M(#T@)D%U=&@Z.G-I;F=L971O;B@D8V]N9ELG875T:"==6R=D<FEV97(G72D[
M"FEF("@A)&%U=&@M/FAA<T-A<&%B:6QI='DH)W5P9&%T92<I*2!["B`@("`D
M;F]T:69I8V%T:6]N+3YP=7-H*%\H(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@
M:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I
M;VXN("!#;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB*2P@)VAO<F1E+F5R
M<F]R)RD["B`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@075T:#HZ9V5T3&]G
M:6Y38W)E96XH)R<L(%5T:6PZ.F=E=$9O<FU$871A*"=U<FPG*2DI.PH@("`@
M97AI=#L*?0H*)'9A<G,@/2`F5F%R:6%B;&5S.CIG971$969A=6QT5F%R:6%B
M;&5S*"D["@HD=&ET;&4@/2!?*")#:&%N9V4@66]U<B!087-S=V]R9"(I.PHD
M9F]R;2`]("9(;W)D95]&;W)M.CIS:6YG;&5T;VXH)TAO<F1E4VEG;G5P1F]R
M;2<L("1V87)S+"`D=&ET;&4I.PHD9F]R;2T^<V5T0G5T=&]N<RA?*")#;VYT
M:6YU92(I*3L*"B1F;W)M+3YA9&1(:61D96XH)R<L("=R971U<FY?=&\G+"`G
M=&5X="<L(&9A;'-E*3L*)&9O<FTM/F%D9%9A<FEA8FQE*%\H(D]L9"!P87-S
M=V]R9"(I+"`G;VQD7W!A<W-W;W)D)RP@)W!A<W-W;W)D)RP@=')U92D["B1F
M;W)M+3YA9&1687)I86)L92A?*").97<@<&%S<W=O<F0B*2P@)W!A<W-W;W)D
M7S$G+"`G<&%S<W=O<F0G+"!T<G5E*3L*)&9O<FTM/F%D9%9A<FEA8FQE*%\H
M(E)E='EP92!N97<@<&%S<W=O<F0B*2P@)W!A<W-W;W)D7S(G+"`G<&%S<W=O
M<F0G+"!T<G5E*3L*"FEF("@D=F%R<RT^97AI<W1S*"=F;W)M;F%M92<I*2![
M"B`@("`D9F]R;2T^=F%L:61A=&4H)'9A<G,I.PH@("`@:68@*"1F;W)M+3YI
M<U9A;&ED*"DI('L*("`@("`@("`D9F]R;2T^9V5T26YF;R@D=F%R<RP@)&EN
M9F\I.PH@("`@("`@(&1O('L*("`@("`@("`@("`@:68@*"1A=71H+3YG971#
M<F5D96YT:6%L*"=P87-S=V]R9"<I("$]("1I;F9O6R=O;&1?<&%S<W=O<F0G
M72D@>PH@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")/
M;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(BDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=H;W)D92YE<G)O<B<I.PH@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF
M("@D:6YF;ULG<&%S<W=O<F1?,2==("$]("1I;F9O6R=P87-S=V]R9%\R)UTI
M('L*("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B3F5W
M('!A<W-W;W)D<R!D;VXG="!M871C:"XB*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1I
M;F9O6R=O;&1?<&%S<W=O<F0G72`]/2`D:6YF;ULG<&%S<W=O<F1?,2==*2![
M"B`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(D]L9"!A
M;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB*2P@)VAO<F1E
M+F5R<F]R)RD["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@+RH@1DE8344Z($YE960@=&\@8VQE86X@=7`@<&%S
M<W=O<F0@<&]L:6-Y('!A=&-H(&%N9"!C;VUM:70@8F5F;W)E"B`@("`@("`@
M("`@("`J(&5N86)L:6YG('1H:7,N+BX@+4I-1@H*("`@("`@("`@("`@)')E
M<R`]($%U=&@Z.G1E<W1087-S=V]R9%-T<F5N9W1H*"1I;F9O6R=P87-S=V]R
M9%\Q)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D8V]N9ELG875T:"==6R=P87-S=V]R9%]P;VQI8WDG72D["B`@
M("`@("`@("`@(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)')E<RT^9V5T365S
M<V%G92@I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("HO"@H@("`@("`@("`@("`D
M<F5S(#T@)&%U=&@M/G5P9&%T955S97(H075T:#HZ9V5T075T:"@I+"!!=71H
M.CIG971!=71H*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@G<&%S<W=O<F0G(#T^("1I;F9O6R=P87-S=V]R9%\Q)UTI
M*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F
M*%\H(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97,M/F=E=$UE
M<W-A9V4H*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B
M4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN(BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@
M("`@("`@:68@*"%E;7!T>2@D:6YF;ULG<F5T=7)N7W1O)UTI*2!["B`@("`@
M("`@("`@("`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@)&EN9F];)W)E='5R
M;E]T;R==*3L*("`@("`@("`@("`@("`@(&5X:70["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@?2!W:&EL92`H9F%L<V4I.PH@
M("`@?0I]"@HD=F%R<RT^<F5M;W9E*"=O;&1?<&%S<W=O<F0G*3L*)'9A<G,M
M/G)E;6]V92@G<&%S<W=O<F1?,2<I.PHD=F%R<RT^<F5M;W9E*"=P87-S=V]R
M9%\R)RD["@IR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+6AE
M861E<BYI;F,G.PHD;F]T:69I8V%T:6]N+3YN;W1I9GDH87)R87DH)VQI<W1E
M;F5R<R<@/3X@)W-T871U<R<I*3L*)')E;F1E<F5R(#T@)FYE=R!(;W)D95]&
M;W)M7U)E;F1E<F5R*"D["B1F;W)M+3YR96YD97)!8W1I=F4H)')E;F1E<F5R
M+"`D=F%R<RP@)V-H86YG97!A<W-W;W)D+G!H<"<L("=P;W-T)RD["G)E<75I
M<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]S97)V:6-E<R]D;W=N;&]A9"\`````````````````````````````````
M`````````````````````````````````````````#`P,#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S4W`#`R,3,Q-``@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V1O=VYL;V%D+VEN9&5X+G!H
M<```````````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$S,C``,3`U,34T
M,S,W-3<`,#(S,3,P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W-E<G9I8V5S
M+V1O=VYL;V%D+VEN9&5X+G!H<"QV(#$N.2XQ,"XS(#(P,#8O,#$O,#$@,C$Z
M,CDZ,3$@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EC
M:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA
M;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?
M0D%312`N("<O;&EB+V-O<F4N<&AP)SL*"B1R96=I<W1R>2`]("9296=I<W1R
M>3HZ<VEN9VQE=&]N*$A/4D1%7U-%4U-)3TY?4D5!1$].3%DI.PH*:68@*"$H
M)&UO9'5L92`](%5T:6PZ.F=E=$9O<FU$871A*"=M;V1U;&4G*2D@?'P*("`@
M("%F:6QE7V5X:7-T<R@D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G+"`D;6]D
M=6QE*2DI('L*("`@($AO<F1E.CIF871A;"@G1&\@;F]T(&-A;&P@=&AI<R!S
M8W)I<'0@9&ER96-T;'DN)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*?0II;F-L
M=61E("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1M;V1U;&4I("X@)R]V
M:65W+G!H<"<["@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B\`````
M````````````````````````````````````````````````````````````
M````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``
M,3`U,34T,S,W-38`,#(P-S<R`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R
M=FEC97,O961I=&]R+VAT;6QA<F5A+P``````````````````````````````
M```````````````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U-P`P,C(U-S``(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O9&EA;&]G
M+FIS`````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T-3<T`#$P-3$U-#,S-S4W
M`#`R-#,W-P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````O+R!H=&UL07)E82!V,RXP("T@0V]P>7)I9VAT("AC*2`R,#`S+3(P
M,#4@9'EN87)C:"YC;VT*+R\@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@,C`P,BTR,#`S(&EN=&5R86-T:79E=&]O;',N8V]M+"!I;F,N"B\O(%1H
M:7,@8V]P>7)I9VAT(&YO=&EC92!-55-4('-T87D@:6YT86-T(&9O<B!U<V4@
M*'-E92!L:6-E;G-E+G1X="DN"B\O"B\O(%!O<G1I;VYS("AC*2!D>6YA<F-H
M+F-O;2P@,C`P,RTR,#`T"B\O"B\O($$@9G)E92!765-)5UE'(&5D:71O<B!R
M97!L86-E;65N="!F;W(@/'1E>'1A<F5A/B!F:65L9',N"B\O($9O<B!F=6QL
M('-O=7)C92!C;V1E(&%N9"!D;V-S+"!V:7-I="!H='1P.B\O=W=W+FEN=&5R
M86-T:79E=&]O;',N8V]M+PHO+PHO+R!697)S:6]N(#,N,"!D979E;&]P960@
M8GD@36EH86D@0F%Z;VXN"B\O("`@:'1T<#HO+V1Y;F%R8V@N8V]M+VUI<VAO
M;PHO+PHO+R`D260Z(&1I86QO9RYJ<RQV(#$N-R`R,#`U+S`Q+S(P(#$W.C0Y
M.C`T(&UI<VAO;R!%>'`@)`H*+R\@5&AO=6=H(")$:6%L;V<B(&QO;VMS(&QI
M:V4@86X@;V)J96-T+"!I="!I<VXG="!R96%L;'D@86X@;V)J96-T+B`@26YS
M=&5A9`HO+R!I="=S(&IU<W0@;F%M97-P86-E(&9O<B!P<F]T96-T:6YG(&=L
M;V)A;"!S>6UB;VQS+@H*9G5N8W1I;VX@1&EA;&]G*'5R;"P@86-T:6]N+"!I
M;FET*2!["@EI9B`H='EP96]F(&EN:70@/3T@(G5N9&5F:6YE9"(I('L*"0EI
M;FET(#T@=VEN9&]W.PDO+R!P87-S('1H:7,@=VEN9&]W(&]B:F5C="!B>2!D
M969A=6QT"@E]"@E$:6%L;V<N7V=E8VMO3W!E;DUO9&%L*'5R;"P@86-T:6]N
M+"!I;FET*3L*?3L*"D1I86QO9RY?<&%R96YT179E;G0@/2!F=6YC=&EO;BAE
M=BD@>PH)<V5T5&EM96]U="@@9G5N8W1I;VXH*2![(&EF("A$:6%L;V<N7VUO
M9&%L("8F("%$:6%L;V<N7VUO9&%L+F-L;W-E9"D@>R!$:6%L;V<N7VUO9&%L
M+F9O8W5S*"D@?2!]+"`U,"D["@EI9B`H1&EA;&]G+E]M;V1A;"`F)B`A1&EA
M;&]G+E]M;V1A;"YC;&]S960I('L*"0E(5$U,07)E82Y?<W1O<$5V96YT*&5V
M*3L*"7T*?3L*"@HO+R!S:&]U;&0@8F4@82!F=6YC=&EO;BP@=&AE(')E='5R
M;B!H86YD;&5R(&]F('1H92!C=7)R96YT;'D@;W!E;F5D(&1I86QO9RX*1&EA
M;&]G+E]R971U<FX@/2!N=6QL.PH*+R\@8V]N<W1A;G0L('1H92!C=7)R96YT
M;'D@;W!E;F5D(&1I86QO9PI$:6%L;V<N7VUO9&%L(#T@;G5L;#L*"B\O('1H
M92!D:6%L;V<@=VEL;"!R96%D(&ET)W,@87)G<R!F<F]M('1H:7,@=F%R:6%B
M;&4*1&EA;&]G+E]A<F=U;65N=',@/2!N=6QL.PH*1&EA;&]G+E]G96-K;T]P
M96Y-;V1A;"`](&9U;F-T:6]N*'5R;"P@86-T:6]N+"!I;FET*2!["@EV87(@
M9&QG(#T@=VEN9&]W+F]P96XH=7)L+"`B:&%D:6%L;V<B+`H)"0D@("`@("`B
M=&]O;&)A<CUN;RQM96YU8F%R/6YO+'!E<G-O;F%L8F%R/6YO+'=I9'1H/3$P
M+&AE:6=H=#TQ,"PB("L*"0D)("`@("`@(G-C<F]L;&)A<G,];F\L<F5S:7IA
M8FQE/7EE<RQM;V1A;#UY97,L9&5P96YD86)L93UY97,B*3L*"41I86QO9RY?
M;6]D86P@/2!D;&<["@E$:6%L;V<N7V%R9W5M96YT<R`](&EN:70["@H)+R\@
M8V%P='5R92!S;VUE('=I;F1O=R=S(&5V96YT<PH)9G5N8W1I;VX@8V%P=VEN
M*'<I('L*"0E(5$U,07)E82Y?861D179E;G0H=RP@(F-L:6-K(BP@1&EA;&]G
M+E]P87)E;G1%=F5N="D["@D)2%1-3$%R96$N7V%D9$5V96YT*'<L(")M;W5S
M961O=VXB+"!$:6%L;V<N7W!A<F5N=$5V96YT*3L*"0E(5$U,07)E82Y?861D
M179E;G0H=RP@(F9O8W5S(BP@1&EA;&]G+E]P87)E;G1%=F5N="D["@E].PH)
M+R\@<F5L96%S92!T:&4@8V%P='5R960@979E;G1S"@EF=6YC=&EO;B!R96QW
M:6XH=RD@>PH)"4A434Q!<F5A+E]R96UO=F5%=F5N="AW+"`B8VQI8VLB+"!$
M:6%L;V<N7W!A<F5N=$5V96YT*3L*"0E(5$U,07)E82Y?<F5M;W9E179E;G0H
M=RP@(FUO=7-E9&]W;B(L($1I86QO9RY?<&%R96YT179E;G0I.PH)"4A434Q!
M<F5A+E]R96UO=F5%=F5N="AW+"`B9F]C=7,B+"!$:6%L;V<N7W!A<F5N=$5V
M96YT*3L*"7T["@EC87!W:6XH=VEN9&]W*3L*"2\O(&-A<'1U<F4@;W1H97(@
M9G)A;65S"@EF;W(@*'9A<B!I(#T@,#L@:2`\('=I;F1O=RYF<F%M97,N;&5N
M9W1H.R!C87!W:6XH=VEN9&]W+F9R86UE<UMI*RM=*2D["@DO+R!M86ME('5P
M(&$@9G5N8W1I;VX@=&\@8F4@8V%L;&5D('=H96X@=&AE($1I86QO9R!E;F1S
M+@H)1&EA;&]G+E]R971U<FX@/2!F=6YC=&EO;B`H=F%L*2!["@D):68@*'9A
M;"`F)B!A8W1I;VXI('L*"0D)86-T:6]N*'9A;"D["@D)?0H)"7)E;'=I;BAW
M:6YD;W<I.PH)"2\O(&-A<'1U<F4@;W1H97(@9G)A;65S"@D)9F]R("AV87(@
M:2`](#`[(&D@/"!W:6YD;W<N9G)A;65S+FQE;F=T:#L@<F5L=VEN*'=I;F1O
M=RYF<F%M97-;:2LK72DI.PH)"41I86QO9RY?;6]D86P@/2!N=6QL.PH)?3L*
M?3L*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M
M;&%R96$O:'1M;&%R96$N8W-S````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P,#<R
M`#$P-3$U-#,S-S4W`#`R-3`W-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N:'1M;&%R96$@>R!B86-K9W)O=6YD.B`C9F9F
M.R!]"@HN:'1M;&%R96$@+G1O;VQB87(@>PH@(&-U<G-O<CH@9&5F875L=#L*
M("!B86-K9W)O=6YD.B!"=71T;VY&86-E.PH@('!A9&1I;F<Z(#-P>#L*("!B
M;W)D97(Z(#%P>"!S;VQI9#L*("!B;W)D97(M8V]L;W(Z($)U='1O;DAI9VAL
M:6=H="!"=71T;VY3:&%D;W<@0G5T=&]N4VAA9&]W($)U='1O;DAI9VAL:6=H
M=#L*?0HN:'1M;&%R96$@+G1O;VQB87(@=&%B;&4@>R!F;VYT+69A;6EL>3H@
M=&%H;VUA+'9E<F1A;F$L<V%N<RUS97)I9CL@9F]N="US:7IE.B`Q,7!X.R!]
M"BYH=&UL87)E82`N=&]O;&)A<B!I;6<@>R!B;W)D97(Z(&YO;F4[('T*+FAT
M;6QA<F5A("YT;V]L8F%R("YL86)E;"![('!A9&1I;F<Z(#!P>"`S<'@[('T*
M"BYH=&UL87)E82`N=&]O;&)A<B`N8G5T=&]N('L*("!B86-K9W)O=6YD.B!"
M=71T;VY&86-E.PH@(&-O;&]R.B!"=71T;VY497AT.PH@(&)O<F1E<CH@,7!X
M('-O;&ED($)U='1O;D9A8V4["B`@<&%D9&EN9SH@,7!X.PH@(&UA<F=I;CH@
M,'!X.PH@('=I9'1H.B`Q.'!X.PH@(&AE:6=H=#H@,3AP>#L*?0HN:'1M;&%R
M96$@+G1O;VQB87(@+F)U='1O;DAO=F5R('L*("!B;W)D97(Z(#%P>"!S;VQI
M9#L*("!B;W)D97(M8V]L;W(Z($)U='1O;DAI9VAL:6=H="!"=71T;VY3:&%D
M;W<@0G5T=&]N4VAA9&]W($)U='1O;DAI9VAL:6=H=#L*?0HN:'1M;&%R96$@
M+G1O;VQB87(@+F)U='1O;D%C=&EV92P@+FAT;6QA<F5A("YT;V]L8F%R("YB
M=71T;VY0<F5S<V5D('L*("!P861D:6YG.B`R<'@@,'!X(#!P>"`R<'@["B`@
M8F]R9&5R.B`Q<'@@<V]L:60["B`@8F]R9&5R+6-O;&]R.B!"=71T;VY3:&%D
M;W<@0G5T=&]N2&EG:&QI9VAT($)U='1O;DAI9VAL:6=H="!"=71T;VY3:&%D
M;W<["GT*+FAT;6QA<F5A("YT;V]L8F%R("YB=71T;VY0<F5S<V5D('L*("!B
M86-K9W)O=6YD.B!"=71T;VY(:6=H;&EG:'0["GT*+FAT;6QA<F5A("YT;V]L
M8F%R("YI;F1I8V%T;W(@>PH@('!A9&1I;F<Z(#!P>"`S<'@["B`@;W9E<F9L
M;W<Z(&AI9&1E;CL*("!W:61T:#H@,C!P>#L*("!T97AT+6%L:6=N.B!C96YT
M97(["B`@8W5R<V]R.B!D969A=6QT.PH@(&)O<F1E<CH@,7!X('-O;&ED($)U
M='1O;E-H861O=SL*?0H*+FAT;6QA<F5A("YT;V]L8F%R("YB=71T;VY$:7-A
M8FQE9"!I;6<@>PH@(&9I;'1E<CH@9W)A>2@I(&%L<&AA*&]P86-I='D@/2`R
M-2D["B`@+6UO>BUO<&%C:71Y.B`P+C(U.PI]"@HN:'1M;&%R96$@+G1O;VQB
M87(@+G-E<&%R871O<B!["B`@<&]S:71I;VXZ(')E;&%T:79E.PH@(&UA<F=I
M;CH@,W!X.PH@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@0G5T=&]N4VAA9&]W
M.PH@(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED($)U='1O;DAI9VAL:6=H=#L*
M("!W:61T:#H@,'!X.PH@(&AE:6=H=#H@,39P>#L*("!P861D:6YG.B`P<'@[
M"GT*"BYH=&UL87)E82`N=&]O;&)A<B`N<W!A8V4@>R!W:61T:#H@-7!X.R!]
M"@HN:'1M;&%R96$@+G1O;VQB87(@<V5L96-T('L@9F]N=#H@,3%P>"!486AO
M;6$L5F5R9&%N82QS86YS+7-E<FEF.R!]"@HN:'1M;&%R96$@+G1O;VQB87(@
M<V5L96-T+`HN:'1M;&%R96$@+G1O;VQB87(@<V5L96-T.FAO=F5R+`HN:'1M
M;&%R96$@+G1O;VQB87(@<V5L96-T.F%C=&EV92![(&)A8VMG<F]U;F0Z($9I
M96QD1F%C93L@8V]L;W(Z($)U='1O;E1E>'0[('T*"BYH=&UL87)E82`N<W1A
M='5S0F%R('L*("!B;W)D97(Z(#%P>"!S;VQI9#L*("!B;W)D97(M8V]L;W(Z
M($)U='1O;E-H861O=R!"=71T;VY(:6=H;&EG:'0@0G5T=&]N2&EG:&QI9VAT
M($)U='1O;E-H861O=SL*("!P861D:6YG.B`R<'@@-'!X.PH@(&)A8VMG<F]U
M;F0M8V]L;W(Z($)U='1O;D9A8V4["B`@8V]L;W(Z($)U='1O;E1E>'0["B`@
M9F]N=#H@,3%P>"!486AO;6$L5F5R9&%N82QS86YS+7-E<FEF.PI]"@HN:'1M
M;&%R96$@+G-T871U<T)A<B`N<W1A='5S0F%R5')E92!A('L*("!P861D:6YG
M.B`R<'@@-7!X.PH@(&-O;&]R.B`C,#!F.PI]"@HN:'1M;&%R96$@+G-T871U
M<T)A<B`N<W1A='5S0F%R5')E92!A.G9I<VET960@>R!C;VQO<CH@(S`P9CL@
M?0HN:'1M;&%R96$@+G-T871U<T)A<B`N<W1A='5S0F%R5')E92!A.FAO=F5R
M('L*("!B86-K9W)O=6YD+6-O;&]R.B!(:6=H;&EG:'0["B`@8V]L;W(Z($AI
M9VAL:6=H=%1E>'0["B`@<&%D9&EN9SH@,7!X(#1P>#L*("!B;W)D97(Z(#%P
M>"!S;VQI9"!(:6=H;&EG:'1497AT.PI]"@H*+RH@2&ED9&5N($1)5B!P;W!U
M<"!D:6%L;V=S("A0;W!U<$1I=BD@*B\*"BYD:6%L;V<@>PH@(&-O;&]R.B!"
M=71T;VY497AT.PH@(&)A8VMG<F]U;F0Z($)U='1O;D9A8V4["GT*"BYD:6%L
M;V<@+F-O;G1E;G0@>R!P861D:6YG.B`R<'@[('T*"BYD:6%L;V<L("YD:6%L
M;V<@8G5T=&]N+"`N9&EA;&]G(&EN<'5T+"`N9&EA;&]G('-E;&5C="P@+F1I
M86QO9R!T97AT87)E82P@+F1I86QO9R!T86)L92!["B`@9F]N=#H@,3%P>"!4
M86AO;6$L5F5R9&%N82QS86YS+7-E<FEF.PI]"@HN9&EA;&]G('1A8FQE('L@
M8F]R9&5R+6-O;&QA<'-E.B!C;VQL87!S93L@?0H*+F1I86QO9R`N=&ET;&4@
M>PH@(&)A8VMG<F]U;F0Z(",P,#@["B`@8V]L;W(Z("-F9C@["B`@8F]R9&5R
M+6)O='1O;3H@,7!X('-O;&ED(",P,#`["B`@<&%D9&EN9SH@,7!X(#!P>"`R
M<'@@-7!X.PH@(&9O;G0M<VEZ93H@,3)P>#L*("!F;VYT+7=E:6=H=#H@8F]L
M9#L*("!C=7)S;W(Z(&1E9F%U;'0["GT*"BYD:6%L;V<@+G1I=&QE("YB=71T
M;VX@>PH@(&9L;V%T.B!R:6=H=#L*("!B;W)D97(Z(#%P>"!S;VQI9"`C-C9A
M.PH@('!A9&1I;F<Z(#!P>"`Q<'@@,'!X(#)P>#L*("!M87)G:6XM<FEG:'0Z
M(#%P>#L*("!C;VQO<CH@(V9F9CL*("!T97AT+6%L:6=N.B!C96YT97(["GT*
M"BYD:6%L;V<@+G1I=&QE("YB=71T;VXM:&EL:71E('L@8F]R9&5R+6-O;&]R
M.B`C.#AF.R!B86-K9W)O=6YD.B`C-#1C.R!]"@HN9&EA;&]G(&)U='1O;B![
M"B`@=VED=&@Z(#5E;3L*("!P861D:6YG.B`P<'@["GT*"BYD:6%L;V<@+F)U
M='1O;D-O;&]R('L*("!P861D:6YG.B`Q<'@["B`@8W5R<V]R.B!D969A=6QT
M.PH@(&)O<F1E<CH@,7!X('-O;&ED.PH@(&)O<F1E<BUC;VQO<CH@0G5T=&]N
M2&EG:&QI9VAT($)U='1O;E-H861O=R!"=71T;VY3:&%D;W<@0G5T=&]N2&EG
M:&QI9VAT.PI]"@HN9&EA;&]G("YB=71T;VY#;VQO<BUH:6QI=&4@>PH@(&)O
M<F1E<BUC;VQO<CH@(S`P,#L*?0H*+F1I86QO9R`N8G5T=&]N0V]L;W(@+F-H
M;V]S97(L("YD:6%L;V<@+F)U='1O;D-O;&]R("YN;V-O;&]R('L*("!H96EG
M:'0Z(#`N-F5M.PH@(&)O<F1E<CH@,7!X('-O;&ED.PH@('!A9&1I;F<Z(#!P
M>"`Q96T["B`@8F]R9&5R+6-O;&]R.B!"=71T;VY3:&%D;W<@0G5T=&]N2&EG
M:&QI9VAT($)U='1O;DAI9VAL:6=H="!"=71T;VY3:&%D;W<["GT*"BYD:6%L
M;V<@+F)U='1O;D-O;&]R("YN;V-O;&]R('L@<&%D9&EN9SH@,'!X.R!]"BYD
M:6%L;V<@+F)U='1O;D-O;&]R("YN;V-O;&]R+6AI;&ET92![(&)A8VMG<F]U
M;F0M8V]L;W(Z("-F9F8[(&-O;&]R.B`C9C`P.R!]"@HN9&EA;&]G("YL86)E
M;"![('1E>'0M86QI9VXZ(')I9VAT.R!W:61T:#H@-F5M.R!]"BYD:6%L;V<@
M+G9A;'5E(&EN<'5T('L@=VED=&@Z(#$P,"4[('T*+F1I86QO9R`N8G5T=&]N
M<R![('1E>'0M86QI9VXZ(')I9VAT.R!P861D:6YG.B`R<'@@-'!X(#!P>"`T
M<'@[('T*"BYD:6%L;V<@;&5G96YD('L@9F]N="UW96EG:'0Z(&)O;&0[('T*
M+F1I86QO9R!F:65L9'-E="!T86)L92![(&UA<F=I;CH@,G!X(#!P>#L@?0H*
M+G!O<'5P9&EV('L*("!B;W)D97(Z(#)P>"!S;VQI9#L*("!B;W)D97(M8V]L
M;W(Z($)U='1O;DAI9VAL:6=H="!"=71T;VY3:&%D;W<@0G5T=&]N4VAA9&]W
M($)U='1O;DAI9VAL:6=H=#L*?0H*+G!O<'5P=VEN('L*("!P861D:6YG.B`P
M<'@["B`@;6%R9VEN.B`P<'@["GT*"BYP;W!U<'=I;B`N=&ET;&4@>PH@(&)A
M8VMG<F]U;F0Z("-F9F8["B`@8V]L;W(Z(",P,#`["B`@9F]N="UW96EG:'0Z
M(&)O;&0["B`@9F]N="US:7IE.B`Q,C`E.PH@('!A9&1I;F<Z(#-P>"`Q,'!X
M.PH@(&UA<F=I;BUB;W1T;VTZ(#$P<'@["B`@8F]R9&5R+6)O='1O;3H@,7!X
M('-O;&ED(&)L86-K.PH@(&QE='1E<BUS<&%C:6YG.B`R<'@["GT*"F9O<FT@
M>R!M87)G:6XZ(#!P>#L@8F]R9&5R.B!N;VYE.R!]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]H=&UL
M87)E82YJ<P``````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`R,S<R,S(`,3`U,34T,S,W
M-3<`,#(T-S,T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"\O(&AT;6Q!<F5A('8S+C`@+2!#;W!Y<FEG:'0@*&,I(#(P,#,M
M,C`P-2!D>6YA<F-H+F-O;0HO+R`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`R,#`R+3(P,#,@:6YT97)A8W1I=F5T;V]L<RYC;VTL(&EN8RX*+R\@
M5&AI<R!C;W!Y<FEG:'0@;F]T:6-E($U54U0@<W1A>2!I;G1A8W0@9F]R('5S
M92`H<V5E(&QI8V5N<V4N='AT*2X*+R\*+R\@02!F<F5E(%=94TE764<@961I
M=&]R(')E<&QA8V5M96YT(&9O<B`\=&5X=&%R96$^(&9I96QD<RX*+R\@1F]R
M(&9U;&P@<V]U<F-E(&-O9&4@86YD(&1O8W,L('9I<VET(&AT='`Z+R]W=W<N
M:6YT97)A8W1I=F5T;V]L<RYC;VTO"B\O"B\O(%9E<G-I;VX@,RXP(&1E=F5L
M;W!E9"!B>2!-:6AA:2!"87IO;BX*+R\@("!H='1P.B\O9'EN87)C:"YC;VTO
M;6ES:&]O+PHO+PHO+R`D260Z(&AT;6QA<F5A+FIS+'8@,2XY-R`R,#`U+S`Q
M+S(Y(#`P.C0V.C4Q(&ET;V]L<R!%>'`@)`H*:68@*'1Y<&5O9B!?961I=&]R
M7W5R;"`]/2`B<W1R:6YG(BD@>PH)+R\@3&5A=F4@97AA8W1L>2!O;F4@8F%C
M:W-L87-H(&%T('1H92!E;F0@;V8@7V5D:71O<E]U<FP*"5]E9&ET;W)?=7)L
M(#T@7V5D:71O<E]U<FPN<F5P;&%C92@O7'@R9BHD+RP@)R\G*3L*?2!E;'-E
M('L*"6%L97)T*")705).24Y'.B!?961I=&]R7W5R;"!I<R!N;W0@<V5T(2`@
M66]U('-H;W5L9"!S970@=&AI<R!V87)I86)L92!T;R!T:&4@961I=&]R(&9I
M;&5S('!A=&@[(&ET('-H;W5L9"!P<F5F97)A8FQY(&)E(&%N(&%B<V]L=71E
M('!A=&@L(&QI:V4@:6X@)R]H=&UL87)E82\G+"!B=70@:70@8V%N(&)E(')E
M;&%T:79E(&EF('EO=2!P<F5F97(N("!&=7)T:&5R('=E('=I;&P@=')Y('1O
M(&QO860@=&AE(&5D:71O<B!F:6QE<R!C;W)R96-T;'D@8G5T('=E)VQL('!R
M;V)A8FQY(&9A:6PN(BD["@E?961I=&]R7W5R;"`]("<G.PI]"@HO+R!M86ME
M('-U<F4@=V4@:&%V92!A(&QA;F=U86=E"FEF("AT>7!E;V8@7V5D:71O<E]L
M86YG(#T](")S=')I;F<B*2!["@E?961I=&]R7VQA;F<@/2!?961I=&]R7VQA
M;F<N=&],;W=E<D-A<V4H*3L*?2!E;'-E('L*"5]E9&ET;W)?;&%N9R`](")E
M;B(["GT*"B\O(&)R;W=S97(@:61E;G1I9FEC871I;VX*2%1-3$%R96$N86=T
M(#T@;F%V:6=A=&]R+G5S97)!9V5N="YT;TQO=V5R0V%S92@I.PI(5$U,07)E
M82YI<U]I90D@("`]("@H2%1-3$%R96$N86=T+FEN9&5X3V8H(FUS:64B*2`A
M/2`M,2D@)B8@*$A434Q!<F5A+F%G="YI;F1E>$]F*")O<&5R82(I(#T]("TQ
M*2D["DA434Q!<F5A+FES7V]P97)A("`]("A(5$U,07)E82YA9W0N:6YD97A/
M9B@B;W!E<F$B*2`A/2`M,2D["DA434Q!<F5A+FES7VUA8PD@("`]("A(5$U,
M07)E82YA9W0N:6YD97A/9B@B;6%C(BD@(3T@+3$I.PI(5$U,07)E82YI<U]M
M86-?:64@/2`H2%1-3$%R96$N:7-?:64@)B8@2%1-3$%R96$N:7-?;6%C*3L*
M2%1-3$%R96$N:7-?=VEN7VEE(#T@*$A434Q!<F5A+FES7VEE("8F("%(5$U,
M07)E82YI<U]M86,I.PI(5$U,07)E82YI<U]G96-K;R`@/2`H;F%V:6=A=&]R
M+G!R;V1U8W0@/3T@(D=E8VMO(BD["@HO+R!#<F5A=&5S(&$@;F5W($A434Q!
M<F5A(&]B:F5C="X@(%1R:65S('1O(')E<&QA8V4@=&AE('1E>'1A<F5A('=I
M=&@@=&AE(&=I=F5N"B\O($E$('=I=&@@:70N"F9U;F-T:6]N($A434Q!<F5A
M*'1E>'1A<F5A+"!C;VYF:6<I('L*("`@("`@("!I9B`H(4A434Q!<F5A+E]I
M;FET7V-A;&QE9"D@>PH)(&%L97)T*")%<G)O<CH@66]U(&UU<W0@8V%L;&5D
M($A434Q!<F5A+FEN:70H*2!F:7)S="X@($QI:V4@=&AI<SI<;EQN(B`K"@D@
M("`@("`@(DA434Q!<F5A+FEN:70H*3M<;B(@*PH)("`@("`@(")(5$U,07)E
M82YO;FQO860@/2!F=6YC=&EO;B@I('M<;B(@*PH)("`@("`@("(@('9A<B!E
M9&ET;W(@/2!N97<@2%1-3$%R96$H)V5D:71O<B<I.UQN(B`K"@D@("`@("`@
M(B`@961I=&]R+F=E;F5R871E*"D[7&XB("L*"2`@("`@("`B?3M<;B(I.PH)
M("!R971U<FX["@E]"@H):68@*$A434Q!<F5A+F-H96-K4W5P<&]R=&5D0G)O
M=W-E<B@I*2!["@D):68@*'1Y<&5O9B!C;VYF:6<@/3T@(G5N9&5F:6YE9"(I
M('L*"0D)=&AI<RYC;VYF:6<@/2!N97<@2%1-3$%R96$N0V]N9FEG*"D["@D)
M?2!E;'-E('L*"0D)=&AI<RYC;VYF:6<@/2!C;VYF:6<["@D)?0H)"71H:7,N
M7VAT;6Q!<F5A(#T@;G5L;#L*"0ET:&ES+E]T97AT07)E82`]('1E>'1A<F5A
M.PH)"71H:7,N7V5D:71-;V1E(#T@(G=Y<VEW>6<B.PH)"71H:7,N<&QU9VEN
M<R`]('M].PH)"71H:7,N7W1I;65R5&]O;&)A<B`](&YU;&P["@D)=&AI<RY?
M=&EM97)5;F1O(#T@;G5L;#L*"0ET:&ES+E]U;F1O475E=64@/2!N97<@07)R
M87DH=&AI<RYC;VYF:6<N=6YD;U-T97!S*3L*"0ET:&ES+E]U;F1O4&]S(#T@
M+3$["@D)=&AI<RY?8W5S=&]M56YD;R`](&9A;'-E.PH)"71H:7,N7VUD;V,@
M/2!D;V-U;65N=#L@+R\@8V%C:&4@=&AE(&1O8W5M96YT+"!W92!N965D(&ET
M(&EN('!L=6=I;G,*"0ET:&ES+F1O8W1Y<&4@/2`G)SL*"7T*?3L*"DA434Q!
M<F5A+F]N;&]A9"`](&9U;F-T:6]N*"E[?3L*2%1-3$%R96$N7W-C<FEP=',@
M/2!;73L*2%1-3$%R96$N;&]A9%-C<FEP="`](&9U;F-T:6]N*'5R;"P@<&QU
M9VEN*2!["@EI9B`H<&QU9VEN*0H)"75R;"`]($A434Q!<F5A+F=E=%!L=6=I
M;D1I<BAP;'5G:6XI("L@)R\G("L@=7)L.PH)=&AI<RY?<V-R:7!T<RYP=7-H
M*'5R;"D["GT["@I(5$U,07)E82YI;FET(#T@9G5N8W1I;VXH*2!["@EV87(@
M:&5A9"`](&1O8W5M96YT+F=E=$5L96UE;G1S0GE486=.86UE*")H96%D(BE;
M,%T["@EV87(@8W5R<F5N="`](#`["@EV87(@<V%V971I=&QE(#T@9&]C=6UE
M;G0N=&ET;&4["@EV87(@979T(#T@2%1-3$%R96$N:7-?:64@/R`B;VYR96%D
M>7-T871E8VAA;F=E(B`Z(")O;FQO860B.PH)9G5N8W1I;VX@;&]A9$YE>'13
M8W)I<'0H*2!["@D):68@*&-U<G)E;G0@/B`P("8F($A434Q!<F5A+FES7VEE
M("8F"@D)("`@("$O;&]A9&5D?&-O;7!L971E+RYT97-T*'=I;F1O=RYE=F5N
M="YS<F-%;&5M96YT+G)E861Y4W1A=&4I*0H)"0ER971U<FX["@D):68@*&-U
M<G)E;G0@/"!(5$U,07)E82Y?<V-R:7!T<RYL96YG=&@I('L*"0D)=F%R('5R
M;"`]($A434Q!<F5A+E]S8W)I<'1S6V-U<G)E;G0K*UT["@D)"61O8W5M96YT
M+G1I=&QE(#T@(EM(5$U,07)E83H@;&]A9&EN9R!S8W)I<'0@(B`K(&-U<G)E
M;G0@*R`B+R(@*R!(5$U,07)E82Y?<V-R:7!T<RYL96YG=&@@*R`B72(["@D)
M"79A<B!S8W)I<'0@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*")S8W)I<'0B
M*3L*"0D)<V-R:7!T+G1Y<&4@/2`B=&5X="]J879A<V-R:7!T(CL*"0D)<V-R
M:7!T+G-R8R`]('5R;#L*"0D)<V-R:7!T6V5V=%T@/2!L;V%D3F5X=%-C<FEP
M=#L*"0D):&5A9"YA<'!E;F1#:&EL9"AS8W)I<'0I.PH)"7T@96QS92!["@D)
M"61O8W5M96YT+G1I=&QE(#T@<V%V971I=&QE.PH@("`@("`@("`@("`@("`@
M("`@("`@("!(5$U,07)E82Y?:6YI=%]C86QL960@/2`Q.PH)"0E(5$U,07)E
M82YO;FQO860H*3L*"0E]"@E].PH);&]A9$YE>'138W)I<'0H*3L*"GT["@I(
M5$U,07)E82YL;V%D4V-R:7!T*%]E9&ET;W)?=7)L("L@(F1I86QO9RYJ<R(I
M.PI(5$U,07)E82YL;V%D4V-R:7!T*%]E9&ET;W)?=7)L("L@(G!O<'5P=VEN
M+FIS(BD["DA434Q!<F5A+FQO86138W)I<'0H7V5D:71O<E]U<FP@*R`B;&%N
M9R\B("L@7V5D:71O<E]L86YG("L@(BYJ<R(I.PH*+R\@8V%C:&4@<V]M92!R
M96=E>'!S"DA434Q!<F5A+E)%7W1A9TYA;64@/2`O*#Q<+WP\*5QS*BA;7B!<
M=%QN/ETK*2]I9SL*2%1-3$%R96$N4D5?9&]C='EP92`]("\H/"%D;V-T>7!E
M*"@N?%QN*2H_*3XI7&X_+VD["DA434Q!<F5A+E)%7VAE860@("`@/2`O/&AE
M860^*"@N?%QN*2H_*3Q<+VAE860^+VD["DA434Q!<F5A+E)%7V)O9'D@("`@
M/2`O/&)O9'D^*"@N?%QN*2H_*3Q<+V)O9'D^+VD["@I(5$U,07)E82Y#;VYF
M:6<@/2!F=6YC=&EO;B`H*2!["@ET:&ES+G9E<G-I;VX@/2`B,RXP(CL*"@ET
M:&ES+G=I9'1H(#T@(F%U=&\B.PH)=&AI<RYH96EG:'0@/2`B875T;R(["@H)
M+R\@96YA8FQE(&-R96%T:6]N(&]F(&$@<W1A='5S(&)A<C\*"71H:7,N<W1A
M='5S0F%R(#T@=')U93L*"@DO+R!I;G1E<F-E<'0@7E8@86YD('5S92!T:&4@
M2%1-3$%R96$@<&%S=&4@8V]M;6%N9`H)+R\@268@9F%L<V4L('1H96X@<&%S
M<V5S(%Y6('1H<F]U9V@@=&\@8G)O=W-E<B!E9&ET;W(@=VED9V5T"@ET:&ES
M+FAT;6QA<F5A4&%S=&4@/2!F86QS93L*"@DO+R!M87AI;75M('-I>F4@;V8@
M=&AE('5N9&\@<75E=64*"71H:7,N=6YD;U-T97!S(#T@,C`["@H)+R\@=&AE
M('1I;64@:6YT97)V86P@870@=VAI8V@@=6YD;R!S86UP;&5S(&%R92!T86ME
M;@H)=&AI<RYU;F1O5&EM96]U="`](#4P,#L)+R\@,2\R('-E8RX*"@DO+R!T
M:&4@;F5X="!P87)A;65T97(@<W!E8VEF:65S('=H971H97(@=&AE('1O;VQB
M87(@<VAO=6QD(&)E(&EN8VQU9&5D"@DO+R!I;B!T:&4@<VEZ92!O<B!N;W0N
M"@ET:&ES+G-I>F5);F-L=61E<U1O;VQB87(@/2!T<G5E.PH*"2\O(&EF('1R
M=64@=&AE;B!(5$U,07)E82!W:6QL(')E=')I979E('1H92!F=6QL($A434PL
M('-T87)T:6YG('=I=&@@=&AE"@DO+R`\2%1-3#X@=&%G+@H)=&AI<RYF=6QL
M4&%G92`](&9A;'-E.PH*"2\O('-T>6QE(&EN8VQU9&5D(&EN('1H92!I9G)A
M;64@9&]C=6UE;G0*"71H:7,N<&%G95-T>6QE(#T@(B(["@H)+R\@<V5T('1O
M('1R=64@:68@>6]U('=A;G0@5V]R9"!C;V1E('1O(&)E(&-L96%N960@=7!O
M;B!087-T90H)=&AI<RYK:6QL5V]R9$]N4&%S=&4@/2!T<G5E.PH*"2\O(&5N
M86)L92!T:&4@)U1A<F=E="<@9FEE;&0@:6X@=&AE($UA:V4@3&EN:R!D:6%L
M;V<*"71H:7,N;6%K94QI;FM3:&]W<U1A<F=E="`]('1R=64["@H)+R\@0F%S
M95523"!I;F-L=61E9"!I;B!T:&4@:69R86UE(&1O8W5M96YT"@ET:&ES+F)A
M<V554DP@/2!D;V-U;65N="YB87-E55))('Q\(&1O8W5M96YT+E523#L*"6EF
M("AT:&ES+F)A<V554DP@)B8@=&AI<RYB87-E55),+FUA=&-H*"\H+BHI7"\H
M6UY<+UTK*2\I*0H)"71H:7,N8F%S95523"`](%)E9T5X<"XD,2`K("(O(CL*
M"@DO+R!54DPM<PH)=&AI<RYI;6=54DP@/2`B:6UA9V5S+R(["@ET:&ES+G!O
M<'5P55),(#T@(G!O<'5P<R\B.PH*"2\O(')E;6]V92!T86=S("AT:&5S92!H
M879E('1O(&)E(&$@<F5G97AP+"!O<B!N=6QL(&EF('1H:7,@9G5N8W1I;VYA
M;&ET>2!I<R!N;W0@9&5S:7)E9"D*"71H:7,N:'1M;%)E;6]V951A9W,@/2!N
M=6QL.PH*"2\J*B!#55-43TU)6DE.1R!42$4@5$]/3$)!4@H)("H@+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+0H)("H*"2`J($ET(&ES(')E8V]M;65N9&5D
M('1H870@>6]U(&-U<W1O;6EZ92!T:&4@=&]O;&)A<B!C;VYT96YT<R!I;B!A
M;@H)("H@97AT97)N86P@9FEL92`H:2YE+B!T:&4@;VYE(&-A;&QI;F<@2%1-
M3$%R96$I(&%N9"!L96%V92!T:&ES(&]N90H)("H@=6YC:&%N9V5D+B`@5&AA
M="=S(&)E8V%U<V4@=VAE;B!W92`H26YT97)A8W1I=F54;V]L<RYC;VTI(')E
M;&5A<V4@80H)("H@;F5W(&]F9FEC:6%L('9E<G-I;VXL(&ET)W,@;&5S<R!L
M:6ME;'D@=&AA="!Y;W4@=VEL;"!H879E('!R;V)L96US"@D@*B!U<&=R861I
M;F<@2%1-3$%R96$N"@D@*B\*"71H:7,N=&]O;&)A<B`](%L*"0E;(")F;VYT
M;F%M92(L(")S<&%C92(L"@D)("`B9F]N='-I>F4B+"`B<W!A8V4B+`H)"2`@
M(F9O<FUA=&)L;V-K(BP@(G-P86-E(BP*"0D@(")B;VQD(BP@(FET86QI8R(L
M(")U;F1E<FQI;F4B+"`B<W1R:6ME=&AR;W5G:"(L(")S97!A<F%T;W(B+`H)
M"2`@(G-U8G-C<FEP="(L(")S=7!E<G-C<FEP="(L(")S97!A<F%T;W(B+`H)
M"2`@(F-O<'DB+"`B8W5T(BP@(G!A<W1E(BP@(G-P86-E(BP@(G5N9&\B+"`B
M<F5D;R(L(")S<&%C92(L(")R96UO=F5F;W)M870B+"`B:VEL;'=O<F0B(%TL
M"@H)"5L@(FIU<W1I9GEL969T(BP@(FIU<W1I9GEC96YT97(B+"`B:G5S=&EF
M>7)I9VAT(BP@(FIU<W1I9GEF=6QL(BP@(G-E<&%R871O<B(L"@D)("`B;&5F
M='1O<FEG:'0B+"`B<FEG:'1T;VQE9G0B+"`B<V5P87)A=&]R(BP*"0D@(")O
M<F1E<F5D;&ES="(L(")U;F]R9&5R961L:7-T(BP@(F]U=&1E;G0B+"`B:6YD
M96YT(BP@(G-E<&%R871O<B(L"@D)("`B9F]R96-O;&]R(BP@(FAI;&ET96-O
M;&]R(BP@(G-E<&%R871O<B(L"@D)("`B:6YS97)T:&]R:7IO;G1A;')U;&4B
M+"`B8W)E871E;&EN:R(L(")I;G-E<G1I;6%G92(L(")I;G-E<G1T86)L92(L
M(")H=&UL;6]D92(L(")S97!A<F%T;W(B+`H)"2`@(G!O<'5P961I=&]R(BP@
M(G-E<&%R871O<B(L(")S:&]W:&5L<"(L(")A8F]U="(@70H)73L*"@ET:&ES
M+F9O;G1N86UE(#T@>PH)"2(F;61A<V@[(&9O;G0@)FUD87-H.R(Z("`@("`@
M("`@)R<L"@D)(D%R:6%L(CH)("`@)V%R:6%L+&AE;'9E=&EC82QS86YS+7-E
M<FEF)RP*"0DB0V]U<FEE<B!.97<B.@D@("`G8V]U<FEE<B!N97<L8V]U<FEE
M<BQM;VYO<W!A8V4G+`H)"2)'96]R9VEA(CH)("`@)V=E;W)G:6$L=&EM97,@
M;F5W(')O;6%N+'1I;65S+'-E<FEF)RP*"0DB5&%H;VUA(CH)("`@)W1A:&]M
M82QA<FEA;"QH96QV971I8V$L<V%N<RUS97)I9B<L"@D)(E1I;65S($YE=R!2
M;VUA;B(Z("=T:6UE<R!N97<@<F]M86XL=&EM97,L<V5R:68G+`H)"2)697)D
M86YA(CH)("`@)W9E<F1A;F$L87)I86PL:&5L=F5T:6-A+'-A;G,M<V5R:68G
M+`H)"2)I;7!A8W0B.@D@("`G:6UP86-T)RP*"0DB5VEN9T1I;F=S(CH)("`@
M)W=I;F=D:6YG<R<*"7T["@H)=&AI<RYF;VYT<VEZ92`]('L*"0DB)FUD87-H
M.R!S:7IE("9M9&%S:#LB("`Z("(B+`H)"2(Q("@X('!T*2(@.B`B,2(L"@D)
M(C(@*#$P('!T*2(Z("(R(BP*"0DB,R`H,3(@<'0I(CH@(C,B+`H)"2(T("@Q
M-"!P="DB.B`B-"(L"@D)(C4@*#$X('!T*2(Z("(U(BP*"0DB-B`H,C0@<'0I
M(CH@(C8B+`H)"2(W("@S-B!P="DB.B`B-R(*"7T["@H)=&AI<RYF;W)M871B
M;&]C:R`]('L*"0DB)FUD87-H.R!F;W)M870@)FUD87-H.R(@(#H@(B(L"@D)
M(DAE861I;F<@,2(Z(")H,2(L"@D)(DAE861I;F<@,B(Z(")H,B(L"@D)(DAE
M861I;F<@,R(Z(")H,R(L"@D)(DAE861I;F<@-"(Z(")H-"(L"@D)(DAE861I
M;F<@-2(Z(")H-2(L"@D)(DAE861I;F<@-B(Z(")H-B(L"@D)(DYO<FUA;"(@
M("`Z(")P(BP*"0DB061D<F5S<R(@(#H@(F%D9')E<W,B+`H)"2)&;W)M871T
M960B.B`B<')E(@H)?3L*"@ET:&ES+F-U<W1O;5-E;&5C=',@/2![?3L*"@EF
M=6YC=&EO;B!C=71?8V]P>5]P87-T92AE+"!C;60L(&]B:BD@>PH)"64N97AE
M8T-O;6UA;F0H8VUD*3L*"7T["@H)=&AI<RYD96)U9R`]('1R=64["@H)+R\@
M041$24Y'($-54U1/32!"55143TY3.B!P;&5A<V4@<F5A9"!B96QO=R$*"2\O
M(&9O<FUA="!O9B!T:&4@8G1N3&ES="!E;&5M96YT<R!I<R`B240Z(%L@5&]O
M;%1I<"P@26-O;BP@16YA8FQE9"!I;B!T97AT(&UO9&4_+"!!0U1)3TX@72(*
M"2\O("`@("T@240Z('5N:7%U92!)1"!F;W(@=&AE(&)U='1O;BX@($EF('1H
M92!B=71T;VX@8V%L;',@9&]C=6UE;G0N97AE8T-O;6UA;F0*"2\O"2`@("!I
M="=S('=I<V4@=&\@9VEV92!I="!T:&4@<V%M92!N86UE(&%S('1H92!C86QL
M960@8V]M;6%N9"X*"2\O("`@("T@04-424]..B!F=6YC=&EO;B!T:&%T(&=E
M=',@8V%L;&5D('=H96X@=&AE(&)U='1O;B!I<R!C;&EC:V5D+@H)+R\@("`@
M("`@("`@("`@(&ET(&AA<R!T:&4@9F]L;&]W:6YG('!R;W1O='EP93H*"2\O
M("`@("`@("`@("`@("`@("!F=6YC=&EO;BAE9&ET;W(L(&)U='1O;DYA;64I
M"@DO+R`@("`@("`@("`@("`@+2!E9&ET;W(@:7,@=&AE($A434Q!<F5A(&]B
M:F5C="!T:&%T('1R:6=G97)E9"!T:&4@8V%L;`H)+R\@("`@("`@("`@("`@
M("T@8G5T=&]N3F%M92!I<R!T:&4@240@;V8@=&AE(&-L:6-K960@8G5T=&]N
M"@DO+R`@("`@("`@("`@("`@5&AE<V4@,B!P87)A;65T97)S(&UA:V5S(&ET
M('!O<W-I8FQE(&9O<B!Y;W4@=&\@=7-E('1H92!S86UE"@DO+R`@("`@("`@
M("`@("`@:&%N9&QE<B!F;W(@;6]R92!(5$U,07)E82!O8FIE8W1S(&]R(&9O
M<B!M;W)E(&1I9F9E<F5N="!B=71T;VYS+@H)+R\@("`@+2!4;V]L5&EP.B!D
M969A=6QT('1O;VQT:7`L(&9O<B!C87-E<R!W:&5N(&ET(&ES(&YO="!D969I
M;F5D(&EN('1H92`M;&%N9RT@9FEL92`H2%1-3$%R96$N23$X3BD*"2\O("`@
M("T@26-O;CH@<&%T:"!T;R!A;B!I8V]N(&EM86=E(&9I;&4@9F]R('1H92!B
M=71T;VX@*%1/1$\Z('5S92!O;F4@:6UA9V4@9F]R(&%L;"!B=71T;VYS(2D*
M"2\O("`@("T@16YA8FQE9"!I;B!T97AT(&UO9&4Z(&EF(&9A;'-E('1H92!B
M=71T;VX@9V5T<R!D:7-A8FQE9"!F;W(@=&5X="UO;FQY(&UO9&4[(&]T:&5R
M=VES92!E;F%B;&5D(&%L;"!T:&4@=&EM92X*"71H:7,N8G1N3&ES="`]('L*
M"0EB;VQD.B!;(")";VQD(BP@(F5D7V9O<FUA=%]B;VQD+F=I9B(L(&9A;'-E
M+"!F=6YC=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B8F]L9"(I.WT@72P*"0EI
M=&%L:6,Z(%L@(DET86QI8R(L(")E9%]F;W)M871?:71A;&EC+F=I9B(L(&9A
M;'-E+"!F=6YC=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B:71A;&EC(BD[?2!=
M+`H)"75N9&5R;&EN93H@6R`B56YD97)L:6YE(BP@(F5D7V9O<FUA=%]U;F1E
M<FQI;F4N9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD
M*")U;F1E<FQI;F4B*3M](%TL"@D)<W1R:6ME=&AR;W5G:#H@6R`B4W1R:6ME
M=&AR;W5G:"(L(")E9%]F;W)M871?<W1R:6ME+F=I9B(L(&9A;'-E+"!F=6YC
M=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B<W1R:6ME=&AR;W5G:"(I.WT@72P*
M"0ES=6)S8W)I<'0Z(%L@(E-U8G-C<FEP="(L(")E9%]F;W)M871?<W5B+F=I
M9B(L(&9A;'-E+"!F=6YC=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B<W5B<V-R
M:7!T(BD[?2!=+`H)"7-U<&5R<V-R:7!T.B!;(")3=7!E<G-C<FEP="(L(")E
M9%]F;W)M871?<W5P+F=I9B(L(&9A;'-E+"!F=6YC=&EO;BAE*2![92YE>&5C
M0V]M;6%N9"@B<W5P97)S8W)I<'0B*3M](%TL"@D):G5S=&EF>6QE9G0Z(%L@
M(DIU<W1I9GD@3&5F="(L(")E9%]A;&EG;E]L969T+F=I9B(L(&9A;'-E+"!F
M=6YC=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B:G5S=&EF>6QE9G0B*3M](%TL
M"@D):G5S=&EF>6-E;G1E<CH@6R`B2G5S=&EF>2!#96YT97(B+"`B961?86QI
M9VY?8V5N=&5R+F=I9B(L(&9A;'-E+"!F=6YC=&EO;BAE*2![92YE>&5C0V]M
M;6%N9"@B:G5S=&EF>6-E;G1E<B(I.WT@72P*"0EJ=7-T:69Y<FEG:'0Z(%L@
M(DIU<W1I9GD@4FEG:'0B+"`B961?86QI9VY?<FEG:'0N9VEF(BP@9F%L<V4L
M(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")J=7-T:69Y<FEG:'0B*3M]
M(%TL"@D):G5S=&EF>69U;&PZ(%L@(DIU<W1I9GD@1G5L;"(L(")E9%]A;&EG
M;E]J=7-T:69Y+F=I9B(L(&9A;'-E+"!F=6YC=&EO;BAE*2![92YE>&5C0V]M
M;6%N9"@B:G5S=&EF>69U;&PB*3M](%TL"@D);W)D97)E9&QI<W0Z(%L@(D]R
M9&5R960@3&ES="(L(")E9%]L:7-T7VYU;2YG:68B+"!F86QS92P@9G5N8W1I
M;VXH92D@>V4N97AE8T-O;6UA;F0H(FEN<V5R=&]R9&5R961L:7-T(BD[?2!=
M+`H)"75N;W)D97)E9&QI<W0Z(%L@(D)U;&QE=&5D($QI<W0B+"`B961?;&ES
M=%]B=6QL970N9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM
M86YD*")I;G-E<G1U;F]R9&5R961L:7-T(BD[?2!=+`H)"6]U=&1E;G0Z(%L@
M(D1E8W)E87-E($EN9&5N="(L(")E9%]I;F1E;G1?;&5S<RYG:68B+"!F86QS
M92P@9G5N8W1I;VXH92D@>V4N97AE8T-O;6UA;F0H(F]U=&1E;G0B*3M](%TL
M"@D):6YD96YT.B!;("));F-R96%S92!);F1E;G0B+"`B961?:6YD96YT7VUO
M<F4N9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")I
M;F1E;G0B*3M](%TL"@D)9F]R96-O;&]R.B!;(")&;VYT($-O;&]R(BP@(F5D
M7V-O;&]R7V9G+F=I9B(L(&9A;'-E+"!F=6YC=&EO;BAE*2![92YE>&5C0V]M
M;6%N9"@B9F]R96-O;&]R(BD[?2!=+`H)"6AI;&ET96-O;&]R.B!;(")"86-K
M9W)O=6YD($-O;&]R(BP@(F5D7V-O;&]R7V)G+F=I9B(L(&9A;'-E+"!F=6YC
M=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B:&EL:71E8V]L;W(B*3M](%TL"@D)
M:6YS97)T:&]R:7IO;G1A;')U;&4Z(%L@(DAO<FEZ;VYT86P@4G5L92(L(")E
M9%]H<BYG:68B+"!F86QS92P@9G5N8W1I;VXH92D@>V4N97AE8T-O;6UA;F0H
M(FEN<V5R=&AO<FEZ;VYT86QR=6QE(BD[?2!=+`H)"6-R96%T96QI;FLZ(%L@
M(DEN<V5R="!796(@3&EN:R(L(")E9%]L:6YK+F=I9B(L(&9A;'-E+"!F=6YC
M=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B8W)E871E;&EN:R(L('1R=64I.WT@
M72P*"0EI;G-E<G1I;6%G93H@6R`B26YS97)T+TUO9&EF>2!);6%G92(L(")E
M9%]I;6%G92YG:68B+"!F86QS92P@9G5N8W1I;VXH92D@>V4N97AE8T-O;6UA
M;F0H(FEN<V5R=&EM86=E(BD[?2!=+`H)"6EN<V5R='1A8FQE.B!;("));G-E
M<G0@5&%B;&4B+"`B:6YS97)T7W1A8FQE+F=I9B(L(&9A;'-E+"!F=6YC=&EO
M;BAE*2![92YE>&5C0V]M;6%N9"@B:6YS97)T=&%B;&4B*3M](%TL"@D):'1M
M;&UO9&4Z(%L@(E1O9V=L92!(5$U,(%-O=7)C92(L(")E9%]H=&UL+F=I9B(L
M('1R=64L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")H=&UL;6]D92(I
M.WT@72P*"0EP;W!U<&5D:71O<CH@6R`B16YL87)G92!%9&ET;W(B+"`B9G5L
M;'-C<F5E;E]M87AI;6EZ92YG:68B+"!T<G5E+"!F=6YC=&EO;BAE*2![92YE
M>&5C0V]M;6%N9"@B<&]P=7!E9&ET;W(B*3M](%TL"@D)86)O=70Z(%L@(D%B
M;W5T('1H:7,@961I=&]R(BP@(F5D7V%B;W5T+F=I9B(L('1R=64L(&9U;F-T
M:6]N*&4I('ME+F5X96-#;VUM86YD*")A8F]U="(I.WT@72P*"0ES:&]W:&5L
M<#H@6R`B2&5L<"!U<VEN9R!E9&ET;W(B+"`B961?:&5L<"YG:68B+"!T<G5E
M+"!F=6YC=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B<VAO=VAE;'`B*3M](%TL
M"@D)=6YD;SH@6R`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB+"`B961?=6YD
M;RYG:68B+"!F86QS92P@9G5N8W1I;VXH92D@>V4N97AE8T-O;6UA;F0H(G5N
M9&\B*3M](%TL"@D)<F5D;SH@6R`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB
M+"`B961?<F5D;RYG:68B+"!F86QS92P@9G5N8W1I;VXH92D@>V4N97AE8T-O
M;6UA;F0H(G)E9&\B*3M](%TL"@D)8W5T.B!;(")#=70@<V5L96-T:6]N(BP@
M(F5D7V-U="YG:68B+"!F86QS92P@8W5T7V-O<'E?<&%S=&4@72P*"0EC;W!Y
M.B!;(")#;W!Y('-E;&5C=&EO;B(L(")E9%]C;W!Y+F=I9B(L(&9A;'-E+"!C
M=71?8V]P>5]P87-T92!=+`H)"7!A<W1E.B!;(")087-T92!F<F]M(&-L:7!B
M;V%R9"(L(")E9%]P87-T92YG:68B+"!F86QS92P@8W5T7V-O<'E?<&%S=&4@
M72P*"0EL969T=&]R:6=H=#H@6R`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B
M+"`B961?;&5F=%]T;U]R:6=H="YG:68B+"!F86QS92P@9G5N8W1I;VXH92D@
M>V4N97AE8T-O;6UA;F0H(FQE9G1T;W)I9VAT(BD[?2!=+`H)"7)I9VAT=&]L
M969T.B!;(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(L(")E9%]R:6=H=%]T
M;U]L969T+F=I9B(L(&9A;'-E+"!F=6YC=&EO;BAE*2![92YE>&5C0V]M;6%N
M9"@B<FEG:'1T;VQE9G0B*3M](%TL"@D)<F5M;W9E9F]R;6%T.B!;(")296UO
M=F4@9F]R;6%T=&EN9R(L(")E9%]R;69O<FUA="YG:68B+"!F86QS92P@9G5N
M8W1I;VXH92D@>V4N97AE8T-O;6UA;F0H(G)E;6]V969O<FUA="(I.WT@72P*
M"0EP<FEN=#H@6R`B4')I;G0@9&]C=6UE;G0B+"`B961?<')I;G0N9VEF(BP@
M9F%L<V4L(&9U;F-T:6]N*&4I('ME+E]I9G)A;64N8V]N=&5N=%=I;F1O=RYP
M<FEN="@I.WT@72P*"0EK:6QL=V]R9#H@6R`B0VQE87(@35-/9F9I8V4@=&%G
M<R(L(")E9%]K:6QL=V]R9"YG:68B+"!F86QS92P@9G5N8W1I;VXH92D@>V4N
M97AE8T-O;6UA;F0H(FMI;&QW;W)D(BD[?2!="@E].PH)+RH@041$24Y'($-5
M4U1/32!"55143TY3"@D@*B`M+2TM+2TM+2TM+2TM+2TM+2TM+2T*"2`J"@D@
M*B!)="!I<R!R96-O;6UE;F1E9"!T:&%T('EO=2!A9&0@=&AE(&-U<W1O;2!B
M=71T;VYS(&EN(&%N(&5X=&5R;F%L"@D@*B!F:6QE(&%N9"!L96%V92!T:&ES
M(&]N92!U;F-H86YG960N("!4:&%T)W,@8F5C875S92!W:&5N('=E"@D@*B`H
M26YT97)A8W1I=F54;V]L<RYC;VTI(')E;&5A<V4@82!N97<@;V9F:6-I86P@
M=F5R<VEO;BP@:70G<R!L97-S"@D@*B!L:6ME;'D@=&AA="!Y;W4@=VEL;"!H
M879E('!R;V)L96US('5P9W)A9&EN9R!(5$U,07)E82X*"2`J"@D@*B!%>&%M
M<&QE(&]N(&AO=R!T;R!A9&0@82!C=7-T;VT@8G5T=&]N('=H96X@>6]U(&-O
M;G-T<G5C="!T:&4@2%1-3$%R96$Z"@D@*@H)("H@("!V87(@961I=&]R(#T@
M;F5W($A434Q!<F5A*")Y;W5R7W1E>'1?87)E85]I9"(I.PH)("H@("!V87(@
M8V9G(#T@961I=&]R+F-O;F9I9SL@+R\@=&AI<R!I<R!T:&4@9&5F875L="!C
M;VYF:6=U<F%T:6]N"@D@*B`@(&-F9RYB=&Y,:7-T6R)M>2UH:6QI=&4B72`]
M"@D@*@E;(&9U;F-T:6]N*&5D:71O<BD@>R!E9&ET;W(N<W5R<F]U;F1(5$U,
M*"<\<W!A;B!S='EL93TB8F%C:V=R;W5N9#IY96QL;W<B/B<L("<\+W-P86X^
M)RD[('TL("\O(&%C=&EO;@H)("H)("`B2&EG:&QI9VAT('-E;&5C=&EO;B(L
M("\O('1O;VQT:7`*"2`J"2`@(FUY7VAI;&ET92YG:68B+"`O+R!I;6%G90H)
M("H)("!F86QS92`O+R!D:7-A8FQE9"!I;B!T97AT(&UO9&4*"2`J"5T["@D@
M*B`@(&-F9RYT;V]L8F%R+G!U<V@H6R)L:6YE8G)E86LB+"`B;7DM:&EL:71E
M(ETI.R`O+R!A9&0@=&AE(&YE=R!B=71T;VX@=&\@=&AE('1O;VQB87(*"2`J
M"@D@*B!!;B!A;'1E<FYA=&4@*&%L<V\@;6]R92!C;VYV96YI96YT(&%N9"!R
M96-O;6UE;F1E9"D@=V%Y('1O"@D@*B!A8V-O;7!L:7-H('1H:7,@:7,@=&\@
M=7-E('1H92!R96=I<W1E<D)U='1O;B!F=6YC=&EO;B!B96QO=RX*"2`J+PH)
M+R\@:6YI=&EA;&EZ92!T;V]L=&EP<R!F<F]M('1H92!),3A.(&UO9'5L92!A
M;F0@9V5N97)A=&4@8V]R<F5C="!I;6%G92!P871H"@EF;W(@*'9A<B!I(&EN
M('1H:7,N8G1N3&ES="D@>PH)"79A<B!B=&X@/2!T:&ES+F)T;DQI<W1;:5T[
M"@D)8G1N6S%=(#T@7V5D:71O<E]U<FP@*R!T:&ES+FEM9U523"`K(&)T;ELQ
M73L*"0EI9B`H='EP96]F($A434Q!<F5A+DDQ.$XN=&]O;'1I<'-;:5T@(3T@
M(G5N9&5F:6YE9"(I('L*"0D)8G1N6S!=(#T@2%1-3$%R96$N23$X3BYT;V]L
M=&EP<UMI73L*"0E]"@E]"GT["@HO*BH@2&5L<&5R(&9U;F-T:6]N.B!R96=I
M<W1E<B!A(&YE=R!B=71T;VX@=VET:"!T:&4@8V]N9FEG=7)A=&EO;BX@($ET
M(&-A;B!B90H@*B!C86QL960@=VET:"!A;&P@-2!A<F=U;65N=',L(&]R('=I
M=&@@;VYL>2!O;F4@*&9I<G-T(&]N92DN("!7:&5N(&-A;&QE9"!W:71H"B`J
M(&]N;'D@;VYE(&%R9W5M96YT(&ET(&UU<W0@8F4@86X@;V)J96-T('=I=&@@
M=&AE(&9O;&QO=VEN9R!P<F]P97)T:65S.B!I9"P*("H@=&]O;'1I<"P@:6UA
M9V4L('1E>'1-;V1E+"!A8W1I;VXN("!%>&%M<&QE<SH*("H*("H@,2X@8V]N
M9FEG+G)E9VES=&5R0G5T=&]N*")M>2UH:6QI=&4B+"`B2&EL:71E('1E>'0B
M+"`B;7DM:&EL:71E+F=I9B(L(&9A;'-E+"!F=6YC=&EO;BAE9&ET;W(I('LN
M+BY]*3L*("H@,BX@8V]N9FEG+G)E9VES=&5R0G5T=&]N*'L*("H@("`@("!I
M9"`@("`@("`Z(")M>2UH:6QI=&4B+"`@("`@("\O('1H92!)1"!O9B!Y;W5R
M(&)U='1O;@H@*B`@("`@('1O;VQT:7`@(#H@(DAI;&ET92!T97AT(BP@("`@
M+R\@=&AE('1O;VQT:7`*("H@("`@("!I;6%G92`@("`Z(")M>2UH:6QI=&4N
M9VEF(BP@("\O(&EM86=E('1O(&)E(&1I<W!L87EE9"!I;B!T:&4@=&]O;&)A
M<@H@*B`@("`@('1E>'1-;V1E(#H@9F%L<V4L("`@("`@("`@("`@+R\@9&ES
M86)L960@:6X@=&5X="!M;V1E"B`J("`@("`@86-T:6]N("`@.B!F=6YC=&EO
M;BAE9&ET;W(I('L@+R\@8V%L;&5D('=H96X@=&AE(&)U='1O;B!I<R!C;&EC
M:V5D"B`J("`@("`@("`@("`@("`@("`@(&5D:71O<BYS=7)R;W5N9$A434PH
M)SQS<&%N(&-L87-S/2)H:6QI=&4B/B<L("<\+W-P86X^)RD["B`J("`@("`@
M("`@("`@("`@("!]+`H@*B`@("`@(&-O;G1E>'0@(#H@(G`B("`@("`@("`@
M("`@("`@+R\@=VEL;"!B92!D:7-A8FQE9"!I9B!O=71S:61E(&$@/'`^(&5L
M96UE;G0*("H@("`@?2D["B`J+PI(5$U,07)E82Y#;VYF:6<N<')O=&]T>7!E
M+G)E9VES=&5R0G5T=&]N(#T@9G5N8W1I;VXH:60L('1O;VQT:7`L(&EM86=E
M+"!T97AT36]D92P@86-T:6]N+"!C;VYT97AT*2!["@EV87(@=&AE7VED.PH)
M:68@*'1Y<&5O9B!I9"`]/2`B<W1R:6YG(BD@>PH)"71H95]I9"`](&ED.PH)
M?2!E;'-E(&EF("AT>7!E;V8@:60@/3T@(F]B:F5C="(I('L*"0ET:&5?:60@
M/2!I9"YI9#L*"7T@96QS92!["@D)86QE<G0H(D524D]2(%M(5$U,07)E82Y#
M;VYF:6<Z.G)E9VES=&5R0G5T=&]N73I<;FEN=F%L:60@87)G=6UE;G1S(BD[
M"@D)<F5T=7)N(&9A;'-E.PH)?0H)+R\@8VAE8VL@9F]R(&5X:7-T:6YG(&ED
M"@EI9B`H='EP96]F('1H:7,N8W5S=&]M4V5L96-T<UMT:&5?:61=("$](")U
M;F1E9FEN960B*2!["@D)+R\@86QE<G0H(E=!4DY)3D<@6TA434Q!<F5A+D-O
M;F9I9SHZ<F5G:7-T97)$<F]P9&]W;ETZ7&Y!(&1R;W!D;W=N('=I=&@@=&AE
M('-A;64@240@86QR96%D>2!E>&ES=',N(BD["@E]"@EI9B`H='EP96]F('1H
M:7,N8G1N3&ES=%MT:&5?:61=("$](")U;F1E9FEN960B*2!["@D)+R\@86QE
M<G0H(E=!4DY)3D<@6TA434Q!<F5A+D-O;F9I9SHZ<F5G:7-T97)$<F]P9&]W
M;ETZ7&Y!(&)U='1O;B!W:71H('1H92!S86UE($E$(&%L<F5A9'D@97AI<W1S
M+B(I.PH)?0H)<W=I=&-H("AT>7!E;V8@:60I('L*"2`@("!C87-E(")S=')I
M;F<B.B!T:&ES+F)T;DQI<W1;:61=(#T@6R!T;V]L=&EP+"!I;6%G92P@=&5X
M=$UO9&4L(&%C=&EO;BP@8V]N=&5X="!=.R!B<F5A:SL*"2`@("!C87-E(")O
M8FIE8W0B.B!T:&ES+F)T;DQI<W1;:60N:61=(#T@6R!I9"YT;V]L=&EP+"!I
M9"YI;6%G92P@:60N=&5X=$UO9&4L(&ED+F%C=&EO;BP@:60N8V]N=&5X="!=
M.R!B<F5A:SL*"7T*?3L*"B\J*B!4:&4@9F]L;&]W:6YG(&AE;'!E<B!F=6YC
M=&EO;B!R96=I<W1E<G,@82!D<F]P9&]W;B!B;W@@=VET:"!T:&4@961I=&]R
M"B`J(&-O;F9I9W5R871I;VXN("!9;W4@<W1I;&P@:&%V92!T;R!A9&0@:70@
M=&\@=&AE('1O;VQB87(L('-A;64@87,@=VET:"!T:&4*("H@8G5T=&]N<RX@
M($-A;&P@:70@;&EK92!T:&ES.@H@*@H@*B!&25A-13H@861D(&5X86UP;&4*
M("HO"DA434Q!<F5A+D-O;F9I9RYP<F]T;W1Y<&4N<F5G:7-T97)$<F]P9&]W
M;B`](&9U;F-T:6]N*&]B:F5C="D@>PH)+R\@8VAE8VL@9F]R(&5X:7-T:6YG
M(&ED"@EI9B`H='EP96]F('1H:7,N8W5S=&]M4V5L96-T<UMO8FIE8W0N:61=
M("$](")U;F1E9FEN960B*2!["@D)+R\@86QE<G0H(E=!4DY)3D<@6TA434Q!
M<F5A+D-O;F9I9SHZ<F5G:7-T97)$<F]P9&]W;ETZ7&Y!(&1R;W!D;W=N('=I
M=&@@=&AE('-A;64@240@86QR96%D>2!E>&ES=',N(BD["@E]"@EI9B`H='EP
M96]F('1H:7,N8G1N3&ES=%MO8FIE8W0N:61=("$](")U;F1E9FEN960B*2![
M"@D)+R\@86QE<G0H(E=!4DY)3D<@6TA434Q!<F5A+D-O;F9I9SHZ<F5G:7-T
M97)$<F]P9&]W;ETZ7&Y!(&)U='1O;B!W:71H('1H92!S86UE($E$(&%L<F5A
M9'D@97AI<W1S+B(I.PH)?0H)=&AI<RYC=7-T;VU396QE8W1S6V]B:F5C="YI
M9%T@/2!O8FIE8W0["GT["@HO*BH@0V%L;"!T:&ES(&9U;F-T:6]N('1O(')E
M;6]V92!S;VUE(&)U='1O;G,O9')O<"UD;W=N(&)O>&5S(&9R;VT@=&AE('1O
M;VQB87(N"B`J(%!A<W,@87,@=&AE(&]N;'D@<&%R86UE=&5R(&$@<W1R:6YG
M(&-O;G1A:6YI;F<@8G5T=&]N+V1R;W`M9&]W;B!N86UE<PH@*B!D96QI;6ET
M960@8GD@<W!A8V5S+B`@3F]T92!T:&%T('1H92!S=')I;F<@<VAO=6QD(&%L
M<V\@8F5G:6X@=VET:"!A('-P86-E"B`J(&%N9"!E;F0@=VET:"!A('-P86-E
M+B`@17AA;7!L93H*("H*("H@("!C;VYF:6<N:&ED95-O;65"=71T;VYS*"(@
M9F]N=&YA;64@9F]N='-I>F4@=&5X=&EN9&EC871O<B`B*3L*("H*("H@270G
M<R!U<V5F=6P@8F5C875S92!I="=S(&5A<VEE<B!T;R!R96UO=F4@<W1U9F8@
M9G)O;2!T:&4@9&5F875L('1O;VQB87(@=&AA;@H@*B!C<F5A=&4@82!B<F%N
M9"!N97<@=&]O;&)A<B`[+2D*("HO"DA434Q!<F5A+D-O;F9I9RYP<F]T;W1Y
M<&4N:&ED95-O;65"=71T;VYS(#T@9G5N8W1I;VXH<F5M;W9E*2!["@EV87(@
M=&]O;&)A<B`]('1H:7,N=&]O;&)A<CL*"69O<B`H=F%R(&D@/2!T;V]L8F%R
M+FQE;F=T:#L@+2UI(#X](#`[*2!["@D)=F%R(&QI;F4@/2!T;V]L8F%R6VE=
M.PH)"69O<B`H=F%R(&H@/2!L:6YE+FQE;F=T:#L@+2UJ(#X](#`[("D@>PH)
M"0EI9B`H<F5M;W9E+FEN9&5X3V8H(B`B("L@;&EN95MJ72`K("(@(BD@/CT@
M,"D@>PH)"0D)=F%R(&QE;B`](#$["@D)"0EI9B`H+W-E<&%R871O<GQS<&%C
M92\N=&5S="AL:6YE6VH@*R`Q72DI('L*"0D)"0EL96X@/2`R.PH)"0D)?0H)
M"0D);&EN92YS<&QI8V4H:BP@;&5N*3L*"0D)?0H)"7T*"7T*?3L*"B\J*B!(
M96QP97(@9G5N8W1I;VXZ(')E<&QA8V4@86QL(%1%6%1!4D5!+7,@:6X@=&AE
M(&1O8W5M96YT('=I=&@@2%1-3$%R96$M<RX@*B\*2%1-3$%R96$N<F5P;&%C
M94%L;"`](&9U;F-T:6]N*&-O;F9I9RD@>PH)=F%R('1A<R`](&1O8W5M96YT
M+F=E=$5L96UE;G1S0GE486=.86UE*")T97AT87)E82(I.PH)9F]R("AV87(@
M:2`]('1A<RYL96YG=&@[(&D@/B`P.R`H;F5W($A434Q!<F5A*'1A<ULM+6E=
M+"!C;VYF:6<I*2YG96YE<F%T92@I*3L*?3L*"B\J*B!(96QP97(@9G5N8W1I
M;VXZ(')E<&QA8V5S('1H92!415A405)%02!W:71H('1H92!G:79E;B!)1"!W
M:71H($A434Q!<F5A+B`J+PI(5$U,07)E82YR97!L86-E(#T@9G5N8W1I;VXH
M:60L(&-O;F9I9RD@>PH)=F%R('1A(#T@2%1-3$%R96$N9V5T16QE;65N=$)Y
M260H(G1E>'1A<F5A(BP@:60I.PH)<F5T=7)N('1A(#\@*&YE=R!(5$U,07)E
M82AT82P@8V]N9FEG*2DN9V5N97)A=&4H*2`Z(&YU;&P["GT["@HO+R!#<F5A
M=&5S('1H92!T;V]L8F%R(&%N9"!A<'!E;F1S(&ET('1O('1H92!?:'1M;&%R
M96$*2%1-3$%R96$N<')O=&]T>7!E+E]C<F5A=&54;V]L8F%R(#T@9G5N8W1I
M;VX@*"D@>PH)=F%R(&5D:71O<B`]('1H:7,["2\O('1O(&%C8V5S<R!T:&ES
M(&EN(&YE<W1E9"!F=6YC=&EO;G,*"@EV87(@=&]O;&)A<B`](&1O8W5M96YT
M+F-R96%T945L96UE;G0H(F1I=B(I.PH)=&AI<RY?=&]O;&)A<B`]('1O;VQB
M87(["@ET;V]L8F%R+F-L87-S3F%M92`](")T;V]L8F%R(CL*"71O;VQB87(N
M=6YS96QE8W1A8FQE(#T@(C$B.PH)=F%R('1B7W)O=R`](&YU;&P["@EV87(@
M=&)?;V)J96-T<R`](&YE=R!/8FIE8W0H*3L*"71H:7,N7W1O;VQB87)/8FIE
M8W1S(#T@=&)?;V)J96-T<SL*"@DO+R!C<F5A=&5S(&$@;F5W(&QI;F4@:6X@
M=&AE('1O;VQB87(*"69U;F-T:6]N(&YE=TQI;F4H*2!["@D)=F%R('1A8FQE
M(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@B=&%B;&4B*3L*"0ET86)L92YB
M;W)D97(@/2`B,'!X(CL*"0ET86)L92YC96QL4W!A8VEN9R`]("(P<'@B.PH)
M"71A8FQE+F-E;&Q0861D:6YG(#T@(C!P>"(["@D)=&]O;&)A<BYA<'!E;F1#
M:&EL9"AT86)L92D["@D)+R\@5$)/1%D@:7,@<F5Q=6ER960@9F]R($E%+"!O
M=&AE<G=I<V4@>6]U(&1O;B=T('-E92!A;GET:&EN9PH)"2\O(&EN('1H92!4
M04),12X*"0EV87(@=&)?8F]D>2`](&1O8W5M96YT+F-R96%T945L96UE;G0H
M(G1B;V1Y(BD["@D)=&%B;&4N87!P96YD0VAI;&0H=&)?8F]D>2D["@D)=&)?
M<F]W(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@B='(B*3L*"0ET8E]B;V1Y
M+F%P<&5N9$-H:6QD*'1B7W)O=RD["@E].R`O+R!%3D0@;V8@9G5N8W1I;VXZ
M(&YE=TQI;F4*"2\O(&EN:70@9FER<W0@;&EN90H);F5W3&EN92@I.PH*"2\O
M('5P9&%T97,@=&AE('-T871E(&]F(&$@=&]O;&)A<B!E;&5M96YT+B`@5&AI
M<R!F=6YC=&EO;B!I<R!M96UB97(@;V8*"2\O(&$@=&]O;&)A<B!E;&5M96YT
M(&]B:F5C="`H=6YN86UE9"!O8FIE8W1S(&-R96%T960@8GD@8W)E871E0G5T
M=&]N(&]R"@DO+R!C<F5A=&5396QE8W0@9G5N8W1I;VYS(&)E;&]W*2X*"69U
M;F-T:6]N('-E=$)U='1O;E-T871U<RAI9"P@;F5W=F%L*2!["@D)=F%R(&]L
M9'9A;"`]('1H:7-;:61=.PH)"79A<B!E;"`]('1H:7,N96QE;65N=#L*"0EI
M9B`H;VQD=F%L("$](&YE=W9A;"D@>PH)"0ES=VET8V@@*&ED*2!["@D)"2`@
M("!C87-E(")E;F%B;&5D(CH*"0D)"6EF("AN97=V86PI('L*"0D)"0E(5$U,
M07)E82Y?<F5M;W9E0VQA<W,H96PL(")B=71T;VY$:7-A8FQE9"(I.PH)"0D)
M"65L+F1I<V%B;&5D(#T@9F%L<V4["@D)"0E](&5L<V4@>PH)"0D)"4A434Q!
M<F5A+E]A9&1#;&%S<RAE;"P@(F)U='1O;D1I<V%B;&5D(BD["@D)"0D)96PN
M9&ES86)L960@/2!T<G5E.PH)"0D)?0H)"0D)8G)E86L["@D)"2`@("!C87-E
M(")A8W1I=F4B.@H)"0D):68@*&YE=W9A;"D@>PH)"0D)"4A434Q!<F5A+E]A
M9&1#;&%S<RAE;"P@(F)U='1O;E!R97-S960B*3L*"0D)"7T@96QS92!["@D)
M"0D)2%1-3$%R96$N7W)E;6]V94-L87-S*&5L+"`B8G5T=&]N4')E<W-E9"(I
M.PH)"0D)?0H)"0D)8G)E86L["@D)"7T*"0D)=&AI<UMI9%T@/2!N97=V86P[
M"@D)?0H)?3L@+R\@14Y$(&]F(&9U;F-T:6]N.B!S971"=71T;VY3=&%T=7,*
M"@DO+R!T:&ES(&9U;F-T:6]N('=I;&P@:&%N9&QE(&-R96%T:6]N(&]F(&-O
M;6)O(&)O>&5S+B`@4F5C96EV97,@87,*"2\O('!A<F%M971E<B!T:&4@;F%M
M92!O9B!A(&)U='1O;B!A<R!D969I;F5D(&EN('1H92!T;V]L0F%R(&-O;F9I
M9RX*"2\O(%1H:7,@9G5N8W1I;VX@:7,@8V%L;&5D(&9R;VT@8W)E871E0G5T
M=&]N+"!A8F]V92P@:68@=&AE(&=I=F5N(")T>'0B"@DO+R!D;V5S;B=T(&UA
M=&-H(&$@8G5T=&]N+@H)9G5N8W1I;VX@8W)E871E4V5L96-T*'1X="D@>PH)
M"79A<B!O<'1I;VYS(#T@;G5L;#L*"0EV87(@96P@/2!N=6QL.PH)"79A<B!C
M;60@/2!N=6QL.PH)"79A<B!C=7-T;VU396QE8W1S(#T@961I=&]R+F-O;F9I
M9RYC=7-T;VU396QE8W1S.PH)"79A<B!C;VYT97AT(#T@;G5L;#L*"0EV87(@
M=&]O;'1I<"`]("(B.PH)"7-W:71C:"`H='AT*2!["@D)("`@(&-A<V4@(F9O
M;G1S:7IE(CH*"0D@("`@8V%S92`B9F]N=&YA;64B.@H)"2`@("!C87-E(")F
M;W)M871B;&]C:R(Z"@D)"2\O('1H92!F;VQL;W=I;F<@;&EN92!R971R:65V
M97,@=&AE(&-O<G)E8W0*"0D)+R\@8V]N9FEG=7)A=&EO;B!O<'1I;VX@8F5C
M875S92!T:&4@=F%R:6%B;&4@;F%M90H)"0DO+R!I;G-I9&4@=&AE($-O;F9I
M9R!O8FIE8W0@:7,@;F%M960@=&AE('-A;64@87,@=&AE"@D)"2\O(&)U='1O
M;B]S96QE8W0@:6X@=&AE('1O;VQB87(N("!&;W(@:6YS=&%N8V4L(&EF('1X
M=`H)"0DO+R`]/2`B9F]R;6%T8FQO8VLB('=E(')E=')I979E(&-O;F9I9RYF
M;W)M871B;&]C:R`H;W(*"0D)+R\@82!D:69F97)E;G0@=V%Y('1O('=R:71E
M(&ET(&EN($I3(&ES"@D)"2\O(&-O;F9I9ULB9F]R;6%T8FQO8VLB72X*"0D)
M;W!T:6]N<R`](&5D:71O<BYC;VYF:6=;='AT73L*"0D)8VUD(#T@='AT.PH)
M"0EB<F5A:SL*"0D@("`@9&5F875L=#H*"0D)+R\@=')Y('1O(&9E=&-H(&ET
M(&9R;VT@=&AE(&QI<W0@;V8@<F5G:7-T97)E9"!S96QE8W1S"@D)"6-M9"`]
M('1X=#L*"0D)=F%R(&1R;W!D;W=N(#T@8W5S=&]M4V5L96-T<UMC;61=.PH)
M"0EI9B`H='EP96]F(&1R;W!D;W=N("$](")U;F1E9FEN960B*2!["@D)"0EO
M<'1I;VYS(#T@9')O<&1O=VXN;W!T:6]N<SL*"0D)"6-O;G1E>'0@/2!D<F]P
M9&]W;BYC;VYT97AT.PH)"0D):68@*'1Y<&5O9B!D<F]P9&]W;BYT;V]L=&EP
M("$](")U;F1E9FEN960B*2!["@D)"0D)=&]O;'1I<"`](&1R;W!D;W=N+G1O
M;VQT:7`["@D)"0E]"@D)"7T@96QS92!["@D)"0EA;&5R="@B15)23U(@6V-R
M96%T95-E;&5C=%TZ7&Y#86XG="!F:6YD('1H92!R97%U97-T960@9')O<&1O
M=VX@9&5F:6YI=&EO;B(I.PH)"0E]"@D)"6)R96%K.PH)"7T*"0EI9B`H;W!T
M:6]N<RD@>PH)"0EE;"`](&1O8W5M96YT+F-R96%T945L96UE;G0H(G-E;&5C
M="(I.PH)"0EE;"YT:71L92`]('1O;VQT:7`["@D)"79A<B!O8FH@/2!["@D)
M"0EN86UE"3H@='AT+"`O+R!F:65L9"!N86UE"@D)"0EE;&5M96YT(#H@96PL
M"2\O('1H92!522!E;&5M96YT("A314Q%0U0I"@D)"0EE;F%B;&5D(#H@=')U
M92P@+R\@:7,@:70@96YA8FQE9#\*"0D)"71E>'0).B!F86QS92P@+R\@96YA
M8FQE9"!I;B!T97AT(&UO9&4_"@D)"0EC;60).B!C;60L("\O(&-O;6UA;F0@
M240*"0D)"7-T871E"3H@<V5T0G5T=&]N4W1A='5S+"`O+R!F;W(@8VAA;F=I
M;F<@<W1A=&4*"0D)"6-O;G1E>'0@.B!C;VYT97AT"@D)"7T["@D)"71B7V]B
M:F5C='-;='AT72`](&]B:CL*"0D)9F]R("AV87(@:2!I;B!O<'1I;VYS*2![
M"@D)"0EV87(@;W`@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*")O<'1I;VXB
M*3L*"0D)"6]P+FEN;F5R2%1-3"`](&D["@D)"0EO<"YV86QU92`](&]P=&EO
M;G-;:5T["@D)"0EE;"YA<'!E;F1#:&EL9"AO<"D["@D)"7T*"0D)2%1-3$%R
M96$N7V%D9$5V96YT*&5L+"`B8VAA;F=E(BP@9G5N8W1I;VX@*"D@>PH)"0D)
M961I=&]R+E]C;VUB;U-E;&5C=&5D*&5L+"!T>'0I.PH)"0E]*3L*"0E]"@D)
M<F5T=7)N(&5L.PH)?3L@+R\@14Y$(&]F(&9U;F-T:6]N.B!C<F5A=&5396QE
M8W0*"@DO+R!A<'!E;F1S(&$@;F5W(&)U='1O;B!T;R!T;V]L8F%R"@EF=6YC
M=&EO;B!C<F5A=&5"=71T;VXH='AT*2!["@D)+R\@=&AE(&5L96UE;G0@=&AA
M="!W:6QL(&)E(&-R96%T960*"0EV87(@96P@/2!N=6QL.PH)"79A<B!B=&X@
M/2!N=6QL.PH)"7-W:71C:"`H='AT*2!["@D)("`@(&-A<V4@(G-E<&%R871O
M<B(Z"@D)"65L(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@B9&EV(BD["@D)
M"65L+F-L87-S3F%M92`](")S97!A<F%T;W(B.PH)"0EB<F5A:SL*"0D@("`@
M8V%S92`B<W!A8V4B.@H)"0EE;"`](&1O8W5M96YT+F-R96%T945L96UE;G0H
M(F1I=B(I.PH)"0EE;"YC;&%S<TYA;64@/2`B<W!A8V4B.PH)"0EB<F5A:SL*
M"0D@("`@8V%S92`B;&EN96)R96%K(CH*"0D);F5W3&EN92@I.PH)"0ER971U
M<FX@9F%L<V4["@D)("`@(&-A<V4@(G1E>'1I;F1I8V%T;W(B.@H)"0EE;"`]
M(&1O8W5M96YT+F-R96%T945L96UE;G0H(F1I=B(I.PH)"0EE;"YA<'!E;F1#
M:&EL9"AD;V-U;65N="YC<F5A=&5497AT3F]D92@B02(I*3L*"0D)96PN8VQA
M<W-.86UE(#T@(FEN9&EC871O<B(["@D)"65L+G1I=&QE(#T@2%1-3$%R96$N
M23$X3BYT;V]L=&EP<RYT97AT:6YD:6-A=&]R.PH)"0EV87(@;V)J(#T@>PH)
M"0D);F%M90DZ('1X="P@+R\@=&AE(&)U='1O;B!N86UE("AI+F4N("=B;VQD
M)RD*"0D)"65L96UE;G0@.B!E;"P@+R\@=&AE(%5)(&5L96UE;G0@*$1)5BD*
M"0D)"65N86)L960@.B!T<G5E+"`O+R!I<R!I="!E;F%B;&5D/PH)"0D)86-T
M:79E"3H@9F%L<V4L("\O(&ES(&ET('!R97-S960_"@D)"0ET97AT"3H@9F%L
M<V4L("\O(&5N86)L960@:6X@=&5X="!M;V1E/PH)"0D)8VUD"3H@(G1E>'1I
M;F1I8V%T;W(B+"`O+R!T:&4@8V]M;6%N9"!)1`H)"0D)<W1A=&4).B!S971"
M=71T;VY3=&%T=7,@+R\@9F]R(&-H86YG:6YG('-T871E"@D)"7T["@D)"71B
M7V]B:F5C='-;='AT72`](&]B:CL*"0D)8G)E86L["@D)("`@(&1E9F%U;'0Z
M"@D)"6)T;B`](&5D:71O<BYC;VYF:6<N8G1N3&ES=%MT>'1=.PH)"7T*"0EI
M9B`H(65L("8F(&)T;BD@>PH)"0EE;"`](&1O8W5M96YT+F-R96%T945L96UE
M;G0H(F1I=B(I.PH)"0EE;"YT:71L92`](&)T;ELP73L*"0D)96PN8VQA<W-.
M86UE(#T@(F)U='1O;B(["@D)"2\O(&QE="=S(&IU<W0@<')E=&5N9"!W92!H
M879E(&$@8G5T=&]N(&]B:F5C="P@86YD"@D)"2\O(&%S<VEG;B!A;&P@=&AE
M(&YE961E9"!I;F9O<FUA=&EO;B!T;R!I="X*"0D)=F%R(&]B:B`]('L*"0D)
M"6YA;64).B!T>'0L("\O('1H92!B=71T;VX@;F%M92`H:2YE+B`G8F]L9"<I
M"@D)"0EE;&5M96YT(#H@96PL("\O('1H92!522!E;&5M96YT("A$258I"@D)
M"0EE;F%B;&5D(#H@=')U92P@+R\@:7,@:70@96YA8FQE9#\*"0D)"6%C=&EV
M90DZ(&9A;'-E+"`O+R!I<R!I="!P<F5S<V5D/PH)"0D)=&5X=`DZ(&)T;ELR
M72P@+R\@96YA8FQE9"!I;B!T97AT(&UO9&4_"@D)"0EC;60).B!B=&Y;,UTL
M("\O('1H92!C;VUM86YD($E$"@D)"0ES=&%T90DZ('-E=$)U='1O;E-T871U
M<RP@+R\@9F]R(&-H86YG:6YG('-T871E"@D)"0EC;VYT97AT(#H@8G1N6S1=
M('Q\(&YU;&P@+R\@96YA8FQE9"!I;B!A(&-E<G1A:6X@8V]N=&5X=#\*"0D)
M?3L*"0D)=&)?;V)J96-T<UMT>'1=(#T@;V)J.PH)"0DO+R!H86YD;&5R<R!T
M;R!E;75L871E(&YI8V4@9FQA="!T;V]L8F%R(&)U='1O;G,*"0D)2%1-3$%R
M96$N7V%D9$5V96YT*&5L+"`B;6]U<V5O=F5R(BP@9G5N8W1I;VX@*"D@>PH)
M"0D):68@*&]B:BYE;F%B;&5D*2!["@D)"0D)2%1-3$%R96$N7V%D9$-L87-S
M*&5L+"`B8G5T=&]N2&]V97(B*3L*"0D)"7T*"0D)?2D["@D)"4A434Q!<F5A
M+E]A9&1%=F5N="AE;"P@(FUO=7-E;W5T(BP@9G5N8W1I;VX@*"D@>PH)"0D)
M:68@*&]B:BYE;F%B;&5D*2!W:71H("A(5$U,07)E82D@>PH)"0D)"5]R96UO
M=F5#;&%S<RAE;"P@(F)U='1O;DAO=F5R(BD["@D)"0D)7W)E;6]V94-L87-S
M*&5L+"`B8G5T=&]N06-T:79E(BD["@D)"0D)*&]B:BYA8W1I=F4I("8F(%]A
M9&1#;&%S<RAE;"P@(F)U='1O;E!R97-S960B*3L*"0D)"7T*"0D)?2D["@D)
M"4A434Q!<F5A+E]A9&1%=F5N="AE;"P@(FUO=7-E9&]W;B(L(&9U;F-T:6]N
M("AE=BD@>PH)"0D):68@*&]B:BYE;F%B;&5D*2!W:71H("A(5$U,07)E82D@
M>PH)"0D)"5]A9&1#;&%S<RAE;"P@(F)U='1O;D%C=&EV92(I.PH)"0D)"5]R
M96UO=F5#;&%S<RAE;"P@(F)U='1O;E!R97-S960B*3L*"0D)"0E?<W1O<$5V
M96YT*&ES7VEE(#\@=VEN9&]W+F5V96YT(#H@978I.PH)"0D)?0H)"0E]*3L*
M"0D)+R\@=VAE;B!C;&EC:V5D+"!D;R!T:&4@9F]L;&]W:6YG.@H)"0E(5$U,
M07)E82Y?861D179E;G0H96PL(")C;&EC:R(L(&9U;F-T:6]N("AE=BD@>PH)
M"0D):68@*&]B:BYE;F%B;&5D*2!W:71H("A(5$U,07)E82D@>PH)"0D)"5]R
M96UO=F5#;&%S<RAE;"P@(F)U='1O;D%C=&EV92(I.PH)"0D)"5]R96UO=F5#
M;&%S<RAE;"P@(F)U='1O;DAO=F5R(BD["@D)"0D);V)J+F-M9"AE9&ET;W(L
M(&]B:BYN86UE+"!O8FHI.PH)"0D)"5]S=&]P179E;G0H:7-?:64@/R!W:6YD
M;W<N979E;G0@.B!E=BD["@D)"0E]"@D)"7TI.PH)"0EV87(@:6UG(#T@9&]C
M=6UE;G0N8W)E871E16QE;65N="@B:6UG(BD["@D)"6EM9RYS<F,@/2!B=&Y;
M,5T["@D)"6EM9RYS='EL92YW:61T:"`]("(Q.'!X(CL*"0D):6UG+G-T>6QE
M+FAE:6=H="`]("(Q.'!X(CL*"0D)96PN87!P96YD0VAI;&0H:6UG*3L*"0E]
M(&5L<V4@:68@*"%E;"D@>PH)"0EE;"`](&-R96%T95-E;&5C="AT>'0I.PH)
M"7T*"0EI9B`H96PI('L*"0D)=F%R('1B7V-E;&P@/2!D;V-U;65N="YC<F5A
M=&5%;&5M96YT*")T9"(I.PH)"0ET8E]R;W<N87!P96YD0VAI;&0H=&)?8V5L
M;"D["@D)"71B7V-E;&PN87!P96YD0VAI;&0H96PI.PH)"7T@96QS92!["@D)
M"6%L97)T*")&25A-13H@56YK;F]W;B!T;V]L8F%R(&ET96TZ("(@*R!T>'0I
M.PH)"7T*"0ER971U<FX@96P["@E].PH*"79A<B!F:7)S="`]('1R=64["@EF
M;W(@*'9A<B!I(#T@,#L@:2`\('1H:7,N8V]N9FEG+G1O;VQB87(N;&5N9W1H
M.R`K*VDI('L*"0EI9B`H(69I<G-T*2!["@D)"6-R96%T94)U='1O;B@B;&EN
M96)R96%K(BD["@D)?2!E;'-E('L*"0D)9FER<W0@/2!F86QS93L*"0E]"@D)
M=F%R(&=R;W5P(#T@=&AI<RYC;VYF:6<N=&]O;&)A<EMI73L*"0EF;W(@*'9A
M<B!J(#T@,#L@:B`\(&=R;W5P+FQE;F=T:#L@*RMJ*2!["@D)"79A<B!C;V1E
M(#T@9W)O=7!;:ET["@D)"6EF("@O7BA;251=*5Q;*"XJ/RE<72\N=&5S="AC
M;V1E*2D@>PH)"0D)+R\@<W!E8VEA;"!C87-E+"!C<F5A=&4@=&5X="!L86)E
M;`H)"0D)=F%R(&PW960@/2!296=%>'`N)#$@/3T@(DDB.R`O+R!L;V-A;&EZ
M960_"@D)"0EV87(@;&%B96P@/2!296=%>'`N)#(["@D)"0EI9B`H;#=E9"D@
M>PH)"0D)"6QA8F5L(#T@2%1-3$%R96$N23$X3BYC=7-T;VU;;&%B96Q=.PH)
M"0D)?0H)"0D)=F%R('1B7V-E;&P@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT
M*")T9"(I.PH)"0D)=&)?<F]W+F%P<&5N9$-H:6QD*'1B7V-E;&PI.PH)"0D)
M=&)?8V5L;"YC;&%S<TYA;64@/2`B;&%B96PB.PH)"0D)=&)?8V5L;"YI;FYE
M<DA434P@/2!L86)E;#L*"0D)?2!E;'-E('L*"0D)"6-R96%T94)U='1O;BAC
M;V1E*3L*"0D)?0H)"7T*"7T*"@ET:&ES+E]H=&UL07)E82YA<'!E;F1#:&EL
M9"AT;V]L8F%R*3L*?3L*"DA434Q!<F5A+G!R;W1O='EP92Y?8W)E871E4W1A
M='5S0F%R(#T@9G5N8W1I;VXH*2!["@EV87(@<W1A='5S8F%R(#T@9&]C=6UE
M;G0N8W)E871E16QE;65N="@B9&EV(BD["@ES=&%T=7-B87(N8VQA<W-.86UE
M(#T@(G-T871U<T)A<B(["@ET:&ES+E]H=&UL07)E82YA<'!E;F1#:&EL9"AS
M=&%T=7-B87(I.PH)=&AI<RY?<W1A='5S0F%R(#T@<W1A='5S8F%R.PH)+R\@
M<W1A='5S8F%R+F%P<&5N9$-H:6QD*&1O8W5M96YT+F-R96%T951E>'1.;V1E
M*$A434Q!<F5A+DDQ.$XN;7-G6R)0871H(ET@*R`B.B`B*2D["@DO+R!C<F5A
M=&5S(&$@:&]L9&5R(&9O<B!T:&4@<&%T:"!V:65W"@ED:78@/2!D;V-U;65N
M="YC<F5A=&5%;&5M96YT*")S<&%N(BD["@ED:78N8VQA<W-.86UE(#T@(G-T
M871U<T)A<E1R964B.PH)9&EV+FEN;F5R2%1-3"`]($A434Q!<F5A+DDQ.$XN
M;7-G6R)0871H(ET@*R`B.B`B.PH)=&AI<RY?<W1A='5S0F%R5')E92`](&1I
M=CL*"71H:7,N7W-T871U<T)A<BYA<'!E;F1#:&EL9"AD:78I.PH):68@*"%T
M:&ES+F-O;F9I9RYS=&%T=7-"87(I('L*"0DO+R!D:7-A8FQE(&ET+BXN"@D)
M<W1A='5S8F%R+G-T>6QE+F1I<W!L87D@/2`B;F]N92(["@E]"GT["@HO+R!#
M<F5A=&5S('1H92!(5$U,07)E82!O8FIE8W0@86YD(')E<&QA8V5S('1H92!T
M97AT87)E82!W:71H(&ET+@I(5$U,07)E82YP<F]T;W1Y<&4N9V5N97)A=&4@
M/2!F=6YC=&EO;B`H*2!["@EV87(@961I=&]R(#T@=&AI<SL)+R\@=V4G;&P@
M;F5E9"`B=&AI<R(@:6X@<V]M92!N97-T960@9G5N8W1I;VYS"@DO+R!G970@
M=&AE('1E>'1A<F5A"@EV87(@=&5X=&%R96$@/2!T:&ES+E]T97AT07)E83L*
M"6EF("AT>7!E;V8@=&5X=&%R96$@/3T@(G-T<FEN9R(I('L*"0DO+R!I="=S
M(&YO="!E;&5M96YT(&)U="!)1`H)"71H:7,N7W1E>'1!<F5A(#T@=&5X=&%R
M96$@/2!(5$U,07)E82YG971%;&5M96YT0GE)9"@B=&5X=&%R96$B+"!T97AT
M87)E82D["@E]"@ET:&ES+E]T85]S:7IE(#T@>PH)"7<Z('1E>'1A<F5A+F]F
M9G-E=%=I9'1H+`H)"6@Z('1E>'1A<F5A+F]F9G-E=$AE:6=H=`H)?3L*"71E
M>'1A<F5A+G-T>6QE+F1I<W!L87D@/2`B;F]N92(["@H)+R\@8W)E871E('1H
M92!E9&ET;W(@9G)A;65W;W)K"@EV87(@:'1M;&%R96$@/2!D;V-U;65N="YC
M<F5A=&5%;&5M96YT*")D:78B*3L*"6AT;6QA<F5A+F-L87-S3F%M92`](")H
M=&UL87)E82(["@ET:&ES+E]H=&UL07)E82`](&AT;6QA<F5A.PH*"2\O(&EN
M<V5R="!T:&4@961I=&]R(&)E9F]R92!T:&4@=&5X=&%R96$N"@ET97AT87)E
M82YP87)E;G1.;V1E+FEN<V5R=$)E9F]R92AH=&UL87)E82P@=&5X=&%R96$I
M.PH*"6EF("AT97AT87)E82YF;W)M*2!["@D)+R\@=V4@:&%V92!A(&9O<FTL
M(&]N('-U8FUI="!G970@=&AE($A434Q!<F5A(&-O;G1E;G0@86YD"@D)+R\@
M=7!D871E(&]R:6=I;F%L('1E>'1A<F5A+@H)"79A<B!F(#T@=&5X=&%R96$N
M9F]R;3L*"0EI9B`H='EP96]F(&8N;VYS=6)M:70@/3T@(F9U;F-T:6]N(BD@
M>PH)"0EV87(@9G5N8W)E9B`](&8N;VYS=6)M:70["@D)"6EF("AT>7!E;V8@
M9BY?7VUS:%]P<F5V3VY3=6)M:70@/3T@(G5N9&5F:6YE9"(I('L*"0D)"68N
M7U]M<VA?<')E=D]N4W5B;6ET(#T@6UT["@D)"7T*"0D)9BY?7VUS:%]P<F5V
M3VY3=6)M:70N<'5S:"AF=6YC<F5F*3L*"0E]"@D)9BYO;G-U8FUI="`](&9U
M;F-T:6]N*"D@>PH)"0EE9&ET;W(N7W1E>'1!<F5A+G9A;'5E(#T@961I=&]R
M+F=E=$A434PH*3L*"0D)=F%R(&$@/2!T:&ES+E]?;7-H7W!R979/;E-U8FUI
M=#L*"0D)+R\@8V%L;"!P<F5V:6]U<R!S=6)M:70@;65T:&]D<R!I9B!T:&5Y
M('=E<F4@=&AE<F4N"@D)"6EF("AT>7!E;V8@82`A/2`B=6YD969I;F5D(BD@
M>PH)"0D)9F]R("AV87(@:2`](&$N;&5N9W1H.R`M+6D@/CT@,#LI('L*"0D)
M"0EA6VE=*"D["@D)"0E]"@D)"7T*"0E].PH)"6EF("AT>7!E;V8@9BYO;G)E
M<V5T(#T](")F=6YC=&EO;B(I('L*"0D)=F%R(&9U;F-R968@/2!F+F]N<F5S
M970["@D)"6EF("AT>7!E;V8@9BY?7VUS:%]P<F5V3VY297-E="`]/2`B=6YD
M969I;F5D(BD@>PH)"0D)9BY?7VUS:%]P<F5V3VY297-E="`](%M=.PH)"0E]
M"@D)"68N7U]M<VA?<')E=D]N4F5S970N<'5S:"AF=6YC<F5F*3L*"0E]"@D)
M9BYO;G)E<V5T(#T@9G5N8W1I;VXH*2!["@D)"65D:71O<BYS971(5$U,*&5D
M:71O<BY?=&5X=$%R96$N=F%L=64I.PH)"0EE9&ET;W(N=7!D871E5&]O;&)A
M<B@I.PH)"0EV87(@82`]('1H:7,N7U]M<VA?<')E=D]N4F5S970["@D)"2\O
M(&-A;&P@<')E=FEO=7,@<F5S970@;65T:&]D<R!I9B!T:&5Y('=E<F4@=&AE
M<F4N"@D)"6EF("AT>7!E;V8@82`A/2`B=6YD969I;F5D(BD@>PH)"0D)9F]R
M("AV87(@:2`](&$N;&5N9W1H.R`M+6D@/CT@,#LI('L*"0D)"0EA6VE=*"D[
M"@D)"0E]"@D)"7T*"0E].PH)?0H*"2\O(&%D9"!A(&AA;F1L97(@9F]R('1H
M92`B8F%C:R]F;W)W87)D(B!C87-E("TM(&]N(&)O9'DN=6YL;V%D('=E('-A
M=F4*"2\O('1H92!(5$U,(&-O;G1E;G0@:6YT;R!T:&4@;W)I9VEN86P@=&5X
M=&%R96$N"@ET<GD@>PH)"7=I;F1O=RYO;G5N;&]A9"`](&9U;F-T:6]N*"D@
M>PH)"0EE9&ET;W(N7W1E>'1!<F5A+G9A;'5E(#T@961I=&]R+F=E=$A434PH
M*3L*"0E].PH)?2!C871C:"AE*2![?3L*"@DO+R!C<F5A=&5S("8@87!P96YD
M<R!T:&4@=&]O;&)A<@H)=&AI<RY?8W)E871E5&]O;&)A<B@I.PH*"2\O(&-R
M96%T92!T:&4@249204U%"@EV87(@:69R86UE(#T@9&]C=6UE;G0N8W)E871E
M16QE;65N="@B:69R86UE(BD["@H)+R\@=V]R:V%R;W5N9"!F;W(@=&AE($A4
M5%!3('!R;V)L96T*"2\O(&EF<F%M92YS971!='1R:6)U=&4H(G-R8R(L(")J
M879A<V-R:7!T.G9O:60H,"D[(BD["@EI9G)A;64N<W)C(#T@7V5D:71O<E]U
M<FP@*R`B<&]P=7!S+V)L86YK+FAT;6PB.PH*"6AT;6QA<F5A+F%P<&5N9$-H
M:6QD*&EF<F%M92D["@H)=&AI<RY?:69R86UE(#T@:69R86UE.PH*"2\O(&-R
M96%T97,@)B!A<'!E;F1S('1H92!S=&%T=7,@8F%R+"!I9B!T:&4@8V%S90H)
M=&AI<RY?8W)E871E4W1A='5S0F%R*"D["@H)+R\@<F5M;W9E('1H92!D969A
M=6QT(&)O<F1E<B!A<R!I="!K965P<R!U<R!F<F]M(&-O;7!U=&EN9R!C;W)R
M96-T;'D*"2\O('1H92!S:7IE<RX@("AS;VUE8F]D>2!T96QL(&UE('=H>2!D
M;V5S;B=T('1H:7,@=V]R:R!I;B!)12D*"@EI9B`H(4A434Q!<F5A+FES7VEE
M*2!["@D):69R86UE+G-T>6QE+F)O<F1E<E=I9'1H(#T@(C%P>"(["@DO+R!I
M9G)A;64N9G)A;65";W)D97(@/2`B,2(["@DO+R!I9G)A;64N;6%R9VEN2&5I
M9VAT(#T@(C`B.PH)+R\@:69R86UE+FUA<F=I;E=I9'1H(#T@(C`B.PH)?0H*
M"2\O('-I>F4@=&AE($E&4D%-12!A8V-O<F1I;F<@=&\@=7-E<B=S('!R969S
M(&]R(&EN:71I86P@=&5X=&%R96$*"79A<B!H96EG:'0@/2`H=&AI<RYC;VYF
M:6<N:&5I9VAT(#T](")A=71O(B`_("AT:&ES+E]T85]S:7IE+F@@*R`B<'@B
M*2`Z('1H:7,N8V]N9FEG+FAE:6=H="D["@EH96EG:'0@/2!P87)S94EN="AH
M96EG:'0I.PH)=F%R('=I9'1H(#T@*'1H:7,N8V]N9FEG+G=I9'1H(#T](")A
M=71O(B`_("AT:&ES+E]T85]S:7IE+G<@*R`B<'@B*2`Z('1H:7,N8V]N9FEG
M+G=I9'1H*3L*"7=I9'1H(#T@<&%R<V5);G0H=VED=&@I.PH*"6EF("@A2%1-
M3$%R96$N:7-?:64I('L*"0EH96EG:'0@+3T@,CL*"0EW:61T:"`M/2`R.PH)
M?0H*"6EF<F%M92YS='EL92YW:61T:"`]('=I9'1H("L@(G!X(CL*"6EF("AT
M:&ES+F-O;F9I9RYS:7IE26YC;'5D97-4;V]L8F%R*2!["@D)+R\@<W5B<W1R
M86-T('1O;VQB87(@:&5I9VAT"@D):&5I9VAT("T]('1H:7,N7W1O;VQB87(N
M;V9F<V5T2&5I9VAT.PH)"6AE:6=H="`M/2!T:&ES+E]S=&%T=7-"87(N;V9F
M<V5T2&5I9VAT.PH)?0H):68@*&AE:6=H="`\(#`I('L*"0EH96EG:'0@/2`P
M.PH)?0H):69R86UE+G-T>6QE+FAE:6=H="`](&AE:6=H="`K(")P>"(["@H)
M+R\@=&AE(&5D:71O<B!I;F-L=61I;F<@=&AE('1O;VQB87(@;F]W(&AA=F4@
M=&AE('-A;64@<VEZ92!A<R!T:&4*"2\O(&]R:6=I;F%L('1E>'1A<F5A+BX@
M=VAI8V@@;65A;G,@=&AA="!W92!N965D('1O(')E9'5C92!T:&%T(&$@8FET
M+@H)=&5X=&%R96$N<W1Y;&4N=VED=&@@/2!I9G)A;64N<W1Y;&4N=VED=&@[
M"B`)=&5X=&%R96$N<W1Y;&4N:&5I9VAT(#T@:69R86UE+G-T>6QE+FAE:6=H
M=#L*"@DO+R!)35!/4E1!3E0Z('=E(&AA=F4@=&\@86QL;W<@36]Z:6QL82!A
M('-H;W)T('1I;64@=&\@<F5C;V=N:7IE('1H90H)+R\@;F5W(&9R86UE+B`@
M3W1H97)W:7-E('=E(&=E="!A('-T=7!I9"!E>&-E<'1I;VXN"@EF=6YC=&EO
M;B!I;FET269R86UE*"D@>PH)"79A<B!D;V,@/2!E9&ET;W(N7VEF<F%M92YC
M;VYT96YT5VEN9&]W+F1O8W5M96YT.PH)"6EF("@A9&]C*2!["@D)"2\O(%1R
M>2!A9V%I;BXN"@D)"2\O($9)6$U%.B!D;VXG="!K;F]W('=H870@96QS92!T
M;R!D;R!H97)E+B`@3F]R;6%L;'D*"0D)+R\@=V4G;&P@;F5V97(@<F5A8V@@
M=&AI<R!P;VEN="X*"0D):68@*$A434Q!<F5A+FES7V=E8VMO*2!["@D)"0ES
M9714:6UE;W5T*&EN:71)9G)A;64L(#$P,"D["@D)"0ER971U<FX@9F%L<V4[
M"@D)"7T@96QS92!["@D)"0EA;&5R="@B15)23U(Z($E&4D%-12!C86XG="!B
M92!I;FET:6%L:7IE9"XB*3L*"0D)?0H)"7T*"0EI9B`H2%1-3$%R96$N:7-?
M9V5C:V\I('L*"0D)+R\@96YA8FQE(&5D:71A8FQE(&UO9&4@9F]R($UO>FEL
M;&$*"0D)9&]C+F1E<VEG;DUO9&4@/2`B;VXB.PH)"7T*"0EE9&ET;W(N7V1O
M8R`](&1O8SL*"0EI9B`H(65D:71O<BYC;VYF:6<N9G5L;%!A9V4I('L*"0D)
M9&]C+F]P96XH*3L*"0D)=F%R(&AT;6P@/2`B/&AT;6P^7&XB.PH)"0EH=&UL
M("L]("(\:&5A9#Y<;B(["@D)"6EF("AE9&ET;W(N8V]N9FEG+F)A<V554DPI
M"@D)"0EH=&UL("L]("<\8F%S92!H<F5F/2(G("L@961I=&]R+F-O;F9I9RYB
M87-E55),("L@)R(@+SXG.PH)"0EH=&UL("L]("(\<W1Y;&4^(B`K(&5D:71O
M<BYC;VYF:6<N<&%G95-T>6QE("L*"0D)"2(@:'1M;"QB;V1Y('L@8F]R9&5R
M.B`P<'@[('T\+W-T>6QE/EQN(CL*"0D):'1M;"`K/2`B/"]H96%D/EQN(CL*
M"0D):'1M;"`K/2`B/&)O9'D^7&XB.PH)"0EH=&UL("L](&5D:71O<BY?=&5X
M=$%R96$N=F%L=64["@D)"6AT;6P@*ST@(CPO8F]D>3Y<;B(["@D)"6AT;6P@
M*ST@(CPO:'1M;#XB.PH)"0ED;V,N=W)I=&4H:'1M;"D["@D)"61O8RYC;&]S
M92@I.PH)"7T@96QS92!["@D)"79A<B!H=&UL(#T@961I=&]R+E]T97AT07)E
M82YV86QU93L*"0D):68@*&AT;6PN;6%T8V@H2%1-3$%R96$N4D5?9&]C='EP
M92DI('L*"0D)"65D:71O<BYS971$;V-T>7!E*%)E9T5X<"XD,2D["@D)"0EH
M=&UL(#T@:'1M;"YR97!L86-E*$A434Q!<F5A+E)%7V1O8W1Y<&4L("(B*3L*
M"0D)?0H)"0ED;V,N;W!E;B@I.PH)"0ED;V,N=W)I=&4H:'1M;"D["@D)"61O
M8RYC;&]S92@I.PH)"7T*"@D):68@*$A434Q!<F5A+FES7VEE*2!["@D)"2\O
M(&5N86)L92!E9&ET86)L92!M;V1E(&9O<B!)12X)($9O<B!S;VUE(')E87-O
M;B!T:&ES"@D)"2\O(&1O97-N)W0@=V]R:R!I9B!D;VYE(&EN('1H92!S86UE
M('!L86-E(&%S(&9O<B!'96-K;PH)"0DO+R`H86)O=F4I+@H)"0ED;V,N8F]D
M>2YC;VYT96YT161I=&%B;&4@/2!T<G5E.PH)"7T*"@D)961I=&]R+F9O8W5S
M161I=&]R*"D["@D)+R\@:6YT97)C97!T('-O;64@979E;G1S.R!F;W(@=7!D
M871I;F<@=&AE('1O;VQB87(@)B!K97EB;V%R9"!H86YD;&5R<PH)"4A434Q!
M<F5A+E]A9&1%=F5N=',*"0D)*&1O8RP@6R)K97ED;W=N(BP@(FME>7!R97-S
M(BP@(FUO=7-E9&]W;B(L(")M;W5S975P(BP@(F1R86<B72P*"0D)(&9U;F-T
M:6]N("AE=F5N="D@>PH)"0D)(')E='5R;B!E9&ET;W(N7V5D:71O<D5V96YT
M*$A434Q!<F5A+FES7VEE(#\@961I=&]R+E]I9G)A;64N8V]N=&5N=%=I;F1O
M=RYE=F5N="`Z(&5V96YT*3L*"0D)('TI.PH*"0DO+R!C:&5C:R!I9B!A;GD@
M<&QU9VEN<R!H879E(')E9VES=&5R960@<F5F<F5S:"!H86YD;&5R<PH)"69O
M<B`H=F%R(&D@:6X@961I=&]R+G!L=6=I;G,I('L*"0D)=F%R('!L=6=I;B`]
M(&5D:71O<BYP;'5G:6YS6VE=+FEN<W1A;F-E.PH)"0EI9B`H='EP96]F('!L
M=6=I;BYO;D=E;F5R871E(#T](")F=6YC=&EO;B(I"@D)"0EP;'5G:6XN;VY'
M96YE<F%T92@I.PH)"0EI9B`H='EP96]F('!L=6=I;BYO;D=E;F5R871E3VYC
M92`]/2`B9G5N8W1I;VXB*2!["@D)"0EP;'5G:6XN;VY'96YE<F%T94]N8V4H
M*3L*"0D)"7!L=6=I;BYO;D=E;F5R871E3VYC92`](&YU;&P["@D)"7T*"0E]
M"@H)"7-E=%1I;65O=70H9G5N8W1I;VXH*2!["@D)"65D:71O<BYU<&1A=&54
M;V]L8F%R*"D["@D)?2P@,C4P*3L*"@D):68@*'1Y<&5O9B!E9&ET;W(N;VY'
M96YE<F%T92`]/2`B9G5N8W1I;VXB*0H)"0EE9&ET;W(N;VY'96YE<F%T92@I
M.PH)?3L*"7-E=%1I;65O=70H:6YI=$EF<F%M92P@,3`P*3L*"7)E='5R;B!T
M:&ES.PI].PH*+R\@4W=I=&-H97,@961I=&]R(&UO9&4[('!A<F%M971E<B!C
M86X@8F4@(G1E>'1M;V1E(B!O<B`B=WES:7=Y9R(N("!)9B!N;PHO+R!P87)A
M;65T97(@=V%S('!A<W-E9"!T:&ES(&9U;F-T:6]N('1O9V=L97,@8F5T=V5E
M;B!M;V1E<RX*2%1-3$%R96$N<')O=&]T>7!E+G-E=$UO9&4@/2!F=6YC=&EO
M;BAM;V1E*2!["@EI9B`H='EP96]F(&UO9&4@/3T@(G5N9&5F:6YE9"(I('L*
M"0EM;V1E(#T@*"AT:&ES+E]E9&ET36]D92`]/2`B=&5X=&UO9&4B*2`_(")W
M>7-I=WEG(B`Z(")T97AT;6]D92(I.PH)?0H)<W=I=&-H("AM;V1E*2!["@D@
M("`@8V%S92`B=&5X=&UO9&4B.@H)"71H:7,N7W1E>'1!<F5A+G9A;'5E(#T@
M=&AI<RYG971(5$U,*"D["@D)=&AI<RY?:69R86UE+G-T>6QE+F1I<W!L87D@
M/2`B;F]N92(["@D)=&AI<RY?=&5X=$%R96$N<W1Y;&4N9&ES<&QA>2`](")B
M;&]C:R(["@D):68@*'1H:7,N8V]N9FEG+G-T871U<T)A<BD@>PH)"0ET:&ES
M+E]S=&%T=7-"87(N:6YN97)(5$U,(#T@2%1-3$%R96$N23$X3BYM<V=;(E1%
M6%1?34]$12)=.PH)"7T*"0EB<F5A:SL*"2`@("!C87-E(")W>7-I=WEG(CH*
M"0EI9B`H2%1-3$%R96$N:7-?9V5C:V\I('L*"0D)+R\@9&ES86)L92!D97-I
M9VX@;6]D92!B969O<F4@8VAA;F=I;F<@:6YN97)(5$U,"@D)"71R>2!["@D)
M"0ET:&ES+E]D;V,N9&5S:6=N36]D92`](")O9F8B.PH)"0E](&-A=&-H*&4I
M('M].PH)"7T*"0EI9B`H(71H:7,N8V]N9FEG+F9U;&Q086=E*0H)"0ET:&ES
M+E]D;V,N8F]D>2YI;FYE<DA434P@/2!T:&ES+F=E=$A434PH*3L*"0EE;'-E
M"@D)"71H:7,N<V5T1G5L;$A434PH=&AI<RYG971(5$U,*"DI.PH)"71H:7,N
M7VEF<F%M92YS='EL92YD:7-P;&%Y(#T@(F)L;V-K(CL*"0ET:&ES+E]T97AT
M07)E82YS='EL92YD:7-P;&%Y(#T@(FYO;F4B.PH)"6EF("A(5$U,07)E82YI
M<U]G96-K;RD@>PH)"0DO+R!W92!N965D('1O(')E9G)E<V@@=&AA="!I;F9O
M(&9O<B!-;WHM,2XS80H)"0ET<GD@>PH)"0D)=&AI<RY?9&]C+F1E<VEG;DUO
M9&4@/2`B;VXB.PH)"0E](&-A=&-H*&4I('M].PH)"7T*"0EI9B`H=&AI<RYC
M;VYF:6<N<W1A='5S0F%R*2!["@D)"71H:7,N7W-T871U<T)A<BYI;FYE<DA4
M34P@/2`G)SL*"0D)+R\@=&AI<RY?<W1A='5S0F%R+F%P<&5N9$-H:6QD*&1O
M8W5M96YT+F-R96%T951E>'1.;V1E*$A434Q!<F5A+DDQ.$XN;7-G6R)0871H
M(ET@*R`B.B`B*2D["@D)"71H:7,N7W-T871U<T)A<BYA<'!E;F1#:&EL9"AT
M:&ES+E]S=&%T=7-"87)4<F5E*3L*"0E]"@D)8G)E86L["@D@("`@9&5F875L
M=#H*"0EA;&5R="@B36]D92`\(B`K(&UO9&4@*R`B/B!N;W0@9&5F:6YE9"$B
M*3L*"0ER971U<FX@9F%L<V4["@E]"@ET:&ES+E]E9&ET36]D92`](&UO9&4[
M"@ET:&ES+F9O8W5S161I=&]R*"D["@H)9F]R("AV87(@:2!I;B!T:&ES+G!L
M=6=I;G,I('L*"0EV87(@<&QU9VEN(#T@=&AI<RYP;'5G:6YS6VE=+FEN<W1A
M;F-E.PH)"6EF("AT>7!E;V8@<&QU9VEN+F]N36]D92`]/2`B9G5N8W1I;VXB
M*2!P;'5G:6XN;VY-;V1E*&UO9&4I.PH)?0I].PH*2%1-3$%R96$N<')O=&]T
M>7!E+G-E=$9U;&Q(5$U,(#T@9G5N8W1I;VXH:'1M;"D@>PH)=F%R('-A=F5?
M;75L=&EL:6YE(#T@4F5G17AP+FUU;'1I;&EN93L*"5)E9T5X<"YM=6QT:6QI
M;F4@/2!T<G5E.PH):68@*&AT;6PN;6%T8V@H2%1-3$%R96$N4D5?9&]C='EP
M92DI('L*"0ET:&ES+G-E=$1O8W1Y<&4H4F5G17AP+B0Q*3L*"0EH=&UL(#T@
M:'1M;"YR97!L86-E*$A434Q!<F5A+E)%7V1O8W1Y<&4L("(B*3L*"7T*"5)E
M9T5X<"YM=6QT:6QI;F4@/2!S879E7VUU;'1I;&EN93L*"6EF("@A2%1-3$%R
M96$N:7-?:64I('L*"0EI9B`H:'1M;"YM871C:"A(5$U,07)E82Y215]H96%D
M*2D*"0D)=&AI<RY?9&]C+F=E=$5L96UE;G1S0GE486=.86UE*")H96%D(BE;
M,%TN:6YN97)(5$U,(#T@4F5G17AP+B0Q.PH)"6EF("AH=&UL+FUA=&-H*$A4
M34Q!<F5A+E)%7V)O9'DI*0H)"0ET:&ES+E]D;V,N9V5T16QE;65N='-">51A
M9TYA;64H(F)O9'DB*5LP72YI;FYE<DA434P@/2!296=%>'`N)#$["@E](&5L
M<V4@>PH)"79A<B!H=&UL7W)E(#T@+SQH=&UL/B@H+GQ<;BDJ/RD\7"]H=&UL
M/B]I.PH)"6AT;6P@/2!H=&UL+G)E<&QA8V4H:'1M;%]R92P@(B0Q(BD["@D)
M=&AI<RY?9&]C+F]P96XH*3L*"0ET:&ES+E]D;V,N=W)I=&4H:'1M;"D["@D)
M=&AI<RY?9&]C+F-L;W-E*"D["@D)=&AI<RY?9&]C+F)O9'DN8V]N=&5N=$5D
M:71A8FQE(#T@=')U93L*"0ER971U<FX@=')U93L*"7T*?3L*"B\J*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH*
M("H@($-A=&5G;W)Y.B!03%5'24Y3"B`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHO"@HO+R!#<F5A=&4@=&AE
M('-P96-I9FEE9"!P;'5G:6X@86YD(')E9VES=&5R(&ET('=I=&@@=&AI<R!(
M5$U,07)E80I(5$U,07)E82YP<F]T;W1Y<&4N<F5G:7-T97)0;'5G:6X@/2!F
M=6YC=&EO;B@I('L*"79A<B!P;'5G:6X@/2!A<F=U;65N='-;,%T["@EV87(@
M87)G<R`](%M=.PH)9F]R("AV87(@:2`](#$[(&D@/"!A<F=U;65N=',N;&5N
M9W1H.R`K*VDI"@D)87)G<RYP=7-H*&%R9W5M96YT<UMI72D["@ET:&ES+G)E
M9VES=&5R4&QU9VEN,BAP;'5G:6XL(&%R9W,I.PI].PH*+R\@=&AI<R!I<R!T
M:&4@=F%R:6%N="!O9B!T:&4@9G5N8W1I;VX@86)O=F4@=VAE<F4@=&AE('!L
M=6=I;B!A<F=U;65N=',@87)E"B\O(&%L<F5A9'D@<&%C:V5D(&EN(&%N(&%R
M<F%Y+B`@17AT97)N86QL>2P@:70@<VAO=6QD(&)E(&]N;'D@=7-E9"!I;B!T
M:&4*+R\@9G5L;"US8W)E96X@961I=&]R(&-O9&4L(&EN(&]R9&5R('1O(&EN
M:71I86QI>F4@<&QU9VEN<R!W:71H('1H92!S86UE"B\O('!A<F%M971E<G,@
M87,@:6X@=&AE(&]P96YE<B!W:6YD;W<N"DA434Q!<F5A+G!R;W1O='EP92YR
M96=I<W1E<E!L=6=I;C(@/2!F=6YC=&EO;BAP;'5G:6XL(&%R9W,I('L*"6EF
M("AT>7!E;V8@<&QU9VEN(#T](")S=')I;F<B*0H)"7!L=6=I;B`](&5V86PH
M<&QU9VEN*3L*"6EF("AT>7!E;V8@<&QU9VEN(#T](")U;F1E9FEN960B*2![
M"@D)+RH@1DE8344Z(%1H:7,@<VAO=6QD(&YE=F5R(&AA<'!E;BX@0G5T('=H
M>2!D;V5S(&ET(&1O/R`J+PH)"7)E='5R;B!F86QS93L*"7T*"79A<B!O8FH@
M/2!N97<@<&QU9VEN*'1H:7,L(&%R9W,I.PH):68@*&]B:BD@>PH)"79A<B!C
M;&]N92`]('M].PH)"79A<B!I;F9O(#T@<&QU9VEN+E]P;'5G:6Y);F9O.PH)
M"69O<B`H=F%R(&D@:6X@:6YF;RD*"0D)8VQO;F5;:5T@/2!I;F9O6VE=.PH)
M"6-L;VYE+FEN<W1A;F-E(#T@;V)J.PH)"6-L;VYE+F%R9W,@/2!A<F=S.PH)
M"71H:7,N<&QU9VEN<UMP;'5G:6XN7W!L=6=I;DEN9F\N;F%M95T@/2!C;&]N
M93L*"7T@96QS90H)"6%L97)T*")#86XG="!R96=I<W1E<B!P;'5G:6X@(B`K
M('!L=6=I;BYT;U-T<FEN9R@I("L@(BXB*3L*?3L*"B\O('-T871I8R!F=6YC
M=&EO;B!T:&%T(&QO861S('1H92!R97%U:7)E9"!P;'5G:6X@86YD(&QA;F<@
M9FEL92P@8F%S960@;VX@=&AE"B\O(&QA;F=U86=E(&QO861E9"!A;')E861Y
M(&9O<B!(5$U,07)E82X@(%EO=2!B971T97(@;6%K92!S=7)E('1H870@=&AE
M('!L=6=I;@HO+R!?:&%S7R!T:&%T(&QA;F=U86=E+"!O=&AE<G=I<V4@<VAI
M="!M:6=H="!H87!P96X@.RTI"DA434Q!<F5A+F=E=%!L=6=I;D1I<B`](&9U
M;F-T:6]N*'!L=6=I;DYA;64I('L*"7)E='5R;B!?961I=&]R7W5R;"`K(")P
M;'5G:6YS+R(@*R!P;'5G:6Y.86UE.PI].PH*2%1-3$%R96$N;&]A9%!L=6=I
M;B`](&9U;F-T:6]N*'!L=6=I;DYA;64I('L*"79A<B!D:7(@/2!T:&ES+F=E
M=%!L=6=I;D1I<BAP;'5G:6Y.86UE*3L*"79A<B!P;'5G:6X@/2!P;'5G:6Y.
M86UE+G)E<&QA8V4H+RA;82UZ72DH6T$M6ETI*%MA+7I=*2]G+`H)"0D)"69U
M;F-T:6]N("AS='(L(&PQ+"!L,BP@;#,I('L*"0D)"0D)<F5T=7)N(&PQ("L@
M(BTB("L@;#(N=&],;W=E<D-A<V4H*2`K(&PS.PH)"0D)"7TI+G1O3&]W97)#
M87-E*"D@*R`B+FIS(CL*"79A<B!P;'5G:6Y?9FEL92`](&1I<B`K("(O(B`K
M('!L=6=I;CL*"79A<B!P;'5G:6Y?;&%N9R`](&1I<B`K("(O;&%N9R\B("L@
M7V5D:71O<E]L86YG("L@(BYJ<R(["@DO+V1O8W5M96YT+G=R:71E*"(\<V-R
M:7!T('1Y<&4])W1E>'0O:F%V87-C<FEP="<@<W)C/2<B("L@<&QU9VEN7V9I
M;&4@*R`B)SX\+W-C<FEP=#XB*3L*"2\O9&]C=6UE;G0N=W)I=&4H(CQS8W)I
M<'0@='EP93TG=&5X="]J879A<V-R:7!T)R!S<F,])R(@*R!P;'5G:6Y?;&%N
M9R`K("(G/CPO<V-R:7!T/B(I.PH)=&AI<RYL;V%D4V-R:7!T*'!L=6=I;E]F
M:6QE*3L*"71H:7,N;&]A9%-C<FEP="AP;'5G:6Y?;&%N9RD["GT["@I(5$U,
M07)E82YL;V%D4W1Y;&4@/2!F=6YC=&EO;BAS='EL92P@<&QU9VEN*2!["@EV
M87(@=7)L(#T@7V5D:71O<E]U<FP@?'P@)R<["@EI9B`H='EP96]F('!L=6=I
M;B`A/2`B=6YD969I;F5D(BD@>PH)"75R;"`K/2`B<&QU9VEN<R\B("L@<&QU
M9VEN("L@(B\B.PH)?0H)=7)L("L]('-T>6QE.PH):68@*"]>7"\O+G1E<W0H
M<W1Y;&4I*0H)"75R;"`]('-T>6QE.PH)=F%R(&AE860@/2!D;V-U;65N="YG
M971%;&5M96YT<T)Y5&%G3F%M92@B:&5A9"(I6S!=.PH)=F%R(&QI;FL@/2!D
M;V-U;65N="YC<F5A=&5%;&5M96YT*")L:6YK(BD["@EL:6YK+G)E;"`](")S
M='EL97-H965T(CL*"6QI;FLN:')E9B`]('5R;#L*"6AE860N87!P96YD0VAI
M;&0H;&EN:RD["@DO+V1O8W5M96YT+G=R:71E*"(\<W1Y;&4@='EP93TG=&5X
M="]C<W,G/D!I;7!O<G0@=7)L*"(@*R!U<FP@*R`B*3L\+W-T>6QE/B(I.PI]
M.PI(5$U,07)E82YL;V%D4W1Y;&4H='EP96]F(%]E9&ET;W)?8W-S(#T](")S
M=')I;F<B(#\@7V5D:71O<E]C<W,@.B`B:'1M;&%R96$N8W-S(BD["@HO*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ"B`J("!#871E9V]R>3H@141)5$]2(%5424Q)5$E%4PH@*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ+PH*
M2%1-3$%R96$N<')O=&]T>7!E+F1E8G5G5')E92`](&9U;F-T:6]N*"D@>PH)
M=F%R('1A(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@B=&5X=&%R96$B*3L*
M"71A+G-T>6QE+G=I9'1H(#T@(C$P,"4B.PH)=&$N<W1Y;&4N:&5I9VAT(#T@
M(C(P96TB.PH)=&$N=F%L=64@/2`B(CL*"69U;F-T:6]N(&1E8G5G*&EN9&5N
M="P@<W1R*2!["@D)9F]R("@[("TM:6YD96YT(#X](#`[*0H)"0ET82YV86QU
M92`K/2`B("(["@D)=&$N=F%L=64@*ST@<W1R("L@(EQN(CL*"7T["@EF=6YC
M=&EO;B!?9'0H<F]O="P@;&5V96PI('L*"0EV87(@=&%G(#T@<F]O="YT86=.
M86UE+G1O3&]W97)#87-E*"DL(&D["@D)=F%R(&YS(#T@2%1-3$%R96$N:7-?
M:64@/R!R;V]T+G-C;W!E3F%M92`Z(')O;W0N<')E9FEX.PH)"61E8G5G*&QE
M=F5L+"`B+2`B("L@=&%G("L@(B!;(B`K(&YS("L@(ETB*3L*"0EF;W(@*&D@
M/2!R;V]T+F9I<G-T0VAI;&0[(&D[(&D@/2!I+FYE>'13:6)L:6YG*0H)"0EI
M9B`H:2YN;V1E5'EP92`]/2`Q*0H)"0D)7V1T*&DL(&QE=F5L("L@,BD["@E]
M.PH)7V1T*'1H:7,N7V1O8RYB;V1Y+"`P*3L*"61O8W5M96YT+F)O9'DN87!P
M96YD0VAI;&0H=&$I.PI].PH*2%1-3$%R96$N9V5T26YN97)497AT(#T@9G5N
M8W1I;VXH96PI('L*"79A<B!T>'0@/2`G)RP@:3L*"69O<B`H:2`](&5L+F9I
M<G-T0VAI;&0[(&D[(&D@/2!I+FYE>'13:6)L:6YG*2!["@D):68@*&DN;F]D
M951Y<&4@/3T@,RD*"0D)='AT("L](&DN9&%T83L*"0EE;'-E(&EF("AI+FYO
M9&54>7!E(#T](#$I"@D)"71X="`K/2!(5$U,07)E82YG971);FYE<E1E>'0H
M:2D["@E]"@ER971U<FX@='AT.PI].PH*2%1-3$%R96$N<')O=&]T>7!E+E]W
M;W)D0VQE86X@/2!F=6YC=&EO;B@I('L*"79A<@H)"65D:71O<B`]('1H:7,L
M"@D)<W1A=',@/2!["@D)"65M<'1Y7W1A9W,@.B`P+`H)"0EM<V]?8VQA<W,@
M(#H@,"P*"0D);7-O7W-T>6QE("`Z(#`L"@D)"6US;U]X;6QE;"`@.B`P+`H)
M"0EO<FEG7VQE;B`@(#H@=&AI<RY?9&]C+F)O9'DN:6YN97)(5$U,+FQE;F=T
M:"P*"0D)5"`@("`@("`@("`Z("AN97<@1&%T92@I*2YG9714:6UE*"D*"0E]
M+`H)"7-T871S7W1X="`]('L*"0D)96UP='E?=&%G<R`Z(")%;7!T>2!T86=S
M(')E;6]V960Z("(L"@D)"6US;U]C;&%S<R`@.B`B35-/(&-L87-S(&YA;65S
M(')E;6]V960Z("(L"@D)"6US;U]S='EL92`@.B`B35-/(&EN;&EN92!S='EL
M92!R96UO=F5D.B`B+`H)"0EM<V]?>&UL96P@(#H@(DU33R!834P@96QE;65N
M=',@<W1R:7!P960Z("(*"0E].PH)9G5N8W1I;VX@<VAO=U-T871S*"D@>PH)
M"79A<B!T>'0@/2`B2%1-3$%R96$@=V]R9"!C;&5A;F5R('-T871S.B!<;EQN
M(CL*"0EF;W(@*'9A<B!I(&EN('-T871S*0H)"0EI9B`H<W1A='-?='AT6VE=
M*0H)"0D)='AT("L]('-T871S7W1X=%MI72`K('-T871S6VE=("L@(EQN(CL*
M"0ET>'0@*ST@(EQN26YI=&EA;"!D;V-U;65N="!L96YG=&@Z("(@*R!S=&%T
M<RYO<FEG7VQE;B`K(")<;B(["@D)='AT("L](")&:6YA;"!D;V-U;65N="!L
M96YG=&@Z("(@*R!E9&ET;W(N7V1O8RYB;V1Y+FEN;F5R2%1-3"YL96YG=&@@
M*R`B7&XB.PH)"71X="`K/2`B0VQE86XM=7`@=&]O:R`B("L@*"@H;F5W($1A
M=&4H*2DN9V5T5&EM92@I("T@<W1A=',N5"D@+R`Q,#`P*2`K("(@<V5C;VYD
M<R(["@D)86QE<G0H='AT*3L*"7T["@EF=6YC=&EO;B!C;&5A<D-L87-S*&YO
M9&4I('L*"0EV87(@;F5W8R`](&YO9&4N8VQA<W-.86UE+G)E<&QA8V4H+RA>
M?%QS*6US;RXJ/RA<<WPD*2]I9RP@)R`G*3L*"0EI9B`H;F5W8R`A/2!N;V1E
M+F-L87-S3F%M92D@>PH)"0EN;V1E+F-L87-S3F%M92`](&YE=V,["@D)"6EF
M("@A+UQ3+RYT97-T*&YO9&4N8VQA<W-.86UE*2D@>PH)"0D);F]D92YR96UO
M=F5!='1R:6)U=&4H(F-L87-S3F%M92(I.PH)"0D)*RMS=&%T<RYM<V]?8VQA
M<W,["@D)"7T*"0E]"@E].PH)9G5N8W1I;VX@8VQE87)3='EL92AN;V1E*2![
M"B`)"79A<B!D96-L87)A=&EO;G,@/2!N;V1E+G-T>6QE+F-S<U1E>'0N<W!L
M:70H+UQS*CM<<RHO*3L*"0EF;W(@*'9A<B!I(#T@9&5C;&%R871I;VYS+FQE
M;F=T:#L@+2UI(#X](#`[*0H)"0EI9B`H+UYM<V]\7G1A8BUS=&]P<R]I+G1E
M<W0H9&5C;&%R871I;VYS6VE=*2!\?`H)"0D@("`@+UYM87)G:6Y<<RHZ7',J
M,"XN7',K,"XN7',K,"XN+VDN=&5S="AD96-L87)A=&EO;G-;:5TI*2!["@D)
M"0DK*W-T871S+FUS;U]S='EL93L*"0D)"61E8VQA<F%T:6]N<RYS<&QI8V4H
M:2P@,2D["@D)"7T*"0EN;V1E+G-T>6QE+F-S<U1E>'0@/2!D96-L87)A=&EO
M;G,N:F]I;B@B.R`B*3L*"7T["@EF=6YC=&EO;B!S=')I<%1A9RAE;"D@>PH)
M"6EF("A(5$U,07)E82YI<U]I92D*"0D)96PN;W5T97)(5$U,(#T@2%1-3$%R
M96$N:'1M;$5N8V]D92AE;"YI;FYE<E1E>'0I.PH)"65L<V4@>PH)"0EV87(@
M='AT(#T@9&]C=6UE;G0N8W)E871E5&5X=$YO9&4H2%1-3$%R96$N9V5T26YN
M97)497AT*&5L*2D["@D)"65L+G!A<F5N=$YO9&4N:6YS97)T0F5F;W)E*'1X
M="P@96PI.PH)"0EE;"YP87)E;G1.;V1E+G)E;6]V94-H:6QD*&5L*3L*"0E]
M"@D)*RMS=&%T<RYM<V]?>&UL96P["@E].PH)9G5N8W1I;VX@8VAE8VM%;7!T
M>2AE;"D@>PH)"6EF("@O7BAA?'-P86Y\8GQS=')O;F=\:7QE;7QF;VYT*20O
M:2YT97-T*&5L+G1A9TYA;64I("8F"@D)("`@("%E;"YF:7)S=$-H:6QD*2![
M"@D)"65L+G!A<F5N=$YO9&4N<F5M;W9E0VAI;&0H96PI.PH)"0DK*W-T871S
M+F5M<'1Y7W1A9W,["@D)?0H)?3L*"69U;F-T:6]N('!A<G-E5')E92AR;V]T
M*2!["@D)=F%R('1A9R`](')O;W0N=&%G3F%M92YT;TQO=V5R0V%S92@I+"!I
M+"!N97AT.PH)"6EF("@H2%1-3$%R96$N:7-?:64@)B8@<F]O="YS8V]P94YA
M;64@(3T@)TA434PG*2!\?"`H(4A434Q!<F5A+FES7VEE("8F("\Z+RYT97-T
M*'1A9RDI*2!["@D)"7-T<FEP5&%G*')O;W0I.PH)"0ER971U<FX@9F%L<V4[
M"@D)?2!E;'-E('L*"0D)8VQE87)#;&%S<RAR;V]T*3L*"0D)8VQE87)3='EL
M92AR;V]T*3L*"0D)9F]R("AI(#T@<F]O="YF:7)S=$-H:6QD.R!I.R!I(#T@
M;F5X="D@>PH)"0D);F5X="`](&DN;F5X=%-I8FQI;F<["@D)"0EI9B`H:2YN
M;V1E5'EP92`]/2`Q("8F('!A<G-E5')E92AI*2D*"0D)"0EC:&5C:T5M<'1Y
M*&DI.PH)"0E]"@D)?0H)"7)E='5R;B!T<G5E.PH)?3L*"7!A<G-E5')E92AT
M:&ES+E]D;V,N8F]D>2D["@DO+R!S:&]W4W1A=',H*3L*"2\O('1H:7,N9&5B
M=6=4<F5E*"D["@DO+R!T:&ES+G-E=$A434PH=&AI<RYG971(5$U,*"DI.PH)
M+R\@=&AI<RYS971(5$U,*'1H:7,N9V5T26YN97)(5$U,*"DI.PH)+R\@=&AI
M<RYF;W)C95)E9')A=R@I.PH)=&AI<RYU<&1A=&54;V]L8F%R*"D["GT["@I(
M5$U,07)E82YP<F]T;W1Y<&4N9F]R8V52961R87<@/2!F=6YC=&EO;B@I('L*
M"71H:7,N7V1O8RYB;V1Y+G-T>6QE+G9I<VEB:6QI='D@/2`B:&ED9&5N(CL*
M"71H:7,N7V1O8RYB;V1Y+G-T>6QE+G9I<VEB:6QI='D@/2`B=FES:6)L92([
M"@DO+R!T:&ES+E]D;V,N8F]D>2YI;FYE<DA434P@/2!T:&ES+F=E=$EN;F5R
M2%1-3"@I.PI].PH*+R\@9F]C=7-E<R!T:&4@:69R86UE('=I;F1O=RX@(')E
M='5R;G,@82!R969E<F5N8V4@=&\@=&AE(&5D:71O<B!D;V-U;65N="X*2%1-
M3$%R96$N<')O=&]T>7!E+F9O8W5S161I=&]R(#T@9G5N8W1I;VXH*2!["@ES
M=VET8V@@*'1H:7,N7V5D:71-;V1E*2!["@D@("`@+R\@;F]T:6-E('1H92!T
M<GD@>R`N+BX@?2!C871C:"!B;&]C:R!T;R!A=F]I9"!S;VUE(')A<F4@97AC
M97!T:6]N<R!I;B!&:7)E1F]X"@D@("`@+R\@*'!E<FAA<',@86QS;R!I;B!O
M=&AE<B!'96-K;R!B<F]W<V5R<RDN($UA;G5A;"!F;V-U<R!B>2!U<V5R(&ES
M(')E<75I<F5D(&EN"B`@("`@("`@+R\@8V%S92!O9B!A;B!E<G)O<BX@4V]M
M96)O9'D@:&%S(&%N(&ED96$_"@D@("`@8V%S92`B=WES:7=Y9R(@.B!T<GD@
M>R!T:&ES+E]I9G)A;64N8V]N=&5N=%=I;F1O=RYF;V-U<R@I('T@8V%T8V@@
M*&4I('M](&)R96%K.PH)("`@(&-A<V4@(G1E>'1M;V1E(CH@=')Y('L@=&AI
M<RY?=&5X=$%R96$N9F]C=7,H*2!](&-A=&-H("AE*2![?2!B<F5A:SL*"2`@
M("!D969A=6QT"2`@(#H@86QE<G0H(D524D]2.B!M;V1E("(@*R!T:&ES+E]E
M9&ET36]D92`K("(@:7,@;F]T(&1E9FEN960B*3L*"7T*"7)E='5R;B!T:&ES
M+E]D;V,["GT["@HO+R!T86ME<R!A('-N87!S:&]T(&]F('1H92!C=7)R96YT
M('1E>'0@*&9O<B!U;F1O*0I(5$U,07)E82YP<F]T;W1Y<&4N7W5N9&]486ME
M4VYA<'-H;W0@/2!F=6YC=&EO;B@I('L*"2LK=&AI<RY?=6YD;U!O<SL*"6EF
M("AT:&ES+E]U;F1O4&]S(#X]('1H:7,N8V]N9FEG+G5N9&]3=&5P<RD@>PH)
M"2\O(')E;6]V92!T:&4@9FER<W0@96QE;65N=`H)"71H:7,N7W5N9&]1=65U
M92YS:&EF="@I.PH)"2TM=&AI<RY?=6YD;U!O<SL*"7T*"2\O('5S92!T:&4@
M9F%S=&5D(&UE=&AO9"`H9V5T26YN97)(5$U,*3L*"79A<B!T86ME(#T@=')U
M93L*"79A<B!T>'0@/2!T:&ES+F=E=$EN;F5R2%1-3"@I.PH):68@*'1H:7,N
M7W5N9&]0;W,@/B`P*0H)"71A:V4@/2`H=&AI<RY?=6YD;U%U975E6W1H:7,N
M7W5N9&]0;W,@+2`Q72`A/2!T>'0I.PH):68@*'1A:V4I('L*"0ET:&ES+E]U
M;F1O475E=65;=&AI<RY?=6YD;U!O<UT@/2!T>'0["@E](&5L<V4@>PH)"71H
M:7,N7W5N9&]0;W,M+3L*"7T*?3L*"DA434Q!<F5A+G!R;W1O='EP92YU;F1O
M(#T@9G5N8W1I;VXH*2!["@EI9B`H=&AI<RY?=6YD;U!O<R`^(#`I('L*"0EV
M87(@='AT(#T@=&AI<RY?=6YD;U%U975E6RTM=&AI<RY?=6YD;U!O<UT["@D)
M:68@*'1X="D@=&AI<RYS971(5$U,*'1X="D["@D)96QS92`K*W1H:7,N7W5N
M9&]0;W,["@E]"GT["@I(5$U,07)E82YP<F]T;W1Y<&4N<F5D;R`](&9U;F-T
M:6]N*"D@>PH):68@*'1H:7,N7W5N9&]0;W,@/"!T:&ES+E]U;F1O475E=64N
M;&5N9W1H("T@,2D@>PH)"79A<B!T>'0@/2!T:&ES+E]U;F1O475E=65;*RMT
M:&ES+E]U;F1O4&]S73L*"0EI9B`H='AT*2!T:&ES+G-E=$A434PH='AT*3L*
M"0EE;'-E("TM=&AI<RY?=6YD;U!O<SL*"7T*?3L*"B\O('5P9&%T97,@96YA
M8FQE9"]D:7-A8FQE+V%C=&EV92!S=&%T92!O9B!T:&4@=&]O;&)A<B!E;&5M
M96YT<PI(5$U,07)E82YP<F]T;W1Y<&4N=7!D871E5&]O;&)A<B`](&9U;F-T
M:6]N*&YO4W1A='5S*2!["@EV87(@9&]C(#T@=&AI<RY?9&]C.PH)=F%R('1E
M>'0@/2`H=&AI<RY?961I=$UO9&4@/3T@(G1E>'1M;V1E(BD["@EV87(@86YC
M97-T;W)S(#T@;G5L;#L*"6EF("@A=&5X="D@>PH)"6%N8V5S=&]R<R`]('1H
M:7,N9V5T06QL06YC97-T;W)S*"D["@D):68@*'1H:7,N8V]N9FEG+G-T871U
M<T)A<B`F)B`A;F]3=&%T=7,I('L*"0D)=&AI<RY?<W1A='5S0F%R5')E92YI
M;FYE<DA434P@/2!(5$U,07)E82Y),3A.+FUS9ULB4&%T:")=("L@(CH@(CL@
M+R\@8VQE87(*"0D)9F]R("AV87(@:2`](&%N8V5S=&]R<RYL96YG=&@[("TM
M:2`^/2`P.RD@>PH)"0D)=F%R(&5L(#T@86YC97-T;W)S6VE=.PH)"0D):68@
M*"%E;"D@>PH)"0D)"2\O(&AE;&P@:VYO=W,@=VAY('=E(&=E="!H97)E.R!T
M:&ES"@D)"0D)+R\@8V]U;&0@8F4@82!C;&%S<VEC(&5X86UP;&4@;V8@=VAY
M"@D)"0D)+R\@:70G<R!G;V]D('1O(&-H96-K(&9O<B!C;VYD:71I;VYS"@D)
M"0D)+R\@=&AA="!A<F4@:6UP;W-S:6)L92!T;R!H87!P96X@.RTI"@D)"0D)
M8V]N=&EN=64["@D)"0E]"@D)"0EV87(@82`](&1O8W5M96YT+F-R96%T945L
M96UE;G0H(F$B*3L*"0D)"6$N:')E9B`]("(C(CL*"0D)"6$N96P@/2!E;#L*
M"0D)"6$N961I=&]R(#T@=&AI<SL*"0D)"6$N;VYC;&EC:R`](&9U;F-T:6]N
M*"D@>PH)"0D)"71H:7,N8FQU<B@I.PH)"0D)"71H:7,N961I=&]R+G-E;&5C
M=$YO9&5#;VYT96YT<RAT:&ES+F5L*3L*"0D)"0ET:&ES+F5D:71O<BYU<&1A
M=&54;V]L8F%R*'1R=64I.PH)"0D)"7)E='5R;B!F86QS93L*"0D)"7T["@D)
M"0EA+F]N8V]N=&5X=&UE;G4@/2!F=6YC=&EO;B@I('L*"0D)"0DO+R!43T1/
M.B!A9&0@8V]N=&5X="!M96YU(&AE<F4*"0D)"0ET:&ES+F)L=7(H*3L*"0D)
M"0EV87(@:6YF;R`]("));FQI;F4@<W1Y;&4Z7&Y<;B(["@D)"0D):6YF;R`K
M/2!T:&ES+F5L+G-T>6QE+F-S<U1E>'0N<W!L:70H+SM<<RHO*2YJ;VEN*"([
M7&XB*3L*"0D)"0EA;&5R="AI;F9O*3L*"0D)"0ER971U<FX@9F%L<V4["@D)
M"0E].PH)"0D)=F%R('1X="`](&5L+G1A9TYA;64N=&],;W=E<D-A<V4H*3L*
M"0D)"6$N=&ET;&4@/2!E;"YS='EL92YC<W-497AT.PH)"0D):68@*&5L+FED
M*2!["@D)"0D)='AT("L]("(C(B`K(&5L+FED.PH)"0D)?0H)"0D):68@*&5L
M+F-L87-S3F%M92D@>PH)"0D)"71X="`K/2`B+B(@*R!E;"YC;&%S<TYA;64[
M"@D)"0E]"@D)"0EA+F%P<&5N9$-H:6QD*&1O8W5M96YT+F-R96%T951E>'1.
M;V1E*'1X="DI.PH)"0D)=&AI<RY?<W1A='5S0F%R5')E92YA<'!E;F1#:&EL
M9"AA*3L*"0D)"6EF("AI("$](#`I('L*"0D)"0ET:&ES+E]S=&%T=7-"87)4
M<F5E+F%P<&5N9$-H:6QD*&1O8W5M96YT+F-R96%T951E>'1.;V1E*%-T<FEN
M9RYF<F]M0VAA<D-O9&4H,'AB8BDI*3L*"0D)"7T*"0D)?0H)"7T*"7T*"@EF
M;W(@*'9A<B!I(&EN('1H:7,N7W1O;VQB87)/8FIE8W1S*2!["@D)=F%R(&)T
M;B`]('1H:7,N7W1O;VQB87)/8FIE8W1S6VE=.PH)"79A<B!C;60@/2!I.PH)
M"79A<B!I;D-O;G1E>'0@/2!T<G5E.PH)"6EF("AB=&XN8V]N=&5X="`F)B`A
M=&5X="D@>PH)"0EI;D-O;G1E>'0@/2!F86QS93L*"0D)=F%R(&-O;G1E>'0@
M/2!B=&XN8V]N=&5X=#L*"0D)=F%R(&%T=')S(#T@6UT["@D)"6EF("@O*"XJ
M*5Q;*"XJ/RE<72\N=&5S="AC;VYT97AT*2D@>PH)"0D)8V]N=&5X="`](%)E
M9T5X<"XD,3L*"0D)"6%T=')S(#T@4F5G17AP+B0R+G-P;&ET*"(L(BD["@D)
M"7T*"0D)8V]N=&5X="`](&-O;G1E>'0N=&],;W=E<D-A<V4H*3L*"0D)=F%R
M(&UA=&-H(#T@*&-O;G1E>'0@/3T@(BHB*3L*"0D)9F]R("AV87(@:R`](#`[
M(&L@/"!A;F-E<W1O<G,N;&5N9W1H.R`K*VLI('L*"0D)"6EF("@A86YC97-T
M;W)S6VM=*2!["@D)"0D)+R\@=&AE(&EM<&]S<VEB;&4@<F5A;&QY(&AA<'!E
M;G,N"@D)"0D)8V]N=&EN=64["@D)"0E]"@D)"0EI9B`H;6%T8V@@?'P@*&%N
M8V5S=&]R<UMK72YT86=.86UE+G1O3&]W97)#87-E*"D@/3T@8V]N=&5X="DI
M('L*"0D)"0EI;D-O;G1E>'0@/2!T<G5E.PH)"0D)"69O<B`H=F%R(&MA(#T@
M,#L@:V$@/"!A='1R<RYL96YG=&@[("LK:V$I('L*"0D)"0D):68@*"%E=F%L
M*")A;F-E<W1O<G-;:UTN(B`K(&%T=')S6VMA72DI('L*"0D)"0D)"6EN0V]N
M=&5X="`](&9A;'-E.PH)"0D)"0D)8G)E86L["@D)"0D)"7T*"0D)"0E]"@D)
M"0D):68@*&EN0V]N=&5X="D@>PH)"0D)"0EB<F5A:SL*"0D)"0E]"@D)"0E]
M"@D)"7T*"0E]"@D)8G1N+G-T871E*")E;F%B;&5D(BP@*"%T97AT('Q\(&)T
M;BYT97AT*2`F)B!I;D-O;G1E>'0I.PH)"6EF("AT>7!E;V8@8VUD(#T](")F
M=6YC=&EO;B(I('L*"0D)8V]N=&EN=64["@D)?0H)"2\O(&QO;VLM:70M=7`@
M:6X@=&AE(&-U<W1O;2!D<F]P9&]W;B!B;WAE<PH)"79A<B!D<F]P9&]W;B`]
M('1H:7,N8V]N9FEG+F-U<W1O;5-E;&5C='-;8VUD73L*"0EI9B`H*"%T97AT
M('Q\(&)T;BYT97AT*2`F)B`H='EP96]F(&1R;W!D;W=N("$](")U;F1E9FEN
M960B*2D@>PH)"0ED<F]P9&]W;BYR969R97-H*'1H:7,I.PH)"0EC;VYT:6YU
M93L*"0E]"@D)<W=I=&-H("AC;60I('L*"0D@("`@8V%S92`B9F]N=&YA;64B
M.@H)"2`@("!C87-E(")F;VYT<VEZ92(Z"@D)("`@(&-A<V4@(F9O<FUA=&)L
M;V-K(CH*"0D):68@*"%T97AT*2!T<GD@>PH)"0D)=F%R('9A;'5E(#T@*"(B
M("L@9&]C+G%U97)Y0V]M;6%N9%9A;'5E*&-M9"DI+G1O3&]W97)#87-E*"D[
M"@D)"0EI9B`H(79A;'5E*2!["@D)"0D)8G1N+F5L96UE;G0N<V5L96-T961)
M;F1E>"`](#`["@D)"0D)8G)E86L["@D)"0E]"@D)"0DO+R!(04-+("TM(')E
M=')I979E('1H92!C;VYF:6<@;W!T:6]N(&9O<B!T:&ES"@D)"0DO+R!C;VUB
M;R!B;W@N("!792!R96QY(&]N('1H92!F86-T('1H870@=&AE"@D)"0DO+R!V
M87)I86)L92!I;B!C;VYF:6<@:&%S('1H92!S86UE(&YA;64@87,*"0D)"2\O
M(&)U='1O;B!N86UE(&EN('1H92!T;V]L8F%R+@H)"0D)=F%R(&]P=&EO;G,@
M/2!T:&ES+F-O;F9I9UMC;61=.PH)"0D)=F%R(&L@/2`P.PH)"0D)9F]R("AV
M87(@:B!I;B!O<'1I;VYS*2!["@D)"0D)+R\@1DE8344Z('1H92!F;VQL;W=I
M;F<@;&EN92!I<R!S8V%R>2X*"0D)"0EI9B`H*&HN=&],;W=E<D-A<V4H*2`]
M/2!V86QU92D@?'P*"0D)"0D@("`@*&]P=&EO;G-;:ETN<W5B<W1R*#`L('9A
M;'5E+FQE;F=T:"DN=&],;W=E<D-A<V4H*2`]/2!V86QU92DI('L*"0D)"0D)
M8G1N+F5L96UE;G0N<V5L96-T961);F1E>"`](&L["@D)"0D)"71H<F]W(")O
M:R(["@D)"0D)?0H)"0D)"2LK:SL*"0D)"7T*"0D)"6)T;BYE;&5M96YT+G-E
M;&5C=&5D26YD97@@/2`P.PH)"0E](&-A=&-H*&4I('M].PH)"0EB<F5A:SL*
M"0D@("`@8V%S92`B=&5X=&EN9&EC871O<B(Z"@D)"6EF("@A=&5X="D@>PH)
M"0D)=')Y('MW:71H("AB=&XN96QE;65N="YS='EL92D@>PH)"0D)"6)A8VMG
M<F]U;F1#;VQO<B`]($A434Q!<F5A+E]M86ME0V]L;W(H"@D)"0D)"61O8RYQ
M=65R>4-O;6UA;F1686QU92A(5$U,07)E82YI<U]I92`_(")B86-K8V]L;W(B
M(#H@(FAI;&ET96-O;&]R(BDI.PH)"0D)"6EF("@O=')A;G-P87)E;G0O:2YT
M97-T*&)A8VMG<F]U;F1#;VQO<BDI('L*"0D)"0D)+R\@36]Z:6QL80H)"0D)
M"0EB86-K9W)O=6YD0V]L;W(@/2!(5$U,07)E82Y?;6%K94-O;&]R*&1O8RYQ
M=65R>4-O;6UA;F1686QU92@B8F%C:V-O;&]R(BDI.PH)"0D)"7T*"0D)"0EC
M;VQO<B`]($A434Q!<F5A+E]M86ME0V]L;W(H9&]C+G%U97)Y0V]M;6%N9%9A
M;'5E*")F;W)E8V]L;W(B*2D["@D)"0D)9F]N=$9A;6EL>2`](&1O8RYQ=65R
M>4-O;6UA;F1686QU92@B9F]N=&YA;64B*3L*"0D)"0EF;VYT5V5I9VAT(#T@
M9&]C+G%U97)Y0V]M;6%N9%-T871E*")B;VQD(BD@/R`B8F]L9"(@.B`B;F]R
M;6%L(CL*"0D)"0EF;VYT4W1Y;&4@/2!D;V,N<75E<GE#;VUM86YD4W1A=&4H
M(FET86QI8R(I(#\@(FET86QI8R(@.B`B;F]R;6%L(CL*"0D)"7U](&-A=&-H
M("AE*2!["@D)"0D)+R\@86QE<G0H92`K(")<;EQN(B`K(&-M9"D["@D)"0E]
M"@D)"7T*"0D)8G)E86L["@D)("`@(&-A<V4@(FAT;6QM;V1E(CH@8G1N+G-T
M871E*")A8W1I=F4B+"!T97AT*3L@8G)E86L["@D)("`@(&-A<V4@(FQE9G1T
M;W)I9VAT(CH*"0D@("`@8V%S92`B<FEG:'1T;VQE9G0B.@H)"0EV87(@96P@
M/2!T:&ES+F=E=%!A<F5N=$5L96UE;G0H*3L*"0D)=VAI;&4@*&5L("8F("%(
M5$U,07)E82YI<T)L;V-K16QE;65N="AE;"DI"@D)"0EE;"`](&5L+G!A<F5N
M=$YO9&4["@D)"6EF("AE;"D*"0D)"6)T;BYS=&%T92@B86-T:79E(BP@*&5L
M+G-T>6QE+F1I<F5C=&EO;B`]/2`H*&-M9"`]/2`B<FEG:'1T;VQE9G0B*2`_
M(")R=&PB(#H@(FQT<B(I*2D["@D)"6)R96%K.PH)"2`@("!D969A=6QT.@H)
M"0EC;60@/2!C;60N<F5P;&%C92@O*'5N*3]O<F1E<F5D;&ES="]I+"`B:6YS
M97)T)#%O<F1E<F5D;&ES="(I.PH)"0ET<GD@>PH)"0D)8G1N+G-T871E*")A
M8W1I=F4B+"`H(71E>'0@)B8@9&]C+G%U97)Y0V]M;6%N9%-T871E*&-M9"DI
M*3L*"0D)?2!C871C:"`H92D@>WT*"0E]"@E]"@DO+R!T86ME('5N9&\@<VYA
M<'-H;W1S"@EI9B`H=&AI<RY?8W5S=&]M56YD;R`F)B`A=&AI<RY?=&EM97)5
M;F1O*2!["@D)=&AI<RY?=6YD;U1A:V53;F%P<VAO="@I.PH)"79A<B!E9&ET
M;W(@/2!T:&ES.PH)"71H:7,N7W1I;65R56YD;R`]('-E=%1I;65O=70H9G5N
M8W1I;VXH*2!["@D)"65D:71O<BY?=&EM97)5;F1O(#T@;G5L;#L*"0E]+"!T
M:&ES+F-O;F9I9RYU;F1O5&EM96]U="D["@E]"@H)+R\@8VAE8VL@:68@86YY
M('!L=6=I;G,@:&%V92!R96=I<W1E<F5D(')E9G)E<V@@:&%N9&QE<G,*"69O
M<B`H=F%R(&D@:6X@=&AI<RYP;'5G:6YS*2!["@D)=F%R('!L=6=I;B`]('1H
M:7,N<&QU9VEN<UMI72YI;G-T86YC93L*"0EI9B`H='EP96]F('!L=6=I;BYO
M;E5P9&%T951O;VQB87(@/3T@(F9U;F-T:6]N(BD*"0D)<&QU9VEN+F]N57!D
M871E5&]O;&)A<B@I.PH)?0I].PH*+RHJ(%)E='5R;G,@82!N;V1E(&%F=&5R
M('=H:6-H('=E(&-A;B!I;G-E<G0@;W1H97(@;F]D97,L(&EN('1H92!C=7)R
M96YT"B`J('-E;&5C=&EO;BX@(%1H92!S96QE8W1I;VX@:7,@<F5M;W9E9"X@
M($ET('-P;&ET<R!A('1E>'0@;F]D92P@:68@;F5E9&5D+@H@*B\*2%1-3$%R
M96$N<')O=&]T>7!E+FEN<V5R=$YO9&5!=%-E;&5C=&EO;B`](&9U;F-T:6]N
M*'1O0F5);G-E<G1E9"D@>PH):68@*"%(5$U,07)E82YI<U]I92D@>PH)"79A
M<B!S96P@/2!T:&ES+E]G971396QE8W1I;VXH*3L*"0EV87(@<F%N9V4@/2!T
M:&ES+E]C<F5A=&5286YG92AS96PI.PH)"2\O(')E;6]V92!T:&4@8W5R<F5N
M="!S96QE8W1I;VX*"0ES96PN<F5M;W9E06QL4F%N9V5S*"D["@D)<F%N9V4N
M9&5L971E0V]N=&5N=',H*3L*"0EV87(@;F]D92`](')A;F=E+G-T87)T0V]N
M=&%I;F5R.PH)"79A<B!P;W,@/2!R86YG92YS=&%R=$]F9G-E=#L*"0ES=VET
M8V@@*&YO9&4N;F]D951Y<&4I('L*"0D@("`@8V%S92`S.B`O+R!.;V1E+E1%
M6%1?3D]$10H)"0DO+R!W92!H879E('1O('-P;&ET(&ET(&%T('1H92!C87)E
M="!P;W-I=&EO;BX*"0D):68@*'1O0F5);G-E<G1E9"YN;V1E5'EP92`]/2`S
M*2!["@D)"0DO+R!D;R!O<'1I;6EZ960@:6YS97)T:6]N"@D)"0EN;V1E+FEN
M<V5R=$1A=&$H<&]S+"!T;T)E26YS97)T960N9&%T82D["@D)"0ER86YG92`]
M('1H:7,N7V-R96%T95)A;F=E*"D["@D)"0ER86YG92YS971%;F0H;F]D92P@
M<&]S("L@=&]"94EN<V5R=&5D+FQE;F=T:"D["@D)"0ER86YG92YS9713=&%R
M="AN;V1E+"!P;W,@*R!T;T)E26YS97)T960N;&5N9W1H*3L*"0D)"7-E;"YA
M9&1286YG92AR86YG92D["@D)"7T@96QS92!["@D)"0EN;V1E(#T@;F]D92YS
M<&QI=%1E>'0H<&]S*3L*"0D)"79A<B!S96QN;V1E(#T@=&]"94EN<V5R=&5D
M.PH)"0D):68@*'1O0F5);G-E<G1E9"YN;V1E5'EP92`]/2`Q,2`O*B!.;V1E
M+D1/0U5-14Y47T9204=-14Y47TY/1$4@*B\I('L*"0D)"0ES96QN;V1E(#T@
M<V5L;F]D92YF:7)S=$-H:6QD.PH)"0D)?0H)"0D);F]D92YP87)E;G1.;V1E
M+FEN<V5R=$)E9F]R92AT;T)E26YS97)T960L(&YO9&4I.PH)"0D)=&AI<RYS
M96QE8W1.;V1E0V]N=&5N=',H<V5L;F]D92D["@D)"0ET:&ES+G5P9&%T951O
M;VQB87(H*3L*"0D)?0H)"0EB<F5A:SL*"0D@("`@8V%S92`Q.B`O+R!.;V1E
M+D5,14U%3E1?3D]$10H)"0EV87(@<V5L;F]D92`]('1O0F5);G-E<G1E9#L*
M"0D):68@*'1O0F5);G-E<G1E9"YN;V1E5'EP92`]/2`Q,2`O*B!.;V1E+D1/
M0U5-14Y47T9204=-14Y47TY/1$4@*B\I('L*"0D)"7-E;&YO9&4@/2!S96QN
M;V1E+F9I<G-T0VAI;&0["@D)"7T*"0D);F]D92YI;G-E<G1"969O<F4H=&]"
M94EN<V5R=&5D+"!N;V1E+F-H:6QD3F]D97-;<&]S72D["@D)"71H:7,N<V5L
M96-T3F]D94-O;G1E;G1S*'-E;&YO9&4I.PH)"0ET:&ES+G5P9&%T951O;VQB
M87(H*3L*"0D)8G)E86L["@D)?0H)?2!E;'-E('L*"0ER971U<FX@;G5L;#L)
M+R\@=&AI<R!F=6YC=&EO;B!N;W0@>65T('5S960@9F]R($E%(#Q&25A-13X*
M"7T*?3L*"B\O(%)E='5R;G,@=&AE(&1E97!E<W0@;F]D92!T:&%T(&-O;G1A
M:6YS(&)O=&@@96YD<&]I;G1S(&]F('1H92!S96QE8W1I;VXN"DA434Q!<F5A
M+G!R;W1O='EP92YG971087)E;G1%;&5M96YT(#T@9G5N8W1I;VXH*2!["@EV
M87(@<V5L(#T@=&AI<RY?9V5T4V5L96-T:6]N*"D["@EV87(@<F%N9V4@/2!T
M:&ES+E]C<F5A=&5286YG92AS96PI.PH):68@*$A434Q!<F5A+FES7VEE*2![
M"@D)<W=I=&-H("AS96PN='EP92D@>PH)"2`@("!C87-E(")497AT(CH*"0D@
M("`@8V%S92`B3F]N92(Z"@D)"2\O($ET('-E96US('1H870@979E;B!F;W(@
M<V5L96-T:6]N(&]F('1Y<&4@(DYO;F4B+`H)"0DO+R!T:&5R92!?:7-?(&$@
M<&%R96YT(&5L96UE;G0@86YD(&ET)W,@=F%L=64@:7,@;F]T"@D)"2\O(&]N
M;'D@8V]R<F5C="P@8G5T('9E<GD@:6UP;W)T86YT('1O('5S+B`@35-)12!I
M<PH)"0DO+R!C97)T86EN;'D@=&AE(&)U9V=I97-T(&)R;W=S97(@:6X@=&AE
M('=O<FQD(&%N9"!)"@D)"2\O('=O;F1E<BP@1V]D+"!H;W<@8V%N($5A<G1H
M('-T86YD(&ET/PH)"0ER971U<FX@<F%N9V4N<&%R96YT16QE;65N="@I.PH)
M"2`@("!C87-E(")#;VYT<F]L(CH*"0D)<F5T=7)N(')A;F=E+FET96TH,"D[
M"@D)("`@(&1E9F%U;'0Z"@D)"7)E='5R;B!T:&ES+E]D;V,N8F]D>3L*"0E]
M"@E](&5L<V4@=')Y('L*"0EV87(@<"`](')A;F=E+F-O;6UO;D%N8V5S=&]R
M0V]N=&%I;F5R.PH)"6EF("@A<F%N9V4N8V]L;&%P<V5D("8F(')A;F=E+G-T
M87)T0V]N=&%I;F5R(#T](')A;F=E+F5N9$-O;G1A:6YE<B`F)@H)"2`@("!R
M86YG92YS=&%R=$]F9G-E="`M(')A;F=E+F5N9$]F9G-E="`\/2`Q("8F(')A
M;F=E+G-T87)T0V]N=&%I;F5R+FAA<T-H:6QD3F]D97,H*2D*"0D)<"`](')A
M;F=E+G-T87)T0V]N=&%I;F5R+F-H:6QD3F]D97-;<F%N9V4N<W1A<G1/9F9S
M971=.PH)"2\J"@D)86QE<G0H<F%N9V4N<W1A<G1#;VYT86EN97(@*R`B.B(@
M*R!R86YG92YS=&%R=$]F9G-E="`K(")<;B(@*PH)"2`@("`@(')A;F=E+F5N
M9$-O;G1A:6YE<B`K("(Z(B`K(')A;F=E+F5N9$]F9G-E="D["@D)*B\*"0EW
M:&EL92`H<"YN;V1E5'EP92`]/2`S*2!["@D)"7`@/2!P+G!A<F5N=$YO9&4[
M"@D)?0H)"7)E='5R;B!P.PH)?2!C871C:"`H92D@>PH)"7)E='5R;B!N=6QL
M.PH)?0I].PH*+R\@4F5T=7)N<R!A;B!A<G)A>2!W:71H(&%L;"!T:&4@86YC
M97-T;W(@;F]D97,@;V8@=&AE('-E;&5C=&EO;BX*2%1-3$%R96$N<')O=&]T
M>7!E+F=E=$%L;$%N8V5S=&]R<R`](&9U;F-T:6]N*"D@>PH)=F%R('`@/2!T
M:&ES+F=E=%!A<F5N=$5L96UE;G0H*3L*"79A<B!A(#T@6UT["@EW:&EL92`H
M<"`F)B`H<"YN;V1E5'EP92`]/2`Q*2`F)B`H<"YT86=.86UE+G1O3&]W97)#
M87-E*"D@(3T@)V)O9'DG*2D@>PH)"6$N<'5S:"AP*3L*"0EP(#T@<"YP87)E
M;G1.;V1E.PH)?0H)82YP=7-H*'1H:7,N7V1O8RYB;V1Y*3L*"7)E='5R;B!A
M.PI].PH*+R\@4V5L96-T<R!T:&4@8V]N=&5N=',@:6YS:61E('1H92!G:79E
M;B!N;V1E"DA434Q!<F5A+G!R;W1O='EP92YS96QE8W1.;V1E0V]N=&5N=',@
M/2!F=6YC=&EO;BAN;V1E+"!P;W,I('L*"71H:7,N9F]C=7-%9&ET;W(H*3L*
M"71H:7,N9F]R8V52961R87<H*3L*"79A<B!R86YG93L*"79A<B!C;VQL87!S
M960@/2`H='EP96]F('!O<R`A/2`B=6YD969I;F5D(BD["@EI9B`H2%1-3$%R
M96$N:7-?:64I('L*"0ER86YG92`]('1H:7,N7V1O8RYB;V1Y+F-R96%T951E
M>'1286YG92@I.PH)"7)A;F=E+FUO=F54;T5L96UE;G1497AT*&YO9&4I.PH)
M"2AC;VQL87!S960I("8F(')A;F=E+F-O;&QA<'-E*'!O<RD["@D)<F%N9V4N
M<V5L96-T*"D["@E](&5L<V4@>PH)"79A<B!S96P@/2!T:&ES+E]G971396QE
M8W1I;VXH*3L*"0ER86YG92`]('1H:7,N7V1O8RYC<F5A=&5286YG92@I.PH)
M"7)A;F=E+G-E;&5C=$YO9&5#;VYT96YT<RAN;V1E*3L*"0DH8V]L;&%P<V5D
M*2`F)B!R86YG92YC;VQL87!S92AP;W,I.PH)"7-E;"YR96UO=F5!;&Q286YG
M97,H*3L*"0ES96PN861D4F%N9V4H<F%N9V4I.PH)?0I].PH*+RHJ($-A;&P@
M=&AI<R!F=6YC=&EO;B!T;R!I;G-E<G0@2%1-3"!C;V1E(&%T('1H92!C=7)R
M96YT('!O<VET:6]N+B`@270@9&5L971E<PH@*B!T:&4@<V5L96-T:6]N+"!I
M9B!A;GDN"B`J+PI(5$U,07)E82YP<F]T;W1Y<&4N:6YS97)T2%1-3"`](&9U
M;F-T:6]N*&AT;6PI('L*"79A<B!S96P@/2!T:&ES+E]G971396QE8W1I;VXH
M*3L*"79A<B!R86YG92`]('1H:7,N7V-R96%T95)A;F=E*'-E;"D["@EI9B`H
M2%1-3$%R96$N:7-?:64I('L*"0ER86YG92YP87-T94A434PH:'1M;"D["@E]
M(&5L<V4@>PH)"2\O(&-O;G-T<G5C="!A(&YE=R!D;V-U;65N="!F<F%G;65N
M="!W:71H('1H92!G:79E;B!(5$U,"@D)=F%R(&9R86=M96YT(#T@=&AI<RY?
M9&]C+F-R96%T941O8W5M96YT1G)A9VUE;G0H*3L*"0EV87(@9&EV(#T@=&AI
M<RY?9&]C+F-R96%T945L96UE;G0H(F1I=B(I.PH)"61I=BYI;FYE<DA434P@
M/2!H=&UL.PH)"7=H:6QE("AD:78N9FER<W1#:&EL9"D@>PH)"0DO+R!T:&4@
M9F]L;&]W:6YG(&-A;&P@86QS;R!R96UO=F5S('1H92!N;V1E(&9R;VT@9&EV
M"@D)"69R86=M96YT+F%P<&5N9$-H:6QD*&1I=BYF:7)S=$-H:6QD*3L*"0E]
M"@D)+R\@=&AI<R!A;'-O(')E;6]V97,@=&AE('-E;&5C=&EO;@H)"79A<B!N
M;V1E(#T@=&AI<RYI;G-E<G1.;V1E071396QE8W1I;VXH9G)A9VUE;G0I.PH)
M?0I].PH*+RHJ"B`J("!#86QL('1H:7,@9G5N8W1I;VX@=&\@<W5R<F]U;F0@
M=&AE(&5X:7-T:6YG($A434P@8V]D92!I;B!T:&4@<V5L96-T:6]N('=I=&@*
M("H@('EO=7(@=&%G<RX@($9)6$U%.B!B=6=G>2$@(%1H:7,@9G5N8W1I;VX@
M=VEL;"!B92!D97!R96-A=&5D(")S;V]N(BX*("HO"DA434Q!<F5A+G!R;W1O
M='EP92YS=7)R;W5N9$A434P@/2!F=6YC=&EO;BAS=&%R=%1A9RP@96YD5&%G
M*2!["@EV87(@:'1M;"`]('1H:7,N9V5T4V5L96-T961(5$U,*"D["@DO+R!T
M:&4@9F]L;&]W:6YG(&%L<V\@9&5L971E<R!T:&4@<V5L96-T:6]N"@ET:&ES
M+FEN<V5R=$A434PH<W1A<G1486<@*R!H=&UL("L@96YD5&%G*3L*?3L*"B\O
M+R!2971R:65V92!T:&4@<V5L96-T960@8FQO8VL*2%1-3$%R96$N<')O=&]T
M>7!E+F=E=%-E;&5C=&5D2%1-3"`](&9U;F-T:6]N*"D@>PH)=F%R('-E;"`]
M('1H:7,N7V=E=%-E;&5C=&EO;B@I.PH)=F%R(')A;F=E(#T@=&AI<RY?8W)E
M871E4F%N9V4H<V5L*3L*"79A<B!E>&ES=&EN9R`](&YU;&P["@EI9B`H2%1-
M3$%R96$N:7-?:64I('L*"0EE>&ES=&EN9R`](')A;F=E+FAT;6Q497AT.PH)
M?2!E;'-E('L*"0EE>&ES=&EN9R`]($A434Q!<F5A+F=E=$A434PH<F%N9V4N
M8VQO;F5#;VYT96YT<R@I+"!F86QS92P@=&AI<RD["@E]"@ER971U<FX@97AI
M<W1I;F<["GT["@HO+R\@4F5T=7)N('1R=64@:68@=V4@:&%V92!S;VUE('-E
M;&5C=&EO;@I(5$U,07)E82YP<F]T;W1Y<&4N:&%S4V5L96-T961497AT(#T@
M9G5N8W1I;VXH*2!["@DO+R!&25A-13H@8V]M92!?;VY?(&UI<VAO;RP@>6]U
M(&-A;B!D;R!B971T97(@=&AA;B!T:&ES(#LM*0H)<F5T=7)N('1H:7,N9V5T
M4V5L96-T961(5$U,*"D@(3T@)R<["GT["@I(5$U,07)E82YP<F]T;W1Y<&4N
M7V-R96%T94QI;FL@/2!F=6YC=&EO;BAL:6YK*2!["@EV87(@961I=&]R(#T@
M=&AI<SL*"79A<B!O=71P87)A;2`](&YU;&P["@EI9B`H='EP96]F(&QI;FL@
M/3T@(G5N9&5F:6YE9"(I('L*"0EL:6YK(#T@=&AI<RYG971087)E;G1%;&5M
M96YT*"D["@D):68@*&QI;FLI('L*"0D):68@*"]>:6UG)"]I+G1E<W0H;&EN
M:RYT86=.86UE*2D*"0D)"6QI;FL@/2!L:6YK+G!A<F5N=$YO9&4["@D)"6EF
M("@A+UYA)"]I+G1E<W0H;&EN:RYT86=.86UE*2D*"0D)"6QI;FL@/2!N=6QL
M.PH)"7T*"7T*"6EF("@A;&EN:RD@>PH)"79A<B!S96P@/2!E9&ET;W(N7V=E
M=%-E;&5C=&EO;B@I.PH)"79A<B!R86YG92`](&5D:71O<BY?8W)E871E4F%N
M9V4H<V5L*3L*"0EV87(@8V]M<&%R92`](#`["@D):68@*$A434Q!<F5A+FES
M7VEE*2!["@D)"6-O;7!A<F4@/2!R86YG92YC;VUP87)E16YD4&]I;G1S*")3
M=&%R=%1O16YD(BP@<F%N9V4I.PH)"7T@96QS92!["@D)"6-O;7!A<F4@/2!R
M86YG92YC;VUP87)E0F]U;F1A<GE0;VEN=',H<F%N9V4N4U1!4E1?5$]?14Y$
M+"!R86YG92D["@D)?0H)"6EF("AC;VUP87)E(#T](#`I('L*"0D)86QE<G0H
M(EEO=2!N965D('1O('-E;&5C="!S;VUE('1E>'0@8F5F;W)E(&-R96%T:6YG
M(&$@;&EN:R(I.PH)"0ER971U<FX["@D)?0H)"6]U='!A<F%M(#T@>PH)"0EF
M7VAR968@.B`G)RP*"0D)9E]T:71L92`Z("<G+`H)"0EF7W1A<F=E="`Z("<G
M+`H)"0EF7W5S971A<F=E="`Z(&5D:71O<BYC;VYF:6<N;6%K94QI;FM3:&]W
M<U1A<F=E=`H)"7T["@E](&5L<V4*"0EO=71P87)A;2`]('L*"0D)9E]H<F5F
M("`@.B!(5$U,07)E82YI<U]I92`_(&5D:71O<BYS=')I<$)A<V554DPH;&EN
M:RYH<F5F*2`Z(&QI;FLN9V5T071T<FEB=71E*")H<F5F(BDL"@D)"69?=&ET
M;&4@(#H@;&EN:RYT:71L92P*"0D)9E]T87)G970@.B!L:6YK+G1A<F=E="P*
M"0D)9E]U<V5T87)G970@.B!E9&ET;W(N8V]N9FEG+FUA:V5,:6YK4VAO=W-4
M87)G970*"0E].PH)=&AI<RY?<&]P=7!$:6%L;V<H(FQI;FLN:'1M;"(L(&9U
M;F-T:6]N*'!A<F%M*2!["@D):68@*"%P87)A;2D*"0D)<F5T=7)N(&9A;'-E
M.PH)"79A<B!A(#T@;&EN:SL*"0EI9B`H(6$I('1R>2!["@D)"65D:71O<BY?
M9&]C+F5X96-#;VUM86YD*")C<F5A=&5L:6YK(BP@9F%L<V4L('!A<F%M+F9?
M:')E9BD["@D)"6$@/2!E9&ET;W(N9V5T4&%R96YT16QE;65N="@I.PH)"0EV
M87(@<V5L(#T@961I=&]R+E]G971396QE8W1I;VXH*3L*"0D)=F%R(')A;F=E
M(#T@961I=&]R+E]C<F5A=&5286YG92AS96PI.PH)"0EI9B`H(4A434Q!<F5A
M+FES7VEE*2!["@D)"0EA(#T@<F%N9V4N<W1A<G1#;VYT86EN97(["@D)"0EI
M9B`H(2]>820O:2YT97-T*&$N=&%G3F%M92DI('L*"0D)"0EA(#T@82YN97AT
M4VEB;&EN9SL*"0D)"0EI9B`H82`]/2!N=6QL*0H)"0D)"0EA(#T@<F%N9V4N
M<W1A<G1#;VYT86EN97(N<&%R96YT3F]D93L*"0D)"7T*"0D)?0H)"7T@8V%T
M8V@H92D@>WT*"0EE;'-E('L*"0D)=F%R(&AR968@/2!P87)A;2YF7VAR968N
M=')I;2@I.PH)"0EE9&ET;W(N<V5L96-T3F]D94-O;G1E;G1S*&$I.PH)"0EI
M9B`H:')E9B`]/2`B(BD@>PH)"0D)961I=&]R+E]D;V,N97AE8T-O;6UA;F0H
M(G5N;&EN:R(L(&9A;'-E+"!N=6QL*3L*"0D)"65D:71O<BYU<&1A=&54;V]L
M8F%R*"D["@D)"0ER971U<FX@9F%L<V4["@D)"7T*"0D)96QS92!["@D)"0EA
M+FAR968@/2!H<F5F.PH)"0E]"@D)?0H)"6EF("@A*&$@)B8@+UYA)"]I+G1E
M<W0H82YT86=.86UE*2DI"@D)"7)E='5R;B!F86QS93L*"0EA+G1A<F=E="`]
M('!A<F%M+F9?=&%R9V5T+G1R:6TH*3L*"0EA+G1I=&QE(#T@<&%R86TN9E]T
M:71L92YT<FEM*"D["@D)961I=&]R+G-E;&5C=$YO9&5#;VYT96YT<RAA*3L*
M"0EE9&ET;W(N=7!D871E5&]O;&)A<B@I.PH)?2P@;W5T<&%R86TI.PI].PH*
M+R\@0V%L;&5D('=H96X@=&AE('5S97(@8VQI8VMS(&]N("));G-E<G1);6%G
M92(@8G5T=&]N+B`@268@86X@:6UA9V4@:7,@86QR96%D>0HO+R!T:&5R92P@
M:70@=VEL;"!J=7-T(&UO9&EF>2!I="=S('!R;W!E<G1I97,N"DA434Q!<F5A
M+G!R;W1O='EP92Y?:6YS97)T26UA9V4@/2!F=6YC=&EO;BAI;6%G92D@>PH)
M=F%R(&5D:71O<B`]('1H:7,["2\O(&9O<B!N97-T960@9G5N8W1I;VYS"@EV
M87(@;W5T<&%R86T@/2!N=6QL.PH):68@*'1Y<&5O9B!I;6%G92`]/2`B=6YD
M969I;F5D(BD@>PH)"6EM86=E(#T@=&AI<RYG971087)E;G1%;&5M96YT*"D[
M"@D):68@*&EM86=E("8F("$O7FEM9R0O:2YT97-T*&EM86=E+G1A9TYA;64I
M*0H)"0EI;6%G92`](&YU;&P["@E]"@EI9B`H:6UA9V4I(&]U='!A<F%M(#T@
M>PH)"69?8F%S92`@(#H@961I=&]R+F-O;F9I9RYB87-E55),+`H)"69?=7)L
M("`@(#H@2%1-3$%R96$N:7-?:64@/R!E9&ET;W(N<W1R:7!"87-E55),*&EM
M86=E+G-R8RD@.B!I;6%G92YG971!='1R:6)U=&4H(G-R8R(I+`H)"69?86QT
M("`@(#H@:6UA9V4N86QT+`H)"69?8F]R9&5R(#H@:6UA9V4N8F]R9&5R+`H)
M"69?86QI9VX@(#H@:6UA9V4N86QI9VXL"@D)9E]V97)T("`@.B!I;6%G92YV
M<W!A8V4L"@D)9E]H;W)I>B`@.B!I;6%G92YH<W!A8V4*"7T["@ET:&ES+E]P
M;W!U<$1I86QO9R@B:6YS97)T7VEM86=E+FAT;6PB+"!F=6YC=&EO;BAP87)A
M;2D@>PH)"6EF("@A<&%R86TI('L)+R\@=7-E<B!M=7-T(&AA=F4@<')E<W-E
M9"!#86YC96P*"0D)<F5T=7)N(&9A;'-E.PH)"7T*"0EV87(@:6UG(#T@:6UA
M9V4["@D):68@*"%I;6<I('L*"0D)=F%R('-E;"`](&5D:71O<BY?9V5T4V5L
M96-T:6]N*"D["@D)"79A<B!R86YG92`](&5D:71O<BY?8W)E871E4F%N9V4H
M<V5L*3L*"0D)961I=&]R+E]D;V,N97AE8T-O;6UA;F0H(FEN<V5R=&EM86=E
M(BP@9F%L<V4L('!A<F%M+F9?=7)L*3L*"0D):68@*$A434Q!<F5A+FES7VEE
M*2!["@D)"0EI;6<@/2!R86YG92YP87)E;G1%;&5M96YT*"D["@D)"0DO+R!W
M;VYD97(@:68@=&AI<R!W;W)K<RXN+@H)"0D):68@*&EM9RYT86=.86UE+G1O
M3&]W97)#87-E*"D@(3T@(FEM9R(I('L*"0D)"0EI;6<@/2!I;6<N<')E=FEO
M=7-3:6)L:6YG.PH)"0D)?0H)"0E](&5L<V4@>PH)"0D):6UG(#T@<F%N9V4N
M<W1A<G1#;VYT86EN97(N<')E=FEO=7-3:6)L:6YG.PH)"0E]"@D)?2!E;'-E
M('L*"0D):6UG+G-R8R`]('!A<F%M+F9?=7)L.PH)"7T*"@D)9F]R("AV87(@
M9FEE;&0@:6X@<&%R86TI('L*"0D)=F%R('9A;'5E(#T@<&%R86U;9FEE;&1=
M.PH)"0ES=VET8V@@*&9I96QD*2!["@D)"2`@("!C87-E(")F7V%L="(@("`@
M.B!I;6<N86QT"2`]('9A;'5E.R!B<F5A:SL*"0D)("`@(&-A<V4@(F9?8F]R
M9&5R(B`Z(&EM9RYB;W)D97(@/2!P87)S94EN="AV86QU92!\?"`B,"(I.R!B
M<F5A:SL*"0D)("`@(&-A<V4@(F9?86QI9VXB("`Z(&EM9RYA;&EG;@D@/2!V
M86QU93L@8G)E86L["@D)"2`@("!C87-E(")F7W9E<G0B("`@.B!I;6<N=G-P
M86-E(#T@<&%R<V5);G0H=F%L=64@?'P@(C`B*3L@8G)E86L["@D)"2`@("!C
M87-E(")F7VAO<FEZ(B`@.B!I;6<N:'-P86-E(#T@<&%R<V5);G0H=F%L=64@
M?'P@(C`B*3L@8G)E86L["@D)"7T*"0E]"@E]+"!O=71P87)A;2D["GT["@HO
M+R!#86QL960@=VAE;B!T:&4@=7-E<B!C;&EC:W,@=&AE($EN<V5R="!486)L
M92!B=71T;VX*2%1-3$%R96$N<')O=&]T>7!E+E]I;G-E<G1486)L92`](&9U
M;F-T:6]N*"D@>PH)=F%R('-E;"`]('1H:7,N7V=E=%-E;&5C=&EO;B@I.PH)
M=F%R(')A;F=E(#T@=&AI<RY?8W)E871E4F%N9V4H<V5L*3L*"79A<B!E9&ET
M;W(@/2!T:&ES.PDO+R!F;W(@;F5S=&5D(&9U;F-T:6]N<PH)=&AI<RY?<&]P
M=7!$:6%L;V<H(FEN<V5R=%]T86)L92YH=&UL(BP@9G5N8W1I;VXH<&%R86TI
M('L*"0EI9B`H(7!A<F%M*2!["2\O('5S97(@;75S="!H879E('!R97-S960@
M0V%N8V5L"@D)"7)E='5R;B!F86QS93L*"0E]"@D)=F%R(&1O8R`](&5D:71O
M<BY?9&]C.PH)"2\O(&-R96%T92!T:&4@=&%B;&4@96QE;65N=`H)"79A<B!T
M86)L92`](&1O8RYC<F5A=&5%;&5M96YT*")T86)L92(I.PH)"2\O(&%S<VEG
M;B!T:&4@9VEV96X@87)G=6UE;G1S"@H)"69O<B`H=F%R(&9I96QD(&EN('!A
M<F%M*2!["@D)"79A<B!V86QU92`]('!A<F%M6V9I96QD73L*"0D):68@*"%V
M86QU92D@>PH)"0D)8V]N=&EN=64["@D)"7T*"0D)<W=I=&-H("AF:65L9"D@
M>PH)"0D@("`@8V%S92`B9E]W:61T:"(@("`Z('1A8FQE+G-T>6QE+G=I9'1H
M(#T@=F%L=64@*R!P87)A;5LB9E]U;FET(ET[(&)R96%K.PH)"0D@("`@8V%S
M92`B9E]A;&EG;B(@("`Z('1A8FQE+F%L:6=N"2`]('9A;'5E.R!B<F5A:SL*
M"0D)("`@(&-A<V4@(F9?8F]R9&5R(B`@.B!T86)L92YB;W)D97()(#T@<&%R
M<V5);G0H=F%L=64I.R!B<F5A:SL*"0D)("`@(&-A<V4@(F9?<W!A8VEN9R(@
M.B!T86)L92YC96QL4W!A8VEN9R`]('!A<G-E26YT*'9A;'5E*3L@8G)E86L[
M"@D)"2`@("!C87-E(")F7W!A9&1I;F<B(#H@=&%B;&4N8V5L;%!A9&1I;F<@
M/2!P87)S94EN="AV86QU92D[(&)R96%K.PH)"0E]"@D)?0H)"79A<B!C96QL
M=VED=&@@/2`P.PH)"6EF("AP87)A;2YF7V9I>&5D*0H)"0EC96QL=VED=&@@
M/2!-871H+F9L;V]R*#$P,"`O('!A<G-E26YT*'!A<F%M+F9?8V]L<RDI.PH)
M"79A<B!T8F]D>2`](&1O8RYC<F5A=&5%;&5M96YT*")T8F]D>2(I.PH)"71A
M8FQE+F%P<&5N9$-H:6QD*'1B;V1Y*3L*"0EF;W(@*'9A<B!I(#T@,#L@:2`\
M('!A<F%M6R)F7W)O=W,B73L@*RMI*2!["@D)"79A<B!T<B`](&1O8RYC<F5A
M=&5%;&5M96YT*")T<B(I.PH)"0ET8F]D>2YA<'!E;F1#:&EL9"AT<BD["@D)
M"69O<B`H=F%R(&H@/2`P.R!J(#P@<&%R86U;(F9?8V]L<R)=.R`K*VHI('L*
M"0D)"79A<B!T9"`](&1O8RYC<F5A=&5%;&5M96YT*")T9"(I.PH)"0D):68@
M*&-E;&QW:61T:"D*"0D)"0ET9"YS='EL92YW:61T:"`](&-E;&QW:61T:"`K
M("(E(CL*"0D)"71R+F%P<&5N9$-H:6QD*'1D*3L*"0D)"2\O($UO>FEL;&$@
M;&EK97,@=&\@<V5E('-O;65T:&EN9R!I;G-I9&4@=&AE(&-E;&PN"@D)"0DH
M2%1-3$%R96$N:7-?9V5C:V\I("8F('1D+F%P<&5N9$-H:6QD*&1O8RYC<F5A
M=&5%;&5M96YT*")B<B(I*3L*"0D)?0H)"7T*"0EI9B`H2%1-3$%R96$N:7-?
M:64I('L*"0D)<F%N9V4N<&%S=&5(5$U,*'1A8FQE+F]U=&5R2%1-3"D["@D)
M?2!E;'-E('L*"0D)+R\@:6YS97)T('1H92!T86)L90H)"0EE9&ET;W(N:6YS
M97)T3F]D94%T4V5L96-T:6]N*'1A8FQE*3L*"0E]"@D)<F5T=7)N('1R=64[
M"@E]+"!N=6QL*3L*?3L*"B\J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH*("H@($-A=&5G;W)Y.B!%5D5.5"!(
M04Y$3$524PH@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ+PH*+R\@96P@:7,@<F5F97)E;F-E('1O('1H92!3
M14Q%0U0@;V)J96-T"B\O('1X="!I<R!T:&4@;F%M92!O9B!T:&4@<V5L96-T
M(&9I96QD+"!A<R!I;B!C;VYF:6<N=&]O;&)A<@I(5$U,07)E82YP<F]T;W1Y
M<&4N7V-O;6)O4V5L96-T960@/2!F=6YC=&EO;BAE;"P@='AT*2!["@ET:&ES
M+F9O8W5S161I=&]R*"D["@EV87(@=F%L=64@/2!E;"YO<'1I;VYS6V5L+G-E
M;&5C=&5D26YD97A=+G9A;'5E.PH)<W=I=&-H("AT>'0I('L*"2`@("!C87-E
M(")F;VYT;F%M92(Z"@D@("`@8V%S92`B9F]N='-I>F4B.B!T:&ES+F5X96-#
M;VUM86YD*'1X="P@9F%L<V4L('9A;'5E*3L@8G)E86L["@D@("`@8V%S92`B
M9F]R;6%T8FQO8VLB.@H)"2A(5$U,07)E82YI<U]I92D@)B8@*'9A;'5E(#T@
M(CPB("L@=F%L=64@*R`B/B(I.PH)"71H:7,N97AE8T-O;6UA;F0H='AT+"!F
M86QS92P@=F%L=64I.PH)"6)R96%K.PH)("`@(&1E9F%U;'0Z"@D)+R\@=')Y
M('1O(&QO;VL@:70@=7`@:6X@=&AE(')E9VES=&5R960@9')O<&1O=VYS"@D)
M=F%R(&1R;W!D;W=N(#T@=&AI<RYC;VYF:6<N8W5S=&]M4V5L96-T<UMT>'1=
M.PH)"6EF("AT>7!E;V8@9')O<&1O=VX@(3T@(G5N9&5F:6YE9"(I('L*"0D)
M9')O<&1O=VXN86-T:6]N*'1H:7,I.PH)"7T@96QS92!["@D)"6%L97)T*")&
M25A-13H@8V]M8F\@8F]X("(@*R!T>'0@*R`B(&YO="!I;7!L96UE;G1E9"(I
M.PH)"7T*"7T*?3L*"B\O('1H92!E>&5C0V]M;6%N9"!F=6YC=&EO;B`H:6YT
M97)C97!T<R!S;VUE(&-O;6UA;F1S(&%N9"!R97!L86-E<R!T:&5M('=I=&@*
M+R\@;W5R(&]W;B!I;7!L96UE;G1A=&EO;BD*2%1-3$%R96$N<')O=&]T>7!E
M+F5X96-#;VUM86YD(#T@9G5N8W1I;VXH8VUD240L(%5)+"!P87)A;2D@>PH)
M=F%R(&5D:71O<B`]('1H:7,["2\O(&9O<B!N97-T960@9G5N8W1I;VYS"@ET
M:&ES+F9O8W5S161I=&]R*"D["@EC;61)1"`](&-M9$E$+G1O3&]W97)#87-E
M*"D["@EI9B`H2%1-3$%R96$N:7-?9V5C:V\I('1R>2![('1H:7,N7V1O8RYE
M>&5C0V]M;6%N9"@G=7-E0U-3)RP@9F%L<V4L('1R=64I.R!](&-A=&-H("AE
M*2![?3L*"7-W:71C:"`H8VUD240I('L*"2`@("!C87-E(")H=&UL;6]D92(@
M.B!T:&ES+G-E=$UO9&4H*3L@8G)E86L["@D@("`@8V%S92`B:&EL:71E8V]L
M;W(B.@H)"2A(5$U,07)E82YI<U]I92D@)B8@*&-M9$E$(#T@(F)A8VMC;VQO
M<B(I.PH)("`@(&-A<V4@(F9O<F5C;VQO<B(Z"@D)=&AI<RY?<&]P=7!$:6%L
M;V<H(G-E;&5C=%]C;VQO<BYH=&UL(BP@9G5N8W1I;VXH8V]L;W(I('L*"0D)
M:68@*&-O;&]R*2![("\O('-E;&5C=&EO;B!N;W0@8V%N8V5L960*"0D)"65D
M:71O<BY?9&]C+F5X96-#;VUM86YD*&-M9$E$+"!F86QS92P@(B,B("L@8V]L
M;W(I.PH)"0E]"@D)?2P@2%1-3$%R96$N7V-O;&]R5&]29V(H=&AI<RY?9&]C
M+G%U97)Y0V]M;6%N9%9A;'5E*&-M9$E$*2DI.PH)"6)R96%K.PH)("`@(&-A
M<V4@(F-R96%T96QI;FLB.@H)"71H:7,N7V-R96%T94QI;FLH*3L*"0EB<F5A
M:SL*"2`@("!C87-E(")P;W!U<&5D:71O<B(Z"@D)+R\@=&AI<R!O8FIE8W0@
M=VEL;"!B92!P87-S960@=&\@=&AE(&YE=VQY(&]P96YE9"!W:6YD;W<*"0E(
M5$U,07)E82Y?;V)J96-T(#T@=&AI<SL*"0EI9B`H2%1-3$%R96$N:7-?:64I
M('L*"0D)+R]I9B`H8V]N9FER;2A(5$U,07)E82Y),3A.+FUS9ULB244M<W5C
M:W,M9G5L;"US8W)E96XB72DI"@D)"7L*"0D)"7=I;F1O=RYO<&5N*'1H:7,N
M<&]P=7!54DPH(F9U;&QS8W)E96XN:'1M;"(I+"`B:&%?9G5L;'-C<F5E;B(L
M"@D)"0D)("`@(")T;V]L8F%R/6YO+&QO8V%T:6]N/6YO+&1I<F5C=&]R:65S
M/6YO+'-T871U<SUN;RQM96YU8F%R/6YO+"(@*PH)"0D)"2`@("`B<V-R;VQL
M8F%R<SUN;RQR97-I>F%B;&4]>65S+'=I9'1H/38T,"QH96EG:'0]-#@P(BD[
M"@D)"7T*"0E](&5L<V4@>PH)"0EW:6YD;W<N;W!E;BAT:&ES+G!O<'5P55),
M*")F=6QL<V-R965N+FAT;6PB*2P@(FAA7V9U;&QS8W)E96XB+`H)"0D)("`@
M(")T;V]L8F%R/6YO+&UE;G5B87(];F\L<&5R<V]N86QB87(];F\L=VED=&@]
M-C0P+&AE:6=H=#TT.#`L(B`K"@D)"0D@("`@(G-C<F]L;&)A<G,];F\L<F5S
M:7IA8FQE/7EE<R(I.PH)"7T*"0EB<F5A:SL*"2`@("!C87-E(")U;F1O(CH*
M"2`@("!C87-E(")R961O(CH*"0EI9B`H=&AI<RY?8W5S=&]M56YD;RD*"0D)
M=&AI<UMC;61)1%TH*3L*"0EE;'-E"@D)"71H:7,N7V1O8RYE>&5C0V]M;6%N
M9"AC;61)1"P@54DL('!A<F%M*3L*"0EB<F5A:SL*"2`@("!C87-E(")I;G-E
M<G1T86)L92(Z('1H:7,N7VEN<V5R=%1A8FQE*"D[(&)R96%K.PH)("`@(&-A
M<V4@(FEN<V5R=&EM86=E(CH@=&AI<RY?:6YS97)T26UA9V4H*3L@8G)E86L[
M"@D@("`@8V%S92`B86)O=70B("`@(#H@=&AI<RY?<&]P=7!$:6%L;V<H(F%B
M;W5T+FAT;6PB+"!N=6QL+"!T:&ES*3L@8G)E86L["@D@("`@8V%S92`B<VAO
M=VAE;'`B(#H@=VEN9&]W+F]P96XH7V5D:71O<E]U<FP@*R`B<F5F97)E;F-E
M+FAT;6PB+"`B:&%?:&5L<"(I.R!B<F5A:SL*"@D@("`@8V%S92`B:VEL;'=O
M<F0B.B!T:&ES+E]W;W)D0VQE86XH*3L@8G)E86L["@H)("`@(&-A<V4@(F-U
M="(Z"@D@("`@8V%S92`B8V]P>2(Z"@D@("`@8V%S92`B<&%S=&4B.@H)"71R
M>2!["@D)"71H:7,N7V1O8RYE>&5C0V]M;6%N9"AC;61)1"P@54DL('!A<F%M
M*3L*"0D):68@*'1H:7,N8V]N9FEG+FMI;&Q7;W)D3VY087-T92D*"0D)"71H
M:7,N7W=O<F1#;&5A;B@I.PH)"7T@8V%T8V@@*&4I('L*"0D):68@*$A434Q!
M<F5A+FES7V=E8VMO*2!["@D)"0EI9B`H='EP96]F($A434Q!<F5A+DDQ.$XN
M;7-G6R)-;WHM0VQI<&)O87)D(ET@/3T@(G5N9&5F:6YE9"(I('L*"0D)"0E(
M5$U,07)E82Y),3A.+FUS9ULB36]Z+4-L:7!B;V%R9")=(#T*"0D)"0D)(E5N
M<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S
M=&4@<')O9W)A;6%T:6-A;&QY("(@*PH)"0D)"0DB9F]R('-E8W5R:71Y(')E
M87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M
M;WII;&QA+F]R9R`B("L*"0D)"0D)(G=H:6-H('-H;W=S('EO=2!H;W<@=&\@
M86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N7&Y<;B(@
M*PH)"0D)"0DB6T9)6$U%.B!P;&5A<V4@=')A;G-L871E('1H:7,@;65S<V%G
M92!I;B!Y;W5R(&QA;F=U86=E(&1E9FEN:71I;VX@9FEL92Y=(CL*"0D)"7T*
M"0D)"6EF("AC;VYF:7)M*$A434Q!<F5A+DDQ.$XN;7-G6R)-;WHM0VQI<&)O
M87)D(ETI*0H)"0D)"7=I;F1O=RYO<&5N*")H='1P.B\O;6]Z:6QL82YO<F<O
M961I=&]R+VUI9&%S9&5M;R]S96-U<FET>7!R969S+FAT;6PB*3L*"0D)?0H)
M"7T*"0EB<F5A:SL*"2`@("!C87-E(")L969T=&]R:6=H="(Z"@D@("`@8V%S
M92`B<FEG:'1T;VQE9G0B.@H)"79A<B!D:7(@/2`H8VUD240@/3T@(G)I9VAT
M=&]L969T(BD@/R`B<G1L(B`Z(")L='(B.PH)"79A<B!E;"`]('1H:7,N9V5T
M4&%R96YT16QE;65N="@I.PH)"7=H:6QE("AE;"`F)B`A2%1-3$%R96$N:7-"
M;&]C:T5L96UE;G0H96PI*0H)"0EE;"`](&5L+G!A<F5N=$YO9&4["@D):68@
M*&5L*2!["@D)"6EF("AE;"YS='EL92YD:7)E8W1I;VX@/3T@9&ER*0H)"0D)
M96PN<W1Y;&4N9&ER96-T:6]N(#T@(B(["@D)"65L<V4*"0D)"65L+G-T>6QE
M+F1I<F5C=&EO;B`](&1I<CL*"0E]"@D)8G)E86L["@D@("`@9&5F875L=#H@
M=')Y('L@=&AI<RY?9&]C+F5X96-#;VUM86YD*&-M9$E$+"!522P@<&%R86TI
M.R!]"@D)8V%T8V@H92D@>R!I9B`H=&AI<RYC;VYF:6<N9&5B=6<I('L@86QE
M<G0H92`K(")<;EQN8GD@97AE8T-O;6UA;F0H(B`K(&-M9$E$("L@(BD[(BD[
M('T@?0H)?0H)=&AI<RYU<&1A=&54;V]L8F%R*"D["@ER971U<FX@9F%L<V4[
M"GT["@HO*BH@02!G96YE<FEC(&5V96YT(&AA;F1L97(@9F]R('1H:6YG<R!T
M:&%T(&AA<'!E;B!I;B!T:&4@249204U%)W,@9&]C=6UE;G0N"B`J(%1H:7,@
M9G5N8W1I;VX@86QS;R!H86YD;&5S(&ME>2!B:6YD:6YG<RX@*B\*2%1-3$%R
M96$N<')O=&]T>7!E+E]E9&ET;W)%=F5N="`](&9U;F-T:6]N*&5V*2!["@EV
M87(@961I=&]R(#T@=&AI<SL*"79A<B!K97E%=F5N="`]("A(5$U,07)E82YI
M<U]I92`F)B!E=BYT>7!E(#T](")K97ED;W=N(BD@?'P@*"%(5$U,07)E82YI
M<U]I92`F)B!E=BYT>7!E(#T](")K97EP<F5S<R(I.PH*"6EF("AK97E%=F5N
M="D*"0EF;W(@*'9A<B!I(&EN(&5D:71O<BYP;'5G:6YS*2!["@D)"79A<B!P
M;'5G:6X@/2!E9&ET;W(N<&QU9VEN<UMI72YI;G-T86YC93L*"0D):68@*'1Y
M<&5O9B!P;'5G:6XN;VY+97E0<F5S<R`]/2`B9G5N8W1I;VXB*0H)"0D):68@
M*'!L=6=I;BYO;DME>5!R97-S*&5V*2D*"0D)"0ER971U<FX@9F%L<V4["@D)
M?0H):68@*&ME>45V96YT("8F(&5V+F-T<FQ+97D@)B8@(65V+F%L=$ME>2D@
M>PH)"79A<B!S96P@/2!N=6QL.PH)"79A<B!R86YG92`](&YU;&P["@D)=F%R
M(&ME>2`](%-T<FEN9RYF<F]M0VAA<D-O9&4H2%1-3$%R96$N:7-?:64@/R!E
M=BYK97E#;V1E(#H@978N8VAA<D-O9&4I+G1O3&]W97)#87-E*"D["@D)=F%R
M(&-M9"`](&YU;&P["@D)=F%R('9A;'5E(#T@;G5L;#L*"0ES=VET8V@@*&ME
M>2D@>PH)"2`@("!C87-E("=A)SH*"0D):68@*"%(5$U,07)E82YI<U]I92D@
M>PH)"0D)+R\@2T59('-E;&5C="!A;&P*"0D)"7-E;"`]('1H:7,N7V=E=%-E
M;&5C=&EO;B@I.PH)"0D)<V5L+G)E;6]V94%L;%)A;F=E<R@I.PH)"0D)<F%N
M9V4@/2!T:&ES+E]C<F5A=&5286YG92@I.PH)"0D)<F%N9V4N<V5L96-T3F]D
M94-O;G1E;G1S*'1H:7,N7V1O8RYB;V1Y*3L*"0D)"7-E;"YA9&1286YG92AR
M86YG92D["@D)"0E(5$U,07)E82Y?<W1O<$5V96YT*&5V*3L*"0D)?0H)"0EB
M<F5A:SL*"@D)"2\O('-I;7!L92!K97D@8V]M;6%N9',@9F]L;&]W"@H)"2`@
M("!C87-E("=B)SH@8VUD(#T@(F)O;&0B.R!B<F5A:SL*"0D@("`@8V%S92`G
M:2<Z(&-M9"`](")I=&%L:6,B.R!B<F5A:SL*"0D@("`@8V%S92`G=2<Z(&-M
M9"`](")U;F1E<FQI;F4B.R!B<F5A:SL*"0D@("`@8V%S92`G<R<Z(&-M9"`]
M(")S=')I:V5T:')O=6=H(CL@8G)E86L["@D)("`@(&-A<V4@)VPG.B!C;60@
M/2`B:G5S=&EF>6QE9G0B.R!B<F5A:SL*"0D@("`@8V%S92`G92<Z(&-M9"`]
M(")J=7-T:69Y8V5N=&5R(CL@8G)E86L["@D)("`@(&-A<V4@)W(G.B!C;60@
M/2`B:G5S=&EF>7)I9VAT(CL@8G)E86L["@D)("`@(&-A<V4@)VHG.B!C;60@
M/2`B:G5S=&EF>69U;&PB.R!B<F5A:SL*"0D@("`@8V%S92`G>B<Z(&-M9"`]
M(")U;F1O(CL@8G)E86L["@D)("`@(&-A<V4@)WDG.B!C;60@/2`B<F5D;R([
M(&)R96%K.PH)"2`@("!C87-E("=V)SH@:68@*$A434Q!<F5A+FES7VEE('Q\
M(&5D:71O<BYC;VYF:6<N:'1M;&%R96%087-T92D@>R!C;60@/2`B<&%S=&4B
M.R!](&)R96%K.PH)"2`@("!C87-E("=N)SH@8VUD(#T@(F9O<FUA=&)L;V-K
M(CL@=F%L=64@/2!(5$U,07)E82YI<U]I92`_("(\<#XB(#H@(G`B.R!B<F5A
M:SL*"@D)("`@(&-A<V4@)S`G.B!C;60@/2`B:VEL;'=O<F0B.R!B<F5A:SL*
M"@D)"2\O(&AE861I;F=S"@D)("`@(&-A<V4@)S$G.@H)"2`@("!C87-E("<R
M)SH*"0D@("`@8V%S92`G,R<Z"@D)("`@(&-A<V4@)S0G.@H)"2`@("!C87-E
M("<U)SH*"0D@("`@8V%S92`G-B<Z"@D)"6-M9"`](")F;W)M871B;&]C:R([
M"@D)"79A;'5E(#T@(F@B("L@:V5Y.PH)"0EI9B`H2%1-3$%R96$N:7-?:64I
M"@D)"0EV86QU92`]("(\(B`K('9A;'5E("L@(CXB.PH)"0EB<F5A:SL*"0E]
M"@D):68@*&-M9"D@>PH)"0DO+R!E>&5C=71E('-I;7!L92!C;VUM86YD"@D)
M"71H:7,N97AE8T-O;6UA;F0H8VUD+"!F86QS92P@=F%L=64I.PH)"0E(5$U,
M07)E82Y?<W1O<$5V96YT*&5V*3L*"0E]"@E]"@EE;'-E(&EF("AK97E%=F5N
M="D@>PH)"2\O(&]T:&5R(&ME>7,@:&5R90H)"7-W:71C:"`H978N:V5Y0V]D
M92D@>PH)"2`@("!C87-E(#$S.B`O+R!+15D@96YT97(*"0D):68@*$A434Q!
M<F5A+FES7V=E8VMO("8F("%E=BYS:&EF=$ME>2D@>PH)"0D)=&AI<RYD;VU?
M8VAE8VM);G-E<G10*"D["@D)"0E(5$U,07)E82Y?<W1O<$5V96YT*&5V*3L*
M"0D)?0H)"0EB<F5A:SL*"0D@("`@8V%S92`X.B`O+R!+15D@8F%C:W-P86-E
M"@D)("`@(&-A<V4@-#8Z("\O($M%62!D96QE=&4*"0D):68@*$A434Q!<F5A
M+FES7V=E8VMO("8F("%E=BYS:&EF=$ME>2D@>PH)"0D):68@*'1H:7,N9&]M
M7V-H96-K0F%C:W-P86-E*"DI"@D)"0D)2%1-3$%R96$N7W-T;W!%=F5N="AE
M=BD["@D)"7T@96QS92!I9B`H2%1-3$%R96$N:7-?:64I('L*"0D)"6EF("AT
M:&ES+FEE7V-H96-K0F%C:W-P86-E*"DI"@D)"0D)2%1-3$%R96$N7W-T;W!%
M=F5N="AE=BD["@D)"7T*"0D)8G)E86L["@D)?0H)?0H*"2\O('5P9&%T92!T
M:&4@=&]O;&)A<B!S=&%T92!A9G1E<B!S;VUE('1I;64*"6EF("AE9&ET;W(N
M7W1I;65R5&]O;&)A<BD@>PH)"6-L96%R5&EM96]U="AE9&ET;W(N7W1I;65R
M5&]O;&)A<BD["@E]"@EE9&ET;W(N7W1I;65R5&]O;&)A<B`]('-E=%1I;65O
M=70H9G5N8W1I;VXH*2!["@D)961I=&]R+G5P9&%T951O;VQB87(H*3L*"0EE
M9&ET;W(N7W1I;65R5&]O;&)A<B`](&YU;&P["@E]+"`U,"D["GT["@I(5$U,
M07)E82YP<F]T;W1Y<&4N<V-R;VQL5&]#87)E="`](&9U;F-T:6]N*"D@>PH)
M=F%R"@D)92`]('1H:7,N9V5T4&%R96YT16QE;65N="@I+`H)"7<@/2!T:&ES
M+E]I9G)A;64N8V]N=&5N=%=I;F1O=RP*"0EH(#T@=RYI;FYE<DAE:6=H="!\
M?"!W+FAE:6=H="P*"0ED(#T@=&AI<RY?9&]C+`H)"70@/2!D+F1O8W5M96YT
M16QE;65N="YS8W)O;&Q4;W`@?'P@9"YB;V1Y+G-C<F]L;%1O<#L*"6EF("AT
M>7!E;V8@:"`]/2`B=6YD969I;F5D(BD*"0ER971U<FX@9F%L<V4["@EI9B`H
M92YO9F9S9714;W`@/B!H("L@="D*"0EW+G-C<F]L;%1O*&4N;V9F<V5T3&5F
M="P@92YO9F9S9714;W`@+2!H("L@92YO9F9S971(96EG:'0I.PI].PH*2%1-
M3$%R96$N<')O=&]T>7!E+F-O;G9E<G1.;V1E(#T@9G5N8W1I;VXH96PL(&YE
M=U1A9TYA;64I('L*"79A<B!N97=E;"`]('1H:7,N7V1O8RYC<F5A=&5%;&5M
M96YT*&YE=U1A9TYA;64I+"!P(#T@96PN<&%R96YT3F]D93L*"7=H:6QE("AE
M;"YF:7)S=$-H:6QD*0H)"6YE=V5L+F%P<&5N9$-H:6QD*&5L+F9I<G-T0VAI
M;&0I.PH)<"YI;G-E<G1"969O<F4H;F5W96PL(&5L*3L*"7`N<F5M;W9E0VAI
M;&0H96PI.PH)<F5T=7)N(&YE=V5L.PI].PH*2%1-3$%R96$N<')O=&]T>7!E
M+FEE7V-H96-K0F%C:W-P86-E(#T@9G5N8W1I;VXH*2!["@EV87(@<V5L(#T@
M=&AI<RY?9V5T4V5L96-T:6]N*"D["@EV87(@<F%N9V4@/2!T:&ES+E]C<F5A
M=&5286YG92AS96PI.PH)=F%R('(R(#T@<F%N9V4N9'5P;&EC871E*"D["@ER
M,BYM;W9E4W1A<G0H(F-H87)A8W1E<B(L("TQ*3L*"79A<B!A(#T@<C(N<&%R
M96YT16QE;65N="@I.PH):68@*&$@(3T@<F%N9V4N<&%R96YT16QE;65N="@I
M("8F"@D@("`@+UYA)"]I+G1E<W0H82YT86=.86UE*2D@>PH)"7(R+F-O;&QA
M<'-E*'1R=64I.PH)"7(R+FUO=F5%;F0H(F-H87)A8W1E<B(L(#$I.PH)"7(R
M+G!A<W1E2%1-3"@G)RD["@D)<C(N<V5L96-T*"D["@D)<F5T=7)N('1R=64[
M"@E]"GT["@I(5$U,07)E82YP<F]T;W1Y<&4N9&]M7V-H96-K0F%C:W-P86-E
M(#T@9G5N8W1I;VXH*2!["@EV87(@<V5L9B`]('1H:7,["@ES9714:6UE;W5T
M*&9U;F-T:6]N*"D@>PH)"79A<B!S96P@/2!S96QF+E]G971396QE8W1I;VXH
M*3L*"0EV87(@<F%N9V4@/2!S96QF+E]C<F5A=&5286YG92AS96PI.PH)"79A
M<B!30R`](')A;F=E+G-T87)T0V]N=&%I;F5R.PH)"79A<B!33R`](')A;F=E
M+G-T87)T3V9F<V5T.PH)"79A<B!%0R`](')A;F=E+F5N9$-O;G1A:6YE<CL*
M"0EV87(@14\@/2!R86YG92YE;F1/9F9S970["@D)=F%R(&YE=W(@/2!30RYN
M97AT4VEB;&EN9SL*"0EI9B`H4T,N;F]D951Y<&4@/3T@,RD*"0D)4T,@/2!3
M0RYP87)E;G1.;V1E.PH)"6EF("@A+UQ3+RYT97-T*%-#+G1A9TYA;64I*2![
M"@D)"79A<B!P(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@B<"(I.PH)"0EW
M:&EL92`H4T,N9FER<W1#:&EL9"D*"0D)"7`N87!P96YD0VAI;&0H4T,N9FER
M<W1#:&EL9"D["@D)"5-#+G!A<F5N=$YO9&4N:6YS97)T0F5F;W)E*'`L(%-#
M*3L*"0D)4T,N<&%R96YT3F]D92YR96UO=F5#:&EL9"A30RD["@D)"79A<B!R
M(#T@<F%N9V4N8VQO;F5286YG92@I.PH)"0ER+G-E=%-T87)T0F5F;W)E*&YE
M=W(I.PH)"0ER+G-E=$5N9$%F=&5R*&YE=W(I.PH)"0ER+F5X=')A8W1#;VYT
M96YT<R@I.PH)"0ES96PN<F5M;W9E06QL4F%N9V5S*"D["@D)"7-E;"YA9&12
M86YG92AR*3L*"0E]"@E]+"`Q,"D["GT["@I(5$U,07)E82YP<F]T;W1Y<&4N
M9&]M7V-H96-K26YS97)T4"`](&9U;F-T:6]N*"D@>PH)=F%R(&DL(%-#+"!L
M969T+"!R:6=H="P@<C(L"@D)<V5L("`@/2!T:&ES+E]G971396QE8W1I;VXH
M*2P*"0ER("`@("`]('1H:7,N7V-R96%T95)A;F=E*'-E;"DL"@D)<"`@("`@
M/2!T:&ES+F=E=$%L;$%N8V5S=&]R<R@I+`H)"6)L;V-K(#T@;G5L;"P*"0ED
M;V,@("`]('1H:7,N7V1O8RP*"0EB;V1Y("`](&1O8RYB;V1Y.PH*"69O<B`H
M:2`](#`[(&D@/"!P+FQE;F=T:#L@*RMI*0H)"6EF("A(5$U,07)E82YI<T)L
M;V-K16QE;65N="AP6VE=*2`F)B`A+V)O9'E\:'1M;"]I+G1E<W0H<%MI72YT
M86=.86UE*2D@>PH)"0EB;&]C:R`]('!;:5T["@D)"6)R96%K.PH)"7T*"@EI
M9B`H(7(N8V]L;&%P<V5D*0H)"7(N9&5L971E0V]N=&5N=',H*3L*"7-E;"YR
M96UO=F5!;&Q286YG97,H*3L*"5-#(#T@<BYS=&%R=$-O;G1A:6YE<CL*"@EI
M9B`H(6)L;V-K*2!["@D);&5F="`](%-#.PH)"69O<B`H:2`](%-#.R!I("8F
M(&D@(3T@8F]D>2`F)B`A2%1-3$%R96$N:7-";&]C:T5L96UE;G0H:2D[(&D@
M/2!(5$U,07)E82YG9710<F5V3F]D92AI*2D*"0D);&5F="`](&D["@D)<FEG
M:'0@/2!30SL*"0EF;W(@*&D@/2!30SL@:2`F)B!I("$](&)O9'D@)B8@(4A4
M34Q!<F5A+FES0FQO8VM%;&5M96YT*&DI.R!I(#T@2%1-3$%R96$N9V5T3F5X
M=$YO9&4H:2DI"@D)"7)I9VAT(#T@:3L*"0EI9B`H;&5F="`A/2!B;V1Y("8F
M(')I9VAT("$](&)O9'DI('L*"0D)<C(@/2!R+F-L;VYE4F%N9V4H*3L*"0D)
M<C(N<V5T4W1A<G1"969O<F4H;&5F="D["@D)"7(R+G-U<G)O=6YD0V]N=&5N
M=',H8FQO8VL@/2!D;V,N8W)E871E16QE;65N="@B<"(I*3L*"0D):68@*"$O
M7%,O+G1E<W0H2%1-3$%R96$N9V5T26YN97)497AT*&)L;V-K*2DI"@D)"0EB
M;&]C:RYI;FYE<DA434P@/2`B/&)R("\^(CL*"0D)8FQO8VLN;F]R;6%L:7IE
M*"D["@D)"7(N<V5T16YD069T97(H<FEG:'0I.PH)"0ER+G-U<G)O=6YD0V]N
M=&5N=',H8FQO8VL@/2!D;V,N8W)E871E16QE;65N="@B<"(I*3L*"0D):68@
M*"$O7%,O+G1E<W0H2%1-3$%R96$N9V5T26YN97)497AT*&)L;V-K*2DI"@D)
M"0EB;&]C:RYI;FYE<DA434P@/2`B/&)R("\^(CL*"0D)8FQO8VLN;F]R;6%L
M:7IE*"D["@D)?2!E;'-E('L*"0D)<B`](&1O8RYC<F5A=&5286YG92@I.PH)
M"0ER+G-E=%-T87)T*&)O9'DL(#`I.PH)"0ER+G-E=$5N9"AB;V1Y+"`P*3L*
M"0D)<BYI;G-E<G1.;V1E*&)L;V-K(#T@9&]C+F-R96%T945L96UE;G0H(G`B
M*2D["@D)"6)L;V-K+FEN;F5R2%1-3"`]("(\8G(@+SXB.PH)"7T*"0ER+G-E
M;&5C=$YO9&5#;VYT96YT<RAB;&]C:RD["@E](&5L<V4@>PH)"7(N<V5T16YD
M069T97(H8FQO8VLI.PH)"79A<B!D9B`]('(N97AT<F%C=$-O;G1E;G1S*"DL
M(&QE9G1?96UP='D@/2!F86QS93L*"0EI9B`H(2]<4R\N=&5S="AB;&]C:RYI
M;FYE<DA434PI*2!["@D)"6)L;V-K+FEN;F5R2%1-3"`]("(\8G(@+SXB.PH)
M"0EL969T7V5M<'1Y(#T@=')U93L*"0E]"@D)<"`](&1F+F9I<G-T0VAI;&0[
M"@D):68@*'`I('L*"0D):68@*"$O7%,O+G1E<W0H2%1-3$%R96$N9V5T26YN
M97)497AT*'`I*2D@>PH@"0D)"6EF("@O7FA;,2TV720O:2YT97-T*'`N=&%G
M3F%M92DI"B`)"0D)"7`@/2!T:&ES+F-O;G9E<G1.;V1E*'`L(")P(BD["@D)
M"0EP+FEN;F5R2%1-3"`]("(\8G(@+SXB.PH)"0E]"@D)"6EF("@O7FQI)"]I
M+G1E<W0H<"YT86=.86UE*2`F)B!L969T7V5M<'1Y("8F("%B;&]C:RYN97AT
M4VEB;&EN9RD@>PH)"0D);&5F="`](&)L;V-K+G!A<F5N=$YO9&4["@D)"0EL
M969T+G)E;6]V94-H:6QD*&)L;V-K*3L*"0D)"7(N<V5T16YD069T97(H;&5F
M="D["@D)"0ER+F-O;&QA<'-E*&9A;'-E*3L*"0D)"7`@/2!T:&ES+F-O;G9E
M<G1.;V1E*'`L("]>6W5O76PD+VDN=&5S="AL969T+G!A<F5N=$YO9&4N=&%G
M3F%M92D@/R`B;&DB(#H@(G`B*3L*"0D)?0H)"0ER+FEN<V5R=$YO9&4H9&8I
M.PH)"0ER+G-E;&5C=$YO9&5#;VYT96YT<RAP*3L*"0E]"@E]"@ER+F-O;&QA
M<'-E*'1R=64I.PH)<V5L+F%D9%)A;F=E*'(I.PH)=&AI<RYF;W)C95)E9')A
M=R@I.PH)=&AI<RYS8W)O;&Q4;T-A<F5T*"D["GT["@HO+R!R971R:65V92!T
M:&4@2%1-3`I(5$U,07)E82YP<F]T;W1Y<&4N9V5T2%1-3"`](&9U;F-T:6]N
M*"D@>PH)<W=I=&-H("AT:&ES+E]E9&ET36]D92D@>PH)("`@(&-A<V4@(G=Y
M<VEW>6<B("`Z"@D):68@*"%T:&ES+F-O;F9I9RYF=6QL4&%G92D@>PH)"0ER
M971U<FX@2%1-3$%R96$N9V5T2%1-3"AT:&ES+E]D;V,N8F]D>2P@9F%L<V4L
M('1H:7,I.PH)"7T@96QS90H)"0ER971U<FX@=&AI<RYD;V-T>7!E("L@(EQN
M(B`K($A434Q!<F5A+F=E=$A434PH=&AI<RY?9&]C+F1O8W5M96YT16QE;65N
M="P@=')U92P@=&AI<RD["@D@("`@8V%S92`B=&5X=&UO9&4B(#H@<F5T=7)N
M('1H:7,N7W1E>'1!<F5A+G9A;'5E.PH)("`@(&1E9F%U;'0)("`@(#H@86QE
M<G0H(DUO9&4@/"(@*R!M;V1E("L@(CX@;F]T(&1E9FEN960A(BD["@E]"@ER
M971U<FX@9F%L<V4["GT["@HO+R!R971R:65V92!T:&4@2%1-3"`H9F%S=&5S
M="!V97)S:6]N+"!B=70@=7-E<R!I;FYE<DA434PI"DA434Q!<F5A+G!R;W1O
M='EP92YG971);FYE<DA434P@/2!F=6YC=&EO;B@I('L*"7-W:71C:"`H=&AI
M<RY?961I=$UO9&4I('L*"2`@("!C87-E(")W>7-I=WEG(B`@.@H)"6EF("@A
M=&AI<RYC;VYF:6<N9G5L;%!A9V4I"@D)"7)E='5R;B!T:&ES+E]D;V,N8F]D
M>2YI;FYE<DA434P["@D)96QS90H)"0ER971U<FX@=&AI<RYD;V-T>7!E("L@
M(EQN(B`K('1H:7,N7V1O8RYD;V-U;65N=$5L96UE;G0N:6YN97)(5$U,.PH)
M("`@(&-A<V4@(G1E>'1M;V1E(B`Z(')E='5R;B!T:&ES+E]T97AT07)E82YV
M86QU93L*"2`@("!D969A=6QT"2`@("`Z(&%L97)T*")-;V1E(#PB("L@;6]D
M92`K("(^(&YO="!D969I;F5D(2(I.PH)?0H)<F5T=7)N(&9A;'-E.PI].PH*
M+R\@8V]M<&QE=&5L>2!C:&%N9V4@=&AE($A434P@:6YS:61E"DA434Q!<F5A
M+G!R;W1O='EP92YS971(5$U,(#T@9G5N8W1I;VXH:'1M;"D@>PH)<W=I=&-H
M("AT:&ES+E]E9&ET36]D92D@>PH)("`@(&-A<V4@(G=Y<VEW>6<B("`Z"@D)
M:68@*"%T:&ES+F-O;F9I9RYF=6QL4&%G92D*"0D)=&AI<RY?9&]C+F)O9'DN
M:6YN97)(5$U,(#T@:'1M;#L*"0EE;'-E"@D)"2\O('1H:7,N7V1O8RYD;V-U
M;65N=$5L96UE;G0N:6YN97)(5$U,(#T@:'1M;#L*"0D)=&AI<RY?9&]C+F)O
M9'DN:6YN97)(5$U,(#T@:'1M;#L*"0EB<F5A:SL*"2`@("!C87-E(")T97AT
M;6]D92(@.B!T:&ES+E]T97AT07)E82YV86QU92`](&AT;6P[(&)R96%K.PH)
M("`@(&1E9F%U;'0)("`@(#H@86QE<G0H(DUO9&4@/"(@*R!M;V1E("L@(CX@
M;F]T(&1E9FEN960A(BD["@E]"@ER971U<FX@9F%L<V4["GT["@HO+R!S971S
M('1H92!G:79E;B!D;V-T>7!E("AU<V5F=6P@=VAE;B!C;VYF:6<N9G5L;%!A
M9V4@:7,@=')U92D*2%1-3$%R96$N<')O=&]T>7!E+G-E=$1O8W1Y<&4@/2!F
M=6YC=&EO;BAD;V-T>7!E*2!["@ET:&ES+F1O8W1Y<&4@/2!D;V-T>7!E.PI]
M.PH*+RHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*@H@*B`@0V%T96=O<GDZ(%5424Q)5%D@1E5.0U1)3TY3"B`J
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHO"@HO+R!V87)I86)L92!U<V5D('1O('!A<W,@=&AE(&]B:F5C="!T
M;R!T:&4@<&]P=7`@961I=&]R('=I;F1O=RX*2%1-3$%R96$N7V]B:F5C="`]
M(&YU;&P["@HO+R!F=6YC=&EO;B!T:&%T(')E='5R;G,@82!C;&]N92!O9B!T
M:&4@9VEV96X@;V)J96-T"DA434Q!<F5A+F-L;VYE3V)J96-T(#T@9G5N8W1I
M;VXH;V)J*2!["@EI9B`H(6]B:BD@<F5T=7)N(&YU;&P["@EV87(@;F5W3V)J
M(#T@;F5W($]B:F5C=#L*"@DO+R!C:&5C:R!F;W(@87)R87D@;V)J96-T<PH)
M:68@*&]B:BYC;VYS=')U8W1O<BYT;U-T<FEN9R@I+FEN9&5X3V8H(F9U;F-T
M:6]N($%R<F%Y*"(I(#T](#$I('L*"0EN97=/8FH@/2!O8FHN8V]N<W1R=6-T
M;W(H*3L*"7T*"@DO+R!C:&5C:R!F;W(@9G5N8W1I;VX@;V)J96-T<R`H87,@
M=7-U86PL($E%(&ES(&9U8VME9"!U<"D*"6EF("AO8FHN8V]N<W1R=6-T;W(N
M=&]3=')I;F<H*2YI;F1E>$]F*")F=6YC=&EO;B!&=6YC=&EO;B@B*2`]/2`Q
M*2!["@D);F5W3V)J(#T@;V)J.R`O+R!J=7-T(&-O<'D@<F5F97)E;F-E('1O
M(&ET"@E](&5L<V4@9F]R("AV87(@;B!I;B!O8FHI('L*"0EV87(@;F]D92`]
M(&]B:EMN73L*"0EI9B`H='EP96]F(&YO9&4@/3T@)V]B:F5C="<I('L@;F5W
M3V)J6VY=(#T@2%1-3$%R96$N8VQO;F5/8FIE8W0H;F]D92D[('T*"0EE;'-E
M("`@("`@("`@("`@("`@("`@("`@("`@('L@;F5W3V)J6VY=(#T@;F]D93L@
M?0H)?0H*"7)E='5R;B!N97=/8FH["GT["@HO+R!&25A-12$A(2!T:&ES('-H
M;W5L9"!R971U<FX@9F%L<V4@9F]R($E%(#P@-2XU"DA434Q!<F5A+F-H96-K
M4W5P<&]R=&5D0G)O=W-E<B`](&9U;F-T:6]N*"D@>PH):68@*$A434Q!<F5A
M+FES7V=E8VMO*2!["@D):68@*&YA=FEG871O<BYP<F]D=6-T4W5B(#P@,C`P
M,C$R,#$I('L*"0D)86QE<G0H(EEO=2!N965D(&%T(&QE87-T($UO>FEL;&$M
M,2XS($%L<&AA+EQN(B`K"@D)"2`@("`@(")3;W)R>2P@>6]U<B!'96-K;R!I
M<R!N;W0@<W5P<&]R=&5D+B(I.PH)"0ER971U<FX@9F%L<V4["@D)?0H)"6EF
M("AN879I9V%T;W(N<')O9'5C=%-U8B`\(#(P,#,P,C$P*2!["@D)"6%L97)T
M*")-;WII;&QA(#P@,2XS($)E=&$@:7,@;F]T('-U<'!O<G1E9"%<;B(@*PH)
M"0D@("`@("`B22=L;"!T<GDL('1H;W5G:"P@8G5T(&ET(&UI9VAT(&YO="!W
M;W)K+B(I.PH)"7T*"7T*"7)E='5R;B!(5$U,07)E82YI<U]G96-K;R!\?"!(
M5$U,07)E82YI<U]I93L*?3L*"B\O('-E;&5C=&EO;B`F(')A;F=E<PH*+R\@
M<F5T=7)N<R!T:&4@8W5R<F5N="!S96QE8W1I;VX@;V)J96-T"DA434Q!<F5A
M+G!R;W1O='EP92Y?9V5T4V5L96-T:6]N(#T@9G5N8W1I;VXH*2!["@EI9B`H
M2%1-3$%R96$N:7-?:64I('L*"0ER971U<FX@=&AI<RY?9&]C+G-E;&5C=&EO
M;CL*"7T@96QS92!["@D)<F5T=7)N('1H:7,N7VEF<F%M92YC;VYT96YT5VEN
M9&]W+F=E=%-E;&5C=&EO;B@I.PH)?0I].PH*+R\@<F5T=7)N<R!A(')A;F=E
M(&9O<B!T:&4@8W5R<F5N="!S96QE8W1I;VX*2%1-3$%R96$N<')O=&]T>7!E
M+E]C<F5A=&5286YG92`](&9U;F-T:6]N*'-E;"D@>PH):68@*$A434Q!<F5A
M+FES7VEE*2!["@D)<F5T=7)N('-E;"YC<F5A=&5286YG92@I.PH)?2!E;'-E
M('L*"0ET:&ES+F9O8W5S161I=&]R*"D["@D):68@*'1Y<&5O9B!S96P@(3T@
M(G5N9&5F:6YE9"(I('L*"0D)=')Y('L*"0D)"7)E='5R;B!S96PN9V5T4F%N
M9V5!="@P*3L*"0D)?2!C871C:"AE*2!["@D)"0ER971U<FX@=&AI<RY?9&]C
M+F-R96%T95)A;F=E*"D["@D)"7T*"0E](&5L<V4@>PH)"0ER971U<FX@=&AI
M<RY?9&]C+F-R96%T95)A;F=E*"D["@D)?0H)?0I].PH*+R\@979E;G0@:&%N
M9&QI;F<*"DA434Q!<F5A+E]A9&1%=F5N="`](&9U;F-T:6]N*&5L+"!E=FYA
M;64L(&9U;F,I('L*"6EF("A(5$U,07)E82YI<U]I92D@>PH)"65L+F%T=&%C
M:$5V96YT*")O;B(@*R!E=FYA;64L(&9U;F,I.PH)?2!E;'-E('L*"0EE;"YA
M9&1%=F5N=$QI<W1E;F5R*&5V;F%M92P@9G5N8RP@=')U92D["@E]"GT["@I(
M5$U,07)E82Y?861D179E;G1S(#T@9G5N8W1I;VXH96PL(&5V<RP@9G5N8RD@
M>PH)9F]R("AV87(@:2`](&5V<RYL96YG=&@[("TM:2`^/2`P.RD@>PH)"4A4
M34Q!<F5A+E]A9&1%=F5N="AE;"P@979S6VE=+"!F=6YC*3L*"7T*?3L*"DA4
M34Q!<F5A+E]R96UO=F5%=F5N="`](&9U;F-T:6]N*&5L+"!E=FYA;64L(&9U
M;F,I('L*"6EF("A(5$U,07)E82YI<U]I92D@>PH)"65L+F1E=&%C:$5V96YT
M*")O;B(@*R!E=FYA;64L(&9U;F,I.PH)?2!E;'-E('L*"0EE;"YR96UO=F5%
M=F5N=$QI<W1E;F5R*&5V;F%M92P@9G5N8RP@=')U92D["@E]"GT["@I(5$U,
M07)E82Y?<F5M;W9E179E;G1S(#T@9G5N8W1I;VXH96PL(&5V<RP@9G5N8RD@
M>PH)9F]R("AV87(@:2`](&5V<RYL96YG=&@[("TM:2`^/2`P.RD@>PH)"4A4
M34Q!<F5A+E]R96UO=F5%=F5N="AE;"P@979S6VE=+"!F=6YC*3L*"7T*?3L*
M"DA434Q!<F5A+E]S=&]P179E;G0@/2!F=6YC=&EO;BAE=BD@>PH):68@*$A4
M34Q!<F5A+FES7VEE*2!["@D)978N8V%N8V5L0G5B8FQE(#T@=')U93L*"0EE
M=BYR971U<FY686QU92`](&9A;'-E.PH)?2!E;'-E('L*"0EE=BYP<F5V96YT
M1&5F875L="@I.PH)"65V+G-T;W!0<F]P86=A=&EO;B@I.PH)?0I].PH*2%1-
M3$%R96$N7W)E;6]V94-L87-S(#T@9G5N8W1I;VXH96PL(&-L87-S3F%M92D@
M>PH):68@*"$H96P@)B8@96PN8VQA<W-.86UE*2D@>PH)"7)E='5R;CL*"7T*
M"79A<B!C;',@/2!E;"YC;&%S<TYA;64N<W!L:70H(B`B*3L*"79A<B!A<B`]
M(&YE=R!!<G)A>2@I.PH)9F]R("AV87(@:2`](&-L<RYL96YG=&@[(&D@/B`P
M.RD@>PH)"6EF("AC;'-;+2UI72`A/2!C;&%S<TYA;64I('L*"0D)87);87(N
M;&5N9W1H72`](&-L<UMI73L*"0E]"@E]"@EE;"YC;&%S<TYA;64@/2!A<BYJ
M;VEN*"(@(BD["GT["@I(5$U,07)E82Y?861D0VQA<W,@/2!F=6YC=&EO;BAE
M;"P@8VQA<W-.86UE*2!["@DO+R!R96UO=F4@=&AE(&-L87-S(&9I<G-T+"!I
M9B!A;')E861Y('1H97)E"@E(5$U,07)E82Y?<F5M;W9E0VQA<W,H96PL(&-L
M87-S3F%M92D["@EE;"YC;&%S<TYA;64@*ST@(B`B("L@8VQA<W-.86UE.PI]
M.PH*2%1-3$%R96$N7VAA<T-L87-S(#T@9G5N8W1I;VXH96PL(&-L87-S3F%M
M92D@>PH):68@*"$H96P@)B8@96PN8VQA<W-.86UE*2D@>PH)"7)E='5R;B!F
M86QS93L*"7T*"79A<B!C;',@/2!E;"YC;&%S<TYA;64N<W!L:70H(B`B*3L*
M"69O<B`H=F%R(&D@/2!C;',N;&5N9W1H.R!I(#X@,#LI('L*"0EI9B`H8VQS
M6RTM:5T@/3T@8VQA<W-.86UE*2!["@D)"7)E='5R;B!T<G5E.PH)"7T*"7T*
M"7)E='5R;B!F86QS93L*?3L*"DA434Q!<F5A+E]B;&]C:U1A9W,@/2`B(&)O
M9'D@9F]R;2!T97AT87)E82!F:65L9'-E="!U;"!O;"!D;"!L:2!D:78@(B`K
M"B)P(&@Q(&@R(&@S(&@T(&@U(&@V('%U;W1E('!R92!T86)L92!T:&5A9"`B
M("L*(G1B;V1Y('1F;V]T('1R('1D(&EF<F%M92!A9&1R97-S("(["DA434Q!
M<F5A+FES0FQO8VM%;&5M96YT(#T@9G5N8W1I;VXH96PI('L*"7)E='5R;B!E
M;"`F)B!E;"YN;V1E5'EP92`]/2`Q("8F("A(5$U,07)E82Y?8FQO8VM486=S
M+FEN9&5X3V8H(B`B("L@96PN=&%G3F%M92YT;TQO=V5R0V%S92@I("L@(B`B
M*2`A/2`M,2D["GT["@I(5$U,07)E82Y?8VQO<VEN9U1A9W,@/2`B(&AE860@
M<V-R:7!T('-T>6QE(&1I=B!S<&%N('1R('1D('1B;V1Y('1A8FQE(&5M('-T
M<F]N9R!B(&D@8V]D92!C:71E(&1F;B!A8F)R(&%C<F]N>6T@9F]N="!A('1I
M=&QE("(["DA434Q!<F5A+FYE961S0VQO<VEN9U1A9R`](&9U;F-T:6]N*&5L
M*2!["@ER971U<FX@96P@)B8@96PN;F]D951Y<&4@/3T@,2`F)B`H2%1-3$%R
M96$N7V-L;W-I;F=486=S+FEN9&5X3V8H(B`B("L@96PN=&%G3F%M92YT;TQO
M=V5R0V%S92@I("L@(B`B*2`A/2`M,2D["GT["@HO+R!P97)F;W)M<R!(5$U,
M(&5N8V]D:6YG(&]F('-O;64@9VEV96X@<W1R:6YG"DA434Q!<F5A+FAT;6Q%
M;F-O9&4@/2!F=6YC=&EO;BAS='(I('L*"2\O('=E(&1O;B=T(&YE960@<F5G
M97AP(&9O<B!T:&%T+"!B=70N+B!S;R!B92!I="!F;W(@;F]W+@H)<W1R(#T@
M<W1R+G)E<&QA8V4H+R8O:6<L("(F86UP.R(I.PH)<W1R(#T@<W1R+G)E<&QA
M8V4H+SPO:6<L("(F;'0[(BD["@ES='(@/2!S='(N<F5P;&%C92@O/B]I9RP@
M(B9G=#LB*3L*"7-T<B`]('-T<BYR97!L86-E*"]<>#(R+VEG+"`B)G%U;W0[
M(BD["@DO+R!<>#(R(&UE86YS("<B)R`M+2!W92!U<V4@:&5X(')E<')E>F5N
M=&%T:6]N('-O('1H870@=V4@9&]N)W0@9&ES='5R8@H)+R\@2E,@8V]M<')E
M<W-O<G,@*'=E;&PL(&%T(&QE87-T(&UI;F4@9F%I;',N+B`[*0H)<F5T=7)N
M('-T<CL*?3L*"B\O(%)E=')I979E<R!T:&4@2%1-3"!C;V1E(&9R;VT@=&AE
M(&=I=F5N(&YO9&4N"2!4:&ES(&ES(&$@<F5P;&%C96UE;G0@9F]R"B\O(&=E
M='1I;F<@:6YN97)(5$U,+"!U<VEN9R!S=&%N9&%R9"!$3TT@8V%L;',N"B\O
M(%=R87!P97(@8V%T8V@@82!-;WII;&QA+45X8V5P=&EO;B!W:71H(&YO;B!W
M96QL(&9O<FUE9"!H=&UL('-O=7)C92!C;V1E"DA434Q!<F5A+F=E=$A434P@
M/2!F=6YC=&EO;BAR;V]T+"!O=71P=712;V]T+"!E9&ET;W(I>PH@("`@=')Y
M>PH@("`@("`@(')E='5R;B!(5$U,07)E82YG971(5$U,5W)A<'!E<BAR;V]T
M+&]U='!U=%)O;W0L961I=&]R*3L*("`@('T*("`@(&-A=&-H*&4I>PH@("`@
M("`@(&%L97)T*"=9;W5R($1O8W5M96YT(&ES(&YO="!W96QL(&9O<FUE9"X@
M0VAE8VL@2F%V85-C<FEP="!C;VYS;VQE(&9O<B!D971A:6QS+B<I.PH@("`@
M("`@(')E='5R;B!E9&ET;W(N7VEF<F%M92YC;VYT96YT5VEN9&]W+F1O8W5M
M96YT+F)O9'DN:6YN97)(5$U,.PH@("`@?0I]"@I(5$U,07)E82YG971(5$U,
M5W)A<'!E<B`](&9U;F-T:6]N*')O;W0L(&]U='!U=%)O;W0L(&5D:71O<BD@
M>PH)=F%R(&AT;6P@/2`B(CL*"7-W:71C:"`H<F]O="YN;V1E5'EP92D@>PH)
M("`@(&-A<V4@,3H@+R\@3F]D92Y%3$5-14Y47TY/1$4*"2`@("!C87-E(#$Q
M.B`O+R!.;V1E+D1/0U5-14Y47T9204=-14Y47TY/1$4*"0EV87(@8VQO<V5D
M.PH)"79A<B!I.PH)"79A<B!R;V]T7W1A9R`]("AR;V]T+FYO9&54>7!E(#T]
M(#$I(#\@<F]O="YT86=.86UE+G1O3&]W97)#87-E*"D@.B`G)SL*"0EI9B`H
M<F]O=%]T86<@/3T@)V)R)R`F)B`A<F]O="YN97AT4VEB;&EN9RD*"0D)8G)E
M86L["@D):68@*&]U='!U=%)O;W0I"@D)"6]U='!U=%)O;W0@/2`A*&5D:71O
M<BYC;VYF:6<N:'1M;%)E;6]V951A9W,@)B8@961I=&]R+F-O;F9I9RYH=&UL
M4F5M;W9E5&%G<RYT97-T*')O;W1?=&%G*2D["@D):68@*$A434Q!<F5A+FES
M7VEE("8F(')O;W1?=&%G(#T](")H96%D(BD@>PH)"0EI9B`H;W5T<'5T4F]O
M="D*"0D)"6AT;6P@*ST@(CQH96%D/B(["@D)"2\O(&QO=V5R8V%S:7IE"@D)
M"79A<B!S879E7VUU;'1I;&EN92`](%)E9T5X<"YM=6QT:6QI;F4["@D)"5)E
M9T5X<"YM=6QT:6QI;F4@/2!T<G5E.PH)"0EV87(@='AT(#T@<F]O="YI;FYE
M<DA434PN<F5P;&%C92A(5$U,07)E82Y215]T86=.86UE+"!F=6YC=&EO;BAS
M='(L('`Q+"!P,BD@>PH)"0D)<F5T=7)N('`Q("L@<#(N=&],;W=E<D-A<V4H
M*3L*"0D)?2D["@D)"5)E9T5X<"YM=6QT:6QI;F4@/2!S879E7VUU;'1I;&EN
M93L*"0D):'1M;"`K/2!T>'0["@D)"6EF("AO=71P=712;V]T*0H)"0D):'1M
M;"`K/2`B/"]H96%D/B(["@D)"6)R96%K.PH)"7T@96QS92!I9B`H;W5T<'5T
M4F]O="D@>PH)"0EC;&]S960@/2`H(2AR;V]T+FAA<T-H:6QD3F]D97,H*2!\
M?"!(5$U,07)E82YN965D<T-L;W-I;F=486<H<F]O="DI*3L*"0D):'1M;"`]
M("(\(B`K(')O;W0N=&%G3F%M92YT;TQO=V5R0V%S92@I.PH)"0EV87(@871T
M<G,@/2!R;V]T+F%T=')I8G5T97,["@D)"69O<B`H:2`](#`[(&D@/"!A='1R
M<RYL96YG=&@[("LK:2D@>PH)"0D)=F%R(&$@/2!A='1R<RYI=&5M*&DI.PH)
M"0D):68@*"%A+G-P96-I9FEE9"D@>PH)"0D)"6-O;G1I;G5E.PH)"0D)?0H)
M"0D)=F%R(&YA;64@/2!A+FYO9&5.86UE+G1O3&]W97)#87-E*"D["@D)"0EI
M9B`H+U]M;WI?961I=&]R7V)O9W5S7VYO9&4O+G1E<W0H;F%M92DI('L*"0D)
M"0EH=&UL(#T@(B(["@D)"0D)8G)E86L["@D)"0E]"@D)"0EI9B`H+U]M;WI\
M8V]N=&5N=&5D:71A8FQE?%]M<V@O+G1E<W0H;F%M92DI('L*"0D)"0DO+R!A
M=F]I9"!C97)T86EN(&%T=')I8G5T97,*"0D)"0EC;VYT:6YU93L*"0D)"7T*
M"0D)"79A<B!V86QU93L*"0D)"6EF("AN86UE("$](")S='EL92(I('L*"0D)
M"0DO+R!)134N-2!R97!O<G1S(#(U('=H96X@8V5L;%-P86-I;F<@:7,*"0D)
M"0DO+R`Q.R!O=&AE<B!V86QU97,@;6EG:'0@8F4@9&]O;65D('1O;RX*"0D)
M"0DO+R!&;W(@=&AI<R!R96%S;VX@=V4@97AT<F%C="!T:&4*"0D)"0DO+R!V
M86QU97,@9&ER96-T;'D@9G)O;2!T:&4@<F]O="!N;V1E+@H)"0D)"2\O($DG
M;2!S=&%R=&EN9R!T;R!(051%($IA=F%38W)I<'0*"0D)"0DO+R!D979E;&]P
M;65N="X@($)R;W=S97(@9&EF9F5R96YC97,*"0D)"0DO+R!S=6-K+@H)"0D)
M"2\O"@D)"0D)+R\@57-I;F<@1V5C:V\@=&AE('9A;'5E<R!O9B!H<F5F(&%N
M9"!S<F,@87)E(&-O;G9E<G1E9"!T;R!A8G-O;'5T92!L:6YK<PH)"0D)"2\O
M('5N;&5S<R!W92!G970@=&AE;2!U<VEN9R!N;V1E5F%L=64H*0H)"0D)"6EF
M("AT>7!E;V8@<F]O=%MA+FYO9&5.86UE72`A/2`B=6YD969I;F5D(B`F)B!N
M86UE("$](")H<F5F(B`F)B!N86UE("$](")S<F,B("8F("$O7F]N+RYT97-T
M*&YA;64I*2!["@D)"0D)"79A;'5E(#T@<F]O=%MA+FYO9&5.86UE73L*"0D)
M"0E](&5L<V4@>PH)"0D)"0EV86QU92`](&$N;F]D959A;'5E.PH)"0D)"0DO
M+R!)12!S965M<R!N;W0@=VEL;&EN9R!T;R!R971U<FX@=&AE(&]R:6=I;F%L
M('9A;'5E<R`M(&ET(&-O;G9E<G1S('1O(&%B<V]L=71E"@D)"0D)"2\O(&QI
M;FMS('5S:6YG(&$N;F]D959A;'5E+"!A+G9A;'5E+"!A+G-T<FEN9U9A;'5E
M+"!R;V]T+F=E=$%T=')I8G5T92@B:')E9B(I"@D)"0D)"2\O(%-O('=E(&AA
M=F4@=&\@<W1R:7`@=&AE(&)A<V5U<FP@;6%N=6%L;'D@.BTO"@D)"0D)"6EF
M("A(5$U,07)E82YI<U]I92`F)B`H;F%M92`]/2`B:')E9B(@?'P@;F%M92`]
M/2`B<W)C(BDI('L*"0D)"0D)"79A;'5E(#T@961I=&]R+G-T<FEP0F%S9552
M3"AV86QU92D["@D)"0D)"7T*"0D)"0E]"@D)"0E](&5L<V4@>R`O+R!)12!F
M86EL<R!T;R!P=70@<W1Y;&4@:6X@871T<FEB=71E<R!L:7-T"@D)"0D)+R\@
M1DE8344Z(&-S<U1E>'0@<F5P;W)T960@8GD@244@:7,@55!015)#05-%"@D)
M"0D)=F%L=64@/2!R;V]T+G-T>6QE+F-S<U1E>'0["@D)"0E]"@D)"0EI9B`H
M+RA?;6]Z?%XD*2\N=&5S="AV86QU92DI('L*"0D)"0DO+R!-;WII;&QA(')E
M<&]R=',@<V]M92!S<&5C:6%L('1A9W,*"0D)"0DO+R!H97)E.R!W92!D;VXG
M="!N965D('1H96TN"@D)"0D)8V]N=&EN=64["@D)"0E]"@D)"0EH=&UL("L]
M("(@(B`K(&YA;64@*R`G/2(G("L@=F%L=64@*R`G(B<["@D)"7T*"0D):68@
M*&AT;6P@(3T@(B(I('L*"0D)"6AT;6P@*ST@8VQO<V5D(#\@(B`O/B(@.B`B
M/B(["@D)"7T*"0E]"@D)9F]R("AI(#T@<F]O="YF:7)S=$-H:6QD.R!I.R!I
M(#T@:2YN97AT4VEB;&EN9RD@>PH)"0EH=&UL("L]($A434Q!<F5A+F=E=$A4
M34Q7<F%P<&5R*&DL('1R=64L(&5D:71O<BD["@D)?0H)"6EF("AO=71P=712
M;V]T("8F("%C;&]S960I('L*"0D):'1M;"`K/2`B/"\B("L@<F]O="YT86=.
M86UE+G1O3&]W97)#87-E*"D@*R`B/B(["@D)?0H)"6)R96%K.PH)("`@(&-A
M<V4@,SH@+R\@3F]D92Y415A47TY/1$4*"0DO+R!)9B!A('1E>'0@;F]D92!I
M<R!A;&]N92!I;B!A;B!E;&5M96YT(&%N9"!A;&P@<W!A8V5S+"!R97!L86-E
M(&ET('=I=&@@86X@;F]N(&)R96%K:6YG(&]N90H)"2\O(%1H:7,@<&%R=&EA
M;&QY('5N9&]E<R!T:&4@9&%M86=E(&1O;F4@8GD@;6]Z+"!W:&EC:"!T<F%N
M<VQA=&5S("<F;F)S<#LG<R!I;G1O('-P86-E<R!I;B!T:&4@9&%T82!E;&5M
M96YT"@D)+RH@:68@*"`A<F]O="YP<F5V:6]U<U-I8FQI;F<@)B8@(7)O;W0N
M;F5X=%-I8FQI;F<@)B8@<F]O="YD871A+FUA=&-H*"]>7',J)"]I*2`I(&AT
M;6P@/2`G)FYB<W`[)SL*"0D@("!E;'-E("HO"@D):'1M;"`]("]><V-R:7!T
M?'-T>6QE)"]I+G1E<W0H<F]O="YP87)E;G1.;V1E+G1A9TYA;64I(#\@<F]O
M="YD871A(#H@2%1-3$%R96$N:'1M;$5N8V]D92AR;V]T+F1A=&$I.PH)"6)R
M96%K.PH)("`@(&-A<V4@-#H@+R\@3F]D92Y#1$%405]314-424].7TY/1$4*
M"0DO+R!&25A-13H@:70@<V5E;7,@=V4@;F5V97(@9V5T(&AE<F4L(&)U="!)
M(&)E;&EE=F4@=V4@<VAO=6QD+BX*"0DO+R`@("`@("`@;6%Y8F4@82!B<F]W
M<V5R('!R;V)L96T_+2U#1$%402!S96-T:6]N<R!A<F4@8V]N=F5R=&5D('1O
M('!L86EN('1E>'0@;F]D97,@86YD(&YO<FUA;&EZ960*"0DO+R!#1$%402!S
M96-T:6]N<R!S:&]U;&0@9V\@(F%S(&ES(B!W:71H;W5T(&9U<G1H97(@96YC
M;V1I;F<*"0EH=&UL(#T@(CPA6T-$051!6R(@*R!R;V]T+F1A=&$@*R`B75T^
M(CL*"0EB<F5A:SL*"2`@("!C87-E(#@Z("\O($YO9&4N0T]-345.5%].3T1%
M"@D):'1M;"`]("(\(2TM(B`K(')O;W0N9&%T82`K("(M+3XB.PH)"6)R96%K
M.PD)+R\@<VMI<"!C;VUM96YT<RP@9F]R(&YO=RX*"7T*"7)E='5R;B!H=&UL
M.PI].PH*2%1-3$%R96$N9V5T4')E=DYO9&4@/2!F=6YC=&EO;BAN;V1E*2![
M"@EI9B`H(6YO9&4I("`@("`@("`@("`@("`@(')E='5R;B!N=6QL.PH):68@
M*&YO9&4N<')E=FEO=7-3:6)L:6YG*2!R971U<FX@;F]D92YP<F5V:6]U<U-I
M8FQI;F<["@EI9B`H;F]D92YP87)E;G1.;V1E*2`@("`@(')E='5R;B!N;V1E
M+G!A<F5N=$YO9&4["@ER971U<FX@;G5L;#L*?3L*"DA434Q!<F5A+F=E=$YE
M>'1.;V1E(#T@9G5N8W1I;VXH;F]D92D@>PH):68@*"%N;V1E*2`@("`@("`@
M("`@(')E='5R;B!N=6QL.PH):68@*&YO9&4N;F5X=%-I8FQI;F<I(')E='5R
M;B!N;V1E+FYE>'13:6)L:6YG.PH):68@*&YO9&4N<&%R96YT3F]D92D@(')E
M='5R;B!N;V1E+G!A<F5N=$YO9&4["@ER971U<FX@;G5L;#L*?3L*"DA434Q!
M<F5A+G!R;W1O='EP92YS=')I<$)A<V554DP@/2!F=6YC=&EO;BAS=')I;F<I
M('L*"79A<B!B87-E=7)L(#T@=&AI<RYC;VYF:6<N8F%S95523#L*"@DO+R!S
M=')I<"!T;R!L87-T(&1I<F5C=&]R>2!I;B!C87-E(&)A<V5U<FP@<&]I;G1S
M('1O(&$@9FEL90H)8F%S975R;"`](&)A<V5U<FPN<F5P;&%C92@O6UY<+UTK
M)"\L("<G*3L*"79A<B!B87-E<F4@/2!N97<@4F5G17AP*&)A<V5U<FPI.PH)
M<W1R:6YG(#T@<W1R:6YG+G)E<&QA8V4H8F%S97)E+"`B(BD["@H)+R\@<W1R
M:7`@:&]S="UP87)T(&]F(%523"!W:&EC:"!I<R!A9&1E9"!B>2!-4TE%('1O
M(&QI;FMS(')E;&%T:79E('1O('-E<G9E<B!R;V]T"@EB87-E=7)L(#T@8F%S
M975R;"YR97!L86-E*"]>*&AT='!S/SI<+UPO6UY<+UTK*2@N*BDD+RP@)R0Q
M)RD["@EB87-E<F4@/2!N97<@4F5G17AP*&)A<V5U<FPI.PH)<F5T=7)N('-T
M<FEN9RYR97!L86-E*&)A<V5R92P@(B(I.PI].PH*4W1R:6YG+G!R;W1O='EP
M92YT<FEM(#T@9G5N8W1I;VXH*2!["@ER971U<FX@=&AI<RYR97!L86-E*"]>
M7',K+RP@)R<I+G)E<&QA8V4H+UQS*R0O+"`G)RD["GT["@HO+R!C<F5A=&5S
M(&$@<F=B+7-T>6QE(&-O;&]R(&9R;VT@82!N=6UB97(*2%1-3$%R96$N7VUA
M:V5#;VQO<B`](&9U;F-T:6]N*'8I('L*"6EF("AT>7!E;V8@=B`A/2`B;G5M
M8F5R(BD@>PH)"2\O(&%L<F5A9'D@:6X@<F=B("AH;W!E9G5L;'DI.R!)12!D
M;V5S;B=T(&=E="!H97)E+@H)"7)E='5R;B!V.PH)?0H)+R\@244@<V5N9',@
M;G5M8F5R.R!C;VYV97)T('1O(')G8BX*"79A<B!R(#T@=B`F(#!X1D8["@EV
M87(@9R`]("AV(#X^(#@I("8@,'A&1CL*"79A<B!B(#T@*'8@/CX@,38I("8@
M,'A&1CL*"7)E='5R;B`B<F=B*"(@*R!R("L@(BPB("L@9R`K("(L(B`K(&(@
M*R`B*2(["GT["@HO+R!R971U<FYS(&AE>&%D96-I;6%L(&-O;&]R(')E<')E
M<V5N=&%T:6]N(&9R;VT@82!N=6UB97(@;W(@82!R9V(M<W1Y;&4@8V]L;W(N
M"DA434Q!<F5A+E]C;VQO<E1O4F=B(#T@9G5N8W1I;VXH=BD@>PH):68@*"%V
M*0H)"7)E='5R;B`G)SL*"@DO+R!R971U<FYS('1H92!H97@@<F5P<F5S96YT
M871I;VX@;V8@;VYE(&)Y=&4@*#(@9&EG:71S*0H)9G5N8W1I;VX@:&5X*&0I
M('L*"0ER971U<FX@*&0@/"`Q-BD@/R`H(C`B("L@9"YT;U-T<FEN9R@Q-BDI
M(#H@9"YT;U-T<FEN9R@Q-BD["@E].PH*"6EF("AT>7!E;V8@=B`]/2`B;G5M
M8F5R(BD@>PH)"2\O('=E)W)E('1A;&MI;F<@=&\@244@:&5R90H)"79A<B!R
M(#T@=B`F(#!X1D8["@D)=F%R(&<@/2`H=B`^/B`X*2`F(#!X1D8["@D)=F%R
M(&(@/2`H=B`^/B`Q-BD@)B`P>$9&.PH)"7)E='5R;B`B(R(@*R!H97@H<BD@
M*R!H97@H9RD@*R!H97@H8BD["@E]"@H):68@*'8N<W5B<W1R*#`L(#,I(#T]
M(")R9V(B*2!["@D)+R\@:6X@<F=B*"XN+BD@9F]R;2`M+2!-;WII;&QA"@D)
M=F%R(')E(#T@+W)G8EQS*EPH7',J*%LP+3E=*RE<<RHL7',J*%LP+3E=*RE<
M<RHL7',J*%LP+3E=*RE<<RI<*2\["@D):68@*'8N;6%T8V@H<F4I*2!["@D)
M"79A<B!R(#T@<&%R<V5);G0H4F5G17AP+B0Q*3L*"0D)=F%R(&<@/2!P87)S
M94EN="A296=%>'`N)#(I.PH)"0EV87(@8B`]('!A<G-E26YT*%)E9T5X<"XD
M,RD["@D)"7)E='5R;B`B(R(@*R!H97@H<BD@*R!H97@H9RD@*R!H97@H8BD[
M"@D)?0H)"2\O(&1O97-N)W0@;6%T8V@@4D4_(2`@;6%Y8F4@=7-E<R!P97)C
M96YT86=E<R!O<B!F;&]A="!N=6UB97)S"@D)+R\@+2T@1DE8344Z(&YO="!Y
M970@:6UP;&5M96YT960N"@D)<F5T=7)N(&YU;&P["@E]"@H):68@*'8N<W5B
M<W1R*#`L(#$I(#T]("(C(BD@>PH)"2\O(&%L<F5A9'D@:&5X(')G8B`H:&]P
M969U;&QY(#I$("D*"0ER971U<FX@=CL*"7T*"@DO+R!I9B!E=F5R>71H:6YG
M(&5L<V4@9F%I;',@.RD*"7)E='5R;B!N=6QL.PI].PH*+R\@;6]D86P@9&EA
M;&]G<R!F;W(@36]Z:6QL82`H9F]R($E%('=E)W)E('5S:6YG('1H92!S:&]W
M36]D86Q$:6%L;V<H*2!C86QL*2X*"B\O(')E8V5I=F5S(&%N(%523"!T;R!T
M:&4@<&]P=7`@9&EA;&]G(&%N9"!A(&9U;F-T:6]N('1H870@<F5C96EV97,@
M;VYE('9A;'5E.PHO+R!T:&ES(&9U;F-T:6]N('=I;&P@9V5T(&-A;&QE9"!A
M9G1E<B!T:&4@9&EA;&]G(&ES(&-L;W-E9"P@=VET:"!T:&4@<F5T=7)N"B\O
M('9A;'5E(&]F('1H92!D:6%L;V<N"DA434Q!<F5A+G!R;W1O='EP92Y?<&]P
M=7!$:6%L;V<@/2!F=6YC=&EO;BAU<FPL(&%C=&EO;BP@:6YI="D@>PH)1&EA
M;&]G*'1H:7,N<&]P=7!54DPH=7)L*2P@86-T:6]N+"!I;FET*3L*?3L*"B\O
M('!A=&AS"@I(5$U,07)E82YP<F]T;W1Y<&4N:6UG55),(#T@9G5N8W1I;VXH
M9FEL92P@<&QU9VEN*2!["@EI9B`H='EP96]F('!L=6=I;B`]/2`B=6YD969I
M;F5D(BD*"0ER971U<FX@7V5D:71O<E]U<FP@*R!F:6QE.PH)96QS90H)"7)E
M='5R;B!?961I=&]R7W5R;"`K(")P;'5G:6YS+R(@*R!P;'5G:6X@*R`B+VEM
M9R\B("L@9FEL93L*?3L*"DA434Q!<F5A+G!R;W1O='EP92YP;W!U<%523"`]
M(&9U;F-T:6]N*&9I;&4I('L*"79A<B!U<FP@/2`B(CL*"6EF("AF:6QE+FUA
M=&-H*"]><&QU9VEN.EPO7"\H+BH_*5PO*"XJ*2\I*2!["@D)=F%R('!L=6=I
M;B`](%)E9T5X<"XD,3L*"0EV87(@<&]P=7`@/2!296=%>'`N)#(["@D):68@
M*"$O7"YH=&UL)"\N=&5S="AP;W!U<"DI"@D)"7!O<'5P("L]("(N:'1M;"([
M"@D)=7)L(#T@7V5D:71O<E]U<FP@*R`B<&QU9VEN<R\B("L@<&QU9VEN("L@
M(B]P;W!U<',O(B`K('!O<'5P.PH)?2!E;'-E"@D)=7)L(#T@7V5D:71O<E]U
M<FP@*R!T:&ES+F-O;F9I9RYP;W!U<%523"`K(&9I;&4["@ER971U<FX@=7)L
M.PI].PH*+RHJ"B`J($9)6#H@26YT97)N970@17AP;&]R97(@<F5T=7)N<R!A
M;B!I=&5M(&AA=FEN9R!T:&4@7VYA;65?(&5Q=6%L('1O('1H92!G:79E;@H@
M*B!I9"P@979E;B!I9B!I="=S(&YO="!H879I;F<@86YY(&ED+B`@5&AI<R!W
M87D@:70@8V%N(')E='5R;B!A(&1I9F9E<F5N="!F;W)M"B`J(&9I96QD(&5V
M96X@:68@:70G<R!N;W0@82!T97AT87)E82X@(%1H:7,@=V]R:V%R;W5N9',@
M=&AE('!R;V)L96T@8GD*("H@<W!E8VEF:6-A;&QY(&QO;VMI;F<@=&\@<V5A
M<F-H(&]N;'D@96QE;65N=',@:&%V:6YG(&$@8V5R=&%I;B!T86<@;F%M92X*
M("HO"DA434Q!<F5A+F=E=$5L96UE;G1">4ED(#T@9G5N8W1I;VXH=&%G+"!I
M9"D@>PH)=F%R(&5L+"!I+"!O8FIS(#T@9&]C=6UE;G0N9V5T16QE;65N='-"
M>51A9TYA;64H=&%G*3L*"69O<B`H:2`](&]B:G,N;&5N9W1H.R`M+6D@/CT@
M,"`F)B`H96P@/2!O8FIS6VE=*3LI"@D):68@*&5L+FED(#T](&ED*0H)"0ER
M971U<FX@96P["@ER971U<FX@;G5L;#L*?3L*"@H*+R\@14]&"B\O($QO8V%L
M('9A<FEA8FQE<SH@+R\*+R\@8RUB87-I8RUO9F9S970Z."`O+PHO+R!I;F1E
M;G0M=&%B<RUM;V1E.G0@+R\*+R\@16YD.B`O+PH`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+P``````
M`````````````````````````````````````````````````#`P,#`W-34`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S4W`#`R-#`S
M-0`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL
M87)E82]I;6%G97,O961?86)O=70N9VEF````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q,C<`
M,3`U,34T,S,W-3<`,#(V,S`V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````$=)1C@Y81(`$@"``0````#___\A^00!```!`"P`
M````$@`2```"+HR/B<#M#TQ4=$Z:K&);[GMH6.8M'!F`DIJ69M=FK/BB\^R&
M>#R&>6^!"$\]2@$`.P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S
M+V5D7V%L:6=N7V-E;G1E<BYG:68``````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3`U`#$P-3$U-#,S-S4W
M`#`R-S8R,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!'248X.6$2`!(`@`$`````____(?D$`0```0`L`````!(`$@```AR,
MCZG+[0&BG/-92.MUN8/->1_(B!19BNC*MD8!`#L`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]A;&EG;E]J
M=7-T:69Y+F=I9@`````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#$P-0`Q,#4Q-30S,S<U-@`P,S`P,S8`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````1TE&.#EA
M$@`2`(`!`````/___R'Y!`$```$`+``````2`!(```(<C(^IR^T!HISS/8JE
M=3GOUF$?$U+C4E;GRK9'`0`[````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S
M+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?86QI9VY?;&5F="YG:68`````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`Q,#4`,3`U,34T,S,W-38`,#(W,C<S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$=)1C@Y81(`$@"``0````#_
M__\A^00!```!`"P`````$@`2```"'(R/J<OM`:*<\SU*K8:X;]9)WQ5F8U("
MY\JV2`$`.P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M
M;&%R96$O:6UA9V5S+V5D7V%L:6=N7W)I9VAT+F=I9@``````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3`T
M`#$P-3$U-#,S-S4W`#`R-S0U-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!'248X.6$2`!(`@`$`````____(?D$`0```0`L
M`````!(`$@```AN,CZG+[0&BG//90^EMN8-M>1&XB!K)B>C*M@4`.P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E
M<R]E9%]B;&%N:RYG:68````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`W,``Q,#4Q-30S,S<U
M-@`P,C8R-3<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````1TE&.#EA$@`2`(```/___P```"'Y!`$`````+``````2`!(```(/
MA(^IR^T/HYRTVHNSWIP7`#L`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?8VAA<FUA
M<"YG:68`````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`R,3<`,3`U,34T,S,W-38`,#(V-C`V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````$=)1C@Y
M81(`$@"B!P"``(#`P,"`@(#_`````/\```#_______\A^00!```'`"P`````
M$@`2```#5'BZW-XB/A>#E;.&P:^@QL4-@A5\C!!ZI648Z-&^I@L+Q5(21$"_
M`D`D)S,19I&@D+@[]GP1@!"G:%F.T.A09^W=D@4BU_0-3V0EF/G,%;/?\#@\
M`0`[````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E
M<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7V-O;&]R7V)G+F=I9@``````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,C8U`#$P-3$U-#,S-S4W`#`R-C<V-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!'248X.6$2`!(`LPL``(0`
M`'L`A(2$>WM[_P#_`/___P``__\```#_____````____````````````````
M(?D$`0``"P`L`````!(`$@``!&)PR4FKE4K=K?.VGO=-6J((VEB:RY"EU;HH
M@U`/.(XM28()AN"@0!Q@>B1@4$`L&'<2G&UZ$U`TM=-A*P@``D^2J[4]#+Z`
M,"DJF+H_`X1\0*BK*P(Y0E`GW"E25#8CA(44$0`[````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT
M;6QA<F5A+VEM86=E<R]E9%]C;VQO<E]F9RYG:68`````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#(U
M,P`Q,#4Q-30S,S<U-P`P,C8W-C8`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````1TE&.#EA$@`2`+,*``"$``![`(2$A'M[>_\`
M_P#___\``/__````_P```/___P```````````````````"'Y!`$```H`+```
M```2`!(```184,E)*TTX:RO3Q!^G>!TYBI>)IJL%#G`<N]Y@W$.A#[1BWP)=
M@5=Y"00P))(RT`@.4$$`$"!R!M##@`JP6@9'L%*`&B#.`X+:6Q&<$0(U@<T4
M@^^MO%X1`0`[````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G
M97,O961?8V]P>2YG:68`````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-38`,3`U,34T,S,W
M-3<`,#(V,34P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$=)1C@Y81(`$@"1`P```(````#_______\A^00!```#`"P`````
M$@`2```"/YR/J<L6#]L)HHHG![4TR-X!XJAL%F`)8@(^Z*DB9H4^*NE<T)O&
M>5J#4``388`';`0AO@7RI!Q)B9FJ]8HH```[````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7V-U<W1O
M;2YG:68``````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3`S`#$P-3$U-#,S-S4V`#`R-C0W-P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!'248X
M.6$2`!(`@`$`````____(?D$`0```0`L`````!(`$@```AJ,CZG+[0_C`D`&
M2B6N<=O\<=9XB9U)INIJ%``[````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC
M97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]C=70N9VEF````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#$S,P`Q,#4Q-30S,S<U-@`P,C4W-C,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````1TE&.#EA$@`2`)$"````
M@````/___P```"'Y!`$```(`+``````2`!(```(LE(^IRQOW&IS21'%E>+O.
M7&U@Z"%``)1&"K15RZY-*L3U+-/THJ\[XU()AP4`.P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H
M=&UL87)E82]I;6%G97,O961?9&5L971E+F=I9@``````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q
M,S(`,3`U,34T,S,W-3<`,#(V-#,R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````$=)1C@Y81(`$@"1``#___\```#___\````A
M^00%%``"`"P`````$@`2```"*Y2/J<OM%@)@<9Y84];8BKUTG]=@H",^GTF&
MV<E)EZRD5PO!8XBK5.\+'@H`.P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA
M9V5S+V5D7V9O<FUA=%]B;VQD+F=I9@``````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3$R`#$P-3$U-#,S
M-S4V`#`R-S0U-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!'248X.6$2`!(`@`$`````____(?D$`0```0`L`````!(`$@``
M`B&,CZG+[?^`G#+6,%W&E^WM45T(&.#RC4I:DB($Q_),,P4`.P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]F;W)M
M871?:71A;&EC+F=I9@`````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$Q-0`Q,#4Q-30S,S<U-@`P,S`P,#4`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````1TE&
M.#EA$@`2`)$#`'M[>X2$A````/___R'Y!`$```,`+``````2`!(```(>G(^I
MR^T/C9@SCADLJ'8"S44>*%B7\$$49;;N"T<%`#L`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I
M8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?9F]R;6%T7W-T<FEK92YG
M:68`````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`Q,38`,3`U,34T,S,W-3<`,#,P,#0S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````$=)1C@Y81(`$@"``0``
M``#___\A^00!```!`"P`````$@`2```")8R/J<OM"B((T\5S;36;2?Q062.5
M9O@]6THBH[=VRU2&]HWG3`$`.P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O
M:'1M;&%R96$O:6UA9V5S+V5D7V9O<FUA=%]S=6(N9VEF````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,3$V`#$P-3$U-#,S-S4V`#`R-S,S,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!'248X.6$2`!(`D0(```"`````____````
M(?D$`0```@`L`````!(`$@```A^4CZG+[>]",!(*6>V=&O.750"@(61Y:JDZ
MENX+QTT!`#L`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM
M86=E<R]E9%]F;W)M871?<W5P+F=I9@``````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$Q-0`Q,#4Q-30S
M,S<U-P`P,C<S-3``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````1TE&.#EA$@`2`)$"`(```````/___P```"'Y!`$```(`+```
M```2`!(```(>E(^IRVT`'(L2T?JPA2P$XV%>J)'B>(*?QK;N"[<%`#L`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?9F]R
M;6%T7W5N9&5R;&EN92YG:68`````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q,C4`,3`U,34T,S,W-3<`,#,P-3(W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$=)
M1C@Y81(`$@"1`@![>WL```#___\````A^00!```"`"P`````$@`2```")I2/
MJ<OM_X(,8M(F3W:[7OQU3"<NY#>&J!D``E"R$T0CUEWG.ET``#L`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V
M:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7VAE;'`N9VEF````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,3`V`#$P-3$U-#,S-S4V`#`R-C$R,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!'248X.6$2`!(`@`$`
M````____(?D$`0```0`L`````!(`$@```AV,CZG+[0\#F"!.<U_.4=;.0:'X
M=>8Q:N7)MNY2```[````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R
M+VAT;6QA<F5A+VEM86=E<R]E9%]H<BYG:68`````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#$P-@`Q,#4Q-30S,S<U-P`P,C4V,#(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````1TE&.#EA$@`2`)$"`#,S,YF9F?___P``
M`"'Y!`$```(`+``````2`!(```(7E(^IR^T/HYRT@8NS/J'[#U;B2);FJ10`
M.P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I
M;6%G97,O961?:'1M;"YG:68`````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q,3,`,3`U,34T
M,S,W-3<`,#(V,3,S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````$=)1C@Y81(`$@"``0````#___\A^00!```!`"P`````$@`2
M```"(HR/J<OM#P$P\M5S5\93;?1]2=AY)7A2*<HZEPC%\DS71P$`.P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7VEM
M86=E+F=I9@```````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,C(T`#$P-3$U-#,S-S4W`#`R-C(U
M-``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!'
M248X.6$2`!(`H@<``(``@```@(``@("`__\``/__````____(?D$`0``!P`L
M`````!(`$@```UEXNMS^4)E!JZ6&C2"X[V"V#()AGF@@*EM6'"\A'Z56OOA!
M**K6OP.8L#:Z'8*40K`WZ@592"*K]#P>*4Q6H'HAK8X"P$%,'K=\@+1Z+05_
MWITO:CZ/V.^0!``[````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R
M=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]I;F1E;G1?;&5S<RYG
M:68````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#$R-P`Q,#4Q-30S,S<U-@`P,C<U,#(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````1TE&.#EA$@`2`)$"
M````A````/___P```"'Y!`$```(`+``````2`!(```(HE(^I&>NO@FRS2H@%
M0+8>L!W=9(!F5H9&MZ@"BV+>>,7+W-CZNO=0`0`[````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O
M<B]H=&UL87)E82]I;6%G97,O961?:6YD96YT7VUO<F4N9VEF````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`Q,C<`,3`U,34T,S,W-38`,#(W-#<V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````$=)1C@Y81(`$@"1`@```(0```#___\`
M```A^00!```"`"P`````$@`2```"*)2/J1GKKX)LLTJ(!4"V(K`9W62`9G:`
M1[>$HH5FWGC%R]S8NKCW4`$`.P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O
M:6UA9V5S+V5D7VMI;&QW;W)D+F=I9@``````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,C,R`#$P-3$U
M-#,S-S4V`#`R-S`Q-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!'248X.6$2`!(`P@8```````#__P``34U-JJJJ_^C-____
M____(?D$`0H`!P`L`0```!``$@```U]XNMQ,,$I'C+V6#!5`_QZ0&9N(78$U
MK`/H`D5L%$-H>,9G%3.>=K<";#:KW5PYGM('\_!@,J&(:1%<!+34R0+`6J4O
MG;6WJ&`*7K+"?+W2RK&X/`8HUVH`?!Y0=_@5"0`[````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]L
M969T7W1O7W)I9VAT+F=I9@`````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$S,0`Q,#4Q-30S,S<U-@`P,S`P
M,3<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M1TE&.#EA$@`2`)$"``0"A````/___P```"'Y!`$```(`+``````2`!(```(J
ME(^IR^T/4Y@,H!E$7L`:K%7=1VU*-VJ9F:!7R'G'6BET%++/C??^#RD``#L`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E
M<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?;&EN:RYG:68`````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`Q-#$`,3`U,34T,S,W-38`,#(V,3(T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````$=)1C@Y81(`$@"1
M``#___^`@(````#___\A^00%%``#`"P`````$@`2```",IR/J<OM#^,(HE9C
M:S@4@%-YX#8(7X8*&`:HYF=0Y4RGV3JIG(8(9'XK97Z2HO&(3#(*`#L`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O:6UA9V5S+V5D7VQI<W1?8G5L;&5T+F=I9@``````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,3(P`#$P-3$U-#,S-S4W`#`R-S4P-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!'248X.6$2`!(`D0(```"$````____
M````(?D$`0```@`L`````!(`$@```B&4CZG+!M_4`R;8>]&,O/NT?2%&:M"'
MIN#IC61VA.I,<P4`.P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A
M+VEM86=E<R]E9%]L:7-T7VYU;2YG:68`````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$R,@`Q,#4Q
M-30S,S<U-P`P,C<P,C$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````1TE&.#EA$@`2`)$"````A````/___P```"'Y!`$```(`
M+``````2`!(```(CE(^IRPB]P#.A6ILF=')[V'T.=5V9:$@:BJJL5IJG&+*V
M6```.P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?
M<&%S=&4N9VEF````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R,3,`,3`U,34T,S,W-38`,#(V
M,S`S`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`$=)1C@Y81(`$@"B!@"`@`"`@(```(#__P#___\```#___\````A^00!```&
M`"P`````$@`2```#4&BZW/[0E5FBH7,,7%D!`5!L8Q$&G6*B4IA>($<%[&*"
M^(F_GR[\0`%/%Q`0CL>?)P<P(@E&@8T8_4&!*J;SF511KT&H#;/E2A_!]-G"
M;BL2`#L`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7W)E9&\N9VEF````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,3(P`#$P-3$U-#,S-S4V`#`R-C$Q-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!'248X.6$2`!(`
MD0(`@("```"`____````(?D$`0```@`L`````!(`$@```B&4CZG+[>]`F`%*
M-$]-FXOL+93286-RF2<'0.X+Q_),OP4`.P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I
M=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]R:6=H=%]T;U]L969T+F=I9@``````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#$S,``Q,#4Q-30S,S<U-P`P,S`P,3<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````1TE&.#EA$@`2`)$"``0"A````/__
M_P```"'Y!`$```(`+``````2`!(```(IE(^IR^W_@@QP"HK`LM@`K7#'!X84
M1I;A-7[-F:D)G+TL9-#XSO=^4@``.P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E
M82]I;6%G97,O961?<FUF;W)M870N9VEF````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-C8`,3`U
M,34T,S,W-3<`,#(W,#(V`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````$=)1C@Y81(`$@#R!0`````9``!F9F;,S,S___\`````
M```````A^00!```%`"P`````$@`2```#.UBZW/XPRDF7`!@((<$@WS``D0>>
M%V2&A$8ZZZEM,/O-+Q/?6VYY(A'N`0R.4D2CT->X9#"<BG1*720``#L`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D
M7W-A=F4N9VEF`````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,C$W`#$P-3$U-#,S-S4W`#`R
M-C$S,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!'248X.6$2`!(`H@4`W-S<@("`@(``____````____````````(?D$`0``
M!0`L`````!(`$@```U18NMS^4)%)*VU$D,'[(`41,-GF<50`+.6):BJKN1^\
M2K-;QKAF93:98$@LBFZAX6\2[$T"$]Q1**I*>4D?%)2<*K;+%+(`")C/:/-8
M`6B[W^V(/`$`.P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]S:&]W7V)O<F1E
M<BYG:68````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#$U,``Q,#4Q-30S,S<U-@`P,C<U,#0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````1TE&.#EA$@`2
M`)$"```SF0```/___P```"'Y!`$```(`+``````2`!(```(YE(^IR^T/8YBT
MVF`"V+QW+&C>N($8&![HE*7M&YIG.I\LK>:9Z?:KC*O%>"M=K%6$W5C"VO("
M914``#L`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D
M:71O<B]H=&UL87)E82]I;6%G97,O961?<W!L:71C96PN9VEF````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`R,3<`,3`U,34T,S,W-3<`,#(W,#$S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````$=)1C@Y81<`%@"B!````(``____
M__\```#___\````````````A^00!```$`"P`````%P`6```#5$BZW/XPRDFK
MG2/KS<<;@@"&X4AZSFB69/EU</:5@1``]9VCC6H+@%^PQF.H`,BD$E!<;(10
MXDR4P]FL@:;BN%QJ":JJV/;UU8;`7SD&N[C?\'@E`0`[````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R
M96$O:6UA9V5S+V5D7W5N9&\N9VEF````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3(Q`#$P
M-3$U-#,S-S4V`#`R-C$S,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!'248X.6$2`!(`D0(`@("```"`____````(?D$`0``
M`@`L`````!(`$@```B*4CZG+[0]C"S2`%0Y%5NWL>1LFC@G(5:C12<`JQ?),
MUTP!`#L`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]F
M=6QL<V-R965N7VUA>&EM:7IE+F=I9@`````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$T,0`Q,#4Q-30S,S<U-P`P
M,S`U-C4`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````1TE&.#EA$@`2`(`!`````/___R'Y!`$```$`+``````2`!(```(XC(^I
M!NW?%%AGI@E=L'!GS%27QHG5LX6JAX&IJGFOE<9R>=+W:E]P](G4A`A=B%B4
M4%:YH'&Y+```.P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O9G5L;'-C<F5E;E]M
M:6YI;6EZ92YG:68`````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`Q-#$`,3`U,34T,S,W-38`,#,P-38R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$=)1C@Y81(`
M$@"``0````#___\A^00!```!`"P`````$@`2```".(R/J0CMOP*(<]73I'F.
MY7IM6*:5V$:6$[FFJG1UC,BZHO;E'`V=26L+\3@K!7`G-%F,Q%WDF2@``#L`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E
M9&ET;W(O:'1M;&%R96$O:6UA9V5S+VEN<V5R=%]T86)L92YG:68`````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,3<Q`#$P-3$U-#,S-S4W`#`R-S$W-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!'248X.6$2`!(`H@``____S,S,
M`#.9````____````````````(?D$!10`!``L`````!(`$@```SY(NMS^D(Q)
MJQUJB,U[QY(G<N``!$"*JNE9GNT*JV5@WSC^RGR\QT!:)D>\_5A(5V;&Y-6*
MQ-)E.HE8K]AL`@`[````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA
M<F5A+VQA;F<O````````````````````````````````````````````````
M```````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q
M,#4Q-30S,S<U-@`P,C,U,3``(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V
M:6-E<R]E9&ET;W(O:'1M;&%R96$O;&%N9R]E;BYJ<P``````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#$U-3(U`#$P-3$U-#,S-S4V`#`R-#0V,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````O+R!),3A.(&-O;G-T
M86YT<PH*+R\@3$%.1SH@(F5N(BP@14Y#3T1)3D<Z(%541BTX('P@25-/+3@X
M-3DM,0HO+R!!=71H;W(Z($UI:&%I($)A>F]N+"!H='1P.B\O9'EN87)C:"YC
M;VTO;6ES:&]O"@HO+R!&3U(@5%)!3E-,051/4E,Z"B\O"B\O("`@,2X@4$Q%
M05-%(%!55"!93U52($-/3E1!0U0@24Y&3R!)3B!42$4@04)/5D4@3$E.10HO
M+R`@("`@("AA="!L96%S="!A('9A;&ED(&5M86EL(&%D9')E<W,I"B\O"B\O
M("`@,BX@4$Q%05-%(%1262!43R!54T4@551&+3@@1D]2($5.0T]$24Y'.PHO
M+R`@("`@("AI9B!T:&ES(&ES(&YO="!P;W-S:6)L92P@<&QE87-E(&EN8VQU
M9&4@82!C;VUM96YT"B\O("`@("`@('1H870@<W1A=&5S('=H870@96YC;V1I
M;F<@:7,@;F5C97-S87)Y+BD*"DA434Q!<F5A+DDQ.$X@/2!["@H)+R\@=&AE
M(&9O;&QO=VEN9R!S:&]U;&0@8F4@=&AE(&9I;&5N86UE('=I=&AO=70@+FIS
M(&5X=&5N<VEO;@H)+R\@:70@=VEL;"!B92!U<V5D(&9O<B!A=71O;6%T:6-A
M;&QY(&QO860@<&QU9VEN(&QA;F=U86=E+@H);&%N9SH@(F5N(BP*"@ET;V]L
M=&EP<SH@>PH)"6)O;&0Z("`@("`@("`@("`B0F]L9"(L"@D):71A;&EC.B`@
M("`@("`@("))=&%L:6,B+`H)"75N9&5R;&EN93H@("`@("`B56YD97)L:6YE
M(BP*"0ES=')I:V5T:')O=6=H.B`@(E-T<FEK971H<F]U9V@B+`H)"7-U8G-C
M<FEP=#H@("`@("`B4W5B<V-R:7!T(BP*"0ES=7!E<G-C<FEP=#H@("`@(E-U
M<&5R<V-R:7!T(BP*"0EJ=7-T:69Y;&5F=#H@("`@(DIU<W1I9GD@3&5F="(L
M"@D):G5S=&EF>6-E;G1E<CH@(")*=7-T:69Y($-E;G1E<B(L"@D):G5S=&EF
M>7)I9VAT.B`@(")*=7-T:69Y(%)I9VAT(BP*"0EJ=7-T:69Y9G5L;#H@("`@
M(DIU<W1I9GD@1G5L;"(L"@D);W)D97)E9&QI<W0Z("`@(")/<F1E<F5D($QI
M<W0B+`H)"75N;W)D97)E9&QI<W0Z("`B0G5L;&5T960@3&ES="(L"@D);W5T
M9&5N=#H@("`@("`@(")$96-R96%S92!);F1E;G0B+`H)"6EN9&5N=#H@("`@
M("`@("`B26YC<F5A<V4@26YD96YT(BP*"0EF;W)E8V]L;W(Z("`@("`@(D9O
M;G0@0V]L;W(B+`H)"6AI;&ET96-O;&]R.B`@("`B0F%C:V=R;W5N9"!#;VQO
M<B(L"@D):&]R:7IO;G1A;')U;&4Z(")(;W)I>F]N=&%L(%)U;&4B+`H)"6-R
M96%T96QI;FLZ("`@("`B26YS97)T(%=E8B!,:6YK(BP*"0EI;G-E<G1I;6%G
M93H@("`@(DEN<V5R="]-;V1I9GD@26UA9V4B+`H)"6EN<V5R='1A8FQE.B`@
M("`B26YS97)T(%1A8FQE(BP*"0EH=&UL;6]D93H@("`@("`@(E1O9V=L92!(
M5$U,(%-O=7)C92(L"@D)<&]P=7!E9&ET;W(Z("`@(")%;FQA<F=E($5D:71O
M<B(L"@D)86)O=70Z("`@("`@("`@(")!8F]U="!T:&ES(&5D:71O<B(L"@D)
M<VAO=VAE;'`Z("`@("`@(")(96QP('5S:6YG(&5D:71O<B(L"@D)=&5X=&EN
M9&EC871O<CH@(")#=7)R96YT('-T>6QE(BP*"0EU;F1O.B`@("`@("`@("`@
M(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(BP*"0ER961O.B`@("`@("`@("`@
M(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(BP*"0EC=70Z("`@("`@("`@("`@
M(D-U="!S96QE8W1I;VXB+`H)"6-O<'DZ("`@("`@("`@("`B0V]P>2!S96QE
M8W1I;VXB+`H)"7!A<W1E.B`@("`@("`@("`B4&%S=&4@9G)O;2!C;&EP8F]A
M<F0B+`H)"6QE9G1T;W)I9VAT.B`@("`B1&ER96-T:6]N(&QE9G0@=&\@<FEG
M:'0B+`H)"7)I9VAT=&]L969T.B`@("`B1&ER96-T:6]N(')I9VAT('1O(&QE
M9G0B+`H)"7)E;6]V969O<FUA=#H@("`B4F5M;W9E(&9O<FUA='1I;F<B+`H)
M"7!R:6YT.B`@("`@("`@("`B4')I;G0@9&]C=6UE;G0B+`H)"6MI;&QW;W)D
M.B`@("`@("`B0VQE87(@35-/9F9I8V4@=&%G<R(*"7TL"@H)8G5T=&]N<SH@
M>PH)"2)O:R(Z("`@("`@("`@("`B3TLB+`H)"2)C86YC96PB.B`@("`@("`B
M0V%N8V5L(@H)?2P*"@EM<V<Z('L*"0DB4&%T:"(Z("`@("`@("`@(E!A=&@B
M+`H)"2)415A47TU/1$4B.B`@("`B66]U(&%R92!I;B!415A4($U/1$4N("!5
M<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N
M(BP*"@D)(DE%+7-U8VMS+69U;&PM<V-R965N(B`Z"@D)+R\@=')A;G-L871E
M(&AE<F4*"0DB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U
M<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@(B`K"@D)(F1U
M92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R
M:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@(B`K"@D)
M(F1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N
M9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O
M=W,@.7@@(B`K"@D)(FET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T
M(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B
M;V]T+EQN7&XB("L*"0DB66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@
M<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C
M<F5E;B!E9&ET;W(N(BP*"@D)(DUO>BU#;&EP8F]A<F0B(#H*"0DB56YP<FEV
M:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P
M<F]G<F%M871I8V%L;'D@(B`K"@D)(F9O<B!S96-U<FET>2!R96%S;VYS+B`@
M0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO
M<F<@(B`K"@D)(G=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I
M<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@H)?2P*"@ED:6%L;V=S.B![
M"@D)+R\@0V]M;6]N"@D)(D]+(B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#H@(D]+(BP*"0DB0V%N8V5L(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B0V%N
M8V5L(BP*"@D)(D%L:6=N;65N=#HB("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@(D%L:6=N;65N=#HB+`H)"2).;W0@<V5T(B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(").
M;W0@<V5T(BP*"0DB3&5F="(@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@.B`B3&5F="(L"@D)(E)I9VAT(B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(E)I9VAT
M(BP*"0DB5&5X='1O<"(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B5&5X='1O<"(L"@D)(D%B<VUI9&1L92(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(D%B<VUI9&1L
M92(L"@D)(D)A<V5L:6YE(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(D)A<V5L:6YE(BP*"0DB06)S8F]T=&]M(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B06)S8F]T
M=&]M(BP*"0DB0F]T=&]M(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@.B`B0F]T=&]M(BP*"0DB36ED9&QE(B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B36ED9&QE
M(BP*"0DB5&]P(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B5&]P(BP*"@D)(DQA>6]U="(@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DQA>6]U="(L"@D)
M(E-P86-I;F<B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#H@(E-P86-I;F<B+`H)"2)(;W)I>F]N=&%L.B(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")(;W)I>F]N=&%L.B(L
M"@D)(DAO<FEZ;VYT86P@<&%D9&EN9R(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#H@(DAO<FEZ;VYT86P@<&%D9&EN9R(L"@D)(E9E<G1I8V%L
M.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(E9E<G1I8V%L.B(L"@D)(E9E<G1I8V%L('!A9&1I;F<B("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#H@(E9E<G1I8V%L('!A9&1I;F<B+`H)
M"2)";W)D97(@=&AI8VMN97-S.B(@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`Z(")";W)D97(@=&AI8VMN97-S.B(L"@D)(DQE879E(&5M<'1Y
M(&9O<B!N;R!B;W)D97(B("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DQE
M879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B+`H*"0DO+R!);G-E<G0@3&EN:PH)
M"2));G-E<G0O36]D:69Y($QI;FLB("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`Z("));G-E<G0O36]D:69Y($QI;FLB+`H)"2).;VYE("AU<V4@
M:6UP;&EC:70I(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(").
M;VYE("AU<V4@:6UP;&EC:70I(BP*"0DB3F5W('=I;F1O=R`H7V)L86YK*2(@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B3F5W('=I;F1O=R`H
M7V)L86YK*2(L"@D)(E-A;64@9G)A;64@*%]S96QF*2(@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#H@(E-A;64@9G)A;64@*%]S96QF*2(L"@D)
M(E1O<"!F<F%M92`H7W1O<"DB("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#H@(E1O<"!F<F%M92`H7W1O<"DB+`H)"2)/=&AE<B(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")/=&AE
M<B(L"@D)(E1A<F=E=#HB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(E1A<F=E=#HB+`H)"2)4:71L92`H=&]O;'1I<"DZ
M(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")4:71L92`H
M=&]O;'1I<"DZ(BP*"0DB55),.B(@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@.B`B55),.B(L"@D)(EEO=2!M=7-T(&5N
M=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(@(#H@(EEO
M=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T
M;R(L"@D)+R\@26YS97)T(%1A8FQE"@D)(DEN<V5R="!486)L92(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DEN<V5R="!486)L
M92(L"@D)(E)O=W,Z(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(E)O=W,Z(BP*"0DB3G5M8F5R(&]F(')O=W,B("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B3G5M8F5R(&]F
M(')O=W,B+`H)"2)#;VQS.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Z(")#;VQS.B(L"@D)(DYU;6)E<B!O9B!C;VQU
M;6YS(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DYU;6)E
M<B!O9B!C;VQU;6YS(BP*"0DB5VED=&@Z(B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B5VED=&@Z(BP*"0DB5VED=&@@
M;V8@=&AE('1A8FQE(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M.B`B5VED=&@@;V8@=&AE('1A8FQE(BP*"0DB4&5R8V5N="(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B4&5R8V5N="(L
M"@D)(E!I>&5L<R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#H@(E!I>&5L<R(L"@D)(D5M(B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(D5M(BP*"0DB5VED
M=&@@=6YI="(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@.B`B5VED=&@@=6YI="(L"@D)(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B
M;&4B("`@("`@("`@("`@("`@("`@("`@("`@(#H@(E!O<VET:6]N:6YG(&]F
M('1H:7,@=&%B;&4B+`H)"2)#96QL('-P86-I;F<Z(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z(")#96QL('-P86-I;F<Z(BP*"0DB
M4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(@("`@("`@("`@("`@("`@
M("`@("`@.B`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(L"@D)(D-E
M;&P@<&%D9&EN9SHB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(D-E;&P@<&%D9&EN9SHB+`H)"2)3<&%C92!B971W965N(&-O;G1E
M;G0@86YD(&)O<F1E<B!I;B!C96QL(B`@("`@("`@("`Z(")3<&%C92!B971W
M965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(BP*"0DO+R!);G-E<G0@
M26UA9V4*"0DB26YS97)T($EM86=E(B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@.B`B26YS97)T($EM86=E(BP*"0DB26UA9V4@55),
M.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B
M26UA9V4@55),.B(L"@D)(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(@("`@
M("`@("`@("`@("`@("`@("`@("`@(#H@(D5N=&5R('1H92!I;6%G92!54DP@
M:&5R92(L"@D)(E!R979I97<B("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@(E!R979I97<B+`H)"2)0<F5V:65W('1H92!I
M;6%G92!I;B!A(&YE=R!W:6YD;W<B("`@("`@("`@("`@("`@("`Z(")0<F5V
M:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B+`H)"2)!;'1E<FYA=&4@
M=&5X=#HB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")!
M;'1E<FYA=&4@=&5X=#HB+`H)"2)&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S
M=7!P;W)T(&EM86=E<R(@("`@("`@("`@("`Z(")&;W(@8G)O=W-E<G,@=&AA
M="!D;VXG="!S=7!P;W)T(&EM86=E<R(L"@D)(E!O<VET:6]N:6YG(&]F('1H
M:7,@:6UA9V4B("`@("`@("`@("`@("`@("`@("`@("`@(#H@(E!O<VET:6]N
M:6YG(&]F('1H:7,@:6UA9V4B+`H)"2));6%G92!0<F5V:65W.B(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("));6%G92!0<F5V:65W
M.B(*"7T*?3L*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M
M;&%R96$O<&QU9VEN<R\`````````````````````````````````````````
M`````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P
M`#$P-3$U-#,S-S4V`#`R-#(U,``@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E
M<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+T%N<V5L26UA9V4O````
M````````````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-38`,#(V,C4U`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I
M;G,O06YS96Q);6%G92]A;G-E;"UI;6%G92YJ<P`````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3$P,0`Q,#4Q-30S,S<U
M-@`P,S`W-S(`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+R\@06YS96P@26UA9V4@4&QU9VEN(&9O<B!(5$U,07)E82TS+C`*
M+R\@4&QU9VEN('1H870@86QL;W=S('1H92!I;G-E<G1I;VX@;V8@:6UA9V5S
M(&9R;VT@=&AE"B\O($AO<F1E(&9R86UE=V]R:R!M;V1U;&4@06YS96P@:6YT
M;R!A('1E>'0*+R\*+R\@36]D=6QE(')E=7-E<R!(5$U,07)E82!C;V1E"B\O
M"B\O($EM<&QE;65N=&%T:6]N.B!2;V5L($=L;W5D96UA;G,@/')O96Q`9VQO
M=61E;6%N<RYI;F9O/@HO+PHO+R`H8RD@,C`P-"X*+R\@1&ES=')I8G5T960@
M=6YD97(@=&AE('-A;64@=&5R;7,@87,@2%1-3$%R96$@:71S96QF+@HO+R!4
M:&ES(&YO=&EC92!-55-4('-T87D@:6YT86-T(&9O<B!U<V4@*'-E92!L:6-E
M;G-E+G1X="DN"B\O"B\O("1)9#H@86YS96PM:6UA9V4N:G,L=B`Q+C$@,C`P
M-"\P.2\P."`Q-CHP-CHQ,R!L86YC97(@17AP("0*"@IF=6YC=&EO;B!!;G-E
M;$EM86=E*&5D:71O<BD*>PH)=&AI<RYE9&ET;W(@/2!E9&ET;W(["@EV87(@
M:3$X;B`]($%N<V5L26UA9V4N23$X3CL*?3L*"@I!;G-E;$EM86=E+E]P;'5G
M:6Y);F9O(#T@>PH);F%M92`@("`@("`@("`Z(")!;G-E;$EM86=E(BP*"79E
M<G-I;VX@("`@("`@.B`B,2XP(BP*"61E=F5L;W!E<B`@("`@.B`B4F]E;"!'
M;&]U9&5M86YS(BP*"61E=F5L;W!E<E]U<FP@.B`B:'1T<#HO+W=W=RYG;&]U
M9&5M86YS+FEN9F\O(BP*("`@("`@("!S<&]N<V]R("`@("`@(#H@(DAO<F1E
M(%!R;VIE8W0B+`H@("`@("`@('-P;VYS;W)?=7)L("`@.B`B:'1T<#HO+W=W
M=RYH;W)D92YO<F<O(BP*"6QI8V5N<V4@("`@("`@.B`B:'1M;$%R96$B"GT[
M"@H*+R\@0V%L;&5D('=H96X@=&AE('5S97(@8VQI8VMS(&]N("));G-E<G1)
M;6%G92(@8G5T=&]N+B`@268@86X@:6UA9V4@:7,@86QR96%D>0HO+R!T:&5R
M92P@:70@=VEL;"!J=7-T(&UO9&EF>2!I="=S('!R;W!E<G1I97,N"B\O(%1H
M:7,@9G5N8W1I;VX@;W9E<G)I9&5S('1H92!N871I=F4@2%1-3$%R96$@9G5N
M8W1I;VX*2%1-3$%R96$N<')O=&]T>7!E+E]I;G-E<G1);6%G92`](&9U;F-T
M:6]N*&EM86=E*2!["@EV87(@961I=&]R(#T@=&AI<SL)+R\@9F]R(&YE<W1E
M9"!F=6YC=&EO;G,*"79A<B!O=71P87)A;2`](&YU;&P["@H):68@*'1Y<&5O
M9B!I;6%G92`]/2`B=6YD969I;F5D(BD@>PH)"6EM86=E(#T@=&AI<RYG9710
M87)E;G1%;&5M96YT*"D["@D):68@*&EM86=E("8F("$O7FEM9R0O:2YT97-T
M*&EM86=E+G1A9TYA;64I*0H)"0EI;6%G92`](&YU;&P["@E]"@EI9B`H:6UA
M9V4I(&]U='!A<F%M(#T@>PH)"69?8F%S92`@(#H@961I=&]R+F-O;F9I9RYB
M87-E55),+`H)"69?=7)L("`@(#H@2%1-3$%R96$N:7-?:64@/R!E9&ET;W(N
M<W1R:7!"87-E55),*&EM86=E+G-R8RD@.B!I;6%G92YG971!='1R:6)U=&4H
M(G-R8R(I+`H)"69?86QT("`@(#H@:6UA9V4N86QT+`H)"69?8F]R9&5R(#H@
M:6UA9V4N8F]R9&5R+`H)"69?86QI9VX@(#H@:6UA9V4N86QI9VXL"@D)9E]V
M97)T("`@.B!I;6%G92YV<W!A8V4L"@D)9E]H;W)I>B`@.B!I;6%G92YH<W!A
M8V4*"7T["@H@("`@=F%R(&UA;F%G97(@/2!?961I=&]R7W5R;"`K("=P;'5G
M:6YS+T%N<V5L26UA9V4O:6YS97)T7VEM86=E+G!H<"<["@H)1&EA;&]G*&UA
M;F%G97(L(&9U;F-T:6]N*'!A<F%M*2!["B\O"71H:7,N7W!O<'5P1&EA;&]G
M*&UA;F%G97(L(&9U;F-T:6]N*'!A<F%M*2!["@D):68@*"%P87)A;2D@>PDO
M+R!U<V5R(&UU<W0@:&%V92!P<F5S<V5D($-A;F-E;`H)"0ER971U<FX@9F%L
M<V4["@D)?0H)"79A<B!I;6<@/2!I;6%G93L*"0EI9B`H(6EM9RD@>PH)"0EV
M87(@<V5L(#T@961I=&]R+E]G971396QE8W1I;VXH*3L*"0D)=F%R(')A;F=E
M(#T@961I=&]R+E]C<F5A=&5286YG92AS96PI.PH)"0EE9&ET;W(N7V1O8RYE
M>&5C0V]M;6%N9"@B:6YS97)T:6UA9V4B+"!F86QS92P@<&%R86TN9E]U<FPI
M.PH)"0EI9B`H2%1-3$%R96$N:7-?:64I('L*"0D)"6EM9R`](')A;F=E+G!A
M<F5N=$5L96UE;G0H*3L*"0D)"2\O('=O;F1E<B!I9B!T:&ES('=O<FMS+BXN
M"@D)"0EI9B`H:6UG+G1A9TYA;64N=&],;W=E<D-A<V4H*2`A/2`B:6UG(BD@
M>PH)"0D)"6EM9R`](&EM9RYP<F5V:6]U<U-I8FQI;F<["@D)"0E]"@D)"7T@
M96QS92!["@D)"0EI;6<@/2!R86YG92YS=&%R=$-O;G1A:6YE<BYP<F5V:6]U
M<U-I8FQI;F<["@D)"7T*"0E](&5L<V4@>PH)"0EI;6<N<W)C(#T@<&%R86TN
M9E]U<FP["@D)?0H*"0EF;W(@*'9A<B!F:65L9"!I;B!P87)A;2D@>PH)"0EV
M87(@=F%L=64@/2!P87)A;5MF:65L9%T["@D)"7-W:71C:"`H9FEE;&0I('L*
M"0D)("`@(&-A<V4@(F9?86QT(B`@("`Z(&EM9RYA;'0)(#T@=F%L=64[(&)R
M96%K.PH)"0D@("`@8V%S92`B9E]B;W)D97(B(#H@:6UG+F)O<F1E<B`]('!A
M<G-E26YT*'9A;'5E('Q\("(P(BD[(&)R96%K.PH)"0D@("`@8V%S92`B9E]A
M;&EG;B(@(#H@:6UG+F%L:6=N"2`]('9A;'5E.R!B<F5A:SL*"0D)("`@(&-A
M<V4@(F9?=F5R="(@("`Z(&EM9RYV<W!A8V4@/2!P87)S94EN="AV86QU92!\
M?"`B,"(I.R!B<F5A:SL*"0D)("`@(&-A<V4@(F9?:&]R:7HB("`Z(&EM9RYH
M<W!A8V4@/2!P87)S94EN="AV86QU92!\?"`B,"(I.R!B<F5A:SL*"0D)?0H)
M"7T*"7TL(&]U='!A<F%M*3L*?3L*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]!;G-E;$EM86=E+VEN
M<V5R=%]I;6%G92YP:'```````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#$V,S`U`#$P-3$U-#,S-S4V`#`S,30T,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`H*+RHJ
M"B`J("1(;W)D93H@:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L
M=6=I;G,O06YS96Q);6%G92]I;G-E<G1?:6UA9V4N<&AP+'8@,2XU+C8N-2`R
M,#`U+S$P+S$X(#$Q.C,T.C`R(&IA;B!%>'`@)`H@*B\*"B\O($-H96-K(&9O
M<B!A('!R:6]R(&1E9FEN:71I;VX@;V8@2$]21$5?0D%312`H<&5R:&%P<R!B
M>2!A;B!A=71O7W!R97!E;F1?9FEL90HO+R!D969I;FET:6]N(&9O<B!S:71E
M(&-U<W1O;6EZ871I;VXI+@II9B`H(61E9FEN960H)TA/4D1%7T)!4T4G*2D@
M>PH@("`@0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I
M("X@)R\N+B\N+B\N+B\N+B\N+B<I.PI]"@HO+R!,;V%D('1H92!(;W)D92!&
M<F%M97=O<FL@8V]R92P@86YD('-E="!U<"!I;F-L=7-I;VX@<&%T:',N"G)E
M<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8V]R92YP:'`G.PH*+R\@
M4F5G:7-T<GD*)')E9VES=')Y(#T@)E)E9VES=')Y.CIS:6YG;&5T;VXH*3L*
M"B\J($1E=&5R;6EN92!H;W<@=V4@=V5R92!C86QL960[('=I=&@@82!54DPL
M(&]R('=I=&@@82!G86QL97)Y(&ED("HO"B1G86QL97)Y;&ES="`]("1R96=I
M<W1R>2T^8V%L;"@G:6UA9V5S+VQI<W1'86QL97)I97,G+"!A<G)A>2AN=6QL
M*2D["B1G86QL97)Y7VED(#T@571I;#HZ9V5T1F]R;41A=&$H)V=A;&QE<GDG
M+"!K97DH)&=A;&QE<GEL:7-T*2D["B1I;6%G96QI<W0@/2`D<F5G:7-T<GDM
M/F-A;&PH)VEM86=E<R]L:7-T26UA9V5S)RP@87)R87DH;G5L;"P@)&=A;&QE
M<GE?:60L(%!%4DU37U-(3U<L("=S8W)E96XG+"!T<G5E*2D["B1F:7)S=%]I
M;6%G92`](&-O=6YT*"1I;6%G96QI<W0I(#\@)&EM86=E;&ES=%MK97DH)&EM
M86=E;&ES="E=6R=U<FPG72`Z("<G.PH*/SX*/&AT;6P^"@H\:&5A9#X*("`\
M=&ET;&4^26YS97)T($EM86=E/"]T:71L93X*"CQS8W)I<'0@='EP93TB=&5X
M="]J879A<V-R:7!T(B!S<F,](BXN+RXN+W!O<'5P<R]P;W!U<"YJ<R(^/"]S
M8W)I<'0^"@H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"@IW:6YD
M;W<N<F5S:7IE5&\H-#`P+"`R,#`I.PH*9G5N8W1I;VX@26YI="@I('L*("!?
M7V1L9U]I;FET*"D["B`@=F%R('!A<F%M(#T@=VEN9&]W+F1I86QO9T%R9W5M
M96YT<SL*("!I9B`H<&%R86TI('L*("`@("`@9&]C=6UE;G0N9V5T16QE;65N
M=$)Y260H(F9?=7)L(BDN=F%L=64@/2!P87)A;5LB9E]U<FPB73L*("`@("`@
M9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(F9?86QT(BDN=F%L=64@/2!P87)A
M;5LB9E]A;'0B73L*("`@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(F9?
M8F]R9&5R(BDN=F%L=64@/2!P87)A;5LB9E]B;W)D97(B73L*("`@("`@9&]C
M=6UE;G0N9V5T16QE;65N=$)Y260H(F9?86QI9VXB*2YV86QU92`]('!A<F%M
M6R)F7V%L:6=N(ET["B`@("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")F
M7W9E<G0B*2YV86QU92`]('!A<F%M6R)F7W9E<G0B73L*("`@("`@9&]C=6UE
M;G0N9V5T16QE;65N=$)Y260H(F9?:&]R:7HB*2YV86QU92`]('!A<F%M6R)F
M7VAO<FEZ(ET["B`@("`@('=I;F1O=RYI<')E=FEE=RYL;V-A=&EO;BYR97!L
M86-E*'!A<F%M+F9?=7)L*3L*("!]"B`@9&]C=6UE;G0N9V5T16QE;65N=$)Y
M260H(F9?=7)L(BDN9F]C=7,H*3L*?3L*"F9U;F-T:6]N(&]N3TLH*2!["B`@
M=F%R(')E<75I<F5D(#T@>PH@("`@(F9?=7)L(CH@(EEO=2!M=7-T(&5N=&5R
M('1H92!54DPB"B`@?3L*("!F;W(@*'9A<B!I(&EN(')E<75I<F5D*2!["B`@
M("!V87(@96P@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"AI*3L*("`@(&EF
M("@A96PN=F%L=64I('L*("`@("`@86QE<G0H<F5Q=6ER961;:5TI.PH@("`@
M("!E;"YF;V-U<R@I.PH@("`@("!R971U<FX@9F%L<V4["B`@("!]"B`@?0H@
M("\O('!A<W,@9&%T82!B86-K('1O('1H92!C86QL:6YG('=I;F1O=PH@('9A
M<B!F:65L9',@/2!;(F9?=7)L(BP@(F9?86QT(BP@(F9?86QI9VXB+"`B9E]B
M;W)D97(B+`H@("`@("`@("`@("`@("`@(F9?:&]R:7HB+"`B9E]V97)T(ET[
M"B`@=F%R('!A<F%M(#T@;F5W($]B:F5C="@I.PH@(&9O<B`H=F%R(&D@:6X@
M9FEE;&1S*2!["B`@("!V87(@:60@/2!F:65L9'-;:5T["B`@("!V87(@96P@
M/2!D;V-U;65N="YG971%;&5M96YT0GE)9"AI9"D["B`@("!P87)A;5MI9%T@
M/2!E;"YV86QU93L*("!]"B`@7U]D;&=?8VQO<V4H<&%R86TI.PH@(')E='5R
M;B!F86QS93L*?3L*"F9U;F-T:6]N(&]N0V%N8V5L*"D@>PH@(%]?9&QG7V-L
M;W-E*&YU;&PI.PH@(')E='5R;B!F86QS93L*?3L*"F9U;F-T:6]N(&]N4')E
M=FEE=R@I('L*("!V87(@9E]U<FP@/2!D;V-U;65N="YG971%;&5M96YT0GE)
M9"@B9E]U<FPB*3L*("!V87(@=7)L(#T@9E]U<FPN=F%L=64["B`@:68@*"%U
M<FPI('L*("`@(&%L97)T*")9;W4@:&%V92!T;R!E;G1E<B!A;B!54DP@9FER
M<W0B*3L*("`@(&9?=7)L+F9O8W5S*"D["B`@("!R971U<FX@9F%L<V4["B`@
M?0H@('=I;F1O=RYI<')E=FEE=RYL;V-A=&EO;BYR97!L86-E*"=S:&]W:6UA
M9V4N:'1M;#\G("L@=7)L*3L*("!R971U<FX@9F%L<V4["GT["@IF=6YC=&EO
M;B!C:&%N9V5'86QL97)Y*"D@>PH@('9A<B!R96QO861?=7)L(#T@9&]C=6UE
M;G0N;&]C871I;VXN:')E9CL*"B`@<F5L;V%D7W5R;"`@("`@/2!R96QO861?
M=7)L+G-U8G-T<FEN9R@P+')E;&]A9%]U<FPN;&%S=$EN9&5X3V8H)S\G*2D[
M"B`@<F5L;V%D7W5R;"`@("`@/2!R96QO861?=7)L("L@)S]G86QL97)Y/2<@
M*R!D;V-U;65N="YF;W)M<ULP72YG86QL97)Y+G9A;'5E.PH*("!D;V-U;65N
M="YL;V-A=&EO;BYR97!L86-E*')E;&]A9%]U<FPI.PI]"CPO<V-R:7!T/@H*
M/'-T>6QE('1Y<&4](G1E>'0O8W-S(CX*:'1M;"P@8F]D>2!["B`@8F%C:V=R
M;W5N9#H@0G5T=&]N1F%C93L*("!C;VQO<CH@0G5T=&]N5&5X=#L*("!F;VYT
M.B`Q,7!X(%1A:&]M82Q697)D86YA+'-A;G,M<V5R:68["B`@;6%R9VEN.B`P
M<'@["B`@<&%D9&EN9SH@,'!X.PI]"F)O9'D@>R!P861D:6YG.B`U<'@[('T*
M=&%B;&4@>PH@(&9O;G0Z(#$Q<'@@5&%H;VUA+%9E<F1A;F$L<V%N<RUS97)I
M9CL*?0IF;W)M('`@>PH@(&UA<F=I;BUT;W`Z(#5P>#L*("!M87)G:6XM8F]T
M=&]M.B`U<'@["GT*+F9L('L@=VED=&@Z(#EE;3L@9FQO870Z(&QE9G0[('!A
M9&1I;F<Z(#)P>"`U<'@[('1E>'0M86QI9VXZ(')I9VAT.R!]"BYF<B![('=I
M9'1H.B`V96T[(&9L;V%T.B!L969T.R!P861D:6YG.B`R<'@@-7!X.R!T97AT
M+6%L:6=N.B!R:6=H=#L@?0IF:65L9'-E="![('!A9&1I;F<Z(#!P>"`Q,'!X
M(#5P>"`U<'@[('T*<V5L96-T+"!I;G!U="P@8G5T=&]N('L@9F]N=#H@,3%P
M>"!486AO;6$L5F5R9&%N82QS86YS+7-E<FEF.R!]"F)U='1O;B![('=I9'1H
M.B`W,'!X.R!]"BYS<&%C92![('!A9&1I;F<Z(#)P>#L@?0H*+G1I=&QE('L@
M8F%C:V=R;W5N9#H@(V1D9CL@8V]L;W(Z(",P,#`[(&9O;G0M=V5I9VAT.B!B
M;VQD.R!F;VYT+7-I>F4Z(#$R,"4[('!A9&1I;F<Z(#-P>"`Q,'!X.R!M87)G
M:6XM8F]T=&]M.B`Q,'!X.PIB;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@8FQA
M8VL[(&QE='1E<BUS<&%C:6YG.B`R<'@["GT*9F]R;2![('!A9&1I;F<Z(#!P
M>#L@;6%R9VEN.B`P<'@[('T*/"]S='EL93X*"CPO:&5A9#X*"CQB;V1Y(&]N
M;&]A9#TB26YI="@I(CX*"CQD:78@8VQA<W,](G1I=&QE(CY);G-E<G0@26UA
M9V4\+V1I=CX*/"$M+2T@;F5W('-T=69F("TM+3X*/&9O<FT@86-T:6]N/2(B
M(&UE=&AO9#TB9V5T(CX*/'1A8FQE(&)O<F1E<CTB,"(@=VED=&@](C$P,"4B
M('-T>6QE/2)P861D:6YG.B`P<'@[(&UA<F=I;CH@,'!X(CX*("`\=&)O9'D^
M"B`@/'1R/@H@("`@/'1D('-T>6QE/2)W:61T:#H@-V5M.R!T97AT+6%L:6=N
M.B!R:6=H="(^1V%L;&5R>3H\+W1D/@H@("`@/'1D/CQS96QE8W0@<VEZ93TB
M,2(@;F%M93TB9V%L;&5R>2(@:60](F9?9V%L;&5R>2(@=&ET;&4](D=A;&QE
M<GD@=&\@=&%K92!I;6%G92!F<F]M(B!O;D-H86YG93TB8VAA;F=E1V%L;&5R
M>2@I.R(^"CP_<&AP(&9O<F5A8V@@*"1G86QL97)Y;&ES="!A<R`D9V%L;&5R
M>2DZ(#\^"B`@("`@(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P
M96-I86QC:&%R<R@D9V%L;&5R>2T^9V5T240H*2D@/SXB/#]P:'`@:68@*"1G
M86QL97)Y7VED(#T]("1G86QL97)Y+3YG971)9"@I*2!E8VAO("<@<V5L96-T
M960](G-E;&5C=&5D(B<@/SX^/#]P:'`@96-H;R!S=')?<F5P96%T*"<F;F)S
M<#LG+"`R("H@)&=A;&QE<GDM/F=E=$QE=F5L*"DI("X@:'1M;'-P96-I86QC
M:&%R<R@D9V%L;&5R>2T^9V5T*"=N86UE)RDI(#\^/"]O<'1I;VX^"CP_<&AP
M(&5N9&9O<F5A8V@[(#\^"B`@("`\+W-E;&5C=#X*("`@(#PO=&0^"B`@/"]T
M<CX*("`\='(^"B`@("`\=&0@<W1Y;&4](G=I9'1H.B`W96T[('1E>'0M86QI
M9VXZ(')I9VAT(CY);6%G92!F<F]M(&=A;&QE<GDZ/"]T9#X*("`@(#QT9#X\
M<V5L96-T('-I>F4](C$B(&YA;64](FEM9U]G86QL97)Y(B!I9#TB9E]I;6=?
M9V%L;&5R>2(@=&ET;&4](DEM86=E(&9R;VT@9V%L;&5R>2(@;VY#:&%N9V4]
M(F1O8W5M96YT+F9O<FUS6S!=+G5R;"YV86QU92`](&1O8W5M96YT+F9O<FUS
M6S!=+FEM9U]G86QL97)Y+G9A;'5E(CX*/#]P:'`@9F]R96%C:"`H)&EM86=E
M;&ES="!A<R`D:60@/3X@)&EM86=E*3H@/SX*("`@("`@/&]P=&EO;B!V86QU
M93TB/#]P:'`@96-H;R`D:6UA9V5;)W5R;"==(#\^(CX\/W!H<"!E8VAO("1I
M;6%G95LG;F%M92==(#\^/"]O<'1I;VX^"CP_<&AP(&5N9&9O<F5A8V@[(#\^
M"B`@("`\+W-E;&5C=#X*("`@(#PO=&0^"B`@/"]T<CX*"B`@/'1R/@H@("`@
M/'1D('-T>6QE/2)W:61T:#H@-V5M.R!T97AT+6%L:6=N.B!R:6=H="(^26UA
M9V4@55),.CPO=&0^"B`@("`\=&0^/&EN<'5T('1Y<&4](G1E>'0B(&YA;64]
M(G5R;"(@:60](F9?=7)L(B!S='EL93TB=VED=&@Z-S4E(@H@("`@("!T:71L
M93TB16YT97(@=&AE(&EM86=E(%523"!H97)E(B!V86QU93TB/#]P:'`@96-H
M;R`D9FER<W1?:6UA9V4@/SXB("\^"B`@("`@(#QB=71T;VX@;F%M93TB<')E
M=FEE=R(@;VYC;&EC:STB<F5T=7)N(&]N4')E=FEE=R@I.R(*("`@("`@=&ET
M;&4](E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(^4')E=FEE
M=SPO8G5T=&]N/@H@("`@/"]T9#X*("`\+W1R/@H@(#QT<CX*("`@(#QT9"!S
M='EL93TB=VED=&@Z(#=E;3L@=&5X="UA;&EG;CH@<FEG:'0B/D%L=&5R;F%T
M92!T97AT.CPO=&0^"B`@("`\=&0^/&EN<'5T('1Y<&4](G1E>'0B(&YA;64]
M(F%L="(@:60](F9?86QT(B!S='EL93TB=VED=&@Z,3`P)2(*("`@("`@=&ET
M;&4](D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(B`O
M/CPO=&0^"B`@/"]T<CX*"B`@/"]T8F]D>3X*/"]T86)L93X*"CQP("\^"@H\
M9FEE;&1S970@<W1Y;&4](F9L;V%T.B!L969T.R!M87)G:6XM;&5F=#H@-7!X
M.R(^"CQL96=E;F0^3&%Y;W5T/"]L96=E;F0^"@H\9&EV(&-L87-S/2)S<&%C
M92(^/"]D:78^"@H\9&EV(&-L87-S/2)F;"(^06QI9VYM96YT.CPO9&EV/@H\
M<V5L96-T('-I>F4](C$B(&YA;64](F%L:6=N(B!I9#TB9E]A;&EG;B(*("!T
M:71L93TB4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(^"B`@/&]P=&EO;B!V
M86QU93TB(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/DYO="!S970\
M+V]P=&EO;CX*("`\;W!T:6]N('9A;'5E/2)L969T(B`@("`@("`@("`@("`@
M("`@("`@("`@("`^3&5F=#PO;W!T:6]N/@H@(#QO<'1I;VX@=F%L=64](G)I
M9VAT(B`@("`@("`@("`@("`@("`@("`@("`@(#Y2:6=H=#PO;W!T:6]N/@H@
M(#QO<'1I;VX@=F%L=64](G1E>'1T;W`B("`@("`@("`@("`@("`@("`@("`@
M(#Y497AT=&]P/"]O<'1I;VX^"B`@/&]P=&EO;B!V86QU93TB86)S;6ED9&QE
M(B`@("`@("`@("`@("`@("`@("`@/D%B<VUI9&1L93PO;W!T:6]N/@H@(#QO
M<'1I;VX@=F%L=64](F)A<V5L:6YE(B!S96QE8W1E9#TB,2(@("`@("`@(#Y"
M87-E;&EN93PO;W!T:6]N/@H@(#QO<'1I;VX@=F%L=64](F%B<V)O='1O;2(@
M("`@("`@("`@("`@("`@("`@(#Y!8G-B;W1T;VT\+V]P=&EO;CX*("`\;W!T
M:6]N('9A;'5E/2)B;W1T;VTB("`@("`@("`@("`@("`@("`@("`@("`^0F]T
M=&]M/"]O<'1I;VX^"B`@/&]P=&EO;B!V86QU93TB;6ED9&QE(B`@("`@("`@
M("`@("`@("`@("`@("`@/DUI9&1L93PO;W!T:6]N/@H@(#QO<'1I;VX@=F%L
M=64](G1O<"(@("`@("`@("`@("`@("`@("`@("`@("`@(#Y4;W`\+V]P=&EO
M;CX*/"]S96QE8W0^"@H\<"`O/@H*/&1I=B!C;&%S<STB9FPB/D)O<F1E<B!T
M:&EC:VYE<W,Z/"]D:78^"CQI;G!U="!T>7!E/2)T97AT(B!N86UE/2)B;W)D
M97(B(&ED/2)F7V)O<F1E<B(@<VEZ93TB-2(*=&ET;&4](DQE879E(&5M<'1Y
M(&9O<B!N;R!B;W)D97(B("\^"@H\9&EV(&-L87-S/2)S<&%C92(^/"]D:78^
M"@H\+V9I96QD<V5T/@H*/&9I96QD<V5T('-T>6QE/2)F;&]A=#IR:6=H=#L@
M;6%R9VEN+7)I9VAT.B`U<'@[(CX*/&QE9V5N9#Y3<&%C:6YG/"]L96=E;F0^
M"@H\9&EV(&-L87-S/2)S<&%C92(^/"]D:78^"@H\9&EV(&-L87-S/2)F<B(^
M2&]R:7IO;G1A;#H\+V1I=CX*/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](FAO
M<FEZ(B!I9#TB9E]H;W)I>B(@<VEZ93TB-2(*=&ET;&4](DAO<FEZ;VYT86P@
M<&%D9&EN9R(@+SX*"CQP("\^"@H\9&EV(&-L87-S/2)F<B(^5F5R=&EC86PZ
M/"]D:78^"CQI;G!U="!T>7!E/2)T97AT(B!N86UE/2)V97)T(B!I9#TB9E]V
M97)T(B!S:7IE/2(U(@IT:71L93TB5F5R=&EC86P@<&%D9&EN9R(@+SX*"CQD
M:78@8VQA<W,](G-P86-E(CX\+V1I=CX*"CPO9FEE;&1S970^"CQB<B!C;&5A
M<CTB86QL(B`O/@H\=&%B;&4@=VED=&@](C$P,"4B('-T>6QE/2)M87)G:6XM
M8F]T=&]M.B`P+C)E;2(^"B`\='(^"B`@/'1D('9A;&EG;CTB8F]T=&]M(CX*
M("`@($EM86=E(%!R979I97<Z/&)R("\^"B`@("`\:69R86UE(&YA;64](FEP
M<F5V:65W(B!I9#TB:7!R979I97<B(&9R86UE8F]R9&5R/2(P(B!S='EL93TB
M8F]R9&5R(#H@,7!X('-O;&ED(&=R87D[(B!H96EG:'0](C(P,"(@=VED=&@]
M(C,P,"(@<W)C/2(B/CPO:69R86UE/@H@(#PO=&0^"B`@/'1D('9A;&EG;CTB
M8F]T=&]M(B!S='EL93TB=&5X="UA;&EG;CH@<FEG:'0B/@H@("`@/&)U='1O
M;B!T>7!E/2)B=71T;VXB(&YA;64](F]K(B!O;F-L:6-K/2)R971U<FX@;VY/
M2R@I.R(^3TL\+V)U='1O;CX\8G(^"B`@("`\8G5T=&]N('1Y<&4](F)U='1O
M;B(@;F%M93TB8V%N8V5L(B!O;F-L:6-K/2)R971U<FX@;VY#86YC96PH*3LB
M/D-A;F-E;#PO8G5T=&]N/@H@(#PO=&0^"B`\+W1R/@H\+W1A8FQE/@H\+V9O
M<FT^"CPO8F]D>3X*/"]H=&UL/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+T%N<V5L26UA9V4O
M;&%N9R\`````````````````````````````````,#`P,#<U-0`P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-38`,#(W,3<V`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L
M=6=I;G,O06YS96Q);6%G92]L86YG+V5N+FIS````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S$U,0`Q,#4Q-30S
M,S<U-@`P,S`Q,S8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+R\@23$X3B!C;VYS=&%N=',*"B\O($Q!3D<Z(")E;B(L($5.
M0T]$24Y'.B!55$8M."!\($E33RTX.#4Y+3$*+R\@075T:&]R.B!-:6AA:2!"
M87IO;BP@:'1T<#HO+V1Y;F%R8V@N8V]M+VUI<VAO;PH*+R\@1D]2(%1204Y3
M3$%43U)3.@HO+PHO+R`@(#$N(%!,14%312!0550@64]54B!#3TY404-4($E.
M1D\@24X@5$A%($%"3U9%($Q)3D4*+R\@("`@("`H870@;&5A<W0@82!V86QI
M9"!E;6%I;"!A9&1R97-S*0HO+PHO+R`@(#(N(%!,14%312!44ED@5$\@55-%
M(%541BTX($9/4B!%3D-/1$E.1SL*+R\@("`@("`H:68@=&AI<R!I<R!N;W0@
M<&]S<VEB;&4L('!L96%S92!I;F-L=61E(&$@8V]M;65N=`HO+R`@("`@("!T
M:&%T('-T871E<R!W:&%T(&5N8V]D:6YG(&ES(&YE8V5S<V%R>2XI"@I!;G-E
M;$EM86=E+DDQ.$X@/2!["@DO+R!)=&5M<R!T:&%T(&%P<&5A<B!I;B!M96YU
M+B`@4&QE87-E(&YO=&4@=&AA="!A;B!U;F1E<G-C;W)E("A?*0H)+R\@8VAA
M<F%C=&5R(&EN('1H92!T<F%N<VQA=&EO;B`H<FEG:'0@8V]L=6UN*2!W:6QL
M(&-A=7-E('1H92!F;VQL;W=I;F<*"2\O(&QE='1E<B!T;R!B96-O;64@=6YD
M97)L:6YE9"!A;F0@8F4@<VAO<G1C=70@9F]R('1H870@;65N=2!O<'1I;VXN
M"@H)(DEN<V5R="!);6%G92(@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#H@(DEN<V5R="!);6%G92(L"@DB26UA9V4@55),.B(@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B26UA9V4@
M55),.B(L"@DB16YT97(@=&AE(&EM86=E(%523"!H97)E(B`@("`@("`@("`@
M("`@("`@("`@("`@("`@.B`B16YT97(@=&AE(&EM86=E(%523"!H97)E(BP*
M"2)0<F5V:65W(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`Z(")0<F5V:65W(BP*"2)0<F5V:65W('1H92!I;6%G92!I;B!A
M(&YE=R!W:6YD;W<B("`@("`@("`@("`@("`@("`Z(")0<F5V:65W('1H92!I
M;6%G92!I;B!A(&YE=R!W:6YD;W<B+`H)(D%L=&5R;F%T92!T97AT.B(@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(D%L=&5R;F%T92!T
M97AT.B(L"@DB1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G
M97,B("`@("`@("`@("`@.B`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P
M<&]R="!I;6%G97,B+`H)(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B("`@
M("`@("`@("`@("`@("`@("`@("`@(#H@(E!O<VET:6]N:6YG(&]F('1H:7,@
M:6UA9V4B+`H)(DEM86=E(%!R979I97<Z(B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@(DEM86=E(%!R979I97<Z(BP*"2)'86QL97)Y
M.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z
M(")'86QL97)Y.B(L"@DB1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB("`@
M("`@("`@("`@("`@("`@("`@("`@.B`B1V%L;&5R>2!T;R!T86ME(&EM86=E
M(&9R;VTB+`H)(DEM86=E(&9R;VT@9V%L;&5R>3HB("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@(DEM86=E(&9R;VT@9V%L;&5R>3HB+`H)(DEM
M86=E(&9R;VT@9V%L;&5R>2(@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(DEM86=E(&9R;VT@9V%L;&5R>2(*?3L*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS
M+T%N<V5L26UA9V4O<VAO=VEM86=E+FAT;6P`````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R,#,`,3`U,34T,S,W-38`
M,#,Q,3(Q`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#QB;V1Y/@H\<V-R:7!T/@H@9&]C=6UE;G0N=W)I=&4H)SQI;6<@:'-P
M86-E/2(P(B!V<W!A8V4](C`B('-R8STB)R`K(&1O8W5M96YT+FQO8V%T:6]N
M+G-E87)C:"YS=6)S='(H,2D@*R`G(CXG*3L*/"]S8W)I<'0^"CPO8F]D>3X*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]#;VYT97AT365N
M=2\``````````````````````````````````````#`P,#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S4V`#`R-C4R,0`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P
M;'5G:6YS+T-O;G1E>'1-96YU+V-O;G1E>'0M;65N=2YJ<P``````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,S,U-38`,3`U,34T
M,S,W-38`,#,Q-3(Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"\O($-O;G1E>'0@365N=2!0;'5G:6X@9F]R($A434Q!<F5A
M+3,N,`HO+R!3<&]N<V]R960@8GD@=W=W+F%M97)I8V%N8FEB;&4N;W)G"B\O
M($EM<&QE;65N=&%T:6]N(&)Y($UI:&%I($)A>F]N+"!H='1P.B\O9'EN87)C
M:"YC;VTO;6ES:&]O+PHO+PHO+R`H8RD@9'EN87)C:"YC;VT@,C`P,RTR,#`U
M+@HO+R!$:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!T97)M<R!A<R!(5$U,
M07)E82!I='-E;&8N"B\O(%1H:7,@;F]T:6-E($U54U0@<W1A>2!I;G1A8W0@
M9F]R('5S92`H<V5E(&QI8V5N<V4N='AT*2X*+R\*+R\@)$ED.B!C;VYT97AT
M+6UE;G4N:G,L=B`Q+C8@,C`P-2\P,2\R,"`Q-SHT.3HP,R!M:7-H;V\@17AP
M("0*"DA434Q!<F5A+FQO8613='EL92@B;65N=2YC<W,B+"`B0V]N=&5X=$UE
M;G4B*3L*"F9U;F-T:6]N($-O;G1E>'1-96YU*&5D:71O<BD@>PH)=&AI<RYE
M9&ET;W(@/2!E9&ET;W(["GT["@I#;VYT97AT365N=2Y?<&QU9VEN26YF;R`]
M('L*"6YA;64@("`@("`@("`@.B`B0V]N=&5X=$UE;G4B+`H)=F5R<VEO;B`@
M("`@("`Z("(Q+C`B+`H)9&5V96QO<&5R("`@("`Z(")-:6AA:2!"87IO;B(L
M"@ED979E;&]P97)?=7)L(#H@(FAT='`Z+R]D>6YA<F-H+F-O;2]M:7-H;V\O
M(BP*"6-?;W=N97(@("`@("`@.B`B9'EN87)C:"YC;VTB+`H)<W!O;G-O<B`@
M("`@("`Z(")!;65R:6-A;B!":6)L92!3;V-I971Y(BP*"7-P;VYS;W)?=7)L
M("`@.B`B:'1T<#HO+W=W=RYA;65R:6-A;F)I8FQE+F]R9R(L"@EL:6-E;G-E
M("`@("`@(#H@(FAT;6Q!<F5A(@I].PH*0V]N=&5X=$UE;G4N<')O=&]T>7!E
M+F]N1V5N97)A=&4@/2!F=6YC=&EO;B@I('L*"79A<B!S96QF(#T@=&AI<SL*
M"79A<B!D;V,@/2!T:&ES+F5D:71O<F1O8R`]('1H:7,N961I=&]R+E]I9G)A
M;64N8V]N=&5N=%=I;F1O=RYD;V-U;65N=#L*"4A434Q!<F5A+E]A9&1%=F5N
M=',H9&]C+"!;(F-O;G1E>'1M96YU(ETL"@D)"2`@("!F=6YC=&EO;B`H979E
M;G0I('L*"0D)"2`@("!R971U<FX@<V5L9BYP;W!U<$UE;G4H2%1-3$%R96$N
M:7-?:64@/R!S96QF+F5D:71O<BY?:69R86UE+F-O;G1E;G17:6YD;W<N979E
M;G0@.B!E=F5N="D["@D)"2`@("!]*3L*"71H:7,N8W5R<F5N=$UE;G4@/2!N
M=6QL.PI].PH*0V]N=&5X=$UE;G4N<')O=&]T>7!E+F=E=$-O;G1E>'1-96YU
M(#T@9G5N8W1I;VXH=&%R9V5T*2!["@EV87(@<V5L9B`]('1H:7,["@EV87(@
M961I=&]R(#T@=&AI<RYE9&ET;W(["@EV87(@8V]N9FEG(#T@961I=&]R+F-O
M;F9I9SL*"79A<B!M96YU(#T@6UT["@EV87(@=&)O(#T@=&AI<RYE9&ET;W(N
M<&QU9VEN<RY486)L94]P97)A=&EO;G,["@EI9B`H=&)O*2!T8F\@/2!T8F\N
M:6YS=&%N8V4["@EV87(@:3$X;B`]($-O;G1E>'1-96YU+DDQ.$X["@H)=F%R
M('-E;&5C=&EO;B`](&5D:71O<BYH87-396QE8W1E9%1E>'0H*3L*"6EF("AS
M96QE8W1I;VXI"@D);65N=2YP=7-H*%L@:3$X;ELB0W5T(ETL(&9U;F-T:6]N
M*"D@>R!E9&ET;W(N97AE8T-O;6UA;F0H(F-U="(I.R!]+"!N=6QL+"!C;VYF
M:6<N8G1N3&ES=%LB8W5T(EU;,5T@72P*"0D)("!;(&DQ.&Y;(D-O<'DB72P@
M9G5N8W1I;VXH*2![(&5D:71O<BYE>&5C0V]M;6%N9"@B8V]P>2(I.R!]+"!N
M=6QL+"!C;VYF:6<N8G1N3&ES=%LB8V]P>2)=6S%=(%TI.PH);65N=2YP=7-H
M*%L@:3$X;ELB4&%S=&4B72P@9G5N8W1I;VXH*2![(&5D:71O<BYE>&5C0V]M
M;6%N9"@B<&%S=&4B*3L@?2P@;G5L;"P@8V]N9FEG+F)T;DQI<W1;(G!A<W1E
M(EU;,5T@72D["@H)=F%R(&-U<G)E;G1487)G970@/2!T87)G970["@EV87(@
M96QM96YU<R`](%M=.PH)=F%R('1M<#L*"@EV87(@;&EN:R`](&YU;&P["@EV
M87(@=&%B;&4@/2!N=6QL.PH)=F%R('1R(#T@;G5L;#L*"79A<B!T9"`](&YU
M;&P["@EV87(@:6UG(#T@;G5L;#L*"@EF=6YC=&EO;B!T86)L94]P97)A=&EO
M;BAO<&-O9&4I('L*"0ET8F\N8G5T=&]N4')E<W,H961I=&]R+"!O<&-O9&4I
M.PH)?3L*"@EF=6YC=&EO;B!I;G-E<G1087)A*&-U<G)E;G1487)G970L(&%F
M=&5R*2!["@D)=F%R(&5L(#T@8W5R<F5N=%1A<F=E=#L*"0EV87(@<&%R(#T@
M96PN<&%R96YT3F]D93L*"0EV87(@<"`](&5D:71O<BY?9&]C+F-R96%T945L
M96UE;G0H(G`B*3L*"0EP+F%P<&5N9$-H:6QD*&5D:71O<BY?9&]C+F-R96%T
M945L96UE;G0H(F)R(BDI.PH)"7!A<BYI;G-E<G1"969O<F4H<"P@869T97(@
M/R!E;"YN97AT4VEB;&EN9R`Z(&5L*3L*"0EV87(@<V5L(#T@961I=&]R+E]G
M971396QE8W1I;VXH*3L*"0EV87(@<F%N9V4@/2!E9&ET;W(N7V-R96%T95)A
M;F=E*'-E;"D["@D):68@*"%(5$U,07)E82YI<U]I92D@>PH)"0ES96PN<F5M
M;W9E06QL4F%N9V5S*"D["@D)"7)A;F=E+G-E;&5C=$YO9&5#;VYT96YT<RAP
M*3L*"0D)<F%N9V4N8V]L;&%P<V4H=')U92D["@D)"7-E;"YA9&1286YG92AR
M86YG92D["@D)?2!E;'-E('L*"0D)<F%N9V4N;6]V951O16QE;65N=%1E>'0H
M<"D["@D)"7)A;F=E+F-O;&QA<'-E*'1R=64I.PH)"0ER86YG92YS96QE8W0H
M*3L*"0E]"@E].PH*"69O<B`H.R!T87)G970[('1A<F=E="`]('1A<F=E="YP
M87)E;G1.;V1E*2!["@D)=F%R('1A9R`]('1A<F=E="YT86=.86UE.PH)"6EF
M("@A=&%G*0H)"0EC;VYT:6YU93L*"0ET86<@/2!T86<N=&],;W=E<D-A<V4H
M*3L*"0ES=VET8V@@*'1A9RD@>PH)"2`@("!C87-E(")I;6<B.@H)"0EI;6<@
M/2!T87)G970["@D)"65L;65N=7,N<'5S:"AN=6QL+`H)"0D)("`@("!;(&DQ
M.&Y;(DEM86=E(%!R;W!E<G1I97,B72P*"0D)"2`@("`@("!F=6YC=&EO;B@I
M('L*"0D)"0D@("`@("`@961I=&]R+E]I;G-E<G1);6%G92AI;6<I.PH)"0D)
M("`@("`@('TL"@D)"0D@("`@("`@:3$X;ELB4VAO=R!T:&4@:6UA9V4@<')O
M<&5R=&EE<R!D:6%L;V<B72P*"0D)"2`@("`@("!C;VYF:6<N8G1N3&ES=%LB
M:6YS97)T:6UA9V4B75LQ72!="@D)"0DI.PH)"0EB<F5A:SL*"0D@("`@8V%S
M92`B82(Z"@D)"6QI;FL@/2!T87)G970["@D)"65L;65N=7,N<'5S:"AN=6QL
M+`H)"0D)("`@("!;(&DQ.&Y;(DUO9&EF>2!,:6YK(ETL"@D)"0D@("`@("`@
M9G5N8W1I;VXH*2![(&5D:71O<BYE>&5C0V]M;6%N9"@B8W)E871E;&EN:R(L
M('1R=64I.R!]+`H)"0D)("`@("`@(&DQ.&Y;(D-U<G)E;G0@55),(&ES(ET@
M*R`G.B`G("L@;&EN:RYH<F5F+`H)"0D)("`@("`@(&-O;F9I9RYB=&Y,:7-T
M6R)C<F5A=&5L:6YK(EU;,5T@72P*"@D)"0D@("`@(%L@:3$X;ELB0VAE8VL@
M3&EN:R)=+`H)"0D)("`@("`@(&9U;F-T:6]N*"D@>R!W:6YD;W<N;W!E;BAL
M:6YK+FAR968I.R!]+`H)"0D)("`@("`@(&DQ.&Y;(D]P96YS('1H:7,@;&EN
M:R!I;B!A(&YE=R!W:6YD;W<B72!=+`H*"0D)"2`@("`@6R!I,3AN6R)296UO
M=F4@3&EN:R)=+`H)"0D)("`@("`@(&9U;F-T:6]N*"D@>PH)"0D)"2`@("`@
M("!I9B`H8V]N9FER;2AI,3AN6R)0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W
M86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(ET@*R`B7&XB("L*"0D)"0D)
M"2`@(&DQ.&Y;(DQI;FL@<&]I;G1S('1O.B)=("L@(B`B("L@;&EN:RYH<F5F
M*2D@>PH)"0D)"0D@("`@("`@=VAI;&4@*&QI;FLN9FER<W1#:&EL9"D*"0D)
M"0D)"2`@("`@("!L:6YK+G!A<F5N=$YO9&4N:6YS97)T0F5F;W)E*&QI;FLN
M9FER<W1#:&EL9"P@;&EN:RD["@D)"0D)"2`@("`@("!L:6YK+G!A<F5N=$YO
M9&4N<F5M;W9E0VAI;&0H;&EN:RD["@D)"0D)("`@("`@('T*"0D)"2`@("`@
M("!]+`H)"0D)("`@("`@(&DQ.&Y;(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M
M96YT(ET@70H)"0D)*3L*"0D)8G)E86L["@D)("`@(&-A<V4@(G1D(CH*"0D)
M=&0@/2!T87)G970["@D)"6EF("@A=&)O*2!B<F5A:SL*"0D)96QM96YU<RYP
M=7-H*&YU;&PL"@D)"0D@("`@(%L@:3$X;ELB0V5L;"!0<F]P97)T:65S(ETL
M"@D)"0D@("`@("`@9G5N8W1I;VXH*2![('1A8FQE3W!E<F%T:6]N*")43RUC
M96QL+7!R;W`B*3L@?2P*"0D)"2`@("`@("!I,3AN6R)3:&]W('1H92!486)L
M92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(ETL"@D)"0D@("`@("`@8V]N9FEG
M+F)T;DQI<W1;(E1/+6-E;&PM<')O<")=6S%=(%TL"@D)"0D@("`@(%L@:3$X
M;ELB1&5L971E($-E;&PB72P*"0D)"2`@("`@("!F=6YC=&EO;B@I('L@=&%B
M;&5/<&5R871I;VXH(E1/+6-E;&PM9&5L971E(BD[('TL(&YU;&PL"@D)"0D@
M("`@("`@8V]N9FEG+F)T;DQI<W1;(E1/+6-E;&PM9&5L971E(EU;,5T@70H)
M"0D)*3L*"0D)8G)E86L["@D)("`@(&-A<V4@(G1R(CH*"0D)='(@/2!T87)G
M970["@D)"6EF("@A=&)O*2!B<F5A:SL*"0D)96QM96YU<RYP=7-H*&YU;&PL
M"@D)"0D@("`@(%L@:3$X;ELB4F]W(%!R;W!E<G1I97,B72P*"0D)"2`@("`@
M("!F=6YC=&EO;B@I('L@=&%B;&5/<&5R871I;VXH(E1/+7)O=RUP<F]P(BD[
M('TL"@D)"0D@("`@("`@:3$X;ELB4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E
M<G1I97,@9&EA;&]G(ETL"@D)"0D@("`@("`@8V]N9FEG+F)T;DQI<W1;(E1/
M+7)O=RUP<F]P(EU;,5T@72P*"@D)"0D@("`@(%L@:3$X;ELB26YS97)T(%)O
M=R!"969O<F4B72P*"0D)"2`@("`@("!F=6YC=&EO;B@I('L@=&%B;&5/<&5R
M871I;VXH(E1/+7)O=RUI;G-E<G0M86)O=F4B*3L@?2P*"0D)"2`@("`@("!I
M,3AN6R));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B
M72P*"0D)"2`@("`@("!C;VYF:6<N8G1N3&ES=%LB5$\M<F]W+6EN<V5R="UA
M8F]V92)=6S%=(%TL"@H)"0D)("`@("!;(&DQ.&Y;(DEN<V5R="!2;W<@069T
M97(B72P*"0D)"2`@("`@("!F=6YC=&EO;B@I('L@=&%B;&5/<&5R871I;VXH
M(E1/+7)O=RUI;G-E<G0M=6YD97(B*3L@?2P*"0D)"2`@("`@("!I,3AN6R))
M;G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92)=+`H)"0D)
M("`@("`@(&-O;F9I9RYB=&Y,:7-T6R)43RUR;W<M:6YS97)T+75N9&5R(EU;
M,5T@72P*"@D)"0D@("`@(%L@:3$X;ELB1&5L971E(%)O=R)=+`H)"0D)("`@
M("`@(&9U;F-T:6]N*"D@>R!T86)L94]P97)A=&EO;B@B5$\M<F]W+61E;&5T
M92(I.R!]+`H)"0D)("`@("`@(&DQ.&Y;(D1E;&5T92!T:&4@8W5R<F5N="!R
M;W<B72P*"0D)"2`@("`@("!C;VYF:6<N8G1N3&ES=%LB5$\M<F]W+61E;&5T
M92)=6S%=(%T*"0D)"2D["@D)"6)R96%K.PH)"2`@("!C87-E(")T86)L92(Z
M"@D)"71A8FQE(#T@=&%R9V5T.PH)"0EI9B`H(71B;RD@8G)E86L["@D)"65L
M;65N=7,N<'5S:"AN=6QL+`H)"0D)("`@("!;(&DQ.&Y;(E1A8FQE(%!R;W!E
M<G1I97,B72P*"0D)"2`@("`@("!F=6YC=&EO;B@I('L@=&%B;&5/<&5R871I
M;VXH(E1/+71A8FQE+7!R;W`B*3L@?2P*"0D)"2`@("`@("!I,3AN6R)3:&]W
M('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R)=+`H)"0D)("`@("`@(&-O
M;F9I9RYB=&Y,:7-T6R)43RUT86)L92UP<F]P(EU;,5T@72P*"@D)"0D@("`@
M(%L@:3$X;ELB26YS97)T($-O;'5M;B!"969O<F4B72P*"0D)"2`@("`@("!F
M=6YC=&EO;B@I('L@=&%B;&5/<&5R871I;VXH(E1/+6-O;"UI;G-E<G0M8F5F
M;W)E(BD[('TL"@D)"0D@("`@("`@:3$X;ELB26YS97)T(&$@;F5W(&-O;'5M
M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(ETL"@D)"0D@("`@("`@8V]N9FEG
M+F)T;DQI<W1;(E1/+6-O;"UI;G-E<G0M8F5F;W)E(EU;,5T@72P*"@D)"0D@
M("`@(%L@:3$X;ELB26YS97)T($-O;'5M;B!!9G1E<B)=+`H)"0D)("`@("`@
M(&9U;F-T:6]N*"D@>R!T86)L94]P97)A=&EO;B@B5$\M8V]L+6EN<V5R="UA
M9G1E<B(I.R!]+`H)"0D)("`@("`@(&DQ.&Y;(DEN<V5R="!A(&YE=R!C;VQU
M;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(ETL"@D)"0D@("`@("`@8V]N9FEG
M+F)T;DQI<W1;(E1/+6-O;"UI;G-E<G0M869T97(B75LQ72!=+`H*"0D)"2`@
M("`@6R!I,3AN6R)$96QE=&4@0V]L=6UN(ETL"@D)"0D@("`@("`@9G5N8W1I
M;VXH*2![('1A8FQE3W!E<F%T:6]N*")43RUC;VPM9&5L971E(BD[('TL"@D)
M"0D@("`@("`@:3$X;ELB1&5L971E('1H92!C=7)R96YT(&-O;'5M;B)=+`H)
M"0D)("`@("`@(&-O;F9I9RYB=&Y,:7-T6R)43RUC;VPM9&5L971E(EU;,5T@
M70H)"0D)*3L*"0D)8G)E86L["@D)("`@(&-A<V4@(F)O9'DB.@H)"0EE;&UE
M;G5S+G!U<V@H;G5L;"P*"0D)"2`@("`@6R!I,3AN6R)*=7-T:69Y($QE9G0B
M72P*"0D)"2`@("`@("!F=6YC=&EO;B@I('L@961I=&]R+F5X96-#;VUM86YD
M*")J=7-T:69Y;&5F="(I.R!]+"!N=6QL+`H)"0D)("`@("`@(&-O;F9I9RYB
M=&Y,:7-T6R)J=7-T:69Y;&5F=")=6S%=(%TL"@D)"0D@("`@(%L@:3$X;ELB
M2G5S=&EF>2!#96YT97(B72P*"0D)"2`@("`@("!F=6YC=&EO;B@I('L@961I
M=&]R+F5X96-#;VUM86YD*")J=7-T:69Y8V5N=&5R(BD[('TL(&YU;&PL"@D)
M"0D@("`@("`@8V]N9FEG+F)T;DQI<W1;(FIU<W1I9GEC96YT97(B75LQ72!=
M+`H)"0D)("`@("!;(&DQ.&Y;(DIU<W1I9GD@4FEG:'0B72P*"0D)"2`@("`@
M("!F=6YC=&EO;B@I('L@961I=&]R+F5X96-#;VUM86YD*")J=7-T:69Y<FEG
M:'0B*3L@?2P@;G5L;"P*"0D)"2`@("`@("!C;VYF:6<N8G1N3&ES=%LB:G5S
M=&EF>7)I9VAT(EU;,5T@72P*"0D)"2`@("`@6R!I,3AN6R)*=7-T:69Y($9U
M;&PB72P*"0D)"2`@("`@("!F=6YC=&EO;B@I('L@961I=&]R+F5X96-#;VUM
M86YD*")J=7-T:69Y9G5L;"(I.R!]+"!N=6QL+`H)"0D)("`@("`@(&-O;F9I
M9RYB=&Y,:7-T6R)J=7-T:69Y9G5L;")=6S%=(%T*"0D)"2D["@D)"6)R96%K
M.PH)"7T*"7T*"@EI9B`H<V5L96-T:6]N("8F("%L:6YK*0H)"6UE;G4N<'5S
M:"AN=6QL+"!;(&DQ.&Y;(DUA:V4@;&EN:R)=+`H)"0D)("!F=6YC=&EO;B@I
M('L@961I=&]R+F5X96-#;VUM86YD*")C<F5A=&5L:6YK(BP@=')U92D[('TL
M"@D)"0D@(&DQ.&Y;(D-R96%T92!A(&QI;FLB72P*"0D)"2`@8V]N9FEG+F)T
M;DQI<W1;(F-R96%T96QI;FLB75LQ72!=*3L*"@EF;W(@*'9A<B!I(#T@,#L@
M:2`\(&5L;65N=7,N;&5N9W1H.R`K*VDI"@D);65N=2YP=7-H*&5L;65N=7-;
M:5TI.PH*"6EF("@A+VAT;6Q\8F]D>2]I+G1E<W0H8W5R<F5N=%1A<F=E="YT
M86=.86UE*2D@>PH)"71A8FQE(#\@*'1M<"`]('1A8FQE+"!T86)L92`](&YU
M;&PI(#H@*'1M<"`](&-U<G)E;G1487)G970I.PH)"6UE;G4N<'5S:"AN=6QL
M+`H)"0D@(%L@:3$X;ELB4F5M;W9E('1H92)=("L@(B`F;'0[(B`K('1M<"YT
M86=.86UE("L@(B9G=#L@(B`K(&DQ.&Y;(D5L96UE;G0B72P*"0D)("`@(&9U
M;F-T:6]N*"D@>PH)"0D)("`@(&EF("AC;VYF:7)M*&DQ.&Y;(E!L96%S92!C
M;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB
M72`K("(@(B`K"@D)"0D)"71M<"YT86=.86UE*2D@>PH)"0D)"2`@("!V87(@
M96P@/2!T;7`["@D)"0D)("`@('9A<B!P(#T@96PN<&%R96YT3F]D93L*"0D)
M"0D@("`@<"YR96UO=F5#:&EL9"AE;"D["@D)"0D)("`@(&EF("A(5$U,07)E
M82YI<U]G96-K;RD@>PH)"0D)"0D@("`@:68@*'`N=&%G3F%M92YT;TQO=V5R
M0V%S92@I(#T](")T9"(@)B8@(7`N:&%S0VAI;&1.;V1E<R@I*0H)"0D)"0D)
M("`@('`N87!P96YD0VAI;&0H961I=&]R+E]D;V,N8W)E871E16QE;65N="@B
M8G(B*2D["@D)"0D)"2`@("!E9&ET;W(N9F]R8V52961R87<H*3L*"0D)"0D)
M("`@(&5D:71O<BYF;V-U<T5D:71O<B@I.PH)"0D)"0D@("`@961I=&]R+G5P
M9&%T951O;VQB87(H*3L*"0D)"0D)("`@(&EF("AT86)L92D@>PH)"0D)"0D)
M("`@('9A<B!S879E7V-O;&QA<'-E(#T@=&%B;&4N<W1Y;&4N8F]R9&5R0V]L
M;&%P<V4["@D)"0D)"0D@("`@=&%B;&4N<W1Y;&4N8F]R9&5R0V]L;&%P<V4@
M/2`B8V]L;&%P<V4B.PH)"0D)"0D)("`@('1A8FQE+G-T>6QE+F)O<F1E<D-O
M;&QA<'-E(#T@(G-E<&%R871E(CL*"0D)"0D)"2`@("!T86)L92YS='EL92YB
M;W)D97)#;VQL87!S92`]('-A=F5?8V]L;&%P<V4["@D)"0D)"2`@("!]"@D)
M"0D)("`@('T*"0D)"2`@("!]"@D)"2`@("!]+`H)"0D@("`@:3$X;ELB4F5M
M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N=")=(%TL"@D)"2`@6R!I
M,3AN6R));G-E<G0@<&%R86=R87!H(&)E9F]R92)=+`H)"0D@("`@9G5N8W1I
M;VXH*2![(&EN<V5R=%!A<F$H=&UP+"!F86QS92D[('TL"@D)"2`@("!I,3AN
M6R));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B
M72!=+`H)"0D@(%L@:3$X;ELB26YS97)T('!A<F%G<F%P:"!A9G1E<B)=+`H)
M"0D@("`@9G5N8W1I;VXH*2![(&EN<V5R=%!A<F$H=&UP+"!T<G5E*3L@?2P*
M"0D)("`@(&DQ.&Y;(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R
M<F5N="!N;V1E(ET@70H)"0DI.PH)?0H)<F5T=7)N(&UE;G4["GT["@I#;VYT
M97AT365N=2YP<F]T;W1Y<&4N<&]P=7!-96YU(#T@9G5N8W1I;VXH978I('L*
M"79A<B!S96QF(#T@=&AI<SL*"79A<B!I,3AN(#T@0V]N=&5X=$UE;G4N23$X
M3CL*"6EF("AT:&ES+F-U<G)E;G1-96YU*0H)"71H:7,N8W5R<F5N=$UE;G4N
M<&%R96YT3F]D92YR96UO=F5#:&EL9"AT:&ES+F-U<G)E;G1-96YU*3L*"69U
M;F-T:6]N(&=E=%!O<RAE;"D@>PH)"79A<B!R(#T@>R!X.B!E;"YO9F9S971,
M969T+"!Y.B!E;"YO9F9S9714;W`@?3L*"0EI9B`H96PN;V9F<V5T4&%R96YT
M*2!["@D)"79A<B!T;7`@/2!G9710;W,H96PN;V9F<V5T4&%R96YT*3L*"0D)
M<BYX("L]('1M<"YX.PH)"0ER+GD@*ST@=&UP+GD["@D)?0H)"7)E='5R;B!R
M.PH)?3L*"69U;F-T:6]N(&1O8W5M96YT0VQI8VLH978I('L*"0EE=B!\?"`H
M978@/2!W:6YD;W<N979E;G0I.PH)"6EF("@A<V5L9BYC=7)R96YT365N=2D@
M>PH)"0EA;&5R="AI,3AN6R)(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S
M92!R97!O<G0A*2)=*3L*"0D)<F5T=7)N(&9A;'-E.PH)"7T*"0EV87(@96P@
M/2!(5$U,07)E82YI<U]I92`_(&5V+G-R8T5L96UE;G0@.B!E=BYT87)G970[
M"@D)9F]R("@[(&5L("$](&YU;&P@)B8@96P@(3T@<V5L9BYC=7)R96YT365N
M=3L@96P@/2!E;"YP87)E;G1.;V1E*3L*"0EI9B`H96P@/3T@;G5L;"D*"0D)
M<V5L9BYC;&]S94UE;G4H*3L*"0DO+TA434Q!<F5A+E]S=&]P179E;G0H978I
M.PH)"2\O<F5T=7)N(&9A;'-E.PH)?3L*"79A<B!K97ES(#T@6UT["@EF=6YC
M=&EO;B!K97E0<F5S<RAE=BD@>PH)"65V('Q\("AE=B`]('=I;F1O=RYE=F5N
M="D["@D)2%1-3$%R96$N7W-T;W!%=F5N="AE=BD["@D):68@*&5V+FME>4-O
M9&4@/3T@,C<I('L*"0D)<V5L9BYC;&]S94UE;G4H*3L*"0D)<F5T=7)N(&9A
M;'-E.PH)"7T*"0EV87(@:V5Y(#T@4W1R:6YG+F9R;VU#:&%R0V]D92A(5$U,
M07)E82YI<U]I92`_(&5V+FME>4-O9&4@.B!E=BYC:&%R0V]D92DN=&],;W=E
M<D-A<V4H*3L*"0EF;W(@*'9A<B!I(#T@:V5Y<RYL96YG=&@[("TM:2`^/2`P
M.RD@>PH)"0EV87(@:R`](&ME>7-;:5T["@D)"6EF("AK6S!=+G1O3&]W97)#
M87-E*"D@/3T@:V5Y*0H)"0D):ULQ72Y?7VUS:"YA8W1I=F%T92@I.PH)"7T*
M"7T["@ES96QF+F-L;W-E365N=2`](&9U;F-T:6]N*"D@>PH)"7-E;&8N8W5R
M<F5N=$UE;G4N<&%R96YT3F]D92YR96UO=F5#:&EL9"AS96QF+F-U<G)E;G1-
M96YU*3L*"0ES96QF+F-U<G)E;G1-96YU(#T@;G5L;#L*"0E(5$U,07)E82Y?
M<F5M;W9E179E;G0H9&]C=6UE;G0L(")M;W5S961O=VXB+"!D;V-U;65N=$-L
M:6-K*3L*"0E(5$U,07)E82Y?<F5M;W9E179E;G0H<V5L9BYE9&ET;W)D;V,L
M(")M;W5S961O=VXB+"!D;V-U;65N=$-L:6-K*3L*"0EI9B`H:V5Y<RYL96YG
M=&@@/B`P*0H)"0E(5$U,07)E82Y?<F5M;W9E179E;G0H<V5L9BYE9&ET;W)D
M;V,L(")K97EP<F5S<R(L(&ME>5!R97-S*3L*"0EI9B`H2%1-3$%R96$N:7-?
M:64I"@D)"7-E;&8N:650;W!U<"YH:61E*"D["@E].PH)=F%R('1A<F=E="`]
M($A434Q!<F5A+FES7VEE(#\@978N<W)C16QE;65N="`Z(&5V+G1A<F=E=#L*
M"79A<B!I9G!O<R`](&=E=%!O<RAS96QF+F5D:71O<BY?:69R86UE*3L*"79A
M<B!X(#T@978N8VQI96YT6"`K(&EF<&]S+G@["@EV87(@>2`](&5V+F-L:65N
M=%D@*R!I9G!O<RYY.PH*"79A<B!D:78["@EV87(@9&]C.PH):68@*"%(5$U,
M07)E82YI<U]I92D@>PH)"61O8R`](&1O8W5M96YT.PH)?2!E;'-E('L*"0DO
M+R!)12!S=&EN:W,*"0EV87(@<&]P=7`@/2!T:&ES+FEE4&]P=7`@/2!W:6YD
M;W<N8W)E871E4&]P=7`H*3L*"0ED;V,@/2!P;W!U<"YD;V-U;65N=#L*"0ED
M;V,N;W!E;B@I.PH)"61O8RYW<FET92@B/&AT;6P^/&AE860^/'-T>6QE('1Y
M<&4])W1E>'0O8W-S)SY`:6UP;W)T('5R;"@B("L@7V5D:71O<E]U<FP@*R`B
M<&QU9VEN<R]#;VYT97AT365N=2]M96YU+F-S<RD[(&AT;6PL(&)O9'D@>R!P
M861D:6YG.B`P<'@[(&UA<F=I;CH@,'!X.R!O=F5R9FQO=SH@:&ED9&5N.R!B
M;W)D97(Z(#!P>#L@?3PO<W1Y;&4^/"]H96%D/CQB;V1Y('5N<V5L96-T86)L
M93TG>65S)SX\+V)O9'D^/"]H=&UL/B(I.PH)"61O8RYC;&]S92@I.PH)?0H)
M9&EV(#T@9&]C+F-R96%T945L96UE;G0H(F1I=B(I.PH):68@*$A434Q!<F5A
M+FES7VEE*0H)"61I=BYU;G-E;&5C=&%B;&4@/2`B;VXB.PH)9&EV+F]N8V]N
M=&5X=&UE;G4@/2!F=6YC=&EO;B@I('L@<F5T=7)N(&9A;'-E.R!].PH)9&EV
M+F-L87-S3F%M92`](")H=&UL87)E82UC;VYT97AT+6UE;G4B.PH):68@*"%(
M5$U,07)E82YI<U]I92D*"0ED:78N<W1Y;&4N;&5F="`](&1I=BYS='EL92YT
M;W`@/2`B,'!X(CL*"61O8RYB;V1Y+F%P<&5N9$-H:6QD*&1I=BD["@H)=F%R
M('1A8FQE(#T@9&]C+F-R96%T945L96UE;G0H(G1A8FQE(BD["@ED:78N87!P
M96YD0VAI;&0H=&%B;&4I.PH)=&%B;&4N8V5L;%-P86-I;F<@/2`P.PH)=&%B
M;&4N8V5L;%!A9&1I;F<@/2`P.PH)=F%R('!A<F5N="`](&1O8RYC<F5A=&5%
M;&5M96YT*")T8F]D>2(I.PH)=&%B;&4N87!P96YD0VAI;&0H<&%R96YT*3L*
M"@EV87(@;W!T:6]N<R`]('1H:7,N9V5T0V]N=&5X=$UE;G4H=&%R9V5T*3L*
M"69O<B`H=F%R(&D@/2`P.R!I(#P@;W!T:6]N<RYL96YG=&@[("LK:2D@>PH)
M"79A<B!O<'1I;VX@/2!O<'1I;VYS6VE=.PH)"79A<B!I=&5M(#T@9&]C+F-R
M96%T945L96UE;G0H(G1R(BD["@D)<&%R96YT+F%P<&5N9$-H:6QD*&ET96TI
M.PH)"6EF("A(5$U,07)E82YI<U]I92D*"0D):71E;2YU;G-E;&5C=&%B;&4@
M/2`B;VXB.PH)"65L<V4@:71E;2YO;FUO=7-E9&]W;B`](&9U;F-T:6]N*&5V
M*2!["@D)"4A434Q!<F5A+E]S=&]P179E;G0H978I.PH)"0ER971U<FX@9F%L
M<V4["@D)?3L*"0EI9B`H(6]P=&EO;BD@>PH)"0EI=&5M+F-L87-S3F%M92`]
M(")S97!A<F%T;W(B.PH)"0EV87(@=&0@/2!D;V,N8W)E871E16QE;65N="@B
M=&0B*3L*"0D)=&0N8VQA<W-.86UE(#T@(FEC;VXB.PH)"0EV87(@245?25-?
M05]&54-+24Y'7U-(250@/2`G/B<["@D)"6EF("A(5$U,07)E82YI<U]I92D@
M>PH)"0D)=&0N=6YS96QE8W1A8FQE(#T@(F]N(CL*"0D)"4E%7TE37T%?1E5#
M2TE.1U]32$E4(#T@(B!U;G-E;&5C=&%B;&4])V]N)R!S='EL93TG:&5I9VAT
M/3%P>"<^)FYB<W`[(CL*"0D)?0H)"0ET9"YI;FYE<DA434P@/2`B/&1I=B(@
M*R!)15])4U]!7T950TM)3D=?4TA)5"`K("(\+V1I=CXB.PH)"0EV87(@=&0Q
M(#T@=&0N8VQO;F5.;V1E*'1R=64I.PH)"0ET9#$N8VQA<W-.86UE(#T@(FQA
M8F5L(CL*"0D):71E;2YA<'!E;F1#:&EL9"AT9"D["@D)"6ET96TN87!P96YD
M0VAI;&0H=&0Q*3L*"0E](&5L<V4@>PH)"0EV87(@;&%B96P@/2!O<'1I;VY;
M,%T["@D)"6ET96TN8VQA<W-.86UE(#T@(FET96TB.PH)"0EI=&5M+E]?;7-H
M(#T@>PH)"0D):71E;3H@:71E;2P*"0D)"6QA8F5L.B!L86)E;"P*"0D)"6%C
M=&EO;CH@;W!T:6]N6S%=+`H)"0D)=&]O;'1I<#H@;W!T:6]N6S)=('Q\(&YU
M;&PL"@D)"0EI8V]N.B!O<'1I;VY;,UT@?'P@;G5L;"P*"0D)"6%C=&EV871E
M.B!F=6YC=&EO;B@I('L*"0D)"0ES96QF+F-L;W-E365N=2@I.PH)"0D)"7-E
M;&8N961I=&]R+F9O8W5S161I=&]R*"D["@D)"0D)=&AI<RYA8W1I;VXH*3L*
M"0D)"7T*"0D)?3L*"0D);&%B96P@/2!L86)E;"YR97!L86-E*"]?*%MA+7I!
M+5HP+3E=*2\L("(\=3XD,3PO=3XB*3L*"0D):68@*&QA8F5L("$](&]P=&EO
M;ELP72D*"0D)"6ME>7,N<'5S:"A;(%)E9T5X<"XD,2P@:71E;2!=*3L*"0D)
M;&%B96P@/2!L86)E;"YR97!L86-E*"]?7R\L(")?(BD["@D)"79A<B!T9#$@
M/2!D;V,N8W)E871E16QE;65N="@B=&0B*3L*"0D):68@*$A434Q!<F5A+FES
M7VEE*0H)"0D)=&0Q+G5N<V5L96-T86)L92`](")O;B(["@D)"6ET96TN87!P
M96YD0VAI;&0H=&0Q*3L*"0D)=&0Q+F-L87-S3F%M92`](")I8V]N(CL*"0D)
M:68@*&ET96TN7U]M<V@N:6-O;BD*"0D)"71D,2YI;FYE<DA434P@/2`B/&EM
M9R!A;&EG;CTG;6ED9&QE)R!S<F,])R(@*R!I=&5M+E]?;7-H+FEC;VX@*R`B
M)R`O/B(["@D)"79A<B!T9#(@/2!D;V,N8W)E871E16QE;65N="@B=&0B*3L*
M"0D):68@*$A434Q!<F5A+FES7VEE*0H)"0D)=&0R+G5N<V5L96-T86)L92`]
M(")O;B(["@D)"6ET96TN87!P96YD0VAI;&0H=&0R*3L*"0D)=&0R+F-L87-S
M3F%M92`](")L86)E;"(["@D)"71D,BYI;FYE<DA434P@/2!L86)E;#L*"0D)
M:71E;2YO;FUO=7-E;W9E<B`](&9U;F-T:6]N*"D@>PH)"0D)=&AI<RYC;&%S
M<TYA;64@*ST@(B!H;W9E<B(["@D)"0ES96QF+F5D:71O<BY?<W1A='5S0F%R
M5')E92YI;FYE<DA434P@/2!T:&ES+E]?;7-H+G1O;VQT:7`@?'P@)R9N8G-P
M.R<["@D)"7T["@D)"6ET96TN;VYM;W5S96]U="`](&9U;F-T:6]N*"D@>R!T
M:&ES+F-L87-S3F%M92`](")I=&5M(CL@?3L*"0D):71E;2YO;F-O;G1E>'1M
M96YU(#T@9G5N8W1I;VXH978I('L*"0D)"71H:7,N7U]M<V@N86-T:79A=&4H
M*3L*"0D)"6EF("@A2%1-3$%R96$N:7-?:64I"@D)"0D)2%1-3$%R96$N7W-T
M;W!%=F5N="AE=BD["@D)"0ER971U<FX@9F%L<V4["@D)"7T["@D)"6ET96TN
M;VYM;W5S975P(#T@9G5N8W1I;VXH978I('L*"0D)"79A<B!T:6UE4W1A;7`@
M/2`H;F5W($1A=&4H*2DN9V5T5&EM92@I.PH)"0D):68@*'1I;653=&%M<"`M
M('-E;&8N=&EM95-T86UP(#X@-3`P*0H)"0D)"71H:7,N7U]M<V@N86-T:79A
M=&4H*3L*"0D)"6EF("@A2%1-3$%R96$N:7-?:64I"@D)"0D)2%1-3$%R96$N
M7W-T;W!%=F5N="AE=BD["@D)"0ER971U<FX@9F%L<V4["@D)"7T["@D)"2\O
M:68@*'1Y<&5O9B!O<'1I;VY;,ET@/3T@(G-T<FEN9R(I"@D)"2\O:71E;2YT
M:71L92`](&]P=&EO;ELR73L*"0E]"@E]"@H):68@*"%(5$U,07)E82YI<U]I
M92D@>PH)"79A<B!D>"`]('@@*R!D:78N;V9F<V5T5VED=&@@+2!W:6YD;W<N
M:6YN97)7:61T:"`K(#0["@D)=F%R(&1Y(#T@>2`K(&1I=BYO9F9S971(96EG
M:'0@+2!W:6YD;W<N:6YN97)(96EG:'0@*R`T.PH)"6EF("AD>"`^(#`I('@@
M+3T@9'@["@D):68@*&1Y(#X@,"D@>2`M/2!D>3L*"0ED:78N<W1Y;&4N;&5F
M="`]('@@*R`B<'@B.PH)"61I=BYS='EL92YT;W`@/2!Y("L@(G!X(CL*"7T@
M96QS92!["@D)+R\@9&5T97)M:6YE('1H92!S:7IE("AD:60@22!M96YT:6]N
M('1H870@244@<W1I;FMS/RD*"0EV87(@9F]O8F%R(#T@9&]C=6UE;G0N8W)E
M871E16QE;65N="@B9&EV(BD["@D)9F]O8F%R+F-L87-S3F%M92`](")H=&UL
M87)E82UC;VYT97AT+6UE;G4B.PH)"69O;V)A<BYI;FYE<DA434P@/2!D:78N
M:6YN97)(5$U,.PH)"61O8W5M96YT+F)O9'DN87!P96YD0VAI;&0H9F]O8F%R
M*3L*"0EV87(@=R`](&9O;V)A<BYO9F9S9717:61T:#L*"0EV87(@:"`](&9O
M;V)A<BYO9F9S971(96EG:'0["@D)9&]C=6UE;G0N8F]D>2YR96UO=F5#:&EL
M9"AF;V]B87(I.PH)"71H:7,N:650;W!U<"YS:&]W*&5V+G-C<F5E;E@L(&5V
M+G-C<F5E;EDL('<L(&@I.PH)?0H*"71H:7,N8W5R<F5N=$UE;G4@/2!D:78[
M"@ET:&ES+G1I;653=&%M<"`]("AN97<@1&%T92@I*2YG9714:6UE*"D["@H)
M2%1-3$%R96$N7V%D9$5V96YT*&1O8W5M96YT+"`B;6]U<V5D;W=N(BP@9&]C
M=6UE;G1#;&EC:RD["@E(5$U,07)E82Y?861D179E;G0H=&AI<RYE9&ET;W)D
M;V,L(")M;W5S961O=VXB+"!D;V-U;65N=$-L:6-K*3L*"6EF("AK97ES+FQE
M;F=T:"`^(#`I"@D)2%1-3$%R96$N7V%D9$5V96YT*'1H:7,N961I=&]R9&]C
M+"`B:V5Y<')E<W,B+"!K97E0<F5S<RD["@H)2%1-3$%R96$N7W-T;W!%=F5N
M="AE=BD["@ER971U<FX@9F%L<V4["GT["@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU
M9VEN<R]#;VYT97AT365N=2]L86YG+P``````````````````````````````
M`#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S
M-S4V`#`R-S0T,@`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D
M:71O<B]H=&UL87)E82]P;'5G:6YS+T-O;G1E>'1-96YU+VQA;F<O96XN:G,`
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,3$R-S4`,3`U,34T,S,W-38`,#,P-#$P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"\O($DQ.$X@8V]N<W1A;G1S"@HO
M+R!,04Y'.B`B96XB+"!%3D-/1$E.1SH@551&+3@@?"!)4T\M.#@U.2TQ"B\O
M($%U=&AO<CH@36EH86D@0F%Z;VXL(&AT='`Z+R]D>6YA<F-H+F-O;2]M:7-H
M;V\*"B\O($9/4B!44D%.4TQ!5$]24SH*+R\*+R\@("`Q+B!03$5!4T4@4%54
M(%E/55(@0T].5$%#5"!)3D9/($E.(%1(12!!0D]612!,24Y%"B\O("`@("`@
M*&%T(&QE87-T(&$@=F%L:60@96UA:6P@861D<F5S<RD*+R\*+R\@("`R+B!0
M3$5!4T4@5%)9(%1/(%5312!55$8M."!&3U(@14Y#3T1)3D<["B\O("`@("`@
M*&EF('1H:7,@:7,@;F]T('!O<W-I8FQE+"!P;&5A<V4@:6YC;'5D92!A(&-O
M;6UE;G0*+R\@("`@("`@=&AA="!S=&%T97,@=VAA="!E;F-O9&EN9R!I<R!N
M96-E<W-A<GDN*0H*0V]N=&5X=$UE;G4N23$X3B`]('L*"2\O($ET96US('1H
M870@87!P96%R(&EN(&UE;G4N("!0;&5A<V4@;F]T92!T:&%T(&%N('5N9&5R
M<V-O<F4@*%\I"@DO+R!C:&%R86-T97(@:6X@=&AE('1R86YS;&%T:6]N("AR
M:6=H="!C;VQU;6XI('=I;&P@8V%U<V4@=&AE(&9O;&QO=VEN9PH)+R\@;&5T
M=&5R('1O(&)E8V]M92!U;F1E<FQI;F5D(&%N9"!B92!S:&]R=&-U="!F;W(@
M=&AA="!M96YU(&]P=&EO;BX*"@DB0W5T(B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(D-U="(L"@DB0V]P
M>2(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#H@(D-O<'DB+`H)(E!A<W1E(B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")087-T92(L"@DB26UA
M9V4@4')O<&5R=&EE<R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#H@(E]);6%G92!0<F]P97)T:65S+BXN(BP*"2)-;V1I9GD@3&EN
M:R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M.B`B7TUO9&EF>2!,:6YK+BXN(BP*"2)#:&5C:R!,:6YK(B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B0VAE8U]K($QI
M;FLN+BXB+`H)(E)E;6]V92!,:6YK(B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z(")?4F5M;W9E($QI;FLN+BXB+`H)(D-E
M;&P@4')O<&5R=&EE<R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`Z(")#7V5L;"!0<F]P97)T:65S+BXN(BP*"2)2;W<@4')O<&5R
M=&EE<R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M.B`B4F]?=R!0<F]P97)T:65S+BXN(BP*"2));G-E<G0@4F]W($)E9F]R92(@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B25]N<V5R
M="!2;W<@0F5F;W)E(BP*"2));G-E<G0@4F]W($%F=&5R(B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B26Y?<V5R="!2;W<@069T
M97(B+`H)(D1E;&5T92!2;W<B("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Z(")?1&5L971E(%)O=R(L"@DB1&5L971E($-E
M;&PB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#H@(D1E;&5T92!#96QL(BP*"2)486)L92!0<F]P97)T:65S(B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B7U1A8FQE(%!R;W!E
M<G1I97,N+BXB+`H)(DEN<V5R="!#;VQU;6X@0F5F;W)E(B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z("));G-E<G0@7T-O;'5M;B!"969O
M<F4B+`H)(DEN<V5R="!#;VQU;6X@069T97(B("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Z("));G-E<G0@0U]O;'5M;B!!9G1E<B(L"@DB
M1&5L971E($-O;'5M;B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#H@(D1E7VQE=&4@0V]L=6UN(BP*"2)*=7-T:69Y($QE9G0B
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B
M2G5S=&EF>2!,969T(BP*"2)*=7-T:69Y($-E;G1E<B(@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B2G5S=&EF>2!#96YT97(B
M+`H)(DIU<W1I9GD@4FEG:'0B("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`Z(")*=7-T:69Y(%)I9VAT(BP*"2)*=7-T:69Y($9U
M;&PB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M.B`B2G5S=&EF>2!&=6QL(BP*"2)-86ME(&QI;FLB("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B36%K92!L:6Y?:RXN
M+B(L"@DB4F5M;W9E('1H92(@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@(E)E;6]V92!T:&4B+`H)(D5L96UE;G0B("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z
M(")%;&5M96YT+BXN(BP*"2));G-E<G0@<&%R86=R87!H(&)E9F]R92(@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B26YS97)T('!A<F%G<F%P
M:"!B969O<F4B+`H)(DEN<V5R="!P87)A9W)A<&@@869T97(B("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z("));G-E<G0@<&%R86=R87!H(&%F
M=&5R(BP*"@DO+R!/=&AE<B!L86)E;',@*'1O;VQT:7!S(&%N9"!A;&5R="]C
M;VYF:7)M(&)O>"!M97-S86=E<RD*"@DB4&QE87-E(&-O;F9I<FT@=&AA="!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(@(#H@(E!L96%S92!C
M;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB
M+`H)(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B("`@("`@
M("`@("`@("`@("`@("`Z(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O
M8W5M96YT(BP*"2)(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O
M<G0A*2(@("`@("`@("`@("`@("`@.B`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_
M("A0;&5A<V4@<F5P;W)T(2DB+`H)(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I
M97,@9&EA;&]G(B`@("`@("`@("`@("`@("`@("`@("`Z(")3:&]W('1H92!I
M;6%G92!P<F]P97)T:65S(&1I86QO9R(L"@DB36]D:69Y(%523"(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DUO9&EF
M>2!54DPB+`H)(D-U<G)E;G0@55),(&ES(B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z(")#=7)R96YT(%523"!I<R(L"@DB3W!E
M;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(@("`@("`@("`@("`@("`@
M("`@("`@(#H@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B+`H)
M(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@
M96QE;65N="XB("`Z(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O
M('5N;&EN:R!T:&ES(&5L96UE;G0N(BP*"2),:6YK('!O:6YT<R!T;SHB("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B3&EN:R!P
M;VEN=',@=&\Z(BP*"2)5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B56YL:6YK('1H92!C=7)R96YT
M(&5L96UE;G0B+`H)(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D
M:6%L;V<B("`@("`@("`@("`@("`@("`Z(")3:&]W('1H92!486)L92!#96QL
M(%!R;W!E<G1I97,@9&EA;&]G(BP*"2)3:&]W('1H92!486)L92!2;W<@4')O
M<&5R=&EE<R!D:6%L;V<B("`@("`@("`@("`@("`@("`@.B`B4VAO=R!T:&4@
M5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(BP*"2));G-E<G0@82!N97<@
M<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B("`@("`@("`@("`@("`@.B`B
M26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(BP*"2))
M;G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(@("`@("`@
M("`@("`@("`@.B`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N
M="!O;F4B+`H)(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W
M(BP*"2)3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(@("`@("`@
M("`@("`@("`@("`@("`@.B`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D
M:6%L;V<B+`H)(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R
M96YT(&]N92(@("`@("`@("`@("`Z("));G-E<G0@82!N97<@8V]L=6UN(&)E
M9F]R92!T:&4@8W5R<F5N="!O;F4B+`H)(DEN<V5R="!A(&YE=R!C;VQU;6X@
M869T97(@=&AE(&-U<G)E;G0@;VYE(B`@("`@("`@("`@("`Z("));G-E<G0@
M82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(L"@DB1&5L971E
M('1H92!C=7)R96YT(&-O;'5M;B(@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB+`H)(D-R96%T92!A
M(&QI;FLB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`Z(")#<F5A=&4@82!L:6YK(BP*"2));G-E<G0@82!P87)A9W)A<&@@8F5F
M;W)E('1H92!C=7)R96YT(&YO9&4B("`@("`@("`@("`@.B`B26YS97)T(&$@
M<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(BP*"2));G-E<G0@
M82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(@("`@("`@("`@
M("`@.B`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO
M9&4B"GT["@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V
M:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]#;VYT97AT365N=2]M96YU
M+F-S<P```````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R-#4W`#$P-3$U-#,S-S4V`#`S,#(P-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````O*B!S='EL97,@9F]R
M('1H92!#;VYT97AT365N=2`O2%1-3$%R96$@*B\*+RH@5&AE($-O;G1E>'1-
M96YU('!L=6=I;B!I<R`H8RD@9'EN87)C:"YC;VT@,C`P,RX@*B\*+RH@1&ES
M=')I8G5T960@=6YD97(@=&AE('-A;64@=&5R;7,@87,@2%1-3$%R96$@:71S
M96QF("HO"@ID:78N:'1M;&%R96$M8V]N=&5X="UM96YU('L*("!P;W-I=&EO
M;CH@86)S;VQU=&4["B`@8F]R9&5R.B`Q<'@@<V]L:60@(V%C83@Y.3L*("!P
M861D:6YG.B`R<'@["B`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F9CL*("!C;VQO
M<CH@(S`P,#L*("!C=7)S;W(Z(&1E9F%U;'0["B`@>BUI;F1E>#H@,3`P,#L*
M?0H*9&EV+FAT;6QA<F5A+6-O;G1E>'0M;65N=2!T86)L92!["B`@9F]N=#H@
M,3%P>"!T86AO;6$L=F5R9&%N82QS86YS+7-E<FEF.PH@(&)O<F1E<BUC;VQL
M87!S93H@8V]L;&%P<V4["GT*"F1I=BYH=&UL87)E82UC;VYT97AT+6UE;G4@
M='(N:71E;2!T9"YI8V]N(&EM9R!["B`@=VED=&@Z(#$X<'@["B`@:&5I9VAT
M.B`Q.'!X.PI]"@ID:78N:'1M;&%R96$M8V]N=&5X="UM96YU('1R+FET96T@
M=&0N:6-O;B!["B`@<&%D9&EN9SH@,'!X(#-P>#L*("!H96EG:'0Z(#$X<'@[
M"B`@8F%C:V=R;W5N9"UC;VQO<CH@(V-D9CL*?0H*9&EV+FAT;6QA<F5A+6-O
M;G1E>'0M;65N=2!T<BYI=&5M('1D+FQA8F5L('L*("!P861D:6YG.B`Q<'@@
M,3!P>"`Q<'@@,W!X.PI]"@ID:78N:'1M;&%R96$M8V]N=&5X="UM96YU('1R
M+G-E<&%R871O<B!T9"!["B`@<&%D9&EN9SH@,G!X(#!P>#L*?0H*9&EV+FAT
M;6QA<F5A+6-O;G1E>'0M;65N=2!T<BYS97!A<F%T;W(@=&0@9&EV('L*("!B
M;W)D97(M=&]P.B`Q<'@@<V]L:60@(V%C83@Y.3L*("!O=F5R9FQO=SH@:&ED
M9&5N.PH@('!O<VET:6]N.B!R96QA=&EV93L*?0H*9&EV+FAT;6QA<F5A+6-O
M;G1E>'0M;65N=2!T<BYS97!A<F%T;W(@=&0N:6-O;B!["B`@8F%C:V=R;W5N
M9"UC;VQO<CH@(V-D9CL*?0H*9&EV+FAT;6QA<F5A+6-O;G1E>'0M;65N=2!T
M<BYS97!A<F%T;W(@=&0N:6-O;B!D:78@>PHO*B`@;6%R9VEN+6QE9G0Z(#-P
M>#L@*B\*("!B;W)D97(M8V]L;W(Z("-F9F8["GT*"F1I=BYH=&UL87)E82UC
M;VYT97AT+6UE;G4@='(N<V5P87)A=&]R('1D+FQA8F5L(&1I=B!["B`@;6%R
M9VEN+7)I9VAT.B`S<'@["GT*"F1I=BYH=&UL87)E82UC;VYT97AT+6UE;G4@
M='(N:71E;2YH;W9E<B!["B`@8F%C:V=R;W5N9"UC;VQO<CH@(S,Q-F%C-3L*
M("!C;VQO<CH@(V9F9CL*?0H*9&EV+FAT;6QA<F5A+6-O;G1E>'0M;65N=2!T
M<BYI=&5M+FAO=F5R('1D+FEC;VX@>PH@(&)A8VMG<F]U;F0M8V]L;W(Z(",V
M,3EA9C4["GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P
M;'5G:6YS+TQI<W14>7!E+P``````````````````````````````````````
M````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T
M,S,W-38`,#(V,#(U`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O
M961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O3&ES=%1Y<&4O;&%N9R\`````````
M```````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#4Q-30S,S<U-@`P,C8W-#8`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R],:7-T
M5'EP92]L86YG+V5N+FIS`````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-#4Q`#$P-3$U-#,S-S4V`#`R-S<P
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````O
M+R!),3A.(&-O;G-T86YT<PH*+R\@3$%.1SH@(F5N(BP@14Y#3T1)3D<Z(%54
M1BTX('P@25-/+3@X-3DM,0HO+R!!=71H;W(Z($UI:&%I($)A>F]N+"!H='1P
M.B\O9'EN87)C:"YC;VTO;6ES:&]O"@HO+R!&3U(@5%)!3E-,051/4E,Z"B\O
M"B\O("`@,2X@4$Q%05-%(%!55"!93U52($-/3E1!0U0@24Y&3R!)3B!42$4@
M04)/5D4@3$E.10HO+R`@("`@("AA="!L96%S="!A('9A;&ED(&5M86EL(&%D
M9')E<W,I"B\O"B\O("`@,BX@4$Q%05-%(%1262!43R!54T4@551&+3@@1D]2
M($5.0T]$24Y'.PHO+R`@("`@("AI9B!T:&ES(&ES(&YO="!P;W-S:6)L92P@
M<&QE87-E(&EN8VQU9&4@82!C;VUM96YT"B\O("`@("`@('1H870@<W1A=&5S
M('=H870@96YC;V1I;F<@:7,@;F5C97-S87)Y+BD*"DQI<W14>7!E+DDQ.$X@
M/2!["@DB1&5C:6UA;"(@("`@("`@("`@("`@("`@.B`@("`B1&5C:6UA;"!N
M=6UB97)S(BP*"2),;W=E<B!R;VUA;B(@("`@("`@("`@("`Z("`@("),;W=E
M<B!R;VUA;B!N=6UB97)S(BP*"2)5<'!E<B!R;VUA;B(@("`@("`@("`@("`Z
M("`@(")5<'!E<B!R;VUA;B!N=6UB97)S(BP*"2),;W=E<B!L871I;B(@("`@
M("`@("`@("`Z("`@("),;W=E<B!L871I;B!L971T97)S(BP*"2)5<'!E<B!L
M871I;B(@("`@("`@("`@("`Z("`@(")5<'!E<B!L871I;B!L971T97)S(BP*
M"2),;W=E<B!G<F5E:R(@("`@("`@("`@("`Z("`@("),;W=E<B!G<F5E:R!L
M971T97)S(BP*"2),:7-T4W1Y;&54;V]L=&EP(B`@("`@("`Z("`@(")#:&]O
M<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"GT["@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN
M<R],:7-T5'EP92]L:7-T+71Y<&4N:G,``````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U,38S`#$P-3$U-#,S-S4V
M`#`S,#,R,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````O+R!,:7-T5'EP92!0;'5G:6X@9F]R($A434Q!<F5A+3,N,`HO+R!3
M<&]N<V]R960@8GD@345D5&5C:"!5;FET("T@475E96XG<R!5;FEV97)S:71Y
M"B\O($EM<&QE;65N=&%T:6]N(&)Y($UI:&%I($)A>F]N+"!H='1P.B\O9'EN
M87)C:"YC;VTO;6ES:&]O+PHO+PHO+R`H8RD@9'EN87)C:"YC;VT@,C`P,RTR
M,#`U+@HO+R!$:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!T97)M<R!A<R!(
M5$U,07)E82!I='-E;&8N"B\O(%1H:7,@;F]T:6-E($U54U0@<W1A>2!I;G1A
M8W0@9F]R('5S92`H<V5E(&QI8V5N<V4N='AT*2X*+R\*+R\@)$ED.B!L:7-T
M+71Y<&4N:G,L=B`Q+C(@,C`P-2\P,2\R,"`Q-SHT.3HP,R!M:7-H;V\@17AP
M("0*"F9U;F-T:6]N($QI<W14>7!E*&5D:71O<BD@>PH)=&AI<RYE9&ET;W(@
M/2!E9&ET;W(["@EV87(@8V9G(#T@961I=&]R+F-O;F9I9SL*"79A<B!T;V]L
M8F%R(#T@8V9G+G1O;VQB87(["@EV87(@<V5L9B`]('1H:7,["@EV87(@:3$X
M;B`]($QI<W14>7!E+DDQ.$X["@EV87(@;W!T:6]N<R`]('M].PH);W!T:6]N
M<UMI,3AN6R)$96-I;6%L(EU=(#T@(F1E8VEM86PB.PH);W!T:6]N<UMI,3AN
M6R),;W=E<B!R;VUA;B)=72`](")L;W=E<BUR;VUA;B(["@EO<'1I;VYS6VDQ
M.&Y;(E5P<&5R(')O;6%N(EU=(#T@(G5P<&5R+7)O;6%N(CL*"6]P=&EO;G-;
M:3$X;ELB3&]W97(@;&%T:6XB75T@/2`B;&]W97(M86QP:&$B.PH);W!T:6]N
M<UMI,3AN6R)5<'!E<B!L871I;B)=72`](")U<'!E<BUA;'!H82(["@EI9B`H
M(4A434Q!<F5A+FES7VEE*0H)"2\O($E%(&1O97-N)W0@<W5P<&]R="!T:&ES
M('!R;W!E<G1Y.R!E=F5N('=O<G-E+"!I="!C;VUP;&%I;G,*"0DO+R!W:71H
M(&$@9W)O<W,@97)R;W(@;65S<V%G92!W:&5N('=E('1R:65D('1O('-E;&5C
M="!I="P*"0DO+R!T:&5R969O<F4@;&5T)W,@:&ED92!I="!F<F]M('1H92!D
M86UN(")B<F]W<V5R(BX*"0EO<'1I;VYS6VDQ.&Y;(DQO=V5R(&=R965K(EU=
M(#T@(FQO=V5R+6=R965K(CL*"79A<B!O8FH@/2!["@D):60@("`@("`@("`@
M("`Z("),:7-T5'EP92(L"@D)=&]O;'1I<"`@("`@("`Z(&DQ.&Y;(DQI<W13
M='EL951O;VQT:7`B72P*"0EO<'1I;VYS("`@("`@(#H@;W!T:6]N<RP*"0EA
M8W1I;VX@("`@("`@(#H@9G5N8W1I;VXH961I=&]R*2![('-E;&8N;VY396QE
M8W0H961I=&]R+"!T:&ES*3L@?2P*"0ER969R97-H("`@("`@(#H@9G5N8W1I
M;VXH961I=&]R*2![('-E;&8N=7!D871E5F%L=64H961I=&]R+"!T:&ES*3L@
M?2P*"0EC;VYT97AT("`@("`@(#H@(F]L(@H)?3L*"6-F9RYR96=I<W1E<D1R
M;W!D;W=N*&]B:BD["@EV87(@82P@:2P@:BP@9F]U;F0@/2!F86QS93L*"69O
M<B`H:2`](#`[("%F;W5N9"`F)B!I(#P@=&]O;&)A<BYL96YG=&@[("LK:2D@
M>PH)"6$@/2!T;V]L8F%R6VE=.PH)"69O<B`H:B`](#`[(&H@/"!A+FQE;F=T
M:#L@*RMJ*2!["@D)"6EF("AA6VI=(#T](")U;F]R9&5R961L:7-T(BD@>PH)
M"0D)9F]U;F0@/2!T<G5E.PH)"0D)8G)E86L["@D)"7T*"0E]"@E]"@EI9B`H
M9F]U;F0I"@D)82YS<&QI8V4H:BP@,"P@(G-P86-E(BP@(DQI<W14>7!E(BP@
M(G-P86-E(BD["GT["@I,:7-T5'EP92Y?<&QU9VEN26YF;R`]('L*"6YA;64@
M("`@("`@("`@.B`B3&ES=%1Y<&4B+`H)=F5R<VEO;B`@("`@("`Z("(Q+C`B
M+`H)9&5V96QO<&5R("`@("`Z(")-:6AA:2!"87IO;B(L"@ED979E;&]P97)?
M=7)L(#H@(FAT='`Z+R]D>6YA<F-H+F-O;2]M:7-H;V\O(BP*"6-?;W=N97(@
M("`@("`@.B`B9'EN87)C:"YC;VTB+`H)<W!O;G-O<B`@("`@("`Z(")-1614
M96-H(%5N:70@+2!1=65E;B=S(%5N:79E<G-I='DB+`H)<W!O;G-O<E]U<FP@
M("`Z(")H='1P.B\O=W=W+G%U965N<W4N8V$O(BP*"6QI8V5N<V4@("`@("`@
M.B`B:'1M;$%R96$B"GT["@I,:7-T5'EP92YP<F]T;W1Y<&4N;VY396QE8W0@
M/2!F=6YC=&EO;BAE9&ET;W(L(&-O;6)O*2!["@EV87(@=&)O8FH@/2!E9&ET
M;W(N7W1O;VQB87)/8FIE8W1S6V-O;6)O+FED72YE;&5M96YT.PH)=F%R('!A
M<F5N="`](&5D:71O<BYG971087)E;G1%;&5M96YT*"D["@EW:&EL92`H(2]>
M;VPD+VDN=&5S="AP87)E;G0N=&%G3F%M92DI('L*"0EP87)E;G0@/2!P87)E
M;G0N<&%R96YT3F]D93L*"7T*"7!A<F5N="YS='EL92YL:7-T4W1Y;&54>7!E
M(#T@=&)O8FHN=F%L=64["GT["@I,:7-T5'EP92YP<F]T;W1Y<&4N=7!D871E
M5F%L=64@/2!F=6YC=&EO;BAE9&ET;W(L(&-O;6)O*2!["@EV87(@=&)O8FH@
M/2!E9&ET;W(N7W1O;VQB87)/8FIE8W1S6V-O;6)O+FED72YE;&5M96YT.PH)
M=F%R('!A<F5N="`](&5D:71O<BYG971087)E;G1%;&5M96YT*"D["@EW:&EL
M92`H<&%R96YT("8F("$O7F]L)"]I+G1E<W0H<&%R96YT+G1A9TYA;64I*2![
M"@D)<&%R96YT(#T@<&%R96YT+G!A<F5N=$YO9&4["@E]"@EI9B`H(7!A<F5N
M="D@>PH)"71B;V)J+G-E;&5C=&5D26YD97@@/2`P.PH)"7)E='5R;CL*"7T*
M"79A<B!T>7!E(#T@<&%R96YT+G-T>6QE+FQI<W13='EL951Y<&4["@EI9B`H
M(71Y<&4I('L*"0ET8F]B:BYS96QE8W1E9$EN9&5X(#T@,#L*"7T@96QS92![
M"@D)9F]R("AV87(@:2`]('1B;V)J+F9I<G-T0VAI;&0[(&D[(&D@/2!I+FYE
M>'13:6)L:6YG*2!["@D)"6DN<V5L96-T960@/2`H='EP92YI;F1E>$]F*&DN
M=F%L=64I("$]("TQ*3L*"0E]"@E]"GT["@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E
M<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N
M<R\`````````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-38`,#(W,S0S`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I
M;G,O5&%B;&5/<&5R871I;VYS+VEM9R\````````````````````````````P
M,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U
M-@`P,S`Q,3<`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG+V-E;&PM
M9&5L971E+F=I9@```````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,30U`#$P-3$U-#,S-S4V`#`S,C<V-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!'248X.6$2`!(`H0``````_____P``
M____(?D$`0```P`L`````!(`$@```C:<CZG+`P_;`:$&(`VU.(D$A=$@?`L@
M!"E:EJ>J=NXDAH8Y65?FZ)U4XVTJO\9PEPGRELRFI```.P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A
M+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM9R]C96QL+6EN<V5R="UA9G1E
M<BYG:68P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$V-@`Q,#4Q
M-30S,S<U-@`P,S0Q,S$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````1TE&.#EA$@`2`,(`````@.&`@`#______P```/______
M_____R'Y!`$```<`+``````2`!(```,[>+K<_O"02>,B(P]B%=9<1U5B8`:A
M19QH)XTAX#*`#*=-76/"(.`Y6Z\7NBEL,(]FX_ID@`_C;$IE)```.P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+RXO0$QO;F=,:6YK````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-#8`,3`U,34T,S0P,#``,#$Q
M,S(W`"!,````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``````````````````````````````
M`````````````````````````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT
M;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM9R]C96QL+6EN<V5R
M="UB969O<F4N9VEF````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO
M;G,O:6UG+V-E;&PM:6YS97)T+6)E9F]R92YG:3`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,38V`#$P-3$U-#,S-S4V`#`S-#$R-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!'248X.6$2`!(`
MP@````"`X8"``/______````____________(?D$`0``!P`L`````!(`$@``
M`SMXNMSNX,D#(KE8UDJ&\,14'<3WA2*)7<K*3FT@!RA,S#3<NCHY_(/:I`,4
M2ES&!_&7="R#/61O2I4D```[````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I
M=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM9R]C96QL
M+6UE<F=E+F=I9@`````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,38P,``Q,#4Q-30S,S<U-@`P,S(V,3<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````1TE&.#EA$@`2`.<``````(````"`
M`("`````@(``@`"`@,#`P,#<P*;*\$`@`&`@`(`@`*`@`,`@`.`@``!``"!`
M`$!``&!``(!``*!``,!``.!```!@`"!@`$!@`&!@`(!@`*!@`,!@`.!@``"`
M`""``$"``&"``("``*"``,"``."```"@`""@`$"@`&"@`("@`*"@`,"@`."@
M``#``"#``$#``&#``(#``*#``,#``.#```#@`"#@`$#@`&#@`(#@`*#@`,#@
M`.#@````0"``0$``0&``0(``0*``0,``0.``0``@0"`@0$`@0&`@0(`@0*`@
M0,`@0.`@0`!`0"!`0$!`0&!`0(!`0*!`0,!`0.!`0`!@0"!@0$!@0&!@0(!@
M0*!@0,!@0.!@0`"`0""`0$"`0&"`0("`0*"`0,"`0."`0`"@0""@0$"@0&"@
M0("@0*"@0,"@0."@0`#`0"#`0$#`0&#`0(#`0*#`0,#`0.#`0`#@0"#@0$#@
M0&#@0(#@0*#@0,#@0.#@0```@"``@$``@&``@(``@*``@,``@.``@``@@"`@
M@$`@@&`@@(`@@*`@@,`@@.`@@`!`@"!`@$!`@&!`@(!`@*!`@,!`@.!`@`!@
M@"!@@$!@@&!@@(!@@*!@@,!@@.!@@`"`@""`@$"`@&"`@("`@*"`@,"`@."`
M@`"@@""@@$"@@&"@@("@@*"@@,"@@."@@`#`@"#`@$#`@&#`@(#`@*#`@,#`
M@.#`@`#@@"#@@$#@@&#@@(#@@*#@@,#@@.#@@```P"``P$``P&``P(``P*``
MP,``P.``P``@P"`@P$`@P&`@P(`@P*`@P,`@P.`@P`!`P"!`P$!`P&!`P(!`
MP*!`P,!`P.!`P`!@P"!@P$!@P&!@P(!@P*!@P,!@P.!@P`"`P""`P$"`P&"`
MP("`P*"`P,"`P."`P`"@P""@P$"@P&"@P("@P*"@P,"@P."@P`#`P"#`P$#`
MP&#`P(#`P*#`P/_[\*"@I("`@/\```#_`/__````__\`_P#______R'Y!`$`
M`/T`+``````2`!(```A=`/L)'$BPH,&#"/L!6,BPH4,``@'\^R=QXL2*%B$J
MO&B18T>-#T,RC'C1WS^3*$^>!,DQI4N*)"F^=,F2HLJ9,!4RQ(FRID2>.2L"
M`.K/Y\VC)D&*#)FPJ=.G4`,"`#L`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC
M97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM
M9R]C96QL+7!R;W`N9VEF```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#(S,P`Q,#4Q-30S,S<U-@`P,S(U,#$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````1TE&.#EA$@`2`*('`.&`
M@```@,#`P``SF<S,S/___P```/___R'Y!`$```<`+``````2`!(```-@>+K<
M[B;*$\([1NAMZLO9IGD-*(2;)T5GBW:6,0P@[4:#.N/[2>^Q`J%`'!:)P@Y&
MB#0RBTH#824E6*]3A:%@`'BW1ZB6ZP6`GTGM=(7%&L;.>/.]E(?3F+;^2J?Z
MJ0<)`#L`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H
M=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<O8V5L;"US<&QI
M="YG:68`````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$V
M,3,`,3`U,34T,S,W-38`,#,R-C4W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````$=)1C@Y81(`$@#G``````"`````@`"`@```
M`("``(``@(#`P,#`W,"FRO!`(`!@(`"`(`"@(`#`(`#@(```0``@0`!`0`!@
M0`"`0`"@0`#`0`#@0```8``@8`!`8`!@8`"`8`"@8`#`8`#@8```@``@@`!`
M@`!@@`"`@`"@@`#`@`#@@```H``@H`!`H`!@H`"`H`"@H`#`H`#@H```P``@
MP`!`P`!@P`"`P`"@P`#`P`#@P```X``@X`!`X`!@X`"`X`"@X`#`X`#@X```
M`$`@`$!``$!@`$"``$"@`$#``$#@`$``($`@($!`($!@($"`($"@($#`($#@
M($``0$`@0$!`0$!@0$"`0$"@0$#`0$#@0$``8$`@8$!`8$!@8$"`8$"@8$#`
M8$#@8$``@$`@@$!`@$!@@$"`@$"@@$#`@$#@@$``H$`@H$!`H$!@H$"`H$"@
MH$#`H$#@H$``P$`@P$!`P$!@P$"`P$"@P$#`P$#@P$``X$`@X$!`X$!@X$"`
MX$"@X$#`X$#@X$```(`@`(!``(!@`("``("@`(#``(#@`(``((`@((!`((!@
M(("`(("@((#`((#@((``0(`@0(!`0(!@0("`0("@0(#`0(#@0(``8(`@8(!`
M8(!@8("`8("@8(#`8(#@8(``@(`@@(!`@(!@@("`@("@@(#`@(#@@(``H(`@
MH(!`H(!@H("`H("@H(#`H(#@H(``P(`@P(!`P(!@P("`P("@P(#`P(#@P(``
MX(`@X(!`X(!@X("`X("@X(#`X(#@X(```,`@`,!``,!@`,"``,"@`,#``,#@
M`,``(,`@(,!`(,!@(,"`(,"@(,#`(,#@(,``0,`@0,!`0,!@0,"`0,"@0,#`
M0,#@0,``8,`@8,!`8,!@8,"`8,"@8,#`8,#@8,``@,`@@,!`@,!@@,"`@,"@
M@,#`@,#@@,``H,`@H,!`H,!@H,"`H,"@H,#`H,#@H,``P,`@P,!`P,!@P,"`
MP,"@P,#_^_"@H*2`@(#_````_P#__P```/__`/\`______\A^00!``#]`"P`
M````$@`2```(:`#["1Q(L*#!@PC[`5C(L*%#``(!_/LG<>+$BA8A*KQHD6-'
MC0]#,HQXT=\_?P1,HE0)DJ-)`B?_P339DB*!FSAS$@#),.9,F3%K`E"9\F11
M?T)U*A5*M.E)H3ZCTHPH,F3"JUBS:@T(`#L`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D
M:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<O8V]L
M+61E;&5T92YG:68`````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`Q-#0`,3`U,34T,S,W-38`,#,R-C(R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````$=)1C@Y81(`$@"A``````#_____
M``#___\A^00!```#`"P`````$@`2```"-9R/J<L&`9\(+Z9*I\#@0AI,W`64
M@&:6C40UR!EVKA.V\P!O-Y[NAN`[`'V"8I%X#`Z#S%L!`#L`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R
M96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG+V-O;"UI;G-E<G0M869T
M97(N9VEF`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,34W`#$P
M-3$U-#,S-S4V`#`S,S<V-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!'248X.6$2`!(`P@``X8"```"``/______````____
M________(?D$`0``!P`L`````!(`$@```S1XNMS^4)%!";@DSGI!AD0HBE%Y
M!&83K*FROJT;+V@\?B8A#`)>3CN?9M=K`0="$#$Y:QX2`#L`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O
M5&%B;&5/<&5R871I;VYS+VEM9R]C;VPM:6YS97)T+6)E9F]R92YG:68P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$U-@`Q,#4Q-30S,S<U-@`P
M,S0Q,C<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````1TE&.#EA$@`2`,(``````.&`@/___P``@`#______________R'Y!`$`
M``<`+``````2`!(```,S>+K<_O"!0(&X(,YZ189`*(K.$#U#>C)IN[)O8\;'
M^*T`(1#W:>D]C8X7^WF*PR!M&4L``#L`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T
M:6]N<R]I;6<O8V]L+7-P;&ET+F=I9@``````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#$V,30`,3`U,34T,S,W-38`,#,R-3$V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$=)1C@Y81(`
M$@#G``````"`````@`"`@````("``(``@(#`P,#`W,"FRO!`(`!@(`"`(`"@
M(`#`(`#@(```0``@0`!`0`!@0`"`0`"@0`#`0`#@0```8``@8`!`8`!@8`"`
M8`"@8`#`8`#@8```@``@@`!`@`!@@`"`@`"@@`#`@`#@@```H``@H`!`H`!@
MH`"`H`"@H`#`H`#@H```P``@P`!`P`!@P`"`P`"@P`#`P`#@P```X``@X`!`
MX`!@X`"`X`"@X`#`X`#@X````$`@`$!``$!@`$"``$"@`$#``$#@`$``($`@
M($!`($!@($"`($"@($#`($#@($``0$`@0$!`0$!@0$"`0$"@0$#`0$#@0$``
M8$`@8$!`8$!@8$"`8$"@8$#`8$#@8$``@$`@@$!`@$!@@$"`@$"@@$#`@$#@
M@$``H$`@H$!`H$!@H$"`H$"@H$#`H$#@H$``P$`@P$!`P$!@P$"`P$"@P$#`
MP$#@P$``X$`@X$!`X$!@X$"`X$"@X$#`X$#@X$```(`@`(!``(!@`("``("@
M`(#``(#@`(``((`@((!`((!@(("`(("@((#`((#@((``0(`@0(!`0(!@0("`
M0("@0(#`0(#@0(``8(`@8(!`8(!@8("`8("@8(#`8(#@8(``@(`@@(!`@(!@
M@("`@("@@(#`@(#@@(``H(`@H(!`H(!@H("`H("@H(#`H(#@H(``P(`@P(!`
MP(!@P("`P("@P(#`P(#@P(``X(`@X(!`X(!@X("`X("@X(#`X(#@X(```,`@
M`,!``,!@`,"``,"@`,#``,#@`,``(,`@(,!`(,!@(,"`(,"@(,#`(,#@(,``
M0,`@0,!`0,!@0,"`0,"@0,#`0,#@0,``8,`@8,!`8,!@8,"`8,"@8,#`8,#@
M8,``@,`@@,!`@,!@@,"`@,"@@,#`@,#@@,``H,`@H,!`H,!@H,"`H,"@H,#`
MH,#@H,``P,`@P,!`P,!@P,"`P,"@P,#_^_"@H*2`@(#_````_P#__P```/__
M`/\`______\A^00!``#]`"P`````$@`2```(:0#["1Q(L*#!@PC[`5C(L*%#
M``(!_/LG<>+$BA8A*KQHD6-'C0]#,HQXT=\_?P1,HE0)DJ-)`B?_P339DJ+*
ME"=Q^@/),.9,F3%K`KA)]*10GTAIDK29L^C.I1)?)J48463(A%BS:MT:$``[
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE
M3W!E<F%T:6]N<R]I;6<O<F]W+61E;&5T92YG:68`````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-3``,3`U,34T,S,W-38`,#,R-C4Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$=)
M1C@Y81(`$@"A``````#_____``#___\A^00!```#`"P`````$@`2```".9R/
MJ<L##U\;H=H`YK6Y[=HQT2@-`B($Z:IBAG`:+;L"\/W.>@<?Y/A"?%R>3V@Q
M/"I^RHGS"7T6```[````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V
M:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O
M:6UG+W)O=RUI;G-E<G0M86)O=F4N9VEF`#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,38T`#$P-3$U-#,S-S4V`#`S-#`Q,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!'248X.6$2`!(`P@``
M`/__``"$X8"`____````____________(?D$`0``!P`L`````!(`$@```SEX
MNMS^,`9%:I7S$#`X#"!(=!U&<9Y$6<3*MM$AS#0<T74LXX(-O9?88$CT/8A%
M'7)H=`";NJB4D0``.P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R
M+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM9R]R;W<M:6YS
M97)T+75N9&5R+F=I9@`P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#$V,P`Q,#4Q-30S,S<U-@`P,S0P,S(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````1TE&.#EA$@`2`,(```#__P``A.&`@/__
M_P```/___________R'Y!`$```<`+``````2`!(```,X>+K<_O"024E4(VM[
M];Z'EW%118%"JI*0NJ*NP#[F!$*!8D9!+@$#(*[7(P2#/!\!*.3I*K?H+0$`
M.P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P
M;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<O<F]W+7!R;W`N9VEF````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R,C4`,3`U,34T
M,S,W-38`,#,R,S<R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````$=)1C@Y81(`$@"B!P```(#A@(#`P,``,YG,S,S___\```#_
M__\A^00!```'`"P`````$@`2```#6GBZW.XFR@/`.T;H;>K+V:9Y#2B$FR=%
M9XMVEC$,(.U&@SKC^TGOL0*A0!P6B4*#PB!$&IM%)69%71&DAH!VR]U>E]VP
M]CNM5LG,I]J)A;K56()\3J=CS?A#`@`[````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L
M94]P97)A=&EO;G,O:6UG+W)O=RUS<&QI="YG:68``````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-3<W`#$P-3$U-#,S-S4V`#`S,C4V
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!'
M248X.6$2`!(`YP``````@````(``@(````"`@`"``("`P,#`P-S`ILKP0"``
M8"``@"``H"``P"``X"```$``($``0$``8$``@$``H$``P$``X$```&``(&``
M0&``8&``@&``H&``P&``X&```(``((``0(``8(``@(``H(``P(``X(```*``
M(*``0*``8*``@*``H*``P*``X*```,``(,``0,``8,``@,``H,``P,``X,``
M`.``(.``0.``8.``@.``H.``P.``X.````!`(`!`0`!`8`!`@`!`H`!`P`!`
MX`!``"!`("!`0"!`8"!`@"!`H"!`P"!`X"!``$!`($!`0$!`8$!`@$!`H$!`
MP$!`X$!``&!`(&!`0&!`8&!`@&!`H&!`P&!`X&!``(!`((!`0(!`8(!`@(!`
MH(!`P(!`X(!``*!`(*!`0*!`8*!`@*!`H*!`P*!`X*!``,!`(,!`0,!`8,!`
M@,!`H,!`P,!`X,!``.!`(.!`0.!`8.!`@.!`H.!`P.!`X.!```"`(`"`0`"`
M8`"`@`"`H`"`P`"`X`"``""`(""`0""`8""`@""`H""`P""`X""``$"`($"`
M0$"`8$"`@$"`H$"`P$"`X$"``&"`(&"`0&"`8&"`@&"`H&"`P&"`X&"``("`
M(("`0("`8("`@("`H("`P("`X("``*"`(*"`0*"`8*"`@*"`H*"`P*"`X*"`
M`,"`(,"`0,"`8,"`@,"`H,"`P,"`X,"``."`(."`0."`8."`@."`H."`P."`
MX."```#`(`#`0`#`8`#`@`#`H`#`P`#`X`#``"#`("#`0"#`8"#`@"#`H"#`
MP"#`X"#``$#`($#`0$#`8$#`@$#`H$#`P$#`X$#``&#`(&#`0&#`8&#`@&#`
MH&#`P&#`X&#``(#`((#`0(#`8(#`@(#`H(#`P(#`X(#``*#`(*#`0*#`8*#`
M@*#`H*#`P*#`X*#``,#`(,#`0,#`8,#`@,#`H,#`__OPH*"D@("`_P```/\`
M__\```#__P#_`/______(?D$`0``_0`L`````!(`$@``"%P`^PD<2+"@P8,(
M^P%8R+"A0P`"`?R;.%$BQ7\6(2J\B)%CQH@/0RZ,Z.]?R9,F37[<B+)E1XP1
M"<B<29/`2HDN438DF3+GS9I`;^;L>;.GT9(W189,R+2ITZ<!`0`[````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN
M<R]486)L94]P97)A=&EO;G,O:6UG+W1A8FQE+7!R;W`N9VEF`````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,C(Q`#$P-3$U-#,S-S4V
M`#`S,C8T-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!'248X.6$2`!(`H@8```"`P,#``#.9____S,S,````____````(?D$
M`0``!@`L`````!(`$@```U9HNMSN)4H#P#,EZ%WJR]FF>0T8A)LG16>+=E8A
M""#M1H(ZX_M)[[$!84`<%HG"@J(@1!J;126&0*U:K5+F<^O,0K_;['5<]7*/
MT278V5V2R=F5?&Y(```[````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R
M871I;VYS+VQA;F<O```````````````````````````P,#`P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<U-@`P,S`R-C0`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O
M<&QU9VEN<R]486)L94]P97)A=&EO;G,O;&%N9R]E;BYJ<P``````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P,#<V`#$P-3$U
M-#,S-S4V`#`S,3(S,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````O+R!),3A.(&-O;G-T86YT<PH*+R\@3$%.1SH@(F5N(BP@
M14Y#3T1)3D<Z(%541BTX('P@25-/+3@X-3DM,0HO+R!!=71H;W(Z($UI:&%I
M($)A>F]N+"!H='1P.B\O9'EN87)C:"YC;VTO;6ES:&]O"@HO+R!&3U(@5%)!
M3E-,051/4E,Z"B\O"B\O("`@,2X@4$Q%05-%(%!55"!93U52($-/3E1!0U0@
M24Y&3R!)3B!42$4@04)/5D4@3$E.10HO+R`@("`@("AA="!L96%S="!A('9A
M;&ED(&5M86EL(&%D9')E<W,I"B\O"B\O("`@,BX@4$Q%05-%(%1262!43R!5
M4T4@551&+3@@1D]2($5.0T]$24Y'.PHO+R`@("`@("AI9B!T:&ES(&ES(&YO
M="!P;W-S:6)L92P@<&QE87-E(&EN8VQU9&4@82!C;VUM96YT"B\O("`@("`@
M('1H870@<W1A=&5S('=H870@96YC;V1I;F<@:7,@;F5C97-S87)Y+BD*"E1A
M8FQE3W!E<F%T:6]N<RY),3A.(#T@>PH)(D%L:6=N(CH)"0D)"2`@(D%L:6=N
M(BP*"2)!;&P@9F]U<B!S:61E<R(Z"0D)"2`@(D%L;"!F;W5R('-I9&5S(BP*
M"2)"86-K9W)O=6YD(CH)"0D)"2`@(D)A8VMG<F]U;F0B+`H)(D)A<V5L:6YE
M(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B0F%S
M96QI;F4B+`H)(D)O<F1E<B(Z"0D)"0D@(")";W)D97(B+`H)(D)O<F1E<G,B
M.@D)"0D)("`B0F]R9&5R<R(L"@DB0F]T=&]M(CH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(")";W1T;VTB+`H)(D-34R!3='EL
M92(Z"0D)"0D@(")3='EL92!;0U-372(L"@DB0V%P=&EO;B(Z"0D)"0D@(")#
M87!T:6]N(BP*"2)#96QL(%!R;W!E<G1I97,B.B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(D-E;&P@4')O<&5R=&EE<R(L"@DB0V5N=&5R(CH)
M"0D)"2`@(D-E;G1E<B(L"@DB0VAA<B(Z("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(")#:&%R(BP*"2)#;VQL87!S960@8F]R
M9&5R<R(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(D-O;&QA<'-E
M9"!B;W)D97)S(BP*"2)#;VQO<B(Z"0D)"0D@(")#;VQO<B(L"@DB1&5S8W)I
M<'1I;VXB.@D)"0D)("`B1&5S8W)I<'1I;VXB+`H)(D9'($-O;&]R(CH)"0D)
M"2`@(D9'($-O;&]R(BP*"2)&;&]A="(Z("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(D9L;V%T(BP*"2)&<F%M97,B.@D)"0D)
M("`B1G)A;65S(BP*"2)(96EG:'0B.B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(DAE:6=H="(L"@DB2&]W(&UA;GD@8V]L=6UN
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B.B`@("`@(")(;W<@;6%N>2!C
M;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(L"@DB2&]W(&UA;GD@
M<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B.B`@("`@("`@(")(;W<@
M;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(L"@DB26UA9V4@
M55),(CH)"0D)"2`@(DEM86=E(%523"(L"@DB2G5S=&EF>2(Z("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(")*=7-T:69Y(BP*"2),
M87EO=70B.@D)"0D)("`B3&%Y;W5T(BP*"2),969T(CH)"0D)"0D@("),969T
M(BP*"2)-87)G:6XB.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(DUA<F=I;B(L"@DB36ED9&QE(CH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(")-:61D;&4B+`H)(DYO(')U;&5S
M(CH)"0D)"2`@(DYO(')U;&5S(BP*"2).;R!S:61E<R(Z"0D)"0D@(").;R!S
M:61E<R(L"@DB3F]N92(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(").;VYE(BP*"2)0861D:6YG(CH)"0D)"2`@(E!A9&1I
M;F<B+`H)(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(Z("`@("`@("`@
M("`@("`@("`@("`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(BP*"2)2
M:6=H="(Z"0D)"0D@(")2:6=H="(L"@DB4F]W(%!R;W!E<G1I97,B.B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(")2;W<@4')O<&5R=&EE<R(L
M"@DB4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L
M=6UN<R(Z(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N
M9"!C;VQU;6YS(BP*"2)2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M
M;G,@;VYL>2(Z"2`@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN
M<R!O;FQY(BP*"2)2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL
M>2(Z"0D@(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(L
M"@DB4G5L97,B.@D)"0D)("`B4G5L97,B+`H)(E-P86-I;F<@86YD('!A9&1I
M;F<B.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`B4W!A8VEN9R!A;F0@
M<&%D9&EN9R(L"@DB4W!A8VEN9R(Z"0D)"0D@(")3<&%C:6YG(BP*"2)3=6UM
M87)Y(CH)"0D)"2`@(E-U;6UA<GDB+`H)(E1/+6-E;&PM9&5L971E(CH)"0D)
M("`B1&5L971E(&-E;&PB+`H)(E1/+6-E;&PM:6YS97)T+6%F=&5R(CH)"0D)
M("`B26YS97)T(&-E;&P@869T97(B+`H)(E1/+6-E;&PM:6YS97)T+6)E9F]R
M92(Z"0D)("`B26YS97)T(&-E;&P@8F5F;W)E(BP*"2)43RUC96QL+6UE<F=E
M(CH)"0D)("`B365R9V4@8V5L;',B+`H)(E1/+6-E;&PM<')O<"(Z"0D)"0D@
M(")#96QL('!R;W!E<G1I97,B+`H)(E1/+6-E;&PM<W!L:70B.@D)"0D@(")3
M<&QI="!C96QL(BP*"2)43RUC;VPM9&5L971E(CH)"0D)("`B1&5L971E(&-O
M;'5M;B(L"@DB5$\M8V]L+6EN<V5R="UA9G1E<B(Z"0D)"2`@(DEN<V5R="!C
M;VQU;6X@869T97(B+`H)(E1/+6-O;"UI;G-E<G0M8F5F;W)E(CH)"0D)("`B
M26YS97)T(&-O;'5M;B!B969O<F4B+`H)(E1/+6-O;"US<&QI="(Z"0D)"0D@
M(")3<&QI="!C;VQU;6XB+`H)(E1/+7)O=RUD96QE=&4B.@D)"0D@(")$96QE
M=&4@<F]W(BP*"2)43RUR;W<M:6YS97)T+6%B;W9E(CH)"0D)("`B26YS97)T
M(')O=R!B969O<F4B+`H)(E1/+7)O=RUI;G-E<G0M=6YD97(B.@D)"0D@("))
M;G-E<G0@<F]W(&%F=&5R(BP*"2)43RUR;W<M<')O<"(Z"0D)"0D@(")2;W<@
M<')O<&5R=&EE<R(L"@DB5$\M<F]W+7-P;&ET(CH)"0D)"2`@(E-P;&ET(')O
M=R(L"@DB5$\M=&%B;&4M<')O<"(Z"0D)"2`@(E1A8FQE('!R;W!E<G1I97,B
M+`H)(E1A8FQE(%!R;W!E<G1I97,B.@D)"0D@(")486)L92!0<F]P97)T:65S
M(BP*"2)497AT(&%L:6=N(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(E1E>'0@86QI9VXB+`H)(E1H92!B;W1T;VT@<VED92!O;FQY
M(CH)"0D)("`B5&AE(&)O='1O;2!S:61E(&]N;'DB+`H)(E1H92!L969T+6AA
M;F0@<VED92!O;FQY(CH)"0D@(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(L
M"@DB5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB.@D)("`B5&AE(')I
M9VAT(&%N9"!L969T('-I9&5S(&]N;'DB+`H)(E1H92!R:6=H="UH86YD('-I
M9&4@;VYL>2(Z"0D)("`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(BP*"2)4
M:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(Z"0D@(")4:&4@=&]P(&%N
M9"!B;W1T;VT@<VED97,@;VYL>2(L"@DB5&AE('1O<"!S:61E(&]N;'DB.@D)
M"0D@(")4:&4@=&]P('-I9&4@;VYL>2(L"@DB5&]P(CH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(")4;W`B+`D*"2)5;G-E
M="!C;VQO<B(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(E5N<V5T(&-O;&]R(BP*"2)697)T:6-A;"!A;&EG;B(Z("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(E9E<G1I8V%L(&%L:6=N(BP*"2)7:61T
M:"(Z"0D)"0D@(")7:61T:"(L"@DB;F]T+61E;"UL87-T+6-E;&PB.@D)"0D@
M(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!C96QL(&EN(')O=RXB+`H)(FYO="UD96PM;&%S="UC;VPB.@D)"0D@(")(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M;VQU;6X@:6X@=&%B;&4N(BP*"2)N;W0M9&5L+6QA<W0M<F]W(CH)"0D)("`B
M2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@
M<F]W(&EN('1A8FQE+B(L"@DB<&5R8V5N="(Z"0D)"0D@(")P97)C96YT(BP*
M"2)P:7AE;',B.@D)"0D)("`B<&EX96QS(@I].PH`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A
M8FQE3W!E<F%T:6]N<R]T86)L92UO<&5R871I;VYS+FIS````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`Q,#`R,C``,3`U,34T,S,W-38`,#,S
M,30T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"\O(%1A8FQE($]P97)A=&EO;G,@4&QU9VEN(&9O<B!(5$U,07)E82TS+C`*
M+R\@26UP;&5M96YT871I;VX@8GD@36EH86D@0F%Z;VXN("!3<&]N<V]R960@
M8GD@:'1T<#HO+W=W=RYZ87!A=&5C+F-O;0HO+PHO+R!#;W!Y<FEG:'0@*&,I
M(&1Y;F%R8V@N8V]M(#(P,#,M,C`P-0HO+R!4:&ES(&-O<'ER:6=H="!N;W1I
M8V4@;75S="!S=&%Y(&EN=&%C="!F;W(@=7-E+@HO+PHO+R`D260Z('1A8FQE
M+6]P97)A=&EO;G,N:G,L=B`Q+C<@,C`P-2\P,2\R,"`Q-SHT.3HP,B!M:7-H
M;V\@17AP("0*"B\O($]B:F5C="!T:&%T('=I;&P@96YC87!S=6QA=&4@86QL
M('1H92!T86)L92!O<&5R871I;VYS('!R;W9I9&5D(&)Y"B\O($A434Q!<F5A
M+3,N,"`H97AC97!T(")I;G-E<G0@=&%B;&4B('=H:6-H(&ES(&EN8VQU9&5D
M(&EN('1H92!M86EN(&9I;&4I"F9U;F-T:6]N(%1A8FQE3W!E<F%T:6]N<RAE
M9&ET;W(I('L*"71H:7,N961I=&]R(#T@961I=&]R.PH*"79A<B!C9F<@/2!E
M9&ET;W(N8V]N9FEG.PH)=F%R('1T(#T@5&%B;&5/<&5R871I;VYS+DDQ.$X[
M"@EV87(@8FP@/2!486)L94]P97)A=&EO;G,N8G1N3&ES=#L*"79A<B!S96QF
M(#T@=&AI<SL*"@DO+R!R96=I<W1E<B!T:&4@=&]O;&)A<B!B=71T;VYS('!R
M;W9I9&5D(&)Y('1H:7,@<&QU9VEN"@EV87(@=&]O;&)A<B`](%LB;&EN96)R
M96%K(ET["@EF;W(@*'9A<B!I(#T@,#L@:2`\(&)L+FQE;F=T:#L@*RMI*2![
M"@D)=F%R(&)T;B`](&)L6VE=.PH)"6EF("@A8G1N*2!["@D)"71O;VQB87(N
M<'5S:"@B<V5P87)A=&]R(BD["@D)?2!E;'-E('L*"0D)=F%R(&ED(#T@(E1/
M+2(@*R!B=&Y;,%T["@D)"6-F9RYR96=I<W1E<D)U='1O;BAI9"P@='1;:61=
M+"!E9&ET;W(N:6UG55),*&)T;ELP72`K("(N9VEF(BP@(E1A8FQE3W!E<F%T
M:6]N<R(I+"!F86QS92P*"0D)"0D@("!F=6YC=&EO;BAE9&ET;W(L(&ED*2![
M"@D)"0D)"2`@("\O(&1I<W!A=&-H(&)U='1O;B!P<F5S<R!E=F5N=`H)"0D)
M"0D@("!S96QF+F)U='1O;E!R97-S*&5D:71O<BP@:60I.PH)"0D)"2`@('TL
M(&)T;ELQ72D["@D)"71O;VQB87(N<'5S:"AI9"D["@D)?0H)?0H*"2\O(&%D
M9"!A(&YE=R!L:6YE(&EN('1H92!T;V]L8F%R"@EC9F<N=&]O;&)A<BYP=7-H
M*'1O;VQB87(I.PI].PH*5&%B;&5/<&5R871I;VYS+E]P;'5G:6Y);F9O(#T@
M>PH);F%M92`@("`@("`@("`Z(")486)L94]P97)A=&EO;G,B+`H)=F5R<VEO
M;B`@("`@("`Z("(Q+C`B+`H)9&5V96QO<&5R("`@("`Z(")-:6AA:2!"87IO
M;B(L"@ED979E;&]P97)?=7)L(#H@(FAT='`Z+R]D>6YA<F-H+F-O;2]M:7-H
M;V\O(BP*"6-?;W=N97(@("`@("`@.B`B36EH86D@0F%Z;VXB+`H)<W!O;G-O
M<B`@("`@("`Z("):87!A=&5C($EN8RXB+`H)<W!O;G-O<E]U<FP@("`Z(")H
M='1P.B\O=W=W+F)L;VMI+F-O;2(L"@EL:6-E;G-E("`@("`@(#H@(FAT;6Q!
M<F5A(@I].PH*+RHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*@H@*B!55$E,251)
M15,*("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B\*"B\O(')E=')I979E<R!T
M:&4@8VQO<V5S="!E;&5M96YT(&AA=FEN9R!T:&4@<W!E8VEF:65D('1A9TYA
M;64@:6X@=&AE(&QI<W0@;V8*+R\@86YC97-T;W)S(&]F('1H92!C=7)R96YT
M('-E;&5C=&EO;B]C87)E="X*5&%B;&5/<&5R871I;VYS+G!R;W1O='EP92YG
M971#;&]S97-T(#T@9G5N8W1I;VXH=&%G3F%M92D@>PH)=F%R(&5D:71O<B`]
M('1H:7,N961I=&]R.PH)=F%R(&%N8V5S=&]R<R`](&5D:71O<BYG971!;&Q!
M;F-E<W1O<G,H*3L*"79A<B!R970@/2!N=6QL.PH)=&%G3F%M92`]("@B(B`K
M('1A9TYA;64I+G1O3&]W97)#87-E*"D["@EF;W(@*'9A<B!I(#T@,#L@:2`\
M(&%N8V5S=&]R<RYL96YG=&@[("LK:2D@>PH)"79A<B!E;"`](&%N8V5S=&]R
M<UMI73L*"0EI9B`H96PN=&%G3F%M92YT;TQO=V5R0V%S92@I(#T]('1A9TYA
M;64I('L*"0D)<F5T(#T@96P["@D)"6)R96%K.PH)"7T*"7T*"7)E='5R;B!R
M970["GT["@HO+R!T:&ES(&9U;F-T:6]N(')E<75I<F5S('1H92!F:6QE(%!O
M<'5P1&EV+U!O<'5P5VEN('1O(&)E(&QO861E9"!F<F]M(&)R;W=S97(*5&%B
M;&5/<&5R871I;VYS+G!R;W1O='EP92YD:6%L;V=486)L95!R;W!E<G1I97,@
M/2!F=6YC=&EO;B@I('L*"79A<B!I,3AN(#T@5&%B;&5/<&5R871I;VYS+DDQ
M.$X["@DO+R!R971R:65V92!E>&ES=&EN9R!V86QU97,*"79A<B!T86)L92`]
M('1H:7,N9V5T0VQO<V5S="@B=&%B;&4B*3L*"2\O('1H:7,N961I=&]R+G-E
M;&5C=$YO9&5#;VYT96YT<RAT86)L92D["@DO+R!T:&ES+F5D:71O<BYU<&1A
M=&54;V]L8F%R*"D["@H)=F%R(&1I86QO9R`](&YE=R!0;W!U<%=I;BAT:&ES
M+F5D:71O<BP@:3$X;ELB5&%B;&4@4')O<&5R=&EE<R)=+"!F=6YC=&EO;BAD
M:6%L;V<L('!A<F%M<RD@>PH)"51A8FQE3W!E<F%T:6]N<RYP<F]C97-S4W1Y
M;&4H<&%R86US+"!T86)L92D["@D)9F]R("AV87(@:2!I;B!P87)A;7,I('L*
M"0D)=F%R('9A;"`]('!A<F%M<UMI73L*"0D)<W=I=&-H("AI*2!["@D)"2`@
M("!C87-E(")F7V-A<'1I;VXB.@H)"0D):68@*"]<4R\N=&5S="AV86PI*2![
M"@D)"0D)+R\@8V]N=&%I;G,@;F]N('=H:71E+7-P86-E(&-H87)A8W1E<G,*
M"0D)"0EV87(@8V%P=&EO;B`]('1A8FQE+F=E=$5L96UE;G1S0GE486=.86UE
M*")C87!T:6]N(BE;,%T["@D)"0D):68@*"%C87!T:6]N*2!["@D)"0D)"6-A
M<'1I;VX@/2!D:6%L;V<N961I=&]R+E]D;V,N8W)E871E16QE;65N="@B8V%P
M=&EO;B(I.PH)"0D)"0ET86)L92YI;G-E<G1"969O<F4H8V%P=&EO;BP@=&%B
M;&4N9FER<W1#:&EL9"D["@D)"0D)?0H)"0D)"6-A<'1I;VXN:6YN97)(5$U,
M(#T@=F%L.PH)"0D)?2!E;'-E('L*"0D)"0DO+R!S96%R8V@@9F]R(&-A<'1I
M;VX@86YD(&1E;&5T92!I="!I9B!F;W5N9`H)"0D)"79A<B!C87!T:6]N(#T@
M=&%B;&4N9V5T16QE;65N='-">51A9TYA;64H(F-A<'1I;VXB*5LP73L*"0D)
M"0EI9B`H8V%P=&EO;BD@>PH)"0D)"0EC87!T:6]N+G!A<F5N=$YO9&4N<F5M
M;W9E0VAI;&0H8V%P=&EO;BD["@D)"0D)?0H)"0D)?0H)"0D)8G)E86L["@D)
M"2`@("!C87-E(")F7W-U;6UA<GDB.@H)"0D)=&%B;&4N<W5M;6%R>2`]('9A
M;#L*"0D)"6)R96%K.PH)"0D@("`@8V%S92`B9E]W:61T:"(Z"@D)"0ET86)L
M92YS='EL92YW:61T:"`]("@B(B`K('9A;"D@*R!P87)A;7,N9E]U;FET.PH)
M"0D)8G)E86L["@D)"2`@("!C87-E(")F7V%L:6=N(CH*"0D)"71A8FQE+F%L
M:6=N(#T@=F%L.PH)"0D)8G)E86L["@D)"2`@("!C87-E(")F7W-P86-I;F<B
M.@H)"0D)=&%B;&4N8V5L;%-P86-I;F<@/2!V86P["@D)"0EB<F5A:SL*"0D)
M("`@(&-A<V4@(F9?<&%D9&EN9R(Z"@D)"0ET86)L92YC96QL4&%D9&EN9R`]
M('9A;#L*"0D)"6)R96%K.PH)"0D@("`@8V%S92`B9E]B;W)D97)S(CH*"0D)
M"71A8FQE+F)O<F1E<B`]('9A;#L*"0D)"6)R96%K.PH)"0D@("`@8V%S92`B
M9E]F<F%M97,B.@H)"0D)=&%B;&4N9G)A;64@/2!V86P["@D)"0EB<F5A:SL*
M"0D)("`@(&-A<V4@(F9?<G5L97,B.@H)"0D)=&%B;&4N<G5L97,@/2!V86P[
M"@D)"0EB<F5A:SL*"0D)?0H)"7T*"0DO+R!V87)I;W5S('=O<FMA<F]U;F1S
M('1O(')E9G)E<V@@=&AE('1A8FQE(&1I<W!L87D@*$=E8VMO+`H)"2\O('=H
M870G<R!G;VEN9R!O;C\A(&1O(&YO="!D:7-A<'!O:6YT(&UE(2D*"0ED:6%L
M;V<N961I=&]R+F9O<F-E4F5D<F%W*"D["@D)9&EA;&]G+F5D:71O<BYF;V-U
M<T5D:71O<B@I.PH)"61I86QO9RYE9&ET;W(N=7!D871E5&]O;&)A<B@I.PH)
M"79A<B!S879E7V-O;&QA<'-E(#T@=&%B;&4N<W1Y;&4N8F]R9&5R0V]L;&%P
M<V4["@D)=&%B;&4N<W1Y;&4N8F]R9&5R0V]L;&%P<V4@/2`B8V]L;&%P<V4B
M.PH)"71A8FQE+G-T>6QE+F)O<F1E<D-O;&QA<'-E(#T@(G-E<&%R871E(CL*
M"0ET86)L92YS='EL92YB;W)D97)#;VQL87!S92`]('-A=F5?8V]L;&%P<V4[
M"@E]+`H*"2\O('1H:7,@9G5N8W1I;VX@9V5T<R!C86QL960@=VAE;B!T:&4@
M9&EA;&]G(&YE961S('1O(&)E(&EN:71I86QI>F5D"@EF=6YC=&EO;B`H9&EA
M;&]G*2!["@H)"79A<B!F7V-A<'1I;VX@/2`B(CL*"0EV87(@8V%P96P@/2!T
M86)L92YG971%;&5M96YT<T)Y5&%G3F%M92@B8V%P=&EO;B(I6S!=.PH)"6EF
M("AC87!E;"D@>PH)"0EF7V-A<'1I;VX@/2!C87!E;"YI;FYE<DA434P["@D)
M?0H)"79A<B!F7W-U;6UA<GD@/2!T86)L92YS=6UM87)Y.PH)"79A<B!F7W=I
M9'1H(#T@<&%R<V5);G0H=&%B;&4N<W1Y;&4N=VED=&@I.PH)"6ES3F%.*&9?
M=VED=&@I("8F("AF7W=I9'1H(#T@(B(I.PH)"79A<B!F7W5N:70@/2`O)2\N
M=&5S="AT86)L92YS='EL92YW:61T:"D@/R`G<&5R8V5N="<@.B`G<&EX96QS
M)SL*"0EV87(@9E]A;&EG;B`]('1A8FQE+F%L:6=N.PH)"79A<B!F7W-P86-I
M;F<@/2!T86)L92YC96QL4W!A8VEN9SL*"0EV87(@9E]P861D:6YG(#T@=&%B
M;&4N8V5L;%!A9&1I;F<["@D)=F%R(&9?8F]R9&5R<R`]('1A8FQE+F)O<F1E
M<CL*"0EV87(@9E]F<F%M97,@/2!T86)L92YF<F%M93L*"0EV87(@9E]R=6QE
M<R`]('1A8FQE+G)U;&5S.PH*"0EF=6YC=&EO;B!S96QE8W1E9"AV86PI('L*
M"0D)<F5T=7)N('9A;"`_("(@<V5L96-T960B(#H@(B(["@D)?3L*"@D)+R\@
M9&EA;&]G(&-O;G1E;G1S"@D)9&EA;&]G+F-O;G1E;G0N<W1Y;&4N=VED=&@@
M/2`B-#`P<'@B.PH)"61I86QO9RYC;VYT96YT+FEN;F5R2%1-3"`]("(@7`H\
M9&EV(&-L87-S/2=T:71L92=<"B!S='EL93TG8F%C:V=R;W5N9#H@=7)L*"(@
M*R!D:6%L;V<N8F%S95523"`K(&1I86QO9RYE9&ET;W(N:6UG55),*")T86)L
M92UP<F]P+F=I9B(L(")486)L94]P97)A=&EO;G,B*2`K("(I("-F9F8@.3@E
M(#4P)2!N;RUR97!E870G/B(@*R!I,3AN6R)486)L92!0<F]P97)T:65S(ET@
M*R`B7`H\+V1I=CX@7`H\=&%B;&4@<W1Y;&4])W=I9'1H.C$P,"4G/B!<"B`@
M/'1R/B!<"B`@("`\=&0^(%P*("`@("`@/&9I96QD<V5T/CQL96=E;F0^(B`K
M(&DQ.&Y;(D1E<V-R:7!T:6]N(ET@*R`B/"]L96=E;F0^(%P*("`@("`@(#QT
M86)L92!S='EL93TG=VED=&@Z,3`P)2<^(%P*("`@("`@("`\='(^(%P*("`@
M("`@("`@(#QT9"!C;&%S<STG;&%B96PG/B(@*R!I,3AN6R)#87!T:6]N(ET@
M*R`B.CPO=&0^(%P*("`@("`@("`@(#QT9"!C;&%S<STG=F%L=64G/CQI;G!U
M="!T>7!E/2=T97AT)R!N86UE/2=F7V-A<'1I;VXG('9A;'5E/2<B("L@9E]C
M87!T:6]N("L@(B<O/CPO=&0^(%P*("`@("`@("`\+W1R/CQT<CX@7`H@("`@
M("`@("`@/'1D(&-L87-S/2=L86)E;"<^(B`K(&DQ.&Y;(E-U;6UA<GDB72`K
M("(Z/"]T9#X@7`H@("`@("`@("`@/'1D(&-L87-S/2=V86QU92<^/&EN<'5T
M('1Y<&4])W1E>'0G(&YA;64])V9?<W5M;6%R>2<@=F%L=64])R(@*R!F7W-U
M;6UA<GD@*R`B)R\^/"]T9#X@7`H@("`@("`@(#PO='(^(%P*("`@("`@(#PO
M=&%B;&4^(%P*("`@("`@/"]F:65L9'-E=#X@7`H@("`@/"]T9#X@7`H@(#PO
M='(^(%P*("`\='(^/'1D(&ED/2<M+4A!+6QA>6]U="<^/"]T9#X\+W1R/B!<
M"B`@/'1R/B!<"B`@("`\=&0^(%P*("`@("`@/&9I96QD<V5T/CQL96=E;F0^
M(B`K(&DQ.&Y;(E-P86-I;F<@86YD('!A9&1I;F<B72`K("(\+VQE9V5N9#X@
M7`H@("`@("`@/'1A8FQE('-T>6QE/2=W:61T:#HQ,#`E)SX@7`H@("`@("`@
M(#QT<CX@7`H@("`@("`@("`@/'1D(&-L87-S/2=L86)E;"<^(B`K(&DQ.&Y;
M(E-P86-I;F<B72`K("(Z/"]T9#X@7`H@("`@("`@("`@/'1D/CQI;G!U="!T
M>7!E/2=T97AT)R!N86UE/2=F7W-P86-I;F<G('-I>F4])S4G('9A;'5E/2<B
M("L@9E]S<&%C:6YG("L@(B<@+SX@)FYB<W`[(B`K(&DQ.&Y;(E!A9&1I;F<B
M72`K("(Z7`H@("`@("`@("`@("`\:6YP=70@='EP93TG=&5X="<@;F%M93TG
M9E]P861D:6YG)R!S:7IE/2<U)R!V86QU93TG(B`K(&9?<&%D9&EN9R`K("(G
M("\^("9N8G-P.R9N8G-P.R(@*R!I,3AN6R)P:7AE;',B72`K(")<"B`@("`@
M("`@("`\+W1D/B!<"B`@("`@("`@/"]T<CX@7`H@("`@("`@/"]T86)L93X@
M7`H@("`@("`\+V9I96QD<V5T/B!<"B`@("`\+W1D/B!<"B`@/"]T<CX@7`H@
M(#QT<CX@7`H@("`@/'1D/B!<"B`@("`@(#QF:65L9'-E=#X\;&5G96YD/D9R
M86UE(&%N9"!B;W)D97)S/"]L96=E;F0^(%P*("`@("`@("`\=&%B;&4@=VED
M=&@])S$P,"4G/B!<"B`@("`@("`@("`\='(^(%P*("`@("`@("`@("`@/'1D
M(&-L87-S/2=L86)E;"<^(B`K(&DQ.&Y;(D)O<F1E<G,B72`K("(Z/"]T9#X@
M7`H@("`@("`@("`@("`\=&0^/&EN<'5T(&YA;64])V9?8F]R9&5R<R<@='EP
M93TG=&5X="<@<VEZ93TG-2<@=F%L=64])R(@*R!F7V)O<F1E<G,@*R`B)R`O
M/B`F;F)S<#LF;F)S<#LB("L@:3$X;ELB<&EX96QS(ET@*R`B/"]T9#X@7`H@
M("`@("`@("`@/"]T<CX@7`H@("`@("`@("`@/'1R/B!<"B`@("`@("`@("`@
M(#QT9"!C;&%S<STG;&%B96PG/B(@*R!I,3AN6R)&<F%M97,B72`K("(Z/"]T
M9#X@7`H@("`@("`@("`@("`\=&0^(%P*("`@("`@("`@("`@("`\<V5L96-T
M(&YA;64])V9?9G)A;65S)SX@7`H@("`@("`@("`@("`@("`@/&]P=&EO;B!V
M86QU93TG=F]I9"<B("L@<V5L96-T960H9E]F<F%M97,@/3T@(G9O:60B*2`K
M("(^(B`K(&DQ.&Y;(DYO('-I9&5S(ET@*R`B/"]O<'1I;VX^(%P*("`@("`@
M("`@("`@("`@(#QO<'1I;VX@=F%L=64])V%B;W9E)R(@*R!S96QE8W1E9"AF
M7V9R86UE<R`]/2`B86)O=F4B*2`K("(^(B`K(&DQ.&Y;(E1H92!T;W`@<VED
M92!O;FQY(ET@*R`B/"]O<'1I;VX^(%P*("`@("`@("`@("`@("`@(#QO<'1I
M;VX@=F%L=64])V)E;&]W)R(@*R!S96QE8W1E9"AF7V9R86UE<R`]/2`B8F5L
M;W<B*2`K("(^(B`K(&DQ.&Y;(E1H92!B;W1T;VT@<VED92!O;FQY(ET@*R`B
M/"]O<'1I;VX^(%P*("`@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64])VAS
M:61E<R<B("L@<V5L96-T960H9E]F<F%M97,@/3T@(FAS:61E<R(I("L@(CXB
M("L@:3$X;ELB5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB72`K("(\
M+V]P=&EO;CX@7`H@("`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TG=G-I
M9&5S)R(@*R!S96QE8W1E9"AF7V9R86UE<R`]/2`B=G-I9&5S(BD@*R`B/B(@
M*R!I,3AN6R)4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2)=("L@(CPO
M;W!T:6]N/B!<"B`@("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2=L:',G
M(B`K('-E;&5C=&5D*&9?9G)A;65S(#T](")L:',B*2`K("(^(B`K(&DQ.&Y;
M(E1H92!L969T+6AA;F0@<VED92!O;FQY(ET@*R`B/"]O<'1I;VX^(%P*("`@
M("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64])W)H<R<B("L@<V5L96-T960H
M9E]F<F%M97,@/3T@(G)H<R(I("L@(CXB("L@:3$X;ELB5&AE(')I9VAT+6AA
M;F0@<VED92!O;FQY(ET@*R`B/"]O<'1I;VX^(%P*("`@("`@("`@("`@("`@
M(#QO<'1I;VX@=F%L=64])V)O>"<B("L@<V5L96-T960H9E]F<F%M97,@/3T@
M(F)O>"(I("L@(CXB("L@:3$X;ELB06QL(&9O=7(@<VED97,B72`K("(\+V]P
M=&EO;CX@7`H@("`@("`@("`@("`@(#PO<V5L96-T/B!<"B`@("`@("`@("`@
M(#PO=&0^(%P*("`@("`@("`@(#PO='(^(%P*("`@("`@("`@(#QT<CX@7`H@
M("`@("`@("`@("`\=&0@8VQA<W,])VQA8F5L)SXB("L@:3$X;ELB4G5L97,B
M72`K("(Z/"]T9#X@7`H@("`@("`@("`@("`\=&0^(%P*("`@("`@("`@("`@
M("`\<V5L96-T(&YA;64])V9?<G5L97,G/B!<"B`@("`@("`@("`@("`@("`\
M;W!T:6]N('9A;'5E/2=N;VYE)R(@*R!S96QE8W1E9"AF7W)U;&5S(#T](")N
M;VYE(BD@*R`B/B(@*R!I,3AN6R).;R!R=6QE<R)=("L@(CPO;W!T:6]N/B!<
M"B`@("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2=R;W=S)R(@*R!S96QE
M8W1E9"AF7W)U;&5S(#T](")R;W=S(BD@*R`B/B(@*R!I,3AN6R)2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2)=("L@(CPO;W!T:6]N/B!<
M"B`@("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2=C;VQS)R(@*R!S96QE
M8W1E9"AF7W)U;&5S(#T](")C;VQS(BD@*R`B/B(@*R!I,3AN6R)2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2)=("L@(CPO;W!T:6]N
M/B!<"B`@("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2=A;&PG(B`K('-E
M;&5C=&5D*&9?<G5L97,@/3T@(F%L;"(I("L@(CXB("L@:3$X;ELB4G5L97,@
M=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R)=("L@
M(CPO;W!T:6]N/B!<"B`@("`@("`@("`@("`@/"]S96QE8W0^(%P*("`@("`@
M("`@("`@/"]T9#X@7`H@("`@("`@("`@/"]T<CX@7`H@("`@("`@(#PO=&%B
M;&4^(%P*("`@("`@/"]F:65L9'-E=#X@7`H@("`@/"]T9#X@7`H@(#PO='(^
M(%P*("`\='(^(%P*("`@(#QT9"!I9#TG+2U(02US='EL92<^/"]T9#X@7`H@
M(#PO='(^(%P*/"]T86)L93X@7`HB.PH)"79A<B!S=%]P<F]P(#T@5&%B;&5/
M<&5R871I;VYS+F-R96%T95-T>6QE1FEE;&1S970H9&EA;&]G+F1O8RP@9&EA
M;&]G+F5D:71O<BP@=&%B;&4I.PH)"79A<B!P(#T@9&EA;&]G+F1O8RYG971%
M;&5M96YT0GE)9"@B+2U(02US='EL92(I.PH)"7`N87!P96YD0VAI;&0H<W1?
M<')O<"D["@D)=F%R('-T7VQA>6]U="`](%1A8FQE3W!E<F%T:6]N<RYC<F5A
M=&53='EL94QA>6]U=$9I96QD<V5T*&1I86QO9RYD;V,L(&1I86QO9RYE9&ET
M;W(L('1A8FQE*3L*"0EP(#T@9&EA;&]G+F1O8RYG971%;&5M96YT0GE)9"@B
M+2U(02UL87EO=70B*3L*"0EP+F%P<&5N9$-H:6QD*'-T7VQA>6]U="D["@D)
M9&EA;&]G+FUO9&%L(#T@=')U93L*"0ED:6%L;V<N861D0G5T=&]N<R@B;VLB
M+"`B8V%N8V5L(BD["@D)9&EA;&]G+G-H;W=!=$5L96UE;G0H9&EA;&]G+F5D
M:71O<BY?:69R86UE+"`B8R(I.PH)?2D["GT["@HO+R!T:&ES(&9U;F-T:6]N
M(')E<75I<F5S('1H92!F:6QE(%!O<'5P1&EV+U!O<'5P5VEN('1O(&)E(&QO
M861E9"!F<F]M(&)R;W=S97(*5&%B;&5/<&5R871I;VYS+G!R;W1O='EP92YD
M:6%L;V=2;W=#96QL4')O<&5R=&EE<R`](&9U;F-T:6]N*&-E;&PI('L*"79A
M<B!I,3AN(#T@5&%B;&5/<&5R871I;VYS+DDQ.$X["@DO+R!R971R:65V92!E
M>&ES=&EN9R!V86QU97,*"79A<B!E;&5M96YT(#T@=&AI<RYG971#;&]S97-T
M*&-E;&P@/R`B=&0B(#H@(G1R(BD["@EV87(@=&%B;&4@/2!T:&ES+F=E=$-L
M;W-E<W0H(G1A8FQE(BD["@DO+R!T:&ES+F5D:71O<BYS96QE8W1.;V1E0V]N
M=&5N=',H96QE;65N="D["@DO+R!T:&ES+F5D:71O<BYU<&1A=&54;V]L8F%R
M*"D["@H)=F%R(&1I86QO9R`](&YE=R!0;W!U<%=I;BAT:&ES+F5D:71O<BP@
M:3$X;EMC96QL(#\@(D-E;&P@4')O<&5R=&EE<R(@.B`B4F]W(%!R;W!E<G1I
M97,B72P@9G5N8W1I;VXH9&EA;&]G+"!P87)A;7,I('L*"0E486)L94]P97)A
M=&EO;G,N<')O8V5S<U-T>6QE*'!A<F%M<RP@96QE;65N="D["@D)9F]R("AV
M87(@:2!I;B!P87)A;7,I('L*"0D)=F%R('9A;"`]('!A<F%M<UMI73L*"0D)
M<W=I=&-H("AI*2!["@D)"2`@("!C87-E(")F7V%L:6=N(CH*"0D)"65L96UE
M;G0N86QI9VX@/2!V86P["@D)"0EB<F5A:SL*"0D)("`@(&-A<V4@(F9?8VAA
M<B(Z"@D)"0EE;&5M96YT+F-H(#T@=F%L.PH)"0D)8G)E86L["@D)"2`@("!C
M87-E(")F7W9A;&EG;B(Z"@D)"0EE;&5M96YT+G9!;&EG;B`]('9A;#L*"0D)
M"6)R96%K.PH)"0E]"@D)?0H)"2\O('9A<FEO=7,@=V]R:V%R;W5N9',@=&\@
M<F5F<F5S:"!T:&4@=&%B;&4@9&ES<&QA>2`H1V5C:V\L"@D)+R\@=VAA="=S
M(&=O:6YG(&]N/R$@9&\@;F]T(&1I<V%P<&]I;G0@;64A*0H)"61I86QO9RYE
M9&ET;W(N9F]R8V52961R87<H*3L*"0ED:6%L;V<N961I=&]R+F9O8W5S161I
M=&]R*"D["@D)9&EA;&]G+F5D:71O<BYU<&1A=&54;V]L8F%R*"D["@D)=F%R
M('-A=F5?8V]L;&%P<V4@/2!T86)L92YS='EL92YB;W)D97)#;VQL87!S93L*
M"0ET86)L92YS='EL92YB;W)D97)#;VQL87!S92`](")C;VQL87!S92(["@D)
M=&%B;&4N<W1Y;&4N8F]R9&5R0V]L;&%P<V4@/2`B<V5P87)A=&4B.PH)"71A
M8FQE+G-T>6QE+F)O<F1E<D-O;&QA<'-E(#T@<V%V95]C;VQL87!S93L*"7TL
M"@H)+R\@=&AI<R!F=6YC=&EO;B!G971S(&-A;&QE9"!W:&5N('1H92!D:6%L
M;V<@;F5E9',@=&\@8F4@:6YI=&EA;&EZ960*"69U;F-T:6]N("AD:6%L;V<I
M('L*"@D)=F%R(&9?86QI9VX@/2!E;&5M96YT+F%L:6=N.PH)"79A<B!F7W9A
M;&EG;B`](&5L96UE;G0N=D%L:6=N.PH)"79A<B!F7V-H87(@/2!E;&5M96YT
M+F-H.PH*"0EF=6YC=&EO;B!S96QE8W1E9"AV86PI('L*"0D)<F5T=7)N('9A
M;"`_("(@<V5L96-T960B(#H@(B(["@D)?3L*"@D)+R\@9&EA;&]G(&-O;G1E
M;G1S"@D)9&EA;&]G+F-O;G1E;G0N<W1Y;&4N=VED=&@@/2`B-#`P<'@B.PH)
M"61I86QO9RYC;VYT96YT+FEN;F5R2%1-3"`]("(@7`H\9&EV(&-L87-S/2=T
M:71L92=<"B!S='EL93TG8F%C:V=R;W5N9#H@=7)L*"(@*R!D:6%L;V<N8F%S
M95523"`K(&1I86QO9RYE9&ET;W(N:6UG55),*&-E;&P@/R`B8V5L;"UP<F]P
M+F=I9B(@.B`B<F]W+7!R;W`N9VEF(BP@(E1A8FQE3W!E<F%T:6]N<R(I("L@
M(BD@(V9F9B`Y."4@-3`E(&YO+7)E<&5A="<^(B`K(&DQ.&Y;8V5L;"`_(")#
M96QL(%!R;W!E<G1I97,B(#H@(E)O=R!0<F]P97)T:65S(ET@*R`B/"]D:78^
M(%P*/'1A8FQE('-T>6QE/2=W:61T:#HQ,#`E)SX@7`H@(#QT<CX@7`H@("`@
M/'1D(&ED/2<M+4A!+6QA>6]U="<^(%P*("`@(#PO=&0^(%P*("`\+W1R/B!<
M"B`@/'1R/B!<"B`@("`\=&0@:60])RTM2$$M<W1Y;&4G/CPO=&0^(%P*("`\
M+W1R/B!<"CPO=&%B;&4^(%P*(CL*"0EV87(@<W1?<')O<"`](%1A8FQE3W!E
M<F%T:6]N<RYC<F5A=&53='EL949I96QD<V5T*&1I86QO9RYD;V,L(&1I86QO
M9RYE9&ET;W(L(&5L96UE;G0I.PH)"79A<B!P(#T@9&EA;&]G+F1O8RYG971%
M;&5M96YT0GE)9"@B+2U(02US='EL92(I.PH)"7`N87!P96YD0VAI;&0H<W1?
M<')O<"D["@D)=F%R('-T7VQA>6]U="`](%1A8FQE3W!E<F%T:6]N<RYC<F5A
M=&53='EL94QA>6]U=$9I96QD<V5T*&1I86QO9RYD;V,L(&1I86QO9RYE9&ET
M;W(L(&5L96UE;G0I.PH)"7`@/2!D:6%L;V<N9&]C+F=E=$5L96UE;G1">4ED
M*"(M+4A!+6QA>6]U="(I.PH)"7`N87!P96YD0VAI;&0H<W1?;&%Y;W5T*3L*
M"0ED:6%L;V<N;6]D86P@/2!T<G5E.PH)"61I86QO9RYA9&1"=71T;VYS*")O
M:R(L(")C86YC96PB*3L*"0ED:6%L;V<N<VAO=T%T16QE;65N="AD:6%L;V<N
M961I=&]R+E]I9G)A;64L(")C(BD["@E]*3L*?3L*"B\O('1H:7,@9G5N8W1I
M;VX@9V5T<R!C86QL960@=VAE;B!S;VUE(&)U='1O;B!F<F]M('1H92!486)L
M94]P97)A=&EO;G,@=&]O;&)A<@HO+R!W87,@<')E<W-E9"X*5&%B;&5/<&5R
M871I;VYS+G!R;W1O='EP92YB=71T;VY0<F5S<R`](&9U;F-T:6]N*&5D:71O
M<BP@8G5T=&]N7VED*2!["@ET:&ES+F5D:71O<B`](&5D:71O<CL*"79A<B!M
M;WIB<B`]($A434Q!<F5A+FES7V=E8VMO(#\@(CQB<B`O/B(@.B`B(CL*"79A
M<B!I,3AN(#T@5&%B;&5/<&5R871I;VYS+DDQ.$X["@H)+R\@:&5L<&5R(&9U
M;F-T:6]N('1H870@8VQE87)S('1H92!C;VYT96YT(&EN(&$@=&%B;&4@<F]W
M"@EF=6YC=&EO;B!C;&5A<E)O=RAT<BD@>PH)"79A<B!T9',@/2!T<BYG971%
M;&5M96YT<T)Y5&%G3F%M92@B=&0B*3L*"0EF;W(@*'9A<B!I(#T@=&1S+FQE
M;F=T:#L@+2UI(#X](#`[*2!["@D)"79A<B!T9"`]('1D<UMI73L*"0D)=&0N
M<F]W4W!A;B`](#$["@D)"71D+FEN;F5R2%1-3"`](&UO>F)R.PH)"7T*"7T[
M"@H)9G5N8W1I;VX@<W!L:712;W<H=&0I('L*"0EV87(@;B`]('!A<G-E26YT
M*"(B("L@=&0N<F]W4W!A;BD["@D)=F%R(&YC(#T@<&%R<V5);G0H(B(@*R!T
M9"YC;VQ3<&%N*3L*"0ET9"YR;W=3<&%N(#T@,3L*"0ET<B`]('1D+G!A<F5N
M=$YO9&4["@D)=F%R(&ET<B`]('1R+G)O=TEN9&5X.PH)"79A<B!T<G,@/2!T
M<BYP87)E;G1.;V1E+G)O=W,["@D)=F%R(&EN9&5X(#T@=&0N8V5L;$EN9&5X
M.PH)"7=H:6QE("@M+6X@/B`P*2!["@D)"71R(#T@=')S6RLK:71R73L*"0D)
M=F%R(&]T9"`](&5D:71O<BY?9&]C+F-R96%T945L96UE;G0H(G1D(BD["@D)
M"6]T9"YC;VQ3<&%N(#T@=&0N8V]L4W!A;CL*"0D);W1D+FEN;F5R2%1-3"`]
M(&UO>F)R.PH)"0ET<BYI;G-E<G1"969O<F4H;W1D+"!T<BYC96QL<UMI;F1E
M>%TI.PH)"7T*"0EE9&ET;W(N9F]R8V52961R87<H*3L*"0EE9&ET;W(N=7!D
M871E5&]O;&)A<B@I.PH)?3L*"@EF=6YC=&EO;B!S<&QI=$-O;"AT9"D@>PH)
M"79A<B!N8R`]('!A<G-E26YT*"(B("L@=&0N8V]L4W!A;BD["@D)=&0N8V]L
M4W!A;B`](#$["@D)='(@/2!T9"YP87)E;G1.;V1E.PH)"79A<B!R968@/2!T
M9"YN97AT4VEB;&EN9SL*"0EW:&EL92`H+2UN8R`^(#`I('L*"0D)=F%R(&]T
M9"`](&5D:71O<BY?9&]C+F-R96%T945L96UE;G0H(G1D(BD["@D)"6]T9"YR
M;W=3<&%N(#T@=&0N<F]W4W!A;CL*"0D);W1D+FEN;F5R2%1-3"`](&UO>F)R
M.PH)"0ET<BYI;G-E<G1"969O<F4H;W1D+"!R968I.PH)"7T*"0EE9&ET;W(N
M9F]R8V52961R87<H*3L*"0EE9&ET;W(N=7!D871E5&]O;&)A<B@I.PH)?3L*
M"@EF=6YC=&EO;B!S<&QI=$-E;&PH=&0I('L*"0EV87(@;F,@/2!P87)S94EN
M="@B(B`K('1D+F-O;%-P86XI.PH)"7-P;&ET0V]L*'1D*3L*"0EV87(@:71E
M;7,@/2!T9"YP87)E;G1.;V1E+F-E;&QS.PH)"79A<B!I;F1E>"`]('1D+F-E
M;&Q);F1E>#L*"0EW:&EL92`H;F,M+2`^(#`I('L*"0D)<W!L:712;W<H:71E
M;7-;:6YD97@K*UTI.PH)"7T*"7T["@H)9G5N8W1I;VX@<V5L96-T3F5X=$YO
M9&4H96PI('L*"0EV87(@;F]D92`](&5L+FYE>'13:6)L:6YG.PH)"7=H:6QE
M("AN;V1E("8F(&YO9&4N;F]D951Y<&4@(3T@,2D@>PH)"0EN;V1E(#T@;F]D
M92YN97AT4VEB;&EN9SL*"0E]"@D):68@*"%N;V1E*2!["@D)"6YO9&4@/2!E
M;"YP<F5V:6]U<U-I8FQI;F<["@D)"7=H:6QE("AN;V1E("8F(&YO9&4N;F]D
M951Y<&4@(3T@,2D@>PH)"0D);F]D92`](&YO9&4N<')E=FEO=7-3:6)L:6YG
M.PH)"0E]"@D)?0H)"6EF("@A;F]D92D@>PH)"0EN;V1E(#T@96PN<&%R96YT
M3F]D93L*"0E]"@D)961I=&]R+G-E;&5C=$YO9&5#;VYT96YT<RAN;V1E*3L*
M"7T["@H)<W=I=&-H("AB=71T;VY?:60I('L*"0DO+R!23U=3"@H)("`@(&-A
M<V4@(E1/+7)O=RUI;G-E<G0M86)O=F4B.@H)("`@(&-A<V4@(E1/+7)O=RUI
M;G-E<G0M=6YD97(B.@H)"79A<B!T<B`]('1H:7,N9V5T0VQO<V5S="@B='(B
M*3L*"0EI9B`H(71R*2!["@D)"6)R96%K.PH)"7T*"0EV87(@;W1R(#T@='(N
M8VQO;F5.;V1E*'1R=64I.PH)"6-L96%R4F]W*&]T<BD["@D)='(N<&%R96YT
M3F]D92YI;G-E<G1"969O<F4H;W1R+"`O=6YD97(O+G1E<W0H8G5T=&]N7VED
M*2`_('1R+FYE>'13:6)L:6YG(#H@='(I.PH)"65D:71O<BYF;W)C95)E9')A
M=R@I.PH)"65D:71O<BYF;V-U<T5D:71O<B@I.PH)"6)R96%K.PH)("`@(&-A
M<V4@(E1/+7)O=RUD96QE=&4B.@H)"79A<B!T<B`]('1H:7,N9V5T0VQO<V5S
M="@B='(B*3L*"0EI9B`H(71R*2!["@D)"6)R96%K.PH)"7T*"0EV87(@<&%R
M(#T@='(N<&%R96YT3F]D93L*"0EI9B`H<&%R+G)O=W,N;&5N9W1H(#T](#$I
M('L*"0D)86QE<G0H:3$X;ELB;F]T+61E;"UL87-T+7)O=R)=*3L*"0D)8G)E
M86L["@D)?0H)"2\O('-E="!T:&4@8V%R970@9FER<W0@=&\@82!P;W-I=&EO
M;B!T:&%T(&1O97-N)W0*"0DO+R!D:7-A<'!E87(N"@D)<V5L96-T3F5X=$YO
M9&4H='(I.PH)"7!A<BYR96UO=F5#:&EL9"AT<BD["@D)961I=&]R+F9O<F-E
M4F5D<F%W*"D["@D)961I=&]R+F9O8W5S161I=&]R*"D["@D)961I=&]R+G5P
M9&%T951O;VQB87(H*3L*"0EB<F5A:SL*"2`@("!C87-E(")43RUR;W<M<W!L
M:70B.@H)"79A<B!T9"`]('1H:7,N9V5T0VQO<V5S="@B=&0B*3L*"0EI9B`H
M(71D*2!["@D)"6)R96%K.PH)"7T*"0ES<&QI=%)O=RAT9"D["@D)8G)E86L[
M"@H)"2\O($-/3%5-3E,*"@D@("`@8V%S92`B5$\M8V]L+6EN<V5R="UB969O
M<F4B.@H)("`@(&-A<V4@(E1/+6-O;"UI;G-E<G0M869T97(B.@H)"79A<B!T
M9"`]('1H:7,N9V5T0VQO<V5S="@B=&0B*3L*"0EI9B`H(71D*2!["@D)"6)R
M96%K.PH)"7T*"0EV87(@<F]W<R`]('1D+G!A<F5N=$YO9&4N<&%R96YT3F]D
M92YR;W=S.PH)"79A<B!I;F1E>"`]('1D+F-E;&Q);F1E>#L*"0EF;W(@*'9A
M<B!I(#T@<F]W<RYL96YG=&@[("TM:2`^/2`P.RD@>PH)"0EV87(@='(@/2!R
M;W=S6VE=.PH)"0EV87(@<F5F(#T@='(N8V5L;'-;:6YD97@@*R`H+V%F=&5R
M+RYT97-T*&)U='1O;E]I9"D@/R`Q(#H@,"E=.PH)"0EV87(@;W1D(#T@961I
M=&]R+E]D;V,N8W)E871E16QE;65N="@B=&0B*3L*"0D);W1D+FEN;F5R2%1-
M3"`](&UO>F)R.PH)"0ET<BYI;G-E<G1"969O<F4H;W1D+"!R968I.PH)"7T*
M"0EE9&ET;W(N9F]C=7-%9&ET;W(H*3L*"0EB<F5A:SL*"2`@("!C87-E(")4
M3RUC;VPM<W!L:70B.@H)"79A<B!T9"`]('1H:7,N9V5T0VQO<V5S="@B=&0B
M*3L*"0EI9B`H(71D*2!["@D)"6)R96%K.PH)"7T*"0ES<&QI=$-O;"AT9"D[
M"@D)8G)E86L["@D@("`@8V%S92`B5$\M8V]L+61E;&5T92(Z"@D)=F%R('1D
M(#T@=&AI<RYG971#;&]S97-T*")T9"(I.PH)"6EF("@A=&0I('L*"0D)8G)E
M86L["@D)?0H)"79A<B!I;F1E>"`]('1D+F-E;&Q);F1E>#L*"0EI9B`H=&0N
M<&%R96YT3F]D92YC96QL<RYL96YG=&@@/3T@,2D@>PH)"0EA;&5R="AI,3AN
M6R)N;W0M9&5L+6QA<W0M8V]L(ETI.PH)"0EB<F5A:SL*"0E]"@D)+R\@<V5T
M('1H92!C87)E="!F:7)S="!T;R!A('!O<VET:6]N('1H870@9&]E<VXG="!D
M:7-A<'!E87(*"0ES96QE8W1.97AT3F]D92AT9"D["@D)=F%R(')O=W,@/2!T
M9"YP87)E;G1.;V1E+G!A<F5N=$YO9&4N<F]W<SL*"0EF;W(@*'9A<B!I(#T@
M<F]W<RYL96YG=&@[("TM:2`^/2`P.RD@>PH)"0EV87(@='(@/2!R;W=S6VE=
M.PH)"0ET<BYR96UO=F5#:&EL9"AT<BYC96QL<UMI;F1E>%TI.PH)"7T*"0EE
M9&ET;W(N9F]R8V52961R87<H*3L*"0EE9&ET;W(N9F]C=7-%9&ET;W(H*3L*
M"0EE9&ET;W(N=7!D871E5&]O;&)A<B@I.PH)"6)R96%K.PH*"0DO+R!#14Q,
M4PH*"2`@("!C87-E(")43RUC96QL+7-P;&ET(CH*"0EV87(@=&0@/2!T:&ES
M+F=E=$-L;W-E<W0H(G1D(BD["@D):68@*"%T9"D@>PH)"0EB<F5A:SL*"0E]
M"@D)<W!L:71#96QL*'1D*3L*"0EB<F5A:SL*"2`@("!C87-E(")43RUC96QL
M+6EN<V5R="UB969O<F4B.@H)("`@(&-A<V4@(E1/+6-E;&PM:6YS97)T+6%F
M=&5R(CH*"0EV87(@=&0@/2!T:&ES+F=E=$-L;W-E<W0H(G1D(BD["@D):68@
M*"%T9"D@>PH)"0EB<F5A:SL*"0E]"@D)=F%R('1R(#T@=&0N<&%R96YT3F]D
M93L*"0EV87(@;W1D(#T@961I=&]R+E]D;V,N8W)E871E16QE;65N="@B=&0B
M*3L*"0EO=&0N:6YN97)(5$U,(#T@;6]Z8G(["@D)='(N:6YS97)T0F5F;W)E
M*&]T9"P@+V%F=&5R+RYT97-T*&)U='1O;E]I9"D@/R!T9"YN97AT4VEB;&EN
M9R`Z('1D*3L*"0EE9&ET;W(N9F]R8V52961R87<H*3L*"0EE9&ET;W(N9F]C
M=7-%9&ET;W(H*3L*"0EB<F5A:SL*"2`@("!C87-E(")43RUC96QL+61E;&5T
M92(Z"@D)=F%R('1D(#T@=&AI<RYG971#;&]S97-T*")T9"(I.PH)"6EF("@A
M=&0I('L*"0D)8G)E86L["@D)?0H)"6EF("AT9"YP87)E;G1.;V1E+F-E;&QS
M+FQE;F=T:"`]/2`Q*2!["@D)"6%L97)T*&DQ.&Y;(FYO="UD96PM;&%S="UC
M96QL(ETI.PH)"0EB<F5A:SL*"0E]"@D)+R\@<V5T('1H92!C87)E="!F:7)S
M="!T;R!A('!O<VET:6]N('1H870@9&]E<VXG="!D:7-A<'!E87(*"0ES96QE
M8W1.97AT3F]D92AT9"D["@D)=&0N<&%R96YT3F]D92YR96UO=F5#:&EL9"AT
M9"D["@D)961I=&]R+F9O<F-E4F5D<F%W*"D["@D)961I=&]R+G5P9&%T951O
M;VQB87(H*3L*"0EB<F5A:SL*"2`@("!C87-E(")43RUC96QL+6UE<F=E(CH*
M"0DO+R`A(2!&25A-13H@36]Z:6QL82!S<&5C:69I8R`A(0H)"79A<B!S96P@
M/2!E9&ET;W(N7V=E=%-E;&5C=&EO;B@I.PH)"79A<B!R86YG92P@:2`](#`[
M"@D)=F%R(')O=W,@/2!;73L*"0EV87(@<F]W(#T@;G5L;#L*"0EV87(@8V5L
M;',@/2!N=6QL.PH)"6EF("@A2%1-3$%R96$N:7-?:64I('L*"0D)=')Y('L*
M"0D)"7=H:6QE("AR86YG92`]('-E;"YG971286YG94%T*&DK*RDI('L*"0D)
M"0EV87(@=&0@/2!R86YG92YS=&%R=$-O;G1A:6YE<BYC:&EL9$YO9&5S6W)A
M;F=E+G-T87)T3V9F<V5T73L*"0D)"0EI9B`H=&0N<&%R96YT3F]D92`A/2!R
M;W<I('L*"0D)"0D)<F]W(#T@=&0N<&%R96YT3F]D93L*"0D)"0D)*&-E;&QS
M*2`F)B!R;W=S+G!U<V@H8V5L;',I.PH)"0D)"0EC96QL<R`](%M=.PH)"0D)
M"7T*"0D)"0EC96QL<RYP=7-H*'1D*3L*"0D)"7T*"0D)?2!C871C:"AE*2![
M+RH@9FEN:7-H960@=V%L:VEN9R!T:')O=6=H('-E;&5C=&EO;B`J+WT*"0D)
M<F]W<RYP=7-H*&-E;&QS*3L*"0E](&5L<V4@>PH)"0DO+R!);G1E<FYE="!%
M>'!L;W)E<B`B8G)O=W-E<B(*"0D)=F%R('1D(#T@=&AI<RYG971#;&]S97-T
M*")T9"(I.PH)"0EI9B`H(71D*2!["@D)"0EA;&5R="AI,3AN6R)0;&5A<V4@
M8VQI8VL@:6YT;R!S;VUE(&-E;&PB72D["@D)"0EB<F5A:SL*"0D)?0H)"0EV
M87(@='(@/2!T9"YP87)E;G1%;&5M96YT.PH)"0EV87(@;F]?8V]L<R`]('!R
M;VUP="AI,3AN6R)(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O
M(&UE<F=E/R)=+"`R*3L*"0D):68@*"%N;U]C;VQS*2!["@D)"0DO+R!C86YC
M96QL960*"0D)"6)R96%K.PH)"0E]"@D)"79A<B!N;U]R;W=S(#T@<')O;7!T
M*&DQ.&Y;(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_
M(ETL(#(I.PH)"0EI9B`H(6YO7W)O=W,I('L*"0D)"2\O(&-A;F-E;&QE9`H)
M"0D)8G)E86L["@D)"7T*"0D)=F%R(&-E;&Q?:6YD97@@/2!T9"YC96QL26YD
M97@["@D)"7=H:6QE("AN;U]R;W=S+2T@/B`P*2!["@D)"0ET9"`]('1R+F-E
M;&QS6V-E;&Q?:6YD97A=.PH)"0D)8V5L;',@/2!;=&1=.PH)"0D)9F]R("AV
M87(@:2`](#$[(&D@/"!N;U]C;VQS.R`K*VDI('L*"0D)"0ET9"`]('1D+FYE
M>'13:6)L:6YG.PH)"0D)"6EF("@A=&0I('L*"0D)"0D)8G)E86L["@D)"0D)
M?0H)"0D)"6-E;&QS+G!U<V@H=&0I.PH)"0D)?0H)"0D)<F]W<RYP=7-H*&-E
M;&QS*3L*"0D)"71R(#T@='(N;F5X=%-I8FQI;F<["@D)"0EI9B`H(71R*2![
M"@D)"0D)8G)E86L["@D)"0E]"@D)"7T*"0E]"@D)=F%R($A434P@/2`B(CL*
M"0EF;W(@*&D@/2`P.R!I(#P@<F]W<RYL96YG=&@[("LK:2D@>PH)"0DO+R!I
M("8F("A(5$U,("L]("(\8G(@+SXB*3L*"0D)=F%R(&-E;&QS(#T@<F]W<UMI
M73L*"0D)9F]R("AV87(@:B`](#`[(&H@/"!C96QL<RYL96YG=&@[("LK:BD@
M>PH)"0D)+R\@:B`F)B`H2%1-3"`K/2`B)FYB<W`[(BD["@D)"0EV87(@8V5L
M;"`](&-E;&QS6VI=.PH)"0D)2%1-3"`K/2!C96QL+FEN;F5R2%1-3#L*"0D)
M"2AI('Q\(&HI("8F("AC96QL+G!A<F5N=$YO9&4N<F5M;W9E0VAI;&0H8V5L
M;"DI.PH)"0E]"@D)?0H)"79A<B!T9"`](')O=W-;,%U;,%T["@D)=&0N:6YN
M97)(5$U,(#T@2%1-3#L*"0ET9"YR;W=3<&%N(#T@<F]W<RYL96YG=&@["@D)
M=&0N8V]L4W!A;B`](')O=W-;,%TN;&5N9W1H.PH)"65D:71O<BYS96QE8W1.
M;V1E0V]N=&5N=',H=&0I.PH)"65D:71O<BYF;W)C95)E9')A=R@I.PH)"65D
M:71O<BYF;V-U<T5D:71O<B@I.PH)"6)R96%K.PH*"0DO+R!04D]015)42453
M"@H)("`@(&-A<V4@(E1/+71A8FQE+7!R;W`B.@H)"71H:7,N9&EA;&]G5&%B
M;&50<F]P97)T:65S*"D["@D)8G)E86L["@H)("`@(&-A<V4@(E1/+7)O=RUP
M<F]P(CH*"0ET:&ES+F1I86QO9U)O=T-E;&Q0<F]P97)T:65S*&9A;'-E*3L*
M"0EB<F5A:SL*"@D@("`@8V%S92`B5$\M8V5L;"UP<F]P(CH*"0ET:&ES+F1I
M86QO9U)O=T-E;&Q0<F]P97)T:65S*'1R=64I.PH)"6)R96%K.PH*"2`@("!D
M969A=6QT.@H)"6%L97)T*")"=71T;VX@6R(@*R!B=71T;VY?:60@*R`B72!N
M;W0@>65T(&EM<&QE;65N=&5D(BD["@E]"GT["@HO+R!T:&4@;&ES="!O9B!B
M=71T;VYS(&%D9&5D(&)Y('1H:7,@<&QU9VEN"E1A8FQE3W!E<F%T:6]N<RYB
M=&Y,:7-T(#T@6PH)+R\@=&%B;&4@<')O<&5R=&EE<R!B=71T;VX*"5LB=&%B
M;&4M<')O<"(L("`@("`@(")T86)L92)=+`H);G5L;"P)"0DO+R!S97!A<F%T
M;W(*"@DO+R!23U=3"@E;(G)O=RUP<F]P(BP@("`@("`@("`B='(B72P*"5LB
M<F]W+6EN<V5R="UA8F]V92(L(")T<B)=+`H)6R)R;W<M:6YS97)T+75N9&5R
M(BP@(G1R(ETL"@E;(G)O=RUD96QE=&4B+"`@("`@("`B='(B72P*"5LB<F]W
M+7-P;&ET(BP@("`@("`@(")T9%MR;W=3<&%N(3TQ72)=+`H);G5L;"P*"@DO
M+R!#3TQ3"@E;(F-O;"UI;G-E<G0M8F5F;W)E(BP@(G1D(ETL"@E;(F-O;"UI
M;G-E<G0M869T97(B+"`@(G1D(ETL"@E;(F-O;"UD96QE=&4B+"`@("`@("`@
M(G1D(ETL"@E;(F-O;"US<&QI="(L("`@("`@("`@(G1D6V-O;%-P86XA/3%=
M(ETL"@EN=6QL+`H*"2\O($-%3$Q3"@E;(F-E;&PM<')O<"(L("`@("`@("`@
M(")T9")=+`H)6R)C96QL+6EN<V5R="UB969O<F4B+"`B=&0B72P*"5LB8V5L
M;"UI;G-E<G0M869T97(B+"`@(G1D(ETL"@E;(F-E;&PM9&5L971E(BP@("`@
M("`@(")T9")=+`H)6R)C96QL+6UE<F=E(BP@("`@("`@("`B='(B72P*"5LB
M8V5L;"US<&QI="(L("`@("`@("`@(G1D6V-O;%-P86XA/3$L<F]W4W!A;B$]
M,5TB70H)73L*"@H*+R\O+R!'14Y%4DE#($-/1$4@6W-T>6QE(&]F(&%N>2!E
M;&5M96YT.R!T:&ES('-H;W5L9"!B92!M;W9E9"!I;G1O(&$@<V5P87)A=&4*
M+R\O+R!F:6QE(&%S(&ET)VQL(&)E('9E<GD@=7-E9G5L70HO+R\O($)%1TE.
M($=%3D5224,@0T]$12`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H*5&%B;&5/<&5R871I;VYS+F=E=$QE
M;F=T:"`](&9U;F-T:6]N*'9A;'5E*2!["@EV87(@;&5N(#T@<&%R<V5);G0H
M=F%L=64I.PH):68@*&ES3F%.*&QE;BDI('L*"0EL96X@/2`B(CL*"7T*"7)E
M='5R;B!L96X["GT["@HO+R!!<'!L:65S('1H92!S='EL92!F;W5N9"!I;B`B
M<&%R86US(B!T;R!T:&4@9VEV96X@96QE;65N="X*5&%B;&5/<&5R871I;VYS
M+G!R;V-E<W-3='EL92`](&9U;F-T:6]N*'!A<F%M<RP@96QE;65N="D@>PH)
M=F%R('-T>6QE(#T@96QE;65N="YS='EL93L*"69O<B`H=F%R(&D@:6X@<&%R
M86US*2!["@D)=F%R('9A;"`]('!A<F%M<UMI73L*"0ES=VET8V@@*&DI('L*
M"0D@("`@8V%S92`B9E]S=%]B86-K9W)O=6YD0V]L;W(B.@H)"0ES='EL92YB
M86-K9W)O=6YD0V]L;W(@/2!V86P["@D)"6)R96%K.PH)"2`@("!C87-E(")F
M7W-T7V-O;&]R(CH*"0D)<W1Y;&4N8V]L;W(@/2!V86P["@D)"6)R96%K.PH)
M"2`@("!C87-E(")F7W-T7V)A8VMG<F]U;F1);6%G92(Z"@D)"6EF("@O7%,O
M+G1E<W0H=F%L*2D@>PH)"0D)<W1Y;&4N8F%C:V=R;W5N9$EM86=E(#T@(G5R
M;"@B("L@=F%L("L@(BDB.PH)"0E](&5L<V4@>PH)"0D)<W1Y;&4N8F%C:V=R
M;W5N9$EM86=E(#T@(FYO;F4B.PH)"0E]"@D)"6)R96%K.PH)"2`@("!C87-E
M(")F7W-T7V)O<F1E<E=I9'1H(CH*"0D)<W1Y;&4N8F]R9&5R5VED=&@@/2!V
M86P["@D)"6)R96%K.PH)"2`@("!C87-E(")F7W-T7V)O<F1E<E-T>6QE(CH*
M"0D)<W1Y;&4N8F]R9&5R4W1Y;&4@/2!V86P["@D)"6)R96%K.PH)"2`@("!C
M87-E(")F7W-T7V)O<F1E<D-O;&]R(CH*"0D)<W1Y;&4N8F]R9&5R0V]L;W(@
M/2!V86P["@D)"6)R96%K.PH)"2`@("!C87-E(")F7W-T7V)O<F1E<D-O;&QA
M<'-E(CH*"0D)<W1Y;&4N8F]R9&5R0V]L;&%P<V4@/2!V86P@/R`B8V]L;&%P
M<V4B(#H@(B(["@D)"6)R96%K.PH)"2`@("!C87-E(")F7W-T7W=I9'1H(CH*
M"0D):68@*"]<4R\N=&5S="AV86PI*2!["@D)"0ES='EL92YW:61T:"`]('9A
M;"`K('!A<F%M<ULB9E]S=%]W:61T:%5N:70B73L*"0D)?2!E;'-E('L*"0D)
M"7-T>6QE+G=I9'1H(#T@(B(["@D)"7T*"0D)8G)E86L["@D)("`@(&-A<V4@
M(F9?<W1?:&5I9VAT(CH*"0D):68@*"]<4R\N=&5S="AV86PI*2!["@D)"0ES
M='EL92YH96EG:'0@/2!V86P@*R!P87)A;7-;(F9?<W1?:&5I9VAT56YI=")=
M.PH)"0E](&5L<V4@>PH)"0D)<W1Y;&4N:&5I9VAT(#T@(B(["@D)"7T*"0D)
M8G)E86L["@D)("`@(&-A<V4@(F9?<W1?=&5X=$%L:6=N(CH*"0D):68@*'9A
M;"`]/2`B8VAA<B(I('L*"0D)"79A<B!C:"`]('!A<F%M<ULB9E]S=%]T97AT
M06QI9VY#:&%R(ET["@D)"0EI9B`H8V@@/3T@)R(G*2!["@D)"0D)8V@@/2`G
M7%PB)SL*"0D)"7T*"0D)"7-T>6QE+G1E>'1!;&EG;B`]("<B)R`K(&-H("L@
M)R(G.PH)"0E](&5L<V4@>PH)"0D)<W1Y;&4N=&5X=$%L:6=N(#T@=F%L.PH)
M"0E]"@D)"6)R96%K.PH)"2`@("!C87-E(")F7W-T7W9E<G1I8V%L06QI9VXB
M.@H)"0ES='EL92YV97)T:6-A;$%L:6=N(#T@=F%L.PH)"0EB<F5A:SL*"0D@
M("`@8V%S92`B9E]S=%]F;&]A="(Z"@D)"7-T>6QE+F-S<T9L;V%T(#T@=F%L
M.PH)"0EB<F5A:SL*+R\@"0D@("`@8V%S92`B9E]S=%]M87)G:6XB.@HO+R`)
M"0ES='EL92YM87)G:6X@/2!V86P@*R`B<'@B.PHO+R`)"0EB<F5A:SL*+R\@
M"0D@("`@8V%S92`B9E]S=%]P861D:6YG(CH*+R\@"0D)<W1Y;&4N<&%D9&EN
M9R`]('9A;"`K(")P>"(["B\O(`D)"6)R96%K.PH)"7T*"7T*?3L*"B\O(%)E
M='5R;G,@86X@2%1-3"!E;&5M96YT(&9O<B!A('=I9&=E="!T:&%T(&%L;&]W
M<R!C;VQO<B!S96QE8W1I;VXN("!4:&%T(&ES+`HO+R!A(&)U='1O;B!T:&%T
M(&-O;G1A:6YS('1H92!G:79E;B!C;VQO<BP@:68@86YY+"!A;F0@=VAE;B!P
M<F5S<V5D('=I;&P@<&]P=7`*+R\@=&AE('-O;VYE<BUO<BUL871E<BUT;RUB
M92UR97=R:71T96X@<V5L96-T7V-O;&]R+FAT;6P@9&EA;&]G(&%L;&]W:6YG
M('5S97(*+R\@=&\@<V5L96-T('-O;64@8V]L;W(N("!)9B!A(&-O;&]R(&ES
M('-E;&5C=&5D+"!A;B!I;G!U="!F:65L9"!W:71H('1H92!N86UE"B\O(")F
M7W-T7R(K;F%M92!W:6QL(&)E('5P9&%T960@=VET:"!T:&4@8V]L;W(@=F%L
M=64@:6X@(S$R,S0U-B!F;W)M870N"E1A8FQE3W!E<F%T:6]N<RYC<F5A=&5#
M;VQO<D)U='1O;B`](&9U;F-T:6]N*&1O8RP@961I=&]R+"!C;VQO<BP@;F%M
M92D@>PH):68@*"%C;VQO<BD@>PH)"6-O;&]R(#T@(B(["@E](&5L<V4@:68@
M*"$O(R\N=&5S="AC;VQO<BDI('L*"0EC;VQO<B`]($A434Q!<F5A+E]C;VQO
M<E1O4F=B*&-O;&]R*3L*"7T*"@EV87(@9&8@/2!D;V,N8W)E871E16QE;65N
M="@B<W!A;B(I.PH@"79A<B!F:65L9"`](&1O8RYC<F5A=&5%;&5M96YT*")I
M;G!U="(I.PH)9FEE;&0N='EP92`](")H:61D96XB.PH)9&8N87!P96YD0VAI
M;&0H9FEE;&0I.PH@"69I96QD+FYA;64@/2`B9E]S=%\B("L@;F%M93L*"69I
M96QD+G9A;'5E(#T@8V]L;W(["@EV87(@8G5T=&]N(#T@9&]C+F-R96%T945L
M96UE;G0H(G-P86XB*3L*"6)U='1O;BYC;&%S<TYA;64@/2`B8G5T=&]N0V]L
M;W(B.PH)9&8N87!P96YD0VAI;&0H8G5T=&]N*3L*"79A<B!S<&%N(#T@9&]C
M+F-R96%T945L96UE;G0H(G-P86XB*3L*"7-P86XN8VQA<W-.86UE(#T@(F-H
M;V]S97(B.PH)+R\@<W!A;BYI;FYE<DA434P@/2`B)FYB<W`[)FYB<W`[)FYB
M<W`[)FYB<W`[)FYB<W`[)FYB<W`[)FYB<W`[(CL*"7-P86XN<W1Y;&4N8F%C
M:V=R;W5N9$-O;&]R(#T@8V]L;W(["@EB=71T;VXN87!P96YD0VAI;&0H<W!A
M;BD["@EB=71T;VXN;VYM;W5S96]V97(@/2!F=6YC=&EO;B@I('L@:68@*"%T
M:&ES+F1I<V%B;&5D*2![('1H:7,N8VQA<W-.86UE("L]("(@8G5T=&]N0V]L
M;W(M:&EL:71E(CL@?7T["@EB=71T;VXN;VYM;W5S96]U="`](&9U;F-T:6]N
M*"D@>R!I9B`H(71H:7,N9&ES86)L960I('L@=&AI<RYC;&%S<TYA;64@/2`B
M8G5T=&]N0V]L;W(B.R!]?3L*"7-P86XN;VYC;&EC:R`](&9U;F-T:6]N*"D@
M>PH)"6EF("AT:&ES+G!A<F5N=$YO9&4N9&ES86)L960I('L*"0D)<F5T=7)N
M(&9A;'-E.PH)"7T*"0EE9&ET;W(N7W!O<'5P1&EA;&]G*")S96QE8W1?8V]L
M;W(N:'1M;"(L(&9U;F-T:6]N*&-O;&]R*2!["@D)"6EF("AC;VQO<BD@>PH)
M"0D)<W!A;BYS='EL92YB86-K9W)O=6YD0V]L;W(@/2`B(R(@*R!C;VQO<CL*
M"0D)"69I96QD+G9A;'5E(#T@(B,B("L@8V]L;W(["@D)"7T*"0E]+"!C;VQO
M<BD["@E].PH)=F%R('-P86XR(#T@9&]C+F-R96%T945L96UE;G0H(G-P86XB
M*3L*"7-P86XR+FEN;F5R2%1-3"`]("(F(W@P,&0W.R(["@ES<&%N,BYC;&%S
M<TYA;64@/2`B;F]C;VQO<B(["@ES<&%N,BYT:71L92`](%1A8FQE3W!E<F%T
M:6]N<RY),3A.6R)5;G-E="!C;VQO<B)=.PH)8G5T=&]N+F%P<&5N9$-H:6QD
M*'-P86XR*3L*"7-P86XR+F]N;6]U<V5O=F5R(#T@9G5N8W1I;VXH*2![(&EF
M("@A=&AI<RYP87)E;G1.;V1E+F1I<V%B;&5D*2![('1H:7,N8VQA<W-.86UE
M("L]("(@;F]C;VQO<BUH:6QI=&4B.R!]?3L*"7-P86XR+F]N;6]U<V5O=70@
M/2!F=6YC=&EO;B@I('L@:68@*"%T:&ES+G!A<F5N=$YO9&4N9&ES86)L960I
M('L@=&AI<RYC;&%S<TYA;64@/2`B;F]C;VQO<B([('U].PH)<W!A;C(N;VYC
M;&EC:R`](&9U;F-T:6]N*"D@>PH)"7-P86XN<W1Y;&4N8F%C:V=R;W5N9$-O
M;&]R(#T@(B(["@D)9FEE;&0N=F%L=64@/2`B(CL*"7T["@ER971U<FX@9&8[
M"GT["@I486)L94]P97)A=&EO;G,N8W)E871E4W1Y;&5,87EO=71&:65L9'-E
M="`](&9U;F-T:6]N*&1O8RP@961I=&]R+"!E;"D@>PH)=F%R(&DQ.&X@/2!4
M86)L94]P97)A=&EO;G,N23$X3CL*"79A<B!F:65L9'-E="`](&1O8RYC<F5A
M=&5%;&5M96YT*")F:65L9'-E="(I.PH)=F%R(&QE9V5N9"`](&1O8RYC<F5A
M=&5%;&5M96YT*")L96=E;F0B*3L*"69I96QD<V5T+F%P<&5N9$-H:6QD*&QE
M9V5N9"D["@EL96=E;F0N:6YN97)(5$U,(#T@:3$X;ELB3&%Y;W5T(ET["@EV
M87(@=&%B;&4@/2!D;V,N8W)E871E16QE;65N="@B=&%B;&4B*3L*"69I96QD
M<V5T+F%P<&5N9$-H:6QD*'1A8FQE*3L*"71A8FQE+G-T>6QE+G=I9'1H(#T@
M(C$P,"4B.PH)=F%R('1B;V1Y(#T@9&]C+F-R96%T945L96UE;G0H(G1B;V1Y
M(BD["@ET86)L92YA<'!E;F1#:&EL9"AT8F]D>2D["@H)=F%R('1A9VYA;64@
M/2!E;"YT86=.86UE+G1O3&]W97)#87-E*"D["@EV87(@='(L('1D+"!I;G!U
M="P@<V5L96-T+"!O<'1I;VXL(&]P=&EO;G,L(&D["@H):68@*'1A9VYA;64@
M(3T@(G1D(B`F)B!T86=N86UE("$](")T<B(@)B8@=&%G;F%M92`A/2`B=&@B
M*2!["@D)='(@/2!D;V,N8W)E871E16QE;65N="@B='(B*3L*"0ET8F]D>2YA
M<'!E;F1#:&EL9"AT<BD["@D)=&0@/2!D;V,N8W)E871E16QE;65N="@B=&0B
M*3L*"0ET9"YC;&%S<TYA;64@/2`B;&%B96PB.PH)"71R+F%P<&5N9$-H:6QD
M*'1D*3L*"0ET9"YI;FYE<DA434P@/2!I,3AN6R)&;&]A=")=("L@(CHB.PH)
M"71D(#T@9&]C+F-R96%T945L96UE;G0H(G1D(BD["@D)='(N87!P96YD0VAI
M;&0H=&0I.PH)"7-E;&5C="`](&1O8RYC<F5A=&5%;&5M96YT*")S96QE8W0B
M*3L*"0ET9"YA<'!E;F1#:&EL9"AS96QE8W0I.PH)"7-E;&5C="YN86UE(#T@
M(F9?<W1?9FQO870B.PH)"6]P=&EO;G,@/2!;(DYO;F4B+"`B3&5F="(L(")2
M:6=H=")=.PH)"69O<B`H=F%R(&D@/2`P.R!I(#P@;W!T:6]N<RYL96YG=&@[
M("LK:2D@>PH)"0EV87(@5F%L(#T@;W!T:6]N<UMI73L*"0D)=F%R('9A;"`]
M(&]P=&EO;G-;:5TN=&],;W=E<D-A<V4H*3L*"0D);W!T:6]N(#T@9&]C+F-R
M96%T945L96UE;G0H(F]P=&EO;B(I.PH)"0EO<'1I;VXN:6YN97)(5$U,(#T@
M:3$X;EM686Q=.PH)"0EO<'1I;VXN=F%L=64@/2!V86P["@D)"6]P=&EO;BYS
M96QE8W1E9"`]("@H(B(@*R!E;"YS='EL92YC<W-&;&]A="DN=&],;W=E<D-A
M<V4H*2`]/2!V86PI.PH)"0ES96QE8W0N87!P96YD0VAI;&0H;W!T:6]N*3L*
M"0E]"@E]"@H)='(@/2!D;V,N8W)E871E16QE;65N="@B='(B*3L*"71B;V1Y
M+F%P<&5N9$-H:6QD*'1R*3L*"71D(#T@9&]C+F-R96%T945L96UE;G0H(G1D
M(BD["@ET9"YC;&%S<TYA;64@/2`B;&%B96PB.PH)='(N87!P96YD0VAI;&0H
M=&0I.PH)=&0N:6YN97)(5$U,(#T@:3$X;ELB5VED=&@B72`K("(Z(CL*"71D
M(#T@9&]C+F-R96%T945L96UE;G0H(G1D(BD["@ET<BYA<'!E;F1#:&EL9"AT
M9"D["@EI;G!U="`](&1O8RYC<F5A=&5%;&5M96YT*")I;G!U="(I.PH):6YP
M=70N='EP92`](")T97AT(CL*"6EN<'5T+G9A;'5E(#T@5&%B;&5/<&5R871I
M;VYS+F=E=$QE;F=T:"AE;"YS='EL92YW:61T:"D["@EI;G!U="YS:7IE(#T@
M(C4B.PH):6YP=70N;F%M92`](")F7W-T7W=I9'1H(CL*"6EN<'5T+G-T>6QE
M+FUA<F=I;E)I9VAT(#T@(C`N-65M(CL*"71D+F%P<&5N9$-H:6QD*&EN<'5T
M*3L*"7-E;&5C="`](&1O8RYC<F5A=&5%;&5M96YT*")S96QE8W0B*3L*"7-E
M;&5C="YN86UE(#T@(F9?<W1?=VED=&A5;FET(CL*"6]P=&EO;B`](&1O8RYC
M<F5A=&5%;&5M96YT*")O<'1I;VXB*3L*"6]P=&EO;BYI;FYE<DA434P@/2!I
M,3AN6R)P97)C96YT(ET["@EO<'1I;VXN=F%L=64@/2`B)2(["@EO<'1I;VXN
M<V5L96-T960@/2`O)2\N=&5S="AE;"YS='EL92YW:61T:"D["@ES96QE8W0N
M87!P96YD0VAI;&0H;W!T:6]N*3L*"6]P=&EO;B`](&1O8RYC<F5A=&5%;&5M
M96YT*")O<'1I;VXB*3L*"6]P=&EO;BYI;FYE<DA434P@/2!I,3AN6R)P:7AE
M;',B73L*"6]P=&EO;BYV86QU92`](")P>"(["@EO<'1I;VXN<V5L96-T960@
M/2`O<'@O+G1E<W0H96PN<W1Y;&4N=VED=&@I.PH)<V5L96-T+F%P<&5N9$-H
M:6QD*&]P=&EO;BD["@ET9"YA<'!E;F1#:&EL9"AS96QE8W0I.PH*"7-E;&5C
M="YS='EL92YM87)G:6Y2:6=H="`]("(P+C5E;2(["@ET9"YA<'!E;F1#:&EL
M9"AD;V,N8W)E871E5&5X=$YO9&4H:3$X;ELB5&5X="!A;&EG;B)=("L@(CHB
M*2D["@ES96QE8W0@/2!D;V,N8W)E871E16QE;65N="@B<V5L96-T(BD["@ES
M96QE8W0N<W1Y;&4N;6%R9VEN3&5F="`]('-E;&5C="YS='EL92YM87)G:6Y2
M:6=H="`]("(P+C5E;2(["@ET9"YA<'!E;F1#:&EL9"AS96QE8W0I.PH)<V5L
M96-T+FYA;64@/2`B9E]S=%]T97AT06QI9VXB.PH);W!T:6]N<R`](%LB3&5F
M="(L(")#96YT97(B+"`B4FEG:'0B+"`B2G5S=&EF>2)=.PH):68@*'1A9VYA
M;64@/3T@(G1D(BD@>PH)"6]P=&EO;G,N<'5S:"@B0VAA<B(I.PH)?0H):6YP
M=70@/2!D;V,N8W)E871E16QE;65N="@B:6YP=70B*3L*"6EN<'5T+FYA;64@
M/2`B9E]S=%]T97AT06QI9VY#:&%R(CL*"6EN<'5T+G-I>F4@/2`B,2(["@EI
M;G!U="YS='EL92YF;VYT1F%M:6QY(#T@(FUO;F]S<&%C92(["@ET9"YA<'!E
M;F1#:&EL9"AI;G!U="D["@EF;W(@*'9A<B!I(#T@,#L@:2`\(&]P=&EO;G,N
M;&5N9W1H.R`K*VDI('L*"0EV87(@5F%L(#T@;W!T:6]N<UMI73L*"0EV87(@
M=F%L(#T@5F%L+G1O3&]W97)#87-E*"D["@D);W!T:6]N(#T@9&]C+F-R96%T
M945L96UE;G0H(F]P=&EO;B(I.PH)"6]P=&EO;BYV86QU92`]('9A;#L*"0EO
M<'1I;VXN:6YN97)(5$U,(#T@:3$X;EM686Q=.PH)"6]P=&EO;BYS96QE8W1E
M9"`]("AE;"YS='EL92YT97AT06QI9VXN=&],;W=E<D-A<V4H*2`]/2!V86PI
M.PH)"7-E;&5C="YA<'!E;F1#:&EL9"AO<'1I;VXI.PH)?0H)9G5N8W1I;VX@
M<V5T0VAA<E9I<VEB:6QI='DH=F%L=64I('L*"0EI;G!U="YS='EL92YV:7-I
M8FEL:71Y(#T@=F%L=64@/R`B=FES:6)L92(@.B`B:&ED9&5N(CL*"0EI9B`H
M=F%L=64I('L*"0D):6YP=70N9F]C=7,H*3L*"0D):6YP=70N<V5L96-T*"D[
M"@D)?0H)?3L*"7-E;&5C="YO;F-H86YG92`](&9U;F-T:6]N*"D@>R!S971#
M:&%R5FES:6)I;&ET>2AT:&ES+G9A;'5E(#T](")C:&%R(BD[('T["@ES971#
M:&%R5FES:6)I;&ET>2AS96QE8W0N=F%L=64@/3T@(F-H87(B*3L*"@ET<B`]
M(&1O8RYC<F5A=&5%;&5M96YT*")T<B(I.PH)=&)O9'DN87!P96YD0VAI;&0H
M='(I.PH)=&0@/2!D;V,N8W)E871E16QE;65N="@B=&0B*3L*"71D+F-L87-S
M3F%M92`](")L86)E;"(["@ET<BYA<'!E;F1#:&EL9"AT9"D["@ET9"YI;FYE
M<DA434P@/2!I,3AN6R)(96EG:'0B72`K("(Z(CL*"71D(#T@9&]C+F-R96%T
M945L96UE;G0H(G1D(BD["@ET<BYA<'!E;F1#:&EL9"AT9"D["@EI;G!U="`]
M(&1O8RYC<F5A=&5%;&5M96YT*")I;G!U="(I.PH):6YP=70N='EP92`](")T
M97AT(CL*"6EN<'5T+G9A;'5E(#T@5&%B;&5/<&5R871I;VYS+F=E=$QE;F=T
M:"AE;"YS='EL92YH96EG:'0I.PH):6YP=70N<VEZ92`]("(U(CL*"6EN<'5T
M+FYA;64@/2`B9E]S=%]H96EG:'0B.PH):6YP=70N<W1Y;&4N;6%R9VEN4FEG
M:'0@/2`B,"XU96TB.PH)=&0N87!P96YD0VAI;&0H:6YP=70I.PH)<V5L96-T
M(#T@9&]C+F-R96%T945L96UE;G0H(G-E;&5C="(I.PH)<V5L96-T+FYA;64@
M/2`B9E]S=%]H96EG:'15;FET(CL*"6]P=&EO;B`](&1O8RYC<F5A=&5%;&5M
M96YT*")O<'1I;VXB*3L*"6]P=&EO;BYI;FYE<DA434P@/2!I,3AN6R)P97)C
M96YT(ET["@EO<'1I;VXN=F%L=64@/2`B)2(["@EO<'1I;VXN<V5L96-T960@
M/2`O)2\N=&5S="AE;"YS='EL92YH96EG:'0I.PH)<V5L96-T+F%P<&5N9$-H
M:6QD*&]P=&EO;BD["@EO<'1I;VX@/2!D;V,N8W)E871E16QE;65N="@B;W!T
M:6]N(BD["@EO<'1I;VXN:6YN97)(5$U,(#T@:3$X;ELB<&EX96QS(ET["@EO
M<'1I;VXN=F%L=64@/2`B<'@B.PH);W!T:6]N+G-E;&5C=&5D(#T@+W!X+RYT
M97-T*&5L+G-T>6QE+FAE:6=H="D["@ES96QE8W0N87!P96YD0VAI;&0H;W!T
M:6]N*3L*"71D+F%P<&5N9$-H:6QD*'-E;&5C="D["@H)<V5L96-T+G-T>6QE
M+FUA<F=I;E)I9VAT(#T@(C`N-65M(CL*"71D+F%P<&5N9$-H:6QD*&1O8RYC
M<F5A=&5497AT3F]D92AI,3AN6R)697)T:6-A;"!A;&EG;B)=("L@(CHB*2D[
M"@ES96QE8W0@/2!D;V,N8W)E871E16QE;65N="@B<V5L96-T(BD["@ES96QE
M8W0N;F%M92`](")F7W-T7W9E<G1I8V%L06QI9VXB.PH)<V5L96-T+G-T>6QE
M+FUA<F=I;DQE9G0@/2`B,"XU96TB.PH)=&0N87!P96YD0VAI;&0H<V5L96-T
M*3L*"6]P=&EO;G,@/2!;(E1O<"(L(")-:61D;&4B+"`B0F]T=&]M(BP@(D)A
M<V5L:6YE(ET["@EF;W(@*'9A<B!I(#T@,#L@:2`\(&]P=&EO;G,N;&5N9W1H
M.R`K*VDI('L*"0EV87(@5F%L(#T@;W!T:6]N<UMI73L*"0EV87(@=F%L(#T@
M5F%L+G1O3&]W97)#87-E*"D["@D);W!T:6]N(#T@9&]C+F-R96%T945L96UE
M;G0H(F]P=&EO;B(I.PH)"6]P=&EO;BYV86QU92`]('9A;#L*"0EO<'1I;VXN
M:6YN97)(5$U,(#T@:3$X;EM686Q=.PH)"6]P=&EO;BYS96QE8W1E9"`]("AE
M;"YS='EL92YV97)T:6-A;$%L:6=N+G1O3&]W97)#87-E*"D@/3T@=F%L*3L*
M"0ES96QE8W0N87!P96YD0VAI;&0H;W!T:6]N*3L*"7T*"@ER971U<FX@9FEE
M;&1S970["GT["@HO+R!2971U<FYS(&%N($A434P@96QE;65N="!C;VYT86EN
M:6YG('1H92!S='EL92!A='1R:6)U=&5S(&9O<B!T:&4@9VEV96X*+R\@96QE
M;65N="X@(%1H:7,@8V%N(&)E(&5A<VEL>2!E;6)E9&1E9"!I;G1O(&%N>2!D
M:6%L;V<[('1H92!F=6YC=&EO;F%L:71Y(&ES"B\O(&%L<V\@<')O=FED960N
M"E1A8FQE3W!E<F%T:6]N<RYC<F5A=&53='EL949I96QD<V5T(#T@9G5N8W1I
M;VXH9&]C+"!E9&ET;W(L(&5L*2!["@EV87(@:3$X;B`](%1A8FQE3W!E<F%T
M:6]N<RY),3A..PH)=F%R(&9I96QD<V5T(#T@9&]C+F-R96%T945L96UE;G0H
M(F9I96QD<V5T(BD["@EV87(@;&5G96YD(#T@9&]C+F-R96%T945L96UE;G0H
M(FQE9V5N9"(I.PH)9FEE;&1S970N87!P96YD0VAI;&0H;&5G96YD*3L*"6QE
M9V5N9"YI;FYE<DA434P@/2!I,3AN6R)#4U,@4W1Y;&4B73L*"79A<B!T86)L
M92`](&1O8RYC<F5A=&5%;&5M96YT*")T86)L92(I.PH)9FEE;&1S970N87!P
M96YD0VAI;&0H=&%B;&4I.PH)=&%B;&4N<W1Y;&4N=VED=&@@/2`B,3`P)2([
M"@EV87(@=&)O9'D@/2!D;V,N8W)E871E16QE;65N="@B=&)O9'DB*3L*"71A
M8FQE+F%P<&5N9$-H:6QD*'1B;V1Y*3L*"@EV87(@='(L('1D+"!I;G!U="P@
M<V5L96-T+"!O<'1I;VXL(&]P=&EO;G,L(&D["@H)='(@/2!D;V,N8W)E871E
M16QE;65N="@B='(B*3L*"71B;V1Y+F%P<&5N9$-H:6QD*'1R*3L*"71D(#T@
M9&]C+F-R96%T945L96UE;G0H(G1D(BD["@ET<BYA<'!E;F1#:&EL9"AT9"D[
M"@ET9"YC;&%S<TYA;64@/2`B;&%B96PB.PH)=&0N:6YN97)(5$U,(#T@:3$X
M;ELB0F%C:V=R;W5N9")=("L@(CHB.PH)=&0@/2!D;V,N8W)E871E16QE;65N
M="@B=&0B*3L*"71R+F%P<&5N9$-H:6QD*'1D*3L*"79A<B!D9B`](%1A8FQE
M3W!E<F%T:6]N<RYC<F5A=&5#;VQO<D)U='1O;BAD;V,L(&5D:71O<BP@96PN
M<W1Y;&4N8F%C:V=R;W5N9$-O;&]R+"`B8F%C:V=R;W5N9$-O;&]R(BD["@ED
M9BYF:7)S=$-H:6QD+FYE>'13:6)L:6YG+G-T>6QE+FUA<F=I;E)I9VAT(#T@
M(C`N-65M(CL*"71D+F%P<&5N9$-H:6QD*&1F*3L*"71D+F%P<&5N9$-H:6QD
M*&1O8RYC<F5A=&5497AT3F]D92AI,3AN6R));6%G92!54DPB72`K("(Z("(I
M*3L*"6EN<'5T(#T@9&]C+F-R96%T945L96UE;G0H(FEN<'5T(BD["@EI;G!U
M="YT>7!E(#T@(G1E>'0B.PH):6YP=70N;F%M92`](")F7W-T7V)A8VMG<F]U
M;F1);6%G92(["@EI9B`H96PN<W1Y;&4N8F%C:V=R;W5N9$EM86=E+FUA=&-H
M*"]U<FQ<*%QS*B@N*C\I7',J7"DO*2D@>PH)"6EN<'5T+G9A;'5E(#T@4F5G
M17AP+B0Q.PH)?0H)+R\@:6YP=70N<W1Y;&4N=VED=&@@/2`B,3`P)2(["@ET
M9"YA<'!E;F1#:&EL9"AI;G!U="D["@H)='(@/2!D;V,N8W)E871E16QE;65N
M="@B='(B*3L*"71B;V1Y+F%P<&5N9$-H:6QD*'1R*3L*"71D(#T@9&]C+F-R
M96%T945L96UE;G0H(G1D(BD["@ET<BYA<'!E;F1#:&EL9"AT9"D["@ET9"YC
M;&%S<TYA;64@/2`B;&%B96PB.PH)=&0N:6YN97)(5$U,(#T@:3$X;ELB1D<@
M0V]L;W(B72`K("(Z(CL*"71D(#T@9&]C+F-R96%T945L96UE;G0H(G1D(BD[
M"@ET<BYA<'!E;F1#:&EL9"AT9"D["@ET9"YA<'!E;F1#:&EL9"A486)L94]P
M97)A=&EO;G,N8W)E871E0V]L;W)"=71T;VXH9&]C+"!E9&ET;W(L(&5L+G-T
M>6QE+F-O;&]R+"`B8V]L;W(B*2D["@H)+R\@9F]R(&)E='1E<B!A;&EG;FUE
M;G0@=V4@:6YC;'5D92!A;B!I;G9I<VEB;&4@9FEE;&0N"@EI;G!U="`](&1O
M8RYC<F5A=&5%;&5M96YT*")I;G!U="(I.PH):6YP=70N<W1Y;&4N=FES:6)I
M;&ET>2`](")H:61D96XB.PH):6YP=70N='EP92`](")T97AT(CL*"71D+F%P
M<&5N9$-H:6QD*&EN<'5T*3L*"@ET<B`](&1O8RYC<F5A=&5%;&5M96YT*")T
M<B(I.PH)=&)O9'DN87!P96YD0VAI;&0H='(I.PH)=&0@/2!D;V,N8W)E871E
M16QE;65N="@B=&0B*3L*"71R+F%P<&5N9$-H:6QD*'1D*3L*"71D+F-L87-S
M3F%M92`](")L86)E;"(["@ET9"YI;FYE<DA434P@/2!I,3AN6R)";W)D97(B
M72`K("(Z(CL*"71D(#T@9&]C+F-R96%T945L96UE;G0H(G1D(BD["@ET<BYA
M<'!E;F1#:&EL9"AT9"D["@H)=F%R(&-O;&]R0G5T=&]N(#T@5&%B;&5/<&5R
M871I;VYS+F-R96%T94-O;&]R0G5T=&]N*&1O8RP@961I=&]R+"!E;"YS='EL
M92YB;W)D97)#;VQO<BP@(F)O<F1E<D-O;&]R(BD["@EV87(@8G1N(#T@8V]L
M;W)"=71T;VXN9FER<W1#:&EL9"YN97AT4VEB;&EN9SL*"71D+F%P<&5N9$-H
M:6QD*&-O;&]R0G5T=&]N*3L*"2\O(&)O<F1E<D9I96QD<RYP=7-H*&)T;BD[
M"@EB=&XN<W1Y;&4N;6%R9VEN4FEG:'0@/2`B,"XU96TB.PH*"7-E;&5C="`]
M(&1O8RYC<F5A=&5%;&5M96YT*")S96QE8W0B*3L*"79A<B!B;W)D97)&:65L
M9',@/2!;73L*"71D+F%P<&5N9$-H:6QD*'-E;&5C="D["@ES96QE8W0N;F%M
M92`](")F7W-T7V)O<F1E<E-T>6QE(CL*"6]P=&EO;G,@/2!;(FYO;F4B+"`B
M9&]T=&5D(BP@(F1A<VAE9"(L(")S;VQI9"(L(")D;W5B;&4B+"`B9W)O;W9E
M(BP@(G)I9&=E(BP@(FEN<V5T(BP@(F]U='-E=")=.PH)=F%R(&-U<G)E;G1"
M;W)D97)3='EL92`](&5L+G-T>6QE+F)O<F1E<E-T>6QE.PH)+R\@1V5C:V\@
M<F5P;W)T<R`B<V]L:60@<V]L:60@<V]L:60@<V]L:60B(&9O<B`B8F]R9&5R
M+7-T>6QE.B!S;VQI9"(N"@DO+R!4:&%T(&ES+"`B=&]P(')I9VAT(&)O='1O
M;2!L969T(B`M+2!W92!O;FQY(&-O;G-I9&5R('1H92!F:7)S=`H)+R\@=F%L
M=64N"@DH8W5R<F5N=$)O<F1E<E-T>6QE+FUA=&-H*"\H6UY<<UTJ*5QS+RDI
M("8F("AC=7)R96YT0F]R9&5R4W1Y;&4@/2!296=%>'`N)#$I.PH)9F]R("AV
M87(@:2!I;B!O<'1I;VYS*2!["@D)=F%R('9A;"`](&]P=&EO;G-;:5T["@D)
M;W!T:6]N(#T@9&]C+F-R96%T945L96UE;G0H(F]P=&EO;B(I.PH)"6]P=&EO
M;BYV86QU92`]('9A;#L*"0EO<'1I;VXN:6YN97)(5$U,(#T@=F%L.PH)"2AV
M86P@/3T@8W5R<F5N=$)O<F1E<E-T>6QE*2`F)B`H;W!T:6]N+G-E;&5C=&5D
M(#T@=')U92D["@D)<V5L96-T+F%P<&5N9$-H:6QD*&]P=&EO;BD["@E]"@ES
M96QE8W0N<W1Y;&4N;6%R9VEN4FEG:'0@/2`B,"XU96TB.PH)9G5N8W1I;VX@
M<V5T0F]R9&5R1FEE;&1S4W1A='5S*'9A;'5E*2!["@D)9F]R("AV87(@:2`]
M(#`[(&D@/"!B;W)D97)&:65L9',N;&5N9W1H.R`K*VDI('L*"0D)=F%R(&5L
M(#T@8F]R9&5R1FEE;&1S6VE=.PH)"0EE;"YS='EL92YV:7-I8FEL:71Y(#T@
M=F%L=64@/R`B:&ED9&5N(B`Z(")V:7-I8FQE(CL*"0D):68@*"%V86QU92`F
M)B`H96PN=&%G3F%M92YT;TQO=V5R0V%S92@I(#T](")I;G!U="(I*2!["@D)
M"0EE;"YF;V-U<R@I.PH)"0D)96PN<V5L96-T*"D["@D)"7T*"0E]"@E].PH)
M<V5L96-T+F]N8VAA;F=E(#T@9G5N8W1I;VXH*2![('-E=$)O<F1E<D9I96QD
M<U-T871U<RAT:&ES+G9A;'5E(#T](")N;VYE(BD[('T["@H):6YP=70@/2!D
M;V,N8W)E871E16QE;65N="@B:6YP=70B*3L*"6)O<F1E<D9I96QD<RYP=7-H
M*&EN<'5T*3L*"6EN<'5T+G1Y<&4@/2`B=&5X="(["@EI;G!U="YN86UE(#T@
M(F9?<W1?8F]R9&5R5VED=&@B.PH):6YP=70N=F%L=64@/2!486)L94]P97)A
M=&EO;G,N9V5T3&5N9W1H*&5L+G-T>6QE+F)O<F1E<E=I9'1H*3L*"6EN<'5T
M+G-I>F4@/2`B-2(["@ET9"YA<'!E;F1#:&EL9"AI;G!U="D["@EI;G!U="YS
M='EL92YM87)G:6Y2:6=H="`]("(P+C5E;2(["@EV87(@<W!A;B`](&1O8RYC
M<F5A=&5%;&5M96YT*")S<&%N(BD["@ES<&%N+FEN;F5R2%1-3"`](&DQ.&Y;
M(G!I>&5L<R)=.PH)=&0N87!P96YD0VAI;&0H<W!A;BD["@EB;W)D97)&:65L
M9',N<'5S:"AS<&%N*3L*"@ES971";W)D97)&:65L9'-3=&%T=7,H<V5L96-T
M+G9A;'5E(#T](")N;VYE(BD["@H):68@*&5L+G1A9TYA;64N=&],;W=E<D-A
M<V4H*2`]/2`B=&%B;&4B*2!["@D)+R\@=&AE(&)O<F1E<BUC;VQL87!S92!S
M='EL92!I<R!O;FQY(&9O<B!T86)L97,*"0ET<B`](&1O8RYC<F5A=&5%;&5M
M96YT*")T<B(I.PH)"71B;V1Y+F%P<&5N9$-H:6QD*'1R*3L*"0ET9"`](&1O
M8RYC<F5A=&5%;&5M96YT*")T9"(I.PH)"71D+F-L87-S3F%M92`](")L86)E
M;"(["@D)='(N87!P96YD0VAI;&0H=&0I.PH)"6EN<'5T(#T@9&]C+F-R96%T
M945L96UE;G0H(FEN<'5T(BD["@D):6YP=70N='EP92`](")C:&5C:V)O>"([
M"@D):6YP=70N;F%M92`](")F7W-T7V)O<F1E<D-O;&QA<'-E(CL*"0EI;G!U
M="YI9"`](")F7W-T7V)O<F1E<D-O;&QA<'-E(CL*"0EV87(@=F%L(#T@*"]C
M;VQL87!S92]I+G1E<W0H96PN<W1Y;&4N8F]R9&5R0V]L;&%P<V4I*3L*"0EI
M;G!U="YC:&5C:V5D(#T@=F%L(#\@,2`Z(#`["@D)=&0N87!P96YD0VAI;&0H
M:6YP=70I.PH*"0ET9"`](&1O8RYC<F5A=&5%;&5M96YT*")T9"(I.PH)"71R
M+F%P<&5N9$-H:6QD*'1D*3L*"0EV87(@;&%B96P@/2!D;V,N8W)E871E16QE
M;65N="@B;&%B96PB*3L*"0EL86)E;"YH=&UL1F]R(#T@(F9?<W1?8F]R9&5R
M0V]L;&%P<V4B.PH)"6QA8F5L+FEN;F5R2%1-3"`](&DQ.&Y;(D-O;&QA<'-E
M9"!B;W)D97)S(ET["@D)=&0N87!P96YD0VAI;&0H;&%B96PI.PH)?0H*+R\@
M"71R(#T@9&]C+F-R96%T945L96UE;G0H(G1R(BD["B\O(`ET8F]D>2YA<'!E
M;F1#:&EL9"AT<BD["B\O(`ET9"`](&1O8RYC<F5A=&5%;&5M96YT*")T9"(I
M.PHO+R`)=&0N8VQA<W-.86UE(#T@(FQA8F5L(CL*+R\@"71R+F%P<&5N9$-H
M:6QD*'1D*3L*+R\@"71D+FEN;F5R2%1-3"`](&DQ.&Y;(DUA<F=I;B)=("L@
M(CHB.PHO+R`)=&0@/2!D;V,N8W)E871E16QE;65N="@B=&0B*3L*+R\@"71R
M+F%P<&5N9$-H:6QD*'1D*3L*+R\@"6EN<'5T(#T@9&]C+F-R96%T945L96UE
M;G0H(FEN<'5T(BD["B\O(`EI;G!U="YT>7!E(#T@(G1E>'0B.PHO+R`):6YP
M=70N<VEZ92`]("(U(CL*+R\@"6EN<'5T+FYA;64@/2`B9E]S=%]M87)G:6XB
M.PHO+R`)=&0N87!P96YD0VAI;&0H:6YP=70I.PHO+R`):6YP=70N<W1Y;&4N
M;6%R9VEN4FEG:'0@/2`B,"XU96TB.PHO+R`)=&0N87!P96YD0VAI;&0H9&]C
M+F-R96%T951E>'1.;V1E*&DQ.&Y;(E!A9&1I;F<B72`K("(Z(BDI.PH*+R\@
M"6EN<'5T(#T@9&]C+F-R96%T945L96UE;G0H(FEN<'5T(BD["B\O(`EI;G!U
M="YT>7!E(#T@(G1E>'0B.PHO+R`):6YP=70N<VEZ92`]("(U(CL*+R\@"6EN
M<'5T+FYA;64@/2`B9E]S=%]P861D:6YG(CL*+R\@"71D+F%P<&5N9$-H:6QD
M*&EN<'5T*3L*+R\@"6EN<'5T+G-T>6QE+FUA<F=I;DQE9G0@/2`B,"XU96TB
M.PHO+R`):6YP=70N<W1Y;&4N;6%R9VEN4FEG:'0@/2`B,"XU96TB.PHO+R`)
M=&0N87!P96YD0VAI;&0H9&]C+F-R96%T951E>'1.;V1E*&DQ.&Y;(G!I>&5L
M<R)=*2D["@H)<F5T=7)N(&9I96QD<V5T.PI].PH*+R\O+R!%3D0@1T5.15))
M0R!#3T1%("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2T*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;W!U<&1I=BYJ<P``
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C(V-S8`,3`U,34T,S,W-3<`,#(U,#$Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"\J
M*B!4:&ES(&9I;&4@:7,@9&5R:79E9"!F<F]M(%!O<'5P1&EV+"!D979E;&]P
M960@8GD@36EH86D@0F%Z;VX@9F]R"B`J(%-A;5=A<F4N;F5T+B`@36]D:69I
M8V%T:6]N<R!W97)E(&YE961E9"!T;R!M86ME(&ET('5S86)L92!I;B!(5$U,
M07)E82X*("H@2%1-3$%R96$@:7,@82!F<F5E(%=94TE764<@;VYL:6YE($A4
M34P@961I=&]R(&9R;VT@26YT97)A8W1I=F54;V]L<RYC;VTN"B`J"B`J(%1H
M:7,@9FEL92!D;V5S(&YO="!F=6YC=&EO;B!S=&%N9&%L;VYE+B`@270@:7,@
M9&5P96YD96YT(&]F(&=L;V)A;"!F=6YC=&EO;G,*("H@9&5F:6YE9"!I;B!(
M5$U,07)E82TS+C`@*&AT;6QA<F5A+FIS*2X*("H*("H@4&QE87-E('-E92!F
M:6QE(&AT;6QA<F5A+FIS(&9O<B!F=7)T:&5R(&1E=&%I;',N"B`J*B\*"G9A
M<B!I<U]I92`]("@@*&YA=FEG871O<BYU<V5R06=E;G0N=&],;W=E<D-A<V4H
M*2YI;F1E>$]F*")M<VEE(BD@(3T@+3$I("8F"@D@("`@("`H;F%V:6=A=&]R
M+G5S97)!9V5N="YT;TQO=V5R0V%S92@I+FEN9&5X3V8H(F]P97)A(BD@/3T@
M+3$I("D["G9A<B!I<U]C;VUP870@/2`H9&]C=6UE;G0N8V]M<&%T36]D92`]
M/2`B0F%C:T-O;7!A="(I.PH*9G5N8W1I;VX@4&]P=7!$:78H961I=&]R+"!T
M:71L951E>'0L(&AA;F1L97(L(&EN:71&=6YC=&EO;BD@>PH)=F%R('-E;&8@
M/2!T:&ES.PH*"71H:7,N961I=&]R(#T@961I=&]R.PH)=&AI<RYD;V,@/2!E
M9&ET;W(N7VUD;V,["@ET:&ES+FAA;F1L97(@/2!H86YD;&5R.PH*"79A<B!E
M;"`]('1H:7,N9&]C+F-R96%T945L96UE;G0H(F1I=B(I.PH)96PN8VQA<W-.
M86UE(#T@(F-O;G1E;G0B.PH*"79A<B!P;W!U<"`]('1H:7,N9&]C+F-R96%T
M945L96UE;G0H(F1I=B(I.PH)<&]P=7`N8VQA<W-.86UE(#T@(F1I86QO9R!P
M;W!U<&1I=B(["@ET:&ES+F5L96UE;G0@/2!P;W!U<#L*"79A<B!S(#T@<&]P
M=7`N<W1Y;&4["@ES+G!O<VET:6]N(#T@(F%B<V]L=71E(CL*"7,N;&5F="`]
M("(P<'@B.PH)<RYT;W`@/2`B,'!X(CL*"@EV87(@=&ET;&4@/2!T:&ES+F1O
M8RYC<F5A=&5%;&5M96YT*")D:78B*3L*"71I=&QE+F-L87-S3F%M92`](")T
M:71L92(["@ET:&ES+G1I=&QE(#T@=&ET;&4["@EP;W!U<"YA<'!E;F1#:&EL
M9"AT:71L92D["@H)2%1-3$%R96$N7V%D9$5V96YT*'1I=&QE+"`B;6]U<V5D
M;W=N(BP@9G5N8W1I;VXH978I('L*"0ES96QF+E]D<F%G4W1A<G0H:7-?:64@
M/R!W:6YD;W<N979E;G0@.B!E=BD["@E]*3L*"@EV87(@8G5T=&]N(#T@=&AI
M<RYD;V,N8W)E871E16QE;65N="@B9&EV(BD["@EB=71T;VXN8VQA<W-.86UE
M(#T@(F)U='1O;B(["@ET:71L92YA<'!E;F1#:&EL9"AB=71T;VXI.PH)8G5T
M=&]N+FEN;F5R2%1-3"`]("(F(W@P,&0W.R(["@ET:71L92YA<'!E;F1#:&EL
M9"AT:&ES+F1O8RYC<F5A=&5497AT3F]D92AT:71L951E>'0I*3L*"71H:7,N
M=&ET;&5497AT(#T@=&ET;&5497AT.PH*"6)U='1O;BYO;FUO=7-E;W9E<B`]
M(&9U;F-T:6]N*"D@>PH)"71H:7,N8VQA<W-.86UE("L]("(@8G5T=&]N+6AI
M;&ET92(["@E].PH)8G5T=&]N+F]N;6]U<V5O=70@/2!F=6YC=&EO;B@I('L*
M"0ET:&ES+F-L87-S3F%M92`]('1H:7,N8VQA<W-.86UE+G)E<&QA8V4H+UQS
M*F)U='1O;BUH:6QI=&5<<RHO9RP@(B`B*3L*"7T["@EB=71T;VXN;VYC;&EC
M:R`](&9U;F-T:6]N*"D@>PH)"71H:7,N8VQA<W-.86UE(#T@=&AI<RYC;&%S
M<TYA;64N<F5P;&%C92@O7',J8G5T=&]N+6AI;&ET95QS*B]G+"`B("(I.PH)
M"7-E;&8N8VQO<V4H*3L*"7T["@H)<&]P=7`N87!P96YD0VAI;&0H96PI.PH)
M=&AI<RYC;VYT96YT(#T@96P["@H)=&AI<RYD;V,N8F]D>2YA<'!E;F1#:&EL
M9"AP;W!U<"D["@H)=&AI<RYD<F%G9VEN9R`](&9A;'-E.PH)=&AI<RYO;E-H
M;W<@/2!N=6QL.PH)=&AI<RYO;D-L;W-E(#T@;G5L;#L*"71H:7,N;6]D86P@
M/2!F86QS93L*"@EI;FET1G5N8W1I;VXH=&AI<RD["GT["@I0;W!U<$1I=BYC
M=7)R96YT4&]P=7`@/2!N=6QL.PH*4&]P=7!$:78N<')O=&]T>7!E+G-H;W=!
M=$5L96UE;G0@/2!F=6YC=&EO;BAE;"P@;6]D92D@>PH)=&AI<RYD969A=6QT
M4VEZ92@I.PH)=F%R('!O<RP@97<L(&5H.PH)=F%R('!O<'5P(#T@=&AI<RYE
M;&5M96YT.PH)<&]P=7`N<W1Y;&4N9&ES<&QA>2`](")B;&]C:R(["@EV87(@
M=R`]('!O<'5P+F]F9G-E=%=I9'1H.PH)=F%R(&@@/2!P;W!U<"YO9F9S971(
M96EG:'0["@EP;W!U<"YS='EL92YD:7-P;&%Y(#T@(FYO;F4B.PH):68@*&5L
M("$]('=I;F1O=RD@>PH)"7!O<R`](%!O<'5P1&EV+F=E=$%B<V]L=71E4&]S
M*&5L*3L*"0EE=R`](&5L+F]F9G-E=%=I9'1H.PH)"65H(#T@96PN;V9F<V5T
M2&5I9VAT.PH)?2!E;'-E('L*"0EP;W,@/2![>#HP+"!Y.C!].PH)"79A<B!S
M:7IE(#T@4&]P=7!$:78N9V5T5VEN9&]W4VEZ92@I.PH)"65W(#T@<VEZ92YX
M.PH)"65H(#T@<VEZ92YY.PH)?0H)=F%R($98(#T@9F%L<V4L($99(#T@9F%L
M<V4["@EI9B`H;6]D92YI;F1E>$]F*")L(BD@(3T@+3$I('L*"0EP;W,N>"`M
M/2!W.PH)"498(#T@=')U93L*"7T*"6EF("AM;V1E+FEN9&5X3V8H(G(B*2`A
M/2`M,2D@>PH)"7!O<RYX("L](&5W.PH)"498(#T@=')U93L*"7T*"6EF("AM
M;V1E+FEN9&5X3V8H(G0B*2`A/2`M,2D@>PH)"7!O<RYY("T](&@["@D)1ED@
M/2!T<G5E.PH)?0H):68@*&UO9&4N:6YD97A/9B@B8B(I("$]("TQ*2!["@D)
M<&]S+GD@*ST@96@["@D)1ED@/2!T<G5E.PH)?0H):68@*&UO9&4N:6YD97A/
M9B@B8R(I("$]("TQ*2!["@D)1E@@?'P@*'!O<RYX("L]($UA=&@N<F]U;F0H
M*&5W("T@=RD@+R`R*2D["@D)1ED@?'P@*'!O<RYY("L]($UA=&@N<F]U;F0H
M*&5H("T@:"D@+R`R*2D["@E]"@ET:&ES+G-H;W=!="AP;W,N>"P@<&]S+GDI
M.PI].PH*4&]P=7!$:78N<')O=&]T>7!E+F1E9F%U;'13:7IE(#T@9G5N8W1I
M;VXH*2!["@EV87(@<R`]('1H:7,N96QE;65N="YS='EL93L*"79A<B!C<R`]
M('1H:7,N96QE;65N="YC=7)R96YT4W1Y;&4["@EV87(@861D6"`]("AI<U]I
M92`F)B!I<U]C;VUP870I(#\@*'!A<G-E26YT*&-S+F)O<F1E<DQE9G17:61T
M:"D@*PH)"0D)"2`@('!A<G-E26YT*&-S+F)O<F1E<E)I9VAT5VED=&@I("L*
M"0D)"0D@("!P87)S94EN="AC<RYP861D:6YG3&5F="D@*PH)"0D)"2`@('!A
M<G-E26YT*&-S+G!A9&1I;F=2:6=H="DI(#H@,#L*"79A<B!A9&19(#T@*&ES
M7VEE("8F(&ES7V-O;7!A="D@/R`H<&%R<V5);G0H8W,N8F]R9&5R5&]P5VED
M=&@I("L*"0D)"0D@("!P87)S94EN="AC<RYB;W)D97)";W1T;VU7:61T:"D@
M*PH)"0D)"2`@('!A<G-E26YT*&-S+G!A9&1I;F=4;W`I("L*"0D)"0D@("!P
M87)S94EN="AC<RYP861D:6YG0F]T=&]M*2D@.B`P.PH)<RYD:7-P;&%Y(#T@
M(F)L;V-K(CL*"7,N=VED=&@@/2`H=&AI<RYC;VYT96YT+F]F9G-E=%=I9'1H
M("L@861D6"D@*R`B<'@B.PH)<RYH96EG:'0@/2`H=&AI<RYC;VYT96YT+F]F
M9G-E=$AE:6=H="`K('1H:7,N=&ET;&4N;V9F<V5T2&5I9VAT*2`K(")P>"([
M"@ES+F1I<W!L87D@/2`B;F]N92(["GT["@I0;W!U<$1I=BYP<F]T;W1Y<&4N
M<VAO=T%T(#T@9G5N8W1I;VXH>"P@>2D@>PH)=&AI<RYD969A=6QT4VEZ92@I
M.PH)=F%R(',@/2!T:&ES+F5L96UE;G0N<W1Y;&4["@ES+F1I<W!L87D@/2`B
M8FQO8VLB.PH)<RYL969T(#T@>"`K(")P>"(["@ES+G1O<"`]('D@*R`B<'@B
M.PH)=&AI<RYH:61E4VAO=T-O=F5R960H*3L*"@E0;W!U<$1I=BYC=7)R96YT
M4&]P=7`@/2!T:&ES.PH)2%1-3$%R96$N7V%D9$5V96YT<RAT:&ES+F1O8RYB
M;V1Y+"!;(FUO=7-E9&]W;B(L(")C;&EC:R)=+"!0;W!U<$1I=BYC:&5C:U!O
M<'5P*3L*"4A434Q!<F5A+E]A9&1%=F5N=',H=&AI<RYE9&ET;W(N7V1O8RYB
M;V1Y+"!;(FUO=7-E9&]W;B(L(")C;&EC:R)=+"!0;W!U<$1I=BYC:&5C:U!O
M<'5P*3L*"6EF("AI<U]I92`F)B!T:&ES+FUO9&%L*2!["@D)=&AI<RYD;V,N
M8F]D>2YS971#87!T=7)E*&9A;'-E*3L*"0ET:&ES+F1O8RYB;V1Y+F]N;&]S
M96-A<'1U<F4@/2!F=6YC=&EO;B@I('L*"0D)*%!O<'5P1&EV+F-U<G)E;G10
M;W!U<"D@)B8@*'1H:7,N9&]C+F)O9'DN<V5T0V%P='5R92AF86QS92DI.PH)
M"7T["@E]"@EW:6YD;W<N979E;G0@)B8@2%1-3$%R96$N7W-T;W!%=F5N="AW
M:6YD;W<N979E;G0I.PH*"6EF("AT>7!E;V8@=&AI<RYO;E-H;W<@/3T@(F9U
M;F-T:6]N(BD@>PH)"71H:7,N;VY3:&]W*"D["@E](&5L<V4@:68@*'1Y<&5O
M9B!T:&ES+F]N4VAO=R`]/2`B<W1R:6YG(BD@>PH)"65V86PH=&AI<RYO;E-H
M;W<I.PH)?0H*"79A<B!F:65L9"`]('1H:7,N96QE;65N="YG971%;&5M96YT
M<T)Y5&%G3F%M92@B:6YP=70B*5LP73L*"6EF("@A9FEE;&0I('L*"0EF:65L
M9"`]('1H:7,N96QE;65N="YG971%;&5M96YT<T)Y5&%G3F%M92@B<V5L96-T
M(BE;,%T["@E]"@EI9B`H(69I96QD*2!["@D)9FEE;&0@/2!T:&ES+F5L96UE
M;G0N9V5T16QE;65N='-">51A9TYA;64H(G1E>'1A<F5A(BE;,%T["@E]"@EI
M9B`H9FEE;&0I('L*"0EF:65L9"YF;V-U<R@I.PH)?0I].PH*4&]P=7!$:78N
M<')O=&]T>7!E+F-L;W-E(#T@9G5N8W1I;VXH*2!["@ET:&ES+F5L96UE;G0N
M<W1Y;&4N9&ES<&QA>2`](")N;VYE(CL*"5!O<'5P1&EV+F-U<G)E;G10;W!U
M<"`](&YU;&P["@ET:&ES+FAI9&53:&]W0V]V97)E9"@I.PH)2%1-3$%R96$N
M7W)E;6]V945V96YT<RAT:&ES+F1O8RYB;V1Y+"!;(FUO=7-E9&]W;B(L(")C
M;&EC:R)=+"!0;W!U<$1I=BYC:&5C:U!O<'5P*3L*"4A434Q!<F5A+E]R96UO
M=F5%=F5N=',H=&AI<RYE9&ET;W(N7V1O8RYB;V1Y+"!;(FUO=7-E9&]W;B(L
M(")C;&EC:R)=+"!0;W!U<$1I=BYC:&5C:U!O<'5P*3L*"6ES7VEE("8F('1H
M:7,N;6]D86P@)B8@=&AI<RYD;V,N8F]D>2YR96QE87-E0V%P='5R92@I.PH)
M:68@*'1Y<&5O9B!T:&ES+F]N0VQO<V4@/3T@(F9U;F-T:6]N(BD@>PH)"71H
M:7,N;VY#;&]S92@I.PH)?2!E;'-E(&EF("AT>7!E;V8@=&AI<RYO;D-L;W-E
M(#T](")S=')I;F<B*2!["@D)979A;"AT:&ES+F]N0VQO<V4I.PH)?0H)=&AI
M<RYE;&5M96YT+G!A<F5N=$YO9&4N<F5M;W9E0VAI;&0H=&AI<RYE;&5M96YT
M*3L*?3L*"E!O<'5P1&EV+G!R;W1O='EP92YG971&;W)M(#T@9G5N8W1I;VXH
M*2!["@EV87(@9F]R;7,@/2!T:&ES+F-O;G1E;G0N9V5T16QE;65N='-">51A
M9TYA;64H(F9O<FTB*3L*"7)E='5R;B`H9F]R;7,N;&5N9W1H(#X@,"D@/R!F
M;W)M<ULP72`Z(&YU;&P["GT["@I0;W!U<$1I=BYP<F]T;W1Y<&4N8V%L;$AA
M;F1L97(@/2!F=6YC=&EO;B@I('L*"79A<B!T86=S(#T@6R)I;G!U="(L(")T
M97AT87)E82(L(")S96QE8W0B73L*"79A<B!P87)A;7,@/2!N97<@3V)J96-T
M*"D["@EF;W(@*'9A<B!T:2`]('1A9W,N;&5N9W1H.R`M+71I(#X](#`[*2![
M"@D)=F%R('1A9R`]('1A9W-;=&E=.PH)"79A<B!E;',@/2!T:&ES+F-O;G1E
M;G0N9V5T16QE;65N='-">51A9TYA;64H=&%G*3L*"0EF;W(@*'9A<B!J(#T@
M,#L@:B`\(&5L<RYL96YG=&@[("LK:BD@>PH)"0EV87(@96P@/2!E;'-;:ET[
M"@D)"7!A<F%M<UME;"YN86UE72`](&5L+G9A;'5E.PH)"7T*"7T*"71H:7,N
M:&%N9&QE<BAT:&ES+"!P87)A;7,I.PH)<F5T=7)N(&9A;'-E.PI].PH*4&]P
M=7!$:78N9V5T06)S;VQU=&50;W,@/2!F=6YC=&EO;BAE;"D@>PH)=F%R('(@
M/2![('@Z(&5L+F]F9G-E=$QE9G0L('DZ(&5L+F]F9G-E=%1O<"!].PH):68@
M*&5L+F]F9G-E=%!A<F5N="D@>PH)"79A<B!T;7`@/2!0;W!U<$1I=BYG971!
M8G-O;'5T95!O<RAE;"YO9F9S971087)E;G0I.PH)"7(N>"`K/2!T;7`N>#L*
M"0ER+GD@*ST@=&UP+GD["@E]"@ER971U<FX@<CL*?3L*"E!O<'5P1&EV+F=E
M=%=I;F1O=U-I>F4@/2!F=6YC=&EO;B@I('L*"6EF("AW:6YD;W<N:6YN97)(
M96EG:'0I('L*"0ER971U<FX@>R!Y.B!W:6YD;W<N:6YN97)(96EG:'0L('@Z
M('=I;F1O=RYI;FYE<E=I9'1H('T["@E]"@EI9B`H=&AI<RYD;V,N8F]D>2YC
M;&EE;G1(96EG:'0I('L*"0ER971U<FX@>R!Y.B!T:&ES+F1O8RYB;V1Y+F-L
M:65N=$AE:6=H="P@>#H@=&AI<RYD;V,N8F]D>2YC;&EE;G17:61T:"!].PH)
M?0H)<F5T=7)N('L@>3H@=&AI<RYD;V,N9&]C=6UE;G1%;&5M96YT+F-L:65N
M=$AE:6=H="P@>#H@=&AI<RYD;V,N9&]C=6UE;G1%;&5M96YT+F-L:65N=%=I
M9'1H('T["GT["@I0;W!U<$1I=BYP<F]T;W1Y<&4N:&ED95-H;W=#;W9E<F5D
M(#T@9G5N8W1I;VX@*"D@>PH)=F%R('-E;&8@/2!T:&ES.PH)9G5N8W1I;VX@
M:7-#;VYT86EN960H96PI('L*"0EW:&EL92`H96PI('L*"0D):68@*&5L(#T]
M('-E;&8N96QE;65N="D@>PH)"0D)<F5T=7)N('1R=64["@D)"7T*"0D)96P@
M/2!E;"YP87)E;G1.;V1E.PH)"7T*"0ER971U<FX@9F%L<V4["@E].PH)=F%R
M('1A9W,@/2!N97<@07)R87DH(F%P<&QE="(L(")S96QE8W0B*3L*"79A<B!E
M;"`]('1H:7,N96QE;65N=#L*"@EV87(@<"`](%!O<'5P1&EV+F=E=$%B<V]L
M=71E4&]S*&5L*3L*"79A<B!%6#$@/2!P+G@["@EV87(@15@R(#T@96PN;V9F
M<V5T5VED=&@@*R!%6#$["@EV87(@15DQ(#T@<"YY.PH)=F%R($59,B`](&5L
M+F]F9G-E=$AE:6=H="`K($59,3L*"@EI9B`H96PN<W1Y;&4N9&ES<&QA>2`]
M/2`B;F]N92(I('L*"0E%6#$@/2!%6#(@/2!%63$@/2!%63(@/2`P.PH)?0H*
M"69O<B`H=F%R(&L@/2!T86=S+FQE;F=T:#L@:R`^(#`[("D@>PH)"79A<B!A
M<B`]('1H:7,N9&]C+F=E=$5L96UE;G1S0GE486=.86UE*'1A9W-;+2UK72D[
M"@D)=F%R(&-C(#T@;G5L;#L*"@D)9F]R("AV87(@:2`](&%R+FQE;F=T:#L@
M:2`^(#`[*2!["@D)"6-C(#T@87);+2UI73L*"0D):68@*&ES0V]N=&%I;F5D
M*&-C*2D@>PH)"0D)8V,N<W1Y;&4N=FES:6)I;&ET>2`](")V:7-I8FQE(CL*
M"0D)"6-O;G1I;G5E.PH)"0E]"@H)"0EP(#T@4&]P=7!$:78N9V5T06)S;VQU
M=&50;W,H8V,I.PH)"0EV87(@0U@Q(#T@<"YX.PH)"0EV87(@0U@R(#T@8V,N
M;V9F<V5T5VED=&@@*R!#6#$["@D)"79A<B!#63$@/2!P+GD["@D)"79A<B!#
M63(@/2!C8RYO9F9S971(96EG:'0@*R!#63$["@H)"0EI9B`H*$-8,2`^($58
M,BD@?'P@*$-8,B`\($58,2D@?'P@*$-9,2`^($59,BD@?'P@*$-9,B`\($59
M,2DI('L*"0D)"6-C+G-T>6QE+G9I<VEB:6QI='D@/2`B=FES:6)L92(["@D)
M"7T@96QS92!["@D)"0EC8RYS='EL92YV:7-I8FEL:71Y(#T@(FAI9&1E;B([
M"@D)"7T*"0E]"@E]"GT["@I0;W!U<$1I=BYP<F]T;W1Y<&4N7V1R86=3=&%R
M="`](&9U;F-T:6]N("AE=BD@>PH):68@*'1H:7,N9')A9V=I;F<I('L*"0ER
M971U<FX@9F%L<V4["@E]"@ET:&ES+F1R86=G:6YG(#T@=')U93L*"5!O<'5P
M1&EV+F-U<G)E;G10;W!U<"`]('1H:7,["@EV87(@<&]S6"`](&5V+F-L:65N
M=%@["@EV87(@<&]S62`](&5V+F-L:65N=%D["@EI9B`H:7-?:64I('L*"0EP
M;W-9("L]('1H:7,N9&]C+F)O9'DN<V-R;VQL5&]P.PH)"7!O<U@@*ST@=&AI
M<RYD;V,N8F]D>2YS8W)O;&Q,969T.PH)?2!E;'-E('L*"0EP;W-9("L]('=I
M;F1O=RYS8W)O;&Q9.PH)"7!O<U@@*ST@=VEN9&]W+G-C<F]L;%@["@E]"@EV
M87(@<W0@/2!T:&ES+F5L96UE;G0N<W1Y;&4["@ET:&ES+GA/9F9S(#T@<&]S
M6"`M('!A<G-E26YT*'-T+FQE9G0I.PH)=&AI<RYY3V9F<R`]('!O<UD@+2!P
M87)S94EN="AS="YT;W`I.PH)2%1-3$%R96$N7V%D9$5V96YT*'1H:7,N9&]C
M+"`B;6]U<V5M;W9E(BP@4&]P=7!$:78N9')A9TET*3L*"4A434Q!<F5A+E]A
M9&1%=F5N="AT:&ES+F1O8RP@(FUO=7-E;W9E<B(L($A434Q!<F5A+E]S=&]P
M179E;G0I.PH)2%1-3$%R96$N7V%D9$5V96YT*'1H:7,N9&]C+"`B;6]U<V5U
M<"(L(%!O<'5P1&EV+F1R86=%;F0I.PH)2%1-3$%R96$N7W-T;W!%=F5N="AE
M=BD["GT["@I0;W!U<$1I=BYD<F%G270@/2!F=6YC=&EO;B`H978I('L*"79A
M<B!P;W!U<"`](%!O<'5P1&EV+F-U<G)E;G10;W!U<#L*"6EF("@A*'!O<'5P
M("8F('!O<'5P+F1R86=G:6YG*2D@>PH)"7)E='5R;B!F86QS93L*"7T*"6ES
M7VEE("8F("AE=B`]('=I;F1O=RYE=F5N="D["@EV87(@<&]S6"`](&5V+F-L
M:65N=%@["@EV87(@<&]S62`](&5V+F-L:65N=%D["@EI9B`H:7-?:64I('L*
M"0EP;W-9("L]('1H:7,N9&]C+F)O9'DN<V-R;VQL5&]P.PH)"7!O<U@@*ST@
M=&AI<RYD;V,N8F]D>2YS8W)O;&Q,969T.PH)?2!E;'-E('L*"0EP;W-9("L]
M('=I;F1O=RYS8W)O;&Q9.PH)"7!O<U@@*ST@=VEN9&]W+G-C<F]L;%@["@E]
M"@EP;W!U<"YH:61E4VAO=T-O=F5R960H*3L*"79A<B!S="`]('!O<'5P+F5L
M96UE;G0N<W1Y;&4["@ES="YL969T(#T@*'!O<U@@+2!P;W!U<"YX3V9F<RD@
M*R`B<'@B.PH)<W0N=&]P(#T@*'!O<UD@+2!P;W!U<"YY3V9F<RD@*R`B<'@B
M.PH)2%1-3$%R96$N7W-T;W!%=F5N="AE=BD["GT["@I0;W!U<$1I=BYD<F%G
M16YD(#T@9G5N8W1I;VX@*"D@>PH)=F%R('!O<'5P(#T@4&]P=7!$:78N8W5R
M<F5N=%!O<'5P.PH):68@*"%P;W!U<"D@>PH)"7)E='5R;B!F86QS93L*"7T*
M"7!O<'5P+F1R86=G:6YG(#T@9F%L<V4["@E(5$U,07)E82Y?<F5M;W9E179E
M;G0H<&]P=7`N9&]C+"`B;6]U<V5U<"(L(%!O<'5P1&EV+F1R86=%;F0I.PH)
M2%1-3$%R96$N7W)E;6]V945V96YT*'!O<'5P+F1O8RP@(FUO=7-E;W9E<B(L
M($A434Q!<F5A+E]S=&]P179E;G0I.PH)2%1-3$%R96$N7W)E;6]V945V96YT
M*'!O<'5P+F1O8RP@(FUO=7-E;6]V92(L(%!O<'5P1&EV+F1R86=)="D["@EP
M;W!U<"YH:61E4VAO=T-O=F5R960H*3L*?3L*"E!O<'5P1&EV+F-H96-K4&]P
M=7`@/2!F=6YC=&EO;B`H978I('L*"6ES7VEE("8F("AE=B`]('=I;F1O=RYE
M=F5N="D["@EV87(@96P@/2!I<U]I92`_(&5V+G-R8T5L96UE;G0@.B!E=BYT
M87)G970["@EV87(@8W`@/2!0;W!U<$1I=BYC=7)R96YT4&]P=7`["@EF;W(@
M*#L@*&5L("$](&YU;&PI("8F("AE;"`A/2!C<"YE;&5M96YT*3L@96P@/2!E
M;"YP87)E;G1.;V1E*3L*"6EF("AE;"`]/2!N=6QL*2!["@D)8W`N;6]D86P@
M?'P@978N='EP92`]/2`B;6]U<V5O=F5R(B!\?"!C<"YC;&]S92@I.PH)"4A4
M34Q!<F5A+E]S=&]P179E;G0H978I.PH)?0I].PH*4&]P=7!$:78N<')O=&]T
M>7!E+F%D9$)U='1O;G,@/2!F=6YC=&EO;B@I('L*"79A<B!S96QF(#T@=&AI
M<SL*"79A<B!D:78@/2!T:&ES+F1O8RYC<F5A=&5%;&5M96YT*")D:78B*3L*
M"71H:7,N8V]N=&5N="YA<'!E;F1#:&EL9"AD:78I.PH)9&EV+F-L87-S3F%M
M92`](")B=71T;VYS(CL*"69O<B`H=F%R(&D@/2`P.R!I(#P@87)G=6UE;G1S
M+FQE;F=T:#L@*RMI*2!["@D)=F%R(&)T;B`](&%R9W5M96YT<UMI73L*"0EV
M87(@8G5T=&]N(#T@=&AI<RYD;V,N8W)E871E16QE;65N="@B8G5T=&]N(BD[
M"@D)9&EV+F%P<&5N9$-H:6QD*&)U='1O;BD["@D)8G5T=&]N+FEN;F5R2%1-
M3"`]($A434Q!<F5A+DDQ.$XN8G5T=&]N<UMB=&Y=.PH)"7-W:71C:"`H8G1N
M*2!["@D)("`@(&-A<V4@(F]K(CH*"0D)8G5T=&]N+F]N8VQI8VL@/2!F=6YC
M=&EO;B@I('L*"0D)"7-E;&8N8V%L;$AA;F1L97(H*3L*"0D)"7-E;&8N8VQO
M<V4H*3L*"0D)?3L*"0D)8G)E86L["@D)("`@(&-A<V4@(F-A;F-E;"(Z"@D)
M"6)U='1O;BYO;F-L:6-K(#T@9G5N8W1I;VXH*2!["@D)"0ES96QF+F-L;W-E
M*"D["@D)"7T["@D)"6)R96%K.PH)"7T*"7T*?3L*````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O<&]P=7!S+P``````````````````````````````````
M`````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-3$U-#,S-S4V`#`R-#$Q-0`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;W!U<',O86)O=70N:'1M
M;```````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,S`Q,#4`,3`U,34T,S,W-38`,#(V,3$T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#PA+2T*
M"BAC*2!D>6YA<F-H+F-O;2P@,C`P,RTR,#`U"D%U=&AO<CH@36EH86D@0F%Z
M;VXL(&AT='`Z+R]D>6YA<F-H+F-O;2]M:7-H;V\*1&ES=')I8G5T960@87,@
M<&%R="!O9B!(5$U,07)E82`S+C`*"B)9;W4@87)E(&YO="!E>'!E8W1E9"!T
M;R!U;F1E<G-T86YD('1H:7,N+BX@($D@9&]N)W0@;F5I=&AE<BXB"@H@("`@
M("`@("`@("`@("`@("`@("`@*&9R;VT@5&AE($QI;G5X($ME<FYE;"!3;W5R
M8V4@0V]D92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("XO87)C:"]X
M.#9?-C0O:6$S,B]P=')A8V4N8SHY,"D*"CLM*0H*+2T^"@H\:'1M;"!S='EL
M93TB:&5I9VAT.B`Q,#`E(CX*/&AE860^"CQM971A(&AT='`M97%U:78](D-O
M;G1E;G0M5'EP92(@8V]N=&5N=#TB=&5X="]H=&UL.R!C:&%R<V5T/75T9BTX
M(B`O/@H\=&ET;&4^06)O=70@2%1-3$%R96$\+W1I=&QE/@H\<V-R:7!T('1Y
M<&4](G1E>'0O:F%V87-C<FEP="(@<W)C/2)P;W!U<"YJ<R(^/"]S8W)I<'0^
M"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*=VEN9&]W+G)E<VEZ
M951O*#0U,"P@,C4P*3L*=F%R(%1!0E,@/2!;73L*=F%R($-54E)%3E1?5$%"
M(#T@,#L*=F%R($-/3E1%3E1?2$5)1TA47T1)1D8@/2`P.PIV87(@0T].5$5.
M5%]724142%]$249&(#T@,#L*9G5N8W1I;VX@<V5L96-T5&%B*&ED>"D@>PH@
M('9A<B!C="`](%1!0E-;0U524D5.5%]404)=.PH@(&-T+F-L87-S3F%M92`]
M(&-T+F-L87-S3F%M92YR97!L86-E*"]<<RIT86(M8W5R<F5N=%QS*B\L("<@
M)RD["B`@8W0@/2!404)36T-54E)%3E1?5$%"(#T@:61X73L*("!C="YC;&%S
M<TYA;64@*ST@)R!T86(M8W5R<F5N="<["B`@9F]R("AV87(@:2`](%1!0E,N
M;&5N9W1H.R`M+6D@/CT@,#LI('L*("`@('9A<B!A<F5A(#T@9&]C=6UE;G0N
M9V5T16QE;65N=$)Y260H(G1A8BUA<F5A+2(@*R!I*3L*("`@(&EF("A#55)2
M14Y47U1!0B`]/2!I*2!["B`@("`@(&%R96$N<W1Y;&4N9&ES<&QA>2`](")B
M;&]C:R(["B`@("!](&5L<V4@>PH@("`@("!A<F5A+G-T>6QE+F1I<W!L87D@
M/2`B;F]N92(["B`@("!]"B`@?0H@(&1O8W5M96YT+F)O9'DN<W1Y;&4N=FES
M:6)I;&ET>2`](")H:61D96XB.PH@(&1O8W5M96YT+F)O9'DN<W1Y;&4N=FES
M:6)I;&ET>2`](")V:7-I8FQE(CL*("!D;V-U;65N="YC;V]K:64@/2`B2%1-
M3$%214$M04)/550M5$%"/2(@*R!I9'@["GT*=F%R(&5D:71O<B`](&YU;&P[
M"F9U;F-T:6]N(&EN:71$;V-U;65N="@I('L*("!E9&ET;W(@/2!W:6YD;W<N
M9&EA;&]G07)G=6UE;G1S.PH@($A434Q!<F5A(#T@=VEN9&]W+F]P96YE<BY(
M5$U,07)E83L*"B`@=F%R('!L=6=I;G,@/2!D;V-U;65N="YG971%;&5M96YT
M0GE)9"@B<&QU9VEN<R(I.PH@('9A<B!J(#T@,#L*("!V87(@:'1M;"`]("(\
M=&%B;&4@=VED=&@])SDY)2<@8V5L;'!A9&1I;F<])S`G('-T>6QE/2=M87)G
M:6XM=&]P.B`Q96T[(&-O;&QA<'-E+6)O<F1E<G,Z(&-O;&QA<'-E.R!B;W)D
M97(Z(#%P>"!S;VQI9"`C.&(X.R<^(B`K"@D@("(\=&AE860^/'1R/B(@*PH)
M("`B/'1D/DYA;64\+W1D/B(@*PH)("`B/'1D/D1E=F5L;W!E<CPO=&0^(B`K
M"@D@("(\=&0^4W!O;G-O<F5D(&)Y/"]T9#XB("L*"2`@(CQT9#Y,:6-E;G-E
M/'-U<#XJ/"]S=7`^/"]T9#XB("L*"2`@(CPO='(^/"]T:&5A9#X\=&)O9'D^
M(CL*("!F;W(@*'9A<B!I(&EN(&5D:71O<BYP;'5G:6YS*2!["B`@("!V87(@
M:6YF;R`](&5D:71O<BYP;'5G:6YS6VE=.PH@("`@:'1M;"`K/2`B/'1R/CQT
M9#XB("L@:6YF;RYN86UE("L@(B!V(B`K(&EN9F\N=F5R<VEO;B`K("(\+W1D
M/B(@*PH@("`@("`@("`@("`B/'1D/CQA(&AR968])R(@*R!I;F9O+F1E=F5L
M;W!E<E]U<FP@*R`B)R!T87)G970])U]B;&%N:R<@=&ET;&4])U9I<VET(&1E
M=F5L;W!E<B!W96)S:71E)SXB("L*"2`@("!I;F9O+F1E=F5L;W!E<B`K("(\
M+V$^/"]T9#XB("L*"2`@("`B/'1D/CQA(&AR968])R(@*R!I;F9O+G-P;VYS
M;W)?=7)L("L@(B<@=&%R9V5T/2=?8FQA;FLG('1I=&QE/2=6:7-I="!S<&]N
M<V]R('=E8G-I=&4G/B(@*PH)("`@(&EN9F\N<W!O;G-O<B`K("(\+V$^/"]T
M9#XB("L*"2`@("`B/'1D/B(@*R!I;F9O+FQI8V5N<V4@*R`B/"]T9#X\+W1R
M/B(["B`@("`K*VH["B`@?0H*("!I9B`H:BD@>PH@("`@("`@("`@:'1M;"`K
M/2`B/"]T8F]D>3X\+W1A8FQE/B(@*PH)"2`@(CQP/CQS=7`^*CPO<W5P/B!,
M:6-E;G-E(%PB:'1M;$%R96%<(B!M96%N<R!T:&%T('1H92!P;'5G:6X@:7,@
M9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@=&5R;7,@(B`K"@D)("`B87,@
M2%1-3$%R96$@:71S96QF+B`@4W5C:"!P;'5G:6YS(&%R92!L:6ME;'D@=&\@
M8F4@=&AO<V4@:6YC;'5D960@:6X@=&AE(&]F9FEC:6%L("(@*PH)"2`@(DA4
M34Q!<F5A(&1I<W1R:6)U=&EO;CPO<#XB.PH)("!P;'5G:6YS+FEN;F5R2%1-
M3"`]("(\<#Y4:&4@9F]L;&]W:6YG('!L=6=I;G,@:&%V92!B965N(&QO861E
M9"X\+W`^(B`K(&AT;6P["B`@?2!E;'-E('L*"2`@<&QU9VEN<RYI;FYE<DA4
M34P@/2`B/'`^3F\@<&QU9VEN<R!H879E(&)E96X@;&]A9&5D/"]P/B(["B`@
M?0H*("!P;'5G:6YS+FEN;F5R2%1-3"`K/2`B/'`^57-E<B!A9V5N="!R97!O
M<G1S.CQB<B\^(B`K(&YA=FEG871O<BYU<V5R06=E;G0@*R`B/"]P/B(["@H@
M('9A<B!C;VYT96YT(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(F-O;G1E
M;G0B*3L*("!I9B`H=VEN9&]W+FEN;F5R2&5I9VAT*2!["B`@("!#3TY414Y4
M7TA%24=(5%]$249&(#T@=VEN9&]W+FEN;F5R2&5I9VAT("T@,C4P.PH@("`@
M0T].5$5.5%]724142%]$249&(#T@=VEN9&]W+FEN;F5R5VED=&@@+2!C;VYT
M96YT+F]F9G-E=%=I9'1H.PH@('T@96QS92!["B`@("!#3TY414Y47TA%24=(
M5%]$249&(#T@9&]C=6UE;G0N8F]D>2YO9F9S971(96EG:'0@+2`R-3`["B`@
M("!#3TY414Y47U=)1%1(7T1)1D8@/2!D;V-U;65N="YB;V1Y+F]F9G-E=%=I
M9'1H("T@-#`P.PH@('T*("!W:6YD;W<N;VYR97-I>F4H*3L*("!V87(@8F%R
M(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(G1A8F)A<B(I.PH@(&H@/2`P
M.PH@(&9O<B`H=F%R(&D@/2!B87(N9FER<W1#:&EL9#L@:3L@:2`](&DN;F5X
M=%-I8FQI;F<I('L*("`@(%1!0E,N<'5S:"AI*3L*("`@(&DN7U]M<VA?=&%B
M(#T@:CL*("`@(&DN;VYM;W5S961O=VX@/2!F=6YC=&EO;BAE=BD@>R!S96QE
M8W1486(H=&AI<RY?7VUS:%]T86(I.R!(5$U,07)E82Y?<W1O<$5V96YT*&5V
M('Q\('=I;F1O=RYE=F5N="D[('T["B`@("!V87(@87)E82`](&1O8W5M96YT
M+F=E=$5L96UE;G1">4ED*")T86(M87)E82TB("L@:BD["B`@("!I9B`H+W1A
M8BUC=7)R96YT+RYT97-T*&DN8VQA<W-.86UE*2D@>PH@("`@("!#55)214Y4
M7U1!0B`](&H["B`@("`@(&%R96$N<W1Y;&4N9&ES<&QA>2`](")B;&]C:R([
M"B`@("!](&5L<V4@>PH@("`@("!A<F5A+G-T>6QE+F1I<W!L87D@/2`B;F]N
M92(["B`@("!]"B`@("`K*VH["B`@?0H@(&EF("AD;V-U;65N="YC;V]K:64N
M;6%T8V@H+TA434Q!4D5!+4%"3U54+51!0CTH6S`M.5TK*2\I*0H@("`@<V5L
M96-T5&%B*%)E9T5X<"XD,2D["GT*=VEN9&]W+F]N<F5S:7IE(#T@9G5N8W1I
M;VXH*2!["B`@=F%R(&-O;G1E;G0@/2!D;V-U;65N="YG971%;&5M96YT0GE)
M9"@B8V]N=&5N="(I.PH@(&EF("AW:6YD;W<N:6YN97)(96EG:'0I('L*("`@
M(&-O;G1E;G0N<W1Y;&4N:&5I9VAT(#T@*'=I;F1O=RYI;FYE<DAE:6=H="`M
M($-/3E1%3E1?2$5)1TA47T1)1D8I("L@(G!X(CL*("`@(&-O;G1E;G0N<W1Y
M;&4N=VED=&@@/2`H=VEN9&]W+FEN;F5R5VED=&@@+2!#3TY414Y47U=)1%1(
M7T1)1D8I("L@(G!X(CL*("!](&5L<V4@>PH@("`@8V]N=&5N="YS='EL92YH
M96EG:'0@/2`H9&]C=6UE;G0N8F]D>2YO9F9S971(96EG:'0@+2!#3TY414Y4
M7TA%24=(5%]$249&*2`K(")P>"(["B`@("`O+V-O;G1E;G0N<W1Y;&4N=VED
M=&@@/2`H9&]C=6UE;G0N8F]D>2YO9F9S9717:61T:"`M($-/3E1%3E1?5TE$
M5$A?1$E&1BD@*R`B<'@B.PH@('T*?0H\+W-C<FEP=#X*/'-T>6QE/@H@(&AT
M;6PL8F]D>2QT97AT87)E82QT86)L92![(&9O;G0M9F%M:6QY.B!T86AO;6$L
M=F5R9&%N82QA<FEA;#L@9F]N="US:7IE.B`Q,7!X.PIP861D:6YG.B`P<'@[
M(&UA<F=I;CH@,'!X.R!]"B`@='0@>R!F;VYT+7-I>F4Z(#$R,"4[('T*("!B
M;V1Y('L@<&%D9&EN9SH@,'!X.R!B86-K9W)O=6YD.B`C8V5A.R!C;VQO<CH@
M,#`P.R!]"B`@83IL:6YK+"!A.G9I<VET960@>R!C;VQO<CH@(S`P9CL@?0H@
M(&$Z:&]V97(@>R!C;VQO<CH@(V8P,#L@?0H@(&$Z86-T:79E('L@8V]L;W(Z
M("-F.#`[('T*("!B=71T;VX@>R!F;VYT.B`Q,7!X('1A:&]M82QV97)D86YA
M+'-A;G,M<V5R:68[(&)A8VMG<F]U;F0M8V]L;W(Z("-C96$["B`@("`@(&)O
M<F1E<BUW:61T:#H@,7!X.R!]"@H@('`@>R!M87)G:6XZ(#`N-65M(#!P>#L@
M?0H*("!H,2![(&9O;G0Z(&)O;&0@,3,P)2!G96]R9VEA+")T:6UE<R!N97<@
M<F]M86XB+'-E<FEF.R!M87)G:6XZ(#!P>#L@8F]R9&5R+6)O='1O;3H@,7!X
M('-O;&ED(",V838[('T*("!H,B![(&9O;G0Z(&)O;&0@,3$P)2!G96]R9VEA
M+")T:6UE<R!N97<@<F]M86XB+'-E<FEF.R!M87)G:6XZ(#`N-V5M(#!P>#L@
M?0H*("!T:&5A9"!["B`@("!F;VYT+7=E:6=H=#H@8F]L9#L*("`@(&)A8VMG
M<F]U;F0M8V]L;W(Z("-D9F(["B`@?0H*("`N;&]G;RP@+FQO9V\M:&]V97(@
M>PH@("`@=VAI=&4M<W!A8V4Z(&YO=W)A<#L*("`@(&)A8VMG<F]U;F0M8V]L
M;W(Z(",X9C0[(&-O;&]R.B`C,#0P.R!P861D:6YG.B`S<'@[(&)O<F1E<BUB
M;W1T;VTZ(#%P>"!S;VQI9"`C-34U.PH@("`@:&5I9VAT.B`U96T["B`@?0H@
M("YL;V=O("YB<F%N9"P@+FQO9V\M:&]V97(@+F)R86YD('L*("`@(&UA<F=I
M;BUL969T.B`P+C5E;3L@;6%R9VEN+7)I9VAT.B`P+C5E;3L@<&%D9&EN9RUB
M;W1T;VTZ(#`N,65M.PH@("`@9F]N="UF86UI;'DZ(&EM<&%C="PG87)I86P@
M8FQA8VLG+&%R:6%L+'-A;G,M<V5R:68[(&9O;G0M<VEZ93H@,CAP>#L*("`@
M(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C-3DU.R!T97AT+6%L:6=N.B!C
M96YT97(["B`@("!C=7)S;W(Z('!O:6YT97(["B`@?0H@("YL;V=O+6AO=F5R
M('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F9F8["B`@?0H@("YL;V=O+6AO
M=F5R("YB<F%N9"!["B`@("!C;VQO<CH@(S@P,#L*("`@(&)O<F1E<BUC;VQO
M<CH@(S`T9CL*("!]"B`@+FQO9V\@+FQE='1E<BP@+FQO9V\M:&]V97(@+FQE
M='1E<B![('!O<VET:6]N.B!R96QA=&EV93L@9F]N="UF86UI;'DZ(&UO;F]S
M<&%C93L@?0H@("YL;V=O("YL971T97(Q('L@=&]P.B`P+C%E;3L@?0H@("YL
M;V=O("YL971T97(R('L@=&]P.B`P+C`U96T[('T*("`N;&]G;R`N;&5T=&5R
M,R![('1O<#H@+3`N,#5E;3L@?0H@("YL;V=O("YL971T97(T('L@=&]P.B`M
M,"XQ96T[('T*"B`@+FQO9V\M:&]V97(@+FQE='1E<C$@>R!T;W`Z("TP+C%E
M;3L@?0H@("YL;V=O+6AO=F5R("YL971T97(R('L@=&]P.B`M,"XP-65M.R!]
M"B`@+FQO9V\M:&]V97(@+FQE='1E<C,@>R!T;W`Z(#`N,#5E;3L@?0H@("YL
M;V=O+6AO=F5R("YL971T97(T('L@=&]P.B`P+C%E;3L@?0H@("YL;V=O("YV
M97)S:6]N+"`N;&]G;RUH;W9E<B`N=F5R<VEO;B![(&9O;G0M9F%M:6QY.B!G
M96]R9VEA+")T:6UE<R!N97<@<F]M86XB+'-E<FEF.R!]"B`@+FQO9V\@+G)E
M;&5A<V4@>PH@("`@9F]N="US:7IE.B`Y,"4[(&UA<F=I;BUB;W1T;VTZ(#%E
M;3L*("`@('1E>'0M86QI9VXZ(&-E;G1E<CL@8V]L;W(Z(",T.#0["B`@?0H@
M("YL;V=O("YV:7-I="![(&1I<W!L87DZ(&YO;F4[('T*("`N;&]G;RUH;W9E
M<B`N<F5L96%S92![(&1I<W!L87DZ(&YO;F4[('T*("`N;&]G;RUH;W9E<B`N
M=FES:70@>PH@("`@9F]N="US:7IE.B`Y,"4[(&UA<F=I;BUB;W1T;VTZ(#%E
M;3L*("`@('1E>'0M86QI9VXZ(&-E;G1E<CL@8V]L;W(Z(",T-#@["B`@?0H@
M("YB=71T;VYS('L*("`@('1E>'0M86QI9VXZ(')I9VAT.R!P861D:6YG.B`S
M<'@[(&)A8VMG<F]U;F0M8V]L;W(Z(",X9C0["B`@("!B;W)D97(M=&]P.B`Q
M<'@@<V]L:60@(S4U-3L*("!]"B`@(W1A8F)A<B!["B`@("!P;W-I=&EO;CH@
M<F5L871I=F4["B`@("!L969T.B`Q,'!X.PH@('T*("`N=&%B('L*("`@(&-O
M;&]R.B`C-#4T.PH@("`@8W5R<V]R.B!P;VEN=&5R.PH@("`@;6%R9VEN+6QE
M9G0Z("TU<'@["B`@("!F;&]A=#H@;&5F=#L@<&]S:71I;VXZ(')E;&%T:79E
M.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(S4U-3L*("`@('1O<#H@+3-P>#L@
M;&5F=#H@+3)P>#L*("`@('!A9&1I;F<Z(#)P>"`Q,'!X(#-P>"`Q,'!X.PH@
M("`@8F]R9&5R+71O<#H@;F]N93L@8F%C:V=R;W5N9"UC;VQO<CH@(SEB-SL*
M("`@("UM;WHM8F]R9&5R+7)A9&EU<SH@,'!X(#!P>"`T<'@@-'!X.PH@("`@
M>BUI;F1E>#H@,#L*("!]"B`@+G1A8BUC=7)R96YT('L*("`@(&-O;&]R.B`C
M,#`P.PH@("`@=&]P.B`M-'!X.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V-E
M83L*("`@('!A9&1I;F<Z(#-P>"`Q,'!X(#1P>"`Q,'!X.PH@("`@>BUI;F1E
M>#H@,3`["B`@?0H@('1A8FQE+G-P;VYS;W)S('L@8F]R9&5R+71O<#H@,7!X
M('-O;&ED("-A8V$[('T*("!T86)L92YS<&]N<V]R<R!T9"!["B`@("!B;W)D
M97(M8F]T=&]M.B`Q<'@@<V]L:60@(V%C83L@=F5R=&EC86PM86QI9VXZ('1O
M<#L*("!]"B`@=&%B;&4N<W!O;G-O<G,@='(@=&0@>R!P861D:6YG.B`R<'@@
M,'!X.R!]"B`@=&%B;&4N<W!O;G-O<G,@='(@=&0N<W!O;G-O<B![('1E>'0M
M86QI9VXZ(')I9VAT.R!P861D:6YG+7)I9VAT.B`P+C-E;3L@=VAI=&4M<W!A
M8V4Z(&YO=W)A<#L@?0H@(&QI+"!O;"P@=6P@>R!M87)G:6XM=&]P.B`P<'@[
M(&UA<F=I;BUB;W1T;VTZ(#!P>#L@?0H\+W-T>6QE/CPO:&5A9#X*/&)O9'D@
M;VYL;V%D/2)?7V1L9U]I;FET*"D[(&EN:71$;V-U;65N="@I.R(*/CQT86)L
M92!C96QL<W!A8VEN9STB,"(@8V5L;'!A9&1I;F<](C`B('-T>6QE/2)B;W)D
M97(M8V]L;&%P<V4Z(&-O;&QA<'-E.PH@("`@("!W:61T:#H@,3`P)3L@:&5I
M9VAT.B`Q,#`E.R(^"@H\='(@<W1Y;&4](FAE:6=H=#H@,65M(CX\=&0@:60]
M(G1D:&5A9&5R(CX*"CQD:78@8VQA<W,](FQO9V\B/@H\9&EV(&-L87-S/2)B
M<F%N9"(*;VYM;W5S96]V97(](G1H:7,N<&%R96YT3F]D92YC;&%S<TYA;64]
M)VQO9V\M:&]V97(G.R(*;VYM;W5S96]U=#TB=&AI<RYP87)E;G1.;V1E+F-L
M87-S3F%M93TG;&]G;R<[(@IO;F-L:6-K/2)W:6YD;W<N;W!E;B@G:'1T<#HO
M+W=W=RYH=&UL87)E82YC;VTO)RD[(CX*/'-P86X@8VQA<W,](FQE='1E<B!L
M971T97(Q(CXF;'0[2#PO<W!A;CX\<W!A;@IC;&%S<STB;&5T=&5R(&QE='1E
M<C(B/E0\+W-P86X^/'-P86X*8VQA<W,](FQE='1E<B!L971T97(S(CY-/"]S
M<&%N/CQS<&%N"F-L87-S/2)L971T97(@;&5T=&5R-"(^3#PO<W!A;CY!<F5A
M(#QS<&%N(&-L87-S/2)L971T97(B/B\F9W0[/"]S<&%N/@H\<W!A;B!C;&%S
M<STB=F5R<VEO;B(^,RXP(#QS<&%N('-T>6QE/2)P;W-I=&EO;CH@<F5L871I
M=F4[('1O<#H@+3`N-F5M.R!F;VYT+7-I>F4Z(#4P)3L@9F]N="UW96EG:'0Z
M(&YO<FUA;"(^6R!R978N(&)E=&$K(%T\+W-P86X^/"]S<&%N/CPO9&EV/@H\
M9&EV(&-L87-S/2)R96QE87-E(CY#;VUP:6QE9"!O;B!-87D@,3<L(#(P,#4@
M,#$Z,#@@1TU4/"]D:78^"CQD:78@8VQA<W,](G9I<VET(CY';R!T;R!H='1P
M.B\O=W=W+FAT;6QA<F5A+F-O;2\@6VQA=&5S="!M:6QE<W1O;F4@<F5L96%S
M95T\+V1I=CX*/"]D:78^"@H\+W1D/CPO='(^"CQT<CX\=&0@:60](G1D8V]N
M=&5N="(@<W1Y;&4](G!A9&1I;F<Z(#`N-65M.R(^"@H\9&EV('-T>6QE/2)O
M=F5R9FQO=SH@875T;SL@:&5I9VAT.B`R-3!P>#LB(&ED/2)C;VYT96YT(CX*
M/&1I=B!I9#TB=&%B+6%R96%S(CX*"CQD:78@:60](G1A8BUA<F5A+3`B/@H*
M("`\:#$^2%1-3$%R96$\+V@Q/@H*("`\<#Y!(&9R964@5UE325=91R!E9&ET
M;W(@<F5P;&%C96UE;G0@9F]R(#QT=#XF;'0[=&5X=&%R96$F9W0[/"]T=#X@
M9FEE;&1S+CQB<B`O/@H@($9O<B!-;WII;&QA(#$N,RL@*&%N>2!P;&%T9F]R
M;2D@;W(@26YT97)N970@17AP;&]R97(@-2XU*R`H5VEN9&]W<RDN"B`@/"]P
M/@H*("`\<"!S='EL93TB=&5X="UA;&EG;CH@8V5N=&5R(@H@(#["J2`R,#`R
M+3(P,#0@/&$@:')E9CTB:'1T<#HO+VEN=&5R86-T:79E=&]O;',N8V]M(B!T
M87)G970](E]B;&%N:R(^:6YT97)A8W1I=F5T;V]L<RYC;VT\+V$^+"!I;F,N
M/&)R("\^"B`@PJD@,C`P,RTR,#`U(#QA(&AR968](FAT='`Z+R]D>6YA<F-H
M+F-O;2(@=&%R9V5T/2)?8FQA;FLB/F1Y;F%R8V@N8V]M/"]A/B!,3$,N/&)R
M("\^"B`@06QL(%)I9VAT<R!297-E<G9E9"X\+W`^"@H@(#QH,CY0<F]J96-T
M(')E<V]U<F-E<SPO:#(^"@H@(#QU;#X*("`\;&D^/&$@:')E9CTB:'1T<#HO
M+W-O=7)C969O<F=E+FYE="]P<F]J96-T<R]I=&]O;',M:'1M;&%R96$O(B!T
M87)G970](E]B;&%N:R(*("`^4')O:F5C="!P86=E/"]A/B`H0"!S;W5R8V5F
M;W)G92YN970I/"]L:3X*("`\;&D^/&$@:')E9CTB:'1T<#HO+W-O=7)C969O
M<F=E+FYE="]C=G,O/V=R;W5P7VED/38Y-S4P(B!T87)G970](E]B;&%N:R(*
M("`^06YO;GEM;W5S($-64R!A8V-E<W,\+V$^("A`('-O=7)C969O<F=E+FYE
M="D\+VQI/@H@(#QL:3X\82!H<F5F/2)H='1P.B\O<V]U<F-E9F]R9V4N;F5T
M+W1R86-K97(O/V%T:60]-3(U-C4V)F=R;W5P7VED/38Y-S4P)F9U;F,]8G)O
M=W-E(B!T87)G970](E]B;&%N:R(*("`^0G5G('-Y<W1E;3PO83X@*$`@<V]U
M<F-E9F]R9V4N;F5T*3PO;&D^"B`@/&QI/CQA(&AR968](FAT='`Z+R]W=W<N
M:'1M;&%R96$N8V]M+V9O<G5M+R(@=&%R9V5T/2)?8FQA;FLB"B`@/D9O<G5M
M/"]A/B`H0"!I;G1E<F%C=&EV971O;VQS+F-O;2D\+VQI/@H@(#QL:3X\82!H
M<F5F/2)H='1P.B\O=W=W+FAT;6QA<F5A+F-O;2\B('1A<F=E=#TB7V)L86YK
M(@H@(#Y,87-T('!U8FQI8R!R96QE87-E/"]A/CPO;&D^"B`@/"]U;#X*"B`@
M/'`^"B`@1F]R(&1O=VYL;V%D('-E8W1I;VX@<&QE87-E('-E92!T:&4@/&$@
M:')E9CTB:'1T<#HO+W-O=7)C969O<F=E+FYE="]P<F]J96-T<R]I=&]O;',M
M:'1M;&%R96$O(B!T87)G970](E]B;&%N:R(*("`^<')O:F5C="!P86=E($`@
M4V]U<F-E1F]R9V4\+V$^+@H@(#PO<#X*"CPO9&EV/@H*/&1I=B!I9#TB=&%B
M+6%R96$M,2(^"CQH,3Y4:&%N:R!Y;W4\+V@Q/@H*("`\<#X*("`\82!H<F5F
M/2)H='1P.B\O9'EN87)C:"YC;VTB('1A<F=E=#TB7V)L86YK(CYD>6YA<F-H
M+F-O;3PO83X@=V]U;&0@;&EK92!T;R!T:&%N:R!T:&4@9F]L;&]W:6YG"B`@
M8V]M<&%N:65S+W!E<G-O;G,@9F]R('1H96ER(#QE;3YD;VYA=&EO;G,\+V5M
M/B!T;R!S=7!P;W)T(&1E=F5L;W!M96YT(&]F($A434Q!<F5A("AL:7-T960@
M86QP:&%B971I8V%L;'DI.@H@(#PO<#X*"B`@/'5L/@H@("`@/&QI/CQA(&AR
M968](FAT='`Z+R]W=W<N8V]M<'5T97)L;W9E+F-O+G5K(B!T87)G970](E]B
M;&%N:R(^0V]D92!#;VUP=71E<B!,;W9E($QT9"X\+V$^("A52RD\+VQI/@H@
M("`@/&QI/CQA(&AR968](FAT='`Z+R]W=W<N;F5O;65D:6$N<F\B('1A<F=E
M=#TB7V)L86YK(CY.96]M961I83PO83X@*%)O;6%N:6$I/"]L:3X*("`@(#QL
M:3X\82!H<F5F/2)H='1P.B\O=W=W+F]S,RYI="(@=&%R9V5T/2)?8FQA;FLB
M/D]3,SPO83X@*$ET86QY*3PO;&D^"B`@("`\;&D^/&$@:')E9CTB:'1T<#HO
M+W=W=RYS;V9T=V5R:RYN970B('1A<F=E=#TB7V)L86YK(CY3;V9T5V5R:SPO
M83X@*$ET86QY*3PO;&D^"B`@/"]U;#X*"B`@/'`^06QS;R!M86YY('1H86YK
M<R!T;R!A;&P@<&5O<&QE(&%T($EN=&5R86-T:79E5&]O;',N8V]M"B`@/&$@
M:')E9CTB:'1T<#HO+W=W=RYH=&UL87)E82YC;VTO9F]R=6TO(CY(5$U,07)E
M82!F;W)U;7,\+V$^(&9O<@H@(&-O;G1R:6)U=&EN9R!T<F%N<VQA=&EO;G,L
M(&9E961B86-K+"!B=6<@<F5P;W)T<R!A;F0@9FEX97,N/"]P/@H*("`\<#X*
M("!,87-T(&)U="!N;W0@;&5A<W0L('1H:7,@<')O:F5C="!W;W5L9&XG="!H
M879E(&5X:7-T960@=VET:&]U=`H@(#QA(&AR968](FAT='`Z+R]I;G1E<F%C
M=&EV971O;VQS+F-O;2(@=&%R9V5T/2)?8FQA;FLB/DEN=&5R86-T:79E5&]O
M;',N8V]M/"]A/BX*("`\+W`^"@H\+V1I=CX*"CQD:78@:60](G1A8BUA<F5A
M+3(B/@H\:#$^:'1M;$%R96$@3&EC96YS92`H8F%S960@;VX@0E-$(&QI8V5N
M<V4I/"]H,3X*"CQP('-T>6QE/2)T97AT+6%L:6=N.B!C96YT97(B/L*I(#(P
M,#(M,C`P-"P@:6YT97)A8W1I=F5T;V]L<RYC;VTL(&EN8RX\8G(@+SX*("#"
MJ2`R,#`S+3(P,#0@9'EN87)C:"YC;VT@3$Q#/&)R("\^"B`@06QL(')I9VAT
M<R!R97-E<G9E9"X\+W`^"@H\<#X*4F5D:7-T<FEB=71I;VX@86YD('5S92!I
M;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T"FUO
M9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F
M;VQL;W=I;F<@8V]N9&ET:6]N<R!A<F4@;65T.@H\+W`^"@H\;VP^"CQL:3X*
M4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H
M92!A8F]V92!C;W!Y<FEG:'0@;F]T:6-E+`IT:&ES(&QI<W0@;V8@8V]N9&ET
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M86)L93X*"CPO8F]D>3X\+VAT;6P^"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V
M:6-E<R]E9&ET;W(O:'1M;&%R96$O<&]P=7!S+V)L86YK+FAT;6P`````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#$W`#$P-3$U-#,S-S4V`#`R-C`W,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\:'1M;#X-"CPO:'1M
M;#X`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R
M+VAT;6QA<F5A+W!O<'5P<R]F=6QL<V-R965N+FAT;6P`````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q
M,C<V,``Q,#4Q-30S,S<U-@`P,C<Q-3,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/"%$3T-465!%(&AT;6P@4%5"3$E#("(M
M+R]7,T,O+T141"!82%1-3"`Q+C$O+T5.(B`B:'1T<#HO+W=W=RYW,RYO<F<O
M5%(O>&AT;6PQ,2]$5$0O>&AT;6PQ,2YD=&0B/@H\:'1M;#X*("`\:&5A9#X*
M("`@(#QT:71L93Y&=6QL<V-R965N($A434Q!<F5A/"]T:71L93X*("`@(#QS
M8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*("`@("`@7V5D:71O<E]U
M<FP@/2!W:6YD;W<N;W!E;F5R+E]E9&ET;W)?=7)L('Q\("<N+B\G.PH@("`@
M("!?961I=&]R7VQA;F<@/2!W:6YD;W<N;W!E;F5R+E]E9&ET;W)?;&%N9SL*
M("`@("`@7V5D:71O<E]C<W,@/2!W:6YD;W<N;W!E;F5R+E]E9&ET;W)?8W-S
M.PH@("`@("!V87(@0D%312`]('=I;F1O=RYO<&5N97(N9&]C=6UE;G0N8F%S
M955222!\?"!W:6YD;W<N;W!E;F5R+F1O8W5M96YT+E523#L*("`@("`@=F%R
M(&AE860@/2!D;V-U;65N="YG971%;&5M96YT<T)Y5&%G3F%M92@B:&5A9"(I
M6S!=.PH@("`@("!V87(@8F%S92`](&1O8W5M96YT+F-R96%T945L96UE;G0H
M(F)A<V4B*3L*("`@("`@8F%S92YH<F5F(#T@0D%313L*("`@("`@:&5A9"YA
M<'!E;F1#:&EL9"AB87-E*3L*("`@(#PO<V-R:7!T/@H*("`@(#QS8W)I<'0@
M='EP93TB=&5X="]J879A<V-R:7!T(CX*("`@("`@("!D;V-U;65N="YW<FET
M92@G/'-C<B<@*R`G:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(@<W)C/2(G
M("L@7V5D:71O<E]U<FP@*R`G:'1M;&%R96$N:G,B/CPO<V-R)R`K("=I<'0^
M)RD["B`@("`\+W-C<FEP=#X*("`@(#QS8W)I<'0@='EP93TB=&5X="]J879A
M<V-R:7!T(CX*"2\O(&QO860@2%1-3$%R96$@<V-R:7!T<R!T:&%T(&%R92!P
M<F5S96YT(&EN('1H92!O<&5N97(@9G)A;64*"79A<B!S8W)I<'1S(#T@=VEN
M9&]W+F]P96YE<BY(5$U,07)E82Y?<V-R:7!T<SL*"69O<B`H=F%R(&D@/2`S
M.R!I(#P@<V-R:7!T<RYL96YG=&@[("LK:2D@>PH@("`@("`@("`@("\O9&]C
M=6UE;G0N=W)I=&4H(CQS8W(B("L@(FEP="!T>7!E/2=T97AT+VIA=F%S8W)I
M<'0G('-R8STG(B`K('-C<FEP='-;:5T@*R`B)SX\+W-C<B(@*R`B:7!T/B(I
M.PH@("`@("`@("`@($A434Q!<F5A+FQO86138W)I<'0H<V-R:7!T<UMI72D[
M"B`@("`@("`@?0H@("`@/"]S8W)I<'0^"@H@("`@/"$M+2!B<F]W<V5R('1A
M:V5S(&$@8V]F9F5E(&)R96%K(&AE<F4@+2T^"B`@("`\<V-R:7!T('1Y<&4]
M(G1E>'0O:F%V87-C<FEP="(^"G9A<B!P87)E;G1?;V)J96-T("`](&YU;&P[
M"G9A<B!E9&ET;W()("`@/2!N=6QL.PDO+R!T;R!B92!I;FET:6%L:7IE9"!L
M871E<B!;(&9U;F-T:6]N(&EN:70H*2!="@HO*B`M+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM("I<"B`@($9U;F-T:6]N("`@(#H*("`@1&5S8W)I<'1I;VX@
M.@I<*B`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM("HO"@IF=6YC=&EO;B!?
M0VQO<V5/;D5S8RAE=BD@>PH)978@?'P@*&5V(#T@=VEN9&]W+F5V96YT*2!\
M?"`H978@/2!E9&ET;W(N7VEF<F%M92YC;VYT96YT5VEN9&]W+F5V96YT*3L*
M"6EF("AE=BYK97E#;V1E(#T](#(W*2!["@D)+R\@=7!D871E7W!A<F5N="@I
M.PH)"7=I;F1O=RYC;&]S92@I.PH)"7)E='5R;CL*"7T*?0H*+RH@+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2`J7`H@("!&=6YC=&EO;B`@("`Z(')E<VEZ
M95]E9&ET;W(*("`@1&5S8W)I<'1I;VX@.B!R97-I>F4@=&AE(&5D:71O<B!W
M:&5N('1H92!U<V5R(')E<VEZ97,@=&AE('!O<'5P"EPJ("TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2T@*B\*"F9U;F-T:6]N(')E<VEZ95]E9&ET;W(H*2![
M("`O+R!R97-I>F4@961I=&]R('1O(&9I>"!W:6YD;W<*"B`@=F%R(&YE=TAE
M:6=H=#L*("!I9B`H9&]C=6UE;G0N86QL*2![("\O($E%"B`@("!N97=(96EG
M:'0@/2!D;V-U;65N="YB;V1Y+F]F9G-E=$AE:6=H="`M(&5D:71O<BY?=&]O
M;&)A<BYO9F9S971(96EG:'0["B`@("!I9B`H;F5W2&5I9VAT(#P@,"D@>R!N
M97=(96EG:'0@/2`P.R!]"B`@?2!E;'-E('L@+R\@1V5C:V\*("`@(&YE=TAE
M:6=H="`]('=I;F1O=RYI;FYE<DAE:6=H="`M(&5D:71O<BY?=&]O;&)A<BYO
M9F9S971(96EG:'0["B`@?0H@(&EF("AE9&ET;W(N8V]N9FEG+G-T871U<T)A
M<BD@>PH@("`@;F5W2&5I9VAT("T](&5D:71O<BY?<W1A='5S0F%R+F]F9G-E
M=$AE:6=H=#L*("!]"@H@("\O(%1/1$\Z($DG;2!N;W0@<W5R92!E>&%C=&QY
M('=H870@=&AE<V4@87)E(&%D:G5S=&EN9R!F;W(L(&)U="!I9@H@("\O('EO
M=2!D;VXG="!A9&IU<W0@=&AE(&AE:6=H="!F;W(@244@=&AE;B!D;V-U;65N
M="YB;V1Y+F]F9G-E=$AE:6=H=`H@("\O('=I;&P@9V5T(&QA<F=E<B!E=F5R
M>2!T:6UE(&%N9"!T:&4@*'!O<'5P*2!E9&ET;W(@=VEL;"!G970@<W1U8VL*
M("`O+R!I;B!A('1I9VAT(&QO;W`@86YD('1H92!B<F]W<V5R('=O;B=T(&)E
M(')E<W!O;G-I=F4N("!);B!F=71U<F4@=V4G;&P*("`O+R!W86YT('1O(&=E
M="!T:&5S92!M96%S=7)E;65N=',@9'EN86UI8V%L;'D@:6X@8V%S92!E;&5M
M96YT<R!C:&%N9V4@<VEZ90H@("\O(&EN('1H92!F=71U<F4N"@H@(&EF("A(
M5$U,07)E82YI<U]G96-K;RD@>R!N97=(96EG:'0@+3T@.#L@?0H@(&5L<V4@
M("`@("`@("`@("`@("`@("`@>R!N97=(96EG:'0@+3T@,3`[('T*"B`@+R\@
M861J=7-T(&5L96UE;G0@:&5I9VAT"B`@=F%R(&YE=TAE:6=H=%=I=&A0>"`]
M(&YE=TAE:6=H="`K(")P>"(["B`@961I=&]R+E]T97AT07)E82YS='EL92YH
M96EG:'0@/2!N97=(96EG:'17:71H4'@["B`@961I=&]R+E]I9G)A;64N<W1Y
M;&4N:&5I9VAT("`@/2!N97=(96EG:'17:71H4'@["GT*"B\J("TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2T@*EP*("`@1G5N8W1I;VX@("`@.B!I;FET"B`@
M($1E<V-R:7!T:6]N(#H@<G5N('1H:7,@8V]D92!O;B!P86=E(&QO860*7"H@
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2`J+PH*9G5N8W1I;VX@:6YI="@I
M('L*"7!A<F5N=%]O8FIE8W0)("`@/2!O<&5N97(N2%1-3$%R96$N7V]B:F5C
M=#L*"79A<B!C;VYF:6<)("`@/2!(5$U,07)E82YC;&]N94]B:F5C="@@<&%R
M96YT7V]B:F5C="YC;VYF:6<@*3L*"6-O;F9I9RYW:61T:`D@("`]("(Q,#`E
M(CL*"6-O;F9I9RYH96EG:'0)("`@/2`B875T;R(["@H)+R\@8VAA;F=E(&UA
M>&EM:7IE(&)U='1O;B!T;R!M:6YI;6EZ92!B=71T;VX*"6-O;F9I9RYB=&Y,
M:7-T6R)P;W!U<&5D:71O<B)=(#T@6R`G36EN:6UI>F4@161I=&]R)RP@7V5D
M:71O<E]U<FP@*R`G:6UA9V5S+V9U;&QS8W)E96Y?;6EN:6UI>F4N9VEF)RP@
M=')U92P*"0D)"0D@(&9U;F-T:6]N*"D@>R!W:6YD;W<N8VQO<V4H*3L@?2!=
M.PH*"2\O(&=E;F5R871E(&5D:71O<B!A;F0@<F5S:7IE(&ET"@EE9&ET;W(@
M/2!N97<@2%1-3$%R96$H(F5D:71O<B(L(&-O;F9I9RD["@H)+R\@<F5G:7-T
M97(@=&AE('!L=6=I;G,L(&EF(&%N>0H)9F]R("AV87(@:2!I;B!P87)E;G1?
M;V)J96-T+G!L=6=I;G,I('L*"0EV87(@<&QU9VEN(#T@<&%R96YT7V]B:F5C
M="YP;'5G:6YS6VE=.PH)"71R>2!["@D)"65V86PH<&QU9VEN+FYA;64I.PH)
M"0EE9&ET;W(N<F5G:7-T97)0;'5G:6XR*'!L=6=I;BYN86UE+"!P;'5G:6XN
M87)G<RD["@D)?2!C871C:"AE*2![?3L*"7T*"2\O(&%N9"!R97-T;W)E('1H
M92!O<FEG:6YA;"!T;V]L8F%R"B`@("`@("`@8V]N9FEG+G1O;VQB87(@/2!P
M87)E;G1?;V)J96-T+F-O;F9I9RYT;V]L8F%R.PH)961I=&]R+F=E;F5R871E
M*"D["@EE9&ET;W(N7VEF<F%M92YS='EL92YW:61T:"`]("(Q,#`E(CL*"65D
M:71O<BY?=&5X=$%R96$N<W1Y;&4N=VED=&@@/2`B,3`P)2(["@ER97-I>F5?
M961I=&]R*"D["@H)961I=&]R+F1O8W1Y<&4@/2!P87)E;G1?;V)J96-T+F1O
M8W1Y<&4["@H)+R\@<V5T(&-H:6QD('=I;F1O=R!C;VYT96YT<R!A;F0@979E
M;G0@:&%N9&QE<G,L(&%F=&5R(&$@<VUA;&P@9&5L87D*"7-E=%1I;65O=70H
M9G5N8W1I;VXH*2!["@D)"2`@(&5D:71O<BYS971(5$U,*'!A<F5N=%]O8FIE
M8W0N9V5T26YN97)(5$U,*"DI.PH*"0D)("`@+R\@<W=I=&-H(&UO9&4@:68@
M;F5E9&5D"@D)"2`@(&EF("AP87)E;G1?;V)J96-T+E]M;V1E(#T](")T97AT
M;6]D92(I('L@961I=&]R+G-E=$UO9&4H(G1E>'1M;V1E(BD[('T*"@D)"2`@
M("\O(&-O;G1I;G5O=7-L>2!U<&1A=&4@<&%R96YT(&5D:71O<B!W:6YD;W<*
M"0D)("`@<V5T26YT97)V86PH=7!D871E7W!A<F5N="P@-3`P*3L*"@D)"2`@
M("\O('-E='5P(&5V96YT(&AA;F1L97)S"@D)"2`@(&1O8W5M96YT+F)O9'DN
M;VYK97EP<F5S<R`](%]#;&]S94]N17-C.PH)"0D@("!E9&ET;W(N7V1O8RYB
M;V1Y+F]N:V5Y<')E<W,@/2!?0VQO<V5/;D5S8SL*"0D)("`@961I=&]R+E]T
M97AT07)E82YO;FME>7!R97-S(#T@7T-L;W-E3VY%<V,["@D)"2`@('=I;F1O
M=RYO;G)E<VEZ92`](')E<VEZ95]E9&ET;W(["@D)("`@?2P@,S,S*3L)"0D@
M+R\@9VEV92!I="!S;VUE('1I;64@=&\@;65E="!T:&4@;F5W(&9R86UE"GT*
M"B\J("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T@*EP*("`@1G5N8W1I;VX@
M("`@.B!U<&1A=&5?<&%R96YT"B`@($1E<V-R:7!T:6]N(#H@=7!D871E('!A
M<F5N="!W:6YD;W<@961I=&]R(&9I96QD('=I=&@@8V]N=&5N=',@9G)O;2!C
M:&EL9"!W:6YD;W<*("`@7"H@+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2`J
M+PH*9G5N8W1I;VX@=7!D871E7W!A<F5N="@I('L*"@DO+R!U<V4@=&AE(&9A
M<W0@=F5R<VEO;@H)<&%R96YT7V]B:F5C="YS971(5$U,*&5D:71O<BYG971)
M;FYE<DA434PH*2D["GT*"B`@("`\+W-C<FEP=#X*("`@(#QS='EL92!T>7!E
M/2)T97AT+V-S<R(^(&AT;6PL(&)O9'D@>R!H96EG:'0Z(#$P,"4[(&UA<F=I
M;CH@,'!X.R!B;W)D97(Z(#!P>#L@8F%C:V=R;W5N9"UC;VQO<CH@8G5T=&]N
M9F%C93L@?2`\+W-T>6QE/@H@(#PO:&5A9#X*("`\8F]D>2!S8W)O;&P](FYO
M(B!O;FQO860](DA434Q!<F5A+F]N;&]A9"`](&EN:70[($A434Q!<F5A+FEN
M:70H*3LB(&]N=6YL;V%D/2)U<&1A=&5?<&%R96YT*"DB/@H@("`@/&9O<FT@
M<W1Y;&4](FUA<F=I;CH@,'!X.R!B;W)D97(Z(#%P>"!S;VQI9#L@8F]R9&5R
M+6-O;&]R.B!T:')E961S:&%D;W<@=&AR965D:&EG:&QI9VAT('1H<F5E9&AI
M9VAL:6=H="!T:')E961S:&%D;W<[(CX*("`@("`@/'1E>'1A<F5A(&YA;64]
M(F5D:71O<B(@:60](F5D:71O<B(@<W1Y;&4](G=I9'1H.C$P,"4[(&AE:6=H
M=#HS,#!P>"(^)FYB<W`[/"]T97AT87)E83X*("`@(#PO9F]R;3X*("`\+V)O
M9'D^"CPO:'1M;#X*`````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!O<'5P<R]I;G-E
M<G1?:6UA9V4N:'1M;``````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,C,U,``Q,#4Q-30S,S<U-@`P,C<T
M-3(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/&AT;6P^#0H-"CQH96%D/@T*("`\=&ET;&4^26YS97)T($EM86=E/"]T:71L
M93X-"@T*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B('-R8STB<&]P
M=7`N:G,B/CPO<V-R:7!T/@T*#0H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C
M<FEP="(^#0H-"G=I;F1O=RYR97-I>F54;R@T,#`L(#$P,"D[#0H-"F9U;F-T
M:6]N($EN:70H*2![#0H@(%]?9&QG7VEN:70H*3L-"B`@=F%R('!A<F%M(#T@
M=VEN9&]W+F1I86QO9T%R9W5M96YT<SL-"B`@:68@*'!A<F%M*2![#0H@("`@
M("!D;V-U;65N="YG971%;&5M96YT0GE)9"@B9E]U<FPB*2YV86QU92`]('!A
M<F%M6R)F7W5R;")=.PT*("`@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H
M(F9?86QT(BDN=F%L=64@/2!P87)A;5LB9E]A;'0B73L-"B`@("`@(&1O8W5M
M96YT+F=E=$5L96UE;G1">4ED*")F7V)O<F1E<B(I+G9A;'5E(#T@<&%R86U;
M(F9?8F]R9&5R(ET[#0H@("`@("!D;V-U;65N="YG971%;&5M96YT0GE)9"@B
M9E]A;&EG;B(I+G9A;'5E(#T@<&%R86U;(F9?86QI9VXB73L-"B`@("`@(&1O
M8W5M96YT+F=E=$5L96UE;G1">4ED*")F7W9E<G0B*2YV86QU92`]('!A<F%M
M6R)F7W9E<G0B73L-"B`@("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")F
M7VAO<FEZ(BDN=F%L=64@/2!P87)A;5LB9E]H;W)I>B)=.PT*("`@("`@=VEN
M9&]W+FEP<F5V:65W+FQO8V%T:6]N+G)E<&QA8V4H<&%R86TN9E]U<FPI.PT*
M("!]#0H@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")F7W5R;"(I+F9O8W5S
M*"D[#0I].PT*#0IF=6YC=&EO;B!O;D]+*"D@>PT*("!V87(@<F5Q=6ER960@
M/2![#0H@("`@(F9?=7)L(CH@(EEO=2!M=7-T(&5N=&5R('1H92!54DPB#0H@
M('T[#0H@(&9O<B`H=F%R(&D@:6X@<F5Q=6ER960I('L-"B`@("!V87(@96P@
M/2!D;V-U;65N="YG971%;&5M96YT0GE)9"AI*3L-"B`@("!I9B`H(65L+G9A
M;'5E*2![#0H@("`@("!A;&5R="AR97%U:7)E9%MI72D[#0H@("`@("!E;"YF
M;V-U<R@I.PT*("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"B`@?0T*("`O
M+R!P87-S(&1A=&$@8F%C:R!T;R!T:&4@8V%L;&EN9R!W:6YD;W<-"B`@=F%R
M(&9I96QD<R`](%LB9E]U<FPB+"`B9E]A;'0B+"`B9E]A;&EG;B(L(")F7V)O
M<F1E<B(L#0H@("`@("`@("`@("`@("`@(F9?:&]R:7HB+"`B9E]V97)T(ET[
M#0H@('9A<B!P87)A;2`](&YE=R!/8FIE8W0H*3L-"B`@9F]R("AV87(@:2!I
M;B!F:65L9',I('L-"B`@("!V87(@:60@/2!F:65L9'-;:5T[#0H@("`@=F%R
M(&5L(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H:60I.PT*("`@('!A<F%M
M6VED72`](&5L+G9A;'5E.PT*("!]#0H@(%]?9&QG7V-L;W-E*'!A<F%M*3L-
M"B`@<F5T=7)N(&9A;'-E.PT*?3L-"@T*9G5N8W1I;VX@;VY#86YC96PH*2![
M#0H@(%]?9&QG7V-L;W-E*&YU;&PI.PT*("!R971U<FX@9F%L<V4[#0I].PT*
M#0IF=6YC=&EO;B!O;E!R979I97<H*2![#0H@('9A<B!F7W5R;"`](&1O8W5M
M96YT+F=E=$5L96UE;G1">4ED*")F7W5R;"(I.PT*("!V87(@=7)L(#T@9E]U
M<FPN=F%L=64[#0H@(&EF("@A=7)L*2![#0H@("`@86QE<G0H(EEO=2!H879E
M('1O(&5N=&5R(&%N(%523"!F:7)S="(I.PT*("`@(&9?=7)L+F9O8W5S*"D[
M#0H@("`@<F5T=7)N(&9A;'-E.PT*("!]#0H@('=I;F1O=RYI<')E=FEE=RYL
M;V-A=&EO;BYR97!L86-E*'5R;"D[#0H@(')E='5R;B!F86QS93L-"GT[#0H\
M+W-C<FEP=#X-"@T*/'-T>6QE('1Y<&4](G1E>'0O8W-S(CX-"FAT;6PL(&)O
M9'D@>PT*("!B86-K9W)O=6YD.B!"=71T;VY&86-E.PT*("!C;VQO<CH@0G5T
M=&]N5&5X=#L-"B`@9F]N=#H@,3%P>"!486AO;6$L5F5R9&%N82QS86YS+7-E
M<FEF.PT*("!M87)G:6XZ(#!P>#L-"B`@<&%D9&EN9SH@,'!X.PT*?0T*8F]D
M>2![('!A9&1I;F<Z(#5P>#L@?0T*=&%B;&4@>PT*("!F;VYT.B`Q,7!X(%1A
M:&]M82Q697)D86YA+'-A;G,M<V5R:68[#0I]#0IF;W)M('`@>PT*("!M87)G
M:6XM=&]P.B`U<'@[#0H@(&UA<F=I;BUB;W1T;VTZ(#5P>#L-"GT-"BYF;"![
M('=I9'1H.B`Y96T[(&9L;V%T.B!L969T.R!P861D:6YG.B`R<'@@-7!X.R!T
M97AT+6%L:6=N.B!R:6=H=#L@?0T*+F9R('L@=VED=&@Z(#9E;3L@9FQO870Z
M(&QE9G0[('!A9&1I;F<Z(#)P>"`U<'@[('1E>'0M86QI9VXZ(')I9VAT.R!]
M#0IF:65L9'-E="![('!A9&1I;F<Z(#!P>"`Q,'!X(#5P>"`U<'@[('T-"G-E
M;&5C="P@:6YP=70L(&)U='1O;B![(&9O;G0Z(#$Q<'@@5&%H;VUA+%9E<F1A
M;F$L<V%N<RUS97)I9CL@?0T*8G5T=&]N('L@=VED=&@Z(#<P<'@[('T-"BYS
M<&%C92![('!A9&1I;F<Z(#)P>#L@?0T*#0HN=&ET;&4@>R!B86-K9W)O=6YD
M.B`C9&1F.R!C;VQO<CH@(S`P,#L@9F]N="UW96EG:'0Z(&)O;&0[(&9O;G0M
M<VEZ93H@,3(P)3L@<&%D9&EN9SH@,W!X(#$P<'@[(&UA<F=I;BUB;W1T;VTZ
M(#$P<'@[#0IB;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@8FQA8VL[(&QE='1E
M<BUS<&%C:6YG.B`R<'@[#0I]#0IF;W)M('L@<&%D9&EN9SH@,'!X.R!M87)G
M:6XZ(#!P>#L@?0T*/"]S='EL93X-"@T*/"]H96%D/@T*#0H\8F]D>2!O;FQO
M860](DEN:70H*2(^#0H-"CQD:78@8VQA<W,](G1I=&QE(CY);G-E<G0@26UA
M9V4\+V1I=CX-"CPA+2TM(&YE=R!S='5F9B`M+2T^#0H\9F]R;2!A8W1I;VX]
M(B(@;65T:&]D/2)G970B/@T*/'1A8FQE(&)O<F1E<CTB,"(@=VED=&@](C$P
M,"4B('-T>6QE/2)P861D:6YG.B`P<'@[(&UA<F=I;CH@,'!X(CX-"B`@/'1B
M;V1Y/@T*#0H@(#QT<CX-"B`@("`\=&0@<W1Y;&4](G=I9'1H.B`W96T[('1E
M>'0M86QI9VXZ(')I9VAT(CY);6%G92!54DPZ/"]T9#X-"B`@("`\=&0^/&EN
M<'5T('1Y<&4](G1E>'0B(&YA;64](G5R;"(@:60](F9?=7)L(B!S='EL93TB
M=VED=&@Z-S4E(@T*("`@("`@=&ET;&4](D5N=&5R('1H92!I;6%G92!54DP@
M:&5R92(@+SX-"B`@("`@(#QB=71T;VX@;F%M93TB<')E=FEE=R(@;VYC;&EC
M:STB<F5T=7)N(&]N4')E=FEE=R@I.R(-"B`@("`@('1I=&QE/2)0<F5V:65W
M('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B/E!R979I97<\+V)U='1O;CX-
M"B`@("`\+W1D/@T*("`\+W1R/@T*("`\='(^#0H@("`@/'1D('-T>6QE/2)W
M:61T:#H@-V5M.R!T97AT+6%L:6=N.B!R:6=H="(^06QT97)N871E('1E>'0Z
M/"]T9#X-"B`@("`\=&0^/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](F%L="(@
M:60](F9?86QT(B!S='EL93TB=VED=&@Z,3`P)2(-"B`@("`@('1I=&QE/2)&
M;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(@+SX\+W1D
M/@T*("`\+W1R/@T*#0H@(#PO=&)O9'D^#0H\+W1A8FQE/@T*#0H\<"`O/@T*
M#0H\9FEE;&1S970@<W1Y;&4](F9L;V%T.B!L969T.R!M87)G:6XM;&5F=#H@
M-7!X.R(^#0H\;&5G96YD/DQA>6]U=#PO;&5G96YD/@T*#0H\9&EV(&-L87-S
M/2)S<&%C92(^/"]D:78^#0H-"CQD:78@8VQA<W,](F9L(CY!;&EG;FUE;G0Z
M/"]D:78^#0H\<V5L96-T('-I>F4](C$B(&YA;64](F%L:6=N(B!I9#TB9E]A
M;&EG;B(-"B`@=&ET;&4](E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B/@T*
M("`\;W!T:6]N('9A;'5E/2(B("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`^3F]T('-E=#PO;W!T:6]N/@T*("`\;W!T:6]N('9A;'5E/2)L969T(B`@
M("`@("`@("`@("`@("`@("`@("`@("`^3&5F=#PO;W!T:6]N/@T*("`\;W!T
M:6]N('9A;'5E/2)R:6=H="(@("`@("`@("`@("`@("`@("`@("`@("`^4FEG
M:'0\+V]P=&EO;CX-"B`@/&]P=&EO;B!V86QU93TB=&5X='1O<"(@("`@("`@
M("`@("`@("`@("`@("`@/E1E>'1T;W`\+V]P=&EO;CX-"B`@/&]P=&EO;B!V
M86QU93TB86)S;6ED9&QE(B`@("`@("`@("`@("`@("`@("`@/D%B<VUI9&1L
M93PO;W!T:6]N/@T*("`\;W!T:6]N('9A;'5E/2)B87-E;&EN92(@<V5L96-T
M960](C$B("`@("`@("`^0F%S96QI;F4\+V]P=&EO;CX-"B`@/&]P=&EO;B!V
M86QU93TB86)S8F]T=&]M(B`@("`@("`@("`@("`@("`@("`@/D%B<V)O='1O
M;3PO;W!T:6]N/@T*("`\;W!T:6]N('9A;'5E/2)B;W1T;VTB("`@("`@("`@
M("`@("`@("`@("`@("`^0F]T=&]M/"]O<'1I;VX^#0H@(#QO<'1I;VX@=F%L
M=64](FUI9&1L92(@("`@("`@("`@("`@("`@("`@("`@(#Y-:61D;&4\+V]P
M=&EO;CX-"B`@/&]P=&EO;B!V86QU93TB=&]P(B`@("`@("`@("`@("`@("`@
M("`@("`@("`@/E1O<#PO;W!T:6]N/@T*/"]S96QE8W0^#0H-"CQP("\^#0H-
M"CQD:78@8VQA<W,](F9L(CY";W)D97(@=&AI8VMN97-S.CPO9&EV/@T*/&EN
M<'5T('1Y<&4](G1E>'0B(&YA;64](F)O<F1E<B(@:60](F9?8F]R9&5R(B!S
M:7IE/2(U(@T*=&ET;&4](DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B("\^
M#0H-"CQD:78@8VQA<W,](G-P86-E(CX\+V1I=CX-"@T*/"]F:65L9'-E=#X-
M"@T*/&9I96QD<V5T('-T>6QE/2)F;&]A=#IR:6=H=#L@;6%R9VEN+7)I9VAT
M.B`U<'@[(CX-"CQL96=E;F0^4W!A8VEN9SPO;&5G96YD/@T*#0H\9&EV(&-L
M87-S/2)S<&%C92(^/"]D:78^#0H-"CQD:78@8VQA<W,](F9R(CY(;W)I>F]N
M=&%L.CPO9&EV/@T*/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](FAO<FEZ(B!I
M9#TB9E]H;W)I>B(@<VEZ93TB-2(-"G1I=&QE/2)(;W)I>F]N=&%L('!A9&1I
M;F<B("\^#0H-"CQP("\^#0H-"CQD:78@8VQA<W,](F9R(CY697)T:6-A;#H\
M+V1I=CX-"CQI;G!U="!T>7!E/2)T97AT(B!N86UE/2)V97)T(B!I9#TB9E]V
M97)T(B!S:7IE/2(U(@T*=&ET;&4](E9E<G1I8V%L('!A9&1I;F<B("\^#0H-
M"CQD:78@8VQA<W,](G-P86-E(CX\+V1I=CX-"@T*/"]F:65L9'-E=#X-"CQB
M<B!C;&5A<CTB86QL(B`O/@T*/'1A8FQE('=I9'1H/2(Q,#`E(B!S='EL93TB
M;6%R9VEN+6)O='1O;3H@,"XR96TB/@T*(#QT<CX-"B`@/'1D('9A;&EG;CTB
M8F]T=&]M(CX-"B`@("!);6%G92!0<F5V:65W.CQB<B`O/@T*("`@(#QI9G)A
M;64@;F%M93TB:7!R979I97<B(&ED/2)I<')E=FEE=R(@9G)A;65B;W)D97(]
M(C`B('-T>6QE/2)B;W)D97(@.B`Q<'@@<V]L:60@9W)A>3LB(&AE:6=H=#TB
M,C`P(B!W:61T:#TB,S`P(B!S<F,](B(^/"]I9G)A;64^#0H@(#PO=&0^#0H@
M(#QT9"!V86QI9VX](F)O='1O;2(@<W1Y;&4](G1E>'0M86QI9VXZ(')I9VAT
M(CX-"B`@("`\8G5T=&]N('1Y<&4](F)U='1O;B(@;F%M93TB;VLB(&]N8VQI
M8VL](G)E='5R;B!O;D]+*"D[(CY/2SPO8G5T=&]N/CQB<CX-"B`@("`\8G5T
M=&]N('1Y<&4](F)U='1O;B(@;F%M93TB8V%N8V5L(B!O;F-L:6-K/2)R971U
M<FX@;VY#86YC96PH*3LB/D-A;F-E;#PO8G5T=&]N/@T*("`\+W1D/@T*(#PO
M='(^#0H\+W1A8FQE/@T*/"]F;W)M/@T*/"]B;V1Y/@T*/"]H=&UL/@T*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I
M=&]R+VAT;6QA<F5A+W!O<'5P<R]I;G-E<G1?=&%B;&4N:'1M;```````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`Q,34R-0`Q,#4Q-30S,S<U-@`P,C<T-C(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/&AT;6P^"@H\:&5A9#X*("`\=&ET
M;&4^26YS97)T(%1A8FQE/"]T:71L93X*"CQS8W)I<'0@='EP93TB=&5X="]J
M879A<V-R:7!T(B!S<F,](G!O<'5P+FIS(CX\+W-C<FEP=#X*"CQS8W)I<'0@
M='EP93TB=&5X="]J879A<V-R:7!T(CX*"G=I;F1O=RYR97-I>F54;R@T,#`L
M(#$P,"D["@IF=6YC=&EO;B!);FET*"D@>PH@(&DQ.&X@/2!W:6YD;W<N;W!E
M;F5R+DA434Q!<F5A+DDQ.$XN9&EA;&]G<SL@+R\@;&]A9"!T:&4@2%1-3$%R
M96$@<&QU9VEN(&%N9"!L86YG(&9I;&4*("!?7V1L9U]T<F%N<VQA=&4H:3$X
M;BD["B`@7U]D;&=?:6YI="@I.PH@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED
M*")F7W)O=W,B*2YF;V-U<R@I.PI].PH*9G5N8W1I;VX@;VY/2R@I('L*("!V
M87(@<F5Q=6ER960@/2!["B`@("`B9E]R;W=S(CH@(EEO=2!M=7-T(&5N=&5R
M(&$@;G5M8F5R(&]F(')O=W,B+`H@("`@(F9?8V]L<R(Z(")9;W4@;75S="!E
M;G1E<B!A(&YU;6)E<B!O9B!C;VQU;6YS(@H@('T["B`@9F]R("AV87(@:2!I
M;B!R97%U:7)E9"D@>PH@("`@=F%R(&5L(#T@9&]C=6UE;G0N9V5T16QE;65N
M=$)Y260H:2D["B`@("!I9B`H(65L+G9A;'5E*2!["B`@("`@(&%L97)T*')E
M<75I<F5D6VE=*3L*("`@("`@96PN9F]C=7,H*3L*("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@?0H@('T*("!V87(@9FEE;&1S(#T@6R)F7W)O=W,B+"`B9E]C
M;VQS(BP@(F9?=VED=&@B+"`B9E]U;FET(BP@(F9?9FEX960B+`H@("`@("`@
M("`@("`@("`@(F9?86QI9VXB+"`B9E]B;W)D97(B+"`B9E]S<&%C:6YG(BP@
M(F9?<&%D9&EN9R)=.PH@('9A<B!P87)A;2`](&YE=R!/8FIE8W0H*3L*("!F
M;W(@*'9A<B!I(&EN(&9I96QD<RD@>PH@("`@=F%R(&ED(#T@9FEE;&1S6VE=
M.PH@("`@=F%R(&5L(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H:60I.PH@
M("`@<&%R86U;:61=(#T@*&5L+G1Y<&4@/3T@(F-H96-K8F]X(BD@/R!E;"YC
M:&5C:V5D(#H@96PN=F%L=64["B`@?0H@(%]?9&QG7V-L;W-E*'!A<F%M*3L*
M("!R971U<FX@9F%L<V4["GT["@IF=6YC=&EO;B!O;D-A;F-E;"@I('L*("!?
M7V1L9U]C;&]S92AN=6QL*3L*("!R971U<FX@9F%L<V4["GT["@H\+W-C<FEP
M=#X*"CQS='EL92!T>7!E/2)T97AT+V-S<R(^"FAT;6PL(&)O9'D@>PH@(&)A
M8VMG<F]U;F0Z($)U='1O;D9A8V4["B`@8V]L;W(Z($)U='1O;E1E>'0["B`@
M9F]N=#H@,3%P>"!486AO;6$L5F5R9&%N82QS86YS+7-E<FEF.PH@(&UA<F=I
M;CH@,'!X.PH@('!A9&1I;F<Z(#!P>#L*?0IB;V1Y('L@<&%D9&EN9SH@-7!X
M.R!]"G1A8FQE('L*("!F;VYT.B`Q,7!X(%1A:&]M82Q697)D86YA+'-A;G,M
M<V5R:68["GT*9F]R;2!P('L*("!M87)G:6XM=&]P.B`U<'@["B`@;6%R9VEN
M+6)O='1O;3H@-7!X.PI]"BYF;"![('=I9'1H.B`Y96T[(&9L;V%T.B!L969T
M.R!P861D:6YG.B`R<'@@-7!X.R!T97AT+6%L:6=N.B!R:6=H=#L@?0HN9G(@
M>R!W:61T:#H@-V5M.R!F;&]A=#H@;&5F=#L@<&%D9&EN9SH@,G!X(#5P>#L@
M=&5X="UA;&EG;CH@<FEG:'0[('T*9FEE;&1S970@>R!P861D:6YG.B`P<'@@
M,3!P>"`U<'@@-7!X.R!]"G-E;&5C="P@:6YP=70L(&)U='1O;B![(&9O;G0Z
M(#$Q<'@@5&%H;VUA+%9E<F1A;F$L<V%N<RUS97)I9CL@?0IB=71T;VX@>R!W
M:61T:#H@-S!P>#L@?0HN<W!A8V4@>R!P861D:6YG.B`R<'@[('T*"BYT:71L
M92![(&)A8VMG<F]U;F0Z("-D9&8[(&-O;&]R.B`C,#`P.R!F;VYT+7=E:6=H
M=#H@8F]L9#L@9F]N="US:7IE.B`Q,C`E.R!P861D:6YG.B`S<'@@,3!P>#L@
M;6%R9VEN+6)O='1O;3H@,3!P>#L*8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED
M(&)L86-K.R!L971T97(M<W!A8VEN9SH@,G!X.PI]"F9O<FT@>R!P861D:6YG
M.B`P<'@[(&UA<F=I;CH@,'!X.R!]"CPO<W1Y;&4^"@H\+VAE860^"@H\8F]D
M>2!O;FQO860](DEN:70H*2(^"@H\9&EV(&-L87-S/2)T:71L92(^26YS97)T
M(%1A8FQE/"]D:78^"@H\9F]R;2!A8W1I;VX](B(@;65T:&]D/2)G970B/@H\
M=&%B;&4@8F]R9&5R/2(P(B!S='EL93TB<&%D9&EN9SH@,'!X.R!M87)G:6XZ
M(#!P>"(^"B`@/'1B;V1Y/@H*("`\='(^"B`@("`\=&0@<W1Y;&4](G=I9'1H
M.B`T96T[('1E>'0M86QI9VXZ(')I9VAT(CY2;W=S.CPO=&0^"B`@("`\=&0^
M/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](G)O=W,B(&ED/2)F7W)O=W,B('-I
M>F4](C4B('1I=&QE/2).=6UB97(@;V8@<F]W<R(@=F%L=64](C(B("\^/"]T
M9#X*("`@(#QT9"!S='EL93TB=VED=&@Z(#1E;3L@=&5X="UA;&EG;CH@<FEG
M:'0B/E=I9'1H.CPO=&0^"B`@("`\=&0^/&EN<'5T('1Y<&4](G1E>'0B(&YA
M;64](G=I9'1H(B!I9#TB9E]W:61T:"(@<VEZ93TB-2(@=&ET;&4](E=I9'1H
M(&]F('1H92!T86)L92(@=F%L=64](C$P,"(@+SX\+W1D/@H@("`@/'1D/CQS
M96QE8W0@<VEZ93TB,2(@;F%M93TB=6YI="(@:60](F9?=6YI="(@=&ET;&4]
M(E=I9'1H('5N:70B/@H@("`@("`\;W!T:6]N('9A;'5E/2(E(B!S96QE8W1E
M9#TB,2(@(#Y097)C96YT/"]O<'1I;VX^"B`@("`@(#QO<'1I;VX@=F%L=64]
M(G!X(B`@("`@("`@("`@("`@/E!I>&5L<SPO;W!T:6]N/@H@("`@("`\;W!T
M:6]N('9A;'5E/2)E;2(@("`@("`@("`@("`@(#Y%;3PO;W!T:6]N/@H@("`@
M/"]S96QE8W0^/"]T9#X*("`\+W1R/@H@(#QT<CX*("`@(#QT9"!S='EL93TB
M=VED=&@Z(#1E;3L@=&5X="UA;&EG;CH@<FEG:'0B/D-O;',Z/"]T9#X*("`@
M(#QT9#X\:6YP=70@='EP93TB=&5X="(@;F%M93TB8V]L<R(@:60](F9?8V]L
M<R(@<VEZ93TB-2(@=&ET;&4](DYU;6)E<B!O9B!C;VQU;6YS(B!V86QU93TB
M-"(@+SX\+W1D/@H@("`@/'1D('-T>6QE/2)T97AT+6%L:6=N.B!R:6=H="(^
M/&EN<'5T('1Y<&4](F-H96-K8F]X(B!C:&5C:V5D/2)C:&5C:V5D(B!N86UE
M/2)F:7AE9"(@:60](F9?9FEX960B("\^/"]T9#X*("`@(#QT9"!C;VQS<&%N
M/2(R(CX\;&%B96P@9F]R/2)F7V9I>&5D(@H@("`@/D9I>&5D('=I9'1H(&-O
M;'5M;G,\+VQA8F5L/CPO=&0^"B`@/"]T<CX*("`\+W1B;V1Y/@H\+W1A8FQE
M/@H*/'`@+SX*"CQF:65L9'-E="!S='EL93TB9FQO870Z(&QE9G0[(&UA<F=I
M;BUL969T.B`U<'@[(CX*/&QE9V5N9#Y,87EO=70\+VQE9V5N9#X*"CQD:78@
M8VQA<W,](G-P86-E(CX\+V1I=CX*"CQD:78@8VQA<W,](F9L(CY!;&EG;FUE
M;G0Z/"]D:78^"CQS96QE8W0@<VEZ93TB,2(@;F%M93TB86QI9VXB(&ED/2)F
M7V%L:6=N(@H@('1I=&QE/2)0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(CX*
M("`\;W!T:6]N('9A;'5E/2(B('-E;&5C=&5D/2(Q(B`@("`@("`@("`@("`@
M("`^3F]T('-E=#PO;W!T:6]N/@H@(#QO<'1I;VX@=F%L=64](FQE9G0B("`@
M("`@("`@("`@("`@("`@("`@("`@(#Y,969T/"]O<'1I;VX^"B`@/&]P=&EO
M;B!V86QU93TB<FEG:'0B("`@("`@("`@("`@("`@("`@("`@("`@/E)I9VAT
M/"]O<'1I;VX^"B`@/&]P=&EO;B!V86QU93TB=&5X='1O<"(@("`@("`@("`@
M("`@("`@("`@("`@/E1E>'1T;W`\+V]P=&EO;CX*("`\;W!T:6]N('9A;'5E
M/2)A8G-M:61D;&4B("`@("`@("`@("`@("`@("`@("`^06)S;6ED9&QE/"]O
M<'1I;VX^"B`@/&]P=&EO;B!V86QU93TB8F%S96QI;F4B("`@("`@("`@("`@
M("`@("`@("`@/D)A<V5L:6YE/"]O<'1I;VX^"B`@/&]P=&EO;B!V86QU93TB
M86)S8F]T=&]M(B`@("`@("`@("`@("`@("`@("`@/D%B<V)O='1O;3PO;W!T
M:6]N/@H@(#QO<'1I;VX@=F%L=64](F)O='1O;2(@("`@("`@("`@("`@("`@
M("`@("`@(#Y";W1T;VT\+V]P=&EO;CX*("`\;W!T:6]N('9A;'5E/2)M:61D
M;&4B("`@("`@("`@("`@("`@("`@("`@("`^36ED9&QE/"]O<'1I;VX^"B`@
M/&]P=&EO;B!V86QU93TB=&]P(B`@("`@("`@("`@("`@("`@("`@("`@("`@
M/E1O<#PO;W!T:6]N/@H\+W-E;&5C=#X*"CQP("\^"@H\9&EV(&-L87-S/2)F
M;"(^0F]R9&5R('1H:6-K;F5S<SH\+V1I=CX*/&EN<'5T('1Y<&4](G1E>'0B
M(&YA;64](F)O<F1E<B(@:60](F9?8F]R9&5R(B!S:7IE/2(U(B!V86QU93TB
M,2(*=&ET;&4](DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B("\^"CPA+2T*
M/'`@+SX*"CQD:78@8VQA<W,](F9L(CY#;VQL87!S92!B;W)D97)S.CPO9&EV
M/@H\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F-O;&QA<'-E(B!I9#TB
M9E]C;VQL87!S92(@+SX*+2T^"CQD:78@8VQA<W,](G-P86-E(CX\+V1I=CX*
M"CPO9FEE;&1S970^"@H\9FEE;&1S970@<W1Y;&4](F9L;V%T.G)I9VAT.R!M
M87)G:6XM<FEG:'0Z(#5P>#LB/@H\;&5G96YD/E-P86-I;F<\+VQE9V5N9#X*
M"CQD:78@8VQA<W,](G-P86-E(CX\+V1I=CX*"CQD:78@8VQA<W,](F9R(CY#
M96QL('-P86-I;F<Z/"]D:78^"CQI;G!U="!T>7!E/2)T97AT(B!N86UE/2)S
M<&%C:6YG(B!I9#TB9E]S<&%C:6YG(B!S:7IE/2(U(B!V86QU93TB,2(*=&ET
M;&4](E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B("\^"@H\<"`O/@H*
M/&1I=B!C;&%S<STB9G(B/D-E;&P@<&%D9&EN9SH\+V1I=CX*/&EN<'5T('1Y
M<&4](G1E>'0B(&YA;64](G!A9&1I;F<B(&ED/2)F7W!A9&1I;F<B('-I>F4]
M(C4B('9A;'5E/2(Q(@IT:71L93TB4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N
M9"!B;W)D97(@:6X@8V5L;"(@+SX*"CQD:78@8VQA<W,](G-P86-E(CX\+V1I
M=CX*"CPO9FEE;&1S970^"@H\9&EV('-T>6QE/2)M87)G:6XM=&]P.B`X-7!X
M.R!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(SDY.3L@<&%D9&EN9SH@,G!X.R!T
M97AT+6%L:6=N.B!R:6=H=#LB/@H\8G5T=&]N('1Y<&4](F)U='1O;B(@;F%M
M93TB;VLB(&]N8VQI8VL](G)E='5R;B!O;D]+*"D[(CY/2SPO8G5T=&]N/@H\
M8G5T=&]N('1Y<&4](F)U='1O;B(@;F%M93TB8V%N8V5L(B!O;F-L:6-K/2)R
M971U<FX@;VY#86YC96PH*3LB/D-A;F-E;#PO8G5T=&]N/@H\+V1I=CX*"CPO
M9F]R;3X*"CPO8F]D>3X*/"]H=&UL/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I
M8V5S+V5D:71O<B]H=&UL87)E82]P;W!U<',O;&EN:RYH=&UL````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,3`T,S8`,3`U,34T,S,W-38`,#(U-S0T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#QH=&UL/@H*/&AE860^
M"B`@/'1I=&QE/DEN<V5R="]-;V1I9GD@3&EN:SPO=&ET;&4^"B`@/'-C<FEP
M="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B('-R8STB<&]P=7`N:G,B/CPO<V-R
M:7!T/@H@(#QS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*("`@('=I
M;F1O=RYR97-I>F54;R@T,#`L(#(P,"D["@I),3A.(#T@=VEN9&]W+F]P96YE
M<BY(5$U,07)E82Y),3A.+F1I86QO9W,["@IF=6YC=&EO;B!I,3AN*'-T<BD@
M>PH@(')E='5R;B`H23$X3EMS=')=('Q\('-T<BD["GT["@IF=6YC=&EO;B!O
M;E1A<F=E=$-H86YG960H*2!["B`@=F%R(&8@/2!D;V-U;65N="YG971%;&5M
M96YT0GE)9"@B9E]O=&AE<E]T87)G970B*3L*("!I9B`H=&AI<RYV86QU92`]
M/2`B7V]T:&5R(BD@>PH@("`@9BYS='EL92YV:7-I8FEL:71Y(#T@(G9I<VEB
M;&4B.PH@("`@9BYS96QE8W0H*3L*("`@(&8N9F]C=7,H*3L*("!](&5L<V4@
M9BYS='EL92YV:7-I8FEL:71Y(#T@(FAI9&1E;B(["GT["@IF=6YC=&EO;B!)
M;FET*"D@>PH@(%]?9&QG7W1R86YS;&%T92A),3A.*3L*("!?7V1L9U]I;FET
M*"D["B`@=F%R('!A<F%M(#T@=VEN9&]W+F1I86QO9T%R9W5M96YT<SL*("!V
M87(@=&%R9V5T7W-E;&5C="`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")F
M7W1A<F=E="(I.PH@('9A<B!U<V5?=&%R9V5T(#T@=')U93L*("!I9B`H<&%R
M86TI('L*("`@(&EF("@@='EP96]F('!A<F%M6R)F7W5S971A<F=E=")=("$]
M(")U;F1E9FEN960B("D@>PH@("`@("!U<V5?=&%R9V5T(#T@<&%R86U;(F9?
M=7-E=&%R9V5T(ET["B`@("!]"B`@("!I9B`H('1Y<&5O9B!P87)A;5LB9E]H
M<F5F(ET@(3T@(G5N9&5F:6YE9"(@*2!["B`@("`@(&1O8W5M96YT+F=E=$5L
M96UE;G1">4ED*")F7VAR968B*2YV86QU92`]('!A<F%M6R)F7VAR968B73L*
M("`@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(F9?=&ET;&4B*2YV86QU
M92`]('!A<F%M6R)F7W1I=&QE(ET["B`@("`@(&-O;6)O4V5L96-T5F%L=64H
M=&%R9V5T7W-E;&5C="P@<&%R86U;(F9?=&%R9V5T(ETI.PH@("`@("!I9B`H
M=&%R9V5T7W-E;&5C="YV86QU92`A/2!P87)A;2YF7W1A<F=E="D@>PH@("`@
M("`@('9A<B!O<'0@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*")O<'1I;VXB
M*3L*("`@("`@("!O<'0N=F%L=64@/2!P87)A;2YF7W1A<F=E=#L*("`@("`@
M("!O<'0N:6YN97)(5$U,(#T@;W!T+G9A;'5E.PH@("`@("`@('1A<F=E=%]S
M96QE8W0N87!P96YD0VAI;&0H;W!T*3L*("`@("`@("!O<'0N<V5L96-T960@
M/2!T<G5E.PH@("`@("!]"B`@("!]"B`@?0H@(&EF("@A('5S95]T87)G970I
M('L*("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")F7W1A<F=E=%]L86)E
M;"(I+G-T>6QE+G9I<VEB:6QI='D@/2`B:&ED9&5N(CL*("`@(&1O8W5M96YT
M+F=E=$5L96UE;G1">4ED*")F7W1A<F=E="(I+G-T>6QE+G9I<VEB:6QI='D@
M/2`B:&ED9&5N(CL*("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")F7W1A
M<F=E=%]O=&AE<B(I+G-T>6QE+G9I<VEB:6QI='D@/2`B:&ED9&5N(CL*("!]
M"B`@=F%R(&]P="`](&1O8W5M96YT+F-R96%T945L96UE;G0H(F]P=&EO;B(I
M.PH@(&]P="YV86QU92`](")?;W1H97(B.PH@(&]P="YI;FYE<DA434P@/2!I
M,3AN*")/=&AE<B(I.PH@('1A<F=E=%]S96QE8W0N87!P96YD0VAI;&0H;W!T
M*3L*("!T87)G971?<V5L96-T+F]N8VAA;F=E(#T@;VY487)G971#:&%N9V5D
M.PH@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")F7VAR968B*2YF;V-U<R@I
M.PH@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")F7VAR968B*2YS96QE8W0H
M*3L*?3L*"F9U;F-T:6]N(&]N3TLH*2!["B`@=F%R(')E<75I<F5D(#T@>PH@
M("`@+R\@9E]H<F5F('-H;W5L9&XG="!B92!R97%U:7)E9"!O<B!O=&AE<G=I
M<V4@<F5M;W9I;F<@=&AE(&QI;FL@8GD@96YT97)I;F<@86X@96UP='D-"B`@
M("`O+R!U<FP@:7-N)W0@<&]S<VEB;&4@86YY;6]R92X-"B`@("`O+R`B9E]H
M<F5F(CH@:3$X;B@B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES
M(&QI;FL@<&]I;G1S('1O(BD-"B`@?3L*("!F;W(@*'9A<B!I(&EN(')E<75I
M<F5D*2!["B`@("!V87(@96P@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"AI
M*3L*("`@(&EF("@A96PN=F%L=64I('L*("`@("`@86QE<G0H<F5Q=6ER961;
M:5TI.PH@("`@("!E;"YF;V-U<R@I.PH@("`@("!R971U<FX@9F%L<V4["B`@
M("!]"B`@?0H@("\O('!A<W,@9&%T82!B86-K('1O('1H92!C86QL:6YG('=I
M;F1O=PH@('9A<B!F:65L9',@/2!;(F9?:')E9B(L(")F7W1I=&QE(BP@(F9?
M=&%R9V5T(B!=.PH@('9A<B!P87)A;2`](&YE=R!/8FIE8W0H*3L*("!F;W(@
M*'9A<B!I(&EN(&9I96QD<RD@>PH@("`@=F%R(&ED(#T@9FEE;&1S6VE=.PH@
M("`@=F%R(&5L(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H:60I.PH@("`@
M<&%R86U;:61=(#T@96PN=F%L=64["B`@?0H@(&EF("AP87)A;2YF7W1A<F=E
M="`]/2`B7V]T:&5R(BD*("`@('!A<F%M+F9?=&%R9V5T(#T@9&]C=6UE;G0N
M9V5T16QE;65N=$)Y260H(F9?;W1H97)?=&%R9V5T(BDN=F%L=64["B`@7U]D
M;&=?8VQO<V4H<&%R86TI.PH@(')E='5R;B!F86QS93L*?3L*"F9U;F-T:6]N
M(&]N0V%N8V5L*"D@>PH@(%]?9&QG7V-L;W-E*&YU;&PI.PH@(')E='5R;B!F
M86QS93L*?3L*"CPO<V-R:7!T/@H*/'-T>6QE('1Y<&4](G1E>'0O8W-S(CX*
M:'1M;"P@8F]D>2!["B`@8F%C:V=R;W5N9#H@0G5T=&]N1F%C93L*("!C;VQO
M<CH@0G5T=&]N5&5X=#L*("!F;VYT.B`Q,7!X(%1A:&]M82Q697)D86YA+'-A
M;G,M<V5R:68["B`@;6%R9VEN.B`P<'@["B`@<&%D9&EN9SH@,'!X.PI]"F)O
M9'D@>R!P861D:6YG.B`U<'@[('T*=&%B;&4@>PH@(&9O;G0Z(#$Q<'@@5&%H
M;VUA+%9E<F1A;F$L<V%N<RUS97)I9CL*?0IS96QE8W0L(&EN<'5T+"!B=71T
M;VX@>R!F;VYT.B`Q,7!X(%1A:&]M82Q697)D86YA+'-A;G,M<V5R:68[('T*
M8G5T=&]N('L@=VED=&@Z(#<P<'@[('T*=&%B;&4@+FQA8F5L('L@=&5X="UA
M;&EG;CH@<FEG:'0[('=I9'1H.B`X96T[('T*"BYT:71L92![(&)A8VMG<F]U
M;F0Z("-D9&8[(&-O;&]R.B`C,#`P.R!F;VYT+7=E:6=H=#H@8F]L9#L@9F]N
M="US:7IE.B`Q,C`E.R!P861D:6YG.B`S<'@@,3!P>#L@;6%R9VEN+6)O='1O
M;3H@,3!P>#L*8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(&)L86-K.R!L971T
M97(M<W!A8VEN9SH@,G!X.PI]"@HC8G5T=&]N<R!["B`@("`@(&UA<F=I;BUT
M;W`Z(#%E;3L@8F]R9&5R+71O<#H@,7!X('-O;&ED(",Y.3D["B`@("`@('!A
M9&1I;F<Z(#)P>#L@=&5X="UA;&EG;CH@<FEG:'0["GT*/"]S='EL93X*"CPO
M:&5A9#X*"CQB;V1Y(&]N;&]A9#TB26YI="@I(CX*/&1I=B!C;&%S<STB=&ET
M;&4B/DEN<V5R="]-;V1I9GD@3&EN:SPO9&EV/@H\9F]R;3X*/'1A8FQE(&)O
M<F1E<CTB,"(@<W1Y;&4](G=I9'1H.B`Q,#`E.R(^"B`@/'1R/@H@("`@/'1D
M(&-L87-S/2)L86)E;"(^55),.CPO=&0^"B`@("`\=&0^/&EN<'5T('1Y<&4]
M(G1E>'0B(&ED/2)F7VAR968B('-T>6QE/2)W:61T:#H@,3`P)2(@+SX\+W1D
M/@H@(#PO='(^"B`@/'1R/@H@("`@/'1D(&-L87-S/2)L86)E;"(^5&ET;&4@
M*'1O;VQT:7`I.CPO=&0^"B`@("`\=&0^/&EN<'5T('1Y<&4](G1E>'0B(&ED
M/2)F7W1I=&QE(B!S='EL93TB=VED=&@Z(#$P,"4B("\^/"]T9#X*("`\+W1R
M/@H@(#QT<CX*("`@(#QT9"!C;&%S<STB;&%B96PB/CQS<&%N(&ED/2)F7W1A
M<F=E=%]L86)E;"(^5&%R9V5T.CPO<W!A;CX\+W1D/@H@("`@/'1D/CQS96QE
M8W0@:60](F9?=&%R9V5T(CX*("`@("`@/&]P=&EO;B!V86QU93TB(CY.;VYE
M("AU<V4@:6UP;&EC:70I/"]O<'1I;VX^"B`@("`@(#QO<'1I;VX@=F%L=64]
M(E]B;&%N:R(^3F5W('=I;F1O=R`H7V)L86YK*3PO;W!T:6]N/@H@("`@("`\
M;W!T:6]N('9A;'5E/2)?<V5L9B(^4V%M92!F<F%M92`H7W-E;&8I/"]O<'1I
M;VX^"B`@("`@(#QO<'1I;VX@=F%L=64](E]T;W`B/E1O<"!F<F%M92`H7W1O
M<"D\+V]P=&EO;CX*("`@(#PO<V5L96-T/@H@("`@/&EN<'5T('1Y<&4](G1E
M>'0B(&YA;64](F9?;W1H97)?=&%R9V5T(B!I9#TB9E]O=&AE<E]T87)G970B
M('-I>F4](C$P(B!S='EL93TB=FES:6)I;&ET>3H@:&ED9&5N(B`O/@H@("`@
M/"]T9#X*("`\+W1R/@H\+W1A8FQE/@H*/&1I=B!I9#TB8G5T=&]N<R(^"B`@
M/&)U='1O;B!T>7!E/2)S=6)M:70B(&YA;64](F]K(B!O;F-L:6-K/2)R971U
M<FX@;VY/2R@I.R(^3TL\+V)U='1O;CX*("`\8G5T=&]N('1Y<&4](F)U='1O
M;B(@;F%M93TB8V%N8V5L(B!O;F-L:6-K/2)R971U<FX@;VY#86YC96PH*3LB
M/D-A;F-E;#PO8G5T=&]N/@H\+V1I=CX*/"]F;W)M/@H\+V)O9'D^"CPO:'1M
M;#X*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R
M+VAT;6QA<F5A+W!O<'5P<R]P;W!U<"YJ<P``````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-C(R-0`Q,#4Q-30S,S<U-@`P,C4V,C,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+R\@:'1M;$%R96$@=C,N,"`M($-O<'ER
M:6=H="`H8RD@,C`P,BP@,C`P,R!I;G1E<F%C=&EV971O;VQS+F-O;2P@:6YC
M+@HO+R!4:&ES(&-O<'ER:6=H="!N;W1I8V4@35535"!S=&%Y(&EN=&%C="!F
M;W(@=7-E("AS964@;&EC96YS92YT>'0I+@HO+PHO+R!0;W)T:6]N<R`H8RD@
M9'EN87)C:"YC;VTL(#(P,#,*+R\*+R\@02!F<F5E(%=94TE764<@961I=&]R
M(')E<&QA8V5M96YT(&9O<B`\=&5X=&%R96$^(&9I96QD<RX*+R\@1F]R(&9U
M;&P@<V]U<F-E(&-O9&4@86YD(&1O8W,L('9I<VET(&AT='`Z+R]W=W<N:'1M
M;&%R96$N8V]M+PHO+PHO+R!697)S:6]N(#,N,"!D979E;&]P960@8GD@36EH
M86D@0F%Z;VXN"B\O("`@:'1T<#HO+V1Y;F%R8V@N8V]M+VUI<VAO;PHO+PHO
M+R`D260Z('!O<'5P+FIS+'8@,2XQ,B`R,#`U+S`Q+S(T(#$X.C(Y.C0X(&ET
M;V]L<R!%>'`@)`H*9G5N8W1I;VX@9V5T06)S;VQU=&50;W,H96PI('L*"79A
M<B!R(#T@>R!X.B!E;"YO9F9S971,969T+"!Y.B!E;"YO9F9S9714;W`@?3L*
M"6EF("AE;"YO9F9S971087)E;G0I('L*"0EV87(@=&UP(#T@9V5T06)S;VQU
M=&50;W,H96PN;V9F<V5T4&%R96YT*3L*"0ER+G@@*ST@=&UP+G@["@D)<BYY
M("L]('1M<"YY.PH)?0H)<F5T=7)N('(["GT["@IF=6YC=&EO;B!C;VUB;U-E
M;&5C=%9A;'5E*&,L('9A;"D@>PH)=F%R(&]P<R`](&,N9V5T16QE;65N='-"
M>51A9TYA;64H(F]P=&EO;B(I.PH)9F]R("AV87(@:2`](&]P<RYL96YG=&@[
M("TM:2`^/2`P.RD@>PH)"79A<B!O<"`](&]P<UMI73L*"0EO<"YS96QE8W1E
M9"`]("AO<"YV86QU92`]/2!V86PI.PH)?0H)8RYV86QU92`]('9A;#L*?3L*
M"F9U;F-T:6]N(%]?9&QG7V]N8VQO<V4H*2!["@EO<&5N97(N1&EA;&]G+E]R
M971U<FXH;G5L;"D["GT["@IF=6YC=&EO;B!?7V1L9U]I;FET*&)O='1O;2D@
M>PH)=F%R(&)O9'D@/2!D;V-U;65N="YB;V1Y.PH)=F%R(&)O9'E?:&5I9VAT
M(#T@,#L*"6EF("AT>7!E;V8@8F]T=&]M(#T](")U;F1E9FEN960B*2!["@D)
M=F%R(&1I=B`](&1O8W5M96YT+F-R96%T945L96UE;G0H(F1I=B(I.PH)"6)O
M9'DN87!P96YD0VAI;&0H9&EV*3L*"0EV87(@<&]S(#T@9V5T06)S;VQU=&50
M;W,H9&EV*3L*"0EB;V1Y7VAE:6=H="`]('!O<RYY.PH)?2!E;'-E('L*"0EV
M87(@<&]S(#T@9V5T06)S;VQU=&50;W,H8F]T=&]M*3L*"0EB;V1Y7VAE:6=H
M="`]('!O<RYY("L@8F]T=&]M+F]F9G-E=$AE:6=H=#L*"7T*"7=I;F1O=RYD
M:6%L;V=!<F=U;65N=',@/2!O<&5N97(N1&EA;&]G+E]A<F=U;65N=',["@EI
M9B`H(61O8W5M96YT+F%L;"D@>PH)"7=I;F1O=RYS:7IE5&]#;VYT96YT*"D[
M"@D)=VEN9&]W+G-I>F54;T-O;G1E;G0H*3L)+R\@9F]R(')E87-O;G,@8F5Y
M;VYD('5N9&5R<W1A;F1I;F<L"@D)"0D)+R\@;VYL>2!I9B!W92!C86QL(&ET
M('1W:6-E('=E(&=E="!T:&4*"0D)"0DO+R!C;W)R96-T('-I>F4N"@D)=VEN
M9&]W+F%D9$5V96YT3&ES=&5N97(H(G5N;&]A9"(L(%]?9&QG7V]N8VQO<V4L
M('1R=64I.PH)"7=I;F1O=RYI;FYE<E=I9'1H(#T@8F]D>2YO9F9S9717:61T
M:"`K(#4["@D)=VEN9&]W+FEN;F5R2&5I9VAT(#T@8F]D>5]H96EG:'0@*R`R
M.PH)"2\O(&-E;G1E<B!O;B!P87)E;G0*"0EV87(@>"`](&]P96YE<BYS8W)E
M96Y8("L@*&]P96YE<BYO=71E<E=I9'1H("T@=VEN9&]W+F]U=&5R5VED=&@I
M("\@,CL*"0EV87(@>2`](&]P96YE<BYS8W)E96Y9("L@*&]P96YE<BYO=71E
M<DAE:6=H="`M('=I;F1O=RYO=71E<DAE:6=H="D@+R`R.PH)"7=I;F1O=RYM
M;W9E5&\H>"P@>2D["@E](&5L<V4@>PH)"2\O('=I;F1O=RYD:6%L;V=(96EG
M:'0@/2!B;V1Y+F]F9G-E=$AE:6=H="`K(#4P("L@(G!X(CL*"0DO+R!W:6YD
M;W<N9&EA;&]G5VED=&@@/2!B;V1Y+F]F9G-E=%=I9'1H("L@(G!X(CL*"0EW
M:6YD;W<N<F5S:7IE5&\H8F]D>2YO9F9S9717:61T:"P@8F]D>5]H96EG:'0I
M.PH)"79A<B!C:"`](&)O9'DN8VQI96YT2&5I9VAT.PH)"79A<B!C=R`](&)O
M9'DN8VQI96YT5VED=&@["@D)=VEN9&]W+G)E<VEZ94)Y*&)O9'DN;V9F<V5T
M5VED=&@@+2!C=RP@8F]D>5]H96EG:'0@+2!C:"D["@D)=F%R(%<@/2!B;V1Y
M+F]F9G-E=%=I9'1H.PH)"79A<B!((#T@,B`J(&)O9'E?:&5I9VAT("T@8V@[
M"@D)=F%R('@@/2`H<V-R965N+F%V86EL5VED=&@@+2!7*2`O(#(["@D)=F%R
M('D@/2`H<V-R965N+F%V86EL2&5I9VAT("T@2"D@+R`R.PH)"7=I;F1O=RYM
M;W9E5&\H>"P@>2D["@E]"@ED;V-U;65N="YB;V1Y+F]N:V5Y<')E<W,@/2!?
M7V1L9U]C;&]S95]O;E]E<V,["GT["@IF=6YC=&EO;B!?7V1L9U]T<F%N<VQA
M=&4H:3$X;BD@>PH)=F%R('1Y<&5S(#T@6R)I;G!U="(L(")S96QE8W0B+"`B
M;&5G96YD(BP@(G-P86XB+"`B;W!T:6]N(BP@(G1D(BP@(F)U='1O;B(L(")D
M:78B73L*"69O<B`H=F%R('1Y<&4@/2`P.R!T>7!E(#P@='EP97,N;&5N9W1H
M.R`K*W1Y<&4I('L*"0EV87(@<W!A;G,@/2!D;V-U;65N="YG971%;&5M96YT
M<T)Y5&%G3F%M92AT>7!E<UMT>7!E72D["@D)9F]R("AV87(@:2`]('-P86YS
M+FQE;F=T:#L@+2UI(#X](#`[*2!["@D)"79A<B!S<&%N(#T@<W!A;G-;:5T[
M"@D)"6EF("AS<&%N+F9I<G-T0VAI;&0@)B8@<W!A;BYF:7)S=$-H:6QD+F1A
M=&$I('L*"0D)"79A<B!T>'0@/2!I,3AN6W-P86XN9FER<W1#:&EL9"YD871A
M73L*"0D)"6EF("AT>'0I"@D)"0D)<W!A;BYF:7)S=$-H:6QD+F1A=&$@/2!T
M>'0["@D)"7T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*'-P86XN=&ET
M;&4I('L*"0D)"79A<B!T>'0@/2!I,3AN6W-P86XN=&ET;&5=.PH)"0D):68@
M*'1X="D*"0D)"0ES<&%N+G1I=&QE(#T@='AT.PH@("`@("`@("`@("`@("`@
M("`@("`@("!]"@D)?0H)?0H)=F%R('1X="`](&DQ.&Y;9&]C=6UE;G0N=&ET
M;&5=.PH):68@*'1X="D*"0ED;V-U;65N="YT:71L92`]('1X=#L*?3L*"B\O
M(&-L;W-E<R!T:&4@9&EA;&]G(&%N9"!P87-S97,@=&AE(')E='5R;B!I;F9O
M('5P<&5R+@IF=6YC=&EO;B!?7V1L9U]C;&]S92AV86PI('L*"6]P96YE<BY$
M:6%L;V<N7W)E='5R;BAV86PI.PH)=VEN9&]W+F-L;W-E*"D["GT["@IF=6YC
M=&EO;B!?7V1L9U]C;&]S95]O;E]E<V,H978I('L*"65V('Q\("AE=B`]('=I
M;F1O=RYE=F5N="D["@EI9B`H978N:V5Y0V]D92`]/2`R-RD@>PH)"7=I;F1O
M=RYC;&]S92@I.PH)"7)E='5R;B!F86QS93L*"7T*"7)E='5R;B!T<G5E.PI]
M.PH`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O
M<B]H=&UL87)E82]P;W!U<',O<V5L96-T7V-O;&]R+FAT;6P`````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M-S`Q-#(`,3`U,34T,S,W-38`,#(W-#8T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#PA+2T@;F]T93H@=&AI<R!V97)S:6]N
M(&]F('1H92!C;VQO<B!P:6-K97(@:7,@;W!T:6UI>F5D(&9O<B!)12`U+C4K
M(&]N;'D@+2T^#0H-"CQH=&UL/CQH96%D/CQT:71L93Y396QE8W0@0V]L;W(\
M+W1I=&QE/@T*#0H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(@<W)C
M/2)P;W!U<"YJ<R(^/"]S8W)I<'0^#0H-"CQS8W)I<'0@='EP93TB=&5X="]J
M879A<V-R:7!T(CX-"@T*=VEN9&]W+G)E<VEZ951O*#(T,"P@,3@R*3L-"F9U
M;F-T:6]N(%]#;&]S94]N17-C*"D@>PT*("!I9B`H979E;G0N:V5Y0V]D92`]
M/2`R-RD@>R!W:6YD;W<N8VQO<V4H*3L@<F5T=7)N.R!]#0I]#0H-"F9U;F-T
M:6]N($EN:70H*2![("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("\O(')U;B!O;B!P86=E(&QO860-"B`@
M7U]D;&=?:6YI="@I.R`@("`O+R`\(2TM('1H:7,@8V%N(&)E(&9O=6YD(&EN
M('!O<'5P+FIS("TM/@T*("!D;V-U;65N="YB;V1Y+F]N:V5Y<')E<W,@/2!?
M0VQO<V5/;D5S8SL-"@T*("!V87(@8V]L;W(@/2!W:6YD;W<N9&EA;&]G07)G
M=6UE;G1S.PT*("!C;VQO<B`](%9A;&ED871E0V]L;W(H8V]L;W(I('Q\("<P
M,#`P,#`G.PT*("!6:65W*&-O;&]R*3L@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@<V5T(&1E
M9F%U;'0@8V]L;W(-"GT-"@T*9G5N8W1I;VX@5FEE=RAC;VQO<BD@>R`@("`@
M("`@("`@("`@("`@("\O('!R979I97<@8V]L;W(-"B`@9&]C=6UE;G0N9V5T
M16QE;65N=$)Y260H(D-O;&]R4')E=FEE=R(I+G-T>6QE+F)A8VMG<F]U;F1#
M;VQO<B`]("<C)R`K(&-O;&]R.PT*("!D;V-U;65N="YG971%;&5M96YT0GE)
M9"@B0V]L;W)(97@B*2YV86QU92`]("<C)R`K(&-O;&]R.PT*?0T*#0IF=6YC
M=&EO;B!3970H<W1R:6YG*2![("`@("`@("`@("`@("`@("`@("\O('-E;&5C
M="!C;VQO<@T*("!V87(@8V]L;W(@/2!686QI9&%T94-O;&]R*'-T<FEN9RD[
M#0H@(&EF("AC;VQO<B`]/2!N=6QL*2![(&%L97)T*"));G9A;&ED(&-O;&]R
M(&-O9&4Z("(@*R!S=')I;F<I.R!]("`@("`@("`O+R!I;G9A;&ED(&-O;&]R
M#0H@(&5L<V4@>R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!V86QI9"!C;VQO<@T*
M("`@(%9I97<H8V]L;W(I.R`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M<VAO=R!S96QE8W1E9"!C;VQO<@T*("`@(%]?9&QG7V-L;W-E*&-O;&]R*3L-
M"B`@?0T*?0T*#0IF=6YC=&EO;B!686QI9&%T94-O;&]R*'-T<FEN9RD@>R`@
M("`@("`@("`@("`@("`O+R!R971U<FX@=F%L:60@8V]L;W(@8V]D90T*("!S
M=')I;F<@/2!S=')I;F<@?'P@)R<[#0H@('-T<FEN9R`]('-T<FEN9R`K("(B
M.PT*("!S=')I;F<@/2!S=')I;F<N=&]5<'!E<D-A<V4H*3L-"B`@=F%R(&-H
M87)S(#T@)S`Q,C,T-38W.#E!0D-$148G.PT*("!V87(@;W5T("`@/2`G)SL-
M"@T*("!F;W(@*'9A<B!I/3`[(&D\<W1R:6YG+FQE;F=T:#L@:2LK*2![("`@
M("`@("`@("`@("\O(')E;6]V92!I;G9A;&ED(&-O;&]R(&-H87)S#0H@("`@
M=F%R('-C:&%R(#T@<W1R:6YG+F-H87)!="AI*3L-"B`@("!I9B`H8VAA<G,N
M:6YD97A/9BAS8VAA<BD@(3T@+3$I('L@;W5T("L]('-C:&%R.R!]#0H@('T-
M"@T*("!I9B`H;W5T+FQE;F=T:"`A/2`V*2![(')E='5R;B!N=6QL.R!]("`@
M("`@("`@("`@+R\@8VAE8VL@;&5N9W1H#0H@(')E='5R;B!O=70[#0I]#0H-
M"CPO<V-R:7!T/@T*/"]H96%D/@T*/&)O9'D@<W1Y;&4](F)A8VMG<F]U;F0Z
M0G5T=&]N1F%C93L@;6%R9VEN.C!P>#L@<&%D9&EN9SHP<'@B(&]N;&]A9#TB
M26YI="@I(CX-"@T*/&9O<FT@;65T:&]D/2)G970B('-T>6QE/2)M87)G:6XZ
M,'!X.R!P861D:6YG.C!P>"(@;VY3=6)M:70](E-E="AD;V-U;65N="YG971%
M;&5M96YT0GE)9"@G0V]L;W)(97@G*2YV86QU92D[(')E='5R;B!F86QS93LB
M/@T*/'1A8FQE(&)O<F1E<CTB,'!X(B!C96QL<W!A8VEN9STB,'!X(B!C96QL
M<&%D9&EN9STB-"(@=VED=&@](C$P,"4B/@T*(#QT<CX-"B`@/'1D('-T>6QE
M/2)B86-K9W)O=6YD.F)U='1O;F9A8V4B('9A;&EG;CUC96YT97(^/&1I=B!S
M='EL93TB8F%C:V=R;W5N9"UC;VQO<CH@(S`P,#`P,#L@<&%D9&EN9SH@,3L@
M:&5I9VAT.B`R,7!X.R!W:61T:#H@-3!P>"(^/&1I=B!I9#TB0V]L;W)0<F5V
M:65W(B!S='EL93TB:&5I9VAT.B`Q,#`E.R!W:61T:#H@,3`P)2(^/"]D:78^
M/"]D:78^/"]T9#X-"B`@/'1D('-T>6QE/2)B86-K9W)O=6YD.F)U='1O;F9A
M8V4B('9A;&EG;CUC96YT97(^/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](D-O
M;&]R2&5X(@T*("`@(&ED/2)#;VQO<DAE>"(@=F%L=64](B(@<VEZ93TQ-2!S
M='EL93TB9F]N="US:7IE.B`Q,G!X(CX\+W1D/@T*("`\=&0@<W1Y;&4](F)A
M8VMG<F]U;F0Z8G5T=&]N9F%C92(@=VED=&@],3`P)3X\+W1D/@T*(#PO='(^
M#0H\+W1A8FQE/@T*/"]F;W)M/@T*#0H\=&%B;&4@8F]R9&5R/2(P(B!C96QL
M<W!A8VEN9STB,7!X(B!C96QL<&%D9&EN9STB,'!X(B!W:61T:#TB,3`P)2(@
M8F=C;VQO<CTB(S`P,#`P,"(@<W1Y;&4](F-U<G-O<CH@:&%N9#LB/@T*/'1R
M/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P
M,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-;W5S94]V
M97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`P
M,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]4V5T*"<P
M,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P,#`G*2!O
M;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#,S,#`@;VY-;W5S94]V97(]5FEE
M=R@G,#`S,S`P)RD@;VY#;&EC:SU3970H)S`P,S,P,"<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`V-C`P(&]N
M36]U<V5/=F5R/59I97<H)S`P-C8P,"<I(&]N0VQI8VL]4V5T*"<P,#8V,#`G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](S`P.3DP,"!O;DUO=7-E3W9E<CU6:65W*"<P,#DY,#`G*2!O;D-L:6-K
M/5-E="@G,#`Y.3`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2,P,$-#,#`@;VY-;W5S94]V97(]5FEE=R@G,#!#
M0S`P)RD@;VY#;&EC:SU3970H)S`P0T,P,"<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#!&1C`P(&]N36]U<V5/
M=F5R/59I97<H)S`P1D8P,"<I(&]N0VQI8VL]4V5T*"<P,$9&,#`G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S
M,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<S,S`P,#`G*2!O;D-L:6-K/5-E="@G
M,S,P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2,S,S,S,#`@;VY-;W5S94]V97(]5FEE=R@G,S,S,S`P)RD@
M;VY#;&EC:SU3970H)S,S,S,P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,V-C`P(&]N36]U<V5/=F5R/59I
M97<H)S,S-C8P,"<I(&]N0VQI8VL]4V5T*"<S,S8V,#`G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S.3DP,"!O
M;DUO=7-E3W9E<CU6:65W*"<S,SDY,#`G*2!O;D-L:6-K/5-E="@G,S,Y.3`P
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2,S,T-#,#`@;VY-;W5S94]V97(]5FEE=R@G,S-#0S`P)RD@;VY#;&EC
M:SU3970H)S,S0T,P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC,S-&1C`P(&]N36]U<V5/=F5R/59I97<H)S,S
M1D8P,"<I(&]N0VQI8VL]4V5T*"<S,T9&,#`G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V,#`P,"!O;DUO=7-E
M3W9E<CU6:65W*"<V-C`P,#`G*2!O;D-L:6-K/5-E="@G-C8P,#`P)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V
M-C,S,#`@;VY-;W5S94]V97(]5FEE=R@G-C8S,S`P)RD@;VY#;&EC:SU3970H
M)S8V,S,P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC-C8V-C`P(&]N36]U<V5/=F5R/59I97<H)S8V-C8P,"<I
M(&]N0VQI8VL]4V5T*"<V-C8V,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V.3DP,"!O;DUO=7-E3W9E<CU6
M:65W*"<V-CDY,#`G*2!O;D-L:6-K/5-E="@G-C8Y.3`P)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-D-#,#`@
M;VY-;W5S94]V97(]5FEE=R@G-C9#0S`P)RD@;VY#;&EC:SU3970H)S8V0T,P
M,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C
M;VQO<CTC-C9&1C`P(&]N36]U<V5/=F5R/59I97<H)S8V1D8P,"<I(&]N0VQI
M8VL]4V5T*"<V-D9&,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/"]T<CX-"CQT<CX-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-;W5S
M94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M,S,S,S,S(&]N36]U<V5/=F5R/59I97<H)S,S,S,S,R<I(&]N0VQI8VL]4V5T
M*"<S,S,S,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P,#`G
M*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P,S,@;VY-;W5S94]V97(]
M5FEE=R@G,#`P,#,S)RD@;VY#;&EC:SU3970H)S`P,#`S,R<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`S,S,S
M(&]N36]U<V5/=F5R/59I97<H)S`P,S,S,R<I(&]N0VQI8VL]4V5T*"<P,#,S
M,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](S`P-C8S,R!O;DUO=7-E3W9E<CU6:65W*"<P,#8V,S,G*2!O;D-L
M:6-K/5-E="@G,#`V-C,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#DY,S,@;VY-;W5S94]V97(]5FEE=R@G
M,#`Y.3,S)RD@;VY#;&EC:SU3970H)S`P.3DS,R<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#!#0S,S(&]N36]U
M<V5/=F5R/59I97<H)S`P0T,S,R<I(&]N0VQI8VL]4V5T*"<P,$-#,S,G*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(S`P1D8S,R!O;DUO=7-E3W9E<CU6:65W*"<P,$9&,S,G*2!O;D-L:6-K/5-E
M="@G,#!&1C,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2,S,S`P,S,@;VY-;W5S94]V97(]5FEE=R@G,S,P,#,S
M)RD@;VY#;&EC:SU3970H)S,S,#`S,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,S,S,S(&]N36]U<V5/=F5R
M/59I97<H)S,S,S,S,R<I(&]N0VQI8VL]4V5T*"<S,S,S,S,G*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S-C8S
M,R!O;DUO=7-E3W9E<CU6:65W*"<S,S8V,S,G*2!O;D-L:6-K/5-E="@G,S,V
M-C,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2,S,SDY,S,@;VY-;W5S94]V97(]5FEE=R@G,S,Y.3,S)RD@;VY#
M;&EC:SU3970H)S,S.3DS,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S-#0S,S(&]N36]U<V5/=F5R/59I97<H
M)S,S0T,S,R<I(&]N0VQI8VL]4V5T*"<S,T-#,S,G*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S1D8S,R!O;DUO
M=7-E3W9E<CU6:65W*"<S,T9&,S,G*2!O;D-L:6-K/5-E="@G,S-&1C,S)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2,V-C`P,S,@;VY-;W5S94]V97(]5FEE=R@G-C8P,#,S)RD@;VY#;&EC:SU3
M970H)S8V,#`S,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC-C8S,S,S(&]N36]U<V5/=F5R/59I97<H)S8V,S,S
M,R<I(&]N0VQI8VL]4V5T*"<V-C,S,S,G*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V-C8S,R!O;DUO=7-E3W9E
M<CU6:65W*"<V-C8V,S,G*2!O;D-L:6-K/5-E="@G-C8V-C,S)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-CDY
M,S,@;VY-;W5S94]V97(]5FEE=R@G-C8Y.3,S)RD@;VY#;&EC:SU3970H)S8V
M.3DS,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@
M8F=C;VQO<CTC-C9#0S,S(&]N36]U<V5/=F5R/59I97<H)S8V0T,S,R<I(&]N
M0VQI8VL]4V5T*"<V-D-#,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V1D8S,R!O;DUO=7-E3W9E<CU6:65W
M*"<V-D9&,S,G*2!O;D-L:6-K/5-E="@G-C9&1C,S)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CPO='(^#0H\='(^#0H\=&0@8F=C;VQO
M<CTC,#`P,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]
M4V5T*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/'1D(&)G8V]L;W(](S8V-C8V-B!O;DUO=7-E3W9E<CU6:65W*"<V-C8V
M-C8G*2!O;D-L:6-K/5-E="@G-C8V-C8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-;W5S94]V
M97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`P
M,#8V(&]N36]U<V5/=F5R/59I97<H)S`P,#`V-B<I(&]N0VQI8VL]4V5T*"<P
M,#`P-C8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](S`P,S,V-B!O;DUO=7-E3W9E<CU6:65W*"<P,#,S-C8G*2!O
M;D-L:6-K/5-E="@G,#`S,S8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#8V-C8@;VY-;W5S94]V97(]5FEE
M=R@G,#`V-C8V)RD@;VY#;&EC:SU3970H)S`P-C8V-B<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`Y.38V(&]N
M36]U<V5/=F5R/59I97<H)S`P.3DV-B<I(&]N0VQI8VL]4V5T*"<P,#DY-C8G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](S`P0T,V-B!O;DUO=7-E3W9E<CU6:65W*"<P,$-#-C8G*2!O;D-L:6-K
M/5-E="@G,#!#0S8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2,P,$9&-C8@;VY-;W5S94]V97(]5FEE=R@G,#!&
M1C8V)RD@;VY#;&EC:SU3970H)S`P1D8V-B<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,P,#8V(&]N36]U<V5/
M=F5R/59I97<H)S,S,#`V-B<I(&]N0VQI8VL]4V5T*"<S,S`P-C8G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S
M,S,V-B!O;DUO=7-E3W9E<CU6:65W*"<S,S,S-C8G*2!O;D-L:6-K/5-E="@G
M,S,S,S8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2,S,S8V-C8@;VY-;W5S94]V97(]5FEE=R@G,S,V-C8V)RD@
M;VY#;&EC:SU3970H)S,S-C8V-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,Y.38V(&]N36]U<V5/=F5R/59I
M97<H)S,S.3DV-B<I(&]N0VQI8VL]4V5T*"<S,SDY-C8G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S0T,V-B!O
M;DUO=7-E3W9E<CU6:65W*"<S,T-#-C8G*2!O;D-L:6-K/5-E="@G,S-#0S8V
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2,S,T9&-C8@;VY-;W5S94]V97(]5FEE=R@G,S-&1C8V)RD@;VY#;&EC
M:SU3970H)S,S1D8V-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC-C8P,#8V(&]N36]U<V5/=F5R/59I97<H)S8V
M,#`V-B<I(&]N0VQI8VL]4V5T*"<V-C`P-C8G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V,S,V-B!O;DUO=7-E
M3W9E<CU6:65W*"<V-C,S-C8G*2!O;D-L:6-K/5-E="@G-C8S,S8V)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V
M-C8V-C8@;VY-;W5S94]V97(]5FEE=R@G-C8V-C8V)RD@;VY#;&EC:SU3970H
M)S8V-C8V-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC-C8Y.38V(&]N36]U<V5/=F5R/59I97<H)S8V.3DV-B<I
M(&]N0VQI8VL]4V5T*"<V-CDY-C8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V0T,V-B!O;DUO=7-E3W9E<CU6
M:65W*"<V-D-#-C8G*2!O;D-L:6-K/5-E="@G-C9#0S8V)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-D9&-C8@
M;VY-;W5S94]V97(]5FEE=R@G-C9&1C8V)RD@;VY#;&EC:SU3970H)S8V1D8V
M-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\+W1R/@T*
M/'1R/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P
M,#`P,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3DY.3D@;VY-;W5S
M94]V97(]5FEE=R@G.3DY.3DY)RD@;VY#;&EC:SU3970H)SDY.3DY.2<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M,#`P,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]4V5T
M*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](S`P,#`Y.2!O;DUO=7-E3W9E<CU6:65W*"<P,#`P.3DG
M*2!O;D-L:6-K/5-E="@G,#`P,#DY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#,S.3D@;VY-;W5S94]V97(]
M5FEE=R@G,#`S,SDY)RD@;VY#;&EC:SU3970H)S`P,S,Y.2<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`V-CDY
M(&]N36]U<V5/=F5R/59I97<H)S`P-C8Y.2<I(&]N0VQI8VL]4V5T*"<P,#8V
M.3DG*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](S`P.3DY.2!O;DUO=7-E3W9E<CU6:65W*"<P,#DY.3DG*2!O;D-L
M:6-K/5-E="@G,#`Y.3DY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2,P,$-#.3D@;VY-;W5S94]V97(]5FEE=R@G
M,#!#0SDY)RD@;VY#;&EC:SU3970H)S`P0T,Y.2<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#!&1CDY(&]N36]U
M<V5/=F5R/59I97<H)S`P1D8Y.2<I(&]N0VQI8VL]4V5T*"<P,$9&.3DG*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(S,S,#`Y.2!O;DUO=7-E3W9E<CU6:65W*"<S,S`P.3DG*2!O;D-L:6-K/5-E
M="@G,S,P,#DY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2,S,S,S.3D@;VY-;W5S94]V97(]5FEE=R@G,S,S,SDY
M)RD@;VY#;&EC:SU3970H)S,S,S,Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,V-CDY(&]N36]U<V5/=F5R
M/59I97<H)S,S-C8Y.2<I(&]N0VQI8VL]4V5T*"<S,S8V.3DG*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S.3DY
M.2!O;DUO=7-E3W9E<CU6:65W*"<S,SDY.3DG*2!O;D-L:6-K/5-E="@G,S,Y
M.3DY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2,S,T-#.3D@;VY-;W5S94]V97(]5FEE=R@G,S-#0SDY)RD@;VY#
M;&EC:SU3970H)S,S0T,Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S-&1CDY(&]N36]U<V5/=F5R/59I97<H
M)S,S1D8Y.2<I(&]N0VQI8VL]4V5T*"<S,T9&.3DG*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V,#`Y.2!O;DUO
M=7-E3W9E<CU6:65W*"<V-C`P.3DG*2!O;D-L:6-K/5-E="@G-C8P,#DY)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2,V-C,S.3D@;VY-;W5S94]V97(]5FEE=R@G-C8S,SDY)RD@;VY#;&EC:SU3
M970H)S8V,S,Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC-C8V-CDY(&]N36]U<V5/=F5R/59I97<H)S8V-C8Y
M.2<I(&]N0VQI8VL]4V5T*"<V-C8V.3DG*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V.3DY.2!O;DUO=7-E3W9E
M<CU6:65W*"<V-CDY.3DG*2!O;D-L:6-K/5-E="@G-C8Y.3DY)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-D-#
M.3D@;VY-;W5S94]V97(]5FEE=R@G-C9#0SDY)RD@;VY#;&EC:SU3970H)S8V
M0T,Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@
M8F=C;VQO<CTC-C9&1CDY(&]N36]U<V5/=F5R/59I97<H)S8V1D8Y.2<I(&]N
M0VQI8VL]4V5T*"<V-D9&.3DG*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/"]T<CX-"CQT<CX-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-
M;W5S94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO
M<CTC0T-#0T-#(&]N36]U<V5/=F5R/59I97<H)T-#0T-#0R<I(&]N0VQI8VL]
M4V5T*"=#0T-#0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P
M,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P0T,@;VY-;W5S94]V
M97(]5FEE=R@G,#`P,$-#)RD@;VY#;&EC:SU3970H)S`P,#!#0R<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`S
M,T-#(&]N36]U<V5/=F5R/59I97<H)S`P,S-#0R<I(&]N0VQI8VL]4V5T*"<P
M,#,S0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](S`P-C9#0R!O;DUO=7-E3W9E<CU6:65W*"<P,#8V0T,G*2!O
M;D-L:6-K/5-E="@G,#`V-D-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#DY0T,@;VY-;W5S94]V97(]5FEE
M=R@G,#`Y.4-#)RD@;VY#;&EC:SU3970H)S`P.3E#0R<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#!#0T-#(&]N
M36]U<V5/=F5R/59I97<H)S`P0T-#0R<I(&]N0VQI8VL]4V5T*"<P,$-#0T,G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](S`P1D9#0R!O;DUO=7-E3W9E<CU6:65W*"<P,$9&0T,G*2!O;D-L:6-K
M/5-E="@G,#!&1D-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2,S,S`P0T,@;VY-;W5S94]V97(]5FEE=R@G,S,P
M,$-#)RD@;VY#;&EC:SU3970H)S,S,#!#0R<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,S,T-#(&]N36]U<V5/
M=F5R/59I97<H)S,S,S-#0R<I(&]N0VQI8VL]4V5T*"<S,S,S0T,G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S
M-C9#0R!O;DUO=7-E3W9E<CU6:65W*"<S,S8V0T,G*2!O;D-L:6-K/5-E="@G
M,S,V-D-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2,S,SDY0T,@;VY-;W5S94]V97(]5FEE=R@G,S,Y.4-#)RD@
M;VY#;&EC:SU3970H)S,S.3E#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S-#0T-#(&]N36]U<V5/=F5R/59I
M97<H)S,S0T-#0R<I(&]N0VQI8VL]4V5T*"<S,T-#0T,G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S1D9#0R!O
M;DUO=7-E3W9E<CU6:65W*"<S,T9&0T,G*2!O;D-L:6-K/5-E="@G,S-&1D-#
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2,V-C`P0T,@;VY-;W5S94]V97(]5FEE=R@G-C8P,$-#)RD@;VY#;&EC
M:SU3970H)S8V,#!#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC-C8S,T-#(&]N36]U<V5/=F5R/59I97<H)S8V
M,S-#0R<I(&]N0VQI8VL]4V5T*"<V-C,S0T,G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V-C9#0R!O;DUO=7-E
M3W9E<CU6:65W*"<V-C8V0T,G*2!O;D-L:6-K/5-E="@G-C8V-D-#)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V
M-CDY0T,@;VY-;W5S94]V97(]5FEE=R@G-C8Y.4-#)RD@;VY#;&EC:SU3970H
M)S8V.3E#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC-C9#0T-#(&]N36]U<V5/=F5R/59I97<H)S8V0T-#0R<I
M(&]N0VQI8VL]4V5T*"<V-D-#0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V1D9#0R!O;DUO=7-E3W9E<CU6
M:65W*"<V-D9&0T,G*2!O;D-L:6-K/5-E="@G-C9&1D-#)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CPO='(^#0H\='(^#0H\=&0@8F=C
M;VQO<CTC,#`P,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI
M8VL]4V5T*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/'1D(&)G8V]L;W(](T9&1D9&1B!O;DUO=7-E3W9E<CU6:65W*"=&
M1D9&1D8G*2!O;D-L:6-K/5-E="@G1D9&1D9&)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-;W5S
M94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M,#`P,$9&(&]N36]U<V5/=F5R/59I97<H)S`P,#!&1B<I(&]N0VQI8VL]4V5T
M*"<P,#`P1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](S`P,S-&1B!O;DUO=7-E3W9E<CU6:65W*"<P,#,S1D8G
M*2!O;D-L:6-K/5-E="@G,#`S,T9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#8V1D8@;VY-;W5S94]V97(]
M5FEE=R@G,#`V-D9&)RD@;VY#;&EC:SU3970H)S`P-C9&1B<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`Y.49&
M(&]N36]U<V5/=F5R/59I97<H)S`P.3E&1B<I(&]N0VQI8VL]4V5T*"<P,#DY
M1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](S`P0T-&1B!O;DUO=7-E3W9E<CU6:65W*"<P,$-#1D8G*2!O;D-L
M:6-K/5-E="@G,#!#0T9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2,P,$9&1D8@;VY-;W5S94]V97(]5FEE=R@G
M,#!&1D9&)RD@;VY#;&EC:SU3970H)S`P1D9&1B<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,P,$9&(&]N36]U
M<V5/=F5R/59I97<H)S,S,#!&1B<I(&]N0VQI8VL]4V5T*"<S,S`P1D8G*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(S,S,S-&1B!O;DUO=7-E3W9E<CU6:65W*"<S,S,S1D8G*2!O;D-L:6-K/5-E
M="@G,S,S,T9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2,S,S8V1D8@;VY-;W5S94]V97(]5FEE=R@G,S,V-D9&
M)RD@;VY#;&EC:SU3970H)S,S-C9&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,Y.49&(&]N36]U<V5/=F5R
M/59I97<H)S,S.3E&1B<I(&]N0VQI8VL]4V5T*"<S,SDY1D8G*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S0T-&
M1B!O;DUO=7-E3W9E<CU6:65W*"<S,T-#1D8G*2!O;D-L:6-K/5-E="@G,S-#
M0T9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2,S,T9&1D8@;VY-;W5S94]V97(]5FEE=R@G,S-&1D9&)RD@;VY#
M;&EC:SU3970H)S,S1D9&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC-C8P,$9&(&]N36]U<V5/=F5R/59I97<H
M)S8V,#!&1B<I(&]N0VQI8VL]4V5T*"<V-C`P1D8G*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V,S-&1B!O;DUO
M=7-E3W9E<CU6:65W*"<V-C,S1D8G*2!O;D-L:6-K/5-E="@G-C8S,T9&)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2,V-C8V1D8@;VY-;W5S94]V97(]5FEE=R@G-C8V-D9&)RD@;VY#;&EC:SU3
M970H)S8V-C9&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC-C8Y.49&(&]N36]U<V5/=F5R/59I97<H)S8V.3E&
M1B<I(&]N0VQI8VL]4V5T*"<V-CDY1D8G*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V0T-&1B!O;DUO=7-E3W9E
M<CU6:65W*"<V-D-#1D8G*2!O;D-L:6-K/5-E="@G-C9#0T9&)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-D9&
M1D8@;VY-;W5S94]V97(]5FEE=R@G-C9&1D9&)RD@;VY#;&EC:SU3970H)S8V
M1D9&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\+W1R
M/@T*/'1R/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W
M*"<P,#`P,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&1C`P,#`@;VY-
M;W5S94]V97(]5FEE=R@G1D8P,#`P)RD@;VY#;&EC:SU3970H)T9&,#`P,"<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO
M<CTC,#`P,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]
M4V5T*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/'1D(&)G8V]L;W(](SDY,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<Y.3`P
M,#`G*2!O;D-L:6-K/5-E="@G.3DP,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3,S,#`@;VY-;W5S94]V
M97(]5FEE=R@G.3DS,S`P)RD@;VY#;&EC:SU3970H)SDY,S,P,"<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3DV
M-C`P(&]N36]U<V5/=F5R/59I97<H)SDY-C8P,"<I(&]N0VQI8VL]4V5T*"<Y
M.38V,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](SDY.3DP,"!O;DUO=7-E3W9E<CU6:65W*"<Y.3DY,#`G*2!O
M;D-L:6-K/5-E="@G.3DY.3`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.4-#,#`@;VY-;W5S94]V97(]5FEE
M=R@G.3E#0S`P)RD@;VY#;&EC:SU3970H)SDY0T,P,"<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3E&1C`P(&]N
M36]U<V5/=F5R/59I97<H)SDY1D8P,"<I(&]N0VQI8VL]4V5T*"<Y.49&,#`G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](T-#,#`P,"!O;DUO=7-E3W9E<CU6:65W*"=#0S`P,#`G*2!O;D-L:6-K
M/5-E="@G0T,P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2-#0S,S,#`@;VY-;W5S94]V97(]5FEE=R@G0T,S
M,S`P)RD@;VY#;&EC:SU3970H)T-#,S,P,"<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,V-C`P(&]N36]U<V5/
M=F5R/59I97<H)T-#-C8P,"<I(&]N0VQI8VL]4V5T*"=#0S8V,#`G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#
M.3DP,"!O;DUO=7-E3W9E<CU6:65W*"=#0SDY,#`G*2!O;D-L:6-K/5-E="@G
M0T,Y.3`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2-#0T-#,#`@;VY-;W5S94]V97(]5FEE=R@G0T-#0S`P)RD@
M;VY#;&EC:SU3970H)T-#0T,P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T-&1C`P(&]N36]U<V5/=F5R/59I
M97<H)T-#1D8P,"<I(&]N0VQI8VL]4V5T*"=#0T9&,#`G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&,#`P,"!O
M;DUO=7-E3W9E<CU6:65W*"=&1C`P,#`G*2!O;D-L:6-K/5-E="@G1D8P,#`P
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2-&1C,S,#`@;VY-;W5S94]V97(]5FEE=R@G1D8S,S`P)RD@;VY#;&EC
M:SU3970H)T9&,S,P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC1D8V-C`P(&]N36]U<V5/=F5R/59I97<H)T9&
M-C8P,"<I(&]N0VQI8VL]4V5T*"=&1C8V,#`G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&.3DP,"!O;DUO=7-E
M3W9E<CU6:65W*"=&1CDY,#`G*2!O;D-L:6-K/5-E="@G1D8Y.3`P)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&
M1D-#,#`@;VY-;W5S94]V97(]5FEE=R@G1D9#0S`P)RD@;VY#;&EC:SU3970H
M)T9&0T,P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC1D9&1C`P(&]N36]U<V5/=F5R/59I97<H)T9&1D8P,"<I
M(&]N0VQI8VL]4V5T*"=&1D9&,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/"]T<CX-"CQT<CX-"CQT9"!B9V-O;&]R/2,P,#`P,#`@
M;VY-;W5S94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P
M,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C
M;VQO<CTC,#!&1C`P(&]N36]U<V5/=F5R/59I97<H)S`P1D8P,"<I(&]N0VQI
M8VL]4V5T*"<P,$9&,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P
M,#`P,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3`P,S,@;VY-;W5S
M94]V97(]5FEE=R@G.3DP,#,S)RD@;VY#;&EC:SU3970H)SDY,#`S,R<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M.3DS,S,S(&]N36]U<V5/=F5R/59I97<H)SDY,S,S,R<I(&]N0VQI8VL]4V5T
M*"<Y.3,S,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](SDY-C8S,R!O;DUO=7-E3W9E<CU6:65W*"<Y.38V,S,G
M*2!O;D-L:6-K/5-E="@G.3DV-C,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3DY,S,@;VY-;W5S94]V97(]
M5FEE=R@G.3DY.3,S)RD@;VY#;&EC:SU3970H)SDY.3DS,R<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3E#0S,S
M(&]N36]U<V5/=F5R/59I97<H)SDY0T,S,R<I(&]N0VQI8VL]4V5T*"<Y.4-#
M,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](SDY1D8S,R!O;DUO=7-E3W9E<CU6:65W*"<Y.49&,S,G*2!O;D-L
M:6-K/5-E="@G.3E&1C,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2-#0S`P,S,@;VY-;W5S94]V97(]5FEE=R@G
M0T,P,#,S)RD@;VY#;&EC:SU3970H)T-#,#`S,R<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,S,S,S(&]N36]U
M<V5/=F5R/59I97<H)T-#,S,S,R<I(&]N0VQI8VL]4V5T*"=#0S,S,S,G*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(T-#-C8S,R!O;DUO=7-E3W9E<CU6:65W*"=#0S8V,S,G*2!O;D-L:6-K/5-E
M="@G0T,V-C,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2-#0SDY,S,@;VY-;W5S94]V97(]5FEE=R@G0T,Y.3,S
M)RD@;VY#;&EC:SU3970H)T-#.3DS,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T-#0S,S(&]N36]U<V5/=F5R
M/59I97<H)T-#0T,S,R<I(&]N0VQI8VL]4V5T*"=#0T-#,S,G*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#1D8S
M,R!O;DUO=7-E3W9E<CU6:65W*"=#0T9&,S,G*2!O;D-L:6-K/5-E="@G0T-&
M1C,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2-&1C`P,S,@;VY-;W5S94]V97(]5FEE=R@G1D8P,#,S)RD@;VY#
M;&EC:SU3970H)T9&,#`S,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D8S,S,S(&]N36]U<V5/=F5R/59I97<H
M)T9&,S,S,R<I(&]N0VQI8VL]4V5T*"=&1C,S,S,G*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&-C8S,R!O;DUO
M=7-E3W9E<CU6:65W*"=&1C8V,S,G*2!O;D-L:6-K/5-E="@G1D8V-C,S)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2-&1CDY,S,@;VY-;W5S94]V97(]5FEE=R@G1D8Y.3,S)RD@;VY#;&EC:SU3
M970H)T9&.3DS,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC1D9#0S,S(&]N36]U<V5/=F5R/59I97<H)T9&0T,S
M,R<I(&]N0VQI8VL]4V5T*"=&1D-#,S,G*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&1D8S,R!O;DUO=7-E3W9E
M<CU6:65W*"=&1D9&,S,G*2!O;D-L:6-K/5-E="@G1D9&1C,S)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CPO='(^#0H\='(^#0H\=&0@
M8F=C;VQO<CTC,#`P,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N
M0VQI8VL]4V5T*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P,#!&1B!O;DUO=7-E3W9E<CU6:65W
M*"<P,#`P1D8G*2!O;D-L:6-K/5-E="@G,#`P,$9&)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-
M;W5S94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO
M<CTC.3DP,#8V(&]N36]U<V5/=F5R/59I97<H)SDY,#`V-B<I(&]N0VQI8VL]
M4V5T*"<Y.3`P-C8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/'1D(&)G8V]L;W(](SDY,S,V-B!O;DUO=7-E3W9E<CU6:65W*"<Y.3,S
M-C8G*2!O;D-L:6-K/5-E="@G.3DS,S8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.38V-C8@;VY-;W5S94]V
M97(]5FEE=R@G.3DV-C8V)RD@;VY#;&EC:SU3970H)SDY-C8V-B<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3DY
M.38V(&]N36]U<V5/=F5R/59I97<H)SDY.3DV-B<I(&]N0VQI8VL]4V5T*"<Y
M.3DY-C8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](SDY0T,V-B!O;DUO=7-E3W9E<CU6:65W*"<Y.4-#-C8G*2!O
M;D-L:6-K/5-E="@G.3E#0S8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.49&-C8@;VY-;W5S94]V97(]5FEE
M=R@G.3E&1C8V)RD@;VY#;&EC:SU3970H)SDY1D8V-B<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,P,#8V(&]N
M36]U<V5/=F5R/59I97<H)T-#,#`V-B<I(&]N0VQI8VL]4V5T*"=#0S`P-C8G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](T-#,S,V-B!O;DUO=7-E3W9E<CU6:65W*"=#0S,S-C8G*2!O;D-L:6-K
M/5-E="@G0T,S,S8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2-#0S8V-C8@;VY-;W5S94]V97(]5FEE=R@G0T,V
M-C8V)RD@;VY#;&EC:SU3970H)T-#-C8V-B<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,Y.38V(&]N36]U<V5/
M=F5R/59I97<H)T-#.3DV-B<I(&]N0VQI8VL]4V5T*"=#0SDY-C8G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#
M0T,V-B!O;DUO=7-E3W9E<CU6:65W*"=#0T-#-C8G*2!O;D-L:6-K/5-E="@G
M0T-#0S8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2-#0T9&-C8@;VY-;W5S94]V97(]5FEE=R@G0T-&1C8V)RD@
M;VY#;&EC:SU3970H)T-#1D8V-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D8P,#8V(&]N36]U<V5/=F5R/59I
M97<H)T9&,#`V-B<I(&]N0VQI8VL]4V5T*"=&1C`P-C8G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&,S,V-B!O
M;DUO=7-E3W9E<CU6:65W*"=&1C,S-C8G*2!O;D-L:6-K/5-E="@G1D8S,S8V
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2-&1C8V-C8@;VY-;W5S94]V97(]5FEE=R@G1D8V-C8V)RD@;VY#;&EC
M:SU3970H)T9&-C8V-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC1D8Y.38V(&]N36]U<V5/=F5R/59I97<H)T9&
M.3DV-B<I(&]N0VQI8VL]4V5T*"=&1CDY-C8G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&0T,V-B!O;DUO=7-E
M3W9E<CU6:65W*"=&1D-#-C8G*2!O;D-L:6-K/5-E="@G1D9#0S8V)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&
M1D9&-C8@;VY-;W5S94]V97(]5FEE=R@G1D9&1C8V)RD@;VY#;&EC:SU3970H
M)T9&1D8V-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M+W1R/@T*/'1R/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6
M:65W*"<P,#`P,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&1D9&,#`@
M;VY-;W5S94]V97(]5FEE=R@G1D9&1C`P)RD@;VY#;&EC:SU3970H)T9&1D8P
M,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C
M;VQO<CTC,#`P,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI
M8VL]4V5T*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/'1D(&)G8V]L;W(](SDY,#`Y.2!O;DUO=7-E3W9E<CU6:65W*"<Y
M.3`P.3DG*2!O;D-L:6-K/5-E="@G.3DP,#DY)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3,S.3D@;VY-;W5S
M94]V97(]5FEE=R@G.3DS,SDY)RD@;VY#;&EC:SU3970H)SDY,S,Y.2<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M.3DV-CDY(&]N36]U<V5/=F5R/59I97<H)SDY-C8Y.2<I(&]N0VQI8VL]4V5T
M*"<Y.38V.3DG*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](SDY.3DY.2!O;DUO=7-E3W9E<CU6:65W*"<Y.3DY.3DG
M*2!O;D-L:6-K/5-E="@G.3DY.3DY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.4-#.3D@;VY-;W5S94]V97(]
M5FEE=R@G.3E#0SDY)RD@;VY#;&EC:SU3970H)SDY0T,Y.2<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3E&1CDY
M(&]N36]U<V5/=F5R/59I97<H)SDY1D8Y.2<I(&]N0VQI8VL]4V5T*"<Y.49&
M.3DG*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](T-#,#`Y.2!O;DUO=7-E3W9E<CU6:65W*"=#0S`P.3DG*2!O;D-L
M:6-K/5-E="@G0T,P,#DY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2-#0S,S.3D@;VY-;W5S94]V97(]5FEE=R@G
M0T,S,SDY)RD@;VY#;&EC:SU3970H)T-#,S,Y.2<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,V-CDY(&]N36]U
M<V5/=F5R/59I97<H)T-#-C8Y.2<I(&]N0VQI8VL]4V5T*"=#0S8V.3DG*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(T-#.3DY.2!O;DUO=7-E3W9E<CU6:65W*"=#0SDY.3DG*2!O;D-L:6-K/5-E
M="@G0T,Y.3DY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2-#0T-#.3D@;VY-;W5S94]V97(]5FEE=R@G0T-#0SDY
M)RD@;VY#;&EC:SU3970H)T-#0T,Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T-&1CDY(&]N36]U<V5/=F5R
M/59I97<H)T-#1D8Y.2<I(&]N0VQI8VL]4V5T*"=#0T9&.3DG*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&,#`Y
M.2!O;DUO=7-E3W9E<CU6:65W*"=&1C`P.3DG*2!O;D-L:6-K/5-E="@G1D8P
M,#DY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2-&1C,S.3D@;VY-;W5S94]V97(]5FEE=R@G1D8S,SDY)RD@;VY#
M;&EC:SU3970H)T9&,S,Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D8V-CDY(&]N36]U<V5/=F5R/59I97<H
M)T9&-C8Y.2<I(&]N0VQI8VL]4V5T*"=&1C8V.3DG*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&.3DY.2!O;DUO
M=7-E3W9E<CU6:65W*"=&1CDY.3DG*2!O;D-L:6-K/5-E="@G1D8Y.3DY)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2-&1D-#.3D@;VY-;W5S94]V97(]5FEE=R@G1D9#0SDY)RD@;VY#;&EC:SU3
M970H)T9&0T,Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC1D9&1CDY(&]N36]U<V5/=F5R/59I97<H)T9&1D8Y
M.2<I(&]N0VQI8VL]4V5T*"=&1D9&.3DG*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/"]T<CX-"CQT<CX-"CQT9"!B9V-O;&]R/2,P,#`P
M,#`@;VY-;W5S94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P
M,#`P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@
M8F=C;VQO<CTC,#!&1D9&(&]N36]U<V5/=F5R/59I97<H)S`P1D9&1B<I(&]N
M0VQI8VL]4V5T*"<P,$9&1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W
M*"<P,#`P,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3`P0T,@;VY-
M;W5S94]V97(]5FEE=R@G.3DP,$-#)RD@;VY#;&EC:SU3970H)SDY,#!#0R<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO
M<CTC.3DS,T-#(&]N36]U<V5/=F5R/59I97<H)SDY,S-#0R<I(&]N0VQI8VL]
M4V5T*"<Y.3,S0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/'1D(&)G8V]L;W(](SDY-C9#0R!O;DUO=7-E3W9E<CU6:65W*"<Y.38V
M0T,G*2!O;D-L:6-K/5-E="@G.3DV-D-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3DY0T,@;VY-;W5S94]V
M97(]5FEE=R@G.3DY.4-#)RD@;VY#;&EC:SU3970H)SDY.3E#0R<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3E#
M0T-#(&]N36]U<V5/=F5R/59I97<H)SDY0T-#0R<I(&]N0VQI8VL]4V5T*"<Y
M.4-#0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](SDY1D9#0R!O;DUO=7-E3W9E<CU6:65W*"<Y.49&0T,G*2!O
M;D-L:6-K/5-E="@G.3E&1D-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-#0S`P0T,@;VY-;W5S94]V97(]5FEE
M=R@G0T,P,$-#)RD@;VY#;&EC:SU3970H)T-#,#!#0R<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,S,T-#(&]N
M36]U<V5/=F5R/59I97<H)T-#,S-#0R<I(&]N0VQI8VL]4V5T*"=#0S,S0T,G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](T-#-C9#0R!O;DUO=7-E3W9E<CU6:65W*"=#0S8V0T,G*2!O;D-L:6-K
M/5-E="@G0T,V-D-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2-#0SDY0T,@;VY-;W5S94]V97(]5FEE=R@G0T,Y
M.4-#)RD@;VY#;&EC:SU3970H)T-#.3E#0R<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T-#0T-#(&]N36]U<V5/
M=F5R/59I97<H)T-#0T-#0R<I(&]N0VQI8VL]4V5T*"=#0T-#0T,G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#
M1D9#0R!O;DUO=7-E3W9E<CU6:65W*"=#0T9&0T,G*2!O;D-L:6-K/5-E="@G
M0T-&1D-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2-&1C`P0T,@;VY-;W5S94]V97(]5FEE=R@G1D8P,$-#)RD@
M;VY#;&EC:SU3970H)T9&,#!#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D8S,T-#(&]N36]U<V5/=F5R/59I
M97<H)T9&,S-#0R<I(&]N0VQI8VL]4V5T*"=&1C,S0T,G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&-C9#0R!O
M;DUO=7-E3W9E<CU6:65W*"=&1C8V0T,G*2!O;D-L:6-K/5-E="@G1D8V-D-#
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2-&1CDY0T,@;VY-;W5S94]V97(]5FEE=R@G1D8Y.4-#)RD@;VY#;&EC
M:SU3970H)T9&.3E#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC1D9#0T-#(&]N36]U<V5/=F5R/59I97<H)T9&
M0T-#0R<I(&]N0VQI8VL]4V5T*"=&1D-#0T,G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&1D9#0R!O;DUO=7-E
M3W9E<CU6:65W*"=&1D9&0T,G*2!O;D-L:6-K/5-E="@G1D9&1D-#)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CPO='(^#0H\='(^#0H\
M=&0@8F=C;VQO<CTC,#`P,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I
M(&]N0VQI8VL]4V5T*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&,#!&1B!O;DUO=7-E3W9E<CU6
M:65W*"=&1C`P1D8G*2!O;D-L:6-K/5-E="@G1D8P,$9&)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P,#`@
M;VY-;W5S94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P
M,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C
M;VQO<CTC.3DP,$9&(&]N36]U<V5/=F5R/59I97<H)SDY,#!&1B<I(&]N0VQI
M8VL]4V5T*"<Y.3`P1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/'1D(&)G8V]L;W(](SDY,S-&1B!O;DUO=7-E3W9E<CU6:65W*"<Y
M.3,S1D8G*2!O;D-L:6-K/5-E="@G.3DS,T9&)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.38V1D8@;VY-;W5S
M94]V97(]5FEE=R@G.3DV-D9&)RD@;VY#;&EC:SU3970H)SDY-C9&1B<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M.3DY.49&(&]N36]U<V5/=F5R/59I97<H)SDY.3E&1B<I(&]N0VQI8VL]4V5T
M*"<Y.3DY1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](SDY0T-&1B!O;DUO=7-E3W9E<CU6:65W*"<Y.4-#1D8G
M*2!O;D-L:6-K/5-E="@G.3E#0T9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.49&1D8@;VY-;W5S94]V97(]
M5FEE=R@G.3E&1D9&)RD@;VY#;&EC:SU3970H)SDY1D9&1B<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,P,$9&
M(&]N36]U<V5/=F5R/59I97<H)T-#,#!&1B<I(&]N0VQI8VL]4V5T*"=#0S`P
M1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](T-#,S-&1B!O;DUO=7-E3W9E<CU6:65W*"=#0S,S1D8G*2!O;D-L
M:6-K/5-E="@G0T,S,T9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2-#0S8V1D8@;VY-;W5S94]V97(]5FEE=R@G
M0T,V-D9&)RD@;VY#;&EC:SU3970H)T-#-C9&1B<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,Y.49&(&]N36]U
M<V5/=F5R/59I97<H)T-#.3E&1B<I(&]N0VQI8VL]4V5T*"=#0SDY1D8G*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(T-#0T-&1B!O;DUO=7-E3W9E<CU6:65W*"=#0T-#1D8G*2!O;D-L:6-K/5-E
M="@G0T-#0T9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2-#0T9&1D8@;VY-;W5S94]V97(]5FEE=R@G0T-&1D9&
M)RD@;VY#;&EC:SU3970H)T-#1D9&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D8P,$9&(&]N36]U<V5/=F5R
M/59I97<H)T9&,#!&1B<I(&]N0VQI8VL]4V5T*"=&1C`P1D8G*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&,S-&
M1B!O;DUO=7-E3W9E<CU6:65W*"=&1C,S1D8G*2!O;D-L:6-K/5-E="@G1D8S
M,T9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2-&1C8V1D8@;VY-;W5S94]V97(]5FEE=R@G1D8V-D9&)RD@;VY#
M;&EC:SU3970H)T9&-C9&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D8Y.49&(&]N36]U<V5/=F5R/59I97<H
M)T9&.3E&1B<I(&]N0VQI8VL]4V5T*"=&1CDY1D8G*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&0T-&1B!O;DUO
M=7-E3W9E<CU6:65W*"=&1D-#1D8G*2!O;D-L:6-K/5-E="@G1D9#0T9&)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2-&1D9&1D8@;VY-;W5S94]V97(]5FEE=R@G1D9&1D9&)RD@;VY#;&EC:SU3
M970H)T9&1D9&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\+W1R/@T*/"]T86)L93X-"@T*/"]B;V1Y/CPO:'1M;#X-"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT
M;6QA<F5A+W!O<'5P=VEN+FIS````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S,U
M,P`Q,#4Q-30S,S<U-P`P,C4P,3<`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+R\@*&,I(&1Y;F%R8V@N8V]M(#(P,#,M,C`P
M-0HO+R!$:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!T97)M<R!A<R!(5$U,
M07)E82!I='-E;&8N"@IF=6YC=&EO;B!0;W!U<%=I;BAE9&ET;W(L('1I=&QE
M+"!H86YD;&5R+"!I;FET1G5N8W1I;VXI('L*"71H:7,N961I=&]R(#T@961I
M=&]R.PH)=&AI<RYH86YD;&5R(#T@:&%N9&QE<CL*"79A<B!D;&<@/2!W:6YD
M;W<N;W!E;B@B(BP@(E]?:&%?9&EA;&]G(BP*"0D)("`@("`@(G1O;VQB87(]
M;F\L;65N=6)A<CUN;RQP97)S;VYA;&)A<CUN;RQW:61T:#TV,#`L:&5I9VAT
M/38P,"QL969T/3(P+'1O<#TT,"(@*PH)"0D@("`@("`B<V-R;VQL8F%R<SUN
M;RQR97-I>F%B;&4];F\B*3L*"71H:7,N=VEN9&]W(#T@9&QG.PH)=F%R(&1O
M8R`](&1L9RYD;V-U;65N=#L*"71H:7,N9&]C(#T@9&]C.PH)=F%R('-E;&8@
M/2!T:&ES.PH*"79A<B!B87-E(#T@9&]C=6UE;G0N8F%S955222!\?"!D;V-U
M;65N="Y54DP["@EI9B`H8F%S92`F)B!B87-E+FUA=&-H*"\H+BHI7"\H6UY<
M+UTK*2\I*2!["@D)8F%S92`](%)E9T5X<"XD,2`K("(O(CL*"7T*"6EF("AT
M>7!E;V8@7V5D:71O<E]U<FP@(3T@(G5N9&5F:6YE9"(@)B8@(2]>7"\O+G1E
M<W0H7V5D:71O<E]U<FPI("8F("$O:'1T<#I<+UPO+RYT97-T*%]E9&ET;W)?
M=7)L*2D@>PH)"2\O(%]E9&ET;W)?=7)L(&1O97-N)W0@<W1A<G0@=VET:"`G
M+R<@=VAI8V@@;65A;G,@:70G<R!R96QA=&EV90H)"2\O($9)6$U%.B!T:&5R
M92=S(&$@<')O8FQE;2!H97)E+"!I="!C;W5L9"!B92!H='1P.B\O('=H:6-H
M"@D)+R\@9&]E<VXG="!S=&%R="!W:71H('-L87-H(&)U="!I="=S(&YO="!R
M96QA=&EV92!E:71H97(N"@D)8F%S92`K/2!?961I=&]R7W5R;#L*"7T@96QS
M90H)"6)A<V4@/2!?961I=&]R7W5R;#L*"6EF("@A+UPO)"\N=&5S="AB87-E
M*2D@>PH)"2\O(&)A<V4@9&]E<R!N;W0@96YD(&EN('-L87-H+"!A9&0@:70@
M;F]W"@D)8F%S92`K/2`G+R<["@E]"@ET:&ES+F)A<V554DP@/2!B87-E.PH*
M"61O8RYO<&5N*"D["@EV87(@:'1M;"`]("(\:'1M;#X\:&5A9#X\=&ET;&4^
M(B`K('1I=&QE("L@(CPO=&ET;&4^7&XB.PH)+R\@:'1M;"`K/2`B/&)A<V4@
M:')E9CTG(B`K(&)A<V4@*R`B:'1M;&%R96$N:G,G("\^7&XB.PH):'1M;"`K
M/2`B/'-T>6QE('1Y<&4])W1E>'0O8W-S)SY`:6UP;W)T('5R;"@B("L@8F%S
M92`K(")H=&UL87)E82YC<W,I.SPO<W1Y;&4^/"]H96%D/EQN(CL*"6AT;6P@
M*ST@(CQB;V1Y(&-L87-S/2=D:6%L;V<@<&]P=7!W:6XG(&ED/2<M+4A!+6)O
M9'DG/CPO8F]D>3X\+VAT;6P^(CL*"61O8RYW<FET92AH=&UL*3L*"61O8RYC
M;&]S92@I.PH*"2\O('-O;65T:6UE<R!)($AA=&4@36]Z:6QL82XN+B`[+2@*
M"69U;F-T:6]N(&EN:70R*"D@>PH)"79A<B!B;V1Y(#T@9&]C+F)O9'D["@D)
M:68@*"%B;V1Y*2!["@D)"7-E=%1I;65O=70H:6YI=#(L(#(U*3L*"0D)<F5T
M=7)N(&9A;'-E.PH)"7T*"0ED;&<N=&ET;&4@/2!T:71L93L*"0ED;V,N9&]C
M=6UE;G1%;&5M96YT+G-T>6QE+G!A9&1I;F<@/2`B,'!X(CL*"0ED;V,N9&]C
M=6UE;G1%;&5M96YT+G-T>6QE+FUA<F=I;B`]("(P<'@B.PH)"79A<B!C;VYT
M96YT(#T@9&]C+F-R96%T945L96UE;G0H(F1I=B(I.PH)"6-O;G1E;G0N8VQA
M<W-.86UE(#T@(F-O;G1E;G0B.PH)"7-E;&8N8V]N=&5N="`](&-O;G1E;G0[
M"@D)8F]D>2YA<'!E;F1#:&EL9"AC;VYT96YT*3L*"0ES96QF+F5L96UE;G0@
M/2!B;V1Y.PH)"6EN:71&=6YC=&EO;BAS96QF*3L*"0ED;&<N9F]C=7,H*3L*
M"7T["@EI;FET,B@I.PI].PH*4&]P=7!7:6XN<')O=&]T>7!E+F-A;&Q(86YD
M;&5R(#T@9G5N8W1I;VXH*2!["@EV87(@=&%G<R`](%LB:6YP=70B+"`B=&5X
M=&%R96$B+"`B<V5L96-T(ET["@EV87(@<&%R86US(#T@;F5W($]B:F5C="@I
M.PH)9F]R("AV87(@=&D@/2!T86=S+FQE;F=T:#L@+2UT:2`^/2`P.RD@>PH)
M"79A<B!T86<@/2!T86=S6W1I73L*"0EV87(@96QS(#T@=&AI<RYC;VYT96YT
M+F=E=$5L96UE;G1S0GE486=.86UE*'1A9RD["@D)9F]R("AV87(@:B`](#`[
M(&H@/"!E;',N;&5N9W1H.R`K*VHI('L*"0D)=F%R(&5L(#T@96QS6VI=.PH)
M"0EV87(@=F%L(#T@96PN=F%L=64["@D)"6EF("AE;"YT86=.86UE+G1O3&]W
M97)#87-E*"D@/3T@(FEN<'5T(BD@>PH)"0D):68@*&5L+G1Y<&4@/3T@(F-H
M96-K8F]X(BD@>PH)"0D)"79A;"`](&5L+F-H96-K960["@D)"0E]"@D)"7T*
M"0D)<&%R86US6V5L+FYA;65=(#T@=F%L.PH)"7T*"7T*"71H:7,N:&%N9&QE
M<BAT:&ES+"!P87)A;7,I.PH)<F5T=7)N(&9A;'-E.PI].PH*4&]P=7!7:6XN
M<')O=&]T>7!E+F-L;W-E(#T@9G5N8W1I;VXH*2!["@ET:&ES+G=I;F1O=RYC
M;&]S92@I.PI].PH*4&]P=7!7:6XN<')O=&]T>7!E+F%D9$)U='1O;G,@/2!F
M=6YC=&EO;B@I('L*"79A<B!S96QF(#T@=&AI<SL*"79A<B!D:78@/2!T:&ES
M+F1O8RYC<F5A=&5%;&5M96YT*")D:78B*3L*"71H:7,N8V]N=&5N="YA<'!E
M;F1#:&EL9"AD:78I.PH)9&EV+F-L87-S3F%M92`](")B=71T;VYS(CL*"69O
M<B`H=F%R(&D@/2`P.R!I(#P@87)G=6UE;G1S+FQE;F=T:#L@*RMI*2!["@D)
M=F%R(&)T;B`](&%R9W5M96YT<UMI73L*"0EV87(@8G5T=&]N(#T@=&AI<RYD
M;V,N8W)E871E16QE;65N="@B8G5T=&]N(BD["@D)9&EV+F%P<&5N9$-H:6QD
M*&)U='1O;BD["@D)8G5T=&]N+FEN;F5R2%1-3"`]($A434Q!<F5A+DDQ.$XN
M8G5T=&]N<UMB=&Y=.PH)"7-W:71C:"`H8G1N*2!["@D)("`@(&-A<V4@(F]K
M(CH*"0D)8G5T=&]N+F]N8VQI8VL@/2!F=6YC=&EO;B@I('L*"0D)"7-E;&8N
M8V%L;$AA;F1L97(H*3L*"0D)"7-E;&8N8VQO<V4H*3L*"0D)"7)E='5R;B!F
M86QS93L*"0D)?3L*"0D)8G)E86L["@D)("`@(&-A<V4@(F-A;F-E;"(Z"@D)
M"6)U='1O;BYO;F-L:6-K(#T@9G5N8W1I;VXH*2!["@D)"0ES96QF+F-L;W-E
M*"D["@D)"0ER971U<FX@9F%L<V4["@D)"7T["@D)"6)R96%K.PH)"7T*"7T*
M?3L*"E!O<'5P5VEN+G!R;W1O='EP92YS:&]W071%;&5M96YT(#T@9G5N8W1I
M;VXH*2!["@EV87(@<V5L9B`]('1H:7,["@DO+R!-;WII;&QA(&YE961S('-O
M;64@=&EM92!T;R!R96%L:7IE('=H870G<R!G;VEN)R!O;BXN"@ES9714:6UE
M;W5T*&9U;F-T:6]N*"D@>PH)"79A<B!W(#T@<V5L9BYC;VYT96YT+F]F9G-E
M=%=I9'1H("L@-#L*"0EV87(@:"`]('-E;&8N8V]N=&5N="YO9F9S971(96EG
M:'0@*R`T.PH)"2\O('-I>F4@=&\@8V]N=&5N="`M+2!T:&%T)W,@9G5C:VEN
M)R!B=6=G>2!I;B!A;&P@9G5C:VEN)R!B<F]W<V5R<R$A(0H)"2\O('-O('1H
M870@=V4@<V5T(&$@;&%R9V5R('-I>F4@9F]R('1H92!D:6%L;V<@=VEN9&]W
M(&%N9"!T:&5N(&-E;G1E<@H)"2\O('1H92!E;&5M96YT(&EN<VED92XN+B!P
M:'5C:R$*"@D)+R\@8V5N=&5R+BXN"@D)=F%R(&5L(#T@<V5L9BYC;VYT96YT
M.PH)"79A<B!S(#T@96PN<W1Y;&4["@D)+R\@<RYW:61T:"`](&5L+F]F9G-E
M=%=I9'1H("L@(G!X(CL*"0DO+R!S+FAE:6=H="`](&5L+F]F9G-E=$AE:6=H
M="`K(")P>"(["@D)<RYP;W-I=&EO;B`](")A8G-O;'5T92(["@D)<RYL969T
M(#T@*'<@+2!E;"YO9F9S9717:61T:"D@+R`R("L@(G!X(CL*"0ES+G1O<"`]
M("AH("T@96PN;V9F<V5T2&5I9VAT*2`O(#(@*R`B<'@B.PH)"6EF("A(5$U,
M07)E82YI<U]G96-K;RD@>PH)"0ES96QF+G=I;F1O=RYI;FYE<E=I9'1H(#T@
M=SL*"0D)<V5L9BYW:6YD;W<N:6YN97)(96EG:'0@/2!H.PH)"7T@96QS92![
M"@D)"7-E;&8N=VEN9&]W+G)E<VEZ951O*'<@*R`X+"!H("L@,S4I.PH)"7T*
M"7TL(#(U*3L*?3L*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<V5R=FEC97,O9V\N<&AP````````````````````````````````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P-38U,``Q,#4Q-30S,S<U-P`P,C`V,S$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J($$@<V-R:7!T('1O(')E9&ER96-T('1O(&$@9VEV96X@55),+"!U<V5D
M(&9O<B!E>&%M<&QE(&EN($E-4"!T;R!H:61E(&%N>0H@*B!R969E<G)E<B!D
M871A(&)E:6YG('!A<W-E9"!T;R!T:&4@<F5M;W1E('-E<G9E<B!A;F0@<&]T
M96YT:6%L;'D@97AP;W-I;F<*("H@86YY('-E<W-I;VX@241S+@H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC
M;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+W-E<G9I8V5S
M+V=O+G!H<"QV(#$N-BXR+C$V(#(P,#8O,#8O,C(@,#(Z-#,Z,C0@8VAU8VL@
M17AP("0*("H*("H@0&%U=&AO<B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N
M8V]M/@H@*B\*"FEF("AE;7!T>2@D7T=%5%LG=7)L)UTI*2!["B`@("!E>&ET
M.PI]"@HD=7)L(#T@=')I;2@D7T=%5%LG=7)L)UTI.PII9B`H<')E9U]M871C
M:"@G+SM<<RIU<FQ<<RH]+VDG+"`D=7)L*2D@>PH@("`@+RH@244@=VEL;"!P
M<F]C97-S('1H92!L87-T(#M54DP]('-T<FEN9RP@;F]T('1H92!F:7)S="P@
M86QL;W=I;F<*("`@("`J('!R;W1O8V]L<R!T:&%T('-H;W5L9&XG="!B92!L
M970@=&AR;W5G:"X@*B\*("`@(&5X:70["GT*"FEF("AG971?;6%G:6-?<75O
M=&5S7V=P8R@I*2!["B`@("`D<&%R<V5D7W5R;"`]($!P87)S95]U<FPH<W1R
M:7!S;&%S:&5S*"1U<FPI*3L*?2!E;'-E('L*("`@("1P87)S961?=7)L(#T@
M0'!A<G-E7W5R;"@D=7)L*3L*?0H*:68@*&5M<'1Y*"1P87)S961?=7)L*2!\
M?"!E;7!T>2@D<&%R<V5D7W5R;%LG:&]S="==*2D@>PH@("`@97AI=#L*?0II
M9B`H96UP='DH)'!A<G-E9%]U<FQ;)W!A=&@G72DI('L*("`@("1P87)S961?
M=7)L6R=P871H)UT@/2!F86QS93L*?0H*+R\@1&\@82!L:71T;&4@9'5E(&1I
M;&EG96YC92!O;B!T:&4@=&%R9V5T(%523"X@268@:70G<R!O;B!T:&4@<V%M
M92!S97)V97(*+R\@=&AA="!W92=R92!A;')E861Y(&]N+"!D:7-P;&%Y(&%N
M(&EN=&5R;65D:6%T92!P86=E(&%S:VEN9R!P96]P;&4@:68*+R\@=&AE>2=R
M92!S=7)E('1H97D@=V%N="!T;R!C;&EC:R!T:')O=6=H+@II9B`H<W5B<W1R
M*'!H<%]S87!I7VYA;64H*2P@,"P@,RD@/3T@)V-G:2<I('L*("`@("\O(%=H
M96X@=7-I;F<@0T=)(%!(4"P@4T-225!47TY!344@;6%Y(&-O;G1A:6X@=&AE
M('!A=&@@=&\@=&AE(%!(4"!B:6YA<GD*("`@("\O(&EN<W1E860@;V8@=&AE
M('-C<FEP="!B96EN9R!R=6X[('5S92!02%!?4T5,1B!I;G-T96%D+@H@("`@
M)&UY=7)L(#T@)%]315)615);)U!(4%]314Q&)UT["GT@96QS92!["B`@("`D
M;7EU<FP@/2!I<W-E="@D7U-%4E9%4ELG4T-225!47TY!344G72D@/PH@("`@
M("`@("1?4T525D526R=30U))4%1?3D%-12==(#H*("`@("`@("`D7U-%4E9%
M4ELG4$A07U-%3$8G73L*?0HO+R`Q-B!I<R!T:&4@;&5N9W1H(&]F("(O<V5R
M=FEC97,O9V\N<&AP(BX*)'=E8G)O;W0@/2!S=6)S='(H)&UY=7)L+"`P+"`M
M,38I.PH*+R\@0G5I;&0@82!L:7-T(&]F(&AO<W1S(&-O;G-I9&5R960@9&%N
M9V5R;W5S("AL;V-A;"!H;W-T<RP@=&AE('5S97(G<PHO+R!H;W-T+"!E=&,I
M+@HD9&%N9V5R;W5S7VAO<W1S(#T@87)R87DH)VQO8V%L:&]S="<L("=L;V-A
M;&AO<W0N;&]C86QD;VUA:6XG+"`G,3(W+C`N,"XQ)RD["FEF("@A96UP='DH
M)%]315)615);)U-%4E9%4E].04U%)UTI*2!["B`@("`D9&%N9V5R;W5S7VAO
M<W1S6UT@/2`D7U-%4E9%4ELG4T525D527TY!344G73L*?0II9B`H(65M<'1Y
M*"1?4T525D526R=(5%107TA/4U0G72DI('L*("`@("1D86YG97)O=7-?:&]S
M='-;72`]("1?4T525D526R=(5%107TA/4U0G73L*?0H*+R\@3&ES="!O9B!A
M;&QO=V5D('-E<G9I8V5S+@HD86QL;W=E9%]U<FES(#T@87)R87DH*3L*"B\O
M($-H96-K(&%G86EN<W0@;W5R(&QI<W1S+@II9B`H*&5M<'1Y*"1W96)R;V]T
M*2!\?"!S=')P;W,H)'!A<G-E9%]U<FQ;)W!A=&@G72P@)'=E8G)O;W0I(#T]
M/2`P*2`F)@H@("`@(65M<'1Y*"1P87)S961?=7)L6R=Q=65R>2==*2`F)@H@
M("`@(6EN7V%R<F%Y*"1P87)S961?=7)L6R=P871H)UTL("1A;&QO=V5D7W5R
M:7,I("8F"B`@("!I;E]A<G)A>2@D<&%R<V5D7W5R;%LG:&]S="==+"`D9&%N
M9V5R;W5S7VAO<W1S*2D@>PH_/@H\:'1M;#X*/&AE860^"CQT:71L93Y0;W1E
M;G1I86QL>2!$86YG97)O=7,@55),/"]T:71L93X*/"]H96%D/@H\8F]D>3X*
M(#QH,3Y0;W1E;G1I86QL>2!$86YG97)O=7,@55),/"]H,3X*"B`\<#X*("!!
M(')E9F5R<FEN9R!S:71E+"!A;B!E;6%I;"!Y;W4@=V5R92!R96%D:6YG+"!O
M<B!S;VUE(&]T:&5R"B`@<&]T96YT:6%L;'D@=6YT<G5S=&5D('-O=7)C92!H
M87,@871T96UP=&5D('1O('-E;F0@>6]U('1O(#P_<&AP(&5C:&\*("!H=&UL
M<W!E8VEA;&-H87)S*"1U<FPI(#\^+B!4:&ES(&UA>2!B92!A;B!A='1E;7!T
M('1O"B`@9&5L971E(&1A=&$@;W(@8VAA;F=E('-E='1I;F=S('=I=&AO=70@
M>6]U<B!K;F]W;&5D9V4N($EF"B`@>6]U(&AA=F4@86YY(&-O;F-E<FYS(&%B
M;W5T('1H:7,@55),+"!P;&5A<V4@8V]N=&%C="!Y;W5R"B`@4WES=&5M($%D
M;6EN:7-T<F%T;W(N($EF('EO=2!A<F4@8V]N9FED96YT('1H870@:70@:7,@
M<V%F92P*("!Y;W4@;6%Y(&9O;&QO=R!T:&4@;&EN:R!B>2!C;&EC:VEN9R!B
M96QO=RX*(#PO<#X*"B`\<#X*("`\82!H<F5F/2(\/W!H<"!E8VAO(&AT;6QS
M<&5C:6%L8VAA<G,H)'5R;"D@/SXB/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<R@D=7)L*2`_/CPO83X*(#PO<#X*"CPO8F]D>3X*/"]H=&UL/@H\/W!H
M<`H@("`@97AI=#L*?0H*:&5A9&5R*"=2969R97-H.B`P.R!54DP])R`N("1U
M<FPI.PH`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]H96QP+P``
M````````````````````````````````````````````````````````````
M`````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-3$U-#,S-S4W`#`R,#0S-0`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W-E<G9I8V5S+VAE;'`O:6YD97@N<&AP````````````````````````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#8U-#4`,3`U,34T,S,W-3<`,#(R,C8W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B`D2&]R9&4Z(&AO<F1E+W-E<G9I8V5S+VAE;'`O:6YD97@N<&AP+'8@
M,BXX,"XQ,"XY(#(P,#8O,#<O,#8@,C(Z,C@Z,#(@8VAU8VL@17AP("0*("H*
M("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@
M9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+RXN)RD["D!D969I;F4H)T%55$A?
M2$%.1$Q%4B<L('1R=64I.PH*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G
M+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O2&5L<"YP:'`G
M.PH*)'1I=&QE(#T@7R@B2&5L<"(I.PHD<VAO=R`](%-T<FEN9SHZ;&]W97(H
M571I;#HZ9V5T1F]R;41A=&$H)W-H;W<G+"`G:6YD97@G*2D["B1M;V1U;&4@
M/2!3=')I;F<Z.FQO=V5R*'!R96=?<F5P;&%C92@G+UQ7+R<L("<G+"!5=&EL
M.CIG971&;W)M1&%T82@G;6]D=6QE)RP@)VAO<F1E)RDI*3L*)'1O<&EC(#T@
M571I;#HZ9V5T1F]R;41A=&$H)W1O<&EC)RD["@II9B`H)&UO9'5L92`]/2`G
M861M:6XG*2!["B`@("`D9FEL97)O;W0@/2`D<F5G:7-T<GDM/F=E="@G9FEL
M97)O;W0G*3L*("`@("1H96QP7V9I;&4@/2`D9FEL97)O;W0@+B`B+V%D;6EN
M+VQO8V%L92\D;&%N9W5A9V4O:&5L<"YX;6PB.PH@("`@)&AE;'!?9FEL95]F
M86QL8F%C:R`]("1F:6QE<F]O="`N("<O861M:6XO;&]C86QE+V5N7U53+VAE
M;'`N>&UL)SL*?2!E;'-E('L*("`@("1F:6QE<F]O="`]("1R96=I<W1R>2T^
M9V5T*"=F:6QE<F]O="<L("1M;V1U;&4I.PH@("`@)&AE;'!?9FEL92`]("1F
M:6QE<F]O="`N("(O;&]C86QE+R1L86YG=6%G92]H96QP+GAM;"(["B`@("`D
M:&5L<%]F:6QE7V9A;&QB86-K(#T@)&9I;&5R;V]T("X@)R]L;V-A;&4O96Y?
M55,O:&5L<"YX;6PG.PI]"@II9B`H)'-H;W<@/3T@)VEN9&5X)RD@>PH@("`@
M)&)A<V5?=7)L(#T@)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G
M*2`N("<O<V5R=FEC97,O:&5L<"\G.PH@("`@)&UA:6Y?=7)L(#T@2&]R9&4Z
M.G5R;"@D8F%S95]U<FPI.PH@("`@)&UA:6Y?=7)L(#T@571I;#HZ861D4&%R
M86UE=&5R*"1M86EN7W5R;"P@87)R87DH)W-H;W<G(#T^("=E;G1R>2<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G;6]D=6QE)R`]/B`D;6]D=6QE+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1O<&EC)R`]/B`D
M=&]P:6,I*3L*("`@("1M96YU7W5R;"`]($AO<F1E.CIU<FPH)&)A<V5?=7)L
M*3L*("`@("1M96YU7W5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D;65N=5]U
M<FPL(&%R<F%Y*"=M;V1U;&4G(#T^("1M;V1U;&4L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<VAO=R<@
M/3X@)VUE;G4G*2D["B`@("!R97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O
M:&5L<"]I;F1E>"YI;F,G.PH@("`@97AI=#L*?0H*)&)O9'E#;&%S<R`]("=H
M96QP)SL*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUH96%D
M97(N:6YC)SL*:68@*"1S:&]W(#T]("=M96YU)RD@>PH@("`@+RH@4V5T('5P
M('5R;',N("HO"B`@("`D=7)L(#T@2&]R9&4Z.G5R;"@D<F5G:7-T<GDM/F=E
M="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]S97)V:6-E<R]H96QP+R<I.PH@
M("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G;6]D=6QE)RP@
M)&UO9'5L92D["B`@("`D=&]P:6-S7VQI;FL@/2!5=&EL.CIA9&1087)A;65T
M97(H)'5R;"P@)W-H;W<G+"`G=&]P:6-S)RD["B`@("`D=&]P:6-S7VQI;FL@
M/2!(;W)D93HZ;&EN:R@D=&]P:6-S7VQI;FLL(&YU;&PL("=H96%D97(G+"`G
M:&5L<%]M86EN)RD@+B!?*"),:7-T($AE;'`@5&]P:6-S(BD@+B`G/"]A/B<[
M"B`@("`D86)O=71?;&EN:R`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G
M<VAO=R<L("=A8F]U="<I.PH@("`@)&%B;W5T7VQI;FL@/2!(;W)D93HZ;&EN
M:R@D86)O=71?;&EN:RP@;G5L;"P@)VAE861E<B<L("=H96QP7VUA:6XG*2`N
M(%\H(D%B;W5T+BXN(BD@+B`G/"]A/B<["B`@("!R97%U:7)E($A/4D1%7U1%
M35!,051%4R`N("<O:&5L<"]M96YU+FEN8R<["GT@96QS96EF("@D<VAO=R`]
M/2`G86)O=70G*2!["B`@("!R97%U:7)E("1F:6QE<F]O="`N("<O;&EB+W9E
M<G-I;VXN<&AP)SL*("`@("1M;V1?=F5R<VEO;E]C;VYS=&%N="`](%-T<FEN
M9SHZ=7!P97(H)&UO9'5L92D@+B`G7U9%4E-)3TXG.PH@("`@:68@*"%D969I
M;F5D*"1M;V1?=F5R<VEO;E]C;VYS=&%N="DI('L*("`@("`@("!E>&ET.PH@
M("`@?0H@("`@)'9E<G-I;VX@/2!3=')I;F<Z.G5C9FER<W0H)&UO9'5L92D@
M+B`G("<@+B!C;VYS=&%N="@D;6]D7W9E<G-I;VY?8V]N<W1A;G0I.PH@("`@
M)&-R961I=',@/2!5=&EL.CIB=69F97)/=71P=70H)VEN8VQU9&4G+"`D9FEL
M97)O;W0@+B`G+V1O8W,O0U)%1$E44R<I.PH@("`@)&-R961I=',@/2!3=')I
M;F<Z.F-O;G9E<G1#:&%R<V5T*"1C<F5D:71S+"`G:7-O+3@X-3DM,2<L($Y,
M4SHZ9V5T0VAA<G-E="@I*3L*("`@(')E<75I<F4@2$]21$5?5$5-4$Q!5$53
M("X@)R]H96QP+V%B;W5T+FEN8R<["GT@96QS92!["B`@("`D:&5L<"`]("9N
M97<@2&5L<"A(14Q07U-/55)#15]&24Q%+"!A<G)A>2@D:&5L<%]F:6QE+"`D
M:&5L<%]F:6QE7V9A;&QB86-K*2D["B`@("!I9B`H*"1S:&]W(#T]("=E;G1R
M>2<I("8F("%E;7!T>2@D=&]P:6,I*2!["B`@("`@("`@)&AE;'`M/FQO;VMU
M<"@D=&]P:6,I.PH@("`@("`@("1H96QP+3YD:7-P;&%Y*"D["B`@("!](&5L
M<V4@>PH@("`@("`@("1T;W!I8W,@/2`D:&5L<"T^=&]P:6-S*"D["B`@("`@
M("`@9F]R96%C:"`H)'1O<&EC<R!A<R`D:60@/3X@)'1I=&QE*2!["B`@("`@
M("`@("`@("1L:6YK(#T@2&]R9&4Z.G5R;"@D<F5G:7-T<GDM/F=E="@G=V5B
M<F]O="<L("=H;W)D92<I("X@)R]S97)V:6-E<R]H96QP+R<I.PH@("`@("`@
M("`@("`D;&EN:R`](%5T:6PZ.F%D9%!A<F%M971E<B@D;&EN:RP@87)R87DH
M)W-H;W<G(#T^("=E;G1R>2<L("=M;V1U;&4G(#T^("1M;V1U;&4L("=T;W!I
M8R<@/3X@)&ED*2D["B`@("`@("`@("`@(&5C:&\@2&]R9&4Z.FQI;FLH)&QI
M;FLI.PH@("`@("`@("`@("!E8VAO("1T:71L92`N("(\+V$^/&)R("\^7&XB
M.PH@("`@("`@('T*("`@('T*("`@("1H96QP+3YC;&5A;G5P*"D["GT*"G)E
M<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<[
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]S97)V:6-E<R]I;6%G97,O````````````````````````````````````
M`````````````````````````````````````````#`P,#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S4W`#`R,#<U,@`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME
M<BYP:'``````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<T,3,`,3`U,34T
M,S,W-3<`,#(T,#`T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W-E<G9I8V5S
M+VEM86=E<R]C;VQO<G!I8VME<BYP:'`L=B`Q+C$Y+C$P+C0@,C`P-B\P,2\P
M,2`R,3HR.3HQ-"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P
M-B!-:6-H865L($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA
M;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?
M0D%312`N("<O;&EB+V)A<V4N<&AP)SL*"B1T:71L92`](%\H(D-O;&]R(%!I
M8VME<B(I.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+6AE
M861E<BYI;F,G.PH*)&9O<FT@/2!5=&EL.CIG971&;W)M1&%T82@G9F]R;2<I
M.PHD=&%R9V5T(#T@571I;#HZ9V5T1F]R;41A=&$H)W1A<F=E="<I.PH*96-H
M;R!(;W)D93HZ:6UG*"=C;VQO<G-C86QE+G!N9R<L("<G+"`G:60](F-O;&]R
M<&EC:V5R(B!O;F-L:6-K/2)C:&%N9V5#;VQO<BAG971#;VQO<BAE=F5N="DI
M.R!R971U<FX@9F%L<V4[(B!O;FUO=7-E;6]V93TB9&5M;T-O;&]R*&=E=$-O
M;&]R*&5V96YT*2D[(')E='5R;B!F86QS93LB('-T>6QE/2)C=7)S;W(Z8W)O
M<W-H86ER.V)A8VMG<F]U;F0M8V]L;W(Z=VAI=&4[<&%D9&EN9SHQ<'@B)RD[
M"C\^"@H\9&EV(&ED/2)C;VQO<D1E;6\B('-T>6QE/2)B86-K9W)O=6YD+6-O
M;&]R.G=H:71E.W=I9'1H.C$P,'!X.VAE:6=H=#HR,'!X.W!A9&1I;F<Z,7!X
M(CX\+V1I=CX*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM
M"F9U;F-T:6]N(&-H86YG94-O;&]R*&-O;&]R*0I["B`@("!I9B`H<&%R96YT
M+F]P96YE<BYC;&]S960I('L*("`@("`@("!A;&5R="@B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%
M>&ET:6YG+B(I*2`_/B(I.PH@("`@("`@('1H:7,N8VQO<V4H*3L*("`@("`@
M("!R971U<FX["B`@("!]"@H@("`@:68@*"%P87)E;G0N;W!E;F5R+F1O8W5M
M96YT+CP_<&AP(&5C:&\@)&9O<FT@/SXI('L*("`@("`@("!A;&5R="@B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L
M;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B*2D@/SXB*3L*("`@("`@("!T
M:&ES+F-L;W-E*"D["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@('!A<F5N
M="YO<&5N97(N9&]C=6UE;G0N/#]P:'`@96-H;R`D9F]R;2`_/ELB/#]P:'`@
M96-H;R`D=&%R9V5T(#\^(ETN=F%L=64@/2!C;VQO<CL*("`@('!A<F5N="YO
M<&5N97(N9&]C=6UE;G0N/#]P:'`@96-H;R`D9F]R;2`_/ELB/#]P:'`@96-H
M;R`D=&%R9V5T(#\^(ETN<W1Y;&4N8F%C:V=R;W5N9$-O;&]R(#T@8V]L;W([
M"B`@("!P87)E;G0N;W!E;F5R+F1O8W5M96YT+CP_<&AP(&5C:&\@)&9O<FT@
M/SY;(CP_<&AP(&5C:&\@)'1A<F=E="`_/B)=+G-T>6QE+F-O;&]R(#T@8G)I
M9VAT;F5S<RAC;VQO<BD@/"`Q,C@@/R`G=VAI=&4G(#H@)V)L86-K)SL*"B`@
M("!T:&ES+F-L;W-E*"D["GT*"F9U;F-T:6]N(&1E;6]#;VQO<BAC;VQO<BD*
M>PH@("`@=F%R('1A<F=E="`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=C
M;VQO<D1E;6\G*3L*("`@('1A<F=E="YS='EL92YB86-K9W)O=6YD0V]L;W(@
M/2!C;VQO<CL*("`@('1A<F=E="YS='EL92YC;VQO<B`](&)R:6=H=&YE<W,H
M8V]L;W(I(#P@,3(X(#\@)W=H:71E)R`Z("=B;&%C:R<["B`@("!T87)G970N
M:6YN97)(5$U,(#T@8V]L;W(["GT*"F9U;F-T:6]N(&=E=$-O;&]R*&5V96YT
M*0I["B`@("!V87(@:6UG(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)V-O
M;&]R<&EC:V5R)RD["@H@("`@=F%R('@@/2!E=F5N="YC;&EE;G18("T@,3`[
M"B`@("!V87(@>2`](&5V96YT+F-L:65N=%D@+2`Q,#L*"B`@("!V87(@<FUA
M>"`](#`["B`@("!V87(@9VUA>"`](#`["B`@("!V87(@8FUA>"`](#`["@H@
M("`@:68@*'D@/#T@,S(I('L*("`@("`@("!R;6%X(#T@,C4U.PH@("`@("`@
M(&=M87@@/2`H>2`O(#,R+C`I("H@,C4U.PH@("`@("`@(&)M87@@/2`P.PH@
M("`@?2!E;'-E(&EF("AY(#P](#8T*2!["B`@("`@("`@>2`]('D@+2`S,CL*
M("`@("`@("!R;6%X(#T@,C4U("T@*'D@+R`S,BXP*2`J(#(U-3L*("`@("`@
M("!G;6%X(#T@,C4U.PH@("`@("`@(&)M87@@/2`P.PH@("`@?2!E;'-E(&EF
M("AY(#P](#DV*2!["B`@("`@("`@>2`]('D@+2`V-#L*("`@("`@("!R;6%X
M(#T@,#L*("`@("`@("!G;6%X(#T@,C4U.PH@("`@("`@(&)M87@@/2`H>2`O
M(#,R+C`I("H@,C4U.PH@("`@?2!E;'-E(&EF("AY(#P](#$R."D@>PH@("`@
M("`@('D@/2!Y("T@.38["B`@("`@("`@<FUA>"`](#`["B`@("`@("`@9VUA
M>"`](#(U-2`M("AY("\@,S(N,"D@*B`R-34["B`@("`@("`@8FUA>"`](#(U
M-3L*("`@('T@96QS92!I9B`H>2`\/2`Q-C`I('L*("`@("`@("!Y(#T@>2`M
M(#$R.#L*("`@("`@("!R;6%X(#T@*'D@+R`S,BXP*2`J(#(U-3L*("`@("`@
M("!G;6%X(#T@,#L*("`@("`@("!B;6%X(#T@,C4U.PH@("`@?2!E;'-E('L*
M("`@("`@("!Y(#T@>2`M(#$V,#L*("`@("`@("!R;6%X(#T@,C4U.PH@("`@
M("`@(&=M87@@/2`P.PH@("`@("`@(&)M87@@/2`R-34@+2`H>2`O(#,R+C`I
M("H@,C4U.PH@("`@?0H*("`@(&EF("AX(#P](#4P*2!["B`@("`@("`@=F%R
M('(@/2!-871H+F%B<RA-871H+F9L;V]R*')M87@@*B!X("\@-3`N,"DI.PH@
M("`@("`@('9A<B!G(#T@36%T:"YA8G,H36%T:"YF;&]O<BAG;6%X("H@>"`O
M(#4P+C`I*3L*("`@("`@("!V87(@8B`]($UA=&@N86)S*$UA=&@N9FQO;W(H
M8FUA>"`J('@@+R`U,"XP*2D["B`@("!](&5L<V4@>PH@("`@("`@('@@+3T@
M-3`["B`@("`@("`@=F%R('(@/2!-871H+F%B<RA-871H+F9L;V]R*')M87@@
M*R`H>"`O(#4P+C`I("H@*#(U-2`M(')M87@I*2D["B`@("`@("`@=F%R(&<@
M/2!-871H+F%B<RA-871H+F9L;V]R*&=M87@@*R`H>"`O(#4P+C`I("H@*#(U
M-2`M(&=M87@I*2D["B`@("`@("`@=F%R(&(@/2!-871H+F%B<RA-871H+F9L
M;V]R*&)M87@@*R`H>"`O(#4P+C`I("H@*#(U-2`M(&)M87@I*2D["B`@("!]
M"@H@("`@<F5T=7)N(&UA:V5#;VQO<BAR+"!G+"!B*3L*?0H*9G5N8W1I;VX@
M;6%K94-O;&]R*'(L(&<L(&(I"GL*("`@(&-O;&]R(#T@)R,G.PH@("`@8V]L
M;W(@*ST@:&5X*$UA=&@N9FQO;W(H<B`O(#$V*2D["B`@("!C;VQO<B`K/2!H
M97@H<B`E(#$V*3L*("`@(&-O;&]R("L](&AE>"A-871H+F9L;V]R*&<@+R`Q
M-BDI.PH@("`@8V]L;W(@*ST@:&5X*&<@)2`Q-BD["B`@("!C;VQO<B`K/2!H
M97@H36%T:"YF;&]O<BAB("\@,38I*3L*("`@(&-O;&]R("L](&AE>"AB("4@
M,38I.PH@("`@<F5T=7)N(&-O;&]R.PI]"@IF=6YC=&EO;B!B<FEG:'1N97-S
M*&-O;&]R*0I["B`@("!V87(@<B`](&YE=R!.=6UB97(H(C!X(B`K(&-O;&]R
M+G-U8G-T<B@Q+"`R*2D["B`@("!V87(@9R`](&YE=R!.=6UB97(H(C!X(B`K
M(&-O;&]R+G-U8G-T<B@S+"`R*2D["B`@("!V87(@8B`](&YE=R!.=6UB97(H
M(C!X(B`K(&-O;&]R+G-U8G-T<B@U+"`R*2D["B`@("!R971U<FX@*"AR("H@
M,CDY*2`K("AG("H@-3@W*2`K("AB("H@,3$T*2D@+R`Q,#`P.PI]"@IF=6YC
M=&EO;B!H97@H9&5C*0I["B`@("!R971U<FX@*&1E8RDN=&]3=')I;F<H,38I
M.PI]"B\O+2T^"CPO<V-R:7!T/@H\+V)O9'D^"CPO:'1M;#X*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S
M+VEM86=E<R]P:7AE;"YP:'``````````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(Q-S4`,3`U,34T,S,W-3<`,#(R-C$Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R
M9&4Z(&AO<F1E+W-E<G9I8V5S+VEM86=E<R]P:7AE;"YP:'`L=B`Q+C$T+C$P
M+C,@,C`P-B\P,2\P,2`R,3HR.3HQ-"!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D
M:7)N86UE*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*<F5Q=6ER95]O;F-E($A/
M4D1%7T)!4T4@+B`G+VQI8B]C;W)E+G!H<"<["@IH96%D97(H)T-O;G1E;G0M
M='EP93H@:6UA9V4O9VEF)RD["FAE861E<B@G17AP:7)E<SH@5V5D+"`R,2!!
M=6<@,3DV.2`Q,3HQ,3HQ,2!'350G*3L*:&5A9&5R*"=#86-H92U#;VYT<F]L
M.B!N;RUC86-H92<I.PIH96%D97(H)T-A8VAE+4-O;G1R;VPZ(&UU<W0M<F5V
M86QI9&%T92<I.PH*)')G8B`]('-T<E]R97!L86-E*"<C)RP@)R<L(%5T:6PZ
M.F=E=$9O<FU$871A*"=C)RDI.PH*)'(@/2!H97AD96,H<W5B<W1R*"1R9V(L
M(#`L(#(I*3L*)&<@/2!H97AD96,H<W5B<W1R*"1R9V(L(#(L(#(I*3L*)&(@
M/2!H97AD96,H<W5B<W1R*"1R9V(L(#0L(#(I*3L*"FEF("@D<F=B*2!["B`@
M("!P<FEN=&8H)R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E
M8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,G+`H@("`@("`@
M("`@(#<Q+#<S+#<P+#4V+#4W+#DW+#$L,"PQ+#`L,3(X+#`L,"PD<BPD9RPD
M8BPP+#`L,"PT-"PP+#`L,"PP+#$L,"PQ+#`L,"PR+#(L-C@L,2PP+#4Y*3L*
M?2!E;'-E('L*("`@('!R:6YT9B@G)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C
M)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E
M8R5C)6,E8R5C)6,E8R5C)2<L"B`@("`@("`@("`@-S$L-S,L-S`L-38L-3<L
M.3<L,2PP+#$L,"PQ,C@L,C4U+#`L,3DR+#$Y,BPQ.3(L,"PP+#`L,S,L,C0Y
M+#0L,2PP+#`L,"PP+#0T+#`L,"PP+#`L,2PP+#$L,"PP+#(L,BPV."PQ+#`L
M-3DI.PI]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O:6UA9V5S+W9I97<N<&AP````````
M```````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S4V-``Q,#4Q-30S,S<U
M-P`P,C(T-3$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J($1I<W!L87ES(&%N(&EM86=E(&%N9"!A;&QO
M=W,@;6]D:69I8V%T:6]N<R!I9B!R97%U:7)E9"X*("H*("H@0V]P>7)I9VAT
M(#(P,#,M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@)$AO<F1E.B!H;W)D92]S97)V:6-E<R]I;6%G97,O
M=FEE=RYP:'`L=B`Q+C(P+C$P+C8@,C`P-B\P-2\R-"`P,CHR,CHP,R!S96QS
M:WD@17AP("0*("H*("H@0&%U=&AO<B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B
M;&\N8V]M/@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?
M1DE,15]?*2`N("<O+BXO+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@
M+B`G+VQI8B]B87-E+G!H<"<["@HO*B!'970@9FEL92!I;F9O+B!4:&4@9F]L
M;&]W:6YG('!A<F%M971E<G,@87)E(&%V86EL86)L93H*("H@("=F)R`M('1H
M92!F:6QE;F%M92X*("H@("=S)R`M('1H92!S;W5R8V4L(&5I=&AE<B!T:&4@
M)W1M<"<@9&ER96-T;W)Y(&]R(%9&4RX*("H@("=C)R`M('=H:6-H(&%P<"=S
M(&-O;F9I9R!T;R!U<V4@9F]R(%9&4RP@9&5F875L=',@=&\@2&]R9&4N"B`J
M("`G<"<@+2!T:&4@9&ER96-T;W)Y(&]F('1H92!F:6QE+@H@*B`@)VXG("T@
M=&AE(&YA;64@=&\@<V5T('1O('1H92!F:6QE;F%M92!O<B!D969A=6QT('1O
M('-A;64@87,@9FEL96YA;64N"B`J("`G82<@+2!P97)F;W)M('-O;64@86-T
M:6]N(&]N('1H92!I;6%G92P@<W5C:"!A<R!S8V%L:6YG+B`J+PHD9FEL92`]
M(&)A<V5N86UE*%5T:6PZ.F=E=$9O<FU$871A*"=F)RDI.PHD<V]U<F-E(#T@
M<W1R=&]L;W=E<BA5=&EL.CIG971&;W)M1&%T82@G<R<L("=T;7`G*2D["B1A
M<'!?8V]N9B`]('-T<G1O;&]W97(H571I;#HZ9V5T1F]R;41A=&$H)V,G+"`G
M:&]R9&4G*2D["B1N86UE(#T@571I;#HZ9V5T1F]R;41A=&$H)VXG+"`D9FEL
M92D["B1A8W1I;VX@/2!S=')T;VQO=V5R*%5T:6PZ.F=E=$9O<FU$871A*"=A
M)RDI.PH*<W=I=&-H("@D<V]U<F-E*2!["F-A<V4@)W9F<R<Z"B`@("`O*B!#
M:&%N9V4@87!P(&EF(&YE961E9"!T;R!G970@=&AE(')I9VAT(%9&4R!C;VYF
M:6<N("HO"B`@("`D8VAA;F=E9%]C;VYF(#T@)')E9VES=')Y+3YP=7-H07!P
M*"1A<'!?8V]N9BD["@H@("`@+RH@1V5T=&EN9R!A(&9I;&4@9G)O;2!(;W)D
M92=S(%9&4RX@*B\*("`@(')E<75I<F5?;VYC92`G5D93+G!H<"<["B`@("`D
M=F9S(#T@)E9&4SHZ<VEN9VQE=&]N*"1C;VYF6R=V9G,G75LG='EP92==+"!(
M;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=V9G,G+"`D8V]N9ELG=F9S)UU;)W1Y
M<&4G72DI.PH@("`@)'!A=&@@/2!5=&EL.CIG971&;W)M1&%T82@G<"<I.PH@
M("`@)&9I;&5?9&%T82`]("1V9G,M/G)E860H)'!A=&@L("1F:6QE*3L*("`@
M(&EF("AI<U]A*"1F:6QE7V1A=&$L("=014%27T5R<F]R)RDI('L*("`@("`@
M("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=%<G)O<B!D:7-P;&%Y:6YG
M(&EM86=E(%LE<UTZ("5S)RP@)'!A=&@@+B`G+R<@+B`D9FEL92P@)&9I;&5?
M9&%T82T^9V5T365S<V%G92@I*2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U]%4E(I.PH@("`@("`@(&5X:70["B`@("!]"@H@("`@+RH@4F5T=7)N
M('1H92!O<FEG:6YA;"!A<'`@:68@8VAA;F=E9"!P<F5V:6]U<VQY+B`J+PH@
M("`@:68@*"1C:&%N9V5D7V-O;F8I('L*("`@("`@("`D<F5G:7-T<GDM/G!O
M<$%P<"@D87!P7V-O;F8I.PH@("`@?0H@("`@8G)E86L["@IC87-E("=T;7`G
M.@H@("`@+RH@1V5T=&EN9R!A(&9I;&4@9G)O;2!(;W)D92=S('1E;7`@9&ER
M+B`J+PH@("`@)'1M<&1I<B`]($AO<F1E.CIG971496UP1&ER*"D["B`@("!I
M9B`H96UP='DH)&%C=&EO;BD@?'P@)&%C=&EO;B`]/2`G<F5S:7IE)RD@>PH@
M("`@("`@("\J(%5S92!O<FEG:6YA;"!I9B!N;R!A8W1I;VX@;W(@:68@<F5S
M:7II;F<N("HO"B`@("`@("`@)&9I;&5?;F%M92`]("1T;7!D:7(@+B`G+R<@
M+B`D9FEL93L*("`@('T@96QS92!["B`@("`@("`@)&9I;&5?;F%M92`]("1T
M;7!D:7(@+B`G+VUO9%\G("X@)&9I;&4["B`@("`@("`@:68@*"%F:6QE7V5X
M:7-T<R@D9FEL95]N86UE*2D@>PH@("`@("`@("`@("!C;W!Y*"1T;7!D:7(@
M+B`G+R<@+B`D9FEL92P@)&9I;&5?;F%M92D["B`@("`@("`@?0H@("`@?0H@
M("`@:68@*"%F:6QE7V5X:7-T<R@D9FEL95]N86UE*2D@>PH@("`@("`@($AO
M<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H)TEM86=E(&YO="!F;W5N9"!;)7-=
M)RP@)&9I;&5?;F%M92DL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?
M15)2*3L*("`@("`@("!E>&ET.PH@("`@?0H@("`@)&9I;&5?9&%T82`](&9I
M;&5?9V5T7V-O;G1E;G1S*"1F:6QE7VYA;64I.PH@("`@8G)E86L["GT*"B\J
M($QO860@=&AE(&EM86=E(&]B:F5C="X@*B\*<F5Q=6ER95]O;F-E("=(;W)D
M92]);6%G92YP:'`G.PHD<&%R86US(#T@87)R87DH)W1E;7`G(#T^($AO<F1E
M.CIG971496UP1&ER*"DI.PII9B`H(65M<'1Y*"1C;VYF6R=I;6%G92==6R=C
M;VYV97)T)UTI*2!["B`@("`D:6UA9V4@/2`F2&]R9&5?26UA9V4Z.G-I;F=L
M971O;B@G:6TG+"`D<&%R86US*3L*?2!E;'-E('L*("`@("1I;6%G92`]("9(
M;W)D95]);6%G93HZ<VEN9VQE=&]N*"=G9"<L("1P87)A;7,I.PI]"B1I;6%G
M92T^;&]A9%-T<FEN9R@D9FEL92P@)&9I;&5?9&%T82D["@HO*B!#:&5C:R!I
M9B!N;R!E9&ET:6YG(&%C=&EO;B!R97%U:7)E9"!A;F0@<V5N9"!T:&4@:6UA
M9V4@=&\@8G)O=W-E<BX@*B\*:68@*&5M<'1Y*"1A8W1I;VXI*2!["B`@("`D
M:6UA9V4M/F1I<W!L87DH*3L*("`@(&5X:70["GT*"B\J($EM86=E(&5D:71I
M;F<@<F5Q=6ER960N("HO"G-W:71C:"`H)&%C=&EO;BD@>PIC87-E("=R;W1A
M=&4G.@H@("`@)&EM86=E+3YR;W1A=&4H571I;#HZ9V5T1F]R;41A=&$H)W8G
M*2D["B`@("!B<F5A:SL*"F-A<V4@)V9L:7`G.@H@("`@)&EM86=E+3YF;&EP
M*"D["B`@("!B<F5A:SL*"F-A<V4@)VUI<G)O<B<Z"B`@("`D:6UA9V4M/FUI
M<G)O<B@I.PH@("`@8G)E86L["@IC87-E("=G<F%Y<V-A;&4G.@H@("`@)&EM
M86=E+3YG<F%Y<V-A;&4H*3L*("`@(&)R96%K.PH*8V%S92`G<F5S:7IE)SH*
M("`@(&QI<W0H)'=I9'1H+"`D:&5I9VAT+"`D<F%T:6\I(#T@97AP;&]D92@G
M+B<L(%5T:6PZ.F=E=$9O<FU$871A*"=V)RDI.PH*("`@("\J($EF(&YO('=I
M9'1H(&]R(&AE:6=H="!H87,@8F5E;B!P87-S960L(&=E="!T:&4@;W)I9VEN
M86P*("`@("`J(&]N97,N("HO"B`@("!I9B`H96UP='DH)'=I9'1H*2!\?"!E
M;7!T>2@D:&5I9VAT*2D@>PH@("`@("`@("1O<FEG(#T@)&EM86=E+3YG971$
M:6UE;G-I;VYS*"D["B`@("!]"B`@("!I9B`H96UP='DH)'=I9'1H*2D@>PH@
M("`@("`@("1W:61T:"`]("1O<FEG6R=W:61T:"==.PH@("`@?0H@("`@:68@
M*&5M<'1Y*"1H96EG:'0I*2!["B`@("`@("`@)&AE:6=H="`]("1O<FEG6R=H
M96EG:'0G73L*("`@('T*"B`@("`D:6UA9V4M/G)E<VEZ92@D=VED=&@L("1H
M96EG:'0L("1R871I;RD["@H@("`@+RH@4VEN8V4@=&AE(&]R:6=I;F%L(&ES
M(&%L=V%Y<R!U<V5D(&9O<B!R97-I>FEN9R!M86ME('-U<F4@=&AE"B`@("`@
M*B!W<FET92!I<R!T;R`G;6]D7R<N("HO"B`@("`D9FEL95]N86UE(#T@)'1M
M<&1I<B`N("<O;6]D7R<@+B`D9FEL93L*("`@(&)R96%K.PI]"@HO*B!7<FET
M92!O=70@86YY(&-H86YG97,@=&\@=&AE('1E;7!O<F%R>2!F:6QE+B`J+PHD
M9G`@/2!`9F]P96XH)&9I;&5?;F%M92P@)W=B)RD["F9W<FET92@D9G`L("1I
M;6%G92T^<F%W*"DI.PIF8VQO<V4H)&9P*3L*"B1I;6%G92T^9&ES<&QA>2@I
M.PH`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O:F%V
M87-C<FEP="YP:'``````````````````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C0V,@`Q,#4Q-30S,S<U-P`P,C(S-S``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@
M:&]R9&4O<V5R=FEC97,O:F%V87-C<FEP="YP:'`L=B`Q+C,W+C$P+C0@,C`P
M-B\P,2\P,2`R,3HR.3HQ,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#`M,C`P-B!#:&%R;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"
M05-%("X@)R]L:6(O8V]R92YP:'`G.PH*)')E9VES=')Y(#T@)E)E9VES=')Y
M.CIS:6YG;&5T;VXH2$]21$5?4T534TE/3E]214%$3TY,62D["@HO+R!&:6=U
M<F4@;W5T(&EF('=E)W9E(&)E96X@:6YL:6YE9"P@;W(@8V%L;&5D(&1I<F5C
M=&QY+@HD<V5N9%]H96%D97)S(#T@<W1R<W1R*"1?4T525D526R=02%!?4T5,
M1B==+"`G:F%V87-C<FEP="YP:'`G*3L*"B1A<'`@/2!5=&EL.CIG971&;W)M
M1&%T82@G87!P)RP@571I;#HZ;F]N26YP=71687(H)V%P<"<I*3L*)&9I;&4@
M/2!5=&EL.CIG971&;W)M1&%T82@G9FEL92<L(%5T:6PZ.FYO;DEN<'5T5F%R
M*"=F:6QE)RDI.PII9B`H(65M<'1Y*"1A<'`I("8F("%E;7!T>2@D9FEL92D@
M)B8@<W1R<&]S*"1F:6QE+"`G+BXG*2`]/3T@9F%L<V4I('L*("`@("1S8W)I
M<'1?9FEL92`]("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`D87!P*2`N
M("<O:F%V87-C<FEP="\G("X@)&9I;&4["B`@("!I9B`H0&9I;&5?97AI<W1S
M*"1S8W)I<'1?9FEL92DI('L*("`@("`@("`D<F5G:7-T<GDM/G!U<VA!<'`H
M)&%P<"P@9F%L<V4I.PH@("`@("`@("1S8W)I<'0@/2!5=&EL.CIB=69F97)/
M=71P=70H)W)E<75I<F4G+"`D<V-R:7!T7V9I;&4I.PH*("`@("`@("!I9B`H
M)'-E;F1?:&5A9&5R<RD@>PH@("`@("`@("`@("`O*B!#;VUP<F5S<R!T:&4@
M2E,N(%=E(&YE960@=&AI<R!E>'!L:6-I="!C86QL('-I;F-E('=E"B`@("`@
M("`@("`@("`J(&1O;B=T(&EN8VQU9&4@8F%S92YP:'`@:6X@=&AI<R!F:6QE
M+B`J+PH@("`@("`@("`@("!(;W)D93HZ8V]M<')E<W-/=71P=70H*3L*"B`@
M("`@("`@("`@(&AE861E<B@G0V%C:&4M0V]N=')O;#H@;F\M8V%C:&4G*3L*
M("`@("`@("`@("`@:&5A9&5R*"=#;VYT96YT+51Y<&4Z('1E>'0O:F%V87-C
M<FEP="<I.PH@("`@("`@('T*"B`@("`@("`@96-H;R`D<V-R:7!T.PH@("`@
M?0I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]S97)V:6-E<R]K97EB;V%R9"YP:'``````````````````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$S-30W`#$P-3$U-#,S-S4W`#`R
M,C`S,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*@H@*B`D2&]R9&4Z(&AO<F1E+W-E<G9I8V5S+VME>6)O87)D
M+G!H<"QV(#$N,3,N,3`N,R`R,#`V+S`Q+S`Q(#(Q.C(Y.C$P(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G
M2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I.PIR97%U
M:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*"B1T:71L
M92`](%\H(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(BD["G)E<75I<F4@2$]2
M1$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["@H_/@H*/'-C
M<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H*=F%R('1A<F=E=#L*"F9U
M;F-T:6]N(&AA;F1L94QI<W1#:&%N9V4H=&AE3&ES="D@>PH@("`@=F%R(&YU
M;5-E;&5C=&5D(#T@=&AE3&ES="YS96QE8W1E9$EN9&5X.PH*("`@(&EF("AN
M=6U396QE8W1E9"`A/2`P*2!["B`@("`@("`@9&]C=6UE;G0N8VAA<F%C=&5R
M<RYT97AT8F]X+G9A;'5E("L]('1H94QI<W0N;W!T:6]N<UMN=6U396QE8W1E
M9%TN=F%L=64["B`@("`@("`@=&AE3&ES="YS96QE8W1E9$EN9&5X(#T@,#L*
M("`@('T*?0H\+W-C<FEP=#X*"CQF;W)M(&YA;64](F-H87)A8W1E<G,B/@H\
M=&%B;&4@8V5L;'-P86-I;F<](C`B/@H@(#QT<CX*("`@(#QT9"!C;&%S<STB
M:71E;2!L969T06QI9VXB/@H@("`@("`\<#X\/W!H<"!E8VAO(%\H(E-E;&5C
M="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO
M=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@
M=&5X="!A<F5A+B(I(#\^/"]P/@H@("`@/"]T9#X*("`\+W1R/@H@(#QT<CX*
M("`@(#QT9"!C;&%S<STB;&5F=$%L:6=N(CX*("`@("`@/'1A8FQE(&-E;&QS
M<&%C:6YG/2(P(CX*("`@("`@("`\='(^"B`@("`@("`@("`\=&0@86QI9VX]
M(F-E;G1E<B(^"B`@("`@("`@("`@(#QS96QE8W0@;F%M93TB82(@;VYC:&%N
M9V4](FAA;F1L94QI<W1#:&%N9V4H=&AI<RDB/@H@("`@("`@("`@("`@(#QO
M<'1I;VX@=F%L=64](F$B('-E;&5C=&5D/B!A(#PO;W!T:6]N/@H@("`@("`@
M("`@("`@(#QO<'1I;VX@=F%L=64](B8C,3DR.R(^("8C,3DR.R`\+V]P=&EO
M;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(R-#LB/B`F(S(R
M-#L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,Q
M.3,[(CX@)B,Q.3,[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@
M=F%L=64](B8C,C(U.R(^("8C,C(U.R`\+V]P=&EO;CX*("`@("`@("`@("`@
M("`\;W!T:6]N('9A;'5E/2(F(S$Y-#LB/B`F(S$Y-#L@/"]O<'1I;VX^"B`@
M("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,C8[(CX@)B,R,C8[(#PO
M;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,3DU.R(^
M("8C,3DU.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E
M/2(F(S(R-SLB/B`F(S(R-SL@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P
M=&EO;B!V86QU93TB)B,Q.38[(CX@)B,Q.38[(#PO;W!T:6]N/@H@("`@("`@
M("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C(X.R(^("8C,C(X.R`\+V]P=&EO
M;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S$Y-SLB/B`F(S$Y
M-SL@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R
M,CD[(CX@)B,R,CD[(#PO;W!T:6]N/@H@("`@("`@("`@("`\+W-E;&5C=#X*
M("`@("`@("`@(#PO=&0^"B`@("`@("`@("`\=&0@86QI9VX](F-E;G1E<B(^
M"B`@("`@("`@("`@(#QS96QE8W0@;F%M93TB92(@;VYC:&%N9V4](FAA;F1L
M94QI<W1#:&%N9V4H=&AI<RDB/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L
M=64](F4B('-E;&5C=&5D/B!E(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO
M<'1I;VX@=F%L=64](B8C,C`P.R(^("8C,C`P.R`\+V]P=&EO;CX*("`@("`@
M("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(S,CLB/B`F(S(S,CL@/"]O<'1I
M;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,#$[(CX@)B,R
M,#$[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C
M,C,S.R(^("8C,C,S.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N
M('9A;'5E/2(F(S(P,CLB/B`F(S(P,CL@/"]O<'1I;VX^"B`@("`@("`@("`@
M("`@/&]P=&EO;B!V86QU93TB)B,R,S0[(CX@)B,R,S0[(#PO;W!T:6]N/@H@
M("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C`S.R(^("8C,C`S.R`\
M+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(S-3LB
M/B`F(S(S-3L@/"]O<'1I;VX^"B`@("`@("`@("`@(#PO<V5L96-T/@H@("`@
M("`@("`@/"]T9#X*("`@("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(CX*("`@
M("`@("`@("`@/'-E;&5C="!N86UE/2)I(B!O;F-H86YG93TB:&%N9&QE3&ES
M=$-H86YG92AT:&ES*2(^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB
M:2(@<V5L96-T960^(&D@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO
M;B!V86QU93TB)B,R,#0[(CX@)B,R,#0[(#PO;W!T:6]N/@H@("`@("`@("`@
M("`@(#QO<'1I;VX@=F%L=64](B8C,C,V.R(^("8C,C,V.R`\+V]P=&EO;CX*
M("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(P-3LB/B`F(S(P-3L@
M/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,S<[
M(CX@)B,R,S<[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L
M=64](B8C,C`V.R(^("8C,C`V.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\
M;W!T:6]N('9A;'5E/2(F(S(S.#LB/B`F(S(S.#L@/"]O<'1I;VX^"B`@("`@
M("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,#<[(CX@)B,R,#<[(#PO;W!T
M:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C,Y.R(^("8C
M,C`W.R`\+V]P=&EO;CX*("`@("`@("`@("`@/"]S96QE8W0^"B`@("`@("`@
M("`\+W1D/@H@("`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B/@H@("`@("`@
M("`@("`\<V5L96-T(&YA;64](F\B(&]N8VAA;F=E/2)H86YD;&5,:7-T0VAA
M;F=E*'1H:7,I(CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2)O(B!S
M96QE8W1E9#X@;R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A
M;'5E/2(F(S(Q,#LB/B`F(S(Q,#L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@
M/&]P=&EO;B!V86QU93TB)B,R-#([(CX@)B,R-#([(#PO;W!T:6]N/@H@("`@
M("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C$Q.R(^("8C,C$Q.R`\+V]P
M=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(T,SLB/B`F
M(S(T,SL@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB
M)B,R,3([(CX@)B,R,3([(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I
M;VX@=F%L=64](B8C,C0T.R(^("8C,C0T.R`\+V]P=&EO;CX*("`@("`@("`@
M("`@("`\;W!T:6]N('9A;'5E/2(F(S(Q,SLB/B`F(S(Q,SL@/"]O<'1I;VX^
M"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R-#4[(CX@)B,R-#4[
M(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C$T
M.R(^("8C,C$T.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A
M;'5E/2(F(S(T-CLB/B`F(S(T-CL@/"]O<'1I;VX^"B`@("`@("`@("`@(#PO
M<V5L96-T/@H@("`@("`@("`@/"]T9#X*("`@("`@("`@(#QT9"!A;&EG;CTB
M8V5N=&5R(CX*("`@("`@("`@("`@/'-E;&5C="!N86UE/2)U(B!O;F-H86YG
M93TB:&%N9&QE3&ES=$-H86YG92AT:&ES*2(^"B`@("`@("`@("`@("`@/&]P
M=&EO;B!V86QU93TB=2(@<V5L96-T960^('4@/"]O<'1I;VX^"B`@("`@("`@
M("`@("`@/&]P=&EO;B!V86QU93TB)B,R,3<[(CX@)B,R,3<[(#PO;W!T:6]N
M/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C0Y.R(^("8C,C0Y
M.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(Q
M.#LB/B`F(S(Q.#L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V
M86QU93TB)B,R-3`[(CX@)B,R-3`[(#PO;W!T:6]N/@H@("`@("`@("`@("`@
M(#QO<'1I;VX@=F%L=64](B8C,C$Y.R(^("8C,C$Y.R`\+V]P=&EO;CX*("`@
M("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(U,3LB/B`F(S(U,3L@/"]O
M<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,C`[(CX@
M)B,R,C`[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64]
M(B8C,C4R.R(^("8C,C4R.R`\+V]P=&EO;CX*("`@("`@("`@("`@/"]S96QE
M8W0^"B`@("`@("`@("`\+W1D/@H@("`@("`@("`@/'1D(&%L:6=N/2)C96YT
M97(B/@H@("`@("`@("`@("`\<V5L96-T(&YA;64](D]T:&5R(B!O;F-H86YG
M93TB:&%N9&QE3&ES=$-H86YG92AT:&ES*2(^"B`@("`@("`@("`@("`@/&]P
M=&EO;B!V86QU93TB;6ES8R(@<V5L96-T960^(#P_<&AP(&5C:&\@7R@B3W1H
M97(B*3L@/SX\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E
M/2(F(S$V,CLB/B`F(S$V,CL@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P
M=&EO;B!V86QU93TB)B,Q-C,[(CX@)B,Q-C,[(#PO;W!T:6]N/@H@("`@("`@
M("`@("`@(#QO<'1I;VX@=F%L=64](B8C,38T.R(^("8C,38T.R`\+V]P=&EO
M;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S$V-3LB/B`F(S$V
M-3L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,Q
M.3@[(CX@)B,Q.3@[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@
M=F%L=64](B8C,C,P.R(^("8C,C,P.R`\+V]P=&EO;CX*("`@("`@("`@("`@
M("`\;W!T:6]N('9A;'5E/2(F(S(R,SLB/B`F(S(R,SL@/"]O<'1I;VX^"B`@
M("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,Q.3D[(CX@)B,Q.3D[(#PO
M;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C,Q.R(^
M("8C,C,Q.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E
M/2(F(S(P.3LB/B`F(S(P.3L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P
M=&EO;B!V86QU93TB)B,R-#$[(CX@)B,R-#$[(#PO;W!T:6]N/@H@("`@("`@
M("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C4S.R(^("8C,C4S.R`\+V]P=&EO
M;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(U-3LB/B`F(S(U
M-3L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,Q
M.3$[(CX@)B,Q.3$[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@
M=F%L=64](B8C,38Q.R(^("8C,38Q.R`\+V]P=&EO;CX*("`@("`@("`@("`@
M/"]S96QE8W0^"B`@("`@("`@("`\+W1D/@H@("`@("`@(#PO='(^"B`@("`@
M(#PO=&%B;&4^"B`@("`\+W1D/@H@(#PO='(^"B`@/'1R/@H@("`@/'1D(&-L
M87-S/2)F:7AE9"!L969T06QI9VXB/@H@("`@("`\=&5X=&%R96$@<F]W<STB
M-"(@8V]L<STB,C4B(&-L87-S/2)F:7AE9"(@;F%M93TB=&5X=&)O>"(^/"]T
M97AT87)E83X*("`@(#PO=&0^"B`@/"]T<CX*("`\='(^"B`@("`\=&0@86QI
M9VX](F-E;G1E<B(^"B`@("`@(#QI;G!U="!T>7!E/2)B=71T;VXB(&-L87-S
M/2)B=71T;VXB(&]N8VQI8VL](G=I;F1O=RYC;&]S92@I.R(@;F%M93TB8VQO
M<V4B('9A;'5E/2(\/W!H<"!E8VAO(%\H(D-L;W-E(%=I;F1O=R(I(#\^(B`O
M/@H@("`@/"]T9#X*("`\+W1R/@H\+W1A8FQE/@H\+V9O<FT^"CPO8F]D>3X*
M/"]H=&UL/@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W-E<G9I8V5S+VQA;F=U86=E+G!H<```````````````````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$S-3<`,3`U,34T,S,W-3<`,#(R,#`W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!38W)I<'0@=&\@<V5T('1H92!N97<@;&%N9W5A9V4N"B`J
M"B`J("1(;W)D93H@:&]R9&4O<V5R=FEC97,O;&%N9W5A9V4N<&AP+'8@,2XU
M+C$R+C,@,C`P-B\P,2\P,2`R,3HR.3HQ,"!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#,M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"
M05-%("X@)R]L:6(O8F%S92YP:'`G.PH*+RH@4V5T('1H92!L86YG=6%G92X@
M*B\*)%]315-324].6R=H;W)D95]L86YG=6%G92==(#T@3DQ3.CIS96QE8W0H
M*3L*)'!R969S+3YS971686QU92@G;&%N9W5A9V4G+"`D7U-%4U-)3TY;)VAO
M<F1E7VQA;F=U86=E)UTI.PH*+RH@4F5D:7)E8W0@=&\@=&AE('5R;"!O<B!L
M;V=I;B!P86=E(&EF(&YO;F4@9VEV96XN("HO"B1U<FP@/2!5=&EL.CIG971&
M;W)M1&%T82@G=7)L)RD["FEF("AE;7!T>2@D=7)L*2D@>PH@("`@)'5R;"`]
M($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G:6YD97@N<&AP)RP@=')U92D["GT*
M:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1U<FPI.PH`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<```````````
M````````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8U-#<`,3`U,34T,S,W-3<`
M,#(R-3$T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<"QV(#$N,S$N,BXS(#(P,#8O,#$O,#$@,C$Z,CDZ,3`@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@36EC:&%E;"!3;'5S
M87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!#;W!Y<FEG
M:'0@,C`P,2TR,#`V($-H87)L97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D
M92YO<F<^"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@2F]N(%!A<FES92`\:F]N
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%
M7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXG*3L*<F5Q=6ER95]O
M;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC
M92`G2&]R9&4O36%I;G1E;F%N8V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D
M92]496UP;&%T92YP:'`G.PH*+RH@36%K92!S=7)E('1H97)E(&ES(&$@=7-E
M<B!L;V=G960@:6XN("HO"FEF("@A075T:#HZ9V5T075T:"@I*2!["B`@("!(
M;W)D93HZ875T:&5N=&EC871I;VY&86EL=7)E4F5D:7)E8W0H*3L*?0H*+RH@
M268@;F\@)VUO9'5L92<@<&%R86UE=&5R('!A<W-E9"!I;BP@9&EE('=I=&@@
M86X@97)R;W(N("HO"FEF("@A*"1M;V1U;&4@/2!B87-E;F%M92A5=&EL.CIG
M971&;W)M1&%T82@G;6]D=6QE)RDI*2D@>PH@("`@2&]R9&4Z.F9A=&%L*%!%
M05(Z.G)A:7-E17)R;W(H7R@B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN
M=&5N86YC92YP:'`B*2DL(%]?1DE,15]?+"!?7TQ)3D5?7RD["GT*)&%P<%]N
M86UE(#T@)')E9VES=')Y+3YG970H)VYA;64G+"`D;6]D=6QE*3L*"B\J($QO
M860@=&AE(&UO9'5L92!S<&5C:69I8R!M86EN=&5N86YC92!C;&%S<R!N;W<N
M("HO"FEF("@A*"1M86EN="`]("9-86EN=&5N86YC93HZ9F%C=&]R>2@D;6]D
M=6QE*2DI('L*("`@($AO<F1E.CIF871A;"A014%2.CIR86ES945R<F]R*%\H
M(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S
M9G5L;'DB*2DL(%]?1DE,15]?+"!?7TQ)3D5?7RD["GT*"B\J($-R96%T92!T
M:&4@2&]R9&5?5&5M<&QA=&4@:71E;2X@*B\*)'1E;7!L871E(#T@)FYE=R!(
M;W)D95]496UP;&%T92@I.PHD=&5M<&QA=&4M/G-E="@G:F%V87-C<FEP="<L
M("1B<F]W<V5R+3YH87-&96%T=7)E*"=J879A<V-R:7!T)RDL('1R=64I.PH*
M+RH@2&%V92!T:&4@;6%I;G1E;F%N8V4@;6]D=6QE(&1O(&%L;"!N96-E<W-A
M<GD@<')O8V5S<VEN9RX@*B\*;&ES="@D86-T:6]N+"`D=&%S:VQI<W0I(#T@
M)&UA:6YT+3YR=6Y-86EN=&5N86YC95!A9V4H*3L*"G-W:71C:"`H)&%C=&EO
M;BD@>PIC87-E($U!24Y414Y!3D-%7T]55%!55%]#3TY&25)-.@H@("`@+RH@
M0V]N9FER;6%T:6]N+7-T>6QE(&]U='!U="X@*B\*("`@("1T96UP;&%T92T^
M<V5T*"=C;VYF:7)M)RP@=')U92P@=')U92D["B`@("`D=&5M<&QA=&4M/G-E
M="@G86=R964G+"!F86QS92P@=')U92D["B`@("`D=&5M<&QA=&4M/G-E="@G
M;F]T:6-E)RP@9F%L<V4L('1R=64I.PH*("`@("1N;W1I9FEC871I;VXM/G!U
M<V@H<W!R:6YT9BA?*"(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN
M=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92!B
M;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A
M="!T:&ES('1I;64N(BDL("1A<'!?;F%M92DL("=H;W)D92YM97-S86=E)RD[
M"B`@("`D=&5M<&QA=&4M/G-E="@G:&5A9&5R)RP@<W!R:6YT9BA?*"(E<R!-
M86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(BDL("1A<'!?
M;F%M92DI.PH@("`@8G)E86L["@IC87-E($U!24Y414Y!3D-%7T]55%!55%]!
M1U)%13H*("`@("\J($%G<F5E;65N="US='EL92!O=71P=70N("HO"B`@("`D
M=&5M<&QA=&4M/G-E="@G8V]N9FER;2<L(&9A;'-E+"!T<G5E*3L*("`@("1T
M96UP;&%T92T^<V5T*"=A9W)E92<L('1R=64L('1R=64I.PH@("`@)'1E;7!L
M871E+3YS970H)VYO=&EC92<L(&9A;'-E+"!T<G5E*3L*"B`@("`D;F]T:69I
M8V%T:6]N+3YP=7-H*%\H(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X
M="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S
M>7-T96TN(BDL("=H;W)D92YM97-S86=E)RD["B`@("`D=&5M<&QA=&4M/G-E
M="@G:&5A9&5R)RP@<W!R:6YT9BA?*"(E<R!497)M<R!O9B!!9W)E96UE;G0B
M*2P@)&%P<%]N86UE*2D["B`@("!B<F5A:SL*"F-A<V4@34%)3E1%3D%.0T5?
M3U544%547TY/5$E#13H*("`@("\J($YO=&EC92US='EL92!O=71P=70N("HO
M"B`@("`D=&5M<&QA=&4M/G-E="@G8V]N9FER;2<L(&9A;'-E+"!T<G5E*3L*
M("`@("1T96UP;&%T92T^<V5T*"=A9W)E92<L(&9A;'-E+"!T<G5E*3L*("`@
M("1T96UP;&%T92T^<V5T*"=N;W1I8V4G+"!T<G5E+"!T<G5E*3L*"B`@("`D
M=&5M<&QA=&4M/G-E="@G:&5A9&5R)RP@<W!R:6YT9BA?*"(E<R`M($YO=&EC
M92(I+"`D87!P7VYA;64I*3L*("`@(&)R96%K.PI]"@HO*B!-86ME('9A<FEA
M8FQE(&%R<F%Y(&YE961E9"!F;W(@=&5M<&QA=&5S+B`J+PHD=&%S:W,@/2!A
M<G)A>2@I.PIF;W)E86-H("@D=&%S:VQI<W0@87,@)'!R968I('L*("`@(&QI
M<W0H)&1E<V-R:7`L("1C:&5C:V5D*2`]("1M86EN="T^:6YF;TUA:6YT96YA
M;F-E*"1P<F5F*3L*("`@("1T87-K<UM=(#T@87)R87DH)W!R968G(#T^("1P
M<F5F+"`G9&5S8W)I<"<@/3X@)&1E<V-R:7`L("=C:&5C:V5D)R`]/B`D8VAE
M8VME9"`_("<@8VAE8VME9#TB8VAE8VME9"(G(#H@)R<I.PI]"@HD=&5M<&QA
M=&4M/G-E=$]P=&EO;B@G9V5T=&5X="<L('1R=64I.PHD=&5M<&QA=&4M/G-E
M="@G=&%S:W,G+"`D=&%S:W,I.PHD=&5M<&QA=&4M/G-E="@G;6%I;G1?=7)L
M)RP@)&UA:6YT+3YG971-86EN=&5N86YC949O<FU54DPH*2D["B1T96UP;&%T
M92T^<V5T*"=M86EN=%]P;W-T9&%T82<L("1M86EN="T^9V5T4&]S=$1A=&$H
M*2D["B1T96UP;&%T92T^<V5T*"=N;W1I9GDG+"!5=&EL.CIB=69F97)/=71P
M=70H87)R87DH)&YO=&EF:6-A=&EO;BP@)VYO=&EF>2<I+"!A<G)A>2@G;&ES
M=&5N97)S)R`]/B`G<W1A='5S)RDI*3L*"G)E<75I<F4@2$]21$5?5$5-4$Q!
M5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["F5C:&\@)'1E;7!L871E+3YF
M971C:"A(3U)$15]414U03$%415,@+B`G+VUA:6YT96YA;F-E+VUA:6YT96YA
M;F-E+FAT;6PG*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO
M;BUF;V]T97(N:6YC)SL*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]S97)V:6-E<R]O8G)O=W-E<B\`````````````````
M`````````````````````````````````````````````````````````#`P
M,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S4W
M`#`R,3,T-P`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V]B<F]W
M<V5R+VEN9&5X+G!H<```````````````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#8P-34`,3`U,34T,S,W-3<`,#(S,3<U`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO
M<F1E+W-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<"QV(#$N-BXQ,"XU(#(P
M,#8O,#$O,#$@,C$Z,CDZ,30@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`T+3(P,#8@0VAA<FQE<R!*+B!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I
M<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I.PIR97%U:7)E7V]N8V4@2$]2
M1$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D
M92]496UP;&%T92YP:'`G.PH*)'!A=&@@/2!5=&EL.CIG971&;W)M1&%T82@G
M<&%T:"<I.PH*:68@*&5M<'1Y*"1P871H*2D@>PH@("`@)&QI<W0@/2!A<G)A
M>2@I.PH@("`@)&%P<',@/2`D<F5G:7-T<GDM/FQI<W1!<'!S*&YU;&PL(&9A
M;'-E+"!015)-4U]214%$*3L*("`@(&9O<F5A8V@@*"1A<'!S(&%S("1A<'`I
M('L*("`@("`@("!I9B`H)')E9VES=')Y+3YH87--971H;V0H)V)R;W=S92<L
M("1A<'`I*2!["B`@("`@("`@("`@("1L:7-T6R1A<'!=(#T@87)R87DH)VYA
M;64G(#T^("1R96=I<W1R>2T^9V5T*"=N86UE)RP@)&%P<"DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)VEC;VXG(#T^("1R96=I<W1R>2T^
M9V5T*"=I8V]N)RP@)&%P<"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V)R;W=S96%B;&4G(#T^('1R=64I.PH@("`@("`@('T*("`@('T*
M?2!E;'-E('L*("`@("1P:65C97,@/2!E>'!L;V1E*"<O)RP@)'!A=&@I.PH@
M("`@)&QI<W0@/2`D<F5G:7-T<GDM/F-A;&Q">5!A8VMA9V4H)'!I96-E<ULP
M72P@)V)R;W=S92<L(&%R<F%Y*"=P871H)R`]/B`D<&%T:"DI.PI]"@II9B`H
M:7-?82@D;&ES="P@)U!%05)?17)R;W(G*2D@>PH@("`@2&]R9&4Z.F9A=&%L
M*"1L:7-T+"!?7T9)3$5?7RP@7U],24Y%7U\I.PI]"FEF("@A8V]U;G0H)&QI
M<W0I*2!["B`@("!(;W)D93HZ9F%T86PH7R@B3F]T:&EN9R!T;R!B<F]W<V4L
M(&=O(&)A8VLN(BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["GT*"B1T<&P@/2`\
M/#Q44$P*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@IF=6YC=&EO
M;B!C:&]O<V5/8FIE8W0H;VED*0I["B`@("!I9B`H(7=I;F1O=RYO<&5N97(@
M?'P@(7=I;F1O=RYO<&5N97(N;V)R;W=S97)#86QL8F%C:RD@>PH@("`@("`@
M(')E='5R;B!F86QS93L*("`@('T*"B`@("!V87(@<F5S=6QT(#T@=VEN9&]W
M+F]P96YE<BYO8G)O=W-E<D-A;&QB86-K*'=I;F1O=RYN86UE+"!O:60I.PH@
M("`@:68@*"%R97-U;'0I('L*("`@("`@("!W:6YD;W<N8VQO<V4H*3L*("`@
M("`@("!R971U<FX["B`@("!]"@H@("`@86QE<G0H<F5S=6QT*3L*("`@(')E
M='5R;B!F86QS93L*?0H\+W-C<FEP=#X*"CQD:78@8VQA<W,](FAE861E<B(^
M"B`\<W!A;B!C;&%S<STB<FEG:'1&;&]A="(^/'1A9SIC;&]S92`O/CPO<W!A
M;CX*(#QG971T97AT/D]B:F5C="!"<F]W<V5R/"]G971T97AT/@H\+V1I=CX*
M/&1I=B!C;&%S<STB:&5A9&5R8F]X(CX*(#QT86)L92!C;&%S<STB<W1R:7!E
M9"(@8V5L;'-P86-I;F<](C`B('-T>6QE/2)W:61T:#HQ,#`E(CX*(#QL;V]P
M.G)O=W,^"B`@/'1R/@H@("`\=&0^"B`@("`\=&%G.G)O=W,N:6-O;B`O/@H@
M("`@/'1A9SIR;W=S+FYA;64@+SX*("`@/"]T9#X*("`\+W1R/@H@/"]L;V]P
M.G)O=W,^"B`\+W1A8FQE/@H\+V1I=CX*5%!,.PH*)')O=W,@/2!A<G)A>2@I
M.PIF;W)E86-H("@D;&ES="!A<R`D<&%T:"`]/B`D=F%L=65S*2!["B`@("`D
M<F]W(#T@87)R87DH*3L*"B`@("`O+R!3970@=&AE(&EC;VXN"B`@("!I9B`H
M(65M<'1Y*"1V86QU97-;)VEC;VXG72DI('L*("`@("`@("`D<F]W6R=I8V]N
M)UT@/2!(;W)D93HZ:6UG*"1V86QU97-;)VEC;VXG72P@)'9A;'5E<ULG;F%M
M92==+"`G)RP@)R<I.PH@("`@?2!E;'-E:68@*"%E;7!T>2@D=F%L=65S6R=B
M<F]W<V5A8FQE)UTI*2!["B`@("`@("`@)')O=ULG:6-O;B==(#T@2&]R9&4Z
M.FEM9R@G=')E92]F;VQD97(N<&YG)RD["B`@("!](&5L<V4@>PH@("`@("`@
M("1R;W=;)VEC;VXG72`]($AO<F1E.CII;6<H)W1R964O;&5A9BYP;F<G*3L*
M("`@('T*"B`@("`O+R!3970@=&AE(&YA;64O;&EN:RX*("`@(&EF("@A96UP
M='DH)'9A;'5E<ULG8G)O=W-E86)L92==*2D@>PH@("`@("`@("1U<FP@/2!(
M;W)D93HZ87!P;&EC871I;VY5<FPH)W-E<G9I8V5S+V]B<F]W<V5R+R<I.PH@
M("`@("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@)W!A=&@G
M+"`D<&%T:"D["B`@("`@("`@)')O=ULG;F%M92==(#T@2&]R9&4Z.FQI;FLH
M)'5R;"D@+B`D=F%L=65S6R=N86UE)UT@+B`G/"]A/B<["B`@("!](&5L<V4@
M>PH@("`@("`@("1J<R`](")R971U<FX@8VAO;W-E3V)J96-T*"<B("X@861D
M<VQA<VAE<R@D<&%T:"D@+B`B)RD[(CL*("`@("`@("`D<F]W6R=N86UE)UT@
M/2!(;W)D93HZ;&EN:R@G(R<L('-P<FEN=&8H7R@B0VAO;W-E("5S(BDL("1V
M86QU97-;)VYA;64G72DL("<G+"`G)RP@)&IS*2`N("1V86QU97-;)VYA;64G
M72`N("<\+V$^)SL*("`@('T*"B`@("`D<F]W<UM=(#T@)')O=SL*?0H*)'1E
M;7!L871E(#T@)FYE=R!(;W)D95]496UP;&%T92@I.PHD=&5M<&QA=&4M/G-E
M=$]P=&EO;B@G9V5T=&5X="<L('1R=64I.PHD=&5M<&QA=&4M/G-E="@G<F]W
M<R<L("1R;W=S*3L*)'1E;7!L871E+3YS970H)V-L;W-E)RP@)SQA(&AR968]
M(B,B(&]N8VQI8VL](G=I;F1O=RYC;&]S92@I.R!R971U<FX@9F%L<V4[(CXG
M("X@2&]R9&4Z.FEM9R@G8VQO<V4N<&YG)RD@+B`G/"]A/B<I.PH*2&]R9&4Z
M.F%D9%-C<FEP=$9I;&4H)W-T<FEP92YJ<R<L("=H;W)D92<L('1R=64I.PIR
M97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G
M.PIE8VAO("1T96UP;&%T92T^<&%R<V4H)'1P;"D["G)E<75I<F4@2$]21$5?
M5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]P;W)T
M86PO````````````````````````````````````````````````````````
M`````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-3$U-#,S-S4W`#`R,3`P-@`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<```````````````````````
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#,Q,C<`,3`U,34T,S,W-3<`,#(R-#0W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H
M<"QV(#$N-#0N."XU(#(P,#8O,#,O,#@@,3@Z,#`Z-38@8VAU8VL@17AP("0*
M("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6ME($-O
M8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!#;W!Y<FEG:'0@
M,C`P,RTR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?
M1DE,15]?*2`N("<O+BXO+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@
M+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O0FQO8VLO
M0V]L;&5C=&EO;BYP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O261E;G1I
M='DN<&AP)SL*"FEF("@A075T:#HZ:7-!=71H96YT:6-A=&5D*"DI('L*("`@
M($AO<F1E.CIA=71H96YT:6-A=&EO;D9A:6QU<F52961I<F5C="@I.PI]"@HO
M+R!'970@9G5L;"!N86UE(&9O<B!T:71L92X*)&ED96YT:71Y(#T@)DED96YT
M:71Y.CIS:6YG;&5T;VXH*3L*)&9U;&QN86UE(#T@)&ED96YT:71Y+3YG9716
M86QU92@G9G5L;&YA;64G*3L*:68@*&5M<'1Y*"1F=6QL;F%M92DI('L*("`@
M("1F=6QL;F%M92`]($%U=&@Z.F=E=$%U=&@H*3L*?0H*+R\@26YS=&%N=&EA
M=&4@=&AE(&)L;V-K<R!O8FIE8W1S+@HD8FQO8VMS(#T@)DAO<F1E7T)L;V-K
M7T-O;&QE8W1I;VXZ.G-I;F=L971O;B@G<&]R=&%L)RD["B1L87EO=70@/2`F
M2&]R9&5?0FQO8VM?3&%Y;W5T7TUA;F%G97(Z.G-I;F=L971O;B@G<&]R=&%L
M)RP@)&)L;V-K<RP@)'!R969S+3YG971686QU92@G<&]R=&%L7VQA>6]U="<I
M*3L*"B\O($AA;F1L92!R97%U97-T960@86-T:6]N<RX*)&QA>6]U="T^:&%N
M9&QE*%5T:6PZ.F=E=$9O<FU$871A*"=A8W1I;VXG*2P*("`@("`@("`@("`@
M("`@("AI;G0I571I;#HZ9V5T1F]R;41A=&$H)W)O=R<I+`H@("`@("`@("`@
M("`@("`@*&EN="E5=&EL.CIG971&;W)M1&%T82@G8V]L)RDI.PII9B`H)&QA
M>6]U="T^=7!D871E9"@I*2!["B`@("`D<')E9G,M/G-E=%9A;'5E*"=P;W)T
M86Q?;&%Y;W5T)RP@)&QA>6]U="T^<V5R:6%L:7IE*"DI.PI]"@HD=&ET;&4@
M/2!?*")->2!0;W)T86P@3&%Y;W5T(BD["G)E<75I<F4@2$]21$5?5$5-4$Q!
M5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["G)E<75I<F4@2$]21$5?5$5-
M4$Q!5$53("X@)R]P;W)T86PO;65N=2YI;F,G.PHD;F]T:69I8V%T:6]N+3YN
M;W1I9GDH87)R87DH)VQI<W1E;F5R<R<@/3X@)W-T871U<R<I*3L*<F5Q=6ER
M92!(3U)$15]414U03$%415,@+B`G+W!O<G1A;"]E9&ET+FEN8R<["G)E<75I
M<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M97)V:6-E<R]P;W)T86PO:6YD97@N<&AP````````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`S,#$P`#$P-3$U-#,S-S4W`#`R,C8R,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@)$AO<F1E.B!H;W)D92]S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP+'8@
M,2XS.2XQ,"XW(#(P,#8O,#,O,#@@,3@Z,#`Z-38@8VAU8VL@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R
M869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(
M3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+RXN)RD["G)E
M<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U
M:7)E7V]N8V4@)TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP)SL*<F5Q=6ER
M95]O;F-E("=(;W)D92]";&]C:R],87EO=70O5FEE=RYP:'`G.PIR97%U:7)E
M7V]N8V4@)TAO<F1E+TED96YT:71Y+G!H<"<["@II9B`H(4%U=&@Z.FES075T
M:&5N=&EC871E9"@I*2!["B`@("!(;W)D93HZ875T:&5N=&EC871I;VY&86EL
M=7)E4F5D:7)E8W0H*3L*?0H*+R\@1V5T(&9U;&P@;F%M92!F;W(@=&ET;&4*
M)&ED96YT:71Y(#T@)DED96YT:71Y.CIS:6YG;&5T;VXH*3L*)&9U;&QN86UE
M(#T@)&ED96YT:71Y+3YG971686QU92@G9G5L;&YA;64G*3L*:68@*&5M<'1Y
M*"1F=6QL;F%M92DI('L*("`@("1F=6QL;F%M92`]($%U=&@Z.F=E=$%U=&@H
M*3L*?0H*+R\@1V5T(')E9G)E<V@@:6YT97)V86PN"FEF("@D<')E9G,M/F=E
M=%9A;'5E*"=S=6UM87)Y7W)E9G)E<VA?=&EM92<I*2!["B`@("`D<F5F<F5S
M:%]T:6UE(#T@)'!R969S+3YG971686QU92@G<W5M;6%R>5]R969R97-H7W1I
M;64G*3L*("`@("1R969R97-H7W5R;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R
M;"@G<V5R=FEC97,O<&]R=&%L+R<I.PI]"@HO+R!,;V%D(&QA>6]U="!F<F]M
M('!R969E<F5N8V5S+@HD;&%Y;W5T7W!R968@/2`D<')E9G,M/F=E=%9A;'5E
M*"=P;W)T86Q?;&%Y;W5T)RD["FEF("@A)&QA>6]U=%]P<F5F*2!["B`@("`D
M;&%Y;W5T7W!R968@/2!(;W)D95]";&]C:U]#;VQL96-T:6]N.CIG971&:7AE
M9$)L;V-K<R@I.PI]"B1V:65W(#T@;F5W($AO<F1E7T)L;V-K7TQA>6]U=%]6
M:65W*"1L87EO=71?<')E9BD["B1L87EO=71?:'1M;"`]("1V:65W+3YT;TAT
M;6PH*3L*)&-S<T%P<',@/2`D=FEE=RT^9V5T07!P;&EC871I;VYS*"D["B1L
M:6YK5&%G<R`]("1V:65W+3YG971,:6YK5&%G<R@I.PH*)'1I=&QE(#T@7R@B
M37D@4&]R=&%L(BD["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM
M;VXM:&5A9&5R+FEN8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]P
M;W)T86PO;65N=2YI;F,G.PHD;F]T:69I8V%T:6]N+3YN;W1I9GDH87)R87DH
M)VQI<W1E;F5R<R<@/3X@)W-T871U<R<I*3L*96-H;R`D;&%Y;W5T7VAT;6P[
M"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN
M8R<["@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC
M97,O<&]R=&%L+VUO8FEL92YP:'``````````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C4W,``Q,#4Q-30S,S<U-P`P,C(W-S(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J("1(
M;W)D93H@:&]R9&4O<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`L=B`R+C$U
M+C$P+C,@,C`P-B\P,2\P,2`R,3HR.3HQ-"!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L
M(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I.PIR97%U:7)E7V]N8V4@
M2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(
M;W)D92])9&5N=&ET>2YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TUO8FEL
M92YP:'`G.PH*:68@*"%!=71H.CIG971!=71H*"DI('L*("`@(&AE861E<B@G
M3&]C871I;VXZ("<@+B!5=&EL.CIA9&1087)A;65T97(H2&]R9&4Z.F%P<&QI
M8V%T:6]N57)L*"=L;V=I;BYP:'`G+"!T<G5E*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5R;"<L($AO<F1E.CIS
M96QF57)L*"DL(&9A;'-E*2D["B`@("!E>&ET.PI]"@HD:61E;G1I='D@/2`F
M261E;G1I='DZ.G-I;F=L971O;B@I.PHD9G5L;&YA;64@/2`D:61E;G1I='DM
M/F=E=%9A;'5E*"=F=6QL;F%M92<I.PII9B`H96UP='DH)&9U;&QN86UE*2D@
M>PH@("`@)&9U;&QN86UE(#T@075T:#HZ9V5T075T:"@I.PI]"@HD;2`]("9N
M97<@2&]R9&5?36]B:6QE*%\H(E=E;&-O;64B*2D["B1M+3YA9&0H;F5W($AO
M<F1E7TUO8FEL95]T97AT*'-P<FEN=&8H7R@B5V5L8V]M92P@)7,B*2P@)&9U
M;&QN86UE*2DI.PH*+R\@365S<WD@=V%Y(&]F(&QI;FMI;F<@=&\@86-T:79E
M(&%P<',@=&AA="!S=7!P;W)T(&UO8FEL90HO+R!D979I8V5S+B!3:&]U;&0@
M8F4@;6%D92!M;W)E(&5L96=A;G0@870@<V]M92!P;VEN="X*:68@*"%E;7!T
M>2@D<F5G:7-T<GDM/F%P<&QI8V%T:6]N<ULG;6EM<"==6R=S=&%T=7,G72D@
M)B8*("`@("1R96=I<W1R>2T^87!P;&EC871I;VYS6R=M:6UP)UU;)W-T871U
M<R==("$]("=I;F%C=&EV92<I('L*("`@("1M+3YA9&0H;F5W($AO<F1E7TUO
M8FEL95]L:6YK*"1R96=I<W1R>2T^9V5T*"=N86UE)RP@)VUI;7`G*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($AO<F1E.CIU<FPH)')E
M9VES=')Y+3YG970H)W=E8G)O;W0G+"`G;6EM<"<I("X@)R\G*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R96=I<W1R>2T^9V5T*"=N
M86UE)RP@)VUI;7`G*2DI.PI]"@HD;2T^9&ES<&QA>2@I.PH`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<```
M````````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V,30R`#$P-3$U-#,S
M-S4W`#`R,S`S,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]S97)V:6-E<R]P
M;W)T86PO<G!C<W5M+G!H<"QV(#(N,C8N-BXS(#(P,#8O,#$O,#$@,C$Z,CDZ
M,30@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@2F%N(%-C
M:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D
M969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO
M+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H
M<"<["G)E<75I<F5?;VYC92`G2&]R9&4O4E!#+G!H<"<["@II9B`H(4%U=&@Z
M.FES075T:&5N=&EC871E9"@I*2!["B`@("!(;W)D93HZ875T:&5N=&EC871I
M;VY&86EL=7)E4F5D:7)E8W0H*3L*?0H*)')P8U]S97)V97)S(#T@0'5N<V5R
M:6%L:7IE*"1P<F5F<RT^9V5T5F%L=64H)W)E;6]T95]S=6UM87)I97,G*2D[
M"FEF("@A:7-?87)R87DH)')P8U]S97)V97)S*2D@>PH@("`@)')P8U]S97)V
M97)S(#T@87)R87DH*3L*?0H*)&%C=&EO;DE$(#T@571I;#HZ9V5T1F]R;41A
M=&$H)V%C=&EO;DE$)RD["@HO+R!(86YD;&4@8VQI96YT<R!W:71H;W5T(&IA
M=F%S8W)I<'0N"FEF("AI<U]N=6QL*"1A8W1I;VY)1"DI('L*("`@(&EF("A5
M=&EL.CIG9710;W-T*"=E9&ET)RDI('L*("`@("`@("`D86-T:6]N240@/2`G
M961I="<["B`@("!](&5L<V5I9B`H571I;#HZ9V5T4&]S="@G<V%V92<I*2![
M"B`@("`@("`@)&%C=&EO;DE$(#T@)W-A=F4G.PH@("`@?2!E;'-E:68@*%5T
M:6PZ.F=E=%!O<W0H)V1E;&5T92<I*2!["B`@("`@("`@)&%C=&EO;DE$(#T@
M)V1E;&5T92<["B`@("!]"GT*"B\J(%)U;B!T:')O=6=H('1H92!A8W1I;VX@
M:&%N9&QE<G,@*B\*<W=I=&-H("@D86-T:6]N240I('L*8V%S92`G<V%V92<Z
M"B`@("!I9B`H*"1T;U]E9&ET(#T@571I;#HZ9V5T1F]R;41A=&$H)V5D:71?
M<V5R=F5R)RDI(#T](&YU;&PI('L*("`@("`@("`D=&]?961I="`](&-O=6YT
M*"1R<&-?<V5R=F5R<RD["B`@("`@("`@)')P8U]S97)V97)S6UT@/2!A<G)A
M>2@I.PH@("`@?0H@("`@)')P8U]S97)V97)S6R1T;U]E9&ET75LG=7)L)UT@
M("`@/2!5=&EL.CIG971&;W)M1&%T82@G=7)L)RD["B`@("`D<G!C7W-E<G9E
M<G-;)'1O7V5D:71=6R=U<V5R)UT@("`](%5T:6PZ.F=E=$9O<FU$871A*"=U
M<V5R)RD["B`@("`D<G!C7W-E<G9E<G-;)'1O7V5D:71=6R=P87-S=V0G72`]
M(%5T:6PZ.F=E=$9O<FU$871A*"=P87-S=V0G*3L*("`@("1P<F5F<RT^<V5T
M5F%L=64H)W)E;6]T95]S=6UM87)I97,G+"!S97)I86QI>F4H)')P8U]S97)V
M97)S*2D["B`@("`D<')E9G,M/G-T;W)E*"D["B`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*'-P<FEN=&8H7R@B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@
M<V%V960N(BDL("1R<&-?<V5R=F5R<ULD=&]?961I=%U;)W5R;"==*2P@)VAO
M<F1E+G-U8V-E<W,G*3L*("`@(&)R96%K.PH*8V%S92`G9&5L971E)SH*("`@
M("1T;U]D96QE=&4@/2!5=&EL.CIG971&;W)M1&%T82@G<V5R=F5R)RD["B`@
M("!I9B`H)'1O7V1E;&5T92`A/2`M,2D@>PH@("`@("`@("1D96QE=&5D7W-E
M<G9E<B`]("1R<&-?<V5R=F5R<ULD=&]?9&5L971E75LG=7)L)UT["B`@("`@
M("`@)'-E<G9E<E]L:7-T(#T@87)R87DH*3L*("`@("`@("!F;W(@*"1I(#T@
M,#L@)&D@/"!C;W5N="@D<G!C7W-E<G9E<G,I.R`D:2LK*2!["B`@("`@("`@
M("`@(&EF("@D:2`]/2`D=&]?9&5L971E*2!["B`@("`@("`@("`@("`@("!C
M;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<V5R=F5R7VQI
M<W1;72`]("1R<&-?<V5R=F5R<ULD:5T["B`@("`@("`@?0H@("`@("`@("1P
M<F5F<RT^<V5T5F%L=64H)W)E;6]T95]S=6UM87)I97,G+"!S97)I86QI>F4H
M)'-E<G9E<E]L:7-T*2D["B`@("`@("`@)&-H;W-E;D-O;'5M;G,@/2!E>'!L
M;V1E*"<[)RP@)'!R969S+3YG971686QU92@G<VAO=U]S=6UM87)I97,G*2D[
M"B`@("`@("`@:68@*"1C:&]S96Y#;VQU;6YS("$](&%R<F%Y*"<G*2D@>PH@
M("`@("`@("`@("`D;F5W0V]L=6UN<R`](&%R<F%Y*"D["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1C:&]S96Y#;VQU;6YS(&%S("1C:&]S96Y#;VQU;6XI('L*
M("`@("`@("`@("`@("`@("1C:&]S96Y#;VQU;6X@/2!E>'!L;V1E*"<L)RP@
M)&-H;W-E;D-O;'5M;BD["B`@("`@("`@("`@("`@("`D<F5M;W1E(#T@97AP
M;&]D92@G?"<L("1C:&]S96Y#;VQU;6Y;,%TI.PH@("`@("`@("`@("`@("`@
M:68@*&-O=6YT*"1R96UO=&4I("$](#,@?'P@)')E;6]T95LR72`]/2`D9&5L
M971E9%]S97)V97(I('L*("`@("`@("`@("`@("`@("`@("`D;F5W0V]L=6UN
M<UM=(#T@:6UP;&]D92@G+"<L("1C:&]S96Y#;VQU;6XI.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1P<F5F<RT^<V5T
M5F%L=64H)W-H;W=?<W5M;6%R:65S)RP@:6UP;&]D92@G.R<L("1N97=#;VQU
M;6YS*2D["B`@("`@("`@?0H@("`@("`@("1P<F5F<RT^<W1O<F4H*3L*("`@
M("`@("`D<G!C7W-E<G9E<G,@/2`D<V5R=F5R7VQI<W0["B`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E1H92!S97)V97(@7"(E<UPB
M(&AA<R!B965N(&1E;&5T960N(BDL("1D96QE=&5D7W-E<G9E<BDL("=H;W)D
M92YS=6-C97-S)RD["B`@("!](&5L<V4@>PH@("`@("`@("1N;W1I9FEC871I
M;VXM/G!U<V@H7R@B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D
M96QE=&5D+B(I+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@?0H@("`@8G)E86L[
M"GT*"B\J(%-H;W<@=&AE(&AE861E<BX@*B\*<F5Q=6ER95]O;F-E("=(;W)D
M92]0<F5F<R]522YP:'`G.PIR97%U:7)E($A/4D1%7T)!4T4@+B`G+V-O;F9I
M9R]P<F5F<RYP:'`G.PHD87!P(#T@)VAO<F1E)SL*4')E9G-?54DZ.F=E;F5R
M871E2&5A9&5R*"=R96UO=&4G*3L*"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53
M("X@)R]R<&-S=6TO<G!C<W5M+FEN8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!
M5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M````````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R-3(S-``Q,#4Q-30S
M,S<U-P`P,C,Q,S8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP+'8@,2XT+C(N,3,@,C`P-B\P,R\R,"`Q-3HP
M,#HP-B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:&%R
M;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG
M:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J($-O
M<'ER:6=H="`R,#`S+3(P,#8@36EC:&%E;"!087=L;W=S:WD@/&UJ<&%W;&]W
M<VMY0'EA:&]O+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"B\J*@H@*B!$971E
M<FUI;F4@:68@=&AE(&-U<G)E;G0@=7-E<B!C86X@<V5E(&%N(&%P<&QI8V%T
M:6]N+@H@*@H@*B!`<&%R86T@<W1R:6YG("`D87!P("`@("`@("`@(%1H92!A
M<'!L:6-A=&EO;B!N86UE+@H@*B!`<&%R86T@87)R87D@("`D<&%R86US("`@
M("`@(%1H92!A<'!L:6-A=&EO;B=S('!A<F%M971E<G,N"B`J($!P87)A;2!A
M<G)A>2`@)B1H87-#:&EL9')E;B`@4F5F97)E;F-E('1O(&%N(&%R<F%Y('1O
M('-E="!C:&EL9')E;B!F;&%G<R!I;BX*("HO"F9U;F-T:6]N(&-A;E-E92@D
M87!P+"`D<&%R86US+"`F)&AA<T-H:6QD<F5N*0I["B`@("!G;&]B86P@)')E
M9VES=')Y.PH*("`@('-T871I8R`D8V%C:&4@/2!A<G)A>2@I.PH@("`@<W1A
M=&EC("1I<T%D;6EN.PH@("`@<W1A=&EC("1U<V5R.PH*("`@("\O($EF('=E
M(&AA=F4@82!C86-H960@=F%L=64@9F]R('1H:7,@87!P;&EC871I;VXL(')E
M='5R;B!I="!N;W<N"B`@("!I9B`H:7-S970H)&-A8VAE6R1A<'!=*2D@>PH@
M("`@("`@(')E='5R;B`D8V%C:&5;)&%P<%T["B`@("!]"@H@("`@+R\@26YI
M=&EA;&EZ92!V87)I86)L97,@=V4G;&P@:V5E<"!U<VEN9R!I;B!S=6-C97-S
M:79E(&-A;&QS(&]N"B`@("`O+R!T:&4@9FER<W0@8V%L;"X*("`@(&EF("AI
M<U]N=6QL*"1I<T%D;6EN*2D@>PH@("`@("`@("1I<T%D;6EN(#T@075T:#HZ
M:7-!9&UI;B@I.PH@("`@("`@("1U<V5R(#T@075T:#HZ9V5T075T:"@I.PH@
M("`@?0H*("`@("\O($-H96-K(&EF('1H92!C=7)R96YT('5S97(@:&%S('!E
M<FUI<W-O;B!T;R!S964@=&AI<R!A<'!L:6-A=&EO;BP@86YD(&EF"B`@("`O
M+R!T:&4@87!P;&EC871I;VX@:7,@86-T:79E+B!(96%D:6YG<R!A<F4@=FES
M:6)L92!T;R!E=F5R>6]N92`H8G5T(&=E=`H@("`@+R\@9FEL=&5R960@;W5T
M(&QA=&5R(&EF('1H97D@:&%V92!N;R!C:&EL9')E;BDN($%D;6EN:7-T<F%T
M;W)S(&%L=V%Y<R!S964*("`@("\O(&%L;"!A<'!L:6-A=&EO;G,@97AC97!T
M('1H;W-E(&UA<FME9"`G:6YA8W1I=F4G+B!!;GEO;F4@=VET:"!32$]7"B`@
M("`O+R!P97)M:7-S:6]N<R!C86X@<V5E(&%N(&%P<&QI8V%T:6]N+"!B=70@
M4D5!1"!I<R!N965D960@=&\@86-T=6%L;'D@=7-E"B`@("`O+R!T:&4@87!P
M;&EC871I;VXN(%EO=2!C86X@=7-E('1H:7,@9&ES=&EN8W1I;VX@=&\@<VAO
M=R!A<'!L:6-A=&EO;G,@=&\*("`@("\O(&=U97-T<R!T:&%T('1H97D@;F5E
M9"!T;R!L;V<@:6X@=&\@=7-E+B!)9B!Y;W4@9&]N)W0@=V%N="!T:&5M('1O
M('-E90H@("`@+R\@87!P<R!T:&5Y(&-A;B=T('5S92P@=&AE;B!D;VXG="!G
M:79E(&=U97-T<R!32$]7('!E<FUI<W-I;VYS('1O"B`@("`O+R!A;GET:&EN
M9RX*("`@(&EF("@O+R!$;VXG="!S:&]W(&%P<&QI8V%T:6]N<R!T:&%T(&%R
M96XG="!I;G-T86QL960L(&5V96X@:68@=&AE>2=R90H@("`@("`@("\O(&-O
M;F9I9W5R960N"B`@("`@("`@*&ES<V5T*"1P87)A;7-;)V9I;&5R;V]T)UTI
M("8F("%I<U]D:7(H)'!A<F%M<ULG9FEL97)O;W0G72DI('Q\"@H@("`@("`@
M("\O($1O;B=T('-H;W<@8FQO8VMS(&]F(&%P<&QI8V%T:6]N<R!T:&%T(&%R
M96XG="!I;G-T86QL960N"B`@("`@("`@*"1P87)A;7-;)W-T871U<R==(#T]
M("=B;&]C:R<@)B8*("`@("`@("`@(6ES7V1I<B@D<F5G:7-T<GDM/F=E="@G
M9FEL97)O;W0G+"`D<&%R86US6R=A<'`G72DI*2!\?`H*("`@("`@("`O+R!&
M:6QT97(@;W5T(&5N=')I97,@=&AA="!A<F4@9&ES86)L960L(&AI9&1E;B!O
M<B!S:&]U;&1N)W0@<VAO=R!U<`H@("`@("`@("\O(&EN('1H92!M96YU+@H@
M("`@("`@("1P87)A;7-;)W-T871U<R==(#T]("=N;W1O;VQB87(G('Q\("1P
M87)A;7-;)W-T871U<R==(#T]("=H:61D96XG('Q\"B`@("`@("`@)'!A<F%M
M<ULG<W1A='5S)UT@/3T@)VEN86-T:79E)RD@>PH*("`@("`@("`D8V%C:&5;
M)&%P<%T@/2!F86QS93L*"B`@("!](&5L<V5I9B`H+R\@2&5A9&EN9W,@8V%N
M(&%L=V%Y<R!B92!S965N+@H@("`@("`@("`@("`@("@D<&%R86US6R=S=&%T
M=7,G72`]/2`G:&5A9&EN9R<I('Q\"@H@("`@("`@("`@("`@("\O($%D;6EN
M<R!S964@979E<GET:&EN9R!T:&%T(&UA:V5S(&ET('1O('1H:7,@<&]I;G0N
M"B`@("`@("`@("`@("`@*"1I<T%D;6EN('Q\"@H@("`@("`@("`@("`@("`O
M+R!5<V5R<R!W:&\@:&%V92!32$]7('!E<FUI<W-I;VYS('1O(&%C=&EV92!O
M<B!B;&]C:R!E;G1R:65S"B`@("`@("`@("`@("`@("\O('-E92!T:&5M+@H@
M("`@("`@("`@("`@("`H)')E9VES=')Y+3YH87-097)M:7-S:6]N*"1A<'`L
M(%!%4DU37U-(3U<I("8F"B`@("`@("`@("`@("`@("`H)'!A<F%M<ULG<W1A
M='5S)UT@/3T@)V%C=&EV92<@?'P*("`@("`@("`@("`@("`@("`D<&%R86US
M6R=S=&%T=7,G72`]/2`G8FQO8VLG*2DI*2!["@H@("`@("`@("1C86-H95LD
M87!P72`]('1R=64["@H@("`@("`@("\O($YO=&4@=&AA="!T:&4@<&%R96YT
M(&YO9&4L(&EF(&%N>2P@:&%S(&-H:6QD<F5N+@H@("`@("`@(&EF("AI<W-E
M="@D<&%R86US6R=M96YU7W!A<F5N="==*2D@>PH@("`@("`@("`@("`D:&%S
M0VAI;&1R96Y;)'!A<F%M<ULG;65N=5]P87)E;G0G75T@/2!T<G5E.PH@("`@
M("`@('T*("`@('T@96QS92!["B`@("`@("`@+R\@0V%T8V@@86YY=&AI;F<@
M=&AA="!F96QL('1H<F]U9V@L(&%N9"!D;VXG="!S:&]W(&ET+@H@("`@("`@
M("1C86-H95LD87!P72`](&9A;'-E.PH@("`@?0H*("`@(')E='5R;B`D8V%C
M:&5;)&%P<%T["GT*"B\J*@H@*B!"=6EL9',@=&AE(&UE;G4@<W1R=6-T=7)E
M(&1E<&5N9&EN9R!O;B!A<'!L:6-A=&EO;B!P97)M:7-S:6]N<RX*("HO"F9U
M;F-T:6]N(&)U:6QD365N=2@I"GL*("`@(&=L;V)A;"`D8V]N9BP@)')E9VES
M=')Y.PH*("`@("1A<'!S(#T@87)R87DH*3L*("`@("1C:&EL9')E;B`](&%R
M<F%Y*"D["B`@("!F;W)E86-H("@D<F5G:7-T<GDM/F%P<&QI8V%T:6]N<R!A
M<R`D87!P(#T^("1P87)A;7,I('L*("`@("`@("!I9B`H8V%N4V5E*"1A<'`L
M("1P87)A;7,L("1C:&EL9')E;BDI('L*("`@("`@("`@("`@)&%P<'-;)&%P
M<%T@/2`D<&%R86US.PH@("`@("`@('T*("`@('T*"B`@("`D;65N=2`](&%R
M<F%Y*"D["B`@("!F;W)E86-H("@D87!P<R!A<R`D87!P(#T^("1P87)A;7,I
M('L*("`@("`@("`O+R!&:6QT97(@;W5T(&%L;"!H96%D:6YG<R!W:71H;W5T
M(&-H:6QD<F5N+@H@("`@("`@(&EF("@D<&%R86US6R=S=&%T=7,G72`]/2`G
M:&5A9&EN9R<@)B8@96UP='DH)&-H:6QD<F5N6R1A<'!=*2D@>PH@("`@("`@
M("`@("!C;VYT:6YU93L*("`@("`@("!]"@H@("`@("`@("1M96YU6R1A<'!=
M(#T@)'!A<F%M<SL*("`@('T*"B`@("`O+R!!9&0@=&AE(&%D;6EN:7-T<F%T
M:6]N(&UE;G4@:68@=&AE('5S97(@:7,@86X@861M:6XN"B`@("!I9B`H075T
M:#HZ:7-!9&UI;B@I*2!["B`@("`@("`@)&UE;G5;)V%D;6EN:7-T<F%T:6]N
M)UT@/2!A<G)A>2@G;F%M92<@/3X@7R@B061M:6YI<W1R871I;VXB*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=I8V]N)R`]
M/B`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"D@+B`G+V%D;6EN:7-T<F%T:6]N
M+G!N9R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<W1A='5S)R`]/B`G:&5A9&EN9R<I.PH*("`@("`@("!F;W)E86-H("@D
M<F5G:7-T<GDM/FQI<W1!<'!S*"D@87,@)&%P<"D@>PH@("`@("`@("`@("!I
M9B`H(21R96=I<W1R>2T^:&%S365T:&]D*"=A9&UI;E]L:7-T)RP@)&%P<"DI
M('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`D;&ES="`]("1R96=I<W1R>2T^8V%L;$)Y4&%C:V%G92@D
M87!P+"`G861M:6Y?;&ES="<I.PH@("`@("`@("`@("!I9B`H:7-?82@D;&ES
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&9O<F5A8V@@*"1L:7-T(&%S
M("1M971H;V0@/3X@)'9A;',I('L*("`@("`@("`@("`@("`@(&EF("@D87!P
M("$]("=H;W)D92<I('L*("`@("`@("`@("`@("`@("`@("`D;F%M92`]("1R
M96=I<W1R>2T^9V5T*"=N86UE)RP@)&%P<"D["B`@("`@("`@("`@("`@("`@
M("`@:68@*"%E;7!T>2@D=F%L<ULG;F%M92==*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D;F%M92`N/2`G("<@+B`D=F%L<ULG;F%M92==.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@)&YA;64@/2!(;W)D93HZ<W1R:7!!8V-E<W-+
M97DH)'9A;'-;)VYA;64G72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D:6-O;B`](&ES<V5T*"1V86QS6R=I8V]N)UTI(#\@)')E9VES
M=')Y+3YG971);6%G941I<B@D87!P*2`N("<O)R`N("1V86QS6R=I8V]N)UT@
M.B`D<F5G:7-T<GDM/F=E="@G:6-O;B<L("1A<'`I.PH*("`@("`@("`@("`@
M("`@("1M96YU6R=A9&UI;FES=')A=&EO;E\G("X@)&%P<"`N("=?)R`N("1M
M971H;V1=(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^
M("1N86UE+`H@("`@("`@("`@("`@("`@("`@("=I8V]N)R`]/B`D:6-O;BP*
M("`@("`@("`@("`@("`@("`@("`G<W1A='5S)R`]/B`G86-T:79E)RP*("`@
M("`@("`@("`@("`@("`@("`G;65N=5]P87)E;G0G(#T^("=A9&UI;FES=')A
M=&EO;B<L"B`@("`@("`@("`@("`@("`@("`@)W5R;"<@/3X@2&]R9&4Z.G5R
M;"@D<F5G:7-T<GDM/F%P<&QI8V%T:6]N5V5B4&%T:"@D=F%L<ULG;&EN:R==
M+"`D87!P*2DL"B`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('T*"B`@("!I9B`H2&]R9&4Z.G-H;W=397)V:6-E
M*"=O<'1I;VYS)RD@)B8*("`@("`@("`D8V]N9ELG<')E9G,G75LG9')I=F5R
M)UT@(3T@)R<@)B8@)&-O;F9;)W!R969S)UU;)V1R:79E<B==("$]("=N;VYE
M)RD@>PH@("`@("`@("1M96YU6R=O<'1I;VYS)UT@/2!A<G)A>2@G;F%M92<@
M/3X@7R@B3W!T:6]N<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G<W1A='5S)R`]/B`G86-T:79E)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VEC;VXG(#T^("1R96=I<W1R>2T^9V5T26UA9V5$
M:7(H*2`N("<O<')E9G,N<&YG)RD["@H@("`@("`@("\J($=E="!A(&QI<W0@
M;V8@8V]N9FEG=7)A8FQE(&%P<&QI8V%T:6]N<RX@*B\*("`@("`@("`D<')E
M9G-?87!P<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)')E9VES=')Y
M+3YA<'!L:6-A=&EO;G,@87,@)&%P<&QI8V%T:6]N(#T^("1P87)A;7,I('L*
M("`@("`@("`@("`@:68@*"1P87)A;7-;)W-T871U<R==(#T]("=H96%D:6YG
M)R!\?`H@("`@("`@("`@("`@("`@)'!A<F%M<ULG<W1A='5S)UT@/3T@)V)L
M;V-K)R!\?`H@("`@("`@("`@("`@("`@(69I;&5?97AI<W1S*"1R96=I<W1R
M>2T^9V5T*"=F:6QE<F]O="<L("1A<'!L:6-A=&EO;BD@+B`G+V-O;F9I9R]P
M<F5F<RYP:'`G*2D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("\J($-H96-K(&EF('1H92!C=7)R96YT
M('5S97(@:&%S('!E<FUI<W-I;VX@=&\@<V5E('1H:7,*("`@("`@("`@("`@
M("H@87!P;&EC871I;VXL(&%N9"!I9B!T:&4@87!P;&EC871I;VX@:7,@86-T
M:79E+@H@("`@("`@("`@("`@*B!!9&UI;FES=')A=&]R<R!A;'=A>7,@<V5E
M(&%L;"!A<'!L:6-A=&EO;G,N("HO"B`@("`@("`@("`@(&EF("@H075T:#HZ
M:7-!9&UI;B@I("8F("1P87)A;7-;)W-T871U<R==("$]("=I;F%C=&EV92<I
M('Q\"B`@("`@("`@("`@("`@("`H)')E9VES=')Y+3YH87-097)M:7-S:6]N
M*"1A<'!L:6-A=&EO;BD@)B8*("`@("`@("`@("`@("`@("`H)'!A<F%M<ULG
M<W1A='5S)UT@/3T@)V%C=&EV92<I*2D@>PH@("`@("`@("`@("`@("`@)'!R
M969S7V%P<'-;)&%P<&QI8V%T:6]N72`](%\H)'!A<F%M<ULG;F%M92==*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D
M<')E9G-?87!P<ULG:&]R9&4G72DI('L*("`@("`@("`@("`@)&UE;G5;)V]P
M=&EO;G-?)R`N("=H;W)D92==(#T@87)R87DH)VYA;64G(#T^(%\H(D=L;V)A
M;"!/<'1I;VYS(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=S=&%T=7,G(#T^("=A8W1I=F4G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;65N
M=5]P87)E;G0G(#T^("=O<'1I;VYS)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VEC;VXG(#T^("1R96=I<W1R
M>2T^9V5T*"=I8V]N)RP@)VAO<F1E)RDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U<FPG(#T^($AO<F1E.CIA
M<'!L:6-A=&EO;E5R;"@G<V5R=FEC97,O<')E9G,N<&AP/V%P<#UH;W)D92<I
M*3L*("`@("`@("`@("`@=6YS970H)'!R969S7V%P<'-;)VAO<F1E)UTI.PH@
M("`@("`@('T*"B`@("`@("`@87-O<G0H)'!R969S7V%P<',I.PH@("`@("`@
M(&9O<F5A8V@@*"1P<F5F<U]A<'!S(&%S("1A<'`@/3X@)&YA;64I('L*("`@
M("`@("`@("`@)&UE;G5;)V]P=&EO;G-?)R`N("1A<'!=(#T@87)R87DH)VYA
M;64G(#T^("1N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<W1A='5S)R`]/B`G86-T:79E)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUE;G5?<&%R
M96YT)R`]/B`G;W!T:6]N<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=I8V]N)R`]/B`D<F5G:7-T<GDM/F=E="@G
M:6-O;B<L("1A<'`I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G=7)L)R`]/B!(;W)D93HZ87!P;&EC871I;VY5<FPH
M)W-E<G9I8V5S+W!R969S+G!H<#]A<'`])R`N("1A<'`I*3L*("`@("`@("!]
M"B`@("!]"@H@("`@:68@*$%U=&@Z.FES075T:&5N=&EC871E9"@I*2!["B`@
M("`@("`@)&UE;G5;)VQO9V]U="==(#T@87)R87DH)VYA;64G(#T^(%\H(DQO
M9R!O=70B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<W1A
M='5S)R`]/B`G86-T:79E)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G:6-O;B<@/3X@)')E9VES=')Y+3YG971);6%G941I<B@I("X@)R]L
M;V=O=70N<&YG)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=7)L)R`]/B!(;W)D93HZ9V5T4V5R=FEC94QI;FLH)VQO9V]U="<L("=H;W)D
M92<L('1R=64I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T
M87)G970G(#T^("=?<&%R96YT)RD["B`@("!](&5L<V4@>PH@("`@("`@("1M
M96YU6R=L;V=I;B==(#T@87)R87DH)VYA;64G(#T^(%\H(DQO9R!I;B(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-T871U<R<@/3X@)V%C
M=&EV92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:6-O;B<@
M/3X@)')E9VES=')Y+3YG971);6%G941I<B@I("X@)R]L;V=I;BYP;F<G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5R;"<@/3X@2&]R9&4Z
M.F=E=%-E<G9I8V5,:6YK*"=L;V=I;B<L("=H;W)D92<L('1R=64L(&9A;'-E
M*2D["B`@("!]"@H@("`@<F5T=7)N("1M96YU.PI]"@I`9&5F:6YE*"=!551(
M7TA!3D1,15(G+"!T<G5E*3L*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA
M;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?
M0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]4
M<F5E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O0FQO8VLN<&AP)SL*<F5Q
M=6ER95]O;F-E("=(;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<"<["@II9B`H
M(4%U=&@Z.F=E=$%U=&@H*2`F)B`A)&-O;F9;)VUE;G4G75LG86QW87ES)UTI
M('L*("`@($AO<F1E.CIA=71H96YT:6-A=&EO;D9A:6QU<F52961I<F5C="@I
M.PI]"@HD:7-?;6]Z8F%R(#T@*&)O;VPI571I;#HZ9V5T1F]R;41A=&$H)VUO
M>F)A<B<I.PH*+R\@4V5T('5P('1H92!T<F5E+@HD=')E92`]("9(;W)D95]4
M<F5E.CIS:6YG;&5T;VXH)VAO<F1E7VUE;G4G+"`G:F%V87-C<FEP="<I.PHD
M=')E92T^<V5T3W!T:6]N*&%R<F%Y*"=T87)G970G(#T^("1I<U]M;WIB87(@
M/R`G7V-O;G1E;G0G(#H@)VAO<F1E7VUA:6XG*2D["@HD;65N=2`](&)U:6QD
M365N=2@I.PIF;W)E86-H("@D;65N=2!A<R`D87!P(#T^("1P87)A;7,I('L*
M("`@(&EF("@D<&%R86US6R=S=&%T=7,G72`]/2`G8FQO8VLG*2!["B`@("`@
M("`@)&)L;V-K(#T@)DAO<F1E7T)L;V-K7T-O;&QE8W1I;VXZ.F=E=$)L;V-K
M*"1P87)A;7-;)V%P<"==+"`D<&%R86US6R=B;&]C:VYA;64G72D["B`@("`@
M("`@:68@*&ES7V$H)&)L;V-K+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@($AO<F1E.CIF871A;"@D8FQO8VLL(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@?0H@("`@("`@("1B;&]C:RT^8G5I;&14<F5E*"1T<F5E+"`P
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1P87)A;7-;)VUE
M;G5?<&%R96YT)UTI(#\@)'!A<F%M<ULG;65N=5]P87)E;G0G72`Z(&YU;&PI
M.PH@("`@?2!E;'-E('L*("`@("`@("`O+R!.965D('1O(')U;B!T:&4@;F%M
M92!T:')O=6=H(&=E='1E>'0@<VEN8V4@=&AE('5S97(G<PH@("`@("`@("\O
M(&QO8V%L92!M87D@;F]T(&AA=F4@8F5E;B!L;V%D960@=VAE;B!R96=I<W1R
M>2YP:'`@=V%S"B`@("`@("`@+R\@<&%R<V5D+@H@("`@("`@("1N86UE(#T@
M7R@D<&%R86US6R=N86UE)UTI.PH*("`@("`@("`O+R!(96%D:6YG<R!H879E
M(&YO('=E8G)O;W0[('1H97DG<F4@:G5S="!C;VYT86EN97)S(&9O<B!O=&AE
M<@H@("`@("`@("\O(&UE;G4@:71E;7,N"B`@("`@("`@:68@*&ES<V5T*"1P
M87)A;7-;)W5R;"==*2D@>PH@("`@("`@("`@("`D=7)L(#T@)'!A<F%M<ULG
M=7)L)UT["B`@("`@("`@?2!E;'-E:68@*"1P87)A;7-;)W-T871U<R==(#T]
M("=H96%D:6YG)R!\?"`A:7-S970H)'!A<F%M<ULG=V5B<F]O="==*2D@>PH@
M("`@("`@("`@("`D=7)L(#T@;G5L;#L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=7)L(#T@2&]R9&4Z.G5R;"@D<&%R86US6R=W96)R;V]T)UT@
M+B`G+R<@+B`H:7-S970H)'!A<F%M<ULG:6YI=&EA;%]P86=E)UTI(#\@)'!A
M<F%M<ULG:6YI=&EA;%]P86=E)UT@.B`G)RDI.PH@("`@("`@('T*"B`@("`@
M("`@)&YO9&5?<&%R86US(#T@87)R87DH)W5R;"<@/3X@)'5R;"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G=&%R9V5T)R`]/B!I<W-E="@D<&%R
M86US6R=T87)G970G72D@/R`D<&%R86US6R=T87)G970G72`Z(&YU;&PL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VEC;VXG(#T^(&ES<V5T*"1P
M87)A;7-;)VEC;VXG72D@/R`D<&%R86US6R=I8V]N)UT@.B`D<F5G:7-T<GDM
M/F=E="@G:6-O;B<L("1A<'`I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=I8V]N9&ER)R`]/B`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`I.PH@("`@("`@("1T<F5E+3YA9&1.;V1E*"1A<'`L("%E;7!T>2@D
M<&%R86US6R=M96YU7W!A<F5N="==*2`_("1P87)A;7-;)VUE;G5?<&%R96YT
M)UT@.B!N=6QL+"`D;F%M92P@,"P@9F%L<V4L("1N;V1E7W!A<F%M<RD["B`@
M("!]"GT*"B\O($EF('=E)W)E('-E<G9I;F<@82!R97%U97-T('1O('1H92!*
M4R!U<&1A=&4@8VQI96YT+"!J=7-T(')E;F1E<B!T:&4*+R\@=7!D871E9"!N
M;V1E(&IA=F%S8W)I<'0N"FEF("A5=&EL.CIG971&;W)M1&%T82@G:'1T<&-L
M:65N="<I*2!["B`@("!H96%D97(H)T-O;G1E;G0M5'EP93H@=&5X="]J879A
M<V-R:7!T.R!C:&%R<V5T/2<@+B!.3%,Z.F=E=$-H87)S970H*2D["B`@("!(
M;W)D93HZ:6YL:6YE4V-R:7!T1FEL97,H*3L*("`@(&5C:&\@)'1R964M/G)E
M;F1E<DYO9&5$969I;FET:6]N<R@I.PH@("`@97AI=#L*?0H*)')T;"`](&ES
M<V5T*"1N;'-;)W)T;"==6R1L86YG=6%G95TI.PHD8F]D>4-L87-S(#T@)W-I
M9&5B87(G.PII9B`H)&)R;W=S97(M/FAA<U%U:7)K*"=S8W)O;&QB87)?:6Y?
M=V%Y)RDI('L*("`@("1B;V1Y0VQA<W,@+CT@)R!S8W)O;&QB87(M<75I<FLG
M.PI]"DAO<F1E.CIA9&138W)I<'1&:6QE*"=H='1P8VQI96YT+FIS)RP@)VAO
M<F1E)RP@=')U92D["DAO<F1E.CIA9&138W)I<'1&:6QE*"=H:61E86)L92YJ
M<R<L("=H;W)D92<L('1R=64I.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N
M("<O8V]M;6]N+6AE861E<BYI;F,G.PIR97%U:7)E($A/4D1%7U1%35!,051%
M4R`N("<O<&]R=&%L+W-I9&5B87(N:6YC)SL*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP````````````````````
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,C(U,#0`,3`U,34T,S,W-3<`,#(S,#(W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP+'8@,2XS+C(N-B`R,#`V+S`U+S(Y(#$V.C0P.C0Y(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($MA<G-T96X@1F]U<FUO;G0@/&MA
M<G-T96Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@IF=6YC=&EO;B!L
M;V%D0V%T96=O<FEE<R@D9&5V:6-E*0I["B`@("!G;&]B86P@)&1T+"`D8V%T
M96=O<FEE<TUA<"P@)&UI<W-I;F=397)V97)#871E9V]R:65S.PH@("`@)&UA
M<"`]("1D="T^9V5T3V)J96-T*"1D979I8V4*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+B`G.F-A=&5G;W)I97,G*3L*("`@(&EF("AI<U]A*"1M87`L
M("=014%27T5R<F]R)RDI('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]
M"@H@("`@)&-A=&5G;W)I97--87`@/2`D;6%P+3YG970H)VUA<"<I.PH@("`@
M)&UI<W-I;F=397)V97)#871E9V]R:65S(#T@)&UA<"T^9V5T*"=M:7-S:6YG
M4V5R=F5R0V%T96=O<FEE<R<I.PH*("`@(')E='5R;B!T<G5E.PI]"@IF=6YC
M=&EO;B!S=&]R94-A=&5G;W)I97,H)&1E=FEC92D*>PH@("`@9VQO8F%L("1D
M="P@)&-A=&5G;W)I97--87`L("1M:7-S:6YG4V5R=F5R0V%T96=O<FEE<SL*
M"B`@("!I9B`H(6ES7V%R<F%Y*"1C871E9V]R:65S36%P*2D@>PH@("`@("`@
M(')E='5R;CL@+R\@;F]T:&EN9R!T;R!D;PH@("`@?0H*("`@("1M87`@/2`F
M;F5W($1A=&%4<F5E3V)J96-T*"1D979I8V4@+B`G.F-A=&5G;W)I97,G*3L*
M("`@("1M87`M/G-E="@G;6%P)RP@)&-A=&5G;W)I97--87`I.PH@("`@)&UA
M<"T^<V5T*"=M:7-S:6YG4V5R=F5R0V%T96=O<FEE<R<L("1M:7-S:6YG4V5R
M=F5R0V%T96=O<FEE<RD["@H@("`@)'(@/2`D9'0M/F%D9"@D;6%P*3L*("`@
M(&EF("AI<U]A*"1R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@+R\@3V)J
M96-T(&%L<F5A9'D@97AI<W1S.B!U<&1A=&4@:6YS=&5A9"X*("`@("`@("`D
M<B`]("1D="T^=7!D871E1&%T82@D;6%P*3L*("`@('T*?0H*0&1E9FEN92@G
M2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I.PIR
M97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q
M=6ER95]O;F-E("=(;W)D92]0<F5F<R]522YP:'`G.PH*:68@*"%!=71H.CII
M<T%U=&AE;G1I8V%T960H*2D@>PH@("`@2&]R9&4Z.F%U=&AE;G1I8V%T:6]N
M1F%I;'5R95)E9&ER96-T*"D["GT*"B1D<FEV97(@/2`D1TQ/0D%,4ULG8V]N
M9B==6R=D871A=')E92==6R=D<FEV97(G73L*)'!A<F%M<R`]($AO<F1E.CIG
M971$<FEV97)#;VYF:6<H)V1A=&%T<F5E)RP@)&1R:79E<BD["B1P87)A;7,@
M/2!A<G)A>5]M97)G92@D<&%R86US+"!A<G)A>2@@)V=R;W5P)R`]/B`G<WEN
M8VUL)R`I*3L*"B1D="`]("9$871A5')E93HZ<VEN9VQE=&]N*"1D<FEV97(L
M("1P87)A;7,I.PH*+RH@57-E<FYA;64@:7,@=7-E9"!A<R!R;V]T(&9O<B!S
M>6YC;6P@9&%T871R964N("`H1F]R(&AI<W1O<FEC"B`J(')E87-O;G,N*2`J
M+PHD=7-E<FYA;64@/2!!=71H.CIG971!=71H*"D["B1G<F]U<"`]("=S>6YC
M;6PG.R`O+R!P<F5F97)E;F-E(&=R;W5P"@HD86-T:6]N240@/2!5=&EL.CIG
M971&;W)M1&%T82@G86-T:6]N240G*3L*<W=I=&-H("@D86-T:6]N240I('L*
M8V%S92`G9&5L971E86YC:&]R)SH*("`@("1D979I8V5I9"`](%5T:6PZ.F=E
M=$9O<FU$871A*"=D979I8V5I9"<I.PH@("`@)&1B(#T@571I;#HZ9V5T1F]R
M;41A=&$H)V1B)RD["B`@("`D:60@/2`D=7-E<FYA;64@+B`G.B<@+B`D9&5V
M:6-E:60@+B`G.G-U;6UA<GDZ)R`N("1D8CL*("`@("1I9"`]("1D="T^<F5M
M;W9E*"1I9"QF86QS92D["B`@("!I9B`H:7-?82@D:60L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B
M17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(BDL("1I9"T^9V5T365S
M<V%G92@I*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=H;W)D92YE
M<G)O<B<I.PH@("`@?2!E;'-E('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP
M=7-H*%\H(B1I9"!3>6YC(&%N8VAO<B!F;W(@9&5V:6-E("<D9&5V:6-E:60G
M(&1A=&%B87-E("<D9&(G(&1E;&5T960N(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G:&]R9&4N<W5C8V5S<R<I.PH@("`@?0H@("`@8G)E86L[
M"@IC87-E("=D96QE=&5L;V<G.@H@("`@)&ED(#T@)&1T+3YR96UO=F4H)W!R
M979I;W5S4WEN8TQO9R<L(&9A;'-E*3L*("`@(&EF("AI<U]A*"1I9"P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R
M:6YT9BA?*")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B*2P@)&ED+3YG
M971-97-S86=E*"DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAO
M<F1E+F5R<F]R)RD["B`@("!](&5L<V4@>PH@("`@("`@("1N;W1I9FEC871I
M;VXM/G!U<V@H7R@B4WEN8R!L;V<@9&5L971E9"(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VAO<F1E+G-U8V-E<W,G*3L*("`@('T*("`@(&)R
M96%K.PH*(&-A<V4@)W5P9&%T95]C871E9V]R:65S)SH*("`@("1D979I8V4@
M/2!5=&EL.CIG971&;W)M1&%T82@G9&5V:6-E)RD["B`@("!L;V%D0V%T96=O
M<FEE<R@D9&5V:6-E*3L*"B`@("!F;W)E86-H("@D7U!/4U0@87,@)&ME>2`]
M/B`D=F%L=64I('L*("`@("`@("!I9B`H<W5B<W1R*"1K97DL(#`L(#DI(#T]
M("=C871E9V]R>3HG*2!["B`@("`@("`@("`@("1C871E9V]R>2`]('-U8G-T
M<B@D:V5Y+#DI.PH@("`@("`@("`@("!L:7-T*"PD8V%T96=O<GDI(#T@97AP
M;&]D92@G.B<L("1K97DL,BD["B`@("`@("`@("`@("1V86QU92`](%5T:6PZ
M.F=E=$9O<FU$871A*"1K97DI.PH@("`@("`@("`@("`D8V%T96=O<FEE<TUA
M<%LD8V%T96=O<GE=(#T@)'9A;'5E.PH@("`@("`@("`@("!U;G-E="@D;6ES
M<VEN9U-E<G9E<D-A=&5G;W)I97-;)'9A;'5E72D["B`@("`@("`@?0H@("`@
M?0H@("`@<W1O<F5#871E9V]R:65S*"1D979I8V4I.PH@("`@)&YO=&EF:6-A
M=&EO;BT^<'5S:"A?*")-87!P:6YG<R!S=&]R960N(BDI.PH*("`@(&)R96%K
M.PI]"@HO*B!3:&]W('1H92!H96%D97(N("HO"G)E<75I<F5?;VYC92`G2&]R
M9&4O4')E9G,O54DN<&AP)SL*<F5Q=6ER92!(3U)$15]"05-%("X@)R]C;VYF
M:6<O<')E9G,N<&AP)SL*)&%P<"`]("=H;W)D92<["@I0<F5F<U]523HZ:&%N
M9&QE1F]R;2@D9W)O=7`L("1P<F5F<RD["E!R969S7U5).CIG96YE<F%T94AE
M861E<B@D9W)O=7`I.PH*+R\@0'1O9&\Z(&UO=F4@=&AI<R!T;R!T96UP;&%T
M90H_/@H*/&9O<FT@;65T:&]D/2)P;W-T(B!N86UE/2)P<F5F<R(@86-T:6]N
M/2(\/W!H<"!E8VAO($AO<F1E.CI!<'!L:6-A=&EO;E523"@G+W-E<G9I8V5S
M+W!R969S+G!H<"<I(#\^(CX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB
M86-T:6]N240B('9A;'5E/2)U<&1A=&5?<')E9G,B("\^"CQI;G!U="!T>7!E
M/2)H:61D96XB(&YA;64](F=R;W5P(B!V86QU93TB/#]P:'`@96-H;R`D9W)O
M=7`@/SXB("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%P<"(@=F%L
M=64](FAO<F1E(B`O/@I3;W)R>2P@;F\@8V]N9FEG=7)A8FQE(&]P=&EO;G,@
M>65T+@I3964@/&$@:')E9CTB:'1T<#HO+W=I:VDN:&]R9&4N;W)G+U-Y;F-(
M;W=4;R(^4WEN8R!(;W=4;SPO83X@9F]R(&9U<G1H97(@:6YF;W)M871I;VXN
M"CP_<&AP("\J("1H96QP;&EN:STG)SL@)'!R968])W-Y;F-M;%]C<F5A=&5?
M;&]G)SL@<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@)VAO
M<F1E)RD@+B`G+W!R969S+V-H96-K8F]X+FEN8R<@*B\@/SX*"CQP(&-L87-S
M/2)N;W=R87`B/@H@/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O
M;B(@=F%L=64](E-A=F4@3W!T:6]N<R(@+SX*(#QI;G!U="!T>7!E/2)R97-E
M="(@8VQA<W,](F)U='1O;B(@=F%L=64](E5N9&\@0VAA;F=E<R(@+SX*(#QI
M;G!U="!T>7!E/2)B=71T;VXB(&-L87-S/2)B=71T;VXB('9A;'5E/2)2971U
M<FX@=&\@3W!T:6]N<R(@;VYC;&EC:STB9&]C=6UE;G0N<')E9G,N86-T:6]N
M240N=F%L=64],#L@9&]C=6UE;G0N<')E9G,N9W)O=7`N=F%L=64])R<[(&1O
M8W5M96YT+G!R969S+G-U8FUI="@I.R(@+SX*/"]P/@H\+V9O<FT^"CP_<&AP
M"B1I9"`]("1D="T^9V5T260H)'5S97)N86UE*3L*)&1E=FEC97,@/2`D9'0M
M/F=E=$)Y260H1$%40512145?1D]234%47T9,050L("1I9"P@=')U92P@1$%4
M0512145?4D]/5"P@,2D["FEF("AI<U]A<G)A>2@D9&5V:6-E<RD@)B8@8V]U
M;G0H)&1E=FEC97,I(#X@,2D@>PH@("`@87)R87E?<VAI9G0H)&1E=FEC97,I
M.PH*+R\@0'1O9&\Z(&UO=F4@=&\@=&5M<&QA=&4*/SX*/&1I=B!C;&%S<STB
M:&5A9&5R(CX*(#P_<&AP(&5C:&\@2&]R9&4Z.FQI;FLH2&]R9&4Z.G-E;&95
M4DPH*2P@7R@B4F5F<F5S:"(I*2`N($AO<F1E.CII;6<H)W)E;&]A9"YP;F<G
M+"!?*")296QO860B*2P@)R<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO
M<F1E)RDI(#\^/"]A/@H@5&EM97-T86UP<R!O9B!S=6-C97-S9G5L('-Y;F,@
M<V5S<VEO;G,*/"]D:78^"CQT86)L92!C;&%S<STB<W1R:7!E9"(@/@H@/'1R
M/@H@(#QT:#Y$979I8V4\+W1H/CQT:#Y$871A8F%S93PO=&@^/'1H/E-E<G9E
M<BU44SPO=&@^/'1H/D-L:65N="U44SPO=&@^"B`@/'1H/D1E;&5T93PO=&@^
M"B`\+W1R/@H*/#]P:'`*("`@(&9O<F5A8V@@*"1D979I8V5S(&%S("1D979I
M8V4I('L*("`@("`@("`D=&UP(#T@97AP;&]D92@G.B<L("1D979I8V4I.PH@
M("`@("`@("1D979I8V5?;F%M92`](&%R<F%Y7W!O<"@D=&UP*3L*"B`@("`@
M("`@)&ED(#T@)&1T+3YG971)9"@D9&5V:6-E("X@)SIS=6UM87)Y)RD["B`@
M("`@("`@:68@*&ES7V$H)&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(&-O;G1I;G5E.PH@("`@("`@('T*("`@("`@("`D<W5M;6%R:65S(#T@
M)&1T+3YG971">4ED*$1!5$%44D5%7T9/4DU!5%]44D5%+"`D:60L(&9A;'-E
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1$%40512145?
M4D]/5"P@,BD["@H@("`@("`@(&EF("AI<U]A<G)A>2@D<W5M;6%R:65S6R1I
M9%TI*2!["B`@("`@("`@("`@("1O(#T@)B`D9'0M/F=E=$]B:F5C=',H87)R
M87E?:V5Y<R@D<W5M;6%R:65S6R1I9%TI*3L*"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1O(&%S("1O;RD@>PH@("`@("`@("`@("`@("`@)'0@/2!E>'!L;V1E
M*"<Z)RP@)&]O+3YG971.86UE*"DI.PH@("`@("`@("`@("`@("`@)&1B(#T@
M87)R87E?<&]P*"1T*3L*("`@("`@("`@("`@("`@("1S82`]("1O;RT^9V5T
M*"=397)V97)!;F-H;W(G*3L*("`@("`@("`@("`@("`@("1C82`]("1O;RT^
M9V5T*")#;&EE;G1!;F-H;W(B*3L*"B`@("`@("`@("`@("`@("`O+R!`=&]D
M;SH@;6]V92!T;R!T96UP;&%T90H@("`@("`@("`@("`@("`@96-H;R`G/'1R
M/CQT9#XG("X@)&1E=FEC95]N86UE("X@)SPO=&0^/'1D/B<@+B`D9&(@+B`G
M/"]T9#X\=&0^)R`N"B`@("`@("`@("`@("`@("`@("`@<W1R9G1I;64H)'!R
M969S+3YG971686QU92@G9&%T95]F;W)M870G*2`N("<@)4@Z)4TG+"!A<G)A
M>5]P;W`H)'-A*2D@+@H@("`@("`@("`@("`@("`@("`@("<\+W1D/CQT9#XG
M("X@87)R87E?<&]P*"1C82D@+B`G/"]T9#X\=&0^)R`N"B`@("`@("`@("`@
M("`@("`@("`@)SQF;W)M(&UE=&AO9#TB<&]S="(^/&EN<'5T('1Y<&4](FAI
M9&1E;B(@;F%M93TB9&5V:6-E:60B('9A;'5E/2(G("X*("`@("`@("`@("`@
M("`@("`@("`D9&5V:6-E7VYA;64@+B`G(B\^)R`N"B`@("`@("`@("`@("`@
M("`@("`@)SQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V
M86QU93TB9&5L971E86YC:&]R(B`O/B<@+@H@("`@("`@("`@("`@("`@("`@
M("<\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)D8B(@=F%L=64](B<@+B`D
M9&(@+B`G(B`O/B<@+@H@("`@("`@("`@("`@("`@("`@("<\:6YP=70@='EP
M93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU93TB1&5L971E(B`O/CPO
M9F]R;3XG("X*("`@("`@("`@("`@("`@("`@("`G/"]T9#X\+W1R/B<["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]"B`@("!E8VAO("<\+W1A8FQE
M/B<["GT*"B\O($-A=&5G;W)Y(&AA;F1L:6YG+@IR97%U:7)E7V]N8V4@)TAO
M<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`G.PHD8TUA;F%G97(@/2`F
M;F5W(%!R969S7T-A=&5G;W)Y36%N86=E<B@I.PH*9F]R96%C:"`H)&1E=FEC
M97,@87,@)&1E=FEC92D@>PH@("`@)'1M<"`](&5X<&QO9&4H)SHG+"`D9&5V
M:6-E*3L*("`@("1D979I8V5?;F%M92`](&%R<F%Y7W!O<"@D=&UP*3L*"B`@
M("!I9B`H(6QO861#871E9V]R:65S*"1D979I8V4I*2!["B`@("`@("`@8V]N
M=&EN=64["B`@("!]"B\O=F%R7V1U;7`H)&-L:65N"B`@("`D:2`](#`["B\O
M($!T;V1O.B!M;W9E('1O('1E;7!L871E"C\^"CQF;W)M(&UE=&AO9#TB<&]S
M="(@;F%M93TB<')E9G,B(&%C=&EO;CTB/#]P:'`@96-H;R!(;W)D93HZ<V5L
M9E523"@I(#\^(CX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB86-T:6]N
M240B('9A;'5E/2)U<&1A=&5?8V%T96=O<FEE<R(@+SX*/&EN<'5T('1Y<&4]
M(FAI9&1E;B(@;F%M93TB9&5V:6-E(B!V86QU93TB/#]P:'`@96-H;R`D9&5V
M:6-E(#\^(B`O/@H*/&1I=B!C;&%S<STB:&5A9&5R(CX*(#P_<&AP(&5C:&\@
M2&]R9&4Z.FQI;FLH2&]R9&4Z.G-E;&954DPH*2P@7R@B4F5F<F5S:"(I*2`N
M($AO<F1E.CII;6<H)W)E;&]A9"YP;F<G+"!?*")296QO860B*2P@)R<L("1R
M96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI(#\^/"]A/@H@36%P<&EN
M9R!O9B!#871E9V]R:65S(&9O<B!$979I8V4@/#]P:'`@96-H;R`D9&5V:6-E
M7VYA;64@/SX*/"]D:78^"CQT86)L92!C;&%S<STB<W1R:7!E9"(@/@H\='(^
M/'1H/D1E=FEC92!#871E9V]R>3PO=&@^/'1H/DAO<F1E($-A=&5G;W)Y/"]T
M:#X*/'1H/E-U;6UA<GD@;V8@;&%S="!E;F-O=6YT97)E9"!E;G1R>3PO=&@^
M/"]T<CX*/#]P:'`*("`@(&9O<F5A8V@@*"1C871E9V]R:65S36%P(&%S("1K
M97D@/3X@)'9A;'5E*2!["B`@("`@("`@96-H;R`B/'1R(&-L87-S/5PB:71E
M;2(@+B`H*RLD:2`E(#(I("X@(EPB/CQT9#XB"B`@("`@("`@+B`D:V5Y+B`G
M/"]T9#X\=&0^)SL*("`@("`@("`D=B`](&ES7V%R<F%Y*"1V86QU92D@/R`G
M)R`Z("1V86QU93L*("`@("`@("!E8VAO("1C36%N86=E<BT^9V5T4V5L96-T
M*"=C871E9V]R>3HG("X@)&ME>2P@)'8I.PH@("`@("`@(&5C:&\@)SPO=&0^
M/'1D/B<["B`@("`@("`@:68@*&ES7V%R<F%Y*"1V86QU92DI('L*("`@("`@
M("`@("`@96-H;R`D=F%L=65;,%T["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@96-H;R`B)FYB<W`[(CL*("`@("`@("!]"B`@("`@("`@96-H;R`G
M/"]T9#X\+W1R/B<["@H@("`@?0H@("`@9F]R96%C:"`H)&UI<W-I;F=397)V
M97)#871E9V]R:65S(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@96-H
M;R`G/'1R/CQT9#X\96T^=&\@8F4@9&5F:6YE9#PO96T^/"]T9#X\=&0^)R`N
M("1K97D@+B`G/"]T9#X\=&0^)R`N("1V86QU92`N("<\+W1D/CPO='(^)SL*
M("`@('T*"B`@("!E8VAO("(\+W1A8FQE/EQN(CL*("`@(&5C:&\@)SQI;G!U
M="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB('9A;'5E/2)5<&1A=&4@
M0V%T96=O<FEE<R(@+SX\+V9O<FT^)SL*?0H*+RH@1&ES<&QA>2!L;V<@;V8@
M<')E=FEO=7,@<WEN8RX@*B\*)&YA;64@/2`G<')E=FEO=7-3>6YC3&]G)SL*
M)&EN9F\@/2`F)&1T+3YG971/8FIE8W0H)&YA;64I.PH*:68@*"%I<U]A*"1I
M;F9O+"`G4$5!4E]%<G)O<B<I("8F(&ES7V%R<F%Y*"1L;V<@/2`D:6YF;RT^
M9V5T*"=L;V<G*2DI('L*("`@("\O($!T;V1O(&UO=F4@=&\@=&5M<&QA=&4*
M/SX*/&1I=B!C;&%S<STB:&5A9&5R(CX*(#P_<&AP(&5C:&\@7R@B3&]G(&]F
M('!R979I;W5S('-Y;F,@<V5S<VEO;B(I(#\^"B`\/W!H<"!E8VAO($AO<F1E
M.CIL:6YK*$AO<F1E.CIS96QF55),*"DL(%\H(E)E9G)E<V@B*2D@+B!(;W)D
M93HZ:6UG*"=R96QO860N<&YG)RP@7R@B4F5F<F5S:"(I*2`_/CPO83X*(#QF
M;W)M(&UE=&AO9#TB<&]S="(^"B`@/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M
M93TB86-T:6]N240B('9A;'5E/2)D96QE=&5L;V<B("\^"B`@/&EN<'5T('1Y
M<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@
M7R@B1&5L971E($QO9R(I(#\^(B`O/@H@/"]F;W)M/@H\+V1I=CX*"CQT86)L
M92!C;&%S<STB<W1R:7!E9"(@=VED=&@](C$P,"4B/@H@/'1R(&-L87-S/2)N
M;W=R87`B/@H@(#QT:"!W:61T:#TB-24B/CP_<&AP(&5C:&\@7R@B5&EM92(I
M(#\^/"]T:#X\=&@^/#]P:'`@96-H;R!?*"),979E;"(I(#\^/"]T:#X\=&@^
M/#]P:'`@96-H;R!?*")&:6QE(BD@/SX\+W1H/CQT:#X\/W!H<"!E8VAO(%\H
M(DUE<W-A9V4B*2`_/CPO=&@^"B`\+W1R/@H\/W!H<"!F;W)E86-H("@D;&]G
M(&%S("1L;V=E;G1R>2DZ(#\^"B`\='(^"B`@/'1D/@H@("`\/W!H<"!E8VAO
M('-T<F9T:6UE*"1P<F5F<RT^9V5T5F%L=64H)V1A=&5?9F]R;6%T)RD@+B`G
M("5(.B5-.B53)RP@)&QO9V5N=')Y6R=T<R==*2`_/@H@(#PO=&0^"B`@/'1D
M/@H@("`\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&QO9V5N=')Y6R=L
M979E;"==*2`_/@H@(#PO=&0^"B`@/'1D/@H@(#P_<&AP"B`@:68@*'!R96=?
M;6%T8V@H)R]<+U-Y;F--3%PN<&AP)"\G+"`D;&]G96YT<GE;)V9I;&4G72DI
M('L*("`@("`@)&9I;&4@/2`G9G)A;65W;W)K+U-Y;F--3"]3>6YC34PN<&AP
M)SL*("!](&5L<V4@>PH@("`@("`D9FEL92`]('!R96=?<F5P;&%C92@G+UXN
M*EPO4WEN8TU,7"\H+BHI)"\G+"`G9G)A;65W;W)K+U-Y;F--3"]3>6YC34PO
M)#$G+"`D;&]G96YT<GE;)V9I;&4G72D["B`@?0H@(&5C:&\@2&]R9&4Z.FQI
M;FLH)VAT='`Z+R]C=G,N:&]R9&4N;W)G+V-O+G!H<"\G"B`@("`@("`@("`@
M("`@("`@("`N("1F:6QE("`N("<_<CU(14%$(R<@+B!T<FEM*"1L;V=E;G1R
M>5LG;&EN92==*2P@)R<L("<G+"`G8W9S)RD*("`@("`@+B!P<F5G7W)E<&QA
M8V4H)R]>+BI<+RA;7EPO72HI)"\G+"`G)#$G+"`D;&]G96YT<GE;)V9I;&4G
M72D*("`@("`@+B`G.B<@+B!T<FEM*"1L;V=E;G1R>5LG;&EN92==*0H@(#\^
M"B`@/"]T9#X*("`\=&0^"B`@(#P_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R
M<R@D;&]G96YT<GE;)VUE<W-A9V4G72D@/SX*("`\+W1D/@H@/"]T<CX*/#]P
M:'`@96YD9F]R96%C:#L@/SX*/"]T86)L93X*"CP_<&AP"GT*"G)E<75I<F4@
M2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]P<F5F<RYP
M:'``````````````````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$P
M-#4T`#$P-3$U-#,S-S4W`#`R,3,T,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D
M92]S97)V:6-E<R]P<F5F<RYP:'`L=B`Q+C$Y+C(N,3`@,C`P-B\P,B\P-R`R
M,SHU,#HP,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#
M:&%R;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y
M<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE
M*%]?1DE,15]?*2`N("<O+BXG*3L*<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&
M24Q%7U\I("X@)R\N+B]L:6(O8V]R92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO
M<F1E+U!R969S+U5)+G!H<"<["@HD<F5G:7-T<GD@/2`F4F5G:7-T<GDZ.G-I
M;F=L971O;B@I.PH*+RH@1FEG=7)E(&]U="!W:&EC:"!A<'!L:6-A=&EO;B!W
M92=R92!S971T:6YG('!R969E<F5N8V5S(&9O<BX@*B\*)&%P<"`](%5T:6PZ
M.F=E=$9O<FU$871A*"=A<'`G+"!0<F5F<U]523HZ9V5T1&5F875L=$%P<"@I
M*3L*)&%P<&)A<V4@/2`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G+"`D87!P
M*3L*"B\J(%-E92!I9B!W92!H879E(&$@<')E9F5R96YC97,@9W)O=7`@<V5T
M+B`J+PHD9W)O=7`@/2!5=&EL.CIG971&;W)M1&%T82@G9W)O=7`G*3L*"B\J
M($QO860@)&%P<"=S(&)A<V4@96YV:7)O;FUE;G0L(&)U="!D;VXG="!R97%U
M97-T('1H870@=&AE(&%P<"!P97)F;W)M"B`J(&%U=&AE;G1I8V%T:6]N(&)E
M>6]N9"!(;W)D92=S+B`J+PHD875T:&5N=&EC871I;VX@/2`G;F]N92<["G)E
M<75I<F5?;VYC92`D87!P8F%S92`N("<O;&EB+V)A<V4N<&AP)SL*"B\J(%-E
M="!T:71L92X@*B\*)'1I=&QE(#T@<W!R:6YT9BA?*")/<'1I;VYS(&9O<B`E
M<R(I+"`D<F5G:7-T<GDM/F=E="@G;F%M92<I*3L*"B\J(%-P96-I86P@8V%S
M92!W:&5R92!W92!N965D('1H92!)9&5N=&ET>2!O8FIE8W0@:6X@2&]R9&4G
M<R!P<F5F<RYP:'`N("HO"FEF("@D9W)O=7`@/3T@)VED96YT:71I97,G("8F
M("1A<'`@/3T@)VAO<F1E)RD@>PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92])
M9&5N=&ET>2YP:'`G.PH@("`@)&ED96YT:71Y(#T@)DED96YT:71Y.CIS:6YG
M;&5T;VXH)&%P<"`]/2`G:&]R9&4G(#\@;G5L;"`Z(&%R<F%Y*"1A<'`L("1A
M<'`I*3L*?0H*+RH@3&]A9"`D87!P)W,@<')E9F5R96YC97,L(&EF(&%N>2X@
M*B\*)'!R969'<F]U<',@/2!A<G)A>2@I.PII9B`H9FEL95]E>&ES=',H)&%P
M<&)A<V4@+B`G+V-O;F9I9R]P<F5F<RYP:'`G*2D@>PH@("`@<F5Q=6ER92`D
M87!P8F%S92`N("<O8V]N9FEG+W!R969S+G!H<"<["GT*"B\J($QO860@8W5S
M=&]M('!R969E<F5N8V4@:&%N9&QE<G,@9F]R("1A<'`L(&EF('!R97-E;G0N
M("HO"FEF("AF:6QE7V5X:7-T<R@D87!P8F%S92`N("<O;&EB+W!R969S+G!H
M<"<I*2!["B`@("!R97%U:7)E7V]N8V4@)&%P<&)A<V4@+B`G+VQI8B]P<F5F
M<RYP:'`G.PI]"@HO*B!)9B!T:&5R92=S(&]N;'D@;VYE('!R969'<F]U<"P@
M:G5S="!S:&]W(&ET+B`J+PII9B`H96UP='DH)&=R;W5P*2`F)B!C;W5N="@D
M<')E9D=R;W5P<RD@/3T@,2D@>PH@("`@)&=R;W5P(#T@87)R87E?:V5Y<R@D
M<')E9D=R;W5P<RD["B`@("`D9W)O=7`@/2!A<G)A>5]P;W`H)&=R;W5P*3L*
M?0H*:68@*"1G<F]U<"`]/2`G:61E;G1I=&EE<R<I('L*("`@(')E<75I<F5?
M;VYC92`G2&]R9&4O261E;G1I='DN<&AP)SL*("`@("1I9&5N=&ET>2`]("9)
M9&5N=&ET>3HZ<VEN9VQE=&]N*"1A<'`@/3T@)VAO<F1E)R`_(&YU;&P@.B!A
M<G)A>2@D87!P+"`D87!P*2D["B`@("!I9B`H)&%P<"`A/2`G:&]R9&4G*2![
M"B`@("`@("`@:68@*%5T:6PZ.FYO;DEN<'5T5F%R*"=P<F5F1W)O=7!S)RDI
M('L*("`@("`@("`@("`@)&ME97!0<F5F1W)O=7!S(#T@)'!R969'<F]U<',[
M"B`@("`@("`@("`@('5N<V5T*"1P<F5F1W)O=7!S*3L*("`@("`@("!]"B`@
M("`@("`@<F5Q=6ER92!(3U)$15]"05-%("X@)R]C;VYF:6<O<')E9G,N<&AP
M)SL*("`@("`@("`D:&]R9&5?;65M8F5R<R`]("1P<F5F1W)O=7!S6R=I9&5N
M=&ET:65S)UU;)VUE;6)E<G,G73L*("`@("`@("!I9B`H571I;#HZ;F]N26YP
M=71687(H)VME97!0<F5F1W)O=7!S)RDI('L*("`@("`@("`@("`@)'!R969'
M<F]U<',@/2`D:V5E<%!R969'<F]U<',["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@=6YS970H)'!R969'<F]U<',I.PH@("`@("`@('T*("`@('T*
M"B`@("!I9B`H:7-S970H)&AO<F1E7VUE;6)E<G,I*2!["B`@("`@("`@)'!R
M969'<F]U<'-;)VED96YT:71I97,G75LG;65M8F5R<R==(#T@87)R87E?;65R
M9V4H)&AO<F1E7VUE;6)E<G,L("1P<F5F1W)O=7!S6R=I9&5N=&ET:65S)UU;
M)VUE;6)E<G,G72D["B`@("!]"@H@("`@<W=I=&-H("A5=&EL.CIG971&;W)M
M1&%T82@G86-T:6]N240G*2D@>PH@("`@8V%S92`G=7!D871E7W!R969S)SH*
M("`@("`@("!I9B`H)'!R969S+3YI<TQO8VME9"@G9&5F875L=%]I9&5N=&ET
M>2<I*2!["B`@("`@("`@("`@("1D969A=6QT(#T@)&ED96YT:71Y+3YG971$
M969A=6QT*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&1E9F%U
M;'0@/2!5=&EL.CIG9710;W-T*"=D969A=6QT7VED96YT:71Y)RD["B`@("`@
M("`@("`@("1I9"`](%5T:6PZ.F=E=%!O<W0H)VED96YT:71Y)RD["B`@("`@
M("`@("`@(&EF("@D:60@/3T@+3$I('L*("`@("`@("`@("`@("`@("1I9"`]
M("1I9&5N=&ET>2T^861D*"D["B`@("`@("`@("`@('T@96QS96EF("@D:60@
M/3T@+3(I('L*("`@("`@("`@("`@("`@("1P<F5F1W)O=7!S6R=I9&5N=&ET
M:65S)UU;)VUE;6)E<G,G72`](&%R<F%Y*"=D969A=6QT7VED96YT:71Y)RD[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&ED96YT:71Y+3YS971$969A
M=6QT*"1I9"D["B`@("`@("`@?0H@("`@("`@(&EF("A0<F5F<U]523HZ:&%N
M9&QE1F]R;2@D9W)O=7`L("1I9&5N=&ET>2DI('L*("`@("`@("`@("`@)')E
M<W5L="`]("1I9&5N=&ET>2T^=F5R:69Y*"D["B`@("`@("`@("`@("1I9&5N
M=&ET>2T^<V5T1&5F875L="@D9&5F875L="D["B`@("`@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M("1N;W1I9FEC871I;VXM/G!U<V@H)')E<W5L="P@)VAO<F1E+F5R<F]R)RD[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D:61E;G1I
M='DM/G-A=F4H*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1I9&5N=&ET>2T^<V5T1&5F875L="@D9&5F875L="D["B`@
M("`@("`@("`@("1I9&5N=&ET>2T^<V%V92@I.PH@("`@("`@('T*("`@("`@
M("!U;G-E="@D<')E9D=R;W5P<RD["B`@("`@("`@<F5Q=6ER92`D87!P8F%S
M92`N("<O8V]N9FEG+W!R969S+G!H<"<["B`@("`@("`@8G)E86L["@H@("`@
M8V%S92`G9&5L971E7VED96YT:71Y)SH*("`@("`@("`D:60@/2`H:6YT*55T
M:6PZ.F=E=$9O<FU$871A*"=I9"<I.PH@("`@("`@("1D96QE=&5D7VED96YT
M:71Y(#T@)&ED96YT:71Y+3YD96QE=&4H)&ED*3L*("`@("`@("!U;G-E="@D
M7W!R969S6R=D969A=6QT7VED96YT:71Y)UU;)V5N=6TG75LD:61=*3L*("`@
M("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B5&AE(&ED96YT
M:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(I+"`D9&5L971E9%]I9&5N
M=&ET>5LP75LG:60G72DL("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@8G)E
M86L["@H@("`@8V%S92`G8VAA;F=E7V1E9F%U;'1?:61E;G1I='DG.@H@("`@
M("`@("1D969A=6QT7VED96YT:71Y(#T@)&ED96YT:71Y+3YS971$969A=6QT
M*%5T:6PZ.F=E=$9O<FU$871A*"=I9"<I*3L*("`@("`@("`D:61E;G1I='DM
M/G-A=F4H*3L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(EEO=7(@
M9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@
M("!B<F5A:SL*("`@('T*?2!E;'-E:68@*%!R969S7U5).CIH86YD;&5&;W)M
M*"1G<F]U<"P@)'!R969S*2D@>PH@("`@<F5Q=6ER92`D87!P8F%S92`N("<O
M8V]N9FEG+W!R969S+G!H<"<["GT*"B\J(%-H;W<@=&AE(%5)+B`J+PI0<F5F
M<U]523HZ9V5N97)A=&5522@D9W)O=7`I.PH*<F5Q=6ER92`D<F5G:7-T<GDM
M/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUF;V]T97(N
M:6YC)SL*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+W!R;V)L96TN<&AP````````
M````````````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3(U-C8`,3`U,34T
M,S,W-3<`,#(Q-C<P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W-E<G9I8V5S
M+W!R;V)L96TN<&AP+'8@,BXQ,30N."XX(#(P,#8O,#$O,38@,30Z,C0Z,#,@
M8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:&%R;&5S
M($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@
M,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*B\*"B\J(%-E;F0@=&AE(&)R;W=S97(@8F%C:R!T;R!T:&4@8V]R
M<F5C="!P86=E+B`J+PIF=6YC=&EO;B!?<F5T=7)N5&]086=E*"D*>PH@("`@
M)'5R;"`](%5T:6PZ.F=E=$9O<FU$871A*"=R971U<FY?=7)L)RP@2&]R9&4Z
M.G5R;"@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@)VAO
M<F1E)RD@+B`G+VQO9VEN+G!H<"<L('1R=64I*3L*("`@(&AE861E<B@G3&]C
M871I;VXZ("<@+B!S=')?<F5P;&%C92@G)F%M<#LG+"`G)B<L("1U<FPI*3L*
M("`@(&5X:70["GT*"D!D969I;F4H)T%55$A?2$%.1$Q%4B<L('1R=64I.PI`
M9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN
M)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G
M.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+W9E<G-I;VXN<&AP
M)SL*<F5Q=6ER95]O;F-E("=(;W)D92])9&5N=&ET>2YP:'`G.PH*:68@*"%(
M;W)D93HZ<VAO=U-E<G9I8V4H)W!R;V)L96TG*2D@>PH@("`@7W)E='5R;E1O
M4&%G92@I.PI]"@HD:61E;G1I='D@/2`F261E;G1I='DZ.G-I;F=L971O;B@I
M.PHD96UA:6P@/2`D:61E;G1I='DM/F=E=%9A;'5E*"=F<F]M7V%D9'(G*3L*
M:68@*"$D96UA:6PI('L*("`@("1E;6%I;"`](%5T:6PZ.F=E=$9O<FU$871A
M*"=E;6%I;"<L($%U=&@Z.F=E=$%U=&@H*2D["GT*)&UE<W-A9V4@/2!5=&EL
M.CIG971&;W)M1&%T82@G;65S<V%G92<L("<G*3L*)&YA;64@/2!5=&EL.CIG
M971&;W)M1&%T82@G;F%M92<L("1I9&5N=&ET>2T^9V5T5F%L=64H)V9U;&QN
M86UE)RDI.PHD<W5B:F5C="`](%5T:6PZ.F=E=$9O<FU$871A*"=S=6)J96-T
M)RP@)R<I.PH*)&%C=&EO;DE$(#T@571I;#HZ9V5T1F]R;41A=&$H)V%C=&EO
M;DE$)RD["G-W:71C:"`H)&%C=&EO;DE$*2!["F-A<V4@)W-E;F1?<')O8FQE
M;5]R97!O<G0G.@H@("`@:68@*"1S=6)J96-T("8F("1M97-S86=E*2!["B`@
M("`@("`@+R\@5&AI<R!I<R!N;W0@82!G971T97AT('-T<FEN9R!O;B!P=7)P
M;W-E+@H@("`@("`@("1R96UO=&4@/2`H(65M<'1Y*"1?4T525D526R=214U/
M5$5?2$]35"==*2D@/R`D7U-%4E9%4ELG4D5-3U1%7TA/4U0G72`Z("1?4T52
M5D526R=214U/5$5?041$4B==.PH@("`@("`@("1U<V5R7V%G96YT(#T@)%]3
M15)615);)TA45%!?55-%4E]!1T5.5"==.PH@("`@("`@("1B;V1Y(#T@(E1H
M:7,@<')O8FQE;2!R97!O<G0@=V%S(')E8V5I=F5D(&9R;VT@)')E;6]T92X@
M(B`N"B`@("`@("`@("`@(")4:&4@=7-E<B!C;&EC:V5D('1H92!P<F]B;&5M
M(')E<&]R="!L:6YK(&9R;VT@=&AE(&9O;&QO=VEN9R!L;V-A=&EO;CI<;B(@
M+@H@("`@("`@("`@("!5=&EL.CIG971&;W)M1&%T82@G<F5T=7)N7W5R;"<L
M("=.;R!R97%U97-T:6YG('!A9V4G*2`N"B`@("`@("`@("`@(")<;F%N9"!I
M<R!U<VEN9R!T:&4@9F]L;&]W:6YG(&)R;W=S97(Z7&XD=7-E<E]A9V5N=%QN
M7&XB("X*("`@("`@("`@("`@<W1R7W)E<&QA8V4H(EQR7&XB+"`B7&XB+"`D
M;65S<V%G92D["@H@("`@("`@("\O($1E9F%U;'0@=&\@82!R96QA=&EV96QY
M(')E87-O;F%B;&4@96UA:6P@861D<F5S<RX*("`@("`@("!I9B`H(21E;6%I
M;"D@>PH@("`@("`@("`@("`D96UA:6P@/2`G:&]R9&4M<')O8FQE;4`G("X@
M)&-O;F9;)W!R;V)L96US)UU;)VUA:6QD;VUA:6XG73L*("`@("`@("!]"@H@
M("`@("`@(&EF("@A96UP='DH)&-O;F9;)W!R;V)L96US)UU;)W1I8VME=',G
M72D@)B8*("`@("`@("`@("`@)')E9VES=')Y+3YH87--971H;V0H)W1I8VME
M=',O861D5&EC:V5T)RDI('L*("`@("`@("`@("`@)&EN9F\@/2!A<G)A>5]M
M97)G92@D8V]N9ELG<')O8FQE;7,G75LG=&EC:V5T7W!A<F%M<R==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=S=6UM87)Y)R`]
M/B`D<W5B:F5C="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G8V]M;65N="<@/3X@)&)O9'DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W5S97)?96UA:6PG(#T^("1E;6%I;"DI.PH@
M("`@("`@("`@("`D<F5S=6QT(#T@)')E9VES=')Y+3YC86QL*"=T:6-K971S
M+V%D9%1I8VME="<L(&%R<F%Y*"1I;F9O*2D["B`@("`@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M("1N;W1I9FEC871I;VXM/G!U<V@H)')E<W5L="D["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("!?<F5T=7)N5&]086=E*"D["B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+TU)344N<&AP)SL*("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92]-24U%+TAE861E<G,N<&AP)SL*("`@("`@("`@("`@<F5Q
M=6ER95]O;F-E("=(;W)D92]-24U%+TUE<W-A9V4N<&AP)SL*"B`@("`@("`@
M("`@("\O($%D9"!U<V5R)W,@;F%M92!T;R!T:&4@96UA:6P@861D<F5S<R!I
M9B!P<F]V:61E9"X*("`@("`@("`@("`@:68@*"1N86UE*2!["B`@("`@("`@
M("`@("`@("!`;&ES="@D;6%I;&)O>"P@)&AO<W0I(#T@0&5X<&QO9&4H)T`G
M+"`D96UA:6PL(#(I.PH@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1H;W-T
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1H;W-T(#T@)&-O;F9;)W!R;V)L
M96US)UU;)VUA:6QD;VUA:6XG73L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1E;6%I;"`]($U)344Z.G)F8S@R,E=R:71E061D<F5S<R@D
M;6%I;&)O>"P@)&AO<W0L("1N86UE*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)&US9U]H96%D97)S(#T@)FYE=R!-24U%7TAE861E<G,H*3L*("`@
M("`@("`@("`@)&US9U]H96%D97)S+3YA9&1296-E:79E9$AE861E<B@I.PH@
M("`@("`@("`@("`D;7-G7VAE861E<G,M/F%D9$UE<W-A9V5)9$AE861E<B@I
M.PH@("`@("`@("`@("`D;7-G7VAE861E<G,M/F%D9$%G96YT2&5A9&5R*"D[
M"B`@("`@("`@("`@("1M<V=?:&5A9&5R<RT^861D2&5A9&5R*"=$871E)RP@
M9&%T92@G<B<I*3L*("`@("`@("`@("`@)&US9U]H96%D97)S+3YA9&1(96%D
M97(H)U1O)RP@)&-O;F9;)W!R;V)L96US)UU;)V5M86EL)UTI.PH@("`@("`@
M("`@("`D;7-G7VAE861E<G,M/F%D9$AE861E<B@G4W5B:F5C="<L(%\H(EM0
M<F]B;&5M(%)E<&]R=%TB*2`N("<@)R`N("1S=6)J96-T*3L*("`@("`@("`@
M("`@)&US9U]H96%D97)S+3YA9&1(96%D97(H)T9R;VTG+"`D96UA:6PI.PH@
M("`@("`@("`@("`D;7-G7VAE861E<G,M/F%D9$AE861E<B@G4V5N9&5R)RP@
M)VAO<F1E+7!R;V)L96U`)R`N("1C;VYF6R=P<F]B;&5M<R==6R=M86EL9&]M
M86EN)UTI.PH*("`@("`@("`@("`@)&UI;64@/2`F;F5W($U)345?365S<V%G
M92@I.PH@("`@("`@("`@("`D;6EM92T^861D4&%R="AN97<@34E-15]087)T
M*"=T97AT+W!L86EN)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!3=')I;F<Z.G=R87`H)&)O9'DL(#@P+"`B7&XB*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!.3%,Z.F=E
M=$-H87)S970H*2DI.PH@("`@("`@("`@("`D;7-G7VAE861E<G,M/F%D9$U)
M345(96%D97)S*"1M:6UE*3L*"B`@("`@("`@("`@("1M86EL7V1R:79E<B`]
M("1C;VYF6R=M86EL97(G75LG='EP92==.PH@("`@("`@("`@("`D;6%I;%]P
M87)A;7,@/2`D8V]N9ELG;6%I;&5R)UU;)W!A<F%M<R==.PH@("`@("`@("`@
M("!I9B`H)&UA:6Q?9')I=F5R(#T]("=S;71P)R`F)B`D;6%I;%]P87)A;7-;
M)V%U=&@G72`F)@H@("`@("`@("`@("`@("`@96UP='DH)&UA:6Q?<&%R86US
M6R=U<V5R;F%M92==*2D@>PH@("`@("`@("`@("`@("`@:68@*$%U=&@Z.F=E
M=$%U=&@H*2D@>PH@("`@("`@("`@("`@("`@("`@("1M86EL7W!A<F%M<ULG
M=7-E<FYA;64G72`]($%U=&@Z.F=E=$%U=&@H*3L*("`@("`@("`@("`@("`@
M("`@("`D;6%I;%]P87)A;7-;)W!A<W-W;W)D)UT@/2!!=71H.CIG971#<F5D
M96YT:6%L*"=P87-S=V]R9"<I.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*"%E;7!T>2@D8V]N9ELG<')O8FQE;7,G75LG=7-E<FYA;64G72D@)B8*("`@
M("`@("`@("`@("`@("`@("`@("`@("`A96UP='DH)&-O;F9;)W!R;V)L96US
M)UU;)W!A<W-W;W)D)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&UA:6Q?
M<&%R86US6R=U<V5R;F%M92==(#T@)&-O;F9;)W!R;V)L96US)UU;)W5S97)N
M86UE)UT["B`@("`@("`@("`@("`@("`@("`@)&UA:6Q?<&%R86US6R=P87-S
M=V]R9"==(#T@)&-O;F9;)W!R;V)L96US)UU;)W!A<W-W;W)D)UT["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@A
M:7-?82@D<V5N="`]("1M:6UE+3YS96YD*"1C;VYF6R=P<F]B;&5M<R==6R=E
M;6%I;"==+"`D;7-G7VAE861E<G,L("1M86EL7V1R:79E<BP@)&UA:6Q?<&%R
M86US*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@+RH@5V4@
M<W5C8V5E9&5D+B!2971U<FX@=&\@<')E=FEO=7,@<&%G92!A;F0@97AI="!T
M:&ES('-C<FEP="X@*B\*("`@("`@("`@("`@("`@(%]R971U<FY4;U!A9V4H
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H)'-E;G0I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?0H@("`@8G)E86L["@IC87-E("=C86YC96Q?<')O8FQE;5]R97!O
M<G0G.@H@("`@7W)E='5R;E1O4&%G92@I.PI]"@HD=&ET;&4@/2!?*")0<F]B
M;&5M($1E<V-R:7!T:6]N(BD["B1M96YU(#T@)FYE=R!-96YU*$A/4D1%7TU%
M3E5?34%32U]!3$P@)B!^2$]21$5?345.55]-05-+7U!21493*3L*<F5Q=6ER
M92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*<F5Q
M=6ER92!(3U)$15]414U03$%415,@+B`G+VUE;G4O;65N=2YI;F,G.PHD;F]T
M:69I8V%T:6]N+3YN;W1I9GDH87)R87DH)VQI<W1E;F5R<R<@/3X@)W-T871U
M<R<I*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+W!R;V)L96TO<')O
M8FQE;2YI;F,G.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N
M+69O;W1E<BYI;F,G.PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP````````````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,3`P,C``,3`U,34T,S,W-3<`,#(S,3$T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B`D2&]R9&4Z(&AO<F1E+W-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP+'8@
M,2XU+C$P+C<@,C`P-B\P-2\R-"`R,CHT-3HQ,R!C:'5C:R!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L
M;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)T%55$A?2$%.1$Q%
M4B<L('1R=64I.PI`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)
M3$5?7RD@+B`G+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L
M:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T9O<FTN<&AP)SL*
M<F5Q=6ER95]O;F-E("=(;W)D92]3=')I;F<N<&AP)SL*<F5Q=6ER95]O;F-E
M("=(;W)D92]687)I86)L97,N<&AP)SL*"B\O($UA:V4@<W5R92!A=71H(&)A
M8VME;F0@86QL;W=S('!A<W-W;W)D<R!T;R!B92!R97-E="X*)&%U=&@@/2`F
M075T:#HZ<VEN9VQE=&]N*"1C;VYF6R=A=71H)UU;)V1R:79E<B==*3L*:68@
M*"$D875T:"T^:&%S0V%P86)I;&ET>2@G<F5S971P87-S=V]R9"<I*2!["B`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(D-A;FYO="!R97-E="!P87-S=V]R
M9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB
M*2P@)VAO<F1E+F5R<F]R)RD["B`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@
M075T:#HZ9V5T3&]G:6Y38W)E96XH)R<L(%5T:6PZ.F=E=$9O<FU$871A*"=U
M<FPG*2DI.PH@("`@97AI=#L*?0H*)'9A<G,@/2`F5F%R:6%B;&5S.CIG971$
M969A=6QT5F%R:6%B;&5S*"D["@HD=&ET;&4@/2!?*")297-E="!9;W5R(%!A
M<W-W;W)D(BD["B1F;W)M(#T@)DAO<F1E7T9O<FTZ.G-I;F=L971O;B@G2&]R
M9&53:6=N=7!&;W)M)RP@)'9A<G,L("1T:71L92D["B1F;W)M+3YS971"=71T
M;VYS*%\H(D-O;G1I;G5E(BDI.PH*+RH@4V5T('5P('1H92!F:65L9',@9F]R
M('1H92!U<V5R;F%M92!A;F0@86QT97)N871E(&5M86EL+B`J+PHD9F]R;2T^
M861D2&ED9&5N*"<G+"`G=7)L)RP@)W1E>'0G+"!F86QS92D["B1V(#T@)B1F
M;W)M+3YA9&1687)I86)L92A?*")5<V5R;F%M92(I+"`G=7-E<FYA;64G+"`G
M=&5X="<L('1R=64I.PHD=BT^<V5T3W!T:6]N*"=T<F%C:V-H86YG92<L('1R
M=64I.PHD9F]R;2T^861D5F%R:6%B;&4H7R@B06QT97)N871E(&5M86EL(&%D
M9')E<W,B*2P@)V5M86EL)RP@)V5M86EL)RP@=')U92D["B1C86Y?=F%L:61A
M=&4@/2!F86QS93L*"B\J($EF(&$@=7-E<FYA;64@:&%S(&)E96X@<W5P<&QI
M960@=')Y(&9E=&-H:6YG('1H92!P<F5F<R!S=&]R960@:6YF;RX@*B\*:68@
M*"1U<V5R;F%M92`]("1V87)S+3YG970H)W5S97)N86UE)RDI('L*("`@("1U
M<V5R;F%M92`]($%U=&@Z.F%D9$AO;VLH)'5S97)N86UE*3L*("`@("1P<F5F
M<R`]("90<F5F<SHZ<VEN9VQE=&]N*"1C;VYF6R=P<F5F<R==6R=D<FEV97(G
M72P@)VAO<F1E)RP@)'5S97)N86UE+"`G)RP@;G5L;"P@9F%L<V4I.PH@("`@
M)'!R969S+3YR971R:65V92@I.PH@("`@)&5M86EL(#T@)'!R969S+3YG9716
M86QU92@G86QT97)N871E7V5M86EL)RD["B`@("`O*B!$;V5S('1H92!A;'1E
M<FYA=&4@96UA:6P@<W1O<F5D(&EN('!R969S(&UA=&-H('1H92!O;F4@<W5B
M;6ET=&5D/R`J+PH@("`@:68@*"1V87)S+3YG970H)V5M86EL)RD@/3T@)&5M
M86EL*2!["B`@("`@("`@)&-A;E]V86QI9&%T92`]('1R=64["B`@("`@("`@
M)&9O<FTM/G-E=$)U='1O;G,H7R@B4F5S970@4&%S<W=O<F0B*2D["B`@("`@
M("`@)'%U97-T:6]N(#T@)'!R969S+3YG971686QU92@G<V5C=7)I='E?<75E
M<W1I;VXG*3L*("`@("`@("`D9F]R;2T^861D5F%R:6%B;&4H)'%U97-T:6]N
M+"`G<75E<W1I;VXG+"`G9&5S8W)I<'1I;VXG+"!F86QS92D["B`@("`@("`@
M)&9O<FTM/F%D9%9A<FEA8FQE*%\H(D%N<W=E<B(I+"`G86YS=V5R)RP@)W1E
M>'0G+"!T<G5E*3L*("`@('T@96QS92!["B`@("`@("`@)&YO=&EF:6-A=&EO
M;BT^<'5S:"A?*"));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D
M9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O
M<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(BDL("=H;W)D92YE<G)O<B<I
M.PH@("`@?0I]"@HO*B!686QI9&%T92!T:&4@9F]R;2X@*B\*:68@*"1C86Y?
M=F%L:61A=&4@)B8@)&9O<FTM/G9A;&ED871E*"1V87)S*2D@>PH@("`@)&9O
M<FTM/F=E=$EN9F\H)'9A<G,L("1I;F9O*3L*"B`@("`O*B!&971C:"!V86QU
M97,@9G)O;2!P<F5F<R!F;W(@<V5L96-T960@=7-E<BX@*B\*("`@("1A;G-W
M97(@/2`D<')E9G,M/F=E=%9A;'5E*"=S96-U<FET>5]A;G-W97(G*3L*"B`@
M("`O*B!#:&5C:R!T:&4@9VEV96X@=F%L=65S('=I=&AT('1H92!P<F5F<R!S
M=&]R960@;VYE<RX@*B\*("`@(&EF("@D96UA:6P@/3T@)&EN9F];)V5M86EL
M)UT@)B8@4W1R:6YG.CIL;W=E<B@D86YS=V5R*2`]/2!3=')I;F<Z.FQO=V5R
M*"1I;F9O6R=A;G-W97(G72DI('L*("`@("`@("`O*B!);F9O(&UA=&-H97,L
M('-O(')E<V5T('1H92!P87-S=V]R9"X@*B\*("`@("`@("`D<&%S<W=O<F0@
M/2`D875T:"T^<F5S971087-S=V]R9"@D:6YF;ULG=7-E<FYA;64G72D["@H@
M("`@("`@(')E<75I<F5?;VYC92`G36%I;"YP:'`G.PH@("`@("`@("1M86EL
M97(@/2!-86EL.CIF86-T;W)Y*"1C;VYF6R=M86EL97(G75LG='EP92==+"`D
M8V]N9ELG;6%I;&5R)UU;)W!A<F%M<R==*3L*"B`@("`@("`@+RH@4V5T('5P
M('1H92!E;6%I;"!H96%D97)S(&%N9"!B;V1Y+B`J+PH@("`@("`@("1H96%D
M97)S6R=&<F]M)UT@/2`D96UA:6P["B`@("`@("`@)&AE861E<G-;)U1O)UT@
M/2`D96UA:6P["B`@("`@("`@)')E8VEP:65N='-;72`]("1H96%D97)S6R=4
M;R==.PH@("`@("`@("1H96%D97)S6R=3=6)J96-T)UT@/2!?*")9;W5R('!A
M<W-W;W)D(&AA<R!B965N(')E<V5T(BD["B`@("`@("`@)&)O9'D@/2!S<')I
M;G1F*%\H(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B*2P@)')E
M9VES=')Y+3YG970H)VYA;64G+"`G:&]R9&4G*2P@)'!A<W-W;W)D*3L*("`@
M("`@("`D;6%I;&5R+3YS96YD*"1R96-I<&EE;G1S+"`D:&5A9&5R<RP@)&)O
M9'DI.PH*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(EEO=7(@<&%S
M<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO
M9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+B(I+"`G:&]R9&4N<W5C8V5S
M<R<I.PH@("`@("`@(&AE861E<B@G3&]C871I;VXZ("<@+B!!=71H.CIG971,
M;V=I;E-C<F5E;B@G)RP@)&EN9F];)W5R;"==*2D["B`@("`@("`@97AI=#L*
M("`@('T@96QS92!["B`@("`@("`@+RH@26YF;R!S=6)M:71T960@9&]E<R!N
M;W0@;6%T8V@@=VAA="!I<R!I;B!P<F5F<RP@<F5D:7)E8W0@=7-E<B!B86-K
M"B`@("`@("`@("H@=&\@;&]G:6XN("HO"B`@("`@("`@)&YO=&EF:6-A=&EO
M;BT^<'5S:"A?*")#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T
M:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS
M(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB*2P@)VAO
M<F1E+F5R<F]R)RD["B`@("!]"GT*"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53
M("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["B1N;W1I9FEC871I;VXM/FYO=&EF
M>2AA<G)A>2@G;&ES=&5N97)S)R`]/B`G<W1A='5S)RDI.PIR97%U:7)E7V]N
M8V4@)TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP)SL*)')E;F1E<F5R(#T@)FYE
M=R!(;W)D95]&;W)M7U)E;F1E<F5R*"D["B1F;W)M+3YR96YD97)!8W1I=F4H
M)')E;F1E<F5R+"`D=F%R<RP@)W)E<V5T<&%S<W=O<F0N<&AP)RP@)W!O<W0G
M*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUF;V]T97(N
M:6YC)SL*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O<VAA
M<F5S+P``````````````````````````````````````````````````````
M```````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#4Q-30S,S<U-P`P,C`W-S(`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]S97)V:6-E<R]S:&%R97,O961I="YP:'``````````````````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#(S,3`W`#$P-3$U-#,S-S4W`#`R,C0S,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@)$AO<F1E.B!H;W)D92]S97)V:6-E<R]S:&%R97,O961I="YP
M:'`L=B`Q+C(V+C$P+C@@,C`P-B\P-2\P,2`R,3HQ-CHT,2!C:'5C:R!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*)&9I96QD<TQI
M<W1;)W-H;W<G72`](#`["B1F:65L9'-,:7-T6R=R96%D)UT@/2`Q.PHD9FEE
M;&1S3&ES=%LG961I="==(#T@,CL*)&9I96QD<TQI<W1;)V1E;&5T92==(#T@
M,SL*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N
M("<O+BXO+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B
M87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O365N=2YP:'`G.PIR97%U
M:7)E7V]N8V4@)TAO<F1E+U-H87)E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R
M9&4O1W)O=7`N<&AP)SL*"B1A<'`@/2!5=&EL.CIG971&;W)M1&%T82@G87!P
M)RD["B1S:&%R97,@/2`F2&]R9&5?4VAA<F4Z.G-I;F=L971O;B@D87!P*3L*
M)&=R;W5P<R`]("9'<F]U<#HZ<VEN9VQE=&]N*"D["B1A=71H(#T@)D%U=&@Z
M.G-I;F=L971O;B@D8V]N9ELG875T:"==6R=D<FEV97(G72D["@HD9F]R;2`]
M(&YU;&P["B1R96QO860@/2!F86QS93L*)&%C=&EO;DE$(#T@571I;#HZ9V5T
M1F]R;41A=&$H)V%C=&EO;DE$)RP@)V5D:70G*3L*<W=I=&-H("@D86-T:6]N
M240I('L*8V%S92`G961I="<Z"B`@("`D<VAA<F4@/2`F)'-H87)E<RT^9V5T
M4VAA<F5">4ED*%5T:6PZ.F=E=$9O<FU$871A*"=C:60G*2D["B`@("!I9B`H
M(6ES7V$H)'-H87)E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)&9O<FT@
M/2`G961I="YI;F,G.PH@("`@("`@("1P97)M(#T@)B1S:&%R92T^9V5T4&5R
M;6ES<VEO;B@I.PH@("`@?2!E;'-E:68@*"@D8V%T96=O<GD@/2!5=&EL.CIG
M971&;W)M1&%T82@G<VAA<F4G*2D@(3T](&YU;&PI('L*("`@("`@("`D<VAA
M<F4@/2`F)'-H87)E<RT^9V5T4VAA<F4H)&-A=&5G;W)Y*3L*("`@("`@("!I
M9B`H(6ES7V$H)'-H87)E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("1F;W)M(#T@)V5D:70N:6YC)SL*("`@("`@("`@("`@)'!E<FT@/2`F)'-H
M87)E+3YG971097)M:7-S:6]N*"D["B`@("`@("`@?0H@("`@?0H@("`@:68@
M*&ES7V$H)'-H87)E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"@D<VAA<F4L("=H;W)D92YE<G)O<B<I.PH@("`@?2!E
M;'-E:68@*&ES<V5T*"1S:&%R92D@)B8@075T:#HZ9V5T075T:"@I("$]("1S
M:&%R92T^9V5T*"=O=VYE<B<I*2!["B`@("`@("`@97AI="@G<&5R;6ES<VEO
M;B!D96YI960G*3L*("`@('T*("`@(&)R96%K.PH*8V%S92`G961I=&9O<FTG
M.@H@("`@)'-H87)E(#T@)B1S:&%R97,M/F=E=%-H87)E0GE)9"A5=&EL.CIG
M971&;W)M1&%T82@G8VED)RDI.PH@("`@:68@*&ES7V$H)'-H87)E+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(BDL("=H;W)D
M92YE<G)O<B<I.PH@("`@?2!E;'-E('L*("`@("`@("!I9B`H075T:#HZ9V5T
M075T:"@I("$]("1S:&%R92T^9V5T*"=O=VYE<B<I*2!["B`@("`@("`@("`@
M(&5X:70H)W!E<FUI<W-I;VX@9&5N:65D)RD["B`@("`@("`@?0H@("`@("`@
M("1P97)M(#T@)B1S:&%R92T^9V5T4&5R;6ES<VEO;B@I.PH*("`@("`@("`O
M+R!0<F]C97-S(&]W;F5R(&%N9"!O=VYE<B!P97)M:7-S:6]N<RX*("`@("`@
M("`D;VQD7V]W;F5R(#T@)'-H87)E+3YG970H)V]W;F5R)RD["B`@("`@("`@
M)&YE=U]O=VYE<B`](%5T:6PZ.F=E=$9O<FU$871A*"=O=VYE<B<L("1O;&1?
M;W=N97(I.PH@("`@("`@(&EF("@D;VQD7V]W;F5R("$]/2`D;F5W7V]W;F5R
M("8F("%E;7!T>2@D;F5W7V]W;F5R*2D@>PH@("`@("`@("`@("!I9B`H)&]L
M9%]O=VYE<B`A/2!!=71H.CIG971!=71H*"D@)B8@(4%U=&@Z.FES061M:6XH
M*2D@>PH@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")/
M;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA
M;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R
M92(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1S:&%R92T^<V5T*"=O=VYE<B<L("1N97=?;W=N97(I
M.PH@("`@("`@("`@("`@("`@)'-H87)E+3YS879E*"D["B`@("`@("`@("`@
M("`@("!I9B`H571I;#HZ9V5T1F]R;41A=&$H)V]W;F5R7W-H;W<G*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1P97)M+3YA9&15<V5R4&5R;6ES<VEO;B@D
M;F5W7V]W;F5R+"!015)-4U]32$]7+"!F86QS92D["B`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1P97)M+3YR96UO=F55
M<V5R4&5R;6ES<VEO;B@D;F5W7V]W;F5R+"!015)-4U]32$]7+"!F86QS92D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H571I;#HZ
M9V5T1F]R;41A=&$H)V]W;F5R7W)E860G*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1P97)M+3YA9&15<V5R4&5R;6ES<VEO;B@D;F5W7V]W;F5R+"!015)-
M4U]214%$+"!F86QS92D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("1P97)M+3YR96UO=F55<V5R4&5R;6ES<VEO;B@D
M;F5W7V]W;F5R+"!015)-4U]214%$+"!F86QS92D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!I9B`H571I;#HZ9V5T1F]R;41A=&$H)V]W
M;F5R7V5D:70G*2D@>PH@("`@("`@("`@("`@("`@("`@("1P97)M+3YA9&15
M<V5R4&5R;6ES<VEO;B@D;F5W7V]W;F5R+"!015)-4U]%1$E4+"!F86QS92D[
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("1P97)M+3YR96UO=F55<V5R4&5R;6ES<VEO;B@D;F5W7V]W;F5R+"!015)-
M4U]%1$E4+"!F86QS92D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!I9B`H571I;#HZ9V5T1F]R;41A=&$H)V]W;F5R7V1E;&5T92<I*2![
M"B`@("`@("`@("`@("`@("`@("`@)'!E<FTM/F%D9%5S97)097)M:7-S:6]N
M*"1N97=?;W=N97(L(%!%4DU37T1%3$5412P@9F%L<V4I.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<&5R;2T^<F5M
M;W9E57-E<E!E<FUI<W-I;VXH)&YE=U]O=VYE<BP@4$5235-?1$5,151%+"!F
M86QS92D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("\O(%!R;V-E<W,@9&5F875L="!P97)M:7-S:6]N<RX*
M("`@("`@("!I9B`H571I;#HZ9V5T1F]R;41A=&$H)V1E9F%U;'1?<VAO=R<I
M*2!["B`@("`@("`@("`@("1P97)M+3YA9&1$969A=6QT4&5R;6ES<VEO;BA0
M15)-4U]32$]7+"!F86QS92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'!E<FTM/G)E;6]V941E9F%U;'1097)M:7-S:6]N*%!%4DU37U-(3U<L
M(&9A;'-E*3L*("`@("`@("!]"B`@("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$
M871A*"=D969A=6QT7W)E860G*2D@>PH@("`@("`@("`@("`D<&5R;2T^861D
M1&5F875L=%!E<FUI<W-I;VXH4$5235-?4D5!1"P@9F%L<V4I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1P97)M+3YR96UO=F5$969A=6QT4&5R
M;6ES<VEO;BA015)-4U]214%$+"!F86QS92D["B`@("`@("`@?0H@("`@("`@
M(&EF("A5=&EL.CIG971&;W)M1&%T82@G9&5F875L=%]E9&ET)RDI('L*("`@
M("`@("`@("`@)'!E<FTM/F%D9$1E9F%U;'1097)M:7-S:6]N*%!%4DU37T5$
M250L(&9A;'-E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&5R
M;2T^<F5M;W9E1&5F875L=%!E<FUI<W-I;VXH4$5235-?141)5"P@9F%L<V4I
M.PH@("`@("`@('T*("`@("`@("!I9B`H571I;#HZ9V5T1F]R;41A=&$H)V1E
M9F%U;'1?9&5L971E)RDI('L*("`@("`@("`@("`@)'!E<FTM/F%D9$1E9F%U
M;'1097)M:7-S:6]N*%!%4DU37T1%3$5412P@9F%L<V4I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1P97)M+3YR96UO=F5$969A=6QT4&5R;6ES
M<VEO;BA015)-4U]$14Q%5$4L(&9A;'-E*3L*("`@("`@("!]"@H@("`@("`@
M("\O(%!R;V-E<W,@9W5E<W0@<&5R;6ES<VEO;G,N"B`@("`@("`@:68@*%5T
M:6PZ.F=E=$9O<FU$871A*"=G=65S=%]S:&]W)RDI('L*("`@("`@("`@("`@
M)'!E<FTM/F%D9$=U97-T4&5R;6ES<VEO;BA015)-4U]32$]7+"!F86QS92D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'!E<FTM/G)E;6]V94=U
M97-T4&5R;6ES<VEO;BA015)-4U]32$]7+"!F86QS92D["B`@("`@("`@?0H@
M("`@("`@(&EF("A5=&EL.CIG971&;W)M1&%T82@G9W5E<W1?<F5A9"<I*2![
M"B`@("`@("`@("`@("1P97)M+3YA9&1'=65S=%!E<FUI<W-I;VXH4$5235-?
M4D5!1"P@9F%L<V4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P
M97)M+3YR96UO=F5'=65S=%!E<FUI<W-I;VXH4$5235-?4D5!1"P@9F%L<V4I
M.PH@("`@("`@('T*("`@("`@("!I9B`H571I;#HZ9V5T1F]R;41A=&$H)V=U
M97-T7V5D:70G*2D@>PH@("`@("`@("`@("`D<&5R;2T^861D1W5E<W1097)M
M:7-S:6]N*%!%4DU37T5$250L(&9A;'-E*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D<&5R;2T^<F5M;W9E1W5E<W1097)M:7-S:6]N*%!%4DU3
M7T5$250L(&9A;'-E*3L*("`@("`@("!]"B`@("`@("`@:68@*%5T:6PZ.F=E
M=$9O<FU$871A*"=G=65S=%]D96QE=&4G*2D@>PH@("`@("`@("`@("`D<&5R
M;2T^861D1W5E<W1097)M:7-S:6]N*%!%4DU37T1%3$5412P@9F%L<V4I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P97)M+3YR96UO=F5'=65S
M=%!E<FUI<W-I;VXH4$5235-?1$5,151%+"!F86QS92D["B`@("`@("`@?0H*
M("`@("`@("`O+R!0<F]C97-S(&-R96%T;W(@<&5R;6ES<VEO;G,N"B`@("`@
M("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=C<F5A=&]R7W-H;W<G*2D@>PH@
M("`@("`@("`@("`D<&5R;2T^861D0W)E871O<E!E<FUI<W-I;VXH4$5235-?
M4TA/5RP@9F%L<V4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P
M97)M+3YR96UO=F5#<F5A=&]R4&5R;6ES<VEO;BA015)-4U]32$]7+"!F86QS
M92D["B`@("`@("`@?0H@("`@("`@(&EF("A5=&EL.CIG971&;W)M1&%T82@G
M8W)E871O<E]R96%D)RDI('L*("`@("`@("`@("`@)'!E<FTM/F%D9$-R96%T
M;W)097)M:7-S:6]N*%!%4DU37U)%040L(&9A;'-E*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D<&5R;2T^<F5M;W9E0W)E871O<E!E<FUI<W-I
M;VXH4$5235-?4D5!1"P@9F%L<V4I.PH@("`@("`@('T*("`@("`@("!I9B`H
M571I;#HZ9V5T1F]R;41A=&$H)V-R96%T;W)?961I="<I*2!["B`@("`@("`@
M("`@("1P97)M+3YA9&1#<F5A=&]R4&5R;6ES<VEO;BA015)-4U]%1$E4+"!F
M86QS92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'!E<FTM/G)E
M;6]V94-R96%T;W)097)M:7-S:6]N*%!%4DU37T5$250L(&9A;'-E*3L*("`@
M("`@("!]"B`@("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=C<F5A=&]R
M7V1E;&5T92<I*2!["B`@("`@("`@("`@("1P97)M+3YA9&1#<F5A=&]R4&5R
M;6ES<VEO;BA015)-4U]$14Q%5$4L(&9A;'-E*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D<&5R;2T^<F5M;W9E0W)E871O<E!E<FUI<W-I;VXH
M4$5235-?1$5,151%+"!F86QS92D["B`@("`@("`@?0H*("`@("`@("`O+R!0
M<F]C97-S('5S97(@<&5R;6ES<VEO;G,N"B`@("`@("`@)'5?;F%M97,@/2!5
M=&EL.CIG971&;W)M1&%T82@G=5]N86UE<R<I.PH@("`@("`@("1U7W-H;W<@
M/2!5=&EL.CIG971&;W)M1&%T82@G=5]S:&]W)RD["B`@("`@("`@)'5?<F5A
M9"`](%5T:6PZ.F=E=$9O<FU$871A*"=U7W)E860G*3L*("`@("`@("`D=5]E
M9&ET(#T@571I;#HZ9V5T1F]R;41A=&$H)W5?961I="<I.PH@("`@("`@("1U
M7V1E;&5T92`](%5T:6PZ.F=E=$9O<FU$871A*"=U7V1E;&5T92<I.PH*("`@
M("`@("!F;W)E86-H("@D=5]N86UE<R!A<R`D:V5Y(#T^("1U<V5R*2!["B`@
M("`@("`@("`@("\O($EF('1H92!U<V5R(&ES(&5M<'1Y+"!O<B!W92=V92!A
M;')E861Y('-E="!P97)M:7-S:6]N<PH@("`@("`@("`@("`O+R!V:6$@=&AE
M(&]W;F5R7R!O<'1I;VYS+"!D;VXG="!D;R!A;GET:&EN9R!H97)E+@H@("`@
M("`@("`@("!I9B`H96UP='DH)'5S97(I('Q\("1U<V5R(#T]("1N97=?;W=N
M97(I('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!I9B`H(65M<'1Y*"1U7W-H;W=;)&ME>5TI*2!["B`@
M("`@("`@("`@("`@("`D<&5R;2T^861D57-E<E!E<FUI<W-I;VXH)'5S97(L
M(%!%4DU37U-(3U<L(&9A;'-E*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1P97)M+3YR96UO=F55<V5R4&5R;6ES<VEO;B@D=7-E
M<BP@4$5235-?4TA/5RP@9F%L<V4I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&EF("@A96UP='DH)'5?<F5A9%LD:V5Y72DI('L*("`@("`@("`@("`@
M("`@("1P97)M+3YA9&15<V5R4&5R;6ES<VEO;B@D=7-E<BP@4$5235-?4D5!
M1"P@9F%L<V4I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)'!E<FTM/G)E;6]V955S97)097)M:7-S:6]N*"1U<V5R+"!015)-4U]2
M14%$+"!F86QS92D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%E
M;7!T>2@D=5]E9&ET6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@)'!E<FTM
M/F%D9%5S97)097)M:7-S:6]N*"1U<V5R+"!015)-4U]%1$E4+"!F86QS92D[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<&5R;2T^
M<F5M;W9E57-E<E!E<FUI<W-I;VXH)'5S97(L(%!%4DU37T5$250L(&9A;'-E
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(65M<'1Y*"1U7V1E
M;&5T95LD:V5Y72DI('L*("`@("`@("`@("`@("`@("1P97)M+3YA9&15<V5R
M4&5R;6ES<VEO;B@D=7-E<BP@4$5235-?1$5,151%+"!F86QS92D["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<&5R;2T^<F5M;W9E
M57-E<E!E<FUI<W-I;VXH)'5S97(L(%!%4DU37T1%3$5412P@9F%L<V4I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!0<F]C97-S(&=R
M;W5P('!E<FUI<W-I;VYS+@H@("`@("`@("1G7VYA;65S(#T@571I;#HZ9V5T
M1F]R;41A=&$H)V=?;F%M97,G*3L*("`@("`@("`D9U]S:&]W(#T@571I;#HZ
M9V5T1F]R;41A=&$H)V=?<VAO=R<I.PH@("`@("`@("1G7W)E860@/2!5=&EL
M.CIG971&;W)M1&%T82@G9U]R96%D)RD["B`@("`@("`@)&=?961I="`](%5T
M:6PZ.F=E=$9O<FU$871A*"=G7V5D:70G*3L*("`@("`@("`D9U]D96QE=&4@
M/2!5=&EL.CIG971&;W)M1&%T82@G9U]D96QE=&4G*3L*"B`@("`@("`@9F]R
M96%C:"`H)&=?;F%M97,@87,@)&ME>2`]/B`D9W)O=7`I('L*("`@("`@("`@
M("`@:68@*&5M<'1Y*"1G<F]U<"DI('L*("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(65M<'1Y*"1G
M7W-H;W=;)&ME>5TI*2!["B`@("`@("`@("`@("`@("`D<&5R;2T^861D1W)O
M=7!097)M:7-S:6]N*"1G<F]U<"P@4$5235-?4TA/5RP@9F%L<V4I.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'!E<FTM/G)E;6]V
M94=R;W5P4&5R;6ES<VEO;B@D9W)O=7`L(%!%4DU37U-(3U<L(&9A;'-E*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(65M<'1Y*"1G7W)E861;
M)&ME>5TI*2!["B`@("`@("`@("`@("`@("`D<&5R;2T^861D1W)O=7!097)M
M:7-S:6]N*"1G<F]U<"P@4$5235-?4D5!1"P@9F%L<V4I.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'!E<FTM/G)E;6]V94=R;W5P
M4&5R;6ES<VEO;B@D9W)O=7`L(%!%4DU37U)%040L(&9A;'-E*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H(65M<'1Y*"1G7V5D:71;)&ME>5TI
M*2!["B`@("`@("`@("`@("`@("`D<&5R;2T^861D1W)O=7!097)M:7-S:6]N
M*"1G<F]U<"P@4$5235-?141)5"P@9F%L<V4I.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)'!E<FTM/G)E;6]V94=R;W5P4&5R;6ES
M<VEO;B@D9W)O=7`L(%!%4DU37T5$250L(&9A;'-E*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!I9B`H(65M<'1Y*"1G7V1E;&5T95LD:V5Y72DI('L*
M("`@("`@("`@("`@("`@("1P97)M+3YA9&1'<F]U<%!E<FUI<W-I;VXH)&=R
M;W5P+"!015)-4U]$14Q%5$4L(&9A;'-E*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1P97)M+3YR96UO=F5'<F]U<%!E<FUI<W-I
M;VXH)&=R;W5P+"!015)-4U]$14Q%5$4L(&9A;'-E*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@)'-H87)E+3YS971097)M:7-S:6]N*"1P
M97)M+"!F86QS92D["B`@("`@("`@)'-H87)E+3YS879E*"D["B`@("`@("`@
M)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E5P9&%T960@7"(E<UPB
M+B(I+"`D<VAA<F4M/F=E="@G;F%M92<I*2P@)VAO<F1E+G-U8V-E<W,G*3L*
M("`@("`@("`D9F]R;2`]("=E9&ET+FEN8R<["B`@("!]"B`@("!B<F5A:SL*
M?0H*:68@*&ES7V$H)'-H87)E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`D=&ET
M;&4@/2!?*")%9&ET(%!E<FUI<W-I;VYS(BD["GT@96QS92!["B`@("`D=&ET
M;&4@/2!S<')I;G1F*%\H(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(BDL("1S
M:&%R92T^9V5T*"=N86UE)RDI.PI]"@II9B`H)&%U=&@M/FAA<T-A<&%B:6QI
M='DH)VQI<W0G*2D@>PH@("`@)'5S97),:7-T(#T@)&%U=&@M/FQI<W15<V5R
M<R@I.PH@("`@:68@*&ES7V$H)'5S97),:7-T+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)'5S97),:7-T+"!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@)'5S97),:7-T
M(#T@87)R87DH*3L*("`@('T*("`@('-O<G0H)'5S97),:7-T*3L*?2!E;'-E
M('L*("`@("1U<V5R3&ES="`](&%R<F%Y*"D["GT*"B1G<F]U<$QI<W0@/2`D
M9W)O=7!S+3YG971'<F]U<$UE;6)E<G-H:7!S*$%U=&@Z.F=E=$%U=&@H*2P@
M=')U92D["FEF("AI<U]A*"1G<F]U<$QI<W0L("=014%27T5R<F]R)RDI('L*
M("`@($AO<F1E.CIL;V=-97-S86=E*"1G<F]U<$QI<W0L(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?3D]424-%*3L*("`@("1G<F]U<$QI<W0@/2!A
M<G)A>2@I.PI]"F%S;W)T*"1G<F]U<$QI<W0I.PH*<F5Q=6ER92!(3U)$15]4
M14U03$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*)&YO=&EF:6-A=&EO
M;BT^;F]T:69Y*&%R<F%Y*"=L:7-T96YE<G,G(#T^("=S=&%T=7,G*2D["FEF
M("@A96UP='DH)&9O<FTI*2!["B`@("!R97%U:7)E($A/4D1%7U1%35!,051%
M4R`N("<O<VAA<F5S+R<@+B`D9F]R;3L*?0H*<F5Q=6ER92!(3U)$15]414U0
M3$%415,@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]S:6=N=7`N<&AP````````````````````````````````````````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`T-S`W`#$P-3$U-#,S-S0S`#`Q-S<P,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@)$AO<F1E.B!H;W)D92]S:6=N=7`N<&AP+'8@,2XQ-RXQ,"XX(#(P
M,#8O,#$O,#$@,C$Z,C@Z,#0@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`R+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J+PH*0&1E9FEN92@G05542%](04Y$3$52)RP@=')U92D["D!D
M969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2D["G)E<75I
M<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E
M7V]N8V4@)TAO<F1E+T%U=&@O4VEG;G5P+G!H<"<["G)E<75I<F5?;VYC92`G
M2&]R9&4O5F%R:6%B;&5S+G!H<"<["@HD875T:"`]("9!=71H.CIS:6YG;&5T
M;VXH)&-O;F9;)V%U=&@G75LG9')I=F5R)UTI.PH*+R\@36%K92!S=7)E('-I
M9VYU<',@87)E(&5N86)L960@8F5F;W)E('!R;V-E961I;F<*:68@*"1C;VYF
M6R=S:6=N=7`G75LG86QL;W<G72`A/3T@=')U92!\?`H@("`@(21A=71H+3YH
M87-#87!A8FEL:71Y*"=A9&0G*2D@>PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S
M:"A?*")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M=&AI<R!S:71E+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@(&AE861E<B@G3&]C
M871I;VXZ("<@+B!!=71H.CIG971,;V=I;E-C<F5E;B@I*3L*("`@(&5X:70[
M"GT*"B1V87)S(#T@)E9A<FEA8FQE<SHZ9V5T1&5F875L=%9A<FEA8FQE<R@I
M.PHD<VEG;G5P(#T@)D%U=&A?4VEG;G5P.CIS:6YG;&5T;VXH*3L*)')E;F1E
M<F5R(#T@)FYE=R!(;W)D95]&;W)M7U)E;F1E<F5R*"D["@HD9F]R;7-I9VYU
M<"`]("9(;W)D95]&;W)M.CIS:6YG;&5T;VXH)TAO<F1E4VEG;G5P1F]R;2<L
M("1V87)S*3L*)&9O<FUS:6=N=7`M/G9A;&ED871E*"1V87)S*3L*"FEF("@D
M=F%R<RT^9V5T*"=F;W)M;F%M92<I("$]("=H;W)D97-I9VYU<&9O<FTG*2![
M"B`@("`O*B!.;W0@>65T('-U8FUI='1E9"X@*B\*("`@("1F;W)M<VEG;G5P
M+3YC;&5A<E9A;&ED871I;VXH*3L*?0H*:68@*"1F;W)M<VEG;G5P+3YI<U9A
M;&ED*"D@)B8@)'9A<G,M/F=E="@G9F]R;6YA;64G*2`]/2`G:&]R9&5S:6=N
M=7!F;W)M)RD@>PH@("`@)&9O<FUS:6=N=7`M/F=E=$EN9F\H)'9A<G,L("1I
M;F9O*3L*"B`@("!I9B`H(21C;VYF6R=S:6=N=7`G75LG87!P<F]V92==*2![
M"B`@("`@("`@+RH@57-E<B!C86X@<VEG;B!U<"!D:7)E8W1L>2P@;F\@:6YT
M97)V96YT:6]N(&YE8V5S<V%R>2X@*B\*("`@("`@("`D<W5C8V5S<R`]("1S
M:6=N=7`M/F%D9%-I9VYU<"@D:6YF;RD["B`@("`@("`@)'-U8V-E<W-?;65S
M<V%G92`]('-P<FEN=&8H7R@B061D960@7"(E<UPB('1O('1H92!S>7-T96TN
M(%EO=2!C86X@;&]G(&EN(&YO=RXB*2P@)&EN9F];)W5S97)?;F%M92==*3L*
M("`@('T@96QS96EF("@D8V]N9ELG<VEG;G5P)UU;)V%P<')O=F4G72D@>PH@
M("`@("`@("\J($EN<V5R="!T:&ES('5S97(@:6YT;R!A('%U975E(&9O<B!A
M9&UI;B!A<'!R;W9A;"X@*B\*("`@("`@("`D<W5C8V5S<R`]("1S:6=N=7`M
M/G%U975E4VEG;G5P*"1I;F9O*3L*("`@("`@("`D<W5C8V5S<U]M97-S86=E
M(#T@<W!R:6YT9BA?*")3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB
M('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@
M<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB*2P@)&EN9F];)W5S97)?;F%M
M92==*3L*("`@('T*"B`@("!I9B`H:7-?82@D<W5C8V5S<RP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?
M*")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y
M<W1E;3H@)7,B*2P@)&EN9F];)W5S97)?;F%M92==+"`D<W5C8V5S<RT^9V5T
M365S<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@("!](&5L<V4@>PH@("`@
M("`@("1N;W1I9FEC871I;VXM/G!U<V@H)'-U8V-E<W-?;65S<V%G92P@)VAO
M<F1E+G-U8V-E<W,G*3L*("`@("`@("`D=7)L(#T@075T:#HZ9V5T3&]G:6Y3
M8W)E96XH)R<L("1I;F9O6R=U<FPG72D["B`@("`@("`@:&5A9&5R*"=,;V-A
M=&EO;CH@)R`N("1U<FPI.PH@("`@("`@(&5X:70["B`@("!]"GT*"B1T:71L
M92`](%\H(E5S97(@4F5G:7-T<F%T:6]N(BD["G)E<75I<F4@2$]21$5?5$5-
M4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["B1N;W1I9FEC871I;VXM
M/FYO=&EF>2AA<G)A>2@G;&ES=&5N97)S)R`]/B`G<W1A='5S)RDI.PHD9F]R
M;7-I9VYU<"T^<F5N9&5R06-T:79E*"1R96YD97)E<BP@)'9A<G,L("=S:6=N
M=7`N<&AP)RP@)W!O<W0G*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G
M+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T96UP;&%T97,O````````````````````````````
M`````````````````````````````````````````````````````````#`P
M,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S8Q
M`#`Q-S8U,P`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R\N:'1A
M8V-E<W,`````````````````````````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,38`,3`U,34T,S,W-C$`,#(Q-#0V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````$1E;GD@9G)O;2!A;&P*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O861M:6XO````````````
M````````````````````````````````````````````````````````````
M`````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,S-S8P`#`R,#<T,@`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E
M<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8P``````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#$W,C,`,3`U,34T,S,W-C``,#(T,34V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#QD:78@:60](FUE;G4B/@H@
M/'-P86X@8VQA<W,](FQE9G1&;&]A="(^"CP_<&AP"B1M96YU(#T@)FYE=R!-
M96YU*"D["B1M96YU+3YA9&0H2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=S97)V
M:6-E<R]P;W)T86PO)RDL(%\H(DAO7VUE(BDL("=H;W)D92YP;F<G*3L*9F]R
M96%C:"`H)')E9VES=')Y+3YL:7-T07!P<R@I(&%S("1A<'`I('L*("`@(&EF
M("@D<F5G:7-T<GDM/FAA<TUE=&AO9"@G861M:6Y?;&ES="<L("1A<'`I*2![
M"B`@("`@("`@)&QI<W0@/2`D<F5G:7-T<GDM/F-A;&Q">5!A8VMA9V4H)&%P
M<"P@)V%D;6EN7VQI<W0G*3L*("`@("`@("!I9B`H:7-?82@D;&ES="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("!]
M"@H@("`@("`@(&9O<F5A8V@@*"1L:7-T(&%S("1V86QS*2!["B`@("`@("`@
M("`@(&EF("@D87!P("$]("=H;W)D92<I('L*("`@("`@("`@("`@("`@("1N
M86UE(#T@)')E9VES=')Y+3YG970H)VYA;64G+"`D87!P*3L*("`@("`@("`@
M("`@("`@(&EF("@A96UP='DH)'9A;'-;)VYA;64G72DI('L*("`@("`@("`@
M("`@("`@("`@("`D;F%M92`N/2`G("<@+B`D=F%L<ULG;F%M92==.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)&YA;64@/2`D=F%L<ULG;F%M92==.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1I;6<@/2!I<W-E="@D=F%L<ULG:6-O;B==*2`_("1R96=I
M<W1R>2T^9V5T26UA9V5$:7(H)&%P<"D@+B`G+R<@+B`D=F%L<ULG:6-O;B==
M(#H@)')E9VES=')Y+3YG970H)VEC;VXG+"`D87!P*3L*("`@("`@("`@("`@
M)&UE;G4M/F%D9"A(;W)D93HZ=7)L*"1R96=I<W1R>2T^87!P;&EC871I;VY7
M96)0871H*"1V86QS6R=L:6YK)UTL("1A<'`I*2P@)&YA;64L("1I;6<L("<G
M*3L*("`@("`@("!]"B`@("!]"GT*96-H;R`D;65N=2T^<F5N9&5R*"D["C\^
M"B`\+W-P86X^"CPO9&EV/@H`````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E
M;7!L871E<R]A9&UI;B]G<F]U<',O````````````````````````````````
M````````````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-C``,#(R,C8Q`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL
M9"YI;F,````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<Q,P`Q,#4Q-30S,S<V
M,``P,C0U,3$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/&9O<FT@;F%M93TB861D7V-H:6QD(B!M971H;V0](G!O<W0B(&%C
M=&EO;CTB9W)O=7!S+G!H<"(^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64]
M(F%C=&EO;DE$(B!V86QU93TB861D8VAI;&1F;W)M(B`O/@H\:6YP=70@='EP
M93TB:&ED9&5N(B!N86UE/2)C:60B('9A;'5E/2(\/W!H<"!E8VAO("1C:60@
M/SXB("\^"CP_<&AP(%5T:6PZ.G!F;W)M26YP=70H*2`_/@H*/&@Q(&-L87-S
M/2)H96%D97(B/@H@/#]P:'`@96-H;R!(;W)D93HZ:6UG*"=G<F]U<"YP;F<G
M*2`_/B9N8G-P.SP_<&AP('!R:6YT9BA?*")!9&0@82!C:&EL9"!G<F]U<"!T
M;R!<(B5S7"(B*2P@)&=N86UE*2`_/@H\+V@Q/@H*/&EN<'5T('1Y<&4](G1E
M>'0B(&YA;64](F-H:6QD(B`O/@H\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S
M<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")!9&0B*2`_/B(@+SX*
M/"]F;W)M/@H\8G(@+SX*````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8P``````````
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#$Q,#<`,3`U,34T,S,W-C``,#(T,C$U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#QF;W)M
M(&YA;64](F1E;&5T92(@;65T:&]D/2)P;W-T(B!A8W1I;VX](F=R;W5P<RYP
M:'`B/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)A8W1I;VY)1"(@=F%L
M=64](F1E;&5T969O<FTB("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64]
M(F-I9"(@=F%L=64](CP_<&AP(&5C:&\@)&=R;W5P+3YG971)9"@I(#\^(B`O
M/@H\/W!H<"!5=&EL.CIP9F]R;4EN<'5T*"D@/SX*"CQH,2!C;&%S<STB:&5A
M9&5R(CX*(#P_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G9W)O=7`N<&YG)RD@/SXF
M;F)S<#L\/W!H<"!P<FEN=&8H7R@B07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(I+"`D9W)O=7`M
M/F=E=%-H;W)T3F%M92@I*2`_/@H\+V@Q/@H*/&EN<'5T('1Y<&4](G-U8FUI
M="(@8VQA<W,](F)U='1O;B(@;F%M93TB8V]N9FER;2(@=F%L=64](CP_<&AP
M(&5C:&\@7R@B1&5L971E(BD@/SXB("\^"CQI;G!U="!T>7!E/2)S=6)M:70B
M(&-L87-S/2)B=71T;VXB(&YA;64](F-O;F9I<FTB('9A;'5E/2(\/W!H<"!E
M8VAO(%\H(D-A;F-E;"(I(#\^(B`O/@H\+V9O<FT^"CQB<B`O/@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,`````
M````````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,V,#<`,3`U,34T,S,W-C``,#(S
M-S`W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#QF;W)M(&YA;64](F5D:71?9W)O=7`B(&UE=&AO9#TB<&]S="(@86-T:6]N
M/2)G<F]U<',N<&AP(CX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB86-T
M:6]N240B('9A;'5E/2)E9&ET9F]R;2(@+SX*/&EN<'5T('1Y<&4](FAI9&1E
M;B(@;F%M93TB8VED(B!V86QU93TB/#]P:'`@96-H;R`D9W)O=7`M/F=E=$ED
M*"D@/SXB("\^"CP_<&AP(%5T:6PZ.G!F;W)M26YP=70H*2`_/@H*/&@Q(&-L
M87-S/2)H96%D97(B/@H@/#]P:'`@96-H;R!(;W)D93HZ:6UG*"=U<V5R+G!N
M9R<I("X@)R`G("X@:'1M;'-P96-I86QC:&%R<R@D9W)O=7`M/F=E=%-H;W)T
M3F%M92@I*2`_/@H\+V@Q/@H*/&QA8F5L(&9O<CTB96UA:6PB/CP_<&AP(&5C
M:&\@7R@B16UA:6P@061D<F5S<R(I(#\^/"]L86)E;#X*/&EN<'5T('1Y<&4]
M(G1E>'0B(&YA;64](F5M86EL(B!I9#TB96UA:6PB('-I>F4](C4P(B!V86QU
M93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1G<F]U<"T^9V5T*"=E
M;6%I;"<I*2`_/B(@+SX*/&)R("\^"CQB<B`O/@H*/&@Q(&-L87-S/2)H96%D
M97(B/@H@/#]P:'`@96-H;R!(;W)D93HZ:6UG*"=G<F]U<"YP;F<G*2`N("<@
M)R`N(%\H(DUE;6)E<G,B*2`_/@H\+V@Q/@H*/'1A8FQE(&-L87-S/2)L:6YE
M9%)O=R!N;W=R87`B(&-E;&QS<&%C:6YG/2(P(B!W:61T:#TB,3`P)2(^"B`\
M='(@8VQA<W,](F-O;G1R;VPB/@H@(#QT:"!W:61T:#TB,3`E(B!C;&%S<STB
M;&5F=$%L:6=N(CX\/W!H<"!E8VAO(%\H(E5S97(B*2`_/CPO=&@^"B`@/'1H
M('=I9'1H/2(Y,"4B(&-L87-S/2)L969T06QI9VXB/CP_<&AP(&5C:&\@7R@B
M4F5M;W9E(BD@/SX\+W1H/@H@/"]T<CX*/#]P:'`@9F]R96%C:"`H)'5S97)S
M(&%S("1U<V5R*3H@/SX*(#QT<CX*("`\=&0^/#]P:'`@96-H;R!H=&UL<W!E
M8VEA;&-H87)S*"1U<V5R*2`_/CPO=&0^"B`@/'1D/CQI;G!U="!T>7!E/2)C
M:&5C:V)O>"(@;F%M93TB<F5M;W9E6SP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<R@D=7-E<BD@/SY=(B`O/CPO=&0^"B`\+W1R/@H\/W!H<"!E;F1F;W)E
M86-H.R`_/@H\+W1A8FQE/@H\8G(@+SX*"CP_<&AP(&EF("AC;W5N="@D:6YH
M97)I=&5D7W5S97)S*2DZ(#\^"CQH,2!C;&%S<STB:&5A9&5R(CX*(#P_<&AP
M(&5C:&\@2&]R9&4Z.FEM9R@G9W)O=7`N<&YG)RD@+B`G("<@+B!?*"));FAE
M<FET960@365M8F5R<R(I(#\^"CPO:#$^"CQU;#X*/#]P:'`@9F]R96%C:"`H
M)&EN:&5R:71E9%]U<V5R<R!A<R`D=7-E<BDZ(#\^"B`\;&D^/#]P:'`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1U<V5R*2`_/CPO;&D^"CP_<&AP(&5N9&9O
M<F5A8V@[(#\^"CPO=6P^"CQB<B`O/@H\/W!H<"!E;F1I9CL@/SX*"CQH,2!C
M;&%S<STB:&5A9&5R(CX*(#P_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G=7-E<BYP
M;F<G*2`N("<@)R`N(%\H(D%D9"!-96UB97)S(BD@/SX*/"]H,3X*/#]P:'`@
M:68@*"1A=71H+3YH87-#87!A8FEL:71Y*"=L:7-T)RDI.B`_/@H\<V5L96-T
M(&YA;64](FYE=U]U<V5R6UTB(&UU;'1I<&QE/2)M=6QT:7!L92(^"CP_<&AP
M(&9O<F5A8V@@*"1U<V5R7VQI<W0@87,@)'5S97(I('L@:68@*"%I;E]A<G)A
M>2@D=7-E<BP@)&%L;%]U<V5R<RDI('L@/SX*(#QO<'1I;VX@=F%L=64](CP_
M<&AP(&5C:&\@)'5S97(@/SXB/CP_<&AP(&5C:&\@)'5S97(@/SX\+V]P=&EO
M;CX*/#]P:'`@?2!](#\^"CPO<V5L96-T/@H\/W!H<"!E;'-E.B`_/@H\:6YP
M=70@='EP93TB=&5X="(@;F%M93TB;F5W7W5S97(B("\^"CP_<&AP(&5N9&EF
M.R`_/@H\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU
M93TB/#]P:'`@<')I;G1F*&AT;6QS<&5C:6%L8VAA<G,H7R@B4V%V92!<(B5S
M7"(B*2P@14Y47T-/35!!5"P@3DQ3.CIG971#:&%R<V5T*"DI+"`D9W)O=7`M
M/F=E=%-H;W)T3F%M92@I*2`_/B(@+SX*/&)R("\^"CQB<B`O/@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T96UP;&%T97,O861M:6XO<V5T=7`O````````````````````````
M`````````````````````````````````````````````#`P,#`W-34`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S8P`#`R,C$P,@`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B]S971U<"]C
M;VYF:6<N:'1M;```````````````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S,S(`,3`U
M,34T,S,W-C``,#(T,C,S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#QT86<Z;F]T:69Y("\^"@H\=&%G.F9O<FT@+SX*"CQI
M9CIP:'`^"CQB<B`O/@H\:#$@8VQA<W,](FAE861E<B(^"B`\9V5T=&5X=#Y'
M96YE<F%T960@0V]D93PO9V5T=&5X=#X*(#QS;6%L;#Y;(#QT86<Z9&EF9E]P
M;W!U<"`O/B!=/"]S;6%L;#X*/"]H,3X*/'1E>'1A<F5A('-T>6QE/2)W:61T
M:#HQ,#`E(B!R;W=S/2(R,"(^/'1A9SIP:'`@+SX\+W1E>'1A<F5A/@H\+VEF
M.G!H<#X*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-3$W`#$P-3$U-#,S-S8P`#`R
M,S<P,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\:68Z9&EF9G,^"CQL;V]P.F1I9F9S/@H\:#$@8VQA<W,](FAE861E<B(@
M:60](CQT86<Z9&EF9G,N87!P("\^(CX*(#QT86<Z9&EF9G,N87!P("\^(#QS
M;6%L;#Y;(#QT86<Z9&EF9G,N=&]G9VQE7W)E;F1E<F5R("\^(%T\+W-M86QL
M/@H\+V@Q/@H\<')E(&-L87-S/2)T97AT(CX\=&%G.F1I9F9S+F1I9F8@+SX\
M+W!R93X*/"]L;V]P.F1I9F9S/@H\96QS93ID:69F<SX*/'`@8VQA<W,](FYO
M=&EC92(^/&=E='1E>'0^3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T
M82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX\+V=E='1E>'0^/"]P/@H\+V5L
M<V4Z9&EF9G,^"CPO:68Z9&EF9G,^"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6P`````````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C`V,P`Q,#4Q-30S,S<V,``P,C0Q,#``(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/'1A9SIN;W1I
M9GD@+SX*"CQT86)L92!C;&%S<STB<W1R:7!E9"(@8V5L;'-P86-I;F<](C`B
M('=I9'1H/2(Q,#`E(CX*("`\='(^"B`@("`\=&0@8VQA<W,](FAE861E<B(^
M"B`@("`@(#QG971T97AT/D%P<&QI8V%T:6]N/"]G971T97AT/@H@("`@/"]T
M9#X*("`@(#QT9"!C;&%S<STB:&5A9&5R(CX*("`@("`@)FYB<W`["B`@("`\
M+W1D/@H@("`@/'1D(&-L87-S/2)H96%D97(B/@H@("`@("`\9V5T=&5X=#Y3
M=&%T=7,\+V=E='1E>'0^"B`@("`\+W1D/@H@(#PO='(^"B`@/&QO;W`Z87!P
M<SX*("`\='(^"B`@("`\=&0^"B`@("`@(#QT86<Z87!P<RYN86UE("\^"B`@
M("`@(#QT86<Z87!P<RYV97)S:6]N("\^"B`@("`\+W1D/@H@("`@/'1D(&%L
M:6=N/2)C96YT97(B/@H@("`@("`\=&%G.F%P<',N8V]N9B`O/@H@("`@/"]T
M9#X*("`@(#QT9#X*("`@("`@/'1A9SIA<'!S+G-T871U<R`O/@H@("`@/"]T
M9#X*("`\+W1R/@H@(#PO;&]O<#IA<'!S/@H\+W1A8FQE/@H\8G(@+SX*"CQT
M86)L92!I9#TB=7!D871E(B!C96QL<W!A8VEN9STB,"(@=VED=&@](C$P,"4B
M/@H@(#QT<B!V86QI9VX](G1O<"(^"B`@("`\=&0@=VED=&@](C4P)2(^"B`@
M("`@(#QI9CIA8W1I;VYS/@H@("`@("`\:#$@8VQA<W,](FAE861E<B(^"B`@
M("`@("`\9V5T=&5X=#Y3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE
M/"]G971T97AT/@H@("`@("`\+V@Q/@H@("`@("`\=&%B;&4@8VQA<W,](G-T
M<FEP960B(&-E;&QS<&%C:6YG/2(P(B!W:61T:#TB,3`P)2(^"B`@("`@("`\
M;&]O<#IA8W1I;VYS/@H@("`@("`@(#QT<CX*("`@("`@("`@/'1D/@H@("`@
M("`@("`@/'1A9SIA8W1I;VYS+FEC;VX@+SX@/'1A9SIA8W1I;VYS+FQI;FL@
M+SX*("`@("`@("`@/"]T9#X*("`@("`@("`\+W1R/@H@("`@("`@/"]L;V]P
M.F%C=&EO;G,^"B`@("`@(#PO=&%B;&4^"B`@("`@(#PO:68Z86-T:6]N<SX*
M("`@(#PO=&0^"B`@("`\=&0@=VED=&@](C4P)2(^"B`@("`@(#QI9CIF='!F
M;W)M/@H@("`@("`@(#QT86<Z9G1P9F]R;2`O/@H@("`@("`\+VEF.F9T<&9O
M<FT^"B`@("`\+W1D/@H@(#PO='(^"CPO=&%B;&4^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O861M:6XO=7-E<B\`
M````````````````````````````````````````````````````````````
M`````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-3$U-#,S-S8P`#`R,3<R,``@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L
M871E<R]A9&UI;B]U<V5R+V%D9"YI;F,`````````````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`Q-S0`,3`U,34T,S,W-C``,#(S,30U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B1R96YD97)E
M<B`]("9N97<@2&]R9&5?1F]R;5]296YD97)E<B@I.PHD861D1F]R;2T^<F5N
M9&5R06-T:79E*"1R96YD97)E<BP@)'9A<G,L($AO<F1E.CIS96QF57)L*"DL
M("=P;W-T)RD["C\^"CQB<B`O/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O861M:6XO
M=7-E<B]A<'!R;W9E+FEN8P``````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R
M-3<U`#$P-3$U-#,S-S8P`#`R-#$P,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\:#$@8VQA<W,](FAE861E<B(^"B`\/W!H
M<"!E8VAO(%\H(E!E;F1I;F<@4VEG;G5P<SHB*2`_/@H\+V@Q/@H*/#]P:'`@
M)&%L;%%U975E9"`]("1S:6=N=7`M/F=E=%%U975E9%-I9VYU<',H*3L@:68@
M*"%C;W5N="@D86QL475E=65D*2DZ(#\^"CQD:78@8VQA<W,](G1E>'0B/CQE
M;3X\/W!H<"!E8VAO(%\H(DYO('!E;F1I;F<@<VEG;G5P<RXB*2`_/CPO96T^
M/"]D:78^"CP_<&AP(&5L<V4Z(#\^"CQT86)L92!C;&%S<STB<W1R:7!E9"(@
M=VED=&@](C$P,"4B(&-E;&QS<&%C:6YG/2(P(CX*(#QT<B!C;&%S<STB:71E
M;2(^"B`@/'1H/B9N8G-P.SPO=&@^"B`@/'1H/B9N8G-P.SPO=&@^"B`@/'1H
M/CP_<&AP(&5C:&\@7R@B57-E<FYA;64B*2`_/CPO=&@^"B`@/'1H('=I9'1H
M/2(Q,#`E(CX\/W!H<"!E8VAO(%\H(D1A=&4@4F5C96EV960B*2`_/CPO=&@^
M"B`\+W1R/@H\/W!H<"!F;W)E86-H("@D86QL475E=65D(&%S("1S:6=N=7`I
M.B!I9B`H)'-I9VYU<"T^9V5T3F%M92@I("$]($1!5$%44D5%7U)/3U0I.B`D
M9&%T82`]("1S:6=N=7`M/F=E=$1A=&$H*3L@/SX*(#QT<CX*("`\=&0^"B`@
M(#QF;W)M(&UE=&AO9#TB<&]S="(@86-T:6]N/2(\/W!H<"!E8VAO($AO<F1E
M.CIS96QF57)L*"D@/SXB/@H@("`@/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M
M93TB=7-E<E]N86UE(B!V86QU93TB/#]P:'`@96-H;R`D<VEG;G5P+3YG971.
M86UE*"D@/SXB("\^"B`@("`\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)F
M;W)M(B!V86QU93TB87!P<F]V95]F(B`O/@H@("`@/&EN<'5T('1Y<&4](G-U
M8FUI="(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B07!P
M<F]V92(I(#\^(B`O/@H@("`\+V9O<FT^"B`@/"]T9#X*("`\=&0^"B`@(#QF
M;W)M(&UE=&AO9#TB<&]S="(@86-T:6]N/2(\/W!H<"!E8VAO($AO<F1E.CIS
M96QF57)L*"D@/SXB/@H@("`@/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB
M=7-E<E]N86UE(B!V86QU93TB/#]P:'`@96-H;R`D<VEG;G5P+3YG971.86UE
M*"D@/SXB("\^"B`@("`\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)F;W)M
M(B!V86QU93TB<F5M;W9E<75E=65D7V8B("\^"B`@("`\:6YP=70@='EP93TB
M<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")2
M96UO=F4B*2`_/B(@+SX*("`@/"]F;W)M/@H@(#PO=&0^"B`@/'1D/CP_<&AP
M(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D<VEG;G5P+3YG971.86UE*"DI(#\^
M/"]T9#X*("`\=&0^/#]P:'`@96-H;R!D871E*"=9+4TM9"!(.FDZ<R<L("1D
M871A6R=D871E4F5C96EV960G72D@/SX\+W1D/@H@/"]T<CX*/#]P:'`@96YD
M:68[(#\^"CP_<&AP(&5N9&9O<F5A8V@[(#\^"CPO=&%B;&4^"CP_<&AP(&5N
M9&EF.R`_/@H\8G(@8VQA<W,](G-P86-E<B(@+SX*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8P``````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P,C(`,3`U,34T,S,W-C``,#(S-#<T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#QF
M;W)M(&YA;64](F-L96%R=7-E<B(@;65T:&]D/2)P;W-T(CX*/&EN<'5T('1Y
M<&4](FAI9&1E;B(@;F%M93TB9F]R;2(@=F%L=64](F-L96%R(B`O/@H*/&@Q
M(&-L87-S/2)H96%D97(B/@H@/#]P:'`@<')I;G1F*%\H(D-L96%R(&]U="!U
M<V5R.B`E<R(I+"`D9E]U<V5R7VYA;64I(#\^"CPO:#$^"CQP(&-L87-S/2)I
M=&5M(CX*(#QS=')O;F<^/#]P:'`@<')I;G1F*%\H(E)E86QL>2!R96UO=F4@
M=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@
M8F4@=6YD;VYE+B(I+"`D9E]U<V5R7VYA;64I(#\^/"]S=')O;F<^"CPO<#X*
M/'`@8VQA<W,](F-O;G1R;VPB/@H@/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA
M<W,](F)U='1O;B(@;F%M93TB<W5B;6ET(B!V86QU93TB/#]P:'`@96-H;R!?
M*")#;&5A<B!U<V5R(BD@/SXB("\^"B`\:6YP=70@='EP93TB<W5B;6ET(B!C
M;&%S<STB8G5T=&]N(B!N86UE/2)S=6)M:70B('9A;'5E/2(\/W!H<"!E8VAO
M(%\H(D-A;F-E;"(I(#\^(B`O/@H\+W`^"CPO9F]R;3X*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC````
M````````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,S,#``,3`U,34T,S,W-C``
M,#(S,S8R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#QH,2!C;&%S<STB:&5A9&5R(CX*(#P_<&AP(&5C:&\@7R@B57-E<G,@
M:6X@=&AE('-Y<W1E;3HB*2`_/@H@/#]P:'`@:68@*"1N=6UI=&5M*3H@/SX*
M("`\<VUA;&P^6SP_<&AP('!R:6YT9BA?*"(E<R!T;R`E<R!O9B`E<R(I+"`D
M<W1A<G0L("1E;F0L("1N=6UI=&5M*2`_/ET\+W-M86QL/@H@/#]P:'`@96YD
M:68[(#\^"CPO:#$^"@H\9&EV(&-L87-S/2)H96%D97)B;W@B/@H*/&1I=B!C
M;&%S<STB8V]N=')O;"(^"B`\9F]R;2!M971H;V0](G!O<W0B(&YA;64](G-E
M87)C:"(@86-T:6]N/2(\/W!H<"!E8VAO($AO<F1E.CIS96QF57)L*"D@/SXB
M/@H@/#]P:'`@96-H;R!5=&EL.CIF;W)M26YP=70H*2`_/@H@/&EN<'5T('1Y
M<&4](FAI9&1E;B(@;F%M93TB<&%G92(@=F%L=64](C`B/@H@/'-T<F]N9SX\
M/W!H<"!E8VAO(%\H(E-E87)C:"(I(#\^.CPO<W1R;VYG/B9N8G-P.PH@/&EN
M<'5T(&YA;64](G-E87)C:%]P871T97)N(B!T>7!E/2)T97AT(B!V86QU93TB
M(B!S:7IE/2(U,"(@;6%X;&5N9W1H/2(Q,#`B("\^"B`\:6YP=70@='EP93TB
M<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")3
M96%R8V@B*2`_/B(@+SX*(#PO9F]R;3X*/"]D:78^"@H\=&%B;&4@8VQA<W,]
M(G-T<FEP960B('=I9'1H/2(Q,#`E(B!C96QL<W!A8VEN9STB,"(^"CP_<&AP
M"B1R96UO=F4@/2`D875T:"T^:&%S0V%P86)I;&ET>2@G<F5M;W9E)RD["B1T
M;W1A;"`](#`["F9O<F5A8V@@*"1U<V5R<R!A<R`D=7-E<BDZ"B`@("!I9B`H
M)'1O=&%L*RL@/"`D;6EN('Q\("1T;W1A;"`^("1M87@I('L*("`@("`@("!C
M;VYT:6YU93L*("`@('T*/SX*(#QT<CX*/#]P:'`@:68@*"1R96UO=F4I.B`_
M/@H@(#QT9"!W:61T:#TB,24B/CP_<&AP(&5C:&\@2&]R9&4Z.FQI;FLH2&]R
M9&4Z.F%P<&QI8V%T:6]N57)L*"=A9&UI;B]U<V5R+G!H<#]F;W)M/7)E;6]V
M95]F)G5S97)?;F%M93TG("X@)'5S97(I+"!?*")$96QE=&4B*2D@+B!(;W)D
M93HZ:6UG*"=D96QE=&4N<&YG)RP@7R@B1&5L971E(BDI(#\^/"]A/CPO=&0^
M"CP_<&AP(&5N9&EF.R`_/@H@(#QT9"!W:61T:#TB,24B/CP_<&AP(&5C:&\@
M2&]R9&4Z.FQI;FLH2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=A9&UI;B]U<V5R
M+G!H<#]F;W)M/75P9&%T95]F)G5S97)?;F%M93TG("X@)'5S97(I+"!?*")5
M<&1A=&4B*2D@+B`@2&]R9&4Z.FEM9R@G961I="YP;F<G+"!?*")5<&1A=&4B
M*2D@/SX\+V$^/"]T9#X*("`\=&0@=VED=&@](C$E(CX\/W!H<"!E8VAO($AO
M<F1E.CIL:6YK*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO=7-E<BYP
M:'`_9F]R;3UC;&5A<E]F)G5S97)?;F%M93TG("X@)'5S97(I+"!?*")#;&5A
M<B!U<V5R(&1A=&$B*2D@+B`@2&]R9&4Z.FEM9R@G<F5L;V%D+G!N9R<L(%\H
M(D-L96%R('5S97(@9&%T82(I*2`_/CPO83X\+W1D/@H@(#QT9"!C;&%S<STB
M;&5F=$%L:6=N(CX\/W!H<"!E8VAO("1U<V5R(#\^/"]T9#X*(#PO='(^"CP_
M<&AP(&5N9&9O<F5A8V@[(#\^"CPO=&%B;&4^"CP_<&AP"FEF("@D;G5M:71E
M;2D@>PH@("`@)'!A9V5R(#T@)FYE=R!(;W)D95]525]086=E<B@G<&%G92<L
M("1V87)S+"!A<G)A>2@G;G5M)R`]/B`D=&]T86PL("=U<FPG(#T^("1V:65W
M=7)L+"`G<&%G95]C;W5N="<@/3X@,3`L("=P97)P86=E)R`]/B`D<&5R<&%G
M92DI.PH@("`@96-H;R`D<&%G97(M/G)E;F1E<B@D<&%G92P@)'1O=&%L+"`D
M=FEE=W5R;"D["GT*/SX*/"]D:78^"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,`````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#(W`#$P-3$U-#,S-S8P`#`R,S4P
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M:#$@8VQA<W,](FAE861E<B(^"B`\/W!H<"!E8VAO(%\H(D%D9&EN9R!U<V5R
M<R!I<R!D:7-A8FQE9"XB*2`_/@H\+V@Q/@H\<"!C;&%S<STB8V]N=')O;"(^
M"B`\/W!H<"!E8VAO(%\H(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D
M;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@
M=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU
M<W0@=7-E(&$@9&EF9F5R96YT(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(BD@
M/SX*/"]P/@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8P``````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#,U,@`Q,#4Q-30S,S<V,``P,C,W,C,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/&@Q(&-L87-S/2)H
M96%D97(B/@H@/#]P:'`@96-H;R!?*"),:7-T:6YG('5S97)S(&ES(&1I<V%B
M;&5D+B(I(#\^"CPO:#$^"CQP(&-L87-S/2)C;VYT<F]L(CX*(#P_<&AP(&5C
M:&\@7R@B66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U
M<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@
M9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(I(#\^"CPO<#X*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V92YI;F,`````````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`W-S<`,3`U,34T,S,W-C``,#(S-S(S`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#QF;W)M(&YA;64](G)E;6]V975S97(B
M(&UE=&AO9#TB<&]S="(^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F9O
M<FTB('9A;'5E/2)R96UO=F4B("\^"@H\:#$@8VQA<W,](FAE861E<B(^"B`\
M/W!H<"!P<FEN=&8H7R@B4F5M;W9E('5S97(Z("5S(BDL("1F7W5S97)?;F%M
M92D@/SX*/"]H,3X*/'`@8VQA<W,](FET96TB/@H@/'-T<F]N9SX\/W!H<"!P
M<FEN=&8H7R@B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N
M;F]T(&)E('5N9&]N92XB*2P@)&9?=7-E<E]N86UE*2`_/CPO<W1R;VYG/@H\
M+W`^"CQP(&-L87-S/2)C;VYT<F]L(CX*(#QI;G!U="!T>7!E/2)S=6)M:70B
M(&-L87-S/2)B=71T;VXB(&YA;64](G-U8FUI="(@=F%L=64](CP_<&AP(&5C
M:&\@7R@B4F5M;W9E('5S97(B*2`_/B(@+SX*(#QI;G!U="!T>7!E/2)S=6)M
M:70B(&-L87-S/2)B=71T;VXB(&YA;64](G-U8FUI="(@=F%L=64](CP_<&AP
M(&5C:&\@7R@B0V%N8V5L(BD@/SXB("\^"CPO<#X*/"]F;W)M/@H`+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O861M:6XO=7-E<B]R96UO
M=F5Q=65U960N:6YC````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#`Q`#$P-3$U
M-#,S-S8P`#`R-3$Q,0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\9F]R;2!M971H;V0](G!O<W0B(&%C=&EO;CTB/#]P:'`@
M96-H;R!(;W)D93HZ<V5L9E5R;"@I(#\^(CX*/#]P:'`@571I;#HZ<&9O<FU)
M;G!U="@I(#\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F9O<FTB('9A
M;'5E/2)R96UO=F5Q=65U960B("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA
M;64](G5S97)?;F%M92(@=F%L=64](CP_<&AP(&5C:&\@)&9?=7-E<E]N86UE
M(#\^(B`O/@H*/&@Q(&-L87-S/2)H96%D97(B/@H@/#]P:'`@96-H;R!?*")0
M96YD:6YG(%-I9VYU<',Z(BD@/SX*/"]H,3X*/'`@8VQA<W,](FET96TB/@H@
M/#]P:'`@<')I;G1F*%\H(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO
M=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(BDL("1F7W5S97)?;F%M
M92D@/SX*/"]P/@H\<"!C;&%S<STB8V]N=')O;"(^"B`@/&EN<'5T(&-L87-S
M/2)B=71T;VXB('1Y<&4](G-U8FUI="(@=F%L=64](CP_<&AP(&5C:&\@7R@B
M4F5M;W9E(BD@/SXB("\^"CPO<#X*/"]F;W)M/@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T-#0P
M`#$P-3$U-#,S-S8P`#`R,S8W-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP
M="(^"CPA+2T*"F9U;F-T:6]N('9A;&ED871E7W5P9&%T92@I"GL*("`@(&EF
M("AD;V-U;65N="YU<&1A=&5U<V5R+G5S97)?;F%M92YV86QU92`]/2`B(BD@
M>PH@("`@("`@(&1O8W5M96YT+G5P9&%T975S97(N=7-E<E]N86UE+F9O8W5S
M*"D["B`@("`@("`@86QE<G0H)SP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")9
M;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(BDI(#\^)RD[
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?2!E;'-E(&EF("AD;V-U;65N
M="YU<&1A=&5U<V5R+G5S97)?<&%S<U\Q("8F"B`@("`@("`@("`@("`@(&1O
M8W5M96YT+G5P9&%T975S97(N=7-E<E]P87-S7S$N=F%L=64@(3T@9&]C=6UE
M;G0N=7!D871E=7-E<BYU<V5R7W!A<W-?,BYV86QU92D@>PH@("`@("`@(&1O
M8W5M96YT+G5P9&%T975S97(N=7-E<E]P87-S7S$N=F%L=64@/2`B(CL*("`@
M("`@("!D;V-U;65N="YU<&1A=&5U<V5R+G5S97)?<&%S<U\R+G9A;'5E(#T@
M(B(["B`@("`@("`@9&]C=6UE;G0N=7!D871E=7-E<BYU<V5R7W!A<W-?,2YF
M;V-U<R@I.PH@("`@("`@(&%L97)T*"<\/W!H<"!E8VAO(&%D9'-L87-H97,H
M7R@B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(BDI(#\^)RD["B`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@?0H*("`@(')E='5R;B!T<G5E.PI]"@HO+RTM/@H\
M+W-C<FEP=#X*"CQF;W)M(&YA;64](G5P9&%T975S97(B(&UE=&AO9#TB<&]S
M="(^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F9O<FTB('9A;'5E/2)U
M<&1A=&4B/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)U<V5R7VYA;64B
M('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&9?=7-E<E]N
M86UE*2`_/B(@+SX*/&@Q(&-L87-S/2)H96%D97(B/@H@/#]P:'`@<')I;G1F
M*%\H(E5P9&%T92`E<R(I+"`D9E]U<V5R7VYA;64I(#\^"CPO:#$^"CQT86)L
M92!C;&%S<STB<W1R:7!E9"!N;W=R87`B(&-E;&QS<&%C:6YG/2(P(B!W:61T
M:#TB,3`P)2(^"CP_<&AP(&EF("@D875T:"T^:&%S0V%P86)I;&ET>2@G=7!D
M871E)RDI.B`_/@H@/'1R/@H@(#QT9"!W:61T:#TB,24B(&-L87-S/2)L:6=H
M="!R:6=H=$%L:6=N(CX*("`@/#]P:'`@96-H;R!?*").97<@57-E<FYA;64@
M*&]P=&EO;F%L*2(I(#\^"B`@/"]T9#X*("`\=&0^"B`@(#QI;G!U="!T>7!E
M/2)T97AT(B!N86UE/2)U<V5R7VYA;64R(B!V86QU93TB/#]P:'`@96-H;R!H
M=&UL<W!E8VEA;&-H87)S*"1F7W5S97)?;F%M92D@/SXB("\^"B`@/"]T9#X*
M(#PO='(^"B`\='(^"B`@/'1D(&-L87-S/2)R:6=H=$%L:6=N(CX*("`@/#]P
M:'`@96-H;R!?*")087-S=V]R9"(I(#\^"B`@/"]T9#X*("`\=&0^"B`@(#QI
M;G!U="!T>7!E/2)P87-S=V]R9"(@;F%M93TB=7-E<E]P87-S7S$B("\^"B`@
M/"]T9#X*(#PO='(^"B`\='(^"B`@/'1D(&-L87-S/2)R:6=H=$%L:6=N(CX*
M("`@/#]P:'`@96-H;R!?*")#;VYF:7)M(%!A<W-W;W)D(BD@/SX*("`\+W1D
M/@H@(#QT9#X*("`@/&EN<'5T('1Y<&4](G!A<W-W;W)D(B!N86UE/2)U<V5R
M7W!A<W-?,B(@+SX*("`\+W1D/@H@/"]T<CX*/#]P:'`@96YD:68[(#\^"B`\
M='(^"B`@/'1D(&-L87-S/2)R:6=H=$%L:6=N(CX*("`@/#]P:'`@96-H;R!?
M*")&=6QL($YA;64B*2`_/@H@(#PO=&0^"B`@/'1D/@H@("`\:6YP=70@='EP
M93TB=&5X="(@;F%M93TB=7-E<E]F=6QL;F%M92(@=F%L=64](CP_<&AP(&5C
M:&\@:'1M;'-P96-I86QC:&%R<R@D:61E;G1I='DM/F=E=%9A;'5E*"=F=6QL
M;F%M92<I*2`_/B(@+SX*("`\+W1D/@H@/"]T<CX*(#QT<CX*("`\=&0@8VQA
M<W,](G)I9VAT06QI9VXB/@H@("`\/W!H<"!E8VAO(%\H(D5M86EL($%D9')E
M<W,B*2`_/@H@(#PO=&0^"B`@/'1D/@H@("`\:6YP=70@='EP93TB=&5X="(@
M;F%M93TB=7-E<E]E;6%I;"(@('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)&ED96YT:71Y+3YG971686QU92@G9G)O;5]A9&1R)RDI(#\^
M(B`O/@H@(#PO=&0^"B`\+W1R/@H@/'1R/@H@(#QT9"!C;&%S<STB8V]N=')O
M;"!L969T06QI9VXB(&-O;'-P86X](C(B/@H@("`\:6YP=70@='EP93TB<W5B
M;6ET(B!C;&%S<STB8G5T=&]N(B!N86UE/2)S=6)M:70B(&]N8VQI8VL](G)E
M='5R;B!V86QI9&%T95]U<&1A=&4H*3LB('9A;'5E/2(\/W!H<"!E8VAO(%\H
M(E5P9&%T92!U<V5R(BD@/SXB("\^"B`@(#QI;G!U="!T>7!E/2)R97-E="(@
M8VQA<W,](F)U='1O;B(@;F%M93TB<F5S970B('9A;'5E/2(\/W!H<"!E8VAO
M(%\H(E)E<V5T(BD@/SXB("\^"B`@/"]T9#X*(#PO='(^"CPO=&%B;&4^"CPO
M9F]R;3X*/&)R("\^"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T
M97,O8V]M;6]N+69O;W1E<BYI;F,`````````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`Q,#,S`#$P-3$U-#,S-S8Q`#`R,S$R-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\<V-R:7!T(&QA;F=U86=E
M/2)*879A4V-R:7!T,2XU(B!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM
M"G9A<B!?<V5T2&]R9&54:71L92`](#$["G1R>2!["B`@("!I9B`H9&]C=6UE
M;G0N=&ET;&4@)B8@<&%R96YT+F9R86UE<RYH;W)D95]M86EN*2!P87)E;G0N
M9&]C=6UE;G0N=&ET;&4@/2!D;V-U;65N="YT:71L93L*?2!C871C:"`H92D@
M>PI]"B\O("TM/@H\+W-C<FEP=#X*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S
M8W)I<'0B/@H\(2TM"FEF("AT>7!E;V8H7W-E=$AO<F1E5&ET;&4I(#T]("=U
M;F1E9FEN960G("8F(&1O8W5M96YT+G1I=&QE("8F('!A<F5N="YF<F%M97,N
M:&]R9&5?;6%I;BD@<&%R96YT+F1O8W5M96YT+G1I=&QE(#T@9&]C=6UE;G0N
M=&ET;&4["B\O("TM/@H\+W-C<FEP=#X*/#]P:'`@:68@*&ES<V5T*"1'3$]"
M04Q36R=N;W1I9FEC871I;VXG72DI("1'3$]"04Q36R=N;W1I9FEC871I;VXG
M72T^;F]T:69Y*&%R<F%Y*"=L:7-T96YE<G,G(#T^(&%R<F%Y*"=J879A<V-R
M:7!T)RDI*3L@/SX*/"]B;V1Y/@H\+VAT;6P^"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M96UP;&%T97,O8V]M;6]N+6AE861E<BYI;F,`````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R-S8V`#$P-3$U-#,S-S8Q`#`R,S`W-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`IG;&]B
M86P@)&QA;F=U86=E.PII9B`H:7-S970H)&QA;F=U86=E*2D@>PH@("`@:&5A
M9&5R*"=#;VYT96YT+71Y<&4Z('1E>'0O:'1M;#L@8VAA<G-E=#TG("X@3DQ3
M.CIG971#:&%R<V5T*"DI.PH@("`@:&5A9&5R*"=687)Y.B!!8V-E<'0M3&%N
M9W5A9V4G*3L*?0H_/@H\(41/0U194$4@:'1M;"!054),24,@(BTO+U<S0R\O
M1%1$(%A(5$U,(#$N,"!4<F%N<VET:6]N86PO+T5.(B`B1%1$+WAH=&UL,2UT
M<F%N<VET:6]N86PN9'1D(CX*/"$M+2!(;W)D93H@0V]P>7)I9VAT(#(P,#`M
M,C`P-BP@5&AE($AO<F1E(%!R;VIE8W0N($AO<F1E(&ES('5N9&5R('1H92!,
M1U!,+B`M+3X*/"$M+2`@("`@("`@("`@("`@("`@("`@2&]R9&4@4')O:F5C
M=#H@:'1T<#HO+VAO<F1E+F]R9R\@("`@("`@("`@("`@("`@("`@("`M+3X*
M/"$M+2`@("!'3E4@3&EB<F%R>2!0=6)L:6,@3&EC96YS93H@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"`@("`M+3X*/#]P:'`*96-H
M;R`H(65M<'1Y*"1L86YG=6%G92DI(#\@)SQH=&UL(&QA;F<](B<@+B!S=')T
M<B@D;&%N9W5A9V4L("=?)RP@)RTG*2`N("<B)R`Z("<\:'1M;"<["F5C:&\@
M*"%E;7!T>2@D:65?8VQI96YT8V%P<RDI(#\@)R!X;6QN<SI)13XG(#H@)SXG
M.PH_/@H\:&5A9#X*/#]P:'`*"B1P86=E7W1I=&QE(#T@)$=,3T)!3%-;)W)E
M9VES=')Y)UTM/F=E="@G;F%M92<I.PII9B`H(65M<'1Y*"1T:71L92DI("1P
M86=E7W1I=&QE("X]("<@.CH@)R`N("1T:71L93L*:68@*"%E;7!T>2@D<F5F
M<F5S:%]T:6UE*2`F)B`A96UP='DH)')E9G)E<VA?=7)L*2D@>PH@("`@96-H
M;R`B/&UE=&$@:'1T<"UE<75I=CU<(G)E9G)E<VA<(B!C;VYT96YT/5PB)')E
M9G)E<VA?=&EM93MU<FP])')E9G)E<VA?=7)L7"(@+SY<;B(["GT*"DAO<F1E
M.CII;F-L=61E4V-R:7!T1FEL97,H*3L*/SX*/'1I=&QE/CP_<&AP(&5C:&\@
M:'1M;'-P96-I86QC:&%R<R@D<&%G95]T:71L92D@/SX\+W1I=&QE/@H\;&EN
M:R!H<F5F/2(\/W!H<"!E8VAO("1'3$]"04Q36R=R96=I<W1R>2==+3YG971)
M;6%G941I<B@I(#\^+V9A=FEC;VXN:6-O(B!R96P](E-(3U)40U54($E#3TXB
M("\^"CP_<&AP(&5C:&\@2&]R9&4Z.G-T>6QE<VAE971,:6YK*%5T:6PZ.FYO
M;DEN<'5T5F%R*"=C<W-!<'!S)RDI(#\^"CP_<&AP(&5C:&\@:6UP;&]D92@B
M7&XB+"!5=&EL.CIN;VY);G!U=%9A<B@G;&EN:U1A9W,G+"!A<G)A>2@I*2D@
M/SX*/#]P:'`@:68@*"%E;7!T>2@D:65?8VQI96YT8V%P<RDI.B`_/CQS='EL
M93Y)15PZ8VQI96YT8V%P<R![8F5H879I;W(Z=7)L*"-D969A=6QT(V-L:65N
M=&-A<',I?3PO<W1Y;&4^/#]P:'`@96YD:68[(#\^"CPO:&5A9#X*"CQB;V1Y
M/#]P:'`@:68@*%5T:6PZ.FYO;DEN<'5T5F%R*"=B;V1Y0VQA<W,G*2D@96-H
M;R`G(&-L87-S/2(G("X@)&)O9'E#;&%S<R`N("<B)SL@/SX^"CP_<&AP(&EF
M("@A96UP='DH)&EE7V-L:65N=&-A<',I*3H@/SX\244Z8VQI96YT8V%P<R!)
M1#TB;V)J0T-A<',B("\^/#]P:'`@96YD:68[(#\^"@`````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]C;VYT96YT<R\`````
M````````````````````````````````````````````````````````````
M````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U
M,34T,S,W-C``,#(Q-3`W`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA
M=&5S+V-O;G1E;G1S+V]P96Y?=FEE=U]W:6XN:G,`````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,3$T-@`Q,#4Q-30S,S<V,``P,C0W,3<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/'-C<FEP="!T>7!E/2)T
M97AT+VIA=F%S8W)I<'0B/@H\(2TM"@IF=6YC=&EO;B!T<BAB861V86PI"GL*
M("`@(')E='9A;"`]("<G.PH@("`@=F%L:61C:&%R<R`]("=A8F-D969G:&EJ
M:VQM;F]P<7)S='5V=WAY>C`Q,C,T-38W.#DG.PH*("`@(&)A9'9A;"YT;TQO
M=V5R0V%S92@I.PH@("`@9F]R("AI(#T@,#L@:2`\(&)A9'9A;"YL96YG=&@[
M(&DK*RD@>PH@("`@("`@(&EF("AV86QI9&-H87)S+FEN9&5X3V8H8F%D=F%L
M+F-H87)!="AI*2D@(3T@+3$I('L*("`@("`@("`@("`@<F5T=F%L("L](&)A
M9'9A;"YC:&%R070H:2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=F%L("L]("=?)SL*("`@("`@("!]"B`@("!]"B`@("!R971U<FX@<F5T
M=F%L.PI]"@IF=6YC=&EO;B!V:65W*'5R;"P@<&%R=&ED*0I["B`@("!P87)A
M;2`](")M96YU8F%R/7EE<RQT;V]L8F%R/6YO+&QO8V%T:6]N/6YO+'-T871U
M<SUN;RQS8W)O;&QB87)S/7EE<RQR97-I>F%B;&4]>65S(CL*("`@('=I;F1O
M=RYO<&5N*'5R;"P@)SP_<&AP(&5C:&\@8F%S95]C;VYV97)T*&UI8W)O=&EM
M92@I+"`Q,"P@,S8I(#\^)R`K('1R*'!A<G1I9"DL('!A<F%M*3L*?0H*+R\@
M+2T^"CPO<V-R:7!T/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&5M<&QA=&5S+V1A=&$O````````````````````````````````````````
M```````````````````````````````````````P,#`P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<V,``P,C`U-C,`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8P``
M````````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,#0S`#$P-3$U-#,S
M-S8P`#`R,C<R-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\9F]R;2!M971H;V0](G!O<W0B(&YA;64](FEM<&]R=%]F;W)M
M(B!A8W1I;VX](F1A=&$N<&AP(CX*/#]P:'`@96-H;R!5=&EL.CIF;W)M26YP
M=70H*2`_/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)A8W1I;VY)1"(@
M=F%L=64](CP_<&AP(&5C:&\@*&EN="DD;F5X=%]S=&5P(#\^(B`O/@H\:6YP
M=70@='EP93TB:&ED9&5N(B!N86UE/2)I;7!O<G1?9F]R;6%T(B!V86QU93TB
M8W-V(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)I;7!O<G1?<W1E
M<"(@=F%L=64](CP_<&AP(&5C:&\@*&EN="DD:6UP;W)T7W-T97`@/SXB("\^
M"CQH,2!C;&%S<STB:&5A9&5R(CX*(#P_<&AP('!R:6YT9BA?*"));7!O<G0L
M(%-T97`@)60B*2P@*&EN="DD:6UP;W)T7W-T97`I(#\^"CPO:#$^"CQD:78@
M8VQA<W,](FAE861E<F)O>"!T97AT(CX*("`@(#P_<&AP(&5C:&\@7R@B2&5R
M92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(I(#\^/&)R("\^"B`@
M("`\<')E/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D7U-%4U-)3TY;
M)VEM<&]R=%]D871A)UU;)V9I<G-T7VQI;F5S)UTI(#\^/"]P<F4^/&)R("\^
M"B`@("`\;&%B96P@9F]R/2)H96%D97(B/CP_<&AP(&5C:&\@7R@B1&]E<R!T
M:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L
M(&-H96-K('1H:7,@8F]X.B(I(#\^/"]L86)E;#X*("`@(#QI;G!U="!I9#TB
M:&5A9&5R(B!T>7!E/2)C:&5C:V)O>"(@;F%M93TB:&5A9&5R(B!V86QU93TB
M,2(@8VAE8VME9#TB8VAE8VME9"(@+SX\8G(@+SX*("`@(#P_<&AP(&5C:&\@
M7R@B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B*2`_/@H@("`@
M/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](G-E<"(@<VEZ93TB,2(@=F%L=64]
M(CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D7U-%4U-)3TY;)VEM<&]R
M=%]D871A)UU;)W-E<"==*2`_/B(@+SX\8G(@+SX*("`@(#P_<&AP(&EF("AI
M<W-E="@D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)W%U;W1E)UTI*3H@/SX*
M("`@(#P_<&AP(&5C:&\@7R@B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R
M/R(I(#\^"B`@("`\:6YP=70@='EP93TB=&5X="(@;F%M93TB<75O=&4B('-I
M>F4](C$B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)%]3
M15-324].6R=I;7!O<G1?9&%T82==6R=Q=6]T92==*2`_/B(@+SX\8G(@+SX*
M("`@(#P_<&AP(&5N9&EF.R`_/@H@("`@/#]P:'`@:68@*&ES<V5T*"1?4T53
M4TE/3ELG:6UP;W)T7V1A=&$G75LG9FEE;&1S)UTI*3H@/SX*("`@(#P_<&AP
M(&5C:&\@7R@B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_
M(BD@/SX*("`@(#QI;G!U="!T>7!E/2)T97AT(B!N86UE/2)F:65L9',B('-I
M>F4](C(B('9A;'5E/2(\/W!H<"!E8VAO("AI;G0I)%]315-324].6R=I;7!O
M<G1?9&%T82==6R=F:65L9',G72`_/B(@+SX\8G(@+SX*("`@(#P_<&AP(&5N
M9&EF.R`_/@H\+V1I=CX*/&EN<'5T('1Y<&4](G-U8FUI="(@=F%L=64](CP_
M<&AP(&5C:&\@7R@B3F5X="(I(#\^(B!C;&%S<STB8G5T=&]N(B`O/@H\+V9O
M<FT^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8P``````````
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,C8U,``Q,#4Q-30S,S<V,``P
M,C(U-3,`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"F9U;F-T
M:6]N(')E<V5T2&ED9&5N*"D*>PH@("`@=F%R(&9O<FT@/2!D;V-U;65N="YM
M87!F;W)M.PH@("`@=F%R('1M<"`]("<G.PH@("`@9F]R("AI(#T@,#L@:2`\
M(&9O<FTN<V5L96-T1&%T82YL96YG=&@[(&DK*RD@>PH@("`@("`@('1M<"`K
M/2!F;W)M+G-E;&5C=$1A=&%;:5TN=F%L=64["B`@("`@("`@:68@*&D@/"!F
M;W)M+G-E;&5C=$1A=&$N;&5N9W1H("T@,2D*("`@("`@("`@("`@=&UP("L]
M(")<="(["B`@("!]"B`@("!F;W)M+F1A=&%+97ES+G9A;'5E(#T@=&UP.PH@
M("`@=&UP(#T@)R<["B`@("!F;W(@*&D@/2`P.R!I(#P@9F]R;2YS96QE8W1!
M<'`N;&5N9W1H.R!I*RLI('L*("`@("`@("!T;7`@*ST@9F]R;2YS96QE8W1!
M<'!;:5TN=F%L=64["B`@("`@("`@:68@*&D@/"!F;W)M+G-E;&5C=$%P<"YL
M96YG=&@@+2`Q*0H@("`@("`@("`@("!T;7`@*ST@(EQT(CL*("`@('T*("`@
M(&9O<FTN87!P2V5Y<RYV86QU92`]('1M<#L*?0H*9G5N8W1I;VX@861D4&%I
M<B@I"GL*("`@('9A<B!F;W)M(#T@9&]C=6UE;G0N;6%P9F]R;3L*("`@(&EF
M("AF;W)M+G-E;&5C=#$N<V5L96-T961);F1E>"`^/2`P("8F(&9O<FTN<V5L
M96-T,BYS96QE8W1E9$EN9&5X(#X](#`I('L*("`@("`@("!F;W)M+G-E;&5C
M=$1A=&%;9F]R;2YS96QE8W1$871A+FQE;F=T:%T@/2!N97<@3W!T:6]N*&9O
M<FTN<V5L96-T,5MF;W)M+G-E;&5C=#$N<V5L96-T961);F1E>%TN=&5X="P@
M9F]R;2YS96QE8W0Q6V9O<FTN<V5L96-T,2YS96QE8W1E9$EN9&5X72YV86QU
M92D["B`@("`@("`@9F]R;2YS96QE8W1!<'!;9F]R;2YS96QE8W1!<'`N;&5N
M9W1H72`](&YE=R!/<'1I;VXH9F]R;2YS96QE8W0R6V9O<FTN<V5L96-T,BYS
M96QE8W1E9$EN9&5X72YT97AT+"!F;W)M+G-E;&5C=#);9F]R;2YS96QE8W0R
M+G-E;&5C=&5D26YD97A=+G9A;'5E*3L*("`@("`@("!F;W)M+G-E;&5C=#%;
M9F]R;2YS96QE8W0Q+G-E;&5C=&5D26YD97A=(#T@;G5L;#L*("`@("`@("!F
M;W)M+G-E;&5C=#);9F]R;2YS96QE8W0R+G-E;&5C=&5D26YD97A=(#T@;G5L
M;#L*("`@('T*("`@(')E<V5T2&ED9&5N*"D["GT*"F9U;F-T:6]N(')E;6]V
M95!A:7(H*0I["B`@("!V87(@9F]R;2`](&1O8W5M96YT+FUA<&9O<FT["B`@
M("!I9B`H9F]R;2YS96QE8W1$871A+G-E;&5C=&5D26YD97@@/CT@,"!\?"!F
M;W)M+G-E;&5C=$%P<"YS96QE8W1E9$EN9&5X(#X](#`I('L*("`@("`@("!F
M;W)M+G-E;&5C=#%;9F]R;2YS96QE8W0Q+FQE;F=T:%T@/2!N97<@3W!T:6]N
M*&9O<FTN<V5L96-T1&%T85MF;W)M+G-E;&5C=$1A=&$N<V5L96-T961);F1E
M>%TN=&5X="P@9F]R;2YS96QE8W1$871A6V9O<FTN<V5L96-T1&%T82YS96QE
M8W1E9$EN9&5X72YV86QU92D["B`@("`@("`@9F]R;2YS96QE8W0R6V9O<FTN
M<V5L96-T,BYL96YG=&A=(#T@;F5W($]P=&EO;BAF;W)M+G-E;&5C=$%P<%MF
M;W)M+G-E;&5C=$%P<"YS96QE8W1E9$EN9&5X72YT97AT+"!F;W)M+G-E;&5C
M=$%P<%MF;W)M+G-E;&5C=$%P<"YS96QE8W1E9$EN9&5X72YV86QU92D["B`@
M("`@("`@9F]R;2YS96QE8W1$871A6V9O<FTN<V5L96-T1&%T82YS96QE8W1E
M9$EN9&5X72`](&YU;&P["B`@("`@("`@9F]R;2YS96QE8W1!<'!;9F]R;2YS
M96QE8W1!<'`N<V5L96-T961);F1E>%T@/2!N=6QL.PH@("`@?0H@("`@<F5S
M971(:61D96XH*3L*?0HO+RTM/@H\+W-C<FEP=#X*"CQF;W)M(&UE=&AO9#TB
M<&]S="(@;F%M93TB;6%P9F]R;2(@86-T:6]N/2)D871A+G!H<"(^"CP_<&AP
M(&5C:&\@571I;#HZ9F]R;4EN<'5T*"D@/SX*/&EN<'5T('1Y<&4](FAI9&1E
M;B(@;F%M93TB86-T:6]N240B('9A;'5E/2(\/W!H<"!E8VAO("AI;G0I)&YE
M>'1?<W1E<"`_/B(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB:6UP
M;W)T7V9O<FUA="(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R
M<RA5=&EL.CIG971&;W)M1&%T82@G:6UP;W)T7V9O<FUA="<I*2`_/B(@+SX*
M/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB:6UP;W)T7W-T97`B('9A;'5E
M/2(\/W!H<"!E8VAO("AI;G0I)&EM<&]R=%]S=&5P(#\^(B`O/@H\:#$@8VQA
M<W,](FAE861E<B(^"B`\/W!H<"!P<FEN=&8H7R@B26UP;W)T+"!3=&5P("5D
M(BDL("AI;G0I)&EM<&]R=%]S=&5P*2`_/@H\+V@Q/@H\<"!C;&%S<STB8V]N
M=')O;"(^"B`\/W!H<"!E8VAO(%\H(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE
M;&1S+B(I(#\^"CPO<#X*/'1A8FQE(&-E;&QS<&%C:6YG/2(P(B!W:61T:#TB
M,3`P)2(^"B`\='(^"B`@/'1D(&-L87-S/2)I=&5M(CX*("`\=&%B;&4^/'1R
M/CQT9#X*("`@(#QT86)L92!C96QL<W!A8VEN9STB,"(^/'1R/@H@("`@("`\
M=&0^"B`@("`@("`@/#]P:'`@96-H;R!?*"));7!O<G1E9"!F:65L9',Z(BD@
M/SX\8G(@+SX*("`@("`@("`\<V5L96-T(&YA;64](G-E;&5C=#$B('-I>F4]
M(C$P(CX*/#]P:'`@9F]R96%C:"`H)%]315-324].6R=I;7!O<G1?9&%T82==
M6R=D871A)UU;,%T@87,@)&ME>2`]/B`D=F%L=64I.@H@("`@("!I9B`H(6ES
M<V5T*"1A<'!?9FEE;&1S6R1K97E=*2DZ(#\^"B`@("`@("`@("`\;W!T:6]N
M('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SXB
M/CP_<&AP(&5C:&\@*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG:&5A9&5R
M)UTI(#\@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`Z(&AT;6QS<&5C:6%L8VAA
M<G,H)'9A;'5E*2`_/CPO;W!T:6]N/@H\/W!H<"!E;F1I9CL*("`@("`@96YD
M9F]R96%C:#L@/SX*("`@("`@("`\+W-E;&5C=#X*("`@("`@/"]T9#X*("`@
M("`@/'1D/@H@("`@("`@(#P_<&AP(&5C:&\@7R@B079A:6QA8FQE(&9I96QD
M<SHB*2`_/CQB<B`O/@H@("`@("`@(#QS96QE8W0@;F%M93TB<V5L96-T,B(@
M<VEZ93TB,3`B/@H\/W!H<"!F;W)E86-H("@D87!P7V9I96QD<R!A<R`D:V5Y
M(#T^("1V86QU92DZ"B`@("`@(&EF("@A:7-S970H)%]315-324].6R=I;7!O
M<G1?9&%T82==6R=D871A)UU;,%U;)&ME>5TI*3H@/SX*("`@("`@/#]P:'`@
M:68@*"@D:V5Y(#T]("=A;&%R;5]T:6UE)RD@?'P@*"1K97D@/3T@)V%L87)M
M7V1A=&4G*2DZ(#\^"B`@("`@("`@("`@(#P_<&AP(&EF("@A:7-S970H)%]3
M15-324].6R=I;7!O<G1?9&%T82==6R=D871A)UU;,%U;)V%L87)M)UTI*3H@
M/SX*("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*"1K97DI(#\^(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L
M8VAA<G,H)'9A;'5E*2`_/CPO;W!T:6]N/@H@("`@("`@("`@("`\/W!H<"!E
M;F1I9CL@/SX*("`@("`@/#]P:'`@96QS96EF("@D:V5Y(#T]("=A;&%R;2<I
M.B`_/@H@("`@("`@("`@("`\/W!H<"!I9B`H(2AI<W-E="@D7U-%4U-)3TY;
M)VEM<&]R=%]D871A)UU;)V1A=&$G75LP75LG86QA<FU?=&EM92==*2`F)B!I
M<W-E="@D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V1A=&$G75LP75LG86QA
M<FU?9&%T92==*2DI.B`_/@H@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SXB/CP_<&AP(&5C
M:&\@:'1M;'-P96-I86QC:&%R<R@D=F%L=64I(#\^/"]O<'1I;VX^"B`@("`@
M("`@("`@(#P_<&AP(&5N9&EF.R`_/@H@("`@("`\/W!H<"!E;'-E.B`_/@H@
M("`@("`\;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA
M<G,H)&ME>2D@/SXB/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D=F%L
M=64I(#\^/"]O<'1I;VX^"B`@("`@(#P_<&AP(&5N9&EF.R`_/@H\/W!H<"!E
M;F1I9CL*("`@("`@96YD9F]R96%C:#L@/SX*("`@("`@("`\+W-E;&5C=#X*
M("`@("`@/"]T9#X*("`@(#PO='(^/"]T86)L93X*("`@(#QI;G!U="!T>7!E
M/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H(D%D9"!P86ER(BD@/SXB
M(&-L87-S/2)B=71T;VXB(&]N8VQI8VL](F%D9%!A:7(H*2(@+SX*("`\+W1D
M/CPO='(^/"]T86)L93X*("`\+W1D"CPO='(^"CQT<CX*("`\=&0^"B`@("`\
M=&%B;&4@8V5L;'-P86-I;F<](C`B('=I9'1H/2(Q,#`E(CX*("`@(#QT<CX\
M=&0@8VQA<W,](FET96TB/B9N8G-P.SPO=&0^/"]T<CX*("`@(#QT<CX\=&0@
M8VQA<W,](G-M86QL:&5A9&5R(CX\/W!H<"!E8VAO(%\H(DUA=&-H:6YG(&9I
M96QD<R(I(#\^/"]T9#X\+W1R/@H@("`@/"]T86)L93X*("`\+W1D/@H\+W1R
M/@H\='(^"B`@/'1D(&-L87-S/2)I=&5M(CX*("`\=&%B;&4^/'1R/CQT9#X*
M("`@(#QI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F1A=&%+97ES(B`O/@H@
M("`@/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB87!P2V5Y<R(@+SX*("`@
M(#QI;G!U="!T>7!E/2)H:61D96XB(&YA;64](FEM<&]R=%]F;W)M870B('9A
M;'5E/2)C<W8B("\^"B`@("`\<V5L96-T(&YA;64](G-E;&5C=$1A=&$B('-I
M>F4](C$P(B!O;F-H86YG93TB9&]C=6UE;G0N;6%P9F]R;2YS96QE8W1!<'!;
M=&AI<RYS96QE8W1E9$EN9&5X72YS96QE8W1E9#UT<G5E(CX*/#]P:'`*9F]R
M96%C:"`H)%]315-324].6R=I;7!O<G1?9&%T82==6R=D871A)UU;,%T@87,@
M)&ME>2`]/B`D=F%L=64I.@H@("`@:68@*&ES<V5T*"1A<'!?9FEE;&1S6R1K
M97E=*2DZ"B`@("`@("`@)&UA=&-H:6YG6UT@/2!A<G)A>2@D:V5Y+"`D87!P
M7V9I96QD<ULD:V5Y72D["C\^"B`@("`@("`@("`\;W!T:6]N('9A;'5E/2(\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SXB/CP_<&AP(&5C
M:&\@*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG:&5A9&5R)UTI(#\@:'1M
M;'-P96-I86QC:&%R<R@D:V5Y*2`Z(&AT;6QS<&5C:6%L8VAA<G,H)'9A;'5E
M*2`_/CPO;W!T:6]N/@H\/W!H<"!E;F1I9CL@/SX*/#]P:'`@96YD9F]R96%C
M:#L@/SX*("`@(#PO<V5L96-T/@H@("`@/'-E;&5C="!N86UE/2)S96QE8W1!
M<'`B('-I>F4](C$P(B!O;F-H86YG93TB9&]C=6UE;G0N;6%P9F]R;2YS96QE
M8W1$871A6W1H:7,N<V5L96-T961);F1E>%TN<V5L96-T960]=')U92(^"CP_
M<&AP(&9O<F5A8V@@*"1M871C:&EN9R!A<R`D<&%I<BDZ(#\^"B`@("`@("`@
M("`\;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H
M)'!A:7);,%TI(#\^(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'!A
M:7);,5TI(#\^/"]O<'1I;VX^"CP_<&AP(&5N9&9O<F5A8V@[(#\^"B`@("`\
M+W-E;&5C=#X\8G(@+SX*("`@(#QI;G!U="!T>7!E/2)B=71T;VXB('9A;'5E
M/2(\/W!H<"!E8VAO(%\H(E)E;6]V92!P86ER(BD@/SXB(&-L87-S/2)B=71T
M;VXB(&]N8VQI8VL](G)E;6]V95!A:7(H*2(@+SX\8G(@+SX\8G(@+SX*("`@
M(#QI;G!U="!T>7!E/2)S=6)M:70B('9A;'5E/2(\/W!H<"!E8VAO(%\H(DYE
M>'0B*2`_/B(@8VQA<W,](F)U='1O;B(@+SX*("`\+W1D/CPO='(^/"]T86)L
M93X*("`\+W1D/@H\+W1R/@H\+W1A8FQE/@H\+V9O<FT^"CQS8W)I<'0@='EP
M93TB=&5X="]J879A<V-R:7!T(CX*/"$M+0IR97-E=$AI9&1E;B@I.PHO+RTM
M/@H\+W-C<FEP=#X*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,`````````````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-#`Q-P`Q,#4Q-30S,S<V,``P,C(Q-S4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*)&D@/2`P.PIW:&EL
M92`H)&D@/"!C;W5N="@D9&%T95LG=F%L=65S)UTI("8F(&5M<'1Y*"1D871E
M6R=V86QU97,G75LD:5TI*2!["B`@("`D:2LK.PI]"FEF("AS=')P;W,H)&1A
M=&5;)W9A;'5E<R==6R1I72P@)R\G*2`A/3T@9F%L<V4I('L*("`@("1D96P@
M/2`G+R<["GT@96QS96EF("AS=')P;W,H)&1A=&5;)W9A;'5E<R==6R1I72P@
M)RXG*2`A/3T@9F%L<V4I('L*("`@("1D96P@/2`G+B<["GT@96QS96EF("AS
M=')P;W,H)&1A=&5;)W9A;'5E<R==6R1I72P@)RTG*2`A/3T@9F%L<V4I('L*
M("`@("1D96P@/2`G+2<["GT@96QS92!["B`@("`D9&5L(#T@)R<["GT*"B\O
M(%1R>2!T;R!G=65S<R!T:&4@9&%T92!F;W)M870@87,@;75C:"!A<R!P;W-S
M:6)L90HD9F]R;2`](&YU;&P["FEF("@A96UP='DH)&1E;"D@)B8@:7-S970H
M)&1A=&5;)W9A;'5E<R==*2`F)B!I<W-E="@D9&%T95LG=F%L=65S)UU;)&E=
M*2D@>PH@("`@)'!A<G1S(#T@97AP;&]D92@D9&5L+"`D9&%T95LG=F%L=65S
M)UU;)&E=*3L*("`@(&EF("AC;W5N="@D<&%R=',I(#X](#,I('L*("`@("`@
M("`D9F]R;2`]("=M9'DG.PH@("`@("`@(&EF("@H<W1R;&5N*"1P87)T<ULP
M72D@/3T@-"D@?'P@*"1P87)T<ULP72`^(#,Q*2D@>PH@("`@("`@("`@("`D
M9F]R;2`]("=Y;60G.PH@("`@("`@("`@("!I9B`H)'!A<G1S6S%=(#X@,3(I
M('L*("`@("`@("`@("`@("`@("1F;W)M(#T@)WED;2<["B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V5I9B`H)'!A<G1S6S!=(#X@,3(I('L*("`@("`@
M("`@("`@)&9O<FT@/2`G9&UY)SL*("`@("`@("!]"B`@("!]"GT*/SX*/'1R
M/@H@(#QT9#X\/W!H<"!E8VAO(%\H(E-E;&5C="!T:&4@9&%T92!D96QI;6ET
M97(Z(BD@/SX\+W1D/@H@(#QT9#X*("`@(#QS96QE8W0@;F%M93TB9&5L:6UI
M=&5R6SP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`_/ETB/@H@
M("`@("`\;W!T:6]N('9A;'5E/2(O(CP_<&AP(&5C:&\@)&1E;"`]/2`G+R<@
M/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX^+SPO;W!T:6]N/@H@
M("`@("`\;W!T:6]N('9A;'5E/2(N(CP_<&AP(&5C:&\@)&1E;"`]/2`G+B<@
M/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX^+CPO;W!T:6]N/@H@
M("`@("`\;W!T:6]N('9A;'5E/2(M(CP_<&AP(&5C:&\@)&1E;"`]/2`G+2<@
M/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX^+3PO;W!T:6]N/@H@
M("`@/"]S96QE8W0^"B`@/"]T9#X*/"]T<CX*/'1R/@H@(#QT9#X\/W!H<"!E
M8VAO(%\H(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(BD@/SX\+W1D/@H@(#QT
M9#X*("`@(#QS96QE8W0@;F%M93TB9F]R;6%T6SP_<&AP(&5C:&\@:'1M;'-P
M96-I86QC:&%R<R@D:V5Y*2`_/ETB/@H@("`@("`\;W!T:6]N('9A;'5E/2)M
M9&%Y+VUO;G1H+WEE87(B/#]P:'`@96-H;R`D9F]R;2`]/2`G9&UY)R`_("<@
M<V5L96-T960](G-E;&5C=&5D(B<@.B`G)R`_/CX\/W!H<"!E8VAO(%\H(D1$
M(BD@+B`D9&5L("X@7R@B34TB*2`N("1D96P@+B!?*")962(I(#\^/"]O<'1I
M;VX^"B`@("`@(#QO<'1I;VX@=F%L=64](FUO;G1H+VUD87DO>65A<B(\/W!H
M<"!E8VAO("1F;W)M(#T]("=M9'DG(#\@)R!S96QE8W1E9#TB<V5L96-T960B
M)R`Z("<G(#\^/CP_<&AP(&5C:&\@7R@B34TB*2`N("1D96P@+B!?*")$1"(I
M("X@)&1E;"`N(%\H(EE9(BD@/SX\+V]P=&EO;CX*("`@("`@/&]P=&EO;B!V
M86QU93TB>65A<B]M;VYT:"]M9&%Y(CP_<&AP(&5C:&\@)&9O<FT@/3T@)WEM
M9"<@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX^/#]P:'`@96-H
M;R!?*")962(I("X@)&1E;"`N(%\H(DU-(BD@+B`D9&5L("X@7R@B1$0B*2`_
M/CPO;W!T:6]N/@H@("`@("`\;W!T:6]N('9A;'5E/2)Y96%R+VUD87DO;6]N
M=&@B/#]P:'`@96-H;R`D9F]R;2`]/2`G>61M)R`_("<@<V5L96-T960](G-E
M;&5C=&5D(B<@.B`G)R`_/CX\/W!H<"!E8VAO(%\H(EE9(BD@+B`D9&5L("X@
M7R@B1$0B*2`N("1D96P@+B!?*")-32(I(#\^/"]O<'1I;VX^"B`@("`\+W-E
M;&5C=#X*("`\+W1D/@H\+W1R/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,`````````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C<P,@`Q,#4Q-30S,S<V,``P,C(V-S(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/&9O<FT@
M;65T:&]D/2)P;W-T(B!N86UE/2)D871E9F]R;2(@86-T:6]N/2(\/W!H<"!E
M8VAO($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G9&%T82YP:'`G*2`_/B(^"CQI
M;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB/#]P
M:'`@96-H;R`H:6YT*21N97AT7W-T97`@/SXB("\^"CQI;G!U="!T>7!E/2)H
M:61D96XB(&YA;64](FEM<&]R=%]F;W)M870B('9A;'5E/2(\/W!H<"!E8VAO
M(&AT;6QS<&5C:6%L8VAA<G,H571I;#HZ9V5T1F]R;41A=&$H)VEM<&]R=%]F
M;W)M870G*2D@/SXB("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](FEM
M<&]R=%]S=&5P(B!V86QU93TB/#]P:'`@96-H;R`H:6YT*21I;7!O<G1?<W1E
M<"`_/B(@+SX*/#]P:'`@571I;#HZ<&9O<FU);G!U="@I(#\^"CQH,2!C;&%S
M<STB:&5A9&5R(CX*(#P_<&AP('!R:6YT9BA?*"));7!O<G0L(%-T97`@)60B
M*2P@*&EN="DD:6UP;W)T7W-T97`I(#\^"CPO:#$^"CQT86)L92!C96QL<W!A
M8VEN9STB,"(@=VED=&@](C$P,"4B/@H\/W!H<"!F;W)E86-H("@D7U-%4U-)
M3TY;)VEM<&]R=%]D871A)UU;)V1A=&5S)UT@87,@)&ME>2`]/B`D9&%T92DZ
M(#\^"CP_<&AP(&EF("AC;W5N="@D9&%T95LG=F%L=65S)UTI*3H@/SX*/'1R
M/@H@("`@/'1D/@H@("`@("`@(#QT86)L92!C96QL<W!A8VEN9STB,"(@=VED
M=&@](C$P,"4B/@H@("`@("`@(#QT<CX\=&0@8VQA<W,](FET96TB/B9N8G-P
M.SPO=&0^/"]T<CX*("`@("`@("`\='(^/'1D(&-L87-S/2)S;6%L;&AE861E
M<B(^/#]P:'`@<')I;G1F*%\H(DEM<&]R=&5D(&9I96QD.B`E<R(I+"!H=&UL
M<W!E8VEA;&-H87)S*"1A<'!?9FEE;&1S6R1?4T534TE/3ELG:6UP;W)T7V1A
M=&$G75LG;6%P)UU;)&ME>5U=*2D@/SX\+W1D/CPO='(^"B`@("`@("`@/"]T
M86)L93X*("`@(#PO=&0^"CPO='(^"CQT<CX*("`@(#QT9"!C;&%S<STB:71E
M;2(^"B`@("`\=&%B;&4^"B`@("`\='(^"B`@("`@("`@/'1D/CP_<&AP(&5C
M:&\@7R@B17AA;7!L92!V86QU97,Z(BD@/SX\+W1D/@H@("`@("`@(#QT9#X*
M("`@("`@("`@("`@/'-E;&5C=#X*/#]P:'`@9F]R96%C:"`H)&1A=&5;)W9A
M;'5E<R==(&%S("1V86PI.B`_/@H@("`@("`@("`@("`@("`@/&]P=&EO;CX\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'9A;"D@/SX\+V]P=&EO;CX*
M/#]P:'`@96YD9F]R96%C:#L@/SX*("`@("`@("`@("`@/"]S96QE8W0^"B`@
M("`@("`@/"]T9#X*("`@(#PO='(^"CP_<&AP(&EN8VQU9&4@9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+R<@+B!B87-E;F%M92@D9&%T95LG='EP92==*2`N("<N
M:6YC)R`_/@H@("`@/"]T86)L93X*("`@(#PO=&0^"CPO='(^"CP_<&AP(&5N
M9&EF.R`_/@H\/W!H<"!E;F1F;W)E86-H.R`_/@H\+W1A8FQE/@H*/&EN<'5T
M('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C
M:&\@7R@B3F5X="(I(#\^(B`O/@H\+V9O<FT^"@``````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O9&%T82]D871E
M=&EM92YI;F,`````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$R,3,V
M`#$P-3$U-#,S-S8P`#`R,S`U-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HD:2`](#`["G=H:6QE("@D:2`\(&-O
M=6YT*"1D871E6R=V86QU97,G72D@)B8@96UP='DH)&1A=&5;)W9A;'5E<R==
M6R1I72DI('L*("`@("1I*RL["GT*)&1A>5]D96P@/2`D=&EM95]D96P@/2`G
M)SL*:68@*'-T<G!O<R@D9&%T95LG=F%L=65S)UU;)&E=+"`G("<I("$]/2!F
M86QS92D@>PH@("`@9F]R("@D;W)D97(@/2`P.R`H96UP='DH)'1I;65?9&5L
M*2!\?"!E;7!T>2@D9&%Y7V1E;"DI("8F("1O<F1E<B`\/2`Q.R`D;W)D97(K
M*RD@>PH@("`@("`@(&EF("@D;W)D97(I('L*("`@("`@("`@("`@;&ES="@D
M=&EM92P@)&1A>2D@/2!E>'!L;V1E*"<@)RP@)&1A=&5;)W9A;'5E<R==6R1I
M72P@,BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@;&ES="@D9&%Y
M+"`D=&EM92D@/2!E>'!L;V1E*"<@)RP@)&1A=&5;)W9A;'5E<R==6R1I72P@
M,BD["B`@("`@("`@?0H@("`@("`@(&EF("AS=')P;W,H)&1A>2P@)R\G*2`A
M/3T@9F%L<V4I('L*("`@("`@("`@("`@)&1A>5]D96P@/2`G+R<["B`@("`@
M("`@?2!E;'-E:68@*'-T<G!O<R@D9&%Y+"`G+B<I("$]/2!F86QS92D@>PH@
M("`@("`@("`@("`D9&%Y7V1E;"`]("<N)SL*("`@("`@("!](&5L<V5I9B`H
M<W1R<&]S*"1D87DL("<M)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("1D
M87E?9&5L(#T@)RTG.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1D
M87E?9&5L(#T@)R<["B`@("`@("`@?0H@("`@("`@(&EF("AS=')P;W,H)'1I
M;64L("<Z)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("1T:6UE7V1E;"`]
M("<Z)SL*("`@("`@("!](&5L<V5I9B`H<W1R<&]S*"1T:6UE+"`G+B<I("$]
M/2!F86QS92D@>PH@("`@("`@("`@("`D=&EM95]D96P@/2`G+B<["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'1I;65?9&5L(#T@)R<["B`@("`@
M("`@?0H@("`@?0H@("`@)&]R9&5R+2T["GT*"B\O(%1R>2!T;R!G=65S<R!T
M:&4@9&%T92!F;W)M870@87,@;75C:"!A<R!P;W-S:6)L90HD9F]R;2`](&YU
M;&P["FEF("@A96UP='DH)&1A>5]D96PI("8F(&ES<V5T*"1D871E6R=V86QU
M97,G72D@)B8@:7-S970H)&1A=&5;)W9A;'5E<R==6R1I72DI('L*("`@("1P
M87)T<R`](&5X<&QO9&4H)&1A>5]D96PL("1D871E6R=V86QU97,G75LD:5TI
M.PH@("`@:68@*&-O=6YT*"1P87)T<RD@/CT@,RD@>PH@("`@("`@("1F;W)M
M(#T@)VUD>2<["B`@("`@("`@:68@*"AS=')L96XH)'!A<G1S6S!=*2`]/2`T
M*2!\?"`H)'!A<G1S6S!=(#X@,S$I*2!["B`@("`@("`@("`@("1F;W)M(#T@
M)WEM9"<["B`@("`@("`@("`@(&EF("@D<&%R='-;,5T@/B`Q,BD@>PH@("`@
M("`@("`@("`@("`@)&9O<FT@/2`G>61M)SL*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS96EF("@D<&%R='-;,%T@/B`Q,BD@>PH@("`@("`@("`@("`D
M9F]R;2`]("=D;7DG.PH@("`@("`@('T*("`@('T*?0HD86UP;2`]("AS=')P
M;W,H4W1R:6YG.CIL;W=E<B@D9&%T95LG=F%L=65S)UU;,%TI+"`G86TG*2`A
M/3T@9F%L<V4@?'P@<W1R<&]S*%-T<FEN9SHZ;&]W97(H)&1A=&5;)W9A;'5E
M<R==6S!=*2P@)W!M)RD@(3T](&9A;'-E*3L*"FEF("AS=')P;W,H)&1A=&5;
M)W9A;'5E<R==6R1I72P@)R`G*2`]/3T@9F%L<V4I.@H_/@H\='(^"B`@/'1D
M/CP_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=O<F1E<E\G("X@:'1M;'-P96-I
M86QC:&%R<R@D:V5Y*2P@7R@B4V5L96-T('1H92!D871E(&%N9"!T:6UE(&9O
M<FUA=#HB*2D@/SX\+W1D/@H@(#QT9#X*("`@(#QS96QE8W0@:60](F]R9&5R
M7SP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`_/B(@;F%M93TB
M;W)D97);/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1K97DI(#\^72(^
M"B`@("`@(#QO<'1I;VX@=F%L=64](BTQ(B!S96QE8W1E9#TB<V5L96-T960B
M/CP_<&AP(&5C:&\@7R@B5&EM97-T86UP(&]R('5N:VYO=VXB*2`_/CPO;W!T
M:6]N/@H@("`@/"]S96QE8W0^"B`@/"]T9#X*/"]T<CX*/#]P:'`@96QS93H@
M/SX*/'1R/@H@(#QT9#X\/W!H<"!E8VAO($AO<F1E.CIL86)E;"@G;W)D97)?
M)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2DL(%\H(E-E;&5C="!T:&4@9&%Y
M(&%N9"!T:6UE(&]R9&5R.B(I*2`_/CPO=&0^"B`@/'1D/@H@("`@/'-E;&5C
M="!I9#TB;W)D97)?/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1K97DI
M(#\^(B!N86UE/2)O<F1E<EL\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H
M)&ME>2D@/SY=(CX*("`@("`@/&]P=&EO;B!V86QU93TB+3$B/#]P:'`@96-H
M;R`H)&]R9&5R("8F("AE;7!T>2@D9&%Y7V1E;"D@?'P@96UP='DH)'1I;65?
M9&5L*2DI(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G(#\^/CP_<&AP
M(&5C:&\@7R@B5&EM97-T86UP(&]R('5N:VYO=VXB*2`_/CPO;W!T:6]N/@H@
M("`@("`\;W!T:6]N('9A;'5E/2(P(CP_<&AP(&5C:&\@*"$D;W)D97(I(#\@
M)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G(#\^/CP_<&AP('!R:6YT9BA?
M*")$871E.B`E<SL@=&EM93H@)7,B*2P@)&1A>2P@)'1I;64I(#\^/"]O<'1I
M;VX^"B`@("`@(#QO<'1I;VX@=F%L=64](C$B/#]P:'`@96-H;R`D;W)D97(@
M/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX^/#]P:'`@<')I;G1F
M*%\H(D1A=&4Z("5S.R!T:6UE.B`E<R(I+"`D9&%Y+"`D=&EM92D@/SX\+V]P
M=&EO;CX*("`@(#PO<V5L96-T/@H@(#PO=&0^"CPO='(^"CQT<CX*("`\=&0^
M/#]P:'`@96-H;R!(;W)D93HZ;&%B96PH)V1A>5]D96QI;6ET97)?)R`N(&AT
M;6QS<&5C:6%L8VAA<G,H)&ME>2DL(%\H(E-E;&5C="!T:&4@9&%T92!D96QI
M;6ET97(Z(BDI(#\^/"]T9#X*("`\=&0^"B`@("`\<V5L96-T(&ED/2)D87E?
M9&5L:6UI=&5R7SP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`_
M/B(@;F%M93TB9&%Y7V1E;&EM:71E<EL\/W!H<"!E8VAO(&AT;6QS<&5C:6%L
M8VAA<G,H)&ME>2D@/SY=(CX*("`@("`@/&]P=&EO;B!V86QU93TB+R(\/W!H
M<"!E8VAO("1D87E?9&5L(#T]("<O)R`_("<@<V5L96-T960](G-E;&5C=&5D
M(B<@.B`G)R`_/CXO/"]O<'1I;VX^"B`@("`@(#QO<'1I;VX@=F%L=64](BXB
M/#]P:'`@96-H;R`D9&%Y7V1E;"`]/2`G+B<@/R`G('-E;&5C=&5D/2)S96QE
M8W1E9"(G(#H@)R<@/SX^+CPO;W!T:6]N/@H@("`@("`\;W!T:6]N('9A;'5E
M/2(M(CP_<&AP(&5C:&\@)&1A>5]D96P@/3T@)RTG(#\@)R!S96QE8W1E9#TB
M<V5L96-T960B)R`Z("<G(#\^/BT\+V]P=&EO;CX*("`@(#PO<V5L96-T/@H@
M(#PO=&0^"CPO='(^"CQT<CX*("`\=&0^/#]P:'`@96-H;R!(;W)D93HZ;&%B
M96PH)V1A>5]F;W)M871?)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2DL(%\H
M(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(BDI(#\^/"]T9#X*("`\=&0^"B`@
M("`\<V5L96-T(&ED/2)D87E?9F]R;6%T7SP_<&AP(&5C:&\@:'1M;'-P96-I
M86QC:&%R<R@D:V5Y*2`_/B(@;F%M93TB9&%Y7V9O<FUA=%L\/W!H<"!E8VAO
M(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SY=(CX*("`@("`@/&]P=&EO;B!V
M86QU93TB;61A>2]M;VYT:"]Y96%R(CP_<&AP(&5C:&\@)&9O<FT@/3T@)V1M
M>2<@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX^/#]P:'`@96-H
M;R!?*")$1"(I("X@)&1A>5]D96P@+B!?*")-32(I("X@)&1A>5]D96P@+B!?
M*")962(I(#\^/"]O<'1I;VX^"B`@("`@(#QO<'1I;VX@=F%L=64](FUO;G1H
M+VUD87DO>65A<B(\/W!H<"!E8VAO("1F;W)M(#T]("=M9'DG(#\@)R!S96QE
M8W1E9#TB<V5L96-T960B)R`Z("<G(#\^/CP_<&AP(&5C:&\@7R@B34TB*2`N
M("1D87E?9&5L("X@7R@B1$0B*2`N("1D87E?9&5L("X@7R@B65DB*2`_/CPO
M;W!T:6]N/@H@("`@("`\;W!T:6]N('9A;'5E/2)Y96%R+VUO;G1H+VUD87DB
M/#]P:'`@96-H;R`D9F]R;2`]/2`G>6UD)R`_("<@<V5L96-T960](G-E;&5C
M=&5D(B<@.B`G)R`_/CX\/W!H<"!E8VAO(%\H(EE9(BD@+B`D9&%Y7V1E;"`N
M(%\H(DU-(BD@+B`D9&%Y7V1E;"`N(%\H(D1$(BD@/SX\+V]P=&EO;CX*("`@
M("`@/&]P=&EO;B!V86QU93TB>65A<B]M9&%Y+VUO;G1H(CP_<&AP(&5C:&\@
M)&9O<FT@/3T@)WED;2<@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@
M/SX^/#]P:'`@96-H;R!?*")962(I("X@)&1A>5]D96P@+B!?*")$1"(I("X@
M)&1A>5]D96P@+B!?*")-32(I(#\^/"]O<'1I;VX^"B`@("`\+W-E;&5C=#X*
M("`\+W1D/@H\+W1R/@H\='(^"B`@/'1D/CP_<&AP(&5C:&\@2&]R9&4Z.FQA
M8F5L*"=T:6UE7V1E;&EM:71E<E\G("X@:'1M;'-P96-I86QC:&%R<R@D:V5Y
M*2P@7R@B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB*2D@/SX\+W1D/@H@
M(#QT9#X*("`@(#QS96QE8W0@:60](G1I;65?9&5L:6UI=&5R7SP_<&AP(&5C
M:&\@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`_/B(@;F%M93TB=&EM95]D96QI
M;6ET97);/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1K97DI(#\^72(^
M"B`@("`@(#QO<'1I;VX@=F%L=64](CHB/#]P:'`@96-H;R`D=&EM95]D96P@
M/3T@)SHG(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G(#\^/CH\+V]P
M=&EO;CX*("`@("`@/&]P=&EO;B!V86QU93TB+B(\/W!H<"!E8VAO("1T:6UE
M7V1E;"`]/2`G+B<@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX^
M+CPO;W!T:6]N/@H@("`@/"]S96QE8W0^"B`@/"]T9#X*/"]T<CX*/'1R/@H@
M(#QT9#X\/W!H<"!E8VAO($AO<F1E.CIL86)E;"@G=&EM95]F;W)M871?)R`N
M(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2DL(%\H(E-E;&5C="!T:&4@=&EM92!F
M;W)M870Z(BDI(#\^/"]T9#X*("`\=&0^"B`@("`\<V5L96-T(&ED/2)T:6UE
M7V9O<FUA=%\\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SXB
M(&YA;64](G1I;65?9F]R;6%T6SP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R
M<R@D:V5Y*2`_/ETB/@H@("`@("`\;W!T:6]N('9A;'5E/2(R-&AR(CP_<&AP
M(&5C:&\@)&%M<&T@/R`G)R`Z("<@<V5L96-T960](G-E;&5C=&5D(B<@/SX^
M/#]P:'`@96-H;R!?*"(R-"!H;W5R<R(I(#\^/"]O<'1I;VX^"B`@("`@(#QO
M<'1I;VX@=F%L=64](F%M<&TB/#]P:'`@96-H;R`D86UP;2`_("<@<V5L96-T
M960](G-E;&5C=&5D(B<@.B`G)R`_/CX\/W!H<"!E8VAO(%\H(D%-+U!-(BD@
M/SX\+V]P=&EO;CX*("`@(#PO<V5L96-T/@H@(#PO=&0^"CPO='(^"CP_<&AP
M(&5N9&EF.R`_/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T96UP;&%T97,O9&%T82]T:6UE+FEN8P``````````````````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,3,W`#$P-3$U-#,S-S8P`#`R,C(Q-P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HD:2`](#`["G=H:6QE("@D:2`\/2!C;W5N="@D9&%T95LG=F%L=65S)UTI
M("8F(&5M<'1Y*"1D871E6R=V86QU97,G75LD:5TI*2!["B`@("`D:2LK.PI]
M"FEF("AS=')P;W,H)&1A=&5;)W9A;'5E<R==6R1I72P@)SHG*2`A/3T@9F%L
M<V4I('L*("`@("1D96P@/2`G.B<["GT@96QS96EF("AS=')P;W,H)&1A=&5;
M)W9A;'5E<R==6R1I72P@)RXG*2`A/3T@9F%L<V4I('L*("`@("1D96P@/2`G
M+B<["GT@96QS92!["B`@("`D9&5L(#T@)R<["GT*)&%M<&T@/2`H<W1R<&]S
M*%-T<FEN9SHZ;&]W97(H)&1A=&5;)W9A;'5E<R==6S!=*2P@)V%M)RD@(3T]
M(&9A;'-E('Q\('-T<G!O<RA3=')I;F<Z.FQO=V5R*"1D871E6R=V86QU97,G
M75LP72DL("=P;2<I("$]/2!F86QS92D["C\^"CQT<CX*("`\=&0^/#]P:'`@
M96-H;R!?*")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(I(#\^/"]T9#X*
M("`\=&0^"B`@("`\<V5L96-T(&YA;64](F1E;&EM:71E<EL\/W!H<"!E8VAO
M(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SY=(CX*("`@("`@/&]P=&EO;B!V
M86QU93TB.B(\/W!H<"!E8VAO("1D96P@/3T@)SHG(#\@)R!S96QE8W1E9#TB
M<V5L96-T960B)R`Z("<G(#\^/CH\+V]P=&EO;CX*("`@("`@/&]P=&EO;B!V
M86QU93TB+B(\/W!H<"!E8VAO("1D96P@/3T@)RXG(#\@)R!S96QE8W1E9#TB
M<V5L96-T960B)R`Z("<G(#\^/BX\+V]P=&EO;CX*("`@(#PO<V5L96-T/@H@
M(#PO=&0^"CPO='(^"CQT<CX*("`\=&0^/#]P:'`@96-H;R!?*")396QE8W0@
M=&AE('1I;64@9F]R;6%T.B(I(#\^/"]T9#X*("`\=&0^"B`@("`\<V5L96-T
M(&YA;64](F9O<FUA=%L\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME
M>2D@/SY=(CX*("`@("`@/&]P=&EO;B!V86QU93TB,C1H<B(\/W!H<"!E8VAO
M("1A;7!M(#\@)R<@.B`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#\^/CP_<&AP
M(&5C:&\@7R@B,C0@:&]U<G,B*2`_/CPO;W!T:6]N/@H@("`@("`\;W!T:6]N
M('9A;'5E/2)A;7!M(CP_<&AP(&5C:&\@)&%M<&T@/R`G('-E;&5C=&5D/2)S
M96QE8W1E9"(G(#H@)R<@/SX^/#]P:'`@96-H;R!?*")!32]032(I(#\^/"]O
M<'1I;VX^"B`@("`\+W-E;&5C=#X*("`\+W1D/@H\+W1R/@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC````````````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$V
M,#$`,3`U,34T,S,W-C``,#(R-S0T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#QF;W)M(&UE=&AO9#TB<&]S="(@;F%M93TB
M:6UP;W)T7V9O<FTB(&%C=&EO;CTB9&%T82YP:'`B/@H\/W!H<"!5=&EL.CIP
M9F]R;4EN<'5T*"D@/SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB86-T
M:6]N240B('9A;'5E/2(\/W!H<"!E8VAO("AI;G0I)&YE>'1?<W1E<"`_/B(@
M+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB:6UP;W)T7V9O<FUA="(@
M=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<RA5=&EL.CIG971&
M;W)M1&%T82@G:6UP;W)T7V9O<FUA="<I*2`_/B(@+SX*/&EN<'5T('1Y<&4]
M(FAI9&1E;B(@;F%M93TB:6UP;W)T7W-T97`B('9A;'5E/2(\/W!H<"!E8VAO
M("AI;G0I)&EM<&]R=%]S=&5P(#\^(B`O/@H\:#$@8VQA<W,](FAE861E<B(^
M"B`\/W!H<"!P<FEN=&8H7R@B26UP;W)T+"!3=&5P("5D(BDL("AI;G0I)&EM
M<&]R=%]S=&5P*2`_/@H\+V@Q/@H\9&EV(&-L87-S/2)H96%D97)B;W@B/@H@
M/#]P:'`@96-H;R!?*")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I
M;&4Z(BD@/SX\8G(@+SX*(#QP<F4^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H
M87)S*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9FER<W1?;&EN97,G72D@
M/SX\+W!R93X\8G(@+SX*(#QL86)E;"!F;W(](FAE861E<B(^/#]P:'`@96-H
M;R!?*")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M
M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(BD@/SX\+VQA8F5L/@H@/&EN
M<'5T(&ED/2)H96%D97(B('1Y<&4](F-H96-K8F]X(B!N86UE/2)H96%D97(B
M('9A;'5E/2(Q(B`O/CQB<B`O/@H\+V1I=CX*/&EN<'5T('1Y<&4](G-U8FUI
M="(@=F%L=64](CP_<&AP(&5C:&\@7R@B3F5X="(I(#\^(B!C;&%S<STB8G5T
M=&]N(B`O/@H\+V9O<FT^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]H
M96QP+P``````````````````````````````````````````````````````
M````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`U,34T,S,W-3<`,#(P-C$P`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC````````````````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#(Q-@`Q,#4Q-30S,S<U-P`P,C(T,30`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/&@R
M(&%L:6=N/2)C96YT97(B/CP_<&AP('!R:6YT9BA?*")4:&ES(&ES("5S+B(I
M+"`D=F5R<VEO;BD@/SX\+V@R/@H\<')E('-T>6QE/2)D:7)E8W1I;VXZ;'1R
M(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&-R961I=',I(#\^/"]P
M<F4^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L
M871E<R]H96QP+VEN9&5X+FEN8P``````````````````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`W,#0`,3`U,34T,S,W-3<`,#(R-#$S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#PA1$]#5%E012!H=&UL
M(%!50DQ)0R`B+2\O5S-#+R]$5$0@6$A434P@,2XP($9R86UE<V5T+R]%3B(@
M(D141"]X:'1M;#$M9G)A;65S970N9'1D(CX*/&AT;6P^"CQH96%D/@H@/'1I
M=&QE/CP_<&AP(&5C:&\@7R@B2&5L<"(I(#\^/"]T:71L93X*/"]H96%D/@H*
M/&9R86UE<V5T(')O=W,](C,P+"HB(&9R86UE8F]R9&5R/2)N;R(@8F]R9&5R
M/2(P(B!F<F%M97-P86-I;F<](C`B/@H@/&9R86UE(&YA;64](FAE;'!?;65N
M=2(@<V-R;VQL:6YG/2)N;R(@;6%R9VEN:&5I9VAT/2(P(B!M87)G:6YW:61T
M:#TB,"(@<W)C/2(\/W!H<"!E8VAO("1M96YU7W5R;"`_/B(@+SX*(#QF<F%M
M92!N86UE/2)H96QP7VUA:6XB(')E<VEZ96%B;&4](GEE<R(@;6%R9VEN:&5I
M9VAT/2(R(B!M87)G:6YW:61T:#TB,B(@<W)C/2(\/W!H<"!E8VAO("1M86EN
M7W5R;"`_/B(@+SX*/"]F<F%M97-E=#X*"CPO:'1M;#X*````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O:&5L<"]M
M96YU+FEN8P``````````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M-#$P`#$P-3$U-#,S-S4W`#`R,C(T,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\9&EV(&-L87-S/2)H96%D97(B/@H@/'-P
M86X@8VQA<W,](FQE9G1&;&]A="(^"B`@/#]P:'`@96-H;R`D=&]P:6-S7VQI
M;FL@/SX*(#PO<W!A;CX*/#]P:'`@:68@*"1C;VYF6R=M96YU)UU;)VQI;FMS
M)UU;)VAE;'!?86)O=70G72DZ(#\^"B`\<W!A;B!C;&%S<STB<FEG:'1&;&]A
M="(^"B`@/#]P:'`@96-H;R`D86)O=71?;&EN:R`_/@H@/"]S<&%N/@H\/W!H
M<"!E;F1I9CL@/SX*(#QS<&%N('-T>6QE/2)C;&5A<CIB;W1H(CXF;F)S<#L\
M+W-P86X^"CPO9&EV/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+VEN9&5X+P``````````````
M````````````````````````````````````````````````````````````
M```P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,S<V,``P,C`W-C$`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O
M:6YD97@O9G)A;65S7VEN9&5X+FEN8P``````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R,C4S`#$P-3$U-#,S-S8P`#`R-#$R,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<"`D<G1L(#T@:7-S970H
M)&YL<ULG<G1L)UU;)&QA;F=U86=E72D@/SX*/"%$3T-465!%(&AT;6P@4%5"
M3$E#("(M+R]7,T,O+T141"!82%1-3"`Q+C`@1G)A;65S970O+T5.(B`B1%1$
M+WAH=&UL,2UF<F%M97-E="YD=&0B/@H\:'1M;#X*/&AE860^"B`\;&EN:R!R
M96P](E-(3U)40U54($E#3TXB(&AR968](CP_<&AP(&5C:&\@)')E9VES=')Y
M+3YG971);6%G941I<B@I(#\^+V9A=FEC;VXN:6-O(B`O/@H@/'1I=&QE/CP_
M<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D<F5G:7-T<GDM/F=E="@G;F%M
M92<I*2`_/CPO=&ET;&4^"CPO:&5A9#X*"CQF<F%M97-E="!I9#TB:&8B(&-O
M;',](CP_<&AP(&5C:&\@*"1R=&P@/R`G*BPG(#H@)R<I("X@*&ES<V5T*"1P
M<F5F<RD@/R`D<')E9G,M/F=E=%9A;'5E*"=S:61E8F%R7W=I9'1H)RD@.B`Q
M-3`I("X@*"1R=&P@/R`G)R`Z("<L*B<I(#\^(B!F<F%M97-P86-I;F<](C`B
M(&9R86UE8F]R9&5R/2(P(CX*/#]P:'`@:68@*"1R=&PI.B`_/@H@(#QF<F%M
M92!N86UE/2)H;W)D95]M86EN(B!S<F,](CP_<&AP(&5C:&\@571I;#HZ861D
M4&%R86UE=&5R*&AT;6QS<&5C:6%L8VAA<G,H)&UA:6Y?<&%G92DL("=F<F%M
M97-E=%]L;V%D960G+"`Q*2`_/B(@<V-R;VQL:6YG/2(\/W!H<"!E8VAO("1S
M8W)O;&QB87(@/SXB(&YO<F5S:7IE/2)N;W)E<VEZ92(@+SX*("`\9G)A;64@
M;F%M93TB:&]R9&5?;65N=2(@<W)C/2(\/W!H<"!E8VAO($AO<F1E.CIA<'!L
M:6-A=&EO;E5R;"@G<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP)RD@/SXB
M('-C<F]L;&EN9STB875T;R(@;F]R97-I>F4](FYO<F5S:7IE(B`O/@H\/W!H
M<"!E;'-E.B`_/@H@(#QF<F%M92!N86UE/2)H;W)D95]M96YU(B!S<F,](CP_
M<&AP(&5C:&\@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=S97)V:6-E<R]P;W)T
M86PO<VED96)A<BYP:'`G*2`_/B(@<V-R;VQL:6YG/2)A=71O(B!N;W)E<VEZ
M93TB;F]R97-I>F4B("\^"B`@/&9R86UE(&YA;64](FAO<F1E7VUA:6XB('-R
M8STB/#]P:'`@96-H;R!5=&EL.CIA9&1087)A;65T97(H:'1M;'-P96-I86QC
M:&%R<R@D;6%I;E]P86=E*2P@)V9R86UE<V5T7VQO861E9"<L(#$I(#\^(B!S
M8W)O;&QI;F<](CP_<&AP(&5C:&\@)'-C<F]L;&)A<B`_/B(@;F]R97-I>F4]
M(FYO<F5S:7IE(B`O/@H\/W!H<"!E;F1I9CL@/SX*/"]F<F%M97-E=#X*"CPO
M:'1M;#X*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T+P``````````````
M````````````````````````````````````````````````````````,#`P
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-C``
M,#(R,#(P`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96$N:G,`````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#$U,P`Q,#4Q-30S,S<V,``P,C0Q-3(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=F%R(%]E9&ET;W)?=7)L(#T@(CP_<&AP
M(&5C:&\@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O="<L("=H
M;W)D92<I(#\^+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82\B.PH`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<P``````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,W-S0`,3`U,34T
M,S,W-C``,#(W,S4T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"\O($DQ.$X@8V]N<W1A;G1S"@HO+R!,04Y'.B`B96XB+"!%
M3D-/1$E.1SH@551&+3@@?"!)4T\M.#@U.2TQ"B\O($%U=&AO<CH@36EH86D@
M0F%Z;VXL(&AT='`Z+R]D>6YA<F-H+F-O;2]M:7-H;V\*"B\O($9/4B!44D%.
M4TQ!5$]24SH*+R\*+R\@("`Q+B!03$5!4T4@4%54(%E/55(@0T].5$%#5"!)
M3D9/($E.(%1(12!!0D]612!,24Y%"B\O("`@("`@*&%T(&QE87-T(&$@=F%L
M:60@96UA:6P@861D<F5S<RD*+R\*+R\@("`R+B!03$5!4T4@5%)9(%1/(%53
M12!55$8M."!&3U(@14Y#3T1)3D<["B\O("`@("`@*&EF('1H:7,@:7,@;F]T
M('!O<W-I8FQE+"!P;&5A<V4@:6YC;'5D92!A(&-O;6UE;G0*+R\@("`@("`@
M=&AA="!S=&%T97,@=VAA="!E;F-O9&EN9R!I<R!N96-E<W-A<GDN*0H*06YS
M96Q);6%G92Y),3A.(#T@>PH)+R\@271E;7,@=&AA="!A<'!E87(@:6X@;65N
M=2X@(%!L96%S92!N;W1E('1H870@86X@=6YD97)S8V]R92`H7RD*"2\O(&-H
M87)A8W1E<B!I;B!T:&4@=')A;G-L871I;VX@*')I9VAT(&-O;'5M;BD@=VEL
M;"!C875S92!T:&4@9F]L;&]W:6YG"@DO+R!L971T97(@=&\@8F5C;VUE('5N
M9&5R;&EN960@86YD(&)E('-H;W)T8W5T(&9O<B!T:&%T(&UE;G4@;W!T:6]N
M+@H*"2));G-E<G0@26UA9V4B("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26YS97)T
M($EM86=E(BDI(#\^(BP*"2));6%G92!54DPZ(B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B26UA9V4@55),.B(I*2`_/B(L"@DB16YT97(@=&AE(&EM86=E(%52
M3"!H97)E(B`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(I*2`_
M/B(L"@DB4')E=FEE=R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E!R979I
M97<B*2D@/SXB+`H)(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O
M=R(@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B*2D@/SXB+`H)
M(D%L=&5R;F%T92!T97AT.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")!;'1E<FYA=&4@
M=&5X=#HB*2D@/SXB+`H)(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O
M<G0@:6UA9V5S(B`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(I
M*2`_/B(L"@DB4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(@("`@("`@("`@
M("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E!O
M<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B*2D@/SXB+`H)(DEM86=E(%!R979I
M97<Z(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_
M<&AP(&5C:&\@861D<VQA<VAE<RA?*"));6%G92!0<F5V:65W.B(I*2`_/B(L
M"@DB1V%L;&5R>3HB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D=A;&QE<GDZ
M(BDI(#\^(BP*"2)'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(@("`@("`@
M("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB*2D@/SXB+`H)(DEM86=E(&9R
M;VT@9V%L;&5R>3HB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"));6%G92!F<F]M(&=A;&QE<GDZ
M(BDI(#\^(BP*"2));6%G92!F<F]M(&=A;&QE<GDB("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M26UA9V4@9G)O;2!G86QL97)Y(BDI(#\^(@I].PH`````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,``````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$T,C$U`#$P-3$U-#,S-S8P
M`#`R-C<R,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````O+R!),3A.(&-O;G-T86YT<PH*+R\@3$%.1SH@(F5N(BP@14Y#3T1)
M3D<Z(%541BTX('P@25-/+3@X-3DM,0HO+R!!=71H;W(Z($UI:&%I($)A>F]N
M+"!H='1P.B\O9'EN87)C:"YC;VTO;6ES:&]O"@HO+R!&3U(@5%)!3E-,051/
M4E,Z"B\O"B\O("`@,2X@4$Q%05-%(%!55"!93U52($-/3E1!0U0@24Y&3R!)
M3B!42$4@04)/5D4@3$E.10HO+R`@("`@("AA="!L96%S="!A('9A;&ED(&5M
M86EL(&%D9')E<W,I"B\O"B\O("`@,BX@4$Q%05-%(%1262!43R!54T4@551&
M+3@@1D]2($5.0T]$24Y'.PHO+R`@("`@("AI9B!T:&ES(&ES(&YO="!P;W-S
M:6)L92P@<&QE87-E(&EN8VQU9&4@82!C;VUM96YT"B\O("`@("`@('1H870@
M<W1A=&5S('=H870@96YC;V1I;F<@:7,@;F5C97-S87)Y+BD*"D-O;G1E>'1-
M96YU+DDQ.$X@/2!["@DO+R!)=&5M<R!T:&%T(&%P<&5A<B!I;B!M96YU+B`@
M4&QE87-E(&YO=&4@=&AA="!A;B!U;F1E<G-C;W)E("A?*0H)+R\@8VAA<F%C
M=&5R(&EN('1H92!T<F%N<VQA=&EO;B`H<FEG:'0@8V]L=6UN*2!W:6QL(&-A
M=7-E('1H92!F;VQL;W=I;F<*"2\O(&QE='1E<B!T;R!B96-O;64@=6YD97)L
M:6YE9"!A;F0@8F4@<VAO<G1C=70@9F]R('1H870@;65N=2!O<'1I;VXN"@H)
M(D-U="(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B0W5T(BDI
M(#\^(BP*"2)#;W!Y(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(D-O<'DB*2D@/SXB+`H)(E!A<W1E(B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B4&%S=&4B*2D@/SXB+`H)(DEM86=E(%!R;W!E<G1I97,B("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B7TEM86=E(%!R;W!E<G1I97,N+BXB*2D@/SXB
M+`H)(DUO9&EF>2!,:6YK(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B7TUO
M9&EF>2!,:6YK+BXN(BDI(#\^(BP*"2)#:&5C:R!,:6YK(B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(D-H96-?:R!,:6YK+BXN(BDI(#\^(BP*"2)296UO
M=F4@3&EN:R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E]296UO=F4@3&EN
M:RXN+B(I*2`_/B(L"@DB0V5L;"!0<F]P97)T:65S(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")#7V5L;"!0<F]P97)T:65S+BXN(BDI(#\^(BP*"2)2;W<@4')O
M<&5R=&EE<R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E)O7W<@4')O<&5R=&EE
M<RXN+B(I*2`_/B(L"@DB26YS97)T(%)O=R!"969O<F4B("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*"))7VYS97)T(%)O=R!"969O<F4B*2D@/SXB+`H)(DEN<V5R="!2
M;W<@069T97(B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26Y?<V5R="!2;W<@069T
M97(B*2D@/SXB+`H)(D1E;&5T92!2;W<B("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B7T1E;&5T92!2;W<B*2D@/SXB+`H)(D1E;&5T92!#96QL(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B1&5L971E($-E;&PB*2D@/SXB+`H)(E1A
M8FQE(%!R;W!E<G1I97,B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B7U1A8FQE(%!R
M;W!E<G1I97,N+BXB*2D@/SXB+`H)(DEN<V5R="!#;VQU;6X@0F5F;W)E(B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B26YS97)T(%]#;VQU;6X@0F5F;W)E(BDI(#\^(BP*
M"2));G-E<G0@0V]L=6UN($%F=&5R(B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN<V5R
M="!#7V]L=6UN($%F=&5R(BDI(#\^(BP*"2)$96QE=&4@0V]L=6UN(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(D1E7VQE=&4@0V]L=6UN(BDI(#\^(BP*"2)*
M=7-T:69Y($QE9G0B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DIU<W1I9GD@
M3&5F="(I*2`_/B(L"@DB2G5S=&EF>2!#96YT97(B("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")*=7-T:69Y($-E;G1E<B(I*2`_/B(L"@DB2G5S=&EF>2!2:6=H
M="(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")*=7-T:69Y(%)I9VAT(BDI(#\^
M(BP*"2)*=7-T:69Y($9U;&PB("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DIU
M<W1I9GD@1G5L;"(I*2`_/B(L"@DB36%K92!L:6YK(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*")-86ME(&QI;E]K+BXN(BDI(#\^(BP*"2)296UO=F4@
M=&AE(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E)E;6]V92!T:&4B*2D@
M/SXB+`H)(D5L96UE;G0B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M16QE;65N="XN+B(I*2`_/B(L"@DB26YS97)T('!A<F%G<F%P:"!B969O<F4B
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*"));G-E<G0@<&%R86=R87!H(&)E9F]R92(I*2`_/B(L
M"@DB26YS97)T('!A<F%G<F%P:"!A9G1E<B(@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"));G-E
M<G0@<&%R86=R87!H(&%F=&5R(BDI(#\^(BP*"@DO+R!/=&AE<B!L86)E;',@
M*'1O;VQT:7!S(&%N9"!A;&5R="]C;VYF:7)M(&)O>"!M97-S86=E<RD*"@DB
M4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E
M;&5M96YT.B(@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")0;&5A<V4@
M8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z
M(BDI(#\^(BP*"2)296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT
M(B`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B*2D@/SXB
M+`H)(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(B`@
M("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B2&]W
M(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB*2D@/SXB+`H)
M(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(B`@("`@("`@("`@
M("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4VAO=R!T
M:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B*2D@/SXB+`H)(DUO9&EF>2!5
M4DPB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B36]D:69Y(%523"(I*2`_
M/B(L"@DB0W5R<F5N="!54DP@:7,B("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")#
M=7)R96YT(%523"!I<R(I*2`_/B(L"@DB3W!E;G,@=&AI<R!L:6YK(&EN(&$@
M;F5W('=I;F1O=R(@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C
M:&\@861D<VQA<VAE<RA?*")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN
M9&]W(BDI(#\^(BP*"2)0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O
M('5N;&EN:R!T:&ES(&5L96UE;G0N(B`@.B`B/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK
M('1H:7,@96QE;65N="XB*2D@/SXB+`H)(DQI;FL@<&]I;G1S('1O.B(@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B3&EN:R!P;VEN=',@=&\Z(BDI(#\^(BP*"2)5
M;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E5N;&EN:R!T
M:&4@8W5R<F5N="!E;&5M96YT(BDI(#\^(BP*"2)3:&]W('1H92!486)L92!#
M96QL(%!R;W!E<G1I97,@9&EA;&]G(B`@("`@("`@("`@("`@("`@.B`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O
M<&5R=&EE<R!D:6%L;V<B*2D@/SXB+`H)(E-H;W<@=&AE(%1A8FQE(%)O=R!0
M<F]P97)T:65S(&1I86QO9R(@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I
M97,@9&EA;&]G(BDI(#\^(BP*"2));G-E<G0@82!N97<@<F]W(&)E9F]R92!T
M:&4@8W5R<F5N="!O;F4B("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R
M96YT(&]N92(I*2`_/B(L"@DB26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@
M8W5R<F5N="!O;F4B("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*"));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT
M(&]N92(I*2`_/B(L"@DB1&5L971E('1H92!C=7)R96YT(')O=R(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(BDI(#\^(BP*"2)3:&]W
M('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(@("`@("`@("`@("`@("`@
M("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E-H;W<@=&AE(%1A
M8FQE(%!R;W!E<G1I97,@9&EA;&]G(BDI(#\^(BP*"2));G-E<G0@82!N97<@
M8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B("`@("`@("`@("`@.B`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN<V5R="!A(&YE=R!C;VQU;6X@
M8F5F;W)E('1H92!C=7)R96YT(&]N92(I*2`_/B(L"@DB26YS97)T(&$@;F5W
M(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B("`@("`@("`@("`@(#H@
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"));G-E<G0@82!N97<@8V]L=6UN
M(&%F=&5R('1H92!C=7)R96YT(&]N92(I*2`_/B(L"@DB1&5L971E('1H92!C
M=7)R96YT(&-O;'5M;B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")$96QE=&4@=&AE(&-U<G)E;G0@
M8V]L=6UN(BDI(#\^(BP*"2)#<F5A=&4@82!L:6YK(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S
M;&%S:&5S*%\H(D-R96%T92!A(&QI;FLB*2D@/SXB+`H)(DEN<V5R="!A('!A
M<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(@("`@("`@("`@("`Z
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26YS97)T(&$@<&%R86=R87!H
M(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(BDI(#\^(BP*"2));G-E<G0@82!P
M87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(@("`@("`@("`@("`@
M.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN<V5R="!A('!A<F%G<F%P
M:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(BDI(#\^(@I].PH`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<P``````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`R,C4U
M,@`Q,#4Q-30S,S<V,``P,C4Q-C(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````2%1-3$%R96$N23$X3B`]('L*"@DO+R!T:&4@
M9F]L;&]W:6YG('-H;W5L9"!B92!T:&4@9FEL96YA;64@=VET:&]U="`N:G,@
M97AT96YS:6]N"@DO+R!I="!W:6QL(&)E('5S960@9F]R(&%U=&]M871I8V%L
M;'D@;&]A9"!P;'5G:6X@;&%N9W5A9V4N"@EL86YG.B`B96XB+`H*"71O;VQT
M:7!S.B!["@D)8F]L9#H@("`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B0F]L9"(I*2`_/B(L"@D):71A;&EC.B`@("`@("`@("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B271A;&EC(BDI(#\^(BP*"0EU;F1E<FQI;F4Z
M("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")5;F1E<FQI;F4B*2D@
M/SXB+`H)"7-T<FEK971H<F]U9V@Z("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(E-T<FEK971H<F]U9V@B*2D@/SXB+`H)"7-U8G-C<FEP=#H@("`@("`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E-U8G-C<FEP="(I*2`_/B(L"@D)
M<W5P97)S8W)I<'0Z("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4W5P
M97)S8W)I<'0B*2D@/SXB+`H)"6IU<W1I9GEL969T.B`@("`B/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(DIU<W1I9GD@3&5F="(I*2`_/B(L"@D):G5S=&EF
M>6-E;G1E<CH@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B2G5S=&EF>2!#
M96YT97(B*2D@/SXB+`H)"6IU<W1I9GER:6=H=#H@("`B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(DIU<W1I9GD@4FEG:'0B*2D@/SXB+`H)"6IU<W1I9GEF
M=6QL.B`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DIU<W1I9GD@1G5L
M;"(I*2`_/B(L"@D);W)D97)E9&QI<W0Z("`@("(\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B3W)D97)E9"!,:7-T(BDI(#\^(BP*"0EU;F]R9&5R961L:7-T
M.B`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")"=6QL971E9"!,:7-T(BDI
M(#\^(BP*"0EO=71D96YT.B`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*")$96-R96%S92!);F1E;G0B*2D@/SXB+`H)"6EN9&5N=#H@("`@("`@
M("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN8W)E87-E($EN9&5N="(I
M*2`_/B(L"@D)9F]R96-O;&]R.B`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B1F]N="!#;VQO<B(I*2`_/B(L"@D):&EL:71E8V]L;W(Z("`@("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B0F%C:V=R;W5N9"!#;VQO<B(I*2`_
M/B(L"@D):6YS97)T:&]R:7IO;G1A;')U;&4Z("(\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B2&]R:7IO;G1A;"!2=6QE(BDI(#\^(BP*"0EC<F5A=&5L:6YK
M.B`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"));G-E<G0@5V5B($QI
M;FLB*2D@/SXB+`H)"6EN<V5R=&EM86=E.B`@("`B/#]P:'`@96-H;R!A9&1S
M;&%S:&5S*%\H(DEN<V5R="]-;V1I9GD@26UA9V4B*2D@/SXB+`H)"6EN<V5R
M='1A8FQE.B`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN<V5R="!4
M86)L92(I*2`_/B(L"@D):'1M;&UO9&4Z("`@("`@("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B5&]G9VQE($A434P@4V]U<F-E(BDI(#\^(BP*"0EP;W!U
M<&5D:71O<CH@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")%;FQA<F=E
M($5D:71O<B(I*2`_/B(L"@D)86)O=70Z("`@("`@("`@("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B06)O=70@=&AI<R!E9&ET;W(B*2D@/SXB+`H)"7-H
M;W=H96QP.B`@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DAE;'`@
M=7-I;F<@961I=&]R(BDI(#\^(BP*"0ET97AT:6YD:6-A=&]R.B`@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*")#=7)R96YT('-T>6QE(BDI(#\^(BP*"0EU
M;F1O.B`@("`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")5;F1O
M97,@>6]U<B!L87-T(&%C=&EO;B(I*2`_/B(L"@D)<F5D;SH@("`@("`@("`@
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4F5D;V5S('EO=7(@;&%S="!A
M8W1I;VXB*2D@/SXB+`H)"6-U=#H@("`@("`@("`@("`B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(D-U="!S96QE8W1I;VXB*2D@/SXB+`H)"6-O<'DZ("`@
M("`@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D-O<'D@<V5L96-T
M:6]N(BDI(#\^(BP*"0EP87-T93H@("`@("`@("`@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")087-T92!F<F]M(&-L:7!B;V%R9"(I*2`_/B(L"@D);&5F
M='1O<FEG:'0Z("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B1&ER96-T
M:6]N(&QE9G0@=&\@<FEG:'0B*2D@/SXB+`H)"7)I9VAT=&]L969T.B`@("`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D1I<F5C=&EO;B!R:6=H="!T;R!L
M969T(BDI(#\^(BP*"0ER96UO=F5F;W)M870Z("`@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")296UO=F4@9F]R;6%T=&EN9R(I*2`_/B(L"@D)<')I;G0Z
M("`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4')I;G0@9&]C
M=6UE;G0B*2D@/SXB+`H)"6MI;&QW;W)D.B`@("`@("`B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(D-L96%R($U33V9F:6-E('1A9W,B*2D@/SXB"@E]+`H*
M"6)U='1O;G,Z('L*"0DB;VLB.B`@("`@("`@("`@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")/2R(I*2`_/B(L"@D)(F-A;F-E;"(Z("`@("`@("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B0V%N8V5L(BDI(#\^(@H)?2P*"@EM<V<Z
M('L*"0DB4&%T:"(Z("`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")0871H(BDI(#\^(BP*"0DB5$585%]-3T1%(CH@("`@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@
M6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB*2D@/SXB
M+`H*"0DB244M<W5C:W,M9G5L;"US8W)E96XB(#H*"0DO+R!T<F%N<VQA=&4@
M:&5R90H)"2(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B5&AE(&9U;&P@<V-R
M965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E
M<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E
M<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N
M8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@
M86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E
M;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@
M9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@
M<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R
M97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E
M96X@961I=&]R+B(I*2`_/B(L"@H)"2)-;WHM0VQI<&)O87)D(B`Z"@D)(CP_
M<&AP(&5C:&\@861D<VQA<VAE<RA?*")5;G!R:79I;&5G960@<V-R:7!T<R!C
M86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F
M;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN
M:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@
M=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(BDI
M(#\^(@H)?2P*"@ED:6%L;V=S.B!["@D)+R\@0V]M;6]N"@D)(D]+(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")/2R(I*2`_/B(L"@D)(D-A;F-E
M;"(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")#86YC96PB*2D@/SXB+`H*
M"0DB06QI9VYM96YT.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D%L:6=N;65N
M=#HB*2D@/SXB+`H)"2).;W0@<V5T(B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H
M7R@B3F]T('-E="(I*2`_/B(L"@D)(DQE9G0B("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*"),969T(BDI(#\^(BP*"0DB4FEG:'0B("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(E)I9VAT(BDI(#\^(BP*"0DB5&5X='1O<"(@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(E1E>'1T;W`B*2D@/SXB+`H)"2)!8G-M
M:61D;&4B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B06)S;6ED9&QE(BDI(#\^
M(BP*"0DB0F%S96QI;F4B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D)A<V5L
M:6YE(BDI(#\^(BP*"0DB06)S8F]T=&]M(B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(D%B<V)O='1O;2(I*2`_/B(L"@D)(D)O='1O;2(@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*")";W1T;VTB*2D@/SXB+`H)"2)-:61D;&4B("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B36ED9&QE(BDI(#\^(BP*"0DB5&]P(B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E1O<"(I*2`_/B(L"@H)"2),
M87EO=70B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B3&%Y;W5T(BDI(#\^
M(BP*"0DB4W!A8VEN9R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E-P86-I
M;F<B*2D@/SXB+`H)"2)(;W)I>F]N=&%L.B(@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H
M7R@B2&]R:7IO;G1A;#HB*2D@/SXB+`H)"2)(;W)I>F]N=&%L('!A9&1I;F<B
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B2&]R:7IO;G1A;"!P861D:6YG(BDI(#\^(BP*"0DB
M5F5R=&EC86PZ(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E9E<G1I8V%L.B(I
M*2`_/B(L"@D)(E9E<G1I8V%L('!A9&1I;F<B("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")6
M97)T:6-A;"!P861D:6YG(BDI(#\^(BP*"0DB0F]R9&5R('1H:6-K;F5S<SHB
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(D)O<F1E<B!T:&EC:VYE<W,Z(BDI(#\^(BP*"0DB
M3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DQE879E(&5M<'1Y
M(&9O<B!N;R!B;W)D97(B*2D@/SXB+`H*"0DO+R!);G-E<G0@3&EN:PH)"2))
M;G-E<G0O36]D:69Y($QI;FLB("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26YS97)T+TUO9&EF
M>2!,:6YK(BDI(#\^(BP*"0DB3F]N92`H=7-E(&EM<&QI8VET*2(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(DYO;F4@*'5S92!I;7!L:6-I="DB*2D@/SXB+`H)"2).97<@=VEN
M9&]W("A?8FQA;FLI(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B3F5W('=I;F1O=R`H7V)L86YK
M*2(I*2`_/B(L"@D)(E-A;64@9G)A;64@*%]S96QF*2(@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")386UE(&9R86UE("A?<V5L9BDB*2D@/SXB+`H)"2)4;W`@9G)A;64@*%]T
M;W`I(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B5&]P(&9R86UE("A?=&]P*2(I*2`_/B(L
M"@D)(D]T:&5R(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")/=&AE<B(I
M*2`_/B(L"@D)(E1A<F=E=#HB("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")4
M87)G970Z(BDI(#\^(BP*"0DB5&ET;&4@*'1O;VQT:7`I.B(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(E1I=&QE("AT;V]L=&EP*3HB*2D@/SXB+`H)"2)54DPZ(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B55),.B(I*2`_/B(L"@D)(EEO=2!M
M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(@
M(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")9;W4@;75S="!E;G1E<B!T
M:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B*2D@/SXB+`H)"2\O
M($EN<V5R="!486)L90H)"2));G-E<G0@5&%B;&4B("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B26YS97)T(%1A8FQE(BDI(#\^(BP*"0DB4F]W<SHB("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(E)O=W,Z(BDI(#\^(BP*"0DB3G5M8F5R(&]F
M(')O=W,B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DYU;6)E<B!O9B!R;W=S(BDI(#\^
M(BP*"0DB0V]L<SHB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D-O;',Z
M(BDI(#\^(BP*"0DB3G5M8F5R(&]F(&-O;'5M;G,B("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(DYU;6)E<B!O9B!C;VQU;6YS(BDI(#\^(BP*"0DB5VED=&@Z(B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(E=I9'1H.B(I*2`_/B(L"@D)(E=I9'1H(&]F
M('1H92!T86)L92(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")7:61T:"!O9B!T:&4@=&%B;&4B
M*2D@/SXB+`H)"2)097)C96YT(B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M4&5R8V5N="(I*2`_/B(L"@D)(E!I>&5L<R(@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")0:7AE;',B*2D@/SXB+`H)"2)%;2(@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B16TB*2D@/SXB+`H)"2)7:61T:"!U;FET(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B5VED=&@@=6YI="(I*2`_/B(L"@D)(E!O<VET
M:6]N:6YG(&]F('1H:7,@=&%B;&4B("`@("`@("`@("`@("`@("`@("`@("`@
M(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")0;W-I=&EO;FEN9R!O9B!T
M:&ES('1A8FQE(BDI(#\^(BP*"0DB0V5L;"!S<&%C:6YG.B(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S
M;&%S:&5S*%\H(D-E;&P@<W!A8VEN9SHB*2D@/SXB+`H)"2)3<&%C92!B971W
M965N(&%D:F%C96YT(&-E;&QS(B`@("`@("`@("`@("`@("`@("`@("`Z("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4W!A8V4@8F5T=V5E;B!A9&IA8V5N
M="!C96QL<R(I*2`_/B(L"@D)(D-E;&P@<&%D9&EN9SHB("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")#96QL('!A9&1I;F<Z(BDI(#\^(BP*"0DB4W!A8V4@8F5T=V5E
M;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(@("`@("`@("`@.B`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(E-P86-E(&)E='=E96X@8V]N=&5N="!A
M;F0@8F]R9&5R(&EN(&-E;&PB*2D@/SXB+`H)"2\O($EN<V5R="!);6%G90H)
M"2));G-E<G0@26UA9V4B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26YS97)T($EM
M86=E(BDI(#\^(BP*"0DB26UA9V4@55),.B(@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(DEM86=E(%523#HB*2D@/SXB+`H)"2)%;G1E<B!T:&4@:6UA9V4@55),
M(&AE<F4B("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B16YT97(@=&AE(&EM86=E(%523"!H97)E(BDI(#\^
M(BP*"0DB4')E=FEE=R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E!R979I
M97<B*2D@/SXB+`H)"2)0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD
M;W<B("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H
M7R@B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(BDI(#\^(BP*
M"0DB06QT97)N871E('1E>'0Z(B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D%L=&5R;F%T
M92!T97AT.B(I*2`_/B(L"@D)(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U
M<'!O<G0@:6UA9V5S(B`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E
M<R(I*2`_/B(L"@D)(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B("`@("`@
M("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(BDI(#\^(BP*"0DB26UA9V4@
M4')E=FEE=SHB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEM86=E(%!R979I97<Z(BDI
M(#\^(@H)?0I].PH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,`````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,#(`,3`U,34T,S,W-C``,#(W,3`S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"\O
M($DQ.$X@8V]N<W1A;G1S"@HO+R!,04Y'.B`B96XB+"!%3D-/1$E.1SH@551&
M+3@@?"!)4T\M.#@U.2TQ"B\O($%U=&AO<CH@36EH86D@0F%Z;VXL(&AT='`Z
M+R]D>6YA<F-H+F-O;2]M:7-H;V\*"B\O($9/4B!44D%.4TQ!5$]24SH*+R\*
M+R\@("`Q+B!03$5!4T4@4%54(%E/55(@0T].5$%#5"!)3D9/($E.(%1(12!!
M0D]612!,24Y%"B\O("`@("`@*&%T(&QE87-T(&$@=F%L:60@96UA:6P@861D
M<F5S<RD*+R\*+R\@("`R+B!03$5!4T4@5%)9(%1/(%5312!55$8M."!&3U(@
M14Y#3T1)3D<["B\O("`@("`@*&EF('1H:7,@:7,@;F]T('!O<W-I8FQE+"!P
M;&5A<V4@:6YC;'5D92!A(&-O;6UE;G0*+R\@("`@("`@=&AA="!S=&%T97,@
M=VAA="!E;F-O9&EN9R!I<R!N96-E<W-A<GDN*0H*3&ES=%1Y<&4N23$X3B`]
M('L*"2)$96-I;6%L(B`@("`@("`@("`@("`@("`Z("`@("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B1&5C:6UA;"!N=6UB97)S(BDI(#\^(BP*"2),;W=E
M<B!R;VUA;B(@("`@("`@("`@("`Z("`@("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B3&]W97(@<F]M86X@;G5M8F5R<R(I*2`_/B(L"@DB57!P97(@<F]M
M86XB("`@("`@("`@("`@.B`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(E5P<&5R(')O;6%N(&YU;6)E<G,B*2D@/SXB+`H)(DQO=V5R(&QA=&EN(B`@
M("`@("`@("`@(#H@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"),;W=E
M<B!L871I;B!L971T97)S(BDI(#\^(BP*"2)5<'!E<B!L871I;B(@("`@("`@
M("`@("`Z("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B57!P97(@;&%T
M:6X@;&5T=&5R<R(I*2`_/B(L"@DB3&]W97(@9W)E96LB("`@("`@("`@("`@
M.B`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DQO=V5R(&=R965K(&QE
M='1E<G,B*2D@/SXB+`H)(DQI<W13='EL951O;VQT:7`B("`@("`@(#H@("`@
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")#:&]O<V4@;&ES="!S='EL92!T
M>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB*2D@/SXB"GT["@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<P``````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q
M-#0V,P`Q,#4Q-30S,S<V,``P,C8S,S,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+R\@23$X3B!C;VYS=&%N=',*"B\O($Q!
M3D<Z(")E;B(L($5.0T]$24Y'.B!55$8M."!\($E33RTX.#4Y+3$*+R\@075T
M:&]R.B!-:6AA:2!"87IO;BP@:'1T<#HO+V1Y;F%R8V@N8V]M+VUI<VAO;PH*
M+R\@1D]2(%1204Y33$%43U)3.@HO+PHO+R`@(#$N(%!,14%312!0550@64]5
M4B!#3TY404-4($E.1D\@24X@5$A%($%"3U9%($Q)3D4*+R\@("`@("`H870@
M;&5A<W0@82!V86QI9"!E;6%I;"!A9&1R97-S*0HO+PHO+R`@(#(N(%!,14%3
M12!44ED@5$\@55-%(%541BTX($9/4B!%3D-/1$E.1SL*+R\@("`@("`H:68@
M=&AI<R!I<R!N;W0@<&]S<VEB;&4L('!L96%S92!I;F-L=61E(&$@8V]M;65N
M=`HO+R`@("`@("!T:&%T('-T871E<R!W:&%T(&5N8V]D:6YG(&ES(&YE8V5S
M<V%R>2XI"@I486)L94]P97)A=&EO;G,N23$X3B`]('L*"2)!;&EG;B(Z"0D)
M"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B06QI9VXB*2D@/SXB+`H)
M(D%L;"!F;W5R('-I9&5S(CH)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(D%L;"!F;W5R('-I9&5S(BDI(#\^(BP*"2)"86-K9W)O=6YD(CH)"0D)
M"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")"86-K9W)O=6YD(BDI(#\^
M(BP*"2)"87-E;&EN92(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")"87-E;&EN92(I
M*2`_/B(L"@DB0F]R9&5R(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*")";W)D97(B*2D@/SXB+`H)(D)O<F1E<G,B.@D)"0D)("`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(D)O<F1E<G,B*2D@/SXB+`H)(D)O='1O;2(Z
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(D)O='1O;2(I*2`_/B(L"@DB0U-3(%-T
M>6QE(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")3='EL92!;
M0U-372(I*2`_/B(L"@DB0V%P=&EO;B(Z"0D)"0D@("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B0V%P=&EO;B(I*2`_/B(L"@DB0V5L;"!0<F]P97)T:65S
M(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B0V5L;"!0<F]P97)T:65S(BDI(#\^(BP*"2)#96YT
M97(B.@D)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D-E;G1E<B(I
M*2`_/B(L"@DB0VAA<B(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B0VAA<B(I
M*2`_/B(L"@DB0V]L;&%P<V5D(&)O<F1E<G,B.B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B0V]L;&%P
M<V5D(&)O<F1E<G,B*2D@/SXB+`H)(D-O;&]R(CH)"0D)"2`@(CP_<&AP(&5C
M:&\@861D<VQA<VAE<RA?*")#;VQO<B(I*2`_/B(L"@DB1&5S8W)I<'1I;VXB
M.@D)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D1E<V-R:7!T:6]N
M(BDI(#\^(BP*"2)&1R!#;VQO<B(Z"0D)"0D@("(\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B1D<@0V]L;W(B*2D@/SXB+`H)(D9L;V%T(CH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(D9L;V%T(BDI(#\^(BP*"2)&<F%M97,B.@D)"0D)("`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D9R86UE<R(I*2`_/B(L"@DB2&5I
M9VAT(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B2&5I9VAT(BDI(#\^(BP*"2)(
M;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(Z("`@
M("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")(;W<@;6%N>2!C;VQU;6YS
M('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(I*2`_/B(L"@DB2&]W(&UA;GD@
M<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B.B`@("`@("`@("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@
M;&EK92!T;R!M97)G93\B*2D@/SXB+`H)(DEM86=E(%523"(Z"0D)"0D@("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26UA9V4@55),(BDI(#\^(BP*"2)*
M=7-T:69Y(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")*=7-T:69Y(BDI(#\^(BP*
M"2),87EO=70B.@D)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DQA
M>6]U="(I*2`_/B(L"@DB3&5F="(Z"0D)"0D)("`B/#]P:'`@96-H;R!A9&1S
M;&%S:&5S*%\H(DQE9G0B*2D@/SXB+`H)(DUA<F=I;B(Z("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B/#]P:'`@96-H;R!A9&1S
M;&%S:&5S*%\H(DUA<F=I;B(I*2`_/B(L"@DB36ED9&QE(CH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B36ED9&QE(BDI(#\^(BP*"2).;R!R=6QE<R(Z"0D)"0D@
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B3F\@<G5L97,B*2D@/SXB+`H)
M(DYO('-I9&5S(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*").
M;R!S:61E<R(I*2`_/B(L"@DB3F]N92(Z("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H
M7R@B3F]N92(I*2`_/B(L"@DB4&%D9&EN9R(Z"0D)"0D@("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B4&%D9&EN9R(I*2`_/B(L"@DB4&QE87-E(&-L:6-K
M(&EN=&\@<V]M92!C96QL(CH@("`@("`@("`@("`@("`@("`@("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL
M(BDI(#\^(BP*"2)2:6=H="(Z"0D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B4FEG:'0B*2D@/SXB+`H)(E)O=R!0<F]P97)T:65S(CH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(E)O=R!0<F]P97)T:65S(BDI(#\^(BP*"2)2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(CH@(CP_<&AP(&5C
M:&\@861D<VQA<VAE<RA?*")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L
M;"!R;W=S(&%N9"!C;VQU;6YS(BDI(#\^(BP*"2)2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&-O;'5M;G,@;VYL>2(Z"2`@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL
M>2(I*2`_/B(L"@DB4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N
M;'DB.@D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@<F]W<R!O;FQY(BDI(#\^(BP*"2)2=6QE<R(Z"0D)
M"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4G5L97,B*2D@/SXB+`H)
M(E-P86-I;F<@86YD('!A9&1I;F<B.B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E-P86-I;F<@86YD('!A
M9&1I;F<B*2D@/SXB+`H)(E-P86-I;F<B.@D)"0D)("`B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(E-P86-I;F<B*2D@/SXB+`H)(E-U;6UA<GDB.@D)"0D)
M("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E-U;6UA<GDB*2D@/SXB+`H)
M(E1/+6-E;&PM9&5L971E(CH)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(D1E;&5T92!C96QL(BDI(#\^(BP*"2)43RUC96QL+6EN<V5R="UA9G1E
M<B(Z"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"));G-E<G0@8V5L
M;"!A9G1E<B(I*2`_/B(L"@DB5$\M8V5L;"UI;G-E<G0M8F5F;W)E(CH)"0D@
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26YS97)T(&-E;&P@8F5F;W)E
M(BDI(#\^(BP*"2)43RUC96QL+6UE<F=E(CH)"0D)("`B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(DUE<F=E(&-E;&QS(BDI(#\^(BP*"2)43RUC96QL+7!R
M;W`B.@D)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D-E;&P@<')O
M<&5R=&EE<R(I*2`_/B(L"@DB5$\M8V5L;"US<&QI="(Z"0D)"2`@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*")3<&QI="!C96QL(BDI(#\^(BP*"2)43RUC
M;VPM9&5L971E(CH)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D1E
M;&5T92!C;VQU;6XB*2D@/SXB+`H)(E1/+6-O;"UI;G-E<G0M869T97(B.@D)
M"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26YS97)T(&-O;'5M;B!A
M9G1E<B(I*2`_/B(L"@DB5$\M8V]L+6EN<V5R="UB969O<F4B.@D)"0D@("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26YS97)T(&-O;'5M;B!B969O<F4B
M*2D@/SXB+`H)(E1/+6-O;"US<&QI="(Z"0D)"0D@("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B4W!L:70@8V]L=6UN(BDI(#\^(BP*"2)43RUR;W<M9&5L
M971E(CH)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D1E;&5T92!R
M;W<B*2D@/SXB+`H)(E1/+7)O=RUI;G-E<G0M86)O=F4B.@D)"0D@("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B26YS97)T(')O=R!B969O<F4B*2D@/SXB
M+`H)(E1/+7)O=RUI;G-E<G0M=6YD97(B.@D)"0D@("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B26YS97)T(')O=R!A9G1E<B(I*2`_/B(L"@DB5$\M<F]W
M+7!R;W`B.@D)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E)O=R!P
M<F]P97)T:65S(BDI(#\^(BP*"2)43RUR;W<M<W!L:70B.@D)"0D)("`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(E-P;&ET(')O=R(I*2`_/B(L"@DB5$\M
M=&%B;&4M<')O<"(Z"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")4
M86)L92!P<F]P97)T:65S(BDI(#\^(BP*"2)486)L92!0<F]P97)T:65S(CH)
M"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E1A8FQE(%!R;W!E<G1I
M97,B*2D@/SXB+`H)(E1E>'0@86QI9VXB.B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E1E
M>'0@86QI9VXB*2D@/SXB+`H)(E1H92!B;W1T;VT@<VED92!O;FQY(CH)"0D)
M("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E1H92!B;W1T;VT@<VED92!O
M;FQY(BDI(#\^(BP*"2)4:&4@;&5F="UH86YD('-I9&4@;VYL>2(Z"0D)("`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E1H92!L969T+6AA;F0@<VED92!O
M;FQY(BDI(#\^(BP*"2)4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(Z
M"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B5&AE(')I9VAT(&%N9"!L
M969T('-I9&5S(&]N;'DB*2D@/SXB+`H)(E1H92!R:6=H="UH86YD('-I9&4@
M;VYL>2(Z"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E1H92!R:6=H
M="UH86YD('-I9&4@;VYL>2(I*2`_/B(L"@DB5&AE('1O<"!A;F0@8F]T=&]M
M('-I9&5S(&]N;'DB.@D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E1H
M92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(BDI(#\^(BP*"2)4:&4@=&]P
M('-I9&4@;VYL>2(Z"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")4
M:&4@=&]P('-I9&4@;VYL>2(I*2`_/B(L"@DB5&]P(CH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B5&]P(BDI(#\^(BP*"2)5;G-E="!C;VQO<B(Z("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")5;G-E="!C;VQO<B(I*2`_/B(L"@DB5F5R=&EC86P@86QI
M9VXB.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B5F5R=&EC86P@86QI9VXB*2D@/SXB+`H)(E=I
M9'1H(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")7:61T:"(I
M*2`_/B(L"@DB;F]T+61E;"UL87-T+6-E;&PB.@D)"0D@("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D
M96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(BDI(#\^(BP*"2)N;W0M9&5L
M+6QA<W0M8V]L(CH)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DA4
M34Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O
M;'5M;B!I;B!T86)L92XB*2D@/SXB+`H)(FYO="UD96PM;&%S="UR;W<B.@D)
M"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B2%1-3$%R96$@8V]W87)D
M;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(I
M*2`_/B(L"@DB<&5R8V5N="(Z"0D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B<&5R8V5N="(I*2`_/B(L"@DB<&EX96QS(CH)"0D)"2`@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*")P:7AE;',B*2D@/SXB"GT["@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E
M;7!L871E<R]J879A<V-R:7!T+VME>6)I;F1I;F=S+FIS````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#0W,C``,3`U,34T,S,W-C``,#(T-C8W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"\J*@H@*B!*879A
M<V-R:7!T(&QI8G)A<GD@=&\@:&%N9&QE(&$@<V5T(&]F(&ME>6)I;F1I;F=S
M+@H@*@H@*B!4:&4@=7-E<B!S:&]U;&0@:6YC;'5D92!T:&ES('-C<FEP="P@
M86YD('1H96X@8V%L;"!S971+97EB:6YD:6YG*&ME>2P*("H@8V%L;&)A8VLI
M(&9O<B!E86-H(&ME>6)I;F1I;F<@=&AA="!I<R!D97-I<F5D+B!4:&ES('-C
M<FEP="!W:6QL('1A:V4@8V%R90H@*B!O9B!L:7-T96YI;F<@9F]R(&ME>7!R
M97-S97,@86YD(&UA<'!I;F<@=&AE;2!T;R!T:&4@8V%L;&)A8VL@9G5N8W1I
M;VYS+"!O<@H@*B!D;VEN9R!N;W1H:6YG(&EF(&YO(&-A;&QB86-K(&ES('-E
M="X*("H*("H@)$AO<F1E.B!H;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]K
M97EB:6YD:6YG<RYJ<RQV(#$N-2XT+C8@,C`P-B\P,R\R-"`Q-CHP-3HR-"!C
M:'5C:R!%>'`@)`H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*
M("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0'!A8VMA9V4@2&]R9&4*
M("HO"@HO*BH*("H@02!H87-H(&]F(&ME>6)I;F1I;F=S+@H@*@H@*B!`=F%R
M(%]K97E-87`*("HO"G9A<B!?:V5Y36%P(#T@;F5W($%R<F%Y*"D["@HO*BH*
M("H@4V5T('5P('1H92!K97EP<F5S<R!L:7-T96YE<BX*("HO"FEF("AT>7!E
M;V8@9&]C=6UE;G0N8V%P='5R945V96YT<R`A/2`G=6YD969I;F5D)RD@>PH@
M("`@9&]C=6UE;G0N8V%P='5R945V96YT<RA%=F5N="Y+15E04D534RD["B`@
M("!D;V-U;65N="YO;FME>7!R97-S(#T@:V5Y2&%N9&QE<CL*?2!E;'-E('L*
M("`@(&1O8W5M96YT+F]N:V5Y9&]W;B`](&ME>4AA;F1L97(["GT*"B\J*@H@
M*B!3971S('5P(&$@8V%L;&)A8VL@9F]R(&$@:V5Y8V]D92X*("H*("H@0'!A
M<F%M(&ME>2`@("`@("!4:&4@:V5Y8V]D92!T;R!T<FEG9V5R(&]N+@H@*B!`
M<&%R86T@8V%L;&)A8VL@(%1H92!F=6YC=&EO;B!T;R!C86QL('=H96X@(FME
M>2(@:7,@<')E<W-E9"X@4VAO=6QD(&)E(&$*("H@("`@("`@("`@("`@("`@
M("!F=6YC=&EO;BX@270@9V5T<R!T:&4@979E;G0@86YD('1H92!K97EC;V1E
M(&%S('!A<F%M971E<G,L"B`J("`@("`@("`@("`@("`@("`@<V\@=&AA="!Y
M;W4@8V%N('5S92!O;F4@9G5N8W1I;VX@=&\@:&%N9&QE(&UU;'1I<&QE(&ME
M>7,@:68*("H@("`@("`@("`@("`@("`@("!Y;W4@;&EK92X*("HO"F9U;F-T
M:6]N('-E=$ME>6)I;F1I;F<H:V5Y+"!C86QL8F%C:RD*>PH@("`@:68@*'1Y
M<&5O9B!?:V5Y36%P6VME>5T@/3T@)W5N9&5F:6YE9"<I('L*("`@("`@("!?
M:V5Y36%P6VME>5T@/2!;73L*("`@('T*"B`@("!I9B`H='EP96]F(&-A;&QB
M86-K(#T]("=F=6YC=&EO;B<I('L*("`@("`@("!?:V5Y36%P6VME>5TN<'5S
M:"AC86QL8F%C:RD["B`@("!](&5L<V4@>PH@("`@("`@(%]K97E-87!;:V5Y
M72YP=7-H*&YE=R!&=6YC=&EO;B@G92<L("=K97DG+"!C86QL8F%C:R`K("<H
M92P@:V5Y*3LG*2D["B`@("!]"GT*"B\J*@H@*B!);G9O:V5D(&)Y('1H92!*
M879A4V-R:7!T(&5V96YT(&UO9&5L('=H96X@82!K97D@:7,@<')E<W-E9"X@
M1V5T<PH@*B!T:&4@:V5Y8V]D92`H871T96UP=',@=&\@:&%N9&QE(&%L;"!B
M<F]W<V5R<RD@86YD(&QO;VMS('1O('-E92!I9@H@*B!W92!H879E(&$@:&%N
M9&QE<B!D969I;F5D(&9O<B!T:&%T(&ME>2X@268@<V\L(&-A;&P@:70N"B`J
M"B`J($!P87)A;2!E("!4:&4@979E;G0@=&\@:&%N9&QE+B!3:&]U;&0@8F4@
M82!K97EP<F5S<RX*("HO"F9U;F-T:6]N(&ME>4AA;F1L97(H92D*>PH@("`@
M=F%R(&4@/2!E('Q\('=I;F1O=RYE=F5N=#L*"B`@("!I9B`H92YK97E#;V1E
M*2!["B`@("`@("`@:V5Y(#T@92YK97E#;V1E.PH@("`@?2!E;'-E(&EF("AE
M+G=H:6-H*2!["B`@("`@("`@:V5Y(#T@92YW:&EC:#L*("`@('T*"B`@("`O
M*B!)9B!T:&5R92=S(&$@:&%N9&QE<B!D969I;F5D(&9O<B!T:&4@:V5Y('1H
M870@=V%S('!R97-S960L(&-A;&P*("`@("`J(&ET+"!P87-S:6YG(&EN('1H
M92!K97EC;V1E(&%N9"!T:&4@979E;G0N("HO"B`@("!I9B`H7VME>4UA<%MK
M97E=*2!["B`@("`@("`@9F]R("AV87(@:2`](#`[(&D@/"!?:V5Y36%P6VME
M>5TN;&5N9W1H.R`K*VDI('L*("`@("`@("`@("`@:68@*%]K97E-87!;:V5Y
M75MI72AE+"!K97DI*2!["B`@("`@("`@("`@("`@("!E+G)E='5R;E9A;'5E
M(#T@9F%L<V4["B`@("`@("`@("`@("`@("!I9B`H='EP96]F(&4N<')E=F5N
M=$1E9F%U;'0@/3T@)V9U;F-T:6]N)RD@>PH@("`@("`@("`@("`@("`@("`@
M(&4N<')E=F5N=$1E9F%U;'0H*3L*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@92YR971U<FY686QU92`]('1R=64["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@('T*?0H`````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,`````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C,R-#<`,3`U,34T,S,W-C``,#(U
M,38P`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'9A<B!C=7)R96YT1&%T92P@8W5R<F5N=%EE87(L(&-U<DEM9TED+"!C=7)R
M96YT5&%R9V5T.PH*9G5N8W1I;VX@;W!E;D-A;&5N9&%R*&EM9TED+"!T87)G
M970L(&-A;&QB86-K*0I["B`@("!I9B`H9&]C=6UE;G0N9V5T16QE;65N=$)Y
M260H=&%R9V5T("L@)UMY96%R72<I+G9A;'5E("8F(&1O8W5M96YT+F=E=$5L
M96UE;G1">4ED*'1A<F=E="`K("=;;6]N=&A=)RDN=F%L=64@)B8@9&]C=6UE
M;G0N9V5T16QE;65N=$)Y260H=&%R9V5T("L@)UMD87E=)RDN=F%L=64I('L*
M("`@("`@("!V87(@9"`](&YE=R!$871E*&1O8W5M96YT+F=E=$5L96UE;G1"
M>4ED*'1A<F=E="`K("=;>65A<ETG*2YV86QU92P*("`@("`@("`@("`@("`@
M("`@("`@("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*'1A<F=E="`K("=;
M;6]N=&A=)RDN=F%L=64@+2`Q+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M9&]C=6UE;G0N9V5T16QE;65N=$)Y260H=&%R9V5T("L@)UMD87E=)RDN=F%L
M=64I.PH@("`@?2!E;'-E('L*("`@("`@("!V87(@9"`](&YE=R!$871E*"D[
M"B`@("!]"@H@("`@;W!E;D=O=&\H9"YG9714:6UE*"DL(&EM9TED+"!T87)G
M970L(&-A;&QB86-K*3L*?0H*9G5N8W1I;VX@;W!E;D=O=&\H=&EM97-T86UP
M+"!I;6=)9"P@=&%R9V5T+"!C86QL8F%C:RD*>PH@("`@=F%R(')O=RP@8V5L
M;"P@:6UG+"!L:6YK+"!D87ES.PH*("`@(&-U<G)E;G1487)G970@/2!T87)G
M970["@H@("`@=F%R(&0@/2!N97<@1&%T92AT:6UE<W1A;7`I.PH@("`@8W5R
M<F5N=$1A=&4@/2!D.PH@("`@;6]N=&@@/2!D+F=E=$UO;G1H*"D["B`@("!C
M=7)R96YT665A<B`](&0N9V5T665A<B@I.PH@("`@:68@*&-U<G)E;G1996%R
M(#P@,3DP,"D@>PH@("`@("`@(&-U<G)E;G1996%R("L](#$Y,#`["B`@("!]
M"B`@("!V87(@9FER<W1/9DUO;G1H(#T@;F5W($1A=&4H8W5R<F5N=%EE87(L
M(&UO;G1H+"`Q*3L*("`@('9A<B!D:69F(#T@9FER<W1/9DUO;G1H+F=E=$1A
M>2@I("T@,3L*("`@(&EF("AD:69F(#T]("TQ*2!["B`@("`@("`@9&EF9B`]
M(#8["B`@("!]"B`@("!S=VET8V@@*&UO;G1H*2!["B`@("!C87-E(#,Z"B`@
M("!C87-E(#4Z"B`@("!C87-E(#@Z"B`@("!C87-E(#$P.@H@("`@("`@(&1A
M>7,@/2`S,#L*("`@("`@("!B<F5A:SL*"B`@("!C87-E(#$Z"B`@("`@("`@
M:68@*&-U<G)E;G1996%R("4@-"`]/2`P("8F("AC=7)R96YT665A<B`E(#$P
M,"`A/2`P('Q\(&-U<G)E;G1996%R("4@-#`P(#T](#`I*2!["B`@("`@("`@
M("`@(&1A>7,@/2`R.3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!D
M87ES(#T@,C@["B`@("`@("`@?0H@("`@("`@(&)R96%K.PH*("`@(&1E9F%U
M;'0Z"B`@("`@("`@9&%Y<R`](#,Q.PH@("`@("`@(&)R96%K.PH@("`@?0H*
M("`@('9A<B!W9&%Y<R`](%L*("`@("`@("`G/#]P:'`@96-H;R!?*")-;R(I
M(#\^)RP*("`@("`@("`G/#]P:'`@96-H;R!?*")4=2(I(#\^)RP*("`@("`@
M("`G/#]P:'`@96-H;R!?*")792(I(#\^)RP*("`@("`@("`G/#]P:'`@96-H
M;R!?*")4:"(I(#\^)RP*("`@("`@("`G/#]P:'`@96-H;R!?*")&<B(I(#\^
M)RP*("`@("`@("`G/#]P:'`@96-H;R!?*")382(I(#\^)RP*("`@("`@("`G
M/#]P:'`@96-H;R!?*")3=2(I(#\^)PH@("`@73L*("`@('9A<B!M;VYT:',@
M/2!;"B`@("`@("`@)SP_<&AP(&5C:&\@7R@B2F%N=6%R>2(I(#\^)RP*("`@
M("`@("`G/#]P:'`@96-H;R!?*")&96)R=6%R>2(I(#\^)RP*("`@("`@("`G
M/#]P:'`@96-H;R!?*")-87)C:"(I(#\^)RP*("`@("`@("`G/#]P:'`@96-H
M;R!?*")!<')I;"(I(#\^)RP*("`@("`@("`G/#]P:'`@96-H;R!?*")-87DB
M*2`_/B<L"B`@("`@("`@)SP_<&AP(&5C:&\@7R@B2G5N92(I(#\^)RP*("`@
M("`@("`G/#]P:'`@96-H;R!?*")*=6QY(BD@/SXG+`H@("`@("`@("<\/W!H
M<"!E8VAO(%\H(D%U9W5S="(I(#\^)RP*("`@("`@("`G/#]P:'`@96-H;R!?
M*")397!T96UB97(B*2`_/B<L"B`@("`@("`@)SP_<&AP(&5C:&\@7R@B3V-T
M;V)E<B(I(#\^)RP*("`@("`@("`G/#]P:'`@96-H;R!?*").;W9E;6)E<B(I
M(#\^)RP*("`@("`@("`G/#]P:'`@96-H;R!?*")$96-E;6)E<B(I(#\^)PH@
M("`@73L*"B`@("!V87(@;&%Y97(@/2!D;V-U;65N="YG971%;&5M96YT0GE)
M9"@G9V]T;R<I.PH@("`@:68@*&QA>65R+F9I<G-T0VAI;&0I('L*("`@("`@
M("!L87EE<BYR96UO=F5#:&EL9"AL87EE<BYF:7)S=$-H:6QD*3L*("`@('T*
M"B`@("!V87(@=&%B;&4@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=404),
M12<I.PH@("`@=F%R('1B;V1Y(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G
M5$)/1%DG*3L*("`@('1A8FQE+F%P<&5N9$-H:6QD*'1B;V1Y*3L*("`@('1A
M8FQE+F-L87-S3F%M92`]("=I=&5M)SL*("`@('1A8FQE+F-E;&Q3<&%C:6YG
M(#T@,#L*("`@('1A8FQE+F-E;&Q0861D:6YG(#T@,CL*("`@('1A8FQE+F)O
M<F1E<B`](#`["B`@("!T86)L92YS='EL92YW:61T:"`]("=A=71O)SL*"B`@
M("`O+R!4:71L92!B87(N"B`@("!R;W<@/2!D;V-U;65N="YC<F5A=&5%;&5M
M96YT*"=44B<I.PH@("`@8V5L;"`](&1O8W5M96YT+F-R96%T945L96UE;G0H
M)U1$)RD["B`@("!C96QL+F-O;%-P86X@/2`W.PH@("`@8V5L;"YA;&EG;B`]
M("=R:6=H="<["B`@("!C96QL+F-L87-S3F%M92`]("=H96%D97(G.PH@("`@
M;&EN:R`](&1O8W5M96YT+F-R96%T945L96UE;G0H)T$G*3L*("`@(&QI;FLN
M:')E9B`]("<C)SL*("`@(&QI;FLN;VYC;&EC:R`](&9U;F-T:6]N*"D*("`@
M('L*("`@("`@("!V87(@;&%Y97(@/2!D;V-U;65N="YG971%;&5M96YT0GE)
M9"@G9V]T;R<I.PH@("`@("`@(&QA>65R+G-T>6QE+G9I<VEB:6QI='D@/2`G
M:&ED9&5N)SL*("`@("`@("!I9B`H;&%Y97(N9FER<W1#:&EL9"D@>PH@("`@
M("`@("`@("!L87EE<BYR96UO=F5#:&EL9"AL87EE<BYF:7)S=$-H:6QD*3L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H@("`@:6UG
M(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G24U')RD*("`@(&EM9RYS<F,@
M/2`G/#]P:'`@96-H;R`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$
M:7(H)VAO<F1E)RD@/SXO8VQO<V4N<&YG)SL*("`@(&EM9RYB;W)D97(@/2`P
M.PH@("`@;&EN:RYA<'!E;F1#:&EL9"AI;6<I.PH@("`@8V5L;"YA<'!E;F1#
M:&EL9"AL:6YK*3L*("`@(')O=RYA<'!E;F1#:&EL9"AC96QL*3L*("`@('1B
M;V1Y+F%P<&5N9$-H:6QD*')O=RD["@H@("`@+R\@665A<BX*("`@(')O=R`]
M(&1O8W5M96YT+F-R96%T945L96UE;G0H)U12)RD["B`@("!C96QL(#T@9&]C
M=6UE;G0N8W)E871E16QE;65N="@G5$0G*3L*("`@(&-E;&PN86QI9VX@/2`G
M;&5F="<["B`@("!L:6YK(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G02<I
M.PH@("`@;&EN:RYH<F5F(#T@)R,G.PH@("`@;&EN:RYO;F-L:6-K(#T@9G5N
M8W1I;VXH*0H@("`@>PH@("`@("`@(&YE=T1A=&4@/2!N97<@1&%T92AC=7)R
M96YT665A<B`M(#$L(&-U<G)E;G1$871E+F=E=$UO;G1H*"DL(#$I.PH@("`@
M("`@(&]P96Y';W1O*&YE=T1A=&4N9V5T5&EM92@I+"!I;6=)9"P@8W5R<F5N
M=%1A<F=E="P@8V%L;&)A8VLI.PH@("`@("`@(')E='5R;B!F86QS93L*("`@
M('T*("`@(&-E;&PN87!P96YD0VAI;&0H;&EN:RD["B`@("!I;6<@/2!D;V-U
M;65N="YC<F5A=&5%;&5M96YT*"=)34<G*0H@("`@:6UG+G-R8R`]("<\/W!H
M<"!E8VAO("1'3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G941I<B@G:&]R
M9&4G*2`_/B]N878O;&5F="YP;F<G.PH@("`@:6UG+F%L:6=N(#T@)VUI9&1L
M92<["B`@("!I;6<N8F]R9&5R(#T@,#L*("`@(&QI;FLN87!P96YD0VAI;&0H
M:6UG*3L*("`@(')O=RYA<'!E;F1#:&EL9"AC96QL*3L*"B`@("!C96QL(#T@
M9&]C=6UE;G0N8W)E871E16QE;65N="@G5$0G*3L*("`@(&-E;&PN8V]L4W!A
M;B`](#4["B`@("!C96QL+F%L:6=N(#T@)V-E;G1E<B<["B`@("!V87(@>2`]
M(&1O8W5M96YT+F-R96%T951E>'1.;V1E*&-U<G)E;G1996%R*3L*("`@(&-E
M;&PN87!P96YD0VAI;&0H>2D["B`@("!R;W<N87!P96YD0VAI;&0H8V5L;"D[
M"@H@("`@8V5L;"`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U1$)RD["B`@
M("!C96QL+F%L:6=N(#T@)W)I9VAT)SL*("`@(&QI;FL@/2!D;V-U;65N="YC
M<F5A=&5%;&5M96YT*"=!)RD["B`@("!L:6YK+FAR968@/2`G(R<["B`@("!L
M:6YK+F]N8VQI8VL@/2!F=6YC=&EO;B@I"B`@("!["B`@("`@("`@;F5W1&%T
M92`](&YE=R!$871E*&-U<G)E;G1996%R("L@,2P@8W5R<F5N=$1A=&4N9V5T
M36]N=&@H*2P@,2D["B`@("`@("`@;W!E;D=O=&\H;F5W1&%T92YG9714:6UE
M*"DL(&EM9TED+"!C=7)R96YT5&%R9V5T+"!C86QL8F%C:RD["B`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@?0H@("`@8V5L;"YA<'!E;F1#:&EL9"AL:6YK
M*3L*("`@(&EM9R`](&1O8W5M96YT+F-R96%T945L96UE;G0H)TE-1R<I"B`@
M("!I;6<N<W)C(#T@)SP_<&AP(&5C:&\@)$=,3T)!3%-;)W)E9VES=')Y)UTM
M/F=E=$EM86=E1&ER*"=H;W)D92<I(#\^+VYA=B]R:6=H="YP;F<G.PH@("`@
M:6UG+F%L:6=N(#T@)VUI9&1L92<["B`@("!I;6<N8F]R9&5R(#T@,#L*("`@
M(&QI;FLN87!P96YD0VAI;&0H:6UG*3L*("`@(')O=RYA<'!E;F1#:&EL9"AC
M96QL*3L*("`@('1B;V1Y+F%P<&5N9$-H:6QD*')O=RD["@H@("`@+R\@36]N
M=&@@;F%M92X*("`@(')O=R`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U12
M)RD["B`@("!C96QL(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G5$0G*3L*
M("`@(&-E;&PN86QI9VX@/2`G;&5F="<["B`@("!L:6YK(#T@9&]C=6UE;G0N
M8W)E871E16QE;65N="@G02<I.PH@("`@;&EN:RYH<F5F(#T@)R,G.PH@("`@
M;&EN:RYO;F-L:6-K(#T@9G5N8W1I;VXH*0H@("`@>PH@("`@("`@('9A<B!N
M97=-;VYT:"`](&-U<G)E;G1$871E+F=E=$UO;G1H*"D@+2`Q.PH@("`@("`@
M('9A<B!N97=996%R(#T@8W5R<F5N=%EE87(["B`@("`@("`@:68@*&YE=TUO
M;G1H(#T]("TQ*2!["B`@("`@("`@("`@(&YE=TUO;G1H(#T@,3$["B`@("`@
M("`@("`@(&YE=UEE87(@+3T@,3L*("`@("`@("!]"B`@("`@("`@;F5W1&%T
M92`](&YE=R!$871E*&YE=UEE87(L(&YE=TUO;G1H+"`Q*3L*("`@("`@("!O
M<&5N1V]T;RAN97=$871E+F=E=%1I;64H*2P@:6UG260L(&-U<G)E;G1487)G
M970L(&-A;&QB86-K*3L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"B`@
M("!C96QL+F%P<&5N9$-H:6QD*&QI;FLI.PH@("`@:6UG(#T@9&]C=6UE;G0N
M8W)E871E16QE;65N="@G24U')RD*("`@(&EM9RYS<F,@/2`G/#]P:'`@96-H
M;R`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H)VAO<F1E)RD@
M/SXO;F%V+VQE9G0N<&YG)SL*("`@(&EM9RYA;&EG;B`]("=M:61D;&4G.PH@
M("`@:6UG+F)O<F1E<B`](#`["B`@("!L:6YK+F%P<&5N9$-H:6QD*&EM9RD[
M"B`@("!R;W<N87!P96YD0VAI;&0H8V5L;"D["@H@("`@8V5L;"`](&1O8W5M
M96YT+F-R96%T945L96UE;G0H)U1$)RD["B`@("!C96QL+F-O;%-P86X@/2`U
M.PH@("`@8V5L;"YA;&EG;B`]("=C96YT97(G.PH@("`@=F%R(&T@/2!D;V-U
M;65N="YC<F5A=&5497AT3F]D92AM;VYT:'-;;6]N=&A=*3L*("`@(&-E;&PN
M87!P96YD0VAI;&0H;2D["B`@("!R;W<N87!P96YD0VAI;&0H8V5L;"D["@H@
M("`@8V5L;"`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U1$)RD["B`@("!C
M96QL+F%L:6=N(#T@)W)I9VAT)SL*("`@(&QI;FL@/2!D;V-U;65N="YC<F5A
M=&5%;&5M96YT*"=!)RD["B`@("!L:6YK+FAR968@/2`G(R<["B`@("!L:6YK
M+F]N8VQI8VL@/2!F=6YC=&EO;B@I"B`@("!["B`@("`@("`@;F5W1&%T92`]
M(&YE=R!$871E*&-U<G)E;G1996%R+"!C=7)R96YT1&%T92YG971-;VYT:"@I
M("L@,2P@,2D["B`@("`@("`@;W!E;D=O=&\H;F5W1&%T92YG9714:6UE*"DL
M(&EM9TED+"!C=7)R96YT5&%R9V5T+"!C86QL8F%C:RD["B`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@?0H@("`@8V5L;"YA<'!E;F1#:&EL9"AL:6YK*3L*
M("`@(&EM9R`](&1O8W5M96YT+F-R96%T945L96UE;G0H)TE-1R<I"B`@("!I
M;6<N<W)C(#T@)SP_<&AP(&5C:&\@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E
M=$EM86=E1&ER*"=H;W)D92<I(#\^+VYA=B]R:6=H="YP;F<G.PH@("`@:6UG
M+F%L:6=N(#T@)VUI9&1L92<["B`@("!I;6<N8F]R9&5R(#T@,#L*("`@(&QI
M;FLN87!P96YD0VAI;&0H:6UG*3L*("`@(')O=RYA<'!E;F1#:&EL9"AC96QL
M*3L*("`@('1B;V1Y+F%P<&5N9$-H:6QD*')O=RD["@H@("`@+R\@5V5E:V1A
M>7,N"B`@("!R;W<@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=44B<I.PH@
M("`@9F]R("AV87(@:2`](#`[(&D@/"`W.R!I*RLI('L*("`@("`@("!C96QL
M(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G5$0G*3L*("`@("`@("!W965K
M9&%Y(#T@9&]C=6UE;G0N8W)E871E5&5X=$YO9&4H=V1A>7-;:5TI.PH@("`@
M("`@(&-E;&PN87!P96YD0VAI;&0H=V5E:V1A>2D["B`@("`@("`@<F]W+F%P
M<&5N9$-H:6QD*&-E;&PI.PH@("`@?0H@("`@=&)O9'DN87!P96YD0VAI;&0H
M<F]W*3L*"B`@("`O+R!2;W=S+@H@("`@=F%R('=E96LL(&ET86QI8SL*("`@
M('9A<B!C;W5N="`](#$["B`@("!V87(@=&]D87D@/2!N97<@1&%T92@I.PH@
M("`@=F%R('1H:7-996%R(#T@=&]D87DN9V5T665A<B@I.PH@("`@:68@*'1H
M:7-996%R(#P@,3DP,"D@>PH@("`@("`@('1H:7-996%R("L](#$Y,#`["B`@
M("!]"@H@("`@=F%R(&]D9"`]('1R=64["B`@("!F;W(@*'9A<B!I(#T@,3L@
M:2`\/2!D87ES.R!I*RLI('L*("`@("`@("!I9B`H8V]U;G0@/3T@,2D@>PH@
M("`@("`@("`@("!R;W<@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=44B<I
M.PH@("`@("`@("`@("!R;W<N86QI9VX@/2`G<FEG:'0G.PH@("`@("`@("`@
M("!I9B`H;V1D*2!["B`@("`@("`@("`@("`@("!R;W<N8VQA<W-.86UE(#T@
M)VET96TP)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M(')O=RYC;&%S<TYA;64@/2`G:71E;3$G.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&]D9"`]("%O9&0["B`@("`@("`@?0H@("`@("`@(&EF("AI(#T]
M(#$I('L*("`@("`@("`@("`@9F]R("AV87(@:B`](#`[(&H@/"!D:69F.R!J
M*RLI('L*("`@("`@("`@("`@("`@(&-E;&P@/2!D;V-U;65N="YC<F5A=&5%
M;&5M96YT*"=41"<I.PH@("`@("`@("`@("`@("`@<F]W+F%P<&5N9$-H:6QD
M*&-E;&PI.PH@("`@("`@("`@("`@("`@8V]U;G0K*SL*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!C96QL(#T@9&]C=6UE;G0N8W)E871E16QE
M;65N="@G5$0G*3L*("`@("`@("!I9B`H=&AI<UEE87(@/3T@8W5R<F5N=%EE
M87(@)B8*("`@("`@("`@("`@=&]D87DN9V5T36]N=&@H*2`]/2!M;VYT:"`F
M)@H@("`@("`@("`@("!T;V1A>2YG971$871E*"D@/3T@:2D@>PH@("`@("`@
M("`@("!C96QL+G-T>6QE+F)O<F1E<B`]("<Q<'@@<V]L:60@<F5D)SL*("`@
M("`@("!]"@H@("`@("`@(&QI;FL@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT
M*"=!)RD["B`@("`@("`@8V5L;"YA<'!E;F1#:&EL9"AL:6YK*3L*"B`@("`@
M("`@;&EN:RYH<F5F(#T@:3L*("`@("`@("!L:6YK+F]N8VQI8VL@/2!F=6YC
M=&EO;B@I"B`@("`@("`@>PH@("`@("`@("`@("!V87(@9&%Y(#T@=&AI<RYH
M<F5F.PH@("`@("`@("`@("!W:&EL92`H9&%Y+FEN9&5X3V8H)R\G*2`A/2`M
M,2D@>PH@("`@("`@("`@("`@("`@9&%Y(#T@9&%Y+G-U8G-T<FEN9RAD87DN
M:6YD97A/9B@G+R<I("L@,2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M('-E=%-E;&5C=%9A;'5E*&1O8W5M96YT+F=E=$5L96UE;G1">4ED*&-U<G)E
M;G1487)G970@*R`G6WEE87)=)RDL(&-U<G)E;G1996%R*3L*("`@("`@("`@
M("`@<V5T4V5L96-T5F%L=64H9&]C=6UE;G0N9V5T16QE;65N=$)Y260H8W5R
M<F5N=%1A<F=E="`K("=;;6]N=&A=)RDL(&-U<G)E;G1$871E+F=E=$UO;G1H
M*"D@*R`Q*3L*("`@("`@("`@("`@<V5T4V5L96-T5F%L=64H9&]C=6UE;G0N
M9V5T16QE;65N=$)Y260H8W5R<F5N=%1A<F=E="`K("=;9&%Y72<I+"!D87DI
M.PH*("`@("`@("`@("`@=F%R(&QA>65R(#T@9&]C=6UE;G0N9V5T16QE;65N
M=$)Y260H)V=O=&\G*3L*("`@("`@("`@("`@;&%Y97(N<W1Y;&4N=FES:6)I
M;&ET>2`]("=H:61D96XG.PH@("`@("`@("`@("!I9B`H;&%Y97(N9FER<W1#
M:&EL9"D@>PH@("`@("`@("`@("`@("`@;&%Y97(N<F5M;W9E0VAI;&0H;&%Y
M97(N9FER<W1#:&EL9"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF
M("AC86QL8F%C:RD@>PH@("`@("`@("`@("`@("`@979A;"AC86QL8F%C:RD[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@(&1A>2`](&1O8W5M96YT+F-R96%T951E>'1.;V1E
M*&DI.PH@("`@("`@(&QI;FLN87!P96YD0VAI;&0H9&%Y*3L*"B`@("`@("`@
M<F]W+F%P<&5N9$-H:6QD*&-E;&PI.PH@("`@("`@(&EF("AC;W5N="`]/2`W
M*2!["B`@("`@("`@("`@('1B;V1Y+F%P<&5N9$-H:6QD*')O=RD["B`@("`@
M("`@("`@(&-O=6YT(#T@,#L*("`@("`@("!]"B`@("`@("`@8V]U;G0K*SL*
M("`@('T*("`@(&EF("AC;W5N="`^(#$I('L*("`@("`@("!F;W(@*&D@/2!C
M;W5N=#L@:2`\/2`W.R!I*RLI('L*("`@("`@("`@("`@8V5L;"`](&1O8W5M
M96YT+F-R96%T945L96UE;G0H)U1$)RD["B`@("`@("`@("`@(')O=RYA<'!E
M;F1#:&EL9"AC96QL*3L*("`@("`@("!]"B`@("`@("`@=&)O9'DN87!P96YD
M0VAI;&0H<F]W*3L*("`@('T*"B`@("!I9B`H8W5R26UG260@(3T@:6UG260I
M('L*("`@("`@("`O+R!792=R92!S:&]W:6YG('1H:7,@<&]P=7`@9F]R('1H
M92!F:7)S="!T:6UE+"!S;R!T<GD@=&\*("`@("`@("`O+R!P;W-I=&EO;B!I
M="!N97AT('1O('1H92!I;6%G92!A;F-H;W(N"B`@("`@("`@=F%R(&5L(#T@
M9&]C=6UE;G0N9V5T16QE;65N=$)Y260H:6UG260I.PH@("`@("`@('9A<B!P
M(#T@9V5T06)S;VQU=&50;W-I=&EO;BAE;"D["@H@("`@("`@(&QA>65R+G-T
M>6QE+FQE9G0@/2!P+G@@*R`G<'@G.PH@("`@("`@(&QA>65R+G-T>6QE+G1O
M<"`]('`N>2`K("=P>"<["B`@("!]"@H@("`@8W5R26UG260@/2!I;6=)9#L*
M("`@(&QA>65R+F%P<&5N9$-H:6QD*'1A8FQE*3L*"B`@("!L87EE<BYS='EL
M92YD:7-P;&%Y(#T@)V)L;V-K)SL*("`@(&QA>65R+G-T>6QE+G9I<VEB:6QI
M='D@/2`G=FES:6)L92<["GT*"F9U;F-T:6]N(&=E=$%B<V]L=71E4&]S:71I
M;VXH96PI"GL*("`@('9A<B!R(#T@>W@Z(&5L+F]F9G-E=$QE9G0L('DZ(&5L
M+F]F9G-E=%1O<'T["B`@("!I9B`H96PN;V9F<V5T4&%R96YT*2!["B`@("`@
M("`@=F%R('1M<"`](&=E=$%B<V]L=71E4&]S:71I;VXH96PN;V9F<V5T4&%R
M96YT*3L*("`@("`@("!R+G@@*ST@=&UP+G@["B`@("`@("`@<BYY("L]('1M
M<"YY.PH@("`@?0H@("`@<F5T=7)N('(["GT*"F9U;F-T:6]N('-E=%-E;&5C
M=%9A;'5E*'-E;&5C="P@=F%L=64I"GL*("`@('-E;&5C="YV86QU92`]('9A
M;'5E.PH@("`@:68@*'-E;&5C="YV86QU92`A/2!V86QU92D@>PH@("`@("`@
M(&9O<B`H:2`](#`[(&D@/"!S96QE8W0N;W!T:6]N<RYL96YG=&@[(&DK*RD@
M>PH@("`@("`@("`@("!I9B`H<V5L96-T+F]P=&EO;G-;:5TN=F%L=64@/3T@
M=F%L=64I('L*("`@("`@("`@("`@("`@('-E;&5C="YS96QE8W1E9$EN9&5X
M(#T@:3L*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@?0H*("`@(')E='5R;B!F86QS93L*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?9V]O9VQE7W=I;BYJ
M<P``````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(R-#4`,3`U,34T,S,W-C``,#(U-3,S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````&9U
M;F-T:6]N(&]P96Y?9V]O9VQE7W=I;BAA<F=S*0I["B`@("!V87(@=F%L+"!U
M<FP@/2`G)SL*"B`@("!F;W(@*'9A<B!I(#T@,#L@:2`\(&1O8W5M96YT+F=O
M;V=L92YA<F5A+FQE;F=T:#L@:2LK*2!["B`@("`@("`@:68@*&1O8W5M96YT
M+F=O;V=L92YA<F5A6VE=+F-H96-K960I('L*("`@("`@("`@("`@=F%L(#T@
M9&]C=6UE;G0N9V]O9VQE+F%R96%;:5TN=F%L=64["B`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@('T*("`@('T*"B`@("!S=VET8V@@*'9A;"D@>PH)8V%S
M92`G=V5B)SH*("`@(`EU<FP@/2`G:'1T<#HO+W=W=RYG;V]G;&4N8V]M+W-E
M87)C:#\G.PH)("`@(&)R96%K.PH*"6-A<V4@)VEM86=E<R<Z"@D@("`@=7)L
M(#T@)VAT='`Z+R]I;6%G97,N9V]O9VQE+F-O;2]I;6%G97,_)SL*("`@("`@
M("!B<F5A:SL*"@EC87-E("=G<F]U<',G.@H)("`@('5R;"`]("=H='1P.B\O
M9W)O=7!S+F=O;V=L92YC;VTO9W)O=7!S/R<["B`@("`@("`@8G)E86L["@H)
M8V%S92`G9&ER96-T;W)Y)SH*"2`@("!U<FP@/2`G:'1T<#HO+W=W=RYG;V]G
M;&4N8V]M+W-E87)C:#]C870]9W=D)3)&5&]P)B<["B`@("`@("`@8G)E86L[
M"@H)8V%S92`G;F5W<R<Z"@D@("`@=7)L(#T@)VAT='`Z+R]N97=S+F=O;V=L
M92YC;VTO;F5W<S\G.PH@("`@("`@(&)R96%K.PH*"61E9F%U;'0Z"B`@("`)
M=7)L(#T@)VAT='`Z+R]W=W<N9V]O9VQE+F-O;2]S96%R8V@_)SL*("`@('T*
M("`@('5R;"`K/2`G<3TG.PH@("`@:68@*'1Y<&5O9B!E;F-O9&554DE#;VUP
M;VYE;G0@/3T@)W5N9&5F:6YE9"<I('L*("`@("`@("!U<FP@*ST@97-C87!E
M*&1O8W5M96YT+F=O;V=L92YQ+G9A;'5E*3L*("`@('T@96QS92!["B`@("`@
M("`@=7)L("L](&5N8V]D955224-O;7!O;F5N="AD;V-U;65N="YG;V]G;&4N
M<2YV86QU92D["B`@("!]"@H@("`@=F%R(&YA;64@/2`G1V]O9VQE)SL*("`@
M('9A<B!P87)A;2`]("=T;V]L8F%R/7EE<RQL;V-A=&EO;CUY97,L<W1A='5S
M/7EE<RQS8W)O;&QB87)S/7EE<RQR97-I>F%B;&4]>65S+'=I9'1H/3@P,"QH
M96EG:'0]-C`P+&QE9G0],"QT;W`],"<["@H@("`@979A;"@G;F%M92`]('=I
M;F1O=RYO<&5N*'5R;"P@;F%M92P@<&%R86TI)RD["B`@("!I9B`H(65V86PH
M)VYA;64N;W!E;F5R)RDI('L*("`@("`@("!E=F%L*"=N86UE+F]P96YE<B`]
M('-E;&8G*3L*("`@('T*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]H=&UL7VAE;'!E<BYJ<P``````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M-#$T-P`Q,#4Q-30S,S<V,``P,C4W,3``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+RHJ"B`J($AO<F1E($AT;6P@2&5L<&5R
M($IA=F%S8W)I<'0@0VQA<W,*("H*("H@4')O=FED97,@=&AE(&IA=F%S8W)I
M<'0@8VQA<W,@:6YS97)T(&AT;6P@=&%G<R!B>2!C;&EC:VEN9R!O;B!I8V]N
M<RX*("H*("H@5&AE(&AE;'!E<G,@879A:6QA8FQE.@H@*B`@("`@(&5M;W1I
M8V]N<R`M(&9O<B!I;G-E<G1I;F<@96UO=&EC;VYS('-T<FEN9W,*("H*("H@
M)$AO<F1E.B!H;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7VAT;6Q?
M:&5L<&5R+FIS+'8@,2XQ,BXR+C4@,C`P-B\P-2\Q,2`Q.3HT.3HQ-"!C:'5C
M:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI
M8R`\;6%R:V]`;V)L;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B!)9B!Y
M;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*("H*("H@0&%U=&AO<B!-
M87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`<&%C:V%G92!H;W)D
M90H@*B!`=&]D;R!A9&0@:&%N9&QI;F<@9F]R(&9O;G0@=&%G<RP@=&%B;&5S
M+"!E=&,N"B`J+PH*=F%R('1A<F=E=$5L96UE;G0["@IF=6YC=&EO;B!O<&5N
M2'1M;$AE;'!E<BAT>7!E+"!T87)G970I"GL*("`@('9A<B!L87D@/2!D;V-U
M;65N="YG971%;&5M96YT0GE)9"@G:'1M;&AE;'!E<E\G("L@=&%R9V5T*3L*
M("`@('1A<F=E=$5L96UE;G0@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"AT
M87)G970I.PH*("`@(&EF("AL87DN<W1Y;&4N9&ES<&QA>2`]/2`G8FQO8VLG
M*2!["B`@("`@("`@;&%Y+G-T>6QE+F1I<W!L87D@/2`G;F]N92<["B`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@(&EF("AL87DN9FER<W1#:&EL
M9"D@>PH@("`@("`@(&QA>2YR96UO=F5#:&EL9"AL87DN9FER<W1#:&EL9"D[
M"B`@("!]"@H@("`@=F%R('1A8FQE(#T@9&]C=6UE;G0N8W)E871E16QE;65N
M="@G5$%"3$4G*3L*("`@('9A<B!T8F]D>2`](&1O8W5M96YT+F-R96%T945L
M96UE;G0H)U1"3T19)RD["B`@("!T86)L92YA<'!E;F1#:&EL9"AT8F]D>2D[
M"B`@("!T86)L92YC96QL4W!A8VEN9R`](#`["B`@("!T86)L92YB;W)D97(@
M/2`P.PH*("`@(&EF("AT>7!E(#T]("=E;6]T:6-O;G,G*2!["B`@("`@("`@
M<F]W(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G5%(G*3L*("`@("`@("!C
M96QL(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G5$0G*3L*("`@("`@("`\
M/W!H<"!R97%U:7)E7V]N8V4@)TAO<F1E+U1E>'0O1FEL=&5R+G!H<"<[("1F
M:6QT97(@/2!497AT7T9I;'1E<CHZ9F%C=&]R>2@G96UO=&EC;VYS)RD[("1I
M8V]N<R`](&%R<F%Y7V9L:7`H)&9I;'1E<BT^9V5T26-O;G,H*2D[(&9O<F5A
M8V@@*"1I8V]N<R!A<R`D:6-O;B`]/B`D<W1R:6YG*3H@/SX*("`@("`@("!L
M:6YK(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G02<I.PH@("`@("`@(&QI
M;FLN:')E9B`]("<C)SL*("`@("`@("!L:6YK+F]N8VQI8VL@/2!F=6YC=&EO
M;B@I('L*("`@("`@("`@("`@=&%R9V5T16QE;65N="YV86QU92`]('1A<F=E
M=$5L96UE;G0N=F%L=64@*R`G/#]P:'`@96-H;R`D<W1R:6YG(#\^)R`K("<@
M)SL*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@
M("!C96QL+F%P<&5N9$-H:6QD*&QI;FLI.PH@("`@("`@(&EM9R`](&1O8W5M
M96YT+F-R96%T945L96UE;G0H)TE-1R<I"B`@("`@("`@:6UG+G-R8R`]("<\
M/W!H<"!E8VAO("1'3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G941I<B@G
M:&]R9&4G*2`N("<O96UO=&EC;VYS+R<@+B`D:6-O;B`N("<N<&YG)R`_/B<[
M"B`@("`@("`@:6UG+F%L:6=N(#T@)VUI9&1L92<["B`@("`@("`@:6UG+F)O
M<F1E<B`](#`["B`@("`@("`@;&EN:RYA<'!E;F1#:&EL9"AI;6<I.PH@("`@
M("`@(#P_<&AP(&5N9&9O<F5A8V@[(#\^"B`@("`@("`@<F]W+F%P<&5N9$-H
M:6QD*&-E;&PI.PH@("`@("`@('1B;V1Y+F%P<&5N9$-H:6QD*')O=RD["B`@
M("`@("`@=&%B;&4N87!P96YD0VAI;&0H=&)O9'DI.PH@("`@?0H*("`@(&QA
M>2YA<'!E;F1#:&EL9"AT86)L92D["B`@("!L87DN<W1Y;&4N9&ES<&QA>2`]
M("=B;&]C:R<["GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,`````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,S4V,@`Q,#4Q-30S,S<V,``P,C,U,C``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/'-C<FEP="!T>7!E
M/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"@IV87(@9&$@/2`H9&]C=6UE;G0N
M86QL*2`_(#$@.B`P.PIV87(@<'(@/2`H=VEN9&]W+G!R:6YT*2`_(#$@.B`P
M.PIV87(@;6%C(#T@*&YA=FEG871O<BYU<V5R06=E;G0N:6YD97A/9B@B36%C
M(BD@(3T@+3$I.PH*:68@*'=I;F1O=RYA9&1%=F5N=$QI<W1E;F5R*2!["B`@
M("!W:6YD;W<N861D179E;G1,:7-T96YE<B@G;&]A9"<L('!R:6YT5VEN+"!F
M86QS92D["GT@96QS92!I9B`H=VEN9&]W+F%T=&%C:$5V96YT*2!["B`@("!W
M:6YD;W<N871T86-H179E;G0H)V]N;&]A9"<L('!R:6YT5VEN*3L*?2!E;'-E
M(&EF("AW:6YD;W<N;VYL;V%D("$](&YU;&PI('L*("`@('9A<B!O;&1/;DQO
M860@/2!W:6YD;W<N;VYL;V%D.PH@("`@=VEN9&]W+F]N;&]A9"`](&9U;F-T
M:6]N*&4I"B`@("!["B`@("`@("`@;VQD3VY,;V%D*&4I.PH@("`@("`@('!R
M:6YT5VEN*"D["B`@("!].PI](&5L<V4@>PH@("`@=VEN9&]W+F]N;&]A9"`]
M('!R:6YT5VEN.PI]"@IF=6YC=&EO;B!P<FEN=%=I;B@I"GL*("`@(&EF("AP
M<BD@>PH@("`@("`@("\O($Y3-"LL($E%-2L*("`@("`@("!W:6YD;W<N<')I
M;G0H*3L*("`@('T@96QS92!I9B`H(6UA8RD@>PH@("`@("`@("\O($E%,R!A
M;F0@244T(&]N(%!#"B`@("`@("`@5D)P<FEN=%=I;B@I.PH@("`@?2!E;'-E
M('L*("`@("`@("`O+R!E=F5R>71H:6YG(&5L<V4*("`@("`@("!H86YD;&5?
M97)R;W(H*3L*("`@('T*?0H*=VEN9&]W+F]N97)R;W(@/2!H86YD;&5?97)R
M;W(["G=I;F1O=RYO;F%F=&5R<')I;G0@/2!F=6YC=&EO;B@I('MW:6YD;W<N
M8VQO<V4H*7T*"F9U;F-T:6]N(&AA;F1L95]E<G)O<B@I"GL*("`@('=I;F1O
M=RYA;&5R="@G/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(EEO=7(@8G)O=W-E
M<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#
M;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R:6YT+B(I*2`_/B<I.PH@("`@<F5T
M=7)N('1R=64["GT*"FEF("@A<'(@)B8@(6UA8RD@>PH@("`@:68@*&1A*2![
M"B`@("`@("`@+R\@5&AI<R!M=7-T(&)E($E%-"!O<B!G<F5A=&5R"B`@("`@
M("`@=V)V97)S(#T@(C@X-39&.38Q+3,T,$$M,3%$,"U!.39"+3`P0S`T1D0W
M,#5!,B(["B`@("!](&5L<V4@>PH@("`@("`@("\O('1H:7,@;75S="!B92!)
M13,N>`H@("`@("`@('=B=F5R<R`](")%04(R,D%#,RTS,$,Q+3$Q0T8M03=%
M0BTP,#`P0S`U0D%%,$(B.PH@("`@?0H*("`@(&1O8W5M96YT+G=R:71E*"(\
M3T)*14-4($E$/5PB5T)<(B!724142#U<(C!<(B!(14E'2%0]7"(P7"(@0TQ!
M4U-)1#U<(D-,4TE$.B(I.PH@("`@9&]C=6UE;G0N=W)I=&4H=V)V97)S("L@
M(EPB/B`\+T]"2D5#5#XB*3L*?0H*+R\@+2T^"CPO<V-R:7!T/@H*/'-C<FEP
M="!T>7!E/2)T97AT+W9B<V-R:7!T(CX*/"$M+0H*<W5B('=I;F1O=U]O;G5N
M;&]A9`H@("`@;VX@97)R;W(@<F5S=6UE(&YE>'0*("`@("<@2G5S="!T:61Y
M('5P('=H96X@=V4@;&5A=F4@=&\@8F4@<W5R92!W92!A<F5N)W0*("`@("<@
M:V5E<&EN9R!I;G-T86YC97,@;V8@=&AE(&)R;W=S97(@8V]N=')O;"!I;B!M
M96UO<GD*("`@('-E="!70B`](&YO=&AI;F<*96YD('-U8@H*<W5B(%9"<')I
M;G17:6X*("`@($],14--1$E$7U!224Y4(#T@-@H@("`@;VX@97)R;W(@<F5S
M=6UE(&YE>'0*"B`@("`G($E%-"!O8FIE8W0@:&%S(&$@9&EF9F5R96YT(&-O
M;6UA;F0@<W1R=6-T=7)E"B`@("!I9B!D82!T:&5N"B`@("`@("`@8V%L;"!7
M0BY%>&5C5T(H3TQ%0TU$241?4%))3E0L(#$I"B`@("!E;'-E"B`@("`@("`@
M8V%L;"!70BY)3VQE0V]M;6%N9%1A<F=E="Y%>&5C*$],14--1$E$7U!224Y4
M+"`Q+"`B(BP@(B(I"B`@("!E;F0@:68*96YD('-U8@H*)R`M+3X*/"]S8W)I
M<'0^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E
M<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#$U-S8`,3`U,34T,S,W-C``,#(T-C8R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"\J*@H@*B`D2&]R9&4Z(&AO
M<F1E+W1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS+'8@,2XU
M(#(P,#0O,#@O,C8@,#`Z,#<Z,CD@<VQU<V%R>B!%>'`@)`H@*@H@*B!`<&%C
M:V%G92!(;W)D90H@*B\*9G5N8W1I;VX@=&]G9VQE475O=&5";&]C:RAI9"P@
M;&EN97,I"GL*("`@('9A<B!B;&]C:R`](&YE=R!(;W)D95](:61E86)L92@G
M<6)?)R`K(&ED*3L*"B`@("!B;&]C:RYT;V=G;&4H*3L*("`@('1E>'0@/2!D
M;V-U;65N="YC<F5A=&5497AT3F]D92AB;&]C:RYS:&]W;B@I(#\*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G/#]P:'`@96-H;R!?*");
M2&ED92!1=6]T960@5&5X=%TB*2`_/B<@.@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("<\/W!H<"!E8VAO(%\H(EM3:&]W(%%U;W1E9"!4
M97AT("TB*2`_/B`G("L@;&EN97,@*R`G(#P_<&AP(&5C:&\@7R@B;&EN97-=
M(BD@/SXG*3L*("`@(&QI;FL@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=!
M)RD["B`@("!L:6YK+FAR968@/2`G)SL*("`@(&QI;FLN8VQA<W-.86UE(#T@
M)W=I9&=E="<["B`@("!L:6YK+G-T>6QE+F9O;G13:7IE(#T@)S<P)2<["B`@
M("!L:6YK+F]N8VQI8VL@/2!F=6YC=&EO;B@I('L*("`@("`@("!T;V=G;&51
M=6]T94)L;V-K*&ED+"!L:6YE<RD["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@?0H@("`@;&EN:RYA<'!E;F1#:&EL9"AT97AT*3L*"B`@("!V87(@=&]G
M9VQE(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)W%T7R<@*R!I9"D["B`@
M("!I9B`H=&]G9VQE+F9I<G-T0VAI;&0I('L*("`@("`@("!T;V=G;&4N<F5M
M;W9E0VAI;&0H=&]G9VQE+F9I<G-T0VAI;&0I.PH@("`@?0H@("`@=&]G9VQE
M+F%P<&5N9$-H:6QD*&QI;FLI.PI]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E
M;7!L871E<R]J879A<V-R:7!T+W1R964N:G,`````````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P-3`T-#0`,3`U,34T,S,W-C``,#(S,S(T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"\J*@H@*B!(;W)D
M92!4<F5E($IA=F%S8W)I<'0@0VQA<W,*("H*("H@4')O=FED97,@=&AE(&IA
M=F%S8W)I<'0@8VQA<W,@=&\@8W)E871E(&1Y;F%M:6,@=')E97,N"B`J"B`J
M($-O<'ER:6=H="`R,#`S+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO
M+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN($EF('EO=2!D:60@;F]T"B`J
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+V=P;"YH=&UL+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+W1E;7!L871E
M<R]J879A<V-R:7!T+W1R964N:G,L=B`Q+C8R+C(N,3$@,C`P-B\P,2\P,2`R
M,3HR.3HQ-2!J86X@17AP("0*("H*("H@0&%U=&AO<B`@36%R:V\@1&IU:VEC
M(#QM87)K;T!O8FQO+F-O;3X*("H@0'!A8VMA9V4@2&]R9&5?5')E90H@*B!`
M<VEN8V4@("!(;W)D92`S+C`*("HO"F9U;F-T:6]N($AO<F1E7U1R964H:6YS
M=&%N8V5.86UE*0I["B`@("`O*B!3970@=7`@=&AI<R!C;&%S<R!I;G-T86YC
M92!F;W(@9G5N8W1I;VX@8V%L;',@9G)O;2!T:&4@<&%G92X@*B\*("`@('1H
M:7,N7VEN<W1A;F-E3F%M92`](&EN<W1A;F-E3F%M93L*"B`@("`O*B!);6%G
M92!V87)I86)L97,N("HO"B`@("!T:&ES+FEM9T1I<B`@("`@("`@(#T@)SP_
M<&AP(&5C:&\@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER*"=H
M;W)D92<I("X@)R]T<F5E)SL@/SXG.PH@("`@=&AI<RYI;6=";&%N:R`@("`@
M("`]("=B;&%N:RYP;F<G.PH@("`@=&AI<RYI;6=&;VQD97(@("`@("`]("=F
M;VQD97(N<&YG)SL*("`@('1H:7,N:6UG1F]L9&5R3W!E;B`@/2`G9F]L9&5R
M;W!E;BYP;F<G.PH*("`@("\J(%9A<FEA8FQE<R!T:&%T(&-H86YG92!B87-E
M9"!O;B!T97AT(&1I<F5C=&EO;BX@*B\*/#]P:'`@:68@*&5M<'1Y*"1'3$]"
M04Q36R=N;',G75LG<G1L)UU;)$=,3T)!3%-;)VQA;F=U86=E)UU=*2DZ(#\^
M"B`@("!T:&ES+F9L;V%T1&ER("`@("`@(#T@)V9L;V%T.FQE9G0[)SL*("`@
M('1H:7,N:6UG3&EN92`@("`@("`@/2`G;&EN92YP;F<G.PH@("`@=&AI<RYI
M;6=*;VEN("`@("`@("`]("=J;VEN+G!N9R<["B`@("!T:&ES+FEM9TIO:6Y"
M;W1T;VT@(#T@)VIO:6YB;W1T;VTN<&YG)SL*("`@('1H:7,N:6UG4&QU<R`@
M("`@("`@/2`G<&QU<RYP;F<G.PH@("`@=&AI<RYI;6=0;'5S0F]T=&]M("`]
M("=P;'5S8F]T=&]M+G!N9R<["B`@("!T:&ES+FEM9U!L=7-/;FQY("`@(#T@
M)W!L=7-O;FQY+G!N9R<["B`@("!T:&ES+FEM9TUI;G5S("`@("`@(#T@)VUI
M;G5S+G!N9R<["B`@("!T:&ES+FEM9TUI;G5S0F]T=&]M(#T@)VUI;G5S8F]T
M=&]M+G!N9R<["B`@("!T:&ES+FEM9TUI;G5S3VYL>2`@(#T@)VUI;G5S;VYL
M>2YP;F<G.PH@("`@=&AI<RYI;6=.=6QL3VYL>2`@("`]("=N=6QL;VYL>2YP
M;F<G.PH@("`@=&AI<RYI;6=,96%F("`@("`@("`]("=L96%F+G!N9R<["CP_
M<&AP(&5L<V4Z(#\^"B`@("!T:&ES+F9L;V%T1&ER("`@("`@(#T@)V9L;V%T
M.G)I9VAT.R<["B`@("!T:&ES+FEM9TQI;F4@("`@("`@(#T@)W)E=BUL:6YE
M+G!N9R<["B`@("!T:&ES+FEM9TIO:6X@("`@("`@(#T@)W)E=BUJ;VEN+G!N
M9R<["B`@("!T:&ES+FEM9TIO:6Y";W1T;VT@(#T@)W)E=BUJ;VEN8F]T=&]M
M+G!N9R<["B`@("!T:&ES+FEM9U!L=7,@("`@("`@(#T@)W)E=BUP;'5S+G!N
M9R<["B`@("!T:&ES+FEM9U!L=7-";W1T;VT@(#T@)W)E=BUP;'5S8F]T=&]M
M+G!N9R<["B`@("!T:&ES+FEM9U!L=7-/;FQY("`@(#T@)W)E=BUP;'5S;VYL
M>2YP;F<G.PH@("`@=&AI<RYI;6=-:6YU<R`@("`@("`]("=R978M;6EN=7,N
M<&YG)SL*("`@('1H:7,N:6UG36EN=7-";W1T;VT@/2`G<F5V+6UI;G5S8F]T
M=&]M+G!N9R<["B`@("!T:&ES+FEM9TUI;G5S3VYL>2`@(#T@)W)E=BUM:6YU
M<V]N;'DN<&YG)SL*("`@('1H:7,N:6UG3G5L;$]N;'D@("`@/2`G<F5V+6YU
M;&QO;FQY+G!N9R<["B`@("!T:&ES+FEM9TQE868@("`@("`@(#T@)W)E=BUL
M96%F+G!N9R<["CP_<&AP(&5N9&EF.R`_/@H*("`@("\J(%1R964@8G5I;&1I
M;F<@=F%R:6%B;&5S+B`J+PH@("`@=&AI<RYR96YD97)3=&%T:6,@("`](&9A
M;'-E.PH@("`@=&AI<RYT87)G970@("`@("`@("`]("<G.PH@("`@=&AI<RYH
M96%D97(@("`@("`@("`](&YE=R!!<G)A>2@I.PH@("`@=&AI<RYR;V]T3F]D
M97,@("`@("`](&YE=R!!<G)A>2@I.PH@("`@=&AI<RYN;V1E<R`@("`@("`@
M("`](&YE=R!!<G)A>2@I.PH@("`@=&AI<RYN;V1E7W!O<R`@("`@("`](&YE
M=R!!<G)A>2@I.PH@("`@=&AI<RYD<F]P;&EN92`@("`@("`](&YE=R!!<G)A
M>2@I.PH@("`@=&AI<RYO=71P=70@("`@("`@("`]("<G.PI]"@I(;W)D95]4
M<F5E+G!R;W1O='EP92YS971);6=$:7(@/2!F=6YC=&EO;BAI;6=$:7(I"GL*
M("`@('1H:7,N:6UG1&ER(#T@:6UG1&ER.PI]"@I(;W)D95]4<F5E+G!R;W1O
M='EP92YR96YD97)4<F5E(#T@9G5N8W1I;VXH<F]O=$YO9&5S+"!R96YD97)3
M=&%T:6,I"GL*("`@('1H:7,N<F]O=$YO9&5S(#T@<F]O=$YO9&5S.PH@("`@
M=&AI<RYR96YD97)3=&%T:6,@/2!R96YD97)3=&%T:6,["B`@("!T:&ES+FYO
M9&5S(#T@979A;"@G;E\G("L@=&AI<RY?:6YS=&%N8V5.86UE*3L*("`@('1H
M:7,N:&5A9&5R(#T@979A;"@G:%\G("L@=&AI<RY?:6YS=&%N8V5.86UE*3L*
M("`@('1H:7,N;W!T:6]N<R`](&5V86PH)V]?)R`K('1H:7,N7VEN<W1A;F-E
M3F%M92D["B`@("!T:&ES+G1A<F=E="`]("=T7R<@*R!T:&ES+E]I;G-T86YC
M94YA;64["B`@("!T:&ES+E]R96YD97)4<F5E*"D["GT*"DAO<F1E7U1R964N
M<')O=&]T>7!E+E]R96YD97)4<F5E(#T@9G5N8W1I;VXH*0I["B`@("!T:&ES
M+F]U='!U="`]("<G.PH@("`@:68@*"%T:&ES+F]P=&EO;G-;)VAI9&5(96%D
M97)S)UTI('L*("`@("`@("!T:&ES+F]U='!U="`]('1H:7,N7V)U:6QD2&5A
M9&5R*"D["B`@("!]"B`@("!F;W(@*'9A<B!I(#T@,#L@:2`\('1H:7,N<F]O
M=$YO9&5S+FQE;F=T:#L@:2LK*2!["B`@("`@("`@=&AI<RYB=6EL9%1R964H
M=&AI<RYR;V]T3F]D97-;:5TI.PH@("`@?0H@("`@9&]C=6UE;G0N9V5T16QE
M;65N=$)Y260H=&AI<RYT87)G970I+FEN;F5R2%1-3"`]('1H:7,N;W5T<'5T
M.PH@("`@=&AI<RY?8V]R<F5C=%=I9'1H1F]R4V-R;VQL8F%R*"D["B`@("`O
M+R!)9B!U<VEN9R!A;'1E<FYA=&EN9R!R;W<@<VAA9&EN9RP@=V]R:R!O=70@
M8V]R<F5C="!S:&%D92X*("`@(&EF("AT:&ES+F]P=&EO;G-;)V%L=&5R;F%T
M92==*2!["B`@("`@("`@=&AI<RYS=')I<&4H*3L*("`@('T*?0H*+RHJ"B`J
M(%)E='5R;G,@=&AE($A434P@8V]D92!F;W(@82!H96%D97(@<F]W+"!I9B!N
M96-E<W-A<GDN"B`J"B`J($!A8V-E<W,@<')I=F%T90H@*@H@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE($A434P@8V]D92!O9B!T:&4@:&5A9&5R(')O=R!O<B!A
M;B!E;7!T>2!S=')I;F<N"B`J+PI(;W)D95]4<F5E+G!R;W1O='EP92Y?8G5I
M;&1(96%D97(@/2!F=6YC=&EO;B@I"GL*("`@(&EF("@A=&AI<RYH96%D97(N
M;&5N9W1H*2!["B`@("`@("`@<F5T=7)N("<G.PH@("`@?0H*("`@('9A<B!H
M=&UL(#T@)SQD:78^)SL*("`@(&9O<B`H=F%R(&D@/2`P.R!I(#P@=&AI<RYH
M96%D97(N;&5N9W1H.R!I*RLI('L*("`@("`@("!H=&UL("L]("<\9&EV)SL*
M("`@("`@("!I9B`H=&AI<RYH96%D97);:5U;)V-L87-S)UTI('L*("`@("`@
M("`@("`@:'1M;"`K/2`G(&-L87-S/2(G("L@=&AI<RYH96%D97);:5U;)V-L
M87-S)UT@*R`G(B<["B`@("`@("`@?0H*("`@("`@("!V87(@<W1Y;&4@/2!T
M:&ES+F9L;V%T1&ER.PH@("`@("`@(&EF("AT:&ES+FAE861E<EMI75LG=VED
M=&@G72D@>PH@("`@("`@("`@("!S='EL92`K/2`G=VED=&@Z)R`K('1H:7,N
M:&5A9&5R6VE=6R=W:61T:"==("L@)SLG.PH@("`@("`@('T*("`@("`@("!I
M9B`H=&AI<RYH96%D97);:5U;)V%L:6=N)UTI('L*("`@("`@("`@("`@<W1Y
M;&4@*ST@)W1E>'0M86QI9VXZ)R`K('1H:7,N:&5A9&5R6VE=6R=A;&EG;B==
M("L@)SLG.PH@("`@("`@('T*"B`@("`@("`@:'1M;"`K/2`G('-T>6QE/2(G
M("L@<W1Y;&4@*R`G(B<["B`@("`@("`@:'1M;"`K/2`G/B<["B`@("`@("`@
M:'1M;"`K/2!T:&ES+FAE861E<EMI75LG:'1M;"==(#\@=&AI<RYH96%D97);
M:5U;)VAT;6PG72`Z("<F;F)S<#LG.PH@("`@("`@(&AT;6P@*ST@)SPO9&EV
M/B<["B`@("!]"@H@("`@<F5T=7)N(&AT;6P@*R`G/"]D:78^)SL*?0H*+RHJ
M"B`J(%)E8W5R<VEV92!F=6YC=&EO;B!T;R!W86QK('1H<F]U9V@@=&AE('1R
M964@87)R87D@86YD(&)U:6QD"B`J('1H92!O=71P=70N"B`J+PI(;W)D95]4
M<F5E+G!R;W1O='EP92YB=6EL9%1R964@/2!F=6YC=&EO;BAN;V1E260I"GL*
M("`@('1H:7,N;W5T<'5T("L]('1H:7,N8G5I;&1,:6YE*&YO9&5)9"D["@H@
M("`@:68@*'1Y<&5O9BAT:&ES+FYO9&5S6VYO9&5)9%U;)V-H:6QD<F5N)UTI
M("$]("=U;F1E9FEN960G*2!["B`@("`@("`@=F%R(&YU;5-U8FYO9&5S(#T@
M=&AI<RYN;V1E<UMN;V1E261=6R=C:&EL9')E;B==+FQE;F=T:#L*("`@("`@
M("!I9B`H;G5M4W5B;F]D97,@/B`P*2!["B`@("`@("`@("`@(&EF("AT:&ES
M+FYO9&5S6VYO9&5)9%U;)V5X<&%N9&5D)UTI('L*("`@("`@("`@("`@("`@
M(')O=U-T>6QE(#T@)V1I<W!L87DZ8FQO8VL[)SL*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@(')O=U-T>6QE(#T@)V1I<W!L87DZ;F]N
M93LG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@('1H:7,N;W5T<'5T("L]
M("<\9&EV(&ED/2)N;V1E0VAI;&1R96Y?)R`K(&YO9&5)9"`K("<B('-T>6QE
M/2(G("L@<F]W4W1Y;&4@*R`G(CXG.PH*("`@("`@("`@("`@9F]R("AV87(@
M8R`](#`[(&,@/"!N=6U3=6)N;V1E<SL@8RLK*2!["B`@("`@("`@("`@("`@
M("!V87(@8VAI;&1.;V1E260@/2!T:&ES+FYO9&5S6VYO9&5)9%U;)V-H:6QD
M<F5N)UU;8UT["B`@("`@("`@("`@("`@("!T:&ES+FYO9&5?<&]S6V-H:6QD
M3F]D94ED72`](&YE=R!!<G)A>2@I.PH@("`@("`@("`@("`@("`@=&AI<RYN
M;V1E7W!O<UMC:&EL9$YO9&5)9%U;)W!O<R==(#T@8R`K(#$["B`@("`@("`@
M("`@("`@("!T:&ES+FYO9&5?<&]S6V-H:6QD3F]D94ED75LG8V]U;G0G72`]
M(&YU;5-U8FYO9&5S.PH@("`@("`@("`@("`@("`@=&AI<RYB=6EL9%1R964H
M8VAI;&1.;V1E260I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!T:&ES
M+F]U='!U="`K/2`G/"]D:78^)SL*("`@("`@("!]"B`@("!]"@H@("`@<F5T
M=7)N('1R=64["GT*"DAO<F1E7U1R964N<')O=&]T>7!E+F)U:6QD3&EN92`]
M(&9U;F-T:6]N*&YO9&5)9"D*>PH@("`@=F%R('-T>6QE(#T@)R<["B`@("!V
M87(@<F]W0VQA<W,@/2`G=')E95)O=R<["B`@("!I9B`H=&AI<RYN;V1E<UMN
M;V1E261=6R=C;&%S<R==*2!["B`@("`@("`@<F]W0VQA<W,@*ST@)R`G("L@
M=&AI<RYN;V1E<UMN;V1E261=6R=C;&%S<R==.PH@("`@?0H*("`@('9A<B!L
M:6YE(#T@)SQD:78@8VQA<W,](B<@*R!R;W=#;&%S<R`K("<B/B<["@H@("`@
M+R\@268@=V4@:&%V92!H96%D97)S+"!T<F%C:R!W:&EC:"!L;V=I8V%L(")C
M;VQU;6XB('=E)W)E(&EN(&9O<@H@("`@+R\@86YY(&=I=F5N(&-E;&P@;V8@
M8V]N=&5N="X*("`@('9A<B!C;VQU;6X@/2`P.PH*("`@(&EF("AT>7!E;V8H
M=&AI<RYN;V1E<UMN;V1E261=6R=E>'1R82==*2`A/2`G=6YD969I;F5D)R`F
M)@H@("`@("`@('1Y<&5O9BAT:&ES+FYO9&5S6VYO9&5)9%U;)V5X=')A)UU;
M,%TI("$]("=U;F1E9FEN960G*2!["B`@("`@("`@=F%R(&5X=')A(#T@=&AI
M<RYN;V1E<UMN;V1E261=6R=E>'1R82==6S!=.PH@("`@("`@(&9O<B`H=F%R
M(&,@/2`P.R!C(#P@97AT<F$N;&5N9W1H.R!C*RLI('L*("`@("`@("`@("`@
M<W1Y;&4@/2!T:&ES+F9L;V%T1&ER.PH@("`@("`@("`@("!I9B`H=&AI<RYH
M96%D97);8V]L=6UN72`F)B!T:&ES+FAE861E<EMC;VQU;6Y=6R=W:61T:"==
M*2!["B`@("`@("`@("`@("`@("!S='EL92`K/2`G=VED=&@Z)R`K('1H:7,N
M:&5A9&5R6V-O;'5M;EU;)W=I9'1H)UT@*R`G.R<["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@;&EN92`K/2`G/&1I=B!S='EL93TB)R`K('-T>6QE("L@
M)R(^)R`K(&5X=')A6V-=("L@)SPO9&EV/B<["B`@("`@("`@("`@(&-O;'5M
M;BLK.PH@("`@("`@('T*("`@("`@("!F;W(@*'9A<B!D(#T@8SL@9"`\(&5X
M=')A0V]L<TQE9G0[(&0K*RD@>PH@("`@("`@("`@("!S='EL92`]('1H:7,N
M9FQO871$:7(["B`@("`@("`@("`@(&EF("AT:&ES+FAE861E<EMC;VQU;6Y=
M("8F('1H:7,N:&5A9&5R6V-O;'5M;EU;)W=I9'1H)UTI('L*("`@("`@("`@
M("`@("`@('-T>6QE("L]("=W:61T:#HG("L@=&AI<RYH96%D97);8V]L=6UN
M75LG=VED=&@G72`K("<[)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!L
M:6YE("L]("<\9&EV('-T>6QE/2(G("L@<W1Y;&4@*R`G(CXF;F)S<#L\+V1I
M=CXG.PH@("`@("`@("`@("!C;VQU;6XK*SL*("`@("`@("!]"B`@("!](&5L
M<V4@>PH@("`@("`@(&9O<B`H=F%R(&,@/2`P.R!C(#P@97AT<F%#;VQS3&5F
M=#L@8RLK*2!["B`@("`@("`@("`@('-T>6QE(#T@=&AI<RYF;&]A=$1I<CL*
M("`@("`@("`@("`@:68@*'1H:7,N:&5A9&5R6V-O;'5M;ET@)B8@=&AI<RYH
M96%D97);8V]L=6UN75LG=VED=&@G72D@>PH@("`@("`@("`@("`@("`@<W1Y
M;&4@*ST@)W=I9'1H.B<@*R!T:&ES+FAE861E<EMC;VQU;6Y=6R=W:61T:"==
M("L@)SLG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&QI;F4@*ST@)SQD
M:78@<W1Y;&4](B<@*R!S='EL92`K("<B/B9N8G-P.SPO9&EV/B<["B`@("`@
M("`@("`@(&-O;'5M;BLK.PH@("`@("`@('T*("`@('T*"B`@("!S='EL92`]
M('1H:7,N9FQO871$:7(["B`@("!I9B`H=&AI<RYH96%D97);8V]L=6UN72`F
M)B!T:&ES+FAE861E<EMC;VQU;6Y=6R=W:61T:"==*2!["B`@("`@("`@<W1Y
M;&4@*ST@)W=I9'1H.B<@*R!T:&ES+FAE861E<EMC;VQU;6Y=6R=W:61T:"==
M("L@)SLG.PH@("`@?0H@("`@;&EN92`K/2`G/&1I=B!S='EL93TB)R`K('-T
M>6QE("L@)R(^)SL*"B`@("!I9B`H=&AI<RYO<'1I;VYS6R=M=6QT:6QI;F4G
M72D@>PH@("`@("`@(&QI;F4@*ST@)SQT86)L92!C96QL<W!A8VEN9STB,"(^
M/'1R/CQT9#XG.PH@("`@?0H*("`@(&9O<B`H=F%R(&D@/2!T:&ES+G)E;F1E
M<E-T871I8R`_(#$@.B`P.R!I(#P@=&AI<RYN;V1E<UMN;V1E261=6R=I;F1E
M;G0G73L@:2LK*2!["B`@("`@("`@:68@*'1H:7,N9')O<&QI;F5;:5T@)B8@
M=&AI<RYO<'1I;VYS6R=L:6YE<R==*2!["B`@("`@("`@("`@(&QI;F4@*ST@
M)SQI;6<@<W)C/2(G("L@=&AI<RYI;6=$:7(@*R`G+R<@*R!T:&ES+FEM9TQI
M;F4@*R`G(B!A;'0](GPF;F)S<#LF;F)S<#LF;F)S<#LB(&AE:6=H=#TB,C`B
M('=I9'1H/2(R,"(@+SXG.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(&QI;F4@*ST@)SQI;6<@<W)C/2(G("L@=&AI<RYI;6=$:7(@*R`G+R<@*R!T
M:&ES+FEM9T)L86YK("L@)R(@86QT/2(F;F)S<#LF;F)S<#LF;F)S<#LB(&AE
M:6=H=#TB,C`B('=I9'1H/2(R,"(@+SXG.PH@("`@("`@('T*("`@('T*("`@
M(&QI;F4@*ST@=&AI<RY?<V5T3F]D951O9V=L92AN;V1E260I.PH@("`@:68@
M*'1H:7,N;W!T:6]N<ULG;75L=&EL:6YE)UTI('L*("`@("`@("!L:6YE("L]
M("<\+W1D/CQT9#XG.PH@("`@?0H@("`@;&EN92`K/2!T:&ES+E]S971,86)E
M;"AN;V1E260I.PH*("`@(&EF("AT:&ES+F]P=&EO;G-;)VUU;'1I;&EN92==
M*2!["B`@("`@("`@;&EN92`K/2`G/"]T9#X\+W1R/CPO=&%B;&4^)SL*("`@
M('T*"B`@("!L:6YE("L]("<\+V1I=CXG.PH@("`@8V]L=6UN*RL["@H@("`@
M:68@*'1Y<&5O9BAT:&ES+FYO9&5S6VYO9&5)9%U;)V5X=')A)UTI("$]("=U
M;F1E9FEN960G("8F"B`@("`@("`@='EP96]F*'1H:7,N;F]D97-;;F]D94ED
M75LG97AT<F$G75LQ72D@(3T@)W5N9&5F:6YE9"<I('L*("`@("`@("!V87(@
M97AT<F$@/2!T:&ES+FYO9&5S6VYO9&5)9%U;)V5X=')A)UU;,5T["B`@("`@
M("`@9F]R("AV87(@8R`](#`[(&,@/"!E>'1R82YL96YG=&@[(&,K*RD@>PH@
M("`@("`@("`@("!S='EL92`]('1H:7,N9FQO871$:7(["B`@("`@("`@("`@
M(&EF("AT:&ES+FAE861E<EMC;VQU;6Y=("8F('1H:7,N:&5A9&5R6V-O;'5M
M;EU;)W=I9'1H)UTI('L*("`@("`@("`@("`@("`@('-T>6QE("L]("=W:61T
M:#HG("L@=&AI<RYH96%D97);8V]L=6UN75LG=VED=&@G72`K("<[)SL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!L:6YE("L]("<\9&EV('-T>6QE/2(G
M("L@<W1Y;&4@*R`G(CXG("L@97AT<F%;8UT@*R`G/"]D:78^)SL*("`@("`@
M("`@("`@8V]L=6UN*RL["B`@("`@("`@?0H@("`@("`@(&9O<B`H=F%R(&0@
M/2!C.R!D(#P@97AT<F%#;VQS4FEG:'0[(&0K*RD@>PH@("`@("`@("`@("!S
M='EL92`]('1H:7,N9FQO871$:7(["B`@("`@("`@("`@(&EF("AT:&ES+FAE
M861E<EMC;VQU;6Y=("8F('1H:7,N:&5A9&5R6V-O;'5M;EU;)W=I9'1H)UTI
M('L*("`@("`@("`@("`@("`@('-T>6QE("L]("=W:61T:#HG("L@=&AI<RYH
M96%D97);8V]L=6UN75LG=VED=&@G72`K("<[)SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!L:6YE("L]("<\9&EV('-T>6QE/2(G("L@<W1Y;&4@*R`G
M(CXF;F)S<#L\+V1I=CXG.PH@("`@("`@("`@("!C;VQU;6XK*SL*("`@("`@
M("!]"B`@("!](&5L<V4@>PH@("`@("`@(&9O<B`H=F%R(&,@/2`P.R!C(#P@
M97AT<F%#;VQS4FEG:'0[(&,K*RD@>PH@("`@("`@("`@("!S='EL92`]('1H
M:7,N9FQO871$:7(["B`@("`@("`@("`@(&EF("AT:&ES+FAE861E<EMC;VQU
M;6Y=("8F('1H:7,N:&5A9&5R6V-O;'5M;EU;)W=I9'1H)UTI('L*("`@("`@
M("`@("`@("`@('-T>6QE("L]("=W:61T:#HG("L@=&AI<RYH96%D97);8V]L
M=6UN75LG=VED=&@G72`K("<[)SL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!L:6YE("L]("<\9&EV('-T>6QE/2(G("L@<W1Y;&4@*R`G(CXF;F)S<#L\
M+V1I=CXG.PH@("`@("`@("`@("!C;VQU;6XK*SL*("`@("`@("!]"B`@("!]
M"B`@("!L:6YE("L]("<\+V1I=CXG.PH*("`@(')E='5R;B!L:6YE.PI]"@I(
M;W)D95]4<F5E+G!R;W1O='EP92Y?<V5T3&%B96P@/2!F=6YC=&EO;BAN;V1E
M260I"GL*("`@(&QA8F5L(#T@=&AI<RYN;V1E<UMN;V1E261=6R=L86)E;"==
M.PH*("`@(&EF("AT:&ES+FYO9&5S6VYO9&5)9%U;)W5R;"==*2!["B`@("`@
M("`@=F%R('5R;$-L87-S(#T@)R<["B`@("`@("`@:68@*'1H:7,N;F]D97-;
M;F]D94ED75LG=7)L8VQA<W,G72D@>PH@("`@("`@("`@("!U<FQ#;&%S<R`]
M("<@8VQA<W,](B<@*R!T:&ES+FYO9&5S6VYO9&5)9%U;)W5R;&-L87-S)UT@
M*R`G(B<["B`@("`@("`@?2!E;'-E(&EF("AT:&ES+F]P=&EO;G-;)W5R;&-L
M87-S)UTI('L*("`@("`@("`@("`@=7)L0VQA<W,@/2`G(&-L87-S/2(G("L@
M=&AI<RYO<'1I;VYS6R=U<FQC;&%S<R==("L@)R(G.PH@("`@("`@('T*"B`@
M("`@("`@=F%R('1A<F=E="`]("<G.PH@("`@("`@(&EF("AT:&ES+FYO9&5S
M6VYO9&5)9%U;)W1A<F=E="==*2!["B`@("`@("`@("`@('1A<F=E="`]("<@
M=&%R9V5T/2(G("L@=&AI<RYN;V1E<UMN;V1E261=6R=T87)G970G72`K("<B
M)SL*("`@("`@("!](&5L<V4@:68@*'1H:7,N;W!T:6]N<ULG=&%R9V5T)UTI
M('L*("`@("`@("`@("`@=&%R9V5T(#T@)R!T87)G970](B<@*R!T:&ES+F]P
M=&EO;G-;)W1A<F=E="==("L@)R(G.PH@("`@("`@('T*"B`@("`@("`@=F%R
M(&]N8VQI8VL@/2`G)SL*("`@("`@("!I9B`H=&AI<RYN;V1E<UMN;V1E261=
M6R=O;F-L:6-K)UTI('L*("`@("`@("`@("`@;VYC;&EC:R`]("<@;VYC;&EC
M:STB)R`K('1H:7,N;F]D97-;;F]D94ED75LG;VYC;&EC:R==("L@)R(G.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("<\82<@*R!U<FQ#;&%S<R`K("<@
M:')E9CTB)R`K('1H:7,N;F]D97-;;F]D94ED75LG=7)L)UT@*R`G(B<@*R!T
M87)G970@*R!O;F-L:6-K("L@)SXG("L@=&AI<RY?<V5T3F]D94EC;VXH;F]D
M94ED*2`K(&QA8F5L("L@)SPO83XG.PH@("`@?2!E;'-E('L*("`@("`@("!R
M971U<FX@)SQS<&%N(&-L87-S/2)T;V=G;&4B(&]N8VQI8VL](B<@*R!T:&ES
M+E]I;G-T86YC94YA;64@*R`G+G1O9V=L92A<)R<@*R!N;V1E260@*R`G7"<I
M(CXG("L@=&AI<RY?<V5T3F]D94EC;VXH;F]D94ED*2`K(&QA8F5L("L@)SPO
M<W!A;CXG.PH@("`@?0I]"@I(;W)D95]4<F5E+G!R;W1O='EP92Y?<V5T3F]D
M951O9V=L92`](&9U;F-T:6]N*&YO9&5)9"D*>PH@("`@=F%R(&%T=')I8B`]
M("<G.PH@("`@:68@*'1H:7,N;F]D97-;;F]D94ED75LG:6YD96YT)UT@/3T@
M)S`G("8F"B`@("`@("`@='EP96]F*'1H:7,N;F]D97-;;F]D94ED75LG8VAI
M;&1R96XG72D@(3T@)W5N9&5F:6YE9"<I('L*("`@("`@("`O+R!4;W`@;&5V
M96P@=VET:"!C:&EL9')E;BX*("`@("`@("!T:&ES+F1R;W!L:6YE6S!=(#T@
M9F%L<V4["B`@("`@("`@:68@*'1H:7,N<F5N9&5R4W1A=&EC*2!["B`@("`@
M("`@("`@(')E='5R;B`G)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!A='1R:6(@/2`G('-T>6QE/2)C=7)S;W(Z<&]I;G1E<B(@;VYC;&EC:STB
M)R`K('1H:7,N7VEN<W1A;F-E3F%M92`K("<N=&]G9VQE*%PG)R`K(&YO9&5)
M9"`K("=<)RDB)SL*("`@("`@("!]"B`@("!](&5L<V4@:68@*'1H:7,N;F]D
M97-;;F]D94ED75LG:6YD96YT)UT@(3T@)S`G("8F"B`@("`@("`@("`@("`@
M('1Y<&5O9BAT:&ES+FYO9&5S6VYO9&5)9%U;)V-H:6QD<F5N)UTI(#T]("=U
M;F1E9FEN960G*2!["B`@("`@("`@+R\@3F]D92!N;R!C:&EL9')E;BX*("`@
M("`@("!I9B`H=&AI<RYN;V1E7W!O<UMN;V1E261=6R=P;W,G72`\('1H:7,N
M;F]D95]P;W-;;F]D94ED75LG8V]U;G0G72D@>PH@("`@("`@("`@("`O+R!.
M;W0@;&%S="!N;V1E+@H@("`@("`@("`@("!T:&ES+F1R;W!L:6YE6W1H:7,N
M;F]D97-;;F]D94ED75LG:6YD96YT)UU=(#T@=')U93L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!T:&ES+F1R;W!L:6YE6W1H:7,N;F]D97-;;F]D
M94ED75LG:6YD96YT)UU=(#T@9F%L<V4["B`@("`@("`@?0H@("`@?2!E;'-E
M(&EF("AT>7!E;V8H=&AI<RYN;V1E<UMN;V1E261=6R=C:&EL9')E;B==*2`A
M/2`G=6YD969I;F5D)RD@>PH@("`@("`@("\O($YO9&4@=VET:"!C:&EL9')E
M;BX*("`@("`@("!I9B`H=&AI<RYN;V1E7W!O<UMN;V1E261=6R=P;W,G72`\
M('1H:7,N;F]D95]P;W-;;F]D94ED75LG8V]U;G0G72D@>PH@("`@("`@("`@
M("`O+R!.;W0@;&%S="!N;V1E+@H@("`@("`@("`@("!T:&ES+F1R;W!L:6YE
M6W1H:7,N;F]D97-;;F]D94ED75LG:6YD96YT)UU=(#T@=')U93L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`O+R!,87-T(&YO9&4N"B`@("`@("`@
M("`@('1H:7,N9')O<&QI;F5;=&AI<RYN;V1E<UMN;V1E261=6R=I;F1E;G0G
M75T@/2!F86QS93L*("`@("`@("!]"B`@("`@("`@:68@*"%T:&ES+G)E;F1E
M<E-T871I8RD@>PH@("`@("`@("`@("!A='1R:6(@/2`G('-T>6QE/2)C=7)S
M;W(Z<&]I;G1E<B(@;VYC;&EC:STB)R`K('1H:7,N7VEN<W1A;F-E3F%M92`K
M("<N=&]G9VQE*%PG)R`K(&YO9&5)9"`K("=<)RDB)SL*("`@("`@("!]"B`@
M("!](&5L<V4@>PH@("`@("`@("\O(%1O<"!L979E;"!N;V1E('=I=&@@;F\@
M8VAI;&1R96XN"B`@("`@("`@:68@*'1H:7,N<F5N9&5R4W1A=&EC*2!["B`@
M("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("!]"B`@("`@("`@=&AI<RYD
M<F]P;&EN95LP72`](&9A;'-E.PH@("`@?0H*("`@(&YO9&54;V=G;&4@/2!T
M:&ES+E]G971.;V1E5&]G9VQE*&YO9&5)9"D["B`@("!I;6<@/2`G/&EM9R!I
M9#TB;F]D951O9V=L95\G("L@;F]D94ED("L@)R(@<W)C/2(G("L@=&AI<RYI
M;6=$:7(@*R`G+R<@*R!N;V1E5&]G9VQE6S!=("L@)R(@)SL*("`@(&EF("AN
M;V1E5&]G9VQE6S%=*2!["B`@("`@("`@:6UG("L]("=A;'0](B<@*R!N;V1E
M5&]G9VQE6S%=("L@)R(@)SL*("`@('T*("`@(&EM9R`K/2!A='1R:6(@*R`G
M(&AE:6=H=#TB,C`B('=I9'1H/2(R,"(@+SXG.PH@("`@<F5T=7)N(&EM9SL*
M?0H*2&]R9&5?5')E92YP<F]T;W1Y<&4N7V=E=$YO9&54;V=G;&4@/2!F=6YC
M=&EO;BAN;V1E260I"GL*("`@('9A<B!N;V1E5&]G9VQE(#T@;F5W($%R<F%Y
M*"<G+"`G)RD["B`@("!I9B`H=&AI<RYN;V1E<UMN;V1E261=6R=I;F1E;G0G
M72`]/2`G,"<@)B8*("`@("`@("!T>7!E;V8H=&AI<RYN;V1E<UMN;V1E261=
M6R=C:&EL9')E;B==*2`A/2`G=6YD969I;F5D)RD@>PH@("`@("`@("\O(%1O
M<"!L979E;"!W:71H(&-H:6QD<F5N+@H@("`@("`@(&EF("AT:&ES+G)E;F1E
M<E-T871I8RD@>PH@("`@("`@("`@("!R971U<FX@;F]D951O9V=L93L*("`@
M("`@("!](&5L<V4@:68@*"%T:&ES+F]P=&EO;G-;)VQI;F5S)UTI('L*("`@
M("`@("`@("`@;F]D951O9V=L95LP72`]('1H:7,N:6UG0FQA;FL["B`@("`@
M("`@("`@(&YO9&54;V=G;&5;,5T@/2`G)FYB<W`[)FYB<W`[)FYB<W`[)PH@
M("`@("`@('T@96QS92!I9B`H=&AI<RYN;V1E<UMN;V1E261=6R=E>'!A;F1E
M9"==*2!["B`@("`@("`@("`@(&YO9&54;V=G;&5;,%T@/2!T:&ES+FEM9TUI
M;G5S3VYL>3L*("`@("`@("`@("`@;F]D951O9V=L95LQ72`]("<M)SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!N;V1E5&]G9VQE6S!=(#T@=&AI
M<RYI;6=0;'5S3VYL>3L*("`@("`@("`@("`@;F]D951O9V=L95LQ72`]("<K
M)SL*("`@("`@("!]"B`@("!](&5L<V4@:68@*'1H:7,N;F]D97-;;F]D94ED
M75LG:6YD96YT)UT@(3T@)S`G("8F"B`@("`@("`@='EP96]F*'1H:7,N;F]D
M97-;;F]D94ED75LG8VAI;&1R96XG72D@/3T@)W5N9&5F:6YE9"<I('L*("`@
M("`@("`O+R!.;V1E(&YO(&-H:6QD<F5N+@H@("`@("`@(&EF("AT:&ES+FYO
M9&5?<&]S6VYO9&5)9%U;)W!O<R==(#P@=&AI<RYN;V1E7W!O<UMN;V1E261=
M6R=C;W5N="==*2!["B`@("`@("`@("`@("\O($YO="!L87-T(&YO9&4N"B`@
M("`@("`@("`@(&EF("AT:&ES+F]P=&EO;G-;)VQI;F5S)UTI('L*("`@("`@
M("`@("`@("`@(&YO9&54;V=G;&5;,%T@/2!T:&ES+FEM9TIO:6X["B`@("`@
M("`@("`@("`@("!N;V1E5&]G9VQE6S%=(#T@)WPM)SL*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@(&YO9&54;V=G;&5;,%T@/2!T:&ES
M+FEM9T)L86YK.PH@("`@("`@("`@("`@("`@;F]D951O9V=L95LQ72`]("<F
M;F)S<#LF;F)S<#LF;F)S<#LG.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@+R\@3&%S="!N;V1E+@H@("`@("`@("`@("!I
M9B`H=&AI<RYO<'1I;VYS6R=L:6YE<R==*2!["B`@("`@("`@("`@("`@("!N
M;V1E5&]G9VQE6S!=(#T@=&AI<RYI;6=*;VEN0F]T=&]M.PH@("`@("`@("`@
M("`@("`@;F]D951O9V=L95LQ72`]("=@+2<["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!N;V1E5&]G9VQE6S!=(#T@=&AI<RYI;6="
M;&%N:SL*("`@("`@("`@("`@("`@(&YO9&54;V=G;&5;,5T@/2`G)FYB<W`[
M)FYB<W`[)FYB<W`[)SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T@
M96QS92!I9B`H='EP96]F*'1H:7,N;F]D97-;;F]D94ED75LG8VAI;&1R96XG
M72D@(3T@)W5N9&5F:6YE9"<I('L*("`@("`@("`O+R!.;V1E('=I=&@@8VAI
M;&1R96XN"B`@("`@("`@:68@*'1H:7,N;F]D95]P;W-;;F]D94ED75LG<&]S
M)UT@/"!T:&ES+FYO9&5?<&]S6VYO9&5)9%U;)V-O=6YT)UTI('L*("`@("`@
M("`@("`@+R\@3F]T(&QA<W0@;F]D92X*("`@("`@("`@("`@:68@*"%T:&ES
M+F]P=&EO;G-;)VQI;F5S)UTI('L*("`@("`@("`@("`@("`@(&YO9&54;V=G
M;&5;,%T@/2!T:&ES+FEM9T)L86YK.PH@("`@("`@("`@("`@("`@;F]D951O
M9V=L95LQ72`]("<F;F)S<#LF;F)S<#LF;F)S<#LG.PH@("`@("`@("`@("!]
M(&5L<V4@:68@*'1H:7,N<F5N9&5R4W1A=&EC*2!["B`@("`@("`@("`@("`@
M("!N;V1E5&]G9VQE6S!=(#T@=&AI<RYI;6=*;VEN.PH@("`@("`@("`@("`@
M("`@;F]D951O9V=L95LQ72`]("=\+2<["B`@("`@("`@("`@('T@96QS92!I
M9B`H=&AI<RYN;V1E<UMN;V1E261=6R=E>'!A;F1E9"==*2!["B`@("`@("`@
M("`@("`@("!N;V1E5&]G9VQE6S!=(#T@=&AI<RYI;6=-:6YU<SL*("`@("`@
M("`@("`@("`@(&YO9&54;V=G;&5;,5T@/2`G+2<["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("!N;V1E5&]G9VQE6S!=(#T@=&AI<RYI
M;6=0;'5S.PH@("`@("`@("`@("`@("`@;F]D951O9V=L95LQ72`]("<K)SL*
M("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O
M($QA<W0@;F]D92X*("`@("`@("`@("`@:68@*"%T:&ES+F]P=&EO;G-;)VQI
M;F5S)UTI('L*("`@("`@("`@("`@("`@(&YO9&54;V=G;&5;,%T@/2!T:&ES
M+FEM9T)L86YK.PH@("`@("`@("`@("`@("`@;F]D951O9V=L95LQ72`]("<F
M;F)S<#LG.PH@("`@("`@("`@("!](&5L<V4@:68@*'1H:7,N<F5N9&5R4W1A
M=&EC*2!["B`@("`@("`@("`@("`@("!N;V1E5&]G9VQE6S!=(#T@=&AI<RYI
M;6=*;VEN0F]T=&]M.PH@("`@("`@("`@("`@("`@;F]D951O9V=L95LQ72`]
M("=@+2<["B`@("`@("`@("`@('T@96QS92!I9B`H=&AI<RYN;V1E<UMN;V1E
M261=6R=E>'!A;F1E9"==*2!["B`@("`@("`@("`@("`@("!N;V1E5&]G9VQE
M6S!=(#T@=&AI<RYI;6=-:6YU<T)O='1O;3L*("`@("`@("`@("`@("`@(&YO
M9&54;V=G;&5;,5T@/2`G+2<["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("!N;V1E5&]G9VQE6S!=(#T@=&AI<RYI;6=0;'5S0F]T=&]M
M.PH@("`@("`@("`@("`@("`@;F]D951O9V=L95LQ72`]("<K)SL*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@('T@96QS92!["B`@("`@("`@+R\@5&]P
M(&QE=F5L(&YO9&4@=VET:"!N;R!C:&EL9')E;BX*("`@("`@("!I9B`H=&AI
M<RYR96YD97)3=&%T:6,I('L*("`@("`@("`@("`@<F5T=7)N(&YO9&54;V=G
M;&4["B`@("`@("`@?0H@("`@("`@(&EF("AT:&ES+F]P=&EO;G-;)VQI;F5S
M)UTI('L*("`@("`@("`@("`@;F]D951O9V=L95LP72`]('1H:7,N:6UG3G5L
M;$]N;'D["B`@("`@("`@("`@(&YO9&54;V=G;&5;,5T@/2`G)FYB<W`[)FYB
M<W`[)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!N;V1E5&]G9VQE
M6S!=(#T@=&AI<RYI;6=";&%N:SL*("`@("`@("`@("`@;F]D951O9V=L95LQ
M72`]("<F;F)S<#LF;F)S<#LF;F)S<#LG.PH@("`@("`@('T*("`@('T*"B`@
M("!R971U<FX@;F]D951O9V=L93L*?0H*2&]R9&5?5')E92YP<F]T;W1Y<&4N
M7W-E=$YO9&5)8V]N(#T@9G5N8W1I;VXH;F]D94ED*0I["B`@("!V87(@:6UG
M1&ER(#T@*'1Y<&5O9BAT:&ES+FYO9&5S6VYO9&5)9%U;)VEC;VYD:7(G72D@
M(3T@)W5N9&5F:6YE9"<I(#\*("`@("`@("!T:&ES+FYO9&5S6VYO9&5)9%U;
M)VEC;VYD:7(G72`Z"B`@("`@("`@=&AI<RYI;6=$:7(["B`@("!I9B`H:6UG
M1&ER*2!["B`@("`@("`@:6UG1&ER("L]("<O)SL*("`@('T*"B`@("!I9B`H
M='EP96]F*'1H:7,N;F]D97-;;F]D94ED75LG:6-O;B==*2`A/2`G=6YD969I
M;F5D)RD@>PH@("`@("`@("\O($YO9&4@:&%S(&$@=7-E<B!D969I;F5D(&EC
M;VXN"B`@("`@("`@:68@*"%T:&ES+FYO9&5S6VYO9&5)9%U;)VEC;VXG72D@
M>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H@("`@("`@(&EF
M("AT>7!E;V8H=&AI<RYN;V1E<UMN;V1E261=6R=I8V]N;W!E;B==*2`A/2`G
M=6YD969I;F5D)R`F)B!T:&ES+FYO9&5S6VYO9&5)9%U;)V5X<&%N9&5D)UTI
M('L*("`@("`@("`@("`@:6UG(#T@=&AI<RYN;V1E<UMN;V1E261=6R=I8V]N
M;W!E;B==.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EM9R`]('1H
M:7,N;F]D97-;;F]D94ED75LG:6-O;B==.PH@("`@("`@('T*("`@('T@96QS
M92!["B`@("`@("`@+R\@57-E('-T86YD87)D(&EC;VX@<V5T+@H@("`@("`@
M(&EF("AT>7!E;V8H=&AI<RYN;V1E<UMN;V1E261=6R=C:&EL9')E;B==*2`A
M/2`G=6YD969I;F5D)RD@>PH@("`@("`@("`@("`O+R!.;V1E('=I=&@@8VAI
M;&1R96XN"B`@("`@("`@("`@(&EM9R`]("AT:&ES+FYO9&5S6VYO9&5)9%U;
M)V5X<&%N9&5D)UTI(#\@=&AI<RYI;6=&;VQD97)/<&5N"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@=&AI
M<RYI;6=&;VQD97(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@
M3F]D92!N;R!C:&EL9')E;BX*("`@("`@("`@("`@:6UG(#T@=&AI<RYI;6=,
M96%F.PH@("`@("`@('T*("`@('T*"B`@("!V87(@:6UG='AT(#T@)SQI;6<@
M<W)C/2(G("L@:6UG1&ER("L@:6UG("L@)R(G.PH*("`@(&EF("AT>7!E;V8H
M=&AI<RYN;V1E<UMN;V1E261=6R=I8V]N86QT)UTI("$]("=U;F1E9FEN960G
M*2!["B`@("`@("`@:6UG='AT("L]("<@86QT/2(G("L@=&AI<RYN;V1E<UMN
M;V1E261=6R=I8V]N86QT)UT@*R`G(B<["B`@("!]"@H@("`@<F5T=7)N(&EM
M9W1X="`K("<@+SX@)SL*?0H*2&]R9&5?5')E92YP<F]T;W1Y<&4N=&]G9VQE
M(#T@9G5N8W1I;VXH;F]D94ED*0I["B`@("!T:&ES+FYO9&5S6VYO9&5)9%U;
M)V5X<&%N9&5D)UT@/2`A=&AI<RYN;V1E<UMN;V1E261=6R=E>'!A;F1E9"==
M.PH@("`@:68@*'1H:7,N;F]D97-;;F]D94ED75LG97AP86YD960G72D@>PH@
M("`@("`@(&EF("AN;V1E(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)VYO
M9&5#:&EL9')E;E\G("L@;F]D94ED*2D@>PH@("`@("`@("`@("!N;V1E+G-T
M>6QE+F1I<W!L87D@/2`G8FQO8VLG.PH@("`@("`@('T*("`@('T@96QS92![
M"B`@("`@("`@:68@*&YO9&4@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@G
M;F]D94-H:6QD<F5N7R<@*R!N;V1E260I*2!["B`@("`@("`@("`@(&YO9&4N
M<W1Y;&4N9&ES<&QA>2`]("=N;VYE)SL*("`@("`@("!]"B`@("!]"@H@("`@
M+R\@268@=7-I;F<@86QT97)N871I;F<@<F]W('-H861I;F<L('=O<FL@;W5T
M(&-O<G)E8W0@<VAA9&4N"B`@("!I9B`H=&AI<RYO<'1I;VYS6R=A;'1E<FYA
M=&4G72D@>PH@("`@("`@('1H:7,N<W1R:7!E*"D["B`@("!]"@H@("`@;F]D
M951O9V=L92`]('1H:7,N7V=E=$YO9&54;V=G;&4H;F]D94ED*3L*("`@(&EF
M("AT;V=G;&4@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@G;F]D951O9V=L
M95\G("L@;F]D94ED*2D@>PH@("`@("`@('1O9V=L92YS<F,@/2!T:&ES+FEM
M9T1I<B`K("<O)R`K(&YO9&54;V=G;&5;,%T["B`@("`@("`@=&]G9VQE+F%L
M="`](&YO9&54;V=G;&5;,5T["B`@("!]"@H@("`@=&AI<RYS879E4W1A=&4H
M;F]D94ED+"!T:&ES+FYO9&5S6VYO9&5)9%U;)V5X<&%N9&5D)UTI"GT*"DAO
M<F1E7U1R964N<')O=&]T>7!E+G-T<FEP92`](&9U;F-T:6]N*"D*>PH@("`@
M+R\@5&AE(&5L96UE;G0@=&\@<W1A<G0@<W1R:7!I;F<N"B`@("!V87(@:60@
M/2!A<F=U;65N='-;,%T@/R!A<F=U;65N='-;,%T@.B!T:&ES+G1A<F=E=#L*
M"B`@("`O+R!4:&4@9FQA9R!W92=L;"!U<V4@=&\@:V5E<"!T<F%C:R!O9B!W
M:&5T:&5R('1H92!C=7)R96YT(')O=R!I<PH@("`@+R\@;V1D(&]R(&5V96XN
M"B`@("!V87(@979E;B`](&%R9W5M96YT<ULQ72`_(&%R9W5M96YT<ULQ72`Z
M(&9A;'-E.PH*("`@("\O($]B=&%I;B!A(')E9F5R96YC92!T;R!T:&4@=')E
M92!P87)E;G0@96QE;65N="X*("`@('9A<B!T<F5E(#T@9&]C=6UE;G0N9V5T
M16QE;65N=$)Y260H:60I.PH@("`@:68@*"%T<F5E*2!["B`@("`@("`@<F5T
M=7)N(&5V96X["B`@("!]"@H@("`@+R\@271E<F%T92!O=F5R(&5A8V@@8VAI
M;&0@9&EV+@H@("`@9F]R("AV87(@:2`](#`[(&D@/"!T<F5E+F-H:6QD3F]D
M97,N;&5N9W1H.R!I*RLI('L*("`@("`@("!I9B`H=')E92YC:&EL9$YO9&5S
M6VE=+FED+FEN9&5X3V8H)VYO9&5#:&EL9')E;B<I("$]("TQ*2!["B`@("`@
M("`@("`@(&EF("AT:&ES+FYO9&5S6W1R964N8VAI;&1.;V1E<UMI72YI9"YR
M97!L86-E*"=N;V1E0VAI;&1R96Y?)RP@)R<I75LG97AP86YD960G72D@>PH@
M("`@("`@("`@("`@("`@979E;B`]('1H:7,N<W1R:7!E*'1R964N8VAI;&1.
M;V1E<UMI72YI9"P@979E;BD["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!T<F5E+F-H:6QD3F]D97-;:5TN8VQA<W-.86UE
M(#T@=')E92YC:&EL9$YO9&5S6VE=+F-L87-S3F%M92YR97!L86-E*"<@<F]W
M179E;B<L("<G*2YR97!L86-E*"<@<F]W3V1D)RP@)R<I.PH@("`@("`@("`@
M("!T<F5E+F-H:6QD3F]D97-;:5TN8VQA<W-.86UE("L](&5V96X@/R`G(')O
M=T5V96XG(#H@)R!R;W=/9&0G.PH*("`@("`@("`@("`@+R\@1FQI<"!F<F]M
M(&]D9"!T;R!E=F5N+"!O<B!V:6-E+79E<G-A+@H@("`@("`@("`@("!E=F5N
M(#T@(65V96X["B`@("`@("`@?0H@("`@?0H*("`@(')E='5R;B!E=F5N.PI]
M"@I(;W)D95]4<F5E+G!R;W1O='EP92YS879E4W1A=&4@/2!F=6YC=&EO;BAN
M;V1E260L(&5X<&%N9&5D*0I["B`@("!V87(@;F5W0V]O:VEE(#T@)R<["B`@
M("!V87(@;VQD0V]O:VEE(#T@=&AI<RY?9V5T0V]O:VEE*'1H:7,N7VEN<W1A
M;F-E3F%M92`K("=?97AP86YD960G*3L*("`@(&EF("AE>'!A;F1E9"D@>PH@
M("`@("`@("\O($5X<&%N9"!R97%U97-T960@<V\@861D('1O(&-O;VMI92X*
M("`@("`@("!N97=#;V]K:64@/2`H;VQD0V]O:VEE*2`_(&]L9$-O;VMI92`K
M("<L)R`Z("<G.PH@("`@("`@(&YE=T-O;VMI92`](&YE=T-O;VMI92`K(&YO
M9&5)9#L*("`@('T@96QS92!["B`@("`@("`@+R\@0V]L;&%P<V4@<F5Q=65S
M=&5D('-O(')E;6]V92!F<F]M(&-O;VMI92X*("`@("`@("!V87(@;F]D97,@
M/2!O;&1#;V]K:64N<W!L:70H)RPG*3L*("`@("`@("!V87(@;F5W3F]D97,@
M/2!N97<@07)R87DH*3L*("`@("`@("!F;W(@*'9A<B!I(#T@,#L@:2`\(&YO
M9&5S+FQE;F=T:#L@:2LK*2!["B`@("`@("`@("`@(&EF("AN;V1E<UMI72`A
M/2!N;V1E260I('L*("`@("`@("`@("`@("`@(&YE=TYO9&5S6VYE=TYO9&5S
M+FQE;F=T:%T@/2!N;V1E<UMI73L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("!N97=#;V]K:64@/2!N97=.;V1E<RYJ;VEN*"<L)RD["B`@("!]
M"B`@("!T:&ES+E]S971#;V]K:64H=&AI<RY?:6YS=&%N8V5.86UE("L@)U]E
M>'!A;F1E9"<L(&YE=T-O;VMI92D["GT*"DAO<F1E7U1R964N<')O=&]T>7!E
M+E]G971#;V]K:64@/2!F=6YC=&EO;BAN86UE*0I["B`@("!V87(@9&,@/2!D
M;V-U;65N="YC;V]K:64["B`@("!V87(@<')E9FEX(#T@;F%M92`K("<]97AP
M)SL*("`@('9A<B!B96=I;B`](&1C+FEN9&5X3V8H)SL@)R`K('!R969I>"D[
M"B`@("!I9B`H8F5G:6X@/3T@+3$I('L*("`@("`@("!B96=I;B`](&1C+FEN
M9&5X3V8H<')E9FEX*3L*("`@("`@("!I9B`H8F5G:6X@(3T@,"D@>PH@("`@
M("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@
M("`@("!B96=I;B`K/2`R.PH@("`@?0H@("`@=F%R(&5N9"`](&1O8W5M96YT
M+F-O;VMI92YI;F1E>$]F*"<[)RP@8F5G:6XI.PH@("`@:68@*&5N9"`]/2`M
M,2D@>PH@("`@("`@(&5N9"`](&1C+FQE;F=T:#L*("`@('T*("`@(')E='5R
M;B!U;F5S8V%P92AD8RYS=6)S=')I;F<H8F5G:6X@*R!P<F5F:7@N;&5N9W1H
M+"!E;F0I*3L*?0H*2&]R9&5?5')E92YP<F]T;W1Y<&4N7W-E=$-O;VMI92`]
M(&9U;F-T:6]N*&YA;64L('9A;'5E*0I["B`@("!V87(@8W5R0V]O:VEE(#T@
M;F%M92`K("<]97AP)R`K(&5S8V%P92AV86QU92D["B`@("!C=7)#;V]K:64@
M*ST@)SM$3TU!24X]/#]P:'`@96-H;R`D1TQ/0D%,4ULG8V]N9B==6R=C;V]K
M:64G75LG9&]M86EN)UT[(#\^.U!!5$@]/#]P:'`@96-H;R`D1TQ/0D%,4ULG
M8V]N9B==6R=C;V]K:64G75LG<&%T:"==.R`_/CLG.PH@("`@9&]C=6UE;G0N
M8V]O:VEE(#T@8W5R0V]O:VEE.PI]"@I(;W)D95]4<F5E+G!R;W1O='EP92Y?
M8V]R<F5C=%=I9'1H1F]R4V-R;VQL8F%R(#T@9G5N8W1I;VXH*0I["CP_<&AP
M(&EF("@D1TQ/0D%,4ULG8G)O=W-E<B==+3YH87-1=6ER:R@G<V-R;VQL8F%R
M7VEN7W=A>2<I*3H@/SX*("`@("\O($-O<G)E8W0@9F]R(&9R86UE('-C<F]L
M;&)A<B!I;B!)12!B>2!D971E<FUI;FEN9R!I9B!A('-C<F]L;&)A<B!I<R!P
M<F5S96YT+`H@("`@+R\@86YD(&EF(&YO="!R96%D:G5S=&EN9R!T:&4@;6%R
M9VEN4FEG:'0@<')O<&5R='D@=&\@,`H@("`@+R\@4V5E(&AT='`Z+R]W=W<N
M>',T86QL+FYL+WYP<&LO:G,O9&]C='EP97,N:'1M;"!F;W(@=VAY('1H:7,@
M=V]R:W,*("`@(&EF("AD;V-U;65N="YD;V-U;65N=$5L96UE;G0N8VQI96YT
M2&5I9VAT(#T](&1O8W5M96YT+F1O8W5M96YT16QE;65N="YO9F9S971(96EG
M:'0I('L*("`@("`@("`O+R!N;R!S8W)O;&QB87(@<')E<V5N="P@=&%K92!A
M=V%Y(&5X=')A(&UA<F=I;@H@("`@("`@(&1O8W5M96YT+F)O9'DN<W1Y;&4N
M;6%R9VEN4FEG:'0@/2`G,"<["B`@("!](&5L<V4@>PH@("`@("`@(&1O8W5M
M96YT+F)O9'DN<W1Y;&4N;6%R9VEN4FEG:'0@/2`G,35P>"<["B`@("!]"CP_
M<&AP(&5N9&EF.R`_/@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E
M<R]L;V=I;B\`````````````````````````````````````````````````
M````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`P,#``,3`U,34T,S,W-3<`,#(P-S<P`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8P``````````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,C(W-@`Q,#4Q-30S,S<U-P`P,C(V
M,#,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*)')I9VAT06QI9VX@/2!E;7!T>2@D;FQS6R=R=&PG75LD;&%N9W5A
M9V5=*2`_("=R:6=H="<@.B`G;&5F="<["B1L969T06QI9VX@/2!E;7!T>2@D
M;FQS6R=R=&PG75LD;&%N9W5A9V5=*2`_("=L969T)R`Z("=R:6=H="<["C\^
M"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*/"$M+0IF=6YC=&EO
M;B!S971&;V-U<R@I"GL*("`@(&EF("AD;V-U;65N="YH;W)D95]L;V=I;BYH
M;W)D95]U<V5R+G9A;'5E(#T]("(B*2!["B`@("`@("`@9&]C=6UE;G0N:&]R
M9&5?;&]G:6XN:&]R9&5?=7-E<BYF;V-U<R@I.PH@("`@?2!E;'-E('L*("`@
M("`@("!D;V-U;65N="YH;W)D95]L;V=I;BYH;W)D95]P87-S+F9O8W5S*"D[
M"B`@("!]"GT*9G5N8W1I;VX@<W5B;6ET7VQO9VEN*&4I"GL*("`@(&EF("AT
M>7!E;V8@92`A/2`G=6YD969I;F5D)R`F)B`A96YT97)?:V5Y7W1R87`H92DI
M('L*("`@("`@("!R971U<FX["B`@("!]"@H@("`@:68@*&1O8W5M96YT+FAO
M<F1E7VQO9VEN+FAO<F1E7W5S97(N=F%L=64@/3T@(B(I('L*("`@("`@("!A
M;&5R="@B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E!L96%S92!P<F]V:61E
M('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(BDI(#\^(BD["B`@("`@("`@
M9&]C=6UE;G0N:&]R9&5?;&]G:6XN:&]R9&5?=7-E<BYF;V-U<R@I.PH@("`@
M("`@(')E='5R;B!F86QS93L*("`@('T@96QS92!I9B`H9&]C=6UE;G0N:&]R
M9&5?;&]G:6XN:&]R9&5?<&%S<RYV86QU92`]/2`B(BD@>PH@("`@("`@(&%L
M97)T*"(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4&QE87-E('!R;W9I9&4@
M>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B*2D@/SXB*3L*("`@("`@("!D
M;V-U;65N="YH;W)D95]L;V=I;BYH;W)D95]P87-S+F9O8W5S*"D["B`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@?2!E;'-E('L*("`@("`@("!D;V-U;65N
M="YH;W)D95]L;V=I;BYL;V=I;D)U='1O;BYD:7-A8FQE9"`]('1R=64["CP_
M<&AP(&EF("@A96UP='DH)&EE7V-L:65N=&-A<',I*3H@/SX*("`@("`@("!T
M<GD@>PH@("`@("`@("`@("!D;V-U;65N="YH;W)D95]L;V=I;BYI95]V97)S
M:6]N+G9A;'5E(#T@;V)J0T-A<',N9V5T0V]M<&]N96YT5F5R<VEO;B@B>S@Y
M.#(P,C`P+45#0D0M,3%#1BTX0C@U+3`P04$P,#5"-#,X,WTB+"`B8V]M<&]N
M96YT:60B*3L*("`@("`@("!](&-A=&-H("AE*2!["B`@("`@("`@?0H\/W!H
M<"!E;F1I9CL@/SX*("`@("`@("!D;V-U;65N="YH;W)D95]L;V=I;BYS=6)M
M:70H*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*?0HO+RTM/@H\+W-C
M<FEP=#X*"CQF;W)M(&YA;64](FAO<F1E7VQO9VEN(B!M971H;V0](G!O<W0B
M(&%C=&EO;CTB/#]P:'`@96-H;R!(;W)D93HZ<V5L9E5R;"AF86QS92P@=')U
M92P@9F%L<V4L('1R=64I(#\^(CP_<&AP(&5C:&\@)&-O;F9;)VUE;G4G75LG
M86QW87ES)UT@/R`G('1A<F=E=#TB7W!A<F5N="(G(#H@)R<@/SX^"CQI;G!U
M="!T>7!E/2)H:61D96XB(&YA;64](G5R;"(@=F%L=64](CP_<&AP(&5C:&\@
M:'1M;'-P96-I86QC:&%R<RA5=&EL.CIG971&;W)M1&%T82@G=7)L)RDI(#\^
M(B`O/@H\/W!H<"!I9B`H(65M<'1Y*"1I95]C;&EE;G1C87!S*2DZ(#\^"CQI
M;G!U="!T>7!E/2)H:61D96XB(&YA;64](FEE7W9E<G-I;VXB('9A;'5E/2(B
M("\^"CP_<&AP(&5N9&EF.R`_/@H*/&1I=B!I9#TB;65N=2(^"CP_<&AP"B1M
M96YU(#T@)FYE=R!-96YU*$A/4D1%7TU%3E5?34%32U].3TY%*3L*)&AM96YU
M(#T@)&UE;G4M/G)E;F1E<B@I.PII9B`H)&AM96YU*3H@/SX*(#QS<&%N('-T
M>6QE/2)F;&]A=#H\/W!H<"!E8VAO("1R:6=H=$%L:6=N(#\^(CX\/W!H<"!E
M8VAO("1H;65N=2`_/CPO<W!A;CX*/#]P:'`@96YD:68[(#\^"B`\:#$@<W1Y
M;&4](G1E>'0M86QI9VXZ8V5N=&5R(CX\/W!H<"!P<FEN=&8H7R@B5V5L8V]M
M92!T;R`E<R(I+"`D<F5G:7-T<GDM/F=E="@G;F%M92<I*2`_/CPO:#$^"CPO
M9&EV/@H*/&)R(&-L87-S/2)S<&%C97(B("\^"CP_<&AP("1N;W1I9FEC871I
M;VXM/FYO=&EF>2AA<G)A>2@G;&ES=&5N97)S)R`]/B`G<W1A='5S)RDI(#\^
M"@H\=&%B;&4@=VED=&@](C$P,"4B/CQT<CX\=&0@86QI9VX](F-E;G1E<B(^
M/'1A8FQE('=I9'1H/2(S,#`B(&%L:6=N/2)C96YT97(B/@H*/#]P:'`@:68@
M*"%E;7!T>2@D<F5A<V]N*2DZ(#\^"CQT<CX*("`\=&0@8V]L<W!A;CTB,B(@
M8VQA<W,](FYO=&EC92(^/#]P:'`@96-H;R`D<F5A<V]N(#\^/"]T9#X*/"]T
M<CX*/#]P:'`@96YD:68[(#\^"@H\='(^"B`@("`\=&0@86QI9VX](CP_<&AP
M(&5C:&\@)')I9VAT06QI9VX@/SXB(&-L87-S/2)L:6=H="(^/'-T<F]N9SX\
M/W!H<"!E8VAO(%\H(E5S97)N86UE(BD@/SX\+W-T<F]N9SXF;F)S<#L\+W1D
M/@H@("`@/'1D(&%L:6=N/2(\/W!H<"!E8VAO("1L969T06QI9VX@/SXB/CQI
M;G!U="!C;&%S<STB9FEX960B('1Y<&4](G1E>'0B(&YA;64](FAO<F1E7W5S
M97(B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H571I;#HZ
M9V5T1F]R;41A=&$H)VAO<F1E7W5S97(G*2D@/SXB('-T>6QE/2)D:7)E8W1I
M;VXZ;'1R(B`O/CPO=&0^"CPO='(^"@H\='(^"B`@("`\=&0@86QI9VX](CP_
M<&AP(&5C:&\@)')I9VAT06QI9VX@/SXB(&-L87-S/2)L:6=H="(^/'-T<F]N
M9SX\/W!H<"!E8VAO(%\H(E!A<W-W;W)D(BD@/SX\+W-T<F]N9SXF;F)S<#L\
M+W1D/@H@("`@/'1D(&%L:6=N/2(\/W!H<"!E8VAO("1L969T06QI9VX@/SXB
M/CQI;G!U="!C;&%S<STB9FEX960B('1Y<&4](G!A<W-W;W)D(B!N86UE/2)H
M;W)D95]P87-S(B!V86QU93TB(B!S='EL93TB9&ER96-T:6]N.FQT<B(@+SX\
M+W1D/@H\+W1R/@H*/#]P:'`@:68@*"$D<')E9G,M/FES3&]C:V5D*"=L86YG
M=6%G92<I*3H@/SX*/'1R/@H@("`@/'1D(&%L:6=N/2(\/W!H<"!E8VAO("1R
M:6=H=$%L:6=N(#\^(B!C;&%S<STB;&EG:'0B/CQS=')O;F<^/#]P:'`@96-H
M;R!?*"),86YG=6%G92(I(#\^/"]S=')O;F<^/"]T9#X*("`@(#QT9"!A;&EG
M;CTB/#]P:'`@96-H;R`D;&5F=$%L:6=N(#\^(B!C;&%S<STB;&EG:'0B('-T
M>6QE/2)D:7)E8W1I;VXZ;'1R(CX\/W!H<"!E8VAO("1L86YG<R`_/CPO=&0^
M"CPO='(^"CP_<&AP(&5N9&EF.R`_/@H*/'1R/@H@("`@/'1D/B9N8G-P.SPO
M=&0^"B`@("`\=&0@86QI9VX](CP_<&AP(&5C:&\@)&QE9G1!;&EG;B`_/B(@
M8VQA<W,](FQI9VAT(CX\:6YP=70@;F%M93TB;&]G:6Y"=71T;VXB(&-L87-S
M/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H(DQO9R!I;B(I(#\^(B!T
M>7!E/2)S=6)M:70B(&]N8VQI8VL](G)E='5R;B!S=6)M:71?;&]G:6XH*3LB
M("\^/"]T9#X*/"]T<CX*"CP_<&AP(&EF("@A96UP='DH)&-O;F9;)W-I9VYU
M<"==6R=A;&QO=R==*2`F)B`D875T:"T^:&%S0V%P86)I;&ET>2@G861D)RDI
M.B`_/@H\='(^"B`@("`\=&0^)FYB<W`[/"]T9#X*("`@(#QT9"!A;&EG;CTB
M/#]P:'`@96-H;R`D;&5F=$%L:6=N(#\^(B!C;&%S<STB;&EG:'0B/CP_<&AP
M(&5C:&\@2&]R9&4Z.FQI;FLH571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIU
M<FPH)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<VEG
M;G5P+G!H<"<I+"`G=7)L)RP@571I;#HZ9V5T1F]R;41A=&$H)W5R;"<I*2P@
M7R@B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(I+"`G;&EG:'0G
M*2`N(%\H(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB*2`_/CPO
M83X\+W1D/@H\+W1R/@H\/W!H<"!E;F1I9CL@/SX*/#]P:'`@:68@*"1A=71H
M+3YH87-#87!A8FEL:71Y*"=R97-E='!A<W-W;W)D)RDI.B`_/@H\='(^"B`@
M("`\=&0^)FYB<W`[/"]T9#X*("`@(#QT9"!C;&%S<STB;&EG:'0B/CP_<&AP
M(&5C:&\@2&]R9&4Z.FQI;FLH571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIU
M<FPH)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`G*2P@)W5R;"<L(%5T:6PZ.F=E=$9O
M<FU$871A*"=U<FPG*2DL(%\H(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(I+"`G
M;&EG:'0G*2`N(%\H(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(I(#\^/"]A/CPO
M=&0^"CPO='(^"CP_<&AP(&5N9&EF.R`_/@H*/"]T86)L93X\+W1D/CPO='(^
M/"]T86)L93X*/"]F;W)M/@H*/#]P:'`@:68@*$!I<U]R96%D86)L92A(3U)$
M15]"05-%("X@)R]C;VYF:6<O;6]T9"YP:'`G*2D@<F5Q=6ER92!(3U)$15]"
M05-%("X@)R]C;VYF:6<O;6]T9"YP:'`G.R`_/@H*/'-C<FEP="!T>7!E/2)T
M97AT+VIA=F%S8W)I<'0B/@H\(2TM"CP_<&AP(&EF("@A)'!R969S+3YI<TQO
M8VME9"@G;&%N9W5A9V4G*2DZ"B`@("`D;&%N9U]U<FP@/2!(;W)D93HZ87!P
M;&EC871I;VY5<FPH)VQO9VEN+G!H<"<L('1R=64I.PH@("`@:68@*"@D=7)L
M(#T@571I;#HZ9V5T1F]R;41A=&$H)W5R;"<I*2D@>PH@("`@("`@("1L86YG
M7W5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D;&%N9U]U<FPL("=U<FPG+"`D
M=7)L+"!F86QS92D["B`@("!]"B`@("`D;&%N9U]U<FP@/2!5=&EL.CIA9&10
M87)A;65T97(H)&QA;F=?=7)L+"`G;F5W7VQA;F<G+"`G)RP@9F%L<V4I.PH_
M/@IF=6YC=&EO;B!S96QE8W1,86YG*"D*>PH@("`@+R\@5V4@;F5E9"!T;R!R
M96QO860@=&AE(&QO9VEN('!A9V4@:&5R92P@8G5T(&]N;'D@:68@=&AE('5S
M97(*("`@("\O(&AA<VXG="!A;')E861Y(&5N=&5R960@82!U<V5R;F%M92!A
M;F0@<&%S<W=O<F0N"B`@("!I9B`H9&]C=6UE;G0N:&]R9&5?;&]G:6XN:&]R
M9&5?=7-E<BYV86QU92`]/2`G)R`F)@H@("`@("`@(&1O8W5M96YT+FAO<F1E
M7VQO9VEN+FAO<F1E7W!A<W,N=F%L=64@/3T@)R<I('L*("`@("`@("!V87(@
M;&%N9U]P86=E(#T@)SP_<&AP(&5C:&\@)&QA;F=?=7)L(#\^)R`K(&1O8W5M
M96YT+FAO<F1E7VQO9VEN+FYE=U]L86YG6V1O8W5M96YT+FAO<F1E7VQO9VEN
M+FYE=U]L86YG+G-E;&5C=&5D26YD97A=+G9A;'5E.PH@("`@("`@('-E;&8N
M;&]C871I;VX@/2!L86YG7W!A9V4["B`@("!]"GT*/#]P:'`@96YD:68[(#\^
M"@II9B`H<&%R96YT+F9R86UE<RYH;W)D95]M86EN*2!["B`@("!D;V-U;65N
M="YH;W)D95]L;V=I;BYT87)G970@/2`G7W!A<F5N="<["GT*"B\O(%-E="!U
M<"!T:&4@96YT97(@:V5Y=')A<"!C;V1E+@II9B`H='EP96]F(&1O8W5M96YT
M+F-A<'1U<F5%=F5N=',@(3T@)W5N9&5F:6YE9"<I('L*("`@(&1O8W5M96YT
M+F-A<'1U<F5%=F5N=',H179E;G0N2T594%)%4U,I.PH@("`@9&]C=6UE;G0N
M;VYK97EP<F5S<R`]('-U8FUI=%]L;V=I;CL*?0HO+RTM/@H\+W-C<FEP=#X*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,`````````````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,3$U,@`Q,#4Q-30S,S<U-P`P,C(W,S$`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*"B1M(#T@)FYE=R!(;W)D
M95]-;V)I;&4H7R@B3&]G(&EN(BDI.PHD;2T^861D*&YE=R!(;W)D95]-;V)I
M;&5?=&5X="AS<')I;G1F*%\H(E=E;&-O;64@=&\@)7,B*2P@)')E9VES=')Y
M+3YG970H)VYA;64G*2DI*3L*"B1F(#T@)FYE=R!(;W)D95]-;V)I;&5?9F]R
M;2@G;&]G:6XN<&AP)RD["B1F+3YA9&0H;F5W($AO<F1E7TUO8FEL95]H:61D
M96XH)W5R;"<L(%5T:6PZ.F=E=$9O<FU$871A*"=U<FPG+"`G)RDI*3L*)&8M
M/F%D9"AN97<@2&]R9&5?36]B:6QE7VEN<'5T*"=H;W)D95]U<V5R)RP@)R<L
M(%\H(E5S97)N86UE.B`B*2DI.PH*+R\@061D(&$@<&%S<W=O<F0@:6YP=70L
M(&%N9"!S970@=&AE('1Y<&4@86-C;W)D:6YG;'DN"B1P(#T@)B1F+3YA9&0H
M;F5W($AO<F1E7TUO8FEL95]I;G!U="@G:&]R9&5?<&%S<R<L("<G+"!?*")0
M87-S=V]R9#H@(BDI*3L*)'`M/G-E="@G='EP92<L("=P87-S=V]R9"<I.PH*
M+R\@4W5B;6ET(&)U='1O;BX*)&8M/F%D9"AN97<@2&]R9&5?36]B:6QE7W-U
M8FUI="A?*"),;V<@:6XB*2DI.PH*+R\@061D('1H92!F;W)M('1O('1H92!P
M86=E+@HD;2T^861D*"1F*3L*"B\O($1I<W!L87D@979E<GET:&EN9RX*)&TM
M/F1I<W!L87DH*3L*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+P``````````````````````````````````````
M```````````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<V,``P,C(Q,S0`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N
M:'1M;````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`T,#$V`#$P-3$U-#,S-S8P`#`R
M-3,P-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\9&EV(&ED/2)M96YU(CX\:#$^)FYB<W`[/'1A9SIH96%D97(@+SX\+V@Q
M/CPO9&EV/@H*/&9O<FT@;65T:&]D/2)P;W-T(B!A8W1I;VX](CQT86<Z;6%I
M;G1?=7)L("\^(B!N86UE/2)M86EN=%]C;VYF:7)M(CX*/&EN<'5T('1Y<&4]
M(FAI9&1E;B(@;F%M93TB;&]A9%]F<F%M97-E="(@=F%L=64](B(@+SX*/'1A
M9SIM86EN=%]P;W-T9&%T82`O/@H*/&EF.FIA=F%S8W)I<'0^"CQS8W)I<'0@
M='EP93TB=&5X="]J879A<V-R:7!T(CX*/"$M+0IF=6YC=&EO;B!U;F-H96-K
M06QL*"D*>PH@("`@9F]R("AV87(@:2`](#`[(&D@/"!D;V-U;65N="YM86EN
M=%]C;VYF:7)M+F5L96UE;G1S+FQE;F=T:#L@:2LK*2!["B`@("`@("`@9&]C
M=6UE;G0N;6%I;G1?8V]N9FER;2YE;&5M96YT<UMI72YC:&5C:V5D(#T@9F%L
M<V4["B`@("!]"GT*+R\M+3X*/"]S8W)I<'0^"CPO:68Z:F%V87-C<FEP=#X*
M"CQT86)L92!W:61T:#TB,3`P)2(@8V5L;'-P86-I;F<](C(B/@H@/'1R/@H@
M(#QT9#X\=&%G.FYO=&EF>2`O/CPO=&0^"B`\+W1R/@H*/&QO;W`Z=&%S:W,^
M"B`\='(^"B`@/'1D(&-L87-S/2)L:6=H="(^"CQI9CIC;VYF:7)M/@H@("`\
M:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](CQT86<Z=&%S:W,N<')E9B`O
M/E]C;VYF:7)M(CQT86<Z=&%S:W,N8VAE8VME9"`O/CXF;F)S<#LF;F)S<#L*
M/"]I9CIC;VYF:7)M/@H\:68Z86=R964^"B`@(#QI;G!U="!T>7!E/2)H:61D
M96XB(&YA;64](CQT86<Z=&%S:W,N<')E9B`O/E]C;VYF:7)M(B!V86QU93TB
M,2(@+SX*/"]I9CIA9W)E93X*/&EF.FYO=&EC93X*("`@/&EN<'5T('1Y<&4]
M(FAI9&1E;B(@;F%M93TB/'1A9SIT87-K<RYP<F5F("\^7V-O;F9I<FTB('9A
M;'5E/2(Q(B`O/@H\+VEF.FYO=&EC93X*("`@/'1A9SIT87-K<RYD97-C<FEP
M("\^"B`@/"]T9#X*(#PO='(^"CPO;&]O<#IT87-K<SX*"B`\='(^"B`@/'1D
M/B9N8G-P.SPO=&0^"B`\+W1R/@H*(#QT<CX*("`\=&0^"CQI9CIC;VYF:7)M
M/@H@("`\:6YP=70@;F%M93TB;VLB('1Y<&4](G-U8FUI="(@8VQA<W,](F)U
M='1O;B(@=F%L=64](CQG971T97AT/E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E
M<F%T:6]N<SPO9V5T=&5X=#XB(&]N8VQI8VL](F1O8W5M96YT+FUA:6YT7V-O
M;F9I<FTN<W5B;6ET*"D[(B`O/@H\:68Z:F%V87-C<FEP=#X*("`@)FYB<W`[
M)FYB<W`["B`@(#QI;G!U="!T>7!E/2)B=71T;VXB(&-L87-S/2)B=71T;VXB
M('9A;'5E/2(\9V5T=&5X=#Y3:VEP($UA:6YT96YA;F-E/"]G971T97AT/B(@
M;VYC;&EC:STB=6YC:&5C:T%L;"@I.R!D;V-U;65N="YM86EN=%]C;VYF:7)M
M+G-U8FUI="@I.R(@+SX*/"]I9CIJ879A<V-R:7!T/@H\+VEF.F-O;F9I<FT^
M"CQI9CIA9W)E93X*("`@/&EN<'5T(&YA;64](F]K(B!T>7!E/2)S=6)M:70B
M(&YA;64](F%G<F5E(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/&=E='1E>'0^
M665S+"!)($%G<F5E/"]G971T97AT/B(@;VYC;&EC:STB9&]C=6UE;G0N;6%I
M;G1?8V]N9FER;2YS=6)M:70H*3LB("\^"B`@(#QI;G!U="!T>7!E/2)S=6)M
M:70B(&YA;64](FYO=%]A9W)E92(@8VQA<W,](F)U='1O;B(@=F%L=64](CQG
M971T97AT/DY/+"!)($1O($Y/5"!!9W)E93PO9V5T=&5X=#XB(&]N8VQI8VL]
M(F1O8W5M96YT+FUA:6YT7V-O;F9I<FTN<W5B;6ET*"D[(B`O/@H\+VEF.F%G
M<F5E/@H\:68Z;F]T:6-E/@H@("`\:6YP=70@;F%M93TB;VLB('1Y<&4](G-U
M8FUI="(@8VQA<W,](F)U='1O;B(@=F%L=64](CQG971T97AT/D-L:6-K('1O
M($-O;G1I;G5E/"]G971T97AT/B(@;VYC;&EC:STB9&]C=6UE;G0N;6%I;G1?
M8V]N9FER;2YS=6)M:70H*3LB("\^"CPO:68Z;F]T:6-E/@H@(#PO=&0^"B`\
M+W1R/@H\+W1A8FQE/@H*/"]F;W)M/@H*/'-C<FEP="!T>7!E/2)T97AT+VIA
M=F%S8W)I<'0B/@H\(2TM"F1O8W5M96YT+FUA:6YT7V-O;F9I<FTN;VLN9F]C
M=7,H*3L*:68@*'1Y<&5O9B!W:6YD;W<N<&%R96YT+F9R86UE<RYH;W)D95]M
M96YU(#T]("=U;F1E9FEN960G*2!D;V-U;65N="YM86EN=%]C;VYF:7)M+FQO
M861?9G)A;65S970N=F%L=64@/2`Q.PHO+RTM/@H\+W-C<FEP=#X*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O;65N=2\`````````
M````````````````````````````````````````````````````````````
M`````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P
M-3$U-#,S-S4W`#`R,#8R-``@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L
M871E<R]M96YU+VUE;G4N:6YC````````````````````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`Q,S``,3`U,34T,S,W-3<`,#(R,C4U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#QD:78@:60](FUE;G4B
M/@H@/&1I=B!C;&%S<STB;&5F=$9L;V%T(CX*("`\/W!H<"!E8VAO("1M96YU
M+3YR96YD97(H*2`_/@H@/"]D:78^"CPO9&EV/@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<&]R=&%L
M+P``````````````````````````````````````````````````````````
M`````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-3$U-#,S-S8Q`#`R,3$U-``@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1E;7!L871E<R]P;W)T86PO861D+FEN8P``````````````````````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#$P-S,`,3`U,34T,S,W-C$`,#(R-#`P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP(&EF
M("@D;&%Y;W5T+3YI<T-H86YG960H)')O=RP@)&-O;"DI.B`_/@H\82!I9#TB
M8FQO8VLB/CPO83X*/#]P:'`@96YD:68[(#\^"@H\<"!C;&%S<STB:&5A9&5R
M(CX\/W!H<"!E8VAO(%\H(D%D9"!(97)E.B(I(#\^/"]P/@H*/&1I=B!S='EL
M93TB<&%D9&EN9SHR<'@B/@H@/&9O<FT@86-T:6]N/2(\/W!H<"!E8VAO($AO
M<F1E.CIS96QF57)L*"D@/SXC8FQO8VLB(&UE=&AO9#TB<&]S="(^"B`\/W!H
M<"!5=&EL.CIP9F]R;4EN<'5T*"D@/SX*(#QI;G!U="!T>7!E/2)H:61D96XB
M(&YA;64](G)O=R(@=F%L=64](CP_<&AP(&5C:&\@)')O=R`_/B(@+SX*(#QI
M;G!U="!T>7!E/2)H:61D96XB(&YA;64](F-O;"(@=F%L=64](CP_<&AP(&5C
M:&\@)&-O;"`_/B(@+SX*(#QI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C
M=&EO;B(@=F%L=64](G-A=F4M<F5S=6UE(B`O/@H@/#]P:'`@96-H;R`D8FQO
M8VMS+3YG971";&]C:W-7:61G970H*2`_/@H@/&EN<'5T('1Y<&4](G-U8FUI
M="(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B061D(BD@
M/SXB("\^"B`\+V9O<FT^"CPO9&EV/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1E;7!L871E<R]P;W)T86PO8FQO8VLN:6YC````````````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S,C<`,3`U,34T,S,W-C$`,#(R-S0S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#QT
M9"!C;&%S<STB:&5A9&5R8F]X(B!V86QI9VX](G1O<"(@<W1Y;&4](G=I9'1H
M.CP_<&AP(&5C:&\@)'=I9'1H(#\^)2(@<F]W<W!A;CTB/#]P:'`@96-H;R`D
M<F]W<W!A;B`_/B(@8V]L<W!A;CTB/#]P:'`@96-H;R`D8V]L<W!A;B`_/B(^
M"B`\:#$@8VQA<W,](FAE861E<B(^/#]P:'`@96-H;R`D:&5A9&5R(#\^/"]H
M,3X*(#P_<&AP(&5C:&\@)&-O;G1E;G0@/SX*/"]T9#X*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP
M;&%T97,O<&]R=&%L+V5D:70N:6YC````````````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`S-#,R`#$P-3$U-#,S-S8P`#`R,C4W-0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\=&%B;&4@8VQA<W,]
M(FYO<&%D9&EN9R(@8V5L;'-P86-I;F<](C8B('=I9'1H/2(Q,#`E(CX*/#]P
M:'`*)')O=W,@/2`D;&%Y;W5T+3YR;W=S*"D["FQI<W0H)&-U<G)E;G1?<F]W
M+"`D8W5R<F5N=%]C;VPI(#T@)&QA>6]U="T^9V5T0W5R<F5N=$)L;V-K*"D[
M"B1A;&QO=U]A9&0@/2`H(65M<'1Y*"1C;VYF6R=H;V]K<R==6R=P97)M<V1E
M;FEE9"==*2!\?`H@("`@("`@("`@("`@($AO<F1E.CIH87-097)M:7-S:6]N
M*"=M87A?8FQO8VMS)RD@/3T]('1R=64@?'P*("`@("`@("`@("`@("!(;W)D
M93HZ:&%S4&5R;6ES<VEO;B@G;6%X7V)L;V-K<R<I(#X@)&QA>6]U="T^8V]U
M;G0H*2D["B1C;VQU;6YS(#T@,#L*9F]R("@D<F]W(#T@,#L@)')O=R`\("1R
M;W=S.R`K*R1R;W<I.@H_/@H@(#QT<CX*/#]P:'`*)&-O;'5M;G,@/2`D;&%Y
M;W5T+3YC;VQU;6YS*"1R;W<I.PII9B`H:7-?82@D8V]L=6UN<RP@)U!%05)?
M17)R;W(G*2D@>PH@("`@)&-O;'5M;G,@/2`P.PI]"F9O<B`H)&-O;"`](#`[
M("1C;VP@/"`D8V]L=6UN<SL@*RLD8V]L*3H*("`@("1I<T5D:71I;F<@/2`H
M)&-U<G)E;G1?<F]W(#T]/2`D<F]W("8F("1C=7)R96YT7V-O;"`]/3T@)&-O
M;"D["B`@("!I9B`H)&QA>6]U="T^:7-#;W9E<F5D*"1R;W<L("1C;VPI*3H*
M/SX*("`@(#PA+2T@8V]V97)E9"!C96QL(&AE<F4@+2T^"CP_<&AP(&5L<V4Z
M(#\^"B`@("`\=&0@8VQA<W,](CP_<&AP(&5C:&\@)&ES161I=&EN9R`_("=C
M=7)R96YT0FQO8VLG(#H@)VAE861E<F)O>"<@/SXB('9A;&EG;CTB=&]P(B!W
M:61T:#TB/#]P:'`@96-H;R!F;&]O<B@Q,#`@+R`H)&-O;'5M;G,@*R`Q*2D@
M/SXE(B!R;W=S<&%N/2(\/W!H<"!E8VAO("1L87EO=70M/F=E=$AE:6=H="@D
M<F]W+"`D8V]L*2`_/B(@8V]L<W!A;CTB/#]P:'`@96-H;R`D;&%Y;W5T+3YG
M9717:61T:"@D<F]W+"`D8V]L*2`_/B(^"CP_<&AP"B1B;&]C:TEN9F\@/2`D
M;&%Y;W5T+3YG971";&]C:TEN9F\H)')O=RP@)&-O;"D["FEF("@A)&QA>6]U
M="T^:7-%;7!T>2@D<F]W+"`D8V]L*2`F)B`A:7-?82@D8FQO8VM);F9O+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("!I9B`H)&ES161I=&EN9RD@>PH@("`@("`@
M("1E9&ET7VQI;FL@/2`G)FYB<W`[)SL*("`@('T@96QS92!["B`@("`@("`@
M)&5D:71?;&EN:R`]("<\<VUA;&P^)R`N($AO<F1E.CIL:6YK*"1L87EO=70M
M/F=E=$%C=&EO;E5R;"@G961I="<L("1R;W<L("1C;VPI*2`N(%\H(F5D:70B
M*2`N("<\+V$^/"]S;6%L;#XG.PH@("`@?0H@("`@<F5Q=6ER92!D:7)N86UE
M*%]?1DE,15]?*2`N("<O;&%Y;W5T+FEN8R<["GT@96QS92!["B`@("!I9B`H
M)&%L;&]W7V%D9"D@>PH@("`@("`@(')E<75I<F4@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+V%D9"YI;F,G.PH@("`@?0I]"C\^"B`@("`\+W1D/@H\/W!H<"!E
M;F1I9CL@96YD9F]R.R!I9B`H)&%L;&]W7V%D9"DZ(#\^"B`@("`\=&0@=F%L
M:6=N/2)T;W`B(&-L87-S/2)H96%D97)B;W@B/@H@("`@("`\/W!H<"!R97%U
M:7)E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]A9&0N:6YC)SL@/SX*("`@(#PO
M=&0^"CP_<&AP(&5N9&EF.R`_/@H@(#PO='(^"CP_<&AP(&5N9&9O<CL@:68@
M*"1A;&QO=U]A9&0I.B`_/@H@(#QT<CX*/#]P:'`*9F]R("@D8V]L(#T@,#L@
M)&-O;"`\/2`D8V]L=6UN<SL@*RLD8V]L*3H*/SX*("`@(#QT9"!V86QI9VX]
M(G1O<"(@8VQA<W,](FAE861E<F)O>"(^"B`@("`@(#P_<&AP(')E<75I<F4@
M9&ER;F%M92A?7T9)3$5?7RD@+B`G+V%D9"YI;F,G.R`_/@H@("`@/"]T9#X*
M/#]P:'`@96YD9F]R.R`_/@H@(#PO='(^"CP_<&AP(&5N9&EF.R`_/@H\+W1A
M8FQE/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S
M+W!O<G1A;"]L87EO=70N:6YC````````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`Q,#$R,0`Q,#4Q-30S,S<V,0`P,C,Q-3<`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`@:68@*"1L87EO=70M
M/FES0VAA;F=E9"@D<F]W+"`D8V]L*2DZ(#\^"CQA(&ED/2)B;&]C:R(^/"]A
M/@H\/W!H<"!E;F1I9CL@/SX*"CQT86)L92!C96QL<W!A8VEN9STB,"(@8VQA
M<W,](FAE861E<B(@=VED=&@](C$P,"4B/CQT<CX*("`\=&0^"B`@("`\/W!H
M<"!E8VAO("1R96=I<W1R>2T^9V5T*"=N86UE)RP@)&)L;V-K26YF;ULG87!P
M)UTI("X@)SH@)R`N("1B;&]C:W,M/F=E=$YA;64H)&)L;V-K26YF;ULG87!P
M)UTL("1B;&]C:TEN9F];)V)L;V-K)UTI(#\^"B`@/"]T9#X*("`\=&0@8VQA
M<W,](G)I9VAT06QI9VXB/@H@("`@)FYB<W`[/#]P:'`@96-H;R`D961I=%]L
M:6YK(#\^"B`@("`\/W!H<"!I9B`H)&QA>6]U="T^:7-296UO=F%B;&4H)')O
M=RP@)&-O;"DI(&5C:&\@2&]R9&4Z.FQI;FLH)&QA>6]U="T^9V5T06-T:6]N
M57)L*"=R96UO=F5";&]C:R<L("1R;W<L("1C;VPI+"!?*")296UO=F4@0FQO
M8VLB*2P@)R<L("<G+"`G)RP@7R@B4F5M;W9E($)L;V-K(BDI("X@2&]R9&4Z
M.FEM9R@G8VQO<V4N<&YG)RP@7R@B4F5M;W9E($)L;V-K(BDL("=A;&EG;CTB
M;6ED9&QE(B<I("X@)SPO83XG(#\^"B`@/"]T9#X*/"]T<CX\+W1A8FQE/@H*
M/'1A8FQE(&-E;&QS<&%C:6YG/2(P(B!C;&%S<STB;F]P861D:6YG(B!W:61T
M:#TB,3`P)2(^"B`@/'1R/@H@("`@/'1D(&-O;'-P86X](C,B(&%L:6=N/2)C
M96YT97(B/@H@("`@("`\/W!H<"!I9B`H)')O=R`^(#`I(&5C:&\@)&QA>6]U
M="T^9V5T0V]N=')O;"@G97AP86YD+W5P)RP@)')O=RP@)&-O;"D@/SXF;F)S
M<#L*("`@("`@/#]P:'`@:68@*"1L87EO=70M/F=E=$AE:6=H="@D<F]W+"`D
M8V]L*2`^(#$I(&5C:&\@)&QA>6]U="T^9V5T0V]N=')O;"@G<VAR:6YK+W5P
M)RP@)')O=RP@)&-O;"D@/SX*("`@(#PO=&0^"B`@/"]T<CX*("`\='(^"B`@
M("`\=&0@8VQA<W,](FQE9G1!;&EG;B(@=VED=&@](C$Q(CX*("`@("`@/#]P
M:'`@:68@*"1C;VP@/B`P*2!E8VAO("1L87EO=70M/F=E=$-O;G1R;VPH)V5X
M<&%N9"]L969T)RP@)')O=RP@)&-O;"D@/SX*("`@("`@/#]P:'`@:68@*"1L
M87EO=70M/F=E=%=I9'1H*"1R;W<L("1C;VPI(#X@,2D@96-H;R`D;&%Y;W5T
M+3YG971#;VYT<F]L*"=S:')I;FLO;&5F="<L("1R;W<L("1C;VPI(#\^"B`@
M("`\+W1D/@H@("`@/'1D(&%L:6=N/2)C96YT97(B/@H@("`@("`\=&%B;&4^
M"B`@("`@("`@/'1R/@H@("`@("`@("`@/'1D('=I9'1H/2(Q,2(^)FYB<W`[
M/"]T9#X*("`@("`@("`@(#QT9"!W:61T:#TB,3$B/CP_<&AP(&5C:&\@)')O
M=R`^(#`@/R`D;&%Y;W5T+3YG971#;VYT<F]L*"=M;W9E+W5P)RP@)')O=RP@
M)&-O;"D@.B`G)FYB<W`[)R`_/CPO=&0^"B`@("`@("`@("`\=&0@=VED=&@]
M(C$Q(CXF;F)S<#L\+W1D/@H@("`@("`@(#PO='(^"B`@("`@("`@/'1R/@H@
M("`@("`@("`@/'1D/CP_<&AP(&5C:&\@)&-O;"`^(#`@/R`D;&%Y;W5T+3YG
M971#;VYT<F]L*"=M;W9E+VQE9G0G+"`D<F]W+"`D8V]L*2`Z("<F;F)S<#LG
M(#\^/"]T9#X*("`@("`@("`@(#QT9#XF;F)S<#L\+W1D/@H@("`@("`@("`@
M/'1D/CP_<&AP(&5C:&\@)&QA>6]U="T^9V5T0V]N=')O;"@G;6]V92]R:6=H
M="<L("1R;W<L("1C;VPI(#\^/"]T9#X*("`@("`@("`\+W1R/@H@("`@("`@
M(#QT<CX*("`@("`@("`@(#QT9#XF;F)S<#L\+W1D/@H@("`@("`@("`@/'1D
M/CP_<&AP(&5C:&\@)&QA>6]U="T^9V5T0V]N=')O;"@G;6]V92]D;W=N)RP@
M)')O=RP@)&-O;"D@/SX\+W1D/@H@("`@("`@("`@/'1D/B9N8G-P.SPO=&0^
M"B`@("`@("`@/"]T<CX*("`@("`@/"]T86)L93X*("`@(#PO=&0^"B`@("`\
M=&0@8VQA<W,](G)I9VAT06QI9VXB('=I9'1H/2(Q,2(^"B`@("`@(#P_<&AP
M(&EF("@D;&%Y;W5T+3YG9717:61T:"@D<F]W+"`D8V]L*2`^(#$I(&5C:&\@
M)&QA>6]U="T^9V5T0V]N=')O;"@G<VAR:6YK+W)I9VAT)RP@)')O=RP@)&-O
M;"D@/SX*("`@("`@/#]P:'`@96-H;R`D;&%Y;W5T+3YG971#;VYT<F]L*"=E
M>'!A;F0O<FEG:'0G+"`D<F]W+"`D8V]L*2`_/@H@("`@/"]T9#X*("`\+W1R
M/@H@(#QT<CX*("`@(#QT9"!C;VQS<&%N/2(S(B!A;&EG;CTB8V5N=&5R(CX*
M("`@("`@("`\/W!H<"!I9B`H)&QA>6]U="T^9V5T2&5I9VAT*"1R;W<L("1C
M;VPI(#X@,2D@96-H;R`D;&%Y;W5T+3YG971#;VYT<F]L*"=S:')I;FLO9&]W
M;B<L("1R;W<L("1C;VPI(#\^"B`@("`@("`@/#]P:'`@96-H;R`D;&%Y;W5T
M+3YG971#;VYT<F]L*"=E>'!A;F0O9&]W;B<L("1R;W<L("1C;VPI(#\^"B`@
M("`\+W1D/@H@(#PO='(^"CPO=&%B;&4^"@H\/W!H<"!I9B`H)&ES161I=&EN
M9RDZ(#\^"CQA(&ED/2)B;&]C:R(^/"]A/@H\=&%B;&4@8VQA<W,](FYO<&%D
M9&EN9R(@8V5L;'-P86-I;F<](C`B('=I9'1H/2(Q,#`E(CX*("`\='(^"B`@
M("`\=&0^)FYB<W`[/"]T9#X*("`\+W1R/@H@(#QT<CX*("`@(#QT9"!V86QI
M9VX](FUI9&1L92(@8VQA<W,](FQE9G1!;&EG;B(@=VED=&@](C$P,"4B/@H@
M("`@("`\9F]R;2!A8W1I;VX](CP_<&AP(&5C:&\@2&]R9&4Z.G-E;&95<FPH
M*2`_/B-B;&]C:R(@;65T:&]D/2)P;W-T(B!N86UE/2)B;&]C:V9O<FTB/@H@
M("`@("`@(#P_<&AP(%5T:6PZ.G!F;W)M26YP=70H*2`_/@H@("`@("`@(#QI
M;G!U="!T>7!E/2)H:61D96XB(&YA;64](G)O=R(@=F%L=64](CP_<&AP(&5C
M:&\@)')O=R`_/B(@+SX*("`@("`@("`\:6YP=70@='EP93TB:&ED9&5N(B!N
M86UE/2)C;VPB('9A;'5E/2(\/W!H<"!E8VAO("1C;VP@/SXB("\^"B`@("`@
M("`@/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB86-T:6]N(B!V86QU93TB
M<V%V92(@+SX*("`@("`@("`\=&%B;&4@8V5L;'-P86-I;F<](C`B('=I9'1H
M/2(Q,#`E(CX*("`@("`@("`@(#QT<CX*("`@("`@("`@("`@/'1D(&-L87-S
M/2)S;6%L;&AE861E<B(@8V]L<W!A;CTB,B(^/#]P:'`@96-H;R!?*")";&]C
M:R!4>7!E(BD@/SX\+W1D/@H@("`@("`@("`@/"]T<CX*("`@("`@("`@(#QT
M<CX*("`@("`@("`@("`@/'1D(&-O;'-P86X](C(B/@H@("`@("`@("`@("`@
M(#P_<&AP(&5C:&\@)&)L;V-K<RT^9V5T0FQO8VMS5VED9V5T*"1B;&]C:TEN
M9F];)V%P<"==+"`D8FQO8VM);F9O6R=B;&]C:R==+"!T<G5E*2`_/@H@("`@
M("`@("`@("`\+W1D/@H@("`@("`@("`@/"]T<CX*/#]P:'`*:68@*"1B;&]C
M:W,M/FES161I=&%B;&4H)&)L;V-K26YF;ULG87!P)UTL("1B;&]C:TEN9F];
M)V)L;V-K)UTI*3H*("`@("1B;&]C:R`]("8D;&%Y;W5T+3YG971";&]C:R@D
M<F]W+"`D8V]L*3L*("`@("1D969A=6QT<R`](&%R<F%Y*"D["B`@("!F;W)E
M86-H("@D8FQO8VLM/E]P87)A;7,@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@
M("`@)&1E9F%U;'1S6R1K97E=(#T@)'9A;#L*("`@('T*/SX*("`@("`@("`@
M(#QT<CX*("`@("`@("`@("`@/'1D(&-O;'-P86X](C(B(&-L87-S/2)S;6%L
M;&AE861E<B(^/#]P:'`@96-H;R!?*")";&]C:R!3971T:6YG<R(I(#\^/"]T
M9#X*("`@("`@("`@(#PO='(^"CP_<&AP("1I(#T@,#L@9F]R96%C:"`H)&)L
M;V-K<RT^9V5T4&%R86US*"1B;&]C:TEN9F];)V%P<"==+"`D8FQO8VM);F9O
M6R=B;&]C:R==*2!A<R`D:60I.B`D:2LK.R`_/@H@("`@("`@("`@/'1R/@H@
M("`@("`@("`@("`\=&0@8VQA<W,](CP_<&AP(&5C:&\@*"1I("4@,BD@/R`G
M=&5X="<@.B`G:71E;3`G(#\^(')I9VAT06QI9VXB('9A;&EG;CTB=&]P(CX\
M/W!H<"!E8VAO("1B;&]C:W,M/F=E=%!A<F%M3F%M92@D8FQO8VM);F9O6R=A
M<'`G72P@)&)L;V-K26YF;ULG8FQO8VLG72P@)&ED*2`_/CHF;F)S<#L\+W1D
M/@H@("`@("`@("`@("`\=&0@8VQA<W,](CP_<&AP(&5C:&\@*"1I("4@,BD@
M/R`G=&5X="<@.B`G:71E;3`G(#\^(B!V86QI9VX](G1O<"(^/#]P:'`@96-H
M;R`D8FQO8VMS+3YG971/<'1I;VYS5VED9V5T*"1B;&]C:TEN9F];)V%P<"==
M+"`D8FQO8VM);F9O6R=B;&]C:R==+"`D:60L("1D969A=6QT<RD@/SX\+W1D
M/@H@("`@("`@("`@/"]T<CX*/#]P:'`@96YD9F]R96%C:#L@96YD:68[(#\^
M"B`@("`@("`@/"]T86)L93X*("`@("`@("`\:6YP=70@='EP93TB<W5B;6ET
M(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")3879E(BD@
M/SXB("\^"B`@("`@(#PO9F]R;3X*("`@(#PO=&0^"B`@/"]T<CX*/"]T86)L
M93X*/#]P:'`@96YD:68[(#\^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<&]R=&%L+VUE
M;G4N:6YC````````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#,Q
M`#$P-3$U-#,S-S8P`#`R,C8P-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\9&EV(&ED/2)M96YU(CX*(#QH,2!C;&%S<STB
M;&5F=$9L;V%T(CX\/W!H<"!P<FEN=&8H7R@B5V5L8V]M92P@)7,B*2P@:'1M
M;'-P96-I86QC:&%R<R@D9G5L;&YA;64I*2`_/CPO:#$^"B`\9&EV(&-L87-S
M/2)R:6=H=$9L;V%T(CX*/#]P:'`*)&UE;G4@/2`F;F5W($UE;G4H*3L*)&UE
M;G4M/F%D9"A(;W)D93HZ87!P;&EC871I;VY5<FPH)W-E<G9I8V5S+W!O<G1A
M;"\G*2P@7R@B2&]?;64B*2P@)VAO<F1E+G!N9R<I.PII9B`H(21P<F5F<RT^
M:7-,;V-K960H)W!O<G1A;%]L87EO=70G*2D@>PH@("`@)&UE;G4M/F%D9"A(
M;W)D93HZ87!P;&EC871I;VY5<FPH)W-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H
M<"<I+"!?*"),85]Y;W5T(BDL("=L87EO=70N<&YG)RD["GT*:68@*$%U=&@Z
M.FES061M:6XH*2D@>PH@("`@)&UE;G4M/F%D9"A(;W)D93HZ87!P;&EC871I
M;VY5<FPH)V%D;6EN+R<I+"!?*")?061M:6YI<W1R871I;VXB*2P@)V%D;6EN
M:7-T<F%T:6]N+G!N9R<I.PI]"F5C:&\@)&UE;G4M/G)E;F1E<B@I.PH_/@H@
M/"]D:78^"CPO9&EV/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<&]R
M=&%L+W-I9&5B87(N:6YC````````````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#$V,3(V`#$P-3$U-#,S-S8Q`#`R,S(V-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\9&EV(&ED/2)E>'!A;F1E9%-I9&5B
M87(B('-T>6QE/2)O=F5R9FQO=SIH:61D96XB/@H@/&1I=B!I9#TB;65N=2(@
M<W1Y;&4](F]V97)F;&]W.FAI9&1E;B(^"B`@/#]P:'`@:68@*"%E;7!T>2@D
M8V]N9ELG;&]G;R==6R=I;6%G92==*2!\?"`A571I;#HZ9V5T1F]R;41A=&$H
M)VUO>F)A<B<I*3H@/SX*("`\<W!A;B!C;&%S<STB;&5F=$9L;V%T(CP_<&AP
M(&EF("AE;7!T>2@D8V]N9ELG;&]G;R==6R=I;6%G92==*2D@96-H;R`G(&ED
M/2)T:&5M96QO9V\B)R`_/CX*("`\/W!H<`H@(&EF("@A96UP='DH)&-O;F9;
M)VQO9V\G75LG:6UA9V4G72DI('L*("`@("`@:68@*"%E;7!T>2@D8V]N9ELG
M;&]G;R==6R=L:6YK)UTI*2!["B`@("`@("`@("!E8VAO($AO<F1E.CIL:6YK
M*"1C;VYF6R=L;V=O)UU;)VQI;FLG72P@;G5L;"P@;G5L;"P@)U]T;W`G*3L*
M("`@("`@?0H@("`@("!E8VAO($AO<F1E.CII;6<H)&-O;F9;)VQO9V\G75LG
M:6UA9V4G72P@)R<L("<G+"`G)RD["B`@("`@(&EF("@A96UP='DH)&-O;F9;
M)VQO9V\G75LG;&EN:R==*2D@>PH@("`@("`@("`@96-H;R`G/"]A/B<["B`@
M("`@('T*("!](&5L<V4@>PH@("`@("!E8VAO("<F;F)S<#LG.PH@('T*("`_
M/@H@(#PO<W!A;CX*("`\<W!A;B!C;&%S<STB;&5F=$9L;V%T(B!I9#TB;&]G
M;W!A9"(^)FYB<W`[/"]S<&%N/@H@(#QD:78@8VQA<W,](F-L96%R(CXF;F)S
M<#L\+V1I=CX*("`\/W!H<"!E;F1I9CL@/SX*(#PO9&EV/@H@/'-P86X@:60]
M(F5X<&%N9$)U='1O;B(@8VQA<W,](G)I9VAT1FQO870B/CP_<&AP(&EF("@A
M)&ES7VUO>F)A<BD@96-H;R!(;W)D93HZ;&EN:R@G(R<L(%\H(D-O;&QA<'-E
M(%-I9&5B87(B*2P@)R<L("<G+"`G=&]G9VQE365N=49R86UE*"D[(')E='5R
M;B!F86QS93LG+"!?*")#;VQL87!S92!3:61E8F%R(BDI("X@2&]R9&4Z.FEM
M9R@G:&ED95]P86YE;"YP;F<G*2`N("<\+V$^)R`_/CPO<W!A;CX*(#QD:78@
M:60](G-I9&5B87)086YE;"(^"B`@/#]P:'`@)'1R964M/G)E;F1E<E1R964H
M*2`_/@H@/"]D:78^"@H\(2TM(&YE=W-F965D<R`M+3X*/'-C<FEP="!L86YG
M=6%G93TB:F%V87-C<FEP="(@='EP93TB=&5X="]J879A<V-R:7!T(CX*9&]C
M=6UE;G0N=W)I=&4H)SQS8W)I<'0@;&%N9W5A9V4](FIA=F%S8W)I<'0B('1Y
M<&4](G1E>'0O:F%V87-C<FEP="(@<W)C/2)H='1P.B\O)PH@("`@*R!L;V-A
M=&EO;BYH;W-T;F%M92`K("<Z.#@X,"]J879A<V-R:7!T+VYE=W-F965D<RYJ
M<RYP:'`B/CPO)R`K("=S8W)I<'0^7&XG*3L*/"]S8W)I<'0^"CQS8W)I<'0@
M;&%N9W5A9V4](FIA=F%S8W)I<'0B('1Y<&4](G1E>'0O:F%V87-C<FEP="(^
M"F9U;F-T:6]N(&-R96%T94-O;VMI92AN86UE+'9A;'5E+&1A>7,I('L*("!I
M9B`H9&%Y<RD@>PH@("`@=F%R(&1A=&4@/2!N97<@1&%T92@I.PH@("`@9&%T
M92YS9714:6UE*&1A=&4N9V5T5&EM92@I*RAD87ES*C(T*C8P*C8P*C$P,#`I
M*3L*("`@('9A<B!E>'!I<F5S(#T@(CL@97AP:7)E<STB*V1A=&4N=&]'3513
M=')I;F<H*3L*("!]"B`@96QS92!V87(@97AP:7)E<R`]("(B.PH@(&1O8W5M
M96YT+F-O;VMI92`](&YA;64K(CTB*W9A;'5E*V5X<&ER97,K(CL@<&%T:#TO
M(CL*?0H*9G5N8W1I;VX@<F5A9$-O;VMI92AN86UE*2!["B`@=F%R(&YA;65%
M42`](&YA;64@*R`B/2(["B`@=F%R(&-A(#T@9&]C=6UE;G0N8V]O:VEE+G-P
M;&ET*"<[)RD["B`@9F]R*'9A<B!I/3`[:2`\(&-A+FQE;F=T:#MI*RLI('L*
M("`@('9A<B!C(#T@8V%;:5T["B`@("!W:&EL92`H8RYC:&%R070H,"D]/2<@
M)RD@8R`](&,N<W5B<W1R:6YG*#$L8RYL96YG=&@I.PH@("`@:68@*&,N:6YD
M97A/9BAN86UE15$I(#T](#`I(')E='5R;B!C+G-U8G-T<FEN9RAN86UE15$N
M;&5N9W1H+&,N;&5N9W1H*3L*("!]"B`@<F5T=7)N(&YU;&P["GT*"F9U;F-T
M:6]N(&5R87-E0V]O:VEE*&YA;64I('L*("!C<F5A=&5#;V]K:64H;F%M92PB
M(BPM,2D["GT*9G5N8W1I;VX@:&%S0VQA<W,H96QE;65N="P@8VQA<W-.86UE
M*0I["B`@("!V87(@8VQA<W-E<R`](&5L96UE;G0N8VQA<W-.86UE+G-P;&ET
M*"<@)RD["B`@9F]R("AV87(@:2!I;B!C;&%S<V5S*2!["B`@("!I9B`H8VQA
M<W-E<UMI72`]/2!C;&%S<TYA;64I"B`@("`@(')E='5R;B!T<G5E.PH@('T*
M("!R971U<FX@9F%L<V4["GT*"F9U;F-T:6]N(&%D9$-L87-S*&5L96UE;G0L
M(&-L87-S3F%M92D*>PH@(&EF("@A:&%S0VQA<W,H96QE;65N="P@8VQA<W-.
M86UE*2D*("`@(&5L96UE;G0N8VQA<W-.86UE(#T@*&5L96UE;G0N8VQA<W-.
M86UE(#T]("<G(#\@8VQA<W-.86UE(#H@96QE;65N="YC;&%S<TYA;64@*R`G
M("<@*R!C;&%S<TYA;64I.PI]"@IF=6YC=&EO;B!R96UO=F5#;&%S<RAE;&5M
M96YT+"!C;&%S<TYA;64I"GL*("!V87(@;F5W5F%L=64@/2`G)SL*("`@('9A
M<B!C;&%S<V5S(#T@96QE;65N="YC;&%S<TYA;64N<W!L:70H)R`G*3L*("!F
M;W(@*'9A<B!I(&EN(&-L87-S97,I('L*("`@(&EF("AC;&%S<V5S6VE=("$]
M(&-L87-S3F%M92D*("`@("`@;F5W5F%L=64@*ST@;F5W5F%L=64N;&5N9W1H
M(#\@)R`G("L@8VQA<W-E<UMI72`Z(&-L87-S97-;:5T["B`@?0H@(&5L96UE
M;G0N8VQA<W-.86UE(#T@;F5W5F%L=64["GT*"@IF=6YC=&EO;B!.1F-O;&QA
M<'-E3&ES="@I('L*("!V87(@3D9C;VYT96YT(#T@9&]C=6UE;G0N9V5T16QE
M;65N=$)Y260H)TY&8V]N=&5N="<I"B`@:68@*'=I;F1O=RY.1F]P96XI('L*
M("`@(&%D9$-L87-S("A.1F-O;G1E;G0L("=.1F-L;W-E)RD["B`@("!R96UO
M=F5#;&%S<R`H3D9C;VYT96YT+"`G3D9O<&5N)RD["B`@("!C<F5A=&5#;V]K
M:64H)W!L97-K7VYE=W-F965D7W9I<VEB;&4G+"`G9F%L<V4G+"`S,"D["B`@
M("!W:6YD;W<N3D9O<&5N(#T@9F%L<V4["B`@?2!E;'-E('L*("`@(&EF("@A
M=VEN9&]W+F%R=&EC;&4I"B`@("`@($Y&9V5T3&ES="@I.PH@("`@861D0VQA
M<W,@*$Y&8V]N=&5N="P@)TY&;W!E;B<I.PH@("`@<F5M;W9E0VQA<W,@*$Y&
M8V]N=&5N="P@)TY&8VQO<V4G*3L*("`@(&-R96%T94-O;VMI92@G<&QE<VM?
M;F5W<V9E961?=FES:6)L92<L("=T<G5E)RP@,S`I.PH@("`@=VEN9&]W+DY&
M;W!E;B`]('1R=64["B`@?0I]"FEF("AW:6YD;W<N3F5W<T9E961S*2!["B`@
M=VEN9&]W+DY&;W!E;B`]("AR96%D0V]O:VEE*"=P;&5S:U]N97=S9F5E9%]V
M:7-I8FQE)RD@/3T@)V9A;'-E)RD@/R!F86QS92`Z('1R=64["B`@9&]C=6UE
M;G0N=W)I=&4H)SQD:78@:60](DY&8V]N=&5N="(@8VQA<W,](G-I9&5B87)0
M86YE;"`G("L@*$Y&;W!E;B`_("=.1F]P96XG(#H@)TY&8VQO<V4G*2`K)R(^
M)RD["B`@9&]C=6UE;G0N=W)I=&4H)SQT86)L92!C96QL<W!A8VEN9STB,"(@
M8V5L;'!A9&1I;F<](B(@=VED=&@](C$P,"4B(&)O<F1E<CTB,"(@8VQA<W,]
M(G-I9&5B87)(96%D97(B/CQT8F]D>3XG*3L*("!D;V-U;65N="YW<FET92@G
M/'1R/B<I.PH@(&1O8W5M96YT+G=R:71E*"<\=&0@8VQA<W,](FAE861E<E1I
M=&QE(CX\/W!H<"!E8VAO(%\H)U1O<"!.97=S)RD[(#\^/"]T9#XG*3L*("!D
M;V-U;65N="YW<FET92@G/'1D(&-L87-S/2)H96%D97)"=71T;VYS(CX\82!H
M<F5F/2)J879A<V-R:7!T.DY&9V5T3&ES="@I.R(@8VQA<W,](F)T;BUR969R
M97-H(B!T:71L93TB/#]P:'`@96-H;R!?*"=2969R97-H)RD[(#\^(CX\<W!A
M;CX\/W!H<"!E8VAO(%\H)U)E9G)E<V@G*3L@/SX\+W-P86X^/"]A/CQA(&AR
M968](FIA=F%S8W)I<'0Z3D9C;VQL87!S94QI<W0H*3LB(&-L87-S/2)B=&XM
M;W!E;BUC;&]S92(@=&ET;&4](CP_<&AP(&5C:&\@7R@G3W!E;B]#;&]S92<I
M.R`_/B(^/'-P86X^/#]P:'`@96-H;R!?*"=/<&5N+T-L;W-E)RD[(#\^/"]S
M<&%N/CPO83X\+W1D/B<I.PH@(&1O8W5M96YT+G=R:71E*"<\+W1R/B<I.PH@
M(&1O8W5M96YT+G=R:71E*"<\+W1B;V1Y/CPO=&%B;&4^)RD["B`@9&]C=6UE
M;G0N=W)I=&4H)SQD:78@:60](FYE=W-&965D<R(^/"]D:78^)RD["B`@9&]C
M=6UE;G0N=W)I=&4H)SPO9&EV/B<I.PH@(&EF("AW:6YD;W<N3D9O<&5N("8F
M(')E861#;V]K:64H)VAO<F1E7W-I9&5B87)?97AP86YD960G*2`A/2`G9F%L
M<V4G*0H@("`@3D9G971,:7-T*"D["GT*/"]S8W)I<'0^"CPA+2T@+VYE=W-F
M965D<R`M+3X*/"]D:78^"@H\9&EV(&ED/2)H:61D96Y3:61E8F%R(CX*(#QD
M:78@:60](FUE;G4B/@H@/"]D:78^"B`@/#]P:'`@96-H;R!(;W)D93HZ;&EN
M:R@G(R<L("<G+"`G)RP@)R<L("=T;V=G;&5-96YU1G)A;64H*3L@<F5T=7)N
M(&9A;'-E.R<I("X@2&]R9&4Z.FEM9R@G<VAO=U]P86YE;"YP;F<G*2`N("<\
M+V$^)R`_/@H\+V1I=CX*"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T
M(CX*"G9A<B!R=&P@/2`\/W!H<"!E8VAO("1R=&P@/R`G=')U92<@.B`G9F%L
M<V4G(#\^.PIV87(@97AP86YD9613:61E8F%R(#T@;F5W($AO<F1E7TAI9&5A
M8FQE*"=E>'!A;F1E9%-I9&5B87(G*3L*=F%R(&AI9&1E;E-I9&5B87(@/2!N
M97<@2&]R9&5?2&ED96%B;&4H)VAI9&1E;E-I9&5B87(G*3L*:&ED9&5N4VED
M96)A<BYH:61E*"D["@IF=6YC=&EO;B!G971#;V]K:64H;F%M92P@9&5F;'0I
M"GL*("`@('9A<B!D8R`](&1O8W5M96YT+F-O;VMI93L*("`@('9A<B!P<F5F
M:7@@/2!N86UE("L@)STG.PH@("`@=F%R(&)E9VEN(#T@9&,N:6YD97A/9B@G
M.R`G("L@<')E9FEX*3L*("`@(&EF("AB96=I;B`]/2`M,2D@>PH@("`@("`@
M(&)E9VEN(#T@9&,N:6YD97A/9BAP<F5F:7@I.PH@("`@("`@(&EF("AB96=I
M;B`A/2`P*2!["B`@("`@("`@("`@(')E='5R;B!D969L=#L*("`@("`@("!]
M"B`@("!](&5L<V4@>PH@("`@("`@(&)E9VEN("L](#(["B`@("!]"B`@("!V
M87(@96YD(#T@9&]C=6UE;G0N8V]O:VEE+FEN9&5X3V8H)SLG+"!B96=I;BD[
M"B`@("!I9B`H96YD(#T]("TQ*2!["B`@("`@("`@96YD(#T@9&,N;&5N9W1H
M.PH@("`@?0H@("`@<F5T=7)N('5N97-C87!E*&1C+G-U8G-T<FEN9RAB96=I
M;B`K('!R969I>"YL96YG=&@L(&5N9"DI.PI]"@IF=6YC=&EO;B!T;V=G;&5-
M96YU1G)A;64H*0I["B`@("!I9B`H<&%R96YT("8F('!A<F5N="YD;V-U;65N
M="YG971%;&5M96YT0GE)9"@G:&8G*2D@>PH@("`@("`@(&EF("AE>'!A;F1E
M9%-I9&5B87(N<VAO=VXH*2D@>PH@("`@("`@("`@("!P87)E;G0N9&]C=6UE
M;G0N9V5T16QE;65N=$)Y260H)VAF)RDN8V]L<R`](')T;"`_("<J+#(P)R`Z
M("<R,"PJ)SL*("`@("`@("`@("`@97AP86YD9613:61E8F%R+FAI9&4H*3L*
M("`@("`@("`@("`@:&ED9&5N4VED96)A<BYS:&]W*"D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<&%R96YT+F1O8W5M96YT+F=E=$5L96UE;G1"
M>4ED*"=H9B<I+F-O;',@/2`H<G1L(#\@)RHL)R`Z("<G*2`K(#P_<&AP(&5C
M:&\@*&ES<V5T*"1P<F5F<RD@/R`D<')E9G,M/F=E=%9A;'5E*"=S:61E8F%R
M7W=I9'1H)RD@.B`Q-3`I(#\^("L@*')T;"`_("<G(#H@)RPJ)RD["B`@("`@
M("`@("`@(&EF("AW:6YD;W<N3D9O<&5N("8F("%W:6YD;W<N87)T:6-L92D*
M("`@("`@("`@("`@("!.1F=E=$QI<W0H*3L*("`@("`@("`@("`@:&ED9&5N
M4VED96)A<BYH:61E*"D["B`@("`@("`@("`@(&5X<&%N9&5D4VED96)A<BYS
M:&]W*"D["B`@("`@("`@?0H*("`@("`@("`O+R!%>'!I<F4@:6X@;VYE('EE
M87(N"B`@("`@("`@=F%R(&5X<&ER97,@/2!N97<@1&%T92@I.PH@("`@("`@
M(&5X<&ER97,N<V5T5&EM92AE>'!I<F5S+F=E=%1I;64H*2`K(#,Q-3,V,#`P
M,#`P*3L*("`@("`@("!D;V-U;65N="YC;V]K:64@/2`G:&]R9&5?<VED96)A
M<E]E>'!A;F1E9#TG("L@97AP86YD9613:61E8F%R+G-H;W=N*"D@*R`G.T1/
M34%)3CT\/W!H<"!E8VAO("1'3$]"04Q36R=C;VYF)UU;)V-O;VMI92==6R=D
M;VUA:6XG72`_/CM0051(/3P_<&AP(&5C:&\@)$=,3T)!3%-;)V-O;F8G75LG
M8V]O:VEE)UU;)W!A=&@G72`_/CME>'!I<F5S/2<@*R!E>'!I<F5S+G1O1TU4
M4W1R:6YG*"D["B`@("!]"GT*"FEF("AG971#;V]K:64H)VAO<F1E7W-I9&5B
M87)?97AP86YD960G+"!T<G5E*2YT;U-T<FEN9R@I("$](&5X<&%N9&5D4VED
M96)A<BYS:&]W;B@I+G1O4W1R:6YG*"DI('L*("`@('1O9V=L94UE;G5&<F%M
M92@I.PI]"@IV87(@365N=55P9&%T94AA;F1L97(@/2!["B`@("!O;DQO860Z
M(&9U;F-T:6]N*')E<W5L="D*("`@('L*("`@("`@("`O+R!2=6X@=&AE(&IA
M=F%S8W)I<'0@=V4@9V]T(&)A8VLN"B`@("`@("`@979A;"AR97-U;'0I.PH@
M("`@?0I].PH*9G5N8W1I;VX@=7!D871E*"D*>PH@("`@=F%R(&-L:65N="`]
M(&YE=R!(5%100VQI96YT*"D["B`@("!C;&EE;G0N:6YI="@B/#]P:'`@96-H
M;R!(;W)D93HZ87!P;&EC871I;VY5<FPH)W-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#]H='1P8VQI96YT/3$G+"!T<G5E*2`_/B(I.PH*("`@('1R>2![
M"B`@("`@("`@8VQI96YT+F%S>6YC1T54*$UE;G55<&1A=&5(86YD;&5R*3L*
M("`@('T@8V%T8V@@*&4I('L*("`@("`@("`O+R!$;VXG="!D;R!A;GET:&EN
M9R!O;B!E<G)O<G,[('!R;V)A8FQY(&$@=')A;G-I96YT(&9A:6QU<F4L"B`@
M("`@("`@+R\@86YD('=E)VQL('1R>2!A9V%I;B!A9G1E<B!T:&4@;F5X="!I
M;G1E<G9A;"X*("`@('T*("`@('=I;F1O=RYS9714:6UE;W5T*"=U<&1A=&4H
M*3LG+"`\/W!H<"!E8VAO("1P<F5F<RT^9V5T5F%L=64H)VUE;G5?<F5F<F5S
M:%]T:6UE)RD@/SX@*B`Q,#`P*3L*?0H*/#]P:'`@:68@*"1P<F5F<RT^9V5T
M5F%L=64H)VUE;G5?<F5F<F5S:%]T:6UE)RDI.B`_/@HO+R!5<&1A=&4@=&AE
M(&UE;G4@:68@<V5T(&EN('5S97(@<')E9G,N"CP_<&AP(&EF("@D1TQ/0D%,
M4ULG8G)O=W-E<B==+3YH87-&96%T=7)E*"=X;6QH='1P<F5Q)RDI.B`_/@IW
M:6YD;W<N<V5T5&EM96]U="@G=7!D871E*"D[)RP@/#]P:'`@96-H;R`D<')E
M9G,M/F=E=%9A;'5E*"=M96YU7W)E9G)E<VA?=&EM92<I(#\^("H@,3`P,"D[
M"CP_<&AP(&5L<V4Z(#\^"G=I;F1O=RYS9714:6UE;W5T*"=W:6YD;W<N;&]C
M871I;VXN<F5L;V%D*'1R=64I.R<L(#P_<&AP(&5C:&\@)'!R969S+3YG9716
M86QU92@G;65N=5]R969R97-H7W1I;64G*2`_/B`J(#$P,#`I.PH\/W!H<"!E
M;F1I9CL@96YD:68[(#\^"@H\+W-C<FEP=#X*"CP_<&AP(&EF("AI<W-E="@D
M1TQ/0D%,4ULG;F]T:69I8V%T:6]N)UTI*2`D1TQ/0D%,4ULG;F]T:69I8V%T
M:6]N)UTM/FYO=&EF>2AA<G)A>2@G;&ES=&5N97)S)R`]/B!A<G)A>2@G:F%V
M87-C<FEP="<I*2D@/SX*"CPO8F]D>3X*/"]H=&UL/@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]P
M<F5F<R\`````````````````````````````````````````````````````
M````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`U,34T,S,W-C``,#(P-S<Q`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&5M<&QA=&5S+W!R969S+V%P<"YI;F,`````````````````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$S-0`Q,#4Q-30S,S<V,``P,C(R-#4`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/&9O
M<FT@;65T:&]D/2)G970B(&YA;64](F%P<'-W:71C:"(@86-T:6]N/2(\/W!H
M<"!E8VAO("1R96=I<W1R>2T^9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G
M+W-E<G9I8V5S+W!R969S+G!H<"<@/SXB/@H\/W!H<"!E8VAO(%5T:6PZ.F9O
M<FU);G!U="@I(#\^"CQD:78@8VQA<W,](FAE861E<B(^"B`\<W!A;B!C;&%S
M<STB<VUA;&QH96%D97(@<FEG:'1&;&]A="(^"B`@/#]P:'`@96-H;R!?*")%
M9&ET(&]P=&EO;G,@9F]R.B(I(#\^"B`@/'-E;&5C="!N86UE/2)A<'`B(&]N
M8VAA;F=E/2)D;V-U;65N="YA<'!S=VET8V@N<W5B;6ET*"D[(CX*("`@(#QO
M<'1I;VX@=F%L=64](B(^/#]P:'`@96-H;R!?*")#:&]O<V4@07!P;&EC871I
M;VXZ(BD@/SX\+V]P=&EO;CX*/#]P:'`@:68@*"%E;7!T>2@D87!P<ULG:&]R
M9&4G72DI.B`_/@H@("`@/&]P=&EO;B!V86QU93TB(CXM+2TM/"]O<'1I;VX^
M"B`@("`\;W!T:6]N('9A;'5E/2)H;W)D92(^/#]P:'`@96-H;R!?*")';&]B
M86P@3W!T:6]N<R(I(#\^/"]O<'1I;VX^"B`@("`\;W!T:6]N('9A;'5E/2(B
M/BTM+2T\+V]P=&EO;CX*/#]P:'`@96YD:68[(#\^"B`@(#P_<&AP(&9O<F5A
M8V@@*"1A<'!S(&%S("1K97D@/3X@)'9A;"DZ(&EF("@D:V5Y(#T]("=H;W)D
M92<I(&-O;G1I;G5E.R`_/@H@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1K97DI(#\^(CX\/W!H<"!E8VAO(&AT;6QS
M<&5C:6%L8VAA<G,H)'9A;"D@/SX\+V]P=&EO;CX*("`@/#]P:'`@96YD9F]R
M96%C:#L@/SX*("`\+W-E;&5C=#X*("`\:6YP=70@8VQA<W,](F)U='1O;B(@
M='EP93TB<W5B;6ET(B!O;F-L:6-K/2)R971U<FX@9&]C=6UE;G0N87!P<W=I
M=&-H+F%P<"YS96QE8W1E9$EN9&5X("$](#`[(B!V86QU93TB/#]P:'`@96-H
M;R!?*")';R(I(#\^(B`O/@H@/"]S<&%N/@H@/#]P:'`@:68@*"1R96=I<W1R
M>2T^9V5T07!P*"D@/3T@)VAO<F1E)RD@96-H;R!?*")';&]B86P@3W!T:6]N
M<R(I.R!E;'-E('!R:6YT9BA?*")/<'1I;VYS(&9O<B`E<R(I+"`D<F5G:7-T
M<GDM/F=E="@G;F%M92<I*2`_/@H@/&)R(&-L87-S/2)C;&5A<B(@+SX*/"]D
M:78^"CPO9F]R;3X*/&)R(&-L87-S/2)S<&%C97(B("\^"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O
M8F5G:6XN:6YC````````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M-S<W`#$P-3$U-#,S-S8P`#`R,C4V,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\9F]R;2!M971H;V0](G!O<W0B(&YA;64]
M(G!R969S(B!A8W1I;VX](CP_<&AP(&5C:&\@2&]R9&4Z.G-E;&95<FPH*2`_
M/B(^"CP_<&AP(%5T:6PZ.G!F;W)M26YP=70H*2`_/@H\:6YP=70@='EP93TB
M:&ED9&5N(B!N86UE/2)A8W1I;VY)1"(@=F%L=64](G5P9&%T95]P<F5F<R(@
M+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB9W)O=7`B('9A;'5E/2(\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&=R;W5P*2`_/B(@+SX*/&EN
M<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB87!P(B!V86QU93TB/#]P:'`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1A<'`I(#\^(B`O/@H*/&1I=B!C;&%S<STB
M:&5A9&5R(CX*(#P_<&AP(%!R969S7U5).CIG96YE<F%T94YA=FEG871I;VY#
M96QL*"1G<F]U<"D@/SX*(#P_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D
M<')E9D=R;W5P<ULD9W)O=7!=6R=L86)E;"==*2`_/@H@/&)R(&-L87-S/2)C
M;&5A<B(@+SX*/"]D:78^"@H\9&EV(&-L87-S/2)I=&5M(CX*`"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,`````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,38Q,P`Q,#4Q-30S
M,S<V,``P,C4S-#``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM
M"F9U;F-T:6]N(')E;6]V92AC871E9V]R>2D*>PH@("`@9&]C=6UE;G0N<')E
M9G,N8T%C=&EO;BYV86QU92`]("=R96UO=F4G.PH@("`@9&]C=6UE;G0N<')E
M9G,N8V%T96=O<GDN=F%L=64@/2!C871E9V]R>3L*("`@(&1O8W5M96YT+G!R
M969S+G-U8FUI="@I.PI]"@IF=6YC=&EO;B!A9&0H*0I["B`@("!V87(@8V%T
M96=O<GD@/2!W:6YD;W<N<')O;7!T*"<\/W!H<"!E8VAO(&%D9'-L87-H97,H
M7R@B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB
M*2D@/SXG+"`G)RD["B`@("!I9B`H8V%T96=O<GD@(3T@;G5L;"`F)B!C871E
M9V]R>2`A/2`G)RD@>PH@("`@("`@(&1O8W5M96YT+G!R969S+F-!8W1I;VXN
M=F%L=64@/2`G861D)SL*("`@("`@("!D;V-U;65N="YP<F5F<RYC871E9V]R
M>2YV86QU92`](&-A=&5G;W)Y.PH@("`@("`@(&1O8W5M96YT+G!R969S+G-U
M8FUI="@I.PH@("`@?0I]"B\O+2T^"CPO<V-R:7!T/@H\:6YP=70@;F%M93TB
M8T%C=&EO;B(@=F%L=64](B(@='EP93TB:&ED9&5N(B`O/@H\:6YP=70@;F%M
M93TB8V%T96=O<GDB('9A;'5E/2(B('1Y<&4](FAI9&1E;B(@+SX*/'1A8FQE
M/@H@/'1R/@H@(#QT9"!C;VQS<&%N/2(R(CX*("`@/&EN<'5T('1Y<&4](F)U
M='1O;B(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B3F5W
M($-A=&5G;W)Y(BD@/SXB(&]N8VQI8VL](F%D9"@I.R(@+SX*("`\+W1D/@H@
M/"]T<CX*/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<"<["B1C36%N86=E<B`]("9N97<@4')E9G-?0V%T96=O
M<GE-86YA9V5R*"D["B1C871E9V]R:65S(#T@)&--86YA9V5R+3YG970H*3L*
M)&-O;&]R<R`]("1C36%N86=E<BT^8V]L;W)S*"D["B1F9V-O;&]R<R`]("1C
M36%N86=E<BT^9F=#;VQO<G,H*3L*)'5R;"`]($AO<F1E.CIU<FPH)')E9VES
M=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<V5R=FEC97,O:6UA
M9V5S+V-O;&]R<&EC:V5R+G!H<"<I.PHD=7)L(#T@571I;#HZ861D4&%R86UE
M=&5R*"1U<FPL("=F;W)M)RP@)W!R969S)RD["@HO+R!$969A=6QT($-O;&]R
M"B1C;VQO<B`](&ES<V5T*"1C;VQO<G-;)U]D969A=6QT7R==*2`_("1C;VQO
M<G-;)U]D969A=6QT7R==(#H@)R-&1D9&1D8G.PHD9F=C;VQO<B`](&ES<V5T
M*"1F9V-O;&]R<ULG7V1E9F%U;'1?)UTI(#\@)&9G8V]L;W)S6R=?9&5F875L
M=%\G72`Z("<C,#`P,#`P)SL*)&-?=7)L(#T@571I;#HZ861D4&%R86UE=&5R
M*"1U<FPL("=T87)G970G+"`G8V]L;W)?)R`N(&)A<V4V-%]E;F-O9&4H)U]D
M969A=6QT7R<I*3L*/SX*(#QT<CX*("`\=&0@<W1Y;&4](F)A8VMG<F]U;F0Z
M/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1C;VQO<BD@/SX[(&-O;&]R
M.CP_<&AP(&5C:&\@)&9G8V]L;W(@/SXB/CQS=')O;F<^/#]P:'`@96-H;R!?
M*")$969A=6QT($-O;&]R(BD@/SX\+W-T<F]N9SX\+W1D/@H@(#QT9#X*("`@
M/#]P:'`@:68@*"$D<')E9G,M/FES3&]C:V5D*"=C871E9V]R>5]C;VQO<G,G
M*2DZ(#\^"B`@("`\:6YP=70@8VQA<W,](F9I>&5D(B!S:7IE/2(W(B!S='EL
M93TB8F%C:V=R;W5N9#H\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&-O
M;&]R*2`_/CL@8V]L;W(Z/#]P:'`@96-H;R`D9F=C;VQO<B`_/B(@;F%M93TB
M8V]L;W)?/#]P:'`@96-H;R!B87-E-C1?96YC;V1E*"=?9&5F875L=%\G*2`_
M/B(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D8V]L;W(I
M(#\^(B`O/@H@("`@/&$@:')E9CTB/#]P:'`@96-H;R`D8U]U<FP@/SXB(&]N
M8VQI8VL](G=I;F1O=RYO<&5N*"<\/W!H<"!E8VAO("1C7W5R;"`_/B<L("=C
M;VQO<G!I8VME<B<L("=T;V]L8F%R/6YO+&QO8V%T:6]N/6YO+'-T871U<SUN
M;RQS8W)O;&QB87)S/6YO+')E<VEZ86)L93UN;RQW:61T:#TQ,C`L:&5I9VAT
M/3(U,"QL969T/3$P,"QT;W`],3`P)RD[(')E='5R;B!F86QS93LB(&]N;6]U
M<V5O=70](G=I;F1O=RYS=&%T=7,])R<[(B!O;FUO=7-E;W9E<CTB=VEN9&]W
M+G-T871U<STG/#]P:'`@96-H;R!?*")#;VQO<B!0:6-K97(B*2`_/B<[(')E
M='5R;B!T<G5E.R(@8VQA<W,](G=I9&=E="(@=&%R9V5T/2)C;VQO<G!I8VME
M<B(^"B`@("`\/W!H<"!E8VAO($AO<F1E.CII;6<H)V-O;&]R<&EC:V5R+G!N
M9R<L(%\H(D-O;&]R(%!I8VME<B(I+"`G:&5I9VAT/2(Q-B(G+"`D<F5G:7-T
M<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`_/CPO83X*("`@/#]P:'`@96YD
M:68[(#\^"B`@/"]T9#X*(#PO='(^"CP_<&AP"B\O(%5N9FEL960@0V]L;W(*
M)&-O;&]R(#T@:7-S970H)&-O;&]R<ULG7W5N9FEL961?)UTI(#\@)&-O;&]R
M<ULG7W5N9FEL961?)UT@.B`G(T9&1D9&1B<["B1F9V-O;&]R(#T@:7-S970H
M)&9G8V]L;W)S6R=?=6YF:6QE9%\G72D@/R`D9F=C;VQO<G-;)U]U;F9I;&5D
M7R==(#H@)R,P,#`P,#`G.PHD8U]U<FP@/2!5=&EL.CIA9&1087)A;65T97(H
M)'5R;"P@)W1A<F=E="<L("=C;VQO<E\G("X@8F%S938T7V5N8V]D92@G7W5N
M9FEL961?)RDI.PH_/@H@/'1R/@H@(#QT9"!S='EL93TB8F%C:V=R;W5N9#H\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&-O;&]R*2`_/CL@8V]L;W(Z
M/#]P:'`@96-H;R`D9F=C;VQO<B`_/B(^/'-T<F]N9SX\/W!H<"!E8VAO(%\H
M(E5N9FEL960B*2`_/CPO<W1R;VYG/CPO=&0^"B`@/'1D/@H@("`\/W!H<"!I
M9B`H(21P<F5F<RT^:7-,;V-K960H)V-A=&5G;W)Y7V-O;&]R<R<I*3H@/SX*
M("`@(#QI;G!U="!C;&%S<STB9FEX960B('-I>F4](C<B('-T>6QE/2)B86-K
M9W)O=6YD.CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D8V]L;W(I(#\^
M.R!C;VQO<CH\/W!H<"!E8VAO("1F9V-O;&]R(#\^(B!N86UE/2)C;VQO<E\\
M/W!H<"!E8VAO(&)A<V4V-%]E;F-O9&4H)U]U;F9I;&5D7R<I(#\^(B!V86QU
M93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1C;VQO<BD@/SXB("\^
M"B`@("`\82!H<F5F/2(\/W!H<"!E8VAO("1C7W5R;"`_/B(@;VYC;&EC:STB
M=VEN9&]W+F]P96XH)SP_<&AP(&5C:&\@)&-?=7)L(#\^)RP@)V-O;&]R<&EC
M:V5R)RP@)W1O;VQB87(];F\L;&]C871I;VX];F\L<W1A='5S/6YO+'-C<F]L
M;&)A<G,];F\L<F5S:7IA8FQE/6YO+'=I9'1H/3$R,"QH96EG:'0],C4P+&QE
M9G0],3`P+'1O<#TQ,#`G*3L@<F5T=7)N(&9A;'-E.R(@;VYM;W5S96]U=#TB
M=VEN9&]W+G-T871U<STG)SLB(&]N;6]U<V5O=F5R/2)W:6YD;W<N<W1A='5S
M/2<\/W!H<"!E8VAO(%\H(D-O;&]R(%!I8VME<B(I(#\^)SL@<F5T=7)N('1R
M=64[(B!C;&%S<STB=VED9V5T(B!T87)G970](F-O;&]R<&EC:V5R(CX*("`@
M(#P_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G8V]L;W)P:6-K97(N<&YG)RP@7R@B
M0V]L;W(@4&EC:V5R(BDL("=H96EG:'0](C$V(B<L("1R96=I<W1R>2T^9V5T
M26UA9V5$:7(H)VAO<F1E)RDI(#\^/"]A/@H@("`\/W!H<"!E;F1I9CL@/SX*
M("`\+W1D/@H@/"]T<CX*/#]P:'`*9F]R96%C:"`H)&-A=&5G;W)I97,@87,@
M)&YA;64I.@H@("`@)&-O;&]R(#T@:7-S970H)&-O;&]R<ULD;F%M95TI(#\@
M)&-O;&]R<ULD;F%M95T@.B`G(T9&1D9&1B<["B`@("`D9F=C;VQO<B`](&ES
M<V5T*"1F9V-O;&]R<ULD;F%M95TI(#\@)&9G8V]L;W)S6R1N86UE72`Z("<C
M,#`P,#`P)SL*("`@("1C7W5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L
M+"`G=&%R9V5T)RP@)V-O;&]R7R<@+B!B87-E-C1?96YC;V1E*"1N86UE*2D[
M"C\^"B`\='(^"B`@/'1D('-T>6QE/2)B86-K9W)O=6YD.CP_<&AP(&5C:&\@
M:'1M;'-P96-I86QC:&%R<R@D8V]L;W(I(#\^.R!C;VQO<CH\/W!H<"!E8VAO
M("1F9V-O;&]R(#\^(CX\<W1R;VYG/CP_<&AP(&5C:&\@*"1N86UE(#T]("=?
M9&5F875L=%\G(#\@7R@B1&5F875L="!#;VQO<B(I(#H@:'1M;'-P96-I86QC
M:&%R<R@D;F%M92DI(#\^/"]S=')O;F<^/"]T9#X*("`\=&0^"B`@(#P_<&AP
M(&EF("@A)'!R969S+3YI<TQO8VME9"@G8V%T96=O<GE?8V]L;W)S)RDI.B`_
M/@H@("`@/&EN<'5T(&-L87-S/2)F:7AE9"(@<VEZ93TB-R(@<W1Y;&4](F)A
M8VMG<F]U;F0Z/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1C;VQO<BD@
M/SX[(&-O;&]R.CP_<&AP(&5C:&\@)&9G8V]L;W(@/SXB(&YA;64](F-O;&]R
M7SP_<&AP(&5C:&\@8F%S938T7V5N8V]D92@D;F%M92D@/SXB('9A;'5E/2(\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&-O;&]R*2`_/B(@+SX*("`@
M(#QA(&AR968](CP_<&AP(&5C:&\@)&-?=7)L(#\^(B!O;F-L:6-K/2)W:6YD
M;W<N;W!E;B@G/#]P:'`@96-H;R`D8U]U<FP@/SXG+"`G8V]L;W)P:6-K97(G
M+"`G=&]O;&)A<CUN;RQL;V-A=&EO;CUN;RQS=&%T=7,];F\L<V-R;VQL8F%R
M<SUN;RQR97-I>F%B;&4];F\L=VED=&@],3(P+&AE:6=H=#TR-3`L;&5F=#TQ
M,#`L=&]P/3$P,"<I.R!R971U<FX@9F%L<V4[(B!O;FUO=7-E;W5T/2)W:6YD
M;W<N<W1A='5S/2<G.R(@;VYM;W5S96]V97(](G=I;F1O=RYS=&%T=7,])SP_
M<&AP(&5C:&\@7R@B0V]L;W(@4&EC:V5R(BD@/SXG.R!R971U<FX@=')U93LB
M(&-L87-S/2)W:61G970B('1A<F=E=#TB8V]L;W)P:6-K97(B/@H@("`@/#]P
M:'`@96-H;R!(;W)D93HZ:6UG*"=C;VQO<G!I8VME<BYP;F<G+"!?*")#;VQO
M<B!0:6-K97(B*2P@)VAE:6=H=#TB,38B)RP@)')E9VES=')Y+3YG971);6%G
M941I<B@G:&]R9&4G*2D@/SX\+V$^"B`@("`\/W!H<"!E;F1I9CL@/SX*("`@
M(#QA(&AR968](B,B(&]N8VQI8VL](G)E;6]V92AD96-O9&554DE#;VUP;VYE
M;G0H)SP_<&AP(&5C:&\@<F%W=7)L96YC;V1E*%-T<FEN9SHZ8V]N=F5R=$-H
M87)S970H)&YA;64L($Y,4SHZ9V5T0VAA<G-E="@I+"`G551&+3@G*2D@/SXG
M*2D[(')E='5R;B!F86QS93LB/CP_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G9&5L
M971E+G!N9R<I(#\^/"]A/@H@(#PO=&0^"B`\+W1R/@H\/W!H<"!E;F1F;W)E
M86-H.R`_/@H\+W1A8FQE/@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F<R]C:&5C
M:V)O>"YI;F,`````````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S-S8`
M,3`U,34T,S,W-C``,#(S,C8P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#QI;G!U="!T>7!E/2)C:&5C:V)O>"(@8VQA<W,]
M(F-H96-K8F]X(B!I9#TB/#]P:'`@96-H;R`D<')E9B`_/B(@;F%M93TB/#]P
M:'`@96-H;R`D<')E9B`_/B(\/W!H<"!E8VAO("1P<F5F<RT^9V5T5F%L=64H
M)'!R968I(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G)R`_/B`O/@H\/W!H
M<"!E8VAO($AO<F1E.CIL86)E;"@D<')E9BP@)%]P<F5F<ULD<')E9EU;)V1E
M<V,G72D@/SXF;F)S<#L\/W!H<"!E8VAO("1H96QP;&EN:R`_/@H\8G(@+SX*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN
M:6YC`````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,3,S`#$P-3$U-#,S-S8P
M`#`R-#0W-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<"!I9B`H(21P<F5F<RT^:7-,;V-K960H)V1E9F%U;'1?:61E
M;G1I='DG*2DZ(#\^"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*
M/"$M+0IF=6YC=&EO;B!D96QE=&5)9&5N=&ET>2@I"GL*("`@('9A<B!I;F1E
M>"`](&1O8W5M96YT+G!R969S+FED96YT:71Y+G-E;&5C=&5D26YD97@["B`@
M("!V87(@:60@/2!D;V-U;65N="YP<F5F<RYI9&5N=&ET>2YO<'1I;VYS6VEN
M9&5X72YV86QU93L*("`@(&EF("AI9"`^/2`P*2!["B`@("`@("`@9&]C=6UE
M;G0N;&]C871I;VXN:')E9B`]("(\/W!H<"!E8VAO('-T<E]R97!L86-E*"<F
M86UP.R<L("<F)RP@571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIS96QF57)L
M*'1R=64I+"!A<G)A>2@G86-T:6]N240G(#T^("=D96QE=&5?:61E;G1I='DG
M+"`G:60G(#T^("<G*2DI(#\^(B`K(&ED.PH@("`@?0I]"B\O+2T^"CPO<V-R
M:7!T/@H\8G(@+SX*/&EN<'5T('1Y<&4](F)U='1O;B(@;VYC;&EC:STB9&5L
M971E261E;G1I='DH*2(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C
M:&\@7R@B1&5L971E('-E;&5C=&5D(&ED96YT:71Y(BD@/SXB("\^/&)R("\^
M/&)R("\^"CP_<&AP(&5N9&EF.R`_/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O96YD+FEN8P``
M````````````````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S,Q`#$P-3$U
M-#,S-S8P`#`R,C(S,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\+V1I=CX*"CQB<B!C;&%S<STB<W!A8V5R(B`O/@H\9&EV
M(&-L87-S/2)N;W=R87`B/@H@/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA<W,]
M(F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B4V%V92!/<'1I;VYS(BD@
M/SXB("\^)FYB<W`["B`\:6YP=70@='EP93TB<F5S970B(&-L87-S/2)B=71T
M;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H(E5N9&\@0VAA;F=E<R(I(#\^(B`O
M/B9N8G-P.PH@/#]P:'`@:68@*&-O=6YT*"1P<F5F1W)O=7!S*2`^(#$I.B`_
M/CQI;G!U="!T>7!E/2)B=71T;VXB(&-L87-S/2)B=71T;VXB('9A;'5E/2(\
M/W!H<"!E8VAO(%\H(E)E='5R;B!T;R!/<'1I;VYS(BD@/SXB(&]N8VQI8VL]
M(F1O8W5M96YT+G!R969S+F%C=&EO;DE$+G9A;'5E/3`[(&1O8W5M96YT+G!R
M969S+F=R;W5P+G9A;'5E/2<G.R!D;V-U;65N="YP<F5F<RYS=6)M:70H*3LB
M("\^/#]P:'`@96YD:68[(#\^"CPO9&EV/@H\+V9O<FT^"@``````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&5M<&QA=&5S+W!R969S+V5N=6TN:6YC````````````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`T-0`Q,#4Q-30S,S<V,``P,C(T
M,S``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`@96-H;R!(;W)D93HZ;&%B96PH)'!R968L("1?<')E9G-;)'!R969=
M6R=D97-C)UTI(#\^)FYB<W`[/#]P:'`@96-H;R`D:&5L<&QI;FL@/SX\8G(@
M+SX*/'-E;&5C="!I9#TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1P
M<F5F*2`_/B(@;F%M93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1P
M<F5F*2`_/B(^"CP_<&AP("1E<V,@/2`A96UP='DH)%]P<F5F<ULD<')E9EU;
M)V5S8V%P960G72D[("1C=7)V86P@/2`D<')E9G,M/F=E=%9A;'5E*"1P<F5F
M*3L@9F]R96%C:"`H)%]P<F5F<ULD<')E9EU;)V5N=6TG72!A<R`D:V5Y(#T^
M("1V86PI.B`_/@H\;W!T:6]N/#]P:'`@96-H;R`D8W5R=F%L(#T]("1K97D@
M/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX@=F%L=64](CP_<&AP
M(&5C:&\@)&5S8R`_("1K97D@.B!H=&UL<W!E8VEA;&-H87)S*"1K97DI(#\^
M(CX\/W!H<"!E8VAO("1E<V,@/R`D=F%L(#H@:'1M;'-P96-I86QC:&%R<R@D
M=F%L*2`_/CPO;W!T:6]N/@H\/W!H<"!E;F1F;W)E86-H(#\^"CPO<V5L96-T
M/@H\8G(@+SX*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T
M+FEN8P`````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-3<S,@`Q,#4Q-30S,S<V
M,``P,C0U,C0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`@:68@*"1P<F5F<RT^:7-,;V-K960H)V1E9F%U;'1?:61E
M;G1I='DG*2DZ(#\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](FED96YT
M:71Y(B!V86QU93TB/#]P:'`@96-H;R`H:6YT*21'3$]"04Q36R=I9&5N=&ET
M>2==+3YG971$969A=6QT*"D@/SXB("\^"CP_<&AP(&5L<V4Z(#\^"CQS8W)I
M<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*/"$M+0H*=F%R(&ED96YT:71I
M97,@/2!N97<@07)R87DH*3L*/#]P:'`*9VQO8F%L("1I9&5N=&ET>3L*)&ED
M96YT:71I97,@/2`D:61E;G1I='DM/F=E=$%L;"@G:60G*3L*)&1E9F%U;'1?
M:61E;G1I='D@/2`D:61E;G1I='DM/F=E=$1E9F%U;'0H*3L*)&UE;6)E<G,@
M/2`D<')E9D=R;W5P<ULG:61E;G1I=&EE<R==6R=M96UB97)S)UT["F9O<B`H
M)&D@/2`P.R`D:2`\(&-O=6YT*"1I9&5N=&ET:65S*3L@*RLD:2DZ"C\^"FED
M96YT:71I97-;/#]P:'`@96-H;R`D:2`_/ET@/2!N97<@07)R87DH*3L*/#]P
M:'`*)&L@/2`P.PIF;W)E86-H("@D;65M8F5R<R!A<R`D;65M8F5R*3H*("`@
M(&EF("@D;65M8F5R(#T]("=D969A=6QT7VED96YT:71Y)R!\?`H@("`@("`@
M("%E;7!T>2@D7W!R969S6R1M96UB97)=6R=L;V-K960G72D@?'P*("`@("`@
M("`D7W!R969S6R1M96UB97)=6R=T>7!E)UT@/3T@)W-P96-I86PG('Q\"B`@
M("`@("`@)%]P<F5F<ULD;65M8F5R75LG='EP92==(#T]("=L:6YK)RD@>PH@
M("`@("`@(&-O;G1I;G5E.PH@("`@?0H_/@II9&5N=&ET:65S6SP_<&AP(&5C
M:&\@)&D@/SY=6SP_<&AP(&5C:&\@)&LK*R`_/ET@/2!N97<@07)R87DH(CP_
M<&AP(&5C:&\@)&UE;6)E<B`_/B(L("(\/W!H<"!E8VAO("1?<')E9G-;)&UE
M;6)E<EU;)W1Y<&4G72`_/B(L(#P_<&AP"B1V86P@/2`D:61E;G1I='DM/F=E
M=%9A;'5E*"1M96UB97(L("1I*3L*<W=I=&-H("@D7W!R969S6R1M96UB97)=
M6R=T>7!E)UTI('L*8V%S92`G8VAE8VMB;W@G.@H@("`@96-H;R`D=F%L(#\@
M)W1R=64G(#H@)V9A;'-E)SL*("`@(&)R96%K.PH*8V%S92`G;G5M8F5R)SH*
M("`@(&5C:&\@*&EN="DD=F%L.PH@("`@8G)E86L["@IC87-E("=T97AT87)E
M82<Z"B`@("!I9B`H:7-?87)R87DH)'9A;"DI('L*("`@("`@("`D=F%L(#T@
M:6UP;&]D92@B7&XB+"`D=F%L*3L*("`@('T*("`@("1V86P@/2!3=')I;F<Z
M.F-O;G9E<G1#:&%R<V5T*"1V86PL($Y,4SHZ9V5T0VAA<G-E="@I+"`G551&
M+3@G*3L*("`@(&5C:&\@)V1E8V]D955224-O;7!O;F5N="@B)R`N(')A=W5R
M;&5N8V]D92@D=F%L*2`N("<B*2<["B`@("!B<F5A:SL*"F1E9F%U;'0Z"B`@
M("`D=F%L(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D=F%L+"!.3%,Z.F=E
M=$-H87)S970H*2P@)U541BTX)RD["B`@("!E8VAO("=D96-O9&554DE#;VUP
M;VYE;G0H(B<@+B!R87=U<FQE;F-O9&4H)'9A;"D@+B`G(BDG.PI]"C\^*3L*
M/#]P:'`@96YD9F]R96%C:#L@96YD9F]R.R`_/@H*9G5N8W1I;VX@;F5W0VAO
M:6-E*"D*>PH@("`@=F%R(&9I96QD+"!V86P["B`@("!V87(@:6YD97@@/2!D
M;V-U;65N="YP<F5F<RYI9&5N=&ET>2YS96QE8W1E9$EN9&5X.PH@("`@=F%R
M(&ED(#T@9&]C=6UE;G0N<')E9G,N:61E;G1I='DN;W!T:6]N<UMI;F1E>%TN
M=F%L=64["B`@("!I9B`H:60@/"`P*2!["B`@("`@("`@9&]C=6UE;G0N<')E
M9G,N<F5S970H*3L*("`@("`@("!D;V-U;65N="YP<F5F<RYI9&5N=&ET>2YS
M96QE8W1E9$EN9&5X(#T@:6YD97@["B`@("`@("`@<F5T=7)N.PH@("`@?0H@
M("`@9F]R("AV87(@:2`](#`[(&D@/"!I9&5N=&ET:65S6VED72YL96YG=&@[
M(&DK*RD@>PH@("`@("`@(&9I96QD(#T@9&]C=6UE;G0N<')E9G-;:61E;G1I
M=&EE<UMI9%U;:5U;,%U=.PH@("`@("`@('9A;"`](&ED96YT:71I97-;:61=
M6VE=6S)=.PH@("`@("`@('-W:71C:"`H:61E;G1I=&EE<UMI9%U;:5U;,5TI
M('L*("`@("`@("!C87-E(")E;G5M(CH*("`@("`@("`@("`@9F]R("AV87(@
M:B`](#`[(&H@/"!F:65L9"YO<'1I;VYS+FQE;F=T:#L@:BLK*2!["B`@("`@
M("`@("`@("`@("!I9B`H9FEE;&0N;W!T:6]N<UMJ72YV86QU92`]/2!V86PI
M('L*("`@("`@("`@("`@("`@("`@("!F:65L9"YS96QE8W1E9$EN9&5X(#T@
M:CL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M8V%S92`B8VAE8VMB;W@B.@H@("`@("`@("`@("!F:65L9"YC:&5C:V5D(#T@
M=F%L.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`B:6UP;&EC
M:70B.@H@("`@("`@("`@("!E=F%L*")N97=#:&]I8V5?(B`K(&ED96YT:71I
M97-;:61=6VE=6S!=("L@(BAV86PI(BD["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!F:65L9"YV86QU92`]('9A
M;#L*("`@("`@("!]"B`@("!]"GT*"B\O+2T^"CPO<V-R:7!T/@H\8G(@+SX*
M/#]P:'`@96-H;R!(;W)D93HZ;&%B96PH)VED96YT:71Y)RP@7R@B4V5L96-T
M('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(BDI(#\^/&)R("\^
M"CQS96QE8W0@;F%M93TB:61E;G1I='DB(&ED/2)I9&5N=&ET>2(@;VYC:&%N
M9V4](FIA=F%S8W)I<'0Z;F5W0VAO:6-E*"DB/@H@(#QO<'1I;VX@=F%L=64]
M(BTR(B!S96QE8W1E9#TB<V5L96-T960B"CX\/W!H<"!E8VAO(%\H(DYO;F4B
M*2`_/CPO;W!T:6]N/@H@(#QO<'1I;VX@=F%L=64](BTQ(CX\/W!H<"!E8VAO
M(%\H(D-R96%T92!A(&YE=R!O;F4B*2`_/CPO;W!T:6]N/@H\/W!H<"!F;W(@
M*"1I(#T@,#L@)&D@/"!C;W5N="@D:61E;G1I=&EE<RD[("1I*RLI.B`_/@H@
M(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@)&D@/SXB/#]P:'`@:68@*"1I
M(#T]("1D969A=6QT7VED96YT:71Y*2!E8VAO("<@<V5L96-T960](G-E;&5C
M=&5D(B<@/SX^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1I9&5N=&ET
M:65S6R1I72D@/SX\+V]P=&EO;CX*/#]P:'`@96YD9F]R.R`_/@H\+W-E;&5C
M=#X\8G(@+SX*/#]P:'`@96YD:68[(#\^"@``````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M96UP;&%T97,O<')E9G,O;&EN:RYI;F,`````````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P-3(S`#$P-3$U-#,S-S8P`#`R,C0R,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\82!H<F5F/2(\
M/W!H<"!E8VAO("AI<W-E="@D7W!R969S6R1P<F5F75LG=7)L)UTI*2`_"DAO
M<F1E.CIA<'!L:6-A=&EO;E5R;"@D7W!R969S6R1P<F5F75LG=7)L)UTI(#H@
M)%]P<F5F<ULD<')E9EU;)WAU<FPG70H_/B(^/#]P:'`@:68@*&ES<V5T*"1?
M<')E9G-;)'!R969=6R=I;6<G72DI(&5C:&\*2&]R9&4Z.FEM9R@D7W!R969S
M6R1P<F5F75LG:6UG)UTL("1?<')E9G-;)'!R969=6R=D97-C)UTL("=H<W!A
M8V4](C,B)RD*/SX\<W1R;VYG/CP_<&AP(&5C:&\@)%]P<F5F<ULD<')E9EU;
M)V1E<V,G72`_/CPO<W1R;VYG/CPO83XF;F)S<#L\/W!H<"!E8VAO"B1H96QP
M;&EN:R`_/CQB<B`O/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R
M969S+VUU;'1I96YU;2YI;F,`````````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,3`T-P`Q,#4Q-30S,S<V,``P,C,U,#4`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`@96-H;R!(;W)D93HZ;&%B
M96PH)'!R968L("1?<')E9G-;)'!R969=6R=D97-C)UTI(#\^)FYB<W`[/#]P
M:'`@96-H;R`D:&5L<&QI;FL@/SX\8G(@+SX*/'-E;&5C="!I9#TB/#]P:'`@
M96-H;R`D<')E9B`_/B(@;75L=&EP;&4](FUU;'1I<&QE(B!S:7IE/2(\/W!H
M<"!E8VAO(&UI;B@T+"!C;W5N="@D7W!R969S6R1P<F5F75LG96YU;2==*2D@
M/SXB(&YA;64](CP_<&AP(&5C:&\@)'!R968@/SY;72(^"CP_<&AP("1S96QE
M8W1E9"`]($!U;G-E<FEA;&EZ92@D<')E9G,M/F=E=%9A;'5E*"1P<F5F*2D[
M(&9O<F5A8V@@*"1?<')E9G-;)'!R969=6R=E;G5M)UT@87,@)&ME>2`]/B`D
M=F%L*3H@/SX*/&]P=&EO;CP_<&AP(&5C:&\@:6Y?87)R87DH)&ME>2P@)'-E
M;&5C=&5D*2`_("<@<V5L96-T960](G-E;&5C=&5D(B`G(#H@)R<@/SX@=F%L
M=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`_/B(^/#]P
M:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1V86PI(#\^/"]O<'1I;VX^"CP_
M<&AP(&5N9&9O<F5A8V@@/SX*/"]S96QE8W0^"CQB<B`O/@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA
M=&5S+W!R969S+VYU;6)E<BYI;F,`````````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#,W-@`Q,#4Q-30S,S<V,``P,C(W-C(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/&EN<'5T('1Y<&4](G1E
M>'0B(&ED/2(\/W!H<"!E8VAO("1P<F5F(#\^(B!N86UE/2(\/W!H<"!E8VAO
M("1P<F5F(#\^(B!S:7IE/2(S(B!M87AL96YG=&@](C,B('9A;'5E/2(\/W!H
M<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'!R969S+3YG971686QU92@D<')E
M9BDI(#\^(B`O/@H\/W!H<"!E8VAO($AO<F1E.CIL86)E;"@D<')E9BP@)%]P
M<F5F<ULD<')E9EU;)V1E<V,G72D@/SXF;F)S<#L\/W!H<"!E8VAO("1H96QP
M;&EN:R`_/CQB<B`O/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F<R]O
M=F5R=FEE=RYI;F,`````````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$U
M,38`,3`U,34T,S,W-C``,#(S,S,U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#QD:78@8VQA<W,](G!R969S3W9E<G9I97<B
M/@H\/W!H<"!F;W)E86-H("@D8V]L=6UN<R!A<R`D:V5Y(#T^("1C;VQU;6XI
M.B`_/@H@/&1I=B!S='EL93TB=VED=&@Z/#]P:'`@96-H;R`D<W!A;B`M(#$@
M/SXE(CX*("`\9&EV/@H@("`\:#(^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H
M87)S*"1K97DI(#\^/"]H,CX*"B`@(#QD;#X*("`@/#]P:'`@9F]R96%C:"`H
M)&-O;'5M;B!A<R`D9W)O=7`@/3X@)&=V86QS*3H@/SX*("`@(#P_<&AP(&EF
M("A0<F5F<U]523HZ9W)O=7!)<T5D:71A8FQE*"1G<F]U<"DI.B`_/@H@("`@
M(#P_<&AP(&EF("@A96UP='DH)&=V86QS6R=U<FPG72DI.B`_/@H@("`@("`\
M9'0^/#]P:'`@96-H;R!(;W)D93HZ=VED9V5T*$AO<F1E.CIA<'!L:6-A=&EO
M;E5R;"@D9W9A;'-;)W5R;"==+"`D87!P*2P@)&=V86QS6R=L86)E;"==+"`G
M)RP@)R<L("<G+"`D9W9A;'-;)VQA8F5L)UTI(#\^/"]D=#X*("`@("`\/W!H
M<"!E;'-E.B`_/@H@("`@("`\9'0^/#]P:'`@96-H;R!(;W)D93HZ=VED9V5T
M*%5T:6PZ.F%D9%!A<F%M971E<BA(;W)D93HZ<V5L9E5R;"@I+"!A<G)A>2@G
M9W)O=7`G(#T^("1G<F]U<"P@)V%P<"<@/3X@)$=,3T)!3%-;)V%P<"==*2DL
M("1G=F%L<ULG;&%B96PG72P@)R<L("<G+"`G)RP@)&=V86QS6R=L86)E;"==
M*2`_/CPO9'0^"B`@("`@/#]P:'`@96YD:68[(#\^"B`@("`@/&1D/CP_<&AP
M(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D9W9A;'-;)V1E<V,G72D@/SX\+V1D
M/@H@("`@/#]P:'`@96YD:68[(#\^"B`@(#P_<&AP(&5N9&9O<F5A8V@[(#\^
M"B`@(#PO9&P^"B`@/"]D:78^"B`\+V1I=CX*/#]P:'`@96YD9F]R96%C:#L@
M/SX*/"]D:78^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]P
M<F5F<R]P87-S=V]R9"YI;F,`````````````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`T,S``,3`U,34T,S,W-C``,#(S,S(S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP(&5C:&\@2&]R9&4Z.FQA
M8F5L*"1P<F5F+"`D7W!R969S6R1P<F5F75LG9&5S8R==*2`_/B9N8G-P.SP_
M<&AP(&5C:&\@)&AE;'!L:6YK(#\^/&)R("\^"CQI;G!U="!T>7!E/2)P87-S
M=V]R9"(@:60](CP_<&AP(&5C:&\@)'!R968@/SXB(&YA;64](CP_<&AP(&5C
M:&\@)'!R968@/SXB('-I>F4](C,P(B!M87AL96YG=&@](C8P(B!C;&%S<STB
M9FEX960B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'!R
M969S+3YG971686QU92@D<')E9BDI(#\^(B`O/CQB<B`O/@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O<V5L96-T
M+FEN8P``````````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,C`P`#$P
M-3$U-#,S-S8P`#`R,C<S-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<"!E8VAO($AO<F1E.CIL86)E;"@D<')E9BP@
M)%]P<F5F<ULD<')E9EU;)V1E<V,G72D@/SXF;F)S<#L\/W!H<"!E8VAO("1H
M96QP;&EN:R`_/CQB<B`O/@H\<V5L96-T(&ED/2(\/W!H<"!E8VAO(&AT;6QS
M<&5C:6%L8VAA<G,H)'!R968I(#\^(B!N86UE/2(\/W!H<"!E8VAO(&AT;6QS
M<&5C:6%L8VAA<G,H)'!R968I(#\^(CX*/#]P:'`@)&5S8R`]("%E;7!T>2@D
M7W!R969S6R1P<F5F75LG97-C87!E9"==*3L@)&-U<G9A;"`]("1P<F5F<RT^
M9V5T5F%L=64H)'!R968I.R`D<V5L96-T7W9A<B`](%5T:6PZ.FYO;DEN<'5T
M5F%R*"1P<F5F("X@)U]O<'1I;VYS)RD[(&9O<F5A8V@@*"1S96QE8W1?=F%R
M(&%S("1S96QE8W1?:V5Y(#T^("1S96QE8W1?=F%L*3H@/SX*(#QO<'1I;VX@
M=F%L=64](CP_<&AP(&5C:&\@)&5S8R`_("1S96QE8W1?:V5Y(#H@:'1M;'-P
M96-I86QC:&%R<R@D<V5L96-T7VME>2D@/SXB/#]P:'`@:68@*"1S96QE8W1?
M:V5Y(#T]("1C=7)V86PI(&5C:&\@)R!S96QE8W1E9#TB<V5L96-T960B)R`_
M/CX\/W!H<"!E8VAO("1E<V,@/R`D<V5L96-T7W9A;"`Z(&AT;6QS<&5C:6%L
M8VAA<G,H)'-E;&5C=%]V86PI(#\^/"]O<'1I;VX^"CP_<&AP(&5N9&9O<F5A
M8V@[(#\^"CPO<V5L96-T/@H\8G(@+SX*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O
M=&5X="YI;F,`````````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M-#$P`#$P-3$U-#,S-S8P`#`R,C0T,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<"!E8VAO($AO<F1E.CIL86)E;"@D
M<')E9BP@)%]P<F5F<ULD<')E9EU;)V1E<V,G72D@/SXF;F)S<#L\/W!H<"!E
M8VAO("1H96QP;&EN:R`_/CQB<B`O/@H\:6YP=70@:60](CP_<&AP(&5C:&\@
M)'!R968@/SXB(&YA;64](CP_<&AP(&5C:&\@)'!R968@/SXB('-I>F4](C,P
M(B!M87AL96YG=&@](C8P(B!C;&%S<STB9FEX960B('9A;'5E/2(\/W!H<"!E
M8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'!R969S+3YG971686QU92@D<')E9BDI
M(#\^(B`O/CQB<B`O/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R969S+W1E>'1A<F5A+FEN
M8P``````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0U-``Q,#4Q-30S
M,S<V,``P,C,S,#0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`@96-H;R!(;W)D93HZ;&%B96PH)'!R968L("1?<')E
M9G-;)'!R969=6R=D97-C)UTI(#\^)FYB<W`[/#]P:'`@96-H;R`D:&5L<&QI
M;FL@/SX\8G(@+SX*/&1I=B!C;&%S<STB9FEX960B/@H\=&5X=&%R96$@=W)A
M<#TB:&%R9"(@:60](CP_<&AP(&5C:&\@)'!R968@/SXB(&YA;64](CP_<&AP
M(&5C:&\@)'!R968@/SXB(')O=W,](C8B(&-O;',](C@P(B!C;&%S<STB9FEX
M960B/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D<')E9G,M/F=E=%9A
M;'5E*"1P<F5F*2D@/SX\+W1E>'1A<F5A/CQB<B`O/@H\+V1I=CX*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1E;7!L871E<R]P<F]B;&5M+P``````````````````````````
M````````````````````````````````````````````````,#`P,#<U-0`P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-C$`,#(Q,S$S
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,`````````````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#0R,``Q
M,#4Q-30S,S<V,0`P,C,T-#8`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B
M/@H\(2TM"B\O($-H96-K(&%L;"!O9B!T:&4@;6%I;B!F;W)M(&9I96QD<R!T
M;R!M86ME('-U<F4@=&AE>2!A<F4@9FEL;&5D(&EN"F9U;F-T:6]N('9A;&ED
M871E*"D*>PH@("`@:68@*&1O8W5M96YT+G!R;V)L96U?<F5P;W)T+G-U8FIE
M8W0N=F%L=64@/3T@)R<I('L*("`@("`@("!A;&5R="@G/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@
M<')O8FQE;2XB*2D@/SXG*3L*("`@("`@("!D;V-U;65N="YP<F]B;&5M7W)E
M<&]R="YS=6)J96-T+F9O8W5S*"D["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@?2!E;'-E(&EF("AD;V-U;65N="YP<F]B;&5M7W)E<&]R="YM97-S86=E
M+G9A;'5E(#T]("<G*2!["B`@("`@("`@86QE<G0H)SP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O
M<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB*2D@/SXG*3L*
M("`@("`@("!D;V-U;65N="YP<F]B;&5M7W)E<&]R="YM97-S86=E+F9O8W5S
M*"D["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@(&1O8W5M96YT
M+G!R;V)L96U?<F5P;W)T+F%C=&EO;DE$+G9A;'5E(#T@)W-E;F1?<')O8FQE
M;5]R97!O<G0G.PH@("`@<F5T=7)N('1R=64["GT*+R\M+3X*/"]S8W)I<'0^
M"@H\9F]R;2!M971H;V0](G!O<W0B(&YA;64](G!R;V)L96U?<F5P;W)T(B!A
M8W1I;VX](G!R;V)L96TN<&AP(CX*/#]P:'`@571I;#HZ<&9O<FU);G!U="@I
M(#\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU
M93TB8V%N8V5L7W!R;V)L96U?<F5P;W)T(B`O/@H\:6YP=70@='EP93TB:&ED
M9&5N(B!N86UE/2)R971U<FY?=7)L(B!V86QU93TB/#]P:'`@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*%5T:6PZ.F=E=$9O<FU$871A*"=R971U<FY?=7)L)RDI
M(#\^(B`O/@H*/'1A8FQE(&-E;&QP861D:6YG/2(S(B!C96QL<W!A8VEN9STB
M,B(@=VED=&@](C$P,"4B/@H\='(@8VQA<W,](FAE861E<B(^"B`@("`\=&0@
M8V]L<W!A;CTB,B(@8VQA<W,](FAE861E<B(^/#]P:'`@96-H;R!?*")$97-C
M<FEB92!T:&4@4')O8FQE;2(I(#\^/"]T9#X*/"]T<CX*"CQT<CX*("`@(#QT
M9"!C;&%S<STB;&EG:'0@<FEG:'1!;&EG;B(^/#]P:'`@96-H;R!?*")9;W5R
M($YA;64B*2`_/CPO=&0^"B`@("`\=&0^/&EN<'5T('1Y<&4](G1E>'0B('1A
M8FEN9&5X/2(Q(B!N86UE/2)N86UE(B!V86QU93TB/#]P:'`@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*"1N86UE*2`_/B(@<VEZ93TB-S`B("\^/"]T9#X*/"]T
M<CX*"CQT<CX*("`@(#QT9"!C;&%S<STB;&EG:'0@<FEG:'1!;&EG;B(^/#]P
M:'`@96-H;R!?*")9;W5R($5M86EL($%D9')E<W,B*2`_/CPO=&0^"B`@("`\
M=&0^/&EN<'5T('1Y<&4](G1E>'0B('1A8FEN9&5X/2(R(B!N86UE/2)E;6%I
M;"(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D96UA:6PI
M(#\^(B!S:7IE/2(W,"(@+SX\+W1D/@H\+W1R/@H*/'1R/@H@("`@/'1D(&-L
M87-S/2)L:6=H="!R:6=H=$%L:6=N(CX\/W!H<"!E8VAO(%\H(E-H;W)T(%-U
M;6UA<GDB*2`_/CPO=&0^"B`@("`\=&0^/&EN<'5T('1Y<&4](G1E>'0B('1A
M8FEN9&5X/2(S(B!N86UE/2)S=6)J96-T(B!V86QU93TB/#]P:'`@96-H;R!H
M=&UL<W!E8VEA;&-H87)S*"1S=6)J96-T*2`_/B(@<VEZ93TB-S`B("\^/"]T
M9#X*/"]T<CX*"CQT<CX*("`@(#QT9"!C;VQS<&%N/2(R(B!C;&%S<STB<VUA
M;&QH96%D97(B/CP_<&AP(&5C:&\@7R@B1G5L;"!$97-C<FEP=&EO;B(I(#\^
M/"]T9#X*/"]T<CX*/'1R/@H@("`@/'1D/CPO=&0^"B`@("`\=&0^/'1E>'1A
M<F5A('1A8FEN9&5X/2(T(B!N86UE/2)M97-S86=E(B!R;W=S/2(R,"(@8V]L
M<STB.#`B('=R87`](FAA<F0B/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R
M<R@D;65S<V%G92D@/SX\+W1E>'1A<F5A/CPO=&0^"CPO='(^"@H\='(^"B`@
M/'1D/CPO=&0^"B`@/'1D(&-L87-S/2)L:6=H="(^"B`@("`\:6YP=70@8VQA
M<W,](F)U='1O;B(@='EP93TB<W5B;6ET(B!N86UE/2)F;W)M<W5B;6ET(B!O
M;F-L:6-K/2)R971U<FX@=F%L:61A=&4H*3LB('9A;'5E/2(\/W!H<"!E8VAO
M(%\H(E-E;F0@4')O8FQE;2!297!O<G0B*2`_/B(@+SX*("`@(#QI;G!U="!C
M;&%S<STB8G5T=&]N(B!T>7!E/2)S=6)M:70B(&YA;64](F9O<FUS=6)M:70B
M('9A;'5E/2(\/W!H<"!E8VAO(%\H(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(I
M(#\^(B`O/@H@(#PO=&0^"CPO='(^"@H\+W1A8FQE/@H\+V9O<FT^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S
M+W)P8W-U;2\`````````````````````````````````````````````````
M```````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#`P,``Q,#4Q-30S,S<V,0`P,C$Q-C0`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,`````````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-3,S`#$P-3$U-#,S-S8Q`#`R,S$W
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"CPA+2T*"G9A<B!C86YC
M96Q3=6)M:70@/2!F86QS93L*"G9A<B!F:65L9',@/2!N97<@07)R87DH"CP_
M<&AP(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1R<&-?<V5R=F5R<RD[("1I
M*RLI.B`_/@H@("`@;F5W($%R<F%Y*`H@("`@("`@("(\/W!H<"!E8VAO(')A
M=W5R;&5N8V]D92@D<G!C7W-E<G9E<G-;)&E=6R=U<FPG72D@/SXB+`H@("`@
M("`@("(\/W!H<"!E8VAO(')A=W5R;&5N8V]D92@D<G!C7W-E<G9E<G-;)&E=
M6R=U<V5R)UTI(#\^(@H@("`@*3P_<&AP(&EF("@D:2`K(#$@/"!C;W5N="@D
M<G!C7W-E<G9E<G,I*2!E8VAO("<L)SL@/SX*"CP_<&AP(&5N9&9O<CL@/SX*
M*3L*"F9U;F-T:6]N(&YE=T-H;VEC92@I"GL*("`@('9A<B!A8W1I;VX@/2!D
M;V-U;65N="YP<F5F<RYS97)V97(N;W!T:6]N<UMD;V-U;65N="YP<F5F<RYS
M97)V97(N<V5L96-T961);F1E>%TN=F%L=64["@H@("`@:68@*&%C=&EO;B`]
M/2`M,2D@>PH@("`@("`@(&1O8W5M96YT+G!R969S+G-A=F4N=F%L=64@/2`G
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D-R96%T92(I*2`_/B<["B`@("`@
M("`@9&]C=6UE;G0N<')E9G,N<F5S970H*3L*("`@('T@96QS92!["B`@("`@
M("`@9&]C=6UE;G0N<')E9G,N<V%V92YV86QU92`]("<\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B0VAA;F=E(BDI(#\^)SL*("`@("`@("!U<&1A=&5&;W)M
M*&%C=&EO;BD["B`@("!]"GT*"F9U;F-T:6]N('5P9&%T949O<FTH<V5R=F5R
M*0I["B`@("!D;V-U;65N="YP<F5F<RYE9&ET7W-E<G9E<BYV86QU92`]('-E
M<G9E<CL*("`@(&1O8W5M96YT+G!R969S+G5R;"YV86QU92`](&1E8V]D9552
M24-O;7!O;F5N="AF:65L9'-;<V5R=F5R75LP72D["B`@("!D;V-U;65N="YP
M<F5F<RYU<V5R+G9A;'5E(#T@9&5C;V1E55))0V]M<&]N96YT*&9I96QD<UMS
M97)V97)=6S%=*3L*?0H*9G5N8W1I;VX@8VQE87)&;W)M*"D*>PH@("`@9&]C
M=6UE;G0N<')E9G,N961I=%]S97)V97(N=F%L=64@/2`G)SL*("`@(&1O8W5M
M96YT+G!R969S+G5R;"YV86QU92`]("!F:65L9'-;<V5R=F5R75LP73L*("`@
M(&1O8W5M96YT+G!R969S+G5S97(N=F%L=64@/2!F:65L9'-;<V5R=F5R75LQ
M73L*("`@(&1O8W5M96YT+G!R969S+G-E<G9E<BYS96QE8W1E9$EN9&5X(#T@
M,#L*("`@(&-A;F-E;%-U8FUI="`]('1R=64["GT*"F9U;F-T:6]N(&-H96-K
M4W5B;6ET*"D*>PH@("`@8V%N8V5L(#T@8V%N8V5L4W5B;6ET.PH@("`@8V%N
M8V5L4W5B;6ET(#T@9F%L<V4["CP_<&AP(&EF("@D8G)O=W-E<BT^9V5T0G)O
M=W-E<B@I(#T]("=M<VEE)R`F)B`D8G)O=W-E<BT^9V5T36%J;W(H*2`^/2`T
M*3H@/SX*("`@('=I;F1O=RYE=F5N="YR971U<FY686QU92`]("%C86YC96P[
M"CP_<&AP(&5N9&EF.R`_/@H@("`@<F5T=7)N("%C86YC96P["GT*"B\O+2T^
M"CPO<V-R:7!T/@H*/#]P:'`@96-H;R!?*")9;W5R(')E;6]T92!S97)V97)S
M.B(I(#\^/&)R("\^"CQS96QE8W0@;F%M93TB<V5R=F5R(B!O;F-H86YG93TB
M:F%V87-C<FEP=#IN97=#:&]I8V4H*2(^"B`@/&]P=&EO;B!V86QU93TB+3$B
M/CP_<&AP(&5C:&\@7R@B4V5L96-T(&$@<V5R=F5R(BD@/SX\+V]P=&EO;CX*
M/#]P:'`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)')P8U]S97)V97)S*3L@
M*RLD:2DZ(#\^"B`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R`D:2`_/B(^
M/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1R<&-?<V5R=F5R<ULD:5U;
M)W5R;"==*2`_/CPO;W!T:6]N/@H\/W!H<"!E;F1F;W([(#\^"CPO<V5L96-T
M/@H\+W1D/CPO='(^"@H\;F]S8W)I<'0^"CPO=&%B;&4^/"]T9#X\+W1R/@H\
M='(^"B`@/'1D('9A;&EG;CTB;6ED9&QE(CX*("`@(#QB<B`O/@H@("`@/&EN
M<'5T('1Y<&4](G-U8FUI="(@;F%M93TB961I="(@8VQA<W,](F)U='1O;B(@
M=F%L=64](CP_<&AP(&5C:&\@7R@B161I="(I(#\^(B`O/@H@("`@/&EN<'5T
M('1Y<&4](G-U8FUI="(@;F%M93TB9&5L971E(B!C;&%S<STB8G5T=&]N(B!V
M86QU93TB/#]P:'`@96-H;R!?*")$96QE=&4B*2`_/B(@+SX*("`@(#QB<B`O
M/B9N8G-P.PH@(#PO=&0^"CPO='(^"@H\='(^/'1D(&-L87-S/2)I=&5M(CX\
M=&%B;&4^"CPO;F]S8W)I<'0^"@H\='(@=F%L:6=N/2)T;W`B/CQT9"!C;&%S
M<STB:71E;2(^"@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)E9&ET7W-E
M<G9E<B(@=F%L=64](B(@+SX*/#]P:'`@96-H;R!?*")296UO=&4@55),("AH
M='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB*2`_/CQB<B`O/@H\:6YP
M=70@='EP93TB=&5X="(@;F%M93TB=7)L(B!S:7IE/2(S,"(@;6%X;&5N9W1H
M/2(V,"(@+SX\8G(@+SX*"CP_<&AP(&5C:&\@7R@B57-E<FYA;64Z(BD@/SX\
M8G(@+SX*/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](G5S97(B('-I>F4](C,P
M(B!M87AL96YG=&@](C8P(B`O/CQB<B`O/@H*/#]P:'`@96-H;R!?*")087-S
M=V]R9#HB*2`_/CQB<B`O/@H\:6YP=70@='EP93TB<&%S<W=O<F0B(&YA;64]
M(G!A<W-W9"(@<VEZ93TB,S`B(&UA>&QE;F=T:#TB-C`B("\^/&)R("\^"@H\
M+W1D/CPO='(^/"]T86)L93X\+W1D/CPO='(^/"]T86)L93X*"CQP/@H@/&EN
M<'5T('1Y<&4](G-U8FUI="(@;F%M93TB<V%V92(@8VQA<W,](F)U='1O;B(@
M;VYC;&EC:STB9&]C=6UE;G0N<')E9G,N86-T:6]N240N=F%L=64])W-A=F4G
M.R!R971U<FX@=')U92(@=F%L=64](CP_<&AP(&5C:&\@)&%C=&EO;DE$(#T]
M("=E9&ET)R`_(%\H(D-H86YG92(I(#H@7R@B0W)E871E(BD@/SXB("\^)FYB
M<W`["CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*9&]C=6UE;G0N
M=W)I=&4H)SQI;G!U="!T>7!E/2)S=6)M:70B(&YA;64](F1E;&5T92(@8VQA
M<W,](F)U='1O;B(@;VYC;&EC:STB9&]C=6UE;G0N<')E9G,N86-T:6]N240N
M=F%L=64]7"=D96QE=&5<)R(@=F%L=64](CP_<&AP(&5C:&\@7R@B1&5L971E
M(BD@/SXB("\^)FYB<W`[)RD["CPO<V-R:7!T/@H@/&EN<'5T('1Y<&4](G-U
M8FUI="(@;F%M93TB;F5W(B!C;&%S<STB8G5T=&]N(B!O;F-L:6-K/2)C;&5A
M<D9O<FTH*3MD;V-U;65N="YP<F5F<RYS879E+G9A;'5E/2<\/W!H<"!E8VAO
M(%\H(D-R96%T92(I(#\^)SLB('9A;'5E/2(\/W!H<"!E8VAO(%\H(E)E<V5T
M(BD@/SXB("\^)FYB<W`["B`\:6YP=70@='EP93TB8G5T=&]N(B!C;&%S<STB
M8G5T=&]N(B!O;F-L:6-K/2)C86YC96Q3=6)M:70]=')U93MD;V-U;65N="YL
M;V-A=&EO;BYH<F5F/2<\/W!H<"!E8VAO($AO<F1E.CIA<'!L:6-A=&EO;E5R
M;"A5=&EL.CIA9&1087)A;65T97(H)W-E<G9I8V5S+W!R969S+G!H<"<L("=A
M<'`G+"`G:&]R9&4G*2P@=')U92D@/SXG(B!V86QU93TB/#]P:'`@96-H;R!?
M*")2971U<FX@=&\@3W!T:6]N<R(I(#\^(B`O/@H\+W`^"@H\+V9O<FT^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&5M<&QA=&5S+W-H87)E<R\`````````````````````````
M```````````````````````````````````````````````````P,#`P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<V,``P,C$Q
M,S<`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC````````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(V-3(W
M`#$P-3$U-#,S-S8P`#`R,C4W,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\9F]R;2!N86UE/2)E9&ET(B!M971H;V0](G!O
M<W0B(&%C=&EO;CTB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1?4T52
M5D526R=02%!?4T5,1B==*2`_/B(^"CP_<&AP(%5T:6PZ.G!F;W)M26YP=70H
M*2`_/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)A8W1I;VY)1"(@=F%L
M=64](F5D:71F;W)M(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)C
M:60B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'-H87)E
M+3YG971)9"@I*2`_/B(@+SX*/#]P:'`@:68@*"%E;7!T>2@D87!P*2DZ(#\^
M"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%P<"(@=F%L=64](CP_<&AP
M(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D87!P*2`_/B(@+SX*/#]P:'`@96YD
M:68[(#\^"CQT86)L92!W:61T:#TB,3`P)2(@8V5L;'-P86-I;F<](C`B/@H\
M='(@=F%L:6=N/2)M:61D;&4B/@H@(#QT9"!W:61T:#TB,3`P)2(@8V]L<W!A
M;CTB-B(@8VQA<W,](FAE861E<B(^"B`@("`\<W!A;B!C;&%S<STB<FEG:'1&
M;&]A="(^"B`@("`@(#QA(&AR968](B,B(&]N8VQI8VL](FIA=F%S8W)I<'0Z
M=VEN9&]W+F-L;W-E*"D[(B!S='EL93TB8W5R<V]R.G!O:6YT97(B/CP_<&AP
M(&5C:&\@2&]R9&4Z.FEM9R@G8VQO<V4N<&YG)RP@7R@B0VQO<V4@5VEN9&]W
M(BDL("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`_/CPO
M83X*("`@(#PO<W!A;CX*("`@(#P_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G<&5R
M;7,N<&YG)RP@)R<L("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D
M92<I*2`_/B9N8G-P.SP_<&AP('!R:6YT9BA?*")%9&ET('!E<FUI<W-I;VYS
M(&9O<B`E<R(I+"!H=&UL<W!E8VEA;&-H87)S*"1S:&%R92T^9V5T*"=N86UE
M)RDI*2`_/@H@(#PO=&0^"CPO='(^"CQT<CX\=&0^)FYB<W`[/"]T9#X\+W1R
M/@H*/#]P:'`@)&]W;F5R(#T@)'-H87)E+3YG970H)V]W;F5R)RD[(#\^"CP_
M<&AP("1U<V5R<&5R;7,@/2`D<&5R;2T^9V5T57-E<E!E<FUI<W-I;VYS*"D[
M(#\^"@H\(2TM($]W;F5R<VAI<"`M+3X*/#]P:'`*:68@*&ES<V5T*"1U<V5R
M<&5R;7-;)&]W;F5R72DI('L*("`@("1O<&5R;2`]("1U<V5R<&5R;7-;)&]W
M;F5R73L*?2!E;'-E('L*("`@("1O<&5R;2`](%!%4DU37U-(3U<@?"!015)-
M4U]214%$('P@4$5235-?141)5"!\(%!%4DU37T1%3$5413L*?0H_/@H\='(@
M=F%L:6=N/2)M:61D;&4B/@H@(#QT9"!C;&%S<STB:&5A9&5R(&QE9G1!;&EG
M;B(@=VED=&@](C4U)2(^"B`@("`\/W!H<"!E8VAO($AO<F1E.CII;6<H)W!E
M<FUS+G!N9R<L("<G+"`G)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R
M9&4G*2D@+B`G)FYB<W`[)R`N(%\H(D]W;F5R(%!E<FUI<W-I;VYS(BD@/SX*
M("`\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(B!A;&EG;CTB8V5N=&5R(B!W
M:61T:#TB,24B/CP_<&AP(&5C:&\@7R@B4VAO=R(I(#\^/"]T9#X*("`\=&0@
M8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E<B(@=VED=&@](C$E(CX\/W!H
M<"!E8VAO(%\H(E)E860B*2`_/CPO=&0^"B`@/'1D(&-L87-S/2)H96%D97(B
M(&%L:6=N/2)C96YT97(B('=I9'1H/2(Q)2(^/#]P:'`@96-H;R!?*")%9&ET
M(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(B!A;&EG;CTB8V5N=&5R
M(B!W:61T:#TB,24B/CP_<&AP(&5C:&\@7R@B1&5L971E(BD@/SX\+W1D/@H@
M(#QT9"!C;&%S<STB:&5A9&5R(')I9VAT06QI9VXB('=I9'1H/2(T,"4B/B9N
M8G-P.SPO=&0^"CPO='(^"CQT<CX*/#]P:'`@:68@*"1A=71H+3YH87-#87!A
M8FEL:71Y*"=L:7-T)RDI.B`_/@H@(#QT9"!C;&%S<STB;&EG:'0B/@H@("`@
M/'-E;&5C="!N86UE/2)O=VYE<B(^"B`@("`@(#QO<'1I;VX@=F%L=64](B(^
M/#]P:'`@96-H;R!?*")396QE8W0@82!N97<@;W=N97(B*2`N("<Z)R`_/CPO
M;W!T:6]N/@H@("`@("`\;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS
M<&5C:6%L8VAA<G,H)&]W;F5R*2`_/B(@<V5L96-T960](G-E;&5C=&5D(CX\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H075T:#HZ<F5M;W9E2&]O:R@D
M;W=N97(I*2`_/CPO;W!T:6]N/@H@("`@/#]P:'`@9F]R96%C:"`H)'5S97),
M:7-T(&%S("1U<V5R*2![(&EF("@D=7-E<B`A/2`D;W=N97(I('L@/SX*("`@
M("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S
M*"1U<V5R*2`_/B(^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*$%U=&@Z
M.G)E;6]V94AO;VLH)'5S97(I*2`_/CPO;W!T:6]N/@H@("`@/#]P:'`@?2!]
M(#\^"B`@("`\+W-E;&5C=#X*("`\+W1D/@H\/W!H<"!E;'-E.B`_/@H@(#QT
M9"!C;&%S<STB;&EG:'0B/CQI;G!U="!T>7!E/2)T97AT(B!N86UE/2)O=VYE
M<B(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D;W=N97(I
M(#\^(B`O/CPO=&0^"CP_<&AP(&5N9&EF.R`_/@H@(#QT9"!A;&EG;CTB8V5N
M=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F]W;F5R7W-H;W<B
M/#]P:'`@96-H;R`H)&]P97)M("8@4$5235-?4TA/5RD@/R`G(&-H96-K960]
M(F-H96-K960B)R`Z("<G(#\^("\^/"]T9#X*("`\=&0@86QI9VX](F-E;G1E
M<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)O=VYE<E]R96%D(CP_
M<&AP(&5C:&\@*"1O<&5R;2`F(%!%4DU37U)%040I(#\@)R!C:&5C:V5D/2)C
M:&5C:V5D(B<@.B`G)R`_/B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B
M/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB;W=N97)?961I="(\/W!H
M<"!E8VAO("@D;W!E<FT@)B!015)-4U]%1$E4*2`_("<@8VAE8VME9#TB8VAE
M8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\
M:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F]W;F5R7V1E;&5T92(\/W!H
M<"!E8VAO("@D;W!E<FT@)B!015)-4U]$14Q%5$4I(#\@)R!C:&5C:V5D/2)C
M:&5C:V5D(B<@.B`G)R`_/B`O/CPO=&0^"CPO='(^"@H\(2TM(%-P86-E<B`M
M+3X*/'1R/CQT9#XF;F)S<#L\+W1D/CPO='(^"@H\(2TM($1E9F%U;'0@4&5R
M;6ES<VEO;G,@+2T^"CQT<B!V86QI9VX](FUI9&1L92(^"B`@/'1D(&-L87-S
M/2)H96%D97(@;&5F=$%L:6=N(CX*("`@(#P_<&AP(&5C:&\@2&]R9&4Z.FEM
M9R@G<&5R;7,N<&YG)RP@)R<L("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER
M*"=H;W)D92<I*2`N("<F;F)S<#LG("X@7R@B06QL($%U=&AE;G1I8V%T960@
M57-E<G,B*2`_/@H@(#PO=&0^"B`@/'1D(&-L87-S/2)H96%D97(B(&%L:6=N
M/2)C96YT97(B/CP_<&AP(&5C:&\@7R@B4VAO=R(I(#\^/"]T9#X*("`\=&0@
M8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E<B(^/#]P:'`@96-H;R!?*")2
M96%D(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(B!A;&EG;CTB8V5N
M=&5R(CX\/W!H<"!E8VAO(%\H(D5D:70B*2`_/CPO=&0^"B`@/'1D(&-L87-S
M/2)H96%D97(B(&%L:6=N/2)C96YT97(B/CP_<&AP(&5C:&\@7R@B1&5L971E
M(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(')I9VAT06QI9VXB/B9N
M8G-P.SPO=&0^"CPO='(^"CP_<&AP("1D<&5R;2`]("1P97)M+3YG971$969A
M=6QT4&5R;6ES<VEO;G,H*3L@/SX*/'1R/@H@(#QT9"!C;&%S<STB;&EG:'0B
M/B9N8G-P.SPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E
M/2)C:&5C:V)O>"(@;F%M93TB9&5F875L=%]S:&]W(CP_<&AP(&5C:&\@*"1D
M<&5R;2`F(%!%4DU37U-(3U<I(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G
M)R`_/B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E
M/2)C:&5C:V)O>"(@;F%M93TB9&5F875L=%]R96%D(CP_<&AP(&5C:&\@*"1D
M<&5R;2`F(%!%4DU37U)%040I(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G
M)R`_/B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E
M/2)C:&5C:V)O>"(@;F%M93TB9&5F875L=%]E9&ET(CP_<&AP(&5C:&\@*"1D
M<&5R;2`F(%!%4DU37T5$250I(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G
M)R`_/B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E
M/2)C:&5C:V)O>"(@;F%M93TB9&5F875L=%]D96QE=&4B/#]P:'`@96-H;R`H
M)&1P97)M("8@4$5235-?1$5,151%*2`_("<@8VAE8VME9#TB8VAE8VME9"(G
M(#H@)R<@/SX@+SX\+W1D/@H\+W1R/@H*/"$M+2!3<&%C97(@+2T^"CQT<CX\
M=&0^)FYB<W`[/"]T9#X\+W1R/@H*/"$M+2!'=65S="!097)M:7-S:6]N<R`M
M+3X*/'1R('9A;&EG;CTB;6ED9&QE(CX*("`\=&0@8VQA<W,](FAE861E<B!L
M969T06QI9VXB/@H@("`@/#]P:'`@96-H;R!?*")'=65S="!097)M:7-S:6]N
M<R(I(#\^"B`@/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B(@86QI9VX](F-E
M;G1E<B(^/#]P:'`@96-H;R!?*")3:&]W(BD@/SX\+W1D/@H@(#QT9"!C;&%S
M<STB:&5A9&5R(B!A;&EG;CTB8V5N=&5R(CX\/W!H<"!E8VAO(%\H(E)E860B
M*2`_/CPO=&0^"B`@/'1D(&-L87-S/2)H96%D97(B(&%L:6=N/2)C96YT97(B
M/CP_<&AP(&5C:&\@7R@B161I="(I(#\^/"]T9#X*("`\=&0@8VQA<W,](FAE
M861E<B(@86QI9VX](F-E;G1E<B(^/#]P:'`@96-H;R!?*")$96QE=&4B*2`_
M/CPO=&0^"B`@/'1D(&-L87-S/2)H96%D97(@<FEG:'1!;&EG;B(^)FYB<W`[
M/"]T9#X*/"]T<CX*/#]P:'`@)&=P97)M(#T@)'!E<FTM/F=E=$=U97-T4&5R
M;6ES<VEO;G,H*3L@/SX*/'1R/@H@(#QT9"!C;&%S<STB;&EG:'0B/B9N8G-P
M.SPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C
M:V)O>"(@;F%M93TB9W5E<W1?<VAO=R(\/W!H<"!E8VAO("@D9W!E<FT@)B!0
M15)-4U]32$]7*2`_("<@8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\
M+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB
M;W@B(&YA;64](F=U97-T7W)E860B/#]P:'`@96-H;R`H)&=P97)M("8@4$52
M35-?4D5!1"D@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G(#\^("\^/"]T
M9#X*("`\=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X
M(B!N86UE/2)G=65S=%]E9&ET(CP_<&AP(&5C:&\@*"1G<&5R;2`F(%!%4DU3
M7T5$250I(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G)R`_/B`O/CPO=&0^
M"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@
M;F%M93TB9W5E<W1?9&5L971E(CP_<&AP(&5C:&\@*"1G<&5R;2`F(%!%4DU3
M7T1%3$5412D@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G(#\^("\^/"]T
M9#X*/"]T<CX*"CPA+2T@4W!A8V5R("TM/@H\='(^/'1D/B9N8G-P.SPO=&0^
M/"]T<CX*"CPA+2T@0W)E871O<B!097)M:7-S:6]N<R`M+3X*/'1R('9A;&EG
M;CTB;6ED9&QE(CX*("`\=&0@8VQA<W,](FAE861E<B!L969T06QI9VXB/@H@
M("`@/#]P:'`@96-H;R!(;W)D93HZ:6UG*"=U<V5R+G!N9R<L("<G+"`G)RP@
M)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D@+B`G)FYB<W`[)R`N
M(%\H(D]B:F5C="!#<F5A=&]R(BD@/SX*("`\+W1D/@H@(#QT9"!C;&%S<STB
M:&5A9&5R(B!A;&EG;CTB8V5N=&5R(CX\/W!H<"!E8VAO(%\H(E-H;W<B*2`_
M/CPO=&0^"B`@/'1D(&-L87-S/2)H96%D97(B(&%L:6=N/2)C96YT97(B/CP_
M<&AP(&5C:&\@7R@B4F5A9"(I(#\^/"]T9#X*("`\=&0@8VQA<W,](FAE861E
M<B(@86QI9VX](F-E;G1E<B(^/#]P:'`@96-H;R!?*")%9&ET(BD@/SX\+W1D
M/@H@(#QT9"!C;&%S<STB:&5A9&5R(B!A;&EG;CTB8V5N=&5R(CX\/W!H<"!E
M8VAO(%\H(D1E;&5T92(I(#\^/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B!R
M:6=H=$%L:6=N(CX\+W1D/@H\+W1R/@H\/W!H<"`D8W!E<FT@/2`D<&5R;2T^
M9V5T0W)E871O<E!E<FUI<W-I;VYS*"D[(#\^"CQT<CX*("`\=&0@8VQA<W,]
M(FQI9VAT(CXF;F)S<#L\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP
M=70@='EP93TB8VAE8VMB;W@B(&YA;64](F-R96%T;W)?<VAO=R(\/W!H<"!E
M8VAO("@D8W!E<FT@)B!015)-4U]32$]7*2`_("<@8VAE8VME9#TB8VAE8VME
M9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP
M=70@='EP93TB8VAE8VMB;W@B(&YA;64](F-R96%T;W)?<F5A9"(\/W!H<"!E
M8VAO("@D8W!E<FT@)B!015)-4U]214%$*2`_("<@8VAE8VME9#TB8VAE8VME
M9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP
M=70@='EP93TB8VAE8VMB;W@B(&YA;64](F-R96%T;W)?961I="(\/W!H<"!E
M8VAO("@D8W!E<FT@)B!015)-4U]%1$E4*2`_("<@8VAE8VME9#TB8VAE8VME
M9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP
M=70@='EP93TB8VAE8VMB;W@B(&YA;64](F-R96%T;W)?9&5L971E(CP_<&AP
M(&5C:&\@*"1C<&5R;2`F(%!%4DU37T1%3$5412D@/R`G(&-H96-K960](F-H
M96-K960B)R`Z("<G(#\^("\^/"]T9#X*/"]T<CX*"CPA+2T@4W!A8V5R("TM
M/@H\='(^/'1D/B9N8G-P.SPO=&0^/"]T<CX*"CPA+2T@57-E<B!097)M:7-S
M:6]N<R`M+3X*/'1R('9A;&EG;CTB;6ED9&QE(CX*("`\=&0@8VQA<W,](FAE
M861E<B!L969T06QI9VXB/@H@("`@/#]P:'`@96-H;R!(;W)D93HZ:6UG*"=U
M<V5R+G!N9R<L("<G+"`G)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R
M9&4G*2D@+B`G)FYB<W`[)R`N(%\H(DEN9&EV:61U86P@57-E<G,B*2`_/@H@
M(#PO=&0^"B`@/'1D(&-L87-S/2)H96%D97(B(&%L:6=N/2)C96YT97(B/CP_
M<&AP(&5C:&\@7R@B4VAO=R(I(#\^/"]T9#X*("`\=&0@8VQA<W,](FAE861E
M<B(@86QI9VX](F-E;G1E<B(^/#]P:'`@96-H;R!?*")296%D(BD@/SX\+W1D
M/@H@(#QT9"!C;&%S<STB:&5A9&5R(B!A;&EG;CTB8V5N=&5R(CX\/W!H<"!E
M8VAO(%\H(D5D:70B*2`_/CPO=&0^"B`@/'1D(&-L87-S/2)H96%D97(B(&%L
M:6=N/2)C96YT97(B/CP_<&AP(&5C:&\@7R@B1&5L971E(BD@/SX\+W1D/@H@
M(#QT9"!C;&%S<STB:&5A9&5R(')I9VAT06QI9VXB/CPO=&0^"CPO='(^"CP_
M<&AP(&9O<F5A8V@@*"1U<V5R<&5R;7,@87,@)'5S97(@/3X@)'5P97)M*2![
M(&EF("@D=7-E<B`A/2`D;W=N97(I('L@/SX*/'1R/@H@(#QT9"!C;&%S<STB
M;&EG:'0B/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<RA!=71H.CIR96UO
M=F5(;V]K*"1U<V5R*2D@/SX\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)U
M7VYA;65S6SP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D=7-E<BD@/SY=
M(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1U<V5R*2`_
M/B(@+SX\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP93TB
M8VAE8VMB;W@B(&YA;64](G5?<VAO=UL\/W!H<"!E8VAO(&AT;6QS<&5C:6%L
M8VAA<G,H)'5S97(I(#\^72(\/W!H<"!E8VAO("@D=7!E<FT@)B!015)-4U]3
M2$]7*2`_("<@8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H@
M(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA
M;64](G5?<F5A9%L\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'5S97(I
M(#\^72(\/W!H<"!E8VAO("@D=7!E<FT@)B!015)-4U]214%$*2`_("<@8VAE
M8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG;CTB
M8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](G5?961I=%L\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'5S97(I(#\^72(\/W!H<"!E
M8VAO("@D=7!E<FT@)B!015)-4U]%1$E4*2`_("<@8VAE8VME9#TB8VAE8VME
M9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP
M=70@='EP93TB8VAE8VMB;W@B(&YA;64](G5?9&5L971E6SP_<&AP(&5C:&\@
M:'1M;'-P96-I86QC:&%R<R@D=7-E<BD@/SY=(CP_<&AP(&5C:&\@*"1U<&5R
M;2`F(%!%4DU37T1%3$5412D@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G
M(#\^("\^/"]T9#X*/"]T<CX*/#]P:'`@?2!](#\^"CPA+2T@3F5W('5S97(@
M<F]W("TM/@H\='(^"CP_<&AP(&EF("@D875T:"T^:&%S0V%P86)I;&ET>2@G
M;&ES="<I*3H@/SX*("`\=&0@8VQA<W,](FQI9VAT(CX*("`@(#QS96QE8W0@
M;F%M93TB=5]N86UE<UM\?&YE=UTB/@H@("`@("`\;W!T:6]N('9A;'5E/2(B
M/CP_<&AP(&5C:&\@7R@B4V5L96-T(&$@=7-E<B!T;R!A9&0B*2`N("<Z)R`_
M/CPO;W!T:6]N/@H@("`@/#]P:'`@9F]R96%C:"`H)'5S97),:7-T(&%S("1U
M<V5R*2![(&EF("@A:7-S970H)'5S97)P97)M<ULD=7-E<ETI*2![(#\^"B`@
M("`@(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R
M<R@D=7-E<BD@/SXB/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<RA!=71H
M.CIR96UO=F5(;V]K*"1U<V5R*2D@/SX\+V]P=&EO;CX*("`@(#P_<&AP('T@
M?2`_/@H@("`@/"]S96QE8W0^"B`@/"]T9#X*/#]P:'`@96QS93H@/SX*("`\
M=&0@8VQA<W,](FQI9VAT(CX\:6YP=70@='EP93TB=&5X="(@;F%M93TB=5]N
M86UE<UM\?&YE=UTB("\^/"]T9#X*/#]P:'`@96YD:68[(#\^"B`@/'1D(&%L
M:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB=5]S
M:&]W6WQ\;F5W72(@+SX\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP
M=70@='EP93TB8VAE8VMB;W@B(&YA;64](G5?<F5A9%M\?&YE=UTB("\^/"]T
M9#X*("`\=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X
M(B!N86UE/2)U7V5D:71;?'QN97==(B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C
M96YT97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB=5]D96QE=&5;
M?'QN97==(B`O/CPO=&0^"CPO='(^"@H\(2TM(%-P86-E<B`M+3X*/'1R/CQT
M9#XF;F)S<#L\+W1D/CPO='(^"@H\(2TM($=R;W5P(%!E<FUI<W-I;VYS("TM
M/@H\='(@=F%L:6=N/2)M:61D;&4B/@H@(#QT9"!C;&%S<STB:&5A9&5R(&QE
M9G1!;&EG;B(^"B`@("`\/W!H<"!E8VAO($AO<F1E.CII;6<H)V=R;W5P+G!N
M9R<L("<G+"`G)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D@
M+B`G)FYB<W`[)R`N(%\H(D=R;W5P<R(I(#\^"B`@/"]T9#X*("`\=&0@8VQA
M<W,](FAE861E<B(@86QI9VX](F-E;G1E<B(^/#]P:'`@96-H;R!?*")3:&]W
M(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(B!A;&EG;CTB8V5N=&5R
M(CX\/W!H<"!E8VAO(%\H(E)E860B*2`_/CPO=&0^"B`@/'1D(&-L87-S/2)H
M96%D97(B(&%L:6=N/2)C96YT97(B/CP_<&AP(&5C:&\@7R@B161I="(I(#\^
M/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E<B(^/#]P
M:'`@96-H;R!?*")$96QE=&4B*2`_/CPO=&0^"B`@/'1D(&-L87-S/2)H96%D
M97(@<FEG:'1!;&EG;B(^)FYB<W`[/"]T9#X*/"]T<CX*/#]P:'`@)&=R;W5P
M<&5R;7,@/2`D<&5R;2T^9V5T1W)O=7!097)M:7-S:6]N<R@I.R!F;W)E86-H
M("@D9W)O=7!P97)M<R!A<R`D9W)O=7`@/3X@)&=P97)M*3H@:68@*"$D9W)O
M=7!S+3YE>&ES=',H)&=R;W5P<RT^9V5T1W)O=7!.86UE*"1G<F]U<"DI*2!C
M;VYT:6YU93L@/SX*/'1R/@H@(#QT9"!C;&%S<STB;&EG:'0B/CP_<&AP(&5C
M:&\@:'1M;'-P96-I86QC:&%R<R@D9W)O=7!S+3YG971'<F]U<$YA;64H)&=R
M;W5P*2D@/SX\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)G7VYA;65S6SP_
M<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D9W)O=7`I(#\^72(@=F%L=64]
M(CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D9W)O=7`I(#\^(B`O/CPO
M=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O
M>"(@;F%M93TB9U]S:&]W6SP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D
M9W)O=7`I(#\^72(\/W!H<"!E8VAO("@D9W!E<FT@)B!015)-4U]32$]7*2`_
M("<@8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A
M;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F=?
M<F5A9%L\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&=R;W5P*2`_/ETB
M/#]P:'`@96-H;R`H)&=P97)M("8@4$5235-?4D5!1"D@/R`G(&-H96-K960]
M(F-H96-K960B)R`Z("<G(#\^("\^/"]T9#X*("`\=&0@86QI9VX](F-E;G1E
M<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)G7V5D:71;/#]P:'`@
M96-H;R!H=&UL<W!E8VEA;&-H87)S*"1G<F]U<"D@/SY=(CP_<&AP(&5C:&\@
M*"1G<&5R;2`F(%!%4DU37T5$250I(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@
M.B`G)R`_/B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T
M>7!E/2)C:&5C:V)O>"(@;F%M93TB9U]D96QE=&5;/#]P:'`@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*"1G<F]U<"D@/SY=(CP_<&AP(&5C:&\@*"1G<&5R;2`F
M(%!%4DU37T1%3$5412D@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G(#\^
M("\^/"]T9#X*/"]T<CX*/#]P:'`@96YD9F]R96%C:#L@/SX*/"$M+2!.97<@
M9W)O=7`@<F]W("TM/@H\='(^"B`@/'1D(&-L87-S/2)L:6=H="(^"B`@("`\
M<V5L96-T(&YA;64](F=?;F%M97-;?'QN97==(CX*("`@("`@/&]P=&EO;B!V
M86QU93TB(CX\/W!H<"!E8VAO(%\H(E-E;&5C="!A(&=R;W5P('1O(&%D9"(I
M("X@)SHG(#\^/"]O<'1I;VX^"B`@("`\/W!H<"!F;W)E86-H("@D9W)O=7!,
M:7-T(&%S("1G:60@/3X@)&=R;W5P*2![(&EF("AE;7!T>2@D9W)O=7!P97)M
M<ULD9VED72DI('L@/SX*("`@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1G:60I(#\^(CX\/W!H<"!E8VAO(&AT;6QS
M<&5C:6%L8VAA<G,H)&=R;W5P*2`_/CPO;W!T:6]N/@H@("`@/#]P:'`@?2!]
M(#\^"B`@("`\+W-E;&5C=#X*("`\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R
M(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F=?<VAO=UM\?&YE=UTB
M("\^/"]T9#X*("`\=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4](F-H
M96-K8F]X(B!N86UE/2)G7W)E861;?'QN97==(B`O/CPO=&0^"B`@/'1D(&%L
M:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB9U]E
M9&ET6WQ\;F5W72(@+SX\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP
M=70@='EP93TB8VAE8VMB;W@B(&YA;64](F=?9&5L971E6WQ\;F5W72(@+SX\
M+W1D/@H\+W1R/@H*/'1R/@H@/'1D/B9N8G-P.SPO=&0^"CPO='(^"@H\='(^
M"B`\=&0@8V]L<W!A;CTB-R(^"B`@/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA
M<W,](F)U='1O;B(@=F%L=64](CP_<&AP('!R:6YT9BA?*")3879E("5S(BDL
M(&AT;6QS<&5C:6%L8VAA<G,H)'-H87)E+3YG970H)VYA;64G*2DI(#\^(B`O
M/@H\/W!H<"!I9B`H0&-O=6YT*"1C:&EL9')E;BDI.B`_/@H@(#QI;G!U="!T
M>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB(&]N8VQI8VL](F1O8W5M96YT
M+F5D:70N86-T:6]N240N=F%L=64@/2`G961I=&9O<FUI;FAE<FET)SLB('9A
M;'5E/2(\/W!H<"!E8VAO(%\H(D%P<&QY('1O($-H:6QD(%-H87)E<R(I(#\^
M(B`O/@H\/W!H<"!E;F1I9CL@/SX*(#PO=&0^"CPO='(^"@H\+W1A8FQE/@H\
M+V9O<FT^"CQB<B`O/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O=&5S="\`
M````````````````````````````````````````````````````````````
M`````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,#`P`#$P-3$U-#,S-S8P`#`R,#8S,0`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1E;7!L871E<R]T97-T+V5X=&5N<VEO;G,N:6YC````````````````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#0R,S$`,3`U,34T,S,W-3<`,#(S-3,Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#QH=&UL/@H\
M:&5A9#X*/'1I=&QE/E!(4"!%>'1E;G-I;VYS/"]T:71L93X*/'-T>6QE/@IB
M;V1Y('L@8F%C:V=R;W5N9"UC;VQO<CH@=VAI=&4[(&UA<F=I;BUT;W`Z(#`[
M(&UA<F=I;BUL969T.B`R,#L@;6%R9VEN+7)I9VAT.B`R,#L@?0IT86)L92![
M(&9O;G0M9F%M:6QY.B!!<FEA;"P@2&5L=F5T:6-A+"!S86YS+7-E<FEF.R!F
M;VYT+7-I>F4Z(#$R<'@[(&UA<F=I;BUT;W`Z(#`[(&UA<F=I;BUL969T.B`P
M.R!]"F$@>R!T97AT+61E8V]R871I;VXZ(&YO;F4[(&9O;G0M9F%M:6QY.B!!
M<FEA;"P@2&5L=F5T:6-A+"!S86YS+7-E<FEF.R!F;VYT+7-I>F4Z(#$R<'@[
M(&UA<F=I;BUT;W`Z(#`[(&UA<F=I;BUL969T.B`P.R!]"F$Z86-T:79E('L@
M8V]L;W(Z(",R-#4W9F8[('T*83IH;W9E<B![(&-O;&]R.B`C,C0U-V9F.R!T
M97AT+61E8V]R871I;VXZ('5N9&5R;&EN93L@?0IA.FQI;FL@>R!C;VQO<CH@
M(S(T-3=F9CL@?0IA.G9I<VET960@>R!C;VQO<CH@(S(T-3=F9CL@?0HN8FQA
M8VL@>R!B86-K9W)O=6YD+6-O;&]R.B`C,#`P,#`P.R!C;VQO<CH@(V9F9F9F
M9CL@?0H\+W-T>6QE/@H\+VAE860^"CQB;V1Y/@H\82!H<F5F/2(\/W!H<"!E
M8VAO(&ES<V5T*"1?1T546R=U<FPG72D@/R!H=&UL<W!E8VEA;&-H87)S*"1?
M1T546R=U<FPG72D@.B`G=&5S="YP:'`G(#\^/VUO9&4]=&5S="(^)FQT.R9L
M=#L@0F%C:R!T;R!T97-T+G!H<#PO83X*/&)R("\^"CQT86)L92!W:61T:#TB
M,3`P)2(@8V5L;'-P86-I;F<](C`B/CQT<CX\=&0@8V]L<W!A;CTB,B(^/'1A
M8FQE/@H\='(^/'1D/G!H<"!V97)S:6]N.CPO=&0^/'1D/CQS=')O;F<^/#]P
M:'`@96-H;R!P:'!V97)S:6]N*"D@/SX\+W-T<F]N9SX\+W1D/CPO='(^"CQT
M<CX\=&0^<V5R=F5R(&%P:3H\+W1D/CQT9#X\<W1R;VYG/CP_<&AP(&5C:&\@
M0'!H<%]S87!I7VYA;64H*2`_/CPO<W1R;VYG/CPO=&0^/"]T<CX*/'1R/CQT
M9#YL;V%D960@97AT96YS:6]N<SH\+W1D/CQT9#X\<W1R;VYG/CP_<&AP("1E
M>'1E;G-I;VYS(#T@0&=E=%]L;V%D961?97AT96YS:6]N<R@I.R!E8VAO(&-O
M=6YT*"1E>'1E;G-I;VYS*3L@/SX\+W-T<F]N9SX\+W1D/CPO='(^"CQT<CX\
M=&0^<WES=&5M.CPO=&0^/'1D/CQS=')O;F<^/#]P:'`@96-H;R!`<&AP7W5N
M86UE*"D@/SX\+W-T<F]N9SX\+W1D/CPO='(^"CPO=&%B;&4^/&)R("\^/"]T
M9#X\+W1R/@H\='(@8VQA<W,](F)L86-K(CX*/'1D/CQS=')O;F<^86-T:79A
M=&5D(&5X=&5N<VEO;G,Z/"]S=')O;F<^/"]T9#X*/'1D/CQS=')O;F<^/#]P
M:'`@96-H;R!I<W-E="@D7T=%5%LG97AT)UTI(#\@)%]'151;)V5X="==(#H@
M)R<@/SX@9G5N8W1I;VX@;&ES=#H\+W-T<F]N9SX\+W1D/@H\+W1R/@H\='(^
M/'1D('9A;&EG;CTB=&]P(B!W:61T:#TB-3`E(CX\=&%B;&4@=VED=&@](C$P
M,"4B/@H\/W!H<`H@("`@0'-O<G0H)&5X=&5N<VEO;G,I.PH@("`@9F]R96%C
M:"`H)&5X=&5N<VEO;G,@87,@)&5X=&5N<VEO;BD@>PH@("`@("`@(&5C:&\@
M)SQT<CX\=&0@=VED=&@](C,P)2(^)R`N("1E>'1E;G-I;VX@+B`G/"]T9#X\
M=&0^/&$@:')E9CTB/VUO9&4]97AT96YS:6]N<R9A;7`[97AT/2<@+B`D97AT
M96YS:6]N("X@)R9A;7`[=7)L/2<@+B!U<FQE;F-O9&4H:7-S970H)%]'151;
M)W5R;"==*2`_("1?1T546R=U<FPG72`Z("<G*2`N("<B/F9U;F-T:6]N(&QI
M<W0\+V$^/"]T9#X\+W1R/B<["B`@("!]"C\^"CPO=&%B;&4^/"]T9#X\=&0@
M=F%L:6=N/2)T;W`B('=I9'1H/2(U,"4B/CQT86)L93X*/#]P:'`*("`@(&EF
M("AI<W-E="@D7T=%5%LG97AT)UTI*2!["B`@("`@("`@)&9U;F-T:6]N<R`]
M($!G971?97AT96YS:6]N7V9U;F-S*"1?1T546R=E>'0G72D["B`@("`@("`@
M:68@*&ES7V%R<F%Y*"1F=6YC=&EO;G,I*2!["B`@("`@("`@("`@('-O<G0H
M)&9U;F-T:6]N<RD["B`@("`@("`@("`@(&9O<F5A8V@@*"1F=6YC=&EO;G,@
M87,@)&9U;F-T:6]N*2!["B`@("`@("`@("`@("`@("!E8VAO("(\='(^/'1D
M/CQA(&AR968]7")H='1P.B\O=W=W+G!H<"YN970O;6%N=6%L+V9U;F-T:6]N
M+B(@+B!S=')?<F5P;&%C92@G7R<L("<M)RP@)&9U;F-T:6]N*2`N("(N<&AP
M7"(@=&%R9V5T/5PB7V)L86YK7"(^)&9U;F-T:6]N/"]A/CPO=&0^/"]T<CY<
M;B(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"C\^"CPO=&%B;&4^
M/"]T9#X\+W1R/CPO=&%B;&4^/"]B;V1Y/CPO:'1M;#X*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1E;7!L871E<R]T97-T+V9O;W1E<BYI;F,`````````
M````````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,C``,3`U,34T,S,W-3<`
M,#(R-C(P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#PO8F]D>3X*/"]H=&UL/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T96UP;&%T97,O=&5S="]H96%D97(N:6YC````````````````````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P-S8R`#$P-3$U-#,S-S8P`#`R,C4V,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\(41/0U19
M4$4@:'1M;"!054),24,@(BTO+U<S0R\O1%1$(%A(5$U,(#$N,"!4<F%N<VET
M:6]N86PO+T5.(B`B1%1$+WAH=&UL,2UT<F%N<VET:6]N86PN9'1D(CX*/&AT
M;6P^"CQH96%D/@H\=&ET;&4^/#]P:'`@96-H;R`D;6]D=6QE(#\^.B!3>7-T
M96T@0V%P86)I;&ET:65S(%1E<W0\+W1I=&QE/@H\<W1Y;&4@='EP93TB=&5X
M="]C<W,B/@H\(2TM"F)O9'D@>R!F;VYT+69A;6EL>3H@1V5N979A+$%R:6%L
M+$AE;'9E=&EC82QS86YS+7-E<FEF.R!F;VYT+7-I>F4Z(#$P<'0[('T*=&0@
M>R!F;VYT+69A;6EL>3H@1V5N979A+$%R:6%L+$AE;'9E=&EC82QS86YS+7-E
M<FEF.R!F;VYT+7-I>F4Z(#$P<'0[('UH,2![(&9O;G0M<VEZ93H@,3)P=#L@
M8V]L;W(Z(&)L86-K.R!F;VYT+69A;6EL>3H@5F5R9&%N82Q'96YE=F$L07)I
M86PL2&5L=F5T:6-A+`IS86YS+7-E<FEF.R!]"BTM/@H\+W-T>6QE/@H\+VAE
M860^"@H\8F]D>2!B9V-O;&]R/2)W:&ET92(@=&5X=#TB8FQA8VLB/@H`````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S
M+W1E<W0O<&AP7W9E<G-I;VXN:6YC````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,3<V,@`Q,#4Q-30S,S<U-P`P,C,V-S0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/&@Q/E!(4"!697)S:6]N/"]H
M,3X*/'5L/@H@("`@/&QI/CQA(&AR968](CP_<&AP(&5C:&\@)'!H<%]I;F9O
M+3YP:'!I;F9O(#\^(CY6:65W('!H<&EN9F\H*2!S8W)E96X\+V$^/"]L:3X*
M("`@(#QL:3X\82!H<F5F/2(\/W!H<"!E8VAO("1P:'!?:6YF;RT^97AT96YS
M:6]N<R`_/B(^5FEE=R!L;V%D960@97AT96YS:6]N<SPO83X\+VQI/@H@("`@
M/&QI/E!(4"!697)S:6]N.B`\/W!H<"!E8VAO("1P:'!?:6YF;RT^=F5R<VEO
M;B`_/CPO;&D^"B`@("`\;&D^4$A0($UA:F]R(%9E<G-I;VXZ(#P_<&AP(&5C
M:&\@)'!H<%]I;F9O+3YM86IO<B`_/CPO;&D^"CP_<&AP(&EF("AI<W-E="@D
M<&AP7VEN9F\M/FUI;F]R*2DZ(#\^"B`@("`\;&D^4$A0($UI;F]R(%9E<G-I
M;VXZ(#P_<&AP(&5C:&\@)'!H<%]I;F9O+3YM:6YO<B`_/CPO;&D^"CP_<&AP
M(&5N9&EF.R`_/@H\/W!H<"!I9B`H:7-S970H)'!H<%]I;F9O+3YS=6)M:6YO
M<BDI.B`_/@H@("`@/&QI/E!(4"!3=6)M:6YO<B!697)S:6]N.B`\/W!H<"!E
M8VAO("1P:'!?:6YF;RT^<W5B;6EN;W(@/SX\+VQI/@H\/W!H<"!E;F1I9CL@
M/SX*("`@(#QL:3Y02%`@5F5R<VEO;B!#;&%S<VEF:6-A=&EO;CH@/#]P:'`@
M96-H;R`D<&AP7VEN9F\M/F-L87-S(#\^/"]L:3X*("`@(#QL:2!S='EL93TB
M8V]L;W(Z/#]P:'`@96-H;R`D<&AP7VEN9F\M/G-T871U<U]C;VQO<B`_/B(^
M/'-T<F]N9SX\/W!H<"!E8VAO("1P:'!?:6YF;RT^<W1A='5S(#\^/"]S=')O
M;F<^/"]L:3X*/#]P:'`@:68@*&ES<V5T*"1P:'!?:6YF;RT^=F5R<VEO;E]C
M:&5C:RDI.B`_/@H@("`@/&QI/CP_<&AP(&5C:&\@)'!H<%]I;F9O+3YV97)S
M:6]N7V-H96-K(#\^/"]L:3X*/#]P:'`@96YD:68[(#\^"CP_<&AP(&EF("AI
M<W-E="@D<&AP7VEN9F\M/FEN<V5C=7)E*2DZ(#\^"B`@("`\;&D@<W1Y;&4]
M(F-O;&]R.F]R86YG92(^/'-T<F]N9SX\/W!H<"!E8VAO("1P:'!?:6YF;RT^
M:6YS96-U<F4@/SX\<W1R;VYG/CPO;&D^"CP_<&AP(&5N9&EF.R`_/@H\+W5L
M/@H``````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M
M<&QA=&5S+W1E<W0O=F5R<VEO;BYI;F,`````````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#$V-``Q,#4Q-30S,S<U-P`P,C,P,C``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/&@Q/CP_<&AP(&5C
M:&\@)&UO9'5L92`_/B!697)S:6]N/"]H,3X*/'5L/@H@("`@/&QI/CP_<&AP
M(&5C:&\@)&UO9'5L92`_/CH@/#]P:'`@96-H;R`D;6]D=6QE7W9E<G-I;VX@
M/SX\+VQI/@H\+W5L/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E<W0N<&AP````````
M````````````````````````````````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,S4R,S4`,3`U,34T,S,W-#,`,#$W,S4U`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO
M<F1E+W1E<W0N<&AP+'8@,2XQ,C(N-BXQ-R`R,#`V+S`V+S$P(#(S.C$V.C4Q
M(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0G)E;G0@
M2BX@3F]R9'%U:7-T(#QB:FY`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,3DY
M.2TR,#`V($-H87)L97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"B\J(%)E9VES=&5R(&$@<V5S<VEO
M;BX@*B\*<V5S<VEO;E]S=&%R="@I.PII9B`H(6ES<V5T*"1?4T534TE/3ELG
M:&]R9&5?=&5S=%]C;W5N="==*2D@>PH@("`@)%]315-324].6R=H;W)D95]T
M97-T7V-O=6YT)UT@/2`P.PI]"@HO*B!);F-L=61E($AO<F1E)W,@8V]R92YP
M:'`@9FEL92X@*B\*:6YC;'5D95]O;F-E("=L:6(O8V]R92YP:'`G.PH*+RH@
M5V4@<VAO=6QD(&AA=F4@;&]A9&5D('1H92!3=')I;F<@8VQA<W,L(&9R;VT@
M=&AE($AO<F1E7U5T:6P@<&%C:V%G92P@:6X*("H@8V]R92YP:'`N($EF(%-T
M<FEN9SHZ(&ES;B=T(&1E9FEN960L('1H96X@=V4G<F4@;F]T(&9I;F1I;F<@
M<V]M92!C<FET:6-A;`H@*B!L:6)R87)I97,N("HO"FEF("@A8VQA<W-?97AI
M<W1S*"=3=')I;F<G*2D@>PH@("`@96-H;R`G/&)R("\^/'-P86X@<W1Y;&4]
M(F-O;&]R.B!R960[(&9O;G0M<VEZ93H@,3AP>#L@9F]N="UW96EG:'0Z(&)O
M;&0[(CY4:&4@2&]R9&5?571I;"!P86-K86=E('=A<R!N;W0@9F]U;F0N($EF
M(%!(4%PG<R!E<G)O<E]R97!O<G1I;F<@<V5T=&EN9R!I<R!H:6=H(&5N;W5G
M:"P@=&AE<F4@<VAO=6QD(&)E(&5R<F]R(&UE<W-A9V5S('!R:6YT960@86)O
M=F4@=&AA="!M87D@:&5L<"!Y;W4@:6X@9&5B=6=G:6YG('1H92!P<F]B;&5M
M+B!)9B!Y;W4@87)E('-I;7!L>2!M:7-S:6YG('1H97-E(&9I;&5S($%.1"!A
M<F4@:6YS=&%L;&EN9R!A($-64R!C:&5C:V]U="P@=&AE;B!Y;W4@;F5E9"!T
M;R!G970@=&AE(#QA(&AR968](FAT='`Z+R]C=G,N:&]R9&4N;W)G+V-V<RYP
M:'`O9G)A;65W;W)K(CYF<F%M97=O<FL\+V$^(&UO9'5L92!F<F]M(#QA(&AR
M968](FAT='`Z+R]H;W)D92YO<F<O<V]U<F-E+R(^2&]R9&4@0U93/"]A/BP@
M86YD(&EN<W1A;&P@=&AE('!A8VMA9V5S(&EN(&ET('=I=&@@=&AE(&EN<W1A
M;&PM<&%C:V%G97,N<&AP('-C<FEP="X\+W-P86X^)SL*("`@(&5X:70["GT*
M"B\J($EN:71I86QI>F4@=&AE($AO<F1E7U1E<W0Z.B!C;&%S<RX@*B\*:68@
M*"%I;F-L=61E7V]N8V4@)VQI8B]497-T+G!H<"<I('L*("`@("\J(%1R>2!A
M;F0@<')O=FED92!E;F]U9V@@:6YF;W)M871I;VX@=&\@9&5B=6<@=&AE(&UI
M<W-I;F<@9FEL92X@*B\*("`@(&5C:&\@)SQB<B`O/CQS<&%N('-T>6QE/2)C
M;VQO<CH@<F5D.R!F;VYT+7-I>F4Z(#$X<'@[(&9O;G0M=V5I9VAT.B!B;VQD
M.R(^56YA8FQE('1O(&9I;F0@:&]R9&4O;&EB+U1E<W0N<&AP+B!9;W5R($AO
M<F1E(&EN<W1A;&QA=&EO;B!M87D@8F4@;6ES<VEN9R!C<FET:6-A;"!F:6QE
M<RP@;W(@4$A0(&UA>2!N;W0@:&%V92!S=69F:6-I96YT('!E<FUI<W-I;VYS
M('1O(&EN8VQU9&4@9FEL97,N(%1H97)E(&UA>2!B92!E<G)O<B!M97-S86=E
M<R!P<FEN=&5D(&%B;W9E('1H:7,@;65S<V%G92!T:&%T('=I;&P@:&5L<"!Y
M;W4@:6X@9&5B=6=G:6YG('1H92!P<F]B;&5M+CPO<W!A;CXG.PH@("`@97AI
M=#L*?0H*+RH@268@=V4G=F4@9V]T=&5N('1H:7,@9F%R+"!W92!S:&]U;&0@
M:&%V92!F;W5N9"!E;F]U9V@@;V8@2&]R9&4@=&\@<G5N"B`J('1E<W1S+B!#
M<F5A=&4@=&AE('1E<W1I;F<@;V)J96-T+B`J+PHD:&]R9&5?=&5S="`]("9N
M97<@2&]R9&5?5&5S="@I.PH*+RH@2&]R9&4@9&5F:6YI=&EO;G,N("HO"B1M
M;V1U;&4@/2`G2&]R9&4G.PIR97%U:7)E7V]N8V4@)RXO;&EB+W9E<G-I;VXN
M<&AP)SL*)&UO9'5L95]V97)S:6]N(#T@2$]21$5?5D524TE/3CL*"B\J(%!(
M4"!M;V1U;&4@8V%P86)I;&ET:65S+B`J+PHD;6]D=6QE7VQI<W0@/2!A<G)A
M>2@*("`@("=C='EP92<@/3X@)T-T>7!E(%-U<'!O<G0G+`H@("`@*'9E<G-I
M;VY?8V]M<&%R92AP:'!V97)S:6]N*"DL("<U)RD@/"`P(#\@)V1O;7AM;"<@
M.B`G9&]M)RD@/3X@)T1/32!834P@4W5P<&]R="<L"B`@("`G9G1P)R`]/B`G
M1E10(%-U<'!O<G0G+`H@("`@)V=D)R`]/B`G1T0@4W5P<&]R="<L"B`@("`G
M9V5T=&5X="<@/3X@87)R87DH"B`@("`@("`@)V1E<V-R:7`G(#T^("='971T
M97AT(%-U<'!O<G0G+`H@("`@("`@("=E<G)O<B<@/3X@)TAO<F1E('=I;&P@
M;F]T(')U;B!W:71H;W5T(&=E='1E>'0@<W5P<&]R="X@0V]M<&EL92!02%`@
M=VET:"`\8V]D93XM+7=I=&@M9V5T=&5X=#PO8V]D93X@8F5F;W)E(&-O;G1I
M;G5I;F<N)RP*("`@("`@("`G9F%T86PG(#T^('1R=64*("`@("DL"B`@("`G
M:6-O;G8G(#T^(&%R<F%Y*`H@("`@("`@("=D97-C<FEP)R`]/B`G26-O;G8@
M4W5P<&]R="<L"B`@("`@("`@)V5R<F]R)R`]/B`G268@>6]U('=A;G0@=&\@
M=&%K92!F=6QL(&%D=F%N=&%G92!O9B!(;W)D95PG<R!L;V-A;&EZ871I;VX@
M9F5A='5R97,@86YD(&-H87)A8W1E<B!S970@<W5P<&]R="P@>6]U('=I;&P@
M;F5E9"!T:&4@:6-O;G8@97AT96YS:6]N+B<*("`@("DL"B`@("`G:6UA<"<@
M/3X@)TE-05`@4W5P<&]R="<L"B`@("`G;&1A<"<@/3X@)TQ$05`@4W5P<&]R
M="<L"B`@("`G;6)S=')I;F<G(#T^(&%R<F%Y*`H@("`@("`@("=D97-C<FEP
M)R`]/B`G36)S=')I;F<@4W5P<&]R="<L"B`@("`@("`@)V5R<F]R)R`]/B`G
M268@>6]U('=A;G0@=&\@=&%K92!F=6QL(&%D=F%N=&%G92!O9B!(;W)D95PG
M<R!L;V-A;&EZ871I;VX@9F5A='5R97,@86YD(&-H87)A8W1E<B!S970@<W5P
M<&]R="P@>6]U('=I;&P@;F5E9"!T:&4@;6)S=')I;F<@97AT96YS:6]N+B<*
M("`@("DL"B`@("`G;6-R>7!T)R`]/B!A<G)A>2@*("`@("`@("`G9&5S8W)I
M<"<@/3X@)TUC<GEP="!3=7!P;W)T)RP*("`@("`@("`G97)R;W(G(#T^("=-
M8W)Y<'0@:7,@82!G96YE<F%L+7!U<G!O<V4@8W)Y<'1O9W)A<&AY(&QI8G)A
M<GD@=VAI8V@@:7,@8G)O861E<B!A;F0@<VEG;FEF:6-A;G1L>2!M;W)E(&5F
M9FEC:65N="`H1D%35$52(2D@=&AA;B!02%!<)W,@;W=N(&-R>7!T;V=R87!H
M:6,@8V]D92!A;F0@=VEL;"!P<F]V:61E<B!F87-T97(@;&]G:6YS+B<*("`@
M("DL"B`@("`G9FEL96EN9F\G(#T^(&%R<F%Y*`H@("`@("`@("=D97-C<FEP
M)R`]/B`G34E-12!-86=I8R!3=7!P;W)T("AF:6QE:6YF;RDG+`H@("`@("`@
M("=E<G)O<B<@/3X@)U1H92!F:6QE:6YF;R!014-,(&UO9'5L92!O<B!T:&4@
M;6EM95]M86=I8R!02%`@97AT96YS:6]N("AS964@8F5L;W<I('=I;&P@;6]S
M="!L:6ME;'D@<')O=FED92!F87-T97(@34E-12!-86=I8R!L;V]K=7!S('1H
M86X@=&AE(&)U:6QT+6EN($AO<F1E(%!(4"!M86=I8R!C;V1E+B!3964@:&]R
M9&4O9&]C<R])3E-404Q,(&9O<B!I;F9O<FUA=&EO;B!O;B!H;W<@=&\@:6YS
M=&%L;"!014-,+U!(4"!E>'1E;G-I;VYS+B<*("`@("DL"B`@("`G;65M8V%C
M:&4G(#T^(&%R<F%Y*`H@("`@("`@("=D97-C<FEP)R`]/B`G;65M8V%C:&5D
M(%-U<'!O<G0@*&UE;6-A8VAE*2<L"B`@("`@("`@)V5R<F]R)R`]/B`G5&AE
M(&UE;6-A8VAE(%!%0TP@;6]D=6QE(&ES(&YE961E9"!O;FQY(&EF('EO=2!A
M<F4@=7-I;F<@=&AE(&UE;6-A8VAE9"!397-S:6]N2&%N9&QE<BX@4V5E(&AO
M<F1E+V1O8W,O24Y35$%,3"!F;W(@:6YF;W)M871I;VX@;VX@:&]W('1O(&EN
M<W1A;&P@4$5#3"]02%`@97AT96YS:6]N<RXG"B`@("`I+`H@("`@)VUI;65?
M;6%G:6,G(#T^(&%R<F%Y*`H@("`@("`@("=D97-C<FEP)R`]/B`G34E-12!-
M86=I8R!3=7!P;W)T("AM:6UE7VUA9VEC*2<L"B`@("`@("`@)V5R<F]R)R`]
M/B`G5&AE(&9I;&5I;F9O(%!%0TP@;6]D=6QE("AS964@86)O=F4I(&]R('1H
M92!M:6UE7VUA9VEC(%!(4"!E>'1E;G-I;VX@=VEL;"!M;W-T(&QI:V5L>2!P
M<F]V:61E(&9A<W1E<B!-24U%($UA9VEC(&QO;VMU<',@=&AA;B!T:&4@8G5I
M;'0M:6X@2&]R9&4@4$A0(&UA9VEC(&-O9&4N(%-E92!H;W)D92]D;V-S+TE.
M4U1!3$P@9F]R(&EN9F]R;6%T:6]N(&]N(&AO=R!T;R!I;G-T86QL(%!%0TPO
M4$A0(&5X=&5N<VEO;G,N)PH@("`@*2P*("`@("=M>7-Q;"<@/3X@)TUY4U%,
M(%-U<'!O<G0G+`H@("`@)V]P96YS<VPG(#T^("=/<&5N4U-,(%-U<'!O<G0G
M+`H@("`@)W!G<W%L)R`]/B`G4&]S=&=R95-13"!3=7!P;W)T)RP*("`@("=S
M97-S:6]N)R`]/B!A<G)A>2@*("`@("`@("`G9&5S8W)I<"<@/3X@)U-E<W-I
M;VX@4W5P<&]R="<L"B`@("`@("`@)V9A=&%L)R`]/B!T<G5E*2P*("`@("=X
M;6PG(#T^("=834P@4W5P<&]R="<L"B`@("`G>FQI8B<@/3X@87)R87DH"B`@
M("`@("`@)V1E<V-R:7`G(#T^("=:;&EB(%-U<'!O<G0G+`H@("`@("`@("=E
M<G)O<B<@/3X@)U1H92!Z;&EB(&UO9'5L92!I<R!H:6=H;'D@<F5C;VUM96YD
M960@9F]R('5S92!W:71H($AO<F1E+B`@270@86QL;W=S('!A9V4@8V]M<')E
M<W-I;VX@86YD(&AA;F1L:6YG(&]F(%I)4"!A;F0@1UH@9&%T82X@0V]M<&EL
M92!02%`@=VET:"`\8V]D93XM+7=I=&@M>FQI8CPO8V]D93X@=&\@86-T:79A
M=&4N)RP*("`@("`@("`G9F%T86PG(#T^(&9A;'-E"B`@("`I+`HI.PH*"B\J
M(%!(4"!3971T:6YG<RX@*B\*)'-E='1I;F=?;&ES="`](&%R<F%Y*`H@("`@
M)VUA9VEC7W%U;W1E<U]R=6YT:6UE)R`]/B!A<G)A>2@*("`@("`@("`G<V5T
M=&EN9R<@/3X@9F%L<V4L"B`@("`@("`@)V5R<F]R)R`]/B`G;6%G:6-?<75O
M=&5S7W)U;G1I;64@;6%Y(&-A=7-E('!R;V)L96US('=I=&@@9&%T86)A<V4@
M:6YS97)T<RP@971C+B!4=7)N(&ET(&]F9BXG"B`@("`I+`H@("`@)VUE;6]R
M>5]L:6UI="<@/3X@87)R87DH"B`@("`@("`@)W-E='1I;F<G(#T^(&9A;'-E
M+`H@("`@("`@("=E<G)O<B<@/3X@)TEF(%!(4%PG<R!I;G1E<FYA;"!M96UO
M<GD@;&EM:70@:7,@='5R;F5D(&]N(&%N9"!I9B!N;W0@<V5T(&AI9V@@96YO
M=6=H($AO<F1E('=I;&P@;F]T(&)E(&%B;&4@=&\@:&%N9&QE(&QA<F=E(&1A
M=&$@:71E;7,@*&4N9RX@;&%R9V4@;6%I;"!A='1A8VAM96YT<R!I;B!)35`I
M+B!)9B!P;W-S:6)L92P@>6]U('-H;W5L9"!D:7-A8FQE('1H92!02%`@;65M
M;W)Y(&QI;6ET(&)Y(')E8V]M<&EL:6YG(%!(4"`\96T^=VET:&]U=#PO96T^
M('1H92`B+2UE;F%B;&4M;65M;W)Y+6QI;6ET(B!F;&%G+B!)9B!T:&ES(&ES
M(&YO="!P;W-S:6)L92P@=&AE;B!Y;W4@<VAO=6QD('-E="!T:&4@=F%L=64@
M;V8@;65M;W)Y7VQI;6ET(&EN('!H<"YI;FD@=&\@82!S=69F:6-I96YT;'D@
M:&EG:"!V86QU92`H0W5R<F5N="!V86QU92!O9B!M96UO<GE?;&EM:70Z("<@
M+B!I;FE?9V5T*"=M96UO<GE?;&EM:70G*2`N("<I+B<*("`@("DL"B`@("`G
M<V%F95]M;V1E)R`]/B!A<G)A>2@*("`@("`@("`G<V5T=&EN9R<@/3X@9F%L
M<V4L"B`@("`@("`@)V5R<F]R)R`]/B`G268@<V%F95]M;V1E(&ES(&5N86)L
M960L($AO<F1E(&-A;FYO="!S970@96YV:7)O;65N="!V87)I86)L97,L('=H
M:6-H(&UE86YS($AO<F1E('=I;&P@8F4@=6YA8FQE('1O('1R86YS;&%T92!T
M:&4@=7-E<B!I;G1E<F9A8V4@:6YT;R!D:69F97)E;G0@;&%N9W5A9V5S+B<*
M("`@("DL"B`@("`G<V5S<VEO;BYU<V5?=')A;G-?<VED)R`]/B!A<G)A>2@*
M("`@("`@("`G<V5T=&EN9R<@/3X@9F%L<V4L"B`@("`@("`@)V5R<F]R)R`]
M/B`G2&]R9&4@=VEL;"!W;W)K('=I=&@@<V5S<VEO;BYU<V5?=')A;G-?<VED
M('1U<FYE9"!O;BP@8G5T('EO=2!M87D@<V5E(&1O=6)L92!S97-S:6]N+6ED
M<R!I;B!Y;W5R(%523',L(&%N9"!I9B!T:&4@<V5S<VEO;B!N86UE(&EN('!H
M<"YI;FD@9&EF9F5R<R!F<F]M('1H92!S97-S:6]N(&YA;64@8V]N9FEG=7)E
M9"!I;B!(;W)D92P@>6]U(&UA>2!G970@='=O('-E<W-I;VX@:61S(&%N9"!S
M964@;W1H97(@;V1D(&)E:&%V:6]R+B!4:&4@55),+7)E=W)I=&EN9R!T:&%T
M('5S95]T<F%N<U]S:60@9&]E<R!A;'-O('1E;F1S('1O(&)R96%K(%A(5$U,
M(&-O;7!L:6%N8V4N($EN('-H;W)T+"!Y;W4@<VAO=6QD(')E86QL>2!D:7-A
M8FQE('1H:7,N)PH@("`@*2P*("`@("=S97-S:6]N+F%U=&]?<W1A<G0G(#T^
M(&%R<F%Y*`H@("`@("`@("=S971T:6YG)R`]/B!F86QS92P*("`@("`@("`G
M97)R;W(G(#T^("=(;W)D92!W;VY<)W0@=V]R:R!W:71H(&%U=&]M871I8V%L
M;'D@<W1A<G1E9"!S97-S:6]N<RP@8F5C875S92!I="!E>'!L:6-I=&QY(&-R
M96%T97,@;F5W('-E<W-I;VX@=VAE;B!N96-E<W-A<GD@=&\@<')O=&5C="!A
M9V%I;G-T('-E<W-I;VX@9FEX871I;VYS+B<*("`@("D**3L*"@HO*B!014%2
M("HO"B1P96%R7VQI<W0@/2!A<G)A>2@*("`@("=-86EL)R`]/B!A<G)A>2@*
M("`@("`@("`G<&%T:"<@/3X@)TUA:6PO4D9#.#(R+G!H<"<L"B`@("`@("`@
M)V5R<F]R)R`]/B`G66]U(&1O(&YO="!H879E('1H92!-86EL('!A8VMA9V4@
M:6YS=&%L;&5D(&]N('EO=7(@<WES=&5M+B!3964@=&AE($E.4U1!3$P@9FEL
M92!F;W(@:6YS=')U8W1I;VYS(&]N(&AO=R!T;R!I;G-T86QL('1H92!P86-K
M86=E+B<*("`@("DL"B`@("`G36%I;%]-:6UE)R`]/B!A<G)A>2@*("`@("`@
M("`G<&%T:"<@/3X@)TUA:6PO;6EM941E8V]D92YP:'`G+`H@("`@("`@("=E
M<G)O<B<@/3X@)UEO=2!D;R!N;W0@:&%V92!T:&4@36%I;%]-:6UE('!A8VMA
M9V4@:6YS=&%L;&5D(&]N('EO=7(@<WES=&5M+B!3964@=&AE($E.4U1!3$P@
M9FEL92!F;W(@:6YS=')U8W1I;VYS(&]N(&AO=R!T;R!I;G-T86QL('1H92!P
M86-K86=E+B<L"B`@("`@("`@)W)E<75I<F5D)R`]/B!T<G5E"B`@("`I+`H@
M("`@)TQO9R<@/3X@87)R87DH"B`@("`@("`@)W!A=&@G(#T^("=,;V<N<&AP
M)RP*("`@("`@("`G97)R;W(G(#T^("=-86ME('-U<F4@>6]U(&%R92!U<VEN
M9R!A('9E<G-I;VX@;V8@4$5!4B!W:&EC:"!I;F-L=61E<R!T:&4@3&]G(&-L
M87-S97,L(&]R('1H870@>6]U(&AA=F4@:6YS=&%L;&5D('1H92!,;V<@<&%C
M:V%G92!S97!E<F%T96QY+B!3964@=&AE($E.4U1!3$P@9FEL92!F;W(@:6YS
M=')U8W1I;VYS(&]N(&EN<W1A;&QI;F<@3&]G+B<L"B`@("`@("`@)W)E<75I
M<F5D)R`]/B!T<G5E+`H@("`@("`@("=F=6YC=&EO;B<@/3X@)U]C:&5C:U]P
M96%R7VQO9U]V97)S:6]N)PH@("`@*2P*("`@("=$0B<@/3X@87)R87DH"B`@
M("`@("`@)W!A=&@G(#T^("=$0BYP:'`G+`H@("`@("`@("=E<G)O<B<@/3X@
M)UEO=2!W:6QL(&YE960@1$(@:68@>6]U(&%R92!U<VEN9R!344P@9')I=F5R
M<R!F;W(@<')E9F5R96YC97,L(&-O;G1A8W1S("A4=7)B82DL(&5T8RXG+`H@
M("`@("`@("=F=6YC=&EO;B<@/3X@)U]C:&5C:U]P96%R7V1B7W9E<G-I;VXG
M"B`@("`I+`H@("`@)TYE=%]3;V-K970G(#T^(&%R<F%Y*`H@("`@("`@("=P
M871H)R`]/B`G3F5T+U-O8VME="YP:'`G+`H@("`@("`@("=E<G)O<B<@/3X@
M)TUA:V4@<W5R92!Y;W4@87)E('5S:6YG(&$@=F5R<VEO;B!O9B!014%2('=H
M:6-H(&EN8VQU9&5S('1H92!.971?4V]C:V5T(&-L87-S+"!O<B!T:&%T('EO
M=2!H879E(&EN<W1A;&QE9"!T:&4@3F5T7U-O8VME="!P86-K86=E('-E<&5R
M871E;'DN(%-E92!T:&4@24Y35$%,3"!F:6QE(&9O<B!I;G-T<G5C=&EO;G,@
M;VX@:6YS=&%L;&EN9R!.971?4V]C:V5T+B<*("`@("DL"B`@("`G1&%T92<@
M/3X@87)R87DH"B`@("`@("`@)W!A=&@G(#T^("=$871E+T-A;&,N<&AP)RP*
M("`@("`@("`G97)R;W(G(#T^("=(;W)D92!R97%U:7)E<R!T:&4@1&%T95]#
M86QC(&-L87-S(&9O<B!+<F]N;VQI=&@@=&\@8V%L8W5L871E(&1A=&5S+B<*
M("`@("DL"B`@("`G075T:%]305-,)R`]/B!A<G)A>2@*("`@("`@("`G<&%T
M:"<@/3X@)T%U=&@O4T%33"YP:'`G+`H@("`@("`@("=E<G)O<B<@/3X@)TAO
M<F1E('=I;&P@=V]R:R!W:71H;W5T('1H92!!=71H7U-!4TP@8VQA<W,L(&)U
M="!I9B!Y;W4@=7-E($%C8V5S<R!#;VYT<F]L($QI<W1S(&EN($E-4"!Y;W4@
M<VAO=6QD(&)E(&%W87)E('1H870@=VET:&]U="!T:&ES(&-L87-S('!A<W-W
M;W)D<R!W:6QL(&)E('-E;G0@=&\@=&AE($E-05`@<V5R=F5R(&EN('!L86EN
M('1E>'0@=VAE;B!R971R:65V:6YG($%#3',N)PH@("`@*2P*("`@("=(5%10
M7U)E<75E<W0G(#T^(&%R<F%Y*`H@("`@("`@("=P871H)R`]/B`G2%144"]2
M97%U97-T+G!H<"<L"B`@("`@("`@)V5R<F]R)R`]/B`G4&%R=',@;V8@2&]R
M9&4@*$A434P@8V]M<&]S:71I;VX@:6X@24U0+"!*;VYA:"P@=&AE(%A-3"U2
M4$,@8VQI96YT+W-E<G9E<BD@=7-E('1H92!(5%107U)E<75E<W0@;&EB<F%R
M>2!T;R!R971R:65V92!54DQS(&%N9"!D;R!O=&AE<B!(5%10(')E<75E<W1S
M+B<*("`@("DL"B`@("`G1FEL92<@/3X@87)R87DH"B`@("`@("`@)W!A=&@G
M(#T^("=&:6QE+G!H<"<L"B`@("`@("`@)V5R<F]R)R`]/B`G2&]R9&4@=VEL
M;"!R97%U:7)E('1H92!&:6QE(&-L87-S('=H96X@:6UP;W)T:6YG($-35B!F
M:6QE<RXG"B`@("`I+`H@("`@)TYE=%]33510)R`]/B!A<G)A>2@*("`@("`@
M("`G<&%T:"<@/3X@)TYE="]33510+G!H<"<L"B`@("`@("`@)V5R<F]R)R`]
M/B`G36%K92!S=7)E('EO=2!A<F4@=7-I;F<@=&AE($YE=%]33510(&UO9'5L
M92!I9B!Y;W4@=V%N="`B<VUT<"(@=&\@=V]R:R!A<R!A(&UA:6QE<B!O<'1I
M;VXN)PH@("`@*2P*("`@("=397)V:6-E<U]796%T:&5R)R`]/B!A<G)A>2@*
M("`@("`@("`G<&%T:"<@/3X@)U-E<G9I8V5S+U=E871H97(N<&AP)RP*("`@
M("`@("`G97)R;W(G(#T^("=397)V:6-E<U]796%T:&5R(&ES('5S960@8GD@
M=&AE('=E871H97(@87!P;&5T+V)L;V-K(&]N('1H92!P;W)T86P@<&%G92XG
M"B`@("`I+`H@("`@)T-A8VAE)R`]/B!A<G)A>2@*("`@("`@("`G<&%T:"<@
M/3X@)T-A8VAE+G!H<"<L"B`@("`@("`@)V5R<F]R)R`]/B`G0V%C:&4@:7,@
M=7-E9"!B>2!T:&4@4V5R=FEC97-?5V5A=&AE<B!M;V1U;&4@;VX@=&AE('=E
M871H97(@87!P;&5T+V)L;V-K(&]N('1H92!P;W)T86P@<&%G92XG"B`@("`I
M+`H@("`@)UA-3%]397)I86QI>F5R)R`]/B!A<G)A>2@*("`@("`@("`G<&%T
M:"<@/3X@)UA-3"]397)I86QI>F5R+G!H<"<L"B`@("`@("`@)V5R<F]R)R`]
M/B`G6$U,7U-E<FEA;&EZ97(@:7,@=7-E9"!B>2!T:&4@4V5R=FEC97-?5V5A
M=&AE<B!M;V1U;&4@;VX@=&AE('=E871H97(@87!P;&5T+V)L;V-K(&]N('1H
M92!P;W)T86P@<&%G92XG"B`@("`I"BD["@HO*B!!9&1I=&EO;F%L(&-H96-K
M(&9O<B!014%2($QO9R!M;V1U;&4@9F]R(&ET<R!V97)S:6]N+B`J+PIF=6YC
M=&EO;B!?8VAE8VM?<&5A<E]L;V=?=F5R<VEO;B@I"GL*("`@(&EF("@A9&5F
M:6YE9"@G4$5!4E],3T=?24Y&3R<I*2!["B`@("`@("`@<F5T=7)N("=9;W5R
M('9E<G-I;VX@;V8@3&]G(&ES(&YO="!R96-E;G0@96YO=6=H+B<["B`@("!]
M"GT*"B\J($%D9&ET:6]N86P@8VAE8VL@9F]R(%!%05(@1$(@;6]D=6QE(&9O
M<B!I=',@=F5R<VEO;BX@*B\*9G5N8W1I;VX@7V-H96-K7W!E87)?9&)?=F5R
M<VEO;B@I"GL*("`@(&EF("@A9&5F:6YE9"@G1$)?4$]25$%"24Q)5%E?3$]7
M15)#05-%)RDI('L*("`@("`@("!R971U<FX@)UEO=7(@=F5R<VEO;B!O9B!$
M0B!I<R!N;W0@<F5C96YT(&5N;W5G:"XG.PH@("`@?0I]"@HO*B!4:&5R92!I
M<R!A('9E<G-I;VX@;V8@=&AE($9I;&4N<&AP('1H870@=V%N=',@82!014%2
M.CIR96=I<W1E<E-H=71D;W=N1G5N8PH@*B!W:&EC:"!I<R!W:&%T(&YE=W!E
M87(@=&5S=',@9F]R+B`@5&AI<R!F=6YC=&EO;B!S965M<R!T;R!O;FQY(&AA
M=F4@97AI<W1E9`H@*B!F;W(@82!L:71T;&4@=VAI;&4L(&)U="!T:&4@4$5!
M4B!G<F]U<"!H87-N)W0@9FEX960@=&AI<R!Y970L('-O('-O;64*("H@<&5O
M<&QE(&=E="!A;B!E<G)O<B!I9B!T:&5Y(&AA=F4@82!C97)T86EN("AR96QE
M87-E*2!V97)S:6]N(&]F(%!%05(N("!790H@*B!T97-T(&9O<B!I="!H97)E
M+B`@268@:70G<R!A('-A9F4@=F5R<VEO;BP@=&5S="!A<R!N;W)M86PL(&]T
M:&5R=VES92!T<GD@80H@*B!L97-S(&5F9F5C=&EV92!B=70@;F]N+65R<F]R
M:6YG('1E<W0@9F]R($9I;&4Z.D-35BX@*B\*:68@*"$D:&]R9&5?=&5S="T^
M:7-296-E;G1014%2*"DI('L*("`@("1P871H(#T@:6YI7V=E="@G:6YC;'5D
M95]P871H)RD["B`@("!I9B`H96UP='DH)'!A=&@I*2!["B`@("`@("`@)'!A
M=&@@/2`G+B<["B`@("!]"B`@("`D<&5A<E]L:7-T6R=&:6QE7T-35B==6R=P
M871H)UT@/2`G6%A86%A8+G!H<"<["B`@("!F;W)E86-H("AE>'!L;V1E*"<Z
M)RP@)'!A=&@I(&%S("1D:7(I('L*("`@("`@("!I9B`H<W5B<W1R*"1D:7(L
M("TQ*2`A/2`G+R<I('L*("`@("`@("`@("`@)&1I<B`N/2`G+R<["B`@("`@
M("`@?0H@("`@("`@("1F:6QE,2`]("1D:7(@+B`G1FEL92]#4U8N<&AP)SL*
M("`@("`@("`D9FEL93(@/2`D9&ER("X@)T9I;&4N<&AP)SL*("`@("`@("`D
M9FEL93,@/2`D9&ER("X@)U!%05(N<&AP)SL*("`@("`@("!I9B`H9FEL95]E
M>&ES=',H)&9I;&4Q*2`F)B!F:6QE7V5X:7-T<R@D9FEL93(I("8F(&9I;&5?
M97AI<W1S*"1F:6QE,RDI('L*("`@("`@("`@("`@+RH@0VAA;F=E('1H92!F
M:6QE;F%M92!T;R!S;VUE=&AI;F<@=V4@:VYO=R!W:6QL(&)E(&9O=6YD+B`J
M+PH@("`@("`@("`@("`D<&5A<E]L:7-T6R=&:6QE7T-35B==6R=P871H)UT@
M/2`G4$5!4BYP:'`G.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@
M("!]"GT*"B\J(%)E<75I<F5D(&-O;F9I9W5R871I;VX@9FEL97,N("HO"B1F
M:6QE7VQI<W0@/2!A<G)A>2@*("`@("=C;VYF:6<O8V]N9BYP:'`G(#T^(&YU
M;&PL"B`@("`G8V]N9FEG+VUI;65?9')I=F5R<RYP:'`G(#T^(&YU;&PL"B`@
M("`G8V]N9FEG+VYL<RYP:'`G(#T^(&YU;&PL"B`@("`G8V]N9FEG+W!R969S
M+G!H<"<@/3X@;G5L;"P*("`@("=C;VYF:6<O<F5G:7-T<GDN<&AP)R`]/B!N
M=6QL"BD["@H*+RH@1V5T('1H92!S=&%T=7,@;W5T<'5T(&YO=RX@*B\*)&UO
M9'5L95]O=71P=70@/2`D:&]R9&5?=&5S="T^<&AP36]D=6QE0VAE8VLH)&UO
M9'5L95]L:7-T*3L*)'-E='1I;F=?;W5T<'5T(#T@)&AO<F1E7W1E<W0M/G!H
M<%-E='1I;F=#:&5C:R@D<V5T=&EN9U]L:7-T*3L*)'!E87)?;W5T<'5T(#T@
M)&AO<F1E7W1E<W0M/E!%05)-;V1U;&5#:&5C:R@D<&5A<E]L:7-T*3L*)&-O
M;F9I9U]O=71P=70@/2`D:&]R9&5?=&5S="T^<F5Q=6ER961&:6QE0VAE8VLH
M)&9I;&5?;&ES="D["@H*+RH@2&%N9&QE('-P96-I86P@;6]D97,N("HO"FEF
M("@A96UP='DH)%]'151;)VUO9&4G72DI('L*("`@("1U<FP@/2`A96UP='DH
M)%]'151;)W5R;"==*2`_("1?1T546R=U<FPG72`Z("=T97-T+G!H<"<["B`@
M("!E8VAO("<\(41/0U194$4@:'1M;"!054),24,@(BTO+U<S0R\O1%1$(%A(
M5$U,(#$N,"!4<F%N<VET:6]N86PO+T5.(B`B1%1$+WAH=&UL,2UT<F%N<VET
M:6]N86PN9'1D(CXG.PH@("`@<W=I=&-H("@D7T=%5%LG;6]D92==*2!["B`@
M("!C87-E("=E>'1E;G-I;VYS)SH*("`@("`@("!R97%U:7)E(%1%4U1?5$5-
M4$Q!5$53("X@)V5X=&5N<VEO;G,N:6YC)SL*("`@("`@("!E>&ET.PH*("`@
M(&-A<V4@)W!H<&EN9F\G.@H@("`@("`@(&5C:&\@)SQA(&AR968](B<@+B!H
M=&UL<W!E8VEA;&-H87)S*"1U<FPI("X@)S]M;V1E/71E<W0B/B9L=#LF;'0[
M($)A8VL@=&\@=&5S="YP:'`\+V$^)SL*("`@("`@("!P:'!I;F9O*"D["B`@
M("`@("`@97AI=#L*"B`@("!C87-E("=F:6QE=&5S="<Z"B`@("`@("`@96-H
M;R`G/&$@:')E9CTB)R`N(&AT;6QS<&5C:6%L8VAA<G,H)'5R;"D@+B`G/VUO
M9&4]=&5S="(^)FQT.R9L=#L@0F%C:R!T;R!T97-T+G!H<#PO83XG.PH@("`@
M("`@(#\^"B`@("`@("`@/&AT;6P^"B`@("`@("`@/&)O9'D@8F=C;VQO<CTB
M=VAI=&4B('1E>'0](F)L86-K(CX*("`@("`@("`\<#X\9F]N="!F86-E/2)(
M96QV971I8V$L($%R:6%L+"!S86YS+7-E<FEF(B!S:7IE/2(R(CX*("`@("`@
M("!4:&5R92!A<F4@<V]M92!V97)S:6]N<R!O9B!014%2('1H870@=V5R92!R
M96QE87-E9"!A="!T:6UE<R!T:&%T"B`@("`@("`@9&ED(&YO="!C;VYT86EN
M(&$@9G5N8W1I;VX@=&AA="!&:6QE+G!H<"!E>'!E8W1S+B`@5&AI<R!D;V5S
M(&YO=`H@("`@("`@('-E96T@=&\@:&%V92!C875S960@<')O8FQE;7,@9F]R
M(&%N>6]N92!E>&-E<'0@=VAE;B!R=6YN:6YG(&]U<@H@("`@("`@('1E<W0@
M<V-R:7!T+"!B=70@>6]U(&YE960@=&\@8F4@87=A<F4@;V8@:70N("!)9B!Y
M;W4@<V5E(&$@9F%T86P*("`@("`@("!E<G)O<B!I;B!&:6QE+G!H<"!L:7-T
M960@8F5L;W<@=&AI<R!T97AT+"!Y;W4@:&%V92!O;F4@;V8@=&AE"B`@("`@
M("`@8V]M8FEN871I;VYS(&]F('!R;V)L96T@9FEL97,N("!-86ME('-U<F4@
M>6]U(&AA=F4@=&AE(&QA=&5S=`H@("`@("`@(%!%05(@86YD($9I;&4@<&%C
M:V%G97,@879A:6QA8FQE("@\82!H<F5F/2)H='1P.B\O<&5A<BYP:'`N;F5T
M+R(^"B`@("`@("`@<V5E(&AT='`Z+R]P96%R+G!H<"YN970\+V$^*2X@($EF
M('EO=2!D;R!N;W0@9V5T('1H92!E<G)O<BP@>6]U(&%R90H@("`@("`@(&EN
M(&9I;F4@<VAA<&4N/"]P/@H@("`@("`@(#P_<&AP(&EN8VQU9&5?;VYC92`G
M1FEL92]#4U8N<&AP)SL*("`@("`@("!E>&ET.PH*("`@(&-A<V4@)W5N<F5G
M:7-T97(G.@H@("`@("`@('5N<V5T*"1?4T534TE/3ELG:&]R9&5?=&5S=%]C
M;W5N="==*3L*("`@("`@("`_/@H@("`@("`@(#QH=&UL/@H@("`@("`@(#QB
M;V1Y(&)G8V]L;W(](G=H:71E(B!T97AT/2)B;&%C:R(^"B`@("`@("`@/&9O
M;G0@9F%C93TB2&5L=F5T:6-A+"!!<FEA;"P@<V%N<RUS97)I9B(@<VEZ93TB
M,B(^"B`@("`@("`@5&AE('1E<W0@<V5S<VEO;B!H87,@8F5E;B!U;G)E9VES
M=&5R960N/&)R/@H@("`@("`@(#QA(&AR968](G1E<W0N<&AP(CY';R!B86-K
M/"]A/B!T;R!T:&4@=&5S="YP:'`@<&%G92X\8G(^"B`@("`@("`@/#]P:'`*
M("`@("`@("!E>&ET.PH@("`@?0I]"@IR97%U:7)E(%1%4U1?5$5-4$Q!5$53
M("X@)VAE861E<BYI;F,G.PIR97%U:7)E(%1%4U1?5$5-4$Q!5$53("X@)W9E
M<G-I;VXN:6YC)SL*"C\^"@H\:#$^2&]R9&4@07!P;&EC871I;VYS/"]H,3X*
M/'5L/@H\/W!H<`H*+RH@1V5T($AO<F1E(&UO9'5L92!V97)S:6]N(&EN9F]R
M;6%T:6]N+B`J+PHD;6]D=6QE<R`]("1H;W)D95]T97-T+3YA<'!L:6-A=&EO
M;DQI<W0H*3L*9F]R96%C:"`H)&UO9'5L97,@87,@)&%P<"`]/B`D=F%L*2![
M"B`@("`D87!P(#T@=6-F:7)S="@D87!P*3L*("`@(&5C:&\@)SQL:3XG("X@
M)&%P<"`N("<Z("<@+B`D=F%L+3YV97)S:6]N.PH@("`@:68@*&ES<V5T*"1V
M86PM/G1E<W0I*2!["B`@("`@("`@96-H;R`G("@\82!H<F5F/2(G("X@)'9A
M;"T^=&5S="`N("<B/G)U;B`G("X@)&%P<"`N("<@=&5S=',\+V$^*2<["B`@
M("!]"B`@("!E8VAO("(\+VQI/EQN(CL*?0H*/SX*/"]U;#X*"CP_<&AP"@HO
M*B!$:7-P;&%Y(%!(4"!697)S:6]N(&EN9F]R;6%T:6]N+B`J+PHD<&AP7VEN
M9F\@/2`D:&]R9&5?=&5S="T^9V5T4&AP5F5R<VEO;DEN9F]R;6%T:6]N*"D[
M"G)E<75I<F4@5$535%]414U03$%415,@+B`G<&AP7W9E<G-I;VXN:6YC)SL*
M"C\^"@H\:#$^4$A0($UO9'5L92!#87!A8FEL:71I97,\+V@Q/@H\=6P^"B`@
M("`\/W!H<"!E8VAO("1M;V1U;&5?;W5T<'5T(#\^"CPO=6P^"@H\:#$^36ES
M8V5L;&%N96]U<R!02%`@4V5T=&EN9W,\+V@Q/@H\=6P^"B`@("`\/W!H<"!E
M8VAO("1S971T:6YG7V]U='!U="`_/@H\+W5L/@H*/&@Q/D9I;&4@57!L;V%D
M<SPO:#$^"CQU;#X*("`@(#P_<&AP(&5C:&\@)&AO<F1E7W1E<W0M/G!H<%-E
M='1I;F=#:&5C:RAA<G)A>2@G9FEL95]U<&QO861S)R`]/B!A<G)A>2@G<V5T
M=&EN9R<@/3X@=')U92P@)V5R<F]R)R`]/B`G9FEL95]U<&QO861S(&UU<W0@
M8F4@96YA8FQE9"!F;W(@<V]M92!F96%T=7)E<R!L:6ME('-E;F1I;F<@96UA
M:6QS('=I=&@@24U0+B<@*2DI(#\^"CP_<&AP(&EF("@D9&ER(#T@:6YI7V=E
M="@G=7!L;V%D7W1M<%]D:7(G*2DZ(#\^"B`@("`\;&D^=7!L;V%D7W1M<%]D
M:7(Z(#QF;VYT(&-O;&]R/2(\/W!H<"!E8VAO(&ES7W=R:71A8FQE*"1D:7(I
M(#\@)V=R965N)R`Z("=R960G(#\^(CX\<W1R;VYG/CP_<&AP(&5C:&\@)&1I
M<B`_/CPO<W1R;VYG/CPO9F]N=#X\+VQI/@H\/W!H<"!E;F1I9CL@/SX*("`@
M(#QL:3YU<&QO861?;6%X7V9I;&5S:7IE.B`\/W!H<"!E8VAO(&EN:5]G970H
M)W5P;&]A9%]M87A?9FEL97-I>F4G*2`_/CPO;&D^"B`@("`\;&D^<&]S=%]M
M87A?<VEZ93H@/#]P:'`@96-H;R!I;FE?9V5T*"=P;W-T7VUA>%]S:7IE)RD@
M/SX\+VQI/@H\+W5L/@H*/&@Q/E)E<75I<F5D($AO<F1E($-O;F9I9W5R871I
M;VX@1FEL97,\+V@Q/@H\=6P^"B`@("`\/W!H<"!E8VAO("1C;VYF:6=?;W5T
M<'5T(#\^"CPO=6P^"@H\:#$^4$A0(%-E<W-I;VYS/"]H,3X*/#]P:'`@)%]3
M15-324].6R=H;W)D95]T97-T7V-O=6YT)UTK*SL@/SX*/'5L/@H@("`@/&QI
M/E-E<W-I;VX@8V]U;G1E<CH@/#]P:'`@96-H;R`D7U-%4U-)3TY;)VAO<F1E
M7W1E<W1?8V]U;G0G73L@/SX\+VQI/@H@("`@/&QI/E1O('5N<F5G:7-T97(@
M=&AE('-E<W-I;VXZ(#QA(&AR968](G1E<W0N<&AP/VUO9&4]=6YR96=I<W1E
M<B(^8VQI8VL@:&5R93PO83X\+VQI/@H\+W5L/@H*/&@Q/E!%05(\+V@Q/@H\
M=6P^"B`@("`\/W!H<"!E8VAO("1P96%R7V]U='!U="`_/@H\+W5L/@H*/#]P
M:'`*<F5Q=6ER92!415-47U1%35!,051%4R`N("=F;V]T97(N:6YC)SL*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+P``````````````````````````
M````````````````````````````````````````````````````````````
M```P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S
M,S<W-``P,3<Q-#8`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O87IU
M<B\`````````````````````````````````````````````````````````
M`````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,#`P`#$P-3$U-#,S-S8Q`#`R,#$R,P`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]A>G5R+VEN9F\N<&AP````````````````````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R-3``,3`U,34T,S,W-C$`,#(Q-38T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]A>G5R+VEN9F\N<&AP
M+'8@,2XQ(#(P,#0O,3`O,3<@,3DZ,S,Z,S,@;61J=6MI8R!%>'`@)"`_/@H@
M*@H@*B!`875T:&]R($IO;W-T($1E($-O8VL@/&IO;W-T0&1E8V]C:RYO<F<^
M"B`J+PH*)'1H96UE7VYA;64@/2!?*")!>G5R(BD["@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O87IU<B]S8W)E96XN8W-S````````````````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R-#<W`#$P-3$U-#,S-S8Q`#`R,C$R-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````O*BH*("H@075T:&]R
M.B!*;V]S="!$92!#;V-K(#QJ;V]S=$!D96-O8VLN;W)G/@H@*@H@*B`D2&]R
M9&4Z(&AO<F1E+W1H96UE<R]A>G5R+W-C<F5E;BYC<W,L=B`Q+C4N-BXU(#(P
M,#4O,3$O,34@,#8Z-#$Z,#(@<V5L<VMY($5X<"`D"B`J+PH*8F]D>2!["B`@
M("!B86-K9W)O=6YD.B`C-C1A-V,Y.PI]"F$@>PH@("`@8V]L;W(Z(",S,SD[
M"GT*82YW:61G970Z:&]V97(@>PH@("`@8V]L;W(Z(",V-C8["B`@("!B86-K
M9W)O=6YD+6-O;&]R.B`C9F9F.PI]"BYH96%D97(@>PH@("`@8V]L;W(Z("-F
M9F8["B`@("!B86-K9W)O=6YD.B`C,#8Y.PI]"BYH96%D97(@82!["B`@("!C
M;VQO<CH@(V9F9CL*?0HN<VUA;&QH96%D97(@>PH@("`@8V]L;W(Z("-F9F8[
M"B`@("!B86-K9W)O=6YD+6-O;&]R.B`C,#8Y.PI]"F$N<VUA;&QH96%D97(@
M>PH@("`@8V]L;W(Z("-F9F8["GT*+F)U='1O;B!["B`@("!B86-K9W)O=6YD
M+6-O;&]R.B`C,#8Y.PH@("`@8V]L;W(Z("-F9F8["B`@("!B;W)D97(M8F]T
M=&]M.B`Q<'@@<V]L:60@(S(R-#L*("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O
M;&ED(",R,C0["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(SDY8SL*("`@
M(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(SDY8SL*?0H*+RH@365N=2!S='EL
M97,N("HO"B-M96YU('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N
M9"UC;VQO<CH@(S`V.3L*?0HC;65N=2!A('L*("`@(&-O;&]R.B`C9F9F.PI]
M"B-M96YU(&$N8W5R<F5N="!["B`@("!B86-K9W)O=6YD.B`C-C1A-V,Y.PH@
M("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED("-E964["B`@("!B;W)D97(M
M<FEG:'0Z(#%P>"!S;VQI9"`C965E.PH@("`@8F]R9&5R+6QE9G0Z(#%P>"!S
M;VQI9"`C,#`P.PH@("`@8F]R9&5R+71O<#H@,7!X('-O;&ED(",P,#`["B`@
M("!P861D:6YG.B`R<'@["GT*(VUE;G4@83IH;W9E<B!["B`@("!B;W)D97(M
M8F]T=&]M.B`Q<'@@<V]L:60@(V5E93L*("`@(&)O<F1E<BUR:6=H=#H@,7!X
M('-O;&ED("-E964["B`@("!B;W)D97(M;&5F=#H@,7!X('-O;&ED(",P,#`[
M"B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(S`P,#L*("`@('!A9&1I;F<Z
M(#)P>#L*?0H*+RH@4VED96)A<B!S='EL97,N("HO"B-S:61E8F%R4&%N96P@
M>PH@("`@8F]R9&5R+6-O;&]R.B!T<F%N<W!A<F5N=#L*("`@(&)A8VMG<F]U
M;F0M8V]L;W(Z("-B8V0V93(["GT*"B\J(%1A8B!S='EL97,N("HO"BYT86)S
M970@;&DN86-T:79E5&%B(&$L("YT86)S970@;&DN86-T:79E5&%B(&$Z:&]V
M97(@>PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",P-CD["B`@("!B
M86-K9W)O=6YD+6-O;&]R.B`C,#8Y.PI]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]B87)B:64O````````````````
M````````````````````````````````````````````````````````````
M````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T
M,S,W-S,`,#(P,S<Q`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V)A
M<F)I92]I;F9O+G!H<```````````````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#$W-0`Q,#4Q-30S,S<W,P`P,C(P-#``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D
M93H@:&]R9&4O=&AE;65S+V)A<F)I92]I;F9O+G!H<"QV(#$N,2`R,#`T+S$P
M+S$W(#$Y.C,S.C,S(&UD:G5K:6,@17AP("0@/SX*("HO"@HD=&AE;65?;F%M
M92`](%\H(D)A<F)I92(I.PH`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]B87)B:64O<V-R965N
M+F-S<P``````````````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$W-S$`
M,3`U,34T,S,W-S,`,#(R,S<P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]B
M87)B:64O<V-R965N+F-S<RQV(#$N-2XV+C(@,C`P-2\Q,"\Q."`Q,3HS-#HQ
M,2!J86X@17AP("0*("HO"@IB;V1Y('L*("`@(&)A8VMG<F]U;F0Z("-F96(V
M8S(["GT*82!["B`@("!C;VQO<CH@(S0T.&8Y.3L*?0H*+FAE861E<B!["B`@
M("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z("-F9CAE834["GT*+G-M
M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@
M(V9F.&5A-3L*?0HN8V]N=')O;"!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C
M9F-C,F0P.PI]"BYB=71T;VX@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K
M9W)O=6YD+6-O;&]R.B`C9C0V,3=F.PH@("`@8F]R9&5R+6)O='1O;3H@=&AI
M;B!S;VQI9"`C9C0V,3=F.PH@("`@8F]R9&5R+7)I9VAT.B!T:&EN('-O;&ED
M("-F-#8Q-V8["B`@("!B;W)D97(M=&]P.B!T:&EN('-O;&ED("-F9C@Y83$[
M"B`@("!B;W)D97(M;&5F=#H@=&AI;B!S;VQI9"`C9F8X.6$Q.PI]"BYT97AT
M('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F9F4U96,["GT*"B\J($UE;G4@
M<W1Y;&5S+B`J+PHC;65N=2!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG
M<F]U;F0Z("-F9CDQ83<["GT*(VUE;G4@82YC=7)R96YT('L*("`@(&)A8VMG
M<F]U;F0Z("-F-#8Q-V8["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@
M(V%A8SL*("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED("-A86,["B`@("!B
M;W)D97(M;&5F=#H@,7!X('-O;&ED(",P,#`["B`@("!B;W)D97(M=&]P.B`Q
M<'@@<V]L:60@(S`P,#L*("`@('!A9&1I;F<Z(#)P>#L*?0H*+RH@4VED96)A
M<B!S='EL97,N("HO"B-S:61E8F%R4&%N96P@>PH@("`@8F]R9&5R+7)I9VAT
M.B`Q<'@@<V]L:60@(V9E8C9C,CL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S
M;VQI9"`C9F5B-F,R.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F.&5A-3L*
M?0HC97AP86YD0G5T=&]N('L*("`@(&UA<F=I;BUR:6=H=#H@,7!X.PI]"@``
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]B;'5E;6]O
M;B\`````````````````````````````````````````````````````````
M````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`U,34T,S,W-S0`,#(P-S8V`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V)L=65M;V]N+VEN9F\N<&AP````````````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#$W-P`Q,#4Q-30S,S<W-``P,C(T,S<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+V)L=65M;V]N+VEN9F\N<&AP
M+'8@,2XQ(#(P,#0O,3`O,3<@,3DZ,S,Z,S0@;61J=6MI8R!%>'`@)`H@*B\*
M"B1T:&5M95]N86UE(#T@7R@B0FQU92!-;V]N(BD["@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]B
M;'5E;6]O;B]S8W)E96XN8W-S````````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#8T,3(`,3`U,34T,S,W-S0`,#(R-S8R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"\J*@H@*B`D2&]R9&4Z(&AO
M<F1E+W1H96UE<R]B;'5E;6]O;B]S8W)E96XN8W-S+'8@,2XQ,RXV+C,@,C`P
M-2\Q,"\Q."`Q,3HS-#HQ,2!J86X@17AP("0*("HO"@IB;V1Y('L*("`@(&9O
M;G0M9F%M:6QY.B!,=7AI(%-A;G,L5F5R9&%N83L*("`@(&)A8VMG<F]U;F0Z
M(",P,#,X.3,["B`@("!S8W)O;&QB87(M8F%S92UC;VQO<CH@(S`P,S@Y,SL*
M("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@(S`Q-CAD8CL*?0IH=&UL('L*
M("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C,#`S.#DS.PH@("`@<V-R;VQL
M8F%R+6%R<F]W+6-O;&]R.B`C,#$V.&1B.PI]"FEN<'5T('L*("`@(&9O;G0M
M9F%M:6QY.B!,=7AI(%-A;G,L5F5R9&%N83L*?0IS96QE8W0@>PH@("`@9F]N
M="UF86UI;'DZ($QU>&D@4V%N<RQ697)D86YA.PH@("`@9F]N="UW96EG:'0Z
M(&YO<FUA;#L*?0IT9"!["B`@("!F;VYT+69A;6EL>3H@3'5X:2!386YS+%9E
M<F1A;F$["GT*=&@@>PH@("`@9F]N="UF86UI;'DZ($QU>&D@4V%N<RQ697)D
M86YA.PI]"FEM9R!["B`@("!B;W)D97(Z(&YO;F4["GT*82!["B`@("!F;VYT
M+69A;6EL>3H@3'5X:2!386YS+%9E<F1A;F$["B`@("!C;VQO<CH@(S`P,T-F
M9CL*?0IA.FAO=F5R('L*("`@(&-O;&]R.B`C,#`S.#DS.PI]"F$N=VED9V5T
M('L*("`@(&-O;&]R.B`C,#`S0V9F.PH@("`@9F]N="US:7IE.B`P+CEE;3L*
M?0IA+G=I9&=E=#IH;W9E<B!["B`@("!C;VQO<CH@(S`P,S@Y,SL*("`@(&)A
M8VMG<F]U;F0Z(",P,38X9&(["GT*+FAE861E<B!["B`@("!C;VQO<CH@(S(W
M,#`T,CL*("`@(&)A8VMG<F]U;F0Z(",P,38X9&(["B`@("!F;VYT+69A;6EL
M>3H@3'5X:2!386YS+%9E<F1A;F$["B`@("!F;VYT+7-I>F4Z(#$V<'@["GT*
M+FAE861E<B!A('L*("`@(&-O;&]R.B`C,C<P,#0R.PI]"G1D+FAE861E<B![
M"B`@("!P861D:6YG+6QE9G0Z(#-P>#L*("`@('!A9&1I;F<M<FEG:'0Z(#-P
M>#L*?0IA+FAE861E<B!["B`@("!C;VQO<CH@(S`P83AF9CL*?0HN;&EG:'0@
M>PH@("`@8V]L;W(Z("-F9F8["B`@("!F;VYT+69A;6EL>3H@3'5X:2!386YS
M+%9E<F1A;F$["GT*82YL:6=H=#IH;W9E<B!["B`@("!C;VQO<CH@(T9&0S@P
M,#L*?0HN<VUA;&QH96%D97(@>PH@("`@8V]L;W(Z(",R-S`P-#(["B`@("!B
M86-K9W)O=6YD.B`C,#$V.&1B.PH@("`@9F]N="UF86UI;'DZ($QU>&D@4V%N
M<RQ697)D86YA.PH@("`@9F]N="US:7IE.B`Q-'!X.PI]"F$N<VUA;&QH96%D
M97(@>PH@("`@8V]L;W(Z(",P,&$X9F8["GT*+G-M86QL('L*("`@(&9O;G0M
M9F%M:6QY.B!,=7AI(%-A;G,L5F5R9&%N83L*("`@(&9O;G0M<VEZ93H@,"XX
M96T["GT*+F-O;G1R;VP@>PH@("`@8V]L;W(Z(",P,#`["B`@("!B86-K9W)O
M=6YD+6-O;&]R.B`C9#%D,60Q.PI]"BYI=&5M('L*("`@(&-O;&]R.B`C,#`P
M.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V4Y93EE.3L*?0HN8G5T=&]N('L*
M("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S)B-S-D
M-3L*("`@(&)O<F1E<BUB;W1T;VTZ('1H:6X@<V]L:60@(SDY8SL*("`@(&)O
M<F1E<BUR:6=H=#H@=&AI;B!S;VQI9"`C.3EC.PH@("`@8F]R9&5R+71O<#H@
M=&AI;B!S;VQI9"`C,#`P.PH@("`@8F]R9&5R+6QE9G0Z('1H:6X@<V]L:60@
M(S`P,#L*("`@(&9O;G0M<VEZ93H@,3)P>#L*("`@(&9O;G0M9F%M:6QY.B!,
M=7AI(%-A;G,L5F5R9&%N83L*("`@("UM;WHM8F]R9&5R+7)A9&EU<SH@-7!X
M.PI]"BYB=71T;VXZ:&]V97(@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S$Q
M-C5F9CL*?0HN<V5L96-T960@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V)B
M8V)F9CL*?0HN9FEX960@>PH@("`@9F]N="US:7IE.B`Q,W!X.PH@("`@9F]N
M="UF86UI;'DZ($UO;F%C;RQ#;W5R:65R+&UO;F]S<&%C960L9FEX960["GT*
M+G-E;&5C=&5D+6]V97(@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V-C965F
M9CL*?0HN=&]O;'1I<"!["B`@("!F;VYT+7-I>F4Z(#$P<'@["B`@("!B86-K
M9W)O=6YD+6-O;&]R.B`C9F9C.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(S`P
M,#L*("`@('!A9&1I;F<Z(#)P>#L*?0HN86-C97-S2V5Y('L*("`@('1E>'0M
M9&5C;W)A=&EO;CH@=6YD97)L:6YE.PI]"F$N:&5A9&5R.FAO=F5R('L*("`@
M(&-O;&]R.B`["GT*82YC=7)R96YT5&%B.FAO=F5R('L*("`@(&-O;&]R.B`[
M"GT*+FYO=&EC92!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C9F9C.PI]"BYS
M:6=N871U<F4@>PH@("`@8V]L;W(Z(",V,#8P-C`["GT*+G-I9VYA='5R92UF
M:7AE9"!["B`@("!C;VQO<CH@(S8P-C`V,#L*("`@(&9O;G0M<VEZ93H@,3!P
M>#L*("`@(&9O;G0M9F%M:6QY.B!-;VYA8V\L0V]U<FEE<BQM;VYO<W!A8V5D
M+&9I>&5D.PI]"@HO*B!486)L92!S='EL97,N("HO"BYL:6YE9%)O=R!["B`@
M("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F9F8["B`@
M("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V1D9#L*?0HN;&EN9612;W=3
M96QE8W1E9$-O;"!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0M
M8V]L;W(Z("-F,V8S9C,["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@
M(V1D9#L*?0HO*B!!;'1E<FYA=&EN9R!S='EL97,N(&ET96TP+"!I=&5M,2!A
M<F4@9&5P<F5C871E9"X@*B\*+G)O=T5V96XL("YI=&5M,"!["B`@("!B86-K
M9W)O=6YD+6-O;&]R.B`C9C-F,V8S.PI]"BYR;W=/9&0L("YI=&5M,2!["B`@
M("!B86-K9W)O=6YD+6-O;&]R.B`C93EE.64Y.PI]"@HO*B!-96YU('-T>6QE
M<RX@*B\*(VUE;G4@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD
M+6-O;&]R.B`C,#$V.&1B.PH@("`@9F]N="UF86UI;'DZ($QU>&D@4V%N<RQ6
M97)D86YA.PI]"B-M96YU(&$@>PH@("`@8V]L;W(Z("-F9F8["GT*(VUE;G4@
M82YC=7)R96YT('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@
M(S`Q-CAB8CL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C.3EC.PH@
M("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(SDY8SL*("`@(&)O<F1E<BUT
M;W`Z(#%P>"!S;VQI9"`C,#(S,#8T.PH@("`@8F]R9&5R+6QE9G0Z(#%P>"!S
M;VQI9"`C,#(S,#8T.PH@("`@<&%D9&EN9SH@,G!X.PH@("`@+6UO>BUB;W)D
M97(M<F%D:75S.B`U<'@["GT*"B\J(%-I9&5B87(@<W1Y;&5S+B`J+PHC<VED
M96)A<E!A;F5L('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",P,38X9&(["GT*
M(W-I9&5B87)086YE;"!S<&%N+"`C<VED96)A<E!A;F5L(&$@>PH@("`@9F]N
M="UW96EG:'0Z(&)O;&0["B`@("!C;VQO<CH@(V9F9CL*?0HC<VED96)A<E!A
M;F5L(&$Z:&]V97(@>PH@("`@8V]L;W(Z("-F9F,X,#`["GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M8FQU97=H:71E+P``````````````````````````````````````````````
M`````````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S<S`#`R,3$S-0`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]B;'5E=VAI=&4O:6YF;RYP:'``````````````
M````````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R,#4`,3`U,34T,S,W-S,`,#(R
M-3<V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]B;'5E=VAI=&4O
M:6YF;RYP:'`L=B`Q+C$@,C`P-"\Q,"\Q-R`Q.3HS,SHS-"!M9&IU:VEC($5X
M<"`D"B`J+PH*)'1H96UE7VYA;64@/2!?*")";'5E(&%N9"!7:&ET92(I.PH`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O8FQU97=H:71E+W-C<F5E;BYC<W,`````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`U-3(W`#$P-3$U-#,S-S<S`#`R,S$S-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````O*BH*("H@)$AO
M<F1E.B!H;W)D92]T:&5M97,O8FQU97=H:71E+W-C<F5E;BYC<W,L=B`Q+C$X
M+C8N.2`R,#`U+S$Q+S`R(#$Y.C,R.C,X(&IA;B!%>'`@)`H@*B\*"F)O9'D@
M>PH@("`@9F]N="UF86UI;'DZ(%9E<F1A;F$L($=E;F5V82P@07)I86PL($AE
M;'9E=&EC82P@<V%N<RUS97)I9CL*("`@(&)A8VMG<F]U;F0Z("-F9F8["GT*
M82!["B`@("!C;VQO<CH@(S,S.3L*?0HN:&5A9&5R8F]X('L*("`@(&)O<F1E
M<BUC;VQO<CH@(S8V83L*?0HN<V5L96-T960@>PH@("`@8F%C:V=R;W5N9#H@
M(T,V1#-&1CL*?0HN:&5A9&5R('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C
M:V=R;W5N9#H@(S8V83L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C
M,#`P.PI]"BYH96%D97(@82!["B`@("!C;VQO<CH@(V9F9CL*?0HN:&5A9&5R
M(&$Z:&]V97(L(&$N:&5A9&5R.FAO=F5R('L*("`@(&-O;&]R.B!Y96QL;W<[
M"B`@("!T97AT+61E8V]R871I;VXZ(&YO;F4["GT*82YH96%D97(@>PH@("`@
M8F]R9&5R+6)O='1O;3H@,#L*("`@(&)A8VMG<F]U;F0Z('1R86YS<&%R96YT
M.PI]"F$N9FEX960@>PH@("`@8V]L;W(Z(",S,SD["GT*+FQI9VAT('L*("`@
M(&-O;&]R.B`C,S,S.PI]"BYS;6%L;&AE861E<B!["B`@("!C;VQO<CH@(V9F
M9CL*("`@(&)A8VMG<F]U;F0Z(",V-F$["B`@("!F;VYT+69A;6EL>3H@5F5R
M9&%N82Q(96QV971I8V$L<V%N<RUS97)I9CL*?0IA+G-M86QL:&5A9&5R.FAO
M=F5R('L*("`@(&-O;&]R.B`C8V-E.PH@("`@=&5X="UD96-O<F%T:6]N.B!N
M;VYE.PI]"BYC;VYT<F]L('L*("`@(&)A8VMG<F]U;F0Z("-D9&0["GT*+G=I
M9&=E="!["B`@("!C;VQO<CH@(S(R-#L*?0H*+RH@1F]R;2!S='EL97,N("HO
M"FEN<'5T+"!S96QE8W0L('1E>'1A<F5A('L*("`@(&9O;G0M9F%M:6QY.B!'
M96YE=F$L($%R:6%L+"!(96QV971I8V$L('-A;G,M<V5R:68["B`@("!F;VYT
M+7-I>F4Z(#$R<'@["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0Z
M("-F,V8S9CD["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C-C8Y.PI]"FEN<'5T
M.F9O8W5S+"!T97AT87)E83IF;V-U<R!["B`@("!B86-K9W)O=6YD.B`C9F9F
M.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(SDY9CL*?0HN8G5T=&]N+"`N8G5T
M=&]N.F9O8W5S('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@
M(S,S.3L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,S,S.PH@("`@
M8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)O<F1E<BUL969T
M.B`Q<'@@<V]L:60@(T,T0S1".#L*("`@(&)O<F1E<BUT;W`Z(#%P>"!S;VQI
M9"`C0S1#-$(X.PH@("`@+6UO>BUB;W)D97(M<F%D:75S.B`U<'@["GT*+F)U
M='1O;CIH;W9E<B!["B`@("!B86-K9W)O=6YD.B`C-C9A.PI]"@HO*B!!;'1E
M<FYA=&EN9R!S='EL97,N(&ET96TP+"!I=&5M,2!A<F4@9&5P<F5C871E9"X@
M*B\*+G)O=T5V96XL("YI=&5M,"!["B`@("!B86-K9W)O=6YD.B`C965E.PI]
M"BYR;W=/9&0L("YI=&5M,2!["B`@("!B86-K9W)O=6YD.B`C9F9F.PI]"@HO
M*B!687)I;W5S('!O<'5P(&%N9"!S=&%T=7,@;&%Y97)S+B`J+PHN=&]O;'1I
M<"P@9&EV+FYI8V5T:71L92!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG
M<F]U;F0Z(",V-F$["B`@("!B;W)D97(Z(#)P>"!D;W5B;&4@(V9F9CL*?0H*
M+RH@365N=2!S='EL97,N("HO"B-M96YU('L*("`@(&-O;&]R.B`C9F9F.PH@
M("`@8F%C:V=R;W5N9#H@(S8V83L*("`@(&)O<F1E<BUB;W1T;VTZ(#)P>"!S
M;VQI9"`C,#`P.PI]"B-M96YU(&$@>PH@("`@8V]L;W(Z("-F9F8["GT*(VUE
M;G4@82YC=7)R96YT('L*("`@(&)A8VMG<F]U;F0Z(",S,SD["B`@("!B;W)D
M97(M8F]T=&]M.B`Q<'@@<V]L:60@(V%A8SL*("`@(&)O<F1E<BUR:6=H=#H@
M,7!X('-O;&ED("-A86,["B`@("!B;W)D97(M;&5F=#H@,7!X('-O;&ED(",P
M,#`["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(S`P,#L*("`@('!A9&1I
M;F<Z(#)P>#L*?0H*+RH@4VED96)A<B!S='EL97,N("HO"F)O9'DN<VED96)A
M<B!["B`@("!B86-K9W)O=6YD.B`C9F9F.PI]"B-S:61E8F%R4&%N96P@>PH@
M("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(S`P-CL*("`@(&)O<F1E<BUB
M;W1T;VTZ(#%P>"!S;VQI9"`C,#`V.PH@("`@8F%C:V=R;W5N9#H@(V4Y93EF
M9CL*?0HC<VED96)A<E!A;F5L('-P86XN=&]G9VQE+"`C<VED96)A<E!A;F5L
M(&$@>PH@("`@<&%D9&EN9RUL969T.B`Q<'@["B`@("!P861D:6YG+6)O='1O
M;3H@,G!X.PI]"B-S:61E8F%R4&%N96P@<W!A;BYT;V=G;&4@>PH@("`@8F]R
M9&5R.B`Q<'@@;F]N92!T<F%N<W!A<F5N=#L*?0HC<VED96)A<E!A;F5L(&$@
M>PH@("`@8V]L;W(Z(",P,#8["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C93EE
M.69F.PI]"B-S:61E8F%R4&%N96P@83IH;W9E<B!["B`@("!C;VQO<CH@(S`P
M-CL*("`@(&)A8VMG<F]U;F0Z("-C8V,["B`@("!B;W)D97(Z(#%P>"!S;VQI
M9"`C,#`P.PH@("`@=&5X="UD96-O<F%T:6]N.B!N;VYE.PI]"B-E>'!A;F1"
M=71T;VX@>PH@("`@;6%R9VEN+7)I9VAT.B`Q<'@["GT*"B\J(%1A8B!S='EL
M97,N("HO"BYT86)S970@>PH@("`@8F%C:V=R;W5N9#H@;F]N93L*("`@(&)O
M<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C-C9A.PI]"BYT86)S970@;&D@82![
M"B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C-C9A.PH@("`@8F]R9&5R+6)O='1O
M;2UC;VQO<CH@(V4Y93EE.3L*?0HN=&%B<V5T(&QI+F%C=&EV951A8B!A('L*
M("`@(&)A8VMG<F]U;F0Z(",V-F$["B`@("!C;VQO<CH@(V9F9CL*("`@(&)O
M<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C-C9A.PI]"BYT86)S970@;&DN86-T
M:79E5&%B(&$Z:&]V97(@>PH@("`@8F%C:V=R;W5N9#H@(S8V83L*("`@(&-O
M;&]R.B`C9F9F.PI]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]B<F]W;B\`````
M````````````````````````````````````````````````````````````
M````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`U,34T,S,W-C$`,#(P,C<Q`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V)R;W=N+VEN9F\N<&AP````````````````````````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#$W,``Q,#4Q-30S,S<V,0`P,C$W,S,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+V)R;W=N+VEN9F\N<&AP+'8@,2XQ
M(#(P,#0O,3`O,3<@,3DZ,S,Z,S0@;61J=6MI8R!%>'`@)`H@*B\*"B1T:&5M
M95]N86UE(#T@7R@B0G)O=VXB*3L*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]B<F]W
M;B]S8W)E96XN8W-S````````````````````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(U,C0`,3`U,34T,S,W-C$`,#(R,C8U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"\J*@H@*B`D2&]R9&4Z(&AO<F1E
M+W1H96UE<R]B<F]W;B]S8W)E96XN8W-S+'8@,2XV+C8N,B`R,#`V+S`R+S(R
M(#(R.C4U.C`W('-L=7-A<GH@17AP("0*("HO"@IB;V1Y('L*("`@(&)A8VMG
M<F]U;F0Z(",U,#4P-3`["B`@("!S8W)O;&QB87(M8F%S92UC;VQO<CH@(S4P
M-3`U,#L*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@(V-F8V9B8CL*?0IH
M=&UL('L*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C-3`U,#4P.PH@("`@
M<V-R;VQL8F%R+6%R<F]W+6-O;&]R.B`C8V9C9F)B.PI]"F$@>PH@("`@8V]L
M;W(Z(",U,#4P-3`["GT*83IH;W9E<B!["B`@("!C;VQO<CH@(S4P-3`U,#L*
M?0IA+G=I9&=E=#IH;W9E<B!["B`@("!C;VQO<CH@(S4P-3`U,#L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z("-E8F5B9#<["GT*+FAE861E<B!["B`@("!C;VQO
M<CH@(S4P-3`U,#L*("`@(&)A8VMG<F]U;F0Z("-B8F$["GT*+G-M86QL:&5A
M9&5R('L*("`@(&-O;&]R.B`C-3`U,#4P.PH@("`@8F%C:V=R;W5N9#H@(V)B
M83L*?0HN8V]N=')O;"!["B`@("!B86-K9W)O=6YD.B`C9&5D96)B.PI]"BYI
M=&5M('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-E8F5B9#<["GT*+F)U='1O
M;B!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C-3`U,#4P.PH@("`@8F]R9&5R
M+6)O='1O;3H@=&AI;B!S;VQI9"`C,C(T.PH@("`@8F]R9&5R+7)I9VAT.B!T
M:&EN('-O;&ED(",R,C0["B`@("!B;W)D97(M=&]P.B!T:&EN('-O;&ED("-C
M9F-F8F(["B`@("!B;W)D97(M;&5F=#H@=&AI;B!S;VQI9"`C9&5D96)B.PH@
M("`@8V]L;W(Z("-F9F8["GT*+G-E;&5C=&5D('L*("`@(&)A8VMG<F]U;F0M
M8V]L;W(Z("-C9&-D8V0["GT*+FET96TQ('L*("`@(&)A8VMG<F]U;F0M8V]L
M;W(Z("-E-F4V9&4["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@
M("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0Z("-B8F$["B`@("!B;W)D
M97(M8F]T=&]M.B`Q<'@@<V]L:60@(S`P,#L*?0HC;65N=2!A+F-U<G)E;G0@
M>PH@("`@8F%C:V=R;W5N9#H@(V)F8F9A83L*("`@(&)O<F1E<BUB;W1T;VTZ
M(#%P>"!S;VQI9"`C965E.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@
M(V5E93L*("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)O
M<F1E<BUT;W`Z(#%P>"!S;VQI9"`C,#`P.PH@("`@<&%D9&EN9SH@,G!X.PI]
M"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*(W-I9&5B87)086YE;"!["B`@("!B
M;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C,#`P.PH@("`@8F]R9&5R+6)O='1O
M;3H@,7!X('-O;&ED(",P,#`["B`@("!B86-K9W)O=6YD.B`C8F)A.PI]"B-E
M>'!A;F1"=71T;VX@>PH@("`@;6%R9VEN+7)I9VAT.B`Q<'@["GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V)U<FYT;W)A;F=E+P``````````````````
M```````````````````````````````````````````````````````P,#`P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<W-``P
M,C$T-S0`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O8G5R;G1O<F%N
M9V4O:6YF;RYP:'``````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M-#$P`#$P-3$U-#,S-S<T`#`R,S$S,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@5&AE;64@8GDZ($5R
M:6,@2F]N(%)O<W1E='1E<B`\97)I8RYR;W-T971T97)`<&AY<VEC<RYU=&5X
M87,N961U/@H@*B!0;&5A<V4@8V]N=&%C="!T:&4@=&AE;64G<R!A=71H;W(@
M9F]R(&%N>2!M:7-S:6YG('-T>6QE+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+W1H
M96UE<R]B=7)N=&]R86YG92]I;F9O+G!H<"QV(#$N,2`R,#`T+S$P+S$W(#$Y
M.C,S.C,U(&UD:G5K:6,@17AP("0*("HO"@HD=&AE;65?;F%M92`](%\H(D)U
M<FYT($]R86YG92(I.PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V)U<FYT;W)A;F=E+W-C<F5E;BYC
M<W,`````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S0Q-P`Q,#4Q-30S
M,S<W-``P,C,T-S(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+RHJ"B`J(%1H96UE(&)Y.B!%<FEC($IO;B!2;W-T971T97(@
M/&5R:6,N<F]S=&5T=&5R0'!H>7-I8W,N=71E>&%S+F5D=3X*("H@4&QE87-E
M(&-O;G1A8W0@=&AE('1H96UE)W,@875T:&]R(&9O<B!A;GD@;6ES<VEN9R!S
M='EL92X*("H*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O8G5R;G1O<F%N9V4O
M<V-R965N+F-S<RQV(#$N-BXV+C,@,C`P-2\Q,"\Q."`Q,3HS-#HQ,B!J86X@
M17AP("0*("HO"@IB;V1Y('L*("`@(&)A8VMG<F]U;F0Z("-F,&(P-C`["GT*
M82!["B`@("!C;VQO<CH@(V,V,#L*?0IA.FAO=F5R('L*("`@(&-O;&]R.B`C
M8S8P.PI]"BYH96%D97(@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O
M=6YD.B`C8S8P.PI]"BYH96%D97(@82!["B`@("!C;VQO<CH@(V9F9CL*?0H*
M+G-M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N
M9#H@(V,V,#L*?0HN8V]N=')O;"!["B`@("!B86-K9W)O=6YD.B`C9CEC93AA
M.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED("-C-C`["GT*+F)U='1O
M;B!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z("-C-C`["B`@
M("!B;W)D97(M8F]T=&]M+6-O;&]R.B`C,S`P.PH@("`@8F]R9&5R+7)I9VAT
M+6-O;&]R.B`C,S`P.PH@("`@8F]R9&5R+71O<"UC;VQO<CH@(V8P8C`V,#L*
M("`@(&)O<F1E<BUL969T+6-O;&]R.B`C9C!B,#8P.PI]"BYS96QE8W1E9"![
M"B`@("!B86-K9W)O=6YD.B`C9&8Y9C-F.PI]"F$N<VUA;&QH96%D97(Z:&]V
M97(@>PH@("`@8V]L;W(Z("-F9F8["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC
M;65N=2!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z("-C-C`[
M"GT*(VUE;G4@83IH;W9E<B!["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L
M:60@(V8P8C`V,#L*("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED("-F,&(P
M-C`["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(S,P,#L*("`@(&)O<F1E
M<BUL969T.B`Q<'@@<V]L:60@(S,P,#L*("`@('!A9&1I;F<Z(#)P>#L*?0HC
M;65N=2!A('L*("`@(&-O;&]R.B`C9F9F.PI]"B-M96YU(&$N8W5R<F5N="![
M"B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z("-D9CEF,V8["B`@
M("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V8P8C`V,#L*("`@(&)O<F1E
M<BUR:6=H=#H@,7!X('-O;&ED("-F,&(P-C`["B`@("!B;W)D97(M=&]P.B`Q
M<'@@<V]L:60@(S,P,#L*("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(S,P
M,#L*("`@('!A9&1I;F<Z(#)P>#L*?0H*+RH@4VED96)A<B!S='EL97,N("HO
M"F)O9'DN<VED96)A<B!["B`@("!B86-K9W)O=6YD.B`C9C!B,#8P.PI]"B-S
M:61E8F%R4&%N96P@>PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(V8P
M8C`V,#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C9C!B,#8P.PH@
M("`@8F%C:V=R;W5N9#H@(V8P8C`V,#L*?0HC<VED96)A<E!A;F5L(&$@>PH@
M("`@8F]R9&5R.B`Q<'@@<V]L:60@(V8P8C`V,#L*("`@('!A9&1I;F<M;&5F
M=#H@,7!X.PH@("`@<&%D9&EN9RUB;W1T;VTZ(#)P>#L*?0HC<VED96)A<E!A
M;F5L(&$Z:&]V97(@>PH@("`@8V]L;W(Z(",Y,#`["B`@("!B86-K9W)O=6YD
M.B!Y96QL;W<["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C,#`P.PH@("`@=&5X
M="UD96-O<F%T:6]N.B!N;VYE.PI]"@HO*B!486(@<W1Y;&5S+B`J+PHN=&%B
M<V5T(&QI+F%C=&EV951A8B!A+"`N=&%B<V5T(&QI+F%C=&EV951A8B!A.FAO
M=F5R('L*("`@(&)A8VMG<F]U;F0Z("-C-C`["B`@("!B;W)D97(M8F]T=&]M
M+6-O;&]R.B`C8S8P.PI]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]C86UO=69L86=E+P``````````````````
M````````````````````````````````````````````````````````,#`P
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-S,`
M,#(Q,C4P`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V-A;6]U9FQA
M9V4O9W)A<&AI8W,O````````````````````````````````````````````
M```````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#4Q-30S,S<W,P`P,C,P-3``(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O8V%M;W5F;&%G92]G<F%P:&EC<R]M96YU+G!N9P``````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#$P,#4P`#$P-3$U-#,S-S<S`#`R-#4Q-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12```#'@```#0$`P```/;+\\`````84$Q411\N&Q)$(BD](F=L
M0`HI$O___________V^.B_@````)<$A9<P```$@```!(`$;):SX```^V241!
M5'C:I9QM@K*\#H:+N@`ZNH`170`*"T#I_M=TZ$>2.VEQ?-[37R.6-LF5CU+J
MN!"FU$9_"<%OS3EWG*9A&&Y3:<^AM'N@]HX?MY[49;MONQ!O[[>K)^X7UH?+
M+0X?PFOK<0GP]30]?+HM?4QCY;Z]HW;2_;<.AVVN\\1MW#H=2,9-[#QB:J77
MB&-LT\Q9@ZQ/GD4&H#:-!QF3#+'U[,S4(.12=$TSSS2;-2.TJ\^6XSD==7>D
M0IZQR6-(H^=YAC1[[O#PPB,":?(H%[Q7EDDHB4>R]M1M'S=PNSRR[?S4!'(C
M<5++7\^A;F_VKV+#&L<V;!F4YQI^HW4\`&$I'0#IRO3B0CL\KN2=PH,5(AVB
M8_KSN\DC7Q*M%I)HD^"G\/!%M-**GW>^813!D<5:)[!FDT=(LEH>60/YH'#8
M"6=1__XA/":>:;/:=E>2[9!Y-($$"3;BD;3BGG4$#I`L\H6HA7-JD,3#;SQ:
M8"M_6UF>;;K?+@^`%LB^M\-#$HM$]@/D`$5APJ08VL2V3SBV*V_,OZX='E'-
MZ.P_$4?*/9*>./`4$LQ8HE>_L,>T<(!5B$=O>*2$I7B\/_"@<,\\\B`G\WW\
MQK=XO#@,3A+9>SS6/"_K\H''0TJ'SE4YZ0S`8VF'QRV1W+[<PK[4@I5-[[V9
M',/8\/`<MC6/JZJET<I;^$V^P6,S0K&]5B#)J1-(4#R<J==)IV0^?34W,OF)
M+)XGNQ*/`7BLV;A$X\?XB`5"!HMZWCFVM#+[/&YYLJ48)4<9F][;`!DMCPZ`
M,+16>*!5-B!WYQX5C][PF'4<CR:#<,(J/(S-"X]K@\?+Y".PUO6'\BE]KU+-
M52U*6D1(]D00>"B#W'?2%2>ZF@=7VBI`3I`OD$?Q#%FL`0YMK,*C_X-'T**Z
M3SQ.P;:E^%Z#QV+*M;$6`9'88=?0B\2\S)C;/-Z*Q_,O'C<@23S*TG4ETZ.9
M_RN/*Y1-X+'L\7#O6YO':'DLP*.1DS[P&#6/M;4BI-FF3SR&8K_U#QX6^)V%
MIRNR'$H(EIK'Z#AH]GFXF@>D1.B@[/$>0N3A6_7#'<13/O.`^+C_7SRF#SQH
ME2+.]?,EC^$#CV!YW&4,X#$ACXDL=?Z2!W<Y"(W//'HU1&]Y*"4B#YV4ON-Q
MK==7JUJ7!/\P3D_2QPZT2LDZ)8.8A#6W<)3@;O.X@_1YW%MH\3AK'OSD?-8\
M\`$$$M:9NYRBP:F#SUZEO70(L7Z4B-#AX9Y3B\>MXL'I:M,)(<&?.</L\2@]
M\^0M'BZ.@4DXRVH"9&9[J6PR`X]5J:*]*5XY3QACQ.-,<-@>=N54>&1HEL<$
M/#"`AFI])3QZ&,'5/)Z:APZ/L<%CP673M,>#'J\`AS;RD%9LFR*.>;A\K;-=
MMP#)AGQ8.R@>HLD=12TN.[5XG/F#&.1A`R3=?YS%QYC'&;K@C#]#:X&UE+#H
M`4>^XSCM\"@X6&SA$0:E(V%+3GWUU0/(2C?'#R_?!O)+@Y-2Y5(52S=-@PWQ
M;/,@',`C;A-6/-R9/ZALF+.\X2%_2K9!,[5X**L,NO(PK7T>OC]I5Y$-'$Q6
MR8(<!L^<\:OPF*00B@@_31Y'FNLP0+TRA0U7F<0#C2^:@#!$(]V`9D^*DLEG
MK?.4=S6,#=`]2999EF45CZL%`CP4IP4WYPP/%1PB`22QE^4QY8TM^BCAD6\^
M07A8OW>*A\1BO/360*XZ[WH1_38;'JCO4NZIPN""/":[6!C!2U+<MGE<`CQ'
M`H^.>8";+@?B85SW`X]+Q:-Z0.R+!=D*E$A>T0>?16_P+`R/*$N#AP[%)H_!
M+-Q%\%M9++ER0?ME[D]1P+H]-`_;#(]#%/6(+B,))XVHLP_R\&+UJ2S>+E_S
MN(2:QVAV8/MB0>11,GN,E9N%J7F$$-Z6QQ$CD7F$P0)1MA"Y;U0,RK+6)`3)
M;C/DXH>O-=WGD60]HLMT8NL&#P\\2)(\4B,\-LF/./?A,X_II&Y^$8\)>20@
MYV2C2J_32^'``$&M-8Y//,J.'Y>6;.F%7V?HG/#RZL65XF&JAG$D]MIL(:="
M6$R]%G=D?^T\\J#KS,.&A^&!.R^8^[GIFZE\&!X3IY#:S^R*@@/D%Y2&'?@=
M'E?X=JO/3^#ALE\B#PR0\RZ/72`-'C$040*R]%H>68!_@\?Z-0]9R5R;,N[Q
MF+_D`>NB2\VCB#)Z>&68UPN6ARR]3ELL'`?AD1Z:7%F2^9K'5/,P>:3!8ZAX
M#+=1NP2-\%`S\C*R2'(R/"R.7%G^*X\L3-QN:?$8!EU`1AT>1>0&CZB2"I!I
M?G_'XU8>CO\K#Y,-6CQJ"5)K\WBU>4S[/-PNC\N?/);"XT@\5L81TT*#AWIL
M""I`@$?22?/8CX^H`F?9*?-8]GF</_)H!T@K7\GC*X6PXB%';#0/-&HK7YGE
M%6P5^V:1:X2'DP7ORM;<]'YJ'L\='A0A6#_B(%@^ON5QF_*>V[<\V'_X^U:`
MC"T>!L>1>7C5>JIDJ/2ZRV-QA@<'R-6WGC^`1]Q-ZU@>X%$FMCR&FS,[!!<0
MXZ"7NV`'1V?$VCQ2<J)R7FZ*CM(U>;QD\_&_\A@;R4I6_.M#J9CSA^6Q''=X
M+,[RH!76E=30`LX@=C2O`[.4:**)G\5`S./7\O!*#%'-9HIXJ1C\_O[$XU;N
MB#P\:X%:.\V#'F`O#1YVVPX-5-%@RRPUCIJ'S_6U?AZL#:"?.O=XK,56DN4I
M'7#[&2R/P:2K&,VG"D<5KRD\BL'ONMR4B7E[2Z3OO.(AX(]:DS7S`)-`)FCS
MF`R,H[*,4K%O\+CPCA$-=-+A(1,%,U^Z>8W&L#RHG[@!YP.D@3R>?$0HWX$"
MJ];9='&<B,<-]J60QT'"8R17:O%84%G1Y'%I\)CAI=0''H9OD#>*LB094!0O
M3NN"`:)'Q'T_ULHGC[S)K-$_5\/#Z^<?+_N$,F"T&?'H2<%1*58<^SS5[0ET
MD4<73;G(9%DI%L%(A^4)[*]2^`K?MWF,R,-X:C%;4H&]C=9')4!>PB.HY+(H
M'G.`8Q7`(R4(DK(\!]SV>`0='H.,%WGD,XU93NMK,F"+!T;;DWAT95Y97,V0
MPNMRKAY]PTY#'LH_Y=;]\%B*V70_7B"9YCA50W@H'D&-TXFGWXN8H/O8Y/%2
MX9$XCC9H76.?*EX8*=1W>-STARY;^@WL,4;K<JX6;W_P@')?\8``0=LM;+:S
MZG<:=H`(#RRC1R4@SM>!HQ?9WHI'ASS>=PD0YA$8+\C4\K7X]\/_S>,,P?+0
M&_:<PRE$C;.HG8C''H_`%MY6#PF.MSPFRT/A<,[K?F\143/YAH<X=#0WXRBR
MS:"\X?$N&Y`OY!'O>B"/_"8)5!M!B-*AP>,I!,Y83&;`<6.?]RI?0[KZ!Q[Y
M2&=(7M(W>9PX_V4WD*CI5#_%0\DE/)RD*[->"\`?>>0`D:&3)8%U&/A=*435
M/>X?*!Z;.#U:&G@\"[$//#HO[SJ2U4#/;:RBPH_Q1*KFF*ZZ/WDDI=>)UTE6
MZ,#/=:'P&.C!1/4[#::U>)R$!Z;`?1[W],U3\<#8>V=F)4+P+J]Y7!O'DQ4/
M_#64X5'>=3PY'L#U;A.O4]XF,12QA$<L/E_S*`H<K="Q+_!8Z3P,=,T\S-[T
MM<4#_OS$`PI!$NU'M,?S'14/ZK?Q6-4JO'+_!H_;'@]>?A67F,W++."A\G01
MJQ<>P^3W<"S`XRX5_:CDH<FX<SS\<R`Y:FY_YJN-FEDB!*D?N.#]D4(05]2?
M>=RY@@B/('LJAX:U7<VC!23;/-6KOG44^Q=Y!(WC0FD4>-QV>3CR^7?YR5ZK
M;7-=()CRM4,11-"-5*I#"X?B89<(.SPN`1QE&T'2E=G'!!XA%L"<Z^Y0ITJ,
M?,&C`21=+LN'!H]?IWBH,Q.%AQ<><:*KIE!5F1#R$;.UR6-T\GI6\Q@PDD:6
MB1/K]4L>F*[@`02S:EP9'8K^;1XE8?4EMF@)+)/ZH?4*M^)1_\H#7>NXN]G+
MTKYLNE(+Z2?X#O`C694]=GAT%'6@R:$2?820K<.CR2/?R#MJJ^9Q,3BH"OQZ
M@\,/P(.*3^!3C#3>V9KZL</#1$C>=&8>3\NC-SPP0"Y,AWA(+M6]+]F7HBQX
M$K_%HW[#JW[URSQXF'<='I''"EGBR"/)X[53/.3G?"E9257NO&_RN"L>LSE5
MVOGJE3KMN5D>)D#4%FE?\;AZRP,"1."H8!OD*#R@2SZGSI$W><`;Q=?1\`#1
M\7341QY3WC750;5EEU?VH5'S0,,=\JB7K,3#\!@@&B*/-X2,+TM5HY?G_9-A
MET>>]LH\IHJ'+XN4.D#ZBH?0O-?%1M8['Q,6\,AQ-\K#@00("O2FQ"J9'GD\
M^:[R_PQB_U"$'I50$!V\EY_D((-&6Z//4?&9BQ#W>,G3HS6FH@<9X6A^FF5[
M_7SDX<L>):C/5CY5//2]NM;4/-H!`J],TLA1$>(AOH2'!XE'SG:6!]@%PXF2
MK!)J4N>A!OHI==$O:]"ARQ$/?EXK/W;)QD!+DX73"WAM)],+8[TJ()Z`U!FK
M#Y9'G>P^\V`7G@G.K>*1&O-@#<$_7BG3_^8BT5D>3]&X*C=@B"(/RMG]T)OU
MUYG2G=25`7\W*3SN:0_\_)%',#RDV^,K'J6\V0`Y53P&VQ!'7_.@`)D)3GH]
M]V\\-N?(+QR<2@O,0VY3U2:K?#8\$,?F]5>O>$R&Q[#+@V:NTM4V?/Q]RS_P
MT$8M#K(D,72`G(+E8</#/!(T>*R"HVP:?<ECY#X3\3CF+_Z)AP`1O8"'_YK'
M67B\6CP>_BL>WO)PQJC"XS#H`.E#Q:/"@3S@02`8(/+W,\KV!8]'SZZQJ9I?
MD!XQ+WS+0Y_!4&&\\:"?7BD>L(D)/.A488J/,WDG6[J7WY4>9]P;+-+E_^LR
MD;)^CT<6*)[M/N!CQ=;QA*7D3QZ]:_-(5I/DE>/C8@I5Q>.ANS@G^4IXA!T>
M;R7:$0)D,7[SP_5<\6!K0OWPBH<M7/@"I3]6)W0CCP#"X[[H47<5<VH>KL5C
M-U\QC:SP"8$H'E/>+:IXZ$,#'H[RY.&%Q]CD\2LY*;Q^4#/>H9S3OUE1CI.[
M7>A1I?"X-'G0U7MPI3?XS^B`1VVG&Q^P*-X'6>70]N\L'!NQ)R=7/"*2.YQS
M+EJ+@C1:4$!FK"7EU>0.CQL)W>+A#(\5>,0OQ2H_$+@D^>BJ)BJ<*>ML(TCV
MEST93[M:VT7Z1VOB0",JW]BSG0P/:/0+\ME8)*DL`>+LJ3!(PRK#Q*^R.-G]
M&D#6FH<YPB$\N#(V><3<XX0'_V,=.<'450KW^SC8-9E'="V/__8+>/P(#Y4L
M>.@RX;GB\3OQ+]UJ'L4+V4G5%_A+[#8/64GDN<ZD:Z#_TM"($$E7Y.$7R^.'
M1BN?J<,+>6Q`Z$W>_P`"<]9\RZW/[0````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]C
M86UO=69L86=E+VEN9F\N<&AP````````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`R,#(`,3`U,34T,S,W-S,`,#(R-S`V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R
M9&4Z(&AO<F1E+W1H96UE<R]C86UO=69L86=E+VEN9F\N<&AP+'8@,2XQ(#(P
M,#0O,3`O,3<@,3DZ,S,Z,S4@;61J=6MI8R!%>'`@)`H@*B\*"B1T:&5M95]N
M86UE(#T@7R@B0V%M;W5F;&%G92(I.PH`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O8V%M;W5F;&%G92]S
M8W)E96XN8W-S````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,C`T
M`#$P-3$U-#,S-S<S`#`R,S(S-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````O*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O
M8V%M;W5F;&%G92]S8W)E96XN8W-S+'8@,2XW+C8N,R`R,#`U+S$P+S$X(#$Q
M.C,T.C$S(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@8F%C:V=R;W5N9#H@
M(S%F,F4Q8CL*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C-60U9#8P.PH@
M("`@<V-R;VQL8F%R+6%R<F]W+6-O;&]R.B`C-60U9#8P.PI]"FAT;6P@>PH@
M("`@<V-R;VQL8F%R+6)A<V4M8V]L;W(Z(",U9#5D-C`["B`@("!S8W)O;&QB
M87(M87)R;W<M8V]L;W(Z(",U9#5D-C`["GT*82!["B`@("!C;VQO<CH@(S,S
M-CL*?0IA+G=I9&=E="!["B`@("!C;VQO<CH@(S!A,CDQ,CL*?0IA+G=I9&=E
M=#IH;W9E<B!["B`@("!B86-K9W)O=6YD.B`C.3DV.PI]"BYH96%D97(@>PH@
M("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD.B`C,S8S.PI]"BYH96%D
M97(@83IH;W9E<B!["B`@("!C;VQO<CH@(SDY-CL*?0HN:&5A9&5R(&$@>PH@
M("`@8V]L;W(Z(",Y.38["GT*82YH96%D97(Z:&]V97(@>PH@("`@8V]L;W(Z
M(",Y.38["GT*+G-M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C9F9F.PH@("`@
M8F%C:V=R;W5N9#H@(S,V,SL*?0HN8V]N=')O;"!["B`@("!B86-K9W)O=6YD
M.B`C8V-A.PI]"F$N8V]N=')O;"!["B`@("!C;VQO<CH@(S!F,#L*?0HN:71E
M;2!["B`@("!B86-K9W)O=6YD.B`C8V-A.PI]"BYB=71T;VX@>PH@("`@9F]N
M="UW96EG:'0Z(&)O;&0["GT*+G-E;&5C=&5D('L*("`@(&)A8VMG<F]U;F0Z
M(",Y.38["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@("!C;VQO
M<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z(",Q9C)E,6(@=7)L*")G<F%P:&EC
M<R]M96YU+G!N9R(I.PI]"B-M96YU(&$@>PH@("`@8V]L;W(Z("-F9F8["GT*
M(VUE;G4@82YC=7)R96YT('L*("`@(&)A8VMG<F]U;F0Z(",S-C,["GT*"B\J
M(%-I9&5B87(@<W1Y;&5S+B`J+PHC<VED96)A<E!A;F5L('L*("`@(&)A8VMG
M<F]U;F0Z(",S-C,["GT*(W-I9&5B87)086YE;"!S<&%N+"`C<VED96)A<E!A
M;F5L(&$@>PH@("`@8V]L;W(Z("-F9F8["GT*(W-I9&5B87)086YE;"!A.FAO
M=F5R('L*("`@(&-O;&]R.B`C9F9F.PI]"@HO*B!0<F5F97)E;F-E<R!O=F5R
M=FEE=RX@*B\*+G!R969S3W9E<G9I97<@:#(@>PH@("`@8V]L;W(Z("-F9F8[
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]C;W)N9FQO=V5R+P``````````````````````````````
M````````````````````````````````````````````,#`P,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-C$`,#(Q,S(R`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V-O<FYF;&]W97(O9W)A<&AI
M8W,O````````````````````````````````````````````````````````
M```````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q
M-30S,S<V,0`P,C,Q,C(`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M8V]R;F9L;W=E<B]G<F%P:&EC<R]T86)?8F]T=&]M+F=I9@``````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,C`Q`#$P-3$U-#,S-S8Q`#`R-3<S-``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!'248X.6$4``$`A"``W>/5
MV^'3_O[^\O3NYNG@VN#2_/S\]??R^?GWZNWDX.36Y>C>[O'J[?#I[_+KXN7:
M^/CV]_?U\_7PZ>SC^OKX^_O[Z^[G=V95X^;;Y.?=_?W][._HX>39\?/NX./8
MZ.OB+``````4``$```4&X"6.9%F&`#L`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V-O<FYF;&]W97(O
M9W)A<&AI8W,O=&%B7VQE9G0N9VEF````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,P
M,P`Q,#4Q-30S,S<V,0`P,C4S-C4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````1TE&.#EA!P"6`.,#`+K)U.WR]-CAY____\;3
MW-SDZ?/W^,/0VLK6W=[FZ_+V]]#;XK[,U^/I[?_______RP`````!P"6```$
M>'#(40B0@9$4AF*%(@Z'8)Q&<RBHL2RM@9@M4L0V?M<[FO.Z('#HZYU^16&2
M>#3*G,BF4LI\3JW5*';)I7:WWC!XK"U#SU=S&IUE?]7MM3Q.?[O%</M<7\??
MR7]Y?GN#?8"$AX:"B7R-A8Z,CY*1E(N6@9B(EYI_$0`[````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]C;W)N9FQO=V5R+V=R87!H:6-S+W1A
M8E]R:6=H="YG:68`````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$W,S``,3`U,34T,S,W
M-C$`,#(U-34U`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$=)1C@Y89`!E@"$$`#"RLV]R];"T-K,U]_1W./>YNK>YNOF[?#M
M\O3Q]OGO]_KR]OGS]_CU]OCU]_GS^/O_____________________________
M__________________________________\L`````)`!E@``!?X@((YD:9YH
MJJYLZ[YP+,]T;=]XKN]O(!`.B%!!+!J/R*1RR6PZG]"H=$JM6J_8K';+[48=
MAD&@($R8S^BT>LUNN]_PN'Q.K]OO^+Q^S^_[_W,.@@<!!A`/B(F*BXR-CH^0
MD9*3E)66EYB9FIN<G9Z?H*&5@H,!#@NHJ:JKK*VNK["QLK.TM;:WN+FZN[R]
MOK_`P;6D@@,$#,C)RLO,S<[/T-'2T]35UM?8V=K;W-W>W^#AU<1@`N+GZ.GJ
MZ^SM[N_PZ.0(`0WV]_CY^OO\_?[_``,*'$BPH,&#"!,J7,BPH<.'`\DY"!"O
MHL6+&#-JW,B1F42*'4.*'$FRI,EV'_Y/JES)LJ7+CBE?RIQ)LZ;-:#%OZMS)
ML^?&G#Z#"AU*5!O0HDB3*AUZ=*G3IU!9-HU*M:I5BU.O:MW*U5O6KF##BL4Y
M<:S9LVB3"0*9MJW;JVO?RIWK-"[=NWA]VLW+MZ_,O7X#"R8)>+#APQ<+(U[,
M6)WBQI`C<WLLN;)E:90O:]Z,+#/GSY(]@QZ]6#3ITX)-HUZ=5S7KUW)=PYZ-
M5C;MVV%MX]ZM53?OWU%]`Q^N5#CQXTS+(E\.5SGSYU"-0Y_^USGUZ\G98M_>
M4SKW[R&]@Q^?43SY\_',HU_/3CW[]^?<PY_OU3K]^XGMX]__3C[__V1I!^"`
M\NA'X('U"?Z(X(+;^,?@@`X^^%^$$NY'887W78CA?!IN^%Z''JX'8HCGC4CB
M>":>^%V**F['8HO7O0CC=#+.^%R--BZ'8X['[<CC<#[^^%N00NY&9)&W'8GD
M;$HN^5J33JX&992G34GE:%9>^5F66F[&99>7?0EF96*.&5F99C:&9IJE&<@F
M>VN^:5B<<J;F9IWDT8EG7WKNV=J=?G+79Z!T#4IH;(`>2IVABK;%:*.U)0HI
M<X]..E:EEN8F::;$8<HI5YY^VMNFHO(6:JE5G8IJ<*2N2INJKM;5:JQ/SDJK
ME+;>6F6NNF+):Z];_@JLE\(.&V:QQI*);+)G+LNLFLX^VZ:"TF#B2FVUNUZ+
MK:_:;AMLM]X2"VZXQXY+KK+FGMMLNNI"RVZ[T\++K;R@P4KO2O;>>U*^^I;$
M;[\C_0MP>-$.G);`!O]4<,)F(<PP1@X_C-7"$H,5<<7P7(RQ.QIOW-Y$(0``
M.P`````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]C;W)N9FQO=V5R+VEN9F\N
M<&AP````````````````````````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R,#(`,3`U
M,34T,S,W-C$`,#(R-S8P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE
M<R]C;W)N9FQO=V5R+VEN9F\N<&AP+'8@,2XQ(#(P,#0O,3`O,3<@,3DZ,S,Z
M,S4@;61J=6MI8R!%>'`@)`H@*B\*"B1T:&5M95]N86UE(#T@7R@B0V]R;F9L
M;W=E<B(I.PH`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O8V]R;F9L;W=E<B]S8W)E96XN8W-S````````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-3(W`#$P-3$U-#,S-S8Q`#`R
M,S,R-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```O*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O8V]R;F9L;W=E<B]S8W)E
M96XN8W-S+'8@,2XX+C8N-"`R,#`U+S$P+S$X(#$Q.C,T.C$S(&IA;B!%>'`@
M)`H@*B\*"F)O9'D@>PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*("`@(&9O;G0M
M9F%M:6QY.B!697)D86YA+"!'96YE=F$L($%R:6%L+"!(96QV971I8V$L('-A
M;G,M<V5R:68["GT*82!["B`@("!C;VQO<CH@(S,S.3L*?0IA+F9I>&5D('L*
M("`@(&-O;&]R.B`C,S,Y.PI]"F$N=VED9V5T('L*("`@(&-O;&]R.B`C,#`P
M.PI]"FEN<'5T('L*("`@(&9O;G0M9F%M:6QY.B!697)D86YA+"!'96YE=F$L
M($%R:6%L+"!(96QV971I8V$L('-A;G,M<V5R:68["B`@("!B86-K9W)O=6YD
M.B`C9F9F.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(S8V-CL*?0IT97AT87)E
M82!["B`@("!C;VQO<CH@(S,S,SL*("`@(&)A8VMG<F]U;F0Z("-F9F8["B`@
M("!B;W)D97(Z(#%P>"!S;VQI9"`C-C8V.PI]"G-E;&5C="QO<'1I;VX@>PH@
M("`@8V]L;W(Z(",P,#`P,S,["B`@("!B86-K9W)O=6YD.B`C9F-F8V9C.PI]
M"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*(W-I9&5B87)086YE;"!["B`@("!B
M;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C,#`V.PH@("`@8F]R9&5R+6)O='1O
M;3H@,7!X('-O;&ED(",P,#8["B`@("!B86-K9W)O=6YD.B`C9C-F-V8X.PI]
M"B-S:61E8F%R4&%N96P@82!["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C9C-F
M-V8X.PH@("`@<&%D9&EN9RUL969T.B`Q<'@["B`@("!P861D:6YG+6)O='1O
M;3H@,G!X.PI]"B-S:61E8F%R4&%N96P@83IH;W9E<B!["B`@("!B86-K9W)O
M=6YD.B`C8V-C.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(S`P,#L*("`@('1E
M>'0M9&5C;W)A=&EO;CH@;F]N93L*?0HC97AP86YD0G5T=&]N('L*("`@(&UA
M<F=I;BUR:6=H=#H@,7!X.PI]"@HO*B!-96YU('-T>6QE<RX@*B\*(VUE;G4@
M>PH@("`@8F%C:V=R;W5N9#H@(V-C8V-E-3L*("`@(&)O<F1E<BUB;W1T;VTZ
M(#)P>"!S;VQI9"`C,#`V.PH@("`@8V]L;W(Z(",P,#`["GT*(VUE;G4@82![
M"B`@("!C;VQO<CH@(S`P,#L*("`@(&9O;G0M9F%M:6QY.B!697)D86YA+$AE
M;'9E=&EC82QS86YS+7-E<FEF.PH@("`@9F]N="US:7IE.B`Q,7!X.PH@("`@
M9F]N="UW96EG:'0Z(&YO<FUA;#L*?0HC;65N=2!A.FAO=F5R('L*("`@(&-O
M;&]R.B`C9F9F.PH@("`@8F]R9&5R.B!N;VYE.PH@("`@<&%D9&EN9SH@,W!X
M.PI]"B-M96YU(&$N8W5R<F5N="!["B`@("!B86-K9W)O=6YD.B`C9C-F-V8X
M.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED("-D9&0["B`@("!B;W)D
M97(M<FEG:'0Z(#%P>"!S;VQI9"`C9&1D.PH@("`@8F]R9&5R+6QE9G0Z(#%P
M>"!S;VQI9"`C,#`P.PH@("`@8F]R9&5R+71O<#H@,7!X('-O;&ED(",P,#`[
M"B`@("!P861D:6YG.B`R<'@["GT*(VUE;G4@82YC=7)R96YT.FAO=F5R('L*
M("`@(&-O;&]R.B`C,#`P.PH@("`@<&%D9&EN9SH@,G!X.PI]"@HN:&5A9&5R
M('L*("`@(&-O;&]R.B`C,S,S.PH@("`@8F%C:V=R;W5N9#H@(V-C8V-E-3L*
M("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,S,Y.PI]"F$N:&5A9&5R
M.FAO=F5R('L*("`@(&-O;&]R.B`C,#-C.PH@("`@=&5X="UD96-O<F%T:6]N
M.B!N;VYE.PI]"F$N:&5A9&5R('L*("`@(&)O<F1E<BUB;W1T;VTZ(&YO;F4[
M"B`@("!B86-K9W)O=6YD+6EM86=E.B!N;VYE.PH@("`@8F%C:V=R;W5N9#H@
M=')A;G-P87)E;G0["GT*+FQI9VAT('L*("`@(&-O;&]R.B`C,S,S.PI]"BYS
M;6%L;&AE861E<B!["B`@("!B86-K9W)O=6YD+6EM86=E.B!N;VYE.PH@("`@
M8F%C:V=R;W5N9#H@=')A;G-P87)E;G0["B`@("!C;VQO<CH@(S,S,SL*("`@
M(&9O;G0M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC82QS86YS+7-E<FEF.PH@
M("`@9F]N="US:7IE.B`Q,7!X.PI]"BYS;6%L;&AE861E<B!A('L*("`@(&-O
M;&]R.B`C,S,Y.PI]"F$N<VUA;&QH96%D97(Z:&]V97(@>PH@("`@8V]L;W(Z
M(",P,V,["GT*+F-O;G1R;VP@>PH@("`@8F%C:V=R;W5N9#H@(V1D9#L*?0HN
M:71E;2!["B`@("!B86-K9W)O=6YD.B`C93EE.64Y.PI]"B\J($%L=&5R;F%T
M:6YG('-T>6QE<RX@:71E;3`L(&ET96TQ(&%R92!D97!R96-A=&5D+B`J+PHN
M<F]W179E;BP@+FET96TP('L*("`@(&)A8VMG<F]U;F0Z("-E964["GT*+G)O
M=T]D9"P@+FET96TQ('L*("`@(&)A8VMG<F]U;F0Z("-F9F8["GT*+F)U='1O
M;B!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0Z("-C8V,["B`@
M("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(S,S,SL*("`@(&)O<F1E<BUR
M:6=H=#H@,7!X('-O;&ED(",P,#`["B`@("!B;W)D97(M;&5F=#H@,7!X('-O
M;&ED("-C-&,T8C@["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(V,T8S1B
M.#L*("`@("UM;WHM8F]R9&5R+7)A9&EU<SH@-7!X.PI]"BYB=71T;VXZ:&]V
M97(@>PH@("`@8F%C:V=R;W5N9#H@(V-D9CL*?0HN<V5L96-T960@>PH@("`@
M8F%C:V=R;W5N9#H@(V,V9#-F9CL*?0H*+RH@5&%B('-T>6QE<RX@*B\*+G1A
M8G-E="!["B`@("!B86-K9W)O=6YD.B`C9F9F('5R;"@B9W)A<&AI8W,O=&%B
M7V)O='1O;2YG:68B*2!R97!E870M>"!B;W1T;VT["B`@("!F;VYT+7-I>F4Z
M(#$Q<'@["GT*+G1A8G-E="!L:2!["B`@("!M87)G:6XZ(#`["B`@("!B86-K
M9W)O=6YD.B!U<FPH(F=R87!H:6-S+W1A8E]R:6=H="YG:68B*2!N;RUR97!E
M870@<FEG:'0@=&]P.PI]"BYT86)S970@;&D@82P@+G1A8G-E="!L:2!A.FAO
M=F5R('L*("`@(&)A8VMG<F]U;F0Z('5R;"@B9W)A<&AI8W,O=&%B7VQE9G0N
M9VEF(BD@;F\M<F5P96%T(&QE9G0@=&]P.PH@("`@;6%R9VEN.B`P.PH@("`@
M<&%D9&EN9SH@,W!X(#$U<'@["B`@("!C;VQO<CH@(S<V-3L*("`@(&)O<F1E
M<CH@;F]N93L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C-S8U.PI]
M"BYT86)S970@;&D@83IH;W9E<B!["B`@("!C;VQO<CH@(S,S,SL*("`@(&)A
M8VMG<F]U;F0Z('5R;"@B9W)A<&AI8W,O=&%B7VQE9G0N9VEF(BD@;F\M<F5P
M96%T(&QE9G0@=&]P.PI]"BYT86)S970@;&DN86-T:79E5&%B('L*("`@(&)A
M8VMG<F]U;F0Z('5R;"@B9W)A<&AI8W,O=&%B7W)I9VAT+F=I9B(I(&YO+7)E
M<&5A="!R:6=H="!T;W`["GT*+G1A8G-E="!L:2YA8W1I=F5486(@82!["B`@
M("!C;VQO<CH@(S,S,SL*("`@(&)A8VMG<F]U;F0Z('5R;"@B9W)A<&AI8W,O
M=&%B7VQE9G0N9VEF(BD@;F\M<F5P96%T(&QE9G0@=&]P.PH@("`@8F]R9&5R
M+6)O='1O;3H@,7!X('-O;&ED("-F9F8["GT*+G1A8G-E="!L:2YA8W1I=F54
M86(@83IH;W9E<B!["B`@("!C;VQO<CH@(SDY.3L*("`@(&)A8VMG<F]U;F0Z
M('5R;"@B9W)A<&AI8W,O=&%B7VQE9G0N9VEF(BD@;F\M<F5P96%T(&QE9G0@
M=&]P.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED("-F9F8["GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=E;FYE=FEL;&EE<G,O````````````````
M```````````````````````````````````````````````````````P,#`P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<V,0`P
M,C(P,3``(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9V5N;F5V:6QL
M:65R<R]I;F9O+G!H<```````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M-S$T`#$P-3$U-#,S-S8Q`#`R,S0U-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@5&AI<R!T:&5M92!A
M<R!B965N('=R:71T96X@8GD@06ED92!&;&]R96YT(#QF86ED94!A;'!H86-E
M;G0N8V]M/B!A;F0*("H@3>EL86YI92!'87)E874@/&UE;&%N:64N9V%R96%U
M0'9I;&QE+6=E;FYE=FEL;&EE<G,N9G(^"B`J"B`J(%1H92!T:&5M92!I9&5A
M('=A<R!T;R!I;F-O<G!O<F%T92!S;6]O=&AL>2!I;B!T:&4@:6YT<F%N970N
M"B`J(%1H:7,@=&AE;64@:7,@<'5B;&ES:&5D('5N9&5R('1H92!S86UE(&QI
M8V5N<V4@87,@=&AE(&AO<F1E('!A8VMA9V4N"B`J"B`J(%1H92!N86UE(&-O
M;65S(&9R;VT@=&AE(&-I='D@;V8@1V5N;F5V:6QL:65R<R!I;B!&<F%N8V4*
M("H*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O9V5N;F5V:6QL:65R<R]I;F9O
M+G!H<"QV(#$N,2`R,#`T+S$P+S$W(#$Y.C,S.C,U(&UD:G5K:6,@17AP("0*
M("HO"@HD=&AE;65?;F%M92`](%\H(E1E86PB*3L*````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=E;FYE=FEL;&EE<G,O<V-R965N
M+F-S<P``````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C8V-0`Q,#4Q-30S
M,S<V,0`P,C0P,3(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+RHJ"B`J(%1H:7,@=&AE;64@87,@8F5E;B!W<FET=&5N(&)Y
M($%I9&4@1FQO<F5N="`\9F%I9&5`86QP:&%C96YT+F-O;3X@86YD"B`J($W#
MJ6QA;FEE($=A<F5A=2`\;65L86YI92YG87)E875`=FEL;&4M9V5N;F5V:6QL
M:65R<RYF<CX*("H*("H@5&AE('1H96UE(&ED96$@=V%S('1O(&EN8V]R<&]R
M871E('-M;V]T:&QY(&EN('1H92!I;G1R86YE="X*("H@5&AI<R!T:&5M92!I
M<R!P=6)L:7-H960@=6YD97(@=&AE('-A;64@;&EC96YS92!A<R!T:&4@:&]R
M9&4@<&%C:V%G92X*("H*("H@5&AE(&YA;64@8V]M97,@9G)O;2!T:&4@8VET
M>2!O9B!'96YN979I;&QI97)S(&EN($9R86YC90H@*@H@*B`D2&]R9&4Z(&AO
M<F1E+W1H96UE<R]G96YN979I;&QI97)S+W-C<F5E;BYC<W,L=B`Q+C4N-BXS
M(#(P,#4O,3`O,3@@,3$Z,S0Z,3,@:F%N($5X<"`D"B`J+PH*8F]D>2!["B`@
M("!B86-K9W)O=6YD.B`C,#`V,S8S.PH@("`@<V-R;VQL8F%R+6)A<V4M8V]L
M;W(Z(",V,V(U8C4["B`@("!S8W)O;&QB87(M87)R;W<M8V]L;W(Z(",V,V(U
M8C4["GT*:'1M;"!["B`@("!S8W)O;&QB87(M8F%S92UC;VQO<CH@(S8S8C5B
M-3L*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@(S8S8C5B-3L*?0IA('L*
M("`@(&-O;&]R.B`C,3(R96)A.PI]"F$Z:&]V97(@>PH@("`@8V]L;W(Z(",Q
M,C)E8F$["GT*82YW:61G970@>PH@("`@8V]L;W(Z(",P,#`["GT*82YW:61G
M970Z:&]V97(@>PH@("`@8V]L;W(Z("-F9F8["GT*+FAE861E<BP@+G-M86QL
M:&5A9&5R+"!A+G-M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C9F9F.PH@("`@
M8F%C:V=R;W5N9#H@(S8S8C5B-3L*?0HN8G5T=&]N('L*("`@(&-O;&]R.B`C
M9F9F.PH@("`@8F%C:V=R;W5N9#H@(S0Q.&4X93L*("`@(&)O<F1E<BUB;W1T
M;VTZ('1H:6X@<V]L:60@(S8P-3DU.3L*("`@(&)O<F1E<BUR:6=H=#H@=&AI
M;B!S;VQI9"`C-C`U.34Y.PH@("`@8F]R9&5R+71O<#H@=&AI;B!S;VQI9"`C
M8V5C96-E.PH@("`@8F]R9&5R+6QE9G0Z('1H:6X@<V]L:60@(V9F9CL*?0HN
M<V5L96-T960@>PH@("`@8F%C:V=R;W5N9#H@(S8S8C5B-3L*?0H*+RH@365N
M=2!S='EL97,N("HO"B-M96YU('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C
M:V=R;W5N9#H@(S8S8C5B-3L*?0HC;65N=2!A('L*("`@(&-O;&]R.B`C9F9F
M.PI]"B-M96YU(&$N8W5R<F5N="!["B`@("!B86-K9W)O=6YD.B`C-#$X93AE
M.PH@("`@8V]L;W(Z("-F9F8["GT*"B\J(%-I9&5B87(@<W1Y;&5S+B`J+PHC
M<VED96)A<E!A;F5L('L*("`@(&)A8VMG<F]U;F0Z(",V,V(U8C4["GT*(W-I
M9&5B87)086YE;"!S<&%N+"`C<VED96)A<E!A;F5L(&$@>PH@("`@8V]L;W(Z
M("-F9F8["GT*(W-I9&5B87)086YE;"!A.FAO=F5R('L*("`@(&-O;&]R.B`C
M9F9F.PI]"@HO*B!0<F5F97)E;F-E<R!O=F5R=FEE=RX@*B\*+G!R969S3W9E
M<G9I97<@:#(@>PH@("`@8V]L;W(Z("-F9F8["GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O````````````````````````````````````````````
M`````````````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S<S`#`R,#<T-0`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A9&UI;FES=')A=&EO;BYP
M;F<`````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U-C,`,3`U,34T,S,W-S,`
M,#(T-3`T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```&!03%1%
M````K:V4SIPQ_\YCQL;&A(2$[^_O,3$`G&,`8V,`__^<__\`A```_P```)S_
M``#_SLXQ,0``SIP```"$4UOO4UOO4UOO4UOO4UOO4UOO4UOO4UOO4UOO4UOO
M4UOO4UOOFY0A+P```"!T4DY3____________________________________
M_____P!<7!OM`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@``
M`(!)1$%4&---CED6Q"`(!-LEXX+CDAR`^]\R@CYG^J_J`0V8&3LLP<%M#AC[
M+YR'=7MEL8/!$5X8UMAKB\D?9X+[M4QCY@1B0IR"X:WL(.9,B!"^](>4$TA+
MO$4I7XY$441M:@LH=$("6FV2D,<]D/1HK<^#//I(6KN"?BL?P5C,+VZX#"IJ
M)#]S`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O86QE<G1S+P``````````````````````````
M`````````````````````````````````````````#`P,#`W-34`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S<Q`#`R,C(S-0`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A;&5R=',O97)R
M;W(N<&YG````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U,C(`,3`U,34T
M,S,W-S$`,#(T,#<S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P``
M`&!03%1%<7%Q@```MP``W0``:B8:I@``-P``_\R93#,:7AH-=S,F3```@&9,
M64`F<UE`A```OYESG1H-V:9SYK*`C&9`@%DS:BHJB!H-\K^,S)EFS```42HJ
M8BHJ____________'#'O^@```"!T4DY3____________________________
M_____________P!<7!OM`````6)+1T0?!0T0O0````EP2%ES````2````$@`
M1LEK/@```%])1$%4&--MC\$*P"`,0PN!-A>][;S__\NEK8PI2Q',4TIBM^1+
M>;?T`*@#;R!/#[*)I9?-*6+YSA?`_\&(J6%N;A`E?1P;F&(;D'"`8T=<.$`E
MJZ1L==+NMN2KK7_Z/QD7"0*-=Z(C`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O86QE<G1S+VUE<W-A9V4N<&YG````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#`Q`#$P-3$U-#,S-S<Q`#`R-#,U
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```#`4$Q410````P3
M&A0;(Q4;(QPC*R,X33)&7"]+9S!+9S-/;#1/;#52<#E6=$18;#U:>$!;>$I:
M;4)>?$9B@$IFA$MF@TYJB%5MAU-OC51OC%=SD5MWE65VB5]XDF!XD5][F6-_
MG6=_FFB#H6R'I6Z'H7>&EGV*F(&6K8"8LX>;KI:HO9BJO9FLP)RLO:*RPZ6T
MQJ:UR+"]SO__________________________________________________
M_________Z9W*WL```!`=%).4___________________________________
M_________________________________________________P#">[%$````
M`6)+1T0_/F,P=0````EP2%ES````2````$@`1LEK/@```(Y)1$%4&--UCU<.
MPC`01(<2FDWHA(02>@EU3I#[WXK=C2A"8CXLO;=C>8W\)RA.RT=@FYU/^S9>
MHGH_K%?I(IE4"H&',)G$T5`IQU3G9!R-!C6HR*ROW.^8N`F3%.Z%)JXZ)Y6]
MB8OV2>66B=U&[I/"+H`]>UP*D]XU4"Q6GL^T[^JE]^K=<>B;`?Y_[CM/A@TE
MPT"5T_L`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O86QE<G1S+W-U8V-E<W,N
M<&YG`````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-S4T`#$P-3$U-#,S-S<Q
M`#`R-#0R,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```,`4$Q4
M100"!#Q2)!PJ%$QZ+`P:!#0^)&QZ7$Q:/"PJ+`P.!'227!06%%QZ1'R:;`0*
M!#QF'"PJ)#P^/%1F3%QZ/#0R-!PB%(2:="0R%!0B#$Q>1`P.#(2>;`P*#$QN
M-$1*/`0&!#Q6)"0N%%1^+!0>##Q&-'R*;$Q61"PN+'R69!P:'&2&3(2:;`P*
M!$1J)"PN)$1"1%QJ5%Q^/#0V-!PB'`P2#```UP$`]```=P!>;0"`:14*]P!X
M=ZA+WN0`YQ(`$@`````#^0$`FP``]```=\B8X.4`21*:^P``=_``#HCLV?G]
M]'=_=X@:XAP"V/0`]'<`=_\XT/_G9_\2%?\``#<`@)``:/0`%7<``,24`![F
M`.42`'<```"J``";`!7T``!W``"S``";``#T``!W`#BX`,?I`!82``````0D
MV`$`YP4"$@$``-R`&.)H`!(5&@```'Y>W@"`YP`*$L!X```")P``````````
M`/\D`/\``/\"`/\``/\`;/_P6__]Y?]_=P!T:`#FP``2%@````!&:```P```
M%@`````P:`#GP``2%@```&OP``"(P`#Y%@!W`%CY``.;``#T``!W``;@!_9)
M`.3[`'=W``\C`!ZC`.7T`'=W```K``&C``#T``!W`'CD`&3F``$2``````#(
M```H`!7E``!W`!0``.4``!(`````````;```6P``Y0``=^!X-OAD`!(5````
M`/``_X@!__D`_W<`_X@$-API`/3E`'=W`/\$5/_G\O\2$O\``#=D`)`O`/3F
M`'=W`.``#!@`Z.4`$G<```!H_@#`6!462P````!O[``0YP#E$@!W`'C_6V3_
M8A7_3@#_```((`'HZ``2$@```&28;R\0$.;EY7=W=P!LO@!OZ`!.$@```*HH
MR(>6_PI._W@`?[@`B`8!Z!8`$@```-P$:.;GP!(2%@```%X`;X`!$`H`Y7@`
M=P#`:`#<P`!/%@```````0`P``````!<``!5``!.``!3``!/``!2;@!4_0!%
M1@!$`'SD&D(````!=%).4P!`YMAF`````6)+1T3_I0?RQ0````EP2%ES````
M2````$@`1LEK/@```'A)1$%4*!4%P0D.P4```,"A[C9E65$EUIF*QNW_;S,#
M````VV4)`.IA<<@3`&E=K&),`,P7AT]3`C!_=V.S!1X[7M=I'1.P;-NSR_$7
M&H#JMAY,[G4$H+^Y9N,P`J"Z3[(R`$!5=+X!`.Q/(0<`O=D3`!!S`$`"\`=X
M`0?2<M`'20````!)14Y$KD)@@@``````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O86QE<G1S+W=A
M<FYI;F<N<&YG````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#$V`#$P-3$U
M-#,S-S<Q`#`R-#0Q,0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$````!`$`P```.W=XE(`
M```P4$Q411$1$7=W=R8:`#P\/*:`&O_,,T`S#0````T-#7-9#?*_)C,F`"\O
M+____________Q'.T*4````0=%).4____________________P#@(UT9````
M`6)+1T0/&+H`V0````EP2%ES````2````$@`1LEK/@```%M)1$%4&%<MQK$)
M`S$`0U$M*12RATAC<)51,HM+C^/FX*>X>]43<"8@8(TGS9VKV2`X]@3!2@<(
MF@;$U30;<9QZ(I9?7P]$G3KHJM\_9^O8J3VU[@S5MNWH\_@#Y$-2T"TJF8<`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O````````````````
M```````````````````````````````````````````````````P,#`P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<W,``P,C(T
M,#,`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A
M=&%R<R]A;&EE;BYJ<&<`````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$R,C(T
M`#$P-3$U-#,S-S8W`#`R-#(P-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(
M`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&!P@)
M"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1
MH0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-4
M55976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::G
MJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U
M]O?X^?K_Q``?`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"
M`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2
M\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D
M969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2U
MMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,
M`P$``A$#$0`_`/XAO'&EPV?CG7M&T:,W:G7+NRMH["R>...YFN3YFF6MF@+2
M+9W;R:=;FV7RKD0K+;HD4D2+^U7[*/PHUV;2XM'T<:O<7]]&MEI]KJYTZSAO
MM%TJP@N]+U`2G3[*21HH;F\M+:>"58+R`J\T-S<J+L?D_P#&OX4_M#?!SX^7
M/P\\8>&]0A^-*>$_`/Q3N_#?A:WO/$FHZ9H?Q*^$/ASXWZ7!):V2:A(\6C?#
M;Q787/B*R;[3:Z'96NIVE[-)I]A<3'W']F[_`(*.?$GX*ZYI$_BK0=,^(>AV
MODV<UL^S2M4729/M:W$=O>PVT\:WD45S"NG7"01M;6UBMB?-LKZ]CF_UWR3Q
M<X#RSB'B2A#&8S!5\3C*E+(:F886"R?#TX^T5"GBL9E]7$S=G5BIU88:I&:K
M0J5<33H05.G_`")XK\%<7<=\$\.T>&EEV=8>EEN"S#'8=9A3IX_-57PM*IA:
M^&>(I87"2P]2KAXU'4EBL%4JTY5I8:$:]*BC^E^'6+SP)J>G:3XCDBM=`ELT
MCMM1MM/A6ZN[[1=*T_19QJ=O;2W]Q%9W)MEU"U"&ZU&(7.E6D]^MM;7]A:_M
MC^Q+\+T\8>$U>33P@U!M4U.>YTBUF>^O;;0[F>WL8+V>\:ZM8KRWGMM7OK86
MEN(GM+5_*M?[0>\O*_G2_:7^+_PO^,O[&_P(_:X^!_BN338?#WQR\'?#KXX^
M$IGOXM>\-_\`":VO]G"5].O+>TU"ZFU&#4H=<3R[(6#:3:6=U9^5)K>C:C;_
M`-1G_!/'Q9I'P]_8.\>?&JXN=67Q&?!?C:Y\(QG5I4O!;Q>!;R&U2XOIIKJ)
M-2?Q+JEJ\=WING:>)-3OGN'LIY[E[B;S/$?$3ROAG^T<AQTJV9XW'4<FA0P4
M(QH9E7KX_P"JY;6J>RG.U.<9/'2J7JT:_P!5HXS"KV7U>O/^)<RREYG1R2GF
MU.OPEB,7CLSR3/\`'8_#1I5<FGD<W4S;$K"XGE<\R_LITZ&&J*MBL/F&/S3+
MZ%.=&<ZWL_J_X0>(O@O\)]>&A^.?&^GO?:[`+_2KBUL3YERDUC`\-LQBG=RM
MO$7G2X^WV]K;07\UW-(FG7"W%SN^)_B+X4UO6OMV@2M+HDMS]GGU2:SN[#3]
M.MC9W%Y:RWVJ7$;V+W+E]-L/LUS=VM]#)>P6L\"W%J\<O\T/Q'_X*.?LI_\`
M!.3Q!JOBS]KN/4?CE^U)KVDV7B;P;\!O!T6FWNI^%?#>HZ;IC>$)OB-<6^J6
MNC>`;K7-(N].U1M/\1ZK=>*[[PY;ZE>_\(A#IFOV&DWWP]\1O^#L[]I"^UW1
M-9TW]@WX0?#_`.'6LZ9<7FDZ7J_B#Q;)K?B&W#);6>IZ-XYM/"WA;3+JPM[B
MT=+V2W\*WZW,[7,1O[9V=3^`YWEV!H<6XZI''8O/*RPE&EC\<J\*.`PE7DE+
M3!8#`X[$49RC[*'^U+!TX8B,8M3C4J4Z=97X,^('B+X>4Z62\-K%Q6:8G,*&
M98N>5Y'B>*<PJT:=.=3+LQS+$8"&+R;+Z:G2P4L/AJU-5,+B95J]>G'#T9?V
MM?8[4\KJMFJGE5FAU%)0IY`E6*QGB60#AUCGFC#9"2R*`[%?@9\._P#@OQ^S
M;XQ^'_@7Q=XE\&:KX:\1^*O!WACQ'K_ARS\:?#^\L]`UO7-$L=3U71+6[N]8
MT2ZNK;2KZZGL8+BYT;2+B>*!99M,L)&:UB*\M8+%M)Q6+G%I.,X4%*$D[-2C
M+ZNKQDG=.RNG?3I^(5_!?Q,P]>M0GP!#GH5:E&5LRH-<U.;A*SCQ#*+5UO&4
MH]I-:G\0NE?MO_M7_L[?MN>#_P!JWPW\0=1C^.OP9T[P9\/_``_XQEM]-EO=
M?^&W@/X6Z5\$-#\/>)+FWLE&JMKWP6TVP\'Z[KLZ+XHE6:76(-2T_P`206U_
M9_/WQSF^"_Q(^*2:W^RM\-?B!X#T#QK'?ZY>?!+4Y+GQC;_"SQ5JGBSQ1/;_
M``T^&7B^77?$GC3XE^`_#G@]?"<.D>,O'=OHGCG5=6?7K;5]$:'3K/6=8^H/
MVL?"GB#P;\0]'^/?AVTMH?!?CV?&F,MI.S^'O%-G9_8_$G@WQ?!<VEG>V>J7
M=Q_:,^F->B"YNM):2VTY[6ZT"^LM'_5;]@35[**)/$.@Z%8ZU"=*U_6]<N[7
M3H[OQ));:?I4]UH[:-)J4%G?6VH7L>KZ?HT.E:9//:W5OK$CW427\ES)IO[-
ME_A+PCXH8NOQMP[QEB</PUF]>6=X+!U,#A88["99B,9B*%/+?K3Q>&@L5E6)
M>*P,Z<\!.D\7@L13I2G4YL0O]7>._$;'^$O#^1XJMPI#&8Z."P^35Z>#S2K@
MLNHYAA\-%5(8O"_V?7A/"4[PK8*O2J1KUXU53I3AA7[:?P;^VA^U-_P42_:+
M^)_PR^)G[:GP[UCX:67Q'\`_"[X8Z+81?"6]^"OA7X@>%_A3J.KZ7X:\5G08
M;?3'U7Q7HMQXDUBYL/%L1A:Q,%CIV@BQ\/Z%I6D6']WNDZK\4O@#_P`$:M+^
M+_P'^&A^)GQ=@^#6J_$'X'?#O3+:/Q!>^(O%T7BVQT_PM<Z_IZ6-L/%$?@*/
M5%\7>)/#<-Y!<:_I/AN_T&%5?4XI+7^2C]K$^-_VJ?&O@I_#OPZ\1>*-$\!V
MVMWMWK6F^&KSQ3=_#KP#8W'A^`>,?&U[`\]GX>\,Z#?74LT=^9+33O#]UX@E
MM9=3>VDEU)?Z[OV4O&/Q'U?]GKX,_`.=?"%MK%GX+\5>#?AIX>O=?M;'Q-\4
M?#_PYMK:W^+/B/X1^&VUJ#4?%VB>%)];TB7Q5XUT9I="T/6[IK.>"XO]0B@M
MO=\1^":?"O".2<+4.)I2RW+>*<%BZ\LUQ6`PN,P^54\NS?$5Z6"J0H4L-"%+
M%9A1Q454PTE1PM/$5E%^SK2A_&W'W'E#BW*."\W?!&7XG/J4L<J619)5Q\\M
MGF%+B;(\'A<;G,Z==YK/#U.%\!C<-BZL\93Q*QM;)JE6K]4CAZ-7_-Z_;_\`
M%/@_XK_M%>,?C]X1\!^._A;?_'O4M9^*7Q0^&7C#0X+?2OA_\:-=UW48_BMH
MO@3Q786FCZ5XQ\"ZQXT@U3QIX3;3?#'AZ#P7H'BS2_AS/'K-]X1O/$6J^G_M
M-_M\_M4_\%$/AO\`L2?LM>*/!OA35-,_9%^'%M\$?@'X0^"_P]UFU\6>+XKG
M2O">@V]UXFTNPU#7I/%7C2_TWP=X=LHAX?TS1['S8[Z[M=#BU'6-6NKW_3&_
M9?\`V$_@_P"!M9MM!^,?P^\$R:%=>%(I+_3/%VBV]_H6KO:6ZW.LP7&D:_::
MAI]C<ZKYT[7MMI-TMD\*ZE9W5Q<SI8V]ROCWP)^S;^SSXIU#Q9\.?A'\+?AO
MHUE>ZGJ&L>,-&^'VEZ5/H/@[P_ISV6I7MS?:+81ZM9RQV5Y%I%I'9P2:>\E[
M<+/;J+ZZN9_P>KA>$<+GN:Y5DN9YIF='ZC_:3S&OE6`C@ZL(1Q]/%3H9]4S6
MK7HUL3@JF,CB<52PU2K55;$3KX>7MEA</^R8OZ46)R[(,DS:?A_E^>9I3SW,
M^&,BR^EQE.CQ`\;2P.'QLI5^'*/#N*Q>&R^E0JX3"4GBZU?%8BO0H3I/$5*E
M+&5OYAO@1_P;[_M(:W\#_@WK7B'X-Z#I6OZO\*OAYJFN:9KOCC6M)US3=8U#
MPCH]WJ=AK.E!L:9JMG>S3V^HZ>.+.\CFMAQ'17ZSZQ_P<A>!_"6KZIX5\/?#
M_P`(:AH'AG4;[P_H=_K4ES!K-]H^C7,NG:9>:M!;:3=VT.IW-E;037\5O=7,
M$=T\J17$T861BODO^)F,VPO^S87(^%)8;#_N,.ZL>):E5T*-J=)U*D<QC&I4
M=.*<YQC&,Y-R48II1^_I>#7'V8TJ>88W.L\P>,Q].&-Q>$HY7P8J.%Q.*C&O
M7PU+ZQCWB%3H59SI0]NW644O:MS3/XH?V9O'WP[^,GPK^,7P3^,7B3Q%K/C#
MXBW-GJ'PXUBXETJ_T)?%4U])-K'B/Q/K^I/J&MKXBOIY%L[;6=.TW5;AWGN[
MC69H98[6:7Y<\#>-?&/[*WQ7U;PS>7;W?A]-2M;#Q1HEY'=VUM):ND,D>HK;
M"&>XT[6=-MIP9GC@GDWI-82K>QJKUX3X>^)7B+2]/T30(;R$:'I'B"Z\3Z1`
M]C9W4]OKNM6NBV%W=S:O=6KZ_?6E_I\7AVS^P7>H-8V86VO[+3K&[OM<33/T
M+O\`PYX<_:V^&'AO4[^[\.^%OC-97%[X2T'7;[6M"MQXXDT&TL+R31?&EG:3
MMK&CNZ:UIUCX6\9:KI5GH=]+<)X?^VBVTBZ_LF/H[^-^`X'4^$^*&J&65,P>
M:<,\2.5;FX9S2K1E1QN78]8?]]B.&<^M0EB:4O;T<HS&D\RH86,,QSFK4_H_
MC+@[`<287&T<9@XYA@<RP:P&<99)0<,51C)2P^84%*#E#,LN=W1JT9TJ\Z7(
MXSJU\%@*2_2;]GG]JOQ!X0TKXQ:+\-]7U'PO>_&/X/:E\+_'4NGW$&E^([;0
M-:OFE#:'KL44FH1S:/J%G'.;BUC2U>QUH6TIM[Z^=;#^L[]@_P#8C^&FK^$_
MV._VX(]?\<:I\4_V5OV2=._8OT?2]6\0R+X(\/:OX8\--X7\:_$'PCIK7%O-
MHWB'XG6=W-<>+]=M9;:;5H=4=;M+63[8B?YWW@>'QG>>*O"6GM<ZQX/\6>"M
M7TOPCXY\-WR6&H:M>ZSIM[<W.E:]';ZX\D,-[?W%Q;VUPWF:7IVK6-NBM?I<
M6`U2_P#[Y_V0?#W[3E_^S!\/-2E_:=T/PU\-O%.F>,?&EQX?^'7P>M+>Z@U+
M4'L+H:?I/B'Q[XS\11W^MP>'M/N+J>6'P]*N@>(HM2LKB]U"STVVC7^QO&K"
MTN(<ER?,\LQ64Y5+.<5&.,SBM@\1C<)GF7XO*\/35",,-A,=-XF&6QK82CBI
MQH8BE+!.CA,7*@X4\3_FCQSE^'\)ZV:Y?4S;%1CFV"Q&7X3+L-C*^"S/)\TI
M5*RPE;$8VG@,PQ,\I_=UJ\J>$52&+PV-P^7XF<*V86/N+XV?$#6O&YN/#<-U
M=IJYN[ZW272KEI;NQNY;;4?#Z0V=ZXU+[1/J>GS65Q)8M9SQ:7<&:QN8M2GN
M+RSLOYZO^"L?[8>D?LB?#B]^`>CZG+\0?C9XRD\+^*?VA-7\<+=:E;FWL18>
M,?#'PDT]%U6WLE\.6^NZB=9\56FDWJZAJ6K/#8PZRBZ3):Z=]%_\%-/^"CW@
M+]C_`$`>'_AL^G6?QWO8((=3TV\NK?4;/X7P_9+%]+E6VGL(8+KQ;J]C);70
M?5+J630I+RXN[JV.N+!/IG\*_P"T1\:?B#\6O&9UKQG?>(+_`%C48;6XL9O$
M#:B+DZ5=Q0)HUS:0:G&SKIDVF[)_#\XM7LSH4%UJEI'<6%O%IK?Q'XH^).'P
M&25/#CA.4\/A'*"XCQ%*%*FYUJ%6%6&64<12G5=;"TZL?:5X4JT\-4JPP\W4
MQ->DZL?V7Z+?@9CJ^-RSQ8XQPV(C3^K/&\-X3,:M.KF&9YCBJT*KXDQGLZF(
MY,OPT:2604YXJK]=]K_::I_5Z6`QN98U_P#$SQG>7U[>1ZW=V<=W=W%REI;&
M)+>U2>9Y5MK=%B54A@5Q%$H50L:*``!BBOFYYD+N3:V$I+,3*^J>$-\A))\Q
M_M-E?W.Y_O-]HOKV?)/FW=Q)NF<K^:#_`$%'/-,@LY4ED60V6IS&1797,R^$
M;*[64N"&,BW5]>W*N3N%Q>74P/F7$S/[-\.IIH-6LO(EDA\N]UN&/RG:/9#:
MW.H_9HDV$;8[?R(/(086+R8O+"^6FTHH`_0OXUR20^/OV)]>A=X==\3:K<:=
MXDUJ)FCU;Q!I^G^-/"<-A8ZWJ*$7FJV=C"[Q6=M?S7$%M$[1PHBL0?[F_#?B
M+Q!:_L]:0MMKNL6ZZ-\/;C4M'6#4[V%=*U&VT*=[>_TT1SJ+&]MW1'ANK7RI
MXF16CD4J""BO]$.#O^3#\`_]?N)?_5;3/\X/I7_\G.X7_P"P*A_ZL\,?P/\`
M[;&JZIJ'Q/\`%,FH:E?WTC^()D>2\O+BY=T\_4FVN\TCLR[H(&VDD9AB.,QI
MCX`UG5=3URZTZYUK4K_6+B)?[$BN-4O+C4)X]&T/7M)\/Z+I$<MW)-(FF:1H
M#-H>EV"L+73](9M-M(H;(F"BBO\`/&?QR_Q2_-G^C&%_W;#_`/7BC_Z;B>6?
MVQJW_04U'_P-N?\`X[1114FY_]D`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]A;'DN:G!G````````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#$P,#0U`#$P-3$U-#,S-S<P`#`R,S8W,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#_V/_@
M`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!
M!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!```
M`7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9
M&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY
M>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*
MTM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!
M`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%
M(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ
M-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(
MB8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8
MV=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/Q:\#_$2;3(;'P]
M\9]"U*?PE;!1<^(].MKN_%A8SLHAN)+R$NUM:1F&.6*X<-<`Q';MV<_H7\.M
M4T+1K<ZM\&/BKX.\>Z9<"SN)M,U;6+;3;^_PQ'E:WHVJI:M<7%O#*\&GZWIU
MS_:LP>Y2[TW656W6S^4?`'P=\&_"G2UU#XR_M^^#O`B*R2W&EZ]X2AN(I+:9
M-TL26+7,TU^[[X/.AAAWD^4&Y*8^N?#_`.T9_P`$VK#PG:Z5I/CWX.?%OXF:
M9=QFZ\3:+X'U7P1J6HP1!V@22RU&TC2YN)"69'@N)@QBRZIF+/\`$'&.7O'1
MJ8K(,JS?,\-*O+VG]CY3F&*R:M4D]:E:AF.3T:5.<ZK=-U\)F3Y977*W%TW_
M`*2Y+Q?1PGU7*<\S.G@<:ZBHK*\VQ.25<SIPIN\(U,3@LQK0JTXRC#V;K1C4
MI05.#?N6/=O$>E_`WX@?#*>3Q-X&N_#/C^W2[GL-*;[7H5P]_)=(#J&@:_"M
MGHMY8S-%%]K2>PM+FYC-HM]`P$)K\\]5_8_E?P_K/Q3^)/CCP+\)K.UM[Z:W
MOM&\1Z1+XMN;2*:0VQUFP.I:5X?EC>-$'D0WEK>3J9PL%VR@1?U;_LE:A^SY
M\<?@JFN^&M#T&9+&WAMI[864"FRDMH8YPTEF)H%<F8!'`1S,)6\P#/S?RE_\
M%3/!7B^#]M>/PQXA_9C\;_%KX%Z/H3:7H7A+PSXC3X8Z!XEU'74NKAO%0UJS
MENX=2UFSO)X/LXO+.=HX],2WD<*\8"X%R'/%CL-0>=X;),OS.EBZV+QF(^J8
MBKEJP&(PTL1E]/#9EB,/A(5\56<X.&)J5*2C"I7E0Q#Y*%3Q,_\`$.-+"YQ@
M\/D.88[,<OQ^'CALNKTZ^+6,K8MJ-'%0EA,+C,52H4J<J5>-3"T*G/3G3IRG
M2INI5I]#\!_^"@/PA^#MM8>'[[7_`-G'X@Z=IJ"U;Q!INFWWA/7EA20P-)J\
M`T_4;J>1/-4WEVL,EHDOE-%/-YFY?UTOO!G@?]K/X6+K2^'=%TN*^T\S>'M;
MT>6:YDO(_*$ELSW=Y9V=R\*,ZF.801"='4-N\I`OX7_\$^_^"/7Q@^,FHW"_
M&K2[#X'?L[3>)]2UO7VMX=.N_C%XTTJ%K6UM_`6K^,WA@U"/PK`=.62ZTK3E
MM-+OKB]FN[RVN9C"T?\`4?9>&O"7A&TTCP9\--*@T[P1X5L+/PWX>MK3<D*6
M&F11VB)))\BW$KM`3,RJ%+8QGMS>(^2<(Y5B,'7X8SK$X_,HXF5?&58RP3H.
M3CSQ]E+`PI83G]HXRJ+"0A2@^>GRJTD>5P;Q;QAF<JV(XCX>H</8FE3PD\)2
MA4S2>(]BY3E.6.I9CB&XPQ,)4X4:53#)RP\*DXQIP]E*?\YFJ?L*7T6IZC%)
MHL,LD=_=QO*VFP.TKI<2*TC.8B6+L"Q8DEB<DY-%?TMGP[I4A,DN@V;2N2\C
M&WMV+2-R[%BF22Q))/)/)HKY=<=\;I)+%JR22O!7LN5+IOM^&^E_TG^W,@>L
MLFRQR=G)\C5V^2[^;;^\_P`Y*V^'M_XCT;QIHOBCX:_%WQ5\9]6UC3+_`,)>
M.]$,NO\`AU]-C$JZCHNII?1).8YEN;5X+ZWF\VP$#NIC+(3[9X?_`&:O%UKI
MGA6X\=6>E^%M-T/5-5U_1O"NE6TW]I6M[JL6F65R-7\0W)?5+F)I=)LKE+26
MX>WM9IKIH0&GD)^BO@[X_P#%'A:RAU#0[Z;6M$U73TFMH+9UF-O!=0[4989-
MSS[AOB"P,OD+"$?*N@'LLDVH^,;9YX71IXXX!=V]P\MG>(A,KQ1""6W)9%99
M"$60HA&<+D&O[#S3B[-L)BE15#+<%@J;<'B_KE1U57C!45"EA7RJAHO9S2<E
M43E45N9V_EWA/PDR#-,/'-:^+S3-LSJJFX8&;]E13J58XN-6O5HP<LSJ/F55
M3G.')+EE*/-"47^PW_!$OXEZCI'B+Q!\/;K5)GM+JQ;4PK7,I#RPSBWD\O?)
MOD56$6]F'.$K^@[XO?"K1/%.B3:C)IEIJ6MZ9!-)9A+.WF'DM(9WMLF)B%E;
M#%`0&;<Q!)-?RA?\$U->;P-^T7HNH7J7D-OJ=GJVBMNB,D2O)&TL895R)$$J
M>9M=0%D"N!GD?UT>&+SQ[XC\/Z7<Z%;0Z1!<W%F\^I:O`)'N[2"2!IS'%*"Q
M-S$)$C?LK2`'#&OPS/HY=7S?/\!*E*M3QE6CF-.G1I>VM6Q\(WJWA%QA"%=-
MS>[W3NKGZ!G.'QV6PX:S;#UE@L0LNHX&I/$5I8=RJ8&K7H.G+[4V\.H4TM7+
MD2?1GYHWWB?Q;>:F_AZTM[C1[)-\%S$XDCF+!@'5`"-JY7)`P#N!P<9KZ[^#
M/PH76;")[^>411QQE'8%2"IF<+D]0K,S*!PK.Y`R[$]S\0?@EI>N^*H=5T34
M+?2]?9RUU!)($L;IVDED#K!&I`.S?YX4+D>0'SL3;TO@C4-:\'2VGA;Q/9/I
MDUPUQ+I=Q,R0PZI:(0&NK?<_VF2'<Z[2H"J'&.HK\WP63XC!9M'^UJ"E@H/V
M5*K!<^&YY/W8RE%<L)+F5T[-3]W>YZN9<14,PR.C'(8QPN/JT8U\7AI4E"M"
M/)3G4J4[MN4:O)[1:V<)1E:*22@D^'%O'(\8+$([("5!)"L5!)QWQ17L1>)B
M6RAW'=D37.#GG(RW0T5]6\HRZ[_<PW_FEWCY^7X*_4_/5GN-22=>5U9/2.^E
M_P!?Z3/\TK_@GSXJTS5O$X^#GC!I].U;3+N;4-)M[R1HC?:2;@1WEM:32$%1
MII<W%G9(0A@N1Y2!5S7]9EIX0^'GA#X%>)-8C\&Z!K-[I^A3?V9-<:#IFIW4
MLOV?>+J(O:RW$7F10H6,15@Q=B<MFOX^]7\&2_\`"8P>.?`>IW/A[Q?X;U*P
MUC0]2@AW^<$CCRET!M!TR=7-A>VS-B*,6ZB,HF!_31^P[^UGX=^+'@2?PAXO
M3^Q_&NF6;:5XC\.WZI$$NEM)8VN+!]RPW.E7R[I+5\.2N^-P`H!^X\?N".(,
M-5P/%.%PN,K912E)YIAZ3J*CA:\8QE+$-4;U)4IQM*4G?EK2<;J"9YOT<?'+
MA7B;(Z7!CSW`TL_PE2CC,NH5,50H8W&X7%2P\W@Z7MJD(UL5A7[6'LJ<DYPI
M\L4Y.S^9_P!FCXS:!\/?BEI6L^)/AM:MI-[J%U]MUK3X;V35+629IY8IK+3Y
MB8T:T201R-$8O+22-3E2`/Z';K]O35=;U'PSX6^%'@6UURP32K"W?6]=U2%)
M;,RVJ0_9].\,Z8K7EUJ.7+QIO`BD52W,QK^3']K'1/BO\'?BG_PF?PYUPW7A
M^Q\2IJVJ>#M0BM+KPKKVC3%OM6B:O'%&\UE;WMG]ICMM0M%$EG<K$^5?RBOZ
M6?L?_P#!5G]GOX$?#*__`+0_98\16?Q5M-2;7O"^JV&JVFMZ=$Z-'.UHNK7)
M&L36D$;0QQ+>RW#SDR*J+]F(/SU3A[-,?A<+Q%PYB(TL#G&$I1QM;+YU<1B:
M,</&M7^K5,/.,JSFX*+52E&-.,4W-J*<C][S;%<.9AF5?*<RR'.\ZSS*9<V4
M8*I5P&`R7'4,RA%4\53QU3%T5#ZOBK0Q5"M!UI5)SI4J6*BU1K_T:K\3=9^%
M7P`^*/[1OQ*\.WVB^%/A?X2UOQ]XIN=4M;9/&>JZ/HAM;:^TGPGX6,^D0OXC
MNVNU.APZUK]O#J<Z_96L-1DES:_E/_P3JTW]J#]I)[C]N+]I_P`<:_>^(?BI
MKVHCX9?"Z.ZO;;P'\-_AMI-P;-;3PSX9<_8M*22Y=#;W)%QJ-Y%%'?7%].+B
M+;\M>+/VH/VF_P#@LU\;?!GP<E\(_P#"G/V9O#6J6?B#Q7X6T?49-3O]<G@>
M&]FUKQ#J:0VXMA+<VUL^E::TEQLE^TRA8GM4)_I2\'>!/#G@?3_#O@KPW8II
MOAGP9X=TGPKHVGPQQ);65CIMM&HMD6)4C<23%[F9PH6227)W,A->QF>$HX;*
MWDF&J3Q+]IAUC,36Q%&K4C*-:CB515&C*I3H3K5J3K5N2I*I2C1PT*RIU*]6
MFOSK,<+5X9_X4LTP]'+>(,[IXU83)88?$TX9/DM7EISJ2GC*5#$XC$XN47A\
MOJSP^&PU/!T,SGA:-3#U\OK4_4(9QY46+2(CRTP6B0L1M&"Q[L>Y[G-%6A!<
M``#;@`8Z=.W>BL8X&G9?NY[+M_=_X/W_`'?F#J4&W[D=_P":?>/GZ_=Y:?YG
M%HJJHVJJYQG:`,[B2<X`SD]<]>]==X2OKW2_%&CWNF7EUIUY]LMX?M=C<36E
MSY4LR"2+S[=XY?+D``=-^UP`&!`%%%?WAQ9_R3F:?]@57_TE'^-O`/\`R</A
M;_L?95_ZL*)^E7B+_B9B$:C_`,3`3:"4E%[_`*6)4,<;E)!/Y@=2Z(Y5L@LB
ML1E01\;>`["Q'CN_MA96@M[>>:2"`6T(A@D!G(DABV;(W!9B&158;FYY.2BO
MX>X>_P"1#FW_`&&5?_2D?]*7`_\`R.\G_P"O:_\`2J!_5#_P2[T/1=.\"W=[
MI^D:78WEW=V,EW=V>GVEM=74C#45:2XG@A269V"@,\CLQ``)P!7ZMZ&[O>W&
M]V?_`$M$^9BWR(\I1.2?E0LQ5>BEFP!DT45\C@?][Q'_`&'5_P#W5/QWQ@_Y
M+?.?^P'#_P#J/@CT%F8,P#,`&(`!.`,].M%%%?2'XJ?_V0``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]A=F%T87)S+V%N9W)Y8F]Y+F=I9@``````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#,R,#4`,3`U,34T,S,W-C<`,#(T-S,R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````$=)1C@Y84$`00#W````
M`````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`
M9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`
M_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S
M,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\S
MS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F
M`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]F
MF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F
M_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^9
M9@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9
MS)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,
M,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,
MF9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____
M``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_
M9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/__
M_P#__S/__V;__YG__\S____XOR0`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```A^00!``#8`"P`````00!!```(_@"Q"1Q(L*#!@P@%5EFX8L7"*@DC2IPH
ML4K#BPT97H1(L:-'@AHQ9K1B4>3'DQ(S5@$@<F/)%2P=KD!)4R#&ARU%,@3`
M$V/-CSJM6,FYD63/GA=_3GQ)M*'0ASB1\IPZ4RE"BTPOLARZ0NA3K5ICPJQJ
MM>#(K"IS(JT2B&N@5:L<EC7;M&5/J%8"L5JUDN7;57GG#A2)M&[7O'JM[1U:
M)2\K5H$$*\PX5BQ,EHU7!;J,.9"USXI9@58L&5M)BRPMW[6BF;-#SZ`?CV9%
M$RM4;(9O-O:*&*[HT<"MH40;T[)#DDSUBOX=''BUY]6L13X)EBAKP!G_-M\^
M.OKGZ1]#_E)F:.5QV\?>N:L'#MYC5M9LV5H#G'B]?>"KAB?%MC<SY,;/W2?@
M=V5=!!=)JT`7W&/,Q;:*;)_!Q=Y<0VG&&G35/`98;P]:<\V'U\"5&&2!O#6:
M9&QUB"%<FJT"(BM"N:CA7O/I%6(5JWQ&FV`+Y:7@:'"!&`A6)1;9%H[?L1:A
M8*PQB&%Z,.:%W5B\C<664,M!-M=;3W:IHX4D.90C:"25"=M\?&V98)<8?ME6
MF$B2V5AC9\+%D56!L.DE<'N-"9IOBHU6Y%Q5L*+GG@XRI]EV0K7WDX^'_HC?
MFXXU%Z5D%ZZ((61^\@FAI7"5AB-T@#WW&&,/L@AJB0&25II"_BPN=&J,0^[&
M%H-[O=D6;)J].E"/1?9)ZH/]X57?7KGZBM!;Z+4:VZ[UA::9H\H.Q%>CQ#HW
MFX752E0B;PMQ"5V?;74[$;1%,M85B\B92Y%C)5[9V&&VW>EN0O`.>>107SUT
M;T0E:@857LCM-M2_!M$WI$KD]5AO0P@3M-F<>#WDE4B]E8AP7/P*Y11#<V+D
M%[&]WAMP6@Z!+!Y;(VKI+F`PWH8393?-R*V[USDZLTL&PCBMO<KZ9H5!(:6X
MUW[8E&DNL<D6]!*2##(4<8S1A>IT5ROP6B+2+P?L&[5E9ITK:BPAO"NVU.(V
M5D-3]61V7F@?Q'985$V]J]4&<=9V9=T18X/W07L'3E;?$06^]^"F04RX0%88
MCA1!&"]NFN`60;ZV4Y)O1A56*;]4'.+W5CFP<72#;BY73L&]=5,\`8VS6%;,
M9U%KEZ_M^KUZIUP9Y9(/YCA5<O6>=TL]"A]13L6_&A```#L`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O879A=&%R<R]A<&4N:G!G````````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#$P-C$P`#$P-3$U-#,S-S<P`#`R,S8U,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#_V/_@`!!*1DE&``$!```!``$`
M`/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!`0``````````
M`0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`!!$%$B$Q0083
M46$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#
M1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7
MF)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7F
MY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)
M"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@4
M0I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I3
M5%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2E
MIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U
M]O?X^?K_V@`,`P$``A$#$0`_`.(^)'[7GBOXL^/XOA%^S;X<T^^;Q=XIF\)>
M"M7A>&/Q-XTUR^N8;2PU:P?7#81>$=.O(H([V5+TV\NF6I76O%%]8:=!K%G'
M\S6=_P#'_P`3>*KO2]=TWQ/'KVCA[.]U#Q9966B2Z$;G38]0BAU!M:M3%`);
M"YT_73:7>FOK4^B0L='DL[>_NWN?A[X5>.;V3QMJWC73;NSU'7/!?AVT\<>#
M/"NE>,4O)1XN\/>*?#G_``B^L7]_HUK;ZIHNA*\MOJ<=_<?VAJLUUJ@MM'\1
MV%M'X:CU7]7/A;J7Q)U+X(V'Q+USPOXIUWXD>+O#WAS6H_#UE%K.MZL]CJ>C
M:1;V]WXBU2ZA^W:/?7=];RZ>FEPQQZ[XFU:T\0:K%MU"XT\P_.TO9IM^RC>4
MH\LG"\JC44[MSBI7ER1DE%ZM7:5FSZN4ZU9WE6G[J;<8R2A"-TDE&%TE'FDF
MVG[NB;;0W3I+?3K==0\0>)O%5SJ5G%;"QTK2K.UA\/Z-=>)O%D%LL!U>ZTRY
MBO(X+>TTW1[)X=$BU>VNM8O-=NM<TIKS3K*S[?X??M1O\.I?#TO@/QQXR^%'
MB*2&*]T]]5U*]UK0QI+Z3*-(NM4M-4DGT;7+2XECMI]6T_4=3OH-4BLK.R<6
MFNV3H?#_``C%\<IM0O?$7B+PCXA\.:'X7TFRU&^DAT__`(1NX\0Z7:W6B>(K
M;2M.?5=+N]1\17[FZN[Z?PII^K:5#>:9<WMN+C04U34[C5O"=;\7^(/BA?,O
MBN&[%_8W<T6G)H?A:6YU`RO^YO=,DM8+VRB2..TTJ34K:?4#<7DR6UQ;M>6\
M,5O;G=.UN:ZU7PV;6L8IM1N[-R3TTY+.ZNDX<GHH7;UMS\T>:VKM*35FE%I7
MUYTURM*Z_K6_8[_X*6^'_BO<:3\*OC/%I>B>(]4ED\/>'O&UA#)I?AKQ/>6\
M,UE)X?O[-+W55TGQ.;B*"Q@-OJ*6>K:E>C3K>RTC48[&RU7]%+FWTX:A(EA<
MWJPSP`M-,BXO8442^5-*\2AFDD$ES:P$+,]PL9A3SHI+=OX._AUK.F/XR\-_
M#W4H`8K.\U'59=<?5[37/"__``@Q6\^WZIJNF7=U8VJ:;HMM?^)"=8N0VGV"
MZGXDLXO`NJ>*-1N+:Z_;?]CC_@JCH?PQU'3?V>_BU\3/#WQN\")/I7@+P=\7
MO#G]O7'B3P%J4VE^'M!U&U\6OXG\/:.=:\/?VA?RZK%K>G76N1P6L.LVL?B/
MQ&--M;5\I152RIU7&2;3Y%&^T7))/FC)J+4G%)\R=UI'6'%KWDG33LI*^C;:
M]Y*45;5-;<NB6C:3_H(`0@%[:[WD`OBTMW&X_>PTD32,,YPTC,[=78L2246W
MB=-5MX-4LM<U&[L]2ABO[2ZT[4DGT^YMKQ%N(+BQFMY3;S6<T4B26TL!,,D#
M(\1V%:*Y/9MZ\M7772E?MU4VGUU3:>FNNCY9)_"UMT?]S_)_<?Y97[,_Q]C_
M`&?/VAM-\:VUEI>J^';^4>$?%SRS:G!%?:+?:]I6J76OQ7LFMZI?)-IVMZ1I
MFMJ]MJL!U:PTQK)KC3'U.>[M_P!4/VG]7_:,U_QW!X3^#^N7WA#0H4L+RPM=
M/O\`7?[6L-(AOGTYKF^%B]M:7.KZ?<6^GSK%J9L-'>:"?S7C$\QE_#?X6R6-
MQ\5_AS-XAO'BTR?XA>$)-<U"9_,DCL9?$FGMJ=Y+)*DY=TMVGG=Y(YMS`LZ2
M9*M_6YX1_9B75M6NO'OQ2\-^"WT75O!YM/#OPRU74KJ:UN=$BC.J^%M:UC2-
M0N([/1K`2^%H;G1_"36NFVO]E3W/B:+51IMM:0ZOW>S<E&$6^;E2N[:VM9S=
MG)Q;Z1B[M[<M[31ES1G?1<ZDDFTTFU=12T3:2UEM9M-RW_(K3?VF?VQ/@XNG
M:Y;^)=;\4WVF^$8F@T'63K&HVFJ:*M[=ZS:-JDEKHHD\0ZU_:-_K%WIEW+IO
MAJQGTV9;..38+W2;WJM*_:UM?B38W[_%+X5):^-]52^+>(GO]2LM;6QT[4QJ
M,K^(KV2WO/[4U#38VL3;>'O%=SK>F^'M!MK?2--T-8-`6:Q_1KXH?"SQ'JNA
MHGQ4^&%GX=U2QT*VL==^)>C:R=9O==\1VUUIT-JMAX>TOX:Z3+X16XU'Q!'<
M7#W&I6?A'1(;230=0MM<;<(?R,UG0A_:_B"T2QU&PMI))[0Z;=[8I+!9KMM.
M:T@26U2SAN+EKFYGFNOL5JW]IV]U?/!(;Y;;2,9.I!+EFZD5+53YFFE&Z2BV
M^G*^:$5JEYI:R]RRDN6\=+)*2?-",N9-:/=<LI-+5+5&_P#M2>(=>UEO[8^$
MVMZG8:WX\OG\-7NH1^*-0M+O[+>W%U/K^OSJFEVL=AH$FGKIUM%I+3RR06=W
M8:AHK7-]X?U2TT./PL_B;X2>'/$]AJ^K7FF7FL>%WEUJ*-M&:]UIUL-0ATJU
MU_2UN+&&&=]2G6)Y]1M(M;T\ZK>7UEI\\TUKI<WQW\4_COXD\,^/)M-\-0:7
M<#P?IUG:-=^(8'N+A]4D$+7]S%:/>6%IJ)>2XL5DMKK29B9+![S[%%;PR,O:
M:MX\U/Q!#>^(M8N+[33:6/B:6\FM[C2?$$FO3:?80G5M!M=1UD+;6.J:;9>'
M)]5T)FLK^TN-/CUFQUCPWI^IP6<-[$VU4C)).ZG[*\KRE)TZ:<VWS>\K2E"*
MM?W%'5V<Q:DI-N2DG#G45:"CS2NE:UDV^5N^GO.5]&OKFR_:\^+&@6=IH6F?
M%CQ/:Z;HMM!I.GVUIJ>L+:V]CIT26=I!;+9SO:+;PP0QQPK:N]L(U40,T6TD
MK\O[_P`=>*(+Z\ATP^#[K38;NXBT^ZO_`!#H;WUS8QS.EI<7C6^NZ;`UW-`(
MY+AH-.L(6F9S%96J%8(RL+8EZIX?757<;ZVM?FM*^JW5]-5>QJJL$DN?%:*V
MCG;3M;2WIIV.R^&GP3\.:E(M_KKRZUI[Z?/=!97GL+)O/MK<V<$$NBW\YN=1
MCN)XY1)#K#V#VIDF\JXBA5YOZW/C=J7B/1)?AOXL\*^,-$\2>#HO@=\*+WPX
M^KZS8Z;'XICT?P/X973]`TZ^;2=0\%:DRW.C6NG6MGK?C/PO87-Q9ZO!<>((
MGT*UC7\=OA]_P2A_;#A;Q[XC\?VG@KX::W\-_!^M^(U\`>.]8\9:A-+J;Z9K
MNO(^F7GACP'XYTZ"_;PS)?Z1?K<:OX=OH=6TZ7PWINE:E>6,^F^'/TF^'>L>
M.CX*T']G#Q\MUJ>L_#RW\7Z3\.OB'X*N8_%>E^)?"$^FW'C%O#-Z]]J$6H37
MND6EJFLZ/X,UO^R?%&C^%]=\/Z!K/P_,^O6,=:+VE2C.3KQC*Z:FY0:]Z\7#
MENH+WK)QLG+6SO)-:4(JG5BO83<917N\LHO3EDI<UG+5-M/51:3:]VS\>\2_
M%7Q=\0/$UAX<UJVN]`U3Q)/!%I&EV-YIWC:&ULYX9K+3[6Y\;:!?:QX.L-13
M5T2]_L[5;C$=U/)NL+ZQNK#4X?AG]NOQ!X7^$?Q.MM1WO//;^`/"\NIVDEG_
M`&:9O$&H+_Q+M.33X[:9!J$WA33-!U:XDN+O2;^^O7.K:UH]A/%-*GWKX9^*
M"^%SH;^&_#WAQM3OM/NM;CUG64CB\+ZWX9TZ]:\U)[0IJ>M:EXZF>:ZDTF\L
M;K3-+LYIM+T^T'BO4K=[/4)?CGXN_L$S_'/XGOXSF\="'X>_%>&'7KWQQXKU
M6R?Q_P""SI5WJ_AZRUNY\%Z7HUFE]I]C>6VOOJFAZI+X7L'O9U\,+XFTB.X\
M.>(-)FE*HH1C.M"4?W5G3=YQ5^;52G4D[12<4[R@N9.+T-,1",[^RISYW*3E
MS^["R45=6C"/O2DTY*T6G'EM=L_!2^U[6O$?B'5=>N[E3JVJ0ZO<7LR6S.C0
MR:7=1WD*0PP7+(K:>);99W4^2"+JZNX0DU[']*^&_$4=M\,[P6NK7T=_/'X<
MU&_6VFL@^G0V.J13ZIK3/:Z5820QV>E6$5AH.C65_P"(M(CLO#5OI%]91W]M
M?>'++]7_`(?_`/!%GP@;_5O"OQ%_:,N](U:3PCJ>MPV$_@B;X=7T3P?$+P=X
M1'V>ZU^XUO2/%BV=WJ>C2W6@76N:/)(VMPZAH"SVMA=ZY/\`9?@;_@BU^ROI
M&NZ-H'Q7^)7[2%YHVAKXFM?B+;>`[CX:ZA-X-TZ3PQ=V=YH'BO4-"LO&+:#X
MFM[GPE:7VI:EXDL6\&:5H,FG6NG:PT]WH(\/[5)PFDH->ZTEHM8V=E'5-\UG
M"RO9[K5*7+3PE>-Y3@^K?O)N,ERMJ23ERM)J6J3DM%KM_+C_`,(W\2T^72+K
M5GTI?ETQ[7Q9;RVKZ>O%DUM(M]9+)`UL(C"XL[0/&586T`/E(5_7YJG_``1'
M_8=;4]1:VN_C#>6[7]XUO=W_`,1O"XO[J$W$ABN;T0?L57L`NYXRLMR(;R[B
M$S/Y=S.FV5RL/;RZJA?J_8SEK[O53UWWZV3ZHW_LZM_+67E[1*VW3V>F^W3;
MM?\`93XJZ/I&G7OQ2U'3]+TZQU!8?"<BWUG8VUK>*^M:)I.I:PZW4$23A]6U
M'7M=O]38/F_O=:U:ZNC+/J-Y)-^9'QP\$^#-/\.:W\1[#PCX8LOB'%\4=%MH
MO'EIH&E6WC..V@^&?CN\@MT\40VB:XD$-W96=U%$M\(X[FTMIT42P1,A137Q
MTO\`'+_VXZ7_``%_W+?^DTS\Z;:SM+WX5?MC2WEK;7<O@_\`:,:?PE)<P13R
M>%IM5OOB3/JDWAQY5=M$EU*:"":_DTPVKWDL,4EP9'C0K]"?"*QLE^.7[->C
MK9VJZ1XU^'?[*&H^,M+6WB&G>+=0\1>*/%FF>(+[Q-8A!;:]>:[IJKI^L7.J
MQ7<VIV(%I>O/;@1T45%'^%_V\O\`TY4%+^)3](_^D1/U1\$65G9^&+&TL[2V
MM;25_@AJ4MK;0106\NHZM\-=,\2ZI?R01(D3WNI>(KV\U_4+IE,]YK5W<ZK<
MR27T\L[Q?$'PYX>L+;Q]XBL=!T6S\0>&-?U-?#6NVFEV-OK'AY;Z[^"4]ZNA
MZG#`E[I*WDR)-="PGMQ<2HLDP=U!!17)/X)_]>I_^F\0>@]J7^.C^>$/FZ;Q
M%X@N9IKBXUW6;BXN)9)IYYM3O99III7,DLTTLD[/)+([,\DCLSN[%F)))HHH
MKE>_S7YP.Z.R]%^1_]D`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T
M87)S+V%U+FIP9P``````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8R,S4`
M,3`U,34T,S,W-C<`,#(S-3(V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````/_8_^``$$I&248``0$```$``0``_]L`0P`!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`
M,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$!08'"`D*
M"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A
M""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U15
M5E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>H
MJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V
M]_CY^O_$`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41``(!
M`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P
M%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E
M9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6V
MM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#
M`0`"$0,1`#\`_P`_^BOZ+S^P%^PG\5?AHND>'_#O[27[/OQLTO3;UVU_Q#HO
MB;7?"FHRVUC>W*GQI\'_`!+I*^.?#]SY]E-;SZQ\)_B!\9-%L(89=4U_1=`M
M!);V_P`[:9_P2'^(7A'P'XZ\>?&?1O%FC>&M.^(/PS\%_#WQUX?U+3;SX>_$
M#3?&OAWXRZYJ^L^'->31+LWMYIC?#71X8[.[73[O2/[8N8-?T7[8UO;P>;C\
MWP&69?C<QQ]?ZK1RZBL1C*5:G4CB:-%U51]I&CRWKTU.]JF'=6G*,92A.4;-
M_7Y-P-Q%Q!G64Y#DV&HYAC<\Q7U/+*E#$4OJF(Q3H?6(T)8F;C##594^7]UB
ME0J4Y2C"M"G*Z7XLT5^_7[3G_!$GQAX%_:"\2>!_@+9?$;6O@EJ^B?#/QK\&
M_BK\5M7\%^&=-\;^$/B;X&\->*]/AL/$FL:9\/\`0_&_B+2K_6=2T+5M/\`Z
M=J%[!?Z+J%I%I,UQ;'SV?%3_`((.>.?@!\(K[XQ_M"_M%^$/@KX:!D;0[GQQ
MX`\1>'+?Q%+#B>XT'P]H?C?5_`_Q@\7>*([$K<06O@?X-^*-"N7N=/67Q%91
M7<LUGT/'8%K">SQN&Q%7&4</B*6%PM58O&1I8J,9495\+AU5KX=24U=U80BK
M3;?+";7#4X4X@HK%3KY97P^'P>(QF%JXW%RI8/`SQ&`<EBZ-#&8NI0P^)JTK
M*].A4J5&YTXQ@YU:<9?@117NOACX(WOBK4C9Z9J=U<6\MP]I831Z.YNKZ>1S
M#9K#91WTSO))*\)DMXY)'+,+6&1YG1J]5\<?L6?$;X>:U>>&/&0UGP=XJL!"
M]YX9\<^"]<\':[:)/&)8FO-*U9AJ%KYJ$/;F6U$<\961)-C!J^DH<.YQB8J5
M#!NIS*3C%5\-&I*,;7E"G*M&<XINSE",DFK-IGS3JP5[MV6[49-+;=I6UNK:
MZWTN?&M%?2__``S)XF_Z&/0O^_>H?_(]%='^J?$/_0KK_P#@=#_Y;Y_GV9/M
MZ7\Z^Z7^7G^?9G]1_AGX5V?C"QL]=^*OCS]MKX"^"=6TQM6\/6?QO\7Z`_Q%
M\6V(;S?[0\*_"K2[N[\4W6@1JMM+<^+O$=CX3\(VT<4]_<:Y#:6XD'3Z/HO[
M-OQ%^#?QTT7X+?M'?'OXB^._@MX5\.?%[4?`?C77M(\6>"M1\''XD>#_`(8W
MNJR:AX:GO?"-IXBT.V^(VB:C'!X3\2^.-+MM/74K6;7(+J-X9_Y^_%?QF^+'
MQ6BO+OXB_$+Q/XODUF\DU+6FU>^61O$6I.]O(=1\2S0Q6]QXGO[:XM@;.Z\0
MM?S:>ZN+%D#&XGZKX*?$CXR^`/$.O:1\$M0U^'Q'\6?"EW\)=;T'PWHZ:_J?
MC;PSXCUG0M7F\(1:0+#4;N]>_P!>\.^'[^UCTR!=3&HZ99/9S(ZE7^%S?P-R
MW.,BS:"E1PF/Q6`Q"RVC#%XUX"ABITD\/7Q6(K2J5ZL*4U&:C&E3IMW=2E./
M+"/]$<(?2+XEX8XEX?Q]2O4QN6X#-,!5S:K4R[*O[2Q>5TL53GF&$P=*E2H8
M;#5,7AO:T/:.K.M'F3I8FC+GG/\`JZ^"6K?\(Q^S[\"?$GC+_@KE\1?V;O$/
MQ)\-_$E?A9\'/$UEXHO/"2+\(_$$O@R7P5X4\:^(_BEX9^&'AC5;FSE\,_V!
MINMZMX/46GB.#3]/@DAFF9_YV_\`@I5\?_B]\7/B$OAGQ]\6?B/\4=3:TBT>
MQU7XD^!?">A7VC:+8W.H2:I:V^M:1XJ\4:DRBX14LUM+JZ\/:]I&J2ZEI>L7
M<%S'Y_S-^UOX^_:=LO#GPP^"/[0&F^+O#FF^!M*U;Q7\.O"_B[P;:^&+K2]'
M^,-AX2\:ZEJ=I>2Z19:SJ]MXHTY/"^J"+4;R_BTI62*R32[B;4K:?QKP>^O:
MAINC#7M9UG4X-$L/L>B66IZE?7EKH>F/.UQ#IVEV=U+Y>FV[SEKF2&UC$+,B
M#[I4#I\/?"7!9%+(JE7%5<1FV%P-&GFT\+FV:8O*:U:G%1=;!T\1B512DHTF
M_P#984XMU81I*$8N/F>+'CEF?'&8<483"X?"4>&L?FV*QF31QG#/"^7Y]@L#
M7KRJPP.+Q^6Y:L95Y(U9P<IYA7K2G&E6J8JK5]I*?V9\/_V1=:E_96U;]J/0
MOBM\!ETKP7XR?PKX@^#T_P`4['2/VB-'MFNO#5KI'C"S^'&IVUA=Z[X9U75O
M$B(FH>&M3U._M7L;RZO=/@M[6>2VL_'[]JO]H#]I?_A!;[]H3XJ>)?BQJ'PS
M\*1^"/!VN>,7L=0\1V/AF&8W::=J7B?['%KWB)A<F6[DU+Q/J6L:F]S/=W,E
MX\]W<O-\\VYCB@61L!G9AD@9)R0%#<84[,_,P4'))`Z>=>-O$\EE;K;6;!]0
MO'^S6D`!8-*SQH4!!`/EB0&7.`\ABA)"LZ+_`$9&G1RO#RQ&*EA\34HSJ5,!
M/ZI2IU\'0JTXTXX>%12DYR<6X<\?92J1J<DXM7;_`)\=1348TU*FYP@JZ524
MHU)1E?G<;+E7P\L'S)22:;.C?Q?8([(98<HS*?FB7E20?E>Y5AR.C*K#H0#D
M45X__P`*\:?]_-=7SRS?O972W:1'DD^=V624O*ZLS$J\CN[`AG9F))*\_P#M
M/.WJL+&W2]2%[>[:ZYM]KKS?=7%"G_,^GVO3R]?Q^?76)#6=J1G_`(]XARK*
M<JBJ>&`.,@[6QM9<,I*D$^A_#/XF>(/@S\0?!WQ6\*-I2>)?A_XBTKQ7H4FL
M^'O#/BFPBU71KR*]L9GT/QCH_B#PY>3PW$4<EDVI:/?);7BV]W#$+F"%U_,A
MM9UA\[]6U)LLSG=?739=\;W.93\S[5W-U;:,DX%1OJ>I2(T<FHWSHZLCH]W<
M,CHP*LK*TA#*P)#*0002",&OB9<74I471E@)34J3I24JT>62<.22E'V;]V2;
M3C=Z:7UN=BHR4E)2LTTTU>Z:=TT^Z:NGW/TZ_;;_`&X_B!^W=^T+=?&WXW3>
M#]!U2[B@TK3])\/6:Z?IFD>'+>_N[N"TA;4)[K5;I)[FZO+RX>[NI+--3OM2
MN[&QTZ*[FM!P.D^-O`T5O'&OBOPW$\@+%7UC3H0BHI\M,O.BH%C4%8V(8.Q0
M`,VROSUHKSLNXEJ98G'#X'#^SY8PC&4IIPA%644XV5DK_9ZW=RJU%UW.56I*
M4YR<YSTO*3U;?3?6RMZGZ3W'BWPZ(ED@UO2;@2)FW,.HV<L;*5W)(62Y91&Y
M8.=KG=O)C!&2/FJ]^*?AZ+Q7]OODO]4M+2)DM&TY;:0*SDD2,UQ=)'+,RO(S
MNK,$=XB3YD#0I\VT5OF'%^-QOL?9T*6']E452W,ZL9-6Y4XRC%6BTVD^;=6L
MU=YT\+"G>\G*_6UOU>A]EK^T1X)"J/[)\3KA0-JV6DE5P`-JG^VE^4=!\J\`
M?*.E%?&E%1_KEG?\^&_\)X^7G_5_2Q]3H]I?^!,****^5.H****`"BBB@`HH
MHH`__]D`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A
M=&%R<R]B86)Y+F=I9@``````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S0W
M`#$P-3$U-#,S-S<P`#`R-#`Q-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!'248X.6$=`"H`]P`````````S``!F``"9``#,
M``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS
M`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,
M`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S
M,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,
M,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S
M9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,
M9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`S
MF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,
MF6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\S
MF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,
MS#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PS
MS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,
M_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS
M_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,
M____^+\D````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````(?D$`0``V``L````
M`!T`*@``"/X`L0D<2%#@BH(($Q(\.'`%PX8*%3[$!@#`0@`3(QIT:-`B1(T.
M.39D.#%C1(P?L94TF7`%2I4;%VHL&/*@%8,C9[;$";.G3H0'2:ID^=,AQB<J
M:HHLZE`/H%+/5JV*6HH4(#U/B([4,_69UZ]@GY72<U-B%5)ATX8=:W(%5U)H
MU88E!765GI)6IF*-*]<K*3UQ[PZL,M4NH*Y>]>B!.G=QU"H&X_Y-6V4%7["`
M`/D]6.5KYK17+W^='+6I9\U]U7+U^@2`GM.I5<=U^=KKY]AA/Z]RV-EO;=Q?
M`3\CI0+;DZYC@8^N#2@HZF?"@8\-/-`*8]*Q_TJ&/'"UX=1_`<5;)<6]817%
MX4E)A6OUJO!2Y[/27`&H"M3PBIW"16PW?%F!Z.EQ%F)R_47851-9L1@I*ZCP
MA'ZE1`C75?)99]5_V"CXUU`5*6742U8`@J%`3V#HD!57I)AB%U>L4.)/*E5Q
M7B"M)%+CC5WD]U,5F>E!8R)``ME*%V>--9-ECW419)"(R!!7<QH19IL5-@8Y
MI!6C:85-;V)9@<B2K5SQ&Y016>?5;E=X(0@B;"KHE9$SY36<APX=!]U/5JBG
MAT2+P;AE>7X&!``[````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V)A<F)A<FEA;BYJ<&<`````
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,3$Q-#<`,3`U,34T,S,W-C<`,#(U,#0P`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````/_8_^``
M$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$`!\```$%
M`0$!`0$!```````````!`@,$!08'"`D*"__$`+40``(!`P,"!`,%!00$```!
M?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:
M)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ
M@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2
MT]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$`
M```````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"=P`!`@,1!`4A
M,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU
M-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)
MBI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9
MVN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`^Y?%_P"T;XG^%D/A
M_P`#_$K^SO#VK:1/JNC::MCKEGJMM>MI)MM.OY+2XFFM9;S2)OL\)T[4$MK6
MX"&$7-C9MN-?('[0W_!7#X8?!_P1?R37=MJ/B&+2]3GT_3M'O;>\UB_NX;=&
MFBOI]-DE%BMU/<)I5O'JDVRVE>33;,W"6:6[?0WQB_9V^'7[4?@GQGH?B6/7
M(-9-[K^JZ!K?AB6.'Q!H<VGN\$&NVFLW,#OIT%CBT-U!+-<O?PEXKF*^B^T2
M#^.C]N/]F/XZ_LG_`!L\"_"WQ38:=XJG\;^*=-U[X1>+K6]T*;3OB7IVEZU_
M9.E6&L6NGW<5AIUS#XAU&SL=;M=5CTF*/STOIK/3H)9)I/Q?)<EP6=XMX7$5
MXR4*>*E7PL94IRK8>BE*?/[27(H1TC-*2K24FHQE=L_KI2R7"97BLUQ%+%T\
M5@%AU3H2]W"U<17JQHTY\L'[:HJC;:TE3BO=ERMI/9_:9_:S^-?[2FI?%3QY
M\0M?E?PO\-SHFF:'X%T]R_@[3_&GCE+A;/1KG2FD&D^(;WPQHVF:]J.L?VA8
MZM_:&NZ#:RW,-G:W4]G'\E6/PWU;Q!\-_&GQ'\8WMWHKZ#?:3!I\6N6\(O/%
M5QK$4WVZ.R::07-L\$4=I>WMY<O<:7+IS2SZ>9Y+.6V7Z=_:4\*)JOQ`^*EM
MH7B#PE>?#^?XQ>&M:\2ZMX?UJQTW1M<^+DOPZMYOB%X0\"#7IY+\Z183:?XU
MT[X4:CXATV#P?J<=AK6CZ5JLNJ:KH^@ZGYQ^UAJWA37/!7PP\)^"_$-KXM?X
M=Z6^@0ZW96?B/PEJ>M>&=^HSZ9:_%+X=^*E-YX?^)OAF=AI3ZAIVN^(/#.M^
M'H[*2UU>]*0,W[7D\,!EM3#9=@UA<!@5*554Z-.%"EA\/AJ5&5++T^12@\<J
MKA-IJI2E%SG*#Y;_`"N.P&*IT:N,K9?5Q.*6%<H1ITJ=.,9XJO.2J*,>2;K0
MH*ERT*$7*I&\X4I1NU\`SSPL61ENB-H6W0A9(D#"1)A)OC4M%,)'13A"Z,7G
M,ADF+?NW_P`$X?VL]3\>V.H_`SXD:MJ>M^*-!L9/$/@/Q7K5_P#;&U'PI9+:
MP:CX)\3:A<2FXFO=&U%=/NO">NWDTL\NEW&H:'?W:?8_#\!_":XTRXMW1;A#
M$)2`@9#N,0`\R8K"'!BB<B-W#;B<L!MQGV+X8R_$KX<7&G_'#P=<VVFS>%;R
M:YTYI+V"6[NK*20V&MFZ\/32L=:\)/:S3:/XG$ZMIM[IMYJ%A+&Z[YX/M,OS
MK_5_&83,*6(I4IRK0I26(G*5+&0EI+#5M9*49/WTJK5-.*?-L?G5'*,RS6IC
M,#2R['8M8?!XC&XE4,-7G/`8/!1I/$8O$QIQYZ=*G[6&E:RFY\L%-II?UP1:
MK;I%&@FB0)&BA#I]NQ4*H`4M(?,)7&,O\YQEOFS17Y(:=_P5!\(2:?82:E\*
M-?349+*U>_33O$V@OIZ7K01M=+8OJ>B7>I/9K.9!;/J%U<WS0!#=W$TYDD8K
M]A_XB!EG6HXO2\>3%Z-\EUI2MI=K33MT/%7"F8::TNG_`"]P/]W_`*>6Z?@O
M,_K!_9P_X*`_L)_L_P#@3Q%XH^.O[0W@#3M5F\"QV^FZ'H/B&T\4>)M6O-0M
MM8>\@M-&T)=02"ZEG>Y6-]1>;5+N\E6TBTIVMY;.U_DQ_P""J?[9/P9_;A^-
MG@>\^%%MXJ2]\):Y=>#?AO=ZG9V'A/P_I^E>)->MI[R;Q%K>M:UJ&KZFCZ]/
M'JNE79LO`L=A_:=]J6LO-(^FZ;H7Y`W'C3Q'<J+>WU1+>.2Y%S!>^18RW\;K
M?FX$ZWPM+K4PZR%(XXK:2REN<O%=(T*&"#C9)FDG62.5KEI98C'*T#N[SR,J
MK)(9;E;EGD:1C([7B+++)YDCM.`\W\N\.<%Y5D&%7+4EC<RA+%SACYPC17-C
M5:?M.50E)1:CI)."2O&-V?H69YU#%YI6Q"I8AX:M6PDZN$J37L5#"R4J=*A!
MRTB_>NY.+E-QE)RLFOZOO@;_`,$X?^"?FF?!WPO\2OVB/V[=+\;?VK8+J$_P
MN^!FA:!#96>D^'9++6]6T;XE7>IZWJ?Q=ATF[LM*GFO-8\,6/@(6NEBQ\1>&
MO'5QJ$[/8?!/QJ\!?L:_##XU?$'PG\'9/C'\=O#?@;6C9ZW\2=?U?X5^(/AG
M902Z-INM6=KX*\;:3H$7]JWFF">]6X\4>+=?T?0K&VT:[U)X_'6I2PO<_H%_
MP30^$W[.4_A/X2?MG^.OVLM.\)?M$>,?V<OV@S/\//B+)H^G^*=8^(]CX3^)
M7P?D^+6H?&GQ)J@\8:E\/E;5=`FT;0->TR\L-<^*T>G^&_"UUJO@[P/KCZ+K
M_L3?%#_@GYJ^M>&_@M9_L&?LJ:U\5?#?[/\`J>JQ^.-?M_%6NZUX-^(/@J[\
M.6FE^+O'OAKQ)>:%X2^+7C+7Y-8/C&]TGPI)<ZV^F:1+HNG^+=1-P+/2/QMX
MW&8?&YCAY8?-<7.E*>)Q^;2@Z^"P];FJ5,7CL?#+Y-86E%0H4<+35*$&I<DJ
M4JEN7]^PV88[%4Z&=RQV<YQ@)4:&6X+*H8VADU;!8>.$=;`8++\#C<'@\'5H
MTI16%Q684HRK1?-)8RM.O*K+^9KXU_"#Q3X&$6IZOX4\8^#]-\0:;I'C'P_H
M_C?PY<^'?$D_P\\5Z;;ZO\/_`!A)`+&Q2YM/%&EQ7%Y::QIB0:5J\@75M/MK
M:"_BM8X=)U9K3X<P210VPTN#X?7NEW<HD1[J'5YO$^JC2['26W>>DDMQ?WJ:
MO92Q2*M@]E/-(P:W1?L7]KWQ1\0=4_:5^(VB_%W0+KPUJE_HVEWUMHG]K#Q%
MHD5CXQT^V\=:%X@\%ZG%'I5I>>"_B+:Z]8^)M*U/3_#GA3[<NHO/XF\):3XV
ME\57^L?F[XFL+_0'U/PS!>37&BW5S9ZM%&R;5D>`&1$EB*@":W%P\4FQ9YHR
MGE@NXVK^P8?#SS'#X'+<5B</5>'CA<VI8FES2H5L/751*G!249.5&5-Q;J0C
M6D]9)NQ^?8[%QR&./XMRO"UX4LWP.8Y%F&$C%NOA,PPE3#UJ*Q<<3*I5>79G
M4HRI5:<'45.48<ZA#F:Y:..\6.-8S:M&J($8KIA+(%`5LS0K-RN#^]42?WP&
MR**!+(`!YVH'``RLDX4XXRH:16"^@95;'4`Y%%?;/V#>VC?\S>GN];>;_I'X
MRHS223E9))6K.VG*E_R\VV^]FK+?B?:+=;K,$=S"2T40"H8C%PD#RO%$54F]
MD$CR0M,80KMAV8UM*/*C(N%F9?M+6I!6+:NZ/!-Q(<)&AD9P\<093M)4;2/<
M_!/P1^*OQ(OHM/\`A]\,?$?B=[BXMK))K#1TEM?-U)XX=/MWO;QH$CFOYYH[
M9(ENK<HZ23B)R=S_`+*?`K_@AW\>[SP_8Z]\6]*N_ACXE\00F^\/+K>AZ-J,
MMC$[F.21-.C\9:/)I_B*VU+%FNL>(GDL;:XD4+X;OT\B\7Y_-.)<CR:E7GC,
MPPL)4)2A6I^T=2I"46H34J=%5*JE"3M*"@VF[VN['UE+AO,L5BJ=/$VH4ZG-
M#VE?#5\-SOEA).G"I2ISJTYPFI0KTXRH5.9<M1H;_P`$5_BIHVK6'[1W[&VI
M0?"^U^(7QR^'.IV/P5E^-/@?6_B1\,?$ES>-HVI?%WX-^-O">@7UCK&OZ1J/
MACP-X8^)?@C2=&U/29;;Q+X"O9K.76+NYA\.:K]*_M7_`+,O[)?P4\):FG@#
MXI?LR_LM>/M572-9^(?PZ\+_`!XTK]H/X\>`/&=[:O</X9^%/BNQ\6Z`;'PS
M'?V6GW6L:OJ_P-T?QG9ZI8QLGC7PY;W4UJ_UQ^SK_P`$@/A!^S%>^&O'6M>)
M=0U_XE6&LZ?XLM=76]L[G4?"7BW2);J[\,Z[X?U2*'2M-NKGP=JMW:>)M.TB
MS\-I93Z[I^EIX@O-9TBUEM+G[JTGXI^(+M/&=IX4_P""7/[-?QI^)^C^(+H_
M%[XI-=_LPW%YKWBNRTBSU32?&]];?%:[N?B3H.G:IX4N-.U32=+T;2-9CTF=
M;BQ\.1:O!&84_`LQXAR?->(\R_LG%8O"X#$XJEFJ=6GAZ52.9NE"G4Q5*$L%
M5I.A5E2H^RI2E3=-*?)1BZU52_0\L57A["4,3B*5#%2A!X3$PIXK#X5+`NK"
M5."<Z?MH5*:YH*M@?95>64*=9U'&,I?RJ?M_:-I+_%WX:1Z-Y]NI_9>_9\EL
MKK4;F.[5]*N]8\>7^@:IJVIZ7:VD$@NO!EGI5_%J*0Z?INKI<0R65MIMI/IN
MG1?G)\2_#T-]*EWHAE:RBGG>WDO8R9'MDD:Y<3YN=D+LKP.;8O-,&$\,%S=+
M:SRQ_?G[9.C_`+8G[1/[6&K>)/$W[-WC+PWXU_:`%KKWP^\.:/:G6-+\4?#+
MP&TW@_2%T'Q)I^SPQ>^#_#-[IM^?%&H+JUAH*:\;7^U;;3+:QL-/'ZP_LK_\
M$/+SQ6EEJ7Q_U&X\;:V86>Y\$>"Y;[1_AMX<9KE]T>O^-;,:?X@^(-[9F5=2
MO7T"X\,>&$OA/!$^OQE5E^ZJYSE_!V$RBC5Q4L=C:6%I1I8;!2>)Q3<G*<HS
MC!5*=.+E.24<3*$8.\8<JCIZ<JN%SG+\W690E@L)5J.I&I#VE"E:=1RCS>U]
MC4JU:::3DE*I-2O*4D^8_DY-GJF3NTJ[=LG+HTNQCGEEPQ&UCRN"1@C!(HK^
M_J'_`((M?LO6D,5JWP!T=VMHTMV?_A74EWO:%1&6^USZ_P"?=;BI/VB;][-G
MS)/G8T4O^(L4?^B:S-;:.OAK_9T?O>>OJ^RO\1_8&2],_J^7_":GVMK[37:/
MKIW/8/\`@G/\/_`<'@#]NCQ/!X)\(P^)-$_:#^-]KHWB&+PWHT>N:1;1?\([
M<16^F:LED+^P@BGO[Z>.&UN(HTFO;N15#W,S/]+^+0)_C!X*$P\X7$6I7%P)
M?W@GGD^-?CF)YY@^1+,\5M;Q/(^YVCMX4+%8HPI17Y)XA?\`(^XO_P"RGSS_
M`-6,3W,+_'RG_L59%_ZJ,.=[\:K.S/@*XNS:VQN[?0[V2"Y,$7VB"22^MX9'
MAFV>9&[PJL3LC*S1*L;$H`*_'#]BK4]2E_X*IZ#I\FH7TEAJOP,GN=4L7N[A
M[34KBS_:*^&EO:3W]LTAAO)K6#7M<@MY;A)'@AUK5HHF5-1O%F**\Y?[W#_L
M'I_^G(GMY#_R)>(/^O=;_P!.Q.9_8"_XJ;XF>(KOQ'_Q4%W%XL^)>@QW.M_\
M36XCT/0-;U=]"T9)K_[1(FE:*]Y=OI.G*PL].:ZN6LX83/*6_J,^#EC91^$;
M,1V=J@GN[CS@EO"HFWF]1_-"H!)N2.-6WYW+&BG(50"BO6R'_DHLU_Z_2_)G
MS?'W^Z83_KW1_P#3:/`-4UW6XM3U&./6-5CCCO[M(XTU"[1$1+B151%68*JJ
MH"JJ@!0```!11177+=^K_,\*.T?2/Y4S_]D`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]B87)T+F=I9@``
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,38R`#$P-3$U-#,S-S<P`#`R
M-#`R,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!'248X.6$E`"4`]P`````````S``!F``"9``#,``#_`#,``#,S`#-F`#.9
M`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P`
M`,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9
M,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`
M,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9
M,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`
M9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR9
M9LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`
MF3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9
MF9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```
MS``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9
MS&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`
MS/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9
M_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`
M_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````(?D$`0``V``L`````"4`)0``"/X`L0D<2+"@
MP8,($Q8D@8TAPX8*(R($H&)4114D'$K<*)#$J&8@FZ4:10(`1(X*2:0*&1(C
M-I,H$ZID&=+BPX<Q":J@2=.FQIP-/_*D.1(C$IP<9PX=:A$FRIU+EY)$"<!C
MU*4J8@(`L/)J3Z0224#URC(K2H^CNHI,I9;GU*0J5L@=-4JN7:$TS6Y<P:IO
M7[E^^U;!"S(56)FLKEFY=HT57\:0'7]-FACR8\615[35&[9RX\N0/ZLU?#:P
M8\^91Q].:1=P:,:2:ZZ6F9;MJ"JH60T&:3.G1[:\<?]=(=0G4!7(H=:=R]))
MVK<<*P)GV9:W<^AA"7N].!NA4K+-*E"6C&D5?#.+0!M*9\N^Z%C2Z1MFG)^<
M,/SX!-%6#X_?H%BF+O4WT'>3"=C0?KQQAE]%;LF%Q0K=;43"%<2U5Q<66`B"
M880*;>7AAR!^6%!````[````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]A=F%T87)S+V)A=&UA;BYG:68`````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(Q,30`,3`U,34T,S,W-S``,#(T,S,R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````$=)1C@Y82``(`#W`````````#,`
M`&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`
M9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`_P``_S,`
M_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS
M,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\SS``SS#,S
MS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF
M`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-F
MF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF
M__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"99C.9
M9F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9
MS/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,
M,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,
MF?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____``#_`#/_
M`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_
M9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/___P#__S/_
M_V;__YG__\S____XOR0`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````A^00!
M``#8`"P`````(``@```(_@"Q"1Q(4&"`@P43&E2H\"!"A@,?0HSH<*+!%18-
M.@Q@\:"5C-@.`D!`LB2"@@X_=@Q@LF7)D"DSLG3I4L!&E1!'VMP80(``DSL]
M3@00E.?!GR2+XFQHU"A2I3F;-OW)<RE*J5.K0L3*-2;#@X%6=&UZ\FN`0($`
MC.59-J'#0-<"25U!EVW;JP&LH-V(%BVKM':_YK&BEN^UP]=8D;U+,,"S9U:,
MPHTKE23%B(\AK]UH62#)C9F?>;1">F.5*H$]FW0<NG7FTZ@YMVW)VG5KV';+
MKLZ3.8]OW[=/YSZYNG4>Q+Q?5R%AE":"VH]__WX,VT!SEP=M]Z8N_#KMY*&!
M*H<^+=;[\\_@M7,O[/T@20#I;9]FCO6S^^<!JF@7;ITK^YGXY3=>>6L%!``[
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O8F5R="YJ<&<`
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S<P,@`Q,#4Q-30S,S<V-P`P
M,C0P-34`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!
M_\0`'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`M1```@$#`P($
M`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R
M@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ
M<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#
MQ,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!
M`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W
M``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8
M&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ
M@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*
MTM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#^)K]F
MWX:W_P`7/BMX'\!6,1N;CQ!KMI`5&^9HK.2:.*5FCM&-S$T7D*_E2)&S0QH\
M:S,85?\`T*OA5\,_#'PS\`>"/!NF65C9?\(IX:L;."2.-O+#PP*;N\07,-ON
M/VV1[N5C!#+#-.&D6$W!$G\CW_!"WX9:5XN_:/O/$VM6BW<'@[2)-6MOM<#/
M8V\\SBT^V$W)EM(G26***VG2**7[9)&D=U]J@@5?Z7?VJ?V[/A-^R1IVDW_Q
M`M-3EO/$4MR]CI6F10S7\Z06L#QW%UMD"6^5*Q2>:[F)(TY8PSQ6_P#$_P!)
MC&YCQ#Q;DW!.38;$X^OAZ,\?/`83WJE;%5H2<$J;G>4:.'A.I-N\82J2<&KV
M/Z`\/\(\-EE7,:E2E1C6<HNK6DJ<84X>XW4JS:C&,VN2,6[2Y4KR<DW]I[K,
MRM<>0'FC+YG2U-Q)F$W4+!98(YMSJL=PAB5VFC\P0R1I+.D3U)+R*`WPD:WM
MQ%&'7%ZX25?M$RL=H@"V\KO+&D\B(9/.N426142WG;\#O%__``7.^$-L9O\`
MA&O!>KZO-:32);2WRI9^7=><[K.Z22((XI&`N%MI1YI>")Y8@\,2P_,WC+_@
MM1\6O&\LFF_"_P"%$=K>7:C8^IO<ZL]J[LL2E([:"U19I1<H5N)4^26*<G;N
M,=K^(8+P9\2,<DUPY4R^D[.=;,\;A<)3HJZE><9U_:J"7-*3]DY-QM922<OM
MWFF2TIJ-3-\-6J7Y(T\,JN*K2E&4%RPAAZ=6\VVE'3V=N;5M(_7+_@HA\&?!
MOQA_9S^(4\4>G:?KUII;ZK9WMW!;V[376E7,CVIV1V_VF[NI8AY5FT"LZO'"
MD[L\4KP?Q$^*86M(VAF'ES1SWD9VNT4BL3$KSNSK,$:%%:)RK$QQI'+`KA/L
MR_MTOAG_`(*@_MU>&7UO2_#/BQ_AM=7L]H\R%-"T+=I=N+FYMKIKEXO-"&1I
MDCEMTFFNIK>&)7W62#\<OB]X9U3P9XBU[PAK*7,.J>']7O=+U0&-H9(KZQE,
M5R'!\Z2.9&,[)Y9EWRQL@20N+B/^N/!7A7-."<IGDF;YK@<;B:^+684L'E]2
M=:."I3]GAZR=625^>K",9*%-0C[.7LUS<\I?GG&>887-5'$X*&(=+#0^J2KX
MN"IRFTW4A24.9U%&GRRY'6ES7<ELK1\LA$OE184H/+3"?)%L&T87RS'(8]HX
MV&1RF-I=B-Q*6,2/&CY4[D5LAH\'<H.1B.88.>,32CTED^\2OV:4\/S.\*=[
MN_[NH];ZZ_7(WUZV7HMCX2,:ME:5=*RM:44K6TM^X>G;5^K/ZZ/^"4_["7Q`
M_8]M?%?BKXF^(O!FJ7WC+1=)>RTGP[]AU*]T>YEB$]Q8WE\AFNQ>6:3B.>2Y
M6P1CYMM`TK)'-9_<?QZ_9H^&?[0VG6%A\0=&AU4:9,TUC)+%&TMN65_,1)RR
M3I%(WEL8UDV!XT*A/]9'Y)\)_P!ISX5>)W^'VGZ+XST+4O%7B_1&U2XT&ROQ
M<78C$4,KRSQQW!CMI[;RKC='/;VLKPSK&8E7S+BOM6VU!)8TE54+'?'.DI51
M"03!,QW%D)BD;$95VW,`T;,5)'^8W'/%G&&:<73XESKV^39\WR4:N$P]?+)4
M84)5,+&6&]YU'"].K%U8RE[2?MFV[M+^G<IR+"9%@*6%RZK#'8*4%']Y[/$0
MFFO:.%6,^:$E/F4XJ>CIRI*T59+S'X&_\$T/V)_@O\+?%'QJ\=?"+2?'M]H6
MB:UXKOK6;3_[3&FZ=X=AN-5DM?#^E)]G#W\T-NCK#+>W@>98H4E@WS6T/SMX
M=\/_`+)G[4?PH\2_'?\`9^^"4WP,UOPWXLN?!.LV.K:4FF0ZI`+6:XDO["V2
M!/)N'6TB@NYX(89%>[B?;>WEL(J^]=&^(?C_`,'VVI0^&[W3[_0;N"9+GP]K
MMI)?:<Z.D\=Y+:B">$K->`[9`1,\ZQ@2,HF^;YK^(7Q#U;4KF3P?%I/A/PMX
M9M'N=732/#4%MI;"6YECM[B2ZBLIGAC>UMW19KZVM8[J2=`+C4[:VNI--M_V
M+'^+_#F8^&M'):CQ^*XC>5+"UW7=6K5EF,;7S"6-K3C>C*LJ=?V$)RBXWH.C
M*ES27A<.<$Y\N.'G.'Q6%I86&+^MMT91I*&#;3J8+ZC"FH-N,W2A3<?8KE<Y
M2@N5/M+;5_CSX)UO]ENV^$/BCPWX2^`GA7PBMM\7O#,]]8V^M:IXFNUN()#+
M%&)&O6U*4QBQDM93Y5U(\J7,MP+.Z3^,C]O_`%-M1_:9^,UY-IYTASX\UHM:
MQ!PL3.\MT)IC%$\4+L)"^R:"652ZQ#+I*9/ZR[?Q@(KRST^:Z+0VEY$IM;FX
MN1$]PS/\DVGM*)+F&179A*Z+9N]Q;FV%Q*Z/:?R:?M]-$?VE/BS+#+/)%+XM
MO#OG,<!=YI"[3,+6VCBCN9`Y$;+Y`:8;H((1,Z0_?^!_'^.XRX@K8;&9?A\%
M'+,APL8_5W57MZD\7AZ$ZMI+EA"I&"]R/-*+;Y'-Q<GXWB1P9'A7*5652=66
M8YC7K.K6IQ4^3EJ5Z<)3<FZDJ:J;R:;<KU'>5SXR3:$0.L&\*H;?(-^X`!M^
M?..[.=V9I3G.9'^\2FK<1;5QN8;1AE6,J1CJI!((/4$$C'0T5_34J%+F?-7D
MI7?,O95='?5?$]GIN_5GXHJVBLJ=K*UW3;M;K[JU/N?_`()E?#_XJ^+OVG_`
M^N>#H-86V\(_:]:O[Y9+F"%+&*SEN1;B1MJSPW9C6(VRLPF$YVQLCSNO]0VB
M_M5^$O#U^N@>,[V+PKJVGR1V,MGK<^G6$8W6SW$TT2O)$6EF$(B29/M2PNDE
MO,[RR2./D3]E[P!K'[-'P;\`Q>$+;1[?QQJ\ND:SK]SY\*:G(U_+%$=/N8Y0
M\DUNT%VT<D%W<""V5X;B5K]?LTB?=OQX\-?#YM5;P?\`M!_#/3]0L=4TZ/58
M-5TZ"&.]TY=71Y<1:AMB:%K"6Z'GQ.)&BA2.6=UO)X#)_*'CKA<#Q;FE+B)Y
M9C*F2Y=4JY!2Q.60HK%6HU'B7C5&M&%+$TI2KS:I-QY8VFJC4FI_OGAE4IY/
M@)Y'C51Q>.S",,U6#GB>2O1=2$*/L:*:<74C"E&-6G:4IN5HJ#Y)/6C_`&H/
MA3/9R2-XN\/&&X.!(-4M+>2.8A/-!C>,*TEJ\L$CLQ?S85$[1)',J+\!>//V
MD?#.I^.=5DT+5]&U`P;5!BD$OF.MM;7*W$TL\.+B*8RVX:U4ATV&222*1-M-
M\1?\$\/V>O&/FW/PN^,]GHS+,9)="\0WS2*`&D53)+]JMY[,6_DW16>ZMECQ
M)$PCM[5YKBV^:?&/_!.#QUX+M-;UC3?BOX#OK/3K7[83'?7B78LGB%T#*D`>
M0^7$H5Y#%.LLOVA4B2YM_*'Y3P]PWX9PJ59UN*<;"K4A&C'"YEEE3!N,ZDZ;
M4)NFZ\:CO96IRC&[OS2CS17[7EN9X?)<;0Q%'):N-==^SJ8!U,7#%TFTH7Y*
MN78>ES5&TH3I5I:RCS)-I/TN;XN^)?$>MVFD:-<32W%TUM91P6OE"Q>.6>..
M01Q2;[<2['68.X$3,H@5$NIY_M'X@?MFPR6/Q^^)4$>J'5(CXDN%EO`7`9E5
M)1;O(T:N[0+,Z*AD82SQRDQPR(]P?W2^!7P:\2>#/A7\4M?^&D$7C'XE:)X/
MU76)/$NNSK;Z9X3N[*TE74!ID%S:K>PR16T3LC2D7*SRVPMD%QY,Z?SPV7AW
MQ'\4/$.MZSKFJ,;J2\O7U*^O'-Q<W=W<7=Q-.4W)"Q!GEW&4(R$B0,R$PHO]
M'^"G#]'^V,YQ^48>%/*\+"CE="O.A*E6S&O&K2Q5;%N$H>UAA*,H*C0DYQE4
MJSKNI!I0/S/Z0W&.$S'"Y%D2RV.68O"?6,9BJ$:E*<L,\3&G2AAJGL6X.M3A
M2O.,W[2"=HJ*3<_&!O8`D("1DAV@+#/.&(8@L.Y!.3DY-%?7\?P7\"V\<=N8
M-9F,"+"9EUH!93$H3S%"V84*^W<`H`P>`!17]*/)LRO[LJRC]E*#24>B25:U
MK;6T['\I*K2LKP;=M7S+5]7_``S]Q_B5J.H6WCF_:VOKRW-GXJ\+PVA@NIXC
M:PFWL7,5N8W4P1E_F*1;5+?-C/-?MK^TDB:E\(/@YJ^HJM_JMYX5L!>:G>J+
MK4+H#0;:<"YO9Q)<S@3JLP\V5L2@2??`-%%?S'/_`)-S2_Z]9;_Z:@?M6*_Y
M.-4]7_ZKL,?@S\6[FXT/Q/%'HEQ-H\;V&G*Z:5+)IZ.L.H:7#"K+:-"&6*&[
MNHHP00D=S<(H"S2!N"76=8&H.1JNI`VL,WV4B^N@;;SGOY)O(Q+^Y\UW=Y?+
MV^8[,S9+$DHK\DS3_>'_`(9_E4/ZCR'_`)%N/_[`ZG_JNF?KG\)]+TR#_@FQ
M^TEJ,&G6,.H/\&[V]>^BM+>.\:\FBS-=M<I&L[7,I9C).7,LA9BSG)K^-3X2
M3SR:VXDFE<'4Y@0\CL"/)L9L$,QR/-EEE_ZZ22/]YV)**_J7P8_Y%+_["\5_
MZ57/Y(\:O^2VS[_L+_\`;Z1]64445^Z2W?J_S/QX_]D`````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V%V871A<G,O8F5R=#(N:G!G````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q
M,#,U,``Q,#4Q-30S,S<V-P`P,C0Q,S``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````_]C_X``02D9)1@`!`0```0`!``#_VP!#
M``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_
MP``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%
M!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q
M%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(
M24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*C
MI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ
M\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`
MM1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!
M"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=8
M65IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJ
MLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ
M_]H`#`,!``(1`Q$`/P#^'+Q-:"TUS5K<L66.YRA,>Q@K`R!=FYMN`Q&=Q!`S
M["MHNB7_`(DUW2?#VCVMQJ&IZOJ5GI.GVD$2M/=WU]-%!;V\"%MIDE:0!=QV
M@G#?+DUV7C]`WBB]NWMG@?4H8KF&UPA9C*H@$:MN6,L#\P9RB9(5BH^<?HY_
MP2%^%NAZK^TFO[07Q(TNYN?@_P#LR>#=9^,7BN^.GS7%O>7V@6;PZ#%IJ74`
MLM0NH=76QO9K:5R#"DZ".9(6=OKN*<_CPMPQF^<S<5/"TO:4XJTJ]2M45\+"
MC1C>K5E5K.G"*A"5FU>RO?P>",BK<3YQDF504I/&U:-*48^\XTXPC.O5DH.3
MA3I48U*DI2LK)VU/Z!?V1O\`@@E\)K#X4>!++]H#Q)XBUGQTVGSZ[XMC\'ZC
M!INF6?B/Q`+74+O1H-2N;.1=0DTG28;2P86T:A]0N-3ND$3WI@B]T^./_!NM
M^S1\3O!&H>&?A+XX\8_"KQO<:=Y'A_4/$5W#K/AF34TN!=VLNLVT$6FS"SNK
MI88+^:*9I8+9Y9HXYF40M^IG[)_[2_PE_:K^'6F_$OX-^*(]=L%LP-5T*YC@
MC\7^&[N=95CM]9\,17%U-IAU*YBC%I=+;)9:C%BVTW4Y+IUC7Z5\;_$SP-\+
MO"T_BOXB>-M`\#:!;1W<D_B#Q3KUAINE"*"X2S4VIN)([BYGEO)[.Q$&GK<B
M#4;J.TN+BW`:<?Y+9IXN^*=+C>6-Q&+SRECZ6:?7:N0R;]I3P]2K%P=2E&34
M83NHSYE>$9-SY4G;_0[-.#N"WD"RC"8+)%@\3E-'+8YK"FHJ-2E3Y54C.4;J
ML_=DX1:J<UKIKW3_`#5O''P8^'?[-_B_5?A1^T%?^,M.^-/PUN=8\(^*_!%K
MHLTNGZ3K.EW]Q.98=6FGAAO='N6MT73]42RC748+J*_M+>>P22XC\53Q7H@M
M+ZUT^;3[!&BOS9IJD*2W4D,L4@@02((Q%+("JH65@KD'!`-?OS_P<D?"'0Y?
MVA?@1^T1X3M4UBV_:/\`AC;OJ.M:>)KK3/$.N^#[33XXM5BFMS;M>73Z%J_A
MC4IG-M9+%)<S6EI"UBMQ;7/\SNOV317US%;6XQYMI"8Y(RC03*5#1L?WK)YK
M?+AMF,_,R]:_U7\/N+_]=^#.%^*N2,/[1H8BG6A%-<N(PDE1Q491M>].I=*7
MPR6L&TE(_P`TN,^%Z63<2YODE2O.*P6*5*C4;NY*?+4@E;5*46[II*_6[M'M
MX?%TL,,47F69\J*.//FJ,[%"YQL.,XSC)QZFBO*6M)`2##@@D$9<X(/(SGG%
M%?9W7=?>CYO^S*/_`$$U.G27]SS]/ZW]%UG3,^(/!J^)+6ZTZSU2[TRTU);J
MSN;.X&EG48X]19;>XR08[9IB#YF"0/F'4?W9_LU_L[_LW_`'X1W?A_X2^%_L
MGA$^'/`Y^*.L/=W]UJ'BW3$CMT\3ZM<CS+M;?[)HFJ:O?6=AID*S1W45JT=T
M\T$;5_#K\8O$7BOQ)8>%[KQ9KLVMW5M#+:+=_98+.X`-K!>E'DB.'DG%P8@^
M8]A7S.=P4?U$?\$A?VV]/U7X2^&O#7Q7U.ZTC4KZ>30-#\2ZZI71_$NH:1/#
M:K96^H75NEE'JD4&R:\TJ[F+06\9DC>]R(S_`##])'+\ZQ7#N39UE]:<:6"Q
ME.CF.`^L*A'$4:4XRHR?OQDY2<4ER1E.-TU[R9_:_P!#/,>'*?$N?8#,,#3E
MGV+R[%3X?SFO3<Z.7U)<U-TITIQM%>QG+WIVA9-2DH[_`%)\2?\`@GCXIT+X
MW_$WXQ?\$]]8NOV%M-\,:IX$TKX?G5_B!?ZQ\.OVE=$\0:'JE[XO\::#I^C-
MJT_ANX\/:M;6<&H^%[G1+K0[]M5+3VMC)!(;GUC]FK_@E1<?M"_M$^)H?^"@
M_P`1OVFOVBG^'OP+T+XK>&?&%WI::?\`LF:OX@UF#PQ)>^#-+\<'7H[[6M6\
M.WWB*+1-1\`Z9HNAZ/KVM>$/%6MSZCG2%T2_N_"_XZ>"9_%'BZT\+I86$&F>
M+/$=O';+_:8BLXFNUG,L,<OFP6UMK+"/SH;='M;F)7C$B),2GZH_"/Q/<:GX
M4:]?6?$CZ3<W"JGAFWUZ\N/#-DD:7)DUNTTFZ>,Q7^J"]NH=3N#/+=72RD27
M+(TD4G\E9WXF8S)9YIBL9PW0H+&Y7'"8;$0H47B/K$X.FD\QQ7)B)\LI+71M
MI1B[O3^H^)OH^O)>%\LS/)>(IX[$U<\6;8K,Z.*^NY?*&(J*:P5/"1G4IT91
MY)P@FHN3G+VEE"G?\AO^"ZG[+/Q8^+G[/7P*\6_L\:9IDOB#]GO7?%^H7_AF
M%%$T/PW/A'PVD&L^&='"L=:7PE#HZSW4%N+6XV64>RWNW189/XM?C+\/]#\`
MZA;^'H/B;X)UW4KKP9;^.7U_0=;FNKFRU751++JW@CQ%I\EBMQ<>)(H$GDEM
M6-C_`&8N/FF/S'^VK_@KK^WWI'[-GASPWX'\+^&[OQ7\6O&O@?Q9J.A0MJMG
M;Z'HNFSP3Z9KM]JLMO*+L7EG$L\6DZ;8;VNVMEG\R,D0U_%3IOPC;4[CQW)X
MV\#?$:Y\:Z7XEN[#Q/X;EDLO"TVB>(K][6XT.QMKJYT74KJ?5KBTU2X-]!<2
MJ+VSA2V>6V-V9H/ZA^BWF6?4?#Q4LXP=7"Y=A*U5Y94J6:J+&352NXQ3E-+G
MD[R<4NMVC^+_`!YX9R&GQKEM3*\14Q&<3P,\7GV`CAZW^RXES]GAE.;I*E-R
MIM2M"<W"]JB4KH^/_P"TM='"R0NHX5]TOS#LW^H_B'/XT5^LFG?L">`[W3[&
M\GG\9VT]W9VMS-;GQ/:,8)9X$EDA++8A6,3N4)``.W(`'%%?TC_;.`3M];CI
MIT_N^7W_`/;Q^3_ZK8UV:RV?1_PI?W?[R[?GV9\:?$.Q2[\(W\[/$9-.U'2Y
M[>)PI^TI=P6MI%#\\L*QK/;0273,9%"C]RS+_KQ^KO\`P2I_:&^'D/P9^,GP
M`^,O@5/B;\-DUOP_XMU/3GMX[K4="TNYCU73K_XB:!9VT+ZY'<Z+/%I,NMS:
M:SVXLM09IFE^Q8N_RNU.6VU-=0\+7ZE-8FLU_LA)HH[<:O>W%O*VA-8+-YL$
MWV:4?85#EHY6;S7"`-#7ZU?\$`_A=^SA\7?CC\7_``=\2/BP?A-\<[[P196/
MP0N-5\JQ\%>(KF^U'46\0Z;?:K.\4R""*S\-O+H#1F+4S<7%M#Y90^9\SXF8
M#`YGPGCZ&(I5*TZ>(4Z%:C:,J56#YJ=:":UE3DHRUC)-JS6FO1X.\28WACB7
M+LSHUJ<E%1AB(3BU"K&?)&5&I'E;E3J+W6E&2M*7-?1'ZH?!_P#X)V?"/QN3
MXY^'/[4>L6^G75W%);Z/I.HI_;NFV'E$FVO)[>4R64D"2#R!,/MUHT2LJR2J
M%KZE\)?LLZ;8^.(+#6?VM?BMXPMK2ZBATSX8>!?'>O7FI2P1;6CBUN=_L7D6
M11&GOII]/-FD)D2:X2/=,/TK\'?\$>/#>N:E!XM^(EGI'AG6]-OI!=R_#W6[
M[2X_$4,#QBRO[RVTG4=*TO5++51A[I6M[>]2%WC2Y:0K(/DO_@MS\7?AY_P3
MG_80\1_#3]GG2-"\,_$GXSI<>#;#^PI&L+O3O!6IV5ZOC_QH-1TF%)[J^CTQ
MQX=TF^OKV*Y_M#6[/4U=FM397'\/X7ASB+BK.Z671S>6.PV(Q/U2K/'Y-3AB
M)4^=4\0H8Q0?OJ#GRSE0A'F2:DM#_0C%^.W!V0\.X_%8?*JV'K2]I.>44:N%
M>5U,5"$)X:K0B\(G3BJT^=0;A-)7=KJ1_*!_P40^/G@+]L/]LV[\)^#=7A\%
M^`OAA8:M\*_ACXT-W!<>'(/$7AHWVGZ;KUUJ\*W^J7NC^,K^UOX_M<]C;RW"
M:A:7^V&.0E/L#Q'\.=>\5>$=+^(D'C'X>^)+W7O"MTWQPTOQ%XITVV\:WWQ!
M\/:-X8AO]:\/:8K17WB,:C>W+SZ;K<<6FW"6EL;"'3IW?SE_FUM=?U:VTSR=
M.N);.\W7%W#J-B(;.[AO;B&**YEDN(;?[3.TD$7V6U8W*&QMGVPDSH)V^MKG
MXJ_$F/3_``SH+^+M<NXM!TS1K:&]U2ZAOYK.XOK9-;T6=-82TM;V.ZALIHX=
MUXU[%))9QW$L;(?LR?WAEO!>099PSEF24GF>`IY706'IN->FXXE\BC&I-4YM
MZ/WGS:NS5KM6_P`ZL5XE9R^+LSXIQBIXR>=XRHL32FN;ZG0YKTE&][Q;M!*"
M?N^]97;/W4T77/!Z:/I*)X4@*)IMBJ%;&)U*K:Q!2'?5E=@0`0SJK,.6`)(H
MK\;M*_:M^)EEI>FV4NF>$+J6SL+.UDNI-*NO,N9+>WCB>>3&I`;YF0R-@`;F
M.`!17S#X%C?3-*S5]'>>JTL_P_#S9]ZO&.R7^S8?1+_ESVY?[O2W_DOF?,7C
MDEO`_P`/;UB6O(=.NC#=L2;F(PWGBDQ&.<YEC,1CC,>UQL*)MQM7%CPY>7>G
M-XXU33[JXL-3L[+0;RTU&RGEM;ZUNXK3698KJVNX&CN(+F.6&*2.>*194>*-
MU8,BD%%?7\2?\B?$_P#7S]$?E'!W^^X7_K]0_P#3R/V^\#?M9?M4>'/@_96_
MA[]I?]H'0K?^S[G]QHWQE^(VEP_)''L_=6/B2!/DP-OR_+@8QBORN_:X\6>*
MO%GQ3_:;OO%7B7Q!XFO;;QSX%L[:\\0:SJ.LW5O:7EOJ]Q=VL%QJ-S<RQ6]U
M<6UO/<P1NL4\T$,LJL\2,I17Y+X>?\CJG_V&5_U/T_C[_D2K_L+7_I<3XWLT
M3R4^1>9;<'Y1R"XR#QSGOZU];:'!!+\1?&=I)#%):IX7\&RI;/&CVZRIX!@V
M2+"P,:R)_"X4,O8BBBOWG&_PJ7^/]4?SY/X:_P#U\A^<#YVOY95OKU5ED55N
M[E5578*JB9P``#@`#@`<`<"BBBN`W>_S7YP/_]D`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]B
M;V)A9F5T="YG:68`````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,C`P`#$P-3$U
M-#,S-S8W`#`R-#8V,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!'248X.6$E`"4`]P`````````S``!F``"9``#,``#_`#,`
M`#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9
M`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``
M,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9
M,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`
M,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.9
M9C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`
M9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9
MF0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`
MF9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9
MF?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`
MS&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9
MS,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`
M_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9
M_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````(?D$`0``V``L`````"4`)0``
M"/X`L0D<2!"`P14$$RI<R'#@P880(Q8$(+$B1(,6,RK$J+$C-H[85A@821*A
MQX0<5S"0P)(E@P,F3PK$N**E30D'8,J<"<#`RILM<^H\:1``T)L,0'8L>O2F
M4HU%?S9-2I&H0218LVK%^C1C41)%PWY]Z/$J$K!B#9+(JL(J##ELV"`)BR2N
M'!@,VI8%8`.0GKAAX^H!=$-"3*@`N`0*]#>PGL6!N!SV"@!R(#:!+0>:;''%
M"LN8B[+1S%GB"BN!NL2X`2BTP=%<;BBV4AKB"BY=&AR0T!HM"3:$6<JNW;`F
MRP82N,B9"P")'"XWB3/T:=-&8P!L]-BPR<!`1Y$D?5Y:88[$2O?PTBL:2.M]
MY\(5:=.[]^C99/V0]^\+S,_?OF>*]H4DH(`(Q61@0H<A!(!G^Q'8WT`,XG<@
MA!\-6*"%!%+8($$)?K3@?A_"%^*`)(H8H(;SI:CBBBRZ%Q```#L`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]A=F%T87)S+V)O;RYJ<&<`````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,3`W-#0`,3`U,34T,S,W-S``,#(S-C<R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````/_8_^``$$I&248`
M`0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!
M```````````!`@,$!08'"`D*"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$
M$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ
M-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(
MB8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8
MV=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$````````!
M`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'
M87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#
M1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66
MEYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7F
MY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`_`,_&\Z5\8(/`_A"1?#'A2RU
M$2:O>Z=9RVMWX@T#1]2FM[JPFN;6VLI+?P[KDEI->R:7'93@0"W216;S8X_W
M1_8E_;9^,/PWDO=+T+XC>+=$T*VUDZ]I=E;:UXC6.TTJ]%L;33!:6NI_V7;V
M5R)[=#`EM<VR102P-8I@/-\#?'+_`()(_'O]A3]L7XA:?\6FM/%/P.\8Z[JE
MK\!/C';:M8:E#\1+"7QBNH>#='\1Z9HET^M>!O&%M;VM_=:IH&N6-MI\^IZ7
MJ"Z9K6M:&;,W/=>)]4TGX7^!?$6Z==.OK.*\?7]<=KB./P[I%EIUY=W>HW:R
M1R?:WTN+2_MT-O&DDU^;(6L;[IY5D_DGQKAAL7FN5Y3@:E2>;^QRZ4<;A:LX
MUZ&*E6A-XB&(H<M:E6HIN$H4ZNRIQITZDY)R_L?P$H95B>'\SQF;T<%6R^-3
M%Q]AC*4)T%3ITX1K3K*JI4G3C%3YY2B[OW;6BI']&OA[_@I-^TWXVN+#Q%I_
MQ-TO3K;2]-TW3-/L[[0+:+2-6BO8)[^_U;58;=Q=#6;66(6T-_;HK2PS>3<6
M\$;23UM>'_\`@L!^U)H4NI6MUX:^'7C"[NQ8ZG%-J&FZ]''HT-F^E6>HQ0Q:
M=XITJVFTJ6V21DCEN8Y[;5YM0GADNHYS#%_.Q^RQ^T9\'OBSX:N-7T#Q1/XD
MATG[5H0DN-)UW1UAUJ/^Q5W065U")[E;=-0MY3.Z213VL^4(>/*?3_AR&6[\
M5ZC+K-U-/8:A;11Z6IMY;8202QCR%,D:P36T5J]W!-LES++"8;B5V>9MOX_B
M^-/$;@W,\=@\QSG/XXW+Z+56EF$L<L2ZC<5'GI8AN/-"G*E*4:M)J2=W>5[_
M`&M/PDX$XOP<,RR+!8#^S,1B%#!5<NH0="K2A->TM4HI3E#FC4UC))+W7JK+
M^K#X)?\`!6GX`^,=)\+6_P`54U;X3^,-6MKX:I!=Z/J>J>$+&[LQ*JQ0^(=-
M2]5(Y8+&5(_M4*^9>`V\+L\D>_\`2#PA\7/A]X^TC2]=\'>+=#U_3-9L8M4T
MZ:SN'6:;3)8HIAJ4EC<I!?VME''-$;BXNK:%+9G$5P8I@8Q_"K\2_%D_A>[L
MDMKCS+*QDAFALU83FV"^3(Y2=YM2E'S,TH8W0V.6?!)=3\T_%WXU:YJ.D7I?
MQ->Q>&SIMI=:KIY^T-:7&HVEF+BR8QR)Y-S<0Z;+;V%LD<0LX?,:]>/$-R'_
M`$OA'Z07&6)J9?1S'),LQV$Q4(-XF/UG#8V3<*45"]#VM&59W3<?JTG*4TO:
MI64?S_B#Z-V64\/BL5DV>XFA5H1<_JV*A0Q&':4E?5+!XBDE3ES<LHS?[N;V
M:3_T3KCXG?#RSN)[2]\>>#K*\M9I;:[LKSQ+HEO=VES`[13VMU;R7JR07%O*
MKQ3PR*'BE1D<!E(HK_)^U#]LW6M,O[[3;8PQ6VGWES8V\?\`:FEP^7!:3/!$
MGD_V.?)V1QJOE9/EXV9.**_H&'%7%U2$)KA>DE.,9I/$5;I246D[1:NE*SLW
MK;74_&WX;8-.SXGP-[V=J3:Z;-U+M=GYKY_IA9?%WQW\=!:^*/BM\0=4\4W-
MMIT-O%?ZQXKUG5$.%687>=<U34;I[@FY>ZF=Y(W,,9!0L7!^*_VO?#_Q6^*_
M@+7-!^$MUI?VS4-0L].\327-W]E&J>#].%U-J5I!>F.ZLO[.UF86-OJ-M>QM
M'>Z;)?VM[$]K<-#)]KZW\&M5\.?`C0_%VE)/;W.J^)I]&2"4YDD7^QK34K9V
MDLP!%)MDG17F<QL+)XBNZ12WSE9^#O&'B&:V\-Z7=7MIK%S>+-):)/(4N+7*
M17TR3B_M(OW8R\MI,N9$7]WYCMY:_P`E9%F5/`YU'.Z5;#-Y=CXUZ%+'I8BC
M25%TZ\:E6G*K&52"<8M.4FW)II7@K?VMFW#N6YOP[CL#AE'`X3%X+%Y95GEU
M..'A0LXT*_+4HTIQIWY]8R5HI6=N:Y5_X)Y?LX>,#%XNU76M&T30/$WBSQ9X
MM\5SZ)X8;2+/P5I%[JM[/`MCX0T+PQH>E:#I&B'1/LL=I8V]@SZ8L#QV+V^D
M2Q65M^O/C#X#>(O"VG7-WK=J]O;:S;F2RU&WCECT[28X+IK>2WBD-AY<%R<*
M]U]F>X\[ST5_+P!76?L0:'X9^%$%I;ZS"]]*^J65T]Y=1"ZW--X?L8;TVMLR
M23VL%U<1ZABUR7V^5YI=`YD_:KXR2_`WXG?#2T\+O=0^'M0F>*[LIOLTL;P3
MWFI6M[,EJ+>T,"V_E+'!/D?(RR!CQFO@>.<QSSC7B#.N*)XG#Q<IQKPIM2IK
M$1H>QIJG0JSC-1BJ5%RY*C?-)*S;DT_&R#'5.`,%PSPS@LNS.ODV%C/#/'QI
MU*L:<93JUY8RI2I*32E6K.:G;2+O;8_@=F_:(U3PU^WIXB^'/C+7_&DUE:^'
M-.\.>'K/2]2T/1_!2^)-0T;PQJL7BKQ_::S#J>J^((8?#VJ^(TM4\/WW@WQ-
MI7BO1_#=[>ZMK>E7/B32]2]F_:&2_L_`E]<6EE,=$@M+R:[54$(CL<3FYECD
M,MK82/#8Q+;2_:46!(XYHXBUM#$*^F/B[\+?!O@;]HSQF_CGP)X?U3Q%I-]'
M=>%O%%WX<L[K6I;;4+2WDE:VUS[-O73HXY(X([>Y8PI%`EO;I&PR=OPYI>E:
MI::S9^(K#2;S3AJ$TPLM62WFT>6+R49S=0$M:S1RQ%H)8'AD=X&D#J0ZM7Z?
MF/%V36X+S'`Y%'#_`-BY!E>'QL:/L%3S>K3<G5Q6'EAXZ5:DZDE4EB5*KS3A
M&4I1I02X,DX6XDP]/C?$8G.'C*7$6>X[-<MQ$ZE6:P6'QD:CI4I1K1IPC3HM
M\GL*,8TWS2E9.4F_YNI?#VMZG+)J5KI5TMMJ$CWUNL.LF.%8+MC/"L2"=PD0
MCD41H&8*F`&.,DK^FZY_:'\'Z#<3Z%8^`O`%I9:+-+I-G:V_@:W2"VM=.D:S
MM[>%+7PQ+:K##%"D<:VTLL"HJB&1XPK$K];CXY9VE%4O#S&3II)4Y/B/!IR@
ME'EDT\`FG*.MFDTY)-+I^#3\,*[G)U.,,`JCDW44<OFXJ=X\R36(LUS+1K1I
MJWG^ZMC\'+[Q1^S]\.?!^KK8BWMK;3XDL(],F@O;34)-*,5PYGO'C=]-@AEE
MN-/71(KFS1;AU2[EM(II4[G]FW_@FII.G:O_`,)]XAM8M22ZDU&+1Y;RVFO4
M@6\>U-M=QP2ZBJ6\T'ELZ3P6D%[@[$O%`")^A/@SPM;>%?"]IX5U+1]8OM%M
MOLVZXT\0ZGJ<5ZD1AO-.^U6D5E#<:$^GQ;GMHK(S13237%Q*T$B)'[/I_P`2
M?"_A?P3>:;X<N[;Q'KVGZ9?7.E^$I)C:ZG<1V-M,MIIEJC(\R7XOA96$$(AE
M5Y)'C1BQ14_$N#>$\'CLVPN(S6O&E3I8:%22=6--5L31A"/L)T76C4Q5*7+-
MI051S;BHPE[UN7B+Q(SO#99F>5Y-.I2PN9YA7E7A34YTO88JM*I*]:*=#"OV
MB@Y3G[.2]_VDU%4T?SY?'W]G34?V;_BN^FV^L:M/X<^(.N:]K$SZ-:W,]UI7
MB+6/$,=V-<FBU2_FN9K'3;"\U;S=.M=1MXV2%]BS2-!!-8\!Z!KOQF\5>$?`
M_P`-?%J^-M0T^[GN/$('A1K272+;5]*TUM(A-WKLFG13S?9+BZO/*T[41!#%
MIL@U3[3=3:?8U]3?MD?M"_%_Q7X!U&X\+_LI7B_$D:;+_P`(KJ?C:?4KBTM+
M74Y[:W>ZEM-*T2PU&XN8+2:[CEMX-1LOLFHO:K-<R6]Q(8?LS]B+Q)\)/#Z:
M'/\`\*4\:?#WQCXDM;'3K\R^&],U_P`.6U_IUC<12WR^+=!L;&:*T>*+;*VM
M:593VOF6]D+BZCB6[E^[EP+D>:YA++WB9X#+L94A.32K8:4X5]9THJM2E>I3
MKR@Z?/&*C"5I<RBK?J</&#-\G\,,+5Q63T\9F]*F\OIXNEB<FQ="5:E!QABJ
M^'HSJ9A*C'#Q5Y4I1A5K4U[:,U3IJ/Y?_P#!5W]A#PYX6N?`OQ/6X34KB'PQ
M%H_B$7UO;HT%U;'3[2RNK;48)[FY22:`R^9`;(V2I%L2?S)$:OSS;]E[0_A_
M^RM=_%+6=$CDU?Q#X]BM=!\-'4)K;5/^$4C\'W%]<>)8]*L[]];UBWN+A(=)
MCGLK(QM=2QP1)]I98W_LS^+WP\^&_P`8])&E^++;PUJ^D^?:B5M3BTRXLWBM
MXVD2"5[Z*6WACED`0B1/G<1+&58`'\3?^"E?AH_%'1O`'PX_9YT^Z_L7P9<P
M^&M8M?`]_-I\&B0M;ZSI=Q<:K9^&]#D=O"-C!=P6.MO>>([?1X'N[:*^TJ&X
MN--N;KXCC7@__57,L9+#8Y1X:H3HK)\&L3.K6FY4\/&=2E9R56%&<JV+J.2N
MYS@K.*<3PN`O%C&9YE66<,5XS>9RQU6KF^=8B5.GA/[/P\JM>C2J2A"-2G.M
M44<)*2G&$Z$8TY*3;<OY:4^"&F:HB:G+IT<4NHJM])&=7U&$QR78%PZ&*YU&
M.XB*-(5,=Q&DZ$;9460,H*_I>\"_\$_[&/P3X.CUR'PO<:U'X5\/)K%P52,S
MZHFD6:ZA,8UND5#+=B9RBH@7=M"J!@%>6O$+B**4:=3$*G%)03EB+J"Y5%/7
M=15O/YL]2>8\,1G*,GETI*33DZN(O)II.3_VE+5Z]+W\W;]*M,O+NR\(V45G
M=7%I%<ZS<O<1VT\L"3O*T:RO,D3(LK2K'&LC.&+A$#$A5Q^<G[1GBKQ/X>LO
MAWJ.@>(]>T/4+J72I+F^T?6-0TR\N':?4)V>>ZLKB">9VG@@F9I'8F6&*0G?
M&A4HKV\O_P!]R7_'2_\`2D?@\_\`=LV_P2_]+J'[5>`--T[Q!X"^'][KUA9:
MW>7?@*.6ZN]7M8-2N;F6--,9)+B>]CFEFD1IYV1Y'9E::4@@R/GR;]JZ63P7
M\-=$D\'2/X3DDU#28I)/#+MH+O%=:S;17,;MI9M6:.XC_=SHQ*S)\D@9>***
M_H;//^1;'_L$P_\`Z:HGYE@OX6&_[&F(_P#2:QX?X5\1^(;^PCAOM>UF]BGT
MO3I9HKO5+ZYCFE_M+6U\R5)IW623;#"N]P6VQ1#.(T`A\.Z5IEO\0EOK?3K"
M"]N_',NE75Y#9V\5U<Z7?21&]TVXN$C6::PO#+*;JSD=K>X,DAFC?>V2BOYV
MXI_BY9_U^E_[:?J7#G^[9W_V!R_]2C[?.BZ."0-)TP`<`"PM0`!P``(L``=!
M1117C5/XD_\`&_\`TJ!X<OCE_B_6!__9````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V%V871A<G,O8F]Y86YD;6]W97(N9VEF````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,S(P,@`Q,#4Q-30S,S<V-P`P,C4T,C,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````1TE&.#EA.@!&`/<`````````,P``
M9@``F0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F
M_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_
M9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S
M_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,
M9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`
M_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:9
M9F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;_
M_YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF
M9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,
M_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS
M9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9
M_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`
M9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F
M__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___
M9O__F?__S/____B_)```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"'Y!`$`
M`-@`+``````Z`$8```C^`+$)'$BPH,&#"!,J7,BPH<.'$"-*G$BQHL6+&"$"
M`+`"VT8`'K%9L9)QXL>/5E@%"K1BY<>2#ZV@'!F(8R"9)SO"7+CB9,Z-5E;B
M!+H384^?0'$&!7JRZ$&D*'U:.=K4*4&H3+%6M2I0:E*J4G%R'7CTFMFS9EE=
MJWGRYL:Q`S>R"HJV[K6/;D$Z9;2H[Z(M`-2B#6H%[<:\>F'R]=L71N%`=M>>
M'?IVYV*_9PP4OK;Y[(JZ;%_N9-RX,^3!=5D!>)PX(^F^`$YS[BRY;F!6(D>3
MC@$`=63#:@,5?0VX+NW(IV,,?[TZK<P5=']?8Q6C+Z.2KQ>=B6UVY0J5TCG^
MA\EN,7O?&%6^KPQO=H7Y1=<GON\+>/54Z5:JOX\?<?[YC3#8))AA9_C'WT/^
MO1:&`=P9EN`B$CU(7(-KP?!@A!*2=L9GW>GG7T2798C99E9L<2%$(F8'@UE6
MC)<@1"&FV-<-A5EQ@X0(RLC8%C>-5.*)##6BHU\\&N?BAPP-V5<8M`5GXHL+
MQ:+D(C&P8B5GW5D(I4)*AL$;;RIQ&(B62'*I(X\M+N(8=)`%<N.6",4HX1F!
MQ&#B&3'<--F1\RVDHY?Z;<>1@PD>>)"(`0)@@(O;P4`C6@8`&6>&,,1P0X`&
M`!+@C5O01N9^?DH8!@`%TA=@J46>%6F9"<EI'@#^;V*VZB(TKN12J>8U$N2#
M,<SJUZ)^+7C2D^89BI"4_FV':V.?JCELGPXEZ"AI-Y!*[4E\DJ:K0\B:!X.O
MV@&0;;@;@4M:1$)F-^JRBQ@0*VD?$4L>NJ]MEVT,S3+V$;OG2I2N7S%XN*2X
MYM4'`*L0=;LN:>Z^ERC!T$XDI`'RTIHO8P^_.V]%`B^R<,'E;H2P0C2QM)I>
MB]D[7[4&\`9QL0S5))Q(2XTD$%^P^K?1C>6.;-!<+L5F,DD"P7`Q8Z-:6^W+
M&QMTF,PRC<21?2?SR[#('N\<<4&$K=822]"=S!%N5EBM;\ZP*;IU7"-9B=M-
M-?DXE5NL<+'R1KBZ/&YB7P@%9:502]'\$E"`:!@#%UL(>G"P'V5G+$$]LB2U
M:D'9>E/=I(4!EMH>;V%PMA&E-%=!MMZLX<,`F-CI1PW[]7A)KI[A>8%A>+X%
MZ'"9+N+K<#7BJE^-;)O[\,07;_Q``0$`.P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A
M=F%T87)S+V)O>6%N9'!C+F=I9@``````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S
M-3$`,3`U,34T,S,W-C<`,#(T-S`P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````$=)1C@Y84``0`#5(0#_WCG___\```!24E*M
MK:T8&!@Y.3ES<W-22A"ME"GGY^?&QL:,C(PY,0@8&`#&K3%S8QCGQCF,>R'_
MWE)S8S&MG&M22BE24CF,A$HY,2&MG%+&K4*ME#E[>WN,>SFMI7N,A&,`````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````A
M^00!```A`"P`````0`!``$`&_\"0<$@L&H_(I'*Y!#@?@JB@(#48I-'#`,N-
M,K]%ISC1Z"H":,7@C&ZG`P1!0TP73\#$>AW"</O;"E0#!`<'!&U4#WIT28N.
M=%!N<1"/CI%H"P*';EM'$Y5B")L#F00#<WJB;15TJF@#!7\">$,7:FX&`W]H
MA`0)`!$)$!B#!@`)NKN2M'E."!`)#@8,IF@'9P/,VLQ44P.#!`P*:@*YL%$.
MV=M@8UB#7>4,`WT+]0H$"@P'W;/KC7JD#FW9A<^-`@.;,`F04*D)J#J:E&$J
M0+'``0<1%DE(%F"``PA*'BY*$)$!`I%Z2"YH(X`CKWY,/B5@L+*-`393"EP)
M6,`#I/\$BAXA,*?.7P%3!1H@<*#O&\6@"/Q);7;L9#`'91!H16"AP-2O2`2%
MZ"?%@00$58J"_<(ORK=O5W+"J[+6B!@H4MK"8S#775TA$-V^*R>QC:E"6QID
MU#-5#X0I6&JV68#P#TTT5X(ZTO;H9H!ZA2?'\N.Q84R13$/OTF>VCE9HOYPD
M^812C`0!?[:87?PP(IJ6G\<:"%.[3H--!TX6=]*`XP'<?F`.69YN7!2^O"%I
MF4>A%<<X"5^I14(;P(,RX`RA:7IO0&P`%-`T7U7GP5FWK_P!&"29@('/X2%R
M`04@,,!!2@@1H.""#!*P#@2$L!$`-0'\UY$8"3:HX88:ZN?_C#,"^<?)7]N8
M)\`!_4V34"XDMNCB7\,-,9X!%KQ(BUY5Z$3``EK$Q857-AJ!XQ0&4$0(%15)
M,5Z+LH7@HP%:&!E'.<_UU9*+=#@`SY#G6!EC773<YM:4<^FT111#,@D,-%)<
M@X5_DA7&EQQU@%6'EE%`R9=+:N02X&>)/'+'.JET$2<F?Q`PVA:4/$)H'0D4
M<,:4!(6W4D('8>0H9WK$]PITJA'BAP$.F(:'4(=*=,\!XA@D@'*;?5&>(Q&,
M)J<"!^12R!EJ./!>K"&A)(&MRH2CP`(5(:"9&+4.$!=##A77@(5^4!9%`Q)D
MH-2R=!S7!BQ7_+,<2:2]NARH`0C0_P$G5P*VG!CH%M!H<1)0&X>$KWPY:W&N
M")!=;2=^2VT:TH7P[@.D&$+%K_5!\,P>Q/K6!@-`$B=2O1V9HHD!\]9ARB"L
MA'*`8>BB4;&XD)[EP"BE?$-',!^L3)\8T\[CWURG'C/R9#MGW!XT$E"@X`$/
M6$`-`QV[-LHZ$T0PB!N%8/9-'YC`ND$%#`>3`$E];3/!(%0'H$#)!@W2P-8O
M_X),J-L@$$#/'>'8`$56*%4&%PC<;:47VFAP#34*0ED-9:$0]=;AB"=^N#\/
M;(T*`@-L1\T"IC@0Y!>A_*(*V-?D=WD3)%U&CGK6=/2Y0PF@U1)-N%*Y0""G
MHPXK`B310092[+AO$P0`.P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O8G)E="YJ<&<`````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,C`P-P`Q,#4Q-30S,S<V-P`P,C0P-#<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````_]C_
MX``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P``
M`04!`0$!`0$```````````$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0`
M``%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8
M&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X
M>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)
MRM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!
M`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$
M!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I
M*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'
MB(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7
MV-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#^^"OB/_@I3X]\
M*_"K_@G[^V7\4?&/@;X:?$W2OAK^S?\`%KX@6/P]^,?A"U\>_"[QGXM\&>#M
M4\2>`?#OCCP?>H]MKV@:IXZTWPY:W=F[6[#S$GBOM/EB2^M_MROYJ/\`@YH^
M)W[8?A/]E[X.?"+]FGQEHGAOX;?M8^-_B)^SC^TII.A^`KGXA_'OQ#\.->^%
MVN>/-?'P?\/SS6>BZGIEE\*/A]\:+?QYX>CU'3/'7B^XU7P5X7^'U_;:IJE]
M(,J]:GAZ-6O6DH4:-.56K-[0IP3E.<K:J,(IRDUJDFTF]"Z5.=6I3I4US5*D
MXPIQ6\IR:4(J^EY2:2OI=J]D?Q5_\$\[#Q=H/QC_`&2?BK\6_P!I']CW]FOX
M(?M1_$WQW^T#XR\3>`M<^&OP3^,>D>%/@M\8]5T[QE^SKXGM_A+;_#'Q3\,_
MAW\<O'MCX?G\%_#2XU*/X;6GA/PQH'B3P!8Z99^#=4\'ZI^FG_!2K_@LU^SW
M!^V/IFG?L_?M4?MT^#1\,;'5?`GC'XD?LZ^*?AAXH_9L3Q)X;TWQ+J7AO7O#
MW[/OQ`DD\*?M#_;/'/B:'PS\3=:\0>)O`&DS>%O!-JO@._\`&NGWEGJ$_P!E
M?\$:_P#@C=^QO\-?!-U^TW#\3;']M'0_C7X"\5?#.VM?'_P?T_PY\+3H^C_%
MN)]=FN/A3\2])UGQ)IGBW2?$?PTTO0+VV\43)=:!JND>(@+8KJ,4.G_E'^UO
M_P`&YO[<6F?M0?%JW_9/T#X/>,?V=OCUXCOY=-\1:JWPX\%0?!SPKXB\;Z5\
M0#X9N/#6LV>H>(/",/@3Q#H6F^&--\3?`BQU'7-?\"Q_V.-/TK0?%_B_P'#_
M`#U7X@\.>(^.\?/-,RG@(91EF)PE#^T:5++,MQ6+JU&LRE6HYE@X5WF&'<:=
M!X7&KV>*E05L/6?MH3_8(Y1QGDW"F#HX/!1Q3S#,:.)G]2K3Q^+I4*5.#P2I
M5<#BIT5@JUZE18C"N]*-5MUJ<?8S7]BW[,OQ#O;?]D[P/\4/C+^T;\*?C;;Z
M?X+UOQ7XC_:=\*Z9I'P[^&?C7P/I&IZY?:5\1M1TJ76=4T;PG*O@:QTR\\=F
MVU5M$LO$EIX@DLH[/2IK:UM_S)^,'P&_:>^-'_!)_P#:4\(^/+JW\%_M)?\`
M!7K]NKX)>*_@9X`\4:9?^"=2\!^`?'7B;]F+P[\//A5\8--LM,LK?PEX@\#_
M`+*'[-VJ7WQ7T2]O]6EOCI&M^%9-;\5^-];ATC5?BO\`X*`_\$X/VAOA#^QY
M^Q/^QE\(OVS?%WCCX=>-_P!I7]FC]FB+X+_&'P[X#TCX/:MXD\23>-=;NM6\
M4>,_AOX`M/CAJ'PUG\?6>FZI:>`=:\4>+;+0]%6*VM&U34/#GA6ZT;]M?^"=
M^K?MB_MV_MU^+_C)^V/\-_@[\-?!7_!,/Q)\1?@I\.='^`WQEOOB!X.\8_MA
M_%#P'IMA\1/&=[);O%>7Z_"S]G#XB+X$7PYXSL]+/AGQ'\7O$!.EWOBZPU.R
M^'?YYPKP3_;7%.18K),WR;'916XIEQ+FCIX:.`S/"9-PQFM''930PF`K8?#M
MX?-,W>&P^;4L#@XX++OJF$C1Q,Z56*CIQWG>+>%PN5X[!U\%5R[+L*FIXAXE
M5L?B\&J-23JTZU>$U1I4YRPU7%5OK52,\1.<%4ERO^D*VMK:RMK>SL[>"TM+
M2"*VM;6VBC@MK:V@C6*"WMX(E2*&"&)%CBBC58XXU5$4*``5-17]FGXP%?@C
M_P`%6K'Q+XN_;T_X)5^"ECO=4^'GAS1/VZOC[XFT-)5BTNQ\9_#;PE^S_P##
M#X<>/+\+>V4\UUX:'[0'BWPUID.-2M/,\>W,]UI$DL%IJVC?O=7XJ_M2>+-'
M\4_\%'K'P?/I-Z?$'P"_9`\!>)-#UAM0BN-/FTK]JOXX?$2R\5:5#I45I=7N
MGWL=Y^QSX)N+F\@FB;58;BTBN=/NAI6EW"?"^)>-_L_@3B6OK>>7O"1Y6TU+
M'UJ6"3NFK<OM^9N]K1=[[/[+P]PBQG&G#M*5N6GF$,9)2CSJ2P$*F-]FX6;G
M[1X=4^2*<I<W+'5IGS/^Q?\`#]]%^+7[=OQ.TW4/$L/@SXH?M-VMMX%\+WFM
M->>"]/3X9_!/X6?#[XG>*_#>D0:UK6GV.H>)_C5HGQ.M?$TT+1WFHS>&]/AU
M&".:Q>U;[W/E$D[WR=YP(449S\@PLN%5ADM@8C.%57'(_"^'Q[^VQ_P3,N)9
M_%WPZ\-_MD?L"2^)_C3\0O%_Q#_9[\"^(K?]L'X7^-/C=\7?%7QH\0^)_'/P
MSU+Q]J'@WQQ\.=*\5_$+Q%I]VWP]TO3]:\/^%&@\4:Z--3P?<VGC7]C/A'\8
M?A7\>_A[X>^+'P7\=>&/B7\./%5O=W/A[QCX3U>QU31M1&FWL^F7D*R)$LL%
M]INH6MWINKZ3>PVVI6FI6MS9ZA:6UY:SP1_Q#Q)@,7&LLT5:AF&68A4,)A,S
MP<G4HSC@\-3PN'I8V,DJV"S*IA</#$5\+C(4L3)SG649P;F?TSDN+H)3P$HU
M\-F-*5;$8K"8N,*5;FQ.(J5Z]7#N<IPQ.!CB*U2E2K86=2E&4/97BTHQ\%_:
MV_9U\(_'0_`_Q3XT^._C_P"!5M^S]\7]%^-W@O6_!.H?!_2K+_A:^A:?>Z1X
M*UW7[KXM_#7X@:)>CPS!KFO#3/#KV\?A_4)=?F?Q%I6LWFFZ%+H_SG^P%IGP
MZ_9L_:;_`&=_V</^"?W[3WQ7^,/P[U[XS?$W6_VYOAO8ZAX7_:2^'U_K%W\"
M?C;J7B'XZ?M$_'ZV^%_C'Q3\#/CCKWQ8\-?"2Q_L*T^*_P`/-"\>Z_8^'?"D
MWPTLH_&%WXDC\T_X+3?LN:_^W+\,?V2/V+/!]_X?T#QM^TE^V+X5\.Z3XV\2
M:+XJUR#P%I7A#X(?'OXH>+O&EGIOAJ1+C4+FR\-^#+S29X-1']C-I^KW]W>2
MZ7'9?\)/HWP9^RM\./VC_P!@']JGX@?LE?!_QUIO_!//]MB[\,Z5\7?A[^RK
M-\5M8^.__!,3]L;P@D=_X1U3XLZ5X3^(-E8?%KP=XD\37?P[UG2/$>I:)XR\
M,?$KPAX+\&:7XD2QU[3]!\7:5:_JWA[B:7"F1Y9QMG6;\187A_#XK&T,93R?
M*\-5R_!X6AB7^_SRM&<\SQV7.KB,9B*\,#@,;++*-"OC<55P.&@JQ^5^(6+P
MV*S+'Y+ALJRJMF%3"X.H\PQ>(Q#Q:G*FG&E@J:M1PU2%&-+D=:K2A6<W^[JU
M*CB_[TZ*_BGO?^#ON;X.WMW\(OVB_P#@GC\2X/V@_A9=7'PX^.T'@/XBZ%8>
M!H?C+X'E?PS\3XO!EC?:;XOO;+PI'XVTO7$\.VEYXM\475OI`LX;CQ%K<R/J
M=R5_7M*O0KTJ5>A7HUJ-:G"K1K4JU.I3JTJD5.G4ISC)QG"<)*4)Q;C*+33:
M:9^%.$TW%PFFG9IQDFFFDTU;1IM)G]K%?F%_P4&_X)5?L_\`[>D_A3XHW/\`
MQ9K]L#X1+H5Y\`?VM?!^D+J'CCX=ZGX4\3Q^,O#FC^+/#AU31=&^+_PPC\0"
M];5OAIXTNC82:?K_`(H7POJWA#6]>NM?7\R?^"_7_!;SXA_\$];WPY^S%^RI
MI7A6Y_:>\6_#FU^,OB_QI\1-$U?5O"OPP^#FJ>,9?ASHU[X8TFUEL+'Q7\2/
M$OBN+4GTRWU+4&T#PUHWAG4;K6[&_N]<T.*+_/2_:%^/GQS_`&N/B5J?QC_:
MD^*_BOXZ?$S6`GVOQ!XSELETRP5=.TC3&M/"W@S1[33?!G@[3&MM$TY1IWAK
M0M.A)@#S&>5Y)7QQ<L.Z<Z&(IPK4ZL'&5&<5.,X3YH24XR7+RN-UNV[M<J6K
MWPRK1J0K4*DJ52E4C*-6+<90G!QG&46G?F3LULDTG?M_H1?LY?M'>+E^-W[0
MG[&?QRUGP#'^UO\`LD:[X:TOXEQ^`=0$'@_XK>!_&/A70/&O@'XP^#?"^I:A
M<^(M&TS6_#'BWP_%XW\,7;ZHOPZ\::DWAT>(=0CN])N[AGQ9_9:UG3/C[;_M
MY?LM0SZ9^T?H_@O5?#GQ)^!R^*[;P%\'/VQ_#T.EW=G8^'_B=J]GHFLR^'?B
M5H*1:/)X$^+&HZ;?2:9/HG@OPKXP@U+P7!I\VD_Q"_\`!*7X[6G[)?[;OPM^
M+5YI6HZ5\*/$6H6OP$^,OB30M+>YM=.T[XT0ZPOPYTNYT^"ZL4O9[SX@>";#
MQ?<P:;%JOB!/"_P]\3ZAI^B:LVFI;5_H>?#;X@>!M?\`&7CGX?:/XBTVZ\?_
M``]M_#5_XU\,`7":UH^A^-+*\N_"6J7%O<6\`&CZ[)I&LPZ1K-A/=Z;J5_HG
MB72&<ZGX<OX=/_C/Q&R"IP3Q)7Q.28>='*<URZ=;ZOR5:F$>#KS6$S'+<3[\
MI/"NM.DX\U2$Z"Q>$="K1KQH58_U;PCG>%XRX3I?VS6IU,\RG,:&#EB75I4\
M96Q"BL1E^/IZ4KXN.&IUDG*G7]LL%B_:4ZL)UHQ^5OVD_P!JB_\`V8O%O_!*
MW]I'XQZ?8_"/1]3_`&P/`_PW^/WAK5_'VC1^%/AIIG[0G[+WQZ\"ZZWC/XDZ
M?IMQX?U#PY\(/'>NZ)KU[KDEMI_A[Q1>>%K%VU;PY:SIJME[U_P<5^`?`</[
M`&K_`+4;>(/`O@']H/\`8\\?_#KXT_LU>/\`QCKMCX:ED\;:1XZ\-S>(_AAI
MU]=7%K)K;?%7P1:>(/#:>#4DEA\0ZC_9R7<#6-O=L/8?B]\(OAY\=_AEXW^#
M7Q:\+6GC+X:?$70KWPUXN\,ZA?ZEIL&M:#JJB*>!-0TF]TC6M.N`T<-Q9:SH
ME_I>K:5=PPZA87UG>6]M<6_\.OQ-_;[\>_"KX;ZKXY\0?'KXO?&_]K"7P-XS
M_8]_X)O_`+0_B+2--\)>-/AC_P`$_O!OQ5UNZ\5?M>^(FU+Q!KUSX@^+/[36
MF:Y=?`3X8_$#3/#]GXNL/#7PRU+QXWQ$N-=T>Z@\2?J'@;F^!SGA3.>&\7EM
M.I0RO%^VQ%.M2CBL!B,-G%3$5:.'E2K>UG)4ZN%K0E3Q"JQE3]G.5:=YQI_D
M_BOE=;!9YE^;4L0I/,L.J4%&2IXBG6RZ.'IU*CLU3BI4\11G%TW!J?/&-%<L
M)5?Z.O!/_!R+^Q9I_@SPE8?&'XKZ%\(/BW8^&-!L_BE\)?&'PS_:&UKQ;\+O
MB-;:5:0^-_AUXIUF/X>Z4FK>(_!/B9-3\-:WJ::7IJ7^IZ9=72V%F)1;QE?Y
MYO\`8.D/\]UI]GJ%RWS7-_J%I:W5_>SMS-=WMU)"9+F[N9"TUS<2$O-,[R-\
MS&BOA*OT1_#>=6I.GQ)XAX>G.I.5/#T<WR"5&A"4FX4:4L1PS7KRITHVA!UZ
MU:LXQ3JU:DW*<ODUG^,22>$RV3LKR=+$*4G97;Y<1&-WJWRQ4;VLDM#^K_\`
MX.EE5O\`@J!XI+*I*?\`!+CX,LA(!*L?VW=60LI/*L49ER,':S+T)!_E7HHK
M^K,9_&?^&/Y'SV&_A+UE^9]`WDLFG?\`!.[XR>*=/D>P\3:/_P`%`/V4[32/
M$5F[6NNZ5:Z=^SG^U3KNGVVFZO`4U"QM['6[V\UBSAM;B*.UU6[N=0@5+N>6
M9_[U-"U75+3_`(+0^*=!M=2O[;0]=_X)E>'=:UO1K>\N(=*UC6?#/[7WQ%T_
MPWJVJZ='(MGJ&I^'[#Q3XGL=$O[N&:ZTFS\1Z];6$MO#J^H)<%%?A?C?_`RO
M_LF\^_\`4[AH_5?"K_><Q_[&F5_^F\T/NS]J[5]6\._LP?M&^(_#^IZCH7B'
M0_V>/BQKNBZ[HU[<Z7K.CZWIW@77;W3]9TO5+*6"^T_5;"\ABN[+4;2>&[M;
MF*.>":.5%<?Y['_!4VPL=$_:MN?#&C65II'AKP;\,?AOX4\(>'M,MH;#0_"G
MA:PTJYU"Q\->&])M4BL-#T"SO]6U6^M-&TNWM=.M[S4]0N8;9)KVY>0HKQ?H
M\_\`(OXO_P"OV0_^DYH=OBY_O7#G_7C,_P`L`?G+1117]"'Y(?_9````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V%V871A<G,O8G5N;GDN9VEF````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,C$V,P`Q,#4Q-30S,S<V-P`P,C0R,S4`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````1TE&.#EA(``@`/<`````````,P``9@``
MF0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9
M``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_
MF0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F
M`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,
MF3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S
M`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9
MF6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD`
M`)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEF
MF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_
M`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPS
MF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,
M`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`
MF?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9
M`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__
MF?__S/____B_)```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"'Y!`$``-@`
M+``````@`"````C^`+$)'$BPH,&#"!,6),&PH<*'`AFNL!*H8B`K)"`B9$CQ
MHI6/(#-J)$@"I$F3*Y!H;,CQI,67*T0>E-BQXL>7K'+J9%5QQ<R:.RONO$:T
M*%%6&!<*U7DTI]&G.@/Y)*DG$*MKK%:L8&7MY=*@/1=Z2G:5IU8K/*4"(+'"
MJU2&!@%\(COTZ$4`$5G*C/NIE+5KUIS:E3IR((D]5[$*YIEVK\:V=7-:31NS
M,+:VDW4*2IS62DS'"=EZ33S89F6(2#`+-BKY)6B#)(0^-1HXZ-2-%$G/#OS5
M;&C9NW?R%`1-\FMLL:T&7RV<\$_E4'47C9KTH.JGT&>WOET0P/6BV6=18[UX
M_#O1S>*G]SR>NRAOZ>HS<Q^8NZO0R=,Y9V?EN&/:M!8YQ<HJ?S$V'5[T*6=@
M>N/]-]U>D/V7F7"M7;153O,!H.&&'';H(0!(D+"60`$!`#L`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]C:&%R;&EE7V)R;W=N
M+F=I9@```````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,3`Q`#$P-3$U-#,S-S<P`#`R-3<P
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!'
M248X.6$@`"``]P`````````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,
M`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS
M`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,
M,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS
M,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,
M,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S
M9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,
M9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,S
MF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,
MF9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``S
MS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,
MS&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\S
MS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,
M_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS
M_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````(?D$`0``V``L`````"``(```"/X`L0D<2)`@@(,(
MG2A<J!!`08,((S*<Z"2APX?8`%#<R%!CPXL//7*D*/(CQI(C%Z*LB#'C1!(P
M8\I<";*@3)@I:6(DP?&FSY@L'_[\^:RH4:,D:F(#JO!F45(*CTI]!A*G$YE0
M2>79NI44J:E'03;EZ37K5[!HJ0Z$*1``6"=GGSE)J[:@6Z-GYQZ%FE9I1J-S
M->*]RW<J0KM%X5+5^XP48<9329$8>#!QWJ]QY=*5W-8QX+R*G])M/#FCY]&H
MGY4V?3<U6LX07:=U'%(V6K]M;1MNV1KPQXB[6_Z5J]!KY-ZTA0^7[1@WXM3-
MV2!Q'GOV03;2IRN'>+!L<P#8I1]CU[[=+L+PX\.3+]\6B?OIZM%+IV[W_7OP
M2.3/QQ80`#L`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]A=F%T87)S+V-L;W=N+FIP9P``````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,C,T,3(`,3`U,34T,S,W-S``,#(T,C,Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````/_8_^``$$I&248``0(!`,@`R```_\``
M$0@`O@"6`P$1``(1`0,1`?_;`(0`!@0%!@4$!@8%!@<'!@@*$0L*"0D*%0\0
M#!$9%AH:&!88%QL?*"$;'24>%Q@B+R,E*2HL+2P;(3$T,"LT*"LL*P$'!P<*
M"0H4"PL4*QP8'!PK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M*RLK*RLK*RLK*RLK*RLK_\0!H@```04!`0$!`0$```````````$"`P0%!@<(
M"0H+$``"`0,#`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C
M0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-45597
M6%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJ
MLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X
M^?H!``,!`0$!`0$!`0$````````!`@,$!08'"`D*"Q$``@$"!`0#!`<%!`0`
M`0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E
M\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W
M>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'
MR,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#Z
MIH`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*
M`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`
MH`*`"@`H`*`"@`H`1W5%+.P50,DDX`H&DV[(\Z\3_&'POH.H+9M</>2#(D-L
M-PC([$URU,93@[;GO83AS&8B'/;E]3)_X7WX7_YXWW_?NL_K],ZO]4L9W0?\
M+Z\+_P#/&^_[]T?7Z8?ZI8SNC6\/_&+PIJZW)DNS8F''%R-N\>HJX8RE+K8Y
M<3PWC:+5H\U^QU6B^+-"UJ.9]-U.VF6(A7(<#!/3^5;PK0ELSS:^7XF@TJD&
MKFBVIV"C)O+<#I_K!5<\>Y@L/5>T7]QP'Q2TS5/%"V5OX>\276AFVD,DDT'_
M`"UXX'O7!4S",96@K^9O#!2<>:1R>FV/Q+\'Q&;2==A\71`222V-^-DC'`QL
M?KGCI]:=/,(MVDB:F$<5=,Z+X4?&;2/'-Q)I=W"^D^((%)EM)S@,1][:3UQZ
M'FN]--7.6SO8])_M*Q_Y_+?_`+^"ES1[FGL*O\K^X/[2L?\`G\M_^_@HYH]P
M]A5_E?W!_:5C_P`_EO\`]_!1S1[A["K_`"O[@_M*Q_Y_+?\`[^"CFCW#V%7^
M5_<']I6/_/Y;_P#?P4<T>X>PJ?RO[B2"\MKARD%Q%(X&2J."0*:DGL3*E.*O
M)6)Z9`4`%`'@G[3?B#4[,:=I-I<&&QN49Y@APSD$8!/I7FX^I)6BMC[;A+!T
M:G-6DKR3T/GBO*/OK!0`4`)0!)'++$#Y4CIGJ%8C-.[1,H1>ZN=M\']"N_$_
MCJ"6Y><Z'H_[^Y<DE)IOX8\UTP2C2<I;O;T/B.),QJ1Q$<)A7;E7O-=6^GHC
MZ3=S([.W5CG'I[5RGBI)*R$!((()!'((ZB@9XO\`M"^!!<V7_";^';=XM=LG
M!OH[9?\`7Q_\]<#N.]>AA:O,O92>C.%N6%K1K0Z.Z_R/((M0EN88[B&YE,<J
M[N'/![UPR4H2<'T/UFE.CB:<<136DU?Y]1WVJX_Y^)O^^S2YF:>RAV#[5<?\
M_$W_`'V:.9A[*'8/M5Q_S\3?]]FCF8>RAV#[5<?\_$W_`'V:.9A[*'8TO#GB
M/4_#^L0:EI]U(MQ$>C,2''=3[5=.K*$N9,YL7@*.)I.E-:,^POASXMA\9^&H
M=4AA>!R2DL;?PN.N#W%>[0JJK#F/RC-,OE@:[I-W['45L><%`'SA^U/_`,AG
M1?\`KB_\Q7E9C\2/T#@[^%4]4>&5YI]J%`!0`4`.BBGN)8X+--]U*P2%?5CT
M/X=3["JA%2=GMU.7&8AX>A*I'XK:>O3[M_1'U3X!\.Q>$_"%CH\1!9!YL[!L
MAY6Y9A^-76J<\KGYA2@TW.6[.@K(V$H`?&P5_F&58%'']Y3U%--ID5(*<6CY
M"\9:+%X1\>:KX;B9&M]_VJU*MG:K?P'WKJQ$7."K?)GT7">8))X"??FB_P`U
M_D9Y!'45R7/M&FMPH`*`"@`H`^K?V;#_`,6Z7_KX?^=>U@?X7S/S#BO_`'[_
M`+=1ZK7:?,A0!\X?M3_\AG1?^N3_`,Q7E9C\2/O^#OX53U1X8.>G/TKS3[5:
M[$<CS`-]ELKJ]="%80(6"GT)]?:JC&+^.2CZGDYAG6'P4G3:<YKHNGJ^_D0V
M5Z+JYFM7@DMKR$X:"7AJNK1=.*FG>+ZHK*LXHYC*5."Y9K[+ZKN2Z=%J>NZN
M^G^&;1+R2%"T\C\*OXU-5T,-257%2Y4WIW/,S#B&=/$?5\%%3Y?B;VOV1Z!\
M#O#=]>?$*ZN=:M(2FC1`9BDXBG?H#[X#?G6\:E+ZNIT6[2?7LOT/F<PS"OCZ
MR6(27(MEM=_J>_\`B76+;P]X;U36K]L6]G"6'&=TA'RC'UQ6-*#G)1..O4Y(
MZ'%?`3Q=J?C3P3?7^MLDEY;7OEK(J[=R-T!'MVK?%T8TY)1.?"U92E9GHC'"
ML?09KD/06YY]XO\`B$?"_P`6]&\,WT=N-%U"!"]PYVR12-G!W=-O3C'XUV0P
MZG2<EN>:\3-5#+_:*\$IK?AMM5M+=6U;33N,L2GS)HNX&.O'2C"U>67(]F:5
M8WBJD-'OYGBTVAZ;;:#IWB/0[Z^;1II##?K<)O:V;L>.V>,UYT<76G7GA*\5
M[1*\;:7_`*W/;R_,IX.4:T)-TY.TKZV\_D4+N>*VC\PL9%;_`%2Q_,9?0**W
MIPE-VV[^7J?=XO&4<+2]M-W36EM7+T+J:#XJGL%O[;0V6UP6:.5OWI`ZX%8O
M&8",_92J^]Y;'S<^(\5)J=&@E#JGO\C-T^]AOH6DC)C9"1)&_6/'K735HRI.
MSU[>9[V79G0Q])U:;M;=/[/KY"6>HV=Y(T=O."ZG[K<%OIZT5*%6FKR6@8/-
ML%C)N%"I=KH]+^G<^P?V?-.N].^'EN+R,1F:1I8QG)*D\9KU\%%JEJ?G?$U:
M%3'-1Z*S]3TNNL^>"@#Y.^/?B2X\9_$:#PYX.L5O+S3D*3W)8&/)Y(ST&.E>
M5F=3#T8>UQ$K17WL^CR3-L1@H2AAXIR;Z[)&-HWPTU>XLM^NZA:V=TS8,,(R
MT:>H/0DU\EB,^P\)VP\')=WU9]9A\XQ=:C+VZM)_"XZ6/2-%TVST33HK'3(1
M#;1^O+.>[,>Y-?.8G$5,14=2J[M_U9'GX?#1I0Y7J^K[LY[QS\/M/\7`W1+V
M6K*FV.[B&`Y[;_45Z&69W6P'N?%"^J?3T.7%X&,WSTW:7=$'A_0+#X8^"=1N
M)YF:X,9:[NU_C;^%4'IFM,7C:N<XR$8K2_NKMW;,,/AZ>"HN<WK:Y;^!*?\`
M"+^$+WQ%XRU/["OB"\5XC<J<\`[6/^]D_P#?-?;UZ:]VE26D4>'1J/6<M6V5
M?BU\6_!FM>`?$&A:7>W-Q?3[5B81$)(01R#Z5KA\+4A-2:,Z]=3^XJ?LW^+/
M"GA[P5=Z;J?B&*VU&XF^TR1SKM2-5XVJ>Y-/&4ISE=(G#34&I7Z'NMQ=6T.G
MR7L]Q%%9+%YK7#MA`A&0V?0Y'YUYW*V[+<]/VD4E(^5_VE=?T;6OB/I5[H^I
M0:A:16L0DDMVR%PV2/KBO9PL'&FTSQJC]ZY[=IWQB\`ZTWV%=8ELR+55,ES$
M54X7D#WK@GA:B?-8[*>(2CR[F%X3\*CPYIL]A#?6VL^&[XF:Q8Q\R1/RP?UZ
MU\EQ')?6HU(IQE;?T[>G4]K*J?-0E">URIX:\":/X=U66>.2.<AR]C;7#`M;
M9]CU]JX<9G&(Q=)1:MI[S77^NIZM&4:6'CA4]$[W]>B[(ZUF<.2Q8/WS7DI*
MVALDK:;'EGQ"\!#5/$NFR:%!+;G4F9=4:(`1H@Q\_L3S]:^IRG.?8X::Q#3Y
M/@OO?MZ'C8BE6IUG&@[*HK2\T7_$GPPT:3P6VGZ)`RZC8JTMK=$XDF;J0Y]#
M7/A.(,2L9[6N_=EHUT2\A5LL4**]GI);=[GK?[//C_2O$'@C3=,EN8;?6K-#
M#-:22#>VS@N!Z&OTF$8J*Y=CY>M6J5:CG5=Y/<]='(JC(\V^,GQ2MOA]:P6T
M5E<7NM7T;&QA1,HS`X^8]AS4RE&$7*3LD.,7)V6YY=\/]*NM*T*:34[>"#5]
M1G>YO#".6+'(!],9Z5^79[CXXW%NI!WBM%V^1]IE>$]A27,M3HP!Z5XYZ90U
MO4CIEG')'`UQ<33);P1C@&1CA=Q[+GJ:[<OP,L;75).VEV_);G+C,2J%/FM<
MJZ5\+=;N[L7OB[Q?=EY06FL-,^5$8]`KGC`K[FGA\!1BHPI)V[[OS/FG4QE1
MWY[7_KU,[5?@7>:M;&VU'Q[?7%J'W)%);L0/3/J:WHRPU"7/2I),RJPQ-1<L
MY77JCUG1M*AT[0--TJ817R6,"P+)<1!]VW.&P>AYK.563FY(UCAHN'++N><_
M'3P1X:E^&VNZM!H=M;:I:LLL=Q:)M9F)YW#IM]JZL+7FYJ+9S8FA&&W89\%_
M!GA35?A1H%[JGAO3;V[D:3?-*IW,03R33Q5><9M)DX>A&IOT1Z;J.E:?JFF?
MV9J5G'<Z:0H-JQ(0A?NCCL/2N*-249<RW.Z=&,H\NQ\_?M,^$]!T;3?"BZ#H
MUGI8NIG6:2W0^P&?7UKU,'6E._,]D>;7I*$G%=SV3P_\//"NAZ?I,::#IMS>
MVMO&PO9(LL[$9W%3W^M<53$U&]&=-'#0G'F8OCKPYJGB'3XK+1M:@T.`#YV2
MV+-UR-F/NCUKG=/#U6GB(\UGH;R]O3TH:(Y'4O@9H=_9F1=:UD>(R`W]JS2[
ME9QWV#D"NFG7IPBJ<8)1[&$Z%9MU'*[_`*^1Q7@+Q;JUOXMNO!GBJ.:;4(9'
M$%TRX9@.?G'H0,@U\[GN2TJ5+ZWA](]5_D>GEV8S=3V577S/3<G!&3@]1ZU\
MD?1!DYR#S0!Y]\3/!-E?:7=:SHUL;+7K4&</:@@W..2&`[\=J^BR/.JV'K1I
M5)7IO37H>)F.60G!S@M3Z6^'>IW6L^!M"U&_"B[N;2.24*I`W$<\'I7Z4U9G
MR*=SC/BY>Z):^)-"2^N;6#5IHY$MO-&&*\;AN["OD>*J>)G3C[--P6]OPT/>
MR2K2IRES[O8YQ61QF.2.1?[T;;E/T-?`M-;JQ]3"<9KFCL*:"B?3M2L=+U"W
MGU.XCMX)'$*R2'"[VX4$]N:]7);_`%I65]'L<68R4:#OW.WN6CM%EDOIH[6"
M%2\LTS;411WSTK[*,'*7*CPI58QASF#X)\0OXJT:;5AITMA8M<M%9><?GN8A
M_P`M2.P/:KK4E3=KW9E0K2FVFM#>K$Z1)426&6&50\4J%)$89#*>H/M33MJ*
M45+<@TG3K/2]-CLM-A@LM/@R508CCCSU]J<I.3O)DJ,8;+7R(Y=8TB*[@M9=
M:TQ;B<L(D%RIW%<;@3VQD5?L:EKV.>.-I2=HO874M,TW7[![2\CL=5M(I!(\
M2.LPC<="1V-)<\'=:%JI2JO_`#+F<A?0*%'L!T%9FZBHJR#:6!5657(.PM]W
M=VS[9IJU]13<E%N.YQ'@WQ\FJ^()O#'B*R.A>+8&(%J[9@N0.AB8\Y(]:ZJN
M'M'GAJCCIXIWM,\I^-]E+:?&[P\VBQ+'J5PJ-,D#@2-S\V_'^R#^%*MR?4*J
MK[)=>_3\25?V\73[GI[XWMCIFOS!;'VJO81?F8`$9/2GL-Z&9X&DU#QI\0I[
M'3MUGX?T5Q]NF9,M=R=HU)'R@>W-?;Y+P[2G05?$:N6J2Z+]3YC,,VJQJNG3
MTL?1(```'05]HM#YXY7Q]X`\/>/+2V@\26/V@6[[XG1BCKZC<.<'THN!\RS:
MR/A)XTOO!NO,\WA_S/.L+E02\"-R`?4=C7RV?\/3Q3^LT%:?;I+_`()[679B
MZ%H5-NC(_%OQ;MX;=H?!<#ZE=>67EN9(CM@'J!W->9E?".(Q$F\2FDNBW?KY
M'=BLWNK45?\`(O6.NZ!X^^&LLOB2]2U$*@WQC.&AD'W74=\^E<53"8O*\Q2P
ML>:[]WS75/T&J]/%X1^TW1F_#(>+_B.;'P[X@NKJ7P+I\PGDGEBP;A%^Y&6[
M@^E?<5)1I0YEI)].S/`C%U)66OZGTL[!F&U0B*`J(HP$4=`*\IN[N>M""A'E
M0VD45=9U&+1M$O=5N(6N(K50?)4X+L>GX4I2Y5S&^%PTL5B(8>#LY=>QXGK_
M`(IUOQ';+!K%TIM=WF+!"-H'HIQU`KS*N)E+2Y^@X/*<'@I.5"/O6M=_F<5>
M>%-&NP/,M61@Q;<CD')ZUM3S/%0VE<Y,3P_@:ZM*"6O33<Q=6&I>`;BWUWP;
M?7=GA@LZ^86!/;(/4'WKULNQSQ4G2KZOH?(\0Y'#`P5;#JT=FOU/J/X=>)$\
M7>"-,UH7"3W4JE+UE7:!..HQVXI8BG[.;1XV%J<T;'1'D8/0\5@=1Q'Q0^&]
MIX\:QNCJ$NE:_8+MM;Q!PXZJK=Q@]ZZZ&)=/1ZHX:^'O[\#PWP+]O\,?%J^T
M[Q]#*=?NU\N&^N'R`>S!CU#`8!]ZXN(Z,Z^"4Z#]V+NUW_X;<O+*D:=?W];G
MH?Q%\5_\(?HT-Q%"EQJ5S+Y=M;."1(!]X\>E?)Y+E4LSQ'LE?E2U:W\D>_F&
M.]A%<NK9Q-K\3/&6J1RQ:;X<MK:XW+&L[@CRF)P#@]:^RI^'[Y95).3C'==S
MSJ>,QF(O"G#7S/I[X1^#Y_!OA<VVH7QO]3NY6NKNXQ@-(W8>PKZ"E"-.G&G!
M6BEH?.5)2E-RENSMJLD*`/FCXSQQR_$2Z$T,,VV%=OFH&Q]*_0\CH4ZF`BY*
M^K/>P3O05U?U.-A2.`L;>""$N,-Y<8&\>A]17KQPU*-[(ZU*WPI+T1Q=WX4M
M_$?C+3_#/ANWAMKFX)ENI//^7:.3D>W7'6OS_B2.%PLDJ<=5K]_0\K%0I\ZI
MTU;OJ?5Y?3O!G@Q!+*+71=+B"_,_R@^QX))].M?!^_5EIU-ER4EKN>8:G\>=
M,6]/]AZ-J.JZ:H&Z[CB90#W&".U;?5E'2<TGVN5"56HN>E3E)+JD['>^#/'G
MA[QG)<IX?OO/DMPI>-T*/@CJ%;!(!XSTK*K0G3^)!3K1GLS1\9Z8^L>$M0M(
M(VENU'F0(K;>1U^OTKFJQYH-'JY7BEA<;"K-VCL_ZZ>IX';S)/"'C=6`.QBI
MZ,.H^M>/4A*$G&2LS]%A5IU%S4Y)KNG<DJ2SC/B/<O=16F@V5O-<7]W(K(D:
MDD\\`>I->YDM!\[KMZ+0^*XNQT/9K"I>\]3ZE\`:"GAGP1HND+:I:SQ0A[J)
M6W?OCU)/K6]>ISS;/D\+#EBV>;^.OC!=6VOW_ASPCIZW&IVQ:.6XN#L1#C!P
M#R2&S[5I[.G2IJK6=DS>C2K8RJZ.'5VO.QB?#GXOWVCWT/ASXAAWDFE'E:FQ
M&%4]GQP1GN*T=*G7A[6@].QE6A7P57V6(5F=Q\<O`5CXP\-2ZF;HP:GIL!EM
MKH-N22,#=MX['L1FHPM9TY<K6C,:U)37/%GA7@>ZN=?C76-:N);V\M`+>V,O
MW85`Z@=V]Z_0^$<FPE"$JU.-FY'1A)RK+VM1W:T7E_P3K;F65HRYD=I$^9#W
M!['WK[J$8IVMHSM<G+23N?4_P_U!]3\(:9<S727,YB`DD7'WN^0.AK\NS2@J
M.*G",;*^A\YB(<E1I*QT->>8A0!\U?&4$?$2[SCF%3P:_2.'W_L$?5GNX+^"
MO4XBYF6VMIKAU+K"A<J.^*]2O4]G3<^R.IM13D^AM_LOV$NH2>(_%=TZNUQ(
M+:-&7+)_%D-Z8XK\6SK%RQ%5REU/+PS=2HYOJ5?C[&NH_%C2=,N'>6R-@LCV
MX8[<^I%>?.K*C@Y5(.SN=V48>GBLP5.JKQU(=-TJ[GMY5TG3)[F"W7]Y]G7(
MC'O7@0HU:]Y+6Q^GN>&PRC3G)0OLGU.:.DMI5[;ZUX5)MM2@F\TF)BIE7^)/
M;-=^&S&<9>SQ#]VUO3S/G<XX<A*FYX6*4[W]?+YGT1\.O&=KXUT(ZE9Q&SNK
M>3RKFS9RSP,.[$^M=M:ER--:I]3XJE4;;I5/B6Z_0Y?QW\*5UG5+K5_"^IMH
MVJW.#/$!F&4]V*]C1STYI1K1YDOO-Z57$85N5";5SE#\&O&P!*^+[0GMF&E[
M/!?\^S;^ULR_Y^_@=7X8^#6D:1XFL-=OM0O-5U*WPP28Y5I!T('H.PJ_K'+#
MV=.-EY')5A.M4=6M*[[LD^.GQ'M?!VD3Z;;7+MXIOE_=1P/\UJ#_`!N1W]!5
MX;#N<N:6R,*U=)<D/E_7]7/(/!^@/8PPA8)+K6;UAO53N>1SVSZ>]>3B\1/&
M5N2'PK8_2,ERREE^&]I4LI6O)OH;GQ8^'UUIL%O::J8)+N2+SK2:/C#CJA']
M>];QC4RZLM='N<E=87B#"SE1B^:#TO\`@_GV/;/AU?WNJ>`M&GUO3_L=X(/(
MEMF3`*KP&QZ$5U5U%3O%W1\+AE*TH25FG^)\Z^+?#\7PZ^*W]GQW[R:9JL?V
MA(P.4W$[58>Q[U]GPMF#C649.R>GE?H9T)*E7Y;Z,W&!!(/45^G(]1JQ]`_`
M7_D0X_\`KL_\Z^`XG_WY^B/&S#^-\CT:OG3A"@#Y)\4%CXKUHL[N?M3<N<GZ
M5^L8*WU6G9?9/I*7\./H<[XBE,/A_47$4DQ\DKLCZ\CK]!6>83Y,/-VOIT"J
M[4I.U]#V3X#F)OA!X<\GRLA)!)Y>,YW_`,7O7X;B_P"*SAP7PLP_V@?#5U>Z
M?IGB?1K027>CL3J$D9Q*UOVP.X'-512JTY49=5^)I"L\)BH5UHD^G;J6/@)X
MEAAUU[>.X@73-43S(VD."T@Z`?X5R954E1K.C4TZ/]#Z_B6A#'X"&+HWDX]O
MY7W.K^)?PQ6ZDFU?PU&L=TV6GM%X64_WE]&_G77F.6*:YZ:U['GY#Q0Z:6&Q
MCO'I+JO)^1Y9X0UF;PEK\]Y!;*8[DA-1M6&#(!_%_O"O$I8F=->SD]%_5CZC
M'9)A,;!R22F]5)?D_(Z"\^-^F:=K5Y!J.A7ZZ*J_Z!>1+EYV[JX[>U>Q2ITZ
MT?<EKU78^`QN$QV"J-5H_-:KY#1\?_"&1NTS60N1D^7T'K6GU.7=''[>M_*_
MN,7Q%\7?$>M07.G^$-#?2(YFQ%J]RV)%B]0.S&LY5<+05Y2YFNB.ZCE&88J2
MBX<J?5[?UY'':)X87[;)<3B?6M9F?S'N9`7;=7FU\=7Q+Y8>['LC[++\APN`
MC[2LTY=W^A]"_#SPC#X*LKCQ+XHN(X;H0D!#C;;IUQ[L?_K5Z^!PD<)!U:NC
M/G\[SB6:U(X'!1O&_P#X$_\`)'B/QA\72:C>7GB*S0PH72.&*<YW(#U`[$UP
M1E'&XSE:T_(]RLJN1Y4H0:<HN[^?3S/HC39S=:+I-PP(:6RB?![9'2M)1Y7R
M]CXNE4]I>=K7=_O/#?VEVTO^W/!R((O[=\\F4C[_`)&?DS[=<5]!P[S?6H=N
M8XZO\>-N_P#PYDR_ZQZ_98['KRW/?_@(RGP*BAE+"9\KGD<]Z^"XH3^NM^2/
M$S#^+\CT>OG#A$9@JEF("@9)/:A*^B`^2?$S*WBG661E93<MAE((/T(ZU^LX
M--8:FG_*?24OX<?0R[B'[1;3P;RGFH4W#J,BKKT_:4W'NB[<R<>Z-#]E?7X;
M:36O"<QQ.)3<P$@[I,<,,=L#FOQ3-L.X5'Y.QY&%DHR<6>_WEI!J-A=V%[N^
MRWD+0R[6VG!'KVKR8RY7<[:T.>-D?*&G6-_X+\577A77%:-XY?-T]C\RN,Y!
M5AC/_P"NGF5%3BL32^9[_"^9^SD\'5>CV_5?\.CZ>^'WQ-@UB5-.UI([.["`
M1R[ODE('.2?NGV^O-=F!S2%;W)Z.QQ9WPQ/#1=;#OFC?5=5V]?ZT-#Q#\--%
MUA+ZZ@WQZA=`NDX;*ANQQZ5I7RNC53DMV<V!XFQ>&<*<M81TMY'D^I?#?Q38
M311?81>EEW&2W8,JD=OFQS7A5<IQ$'HK^A]I1XCRRO%R<N6SV:U_"Y4'@+Q2
M3C^Q)\?\`_QK+^S<5_*S7^V\K_Y^K\?\C3TOX7>)M2M3++%%9'S-ICN7^;'=
M@!D5T4LFKRU:2.;$<4Y?0GRIN6G1:>FMCU_0_#^A>`])FNV98MJ`SW,IY;`[
M?X"O?H86C@X<WXGPN+S#&YQ65-:ZZ)?U^)XE\1O&D_BR].XF#1X#NB@8X!Q_
M&_O[=J^>Q^82Q$^6&W0_0<FRBEE5%RD_?:U?;R7D<3\-M"3XD>/X[RX@\[PM
MHQS/ODVB5_X?E')R?T[UZ.&H_4Z'O?'+\#XG.\R_M'$)4O@CHO-]SZ;52S*D
M:``?*B(,!1V`%8;LP24(GRQ\7]7LO%_QDL(]$?S%TV)89Y64JI9"=V._'3G%
M?7<-X6I*O!+O?Y'GQ7M,0N7N:[G+DCH37ZPEH>PW=GJ_[/-Q;Q7^L6[RA;J7
M:ZQDGYE'<#I7RO%<)N%.:6B/-S%-J+Z'M]?$GDB.H=2K`%2,$'O33:=T!\C>
M(!$GB36([8*L,=TRA5&`OMBOUG"N3P]-RW<4?2T[\D;]BC6Y1@ZQ8W>GW\?B
M3PW<-9ZW9?O-T?\`RV`ZC'<_SKYC/\FIXFFZL5[WY_\`!.3$X?G3J0W7XGK?
MPH^,5EXUOWT?7+:'1O$&?W*9(BN?5>?NO[=Z_+L5@947L<E'%-.T_P#ACI_B
M9X'A\<:9;6LER=-U.RD\RWN]F70_W3[5RTJG)>,E=/='5*+NJE-V:=TT>!:E
M>ZQX<U"YT_Q=H]Q`;?`DO8(R864\!\CL>/SKFJY3=<^'E?R>Y]1@.+;-0Q<;
M>:V.M\*?%:\T_3W&EZY"]L[<)=GF,^@!Z"IC5QV&]RS_`#.VK2R7,DJTFEZ.
MWWG8:%\;=02%H)DL=3N2VY6CD"D#TP*WAFN(IQ_>1^;.*IPUEN)J?[/5Y=-M
MS4_X73J.,_V)#CU\PT_[=EV0UP5AWM6?W&;K/QDUBXBB-E%::>(SNE=V#!AZ
M<]*SJ9Q6G905CHH\(X+#J4J\G)6]+'F7B'Q_>ZU<72K)J.NR%UDDALT+11GH
M.>@J5A<9B?>J/E3[_P"0JF<97EMJ>&C>273>WFS?T;X4>(_%>F2'Q9,_A^WW
MX%I;+O:91U+'^5=%&C0PLN:'O/N^GH?/8[.<5F$/9R]V/5)[GL7A'PAIG@S1
MAINA6;06TC!W+-NDE;'5N]*M6E-\TV>?15..D7JC%^)?BA=$TJ?3M/:.;7;I
M-B1[N+=3P9"1T('3WKV\CX?Q6:?OH>[23^)]?)?YFCC*JO=V/#M$TB#2;81Q
MD2W!SYER1\TI)SS7ZU@,OIX.FH16O<UI48THV7WFC7>:'?\`P*_Y'V3_`*]6
MKP.)O]Q7^(X\?_!^9]$U^>GB!0!YA\4OAQ'K8?5]#5(-81<R(!A;H>A_VO0U
M]-DF>O#6H5]8/\/^`=^$QCA[D]OR/!7W1N\<\;PRH2KQR#!4CJ*^[5FKQ=T>
MQOL`D4$$,,BG9CU,[4]'TK5)FGO82+L@8N86VNA'1A[UY>+RC#XF[G'6QG4H
M4ZKO46O='9>%/B!XHT9EM==N[;7M)C/RS$;;LKV4U\E/@6-6<K5&M-/7S\CG
MIX.5.3][3IW^:/1+7XB^&]3BBL+F9=ER,26]Q&"@[[6)^E?/U^$,VP\93Y5)
M1ZK=^:*EA[ZM$5]X!^'_`(JN7U671;.ZE<;6DLY-B''^R.]>+4EBL++V55.+
M[,YI8./-_F<_K7P(\&:AJ$5WI\E_HFQ-IBM6W!C_`'LGH:E8V=K25_4GZK.#
M3INS[IV$T[X'Z+87$+P>(]9:%)`[P.`5EQ_"3V!XK.I5I5/BIJYV4,3F%"RI
MU&E>_<V_&?A3X?6/AJZOO$FFBVTF(C>RS$,S=E7U/M48:'+43IK4VS#,L9B*
M7LJ]6Z_K<\\TSXTVNG:=)IGPZ\&?9(-WE6EPR@(_^U(>Y[]:]ZADN+Q<HR2N
MGU/'I4G+2$6[_<9-WXW^)VJZD]VVM6NB!`H2WC`*,0,$]^M>YAN#JLHOGT:.
ME8&M+XK(9X=N-7T6XOKV'7[RZU+4%*7D\IRI!Y.P=C[U])A.%L!2477I\[6J
MO_6QU4L+3IZO5BHNTL2SR.WWI)&W,WU-?2Z)62LET6QT-CJ!",RJI9B`!W--
M*^P'KOP,\+:A'J#^(KH?9[22(QPQ,/FD'][V%?(\2YC1=/ZK#62=V^WD>;CZ
M\7'V:W/;*^+/*"@`H`PM:\):'K5U'<:EI\,TZ`@/C!Y]<=:[L-F6)P\7"E-I
M,VIUZD%:+*'_``KOPM_T"8?S-=']MX[_`)^,OZW6_F#_`(5WX6_Z!,/YFC^V
M\=_S\8?6ZW\P?\*[\+?]`F'\S1_;F._Y^,/K=;^81OAUX692K:3"5/4'-"SS
M'+7VC#ZW6_F.1\;_``WO=-ELM>^&9CL=9L%V&PD;_1[V(GE6'0-[UYN/K5,=
MKB'S-=>I+Q-233D[FGX4'BG4S(FO^&XM(:.(-O6\6997[@`#Y1]:\2IE\U\+
MN==/'1^TCH4T>[+@,%52>2&Y%9?4:W8VEC:26AXWX@^&_BWXE>/((_&MJ=*\
M'68;[-;VETK$D="W');N>U>IA\.J2\SS*E5S9Z[;_#CPK;VD5K!I$$<$2!%1
M<@8_QKV*.:8JE%1A.R1I'%UHQ45+1"_\*Z\+?]`F'\S6W]N8[_GXP^MUNYEZ
MU\)_#VHS0/`DMB(P0RP'`?ZYKJP_$>+I)J7O7[FD,=5BM=2A_P`*8T/_`)_+
MW_OH5O\`ZTXG^5%_VC4[!_PIC0_^?R]_[Z%'^M.)_E0?VC4[%S2/A'X?L+X7
M$QFO%`XBG.5!]:QK\2XNK#DC:/FB)X^I)66AZ%&BQHJ(H5%&``.`*^?;;=V<
M3=QU(`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"
M@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`
M*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@
M`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*
M`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@#_]D`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A
M=F%T87)S+V-O8VMY+FIP9P``````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<V
M-C$`,3`U,34T,S,W-S``,#(T,C(W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````/_8_^``$$I&248``0$```$``0``_]L`0P`!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``
M$0@`,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$!08'
M"`D*"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R
M@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*
M4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2E
MIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S
M]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41
M``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC
M,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:
M8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*S
MM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:
M``P#`0`"$0,1`#\`_@OHHHK^R#Y\_:[_`((&_M+V?P1_X*`>!O@]X]N)]3^`
M/[:^G7_[)'QH\!71U6^\.>,$^+D,OAKX;#4="T\2PSZBGQ#U'1?#$6OS0QSZ
M!X3\:>.(4U'3M,UG67F_=K]EC]A3QK=_MA?\$,?`NHVTUOXF_9)^$7[7WB[X
MT:C>R1WOB#2/`OP+_:F^)FC?#(ZB+.XET;^SO%'Q"\6Z5H'A^UT[5KIK&PU3
MQ!=PQWMGH217?D/_``0&_P"#:_QW^U+I'P=_X*!?M3_$#QG\"_@]:>*]!^)7
MP`^'G@BRL=-^,'Q0;P5X@@UCPS\2=5UGQ3I.KZ9\/_AGJ'B#1K2X\,+_`,(W
MK/BCXE^&UN/$F@W/@SPSJ'@OQGXJ_MVU+_@G9<:+XZUWXO\`PD_:C^-GA?XK
MZSX1\.^#KR?XF:3\,/C+\./$6B^$-=\8^(O#&C>,O#%[X*\(_$9?#NF:K\0/
M%MW)I?PI^,OP@O\`4I;^R74=;N+?1M+M[;_&_P"F_P#1^\4N./$KC/Q"^CIF
MG`V&S;B_PLS+A'C/+N)LUSC*H9SQ;3\/O%SPERW-\"\'P_FN5U\=0X$\8,RI
M2Q^/Q%"C5S'@[@S+ZTHY=2Q6,P?Z%PUF^!PV"PN%S:GBN7#9A3Q6%JT:5&KR
MX=8[`XZK1JQJUXSA#ZWE<&J:HOGHXW$58S;=-2_Q]_VCO"^J^)?BA^TC\:_"
M'A74;?X*C]IOQKX3T[Q(QL'TG3]8\<Z_\1?%_@KPG'=60M[/4=1F\(^$M=U"
M=M$MGT^PMM.MY+H6$>L:)'>_,]?UN?\`!:WX`P?LD?L??!?_`()U6/A?X?\`
M[*GPQ_9,NIOBIXU;7/'^F_$?XD_MS?M&>/?#7B3PQ\-_BI\&]!TJPTKQ[XH\
M)SZ99^-[OXK?%OXI>'?A7\//ATVLZK\&OA_::CJ?P5\*?##Q)_)'7]^?1=\1
ML]\0N!,VCQ#PKCN#<5P;Q3FO`^79#F3^M9GAN'^%XT,ER/%YYFV#K8W(<;Q!
MGV"P,>*L=@\@S7-L)DF"S_*LKQ..KXZAB*M3Y3.L)2PF*I^RKQQ$<10IXF=6
M'NP=6M>I5C3IR4:L:5*4O81E5A3E4E2G.,5%I(HHHK^E#R`KO/ASX"U?X@^)
M])T>RT7Q3J>COK?AZQ\3W_A31I]8OM"T?6M7M]-EU`JJ"RMKCRY+C^S3J=S9
MV=S>Q+!)<Q)YDB5?ASX(U3XF?$+P'\-]#EA@UKXA>-/"W@;1YKA))+>'5?%N
MNV&@:=+<)%B1H([S4(7F"$-Y2MAEZC_50_9L_9S^&_[*OP.\!_`SX0Z`-&\!
M_#O1[+1H9Q!']MUG6+B.6YU;Q-XDO8(HH[[Q1XMU./4==UB\=8S=WTUVUO%#
M:P1P0?YR?M`?I\Y7]"_*^"<JPG!4^/>,?$2.=5,)E\\_7#F"R3(LI^J8;%YO
MB<<LGSNI7Q>)QF84,)E6"C@X4ZDZ6-Q-?$*.#AA<9^N^%7A76\1JV9UJF:PR
MG+LI>%A5K?5OK=?$8G%^V=&A2I.OAX1A%47*M4G4O>=*%.G-SE*E^%GPW^&O
MQP\+_!;PA^QI^Q)\1/'_`(3^,?B;XO?MF:7\.Y'TOP'\/[/6_AWI7@GX<2?`
M#]AN7XB?M.:WJVE?&KP)X3\875[^T;\9/A3\??"/AK]H/1?@YH7[07PH^%OP
M_FB\':]HWCC^S3]C2VUKPM=?$GX7KK%EXC\.?#_2?A5!XHU#0]4\4:]X%\*?
MM*ZIX?UD?M$?"GX3:QXLG&H+\*?"4^F_#_Q;H/AF.SF@\#^)OB/XS\(+JMF=
M'_X5W\./PZ_:+T/X"_##X;^!/!^I:=\//!\OQ6_:\^$5M\-M.\0#PM8Z-XE_
M:2^,?[0FF^,&O]1C\6I<:3JT?B+Q!JGB[Q1\3K*[M=576?ANOC_3KK1-:T6:
M[T&[_J/\/^'O#?@S0-,\-^%M#T3PIX7\/V$5AH^@>'],L-"T#1-,M$VPV6F:
M5IT%KIVFV%M&,16UK!#;PH,(BJ*_&OH;_21SGZ3WAOG?&V=<)PX8KY/QCF/#
M6'KX*C7H93GF#PN!R_'8?'82EB<1CJM'%T:>/AA,TP\<PS"E3Q='VM/&2CB'
MAL+U>)O!.$X#SW"93@\S>8PQ.54L=4IXB?M,9@JM7$UJ?))TE1H^PE["H\/)
M8:BZD)3=2BJL)8C$?C-_P7W_`."<_@O_`(*'_P#!//XNZ%>"32?BM\!O#WBO
M]HGX,^(=)TJSNM:U'QW\+OAQX_N=(^'E_>.8KP>$?'JZS?>']9MHYIHK.XOK
M+7X-/N]3T>Q4?X]*L'574Y5E#*<$9##(.#@C(/0@'UK_`'E?B+#]K^'OCZU;
MPZWBI9_!WBBV_P"$7,'VL>*5FT&\4Z$MK%>6<EPNL&0Z6;<WEA),TS1K<0*Z
M7%?X/.IZ5>:#J6I:%J#Z;)?Z)J%]H]]+HVL:+XBT>6\TNZEL;F72/$'AN_U3
MP]KVE2S0/)IVM:#J>HZ+JMFT%_I=]=V-Q!/)_HOX3XJHJV;X%SO2=+#XJ-/?
MDJ1G.C.>D_W?M8SA'WH/VWL?<FO833_*<=%6IRMK=QOW6]O.VO72^NZ*5%%%
M?M)YQ[7^S3\4-+^!_P"T?^SY\:M<TS4-:T3X/?'+X2?%36=&TEK==5U;2OAY
M\0/#WB_4=-TMKR>VLQJ=]9Z/-;6!O+B"T^URP_:IHH/,<?I[X-_;`^.O[=G_
M``5+A_:"D_:^\.?L*VMQJ'B"[\-?%3XD_$.STWP1\!O@5X.T^34K/P!IFB>)
M=3M]$^(6K:_I^DVL=_\`#*PTY=%^+GQ.UW5M7U3P_INDZQK%QI?XKU]7_L??
M$']ESP+\2]5M_P!L3X+^(OC-\$/&'A2\\-ZI'X#\07/AKXF?#O7EU;1M:T7X
MB>`+R#6?#UIJVK62Z3?>&-1\,:]K5EX?U30O%.IWUUY^I:/I$+?@GBQX:\"U
ML9G?C%FGA97\5N,LI\.<QX!H<.8;!Y/G./S/@K-LWI9EQ)DF49'Q'C,!D&.Q
MN94^:I7H8W$PK9CA\''*L+)RQ=3#8OZ[AG.L;1JX+(Y9K#+<GKYUALTQ#K8C
M%X+"_7</2E2PU7&8O+Z5;&TJ$6U!U*=*I]7<G745RRDOZA?B1X[_`."1_P"W
MG^T)^S=/?_\`!27]KS]HG]ICX3_$CX90_!_0O&OPMT_P]\)O'^J1?%_PM>:O
MX2@\!^#OV8OAI\/?#UQXM\.:78V_BSQSIMMHVHR66@:=JFL7/QBFTG2M%K_2
M1D`QO,7FO%NDC4!-^_8Z_NC(R(DCH[QABZ##LK.J,QK_`#P/^"9'Q$_X(,Z1
M^U+^SO\`"+]E?4=(^%/BKXG?$WPAXL^(7Q>^/5UXUT#6+;1_@]KR?&?P9\%]
M#\>?%F^N/"VEZW\5OBAH/@+X::CX/\,R:5X=^)'@JW\0:7K6L^(/'</P\L?$
MW]^WP^^,WPF^+-YXILOA;\1_!OQ'?P3>6.F>+;KP+X@T[Q7I7A[6=0AN+J#P
M]JFMZ%/?:/:^)HK*"/4=0\-/?#7M)TO4=#U35-.L]/\`$.A7.H_S/X49_'B#
MA64\N\`LW^CIPMDV9XK(N%.!<]X4CP%F5?*L+"CB:V=+@?#5L3E_#668O-<7
MF6$RNA0K/$YG2P%;.L9"E_:%""^JX]Q$<3FV'JU<RX>S;,*F!HU<QQO#-?&8
MO+G5FY>QP\\;CL1B<1C,7AZ"IPK595:OLZ<J.&E6G4H3C3^*?^"O_P`8?"GP
M+_X)D_MK^/O&/Q(UCX4Z8/@#X\\(V?B_PO):0^-DU[X@:3+X'\/Z'\/[B]U/
M2(;'X@>*-6\06GAWP9K/VS/AWQ#J=AXC-M>1Z2]I-_BK1IY<<<><[$5,XQG:
MH7.,G&<9QDX]:_U2_P#@Z:^$W_!1[X^_L-+\)_V-OA5:?$;X#2ZSI'C7]JS3
M/!\TOB'X[>+-&\':[8^(?`GA?P+\.TTNXNM:\%>'_%NCZ9X[\>2^%+B]^(=]
MJND>"(-#TU?!NF_$9-2_RM@00""""`00<@@\@@C@@CD$=:_KCPJPN'CA<RQG
MMZ<\74K0H?5E63J4,/"*G[6=!-.*Q-1\JJ234EAE&#351/\`-L=)\T(V:BDW
M>VC;Z)^2Z>>O06BBBOULX`HHHH`0@$$$`@@@@C((/!!!X((X(/6O]Z_PWX;\
M.^#?#N@^$/"&@:+X4\)^%M&TSP[X8\+^&]*L="\.^'/#^BV4.FZ-H6@Z)I<%
MKIND:-I.G6UO8:9I>GVUO96%E;PVMK!%!%'&I17X=XM_\C'A[_L"S?\`]/Y6
M>E@/@J_XJ?Y3/X`_A[^UC^U//\)_"7BZ?]I;]H";Q9JO[;WACPCJ?B>7XR?$
M63Q#J/A0_%:RT0^&+_6G\1G4KSP\=%)T@Z+<7,FFG2R;`VWV0F*OY[?^#A?P
M[X?\,?\`!8/]KRR\-:%HWAZSU6W_`&<?&FJ6FAZ79:3;:EXQ^(O[)?P'^('Q
M!\67\%A!;Q7GB;QUX\\3>)/&WC+7KA)-4\3^+O$.N>)-;NK[6=6O[VX**\WP
MP_Y*2I_V+,5_Z>PI>-_@K_''\I'XOT445_09Y1__V0``````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V1E=FEL+F=I9@``````````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#,R,C4`,3`U,34T,S,W-C8`,#(T,C`T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$=)1C@Y84``
M0`#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``
M9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`
MS,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S
M,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DS
MF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F
M`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF
M9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F
M_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9
M,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9
MS#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,
M`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,
MF3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,
M_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_
M9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_
MS,S_S/___P#__S/__V;__YG__\S____XOR0`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````A^00!``#8`"P`````0`!````(_@"Q"1Q(L*!`*P83*ES(L*%#
M%@X)0HQ(L>+`%18G6MS8L`3'CR`->K08(*1)@4DVECP9,J5%C"Q!MJ%C$0J4
MF!^3M-FX$^?&)Y`V1O*Y$0JD)P1M*DT8Z2;1BI#8#&P#J6I5-B,'0G+94*//
MJMB@1()$JVS9JFU@8HL:<251-I"0P#5+EU95I&NE.E3K,XE<LG7K'@4:M*M7
MG$](``Y,-RH2L%V?"B3,.'!4R`6]\O5)M;+GP@7=LI`A>:WGSP99(!2H>N#A
MD$!/5]8KD>!J@6Y/)EE<^3)=VJPUMAZ8VV3GSY3-0IIC6RT+S3CG5IX3J-0<
MWK1Z'E1K!3K+)VP\_E\*=.U:H.O*::N&:<4*Z>`GH5#%;O:2GO+E2UTRRP8N
MFR3MP21#=Z[=UI)5RIUU'W[EZ0%857:QT=Y$[=EF($A6G(=@>,NQPF!YK,QQ
MUED25CCA0%=4>!)YU["BQW7^6>'AA]?`Y9M=3TRX@A7.67$%2S."J`=X)!Q@
M!8TA7D5653NV=R(VJEWXT0HKL`AB("L<`,"1'P9R51+]M8%4E$XV2>!)6G+9
MHG5LD%`E@ZP$8B,2"3EIYYDG97E%*]=89]5_@507Z'5+<E70@$X^)]D<E_QI
MU640DJB0G:5ALYNCCV8J:9WN58I-?Z#^"6I_CVTZT*4YOH;3?(_VEVE4_G-M
M1=!N9;'QA*HQ0?@@@HW%ZI1`TD&R`A*_^@2>IO2==5=!OL4%%V>9LH'$7[QE
MJMU`1MEH(R3%AG2<<E9-^^"TMB8$9E5RQ2HE1T8I2^*2I4)Z5$'R/?I8N.MR
M]*"V^RJY[Q,W71KAJ/T9&M*P\#Y1:GHV-J8DB27<>]5F,I&@K0GT1<K88MQ^
M:C&I^6X4%<+2)MNKQE;A5?*R,5'U5\.>_8?-$ZQ"TL:O:3T!,%&L2M<;G0ZU
M\211.OTE&UX,09$CGI*%=]IR#B71)*XQ^3Q=0U``Z*2G"WO&'$,IM;!UI:Y^
M]K5");"GHF2[62U8MP0]X1*EI?G'JV`+*3T0==V2+3DJ=@9C.\>OB(9L4KMV
M.:I<MRPD`28;/:Y--':\VIS0H]J161JM=P-V[:Q+GATEU2;%VG59GQ<T'])F
MLGUOJ'X'#?5!8_L$A<5*N@KKV0OIO'>B.-4K:JM6I>[0T"RQVI-.KUKNJ4,G
M,$3''*,&7EI````[````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O879A=&%R<R]D:6=I;6]N+F=I9@``````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`T,#`P`#$P-3$U-#,S-S8W`#`R-#4R,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!'248X.6%!`$$`]P``
M```````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F
M`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_
M`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F
M,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_
M,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F
M9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_
M9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F
M9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_
MF68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QF
MF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_
MS#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EF
MS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/__
M_P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F
M_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S_
M__\`__\S__]F__^9___,____^+\D````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````(?D$`0``V``L`````$$`00``"/X`L0D<2+"@P8,($RI<R+`A05F!]%@)
M9,VAQ8L)`P4"M+'B0&C0#F$<>3$B(%*`K!@,9&45R9<+K53Y,[.*P2=6KL#<
M>9"+-4!5`.FY:<7*'IY(!;*RMB7H02@L]E@!E'2G-993#UI9<87%E:)57X)%
MF!.*T9PJPXY,>[#*GBM?5>94BVVBQ4`(X>I$*W"H6BLR++)"*%4@E*]T"=IM
MV"IO6BN'Z195"9>MPL$+<28N^O7M%9<+,<>DBU=@SLH,2R5NR%&@7KBB$99>
M/=!R[:)1KD0QJ@>:0BBT:R>4^A9+Y5:Q"[)<?9IA3JE%`UVSEEPXW2MO+4J$
M`BU:(%;7H/ZQ2DZQ*N>OE;?:-LA1UC56@L!?"^\1VZI6]7>^3K]>H?OYI<@7
M'FBLB,>3#"R8Q<*"&+GD7C34L?+=+-&\IQ0KH"EDC2S1R$+A?(&8$DB",D2Q
M8((KL&!3:-;,-U^!T>P12(5+8:,'(H%`(XMXC1&DXW\NBMC*D`ENQ8(,*SQA
M$9`5BL=**8',`N)X`L[G)#;/R-?B=,@)@@@KR&VU`DS_25D@*\I`*9V+4F[I
M8C3@13.+>&H*,J0IK7PYVTM5@E2@B&NZ^>$U4EIY#:"F)&H*F$,.61U)X+4(
M)S045>CB?)9BNB5$B2J3*)CCM2)+ACQ!<RDT(DJY:(52SE+HI?Y2[E%*HK,V
MBA^$56WH(JI1E@+8%15:DZF+K80'99JS@NGBHU:Y&.5$I7QERJ4N7J&1%5Q0
MNBAR\U'H6V+0S/D="U%B12&KU^"(R$160/0=*Y;.F9]:$5K#0A<R'""#%>$6
M"LT*70@B@PRL7('C>//-2QLKLTR$[Q4$7R-GNC$,S,)$>.J!,#0*KR8Q(E=T
M`1@BF()X;Q<!6S%G@!W3II&`A5ICQ0$KK"!Q(%_%AQPBP2'$,"L/L@F-%?%)
M3&BAXPG2\T$%7FIIBX>X:6FX-"YM$)55FA*@1K-(*#&$70?"L]4%M5JR-<@A
M-QZZ3<)']D'B7=JBG=U"^.)WIKQ]T/XA55H3\Z4:1;2GW@(=LFB5A!(KX2JR
M=$4X0:%.)\@A@@0B2.6(+"J+A-$@]KA2UK38RISP@@GGSJP@@DBTGV.#\'N'
M"#T+ZFE;/CC9UJ`J2X05LFIW*X'(@KK2CX\:R"JK8)AIH3L&<@@@JZ347\_1
MJV*]*E/!ZBP@UANBBB%4$;[*]86H0A.U5D*O2BJO8&,(%7KK4445AOR1BBK8
MI%3LJQURL4HJ?PC@%OX0ON#,CWO7,U\>\J"**J@M5,CA'DW^L#[KT61Z.XF>
M^M8'0"V0@A14J$(>\F2K"`+E>O=;'U!6E!0)J>(D@$A%*F!1B!2.8H%C,L@J
M\H",/(PB@>'82"$!6\.30#PA);(`BO<*`0CUY0$/?BE(*5310U)\[X57!`H@
MN#`VF$1K!57PU0I44#X"5H$*JL!#'I2T$FPLT'J%^,,6:OC"53SA"1+:2<U6
M<(A`K`!)-`%$S520ARH\(8H$V6$`4X$\61QB"TT4&RNVHI&7^)$%*PC$P&KV
M!RX<8@4Q6($>V(B0!5+0$,ECQ1'G9X4\+>AV#1&32OZXQRH<X@DL""4+$;**
M/^1A%5RHV17V2$O`[)$GQQ2('^=GD2;.KV9;,0`Q<U@SF.20()C48S(%<LW6
M>?.;X*1+0```.RXO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V%V871A<G,O9&EL8F5R="YG:68`````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C`P-0`Q,#4Q-30S,S<W,``P,C0U,30`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````1TE&.#EA(``@`/<`````````
M,P``9@``F0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!F
MS`!F_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_
M,P#_9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,S
MS#,S_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,
M,S/,9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`
MS&8`_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9
M,V:99F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_
MS&;__YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF
M,YEF9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,
MS)G,_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS
M,\PS9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9
MS,R9_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`
M,_\`9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]F
MS/]F__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__
M,___9O__F?__S/____B_)```````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"'Y
M!`$``-@`+``````@`"````CB`+$)'$A0(```V`XB5)B08<&'!0$\.SB1HD)D
MR!!"W-CPF<>/(#-JY+A1(LB0(TE"-'G28T:5'%FV?`ES9<N/-&M&O.DRI4Z#
M/)_E_)GPFDR41`T:-?J1HE"?-0$L56A2XE"=4K,VG?@T:5&M'B5:A0K38LNQ
M29V>='JU;%"<9$D>O=FVK-J9<=WRK!LU*%^]=/.JG`NWI&#"/0WG1>PP(M62
M3:E>,[KR(*2XDB=K/E@9$N6'`"YKGJSP<T3/URZ#AB3:J-3-9%^;'ECZX.C-
M*STWIBW[-NG8"E73;NT;]\"````[````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]D:6YO+F=I
M9@```````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,3<Q`#$P-3$U-#,S-S8W
M`#`R-#`S,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!'248X.6$@`"``]P`````````S``!F``"9``#,``#_`#,``#,S`#-F
M`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_
M`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F
M,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_
M,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F
M,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_
M9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF
M9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_
MF3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EF
MF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__
MS```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9F
MS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_
MS/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F
M_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG_
M_\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````(?D$`0``V``L`````"``(```"/X`L0D<
M2%`@"8$`#A9<R)`AB8</&TJ<"#'BQ(L%*UK$R)%$0B0<0V(C46*C2(<E2M"I
M\X1.B9,+2ZR@0^?)GIMT5L`D6*+.32AU]$#9\R20SIW85NSYM&<%E*)&`QG=
M28+.IZM0<EHQNF(JS!)+07W**=,H@!4EORYE^F1%6Z<SH:Q0<1(L4RND2#W)
M^D3/DR=Y5QS%:!?PL[Q_23TK5>K98KT<>S;-6R5O8\>8'4/&^*3."E)5/F<>
MK?D)8;F(%9,>K4>AQ*J`]:I>C7GSQ"0U`:W00SMS*5)T*<K5(WCV:E)Y@)_N
MJT+T:%*7\P:G6),X`,"7->=I3*HU1]Q0_%<B:0Y]<1Y`A_V*!.]71?.^>1&[
M[DAG3WA`Q-NZ=X]4*5&W+B%54$]7+=64@`0AL4(=5UU%QWQ(D>#4306^A&!2
M@0@B%U!0I'3A"H*T(H@@1LETQ6`,!00`.P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A=F%T87)S+V1O9RYG:68`````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(Q,#8`,3`U,34T,S,W-C<`,#(S-C4P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$=)1C@Y81T`'@#W````````
M`#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`
M9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`_P``
M_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS
M,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\SS``S
MS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF
M`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!F
MF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF
M_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"9
M9C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9
MS,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,,P#,
M,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,
MF<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____``#_
M`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_
M9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/___P#_
M_S/__V;__YG__\S____XOR0`````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````A
M^00!``#8`"P`````'0`>```(_@"Q"1Q(L*#!@PA7*$3(D.$*5JQ6-)Q(\.&?
M0!(I&E2XP@I&5A<S)F1HQ4I'BQ@=ICP8**+"0#!-)F0E\^`*F"TAKMS("J9(
M@AB#0J3Y<^#-HRR/YNQ95.#)G=@XWKPV=&C-BB9W`E`"\2'5JDR;=M2J1--'
ML#KU0"(!@(1;``^U;E7R$&T@M6RLD$#"EX25B`4!`"BQ5*<5O'I8Z5E!8D5B
MJ%&S#@U4D@0D-HG1,BVHU'#;RYDU$\4ZMJ1@))A%6RTJ4>I>)*%57W7X5_5J
MC1VKXM0]FR'<VC0IYQZ-V^1?C"6-;RZ>U0I<P;\AJVS>.OE-Z9Q+OJ3YW.3V
MW@2))()UKGU\4Z?"S9>O"AY]5IS:M>.DW-XI@*C0!6/3OR+_?8$!`0`[````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O9'5C:RYG
M:68````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$S-@`Q,#4Q-30S,S<W
M,``P,C0P,C(`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````1TE&.#EA(``@`/<`````````,P``9@``F0``S```_P`S```S,P`S
M9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9
M_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`,S,`
M9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F
M_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_
M9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68SS&8S
M_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,
M9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`S)D`
M_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF9
M9IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G_
M_\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF
M9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,
M_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S
M9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9
M___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/____B_)```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"'Y!`$``-@`+``````@`"````C^`+$)
M'$BP(#8`"`TJ7%@0(0`K$`$PG-@0HL6(%"D^O&A18D:&&SE:\?A1X4.'*$>6
M-`E@A<L5@5BM2+BRX<L55E:P"C2SILV;,5V2K(FR:-&,1@,I7<IT*0NC!(U*
MG4KU(%6$>[)JW7/BZ=6O6+#N`9`5H=>O4\<^(LMV[8FK5M,"6`L@[%RV4P=2
M'7L-*\*^;Z7J!7#-RK5K._T>9KMX+("8A?M*)'RX<F6RC@?5Q?K6LF6'AV<Z
M7-%7*P!2`$YP)2RZY>*_G@^S.NV0E#'4"%$'BMTW;M&^MX/;'FZ,L&"0"(4K
M=^A3X&GEPX<2=;B<N<_GQ+/?EJ[1]M?M$XL\BIX9+'NPE@A;#TU_,^O,"U()
M8+XI^B!]EWM$$[A`H']__BWE=U]+]PE5%@`7))B@7P4V:.!614'88$```#L`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O879A=&%R<R]E:6YS=&5I;BYJ<&<`````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#$Q,#8U`#$P-3$U-#,S-S<P`#`R-#<R-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#_V/_@`!!*1DE&``$!```!
M``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!`0``````
M`````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`!!$%$B$Q
M008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X
M.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4
ME9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+C
MY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!`````````0(#!`4&
M!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R
M@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(
M24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JB
MHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR
M\_3U]O?X^?K_V@`,`P$``A$#$0`_`/QM+`9X/'4D8`S[\Y[9_P`Y4$$`CH1D
M?0TJ_P"NC!!EVGYHDC9EY!(W.,`\'/&""<8R,TVYFCM87O+WR]/M/MDD+3W4
M]I;;(_-*IY%E+<BYN0?E"NA4%3OV``@<E>K%7MB%2:TVB]4XWW3Z/?[ANEB7
M%.C2==R2T2>C=M/=:;U]/F<)\1=+T?Q'X>EA\0WDMMX>TP-JNKVUO'J!L=3D
MT3_B;26NH1:5;WFI7>FXLR=0M[*SN;BYLUG@MXGE=5K]/_\`@F5_P4M\5_LE
MVS^*_`_QWT34_P!ESX>^.O#7AS]I#X3:SIFBWOB'P#\+_B3J.O?#7PW\5?#^
MDP:GX!\8:Q!X=^)K^&-&\2:-X%\6ZWKGA^?5K/5K3_A*="M[O[5\H?LG?&?P
M/\#/VG/@7^T'\6O#\_BC]E7P]XS\2>"/B[XNT_PE;^*O#W@?Q7XQ^'GC#1O"
MGB$V9\1>5=7?AOQA!>:MJW@2>SUC4K/1_!NO7DE]>B`6[>[?M?\`_!&/3-._
M;]^'OA3X6KJ$/[-?[9VA?&O4/AAXCL_[,3PSX8^(,OPZ^(?Q.^'O@"PO[#3?
ML-SX%UOQ`NDM\-='U?\`M7Q-X:\(13SZ_P")]>\3V,'B:#P)9E.I+]ZKI-)Z
MI:)QYGTZ)N^EW;?4^BP.25*F`A7=1TL6IISPW*FY1T=K2O+WK-:6?6ZW/V^^
M"/[0G@K]I#]I?]L;XO?LW^%/B=\,?C!#K%QX5_;E_8X\!^+O#OB2?]K7]D^9
M=6^'?@S]OSX07&F>#=-T^R^/?@"1EU_PWHG@_P`9>+=4^)V@>&8O"=A>:OIO
MQ5^%WQ&\97_V1_\`@G/_`,%(-8T+]G_]ES]H?Q5\.?B+^Q]^R+^U-\(?VI?V
M=?VA=9U?6?"W[07B[PGX`?6M:LOA?XN^&LEGK/B3P)K6HIXJM)O$>A>,(M-F
M^&\.EV'A"VN_%#74=S7S9_P0?_9'^-GASXY?`7]L?Q;XZ;P]IUC\"O$_[(/Q
MS^$7B#2+G1O%MCXP^$5YX9\,^&-*T&^LWTU+3P-H-GX*\(75YJ.I1ZR;_4/A
M_K&G6%U;V3Z+IFE_I-\5?V[?^"AW@/\`X*M_`[]C#PKXX_88\5?#OXM-K_C&
M;PYHO@OXV7GC?X<?`[0O!OC#QK=^+?B=XGNO':^']6\9>*--\(ZEJ/A:Q\+V
MROJ<GARUT:TT&QTR^UOQ-I?K8#&X2OS4Z=6*FK1Y$[MNT=+MM[?RO9+7H>7F
M&78["3C.MAVX5$G&\6G%76NG3OOYZ'[RWOASQ/<WEW<KHG@:Y6XNKB=;B>S\
M6033K+*\@FF@33;A(990V^2);B=8W8HLTH4.Q77R^)=8$L@C^&WCJ=!(X2:"
M;X;>1,@8A98?M/CFWN?*D&'C^T003["OFPQ2;D4KT[+S^]_YGEVEUI=NK_N7
MZ^;/\RK_`()X?L'?%C_@IUX[UW6=0UG7/AK^R/X9URZT?7?&.A/$OQ/\<:^E
MM</IWAKX?6M]$^B6VD0W<,0US6=5MI;B&&TU$P749,83^HWX"?\`!*']@C]F
M>RTS_A%O@UX2\<^,=+N?LTOQ`^+VE6?CKQ`XBA:SN+[4?[9DU7P[<:G?KYLE
M]<Z7IT-A)=SRS6$4,!A5?K']GKX$>"_V9/@[\-OA%\/-.T_2]`\%>$?#^CW]
MSI=A::8?$^I6VD0Q:KXBU?[%%`-4O]>OY;W4KK4+P3W-Z][)<7$LCSNS='\5
M?B?\,_@K\-O&GQ=^(>NVW@3X>^`-"N]:O=:ELTU"&RTG1%CNY+V#1BC)<M%X
MC%GX7TKPZD6S7[.Z73HX98)?*/XCFV8YEC<>J-&=2$8RY&HSDKVE;F>OO-]6
MWKMHK(_I+*.&,MR3!T\?B?92YJ4*LHRA%I-Q@[:II:Z:+;5WL?D__P`%K=-\
M)>`_@'\,/VA_$NCZ/XA^''P:U#QWX*\7_#*336TWP_K/AKXX?#C7?V=M)UJ8
MF%[+06\$>,=:T/QCX;U2WMXCX5\0Z.VNZ3]DU"[U&>[_`)B/@;^U#X6_8M\,
M?LV>)/V:_P!HO7?B9JMQX\M?C'^UI^R3K'@B3P[\,?`%S\/_`!/%XJT:?X8?
M%?6[O7_#FDIJNF1OHM]'HVD:$FN27=OX5<2:=KUSIDG])7[5?Q7_`&R?CG^S
MA\2M>_:@_P""?GQ#^'__``3B\;Z!H&N^(O'_`(7^)_P[\:?M2^"/A=H/B[3?
M%FF?M&WOP5\/:.NN:#9_#SQ-;:?X_P#&7ASQ!)?:!;>'M.US4O$FA:GHZ:A;
M7GR;^S)_P1<^&/[0EG#X^\??M:^"_CI^SYX]\.:U9^%_"GP-\'^&_A+J'BO2
MM6M6MK/5_B?KWA*QTVT\8>-O`@:U\4R:;900WZZ_X>L;B4&.V=*^HPM>O@,'
M&IF%-3]I**?.U/W9*%KIWU2<NO>+<6M?@LRHT<[SV.9Y-C*5*<'"+P=&\(MP
MFG91BDN:6BTB]6G=F=\/O^"F/[2W_!0WXJ_#[2]!\?\`P>_8&_9AM_B/#XT\
M6Z]KOQX\':S\>3HNEZ_IWQ&T;2DTOQ/I5\/['O\`Q'X3T9)-&4Q:-/:7VIS7
M]I=6][J5O??IG_P6#TW3==_X)D?$;]J#X>>*1-#^SMXV^`OQ7^%WQ3\&7^FZ
MSK6M_$2Q_:#\#^$=%\4^$];T6%-!\3MHQ^)?B76]"T#Q)8ZY9:?XG_LG0]"T
MZRTJYFM*^5OV#_\`@GW\#?@U\=HOV(OVQOV8_P!F[X]07EQ_PM?]F_\`:CN_
M@GX+UBY\?_!R'4AX6U#X=_%GQ)J'ABYU75/B!H^BWE\='O-:OKB]BUN'3&@D
M698I!^EW_!/KX.:_^U1XP^(G[3?Q>\0^"O#O[$_A7XG_`!8^%'[#O[&_PX?2
MK#]G#2O"7P;^(VN_#RW^.7Q+^&.GF#X:^,?&^E:[X)OOB#X,NO%7AZZDT&WU
M/3O%>EW5IJFA:/<1]>6X7"9ACH8O"35&>'FI<E)<BGR_S1CNK22U[+317PXC
MS''Y70AA\=156KB8KV+J>^J;DTGR<R]UW3O):ZWU;NOR[\:_\'-7Q=\">,O%
MO@CQY\`F\->.?!OB;7O"OC/PY<#XS6\^@>*_#VJW>D>(M$FM[+Q+#9P2Z5K%
MG>6$D-I#%;1/`R01I$J*"OY\O%?P+_;=^._BGQ+\<+:+7[NV^,NOZQ\5K>Z\
M0Z)X9U/7[F#XB:C<^+XKC7-2NC-<ZAK$T>L+)J=]<32SW=ZT\\LDDDC,2OK_
M`/:OYI??Z?Y+[OO_`#GZUB>D$MM.WPZ;>?\`6M_T-^'_`/P7W_;]\&Z)IWA;
MXF_LT_"CXGKHNCV&@Z?XH\)R^//#NKZC%I-I%86%WXHGN]3\0:!'(MK;V\4U
MQ86=NUUY8FG`O)9G/ZU?\$UOBM\8_P#@K<^O>/?VH?!?P7\#?LX_!3]H?X2Z
M;<_LY^$['Q1XRU?XY?$6TM/.\+0?%G7/%FMZYX9UGP'\/UB@^)2?"WPQX2\-
MIXD\7^&]/U+699IHFB/\U+`J$+`J)#A"PP'()!"$\,<@C`SR".U?2G[&W[3_
M`,8OV+_%?Q#F^'LWAS6_#_Q1\1>"_'6N>!/$G]IZ;)/KWPROX=;\+:EI7B;0
MH-4DMYIKW7[BX-G-IIG1=-O('W-'.8?(H91@,+.GBIQC*<8QE/3F:E[O,Y)W
MW=VU;>]K*Z7MU.*\_P`5AG@IXR<H-<D8).34;12A>*=K+1WN]$_,_P!'/3_B
M#X5U73_'-I)B"+P5XI@\,>(&1)>;S4;B"Q%PZVSQ7$DTQN1'.T4J7$L;/&LB
MLX(_`CXU?`?2_P#@EO\`'67XS?"B*R\$?L#?M$?%'5[7]H+PLUE::7X._9A^
M.OC@Q-\)?B;\+(+2STV;PQ\-_BMX[31?AS\2M,M5DN?`WQ+\2^&4\&WV@Z7J
M&IZ?=?EQ\'/^"X?QJ^)GQR\9?L_:?^S?\-KZ[_:JLM<N?!^H^(/C?>:/I/B_
MQW:Z-?WVBP6'B.\^"^L1:%KVG:A;07]GX*\7:+J5CXJN;:/P[J$4-KJ<L\7U
M7^TM^V]\6/VCOV0/B?\`L2?M2?\`!+;]LKQIXV^(/A>Z\+:Y8?#36_`_C+P8
MVI:-<VVN>"_$^C_&V.\3P\M[9:QHVE:GIFL6OPCTFQ\,W5E:QWRQG?,NF/6`
MQF&^KUI<DXI\CT5I/X&EMOMYZ&'#E+/LNQ\,?@\$ZM!5J?MG=32BIPE---NS
M<=5I>^VBU_:$R+;R6NHZ?/:PW%AX>86<MEJ%O:?8Y+AEUW3-6TF[U-;FSM-+
M\2:W!80:3XLN8+C63XBO-.NY[FZ>,1-_*1^S[XZ\&_LO?"[]NW_@FY\*OV[+
M;QY^QMXE^&'CG7-+_:#T'POXBTSQK^S!XTU_6;C0-;\(>(=1AT;1/"WB?PM\
M2/!WAS6-)NM2T$V-EIOC"+5O%UOI$NK7,=_8?,%O_P`%!OVC_!'[)^J?\$Y/
MB'XU?PSXQ^$OA'48/VB/VK?#?B:VU3Q1\#/AU#XB?5-(^$NI0:'%+X*\0?%&
MS7Q59?!#7K_4/%N@2>&[[4K'PM<:,WB;P!J&E7F%^P1\*/$_QFA\$?$*V\.S
M?#?]DCP%X@U"?P/\'K^VNM;F^+_B[P_;W5[IWQ0\?WWDZ9_PD$<7B6.QU:>U
MT:PNHM+\2SZ#-/?%(-LT\&<'8R&(K8C$8QRPM:=Z7LU=Q5DK^ZN:.ENB\U96
M7UO&/$&"SFA0C'"NGC<-#]Y*2:<7O=.6KLVTN5Z)]7=OPCX?:O\`\%.?!/@+
MP1X,\,?LK7?B7PUX1\(>&O#'A[Q':>"9+JU\0:'H&C66E:3K=M<RW[2W%OJM
MA:6]_#/*QDFCN%D<EF)HK]_+KX;:@UU<M)XJ\4-(9YBYLIX5LRYD8L;12S%;
M8MDP+N;$6P9.,T5^G_ZI8;_H.J_^`S\O+S?X=F?G7,OYE]_]=E]Q_.?/+)!%
M>O#(\+G3;LEHG:-B51PI+(020``"3D8XK$\'2/=Z&QNW>Z)AA)-PQG))1&))
ME+9)/))Y)YZT45^=2_B8S_KW_P"VHUP/^]K_`!/_`-M/*OVK;BXT?P+#K6D3
MS:5K&D>-I)=)U;397L=2TN78R>9IU]:M%=64FUF7?;2Q-M8C."17]W'[`/B7
MQ'K?[!?P5UO6?$&MZOK*>#Y@NKZGJM_?ZFH30+IT"W]W/+=J$=590)1M90PP
M0#117S>8?[W0_P"OE'_TY3/U?A+_`)$V8_\`82OSI'\&=C=W>I_L%?M.:[J5
MU<:AK?B;]H7X+VOB/6;Z:2[U7Q!;7O\`PB&JWEOK>HSM)=ZK!=ZHB:E=0W\U
MQ'<7ZK>2J]PHD']:OP2TO3-*^$_P]L-+TZPTVQ@\-6;06=A9V]G:PM/9:=).
MT5O;QQPQF9U5Y2B`R.H9]Q`-%%?M?!?^ZOT_2)^<YW_R,ZWHOT/5=B?W5_[Y
M'^%%%%?8GA'_V0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V%V871A<G,O96QM97)F=61D+F=I9@``````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C,P,P`Q,#4Q-30S,S<V-@`P,C4P-#0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````1TE&.#EA(``@
M`/<`````````,P``9@``F0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F
M,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,
MS`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S
M,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9
MS#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`
M,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69F
MS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_
M,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DS
MS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,
M,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`
MS,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9
M,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_
MS,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F
M,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,
MS/_,____`/__,___9O__F?__S/____B_)```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"'Y!`$``-@`+``````@`"````C^`$E4&4BP8!4`V!(J7,APH4"#
M!DDTG-CP(<2"$B>2R%CQ(D2."3<.!*E0I$>,`%(^5'%0HT6/*EA6D>DD9LN*
M<EX:E#FSBI,JI)Z1>D(RI)R<$&T.E$EJU;.GI4BIP(FTH-*>0(4^U2J5(8FC
M5;$N'1B45-"G9H6"_`J6Q!.>!<^2`K0U3YZG*QR"/>K6:E:T6P.K+;DW)\^?
M9P4K7L61[5$59M_^54R9,6&P3[8ZI?SL[M8G02T;?9R8<^<5I=`^6;&*5&.P
M2$QK?K+*<YY50/->EN-$-EI6T&RSRN-:[]'8OO58LR:<N.[1<I"CS9,ZL')6
M59XZL7*W*_3>:$FAE5I16@\K*ZR?U90[-:23Z.&)DW`BU^X*VTZHHVU,`KG9
M/"J\EUE@FVU%BEW/B%;26?(=15]@!T+H67$,0=9:'HX]>"!BTZ7F747D2;57
M9H`<6)M=Q`G5'D78;%38@\^4<MMP9JU0E$;OC;B5C-1)A02+%6V$Q'&EF>7$
M1AL!61)!2$*&EHTY'JEDBW[-A&),+N8T)38`[#32D3&IP!9(`0$`.P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R
M<R]E;&UO+FIP9P``````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V,30Q`#$P
M-3$U-#,S-S8W`#`R-#`U,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`
M,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_
MQ`"U$``"`0,#`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C
M0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-45597
M6%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJ
MLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X
M^?K_Q``?`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($
M!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B
M<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G
M:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>X
MN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$`
M`A$#$0`_`/CG]HO_`(-F3HG@[7_$?P+^(5YKVO6=O]IMM#\1_P"A_P!J<^W3
M_P"OGBOPW^!O[1?[7'_!+#XX76E_\55X)NM-U`VWB#PKJI/]BZ]8Y[Z9TU;V
MZGK[5_J,^,[?0?#^F2ZI;RWDUIINCZYJ6H0P7/VR]NO[+T[D=J_R[/VYOVUO
MBS^W#\8O%'C'QO\`V=H/AP:Q?6W@?P/I6CZ=9V7AC1/[1_XEFG#_`(D_]MZM
MJX_YF77"3T/0'%?B?"&;XWB'"RPN9*&9Y<HVM-NZM;IO=*_-=6M>VO+?]@SW
M`0P6*>:98Y99F4I.2<&UK)WLK6>K]7=*Q_15XD_:?^%/_!5[]G+6?^%#_$+4
MOV</VV_"OA^^UO1_#?AS6#X;T7XLWVEZ=_Q,_#O'_0>_YEK7?^1C\.>(\_\`
M,K5^,/[$GC#]N_XN_&N+X(_"NZU+XD7^O7']I>/_``Y\</\`B<>"]"T/2R=,
M\3>(O'.J:M_R*FD:#ZDYZ?\`"+'_`(2C%?`UQ\!?V@?@-X"^$?[3_A2TU[3?
M"_BJ>_UKPOXCT.X(_LJ^\+^(SI?8CG.F9';.,\'%?05Y_P`%1/VL]7\(^+O!
M'AZ8:=XG^(0&F^(?&.A>'S9^-+K0],!.F>'/[3TH`_V2NKZGJ>LG((SJAP3P
M6[L-PSPZL'C\OPV49'F>7YDY)3DX1J91;EYKM-RO?6_,TFM&F['IX?COC7!5
M\#CJ_%&?9?C\MY;+_A6Y96M:Z=U).]MFM?.Y^^W[4WC_`/X)-?L7&71O%%]K
MO[07QM&GV8UCP=\*_%&I>'/AEX8US_F):?IFJ`_VT!_:X.1R2,$E?F%?@O\`
MMI?\%$/"7[56F^%K#2_@T/"NL^`[?^S?"_Q`N/%.H^)/&EUX5Y/_``CGB;4]
M6_Y"VD:#C_BF?^A=Z#GKX/>?LN^*/`7AKPE\8_VJ+#QAX;T'XD7]\?!^A_9\
M>-?&0TP?\3/4?^)O_P`@G2!_Q+<ZWKW7/L:_IF_X(K_LJ_\`!(K]N&S\9?#J
M3X/>/+/XV_#'P_8^+-8T/XC>*/[8LO%&AG4O[+_X2+PUJ?A/^P/[6_L+_B6?
M\))HAT#KJN.<\9X7*.&N#<++,\!@G-8"/O2B[PFE:^KOS)-V=[IOY,VXGX_\
M0N/YPH<3YX\PP<)1=/*)752+7+:2O9IZ7T\V];G\KUA^UY^TGI=C9:99>-O$
M$%EIUI;V%I`-3"B&ULX4M[>(+GY1'%&B!>VW%%?Z6UO_`,$K?V#[.W@M(OV=
M_`LT5K#%;1RGPZ)3+'`BQ)(9<?O=ZJ&\S^/.[O17S/\`Q$[A%ZO+X7>KTZNU
M_M>;^[UMW+.>/DDHY_F$8I))76B7+9?)*WR\E?TBS^/?@/Q39:7K.A>)--UB
MU\C[+;SP:@/]*(!_'\_TK^=7]I__`((]_L2>+/B_K/Q:\)^*?'?A6U\4^(+[
MQ)?_``=\.7'AT^%[J^U0G5-3&F:G_P`AKPII'KH9!_ZE;-?&WA/QOXR^'^FF
M+P7?ZE-+KUQ]F$$'_+K]/7_.:_:GX;Z':Z=X(T&+Q)%_:6LS6_VG4+[5;?\`
MX^K[^SL_V=UYYQVR/4\X_G#C#CO-N`LH:R;'-9AF:<4DVK)JSY>S2>CLK-7W
M/]`ZWT8^&L#F2QF(QJS+`*7,LFE?1W3OKV>K7DSB9?AQX#E^'F@?#6Y\+::?
M`GA7P_\`\(WX7\.&#[;HNF:'I?\`S#]-Y[^O<]3U%>2:?^S!^S]X;\16OBW1
M_AQX5AUW32+FWU6#1Q_HIX_$]S]*^U[C3_#D:12QZ5IOE3?\\./\@9Q_DUP?
MB"/1K>&_ECM;.&6$_P#/O]LY^O4C\SVK^9\)Q?GKQ,IO,<]YIR<I?\+#Y92;
M4I75]4VW>]]+Z'Z10\.<DQE:,:^6Y(HI)+_A'C=)<J2OI=I1W6]MV?EY_P`%
M0/V??BS^WCH/P0M?A1I6A:E\5?@IX>\5Z);>%9]0TWPY??$7P/XH_LK5`/#(
MU8C1/[6T(Z7SG_A'SXB\.:MGG@'K/^"(?[`O[0'[%7QQ\>_M2?M,:+%\+#IO
MPPUSP3\/_!%QX@\.WFLZ]>^*-0TK^T_$6IC2=7U_^R=(T#2=,/.>?$1'`YS[
MEX_\2'0YO^$BT>+3(=9T'_B=Z?!!8<_\2OG_`#GK7S!\2_\`@H+XW\4>'?L'
MA_2IYI;RW_TC_1_L9M<_CV/Y_GG^P_#_`,0<^S;@I9+BTI62BYM<T^7F35V[
MO36[WMIS6T/YX\4?HV)<68+-^'L$HK,=TE:-[J^BT2Z);+ML?O%>?\%"?A_!
M=W4$E_:2R0W$\4DK3[FD>.5D>1FQ\Q=E+%NY.:*_C_N/$7C.YGGN;MD6ZN)I
M)[D*GG*+B5VDF`ES^]`D9@)/XQ\W>BOIEEW#SLW'71OU]V_3R_JSO\JOH^YU
MI^\?3_VVW7T^[SU^A_`&J17'CKPWX7MY?.BL]8L+G4)^;/\`\%F3_P!0SWK]
MS+GQ_HT^E1120S3Q?9[']Q8W'V/W_J>]?SG^$/$DL>OZ#XHM_.$4^K_:;B?_
M`)??L/Z_XY]J_5G4/&D4F@6LMO+-]EU/[#<W$\]O_+D5_/OB[D^(QN/R3EW3
M7HMKW2^^W^1_HM@\NP^=.ZNO.UGNFKOUL?0^L>+-+^S6L.ERWD,O_'M<03_Z
M'Q_T#N_0?_6YQ7AFN?$.6-)89+^::*&W_P!'@^T>_P#R#N_K^6:\;USQY^__
M`'=U#-%_Q\^?;_Z']D^O7^UNWL#7E^J?$/[-#Y4EUY,4-Q?7/[_Z\9'!Z^@K
MX/+>&JUU>-WI?37IY?ETT/;I95A<`KXAQT6FJMY]?ZZ^74?$?QA=7%A?RQ2S
M>;]G_P!'@^T'[;=?S]QS_P#6K\R=+DU2.S\V2U\Z&&X^T^1!<?\`'K_/T_'K
M[5]&>._BGI<GAV_EN+H37\/^C6T$%Q_T%/\`//-?-.GV^EQW\LEMK_DRS?\`
M'Q8SV_\`GG\_7FOZ$X$R>O@<!C=++2R>FEXO1/O9]/O/S_/<SP^.Q^"^K->Z
M^CNE:U]%>VOZ]3HSXAMU)4QJI4D$9'!!P1U['BBIUTJP151Y+%W10KO]@,6Y
ME&&;RO\`EGN()\O^#.WM17V_L7UO]Z.?F?E]R_R\E]QT.GJL.B3K"HB5+KPQ
MM$8$87&<;0N`,=L8KZV6><^"?"#F:4NGA$S(YD<LLW_/56SE9?\`IH"&]Z**
M_->--Z7K'\X'V_#7^[_]N+_VT\4UN^O9=WFWEU+LN!L\RXE?;T^[N<[?PQ7&
M>,+NZ_LP_P"DW'%SQ^^DX^GS<445X>4_'#TA_P"VGS?$'_(H?K4/FWQ7)(]_
MX:1I'9)8?M$J,[%9;C'^OD4DAYO^FK`O_M5TFA$DZLY)+%^6/+'GN>I_$T45
M^VX/^'_V[_[=$_,.'/CC_B7YP(]S'JQ_,T4451]T?__9````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A
M<G,O979I;"YJ<&<`````````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S(P-``Q
M,#4Q-30S,S<V-P`P,C0P-34`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R
M`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%!@<("0H+
M_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$(
M(T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%56
M5UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBI
MJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W
M^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"
M!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`5
M8G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F
M9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:W
MN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!
M``(1`Q$`/P#^QOQK\3;/1M3UA;2)KV^-W*4MK8*I,:2-%''///)&\0+H6S"C
MMDX(``KY%\=/\0?BQJ<5A?SM;>'X+ED.@Z0^P72!\(^JW$3^;+"Y12"ZYAW.
M8RS,6KS3XB_%#Q5K6JZI9^'/#MCI]AYTACUO5KN:YOK_`'R&22YC*"WEL^3*
M%1F=BH7H*]]_9X\0V]U:Z;875O&=9A6!-0D>1Y);[83YLLDC,74K\^R,G#$@
MD$9S_&_$/B)AN),\Q.2UJV(KY;5Q57#NE@ZDZ6&KQ5:=*F\54NZM:BIVJRP=
M**IXM12JRJ\\H/\`7L)D&)RG`4,P5&-*LXP]^:4J])S@GS024HTZCA+V:G43
M<;^ZURJWRG\=_B+\0?V</#4/B#P1X>37=4\M=/O':TNKFP\,:;"?.6+2;>V"
MW+L&93<,LD:SO)))]]WK\YK?_@K=^T5I'B:RMI[SPEJNB76HK#>:!<Z=>_;/
M*!!DA:XD=;J*<H\"IA72-OD:-Y`J/_05^T%\/I_%'AW4(M(M[9M2NM-NTMXG
MCD"O/)$/LL8EBB),Q?RE$>?D!8]UQ_'C\=?A5\.OAWK7Q*T?Q?H/C[0?B(GB
M*YF\/>+=)U:.?28+_=]HU+1?$>E7=U'=VL897-O=*B(--F8LR,8I*\#-<#CN
M'L7:..S:K1E-<^(H4E4<\16<6\34HJO[\'RQA]4H0J5%2H03PLJ:ER>[ECP.
M:8=*6%P;JITZ;G6Q'L'"%E)3<^913IM*"E-<MYN4WRIG]//@OXQ^&?VIO@G-
MXCTV2"RU._T@6>MV*1NZV=U,B[K24*L+1S6LL1'EE`6/R[QC)^./%?QX\2>`
M?`L_PIMIYX=5AUQK>WU.VD/G?V)"PF@1)/._=.)E0M(2WRK\R$'%?E!^P'^T
MCXB^$NL^(O"M_:ZCJ-IXML`8G#3W&DP2VS2VEO?W?D"4V_VA0DZW'W/,<AWD
M<&,_H7XF^(/P-\0>&9Y+_P`3Z+_PG\RS7BF^U$6J6L4:AHDE^9"_FDE45!N9
M]HP02*^2S?-,9A<;4HX3&SPN:O*\5A:^/C6@J6/P=>FG&$G%QJ5Z\KNE2]G!
M\U2C"M4^&I&'KY?EM&%!+$X9UL%]>IRH0F[3HS4*<E.I)<KE15.JFU?EJ*<7
M;16YJX^-?B&>>>:;6BTTLTLLK,EX6,LCL\A8J^TL6))(&"<D<45\X2^/M%26
M5!=K($D=1)%J*^4X5B`\>4SY;8W)GG:117SB7$#2?M\W=[.[JUTW?E=[*HEK
M>^B2UVUU]%RHQDXK!X2R=E_LN%>B:2U]F^ZZO??M_1%!\'X=3MI+T10P_;(3
M,&$30*%D9\00Y&WCS0Y*9.XEAP<5\X>*M9U'X(^+K-UC4O([R0,DFUKC[+,#
MQ(?E*,THRA52R@C>!D5]90?$`_V/::?]H;$4=M'$;,9V-L0"-HINL@(^9U;:
MW`S7D'BSX<VGQ!UZSU#Q#OFTZT\QA`L_DR/"58/'*I=2$:148JK,#@$G(Q7O
M<283*L#A88O)98JCF<9^UC6J23A&;FU6O348\SO:=.LW*$4ZB:JKV<*?A97C
MJG-['-;5,$Z<82I03<Y<KM%1YK+=1LW9W2OH[GE<_P"T5\1/B#))H7@FVO(_
M$-[.8UO;RZC33[4P@EXWE\MVMWCDB7RV#,=K;<D'CYF\7_L)Z3\7?$.K^*?C
MUK5U<^+]5_<1?\(Y(D,=F)G"O>W,H18KB[:-%1'E#.%=\,HD85]HZKXX^'OP
M#18]+T2TN)97E:6PLPC7T[I(Y/D@^=(TA5F#X*J1SA>:^<?A_P#M7ZS\;O%_
MC<Z/8^&_!NB^#]0BMIX];U>V@U^_DN#F-+'2YW\IWMU?<)0Y5I#$FW<2M<7]
MHXGZK@\9BL;F>/QDJC=+"PHU:6&IT_=E.O.-6KRMRNJM2JW>'+*<$W8[J5-_
MOE@<-0P.$G*%/VU62EB)2E9QI\\:<^2/N\S5I64?XEOB^>_B!^P-\(_@[^S_
M`/%_Q!X:U7Q*_BN+0=3^Q^*-:N9/ML:V\;36>CV5I:Y@(FD9HI)HXU:8-&IP
MBA1^0_[(_P"S5XF^-'Q1\/\`A:VT3Q-IK:'<7&M>//%%[J31^'8_#,%PL$4(
MLY;83C4881)]I@^ULINS"$5(RT9_HU_:1U+QS:_LYW_VF(RSZWK-OB86\<K7
MEA?75M%;110*P9FDE*RP@`$D@'()%>>?LA_"KQ/\-=/\9>._&U@VBR^)?#1M
M=,TR11;3QQ0))/+=:CN#,91C:H)'#[,8.![W#&*S#.\XKX*658NCEOL<&\=6
ME3EA'AYTZ46Z<G!J-6$E6C1HUYOGE",ZU)-\J>6/]GA,JHU'BZ;Q2Q57ZK15
M3V\I4JF)A1E-0M_RZC0;=9VLFTG91.#F^"/P)TV:73H_#27D=A(]DEY(B^9=
M):L8%N9/E^_.L8E;_:<T4Z[>Z>ZN75$*O<3,I:4HQ#2,064(0I(.2H)"GC/%
M%?I7/P['W?JO#ZY?=MR1TM96UQ+VUZ]]>WSEL0]?K>(UL]95K_9\M]O73N?;
M6C7NC:REIJ5K<K-IT,D5PJI<%D8QJ%AC*MRH=B78$8(8#'R@5TGC+XDZ?X6T
MVZDNUC@M+&`2.T4K32%82LTBF)%,K;\`,RD*5)!!!K\\?V=?B]+8>(+7PCXE
MO5N;._)_LMKDA;?S%+RK#&3.'D)DD*/D,(T1&(`-??5[X%LO%=M),EI:7<=W
M;^8EO,RW+-*S$E8KA8BT43("L<F3$RY0.6X/Y7A,5#B:C3Q.`HQ]O33^L4ZV
M'A-J4J=%N:P\VX^RJOV-3#T5.TYNU1.+DCV,5@991BWA\QE>G"5HNG*2C.',
MK1]JO>5M(3]UV=U:2U/&?#7Q.^%OB&];Q;X@NO#NBR337-K:W?B34(@K+#(T
M=R;:UOL>6[I'DGCAN.K8_/']O3P-\+O#FJ^!_BI\(5T>-/$FKWL'B6?PAJZ7
M^GWDD%M#>V>H7EO:R-;V<J74#JZ1-RT0<XD+5]"?M*WOQ/\`@>=`U2+X.:-K
MVE/=SB6\N=*MM>T:2QARDT+1VL3O;R",K'(I"RPL7:0`FOA[0]-\,_'GQC':
M?#[P=XM^'VJ^*M=L9_%7A+27>]^'>IO.&,\PL+S-SHUSB25M1CM/(2=XS&W[
MQ'->-*>=5)TL!BL+7EC88VE'ZO5HUX5\33J0C-PG2P3=256NJD882A'#2HU*
MG*ZN(E"G*M#W\)1P=%5<<L7&GA)X:?/*-2%2$91IW5U5A%\T;;N2<E=W5]/T
M5_9_B^*WQ@\%>&=6^(&K1S>!]$;2KW3K>>SFO)]6N]+ECGTY;>1DC2.WMG@$
M=V&:0H5(#$8-?6OQ0\2Q6WA&\2)$DGGBFLC&DS%C,%W2H+63=(%*DC@\\`9.
M#6OX5\,6_P`,?AUX?\*Z1L:+1M(M[2/S558S<0B,,QD"2,P-P[I\S*Y==K3R
M/R?`_BEK;ROI^G>8\;()9S;O+$R-<7)7;/(P;S@A$P="XV%03G:2:_>,-@,-
MPID-2-*E46,K+"RQL:^(JXSV^95(0HVE*M.JHSH7A3P].E*-.G3I4I<THTTG
M^?3KU,US"GSI*FN>-",8Q2HX6,E*%.*C&/Q2FY5)-WG4J2E:-[+PUKB0LQ\M
MUR2=OE70V\_=QCC'3':BK[1W(8@^43DY(GM\$YY(^?H3R**^"4<.K*5>A=63
MO.@G=<E[^\[.Z=]7UU/HE"EI[E?I_P"V_P!WST^79G#_`!.TK2]*\`_#/5M+
MTVPTW55U>R*ZG86=O9Z@I:*'<1>6\<=R"V3NQ)SDYS7Z>?!*1Y=/T&25WDD:
MSMMTDC%W;$7&68ECC)ZGN?6BBL,E_P"2AP/_`&+LN_\`4+#"S;_<7_V%XK_T
M_4/<O$EO;W>CZY%=00W,:)>[8[B))D7<)MVU)%95W8&[`&<#.<5^2/[,%G:1
M_&SXNO':VZ-;:T3;,D$2M;G[1=C,#*H,1QQF,KQQ117T]3_DY'"O_8=F7_J!
M5/*H?\DYFO\`U^P__IR!]T^,W?\`X1[S-S>8/L@#[CO`:YA+`-G<,DDGGDG)
MYKXV\=2R'7M0S(Y_=V:??;[A3:5Z_=*@*5Z$<8Q117TG%?\`R+,/_P!A%#\X
MG'E7^]K_``K_`-.4SDB3D\GJ>Y]:***^=I_!#_##\J9];'9>B_(__]D`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V%V871A<G,O9F5M86QE,2YJ<&<`````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`Q,#<U,``Q,#4Q-30S,S<V-P`P,C0T,S``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````_]C_X``02D9)1@`!
M`@(`3@!.``#_P``1"`"^`)8#`1$``A$!`Q$!_]L`A``&!`4&!00&!@4&!P<&
M"`H1"PH)"0H5#Q`,$1D6&AH8%A@7&Q\H(1L=)1X7&"(O(R4I*BPM+!LA,30P
M*S0H*RPK`0<'!PH)"A0+"Q0K'!@<'"LK*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RO_Q`&B```!!0$!`0$!`0``````
M`````0(#!`4&!P@)"@L0``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-1
M80<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$
M149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8
MF9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;G
MZ.GJ\?+S]/7V]_CY^@$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+$0`"
M`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2
M\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D
M969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2U
MMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,
M`P$``A$#$0`_`/JF@`H`*`"@`H`*`,7Q/XJT'PK:BX\1:O9:=&R.Z"XF"O*$
M`+;%^\Y&1PH)Y''(H`XNT^//PUNKJ&WB\3QK)*X13+:3QH"3@;F9`JCU)(`[
MF@#O]%UK2M=M7NM$U.RU*V1S&TMG.LJ*P`)4E21G!!Q[B@"_0`4`%`!0`4`%
M`!0`4`%`!0`4`%`!0`4`%`'S'\:OVCX[3SM&^',V^]BFV3:NT:/$`N"1"#D/
MDY!8C&`=N[<&`!\I7=S/>74UU=S23W,SF2665RSR,3DLQ/)))R2:`(J`"@#U
MCX?_`![\:^$[H"[U"37M/=]TMMJ<C2/R5SLE/SJ<+@9)4;B=I-`'UE\+_B[X
M7^(%K;1V5['9ZVZ`RZ7</B56PQ(0D`2@!&.5S@8+!2<4`>B4`%`!0`4`%`!0
M`4`%`!0`4`%`!0!\Y?M0_&#4?"UTGA7PK<QPWT]L6O[I.9;8,1L6-@WR.5#$
MY7(#H5(/(`/CZ@`H`*`"@`H`EM+F>SNH;JTFD@N87$D4L3E7C8'(92.001D$
M4`?5OP$_:"M9+"+0/B)?^3=Q;8[359LE9P2%"S-_"PS_`*P\$`EB",L`?3E`
M!0`4`%`!0`4`%`!0`4`%`$5W<P6=K-=7<T<%M"ADEEE<*D:@9+,3P``,DF@#
M\R_%6O7WB?Q'J.MZK)OO;Z9II,%BJYZ*NXDA5&%`R<``=J`,J@`H`0]*`$#`
M^QH`=0`4`%`'TY^S3\;8]/ALO!WBZ?;:+YGV35;JZ1([9%0%87W8POROM8L3
MEE4#&,`'UE0`4`%`!0`4`%`!0`4`%`'B7[5WCQ_"G@,:+:12?;O$*2VZS#;L
MBA7:)<Y!R65]H`'\1.05&0#X>H`*`"@`H`:5!H`!G/4XH`=0`A('6@`'(H`^
MTOV1/'?]O>#I?#.H3[M2T7'D;WRTEJQ^7&6).PY7@!54Q"@#WV@`H`*`"@`H
M`*`"@`H`^!/VBOB+:_$/QO'/I#7/]C:?#]FMO-8A93N):4(?N;LJ.>2$4G!^
M4`'EE`!0`4`(3@4`(`3R?RH`-PS0`H(/2@!C_>H`<G2@#IOAWXPU'P-XML-<
MTN20-"X$\*/M%S#D%XFR",,!UP<'!'(%`'Z0:3J%KJVE6>I:?+YUE>0I/!)M
M*[T=0RG!`(R".",T`6J`"@`H`*`"@`H`^0_VC_CE_;/VKPGX+NO^)5S'?ZA$
MW_'UV,<9'_+/L6_CZ#Y<EP#YMH`*`"@!"<#-`#5R3DT`*QP*`(Z`%7[PH`5S
MSB@!8^AH`?0!^@'[,]S/=?`_PQ)=3232*DT8:1RQ"K/(JKD]@H``[``4`>G4
M`%`!0`4`%`'P]^T5\3?%FI>/-9T$W%[HVDV#RV0LH97C^TQG@R2]-XD7!`/R
MA2,9R68`\2H`*`"@`H`:_3\:`%`P,4`,8Y/TH`0<F@!YPHXZT`,ZF@"0#`Q0
M`M`'VW^QSJ%U>_"6:"YEWQ6.IS06Z[0-B%8Y".!S\\CG)R><=`*`/<Z`"@`H
M`*`"@#YR_:8^"L_B.2Y\8>%(Y)M95%^W6()8W2JH4/&/[X4`;!]X#CYN'`/C
MZ@`H`*`"@!",B@`YH`BH`4'!H`.IH`>HP/>@!U`!0!]M_L<Z?=67PEFGN8MD
M5]J<T]NVX'>@6.,G@\?/&XP<'C/0B@#W.@`H`*`"@`H`*`/SJ^.>E3Z-\7_%
MMK=/&\DFH270,9)&V8^:HY`Y"R`'WSUZT`<-0`4`%`!0`4`-*B@!-GO0`X`"
M@!:`"@`H`_07]G'3[K3/@IX6@OHO*E>&2=5W`Y225Y$/![HZG'49P<&@#TF@
M`H`*`"@`H`*`/@3]J'_DNGB;_MV_])HJ`/+*`"@`H`*`"@`H`*`"@`H`*`.O
M^$_@R?Q[X\TS0XA(+:1_,O)4S^Z@7EVSM8*2/E4D8W,H/6@#]!=:UG0?!F@)
M<:K=V6D:3;((H@Q$:`*I(CC4=3M4X102<<"@#Q'Q+^U1X:LO,C\/Z-J6J2I,
M4WSLMM$Z#/SJWS-S@8#(IP><$8H`\[N_VJO&#74S6FC:!%;%R8HY8IG=5SP&
M82*&('4@#/H.E`'OW[/GC_5?B-X,O=7UNWLH+F'4'M56S1E0J(XV!(9F.<N>
M_I0!Z=0`4`%`'YR_&;Q/:^,?B=K^N:>N+*XF5(&R?WB1HL:OR`1N"!L$9&<=
MJ`.+H`*`"@`H`*`"@`H`*`"@`H`]C\`?%FR^%>C:KIWA+2(]3U:[>,S:Q=SN
M(9=G9+?:K!!N<*2P8[MS`?ZM0#S'Q+XAU?Q/JLFI>(-1N=0O7R/,G?.T%BVU
M1T506.%4`#/`%`&50`4`?27[%&O6-EXC\1:)<R>7>ZE##-;;BH5_*W[E&3DM
MB3<``>%8\8H`^O*`"@#YM_:C^,/]D0W_`(&T!<ZA<0^7J=S(GRPQ2)GRT!ZL
MR,,MT4'CYCE`#Y#H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@#J?A;XJ_P"$
M)^(&B^(&B\Z*SF_?(%W,8G4I)M&1\VQFQDXSC/%`'Z2T`%`'R'^TS\)_%>H_
M$#4_$^@Z7<ZKIMW#`\GV95:2)PHBV",,7?A%;(7`#?[)-`'@6N^'-;\/^1_;
MVC:EIGG[O*^VVKP^9C&=NX#.,C./44`95`!0`4`%`!0`4`%`!0!WWQFMO[(U
MW1O#C:?]@GT+1K6UN$\[S=\[J;B5L\@?O+AQ@$CCC@@``X&@`H`U="\.:WX@
M\_\`L'1M2U/R-OF_8K5YO+SG&[:#C.#C/H:`-3_A7/C?_H3O$G_@KF_^)H`M
MZ7\*_'FIW\5I;>$=;263.UKFT>",8!/+R!5'3N1D\=30![1\)?V:M335;#6/
M'<MM;06TRS?V2@6=IMK'Y96Y0*2%.!OW*Q!VF@#ZRH`*`"@`H`X;QY\*/!WC
MB22XUW1X_P"T'1E%];,8I@2H4,2O#E0JXWA@,=,$@@'SE\8OV<_^$2\.:EXA
M\-:M<W]E9[7>QN(-TR1<!W\Q.&P?F/R*`N23\O(!\[T`%`!0`4`%`'L?[*7A
MK3O$?Q6C;5%D==*MCJ,"(^T&9)(PA;')`+[L<9(&<C((!Q?Q=\2IXO\`B5XA
MUN%HWMKBY*V[QHR!X4`CC;#<@E$4G..2>!TH`Y"@`H`ZGX9>-+[P!XQLM>T]
M/.\G*3VQD9%N(F&&0D?@1D$!E4X.,4`?HWI.H6NK:59ZEI\OG65Y"D\$FTKO
M1U#*<$`C((X(S0!:H`*`"@`H`*`"@`H`*`/S_P#VA/AXGP]\>26^G0R)H5\G
MVBP+,S[!T>/<0,E6[9)"LF22:`/,:`"@`H`*`/H+]BMH/^%D:RK1R&Y.DN4D
M$@"*OFQ;@5QDDDK@Y&,'@Y!`!\^T`%`!0`4`?7G[&OC?[=H5]X-O'_?Z=FZL
MN.L#-^\7A<?+(P.223YN!PM`'TE0`4`%`!0`4`%`!0`4`>+_`+67A?\`M[X5
MS:A!#OO=&F6Z4I;^9(8C\DB@CE5`82,>1B(9Z9`!\,T`%`!0`4`>Q_LGZ_!H
M?Q?M8;H1K'JMM)8B624((V)61>OWBS1A`.,EQ]"`<A\6O`E]X`\8W^F3P7/]
MF^<WV"[D1MMQ%@,,.54,RAU#;1@-D>E`&?<^!?%%KX27Q/=:'>PZ$SH@NI(]
MH.X`JVT_-L.0`^-I)`SGB@#FZ`"@#N?@9JL^C?%_PE=6J1O))J$=J1("1MF/
ME,>".0LA(]\=>E`'Z*T`%`!0`4`%`!0`4`%`%#Q#I4&NZ!J>D7;R);7]M):R
MM$0'574J2I((S@\9!H`_,"@`H`*`"@"UI.H76DZK9ZEI\ODWMG,D\$FT-L=&
M#*<$$'!`X(Q0!^DO@;Q=I'C?PY;ZUH%QYUI+\KHW$D+C&Z-U_A89'L0002""
M0"7QGX:T[QAX8U#0=961K&]0*YB?:ZD$,K*?4,`1G(XY!&10!^<'BK0;[PQX
MCU'1-5CV7MC,T,F`P5L=&7<`2K##`X&00>]`&50!:TG4+K2=5L]2T^7R;VSF
M2>"3:&V.C!E.""#@@<$8H`_42@`H`*`"@`H`*`"@`H`*`/RQH`*`"@`H`*`.
MT^%/Q%U?X<>(UU+2F\ZTEPEY8NV([E!V/]UAD[6QD$GJ"P(!^@'A'Q3HOC#1
MEU7PWJ$=]8L[1F1`5*L.JLK`,IZ'!`X(/0@T`>;?M&?"5_B)HUOJ&BF-/$6F
MHPA5@JB[C//E,_4$$$J2=H+,#C=N`!\1Z_HVH^'M9N]*UJTDL]0M7V30R#E3
MU^A!!!!&00002#0!0H`_1#X)^/K'Q]X(L;J*]^T:O:PQPZG&ZJDB3[?F8J.-
MKD,RD<$9'!!``.^H`*`"@`H`*`"@`H`*`/RQH`*`"@`H`*`);2VGO+J&UM(9
M)[F9Q'%%$A9Y&)P%4#DDDX`%`'KWP\^&WQBT*Z@\0>$M&O=-N71XPTTL$3LI
M."KPS,#C(R`R]E8=C0!]H^#[C7KK0+67Q7I]E8:LR*98;.X,R`[03G*C:=VX
M;07`P/G:@`UKPGX=UVZ2ZUO0-)U*Y1!&LMY9QRNJ@DA06!.,DG'N:`/,==_9
MK^'NI>1]CMM2TGR]V[[%>%O-SC&[S@_3!QC'4YSQ@`BT7]G'P[H5T]UHGB?Q
MCIMRZ&-I;/4(XG9202I*Q`XR`<>PH`])M/#NJ074,LOC/7[F.-PS0RPV(20`
MY*MMMPV#T."#Z$4`=)0`4`%`!0`4`%`&!\0=0NM)\!>)=2T^7R;VSTRYG@DV
MAMCI$S*<$$'!`X(Q0!^:%`!0`4`;7A'PMK7C#65TKPWI\E]?,C2&-"%"J.K,
MS$*HZ#)(Y('4@4`?47PZ_9=TRQV77CN^_M2?G_0;)VC@'WA\TG#OP588V8((
M.X4`>\>&/"N@^%;4V_AW2++3HV1$<V\(5Y0@(7>WWG(R>6)/)YY-`&U0`4`%
M`!0`4`%`!0`4`%`!0`4`%`'@7[8WBK^R?A_:>'XXMTNNS?.[+E4BA9';!R,,
M7,>.",;NAQ0!\74`%`'OOP5_9]U?7]5AU+QS87.EZ#%\_P!EF_=SW9#$;"OW
MHUXY)`)!&WKN4`^O?#7A[2/#&E1Z;X?TZVT^R3!\N!,;B%"[F/5F(499B2<<
MDT`:E`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0!\2?M#Z/XS\8_%35;RS\+>)+
MC3;3;96;C2Y-I2/[Q5E4AE:0R,&R20PZ=``<_P"%_@'\0O$'V:3^Q?[,M)]W
M[_4I1#Y>,_>CYE&2,#Y.X/3F@#ZH\`_`KP7X1_LF[_L_^T=<L,/_`&A<._SR
M\_.(MVQ<$_+P2N`<EANH`]3H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`
M*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@#__9````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O879A=&%R<R]F96UA;&4R+FIP9P``````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#(R,34U`#$P-3$U-#,S-S8W`#`R-#0S,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#_V/_@`!!*1DE&``$"`@!.`$X``/_`
M`!$(`+X`E@,!$0`"$0$#$0'_VP"$``8$!08%!`8&!08'!P8("A$+"@D)"A4/
M$`P1&18:&A@6&!<;'R@A&QTE'A<8(B\C)2DJ+"TL&R$Q-#`K-"@K+"L!!P<'
M"@D*%`L+%"L<&!P<*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M*RLK*RLK*RLK*RLK*RLK*__$`:(```$%`0$!`0$!```````````!`@,$!08'
M"`D*"Q```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$(
M(T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%56
M5UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBI
MJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W
M^/GZ`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@L1``(!`@0$`P0'!00$
M``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A
M)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V
M=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&
MQ\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`
M^J:`"@`H`*`"@`H`S-4\0Z+I-PL&JZOIUE.R[UCN;E(V*Y(SAB#C(//M2;2*
M4)2U2+]O/%<V\4]M*DL$JAXY(V#*ZD9!!'!!'>F2U;1DE`!0`4`%`!0`4`%`
M!0`4`%`!0`4`%`!0`4`%`!0!XS\8OA+=>)M6FU[0)X!>O$HFM)<KYS*I`97)
M(#$!%"X`XR2*SG"^J.RAB5!<LCP66#7O!/B*%Y8KK2M6M6WQLRX/!*Y'9U.&
M&>589ZBLM4SMO&I'NCN_#7QR\3Z==LVL^1K%JW6-T6%UX/W61<#DC.0W3C'6
MJ51]3&>$@U[NAZ?X.^-WA_6MT6M+_8ET952)9',L<@/?>%`7!Z[L`#!SUQ:J
M)[G-4PLX_#J>GV%[:ZC:1W6GW,%U:R9V302!T;!P<$<'D$?A6AS--.S)Z!!0
M`4`%`!0`4`%`!0`4`%`!0!YW\7/BUH/PTM85U$27FK7*,]O86Y&\@`X=R?N(
M6&W=R>N%;:<`'S;=_$_XW>+;6:]T:SU:/2;U"B?V1H[-$!C8WER[&<'(/(?(
M.<$8&`#@+;X9_$/7]997\+Z_)?7;O(\]];/$';EF9Y9<+D\\L>2>Y-`%O4OA
M+\2?#%U971\-:LER'\R"73L7#Q,A!#9A+%""003CIQT-`$W@SXT>,/#VHEM0
MU2ZU_2IR%O-.U28SI<1X(*AGW%,ACR."0-P8#%`)VU1[?\./$?PD^).HM#J/
MA^#0-=DV@6LEVT4,Q+;%6$HRJS?<RNU22QP&P34\D398BHE:YH>-_@+):VGV
MGP?=SWDB[0UG=L@=N3EED^5>./E('0G/05#I]CIIXN[M,\[\$^*M:^&WB*X+
M6+J[JL=U8W8>,E<A@<<8;&<,0<!CP<U";BSHJ4XU8[GU%\/O&FF^-M%%[IY\
MNXCPMS:LV7@<]CZJ<'#=_8@@;1DFCS*M)TW9G3U1F%`!0`4`%`!0`4`%`!0`
M4`?"G[6>E3Z?\9]0NIGC:/4K:"ZA"$DJH018;C@[HF/&>"/H`#[ATG4+75M*
ML]2T^7SK*\A2>"3:5WHZAE."`1D$<$9H`M4`%`&!XQ\&^'O&5@MIXFTFVU")
M/]6T@(DBR5)V.N&3.U<[2,@8.10!\A_&KX`:GX-\[5O"PN=5\-Q0^;.TC*9[
M7&`Q<`#>O.[<HX`;<`%W$`E^!7QZU'PI=66B>+;F2\\,*BP12%-TM@`3@@@;
MG09P5.2`!M^[M8`^MM8\.>&O&%C%<:A86&I0W$*&*[3!9H\[EV2K\VTYSP<$
M$]C2:3W+A4E#X6?.WBGP]KWP>\6P:MHD[R:;(Q6"X89613R89@,#.![9QN7!
M!"XM.#NCT(3C7CRRW/;OA7\0[/QQIA1PEMK5NH-S:@\$=/,3/)4G\5)P>Q.L
M97..M1=-^1W=48!0`4`%`!0`4`%`'@7Q6_:0TCPQ?MIGA.WMO$%WY)+WB7/^
MC0N1\@!4'S?5@"H'`W9SM`/._"GQ$^-_Q)UF23PI)':6+.$>2.QB6TML;`W[
MR568GY@Q4,S8)(&.*`/HW6/AUI'BGPYI>F^/5_X22[LLO]NE7[-(SG[Q'D[=
MJGCY0<85<[B,T`=5I.GVNDZ59Z;I\7DV5G"D$$>XML1%"J,DDG``Y)S0!G7'
MB[PW;7$L%SX@T>*>)BDD<E[&K(P."""<@@]J7,BU3F]4F1_\)IX6_P"AET3_
M`,#XO_BJ.9=Q^RGV9OTS,*`/#/B]^SUI'C._O-:T&Z_L?7)\O(A3=;7#X;EE
M'*,Q*Y<9'!.TL22`>0_!KXHZO\(_$<_@[QW!<QZ-',4DBD&Z33G/.],9W1MG
M<0N00=ZY)(<`^R$:SU7359&M[W3[N'(((DBFC8?B&4@_0@T`G;5'R_\`%3PK
M+\,?%NG:KX:OG@@N6>6T`),ENRXW(2>&7#@#.<@D,#U;"2Y7='IT:GMHM21[
MM\*_&\7CCPZ;MHTM]0MV$5U`K`@-C(=1G(5N<9[AADXR=8RNCBK4O9RMT.SJ
MC$*`"@`H`*`/`OVO_&E]X>\'6.@Z>FS^W_-2>Y$C*T<49C+(`,9W[P#DXV[A
M@[L@`X#]GWX"6OB/2K?Q-XWCN1I\V_[+IA!B^T(579,75@P4Y;"X4G"MDJ<$
M`^M[2V@L[6&UM(8X+:%!'%%$@5(U`P%4#@``8`%`'EG[2_C76O`OP]M[_P`-
MSQVU]<ZA':F=XA(8U*.Y*ALKD^6!R#P3WP0`3:XVH>/?AG8V.I%M(O[ZWMYK
MQ5BR%?"NR%&^90&[;@1@9)Y!\NKC]7%+J>IA\)RM3;Z'C][\'M>B\]K:ZT^X
M1-QC7>RO(!T&"N`3]<>_>DL9![HZ^5G.ZAX!\46,*RSZ-<,I;:!`5F;/T0DX
MXZ]*U6(IO9BY6)X-\6ZWX$UF>;32(Y"#%<VERAV.1D8=<@@J<X/!'(Z$@[QE
M;5&52E&HK2/J+X5^-XO''ATW;1I;ZA;L(KJ!6!`;&0ZC.0K<XSW##)QD[QE=
M'F5J7LY6Z'9U1B?/O[8G@R#5/!,'BJ$1QWVCNL<S'`,L$CA=N=I+%792`2``
MTG<T`7_V2/&G_"1?#]M"G2Y-[H&V)IY9-ZRQ2,YC`)Y&T*4V]`%7!YP`#M/C
MKH_]L?#75-D'G7%EMNXOGV[-A^=NH!Q&9.#^`SBHFKHWPTN6HCP7X%^)I?#W
MCRS@)=K/5&6TFC7)^9CB-L9`R&(Y.<*S8&364'9G=B:?-!OL?7-=!Y04`%`!
M0`4`?'/[:VH74GCW0M->7-E;Z9Y\4>T?*\DKJYSC)R(DX)QQQU.0#Z7^$&JV
M6M?"_P`+WNFI'';'3XHO*B#A(FC7RW1=Y+$*RLH))SC.3U(!M^)?$.D>&-*D
MU+Q!J-MI]DF1YD[XW$*6VJ.K,0IPJ@DXX!H`^/\`Q[X@F^.WQCT_1]+DD/A>
MQ=A#(L)C=8<*9I2<,06*@+N`'^K!`);.5>JJ4'(UHTW4FHGTY7SI[H4`%`',
M>-O!>F^+(4-T7@O8E(BN8@-P'.%8?Q+DYQP>N",FMJ5:5/;835SY[LKC5/!W
MBF"X$;VVIZ=.&,;D@$CJIVD95AP<'!4]<&O6A--*43&<5).+/LCP3XAB\5>%
M[#6H('MTNE),3D$HRL589'494X/&1C@=*ZD[JYX]2'))Q.'_`&H?^2%^)O\`
MMV_]*8J9!X#^Q;_R5+5/^P-+_P"CH:`/LK4;.#4=/N;*\C\RUN8FAE3)&Y&!
M!&1R.">E`TVG='Q-;F7PCXVB-RB7$^CZB#(D;D+(T4G(#$9`)7KC\*YMF>P_
M?AIU1]P5TGC!0`4`%`!0!\Q_ME>!;J]MK'QK8_/%8PBSOT:0#8AD_=.JXY^>
M1E;DGE,#`8T`<_\`L@?$6UTB_N?!FJM;6\&H3&YL[EV*L]P0B>4>WS!05Z<@
MCYBR@`'N?Q1^#?AKXD:K9ZEK4VI6U[;0^0)+*95\Q-Q8!@ZL."S8(`/S'.>,
M`&3X1^%?AWX;W-Q_88NKBYN4&^ZO'5Y0N?N*550%R,\#)/4G`QY.82?.H]+'
MJ8&*Y7+K<Z>O..X*`"@`H`\8_:#MH5NM$N5C`N)$EC=\GYE4J5&,XX+M^?TQ
MZ&"EHT1):W.Q_9:U'S=`US3/*Q]GNDN/,W?>\Q=N,8XQY77/.[VY].F]#S<9
M'WDS;_:A_P"2%^)O^W;_`-*8JT.(\K_8<_YG7_MR_P#:]`'U/0!\G?M"Z/%I
M7Q'N)8-@34($NRB1A`C'*-TZDE"Q/'+'ZG"HK,]3"RYJ?H?3WA;4)=6\,:1J
M-RJ+/>6<4\BQ@A0S(&(&23C)]:V3NCS9KEDTNYITR0H`*`"@"AK^LZ=X>T:[
MU76KN.ST^U3?--(>%'3ZDDD``9))``)-`'YW_%B^\+ZCX\U.Z\#64EGHCO\`
M(K<([?Q/&F`8T)Y"'./]D$(H!>\/_%/X@^$(!9:?X@U&WA,,0C@NU$ZQQA<Q
M^6LH;8I5@1MP"-O4`4DT]AM-;GWAK:SK:V"W<D<MR$(EDBC*(S87)526*@GH
M"3CU/6O-S+[/S_0]#+_M?+]3(KRST0H`*`"@#S;X]_\`(GV?_7^G_HN2NO!_
M&_0F6P_]E3_F:/\`MV_]JUZ]+J>;C?LGI_Q=\-/XO^&OB'1(5D>YN+8M;I&Z
MH7F0B2-<MP`710<XX)Y'6M3A/'/V./#FM^'_`/A+_P"WM&U+3//^R>5]MM7A
M\S'G9V[@,XR,X]10!])4`?+W[34\4OQ!M4BE1WATZ-)%5@2C;Y&P?0X93CT(
M]:PJ;GI8->Y\SZ"^'O\`R(/AK_L&6W_HI:VCLCAJ_&_4WZ9F%`!0`4`?)O[;
M>O;]5\->'XI+E?)ADOIDSB)][;(SC/++Y<O4<!^#R:`+/[-7@"WTW0HO%6IV
MN=5O-QLS(#F"#H&"D##/R=W.4*X(W-GR,=7<I>S3T1ZF#HI1YWNSAOVL8)E\
M>:7<-%(()--5$D*G:S++(6`/0D!E)';</6NC+VO9M>9ACD^=/R/K^_O;;5]%
MTS5=/E$MC=1+-#)M*[T=0RG!`(R/7!J,QB^6,B\!)<S1E5Y1Z04`%`!0!YM\
M>_\`D3[/_K_3_P!%R5UX/XWZ$RV'_LJ?\S1_V[?^U:]>EU/-QOV3WZM3A"@`
MH`^,_B[J/]J?$KQ#<>5Y6RZ-OMW;L^4!'GH.NS..V<<]:YYN[/7H1M32/K7P
M=9SZ=X1T.RO(_+NK:Q@AE3(.UUC4$9'!Y!Z5NMCRZC3DVNYKTR`H`*`"@#Y#
M_;;TCR?%/AK6?/W?:[*2U\G9]SRGW;MV><^?C&.-O?/`![%\-O\`DG?A;_L%
M6O\`Z*6OG:_\27JSWJ/\./HCQ;]KW_F4_P#MZ_\`:-=^6_:^7ZG%F'V?G^A[
MQ\+-1AUOX(^$KNT61(X+**W82@`EH086(P3P60D>V.AXK;'Q;I7[,QP4DJMN
MZ/'?!?B#4?A7XFF\)^/+B2?2M0N'N-/UN5V*,S$;@Y8G:"QRW]UF).5;>.:K
M3CB(^TI[K='33G*A+DJ;/9GNM><=Q7U&^M-,LY+O4;J"TM(\;YIY!&BY(`RQ
MX')`_&G&+D[)";25V9OA/Q1H_BW3I+_P_>?:[2.4PL_E.F'`!(PP!Z,/SJZE
M*5-VDB:=2-17BSD/CW_R)]G_`-?Z?^BY*WP?QOT'+8?^RI_S-'_;M_[5KUZ7
M4\W&_9/?JU.$*`"@#S+7?@YX3O\`7;O7+^:_B668W-Q"+A5A)SN?)*[@"<DX
M88R<8XQG*,5JSIAB*EE"*/1=/O;?4;*&[LIEFMY5W(Z]"/Z'MCM50G&<5*+N
MF8U*<J<G":LT6*H@*`"@`H`\,_:[\(R:_P##F+5[*W\Z]T.8S,1O+"W<8EPH
MR#@B-B3T5&.1R"`<3^S#XQM+OPM_PC-W-!!?V,K?98V8*UQ&Y:0[06RS*=^<
M``+M]Z\C'T6I\ZV9ZF"JIQY'NBS^U?\`\D[T[_L*Q_\`HJ6EE_\`$?I_D/'?
MPUZGH?[.,1F_9\T!%SNVW)&!G.+F4X_2O1Q,'.E)(X,/-0J)LX#5_A[KWCKX
MAWDOCUXSX6TYV;2XK.14\T,4^5N"^-J8?)!W'Y#BO-CB(4J:]E\3W_K^O,]"
M5"=6H_:?"MCS'X<^`M<UC6O%R>"O$UWI6DV-P\%O=Q3.%OF5F\H%X\*1MY+#
M.-X(4[JZZU>$8Q]I&[?X'+1HRE*7)*R7XF!XET;5[GX?>&?&7B#7K_6+"ZNY
M(&LY[A_,A^9@?+=MX^80G)P,';PW;2$XJI*G&-G8B<).G&I)W5S[`T#0],\/
M:<EAHEC!96BX.R%,;C@#<QZLV`,L<DXY->+.<IN\G<]>$(P5HHX?X]_\B?9_
M]?Z?^BY*Z,'\;]`EL3_LJSRM;^)8&E<P(UNZQECM5F$@8@=`2%7)]AZ5Z]+J
M>;C5LSWJM3A"@`H`I:Y:27^BZA9PE5EN+>2)"QX!92!GVYK.K!SIRBNJ-:$U
M3JQF]DTSQSP=XGNO!-_=:7K%K+]FWEI(E4>9&^!R.<,"`.^,8(/KX>&Q,L+)
MTZBT/I,9@X8V"JTGK;Y-?U_D_+VC3[VWU&RAN[*99K>5=R.O0C^A[8[5[T)Q
MG%2B[IGS-2G*G)PFK-%BJ("@`H`*`/E/XR?LWZC<:S?:UX`6R:VN'WG1Q^X,
M1.T'RV8[""2[8)0*.%!X%`'E?C+PK\5-8L+N]\5Z5K,]IX=B\J26Y0!40$@N
MO_/;[N6D7=P`6;&#6<*4(7Y5:Y<ZDIVYG>Q]$?L9W,\_PIO8YII)([?5I8X5
M=R1&OEQ-M4=AN9C@=V)[UH0>BW,8BN98U)*HY49]C7S=2*C-Q71GT%.3E%-]
M48'A/POH_A+3I+#P_9_9+224S,GFN^7(`)RQ)Z*/RIU*LJCO)BITXTU:*#PG
MX7T?PEITEAX?L_LEI)*9F3S7?+D`$Y8D]%'Y45*LJCO)A3IQIJT4;59EGGGQ
MTMII_!4<D2;DM[M))3D#:I#+GWY91QZUU81I5/D3+8H_LLZA%'J^OZ<ROY]Q
M!%.K`#:%C8JP/.<YE7''8_CZ])GGXU:)GT36QYX4`%`!0!SOCGPU'XFT@0!U
MBNX6WP2LN0#CE2>NT]\>@/.,5RXO#*O"W5;';@<6\-4YMT]SQSPAXCO/"VLJ
M)S<_8U=EN;3..>A.T]&!`]#QC(S7AX;$2P\];VZH^DQF$ABJ>EKVT?\`73_A
MSWC1=3M]8TNWO[(L8)URNY<$$'!!'J""*^BI58U8*<=F?)UJ,J,W3ENB[6AD
M%`!0`4`5=6T^UU;2KS3=0B\ZRO(7@GCW%=Z.I5AD$$9!/(.:`/D/]C[7)-!^
M(VL>%]2C^RRZE"5\J:)Q*+B`L?+/]W"-,3N'50,@\$`^H?$$12_+\E9%!''I
MQC]/UKQ<?!QJW[GKX*:=.W8S*XCK"@`H`H>(+.34=!U*R@9%EN;:2%"YPH+*
M0,X[<U4'RR3?<&>"?"#73X3^(UD^H.]K;RLUG>!U5=@;@;MV-H5PA)X("GZ'
MW825[G'B(<\&NI]A5T'DA0`4`%`!0!R7CSP?::_I\T]O"L>JHI>.5``92!PC
M'C(.``3T^F0>+%X2-:+:7O'HX#'SH349/W?R\U_6IY/X+\0S^$]<D:>&4P-^
MZN8#E6&#UP?XE.>OJ1QG->-A<0\/4U6G5'T&-PL<72LGKNG_`%T9]!PR1S1)
M+"ZR1.H9'4Y#`]"#W%?2IIJZ/CVFG9[CJ8@H`*`"@#XS^)\J?";]IZW\1Q01
MO8W+KJ+0H6D?RY@T=P<,1\Y;SF49VC*]N``?7NMVXFL78#+Q_,/IW_3^5<F-
MI\])OJCJPE3DJ)=&<M7AGL!0`4`%`'B_QM\)PVVS7].@V"63;>J@.-Q^[)@#
M`R<@G/)*\9)-=^$JM^XR)+J=E^SSX^^WVD7A34_^/JUB9K.=I,^;&#GRR"<[
ME!XQQM7H-O/J4Y=#S<51L^='MU:'$%`!0`4`%`'E7QC\.2NXUZV$7E(BQW*@
M!6SG"OG^+J%]1@=1T\;,\.W^]7S/?R?%I+V$M[Z?Y?J/^"^N*8KG1KF=0P;S
M;5&)R0<[P.V!@'`]6//.'E=?1TV_3]19UAM56BO)_I_7H>I5[!X(4`%`!0!\
M^_MF>&GU+P'INO0+(\FCW)64!U"+#-A2Q!Y)WK$!C^\<CN`#:_94\;_\)3\.
M4TJZ?.I:#LM7X^]`0?);A0!PI3&2?W>3]Z@#N=1MS;7DD>,+G*_3M7SV(I^S
MJ.)[M"I[2"D>:^._'TNA:H=.TVW@EGC56EDFW$+D$[=HQS@J<Y[XQ7;A,`JL
M.>;T/K<GX?CBZ/MZTFD[V2M]]]?-6L<M+\4===0%@T^,[@<K$V3@Y(Y8\'I^
M/&#S78LLHKJ_Z^1[,>%L&GJY/YK_`".T\*_$.PUN\2SN8&L;J1L1;G#(_3`W
M8&&//&.W7)Q7!B,OG2CS)W1X&8\.UL+3=6$N>*WTLU\M=/G\K:G6ZE86NIV$
MUE?PI/:S+M>-NA']#W!'(/-<$9.+NCYT^=_'W@[4_`>K64XF`M[EFFL+B&7Y
MU"L",G`(<`H<@8R>#P<>W&_*I/JCFC.,VX]CTOX7_&N"#3XM,\:RSF2+Y8M1
M"&3<@!XE`^8MP!N`.<\XP6.T:G<Y*V%;=X'N>D:G9ZQIEOJ&F7"7-G<+OCE3
MH1_,$'((/(((/-:IW.*47%V9;H$%`!0!%=V\5W:36UPN^"9#'(N2,J1@C(]J
MF45).+V94)N$E*.Z9\WZK9W7AKQ)+`'Q<V4P:.3`YQAD;'(Y&#CGT-?+5(2H
M56NJ?_#'VM*I#$T5+I)?\.?1NG7<=_I]M>0AEBN(EE0,.0&`(S[\U]3":G%2
M75'Q=2#IS<'NG8L51`4`%`%#7]&T[Q#HUWI6M6D=YI]TFR:&0<,.OU!!`((P
M00"""*`/@ZVEU[X#_%]FD@DE:S=U"2$Q)J-HQ(#?*2,,`&'W@KJ,@E2*`/MK
M0]:TKQUX8M=5T*ZAFBE5'P)%9H&*JQCDVD[7`897/!Q7/B:'M866YT8>M[*5
MWL>9^/?A]_;6H2WME.MO?D!94ER4D(P`<C.T@#L"#@=.2>/#8UT%[.:T3/OL
MFXA^JTE2J1O#HUNKZ_/7TMY['$V'@37;+5HY+O0XM2M(I,/%]K6-9EZ<,&##
MU!^F0>17H?VA0:^*WR9]#6S[!U:+5.LX2:T?*VT_2S3\_P`'U/0[_1[GQ)'8
MVMYI&GZ!H,,AN)=.LV5I)IN5!9E4`#;Z<X_#;RULQC%-4]7W/EJ.,IX%SJ4Z
MLJM5KE4Y7LH[Z)MMN_?3\;]K86YNKI(AG:3EB.P[UYE"DZLU$^>K5%3@Y'4W
M]E:ZC:26NH6T%U:R8WPSQAT;!R,@\'D`_A7T)X:;3NCYQ\<?`W6;74)KCPMY
M%]92RDI:[Q')`I+$+EVPRJ-HW;LDGIWK&5-]#T*>+BU:1YA_Q/\`PGJ'_,4T
M6]DB_P"FEO(T9/X$KE?ID>U1JCI]V:[GV+X!N=9O/!^EW'B:#R-7>+,Z%`AZ
MG:2HZ,5VDCC!)&!T'1&]M3R:JBIM1V-^F9A0`4`>5?'#3_\`D&:DD7]Z"63=
M_P`"08S_`+_('U[5XV:T_AG;R_R_4]_)*OQ4V_/_`#_0ZWX9WK7O@K3FDF66
M6)6A;&,H%8A5('0[=OZ'O7;@)\U"-WM_7Y'GYG3Y,3*RLGK]_P#P3J*[#@"@
M`H`*`.+^*WPZTCXC^'&TW55\F[BR]G?(N9+9SW']Y3@;ES@@#H0I`!\>^'-<
M\6?L^_$*^M+VQCE:1%2XMY)'\F[AW@K+$PP,X#!7(.W<X*YR*`/=M!_:)\#^
M(M,:3Q%]J\/:C$/N-$]RCY+<(\:Y/`!.Y5P6XS@FN;$X>-57ZHZ,/7E2?D4-
M8^/?@BP\G[+/?ZGOSN^R6I7R\8QGS2G7/;/0YQQGS8X&J]]#T)8VDMM3S7Q#
M^T=K-W;"+0M&M--=D=7EFE-PP)'RLG"@$<GY@P/'''/7#+XI^\[G+/'R:]U6
M.Q_9B^+FO:]XZFT#Q5J45U'>VS/:$VJH_G)\Q4&-0,%/,)W?W!@@G![*=&%-
M6@K'+4JSJ.\F?5%:&84`%`!0`4`%`!0!YU\;;B)=`L+9FQ/)=>8JX/*JK`G/
MU9?SKR\UDO9J/6Y[620;JRET2_7_`(!+\%/^15NO^OUO_0$JLJ_@O_%^B)SK
M^.O\/ZL]`KTCQPH`*`"@`H`^??VU+:!OAOHUTT,9N8]62-)2@WJK12EE!Z@$
MHI([[1Z"@#S7X&_!;P[\2OA[>:I=7NK6&K07,MH'CEC>$L$5E?RR@;`\P`KO
MYVGD9P`"S_PS1_U-G_E-_P#MM>9_:7]W\?\`@'H_V?\`WOP_X)Z#I7P4\%:=
MI5S:+I\EQ//;R0->W+B250W\2@C8KKQA@H(Q[G/++&59.]SHCA*25K'R]I]Y
MKGPN^(@N(!''K.CW#+B2,M'(,%3PP!*.C'!X.&!!!P:]N$U.*DNIY$X.$G%G
MZ">`?$]KXR\':3X@L5V17T(=H\D^4X)5TR0,[7#+G`!QD<&J)-^@`H`*`"@`
MH`JZGJ-GI=HUSJ%S%;P#^)VQDX)P!W.`>!S45*D::YI.R-*5*=67+!79\^>(
M-6O?%WB))3$HFF98+>%2`%!/RKDXR<GJ?7L.!\S6JSQ-6_?1'V&'H0PE&U]%
MJV>Z^$-)DT/PY9:=-*LLL*MO91@99BQ`]AG&>^.U?18:DZ5)0?0^4Q==5ZTJ
MB5DS8K<Y@H`*`"@`H`\"_;2_Y);I?_89B_\`1,U`%K]CNPN;#X1SW-W&(X+W
M4IKB!RP.^,)'&6X/'S1N.<=,]"#2;25V-)MV1W=?,GT(4`>._'WX1W?BS36\
M3>&+..35K-2+JWC4^;>Q@#!7!^9T`Z8RP.`2553Z^7N3B[['EX]1YE;<\9^!
M_P`6M1^&NLE)!)>>';IP;RR!Y4]/-CSP'``XX#`8.,*R^@<)]N>`_&V@^.=&
MCU'P[?QSJ45IK<L!-;$Y&V1,Y4Y5AZ'&02.:`.DH`*`"@#FO%WC'3O#6(K@2
MS7KIOC@1<9!R`2QX`RN.Y]JY,3C(4-'J^QW83`5,3K'17W/%-7U?6/%FI1_:
M/-NI_F$-O!'D(.I"J/;OR<`9/%>#4JU<1+75]CZ>C0HX6#Y=%U;/6/AYX)CT
M&);[4563577@=1;@]AZMZG\!QDGV<%@E17//XOR/G\QS%UWR0^'\_P"OZ\NX
MKT#R@H`*`"@`H`*`/E/]HOP]XU^(WQ9L-`TG0KU='L$6*WOI86%J6D57EE:7
M9@``*I7+<Q\#<VV@#Z`TK1(_"/@/1]"LFC\NR@CMWDBB$0E(7YWVC."S98\G
MDG)-<6/DXTM.K.O!14JFO1%.O%/7"@#J](M7M+39(1O9MQ`[=./TKWL)1=*G
M:6YXN)JJI.ZV/#_C5^SU:^,=5FUWPK=6VEZO/\US;S(1!<N6&9"5R4;&XG"L
M&..`2S'I.<\!TOP9\6?AMXCBO=&T+6[74C"1YMC;B\C9&R"K;`Z'E<[6Y!"G
M'0T`?9GPK\3ZKXK\)0WWB#0;W0M6C<PW-M=0-$'8`'S(PWS;#GC/0@C)QD@'
M7T`>;_$/Q\VFRMINA2*;U&_?W&`PB(_A`/!;U].G7IY6-Q_(^2GOU9[>799[
M1>TK+3HN_G_7Y;^=:'HVK>+M4E$+M-,%W37-RY(48P-S<G)Q@#GIZ`X\NE1J
MXF>FOFSV:^(HX2"OHNB1[;X3\*:=X;@'V5/,O&0++<O]Y^<\#^$9[#T&<XS7
MT&'PL*"]W?N?+XO&U,2_>VOHCH*Z3C"@`H`*`"@`H`*`"@`8!E*L`5(P0>])
MI-68TVG=%273;.1@6@4'&/ERO\JPEA:,G=Q-HXFK%64B2VM(+;/DQA2>IZG\
MZNG1IT_A1%2M.I\3)ZU,PH`*`"@"*[N(K2TFN;AMD$*&21L$X4#).![5,I**
M<GLBH0<Y*,=VSYDU:\_M#5;V]V>7]IF>79G.W<Q.,]^M?)U)\\W+NS[FE3]G
M3C#LDCZ(\):+'H&@6M@H4RJNZ9U_CD/WCG`R.PSS@"OI\-15&FH'QN+Q#KU7
M/IT]/Z_$V*W.8*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`KZC:1W^GW-G,
M66*XB:)RIY`8$''OS4S@IQ<7U1=.;IS4UNG<X_3OAIH]AJ%M>0W.H-+;RK*@
M:1,$J01GY>G%<,,MI0DI)O1_UT/2J9O6J0<&E9JW7_,[BO0/*"@`H`*`"@`H
M`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@#__9````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O9G)A;F,N:G!G
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,C8W-``Q,#4Q-30S,S<V-@`P
M,C0R,34`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!
M_\0`'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`M1```@$#`P($
M`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R
M@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ
M<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#
MQ,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!
M`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W
M``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8
M&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ
M@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*
MTM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#ZR_X.
M8-(\7ZU^W#_P3/'PXD^&\_Q#T#X4?M;>(O"V@?%";5+70?%4]MJ'P8M]6\/6
M-YI$R7]GKUYX6E\1W>GWL-GK$5C'I]U=ZAI;Z?%<W-M^0?[,7[7'PX\6_M!?
M`SXU_MQ>!?&_[/G[/GP"\::]_P`(5XWT;2=4^-'[/WQ+_;"M=2T/P;81:O\`
M%?X<>#-5T:UT7X0Z=XDU+7?"UU:Z]=^';KQO)>ZG+X@O8O#9T[4_U*_:-_X(
MW>!?B5XTTCXQ?!C]I/\`:0^&OQA\`Z/K6G_"R?XL?$;6?VJ?AMX:?Q!X=U+P
M_P")8I_"7[1%S\1/$36/C*WOA'X@M$\;3V$,4<;6>F23V\+U^G/@OX"^!](_
M9[\0?LT?"FS\->!_!LWPP\9_#;1[/P[I2P>&O#E]KFFZII]_J(\/:7<1VXGA
MUK5]0U6ZLIKN%DU*ZGD:X-Z4\W^4N-/$3A7.ZM/'X7"5\3/%X*.65*M2,\MS
MC)L+75>&8..)5+,,!5A6I8B$</#V..E3JK'U:<L+46%JUOZ/X<\-.)LGI8B.
M8UJ&%C@)K,,+3A*EC\!FF*C.D\/2=!5L%C*=2E4I*=:K*MA8I1PE.<<12G6C
M1_%3X&_LR:W_`,%X;/XB_MK?MY?M6_$G]E?_`()F:A\;+']G/]E;X$_#[Q-I
M_P`.I/C!>_\`";6_A#P5XL\=7/BBT\7>!TUW6_BCKGA;0M-N]6TGQEJ^J_$6
MV\1^#]#?PAH?AWPY>:SS?_!37_@W_P#@K_P2:^!VM?MQ?LY6&K_M>?!;X0:7
M<P?%?]E;]K[5-8\4Z-#K7Q"6Y^'/A_X\^%+[X,Z/\/-)U.]^'^M^)?"+^(?"
M?C3PLVG_`/"#V_BW7+'QOH?B.T\-7FA_6W["_P"VA^Q+^S]^RG\'?^":/_!9
MSX7WGP#\5?L,_%U->^`OQ,^)GA'XMR_`3X]:W\$?B!J>N^!?C/\`!WX@Z/X>
ML_M>IZ)=>(V6[\.:GYFAZMH%]!YZWMKK6M>$=$TO^"O?_!<OX`_MG_"?4?\`
M@FK_`,$W-#\;_MD?%K]JE]+\&^.-;^'7A.\T[PKHWP9F)UCXC+X-\3^+VTA7
M\?RZ5IS:?::[J/AC4_A[X,LT\1ZYXJU6"YT2UTV\_HC+<#PY@^'*&'RY86AP
M_'!7A6PN)]A1>'C1O5Q,L;AYT>2JZ<)3K8SVL*MU.=2JG=GX7CL7G&(SFM6Q
MGMJF:RQ3YZ=>C[:HJLJJY*"PU:-7F@IRC&EAN2<;.,8P=TG]Q?\`!-__`()$
M?\$>O@/X9^+?_!/J]\%?"#]KO]JKX4^#/A;XH_;&\7?%3X<+K?B>YO/C#I=U
MXE\%OX=N=>T^\TKP1X/GT[2?M7A?PGX`U^XU'0M"ET>_\9:IJGB;Q#>:YK-K
M]D+0?A9_P2<_X*;?M/?L1^!C;_`S_@GC\1/V.++_`(*$^';KXI^.["T^&'P:
M^+_AWXN^$/@'\8[/PEX[\;SQ:EI'@SQ5H_B;X8ZCK&D>,?&.K6/AK6]%L_\`
MA'WTRQ\0/8+C>!O^"]O_``2U^'7[0WQ@G_:,^"WQ8_8;_;$;P#\-]#^,:_%#
MX2Z5XI\7>.-'T#P5=^-O`_AB7QW\!=<^*<7BZYTQ?$5YH/@6T\7_`-@>+]:E
MUC1=+M-$M9IFT;1_Y\?VZO&_P?\`V^/^"A7Q2^,7[6W[!G[47B+QE\<?@XWP
M(_X)-_LQZGH'C'X7^+?BWJ/PCU^ZT^Y\7_&W3_#?Q`\,_$GP!J?BOXA^,=7\
M2:;<^*-)\->`_!WP/L?%6JZZOB77M)\,ZMK/7C<YP>!PV'KQOF%;'2I_4<+E
MGL:^)S%RC3DY8.,Z].G7A1PT_K-:JZT80P=.IB'*,(V7-ALNKXJM5I-QPM/#
M1D\36QTITJ.%4>9)5W&G*=.56LO8TX1IRE*O.%*S<FS^Y_\`X>,?\$]_^C[O
MV-?_`!)_X)?_`#<45_GF:+_P9[_\%3-2T?2=1U'Q5^S#X>U"_P!-L;V^T#4O
MB7XBN]1T.\NK6*>ZT>_NM%\#:IH]S>Z9/(]E=7&DZGJ.F33P226%]=VK17$A
M7K\S[_\`E.?^?K^';7S^7T_\#BNWW;_+Y,_6KXG?`C]OS_@E[_P4,_8B_9(T
M?]N^X_:-_90_::;XA7'@[3/VD/`T.I_$70=`^$Z^'?$7Q%\$:C\3-%T2_P#$
M&K^,AX+N96^%FL7'BC3?"?VWS-%U/P=H%G'8SZA^E_P__9Y\;>#_`!E\?[KP
M?\88?A]I/QQ^,7@/XN:+=^%?`YU#Q;X7UNQLO!FD_%+2]:O_`!YXH\;^#M>L
M_BIH?@FP\)V\OAGP%X`_X0W2=2U'6+>+5?&\K>,#]_\`_!7S]CSXJ_M._`7P
M#\1_V:%F?]K?]D3XK:!^T!^S]I2^*/\`A$K#X@SZ?'-X=^*/P8UW5[B5=*MM
M&^+OPOU;Q)X5>75$2S?5'TJQU*_L?#]_KQF_.OX!?M$^"/VWOV=9?B!\'?%?
MBKX<ZAXETOQ#X4U0BQT*/XG?!+XC:<U]H6L:;JN@^(M.\0>'O^$H\%^(;6>6
MTBUK1];\+:\MG;WAM-8T&^V7'\L^,>1U<FS/"8_+,%@\#E&84*>%QU:E@,'*
MC+&0QWUZ%?&TJ>%DJG.U"$95J=:MB(X7$4ZKJQKRC5_IGPCS7#Y[E&/RG,\;
MC,;G.#EB<3EE&MC\4JCP=;+OJ%3#82=;$J,(T[N<J<'2IT)8BA7HN$\/SX;Z
MX^.WQ1_9A\#>$;FV_::^(OP(\'>!]0O])TJ[MOCIXM\`>&_"FH:O*LVL:)I]
MU!X_OK?1+O4I3I-QJNDVTG^E3)HMU?V\7F6KSQ_BE\0?$O\`P1._:,^,$7Q%
M^'/[?-K^R!\7_AIX!U/X.S?$7]GW]H6W_9(L/$WPPN_%VM^(SX*T+5?&NA6/
MPJ\=^&XO&VI:EXV.L?#6TN;K5-2N-(UK4M;U+1T\/[_N/]FG_@G=^QW\!=2U
MGQ???#6V^+WQG\8:?!%\1?CU\?+V_P#B_P#$[Q]?Q3)=:CJFHZIXXO-8TGPY
M)K=VTE]JFD>`-&\'Z+<M8V$7]F7MQ!8)!]Y^+?A!\&/B7H-IH'CCX7?#?QWX
M;M="OO#.GZ5XI\(>'?$&E6'AR[M5T^XT'2XKK3YX[/2Y;.!+-[*S^SV?EJL0
MMXUB#5^/X/,,ER*NXX3&\454XU*<\;A:N!RVA+VE*,*Z665J>91Q=&H^>G%8
MC%X6;IQI5YTX5%["G];F&4YSC$H8_`9+2DG"K##5X8K&U4J<^:ERX^E/`QI3
MARJ4GAZ%:$9NI0C5E']Y/QS]D;]EK]F#]F[P$;K]F7P_HDVG_$RST?Q1X@^+
M,7B>\^(WC;XT/=QW5]I?C'Q=\6-8U#7==^(2WT>M7^HZ-,VN7.AV%KK<T?A>
MSTW1I!91^&_\%(?A?\2(_"OPI_;/_9VTRXU#]J']@CQI>_'7X8:9#J5Y;0^/
M?A\]C:P_M#?!J;1K71_$5OKDWQ=^%6F7GAO2]-AT^UUJ'Q*FC_V'XCT%I+J.
M]^[/AM\,OAW\&_!FC_#OX3^"?#'P]^'_`(=_M`:'X,\&:1;:)X8T:._U"[U*
MZBTW1;..WM]/@N=2U&[N]MND<4;WC"V2)H_*7\POBD?B1_P5U\<W?[$W[+4/
MB#2?V,]-\8)HW[<_[;%M9:EI_@;Q%X,\+ZFT/CK]E7]G77+[P^=(^(_Q'\;7
MGDZ+XK\=^$_$%YHGPRT6TU2'Q#::HFNZ3INI^IP#A>(\^X]P./R*MC,5B<)F
M-/&XG-,?)\]'+8U%1JSS":JSBW6P4IX9X2G6FZRE.A1YJ:E*/C\68C)<IX3Q
M6%S:EAZ%'%8.IAZ.7X.*2J8V4(U8QPL7"/+[+%QA7]M4@G3NJU1^U:YOU^^&
MO_!7W]C3XH_#GP!\3-#F_:!LM$^(O@KPKXZT>SOOV5?VB=0OK32_%VA6'B#3
M[:\O_"OPW\2>%[VZ@M-0ABN+OPWXBU_0;F9'FT?6M5T][>^G*^UOAI^SK\%/
MA)\./A_\*?!'PV\(Z?X,^&7@GPI\/?"-A<>'](O;BR\,>"]"L/#>@6D]Y/9-
M/=S6VE:;:0RW,S&6=T:60EW)HK^\/9R_Y_UONH>7_3CU^_R/Y2YU_P`^Z?WU
M?+_I[Y/[_(_F4\#_`/!?#]O7X.W=Y)^V-^PU\*OB9X,TS6VNM=\:_L<?$+Q3
MI7C#2_!$?A9[JZO_``]\$_B_#K,OC_4=,\2Z??173P?%?PI-J&FW]G9^']`U
M>]TYKS6/RC_X*5?'+7?CW_P5=_9]\>?\$(T\":GXC^)?[.WA7XR?M*_%3X8V
M6M:7\-?B%K/Q/\0^,M6T\?M>Z=<QV_@:2^\)>#4L[HMXET.'XI:-XO\`%VH>
M$;B7_A8GA_P_H.@_T5^+?V*](U7P8/$<`A>Z:SAU-K*8&YV;YI@LL4307=O+
MNM+A;ZYO;EH91;YMWBL#%/<2_@#\./B!X6_X)2_\%$_BQX>N_@#\1?''P._;
M"^&'A;XR>*?$GPC^'VL^+]3^$'B7X1ZOXB\-^,-9'AWP]\WB?P5<2>--&\2_
M$2XLM.?Q#I-_XFT*\M],UY]7C_M#YOC%8V/#>:5,MRFAGV/AAI+#97BZ<:U#
M%<_)"LJE&<HK%*%%U<1'"M_[35ITJ5-JIR-^_P`*SP?]O9<L=F6*RC!O$)U\
MPP51T<3AW!.=%T:R7^S\]:-.E+$VFL/3G4K2C.,91/3OC5^TU_P6%_82^!Y^
M/O[3?@/]B/XM?";P%9:'K?Q1U;PGXE^)?@/QY<7/BGQ7#X9LOAQX?0Z5?Z%#
MXEMM9U;3-(L?$,7@_6-%^RI]JU6WD<O?3?0G[4G_``5G^+W[&_[._P#PT1XY
M_80^(-MX4UC6/#FD>%M1\5_M0_L>IX5\6>(?$\PDETO1M3^%/QG^-/CCQ%J<
M&BV.J:Y)8^&_AMKM]96FEMJ.N'PYH+:IJ<?P%_P6U_X*=?L;_M"?LK_`#X=_
M!#XZ^'/&VA^*OVK/#>H?&7P?)'XY\+7^G?#7X0Z=XHDUKP]\6OA#J.BZ-\2X
M=#O/'UUX-U31-'\3^!AH^N:EX2AO].$DFGVFI6/R_P#\$CO@!H/[0GP?_:%^
M&GQ9\%:5\8?V+7^*]KJ?[/\`9>.;+Q'%8:3XBU/1-9G\<S?#*WUJPTCQCX/L
M[2/7=,T^+Q9H$VE7"ZG)XGNM/>YF;Q;<3?D/!'AUD_%.21S7BWAF&6YD\RQ]
M-8'"T\?DD7AJ-2E"-/%X*->,J$EB(8FG^YIX=JBZ48I.*F_TWB_Q"SG*,QGE
M.0<0ULPRQ8+!OZUC)8#.*BKN$I2JX7'2P\IR;I.C*7/6K.595G*;C)1C]R^$
M/VZO@-^V):^)=5_;[_X*1R)^SE>:QJNO6G[$_P"P%^RU^VC>ZY\5="@US3+S
M3_@O\3?VNY/@?X1U'5-.8:9>^$-;TSX8W/@*7QU_PD=QXAU7QYX&T>$:#8_N
M9\$?^"XW_!,;X">"?AK\%])^!'[7_P"R#\#_``OX=N_#GPZF\;?L/?&SPW\-
M=+L/#-J;F30]*3P9X>\:>(-3U:ZEE>:[N+?1-4OM1UF]FU#7K]K_`%">\G_(
M/]GKQWX@_9!_:&\%_P#!/;XF:S)XG^&/C'P!KGBK]C?XHZLZ6WB*^T7P3+!_
MPDG[.WBM+:"YBU;Q+\//#SOKGASQK=_V?'J_A"&PT[4OMOB1HHIOV=\$^'+7
M4W@\X6\C*Z;G8Q)&9/M+I%']MD6*VMXTDW&:ZDG4E58Q3&WB6:W_`'+*,DRG
M(<(L%D^78/+L.FI2IX2A&DISY8Q=2JXVG6K2A&,95JTIU)*,.:4E%'X_F&9Y
MAFM=XG,L9B<96:LIXBJYN$;MJ$$_<ITXRDW&G3C"$;M12O<]#N?^#CG_`((N
MV-Q<66H_MM:)I.H6<TMK?Z7K'P7_`&D-'U?3;VWD:&ZT_5=)U/X.VFI:7J-G
M.DEO?:=J%K;7UE<QRVUW;PSQ21J5VUU^RUX?N+JYG;P]X)NVGN)IFNKNSD%U
M<F21G-Q<@V%P?M$Q;S)LSSGS&;,TOWV*]/5[-6Z>Z]M.M_/^K,X+KS_JWE_7
MR9]3>(P/^$1\2-@;AI=V`V!D!M-U`L`>H!*J2.A*@GH*_E5_;5U;5-._X*Z?
M\$O;/3]2U"PM->\+_MNZ3KEK9WES:VVM:7#\*K;7(=-U:""1(M1T^+6]%T?6
M([.\6:V35=)TW4%C%W86LT114T_M_P"*/_IJF/[%/_!_[=(^X_'O@CP7K6FZ
MA8:SX0\+ZM8ZII-[:ZE9ZGH&DW]KJ-M->:?:RV]];W5I+#=P2VVHZA;217"2
M1O!?7D+*8[J=7[GP[ING:9HND6VFZ?9:?;0:;:1P6]C:P6D$,;6UN&CBB@CC
MCC1A#$"J*JD11@CY%P44W_$C_@J?^E4QKX)?XH_E,_*O_@K.[Z5!_P`$]?$V
MENVF^)+#_@I3^SCH-CX@L&-GK=GH?BC2OB#:^)M&M-6MS'?V^E>(K:RL[?7=
M.AN$L]7@M+:+4(;B.")4_>7X91QMXL\.VS1HUM-KS6\UNRJ8);=M2F#021$&
M.2$A5!B92A`&5X%%%:=%ZO\`*))]Z^'YI9M!T2::626672--DEED=GDDD>SA
M9Y)'8EG=V)9W8EF8DDDDFBBBLET^7_N,S73Y?^XS_]D`````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V%V871A<G,O9G)E9&9L:6YS=&]N92YG:68`````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C,T,``Q,#4Q-30S,S<V-P`P,C4W-#$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````1TE&.#EA(``@`/<`````````
M,P``9@``F0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!F
MS`!F_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_
M,P#_9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,S
MS#,S_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,
M,S/,9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`
MS&8`_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9
M,V:99F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_
MS&;__YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF
M,YEF9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,
MS)G,_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS
M,\PS9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9
MS,R9_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`
M,_\`9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]F
MS/]F__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__
M,___9O__F?__S/____B_)```````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"'Y
M!`$``-@`+``````@`"````C^`+$)'#B0!!(```@B7+B0H,.'V`X"0(*-H<6)
M$"%>W'@QXT".("UZ#$FRH<:0*TB1`J""U"I2*@#D04CB)$=2SW*F7)5S9<R1
M$S?RS/F,U(J41P'5]%@Q*,.A.@.Q6B%U!5.!!A'JB;F"Z+-5)%9,%;OT:L45
MI8SB)+IJA96I;\M>);'6ZS,]1EE-+;6"A%^S+9_8+8KW**DGI5:]E/N0!*`G
M==DFALJ6L4,`.^T:/3KXJV6"+3GW-*QV,*G/6'&J[`G995'(BA7#9$J"\F&5
MHHV24*'B*$6/M;VFU%W7:!Y2:570AMKV=DJOMWLJSQ@\9UN>8%M"AYQ3Z<.%
M==N^$EV!<*=LP<]*,08``<*!YU^[]K3H%S[8RQ`L6'"/MOGXBZYYYA`2)1P`
MP0470#"<?$6IP`8;"XFFGD,D=-+)"@=>8,$!!P!07%]AX=9=``D59.$E&"*8
MX'N1*6976PE`4&*%G?`VQPH&JLA?9'8!8J",6-6HTA.77)@A@OR5,A@@*\08
M@(DJ\'28A0'DB*2"=97"Y``0/`GE4%.J<&.&'#[`(HX!<-DA015&291:*EQ2
MI04KROBC@0=<LE1````[````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]G87)F:65L
M9"YG:68``````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S`T`#$P-3$U-#,S-S8W
M`#`R-#8U-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!'248X.6$@`"``]P`````````S``!F``"9``#,``#_`#,``#,S`#-F
M`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_
M`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F
M,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_
M,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F
M,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_
M9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF
M9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_
MF3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EF
MF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__
MS```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9F
MS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_
MS/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F
M_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG_
M_\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````(?D$`0``V``L`````"``(```"/X`L0D<
M*!"`01($$Y(P"""APX$,`<Q!Z)!$GH@/'48D,5%A'A48,Q(T.''B)8K8+*HH
M:5#D2``D+JF(B9)$)Q(J3K9T*9"CBDZ=3DY$PC$FT)4H>=KL-)-$T8E.?][D
M23"F$Z!`G<RYBM7)2:H]3U["&M0H5K%)'\+,<W/%"J=N`;B%^Q;HPHP+EZY@
MQ<HMW[U]`<,\Z;0B6Z8X65V[]I<$X,6L0$K]6C6K'Q6HJO#MF^E3)L"LJJ!2
MX>?J78@P,5-!Q5J%:Q4K/JUXC9GUZIRGL0W&+&TTJMZL43D)_MMW;ZDUC_YV
M3=PUT]JM51RW.W!II^'1G0?;_IPY:ZZY#Z)FW1X,*/GSYK>#WUD0@(KS\..C
MWYZ[?2?Y^,__#$:Y\LVE3N3'52>#I57=0@;MAQ]B#!E($!('79+?=CH!@(1(
M3A$U5H`3:G506D[91)B"$U8X5H@IE4786.]-&,Q/*QKE%&%.F623B[A!-2-"
M3F&%(`DNEI>7CQ3=R!U,]P5Y4Y)"AN655T8&^>(E3U(&4TD+D:7EEF5AV5![
M$84IYI@A!00`.P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A=F%T87)S+V=O<&AE<BYG:68`````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(S-#0`,3`U,34T,S,W-S``,#(T,S8Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$=)1C@Y82``(`#W````````
M`#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`
M9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`_P``
M_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS
M,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\SS``S
MS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF
M`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!F
MF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF
M_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"9
M9C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9
MS,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,,P#,
M,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,
MF<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____``#_
M`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_
M9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/___P#_
M_S/__V;__YG__\S____XOR0`````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````A
M^00!``#8`"P`````(``@```(_@"Q"1Q(L"```$A(%%S(L*%`)`>1.)S8D`2)
M@Q8I:L1&0D4>/8!`ZE&A<./"CGKR.%$!:(430"%)FAQ(0D_*$@"JD*H"@,3+
MD"4I8LR39\4*``&<5+D(0(5'4GJ".CR(=$4@5H&L!`!@E14K*Q[S4&5XD031
MBX&L7;/V%<#5:]?:4@5P\BP@4D59P85FQ<J*K]#6!NJ9$B-!LU54D,+[%V[<
M0'\#Q[5B=K&**E$/5UYL52W6HVD%K\BS&"_+S`]9EBYZU:H5KE<ADRY-RJ,>
MN@)KTM[I%(!?JDZ=[(9Z&?=FVBJ<.)E[T(G*X7B#DAC^G-1RJL*MSZ8-J.3Q
MU;15PCJG/7ZW][OAH0^W6'ZQ=^KJ=[=?W#TW^OC0B5+WOAU_^/ZK20=??O.5
M5A]-L[5T5W^`Y&$1@`$69%9+K#RQH'(K793=?F15\5>%>BQ&6DK5[>:@0VC%
M9:&(&.[68$83P1;7"O?MIL=1!VE4E5Z0A4C;C2N\=A1%)*P0``M6+5661;!Y
MM0(+`4Q$`@M04EF"$Z,XX5,56EKA))4L2'48F%4&D%26H^21)0D!/$FFF!R1
M6264!IB)I9I.'$FEGF$.%!```#L`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O9W)E96YH
M96%D+F=I9@`````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#8R,@`Q,#4Q-30S,S<V
M-P`P,C4P,C8`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````1TE&.#EA00!-`/<`````````,P``9@``F0``S```_P`S```S,P`S
M9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9
M_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`,S,`
M9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F
M_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_
M9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68SS&8S
M_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,
M9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`S)D`
M_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF9
M9IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G_
M_\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF
M9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,
M_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S
M9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9
M___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/____B_)```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"'Y!`$``-@`+`````!!`$T```C^`+$)
M'$BPH,&#V%8`6`@`H<.'$",B5,APX0J)&#&NN/B0X8I`K:Y=8W7-BL*,*`]2
MY(AP82"2(EG!#-0PI4TK%0%0-*B0A<AK@5BL8'%EY`HK-C.N/"2352":-0<"
ML!)3Q@,$+!X\D"&(%<ND$%W*M"*#ZK6=4F<BX,I*D%4KK**"/<C"HB`K#R[H
MM?`@$-"-4G_*@/!S)(*U.><69.@W[P4(%O0^$&DR+64(30-AR\EPX$:+-AF*
MC"PC1Q<$%BS$9`G`;TD$&U>H4`'`0(PM6V@OC+&YXE>(%,TBDA%2,&:1G'4N
M#,,\S")&C`P9TKU".J-8V&,=4HC6X4(N/P/^R2A<T@(BY`P-P*@-H[GSY]+%
MY*YB*+O]6-(-Q=#Y4"',:Z>Y)I(,%\#$D`T\).@><XL\!UUT6T!WWX2Q`.*1
M2@`4UL4%,L#$2EX_L4";#6"4N&`8C#CX(".PP$+AA(9PL1]_!"E$W@5\O21#
M9#]9$8-Z/)CH7H,KKHB?="_>QT5GG@'P'U`/I";E>")5$08,)`K9')&&%,DB
M%[.IP$62V3VQ4(T`4%E8("L@\``BQ5V#7Y!:;NDE="Z*`8A^7*S`Q2K8U6<?
M(+H1A-,*3XJ$"%+DQ<((G74Z!UV7*[J(W2$ZT19#GRJL$$-^%,F%S:&)DO?3
M(8:$42(8)Z+HI8O^TAT2`R20K``(8$TR:9!+IIK*2G191JHB(V+@"8LJ*NQ'
M"RU(<)>21;V2%PBQP;(Z)'1AQ+""&-)Y<@D;)`"P+"0>(:617=&NI,*JUB[8
MZ7].68$3"22PP08MM$*"Q)GGZD1>O.DA&&D86V@KH+1.R8:OO4B0$%IR'*4W
ML&C1FDH1N+])%.J%`H6ZJGOK+52QJ3@!@`0;2(`5VT$F`5"G`;Z5VFM="2'A
MB6(/&?#QE<DE>A=Y_,J`LT,X[9P<NB,)\B^-0SND4+MA',T0"_*:NAEO37OG
MLJH\)V?(%C5MS!#66;<$@'NZ<28&;;EREG'9O;D'<TX&@"UJKGH\8>;^9W?C
MO%QS<U>TA2'\%E2R'LDD;J9O92]D`^"<;2'&5`<MI$<IB2=32K@5F=LT3@8P
M%_@3>N0-VF(`E*Y"YHF34(HGNC;]=]J8)ZY'X9X]H7GIK*N`>>Q#+W1#&+HA
MSKHG9A9T>3)Z<)>Y\<`''_IZQK.N>-@`)%X*?QM9OSC<`IV]GR?)K$2^[13I
M7LH3!`'P1.W)G/XV6`!LP0,`I=R^$&W6+]\\"^&KR!-6DI#3#6T%[4D=0U10
M!?=9+W$<$5M%I&)`G,F&>(M;B-VJIST*;J1EH-D8`.?"M+.%86.,V()"7,>\
MDVRD5%`QF;[Z)A%SE4PJHJN(=`KH/H\`(`;^T9(!`.Y%"]PY3538BTKHHE81
M;B%%A)Z2V4BJ`(EEA6M^!0E5QQCRF#/5+PR!VY\A<%5`F8R,%55<%K.,:)!#
M<<\*!T"`7@[`D"T0CS/2Z50``2$OF;'""FH<U[ZP&#Y$L6DA><G+#G1`QPBE
MD#,J,(2L5"#%PMR+<T0D%PV;1!(VH>8";MH!*,_VH.1\*@9FZ96'+G&)BB`!
M7VS<U0I$$HC(7.`J.]@!`D+GH+1Q)DZ]`HD55`$(A_6F8;&4)2L(=(%<ZN`P
M7PQ#JE+HRX4`8F0BJ4[RVA<]#"%`!\W,Y0[HN$05&$`%W")<3BH9DQ@9L67G
M^J8.Q!F$&7B*>'3^!``#8[0Q;)8D%LX""TX0<`"M!.&@02B#0KV0`QG,P`LS
MV%\,#K&D#$7K$%:(Q2I.HAB%1/0`7"`#0A6JT$20(1$FI4@D5]&G4LF$"_6Q
MT"8SHA,/B92D)45I(OC6$(5,%%6"LL]VDODLUP3")#+`J4Y-:H6C\NL[+Y)5
M-U-BDE;(9`4'D`$+O%`&E';5I$)D'$4`-:%0$5(C@F`(2;OPPK-T85&(B)Y9
M)=BTV*BUJUTX@%E6(`-$C"664CLK3?ECD2XH-`>N`4`73((HIS"M;5--BD+,
MM9`$P4`&BY4)`/)I$7B"[XBY2A!U-$NCDG'LLX;C)HGN%SZGWDV+J.UUB`J"
MQ-K->-8A(XQMY=H3!AZHH)"/U2U*`,!;Y@1PIL+M2'%/V!OD)K<E[6E0U)K[
MW-"H0%+$ZE1PJQN1'TIS4G83+'>;1*D517:\J"OO@[J#7MD6J4ON%"]W=V,L
MH1*UO26KPG4FM(KSCI<B,=COA/P+MX```#L`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V
M871A<G,O9W)E;6QI;BYJ<&<`````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,#8S
M-``Q,#4Q-30S,S<W,``P,C0U-#8`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1
M"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%!@<(
M"0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!
MD:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I3
M5%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6F
MIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T
M]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$`
M`@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S
M4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC
M9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.T
MM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`
M#`,!``(1`Q$`/P#^=SXF?LIZMX)\*ZEXET;6%U^+2;V^N;VU%LT%W!X:15:T
MOF)E\B2YL<S2:XRB*VCL42\MUC%K=I<?)C6ES"Y6>UFAQ-<VKF>&>-8[BU5?
MM<;@*'$UDLL<MQ%AGA#1F:,JX5NNMOB)XLLT=+36=5M@U[J-ZGE:[XB58WU.
MU:UN8C#_`&P;>YC=/*,LE[#=75ZMM!:ZE<7M@KVC^[?#KX(^*_'+:9?2:-/9
M^&-0\3Z'JTOB_3;_`$6SCCL=.M;RV\06-CHDMU)%?O'J;PP:'JMMIKZ)9K:Z
MK-I=G<:=J$6GU_5&*H8?BO.L+A.#.&LPRZI7P[=;+'B,1G-*G*G4A1>-6,HT
M)U\+AG4Q&%I5I8G#_5J$I>WJ8BC1E4=+]?QV1<,>+7%>7X+P=X%X@X?KRP]*
M.8Y![3%<28*$:<Z<'FBQ].BZF78>4ZD<)B)YFZ6`C7GA:]7'86&(KQP_;_#[
M]GG1_B/X*77?["E\#ZD\82PN7U63Q#H7BB/=YQNFT^=5U31;,3VULL%QI'B6
MYFEMKF]B-Y<J6B7Y;^(7PV\0?#753HWB%8EO$V_/%D6MY%(9#!?Z1-)L;4M+
MG6-T-R(H+JRO(IK/5+"PE-F;S]*K7QIIGA#1H])^'WA>0:+;B22[\:>/M2N_
M!?A9KV581)?ZAXA\0V<VL^(K]F\S[9]EL)I`MA+:1W$,=LB6_G?QDLH?B)\*
M]2\3ZHWA%];T36+33?"^I^'&U/4&U<:I)9:?<>'&76-(L98KF\NK\/;21+J%
MM:7-O:ZGOLI;.XF@_1^(."^&J_#5"64XVE+B_*,HJ9CFM;!TYPR3/,+E]'VN
M/EA:JP6`P%6&'A6BL'F66T7]9=&&$Q];'8R7M8_TYXF^`OAWF'A__P`8M/#T
M/$?A3AUYKF>89=AE@L@XCH99@YXC-(1EALMRS),3*-##U88+,LIPM&G4QE.E
MA\TKU<;C959_FR00%)Q\PR,,I.-Q7Y@"2IRI^5@&VX;&UE)Z7POI8O\`48KB
M:[-C9:=(E]?W,<D]O=P6-NP:>XTZ=(9(O[12=K.STV%F\V?5]1TN%()8I)WA
M[C3_`(6:]K>NZ-X6T.'4_$$DVF+KDXL$(T__`$ZY%L);6]99=/L-/FB@LXYO
M$=_(+"?R)6L1J4D%A8W_`$/QDTC_`(5W/9^`+2:WEFL;.S?Q#=6MI')IU_JU
MW8S7ITZW-X'N;.S\.Z=K-@^F6[&YGO+O5;GQ/?3P:Y<>8WXU#`8UX*KF=7!U
M:>6T<33P;Q5:G*&'Q./J^TJ4<MHRG!JMB)X:A7Q.*A3C+ZGA:525=PJ3HPJ?
MQGA^`L[RC+\SXKS_`"JO0X>X?QN!P$ZM5<V%S?/\73^L87(<)B(_N<7^[I5\
M1FM3#U72PF`P]9*O+%U\OHXSI+;]I?6M&MX-(LO`WPTCLM*ABTVTCF\-7.J2
MI:V*+:VZ2ZG;^*;>WU&18HD5[^"W@ANV!N(H8DD5%*^7**]ZGQMQ93A"G#.\
M1"%.,80A3P^"A"$8*,8QA!85J,(J*48IOE6ESVH>/?BM2A"G3XKQ=.G3C&%.
M$*5"G"$()1A"%.G3A3A&,8I1A",81248QC%))55F8*H+,Q"JJ@EF8G```Y))
MX`')/`K[A^`'PRU'2['6_'GQ!T"";PYK_P`/]>M/`MU_PLW4OA;KOAKQS?:3
M#<^"/B?HSZ5I6K:3KHT6[TZ$ZMX<\9VMG8^,=#OM7_TS3[N;2_%MC\F>`HO#
MUQXLT6#Q2MRVA27MN;\65I<WUZT,$T=TT%I:VV]I9[Y8&T\"2WNXECNW8PHZ
MI<V_T`?B[X?\;_'KX=ZE\23K;_"/P]XITE-1\+>"S(FI6?A>.]5=2T_PX^GW
MD$>H>)K[38X[5+^*XMK";4W6RM;@Z#;VUW-\[7CP]2R+.L=GM#.LRK4,-4_L
MO)^&LSKY3G5>MAZ?UVMC:>8X*I3QV#5#V5&CE]/#U<//,\QJQP\J]/#4,4WE
MX>_ZBY)E>-XJXOQ>;8S,8YEA<JX;X;X>S:&58^==>RK9CGV:XU4JU3!9;EF&
MKTUE].,8U<US*I[*E4I8?!8ZM3^Z_"\7PBUKX-G3M>T*Z^*7QDTWXO\`AWQM
MIO[06H_%>PO?!G@'X.6/@V>/Q3\.IO`6D7;>&KKQ3=^,;:[GN?$<^@S)J'AS
M4;:1O$ND3^%;?3[_`,EE&K>/&U^^\;>(+G0]!>:"]^&=Y<V\.C:'J-M<3:CH
M&FZE<Z?+]IU#3M0DU+Q+X4UBSGU&Y2]N_"/B/P9JUG;P1:VM_)]:?`GXP?\`
M!*;X<>,OAKK_`,?-)^.7Q(TK2]9TGQ?XQ\$>([&TUWX>^-M"D_90NM(U&V7P
M5X?U6+0=9\02?M-:!%J&C6GB"XMO#Z:3XPTBUD\6R>&/`FIW_BKX$^._[:&O
M?M*)X6\(S^`/"7A'P=\/OA1:^#-!BL%O+[Q%KA^'OPC^''@?2_%'C75;J?[!
MK&N:AX>^!'PWCO[.QTC2]#AN=#@DM+!=A,GQ'!GC)FV:\=XOA_AOPM\2*/!6
M>9CC>,^/>)_%/B/,E@LRS3/,MS+)>'>%^$,'5S3&XFGE&0U<@RK,,=EV%G5P
MV15<QI3P_.\=7IU?WNAX\9%@LTRW+\DP&95LMS7.LSS'B+#YWGV88VKQ%FN+
MR%9/DV%KPP]>OB,'D>7XR6"QF#CCLSSC%3K4G-8BAAZ/LZGTS\*T@O;KQUXA
MTX1+H%[XD@\.>%TA(FMSH/@;2K/PR)K.\'%S83ZU::W):;3+&B[Y$N9_/8K\
MJ_MA^!!:ZKIOCBUC6.VUJ-;"_<RRA/[?TVS=HY'^T7<%C;MJOAVR2WS%'<7E
MW-X9TZSMK=7GGED^[?#ITQ-&TJ#2[*QTFU&E:?=0:/IZ6\%OIMK>1&2"&&VM
MXH(XK<,L\<3);PQR-#+L0%'5?)OC1?\`AWQ-X'\=^$K6]M-3\1:1X>N?$S:;
M:Q-J$E@_A^1M3B%\T-G?VEC-=OIT]C%9:D(SJ*RS6+0RP3S*?[\XTX:R_&>&
MU;+*V+P<<;1C7SK*ZZ]CA*6(S]SQ>:5:&!H5?9JG''SQ&.P,,/!*K2PF*G!)
M2@VO[-\7>`,KXG\#LTX:Q^/P#S1X;&<29/BVO94JW%=.ICL_JT,HPU>?MZ5/
M&5,1F66X3!TE.OA,NQ3H1I25%TW^0=%6+N**"[NH()C<P0W$T4-PT+V[3Q1R
M,D<QMY<R0&5%$AAD)>(ML?YE-%?QG%J45)7M))JZ<79JZO&24HONI)-/1I,_
MQ<::;35FFTT]TUHT_0KUUW@G1UUC7(T>Z6RCL8)]4>Y:8PB%=.C-VSCR+B#4
M)I%6)OLMGI6[4M3O_LFDV4MC<:A%J-INQ_"+Q_<^%T\767AK5;[1,WWG7MM;
M!T@73IH+2^\RV,HU2)M.OC?6NI2W.F6UA;?V;=SP7UW;Q3R6_%6&IZMH-S%/
M937%A=13:?J5L^UHIH+JU:._TG4[4L`\%U;ETN;&]A*2>1/(BR/:7<\<VU?#
M5Z"PKQ6%KT:>+IX?%4XXFCB,-];R^K.$I5L.Y*C4J4:]!R]C7HSC";E&5.M&
MZFOHJ>48K(L;D6+XJR'.,-E&8QPF9488C#8K+7F^4573JQQ.78BO2IK$X6O1
MG"I3KX:?+6HU(NCB*7M:=>/[&^'-!'A_X>^!_#%U\-_V;_&^C>$_%(\;_:_B
MW\#=+M?'=QIMQ\-+7P)+X.\6^//`WB'PWJVK^'=.6QLO%8T[57OIH/&EH-6D
MUB>SBDTZYX_XZ>*-,_:>7X'>#[+X=_L[^&-1^#?A9/AI?:Y^S)\(KWP!X?N?
M"LRV\FJ:O\3_`!2_BS7M,\7^-9$MKZXTVQL;C2;JSUKQ3X@U*726%W--)^8M
M[X\\2^([VU/BCQ!JVKVWFKYR:QJNJZI9[O/NIK>:YM;V74A]CLY+O+V-A;P"
M6U@\NW6&^<WM?HIX=^)7PP^,XTSX9VEMJNAQ?94U75-`LDMK/0]0CL/M8OO"
M::GHUX@N+47*KJ<QMH+>SU;3;;]W*5N)X(_J^'?#KP-XBXKHYGE_!&%X=S_+
MJCJ9%]=XIXBE+-LSSZ>,P&91R_"K'?V!E%;%1Q^(I8^I/`9K5EALQC/+\N>+
MPV'EA/[8\.J_@%XEYUC,#D7!>3\(YI1J97A\HRKB/B'-*^+XOQE:K44</E2E
MBJF6Y#.G+"8:.(Q4L)G^(HPQLWE>5O'4Z&(AZ7\1_#UIXW\.33Z'I^A>)=0M
M7:(KY&@ZC/=VPMYVDTB"\U%HX(#)<3VES)`=4TE)8T:.:\2">6*?QN#PQXK\
M)>#O'.NZWI=EX?L+'P-XQ@N-*LYO#_AG1KR>32]1:SET[POX*%SI4ES/<F."
M/4/$VL:OJ$<%U%;Z?96EVUW+=>W0_#ZR\+:]8:Y\/]/TKPY#=7$%GXMT*PM6
ML])UG23B.&\M]-M;FTTJPUG1Y&:YBU"&R^T7=I)>6EQ]I9[>,?*W[1O[0-O/
M;Z[\--&TB[`34S9:MJUQ="*UU"WT;4(TO=.@@MA]HDL;G5;.\TW4)%O;69HM
M/NK(Q%+]Y+?^A>.:.2Y52S#B;B/ZUEF>.CB<OP.`RW&*OE?$F(>!J/!5%&I@
MH8A.$9^RQ<JLL)+`SI5U"K5HUJ>(QG]*^+.8\.<'93G''_'%:OP]Q/A\OQV4
M9%@<LQ2S#).),U>"KXK*)X53RBGCZK59TH8Z..CA*&78FA7E^]P]2ACL=\(7
MUO+:7UY:3H(Y[6ZN+>:-61E26"9XI$#1*D;!74J&C14(&455P`55HK^28IJ,
M5)IR22;2<4VEJU%N32;U2<I-+2[W/\<92<I2D]'*3DTMKMW/VS^&-E9Z?X'T
M.SL+2VL;2'^T_*M;."*VMXO,UC4)9/+@A1(DWRN\C[5&Z1V=LLQ)_*'XSV\%
MI\1_&=G:PQ6UI9>+/$%I96MO&D-M:6JW,=PMM:P1JL5O;K/<7$PAB5(Q+/-(
M%WRNS%%?N_C#_P`DMX5?]BNK_P"J;*#_`$+^E;_R9'P-_P"Q5EG_`*S.3GE5
M?2_[)ZK_`,+>TAL#<+35U#8&X*VB:H6`/4!BJD@<$JI/0445^3\*?\E;PC_V
M5G#'_J]R\_DSP&_Y/-X9?]EEDG_J93/U9K\-O&LLLGBWQ*DDDCI!XAUV*%7=
MF6&(ZQ?3&.)6)$<9FFEE*(`IEEDD(WNQ)17[U](?_=^$?^PS-_\`U%PA_:GT
M]_\`D1^''_8TXC_]1<H.8HHHK^9S_-$__]D`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]G<F]V
M97(N:G!G````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W,3(U`#$P-3$U-#,S
M-S8W`#`R-#0R-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"
M$0$#$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"
M`0,#`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1
M\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E
M9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:W
MN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?
M`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$
M!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0T
MX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U
M=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%
MQL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_
M`/XA-0\/75E<21-)*KR7#I:0SQ/!]H>=XU3R&D"^<SR$1*L6XLSJ`"U036>J
MVP$,\+PRLJ*(QN5\-+M3:A`8N\D91`!EF#*!D$5^W/\`P2A_X)U:E_P4F_:A
ME^'FLZM=^%O@W\/--_X6%\:?$EC+(VJ-X=$]I:V7AC3+FWCE2/Q#KEU=I&K;
MDC72K36[E1NM"R?I3_P7^_9"\)?L&?#CX%>'?@G\.?#^B>%?B'J.O^'H?%__
M``BFE:Y+H&G>#[>!?#WAF'6K]EDL=5U]-4N;QK^5S?WUO9:C?V4<MI87LD/R
M&?U\!EN;T,GPE3GQ;:]O.M/V<*-)V=-QE&]VTM4[*]K=#[O`SGB:,L5B4XT(
M1BE&DE*<M(WTEVNK63\]+'\E\.M:]I0F17N_)EP+JWN!(/,\HH'MG#8V,-RL
M<C<H4@CK69JVJR:O=BY>,VRJL=O%9[VEAQ(H1W,BDA6\MV4!B.77N1G]X_V,
MOV/-3_:%_P""=_[8W[27Q+T/2X_#OP"TO7XO!7Q'U>S*SW][:>&;_4M5T*QO
M6BAAU%=#U--)T^">V>9)?[4BRV\PJ_XN'PMJ$PMKR6"STZ*S0R)`0!#'+A(H
MX;?<`;J:99H;J8`L;=`H<`."?3R*&:YM/'8*G7C[/#7_`'WM7*C*]KWFTK.-
MDI1UMW[:XVIE=%X98-8S$8K%<BPN$]A%U)U%;VG.HJ\87MRO=I,]F\%?![XV
M?#3X3Z+^TMX>M-1T[1SXG@TO1O%6FP0WL_A/R8[M_P"U[F62-X='NB+=K*QN
M[EDD>:]CLK,->7ELI_M"_P"#9S]M[]I_XX#X\?`/XT^(-;^(_P`.OA-X%T+Q
M%X+^(>O:?]JU_P`(ZY?:G'877P^O]=:&(:E8ZY9SQZ[HMBWF7]I'I-VL@`:O
MYLO^"?W[?7QN_81M/$V@S?"[PW\:/@M\0=/ND\5?"KXT^&=2N_!6K03&".\F
MTK4_*2W@BN(P4D60W-K<Z?-?PP6\NH263)^W7P@_X.+O@Q\(OAQ?>#_`W[!/
MA7X4PPRQ7MGX;^#_`(I\-^&/!.H7ESN6:?56?P2\\NH1!EB?4[V#45%J;6TM
M!YB7;)Y&=\&YSC*7L<+A<OQO._\`>%B)Q<)OEYDE!._+JMU=O5Z:^C#%PPM>
MC+&2Q.7PY(QKX7%8=Q4)12O*E*249.6ZYM/4_L[DUNQ,CEM5LT8NQ9/^$@EB
MV$L<KY17,6T\>6?N8V]J*_A>U#_@Y%^*DE_?26?[*W@>*S>\N7M8[CQ5XFN9
MX[9IG:!)[F!+2&XF2(JLD\-K;12N&DCMX481J5\JO"3BYV=H=/\`E]/^[Y_U
M;TMV_P"LF1W_`-WQSUW5+#V?PZKWMG9_TSJ_^#9[]K?X/?`WXD_M%_!CXAZM
MX+\(:Q\<;+P'XH\!>(/$\\6@+K]QX';Q'IVH^#;#6;Z6WA@U*_37X[VTL1(S
M7L5B66)SY;5_7'^T9XG_`&.?B+\)=:TS]IFQ^#WC?X<0R1:[>Z7\7G\.77@Z
MWOM,B%VFKF;Q0K165S;_`"V=E>Z<&>=I)K=5DAEN%K_*.\2:S%J&IVNJA;:U
M-G:VT.FVR;$9?(54GE^56FMGD8[A<0A)5#$!PDC!K=UX[NM6M+JSO+[59O*M
MUMM/BUC5[O4K2.$[7F@BCEN8+98&>-7'GN\F]$4(P=B/TS/_``VI9WG-;-GF
ME6A&JJ<>6,:>BI[KF;3L[Z/RZ,^&R_/:M#`RP\<-2YI2=ZO//FMI;W?AV2W6
MI_1;_P`%A?\`@IW\(OB)\.]-_86_86\)^"O"/[,7AJ_M9?&-[\,/#J>&?"GB
MS6[>]DN]/^'/AW3-*334USP]#>V5KJ^J^(4T>8>+-<@T,:?J$MA97\,W3?L*
M_L1^#?A5X!TKQQ\2O"/A/Q1\9_$MK!KD\WBO0;+7[3X<6MWY%Q!X>\.Z9JUM
M<V4>O6UD=.;7]3GA687UY<V43H+6[2OY^_V0M&3QO^TQ\(-!U-3>Z.WBR"]G
MM)X2%N+31;2ZU>6VEMD#6X25K%886+%V+!$R'-?V!Z3=N/M2[Q"T:P)<2P8E
MCB=D`FC8*&6-"8[=G9MH4F(-CS%SCCZ5'AS"4LCRZHXQK+FK8B,G[2<JC3DV
MT[.[6VRZ']=_1JX(P/$5',^,L[PE+&RP6,IY;@54IP<*+IT/:RJQ5OCYK1>E
MK-M]$=A>>;%:_P!G)I.BMIB1&6VTU]*TVXTRT)C:*4MIFQ]+NC,LS';#!&L,
M9=!(F2C?CO\`MO?L&^$-?\/:W\3/A/X6T?1/&MM93ZSJO@S0+6;2?#GCN=68
M32G3X1);1:HC2K)#)9OR5D@6,F<8_6K4-6$(C2[$DD<:Y6:W;9<#<A`:!R=D
M;[2Q#2?)L##.<5Y)XLU^RM["5KJ_C^SPQRF!%VLC+,&B'V]F)#R(\JEIHSY*
MX*L0S*#XN%S>OE;<U6E&-*4;4G.3C*7NN4VW=WF]TM-#^H>*_#+AWC')L5E6
M.R3!)UJ=/V&)HT(4\12G4@G[2%2*3;O;W962M9:'\8ESXL\.6EQ/:WDVHV=Y
M;32V]U:-:78:UN87:.>V(90P,$JM$0P!!7D`\45^Y7B7]E?X-:SXCU_6%T6T
M5=6UK5=24+%%M"WU]/=`#Y>@$N![45]4N-Y67[S=+[3Z\O\`\E_5M?XBJ_1Q
ME"K4A'%8_EA4G&/[SI&5E]KLETZ^;O\`AIXNT/Q!X6U.XTWQ+I>J^'M1@NKN
M5](UO3KK2K^SAEEC!\^UN(H1%&9618.!O##R]PS6(+VW53%+&1(!G!&&P,<A
M2,X^89X[J,\YK]2?VI?VC_"7BS7I[?XR_!W6(+@S1P0ZD#I`O%>$$F33=8M%
M4B*-7):VN\DADD?#(F?R8\1ZCI;ZQJLWA=KN'1;J_GN;."[D222*($(@N6P6
MDN-K?)+%^Y*"0=2N./A[C59W@_:U\&Z=7DC-JE*<L.G+E;CSO7W7I*VJ:LTF
MC\3XJX1Q_"..Q&78SW:]&HXPIUDX5)PO[LVDK7DDWIH]]K7^FOV2?&NE^!/V
MC_A/XEO;AK.R@\5VEG>S72,UG%:ZDDMA-)<C@M!&MP7?!!54WDA%<U_6\_B7
MPO#<Q1+<&ZGU)6>UU))#$);>Y(EB.FX80PP^7;(PDG)^7;@X<9_AJ36KQ65E
MG,9CDCD$D1\J3S(I4DC\N88,;I(B2@A@2(RO\7/[!?L\?M]I-X7LO#GQ'O3;
M>*]&2WT_3-?N+EX;35],BC$"1W$@)%O<0JZ`;BOF(DDA)*UP\3JI5C0QF#IQ
ME*,(6BI-IM)<ROO=>6B[]OZA^BUXCY!P]3S3ACB+&RP5/,<3'&9=[1Q4)XQ4
M52JTY<SLJ>JE?>^ZMJ?OMK7C[P]:.B12M-+$IFC0;HHKB[CQ`OGRR$+<S!)I
M/F@)C(W'J!7RW\3?B'H-MH^IWEW>SR3QW"2"VL9%=[<DLA,4BLR1F.5XT=YL
M1)OV,0[J#^?/C#]L+3+5YETJ6*YA@N(HU,-U<WT=Q+,CS-/;2,#')&OEE6:-
MFVE@.A-?"/Q+_:DU34);EK.66&YEN;PB/S)`KF0X6.>-C\D;`^:I(^_$F#SB
MOB:6%S/&591K4E&G5Y6Y<TM-8WM?HGU_-Z']1\7^,G!W#675)X?-L-C,7!1<
M*=*I&5ZE."BJ7N-NRT5U9[]#]"9OCGJ$,TL7VK1QY4LD>+A2UP-CE<3L"`9N
M/WI'!?<1Q17X<3^.-?N)YKA]9U/?/+),^#+C=*[.V..F6.**^C63RLM%LNJ_
MN?Y?GV/Y#J>/>(G4G)8"5I3E)6E5^U)-6^]6^7?3]B_VVK"Q?X:ZB[65HSP(
MAA=K:$M"6L)\F)BA,9.!G81G`STK\,]-`.GVF0#EWSQUY;K117A>&O\`R),7
M_CJ?G3.3Z57_`"6^$_Z]83_VXN2JHG("@#9T``_N^E3!W5H"K,I$B$%6((.U
MN1@BBBONU_N4?\3_`#B?S13_`.1UDO\`V$5O_;3H8;R\9T4W5R5#`@&>4@':
MXR`7P."1QV)KGIF:2])D9G)N!DN2Q/#=2Q-%%<]'X5_V]^<3V<?_`+U/_L+?
MYHZ98X\#]VG0?PKZ?2BBBJ73Y?\`N,^DCM'TC^5,_]D`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O879A=&%R<R]H;VUE<BYG:68`````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R,3,P`#$P-3$U-#,S-S<P`#`R-#(P,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!'248X.6$@`"``]P`````````S
M``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,
M`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S
M`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,
M,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS
M,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,
M9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS
M9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,
M9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68S
MF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,
MF<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,S
MS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,
MS)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S
M_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,
M_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S
M__]F__^9___,____^+\D````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````(?D$
M`0``V``L`````"``(```"/X`L0D<2!"`00`$$RI<F/`@$B0D&$ID2`+`0Q(8
M,T[<2`()`!(J1C4;V6R4BH@;%W8,2;)E214I58YRXK+E*)0Q!ZJH61-F3H$D
M1/*TB3,FB:$N38+,N9/GJ!505ZA@=8W5"J-.K5"MNF(K*Y\3C];L>JTL5U9:
MBS)DZ7*%6;-=6;%2NW;D"J%DK93]JJ(O$J.C3+(<]41NU2=";\;\&'+FR*=]
M[Y)4G-(B`+8V`TL]^3=E1(--)V\&1(J4'KH2@R9]HJ>T:].H93HNN:+U:]>Q
M5;*M??OUZ9]BFZG0,[PW[)^AAV,\>=(@QI_8@A=_G2=WV,DJ;EN?&+H9[]*_
MH38+E"KT)>GPXN-"3=Q7Q4?QT<U:E?QXZM6?4+?N)6^7:T[U^LEU66!35;4=
M-@<EZ)R"#!(4$```.P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VAU;7`N:G!G
M````````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3$R-#$`,3`U,34T,S,W-C<`
M,#(T,#8S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````/_8_^``$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1
M`?_$`!\```$%`0$!`0$!```````````!`@,$!08'"`D*"__$`+40``(!`P,"
M!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B
M<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI
M:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"
MP\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!
M`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"
M=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7
M&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY
M>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)
MRM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`_+_P
M7\/_``]X4\:):>"_`.JV.NZWKQT_QUKNKVE@EY<^'+QUD:9(GO[G1[?3;3P]
M<:;%8?-K$Z>6LE[B=I;*#W3Q6EQHEC8^&K1+N^COO"GA[S;'P]HE[]MT2VUZ
MWN;UIO#GB`CPUX7MKO3]'NK;Q!J5[)::_:A+N72S;I?VT\A](MO#^F^$;'0-
M=U'PG;:')IVIW&F^*;LZOH=WX>@NKN[74-2BM-.^V7<EK%/?K)IDQ@D1X]42
M^\QRYVKY#\3XM<U;5M-N=/0)K&DW^@KH$J7>HZEIO]AP7^^P\+PZ@9H]`3-A
M=JMW#"?.2[5[226(0R6Z_P`CU\=B,SK*6*G7EB:,>:$I.2C&W*K+ELG:^SNO
M6Q_:=#):&78)QPW(H2;YJ<5=/VD+2D[W>JE)/6VOJS]$O^".O_!-SX"?\%`?
M&GB;XO\`QZT*_P#$?PL^`%OX7\$:=\)--U>30O#OQ*\>2C5(K;Q;XZ\6^'8[
M'4]<TW0/#>E>%O&LVA:+K5K#_:_CJ>WU!97\*7.A^(O!?^"]G["O[,OPP_;D
M^"/ACX-^'=$^'7A#QM\)?^$C^(?A/X<ZK;>&M0U*&QU>;0]/O+*&72[KPU;W
MVM0V`U%7?1-1FUJZCU+5KNXNKK47G.-^QI\8?VDOAG\%/V@/"7P43QE\-OA=
M^TS;W7A+XB^,9;29OB)X1\6W=C+H]QXK^"T>G3:)"+*RM;[Q#X>G\9V&I7\'
MAYYGMIK0^(O#&C:II+?$GP]EU?3/ASX6\=>/O&_Q$3X':.WA[X8^(_'^N6?B
MKQ5X:\-RZSXJU>YLY?%^MS:MKOB72M&O=5U35]+6_P!2\0P>&-$OK#P]!]AT
M_1[/3++[?!<2X7+\EPN#H>RIYG/&0YZTHN<Y1<*ONIMMZOEM9+KILU\#3X-Q
MF:9_7Q68.4\IGAGA:=*/+"%H4XNG&248JT)*HHJ[DU9\VMC\5OC)^P)XM^&W
MP;_9?^)$'C/P%J&D?M!0?&RXTCQ#ID?B"Z\5-/\`#'X@6W@^\T_6OAY>:1;Z
M/9/;ZIJ+V6C'1]=NG\6:18'5,Z7?0:A'+\[>/_@'J<7PU^'6N?#_`,/>+KW5
M)Y=3D\>WNCVNJ:E:P0>*+6RNO!5]HM]X=TZ+2]2TMK+9>W)DTV(PRWLT4D@E
M621_VV^+O[2/PMO_`()_LS_!G7/B=\&=2'P#^,_Q6^)_AKQQX>^*NN^(X-$^
M'7QJM);GQA\,&\#KHDGA4%?$=M%XJMO%UCX^L%\*:A)<:+J?AF'48-6UJ_\`
MFGX<^&_"$&N?"KPAH_QO\-Z'HGBWQ5;?\)/XCUN:]TBU\*^$?B%/:6.@WUWX
M>M/[.U76O#>GPK;ZS;ZQ8V<NAV&G:Y8QZ(VLZ''I^JWWT7^M>=8=0=>C1Q,8
M1C456I0<G%VC>TFFTES.VMO).S7C9?X?Y!F,Z>"_M&6$KSQ6*P\7*M&HZ=*+
MFX<J5W=N$))--Q?NW=KGPE!X'_;'CAACTSP)\4CIJ11IIYA\,V*PFQ5`MH8E
ME/FK$8!&8Q+^\"8#_-FBOVVOO@/X:M;Z\M1^W!^Q,@MKJXMPA\0?$92@AF>/
M:5/A)]I7;@KO?&,;FZDJ/]=W?7"8*]^M);^[Y^GWOY?J4/`'+W&#_P!;\;K&
M/V9=5#_IW_5_6WF7AB71I?$&H:MJOA#7=)\2>%KRPL/B;JNIZU9ZK8'6=7LK
M;68S)9^*-/M].O\`7Y7U"/4(=$TV\OI9KF=I3/:(_P#9UMT^H)+87FH:II^M
M^+[E[KQ-X:MAX'UW1?"FE-%>:W+$?#'BJ[_LXZ))HR7NI6-RM[:127+Q6D]K
M?,0)MTGS?=ZYHWQ"U/Q/X9^-.MS>+;K2-7NM>\*^+?/O(--^'U_?7VH7=]9^
M)F#CP7XHGO?$EW;V-A<Z3966K:)#*(;G46:'$7=ZAXET32++Q7H_C=BMLNA:
MQH$4%M#I6IZ[J^KZMINB:4^OW7B*>WU:/0&\+QZ*FG>&M="36-G:M/)<:=>7
M4RW$?PE3+ITXJ,I3Y[I.-O<2T3L[7OTM>VG56"EC:%3]W#%MJUVN9/1.*Z^?
M;770^G];N/%4VJ6ND:OMN-4T6'2)/#UIHL?C7^S]-AM]/A%S!-K,&LZ;;WFO
M)J,MT-1T?19(M+UET?4_LBRW4F?SW_:-^).H^,_V@-!_9RO/B;J?P@N=+\'Z
M:F@:J?%'_"%_#W6_B)XNU?PY>:EK7QF\8ZUXJTC4?#OPET/P+/=#Q%;:)X<\
M5:M+K,=_I-OHVJ!?,N/:3\2X?&US/X3MFU;3[#1?#DEU;>*_&4Z7.G:OKVNV
M\=KHWA;X?Z7#:7&L:AHGAS1H9/[0U22^LM9N]1M9=1L=7LM-FM[*/\D?VJ?!
M]W;>)K7XB:5>ZEJ'@G6(HO"][J6I7<\,UZ-!BA@L+E[$?:I=07R;-+^TO;V6
MZU&*>XD@>]%C'!IUK[?"&3X2KGV%EB\-3K):QYX\R4VZ:36MD[2:ONNGO6/D
M^/<WQ>7<-U9Y?BZJG&M%I4Y)./[JHN9-*^SY>WO=K'K_`,1O!'P:^*WQ5UO6
M/B+^W5^Q'\,M.F\0>!O#S2?L\_LT?M+^%/@II_A._?6?"/C+5_#WA[P+^RU\
M.]$O9-)T31_#'B+Q+XGOX-2G^)6D>,(+ZW\3^(?&LFNZ(GBGB_X]_M->(O#W
MAWX?^,OVH_C3\8O`GPGFT_3?A-HNO_$[XH>*?AMX=TCP:UMIGAN\^'O@KXI6
M>E77A3PVFDZ-I$.B^%K[P;X<BL-)M-.M-3\,VVHP73/XE)XMC9HQIIT_1XB_
MVBRDLK-6GC\W]]"T4A+R6:1S22W7V9"EK+<7$KW=M.%B2*W8C6=>N[/0=+47
M^I7\DPM5TQ9)KZ3S9(C<372007,\TKW-V9Y'L["XW1%S<2+<>:P_HOZMEBH5
MWC:<(X>"4-*<6VN2+Y+VO9[^J6J/Y+H9QQ`\RPM7+JM>GBHN5:51U&W9R2E)
M<VB;<E>UM-K+;],/#W_!:+QIX?T#0]!U/]F7]F?Q5J.B:/IFD:AXG\1>!/'\
MGB#Q'>Z;9065UKVNR:1\5-'TF36=7GADU#4WTO2-*TYKVXG:RTVQMC%:Q%?E
M[JOPZ?2-4U+2=2U6].HZ7?WFG7Y@T\>2;VRN)+:Z,/FE9?*,\4GE^8JR;,;P
M&R**^*>4\.7=HQM?3]VMON_J_I;]?CQOXCJ,?^%?$:*/_+U=%'^[TM_Y+YGV
MG-/XPAAU/0+W6?#UGX<T>6YNI([G3[GP[H\=SJ-QHVJS7FC7$C?VCJ,^J)I=
MLUPM_<W@M9+_`%&)%2X\JXB9#\=O$GB#Q7=:EJY_L!=8U%9K74/*N[O1KAK2
M--/M+:*\N?[72[T^WM[6*UM[34D6%(XD2[-W<)+>3?N?^TI_P1B^*OAK4]0T
MG]FKXTS?$J*:WNM6\%?#K]HWPM:^"]5\6^&8K*W>QT;X5_M,^'Y?%W[/OCKQ
M:9FGM[3PC\0HO@IX[>UMTM5\.ZG-;OK>H?EE\+_`DVIZ=XG^'OQ)TI_A]XD\
M`:RWA'Q/\._&EI'X7\2:'XDUV>>]L8O$-G;;VET[4999Y-/\0VM_)I*VUQ8$
MQ!0T)^!R?B/A+B/"^TRC-LKS6A3C!U91E&G/#J<4U5G2<E4DHJT7I9<ZO9M-
M_H>(P.;8?$RPM/"5,'4HU$YUZM.;IU8*\724K6?-*]I1NG[.24GRR,W0;JYT
MG4M-NQ?:K+K.IW.K:SJ<6BZCH\\<$7]G&RBN+BZBU*>31YY=/6-M/L8;**V6
MSFB5+100!!%XDT>Q-FLESK>F"TL!I6@VWB]O#.KZ9JC7@-VQG\"GPIHU[IT\
M*3G3K2]_X2Q_[3LX+?56,;WK1IZ+X-_8U\:>)M-UCP#\-?%NKV7CJPGU+Q'\
M+/#MCXHM==\->-'CE;5?$GPQDN=.TW2HF\>0V6H0ZCI/A@++>>(+.5;NRO(!
M=100?/7Q3U[Q5X.U*]E^*/P"GTAO!6C?\(WJNH>!_'WC[PY9V7C*V5+(#QAH
M/CA/$=EI_B"SBMY;N]\&:7I>FWK1@;=6D=FNY_>P628BE.&:974IXNAS./ML
M/)0]D[*;?*WS>[R[V:[;(Z,=D6>8[`SJ5\"I8+DLYPINM"I/2T94[W@FE)\^
MRLUU=O-?$/@#]G>[O-0@U[3OB_\`#G7+NUGU2+5=+M/#=_HNLZBFI2'4;6R\
M)PZ=JE_%I\EJZBSEC\6.;=TDEF#*/LD/9?!S5?V2?A=\0-&\2?$'X8^/?&GP
ME\(KXGO?%/A[PWXVM;+XF>*=4O=!U#3?#5_IGQ`TBWTA/!/ARWNY=/U/7=%@
MTA[J2-2HU-;GS+N7](O@O_P2V\,VW[._A[]N#]MOQWXN\/\`P&T73O$?Q*\2
M_!NRTW4M.\0>,?!GV:^TCX+Q:+K!WZS:^)_BUXR\5Z#!HMFME9:!+H-@\]Y=
M-<S"[7\K/AZEOKVLZII6K6NGW]CX>\%0^!M-M=)T[3&,^IZJVF^$_#^D>9)I
MC'5M2.IWVF:;J<MZ-2DF,5RMI>R@Q7[]L,^CFM#$8?"YE6Q&)H8A4\3A*=DT
MHQ7-.4I1L^63C%I:^]&R:29\]0\-<PPLXXZME664<.\+.I3J3JM5%[U-J/LN
M9<MXOFO?W>J5[+^T3]EW_@@_^PG\=OV9_P!G;XWQ_LO>,MGQD^!7PC^*J?VM
M\4C=ZKL^(?@#P_XN7^T[NXG^T7.H8U<?;;B<^=-<^9)+\[-17]1WA.#P[X'\
M*^&?!7A[3;7P_H'A#P_HWA?0]!TJRL[;2]$T?P_IUMI.F:1IMO\`9F^SV&FV
M5I!96<.YO*MX8X]QVY)5_5L1I=XM/2Z]I3T?N77P=+/[CYF2QBDU'`81Q4GR
MM4Z[3BG&S34];I-W7E;H?SV_\$PO$OB/Q_HWB31/'>OZWXUT:_\`!T%S?:1X
MMU6^\2:9>W)6[<W%W8:S/>VMQ.7`<RS1/)N`;=D`U^&O[?=I:WFL?!W7KNVM
M[K7-;\"_'[2-9UJXACGU;5])\,?M5?%#0_#6EZGJ,JM>7^G>'M$T^PT?0[*Z
MFEMM)TJQL]/L(K>TMH84**_S3\&?^1X_^Q?#_P!/43^T>/\`_DH>*?\`L.P'
M_J#,^/OB]K6L>&?!=]>>&]6U/P]=Z)X57Q%HUUH=_=:3<Z1X@L_$^JVEIKNF
M3V$MO+8:Q:VEM;6MOJ=HT5[!;V\$,4ZQQ1JO%_$+XB?$#XC^#/A!H/Q#\=>,
M?'FAZS\/O$VOZQHWC/Q/K?BC2M5UVZM_&$USK6I:=KE]?6=]JUQ,3+/J5U#+
M>32$O),S'-%%?Z+\.?[JO^P:?Y1/BLO_`.11C_\`KU+_`-.1/W8_:^)M_P#@
MF_\`!>RMR8+.3X/_`/!-C2I+2$^5;/IG]I?L_P`G]FO`FV)K#S+N[?[&R&WW
MW5PWE[II"W\TW[+-A8_\-9?`#3/L5I_9LW_!0SX`:--I_P!FA^Q2Z1'\;/!<
M4>E2VFSR)--CBCCB2Q>,VJ1QHBQ!44`HKX#P^_Y'G$G_`&'5_P#TY2./C3_D
MF,J_[%U/_P!)1_JF72J;JY)523/,22!DGS&Y/%%%%?KKW^:_.!_-2Z?+_P!Q
MG__9````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]I
M8V5S:V%T96MI9"YG:68`````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,#<T`#$P-3$U
M-#,S-S8W`#`R-3,V-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!'248X.6$H`#P`]P`````````S``!F``"9``#,``#_`#,`
M`#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9
M`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``
M,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9
M,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`
M,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.9
M9C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`
M9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9
MF0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`
MF9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9
MF?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`
MS&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9
MS,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`
M_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9
M_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+``````H`#P```C^`!$)'$BP
MH,&#"`FR2L2PH<.'$"-*9,AJX<2+&"-6S,B1X\:.("5^#$FRX<B2)#<B\G)%
MALLK7;P@0BD2T945`'+JU+E"QI66,KS09&5EI]&C.0-8F9GRZ(JG4)$"8"$T
M)"NC5G`"6&&%5:!`7I_J/-#%ZDZ7.5>PNL:*Z]J*6=->`=DV)XNB6]>RM0+V
MFE^X6N=Z%,1BA1<6.0/Y91MHA>+%;.NNN,+T(BM$@JX(PJDV<N/'C/O6W2IX
MXDC.:[\VMO(7K&._@<Y6AC@2,8"WC@-U#;V;K=:<I6E;3-0E)^MK6<'JK:C7
M]\X5LQV.1(3:MUO(D$?K%"1R>"(O.'?^:W5;,?OOG%VB4_2>Z$H``&!C;]7-
M-SM2Z*T>GF1XTVWXBGTMAA=/:04BB"!6R)`>>XED]A1?#]:WF';S&9?59%E=
MX1UF3S7V8(?9#6@<9Q<J%E9!YVW587E_B9A68G@]UIA4/.G&E7(S&L555`42
MY>)1-J9(HXHJDJC55_<Y)N1.(BH'H%,7[A3D5E(I^1R/.B;G6%S/9>GA34/"
M>*%8/%F1G&K*P?:@?#22Y^*.636''6-0\96C43*6.6.<<V(W&E=7.*7<F'?R
MV:=7.4ZVY!5\G7E4<H=")>EY$,ZGVI*09N=A5P".YR%7/R*5U7%_<?:5F6::
M&IZ'!$I5U''^1$'5'&`[\L157LREJ*A:%W9EIIRH"@D=1`IYE=:-)OY:JEBY
M_<8@1(+L!%=K?,5ZJY1%/?L0=3T&>,VGH>JD[4-=K-"%;G"]M>EOY^$T[K:)
M4`=GJBR4E9!`K+0R2Y_Y04LB3-QEU):^K11LL+[7S`*1%0<$3)=Z#;62L+\0
M6Z:MQ`D?7#!1&A>\+W8'[Q>QOK.4;/(LK6A(\LD=GRSRR!HW]%1P`L\D$,)]
M0C9+73(07#!&5\GZL\<?]XL(EVI][!?*(D$GT$3[VM2N0QXOUJ])#D^DKQ4!
M!/!4O2MD/?*^5[?U;B+[;J;@"@>P3?-#$BN<2$7[HGQUU2C+^[4D%>EEQ/1&
M!??)=+P^"5*Q1'][%S--TEU#T;V01XY(6X8+%!```#L`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O:F5R:2YJ
M<&<````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S0U-``Q,#4Q-30S,S<V
M-P`P,C0P-38`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!
M`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`M1```@$#
M`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D
M,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G
M:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BY
MNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$`
M`P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0`
M`0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E
M\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W
M>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'
MR,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#\
ML_A=XBO+==$M)9;JT+W&@R2,(Q)'#';PVTES.9O)9_)@_LT%X`!O:=29%,0$
MO](O[.O[4'PD\.^%M.;QWXJT2RCM(;Q+R[?2]4UA7LI!J.H:2)HQX<U&UTQ0
MI5#?RF&.$V@0W<9NQ"?QU^!?P+DU+PW>^+Y[Q$.F_P!JW<.G06\%W=3:=$\\
MJ1);B[^TGS1IWV7_`(]#L%X93N,`AG^K_P!E'XN_MR>*_%]OX#^$?PH\">,?
M!_B'Q)-X>N-.G\#MXMN/#]C9P+Y+>(HK2#2[@V264MPL[ZM]DT=9I+>*XN!<
MRV:M^5RPU?.JKP^`A3G6A*2E3G6I4+<EKV=:=.+OO9-G]BX.G+A;)GC,=%RI
M8]8B<4[SY:,;*53ECS.-KW]Y*6CM>Y_4W\%?&_@CX@:'IU[\//'/@OQ-H5U;
M6+WNHZ=XETN6661-+E(ACTVUURS-I=F[NK2SD4AIHH'GF,#;6BKZCCNKM-#U
M`75SJ3VPN/LUI8:?_:2".]T5[_3KVQANGOK6TOD<E;B.R-UMODWW(C/V`LWX
MBZK\)M+^"WBOQ3KWB;0O#7@WQ=X"L+7QI+XV^#UMJ7@S2KYM6MK9=1\-^(?"
MFBSS:/;+:74<6G&T;7=1DN[FYMM6$<(TMK2Z_3KX>?$/_A)_A#X?^*FG232R
M:_::7KHL[$VWVRX;4(Y]<&ERFXT.XGNUTA&.F7LYN++^UGNX]2<V!M!97/7E
MN9SP=1Y<W3YJ,W&I'VD'^\5E**DFXNUMTW%]'T?XSQGP?4^KX7/,/F"AA,PJ
MX>=%*#E&V+:=*_;F[-)Q^U&.YXC^UQ^U_I/P*\$V\O@CPUH_Q"^)'F^&ET70
MX]2@\.6D<6JKJMWJ<_B+[-X9DU>^DT@:0EM'X:T[4=7?7KZ^M21:FU^U0?R\
M_P#!0G]H;]J+XQ>"O%OP]^,_Q!TDZ%X@@TC5;#X>?#'2I+;X>:196FF:9J+0
M:C=ZC:0ZTOB[3A-:6][9W!CAMA=WRE)Y($E7]-/VI-%NOVFOVQ/#6DP_`_Q;
MXRUJV\.1Z=;V7B+QS<_##P1+;7&N7-FNH:0_A_2/%5S?7WA_48;"^_M*!=%N
MXH3=*;ZWA$L-Y^3'_!1E-'T/P)X)\#:3\,OB1\+/B%\-Y_$'@;QDNM>-DUW0
M[^W\)POX=DU?0-<O])TR7Q;I>I:QJOGZIKVH3KJ=U<66F6L=MY2S3Q_:8"IA
M*N+7UJ,%+EBXN*Y[Z*UG%-7];O17V.3'9-5R+!KDG"IC.1.M*$HI)-1:5^;E
M;NWHGYVNS^?_`/M"ZM_W`TYI!!^Y$AN""XC^0.1Y/5MN[\:*Z6U\4:=#;6\-
MQ:Z;+<100QSREI"9)DC599"5M74EW#,2KLISPS#!)7V:IX;3]W'I]E?W;?I]
M[^7Q+KXF_7?^9>7_``/Z6G]5G[$LQ,.@^%9='G:QM4CM7%S<:F]E%=K%J\BS
M6R1Z9=V9N9;348G6.U@NKA8I)0L;P^=*G[DZ'^RI\+-)NK3Q-I&E>&=-US5[
MR(:G=WT]K;6UQ=7+Z2S37JQ:C9QGRH(YI&@N[6SO90&_T9(Q*R?SP?LR^*;G
M1?&$5S=6D%LFI:KJO]F3W"K<&Y>VO+2RC"-I,UEJD$D5F`JNNJE-L#JZEIE,
M?]37PC\7G5M#L-7N+[5=(TQ(4NY)=.U9=`>XB2UM[:Y5Y=/TR74K^"+:;AK/
M4;BZ>X:)&:_B:%3+^#X2>$>;RCCHU,+["4ZCK4Y-J;FTXQ:IW;[.Z:U]$?U%
MX@8C,:?#N55,+AHUH5L)B,).FZE&/)*:C&#2E-.[;332W5F['YY_M_\`C3P_
MX)\+_P#"G_#DERU[XKFEGO\`4?#]W/#I&HC24UIK?3[-;*QN[&WBN8].M[E+
M9K>>XFEDB0:@%A9+K[,_8RO]1US]FWPEIJV&OR6^ES^&M'BBDM+I9)8X[6RM
M]6#R16`DC6.!)+FX5XRB2Q0Z>T@>]2XC_+;]MWX/_%3Q7\??%WQ?U,R:[X#M
M8/#]CX`\,Z8D=[>S7UO)H=M-<&34XH1-.+W3M3NY56,S31F6S`"7$ES%^G7[
M%+WUY\/5EN/#ITI$.IZK:Q:KH-A8:A:W^I:IHUUJ;G3$>Y5H!?Z'9M'="2,P
M1N]J%(G\Q<<(\%7S2=1X&JU4J5Y491=_:4J$H\]1/6VFKC*S?1;'F<69?2P7
MA+D]-UZ,L="I@L15A*M35:#I6]M!0<E*U*R2<4U--\ESZ!U?X;ZEI]GJM_I7
MB*#P_9NFM2?;+:#1$U73-&U/4K\&;2)A9R:QHH?3;Z_@N899;J**\%M*6$[1
M+%_'W_P6<^.3W.NP^#?!N@^(=`^',\.G^&_#GBO5(KJ+4/&<WAVZ-WXCU&.5
M9;6YDL]3U03/J!\^6UN;BXM+B1&>SA63^V'6CJ']A;Y$U%;4Q-'=JUT)-"CA
MNHKY]0N98Y+@6S+=ZE+IS16`MH&T^WCNI%O)8_,B;_/X_P""PG[1-E^T%^U/
MXMLO"!'_``K/X,27GP[\%?9VA2PN[NSELCXIO[:.`;($U75\M;KMN<1Z;(WV
MN43%8_TW)*&'JXV$X4Y4L-/#TJE)2NW+F2]YIWDDVM.;6R>A^`O-<7CJ-><I
MRJ*6(K*%26CE"/)&&DK-*RLM$M=$E<_'R;PL9YI9UN]*C6:6258VT6*5HUD<
MN$:1KP-(R@A2[`,Y!8@$T5T/]F79Y#38/(_T=#QVY^U+GZX&?0=**^V]G;1/
M3_AO^#_3T\;EK7V?_@4?+S\E]WW_`-(/P+U:"0:=J]C9-#9Z?J8N[94URPNO
M[.MM0N;(SSK$-#LWND4W0^43Q;L`$`D,G["S?&F\^'/PGE^*WB*6XU3P;I-R
MVFV^F:%I+7.K^8;JVM1-<P_VOI\?]GW5G+>R33*9#;SI;1>1,)_.A_DD_9>_
M:VTJU@A\/>*[^+3!.;2WT%)[::2>XF2;3[5H+HN]FD"1@23F8RS[I(TA\G]Y
MYT?]$GP5\>^&/B9X6CL[S5++6]'U32(+*+PZ-<8QW$ID;S6DTVTT759+&426
MB3)=S))%C,#.K3(3^$9_EM;"U)U*%.=23BE.2C)6>GNW=KV?FT]?E_6W#V=9
M%Q%A,+@<7!XI81JK.:C)+EO%V2:2=K=$W]Y[7\-?V\/"_BB^M-8ET#Q?J*?V
M@E]IH71]0CCL3;W+W"VTS6&H:JUNM\T%[=&Z>W:*V\P0&*=MK/\`H3\//VO?
M"7B"PETE+WQ+=27E[97&EI%)J\\D(NOM3ZA:S0WNC6<)L=-$Q::1+HR2/'$O
ME1H9&3PG]FG]E71M!TIM1T?7HM$AU.Q8+I^H"UN;-YM/^U7@99@NEW<0NBPL
M57[-*(_-$QCE8!%^N;#PMX5^&>AWWC'QQJVEZ7HG@;PYKVN7-[=QZ=9:9;V-
M[J,6GSWI!U"X:XCLK9]J2R_9Y)I-01/(BVEWY,HP>.J5,'7IXGV-/V&.HSBX
M2;56JXJ"T3OS=TFM+NQGQ]GWAGB,N>7T<%B*V8T*<8*HUB*=-.*:C%1J1C&Z
M::<EI)-K6.C\?_X*%_M`Z5^S9^QI\6/&;ZL(M?\`$>F:GX&\$V<T<MNNI>+]
M8CM]/D^RW/VR4Q2:=I>I7.J*Z6C[Y;7[.&A9OM$?^>-K\D;:CJ4]Q<K%>7-R
MWVM8VDF:0$NUNL[22D-*\RWUQ<76`\[7"1E4$.Z7]8_^"L__``4,'[87Q-B\
M&^#KZ\3X(_#;4+A_";QZIMT[6]?MVCM-6\2"U2RB4->!8$@A,UQY,<;[;F7S
M/D_'V:!+F2.^^W0/:2VD-O<;5,ES->1R32"Y)\Q=B-'*Z%</M8(=YW`#]IX>
MRZKA\%A)8J:J5H8:G3E-=''[#UOIWVU/Y:KU5>I&E25&'/+DIJ4;<M]&VG;5
M:]=>R)`[@`>5;-@`;BTF6]SA\<]>**K?V>G\,,I7L=X&1V.-O&1SBBOH.27;
M\5_F<%Z_]3CY?Y_@^QU_B6&&VU[PV;:**W($#`P1K$0QU[2P6!C"G<02">I!
M(SS7[!_LE:CJ%OJ,SV]]>0.+W0$#PW,T3A'_`+0+J&1U(5B`67.&(&0<"BBO
MEL\_W2IZO_TI'[#X;_Q:W_7A_DS^PG]FQ5D\!:/<2*'N(],M'CG<!ID=[VP5
MW25LNK,K,&8,"P9@203G\DO^"_VLZQI'[&&@1Z3JVI:7'K'Q)TFQU>/3KZZL
MDU6RD\-^()I+/4EMI8EOK62:**5[>Y$L+2QQR,A9%(**^1RC_=X?]?ZO_MI\
M]Q;_`,C;&?\`</\`0_C0U&WMTTBWC2"%(TG4*BQ(J*&A+,%4*%4,W+```GD\
MUG0Q1++`%CC4%!D*B@'E.H`YHHK]2P/^[4_1?^DQ/SO$_P`7_MU?J2LS!F`9
M@`Q``)P!GIUHHHKK,UT^7_N,_]D`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V%V871A<G,O:VED+F=I9@``````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C<W-P`Q,#4Q-30S,S<V-P`P,C,V-C0`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````1TE&.#EA+P`P`/<`````````,P``
M9@``F0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F
M_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_
M9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S
M_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,
M9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`
M_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:9
M9F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;_
M_YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF
M9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,
M_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS
M9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9
M_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`
M9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F
M__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___
M9O__F?__S/____B_)```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"'Y!`$`
M`-@`+``````O`#````C^`+$)'$BPH$&"`!(>7,BP8<&$)2)"F5A"H<.+#@%,
MW,B1(@",(!]V'+GQ8\B0&J%$!%`%#YXJ)526/`DR9<42>`"4T*,SI4J:%W5Z
MA(*G(D^A%($V1#J1I1\`+R%N+*&484R.3E?XJ:+S*A2350WZY%A%CQZ5$IN&
M/3B68]J18-<*[!JQKMV[*^4.7"&S+LFW>>6.+7'@@->)"%BP0.!6K\\2BPM?
M+8&@,(('C&<N31@7X50:@1*R:)%X!><#++Q^U$/*Y`J$G.,JM'F@A6D`!VB`
M/BK:JT`]R:H\(94LS\#88&?K?%)E!0O."%K00("<A>&(`I\D2P:\^''DV"S^
M)NQ.*G'A%GJJ'*A.BI1I@56V`W\-._S'V>&W$]?CG'SE]0",1IQ[`JU`G'Y/
MS,69?<KE%]QV$)*BG7N*C6;6=K<EI%][#";7(`#)D-(=A-Q!F%YW51#'U4`A
M+KB@6+,!%Q^)--)(2GRWP:<@@S""M0)W,]8H)([VU5<D;++).**0$99EDFP6
MP2B6C"DR"6$5GB0XUT.=*=AE>/'=&&2-9:UX)$91/K13B%5426*93Z9YT@I:
M*E@"EB*F5V9S<7X)$G%//&&:5ESI5)99?!JI%``3NG>`'ZB@4@4+4"!@Z7H]
M^MG0A$#&%*FDNND&P7-LR8F1=O*M@!JD?I"DF%[>!+&V75K.A6IK"U]IJI1V
MZHV&ZT8M_`J%=2G"RF(RIK$`@6[!XJI8"RSH88TU9AD[W`I\0F'K`Q6ML$(I
MJZPBK1[&AB?M$T*M],0JU);)+KGE/C'M*H)BR^ZTUM!;RK3OP<H2O@`'G*^\
M/$%!WUH`K"#PO.$"+!Q,,1V\J$KWYBON"A4E7-8JI902",9JE8K?EG,UU=-=
MWT$DE<%HWI?<8635^1A'3_C1\IG8K%"476W6&1[,=Z+B,T/WA8<0'GXDK727
MV&),)ZNZ'F=T9PG5C.Y"3J'"ZM7E!E6OI@$!`#L`+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]K:7)K+FIP9P``
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$R,S8P`#$P-3$U-#,S-S8W`#`R
M-#`U-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_
MQ``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#
M!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*"
M"0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS
M='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$
MQ<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!
M`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<`
M`0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9
M&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"
M@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2
MT]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/Z"O`_Q
M,\#_`!*\6>//#?@O5-*\01?#'Q;I?P]\8>+/#FJ:7J/ARU^*'VRXN?$WPNTF
M^N-9@_M_QSX0\/\`]B7GB_2/LFD6/AVY\7>'M-DU^]\16_BSP[X4_)?_`(*_
M76O7#_!VSA\07WAG0=3_`&9_VW-*U#Q-HUF^JQ:CXPU'4_V;?$OP%\$>&9[.
M2WN#XX\=_'7X>^%-#\.:/.KWNKZG:77@[1=4EOKVX72?O+]C[]GO1_V2_P!G
M;X6?";3[6[C\80^$=!OOC#JL$]_<ZEXG^-'B+2E\7_$/Q=X@UH7L3OJUU?:Q
M8>'(_$.O0:GXBL-"\->$O#Z:DFF^#_#EKI?Y[_MS?"7PC_P4`^..M?#WQYK?
MC'X9?#S]D#6K2VFU/P;J4$$/Q>\:_$OPKX/\1^-H/%6JW=K>0>&_"O@/P'=^
M$-$^&_B3^Q[VRUJ]UWQ=<Z=+X?L_#U[':?P#@JN3\.9K5Q6-Q4J>%P%!R:^J
M_6%6]JE1BITES*+4G%P=I)-WDI14HG]R8"CB<QK865&K3C&O5M:KRN%EH[7B
M^DE>S3=DKJ[;_/3]E?\`83^'W[1_@+XQ_%KQ5\69?#OQI^-/BR_U_P`4:#\$
M=?\`!-[;?#6]U7Q+=^,+_P"&OB73%N_%>@^$M*\1>(/"NB?%&?PUK,FE>(]$
MD\.Z1X:O&M_'FA7US7T7XH_93^`OPA\:>&_"OC/]I#XW>,_$7Q(U;XB^*O`O
MP$\)+X%^&VHZCJ_Q`DM_$>NW[>(`?#>CZ5X;\0S+87FG>&_&7C/P]I?B1-+\
M//9P:_+I6D30]EIO[+'[-UQX#\'>!OV>O$;^%/!7Q*^-GA;Q#XPNO!7Q$\3>
M,[CQ?_PAGP]^+FOZ;HZWU_XRU'0E\3PM<W%UK5G:>*M+5=!LO^$[\17VI^.K
M75[KQ)[K\5/^"?\`^S'^T-\0?%WC#XF_#>YU_P"(GQ%NH-5B\:^&_&VJ:?XS
M\)0:/:RMIWB+X417M]X<L;ZPM3IJO8:UIMW?:8^BW=J#H&J7A@U0_G^8\;4Z
MO$]>ABL\S+#95CH3G0K1RA.I1A;EA!-RC*$(I-)1JKD3<H+FJ2D?K,LN6!P5
M*-"K@98NDN=44H)5&^722BFIK>334GHMFTGPW@CPY^S_`.`]-TG]E_QG^S+/
MI_PDO=8$-IH7QCT;79/B1X<^(VK^"YM#\':KXFT/Q'H?BGP]>:)XST7PI9>`
M?"WC[X:^*/'5OI'B6VTOP;I=EH&H>-=+\/>%O`/%/[+[^'_VK_%]CIY_:$_:
M";X4>#?A]XA^!5EH/QS^$$8^"OPVGUCQ/9^-?"!M?C%<:SK^J6^D/;Z;>>#?
M`_AZUU+PEXL^#^KS^'/$UYJ6M?#33M?@_1[X,K\8O@!\)?B;#\79=*^-FK?`
MGPYXL;X.?%^VU.STWXG_`!0^#NG>'+_XA:3X.\5R7RZ)>/+HCV-IH-I9W/C+
M4_[9&J7GBO7$U?Q'X9&I:I\+6?P6L=#T7]EO]L"]U_XVZ)^U+\8_C1\$?C#J
MDNO:D'^$WQ.USQ)HD;:5IVC:O\/K[7-2TGX;^%?A-XF?X+>#=6\-W&L6>D:9
MJGAWX<^.O#AT?6O%;V?3D&9X>E4QD\-Q'CLWH5)>P4L2JTFJM27M54C[2I"4
M8N*5-NSY;1A*'M)3G#YS%XK&58*.8T\-2K5I.%&C""BHV7-=1BK)RBFW;73F
M=TDGZ%XO_9\^`_CGQ;XH\;2#]N*XD\8>(M;\4R3OX&_9YLGF?Q!J5SJS2O9Z
M[\#+C6[1I&NR[6VLSS:K`6,6H2R7:3.Q7DGB;_@L-^T!\,O$GB#X;:I^Q!%X
MSU/X>ZWJO@?4?&/AKXF^-+SPYXLO_"=_<:#>>)?#]W'X%U".ZT37;BPDU32K
MA+^^2>PNK>5;RY5A,Y7VD:&-DE+GAJD]<9AD]5%[.NFNFC5^C/FO[/?9O[_T
MTZ]-/N/Z)%GL]0\9/>V^KV6OVFK:FE]!>6<EGJ*R:9K?V?5HIKF_5&BGGM].
MTT7.F:A;LFA:EX?DCU`0/%)&P_D[_:1^)/@#4O"7Q7^+OBG6/CEH7Q^\:_M>
M^)_AA-\3O%ME\&OBG^R;I^E?"CXW?$O0O!6HZ#H&O:'XUU'5]$^"GP'CGT+P
M*-,TBRU:/Q1JOB*'77U#3M$TJ'3OZ4?C-X:OS\!OCAX<^'DNG>&O$\WP2\9^
M&/`U_86]SI\&@F#P7<^'O#L/D:684\J#28[6RT>WTB*$:#IMOK$2+$+"V$7X
M.?`+Q1X?^,OP@_9'\"?#GX,?!+4M)^(O@BZ\-:7:?%K_`(1V\T#PM\6OAAX`
M\3:Y\6-;FL[33/BI:V7_``N.ZUBTU72/%&K1Z%XFU"[DO8;S3-,GU76M.FXL
M#G4J6"Q.8U<'3Q*Q3H49>TC"4GR*=:,6JEU+F<.92Y9Q@X*]N9*6F291@:_/
M3Q&(Q5-4J2GAY8:<X*G4;@I.3CJH\NFK7-KULSZJ^)O[._A3]G_XW?`?XY:9
M^VE^U9;67BKQ?#^S]\4?%]Z_@CXUZA-\+M7^'OQ<^,D\END7P%UO2+:PU/QA
MX/\`@AH%WK4&E:KX:AT37=0L)HY]/\/WU\_B_CMA\2_'7P=\+_"3XM^'?^"@
MD'CVY\:>)/')TKP%\+?V</B[\*/''P\L]$TSP=XOT+XJ>&/"VBVFC^)9?&/B
M32K+4K34=/MY;K1/`_B>VU+6-2M9M2>Y]*\+6?[/?PR\0V?A[XO?`#1OV*O&
M<TJ6?A;QWI(TSPM\.M5G%NNA2Z+X8^-W@0Z)XF\/>)O[/\0MH.IP^*;/1)]3
MTFYO?#EQ':V/B^\L=-Z.Q\>>$OV5_&VJ^)M(O_AMI_[)_P`7_$OP_P##6LMX
M1\0>#5T'X&>.M,FU;P3X:\0Z-X>\/WWACP[?VWQ(CGF\.20:1HO]F^'-<T_1
M/$OCWQ&=1UW4EU#S,5Q)C*]+F7#U/'3HTIT\+'ZG2E[31WA^[4U>,:D+1<[6
MBU*\G&#]&?#$%B85_P#6F47&2Y*<L54]K'2/NN\N>2WLHW;EHK-I+B_$'CW]
MJ?0?VH?"7Q4U7X(?M=K\/=<BM;[5_@B/$'PL^('PYT;PEX>N?#%OXV\2:!8_
M#+XLZ+X?U7Q`MOXA\)76E6VM_#K7?$'B?4+>\?29ETG3K&TM.B_9W_:4TR__
M`&9_AY\,_@YX*6'Q>-3^,/QA@U?XFV&N^"?A!\+_`(9:G\8O%Z?#WXZ:YXKM
M[./QWHGA[Q6FN:KI?P]T[P[X9GUF]U&?Q/H5GXK^'_A""V\7:C^F.I6EQ;O>
M6IN6M)Y+N&:[NM-MY8;EX[2Z;5HKT7-BNI:1)JT-V+6SM]8GU.RU"%+&.W@N
M;>W7R*_%#XN_`3X)>%_A'HWPWV^+M2^$VC:I\3;?]JOXH>%IKZQL_#G@KX/^
M'-$^-GB;P7X]7PQ=VND:KXAU?P'IV@?"C]G;P7X_N/$/P^T3Q#X^N?$N@1:1
M>7-IM^4X1XLRWB#%+*\3D\\#CL+C%.IA:,9PA3I^]3YI4I2:4IWC!*+A=Q<8
MIRG8]W-,JJ8+*I8ZK7I8N-!.:KI>TJ;<RESVYG>VMN9\S3OIK]`ZC_P3LT7X
MD:A??$2W_:N^$^HV_CV\NO&D&H7G['-UKUW?0^*9WUR*\NM<6VB76KFZ2^6>
M?5EBC7497:\$:"8*"O>IO"?_``43M)I;2Y_X*)_L_?!ZYM99+>X^$F@?";P_
MK6A?"V>%C'+\.=$UB7X>3RZMI'@B16\,Z;J4LTTE_9Z9#=/+(TI<E?LJ65I)
M?4JVFFT^EO/R_%^5OR1\1R;;6*KV;NK.E:UX_P#3IZ:=WUWMK^E/AI;H:S;1
MR":[DCNK?0KZ."`7L5K<W%Q:)?3_`&86\]O91V]I+?:;>7#/+873:E]JNC<P
MVNOR7/\`/[\![_X<?"G]D3P(WQ=\1:%X<\$?!WQW\>OA;?:QKHM?[/\`"USX
M&^/WQ*MO[2\/K>P&5/&$NDZYX9T"SO='T.[%O906L>DR1VJ0`?FBW_!0S]N_
MX@'P[>:I^T3XA\/7?A>'^P]!D\"^#_!'A/31JU@)=5O-5UQ/#6E:A::Y<:AI
M?B33]-F\/ZSH+>&[4VVH6]AX<TV._P!1MIH/@5^T7XHO_&$'[.7QA_L#XL>%
M?VMOVG_`?B/5;O7)=.\&P>#M4^)GQ+T/3?B7XAC\%:+'\,[75M8\2ZE?>&84
MELI]*\-:3XCM[R\L=$6QL->MKOQI\.4*6#K86E7G7]G.EB88>E4E&3A24I5(
MTDX:2<9<J=FVTU&,[I/^BL'X:<5\(QEFF88?"3R[DE2JRJ4H5(.*ORRE%Q?,
ME=N]M+N[6Y\D?$O_`(*9_MG_``S^+/Q[M_`?C_6OB%\";3X@>)]`D\%_M%>'
M4_:*^&VG:7'>:M;:!8ZS:_%=?&<DU_<6M[-!86^I-X>6-KR>!M'TGS9M/@F^
M#?QC^-W[>?QP^'_[,K_!G]C3X;W'Q4U)+GQAXA\*?L2_LS?"#7M#^'6A:4?&
M'Q&U;3?&.E^%)O&-IXIO/"_@K5M1@UO2O%/@>^OAX<U2PT&]OSK/AR./^GE?
MV3?@%KNJ>(?B?K_A#0-)U[7=!@>_US[1IVA:-)IFC6L*Z1K>N6GCB\F^'%EX
MKL=)-E<:MXVU+P_XA\):Q)8^)+BSGM=;32].U#XMT7]LW_@GM\,OCC\9=8\$
MVNO?$WQM:?"273+[XJ_V;K^OZS\0+Z?5B-(\$?";X;ZAHOA/0=/L+%M(\;3^
M(?B)'X?^#VCW<,6FP:CXCUKPAK<&JZS]5PSXL91FV6X_*<CX&GALPR[!QP];
M,*^"IQC6JRG&@I>W]G%N?/S3DW)N?,N=M-R/Q3BC@?#X/-?[6Q/$53"NIB'B
M(X7"PJ58.$N67)[*"<5"*:Y;+E<E*#=TU'](/V,=9E7]C/\`9\MO'OBS6I?^
M$>\+^-/#ND^+=9T[.MZMX/\``GQB\>Z3\/DN-$3PI:ZO9:[HOPT\.Z:ERSV%
MGH6LZ=X>UF.[UEM1A?Q5><A^PS\!/`?[0FF_';XX:G8^/O$/PG\?_'W7]"^%
MVB:AXV\4Q^#_`(Q^%?"T\&I:YXR\:_#OP'K.O^$/BKX6\=_$YY-"T?PWXQT+
MQ+H\O@;PKH,WB[P[HTM@D-I^-?B[Q[\<OB1X7U"PO/A)X?\`AU\%?#GPS\1_
M#[]G_P"`OBGQ+XTBU73OA#=>$_AC;^(=!U&;2H]*N/$'Q`^+/P8\<>$/'&@^
M-8_B6L'B/X1^&?'6D_#V\\+Z]J_B/Q=8==;_`/!27]O'5?`WA'PUX)\6_#G]
MF_P=X4@\66GA>Q\$>`/A5XT\5)HVH>(/&OB;PCX.DU74/"&I?#?P7X6\(?#:
M\TGPSH/B#PYH=OXBOQX4M+[4M<U/5M4U*_OOG<!P+E>78['<18VO1PV;9JXT
MYTH<M/V$$W63I1IS:YI*7)4<>;EE%1]I)-R?VV2\,<7\;8*CE?"SK8["SUQ4
M\3A)T:=.B[.G4YY0?,O:;1Z1^%1BHI?V!17>LSQ1S07.A7$$L:2PW#7ND7K3
MQ2*'CF:]DT74I+MI4(<W3ZC?O<%O-:]NF<SR%?R2V?\`P4J_;=^R6O\`9/[1
MNM7&E?9H/[,N%\`?#:)9]/\`*7[%,L>E?""'2XQ+;>4X3388K!`VVSC2W$:@
MKO\`[/7_`$,\7_X.E_=_Z>>:_INWM_\`$LW&O7#X._IKT_Z<^GX=M?R2\)00
M?8]03R8MAUAK@IY:;3/+<`23E<8,T@1`\F-[A5#,=HQZ'\/56X\.?'_4KA5G
MU'P[\)?VH]7\/W\P$M[H6J^#OA-_;'A'4]'NG#3Z9J'A75KFYU3PY>V4D%SH
M>HW$][IDMK<RR2L45Z&`_P"1G_W"E_Z4C^L_$W_D@JG^-_\`IL^Q_P!K_P")
M/Q%U7]A3]D6'5/'WC74HOB3\4/V<+OXBQ7_BK7;R/Q]=ZE\,_'^O:C<^-4N+
M^1?%5Q?ZYX=\/ZS>S:Z+^2ZU;0]'U&=I+S3+*:#[7T/PUX<\)PSZIX6T#1/#
M6I7-G^W/IUQJ/A_2K'1KZ?3]$_X*=?L0Z7HMC-=Z=!;7$MGI&F:]KNG:7;/(
MT%A8:UJUI:)%;ZC>1S%%:<+_`,.G_P!A^)_])D?Q5'_>\1_UYPW_`*EH_GH^
M%7B'7_$OBPW?B/7-8\07>A:/\(9M$NM;U.]U6XT:;2_AGHGA;3)M*FOYYY-/
MET[PQX:\.^'+"2T:%[/0=`T72+<QZ?I5C;P?2GQNEDB\,^(/+D>/?\)M4NGV
M.R;[J/XPZ'8I<MM(W7"64\]FDQS(MK-+;AA#(Z$HKEXL_P"1OA_6D?WGX&_\
MDW_W"A^43QPZ3I3$LVF:>S,268V5L223DDDQY))Y)/)-%%%<2Z?+_P!QGZI+
M=^K_`#/_V0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O879A=&%R<R]K<GET;VXN:G!G````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#$P,3,V`#$P-3$U-#,S-S<P`#`R-#0S-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#_V/_@`!!*1DE&``$!```!``$`
M`/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!`0``````````
M`0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`!!$%$B$Q0083
M46$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#
M1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7
MF)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7F
MY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)
M"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@4
M0I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I3
M5%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2E
MIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U
M]O?X^?K_V@`,`P$``A$#$0`_`/X1;AHDO5,ZL\*S,TBJ^PE`[%BKX*[E'S!,
MAI"`BD%@1^]G_!+K_@D/\>_^"E.BWWB;PGKOA_X8?`7PEK8\.^./C-XELI]7
M:3Q)#86FH+X1\'^#+6ZCU#5=7E@GC>6ZNYA;Z>\IO)DEM+62TD_"SP^MO+KN
MG?;()KP27+16UG;#?-->SAX+8&-"'"R74MK$F0%DE8(N\AEK_6-_X)?_`+)V
MA?L4_L4_!'X(6NG06OB:#1%\>?$_4(K5(7UGXC^.H8]8UB74<@F:\T.P&BZ7
M!*-H@4D0K&SRE_Z0XMXNK\+9'CJF!Q%-8[,*LJ&'HM^\E1IT9SJR5TU&2FHP
M:YGS0D[)73^<RK)*.>9C@<+B\/*IA,)'ZS6J.*=+WFX>S4K-\\7!-KW5:2U=
MM/GC]E7_`((@_L#?LM:5I]J_@'5?CUXOMA;75]XM^,\L>L6\^IQ;6DEL_!-F
MUGX7TRR23=):1:EH]V^]8L-]H6.1/T8USX'_``7O-&F\/Q?!SX:?V)+$?,T5
M?AGH$.EGRU#1JD5OID-FBHZ(R`1A-R*0N[!KV'6-52%)'-VP(B=C(Y$TC/&I
M>%6:7S'=3*$`5B5!(P*_/;]HSXL>.UUZ_LM*\5:II&FP0V]O%IEC-'"KR&W,
MLS,\<:S_`#!2^/,(7&$"C@?S/G7B!G,:DZ^:X[&8RLU&RC6DJ<(2C&:IQ]Y>
M[%MO9/5O2Q^W</<(X2=>G@,LP.74()<WMI4N:=Y/NZ;L[):7U>SZGR7^UE_P
M37^&OCKP5KU_\(_&$W[,?C"WT^\-CJMHUK??#V"\F/E_:-8\%373VHT]XGEA
MGEM+6..P$HU"YAN;>UE@D_@U_P""E?[)6O\`P#^,VK7RQ^%[ZTO=.T2^U:Y\
M'ZJ-=\-75Y<6L=M>^(]-O,0SKIFKZE!)+<),K+ITU]Y4;Q011+%_;#XUUO4;
M^W4:Y?WFLQ7SO'/;ZC>7%S&(V)\X3":0AT*%LJX9>>!D5_.__P`%+=(TF?QU
M\!?%]S;Z;>Z0;_Q?X,\3Z#?M(MAK'A2Q-KK]]I-Z89(Y#;R6T=XMH`ZB-Y(X
M%86I:&NC@[C&KQ%FM'(:F'3IX_F5.=2<IR53E2;G=MQBTHVLGK=I'H\><'U<
MHX?K9L\4ZE3+ZE-RC1A&,>2;C%1BDE?EE=MNWNM/5Z'X/^'_`-L?]J_PQH.B
M>&_#GQG^(FE>'O#VD:;H>A:797LBV>FZ-I-E#8:786BK:,HMK.QMX+>`!F`B
MC0`D<T5Z=J_P+^$<FK:G)IOQ,\0Z?ITFHWKV%A!]GD@L;)KF5K6SAD)8O%;0
M&.&-RQ+(@8DYS17Z3+PRQ/,_W/5ZWGW7]S^K+R/RF/$6,M&V*@E:-DZDKVM'
M_+^KZ?//PKU&WT3XE_#?6K^!Y[32OB!X-U6^@4(WGV.E>)-,O+BS<G<J)>$1
MAY9AY,/E*?WDC+$_^JK\%OVS=0^*'B^Y^''C_P"%/B/X,_$+3=)U34M/@\07
MD<OA7Q_I7ARV\-IXSUWX>ZM]IDGU_1_"3ZAHL>HR-IJW"27<ZK.8K=0G^6-\
M.?A-\3/''@OXK_$_PEX5O]4\%_`KP_X:\7?$?Q6EM.=)\+Z?XH\?>%OAMX8M
M+J_V?8!J.O\`C3QCH$>GV)F%^\.F7U_;Q"WLKJ5?]4CX76GPA^,/@KPY^T'%
MIMOJ?C6'X+:1X/TS4)[&UO-3\/R^(O"?A>W\4IHMU/'//:6FMZI96ESK"6BI
M%<?9R\R[=^?&\99X9QRC&4,5%XB&(S##2BIJ5)>SPF&J1C*UU&IS5973UVNE
M9'T?AYR1>9X;&X>I*@Z.#K1E"DY3:Q%>=/FA>RY/W3N[VT?Q-V.5U7_@I#^Q
M==ZQ<>'W_:#\!:7K&GZE;:9>Z;XB_MGP]%+<R2OC['=ZE;$7"DVLJ*\9$4C8
M5<%EKYK^*WQ*\.^)_$>K>)/"VK:?XKTJ^F,EG?Z3J<%U8L3`\44D<HACC$81
M^=XPRYQER"+WQ>_X)7_LN?&#3=25?#FCZ9XS\4Z5X7TVZN]5U>;3M5L;;P]?
MP:[!<^#YW2Y-M=37=L\>HW,,`N;K3I[RSGG:"0JOF<W[*7P=_92TJ/PGI?Q(
M\6>+;Z2R>;7_`(?036>LV&F0PQ-)!>7?B'4KIM0L?/F2*-8;6-49F6*.*$N)
M%_FK-)8S$X53K2@YRC&3G&3<;*,59MJ]TEKIY7/Z$R*CE=+,7+`JIR2A%1A4
MIN-2Z2BW_(E)QTM/JMMCQ/4?[6\3K=6MM'NE*3_:Y$_=64"!7=2U^X$,9+*%
M/E$/(3Y2$.ZU^'/_``57^'%SI'AK2M1L?$^G:I)\*?&WA[_A/[.UM;F#^R[?
MXB6-M8Z6D5S?%[>9Y;AHDN@00UKY^!S7[3:E\2X_&6H:%H4<-IX6\(Z9K5HB
MZ'IJ7#3WUO#=QO.=2N\2W=V?+C:0>;+*L3JKH(R@9?PM_P""IOQ&:WB\7_#_
M`%N^CM-=_:)^+&E^-9]+O+F.2+0_AM\(;9]$\/1+$;575_$>JW5O-&?,2X5`
M\R2$1*![?A/+$U.,,J6$3K5H8BFGRQDX12E%R;=E9:VZW7E<\SQ-JK"\*9U#
M'3ITJ.(H+V,)23JRG%Z24;N-GHE:5[]-K_E;'K_A&"-(4\-Z-*D*+$LOV\#S
M%C4(KX$@`W@!L`8&>.**XB+7K"TBBM!X8TQA;1I;AA;1ON$*B,'>X+/D+G<Q
M+-G+$DDT5_I`L3B;)/"J^E]*>_NWZ^;^_P"[^&^>;LTZMM+:>EOT_#MKYU\(
M/VH_BM\*_@U^TO\`LZ>']2CC^&O[5GAWP-H'Q)T"8(H74?AG\3_"OQ1\(Z_;
M*8S)%>Z=J_A&32I`6CV:?K5ZV5E,'F?VO_L/?&B;]I/]BOX">&/!EKXYT+7K
MKX?Q:;XFU[P9X_T3PMXAA\1^"KW^Q]<T:QTK6=;M[B^L_$2:;%?R7EG''?VU
MM<O%:3PVI:%OXOOCW\([C3M8^('CCPYIT&G6?P]\;/X5\=:5]JB:XTO59M6O
M=(T34].M)#YUSIFLBSB6ZE,1@M[UH(P[233)']X?\$WO^"@/@K]GVUC^&WQY
M6RN_AM<:A>ZGX?\`$%UX:MO%-]X<U#4);:6_TR]C6%=5MK.^N=/LME[:WD4F
MD,[7]LT<<4Z2_P`I<;Y%4S/P_P`9/!4JF(QN$SG^W8U)M^UJ9;B\+@L/*-"[
M;G)SPU65FU!K:;V7[]X?YW1R[B*K3S/%1PU">`GESBH4YTEBZ->K.E[1R:MR
M2J-.R<DDO=Z+^MI/#7BOP3<Z?"WBCXO2^)`D-E#X=^(=SK=W-HZQ2K);RZ?J
M=_>ZI#?^9*B&21;ID:$NI+1,4;RSXI_$K[%YT[O=+J.N:=:W6MI?+`)8[F*.
MXM9XA.$$UQ"]^MO?)#,[Q1&$>3&BY4^5:9_P4#^#USX/FO?A3\3_``=>VFL+
M-#+#KGC[6/'%KI%I)`PB70[35I+B\TV_#E%M[.XNIUAN"B(`1BOD+4_B/8^-
MK^.\MSXVUS2+;Y;Z\?3)+34+B"(R27*V"S[;,!8'G:U>6-(Y7V">=%S+'_)=
M5XNE)T7]<;I2<)T*D+.[:DE;F?V)1COOS>I_5.7JE62KP]C4HO#QDJ])4XQ:
M48\SYKIWNG+;9KT.M\0Z]J_B73M1&D:UJ>APQ02V[:QIDCVEVMY,?*C:SG@\
MMXF,CHC^2R*T32+(&0NI_FV_:9U?QUX?\56.I_%G5KSQ)I_Q(M=:\1^`=4U;
M7Y->\1:)X'\/>._$_@S2;>:WFFFDMS>3>'+B^ACN#YEU'=K=3F<V\3Q_IU^V
M9^W'X;^&'AJ'X7?`PVGB;QAK,<ZPO'C4XO"$=PNRY?5;BT5_[2\4Q6WVG[3I
M,/GZ?IB;]06Y=K0(WXK_``L^(N_Q7=^%?&_AZP\=:;XW?PWX>U.;6;<ZEXAT
M'0M)UE[VYMO!][<^9=:+'-+/>R:@UK<6LLUI)=2R,]RJ2K^[^#5#'Y;CY9@Z
M-+#2Q#]AA858-OVUH2]K)V;47S*-XMOW79=OYT\8\URW,J<,NP^(J5XX>?ML
M7[.I>"C=ITDW+F]I%PY^5I1LTF]6UOP?$#X;&"$G4+X$Q1Y$MKB0'8,B0*H4
M/G[^!C=G'%%<GJWA[]G/3]5U.PL_$?CN^M++4+VTM;TZ?"AO+:VN988+HHBJ
MJ&XB192J@*I?````HK^EGC>)KN];+-]?]HQ"[7_YA_7[_N_$8XG*THI9?C'H
MDG[!:Z1L_BZZ/[O*_P!N_MF(EOJ'[8H@18!+\2XUE$*B/S5@\7^"YH%DV!=Z
MPS32S1!LB.6621`'=B?R?OF9;)RK,"[0[R"07S!D[B.6R22<YR22>M%%?)XS
M_D0T_P#LE<L_]/8PZZ__`"-<=_V-\;_Z>B>N?!+7-:L?%OAZWLM7U2S@76;!
MU@M=0N[>%7:Z&YQ'%,B!CW8+D]S7[6_&?X@>/(]+\+V$?C;Q='8ZAJGAK3[^
MR3Q)K*VE]87NK:=:7MC>6RWHAN;.[M99;:ZMID>&XMY9(94>-V4E%?S7F/\`
MR,*W_7Z/_I%,_I7AK_DGX_\`7N7_`*;B?'?Q/TS3=,\'?';5=-T^QT_5-'U/
M2=-TG4K&T@M+_2].FUK28IK#3KRWCCN+&RECEECDM;:2*!TDD1HRKL#^>.CN
M\6G^*=1B=H]0@\/Z=+#?1L4O(99O$&G132172D3QR2Q.\4KHX:2-V1R58@E%
M?JW"'^\99_V$/_TBF?S]G_\`'S+_`!_^WH](TR&%]-T]WBB9WL;1F9HU9F9H
M(RS,Q!)8DDDDDDDD\T445^VO?YK\X'YR]_FOS@?_V0``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T
M87)S+VQI;G5X+F=I9@``````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,V-#``
M,3`U,34T,S,W-C8`,#(T,C0Q`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````$=)1C@Y83P`1P#W`````````#,``&8``)D``,P`
M`/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`
MF68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`
M__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S
M9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PS
MS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F
M,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QF
MF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9
M`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR9
M9O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9
M_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,
M,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,
MS&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_
M`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_
MF6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S_
M___XOR0`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````A^00!``#8`"P`````
M/`!'```(_@"Q"1Q(L*#!@U!6'%S(L*%#A@D!2)P(X,##BQ@;LJ#(4:+"C"`Q
M;NPX<<4*B2%3-B1)T4J@DP!4RB08@.5$*U9,`O@X4Z7-DC`ELNB9<N1/DD1#
M'K69%&3-I4$E0FF*\:E.BB9S1MU)]6)-*ZQ>MF1%UDK'K@\#K&!U[5J@FV39
MLMJ*UF$`L"[G2@QD+6>@L!SK-@P0R,H!L##_GES+*K#@A2QP[BRU0H4**ZLF
M*J;X>.'=N2K^C$HU:M0?%22<L"KEN'-!%@%6`<J3JG9M5:/RD%KUI+7K@37_
MD&J6BAFJ9LB1JU+EQ/=O;!OSC"*.BEERY*E4`7+^F\6*T:E0_E6_GDI4;HY#
MGPO<B&>4\>3A1<D?U7SG8O7K`521GJK9*/E^^"%<*55(Y-))^$%W`"FD4"$:
M@`&24@HTJZBP4V$`!(#?1H'(`LAL>>11!2"ED-666?:AI%X``9C"RBJEA/AA
M*:M`T]8UK!S`D8;=W=5**V2M(N0J;-UXS2PH4I3>8[`%4&20+[(BBY%MZ<5=
M5QP:&5>15!Z9Y$1+HK41%%QV:2:.)(79U$:$G>DFCA:>A65-:[UYII5R)@6;
M1X%0:4V956X)&$D\$F74"G^U8J0U76[Y%RLH;J5F44\!\)>=5`JZF(Z<]604
M6)B:^:=;)2G94P`'U-1GJ&Y:>96*_BK!ME&=K+IIEDE132K24ZO6>N9;.@55
M:$@!S`JHKUH&%56LO"+KIC7*FAH2F[1VJ2BRT98T+8L[/>MLDE$->]&LEK;Z
M;:F=BN01`,?>V*Z=7U[)D%75-NKL6RQEM">N[SK;%KY(J4M1O\Y:@^]6,6&4
MD!-4D*!"OP3[:0TT]2G)8D:!D+(<()<]Z6];SX1<L40DL.!=1J6,UHPJ>:A0
M1;LVLKH<RQVIE4=&TL%7A0KU(FM-:31W5,5R%UDA"G+6^=<<HOY:8PUIJ>!!
M`D<JD$(:0_OE(1IQQEPW"I]3^FK-*J6EX@=J$ZF0ARKE+20:,TE/9QW<R!5H
M8,14PEC:_G]X..&W$Z*-)LI"?C0#]^%)6]=?*7$"`"JK>O]7VA^!E]8,*JF4
M<I`HQ1UN..+6!6U@K12:QXQYDAMC#.*JD&(0YYZ#3G=V%:]PK9DQMP5-*>V=
M7IHHJG?]^=4%_?%YXK+W-XJ%)%A1ZRHK]+YZ\,P([_DHK@_T=NS)9Y?'$X#<
M;N=<)+2W.G*KT_VYX:-I+I`?[E6?]/&(US9AJ`:?I`+\LC/3N>?^`<1`^">_
M^76/0;F[4Y)48#K$K>]X_AG%0`#!N?3!S8*@BR`52F0F((DE;02<FW&J<[B]
M$21G7<-@_[K&'!4\X5%D"40@(L(1)Q#P>.*QCC%05Y`\<(XX@?-#6@'3-PJI
M36TI$K'A*-*'P=)DSR!_P$,>_"`?U%V'?N;IVQ&7DIH'':YKS/@/1JI`!2E6
M3F[8$46(&L<1A#FL/:6)6VY40H4ZXJ&*DO.#%GER$2E6T3Q_H`)1R.@$/$01
M#WUS0DI4X"#*_2$/@J3*WYS@0IFH@&%XJ&."GA,0```[````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]L
M:7-A+F=I9@``````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,3`V`#$P-3$U
M-#,S-S8V`#`R-#`R-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!'248X.6$@`"``]P`````````S``!F``"9``#,``#_`#,`
M`#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9
M`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``
M,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9
M,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`
M,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.9
M9C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`
M9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9
MF0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`
MF9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9
MF?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`
MS&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9
MS,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`
M_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9
M_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````(?D$`0``V``L`````"``(```
M"/X`L0D<2+"@P8,($RI<J!``"8,/&38<I8*@"HH2$P)HAA';Q685!9(`D'&@
MBF8<57SD^/!B1(T`8@)8B;(F2I6CFKU$2"*GS9]`4>Y$>#*H4:$,>QXUJF(D
MR81%EP8=-=2B3ZD_.Q:,21/HQ95?1ZU`".`J4"=B5:[(24(%@!6!QA[L:G/4
M$U;7KK%Z(A8O*RN!J@JD"W(%WKQZ#2-F)9<H4(I_$5\S;"4OJY!SS=94O-BP
MW\8&":.T>YCQS!5-H6JF6#2MBK4<1XUZRI-$VYL4CZIT*Y%$2MD@-=?4JK!G
MQ9FL"<L6#%'D5=8.;4LO.3@K5>H0-:?&/E"F9N89`20$.NV3.'>9K!BCG@U>
M(E?/*]X&YNY<=DRX^.ECD\F_/VV$`0$`.P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]A=F%T87)S+VQO=F5B:7)D+F=I9@``````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(R-S``,3`U,34T,S,W-S``,#(T-S`Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````$=)1C@Y824`)0#W
M`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`
M9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`
MS/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S
M,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PS
MF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F
M`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF
M9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F
M_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9
M,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9
MS&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,
M`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,
MF6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,
M____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_
M9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_
MS/___P#__S/__V;__YG__\S____XOR0`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````A^00!``#8`"P`````)0`E```(_@"Q80-`L*#!@P(3)CQ(4*%``-<B
M2IQ(T>!":A@S4FOX<&)!CP0I7@,PD)JSDRA1DAPH$<"NEQ!'OMP5,^)*`"93
MZB09$X"PF1!]`O7X,*=.E2Q=[A*6+%(DI;MJ[7IJLZ@S@BD!(`WZ,EFR6DY?
MUAI+=65)K5>-&=.*]5A(I<F$D1U+M^Q%E,:``4-[TBW7J'+I"K9;\N2>/0#T
M`MB#TJ],L8+K$L:Y<V]*QX^C1G8:].Y.OLXP/XX,EG#ASY=#MH1,ENK(HJ"/
M]E6].JI3UV9Q4HZ=NN;JVST?ZC;I5O9LEA6?!A=..33OQC=%ULR-L7EQXVX7
M^FYYU_ISZ`X9EE(_J?68^>_.':H/G[/\>>/IUZ]O3KX@_/CR%=*_?S1[_H7'
M\"?;>?^%9YZ`E_E7H'8'\G>>60OJ!X!Y%%9((4<1JD>0A1SZE6%^XB'TH7RL
ME&@B`":R@F*)(RJ48HHKEABCB2.^"..-,[*2H8TWGI@CBQ'RJ")!/A*9XHX\
M%E1DCA_:B.*3*_ZH8Y-.5GEDBT)F.65````[````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O
M;6%L93$N:G!G````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S(W,P`Q,#4Q
M-30S,S<V-P`P,C0Q,C,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````_]C_X``02D9)1@`!`@$`R`#(``#_P``1"`"^`)8#`1$`
M`A$!`Q$!_]L`A``&!`4&!00&!@4&!P<&"`H1"PH)"0H5#Q`,$1D6&AH8%A@7
M&Q\H(1L=)1X7&"(O(R4I*BPM+!LA,30P*S0H*RPK`0<'!PH)"A0+"Q0K'!@<
M'"LK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M*RLK*RO_Q`&B```!!0$!`0$!`0```````````0(#!`4&!P@)"@L0``(!`P,"
M!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B
M<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI
M:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"
MP\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^@$``P$!`0$!
M`0$!`0````````$"`P0%!@<("0H+$0`"`0($!`,$!P4$!``!`G<``0(#$00%
M(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ
M-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(
MB8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8
MV=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/JF@`H`*`"@`H`*
M`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`
MH`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`
M"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`"0.IH`JW6H6MJ
MI,\\:`>K4KC46]CG-4\?:'8`AKI78=EI.:1M'#S?0YR]^+^CQ8$*,[=QG&*G
MVB-%A)=3'N_C1&)F6WM5*@?Q-S2]H:+!]V<KJ7QHU-I3Y$L<8'&U4S4^T9HL
M+!;F1=?%SQ%=D>7-<JJ]XHP,TN=EK#TUT(+OX@^*9[<!;F]=7'(W!3^E+F92
MHTUT,S_A+O$O]_4O_`EO\:+LKV<>Q6N]?UF\(-W!=3D=#+*6Q^=*XU%+9$']
MI7__`$#W_.@H/[2O_P#H'O\`G0!?A\7ZS;(J32ZC!".!LG;`_`&G=D<D7T.@
MT?QQJ\0#6FK7#`G.V1]V?SHYF2Z,'NCN?"_Q0O(KDIK6)HFZ,BX*U<:G<YZF
M$5O=/8-+U"WU*T2XM7#QL,@BM4[G#*+B[,MTR0H`CN)H[>%Y9F"1H,EB>!0-
M*YX;X]^)PDOVMM,O8H(4."Q<`M6,I]CT*.&25Y'F>J>+([YFBDU<M*3T5B2:
MB[.I02V1EV5K'J$;.;FY==W\8*TBBV-%M-X8J2WKF@"TEE;H21&N3UH`>MK`
MK;A$@/KB@"5451@*`/I0`M`!0`4`%`!0`C*K##`$4`9][I<4X4QDQ,IR"G%`
M#+2\DAN/LUZ`I)_=OV8?XT`>L?"GQ2=.OUT^[D_T>8X4GL:TA*VAR8FES+F1
M[HI!`(Z&MCS0H`R/%.AQ^(=*-A-<2P1,P9S'U88/!]N?TI-71I3GR.]CS:?X
M#^'EC8VC`3$Y#2QAN:CV:.A8R75'$ZU\(?%%O/(^GW%H85.$"Q<GWJ'39O'%
M0>YS&K>$/%ND1M)=RD1KU*6^:GE9JJL'LS/M[YH?W=QY\DF>28B*5C2Z$.L_
MO?+%K<9S@'90,M6-U+<.XDMWB"G@MWH`N4`%`!0`4`%`!0`4`%`%:_MEN;=D
M8<CD'T-`$>C7KRISE)H6P?J.]`CZ?^'FM?VWX9MIW(,Z#RY![BNB+NCR:\.2
M;1TU48A0`4`%`#9(HY%Q(BL/0C-`%"?1--F#>990'=U^04K(I3DNI@ZYX"T?
M4+=ECMUAEQ\K(,8I."9K#$3BSPWQ+H5UH.H/;72$+GY'QPPK!JQZ5.HIJZ,B
MD:!0`4`%`!0`4`%`!0`&@#%MW%OKTL.T_O5W`T`>S?`_4)(]:N;'),4T>_'H
M16E-ZG'C(^ZF>V5L><%`!0`V8D1.1U`-`&9X8NIKS24EN'WR%V&?H:2*DK,U
M:9(4`<E\2/#XUO0)?*3-S#\Z8')]JF:NC>A4Y)'SO+&\4C1R*5=3@@]JYSU4
M[C*!A0!8M[.YN"!!!(^?[JDT6)<DMRW/H6J01&26QG5!U)0T^5B52+ZF:00<
M$8-(L2@`H`*`,'40T?B&RD4C#@J10!Z5\+KG[-XPLB7**YVGWSVJH;F&(5Z;
M/HRN@\D*`"@""^E$-E/*W1$)/Y4#6YA_#VZ6]\+6US&"$D9F`/UI+8JHK2.C
MID!0`$9&#0!Y_P",_AY;:S(US9,(+D]>.&J)0N=5+$N&C.;L/A+<,0;V\51G
MD(*E4S66,71'3Z/\,](LN;@-<-G(W52@C&6*F]CL+/2[&RB"V]M%&H]%JK&#
MDWN<1K'C&]O[Z[T[PKI*:D;?Y997;:BMZ>])OL:1@DKR=CS7QCIU\KRWE[HT
MFGR#EQ'\Z-[Y'2LY1.RC56USE@#L5\$*PR#CK69U7$H&%`&)JW_(:T_ZF@#M
M_`__`"-.G?\`744X[F5;X&?3E=)XX4`%`%/6O^01>_\`7%_Y&AC6YS?PD_Y$
M+3?HW\S2CL75^)G84S,*`"@`H`I3ZI:07\-E+,JW,P)2//)H'9VN7:!$5VCR
M6LR1G#LA"GT-`(P_!&@?\(_I`@DV-<N[/+(H^\2:25BYRYF;ES;Q7,+Q3(KQ
MN,$$=13(/&9M!CU#3M?TVUB4-I5P?(8]=I&2*S:NCMIU'&2;ZGF;*58J1@@X
M-8G>)0,Q-6_Y#6G_`%-`';^!_P#D:=._ZZBG'<RK?`SZ<KI/'"@`H`IZU_R"
M+W_KB_\`(T,:W.;^$G_(A:;]&_F:4=BZOQ,["F9A0`4`5]1O(;"QFNKAPD42
MEF)-`TKNQR'@K3EU:Z;Q/?HQN9\BW5O^6<?;'UJ5W-)NWNH[>J,@H`*`([B9
M(('ED8*B`L2>PH`XSP#:+=#6=5&?)U*<LBD?PCC-2C6;M9=CQKQG8#3?$=Y;
MC[H<D?C6$E9GITI<T$S#I&IB:M_R&M/^IH`[?P/_`,C3IW_744X[F5;X&?3E
M=)XX4`%`%/6O^01>_P#7%_Y&AC6YS?PD_P"1"TWZ-_,TH[%U?B9V%,S"@`H`
MX7QY*-=U"T\,6LBEI6$MW@\K$#T_$U+UT-8>ZN8[6U@2VMHX(E"QQJ%4#L!5
M&1+0`4`!H`XKQ%JJZYJG_".:7)N?K>2+R(T]/J:EZZ&D5RKF9UMA:16-G%;6
MZ!(HU"J!5$-W/'?C1HHMK^'4HA\LWRO]:QJ+J=^$G=<IYC69VF)JW_(:T_ZF
M@#N?`JL_BK3@H)/FCI51W,JWP,^FJZ#QPH`*`*>L@MI-X%&286`'X&AC6YQW
MPMU6QM?!^GVES=10W*[@8W;:P.3V-3%Z&E6+YFSNXY4D4&-U8'N#FJ,AU`"/
M]T_2@#S;X6Z<D^N>(=;N)'EO9+IH`S'[J*>`*F/<VJO11/2JHQ"@`H`R_$MY
M/9://+:0O-<$;45!DY/&:3*BKLI>#/#\6A:;\P#WLY\RXE(Y9C0E8<Y<S.AI
MD&5XDT2VUW39+2[7((^5NZGUI-71=.;@[H^<O$VB7&@ZK+:7"G`/R-CAAZUS
MR5F>M3FIQNCD-=REU8RJ/F$F,^@I&AZ-\*^?&=A]3_*KAN<^)_AL^BZW/*"@
M`H`"`1@]*`,#6O"&BZP,WEE&7[.ORD?B*32+C.2V.5M].3P9XQT:SL;BYEM=
M2WQM%+(6";1D$4MF6WSQ;?0])JC$1_N-]*`.%^%'_'MKG_80D_G4Q-:O3T.[
MJC(*`"@`-`!0`4`%`'(_$3PU#KFD22;/]*A4F-OZ5,HW1O0JN$O(^9/$EI/)
M"L4:DR)*,CTP>:YSU3T?X-VPG\70%B08HRP^H%73W.?%.U,^@JW/+"@`H`*`
M"@#@_B5_H^L>%+Z/_7)J`B&>FU@0:EFM/9KR.\'2J,A'^XWTH`XKX7VTUO;:
MQYT;)OOY&7(ZC/6IB:U7MZ';51D%`!0`4`%`!0`4`)(H="K#((P:`/!/B?X7
MDTK5'N[:(_9)3DD#H:PG&S/3P]7FC9[DGP5!_P"$N)QQY+4Z>X8OX#WBMCS`
MH`*`"@`H`YGQS:17%OIDDJY:&^B=#Z'./ZTF7![^ATPZ4R`H`1551\H`^E`"
MT`%`!0`4`%`!0`4`%`%>^LK>^MVANHEDC;J&%%AIM.Z,_1/#FF:+([V%LL;M
MU;O244BYU)3W9L4S,*`"@`H`*`,'QC_QY6?_`%]Q?^A"DRX;F\.@ID!0!#<7
M4%NI:>9(P.[-B@+&5J'BG2+!`UQ>Q#(R`#DFE=%*#9F?\+"T#_GZ;_O@T<R*
M]E(TT\4Z.?*W7L2&094,<9HNB>21KPSQ3J&BD5P>ZG-,DDH`*`"@`H`*`"@`
MH`*`"@`H`*`,OQ)I"ZWIIM&FDA^=75XS@J0<BDU<J,N5W,`VOBW39`MI<VE]
M;C`"S`JV/K2U*O!E74[?QOJ=[Y<$]EIME@99<N^>^*-1KD2[A'\.X;F3S=9U
M*\O7.,AGPOY4<H>UMLCHX/"^CPK$%L8B8QA2PSBG9$<[+G]D:=_SY0?]\"BP
MN9E/5/"^D:G&$NK*)@O0@8(HLAJ<EL+X?\/6FA>:+-I=LAR5=R0/I0E8)2<M
MS9IDA0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`
M!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4
M`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!
M0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`
M?__9````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V%V871A<G,O;6%L93(N:G!G````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P-S0W-@`Q,#4Q-30S,S<V-P`P,C0Q,S$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````_]C_X``02D9)1@`!`@(`
M3@!.``#_P``1"`"^`)8#`1$``A$!`Q$!_]L`A``&!`4&!00&!@4&!P<&"`H1
M"PH)"0H5#Q`,$1D6&AH8%A@7&Q\H(1L=)1X7&"(O(R4I*BPM+!LA,30P*S0H
M*RPK`0<'!PH)"A0+"Q0K'!@<'"LK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RO_Q`&B```!!0$!`0$!`0``````````
M`0(#!`4&!P@)"@L0``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B
M<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'
M2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JB
MHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ
M\?+S]/7V]_CY^@$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+$0`"`0($
M!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B
M<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G
M:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>X
MN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$`
M`A$#$0`_`/JF@`H`*`"@`H`*`(KNY@L[6:ZNYHX+:%#)++*X5(U`R68G@``9
M)-`'`:U\:OAUHUTEO=^*K*21D#@V:O=)C)'+1*R@\="<]..10`:+\:OAUK-T
M]O:>*K*.14+DWBO:IC('#2JJD\]`<]>.#0!W6EZC8ZM817NE7EM>V4N?+N+:
M59(WP2#AE)!P01]10!:H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`BN[F"SM9KJ[
MFC@MH4,DLLKA4C4#)9B>``!DDT`?-'Q&_:BL5L+JR\!V-S)>MOC34KQ%2./!
M`62./DOD;B-^W!VY4\K0!\Q>)?$.K^)]5DU+Q!J-SJ%Z^1YD[YV@L6VJ.BJ"
MQPJ@`9X`H`RJ`"@`H`].\(_'3Q_X:D4)KDFJ6P=G:WU7-P')7;RY/F`#`("L
M!D=.3D`^B/A7^T=H/B>2'3O%,<>@:F4)-Q)*!:2E5!/SL08R3N(5LC``WDD"
M@#WB@`H`*`"@`H`*`"@`H`*`"@`H`^'OVA/C5/X[NI-#\/220>%87Y."KW[`
M\.PZA`1E4/LS<X"`'B5`!0`4`,9L'`H`56S@=Z`'4`%`'K'P>^->O>!M9MTU
M2[O=6\.E$@ELIIBY@C7A3!N.$*C^'A6'!Q\K*`?<^@:SIWB'1K35=%NX[S3[
MI-\,T9X8=/J""""#@@@@@$4`7Z`"@`H`*`"@`H`*`"@#PS]L+7O[,^%::9')
M;>;JU['"\<A_>&),R,R#/9TC!."`'QU(-`'Q)0`4`%`"4`1L<F@!*`'!B*`'
M*P/UH`=0!ZQ^SW\4Y_A[XGCM=2NY!X5OGQ>Q;#)Y38PLR@'(((4-C.5!X8A<
M`'WC:7,%Y:PW5I-'/;3()(I8G#)(I&0RD<$$'((H`EH`*`"@`H`*`"@`H`^/
MOVV=5GF\9^'M(9(Q;6NGM=(P!WEI9"K`G.,8A7''<]>,`'SE0`4`(QP*`(\Y
M^M`"4`%`!0`\+QZ&@!5/8]:`'4`?5G['?Q#>:.?P-JDT86%&N-+)55)&XM+'
MG.6.6W@8)QYF3@```^HJ`"@`H`*`"@`H`*`/BG]LRY@G^*UE'#-'));Z3%',
MJ."8V\R5MK#L=K*<'LP/>@#P>@!#P,T`1DDF@!Z#C.*`&,,&@`'7B@!ZJ!]:
M``MDX'6@!-IQ[T`+NX/K0!T7PU\3R>#O'FAZ\KRB.RNE:<1(KNT)^655#<9*
M%@.G7J.M`'Z74`%`!0`4`%`!0`4`?`G[4/\`R73Q-_V[?^DT5`'EE`!0`PIS
MQ0`T$CO0``\\\T`29`&:`&\L?04`+PHH`!D^PH`4J"*`&[.>O%`'Z4?"C_DE
MO@[_`+`UG_Z)2@#J:`"@`H`*`"@#+\5:]8^&/#FHZWJLFRRL86FDP5#-CHJ[
MB`68X4#(R2!WH`_-KQ5KU]XG\1ZCK>JR;[V^F::3!8JN>BKN)(51A0,G``':
M@#*H`*`"@!"`>M`#&&#0`+C//6@!Q.!F@`5><GK0`Z@`H`*`/TE^%'_)+?!W
M_8&L_P#T2E`'4T`%`!0`4`%`'RQ^V=XTOH9M.\%VR>593PIJ%S,LC!IOG=5C
M*CC:"FXYSD[>FWD`^6*`"@`H`*`"@!#0`A4]C0`PY_&@`R?6@"13D9H`6@"6
MTMI[RZAM;2&2>YF<1Q11(6>1B<!5`Y)).`!0!^G^DZ?:Z3I5GINGQ>396<*0
M01[BVQ$4*HR22<`#DG-`%J@`H`*`"@"KJFHV.DV$M[JMY;65E%CS+BYE6.-,
MD`99B`,D@?4T`?FKXS\2ZCXP\3ZAKVLM&U]>N&<1)M10`%55'H%``SD\<DG)
MH`Q:`"@`H`*`"@`H`*`$H`-H]*`"@!:`/6/V9?!D_BSXH:?=$2)I^BNM_<2K
MD?,C`Q)G:1EG`.#C*J^#D4`?>U`!0`4`%`!0!E^*M!L?$_AS4=$U6/?97T+0
MR8"EEST9=P(#*<,#@X(![4`?''B7]F3QQIGF2:0^FZU%YQ2-()_*E*<X=EDV
MJ.@R`[$$\9&30!XWK^C:CX>UF[TK6K22SU"U?9-#(.5/7Z$$$$$9!!!!(-`%
M"@`H`*`"@`H`*`"@`H`*`+6DZ?=:MJMGINGQ>=>WDR001[@N]W8*HR2`,DCD
MG%`'Z(?"'P+:_#WP19Z-!\UVV)[Z42%UDN&50Y7(&%^4`#`X49YR2`=I0`4`
M%`!0`4`%`!0!\Y?MF>#WU#PQIOBFTCC\S2G,%V0BAVAD("$L2"0K\!0#_K2>
M,'(!\?4`%`!0`4`%`!0`4`%`!0!]>?LD_#2QL](L_'US=?:KV]AEAMK=H%"V
MF)61F#$DEB$P"-N`S#G/`!])4`%`!0`4`%`!0`4`%`'-_$O1G\0_#WQ'I4-I
M'>7-UI\R6\,@7#3;"8_O<`API!.,$`Y&*`/S5H`*`"@`H`*`"@`H`*`"@#]&
MO@KI]KIGPE\(P6,7E1/ID,[+N)R\BB1SR>[NQQT&<#`H`[2@`H`*`"@`H`*`
M"@`H`Y;XJ>(/^$6^'/B+65N?LL]M92?9YO+W[9V&V+Y<$']XR#D8YYXS0!^;
M5`!0`4`%`!0`4`%`!0`4`?HK\#-5@UGX0>$KJU21(X]/CM2)``=T(\ICP3P6
MC)'MCITH`[F@`H`*`"@`H`*`"@`H`^=_VTH]7E\$:,MG9>=HT5Z9KVY5<M`X
M79%GGA6\R0$XQD*,@D`@'QS0`4`%`!0`4`%`!0`4`%`'UY^Q3KUB_A;7?#_F
M;=2AO?MVQBHWQ.B)E1G)VF/YN,#>G/-`'TE0`4`%`!0`4`%`!0`4`9?BCP_I
MGBG0KG1M>MOM6FW.WS8?,9-VU@P^92".5!X/:@#Y'^('[,7B32[HR^#9X]<L
M7?"PRND%Q$"6(W;B$8`!06!!)/W`!0!R'_#/WQ-_Z%G_`,G[;_XY0`?\,_?$
MW_H6?_)^V_\`CE`'(>+O`OBCP?(R^)-#O;&-76,3O'NA9BNX*LJY1CC/`)Z'
MT-`'-T`%`!0`4`%`&_X&\7:OX(\1V^M:!<>3=Q?*Z-S',AQNC=?XE.![@@$$
M$`@`_1#P-XNTCQOX<M]:T"X\ZTE^5T;B2%QC=&Z_PL,CV((()!!(!OT`%`!0
M`4`%`!0`4`%`!0`4`%`!0!X/\??@WX7O/`>KZUH&D66DZQIEL;A'M5\B*2./
M+.K1J-I)4M@X!R%!;:"*`/BF@`H`*`"@`H`U?#7B'5_#&JQZEX?U&YT^]3`\
MR!\;@&#;6'1E)495@0<<@T`?8WP:_:`TCQ983VWC&YTW0M9M\OODE\FVN$SP
M49V^5AD`J22>HR,A0#VZTN8+RUANK2:.>VF0212Q.&212,AE(X((.010!+0`
M4`%`!0`4`%`!0`4`%`!0!RWQ7_Y);XQ_[`UY_P"B7H`_-J@`H`*`"@`H`*`)
M;2VGO+J&UM(9)[F9Q'%%$A9Y&)P%4#DDDX`%`'O'P>^#/Q*NO,N8M5U+P3IM
MQCS7\V2*>;;O`_<JRDX/]\KP^5W4`?8^EVLUE816]S?W.H2IG=<W*QB1\DGD
M1JJ\9QPHX'<\T`6J`"@`H`*`"@`H`*`"@`H`Y;XK_P#)+?&/_8&O/_1+T`?F
MU0`4`%`!0`4`7]`T;4?$.LVFE:+:27FH73[(88QRQZ_0``$DG``!)(`H`^X?
M@K\$-(^'GDZK>2?VCXF:'9)<-S%;DYW"$8!&00I8\D`XVABM`'KU`!0`4`%`
M!0`4`%`!0`4`%`!0!RWQ7_Y);XQ_[`UY_P"B7H`_-J@`H`*`"@#:\&>&M1\8
M>)]/T'1EC:^O7*H97VHH`+,S'T"@DXR>.`3@4`?H!\*?AUI'PX\.+INE+YUW
M+A[R^=<27+CN?[JC)VKG`!/4EB0#M*`"@`H`*`"@`H`*`"@`H`*`"@`H`Y;X
MK_\`)+?&/_8&O/\`T2]`'YM4`%`!0!+:6T]Y=0VMI#)/<S.(XHHD+/(Q.`J@
M<DDG``H`^W/V7OAD_@OPP^M:S;R1>(-60;X9XE5[2$$E4'5@6X9@2/X05!0Y
M`/;:`"@`H`*`"@`H`*`"@`H`*`"@`H`*`.;^)EM/>?#?Q7:VD,D]S-I-U'%%
M$A9Y&,3`*H')))P`*`/S5H`*`-KPCX6UKQAK*Z5X;T^2^OF1I#&A"A5'5F9B
M%4=!DD<D#J0*`/M;X*_!#2/AYY.JWDG]H^)FAV27#<Q6Y.=PA&`1D$*6/)`.
M-H8K0!Z]0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`'YZ^./AQJMO\7]=\)^
M&-,DO9(KG?;P6FZ0102%6CWLWW0JR(&9C@'J>]`'IWPZ_9=U.^V77CN^_LN#
MG_0;)UDG/WA\TG*)R%88WY!(.TT`?5'AKP]I'AC2H]-\/Z=;:?9)@^7`F-Q"
MA=S'JS$*,LQ)..2:`-2@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`
M"@`H`*`"@`H`*`"@`H`__]D`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O;6%N+FIP9P``
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S$U-``Q,#4Q-30S,S<V-P`P
M,C,V-S4`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!
M_\0`'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`M1```@$#`P($
M`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R
M@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ
M<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#
MQ,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!
M`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W
M``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8
M&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ
M@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*
MTM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#^-6[^
MVVUP9CY=O&CNCNKQJXBF@EB+N9"$:`L8PS](1O<D9!'Z^?LI_P#!,3X\_&OQ
MK\$/AMX-^"VD_$?X@?'3P=8^/[:^^(NK^*?!'@'X>>$XWTKQ%)I]U-IUI')?
M>(X_`VH>']8UR_U![VS@'B'1+*VL?MFHK]K_`",O3#++);&1P+RS:%O,Q(&E
M_?>0D,`S(99IVCMI7`*QVEQ/<'"6LC+_`*CW_!%O]H3PM^U+\"_#'[5=_8Z'
MX&_LSX-_"C]F?PQ:ZF^D:):ZIXZ^$F@6.C?&KQ!X;AE2W2YT_7_&]QX;T2.]
MM7D)@TJVT^63?!&E`'Y"_#?X0_LK?\$POBAHOP!_:R_8R^$;ZS:RZA:^$_CG
MXU\"Z-\1?`GC#X<,+35M1UKP#JWBC1KF[7QEJ.LS7VC^-KWQ+;Z3J=MH5G;V
M-G86RZ9)<S_77PN_9J_X-U/VC;P3^&_V5_@I_P`)CX@U/5KB^T+3=7\4:7''
M>37LUW9O,-*\1F.RT[4UFN/[,O-&LX;.%Y/LBP(T>Y?T=_;W\+_LC?'CX8ZQ
M\%_VG_$7PL\/ZE<,OB7PCIWB[Q58>$_%VFLL[Q1/X;N!>1:K93ZY`+>SFU%-
MT5S)"+8QL\.3_-3XD_80^`?P+^'FK_&OX$?$O5;;5O"OB>T?PQXN\-^+]-UG
M0](T*#6(K/7].\5ZG9?VG_;CVMU/<:;>:I<20WND0LMS);PW6BV0G`/SJ_X+
ML?\`!&^W_P""?WB'1?V@?V=K75=<_8P^+VNQ:+IJW<MWJUU\$_'UQ#/>1?#W
MQ#J<DU[=ZMX)\5V]G>ZMX8\0ZA-!<-JUC_8JM(TT(G_G&CN)(B?/;Y^$+LWF
MN75`LA1XR0T!E5S"03F,@EB237^EC\7;GQ=\??\`@D)^W1\*OCSH^CSZMX3_
M`&=/B7XG>6S%M*=!O_AUIA\5>$->MXI((3'";^QTS5;>2R3S;"[BUS21<-;S
M(@_S:9[)+F)I_*=)62&21""QCWVL,L1\Q<HYDMWAGD*<122O;MB2!P`#)V2M
MR'@(/(R#G!YYSS150F0$@$8!(')[?3BB@#L+ZSMA#*4G,";&28L"TAC9'$Q>
M*/,MQ&C&V"Q,%CC:1W#[I"*_MP_8*_99^+7Q*_X)]_LW?M4_LT^`_`'PC\.>
M&/A+I5U\2/%/B3Q"OC7QBOB;X+^-?&S?$[QG\.T\;:?=Z=\*;%;71H?'GAAO
M!NE:K<:YXXEGCUN4::]OC^)2_F50[00Q9(_>3F&+"/&))H(P[L)P"4D:X5%*
M(BQ,3R<?Z*'_``;!^-/$7[0G_!)#XB?L^^*-032M(\`>/_BE\)/"_BC3K][W
M7-.T+QEI3^+I9[S1+I;?[%>Z)JWBF]U+2I))PVM6\X1(_LVDRNP!Z9^UW\(?
MC;^T!XE_8,T/Q]XZTBXN?B7^SP^NZSJI\->&M&F\;?$N>:T\9:]X5%];Z*]E
M\/==U/P5?VNG>$_%-UH^MZ9=:QI<L$VC:9<O/<7/%>$?V!/#OP`^$?QSU_\`
M:F^*'P[USX>_$[X6>)?!OQ1B?PEIWAR^F\0:V-1T#P'=66I^"D7PSJ_BRPN]
M2\-:&FK6?AJ35/$^L&34&O9X?L=C9>H?%[Q#\6_A9^TO8>&=0\0>)?'WP,^#
M&B>"?AGH_@KQ!H,?@6\B?0_!MC'+XX\-:^=1U75]5@T^UAMIY->\V"V\7>);
M_6TT^)[1+9YOL3Q_\,/`?[2WQ,\!OXC276O`,'@30_%MEH>N,1I6D7)^U6&L
M'2K>)XX8?%MQ$5T_7M>NUEU/2H+;[!#:0RQW<L0!_+9_P3^_:-^+'C#]G[]M
MG]DWXL2^)O#'QJ\(_L4?M36NE?\`"9Z?<6'_``MWX7^&/A[XGT_0O$MB-0M=
M/?Q#8)9:-):Q^([.UDMKIK$R&4NK-7\@NF+));Z<BJQ62PM[E/,8_.GV.W\X
M`G_6+',SC<"P"M&#@8%?UD?M1_MSZ7IO[0O[8_[>OBCX+KX?\+:7^S-K/_!/
M/]A[0-0UV[D/Q`UCQ!XC\5_#;7/B)8/;:,=-&B>#_A_#XBUK6/#]Q+/<1K'X
M=TC!>2&6Y^:_^#=K_@FY\!/^"C>K?MP>$/V@?#]QJ?A7P%\`?`GA/P;XRT1H
MHM9^&7Q"\4Z]JMS9^.?#5S!%!!+XCTO1O"$,:6%[&ZW6CWM_92`3N#$`?S;R
MM&LDBEK)"KNI1KN%64AB"K*7!5E/!!`((P>:*B^)NJS>!/B3\0?!%E>7&O6?
M@WQQXL\*VFN0-HMK!K5MX>UZ_P!(@U:&UDE\RVBU&*S2\C@D^>%)A&WS*:*`
M-HSQ769PQ25[>2#>?NDEDE7$>/[B7$0DP<M.J9R<5_77_P`&I7QP^%]QXH_;
M'_8T^+OQ/N_`6E_%K1OAM\5/`VB+XMNO`MUXEN?`]U=Z7\08-%\4V4^FWMM/
M>V,.@?VIIEMJ<4VI:`+[[-&JK=35_(1*ZFY6-2"C%E&P#C:K2,N!G!5%>0^B
M!G/RJ:_<G_@A?_P3L^%/[??Q3_:,U7XQ?$CQU\*=#_9N\!>$?$WA?Q5X6U+P
MOI%BOBOQMK>K^'[K3?$UQXN66TGTNX\/VEV?[.LAIQN9'2XU74XK6TL]@!_6
MGXOT;]AZ]T3XT?$'QS\9/V2/B=XY\.:_INC^%-0_9QO/&_PV\>_#](/$^H2:
M5+X[\;:I\6_%UUXSCTG3K*ULKW2KK3+6SEU"35[IK>-)W9O+O&7_``4=_9P^
M!G[,FA?!'X*_%70/B#\<-2\%:M8^8WC2R\3:?\,[3Q!<ZE%<_$#QSXQ6?^QK
MFZT>"?5=5T?0%O1>S:K>0VKH\BQQC^1#]K*-?@)\9OB1\+/B%\>-.\5KX`\5
MW.A:%K?@C5HM8U3XDZ$\4$?@WQ;+-H<\NFQ:+>^#K?2[N<Q27FFI?WEY'87T
MJ,A'K7['WB/]G*;7-#EM8O#FIW.HB9XKG5]!;S+EK6YCU2ZM9-2U2"62S:TM
MX96$%P1;M-+*T:$R/0!?_:E^.OPA^(GB#X2?#JV\/:%\2M!_9RL/VG/VAOB?
MX5U.^UR?P!KNHQ>%4U3P1X&N[W0-4TR[FTVX6#0%URUT[4+2+6$OWM8-2CN'
MO8Y/ZF?^#<*W\8>&?V%_%7[37Q'\/^"]!\>_MH^+/$EM\*O"GPV\$^'/AYX2
MT'X4?`?P5K7AWP]:>%?"GA^QT\3:-9:GIWB2Z-Y=6UWJM[<7-Q>ZEJ5_+*U[
M=?RI?M%_LB_&GQE^U'\:X?A;X&\0>)/#_P"VO\0_A!^S?\#/'V@^'9IO`$]Y
M\4=7\.WOQ`T:?QC9:;#X9T34O"VA>%#IFJ0-=^9%9:AJ0F"'3[M8/Z\/V*OB
M'\+OAY^UU:>&/#NM1CX!?LN_!C3/V+OV:-`TXV=K;^*9?"]EH>C^,?&]G;13
M#3[)O'GBZ.?4-:\8W6Z'[1=V-BUR\NOVL=R`?YF7C*33-4\7^*]3U;5#;:KJ
M/B37;_4[>\N(+6[@U"\U2ZN+V&ZMIF2:WN8KF21)X)422&56C=592`5Z3^T9
MX$T;2?VA/CMI6CZWX6N-(TSXR_$_3]*G@O+6_@GTVR\;ZY;6,T-_;326U[%)
M:QQ/'=V\DD%RC":)VC=6)0!S6KDIX7UZ[0E+J*STEH[E25N(V?5&C=DF&)$+
M1JJ,58%D55.5`%?>_@F\N]"_X)J?M-#1+JXT<:Q\0_A!-JPTJ>73_P"U)K+P
M#JTME+J/V1H?MLEI+<3R6KW/FM;R33/$4:1RQ10!^<-NS-=^(4))2VAT]+92
M25MT9FD98%/$2L\DCLL84%W=B"68G[K_`&2;6VA\,>(+R&W@BNTU",I=10QQ
MW"%Y](#E9T42J6'#$,"PX.:**`/[9_V9[BXT_P"$/[$T%A/-90)IW[:OC)8;
M25[:)?%_AW]CKQO)X?\`%:QPLB+XDT*2[NY-&UP`:IICW5PUE=0--(6_*;X-
M3SMX(^&<!FE,.M_M/?"/P_K,)D<Q:OH-WX.\2:S=:)J<9.R_TBYU>XGU6XTV
MZ$ME-J4\U])"UU(\K%%`'\L'[4.C:1X?_:8_:)T'0=*TW1-"T3XZ?%O2-%T7
M2+&UTW2=(TG3?'_B"RT[2]+TZRBAL]/T[3[.&&TLK*TAAMK6VAB@@BCBC1`4
M44`?_]D`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V%V871A<G,O;6%R9V4N9VEF````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,C$U-P`Q,#4Q-30S,S<V-P`P,C0R,#``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````1TE&.#EA(``@`/<`````````,P``9@``
MF0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9
M``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_
MF0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F
M`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,
MF3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S
M`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9
MF6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD`
M`)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEF
MF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_
M`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPS
MF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,
M`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`
MF?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9
M`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__
MF?__S/____B_)```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"'Y!`$``-@`
M+``````@`"````C^`+$)'`B@H,&#"!,"&,A0((D!$"-*G#A1P,*&`Q]2W$@Q
M`,:&`3B*A"B`Q$>'(T=:/(E-8\J-'EEB"[E10``!$&_:)&GR)`F<%`6L&*4"
M@(I11D?=!-#SY,V)29L1'345Z4J9,R4&H.IDU`JC0[T:Q`J`H@JI3UA=N\9J
MA0I6;?\T_>B2Y-$5:M>R7;&6E0JL,X$."/"GJ%Z]>*VP8@J8)L2C;ZWH;0N7
MU5R?$@7<S;L7[&6G0*..2LOVR:AF4C\['0#@-&JI;H>^)DKBKTR-1E^C=OU:
MQ='4MR&V'N5D]^_9IVEC?1K@>%'?T)F24/U1)XG>O*E2OUU0]VP5VP%-7_?>
MS#9@EN.]AQ=/@O?KZ>?I0JKMOAD)-NM]DH`T'_)1QO%A--U^D*C`7U'X!<B0
M;$3YIYR"`YU%WF[Y?714?;-5"%)!)#"ET$4G!00`.P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]M875L+F=I9@``````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#(W`#$P-3$U-#,S-S8W`#`R-#`S
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!'
M248X.6$@`"``]P`````````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,
M`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS
M`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,
M,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS
M,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,
M,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S
M9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,
M9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,S
MF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,
MF9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``S
MS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,
MS&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\S
MS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,
M_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS
M_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````(?D$`0``V``L`````"``(```"/0`L0D<2+"@P8,(
M$V);`:#A"H40"3)L2!'`PX@))U:D>!%C08T;.7J46'&%29,E1PHL"8E$2T@@
M54XT">DE"5HP9XZD6!,))%I`(?F$1-'CS)M"@=+R28N$SH@.`?QDADHI*F8X
M+3:,.!.`2V9.E#IAUE*K18@<&[K\&;2L60!H'98E<1,H7:\PBV;D6),MSK8U
M-78T6%+M3[I(2435>["P6IPUFZ9E3'AR9)=(B;Z%BW#C1,PV%U,FZ?FDZ9,A
M!P\,R;IUQ<:N8V\T"%*V:Y,J<RN<712N[]R_@V,3KE)X[^'(BZ]&;ASX\N!;
M1^N>3KWZ](```#L`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]A=F%T87)S+VUE;&]N+FIP9P``````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,3$R,3,`,3`U,34T,S,W-S``,#(T,C$U`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````/_8_^``$$I&248``0$```$``0``_]L`
M0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M_\``$0@`,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$
M!08'"`D*"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B
M<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'
M2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JB
MHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ
M\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$
M`+41``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&Q
MP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-45597
M6%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBI
MJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY
M^O_:``P#`0`"$0,1`#\`^!OVM/VU/'W[3W[/_P"SKX]^-.NVESK^C?$_PA-\
M4/$.@KX57Q5J%@-:UC3/$>G^'_&FEV<.K2Z=!9+8Z?HMC#<I%<2BZDN81>7-
MWNH^*OA!^U'^WG\+_B#^S@VSQ)XL\(?%CX7^,/V=?%_QYUKP?\(K?PMX$N+6
MV\/Z@MIJOB76+$:K;W?A:[A\%:K8^%--O+O4]/\`AUH7]H6US-I=K%#]1_L7
M_LU?"/P[\*_!^H7?P(^*/[2-O-K>JW\7C#QEH?P<\#?LYP6&M:K#XRT73?@G
M\./V@?$*>/?%NC:3J.LW>F>&?BQJ&BW&M:REG)K_`(.?2M,NDMS^BWCR6UT+
MP;9V?QG\`VOAOPOXGU6+PMX6\">(_B?XQ_:`O_&'B">>Z@MK"Q\.:3=>#=&L
MS9W%W?%M5^&%_J=Q87%Q=M*-&1[K4)/\V\3Q-DG"^;8?+\DH8/$9CDN=9AC\
M'C)T5.I@(/$1Q-HV;QE"#C0KX6OAJLHWP];EJ4W92C^9TLPP\ZE*E.HU452,
MI+FE9V5K]$][J7<_!_\`9)_X('_M#>,?$OQ"^'_CC]I_X=?`[Q7X/M]1U_7-
M,TKX6_&;QAXAO_#,'B6?1+GQ+X,OM8L?AE'JFG67BC[1IJ()D@U&XM'UF":_
M\/W=AJMU]E:+_P`$F?BOI/C_`,._LUW7QQ\,?M`^&_V?=5U8>-;FRTC5OA3X
M%\*6'B26>_\`#OAGXI_$.?Q#XBTS3O$7C35-2CO-5\`_"A?B[\48_#=_:WL6
MA>']#N+:.S_<3XE?$.7X8?L]>*Y#\4M=^'GBGX0>`AXZ\+R_$"*_^+GC'P7H
MAM+#POJ"1:.=+UW4;#X4^,[ZXO\`X:W4'C[6O$5IICV]IJ&FGQOKGA4RZ3P/
MP%\5>$_@+\*-6\*6VWXE>$=1^('C;QM>:[X8U;QWH_A_Q/K6J0Z3I=SJWB71
M-+MK#6=5AM=!GTK3OLWB-]0TI?"EMHNG>'?*O+S4)V\[.?&CB'.GB'B:^4X:
M&.Q<</0P4<%2A2K8S#QYOK$<1*FJV-@J59N5&5>\*CHS33A&_O3HY3C:U.C7
MJJG&K9KE=G*HGI=1TU?-S-ZM?(_E7_;1^$?[??@SXI_LY?#?]M;X#^"_AK\&
MO!OQY\,:?\/_`!K\(O@+\#=.^%=IX$TOQA+)JGAKPW^T%\(/!UOJ?BW1+33'
MMM0GT3XLI<ZK<Z_IU]?^,+6/Q3::LZ7/A?\`&WQ*_P"S=\;=3L/BYK?@#QI\
M9+WX[>._'GQ#M[2,*PN]<O=`_M&+^S18V^@ZIXH\*^$M+T:+4=.A%S-!<Z[X
MBB9KTV#-_7+\)OBKX(\0ZIK'@73/A/\`#_Q]!X5)T[XH>'?A4OP_CU/P_::C
M923:?:^+_@%\4)+/6/">EW>@:E`UQ:VC:MHK17DT]K%Y%ZBU^3'[<_\`P3S_
M`&7_`(EZ;;Q?LO6_@[]E+XKV_B;2[[1?@;\7O#OQ#^$WP`^*<-K?3ZW=^$/!
M6H^)]&UKX7>"?%'B6'3;2X\.W/AW5++P?XG\7R2Z8(M,OUE^S?5Y1XQ8+/*N
M5\,\0Y*\DK8?,\#4CF&$BY9?B<)&K'$5XU*6(YJU"A6J1PU22E]9HU)4X2G4
MLJ=O.SO*<%6A3IT)^YAYQ2::NY)/JDE*[6J>KM%>\XH[3PO_`,%?_AY8>&?#
MMC#^T[H/@^&RT+2+2+PE<_$C1["Y\+1VVGV\*>'+BQM_#P@LI]$5!IDMI`!#
M;26K0Q@(BT5_*3XN_:L^(WA'Q7XG\*>)/%]YHOB'PQXAUKP]KVC>(/A*-2U[
M2=:T74KG3=4TS6]176YEO]7L+ZVGM=2O5EE%U>133B1Q)N)7[W'PUP$E&2IU
M&I)234(6::BTU:@U9KLWOOKI\]_J_5Z>T:TZRV]S_@_CYG]%_A3]MKX6_%#X
M9>*?VFM7D_X9]^/'Q#U"_P#A3\+?BWJVF:M\:OV?_A@^BZOJ&@^%?"=QX(GT
M'66\'P^,M/TN\\5>)O&>G:!XE;5M?N(-,N[NW338=/LO6]+U^V_X)_\`P;\(
M_M(^-M$UKQA\2_COK^N:;!\9_B/\1-5^*.ER^"/`W@[4?%OAWQ5JOC70!;:U
M?^#_`(FOHVKZM%\#=$N/!GB&?5_$^A>"/'/BK3M'T.<^!/Q3^&.I3Z)\`_V3
M;'7%TBW@/QSO[W6;/4+>W72%L=%\5_'#Q3HEH(I4^S64.G>)[N/[#:!%CM]0
MLX+NW6.>-)!ZYXR_;-^-WPW\4?#^V\#V=K\2/#?B;Q1XDTOXH_!OXB1_\)+\
M$_B=>^+#X*D2W\9^%=;:[TZ?Q?8:KIE]J?A_Q'9V,EW:3V]K?B=;Y'EK\[_U
M*X8SG%PRNIA:.`P]?-,UQ..Q]"I)U*N6Y3#$83"X/$-6K_5Z<\-*M4C&5W.-
M/G4E*<7Y5+#^\J7Q5%5=7G;?-9)K23?,TG+O;35=_P![H?AUK&H_L9_%K0-,
M\5_&/X__`!!_:7^%/_"SO$EC%IFA^'O%&J^(/B?H-EIEEX-T'P;S<^%+#P/X
M(=M,MO"OB62^?2+<W]OIXCL;KRV]U_8%^"WQ/\??LO:'H_B-/C7XOU#0KOQ9
MX%76/&UQX!M4T?2-)*V>C>'K/4+RPM]8\265CH\UGHFHR^,-;U2\MK^UO?#6
MDFR\%Z?HNG6OP/HW[6WA70M5'Q'T7Q'>?"K0=/UNR\523)>W8MO"=MI6IQ6^
MM:=8^(4G0V]M=P1/H5A(@B=K&X-C,9%:4-YA_P`$^_VLO&/PP\4?&GP#^T/\
M<-<EM_'#V/QA^"OA75-;U:Z2ZN]2U&\_X2K3O!NJ6\XBN[K5/">L^%K/5DOG
MCD;6=*O=/821Z?$J_P`ZXGA/,\=PIQ\JV%JXNEEV>X3/<'C/80HTHT(RG0E0
MRMJDE1H1H+#RKI*G[3E3>RB>WE%2E.E6IUY-NG63C-/WHM1=DF[M*\MEV2ZW
M/U#\3?LS_##4=.U&W^)NDW,_AKX-_$:7X;_8?A!>36?Q_P#V1]=UJ32-=TG6
M_"?CS3M=\,ZUI_PMN]$\8>"O$_B#PK>^+/&7AKP''XLO;KPCIFD_#OPM<>&-
M.--_:.^$7PW\)_&S]F/]I#QS\/O&WB+X/^(M,\$^(-0\6M9^.?&'QW^#'B_1
M+3Q!\+_%WQ"$.AV6BZ?>:[IMWJ?@_P`8-I]@)].\2:5=7)EO7#:C=?FA^U3^
MVU\2_$'Q7^.G@+PW>ZG\-?`OB']C?3M;@NM.C%O)\2?$OA'6_B+HMWXFN(;6
M6,6NO:=HNJ:;X(_MJ8-?RZ#X<TRQ6Y_LVWL[>/\`+'Q1\0M9N?VD/B[XZBU2
M:]M?%7[/GP1\0W^C2+I3W.IZYJVF:_/H[Q:G<12RK<F)99I)3*T[37=UESOP
M,H\#YSQ1E5?!XZM/!X.CEE#.<LQ&'E-X^GC)X_):=*E];@N:-&='%XA5:'-R
MQJTVJMY4[GIR]ARR=*I*4KN_,VVUM?6ZTM=2]W1NS=['[>0:G\*M,@ATWP?^
MU[\1_"_A+3XH[+PMX9_X5UI?B#_A'?#EH@@T30O[>OEDO=;_`+(TR.UT_P#M
M>\=[K4OL_P!LN':69R2OR)TGQW-?Z5IE]/=W]E->Z?97<UD+C1L6DMS;1S26
MHQ!C%N[F(8X^2BOHX<+<;1C"/^L^=/EC%?[SBW>RBMU4UOKKUNC#GG_-+_P)
M_P"9\^>*=-T/7?A%\&/#22:=J6C+XALM,\6Z?+>6=UI\_C**_P#&.F>+=9L-
M9BABU>UE3Q:U_JVEK;RB2T352D3H78M\]?'.77Y#8^(8K[4[6#P-K?A/5;?0
M]!TXW5_<Z_K_`(GN8-*N;4W\TU^-7TR+3;33;6Q:+[+>6=[-=OE]2N/,^S]>
M\.1V/@O2K?5-`TF./X;_`!GU:'4M&>&WO[B65?B8EG:1VNKRZ9I\D_VFQ\0:
M7-<SK;(MY(1,TEV-EU+\X?M*Z8/"]M8^([>\U73/$_G75[86\%G'J!O[?PA%
M-XSN4U%)`8A8:(^FW5\^LR[M3BF,ME:,(844?T=0IQHYKE[5)SE5Q&<.G"/V
MGB)47-/E4M))3<GRRNVY6;M?R:"7-A797<;-VW]Y+7NO+L>W>)]!G\<VWB6P
MTZZO#:VNE7^JV/A>24#PIXGOWFT]-#TSQSH420VNK:5IL]B+N;P]J5K<Z9IN
MK+<Q6$"111$[7AS4?%6F?&G7?#_Q`\9Z5\2M+C^$]CXJL;JRTFTT:T\`^-].
MUSPSKVJ>&_#EJT*:AHFCZ1I>MVMY<W*&.U\0OJ3:8/.M+"&"+;^%DL5WIMWX
MALYM.F7Q#I>E:K]IL(O,L)EOY!>IY,5S'G3;:1YS*L%Y&8H2YV(L>T5X#K_B
MK7YOVG_%\&MWPO+KQ'X1N/#69+IK^/3+'2-#\+:_H6C:9JVE-;:>\]Y)H^H7
M\%I8Q1-:33S0RJ]Y'<R/\+A)X['8?BG(IN/U2&79ABG1=TZ=2A6HM14;I6BN
M;3X;MNVUNC#Q2G6:27[WLND7_7R78[+Q3\0_%;_'IKCQCIFB2^$O&OPGU3X6
M>#1I.NVUQ?\`A_28M5U7Q!KT%VSQFQ\0:@URET)[$Q+;1:1=:?I]YODMVQ\O
MV&K^-;.R\+:?(UA#KFO?!&WNM<G@N+J:TM=(^$=UI5IX/6**[D=[;6;FVO[R
MVUB.+;%'K,^LQVH6VF*MVWB(ZI-\7/A@MT+$:,FC_$2P^U3S7BW;V6H?V-%K
M=Q?12-)(VHFVD@LTGE9II8Y+K+E)W4^57;>(-8TG3M7T&TL]UK\*/'\&K3WT
M]W;7%DT/Q,?3([>SD;;((YS!]ML8D8(D-Q&8PH(S][PU@4\ORVA*E3_?932I
MNT%"SPM;,,+&[BU=N5&-22:]^I%2EJ>]1HQJ**25[KHKM>[=7MMMZ(^E[?Q&
MX@A"WEN`(HP`;%<@!%P#\G845Z[_`&#X2@_<3W6E130_NIHC:3$QRQ_))&3Y
M7)1U*D]\45U?ZN5.\^G?^YY^?]61Z_U*/:/_`(#'R\OZMZ7]`^,LDG_""_&!
M_,??:ZQ\$;JU?<VZVNKKPMX$O+FY@;.89[B[M+2ZGFC*R2W%K;SR,TL,;+XY
M^U_%%%X#DNHHHX[EO$_AR%KB-%2<Q:GH26^I1&90)#'J%O=74%\A;;=PW,\4
MXD2:16**Z</_`+_@?^QGF7_I4C\ZPW^^4?Z^TCVWPBJVNF:VULJV[>7X<AS`
M!"?*4V,:Q9C"GRUC_=JGW0GR`;>*^&OB1&EU^U#XZCN42Y33_B)I\M@DZB9+
M&6#X2NT$MFL@86TD+,QB>$(T99BA!)R45\3D?_(^XP_[$V;_`/I$3U<+_$K?
MXU_Z0=AJ<$"^+_@BZPQ*]W8>.Y+IUC0-<NVB:%=,]PP`,SM<DW!:0L3.3*3Y
MAW54/^D:%H*3_OTN/`7PC:=)OWBSMJ7Q@TVVU$S*^X2'4+8"WO2X8W4`$4_F
M1C;117V7"_Q9+_V#5O\`U98\]G#_`,2'^*/_`*3$_9`>$/"<P$TWA?P[++*!
M)++)HFFO))(XW/)([6Q9W=B6=V)9F)))))HHHK];73Y?^XSZ6.R]%^1__]D`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O879A=&%R<R]M:6(N9VEF````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,#4V`#$P-3$U-#,S-S8W`#`R,S8U,@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!'248X.6$@`"``]P``````
M```S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9
M`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\`
M`/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9
M,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`
M,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"9
M9@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`
M9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^9
M9O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`
MF68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9
MF<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`
MS#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9
MS)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``
M_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9
M_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`
M__\S__]F__^9___,____^+\D````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M(?D$`0``V``L`````"``(```"/X`L0D4"*"@P8,($PY<.#"A0Q(02>29F`<`
M0X8."R*)")&B1XL7"3K<&-&CR8(AL67D*-'DQY0K.;I\&?(ARYD405Y,R+(C
MSHHP$?;T.5,G1IX``A146O#D08P;,R*\EI&J3@`D(4K=^I1@GJ$&I$HDX;#A
MQ((LQ7XEB]!L10`]P_*<R-;@0@!GT<I\VY1HU[LY>[IL27/G6<$_<Z94N90E
M$J=P%2]F'.#FQX(&)"\^*)BM5KQ`)\--&A?`G-.G*X;>7'=HUL=?)Q/\##<M
M7-BK6=>M'1')P;.R]>ZNC5OS9MX\B0(7#8!JU.0^C=9L?HTJ[8<HCQ>L;GWX
M2>8'N0QG++S3H?B$F9=?#`@`.P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VUO;FME
M>2YJ<&<`````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,C`S,3<`,3`U,34T,S,W
M-C<`,#(T-#(P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````/_8_^``$$I&248``0(!`,@`R```_\``$0@`O@"6`P$1``(1`0,1
M`?_;`(0`!@0%!@4$!@8%!@<'!@@*$0L*"0D*%0\0#!$9%AH:&!88%QL?*"$;
M'24>%Q@B+R,E*2HL+2P;(3$T,"LT*"LL*P$'!P<*"0H4"PL4*QP8'!PK*RLK
M*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M_\0!H@```04!`0$!`0$```````````$"`P0%!@<("0H+$``"`0,#`@0#!04$
M!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6
M%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V
M=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'
MR,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?H!``,!`0$!`0$!`0$`
M```````!`@,$!08'"`D*"Q$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!
M40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y
M.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4
ME9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/D
MY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#ZIH`*`"@`H`*`"@`H`*`"
M@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`
M*`"@`H`*`"@`H`*`"@`H`"0!DG`H`H7^KV5C!YLTP*9Q\GS&J46SIHX.K5ER
MQ13'BC3"`?-?_O@T_9R.C^R\1V#_`(2C3/\`GJ__`'P:.1A_9>([!_PE&F?\
M]7_[X-'(P_LO$=@_X2C3/^>K_P#?!HY&']EXCL366OZ?=R^7%*0W^TN*F2<=
MS.KE]>DN:2-**:.4D1R*Y'7!SBE8Y)0E'=#Z"0H`*`"@`H`*`"@`H`*`&NZH
MA9R%4#))[4#2;=D<QJ/C&UB#)8(;F53@@=*U5-]3V*&35):U7RHY^?6M3G:4
MM-MBE_@_NCTJ^6)ZD,%AX)66J*"@J,;B1[FF=+=Q:`"@`H`*`$Y[$@^U`$MK
M<W5DY>RF*NQRV3UH:3W(J4Z=56J+0W[;QDXEB2XMB(QQ(X_G4.D>94R56;A+
M7HCI=*U:TU2)GLY0VTX([BLW%K<\C$82KAW:HB_4G,%`!0`4`%`!0`$@#)Z4
M`<)XLUIK^4V-C(5MU/[V0?Q>PK:$;:L^DRW!*BO;55KT1@QHD0`B4+[]S6AZ
M<I.7Q,=2$)0`4`%`!0`4`%`"T`!.1@\CTH$%J\EE>I=V+>6Z_>0=&H>JLPJ*
M-6FZ=75'=>&_$$>KJZ2)Y-PG_+-CR1ZBL9PY3YS'Y?+#6:=XOJ;M0>:%`!0`
M4`!.`2>@H`X7Q%XB>]DDLM.8K"IQ++W/L*VC"VK/I,#EJI)5:N_1&"H"KM7I
M5GI-W=V%`!0`'CK0VEN`#YCA02?I0G?;4-MR5+>X<92!B*I1D^A#J06['&UN
MA_RP--TYIV%[6G_,1M'*OWHF%1[W\I2E%[,9D=.<TKK8JPM,!*`%H`$:2.9)
MH'*3)R&%`FHRBXR5TSOO#&L'5K1C(H2:,[6'K[UC./*SYK,,']6GIJF;-0>>
M%`!0!C>*]0^P:3*8W"SR#:@]:N$;L[\MP_MJRNM%N>>VZ;(1D8D;E_<UNSZF
M;O+R)44LVT=:(Q<I<JW(;LKBR1LA^89'K53A*#LQ*28L$9D)[#U/2M,/!2YN
M9"G)1.0\:?$;P[X.8P75PMSJ&,^5&<X^M2W"@U?6YQ5\;&#M)GF.J?M$74L+
MQZ;I*(V>'/I1/%1C+]VCS)8YM/E1R]Y\2_B#J[BZLWF@@_A6->#7#7S2%U&4
MDFATXXRM&\8W(1XX^)+,I%S=97G[M8?VG26O.7]7QW\II6GQS\5V#E-0MTD=
M>#O7%>HLQYXWBD92QM6.CB>@>&/COHVK2P6^KVWV.5\*7'W<T_;P:2MJSKH8
M^#:3=CUF-(I8TDMKB.1)!N7#9)%/V#;M3=STU6OHT,((;:5.?2L7=.S1JFFK
MDGEJ"%:9`Y_A+<UJZ,DTGNS/VJOL,=&1L,..Q]:SE%QERLT336@0W,]C>075
MM(5VMB4=BM)I-682I0K4W3FO0]1M9X[FWCFB8,CC((KG:L?&U*<J<G&6Z):1
M`$@`D]!0!YYXLO/[0U-8AM:WB/RLOK6\%9'U.6T?8TN;JS+))/OVJCL1Y7\>
M/B#)X7L8-#T.;;K5Q\T[@9,2]L>YK6HXT8V3][N>1C<8XOECN]CD?!GQ#\7^
M%[BR_P"$QMYI=!N"`\TB\H#WS7)0S2,JO+S79A#ZSA[3JIV_(C^*/Q7OO$6J
M?V%X'>1-/?"^;&,/*?Z"M\7C5"+N[+N*MB9UI*G1U;(?#GPHCD#7'BFYEN+B
M49VQL24^IKY.OF\W)>R6GF>WA>'X<C==WD=KI'@W1M(0+;6$4F/^>@!S7FU,
M35J3YW,]G#X##T:?LXQ-9$BB0(EM'&@Z*%P!6+]YW9W0I1@N6.PX>7U$2?E2
MLNQ?*^Y4O=-TV_@EAN;&W;S1AG"#=6D:DXVY7:QSSP=*3;:O<Y:V^%_A>"5F
M9;AR0<*S<`UVSS3$25KV/)CP_AXN]CDM6\,^,?#%P]_HVIW%Q!`<H$D)(7TQ
M7K83.H1DH_"^_0\G$Y-BJ2YZ4N;RZG;>%/CN+C0;JVUFU"Z_#&1;2`?+*WH1
MV-?0/'Q4;S6APT<9)ODDM>W=GF=Y;_$'6+RXU9Q?+(Y+G:Y4`>PKS)9K23YW
M,?U',*D^91:9ZI\"/B/?Z]?'POXF<--&A,$[##9'\+5Z-+$QG'EGK?9CPV*J
M*HX37O(]C((9E<9[$>M#BXNSW/:O?5&]X!NQ;SS:<S,Q/SKSPH]*SJ*^IYF<
MT>>*KKT.XK$^=(+^6.&SF>9@J!3DFFEJ:T82G-*.]SRX@++)M^Z3Q70?8WNE
M<<C!6!/0&KIS4)78FKH^<?C_`*9/I7Q.AUN[M_/T^_5?(;L&`QC\.M<V98>3
MB^5VN>!;V&)4Y*_^9C>/_$&K6^@PZ'>74-Z;H!EV#E!V'UKYO+\/2G4]K%-*
M)ZV;8RK"'L)).4NQU'PU\.V?A'PW+K.O*D-ZXW@OU1/3ZUS8[%O$U5&GJEMY
MG=EF6K!4_:5+7M=OMY"1>(_$_CJZFM?`UC]DT^,?OKV;@?GVKHIX+#TG_M,_
M>?0X:^;UZT^7#+2^[([?PEXNN8W;1?%EI?W4#?O(4?E36+JX2$^6M2<5W-/K
M./;:C630Z?Q7XR\/.L?B+0&NXU&&FA'#4X87#8F7[FI;R)CF^(P\+5Z?S19B
M^)MB]NTD^EW4,J]8MM34RVK3GR-HZZ6?TIT^9)E$?%.XO8W32?#=T]QV;;D"
MMGE,5O41S+B))WE!M%JV^(TMF%3Q5H=S8L>DNPX-8RR^Z_<S4F=5'.O>O5BX
M1?4[FQNX+VQBO+*59[249&#FO/E%IN,D>["<:BO%^C/+OC!X-#Q-XATB)8_+
MP9XT'_CU>OEF-:E[&IJGL?,Y[ET>7ZQ3^);^?F5=%\8:UKD>FS1W*VMOIH'V
MO)P)5'_UJC$86CAYR4US<VWD983,<1B5!1=N7XGW&^#)7\6?&N*\T&`Q1!]Y
MVC`"CJ3]:^ARB#P\8QFK_H>7B,5&KCG5IJZ_K4^I+E@T[$=N*]*MK49[=--1
MU&P.T5];R(YC`8;F'I63V'.*E3E%J^AZC;RI-"CQN'4C@CO7,SXZ<7&335C*
M\8*&\/W(/3C^=7#XCMRMVQ,3@3UK8^F#N!Z\4`<SXBU[PS/J%]X6\1PI<W%I
M`;B(,N?+..,>E=*CIR2=SR<4Z=62<?BW/FGP/9'7_B$9W!>""4N!UX!XKYW-
M\0J=)J*M<C)\/+%8KGF_A/3_`(J:/?>)3I5C99\@S#S@O9:\+!8BGAN:<NVA
M]'F6#JUX1A%^[?4U?B_?#P3\++/2M#46JSXC)C&">.>:YLJIO$XYU9ZVU/#Q
M[A1IR4=.B/-_V;_._P"$RFD5GV^40YSP?K7K<1:T5?N<F3Q3E+T/HYYF)='"
MNF>C#-?(K1WCHSZ9THM%0:=ID\^^6P@9^YVBK=:JWK+5F;H1BM$>->//B?<Z
M)XP2P\/6EM;V\#@2$(,O[5])@LE;H.5=N[1Y6*S+V$_8PL^[/9[VSL=>TV&+
M6+2.:.[@#,"/NDCM7S=.I/#U+TWJF=\J2K47%[=CQ;X?0S^'OB%K/AG>SV";
MGB#'[H[5]+C%&MAX8EJTGN9916J4:LL*]8K5'H%U;B\LKFT(RLJE2#W%>6I-
M:QW/J*L(3C:>S1\[^'?#IU?QPWAP7PLX)9RC.S84`&OM:#C*$9U%=V/S6=+E
MKSI0=HW/K3PEX,TCP!8'3M(C66[<`RWO4O\`C7IQG&G'W=SU\'AH<JFE9?B:
MXX%9)6/1&S?ZI@>AIH<?B/1/"JA=&A"],5SSW/ELQ=Z[&^+O^0!<_A_.G#XA
MY9_O,3@#UK8^G'P_ZP>QS6V'2=2S)GL>(7,2V\GQ+\43(;B['[B%Y!P@/'%.
MK^ZE*<3PU%?O*W5:(Y'X"6RBZO+W<3*5(QVKY#.*K<E`]'AVDI.4F=]XTU^Y
M\+Z,-4LHEED5\%6Z8KR\-15:HJ3=KGT>95W1P\II7L;5]86/Q*^'ME)>MM:=
M=Z,G_+)ZY\+B9Y5BII1OT=SP94H8VEZH=\-_`T/@C3[I5D$TD_WYVXP/:IS'
M,98R2MLNAKA<%1PZ2AJ^IN1ZOHSPW$L>K6[K;9\W#CC%<3HU4TG'?8Z%BHN]
MNAR>B?%GPMJVJRZ;F2UWY1+B0X5O<5Z%7)\53@JEK_H<5+'TZTW!2V_$\FUG
MP%JD?Q*BBM0VI6<TXE6Z4;DVYR<GVKZ"&9PJX-N3M)*QY4<NE];44M&[GTLT
MD4"(\TBQV\$8WN>B@"OBXPG4?+!7D?2-J$&>*^%9QK?Q6UK7+'+Z4@,2S8X8
M^U?3XA>RPD*,U:78XLM<\3BYU5\*5D>@P`F5L=P<5Y9]34^$^=+:V>X\<ZFB
M*Q<2.<J>5YZU]YETXQC%R?0_.)K_`&J?JSZ7^$&IG5?!<H>5YGM7V%WZUZ$E
M+V3<UZ'J86;NDV=>.@KG/0&S?ZLTT.&YZ+X8_P"0/#]*YY;GRN8?QV,\7?\`
M(`N?P_G3A\166?[S$X`]:V/IP4D,"#CGFFFT[H36AR'B'1[B72_%L)@B71;B
M'?&`.2^.371!>TO<\VK3<.:_5'A_P'NRFJWUBY41[203US7R&<TXJT^IKP[.
M2E**6AZMJFGV^K:?/87J;HI01CTKPX2E&2E'='U]:G&I!QELUJ9<?B'1?A;X
M46S>9KJZ+$PV^<M^/H*ZJ]&KFM932LDM6?*SI4,L3@Y-IZ^9YG?^./&GCV\:
MSTE)8H7./+@&`![FO3C@,'@H\]3<\R&-Q6(J<E'2_P"7J;?@_P""VJM=F3Q'
M=-:V3<ND;G,GUKEQN>4K<M%7??L=&%RMQ;=25_)=3I]0^`^CWL<G]E7TD,X'
M[L,<@FN.CQ!6@_WJNC6IE>'3NTT>?VFL^,_A'K?V>\1I;3=@I*-T<@]CVKU)
M4,'FM.\'9KL>?[2OA'RRUBV>U:3XAT'QYX:F\JY$0E7$]MG#`]Q7@SH8C+L2
MIQ6O1GN0G#&1Y*;NBEI6FV6CV9LM)@\FT!SCNQ]36]:M4K3]I5?O,^@PN%AA
MZ:A!6L,UR]73="O;UG">3&2">YJ*=-U)J"W;#%UO8TI3[(\B^$=C+JVKZUJD
MVX1)$S,V.I/:OO,+0BHI2V1^=4I2G4=5[,^@/A5I[:;X)S)&(FNI2P'<CWKN
MJSO2Y7N>SA(-/\3JNG%<QWC)O]6::'#<]%\,?\@>'Z5SRW/E<P_CL9XO#'0+
MG8C.>.`/>G#XBLLM]9C=G`'K6Q],)0,DA59C):S#=!.A0KVK6BWS\O2QC6BG
M"_5'R?J=J?`7Q::*13%:--SZ;2:\C-<-[6G*-MMCQLOQ,\-C$UHF['J?COQ+
M#X9T7^T%Q(]R,6Z^IQUKY7#8>6(GRK3N?:8S'4\-1<Y]-O-GEGP]\&:E\1_$
M$FIZN[IIJ-NFF;^+_96O9QF,I9=15.GN?(4\-5QTGB*[T>WGZ>1UWQ2LM9\%
M2VU[X/@-KI40`:2)<G/^U[5Q9;4H8M.-?63Z,[<PI5*=*,L.K6WL>@?#;QBO
MCGPY)=NICO+(`7*=B<=1]:\G,<`L)75.+TEL;9?C8U87MKL>4?$CXI:EJ>JQ
M:?X92>U6W?:60?-(P/IZ5[V$R%8:\L5K?[CAQF83=7V.'N]?O/8K>Q'BSP%!
M8^+;8"YGC&21\R'L<U\ZZSPF*<Z#T3/4JX95HVDNFJ/G'Q3H&L_#3Q.K1NYA
MSNAF'W9%]#7V%"I2S*A>WKY'@2]KEM=3I/3^M#VGP5KR>*M`COHP%G3Y98QU
M!KYW$8>5"HX2/ML!CH8FDIQZ[^3/-OC1XN@O`FB:>Q98FS.X/!/I7JY3A)7]
MM->A\[G^87_V>#]?\CUKX"^%'T'P6;G5(E+:@`ZIC^$]*^PI15&GSR^XX,!A
MKQN^IZ,BJB+&@VQ+]U?2L:E1U)<S^1[,8J*LA:@H;-_JS30X;GHOAC_D#P_2
MN>>Y\KF'\=FG,I>%U7&2I`S4G)%VDF>7WEO+:7LL-SCS2<\5TIW6A]C2J1J4
MU*&Q#WP.3Z4%DDB-`$>5@CCE4)Y-6Z,^7G73H9JK"3Y4>.?M)>$_[2T2/Q!:
M*QGM^)5`_AK>LO;4E-=#R,PH-QYNQX/)J6I>+M1TG3KF0LD>V&)1T`]:\"&'
MAAHSJ1W>K.*IBJN*<*<WHM#ZWT?3X]&T*RTN!%C6&,!@HQDU\#6JNM5<V[ZG
MV%&.B;Z*Q9D1)H'@N$66!QAD89!%1&3B^:.YK;6ZW*6CZ1INAP20:+:I:PRG
M<ZH/O&KJU9UG>H[LRI4(TUHK:A!HND073W,.GVXN7Y:38,DUK/'8JI35*<VX
MK8%22J>UM[W<O,2W7MTKF-5H9'C#PY;>+O#MQI=T!YV-T,N.4-=F`Q]7!5.:
MF_=>Z.3%86%:-I[,^:_#OB/4?AQK&K6)@$DC`Q$,<`'LU?75\/3Q].-2+L?/
MX?%3RZI*FU?^MSJ/@?\`#Y_&&MS:]KT)_L:%R[;O^6TF<X^E>WA:"25]DC##
M0E7K.I)7NSZ:!0(L<(VPH,(@Z**TG4YY;GT<8<J"D4)2`;-_JCW/8>M-#CN>
MB^%]W]CP;T*''0USSW/E<PM[=V=S5J3B.$\:6+V^HQW4>Z0S'&W^[6]-WT/I
M,JKJ=)TWI8\K\;^/Y-(OAH?A*Q;5_$3\%%&5B]S753DJ<6[788G$2MRPU9QI
MO+WP#K"^)_B'KJWVL3H0FD0/N\O/J.@Q449N#=2II<X(VI/VU26KZ(K7_P"T
M3#>6=U:R:`CP3J5*L<\&LOK,E?E)GCHW7*CD?@)I,.K>-;J]:#;;P`O'D<(<
M\"OG<YQ\\/0Y([RW-\HC%U93<;]CZ+=BSDGKTKXE*R/J4K(2F`4`%`!0`*Q1
MU8=0:&#5U8\%_:3T**UUBQU:%,+<KMDP.,BOK.'J\I4Y0?0^;SFG)J-5[+0Z
M_3OC?X9T/P]I&E:?8.8H80)@BX&['/UKZZE6A*'OF-/%T:>J[?<;&@_&_P`*
M:I*8]2$E@,\,1Q6LZE"5HQ1O3S"#=D_O/28'BN;.*\L)DN;.491XSGBLZE+V
M>L=4>A3K1J;!69L36,$UUJEM%;1[V5LOZ`4-I(BM.%.C*4W8]10811@#`[5S
M'QKU8M`BAK=FU[ITT*,$D(^5B.E5%M-6.C"UE2JJ3V/C[XA?$;1_"MU?V?@J
M(G7)2T5W?NO*GOM/K7=7K<B4(,[\5B8PO&GN_P`#BO!?@/4/%4LFK^(9IEA<
M[@TI)>4_CVKY?'YJXODI.[ZOL=V6Y'*HU5Q.D7TZLZ3QMX0T'P[X8N;FPA/V
MDIC<_-<%'&5Z]:$)/2YZF(RO"T*%2HU;30V_V<$`\,7C",[FF.7Q6/$+_>+T
M.+)Z<5AN?JV>KD@5\\>Q8D6&1@6;;$@YW2'`HOK9&<JD8^9SVK>-/#.D!OM6
MK0&13AT4Y(KKHX'$57919E4Q$*;:J22+&F>*/#>JB/\`L[6()&?H"V"#Z5G4
MPE>F[2@QT*_MDY0LTC8DC>(C>/E/1AT-<Z:-HRC+8$4.DJ9^9D(7ZXXI]4R:
MM^70\!U^]U+4=`\0>'?$3HVHV,IFM]W4I[5]91I1]M3Q%!:-69X-:<J5&I1Q
M#NWJBM\+_!FAZ]X5DO-11VN1*5R#T%:YAC:M&MRQVL;Y1EE'$T.:2N[F]J7P
MHT6[5EL)&MV(^5F/0UQPS3$*2;U1ZE3(,+[-JUGW.:T#7_$?P?\`$8M+TO<:
M3,?FCSE'7U7T-?3Y;F<*BNMNJ/F)TJN7U>6IK%GTKHVM6&N:/;ZMI+B2WN1\
MB=PWI7I5*-EST]8GM8>HJL='IW/0_!FDS:;8N]UCSYCN([J/2N.I)-Z'B9KB
MX5ZB4-D=%69Y04`!Z4`>"?&3X.^'Y;]O&-N@MGMV\V\@4?)-[X[&N+'N<:+Y
M#U<DITYXN,)J]WH<[=WUG;:2NH7$J0V`3<@!P/I7R<(.34(K4_0:M6-!2<GM
MNSA_'VK67B'P+<7%@X94["NO"J5+%1C-69YV.4<3@9SINZL<+\//B??^#M*E
MT^.W2:UD??SU!KV<=E-/%554D^A\9@\?[!6:NKGI$_QSTR'2TDBL3+>L.5/1
M37B0R"K*JU)VB>I6S:ERWA>_8\XU?Q)XT\?$1(UPUF9/ECA!55^IKVZ6&P>"
MVM<\V4L5B8\R6ESL],^!3&WCEU._)F=<LJ]C7%'B.G3K:PO!'93RA2C>I+4H
M>*_@O=Z=:FZT.Y:9U&3'GG\*=//Z56H^:-HMZ%RR>T'*E*S#X;_$G5?#VIQZ
M%XN:5]/)VAIA\T1^O<4L=E-&O!U</N9X?&U*$^3$;]&>SV_BGP[-<!8-2B)!
M!&6'-?-3PE>"O*)[5/$JK[J:N>6?'W1([6X/B:.4HUV@B3:>'KZ7AK$5)0G1
M3LD>3F>'I0A[6_O;$WP4BD3P3)N7&Z4E?<5CFLDZ^G8]?AY-8=-]SJ+;7-(N
M[Y[&"[1KM3@IGO7%.A4A%3DM&>O1QM.K4=.#NT9OQ+TF/6/"%S'<$*]J/,C;
M'.16N#K.E64EU.;,L)#$4)1^:.@_9%\-ZA+X?NKW54D73O-S:HX(R>Y'M7V\
M,1.--P6S/A:.-E2I2I1W;/IH=*P.$*`"@`H`AO+6"\MGM[J)987&&1AD,/>I
ME%25F7"<H24HNS1\I_&3X&^('\0H_A>:6X\.W+[GMM_-H>^!W'I7%.G3PL.:
M$+L]2&)K9C54,14Y8_U^)3LO!FD:7X=U#2K"26:XEC*R"7J&QV%?.3QDYUE5
MFO>70^RI9=[/"O#QTC+J>9_"J;0K7Q'=:'XMM!);W#&))2.8GSBO>QN'K5Z7
MMJ$^5I7MW/D,#)4:\L/**;O8]OT_X9>$-*E9H[+[5OY#2<\5\J\WQDH\K9[<
M,%2YG)029U%E;66GQB/3+**U0=@M<,ISF[R=SIA148\K>A*2222Q)-38UT%1
MW0Y4_G183BGN87BKPCH/BRS:WU6U$$O5;J(?,IKJPN.K867-!W\CEQ.&]K!Q
M:O\`H>82_`.Y^TEK/7%%J#GS'&"!7M_ZQ)Z>SN>-_9/+:TW<YCXI:^VHMIG@
MW3;G[9;Z<1']H)SYC]*[L!0]DI8NHK76Q.-JQJN.$H*[OJWU9ZQX5TV31/#]
MG9S%7D$?)7Z5X=2?M)RGT;/M,-AXTZ,:2Z+7U/)_B#X%O/#;OXBTJ[_<&7>5
MW8>,D_J*]S!8V-=>PKK6WWGRV99=/"U'B,*WIJ_+_@'T!\$O#\_CCPW8Z[XG
MMVCMU^6.`C`N,?QGVJ*63VK-S?NK8NMQ+?#>SHKWVO>?;T/>[6WAM;=(+:)(
MH4&%1!@`?2O=2LK'RA+3`*`"@`H`*`"@#B_$W@+3]4N);^U7R-0*G:5X4M[U
MY>+RNG6;G'21]!E^?U\/%49ZP/ESXT?!GQ#HL]OKNG1&\>>3$J6J$M&_8XK7
M`T:M.E[.MJ89OC:&(Q*K89<O^?<W/"7Q)CTNW30OB':W&DZK;H-DLL9`=>V:
M\#'Y%5C-SHZI].IV83-HU&N=V?7LST72;ZTUBQ^VZ7<1SVO]_.*\"I&5.7)-
M69[:J+3S[%J)#,<1M'_P)L5+:74J<E!7D.>!TSN:+CT<&BZW)C5C+8;*D=O"
M9KRXMX(`,EWD'`HC+G^'4EUEKRJ]CQ7XE?%VU2"\TCPZ3*&RC7(/!]<5]+@<
MCE>-2J[>1X^+S>"BU2UEW.+^$?AN*^U;^U]9,B6L!WQG:?WC5Z&:XZ-*/L8[
MLUR/)Z]9K%R6E]//S/?-+LM0UVY1=+LY'MY#L%QCY4KPJ5&I5?+36G<^LQ%>
MAA(-UI)-=.K.YTWX2VM[!#_PE+BZ:)\^4A^1Q[BO=PF5>S?-4>I\KF'$O.I4
M\/&T9+J>H6UO%:P1P6\:10QJ%1$&`H'0`5[3=SY%)+1$M`PH`*`"@`H`*`"@
M`H`*`.>\3>"O#GBB>&;7](M;V:'A'D7D#TSZ4XR<7="E%25F<_J_PLT>\U*P
MN;%GTZ"VX-M;_*C_`%%<6+P-'%7YUKW/0R_,:V";Y-5;J4_&WPCT_P`2:;]E
M@U"[L&SGS(3S7)@<DPN%GSVOZFV(SG$U:3I]S)\/_`VSTJ%(Y-<U"YVCDNW6
MNBOEF&JU.;ELNQ%#-<12I>SO?S,?5/V<-/U._DENO$.IFW<Y,&[Y:[_98>-G
M3II'%4Q6)J.SGHQ;']F3PE;ONFGNIL=`365:$IJT78K#58TJBG*/-;HSU3PY
MX(T/0M%CTRWLHI(%ZF1<DUA2P-*$6FKM[MG;BLXQ5>K[3FY;;);(W[*SM[&!
M8+.%(81T5!@5TPIQIKEBK(\^K6J5I<]1W9/5F84`%`!0`4`%`!0`4`%`!0`4
M`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!
M0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`
M%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`'__9````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VYE;RYJ<&<`````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<W,C8`,3`U,34T,S,W-C<`,#(S-S$P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````/_8
M_^``$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`
M0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$`!\`
M``$%`0$!`0$!```````````!`@,$!08'"`D*"__$`+40``(!`P,"!`,%!00$
M```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()"A87
M&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W
M>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(
MR<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!
M`0$````````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"=P`!`@,1
M!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H
M*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&
MAXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76
MU]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`_B5EUES/&Q\J
M)9),-*S!5=@<[58L`68C:`"2<XZ\5C>-]6DU"Q6VMRHBEV02.2YBW>8I8,\6
M6!4?.P&<*"7!0,*\WEUB\<;`X+0LTD8<\,?XL<\D#)&WN/I6@EQ+(+.!=UQ#
M,CW%TC.L>TLCF2-9'.$+)N')S@G'I7G0IXFBJ=6GAZ=6G1<I^^ES.48QY^6,
MFF^5<CZJ\M6KZ_0+&/&2G"HK5,74A1Q,]N>O4G%>[)V4G*\5%+5O1:Z/]E_^
M"2W[,7[<_C;5_%_BC]ECPW=Z19>);`^$K_XIW5UX<\,QZ9:B86^JPZ)XBUR"
M_GBANX;E]#UK4-+TC6KK2-/U2YO$TRZN8DM9?W7D_P""''[=&MS>`="\2^,?
MA;?>&EU:\GN-<\*:,FGS^#/M"2:_;S23Z/9SWWBW2?!FH6/]E?#ZWUJZ6Z\&
M6>N:Z=$U:/3]8O/#;_7W_!."^U[3?V5/@IX7^&'AC4[32[7P?HNH:CI5OHDT
M'V/6/%&G0:W<7U_JD%L#<K=H--:)I'Q(-2T]TR+NW,GZDZ=\0OBK#IL&CZAK
M&G02E68:=!=6TMRR0*D[(\4TJ#&PQ%PY'RR*1RZ9_P`[O$+Z1O$\>+,WHY70
MRW`X3!XN>%2QF%E6E4E3DKU(57%QE!WC%<KLI1FK;)?W#D_@5"GPIDKR[$9:
ML=B<)3Q>,I5\;6H8FC&JKM5:-&:=./)'F_>04VM6TDK_`,Q^J?L'?MG?L(_&
MS3_C;!X\TSQ-X"^'5MJ$-_\`$RXT6]^)]NWP]\122^'_`!_;ZQ\+]:AL#KUT
MOA_6M7N/^$>L!<Z[>1INT"*765L%;\L/^"TW[=OAO]M:R_9/?PUJ[OJ_PK^'
M/Q$T+QKIDICEO+?Q#J_Q(O=(M/$&J:C:YT.;4/'_`(-^'?ACQF^G:/(YT[1]
M5\-1EFA29Y/[,?BKXV\8^'_#FO\`BGQC93/H%C;WQG5=+TU=(T^TU"PN8S<Z
M[J4K266F6,UH\UPUS?-%"UK'+*'V*SC_`#G?VP].T+2OVCOC'HGA"TO[;P]I
M?C75M"T2"\,5Q+-;6.I3P7<TAA!6(K/:NMCM&'TU':,F-&(_7/HV\9U_$?B;
M,:W$-/#?VAE67^UPN,PU!8;#>PDI1C17-"*G5<Y5')*3?*U9)7;_`#;Q[X'H
M<#<'9/5RFO@IO-,:L-CZ.#Q4\3S8GEIN<YJ4G45XNFMN6T5;?3Y01DV)ED)V
MKDY7DX&3U[FBNO31;,*H+2`A0"`3@$#G'M17]</%33?[QZ/_`)^0Z./_`,B_
MP/YDCD[M']V]E]C3['EZ_<^^G&POO8.Y5-N6)<$#"J25(QDE@-H'!)8=#S7T
M!\(?A)XG^(<6IW^E:?JTFB^&-7\$KXFU*U(FBTNT\>^)K'PCI)EMPI,=S<W>
MH&32TG*1W-Q;2,`Z03[?`[8JE_LD=H;>:1XY)=K#R[=\QW"C:DAW-$\D0&QL
M,X!`S7Z1?L2_$GX;Z5X.^/7PD\>Z/X$BU/XB>!+WQ1X#\:>(O$?]CS>&?B/X
M*\/ZH/!EC;QZS>66CZO<ROJ]S/I-C-=22)XEAL6M(Y+VW@@'-GU?'4,IQ&(R
MSWL9@I8:K"G*ZC4IU\=@Z-7D:7ON%)U)SBE)QBE)JQZ7!>"RK&\3Y70SK%2H
M8)UJ]7EYN51Q&'P&+GA9RZ1_VZ>":<GKRM=+K]N_B1I7[3W@_P`03^%_!MCX
MJT#P-X!M9-'^#/\`PC'[3OB+X.VNFP:6-)T\ZI:Q>$UD\/:IK_B*U%_\0+V7
MQ1>OI6H:'+J_A/3K/4KZU@TJX^V/@Q\/OVTQ^S[^U5XI\;?$:+Q1X_\`A1X5
M?4O`_BBRUA+&#Q6S:6]S=6,^AVW@SPJ]M)INCV,>M27FK>&K"XGT^]T;23<W
MVHZ#J-NW,?L2_M&>)OBOHVF_\)3)J=MK&B:!H]F^I::N_5=4>UTZVL+>WUBP
MM+2[M)]4M;G3[WR],L\ZI/*?LT,,ES(D;>N_&O\`X*4_!+]DO4/BM\&OBW\-
MOCA/XOU_0Y].U:;2O!WAZR\`7,_BZZT#4=-@\&>+9&2_\9WZ?#34M.\1:U%X
MB6`:5K%C?:)"5U*2*V/^=&;9UQ/C\XQ'!^"X%P.+Q.5RI8FM65#!UG.-2G2J
MS:E7G[2,75J.,U2C&+E+WVY*\?\`3O'8/(\%E^$XQR_.\5AJ?%=26%5&FFW3
MP<:\J5%U$E[BCAHK6=K)>[JTC\C_`(B_$/\`X*#:#?QQ^(_BC\9/B3\1;?PR
M(_#6L^$/CJVG^&=-M[_1HM3\2Z7;?#/2;3P[HNJ:/H-Y<:?H_P`5#XH\->(;
M;Q)K5QH]EHUWIV][V/\`$?\`:M\$W7A;XU_$.)+>WM+>VU7PY?ZII]KIIM=.
ML-;\4>'+36+W2@NES7FBRWND:A=ZEI-AJ-K>/)XBTZSO=8A22$SO'_6%^T=\
M?]-\)?!;P_K^GSOK4FL>%_"^K^';/Q-IJ:1K^O:=-I<\.B7?B2SM;98M#37X
M;G3;[QBE]+;QZ3K6HW$%XT=SH;1Q_P`VGQF^(_A_6?@7\5?'?CDV/BGXH_'3
MXD:?#I%YINK::5\&Z7\.]0TV.+5-3T:"1KS3KB6P^W^%-$@NHX#JNCWUQK5N
M;B"T>2OZ5\%N(,RS&..C4X/PN2_4K957<</0P\IUJ:A5G4ITJ/N\EJW,FK2Y
MM%&UW'\%\=^&.&\#D]+"?VY/%5Z&$AG5*<IQ<VZTITU3BKIR=Z6EMKMMZ6?P
M>LUN%`-M""``0;6<$$#D$%<@@]<T5P'VYCS]J!SSG=U]_O45^[_49=Y_^`OR
M\O)_T]/XE_M:'3&8OI]B?E_G^/DR'4XUCU&]BQN$=Q<(D.[:S%K@(BJ."3R&
M``R0I-30:;K6GV^G:T=*U""RNKIH],U9K>X%A/=6Q\R6.VO"GV:>2`(3,D<K
M/$JL[JH4U<U55BU[4)6R(?M-W#(2F5>.4SP7$08J50R([0^:"/)=Q(&!4$2S
MZM=ZK;Z99W-RACTG3Y+2P@>0"WMX3=!K.V6/:`\T=R8[BYNA\TELC>>72,M7
MN1A&6'H2E9PE-TZB6K2Y8-IV=UVM)6M=/06+IRH9GF'L])4JTG1G]F:C-).+
MM:2;3]Y=4U?0_;K]B']IK6-(MYK73;G3=/\`%@TC1[NSO?$EAX@U+POI.J$6
MFK6?B#Q!9>&HY-9-E$;Z:[LY;=%22ZAA=V-NDQ'WA\3/VD?COXHU2_G\?ZY?
M:YK&INFKZ=?>%/V-CX\^'^JNEM=Z);ZGX?\`$Y^+MAXAO!<:*+"RO(_%OA^W
M_LRRCEU"QB%_9VI/XUWWP9^)'P'\*_LW_%;2-0NH8_B%\+M-^(G@[Q38Z5<#
M3=376]7NFUGP:\TLUA8:MJGA_5(M1TB_TN*^-]I^@7MA<S6ZI+;K+]:Z;_P5
MT_:5\.^!;CPA:Z=X!`2>6SDO%M=6L[RTN94%H+=M&U&^O-/O$A9Q,`J,D$BB
MYC"R0HR_S3Q5X?8B>?XO/>&,AR+,Y2Q#H8W&8G&>RQU!Q:E*E&,(5?W$54Y[
MN*O-U(R2M%G]L^&_BI@,%PQ@LIXLQ&8T8PPJJ894<)1JTG'DC"+<ZSBU/FBT
MU'W=FMVAW[7?[37CK6?A7#I'Q(\1>%]=\4-J5AH^AVGA+0-0T>/0='T]X+J&
MTU2PU:XU2ZMI[HVRV`LM+U%A%<W"1/NBWJWX1ZUJ%U?3ZB\\4JFYNC=I;?Z1
M''9-+)N+B!]H4S1Y0;ARIW*>%Q^BFC:7\6/VLOBSX;M+VVE\:^+/$NO+9Z5H
M$%N-,LY;R*X635+RZABC!AT#2K7S;KQ)K;(MEX=TB&\U?4KBUM+*::/Y/_:4
M^'J?![XT?%7X4V=_JNM:3X"\>>(/#_AW7-8M_P"S[_7/#D&J7;Z?XDELGBBD
M9/&-K]@\2VNW>L%K<J(V>%V>OU?@'*<IR2E+!4J6#CF.+_X4<;1P=:591K5%
M3HR;C.TH6E22<4E'2ROL?SMXO\28[B;-O[2P];&ULJP])8##U,70C0]V%6I5
M5.+IWIRBHUKWNY>\^B37SKO/H/U_QHJ<K%DY9<]\E<Y]Z*_3K/L_Z_X=?>?B
MWM%V?]6_S_#UMT>MD_;]1&3@WU[D9.#_`*6Q_G63:@&ZM5(!#7,"L",AE:5`
MRD'@A@2"#P02#P:**XL/_ND?^W__`$VCV<;_`+__`-N2_P#4RJ?Z$%YX$\$:
M[_P2"^,?A_6_!OA76=!\$_LO?!3Q)X,T35?#VD:AI'A'Q%=_"D:G=:_X8TV[
MLYK/0-:N=2CCU"XU72H;2^FOHTNY)VN%60?QA:LB'4?AW"54Q:IX*T"_U.(J
M#'J-\;:1#>WZ8VWEV4^0W-P))BOR[\<445^0\"_\C/C+_L98_P#]1\.?L^??
M\BK(?^Q7AO\`T_4/Z9?^"._AOP['^QY^TWXRCT#18_&$WQ\;P++XK32[%/$D
MO@F"WTS7(/!TFNK`-4?PK#K=E9ZQ%X>:Z.D1ZI:6VH)9B[@BF3^>S_@L!;P6
MW[<OQ=AMH8K>)8OAUMB@C2*-=WPN\(NVU(U51EF9C@<LQ)Y)-%%<'AW_`,G'
MS7_L6+_T_6.#C+_DWV"_[&[_`/3&'/S(")@?*O0?PC_"BBBOWD_#ET^7_N,_
M_]D````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T
M87)S+VYI;FIA+FIP9P``````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S,3(`
M,3`U,34T,S,W-S``,#(T,C`R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````/_8_^``$$I&248``0$```$``0``_]L`0P`+"`@*
M"`<+"@D*#0P+#1$<$A$/#Q$B&1H4'"DD*RHH)"<G+3)`-RTP/3`G)SA,.3U#
M14A)2"LV3U5.1E1`1TA%_]L`0P$,#0T1#Q$A$A(A12XG+D5%145%145%145%
M145%145%145%145%145%145%145%145%145%145%145%145%145%_\``$0@`
M,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$!08'"`D*
M"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A
M""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U15
M5E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>H
MJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V
M]_CY^O_$`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41``(!
M`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P
M%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E
M9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6V
MM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#
M`0`"$0,1`#\`]<K(UK5I;22&SLU5[VXSLW?=0=V/M6O7)J_F^(M1GD^]&RP)
MGLH&3^M`%J/1K7/FWFZ]G/WI)SGGV'0"B[M`M@\-GBW/4>6,8-6]^5V]QT%0
M22AUSF@"OX0MK5(9Y!%B^1O+F=N2?3'M735S&@MCQ#J"H,1^4A8=MW/]*Z>@
M`HHHH`*XV[>6P\1W,'E!_MC"2,E@HZ8/7O795RWC"VW/973>8(XF*LT9P4)Q
MM.?3(H`S+BZUJY+?9+80QJVQVW]/]HGT^E6;5Y!YLSSM+"0!&Y&,X')^A-2)
M`)X0UW/=S`C_`%<S`@'W`X-$4YO9)"FTP1_+G'#'N![4`:'A6!C92W\HQ)>O
MY@']U!PHK?S7'6DFI:-;O#91QW-N3F-96VF+/\Q[59%OJTZF275W1S_!$@"K
M[<T`=1FBN9_LZ\[ZW<Y_"B@#HKB>.V@DFE;;'&I9C["N3>34/$$;27$YLM/<
M';`B@O(OJQ/K6OXI?&C/'S^]D2/\S68;DW.HB&'B"WQYA7H3CA:`,^;1I+6`
M1175W);,N"J$%D_Q%6$NFAMK2UMH5DN&CRJH,(%'5CZ5I>9GYFX)./I348#G
M&,#B@!;6T9&$ES,)9>@P,(GK@5:FEC@0R.RH%&22:KW!D%M*4?8^TE6_VJI:
M<#KU\B7"#[-!&LLB_P!]ST!]AUH`B_X2$'E;:1E/1AW'K178A%`````[8HH`
MQ_$__'C;_P#7U%_.L;2_^/*8]S.__H5%%`$TI/'/>G6Y)7KWHHH`GN>+*<CJ
M(F(/IQ3O"(`MKL@#/GX_#:***`.BHHHH`__9````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O<&%I;G1I;F=B:7)D+F=I9@``
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C(S,P`Q,#4Q-30S,S<V-P`P,C4U-3(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````1TE&.#EA
M)0`E`/<`````````,P``9@``F0``S```_P`S```S,P`S9@`SF0`SS``S_P!F
M``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,
MF0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S
M`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9
MF3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8`
M`&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9F
MF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_
M`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDS
MF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,
M`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`
MF<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9
M`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_
MF<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F
M`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,
MF?_,S/_,____`/__,___9O__F?__S/____B_)```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"'Y!`$``-@`+``````E`"4```C^`+$)'$BPH$``!A,J7'@0
M@,.'$!E*;`@@T(H5$#,ZE*@J(42,&D,R[&CP8TB1"_&0+'BRI40G*E<2!$`-
M@+.;.&W6G(C-"4P\+&DZL^G,F-&ASG9.Q/,S*+6<P*(:NZET(L*20F\"B`J,
M:-*-"S,ZA>H0Y]>K"L7.S#JTJ]>S#&D".'8,+#:'3[6^I6K7XU"ZU&HBQ&NV
ML-;`:$O^/495,-O".N?6C2O9;-W'..OR55N2KF7"AC4W!F#&#)[$`Q\ROGDY
M;V'121&7/HTZ-5VZH%^7Q8D8C^_3'F^W-NSLLMG>OVM3A+CZ\]Z:M6KY5AX\
M-(#3QP%$G\[S;O/,UR]Y9-S.O?M<W7@NJ+_PF_9<ZIVMMW=_&W[P[\4SUN_+
ML[)SU;CQUY]DPA5X67=AM21@0JPTR(I!#CH4H8,.3D3AA11*V"``&#;(4(<9
MLJ*AB"!ZR&")&X[((8HGHOC0A"RVB&%&*:[8H40EVLCACC::B&"(%_9884$!
M`0`[````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A
M=&%R<R]P:6-A<F0N:G!G````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W-S$W
M`#$P-3$U-#,S-S8W`#`R-#,W,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(
M`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&!P@)
M"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1
MH0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-4
M55976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::G
MJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U
M]O?X^?K_Q``?`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"
M`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2
M\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D
M969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2U
MMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,
M`P$``A$#$0`_`/Z9?'_V^>PTW6I-.NM.GTO6+0R&[C*K';VW\?FQEP0_.?E^
M7U;K7A/[:O[0.K?!WX;>&[/X8Z?HOBGXZ_&KQ'%\-/@%X,OYH`;WQ_=1:KKE
MWX]\1QQQWH/@;X;^!O#/BGQAXEU"[2SMX5LM!T1I[;4?%>G&#ZL^+7BCP=X5
M\#^,?%?CO6Y-(\">%O!6M^)_$^I0178M]'TWP]HU_K^J7VI3V=KJOV06VFZ7
M>S,I1\^2!N!:OR*\4?$?XJ^.#XW^.OCSX7/X/U?PE^SM!X@^#?PUMG\?'X@Z
M-\,/BCXRU[5[SP_XPU=['R;+Q[\0M3^#/P[U'74TS39;KPI=:=X3TC7WL]/\
M3:Q#;?YYXO&T\ORUYC5IUJ\VIJ$H59KWW&U-NSY>15+<R2NX*5I)M-?V7DN&
M>;9C##\L*=)RC=.$;-*4>97=I7:=NR;U6J3^EOV6/!^@_!OPC>>#;/5)_'/C
M+QI/J&L_%_XC>*(I4U;XT^/9[Z[?4O$GBG[5Y$U_X;36=4U@^&O!FG:EIJ>&
M9--L?`W]NZEH]PL\&'K_`,/=,_9<UG4_CU\)=2US2O@C/J=YJ'QN_9ZTCPWJ
MGB?PQH^F^*=0N(/%WQ2^"6EZ;J>B^*/!VJ^%])M;_P`3_$+1_!FH:KX=\7^'
M?#WBK4M'T;P_%H]C)K?Y4V7_``4,^(OP2^('AW2/VE?@QX1TKP)<Z7\-SXT\
M1?"#Q)>:MJ'PCU_XS^&/&_Q,\*^!?&.D^.8/#@TSX@V/A'X=^*=;\2:)X=U3
MQ/I6B:[X9M+^?Q$[>+;*VM>I^%__``4^^-'[6W[5VF_##]G"Z\'_`+/WPW;P
M]KGB[X>>*OBW\/?$7B>]^/\`J'A^ZU+5SH>C:Q_:FB^&O!7A_P`11^#M6\7^
M&=+@OI]8BUWPY?ZA:Z1XOF\/Z;-X9^*R+)/%>68O'XA0AEKO6Y77HUHN-[KE
MG!SYD[:)3LDW)KENW]#Q1E>58"?LLNA35648\W+*44[I)MIJ=FHMM-13NHIM
M*UOZ%?`/B31O%>G6>L>"=?T[Q=X:\7Z=IOBWPEK^CZUI>OZ+XIT/4;.RC2_T
M^\TN[N[CQ+I3_;1X=M9M2M9]8?P/IVI6-YHFGW=FNKSZ.H6NJO%+#K$J!C#=
M0VZ\'[/]F_B\_(\S?TQM3;ZM7YT_!GXC1?"S]N#XV?`Z_P###V?P^^-7C[X6
M?$;PW-H'B**]T/P[\<O'GP`\=>)?B-IS:3X@UK_A(/$MAXMT#X.^)[Z"UTWP
MRFAI%_;NL_V1HDHGM(OU0OK"QOHS#)YEQ%_I7&2C_P"D_P"V,GY.G^UWQ7Z=
M3GBJG)BYU)->J2LG9I623VMS.[;O=K9?$8:*H8F4:D(VER[P2E*T8[K5)IW=
MHV2U=KZF#&-):.-GD;<40M_I$7WBH+=_7-%4U\#:054F.8DJ"3^]&3CT\[CZ
M45Z2SBAI[DNG_+R?]WS\G]WWY7I7V>_\\O[O][R7W>MN=^*'@?2/B+\-OB1\
M/O%5C%=^'?B#X#\:^#/$EA=O>6]OJ>F^,]&OM!N3<PZ9=VYD%KINIWT/EAT-
MQYV1);E0:_F"_P"":O[0'[2WC'5?V;/AU^T)I_BC4OM?P+^,^IZ!XTUR'0]6
MT7QU\*K_`%'P!)X'\5S:SIM_?7-QJ7@/Q[\-[2/6I]9A&H:-J'[0>E>'?'.F
M$^(=+U*?^K.>:6*W$GE2Q1^3Y3"`(F[_`&OWDDW;J.?J>WX9_`?P?XJ^&7QW
M_;7\">(/!6I:)%H7QO\`'7Q%\$:S<W-QIN@2_![XYWNC^)=-T?X5WMIKL1BL
MO#_Q#^'VK^%/BOH.F6-OI^F:YKWA/Q;JR^+5T?PQX=T_X'.,ZH8'@WB&E+!?
M7:N`2G0E=*5)RM27+?XUSU8RE'EE)J/.G#D<X_6\+47+'J<ZJHU-KV2=E**N
MHI[I/1I-WLEKRI^$W/B*;QO\&_&/[$%Q\']7O_VC_&_[57Q+U;QQ\4/BK\+;
MQ='^'O@;QI\6-9LYOVA4\0^*=+N[37?B7_PHZ_TKX:?#(>%K_P#X3`7$=CK5
MK=V^C:#XD+_6_P"R]H7QW^'FM>'?V==`\5?"RR^!'[)?C_Q38>&KCS=;U_XZ
M^-O`WQ-\-?$8?`S1_&%S-I=KHUQ9S^$/&DFI/XLMQI^K^+M6\':;HFL3K)J/
MB6_U;A?B%^T%X:^&/[27P9^"U_KD.AV7B#1K]_$M[-I.G67@R#QSXJU&?0_@
M'X)\6>)AJ6A'P#)>ZSX1^,WBGP-<6UY>^)=<\1>"XM>TF2\U;6=3U"]L_$CQ
M_!IO[<_P:\2_#+Q;?>)O"MIH_A#X,_M=>#O!FKZ?:^"_"<7Q6\9:M\/?@?)\
M2->N;M5F^(&E?$3XI:9J7@SP8IT[Q#I>F^$]5\.W,MG'+::DWBY9Q)Q7G.!R
MS!PIU,MPN*INK.+FU[6[?([J-X*]E3C%)*,HRNH2YE]'G>383"5'B6UB*R5W
MRSE-;)S2A*=DFN:*OIS2M)-JSH^$;34O!7_!4?PKK=[\1_#R7?Q?\:?&FQF^
M%^HR^#-2@\)?#GP;^RY\+-/T36(=9$_B3Q%X?\7^*-6L9)WOM)UG36.@:5XL
M\*Z?]G'B?Q;J^J?N_#<MG]V3&O9I8PF?_'B/\G/&:_*3Q'X1\*67_!1S]D'X
M@/IIN?&?CG]F[]ISPQKYMTU&QT4Z_P#!ZX^'1LO$UWX=L+!I3<Z5I/B[XI>"
M9]2N-6L5U>X\1^%Y@(#;Q6$OZE644"6VU'ENGYY:X\PC'7@JOTX/X8K]'P%#
M%4,GP"Q5>.(5;^):,(MVM%)N$8V=DFW%ZWNVY7/S?&VJXS]SH[)M)=^NO6][
MZ)^2TMT2W\FU?FAZ#^'VHK-"P``>4W``_P!8>W_`:*ZOJM#^3_R:7EY^7XON
M>=9?U\O\D<I%>13IF:!#'_SP*OV_V]_OU\OI]:_.O]N77M2^%WC;]E_X_P!_
M>7"?!O1/$GQ`^`?QUO(;.SU+5])\+_M%S^`[?X5^.%<16T5HWA7XP^"_A^\U
MQ-:S1V5GJ&O3W=XZW$ZR?H:/-^T[0&1/^FJ1QCCU'FMV[9KSGXG_``S\(?&C
MX6?$+X4?$#3YM2\'^.?!.H^%?$FGZ80=5@CU>&5K#5-/4C,VI0ZFMYJVCW"&
M&32;O3H#&\S;9$^`A4HX:CB<-B\/]9P^/LL53:UFI:/EEJX36KBU9)V=FK(^
MEJ2E1KQQ%)NG334KQ;WVL]4W?71-:OKU_)_P]X1T7QW^U)^UOX/\?^'/#/B;
M1KSP!^R+I=KX5ATZPU_1KW0M&\(_'B*/1=/L;Q;B/4K#1O'.EZQ<O#%KMI#9
M1:Z\VJV&O#PKX5.E>M>-O@S\./AC\*?"OA#X9^%+#P-:W?[4'[(OB#5=,TBT
M2_U2?7I?VW?@MJ=SXAU.2_CU6ZUR9K:Q\0C6_$OBG4->>34='T?2?!VNZS'"
M;S6/FSPQ\.?B=H'[0'Q5^$?Q&^)VO^'OB'I?P13PGX1^)B:EHVM>(?B9\$_#
M.N>';;X/?&70-7\9Z7)X0TKXK^"E^(GQ&\$_M&M(=230-;\7?#G4?#3>.!XU
MTJV3V+7_``1JGPR\&_L]?LU?!/X@3Z?XH\=_&GPQH<WB+QYXH\7_`!0\>ZCX
M1TSP=KFH?%GQGK%K-XD\-W_A7Q!X.UH>'OB5\)M>O9)O"'@OQ!;?"/3[GP]X
M:\2^(8M(NO/PN758<3Y/06,Q5/`?N'##>SE.#A"DDINHN:;A&24(PBY)+FA)
M4U#EE]SBJF$E@/K*J2DIQYN9/EBFN6/O2DKJ\4VU)RNHZ:N-_H/]FV\M_CC^
MTU^T/^T=INH&W\)?#8WG[&/P.O[-M9FMM9N_#OB'_A9'[3OCO4A)`(;FP\3^
M/[[PYX"TZZLC%'<WWPTO8(]0E6(PP_H9"8G3SIT$?_3&UE*?^/!6)]/N]Z\<
M^"7PL\*_`/X9>#?A%\.[==+\'>$?"ECX7\.7.H:A<W\^L:9H1U'4KGQ+J^M(
MX?6?$OBJ[UZ?QCJ]Q):V\\NLZW=O)/<[5<^PV5O%%T39S]QI=_Y$A>/PK]/Q
M-*GEE2CA'>KAZ5O8PN[K1;M7;;O=ZO6]VWJ?G6'IQ=6=1ZR<G9W:T:TTZ;??
M=JU[&K]OMO[_`/+_`!HK-+VI)(@'))^\?_B**Z%JD^YE["E_(OOE_GY?U=G+
MVRK(#YBK)P/O@-Z?WLU'XCDDMCX9FMI'MYGMM/#S0.T4K",:@8PTD95VV&20
MIDG;O?;C<V2BO@JNT?5?G$]#%?[FO7]$?C/^VCJ>I0_\%AO^"9_AV+4+Z+P_
MK'PL_:KL]7T*.[N$T;5;21=9U%[74M,6065];/J&F:=?/!=02Q->:?9714SV
MD#Q_)WBGQ=XKA_X+H_\`!/S1(O$_B&+19_@QX^TR?2(]:U)-+FTW_A;G[46F
M_P!GRZ>MR+22R_L[PWX=L/LCPF#[%H.BVOE^1I=C'`45]SA/^1UDO_8'_P"Y
M:AV5/^2:C_CE_P"EQ/Z9K"../Q/J]K&B);6TFEBWMD55@@#Z1IT3"&%0(XMT
M<:1ML5=R(B'*J`([DD76`2!QP"0._:BBJSC_`'U?XOT/*PFWW?\`I)HL!D\#
MJ>P]:***<=EZ+\B3_]D`````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]P=69F+FIP9P``````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`W-C(V`#$P-3$U-#,S-S8W`#`R-#`V-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#_V/_@`!!*1DE&
M``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!
M`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`
M!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I
M*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'
MB(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7
MV-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!````````
M`0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1
M!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ
M0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25
MEI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3E
MYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/D+X->%KWXL>)WL;87.FZ%I
MSAO$FNS)#&=,M/+,<,-L2RQWUW>)%-::;9Q03EY2OFA(DN67]1]<T71O#WP\
MT+3E7[!96]BMJBNN!;VEO/;BTDD9G17,\EPUQ*ZC<TTSRR$RNY;\&OV2O`7Q
M^^,/[8LNG^!_BCXR\`_"'X51>#_'WCVTT_5]8E\(Z]IM@MG?6?A_5=!M-;L=
M-UB^\9:G>ZQX4MVU"'47\/V-YK7B=["YLM+N[&3]I/B1=:A\0O'&F^#M,F:X
MGU:66"Q@\^:*SM8;"R2_OI3:1*MM,MG#9RSQ^:\$48@A$+I$T9KZS-<$L!D5
M#`86G*KFF?T:?LXPMSTJ-3E<9.HO=BY7TBY)KEDY66IS8"MBZF>/%YC*6"PF
M2RG)0JJ=+VE;V,9KGI5%&;C*$HU:<DG3G"K2G"<HRT_*?]J77O&6M_M-^$?!
M'P(\#O\`$O7=4\&OK?Q`M;%/(72K>>>2S\.ZB=7U"_L-%TMYX=$EBG;5[D)>
MM_9T=K_ILD+#WG1?V8/BM+8PW.JVV@:;<B(M<6EQJXN)%:5<K&5LK2ZMMR.K
M%C!(X5EW`[H5(_2#P_\`"C1/AM$OAW0+"QNO%.L70N/$'B:'2H;;6/$VK1?)
M92:C)))-=74=A90C2='BO+R>+2-+B73M,%M96R1-9U^273C/;D(WV:81J8XX
MF+Q)(!.P;:1+(P9VD9G8%`RF0I))CY+%\-X+)L)A<+C:DZF+IX=*:C*$;RC[
M\];R=1IRTE'F7(H.Z/J<MXCQ&9XFMB,(H_5J]=3@YV;A3<8PI2C%/W8R<'+E
MDD^>4[I7L?DSXV^%7C'P,BWOB#3GDL"]M%'J=I)%>6JW+M>.KRAD$MM$(X)G
M^T2V;E6-OAR9$AKS%(HHXLEIGGC/S#<Q42^1^ZE:-F$ZKYOF;2T>61@\*K()
M<?KC=:?;:U:W=IJ%I#/%.IM9+6\1+N`VP@5`)(7#1S![ABI:6,KN98S,R]?S
MU^./PON/AUJ]OJ=A)%-X<UO4+P6P2&&"+2;J0221Z4T8NK@F."S2[FLYU2(!
M;.2/RK<P;Z_+L7B(4,4H1C*$*LIJFY..DHZ\M_A;ZQ;:V::;:/U#"PE6PTGM
M6A&+J0TY4^6,ER]M59ZOXK+JCR46<;`,#=`,`P"@2*`><*ZH5=1G`<$AAR"0
M<T51CUQ1&@34K)E"*%8R;2R[1ABJP,JDC!VJS*,X!(P:*M5:3L^6H[V?\6GK
M\'][KI]_D5[+_IW/[H^7][R_K6_UM^P%<0^!/V.3\1+2<:GXV^,OBS71K@M&
M@L?[(TKX;R)9Z+8ZE=!6O9KR74_$WB.Y?=$((K-[`KLD($OIG_!,;XD^(?V@
M?B3^U5\2O$F@6">&OAKXCT/P#\-'96NT6.VO/&%AXLU:SUN]B0R7.L/)H#SF
MP:*!(;&.U0S1RV\[?E?^R]^U?8?#CX(7/P:\0V6K7!TKQ!KVL^$M5T>ULVBN
MK'Q1*;_7;74FU*[LKBWE>[MXY[7;!.\/G3QH;:&"V#_MQ_P1W^"=W\-?V,C>
M7<ZSZAX\\3^+-9OKPK,@N5L?&.OV`=Q($0.4L8$8P11K)/'*&():OZAR"CAL
M8\MJ\\:]3"99AE4BTW.C65*,9IW;Y9/$.<VGTD[6;2/YV\3<\Q.8<2\4YHU*
MGA<PS[&4L+=*-*K@5*&'R^,(QC%*G3R^E0IVCRJ*A!**::?T]JW]M0:]?Z];
MVC0KY5Y%:WD*2M"'M;`6\D`F614-S+:SEVWLSQLPR$&47X5_9_TOX\:[:>+M
M4^.?A^X\"ZCJ&OW=WIFA:AXZT/Q1;KI#:9X?\F[LT\/ZOK4&DI)J4.L-!H(D
MAFTXR29A9)H)W^_OBI+'8VUFZ.YDTV2Y-O$WE@(MW(R74S1A0=TL:[SYHDVK
MLC38%KX"^(W[5GPA^$7BCP#X-^(=YXL\.:A\09-9N;7Q;=:5I4OP[TQ;*^T6
M!-,U/6)-<_M&RU0-J37$MI#H<UA%ILMG=K=*YN+=?"XNRW#U,?3J5N:5>E2B
MX.#:2C-S4G9:6?-RR5M5!IZZD<&XZ-#"O$^[%5%##WE>44Z$F[<K5M5*T9-I
MW=]W<T_CYX]\4_!3X;^+?&?A#P+J'Q!US2]'C_LO0]+T2YUF2XU34=>T_3([
MZ:WLHCJ-S8:+;O<ZQJT,$]K*=*M+EQ>6`WW:>>^(=4N/B]^RCI'Q)\6Z3;:9
MX@O?A=IOQ2N].T^TN&BTS5X/"4FMW<>FP7<EY?6\5QYL[0V;/=7D=O)):B6X
MEC7S/8-*\??#OQ9J=Q;>#?BOX#\4:Q!:W&KMX>\,^*]+\0ZP=$2>"5M6:WT2
MZN/L%LMQ=6T3F>2.XAFD:WDMX6D1H;WBVY.H^!/&FEW(A:.#P=X@M<NODQ,T
MN@WD,B22)LF*A90QD8M,=[LP=@"?YNXH_P!GKTZ:H2INA44J<W=NK"5I<KOK
MJXQU5FK*VC:/Z$X95+%UJ^.I8MUH8BE&DJ4)7I4W%1;EO:]VE:\OB;T9^(4/
MCKP>T43+XAO$5HT958(S*I4$*S'36+$#`+%B21DD]:*P;CX96!N)S'KE_#&9
MI2D,3QM%"F]ML4;':6CC7"(Q525`)4'BBO/6)RUI-RQ=VDW[T]W:^O.O/HO3
MOZSP.8WTJ4+7T_=]+P\_+\&?+V@BXT#Q8FFW=L;5QJ=]9W,<R;[B"8"1YMRQ
M.J-Y<CE8D9Y$9W=HG8;99/[#/^"=7B33=4_8S\,Z3:;E/@R7Q[H^H(Z.L<=S
M<^,/%7B+$"^;,93+9:W:R1%HH0)G174!&EK\%/\`@I%\/=#^'?@S0/B;HME'
M#X\F\2Z?H6E^8`]KJT=Y'%+<V^LK;I`)3!96MTT<\4Z21Q/.N$C=K=_M/]BO
M7[K]DNV\1>'OVB/$FG^!++]JOP]X'\4_""PUBXEL9M$UCP3X::]\>:-XQDU&
MTL[?PE=PGQSX<MM(:]GDCO+Y1ILUY%JKQVMS_9_!.0XZEB\5:"G0Q5&<5.+;
MG&>&<*RIM)*]2,'7DTVK1BY.ZC8_CSC?'8:>7X>]3DG0QE*;BE%*U3DBY.VW
MOU*+;MHJB79O[W^/GB6WMKB[!\X)#L2:-4W1%O,9K61`765U42!'R492I.YQ
M(`GYE_&'P7H/QB\)-X<\06-I=P:;JD&MZ+=WMM]JATW7+*WU*UL[QH'RTD;6
M^LWMI>0*-TNF75]#!);SW,=S%]$^++OQ!XL343I5UI_B*UTLW;Z=<G6;)Q?Z
M9YHC06][/JL=E=6L%BD8@N(9ECE:)(H993+$DWS!<^-+F!I(=42.R8//!*CH
M\;LUO.8Q&JO<-($1RT+;$"QMY"R,B`!?$X[R_$JHJCHUO8RIU(1M%QYN96E%
MM--<K;:>[2TZL^I\/<RC@98:KAZM!8O"XC#XNBY*G6C"K3E&M2FZ56,J=1<T
M+3IU(N,D[23V<7[//P7^'WP&MKV'PMHVD/X@U"YE;5_$D&FQV=W.C65C:7&G
M6LZ^;?VFAFXL([U-/>]FS>S/<S2O+R/JCQ9JZV/PW\93-$Q>?0M9A,K.LJF2
M_M!:6T:,'PY,\^\1@JJ0IC=O`1OCV_\`C)X9\-SP7&L:U:6MNJ11E46X>=)'
M>4(C6MO%+=%,HZF;ROLP`<"0$K7#_M`_%/Q%\2O@AXC\0_`Y]+\56_PHL+CX
MG?$&Y-RUMINF:/X6T"[UJ&RU99;ZPO)TDA@N-2N])@EM[^YMM*:2*3[6UC;W
M7\Y\19/7J>S]E%O6,(SJ5793J.-.G&<Y)N"YFD]]TK:JW[_E6>0Q&*Q6+KRP
M\*M:=3%XCV%.E0A)M^TK>QP]&,*<7:,G&$%%:)*UCY]N]=,-U<PI=S(D5Q-&
MB;I/E5)&55YMF/R@`<DGCDGK17QEIG[3/@W4--TZ_P!:MWCUF]L;2[U:.Q:Z
MCLDU.YMXYK]+-':=TM5NGE%NCS3,L016ED(+DKY[_4C/EI[2EI964KK3E6_L
M]?7STZ7]3_6[(GJL1.SL]='9\NZYM'J].FGS_5O_`(*YDGX6^$@22(_B9`(P
M3D(!X;\1$!!T4`@$!<<@'L*]>_X.#)I8-+_8RNH)9(;HZ#\;<W,3M'.?^)A\
M!UYF0B0_*[KRWW68=&()17^@?!_\.A_V'9K_`.H-8_B[B7_>Z7^'"?\`N(_F
MYT[QQXUTF)AI7C#Q3I@4N5&G^(-6LPI?5)MY46UW'C=N;=C&[<V<Y.:VN?$W
MXD2P:W')\0?&\D?GR+L?Q7KSIM.GW(*[6OR-I$<8(Q@B-,_<7!17E\=?[G'_
M`*_5/_24>[PU_OL/^O$?_2F>5/XM\57&BVUK<>)O$$]K)(MQ);3:SJ,L$EPZ
M/OG>%[EHWF;)W2LI=LG+'-?K=^PW<7$'_!/?]N6ZAGFAN;S2_B[8W=Q%*\<]
MU96?P&MY[2SN9D823VMK->7<UM;RLT4$MU<R1(KSREBBOYKX@_@4_P#L*P7_
M`*DTC]2R3_>X_P#8%CO_`%'D?D7I=M;OIFG.]O"[O8VC.[11LS,UO&69F*DL
MS$DDDDDDDG-%%%>W+=^K_,X#_]D`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]R961C
M<F5A='5R92YG:68`````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-#(U`#$P-3$U-#,S
M-S8W`#`R-30Q,0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!'248X.6%!`$(`]P`````````S``!F``"9``#,``#_`#,``#,S
M`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,
M`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S
M,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,
M,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S
M,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,
M9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS
M9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,
MF0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DS
MF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,
MF?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8S
MS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,
MS,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S
M_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,
M_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````(?D$`0``V``L`````$$`0@``"/X`
ML0D<2+"@P8,($RI<R+"APX<*K4!AP6(%Q(L8$S[9N#&CQX^8+LWA".6CR8>=
M+HF<@^W)R9<+=Z6<,X>.2Y@X#>X*-A,*G9Q`!^[:I7(.E"<E@P*E0X?F'#U*
ML3%52G-/4"B7?@:E"16G%3J[,&D%ZG3A"BM6K@BZ,C!M($%[OEX:2C1JV80K
MH.0!E.P9E!4K].@I]>R9ITN8AE[R%!7;78-Y5W`L%6BC"LEYGJFDB]BJ4A8T
M$5JAN$*%BB>DGI0&_`00LDO!%#-N#,4H0HI/2)!0844U8,!ZD'4*%GO7[*B@
M;V*#PAS*%1:J293F^'O%'E*=#A,=&S3Y1LD5J?[_EO[=R1.G13<?'[B"!9VL
MGC,BY?B==>_Z'-&KO#1S,<&\M6UVB4E[.$7?1FCY1A]-`G8RG(.`$`3%'DW-
MX4ELW&'DU!R2<816;QWJ1U0PPB23#"DU=;6<)WHP.!<F!(XTDF0=*IC?'/NI
M)`PII7C224UT,-<4(.?-D=TE2;659$-'B:>"$RPP=UZ1.2JF4AX<F4>3350.
M*-"$S.T2GT-3JG::8"T6Z:)**8FD!T<``%#C@0*M`)9(*M$QYD+0D63%)Q32
MI":.^\V11VKWQ2GG91TF:2=1<R1FW$.CT6=%()\T>:.+I/#(VA.*QDDC"_\5
MNMDN&2XDT7F"[:'I@?ZH=2K8IZ$"<%NA.`ZE(D3?I77%%1+=!]AEI@4@'6"U
M`A``00%(5F51'OGF!5R!Q+6";BH<6YUOORFZK$#A$9IC:!E5Q$(7:P%;VF[7
M,CH=M\@J2Q!TN>XW5*H/`69%%X&,-NQJTPF6Y:<KV/K?$_;.-=1Z%TG6A;K5
M_?:$'IUZ8N2/JL%9T`ISP::P2@Q#U!Y@,@02R!5=Z&'%ACD6M9&!U06`L,)T
M+?Q19"0#VUN3&^(HZ,N+_<8HPHIQYJ5'4DH,Z]*"<OF$$Q'7RQFJ)S6W-'4+
M"CK2:9*Q=YZ`'>/;,'T1S_FR@?1MS&#1,+XT<MF?;MJS;01]36@G8N'T]O6V
MFZIY21Z/S7M431,"55'9?1>%'DN-X07W@2/]^#/CC3L>L=SY%5EY1(<K?=Y,
M&6^XN4)0))BU@0QN.7I$]ZGFA-9.Y>$)1ZLGA%85N)^M.TWF65$[9+_I@7L5
MF#NUY.]U`G9X[ID_[02+>R+_UT;3,^^4$T]2COR\'=7YA/7G$:_]]@)M1.K&
M<E=!?D'G'8\-C2NDOCY:>]3_7LC8M*[Z]E8<%M*=GL`?<R3BOLJA14@)R]/Z
M$"(EN;5,;-M[U>D$!,'?]>EJZ`D+_J1W-<CEJ8*CTY39($>H!1XD/!WTB0E/
MB$+Z,&>%"M$74EX(PQK:\",!`0`[````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O<F5I+FIP9P``
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,#8W-0`Q,#4Q-30S,S<V-P`P
M,C,W,#,`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!
M_\0`'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`M1```@$#`P($
M`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R
M@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ
M<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#
MQ,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!
M`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W
M``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8
M&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ
M@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*
MTM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#ZL^!G
MQ-\::M\#?!7Q7?3]&TC6O#>J_$V^\,V%GJ-QI.IV6E^)_!_CKP%X1UK0[N.:
M_?7?B49O%.F:K+I\LYN?$/B.&+S=C>0L/EOQ:^(]Q\+/V:)=+DU*XF\3>+]=
MTSX(P:[XA?3Y]<\66'A6SA\.>*/&`>QL[*VCL[#3-,UOP_X:TVUMH-,\.6]U
M<3>'K'3=6U+4=2O.5\&_$FS\(_LV>%'TY;5Y?AQ<^,_'K6;$0>7XOU37)M*^
M&5B/L\;0PMH^K:S!K)'V.:2*;2],G13'!/!=_(7B#3/%WQU^!-D_@_4F.A?L
MN_LU1_%+QOJ=P;K5]0\07?CGQG=:3J=]IMY>6EC;3>(M.M[/6O%CE$MHO+@N
MV>-86'E_NV)AEV283#YS%T:*P.!H8>4XQC%IR48VO\[;/UL?CF483,LTQ+BX
M5)^VKUN1OF?+3234?1=.NGJ?IE\4?'*VWQX_96\$Z9([:3>ZCJ/C)(E^SPZ;
M-8W'@^+P;X3FN+?RPLL%I87MT+:-2@2X(N(&CF`:N^^'GQ8@\1_##QS\4X9F
MN+"/6_B=K&GAP2HM_`5[J4%A#@$,8[ZUM+,S*K`S332&%H$9(T_+#XE?$'Q-
MI'C7X%S>*-/U0>)/@%\./!W@CQUK!@:UMKGQ#X!\4:AJS-81FXFB"^+OAQIS
M>-=-8ZG>R2:?8:@5AG#11Q?2?[,7Q&\&ZI^QMJ,<FIP65CJWC#P3X5T;/_'U
MJ1^,'B;P5;^%K.W4DJ=2U^+5YY[M_+,,L,%V%MXSEA]%E/$66X[#494,3"$I
MSA&4TU=*3C=WUV6K_P`K&&9Y36PM2,:\G:4HQ;=[Q3<5_E?Y;ZW^^[;6=:\$
M_#OX>M<DZIK]M+\-=!U5]4A2]'V[4=>TCP[JY:V`@6YE@;7+R2UAE$D;0VL2
M7,=TBS";T#3?&GAK0M:L1JEKI6OV^I'QA\//&/P_GL_[0M/BAX$EFDD^)7P\
MUO4+EI7NKVXT6^U#5=`:Y>270O$BV%Y;.ME;R:?-\_?'HZUK'C_X1>';"ZAT
M;P1X#^+?@[XH?&3QD;M(=*L?"OAR#77T30)WS\TGBW5]-O=?>)29)O#OA/47
MMC;3ZOIM[9^;_#WXF2:IX4_9_P#B!K^EZKI/C77?#G[6?Q:U3P=+'!)J%G;>
M'8[W3KZ*Z7R"L5^\#Z?IF90UQ]HEE>)T*CR\\VQ609]A<?D,,12QU:-5PUDI
M23=DFK-?::UMND]#FIX+%Y966+A.5?#QDI[)QBHN,KK3I:_W71W_`(S_`."K
MO@;X5^,/%GPPL/B#\!==L?AQXEUWP%9:WXE\"^)$\1ZS:>#]4NO#UOJOB!-.
MU_3M/36]1ATY+O55L=/L+-;^:X%K96L`2",KT\?"'X0^+0/%>H_#'P->ZAXG
M`\0W]Y/X8T6ZGN[S6O\`B975S-<M8.UQ+//<O+).SNTKNTA9BQ)*_&7X>8F+
M<57JI)M)*3LDFE9>]T5[?+S/IUQ72:3YHZV?V>O+^=_Q\C^>C0/%?C;2_#GC
M_P"&WB"P-GX@/C'7%E@ANO*NCXA\$:G9W&IZ?;++,?LQM46VU2WM929C:@_Z
M0)")E^BOV1Y?$_ACP!XCT^7]E3P7\9?^%\>+[[P9\*O%'Q6\07VG?"SPQX1\
M$^%O'?Q*U)O&M_X?M;C6=0U.\\,WE]X,\->"]'N8-6\0^,[W2+#3I!-.MM-#
M^USX0T?P=^T-\0-8BT$P3>)#X<^*<&H689X_^$DUG2&T#7M1AAE,L+_;]0TB
MZ&J6S1R1S0F!-J$LS_IM_P`$6/B3X/\`&5UXZ_9D\0ZKILB^$_'6B_%3P7X=
MU*6UL+O3_#.L07%KJUII40M%*:OI^N>'M'UC2[^T6'5=/7Q'9-:WT4YBFCKQ
M269Y+P)EMH3Q#EB*4\PD^9^WIU)0C255K[$6TU9Z75S7PXS6MFT<LQ]&O*-"
M4%.?);X9\JF_A>\6]?/N?EW^R_8:!^W!I5XFD>!O"W[-/COXU?!G7_$VG?"7
MPKXM\9>/?!FI?&O]G?Q3JF@:+JWB6'XE37WB3P/J/CSX;ZOK6GV6A6.L17.F
M^!R]^\5Y/#E_<_A3\%9OA1\5OC5\&=3T-M1\*?L^Z?\`#CXO)H*71.L-K6F^
M-M%L/@[+I,\NG6FDJFD+XB\06[SW=NEN@\%P3/<VD-G=-/\`U'?LT?L&?LS_
M`+(7ASQ?X2^$O@_7+[2_'GBRZ\5:U=^-M4@\3Z^L]YI%SH/]E:/X@DT^RU73
M]-@TZ]NH+<I>/JDGGLE[JEU!B(>D:'\'O@?K?C+Q1\3?">DZ/J7BO4H-&^'W
MB_Q-IE^^LBYN_AW=Z[IA\)7=JMPJE]/UK5?$5U=K<7,K+?,K+)"L91OPFAQ#
MQ-A,+F=+#3]@K4I86-.?\*,I0NJ:=WM=:W;\GJ?J6<Y'D6:2]V525VELU?X;
M]K-MZ::;G\UGQ9^+'AOX<>-_AY\#?CG\1/V>OAAK6L^.M9^)7BKPUXXTGXS>
M.-7^(M[HUB-"\%_#^X\!^"=)TWQ[%X,T/PG?PF+4]-TO7["R\-65Q<S^(+RX
MDN[^YA4>+])^#.@?M$ZU=_#7Q3X>\;?%F\LH/B!\'?B'HOB[P/HWPI^*Q^+.
MDWMFVGW"0ZOX>G\5_$;QWX3AFL)-3UFXT:TT+0DUS3;>>QO9;SZ;_P""C/\`
MP1M^(7Q:_:!^"GQM_8STGP5\/O&O@S4M>O\`QO\`$^W\>V7@?XT0^)+OQ-80
MZ;XNT35I/"VKZCJVJ:5HK3V5KH<NIII>H6BII[PQ/+]J6Y^TW_P30^"?[&O[
M'O\`P4%\5^$/%YTS0?C%I.@R_#/X8:5IA\-?#_X<:[96_A_PAX8T;P=I(ECM
M+/QGXXU2VNOB+\2M3LO+/B#6&O-0L;71+"40+Z>09SG6"Q='%X6KB(YA4Q%&
M>*Y7>=5*M!R3O=6<59Z:OF:>B0\[X:R7+\#A*-"K1KT'@ZDL70AK7IR5-O\`
M?3;<6E:[MJUT1X3\"/VB=3M?@?\`!JVN"TT]M\*?AW!/-)`)I)9H?"&CQR2O
M*3F5Y'5F:0\NQ+'DT5^4?P]^-_\`PBO@'P/X7-GX\NCX;\'^&M!-U;>'99;:
MY.CZ+9:>;BWD!8203?9_,B<$AXV5LG.:*_IM<08Z24G@Y7DDW[O5V?Z_GV9_
M/#PF5W=I4[7TLW:UXVMKMM_6_P!;?MQ>%]<UOP?IOC?2YIH-8\*Z1K^G7]HD
M:W-Q+HVK0BXTF]N"BJ7_`+.UF`21MOCBCM;N]5D\R2.:'Q#]C;QKXH\'?MD_
M#+XE^%!;1VMU9:-H.N:;&=-T_4/&4WBNW'B7PQHNC:G=J;>WU75?^$<T[P_;
MZ9=HTM\([2UM;RRN9&O1^DVJV&GZ]I]UH^HV5IJ5GJ]A+HNJV$ZRR1ZCIET2
MD^GSB.:*X\F9'>#_`$>>WN!'(PBGCEV2+^/GC3X,3?LZWGB#7/$,^M^*/#'B
MSQW8:!X5\2Z)+-=:S:>&M+T#2KKP)J-UI=K;EM/\0>'DUWQ#!'=:9:VUW>2:
M?I<>G10WD<TEYS^),H9MAYY.L2I9?4IIN,FO9Q]BE*E!R2T2DDEJG\CXWP5X
MQCA/892ZC<:3A3A1OLKQCRKJ[K3?7\O[VGUNY\6>!(WTR2UM[Z."T@G&KW[Z
M=;6U[.T,EY8:M<6D5W-:S16#S>3#$\<MY<(OV6=`5%>$_L8>&OA1\-O@Y9_"
MOP)X]@^(UY;^+_B9\0?$,^KI?:%XBU76?B9\1O$?C+66NX=1M[*YU)=%U/Q%
M>:-I%]`88CX=M+""6&\O4EU"X_-[_@F%_P`%%])^(OB;P_\`L_?'067P\^/O
MBSPM9Z_X&.HZUGP]^T)\+/">JZIX;\(?$;X::G:1/HVO:[;W>ES:;XP\,KJ%
MGXOTB\T:]U(6DL5_8V</[V7&Y;6[NIXXTMI+)SJMW=SZ;#=6.GV:M/OU/6Y]
M-MM,LK&W5&N(XI->LYT12UQ'(0]?RI0RZI'%8Q?6INI2J02A.5J*IPE'E4>C
M2M>^MTD?V%.&*IX9U'1]C'%/EH^U7(XQE9:72MO=6U6FNB,G5+NTL(=3>^U7
M3=%L=*LI-0O]:U`SP:/I5O;Q&YE%Q.)TFG2-(S+<(DXDD6-A$R,5(_E&_P""
MG/[4$G[:?[0?AK]FBS;5H_V6?@OHUS\0?B9XPT;49K?_`(7'XFN--N9?%&G>
M&;5);J.TTCP=I-M/X)T:[FM[F]N-=U.WC@NY[DHH^^O^"G7_``4O^$_ASX5Z
MC\*OA+J]QXUU[Q#%K6K:QXVTF1X_ACX0\.^%YK>UU]],\2RV*+\3O$MC:C5I
MQI_@PZIH4-Y;06^LZG8VWVB4_@K^S?J.H>$K3P7CPBBZAX@\+:7X_P#$9UDW
M>J6&AWVGZAHFL^`/"E_J7VF(W8L?'-W'\3?%ME9/#;ZT^E6FF1_8[075M=?K
MG#.799E<7GV;8S!-33G"-64??DK-12NE9M)+Y:6/S?C'/Z628&OEM36HZ-12
MC?6HW"W*VWS-2V>MK,_8?PW\,O@]:^'=`MO^$"\/Z']GT72H/[%3PUXAU!-'
M\JQ@C_LM;_\`X2=/MRZ?M^R+>;5^TB$3;1OP"OS7N-1U*XN)Y[[Q]XMN+V::
M66\N(M6N8(Y[J1V>XFCA@$<,*2RL[I%#&D4:L$C14`4%?1_\14RQ/2C@4M+;
M;+EMU\OZUM_-2XGEI_PG+IT?]S\OT]3Z!DFF5+]EED5DM9V1E=@RL()&#*00
M58,`P((((!ZBOD+_`(*AW-QIO[$?[16IZ=/-8:EIFC?#R_TW4;*5[6^T^^@O
MB(+VQNX&CN+2[A"((KF"2.:,*NQQM&"BJXF_W"O_`(D?#>#_`/R6.&_[#<+_
M`.GZ1_-/^TOXV\9^'-(^$-[X>\7>)]!O/`?Q$U^_\#W>BZ_JNEW/@R_N;/P]
M?7%[X4GL;N"7P[=W%ZBWD]SI#V<TMTJW$CM,`X_JN\5?&3XO>/-%_8$\!>.?
MBI\2/&?@7QIJOP@LO&/@OQ9XX\3^(O"?BRSU/Q)H=GJ5IXE\.:QJEYH^NVVH
M6EU<VM[!JEG=17=M<3P3I)%+(K%%?@M3_=\=_P!S'_I<C_3_`(X_W;)/^PC"
M?^G*)N?\%B[:VM?B)\)]!MK>"WT.T_9M\516FC011PZ5:QP:OK*01V^G1JMG
M"D*HBQ)'"JQJJA``H`Y>/]QH7@B"#]S`GPWTW9#%^[B7_0;;[L:;47H.BCH/
M0445X'%G_)*9=_U]H_\`IRF?RCXP_P#(]E_B_6)BT445\$?DCW^:_.!__]D`
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]R96DR+FIP9P``````````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#$Q-S$Q`#$P-3$U-#,S-S<P`#`R,S<T-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#_V/_@`!!*
M1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!
M`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!
M`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F
M)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$
MA8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4
MU=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!````
M`````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&
M$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W
M.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2
MDY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KB
MX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/@CX@?$/3KS_@H;\`_$
MND>+[NZ\&7GQU^.WP.T^WM]96Y\-66B_!7]GC]F?Q)ID\"V]VVEP7EOX]^)?
MQ5MI_)8):7=Y-$EO:ZC=:H;C]V/VZOB@NF?L?'XR:)J#V5W/X7^'0AN[2YV3
M+CXQ^!/!NII:3VUPLC3QZ'XPM&1([DLD3H9/W#HDO\?G@C0+RR_9YNOB1<?$
MOPG:?$#X*^./!7[1&A:=?>(-)N;A;WXX:EJ/@KXNSRZ;%=SWK66DIX?^%*Z@
M'L[AKJ;Q1I46EV?VFWOQ7]$WPK\8>`_VX/V#/B+\,?`M[J4\VA^&O%&EV%K?
M0ZK;2Z?-J-QX@N?`C-<ZO'80M=V/B/X;Z'X8NO)O+BW.J>![R6\N1%?V5_JW
MZ!P/QE1SG"9BN5PS.CC<3BOJ]72=:GB%23E051\LXP=.HIQ@Y./NN22E%OX+
MQ!X"K</9GDCY:>(P<LNP*E4IU*-6-.M2N_WRA*3IRG1J4:BG5C'GYFDW.$XQ
M^O?^"R'B?XF>&5_9_P#B?\/+&^UG1O#NBZEJ'BY-)75;C-LMK\(?C#:R6\>E
M,(8Y)=%^$/BJSLWN)D#WVI%(24N+J:'Z!_;=\->'?B-J/C#XY)<6^KZ;\1O^
M":/[:GPVT:]@$4EC=^)?"-UX`^.OA:QN[I4N/,O[_P`,:?X\;24-W-*UK%JE
MS9P+;0ZC=)\^^/?CM_PN;_@G+\+/C=X=BMKL>*/AKX5U$2W$*2P7\GPU\?Z-
MX.\>Z%<PWL$8T^/4=!TSQ5X<NYRADLK7Q%=SVZWCVULS_-_P^^.&J_$/_@GK
MX,\$>*O$FGG7?V<OCWHG@/QOJJ36=LVL_"3X@^`_&_P9;5E;=;02IK^A?%KP
MU;W%G:7-YJ45U;3HIDFLYYH>3BMX>OE.8X6C*,J^%HU\3RZPG##8N4Z:JQ<E
M'W(."DU%OD:3E%;E<.4ZV$XERK'/#5:V#CG6&I*<:4JD)-4L)B9TVHQDX3G3
MJ6]Y1<K22;E3DH_*GP]\8^+/C5^P%^T+^R]XNUSPY8^+OV6KC3/BQ\%-'UV_
M2UU3Q#X4^%-I%JWP=\:?9;VXFO\`58-0\&ZGXF^''BFZTFPM[>]U#21I=K>1
M6]M/$O(_L/?'#QA\.5TQ?#FL>(M,UO1K/2_$7AC0=:M==TBV\*>%#_9^I6>G
M:E?Z%<VPNH/AEXGTIO#/B^V81_\`"._#OQ%X4\'7)MM3O[F%_-M;L_BEH=EX
M+^-7PR_9X\1?$*^L_A)J?P9^,.L3ZQX<\+VK?#/67^TZM:V^EZOKMIXTU*]\
M/ZS8>%_$?A[5;'P(T%]<VUYH]MJ(_MN_LYOF;P5<_&KQ%X7$/P_\#2ZEKOAK
M4-;^,WA'6?#OQ6\,R:%J7AD6<%C\3O!&O76I+H<UUIGCN;Q+K.NZUH:2Z[J.
MBZ=XT%WH\\Y\)Z;)IGXGDGB/B.;A[B2O5HRG##?V!Q7@76I5>:G@YRP\L55I
MQJ3BGB,+[.M:7[V%2A/GC%N"?]*\3^%5*&9<6<*X+#8JIALQ7]O<&8Q8+$T7
M*KBY1Q$,+AI5:%.55T:\IX=2IJ5.<:]*<9RH\\X_VB^'/^"V7PHT7P]H.C^,
M?!6O7/B[2=&TO3/%5Q97OPCN;.?Q)86,%KKDUI<W>O\`VNXMI=3BNG@GNO\`
M2)8F22;]ZS45_&]#^WO^SUIL46G>.9[WPUXVT^-++QCX<E^$LOB:7P_XIM5$
M'B#1)/$=OIQ@\02:5JT=W8/K<!,.JM`;^,[)UHK]PAEW#%:,:T.(,J4*L8U(
M)YAAE:,U"44TZB:LG9II;2VZ?SH\-Q/0DZ,^'\U4Z+]E/_A.Q'Q4W&$MZ5]X
M]==[];5O"L_Q]^)GC?X1?`/]F'X`?\+`\=3>%[V^\+7.IQZ_:^%]0\.VOA>Y
M?QHEY=C0]!-[#_8$^HZA<0:=-?I87<>@ZZ6M)=/@O(O-?@U\2OB%^Q7^U-/X
M(U[P,/!'Q#U;6=>\"^./AAX+U^U\8:#J>FZ5>W5EKFE>*M(U6[T_Q5\.M4AU
M/3]+UKP%<ZIX7N-1\4Z9)8[=0BT^[MDN?UU_87^'#?"K]J+X8?"/Q)KEWK^H
M_"[QH+GP7\4+>SO=`U'5/"T^B^*_$.@:EX>U<7D-S:R2:-87/AK5KK0M:D60
MZ1?Z=+-?1/9VMU^BG[0?_!)KP%\<OVUU_;L'Q/L?"NMQ^*/"OC#6_`.C?#/?
M-KOBKPOI.BV!UU?&R?$'29M)N==N?#^FZKX@MXO"&I"]:.XMY;B5;VYFK^0,
MNXORO@O'XNECL%C<ISK+<5B:D:OM,14>)JRF[5.:?NRIS2UIJ%H\R2>MU_;G
M$/!>.XZPN5XI9_0SOAGB'+\LG1P\L%R/+X*A2I0PZIT(1FZM&46YS51RT7/%
M)H_(WX$?&[P!^S#)\2/@3XE\5KXG_9A^(FO:CXW^"OB*=[6.?P^/&&BV]Y\4
M_!GB:[N&&@P^(H)?$^CI86%CBT35=)O1;P/.\\UROPCN];\+>(;[Q-IMC93>
M#/B]X)N_`?C/5(;FU33/AY\04U^VEL?%@L8K)[8^&O#6L1IXN&I75Q#?67AE
M_$QN[.\72M,LY?T0\!?LI?`#XS_M#_$[]C>Z\/V.I6/B#P;#X]\,^*XM'MKO
M4/A!XP\.+ID.J6RRSP(/$/\`PF6CZ]H#2+='3[+=X+CGE^T7=S<IIOW;\*_V
M`OA?\)[;Q1X8BTV/Q'9>)WAOKO[8GV?2M,OFCN+'5X-'\.R7>H6^DZ=JL2VL
MMWI=KJ+:>\IN=ENGVAW;?B?QFQ6;95E.:+`SAF$5C<'5C*#CA<WRC&1A&>%Q
M%-J$HO#IRE0G%MU&U=QT,N$_!#*>',\S[(\RS-5<LJ1P&,IU,/-_7\KS7!SJ
M5,)CZ%&=U..(C-PQ5"K*$J4)<LKN*/SR^&7_``38_:3_`&H-;&J^%=;^'_A#
MX2ZKX;N(-:\5_$_2[+QUXL\(:OK\]MJ$T7PR^&4[3>"+*^3P;?:9J%C\6/',
M?BCQCJ%T-GAK0M"\/:C%J+?R>^*?A'\?_AQ^UGXU\$_">7XHZEX^^%7Q,^(7
MA[4-6U[1S!JFJ?$GPC\:/$?P[MX=`A\*P:"]M9^)9+/0+*ST/4I(-1OM;U6\
ML8],DTB:V!_T\_A+\*Y?ASX,TVS\&(/#&FVUC;VT,%G>:B5,<5N(+:'RC<Q+
M!!%"%CC2/SDMH(H;>'=%$H3X9\1_\$Z/V-_"OQ'\;?M$ZA\,XM<^)?B77O$G
MQ2\2>)-3\;>/M1TQ_%=YJ4OC/5O$5WH\OB(Z42=8TI/$3)>P/&-0$@:;S+@2
MGS<KXOPV59+3I5,DE1EB(N5*-3#TYT\32Q',I2C"*E4>(J3G&,DVW)-2NM3K
MQ_"&59MQ)C,7CLYK8O#X:#6%D\35HO#5\/[*2ISG&K:AA,/R.=-49PMR*,F[
M67\8OQ'\%_MC^%OB'X\\,:]^RCX<^(6N>'/&?BC0=9\?:9\(?BIJ>G>.-6TC
M7+[3]1\8:?J5EXTLK/4++Q->6\VM6E]:6=I;7<%['<06T$4B1(5_1/XU^.]U
M#XR\6PZ'9Z:^BQ>)M>BTAW\1:G:.VEQZK=II[-:R:,\ELS6@A+6[LSPDF-F+
M*22MHX?Q'DE*EX=T72DDZ;<Y)NF^5P;71N+O;IMUUZ.7P?6E;QRS2-9:58JM
M&T:JM[1+?1232U>B6O5?B;\*/C7\5O@7XS\&^#]%^)-D_P`%=$UC7]1F\*>+
M](TS7O!GPR\57^F6>IZ5JM_>QW^A>(M+TCQ>^NZ?;H(?%-IHFA:W#X>U/4K.
MZT[4+6QK^NSX1?$+2/C?\--%\5V,L-M-K6EW,$T=K>PW%YI6O1-+IE\MQ@1I
M#,)+1GCM;B)9)+:>&2((27?^*&VTSQ5\1_"E]XJT2#0/$7QE^$NDZA8?'3X6
M^'=+O!HOQ3\+:K;V[>'[C2M*N;%-7UG5M'T/4;[4K1M?CLH=/N=0\5Z-8W>K
M:9-#;K]W?L<?M\S?LO\`_"$:WXPO]5U?X)?$D:M9^%_$OB36[75=836_!J7;
M>)=*\92:7?3:!!KVE1^(M!NM-N4:SN]?\'WEIJUM;:G%HOB*_P!*_0OI%<`5
M^(*U/C7A"I#%8>IAXUL7@(/#TYRC.-*I3QN$JM>TQ"G#GIU\,],/*A&:7-B6
MW^:_1S\0,!E&"Q?`_$O/E^*IXNO/*,UKSG+#+%PJ1IU\HQLIOEPS]I[.5+$Q
MU7M)03LC[^^`_@W]L']AS]M7XW^+M*\$:K\=_!O[18\#P77C>UL)=+G^&S?#
M[PYXL2TTU[."+5%O=+\3:IXRO8+R6-M+FTK44L7NVO+.YMX5_>7PAKFL:QIE
MMJ'B;PU_PC>KRNZ76ER78N9[6W$9F^TNZP6_RM*6&3$N"H&_:2M?,<7Q-\#_
M`!_\&#6M)U7Q7I5GJ:032'PEXEU3P/X@M)-*O71(K+7?"VI:;J]MY;6C&Y>W
MOIH)X6;R)7MIPS]9\.O"/A?2Y+VYN-5^*.N2%8?L47C;XR_%+Q/I\$D-Q:W-
MM<_V/K/BO4+)9S<P12O>PLEVZHT`E2WEGCF_CW&YC/'SP]#,<7.C6P.$I8&C
M1A25*FHT:<:477C3Y:<*[5./.^5-S3;NVV_ZXQ65XBA1Q-3`\.X:+KUYX['Y
MK]<]I5JU<=+V]2-*+UJT(3J3]DU)QY'[J5]?M6_\0:GIWARXNH+F34&M;$W-
MCI44MO#/J"V>GFYM["V:6+9')?SG[+'/(\FQW&R,E:_&;]N_XH?&.3X$:AXB
M\4:KH'P*T[2%NYQX>BNK?X@?V7J2Z-?6EOXR\5:K;PV;WEO:7VL6NEIX2T=F
MN-6U2.QM=`NY=>OM/L+S]/\`6=>EMM'*Q2*T]S*;9L/(PA6:&2XNKP%V!-NA
MR\CJHDWODP.Y>5_P'^/7QW\'?'K]MJW^!=A]O\3Z/^S7H[_$#Q[>.]@OP_\`
M#_C#PYJ>JWEO_P`)#/:W5Q<ZGXQ^'/V9_'>A6-_:WOAWPUXCTCP1XE.FZGXC
ML8KK2_T+PORW-.,.+<JR;"SE7C3K4L36Q55NJ\)A<*_:5)1E*[I1;2AHXIZ+
M4_(O$&67\)\#Y]GV:)0E##UZ6"P5&U-8W&XMJC"G.DE%5DG5=3EDI)<K:5S#
M\!_LV?MD>)_`_@SQ+IEU^R['IOB'PIX=US3X_B;8^-O!/Q)CL=6TBSO[1/B#
MX,M[UX/"7CA(+B-?%GAB!WAT'7A?Z5$S):*25^8/Q1_X*-?M(Q_$SXBQ^"/%
M.M'P8GCKQ<GA$W%W)-.?#"^(-070//FDGFDEF_LH6GF2/-*[ON9I')+$K_1>
M.4X.,8QYL2W%*-TYV=DE=:[.ZMZG^=CS##2DY/!0NW=WP\;W;B]?=\U?Y]D?
M#FF:KJFD?\%:?!.I:3J5_I>HR>--7MI-0TZ\N+*]DMY?A!H<4L#W5M)%.\,D
M<\T<D32%'2:5&4K(X/L/A+3=.3XV_P#!4;X;)I]DGPZN?AI\5-1N?`*VL"^"
MKC4/#VK>'_$V@7T_A41C0I;S0_$DDGB#1[F2P:?3-;=]6LG@OV:X)17Y)DW_
M`"2V5_\`8JH?^DQ/V//_`/DK^(O^RBQ?_IQ'Z"?\&]VLZQJ?[.^NQ:EJNI:A
M%9:I%#9Q7U]=7<=I$;CQ.ABMDGED6",HB*4B"*555(PH`_J*LN;>U)Y)-H"3
MR2,OP2>H]CQ117\.^(7_`"4/%G_8SPO_`*7,_P!&>`O^3?<(?]@#_P#3%(\7
M_;/U"_T;]E']I;6='OKS2M8L?@?\06LM5TVYFL=2LV'AZ^<-:WUJ\5U;L'57
M!AE0AE5LY`(_EA_8%1(_@[^W3<1HL<[>/_$%JTZ*%F:VE^'/PA>6W,B@.8)7
MGF>2$MY;M-*S*3(Y)17[/]%#_DHL3_V"UO\`TL_ESZ5W_)+X?_L(RW\JASWA
M33=.G\+^&YIK"RFFFT#1Y999;6"226233K9Y)))'C+.[L2SNQ+,Q+$DDFBBB
MO[AEN_5_F?QK#X(_X8_DC__9````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O<GEU+F=I9@``````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S`W,``Q,#4Q-30S,S<V-P`P,C,W
M,3<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M1TE&.#EA(``@`/<`````````,P``9@``F0``S```_P`S```S,P`S9@`SF0`S
MS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9_P#,``#,
M,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`
MS#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9
M,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_
MS#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F
M,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,
MS&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS
M,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9
MS)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`
M,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QF
MS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_
M,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\S
MS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9___,`/_,
M,__,9O_,F?_,S/_,____`/__,___9O__F?__S/___P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"P`````(``@```(_@`!!`@`H*#!@B0`D""Q8B&)
M)RH0/EDH<&!!@@03DC"@T,#"%:2>&'"B`ED5$BI4;!PH0$!!EQ01`O"X0H63
M/*H8DJB2;.&3/`L#M`Q@@%6@%0@31E1((L^<9P_S.+'F9$6>4E59"F3%RDH@
M*RJ93E1!RLDSE:1(E`)*`L\39"566`QTU-JU:W1K+E3QY$E:%:6:Z@&@!RB@
M)ROD`K"2V`JKN]=*6;%R4B5$$B$1DQAU^0^)P8NM%%SQ&#+D)P%0_JRLT`G#
M)P`4T]68N`K7N]`".0D$Y8F>9'R?G&RHDB"`0*P6KK*6IZ"*QX!4!%J[*D^>
M)ZNJ."%U4C/!*]?X_CJ3@ZQA=8-JN5;18^B:$T"K'*K("'Y%84^J\E2Q!HAQ
MP2K7/$.*7<\D1I$!`PT$7E/(D-*)$WK8=0TT#0&PREVL6`,;"0DFF%!]3S"7
M!REY6/.,'ERH4`*'>I`R2A6Q-=2A``2Q<$T5*D"3QS.K.&.--:5`P\<*@BP$
MB#5(0+''%0FV)$!"-B:WW#/'+'>7-5\Y\40GU6AH12G1R,42C0:T@A=A`8Z"
MS)776$/*'@(^`\V`;98@E),)80B`"GF,XLR`$E[Y3"?+02.A7$["A"$)-W4R
M*"EM0@;-**0<TZ9=K-B9Z$"S7+,*GYV,8HTSCD+F9C("_OB,-="TTD*B_@5!
MYD0G)%K3H(\_6H/?JFV2$A(KLV#A)%&X;>=@-0)VXHRAT#B#!!6>D`)(,J1(
M=U<K"#Q)`H;;/4/>,\B,LJJJI,C1+7,,0=8*"\1.N&4UM#ZCYC/5/#&'K\\\
MX]0S?5F1"&2)>'37*G+(&6HUI"!CC2I(_,$55WI4X6U:5MPURRPSW15(%<@@
M:PFXXKJY`B#(!?+$B3ON9MI`K,CR3"GB/C.'$ZN$BPR]R>2:KQS.\%LQ9!P!
M`DTI5`HX"A(['N,)I2<])"`)-U<!GL4*!;+*J@D?0PH>2.!1:8.K9GA-63]&
M;-I,@8QH(JO.2.7$N4""7=B/G:QP-F%4R`D9("M.F#N'37G((8=UYM([Z'.0
MS220X@<M;I!QCC_>>$```#L`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W-E>'DN9VEF````````````
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#(Q-C$`,3`U,34T,S,W-S``,#(T,#8R`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````$=)1C@Y
M824`)0#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`
M9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`
MS)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S
M,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68S
MF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F
M``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F
M9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F
M_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9
M,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9
MS`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,
M`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,
MF0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,
M_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___
M9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_
MS)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````A^00!``#8`"P`````)0`E```(_@"Q"1Q(L*#!@P@3*ES(
ML*'#AQ`C*@2@@B"`BQ(1JE"1*M4*%1]3-4NU<47&@1R;31N9:I3(:2M'FLP(
M(-5*DAMSOEP)DN;(C:*,"34F:J/-:20E4ASE)"BSIU").GGI$2)'DJ*@:H5:
MM)G7F0Y5>%5AC-G0IV>-`?#:#&S#JV2-Y10ZEZY(MPM5N%21E5FI/:6>_@UL
MMFC5L!T!E/5;(JZ*$H3-<L2K4.\HQ8(WTE416>[AMZ,N+S:[6*A6SY0G8D6[
MU2Q:PZD3PJ4[6O+0E+$UCJ7;]VG1H6N;57R8DB\S44V%(L_:=:Q5E:F2%\T9
M%/G.SPS%PL0IJKMWHS"W3^<VJ!WF3XHEL:TX^A-B3;;-+A^$.Q[AQ?L`$MX_
MR;^__X/X8;.?@`3F1Z!2%B68GX$&1A0@1@,Q..!)"RJ8H%+[#5AA@/]UZ.&'
M('H8$```.P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V
M871A<G,O<VUI;&5Y+F=I9@``````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$R
M,``Q,#4Q-30S,S<V-P`P,C0S-S4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````1TE&.#EA(``@`/<`````````,P``9@``F0``
MS```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9
M,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_
MS`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F
M,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,
MS#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S
M,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9
MS&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`
M,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EF
MS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_
M,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PS
MS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,
M,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`
MS/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9
M,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__
MS/____B_)```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"'Y!`$``-@`+```
M```@`"````C^`+$)'$BPH,&#"!,J7,@0VXH5*B"N:*CPH0H_J%!)DX9*(D6"
M#ZE@W$B29,>)%*N(+,FR9,>&*OVTG+F1"LJ$*E>V]*/B8DD5`&X:7$%%9TN@
M``#(W)@T*$*B?I:V;`I`A49I2`$<A&K4)54`5#;Z:2I4(%2I1ZFJV(@JZU"1
M:%F.I4J22M."7..ZS`K`I-N!1.'2%-MT;=V[@$5VG<G39TD_=D$JUCNX)2JM
MB057WHS9;-&H,WMNYECVK%Z@5P>K,*CBL]ZQ5@>W?0N9LMW8EB,2#!3(2NO:
MC*NF9@MT(&_>OB?3;&PU8T^GV([W[OU[L4DJ/;/;-#[=2N_DFC<NO]S=_7MK
MN)1-5CDHW;L5W^?#LVU;UF#[]T#/U\;^\*/`X^Y9Y)%_!!9H($$!`0`[````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]S;75R9G,N9VEF````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,3`Q`#$P-3$U-#,S-S8W`#`R-#0Q,0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!'248X
M.6$@`"``]P`````````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_
M`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF
M`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_
M,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF
M,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___
M9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F
M9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_
M9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-F
MF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_
MF<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!F
MS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_
MS)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]F
MS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/_
M_V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF
M_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````(?D$`0``V``L`````"``(```"/X`L0D<2%"@%0`($R*T
M4K"A0VP+65V;2'$B*P`,'S9$*+&B1XH7,VK$V/&C28L`1I8\R?):RHTM8U)\
M.=#*2IDL5Q`$(-.*%9DT;<ID=1'`"I8T><:4Z-/G"H1'*^H4J!0G2**LGD+=
MV5-A1:(T!P*X^?'@A;,7`*1-Z+#J2;-HSZY`BQ%F480>$=)5>^'IV;H[+\:%
M>@UNVHEX7?XMJ#?N6JU_*U95&Q;BW\:/^;J5G)8Q6@*-U?H]C)BG0H54XX)V
MK+FT:<R+^7YVW#?R:=IG#\H>W'ANVA5S=[/6C7LW5-RT&>K&#!MY\9T$!D,2
M[ISN1NG3G9\&?)TNI.S511\^-+QV.VN-8A-6CRO^H6SUR!>B3TU[.]OY]*M7
MGA\0`#L`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A
M=F%T87)S+W-O;FEC+F=I9@``````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(Q
M-C8`,3`U,34T,S,W-C<`,#(T,C(P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````$=)1C@Y81\`(`#W`````````#,``&8``)D`
M`,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``
MF3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`
M_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S
M9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DS
MS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F
M,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EF
MF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9
M`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF9
M9LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9
M_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,
M,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,
MS#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_
M`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_
MF3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG_
M_\S___\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````L`````!\`(```
M"/X``0@<2+"@P8,$+P`04+!``0$0(PIPZ!"B0&08D0F\4$9@Q(420T9\:!$`
M1H%E.I(4*;$`P94E-ZH<.%&D2P`[=@B$65(A`)<Z?]K$>>U:4)X;?P+5R?/F
MCJ)&A4I,ZO3:SI9$H2;:N9)J5JLP@18%4'1KQ9X_`22"ZG&A6*L"KYGM"D#A
MS;4TTY(=&W?N1P`J&>(="!<J7+)^T3Y4>]BP8<*)&=;=R=BJ8\>(K_Z]8%?P
MY<]RE4ZMZ_,FWX*.YQI4Z$%H7),9->XM2S"8[:2M"\;.&#>T0-O!3@HTL%?W
M;MD#C\LV0/Q@<.6[#QK(;?`Y=-X:D;?V6?NZ<M@#.5QS!`#<^W?AQ#EV)&_^
M^,7ES5/^MGZ=(&\`TSVTEC^_?<;;`%#'&7CST8<1<,`5)-Y%!0Z$((`%2;;@
M2;LE&"%YP4VVD4(40H>@1PP]IR&'V?EWFT4B(J3BB@4%!``[````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O<W!E961Y+F=I9@``````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,T-``Q,#4Q-30S,S<V-P`P,C0S-S0`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````1TE&
M.#EA(``@`/<`````````,P``9@``F0``S```_P`S```S,P`S9@`SF0`SS``S
M_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,
M9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`
M_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.9
M9C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/_
M_V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F
M9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,
M_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS
M9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9
M_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`
M9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF
M_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_
M9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S
M__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,
M9O_,F?_,S/_,____`/__,___9O__F?__S/____B_)```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"'Y!`$``-@`+``````@`"````C^``$('$BPH,&")+`I
M5`B`E+.'I"(^G$BQ(D52"1<"H*BBHT.+(#DNQ+9Q(JE1*@"04/$Q9$6,&IV1
M2KGR#T&6+BNJT#B3Q$&!.'-"S$@"XJB?`%0(G;B3Y,,5*GP>)-$R)\R2,H_^
M#"IT9\F9`TGDZ42VTYR52V7Z?/A$JXHY93OE63&'*T29>!\*I$AB!:L58\GZ
MI;NB)2FH'544=K9WHM]K?P6S@DS8X<P\F#.OT&I2H%\5<CU'SA-5!6:I8DDW
M/CR0U=N4`EV3)7V:8&J!$>F>#3NGM>FX;WW.Z4VB=U+>J/-(%4AB95SES8O#
MMCGP;6:SS.<$CCL[SYS-0-_"SH9=\.QOX*0],FXXLVR>J=H[/K?;^'PG%8`*
M7R;-7>YBBJL!1M9*N6W'71Y/5*570Q!U=)I\_<VV&4C,X722:08>&%US])$`
M"20;1G=:<:AY2`LDM)S8UT<`8$-"BB=^"*)*'R(!"8TI0H($C#<JQ9B+*-+2
M'(HWOIBCB2?:"&)S*CG4(I`RVC@D+3;20N.0,XZDPE$+1??AD36"*..'/HVD
M4)EF8CEEBBIM:.:;;[:)A(<>@@CGG7AV.6=&>8X4$```.P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M879A=&%R<R]S=&%N+FIP9P``````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`W
M-30V`#$P-3$U-#,S-S<P`#`R-#`V-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#_V/_@`!!*1DE&``$!```!``$``/_;`$,`
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_`
M`!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&
M!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4
M,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)
M2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.D
MI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R
M\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U
M$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)
M(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA9
M6F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JR
ML[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_
MV@`,`P$``A$#$0`_`/TA^%__``0\\0^'!#;:/XX\#Z=K$N)==UG0?"_B7Q-X
MKU^[DAC6ZU?Q;XKU,:%J.N:I>8(OM0U?6O\`2)762*&$2>4/HY/^"'WC&4R3
M2?'.Q7A2(C\,K:5N%P5Q_P`+2A@4#&!MW97&]BVYC_1;H^D0Z7:06L"*J+&!
M/\N3<3`)OGE9RSEB5(52655.!@``?&?[3O[5_C?]G[XX_LE_"KPI^R9^T1^T
M'HO[2OQ!U+P)XO\`BE\&O#>HZW\/OV9],TS5O`M@/''QQU5;:71O#OAJ]L_'
M>H:[;SZG>Z.]SH7@+Q?)IEUJFNVFC:)<?B.$\$N'<1"%;/Z^98['55[2I%8Z
MI[.@U92IIMR4G=WYJ:H05G^Y;LX_D^/\"/"3$8R=5\.9CCY1DXSQ.<<4<28S
M$5]4U.+IYI0H8:/>A0P\8.^O+:Q^/US_`,$:+S3+HVMS\?I[2X:,'[/+\'KV
M%6#-@O%-;?%>XMYX5*%1-$TD9)Y8';NKM_P1C^(%[;,?"'QAT/6%1G#MJ7@S
M4=!B:155CMGAU[58&R.#F0S!E`90AC)_HM^(MA:3^'Y+J>.2*6PELWMWM8T:
MX1I+J*W,<8+Q(8W24B2-G$;!%)!*KCYW_;!_:;TS]B7X&77QAD^!_P`?OC]8
M:7XF\*^'O^%8?LQ?#6'XH?%*_'B/5X-*_M&U\+7/B+PO;'1K"XN(Y]3U6XU:
M!+*XFL[()>2ZG;VTOFTO`G))9IB(U9XB.4PA"=+DKRG7DY-IT^:HMTHIO[.N
MEVV:8OP"\$:V#I1I<'U:./G-PE&GG_$B@H1Y;33_`+6>LF^VC6O1/^?3QK_P
M2%_:]\.QSS:#8>!O&,5NK2HNG^+H=+OG=78*JVVJV\(0J521IENHA&"SQW=N
MT8N8_@7Q_P#\$P/VU/A]J6O?$[X9?!:Y379+5?\`A*?`EAXG^'NJ^%/B%=E8
MK0SHGA+Q3JNI>%?&"P//-;^)[/0G74[A!8^)[/4K2222/^['P[J\?B?PSH'B
M&/2];T5-?T/2=9CT?Q'ILNB^)-(35+&WODTW7M'N6\[2-<T\3BUU/3IV\[3[
M^&>V<^9"37E_Q.\*7B6=WXD\,6FFCQ)%8W$*+?R7UCIU_=3O9VVGG5=5TR*Z
MN]+M(IBL6H:A;:=J5U;6-Q=W\5G?I8R:?>&:^#6!RG"UL7D.-QU1<C>+R[%2
MIU:&*IM).\6E'FHJU:/-)6E3C9W/(RSZ./AU'$RI87'\39+#$J=.I"EF6%Q^
M7XA5$XJ&.P.89=7CB()-*F^95H5%3J4Z]*K%5H?Q5Z7^S_\`M,ZEIFG:C<_L
MM?M':9<7]C:7L^FR_!_Q0\NGS75O'/+8R/`M[`TEH\C0.T-Y=Q,T9,=S.A$K
ME?U+^!OVC/@-X]\$^#_'.E^/=#TG3/&?A;P_XLT[2O$]W#HWB73+#Q%I-IK%
MII_B'1[^[GOM*URRM[R.VU;3;R::[L;^.XM;B62:)W)7X\^#Z',_]GJ+7;V.
M&:6L=-[O9?TT=K^AGP(VVN+<V2;NDLJRJR3L[+]P]MMWZO6_Z3AB`N#D=QU'
MX'K[_KWICA2[_O)-S!``K8"C';;R0PR?FW!224VDDGQ31O'^H6-JMO>VJ7R1
M!4BE6=;>78J!55Q]EE4E=I`8'<P()(Q@W+[XCWDR,EGI\5J[@AII9_M)7(P"
M(OL\2M@=074'VY)_JFGQYD#P\:ZJ5/:\CG4POO>TCHKQBVN3F3LK*235W>Z/
MWJIPSF].K*FJ4?9N7+&L^5QMTLN;FNTNL6]UMMT7CS6H+6SM[#9;W-Q<W$,K
M6TJ0RAK>!FE)"RB1=[2(GEML.%5\$'D=A:20ZE!:WUK<.(I0LJR0M$PF0;OW
M4Y,;@QY:0;5*D,?,1E<*R_,US+<W5Q)=3S&6>3+-+(<F1B<\H%VQ*<L<)NP<
M#!ZC>T'Q-=^'6*1J;BPD8>99O)RN!Q)%,49E8.Q)CP$D``+*>GRV7^(D)9OB
M:F-C.&78B,:6'497EA(QDOWE2*5W.2?O;WLK;._N8SA.<<NPRH7GC8-U*KY+
M*IS*/N)O9QL[:I:ZM+5?1BY50JA0J`*%`P%"@`!0.,`8],=!P!7,>,957P]J
M<<RN\5Q:S6DD:(K^;]H7RE1R\L*QH[NL;R>=$P60K"WGM#CET^)^C%5S9ZJ6
M*D.L=M;LBD(2062Z.Q6(V(2`P)7*KFN)\2^+;CQ"%BCM9(=-"NOV66;RY;I9
M5$$RW;I'*1"L+S,D&'2:3RU=HP-Z_1YMQMD-/`UUAL7+&U*U+D5.ESQG#GLM
M.:*6E[R=]KK8\;!</9G5Q5%5\/4PU.-12G4DX-6A[RVD]VK+JGJS^--O^"?'
M[>/QQ9OC5\-]+\2^!?AW\8"?BCX"\$ZY%XITK6O!W@OX@'_A+/"WA76-+6S`
MTW5/#VAZO8Z1J%@`!9W=G-;CB.BO[!V=I&,C#:SDNR[B^&8Y(WE4+X)QN**6
MZE5S@%?BKS.FW?ZK7U?\Z[Q[_/\`'S/TA82=E^_I]/\`ETF].7KSZ[;];+NR
MKOD4E0,IU!^4$G^?<]J^2_VM?V[_`-E7]A+PGX=\;_M6?%K3?A9X>\:>(AX3
M\)O=Z%XR\3:AKFOK92:A+:Z9I/@+PMXLUA8+6TC:;5+^\THV%C&UN3<^==06
M\GT1X,\;>&/B'X:T;QCX)U[1_$OAGQ!9K?Z7JNE7L<\-Q;R)'(F(F,=W'*D<
MT?VN"[MK2YL9G6UN[>*<[!^<'_!4_P#X)<_"[_@II\(M)\->*/$&O>`/B]\+
M[/QQJOP`^(^DWK-I/ASQ;XRTS0;75=.\;^'I-'U%/%/@#Q-?>#_!B^*=-LGT
MWQ!!;>'HI?"6MKJMS?Z?6.5?V=B<5AECL0_J-2HHU:^%@ZCC=7NE:=DGNVI)
MK2UWH\1BO;8+V^65</BIU(J5&5*O&K&:\HP49-;7:DNF]U?P:?\`X..O^"2L
M%V]HOQ]\67+Q-,'\GX'_`!MPRP3/;2A&G^'EFH=)E(^8E64$J&!!'VK^R;_P
M4V_8=_;EU/6/#O[-?Q[\.^,_&.A6D%_JW@;5])\6^`?&5OITK3J=2L?#GQ%\
M-^$M0U_2[1+9I]8U;PPGB'1]"6>W_MG5-/>YAMH_YEOV9_\`@TXU&2/Q!??M
MB?M+V5E?237MOX/\._LK6.I>)].,<LMI=6OB+Q-X\^+/@WPP\-W=1MJ!7P-I
M_@.1?L_V"_A\>W"W,EK!Z?\`\$Z?^#=+]I']D+_@H5\+?VA?B5\;?@KXQ^!/
MP7USQ3XH\-2>#I_B+'\3?'.N7_@GQ'X>\$E_"&J>`E\*^%'TG4=;%[XZDTKQ
M]XH)TK3KK0]-N=5N+J^@TC[K'Y/P`\-B?J6<XF&,HX>O5P[J4J;>+J45%JA3
MY8I2FF[RM=N+5K;OY_#X[B2E6HSK89*$VXSC*,W9I:N,>;:ST3OLUL?V$1.L
MD,1+LT3)&ZG<XX(!3'(8#IA>`!P1C(JR`JC(P-P')P<X^N2.OXYYJJ)5D!;<
M@.UII=KB2-(XU,UP\<T89)1'$LCQNH"2[5(9%;<OS5\=?VJ_@O\`L\"S'Q`\
M337.OZA;O/I/@3PK;1:WXQUB$+"[&"-[RQT+2(5BNK6[FN?$NL:1#]E$AL7O
M[I1:M^:8C%8;!T)8K%UJ=##4E&56K7J1HQA!R4;RG-.,9.]HIIN4VHI79[F,
MS'`X!8=XW$>RJXR=*CA</3I5,1B<1B:\HTZ&'P^'HJ5;$U\16G&CA\/AX5*]
M:I*%.E3J3FHGT]MN&^98+AE;E66VF964\@JRQD%2,$$$@CD'%%?@'J7_``5+
M^)KZCJ#V'PL^',%BU[=-90WY\57=]#:-/(;>*]NX-9LH+J[CA*)<7$-G:133
M!Y([:!&$2%?!/Q5X$3:_MS#Z.V\'U2_GMU_K6WZ9'PH\4IQC)>%?B8E)1DE+
MA*K&24E%VE&6-C)-<VJE%235FDW8_,JP\<>-?A_J6F:YX#\7^*/!.MW%U;P3
MZQX1\0:MX;U6>">14FAFU#1KNRNY(ID1$EC>9DD5%5U(4`?UY?!^66_^%VCW
ME]))>W<VE6#S75V[7-S*\L<S2O)/,7E=I&)+LS$N22Q)HHKRO!__`))RI_U]
MI?\`IMGYGQQ_R?WQ`_Z]X;_U/K'=V$<<K[9$212DF5=5<'E.H8$5F>*28;B%
M(3Y2[5;;%^[7<O*G"8&5/(.,@\BBBOURE_O6"_QS_.!O4_WZMZT__4O`'Y+?
M\%9/B%X^\!?"OX6W'@;QQXO\&7&N^+'TW6Y_"?B76O#LVL:==>&_$7VFPU67
M1[VS?4+*XVKY]K=M-!-M7S(VP,?B7X:`OK'3KR]`O+N\N@;RZN@+BYNC+<A9
M3<SR[Y9S(I*R&5FWKPV1117\^>-W_(OH?]Q/_2YGB_1D_P"4L*G_`&2G$'_I
MB1]5_P!G:>ORK8V84<`"VA``'```3``'``X`HHHK^+S@Q'^\5O\`K]4_]+B?
M_]D`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]S=7!E<FUA;BYG:68`````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R,#(V`#$P-3$U-#,S-S<P`#`R-#<R-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!'248X.6$@
M`"``]P`````````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8`
M`&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9
M`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`
M,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9
M,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``
M9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:9
M9F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`
M9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9
MF3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`
MF<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9
MS`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`
MS)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9
MS/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`
M_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9
M_\S,_\S___\`__\S__]F__^9___,____^+\D````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(?D$`0``V``L`````"``(```"/,`L0D<2+"@P8,($RI<R+"A
MPX<0(TJ<B!"`Q8L8,V9<"(`6+4@@0XH<"8D-&P`).])BQHS31Y(P3:(TJ)*9
ML9<AV2#9*=+839,G"]:\*9(-)V,LC;D,Z=*HS($UI>$LB52:56DVI[)1^C3J
MTIQ5KUIEAI,-,VF<9`(PR8DLR:UGQ6*E!?1LVJ!KC4X=&5;NU;LSL>7=.]*C
M84MMK0(6:I(PS)"T."VF"=3DX[=/*[+E6KESSJ`*\R;VB[5E2=`<V;;T>#0I
MI].!&>:%Y!AH[(:S,:.&*+JRI<P31;.<3%$P6^+%C=M.SG@W<X$6GTN?3CUA
M0```.P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T
M87)S+W-Y;'9E<W1E<BYG:68`````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(U-C0`
M,3`U,34T,S,W-C<`,#(U,30W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````$=)1C@Y82``(`#W```````(```("``("`@0```0
M$!`8```8"`@8$!`8&!`8&!@A```A"`@A$!`A&!`A&!@A(2$I```I$!`I&!@I
M(2$I*2DQ$!`Q&!@Q*2DQ,3$Y*2DY,3$Y.3E""`A"$!!"&!A"*2E",3%"0CE"
M0D)*$!!**2E*.3E*0D)*2D)*2DI2&!A2.3E22DI24E):``!:$!!:*2E:0D):
M2DI:6EIC``!C*2EC.3EC6EIC8V-K``!K*2EK6EIK:V-K:VMS:VMS<VMS<W-[
M<W-[>W-[>WN$``"$"`B$>WN$A'N$A(2,``",C(R4``"4$!"4&!B4E(R4E)2<
M``"<G)RE$!"E&!BEG)REI:6M*2FMK:VUK:VUM:VUM;6]M:V]O;6]O;W&O;7&
MO;W&QK7.O;7.QKW.SL;6SL;6UL[>SKW>SL;>UL[>WL[>WM;GWM;GY];GY][O
MSL;OWM;OY];OY][O[][O[^?W[^?W]^?W]^__]^___^____?_____________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M______________________________________]E65@A^00!``#_`"P`````
M(``@```(_@#_"1Q(L.`_`Q<,*ERX,`+#AQ`=0IQ(<`&-!2[^?6#P@>)#`P("
M`""PP.-$`A````A`P^3#"P)4`A@`PB5#`C)5#B!0T^:_%0X(B)0Y@"B!$!0M
M.)C@X$&"`CD+B"BJDP,#B!*VC$FS1LN5'@ETIO@R@^H`#B*NOM0PA@V=.5QZ
M%!V0H@T9!44%5(@R8@)3IA846F![AXU<E1G*K,F08H0")6)NA#%C1@T;,1H"
M&P0AIHH"HB/(L%D3)4&#"T6F3+'B9@V;,6`2%J0Q`4(!!;@50$B!1DT0#T2(
M0%DRO$F(##.`H#`H@<60*Y;7K!F#A,>-#S22#(=2W,R8#%@J_JP@>,')FCEU
M\-S!,Z<*FSAE8-"@L:3^$B(ZV)#A@(,%>2=QV*&>>G>@T0(9;=`1!@PJ9$>$
M"C6<4<:!8-P@@T`,*!''>AS:T<818O20PAA*H+$@A%Z<D<8199!14PP"35`%
M'0/>D4<<6K111QQB`)&&&B6N(<8//``AAA@]"22!$VUP>(>'7\QAQQUJ"#&"
M&$.,`<>*:(S!A083%#1!&33:2`<76LRQ7AQ'J%'&#SCPT(./9("IT`1D=#$'
M@770(2"52,01!Q!JQ-%&'&,D:5`#2LPXH!UYW$&E$FO4L<81<:B7Z$,$/*"$
ME$ZR4881:N#!IAI/N@B111<\L:&'4V-H0,$-9=2A1J!WJ.H1!4^D$:ML*X0`
M!JEXL*&!2R4HX-=`-L38@QQWC"&;2244U.P_#I11V+$^+33!&GBH$6:W"FG`
M1F$/D&N0!6*HMT:Z$P4$`#L`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O=&AO;6%S+F=I9@``````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C(T,0`Q,#4Q-30S,S<V-P`P,C0S-S(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````1TE&.#EA
M(``@`/<`````````,P``9@``F0``S```_P`S```S,P`S9@`SF0`SS``S_P!F
M``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,
MF0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S
M`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9
MF3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8`
M`&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9F
MF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_
M`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDS
MF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,
M`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`
MF<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9
M`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_
MF<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F
M`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,
MF?_,S/_,____`/__,___9O__F?__S/____B_)```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"'Y!`$``-@`+``````@`"````C^`+$)'"B0%:M`@:Q8`<`0
MP+6&!"-*%-@0P(F+CQY=>WCM(H")("U>')GQT1Y6#%=X!!E1I#25'@L\8H$2
MP`J5'UD.M'@3Y@D`!2[03(E3Y\X3/4<"%5I3J5&*(SWN63I4Y,^GV*S^W//H
M0M>A/G,:M=B0*Z1'Q%8H9!BA;=NG`-RVY;KGVHJ*<2,0(/"695Z]?/?<!&"P
M,,.]>W7F+<"X0$-65@JK18E8<=O&C]4&,F@%(8#*?B\S9EBX<&?#B4-'P$R8
MU4/.KRD3L+QZ=.N#G$M_GJV:M<%`*UC=1&AP-VW6A%<$NO9;^6[>(47;QNV:
M><**EO$^WCRY)L.Q;;5_,T1(_C!HD)#:[A6/-Q#BU!/3`R;0,)!X@^_]IM_;
ML_7-S@A9L8)<^D7`W4N0W6;:;83I!XEP-R586(`"*K200B%!`HF`_UFXQX=[
M:"CBB`Z."`D`(J)HHAN!N`%)B2RZF.)#)MH7R(L.VFBB>,JM`)=-P&GWD'A8
ML6>D6-@$!``[````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A
M=&%R<R]T:6=G97(N9VEF````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S$T
M`#$P-3$U-#,S-S8W`#`R-#,V,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!'248X.6$@`"``]P`````````S``!F``"9``#,
M``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS
M`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,
M`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S
M,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,
M,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S
M9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,
M9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`S
MF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,
MF6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\S
MF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,
MS#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PS
MS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,
M_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS
M_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,
M____^+\D````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````(?D$`0``V``L````
M`"``(```"/X`L0D<2%`@`!(%$RI<.)`$B3D(&4I<2"+0"H@3,Q(DH<(A@(\?
M(P[LZ'!BQT[!@G4B`1(`Q(A..G6ZM$)DPB<H4^I<&?)2IY.=5JQ8M<KFP!67
M=NI4R?+@SB=$K5D#D%`%@!4I5Y+(J1)DUB<65U@K6M#J4&O/5H3,R9-$RJ%#
MB:Y(R'*5U+&KU+H-]G!K2A6K#I94>-6N4*).@QWD>LGJQ!46I>;-F_.CRI@L
M,X:46A-MIY@?>7;Z.+&I6&M"T>(<O=7A2HD=#]J5O.J93M<K91K="*DW)*A5
M\JK@FM7U[H:0>NWR/33X"A5+@P$]CHT$I%VT:/E6\4RJ[>@J7ZI3]$W^M/?H
M6I%(M$X>ZEW4SXYE=7()),.#O4F<O9L7[5^4(%&'S4&%O8<:`%(=\UE76XE'
MET6SO?>1=RN@Y!J#"T&VGV032@5=,#$Q%1)%!8ZEUUT?%G?0)0)6Y]"+;)RV
M2HI\+:98B]@@00(;,<Y6TU)^=7400QZIL.%PX*7$$@DL+@28@28FF=)B/&48
MH8G$18=D4PR=E5=B2X6XU&+KM90E4WLIB5)````[````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W1R:6XN:G!G````````````
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,3`T-3(`,3`U,34T,S,W-C<`,#(T,#<Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````/_8_^``
M$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$`!\```$%
M`0$!`0$!```````````!`@,$!08'"`D*"__$`+40``(!`P,"!`,%!00$```!
M?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:
M)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ
M@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2
MT]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$`
M```````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"=P`!`@,1!`4A
M,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU
M-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)
MBI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9
MVN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`_C$LM,&MZE?M:`I:
M0)<WP=D$:I;+,JP)((U:&)I/-C54&$+`JC!1S[_\%;&U_P"$AM57;YZS`#YS
MG<D5R`?E/!VDG@=^0,5P7PWM[`67B.?4#+%HU^+72VO7BCB<$V][=1K$&+Q)
M.9/L<H'V@)%,;5)%='6>+H/AKH7CW5/&OAC0_@KX;\9?$;QYK.LP:-I7@WPS
MX0UKQEK>M:S?SO8:5I.AZ!H-G/J.NZGJ<LLL-IIUB'N;B["1VXED`2L.,\&Z
M^60Q$9T_;YC3Q4ZD%92I3=6*@W!?#0E&3A2JW:ER2CTN]_#3$8?*,TP]:M2F
M\+@:U!SJ-PE548U%":I*HX.K6IRBYU:49*2YDXIWLOZ\_P!D"]O$.BR"U1(X
MX[>*7Y)#%,T,(246A\P2$PL%2?SB6$$L,D:AQ<.O[U_"?4I5BM#`(YFDC@21
MEV2ASY,)D*L`NX1;G7``8HN"&D`W?R?_`+"7[;'A7Q5)%X0URU_X1/QYI2A7
MTJ:/R8;G5?L5O970TR2[OS=S3O/>%DLY4BOFA>=IH(HRKS?L+\4/VU=9_99\
M-_VA'X+\0^);RRMSJ-NMMI$46AV;,MY<Z<_B#7[W4K/3]!TT2::%U34-1>,P
MPF:[@M[\$Q-_%^<4JV`SB-*O3J8>NZT.2"C:>LDE*G>W-&26C5N:-G:Q_J!4
M>!XKX7H8W+,5A<?@ZF$:<Y2=H<E).<*R5YTITY:3IM<RM>S3/VC\:Q0ZAHEV
MMQ#"S2P2H&D@AE,:,(U?8+B.502O(WQNA(0NC*H6OX/O^"\OPSMO`WQR\%ZQ
MIVA/9:9XK\/:U?RS:>D$5I?^(;35(;>_>TME@M'\\1W&G-=F-A:R)=PPI;/>
M6VI:IJG[._L__P#!0W]I3]L+5O#TVL?M`?LQ_`/P7)K,&DZI=>%=$U[Q3XG.
MIZD)H-+T54\4'4_`-[=ZMK5MI.C6UI<:KINH&'Q+%)I6FZEK7]E:5=>0_P#!
M:GX&ZUXM_9?\%^.9WLO&FJ_#CXE:K>2>(+72IM.N-2\+ZEIMS<7NK"T>YG%C
M<3QZ3;:CJ<&DK:VK3V44]K'!:6-OIMMZ^1*KDG'64XVMB:*I8F<Z%93E*-7E
MK4*J4JD9P45-2M)ZR2<6D]#\GSW(:N8>%O$&3TX3GB<3@EB<NI4J=:5+VN'Q
M--JEAI3IQ59\M&46X)2CS>]%IZ_SO^"?^"57[<_Q$\&>$?B!X0^`WC+6/"?C
MKPQH'C'POJUOI&J/;ZIX=\3Z5::WHFHP.FGLC0WVFWUM<Q,K,K)*I5B""2O[
M]?V8+:S^''[-7[//P\.FV,I\!_`WX2^##)<>'-1GN)#X7\`^']#+SSQ7]E%-
M,YL=TLL5G:1R.6=+6W4B)"OHY^-&<1J3C2PV"=.,Y1IMTTVX)I0N_8ZMQY;N
M_5_+X&C]'_(U2I+$KB58A4Z:KJ.(PZBJRC!55%-)I<_.DFD[-72Z?YV/Q,^$
MFH_##5/'OP\UFX.[1?%7AF]@NREHLFHZ%XGT749=/UD+92SV:+<6MMI]VUM`
M6ELIKE[&\M[:YM9[=/N_]D/]GK7K*XTWQ/JC>%;SP'9M9:L+W6OAU\-O%=IJ
M`4:I<P+K.D^-]#\5KJ,%MJ;_`&>.VN;.:!D+J\7D%!'W_P"U]ID-_P"$-+G;
M1;&Y5Y=2TEM<EBM&O]+?4(-^G:;;RR[[M(+N]\VYQ#$EG]HT^$SW-K<36:7'
MBGAK]I73_#?[/4_@B]U*WM-;TZUM]/FA::7[5,UKK+G8T2VTB@Q1K'NVL?,\
MQI!G8S5_;'TM?#O%^%G'-')N'<3C*^5S5"67U%2K4:^$P=>I4Q6!PT*\''F^
MHX>:R^&,I3@J\L)5?)"I[2E2_DKZ!?B+D/B_P%6XLXNH99@LVH4<9#,*.*J8
M7%X',L=@(8>EFTL5@Z[J0A2S/$49YM]4KTY1PZQ>&IIU(>RJ5N<^!>M_\+>_
MX*2:1XCTA?MK?$?]H+7?$,GDM<@ZU)K^M7^H:IJ<C:@Z7$*ZU=IJ.IRV:M;_
M`&-+AK.Q@MHTM85_LV_X*)_LBM\=O`B7?@RT:T\0>#]5TZ\M-26/1;R`Z'#:
M21PP:KIOB"&YMKS39KNY@:^2S-GJ,ABM@NH65G;B:+^&;]A;Q-J'A?\`:O\`
M@/XFTQ6?4X/B)I45N$0^9C491I[RE@CL_DPW5RVUHSE?-^:,NSK_`*0U[XL@
M\.37TNJH]S81:?<0:V\\EQ$+3S1&PN[PE;ATC,;K++<3`I;1R^9)*L9!K^%O
M$5TJ6;Y4\1%I4L'0DZSUE#V4J\;RE?FG/GE"3=VW[-:<J=_[I\*L?FCRVIFV
M64Z$W6SSB%_V0J<*>%Q4,8LEJ3H^S@E1ARX>M/#X=2Y:?+B)0<9:\OY>?LI_
M\$U;+3-"T.3XH:)HFNQ^#O$6D>(?#DD5QXFEU/03INN>+=>AL_`^JZW\2/%P
M^&6D3:WXGUC5/%.E?#*W\$V'Q$GO[N+XB6/B[S([B#ZI_:I^#?AWXMVWA#X8
M7MG;0^"/#VOVGQ`\8W9\G[-I?A/X9VNH:]=S7!O[FS#6FHZC!I/AR^W7$[K8
M:Y=7<EA?QVTT:?3N@>.-(TC2]2MM-N%@+Q+Y*V]P\\;"0SNS;BL[NC+,[1*L
MJ+&64(=JJJ_S?_\`!;7Q#\5O%GB#X`>`_#OB37]%^&_BF7XD77Q4L-+UUK#2
M];LO#^H?#O5_"B^*-&6XA'B"WEU.SU&/2-,O;2[M(]1-U>N";65#IP'PSC_%
MKQ!X3X9R^KF>:9CF>(CA\16H4O;U<-@Z3J3JRPT:2O2I4,$JU>K7JR5"A2BY
MU*E.$)-8>(7%U'P>X+X[X_S?!Y+D/#W#6"Q&-RG+J5+#Y51Q6-QRP^&ISQ-*
MK3IK$8O%XZK0PE"*5:O7Y:%"C2GRTZ3YSQ__`,%0OC]-X[\:S>`_$/A&Y\#R
M^+?$DG@RYUGP1:IK%QX4?6;UO#L^K)_8\6W4I=(-G)?+Y46VZ:4>6F-H*_-P
MZM?`D*U@5!^4R64SR$=C(XO%#N1]Y@JAFR=HS@%?[P8;Z-O@5A<-A\,O##(Z
MZP]"C0]M6JX]UJRI4Z=/VM5QS",75J<LIU'&,4YMM12LC_G=Q?TP?I%8K%8G
M%+Q3SK#+$XBM76'PZHPH8=5JCJ*C0@\LDXT:2E[.E%RDXPA%7=KOV?XH>"H_
M'?@+Q'H0"O?SVHFT93):Q-_;=H3?:8JRW6([5+NYM5TN6_9XX[)-1\Z:18]P
M;\-O&.BWEMXAU?2-0L[FQF6Y$&I17L1LWTRYL2B:HE[#<^2T%W'<QRI)%.L,
MRW(9'1I=R5^LO[8?Q6U/X5_`KQ'-H5Q<:?XD\8ZEH_A'0M9TZXDM=5T":\^T
MZQ>:IIUW#<6UW92Q:7I5Y:K>6CB>UNKFUD1B`8Y?R*LM=U:^LXM6N=7U+4/$
M>H6\VH:Q?ZO?W%Y>7LVLM<7+W4=S/.][?3*EY,+XN\TRR10S,S)EU_&?I\9C
MD&,X@R#*,%&J^*,MR6&(S&M&I'ZL\+B\1BY9=A9TK.HL=0C#$XR-1.,%AZ]-
M-.4KO]M_9LX3B3!\*\28K,9TO]4LUSB:R?#RI3>)>,PU/"X;-L1&K)JD\#C.
M;#8-4TN?ZS@:LE)*4U+[Q_X)X_!/X4^._P!H;PM=ZM\8KWP-9^'8-7\2Z(/[
M1\/:'X@U#7M"TY+W3=+TIM6DGAU&]O\`49?*@T6UL8;[5;.UOTM+ZU:*>[M/
M[F/A]\;OA9XF\$P^)/%'C/PKJ5YJ/AU+3Q+H]]JFBRO87GV.V&HV6HZ9<7T]
MQ;/&ML#=PSF9V6\WM"R7%JL?\-W[(O[*FN>-M=TW7M,O?"E^]]86U[8Z6FJ2
M:;YFZ53;WMIJ-D+6[TJ:SN)?MJ3B9$N+C2XHE2XF%G)'_6;^R3^RII_PS\.Z
M/K?COP'H<GC&U36;<W%Y'H.O6UM+>3V)FU*+5?-U2XU#4[XV=PR7QGMO[.@N
M[BPMK>(7%_->_P",?B)BI5\R<?KLJSPT%"G&4*<G"3352-XI2<4V[N<;7O9[
M)_\`0GX><*<-X3PQP^/Q.,J93G&,Q,Z]'*<%1J.IB7*:46L17;A1A55'"MSI
M.4E"C&*7,?<7AS3K":-X[&ZCN[&=Q#:7DAB9Y$BFEB82RK(T!=&0P^8DBP`H
M2-L>`/YO/^"D/Q2T3XC_`+16HZ7X6U"ZU#1/AKX>B^'=P9F4Z9-XMTC7_$>J
M>)[[34CE;_2;>75K#PIJDTT$$G]H>%;F$"2WAMY*_H`^,/AGQM??`7XS^&?A
M)>W&A>.[[X:^--%\%:[H5Z^E7_A[QAXAT'6+7PWJ>EWUG+:3Z?JEOK5]:W=G
M?64Z2V5Q$E]))'Y88_P^?`#XC^+/&S^.M*\;7FLZMXHT36%U*\U'Q->7]SXC
MOI/$&IW[^(7U:347FNIKW3]:65[FYFE%QG5HK6X5Y;:2:3^L?V<5#AF/B_CL
M=G%:K_K!#A_,,+PS2C:&'IUL72KU<;4KV?,ZE3*\#BJ6%@FJ;YZ].2E*=-'^
M=/[3O-N+*_@G0RS*>2MD6)XCRS$<55*CY\5/!996PBP%"C**5-?\+&)P&+QR
MTE!4Z;C%0YW#WG>X[+^9_P`**L&T8DD$<DG_`%C?_$45_N'K_3_X'K_3T_Y_
M%.EI\/3]//[_`)]T>`?\%*Y)%\*_"R%7=8G\1Z_*\2LPC>1;#3HUD9`=K.L<
MDB!R"P21U!VNP/Y\^$V8:KX7()!+VZD@D$J^U'4GN&1F5AT925.02***_P`T
M/IL?\GPSS_L`X9_]4.$/]5/H)_\`)G>&_P#L9Y__`.M#F)^\G_!)7YM8@W?-
MB9%&[G"I=:>R*,]`I`*@<*1D8-?U\>'V;_A!_#AW-DP6V3DY.5N6.3GG+<GU
M//6BBO\`)_C;_D=9E_UZ?_I<C_<;(_\`D@>!_P#L&I?G(W?!0#_#G1BXWEXK
MQG+?,6;^U[GELYW'W.37\#FL?N/^"B7[5<<'[E'^+_[2$+I%^[1X8_CB[)$R
MIM#1HT<;(A!561"`"JD%%?O_`-!?_E(?AS_L(PWYUS^#_IW?\H\\>_\`8;F?
M_IF![XO0?0?RHHHK_H(/^=Y=/E_[C/_9````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V%V871A<G,O=7,N:G!G````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`Q,34R,0`Q,#4Q-30S,S<W,``P,C,U,S0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````_]C_X``02D9)1@`!`0``
M`0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$`````
M``````$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A
M,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W
M.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3
ME)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'B
MX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%
M!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B
M,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'
M2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:
MHJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ
M\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#^/<#X+>,?"2ZA\-?V:/#&O^/+30O&
M?C#XN>%;6;XZZ;X:^$OASP5XST+6M#U;P3XDN_VC?$FH>*M!\0^'&F\)^/XO
M%>E_VOI^A7VJ0^$[S1_%TNA_$32<,:#\!]5\$>+[Q/@7\0?%-KX:L?AM=_\`
M"Y_A!XP\8_#[P/\`#SQ!X_TG3YO$/A;XT:-\1/!'[0\7B;3])UO3]7\.?#F]
M\*:[\'-1U+4;+Q=K%])\0;"[\-:+X5UKR]\,>,/AKIGPX^(>I_#OX9:%\`O"
MOQQM_A-\7_`GPE\3ZUJ_[4'CN;QOX?UF/X>^)?'<5WIZWVFV%MKL^H^%?$.I
MZ;96W@SP_>PV>J:0UYXDM6/->)M?\<:WX?UVP\>:MKOPZ\3ZKX.^!VF^#_A%
MX7^%@\&:#\9O"UI9Q2>#_$7B*Q\-IX9TO5&M]$EL/$F@>)M4T/Q+>^++C5;5
M]+NHK=;26'^PJ_A_P;B,-[%Y-EZH8BH\0\0Y5L'7P_U/,(U:>'HU\#4P]:HJ
MV&DTY.I[#$T:4?K="KAUB[>5',,9!32]C&4XI)RP^&G*/^S\KJ0A7A.,.=24
MXIP<75ES4$JJA;IM0UO]G":/3_A?IGP.^"VD:>WQ/?3X/VKM9\4?M;:O]M^'
M^G:+H.EJNK^#].\::9I]YJ_G-)XR\87OA_X6:-?3ZSKPT[P]X5\)^&TTS3H=
MQOB_X/\`&'A[PUX)\9^$/@I\)/#'PW^'OQ,7P3\1/`?[*WP[U7Q+\;_%&D2:
M@GP^TCQAX@US0O[:O++;::1X4D\6ZO=:UKH^R7FM^.+[7O%NKZIKJXWCQ/%-
MKXL1O&7@BW\)_$=/C)I5Q<?L-3?#?XH>$=`CEU_P?X=GL/%FD^$EO8DLV\82
M)I]C/X;@N-.UJ[%WI4NDVE_X9O(["Q\K:\TSPM9Q'Q3INA?%@WOPQ\6:#IGA
M&]U7XEZ7)^S_`*UJ/BK5+>QNI(8Y]#V:MX<UR[OM8LM`O+[5_#%]J?B"6;7K
M'4C>V\^HX83A+A/*<0JM#(L-.DJCJT'C<MHXYU:?LXTISA4S'EQ5+GA4E5I5
MJ,XTZD%"O'`X7VE-Q4LRQM-TU3Q;H4YSDY*BW0;<'#V%.M4PS]M%RG3C&E"=
M6<55YY3G[6K3K3_9K_@CG^SA^S)^TO\`M-7WAG_@I3!\$?@Q^SQ\5?V;]8^(
M6C>)=77X1?!5_'NK>!O'_A;P9X'?PY=:8/#GB7X>P>;I?BLZE<_!"3X5:O\`
M$>XT&YOOB/J?CC0[_P`0VWB#]@_B=_P;J?\`!+OXS^-[X_LJ?M3>'M9TRUM]
M36P\-?`KXS:=XATN*S%Y>7ND-XJE\>+\=_%;^+8X+AK/7-0T;4](\+_V!9^'
M)+#PLFMIXAU;6_QY_P""'G["OP,_:W_;=3X0?&O]H:XL?AY8?L=ZY\:7\3_#
M/6K&QN_!NN_VYX&EO?AMJ[^/?#.I:?!J>@2^)-:.NZ?H]A<)/J,2W%A>2>=<
M*_\`7%K7_!`'_@EAHUGI4U_^W;\1M(;Q)K\/A#PW<:G\2?@2(-1\4W\MY:Z;
MIMO;GP-:RWLEU<65PUM'%/!'?00F2VNQ#+%<'^0?''!YSDW'5-9'D65PR6>2
M8"M%87B2KPS5J59SQ=&HZ^#PN)_LQ8J"2I2KO!5*M10HRK.&)I15+^SO`[(O
M!//O#YT>->/N*<AX[AFV-HX?+L-X)8#Q1R;"Y5#V->A4J8J.7T,ZG[:O6QM:
MM@L-GV$6%E%1Y?>K1K?AB?\`@U]^%#$M:^._BY?VK$M;7UI\7_A6UI>P'F&[
MM6E^",,K6]Q&5F@:6&*0Q.I>-&)4%?HE>?\`!`/PSIEW=:;8?\%3_`]A8Z?<
M3V-E8P^&O&GDV5I:2M;VUI%_9?Q3BTSRK:&-(8_[.BBL=J#[)&EOY:@K\*<^
M,FVUE.<I-W2_XB!A'9=%=YY%NW=Q3>MTKM'[(^!/`--I>-?AI9.RY_HE^,3G
M9:+G=+"NDY:>\Z;=-N[@W%IO^"UM5L$\.:+9Z]XEUCQ/X&MYOBX/!_PTB\3:
MK_:GP\\2:EH>G0Z3XHU73;C2[;P[!'KVJIX7O-8G\/,9?$=GX1N[34/L3Z?9
M6M=!<^*/"\/@SQOHNOZ,?C7XMU;P/\(SX&^*[^)OB-IMW\!(-$EL'\0^$!X>
MOH;31/$%IY-[#\/2VH1W?A[2I+2SO_!]^S7JI7]4WQB_X-2_CY\*=1OY?@O^
MWW\-?B+XT\1:;KNG>++KQ#X"\3^!=#O=`\7:7J-GK5C=>(_#_BCXJW^J7FL?
M:##JMC>Z!:HEK>?VDE]/=QPP/X!H_P#P;+?M^Z!X9\8^#-'_`&G_`-G+3?"O
MCQ_#J^+=$M-8^*JV/B2'PSK=UJ.BMJL)^&`+OHQE&J6$2NRMJ-Q<64DL<$27
M\_\`I:^/>$Y3ISP/$5">'A*BJ4^?$X-\E.3E1E+#XO#X?$U7'VLI351O#5</
M6KY=.4\%*HY?YFPPE>7M%4H1I.$ZU*46J7M*=6+J4Y4G"I5BU%5FH3K34ZE%
M05:$G*ERO\'4\9:;XDTRPN?&5SKFM?$-?C7\*[O5_P!O&+Q5\9O$5YX"\(3>
M#;:QL/`$GAG5;723?:QX2'AZ;6-"U-$M_$?V;P;J^B>&5U'1;;2]2LO.)-0U
M7PU>^(8O"/C74?"VG>*/!?Q$\,>(_B/J5SXTM])^/6F0>)M3U6\@TB(^%Y-3
MLH?%=C:^&]';1=7`MGU:S:7Q+K>F?VK<6UO_`%O_``J_X-(_'_C3P!;^%M?_
M`."EGA3P,VI7MMXG\4_#I/A#XCU+P2OBOP_8+IMMK=I=7GQ9\.6FN365IXKU
M+2]`UW4_#6BZU)9W&OP0:?:VPNQ)[)=?\&8?Q#UG0M#TZ\_X*@>%M4\->'K+
M69_#=E<?`S6;W1=%TYK[[5X@FT:"3XWR65A9'4KC[1J\EFL4`O9_-NV$\NYM
MI>)/`$J$Z-;B6A'$J,:L.?"<1XIQE[2C&=)5)Y2YX>G.A0HP]MAIN[YXJ$Z5
M2,D4<!C7RUZ&#Q?L_:.FZT&N6K6C!>TITJBDJ<>6"J/DA&HX3515'*2GR?@G
M_P`$>?V`9/VY_B3\98O"OB:T^$7_``JSP)\([J^?Q3I6I>*K_4Y/&>B:O#K&
MI:3%;7OA\0V>OZ[X>7Q!9VUT)[>TT75K2WMKNX-I!/=_U9_!;_@VJ^&OB6+^
MV?B5^V_&FDRQ7"1:'X:^'FA^%_%%G=17$D$+:D?$/CWQ+:1VUTL;W,)AMG+P
M+$%D+W$OV+\F-(_X-T/VV_AAXB\<Q#]J7X2>.(;1M!\&^'KW3-6^(.D7]YX5
M\`'4?#WAN(VS:(VCV=O;Z-+!-!8V^NWUK;`WGV?4-1FG^TWGU_\`#S_@@C\7
M_%5AIV@_%G]KGPMX?O3JEA86`TKPGXG\<^&(;=PEG#K&K:GXE\5^!)M*:U6>
M079ATB_CBM1-<+=`2-;)_"/C/E^!XB\1<ZS7+^!:O&$91RJC@\V?$D\NRVMA
M\-E.#BXT,+5J4\/2HTZL:]*K2ES3J8M5,3*4YXB2E_I=]&_Q;QW!WA%DO#E?
MZ8F5^!.1>US_`!6.X/P'@I2XRXEPF-QN>XJ#JULXPN!Q.?5<9B:/U/'8?$74
M,-ETEELG&.!<J7Z<_P#$,G^QC_T>#\5O^_\`\*?_`)645\OI_P`&OR2*KI_P
M4'^&KHZJZ.GPB#*Z,`596'QD(96!!5@2"""#BBOR7^P)IV?@W@DUHT^,J2=_
M=T=Z_P"??7K?^BUXP8>23C^TLXE::337T:,Q::?*TT_[*:::::?GZWO^._\`
M@@+^WSIFBZ_J][^W-X@\2)I%E=W@>[U;QV;&Y32+?4)K.XN)KCXC7FIVVG1F
M>Z;[1'HU[J%A;7UW/'I,LCW%N_P%J_\`P1O_`."D\[QS6'[57@2`!H(7MH?C
M9\>.D]Z3<79>3P!`NVWAG>8P@%S#;"WM@288A]M7/_!&;_@NO)*9)/VROM<C
MYW3']L#X]NQV,T2;FN/#T<C;HXT=.#B)XU;9(KQ1^#7O_!.#_@L!/$J6?[?7
MV&42!FE_X:7_`&E[G=&%<&/RY?!`498JV\'(V;1PQK>GDF%=2E4CX>\:X>2O
MSMYY.K3:;3M.->I6FU&S2E"$9M.]D]3S,1XHY[1PN+PN)^F']%_/,.G2GA\/
M'PLP^6XF+I:6P];)\)DM&+KI4I5:=?%SI1E24(U%%*)S_P`./^"1O_!2B/4M
M%T_6/VQ/"?A6SUJ]TZ#7=3T/XQ_&@7NGP3N$+S6<GAGPWHFH2:8]Q,`]WXAT
MC3Q%YDCWT$?F3O\`H'9_\&__`/P4,U&!WO?^"DGB?3F\XC[-J>O?%J>63;NE
M%R#IOQ"U.WV-+=7(7?.LXE:X=HE6422_`NB?\$X/^"QB@/J7[>%PI1&4I<_M
M2_M*N[F>RT:1-JVW@^YB(LYH[^SDEDD266X2:XC66&Z%Q+]&>'O^"/G_``7.
MU;2++5=)_;=:VTW4X(;^R+?M>?M&69N;:ZABE@NQ;KX4#HL\+(4\](YBH4M&
M%V$NKD6$P\I->'?&F*2J-I+/L13I0;FURTXX6O!J*Y>:-HZJS<K:HP_BKQ%F
MZITY_3(^C#PW/V,:=2$?"K)\QQ5>%&G3M/$XO/LMS*.)FHU5AZDWCI_!9<TF
MY/S3]I/_`((7_P#!1#P)#ITVA?ME6WB_6=6N-2=KWQ/X_P#BEX0%]!HL-O"@
MTZ^TRY\?WVH2SK<VT4=MKEOX:AMXY+.0WCF&YMK;YB\,_P#!(/\`X*<+>W":
MI^T9X/M[1H93'+J?QP^+EPC21S6XMP@L?!VJ7$4TL4ERTD8C6W41+NN)7,2K
M]A_$/_@DE_P6U\,:-]I\8?MPH-+OW?2(;F?]K#]HK6;?[5?VMW(;62Q/A*>6
M1)+>SFDF66W^R2H@AEE+.$/RC9_\$O?^"P4&M6EQ)^U^LDEE?V,-OJK_`+3G
MQZEMHK:R*VUM?H5T*WU58-/A@M9+*U2V2<6\20^1$8EMG4<BPU:C*_`?&>%A
M)INA_;,JCG*5KM5*M.M7BTXQ=W4II2;;Y8I-Q6\5\[RS,L+*'TL_HT9_B:--
M0IYI_P`0VH8"EA:=&T8TYX/+\5E655H^SJU*:C#!8J52A1I1A[2JY0I_H!H/
M_!"?_@HSK6AZ-K/_``W1X^7^UM)T[4]MGXJ\87-FOV^SANL6MS>_%W2;VXMA
MYN()[O2]-NI8MLEQI]G*SV\97S1_P[F_X*[?]'W?^;/_`+3?_P`P]%:K*<&D
ME_Q#7C1V2U?$>-N[6U=LR2N[=$EV2LK<4O$'B24I27TW_HR03DVH1\%N%G&"
M;NHQ<^")SY8I))RG*5EK)O4_%N;]M/\`;'N5"7'[6?[3$Z!@X2;X\?%.50X!
M`8*_BI@&`9@&`R`Q&<$U6_X;&_:[_P"CJ/VC_P#P^'Q-_P#FHHHKS<%_N\?5
M_H?;\2_\C27_`%XH?^D'#6G[9?[7]OKNEV$'[5G[24%C'%J4,=E#\<_B?':1
MPVUYK,-M$ELGBA84BMX8((H(U0+%%#%'&%6-`/0(/VT?VQ;;=]F_:Q_:7M]^
MW?Y'QV^*46_;G;N\OQ4N[;N;;G.-QQC)HHKHS'_=H?\`7JC_`.GSQN#?^1WB
M/^QIB_\`U6TATW[:?[8]RH2X_:S_`&F)T#!PDWQX^*<JAP"`P5_%3`,`S`,!
MD!B,X)KPV_\`VQOVNK;7]6U"W_:H_:/@OYKFYMI;Z'XX?$V*\EMXYE2.WDN4
M\3K,\*);VZI$SF-5@A55`B0*4493_#I?]?8_^DS)\0?]XQ7_`&*Y?^EX,]I_
MX;&_:[_Z.H_:/_\`#X?$W_YJ****LS/_V0``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W9A;7!I<F4N:G!G````````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,3`R,#<`,3`U,34T,S,W-C<`,#(T-34V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````/_8_^``$$I&
M248``0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$`!\```$%`0$!
M`0$!```````````!`@,$!08'"`D*"__$`+40``(!`P,"!`,%!00$```!?0$"
M`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G
M*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%
MAH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35
MUM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$`````
M```!`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,082
M05$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X
M.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3
ME)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+C
MY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`^C?A5^Q1X:_;7_:2_9[?
M]H#P%?>,OAA^PC\&?A9\5OC+JOB731X6A^*?Q-UOPWI7ASX6?"/7!K"C4H9?
M$>I^&=0^*'Q!TWQ(AN+SPXN@:#;V$\?C&TM[W]@_VPO&GA#Q9\3_`-E[P/\`
M''QMX9\!^//BIXQ;PM^Q]8Z)<W7B'Q!X?^('BWP7K%UH?CC5/!^GZ5#I%G#9
M7>AZ,_AVX\3:U>1:CJUQ/I.EZ%X/GDT^.3T_X0_`?5_&'PHUZ^T"&]T]OVCO
MVGOVH?C)\3GM(+^TBUK5]=^*.O>$/!MCJ&N?:(]0T[2-.^&GA6TTW4C:R"^;
M3;*6R\.S6>IZM`[?GW_P4Z\5_`O]E3QW^P_X"L-)L/&/Q#\0_MU?L>WGCCXM
MZ\]M::UX?N=(^)7A:W\/:%X=O=)B&G^#O"HT*/46L/!&B&UT71=`FB2:"-=)
MLEC`/S\M;?QA^T_\?-+^$/B*V^.'_!3?]KN[\.C4/B9X=\1>/?$/@W]CS]D?
M1;W4I[>+0OCK;:*?`/AIO%&F3VVOZG'\+]/N-$N[F"YL]/UFX\9:C<3F;V>P
M\0?M2_\`!.[QSX&^"_Q9^!7PM^#^F21:M\7/@N_PKEU'QI\%/&'Q)\!S)XMC
MT+1YI-,M_$7A_P`3/X1/CG3[V"]T>Q%S80VIU/538:%H=Y/^MW[.WQS_`&0?
MV+/VW?'7["-\=$^'7QQ_:S^)'Q-_:!T&]DMQ;Q^,?$6IZQ/:^%?`MWJEP%3^
MV[_X=>'=.\1>`89)FTG5;/2?$5@T<6O1PQ7'V?\`$_X-_"GQU\0-)^!?QS\'
MP>//AYXUU/Q!\3_@9-JG]H277P[^(.D:)K%KX]\.Z9K.GS1W^E6PT/6;WQ'X
M9M;J<V)M=5\3^&8;?^R/#>EV@`/P'^#W[8'PQ7]H/]M;]M?X:_L?_$KXE_`G
MX#ZOJUCXV_:!U+5[^U>RU,ZO/K?Q!C\%:UK/G^+?%?B'18"FIZUI^@OIWPX\
M#_#T6_AW3[833$:_^U?PJ_:&^"'Q2^)'Q0T!O&/A#Q7^S[\8/A]XB\27.D^*
M&TR\\,0WVF:/#JGQ-NM0EUAAI\'@OXA_#/Q%H?BC4=-U)1I"S^&O%VLW%OI,
M,TUK<_:GPU^'?PE\%_#";X0>#O#V@MX&\+Z1>^#?$.BI9Z:]EK+MH\-MX@C\
M1M:VMOI^KZSK%G<K-XPG>*;[1J-Q<V]R\TL4JQ_RL_L%?\$P[GQ9X2\;^%?B
M?XHN-3_9@^*?QU^(?A7X&_"K3=<ET>3QKX"\)S^(_`D&O:EXSL=4T[QK+\)=
M)^%.DVMY)X?TFZBL?$?BJV\):!?Q3Z4JP(`?6&C_`/!,+_@E!XVTC2O&?P\^
M/'QOTGP!XNTVQ\3^!M*\%^/M2/@[3/!^O6L6J^&=/\)F_P#"=W?'PS9:+=V5
MMH)O;JYN_P"RX[7[1<33;Y&*_H!\(^`?A9\/O"GACP%X3LO#7AWPKX(\/:+X
M0\,^'T:YC70O#_AK3;;1M&T=8YM96:-=,TZRMK)4E42*(`L@#`BB@#PS]A7Q
MB?%/P+U_2;^6W.M_"CXX_M)_!OQ'+]F6W6WO_A[\;?'&FVT\T+EG"WV@Q:'J
MDK.1]LBO;>X?=O#G\??VH/V0?"7[5?QN\'>&_$>K:U;>*_%FN>)OB%IVOKY6
MH77@N/6=8MK'PSXFL-'O/,CN-9\+:5J5O>-J*B*ZM&6"UM9OMUUI[0?9?[.O
MB!/V??\`@HQ^U5^RQXDE,WPR_;6TO_AN+]FSQ'%=O+H&L>()]"\*_#O]ISX:
M6&K0.8&U>UO]$\(?$[3HH)OM5UX<\8ZAJUD!'9W!B^A_!GP=TJY_:^^(?C2:
M6673?"N@:'X4T.U\J/[1#>:`OA/QN+&>1@3-;1#Q);-;G)5HC"[XF,I`!_-5
M^WC_`,$R?VI_^"L>F?#+]L_X?>.+/X>_MB?"F2^MH?A+KNJ6O@S0]<\*:-X\
M\0>-/@IXD^&?B_0?LNI^']2T?0+:UN)[W6AJ_B;3?&?AW5-+U-9].6[+_8/P
MY^.'_!4OQ[X3_9A\'?MQ?`+Q#\-/B[\&]8\1ZKXW^('P)UBTU7Q1XDTG6?AK
MK7@/P1K.N:DFIZA\./`WQ"^(.M:KJEC9>#I?$.K1:_X@@T76YK/P;H^LZ#IU
MS]H^"O$47PL^.OP"\5V6BC5?#_@+Q9^U/\"/CQK+74LFH_#KP]X2^*.H6?PN
M\5W.GS2_8-/\"65EXW$FM:XJV7]B#Q*)I)I+.[N%B]F^,WA#5].M?%_[37Q-
M^.WBCPY#:_&'P%=:7X1T#XMI;_"2T_9F\`^/+"]NO#6K^`K:ZO?#OC#Q)\0?
M!'_"5^-]=GL-.U;Q'XAGO]*\/"X31]!MK``'\]'Q<_X+B_MI_MC?&?X=?L=?
M\$KO@1\3O@?X)U+QAIWA'QM\3_C%\,)[SXVWNGVFO0CQ_>V/AB_74_!_@C3=
M.FDU;3?$FN:YJ.L^([[Q+<7TRR>';$S7.E?;W["/[4=O^V/_`,%,?&GACX%^
M$M4\)?L9?\$YO#_A_P#9V^&&E7]I!:WWBKXA^+M>\3:)\2?B'-;R&<6VE2W7
MAFXT;139W<SW.G::U^PLY-3N=/MO7?CK\9M<^+G[.7Q,TO\`9<\%?$G]DO0O
MC7\49/`VD^-$O;[P/\1O''BS7=!L=9^(OC3P/I4+VVK^!_A)X(\-:GX@\4^(
MO&\_]FWOB?QA>6<&AVT`OF:7H_\`@BM^S/X<^!GAOXWV?@^PD3P[>_%;X:V%
MK=0R3ZA=;_"_AOQ1XIUJZUS5=7D>_O-7N]2\2@:MJ-U<3SM?M+<)<!+I`P!Z
M'\7+SQ`/BM\3A#?7ZPCXA>-!$L<>K>6L0\2:D(U3;=!=@7`7:`N,8`&!17X]
M?&K]J#XZ>*/C)\6O$W@6#QE?^"/$7Q-\>:[X.OK/2M<>TO?"NK^*=5U#P]=V
MK0YA:VN-(N+.:!HB8S$ZE#M(HH`_1GX;_LS_`!R3]E/X8^-K;XAZMXHD^%WQ
M!\3_`!1^#6LIX?U/7?B7^QC\:?AQXC\1^"-4\.:18P+J/B;XH?LX>-X[+6/!
M/QG^$\D)^(-GX3US5CX9M?%.HW"6VD?J=^QQ^T'\.?VF+37/B!X4U+0-(^(_
MA[7=6\/?''X4)JL&J>(OAY\0WTKP997=J]U:;&U3PGJ=GHMKK7@WQ;)8O;>*
M?#FN:5-##X?UN#7M)M/%/^";G[0_Q8^*GP]\9>)/C5\)+SX>Z*VIS>)A\5+>
M32X/AUXT\5C6-6\-_$:[\+P0:G;ZUI8O?&.DZKJUU:3:4(+74-3UN)YW@D1:
M^_[KX+_![7?$-A\1!X&\+?\`"8V]A?0VWCCPY86^D^(YM/UE0;L#Q%X<CL]3
MOX9S-<362R7L\*27%Q/&%FEG)`/BOX7_``0^$_Q4^+'[3^A?$;PA%JI\#_M(
M:QXSLV.N:I9Q32_$7X9:-87L&KKI6KV]I>Z0UG9MJT>EZA:((]3.D7UQ&U[:
M0SU\BW_[/5KX;U'PL?@OK&M>$Y[[3=*AU33EUZW\1WWBC4_C!XN\2>&?`_P^
ME75I[V7PQ#?>`[%OB'\1/%:2GQ+I?AWPT]SX9ET_4[^]NKGNW\3>+?V:_P!L
MWXF:C_PG9?X2ZW\1?!Z^)O!T^MZ-XT^/GQ!U)?@W96?AWP]X2\(:A?1>)]?\
M%SW&IQZX]SX:M]5\67NL>!=7TMT-G`]O-[EIOQF\'Z_\;['XM7WAWQ3\,?@#
M\,O"WB#5-7U?Q1\._$&BMK_QD\:Z)X4TVPU3Q=#%ICR^!9/AY\)K.32S/XXN
M-#N;"W\46MO:V=CI$=B]R`;_`(8^&U]_:GA;P98^&;E+"QM-1T3P5#J=N;:*
MV\#^'%?7?$'Q!\3+AWT[6?C#X^N_#\5KILF+A?"<L]C?>;)%>QUY5^T-J%A^
MS!\/O`/[$7[,E_</^TG^V1XNU7PWX*6*,7=Q\+?`O]EZ3:?'/]I'Q%%;`'3?
M"/PI\#VDVH^'H[UXFU[X@ZSX/\*Z<LR:AJBQ>MWW[8VF>*?#NJZK^QGX!\3?
MME>-_'=S&OA_Q5X9B/@O]GZRLIH7&DWOBKXZ>)([7PC_`,('I%NUW?7LGP^3
MX@^+;V2ZU.[T#PMJ>HZI,U=/^RC^R)XA^%/C3X@?M+?M`>+--^,?[8OQGT[3
M-)^(OC[2=+O-&\$>`O`>D7AU'PK\!O@3H>I322>'/A3X,U*:YN[[5K_R_%'Q
M)\2K>_$3Q9;VVI:S::5I(!]6>!O@S\,/`7@GP?X%\.^"?#</A_P7X6\/^$]#
MBN-(TZ^N(M'\.:3::/ID<][<VK7%Y,EE9P++=3LTUPX::5B[L:*[SRM)/,EM
M;S2'_63&Q\TRO_%(9!`PD+MEBX)#D[LG.:*`/B7]AVQLI/`'QZT)[.U?1+#]
MJ?\`:$T:QT9[>)M*LM'N/$=K+<:5::<4-I;Z;/+?7LDUC#"EK+)>73O$S7$I
M?D_V&]6U24_$;P[+J6H2>'_#'Q%\?:3X;T*2\N7T;P]I6G^/]2M+#3-#TQI#
M9:3I]E:@6UI96$%O;6UO^YAC2/Y:**`.@U+POX9\:_#+]I[4_&7AW0O%NI>'
MO%_Q\CT#4/$VD:?KU]H:>&K?2[GPXFCW>JV]W<:8F@7,$%QHJV4D`TJ>&*6Q
M$$D:,OS)\:+Z]\(_L>_M$:AX3O+KPQ?VO_!.G]H'Q?;7OAZXET6[M_%A;Q;.
M?%$%SIKVTT/B(SHDQUN-UU(RJLAN=ZA@44`??'[&FA:)X=_9*_9DT7P_H^E:
M'HVF?`#X/6^FZ3H^GVFF:9I]O+\.O#%S+!96%E#!:VD,EPS3R1011H\S-*RE
MR6/TL$0$$(H(Z$*`1\NW@@<?+\O'\/'2BB@!^2.A/YT444`?_]D`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V%V871A<G,O=F%M<&ER93(N:G!G````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-S(V-P`Q,#4Q-30S,S<V-P`P,C0V-30`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````_]C_X``02D9)1@`!`0```0`!
M``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$`````````
M``$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&
M$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ
M0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66
MEYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3E
MYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<(
M"0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(
M%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*
M4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.D
MI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T
M]?;W^/GZ_]H`#`,!``(1`Q$`/P#^M?X4Z)X7^.?QA\(?M0?#&Y6^_9^^-'[$
M.D>$?!-U8:2=,M-,M]>\>S>+HQ'"MP++1;G6?#_B71Y6T(6?VF^UC14N`U@+
M*_@D_(7P;X-\>?\`!0/_`((]?ME_\$U/%G@Z/3_VIOV+=$U;]G3PS!=Z:EK;
M>*=:^#T8U3]G/QYX>?4Y;-K*X^).A>$])T5M4$[6EM=WMSJES']CO?)?H?\`
M@DWXE_;8^`7[*>F>`?@-^QG?_%/]F"?QM?7_`.SQ\6OB?^T/X:\"^(==\&^.
M?B)K<OB;QQJWPJU33=0\4>`OAWHU@+;6M'\*6T_B#7Q!<W][ICZO97;3-^]N
MG^,?@_X=^/.N_#N/Q9I3?'GQ]X!T7XB:_P""+6Y']I)X#\)W,7A)?&VHV)MY
M8]-TQ+^YBTFUO_$%[)J&IFTGLM'MWM]+NV0`P_V=!X3^$WP?^!7P'NKO3O#G
MB#X?_!OX9>$%T"ZOX[@6=[X>\'Z!I%UH*:LT[V=]KNFW5DKWFD+>#5;JQEM]
M8CAECD%P?H[4M1CTK3;C49X+N1+2V,\MM:PBYOE13AV^SPL_FB(`EC`S*V&*
M!EP1_/[_`,%2O$?B;3]#^+_BG]EWQ=\1?AC\=?A:=+\6>*_'T/CPW.G^"C?W
MFC6,&B^-?@)\0X/[)\5?!KXOZ1IMG#H_C7PC)K.CR^)%FT&6;0O$$=Q8GX7_
M`.",/_!PS=?&WXG6G[%_[=MSX:\$?%N\U`^'_A)\8;..3PYX-\9Z_90;;GX9
M^++;6+J63PSXKN9@I\)>?J/V?74$.C3WB:W]BDUP`_?_`/;>\9>%_&7['_[1
MEWX;\1Z>==^'_P`--7^+FG0MFWUBPOO@O<6?Q<M;@V.J"SN+*&UU7P?96.H:
MC:SE=/FDMKB*\L[V"",?5&L:)X$^.'PXTL>(=#T[Q5X2\8:/I'B6RM;I3,95
MU+18-2TRZTG4XOL=]I6KQP7<5QI6N6$UEJ%K*BO;RVY(47/B/\+?`/Q9\/:C
MX5^(7AJRU[2M7TS6-%O8I6GM;JXTOQ-HMWX<UB".^MI;>[AAN=.UJZLY+87C
MI@Q.`\\%M)'\'_\`!.?Q+\3O"'A[XG?LC?%_Q+9>(/&G['GBD>`="UN&RM'O
M_%7[/.JO?3?LW^)=9NH=9>2Y\0V?PZ\/QZ7XPNWLO/O]3C99';55N9W`/H6#
MX)_M&V$$-CI7[7/BE-+LHH[334UWX;?#;7=;2PMD$-FNLZY>:(]YK.JK;I&-
M0U6[=KG4;L37D[-+,Y)7UBD2*B*8TRJJIRD9.0`#DJB*3GJ550>R@<`H`^(_
M^"=&I:?<?L;_``(\*V]A!H.O?!_P+I/P"\?>&Q!##=>&OB1\#7F^&'C;1;^&
M`D6TL'BCPSJ%]IMM(8VO-(U2R\1D7%OKMI<2<KHL/PT^`7[=/Q2U3Q7JFHZ/
MXB_;2\-_"ZY\&:_XH6T'AG4?%?P5\-:EX4U+X3>%?%!\FWTK58?"KZ5\0K#P
M7J%U_:&LWNH^-?$'A:WOH;;7(8OP+_93_P""FGQ?_9T_;DTF#]JOP[X(T+X.
M?M?IX<\+>._BM\,-2O)/A5K'QKTVVT[PG\+_`(_:=H<T"S>%;GQYIMA9_"SX
MS6&@F;3=-U*W^&GC#4+:R:/5[KQ#_4-^T)^S_P#"?]J'X1^*O@O\7/#L/B'P
M7XLL;>22"&\N-,U?PWJ=E/)=Z!XS\&ZYI$]KJ?AGQIX5UQ+?6M!\2>'=2L=6
MTS4K6"XL]0!6)'`//_VH?V-_V9?VK-.T*\_:&^'6D>*)_`*ZI<>'_$5UK7B+
MPO>:%#J5M&VJZ??:QX:USPU<W_A6[2&&XU?1=:OIM"OYXO.DL5G*M7\('_!3
M7_@E%\'?V7M6^)G[8OP&_;)_9P\76<7B@:YX/_9;N;:P\1>)]4L_%MU8:)?Z
M5H6G>,O%7BP>*;6RL)YM?GN=3T_4KC2[R4RQ/#)!`R?NS\"?VN/^"I?[`?[2
MOQD_9!_:?^%7CO\`;W_9O^"OP[L_B!\._P!IKPCIVFG]I#4_@YXHU/4M)\!W
M/B+3X;^SM_BCJ6EZIHMUX8^($]KI8\8Z3K(LM8(O-%OX9V_5/X=R_L/?\%5]
M+\)?M`^#-8A^(VE_#][OPM+H\OACPUINH>$M?N)1J6J:1K\GB#P=>^,M(UFW
M'FZ9=-X=\26.FW(M!-;&2.X%R0#^=;]@;QE^V'\&?^">S?M!?%G]O;]I[4/$
M?@SXI6'PMT;]GWR/#OQ0T>QU*\A\*ZG\%O"^L^*?'EG;^,]$?XKWNKVEKIGB
M<ZAK_@QO"VH:?)'Y6H2I=C^JC]D/]F#4?@+HGB/Q=\2?B%K/QB_:)^+T^B^(
M_CA\3M<FME74-;TC3Y+2Q\*^"-"LK>WTWPW\.O"\M[J-GX6T>VMTN!9M'?:W
M=:IKL]SJ3\!^V)\&?V&/#WP,\=^/_P!I[PAX+\*?#+P=X3TZ'6O&MO=:CX:\
M4V5CH%K9^'/"]IH6M>';C2_$&I>*[*Z30='\!6$,]YK-QXJ;1[33+226"RCN
M>Z_88^(_Q)^)_P`!;3Q3\19=:OHI/$VO:5\.M:\8Z3;Z%\1?$7PVTDZ9::7?
M_$O3-+V:*?'\>KG7="U>]\/VEAHNK1:38ZU9VZ-J,\TP!]H`8`&W9@`;1@!?
M]D!20,=."1QP<44!=H"]=H"YP!G''0<#Z#CTHH`_`;]K>Z^&_P`=O!^N>$OV
MD_\`@BY^T]XF^".I6<*1>-_`.C?`[6_B5ID)CGO8]1MOAY\*?BQ-\5_#20")
MH=2N;1OM\D'G6,NGR17$MDW5?\$B?V[?`7Q0B\5_L43_`!H3XL^-O@+I\E]\
M(_'7B&PU?PUX^^*'[/MEJ\6DZ!;_`!&\$>);'1/%7A/XU?!B5[?X7_&71M0T
M9)KC4-.T+X@I<W]GXOD$'[G%%`5`H54(VHGR(I5PZ[57"C#`=N1E3E20?S>_
M:_\`^"?G@3XP^*-)_:=^".A^%/A3^W;\)DG\0_!CX]VMA+IK:IK%GIUS9MX%
M^,"Z&UK)XW^%_C/39YO!OBZTU>UU36-+T:]M]5\-7>F:GI5M=Q`'1^,=3.C_
M`/!2;X/IJ\2:9IGBK]CGX[^'O"FMW:7,,/B;Q=I/Q<^#'B/7?#-K=K%%9W&L
MZ3X+TW4O$5IINY]031X-;U6TM;^QL+OR<WP!XI^"?P>^.OC_`.!W[,?@VW\7
M_%7XK_$S4/BU\>3X?ETK3O!'PQDN=)\.^']6UGQ+J-M'!%#.FGZ5I5OI7@C1
M8K^]N?$EUJ<VIWUG=R7CR:7PI\9_!K_@HM^SY%<_$+P7<>'/&/@[Q7>>%OBI
M\-[O5;G0OBC^SC^T#X,ADT#Q1I-KXFT"ZT_6?#GB70HM1U;_`(1WQ9H%Y8/X
MI^'^N6MQ93SZ%XAU&TN?P.TK]G[]K;]BOXL_';1O^">OC/X:W'@7X73:C;?&
M?]H/]I'X=Z[X2T;3+6#PS?\`C#Q./%OQJ?4[_P`)^/[OX<37&@:-I'AKP9X5
MN##XNN]2U[QMH+II$"S@'[!?\%!_$'@#6_%/AKPC/XBTWXA?%;3--T[PS\%/
MV?+OPW9^(O"</[2GQSU-/"?P?^,OCJ"\DU+2K[4OA?X1TCXA>./"^C:K979T
M30/"GCGXA65M_:6F^'IQ^F?PO^'^C?"GX<^!?AMX?EN)](\">$_#OA2PO;F1
MGO=2@\/Z/:Z1'J6I3&21[K4+^.U%U>W$TDTD]S(TKR.P5A^1?_!,?]D_QM<Z
M)\,_VR?VF[32E^+/C3X?6_BSPIX'$^MZUJWA/5_BCH$$OCSXN_%GQEXJ$.O^
M-OCMXX\*/I/@S5WU+2M#\+?"GP!I-I\,OAUIFG:;J'B"+4OVP&<#<,''(]#W
M'WF[_P"TW^\>M`"`````````#H`.`![`44M%`#8R2B$DDE%))Y))`R2>Y-5+
MKBWNG'#Q07LL3CAHY5MU19(VZI(%=U#J0P5V`.&()10!^2_P;1-"_P""T'[:
M&AZ(BZ/HOB#]CS]E#QKKVCZ4HT_2];\92>-?C%X=D\6ZOI]H(;34O$TGA_1]
M)T)]>O89M5;1M+T[2VNS965M!%](?MQV5GJO@OX%:%J=I;:CHFO?M@?LRZ=K
MNC7\$5YI6M:>_P`6]+O'L-6TZX22TU&S>[MX+IK6\AF@:YABG*&6-&4HH`^U
MRS%$RS']ZIY)/(TQY`>3U$@$@/9P''S`&KP54`1%5$0;550%557A551@!0``
M````,#BBB@`HHHH`_]D`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O=V%C:V\N9VEF````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C(P-0`Q,#4Q-30S,S<W,``P,C0Q
M-S4`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M1TE&.#EA(``@`/<`````````,P``9@``F0``S```_P`S```S,P`S9@`SF0`S
MS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9_P#,``#,
M,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`
MS#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9
M,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_
MS#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F
M,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,
MS&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS
M,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9
MS)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`
M,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QF
MS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_
M,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\S
MS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9___,`/_,
M,__,9O_,F?_,S/_,____`/__,___9O__F?__S/____B_)```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"'Y!`$``-@`+``````@`"````C^`+$)!$"0H,"#
M)`B2.(BMH$.&#1T61`BI(B02&"4^'*C1(#82%D->[.A1(Q*/($6&3*CQ(,&3
M)PNF5"F2Y42(#DFPF4FS9DR<#GL*K4@""42,.PD.';J0HD6E%Y>JQ.B4J$RI
M(P'HO"B0)R2%0C%FS,GU8TVO%S&N8'7M&JL5!=_NK$J3Q-JV>/&^#>"V:5>F
M;/,*?MN7(5J+"04KOK86[M&55@$L;LO*"JNW@?Q2U*DQL.(5@=8&\&B8#<F[
MBN/*Q&E3(^J\J@FRTLQ9XN45=E/+UDF"%0"GK253OFPE+URM%9-V97,Q:=RV
M*Z)[=HN;^<CE&"V:)GB7[5O/EM]C9N3H-3B`N]RG4VX*8"I#AVL+OJ;NLB9$
MP[XEP@U0PNA`Q)K=UUMG`9AP@E]:476?@.U5=!XK)9QPPF\+5OC>3+VM8."$
M%%I8(4^]!2#A"05VZ.%CD0&PH0DFF'BB820]%!```#L`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O879A=&%R<R]W:6YN:64N9VEF````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R,#4R`#$P-3$U-#,S-S8W`#`R-#,W,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!'248X.6$@`"``]P`````````S``!F
M``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_
M`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F
M`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_
M,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF
M,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_
M9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF
M9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__
MF0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69F
MF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_
MF?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-F
MS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_
MS,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F
M_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;_
M_YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F
M__^9___,____^+\D````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````(?D$`0``
MV``L`````"``(```"/X`L0D<2+`@```%$RH<>!`A00"D2#E<2!%`LV?-$#9L
M*)'B0HL8GQV\2%)D0X\&0UX$H+)EQH,HL8$D.=-ER),554)L.?+FLXX>698L
M*=0E4)@&20TU6A3B1IP,ERX]2.KF09-(!=:4BI&J5(E99=K\RO4B4*U5RXZU
M.5&KVK<Z4\(EZK*MV[53E?),6'2NR+U\_=)\^A'O6`!NW-AEN-7PX(J*^SKN
M6A&2Y9YS%VMM:!E20[8ASQKL?-!-9\^'-RH$<-HS:])7S49$3'A@:]BMG[Y^
M?=GA[=.\?WLV#5R@\,ZF@^/.C?"X\^&W(69TS;DU\>>7:>I4[CGZ[Z)UN0A3
M/_A=;[.````[````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W=I>F%R9"YJ<&<`
M````````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,3$T-S0`,3`U,34T,S,W-S``,#(T
M-#$T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`/_8_^``$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$
M`!\```$%`0$!`0$!```````````!`@,$!08'"`D*"__$`+40``(!`P,"!`,%
M!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()
M"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T
M=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%
MQL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!
M`0$!`0$````````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"=P`!
M`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:
M)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#
MA(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3
MU-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`_GWN[2UO
M[6YL;ZVM[VRO;>:TO+.[ACN;6[M;F-H;BVN;>97AGMYX7>*:&5'CEC=D=65B
M#Y7X+>[^#]EXB\'6'QCO_'FE_$_4M,\=>//@]HOA'7=*U;X9Q?!&R\7>%/!G
MQ%^*VKW&D>$OAOK&B:=\,O%/B?6?!M_\-+_XD2^&O!1^*>K>.[;X/W6EZOHO
MB;URMKX._#7X*^&O%'A?]I;XM?!/PA\4SX?_`&K/`46F^%?$/Q`T6_T3XB>%
M_@S!X'^)GQI\%^,OA!JNB:W)?V'B'3/$GP0\+:S>:_9W'@G4?A[X[\3^'VM=
M7U/QE9W?P\_N;Z3"XDP>-\(\\X-AB:O$^`XWEA\NPV%P&"QW]I/%X&;^HX^&
M-]BI94G1>+QE/`X_`9JX8?GP->5..,P];+@AY?-9]0S3"1Q6#>5/$UE+$UL+
M*E2H5H0KU*-:EA\7"EBHT:\YX6KB,-7P_P!8ITJ,H*=:G5I_87Q&_P""<?[:
M/PDO[/2?B/\`!&^\*:K=^$](\;2:5J/C/X</J>D>'?$OBB;P3X/F\3Z?:>,;
MF[\(ZEX\\86FI>&/AUX>\4PZ/XB^(FNZ-K^E^"-*U^\T#6HK#V;Q5_P1_P#V
MVO"G@NV\977@+3[U93<07>BV&HW$MSIFHV>DOXFN].U7Q"U@O@/0KBW\)"/7
MMGB;Q=H4UW*S^'M,@O\`Q,]CI-_\OV'[;/QF\3?$3P]X+\,>$(]<\=ZA?^!O
M&?B7PUX=C;6=)\:ZGI7BM[;1=5T'PK<>--(\9_#'PEI&E^"_@/\``FYL/!OC
M7PU=6_PX\*Q:]:>,/%?Q"TS0=%K^IC_@F-)^UC^UE\0O'GPI^-'QI^'&I?"7
MPUK?PQ_;6T'5_@KI'Q(U3P%KMSXRA\#ZK\!O!7@O4?C!9>%_&&H_#;X=W7P]
MT[Q7X<B\8^'M-^,/P[\<?#_1[GQ;JK>+==O1H7XGG_TGO&C(L_RK)\^R/@_)
M,?@YU<%Q%E.58+/,WC3SZC7Q,*V#JX[%RI1K9"J.&57"YQ@)82KB:5:C7JQP
M\<92HX7U<+POPOB<GSK$T,=F%;$8?$3J93C<54PN#PV+RZE/#02G@:2Q>*HY
MG76)A*&%J598=R<U#%-8#%.O_'#XD\,^(?!VMW_AKQ7HFI^'=?TN2.+4-'UB
MRGT_4+1IH(KJW,UK<I'*L=S:3P7=K,%,5U:3P75N\MO-%(^'7^C?^UU_P2`_
M98_:%^#'B7POK-GXPT#Q=I_A=[3P#X_\(2^*]=\0^%/$6D:KJ=[X'U%/`5OX
MFM/"7C6SMH==U?0O%>B:[ID(UFQ\0>)M?\/>(OAEXIUW6_&4G\8/@S]@SQUX
M,^+GC+X<_$K38Y?%'P[\8W_AO4!91WK>'M0_LV\DBT_6-#N=4TW3M0U+2?$M
MNMEXA\-:F=,M_P"T/#=_8:G';*EP\5?T;P7](3*>*<DFY93B(\7TJM+"PX<P
M<ZE2&8U*E)-9AAL94H^SPF6\\:KQ,:[KXG`*,**6.K5\)]:^&KY14I5+JI%8
M?1NM-Q3A=M*#AS<TY;6<4H-M<SA?3\ZD\-ZY(B2)ITY5U5U),:DJP#`E6D#*
M<$95@&'0@'BBOZ/H/V./"K00M<?9EG,49G57<*LQ13(J@6\H"A]P`$LH`&/,
M?[Q*^E>:^-<FY0R'@N,&VX1G+-93C%M.,9R68P3DD[2:A"[3?)'1/-4\LTO4
MQ5]+VG1M?2]OW;TU?5^N]OYI:IZ)XGM],UOQ]X:MO#G@Z;4?$?A3P*VI>*KZ
MRUK5_&EEHUIXC\3WMOHND'5=0NO!OA/3;K5-*@NQKWAG0;#XAZDJ:]X>O/%$
M?@O4]8T#7+E<-X?T\Z=XP\?,]QISRZ[>Z%X@%K;W<LNH6]E_PCNF^&[2XO[2
M2WC2V%[>^&]7CMC#/-#)%8!PYG>YAM??\0L+@\;5X!P^/HJ>&7B+D&*6(E3G
M6A@L9EV$S;,LJK2I0UD\3FN#P.64JDFH86OCZ6,E=8=Q>N3UZ]#^U)8=QYZF
M38ZA*#Y5.I0K^RI8E4I.$W&5/#RJXB?)*E*=&C5I.;IU)TJFUJ'B74O`/B7X
M?_$;0+>^7Q#X/\8Z;-9ZOID4[7NF:;J.ZUUFWDN+*>&^L['6(5@TX7\4.H0:
M#K4FA>+;K3V7PVE]8?3_`.Q]_P`%!?%O_!*3X@>'?B#;:3J7C'P`+3P3\&_B
MGX7LGM-?C71]$\:?$;7M!M],TG7O$M_#!K_@3P;IWB#3XH+VZL_#^M^*+33/
M$UU8:UHUCX8U.V^3?'OA^;Q%X9O[:Q!&M6<<VHZ!,B0-/%JT-K<0I%!+/<67
MV4ZG:7%YHES=6^H:7>0V&IW9L]5TRY,5];^,?&?Q5X[N=&NKGQ'I.DO<B\\&
M>+?$LW]LWETZ2:#>^'=)TFYT#5[BTL;^#Q?/J0\06\=YI$\JZ#X<FNKZWL-(
MBUQ=&L?Y(^DYPUF^%XPQG%:PF(HY%6R#*JCS6G"K+!RS/#XF67_V=B*\:'LZ
M.-K1>#J4:$HXJI5PM.5>E4I4Z6*^J^]PI1ACZV"R^-2*KUL8Z$J<G2BY4:SI
MN,82JXC#INK5M"E%UJ$98KZM!^UE.-*?]*&C_P#!4W]L3_@H-XF^'7[7,?@K
MXZ>'/&GPO^(GC3]JC]G?X5:/\/OBIXY_9'\3>`O@!X4OO"6F?"/0/A_?S>#_
M`(??&/Q%X;\?>+=:_P"%Y_M'ZIK&E_$KP=XBU"^O_@WXPTKQ9#^SS^RUIWZK
MQ_&OX=_M4>+M8_:;^'5O;1Z/\4['1->N2S02:M;:[J&AZ9<:II&NP6OB'Q-I
MVC^(/#"/#X:U;2=(U*6TLY[%[:XFN=5BU2\O/PF_8#L/VAO@5^Q;\;?$OPY_
M9Z\9>`/@IK'A?Q/KTG[0>H^!_&7@W3]>\.Z?\*?B5K&E:MI'C&XTJ+0/%UO'
MK6CZ;9^`+OPAK`O-8'Q5:XU#1_#_`(;\;_$3QMX4^]/^":?B'29_V<Y?A[:-
M;1:M\)OB-\1O#.KV$-_9:DUK!X@\6ZKX_P!#\B]M;Z6?4=,M-)\60>';+4]0
MTCPWJ4MSX=U'3=6TF?6])U76-4^$^BE3P5/Q3K1HYAC<4\32S_$8BCC\9B<0
M\+CIX3+L9#+<+#$2M0PU+#N&-H83"PA@Z<8NK24JGM)S]#BZ6)C@\)2KX/#X
M1T<!@Z%*5#"8?#2Q-"EBL93>*Q$\+[F)QE6HI4<37Q#EB4J%*C5?-#VE;]!Z
M***_TW/SD_S?_"/[37Q4\*6=QITM]9^)K9)VA@E\7PZGJEUIQ2\B-T8]3%QH
M^HW4<TNHR#9XBU>Z>SMX=/M(IM/C@$>H^U^$OVAM0U*W\=?$R\\+0M>^'_"?
MPWT&^T6RU22VM-2N[OQ%JR-JL<TNG76IV-J9?$TAM-.>RUEHE@\NTU&^^UW-
MU#\C^-_`=UX$UB"&*]T_7_#E]Y]UX7\9Z-+;W6CZ_I]MK4-M*UOJ5E/):KJ&
MERXM=8MVOM/N]-OI6MCJ$VFR:5<ZAIV6EWME\'-0UF.[*)K7Q&T+PW=Z:@<H
M)])T36KR%-3LX)D:2.62XMKQ;633;DRWND6]Q</?/.D%A_E)F?'_`(F9']5X
M>S/B3-J4\ASC)\;@\+FDZ&93PN-RK%TLQRNM0KXR.+=?#>[3GA73Q%?`8O!5
M:,8QQ.75(0E^NX?`Y=B'/%X;!4Y/$X/$0JRPBE0I.AB$L-B8SC2A"$7%5YRD
MITJ51>QG&,J->,.7[\^&?[3/@;Q_<6&D7Z3>$_$FH306MII]]-]NTJ^O+M[_
M`.S6-AKL5O;QB]:.SC3[-K%EHLMW?W4-CHJZONCGE[+X_P#P7EU_X?:!XSTC
M3M(T_5[KQ)J-QK5Z^D/<ZSK?A738]!T6+4[>^TR6ZU`Q:!<7>M[](_L::;6X
M[`QRZC87&F>%=.\2?D.B``2,T:(VR)FN/M#2)";1KBW$MP)+:81O:,^GS1Q1
MP175LH?3;;4)XP8?Z'/V'/"6B_$V7]G/X7>)'NO#G@[2?#SP>)M$N[C4[+2[
M5[+PQ=^-_B?##::9K?A6X\$7?C6S\/P+XP\8-JTOB+4]4DTU;:WNO#GASQ/X
M?;Z[BCQHSWQ"X(7!W$F'PU7'T<RPN8O/,)AY4<3C,!A<+BZ>)PU3!8?#RPU+
M,:\\0J5/%X*6"H3IU5AY9=.$JT<1YV$P=3AK,L/FV6UI4Y^_35/VD9*G)5:5
M2Z523E.A*"2=/$4\1&$DW[6=2-.</K+]B/\`:(TK2_AC\,OA-IOCCXO#PKX0
MO](\/>-?AM\8AKMN-,M=6O;./Q,J?#R*&U\-ZM%ING7NK>`=.=/#VJ3+I;-&
M$O?$4>EZ^OZ<_P#!*;PU!>^-/VBO@!KGC/4;C5="ET+Q5X8U&;PI)O\`$,7A
MBUT;P;K_`,1KR_\`[6O4BLO'_AO4/AA/I&D3>(]>LM8M+"'QIX2U6UBNO%VG
M:E^:?QV^&B_`_P"-GB-](FNW\'^,/&FGV<$SQ>))-/TG6M0L-!O['2&^T:M>
MQ7+FR\5ZA87\MHQTFSOKWX>S+H6B65M=25]':;\6-:_98_:)^!/[5'A^Y-II
M7Q&\-7B>-])\.%->U?5=+L)K/P/\1[&*PG\9Z;'?ZYXGT'Q9X3TFXDO/$FJ:
MOX^^(4%@_BK2O`,^B27%Q^3<'YAF'!N-P^;9=G&/HYS@,1CL3A<74G1J/#3J
M4*\J5"E+&4JN&^HXB%&CA*F'K3H2J0Q6,RZ$:^#Q,8XG;.\;#/L4ZCP.$P"G
M2PU/$X?`T94L/7=*E!2Q=14E/FG5YI8JO&E4JSC6IQJXF*Q-+F/Z)]5_91^-
MVEZIJ6F#0?"]\-.O[RQ%[#\3OA?80W@M+B2W%U%8Z]XQT?7+.*X\OS8[36=(
MTO5;=7$.HZ=8WB36T17["^"K;X#^.O!OA+QMX,\+^/=?\'^,?#.@^*O"FO0Z
M=\3[&'6_#7B'2K35]"U>*QOYM-OK./4M+O+6\2UO=.T^[MUF$-Q96LR/!&5^
MS/Z5?B#!N$Y9#SQ?+*]7"P?,K)W@\KDX.^\7*3C=KF=KGATL@P$Z=.;H<2-S
MA"3=/AK'U*;<HIMTZD,3*,X.]XSC*491LXR::;_Q^_"/A_05_:,^*'@M=$TA
M?!T_A.TFG\)C3;(>&IIK"T^&5_8RRZ$(?[+DDLK[5=4O;1WM2UO=ZE?W,)2:
M\N'D]UM],TW1/^"57[=^J:+I]CI&IW/_``4`^%_PWN=1TNTM["^N/AVND^)?
M%*^`I[NTCBN)?!:^)_!7@WQ&/"TDC:&->\)>&=7%C_:&@Z5<6A17Y_XX?\D=
MP/\`]G(K_P#KT<Q/K.'O]\SK_LE8_P#K)L_&V]9HI8TB9HT%G9,$C)10UUIE
MH+EMJD#=<#B<XS,.)"PK^U?]BWP]H%AX&^%6MV.AZ/9:TFI:1.FKVFF65MJB
MSZY%\(-.UJ9;^&!+M9=8T^YN;'5)!*'U"SN)[6[,T$LB,45\5A/X_P#W(9C_
M`.H]8X<=_O.%_P"QM@?_`$[EHO[=&HZA=_!/XBW-W?7EU<Z;XDCT[3KBXN9Y
MI[#3]3^*G[0^DZE8V4LCM):V>H:5X>T#3+VV@:."[T_0]'LYTDMM,LHX.`_;
M8OKW2/V0?"(TF\NM+%O\:_@\D`TZXELA"DO[.<'BV5(A;/%Y:R>*KV\\32*F
MT/X@N[G66!U*>6Y<HJJOQ8W_`+!,-_Z?KGEU_P"'EO\`V,,5_P"H*/PQF\+^
M&;B66XN/#NA3SSR/----I&GRRS2RL7DEED>W9Y))'9G=W8L[$LQ))-%%%?'O
M?YK\X'Z_A_X%#_KU2_\`2*1__]D`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]W;VQV
M97)I;F4N:G!G````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$Q-C4W`#$P-3$U-#,S
M-S8W`#`R-3$S-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"
M$0$#$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"
M`0,#`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1
M\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E
M9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:W
MN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?
M`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$
M!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0T
MX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U
M=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%
MQL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_
M`/T\^-7C;5_$7QU^.WP.UC3;32KGQ)=^(?`W@/Q;JOV33K3PSXC7Q3X>\82W
M.MZQ+"1IW@+Q._PYT?6;[5(Y;R[TV_ACF:SMH=5U4C\;/VR]4\0_&NR^''P/
MALM'U^Q\->)8/CGJFJV=ZDNEP?"OP9X`\9Z;<7XO+83O=W>IW^I^&M&TV2WC
MFTO55\0"_MM0-FXD7]:OVJO!^N?"+3_A/\9?#\D'Q,^$_CF;6$LOAOJ%[;V_
MBRU@(^VW/AK0?%MY97^JSWUIIDDVD:9X;\5ZCJ6FV,*S>'[==!M+*PFL_P`:
MOC!^T%:>"-!^%GQ/^&NGVL.I3?$SP;\/+;2]>L=&N-+\2?LO>/\`P[\2+G5O
MAUXTN;PZG'X>U^U\1Z;X=\/VNNP75O?:!XD6WT"ZU860ELF_S?\``[P[7"7C
M1X3YSGV78/,LAPG&&%7#N<\.8^>+PT5CY8V&%GB*./PF6X["8JK5JTXX^%>@
MZ->5;&2P%3%_5\3B#]>SSC;+^+_"#Q$R+(Y8K`YC3X3Q%3,LOSK`1P]6GB(4
MJ6'K8K#5\-5QE&OA)4:5.I3C1=26&E"DL6Z3J*G+L_@S\5OA!9'Q1XX\9:A9
M^'/`7P#_`&=?`FEZ[J]SO\V'QA/K/B_7M5TD:7:K<2R6TTOB[P_I^BQ6B37F
MH7MU<P1VR^3;FX]S_8?_`."E'Q"^%GQ(M9+CPQXYUG3?$GBKX>ZB_P`-_P#A
M&-2U'Q#<^'_$'A?XHF&]B'D6MN(=8N[70+W1+BTO-1TF\&G:R)]6LU2&YD_F
MA^*/CZWTG]IKQGX4F?64^"7BKXO_`/"=7OPHU6=X;W4+/PC;S1^`O#?B&.26
M&>\M8O\`A);?4=6TV_OI=%672Q`8[B/3Y$/[2?#[]KSQMX7LO&7QPU_5K9/V
MC/B2=!T?P7K.@Q2V-QI.B^$YM5M=#T^#2GMX6\0:9H&G:C;+#J>M64D,D\4V
MHO;NT7AQ-*_V4>9<59[Q'/AO+<CP%3A?!X7%8C/>(,PKNGRXNOC7++\FR?#1
M@Y8O&8QNIB<5B*CI4,MPE*D^3%XG$TL*_P"1,JP64Y%P3EN<YKGE3_6#'4J2
MR[)L#2C.?^R83#1QN:9K*:<J&7T[SPF$I4IRK9AC83@O9X3#SQE+^I./]IOP
M]\6/`?BOQ_H_A&]NK9X=0.B:2D^E:GJ.D_9+2Z47&LB&[1+!+R9"\2M&LI2&
M;!DPCU_-=^U+^T'JOA_XN:;XSBT/4["_\-:_H/B6R9T@-M'?:;K5O>P)*K3Q
M1,DTMF8_+";=D;1*^SYV^E/A'\8(_">AZ9X$\/7-SKFM>*H(+76KF0:5J$>F
MO<-);Q>?J=G;R1F[@^VR2/:Q7MW:^:LD4;M'&ZMZ9^U!^R4=;^`'C+Q))I,=
MUX@;POJ-_8:A);3J]AJ%G8W$T+198Q7P$H5T4>:K,P4!0HV_K609/ALFHXFE
M/GA/$RC3P4I5;QDX0:^&::5.,GR.7,W-^^MT?+9OF>+S.A%T6G4HI5*VG5)2
M<79+WY12:CJHZ0O9-GPQ>6EOXDN[KQ%IOQ*U?2=.U^YGUK3]*F\])=,LM5E:
M^M=/E2._EC22R@GCMG2.65%:,A)'4!B5^6]K\:/$NG6MMI\KZJDEA!#9R(LE
MOA7M8U@=1YL+2X5HR!YK-)@?.Q;))7N?VC66CKU%:R:]A%VMRW5^;6WO?U8Y
M5Q#@K+FHJ]E>U;$)7TO9)::K3MIVU_;#_@MU^V-XRUGX3_L]:[X=A\'Z3=?$
M#6O"'Q.T&7P1X3U&TFU"^UJT;7/#,&C:M%XA\1/X@2ZFET^)+[4;/PWKDTXQ
M<>&-+GN9--M_Q2T#XR_%KX1_M%^&="_;!\)36OPH^,FJ^$;/Q?X*\%:[%!I"
M:YXCMH-/\#P>+]*:":SU&T\-Z[IEC?\`Q)T+2M1L[&[MUNY;J35;RQT#29\K
MPKX^L?B+X9\,_!GXJ>,/$7_"J]`\3WGBK08[%)]5USX;^-A;7TFG>*_"%L-0
MLL3/J4D=K?:)JDNI^$)[75;S6-0\,ZIJFFZ3>V?U#^T[\&/#GBVR'[:_CC0+
MN7X,>`_!ECF\L;&]T+P3XC_:#:V'A3P9\(M-U.[U:^M=1\06^I:'XX\:WUEX
M'U"+PAI7P]\-^%==T_2[;2O'.G$?YJ8!\-XKAN?!&986>4Y;GM+,LJSC#9/D
MN-S;,<5F^85JM;(,WP&9QJJKDSPE>G5K8;$^PKSP^;?5:3Q^"C7H5L5_7/&'
M`N;>%N?U<QA&6;RA+#YIPYGTL=_9V!>6X67L,PRW$8145'&YE)2HT<=A*>+I
MPHX*?UE4,;&<H8;]?/@-^PQ\%W\6?%'Q)\9_@3\,_B59^'M9U"RLM$\2^'[.
M;P_X'NK#4?$`@\/^%KVZ\.^:?!]O=Z@!;P"QTJ:SLK#2K%;.]C@2.W_"N[U"
MU_9)_:2UOX;_`+4'PJA^&6M6JZ=K6G:A!X9\)6GPQUG2)MDB:QX%O-)+6^K"
MYCE5!LALKJTN[66RU^32+U(HF_H>\"_M*Q:_\'M075_$>F>'/$?QH^&WP<_:
M&\`1QZ?)>:9XYT?QYI&@>-/%*:!?1*]K<7/A[4KZ_P!)U#28A<75IJ-A>Z'/
M]EU"UDM'^,+?7?&/[3WAV'5/VL_"/P1UOQHEUJ5CX*^&WPY;3O%.G^$_#!^S
MOJVG^)M<LE9]=\3PW%G`?$VM!1;)<((6E\R%I*_D/P+^DI])GP^QW%>1\?9K
ME.-X#R*KA>&.'85LMRR/&F!ABX3H9=G.2YC.C*6(R["4<#F%;,*'$>$QV(I4
M8X.4<30PZPCQ_P#0V)^C;X?<<TLKXQH91C\)'$.IG^(P-&MF<\LSU1PN48G$
MX3%X>G+`QH.MF&9O"8>KEF,H\U6.*G1ISJ8/%U<-^D7_``3T_P""D_[&WA#Q
M-:V&GW_AN34/$NIZ)8'6ICX7N=9%W<33Q6!2XN=42[M8X99F2"+1D3R`TC"T
M,@19/TS_`."@'Q+T*T^$'BWQYIH2^\$>*?#T,UW/HLD-S<V/BB.&[BAU;4AY
MZVT6FZO:VFG:='<03N\&M00.\+S:Y),?X]/CS^P7^SMH'@";Q5\+=`OSXXU7
M4;/1O"^J?!G2O%_BGP=H'BGQ)JEGHO@_4/%GCG3[BZ^'_A6U/B"^M+8N=6O;
MI9!=*(X;R(+']^?\$_/CS\5/'?[/WQS_`&(OVQ/$^ICXI>'UU*+PV^J)866M
MZG\--1M;*.*ZM[>*RMTUA_"7B+3K^9;R*&6ZM+E=)N[F8-,9'_:>%/%S./#[
M'X7CJ7&F<<=\-PS?#XWB7#<5KZSQ;1PN(K8:CB\3EV.PU7$4\SR^E3G##U%.
MIA?[+QT\!%TYX>>)CAM>/?!+*.,L!47#G!O^IV84L$\-A\#EO.LBA7I4ZCP<
M*N%Q-#"X[+:]6=*=:,I4<9A\QPE/&5:>-=>$8U_CV\T/X?ZA=W5^+*QE%[<3
MW8EEMH!)*+F5IA)($#('??N<(Q4,2%)&#17.W_[)'[5UA?7EA9^!M7U>TLKN
MXM+75M.O=/?3]4MK:9X8-1L7\P;[.]B1;FU;`W02H<#.**_U2H^-'A!7I4JU
M/Q/X(E3K4Z=6#EQ1ED).%2,)Q<H3Q<9P;C*[C*,91;LXII(_S^J>&'&,*DX5
M.#,_52$Y0FO['QCM.,DI*ZP[3M*ZNFT]-6FS\>;*PN-.O[?4;5=JL46>/&Z*
MYRGE,)`%W*\C%96(90O#$KG97[<_`KQ^/V\/V6_A-_P3T\2V<?F_"SXM^(_V
M@I=,E6WLM*^*V@>#_A1XG\,^$?!4<EBR:DFOZ)=ZGI4-[;-`R:WX6T9#_:;7
MROI[?C%;0/\`O&W*D)\MXXRQ#/(&(&TLY\O<!D%2BXVH[E2%KZB_9N^'GQ(U
MWQE97W@!]>L-:LS%?Z?K>DQ7UM/IKQ7MJZ26=Y;(A@N8I3&Z7*2QF-TX8DHI
M_P`R.,,QCEN48O-O[6CDN+R_!XJ&&S=8AX7ZK&OAJE&<IUKI_NU5]K3G[TJ-
M>G0KT_WM"GR_ZL9YD_#?$U3*LKS/!4L='!9O@\[P6#K4UC,,LRP-2G.*Q>%]
MI16+R[&QI^QS#!RE3CB,/4G%R4U&2^Y/V(M4^%MA\1?&WPP_:OET:Y^#'P?A
M^,.M>$_!GCNTU;4=+^'GB'0H;NXUJU\`V&D:?>:YX:U;Q;-JW@O67T+PI'H]
MKXH2RFDU$3MHT3)T_P"R+^QKXI\3^$O#C>##\2M!^#'BH'6O$7B+Q9/H6A^)
M/'^BWMF=9T.U\/\`A;P[KEQJNB^%Y#'=ZGJ\ECK+3:Q8ZKHLT<8@%OJE?1WQ
MO_X)K?'SX]_#Z/XR>"K73O$GQQN]-MI_B5I\]K=:5XH^*EGI.A+IGA>XT/[%
M%9>&+3Q9X<BDOK2ZFN;33)_'VEZO=0>)M5U'5M.TV[;Q+]GCX$0_##X#?$_X
M8Z1XI^,7Q._9DUC3?"MV?@Y\4]2U+X;^//V4/$-BFNZI\2?`GQF_X0RY\*?$
MKQ)X5\?ZE/I]UX+\-Z,M[HNH:-X=\0V^H^#KWP_XG76=;_F=<?</^(_!V=YU
MP/QKA,PQ5/-<KRS/<EI2^M5L)4RV=?+\?4R[#XJOAL%2S>G5Q,<XR%9GB\KR
M[-<-#$Y@\?'.</AL'0^CPF:SP7&DJF7953QF*J0Q>'J3IXNG4P/#^+K2PU3`
M?6,/AJ$:ZPF90>)PN.Q]/"8[&?6X8.GA\HITUBZDOJ34?',?[5'B;X'>%OV=
M[W6]#_9;TKXR^']0N-:TV^\,:EX5^-^O?"'7=$\4>+-.^'^FMJ-[XL\,_"W0
M)=`\*^/--U[7M'\,ZSXLUV*;P]X9TQ?#]AXF?3;GQ;^!<T/[4OP$^+7@^+SM
M7T+XBZ-X/^)<L8"WUWX%^+%W=^%+DSPC<)+*PU&Y75?*,J,'M$D0RS.B'SWX
M1?&MM*\3^)?&6EPZ;IVMWUA8Z'X9%]8:7!K>G:/]DO6UU[*PTVWM-!L=1\1Q
MI;-+:>'M+AL]`T^U^R:1=W-YK'BK5=<_0C]G'3/"PM?&'Q+\<:PDFH:7HLGB
MC4+^]ND&F+)X9U73-1T+3[=1+;VB2V5N^HW3I(-[+))/,[M&#'\S@7C:F=9?
M@,OP>"RS*\MPV;8+$9>FJ]#$TL\A3IX]XW,%A<#4SC&5<%*M"KF.)P^%;JQI
MT,'A,!@,)A,)0]O$RK<+PQ$,VQU;,L3F6&A6QDY-RK8W&QJ\^'C@</\`6<8\
M%A,M:P]E&OB'6S!8K'XJOBZF*G7J^$0?%.ZT^&&PDA<R6,4=G(5=MI>V00L5
MQ'C:60D8XQC'%%?'NG0Q:UI]AK%WYJ76K65KJ5RBLZ*EQ?0)=3*J+&%15DE8
M!5`"@```#%%>96H\/4ZU6FH*T*LX+W8;1FDOM]DOQ[H[J/#O%TZ5*4J%I2IT
MY.\:FC<8-WT6S;[;/:RM_/D680OAF'[VT7@D?*\?SK_NMD[AT;)SG)K^E?\`
MX)_:1I47@_PY+'IFGQRMX?T;=(EE;)(V[^S`VYUB#'<&8').=S9ZG)17Z3],
M/_DT^-_Z^U/R/S?@?_DI,7_V"5?S9_4]^RW;6YM[@FWA)BM=!2(F*,F-&MKO
M*QY7Y%.U<JN`<#(X%>;_`!O\#^"_^$O_`&B8_P#A$/"_E^(?AD5U^/\`L#2=
MFN+IEWKK::NL+]DVZF-/:]O6L1>B<6AN[HV_EFXEWE%?QI]$7_DS&#_[++B'
M_P!2*A^,Y5_R<SC7_L&R/_U?9*?R$?#N**#X?_%74(8XX;^">.WAOHD6.\AM
M_LS_`+B*Y0":.'D_ND<)R?EKZE;4M13]F_XK,M_>JQ\%7^66ZG4G?8:_NR1(
M"=VQ-V?O;5SG:,%%?UEC/CE_V&99_P"HN#/WS/O^3B9;_P!>*W_IRD?BSJVN
MZVNJZFJZSJJJNH7BJJZA=A547,H``$V``.`!P!P****_1J/\*E_U[A_Z2C]P
M>_S7YP/_V0``````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A
M<G,O=V]M86XN:G!G````````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-S,V-P`Q
M,#4Q-30S,S<V-P`P,C0R-3$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R
M`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%!@<("0H+
M_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$(
M(T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%56
M5UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBI
MJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W
M^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"
M!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`5
M8G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F
M9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:W
MN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!
M``(1`Q$`/P#\2_\`@K/_`,%;OC?_`,%/_C2FN2W'B7X=_`WPD=0T'X1?!G0M
M9NE^Q:3JDC&[UKQO_9-[#IOB?XC^*6CAT_Q!=6D]WH=K#':Z?H'G:3>7ER/M
M+X+?LV_L1_L6_#+X,:M\7OA=X9_;9^/7Q-MM`^)?C*QU:U\06WPH^#'@*!=1
M\7>)_A3X<\,PSZ!%XA^(&G1^$O&.B>/-?U]8=.E\0)'8:)IUG/!+<C^:V:ZO
M+&2UNK%)K2:WEBN[:Z5IXO(N8'66&9989;>5&BE5'#17$$BE=T<T38=?Z2/^
M"4_[%'Q@_P""RGC7QB;OXY7WP5\/?`G0Y_%\_B'3K"#QSJFI?$'Q-JT-E:Z%
MXBT'5M3TJVET?7+:PU>XU+47U*Z;6],AUB_\I=9<1D`^[_A-_P`%AO"WPHM;
M#P-^S1^SA^S[^S[\/K"Y\*:QK=A\/_AKI*^*-,\*_P#",W>L>-K9=8NK0WEU
MXB\4ZZ-/O;53K-W_`&5&\$#J$N%#W-$_X*Q>,?VC/`U];_&_X:_!/XPQ^(?$
M[:IJ'A3XB?#CP1XRLM$\$P-9W=EIFKZMXCT^*6"XN%TN.YU+69;ZWN-9U87D
M+^3HUG=W$?Z:?LL?\$(OV6?V<?AZVF?&V%?CE\:=0_X3?1O%VKQ:GJ6C?#./
MPSK.H7-E8>&_#_AR>'4M3$.DZ')!>V][+=PZGIFIQAM)D?RH:],_;)_X)>?!
MWXD?`;Q!%^SOX'\'_#C]H+PG-;>,_!FL:5X:MM0TKQ=J?A_1SX=31_%6@-*E
MOJ%C>^'PEI;CB[34+2&\>!IK]=X!^,/_``48_P""/7P!_:+_`&%]9_X*&?L.
M_#;P1\'OBAX!L=9\9_%7]G7X0^)I_&OPY\5>$_"["X\8SZ#H<UA*?!WQ%\&:
M`[^(;S3?#\TUGJ4=BNG66)I(0_\`'I826ES#!/`J,DT*3"2-Q*I5D+JPV%@R
MLGS+MSO4<9YQ_?\`_P#!&K]H#QC9?'>T^`OQGL_#FG>%/%UIJVB^'[WPWJEO
MJOP]\0ZKHMK=Z?=^"]4\+:DWVCP_>S:8\^Q9(GM9(+:ZT>^+W15!_&#^WC^S
M)XM_9%_:O^)G@'7_``S_`,(SX%\>:WKGQ5^!TJL]S9ZK\%_&'C#Q/=^![FQO
M%46MQ/:"TDT+54M'ECTRZ$=C<&.8"(`'R(;JR!(,\&02#E&SQZ\45EO`2[GR
MWY9CQ&Q')/0[3QZ<FB@#`#;#_I#!X'PH#.KJH/=DD2:-EQU5XI48<-'(I*'^
MIG_@@E_P4*\+?\$Z?@W\2O%L'@&[^)=Q\8/CYX>\'?%6"/PEXWM]6\&>%=`\
M,M'X`CTKXHV=IJ'P^NM=U*UO_%&LP^`6-AKNMR6<L5G!YL;2Q?RS-A(&0/PB
M,3(I;S(P!]]?+#2!E'S*45F!`*@G%?W)?\&LVA?L^^/_`-C[]M/PO\3_`(?Z
M'\2/%?PL^,.D?&NX\*7FE)K'B&X\.S_#.31_#^H:'HEZOEF]L;_PMK]GI>J6
MJR7::I"K6R/=7'E.`?JG_P`%'OVE?B=%^SE\%?B?^R+J?B/Q+X/^-$]WXA\0
M>)_`-M9:-XY_X0#1[:YN7TZ#Q)XO:VL_A1+'XFM-0TCQMX@O7ANM$U'0K.VC
M:*_O(8)/$O\`@C1\?_VHOVF_$'[12>(Y_'5A\,?"7@WPO=_!_P`5_%OQ;=>.
MI=)^)/B&368=(TBUU^X\,Z+K/B(:!IEFEQXVMIKW4(=%NYK1$1VGMED_5GX%
M?M"_LJ_%IXOA/^S=IEQKGPQ^%_PVTF^L?$<?@C6-+\)>'G\2W][;O\/+VU\;
M:=9ZE=>,+IC%KWBBU>+R+BYO(]5U807K6J3_`%?X>CM]):WL=/M].2P:2(V>
MG:386UK9S'>L$$D6E:?:P6[3O;N\L4T+3-M5I4WJI8`'\`?A7Q_\<_AE\7?C
MIJWQ4TW6O`?C+1_CKXQT7672&707L/'>DZOJ]OXS\<_#^>&..\D\&C6A>7&E
MR+%]CN(M=M[596*(I^F?^"P'P]L/VN/^"5WP[_:RMD.L_%+]D'XL^&=&U?5K
M*UMIWLO@;\<+6/PUJ6C:A=[1<3Z5X=^*NB6.HZ3>/^YM+'6=1N(7&68\'_P6
M:_;Q\%_M$?\`!2D_L_\`PATE)E_9Q\*^(_@YXBUJ/^SETSQO\3XO%5AXS\8:
M#9G325GT^UA^T:9IVI7327EOX@1X;QPT<J5]:?LC?#[6/C_^SU^U9^S#X4MK
MWQ7X'_:/_8\^*UGH4DEPJSZ)XCT?1I?%WP^U/4+)]Y&O0^*?#RZ'<:<B+J%F
M+NZD6)9@10!_$EBX7Y6$89>&!D((8<$$9&"#D$8X-%58M>T^UBCM=5MEM=4M
MHT@U*UGD6*>VU"%1'>031RE9(Y8;A9(Y$D571U97`8$44`<^[7$BDQ*,*"4,
M8!8L.5W8SP3CDC'/:OZ%_P#@VW_:+\6_L_?\%%?#]C;ZP-$\&_'CP+K_`.SK
MJ5_K!DE\)6GQ3\7Z-_PD_P`"AK1CN;**<WOC7PV]E&JWMO>OIVOW[6;[G9J_
MG]A)@A8,/,E,KVD-LR2K)<WR`*-/1(5:X>[>0K#]GMT>ZW.JQQF1D4_M1X]^
M`&O?"3X0?L]_`ZU:+X6?$GPWX63X\^+?B'HOVA?%FL?M#Z_?Z7XI\(:;+<Z?
M)$UG=^&O!EYX.T#1/#UK<10^&[ZSU35('74'F0`']:7['7Q(_P""CW_#3,?P
MZ^,?B_P_XR\,:GJOBB3XG>'_`!=^SUXS^'47@2;PY=:K:R^)O!WCU/"GAKPY
M]D\1?:[FU\*:/<W.N:9KLEQ;1W>K>1;RS+[;_P`%*/\`@IYX3_8VTFV^"WPJ
MO;#XE?MJ_&:UN-)^#GP:T"[AO;SP5>:RLFG1_%CXL;'E7PAX8\'&0:E:V=S'
M;?VL+*:ULVDD)`_"7P]_P49_X+/_`+1/[.WQ=\!-\:_A7H>J?LX^(?A5\.O%
MGQ<\.S6?@GX\>/\`PS\79+'3_`/C30DM8M3AO]7U*WCN-1\0:YH$?A>[LA`@
MAN9]0E20_G;^Q?X$^'^@_&'Q#IWQ6^(OB?0?$?B6_N=3UCXC:3XF'A[QGXB\
M5F\+W,FL^*3HVM>)KZ::\M;V9$;5X5D,^Y8@&!H`_.OX1:+XCT7]H'Q_)J.J
M-K/B_P`+^+O&]CXF\8:K<J-8U#XA^']?BU:;Q)?I=-]I>#7=1_M2W$CC%Y'K
M,%K&SM$BU_1W_P`$V?VC/#?P=_:ET#QE9ZAJ6B_#S5_BE9O?Z;>W*WVF^'[?
MQ]/833P@0N%L=#U?48_%&HVGVHQVMM<00Z<C!Y/+K\O/^"B'[//@?]CC]KJ#
MQ-\$;*[UG]GW]I?PIX6\:?"3Q?8^([CQ9;WGC>SM],TWXW>$?$GBZ82"V\3Z
M#XYL]7\1>);>\>.\:_GTJX$$5DP+?=__``3N_8P^,/[37C34K'P%=:)X.^&O
MA2V-A\</CAXB>XU7X>:'X<7R-;\-Z!X*MM,D1?&WQE\&ZIIL]RGA:UU"/P]H
ML-M;W^J7MI!J,CT`?/7[3W_!MM^U]XD_:5_:&\1>!+.)?`^O?'+XM:UX-6VT
MV\-NOA35/'WB"^\.B#RH#&81I$]F(O+)39MV$KBBOZ[].^/7[./A#3[#PEJ7
M_!87XL)J/A>RM?#M^EW\3_V1+6Z2]T2"/3;I;FUO?A'?7EM<+/;2":WN[V\N
M89`T<]U<2J\SE`'\CO\`P:^_#WP#\0?VIOVM[CQ[X'\'^-[CP/\``36=3\%3
M^+_#.B^)9O!^I6_AV.[@U#PO+K-E>OX?OH+N-+J&[TEK2>.X1)DD610P]X^.
MUK;7'[87P(CN+>"=+WXM_'"YO$FBCE2[N--\+,=.N+E75A/-8&W@-E+*'DM3
M!"8&C\I-I10!Y?\`LZLR_$W_`(*:HK,J6-G^S#;6*J2%L[>P\11W-C;VJ@@6
M\-E<113VD4(2.VFC26%4=%8?`/QU9K#XM?$%[!C9/)X_\;^8]H3;._\`9NJ%
M=.WM#L+?8%9ELMQ/V4,P@\L$Y**`/Z&OAIX5\+^)_P!F+]E3P!XE\-Z#XA\"
M:A^T_P#LMZ;?^"M<T?3]6\)7NG:SK'B>XUBPN_#=_;W&C7-EJMQ##/J5K-9/
M!?311RW4<KHK#]H?^"UCO\*OV&/CAHGPO=OAOHNE?!#QI?:7I'@)CX/TO3;U
M'MHTO+#3_#QTZTL[I(Y98TN+>&.94DD0.%=@2B@#H?V3/V5/V7M7_96_9GU;
M5OV;O@)JFJZI^S]\&M1U+4]1^#WP\O=0U'4+WX<^&[F\OKZ\N?#LMS=WEW<R
MR7%U<W$DD\\\CRRN\CLQ***`/__9````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V%V871A<G,O=V]O9&EE+FIP9P``````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`Q,#4P,``Q,#4Q-30S,S<W,``P,C0S-C<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````_]C_X``02D9)1@`!
M`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$`
M``````````$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01
M!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT
M-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)
MBI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9
MVN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"
M`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A
M<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$
M149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7
MF)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;G
MZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#^W[]H[]HCP;^S+\.)?B'XO\/?
M$?QO/=ZI%X;\'?#CX/>!-;^)?Q4^)7C*[TW5=7T[P7X!\&:%$UQJVOW^FZ'J
M]\KWUUI6B:?8:;?:EK>LZ7IEI<WD7Y*?&[]OWPI\0-"L/VL?AW\&/C7X,^)?
M_!,OXYZ1?_MF?`+XV?#&3PE\??`W[(GQK\#>*/#/Q1\=Z#X3L==US2?%OAQ/
M#4&E_'[P;KG@+Q)X@/C6U^`^L^'-%GNKF75-!OOW?EMK>>2VEGMX9I;.9KFS
MDEBCDDM;AK>XLVN+9W4M!,UI=75JTL120V]S<0%C%-(K?S5?%;XP?#G]J7_@
MIKXB^)G[.FJ:AJWPS_9S_9X\6?LY?'3XI>&[:_L_AM\:_CGKGQ7\.Z_X>^'N
ME:ZUI%H?Q/N_V7]'\$>.(]=\0Z+/JUGX1\0?&G_A%-.UN"[3Q=I+_B_T@O%W
M+?`KPFXO\4,TP^%S"GPW@(5<OR;%9C'*O[:SNOB*=#)LJH8Q8?%U85<;CZE&
MG45+!XN<,/&KB/91I4*\SZ?@WANMQ;Q%EV04)RHRQ]2<:F)5-UHX3#TZ4ZN)
MQ4Z7M**J*C0A.4(.M14ZOLX<[<E"7UQ^V/\`ME_LT:WJ'_!.K]HGX=_M:_`F
M^^$7@;]M[PC?>/\`QEI/QP\.6_@4>!?B[^S1^T7\+].OO$GB'3?%<7A.RL?[
M7^(/AR[ME\:03V4[3):V$FF:S=6-XGU]\+/^"@'P4_:*^)L?@7]E6UU[]J?P
M3I36J?$+]HWX'ZGX`\3?LT?#Z\O+>VN(?#LWQ@O/&VE^'_B#XVM8-2TK4-=\
M%_"3_A/M<\,:3<SS>(X-+U6&VT6__)OQ+^S+^SKXP^&VM?!SQ'\#?A1J?PI\
M1ZO%X@UWX=OX#\-6_@_5=?@NK.]BUV\T&STZWT^76DN]/L9QJQ@&H;[2`FX(
MC4#Z7^!7@+]H32/AI<_LU?L1?$/X#_LG>$O!>@OXC\#R:M^S[>?%;2M'NY-2
MU`:UX9TOP3I7Q-^%GAGPYX?UG6=5TC7]2U6!-9U>]U*Z\5W3VBZGJZZLG\0?
M1M_:49+XX^)F3>&&<<!XGA?->*LWSFED68X;'X>OE\<)@<H>8Y=AL=]8J2K5
M\XS">"Q6`JJC1H86G%82I2K2E4E2H?J?&_@CC>%,BQ.>8?-8YCA\!0PLL30]
ME.%7VM6LZ6+Q,$HJ%+"THNC*,'*K5DY3YYVIQ]I^V5%?$G[)7QI_:N\9ZM\0
M/A-^UY^S8/A=\3/A<+"X/QJ^%VL6&O?LL?'+0M>U+6+7P]K'PDN]?\0_\+6T
M#Q.MEHT][XX^''B_PO>#P$MSHRR>/?$+:_8(OVW7^HD)J:NKIIVE%VYH2LFX
MR2;5[----QE%J47*$HR?X*]`HHHJP/Y3/B-^U1^TU_P5*^,W[07@7P7\1?&W
M[,7_``3?^"?Q3^(7[/+O\*M1@\)_'K]L_P`:_#;Q#=>$?B5JUY\6-*O]0\0_
M"_\`9]M==T>\TG0+3X;S^%/&_C_2-1U2S\3Z[I82ZT/2]WQY^RV-&^!GPL^$
M/[*7B%?V;HO@=X^^&?C+X<Z;X6EU>Q\$WNC>#/%46H^*_AYX_P!)TF]MM3\7
M>#/B-X9U#Q5IGBBTO=2:]U/Q#J]KXKU*\OM4LI'N?H'QG_P2^_;:^!_Q1^*M
MS^PA\6/V9-3^`GQJ^+?BKXU7?PY_:MT[XL+XH^"?CCXJ^)-2\7?%U/A[XK^%
MR7H^('@C7?%NH:CXL\.^#O&%MX:U;0M1\0ZGIG_">3Z386,4_&W_`.PO_P`%
MNM'U2YO-&^.7_!,+Q[IUW;A4T?7OA=^U!\,8](N@LF)K&^TGQS\4;N]M]RQ>
M=;:@QDG\YVANK(6RQW?^+/TH_HT_3H\:?%_.^)\+BN%L=X?\*\0/%^&/#.(X
MFR]Y#_95)O#X2MB>&<9AJV'QF<XK"5J\,^K\08>];ZQCL%A:SR9X7#K^G>!>
M./"CAOAG!X"M3S&AG.88.-+.LQI9<HX^GB%4ISDZ>/PLE4IX:AB(JO@%0E*L
MH8>E7KT_K3BI]3+\6OAY#\6[+X$R^)(4^*^I?#G5/BU8^$6L-6\^Y^'FB^)M
M(\':KXDCU3[!_89AL?$FOZ-ID]@=3&K!]0M[A;!K,M<+U7[-W@_QE\6OCSH'
M[5'[&WQ2^$^N>(?@QX^^(G['?[7?PQ^).L>.]#LW^'\4&F>+;N&RTS2_#FO7
M>F?%KP!X^3PMXK\!7%YH7A_0_'?P_P#$/B6"/QQ-X=\4>'M7LOR*O?"'[=O[
M,'B']HKX-?M#>&_"?Q-_;P\2?#_P1^T'X7^*O[-OQ)FNM"^-'[,NC?'.'0=?
M^!OPJL?BWX/EU/X`^,_#.AZAXO\`"?AV&?X=ZI\/K'Q5X[L/B1J?BJ]UMM9U
MMOM+P1_P4J_:?^+7[?\`^R]^S[^S]H/PE^%_PT\4?&F1_P!I2;PC\#=2N-&\
M8Z%X5\%^(6U?X"^#OVBO%>L#1_CK\2/AOX>T:3Q5\2O%OPH^&/A3PU\/='\+
MMHFJ?$&Q\1O8?#?Q7\=]#3Z./#G@I])2<O%'B"OEO'O!M>CPKP[PC@L1C<UJ
M9SQ)GG#^`Q6*XTQCR;)IY?E_A[6P7$-#`\'RSS,Z689IG^&J5,3@L-F>%AD^
M&]'Q,XXQW%/!,%D>"IXC)LS;S#'9A7HT,/3PN#PN+K>QR?GQ..=2>>PG@U7Q
MT<%1E'ZO.2P=2=*G5Q$_W:_::_;W_8__`&-M3\*:+^TU\=_"'PCU;QOI>NZU
MX7T_7X==O;K4]*\.R64&IWIBT#2-7:QA:[U"TT_2_P"T1:-KVJ2/I>A+J6HP
M7%K%X3^P-_P4*TW]K&/XH>'_`(F^'['X&?%+0/B5K>H_#7X4^--7LM)^(7C?
M]F3QK=6NM?L^_%R;PY<S(\6H>)_#VJ+X6\:>'])GU>7P/\2_#7B/P5KERFM6
M06X_.#]K+XU6.F_M\?MB?$9;76?'UG\(?@Y^R1^R[X!\(>#(VU_6/%'QXUS4
M_B[\5=1^#GA32]*AN+BX^)?C"3XY_!"TOK&\BE32-.U/PMJVIW.DZ)'JUU;_
M`$=\*O\`@DC\3=;^/?P;^.W[9W[4FA?'OP[\'=0\,_%[P1^S7X.^`_A;X??#
M[X??M.>';K3M4T#QWH?Q;;6M3^+/C'P-\.M3@N;WP3X/\3?V?)JWB.U\/^,?
M&=[JDFAZ;X<LO],,B\8?%GC+Q_XU\/\`A3P\X8J>%?A9FN6\/\:>(&;\4YIA
M,=FV:Y_PWDO$,,%PEEF&R#%8*OFG"GUV>'X@R_&XITJ_UK"*.991*=/ZY^&X
MOAOA_+>$LMS?,,[QD>(,\PU3&99D>&R^C5IX?#8?'8O">WS+$SQE*=.CF,*5
M.K@YTJ3G25*LW1Q2J)8?]Q****_J<^#"O,OC/X:^)'C+X4^/_"OP@^)0^#OQ
M.\0>&-3TOP1\4O\`A%M"\;2>!-?NX3'9>)+?PMXHMK[PUK%YIS%I;*W\0:9K
M.BQW?D7.J:%KME#/I%[Z;12:NFG>S33LVGKIHTTT^S336Z:8'\3_`,%_V4OV
MSOV-?V[-*^-7_!0O4/A_K&L?M:_!BZ^$OP]^+'A/6?#?B.^NOC'I7CK5?'&H
M?"WXN^-[?PAX+\6>)_B-XI^'/A31?$WAC7M<M-9\#PKH=]\-?`.O:3%8>&O!
MC^W?\%"?AQX<TCX3?$C]HWP]\2/B/\"OCQX)^%FM>$OAC\=/AQ\8/B/\)+_X
M9OJ!UW4AJ&JWWPWU6SU;4OATWB34-*\:_%WPFNGZOI'CG3/A[X7G\8:;<:9X
M+L=1T;^ICXW?`?X._M)?#K6?A+\=OAUX8^*'P[UY[6?4?"_BJP6]LQ?:?,+G
M3=6TZX1H;_1M=TJY"W6D:]HUW8:SI-TJW.G7UM.!(/YZ?^"C'[!/_!,K_@G-
M_P`$X_VD]9_X4YX/U"Z^+WBOPKHMG\2/VE/%VO?&WQ7X=^(/BZZTG0+/Q)X>
M^)_QP\0^*?$_@74O#F@Z5JGB/0+CPQKND7C>*=/L9H9C?R6L]O\`YM>,7T&<
M5F_CAE?T@N`_%O.O#N&099EN+SO*<MRC%9AFV(EPXZN)Q4,HS3!YWE=6%//\
M'1A0S"CB</CJM?'U\9B<1',(8ZMAU^U\.^*_U?A3%\'9MPYA,]>-ECZ6$QF)
MQ=&A1PL<=24:'ML/5P=:FUE]>U:E7>(H1IT:5%3<94'5G^)?[#UOXE\"_P#!
M3;_@GA\2-!^,>A_&_P`*^(_VG?VK/#WQ"\/Z;\/?'?ACX#_#/Q'KGACX6>!;
M3QIX8L?B9)#\1O&GQJ\;W_[1MKJ6I?M4?$_4-1^(OCSQ3XE/AJ\N];TCQ"JS
M?VN?M4^,/VPOAEJGP]^)7[-WPQ\)?M!?#SPY!XHMOC?^S^-7T_P5\9O%^F7_
M`/8MQH'BKX)>.?%&K:?X`E\6^$%T[68U^'_C:X\-Z+XVBUM[!O&.AWZZ;J>E
M?QA_L0^*;G]J']MO]C?PUX%-GXUO_B9X)'[7?QT_X1NYO?BII7A+XA?%/]NO
MX+_$N]F\4>*M*T2\\+6VD^!_V?\`]DIO`_A;3_&>D^#/"^F75MX,M+31M?U.
M^TA+_P#T!*_?/HCXSBS&>%^-P?%F"Q6$Q66\4\1X7#XO&T,-A\;F?M,XQN,K
M8[$5\KR_)L%F"]KB(T*>8X;"4*N94*$,;CI5,;BL34G\AX@TL!3SJA4P-2G+
MVV6X!UZ-/VG[FK2PU*A+GA7E.K0E6E3G66%FE'#0G"GAU+"+#RE^9[_\%0OA
MU`[0WG[+?[?EC>0LT5U97'[(?Q'>>SN8R4GM9WM5N;5IK>4-%(UM<3P,Z,89
MI8RKL5^F%%?U5^/]>1\(W=MI))MM)7LK]%=MV6RNV^[;U"BBB@05XQ^T'\-_
MAW\4_@_X[\+_`!.\!>"_B/X9'AG7]3'AWQYX6T/Q?H0U*RT+4UL]0&D>(+'4
M=/%]:">86UW]G\^`32B*1!(^2BL<1_N]?_KS5_\`2)#CNO5?F?+7_!,#X3_"
MSX?_`+%G[-.K^`_AI\/_``3JVK_`SP'INJZIX1\&^'/#>HZGIUA;3W5C8:A>
MZ-IME<WME97-[>7%I:W,LL%M/=W,L,:23RL_Z&445L(****`/__9````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O879A=&%R<R]X96YA+F=I9@``````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R,3<T`#$P-3$U-#,S-S8W`#`R-#`S-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!'248X.6$@`"``]P`````````S``!F
M``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_
M`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F
M`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_
M,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF
M,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_
M9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF
M9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__
MF0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69F
MF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_
MF?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-F
MS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_
MS,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F
M_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;_
M_YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F
M__^9___,____^+\D````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````(?D$`0``
MV``L`````"``(```"/X`L0D<2%`@@(,(#Q9<R)!@PH<(&THTF'`%@!48$TYD
M^!"C1X\1-SJL^/&C0I$4+5XTF3$C`)38#JI4"5&C2)DUG1S4^?#F180D=N9Q
MXH34T*`G)SY$>O"9TV>D>F[\N9,$49UYGN4!8!7IU)\ZNP8E^HPKUZT^#VX=
M.M3)4*UDT7X5FH?44U).GD*5JQ2H6U)V]]H%C/?E5XM6\]2U^]>IT:0-$2)V
MJQBPWKV0.:[D2D)QW3Q/0F<M;%BB3)6)%WMVK--B7Y<D.B^^O/7G:XLKNE;6
M2]JUZ<VYKS:&RM/V[Y96*0LO3K5T0<D'4W]6#'UF9IPT*2]^C!W`$P!UG5KC
MC`Z`LF6HDD%^#T^Q.8GUYYW67HD8?LJ$[\O'=\H39/ZZ,=44VW?[:95>?0!$
MU1Q"5^EWV3/%940-->DE1)0??E"#U5-9&0B=$QGFA.&(%!8EF(>G`1!B0```
M.P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A>BYP;F<`````````````````
M````````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R-C<`,3`U,34T,S,W-S(`,#(R
M,#<Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````)````"0(#````G?_N@P````E03%1%N@`6
M9F9F````C+7,0@````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,`
M``L3```+$P$`FIP8````!W1)344'U`P4$389KV,IH@```"=)1$%4>-IC8`"!
M!@8&Q@D,#$P+&!C8EC`P<*U@8)!:R<"@M0HL"P!.9P2G^K[9)P````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O8FQA;FLN9VEF````````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#4R`#$P-3$U-#,S-S<S`#`R,C4R,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!'248X.6$!``$`
M@```````____(?D$`0```0`L``````$``0!``@%,`#L`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V)L;V-K+P``````````````````````````````````````````````
M```````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#4Q-30S,S<V-@`P,C(P-#$`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO9&]W;BYP;F<`````````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-S`V`#$P-3$U-#,S-S8V`#`R,S4R,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````"P````L(`P```)YRAQ0````$9T%-00``L8Y\^U&3
M````(&-(4DT``'HE``"`@P``^?\``(#I``!U,```ZF```#J8```7;Y)?Q48`
M``,`4$Q410```/_______P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````$C*MP<````#=%).4___`-?*#4$````)<$A9<P``"Q,```L3
M`0":G!@````A241!5!C38V!"``8PP<!`/)L!!D#B,"98#92)J1>%A```*]0`
MJ;U8DOT`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO;&%R9V5?9&]W;BYP
M;F<``````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-S(U`#$P-3$U-#,S-S8V`#`R
M-#8W-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````(0````L(`P```,8-%`T````$9T%-00``
ML8Y\^U&3````(&-(4DT``'HE``"`@P``^?\``(#I``!U,```ZF```#J8```7
M;Y)?Q48```,`4$Q410```/_______P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````$C*MP<````#=%).4___`-?*#4$````)<$A9<P``
M"Q,```L3`0":G!@````P241!5"C/8V1B(``8D57\@S&8!D3%/]S.9(*;\0^'
M-(HM_[!)D^Y2B"(F/"&&%0``X2@)(EX](BD`````245.1*Y"8((`````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO;&%R9V5?
M;&5F="YP;F<`````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-S$W`#$P-3$U-#,S
M-S8V`#`R-#8V,0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````"P```"$(`P```#A%H40````$
M9T%-00``L8Y\^U&3````(&-(4DT``'HE``"`@P``^?\``(#I``!U,```ZF``
M`#J8```7;Y)?Q48```,`4$Q410```/_______P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````$C*MP<````#=%).4___`-?*#4$````)
M<$A9<P``"Q,```L3`0":G!@````J241!5"C/8V!"``:\;")(!L)L!L)L!BC`
MPV8@@DV,.42YARA_$4?B#V<`AVL!^=D"F,(`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M;&%R9V5?<FEG:'0N<&YG````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-S$W`#$P
M-3$U-#,S-S8V`#`R-3`T-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````"P```"$(`P```#A%
MH40````$9T%-00``L8Y\^U&3````(&-(4DT``'HE``"`@P``^?\``(#I``!U
M,```ZF```#J8```7;Y)?Q48```,`4$Q410```/_______P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$C*MP<````#=%).4___`-?*
M#4$````)<$A9<P``"Q,```L3`0":G!@````J241!5"C/8V!"``:\;*)(!F+8
M#'C9#%!`#)N!"#8^<XAQ#]'^(H+$'\X`AVL!^9V+B'T`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M8FQO8VLO;&%R9V5?=7`N<&YG````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q
M-S$W`#$P-3$U-#,S-S8V`#`R-#,U,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````(0````L(
M`P```,8-%`T````$9T%-00``L8Y\^U&3````(&-(4DT``'HE``"`@P``^?\`
M`(#I``!U,```ZF```#J8```7;Y)?Q48```,`4$Q410```/_______P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````$C*MP<````#=%).
M4___`-?*#4$````)<$A9<P``"Q,```L3`0":G!@````J241!5"C/8V`B!!C0
M^0P,^%0PP`!V%0RH`%T%`S:`4,&`&Y#H#KJIP`H`<:T!^2R^!8``````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLO;&5F="YP;F<`````````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`Q-S$Q`#$P-3$U-#,S-S8V`#`R,S4P,0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M"P````L(`P```)YRAQ0````$9T%-00``L8Y\^U&3````(&-(4DT``'HE``"`
M@P``^?\``(#I``!U,```ZF```#J8```7;Y)?Q48```,`4$Q410```/______
M_P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````$C*MP<`
M```#=%).4___`-?*#4$````)<$A9<P``"Q,```L3`0":G!@````D241!5!C3
M8V!"``9TD@'!9D"P&:``R&9`8B.+HZA',0>5A```*]0`J35R@;X`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O8FQO8VLO;6]O;B\`````````````````````````````
M`````````````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S8U`#`R,S`Q,``@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]M;V]N+V9I<G-T
M<75A<G1E<BYP;F<`````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,V,3<`,3`U,34T,S,W-C4`
M,#(V,C8P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````P````,`@#````8-P)M0```P!03%1%
M`/\`"`@($!`0&!@8(2$A*2DI,3$Q.3DY0D)"2DI*4E)26EI:8V-C:VMK<W-S
M>WM[A(2$C(R,E)24G)R<I:6EK:VMM;6UO;V]QL;&SL[.UM;6WM[>Y^?G____
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M`/\`%Y409P```0!T4DY3________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M`%/W!R4````!8DM'1/^E!_+%````"7!(67,```!(````2`!&R6L^```#'$E$
M051(Q\667V_=1!3$?W-V[1N20!$1;0K)]_]@38/45N(A!-W8NV=X6-_D-DT+
M/"`L6Y;6.SOG_UCFWUW!?PVH+RU>97.JQNT+W_2E#V_V2S=*B/GTP]\!KO?K
MVC*1!4F93DYOO@&XWJ_9K$QC$"8\G7W\*N!R[TEKSV8E1MN6^=7[EP$7RTEI
M7IK=)*4`+$OE_.-+@(NVXSX:5N\:3F`L%.7)K#@ZOT;/!D(!"4[;"+S<O_X"
M<+&HK,LCW++M!!P0Z]W;9X`W"]'71$C"2+(E(%.&]>[JLTS_^B?JO2M2D(@<
MNY'!F-C??<:P@.02#J12:ADA,D8VQKJ_/&+X9:^014IA*SL2MF0+AXTB_SAB
MV*-0D,@H$J4!R2Z@M,'L7S\Q&$JF4;%-24QB4'@PI0(MCPQO.JR=.-1"*(ZB
MR\&?)\":V`:(6N=:@^QIL`46(,#KV\VDZP4,!*EPR1YA2<8:)0LRQON-(7UP
M)-,J84N*\2`P$L@\;`QF+-;LW>4AVX@*$)8AC(1%._@@+"R%%'3;"K`A,1$:
M^RQ?#8""0,K61,\2!6L2PPS%J`XAQ\80E33.WBVY9928(C2B8R.$)>2;S:0`
M@3.=V%U%18?6$B@\&K9L#.^V/-E8IDAML;98;#[:2-/!:1=R'!*5[)V2ED9`
MG]*`3QZC%`6GP=GHN;J(W(;&ECYAQWP`[*(&$H6V]%K4$S\6$^0HC=C='``W
M4:=:ZC378D^0"5/8QS-%TNZI'TJKU1&&$IDFA25I<WT@RJ<GP&VQ([0L35./
MXF)WZU`$2@#.CH?`M$::Q6[N(;?'JALWEN=/QT/@_51K&.B>S1QUFLL6)(T^
MBO-GH_*R!>N:VKF7'6MX7=J6/.'P^>_/%"C<Z^E#"ZV.+!,IP@A20)Z>/Q^5
MM[/7%8AYGDB9T>)C_,7)#^^^&,:_G935F!)I$4-3;).P^_'F!16]G6N+2BE%
M"2$DC]?9JYNO2-;/-D7J+O*Z](Z1I_,/7]7IC]]-])XY>MP@Q?<_??BF[%ZW
M=*K@OBZMS/69B+ZDTW!E0V^>YG?_1-C_[Y^3OP#`P.^JJ^O84@````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO;6]O;B]F=6QL;6]O;BYP
M;F<``````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-C<Q`#$P-3$U-#,S-S8U`#`R-3,V
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````,````#`(`P```&#<";4```,`4$Q410#_`#$Q
M,3DY.4)"0DI*2E)24EI:6F-C8VMK:W-S<WM[>X2$A(R,C)24E)R<G*6EI:VM
MK;6UM;V]O<;&QL[.SM;6UM[>WN?GY^_O[_?W]_______________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M_____________________________________________________P#_`-]/
MV=P```$`=%).4_______________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M_____________________________________________________P!3]P<E
M`````6)+1T3_I0?RQ0````EP2%ES````2````$@`1LEK/@```T9)1$%42,?%
MELURW$80@P'T<%=2JESE.++]_D\72\DE?S8YTT`.7MFRI3C)(14>>.#P*W"Z
MV<`P^'>7\%\#X_G';V-"/SZSPJ=[N%UM``DXSG=_![S9^PA`C!B+I^OQX[>`
MM_MA8Q-HN[9.3N27R!?`J_<<7*9Y!2\.8(U`=?\7P(O]1I-["]9I!-1:Q=[*
MV[OGJO1BW>`WV`J3Z=JZA4FOF^KG%%X<I^WX$``"64OG?6Z!OVMMP/V3QKTX
M6/.XX(G5RYEM3)V2_/`U\/T!]3()".ED<&^2S!\[F'E\_^4GO?X%8)HP0P"#
M429`QKP9<8Q?'RL<0"$EBY+&*"Y4XA"$Y\[3V&\?5>GV`T4Q$!G$$:ZU0B%A
MNJ9OKM;OCQ0^@+JL@D2P+SDU5#7$=:1[G>?M9P4#U0A822!D#,^NBL;>@.'W
M??YN?5)X96`Z%!`&I:&T[1"]#`),[](GA<,,0!HJ5)1>R1C+IQ&04`CV.C\H
MO)E!$DB@L`V`P#AM6VG4$$+2T7S_\J(0\])@FRHN!+HB1@9=G?08Y&0?#P`^
MWH;<J3T+#!958@5J>KN:1_BY#T0(D*((.RFRH0+LND9_B*E:]`6@K!!>08(B
MVCQS$G*(JUZ`51,Y70"5S<`(H:P(&*I*3$8=#P=C^)-":@),'#".*&NTV!!L
MYFP?N!YQ+F5]1UVF`"$)LO>)-.-V!:=!]Z(T'CJ=HH.`T$!GL=94D'281H;C
MK/ZT!U!R`B)>-J!J'L6/6T)3173`NP?@-.&`U+2Q)48:@R2:9"]R.RU]_)<$
M`'<<VQACG#8E@W`C6]%I0QU4D*K:/L]#K3$B!2BEX0!!Y&R$J44%&G>/9OIE
M;.F8/M44NAIU)2;"4801^/3SXYG>*""',U>,3(-2B5X2`0>7TC\XW]UK`P;H
MC(6MJ[8-!D$Z`-!#7SG?JR7,:9ZSQIFK-J(#HY&0P>G^*V]5>KNN)>V)QR@`
M,F@!#6"[?^*M/^P8;I0ILE`AG30<@O73,W9_.Y>:@[%40%"P)P!A_/1L/KS>
M9Q6&`THF"7<"8MS_562];*`(9U`?3=P$'\7)DU!\.R<HHR@D`4'=?3MVWR['
M+`@TJ'?_(*>!-T&>OOH-X/\]G/P)+&E`R&U.=4P`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+VUO;VXO;&%S='%U87)T97(N<&YG
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,S8U,``Q,#4Q-30S,S<V-0`P,C8P-S$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```#`````P"`,```!@W`FU```#`%!,5$4`````_P`("`@0
M$!`8&!@A(2$I*2DQ,3$Y.3E"0D)*2DI24E):6EIC8V-K:VMS<W-[>WN$A(2,
MC(R4E)2<G)REI:6MK:VUM;6]O;W&QL;.SL[6UM;>WM[GY^?O[^_W]_?_____
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M______________________________________________\`_P#,3(-W```!
M`'123E/_____________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M______________________________________________\`4_<')0````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```,U241!5$C'M9;+<A1'
M$$7/S:KJD8#`X?"+$(___RXDP'AE'!Z-9J8JKQ?5$AJ0L+V@%[WHCM.5CYLW
M6^;_7<'W!NI##]\D9!!O'WBGKW)XM=L/:@1&=7/U;\!OVS&2*-%L#RWGY?);
MP,7U%J.(4DTM=F[0*7("_/Q7%ANAI94>1?2:H?+N$>#YMB4V`BUGX<(X-D8K
MV2X?J-+K/V_:,(!E^1B+';&/[$_*>*`/;S[=D`)C+'ED[K>[03]?4KSZ&OAT
M3:2-+,#0#V/T/GPLS8R++X%?MI`R(+#)&GV$%-KNP?WPXA1X^4DR)@P@I$.I
MDA'E>$A+QY].@.L!,NIB)=*!92/RN-=2]R_O`2_^#D"X"(2-6U$:R&!DW_EL
MN;X';+$T$0'R2.4H-6JIBG[PZ/WL\/*N#Z^[98$\^RA)'D2UVGZDC'=C\[3?
M`3=]5G+6:-9I0%CJ/4,F/&Z6N`MIYSN%"`GPZ(H\9A0D0I)RUV^!UX?[XM)Z
M3&DM2HL:6-(@CKM?UY!&:N:`<!@,*HI&B5Z&/6H51XWC>D).P2%-)=G&F:DH
MJB4DM_,S+'D](;%LS10\-2]WMY)R.6?LG(K2Y?4$QXH;C)"10F%[H,UBD5&,
MEQ4(A)'GQPT24@0.@8=+6K4J<@VIS*FYS6->&6"%298<Q\-92VY#*K?!FSD+
M,G;:#*>L5F.,05%=@<N"4DAHAC3[Z'2F&*:FTWW<Y<!&R!BP5Y%X9B2Z1[I(
M/='5K9:>W*17"_&\R^MX(XTN-?6(SUIZ7Z9<[J0GSWYF6@.*<2FE?9Z'LYFT
MM-;58,$@0DET!:A>?0:>-A/@L0X#R+8C0H<HF6FY7-V;N+?/B`RL@3VUA!6A
MT:.LXM&)"7P\)Q([+)""*+,CA'M".N+4*I\?N\*S1@))>$0HDND^]?+4R"Z?
M5X\HA(61[-D3HA0#[?V75OG[LX(MSYP1:]D\4M+R_NNE^,</[=8'9M+.S-''
ML!3O'MJB'W_8Y&S>]`&,*5&D^N&QE?7C=CK9]('::B#4+A]?BA?;W3H<0E%:
M4\35M]?NB_U^K'X9=;-\N40?V--P<7/LH%HW'_[+8E\WV-M'?AWTW?]F_@'#
MN?+JV,C/D@````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]M;V]N+VYE=VUO;VXN<&YG````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#,S-C<`,3`U,34T,S,W-C4`,#(U,C$Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````P````,`@#````8-P)M0```P!03%1%`````/\`"`@($!`0&!@8
M(2$A*2DI,3$Q.3DY0D)"2DI*4E)26EI:8V-C:VMK<W-S>WM[A(2$C(R,E)24
MG)R<I:6EK:VMM;6UO;V]QL;&SL[.UM;6WM[>Y^?G____________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M________________________________________`/\`%#K$I@```0!T4DY3
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M________________________________________`%/W!R4````!8DM'1`"(
M!1U(````"7!(67,```!(````2`!&R6L^```"A$E$051(Q\66VV[;,!!$`\Z<
MD:4XCI/X4C7*_W]F^T#2EG-K^U3"@"&`1SNSW.7J[M<_KKO_`RSSZ?AR^/'S
M[X#7Y_L`(&=[_B-PV@Z6),MV*4S/RW?`_"A4`-LVV&$Z?@V\H&!;!FSJRO;U
M"^"A#&#)*G),I4S&XV?`LG657R2IO;^&&U:R+L#;@PU2*9*;:5D2)I[.'X"=
M'+E<(DA6*9(<$L;Y'7"0;*O4_44UJY)4G`#WM\!/J@`WPK;:*@:('V^`?;$M
M^:ZIL57C29(QX!\KX&R[OK2]V#:H:<(R`]L5L+7HHJI=&_5'J9C@XP58-C)N
M.JZB5!-=DP#L+\#!:IKZK^DS36*1S70![M4W&6,CJ5A2C>#N:F[`@MR15A!2
MXUN(>NA/#9@EV<*V>@&)8`C44Y1=-#7@W`*`;-/\&I(AMB3J7QIPK#(!KWQ6
MHC=K*!)+!0Y4D5533Z@AA`RQ7$,,#3BA2S*],A\")`B(B[NDN;:9:NH;D(XD
MP3C8XR6M7M609-3Z.6W9`K/K![=QZS$964:=H+I`,O:I`X^X=#WJNJ!:@*06
M6I8.S`-MGU1ZT=[8QL8/U_*>XGIDZO6MZKK+PF9XN0+/A%(/KG>F"3A=ELFX
M:J"W"6-47%II6S6GV`D8<ECW](DH2'?J=YE)<I%E/-U>,[L82BG%+4E)$@+!
M&.=\"RPC#)8+D@/),%PC.#R]O_G.HYV(VA-)AA:C-N%N^7`9'P?'&%SE5Z(=
MQL/RR75_VG@U%-),&Y/K_IOY,$]VG."VO9G(?OEJ9.WAMDX!IM,W0W'>M;37
MJB,9GU^_'[OG_1B2#,,0QMW[(?KI8)^?MN-F,]X_G9:__W1X6_[;Q\EOZ&RM
MYEJ(G<8`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O8FQO8VLO<FEG:'0N<&YG````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`Q-S$P`#$P-3$U-#,S-S8V`#`R,S8V,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````"P````L(`P```)YRAQ0````$9T%-00``L8Y\^U&3````(&-(4DT``'HE
M``"`@P``^?\``(#I``!U,```ZF```#J8```7;Y)?Q48```,`4$Q410```/__
M_____P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$C*
MMP<````#=%).4___`-?*#4$````)<$A9<P``"Q,```L3`0":G!@````C241!
M5!C38V!"``9,D@&9S0!F,T`!,IL!31Q9/88Y2"0$```KU`"IC'3)$@````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O8FQO8VLO<W5N<FES92\`````````````````````
M`````````````````````````````````````#`P,#`W-34`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S8V`#`R,S4S,0`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]S=6YR:7-E
M+W-U;G)I<V4N<&YG````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U,S8`,3`U,34T,S,W
M-C8`,#(U-S,S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````<````#0@#````C5G^F````&!0
M3%1%[+"=_8]U7%0D__GX\,,*_UDT_W-/__0H_,:W_>/:_^$6GY*`_SH6D'Y!
M_^[KOI!Y__\S____````````````````````````````````````````````
M````````````FTQKGP````EP2%ES````2````$@`1LEK/@```*1)1$%4&--]
MD%$2PR`(!4$$,5$,][]L,4D;.YWI^T*7513\3V"ID>\]I@7>M39S5">&Q50)
M2NK6U%D=6EV@,<<R^@6=C1HZT7.L<32K.`P;(=KTGX%,PAU[3Y$^7-C<JWZF
M18:4\[9MN:<=*=J;7!"D^IX"E3)Q`L?6@"Y8$<,+5(Z)<QH-[;P3U,BI]_".
MF1*PQ]-L0F%FQ/1FQZDJLM#7]_WD!6(/$3L-?YH$`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO<W5N<FES92]S=6YS970N<&YG
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-3,P`#$P-3$U-#,S-S8V`#`R-34U-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````'@````\(`P```,1DCZX```!@4$Q41?[MZOE6&?]A
M1_]Z)/^#;O\\&VXX(/W-Q?ZTI]6TJ8MC2\4\#+JBF*F+?OR6@M*2@O^9,___
M_P````````````````````````````````````````````````````````HR
MJO\````)<$A9<P```$@```!(`$;):SX```">241!5!C3E9!9#L,@#$1MUPN0
M`O7]+UM#%C5M%2GS`98>,P.`7PINX$;KGN@O-@ED[I1.V'BN#F).YDG@A`$)
MIH>:QX3MJQLP#-&8._1IWN.W&*!P]5I4M=3L/-(@?5R-*>LB&%KT&>G`0CM.
M#%X5\3&$J#D:I!WAQIQUP%<H#I0N#%MWLE%4<+*5+W5SC@>)$+=RT.!8K!'=
M_/-?O0&,`!;R[ATVXP````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V)L;V-K+W5P+G!N9P``````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,3<Q,0`Q,#4Q-30S,S<V-@`P,C,Q-S,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@````L````+"`,```"><H<4````!&=!34$``+&.?/M1DP```"!C2%)-``!Z
M)0``@(,``/G_``"`Z0``=3```.I@```ZF```%V^27\5&```#`%!,5$4```#_
M______\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!(
MRK<'`````W123E/__P#7R@U!````"7!(67,```L3```+$P$`FIP8````)$E$
M05085V-@0@`&=)*!`4)!F&`.`Y0)XC#`F$`.NGJBV%```"O4`*FW0N%!````
M`$E%3D2N0F""````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO````````````
M```````````````````````````````````````P,#`P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<V-0`P,C0W,#4`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE
M<F1O=&-O;2\R,W@R,R\`````````````````````````````````````````
M`#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S
M-S8U`#`R-30V-@`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S`N<&YG````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(R-C$`,3`U,34T,S,W-C4`,#(V,S,T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````7
M````%P@&````X"K4H`````=T24U%!]0!#`TW!=IXI7D````&8DM'1`#_`/\`
M_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```0^241!5$C'U97+;QM5%,8_
MSXSM<>S$3MRQ$]L)L1/L0HB:($H%10A+%2R*6B2D2A&B"UBB+FCA'V"'A-05
M98$0K!"@(B2DEDJ-D-4N$EIHG*9*B&L[\?L=C^WQ:R9V.![$HB1ND-C`6%<S
MOC/W=\_]SG?/!?ZOE^9Q+U=65QU#@Y;3+46Y6,CGH=?IT%84:#0:Z#@6&I;#
M`*^#S6:'EF.7<OG\1]9A2])NM^\^%I[+Y4YLA")7.WMP#9DM,!AX`G#J@$ZW
M"Y9ET6RUT)9E9#-95,4=/#'NP%&O]SU!$*[T&%P_^+V5E3>,9JMK@.?!L0QT
M6DX%<M1J4AWELH@[ORRAT>@]5["K=-%IMS#E=E^@X?WAD4CDY;4'OW_0K59A
ML9A)!D8%J@-(#K%<1B:=P</-$)X^ZH-K5.@R+'?+,^V%8<`0_XMS(/R++[]B
M!/L8YW"ZD$NGX70Y(1&<Y_7@]7JT6FU4*C7J'\/"PKF`P6"X1NV3OW.8@^!G
MSYS]M+=LEM-"[@+)3![9;`&93`[A2)2D:"&62*#9;*+3Z2P?!.X+W]K>]B22
M&8B5BJIM=&L;9K,),CDEF<SB[F]!51)9WE7ST._:)PM%<VGA_#M:P>Y`FY9?
MEQKD"`6;H0@8AE'[1+&J&JU8V.E%WA>^+_+OOOWAI>$1.VNWCT*J-Y`OEI#/
M%]&@9PW]DJD,RCLE@-6A2/=KUW]R2E)MZ!_!E^[>@U404"B4$'H8!4,;9F+"
M"2U9D6$T,)F,ZG<6"_$X/5;7'KP="-QZ]E#XXN*B+KH5UH8VUM5D[74[\/F>
MA*+(V(XE$8O'52L*-@%Z/8]ARS`2Z0*"J^N7::RQ+YQ@1EE6KO!Z[G3/:E*M
M2JV&C8U-!(/WR9)Q<@FY@R94*`<LJX'-;B-?#^#&S9MSR4PV0/I/'YA0CN,$
M2M*[9;&"7);J".U,HW$057),)A6G_WK:2+7>=V@U6W^ZA"1CM%HUT13`<T_Y
MO*<(%=Y7N&A6-A9+7%I<#'P<V"E#$X_":1E!@_0WE4OD]P0$81D;00GUL?-P
MTII'S%84=1S,8BGL<T]*?K^_ZG`XSM'$N4<BIXZ.)#6JQ^;GP6;3F#[Y`M)4
MH)P#/*3\%JPCG\-ER^&SG!V#'C?\<_.(U^O0MAO+4T['6\_,S$3[:MYJR:/1
MK>3[MTMEN(Y842?[!JL2&I421?@-I$H=]^X/8VJRC1'-'C)B`ROTOBE)@8/`
MC\#O_!KDUQ(I;ZI4A$#ZBE1*^7P*M>+7&#3<P(_7GX?"G,)JV`$KN237JD-0
MVA7_R1?7#]VA0T8>HUH6_B$>DY,3%\3*VNLU^?9KGIGO\?/R!(Z?>!,=?@QS
MQ\O-F=F9BQ&J,WK&6*2#X>JA\/%Q5])4K;DUM&1%EF/U>E5W;%9Z)97RZX]8
MSZ0]GME790U7-SG=79_7&__79Z`HEC^,A$.7B\7B_'_N@/X#RG'V`-Z*9CP`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C
M;VTO,C-X,C,O,2YP;F<````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,R,@`Q,#4Q-30S,S<V-0`P
M,C8S,S,`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)344'
MU`$,#3H:XM[6P0````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!
MTMU^_```!%])1$%42(GME%],VU44Q_?HLS$Q633RY)OQQ<QD,8MN$DFF4]D8
M83`'3*#0CK^%_@&$,N!78(7^$2@=Q1;Z#]K2C8Z6L0(%U@+R3\J_TM"61<7!
M8+`!+8ZPK]=&,#/CP<0'33S)S<D]N?=S3[[GG'OLV/_VK[4J4;V*P>2:.JWW
M5/\(T#D\$MYK'PR*ZV1!G<$,AW,86OTM4`)QL*%14>KU^M_[VU"'TWG=V-Y.
ME5=4KA3R*'Q;+X-2I4.KW@BY4@V!J`YIF7G@E56NI*32J3Z[G7(X')2=^`ZS
MF7*[%ZAGS_;>/@3N[^\?#P0"DUZO=[*<HIZ3!8K/1W8.$WDL-IBY!%92`FF#
M#"P6"[34-##2,Z!0*L'F%H#/KP"/QPO=:6O38WW]<<0AG+P4MK&Q"8?#"3:;
M#8%``&M7%[G$1VEI*<1B,5AY+-AZ>E!148',K.R0ET@D*"HJ1DU-#9J;6Y"5
MG4/D<\X&@L%W#N$[.X&PF9E9=%HL(:!>KT='1P>$8@G)FH4VLB\K*X/-9H-.
MUXJ"@D*HU9K0HQF9V22F"^T3DNE87OZEY@6=53I]!)?HJS>:H-9HH=%H2):]
MD,N;0E"A4`BA2`252H7^_OZ0!#+934BE4L1>28"2R).1E8.81`;J9$V[6UO;
M9P[TCE"HM(^J:QNAUK:2C,V@B.:_0[CY!=`;#.!P."@N+D9]?3U(T0BT`7<Z
M.\'AYN-:>CH:Y7)<^BH1D7')**&JX/7Y(@[@;UWG"Y8D,@4:FEJ0F$3#Q=@K
M./O%!43&Q"/^:QJX!))&9X!Q+1UQ\5<1%1.'\(BS.''R%&*OTA%Q+A(?GXM"
M4@8'Y54B^/S^/PLZ[UZ0<BJ%H/-(AW"+D<@LPNEST0C_["*B&4QP29S]33GR
M^$*DYQ;B\^AXG/SD2WP0_BG.7TY!%#T7";0,,/.+8;5:%S8W-]\]A/?/N,/D
MK@5\2,]&FX'HWM4#F;(%0GD+8FZJD,GF@OI.@_,B&4226FB-MU$B;8)`6`M&
M:362FUM!ADUA;#?%/WRX<N*%@KI6UD^+!D=1)*[U64:GG^>*ZN%>\,`\ZT5B
M@P+3[@5,/?@)8\3[B*\V6=!QMSLP-C&]G&NQH^[VG<W=W=T++YW*^_Z?Y[7W
M>C$R,M:<W>W82ZNJQJ)O"9:1"0R,C&+`Y4&2LA7=]YTP."9QJ5F/OJ'A9>>X
MRZJUV?>F7*[++P6OK&\R\H=<.XF<0@R,3H#9;H7.:(1U?!HI2CWNVOI0U3V$
M>"+#Q)3KUVI+/W(5+?`L^G##TH=*K3YXY%\BF?#4I!HZ45)&^0.!H(E,J^GQ
MQA-/^>`$TF^(,#?G1N/P)`R]=BPM+9W9VMXV!8.[#TP]3B2HV]$W.74TW+6Z
M46,;_V%-H5"<.HA-NCSO6^86?S1W=CFWMK9H&T^?TLC?0R-M^_H?[?O1R/3\
M$\/0]_#X_)5'PLG!5_?V]M[X:WQU]=%Q4OG7CKJWMK;^IM^_%$;.O7(D_#]I
MOP&%;2%;T^KIU0````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\Q,"YP;F<`````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R,C<T`#$P-3$U-#,S-S8U`#`R-C0R,0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M%P```!<(!@```.`JU*`````'=$E-10?4`0P--QW)%#TO````!F)+1T0`_P#_
M`/^@O:>3````"7!(67,```L2```+$@'2W7[\```$24E$051(Q^V374S:9Q3&
M>[WL8M=+EIDV:;*+KKW:DFW9VM4L+NU%FS:IIFJ5;?+7JE70JE695J=H503\
M`.5+$$%!P"\4/R<JBM*)HJ#&#]`.II7*9A6TSF?_WKAUK<VR[;)/\N9-SON>
MWSE/3LZ)$V_T7\3F5D7?H:<1>D-/]/\"=+I<[\PZYK3%+*Z6)ZK?5ZHTD"G5
M^\5E'*UQ:.3+?PVV.QPGF[1ML\4</AIU>LA;]6"K6J`B[]!\-D*2L_8EFC9_
MT\B$O\<T1E<.C_OGG2[_[N[N^Z\%Z[O[3\H4ZM$2;@WDZC9H.WH0PZK!AU5-
MN)J>BU.23IRJ5.&#\`2<+96`PBS'QW4=D+5WP>5R!;T67L2JO%I05@5]SX\8
M,IDQ-OX03%DC(L0JA#&*<*-"BO.AT0@._08W6;4@=`.(Y,IA'#;]NKW]]+V7
M@'Z__^VI:5M4G:PA2J'2[%?4UD&K[X6FW8`::2,R'G"0(U6`R,I!2GD-PBCQ
MJ!!(P5-JH+`OXE9,/,HXE9*LG/PHK]?[T0MP@406Q!-*42V20]*@1EVC#DVZ
M3K09^E'&KT-<:A:$BD90XY.@;&D#3R`&I[(:U35"](V:023244D6H]W+0W-+
MQ_S>WO[9([A:UV$I8O-1)6Y`[Z`)]:I6=/89T3TP@N=Q:@(-`J$8M-1TC(Z9
M,3$^CIR\0F0P\J%NUN(!BPLIV5`DD8*"HA(XG<Z0(S@],\_!K95!UM2*AY/3
M$,I5**\6(2FK$,SR:C2J=5"I5&0!$0P&`SJ[ND")3<*U\&]AZ.G#[50&"%H6
MHN/HR&.68'EY^4_X@''$<IN>"297B&JQ`G?S6`BG)N/R#0H2[_T`H52)S.P<
ML'EBI&7?1WAT#,Z'7,'G7U]#[!TZKD?$X!:1!$H<#75R96!S<_/B$?S1D]V@
M6LL3G`YC()VT&EL@P!4R@99=@$_3Z_%5:`P8;`G.)?`10:$BE\E"<%@,*-1X
M9)8)<89@@\C(G6C6:A4>CR?RA8%*9P)!J>TN7(YE8-;I@;C=B&G;#`R+.SB7
MJ4.+OAN3JS[<%73!,3>'WJD5-!L&X'9[D-RR@C!F$Z:FIXE7K_K6OLE@MF%R
MRH:4KG5<2N/!N;J&H04WV/4:S+NW0&\8QZ!E!C,;`814C$/9VKVTL;4MNJ\8
MA*ZCJW-]??VME\!;_M\O$FV>C:COR_&38PD72H=01&[G_"^_@2HPPFRQ0FW?
MQAFZ',,35H@LF_@L5825-3?4U@WPFON>'1P<1+RRZWK['NL+_CS2<@H/'ON>
M^D=F7?ZU1S\_JS1O(3A#1-JU(5&SB.^*Y;#9YU*GG1M^DW7NP.7=P26^%66J
M`?^QZZY9V&.5*@P[,IF,^(N;"$:/V\?ABUT[.SM:]\9C[:;7JR67X_3S]\/#
MPT3KJB]`Y9&SL"_T'PLG+7T2"`1N_CU.3OTZ>2X<E^?S^2*7EI8(\L^[)][H
MG^H/D2P#*1P74*0`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T
M8V]M+S(S>#(S+S$Q+G!N9P``````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S-C(`,3`U,34T,S,W-C4`
M,#(V-#(P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4H`````=T24U%
M!]0!#`X,&QZ#R7L````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2
M`=+=?OP```1_241!5$C'[95;3)IG&,>[9#'+KMS%DEUMWNUF27>Q;#=+Y@[9
MFF7IVG5IK+%&L1YJ.V/KG%,)U7B86">"XCR!H"@B*B@"HE(0000%%44$/*$6
M-![P?(S][Y4E)FW:IFEVM>Q-WGSYGC?/[WO>__M_WN_"A?_'ZPZ+U?H--3L_
M@9I;F.!9?!S]KT#7U]>+U1JMA%5>M50G%$/8(D6#6'K<U"*1G)R<?/5:T-W=
MW6"'T\4O*JU\4E4G@KRK!T;3$`:'K.A2ZU#(J@*=P3[6&0;MXQ/VT/6-C>!7
MAAM-P_S2ZCI4\IO0)E-"W*X`M[$5(JD2\AXMU!H=_F!4X,<P"JA9N:BLX?)?
M30I2!:.<<\AODJ!;H\>0Q0K]@`G-4CG4?7J8+:,HJ>0C.2,/F7D,1-]-P[5P
MRA.=7E]^>GKZ]G.AJVMK5_D-S5'=C_HLC+\X:)0H(._M0YVX`XPJ`?*9U>"+
MVL&J%N!64CKHS$KT#PY!K3.B5BA!=6T#1&TR7@Z=$;6]O?WI4_`Z8;.#S1&@
MC,@ADBK`(0F=/?_`TW**$7N/!GH9%ZE9#U'#$V#4-@ZGTX6^`3/:%&HTM'2`
MS:G';P\*P*[F,<[!JEY-?@&SXI1)JI(H>B!3/8*@I1,&LQ7\YG;<H]*17<C&
M@'F$0"<"L\]@#NB?36?B3S8'0R.VP`XB;Z>BA%USN+^__W4`GII!8S`J>"CG
MB8BF8Q#+NL"J$2"WN!))Z7EH)%6-$*#=,84)^R3$':K`6C21YTIX#%)H!:"7
M<G`KF8J87]+`(K(2:2X%X/9)1WX:+>\T]R$+U?5BY!2Q$9N<CFN1B;A\(QXE
M%7PTMLI0Q1="(&['@\(R7(^^BR]_",.W5V[B)JGV[$.1<4F(N7,?'7(EB)TO
MG4OC]7H=O/H&)))M?G?Y9T1$Q2$L@D*>L;B=E`I*TJ\(2\E$."4>E+@[@?G3
M]0C<B(Q!5&(**!G9H-*R()6V8W5UU4F<<_$<3CKNZL+BXRCCZ+A%UBG'[-P<
MN!H#Y*I>V&RV\NFY^3VE6HMABP5ZZRC*B52#)C/&QR=@&;6A5]L'MWN:Y_/Y
MHHZ/CY]VR\;63A"G?RB#*U$<KJRL&#:W=].YO?I]44L;R'M84X_.KS59SJKZ
MGJ\UQA=R&K"PN#3AFE_(%?2;,>_Q*`\.#I[O<P)_1^^>[RJK;\3TS(Q&V6\*
MG7"XO+[E%=O1T=%%09?&+U-VPSXY^87).M;HGID%<42ZP3KV.U>IAL,Q)7EA
M9[H]2^_->!:=7J\/VSL[<7+'C*>LK@G+R\NU*VMKM"GWS(G7YZM56L??+Y*J
M8""=NK.[^[EO996D+1WY?,L?O1">J=2%T`1MZ.I18]7O_Z3?X7:URI6'Y#I(
M*I:JA$SB>^O(2)98:PAN5JEA&1FUV!S.4('6B-9>S<%+[Q3#M"=$:QTC7><\
MJ_8M<L"?[>WM19ZMF5RS0KUI^"R>1>)!1*8$8K4/79[%C\WV*4RZW"^'DX0W
M-S<W0[:VMD+(P;SQS-J[Y%#/XL'/Q(/\?G\(R?O@O_5[_!NA%%<GTG"]L```
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,3(N<&YG````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C0P,0`Q,#4Q-30S,S<V-0`P,C8T,3,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!<````7"`8```#@*M2@````!W1)344'U`$,#@P3$%A!20````9B2T=$`/\`
M_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```!(Y)1$%42(GME&E,TW<8
MQTWV9MFRS)=F2XSO?+$8=9LQ6S+C03(W-49@,Q.%68Z5J@/I4"A%H!U72VD+
MR%5HQ=)R%-I"6TI/H(>4XU]*H10VK0K#H>"`S`D)P^]^D,RE<TNV;*^6/>^^
M_^/SW,^6+?]Y$X@KME]B9NPPFLS;_Q7@O?O3KP0F@O1B@8A^O:;^J;"B!BJU
M]NF&=KK<._\1W-;GJJR4*M#0I$*/PP6O;Q16>R^*1%5@<?C4[=#=TK\--73;
MMAK-]H;\TLIG\M8.M'4:(6U20]79C7:="3W.6ZBH;<`GGS.>\<55*Y6U]1?_
M,KQ85'VP4%BU";7T.G'+,PBUWD3@1KAN#:"CRP+B&$EIV8@\FX1C46?65&WJ
M<W\*7%E9><DWZM]VXZ9\FT9G#!2+JZ$W]\%D=Z&UPXCJAA8T:;J(=B*G4(3D
MM&M0MNN)4S,V`JFNN[$T,?D-C5,DW/;CDR>OA<%=_0,[M'HC:F5R7*]KA%)M
MV(2V:(W@54B1D)(-5KX(F5\+P6070&^R8G+J6PQY1Z$S]T*J4"%?4`XVEP^3
MK4\8!C=9>ZKS>&4HKU=`9^J!5-F.+DLOW(->"&MNXAR=B89F#<F&//,,P3\V
M#LKGA[Q5BPJ)'(->/]0&,[Y(8R.+4SCU\-&CW<_AF3G<H)@TJ:Y1A1'_V&;*
M,M+$O!(R&21:`XET9-2/B>`DG/U#D#2V(:M`A)C$+Y'"XD*F5".-9/09[1+2
MLW)`4=31YW")K"&8<O4:)#=;T4+*D<N[CJ14-J+C+H#++X=[8!C=UEYTF6UH
M5'6`<24/QT_3<.1D#&(9Z:"3'IQ-3,69^`M@7F7!Y_/]!K\W_=UP2ID$$;&)
M.'@R&@>B8[!SSS[LB3B!G;O>QJG+F=C_P2$<2TY%Q/%(O/M1)':_=Q![#W^,
M?<>BL.?041R(2<"N=_:CIJ9V]?NYN2//X<&%Q;C,;B=.)##`KZD#JZ@$\60*
MHC@\T-A<G)<V(^X\#26*5IRF)2&N68?#D:=!^RH#R>DL,&J5^)1;`DYAZ3+9
M[-BPA@;GYA-9I"1E!%SMIF#M=8!KZT=J;@$,?6Y8R:RK2*V;[0YH/<-(5FB1
MGE^(4E)"N],%9J<=C+Q\^/W^8!AX?7W]3>MDB'(,45!Y`X@GTU$EO8'!0!`&
MLC39%C=JFU7@#8XC@9T#Q_`(W-0(1!8G:)7UD"F4&`Y.D64;F+ES)_16&/S!
M\A,AVT$AFR>`H,>#*T4"\/167.:703[HPUFQ!/PZ&5*5'>`(RY&GLT':KD56
MAQ4L424XVFX4RA3P>KV:M;6UU\/@9<-!(:.I$U62^I_O/IQ?Z1^?`-OD0C([
M%^*>?J3P1?"-!U8G0O=7C)1_/;ZYD]P6"0+WIE<=U.A:EF<,3!8;3J=+0.`O
MA\%;O0&A3*/[R6RVT#?T[1^6[4*]!5U6VRHQS?+RLF9I:>G5C7=R[T2_4*V#
MQ^.A%A<7MRI\DQEBFQMJC>;!_./''[YP5TC-WR<>8W[5Y,Z\L;"P0"?`V-]_
M2YR="H5"])F9F<U[3O[;.SL[NZ%?!/]O?V2_`"@"/7J9?!_U`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O
M=&-O;2\R,W@R,R\Q,RYP;F<``````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-C0V`#$P-3$U-#,S-S8U
M`#`R-C0R-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-
M10?4`0P.#`L#--D?````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+
M$@'2W7[\```#,TE$051(Q^V5NT\;613&4U%3TFV4)DVD[?8/2)IM5]HZHDR5
M)AU::24"38B#8@R*27:]7CLA!,S@!TD<;`.V\8P]X]?8'MOR8\:/\1M#LD&`
M%?3E>)!6*2)%*!0IN-+17,WC=^_WG7/N7+ER.7[($8O%[FWO[##!8)#9W]^W
M?C<P(V6OR4HMDTI)1Z5R^5.WVT6M5L>./X2M+?]1/I^?$D5QY-Q@556OI5)I
M-I,M0*XTH#8[6@SG1;F.%=L[+"V[8+&\F*,%?CT7/)O-9F1%0;?30:O30T*J
M82N0!LMGT6BVX?,G\=A@PY-GZWABM+8W-SUA699'OPFFEVX*T?B@T>JBU>ZB
M6.E`$.OPLSG4U1;*LHHU!XO-K3@BL0(81P"Z1P8$`H'HWM[>]:]"^_V^CA*V
ME$C$ZV6Y`JE00S*K("04\<83A]/-@XT6X'@3H>"@5%1TNCTHM1:$F(A7*ZOP
M>GU\)!)9.CP\O/WE;G^*\(*2+U91HH_X>`[;;`HEI0%.R,'XEPN.UQR2Z3+"
M@J190[O4E*3S%<I'&VJC"2Z:)Q5SM(CW^.#@X)8&3R02LVFI@+<D-5NH:I',
ME%!6FO#X13"N761R9?3[>P3MH:JVZ7D9;I^`5XR?WJ\@+A;!.%G,/)R#P6!`
M+I<[2S39,2N3%2FIA&:K`U&J(,AFL+[!PN8(HE)5T24+>KV>EH=`6,*_+[V8
M-]IALKC)L@BL+WV:NH<Z/186%D"E>@;_\.'];9[GWX?8,'S;NW"^WH;9ZJ2*
M>$YAU>X%@BQ8ED68C\+\G,&LWH*91V8\_7L%-H86<'FP;G?A_OVIH?=Y4OGS
M_[Z3A[_9[?;Q<#@23222X'D!N[LA<%P825$$Y034J5A=M>'!@QF8_C%C8N(/
M3$U-0Z?3#>;G%\:-1N/XD$%]\LM7JV8P&(P>'Q^/??SXWQC9,$:JQDY.3K1K
MM5J=65M;@]/IA-ELQG!.0"PN+AY=Q!GSY_+R,DPF$W6G18LAG..X[X=3#5_=
MV-B(>[T>Z/5ZK%!M3TY.DE6K=R_DA*2S9-3M=F-Z>AH,PQR0QPPING$A\-/3
MTY%&HW$G%`K=H4;Y_?*'=.[Q&>K9P4!7*NHW`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A
M=&AE<F1O=&-O;2\R,W@R,R\Q-"YP;F<`````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,3$P`#$P-3$U
M-#,S-S8U`#`R-C0Q,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`JU*``
M```'=$E-10?4`0P-."5FCIE^````!F)+1T0`_P#_`/^@O:>3````"7!(67,`
M``L2```+$@'2W7[\```#U4E$051(Q]V524\;9QC'TW-;J8=&JGI(J'K@4JE?
MH<=\@!QZH>+2BD,^!$I41:@+P0DD(!.,B1=B&S`E%!M[O#M>\3J>L3UXM\=K
M;5:#3/CG&0Y%58M4FI[R2B.-1L_[>_[/.C=NO->G7"[?=+O=0R:3::C9;-[Z
M7Z#[^_MWT^GT6+%8#":32?C]`223[+'9;!X[/3T=_L_@;O>/$9[/]5A.0+U>
M1Z?3`:E&.)*`2FV`T^D*=SKM7Z\-)MB]7"XWJ-9J:#1;R.9%L'P)._%=E,HB
MMIDPIF<->/Q$?AX(1OJ)1.+>OX93*OHU422U;53$-D+Q,K;M<22Y'.J-%LQ,
M%,^5)FCU+OPRJ81<OC"@NHQ<">SU>I_Z?+[/1%&<B2>2YX5R'=*3$D3X(D4X
M?3QV"S6$H@*65UP(13+(%40$=W@HEY9!Q29$+T+GZ\/#PX__`B\62UPBP2+%
M\<CL%N&/9A%A\[![62PM,]"M>6#WI+"VX46(@*U6"ZUV&^5J$Y5J'3Y?`*9M
M.T4Q#X[C)O\$Y_/Y[R(Q=B\038/-E!",\G#[DZB*35*:Q;/Y5[#:=U"JB,@7
M*@1N$[@#/EN$R\>B6FM`)%N[F\5//\LP,3%Q"7<ZG9/I;!Z,*WX!$/(UQ+D"
M_.$,5C9>(QCF"%!'FY1*X`1?P*8E!*7&`L4+,[R!%#9-0>A6/!?P\?'Q2W@F
MDYF,Q>)(\3GD2U4$(@(VS6$H5!:HM!84Z9M8;Z#1:*!6;V';$</L\U=X]%@/
MC<Z.+68'*[^Y*2VO<?_^CS`8#)=P*L!M&I2XQ6(]5FN6,26;P?R""K(G<LAD
M3Z'3&_!"I8%>K^\;C>MGLW,+F'ZJP*,I.=D^(]M%ZOUE+"VICBT62SR5XF[_
MK6.VMK;&""`9@7H75BN#0""`@X,#S]'1D68P&-REU#R@KO!XO5YHM5JX7"ZD
MTQDX'`Z02/G9V=F'_]B.-'7#L5@LK%`H+BY:K5:P+"M-Y[?]?O]+FM"%;K<[
M3:/_!;7MZ.KJ:H]V#F@=D*`E9+,"]O;VAJ[L=U*_2NH/7K[4->@=!$4T&NTR
MC*V]MK8F*3VG2+252D6IT6C>S,W-0:?301"$'CF.D.//KX13<4<HQ!_L=OL=
MNO20+FQ0@:!1J[&^OH[-S=]!@P):#QL>C^<AS_,VA\,)2M7JM78,Y?@#"OE[
MAF&D8EXH-!J-D-32]U')IMELW1*$W6](\5?7A7\BU6!F9@934U-0JS6@5$AI
MDGI^])UW.J5IF-(0E!PL+BY>.*%BXN3DY-WATJ%E=M-FLX6H,SBJQQU2/D11
M??3^_GO?`FQ49\\02%VJ`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S$U+G!N
M9P``````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#$S-S8`,3`U,34T,S,W-C4`,#(V-#,P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`TX-7LYB1H````&
M8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```*+241!5$C'
M[51+3YI1$/4GN.BBJZ;K[MITT473L.E/Z*:+_H2F:=*]24T^$V.-1'E'0<$`
M/A"#$0UQH1(@/'P0BH`2P53"0P%)$%`YG9FT7=B739=ZDQO(O7?.G#ESYNOI
MN5NW;W6[W4>7EY>JDY,352*14$4B$=75U=7]_P5]2Z#*Q<7%Y^/C8VQN;F)C
M8P-.IQ/E<MD#0*$WRMG9F9),)A5*J-#9^Y^`Z/`>LZ''FG:[O56I5+9RN5R3
MP-%JM>#S^3`_/P^OUXO)R4DL+R^C5JN!$N/T]!1K:VO(Y_/\VZ+X#]?!DP0.
M8B'L`H$`YN;F4*U642J5!-SM=O_8`P,#V-W=13J=!DF%_?U]V.UVV&RV&N&\
M_B4XLPF%0A)HL5C@<#BPL[,#H]$(J]6*Z>EI`>&[8K&(P\-#A,-A23(U-86%
MA86ZQ^-Y<QW<Q>5'HU%HM5J,CX\+(#/B<ZZ$2Q\9&1%@O5Z/1J,AE<W.SDK,
MX.`@AH:&8BZ7Z]UU\%[2JH]T2S*03J>3H%@LMD45]9&N1F(DP.OKZU(-O1?)
M5E=700V5NXF)B8=_<LAC2M!.I5+"BOZ7MK>W`YE,)L[]J-?KLKDO=";54'7M
MHZ.C9V0`&R5[\%MPEH<2@/4G7XN.P\/#4DDVFQ6VK#4SY]Z,C8UA;V^O0^^?
M_]7;#,[`G4X'P6"0-11W<)*9F1E)R#Y?65F1IFLT&IA,)G:9ZR;@O;1;[%]N
M)EE+7#(Z.@J_WR_-+10*6%I:@L%@8(TY:;?9;'ZZT602^,=ODU?DP6%F9K/Y
M"^FI\,22#.[^_GXL+BXZU&HU-]WRS^-/+)^2?U44K*)F/?E^3LU[=7!P<!Z/
MQU_2W3E]:U[<?8%OP?H*48V9-"+GH$D`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S
M+S$V+G!N9P``````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#(S,3(`,3`U,34T,S,W-C4`,#(V-#(P`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`TY"Z-#
MI?`````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```17
M241!5$C'W97-3V)G%,9GT46;=M$F31>SJ6FF.]-T-;.=31L777311=.D&9?]
M!Z:956.[L4['L;83M2J*SB`@#!=$^1`1^10!4<#+11!!N'!!^12PT=$^/?<N
MIIDX:<VD29.2O(LW)_=WGO<Y'UR[]K_\M=OMZWM[Z:YBL3@6#H<YI\O%\3P?
M6EE9Z3H[.WOKE<''QZU;N1R?YW;3.*I4T.ET4#JLPNT-0*=;0"02D==J]2]>
M!=S-\X7D?I:'4*ZB4*J"%ZK@]GBD,@*TS"JF9QEH--J&(`@,)>Z^,CR3/6@*
MAQ6T2*UPV(`OF(+1$L!&B*-[#4NV$`:'U1@99S`P,$(O85IDW3\GJ#?J7^^P
M\6=YH0*>%,>2!;@#2=C=$4E]/)G'8]4J+/8P0I$T%BWK^/71.*Q6*W-Z>OHY
MG7<N0:O5&A/>VMI*)I.-;%Y`,)*"/[P+FRL"E<XIG15G%"JM$]:5(`Z/ZFBV
M.LCP1V`3&9A,UL:RS5Y1*I5LM5J]^QR<R^5NAL*Q8I3+8B\KP!N(P>8,83]7
M@B<0Q_"(%OHE']A='C$V@^;Q,5KM$QSP94F`<%C'4;4)AR>&'P<&,3HZ.O0<
MOKV]/11ETS"8U[&7*2!!A0OO[(,E"_0F'Q;,/J3V>;0[)Q)4$A",XZG!A6F%
M!=%X!I[U'3Q6VG'__C#Z^OI>A&>R.8)E42C7X`LDL&C=P(QB&7/S*]2"-1RW
MVNBTVRA7&C"3+2,3!CSX68D)N0D:,<D3"_1&-Q5X"&-C8W_!J95Z6#9^Y/;Z
M8339H-.;,3XYAP</QS'TBPPFBQWV51>"P1`<3B\4J@4\');CIT$9?IN8@UIK
MA,Y@AE*EP=34U%$BD>AYH:#-9O/33"9S0J^@XIBD$^>X/U*I5(<F$Q:+!;.S
MLUA:,D$FFP+#Z.'UKL/M]L#O]TMQF4P&E\O5\[+!>7-K:WN2&H8^<&-A80&;
MFYL"J>A=6UN#T6B$V6S&S,P,M%HM8M&H/YU.6SP>#[+9+%975^DXQ$1W+L$Y
MCNMR.IVD;$D":#0:T/TN);AAM]O]8DR$ZO4&3$]/BY!>VB^SH5`(*I4::K5:
M$D!W[A*\5"I=IU'.!X)!3$[*6@S#E`T&P\=BC'K_;5(=%FTAA6FZ@Y;:=]5J
MY1M27M[=W8V(8++F6Y9EWWWI=`*X1<%D/!YWM-N=?H(,DTWW<OG<O?)A^<-Z
MO=Y/T(\*A0(*A2((#MJ:CD:C^0%]UT_GUM^.__GY>??%Q7DO[8H#K?8IYN?G
M0;:`"OT>)7_MXN)B0O1X8V-#JHO#X0#9\\F5%Q?M[-M4=3Q1S,'G\TE>DY?K
M!/\R%HO5EI>7(:I74%SL%K+T]RO#Z?FW(Y&HI$Q4+4(.#@[6Q1BUXE=BAXB%
ME\OE4IS6Q]7A]/37\_G\]RJ5BJ-%Q'F]7JY6J]T08V3!H\7%15BLUB(5\)E"
MH1BA&7G_7_GKH[Y_@ZP9(L]OVFRV'W0ZW6?_R7_PGR8YZU2LPLFE`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L
M;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,3<N<&YG````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C(W
M-``Q,#4Q-30S,S<V-0`P,C8T,S``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!<````7"`8`
M``#@*M2@````!W1)344'U`$,#3D>SIY!&P````9B2T=$`/\`_P#_H+VGDP``
M``EP2%ES```+$@``"Q(!TMU^_```!$E)1$%42,?5U<MO5'44P/'O?<W<Z73:
M:6>FTW;ZL`5:$`S%2%`QAD:C"PP8%QI"U$27AH6@_X`[$Q-6DK@PNB-17+!`
M$VIC08/8`"WET=+']#6OV\Y[YKYFYLZX<H&T8.)&?]N3?')RSN^<`__7)SPN
M.'U[NMOG:SMJ56NG-S8V4=PNG(H)"+@4!4&2:5(5PAUA9%G^7=-2GP7:VV/A
M<+CV6%S3M$-S\TL7J@UZ6EK]-'E4%$5&`.KU!J(D85L6IFV32B8IYK/T]T;8
M/33T42@4.@<@;X??FIIZL[DUT.-3511)0I%E9$E&ED3*ND$VF^?&Y#7*NDXN
M5Z!6JU.M.NP8'#P%;(\O+2V]?.?NW"?U8I%>OQ]!$"CI.@(@RS+Y;(Y$*L'<
MW#Q[=@_1TQFJBY)\=7"@'X_J7OO+V1+_^IMOQ5"X2^Z.])"*)XGT13!*.FZ/
MBNIV8UD6Q7R9GIXN3IYX9\+C\5SR>#Q?_-T1M\*/'SO^92Y70%9D*O4:\82&
MEM)()C06EZ+HIL':>@S+-'$<Y_I6\+;X\LK*X'HL02Y?HI`O$HTNX_/[J%0K
MQ&-);MR<8?[!'':EAB1)V_ZV1\IBFN:9$^]]H(0ZN[$M"[VL8U<J/%B((@HB
MMF63RQ=H`.G-+([C;(L_DOGY[R^^U!8(2YWA3LJZP48Z@Z9M8I0-!"">2)+/
M9A%$%^ELADL__A0IETLM_PB?G+Q!(!AD8S/#PD(401#H[^_%I<A(HDBSUPN`
MW]\"LHO;=^Z^.S%Q]=DGXF/CXZZ%A7EE8786PS2IU^OL&=Y%M5HANK+&RMHZ
MDB(1Z@CA5IMH\P=83Z2Y.3-[=FQ\W+LM;IJFMU*IGO,VN8^:EHU>+**7BMR?
MG6-Z>H;-9`S#,'`<AVJUBBQ!1SB$VN1A[/+ED5@B->$XSLXM&RK+<H@&'^;R
M>;34!FY5Q>OU42@42,;7<*MN2N42DBQC6R:B*-$01$1%011%IJ9O/_?T\*Y7
M@<5'%I?C.-+JZOJ9L9^O?'XEFZ6QMDRD-8C5T4YS+D.EODY7UV_<NVE0"K]/
M1!9I;PV05B1:\YG%X8&!\NCHD6)W=_?;DB1I#V4N29)3+AO%D0,C2*D$NPZ_
M0*+>(-+DHJS=)QC\BIX.C7/Q+GP[=G!D_WYBAHEL&==W1CI/[MV[+[IMS2W+
M[HPNKW_\:R9';[`=W8'I8@FCD*'=_P/E@L'43(#^OAKMU$GE36X52ICETL16
M\$/X]3^FU9G5^%`\DR:HJN2J-NIFC&+Z.WQ-OW#QTO/8PJO<BX8)M+6Q8>N$
MJG9A]/"+]Y\XH7Y?,S6WBU&_AX&G^DX5BH4W2O;DZP/#YQF_%N'@H;>HNSLY
M<+!@[MNW]_1B4L/=XDV'P^$+3\1[^[IBS<72@"`TJ%8JJWJIX!K9ESN2U%YQ
MAX+'$H.#S[Q6$22]I7=G?6AH:.U?W\!\/O?ITN+\V70Z?>`_=Z#_!`Y._!JS
M\M!W`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R
M,R\Q."YP;F<``````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S4V`#$P-3$U-#,S-S8U`#`R-C0S,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P-.2[H
M1W&W````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```$
M>TE$051(Q^64ZT_:5QC'^VY[N25=VNS-^@<L6?9B-EG2M>E:;;;IM.MF.N^S
M%[5>VM5;7:N3>;]AU2(B5D%!BH@@@@BB@(@@(JB@6(IS0T44HVYQ7F;ZW9%E
M)DV3;69[M9WD).=W\LOG.<_S?;[/L6/_Z45K8+Z1GD,YQ6IK/V6WVU_Y5Z!/
MG<XK+`X_@5K',-70'X/#ZT0-C5%JG9R\\(_`6KTQBLGB;K1P!9#(^V&V6*'1
MCX+>S$%!&75!K=%V>3R>UXX,ELG[D^L8+;_26WCHZ):#]40$OK@7`G)6:8;1
MQA<A*B$=^85E.SR^@)5'*?C[04JIM.UFC@`RI1K#!A-Z^S7@=O9`H]-C4*M'
M12T3J=D41-R\BX_#KN)!?@'K3X$>S_)Q>A/[I-Y@HGU;5/F\LT>!OD$=1+TJ
M,-L$:"*[7ZT#K:D-\:DYJ&5RT"U7H;:Q%??R2Y\/Z?2TVYD/3KI<WQ]_":X<
M4,\\8K)136ORI\\52""4*@B$B^2L`MS^I@24BGHDI>>!W2Z`?686-OL,9"0K
MOE@.2G$ELO**()$IEK:VM@(.P:-CYNC\TIK-NB:N'\P3]J!=*(71;$4+3X28
MI$Q_*90DDW[U$":F;)BP3:.G;P#5#2RH2*E4&AUR"JH0<SV)!+7/[NWMO>.'
MW\G.H]:0GQXR6C%*@"*9$DU<(:KJ6;B;6PHVKPO&L7%,SS@P;K6AM4."0BH#
M\6DYB$[,\)?M?E$U8LGY4O!E,!H;,3\_?\D/[^U34',+*U''8*%+JD3)0R9N
M95(0_E4:$C/RH!@8\K^XIT]%VE*%=!+PL^ADG`^)Q.=Q*4C)_@Y7X],0GYR%
MD+`KJ*?3,3<W]SM\8V/S+>.8U99:0D4,I00?A8;C[,5@O'<V".]'QN.+Z[<0
M%AY%=B1"KZ4A*/8F`LY<Q.D/`A$0=0-GRNMQ+C`8(9?#$1T3BRZ1:,?G6_O0
M#_?N[KWK7M](82RM(4(ZB-+*2O!%8C1W"G%!/8:HXG+4\_AHY@L0I[<@L)I.
M!"Q!(:T1Z?1&A-*;<:>@&.W27BB5_=W$7-&'@B:L[5$?+?I@FI@$D]T&_L@H
M[GE_ALPT#K%61]J-]/7<,@I'S%`9C6A@L=!AF4*$8P$=$BG46BU2IN=Q@WC!
M8K'4O-"&&8X?J/%T)MC"+EB6EF%=]."6<@CW*ZLPXUV%S;T(AF$,:155L#L<
MF/*MPS0WC^3F5B)\.[1+7M#%4F25E($,-ND+<-*7GYC-9AK[QV5\JAL'B\,Y
M$`0VQRS*O)OXDMA?IS?`[79C=7L'06,.Y+(Y<+E<T)'`YR?GD5]>A6<NE]SG
M\[W^DHGV@5<=O^R4"4WF[8YAPVZ.TXW'8@FLRRO[7*5JNWQB!M7$H0ZG$[+9
M9]NM`YK]W&D7GO0I()^>W=4;1[<W-W^Z]I>S)=*]_G:B>?II'9=/5/>E'MRE
MN3RRKSLE&#$89`??BLVMU#BK<X<CZH;3Z3QWI,FXLK)RFH`/55]<7#RQL+"0
M0$ISXH\[K]<;O;JZFD#<^.:1X/_O]1L@LD#Q#QA`\P````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S$Y+G!N9P``````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P
M-S$`,3`U,34T,S,W-C4`,#(V-#(U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````7````%P@&
M````X"K4H`````=T24U%!]0!#`TZ`X:U?@$````&8DM'1`#_`/\`_Z"]IY,`
M```)<$A9<P``"Q(```L2`=+=?OP```/&241!5$B)[=!+;Y1E`,7Q_W-YW[E0
M.QV@4Z8MVE9;1<70`(F!&+9N1%T:/X,;5YH8%_HMW+@C2HQQH\0%8B/$60!N
M1&MI@>*43J>=S.V=>6_/Q04;PP=P8?AMSNXDY\!3_RL"P%K[PL/M!S^LKZ\?
MM]9BK:5>KW\Y5:U>N'WKUM++K[R*`.[<N<.9LV=)TS%;6_=(XC''GUTDRU*B
MX0`I%=8Z:C,UEI=7+BIK[8IS[I(G.8ESNEP*]:.=;=UH-,Z>.+$\O;FYKG=V
M6GIAH:X;C1LZ'H_TT2.3>F)B0@<:_?/5JWIN?E:OK"SH4KF@V_MM_><?ZWIV
M;NZ2S+)L*8[C,\(GK*U=Y>;-VYP_MTJ_UZ';:5$J*IK-)J%."`.!R8?T>WM<
M_OHK#O;;6&M)X@231_QZXQ<*89FW+E[\;F9F9DO&XS'[[199TB4:'K#]8(M"
MD"&E)4UZ>!?3Z[1)DPAC8EJ/VLS5)WGCW$D:C0:')IZA/QB2)ST&_0,ZG0Z5
MRM0[Q6)Q0^I`?[1_<(#)1^!SXE&,=SG66KR+P><DHP'.#L$;_M[>X<<KUYFI
M57GW[?/<O?L[#^]M`@G.9K1:NSS:V6$41<@LRR_L[K;P=DRE4J1:+9*F7:*H
MCS$QI2(X85'"X%W*BR_-$!8ME[_YGMEC$U0J!:+A`$&.$(9!O\?FYB;-G2;:
M6DN2)/0',:=7%\DRR]JUW^@<C&ANMSFU.L_[[[W.WEZ+OS::G#YUB#.K"RPO
M5=FXNT6KU>.YXU7VV[L,HPCOINCWNK3;;42KU?)KUWYBKW6?_;TFSCJ&_9AR
MJ4AU:@HG<CK=+E&44BZ4F#Y2Q9#3[?6P5A$4)YDHETG3`8-AS-'I.G/S\RPN
M/H\60N"%0(H"T[5%I+,<JWF,R7'68`U4)ZI,E2W>@[66("Q3KU4(`@U2H[5&
MJJ,@-4A%(2Q0*I?1A4*!(X</$PT&.)."![Q#YQG&&H0/P8-U#@`I)4J'**5`
M")36Z+!`4"BAE,9:@Y`2K15::WUONC:SE&89HRC"&(,U.2Y/<<;@G`7`.8=4
M"N\<0DJ\!Z4D0@BD5`@A45H3A`4F)R>IUV<1\7C\9IS$5T:C$8/!$&LMUF1D
MF2'/TL>E4F),AA`"YSU:::SS!$&`<XX@"`G"X/$JI:E4*M1J-82U]K`QYC7O
M_1?.N>-`"."]=\88Y[T72JG`>Y\YYT(@DU*&0@@`;ZU-I92AUAH>GVJ44EXI
M]8G@"=;:CX$RL`%<!Q:!#X#/@$__E0#WE5(?6FL_!\9`%_A6*=5^LO>I_\8_
MV6<+;00#OMH`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X
M,C,O,BYP;F<````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,R-P`Q,#4Q-30S,S<V-0`P,C8S-#$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#@$X
M"4K&1`````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```
M!&1)1$%42(GME%U,FE<8QWNYZV7)DF;+O-K=LINE2YIES>K,3#:WM+8ZK:T?
MM8K?K0HJ:A5$7D0J`A,0E8*"**!$J:`6OPO5^C696F$%M-M<M:*V*K@:^]\K
MF2Y=ZL6276S)GIN3]SGG^9W_^WR<$R?^MW^M\012548NW=!EOJOZ1X"VT0<A
M_8,C?I%$YF_5WX'5-HH670<XMX3^VGH%R^7R?/2WH5:;K:RMO9U@5W!7BAD$
M:B1U4*HTT.K;T:!4@R<0(S6+!D8Y=R4Y)8T8&!@@;#8;,30T1!B-1L+A<!(O
M7NR]?P3<W]\_Z?/YIETNUS2;(%ZRV00(@H/LG%S0\O*12R5AS#)(:V7D=QZ2
M*2E(S\B"0J%$/KT(%1458#*99`P!G4X/KW<]]`A.WA2TL;$)J]4&&HT&'H\'
M<W<W.!P.6"P6A$)AP&_IZP.'!&7=R`[L'?A+2DK!KZY&4U,3;F3GX)[--N?S
M^S\X@N_L^()F9^?0U64*!&FU6G1V=D(@_`XYU#QH=3J4EY?#8K&@I;45A47%
M4*N;(1*)`A>UM+2@N;D9\4EI6%[^E?]*GE4:;2B]M!QZ0P?4S1KRH(94.0"Y
M_#8)94,@$*):((!*I0*96Y0R&)#)ZB"12A$=<R6@.BN;BJB$=(AE\MVMK>W@
MPWR'*E2:I_P:60!\H/A`_=#P,.B%1=#K]2@HH*.TE`&Q1().HQ%2:2U,)E-@
M/S,S"_7U#8B.3<3YF"0PB4JXW.[00_A[99Q;B\):):0-34BX1D'$I5B<BXA"
MV,4KB$ND@$XO1%I:.C(R,A$3=Q47(J,0$OHE3IT^@TM74Q$:=AZ??Q6.Q,Q\
ML'D"N#V>/POZ<,$A+>`*D,:H0#:=@?C<FSC[=22"PR(0D4X%G<E!?C$+-$XU
M,JDW\4UD'$Y_<0Z?A(0A_'(R+J91$4_)0@Z]%&:SV;&YN?GA$7QH=B&HP>[`
MF93K9#\;H.[N0ZVR"?SZ1GQ;I\;U_"(0MS4(%]9!(*J!IJT#3.EM5%6+D<[B
M(ZFQ%4*Q3*'3M\4]>;)RZI6"VE>\9P4CXR@1B=VF<?M+FE`"A],)XYP+";4*
MV!<<F%GZ&1/DZB;7*H,)QIY>W\34[#+5-`1QQYW-W=W="Z^=RGN>7QYJ[O9C
M;&RB,;O7NI?*K<*/[D68QB8Q//8`PW8GKBFUZ"7G0&^=1G2C#H/W1Y>MDS/F
M9LOPWHS=?OFUX!7O9GKA??M.//GKP^-3R&TWHT7?AIZ).5!(8(^E'Y6]5L1*
MY9B<L?]612K-5:C@?.1&I6D07(W6?^Q;(IIR\E/T76"6<SP^G]]`3JMA?>.9
MDSTRA4R>$//S"Z@?G8:^?Q`>CR=X:WO;X/?O+AGZ;(A7MV-@>N9XN'UU@V^9
M_'Y-+I=_>NB;MCL_-LT_^LG8U6W;VMJB;#Q_3B'?'@K9MF__T;Z?C?VP\*QM
M=!Q.SR+W6#AY\,V]O;UW_NI?77UZDJS\6\?%K:UYWUUZ_#C(N[[^QK'P_Z3]
M#NY%(78IO;S5`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\R,"YP;F<`````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q
M-C`S`#$P-3$U-#,S-S8U`#`R-C0Q-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````%P```!<(
M!@```.`JU*`````'=$E-10?4`0P-.BU:8W/.````!F)+1T0`_P#_`/^@O:>3
M````"7!(67,```L2```+$@'2W7[\```#$$E$051(B>U32T\3413^9N;.HYVV
M4Q[R2`DL)""F1$S41(PA)FQ,7/@/C"Y<N6/CSI6)>Q/CSH4[-R[<L7"A!(A&
M7CY0@:A0*"!!:*<SG4[;\9R1,0TN7&LXZ<GM/??<[WSGNV>`(_NO3#H<R.5R
MV;<?/K8&00`A!`;Z^C:325.>F)QNL]TRAK(GJR?Z^R8X=W)J>OC+1E[K[FBO
M7[PP_.*OX"^GII^N*\FKD"34/!=6J?@VU902&]`'_%H=<=_Q,KIR?77M6U7*
M''_D2L+44:M^7YB[<>OFM<>-6'*Y7-9]W[_CNNYLL5B<=4K.I?BQ5KQ[,X_%
M5_/X^G5MT#;,@?7\-A9G9J&VM^LS[Y8>*%;30R1,\_7X<^BZ*I!(W?^TM#Q+
M.,]*I5)'K5;3A2S+=QW'&=O>WD:A4,#69AZGLH/8;S719K6A9-O(Q!6\7UM!
M;T)#?TS!W,Y.NOMX-V2[A'3=P?SX./;W;.M3RACR7&>HIZ<G7Z_7+\O$?HRJ
M@#:ALTX90T>K96%I)8?/RVM(RD1,UY&F6%R6H"LRF@T59KU"Y&.X,CJ"$U0L
MJ`=PZ5V(+.C-;@N2!;N[NQ1T?S^":Q>1^[:*\^=.HUKU2/X`5B(.DH_.)52\
M"LH$T-'9B1_[-IJ:T["HL*II2"83!`P&'Q$:!5*I5#@9I!4,8NTXM,8,Z)J`
M4`+D\YL8S/:'LN4WMQ"+QRBW"%GJQ,B%L]!4E2@%4(4"5L&C00A5L&T[V-O;
M`W?`+14*^W#+7MA#5Z83FJ:'9S6:%+[H."[,A$E%)3BN!Z]2086\6*0.TBER
M"RTM+:$+B4:.9YI=(2VY/?J%G3"P[U<@D\ZRK)"#SA('[Q,08XI)*@3%8WHS
M5.I`493PC.VW+#0UH>ZL*S-D-FP,U&B_2"AA?@A`)!B4]QQG)[YAGN#++(=-
M8^6Z3@@<=<*%(I"HPZ@8QSG&^6P1:\Z)\EF6>[&8,2J$<L;WDV%R=(&!HN1H
M/?R_D7'4D6$8O#X)/W\"ZZ4+71%8=#G:-Q9I-&87@3?:09&%/RX<V;]M/P%6
M'IYA15G6S`````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\R,2YP;F<`````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R,#4P`#$P-3$U-#,S-S8U`#`R-C0Q,P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M%P```!<(!@```.`JU*`````'=$E-10?4`0P-.P.?KD]`````!F)+1T0`_P#_
M`/^@O:>3````"7!(67,```L2```+$@'2W7[\```#M4E$051(B>V4RV]491R&
MG^\[Y\R<Z=POK<,P7#K3B`(B"QJA5A$,\<+*#2Y,C"O7^G^8Z-;$E0L71C>&
MBQH(!;Q!);4DB%IMZ+3T>N;6]LS,.><[WW%1(?X-A&?U+GYY\^2W>.$)CQ7B
M89B>OFF[V]WC0DC\(+SC#[:.C-8/^'8\,=]8F'MFT'<I5VKW"\5B8>;VC8P0
M`J*(8FDW@[Z+V^L"D"_LYL3$Y))IFG^;#\L[[;5R.J6O;FVY[-U[Z,M.LWFN
M[3QP=^\9FRIDO+/DP/.V?PC\9&U/.:I(*;!,@_7F*I81,K;/(B)B97V99M/Y
M!/A0/BQO-=<QC9"UY?NTV^USZ2&X>?.G9,_MG$W8'OFTQG$6)J5A5JY,W>/S
M+RYCQWWNWOV-P&LS-S?/IY^=Y_R%JRPM+KVC@F#BD?D+)TZ=65N^0S:7H]U:
MI3B:QG$Z;'8=VAL.81BBM(6[[7)B\C4>-.[Q8#UD^M=_.'SX$&8\1KWV-.E,
MB5*I.*RUSDB`0;__;J3YR-T.&*N/$>D>B42:;K>+L[["W/P:=_]8Q8S%F9V^
M@;>UP?BQ0WSU]77B]A"F:5,?W4NM5L;M;2&$N"0-8]942N6ZG=:;BXL+&;>O
MN';]-K=^_H7AXOO$9$0JE69B<A)OX)%(V/PU\PV52IY;T[^SLKC$2Q/'2"2R
M7+\VPW=7ICCP[!&44J>!@U)K?;S3W7Q[<?Y/"","9?!<O8J4-ME\B4QFF(L7
M+O/MQ<LH9:+C1?:,'J35ZG+RY1<IYY-H%;)_M,[I5TXQ/CY.W$[,``O"][S7
M&XN-2S].?4][8Y5&H\'^D016JL1\8YF1D3*-N5G&JB5D:A<K3H=JM4H0^`AI
MT''62*93#*7RJ$@2^#XG7WUC]?FC1]\RA1#$8C%2R2&"ED>M%*-:SN/U>U@C
M,2RC0^UHG4HI1VO3)1U)I+>"T@)?:8:38%L1W<XRRDRPJUHCE\MLJB#HFUIK
M>J[+5M>AD(J3*Y:Q3`,Q9!$5D@@$&E`:,JDDJ506A$`(0`A"#:$PJ402925Y
M:E^=8J%PT4XD9DW#-#<+A>)&J;Q_>'MM'@]%)`P,*8DB3>`/4"I`:PV`0&''
M#"Q#((5$"K#0*`R$]A`(I)3_W0*]7N_CIK/Q@;.ZA!JXZ#"`""(=$.D0`!WI
M1ULA!1A2(!`(PT!*$\.*8R6SE';M:V:SN?=B\?AY`:"4&O,]KQKX'BH,48%'
MI#5:1SL&.S.R\XK_(W8LI6%A62:F&2-NVSW+LF[QA,>/?P$7!*F'6&3[=```
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T
M8V]M+S(S>#(S+S(R+G!N9P``````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$W,3$`,3`U,34T,S,W-C4`
M,#(V-#$W`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4H`````=T24U%
M!]0!#`X+,A-PQ]`````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2
M`=+=?OP```-6241!5$B)[51=;R)E%'Z&F6&``::1*BT%AM1MPFZ[75,;W5@3
MHUTOUKU;C=?^A/T%)OX8;S0QQICHE2'67G3CWIBN@+$KU78H'0:H98;Y8L;S
MOEA,XS_8[$D(`^][GG/.\SQG@!?Q7(5P]7!Q<9$R#.-NN]W&SLX.NMTN^]O7
M-.U9O]^OI]/IOX?#X<`TS=KV]C9\WX<D20C#$.:Y.0>LU6I.<:GX^!IXUS`^
M^_G)DT^3R20FDPD$@1_9BXN+C<%@\,"Q;4.2Y6?9;/;M.(XY\'@\!A7%>:^'
M4FD%01A`EJ36[KU[-UFR=`7^1Z?S\>7E)0>E*:"J*G*YG'IP</!@8V,=AX>'
MI7*Y7&*`BJ+`MFUT.AU4JU48IZ<HK:S@UZ=/(4KB?(K$U0-+4C,J]O?W,!J-
MD$@(R.?S1(^!?$YCA3C@T=$1[YHUL;FY"<>Q$4Y#6):%Z72*^_<_^#^XKNL8
MVV-\^/`C^)Y+%R-.3Z52Y9.P;F.Z5WRY0%P*$$41]7H=J90"+:_AUJV;G)I6
MJW4=G$31W8F3[IL]'!]WL+Z^`==U>3=;6UOH6WT.IB1E>&,+2?HF;G%R<H*D
M+,.Q+]%L-K&_U\#R4C$=3:?Z'#R*HD?M5E-???4&>KUS:-H"F+!]TX1,R8RR
M(`@X;2EU@;I-$34RTP%J-@<EE<%RL8@[=VY3(5LGP1_]1PNIO[R\!'?BXKW=
M730:/V!`W9X1W[^U6S@[,\AN9Q@-^WC]S;<(]!>P*;NG?V$X&$"F2914&JLW
MZMC[L<'M.7>+D$B@0FK_^7L3WWSY$];T$@+?0:%6@&\=HU90$)%H&='!]U]]
MCM5JB6B*\-I:":$WA#L<X;NOOT`017CGW??GG$NSQF,:VX->7D+E%8V``L2D
M/',$449G(8D9\[6XNW6;\\_.V">.!;)CA3<H2`HJU?)U<$D4C6QNP;,459F0
MD)[/@!,(`Q^NYW'PJY"E!#DG"8FL*B9$7I(5]L,8D2`1YV/>T+4-)2&:`\NL
MCRP30_*YST$])@=E1[R8\._MF)*9MV<_9K0J2@HY,H*^NF:]5%C\A`SQ[1R<
M%N"-P/<SK%.;W,'>'2&M<\SJ1U.27N2+)<S<1:L>8E89W#ELR3*9-++9G"-*
MTF.\B.<O_@'9;99C?N6NW`````!)14Y$KD)@@@``````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T
M:&5R9&]T8V]M+S(S>#(S+S(S+G!N9P``````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$Q-#8`,3`U,34T
M,S,W-C4`,#(V-#(R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4H```
M``=T24U%!]0!#`T[*#,2M@`````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``
M"Q(```L2`=+=?OP```'S241!5$B)[9+)CA)1%(9_JAH(0S$V0S%);!-(H-N-
M07KKRL?0MW#E"_@6+GP`HXD+,9U(NA,W+@D+`B1@F"D(\^@Y)ZE.]QN8R-G<
MFUOG_N?[_UO`J4[U3Y3%W&RWV_/I='I6J53>]_O]:ZO5BN/QB,UF`[O=CMUN
M!YO-AO5Z#8O%`I_/AUJMAE`HA&@TBF:S*7V:YD&Q^/*3P^'X<&:*D]#/U6J5
M+9?+<+E<F,_G(MCM=F5?*!30Z7203"9Q=WL+/1:3/DW34"J5L%PN07#(YR]Q
M=75YPYK*0QLLPF1,G4JE0-.1R63@\7A`@T4L'`[CG&@;C0:\7B_J];J<^_U^
M`;BX>/J'[GU\)+[?[[%8+*0QD4C(RI04%W*YG%!QCZ(HR&:SB$0BXLR,28_I
M2*?31)[_Y70Z?S\2YVPGDXG8U*,Z#,.0(8/!`*JJWF?O=KMEY<'T-N*DU6I!
M550&^D+NWYJ:RN%P*-+%.\KL"9,ST6@\$O)>KR>7F78X',H0/N=(&((?DUU4
MJU6Y1T!?B=XPQ2UD]3D->#>;S5C@&5E]T6ZW$0@$)":R"/[&KG@?HX=D4A8F
M%P9E_FT\'K^B.+;T-F_B\?CW>W$\*!+.D*UK)J6!\NMQ<:Y\QL5OP.?\=Y"3
M43`8_$S$KZE_0T`_<*I3_6?U%TN*\1^R2?GJ`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(T+G!N9P``````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$Q,C4`
M,3`U,34T,S,W-C4`,#(V-#(P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````7````%P@&````
MX"K4H`````=T24U%!]0!#`T[.5FBEO(````&8DM'1`#_`/\`_Z"]IY,````)
M<$A9<P``"Q(```L2`=+=?OP```'B241!5$B)[5+)JE)Q'/X\'A5G<9X3#!04
M[^8BWFVK'J/>HE4OT%NTZ`&BH$5&D""T:2DN1`4-G`><QW[?'T[<^P9!?IO_
M]..;S@%NN.&?@,G8'(_'X'*YU!N-QMO1:/1@L5APO5YQ.!Q@L]EP.IU@M5JQ
MW^]A,IG@\_G0:K40"H40C4;1[7;5N\?C0:52^6"WV]_I!KD0_=CM=OE:K0:7
MTXG5>DU!#(=#K&5?+I<Q&`R03"91K]<1B\7@E#FWVXUJM8KM=@LQAV*QB%*I
M])V<VN,8)*$S75RGTVDX'`[D<CGE1H35.1P.(Q@,*J=>KQ?M=EN),`D-9+/9
MW^+Z_1/R\_F,S6:C!NF.:RJ54NX+A0(6BX6:T30-^7Q>B;`JHZ9X/(Y,)D/G
M/\7$KR?D[)8$C,G(L]E,B8S'8YC-9B7"[ETNEUHIS#>*]'H]-2.&/DGZUP:G
M=KE<*D)<E\Z>L18.3Z=31<*^>::SR60"7=?5/2NA"=;#%,UF$Y%(!//Y_+.X
MGQOD)HEZ)P)O5JL5"9Y+U/M^OP^_WZ]J8L]\8RKN&9].22Q"\TZG\T52OI`Z
MCO)M7B42B:]_R?$(0IP3]P_L5035KT6P5]X1K(?W_#NDBFD@$/@HCE_*_$$,
M?<,--_QG^`,_EO$=7&0H,P````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(U+G!N9P``````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#(P,S0`,3`U,34T,S,W-C4`,#(V-#(Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````7````
M%P@&````X"K4H`````=T24U%!]0!#`X`#ZCL4@H````&8DM'1`#_`/\`_Z"]
MIY,````)<$A9<P``"Q(```L2`=+=?OP```.I241!5$B)[91+3%QE%,=_<^=Q
M9^X,<X?R&)!Y`65XM$"%"2E%&Q%CM:EIXM*HL7%O5R[<N3!JHC&N3$P7)BYT
MT[2)QEA;`RLBJ9:*@X5"H<[08889F)?#,*\[UV^(+NS*M>$DYW[W?.?U/^=\
M.7!$1_1?R9#-9H.?KNQ<^FPEAU8W<%;.LVRPDRX9.6[2>?^TE_?"*::T')X3
MO;RSDL>^M\>5J4Z^WJY0V4VS9[&RF-=0ZS4N^^VIR^=&/CD,/CL[^\+GU;;O
MK\5UC*OK.'<BY,]?0(MN8W&W,7;_'EO#_1CF%E%G1ED.)S`_T<+(7HIT5SN9
M!UM4>OP<9$M(#AO>1*(\HR4_>/O5ISZ4TNDT!4E#3R49^/TJ_LP:%8%`F;LN
MSAQW(C'BI3R/!+JE0@WUYUN,W+_!ZB\_L97?(UNI43`;,-V^C7WQ)INMQ^1L
M\N#=1"(Q;6K`/R:^OE`08^`M]-_NTM6E(K_Y.G^6ZM22&]BLX^2=,F:K!=EE
MP]8=I'UWGGW%1-XB(=E,Z(([U3H&=Q/Q6PD6%O8Y#!X2BM):C.AW5[%H15YZ
M\0+AN\L\>S;$:J"'H38G]^K;^.P2OTK0/7228L')20OD9(TNNY$E@TY0;67$
M;N)AI4(^G\=4*I7PF*''*)SZW30IHA*SSN:#)8:?&R6M6ND7@_VC7&+<J5'V
M^!BI%-!L$AY9(FJ5&5;,*"<"^+M5MF)Q%)'0Z6Q!*A:+:#MB2.D$6K6,0S9C
MBS_"5"MCW(Y@JQ:1XU&T^`:6K55>N_@TQ]N:T5(QE$P"2R:&O+W.\V<&:)$5
M%JY=Q^TJTMO;BVEZ>II(),+I;C-)>Q?CX^-$HU&FGO3@40R,>27<QBHA?XU`
M<Q--U5UVX[OX]0W:#0%J<AJWH0UW+2E:FF'25V7TU"DF)B8P=79V4B@4T'6=
M@X,#&G+C!7F]7IJ;FU$4Y1#%VOHZ'H\'3=,.[QL`G$XG=5VTLSN`5^CFY^</
M_<],3MX4-F')8K',Y7*Y*YE,!K/9_*75:KU1K59QN]T$`H'-4"A$K5:C/QC$
MY_-]K*KJG5@L1E#(@X.##`[TT]O3LYE*I1!QF)F9*??U]?TH0,5,(GA9H/BF
M4JF\+(9;M-OM7PG4:9O-]HK+Y7I#)#DO*KK8VMJJ"MT/#H?CH?")"38*?;CQ
M*D357PB?2^+N7$='Q[<"X$?_V@-B#4PT5L'?_Z[]_?UG1$)'0Q:M&!()QOZQ
M%7*[X`X>(V$?%&Q]_/Z(_B?T%_0&DE6L-_9.`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO
M,C-X,C,O,C8N<&YG```````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C(Q,@`Q,#4Q-30S,S<V-0`P,C8T
M,C``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,
M#@`CFC0^Z0````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^
M_```!!=)1$%42(GM5$E/6U<8Y2=D4W55J;LNN^BBFW33-@IJU2[;31=1I2(K
M"6K:)D0D$0TE,34)F#`$@J7@,(2$4$R#L?$4!T_8&#_C><#P/#^,8^/A&<RD
MTP^K)9NJ2M,N<Z6G>^^[3^>>[YSSOKJZ-^-U1Z%8^M3C\0BBL9B`UF__+Z`[
M.SLGLMFL;''1FO1ZO3"9S`B'5Q7_"32=YL[[_/X=D]E2-1I-"(37H#>[H-3:
M(;XS@$AD;>2UP9<=S([+XT>:V\#FBQR":TG,JFS0/F<@GS>@I_>N7ZE4?O"O
M@0\/#ULTSXR';#P--I:`V>[%TWD+AA\\QN`]">Y+1]'2*L38^,.8;<GN#`1#
MSD0B>>J5P!/)Y,=/IF?W3$M>3,\:<4-X%]=_Z<*#D3',S2DANB7&F6\;<+;Q
M(E5B@4)MP)Q2O6>S.\[L[^^_][>@J52J4Z%43:C4NJ1:OXAY/8/VCB$,#(U`
MKE!CJU#`]O8V<EM%S*D,:/R^"0V"<^@?E&)R>AY3,CEBL9B=+GCK&)0V)^+Q
MQ/"RPWD86D_![6=K^HHZ)9B6_8[\5@'%,H]5=@.!2`J,)PIN,T]5F='6?@_?
M-33BJZ^_P?G&'TBJ<83"X7>/P8E1O<OE!C%')OL"P4B<RK5!HS.@4"R"KVPC
MF2F2]A%H%ER(K'-D<A&S\TL8&I9C=$*#-F$?/OO\2S1?N0:69<7D6WT-?)UE
MZUUN/\5M';-*`[IZQ]`NN@.'TX,$ET<\G8,ODH&)P*V.$))<#I:E,!Y-+6#%
M%T,TD87%'B0)NW'RY$<0B6[!X_%RI5+IDSJ>+[^_8#"%FJ^V4FD7<%/X*YPK
M;H364EAR1<!X6>B,;DC'-)#)K=`:O)B1F^$+LJB0!R6^@CB12*8YF,Q6C#Z<
MPH\7+\.^O(P:>S)*//%H$GJ##58FA$AT`T=I<7K7L)DOT3J$`<E38AP@D!PX
M+HLRSZ-0XA$FGPQ6'XJE,OE3@N:Y&Y>:V]#=W8._LGUIQ>6J^D)Q&&P^TII'
MB.7@"Z=@M`6)\6*-:2Y?1*52J8%ZZ5NYV@[IN`KW1U5PN%BHGCDQ*3/@IZ;K
M:&JZC&-C-S*9`!N-8Y681!.;Q#98DT$B56)FSE*[<(MBR)?+2&WDH=0QZ!N<
M@;AW"A.DOU++U.12Z6PX>^X";MP4O@0O%`I?D!%[OTW/H']`@IZ^(73<[D%K
M6P=:?A9B6#J.@4$)S:-X_&0&G>(^='4/TCQ$/UHGA:`3W3W]$'7<QI6KUZ#5
MZEZ"'PW*\VDNDY&MK+AD%,_P42>TV^U@&`8.A\-RM/<'`O#Y?+!:K?2.@5ZO
MAT*A@,UF2SN=3AF=R2B.LFJU*ONG'O,A/8*]O:K@X.!`0.MW_IQK^]W=73K;
M$_`\+Z"J!=2>3[]2?WDS_@"EY9'"QOVJ10````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\R-RYP;F<`````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R-#,P`#$P-3$U-#,S-S8U`#`R-C0R,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````%P``
M`!<(!@```.`JU*`````'=$E-10?4`0P.`00F);K#````!F)+1T0`_P#_`/^@
MO:>3````"7!(67,```L2```+$@'2W7[\```$I4E$051(Q\V527,;512%LV#!
M-EM8X+^0+5O^!RL65(H%&RBR@H(B184D<N(8B(GCQ$:)+%N6+%F6;,UR:[!D
MM6;UJ*E;\V1;DFU9T^&UBHT34I`*"[KJ]>OQN_>>>UZ]:]?^#P<PO4V&2IG?
M%?0^IN,Y,LS3<9^9#(^9\?!D,AX>8T+FZ>B4P71(QN@&^?;Z6\+'=Z;C'@:]
M`D[J$30D+RH%#RIY#^KD^J061K_#8'+9(>R1E9P^^+=9WU*R.VE$49=]D+)>
M\!D[1,:!+..$3.XK11\*K`/EG`^#OJ0$</XS>#K^3`$W9`IRSHNBZ$:>=Q&P
M'7S2BI!+C73(`)8V@8D8D3S4@:/UZ+4YD&J=;ZR`:'A].CRV*AE+@@<%WHV"
MX$:)!,D1>)@R@`[:X-W78'?U.T3<:R3(#I(D6.90B]%%E;#'G[])9[.B<9%W
M0DC9(&8<2-!V)*(NQ&@?6%Y$,,+`X?9#O?`-W'H5,J2"=,2$@&T%$N<A[`OY
M;[.?CL\9I7EYSD%^,"-RN`]!%'':[:)_?HX$D\>6Z0`V%PW3SBZ<YF=(A?1(
M!'4(VI;A-\YCT%7T'\Z]!E?LIKA"2%EQ1&WA*$*C5&NA6*HCFLK!ZJ012XFH
MMSI(L0+T&RN@]I\CX%J?]6)?_3U:I00PN9A[U2$?C0:=0D&1)&%%P+V!7<L^
MPC$.)FL8.J,/>\Y#9#A%&A9[KA@,9A^VS2[$,UDXG"Z8U'<@"T&EL4>OPE67
MYRV2P1^@[!K8K5MP'X2P:7#C]Q4#]FP4HO$D/%X**ZMZW)U?A5KK`BN4(%7;
M",=SV#::P68BF$Y&S&N9][OU0C@41#+#X2"8P(;!":?+AT@LC5*YBE:KA6J]
MCA"=QOV'S[&^L8VB)!.9VH@D"7PW"%\@C,O+BZOPL[.S&]E<H=SMG^&XVT<L
MD8'+&T"I4D&CV4**E^$/LPA%.92K=1+X``\6M;BG>@R-U@`A)\.P&X!YSX?C
MD].K\&ZWJ^*$`BKU-JC##%YJ=TA6)=0)6*HT$4G)<%))%*0RQ'P)&IT7%OL1
MT=V/7Y<T6%/K<4B+2+)Y\(+P"KS7_4JKW1Q\?>M;W/SB2[@]7K!B"8P@(13+
MP>Y-$AA-`#Q,EO#,CDH%E5H#:0)\M/@8RT_7\,.//R,0"%R%CX;#3P+!8,.X
M8X&'"I%&%>#V)T@`B3B&QY/G%NAW?#B*\@B&&=3J3;0['5*%##Y'*FPTD23K
MX-[\;Z!I^BJ\U^NIHK$8T34-7RB%@EQ!/)U#7JK"1>30&0]F&;;:K5D/<L4*
MT9^'5N^%FXJ#$V7L.:*X_=,"'`['5?A@,%!Q'`]>+"*;+X//EF;:;YG(4M<Z
MD2^6T22N:!+'2.7&S/N+2]M8^$5/O@E`L^4AST*X<_<1*,I_%3Z93#[N=#I5
MCA=F7M[<,F+YF0;S"ZODAT5LZO0PF79@-IM@<SA)$]?(NS6HB"67GJB)]]?Q
M8ET']8N72*72-U];_L/A\$.>Y^?:[?;36JW.R++,B-D\PW$,4ZWD3ZOE/&J5
M'&1)G+!,FDDD4XS?'V18EF,:S6;\P<.%.8O%,A>/1]][VVWOT[_VSW??0_^K
MXT^TJJ_'_D_#20````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M
M+S(S>#(S+S(X+G!N9P``````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,Q,#,`,3`U,34T,S,W-C4`,#(V
M-#(R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!
M#`X!%#N2JJ<````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=
M?OP```70241!5$C'K55K3--7',6X+,XE+IFO96X+R3YLF=O<3+81=0_=S#!;
MXF,1T$T<ZK`3H@@B#(R!30'!\BA0Y"WR!L>CT!=("[:45RFTA9:6`GU`2TM+
M>0D%BF>7)O/#<(G+O,D_]\O_=^ZYY_Q^][BY/>.:LNL"#`8M#`:]A]OS7C83
MUU[/R$99><7_!P<<P;9)L])JG:!AQ>QN55&FR[)\H1J0]V%EU-WAF*)9+&;E
M\O)R\-\U3J=S,_EVK`%S.A>\!P:Z*2-:+<4^95__V&F*5?6DHX%3A*5'0DR)
M/T5)_/OH$B;AL>,!AI59J*LMA<.Q$+NR/+'>9M513"93R^+B(G4-^/+BV`F=
MZBY8M6G0:H<9<!K4=KD7BFE[H11X8ZIA$XJC7D5QRAY,2K\!(_-#\-@W@!6C
MVC'=S&AIRD"KJ!5ZO<Y]#;C#7KMNWIP8:.OY&L6I!R&L]X>F\1/0`S<AQ&<+
M?`]MQO<'WH&OUWY<H^S&5=]M4/`\L:#QAKQN)Q(3HB<Z.SN.C8T9UCU5Y\<K
M<Y1%<PXFV2^!'K0-4>=>1^B1C;AV<CMBPXZ!RRJ'4J5&34T%0G[>!7[::Q@L
M>1%)D;L@ES6K`>=G3S'/&6JU*'N&U&V&&7,^U,QW$7UF.W[SWX/:DA3P&ZL@
MD72A6Z9&98T`?S):D'@S%#?.;$5V^!9PB[[$XG0IYF9&#7-S,]7_!#\Y9ZFJ
M5/(.H>G.6\BY]@8*;^Y"9P<?XNYN%!85(2T]`_'49-#2<R%LDZ%_0(N<V[^@
M-&(K1-EO@Y'M@=+\"'*#7N4:]BL.F?O25`D,#_>A.FH3.!D_("X^'M3$1#!9
M+/3V2L%D-R`Y)16Y>;GH%,M0<B\=ETZ\AZMG=^/RN:^01KV*(8WR]!-0^T2'
M1Z_PHH=:1#EJT\1!5+@7[.LOX^:5[\#B-D&NT,`T;H'9,@$CV:5]:MQ.SL;%
MH'#$Q-.1GED$OD`"*?F/?B<'2<G)TQP..U^CT7BX6<=YD#:?AK1F)ZIB7L'Y
M8SL0>&H?&-6E,)K&":@5<I4![=T#Z)"H,#HV#F9#)Z@I90@-CT5H6!38#<W0
MCIHA;.]!5DX>8F+^@$JE@IMYM,Y#(?3?SZE.T*<E1B+C3C8*[A5@?-P,J]7F
M*NJ4#H,GD&%$;X1AS(R:^C945`O(+D)*6@%NW4J`4CV"!KX$M4PA,K-R(&QM
MC71)0QZCI+BX6R@L*2-ZYJ-'IL#@B`D#0V,0RT;0+%*@2=`'F5(+#J\'576M
MT`P;7'(-#!I07E&%F+@XI-%SD9Q6@B3:70@$0JR^!Q]TB;OZDVFI$+2V0=[7
M#YEB""+Q`.0$C"^4(Z^P@;2?""UM"K`;NS`X9(#59G-)IAL=AW[4Z*IC<IH1
M>?T&&$P^&IMX<+--VCPY7`XQI0M-+5+"3@<9,4W<J\:8R4)T[$=!<0,D4C4F
MK%:8S1878YW!A/:N?G!Y$@)N@FI0CWIN%X)#PLCM[Z&/'$8D&?7D\_E0J(8@
M[%`2$RU0:0P$?)`<)D-UG8CHJ75UB\W%=H*8JT1Y53,R\Q@H+&U"([\'%54"
ML!](<-S+&[34]%42Y6X+"XZ#/;U2)XO-1J]<@3[24@_;%;A/)C$KCXG\0C89
M^1$,:_6K0>$RM8[3CI3T^TBD51*YA,1(,>D8(>J8C?#Q\49M;>TJ$4^7H4M+
MBV>;>(VSEX/\<>%7/T1$1"(L+!1!%P[C^-$O$'KI"$+.?PY_GX\0?-$/(8&'
M$13P(ZY<"49```6!`6=QZB<O^/F=`IU.A]%HU!`O/WXR3+,S4]Z,FDI*5G8.
MA<5B47LE0E04A",OFPJ%O!KB^F^1&O8F:`D!$#7349(7AKC8:'"Y7+`Y;"JC
MIB)#WM<'G4X728#W_&L*D9ML6%EQ1)M,>J79;'0ET;R1.EU./X`VT</I^=E^
M=^N$CJ94:9@DC=Q)N&P@-1M)*KD3X!?^<^PMS;;;N36_@XRU_;D']/PC2X!.
M.[BJ9\"SUOP%ROJOY-O;JI@`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R
M,R\R.2YP;F<``````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,3<W`#$P-3$U-#,S-S8U`#`R-C0S-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P.`2;S
M1?LG````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```$
M#$E$051(Q[V5.6^=51"&GSGG?,OY?#<O%SMVY"4$"R$B\@.H0XUD*!`E$D4J
M&B00582@2$.+1(405?@!X1=0`&F00BSAQ#:Y<;Q=W\W?_;9S*!P[()8$H3#5
M*8X>S<P[\PX\PY"G_>B]^P2P0"JB/OQ/<.?*2?'ELA?Y6GP!WJ\""G"(K'L,
MHLR&][RME.D^-=S[ZAU<OH8?O^;+$44^P'F'1R$XM-)H8U%!'22ZB40W1)DO
MG@CWWGV`&W^,&ZDBW64X[#/.2ZJJPCF/T4(4Q8AWV"3!UF9!-QS*?B2B/OU;
M^$G&V><NWU/#_D,&HQ3G%=EX#!Z<<R@E1'%$,<[)BY)6(V)F;AD3SSI4_*Z(
M/JO`_+['N'S-ESVUT[G+WL&0K'"@-$H4KJH8#7H$VB`XE`ZHO&=OO\MA=\C*
MJE*A;:\Y5WYSJH$\`M>KLK@QZ.]=N;]YFZWM'?+JI/SFY`RU6I,@"%!*H;5F
MT.^1CC.\!R@YW-EBLE7CPNHEGCNW\JW6>DTI,SC-_-KAX?Z5.[=_HG=T0!#7
MF;8)UEJ2Q!*&!A.$1%&,#F)B.\'Q:$A1%GCG$1%Z>[^R\<LZ:>ZOS,TM7`/>
M.X5_J<2_Z5T^CU)$44P8!$2!X(J4H]XN46S)[`0FK"'*X+W'.T_E*HPQ5!X&
M_3YFMT-MH@:/YI:JJMZHG)M3ZD1?K12138B2!CJ(R<<9PT$?5Y:D@T.*<9\\
M'U.4Q8D6PP'W-^[@JXR5E>>9G&H_AH]&Q_;!@X=J.$P1!*4U(A`80V`4L8VQ
M-B:9:*"U0BN(HQ!<15ED:*4P48(23Q('A&'XAVGY;&GQW.O#;F=I>VN;LB@8
MIRWR;(Q2"B<QB&)[ZQ[][CY)O8D.8BHON*IDG`Z)8\/"^5FLM0Y(S^"MUN2F
M*P?IZL4%LOXN1P<=2ETP+`?@/;B*X=$!!P\[E&5!HS%-E$R0-)LTVFWJ-J3=
M.,_R\B(F"-=/O>=LSE$A4^U9%N<:J%Z'V/68B#3[G4V.!WV,:*:"G-QGS$W'
M--K3F+A.8W::]#C#5QDVJ>/E,?+L)=Z_9<+&C[-+B_S\PW<\Z&QB:W7R+*-_
MU*59;[+TXLM,3,X0V9@BRPEMS'@T!&69FVMBHA:(V3C+]VSUQ=Q#XIN-F8LL
M7;I$7I7T>T>,TF,\X$4P880([&_>Q5<EB."<IY$(]<D%4`G>R]4_P94R751X
M`UUWJZ^\R@N7+^-%"$4AH@B3":JR(K8)\ZLOT9R=1>&IV9"I]CQBF@X)KHO(
MSI-=L1JH^W=OL7[K>^(@)K`U;',:K4`;39PD-&>FJ;?F$=-ZLBO^E9\7Z0''
M_2Y9FIY4J#5Q8HEKK4<]3D"9ZR+F_7]WB82OO*\N_/,EDJLBLB.BQO_K#7VF
M\1O]9^:]9@A8)P````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S,N<&YG````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S
M,#``,3`U,34T,S,W-C4`,#(V,S,Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````7````%P@&
M````X"K4H`````=T24U%!]0!#`X%*^F80IX````&8DM'1`#_`/\`_Z"]IY,`
M```)<$A9<P``"Q(```L2`=+=?OP```1-241!5$C'U=7+;QMU$`?P[^YOU[N;
MV''L9+.I[83$*>XC04D1I:BJJD:JX%#4(B&!JJH<X(AZH(5_@!L24D^4`T)P
M0U2%`U++(T0*%5+35FJ<M+2-&SN)';_M>-\O>VU.'$KC%HD+_*XC?32:^<T,
M\']]U-."R>5D)!`(G7":K?/E:@TLQ\*S+8"BX&-94(2!P/L@#4GP,>1&J5SZ
M>"`<WI(DJ?54O%PN'WJ86KO2ZM"QOOX@>@0!#$-`=8!VIPV:)K`=&X[CHE@L
M097K>&XDBKV)Q/NB*%X"`*8;?F=IZ8W>X$`LP/-@"0'+T*`)`4L(--V`HLJX
M??,&+-/`=D-!J]5&J]G"1#Q^#D!W/)U.'[U[[^&';55%.!0$*`)-MP!TP#(,
M&ML-%$L%I%93V+<W@>BPV*8)<ST^/@:!Y[)_.3OB7W[U-2U*$28:C:&XE4=D
M=!2:ID,0./`<!]NQH<H:8K%=.'/Z[05!$*X*@O#IWQUZ)_S4R5.?-1HR",O`
M:7>0+Y11K%11*E203F=@F"8V<ENP+`N>YRWN!'?%US<VXKFM`AJR`EG6D%E?
M1ZC/#[?E(ILOX?;M9:165^&Z+1!"NOZV)\IB6=:%T^^\RXI2!+;MP-!-V*Z+
MU50:-$7!=&S(B@H*%&K5;7B>UQ5_(O-O+W]_)!26B"0-PS!,5*IU5"MUF(8)
MFJ)0S)>A-+9!$1]JVW5<O?9C5->UOG^$+]Y:PH`HHE:MX]&C#"B:PNAH%#Z6
M!:%I!/P]Z``(!OM`$0[+*_?.+BQ<?_&9^-S\O"^366-3#^[#M"VTVQ[V[=F-
M9M/%QF8.Z]D<",-`'!+!\3SZ^T/(%JM86OGCXMS\?&]7W+*L7M=M7N)Y]H1M
M.]!5%8:FX?Z#5223*R@5LC!-$U[;0ZO9!$,H#$E#$'IZ\/,O<S-;A=*"YWF[
M=VPHPS`B.GBOT5!0J53@XSCT]OJAR-LH%O+@>`Z:IH%A&3BV!9HF`$6#9AA0
M%(VEY,I+^_<\?QS`VA.+R_,\LKF9NS#WZ\(GOS4:Z&RN(Q8<A#D4AK]11[.=
M@RC>Q(.D!F/X+*(,C7!?&#4?BZ!<6]LS/J[/SAY3(Y'(6X20\F.9$T(\73?5
MZ0,S8$I%3!Q^!<5V!Y$>'EHU#3'T!6)#97Q>EA"8F,#L]`RRA@'6,A=WCQP]
M,SDYE>E:<]MVAC/KN0]^K\N(#0[`]("DJL-2:ACLNPQ=,7!G)82),0=AM%&4
M32PI.BQ#7]@)?@Q?O)7D5[+Y1+Y>@\AS4-PF^&H>:NT;!(2?\,.UE]&DCV-Y
M+8*!_A"JM@&QY2BS1P[??^:$]OO]:/E\F`T*&!L;/2>K=U]7W>NO3>S_#O,W
M1G#PT)OP^&',')2MJ1<FSV\6RR!T;TV2I"O/Q$=&=VWY56V<HCIHNNZFH2F^
MZ2GC6+XPRXF#)POQ^-2K#L48@6B\G4@DLO_Z!LIRXZ/T6NIBK58[\)\[T'\"
MT;3]$X8W@O0`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X
M,C,O,S`N<&YG```````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C<U,``Q,#4Q-30S,S<V-0`P,C8T,C(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#@(0
M%](]?0````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```
M!75)1$%42,>ME6M,DV<4Q_$6`O&:N<1YF74Q2W3[X'0ZS/33LCF_$)ENR\PR
MYX=E+))M,9O)!M/%&Q.1"LA%6["`E`)"+2VT6NZM%"BT4%IZA=(K??OV0JG2
MT@O_O9",9(,E+O-)3I[DR?/\SGE._N><A(077%-^ZSF;S0*[S9J2\++7E%OD
M%_`8J.6P_S\<")_W>EU:TDT4($[0`F,9`4[):>BT*C7B=MIL.%#@)@EM+!8[
M_]>;>#S^"F7;EL!BT9G/=:/R](F)\73_E'_57,R9K5,40BQB(?)<BN>*?6#G
M[(5<>@MSX0Y8]&40--4B&HUDQZ/$*I]W(MU%D%V12/36$G@D//F%65>%)FXI
M+!9S$V(V0T!]"C7T@S!(3F&J=1/8ES9"4)Z"J.D8!,QWT2Z\!L2=AI!?V-0I
MO@.)5`JKS4E;`G_N$ZT(.2YG>.1'P2D\C@'A=S"W'431CQMP\<O-N/+U)OR0
MM@F_?+L?XOR]N)ZQ'6KQAWBF3X.*_S;H>==)N;S_$[O#N>)?\AQ*CQ+E"`@2
M<??\9N1GO(:V2\D8N;$&BH*MD#`^AD)2B[X>,:I9V6AG[H>)G01ZUB&,J#H-
M0/2]9:#1G]TNK7+<V&L+$I48:WX+E3^MQWCA:@2K5Z+O[CZH^EM@U*M!$&[*
M2(R9K>!45R(G\P0>E7^$T%0=@M,.6S`8Y/X3?MKKJ*\W2-+PE+D3%5D[X&*L
M1J1A)099!S`LJP-)DK`["<B'3.CI'Z7@=O0.ZI%?U(A">@YJRLZ"4Y$)]<BP
M=JE:PAI:Q,^!6WH4PM_78ZXV`1Y.(KH:LS#I(D"X/3"9G118!Z7*A$G"`U&;
M`@T\*1ZW*W"/48':FC(J"'>`DN-7"U`OT9>BE'Z?,B;])LUON@8E]P@T>6LA
MH;^)9L8)J%5RC!JL&-%:\+1?#UY+'[IEHVCK4H'7+%OX`4EZ8+;8(1`(T-S<
M3*E&QM%H-"D)WLE6C$C/PBC<"P\_"9S?UJ'EQC[(NOD8&AJ&8F0,DMY1C$],
M+D18RA1`KC1@0*FCSASP^7RP.0AHJ0#<;I+ZG1U5[$?H[^]'@M?!31F5GDSQ
MV01JYT@FQ(P#>%)W'=T]*B@I\/QEM=:,4;T%S4\&T"$9!E4L\'@\%-2%P6$3
M^*(^</E/%QRT=0VCJ*0<HL=B+.8\&C:<F7$5PB@ZA`Y>-HP&'2PV)Y6."8@[
ME6!5B_&D?1!NT@N2`L];CUP/)DN(@N)&U'$EE`,9N`(9[E=4HZNS`XMJ\3BX
M4X.//T,G^PBZR@[#Q#L#2>,E"-D745EZ&7=RLU!9?`&M/#K$#Z]")F:BAD5'
MR9U;*"DN!;,D&\5%M_&P@0<NEP>%0I&[J/-@@%!.^<9L(7\%)GB[T'9E`R7'
M9$Q7)R+`20))F9M2SS0W"3XVM5>MQ5#!!C3D[D9'_7$8U950*KIL>H.1+Q2V
M;-%HU(E_D^-<C$B/V2]@HGX]F)D[H&3L!GE_(WSE:Q!ZL`+A!PF89JV"F[D.
MSJIM\/$2(2E>"T9>*D+/3,M7Z$+T<].OQ_P->F-K"JH*3V*H^P("`X?1GK\%
MG3DT6-AOH#5O)U2ENV"O?16\FY3C@0_@[]V#^MOO0"CDD3,S,ZG+PN.Q@-:D
MO@<>]RXE*6*Q*U;F'H2F\U-$NK="G+<.53?W8U;]/LJN[L'H$`O1L-;@->>3
M#6PZI%))"=6NDY?MYWJ=/-WE<J3/SLXNZ>>QL50\S-L.?L.OF'O.1V_''V@5
M"VSSJ8C%(JGC)D7)O#Q#X1#MA2:1B[!K7:[)A4D4(8L#]?>.H;>W.X#8.(TD
MK04ZX_ABDZ("2HY&HS2J]%?_Y[$W&^SSBWA78#09_2]]0(=#Y#FKU02'PWGN
M1=_\">4#?/OB][B+`````$E%3D2N0F""````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\S,2YP;F<`````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R
M,3(T`#$P-3$U-#,S-S8U`#`R-C0Q-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````%P```!<(
M!@```.`JU*`````'=$E-10?4`0P.`B+?!6S]````!F)+1T0`_P#_`/^@O:>3
M````"7!(67,```L2```+$@'2W7[\```#X4E$051(Q\65O6Z<112&GS,SW__^
M>..-8TQD80LMB2(BT7`+O@%*2KKT2"!$A:"(*"EH420:;H!K0`*$(B1,",9)
M[-AK>^/]=O?;[V=F*+R)B0(D`B%./7HT\\XYSX'_L.1%#WIO/P82H!#1[_\K
MN'=E#]0M?+F)K\#;`:``A\@V$H.$=T%N(.JAB)Z_$-R[^AW<["W<=,O7(^IZ
MBG-NP?88I=!!B@1+H+L@T4U1P;O/A7MOW\/F']$<J6IV2#ZK*&N/<^"<QV@A
M#`.4;T@30YRM0'#1H3L?B.A/_A)^=N/IYVZ^JR;YB'PN>*\IB@+!XZQ%*2&.
M(LJJHJEKNBU-?^4E3+KNT*U/07WX.")Y*F,W_Y)FN)6/=LD+1=T`(B@1JOF,
MX=X#PCA%JH(@:X,.\,ZRW`M96W\-PC60:$-4L,,BQ$6I6[C95E4,.<D]=>T`
MAU)@`D,]GV.]PP2&X<$]CN[?06F-"6/V]T;D)_?`G@+^L\=$<YY)M>GK$V:S
MDK)L,$H00(E@RX(PBGCY\CI:*[B\P7PZ`=?@$*RU[-SYA:OM/B;K;OX)O,8U
M!77C$>]PC4,IC:U*1GOW,6E&$$8H\0110A`G6.<0.7O9R7"/8C*BG9QWI#H?
M$#NH&D=5>VQC,<801B'CXR-VMF^SO_,S35DR&^=X/-X[ZK*@*DN\,M1.,YU,
M`3]8#-R3S!.\4]6\Y/31*0J/M1:\Q345)@A0(H1QS'PZP585V@3410[>$P0A
M)DYIK`6\6DSRDU@*1+FFKM3T>$@4I[1[/9RMR99ZO'+E.E&2<K2_R^'=;=;6
M7\66'90.2-L=1(=$<8K1&A`'%$]N?N8*M9TD$:$6\L-]BGQ,739HI6BU.^3#
M`QYN_\@L/^7HP2[CX0%!$)-TNBBE2+*45J<+R/9C]YQ_J(1$:8<L"SFZG_/H
M8)]6M\OQWCVF^2E*%%IIDCBCO;)*MW\)'48+(4"2)L1I&U3,L]TBX5T=]:]<
MNKS*[6^^Y?#!#DF[2U7-R4<CVITNZX/7:5U8)DH2ZJHF3!+FDQE*:U8O=3%Q
M?R&S/W3+6;FW4=G7[?X&&]<&%(UE?#IB.IWA/(@H3!0CHCC^[5>\:P#!.4<6
M6UI+:V<20VX\`Q<5C5#I5P0K[LH;;S*X?@UT@#$1*$V09+BZ)DI35@=7Z5Y<
M`1&R!);[?21<<4AT$U$/GV_%^E#M[]SFI^]_(#(I0=(FZ2VCM6"T)TXBEBZT
MR9;6SL"Z^_=6?-;GDZUJ=D@Q'E$6,SP:K35Q&A*W>IAH&<S2B_O\Z4TDM_#5
M)GX.W@\6`P)BQDBX]X\VT7-V*,!W(OH+_L_Z'<\-TN/H.\'F`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S
M>#(S+S,R+G!N9P``````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(T-34`,3`U,34T,S,W-C4`,#(V-#(V
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`X"
M-5S6Z3H````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP`
M``2Z241!5$C'K55M;%-E%&[9)',(AA4RG(84G&!B8I00UD#X@2:"_B#`+S61
MJ8FXA!@3`V80DRV(#C_PHT,G(!O$(7.X=>W&!EOM/FB[LJU=U][UXW;=VGO[
MN:[MNJW=VE$?W]L5U+1$3':3)V_;O/<YI\]YSCD\WD,^;I==1`#NY"WWT]OY
MF8@`W+DLA'Z?2Q(*>L1(>H5!KYI227<CX.ZEN.\+"U%Q<,IKCL?C']V[GTPF
M!01/9A#YO*[5M$5;QC*VLD@DD@,LE@P/-K'4P->(1WO@MU6!E@G`CE;@SX02
MX];?H514(Y%8J$HD$CDD4-FDW]5+/I_-()^>#@EILQ(#W9^`=>IE2'IH/W,1
MNN:GX=?NA_GF3DQ*<D&U;</TV&%8Y=N@5QX#=V]V-B33*K^%::05'K=3F$$^
M-S?+]WJ80_K;)P.66UMA4[\!I^I5G#]>@*IWU^+3MP2H?#T?XB,%:*A\"GT_
MK@:KW@N6*H?IUDLP_G$@,#S4=8@HP,^J,2=%<-)`4VW/P_CS2E2\O0$_''D,
MJE.Y"%WB(WZ5AT@='[HO5J+EQ!HHSFV%_=KCF&@1@!YMH;GWLUO-[9`X["HV
M&OH-YJZ7<>+-`M1_D(?H+WQ`0N+>^`>D/,Q?Y6/HS"K(OQ)@1";"?*09T3F&
MG9D)2S+()^Q&L49^''<:-^-"^5+&*>)60B8GZ"-0I2%?"A*_QH?Q7"',C<_!
MT%Z";ME[L%HTY@SR1)P5S@8[X-#L0]4[:U-2I#*6IPF'"0P$>H)^`@4O%9C]
M*0\]XB<PVKX=/L<51*;=I?=)B7U$FIYJD5%U[*#7=@94QRZ<(L7C-$Y)T)<F
MMI%@CORE4Y\.V,XC_VX%3)>*8>_<F;)KP*VDN$8CEA;Q/.YQW.X\#95T#TR2
M]7`VDD(25W#%2Y&KTMF.YP&>#4L!#.G?.SEI>+ASMA#3TAS04@%4S;O1W5$!
MQD&#QS(64?>-XR(?HZ"X!AEJVH[3AP4I5_PK<SHG:^:Q^A4PUQ:#:GTQU6`^
MIX)2W#@I<DY8_QX3\7BD-.QK`BW?A8O'UJ7LEJ&Y/GW>*RIQ3?#RH[#6;P+3
MOP^QZ2XD%SV93<0R)K.RXRBTTA<@K]F"FY4%F/\/M]QMX&.JO@C&>B&&&C=A
ML+L<C-,LSM+^04DD;&<79II)BY>@Y?0Z:(F/X[]F\;EDB3A8NPKFNHWP:O:"
MZP^;Y3;K8L<E#^Q09J*;'I,58>SJ&O2??Q:&ZD*P-7DI5W!%YC3FI.`RIJ\4
MPWW]$9+,#LS-V!_<H602\L?HD4,&16G`V+$#CN$/$:$.8+"V$%3=)EAJGX&&
MN,)XH1CC#5N@NUP$WYW78%+LQT371NC5XL#"?&Q_5O)@<(I,Q1X,]'Z.23^3
MGHH7H&M:FHI>Y1[X)2LQW+`5/MU!&&6;X;14X^XB2^L&KLLT\H^A&VBM"8="
M^5G6&$/F^7"9S^LLB\5B]^?Y2/^7B,_U(,Q^#T?;>M#J][$8Z\/HX#=0]UQD
MN7MC-BIGW&ZH"4YY$(M&A0^UB;CB!"9=J4UD&OKNH+;]%3#6E@B2?F$@X!;;
MQXSWBT>61#Z!D"#W?Z\\O58B4BNJX',;PLN^H$,AO\C%TO#[G$<?]IV_`,`2
M&#[\GX0E`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,S,N<&YG````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,C$R-``Q,#4Q-30S,S<V-0`P,C8T,C``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!<````7
M"`8```#@*M2@````!W1)344'U`$,#@,):J*D_`````9B2T=$`/\`_P#_H+VG
MDP````EP2%ES```+$@``"Q(!TMU^_````^%)1$%42,?%E<EN7440AK_J[M-G
M\AT<W\3A*@FRA6X2,4AL>`6_`$N6[+)'`B%6"!812Q9L4:1L>`%>@H"($'(&
M[#CQ$,]W/GW.Z6;AZY@H0"(0HM:EKTM___47_(<EK]H80OT%D`(3$?W)OX('
M7\R#ND4HE@D.0MT#%.`16442$/L0Y`:BMD7T])7@P9<?XL?OXT<KH3RB+$=X
M7Q/0"#5::4R4(U$+=`LDOBDJ^NBE\!#JCZF'GU/M*3?>83!VN-)3>_!>H74@
MMA$J5*2I(<TO0'3>HYN?BN@O_Q(^F_@;/WVDAH-]AE.%#XK)9(*(X.L:$2%)
M+%7A<&5)*U=T+G8QZ16/GOL*U&>G$LES&OOI;:J]E<'A.H.)HO0G+8)03<?L
M;C[&)#GB)MB\@6A#[3V=>4OWRE6P79!X252TQNR#9J5NX<<K;O*4@T'`50&\
M1PG82'#%E#H$HLBPM[/!WN/[B-:8.&%K\XC!P0;4QT#X^I1HSC1QRZ$\9#R>
M4A051@D@*!'*:86U,=U+5U!:$2XO48R'$#RA\M1UQ=J]!UQO=#!Y:_E/X"6^
M&N,JD!#P58TH15UZ#IX\)LHR(FLA@(TS(IL0ZOH$8BT'3S>9#`]II&>.5&<+
M4O=<Y:G*0%V5:&.($TM_;Y?U^S^SM7:/LBB8C@:$X(&`*R:4KB"(IO2:T7`$
MA-YLX9YIGA*\<M."XZ,^2L#[&KRGJAQ&6Y0(<9)0C$9X=_)X.1X00B"*(J(D
MHZIJ(*C9)C^398(H7Y5.C?=WB>*$N7/GJ*N*9JM-=.TMXB1G?VN#G0>K=%]_
M@ZALHDQ$VFB!CK!)CHDB0#PP>3;Y25;HU32-,48QV-UF.NA3.8?2FKE&B^'>
M#MOW?F$ZZK/[9)W^SC;6).3-)EHITCQEKM$`9/4T>\X^5"+BK$6>&?8V!ASN
M;-%HM=G??,2P?TRD#4I%Q#:E=>$UFIU%C(U/W4"69219`U3"BVX1^U#'"]<6
M+UWD[IT?V'ZR3M9H4KHI_<,#FLTVEWMOTYA?(,E2G"N)TQ0W&J&UYOQB$Y-T
M9F'V![><E/\`E7_?Z"RQ=/4J154Q/#YD-![C?0#1V"1%:<W^^F\$7Q$0:@]9
MXIEK=T]"#+GQ`EQ4?(C*OB-:]-?>?8_>.V\21&&U1AF#S3)\Y;!IRL7>=5KG
M%T$@3VH6%CJ(O>"1^":BME^>BN6.VEJ[RZ\__D1L<FS6(&TOH+5":T^:)K3/
MS9&WNR=@W?K[5'PQSX<K;OR42?\(-QD1Q*"4(LDLR=P\)EX`TW[U/'_^$LDM
M@ELF3"&$WFQ!0$P?L9O_Z!*]Y(8"W!'1W_)_UN^:0M;74-[QB`````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R
M,W@R,R\S-"YP;F<``````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-C8S`#$P-3$U-#,S-S8U`#`R-C0S
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P.
M`QN9&]6T````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\
M```%0$E$051(QZV5:VQ391C'BT-1(D8C&(W(*D82/OF!!*?A`\9$)CC$$6/\
MXB51F2'$C#"\0,*XN"T,!<H(H)ML0UR8&=VEFX-MI5MWZ;IV:W>ZGO6<;=VY
M]/3TWL/6K>U6_KYE@I+Q`1-.\L_SGI/W_,YSGO=]_X]*]8"71QS/(D(ZJA[V
M=:.U.(L(Z?A0@#Y9T(9#D@8I61WT]CFZZS<CX.ER("6IX_&8)A3TTHE$8N^=
M^:E4ZEFB%Q>!9*^T@AT=S!,%-D]1E`Q@_G6;12L,]Y]`(M8)WV@11IM60:*+
M<"MAQ,1H'7IOG$0R&2].)I,9H9"<Y_.)G63\TR)X.!Q6,W0GS(:#$#BJD63'
M^/AR6.M>@6]P!YS-;T+0+L.([C5$V4]`7]\`6]<^I.=-384:A[J/PVEK)FO"
MJ1?!2;9+O!X^UV8\$&!;U\/5^R7\UITPG<T$<V$-(I>>A_+[<^`K5F.X8AV<
MM6L@FC^$Y#H"JCT'PX8O(`J,9FXN^<0B."G#7E*_8@\_Q%AU6T%=?1M#=9]C
M['H^I+Y"2):3\-G.(#!\]G9DC3]CI.<L;(8BC!GSP3KUB,=G,3\_?_@>,%F$
M`ED6XR[:!#?;`EMW"1PMWT`P%L`W=!1AYC04L0%1V0@E:$<DX(*/ZP9+7<?P
M0!,8>S,DP0*_WP-%B<;GYN8.D=HONP,_*4EN&-M+86S)@[FI`*)^#Y2!78C;
M/\;LR$>89;]"S%V`:;$$T\(E!+DF"'0SZ"$=[)9Z4)8Z6$Q_@F5LF)F9`?E`
M]EUX/#X##]\!JN<P[*U'(/07(TP50J%_P!2['[')?,2$?$SS^W"3/88@4P:/
M_0+8@6K835?@,)6!9]MP4XFD2P/"S%9-W0SOCH3$N"S:,3YR$5;](3`=!R'U
M'X4R>A13$X6(B=]A1MJ'N%QP.\:X;Q%ECL/K^`43`[_!WEL-UEH!]T@E?)X!
M!&1:2T[R)I7D&8>QK00]NIV@6G:`OD86L?T`^-YC\-M+$':5(LH70?$48<I7
M@BA7B/#8042=A?#:3H,SEV&H[02XSEV@=)O17?\6NJX=`L^YH!)X)DO?_'V6
MS-]P<-1Q##:1/5R3#5&W#;(^!Y)Y.]D=1/:<!0V1YX-;X>\ATF\#?W4SG#7;
M8&_9@DFJ&#[!X$CS)B?I?VTB&8]\&I5K,=JV"=2IQY&J(;M3IT+*H,(M$Y&%
MW%M)-)-GG61\C8SK59#+5\!1]3(XT[N(1=N0FO,L/D2B,$KWM.Z&I7$#1JHR
M$:U:!EPED%8":2-`(U$/&7<L@-&@0N*/#'`$3%W.A+GV55@,^\GI=FH6P:/1
ML%:)<,),M`&NEHVP:9Y"M/)1W+I"0"1#-/\CW4+&B<N/P'W^&0R6KX78MP6*
MOQ8NNDL0!;?VOBZ8-BMATL!,UJV$N_I)L%6KX?GU:03+'T/RTA(B%92+2V^7
M@KNH)G^X#F+=8QAN?`.QZ3$F_?Y]P6EO&1]SY%*&SP*.OS:"&]R#J9'W8*E8
M!:92C;'J=1@H6PGJ?"8F:M9CN/(%^/IR0'?DPJ-_B6S',X'X[,SV^\)#H>""
M*W:6(!3PW..*WH'WX>U\!S+)TD;`OL%<.)O6PN,LQ?R<R%A-5QI-[?MA-3><
M"X=#RQ?!!8%;P1`_]WFY/')\_^/GI4A,&Q#A3F&2^+F[]VLD8]V@S!KT=U4(
MZ7GCXW2&>\)Q+A24$(O%U`_4B41^0AOPBYITYZ'-9SX8:LD&[](JZ<X4"$@:
MAK'=73QB5,N)U$1+_W?+HZQ-62;]CY`]MLA#;]#AL#]+Y!GX9&[W@[[S-^18
MB)Q:5U_:`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S,U+G!N9P``````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#(R-C8`,3`U,34T,S,W-C4`,#(V-#,Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````7````
M%P@&````X"K4H`````=T24U%!]0!#`X#,MNI3=@````&8DM'1`#_`/\`_Z"]
MIY,````)<$A9<P``"Q(```L2`=+=?OP```1#241!5$C'U97+:UQE&,:?<YE;
M)I-,YIK,3&(R32?5I+01;;$4<2#HHF+$12&("KJ4+FSU'W`G"%V9A2"ZTTH1
M!$-!$QBJTEA-,DD3DR:3R67N]SEGSIDS]_&=$1<UF49PHP?.8B[?[WV^YWV^
M]P/^KP_SN!_]JWZ'P=!WI52M74\E4]!H>)0K=;"H0Z52@>%X=&E5L-OL4/'\
MO40B_J')9`K;[?;:8^&)1.+BUG;@=K7)N'I[C=#IM"U`>T&CV03+<2B72E#*
M9<1C<8CY#(8'G1CS>-ZU6JVS+0;?";ZTO/*JP6AV&;1:\`1J@?G6R[&0Y"*R
MV1Q^NW\/LBPCFQ-0JS50K=3@=KNOT?+.\-W=W><?K&^]+XHB!HU&,`R#`D%:
MJEM%<KD<8K$H'FYMXZDS8W#V6QL,R]\]Y1Z&3JLY_(MS+/RSS[]@K?8!WN%T
M(1&+P>%T0BI(;6NT&@U*9(>0+\#I&L#,S%6?3J>;H_?COW/8X^#3KTQ_DLOE
MVS94Z@U$R--8,DUJ$PCL!E$LEG`8CJ"D**C7ZXO'@3O"]_;WW:%P##E!1*M(
M<&\?IIYN5*I5A*)Q_+KDQ_;6%B6G!H[ZT>DY8HNB*#=FWGQ;9;4[:/MER%*1
M(%50<L"P+,KE"O)YL1VT="K;4MX1?D3YK:^_N=QGMG-V>S\EH8AD.H,D65*4
M%7#4T4AK1]D,P*F0SF;QW=P=IR05>OX1?/'^"LP6"U*I#'9V@NVD#`TYH5;Q
M!&=AZ.YJ_\]H)!ZOPH/U]3=\OKM/GPB?7UA0[P2V53N;FRA2LQJ-.LZ,C:):
MK6#O((R]PS`X:K+59J'3JD-?KPG[D126US9NTEI]1SAYK2<_9_4ZS16EY75!
MI/@5L+GY$*O^-22CAY228KM@A7SGR"-;OPUZ?1=^^'[^?#@:]Y'_H\<VE&)G
MI2:]D\OGR>,4U&H-]-T&B(*`6.20E&I0D`IMY26E]&=*R#*69@S+,EA>67WF
MR;'34X0*'!E<5)4[.`C=F)_W?>2C$]C<#\+59X9BM:`[ET&E$<*`8Q$;2P44
M[&_!27LV]9J15O/HS6<"8R/#DM?K%1T.QU4JG'A$.7U1EZ2B>&YR$FP\BM.7
MGD.TT8"KBQ0G]V`Q?PJ7+8[9\``,IT;@/3>)$*6)5^3%T<&!U\?')X(=/:=,
M]P?W0N_]F,EAT&*"3/'UBQ)D(4,*;T$2BEA9->.)P1I,:"*6I\]"`8HL^8X#
M/P)?_,6O73N(>"*9-*PT"85*&=I4"&+Z2QBZ[N#;N8LH,U/8"-IA-O8A59)A
MJ94%[^5+OY]X0HV&;M0T:GB-.@P/#UW+"\++0OGGET8\7V'A)R>>O?`:&II^
M3%X0E(FSX]</:,YPK#Y-%\/M$^&#0P/A;K$PPC!-FLN5`UD2U.<GI!=BR2F-
MU38==;O/OEAA.+EG:+3A\7@.__4=F,_G/M@-;-],I].3_[D+^@_>]/GVV2>O
M<`````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO
M,C-X,C,O,S8N<&YG```````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C8T,0`Q,#4Q-30S,S<V-0`P,C8T
M,C<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,
M#@0-(H[V(@````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^
M_```!2Y)1$%42,>ME6M,DU<8Q]_W;0O>F/,RLV11B\O,W)?-Q6BW^<68;'Z9
M3OVTF8ULB1O+W*8N3G?S@L$H4T,:400<0PW,BA0H*CB@@*50;J6E]/)2+NW;
M*RV]0&NAI?QW*FPN*4M<XDE.3L[).;_SG/]SGN>AJ*=L=MN@B'0D1NI9-T5]
MMJBY+AL-][.?#=SMLDE]8TXQXD[AF/.A3EFY%5Y'BRXQGYR<$/O&7(;IZ>CA
MO_?'X[$5I+^4!'(Y;6FLL3N3LPYD!H-!'MFT1=UYA^OO.(]HN!EN\UD8JY>#
MZS^!F:@"PZ9R*)NN8#H:KD4\O-KG<V9Z1JW-L=CDA21X(.`7#AB;T=%T')RE
MMQIQ!SMJ*82N8@T\7>]CZ.XFN"KY,-_=B(#A0Q@;WT1/TW?`>!]"`:=2W9H#
MO48&A]TB3(*'0B':Z;#N43_\V</6KL-`ZT?PJ;9#=2$5`SD"A(L83!=3>%3`
M8"PO!>X;?#AKMB!0M1MLV5OP%KP.1]WI`T0!>EZ-$U)X1S6L4?8:["4"#.<M
M1*"`QN19&LYL&H]R&;A.THAFT0C_0,-[/`V!HP)$?Z00RD['1$M1+3%R6?)7
MLX](+4-M7-A7#F?+VS"+!0@5TYBIH#!UGL&E?0LQ=(0'Z3X>!O8S:-G+8/@+
M&K5[>7#OI]'X^?-HD5R$W^>YFP0?&=2(.QH.H:L\'8WGTV"_Q&#F#@74$2FN
M+H#L2S[8GW@H^Y2']J\%*-R?BL%?&.1E+((E2X"\`R_@WJW/8#*J#$GPZ*1%
M..&K@[7U/4B/+87[*@/("+R!P/^@476(!_4Y'FX=Y*'[%(.*0WP,BVE<R^3#
M=IE&Z:DUL+%%"`8<&4_^LMLF:F^Z(-*V'M[M'#B'OGM;D9NQ!),W:*"&P!44
M(G(*OW^?"I-D,23$^OYB!J7'>#"5\%!^F#BVG$'9KZMATY]&(AX2`4>^M(AR
MV(?1_.`,%%7;8:A8"7-9"BY^O!B1?\'#;0PZRE)A5RZ%JC0%'CD?([(4J(L6
MP'*9@:8P#:I\/O05RZ&L>`?RVM.P6DR@."LK>E!S4N2T-.ILNA/HD+R!,_O2
MX"R<DZ69PHR*0DQ#8UK/0TQ+(ZXFKZDGOZB21N@Z`\.U5V"XLQ%6<MYMD>L2
M/,N(\4F:F)H*9/A=%3`V;47>MRO1<IR'&2F!_SEK/<@%T)#>,S=/K%=1&"U>
M`L/UE\$I=R`<J$<\YD@.(JM%;U#4?H/.ZLUHN+P>MX\L0ZB$2%,]!Y+/0>5S
M<[(>*V5@O[D&^AOKT"E)1Y?\"(GN?O$\X>^3!OU#7"18"7W-)DBSEJ/^Q))9
M[2NI68EJYL;*63!7\!QQ;CK<;3LP[KD-D_XA9[,-2_\S0FTC3:Q9N@KFTC2T
MYF]`]\45Q&DIY!4,HC>)<XG&7B)%PF)=R3HX;PN@E6U!:-S,)L[/"R:9D&99
M[1YMPR>>OON;,=)[$..Z#]!6M`I]OPEA)$Y3Y*R"-G\M1FZ]"FW)BW"KWH5!
MO@N6AM7H58H]X=#$SGGA8V->H<G0A+:&+'@]ML=9T6TM0(]T/5R=.S&JV(;1
M2@'4D@WP].R"3K86P_UBDG(Y5JV25+?7'X6ZH_J*W^=;-$\9LY)\KLYTNZR9
MD4@D*9\'N%Q89"MA4F:2>0OZ.G*AD.=SB7TLV\\;,FNO^,8<B$0>"9^J$MFX
M(:G78W]<B0Q=.;M[[FV#U20-(NX6>CP.\="@YA_G$8,6Q6)30G(9_W^7O-YN
MJ:A=?@9NA];_S`NTWS\JLG,#(*7LJZ<]\Q=RQ0HEN9,4IP````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\S-RYP;F<`````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R,3<R`#$P-3$U-#,S-S8U`#`R-C0R-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````%P``
M`!<(!@```.`JU*`````'=$E-10?4`0P.!"J'A$-)````!F)+1T0`_P#_`/^@
MO:>3````"7!(67,```L2```+$@'2W7[\```$!TE$051(Q]V56TP39A3'?5JV
MQ$4?%I(MF:F)(7%!-S(R9FBP;+&8,%@!A3&A@..68;ET*B7"8+K0%A!PZ.2N
M0)%+6]H*K(*TY6(!2TOO!5HT&.F8*9,"`V2$_/?).PAC3_N2\W;R.Y?_.>?;
MM^]_^UZ^G-]O=SRA*/L&*(/#(Q1E_^"F]3\:I@QIM!2SU4I97%RD;&QL>.P*
M/*8WG-$:S'?-XW8,/=9"HS=A>'0,(UH]M$;+INE-9DS8'9B<M!MLMO&4V=G9
M=]\()DXQ#U4#[KYA+73F"4P^?0['M!-3SYP8GYJ&S3$-K6D<HP8K)%T]J*V]
M@YY>)=P+"W7;@DF9!T5B29-:,P:]U0ZCS0&+_2F!/B/P&>A,-G3UJ/!=,@O1
MS'C$GT\`C\^'1J/!ZNIJZ[9PA4)):VIN@_B^'",Z(ZP$/&JT;9IIW($>U2,(
MVJ2HJ*R$4JDBT-'UWMY>CM/IY)#$#FP++RPJ#KU>5@ZAM`N=W0J2J14RN0H#
MKUM$6M&M&D!QV6UT='1.K*RL?+*^OGY\QT(^UFA766P.FH122#H?H+%5!MEO
M"C2+.U!1=P]EO]8@\?M,M`I%^EV/7U%QR6I2*AMU`B&JZIMQH^(.!$(9[C:W
MXV;M/;`NYH%Q-A8W;U7L#NYP/!&$142#S<D#GY2>5W`=6;E<7.65H[B\&A>O
M%"`N^0=$1"<C-"S"WC>H/K1C.*^P5)+]$Q_L[*LD0#XX^7SP2F^C]%8=JNM;
MP,GCX^RY)#`3TA`3GX*\:USNCN&1W\9)(F.22':9B(Y/175#"WZIK,>E'"YR
M?RY!/O<&4MDYI#6YB(I-05PBRVDT6?K?"&YH%!PY=3ID-(@1N9G=N?@+X)55
M()&5A=<!,[+R";P4*>G92+N42ZK@(38I':R,RW^WM(JH6X+)2+TG:&H9\@\(
MA-=Q'WSZ&15^_G0$T(/A[4,%E49'^#=,1#$3$,2((H)&(^CK"`1^%8X3U"^0
MSKXLV1).9O4#4M[SU`MI^/R$'S[V]L%)&@T,1BAH`5_"ZY@7/#T]</3H89RB
M!\+_9`!"0A@(#@Y!6/@9M$NDK\AV,K<,,#,SXZM6J^UBL1@-C8UH:Q/^5555
MS2WD7[%QKWV$HH)W\&-.U"N12"23R^5D0ZO*9;+[*N+7I-/IN&MK:[[;]ITX
M>+G=;AHY7+2YN3_]%(H'P1V2H!?ZD?VPZ-Y&OR)IGOAX+"\OTY:6EMXBI_80
ML8.[7B:7:S;4J"^!PWP`-94,]/<<QO!@Y/R>/PDB,$.GJ9Z;,'Z(AUWO8TQ'
M;HR&@S%M\][A(^H,[I3E"+JDONB6USB7EY<D"PM_Y+A<,_0]PU_\SN,:M)E0
M*-JM1&CO__3O)&)Y3CDF3KM<KF/_EO$/_32U3W/CF=T`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M
M+S(S>#(S+S,X+G!N9P``````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(Q-S<`,3`U,34T,S,W-C4`,#(V
M-#,U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!
M#`X%`JLJVO(````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=
M?OP```0,241!5$C'W95K3)-7&,?]M&R)BWY82+9DIF8+F7%N<W-A!"+%Q<HB
M,$J`;@+%H5@,E)LP2@0!S5HJ<AE(N(-"P5):2A%$NK:LU`(K+:7T`K1@<-`Q
M`Y/;`!DA_YWQ'82Q3WN3?][SX3F_\YSG=@X<^-]^+U[,'[0[)BC*GEZ*IJ^?
MHE1K*"HB]9,^2J].3S%;;)2EI27*YN:FRY[`@\:A(/V0^9YYQ`ZMS@B=<1A]
M`X/HUQNA-UFV9"0:M3LP-F8?LMI&HF=F9MY\)9@8A<M5/0OJ/CT,YE&,/9V"
M8]*)B5^=&!F?A,TQ"?WP"`:&+&CMD*.ZNA9RA0H+BXLU.X+)-0\W2Z0-6MT@
MC-8QF&QV6,8F"/09QI]-PS!L0X>\&U'1,0AC1N)B)`LY?#YT.AW6UM::=H0K
ME2JJH%$$25LG^@TF6.U/,6"R;6EXQ`%Y]Q,T-$E15EX.E:J;0`<V%`H%Q^ET
M<HACAW:$W\[-I><5%J.YM0/M7<HM3]L>J]#S3XA(*.3=&O#S2]#VL'UT=77U
MDXV-C8]VG<A?=/JUN*14"$122-L?H[Y)!MDC!822ARBK;411:0VBKL:C220V
M[KG\<N_DK[%BDU`C:$95G1`_EM5"T"S#O0<MN%O=B+CD3-!#F+A;4KHW.*EI
M06!(.!(Y6>`7E"*+FX?O,[BXR2_"G>)*)%_G(N+*-02%1L&/SK#_K-$>V36<
MR\^7IF7SD9B6C23.37`R^<@I*$-!234J[S]`6F8.`;/`O,Q&Z,6KR+K%Y>T:
MSK@0(?TF/(IXEX"P2#8!"E%4<1\IZ3QDW,I#%J\0L=<RP$Z^`48X"Q&78IRF
M8:OZE>"Z>L'[9WW\![[R"][:&!H9"WYA.5CL5#"8T8A+R23P`D3'<\@Z@]PJ
M!]^QXL!.3/U+V"3VW!9,2NHM08.P][3W.1P_\1E.N7G"PXN&,S1_?/JY)SRI
M-`0Q0G&!>0GG`Q@("`[#^:]#X.,;"'>/,TA(3)%N"R>U^H[98IF*82?A"W</
M?'SR%+RHWJ#3`T'U_I(<>!RNKBXX=NPHSM+.X;27-WS]Z?#S\T=04#!:I*TO
M27<RMSU@>GK:3:O5VB42">KJZR$2-?]945'!N\V_;OLA^P/D<M_`C?1O7XK%
M8EEG9R?IT(IBF:RMF]@UZ`T&WOKZNMN.<2<&'RXL+%#)X*+.S?WAH5)U^;5+
M?9\;^P_"8G@=:N65>6+CLK*R0EU>7GZ-C-HC1(?WW$RSLS-TDS$?#O,A5)4'
M0"T_BCX-8W[?CP1)<(!!5SDW:GH7/W6\C4$#F3$Z#ODW[!_>KTW@C5O?0T>K
M.[HZJYPK*\O2Q<7?T^?FIFC[AC__+8<WI(^'4MEB)8D^^9^^G219KN..49_9
MV=D3_Y;Q-[DCM4"!``@K`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,SDN<&YG````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C,W-``Q,#4Q-30S,S<V-0`P,C8T,S4`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!<`
M```7"`8```#@*M2@````!W1)344'U`$,#@447_YOHP````9B2T=$`/\`_P#_
MH+VGDP````EP2%ES```+$@``"Q(!TMU^_```!(E)1$%42,?ME&M,FV44QTG\
M8C3&?22:+/O&![.,:<BBB0O;2+;(=!D0B0,!R\#"4"X=<FFYE;%"N;RT0*'E
M4@J4.RVTE-X+M`7*I2U@:2$ZV`04Q2G-YB!!]O<!$[0:DQG]9#S?SO.<]W?.
M>_[G.7Y^_WDKYPM/?L+(/J76Z$[^*\#5U=477*XE>EEE-9TODCRA:H7HE2F>
M'/H6ZT3`/X*/F\T"H;@#;5U],)HGX)A?@'[4@M+J>N2S.?;5M;6JOPU5:8TG
MU'J3I*12\+2C=P@RQ0A:NF3H5V@@5VHP:ID$3R3!^W')3ZOX=;L"47/*,\/+
M>`W!'*H!?4-JZ,>LL-IF(1O6HD^AAG5J&D,C>I14"9"8D8>PZ$2$1MS8[QE0
M?/B7P-W=W><<BRY_<;O47ZX<6>+R15#IQX_:T#.HAE#2@RZ9"EJ3!06<:M`9
M^>B4C9"D>I3R1&AHENRXEU=H[-(J_T>/'[_D`R<5G1HDU8E(C^N:V@AH&+VD
M\I[!$937B9&0R@2SA(?<$@H9S#M0:0U87OD"LXX%*+5C:)'VH:2"#V9Q.;3&
M<<H'KC.,-A1Q:U#;+"7!HQ!W#I#*QV"==J!:V(88^FU(NN6_GDW-8-&U!/O\
M(CKZ%*AI;,<,22)3Z?!Q!@M,-F?EN^WM,\?PG()B#T_4AL:./C@77)#V#Q,1
M!U%8+D#.'0HJC8&<+\+M689E:I;$]8-UEX<;":E(S2E&:Y<<C+R["(]-1B:S
M`':[_<HQO$DL\:1FY4/4UGO4XT)N'1+3F8B(2P&;_-&AJ!K#&%0Z$PXGZ-9G
M1;@:2<.E:U&(2<H\TB`Z,0T?Q">#D96+^?GYW^#WO]J82^4W(B0F`<'7(G`^
M/`H!@4$(#'D7`:=?Q_6T')Q[^P)"Z6D(N1J&H'?"<>;-8)R]&(J@T`@$7KB"
M\]$W<?J-<Q"*1'M;6UN7CN&>[1]C<S46O)>8@@IA$W)**T"CZA'.YH+&8N,C
M<3?B:/&HD/8BDI:(V"XE+H9%@G8[&TF9N:`WM".278KBLBKO^L9&C(^@GJWM
M!"9I24UC"QHF[&2^S6";II%:R,&P>1(Z,M_]MCETF\P8FII#DG00Z>P25)&)
M,EFL8"A,2&)SB-`NCP_XX.#@5?W*?;MYUH%^APOQ1-CZEE9,NSQ03\X@7S\!
M46</N#,NW&05P#SGQ(3="4IO`4W0#+&T$W.>%4S:IM?OW5M]S0?^S<XCBF6V
M(X];B8I1&[)**U&N,B*]G(_VF7E$\YO`;6I%.JFVN)J/(J41+?URL!0&Y/`$
M8`]JP&F5PNETRO?W]U_V@?/M;BJY2X'ZQN:?U[[=WK6YW&!IK4AB%8)GFL*G
M7`H+2^X]]^J#7;5]\2"^6X%:H0B>!^M[XXZ%?:;M<S"8+%BMUDH"?]X'WNM8
MHL1RY4\ZG9Y^Z'_Y@]=$D6<]8C#N$9-[O5[YSL[.BX=W[4[W%#6@A,UFLY.S
M$QT.3S;/.($!F>QK\G`N_VFOD)Z_13)&_6[/O/+]PX?T':\WYH^Q)-EULN?I
M9"*.]CGY[NSFYN:A?]GO?WL6^P4/`3VM%.T+I0````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O
M;2\R,W@R,R\T+G!N9P```````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,C<R`#$P-3$U-#,S-S8U`#`R
M-C,T,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4
M`0P.""8BAT!N````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2
MW7[\```$1TE$051(Q]65RV\;51C%S[QL)['K^!6[MI.T3G"K)E531*F@J"*H
MHHNB%@FI4D'=P!)U00O_`#LDI*XH"X1@AXJ*A)!:'B%26A!)2TGLM$J"8^=A
M.X['[\>,QY[Q@\]&+$KC!HD-C'3ED4?W=\\]Y_ON!?ZO#_.DCX%@P&TR6<[4
MM/IE,9V&H-.AH2J=:3I!`,/QZ#4(<`XXP?/\K"@FW[=9K7&GTUE_(EP4Q>,K
MH?"->HOQ[NGO1X_!`('G.Q,:K18XCH.B5%%3:TAN;Z-4R&%XT(.#?O_;#H?C
M6IO!=X//+RR\:C3;O":"\@0B97\.CD59KB"?*^#>W5]0J<C(YXNHUYNH:PV,
M^'R7:'IW>"02.?G@X<J[S5()@_UF,`P+698[W]H+%/)Y;"<2"/T>PJ&#!^!U
M.9HLQ]_Q[1^F'>JC?W%VA'_ZV>>LW;F7]WB\$`GB]@Y"DF08:!<&O1[5:A7%
M8AE>[UZ\?N'\3$]/STT:'_Z=P^X$/W?VW$<%VJH@\%`;36QMBT@FTZ0VB7`D
M0E94$(UMH:HH:#0:<SN!N\+7-S9\L7@"N4()^4(1:^OK,)N-4.L:XELB[MT/
MDB7+%&:]$VRWYS%;%$6Y<N'BFX+#Y4:M6H,L50BB864U`I9A2&T5!5JTK2N3
MSK65=X4_IOS+ZU^_8+$[.9?3!8FJ(IW.(I7*0*%%6"K$1$+L!,IP`C*Y+&[>
M^M8C2>4]_P@^>_\WV.QVI#)YK*ZN@6%9#`UY.OZS]&XR]E%W,&03\3@=@HL/
M+\[,W'EZ5_C4]+1N+;(JA):7.J$UFPT</#`"35.QL1G'9C0&3N`PX+!2Y?3`
M:K$BMIW&0G#I*LWMZPHGK_M45;UF,`AGJFVORP4:92PMAQ`(+"*5B$)I+T@>
M:S65@F3@&!@`50J^_V%J(IY(SI#_HSL&2LWA0(MYJ]UMHIB"GFK::#)1>%DD
MJ=;U!CW*Y1(I%SJA<M2IY!FH>>B'P4(@^,RA`T^=(E3XL8.+5N4V-V-7IGZ\
M_<'M7`ZMZ!H\%CL4NPVF?!9:*P:[_2Z6`V7(KHOP\"RL9ALRE(6YD`G[]^^3
M7IJ<++G=[O-4GN(CRNF/AB152A-')\`G$Q@]\1P2S18\O3I(J778K)_`.R#B
MXY03)M\()H],($8V\55Y;M1S\HVQL?&UKG5./KM"JQOO_)S-8YS4RK4F`N2Y
M10,IO`ZI*&,^:<'(<`UU-+%=J&!>*>.P5IG9"?Q(H'._+A@6HW%_/)N!@_PM
MJBH,Z2V4,E_`U/,=OKGU+#3V%()A-VS]%J2J,AQ:K3AYXOFE73NTW]B+ND[`
MI+D7^_8-72J6'KQ24G\Z/7+H*TS/#N'8\=?0TKMP]%A1&3\\=CE,YXV>[<O0
MQ7!C5_C@H#=N+)7W,TP+FJIN2N6B[LB8].)68E+OL)]-^'SC+]-)(AN]HTV_
MWQ_]UW=@H9!_+Q(.7<UD,D?_<Q?T'VJ\^9(;T?Y@`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S0P+G!N9P``````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(S-3$`,3`U,34T,S,W-C4`,#(V-#(P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````7
M````%P@&````X"K4H`````=T24U%!]0!#`X&!1YC')(````&8DM'1`#_`/\`
M_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```1V241!5$C'[91;3-IW%,=]
M7/;4+'M:MJ0/>URR+%O:+&MVL75MTZBS,=;82[051[56NU:GM>*\(:#R1U$$
M5`3Q@H`@"%[X"P(B%`'%6K5BZV4V6^IM=?$6C'[WKP^F36O2-'M:=I+?R^_W
M.Y]S?M]SSB\DY'][5_.-CIUB%+'IN05,^I.9V81_!;JRLLJUV!U:ODCR5*Y0
MHU6E06.K.MC0U*9=6UL+?2?HQN;FD<FI:5EY5>V>N+$-AEXSG&XO[GN&T6L9
M`(L0HIA-!/L'G.-^_^CW5*`C;PUW>WRRZKI&B&0*M.N[H::6I$4#94<7NLE^
MD!8[2@@!PB\D((M1"(&X0?96X!=9\(7UVU*%%J1U$![?"!PN-U04V&QU8,@W
M#)Y0BK3L8MQC\I!P(PN1L5?W^LQ603`8?/^-T.65E2BY0A5/`7R\F@:T:(PP
MDG8T*O7@B>0HJ:B%K$V'RMHFT-+N@L438L#E09_-"6FK%C5B"13M.FEQ:64\
M)>NQ5^!-"O5D55T3!'5RZOG=J*<<#"8;FE5Z9!5PD70K!YPJ"3+SRU`K;8'_
MP4-,!0*P.X?0T6W9OU=-^6;FL2`0BH@#L,EL97(J1+O\NF9H#29T]EK1I#90
M1?1!KM3A%P8+^:55<`X-8^3!V#[8ZKB/+M**?$XER@42>(?]:&AIQ^7K&2@I
MYV\O+2V=W(?_RB@B"*$,-0T*#'G]5`%[\")0$5=(:5N$9K4>P_XQC$\^PL.)
M2:CTO2BD.B8A]2XB8FFXD\<!FU\/6GH.XI,S4,#BXO'T])E]>.#Q##./R=TM
M+.-#+%>A@,HR*3T;YZ\D(RHN$3RQ;#^`6-J*9HT!O[$K$9-P`Z'A<3CUTR5<
M_/DVXF]FXTI2&N+BZ>!5\C$[,W/F0)IGRZO"@K8.G+A&QX_G(A!^-1F?'?L&
M9Z/C$,GFXWCH:5R@I2+LSCV<^"$,D3$7\>7I"'S]71C.7[N)LX4<7$I,0BZ#
M@4&7>XHJZN<'\/KAJ:/%5@_.T>B0*C4HJV]$4W,K^,8^1(OEX'!YT/<[D$Y4
MH[9.`H%*A[(:(:JJQ$A5&)`BK(-&VR$UFRWQBXM+KW;+[W_][6PGS6AM4Z+(
M.H0D+A^34P&0_G%DL`F03C=*30.PN#TP><=`;^]!>U?O$X=[1,*0-D.MTSW?
MW-R,?JW'%U?73C*]$XL9!!].GQ\T=1?2<ABP>$;![K'!8K-#1`6,$3:@Q]*/
M2M*!J!("UD$WE)XQ-/:8=RB-+[]Q@-2/YHD4LPN)UU,P/3L?%"M4T'<:P1\<
M02R+AZX>$KG==M`*F=!J.S(--@<J*&FZ!SR@:TS@M:FW#AUYW=0\D5%&0"@2
MS5)Z':?&6/GTCV=:5J_U^>VL7,S.S7N<+G?0:#1.!@*!+[:VMK3KZ^M:->G8
M3J3DL[M<A\,W-C:)\8F)Y<Y.P[<O[WN]WA&;S>:DGOSI^L9&`O7O?/7R^>S<
MW)\FDL3"P@+G4/CN[MX'.SL['[]6B\6ECZCUX6%^R\O+G\S-S1^E[KP7\I^R
M?P#<:#&%9C&U^0````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C
M;VTO,C-X,C,O-#$N<&YG```````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,Q-``Q,#4Q-30S,S<V-0`P
M,C8T,C``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)344'
MU`$,#@8:DVL19P````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!
MTMU^_```!%E)1$%42,?=E<M/8W44QV?A0J,+38R+V4C,N"/&U;"=C8:%"Q<N
MC(D9EOX#8V9ET`TCSH",$T">!2E]3I_T01^4ODM;6DKINZ4MO>WM^T$+!H;Q
MZ[E=,#%,%(V)B4U^Z;V_<^_GG-_W/.Z-&__+7Z_7NYE.9P98MCP;"`1B-ILM
M5B@P?I/)-'!^?O[&/P9WCH^'C@I,(9[,H%9OX.3D!)5:`S:G%S*9"J%0B-=H
M-C_[V^!NMSO(%(O)3*Z`<K6.8KF!`EM'+,T@E6,AE9O!6Y5!+)&V69:5D^/!
M:\.SN7R'K3;0/3D%6VW#[4]!K?=BQQ^C^R8T1A\>38DP/:_`@_&?Z22*;K%8
M_&L'S5;GRX-([!D7*4,1AQ-%.+PI;-E#8&@OFBA@36B&WAS`;BB##;T'/SV9
M@UZ_*3\[._N4UEM7H(U&0QX(!(.)1+*=+Y3@"Z7@V4W`9-V'4&;M+Y,U!*%T
M&YLF'ZJU%HY[/>28&B+Q++0Z0]M@W*H+!(((L>Y=@H^.CF[[`P>E<"S?U]3A
M/8#1ZL=AODS744Q-2Z#0N!!),@A'#M$Y[J+;.T6>J6(GD`!;::#6Z,#B"./!
M]Q.8F9F9O(13YB?WHQDH=6YD<B7$,PP"!X>()!C:\T"E<R%U6.SGH$=5DZ8`
M7+XHGJKL6.;KL1_-PN&)X!>!">/CCS$Z.OH"OK>W-YG)'1$LAQ)%X?;%L;&Y
M@Q6^`>MB,U5,$\?='JCN428YM$8O)5.)AY,"+/"T$"MMX*WIH=BP$WP"L[.S
M+^!42L/1:+1F=[JAUIH@4^HQM[".AQ-S^/'Q$K1Z,\P6&WP^/RQ6%_A")2:F
MEO'#HT7,SJ]#)%%#KM1A72#!TM)2+1Z/#_^Q:3J=C[/9[&DP&(16J^VO:"SV
M6RJ5.K':;%PU8'5U%1L:#187%R&7*^"D8.QV!SP>#]GU_7V[W3[\LL9YG>19
MX.#T`%0J%79W=UF*8F1[VPJU6MUWN+*R`JE4BG`X[$FGTWH.GLOEL+6U!8O%
MPCFZ>P5.L@Q8K=9+@$0B`<V2>^3@EMEL]G`V#JI0*+"\O(P=KW>$YLNJW^^'
M4"B"2"2B`#9`][$K\'*Y?+/$L@6OUXN%A<6N7"ZO*)7*#SE;,IE\4Z?3!3A9
M*+I,(IG@DOM-HU'_RN%P5!*)1(@[&4GS-07Y]DN[$\!0)!))T@,62O(80:=(
MIOLTP.Y7*M7W6ZW6&$$_H%8'M^KU&FAJ6EKMSGOTWABMH3]M_XN+B\'GSR]&
M6+:4ETJ?0BP6PV0R([BW]PXY?X7L\YS&7!*YO'`ZGYV=?W3MP<4PS!W2&VMK
M:W"Y7'VM?3Z?F^"?4R*;!H.A'SF?OPZ2!23IK]>&-YO-.]2U_<@HF03A<Q7A
MYFP:C>8+A\,)^@>/Q^O;:7Q<'TY'?[50*'PK%`IC-(AB3J<S1@YO<3:JD"<<
M>--@*%$"GY'CZ7:[_>Z_\NFCNG\M?'`PZ?7Y;AN-QN]D,MDG_\DW^'>LX.MG
MIJPOSP````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\T,BYP;F<`````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R,S$R`#$P-3$U-#,S-S8U`#`R-C0Q-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M%P```!<(!@```.`JU*`````'=$E-10?4`0P.!B_%V-5$````!F)+1T0`_P#_
M`/^@O:>3````"7!(67,```L2```+$@'2W7[\```$5TE$051(Q]V5R6\;=13'
M>^``@@-(B$,O1*C<(L2IN?8"RH$#!PX("9$C_T!13RAPB1K:F)0J25N;.B&.
MG=C8\1+O2[P[MN,%[UOL>&R/G7@<.[:#DJ9\>>-#*Y0*`D)"8J2?-+]Y,Y_W
M?M^WS)4K_\MK,!A<+19+8RS;7(I$(AFGRY5AF%K8:K6.G9V=O?:/P;WCXXEJ
MM<9D<B4<MML8#H=H'G!P>H)0*C6(Q^-BKM/YY&^#^_W^>*U>SY?*#%@",BR'
M>K.-?*F&0IF%0F7'XQ45-N2*;H-E58/A</S2\')EO\>VVA@,A@0_@B]<@-88
MQ$XX0_L.MBPAW)W?P,(#!6[/+M))-OOU>OVO'1P='7V>3&6>,(TV1<LAD:O#
M$RS`[HZAQK:1SC%8E=E@LD6P&R]ARQC`#_<?PF@TJ4Y/3S^F]<8%*,=U5)%(
M-)K+Y;L5AD4H7H!_-PNK,P:9TDEKF^[CD"FV8;*&<7!XA./^$.5:&\EL!7J#
MN6NVV-M2J33%<=S-9^!JM7H]'$DT$ID*:=J@2),P.\,H[;-TG\;\@@*;6SZD
M\PP2Z3(HV>B39/NU%@*1'!HDW0'7@\.3P,SM.2PN+@J>P2GS@D1Z#YL&'XJ5
M!K(E!I'D'E(D@=H0@(:>Y_?JZ`]/"'I"[[#PAM)0J%UX+#'B%W+H]B?QD]2*
MV=E[F)Z>?@Z/QF*"O4J58!4T6AWX0UGH3#L0KYDAD=NH!#LD09_``[3:71A(
ME@6A!G>^ET*XK(=<[2$G)FSJW`2?P]+2TG,XE=)D*IT^='O]T.HM4*H->"A<
MPQW!(PCNB:`WV6"SNQ`*A^%P^2"1:3`W+\9W=T5X\&@-ZW+MZ!NI5`Z1Z,?#
M;#8[^<>FZ?4^+)?+)]%H%'J]?K3HI=\*Q<*0.I.O!JRLK&!K:XL'0*7:A)>"
M<;L]"`0"9#?2<Q%<+M?DBQKGU5@L)N3A;K<;&HT&N[N[+#F8VM[>AE:K'3E<
M7EZ&0J%`(I$(%(M%(P^O5"JPV^UP.!R\HR\NP-/I])C3Z1Q%Q@/D<CD?Q4UR
M<,UFLP5X&P]5J]40B\78"0:G:+ZLA$DJF6P=Z^OK%(`.M,]<@#>;S:O4RDPP
M&(10*.JK5*H6@=[G;?E\_G6#P1#A9:%3E&A/W3OXFN/:7WH\GE8NEXOS)R-I
MOJ(@WWQA=P*82*52>7K!08-JAB#S)-.M*L/<:K5:[U+WSA#T/6IU\*O=/@1-
M34>WUWN'OINA-?&G[7]^?C[^].GY%,LV]A6*G[&QL0$:L:!\O$7.7R+[(UYC
M/HE\7GB=3\_./KCTX*K5:C=(;ZRNKL+G\XVT#H5"?H)_2HGLF,UFT-2$1+(V
MJA:2]-=+PSN=S@WJVE%DE,P1A*+U\S:JF,\\'N\H\7QB>3N-C\O#Z>@O,PSS
MC4PFR]`@RGB]W@PYO,;;J$+NZW0Z&$VF!B7PB40B6>AVNV__*[\^JOM7$LFD
M(!@*7;=8+-\JE<J/_I-_\.\1`.M1RR!1C0````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T
M8V]M+S(S>#(S+S0S+G!N9P``````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S,30`,3`U,34T,S,W-C4`
M,#(V-#(R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4H`````=T24U%
M!]0!#`X'!0=X+=,````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2
M`=+=?OP```19241!5$C'W57+3V-U%)Y_@(4+7;B:A0OCQLQ"^0-<."M7)JZ,
M\;'`Q,SH*#J2`8-`"V&8BXQ"`2D,E#XH[6WINZ5T@#YX%*&\+L,S4%J>27EV
M8'A\GO.+D7G$2*)QX4UNVIQ[[W?.^;[OG-^5*__+*YO-OKJTM'1U=755DT@D
ME(F)"263V8F'([&7_Q'PWMY>;C*92L[,S&-A<1';V]O8W-S$H]EY!'NBPR,C
M8WF'AX?O7PH,P"MTRV=G9W)O;Z_<U=4U:[%8X?8$$.CN@=<7I-^'D.U.Z/0R
MJN\WH:FI><=H-,IC8V.RR^62@\&@/#0T))^<G'SZ/`57-S8V$`Z'T=+2@K*R
M,K2WZU&F4J&BH@*UM76X>[<*G/#'DA*H5&H8C29ZIYW^J]#6ID-U=34J*RN1
MR62D%\!75E9@,!CH(R.!U<+E<N/>/4E\K-/IT-#0@%`H)&)55570Z_54?1,D
M21+QTM)2F$RFS:.CHW>>`2=.78%`0``3)3";S7"[W:BIN4\5_836UE9HM5IT
M=W>CHZ.#0+6BD.;F9JC5:I#8HENWQS<W-36=\R=P.IU^>W!H.&VU.6&SV1")
M1"#+,@8'!Z$NKX#19$)C8Z.HU._WDZ`]?U2M11,E+"TM@\?C@:9!"X<GBJ'X
MR`4M4U-34ORW!'ZI?P"K;$-?7Y^HLK^_'[>_OP.GTXGZ^GI1,7=GL5A$5R0\
M5.H*:#3TS&S%SW4&V!PQF,R6"_"9F1GIT>PL^L,#T+4;</.K;_'%C7Q\\MD-
M?%=0CCN%Q2@N+D%A41$*"XMPZYL"?$S//OSH<^3?5J.@L!RW\G^`SN@CC`0<
M#L<%.`EPG:K?BD2BQ)D?MJX`]$8'M4F</K!0-T[X`R'1R<#``.S.;C1J.U%9
M]2L]EV$PV1$,11!Z&":WQ;9H'JX_[?$OCX^/LUM;6X("\BMQ:D`B,8Y%&B#R
M,,R=G8+G3OKU>KU4A!>1:`P^?X!$;0'Y6\2I2.7Y`9+.S\]!$\<M";Y93+O=
M#D51A)CL$G911X=9%#`\/(Q4*B5\;K5:0:80G2TL+*3(Y]>>`:?)Q-S<G!@,
M]C.[@@=J9V<'T]/3PJ)\,Q@+.S\_+XKI(>>PP!QCEXV/CV-W=U=Z&CR'P-]\
M_/AQDL'JZNJXRG0T&LURTM/34^YD@>U),4Q.3H(II/TC_,U%\5QPE\ED\BV*
MY[RP7XB:7`)3DQ7;::@\M!'37'TL%L/Z^KJ6DY`VHB.V*VO#])`A3NA]-254
M'QP<O/17R^L]ND.49)1!N%5>`TP3NX06DA#8Z_6)Z61Q.1%1]/5E-F,>"\M4
MD#`"E(>&>6YM;</&QB;1$A/B^GP^+"\O"P/05GQ"5^[?@;]!X'D$_N0PFQ7N
MT&@TM%]J!#74/D@7$6?;L6OB\3CSS.#O7J;Z(DHP30D46L$*<:J,CH[2"911
M.$8)%*(H15/-^V2%3BBFZH-_[?@CT:[M[^]+).#K:VMK$OG]M?_\#/X=%^-$
MNJM;MP<`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O-#0N<&YG````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C<U,``Q,#4Q-30S,S<V-0`P,C8T,C<`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!<````7"`8```#@*M2@````!W1)344'U`$,#@<7],%<FP````9B2T=$`/\`
M_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```!75)1$%42,>M56M,DV<8
MK:)!40S+_&%T,Q`3-]V/J=.-Z?RU+&0Q(=.QN2W+7,R2L;`M1C.3J5-'IFP!
M1"X"0KEU*U#`EEZP2+GUPJV4%FA+Z07:4EKX^O5"02Z]GGTT&<D&2USFFYSD
M^_&^)R?G.=]Y:+1G/'->:X;-9L&TS99,>]YGSBGT"GAE8+'J_C\YL'+9[9[5
MD4ZB`&$BT3>1X6,^^`0&O5J#\'1BP.\K(`A"Y_?[+__U)A()OTAAWSJR4&CI
M_+AN,-UB,:=[O=Z82,B1I5,60]1:C<"B#(NJ(ZC-?@6#LAQ$_%VPZBL@X+$0
M#`:RPD$BQN.VI!-.4AP,!G/7D0=6')^:QW\'E_T05JN9AY#-,*?Y&'6Y;\(@
M3<.\,!ZUMQ/`JSB)X$0*!/1CZ!3>`<(.P[*WE2?I*$%?_P!L]MG$=>2+GM9-
MR_;,;UV#I\$J>A\*X3<P=YS`@TL)N/GY;F1^^0(NG4O`M:^/091_&'>_VP=U
M>PJ>ZL]BE/\:\N_=)A6*P7..&6+3O_B\G!XD*N$3Q.+AY=THO+(?HEMQ&,N)
M@2)_+WKH*5!*6)#WBL"LSH*(?A3&VNW(NW$"ZM%N`Q!\:P/2X`\D,:8R&_MM
M"TX&3"V'47,E'I.%6S'/W`QYV>M0#CR!4:_!+.$$Y2TFS%.H8]8@Z\=4-%>E
M8'FN`0OS=MO"P@+GG^2?N>U-C0;IAY"6)Z'Z^LN8>;@%_L;-4%0?QTAO(UPN
M$O89)P:')]`[,$:1V]`_I$=A23.*[F>CKO(BZAFWH%&/Z-:G946;&)BKAT/V
M#H0_[T*$18.K+A82]D^8F24HM2X8)NV0R<>A&C5AAG"AM4,)-E^&MBX5RLH9
M:&RHA(LD?%0<OXB2NHF!9)7L^V13SU=GO::[4').0I.[$]*\@V@I_P":$3FT
M>BO4XQ;TR/7@/AZ`I$^##LDH]=V'28L=I,L%LW4:/!X?@I862&5]]5JM-IGF
MGFF'6G81QM9#</&WH_[&#@A^.X(^"1_#(\-04BJEE`V35@>>="I12A=@4&6`
M0J6/$GL\GM7X06>8@I-TPV2>!H/9#+E<#IK;SDD>Z_DHV6,3:!R:ZV@K.XXG
M#7<A[AV%2CT1O:S6F3%&J6]I4Z!+-D(-E:1FX(J2#@T;P1/V@\/OP9C!B@[Q
M"$K+F6AO;\.:Y\$5PX7EF7P8A<?1Q<V"T3`.J\V!T3%+5'$U4X2VSJ&HNE4;
M5M&KT(->+41!,1L-'"G8@CYJ!KVHKF&@N[L#:VEQV3ESRM8TB)FGT%V9#!/W
M`J3L6Q#6W@2C-!-%.3?`*+Z*#FX>1$V_H$]$1UU-'DJ*<E%27`IZ21:*BO+0
MT,0%F\/%T)`R9RWG"SY"Y?-:;,M>!LS<)(@R$S!;N0/S];$@67%P1K$-\YSM
M\#"WP5>U$\/Y5!WD'H3DT1D8-0RHE&*;7F_D"X6/]VBUFMB_Q3$2)M)#]JNP
M-.X"G<KZ4-D!.*L2X*G<BE`M#?X_:)BKBH&S,AYVQCYXFW=`6AP/>NX9/%VP
M;/R'1M5'YO<'/&R]57P:Y;GG,2RYBCG%V^C,WX/V@@,P5B1!G)<(36D2IEF[
MP<T^`'+P/7CZ#Z'Q_A&TM`C(I:6EU`W)PR&?SJ2I0#.;#I(DHJTXKTT#\]X;
MT(K3$)#LA8C*/R/[*%:TIU!QYU6,#5<AN*(SN,WYY*/:/,ADTA*JKN,V['.]
M7IT^,^M*IQ9`M,_'E85K?1Z:2$53WDO@/[J&R!(?`UV_HEW$M:U:$0X'4B=-
MRA*2=&)Q<3'QF38104RO;:(`6>QK*GL7_7V=/H0F$SVNZ0*]<7*MI"A!<102
M*6SYSVO/OS#@%7(R830:O,]]0:\LDQE34R;8[8Z,9WWS)Z]V?1:A_-;1````
M`$E%3D2N0F""````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O
M=&-O;2\R,W@R,R\T-2YP;F<``````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,#(T`#$P-3$U-#,S-S8U
M`#`R-C0R,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-
M10?4`0P.!RJLJ1"*````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+
M$@'2W7[\```%H4E$051(B9656TR:9QS&>[';)ENRNUVL%[O:LF2[V9+=[&XQ
M6[:UW5)K#S:=UJ[:M=IJK;8J'BC60U$\@`HB*@HH?("`R$$!141$/%0HGK&Z
M5JM23]4J\NR%I6FL:YM]R9,WW_?E_3W_[_\^[_L=.?*>*[C_XA.BB+?HN_?-
M?Q<XA:@C&%C![M84-M<\86UO>+'_<A[!O:4E\IY)5/A_H-\$]S<]@=V5G8U5
M)Q;_MN&QKQMSLY:P'OMZL/"X%ZN+O=A9'\/^WDJ0S*DE.OI^>&"M8._%%):>
M],`WVQV6UV/`([<!8Z-:C'M,F)HTD7L]W"-M6%ZP(ACP@\"%[S0@+]."+V?W
M_4M]!&H)0T+PZ2DS@>E@UO/AM+>BOU>,8:<"+H<,HX,4_(O]KPQJWP:.#0;6
M]S?]PYB9-F-RO(N,EC`\--JM$A@T->BU-$%82T>GE@?/0]V_)OT2;/F'B,&&
MCW`^>Q/\$9$VL#V-I_-=X19,>#LQ00PFO`98S4TP&^M)>_3A>Z.6"T,[%Z-#
MZC#<8JS#S+@.^[M/0M4SWX0?"P96\7)C&+X9<[@BAYU"ITX`H;`:<J4"4DH*
MOH`'G89'OD),JI5B:(""O4<$O;H*O5VUV-N:>`M\;QG/G]DQ/=F%+D,3RMF5
MX`J:H&S7HZ_?230`5;L!C"(6"HMRH:"X<)#>A]1M%$`A>8"-U1&$XTOVQR'X
MXGPW;%8I2E@EJ.(WHD6N@;!5`;Y0`I%,!4.7!0J5%M=2[^)45!0R,I)AU-7#
M9A%"0Y5A8R74]Y600<0A^,RX$9P*!D02*;K,5O0/.&'NL4%"P*&QRV)%&HV.
MQ+0<T`L?X$)</-*S:'#86DEK.&111PE\_2!\_?GRL95GD^@E"\?A\M$J5Z.-
MM*"A28(R#A>,XC(T-DN06UB"A.0[$,O:8'<XH=(:4,+F@<7*1X.@'&O+KE>1
M?`V?F)BB*CAL5-540=:F1;V8"L.%8BG2:0S$WTQ#:04'MS+SR',]QMP>/'SH
MAE*C@URE`[=>A*Q[Q5#*:A'8VQ01^(=A\,+\W-?<^J:%JCHAI$H-U%HC1%(E
MNJU]X<I#P(KJ.KB&AL-0NV,0^DX3!(U-R,R[#S4Q4ZH[</-N'DZ=.8>!0=?K
MM*PL+S/+*SG$O1E6FQU2N0I%S#)D,YBX3;M'S,@V]WC@=C^"<]"%*EX]4N[2
M<.:/2S@;FP!Z`3/\95>3TQ`=>QDVN^,U?'UM_6A9975'`;,<G-H&Y!>S$)>0
MA!-G+N!T]$6PJ_FH(VD)Q;)!),75I!0<CSJ/B!._(_+")<1?2T)4S!7$7$U&
M[)6$G>&1T90#.??.S-VBE=4@-OX:+MW)P4_'3^)*%@,__'(2L;=I^/&W2$03
MP-F+E_$S,3T5EX!?R1@5GXC(\]&(2:<A-9.&1K$L^]"YXAAQ>U+9=6AN:87&
MU`T.OP%%"CWBXN-`%]0A\MQI<#D,I*6G(J.D`I$)UR%LKB0J![N6AQL5/"C4
MVEW_ZNJG!\"D+5^:+-;Y8A8'?*D*#\HJH'>.XD9F+B0*"<FV%`:C'"55%7`-
MR%'-YR$]XP[*&R6@%$K(^ES(8A1"U6'\\U#58^Y'3)'13#)K1*E23U8]!U*%
M.IR6&GD[Z&PN&I7MN%Y8#G%+"U0J"A35@FP"#\6SE03`,>`<(JG[_`!X9WOM
M>Y-W>NVO+#K)-.7/+F9ML`0B)!640B"6(;NV&0R2''YS"W(*2U&FZD0FO0!M
M9/-DY!>#+54C,3L_E'GJ4-7CXQ,1E,F*]#P&9F=];.(>PY=0@<2\@E!%%-6F
M@=,UB,U-?R79^K;[@A:4<ZJP_>)Y!TE%8Z6(0E)F;B`T[[_@'T].>JFI:>]3
MTOLO0L]T1M--IVL(4S.^;\D>B-C:](?^]!\L+3VAF7NL&!X>,H5./=_<_%?]
M`X.P]=FW#X')]0]P41`MQI).?`````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO
M,C-X,C,O-#8N<&YG```````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C<V,@`Q,#4Q-30S,S<V-0`P,C8T
M,S0`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,
M#@<ZL1X`[@````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^
M_```!7])1$%42,>-55M,FF<8;K*+)4N6)4MVLYON>C?+=K7L:DFSK!?+LETN
M67JWS&Q+UF:+3;.V-NE:7;5%K58\@Y:3U`):1104D/./G`7D+(*BR$$!L2@\
M>\&N2;N>ON3]3]_W/=_S/N_A/W7J%0.HOHW:X5G4'JM1+0#'NZ@=I1KWAM6_
M58LBH'*6'CX]]::#%G]#&P=0S1-V#$<E-XHY!L6LX>1.=GS@H;DP'9@&D0C1
MGB_>!/@T:I5[M<H&2OD5;&_JD8CKL;&^_-02<1TR*0WV=XVH%.VT/$$''&R1
M2Y^]&KQ6*1^58]C+,(BOZQL6\"]BS:=JF,^C0#BH;MBJ:PZ1P!Q*63-MBS\Y
MX"4>T,0E8EPM9HT-AJ&`&K[5>2S,2V#0BF#6BZ%5\;!BD<"Y,@4[(VV8QS;Y
MY(!-$`;K1<`?4I"6BSD7HF$-5JP*+"])8+<Q."CE$0Q&,2630C;)Q@-A/QX(
M>F&S2.%VS,!NE<'GDN+H8*T>Y&.Z?/4\>!..L]A.+,)BF(39;$8H'$<FNX>]
M_0)VTADDDBG(I#)P1WHP,GB7O!'"2S)9#&(L*D:1V]91@+=)GO+99\&KA:;C
M<A`KYFDPC`7YO1-0KR^&9;T#2QHS8NM)F,P.='?UH(O5@4%V-]0J(7EX'S.2
M/D1\TY1!T7J:_O`<^%Y3/LU@63U'H"5D<WN(1#=AL?JA6K1@?2-%[+.0RI00
M33R"5F>'2"3%8/\@=&H^YJ8'H5%R43T,$_,*G@+G\OL?Y')99L4\@VAT@]BN
MDP5A,'FPI+9B5JZ&S1[`XI(!0M$T5KV1AER)9!IVAP<C`QW@CW5#+J/2*/OK
M67,"_KA2.>UT>CQNSQK\_B`\WC"4*@8N=P!&DPU<KI"83I,<;JA4RPB$*/\/
MRLB09^[5$#:W=NB@')Q.-T;Z6E$I45!KCT_`(]$(R^GRDYLV8A0@QB$8C`YB
MM0.]T0D>[R%6;"Z*08'D*C8"&PC%H=-;P>=+X0_$&H%?4!K`OMN&W92S7K'C
M#7"CT<#:2NW`YO`CM;U+BS>(I9=T-A)C.;VOHU`L-=CN%XJP,"Z(Q;,8'!C&
MZ"AIK=""+Y!1+%3@#/=B9YMDH7[3`-\OE,[9[*M[)`U,)@OFY$IP1L=QIYV%
MWKM]T.DL\'A68;/9&G&8G)Q&/WL(W9V=&!WAT_LL!#PA)`^G(1COP_Y^LI[L
MGSP-:#R^^;U.I^=8&09]]^[AKS]_P>\__X@_?CV'EDL7P&IO1=>==K3=N$G/
M-W#]RGE<OG@>MV^UDMT$N_LZ[G,ZD4P$7URA2VISDU:KQ\/)!Q!P66B]=AXM
MS3_A2O//:/O[*JY>_`U#@\/H[""@X3;*$!8$E"&:I062B8I.+\?A84%!X.\^
M`VQS>-_3&1B)0J&D`F(PQAG!E(2#H9[+Z/RG&;?;6HCU-;![VL$=9<-!Y:ZA
M'B,6CL/G\V)2/($)(1^Q6+SY?ZP)_/2"4E?F<KA5D5`(@4""=#I9R^ZL5O1J
M$=B]+'1UD"2W6M!/$A@T0GB<<HAX;(R/<4CWJ7I<*KE\WO'2=CLK5TJFIN;2
M<KE"DLUF8X>'AUVUVC'#F&8T>NT<-I-.[*0"."@DD<EL4CN(![92Z2F#T8KT
M;J;IE;V<//C:Z_5^&XMO?:?1FG?K%;D6B"Q4CBH?U1M;J52\,"M748>,P&JU
M0Z^WM%)UOT7YWW10+G_\VC]1(KGUN<EDS8]Q^1@9&FZD7J%8E-;GHK$-J=7J
MP/S\(@1\'N6\=4"G6W[GM:#_#8?3_:5"09MY8UA8T%+YBQ".Q(WU.:52;93)
M9A")1#`\-`#QA!C^-7_G&X.3).\;3':16,@!ES.&1X_D"(;"9^IS+I?KC%P^
M3ZQ%X/,F$`H%42CLEU^$\R\$GT'$[ZC55@````!)14Y$KD)@@@``````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\T-RYP;F<`````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R-S0V`#$P-3$U-#,S-S8U`#`R-C0S-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````%P``
M`!<(!@```.`JU*`````'=$E-10?4`0P."!-T-(1-````!F)+1T0`_P#_`/^@
MO:>3````"7!(67,```L2```+$@'2W7[\```%<TE$051(QX65VW,3=13'O]E[
MFGO:IDF:WJ`IK5#*50='QV%0T!E]<N#1\6]P1%]U?%"??."=$8<''WSPB9$6
MH6#+H`B.M*4M+2G-I;FG:9/=)KN;7<\N3D&!\LOL;+*;_9QSON=\?^O`2Y;1
M:G33:12F^A/]<IEF:_N>@SYP<'2PGP/L/;HTQ[!2ZLG]G<%G"?JV`]I)0R]#
MTV3HFK)]7Y3<8!B)*"+Q_726KM+ETQ2@LB.<P`%`GS*T_"N*7(3<,*&J39B&
M`8?#`8;EP/$\6&AP.44*Y`'#AXGHG*3'/[0".%X`CE+&Y]7&VJE:O0IE2X-I
MFMA2M@C*V`%8E@4O"E`;3:I(0\`G(MC>!4'JM@)8%7S\`GCM*O3R\5(E2V#5
M!EM%6F?3-)!-I<`+@ITYQPMV,,-HP>?SH+>G!ZP0L21ZS_&<K/?)]<*==&I1
M*!2J**P[X!:;4#3I<8!F`9L*`TEDH%37X`OZ$8N%X/5ZH<@U1*,!A,-]U.>(
MRCTG\:_^N#,C,)P?+E\G1GM\X#@6AI6]=9#>EN:R+./^[!Q6LCED"TD<.]J'
M5JN%U&H.[>T=$+B6\`S\YJV[:.\<(`!#4,YB498<&/I2DQNH5JN8&!^'4J^A
M5B^#9^KHB71#;7;9E>77,NC?W8^0I.,_\/$KU_;,+RSVQH>&$0@&[%F2905;
M6PVPE/WFQB;6URM(KMS%ZX=C"'0>@4M4(9#^O"C9#,GI1+5202A4`_,T/)E,
M'V<Y\5"5`,5\CIID4*;KT'7-KD)35>1S>;0Y?:3S;H1#3H0B47`"3_>:MJE$
M2;(GR%K;<&JD*(K\0+5:ML=,536L)!+8W*PAD5C![[=N(I7.8#691B&?1F)I
M`0U%MJ%RK09)<L+M]4&@"JQQ!8FR+4MB)1TQ#?VSI>5'5%(7!6MA@V08C,=)
M%H6"Z4AE"/IPF:K)06FT(YO)P%NOP^OWPT]-M/K#TWAZ?0&8#M<3.,^SWTU>
MGX;'YT.I5(%*QF@V5?P],PN)-*W598)N/#8U(U)`S9:IS>6RG[=ZTM);-/<L
M_`$_!7HJ\WMSR\.]O3UV<QH-A5QG0&^1M=LD^'TN9',YY-;2MNTE=S^:N@][
M]HW:)K(,I9&,EIE\@7:XW1V4`W-]6_-T>A7KE%DRE<'"@V5RFQ>Q[BZJ0$>E
M*A-`A-]/!HE$:#0E)+,R,O3?9H,FB>5LN#7_H<X@;6(>2XMO;'BE7.R>G5N4
M\H6BW4@G/>SV>)#.%+%$@0K%HFVD-I>;LC,1CL;`2^VX='76OLXP#C*0M8$Q
M<'D&FJ;#^05AK]FR3-V\_6DAO]9?+A5)!C=84<34]#2*N2P,F+:>09I[J[$T
M4F28!LU_':7"&J:G;N/XB3=H3^F&SQ\E\<5O&;;M2]CS0BM7*.L,RYI67?E\
MA@S4@2I!LVM):G"`++V`Q+)!.YX+\N8&5>5%B_35=`/S*W6<X*.TQPPVX.#/
M$?WK9UX6ER>GYZ_\>7>8K58P=N@`9A\\Q.&](WA02N"=L7.X/#&"]/I^'!N-
M@W=[,;^8P)EWQS8Z0I%K@4"/)HBN,__?2KA_#73Z_E(J/-P=1M_A`W"0&?8;
M^+DK)!Z)]7\?"P=7P6,$!X?B&**M8<-PX(-8#+OB@Y\XG=[S+WKA,`1VW5M,
MOO_7HXR_IR,(,]B)WR9^17O0^Y92^B542>>Q^LB#KF@9\5U1I%7@QO@5RZEG
M14&X@!T60T9YL\ZP']VY,6G/*ZO3T^H&U*WQ0%_\HC`S<PKERFN8OLZAN55#
ME>:]36`P.KJW1*^RUDYPCF48>$P->P9BB._NO^1TB@'UX-:QCJX?<>&'`(Z^
M>A*R4L>^`W4,C8Q='&SI1Y2AOGQ'P#N!EZQ_`"(<=I4@?G\V`````$E%3D2N
M0F""```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M
M+S(S>#(S+S4N<&YG````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S-S0`,3`U,34T,S,W-C4`,#(V
M,S0V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!
M#`X(.:^/39L````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=
M?OP```2)241!5$C'W95)3!MG%,=SBJJF!PX]]1!QZ[&W1,JA2D5516I516V:
M2+2!!`+%90D0S&*"C=EL@K$]-HOQ-C9>,(M9;%.,"9C5QI6-L4T**02Q"(Q!
MJD"$I2SZ]X-641#J$K6GC/3I&WWSYO?>_-\R%RZ\]9>8JKF<\C`WVN7Q7OY?
M@)N;F^^N12(I`JD\I9JJV^4+:]#CZ-]5TOJ4N=FY#_\3?'#852>1-Z)!K4-W
M[P"\_DDX1]RHI.2@ZI4^4ZLYZHVADX%`E*A.<3V363!K(]#)8`AMUEYT_O@4
MFF8+.NT#B&?DX&9LTCZ;6Z;EEO$__M?P"?^DEEU>!7U+!_J'7+`Z!E$LD(%5
M3L%LL<,Y.HZT/"X^OY.(3[[X!G?N)AS.O9B_^X_@X^/CJ.'1L?W22A&!>.`8
M=$%E[`!?JH;:V`Z/UP]Q@Q8)&040R_60*`Q(SF01Z;2;X?!:PJC+\_XYJ$[?
M]%X)3WBOL]ONJQ;7P&BVHM7J@-YL@U#6B*S'?)0*9>"2+WCPD(4:I1X^?Q#^
M0`BVOB'4*#2GN5'I3*MRA>K*&;@_$)0QV3SPJ`:8VFV0ZUK18NG%D.LG2%5&
MQ#%R(2).ZC3-,+99$)IZAMG960P0B4Q==O3TCZ"%[(P<#BJJA,]75E8_.@7O
M[NY6E%<*COD2):1*`\8\OE-#FV,(S9T]*.11*"*K;W`,P:F?$0A.P=X_#'V;
M#<SB*K#*A!@;]Y%WC;B=D`YF(1M>K_?&*7QA84$4GYP*2JZ#J:.;Z#J).MJ$
MTFH9?F!R45VK1NC9-*9GGI.(I]!-9*@0RQ&?FH\;M^XC.9L-=F4-DC(+B3T'
MN8^+,>'W_P%_N;U=04EKC[,+.*A5Z7!2V_FE0MRZEX;/OHK#]UF%,!`I:'TS
M5/J6TQS<3\_'IS>_0\R7L<C(Y8!95`$FNQR)C`PT*%3[:VMK,:\T7PZOR21F
M"QH[+'A2)4`>\9[!+$"10`PF58?4C"R4\*J0^HB%V/@DY!?S\2`U&XR,'.+4
M!$-3,SC%)5"JZ2VB=]R9A&I[G-$"VH!ZI8I$3R.7&'I]/K1/SB"!+X9*34.K
M-X+6ZH@-#?7(.+KL?1@<&D8)K0-56P^'HP_A<'CZ7"G.;+YT.2<"L!.#1)D6
MMTE$:HT6D@8%^-5B#+@]2!=0,+2VH://B<1*(6B=#HTD8BG="+?;C8F)B=SM
M[>VS=?YBX]>8`N_T>B*+@ZZG3J209')*RTGVM6!*ZB$0BE!"VOYKG@BC+C<D
M>C/X"C4,QB8\(CU!-;4>[N_O\W9V=JZ>BUHSLR1B](XB.X]U%/IEKF!Z<7EK
M?-QSF%;^!+'YA1!3$B23BN&J-(A$UG_K[7?"'PS"W-6%3)(338MY[R];WCZ_
M*JIOM^S06GW*J^$U-<-KLM@@)5I:K;83+6U[>WL=1T='5\@]+!8+%$1_!IL+
M?VAJX._FR;7#P\-O7S\[.#BXNK*RLKRXN(BEI24EV2_^:7MQ8V-#>=*=\_/S
M"(5"('/_^AN/7@+Z@#B))NO2Z^?KZ^N7MK:VH@DT.A*)G#Q_Y^WZ[_X.LS51
M]1?]Q7X`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O-BYP;F<`````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C,U,0`Q,#4Q-30S,S<V-0`P,C8S-#(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!<`
M```7"`8```#@*M2@````!W1)344'U`$,#@D/>2[I0P````9B2T=$`/\`_P#_
MH+VGDP````EP2%ES```+$@``"Q(!TMU^_```!'9)1$%42,?EE.M/FV48QO=-
M/VHRL\4O[@\P,7X91HUS4P?&R=R8([(!8S#M!BNX#`H;XUBDE$$9A[9`@;U`
M2^F)0J&4MIQ**8=26@ZEA:Z(*U`J)8`&.4AV^5#CDF6)NN@G?9([[_,^>?.[
MG_>^KOL^=.@_O<IY@M<8:>G'J,:F8W:[_:5_!3KG<EV@A!(:I[S27,ZK@K!9
MCE)N=8%M<O+C?P0VF$8BJRGQ1JU(#I5&#XO5AG[3*'BU0C#9G,6^?D.+U^M]
MY87!'1I]0ED5]2O_H1C2-@VH9B4DRD[(R+Z[?Q!":2LBO[F%[#SVCE@BHS)S
MF'\_"8O#W:X5RJ#6]6%PV`RUOA\BN0K]1A-Z#284EM>`SLC&)9+@S/D(I&<Q
MJ3\%>KTKAZMKJ*,$QLW*+WXB;]>AJ]>(ULX>U`@5).30]QG!K6E$+/TNR@1"
MM&FZR;,1J5D%3P:,)FY22L91M_O[P\_!=3U]#IZ`0@FW)E`*H4P%18<V`$E@
M,)%T-Q\YA5S$IV2CODD&N\.)Z1D'.KL-D+1JD)-?#$9F/E1J[?+6UM;QI^#1
M,4M4;F'99D5=$V0J#9H5[6A2=&#$8L5#L1+1-Y)QOTP`;>]`H.83TW82,VCO
MZD%))85NPV#@K]*8Q8B^=@.34_;9O;V]MP+PI-1,SL%'#ZH:8+;8T-*A0ZVH
M!<4\"K?O%:!>W$+.K8';CD],H5ZJ`I/#1VS2G4!B0:,,F:S2P/YT:!BJJJNQ
ML+`0$H!W=FDY]_**0!P"I5J'_%(!$E)R$'Z5CNO)F=#V#$!';MU.+*DB=;Z=
MP4)8U'6<#(W`ES$WD9#*Q%>QB8A-8.#3<^'@\?F8GY__';ZQL?G&B,4VG<A^
M@#A2MY"SX7COU&<X?B($[UZ.Q<6OXW$^/!+GPB_CBVMT!%^A(>B#TWCG1#""
MHFEX/_\!3@9_CM"PBXB*OH(6I7+'[U_[*`#W[>Z][5G?N%FUO(9+ZAZPBHJ)
MKUM1)U?@$\,X(EE%X(FEJ)/(<'7(AM,E?"(@"WG<:J3P!;A068=O<[^#1*V!
M7J]O(\T5]510VMH>IV+)#_/$)`0-C9`,C2+-]S,TI,XJXNUR`?&U>P6YIC'T
MC(RBDJ(@M4[ADG,14E4'\;X!\<['H,G;8;5:2Y^Q8;+S!TY,127J%2VP+J]@
M8LF+>+T1Z44<.'RKF/8LH6K(##K[/NQ.)Z;\ZS#/+R"AK@$UHB88EGW@MZK!
M8+%!!EO',W#BRS,6BX5;_W@%9P>M:!")#@3!M',6;-\F(DC[&X>&L;BXB-7M
M'01;9I%1+X3;[8:1)#XUN8!LHM<CMUOC]_M??:Z)]H&7G;_LL!7F\6WIX/#N
M'9<'M:TJV%9^W!?INK<+)QPH(5YVNEQ0SS[:;NCMW\^8<:.Y2XLNQ]RN:7AT
M>W/SI[B_G"V7/>MOQHW9YWAB"5'=3S\X2YSWJF\I5!@:'E8?O&LWM^@Q-M>.
M4-D&E\OUX0M-1@(-(O%4]:6EI2.D+#2/QW/DCS.?SQ>UNKI*(]WX^@O!_]_K
M-ZO,02C,Z.%W`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O
M;2\R,W@R,R\W+G!N9P```````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-#<R`#$P-3$U-#,S-S8U`#`R
M-C,T-P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4
M`0P."2VL3JBG````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2
MW7[\```$QTE$051(Q]V574R35QS&O=^6>#$7HXF2[&)9LF0FNW%+MB5N;+H)
MV\2,!84A:*A:76%VM"*@I:VE6-O2EO+VA7Z\_2YMWT);2J%\.2B"?/A1:;`4
M)<.I*%@U4P<;SUY9MLSIO#"[\B0G)SD7O_,__^<YSUFQXH4>(R.CJWXX(DCC
ME1]+NS(]O>Y_@<[/SV^/=/6R;$[W&85&!Y661*2KY[[)YF(M+"R\\=S@NW?O
MYIH=[I3)[D&3MQG=/;T(AL)P>OTHK3R.HP+QR.1DDKX0NTC?NW>/GIZ>IJ>F
M+M.SL[.O/1,<BT^P+0[/HE)'P=W2"H>G!04U6KRN]&&?6(G5VA:L-/?BS8(2
MK)=9(+#[\*XN`([9`Z_7F_9,.&5S/E"39OC;NM`?/8V>OB@X"A+I>C^VE)W$
M1Z80-K#+\0ZK%.E*"S(49FRA0B#<S9B8F'@2/C<W]RIEL:Y.)*?JJJ2*)0?=
MBO:>?OC#W3`Y?>!*U2BV!)`OJ@6;=.'K7?M0K2)1;?2@YG0"!^4$U'7UM:KZ
MQG5S\_.O/`;OZQ^(DT8KI,IZN/UA4*X6-#.5$^8F'*ZJ02&'CSI/&-\+9="U
M=.*H1`:"LL)`61`8NX2<@KVH$,E06B%&;U\TS`B^=AE\[MSY/*%4?D>CM\/F
M"<(3:(>!Z>/@R%GX0IW@'!8A>S<;[D`(7-X1=/P813?3+JE2A:KC4G1%!U'"
MKX"KN0T%!WBH4:AQ??;FYF4XI[1"KB1,D&F-B`Z.(!CI@=[NA8YR@ELI02UA
M@+Q6#4)'0B@2PV:W@R1)L`YRL;^$#ZO-@>S<`A2756'GG@,02DY@,CGU)]P?
MZI#S!1(HZHWPM4:80_0XR!<BMZ@8.XI*X*(#<#1Y(9,K8++:EZOE\LJ0]4T>
MOLC.AU!<C4QFS2WB8`^[&$2#'M>N7]_\EZ?7#PV/QHX1#FS:4X[/M^4@ZUL6
MWD_/1$9.(3)X6GR6M1,<_C%LW2_`IQE9R,K)Q\:/,_%A>@:*&.#V76SL+&3=
M)\B&V[%8S,`P5_XMJ'MJ(8WK'L57^\J@J=/B[/D+S'5M:/1UX(.J9E3+58C$
M;^*32CM"H39T]`]#JM"@N[L;%RZ.,X*7PDO[&ACH2T]8,75_H99L.<7T6`R1
M3(T:91W<'B\(3PB9>WDX-30*1U]LV983/]]&D>T<2+,#`P,#<-/-X!TNA\/I
M0C@<?MSGJ8=+:X_WW;Y\2-T$B]V)W3PQMF;G0:LWXX1W`*2!@LW?CN_DYF7K
M4?U)O'V`0*U6!ZY0#O%)#6B:3B42E\8F)Q-K'H/W_/2[?%/CY67Q3H_%P!:I
M0)"-X!LBV'C(@/*C51`Q(DOK#=`;C*BW^E!268WV4P/85A=%8273LDB$?NIS
MUXP]E'\I,$(BK?GMQHT;_)F9F3O7;LX]V.^[LK1Y!PLFB@)A,*&A40^7RP6!
M4(A@:RL&IU/8P'/"Y`[\.CX^_M93X:E42M[9V?E+,!AD_7._+1P>>U2I2JV&
M1%(-RFR&T61"N+T=R61RA,F1AT:C$4PB=OUG4"TM+;VWN+BXX]_[3'QN9R8K
M'H^?>52U6J.![*0<9HL5\?AX_JU;M_(8,(O)DC7/G>W,X:L&AX:&F]SN>"*1
M&+8[G&E7K\Z\_.+^O7\`<;IE0W%DWZ8`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S@N<&YG````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(Q-C``,3`U,34T,S,W-C4`,#(V,S0R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````7
M````%P@&````X"K4H`````=T24U%!]0!#`X*`UNU]JL````&8DM'1`#_`/\`
M_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```/]241!5$C'[91=3)M5&,>7
MJ/'*9$83O3*[,_%B6>)'=F-23=0MCAAOW!(U86YJ59(9.@,3-V"B3;"EE`7*
M^DU+^_9#U@]H*6N@@Z[TBPK=1@.RIH!(6?F0[T(I_'W>-[:)4=-=:N)S<][S
MY+R_\S__YSGGT*'_XU\9.SL[@E@L9DLFD[:%A04;&R,C([9X/&X;'Q^W93(9
MF]_OMTU,3+SUMX!\/O_*^OHZ;W%QD4<`7CJ=YD;ZD4>`_A>,M_!)8PO>T/?B
M&64O7JR7XJA(BW?:#'A/:<6;S1JH5"K^7\"Y7.[4ZNKJ4B*10"`0P.#@($*A
M$-AY*I5",!A$F2.$URJJ4&8/XN6S7^#5JN]PLD:(4WH/R@PW<490C7`X[-G>
MWJXL@O?W]Q_/9K/RF9D9>+U>Z/5Z:#0:='5U@8X*.BH&AX;0X(W@M*`&W_3X
M\6'Y6>@8,ZXI-:CM'<8%C17\"U_"X_%@;FYNBL0^4;#C!-F!R<E)#M[9V0FE
M4L6-#H<#T6@4GKX^F`(_X>.+E\#<"N-]@HO:Y/BJ^FLH'!Y4U-1!I]-A8&``
MT]/3V-W=E13AFYN;8)7[?#YT='2@J:D)$DDSZR'<;C<Z='K<]`_C//\S,'8G
MG.Y>J(QF?/IY!;0&!@U"(60R&9Q.)W?2(IQL>9K@-M;;_OY^3K%"H8!6JX75
M:N74L!NP\\I*`7X0B2!M:2%8.QH;&U%5506CT8CV]G9$(A%00X`$%^$G:"=0
M5V!L;(RSQF0RP6`PP&PVP^5RH;N[&W*Y'$)2*)%(.*A`<!%JM1JU=75HHAQK
M"]L,Y#G(\R+\,$TT*RLK^]2W7%%:KRO1UB;C++)8+-QQ%52'YI9K8!@&M;5U
M:&UMA=UN1ZOL.NJO?LO]QXHCD?ND_/L_M2.I%Z^MK3'SZ86YLBLJ:/1&MA4]
MY"%#Q6;Z0G'O5;D)`SZ?E\U-34TQL3OCGIH.#\X++N?)#H;L95C./][&I=7-
MU[N&XKG[R22VLSO'"GG'T*AE9.P>EI>7CQ=RB=G,,5\\"5\@G"UYS;.Y_%-7
MS,$;C+WW@)0TD&6/_F%=^P?2G@.MY09^6ULOPJ,_SR?$G2[8'<YW2[\AN3V^
MR'T7"IT)L[.SU47+<GN,RQ_[-1`8%E)]GBOD;:')M$!J@$@LYI6$_Y)9X2?N
MSR`<B;Y-_G.07/[@D8:>A*51_>,:%:N\N/;!\F.3,^F%T3MW#=2"ATO"C]<[
M^*<O-2,2C?H*N;W\0;DZD()4K<?&QD9=(7]O]H'FC-B!C\Z=$Y8$LV$.3O'M
M7C_FY^>+</+[^<S2,I]N,)^^7RKD4TOK&H=_%/[;MQ\.SCXX5,@C])`]6VHM
M>[/)IB-;6UM//A3\/Q6_`VVM+6<D3TRB`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C
M;VTO,C-X,C,O.2YP;F<````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,38R-@`Q,#4Q-30S,S<V-0`P
M,C8S-3$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)344'
MU`$,#@H4V&9S;`````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!
MTMU^_````R-)1$%42,?M54U,$U$0GG:W?[2II:WI'UAK0\I/-"2&F\&#&@]$
MCQHOQ&N/QAB-1T_&1&/DXL&#\>!!!(ER,$+1F!B1&()26RV68B&HE;;;=EL*
MVW:=>70;(`0]&R=YW;?S9K[YYF=?`?[+/R4J95,NET_A>B0(`A2+1:;3:#2@
MU^N!XSBVF(-*!;(LP_KZ.JRMK4&E4F%G)I.)G@-&H_$Q[J>V@"-@=&%AH3T>
MCT,JE6*@-IL-/!X/VV^6:K4*HBA"+I=CB\@0$8?#`5U=76F[W7X>`XVJR1BC
M7UI=7?41$Y5*#3S/,X:2)`'J&6"M5F-L":A0*+``.IT.+!8+6[0G&\S>AF?'
MR(>G'TS3C6`ZBHYOC!4!$0BE72J5F",%(U`*7"?%[$A7+RWS)=L&N%JM?H`.
M9R@(&5(0`M!JM2P+/&^4AAS)AIX4E!8!DJW3Z619*/WAZV7,(*!$3;%:K<R9
M6"CEH7T^GV_46V%&C:4]V1`A`B6=(@IX!QX8*;K!8&`.5&MB3*7`"=APK`-2
M4"6P(D2,_$FGZ%E#T?$Y1DZ8S68!4Y,^?1?@VZ\5\/O]A4`@('B]7F%/LUV<
M6?P)V6)1;FUM%=QNM^!RN0JRU@BO(S'`=\GG\PE8EED$O[WCX(MBZ>+`:*CR
M<&A(3B02W8I^-AR[_';JO9Q,)D<47?QKTOOB0VSFZJT[<CJ=?K(=B]^NF)J.
M2%Z^"IT=W8/()EEO8O#^R-BUQ502_";#=<768C5?R$7"E7,GCTN8]<!V+/7F
M%TFJ].<X_L9P:(*;B\6F<78S]<;U>FQFK==B_H%E*BKVJ6SA['CXR^'YI<4J
MEG5B5^8(WG30;=-93_<E`VUMDXH^')F'HH:#_4['W9Z>GEE%WVPR0%]WY^2!
MEI;QG4J\A?GPFQFX%WH)V6QV'AO[:F/T:B>65H2C@V,AB$:CC?'`^;[R[-U'
MZUPVXRZ*XM!.X%N8&_3XT0@9<!UJ;^@X3CV6+X@W?4[3$:?#\3D8#-;OHG*)
MDR5Y+\_MP]Y8=KT52?!NZ<1;L1=G=AEG^^F?KE3\L/KQ"F@B6^S/\O\_F;^2
MW[$YEK:%FEIM`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H
M97)D;W1C;VTO,C-X,C,O;F$N<&YG````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C(P,``Q,#4Q-30S
M,S<V-0`P,C8U-C0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@*M2@````
M!W1)344'U`$,#@HI@`X_?0````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+
M$@``"Q(!TMU^_```!`U)1$%42,>M54E+HUD435%=FP*A&FQL>A5PI>#"A1AP
MX4YZFUJYD<)::*`W(HJB/R"X$"6"43?.L_)IQ%EQUG*,\SQ/X)C$*6K4V^<\
M.E*TD;;!#SZ^X;UW[KWGG/N>3O?&:W-S\\O.SLZ?^_O[7W3O??7W]QL&!@9D
M<'#0\"Z`,S,S?QP?'_N+R&_CX^/&RLI*:6EI,?+[^OK:?WEY6>_Q>'[]3Z"+
MBPL_W*;+RTN]]]_4U)1]965E^.'A8?SL[$Q:6UME>WM;'A\?QT]/3X='1D8$
M8V;.Y;JKJRL3@OJ]`-_=W=4O+B[*Z.CHC\G)R4]/3T\Q`'*"!CDZ.I*]O3T9
M'AX6!!2`R/S\O'1W=POFF>UV^Z<?N.;FYH0X+\#7UM8^V&RVK^WM[2>@P`U`
M#P$;&AJDIJ9&ZNKJ)#<W5XJ*BF1H:$CJZ^N]@3RHSDW*`+[B=KM_?Y4>9*0A
M<^GKZU.@Q<7%"JBCHT/:VMK4[0W4T],CX)TZ")):<#J=H:]QKMW<W-@1V3DV
M-B86BT7*R\L5%?R>F)@0!N43#$AO;Z^4E95)55652@*<.['V^\;&AK\O6I9@
M-Y:FJ,C/SU<9$XQ",@!!:4?24EU=K3@G3=!)T`=J;'5U=>D%^.WM[3=RS(PR
M,S,E+2U-(B,CA8Z(C8T53=,D.SM;2DI*I+"P4(*#@X4\0R<U1JHX=WU]_=O/
M=!C@9P.ZSPC.!.]26EHJR<G)$A(2(@D)"1(5%:5`$Q,3%5A<7)Q$1$1(?'R\
M='9V2FUMK<S.S@K7(W,CA#805P=0539+I/H4C&*EIJ9*3$R,RCHP,%"RLK(D
M*2E):1`>'B[1T=$2%A8F34U-S_31MJ2TL;%1B*MSN5P.1'/`JRXOEWEY>0K<
M9#))3DZ.!`0$2$I*BJ2GIZOQH*`@-18:&BH9&1GJ'P'I,(CN@C4=Q'VF!VW,
M#A,V$L6T6JWJ21'-9K/Z9E7DF?9$,JI"@L.&`I?(W=T=FTKOR]^6KJXNQ6E!
M08$JCP*Q7.K`CEQ86%!NFIZ>%C2:T%VDY!^?*ZLZ'`[+"W`X1<-VNG=R<J*R
MHH`L]=\^)RBK^1F8`;E5P(IV5*#Y;"3L=N'GY^>K5-Y;/BMA5K0H`=F5S<W-
MRGX4DSHQ&"C17FU[["4?`/H5$T\J*BK4(K:VEV?2Q&ZD>`S&_ZR0\R@D+&F#
MXS[Z!#\X.-"S;`+CW8:M5$-`)S-D!S(0@9@M&D6!HRN=]_?W&JJQ,3CF6>'O
MS[[:WP_<FO`T@1J5`:JP4V2ZB%JP%T@!]A`5$-]VSH,N']$C5F[-&-._Z22"
M2!I.(@L.!SW<8B0M2TM++MH-P2RHYIEG'!*?L87H4<DO__O(@Z`&\HV`CG<_
MH)&I86MK2PX/#_]ZZYJ_`83H3*%#H?J#`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\`````````
M`````````````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S8V`#`R-30V-P`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T
M8V]M+S,R>#,R+S`N<&YG````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(T-#4`,3`U,34T,S,W-C8`
M,#(V,S0Q`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!
M``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\
M```$MTE$0518P]677TS35Q3',=G#?%KVY!(S7R:)B<'LSX,Q/K#%N&BF:$*4
M*?JP"%-'"#@L6XA_.T19;`)5YIQT@@PR_H.AL';5N,E(0$0-X*;#9<JRV5A)
M$TF(&CSZ.>9":W\MEF4N/!SN_=W>>\ZYYY[O]QP21"0A5/1/J?.H7+YZ7<;&
MQIZN9GVZ2XI+OI:)'</#?\G]X*S)A0@=UX>&I+JN:7)'=6.+[#[@>+KPX,%#
M<;>[Y8MO:B-U]%X9D%^'_I0;P_](?4M;^(:ER<OEH*-,&MN\PCS,Z/CXN,R=
M]X8L>GNQ)"];(0L7O:-CA(F\'1^)I=NQ9&(R,#@H??V_R>"U&SIZS_X4;@*O
M"2`_$*H(#02C]0>?Y'YFEV`P&+XA;5.FK%R[4?85E0B1YS9A&UC@:HD+DE3>
M6[E&ZAH:)GWXQ'=>D`M=LR5SV[:)'\-\N-(S7V)><[IBN<B#\K"__W%3;OWM
MU]BU><^I>ZGKTZ6@P"Z!0,`ZH]A`N,YV]<C)FF9]?`ZG9V2)W^^/_90UW]5)
MP?Y#4GK,I2-A/>P\(2;,%965L140XLV9.7K`_N41=9=,YFU0B"Q>DBQ1%335
M>^1`Z9&)^Y^L29)'HPF2NJ]07Y]LB.H![MN.?B5W`R-27EZEL-N4_K[D?[M3
M2,03C<TO\!G_?P5@JZNO7Q,(@25(+G*#WT+S(>(P;\TK`$X.D8G,\VSYFHD\
M,;P450%)!*JQW-E]44>LH@"ZC'D%Z`E.)'61V@:W'D:P/F4,RHZ7:QISP%55
MJS@`#UNS;>KZE`K(=]B3],W(^ES*GB04(_)L"ELJ``<H@;@XC#(`9<!$'*(J
M\/E\NHG-'$;9ENUY"BI&O(++V&>I`.3![R`21<PA0@B18L"(@E6KUU@KH.YD
MEAU74H906IH\<F?X)7DW^75%*%4+4$6]@M-9):<Z/%JX2)2;UUZ6M+2WQ.EX
M5?RW`\JZ,8.8==HKHZ/WU#J'H&A@G;+Y`_7JYZ[NYX,SUL^T)\K%OEZ9&7!^
MX0Z,C`05[0"VL_,7!2QSA#B;-4((+Y,=8/1?.0#_@$WXB.8`>H&CC$`Y4`\"
M>\!E[$'`,Q@_['`H"$B4N!R`@HH..O1VQ@B*<<20)M_<&L$8H,K-L8G=7BC%
MQ45:#TDN]L;M`#36ZO8H0Y'6@,F4>L2P-<:Y+66?,Z%-T+1S`"70``69)\`@
M/,,<@WPSI_I#6I`7[2$.F-YCV@X0>L,_$!H\C2&,\(V8UL-T=M`NX8=ZK?J8
MN!P@E#3IATJ/J6(,8@0',(I#5!P*!O1MF!@6II$B$L^^=UP.H`#!.`JA=&A.
MW_G)D[!N>B:<8V0/SC!2Q8@>'4]<#A!Z*!_CA)(<X';FA@AKA)JY:=HPB'%&
M'$-P`!V,T;C`TBO(FR?84O&]K-AA4X>`%=\I'V]5>&'LPUT;E/A3U[VF#2!"
M`G*6XL!>\.]RN92@K)R(RG:0#C@'"72=VYO<6JY0LG_O>NTZ&^I>T28R-WN.
MXI_&TMMQ7O)J6Z,VDU,Z`,%0$S&(UT8AQ18FVUWPIAK76EE2J$67"$`XH7NG
MC0)N`<9#%?!OCWU/HAJFY^9-#=?7>W[4:O^?%R,@-=!_Z;D)9L:4X\=A)IF_
MD1-ID`````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,2YP;F<`````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C0V,``Q,#4Q-30S,S<V-0`P,C8S,S8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A
M<F4`061O8F4@26UA9V5296%D>7')93P```3"241!5%C#[9?I2U1A%,;]-Z)`
MB+Y$U(<@(BHHVA,+6BA3L$5J3+-IT28<!L8,-<M)32JCG"S;Q;`@FTR=,DW3
M+#&)H45)HP5%#1,*.?D[P[TYN6`D?8@^O'/O?9?GG/<LSSD3)")!@X?YTM3T
M0LP)N]TN5NL>24U-]:]:=NX4B\4BSHSC@>?-(]FG\\1F=_HQSE\IDOS\"U)5
M52VA8=LD:'KH6IF[*$1.Y.1(@-B1AOY\^_9=<G-S=20YG;(A;)-JL7+5&O^N
MJ]7UTMO;*\ZB<HGW5,FK=^]EW[D;OR%B?#8\KJV5NOIG<O9BH0S9<*>D1-C@
M\7C4H%%14?*\L=&O9']_OQ04%`CFQ^)8C.LN7KI<7K]YXX>9,6N.M+>W2_+A
M%"DN+M;3)D)'9[<\>=TJ^245:@=W<;GDG+DDXW?-/P(@+J*M\3(F`*SA\_DT
M3+`"%L'A-IM-XN+BU'08@``@(-*/ILN'#Q]_(L7L/2A>KU=Z>KZH0^+C$\3M
M=NNAKJXNM3_!C47QQ]9=-B'*3("0-6&2GG5*'"F9&KD+5JR7@NNW)#DM0[W+
M.H$<&9V@[^P!V`1H^=RA=PV_6ZG(A"@N"C^6*6UM'V7=K7NZGG3S]M!0R7[J
M4W6-24O-"VEI:96.[F[!-H:-(BH;%/SON?$?`+`><&A,_#8`!\O*RC5'`<#W
MGSY]EE$!.CL[)28V5L.7)Y%(N!86%FHH,\\[\Y&;M^@(`,#O;(1'"5OBG?AG
M'L;@\-5KUW2-/;!%`$!B4IHR!I)0'P`2B<1"(PZ1`R3;['D+-9Q-`%*6U.4@
M6L!'$!E7X`"@2)P8/%GWD`?DA0G`_3$<R;3=:M<-?$--`#-'<C'/.YE+N@=<
M(>9ENQ(?_$:>DSSP0ZC[BB"`Y+KGJ323*L`+)`K&<I76:.4@"[DOW[@RX<9=
M-2`N-=@T``#I;*"R4&6B&]^J5"/[D,H\W\/&041RJKG0T.A3"Z,5A&',0RI1
M=H?\@]GX7X&_J@"Q_J#RD59;LHQ6HN)AM1@5F+HXK@J0-)`(O``_T/Y!.#PA
M'ZC-$)Z9E:6\8=1/*CC,!49S<[-6/9[D&WQB5+<A0EG@IF0R=,A!R`@@B`H`
MV`VB@O'@%-:H^B@!$S#O<KG\R3V@)&NPHD%L[/O:US>\`K06W!)S<I"GP<<H
MQ0VA65S!DS7F<0?`".0=Y:$A+(>R,`E%`.L,KBX!PNDC,2VL"BA",1M@`*`0
MMT(H@KB]T4RQSNTY@R+T1$:#Q3MGM1(-E#>4&%)0&/@6X?1$^!;MN3'^#)XR
MU>R)F,?,`*(<3XH,"M!\39@4K+6#.9HPYAB<I?>B-`RK``/S;+M?*_RK0#"'
MYNUWF(#,+3N2K8`HPHU8YYLUP*<M66T*1>D%SB.*PP6Q(.5FQ"R@3XLXF:=!
M]-+W5DL)?Y$P,41/I9B_(U9OH&5HH"DTWA]4U,KNT^?4#7R3JE00BH71XXV:
MAJ[J)A6.?^DH*5,S-X9K(%+C<KTUZB(BF.)H*$/6W"PJ%9K*)7L3M`JUMK3I
M'P>"=4P\P,T!P&R8"(U)20:9D>AM4-,3="C']PK'(:FKJU,!*$4-93^6P'(A
M>9>UJH_Y+\*OK>^OL3'8=Z,-%"9[1FKF_A>CP>,'G#^BDS84A!4`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O
M=&-O;2\S,G@S,B\Q,"YP;F<``````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-#$R`#$P-3$U-#,S-S8V
M`#`R-C0Q-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````(````"`(!@```01]2F(````$9T%-
M00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE
M/```!)Q)1$%46(7MEUM(E$$4QWWJI>>">BAZ*>@"08$8@?70%DA4%)214'33
M2@*QS*"K=L?*,KQ@%%Z*TBC3-KHHUEJV:1G$:B!M1EO;9I)8II9Y\G>6V7;=
M+;;(*.AA=KYOOIESSOSG_S]G-D)$(OR;[\&R,55N55=[7[).%DMV=K:T/'_N
M'6AO;Q?;W7M2__!1X'J?C=++UV1X3IGHP,'C^1*7D")[]AV0K6F')"(JVB)'
M,S.EXT.G!+C]7M.?KJXNN5I5(QDY!1(;MT)-V5PO975"HG?6H;INV6%URM3"
M#JEY[)3D@MLR8J_C)US\G@FK$S?+IFUI"@`M>M?A;S$4G3DGH#,_=J64VNUR
MK[96=^";P!9977?_OJ(^9\$21<_I='K-)R6G2&]OKT[P>#S2U]>GO5H`@]X^
MD:3*][*F_(U"O.I"B_R^;?ZR`1@#E6[;[LB&I!0)VP!XWK'72W-SLQS+SI7Y
M:]=+XG6[S(Q9J.CP#+>"#,`0/%JO5ZD!H(5[X$T48)^5=THJ*ZND\4ES(,PT
MT!L9O50_C!H[41>.B9RM%)PT=;HL69FH/8ZFQ,;+^9*20+8MS"J3SI[/:H1S
MRB\JT?=1<S<*?*9G'"4%8<`A^P^ZW>Z0H#D<CJ#QP3O&?]P`20SV*1O[SQX>
MA&V@L:E)C["XM%R&7'B@.J6'$Z@<M;M<KF`FFE9PKLR7.5.;/+(\+5-FS(J1
M:7,6R9:'SP2^]/1\"C:0EW]*O6$`[^E'<C7YL148R+?M!X^I'GAN:VO[QD2\
M$;;)GG`=RI+AH30Z(*OP3(]FB,IGP'AF(5[0`]N`[Q45%=KC&46B"1K/`5N(
MS'6JU1&+TS7DT?'YJD;>Z0&1<=YQ:.CN,S!M2Y&*A])A1(1X")=W$B**G;!L
M9["82(PLI#@0<LY=MR(]+J]5$PL]W#AK:Y*!PM,?)E#X0!:OA$]/N'S'"`N'
MKK\86HWHW7\PE)R9$VK\+Q73GVS_;@!H%UFAU8&)?E`"H-:A(+1^H]KFDRIU
MC@!('L@5O4-;QDS:(L514`9J(*P`*+14:Y.EN.@0`,%$-;R5R>LV"U=+GL=;
M^M.>]8'63<9Y9LS2X-$*3R'^J0"('(A-IL,Q`?%.`*=;7JOA=>G[9=^56LTY
M"9MV:Z#,V5U2)N7]$B5Q@5181X!#8"8'7;+>5&,\LW-@)Q`R)D9?M;Y5R+F\
MON@7.9P@Y9"6X`AW&-[Y;FP1(%=%4Q0"G!NHR>7T0(93GC%`(!A@]\SAK'&&
M(\Z8QAHVP3P<PP/#'>R3RD'*'$=``.1"B,1.#`J0"V,L)')*&\Y!A'DT<R0X
MQK@I@:!$$#36\MWTY-Z01V!W=6OVIG:P(TK!R5*K,IX`<QHZ95AJM1JA/'`U
M)DF#!$:?NMYH'68^N9?*P'QSF?LA!Z@`[G>=6DI9?.+1)_W/P0Z0$-\A&\Y(
M[F<='R5F1['OXFZ"XV\!]@B0[]]S'A#`NZXO6L^X76*@L;5'+'E>Y^R,=Y`!
M6N/<!(=SD,,Y?."=^7R'L&$E(HKJO.0,*2PL#%I@@L,YI,(!"H#A_E<<?Q1Q
M/C=^:]#W7\Z$@]7^!_`5VL6\7X@?!&,`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S$Q+G!N9P``````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(S-S0`,3`U,34T,S,W-C8`,#(V-#(T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W
M87)E`$%D;V)E($EM86=E4F5A9'EQR64\```$CDE$0518P^V7VTO441#'_7=Z
MZB7H(>BE0*)Z*$@C*NA^,2/,RE(Q2K2PR.Q":DKJKJ:[+KEKFM6:I8EWM-0N
M6V;D#211,T1%)C^SG'47==G*7JJ'L^?W^YTY<Y_OS(:)2)C_TI^)B0DI=%2(
M[T/RE1O2U=4E)Y/2O&134U-Z.CL[&WC?=\7VX*'L.!CKY9%77";9!38Y<")1
MX!7VZ4N_GO3V]LY+";;T)^>>16SE3^1J9KZDI&?)Z^YWXJYMD..G$N8I)R<G
M971T5#H[.R7%6JK/H8M8'@(4Q.;6MC9Q5S^3``*T=3VN46=LW7E$>GH^J@5*
MD'@A5=YY>O00YY0XJV3]YNWJRO'Q<2\;3(JK:9:9F1DQYK+[1!"6LTG)ZJ"S
MSFKA??G,_"4&8V-CDF^]+ZXJMY`;&!HR@\L9V?*DYJ7FH*.\2KK?O)7<0H=Z
M*2XU0U:M62<+&+2_ZI([><7JZXRL`GG_H4?2LZWJRM:.3O5[0TN[)N;MG$)U
MUNZC9]23/DY9.?=D:\IUE;!BY6I=/&^)BM7=K(V1^V1;Y`ZYEIXN`44Q,O9-
MHF-.JWI#0T-"Y5RP5TA#8Z-^(T78"=.B/N"@HZ-#3&&R8S,["<!>6ETGM77U
M\N?#^!<PP./46U-+FX*1<6)(#&+B+VI-DGTD%NE<9'?*V@T1\G5D1((R0!H9
M1_HV-K>*L\*;RH=CSRN>D40F+P(8D#1(06*^W257;N<J%K-(62[#"&U(9;0$
M+7P,^)!QUZI%!)/:IE:M@Q?U+7J16F%!1YU`"^SX&""!B]B-U(B],=+7UZ=%
MQ$6C/HOSR'W'9=.V7?,,!@8&M$!,(;$C(?S8:>]S^*;YXDI(55K*?8$3P77\
M06D;,*0N+CF?RO#PL#Y#LV@40$US2/S]BPD-R87"2O?B46`-#@Z)800^$W.#
MKDES(,,.D"R9!W'GX@-*%RQ84-[9%OD+J_'?5`"XH1?3!*C;8'"S+`K0:<$W
M2K+84::Y3,ZS*%4P@(;*[.%TN7R3PV\K0#U0]S14T`KA[F?/M6/3@/G&6,G(
MQG?0"D@$!@PL%!67R"\I0"%BM>GX"&$O*GLD-W/OZT(X^`N`@W2`%0JH0G/+
M[GJJ7F,V\1^9EE2`N!)3X-)J*U-+F?W`:,,4P<PI("9GT(*06/KQ@T<1E)V1
M!,50V'069DB:P_[H4POG-Q*JP%ZN`Q!"8`2NPX`I&6M-@\#]*(,0\-[C\2CV
M0X-2\$`(D(U!*,#.7?*$$)%7`0J`O%S`[204G8<=UY('7*0O8CE]`VN@P>58
MRC`&'6&`CL4=A&*UX<V>FG95##P&A(`XH0B6`<#T#5S+V%U:ZM!%EE,%)!TT
M>PX=%8O%XCV;Z\'LF9F9NKB+Y5'GDO0>WJ(S3$]/!Q^AZ3_$WVC)X)=8\E#K
MGDYIYK1;-I>O-[.@P6/T+MX_]P]J+S.=)N0JH.V@L1E#*FL;-<;^F4QOQT(F
M4=[)%V+M3\,9-#^E0$)5G9:.:66C$]]US"5N1J&;SL?ZS8R\.E?,_4/SI\'=
M\/+_UQ22`HP$N#D8FOT,C0GC_VZXU/H!8$/SU2\-594`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D
M;W1C;VTO,S)X,S(O,3(N<&YG```````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C0V-@`Q,#4Q-30S,S<V
M-@`P,C8T,C<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!
M34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')
M93P```3(241!5%C#[9?+2]11%,?]"X*@38L@B"!:U*9%M"BH121!B\+>%-+#
M,F.PIJ)1RRRSQ*B$,NQEF1*:D:-E.AHZ6HZFH^58-AC5]*`B%`I<B)SZG.'^
MFE\SAD5!5(OKW#ES[[GG]?V>8YR(Q$4N_5-=4R^7RVZ(8Y<K+#V05R"Y^86R
M9O..L"#7VRF#@X.RI:O??M_24>Z^+6<NEH@*9LR>)W,6+I/%*S9*_-*5$K?5
MX90-I6[Q-K>(=25R<2!*)_:45%1)34.+G"^]+D^?]NOW[7L/AD^=K/:HT67E
M%9+<Z)<U6;GB\_GDXZ=/T6;&-'O,!TZ=*911#Q"\L\7EZAY^VP[DG[LB1&?Y
M^F0AL`]Z'LGUFYZO<<@[7:0_(N2@B5RGWQ]64]_HE=3Z-GG]^I4*<37QR,FP
MAHR6;AD9&9&DI"1Y]OR%IHA4U=;6R8^[^3,KIK"EM5UP#'M[`@'-WY[,HS(F
M!=M2]VK2J^N:A/`U-/NT'C>G[K/V0T-#$C,1K*:[/@WGIAU9<NU&E<:<=>KB
M5:T>5_8),6&G8"P%A6T/9=K,65I)*](.RJ0I4S6BRQ(2=)_4&])/SB!'@64!
M:>#2MM9>R<G)D?3\`MG9V"$NETO6%57(!8]78P$2*-WN[FZ["R@P`ORCCB/C
M$@P&K>^`X?>G\<]1`,XIIA]60+Y!$)%O[^A44GO[[MW8*C$Q98\6%`I`.%1)
M58)/:N"["@*]C_02I<PGU4?Y&K"C*";Q&5;@$/5/.5.RR<X#^HD;Y!\%+"RT
M52):01N'0)ZI>U_[?>GK>Z**X2+(&06X"6E;"C"=B/,ZK^(O"G$#FD>V8,DJ
ME;,'L>#"YD)BY1W9Y$C50&VLO:><-7'29%F??UYFSU^D+R[)RM.,H`SZLBG8
MG9:A8.KHZ57_@J_>R/L/'Q18$*(!&7M`9@LB%R%!$+G_5I/ZO>IXH2(2LCQ:
MYM:+9A^5!2`+DX)$(%M\-PQE4%H7""HG#`\/2Y4_H/LH!?QH!*%0R':`WXPL
M<O\7P?G?,H#BI?\#/1`"9@$[@P,R,_K\<@.`*O@%Y_0Z)B3PSB@!SOE.-X;"
MG.G9BC2@_&W%_90!AA]Y@$6'@J7Q'KDA'"+!HYR'P2`?$`T%,+V-V0#`2$B+
M2TK5&[B5A_`63Z%-E-/Y&1?8.](.ZV,\CI&!QT%E1HPR]TD1^B"RR+9K>QS>
MQ0O""S/JC/*E(_"H40R=XB',R)R"K-W_0!_4_1<=?,=@'C1GB!)Z,1)R-"W*
M9@"$R`4LYG$N8HCQDLO&2Z9%'B4E]#Y2PED3#>J`15_`*5@8.<9C@)E.;`;`
M?1BP]F:S\CUK;LIN_1PW?H+,7)R@%,\>.=1O]BCE-\X@9[&?OB#>.F/VD/+`
MP$!L`V!V6!TRIB40*KR%V5<?.RU.IU,N-+:)HZ!(]U0Z.27TAVY[M1=!V-00
M7K*0,U<C9R(<M0B[GKW4?H1U3(LT.2Z1/WH3U7^IM4L?H5#I#F:"!((8`A<P
M#!HY;<K(T3,J"NZ'WJKW"^/C-<>950U"35#)**.?7ZWQZ)C*OM+MUMY'CMES
ME]$6P](K/9IW.,/(::B172O*`,*4DIEM_7=A4D(C)26$%`5X0^^,5))1WZI]
ME+29W'XK)X+_F]$?:<!GUMBJN:H`FI``````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\Q,RYP;F<`````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,3$R`#$P-3$U-#,S-S8V`#`R-C0Q-``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````(````"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T
M=V%R90!!9&]B92!);6%G95)E861Y<<EE/````]Q)1$%46,/MEUU/4UD4AOF=
M7/$+N.!&TT1"3!@3/\8I6E`TJ,21`;4ZQ$"LM5"4"I4>I5ALJU!;I7B&MF28
M$!(2\GJ>15H@!05!XQ@O=L[N/ONLSW>]:[5!4L/V5=LL+U=4.WB5+:A4*HEG
MPYZ?[#AP_RDIF4QNRKC]]U.Q!A_&=?Z/SJVK+2TMVE7&GDIRA8^:R;IZ]][5
MAZ*KKDM7=TI86?E7:VMKVMC8T*-P6+V]O0=4<?@+3V..*N6R>J[?4]V%7"ZG
M_`=7D=BL>GK#MB][E^U"-!H5H9].Y<V]?'%)Y_P#Z@\^43J=WA2SOKXNUW6%
MJUU=EVHN[FJDXR3D\_ET=&X>2@`.3DU-Z4`"4K.O5?;P1S2&'SERIK/*S!5U
MZDR?3I^^5@-:G0!06'1+&@S%!'((X\W^B*+C,Q9>DD3\EY8V[_E\)PP\-20E
MG!=*I><5&DVJ\\H#3_ND"N\7S9KQ1,9R0Q*?/<]J>B:MQL9&52KE+P<)DX>&
MAA2)1-36UB;B<N`L@'''<?3]T_@_%T#0(`<JZ<!(')^<]0JV9'E.9=[IXL6`
M]B6``H9&^7AL<L[HD&+O"`0-7-3R9P7$XW$CODS.U823-TB#/+@5^&(98*H3
M`,KF\T4K'&";>5,PZ$(SCZ..64$-O)Y;\"Q<,F[:09P4"]+1@J#^^Q.:2<VI
MY+E2K85;=T8U.#QAQ76S;T1-34U;`N[>#5JPXD[67E*Z"(,->5*5G*$D'$DH
M>.^!3IYLKZ=N4K:ZNFHFL^<Y,.!584^/5=]VKMLWD&*QF+J[NTW(=C;=MP`R
M`ZU1QLW-S?HJ*(="(7/M)ZW&7P9\-P.H92J+NE_\N&BLPQGT1671>?9"VJ$,
M6%A8L!J@\;)03*>&J7A2_IQ#1-#>Y2M!=70$ZCKX5QDP,CI64PK'PBO,BE#E
M<'C:6.^_E66+Q,B35[KQYV,;)\:>I:V)7PCTZ=BQXQ:Y?1E`"*$./&;.JL[(
M3BJGR9=OC4:9'"`W%K\Q!,6PI4T2W@C"&(*Q+)CVK_X[UIX@3>1O3]76).Q9
MR<B!T*&1*>-N&):N\F:^8-,AS6+P8<*X'I[GS!16-E<U37Q'$X&Z(=2*MUXD
MYVU>8F"'RNE>.PS`:X2AC)Y0G5L))Q2.A[0UWA-V%!(A%DJ)4/4.6&!5_REP
M5AW4P,>N!E13`,IA[C-G?[?+]`WV/%GM[;\IT-GEG?G5VMIJ3,]OB)I\<\[B
M+HJX3U.G'W.7]@*PCXP'\OF\_'Z_Y1;#4<*>UH-2WGU3(J)=\=\+[XD>31.P
ML<?[+W'#D3$:"C&$L!,)O-]KHOW5"WXH`SX!F79C/N?C9-D`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R
M9&]T8V]M+S,R>#,R+S$T+G!N9P``````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S,S,`,3`U,34T,S,W
M-C8`,#(V-#(R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G
M04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQ
MR64\```$;4E$0518P^67_T^2<1#'^R/]3_RAY=QRSBPKFN:71CF+55HR7;*<
MD?@]1"E`4#10$24%%)3,S3G=+EYG#T(@A*VMU0_G>)[G/G?WN7O?^\YK(G(M
M7_3/\O**^/PA"00"YV_?3P8DE4K)[*?0A:K9;);<D2(;T>V4M-Q[>:[A\7AE
M9'1>3&W]4E-3<ZYFM5JEX$B^V.UV*;*9W$N+[;U+>@>F9,JY*.ET2G9W]^3Z
M]1L7FKV]O7)R<B*12$3*AAF+Q8I=E)."!^>'#W*I`H&-C'HE%$GDDI!3V$FD
M)+(5EQ>O)^3+=D(VMY/".U4X.CJ2I95UZ7KR5C9C<<UXC\6AY<A9.#L[DXV-
MC9Q9A\,A%HNE^)K#P\-26UM[^36I<-EK7D5*OG2Y%K16^_MI.3C8EV>6-^);
M6)"*!L`=Z8K&DK(83LJX<T5_/WOAT+21OJY'3X2D%!B8G)P4ZY!3O2V&8^(/
M;NHS.<<H!VWOW`K*8"@J_0.S<ON.J3B+-IM-P./T]$PV_'TY/#Q4)7X#8A!'
MRU"[DE<(A\/ZH;N[6SV#'0R2?5"(08S\4A4PQF$*WM/S5*JJPF^7\>\P0-+(
M`7U>E0&PX)P/2CJ+0I!(W=O;.^7KUTQE),;C<2T?W3T]MZ;@P>##SD'M5VBH
MK`&WVZW0A19<WDV%-0T.*H$RD;6VMLKQ\7$AD$`>RK``!T*K6PI;(#TVY=$H
M]K*1?5[?SD:XISUB`$H-@'FL&]R#Q\7@JE['('98E2O!K,_[)J2AH>'"`#U`
MLN9]J_H15DMFVQD:PJCQ#B=$-#`PI#U1D`.,\(%&8230LJ>GIQH!5X#'Z`F#
MRTHFD8YK:FJ21"*A2B3+Z#R7:TYQ0>B034D#\`(">.KJZ@22)%E$P&\<&,8K
M(I%K$#8'D:JAC&=P0<CY!%)5,Y7S_/>T\_\3`(6D,QAP!FNPO-`1-``[227N
MNE(`F4Q&T41KT@"0`FP#ZX2SY$#[\LWG7U?:>MPS*/7U]47CZTH!T'T8-SB2
M&S.QH;J1,;^RUK?#C+X?GUG2"<Z6!)>RX[1W]BF'_KR871H`K<]MF:?P!K=E
MTGN#&^)>6%,:9'5ETT)X)A`<O[).R-:7'0V420")(3`E)8)R&:^4JN1@I[Y0
MZ,3<DHR,?U3NA2%94,/K6SI22+O-[E&NAA5YE_ZQ`.&43""<@Y*A7DK(=TK$
M2G+O?KO25%$`<!BIIJYP^D'F0`?"S.RRV,=\RN>,)8(A[3@T^)XR@05#!RP@
M!('PCHQAZ^[=!TJX)4M`:D@_E,T@I7Z,,#8R#C8WWQ:3R22L/CRWM+0HV?+<
MV-BD9UK;S"HW&V[I=_1)/=_0BT:CE<F8>N$8'H7!`1'/B+%_E1+:$'W.0:-<
M"(=DERF0OU;^$IEW='2H<S)AC!D$H-(A``I'!&P81Y]S"+5FHO".`!B0O\V$
M@)7@Z'6"(@A&%[\))%\7WH`/RA%45<ZY`3A`^&_$V%R-%?CG8?O'9@%43`!D
M@9H#-((HE>)_9QC]*?D../F$_62!OKT`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,34N<&YG````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,3<W-P`Q,#4Q-30S,S<V-@`P,C8T,S8`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F
M='=A<F4`061O8F4@26UA9V5296%D>7')93P```.1241!5%C#[99'2V59%(7K
M[SEWY-")(P450<PH!G!@3IBS8@Z(@EDQBQ%S%@/F@#FLXMOTLWUE:KNDF@:%
MR[OW>/8Y:Z>UUP])/YX_3R_KZ^MZ6HB(B%!=79WN[NZ<MSN9?+RPN+@HIX7+
MRTN]:O+J$8^/C^KIZ=':VIK2T],5$A*BSLY.'1\?_[WSX>%!)24E&AH:TN#@
MH#P\/#YQQ==M`$=#0X->;`!]7U^?1D9&E)B8J.WM;6UL;,C)S8F)"5NXNKK2
M[>VM2DM+G;Q0?7V]+186%LK;VUOO@MS?W]?7N?G'#["Z(VQ$HJ6E1=W=W8J-
MC55F9J:(\^'AH>;GYY6;F^N<Z_O[>S4U-:F@H.!I<W-SLQ4'E9.=G:WKZVLK
MF.3D9$5'1[]:+"(GY"(L+$Q^?G[V#9JVMC9E9679P>_&`(/S\W.YN;G)U=75
M##C`Q<5%C8V-'Q_PGV?A^X!?TGES<Z/IZ>D7J7OS`(SH=JJ2JLO/SU='1X>F
MIJ;LFS(O*BK2[NZN'>[4\!BEI*2HO+S<V`$N[>WMU>SLK&)B8JP_TM+2='%Q
MH>#@X!?]KM/34RO=A(0$XQMN'!\?MYJ'0:C&HZ,C!00$*"@H2#4U-2][86%A
M065E9=K9V9&#P,?&QJPW@'QR<F*]45%1\2;CV`:Z#_\=`:0WX'9W=W=]&$1\
M]/'Q,9_A=Z`#>W5U57%Q<3HX.'BWF0P!D<:(`!)<2(5XQ,?'ZU\5$C'@E_1]
M-]/7/]\`_C\`:#":"DJ#:&"KZNIJ)24E69O3O<S.O[C3&I)W^*._O]\Z^MG?
MVYV,$1=!"=#BYN;FDSQP_!]Y@%8:&!A03DZ.:2:D87M[N[R\O#0Y.6G\`WWL
M[>W9]_#PL*DS3T]/)X)_%0!>@APJ06O-S<TI/#S<C$='1TUNP,F!@8'JZNI2
M5%24#7VD2%55E3$G#\,!-EU963'Z1>3"Z>Q]+P5V.8P*:G[]_?T-/<:.T!(E
M1#R<Y^OKJ]345%/01(P]/*VMK<;`1`)MA";Z5`W`O,O+RY8.+CP[.[-PSLS,
M6%18<X#!8^8)Z4"],90`Q*!ZKJ(_-90=AU-`>%9966F'1D9&JK:VUL*]M;5E
M`PM`R$G"#>"\O#PM+2U9L?[CH?Y:.@!"U>,5.2XN+K;+48IT`.D"))Y2>$Q+
MZB4C(\,`HV,=T^2WVI#"))=T!H5(1'[=@Z!`0/`>&AKJ)!Z^F?`;P%O/3Z5H
M=A*ZS:EQ`````$E%3D2N0F""`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,38N
M<&YG```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C0W-0`Q,#4Q-30S,S<V-@`P,C8T,S,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET
M15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```3/241!5%C#U9=M
M3Y)A%,?]DGX*W_BN^<9R%IE:81M-BE)RN=&#31>YR$'VP*(&4T@#"C,J(LTH
M`T2GGOP=O7CP!K*G96X7%]SW=9W'__F?8XN(M%0O_5A:^2I;6UO2T=&Q^]1F
ML\GX^(0XG<[=!]O;FU)SQ2+C6?2UW+K]1$^U!(-!&1@X)_:!04FE4A6AH5!(
M+#)F8\\EGG@E%IEW_,_D^H1_9SV0W&I>L+-0VI"^/OON*?1X/!Z]:7;TQN/Q
M6A-QA/W3RDIC/^KZQ2H6BU(L%L3E<DG=`_E"4<;O!,5[+RQ.E[>B(IU.2RR1
M5JN]OI`4=B2->*8D%'Y9B8/#X9#N[A/B.#\H0T/#TM-S1GP^7^6`<2V93$I[
M>[MDLUGQ>KVUD<1O=A+9U=5E=1,U)FCF\('B<.`XF;6Z^DUSM9HORNNWR_(P
M-*<>G[]P3?"AH8!P."R)1$(BL06]-'XW))>N3"JPW%=]0B(^+'^1-^^7!3=,
M6LM@2"Z\DWRQ)#Y_6"_PNU0J26EM3::#,;$[;LAINT=S@.#>7KL5CS,S,S(]
M/:V6@%[SG30@B!P5"K5PJ!'`@?T^8OKFYJ:NO;^6N;FYQED@4"0Y$`B4R^;4
MJ5X!4B@`!$VS\-MI/!P"\#?W):>`@I,V-C;DP`*BT:B`1FJ0A1#RW]G9J2EL
M*H"H0SMO,I\E\#BN8$(`%3[IC\A9NULRF8PU"R#.7`Y&XGH8M!EZR"ZMR/KZ
MN@J^>7-"TPD^R@(BLPGED^C\@FI-I3^*K6]$:82+6,$[8`[W`'5<*@N@\EXN
M?M"J0Q"XA\/QF<M<Z#L[JG7`.P3!SQ4!.T%SN]TR.CJJ9`'RP#NFPE-0,.S.
M)=[3.BQ!'!L;T^(A"Z:\*2),11C!HVI),0HM`CC(,J3!/C4UI3C8JPGI[^]7
MH0BJET8M(A-=EBD<>H'I:]656!=(<,(^+6H)SV#<'R*1(.$G@>2W<8'`5=-U
M0P%<)J#LQH*VMC:UXG"6\S\Q`$P15\+":D87?\0`@/LX^%3\CZ*2^_I-H08!
M4)>4822V*!<OW1#:KZ&C/V(`.)Y/I%01<P7[J_0G\05FM6%>O_50(!)8:.;%
M6ZWWH]V7M=Y/]K@4>?MQ?V`#8&2\@9E@J.1B5I4P!MX/[E(>!$3[)S+0'F2#
M@9FEG'9PG@\Z+Y>'$9BMJ0&$V;1_6"P4>:'S(8(P`H9'"50)WQ)ZH@&[4>TH
M(#6D`,,Y3\KR^8)R,?Q\Y$B'DI[%`"H?;U#`*,$D@"=XC/=0+>]8<#,DCV`H
M%QQP!D,99J%?C.2[X7&>$26FO[KS&X+@,L9E!B06AMR>?*K>DM=C)X:4[S$,
M8\$(N##AYAR*C]N&51G/6$S:8(5NU-K:J@-T0PPPPG"`4H/2Z0$81XB)"CNE
M!SY@9UB+Z$%Y@`X6!WC<A<W@5GYSMCKT3>=+!C,NLQ,NC##DC&`&:GH,XY/Y
MSX/H5;<)2A7%&(!BT^#H64T-P$,60D$O'II9M'JAG/[%.Q1C&`"LGG?I(`"3
M'3D_58:DPK0?HH)`PJ[3QTZ)UFLBI('4L?`6D/XV$P(TK&<VP&L6OTWKY\-T
M;V9I\()R<$0*]\;B7S>`**",,))GAI=ZXR(YQS#21LY1CD'UR.>O=$,\-O.\
MB=)_T8Z_`P3>G$`[&69S`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\S,G@S,B\Q-RYP;F<`````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-#0V`#$P
M-3$U-#,S-S8V`#`R-C0S,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````(````"`(!@```01]
M2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G
M95)E861Y<<EE/```!+A)1$%46,/5E^UKU648QQ=$V#^@0=2;$@+1%_9"I!<;
M1+&,S!BU3`M"9^I8/LSEXT!/<V[H(7?<RH=SFMO2VF/3=IAG.D&=@@\SM2U,
M6F"+ZM!I'&@P,M:W?2ZYMQW/PSP3#5]<NW^_W[GOZ_K>UWU]O]>]#$D9X\W^
M5/@J=>7[&QH:&KK]=>7:+2K_9*]&9_3W_Z*_HX^,?8CS<;WOIKYH:!F;<:CY
MB(JW>V]_N'7K'P6#;?IX?WV\CTM7>L7ROO[?U-C:%COAA<R7M,-;J>:V#O$<
M$W1X>%A//OV,9LV>HZP7LS5CUO,VQH4H7/.^$L).9:,/O;T]ZNZYKMX;?38>
M[^R,#0%J$MAQXHQ(59P'DM':WJ'5ZSV*1J.Q$W(7YVG>@G>TM72WR#R[B9G`
M![8V_;F99EFOO*Z&IJ8Q#"M'XF(7SSVNO.7+1W^,P7#UPK-*N<W)6L*/'*@[
MV)]_#5ON@J%3!B_GK47:N+E$D4@D<44QX9O0"9T\=UZUAYOL\'E_;^F'"H?#
MJ8^2!9NVE:GBLX"-I'67[X!<F@_6U*1V0(J)Q`+/SCT&ETKF;'"(S9F;J:0.
M6AI#VEZQQ_;_8]]/JCX\T]B3XRFUTZ<:DB(X5-.JHLI/]6=D0(%`P!8N7O2R
MUG^^3A3B@>:O'^`Q_O\.X-;9R]>L@#!4@J*B-OAM?#W$+>:L.07(Z2J1Y\*B
MCZP2.6(**ZD#B@A6$[GK?+>-1,4!<IER"\@3FD@$:K^^*6B+,:)/F(.J_7XK
M8Q;X:[\T'E#>RPHV&/0)'5#OJ"?ENV1%D:K\M;:8YSM+.*$#>(`3A(O%=`4(
MY<A$'I(Z0">9Q&06XXS(D(H15&B9T],X!S`/?8>1..(9(400:0:F^R,.LE][
M([$#^DY>U3X39?2WM26D/_H?55;F4\90V`FIDF[!YZM3;7O(&A<-[.8/4Y2;
M.UL[RZ8J_'O$5#=E$O./=FAP\"^K`18AT7Y_G>:_^ZJA.CU2QG?%!:)WMD]7
M]^5+>CCH_,`!#`Q$C>T0%GF`L-061IZ[NL[:-U+(R5,=</2>`*`_@;H&"\CE
M`'E!HYPA.4@/AGHX.<+@,QS?Y?4:2`HE+0!(4.D.K^W.!<`Q0)QH\LZN,8)!
MJOQ5A?)X2E1>7FK]D.*"!VD#0,8@EBG42%D3S+5ZS*DUP=DM;9\UXR]!DZX!
MG"`#-&2.@(#H#,\$Y)UGNC^BA1)R/02`NWM,&@"I=_J#H*'3!"(([YB[>KB;
M':)'^I'>1/>8M`"0RK**O69H.@$)`@""`HB.0\-`OIT2H\(+E^9;)NX\[[0`
MD'J<$!R'[`Z9XYPY$M[=G0EP[AM@&%E']@"8%@!2C^03G%0"A-VY'6)\(]4\
MNTL;54]P1H!A`,`'8S(M2(@*\>8(EAS\2MEKB@S0JH)-]CY_V0=&+X*]O66A
MJO<]IIPWGU!.\3:[!%*`K*4Y,!?^<]=#H!*!2*IVB`X\APG<.E>T!*U=X61K
M\5S].YBA8T>GV"5R=<$TXS\72YBQKOY(TLODA`!0,7HB`4'M'-)L43(7G%[I
MVUUB39<,(#C(LYL[:1:P"S@^W@'_]KC`U353[4R=UC>&CMMXWYL1E.KY[MN[
M%IB'IAW_!_A[F:WC0:;M`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S$X
M+G!N9P``````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(T-S``,3`U,34T,S,W-C8`,#(V-#,P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9
M=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```$RDE$0518P^V6
M[V^3513']\YW_@'&EYJ0F/""&`P!8C3@_!$UP2`8MV1+1,3J8K(XRR"BXY=4
M4&/%*1(G`9G+"*C;',[&):Q.:VB8@W7M*M/1='5-%=`MQD;S=9]3[K.651P8
M#5%?W#Y/SW/.N=]S[CG?<RLD510O^UGSY#/J.AJ2)_`]W:0W]K6)IPE6CZ2U
M==LVI5*I4GO/Y./>L.Y=_4C!1UW]>C4\OU/+[J]6Y5WW%-32Z;3>CR5F=BE>
M0T-#FN5S5_,^!=_:KTT[@K9&1T?5%3JFVK5U!:U0**0%J9\,//""Z9RFIJ;*
MPRP+>\X*]8U-^D.%`^T?:N^!0X9CWOR%*E'H[.[1L?Z()?/+XU&+``-3.'?N
MO(5(ZO"`$N]DD'`KKAO/BS`/MKZG9=_^H+YP6$]LWJIK,K_-9#(2B2@0".C9
MV&F+OSZP4_E\7I<?YI6LLD+R14UPL/W1`5%CF4Q&?^K@Y*F890)CGKO?;E5O
MW^=:65.G(]V]ECZ<E:UBBHZTM;0>,<.G-FY7?^2XXHD1,][\TAXK2N=DR>V5
MA30[3_$?)[7CFW&]&GS-*NJ.\4E[9Y%^9#6UM5I\Z".]_N9>=71TS&29U`\,
M#LJ?RHF#C4:C5IX\*4D<M+2T:&QL3)PKQW;)).9R.4\!!^X=R/_,,5X=#L@T
M'7'9#NB[5YK?471@4!06=;&I:8OFY(#&Q>!P9X]5(DU+)<*,B^Y<6=91R1\@
M4\94FROC%X-[M+;^.7N'W\H2'X:P0NOA3K5_<-2<4/\&_P(1$@[?0>E;WV1]
M[SD`*HOXJ7MVQ!%&7YT<+I#[M%'CEI<-Q0/5ZZRL/0<(^$##L#/QD@?@XPB.
M0E:]KL'>624.6'"4W^\W:KK^BX2]D[0;$Q,V%@B31N(=?G/\8,:/IL^:@%CI
M0GH!\J.A&"4DC@WXOO'TN!Y<M:JTF6#-VY(3YIE.^VSR9[W;%[;N^W5:`2.:
MBJ%!+HJ;S0L!%H4\&(`.@4/&^XK,I+5\;#BN2U9B-IOU%(!?W.*.JO]E[?S?
M`4`-TM`4-(U.V_&?'D9&A?PM`.AGYAC$0%M""/0VK<KB/_,/,,Q"9A^CC![X
MRP#8&))A`R).)I-&M+PCY[*#C,T9S.A#.(Y3;EYTJ\W0.0.`XC"`C-W]@HU<
MI(ZP8#L6[T0-F;$Y0&/QI-QQN9L8]TG\<53,[;(`B(8H2"]G;,0^?=]C4^<8
MAT0(&\*4R,@(&\(07(3X#V!\.1T8!K^P*5<2*&O6_0WFQ`#$;(XA0!@(1(DQ
MB_3#,&Q*^JD19!0C>J2>.F#!>P#!#CG@86.HW%TR2HX`5(!8^%B='O9OL#-D
M<>MEW;3\;BU?\[A%@=P]F17(G:Y[S@\$M:!YOZ?+YC`Y]RQW%-[F$[_D=6::
M1P&QX6";&:"(//9=U@QV?_*I@<-)5WI";6<R@GN1+WFHRB)#%SE9X0*'C.]<
M_"XF\A(`-2?B6MK0*)_/9],@>P$,]VXBP1&3`2!\;Q\>*=%'%QL`5+ZPRT!R
M1`1%;9!1="^^*,]J"^87LXU-G0&.Z&OF'-.6:+D<,./XCLTM)[XV&R8R,O3)
MT@W=8=U7566%>$5$5)4Z:Z.<%BH>I%R%`4-FBF^P/>>G=&WB>ZL)KL?_#Z.K
M'L#O+J+358IRUM(`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K
M+W=E871H97)D;W1C;VTO,S)X,S(O,3DN<&YG````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C4P,@`Q
M,#4Q-30S,S<V-@`P,C8T,C4`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$
M?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA
M9V5296%D>7')93P```34241!5%C#[9?_:]55&,<__T3^)(5%4+^5$"1"B!%!
M!?5#45#X0R2D(8J1Y30<.9UZO3IOFVWJ%;=QG7?L;K9EKCO<%[?IW29NN<EJ
M:].!HYO.NSO*"QN,I\_K?3G7ZRP)E/"'_?#<<\YSSGD^YSSG>;^?YWIFYN6+
M?E:]\K(M?_$%&QX>-&]V=M:>?^Y9^^C]=ZVXL""[;&YNSC*9C,2[ST;_Y1YM
MF4FGK:^OQ[S6YOTV.79*LFWKEKO[:?G`?3;^\5R#EYNL+5YE3SVYU)YY>IEE
M9@8M=*A$XLW/S]N1[\KL6%F)E1_<:V7!/7:T](!5ABLL4EWY'S_Q<`LX0R+1
M)<=Q\>:SW]O;;[UA.&1H:,B\KO/M5E$:L-'A#N,V/]0?-KS-3?"65UH:,KP5
MW%E@IVMWJ[]RQ4MJ*T\<-Z^A(:9K<CVDO"2@*T<CU<:<#H)+<:]KG:LYW\-?
M\_\QD$JEK/_2.>ON;+-8](2-C?3KT7$=P77GSVN*)01?,VYO;S<9X++'CQVU
M*Y=JK/Q0D5PY>K71EBQY0CH,)#HC%BS>:BUGRRRT;Y=EIL_+&$;D0=XBN#^@
MR8-[=NI-BK9MML(OUDOH@XC`KD+-:XV_ON9D)'N/D9%?92T>CUM=;51O1"@2
MDCQFI"JL%GVLKLX:3S=H[<3$A#TFK[!HP+R)ZZ/&4^[87J"GN7"A0RU(!]6I
MVS>L/E8C^(%TT/_Z:ZNSD0CTTJG?%'F$*&">OO6+U4:CTE_L;+)75Z^T<_%Z
M^VKS!NN]V*S-!*`,))-)2]_JDP%H@M!E3%320@#H(Y4!12)AC<'Q\7%AWDLD
M$C9SLS5KP(]Q,;,_YFNT<)#8U)^#]9T!PA@C'B'<VWE$0MQ_ONYC`>KVC9C(
M"Q#1/U6UW39\MLZJPU]+#TT)3,0T7,61$8"T;\>6')`<F-`[,`$D#`P,#&2!
M!)S#%8<EW!F.=SQ/"]=7A(*:!V0X&'")=^%6.D+C3V>$-%`GY/GD`A+I@U*D
MJ:E12.SN[KZ;GURR<K*081?J$?8L@NG1R.(![AE,3DXJ:R`$._%*G(NR?'I"
MCXXP!,>,B7_&)%?HBLH)D&"+-<0]\>_L(B`PQT;\4$6@N//7[^(^TAG9F?&G
M:S\4!_R1'-,88L&`FX=\VEI_5!_042'1!_8(X'1[60>O8H\+Y0[`+2'9]-05
M55$P&RB&!JD/83'*!.:I%:&$H9];-.9`;BVZ3]9\H!(-KL$C>`!.9AX>Q@-\
M+U<^\0,?L3A]LTOE!`<0#T_WZ`#<DG*#>0X`V;&.,0>`>A%(CPNPK[AHHSX(
MGT'!Z&#1HF\*]6Q\4R4BKD=!>9))M=AT\HR%R[_4!QCS!&29COBW&C,7.K!)
M?70<SLVAAZY=GWT\`U2/CCQ`VB-&\(2J>0Y`8.%63L<'<:,31^?<FI9_#MP,
M-Y,[W!P>>.^=-S7'&HHO/H;PYNAH&;M`A9!%Q'1("4Q`^PA/X.KB7$'F)R?R
MBLLY3A@S3SY2*O'W8H-:.E>?^6F$+*B:S1_35SXB!H`+SX!;F&`!XO(4AO1?
MQ#=,;E+.RON(T[O#TW=[\@\`M)V0RJD'<C!TJ6=J:NH>`<\LY)`(\'$8IT\P
M+=3GS[,7.ZY%X`R>_H%_(IA$7/_?]`O[^;H'V5G,!8_-`?X&W&<(((<3Q.\`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\R
M+G!N9P```````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R-#0W`#$P-3$U-#,S-S8U`#`R-C,T-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````(````"`(!@```01]2F(````$9T%-00``UMC43U@R````
M&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```!+E)1$%46,/M
ME]E+E&$4QOTWBJ"++BN*@KI(J&A7*FBA3"G2B"G-;'&A)F/:3+%L46.21I-$
M$:W0B\R%M$S3J2Q1E*%%22,310L+"CGY.\/[Y>22DG017;SS?=^[/.]9GW/&
M3T3\A@_KI:FY6:R)XW:[1!TZ)(F)B=Y5F\TF#,?%2[[GK2.ISBR)LSN\&#?S
M[DAV=K;4U-3*^J`P\9N[8;,L61$H5]+3Q>?:L8;^?/OV79Q.IPZ'PR';@G:H
M%`$;-GEWY=4^DX&!`7'<*9/HLAIY]>Z]''$53.**J=GPI-XM3Y^]D!NW"F7$
MAGLE)>)VNZ6TM%0-&AH:*B\;&[U"#@X.JJ4P/Q;'8BZ72U:N7BNOW[SQPLR9
MOU`Z.SOES-D$*2HJTM,60D]OO[A?MTO.O6JU0U;1`TG+R).I4_./`(B+_5'1
M,B$`K.'Q>"0U-4V=CD5P>&Q<G$1&1JKI,``!0$!@S@\?NGXB<=/#ZL?RZ=-G
M=4AT=(R:ET-]?7V2D)`@!#<6Q1^[#\0*468!!&X*DJ2K&7+B7(I&[K*`K9)3
M4"QGSU]4[[).(._:%Z/O[`'8`FCK[E%=@TL>*3(ABHN"+UR1CHXNV5)<KNNX
M:H0-KC[WJ/?-I*VN2=K:VJ6GOU^PC;%12'6#@O\]-_X#`%&Q)S4F)@W`P<K*
M*LU1`/#]QX_=,BY`3V^OA$=$:/CR)!*3DY.EL+!00YEYWIDGK!D^`/B=C80O
M84N\LXGYW-Q</9R?GZ]K[($M?`".GSJOC,%-B`\`B41B(1&'R`&^%_LOUW"V
M`$@D4K>BHD*E@(\@,E0@.P'EQNDS9^D>\H"\L`#0'\.13'NC[+J!;T`9S)%<
MS/,>?N28IKN/"N&MG4I\\!MY3O*T>M[*^JP\X0*2JZRTVDHJ'R^0*!@KI;Q.
M*P=9B+Y\X\J8@A(U("XU;.H#P.U8FLI"E=G?^%9O-=G'K<SS/6H<A)Q)M!8:
M&CUJ8:2",,P\I++''B__8#;^%^"O"D"L4_M(71H`6HG*1[5B*C`<,*4"D#20
M"+P`/]#^03@\(1^HS5R><OFR\H:IGU1PF`N,EI86Q>%)0B*HJ6XC+F4!3<ED
MZ)!R"1D!!%$!`+M!5#`>G,(:51\A8`+F66<O0K(&CB$V]GWY^G5T`6@MT!(I
M.<@3Z>%CF!`-H5E<P1,&05C<`3`7\LY%T!"60QB8!(6PSO#JXG,YC2:F!0A0
M+L5L@`&`0&BEM#5T$=J;9HIUM.<,<_1$IL'BG;,[P_9I>4.($06%@6^A=#I\
M?(OT:(P_::H,I3-O*I89%!D$8-^T&3.U=C!'$S9OD;_.<Y;>"YQ1!6!@GK"*
M>N%?!1=SR/]HO`7(X35)J0J*(&C$.M_L9WWVJHWZS4"!I8XDQ4%!K$>Y&3,+
MZ--"KF6J&ZA'E!*"#A-#]%0*?UN$:J!E:*@I-.\/*^OEH-.E;N";5*6"4"Q,
MCS=N&J;4-.GE^)>.DC*U8'NP!B(U[GI5G17!%$<C#%ES]W:YT%2N.ARC5:B]
MK4-<]\LU6"?$`V@.`&;#1$A,2C+(C&-5#6IZ`@SA^%X7?UK_`'$>H:BA[,<2
M6"XP,U>[_@G_1?BU]?TU-H;[;KR!P&0/`OTO1K\;/P`H0J*N_`#'40````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S,R>#,R+S(P+G!N9P``````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(R,3,`
M,3`U,34T,S,W-C8`,#(V-#$T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````@````(`@&```!
M!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM
M86=E4F5A9'EQR64\```$'4E$0518P^V7W4^45Q#&]__SJM&;WG"AB1<V36N,
M30P8:VT,K1A4("($95<T0C&42ENMUOB!("S[P>?"=A=?NBSLLJX04@@EP./^
M9CUO,39R86-,Y4UFS]><F3ES9IXS&Y`4V$[V\\N=N^KJ[E$D&E5@<W-3K:'K
MRN?S*A8+K[/[6]X^X7DSBD0B:FMK4Q2A.VYY@P$S!@8&-)TOFCE7VZ[)6WBN
MJN.GU-?77[9S>GI:\7A<DY.32B022J?3&A\?M_F=5?PW#+.SL\*!/3__*L;7
M;G;)9R@6BZJ]4*???G^@4]5UJC[;J(K]7^J'SFZMK:TIL+2T9%[B!'-S<\94
M6,CK2NB&<KF<`HN+BW:DB8D)34U-&<&<3";%YO=PS/<C@/O$)=<[.G6FO4=?
M5-:8%QKOAW7^Q[OZ_%BU&KIN:>^!(TJ5-N!2]I@`-HZ.CEK$U-75ZU)3J_Y(
M>Q8UM>>;K/WZFQIYS](Z=/A$:<^6W06>75Y>E@G`I0@9&1FQ!:*8N50J92X?
M&QNSM:&A(3U^W&MAR+P)P)1L-FOW,SP\;$SA<%B#@X-&]+'.$>F!$A28@`_C
M%G8%_#,@JZ%,)FNI%FSOM"MF#53;GNFO"5A?7[=0?K*RI8K/JDI)W6C]/7OW
M*[RATKTGK"42"75X?0$,B"J"Y/G?6^H/QRR<^1X^?&1MS=EZQ9.>0<OA(Y4V
M#^:9`#HN^O@N7FPU,.=[!5*6$R`+:'K[SCT_W(GBP,K*BFT`<F:\9P96A'4P
M&+(7`3@F%V+1N.;GLK8>B\4L-S8V-LJ0R&8F2"A@&:M()(=?"`"Z.2;)A$-]
M"_`!GG89"2/X[@"0/FL0ICOLSV0R90%D%!K1@F3\X;+09:7+1,9D+()]"W9S
MX=T%[!KP_S4`[&M.%GUJB'OV0L_/YW3Z4DC!/U=MGK:JY8:>#@P9.G5TWM2Y
MWG%=\?XRHE_?%-1;#0`."H6"I3N92D8#?90!*/ON^UK#$-:8SY7FO_JVUBJ!
M<XW->O%J#&P^2*34/[-@51C&,/_IP:-6#8`&P`G(Z)<6=(`3JC%PQD$KPODB
MT6';?/+T!0/TELLAFZ>2`UI!33YX,/3%8M%*DT_V53C,-EAFG8H"XJ"@L$$1
MKPEP##,&`(;@ES.`(BEXM?PT0923[!D=FS!\=X^&JSMO_=1M8^HA#.+#4-X$
MY+M*$Z@W.'=H#,*R`")S!5B*Y1!>81T`!?[M'T#),]P[?.%P&=XA#L*8"L[]
M]8`8<P4\&R`Y7C</8`4#O,`"BG"1LQ:4YTU!,&,\Y`HY^CQ.$/$!L<8>6L;4
M8AP(@I]]R":8S0!^"`JL1\'V)\4]*[3,H<@I=0H=/X2R?YN''Z-0[`I\%XA^
M.C#`&]ROJS*V$T'C"(_M1/"MKJZ^(0="OI\%NTCXT1OP$E8<O)S]V'FM````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O
M,C$N<&YG```````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C(R,0`Q,#4Q-30S,S<V-@`P,C8T,30`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@``
M`!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```0C241!5%C#
M[9;?3U17$,?Y?_K8!WTQ3=K$!TVL]J7&UM0836H,Z@.-%1<1J8*5$G5Q#0CK
MP@)9T$5:*F2UBB2B;#5(BC^P!<7P0RU(L!$4(7[E,YMSX59,3.3!F'V8/7O/
MF9G[/7-GOC,9DC+FB_TD$BUB_;VQ+K4;CY1H?&Q4M[N3?G7/Q+=Q[5I2]_IZ
M]5MCC?"5<2`G2\'#A8K7114)E[V#CP45,'WP=[.F)[JT:<,Z6WNZ$W,N8\&`
MVB,!M89S3-HJ\]0:+=#E\XUZMU>\OT)'QU7U]_?KUX:H"4$D$)["7]<;]-6:
M5<K/SM3HR+_Z;-E2M9X[J9F9F53HN1JRXO,E>C(RJ$13RHMY:+UXWJ[HKGGQ
M9+Y=\VS%`2WB+=Y'%L]!K+9<.[=O5$-]B;Y9][6MDZ,MEE1[`KLLC,FVX[IW
M*Z:5*Y:;6!@Q)F%1VO3M:H6*\RR<TJB2[6=UXEBA0C]GJ7!?MGV'^[V=6OKI
M)_82ST%/SQU%@ON5MVVM&D/9.IBUWB19G:NCN]:;\,QY*"_3D.+PQ?/G*0=/
MQ\?MP\7+BU)2^I-.A?:*-$7J@[O55)IKPO=KK@U9W7Q@7R'M0!E4\O_7KAN=
M&AX>MNKFF7SA/T(2^1%,)\V`]*7J6>.Q_9J<F+"T?3)0YZ4SS]&JJCD'>(/L
M+OU1KY&AJT9X9-NK%]V6,+&:2JL-TIUS4IST]QS`R.0^.3[YWS]6#RBQ=R1G
MLW=6=C1?%YI/&P*8QAR0SQRPH@PGX1V#0X7Y]E8Z`X:<#PWTF3'Q,`?`A_HI
ME-K#.ZQH*)[ZHBW&8ZZP.'<KU_,0O)R:,LCGRO=XY#>?YR%!Q_>.\RDF7PR(
M/HW,52.5Z*J12J3$726V5!99T^#%Z5I8)`=I`!\?@/BIL#3=HI(CN:+=)9J"
M>CD65T5IB7$@7,@S.HY#*,2!GK!1WJ.^*COG&2ZYVW7"GCECK0X'/!Y9$``C
M`MRZ]?OO=*;A=&I$&&LS+F448]H"%,+L"%D!#!#%Q<76L+%G2J#[H\,TACUG
M@&+<`+@/`!MP+PJOIGJ-FRO*"FP@A8,9ZP(_9-H9=(IS:="`,E5`14QVT#&Z
M[H7.OCKRBUT&?<#Z(L`-;MV\::S*2^!O1D:8D]GFV=,AFW?@,&8;AF^$_YU_
MMFGMEU\89?,?&N?V\=*`32CH8(<]@(@J`ZVOI4&,A)?OS`#%A(]3^!\!%$YQ
MP/[NS2N-[@&(+F?H.%OTW/[\/:*+'NW0!X#PTQ^X+0P.<],>H/[VJGVI-C#;
M$OB/=$3WVN"&\)^]*S4%)I=K#YE@"_,[<9^(*+E6XOL$KO?:]YP-G?6AZ)Q#
MA#V`-1__\0TQ@+-]#$`+`<36M:(W`#@03!"4'@I,%H\?#IH\''R@X8$Y<<^L
M;Q-GBQ_\X1?_+O1I)DP#</(:[E7S(,*&!LX`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO
M8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\R,BYP;F<`````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,C`V
M`#$P-3$U-#,S-S8V`#`R-C0R,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````(````"`(!@``
M`01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!)
M;6%G95)E861Y<<EE/```!!A)1$%46,/ME^]/4V<4Q_FWC/^`B?J&.1),=-FB
MVS28&'4A@01,DY%T,DQG4ZVIM;0#@:X6.S:V&F#C-T@P0:SEAQA,E00C"7%.
M0W#?\3GUWO4*2TSDQ;+TQ>%Y[KVGWW.>\YSS/8<*216E8G^6EY<U,C*BB?&)
MXMNZNCH]??)$C0T-7G7W)YX7Z^OK`F-J:DIK:VM%P-K:6BTM+<EWOO$],'94
M:&UM57U]G;+9K)J:FM3;VZM`(*#%A86BUE"V6WW)L#*M`?T8#RK;&=9OF>^5
MG[VK]S/QX0KI=%JY7$[Y?-Z$8!!(5^'33XYH='34/.<#ISA[YDQ1X?6K5^*8
M)[_\0I%(1'^\>&%K,'BIJ+"QL:&!FU'UIZ[:,7MO7-'M9$2_]W1J%T_Q(;)[
M`.WM[4)J:FJ4R634W'Q!/I]/,S,SFIN?MS"&PV$+'^$D*3P`Z52792$**`+&
M"M#T]+3Z^_LUOP74_(U?>_?LT>R]>_\`;&YNJB>94.7!?;I\H=$DZ&_0^7,G
M3.I/?VYK,M*BFF-'=?3P(76TQ;T>S.=S!M)V+:3PQ:^W"8`.\-6`7^C_QVZA
M#*`*LH]*'MZB19X'!P?E9"AY`L-1S(YX`.!2`*ATLHT49H42R<3JZFH=/WY,
MB43"WD.S'@!2F'R'6]A757UL5CJ[NHP=`*(F`)F]/RN_W^\%@+SA'?(=]H28
M<!W`9M]7QJIX5UU5:0#H>@`"+7[[(=;'QL;TY\N7!H"K+2W?FD=4*15)G#@6
M<7$!"LN/#-6LO2T<]K]TA*S`H&V>*22GF"!#%P`.A\M1=`0"-*YO"[E$V'<S
MKN&>=M$+/`!0Z<10GU4BE?9N)9:6.)+J2`BV+=?"+@&4'?A_.4!U,1E"'%`<
M>Y@H]4/*.C&<"#_PS-0'4\%8<`@,=?UZ3-%HU.40Z(]&#2F!&8O%W+EG1P=0
MA`;ATP/[]]G*X#0W-V<D=>BC2@-E[,0A9Y"";^G^$)8S2_+L8$#RZ.#$RLK*
MOSL`"T*=DY.3*A0*9IPHT!T@?$Z%`1P-A4)V>HS!ICB(+M\QPC?>$QF>&6J)
M$`?8T0'H-?A=P`QA&%E<6+1PXCDKTS<G)I2E\T_MJ<_,`.$F@NC2$\#@JIB#
M8&'X\OFS5?WUYHVV.0`YWAD?<2=[[IL.A&"(\-,/6(D$)X?6R975U56[#D*.
ML[0&C!,Y(DJ.T`IQCO;@,/DV!V@+XP,_:>S7I"M#F;@&NZ.VCO8D3(9OQ>R=
M(\XW6H4C`^FXM0_F-4=N_WS+9C*G$W@<("Q/"X\M3`S@`-"#Z%/.GM[$A/BN
MT+?X_X1!'H=PL-1)Y[?=;1'#)]=V3$*<P#OZ&_=-K^<J'BXN;(4P;V&D(C@%
M>^Z=;PA[WM/S<V_E0>Z^Z9'0W#VXI?=?9L*R`\C?J/GYBQ"-VWH`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R
M+S(S+G!N9P``````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#$V,#<`,3`U,34T,S,W-C8`,#(V-#(U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(`
M```9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```#&4E$0518
MP^U72TNR01CU9_0KPG6T<A'UA9O`91`$[2J2"*(BLJ`+&$'X2B5T(5,JK0PJ
MBHHHA:(+"A5A66`7L0B_*,5NY_,\T$4P</7EXET,,O/.G#GSS#/G.6H`:+XW
M3<:!NKHZU-?70Z_70Y/=DK2!G9T=E):68FMK"]DMR3CA^OH:965E:&MK@]/I
M%#JMK:U0%`79(>3"A(J*"K2TM,#C\>!/20DZ.SO1T]/S%1BKU8J#@P.4EY>#
MD9N<G,3,S`QRY13_%V!_?Q\G)R?8V-B0D$U,3&!D9$3ZQ\?'8+2.CHYDSMK:
M6GJ4F#$-#0U86%C`Z.@HFIN;83:;9?'T]#0J*RM14%``D\F$V-\87EY>O@"2
MR20N+BY`!D-#0]+FY^?1U=6%WMY>3$U-X>;F1E*1FUQ=72%'@Z@"Y`+`^/BX
M9.'R\C*\7B^"P2`6%Q?E<=ML-OC]?DEM/G@FWR?`Z^NKI.SL[*QD8U-3$XJ+
MBU%34R-@#H=#FC>EKQ1'1;$@'H]_`3P_/\L;F)N;DQV=J<DNETM$F:#M[29)
M;3+H[N[&\/!P>BH_/C[*@WEZ>L+>WIY0]/E\<+O=N+R\1%%1$0P&`\;&QN0]
MI,7@[>T-L5A,%O!\/#>?*B>2#0'XJ,[/SQ$(!"0V.7R-*L#O-)6`2B"M0UFD
M,(7#851558FVU-;6HJ^O3V20[HK5GIZ1W^BTJJNK8;?;H=/I,#`P(%+*-51'
MZC,+N=%HE'5T!HIBE2*?D0"%[?[^'NOKZT*`P+1V%#CZ94IK1T>'@%)2J9)T
M=O0Q'.OO[T=^?CY65E906%B(S<W-E!2WRYJEI:64XKK$V_P8`?J5W=U=`:"'
M.0V>RJE(A!OQQ-1X2C:=,OT/B:RNKN+P\%`*""-#!TTOQ"@T-C;"8K$@%`J)
M_<EX!>_O[T@D$HA$(L)Z<'!0))V@]*VL$W1F!&9!8>U@.$F$=8+?*?]:K58V
M8=3.SLXD,GEY>=C>WO[\MY!5$C(7[N[N\/#P(,1N;V^EAO**/L;96(>8,]%H
M5'[9Y_WR&C^P./:]G]NO0"6@$OB-]@\E2/A&Z>%#.@````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M
M+S,R>#,R+S(T+G!N9P``````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$V,#(`,3`U,34T,S,W-C8`,#(V
M-#(Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6
MV-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```#
M%$E$0518P^U72TNJ413U9_0OFD<C!R%!DP;-A"!H9F%$$*F$!CT@"20M"C*P
MM#+*A(RDHM`@T8S`'O2$'DI%2*2A/=9U;>@A&#BZ.7!PT'/\SOKV66?OM9<*
M`(J?0U%P0:O5HKV]'75U=5`4MR5O(10*H;:V%H%``,5M*?C`[>TMZNOKT=W=
MC9F9&0F'WZU6*XI#*(4'&AL;H=?KL;2T)*3T]O9B8&#@FQB;S89H-`JU6@TR
M-SL[BX6%!93**?XOP.[N+HZ/C[&YN2F434]/PVZWR_SP\!!DZ^#@`$='1UA?
M7\]GB1G3T=&!Y>5E3$Y.0J?387!P4#:[W6XT-36AJJH*1J,1R602KZ^OWP"9
M3`:7EY=@!&-C8S*\7B_Z^OI@-ILQ-S<'OL#E<LE+;FYN4*(DE@%*`<#A<$@6
MKJZN(A@,XN3D!#Z?3XI[?'P<^_O[DMHL>";?%\#;VQNVMK;@65R4;.SJZH)*
MI4)+2XN`.9U.&<&<OHH@#@\CG4Y_`V2S6:D!C\<C;W2YG)B?GQ?]6<R!FDQ&
M2>V]Z![Z^_LQ,3&1G\K/S\]2,*E4"I%(1$+<WMZ6T*^OKU%34X.&A@8Y'NLA
MCX/W]W>I+F[@^7ANEBH?9#0$8%%=7%P(!^2FA*^Q#/`WHQQ`.8"\"661PG1U
M=87FYF;1EM;65@P-#8D,4MW8[>D9^1N=ED:C@6-J"DJE$J.CHR*EW$-UI#ZS
MD;>UM<D^.@-ZRW@\CH(!4-@>'Q^QL;$A`4SE@`UZ@P@<_3*EM:>G1T#M.4FE
M2M+9T<=PS6*QH+*R$GZ_']75U:+Q)I-)]JSX5N#.232]S:\,T*^$PV$!X,;3
MTU.,C(Q(('P13TP6V#0,!H/X'VK[VMH:8K&8-!`RPU/2"Y&%SLY.#.<:R/GY
MN=B?@E?P\?&!EY<7)!()B9I44M()2M_*/D%G1F!*.WL'Z63O8)_@[[3P/#UE
MGX;X[.Q,F*FHJ,#.SL[7OX6BDI"Y\/#P@*>G)PGL_OY>>BBOZ'.=@WV(.7-W
M=R>?G/-^>8V?6%S[.2_M*B@'4`[@+\8_NCWX-B:--ID`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R
M9&]T8V]M+S,R>#,R+S(U+G!N9P``````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(R,38`,3`U,34T,S,W
M-C8`,#(V-#(T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G
M04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQ
MR64\```$($E$0518P^V6?VC4=1C'OTXJA<@_HA()(S#4RB0A_^H'V()84.JL
MG/1[.3I04O/\IR.A#6P=$B<7,L]RM6:K;8&<.MLQC:WIX(:;ZU*466P8[.+2
MH7&XU7AWK^?X;'=NQ*"2D/OCP^?S>3[/]_UYOL_G>=[/XTGR<H<WI6#=MCH=
MO3ABPYO>)WF"I2O*M&K+=BU9&U)Y\/`T,*94N/OU@&9N:M2LL@WR=G;HS@5+
MY,4ORNM(9;6JJJI47U^OIJ8FI5(I!0(!#0X."OGTKOB/%;`61S#/>"EBALUH
M."L<%(E$Y'5>_E.;_7XQXZU=!]JTI^LG!2(M"H?#\J+1J/U:/!Z7S^=3(I&P
M@U@LINOT%]<'P#N2E/=>3+>4O*NB/:?$_ME0LXJ>J+8U,CSDSKS*8_(J]D\X
M8=OY*YK_Z,OFV^+0=V*_[OV=]A'[M2W=FKTRK!=;SFK#P%737=]_Q8+&`'@0
M'@A7$U6X&)<SB*I@,*C2TE*+MO;V=M/AK+^_/PN`$A^-C8V9$K+1T5%39IU,
M)I5.I^T]V?.6[/]'KU``^(<`Y"L9#F]9F&9XBZACO3S4:"'+^?R&GKQ0?ZNR
M-AL'!`["C?M;C#;N+:O(`D!\1W^VL%WQ9+%N_JS-`+AH;K!61??Y)P!6?]YM
MBN3`(UM#E@/$O*_W%]U3_*JMUWP5T^(2OY;YOY;_2-\$`'E0V=AK(0PO<1OF
ML=Y>4RNJ`^OPMQT&#%^QO^W^%[(`Q#7)X9*$I`$4WSC*AL,8@',1,M8&0-*X
MY""A."3[2##D`"%CSN5^$FS\&4EC9M*3`T`!8"9#L8[9G3E&+83ROP10,.#&
M,&!X>%B+OCRAV_?&QP?LE"M[L*93?0._&1>P?W-75$.7TWKZX!FC.QB-:IX>
M^<,*,/K5![JTM*$W#Z/N6$*3#"#%K>?+E'QZ0'@"LD%&5V5](><9;J5G9`UE
MSJP[+N_C+M.%1LV03#MQ:TVK&01]NN_0N>FC;[(Z&2:$-?(,>/CDKUKVPR6;
M%T?/V$4/]%VR\="YM!$Z((M\[YALSFN[M:![2'?L:-5=SU28MQ@8PCRWZ4<S
M8-[IWXW#H>7'OCAH>PR`*/,,J!L:4<6^N$I6E1MG/?]*N2)#5_74ED;SB%O3
M;[*&FJL[$\;MU`(HW,EY/N3PO_N.O@G]JIX+DPV`J@\=/Z7-'S2;`3`OC(OL
MN3="9D!SV_=6&S`,^<+'W[;>%GGW0$HGSB?M?;GTP]V?:,>GK78IYX=[!FS0
M]^)%GI0[Q@W@CQ%0$KB8,H`,%H?5:<38NU*!'I>SIQ)P1B`[73P*XV.L*S4,
M[J!>\<.3>C,.^<@U=P"RI[@!PAZ#6",'!)DK0YRY#A,=<%A3AC@'!^/1HR1-
MR0,`.M!<6>X'#$#='UPK_[N<OQ:GP(0%`QA_`:A8G@DRG3U,`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,C8N<&YG````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C0T,P`Q,#4Q-30S,S<V-@`P,C8T,C<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F
M='=A<F4`061O8F4@26UA9V5296%D>7')93P```2U241!5%B%W9?+3U-1$,;Y
M8]CR#VC<ZD;=Z$H3WW&!AL0$5VI\)+Z"`15\(+Y0RD/`1U$I"$30`$K1%*02
MJ$1>10K%`NUM@>#(;YIS%=M$HDB"B\.]O??<F6^^F?GFD"(B*3\O_>,H*9?'
MS]^*_>!^D4,ZNGQR,:\BONWTF2Q)3S\H&1F'%G]O?Q*<"(G](!0*23`4D4+'
M"^$^)1`(2&;F83ER])A>$VPDM<EZW=8EZS=LE,GIL&S<M%G.GL_Y@1.,OL_#
MXA^?$BL:TTW.ZA8-9NDN_G[#L/^+E#]Y)5D7<B1AP^#0D!+)IK**Q^)^YY6Y
MN;EX%"VMK5+_JD.FPQ%I?=^O432W]6K(NF%^?EZJ7KBEIV]8K<1B,1D)3,CL
M;$S6K%T7]Y.;FR<G3IX2TG3[;HE<SKNA5%^[GK\,//RQ`:_7*RS@+=D``9-3
M:*MK=&L\Q):=>U,\'H^XW>T)QN(5&`Q*UZ<1>=/NDRLWJH0B#DU.R:>!@'P>
M&A<JE.?4,/1NV;)5%AF`/?."?+@[^S0WC@>-XFKP2%%9@R*+1J,R./)5JIZY
MY-;M.^K(AF)9EGKS?!S0C_#X;7Y.(I&(&J5,R"/&;A:ZU$%:6EIR8N!B9F9&
M85(RYC<(Z*N52>,J-P!9%165TNOS"36R9`-LIGRY4D2D\EQ6_M(-5#YYKEV/
MAI4^;-0^H%AV[]DG-/ZO*4PP0/]2,-NV[U39I+BH0*H4*:$_J,($`ZZ:6E4,
ME&/O_@SM`Z2%RD1>""?[4K$J"&4/-[8!.@]H&,!#,#2MGC_T!K2D*6>:#&3T
M!NAH*JI3#83#TW(H\[@V4G5UM73WC=K-Q$C`"-=H+"[9+&80^DZ?*`R(>MG<
M*5T]?G'6M*AD\B%>(U94A1!DO*.U^P?'E&0Z4@T0$W'2,!CBI;=G0'];"U[H
M4%)*-S(PZ,:Z>O=BT70ZGZJ2FD6<J#RDH4KFGN%HAAN.D[8RFLW5+)`0%F13
MI:N@F59RK4X`M!ISBL7]/P5`MZ`D]#L:5U=7+P/^454<:I[VI21IEF4'0&\,
MCXZI(J&1@?%Q_8USA(?3&0L=H4>0@F4%4%+V2)UU=/=IM&@*"Y$F:IH3S44N
M43J4D&,$H/B.8]+/RO=;`$0)U6@N@H41A`UI0?!<M4T*!#VBH>VU0#\G!H8^
M2@$85/->J5-3=+7`H>DSQ\($`+Q@`^=H:#9THV=$RZ'(LB(JTSCD0(S.DP:T
MC?MPQ%(0Z-RQ4_GV.$/2`(3Z4DM)`4`3!U>*BPBS<PO5R(Y=!\3I=*IAA@M7
MY)Y9P7D6R2?_7\8FQ=W1K_."%+&'_Q#T^0*#L,`Q*#4U51F"95.T-A*B1V01
MWD!P2L$P`CJ[^W4,D`X4'X>5S]ZHLA,MCF$`=6<>H\.PQ!@!0*?/KZW*^0R6
M`$Z`,`*S-@!$NZFI29TSAW!HYA!'3QA@7N&<7%-H'-8Q2JOBU$1,:LQA$)!\
MQU0E73#$.]B@@!?E@ZD!*CU=+^2?Z/G03%6,G<TJ5@,`!13,,94!"AL4+([9
M1QWP+39(%VEF4:`P0-TE;0W&-F<%<RJ'&1:YHR80(PJ*9>[9QSOSGFM!08$N
M[GF//?.O`\!A?45U_X^D^+\'\!T0>'68IU\/T@````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE
M<F1O=&-O;2\S,G@S,B\R-RYP;F<`````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-S`U`#$P-3$U-#,S
M-S8V`#`R-C0S,0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````(````"`(!@```01]2F(````$
M9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y
M<<EE/```!5=)1$%46,/5E]]3&U44Q_D#=:9_1!U?G.F#(T^*C#Y4BW:LG5)K
MS5A:P2G4(&E)"1"AT)#0AD)20]K$G0(!&D)2?F;L1)/C?DZ\FRR;4)E.G>G#
M83=W[SWG>WY]SZ5#1#J:1?^L9*=E=.@[V;+&ZZN+R:>2S69E?LFJ+V2?;4JQ
M5)+'Z17W>4?'QLI]2<5'1!?F@I?DEO^V3,XD[=\UZ4AG5^6GP=]T(1:+-9^O
MR6%A7K;79T7^WA>73CZ$QV[*_N&AH.%>\*K$I@:D831?E/6-34E9!=G9>2'`
M_++GLB02BPT3Y7)9]G:>2_F@(.GTLE2KU8:&XZ3QHUI6@.`!L`<D`4POCLKT
M+SV2C`XYFW2#M3PAUMJ61!]E!,!$:34Q9#;4Q'_3)]=N^#7`'YSIE'QI1P*C
M$_4-NWN[&KE\85NCU]<_*8/^B)3V#AH;$JFLJLY8.<EM%.2'OC'=Y&#`Y^UB
M4>.PGK,TN5XW6TK-Y?+Q<6I*Z/.UJ*0?AR2;FI1G3Z;T]Y-$2$KK4QZ%KD"S
MB7@^F+NK@E^S\[^+[^N/A+I"*850K>QZ7:`*,TM!Z>^_KA5#$.Z$HEI!1.]6
M8%:6TJL2"(QHLER)0@CKGR]?:OP)&$+11^-I57"QMU^N^OHT_*3%4TS=GWXB
M$Y-AB2<S>G`X..^D@_209,J4L@59/K_E3A,ERH:9V%,]&`H_U)QR<'1\0<Y^
M-:!/#L]$%MP*7D?>M((3%Y(MM8I4#C):-#0@3WZS_FH%=C'EK'M.)?ZQ'-;?
M"$763#<M*Y%BHA(YP#-P_7/M[H69`6UBI2)[7PL%-86*%>J?,H;U8`!*>>1*
MI](%RIKIHJ'`]@^K6($-*%\JCIQ31#\/#CM(4-8<#P<^D%%`D4S/I;1H*"SJ
MG^*"<B`.W/)0+PH8"30*4X"Z-_V`=:IP_V!?4:'L17'-K0"&X2.T3#-1OEBF
MD:`L%)S]HD<8-72E(3Q'`1^P#)]#?O#`PV1.&\<T%@'E.PAPQ:6`B-.)-`A1
M9_.E[W_5-J8;08$[*&;/Z=/ONQ5$(A'M<381=:S0C;B$.RBD0PDJP?4H(`8<
MA(GP$9]Q!6M,!-"<OS"DBHF+1X$1&`FK^,X8(]K0.(KB\4?"B/N_V_G-RPDV
MU^HM@-"0"!5MWA%MD>/YY^2$9BLV_$2_&L9`H!L&'VM0$$\N6,I?RAJO!G.L
M88RBU-`3DDF-JYC>AR"8AP"QDF.Z9EAG,QO\M^_;`VG+R!A%*6*,FPA@A&N;
M5JA=[MQO;IQ[3^Y>ZU+#`($:H4`FNEZK_A.CVT@QCA%N548)QN@UFI)60>AJ
M>HX>\]^)*=L-^,XI``!RCN@``&#M0'A&BLFU"24,"0/`T^:N`L5@%+:`NQ&^
MWPZ%%03W%T`S00R'`^3H-#D"H)YW#"/D%04_^GJ5/3`('>$QWF(,<.>_N:(L
MP\T1.N,)X\!`7)R9#=R7`-:J'EQHN'7!BQQ$`0P-$S,?8")8&%:",PU/\KZ0
MM!38A6\O.J3,_"`J```\Z>+FWA8`-(>!ORH5%0`,#H_KA,,(QA#6\1"EI`+:
MY#OO1((H\61T<)DC?7P#B)E/+0&`N+?WLISYL$O>>?>4"B$F[PPWR)Z(,*=0
MR%3`<R8%(X?0,PQ,9+C7,><@?H8APG\`]2BT`(#7S#6BP`T3M!CE8H!!$V[>
MF3:LLT8$"#F>F2AQGF(UJ2!J1`P0;0&0`O+,(;SBB1?JI0T&CPDOBE&*IR8U
M1(FT$`4S^G@W5V13F$0#&^V+T+XF8YA"I'(I*@3DY+2[^S/A'DZJD*Z/.W4?
MPA[V4K!T!GO-FI&CWK_&-#27WF9Y2\?Q/_?)_\X04%SD`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S(X+G!N9P``
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#,Q,#8`,3`U,34T,S,W-C8`,#(V-#(V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O
M9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```%V$E$0518P[6776Q451#'
M]T$#4<,;)OAH8O#!$$-X,8;PH(D-QI`8-6`QA*A-,+1IL(8/@S0$*F**@50H
M$MA$9(%LC,`&VFI+M:75?@380JEU4P1EL5_KMEC0PL7Q_N8ZU[O=M5^$A[/G
MWG/GS)GYS\Q_SH9$),2X<6-(F/4EMN41:?SVN)2\-5="P[^?DXZ+%Z2CLT?J
M3I_VQ*N^.2NI5$J:6B]Y"\&A/SM6S-3]NG!P_4RYDAR0C\J/>%M0B`X6%BU:
M.$;'WW_(.P6OR<^)F&YW',?[\%?ZN,0K9LC6L@_EE9=?D)&1$4$ULPKT]0]*
MK*9%(M'OI*ZA0TWL'QB4MPL*LLUDT=SVS1YO^`\_-$4D?>%%D;O7].P,@5OG
MGY9#'S\EQ2\]I'BE3CR8*8`']0W?2S@<5F!!ZMTW\SRDSL6>D<7/S5/+\>1\
MYU4IV_:I7+YZ73>$(H<CTMO;IPNXB<L\`R]:0R=/56NL]NP[J1_JF[M4D#6T
M^EZ@!43_U\U<@PV5>S^32>&$\,[R#X2``LO6-4\J',OR9LOEQF>]_+@35RN(
MZ1@%CL(CM\IUXZK\^=+:_+4DD[]*4WM"]G]>K;"1`-UG\C08MV^/2H8%)&_[
M_@6RM_AA18=D`(3T4%IV[8[(TM=7RA='JQ1FE'ZRL^(_!0A]=>R8E):6^A!W
M)I***.]88/`CPV;6"@N+O-.)%="CB(V<\F6L69*_]:L5;"3(.W9%-3S(4@V$
MT'<!GXD\J(-#V>9E.B]>^)AL6ON\9@NIC*4;-FR4GIX>F3B=W8B@=%)AS#5P
M:=+UDFO4GRJ:A@(WQOC)G(C-D51_HSX'78$MLA2TU+PJ/W8G--MJPX]K]9*)
M%.KHF0=$K7$Q82;!LA3<O3.@@B!/95.T9"3"1.)Z[7S]/A94_1GHZQ(&-<#F
M6/2`AHGX4Z;D`.M:#VZZ6QIG6-#;,$=*EL^6Z)%*/RO)N)*2]Y3&(@>WJ57(
M5%=%LQ7<O%8DO^R>H>D)"9.!C/;X3YI`U`.U0)KSKGBAX%);H:)-V4*[MI$Z
MP'1R`2(GC=DX.#2LQ41)^XR#F2=JZK0*K9`04M[Z5Q%UP;-90S&I`F**KP"&
MN2UGN[5@.)&B:FB*JQ64-S+&GARF/0NT.0F_@^QII&B]#/]I'`SZ$_R@[8<?
M)6QW@[$//F.R*;<U%!G!&ZTI!L05-_@`+U*ZA\+Y2F$D$\D%P(1V7^5V#;.E
M<XX"<?SV16Y8VN+:E*N15AO,NBDK&'>X%<IU@DA,6\?D#7`T%8)]F<RGL8)K
MT$NP139(&5,PP-&BQJL@&\(4T,O[Z_*E.UZN!3W:^JC2#4&FFEC#J-CA)1IH
M=`7WM[6U^CP^(0(H(@%H!I``[S`-]PRH"4*@=.<],<L?K'/+8UV;IVL01J.'
MJQ<&3"$$CK9P^`^"03ET9@.O27>44B]4,/6"YWRG.8,.,TXHJXLSD0'>H<05
M1H?)&=02=40Y$!98C#Y,W3&H<`;T0(5#)=O7OZ'[N"E`Y-Q-Z!@8.!:)G-D-
M?&P"4A#@($@,TJ/8[=K!;8$#Z>5\QS"HAD)?LSI?D0-^GD$-KL]"X,^;5S2Q
ML!#OH69B32R!$R7<(#B,@QFP+<3`#/Q\@Z8@4+L',7A&QK@2P]:N*U96XCGC
M`LD@^Q&`@8$5SR!8(U7B;50/W!@!:['..YQIA$LKM([&=PS@NH0<Z]KY@R$@
M-L#(1XB6=_.6M@#4]!,4P/8,ZS4<'+R+F;$@8SF#<W#&ZN*-*LM%G#/\&Q"'
M`J>U"PYF,P>8I\QL!FH\8LT.M)S`:#H+<AAM,LAC-"T;)PDKO.#_V2&Y$+3X
M8I0U1/,:3\V8X,$&,6'#.`8AP`CV\<R,/FZE&,&^C!!`IT!%@MA`D+`PD\VL
MT>K(:MY)5+X#K64[-U?09#8]'&HSNH!^G':8.3",2JFMJE`#N=U1JK`C1(5B
M_L<-I[N\6Z$K1_(:;P3UY.H/T^^&[F%0+9X&_W[>IVZ8>]`=*=-[T?$/BGTA
M3''7"$8`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\R.2YP;F<`````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R-C(P`#$P-3$U-#,S-S8V`#`R-C0R-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M(````"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R
M90!!9&]B92!);6%G95)E861Y<<EE/```!2))1$%46,/-E\]/&U<0Q_,G]M9<
MJEYZJ=1#E`.G*H>J51,IR:$E31Q5<026B!-P9.)88&/2#3B.(0:#P1!C`@&+
M&BI^-8D(A.QT/[-^:R^V8U#5'X=AEWWOS<S[SLQWQN=$Y%RCZ)_M]5%YE@C*
MT9]S[M?I_`M96RE*>BSI?CC8GI#IH=LB1U7_>4_'RI(E"Y.#HA\20Q%Y.9^1
M<KDD!V]K1X*7SLM&*27>$4\<I7)4$?GPA_AT8MZRAF4N/Z;NH.Y%+BO)Q&#M
MY/&.Q+HO2NC[+R1R[6LI/+DKQ7Q2;/OXA)OVH<CQ&UWPF?B4U/_Y^,YUT)%F
M#8[77'YY(27EF;A,/^L7-<<&=D<'[LI,SI+%V;2L5]9D;KX@UDC$W;"WMRN@
M55DKZ08$]&]<Z:H#-9,(*/I<<>S>95DK6QJKN@^.@X%O/Y>'W1>DNFQ)>8I`
MV">AMA4#O4W+:[84V]/4&2=SP(&$C*FLICUH-BN3&GW[X%5[#PX/]N3I2$CZ
M0@&)/0HK$@0=V!87BS*>'M<$Z`O^+%/9A/^.8$VF<#`W8<E2:5:?8`W^)"0*
MP9\,`N*MS8H?I+<[)=4>#%R5@?"O,OSXOD3Z;NGFGE]^5'D<[54O7^;ZO:MX
M"O"".Q(.TA)Y</DK#0FQ*Z;#FB:OBT/-"=^4LD[";<P_E,S`=95RIM<-O!ZT
MSQ+&SO)/*SAS(KE@4N.F^%RI-B50:P6UJMU<27I92.5LK8_+WH;E*FH+HH/^
M\;N2+X41*&ZID-0J+^4C-24G%.#VZ^4I3:"!!SW*8:3OZNJRIC(I3"KS/1J^
M)?N[=27ZA[2$-DC33'I$TQIF*"].J@)3#Z3S;Z-Q37F^>0K0B`(6R7=JP8J'
M5`FU,#N;T\-X0FI33(>'[^L*LAE+7<<ZA^&GPF1*"P9O^-\HH59@73_C..C3
M4R@8/$$H'*R98N+NH\D^20T&W-">!)$(C`8O:>$,W>[28H+O(4*JCV@04N7<
MEL7D)$\V?E4/WOGA2ZU*F@35B&(JD7!BJ$UOL#7&]V]^HV6,@FSLIE*985JH
MK@.IVIK&E"[6)Q[=4#ZG[^J]6Z1SRP)1%]D,C2/:9UH7U7_/!_^J`PH-<#3"
M8X1OSIH;X4]ST-D(3<<*EY\@_?>[.0TJ`LT@O$,WK)%FWJ2C03\C(7J&E=NJ
MJA`#%(&AJH5I-Z<10UNLL8=OE.KJ?,QM)!Z9GC*)#"-C&/ZCN5+6""S$+`-K
M\:3DZ>2FAU+NO"/LAQXI?48#IL3&`FQR@$7(AXYNE&,08\R)$!:$!%D9GMVH
M_B[;.]LJO#-*L`>!%7EROK_G)QF.]2JQL;?ME`BM0I7FMM`KQG&*PPCK4&TN
M'=>1`[K%*03.-JS)$_J%84%"G7"0X7\SEO@<8%3D`)!S`"=PP$S(&*!!8!@'
M@-8T#:A;!W+G'<.@A>,(:$+AL'+:BLJ;?7]?]"'P\<.^*H&^.41\&SL5@G*>
MH,*3N',[',;YQAP!12Z#KOZ>[X3Y"QMM'="2<\J'K&<D@L7A4^8IR#B?"DKA
M:4C7:!NL-\YA[(7`$2J"Y*-BGC\)U_BXZHWO[<NP-EILE:+:BXP!YF^$GSK=
M79_I$P=PBL&/KH&3.$CK03!.:!A3ZLW@-+-=#0GJF/:$07H<PKL1&J;I.*#"
MKPE%"^-.`\4!R*E^<ULZ\D`3&3F.P(#%YW?4`8P"/S";F8F;\ZXCL//.C5U&
MK'9DP]/W`.7_'?%^5+:4JD?!I^T)?Z.3F<&W\P#\OV['?P%L)>\B8SNVV0``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T
M8V]M+S,R>#,R+S,N<&YG````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(T-3,`,3`U,34T,S,W-C4`
M,#(V,S0R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!
M``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\
M```$O4E$0518P]67?TC4=QC'#?9'_37V5T$%(V8$453[(\;^,`8+6221*R/K
MCZUNV&QH,U<<67G9E=&17EJM>5OFBIU9V=)$TZ`TH1\:D@:*165$1Y<<3)`*
M]^Q>3WS.N^Y[5W>CC?YX_'R_W_M\GN?]>3[/^_U\3!&1E'#3/^7N"NFY,R"C
MHZ.OON;^N$U*#QR1T(RAH4?R/#!A_$.4CX'!03E1>V9\1LWI>BDJ<;WZ\.+%
M2VEL;)!=1[W1/KIZ^N3.X'VY._18ZNH;(R=\GO:E.%T5<K:I57B."#HV-B93
MI\^0N0L62MH7Z3)[[J<Z1H4HV/2-6,*.9Z&'OKY>Z>[ME[[^NSI>;&N+#`%J
M?FBYU"ZD*LH#R6`')#80"$1.R%ICDZ^6K9:=SC*=P&XB)O"!K:7.FJ.V*#U#
M:NOJQC%\W]HNV(W.26++R0G]&(&AY_HG$G>;R9KE1PZ4@QVX=U\>/O9I[AI:
M+BN\S)798K<[Q._W6U<4$\XWM\JESFM2Y3TKI\\WZWOV^ESQ^7SQC_+WDUZQ
M%^^5\L,>'4GK?O<O8M)\K+HZO@-2O-:6IPL<^PXJ7"J9L\$AMO"S-(GIH/;4
M!=E=?C"T_]].SI&_1U(DT^'4TZ<:8B(X45TOA16'Y)E_6*JJCBOMUF0OEBV_
M;A8*T6KQNSO&_]\!W.KLOJT*01&A$B25VN"W\'J(6LQ9<PJH&PZH1(A:4/B3
M5B)'3&'%=$`107<6=USK4@1$Q0%R&7<+R!.:2`1JG[I@,4;T-^:@\FB5EC$+
M/#5>Y0%\L&W<JM#?Z(!Z1STI7Q95!@N*$7N]A"T=P`.<Y&]QZ&*Z`H0R9"(/
M,1V0."8QF<4X^W9#@9**$51HF='3*`<P;]K',U7TTI<N5ZU'"!%$F@$C#OC-
MT@%]QU;YLXHR^DLBGPY]((O2IBM#Z5J0*N86W.X:.=[4K(V+!O:@?Z)D9<T7
MM^LC\3WQJ^K&36+NGRTR,O*7U@"+D&AHG;%VB:*Z$BSCM^("T=N:4J6K^Z:\
M'W3^SP$,#P>4[;1AY`'"4EL8>>[HN*K?2"$20G7`T7\%`/V!FP1$6I`:-,H8
MDD,PHU]H&7,P^`S'][M<"I)"20@`$N3<X]+=F2`X!@B!",@[N\8(!JER\X(L
M=)1(::E3^R'%!0\2!H",&6)1U@0SK1XC`T8[V2UMGS7AEZ"D:P`GR``-F2,@
M(#K#,P%YYYGNCVBAA%P/`6#N'DD#(/5&?Q`T=)I`!.$=(VAIV9'0[0'9)?U(
MK]4])B$`I!+G&(X)2!````1`=!SN0\BW46)4F(L4F7C]O!,"@`--9S`X#I%T
M9$[/.7@D?#=W)L`Q,@<PC/Q.]@"8$`!2C^03G%12`^S.[!#C&ZGFV5S:J'J"
M,P(,`P`^&&-I@24JQ)LC6'?L#TG?5*B`\GZPZWO&=SE*+X*MVK9:A3]SQ13Y
MNJA8+X$4(&MI#LR%_QZ/1P7*"D1,M4-TX#E,X*PWG&G0=H63XATK]=995_NA
M7B+S-TY6_G.Q;&EJE\W><WJ92*H(D5EZ(@%!;1S2;%&R(OL\#:Z]LJQ$FRX9
M0'#"YR;-`G8!Q\,=\&^/8WNJ!N;.S9D:K3_5?%&[_3MO1E"J]_:MMQ:8]Z8=
M_P.<GIE^IU\DH@````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,S`N<&YG````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,S`R-0`Q,#4Q-30S,S<V-@`P,C8T,3<`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A
M<F4`061O8F4@26UA9V5296%D>7')93P```6G241!5%B%G9=?;!15%,:WAI`H
M"1$Q-N'9%[3*FT]B8DR,"<J+45.C/DC4Q!@U:DQ(3!\T6-((*HJT)6I1,"&L
MI;;1MC:R%G7%EE+H4MLNM!1LV=VR"[5U2>JX'._O#'>8V5GH;A].[\[,O>?O
M=[YS&Q&1"#(_-R>L^M!1MU*0-U]<)Y'\;+\,#Y^4O?L/26+TK+L]?GB/M&RY
M6R5B=5C1/]N?O5G/ZXMLYPII[?A=TIF,C$].FVU7YN6MVC6R]8V::V8],1]?
M>?DY.7.J0S\6"@7W0_YBEQ3V1229/"5_)L_)I=E+\O'.5L%YW7"DNU;&=ZV2
MZ(>/2.-[#\OWW[PKS;L^D):6+\-N8@(-`;=O)-X/HO]W=+U(84H6%A:"&N;B
M:S4M?^^NDI[O]@BQ!S:,M"R70F>5Y'(Y30H1>)D:CCTD6UZX3?H'DQH6V6+C
MU/1Y:6BH1XTCW=''-<1/ZS=IF*QU;V_4,JF)WKTU\E_B'DFWKY.%'V^7W,F-
MGJ->%!1#\EURW3!+2CXJC8V-H4,E%5`OG*:@N$.U2<<S&ZHU?QJU,R27L_ND
M[IW-Q95P-"#)?Z09H?#IKV_2XI,1A.QPD*SYBW'-`P/>$ZWWR;'WEVE1)J<R
M"N+?^L8D]FM".KKZ-=56&4`)YL!H10')NI#-ZN;]WQY611SB'<\4$66??]6M
MV`TDQ+FP6:AZ8IL;QI6H*_P&KK/1*@&ZA!Q*8B8UXL5%'<=.-&@RGW_B3LT-
MA><@7=+6=K!,.)N*V%@7+6,I\3?.DA3$?GAU"0I,-31&LTZTK9+<S"_ZVQ\*
M>0@I(+L`![3%FJKEG\2#FG4:Q8DO$_7&Y(255@M[8#ZR$0A#7`#J[([ERC!4
M8*9WO7XO3JI70@3,PZO4GOZ%P_P@TGXP)0UQ"I+^N5HM<[A]VUUZ*#.3E9[8
MH"H:2$PJ"NOK/Y-#/W6'%<R,O:8NX\'@D4[O$+!E!;IX<SZ5T:8:&#CJ]L)(
MWTN"=4BK^?75V@,<9J4/L(HG8`*AN>`NR,VC)-L'\:Y/O(-T(%;93#@V!-XA
M**)J>GCJ]`XYT+1)NW'TBYH``?+>/L/W2H@FA%`[`P["()'^3K3=""9@)W!2
M$HF4D'H3"@C$$ZK!VK?[5KD\4:LX4-H+*W"DM]<M3<')N*UKZLT!.!WE]OOD
M>&RQZ>1X&U)_W.O!%AJKN!O/)%L#J*M8P0W%="AA^5&Y%"ESHYL6>Z&QN`,V
M0,(?)6A@KY\R*G#`T:8F*G^A*"P\37'A:FWHOCMT\,'9=),6W3A%T<&KG_@Y
M3^N5JF-)KX`<[8E!Z`C%#(C^YEODL?M7*];!-+\1G(`#F$B\9WAR!J?1P_BR
MO5]F"1R]2-!83&B,</WC!D1303KT"!T*\5CF8J:2/3B5QH-;"$)9W9>1ZSC@
M2';Z@'H/BV.`"4]DMK-QAO<8M5<&>`>>&1J>4/Z![2`S>`>!.B@+$X/2%&>B
M)+JI)Q.@V#@18X!H$?_UP][P>`=3<K^VE,PSMRR+K<!,R\^?4V#A(:B&AD@?
MER3&$F1(Q(GC<56.,<0:AEGM=87AP>3!&0SY+U8X3HEPG+TXQ+=`]$20^JM'
M44VJ`2!1V&BH-2L*$101'091;`UBC,@I"6=QD',X;<\`3,H6<(!V8;*!7!`/
MF*83[3HW,,@!HK1*$=[9Z#".(_[,(!CD'6=QEA7^8&\`A&1`^_\J#KC_@V10
M#Q;L6`$3K%;H%EVO[J%T7$T`,:"FQ`P!`(BSB[>AF5E,$O!`%E`$*!E-W#QQ
MB):TPC/O^<X_"A"4WH6:7`Z`W,IF0J[PM`US3[TU]R4<@HA0R-6&2Q?_C1`Y
M8,5!OEMF9,)SADM[:O!1;47_C;;R66!*PO]JJ@2'S#-,1Y1//_6`'#]VT"V;
M,>KM*]+!O"@U'Y8\Q3"6'GI2P53.+;K,$E0F1%4,JDKE?_!K,%,X$CKY````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S,Q+G!N9P``````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#(V-C$`,3`U,34T,S,W-C8`,#(V-#(U`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````@````
M(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D
M;V)E($EM86=E4F5A9'EQR64\```%0TE$0518P]67[4];=13']Q<:WQA?:+)7
MOE%?+)K%:$QFW+)I1F)<AH*ZS6G9&`XVVC';TL(HT"'EJ;!>Z`,/`[LG"'%J
M<'-T9[_/^=U[:<MM`8T:7QP*M_=WSO=\?^=\S^&0B!RJ-OVQOMHOH_'SLOTX
M;9\69OID[M9WXDS?M`^>K"=E.MHN\L="[7G?QW(Q)<YDK]@'6UD9[#PELR,=
M(L\>V=>^^>AU*9<&Q#_BVY.B<$*>KDF-3[X`RHH34W,F>F0,%)7?W9/F1%_K
MN])Y\K!TGWY#,<]GXR+/G];!-"<`PA>U(9K8SA_;CRW`K5R`!P/R;O&6+.4'
MI92]*=G;/0K0?Z&\."2EN:@LY6(R/]XM^:E>V5B\YKU0D<E4AQ*3Z#@NZ9[/
M92)Q7N)73NQXN)-H5?9)<>1JBZR5AN3/S505DP8@]%X[>T0>+*4T!)[KTC0/
MGFV(;&]*<)J!5O$][<V3=\!0LO6P7U:7AX6Z6)Q/ROW5,;E7C,KSWS)-$)@\
M.,B!NX4!*:^,:`'<'@@I(Z/A%LG/QF0XTFXOHS;'BCZ$G;PI7#XIPO"Y]Y52
MN'?&NF0F?44F1W]09\I'#0+C(!W^0L8CK5*<CLBCM6%Q1B_+M\=>E<AG;TGB
MXC%%!XKB9,A/9<>!J0]R;/_@%0D=?TV->\/93YV?*`+*9"47"2CX^I(EG6Q(
MQJ^>U,K(I]OLQ>O!RD&N<6_[IQT<N)`LF9HK=ZT-F-7BLJSO=E9[V.W:^TLQ
MOPJI"2KQUW+4.FI(HF$?.:0"O<-8+M.KS4P1Y2>Z=SG9R=4H)9)`&2,/1!T,
MGU&-[#KSIC@S/ZJ\JA)4]8.?-Y)+1(KEYT)2EN?Z9&TAH9\4$8[05\J;8+4.
MC$=4';@/2E:8+IXZ;.L_>4$/(CO8C=`)2VQ-,YG&X"6:!NDE5]2%W^D!$-%`
MI,'HV.W`L$_IHE=`QD`2^^JH]D3_N0\U`!I!>]MVKN.`&^!%VM@[B-[3B2""
M`\BEG8.;R3P$)@."_.E*AL3BU'49_OYCY24_F]1`#6:#E3.NK*OE;76`-I`_
MZ2`T*)8G)(TUT2"A==%R6AD]_V4E;/.F4O?53$"D6!AEF,Z9X*;Z[_7@7P10
ML;<''7#)950;E/&=WG!S#3J8H.'4U2=$GY[=7.W3UL.8'GPB-WRGPX\+YXQ>
M^D$%T0O,85.6U"T!Z"(41K<PTY*%.W$U3[;*RR/"'L+88D%B^N@@:2*F>RAR
M5C/%,1*'U&'H)89.L*HA+FQ$=#!2@"`A>SRC:YFAR@H^JQHP&(`;G`-DC2.R
M5`!FNT(*R%(W+CK;K$&Z1IB_43X6+$`@&[`$",1K/'K6*D``B("1DM..9Y2P
MF^",X`0DF`8R"DGV.O3C7UNM0K-=8WIPCD\,#6>V6S%HN)ZY^YNA'GK)G%&$
M(_YFA2006:I<,67<;0,PGIRS10,*\V8`DTE73F0<8=D]TKS"VU24T\DVW9.F
M^B]H4/20HBK-]/H3BFG%=P!!@!%<Q!?])#A`O%V*$:`+F0+8:`3`K0%3M6@G
M.@K5.(0!5)WI1A#N&?/&!@`PWE4`D3:MEX?W,EI'`*"@=92ZZWMC,7?K8'WA
MLDX%;]&[WGI$C6WQR_=>UD_F%Z#8(F$)D'.I2WHM6J0F>-$9M(N`?__[V>U`
M:9B@CZ'XTW=>TAG'/P($]XR!"5-<%8PP>6"+X$[FAG8)XF2U(%B4FJN@*T:T
M)54,"((.73JM-!<R82U4NH'?80(6R%C;CL!U=_[79H$W'NEC_:>R:FWT+6?O
MF'<(NL^9\#<FF;?X5MO_<!R_`+R2^CNG?["7`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO
M,S)X,S(O,S(N<&YG```````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C<T-``Q,#4Q-30S,S<V-@`P,C8T
M,S``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8
MU$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```5V
M241!5%C#M9=-;%15%,=?*:V(42'12$*C"7XL6!%#="$+7;!18T+<Z%823-Q@
MT,1HXDHD!%'C`JP"30S8-FB;EM9IA;;HT`\[:8#:BNV4*"W8CU&IM75J6J?'
M]SOWW=?[G`\&&A>W[9NY[]QS_^?__Y]33T0\ULS,C/!;'R3NR>RQ$I&$9[[1
MA_$-TKKO`;.]K_.`/OS5N]I\X"[]\?RVN^3@*QM-T$O-]VDP`G>??,QL&ZZY
M7;JJ[G&.M6MI6G@C.=RK7V8RF2#)/ZX*<:7-,^%BGO1\?+?,S<V:#:WUNZ3Z
MG<WZ!6=)HR==1Q^6R<GQ[#0YPEX[.P?)<R]65_P+^7,Z(9*Y*NET.AKA0E^[
MYI`\4"HUN\OEV^.;HQL&ZM>)U'DA(%+KA9N\CL879>IDJ;E!LL0L?W/JU&II
M/WW"A#G7\)0LG?`,#OY*599+3]TCRTARM<S8#AFJWBJ_MSXAX\G=LK"P$(4:
M4`I>,]_J:'I9BL*)NI"K+,W*].1'6FW*/].P2M-+M9>)_-.O56BI>2Z[$LJ`
M^4^52&??+C.PQ9SE0W?XU0KI[W@Z4HPP`%7B1(JA+R0"6'^^360@P-\/"E`Y
M02(J`:@D;-(7!H*5"$I0:P(LS>W/3:;YN5[=6/W6@Z9N=<&J-;6CX-^U[?2W
M+F8'^.7:6'BO2]^?DA_/[Y79B3<T$TXTA3<OGHD=*I[.3?7O%E?&7,L5SBT%
MN!&)\@;XYLPG6NN+]?=+:B(NN(5[%=PB*T#SEZ\;._'9AO[2`]L5=737W;#5
MH.^S-!Y[328GKN4&D1>QFY>>W2A5N\K5%:]\N$K>?&&#3)W=)A@:!V5=`:7]
M.O6#<O[)+>NU[DHF2V.?"S"4X-#=LC"2`<Y0N6>-(9#UMX3#0C\@ECS54B:]
MYXYD!X#?I*[,:PLHC`Z2):&;PL;!AL>-N]D`(`Y(>)#:;YVC`[\K:)`@"S!9
M;/+4O\EX^OKU93"@J_:$6F_9PZV8XB:#9.5:&>W>KB6.7.'RR*":">F%7M`6
MO!A?]@/\KN?SBD@EG#(NRM?'MN@IB7UK32:!&@%VZ,A#QGY]GN1D(EF@.*Z"
MG:%[4#]?]:B6+SVR0ZW,M;-(@-Z>9K&9N($Z&Y^1L9&#8>DX"/`*:L&J$-KB
M$_P].CIR\[:.-ES6W5)?*+1HF:R5Q"AZ([C1>UQ+@#J0V+TEGP/AC6Z>-P&L
M@EM%W7!1\&F*.SRP7PN,]'ZJOT.U.=2W4S];F#NN+&%F<8V?9)@A<M4Q9U:X
M"S>[TKY>@]$<<)J6]^]5P\">T#W29?',@/+5>W=J0JB-A`8O?*:MCC@D<!,E
M6%3!H'<\@EZ)S?%;W<H1F=OZ^`XE']ZS206)FD\?VF1<W4$D;P)0'ID#-9+G
M96ZJS=H>&O/".2FTBGCP'`M\V-^+&R!BC)QQ@LN`9O_%3BF,@&]4P`>,0$MG
M"`W>'NH:'79KIX>$DTB0!)>@+<VF]D9,,$P`9E,?1(]K*-'\UL.BOCJLVYN[
MAV/3V+6U;)N$1:/1V#=VQH0&86FR*(=N#=$C=LYB,J%>L!IC!7YZ8@3ZA'-S
M#K9-QTT@:(,T(#P5!(A);'?$SBH!&L:]8"YLAM64(9RS8O\I@[M<'C@=P*+)
M5/#W_&^%94@Y5/_4RF_>\`#IT>AT[+1$=!N^78W+:@!Z#N?_%>1++(8&".B.
M)`6=D`$PW5FJM8-(L!E64U/(!;P<Q.)O9,>A-$U@UPG$1P4UY6LD.1,``>2"
M;+03^<,4GC`]^8$.7+0X';J".8G;DR"?M1^MD+'8&FU_O`/D=N;0:6\EO0#6
MZECLCXE:(O\`N`)*.)Y^YB?+0>[X[-IQKOZPHFY(DT=6Q4S1_TL[1E+Y_O\K
M=OT+\`K`,@5>Q@H`````245.1*Y"8((`````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\S,RYP;F<`````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R-C4P`#$P-3$U-#,S-S8V`#`R-C0R-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````(```
M`"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!
M9&]B92!);6%G95)E861Y<<EE/```!3I)1$%46,/5E]MO&U40QOL?PA.\('A#
M0KQ4((&0*E4JY58J)$HCTJ(&"&YPZ=6Y-78<)PV.F]I*7#O9Q':<JYM>HX@(
M%%H:=SB_.;L;K[-V$A`@'B:[WMTS\\V<;[XY.2(B1QI-_VRL)223Z)*=K8Q]
M6BD,2G&L6YR[-^V#IT]&)#]T3N3W4G"][V-Y84SFIF)B'VP7)!7]1(KIBR+/
M']O/OCO^BJQ74^(O\>UI55@ASVH2\,D+H*S,)=3FLU=E,FY0U']S5YH5`QWO
M2O2CU^7RJ3<5<ZD8%WGQK`FF60$07@1#M+'='SM;%N"V$^+!@%RMWI*E\JB"
MO7O[J@+T/UA?O"75F;@L.W'-@"IM+%[W/JC+U/A%+4PR<D(RU[Z47+)+$M&3
MNQYFDQU:_=@7;\G$E=.R:FK]Q^9X0R4-P'/'7I7K9X_*PZ5Q*4\;#,9S4YKF
MP?,-D9U-"4\SU.J^I_WKY"TP)=E^-"RUY;3`B\7YE#Q8FY3["T/RXM=<&P0F
M#Q:R8+62DGLK::WI[51$*S(1.ZW[F^X[;S<CF&-='U+O^?R`7B%A[X4/M*34
MWIF\)(7,)9F:N*S.M!X!!,8!WK-]9Z4R'9/'-5/-3(]`7LH__/UQ10>*A:F(
MG\JN`\,/<F0[NC]\30UJ5@VB.]%/%0%L6)GK"R%\,V4-FEHA(MDK'RLSRIE.
MN_&ZL'Z8;=S?_FD'AR:2+:;FREYK`Q:47+;J>YT%%[M=^V`IKBRD06E4F+BU
M/F0=M2RBJ3YR"`,]"B-!,]E>W3Y(I%W6Y&0W5Z.41&0Q_0J11GO/:/?_=.9M
M92CRJDK0T`]^WD@N4>'_O8JY+PQ(K934*R3"$?H*O0D6=&`\HNI.[H;V`8NZ
M/WM#%^9'NG0ALH/U1T[:P@::R30&']$TY$VNJ`OW]`"(:"!28'3L=6"J#W71
MJ^790;6'U5&)GW]/Y7KXPC&9&>]1C:"];3LWU8`=X$/:F(4T$WI/)U9RUZ24
MBVEQ57-#F\D\!"81OS7V]?LOZY!8-*W]\P\GM"O+Q1$-U&(V6#ECRVACVCI[
MLT/S)YUR?E`5RQ.2UIIHD-"Z:#GB@I[_LM)K\X:I!VHF($(61AFF<R:\J?Y[
M/?@7`=3M[E$.:LEF-!HEXYWN<'L-.IR@X=35)T2?GMU<&]#6H^$Q[I$;WNGP
M8\-9HYM^6$'T`K/8T!+>$H`N0M=0&UJRXB35$!`,&?/.(?-%<YJ:C=E!TD9,
M]U'D@F9*8"8U@3$"8>@$1S7$A>ZD@Y$"!`GIXQE#F!FJ5<%G0P.&`W"#LT#5
MS62Z,)M0"?"N9(DAFPQPP/$;Y?..$$@G`QP0B!<-K0H0`B)DI#C:\8P2@N",
MHQWW!$,Q44BR!T`V\8T^\XX?WA&$=5P!@88SVZT8M#R>N><W4WK*2\;L)X[X
MS1&2(&2)7&$$0_L!X:2C^AXIYS?FS0`FDQXYD7&$9>](\XBWJ2CS(YURIZ]3
MIH?MP0H]1.(15LA%8*85*@T0!!C!17PIMP(R7("<$)(1D.G_R@6PT0J`RP'#
M6K23(Q&E1D^I`,%UNID@D`WSYHUG?(L!'KX\NI]30@(`0NLH=8_OK<7<Y<&3
MTH^:G7?0N]%Q5(W3(J.&*_,+4)1?Y[@!R>!C6S`F"%70@X"__P<YVX'25((^
M!L2I=UX*S#G/&)ADS%91$28/U6+VS>7ZE:2(D]6"<%%JKX*N&-&6L!@`!!WK
M^5S+S)2&J`3DGDI0!3+6MB-PTY[_M5G@C4?Z6/^I;#@V^N;8/>8;@AYP)OR-
M2>8=?!OM?SB._P2#Z?J/-<BB#0````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M
M+S,R>#,R+S,T+G!N9P``````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(W-3``,3`U,34T,S,W-C8`,#(V
M-#(W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6
MV-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```%
M>DE$0518P[6736Q4513'QX4?+(PA,>I2%KIQP<:/C<N*QHVR48R)2XNX(Y@H
M*T43#`%###8@")$HV&AI0TFGM68B#.T$G,DPE+9,RP"=TND4+'4RC\ZDZ?1X
M?^?UOGF/F6G'$A=G/MZ[[]YS_N=__N>\D(B$L$*A('R[?Z(;)1=^1_C6.^/]
MVV3VY@X9.-GJ+K\8W2M_[%LOD@RY%_RF'SP_>'R+NVGZS(N2'_E,"O&M,M#Y
MDKLL_>-C\M?A)ZK'>K94E-'P,S*63NC-2J7BWIBZ=56RD1U2&GU7G.PGDA]K
ME\3Y8Y*?SKD+>CL_EM2!IT1Z0E*)FDOM(8G]]&QU@=\XPH9=ZX,TB`N+17^5
M?V['12I9F9^?#^Z02I[5P`$`&PBW"A'H`GYP`2!*XQ^*<^-+&4^<%/#4,"-=
M[\M(]YLR%?M4$;\]TJJ_03#2?\P]YUQ7BX:F(9I0"7FPX_DJDH2VE-TLX[^\
M+'/A5Q7[A86%(-2`LF*8C0R4F\()=-57D]"YF?T2/?JT1']^17(=#ZM[T[\_
M*K*8TBSTGG@[B"-P@.6-3*=$NW>ZB*3WRKW<:07_[MU9R5V/2NIBM]P<Z9>9
MF0D)L+A<+LOTY'E]&-8X8SN5-:6ICSQCPXGX$671V-#WXCC%^_AH4HS+P.VQ
M*NF:A9][0R<VRI*SISZ92LX%79C8L][=R&>7OWE2\8`5!HS:#28G)SR2#5_N
ME:NIW1H&IW.BFWCWP4A?6_-T/G-J5W-IK&?^PEG3!JN1J.$&&J/)RE#7AN4B
MG!5_*+;6`AMPFLJ)8=N5CL>E/+Q)44<<$"1%W["4;W]=!$[F1+APK?TMK[JM
MP4[J%D]J/""%G`[#8.*=Q"XI9`ZJ^X6YC'Y#8:@,8Z&V)QF6RG_V?2&QW[;+
MG7-;I7SI/4\$,3;S:#QX0.*Q;H\S"@CI@CCIWNUZ.K7@KP/^YZ]\IP^C1WCA
M>8#N`!(:=.W4!UX(Z)/5**M3W,M'7M?LH&6$X@$(70>^7E?5KF1M,5$/$X,M
MFN(`B)G,J(H)7MAJ]"JRIUJ)Z!UI]1/,E\9%Z?OV.;G>]HC<^^&A0"7R/W7X
M!>4%/*G+1+S0BBM^KG*&PK(A#]+,R`I2YI>SP`:DQGK"1F#"1A<,>>`'*;0'
M`=Z*M6"K$(F#9/;!_UR-L-,VB#65\VI&R\0>9(^F%X*;57(K"5`'$ONCM)6Q
M6N0-'4`JB"JHAHN"3I-<2HX$4QW(#@UO-+Y-KRT4CRA+J!*_\.,,?:]>'NMZ
MA1-$QN:0'D&@NS*?46V9_>N4V];XS\3`?9[1:C-TAGWLP_"``TT@L*@B`=1(
M&(>C@4P_",WPV:]4E1C3Z-2("NNL<0W9HR0PA`?Z<YT4HF!^+0TXP`T@0G"!
M$.6F#%3AC$0R82&35BJ9MNS$Y4RWZ1B!X91UA*A)G?TFM?SV<R3@`!<1\'SV
MD$9[*;Q;)10I9;2PIH<N:[7*+;^-Y-K[K`<I$*`),`Z"&GNC_9SER3%PLXB&
M0-28A9O#%7*S(4T!(UIKD`[C=_'6/F\-AX$`#I`*=<8,_:B25HXY`S0"<HZ1
M(R"$U;P=#!U_329/;U*C#T"N7/R-%8UU&,J-CM)?Z;/LR=X@T)"$P(+GM@)@
MO*?LOA9AS?8:[[^O==@.P)L)Y4K4Y=+?*Y<AZ=#Z-W,(T!(1I54S[/4TL.7[
M6I;F<+H)Y<M>O/!`P/M']88*Q7!$5/0P-N(-CDUQIIX.T&VY#_2,L+0PGJ>!
M<GC32J@CO*E_2E&]-<,4392Q'RAI<4ZR1?,,O$2.@PQBW"-UO*7P#)`3""GU
M3[1KZ@6PUAT99]V9PAP`N8@2MNLUXRQ#3KW#*/%Z_>&!NB$J1W3-3-'_2SNF
M;!N]_S5K_P*:/E,\&85R_`````!)14Y$KD)@@@``````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,S4N<&YG````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C0T-0`Q,#4Q-30S,S<V-@`P,C8T,S$`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```"``
M```@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`
M061O8F4@26UA9V5296%D>7')93P```2W241!5%C#U9=O:-5E%,<7],+>]+("
M$X*R7HB^L!<2O5@1Q408PL196A"ZFERRV9S&6#3GG%MZT6VNENVF;2E=-]<<
M=\Q[=1)M#OPSR]I"HPFVJ"[=UJ#!4!G?_!QYMGN]OWOUWK#PQ=GS_)[[/.><
MYYSS_9YG.9)RXL7^U#?LU84??M34U-3-5=\[%:K;W:R9'6-CO^CJ7_?-+B3I
MN#AZ10</=\[N:#O2I?>V^V\N7+MV73T](6W;%TS6<>[;$7%\=.PWM7>%$C<\
MF_NB=OB;="04$?,$H]/3TYH[[W$M6KQ$S[^0IP6+GK8QR43IQM?EZ78ZF9F,
MC`QK:/BB1BZ-VGBBKR_1!%[S0^1DOPA5D@:"T7WLN$JV5&EB8B)Q0^&:(BU=
M_HHJ:_:(R'.;A`TL<+7Y3RTTR<W+U^&.CED??"?ZA9P=?$!%Q<4S/R;X<.',
M$TI[S6S%<Y&$NL3^_&O48A>*?&7N%:Q<K?+R*L5B,>^*8@/A.CEX1BW!+RWY
M''ZM:(.BT6CZ5'Y^**CRK;6J_RA@(V'=U?B)7)CW'VA-KX`08XD#VSYH-'>I
MY.(-FTTALN297*54T-D>UO;Z1KO_3Z.7M?_00D-/066U99]J2.G!P<^Z5+;W
M0_T9&U<@$+"#:U:_I"V?;A*%Z'7X[J7Q_U<`MDZ=_\X*"($E*"IJ@]_BZR'I
M,+DF"[";JT3FI66;K1)),8664@%%!*JQ/'!ZR$:LH@"Z3'L%Z`E.I'218$>/
M'4:P?ML8-.UKL3+F0*`M:#@`#U0BKM]6`?4.>U*^ZWSOJJFEU4;DUA+V5``.
M4`)Q<9BN`*`<F(A#2@7P))O8S&&4K5U?:J!BQ"NXS/%ID@*0]^AC3QKIH0BN
MAP@A1)H!(PKREBWW5D#?*6KZV$B9/'=UAO7'V/UZ+G>>(11T`JJ45VAH:%-K
M;]@:%PWLRJ4Y*BQ<K)VU#RGZ>\Q8-VT0?=T134[^;=8Y!$6W-+<I_]5EYM77
M@Z?O#,Y8[^N=KZ'SYW1OP/D_=V!\?,+0#F`'!DX98)E37\39K1%",D]U@-%_
MY0#\`S;A(]X`T`L<Y03*@7H0V,/1$0*>P?@NO]^<I%`R<@`*JMGAM]LY`RC&
M$4>:?'-K!&.`JN3M,E555:NNKL;Z(<4%#C)V`!H[VA,VAD(1QERK1QQ;8YS;
MTO8Y$_\(RKH&4`(-T)!)`0;A&>88Y)LYW1_2@@EY'N*`>WMD[0"A=_P#H<'3
M&,((WP@$YXSSLH-V"3_4Z_6.R<@!0EE;WVR"8@QB!`<PBD-T'-Y#T+=C8ECX
MY74^B\2M^<[(`4*/$HRC$$J'YBS/-U+".@XQQSE&]N`,([\3/1S,R`%"#^5C
MG%#B"+=S-T18(]3,W:.-MHEQ1AQ#T(,.'$G%!9Y>0=ZD8.V!+Y2WL<P4`2N^
M\]]XT^"%L545-YZ<@0=5L.(1>P`B%"!G:0[L!?^\]2`H+R=2LAVD`\Y!`J_.
M]9TA:U<HV?K^2DU/YNA8]QQ[1):\];#AGX=EI+=?FX)'[3&151'"8O1$#.*U
M4TBSA<DJ*Q:8<7IEPYYJ:[I$`,*)WYLU"K@%&(]7P+\]SC`A)Z>.Z]O#QVV\
MZ\T(2`U__\T=$\P]TX[_`8&KF9@2S6#L`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O
M;2\S,G@S,B\S-BYP;F<``````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-S,V`#$P-3$U-#,S-S8V`#`R
M-C0S-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````(````"`(!@```01]2F(````$9T%-00``
MUMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```
M!7!)1$%46,.UETMHG%44Q[\\:C9B2T$1P>)&J]"MCX5NM+BH8G7AVHU@!`N"
M8"C=J+38"$T0:4I(I8C&%!NCC0.IF6([:1Z,#2%MF=`D!-HF)A-J,\:,G8%Q
M<KR_<^=.[F2^&<<4%V>^^SWNN>?Q/_]S)A"1`%E=716N>B/10')?6-$WZ:XZ
M6;N^7?H_V64_'Q_^3&\RE^OM`U_T)]<92/)P@U4ZU?^@2#R0Z]U-,OK=,_8S
M;L9/;O>.=;*>$G;,3,?U93Z?LR]2*W,R>J11)!;('^V-NL;&=#IM/QCH:Y;3
M'^\1B03ZD?0&,G'R*4DF%\O-Y`CG=KD-4L$O9&3HC/R9^E4D/R^93*94P\3X
M>9D]OD,(`,8M?+I3<D/M&V[._="D!A(=O#BROU%^/K';?H`'!$8_B)GP)0+)
MG@F$3;]$3]ESAL[N$^DVRZ@5CAO[_HF-(W!M_>8;,M/SM*R<>UX69S\H&EKT
M@J!4=;.28&--<2(O:FL^+:GDYYKM:]\\*:E(@^2G]EH';T<T"^=Z]I=G`@3D
M[WXILYU-UF$3E7=??D!RS8'</E`G%U^ID[Y7Z_7^Z)M[RGTD2P`.`"LH#`B/
MO=4@F<%`I:.Y7N\!R_3XVP+42F-@4CSRXW/V(X<JHX2\Z#5J44:DU].MX6#*
MI./ZX:F6QZT;O07IMKE;/ETOPP/-Q=-+%/RV<*OHU]35?IE+M,K:4HM:PHDD
MWFV,#9ZH'<X#/[75EL8P\0MG2PKP=TL*U$>3E<F^7;*\."2PA>]*:!"!K-+)
MWU>TE/Z:?$FC#AI)KUJ32N@UN;00'D2J"@@GCC9*]G"=ID^KW,B=CL?TV=I'
M.Z3,!2H-[LK.OJ:;R7VVI5[.'[I/JQ\(`V>NEPTB9V82Y19@6N^'C<7"ASJ@
M$)")$K@&A4`Z?JFK7`$D0/$H\F(6_Q>Z'E(%K@90T/9^DV4WIP#>(4B4;8D"
M0_YT!<IX87";\M;:5X$&EE@1]-3*RD8P@&OK.X]N<)<KI$2AL$R!73NV4^9'
M]VJ*2UP@*)#)U-EGY=L#VZP5T<+&J-V,8OANK.<1\5DJ\,$!UT(H^+JY&FD6
MF`].0I&(%50<KA`\ZIY&R$:P08JA,I_.2A3$QR+%IN84L1'7*&V7.@XB>%5K
MP54AV(`G6,_?FO[OM*Y$ZQ7.EOI"-:%E(O>BH^8/B1N]Q\\Z`$9\+UD3PG_S
MO*(!4`5>^6R(,GB:Y))0$DSI03M4"6V&9_0U4*(X-0U2I;"?&2(LCZ%6P2YX
MAG*4T1QH_M'V^W5"@G&T_Q7HBC7D00U0TC<NO"@R\KK<B!S27LD[UC6G0,-G
M"@8(,ZMPX-)QRU3P`50'K?',K;G2M5TG1]P][Y8/[BY)8:@!0!Z/"34E3T$6
MO>TM4(*A!D@9BH0V4,Z:*V2FSPQQ\ZSKO8>+ZZ\[]JGN*Y/#4CT"AJC()V%$
M@2-X=SC\1!2@6*C5K;ER$"DB:CR#W]T:S/@D6#2`L``0BIZ0XSW4B^"1AMX9
M4!A7H.C.@PT:)=88X@")^%CAGF_11Y-U_1&@E]"Y&_'HPJ`:8L4`'=']",0W
M4;TO<8^]S1Z,AU/A4W2BVQ^QRU(`^&`OD.L\P8C-&-!(Q#QC8IM:A]<!7#3Q
M.IOYO3H(B8#6O\D5-4WSP@@:74F+B520PL%XSN$(Y:NZ#`<`P,VC>D6&8CBZ
M>ZE!<TLZ[EQ\0172HD@+AQ`9A#73)^]IFLQ"^G_,1`6<5&HDH080`<H%1M,!
M"C8SG)!*MNDL0&DR=&&0_K\Q8<=`_@;PCM3!ENPAY#@"\/R)=DN]`-2J$C,F
M:CF9`\`*4;HZT6V?&6,9<L(F8L`7UA_NJ1O2Y/&NEBGZ?VG'>.7/N5N1?P`F
M#Y\BR6S/&@````!)14Y$KD)@@@``````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S,W+G!N9P``````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(S,C(`,3`U,34T,S,W-C8`,#(V-#(U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````@
M````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E
M`$%D;V)E($EM86=E4F5A9'EQR64\```$9$E$0518P]V7<6C491C'!_XA8?XC
M_>$_1@0J!(FAK<16V!!"&S34_E`H!C41$@J[9.YFSO.J3<=Q:,/FTC6WI6UI
M7:QY0VHF%S57RYW-Q=QP-1IU8+#58+#Q;9]'WGFWZ[Q=FP;]\>Q][]W[/N_S
M/L_S_3[/+TM25KS8G^'A85WN[E55U;&;JZ\5[5-E=9VF=B!_QN8E+B3HZ.D;
M4.7[M;=VO%?3H#=*_+<6PN&P$HXXN7'C#T7:.]1V,:*QL;'$2]8\D:N#P2J=
M;0Z+>8*&T=%1+;E_J98N?TCY6[8J>\U36IV]-MG,O=[M&A\?5Y+9MY.$'^>_
M:!-RZ?O.Y%>TMD7T7;1'%[]NE]?K55=7--&&ZI,?V1-W%?F3;=CE\6K+UI?L
MF=L*7M&33S^3>,6*1QY3O"1M<'*]9[Y2OH+X3??!C/R0D9^<U#>>54=7M_I^
M&3(A/\@QUNH;0PH$@LG!=O)R8:&:/FE6YY6K.G6FQ0Z;^R8]E=8"T@EWOAVH
MU/ZW*E1<6F'S@AT>Y6UZ,;T"LHC-Q")P](0I*]Y_2#M>W6,9751:KNKCM:F3
MJ:RL3#S!X_$8IC9L?%9Y&Q?8G/0X?.1=F[OWIW0BP"2FH5!(OP_,4\91N!+M
MU*S"..L\F!,%G9>CQ@X`$(R1"WU]O9J8F+@]I(>&AO1EI,,RCRP<^/4W=??V
M*]+199E()%"84@$)Q`$4?/O#CY:1*"2\/M\!BPQ12JG@TY;SJFEHM(/,4<08
MSX8IGQ"+Q2R%(3\H!)XY>KQ!15Z?^2*M`L@0!27^0]KY^C[Y#AZQD53.S5V?
M7L'N-]\QT(`'&!T!4&`"2:L@+_]YVPCF4<+-6`&X`-7Z#9M3,Q)D]\"#R_3P
MBI7&ZW`]Z(0`.<C_^<TE_ZA@<'#04$BX'/I`8OYSZP1*B3],-#T:*3,Q'+I7
MR+G/BS-'8S"PW0[7U6R:5/!!9@I:6PK5_M4]FBFDDQ9&1D9$0MTU./_G?'+7
M#*#>@U$8`@'DT9_ZK6XQ(O&%T/4*U#@8!"Q#5?_*@-J3=5-*$2YW%\-W"&LP
M$!>"1JM(DZ!A=-B`4#/ND0`/M1#%"%QY]5J_D2L\Z;P`<T$!4"$OIG-#IC-X
M1A[@,&T??2?NQXUP*RT#PH70):TL%R.\'@/F)`>H`'`178)[':W&X:H3=C'K
M\';PV(=&NQ`@O(779FT`;J<=X1+X'2_0FC#W%/NMG70>@'6A<5B7$:]14&=E
M`$IX#<I1C&OQ`"%PA8:&%Z/XS8@',-K5#RI9?!LT8P/(>KX'7"G@5:Y0.3=C
M((;M]9?K0'G`#.+3!L%#C.Q#SZG339JQ`<`$]P,?:A/?']2I[.Q'K:SFY.1,
MK2]>O&A*^#_KB-N',"<G0$1&(<!UM!_P.K6.WC>^VEQH76B-(U7GXZ:;%8<S
MU()X%,TI%:/PLS,KI;^R%*Q8I9(]C]O\7/,VW5$JQGVGZPO$EP["Y=!J+';=
M"C8,=T<-^/G::GUSX3[Y2E^P</ROJN'?,7>6M)5#!3,`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C
M;VTO,S)X,S(O,S@N<&YG```````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C,Q,P`Q,#4Q-30S,S<V-@`P
M,C8T,C8`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$`
M`-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P`
M``1=241!5%C#Q9=;;,MQ%,>7>/"`2#QY$2)!(B$$0V(1)/.P$#/!XDZ,N#RX
M%+.2T;G,T-1=D8T9QMPJFZV$(167R5BQB8V-Q4(3DHTE2[8</D?^U:ZZMFP\
MG/Y__?U_OW,_WW/^42(2Y4OZ4U]?+\]>OA:[W?YS=U5RJAP\GBW>$]!73R?_
M#3\>%54U<O3$R5\G#F>>E76;MOW:<#J=XG?%H,^?OXCK48D4WW-)4U.3OY#1
M8R9(ALTNE_.+A+4?A\;&1NG5NY_T&S!0IDY+E.C18V78B#&!:FXV+Y'FYF8)
M4+LM\OMSH]@E-VX5R^,GI8%6\/*)NUSNW7\D9K-9RLK<_CH<.W5>332EI`7J
ML,9DENESEJJ9LQ:ND+'C)_J+&#QTI/A2P`&#JBLZ2U`KB%]K'X3EAXC\9%!V
M[F4I*7LA5>_KE,@/<HR],Q<<8K7:`H-MT.*D),F[DB^ESRODW*4"O8S[EJ_:
M*"$U()UPYXZ]AR1U^VY)V9JAZT7+ULFDA#FA&9!%'"86UB-9R@PF2">C6=LS
M<X(G4WIZNF""R632FHJ-C95)<5UT37KL/W!0UX;]09U(81)3A\,AGVHZ2<11
M>.XN;?-2Q^=!NS`H?>96=*``J3%RH;*J2EI:6MHNZ;JZ.KGM*M',(PMK/GR4
MEZ_?B*ND3#.12,`P*`,2B`LP>/#TA68D#`FOQ9*FD2%*01E<O7Y3LG+.ZT76
M,.)96%04.A,]'H^F,.`'A(`SX&JRV:*^",D`,(0!M')MJE@R#NB3]/9%D:`,
MUF_>J47#!30@[\G_A)F+E$(RF!@W50N(FH<)A!84%XQX'Y0!8`>^#QH\1'&=
M=71TM*K.1=Y3K9.G3/M]'M36UFH5$BZC^JC$^"GCA"HE_B!1ZV@$S<0B1U>!
M"@M2(J]&FW6)7CZ=E?"#P<G(&#BO)\G#N]TEW)(.V&AH:!`2ZI^5\W_'DW^F
M`/V>&@520`F*W/WJC?8MT(.UT0C+*ZN]LP(]#@2AEH&J/U+@5/9I%013".$(
M02AX![$'`B$P<?8\+1Z*AJ=1&P!JQ#,2Q</8!V,(:PT+P4G#"R`7$``48C&3
M&]0:P2/R`)<9^U``]^-&L)61`4(@@,4HRSR"\.F)\U2!=LD!.@!8M.]HI@I#
M"*,&_\%II@=0TW;LK!=V<3E>^VL%L)IQ!"$@*58FIZ;KFCF3<1*%\`"C2US\
M0D5=X!RBH?Z5`K@>:V`.Q$.XF!`8C6;UAC15BO\HA@=0FMX1/V.^=C+?,2AL
M!<AZO@>,5@`SHU$9;F8/B^E^:;NLJBB?-A`>XLDY^)S+S9.P%:!,4(#+]":^
M/_KT[:^]B6$O)B;&N]^S9P\O\9Y]",4Y!W&'G*`B(@H!KF/\`-?I=<R^OMWF
MCK.;#HYTG8MY/SL.=^@%OE74KE`,PVN7AHA\BQ+;GF&R:>,H71?FSPH[Z_](
M`=R7F[-`^-*!$`ZL>CS5VK#?OBWO6`7>50[7'FW9,E?#\5^:44?1=Q@UEHTW
M7)8S`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\S.2YP;F<`````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R-#8S`#$P-3$U-#,S-S8V`#`R-C0S-0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M(````"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R
M90!!9&]B92!);6%G95)E861Y<<EE/```!,5)1$%46,/ME\MOS%$4Q_L72"0V
M%A*)2,0""PNQ($$B&F)!/(J@\2AMDTG'8"BC1@GC$2;JT5!%-$T]HJ/H4]II
MJZ,Z-9@6$UUX1,*F"4D737/T<R;W9WZFE2&(8''-Z?F=>^YY?L^1)B)IB4?_
MJ:JNETL5E>+8NC/.]1X]*SY_L:S<Z(PS?,&P]/;VRJ9'+^WW+1U7`]5RYL(5
M4<:D:3-E^MS%LF#Y!DE?M%S2-CM<LJXL(,'F%K&N)!X$DG1B3_FU2KG;T"(E
M93>DIZ='[<QU%\:E_%5U8H2RFSIEI=<GH5!(/G[ZE&SFD&:G+.`OOBC#"F!<
M\:4*=0^_;0+<)#I+UV:+YZ!?'C_MDINW:[_$X?"I4OT($T$3N7"X,ZZFKC$H
M>8UA>?WFC3)Q-?/@B;B&W:T1&1@8D*RL+!4@1:2JIJ96OM_-'SE#,DG#B=,7
MI+TS(D^C4<V?I\`K*2G(<>[0I%?5-LG)\V72T!S2>MR8YU&:B/7U]4F2`JJ#
M@]"-._=D@],KUV[>TIA'GG1+46FY5L^.PF-"7@@SEEH*SH4>RX3)4[62EN7O
MDS'CQFM$%R]9HG16]+7^(@--WBP+2`.7<MJZQ.?SR2[_:<V;.W^WK"Z]+B5U
M08T%G4#I1B(1NPLH,`S\HXX3XQ*+Q:R_:89?G\8_1P%]3O%_MP)GOE?H(")/
M-0)J[S]\2*T2,W.W:T&A@`X'*JE*"H<:^*:":%>WUKVY;$J9HJ$Z430D\'%H
M'A"!,N42T)'MVJN_#SO""H8HX&"AK1+1NK7`IT)8P,O4?:C]H3Q__D)?!^0!
M9Q3@)J!M*<!T(L[KO(J_*,0-8![>[(49RH>F8^D+FPN9@<$.=.1IH-;7W%?,
M&CUFK*SQGY=IL^;IBPN]1]3TN>GI"E\V!30.S=0QV+X(Q=Z^T]316,[Z!PHH
MAD;6%D0N`H)TY)X[3>IWQO%B%08L#U4$;'12%FA9D)1.I&4OMW:(V^U6M*V-
MQA03H&]U1I5.4M#?WV\QC6_F\,WP$NF_J)W_+0-H->8_K4>[!5M#VK?T,3RS
M^OQT`VA5^I<^9]:Q##'G6"4`$/YN:6M7%'+D']"VI7&^KK@?,L#@(P]PF%"`
M+-[#-X!#),`/Y!F^@`\=#01@8,H&T(R`TN4K90*RLR;P$-ZBB-4`Y:P*'&B\
MYC$>Q\CHLY@B(T:9^Z0(?0!9XMBU/0[NX@7A)<>ZHPQ.!!XUBH%3/`09V5G@
M$1$>)%70'`Q&EY$A2NC%2,#1C"B;`8`<%["8Q[F((0P%O.0RA_"37QXE)>P_
M\(B<B09UP&$N8`AS$3[&8X#93FP&@'<8L.IVL^(]9T;.-OT=,7*43)F_5"$>
M&C[0;VB4\@T9^!SHB7/2+1E#`\I@[Y`&@.R@.E5L1@+>LFNM.')*7"Z7E#2&
MQ#'8>@`VW\@IZ2NL#NHL`K"I(;SDP&>OAH_<L$48?O5.YQ'6L2TRY+A$_C`$
M94P*'BDJ*M+I8#9(6A!#P`*60<-G3!D^>H;M`A['>Z8E!><)U.O@HY)1QCPO
MOUNGJRET92"@LX_*AN8NJRV&<7>+]X!BAN&SM29.K20#"%-NP7[K?Q<F)0Q2
M4D)(48`W)G_F>!K:=(Z2DL1ONVI:+7[*B]G_8?2[SV=A5:K<*A;`+P````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T
M8V]M+S,R>#,R+S0N<&YG````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(T,S(`,3`U,34T,S,W-C4`
M,#(V,S0P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!
M``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\
M```$K$E$0518P]67;4R-81C'L_G`)_.)S7RBS6:,OICYD-G(&+)&"&/*LK/0
M*F\)'4F-,RIY[1`)I8Y0:R>R4=H:A57>)AL9SASM;-H:EHO?U9XZQWG)R3`?
MKN[G><Y]7]?_ON[K_[_N0D0DQ-WT3T[N$7GX^+ET=W?W?C4EI4GVH>/2-Z.C
MXXU\=@WI_^#EXT7[2RDNM?7/*"ZOD+0,2^^'+U^^2E55I>P]6>+MH^E1FSQI
M?R7M'>_D<D6EYX09X;-EOR5?;-4WA&>/H#T]/3)F[#B9'#9-PF=%R,3)83IZ
MA4A*7"L^80>ROH>VME9I:GTJ;<_:=;Q16^L9`M0DL.96G9`J+P\D@QV06)?+
MY3DA>F6<S(M<+GLR#^L$=N,Q@0]8Z(1):C,C%DEI65D_!M/-.L'N-0R7N/CX
MOA\],#QJ'"\!MSE8\_F1`S4.]O5;A^:NLN:VPHM:&B/;4S/$Z73ZKB@F5-IO
MRJV&1BF\>$7*K]OU?77L1G$X'(&/LOA\J:2F9TG.,:N.I/5@[BDQTEQX]FQ@
M!Z282"PP'\A3N%1RPJ:MZA";-CU<_#JP7;;+OIP\W3^\.'-ADGSK"I$H<Z:>
M/M7@%P'P4XX<E8_.3BDH*%+:K8R9(UM/)PN%>*K\RE\\QG_O`&XU-+=H`6&H
M!$5%;?";>SUX+>:L.07(:50BSTDI6[02.6(*RZ\#B@BZ$[F^L4E'HN(`N0RX
M!>0)320"M5]25J6+,:(/F(/\$P5:QBRP%I4H#^!#?$**0A_0`?6.>E*^L:9M
MDO^CH!BQGTO8IP-X,&_Q&DG<9M;%.(-0!IG(@U\')(Y)3&8QSM9M2%)2,8(*
M+3/TU,L!S$/?863$@DA]1N,10YH!(P[XS:<#^DY<_@D59?2WPF:7#QU#96;X
M6&4H[(14?K>0EULDYZKMVKAH8*^>#9/HZ*F2:QDICO=.5=V`231=JY&NKD]:
M`RQ"HJ'UPE7S%=6='V7\2UP@>FUUJ#0UWY?_@\Y_'4!GITO93AM&'B`LM861
MY_KZN_J-%'+R5`<<_2T`Z`_<)""7`^0%C3(,R4%Z,-0#+6,.!I_A^$&+14%2
M*$$!0((R]UMT=T8`'`/$$$W>V35&,$A%*S.;,R0[.U/[(<4%#X(&@(Q!+!2*
MLB:8T>HQ0ZT)SFYI^ZQQOP0-N@9P@@S0D#D".(;.\$Q``/!,]T>T$"^NAP`P
M[AZ#!D#J#?U!T-!I`A&$=XR@63G'5>BXV2&[I!_I]76/"0H`J<0YAF,"$@0`
M``$0'8>&@7PCXR@Q*KP\UJ29^/F\@P*``XS@.$32.0+.F2/A.X!X!APC<P##
M2!<C>]QX@@)`ZI%\@I-*:H`^8_0:C&^DFF?CTD9`@C,"#!8``!^,_K3`)RK$
MFR-85WA)YB:F*"`<\KYP?;S2BV#+=JY0X8]:,EJBTM+U$D@!LI;FP%SX;[5:
M5:!\@?"K=H@./(<)W#HWV*JT7>$D??=2O766E8[02^3FA%'*?RZ6-=5UDEQR
MU>]E<D``R"P]D8"@-AS2;%&RM!U3-+CVRL,9VG3)`(+C/G?0+&`7<-S=`?_V
MF'>%:F#NW)RIH?6(%.,?;T90JK7EP2\+S'_3CK\#8(F9DT9^-`L`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O-#`N<&YG````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C0U-P`Q,#4Q-30S,S<V-@`P,C8T,S``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A
M<F4`061O8F4@26UA9V5296%D>7')93P```3!241!5%C#[9?=2Y-Q%,?]'[KL
MKB`B(J@;B5X@2RC$B\C*J+#"RI)2V,R2EJ5E2:TWRZ0R>G&YV!)M4TLLF(7K
M18-ERV9F8"^$0>!%70AUVN>,WU*W:H;=5!>_/7N>WWG.^9ZW[_D]22*2-'SI
MSZ?/G^5J79-$'Y0=/2W![FZQ%A^.B)VNK!2[W2X.AV/D^]%77/5>69UCB>BX
M>*U>SM>X)3O?)OL.'9.D:=-G2/;F+>+Q>+];^=G2G^HK#G%Y6L1>=4G*CI^5
M0+!'?/<>27YA<43J3*!73K9UR/;0._&V^/1_EO_)&$R,CP``\?EA1V?4Q:@`
M:`%',):NS957?7VRS;HK`I+H]+QXI9MLX.Z"M)4:2NY50\;RY3(P\$&C[[O;
M+D^#0>E^_CRB@1A\^?)5BOU=NOI>OQ%KBU_&S\W?4C`X."@.ITL\-V\+M6'=
MO5\25D"R6WU^=;3>VZ+.FGHJ*JN0&<DI$J,@T!54(2R>.%<C+WI[]4HH.P-=
M&L[V!YTJ4WFA5I5GY>X4D$8UG3M?+<D9F3)O\3*9,'&2YF+JK-F:.*[)*6EZ
M3<_(4CE20_M$%5C=3?+VW7N9N6:#YHP:;KW3)JD%N]25.=E;==]9UQ#K`B\,
MKQ\2#FPL#!>V6"PR-#0D?SZ-?X$"<D\/TIRT&_E.6`%EZVRXI=U-$U-<M>X;
M6A_Q%(VXL1\_)?<[`EJ^6"?_T&J.=:^45U1+VLJ-VL\Q"L@M38/%2VZ/$B!<
MS*)DZ0^4@H92!J6ID2AL:I\F0@EU3Q_`GB"@5UC(F3[!I>\3(&P![30+5E=M
MR)7^_M=:C;S(/O!99I]>B2J`DI:45\CDJ=.T%Y@`W,^>.U][@.OTA>G:3"FE
M1V11:JH0KQ%!S#Q1I0&D*W&!%_$3^N2^N;E9JBIKM;EB@@@QTD`,AY+24JE[
M%H8>".A]*!2238]#VIE-@:?J5HP"!+#@<KFU98$/5QMK*"6@2ZH=\>N`J3FZ
M;0TWFF<H'BWWEW3COPD`NME=<E!KE((>S=WC#H!J@M]H2:8*C<%L8]&J<`!L
MP\BBE,<"Z*>;\`%]#T?`B1BGH:`Y",4\@^)X#I]`P/`$<W3BE%EZ1/@M`,9K
MZ`^&,TS'.99G+/Y#'Q`X3`=9`0!9%H<MHE906!0S3N,"(*^$TGB'IW#S99=7
M%>(IACFG$!GVE)_##(FG4"U4\S)\I4X``#@S69@R#`>.RC$`*"@,<0!"*4K(
M-0I0A+=F0!CNQPA\CV&HRM'0J*#0@1PUP3T`<(QG''5(#QPY`@"%@U<`01@0
M7$D#SWF1W)J:P!MD^)H`(*#8(PW(,7!XA\&$UX!!%U?.53@8MP:<#X/*XLP6
M.)7Q@!)F"+GD#+;"VZHS9H^M1.\A:?9M-INV)X<W[O/R+++MC$/E^4^'0/H<
MQ>+6`(.-,S:?0YS5^.98[^O0G!&A@8^#4NJ\KIXR;@`+`/).QQQH:%-CYIQ'
M6C(/'I:R\O)?%R'*\1ST>.WOZ=?#/IYJ+83_LX]Q.@1C?!#A*0#8QSC[3)ZJ
MFB:=@]1%0FW(4,W8423FD\2<5EA\GED?]VCQ4.U$BKXGY$3"R`*,2%VYVJB1
M6[QNO19H0@!0^J,PF2/T\-S]BCDY1B4B_W\:?@.>\+\6=<U-'0````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O
M=&-O;2\S,G@S,B\T,2YP;F<``````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R-3`P`#$P-3$U-#,S-S8V
M`#`R-C0Q-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````(````"`(!@```01]2F(````$9T%-
M00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE
M/```!-))1$%46,/5E_M/DF$4Q_DG_3?\U?F+S2ZLU'EIHT69B9MN2+.TK(8:
M&<.\00B:2(E&6>2T4GH!G>O4Y^B#+W*935O%]OC`^S[/N7[/]QP=(N*P+_VS
MN;TC!P<'TMC8>/C4Z73*\/"PN-WNPP<_?AQ(R94R&?/Q=;G_:%I/.4*AD'1U
M79?.KIN22J6.A4Y/'YVPWU^(+TIBY:V4R7SZ[)4,C@3$-Q*4;UE+L-/*Y:6E
M]?KA*?1XO5Z]:7;T)A*)4A-QA'UK>[NZ'Q7]8N5R.6%U=W=+Q0-9*R?#CZ=D
M=&Q>W-V/CE6DTVF)KZ3%*NSK2ZSO]TW(3/C-<1Q<+I=<NGQ%7#?<<O=NKUR]
MVBY^O__X@'$MF4Q*?7V]9#(9&1T=+8TD?K.3R.;FYG(W46."9@Z?*@ZGCE,Q
M'-FL9+:^2?:[):OISQ*<65*/;]P:%'RH*B`<#FON(HMK\N+EHCQ\.BMW^IXH
ML#S]?DT"@M]M;$EH:E9,6HM@2*Y^T!C[`Q&]P.^]0D'R^;P$0@O2Z;HG;>U>
M\7C'5'!K:T<Y'J/1J$Q.3JHEH-=\)PT((D>6997`H40`!T[ZB.FDAG7T<2PM
M+57/`H$BR8%`H%@VUZZU")!"`2"HF84SI_'?$("_7[[NZ!IZ\%#V]_?EU`)B
ML9CL[.YJ#;)@D/;.?FEJ:M(4UA0P.S>GM//NXY=?X$DHF!!`A4--"-K8V"C/
M0J&0UY2A>2J2T,.@S=!#9G/[EQL%%8Q+I!-\%`5$%E:43V++:ZJ5(G*V>)1&
M]O;VU`K>`7.X!ZCC4E$`9K]9_Z15AR!P#X?C,P7$A=:.`>4BWB$(?BX*H(0]
M'H\,#`PH68`\\(ZI\!2%`[MSB?>TCK(@#@T-:?&0!5/>%!&F(HS@4;6D&(5E
M`CC(,J3!/CX^KKV)[/!I:VM3H:9&3J91B\A$EV4*AUY@^IJ]$BL""4Y`"^8:
MP5C"LZ.2KHU$@H2?!)+?Q@4"9Z?KJ@*X3$#9C04T`ZSX-\OYKQA`=H$"86'5
MHHMS,8`BIQ?17OA.AX``J,M=JZ"][/:=>T+[-71T+@;@Z>N5E"JBY[&OIK=D
M['E,&Z;O?E`@$K@@NOQ>Z_W"I1ZM=\@$Y)W$_:D-@(WQ!I*!H9+K&54R%UV3
MYU.'E,>[M0^;$@C&E?8@&PS\M/E5.SC/;][J*0XC,%M-`P@S[(50*'`FLJSS
M(:''"!B>SHYW\"TS*='P3\P)U8X"I@$B`J5R'D>84^!B^+FAH5%)K\P`0(5B
M%#";D&,\"<=3ZCU4V^=]IE["S9`\@J%<=LY@*,,L](N1?#<\SC.BQ/17<7Y#
M$%S&N`RH4&P?DLCK16>O\CV&82P8`1>$>R(8TW,HYAS*>$8:B!!8\?E&I*ZN
M3L>=JAB`[S@`?4/I]`",(\2@GYW2`Q^P,ZP%;T)Y@`X6!WC<A<W@5GYSUA[Z
MFO,E@QF7V0F7_;\+!#-0TV,8G\P[HF=O$W0%%&,`BDV#HV?5-``/60@#O7AH
M9E'[0CG]BW><Q3!P8Y]WZ2``DQTYOU6&MHE2HX)`PDYG`=F5F@AI('4LO`6<
M9V9"@(;UL!Q>L_AM6C]_3/<&.^`%Y6;&KM1#?\L`!*",,))GAA<\/<G_Y!S#
M2!LY1SE&5"*?/](-478TNSA,E/Z+=OP3(]&<6POS%;P`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S0R+G!N9P``````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(T-S<`,3`U,34T,S,W-C8`,#(V-#,T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W
M87)E`$%D;V)E($EM86=E4F5A9'EQR64\```$T4E$0518P]6764^341"&^R?Y
M%=QPI>$&)0HBH`()Q&J116TL*&H!ET):"!;92DH+TJ)%0!%$D*W4EA!'GX%3
M/N@2B!BQR>&TWW?.K.^\,]A$Q&9=^F=E;5/V]O:DN+AX_VEY>;FXW6ZQV^W[
M#W[^W),C5S)DC(7GY&G7D)ZR^?U^J:VMDYK:VQ*+Q0Z%#@T=G+#>GPA/2B3Z
M03)DOO*.29O;)^WN`=G8B@MV[B124EE5MW\*/2Z72V^:';V12.2HB3C"OKJV
MEMN/K'ZQ$HF$L!P.AV0]$-_9D><O!J6[9TSLCJY#%0L+"Q**SLM.,J4OD?*@
M[;4,!]X?QJ&^OEZN7"V3^@:[-#4U2T7%3?%X/(<'C&LS,S-25%0DR\O+TMW=
M?322^,U.(DM+2S/=1(T)FCE\HCB<.$YF;6]OR]*W#=F*)V3NTU<9&)Y2CQON
MM`D^Y!00"`0T=^.3L]+_-BR=KT:DL?6E`JOYH4?#A^#YQ57Q#XZ(26L:#-'8
M9T5(CR^@%_B=3/[0BPBL:7@B-VI<TNKRJN"JJEN9>`P&@]+?WZ^6@%[SG30@
MC!R1<2L<C@C@P'$?L8#4L`X^MJFIJ=Q9(%`DV>?SI<OF^O5*`5(H``1YL_#'
M:3P?`O!W?7U=B[_C6:?L[N[*B06$0B'9W-J2X/0GQ0)"R'])28FF,*^`D=%1
MI9WY+QOB\T?2`JCPU]X)J:E[*(N+BYE92":3FC(N#XY'!!X#;88>EE:^2RJ5
M4L&X1#K!1UK`^$14^20T/:M:8PLK4EYY7VF$BUC!.V".&T`=E]("J+SW<TM:
M=0@"]W`XA[G,A:I;3G&V>_4=@N#GM`!*N*6E19Q.IY(%R`/OF`I/43BP.Y=X
M3^O("&)'1X<6#UDPY4T182K""!Y52XI1F"&`@RQ#&NR]O;W:F\@.G^KJ:A5J
M:N1X&K6(3'19IG#H!::O62LQ*Y#@!+1@KA&,)3P[*.G\2"1(^$D@^6U<('!6
MNLXI@,L$E-U84%A8J%:<SW+^)P:07:!`6%CYZ.),#(!>Z$7>-T$M>*!&EZ#4
M*,-`>%;N-CX6VJ^AHS,Q`$_?16.J!*4HA"@\?6%MF.U/!P0BP2CXCWJ_=*5)
M:>M:A4.1=QSW)S8`1L8;2`:&8D?):/"C]`WN4Q[/:/_>@;#2'F2#@=`?'9SG
MM^_<2P\C,%M>`P@S[1^AL-CP^+3.AX0>(YBT6A[U*%7"MX2^MR^H[$:UHX#4
M$!$,X?SJ1EPC"!?#SQ<N%BOI91@`J+`:!8P2D#R>H&3FX[)2+6,%7L+-O$.P
MP0%G,)1A%OK%2+YSEFCQC"@Q_66=WQ`$ES$N,R"AV#HDP>.7RYJ4[TV4P$C\
M-S9,N#F'XJO7FE49SU@8`%8>M[NEH*!`QYV<&(#O.`!]0^GT`(P#$X274%-Z
MX`-VAK7@32@/T,'B`(^[L!G<RF_.6D.?=[YD,.,R.^&R_G>!8`9J>@SCDWE'
M]*QM@JI!,0:@V#0X>E9>`_"0A3#0BX=F%K4NE-._>,=9#`,WUGF7#@(PV9%S
MJC*T3)0:%002=CH+Z<C61$@#J6.94?:/F1"@83TLA]<L?IO6SQ_3O<$.2E%N
M9NQL/?14!B``9821/#.\X.EQ_B?G&$;:R#G*,2(;^?R5;HBR@]G%9J+T7[3C
M7WN6G#I+*ZS#`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D
M;W1C;VTO,S)X,S(O-#,N<&YG```````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C8T,0`Q,#4Q-30S,S<V
M-@`P,C8T,C8`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!
M34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')
M93P```4S241!5%C#S=?M2]97&`?P_KFQ5PW'V)O67A5[$<1:;&M2%(V5%,@P
M-Z-2I^[.TE:6*9HXLSM#7";B/;<,B449K=D#$1+V<&V?XW[J+W636"SA^'LZ
MYWKX7M_K>\Z])B+6+![I7V5E9;2UM<7.G3OGWA8*A6AN;HY]^_;-O7CQXD48
M\TMR-AX_?AR6;-^^(W;OWAUK!@8&HJ>G)X[4%:)4*LU-:VQL3+.6V!@='8VI
MJ:E8$M?1UK-Q_?KUJ*BH2"N'AH:BIJ8F6DX5YV;-SLY&75U=/'OV+%AY^/!A
M]/;VQM6K5Q=,B?O:M6MITL3$1.1<_-.8OWGRY$E,3T_'P*7!I4'6UM:FP+JZ
MNF+;MO+8LV=/PBU-N'W[=@KHT:-'*8O?;MQ(@6[:M&D!AT.'#L?A(]^E43AZ
M+*%V\N3)^0DI=S"Z5E=7)PN#@X,Y)$,1.SHZHE@LIGA>SB+%8/@X/#R\>AQ6
MC1.34#Y^_'B`1;R2,<ZT=\9G7^Q-]5.>D9&10).<`;&?/GTZ.CL[H[N[.]9]
ML#XA`4+CQ(D?HJ&A(<K+RU.N%XH7%PQ`961T/(%OX5MOKXU//R]/6&_8L&'^
MW7OO?QCKUF^,KRIJH_3S5!Y%X5=55:4(=(`0@=77UQ?]_?V)2)#&[ENW;@5J
M+`'Q^?/G:1%Z&AF'L._.G3LI17^XO6P54%8DN`U(.3]]^C3NW;N7<!!51H#7
M4L8WR`#``/?[']/QT^4KL2H#``00`#'O6.NIOXAT-@Y\<S"Q4*,"LJ6E)=K;
MVQ.X.0,05B;M1A8QSE!6U<@8BA,Z/L<##WC.,@\FHS%#O"*0]Q11>MB92V%X
M>"0J]E>F.O.Z=>O6Y`GG,=$SKQ]O^20U4U]Q-,[UGE^(@%5YKWWGW<3WS5N^
M3/S/AG=Z00^X4M2<-E-2_-=QAG!A@?<B:6L[$]_6'$Y7F%"_7`HJ@/L668#K
M]@8&Z`-\T%FSS<S,I#DY`YJ(,IH@-,\V&N#I">AG#F`T.3F9Y&T)#UI;6R/;
M+#25H=XBH,>J92'CRTH:(SY:P+,%<A:=5!:'OJP!H?,D#>%GPN'^YLV;J<R9
M3JRH!XS8!/2"9RF0/!OW8CE_<]KY?PD`\\%AEQL?_R7^_GM]`:".@\&%@;%4
M9*2^?W]AT*V>'Z\D^<GH]LH!Z!1;$,8T-34E$7#J0@)B0)H\HZ9KID($`W4U
MBG9&6>SS;*VYU,A>Z:2S8@"B)ZP,ZWD!,*`;.=7BWG'*N$`Y,]_@E*YF5_.Q
M6+G*RLIB;&QLY3;@V`Y/U>DH.51O#J$B>SL^A_7U]2EC#6HN_3$O"Y0>>[83
M^$:#26C;V<&,-_D`D.K7B<DX<+"0E(]147-*H_3FQH\VIRR]EZ$YG@7N'LQ.
MNH)V3#$?>D31MO1]\_GH.C<6C4V%6/84"G)PE<8G$Q*()>+:AH[XNKHU]NXO
MI/LK(Z4T)Q,,F\3%H5+2>7-V[#J8KM;:/#JZ+T5_\7):@ZAW[]Z-%:6,@"(B
MPF2P@MPBW2!#^X7RR![4I,_ISCMSJ;5[4$/*<3`KJ5*NJ*69]"D')H.18X%P
M(EMM9J_E",$85G/H>6=SDP3-53X<L=X\-I3CP8,'*W>!()0#"AG+&>(@^ZD$
M*<'(SA:4G1ZU%^?F$']<$3`.6?_R+Z%5"1%G!HAE;E.$#,-9,%#C4$!XP:%,
M\<GW5U'"G'&UPP4PRCSK=S6&EA+X!F[UAAYNX(K`7EF*L^.R>C+HEQ9UA(!,
M%P?I4`,=]?8=Y/CP;[+\G^YL3A/96846+%?S-VX[_A-GM&[F<K&,\@````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\T-"YP;F<`````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`S,#,W`#$P-3$U-#,S-S8V`#`R-C0R-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````(````"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T
M=V%R90!!9&]B92!);6%G95)E861Y<<EE/```!;%)1$%46,.METML5&44Q\>&
M2&2A01`2UFX,55RP1!,WP@+9^"`UL+&))"QLH@1QHXE*;,`'/K"5!&DA(2'4
M4CH)M#2V4$)!QM+"M(6V]&$?=J;M6-(Z3>JU/7R_<_TN]\[<L5/"XO3._>[W
M.(___W^^1D0D@LU,3PM/?8E^_*1@'[R[7B+I>S'I[.R0$Z<:)7YGP)W>TEPI
M-0<+Y=C^]>Z`W_3/USN?T/4Z,%&_0JJC5R613$K?X*B9MC`C>XK62>G[A0^.
M]<Q\+-G]A@ST1O7CPL*\^R']5YTXE1'IZ>V5KIXAF9J:DF\/5PO.ZX1K]472
M5[92JK[9(N6?O2KG3GXJ1\J^E(J*8]EN<H0-.]L'R1&7C?Z?[I=$YD=D;FXN
MN,-TRW.:EO&R`FDX6RG$'IAPN^)QF3__F*12*4T*$>"+3NBZM%D^+WY*8NT]
MZAS98N(?(TDI+2UE&T?JJU[7$'_XHEC#Y/G)OFU:)CVB_<Q&^3?^O-SYN5#F
M+JR65,<VSU$O"HHAZ3K)&6:HI:NDO+Q<\LH3]<)I"HH[5/O>+P6R8^M:S9_B
MP[DELY,GW7G!#1P-2&8/:48H?.)$@6)P8G)2BT]V]GVX5\B:OQ@//##@)1DW
M]B_3HK"`#:[$NJ7I<IM$ZV*::E+,-X`2S('9E0U(%J>R\%1UL]:#18SQ3A'9
M[.CQ>BUF("'.Q$="U>-?/2T+IR,!`Z[D!.@2<E82QQ-=7ES4L?OF`4WF.V\^
MJ[FA\"R$)34U9_*$LZF(C771,H89V<^;+V'6=.Z]A]C`5$-C-,_^FI62&K^L
MO_VAD(>L#<@NJ@':?CV\3O[N>$6SWGC\17&N+A/UQN2$YY]CR9`DFH],!,((
M%X""X2@,%1B^N$F_9R;5*R$&YM%5Z@Y_T3!`E!QW0:1\,"7-TA2EZ\6U>C*+
MD5Z0Q\(+33=UH];XH*(/(C5?J@T!4G>)#!Q:KAZT73OO+0*V=C%E)7Y(U=KZ
MN\N%V]=W":<C6C^6/*.$@40\X0'8QQ,68W`$[4+</$FR/&BI^]Y;"`,YE<F$
M@Q=LQAC&1E1-%X_<_4ZJ?BI6-J)K?@%DW+ZC]SP)(8O.@(,P2"2"XF<B[U:=
MP$DH$@$._"84$(@W5`./8D=6R&Q_D8L3GYP%)(V8^3WO)%WJFGJS`$T''[9T
M@WU-XB=9"$$<KWV-_?:"#(\,Z6]D;,EL'.BI#J!NR1O\KQF&$E9C8\.BE'\$
M#CB:-W]GIU@4"DCXY8'?S%TL\AP..$IJHO(7BL(FXF]I<=%J)?3U-7H/0+-A
MDQ;=.$71P:M?^%D/]<+J&.H5D(.>'(@<L3$-`CB^MFF58AU,\QO#"32`CL0X
MS9,U-!?V`=Z6^WF6P-&+!,2B0W,(.H$^0BR><`2&(CQH!49/)7OV6L`:@E!5
M]V4DAP..3(Z>5N]1<7L;)3++;)QAG$/16<J$[J`SMSK[E8NH'4J([F!(!V6A
M8U":S$R$HIMZT@&LN-O#B9@H;<3V<(3-WO`80RGM_9KOO'/+@C4X'>AIZ9DA
M!18>@FIDB/1Q2:(M(89$W-'>HIMS&&;O/2BKO:[0/.@\.,-!9,G>A<B,=9RY
M.,2W0/1$,#;<H*@FU0"0=!(-3V2=)QMB;$1T',C&]D`.(W)*PEH<9!U.VS70
M-]!/+%WH;-`+Q`.FT7BM]@T.I,Y$:3?%&.-`2F/[KS\S&`<RQEI[6\0!YF9I
M,(8CX(#[/TBFU5HL4)Y,@RT\`2M&Z;B:D$5`38EI`@#0?R7)34/3L^@DX($L
MP`9`26OBYHE#]C`HR3OC?$_4;I!4=+6NQPDTP#:4O)20*SRTH>_I/Q;FOH1#
M"-&5HZOT:D/OY+\1(@>L.,AWJXQT>-9P:1]KVZI4]-]HE]X+##7U/U4VP2'S
MCM(1Y=O;7Y;V&^Y5DD.]>1E[T!O"^L/#=T-S&/T!,.5SBW[T[?B_J#)!M52[
M#T\$,'V[/<\J`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O-#4N<&YG````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C$R-``Q,#4Q-30S,S<V-@`P,C8T,C0`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```"``
M```@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`
M061O8F4@26UA9V5296%D>7')93P```/F241!5%B%I9>[CTU1%(?O/X/_04&M
ME4CT&DJ5!!&=0J@D)!)&03&9>!04(B8R*,R$9`@R$\^0:!0SA5"P^?;UG5E[
MGWW/O<D4^YYU]EF/WUI[/?8=I91&<>6?MZ\?I!?+-_/*&_?N+Z8S9\^E^5MW
MMS:N7CJ=KMQ8*.4['9\^+F6./[]_I-'7+Y_3Q<MS:?7EJY1^O4NC"T]6\]?=
M>_:F3H0%.Z)`X`EWQ\!'/@"#=?#0D?3XX;7T<^/96!HXQT^>RA^Q!0/O^_8?
M&#,``MM\@$8`NL`P:77$]V^+&<>']97\!-<6PS_$('<9R"(RV`;DHZ6GV8,[
M\^?'D8*!P!#@PT=/9'#+*\^S%YEA<V,SK:VMYX^&%?<*+_B`FX27<\-$QZ#_
MV-=_M/3<C`O;+$*-^RP\=;\9)P41:H4$6%UX_BOK90/")B1A`C9PH:,BHE9D
MBPI@(`C$FJ0P.=@SQ`9)%)T"`J1%PLX3(<Z$=Q7Q#F\OH1%@TS/:N6-7?J($
MFGUH>3#6*>"PT<R18<GT90]F7,-O:#*&<R].`6@H@38!9+*HI6,.S%0/,]=+
MG0]$V23B>./9#RL(M45.V"5XOG]S>S@3%5:(11+%+*R5%+`M^VC5S.04H&,2
ME0B"=9B(O">@=5,YHN@I4)!LXTE:TQU8",=VTE,`3)*'9.*)`IYD((K)0A`V
M%0#/U@LS%GF26"BB'NQ;[!<*@"MDK=K<+"1<L=!0DL>%"NSK+&B$2668[9`6
MDR7-?N$"'^O*@^;)._Y;B:PB#ZPZ+.(*]+'K"SE86(>V2T%;>)T"_,%W!/'5
MQD)),TN`#(U;5F:G@&C:MFWZ,$.S#^U0M$<4"H`=ZQT7@.@Q$0-I>\6V^H&S
M8=K:5C^99-!!%>=.:]4]:`C05.,VMMJ(G2)>K%I[%/X0D$&OZ^;8`D%J.CCI
M!2P:1@3">QSO@P#J<$>O!&%-:"Q>`V+SC0#@;X&8&G85D.DLLMP>8Y^A3&Q2
M\1H1EY&:&0!GAZ!=,38\GEXWO?:QO'[9=I"-@T``[8E2`=`XANRR=AD!V'DU
M3!2@X?,.P)YST=OU1``T$#W60-WJ5>I%TXN7,\-E1-@7-'S^C>@=@7U2I4XU
MQX2#"B7P>`,T#P3K,#,B-6B.!MEF#L"(<+PI\NY(8?&N5W%V.SWE<R1%,%X.
M'8;-(XC_:1@]&G7?88$B^:39]W:JK)/((3O8B`B-Y63(";&*>:<\32B\YTS9
M<V(908#Y[X5]]@9;,<9![7E#F]4H(SKN:T0>CPN#D<?].,";`**7GD]4A@=>
M:J#A)Y-YPJ,L,I/VIPZC2<,"X2$/D`%T;029UGZ]_@+-Z3G;";P;6P````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O
M;2\S,G@S,B\T-BYP;F<``````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,34V`#$P-3$U-#,S-S8V`#`R
M-C0S,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````(````"`(!@```01]2F(````$9T%-00``
MUMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```
M!`!)1$%46(6EESUK%4$4AO,[K;7R!]@*@F`7$*LT5FEB$5"K$!1,L%"BC5=C
M(2:"5U")1F)(<!WWF;G/[MF/>V^"Q6%W=L['>SYG=B6EM)*I^IEXYL7^V^WZ
M426>^</>ZTDZ_G62/AY.RX>UM?5T\\:U=._NZDR^K^/=_J?T8'TU_3G92RN/
M'C])B&QMO\QB6>'?LP_IU8O-]/OT-.BHS1X>[&;3/+]/"Y2&`1A('_TX3MA`
M+78:ACNW;Z7K5Z\D;&*+-<@:AJ_?CC)NWC<V-I/?`X:"H_A3#1GP"8`2GK0,
MM12@SL[/LQG`/=VZWWIQ\/YA^CS]DH.!?;S(#(#<V7F678.!://$`[QIO(`!
M%]G`A-1@*(LJ?R0&8$"HXP4@86)C,IG,BT.;6]S$=7(BL2[NC\3)0,)D4O&8
MK!L6WB&BTHUC"#9"E`FI(VQ$P\A`*$`92CJYIE(((T*\HPB_4;#[_$U.$OO$
M``,$JU%`J;&!59@1Y"FSWZQLUEE!K%>K#":@VC40:^(2TS4:1*";>"P;6*J%
M)PCYUNZ-I!$_00$:@L<W%/".96(1^<?K(/:&%'*_1$$1G%M$LP$RMY!@(F`6
MDU/"-8JBDHX"A+$&8ZQ`UQ915C)SJ6,=89AR+]9KZP-%!%`ET+"4:UALD`6+
M!T6DSMI`"0B<FP,%"#`N(!2@S"'(.]\0;A7,*I'^AF(O6,XV%^2@IRXZ"H")
M=<<N2B"8%73*VVCE&)FYP*9P9528RD,`_VUOD)'63@Q@AI$FBL0P]$D@\9]@
M#]((-'R#`0&B'2,/8<!X#0H)V#`[C[&"@%9M9_ALLD$EJMF17&!666EL]87-
M9,!*-98,^>U"W>@L*.=`0:4K8TH6S(/%,X)>D&SU/K5S9'R67`)`U3FH'`_S
M*,Z@[AP:`KF0X3&C\;(0QTU_[4$X#\A\X[,P1X/.N%Q1]3X51;%X*6$_OBO#
MDS[`D3Z(I9XCC$(Z%8,>L%0GY('LU/(HC!%Q$*.G"V+!Y01&!#`(>5UP5#I3
MG'3]PSO.8,%X0K3'2C4T[FU-KS5(.WDKP#BMY=JVB[<)AB&`O==XJCC+O64U
MAO'2J8IB##IZ4>SQQ!X*^:X14\/:B[TCO4R>JAGSR'JQZ@!@D*($1@S[CG&]
M-KPQ+7H;SPQG)B#]IBQ[_I(,:B"./:^#'`-]4KGO&E4FDM=F[VM>LQ:V(:AA
MQ(AG</^,4J'_)_%^;JXA]+`//WE?>C4S[R+UEX%90.[B(8DAWC%$%.(M7.-0
M_+-8>AI)5K:1:,-69KM#!Z.`L[=]4L1T@->B>(9>^BSPQBOUO3!M`&6O!;U<
M]U*&6`MTA9$!U%BT_`&PCOX;@'5A<;7U,00:6]!_PD5',?0/2-3K((#((R<`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S0W+G!N9P``````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(P-C8`,3`U,34T,S,W-C4`,#(V-#,R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````@
M````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E
M`$%D;V)E($EM86=E4F5A9'EQR64\```#R$E$0518A9V7NVM4012'M_%/L1+S
M)_CH+2RL@]A866@G0AIM%"2-E4;L1$$(P4*4B`$+BXB*B((015RPD+44P<>X
MWVR^\=S9N3>LQ=FY\SBOWYS'["BE-(+^_/Z1&//DQLVU].'3.&W<N3+;O7MO
M(YTY=SX]?7QKMK!R\7(Z=.1H^C;Y.EN8DP'_H\TGZ>7V>AKQ@8SKJV=G,HX=
M/Y'YEY8._F.1/NYLI7=O'B9'Y)9-1&V_>)W%(0HJ=B(6TZ#EDZ<3<R3\^OYJ
M=N#JZK6\>6KY0-)<J6,#F]+\@9_C-/[\K!B)^'(`#HQ\^WXG@X@Z0("IV,`F
M!*ALXD4Q$@X.X2(`X1[JR@%<XXYTDP,%*+DB@4.Y'=!;VWJ>+^/^@_W9AEX<
M.G<[]0`;)E\V"S&'VCA5>(&5A,=X+HE`Y[*]<.$"3T*.;YWG*HTKQH*2!%((
M,0B9,Q)_,&"-"';N0:BY"PB@(NR@B@`8#87.36,JAS@,,Z,"F2L((3!&((L%
MEVZO9W\Q&?^YLI4+AS.CL=:ZL?S#/>L[6B:3?26L#,X6<V\<M/*CSI.%`\D@
M8GTPD-CDH,DGZLX1%H4TF8U`(Y*[C]'(&D+F!,!@^8D1R6AA&0QE#LM,;#@W
MF!BM:<W"Q]6I&4:(=5R(B611+)%HW8EY(&&V"12USPD@:&"P-LF<J^XT(A$"
MDP!W7,!4DL<$@OB&65*[S!T0.4S2<!`7%"*ULK%SC2)LDXC-0J(FJ%WFC@";
M%L0WQ#ISK&..H&9S`0,.L`EXI#89*0/`MA*ID\X<D`%F"$;V&'O3V6H$(V!F
MS=-K@P`49L[\5ST8JA$9R-V4;Y'[0[5D(0/J&E/WGE@!I%8=&GPA#"EN*8UQ
MR4BNQKEKEJ"6(7LJA\DB8+:1DGY#)(DY[]P:J"'V0E'1D$'E"*MK8TUUW?29
M:"V!+,96,8T8-*!6'DMDJV3F1-TM6J)4=P+(-5%H*K<B(C@:HF=ZKW+.8X#"
MA3[6[UC/.==K`+!0>GR>:`1*5!@K+^O404I6+-LJJ@-3@YI7P$(LJO9!1\FY
MAL(#`K[>Z@84N[J!V`Q"&Q+>^<Z"7*N;E<9ZSFOP\:;W7H?IV_NLL"?%!UZM
MT,=>_&^B`=&HV/PT!L][_XGH06Q)L:/&-97Z+7E6.;Z)6R^R9B4DP.@^H@#D
MM#8[-=]X:<-QSZ!DCB%XRYW3A/IZP)P!'+2(F-\8`_P:9YO4`/;,#%_(>REL
M&@`3`O0:0T3"M%.IWT:\RH$=8Q;MKL4`%=F[6<ME<ZJ,/PL^VS!.R./9H9X_
M1'\!EFXBARQ*W20`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C
M;VTO,S)X,S(O-2YP;F<````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C4P-``Q,#4Q-30S,S<V-0`P
M,C8S-#$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$`
M`-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P`
M``36241!5%C#[9?93U-1$,;Y>WS3%Z/QQ27&F*#1Q"6*&K$N(.X;BA)Q(;D8
M%%$,99%`*9NX4,6E+A`%+2J(-2"6`L%$'U`,#_)"@F-_TYRF%PI!C8E1'PZ]
M]]PY,]^9Y9LA3D3BHI?^:7_]6G8=M:2DM#R\>[&X0KK>OI6D_1GAC9&1$7G9
MVBH^G\]^/J+#W]$IBU<FBFYD6+F2F')(SZ,K;MJ,F6)9E@P/#TOD2/1">IQ.
M5WFEW&MLDORR&LG(=DJPIU<J;]R1%1M3PE+NVPV2YBR2S<U^.7(\4S9XO++$
M.J=FQIF("7O*`@6%Q3*A@'7>J0!QPO0Y\\0FD.!(4M1KM^Y7Y-P"!ZE`7V^O
M7A%/]??WR\,G/ID;OT8%<7A8?<AS@X.#XO%X!!P\LZ<:SOA[]6%%:KHXG"XA
MF&=<%?)SU_R9%7.SY46;I&7F2G-+F[JEN+).JJY<E2DI6+EFG1ZLO?5`SN:[
MY$6;7TIK/.K"BNMW]7=T=-1^1S:L"T6:<!QF%9;7JK"_HTN,JS6;K#`RW&S+
MZ;(;81<?3#VLD5R=O$LV.;9(=IY3YB]:JBD^:\%2J:VK5QF6[0KK2JK$ZWNN
MAV_>]DK6^0MZ#=Y=5?5"-N3E75(94PVV*T3[H:&A05CFG>\D@0G^[P_CGZ-@
MY]X#\N'#1_EA!5`+3@L$`O+J35>$I::D@`0AUB0.Z9Q]Z;*&DQJ%U"95,#0T
MI,)D&EF9F5,@G5WOE!JI!U*;?(BI8%E"DA*R^UJ]T@?6.>C8DZXH@L%N1<5W
M%!F"BC@+:U@FW_G=GGI*GZE&JK/^P1.MC7>!H)*7(2Y5P`N:<1B6$:0*<2*\
M!`(0X@=:1_*!8W8%Y/:ARNM:(,"FI)-/6UI$.)4B8L4O7RV-CYLD8</&2'@C
M/L`Y%!"''S]K4PN$LKGYJ<#]1`8?(3,P,&`OIA,=_6J=YN!VNY44<1+O<$%6
MB&I1=NI^H]#?QD4!0;3RD2J<[=BF"A;NWJ?LX_5Z50'7BID'T5IYY@`D;_9@
MGH[.3MO>7U3._Q8`BIW63K+37B!_ZI/\9#8)=@?EMP&@>LIK;FIM4Z)U=Q]I
MC3-.P#3\9N65:,51LJ3M+P,@I2E?N("I`Y*!5#`(H9CICYL##`"4/KS!-\#`
MH7CMAP%0@+!<J;M:1P-NS,(@"])B\0UZQ""&S71`W4%H`*:Y4]C,)WAM0@"P
M`>T#9N26&&3$@&IYAMQ1RNTQ!@!X"_XF%Z`=>)M?0+"/+F3P$,T"FH;GQI$A
M+`%[<B,40WXH,B",VTE`O@,$0"QR@G>&)\(`94/IY(+QDJ%Y%@`(J0T`\69T
M(>8P+G$WDR_NQ3,H)*Z`0"GNSKGHU%\`<CMRP,CA):J#A0[THI^9BXJ*F0,%
MH1O#YG@$8H;E7:[PZ$N(&(F+:Z_I/IQKAC64XGX2KKJZ6L^:_S&(/6,5K87<
MF#`'OHY^DYY/7U0)RIFY^9\#U+09@&",A`(@0)G-3=\"/)W$R):55NBM`4-#
MF+0*,+RC[[.6#3=H";S7+DLE:"L*M6$F4/B`4&W.*9)5WB:].15#GFQ*2U=/
M(4^#!3SNGQ(/Y+=WR_KTD\IJ8X4@F=RJ&@6CDTOHAH2#.)K)UO12ON$A/,&,
M'3T*_Q(38@@C8SOZV#+&((O*F$SV?S<TZSM[#L`OP#39_P````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\V+G!N9P``````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R-#,W`#$P-3$U-#,S-S8V`#`R-C,U,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M(````"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R
M90!!9&]B92!);6%G95)E861Y<<EE/```!+%)1$%46,/ME]M+$W`4QWWKK3\@
M>JR'B`J"B*(>RK(;$51T(2NE&V47Z&I)5S/*TJ!98D@FF:6"76:M9""H&8M&
M(KF<EJ5K+M>Z*]$H3GW.^,TM5UE11/7P<[^=G7-^WW-^YWS/SS@1B8M<^F?Y
MNFUR]9I=PH*4+?LD[W2Q\*F"!<U>R3AP0+Q>;[1]V.1Z5:W,7+`LY&/]INVR
M9>\1B9^5*%.FS0BI87O1Y>XY)7(U-C9*+Y]9N85BR2^2G0<MNEI;6^6*O5J2
M5ZT/:=GM=AG9_D;![]ZW7RS>@'1W=XO'X^D-,R;L/BML2]TA7U0H*KLL)\^4
M*;@A(T9+E$*%K5*JZQR:S%NWG:J$@2J\?/E*0R1U>$")/1DDW+@!'4$AS-+2
M4IGTZ+G4U-;*VO0,Z>?[T)-)A\,AF9F9LLOU0./?E'E$@L&@?'^8/[)B"C>F
M90@UP<76.>N%&O/Y?/)-!PUW77*J^((:\WF\X+Q4U=R4><D;Y(*M2M.'LYA5
M3-&1ML+22VH("G+>Y&Y6X_3L/$F8O33L9'Q\0BC-QE/3ZRXY]+!#CEERM.`3
M.KITSR+]R)*2DV5BN4UR\_+%:K7V9)G4US<T2*HG(%RLT^G4\N23DL1!04&!
MM+6U"??*M7TUB8%`(*R``[,'\N^YQC_#04YNOG;$=SN@[V`19WV#F,*"*/KD
M@,:ED,HK*K4W:5HJ$68<,W5N3$=17X!,&5-MIHP/6T[*JHU[=`^RF,2'(:QP
MKKQ"RBY=4R?4/_`I8>Z?</@=E&NWIVO?AQT`V\"E[CD11QBQ0(/1COW9>M"<
M)6NTK,,.$`"/TSB9>,D#\'$$1R%;O'JK[EE1#EAP%+P)-0UTN'5/T@:[.W4L
M$":-Q!Y^,_R@QBL?OU`!L=*%]`+D1T,Q2D@<!_`[#3=O_OSH9H(U)[1TJF<Z
M[4;76SE;4ZN=^/Z30MH#K^X9&N0BLMG"(<"BD`<#T"`PR-C/]G5IR\>\QB^U
M,O`CY8:J_[)V_G<`4(.T&@4-.T`[?*>UD%$AOP0`O<P<@QAH2P@!JJ)567R_
MX;BM8)B%/,@894R@GP;`P1`-!Q!Q2TN+$BU[R(?!BXS#&<SH0SB&4T:-G2`P
M>Y\!0'$,W<*BT&2'%@U!$ZDA+-B.Q1X]R(S#`>IJ<BME`-*\Q'A/HL=5,;=C
M`B`:T)->Z)/#>7=RJ'&,0W1@0Y@2&1GA0/8\A/@.8#)B=&`8?,*F/$D(L-?[
M#>;$@(@YW!CQ,@8]QBPB@V$XE/13(\@H1I,-ZH`%[P$$.ZX$\-`Z5&X>&5%7
M`"I`C-FP65/*'?+B-6OHY.DR><4:C8+?S"=.D1M]\SD\ZX0NH\LH@,EY9YFK
M"!_>^2XH[?ZGFIJTXA(U0!&YZXE?#?*JJA4<3JYX.Z6DW2=^OU_EXQ8F:F3H
M(B<K/."0';7:=!)\3N11`)+N-*GSE)04G08X!@SO;J+`$9,!(/Q>=J\Y2A]=
M;``PY6"6@N2*"(K:6)2:IKJ?/Y1[M07SB]G&H<8`1_0U<XYI2[0\#IAQ_([-
MZ#OWU8:)C`Q]LC3(%OKOC9KZ(2)*]+R08256'?&1HX[)#!@R$_F"K7S5+?W=
MS[0F>![_'T9_/("/V;C3JE)*TOT`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T
M8V]M+S,R>#,R+S<N<&YG````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(U-S8`,3`U,34T,S,W-C8`
M,#(V,S4U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!
M``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\
M```%$$E$0518P^V636A45Q3'`]*=.W'AQHW%@HHMN!"5;FJJ$"I(BU^-"P5C
MV@9M-`F*41/BD,:*2F8B4<=H/IIOTR1,!\F@44<EC<EH1]O1HC9JC4K\*H-3
M-&*._DZXX[R\9]*X$,$NSLR[[]U[[CG_<_[_>Y-$)"G1]&?)R@R9G)8E<U(6
M#[[-V%`@6_*WR;+4Y8,O^OO[I;2T5*Y>^\NZ/N[C:/L)^=@?%GV1D94KRU:O
MEWD+%LF"1:F2A*-M+I?T]?5)?$FB[=BY2VP^=^ZM%,Q35B-9F_*E^62'7/OW
MN1">3NBY^;?D[=HG&<5U:N,WGY*"HAW.6P2#0?L6PYEEP/ZOG5#5Z)/5:W)D
M>CBJ0'Z4YWX5`Q^/!3ODT[DI&CTX'O:U"9@F1:-136_AUVGBK6S0-"D#J/%-
M/30U_2RAT#DA75;]VMFIY=$M]IQ_H@]SJ^\)$[.RLV7"]DOBF$5O[RT9-LTW
M,<>7M$!#LT]C/1)HEXVNW5)8]*.$+_XA`P,#FH^C@P</'RH20%;3?$1Q3?DV
M6XHO]JJ3%G]`*FX_%8_'8W7`1";0HRPTBT&*]O+[_>+U>K4Q`:K(O5_H?$M/
M'[_[5,-L"P2T4(?.7%<6Y)R(R:;<S;H[3DB#L26"?YX,R*1Y*\3?\;M6FSYE
M![A175VMBW%&9)DYN?9N!)C$E]`%(W3R-2R)1")OJ8SOA@.:A5+2_*-R`(6H
M,UU(S0T/`140#<".#J`;G4@;0UC8G;PV+\YPQDA>HK#8./!+X*0:)-]_X[&L
M^L$M4S^9J8Z1K/3B,GL?T+(LH&&,?)`_\I&SQ26KTM*EMJU=M0ZE8`[_%LW!
MP>FS(0T=7I0<J)!#Y>4J$+0V#FGUSY+GZS.XQ!W@#>`P"(,FE=<T:L_CD`B-
MNJ-=M#..+1A,3/<J66*QF(*$/(/VV/0:,94)AR_(K*]6.G.!?N<`@#30E/^6
M*X^TG.@>+(4;X$%*%@=3?GJFN\_(]&C>'[I[--_%+J^FD;RU3NKJZU4L8:<M
M`FI-N'3=_5B_3)G]N:;!9*.TO!\:?MS!T';%&30F?%+#&3@@>:,B4V55E8+Z
M;M/Y_0F`(J)1,`0F<.!U=7>K<L!13O61M.N-`J`)<`Y)H"4;$@0B,::^2WN?
MCAM7>%#'&&W,&*,3OW`WR0>E/AL'1@R`%H;"'5V_J4(AJ%AG5TCU8=WEJ)[<
M$.[[T&V5/;B"H1N9G3<DM<HO:X)_ZGA$&@`A3*YM:!*CK62-VO%L[HMDCSAQ
MF"->:PMWJVR@=*@@):%<_#.'S3FG*1U*F!A(?'.$"J@1;J25#<F:#7E&GY!;
MOK$I,(<CEY7HZ%-SJT\O<!<BEU0Y\,4W;A($P+]9BQ0SUQ(`60&WR98-J347
M8+Z!"%D0(/<\U`6T,'0.[4,XN(<3$`B1,4CPS,88J##&OZT$-!S7&1J+JPXU
M)7K.!Y[)FLR0?L8X(NB)*=_IF,R8SSPS)@BN2KQ#F`GVM8<RMKW[F4Q;NG%P
MLY=0@@+1DB%&1Q,<'<TQTA@XHW4E4WJ(<Y=U'!TDQ%H:EA)!Y6&;D'/GRY*@
M0HEQM-+1-!<.N3%2`IXI`4@QI@S4=-J^.XJ&.8K)G&.*8"G;L%=TS?RE`Z!C
M`[(#+CA.)EQ3@=X<B-`/AE!SN$[IR)0U(/%-ZRT]C4'-Z5)I"\`<86SN-!''
M9$5GFT8C.].$J"*G-IN3*7/Q-^J;W7\QT"$SLPE!,7:"^/_3<"1[`5E)DG>L
MPM'^`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O."YP;F<`````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C,Q-@`Q,#4Q-30S,S<V-@`P,C8S-#8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A
M<F4`061O8F4@26UA9V5296%D>7')93P```1@241!5%C#[9==3%17$,=]KX^^
M]KVF)C;XT(1':Y2T)M6D$8QM%#^JI*P&J5AUK4TD-FM<OP`7W&QJB!O672+9
M"MM`)8TDHA*(4+&LB$4$":"@1$%"I-/^AISE7O:B^)$:C0]G[SWGS)WYSYR9
M_YR=(R)SK$-_^OKZ9*7[@'P2;9Q<+2TME8J*"G&Y7';QQ">VA9&1$1D8&)"/
M=QT47>CL[)18+*;?=W5US4*'HT!]?;T</7I,ZNKJY/O=;@G&SLNJ]`QI;6V=
MDL0PS_'Q<7T"9O8F7ET`^P1PP>4!^7#U)GU&H]%)#&P6%Q<+`;U^_Y$L34M3
M3PB."HR-C4EM;:T*^/U^\7J]4EY>+C4U-<E>5%Z)VURU8>"Y/.M'L<Y?CYNO
MI*"IJ4EPDI"0%C@+O'@\;H>($`<="`0D%`H)A]_1T2&^FX.RQ>N3A2F+-&PY
M):=U3L1Z>WNGHC0\/*P?H8!01B(1G2-(UG@\'@F'PY*;FZN*"/'0T)`]S&0/
M&;LN>X="9/QY_2]9N^E;?0?1V?,7)#,S4S!HCL+F\WS/)<U1,__IU&]B/3/V
MGQG$[.UY"8&)B0E;L,ZU=LD>MUO^WV-\RQ68Y*)0*2].A^,S96930,1)#(3)
M,-*5CTUU0Y,+M[KETQ49"<JS*2"!H$^RD+SG^,Y55LKG7Z^70XT=TM#0H"A(
M[65?I=M0:'&390A`?M`'Z7K"5R(;7-N41LA`4IIW]E&`BPD$**"(#/=0=2#)
MS\_7^J`6H!H(FG?D<5L5&/^O-C<K"A3P1`%YCU*LXQ*$QCYE;JL%)@1NR;Z@
M!H\8M+>WRY?>*HV^F7^1']%`CXZ..E/6O<$'"6B,PD#0%O';W7=GKH4GXT]E
MU<8<6S$15"NCXLJ,"KK[!VV;WP0:Q,JNT_>3%*3L/2LM+2UBA6MU!__?T6I\
M#^"-`&AK:Y.YY9,418E^5!#6^0>G_I#/,K?H?-Z1,N6!M),1?2\H*'QV%IIR
MIJ%";:;)0C+P`I1&66,<HZ[F?N7'-0=]DGWQEG;OK?L]NK9Q<Y:NK?DE*M_5
M7M,]"(KK@;5-V@@9XRB'2S`(Z3`,`"@0PC)7S]B=(>7;'PX7"2T3(X7^@-!:
M84&WQZLR\*^A4)R#\)/N5P"@7?3T]"C38=#<UJ!/*(4YD<$3YM?B-[1/PY!5
MU372?NMOO4EP_2,"._)V*F"N(^@(!H,*'"<=`7`U@2EA$]!BC(\8W'68LPX`
MWJ%L/$4Y0)ACE#GG;=8!@2,8YQTGDP"8'*`O@!`C&*4KX6U149'FA/5(>`<`
M<ABGV2`+8/:1,T"8$WYT<]16BIPQT^\_?"SP*U[1)IQD6F[<_D]IW''/_WNS
M]B>GZ]2LRO!`Z(+X2L.):Z1UX$'JX8N:\4[@`,_W9:$S\E(\P'$<#U7KF9.<
MT_='GHPYKB=XHON>@J=T7PI`ZOY?97W>SUH12>">_J/>4X).T:%O+CYVR;'Y
MOE`$R%9S]7F1P?'PK?F[^+X9/6_\"Y94&YT>3C\/`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O
M=&-O;2\S,G@S,B\Y+G!N9P```````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,C(T`#$P-3$U-#,S-S8V
M`#`R-C,T-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````(````"`(!@```01]2F(````$9T%-
M00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE
M/```!"9)1$%46,/MELM+U%$4Q_UC@C8M6K2*-E&X2JC^A8A:15244(985M9"
M,)+!U)@9:WR_'\/X0`<1DY04WYJ8F>B,3-H,XHR.I_F<^/WFK5$1(2[._.;>
M>^ZYY_D])T-$,F))?\K+RV5Q<5'XZD9149'4UM='-Y*NQ&VLK*S(Q,2$#`P,
MR/;VMF1XO5ZQV^W2VMHJ'"I;.+PG6UM;DE)&RD?0J:"@0#HZ.J2KJTLZ.SNE
MHJ)"QL?'HYPC(R,J$D:^O/WK3_PY0TU-C3B=3IF;FU,G5E962E]?WT\=PN&P
MU-;6"@[MZ>E1"QH;&]4*4P*FE924Z$%=79U45U=+?W]_E*''_4$716^:]-OJ
M<DN<#F=N9^O&J>LW)';]=\S\-P)V=W<UB>KK&\S<F9Z>EOGY>9F<F)3AX6$9
M&AI2SW!&4BPM+<7'FF0C&/@7OW=W=ZM;$8I;"8[#X1"+Q2(M+2W)`J!`8$M.
MG#TGL7O.2.",_Y_FE^3D^4Q)ZP/W^X^RNKIJ,GS;V(AC)GZ;FYOI!1AJI:/E
MY67Y3\-X"`2$0B%QN]U26EJJ20/"S,S,:"92X;.SLYIDH&-5597NQPGP>#S2
MV]LK-IM-@`?@@(L(&1T=U30&*\G.IJ8F_<^CI@"2`Z;BXF(%0`09\`%QD?SG
M=;1H:VN38#`8%1`(!%1MX(1\YQ54;FYNUKK@(K6`B0B`=V=G)RH`:<"L/5)(
M:%%65J9%!&$2@JE"*I4]*A>P2XK"W99^M=E8>]:_Q>4^YU1MVC#>?_+</-S;
MVY/3N4_--9AQ[U%^^EJ@YSS,RS,9@L&0::=1ZGGY^PAX4>U2;#;6+]^VJ].,
M]5-[NPP.#J87@".-KI>*.#-"=\B*Z4B!OZX`N4MM^WP^`66H'(/H.&MK:[J_
MOKZ>1`Q&G,,'P;<1Z4QDH%&Z^RH`X\+"@L(9&$!=@`O\!XT`$:8@\!"HFYJ:
M4EP`1\;&QK2#`W7<!\6,3D\]@7"@&)TO5AGS<?`1C0%?P!D$`Y@*"PMUND((
M>PQ3C`A`)(B'4-`/Y(/H^DP$H""$\GS9=[E<BE7,L"D]@+NP#'!GQ.!11@F\
MP)J'L`XKL=8@`_!1C+MX"P3E'D;@2?:036C!M118%M98P8"+$8S&6&VU6M65
M*(%U6(U%".4_EO/%(WB&9L+_6#A'%C+I5$8W2O(`2G#H]_LUF?(M#LF\<DV;
M"/%F8H.PA*GMV>M*N7@G6Y4C=.SS)4]P]>-7-KV/=XQDC`7H`\OPNS\@XY$D
M2X6ATY.?Q&)]%]=_$FGCNU_O)SYZH`*AT(X\>.N4XUF7M,4FGM.K&`2OWKRE
M%9!XOO+5H_>/7<C:5\&T"OA\F_+YRW)<LL22W=$AERTVR<G)27GN]?KT_F\C
M(;V1.;DS9C9.#,V'"":0L*D>S[4VZ!Q-3ASU@O]>@1_F3F"]!M[#D0````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+VYA+G!N9P``````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(W,#$`,3`U,34T,S,W-C8`,#(V-3<S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W
M87)E`$%D;V)E($EM86=E4F5A9'EQR64\```%4TE$0518P[V7QTID41"&?0)?
MP$=PY\)7<.G"E2MW(KAP*8BX$5%$!#&A8LZ8Q8`Y8,XY1\R".<>:^<HY[>WI
MMJ='G1DXX_7><RK\]==?1P\1\;`N_:^WMU<*"@ID>GI:/'9W=V5H:$C:V]NE
MO+S\;5M+2XODY>7)R,B(_7F;C?#P<(F/CQ=]T=;6)M[>WN+O[R_)R<EOVSC?
MT-`@MB/6E9:6)C<W-V)G<W9V5K*SLV5F9D924E(D.#A88]S<W'S;1=!965DR
M/CZNFX:'AZ6VME9N;V\=PR2ZR\M+>Q>NENUA8F)"'AX>."E/3T_V%IJ:FH1`
MP2HW-U<.#@[D_/S\/4W`C(J*4D#GYN:DL;%12%<W$'U969F$A(1(966E>'IZ
M2E%1D?3T]$A&1L:;G_S\?"T)*4Y.3NJ&DI*2=Q?=W=VRO[\O-34U`O9L=,AB
M;V]/7*;YT2(NMW!:75W54O!\='2D,5,K,KZZNA)8]/KZJM_)P<'`R\N+/#X^
M*HYU=75:S[&Q,34*]?KZ^B0G)T<1^_7/W@"'J1;P>7EYR?+RLA:&Y_3T=/'S
M\U-#&"`BIQ%@`!0I6E55E41&1LK&QH8$!04I_+":8M[=W3DG$_1;6%B0Q,1$
M&1P<5!Q(A9^%A87J8&EI23X$\?3T5#\>'A[J03A57U^O'6(%KK2TU'TZTTEN
ME?&SR^5'@/R4@>/C8RTT9:.\O!L='75-Y>KJ:MT`VSH[.[4A`18RG9R<"$W+
M=\JYLK+B',2UM369FII2X@`>:@/Z"`DR!+FBHZ,=RTC]\<R&L+`P#9V0H3$1
M\(Q1^MI*(IL!6`C_\00+(4QH:*@:I,?QBM'BXF+M]=345,<4+BXNM%E\?'S$
MU]?WYQ</9>/6UI;*3&!@H%145"C!<&@SP"%RQ0/>,8!X8P!5W]G9L1D$:/;1
M9-`=%;)%`.K(/YX`C$/@$1$1H9*)<0"E%XPNV%(@5Q20#70C85(-#F(,(`<&
M!E142(.6=U9&[42F!S7'B%GP`N/,)*MW.P.@&QL;JQV(5X2#LB&_>(=45(3\
MG1I@')EGL*"%F0(='1VJC43'-XS]<3H9R4('S\[.]'E]??WO91WPK)/LV_4`
MO>0F\<_TY$^+F4/5OS4`"F0=&U8X*?3U];7"BL3`#-@""L_/S_J>8M.KUG8S
M=;7>?EPB@"/80U-`@OO[>T$D41>H24,@'B@,U*5UH2Y=AF`PA0B&&PU,I(5!
M"CMNEX`)11"()]J((G%/X"J)'K!`Q<@=]#9!T2^\6UQ<E+BX..UHMTJ`6G.8
M3+:WMU7ZDI*2=$ACD*X&!62";Q@V<H&$LH?`^OO[M0R9F9DJJ2@EBS/TI$L$
MJ"4UI0P(67-SLRHD:LCS_/R\/J,0=`%7#^YG!(WL\@W908JYY[`/^-$O!H<#
M`@P]1A'9`1D-ST\S(#!$`%PA<<8-`R>4@[)P:T:R`P("='%39Q_VJ#T+9`F<
M!4H(##[QK=,(9J.!..<@8HHZ$P!PF@"`V\P&[K9D#%I`S3NFF`F4L4#I("4D
MY8:#<TK`]1&?^'8H`3!1?S;'Q,0HZZDK@5%GZD@F0$Y]^0EBL!UN&*[0*0P[
M$.0\P^OWUG3@`)O(""V`-$0+U$R_KJXN;2\63LS=E66<\HUNX.[&U(`;V.!Z
M3K!PB.3<:D/*09T@$M,%33!_B!`4QEI;6W4!+U`SVOF=*RP(<!XN.1.V#P.@
M/F0`P8B6KF"A"V29D)"@<+,H"<C@G`Q!@HD-*1F\*!\\@+AHRI=F`0C`:!0.
MXZ@:?``1G/..&K,/+?G]/,&8:^:W#2/*0*<XT_C_,@VY9?+'Q%=L_`!M65P(
MO0_*A`````!)14Y$KD)@@@``````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D
M;W1C;VTO,S)X,S(O5%=#;&]G;U\S,G!X+G!N9P`````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P-#4P-0`Q,#4Q-30S,S<V
M-@`P,S`S-S,`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```"L````@"`8```'\G;&5````!&=!
M34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')
M93P```C7241!5%C#K5@+4)7'%5[;&F*;-FG:3NO8229M,[:-S7223!IK,TEK
MC/A$34#!BHJ)2`6BP8AB)!:CYM&H$V.-RLL'ET=X/X3+6P5%07PA&A`113&(
M#U!!`N'T.[M[?_Y[>6A)=N:[^_^[9\]_]NQY[15B88H0,RSB%^_ED`TB,%,(
MX9<JQ'0+B3<3B9M8GD4_#\G3$S,L]-*6@_3\Y@/T<5&-GL`R<FCBW6Q,X!MV
M_.?%:S;@*:F6657/@TF5C?38VD(:_I]]>O"M-#N^8MJNYX7P3U68LDN*]LN0
M?#K6T$)55^^0"+*2P7K)'OTM/T7<UMY%'=1%Z_)J#(Y55UMEW[T_N?EHRCUW
MG1I:VJFD_B9M*[U`FP[6&8N,/9LPR.'='JR'(7@PZ\(1(,Q2Q-B<',!&>$.-
MM]OI"C`YLER-_2M9:<>V04F\-$O"UD9N.@CE9I+P39'$Q@:9N.,;HJ'OYU-X
MV05CP1,?[H5^=_<D%MY)%)!QAIKO=A!K1G@GD[7J&N%P>A(75C?1QJ):*H7:
M=I354_*I!EJYYPR)V7$FXA56/M8>)F-WU+XI6G7VNOP+\$B_>C;@&O42<QJ_
M]3!-"RN5F!)>2I-"2VFR!C_SF&W>!4BJ_`HVE=,$58_M9FPS#9M2V#\",[LQ
MYPLI=CNK5K??K,O'$61UTZBC,/1@;W,VQG_?3KE0XNBPPY1Y^JJB=HV2B]-/
M7Z'$B@;*@_9KFUKIZ8W%U,*GXAE['XS=HVG_^1L46GJ1A',XW81%]=5&?+)?
M<1L?<1^,I^Y2%(]_(/L7/BN1_9-K"ND67&[2CC+Y'I!62=ZIE51SK96$?UHO
MC/G(M7-+QB]O([$H3>I6S$^$#:%?DJ'>?9)AB!CS1;\@2<VYPC@G1AJ,![^3
M(08'I)M,:'F6M`QM>_\WG)9D.)A;8":;R`F3)6P"E@*K@-^;B&N!""`)N*3'
MINC^KWKM1P8?PX9]DL7#0=9^XT9?D"%B>18[2["]<X#IAGVUY+*MQ#!\!CN#
M"S`U7('?S?.C/SV@%#LOD:5^P@A6$AXQ0H=]%:08?JER0<57M^EWZ_?1R"W*
M,CBQ&#0K$+$7IZL(^':ZL(_:[IKI<I,7<8CW324QZG/)["G8:D<7:'R2NFG@
M=4-`QTQ[VJV-J<X5TD6!9S84$6>W8>L*Z+7=Y4I2-KM`%5F9]L%[,0VPGJ&?
M!>>05WP%I9QJI'^$*>._W=Y)Y8B)PBN.GOU,Z;'NVAWZW@I(NB+['I+ZI="1
M^F:9X5H18(:%Y%+[-UTJ"+WP7\GL<83O+\&06P0"KQ.D[9^IZVX[G]]<?)[V
MU5ZC<3N.DO"(YL.@\9%'J.YFFYR_@1TX!=V+J0YQ'C'':7Y"!8EQ8=*%K8AD
MQ>>ODZ7\LI2NHJ&97D05(<:&W<=!(=_])#B7+!57)//@G&I:HW-X7DV3["/+
M+\E^978U"3?+O0]*S(B6"VJOMU$4I+*U^)/J(ZFH1;KTV*K<LW3GZTX:]$Z&
M`U.;\7O&*J8<G5ZWL(>0>`/PC"'QSQC]'*?&.5)Q&N4(AL`]+O2(9"JC%6!$
M*2Y^'@C*NDX#:.S>L!H!U2E^1B1"ZH6G##@$PFGLPE]_V*W=L:_Y'^G^Q[IW
M`AX4>M$UP`4(`&*`1#W>I'L?W?L#H9H!.?2EO=<%IC#(-9F8O'-F]"EUZG>!
MUJZN7M'F@%:'OJV/=39T<AA@KWT[O0K)F(_BMQ`N$DCNNXBQ85:<T$%='>YT
MMJIX+JCMP6.S8&FOA)(8`^=SCH`3`F[1ZAE>+\:&DQ@=*BL"\49"3QX2&!^Y
MA<(.7Y3?-!)*CXK+5`V8?<PFK(Q1YO!M"M%B$<)X0#KRPRU)ZXV(P6WHZGS9
MCX]0P7/[H3KZ*8(JYQ.[@LK,"W/?#[3:"3ML38$=!BXL@\=1"O_AHT)%BRC#
M[?W\L[KL.2A[EZV'9!A$(E,%>&_"8IXCE%E86U#IM<[J55@^OH4I*J!P\IN+
M(_-.4(%F5BR)2;@?+4XCS]CC,(%(J4TQ)XY&?+!7T@Y?DX]P>5;6\<(+/-RQ
M>;<HQ=,]1FY0;@2UVK<7]N6MY&XY)I_#CM3+/NY$`UFK&^5S=M55>4<(R3\G
MWR?BKI.NG3(0]P?)XZUTV8]!+2+',T[3(RL5_Y;V3D4S(9(&ZPO@P(7EG4,#
MG9WP6GANHDX\K#UN_C$G4,,D&-'VV*5F>A1'J]:JM!IBK9;]GS<6R7[4^OTR
M$]K:#]@T\)TA[^9\2V%1LHA%Z?3#8"O]:E6>M+NG^"[G$DFO?%Y""Y-.TH*T
M,_1K=J`QH>1A.2X%<8LZ1GPKGKX+^7YV+$T,+Y-FY!QZB&;O/BZS[M]@TP\%
M95,@9U6O>'):EOD=:-8CVM""<_@1.M_<1FOA1$6XG*PM/$=/?Z(TY@%S>1'.
MQ&WT]E)Y_URL36%6S$FJ;+Q%VP\K4_KCF@**/'J9NKIT5>2?^AW8[#0XT'QY
MUZ8)J(?%G]93P84;5'ZI159%<V)/TDG\\<"MIND.38@HI:NM7\OWHY>;:3;,
MI/Z6JIX28$(AJ%F:,,^EQ_H#=51VL07EVV9YAQD"+0]`V.AN85TM*N0@1&TH
MKJ.I.\OI.1P?%YO/`#-C3]`,",P7)#=49Z];CM*SFP[0H*5[Y-R(#<6R/N?W
M*3C^Q]86T-J]->2#6]NCJ#??RSM+P04UJG;759Y-V*&(K68(^=\/EQZF&QU7
M'9RYC`SFLE.%+LXV7AIS3<_R_0O[N7D.='-[66>C@T(>T$ZY.E]^5U4POKHL
M6I"DJAF[=,;E$:=;UB[J+P@@A1[(_6N@=S8I)`O'2N3:S>'&V3N8D+$4SXMQ
MC5K4#P+O@Z9?0#$!&>I[R[+ZE@D_U<!P8`=0!CP$5`)^0*=.B3/U>(=^7PT$
MF<JXNT"5?A\#N)K2J2<P03_':/K)IOE_`R--[UL`9_U\&6@!BH%&F]0\\2HP
MPB3`2B!;EVE/ZOM]+O`QD&E:-Q0XJM]?T_.OZ@]8@.?TQI?IV_-6K9Q&X$O@
M36"4_J_@$!`(N`.+-<\2W6?]#V*[0^-\C+@O`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L
M;V-K+G!N9P``````````````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C$V
M,``Q,#4Q-30S,S<W,P`P,C(U-#0`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,`
M```H+0]3````!&=!34$``+&.?/M1DP```"!C2%)-``!Z)0``@(,``/G_``"`
MZ0``=3```.I@```ZF```%V^27\5&```#`%!,5$47'Q85'!0=)1Q7;U.CMJ!=
M=EAQCVMPCFINBVAMBF=?>%I>=UE@>5N%GH""F'YD@%YC?EU19TQNBV=A>UM8
M<%-:<E5JAF1<=%=M@VB&GH&ALYT-$0QC?EQE@%Y2:$QIA6)HA&%D?EUA>EIK
MAV1JAF-H@V%G@F!;<U5MB69LB&5IA&)G@6!I@V)RBFQXCG)\CW>&FH&%F8"-
MH8B3IHZ<K)B<JY@:(1A:<5,<(QJ`E'J)GH.'FH&-H(>/H(F?K9J@KIN;J94'
M"082%A````#___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````W37<V````17123E/_
M____________________________________________________________
M_____________________________P"R[K$X````"7!(67,```L3```+$P$`
MFIP8````B4E$050HSV-P00,,Q`E(@X"SLS-<@-'.VL;(6`(J`)0P,Q#04540
M<0:Q&9Q-'9R9#/G5M,1$G9VE6)P9G.WU;/ED^!6T-#6$>"6Y@0(F2G+FBK):
M*AK"K#QL/$`!2T%G"UUM+64.<6=G5J`*L$%66O*<[%P00T%6.>FK<W-Q,R/<
MX0@"R`XCS7,`HI`WST%D2+``````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8V%L96YD87(N<&YG````````````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,3`T`#$P-3$U-#,S-S<R`#`R,S(R,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$````!`(`P```"@M#U,````$9T%-00``L8Y\^U&3
M````(&-(4DT``'HE``"`@P``^?\``(#I``!U,```ZF```#J8```7;Y)?Q48`
M``,`4$Q410```/______^/__^\O*P*FHH)64C<"_MY.2C)N:E*JHH;>UKK:T
MK?WZ\)22C)B6D?SX[[Z[M+NXL=+.QLG%OM+.Q_^X1IF6D:M-0?=:3,-02/CX
M^/'Q\>SL[.#@X-34U,/#PZ&AH8B(B'EY>6-C8TY.3C<W-S(R,AD9&?___P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'U:V4<````J=%).4_______________________________
M________________________`#*H\%P````)<$A9<P``"Q,```L3`0":G!@`
M``!X241!5"C/C8_9#H)0#$0[,NY;%8O7NB#*=?G_'U0P/$!,=![FX>1DTLJS
M$_D#2"MO\#@7Q>5:EC'&V[T"`N`(G(`<6H,#N2#'54\^1I*L@:'J5%F#O=G6
M;.?NUF\V9KVY9UEH&1Y":(SNAJ;I@%R2H\U*OEWZZ[D7"'H6YK_\T?8`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]C
M;&]S92YP;F<`````````````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`T
M-#,`,3`U,34T,S,W-S,`,#(R-38Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````0````$`@#
M````*"T/4P```#-03%1%!0`''!P<'1T=.3DY5%145555<G)RB(B(CHZ.IJ:F
MJJJJN[N[Q\?'X^/C_O[^____````$)I!C0````%T4DY3`$#FV&8````!8DM'
M1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U00:$`@+!R[&
M]P```&E)1$%4>-I=CUD2@"`,0UE4L%";^Y_60F49\Y<WZ1+G'#8Y%<I20O<R
MU`G,/T8,G$`5\0@\$A&>E?)("(=V@>:("*D_9`,M0CN(;807N(`<$";0#5D8
M."<@TL<JT6V@S,=+^LJ,:MW_Z[^;TPQ1(OVC1P````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8V]L;W)P:6-K97(N
M<&YG````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,S<U`#$P-3$U-#,S
M-S<R`#`R,S<W-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```&`
M4$Q410```)\X4S43'%^@AR`U+3*5EA$R,@L2#Y:.<RHG'A(&";NSFS`M(P81
M$<=H24(C&+36N#Q'/4)K;&:JJWS1TRE&1JO/L#-`-;>OE$5!,R(M*@X7%TM=
M2PT,";"GB:*7=I.*;"TJ(1<5$18,"+JPDGIR6["D@7AP6(A_9)V2<^[6@$]'
M*SPX++ZTE<*YG+RRDK>LBK2HA)Z4="8D'#0P)H1[8;^UE[VSE)F/<"$?&&A;
M35I30;BMB\&XF[ZUEG!H4A43#QH8#B,>&AH8$ZB>?Z29>%--/6MD3K*FA,"W
MFI:+;2XJ(AT;%8J!9WYV7/______________________________________
M____________________________________________________________
M____________________________________________________________
M_____________________________________WE:-^,```"`=%).4_______
M____________________________________________________________
M____________________________________________________________
M__________________________________________\`.`5+9P````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"*241!5"@5!<'!20-1`$#!
M>;L_NT%S#(H$M`ZK"VG%'NS!2@2]ZD%74&<Z`P`&%P"<#9<HBI@`FH$)T)B`
MB6K?/,_5RN!`2YM#Q0"6UL^UGX4!+&5YOWU[:A#'7_-=]W\/?0U.E*IT-8!]
MV]_:9FD`2VO:K`WBIOK&L<?A#+Q<OYX^=ID`=KL]X]D_:U$54//2I44`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8V]L;W)S
M8V%L92YP;F<`````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S-#(R`#$P
M-3$U-#,S-S<R`#`R,S8P,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````9````,`(`@```'T-
M4?L````$9T%-00``L8\+_&$%````!W1)344'T@@/!R0?@IZVQ0````EP2%ES
M```+$@``"Q(!TMU^_````"QT15AT0W)E871I;VX@5&EM90!4:'4@,34@075G
M(#(P,#(@,3DZ,S0Z-34@*S$R,#"ZI"]T```&:4E$051XVNV=X8D<1Q2$A;#A
M!!+L_=,/)R!P`@)'('`"`D<@'(%0!L(1"&<@9R"'(&<@AW`+,DA@@X7$]/QY
MMW55KWNZ>W9KJ%^[LW.ST]^]5U,SVW/_7EFNBAX7/2EZ6O2LZ'G1BZ*71:^+
MWA2]+7I7]+[H0]%-T?]1#Z\6_?!XT8]/%OWT=-'/SQ;]\GS1KR\6O7JYZ+?7
MBWY_L^B/MXO^?+?HK_>+_OZPZ.;FJ[XM]^]YH1?N8'U'Z(K00T('18^*P`8?
M%($=^[[HU+<3#I:7DP=K6H[63P&@UK\.@&*^8/[?T,O=!VLVQ*Z+F`TR.R8B
M9K)R9$W"T740T_)RI2HVP0;6P<M(G_7HM+;KCS7%RV1-Z;,B/I4^"P#%[-B=
M?MT^:VZ?M3:FYCY+ZH^@4=IG[<%GK>/&#/MV/JN=7W?-.H\\J])G@0TR>99]
MUGP^"XP;,^QK8:KD2,I%G6=-[+-6$YRS\LTCTYR5M\_:>9XEG1("G]67(]>L
MGCX+G*\SYV(]?9;SK`O(LX":^ZPMBY?)&IMG,:6J>63JZX;[[(9#RIDD^ZR=
MDW5Z^=Q(QZ!66Y[H8)FL##6?BN(K*RSK':3QE:@CH3[TF:Q&9('C#3@"92BN
MS.`36?L4M+Y5R1%&S&35D16/+L,1H"8BMEW-`O1)K-V*F,G:S#J`$9#Z8ZQB
M3,VJK%#KQ\D*Y9JU&5F1"/`6PQ%3Q9B:%2N4Q!I`S-UP=,W*]4=`A.2S@'&7
M>E]$S#5K`[*D=@;6D=#(U2QI'6GGL?\R64/SK,J1C(PT0<-YUMQY5J[7`&IN
M"$EM,=>=G6=-DV=)B('&Q"0*#$<YQ,#W,EE]\RPP2H`:Z4R0J5F@8TJ(.<_:
M59[%1)0`.E"S0`:;:WD^-QS=#7,!*<@88N8IU2QP<4CR?<ZS)LZS6MW0(/FL
MB!BX#-[P-@B3-?1$^G-K,8B!5QCH[GS%9(TDZZJ1#L2O+Z17XDVNB5=,UC9D
M=:#F</K'.P`?"18@=\.^9($#+P&U@O`@".`#H(M;7M=A)@B(WXMBS635DL4<
M>#!ND9I6-2L"Q>`#J%E7=LT:[;/`X%16,:EFQ;?6[<3BE6N+MQ0OD]6^&U8"
M!:I/SF=%:B2@0*E"5<QD;5BS)*#`RH`CJ5'F@$I:>9.5)"O'2%P',,)P%->1
M_GKM":#)VE.>):&1<_E@G29@FJSN>9;4?1@TK@F!C"'7KUVS^I+%.%T)*(8U
MIF8QYP824,ZS]I!G`:`.R@4;8+@DCAB@7+.F.3>L;)1,FBZ)R?N=9^TASY)\
MS4&Y/,/X+";OSUTN=#<<G<%+I2J^PMRCD*M9E7(WG"]UD.@;(N=9TY'U'R'F
M)KY_"!V#F$\Q?YWY%B9K2[(J.5IOQP0@?"PZIC2(-9/5JF9U*%428J.+E\G*
MD<4<;^9W"Y$:IN7E)M#JQIK)FM)G,?T10/?QM.RSSLYG2<4+5+%*G]67-9/5
MTV=5(M;<9S'[8Y\UG\_:KN4U]UDKLTU8,UD3^"PPDI4^RWG69>=9JQ@BCJG?
MX>=8B\C;9^T\SP(^6T*,.25@]N??(ONL/?@LJ>7E)M!B3A*=9UU2GM739P&7
M%_<Y%B_[K#WXK!Q'C,_R=4/[K*:(2;U/*E[V68.ZX1#6&.B81LGD67=Z>I.U
M,5FGE_.?/<MDM2?+LV>9K*9D>?8LD]64+,^>Y9K5W6==].Q9)JM]-_3L629K
MXYIUT;-GF:PD69X]RSYK;WG6F<R>9;*ZYED7-'N6R6I&EF?/,EDSY5EG.WN6
MR>IQ;EC9*'<Y>Y;)ZI%G7>+L62:K1P9_B;-GF:S!$<W9SIYELD8=K.T>V-IJ
MRR9K/K*D`01/.#T23U.5?KS3E3Z3U8PL<+RE!S8?3S]ZE\$'/.(\/NN\DB.$
MF,FJ)0L\'!YP!*B1G@E=6;,`?1)KMR!FLC:T#F`$I/X8JQA3LRHKU/IQJD*Y
M9FU(5B0"O,5PQ%0QIF;%"B6Q!A!S-QQ=LW+]$1`A^2Q@W*7>%Q%SS=J`+*F=
M@74D-'(U2UI'VGGDOTS6X#RK<B0C(TW0<)XU=YZ5ZS6`&FDR&J8MYKJS\ZQI
M\BP),="8CLI,(8"C'&+@>YFLOGD6&"5`C70FR-0LT#$EQ)QG[2K/8B)*`!VH
M62"#S;4\GQN.[H:Y@!1D##'SE&H6N#@D^3[G61/G6:UN:)!\5D0,7`9O=AN$
MR1*6+V7DP9,GY:$&`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V-O;F9I9RYP;F<`
M````````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3<V,0`Q,#4Q-30S
M,S<W,@`P,C(W,C0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````
M!&=!34$``+&.?/M1DP```"!C2%)-``!Z)0``@(,``/G_``"`Z0``=3```.I@
M```ZF```%V^27\5&```#`%!,5$4```#____O[^_?W]_#P\.^OKX;&QO___\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!*U\L:````"'123E/_________`-Z#
MO5D````)<$A9<P``"Q(```L2`=+=?OP```!'241!5"C/;8\!"L`P"`.OSJ[_
M__$L;4'3!10\@D:&B-59=0!M`B.#4`$6<M*.=N8-@CBC`E,@CE<<=/.\E$?.
M_@23Z-=S61^[7@4G;`UY]`````!)14Y$KD)@@@```````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V1A=&$N
M<&YG````````````````````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3(P-P`Q
M,#4Q-30S,S<W,P`P,C(S-C0`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H
M+0]3```!+%!,5$4````!`0$"`P,#!`0#!`4%!04&!P@'!P<*"0@)"@H*"@H+
M"PL6%A08&!8A(!XH)R0A-D@V-#!#0C](1D$Z3%M)24-96%1)8'),8&U=7%5@
M7E=/9'598VUE8UQ4:7QM:V-R<G!V=&MK>()G>XN`?72(AX&)B(.,BXG'=&;'
M=&>,C(S'=6C(=FB0CH:0D)"3D8M_FJZWAWZ!FJZ7E8Z#GK*$H+7-AGK(BH"?
MG9:=G9V&I+F)IKRAH:'1CX2,J+W1D(2-J;[3D8:KJ:.PKZFHL;VVM:^VMK:Z
MN;:NO\W`P,#%Q<7(Q\*_R];-S<W'S]J_U>C*UM_5U-'6UM;7U]?+W>O/X.W?
MWMS;Y_'FYN3FYN;KZ^ON[N[Q\?'R\O+T]/3W^/KY^?G\_/S^_OX```!R:A(P
M`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q(```L2`=+=
M?OP````'=$E-10?4#`@2)P7P,@"#````U$E$051XVF-@2$8!#`S)\2'FMF!@
M;^OH[Y_,D!SN8*BM"00:FCIF#G)`@5"'X"0H2#"5A@A`05",D3A"16)<%",C
MHSA<A1L7ER6K.[,(6"`Z*2F66TN!6]A"F$45).`1X.?#Z>UJ86&A:ZP"$G"P
M-C!29K.P$)-24U$$"=BY>#$R"EM("?$+6LB#!$R]O)+572W$^#AX(T!:K(R\
M?).9A"W4!'G4PV09DI5,C'PC!22XG%5<(P+U98&^DY&V\=1C=W6R4%%15)1D
M8(#Y7RQ96%$X610`L?4]@S"/>ML`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V1A=&%T<F5E+G!N9P``````````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#4V-@`Q,#4Q-30S,S<W,P`P,C,R-3,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!`````0
M"`8````?\_]A````!F)+1T0```````#Y0[M_```!*TE$050X3Z62.VK#0!1%
MM1KWJ;*(D&0#@30B8$AO`B%-6H.40H*@/Q'J5&4'*KP0]];__WO)&QC/V)(+
MHX%3B7/OG4&"(`BP$`'>Y1]XVDA7<?_RP0*>WR2X6W]>Q>VCR`+P]'U_D:[K
MH&U;:)J&4%45N*X[#?!]_T3\_O_V^[4^RG5=$[DL2[!M>SZ`0@.0<SG/<W`<
M9SY@;C(O%T4!699=7L#+O'CS\$K`]C1-0575^8`YL!7?`@.P/4D2D"2)!8SC
M.)F,(IV,K2AB,\I1%($LRRQ@&(;)9-I,Y=5F18CC&,(PA.UVRP)P_OE#\5?`
M9AJ`[8?#X30`97XFG8IM*&`C2CR*HK"`_7X/01#`;K<C>)X'IFD2#,,`7=<)
MFJ:!95E$%D7N5U[(LO,'BZ^28&3PF^D`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]D96QE=&4M<VUA
M;&PN<&YG````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$V-#,`,3`U,34T
M,S,W-S(`,#(T,#(V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````(````"`@#````\]%.N0``
M`P!03%1%F0``F69FS```S#,S_P``_V8`_YDSS,S,````````````````````
M`````````````````/____]%!@```````,SX$@`SRM9W?%K9=Z(/V'>4#]AW
M&&^/`!AKCP`!`````0````$```"@^!(`G/D2`!#[$@`PU=AW^/@2````%`!0
M.OEW)````$@-%````!0`Z`$5`-#X$@``````Z/H2`$!]^G<@./5W_____U`Z
M^7?W?/5W]8CU=P```````$``.(9(`!$````$`````P```!AKCP!HVV$`0/D2
M`.M`U'=HVV$`[/___P`````8:X\`&&N/`"":]7<IFO5W&&`8`"0``@!0/!4`
M+/H2`##Z$@``````<SKY=R!@&`!^BO5WV`<4`,&.]7<\8!@`*&`8``````#!
MCO5W!0```"@`````````8EX8``````````$````4`/SX$@!X`10`Y/D2`$!]
M^G<X'/5W_____\&.]7=FD?9W@9'V=^`U_'=TD?9W@&`8`&!@&``\8!@``.#]
M?\SY$@`$````*/H2`$!]^G?8%?5W_____W21]G>4FO9W!P```#@````H8!@`
M`````+!5&`"X.`$````4`'3Y$@``````=/H2`$!]^G<X'/5W_____\&.]7<N
MC^=W```4```````ZC^=WH+S4=P``0``!````$%X8``#@_7\``$``````````
M```(`0``*&`8`$3Z$@``````L/\2`(:[Z7<`C>AW_____SJ/YW=<5T,`*&`8
M`*"\U'<``$``(````#`Z0I9PR\,!,#I"EG#+PP&`IY'D<1?#`0````")````
M)````"`!``!D96QE=&4N9VEF````````&/L2`.@!%0```!0`!/D2``3[$@`T
M^Q(`0'WZ=R@<]7?_____]8CU=].8YW<``!0`"``4`.28YW>@O-1W````````
M`````````````$3:1``8`A4`W-L6`!P"%0!LAD@`_____^@!%0">VD0`&`(5
M`'/01`#H`14`R8O"LP````AT4DY3_________P#>@[U9`````6)+1T3_I0?R
MQ0````EP2%ES````2````$@`1LEK/@```"A)1$%4&--C8(<"!G9&1A#-Q,#.
MSL(`XC.`>6`F@L$$E6)F@>J"`!8`,,D!7-.0&>D`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]D96QE
M=&4N<&YG````````````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$T-C8`
M,3`U,34T,S,W-S,`,#(R-S(T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````0````$`@#````
M*"T/4P```8!03%1%````"`@($!`($!`0&!@0&!@8(2$8(2$A*2DA*2DI,3$I
M.3DI,3$Q.3DQ.3DY0D(Q0D(Y2DHY0D)"2D)"2DI"2DI*4E)"6E)*6EI28V-2
M8V-::V-::VM::V-C:VMC<VMC<W-C>W-C>WMC>WMK>WMS>WM[`/\`A(1SC(QS
MC(Q[C(R$E)2$G)R$G)R,G)R4I9R,I:6,I:64I:6<K:V4K:V<M;6<O;6<I:VE
MK:VEM;6MO;6EM;6UO<:]QKVEQL:EQL:MQL:]UM:]QL;&UM;.WM[&WM[.WM[6
MWM[>Y^?.[^?.Y^?6[^?6[^_>]^_6]^_>[^_G]_?G]_?O__?O____________
M____________________________________________________________
M____________________________________________________________
M________________________________________________A:+W/@```(!T
M4DY3________________________________________________________
M____________________________________________________________
M_____________________________________________________P`X!4MG
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,-)1$%4&-,]
MS_T/@6`0!_!+Z"DBI!="9"/O(</FI:&%$/^0?UT]3[G;;M]]?KC;P3<JJEPM
ML(!C-`%ZS_?K*`$0H/>[3H7A>M/9#")@G;.WK?&\.K+M4,*^OP/_YNP7N\.J
MC:'_^(05^)>Q*D?PE?2)=_5.IEX7$%Z:R8N-5E.3>3J=P8`L,8]8BDH5N"R!
M^4:W]**6TWB&P-HU3Z8\+!D22F#@+A5+_$,W@?@*(PR4$(:B@K+)<X)I"!K'
MQL]AH@!(_`%4P#NN>&B9+0````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]D979E;"YP;F<`````````````````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#(Q,#8`,3`U,34T,S,W-S,`,#(R-34Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````0````
M$`@#````*"T/4P````1G04U!``"QCGS[49,````@8TA230``>B4``("#``#Y
M_P``@.D``'4P``#J8```.I@``!=ODE_%1@```P!03%1%%A8424E#&!@6YN;D
MLK*P[N[M75Q5B(>!D9"*L*^IMK6O0D$\B8B#=G1K;6MCD(Z&65A4G9R88%Y7
M96-<EY6.GYV6*"<D@'UT0T(_DY&+JZFCU=312$9!-C0P(2`>C(N)W][<W=S:
M"@D([N[N````____````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````FU?PM0```"9T
M4DY3_________________________________________________P"G>H&\
M````"7!(67,```L3```+$P$`FIP8````?DE$050HSVV/R0[",!!#`V4M#92$
M(2Q3UC?__XM<DBH"?+%DV;+M[`LN,U`)8#PQR`+O&2K*$K*P7XG([I"4$A'I
M0Y=\CH!*.!T'V2J8,V/>2G][39L4`\71#>[^B-EAQCJUS?4<Q]KV(BEYOR@M
MT*->F4"U=%,M_?WR[^V(#[*+'Z@DO2(``````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V1O=VYL;V%D+G!N9P``````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,W,P`Q,#4Q-30S,S<W,P`P,C,R
M-C4`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!`````0!`,```#MW>)2````,%!,5$6`````
M``#_``!_?W_`P,#___\`@```_P#________________________________6
M&,+;````"7123E/__________P!33W@2`````6)+1T0/&+H`V0````EP2%ES
M````2````$@`1LEK/@```$])1$%4"-=CZ.CH:&`$$@P@AB(N1@.#HB!$A$E)
M`D7*V-A8V-C8@J'9!0P,&4Q#02#8D,$$Q'<KAC)<G($,8Q``,<!J@`QC")!@
M:!0$@PX`X^<J.JA\;5$`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]E9&ET+7-M86QL+G!N9P``````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`T-#``,3`U,34T,S,W-S,`,#(S-3`T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````)````"0@#````UT_V(@```&!03%1%YN;F^-DX3T$595P^7$\K
M\;5-]K1$UZYT_.D\2TM+2$A(145%0T-#0$!`.3DY-#0T,3$Q+BXN+2TM+"PL
M*2DI____````````````````````````````````````````_A/20@````%T
M4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````
M!W1)344'U0<."!\L+4F_V@```#E)1$%4"-=C8``#3DY.*(.#E1_,X.)@8P:S
MN&$,'D8V9@$0@Y>1E440K(B/G5D8HHU)2`1F$H1F```[5`%246O)O0````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O961I="YP;F<`````````````````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`Q,S8U`#$P-3$U-#,S-S<S`#`R,C0P-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$```
M`!`(`P```"@M#U,```&`4$Q4149&1?SI//C9.$]!%65</EQ/*_&U3?:T1->N
M=/[^_OW]_?O[^_'Q\>[N[NSL[.KJZNCHZ.;FYN7EY>+BXLS,S,K*RL3$Q,'!
MP;V]O;N[NZ>GIX6%A8"`@'Y^?GU]?7Q\?'IZ>GEY>79V=G5U=7-S<W!P<&UM
M;6MK:V5E96-C8UY>7EE965A86%%144U-34M+2TI*2DE)24A(2$5%14-#0T!`
M0#T]/3P\/#DY.38V-C0T-#$Q,2\O+RXN+BTM+2PL+"LK*RHJ*BDI*24E)2,C
M(R$A(1T='1D9&1<7%Q45%1(2$A$1$0\/#PP,#`L+"PD)"08&!O___P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````/:1
MIO\```!2=%).4_______________________________________________
M____________________________________________________________
M_P"M+0QQ`````6)+1T1_2+]QY0````EP2%ES````2````$@`1LEK/@```+!)
M1$%4&!D%P;TN!`$8`,#Y?JR]0J%Q)94(A41!$`_AM0E"(I$K%3J%4.QMG)B)
M6_<B,S+B!-K])XA%OQTAI:JJROKY6J$E(Y->OG]4';1B@G7\GKYL;;5D@2GG
MLZ=A4RW%!-/AX[`Y7[8(HVFT_SAL+O:T9"WFPX?^NVQ2RG$<HX:_JU71@C7'
M=]?]M)VT$MOS4#?/0M):S.;7"!2M"`@B:;43$(CO76TY1D9D9$8$_^[L*5BN
MR2V[`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O96UO=&EC;VYS+P``````````````````````````````````
M`````````````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S<Q`#`R,C<T,P`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O86YG96PN<&YG
M````````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U-S8`,3`U,34T,S,W-S``,#(T
M-30V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````/````%0@#````KD5$A0```&!03%1%````
M_____?\`^OKZ]?7UZ^OKX>'AU-34T-#0Q\?'PL+"P<'!NKJZN+BXL+"PK*RL
MFYN;E)24D)"0C8V-BXN+?W]_4%!0)"0D("`@&QL;____````````````````
M````ABT[#````!MT4DY3__________________________________\`)S0+
M-0````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"0241!5!C3
M98]M$X,@#(-SFQ0J#O<":/G_/W2M>O,<^<1SN:0!K<FIUM#D=DH:%'^V/CN_
MRU^UL\AJYL%2<YI2KK+S4B*;8EFV^V7DX+T//!;KKY$!(@(X5MV3.0#..2!P
M%DAB3VX8!D>>DV"=-KYO/*V=KWG,I'E*L+SV/_'0_AEOZ[?['YA>^_W_?=W^
MR_^^EH`4!>W\QSL`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V%N9V5L=VEN:RYP;F<`````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P-S8P`#$P-3$U-#,S-S<P`#`R-30S,@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````#P```!4(`P```*Y%1(4```#`4$Q410```/____W_`/KZ^O7U
M]>OKZ^KJZN'AX=34U-#0T,S,S,?'Q\+"PL'!P;Z^OKJZNKBXN+"PL*RLK*.C
MHYN;FY24E)"0D(V-C8N+BX>'AW]_?VMK:U!04"0D)"`@(!L;&Q04%!,3$P@(
M"/___P``````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````&'A
MM_4````D=%).4_______________________________________________
M`%@L#0T````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````F4E$
M0508TV6/;1."(!"$=THZ["3#WHC0T_C__S'0)L?83SRSLWL+8I15,2+*;I5$
M)/S9Z5GX17ZKA46&;'Y9@K.M=4$6[KWA+./[^;X_<:VUKKGQN3^8T;^F(P%L
M0MKC^#*]GP<%U.P$8EF3JJI*D68K&-J9]S.W0^&G/#I22I%%SJ?^*\Y$U.&>
M^]/]YH&LVW+_?U^Q?_._#[[Q&BRYYWX.`````$E%3D2N0F""````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V5M;W1I8V]N<R]A;F=R>2YP;F<`````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,3,U-@`Q,#4Q-30S,S<W,``P,C0U-S4`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@````\`
M```/"`,````,"&5X```!@%!,5$4```#____&("/#("*Y'R!""PRW(B20'A^-
M'A^B)RB%("'\1$5+'!WY:VT"``#_!`3_&!@0`@*?%A:7%Q7H(R'.'QTB!07[
M)R>M'!O3(B&?&AF$%14L!P?_*BHC!@;6)B7\,#`0`P/O+R^R)23]-S??,3'E
M-#.#'AZ-(2&"'AYU&QOE-S;V/#SY/S\,`P/Z0$#R4E+W5%0L#P_W5547"`B$
M,##R@']D0$`G&QMX6%CT]/3FYN;EY>7:VMH@("`?'Q\;&QL6%A85%141$1$*
M"@H("`@#`P,!`0'___\`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#3
M0HAX````27123E/_____________________________________________
M__________________________________________________\`#`B?50``
M``%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"R241!5!@9!<$%
M0L0P`$7!WTT@2(HN$MR#0]%BR\??_4_$C`"P>QL``<XIQIBR`8%KV%@KJ\NA
M&H3KH"S-+,POED$U(H<B35Y.[:J$C)S*4.JN.VE8DN5X>'71M6W;31\<1:N/
MYW,[M^U#VVW.KL1>CF?W3S>2[AZ/]Z+EM/W^K$;-Y\NH)(L</EZ_&C6?;Z.0
M$:YC/[^2_KZWJA&XCI^LE[(_<6H0X)QBC"D;$`!V;P/P#_4V(P&3>GD4````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V5M;W1I8V]N<R]A;FYO>65D+G!N9P``````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,3`R,P`Q,#4Q-30S,S<W,``P,C4Q,#$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@````\````/"`,````,"&5X````8%!,5$4#`P-JDKXR0E8>*#2RRN)(9(`I
M.4F&JM)24E(0$!#F[O92<I(Z.CIWG\[*VNHN.DJ8N-K^_OY*2DI"675<?*,Z
M3F8F,D*BOMYRFLH*"@H6%A;2XNY&7GY"/D*ZSN8````P1),0````('123E/_
M________________________________________`%Q<&^T````!8DM'1!\%
M#1"]````"7!(67,```!(````2`!&R6L^````D4E$0508&36."PX"(0Q$"_(1
MD95(61=QX?ZW=(JQ21O>E,R4IA1)_5Y"S3FW7Y:";KJ64JJ&(MRJC<P</]5!
M`%M6*27%MNY@X.%SSOY@J^%!48FYD8$/1)R(MKX1)2YN<1[]UD<&/X@"V&!O
MA+&?0?F7&>9Z?\<J>0'^Y_-<_L(0_OEMW3M#D/ML`RZ&@ARA.;]::@WWQ"**
MS@```(-T15AT8V]M;65N=`!4:&ES(&%N:6UA=&5D($=)1B!F:6QE('=A<R!C
M;VYS=')U8W1E9"!U<VEN9R!5;&5A9"!'248@06YI;6%T;W(L('9I<VET('5S
M(&%T(&AT='`Z+R]W=W<N=6QE860N8V]M('1O(&9I;F0@;W5T(&UO<F4N`553
M4U!#350]`#H8`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]A<VQE97`N<&YG````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#,V-P`Q,#4Q-30S,S<W,0`P,C0W,S``(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@````\````/"`0```"1WUW!`````F)+1T0``*J-(S(````)<$A9
M<P```$@```!(`$;):SX```";241!5"B18_C/`(/2_Z7_*_P'D0@QN)3Q__#_
MV6`8#F3#E$`E`_X7_J^$PT(@'Z(`*ED,%&SYWPF&+4!V,50!4-H8K+,3J'@F
M&#(#V2`3C$'2TD"[0#HG`:67@B$#D`TR(1RH'RB=#=8[\S_;_TU@"#(%I#\;
M)*T`EU[ZG^,_+XJT`K)N5FRZ"=B-Z7(N9)<3]#>!4",8YKAC#``"B"&YUV)%
MO0````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]E;6]T:6-O;G,O8FEG9G)O=VXN<&YG````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`W-S4`,3`U,34T,S,W-S$`,#(U,C<W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````/
M````#P@#````#`AE>````,!03%1%````____A#L%_W(*62@$%P\)=#,%Z&<+
MXF0+WF,+:"X%NE$*UET,R%<+RUH,WV81_W44QEL0N54/GDH0B4,1CT82C$42
M72X-_WTE+A@)WW8MU'`K_X<T+!<)9CP>1RH5.B(1_Y9,9#L>QGY.*!\9VET,
M;"X&9BL&0B`*4"T6'1(+_Z)E[I=>HVA!!@0#&QL;____````````````````
M````````````````````````````````````````````OT5OS````#%T4DY3
M____________________________________________________________
M____`!^:3B$````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MF4E$050(UVV/6Q,!,0R%,ULV+E6EEEIQ*;NH1?K_?YV&)\-YRG?.G$D"2<3<
M,+\G$(K.&.,B?Y@KC2)=L3!7;0E@`<HV&Y"BQ@R4+=0Q`3M4GD((Y!4Z!C9H
M*71=%\BB86@RUX?;L[^O,S>23]?'Q_VTVTXES_WBNI'^JI!^BI/1W!.1G_7&
M4?8O+T-EK56#\X+_W/=S_]=_+]XY&9/:>/@B`````$E%3D2N0F""````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC
M;VYS+V)I9V=R:6XN<&YG````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#$U`#$P
M-3$U-#,S-S<P`#`R-3`V-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````#P````\(`P````P(
M97@```#`4$Q410```/___P$#!`$$!1PC)3BBNQQ072QH=@('""N%F2=YBSV[
MUR9UAR-L?#NSSC22I00)"A]"2FG+X2E[B29P?36:K2AU@R%@;!];91M/6"EV
MA!]99$C%W"U\BB]_CBUU@57)WR)`12QS?@`!`0$$!`$"`OS\_/O[^_KZ^KV]
MO;6UM:*BHG5U=1L;&Q@8&!<7%Q`0$`\/#PD)"0@("`8&!@4%!0("`O___P``
M`````````````````````````````)9BL>$````X=%).4_______________
M__________________________________________________________\`
M.UP1R@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"B241!
M5`C758_)%H(P#$43!7&DBM81+444'"**E/[_G]F6P\*WRLWX`MJ*R"-R$5B2
M@C$F)+5,`?>M>$"6*5CU^K/)*,NV)@%:\N'X>$GFI^F92PTD_#!.HBA*XM`7
M!,0&T&G!"#SV1@3$O,1",<_4P7%18EZ9.HGZ@5_'=V7FM5PWSY?MOZF-=/>7
M#11X_:B=NV\2^\HLKP^MO\Y_VOG_^^\'/J@;#>'Y-3$`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M96UO=&EC;VYS+V)L=7-H+G!N9P``````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M-S8U`#$P-3$U-#,S-S<P`#`R-#4W-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````#P````\(
M`P````P(97@```#`4$Q410```/____KZ`.[N`-;6`,C(`,3$`+BX`*>G`)^?
M`)N;`)B8`(J*`'Q\`#P\`!`0``0$`-75#<S,#,?'#/__'___.?__50L+!!(2
M!__X.]G.!^&V&/_3*>:@'^>?(_V7,_^5./!R(_]Q(?]T/?9B-?Y<,O\_*_]#
M+?PU)/\D&?\P*?\$!/\9&/___P``````````````````````````````````
M`````````````````````````````````````//X68P````N=%).4_______
M_____________________________________________________P""CW-5
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```)1)1$%4"-=E
M3TD2PC`,TS1NPI*FAL:!LN][__\]8GH"=+*LL22C4S#7S)\)RH)WSOG`/>?*
MDL)6K)RKDDQ1%(;*O$`7+`$Q1H!LZ,">#"`B@"'/8+?<KB3-DNS.:\>HW>EU
M;=,\R>-Y<W76-Y=CFU*2PWV?=?8+-#'?QRGT/OL/,,G^#4;JK_EC*(9]_F^_
MO_Y?_[T!7JP2"/5$A`L`````245.1*Y"8((``````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]C
M;&]W;BYP;F<`````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,34Q-P`Q,#4Q-30S
M,S<W,0`P,C0U-S<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@````\````5"`,```"N142%```!
M@%!,5$4```#___\``%D!`<@!`;\!`;D!`:\!`9,!`84"`N8"`K8"`J`"`ED#
M`UL'!Z4-#>(&!E@3$]85%=(?'[P<'%88'!C!PL$8S0`8P@(<E@PWB"QQB6ZZ
MPKG`Q[]\@7N&CH0F*27-``#-`@+-`P/.!07.!@;.!P?."@K0#P_/$A+0%!31
M'1W3,3'3,S/4-C;50$#734W855798F+:9F;;;&S;F9G<J*C=M+3*I:7AX>'4
MU-3.SL[*RLK)R<G'Q\?%Q<7"PL+!P<&]O;V\O+RZNKJSL[.PL+"GIZ>?GY^:
MFIJ-C8V+BXN&AH9_?W]Y>7EN;FYL;&QH:&AD9&104%!.3DXD)"0@("`>'AX;
M&QL2$A(,#`P)"0D("`@&!@8%!04#`P/___\`````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````"_5]``````87123E/_____
M____________________________________________________________
M____________________________________________________________
M__\`KH!O,0````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#[
M241!5!C319!G4P(Q$(9W['K8E4"H=L7>3=1(%$\TG"UPKI7\_U_AYH[1YT/F
M?2;)SNZ"2Y@>SJ0!DG-V,`@R_SXS$!#C/9_LZS$ZE?C$T%A_D#!'SKFU(ZE:
MRSEPQIAM8XQM2XD#,);CE;`15GB.,2#/%XHEI52I6,A[AW)V_E)*>5'-ELD<
MUV_0%4)\P/>S=8!&G7^='6SNG72OE4'`4$MQ5%M9WA52A0AQ`V[$]OK"XIJ0
M/[<QW7\VQ6%M=6E+7+TWZ;VY@];I_L;.\0/X_\[J1[BG^BUXT53?851_]6W`
M4SU"/U\GTLJCHTZZ#[2&^C<6__:%-!\FZ1=DLD5V)>;O-0````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I
M8V]N<R]C;VYF=7-E9"YP;F<`````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#4U-P`Q
M,#4Q-30S,S<W,``P,C4R-C4`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@````\````5"`,```"N
M142%````8%!,5$4```#___\$%`0'(0<QXS$PVC$NQB\LKBLQMC`"!P(F?"9+
MZDI@ZV"(ZHD<)APNNBPNMRPPL2XOKBXGD28HB"<A2"!W[W8;&QO___\`````
M``````````````````````#2AUON````&7123E/_____________________
M__________\``30*MP````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;)
M:SX```"#241!5!C3;4\!#@(A#&L4A@)RJ$#W_Y=Z'#$7Q"Y9TG7K-JA"]4PX
MXDS0N0%+_XS_.IG(KZZLQ3E7*@>GS]*1/3NGW\0:8ZQL>P%:LP`A!$!R5;"(
M!6*,@)5"T(D)L;46@Q%'I,$?@Z=%[_.W.W8\C_GN?WGO_J_KX;_L_[UON7_Z
M[P.,R1.>+7A]5`````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O8V]O;"YP
M;F<`````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P,#(`,3`U,34T,S,W-S``
M,#(T,S<U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````/````#P@#````#`AE>````,!03%1%
M````____``$!`0,#`@4%`@0$`0("'6)7/<RU'V=<)F9<"!43C^+5/]6[.KJD
M+9&`*XMZ*H=W*81T,I^,-ZR7-:20.ZZ:/K:@.JJ6+H!Q)VE>+'5I5MW%-8EZ
M(55,%38P:^#,:=S(&C8Q$2,@#!@6!@P+(T4_$B,@?^72/6YE-Z^8,9R'"AH7
M?>'.8[*C'24C`0,"&QL;%Q<7$Q,3____````````````````````````````
M````````````````TA5U?P```#5T4DY3____________________________
M_________________________________________P!\M=`*`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```)I)1$%4"-=EC]D2PB`,1>]H
MK74!-]!BH^*&6)<:[?]_F]`^.=ZGG$DR.4$=PUPQ-Q4B.:.U-HY;YD+)&%5P
MY/?P)C,A1";+]2?PJ=M!,MK>4R"YU&"SZ"=(#SV\!M(P6$NQ.S\?U^-&2,VH
M`M/>C[VEP%73)^M]RV'>2.1DK:4EXG[MU`0K(LHQ4R[<XZ*<(V9:!J%_OS__
MG_^^XQ\;I55VD%``````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O
M8V]O;&=R:6XN<&YG````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$S,S4`,3`U,34T
M,S,W-S``,#(U,C8V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````/````#P@#````#`AE>```
M`8!03%1%````____``$!`0,#`@4%`@0$`0("'6)7/<RU'V=<)F9<"!43C^+5
M/]6[.KJD.;:A.+.>-[";,J"-,I^,,)F'-ZR7-:20+H!Q)VE>+'5I5MW%-8EZ
M(55,%38P:^#,:=S(&C8Q$2,@#!@6!@P+(T4_$B,@?^72/6YE-Z^8,9R'"AH7
M?>'.8[*C'24C`0,""PT+`P(!$Q`."@8%$0L*(`L*_P``^@``]0``(```%P``
M`0``.`,")00$!@("&QL;%Q<7$Q,3____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````:Y/:^P```$)T4DY3____
M____________________________________________________________
M______________________\`1!80``````%B2T=$`(@%'4@````)<$A9<P``
M`$@```!(`$;):SX```"H241!5`C798_9$H(P#$4SBKBVHM!6<->*N.!>W*/\
M_T_9BCXXWJ><23(Y@=0$,49\5V!("LZYD)@Q^HR:,!\-/RHS6B*$E&C4>FH>
MY7-@53MS&\":I(#"+5I@#PJP*E.!@)R2[GBYF`[;A'*$6'/0#VMA+]`<F_X&
MLEP<W4=!#^>C2E1RVIK]5++Z^J:4NNX<)O4]]*/&74_OFY$6^OBYGO?U^_/_
M^>\%#5`A)V@E_S<`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T
M:6-O;G,O8V]O;'1O;F=U92YP;F<`````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$S-#``
M,3`U,34T,S,W-S``,#(U-C(T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````/````#P@#````
M#`AE>````8!03%1%````____S@!2M0!(_0-G_`-G(0002`\H+A0B$`L./",S
M$@T1#PP/%189``$!`0,#`@4%`@0$`0("'6)7/<RU'V=<"R`=)F9<"!43"A$0
MC^+5/]6[/M&W.KJD.;BB,I^,)GEK'V)7-ZR7-:202MK`+H!Q)VE>+'5I5MW%
M-8EZ(55,%38P"!02:^#,:=S(&C8Q$2,@#!@6!@P+(T4_$B,@?^72/6YE-Z^8
M,9R'"!@5"AH7"A02?>'.8[*C'24C`0,"&QL;%Q<7$Q,3____````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````P=%*Z0```$1T
M4DY3________________________________________________________
M_________________________________P!QTH\2`````6)+1T0`B`4=2```
M``EP2%ES````2````$@`1LEK/@```*E)1$%4"-=EC]<2@D`,13/V+N):UUA8
M5[!@0\2*4?[_G]P%7ASO4\XDF9Q`I$,4$L45:/*D$$)ZE##9%NI8-FE^]R[(
M..<,@\5'\:'9`*._NID`QBD"DI.V`>:N!:\.2@(2R-?'Y^.\7W(4!*%B9^L/
M?==1',9]Q_7]A-6\1-;=W&OEP97I_<BSD,_KN7QUA):G[I$=(*MDLL5QH(12
MOVFI,$O]_OQ__OL"/9LFS1:RQE(`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]E;6]T:6-O;G,O9&%Z960N<&YG````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#$P-#``,3`U,34T,S,W-S``,#(T-3,R`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````/````
M#P@#````#`AE>````,!03%1%````____QB`CPR`BN1\@KQT>8A(3FAT>10T.
MD!X?OBXO?1X?]SP]\3L\[CH[XS<X2QP=4B,D^6MMR%98F4)#%P0%\B$AFQ45
M0@H)Z2`@KA@8DA049@X.2`H*Z",ASA\=:!`/3@L+1PH*3`L+3PT,QR`?PA\>
MMAT<C1<6@Q44@144TR(AP!\>L1T<I!H::Q$10`H*:A$120X.@QX>2A(2CB,C
M&`8&!`$!31H:]U14P4)"1A@8\H!_)QL;&QL;_____WT-`0```$!T4DY3____
M____________________________________________________________
M____________________`,)[L40````!8DM'1`"(!1U(````"7!(67,```!(
M````2`!&R6L^````K4E$050(UV5/UQ+",`SSD3!20@D!PBA[0\HL*RUU__^O
M2"@O''JRK+,D0^:`F")^)G!,,$HI$YASC,CYJ(]G$J'C&!4V$*@`-@6[@$P0
M_0"/>_#01&2`3(_:]]C$]_9(,P2DH?*-E-+X2E.$M'CJ<"-?TO!>2%.K+X8U
MTVRT#!]LK8YLW2W?DF=2+\V7]M[Z[V:5:NUZF:Z<O\O?CY7J3PYYONNG';[]
M_OK__/<&3&8BVL"0?GH`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]E;6]T:6-O;G,O9&5V:6PN<&YG````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#$T,3``,3`U,34T,S,W-S``,#(T-30W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```/````%0@#````KD5$A0```8!03%1%````____QB`CQ2`BFAD;E1@:E!@:
M>A05<!(4PR`BN1\@]BXPC1T>D!X?]SP]2QP=^6MM8Q`2&`0#\B$A[2`@Y1\?
MR!L;WQ\?S!P<?!$1Z",AW!\?#@("SQ\?S1\?R!X>%`,#UB$ARQ\?-`@(TR(A
MPA\?P!\?:!(1'P4%M1\?KAX>@QX>8QT=4A@8]U14)QL;(!L;_/S\^_O[^OKZ
MO;V]M;6UHJ*B=75U&QL;&!@8%Q<7$!`0#P\/"0D)"`@(!@8&!04%`@("____
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````#^>L4````$-T4DY3________________________________________
M________________________________________________`$%B!.\````!
M8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````TDE$0508TVV0ZU+"
M,!"%SR(B#;:I2`'!N_$"T5:IRHHBI>__4&RWR(PSG,F/_<Z9S6Z"\K^PAY-M
MG=1\=;;E\WOE\5\/$N6+'=\J7WHP9\P83)4G_CDTQCP,IE[YU0=.='/@N6+V
MC;MN[S2Y?FJ(@=(&K@]$P-`%M@2';M0!4J`S<B&#S2.B-([C-,*+863FFU`K
M+TPF.8CDS!8T6TK.X>J3?HGR!7T4TE_:UGK^5>7OQ9'5^<TU<GK[*4YTOAB'
M2[EMU:[W$\-6^Q];WOV7OD^K#3Q^,].F5/;C`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O9&5V:6QT;VYG=64N<&YG````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#$P-C``,3`U,34T,S,W-S``,#(U-S<R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````/````%0@#````KD5$A0```,!03%1%````____QB`CQ2`BPR`B
MN1\@]BXPD!X?]SP]2QP=^6MM%@4&)08+%P4('`,(%P0(6049/P0450,=)`$-
MS@!2M0!(_P%E_P%F&`0#\B$A[2`@Y1\?R!L;WQ\?S!P<?!$1Z",AW!\?#@("
MSQ\?S1\?R!X><!(1%`,#UB$ARQ\?B185-`@(TR(AT2(APA\?P!\?'P4%M1\?
MKAX>&P4%)0<'@QX>8QT=]U14%@@(\H!_)QL;(!L;&QL;____````````#*Q`
MYP```#YT4DY3________________________________________________
M_________________________________P"Z^W$V`````6)+1T0`B`4=2```
M``EP2%ES````2````$@`1LEK/@```+])1$%4&--MT-ERPC`,!=`[U,Y:H*QM
M2(&4?1%=*"8T5?[_MXAER@Q#]:0CCRS9*&\#_SB]Y*GS?'SQY%W\]M>#5#R]
M>BV>&3`7S!CNQ5_FZ&NM/X9[(_XUBJI8/1BV9E/;O@R2=/E9JPHH0T6O0`",
M2(4EV*?,`W+`R\AGL*8DR*,HRH.$-*-P_G$N[LYM_R$^U9OQM_3;^Q/O\;G?
M&,C]=CYE3]U>>^?F5P5%FU9GH=Q^52&T^_LA7_]+WB?9&84`,MH_%4]Z````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O9&ES87!P;VEN=&5D+G!N
M9P``````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#$P,3(`,3`U,34T,S,W-S$`,#(V,3(V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````/````#P@#````#`AE>````&!03%1%`@("KH0R_L16
M;DH"SJ9:H&P(^*0"_K,@6E)"+B`"U8\"9E8ZMWH"'A,"_:L1_;L\_O[^GGY"
MQH("[9X"B%H">E("#PL"'AX>QHX>:F)2KG(":E(B]LIN.B8"PGX"````/WO<
M&0```"!T4DY3_________________________________________P!<7!OM
M`````6)+1T0?!0T0O0````EP2%ES````2````$@`1LEK/@```(A)1$%4"-=E
MCXL.PC`(1>^F`X=]Q+5;M=KN__]R?1@3E82$`^%RP5X#V(!>U4Q>*>43.F/-
M4B.O%0HNXHC(R5(:V%,6,LQL2'(J2EZ<86LM&R<>0)1XM^,X6B:)A96<GI?S
MJ[%J<^)K"(\A8)O0]X=PLSRE6/9_]?_N-W^SUGKN_M[^X\?_UW\'PUL.=->=
MS)@```"#=$58=&-O;6UE;G0`5&AI<R!A;FEM871E9"!'248@9FEL92!W87,@
M8V]N<W1R=6-T960@=7-I;F<@56QE860@1TE&($%N:6UA=&]R+"!V:7-I="!U
M<R!A="!H='1P.B\O=W=W+G5L96%D+F-O;2!T;R!F:6YD(&]U="!M;W)E+@%5
M4U-00TU4/0`Z&`````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O96UB87)R87-S
M960N<&YG````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P,S<`,3`U,34T,S,W-S``,#(U
M-S0Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````/````#P@#````#`AE>````,!03%1%````
M_____A@9]AXC^2PO[BTT[S4][3A!W$=8U$Q>TEAOODAILDMLM&:-K62.AF*6
M@F"6`0$"`P,%96BJ=7S#67'#`0($`@,%$Q06/&N_#`\4,'7:*V:[+FS&(4V-
M'41\'D:`&SYR)DE\6(/%'"`F,7OC`@4)'$1X+&FZ+&>W'$)U*V*N/8;H)U"(
M2HWJ4H3*8)KK(#%(=JKO#`\3!@H/``$"`0(#!PD*``$!'1X>_P0$&QL;$Q,3
M$!`0"PL+____%J]MB@```$!T4DY3________________________________
M____________________________________________________`,)[L40`
M```!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````K$E$050(UVV/
MQQ+",`Q$=^B]$T(1-0:"8^.$CH#\_U]APXD9=-+3SJXDI*Z8`^9/!T>QDE*J
MF+_\:'L+(IIZYZ=C'FQF)R'$>KZ[LN4X!"*M=02$<0I6!&ACC`9(,5AV&SV3
M)(FIEUJ2$<ARIKBZ/"_[W#TO`ZLW"Y7#+;F-JMF:U5D-^Q&L']'8^6T^"=A\
M"'+Y*2^WU/&%WZ'MTNVW@W!R?!TGH<5_]__\]P;#!28-=RQ]$0````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O96YR
M86=E9"YP;F<`````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P,S0`,3`U,34T,S,W
M-S$`,#(U,#4T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````/````#P@#````#`AE>````,!0
M3%1%````____IP$"_0(#M0(#^`8)!`H3'$>$,'7:#B(_#R1""!,C+FS&'$)Y
M%C1?)%.9)DE\#Q4>0$M;'"`F$"E,,7OC(U>@#R5$"18H%S=D+&FZ+&>W#!PR
M*V*N"QDL/8;H)U"()T^'2HWJ/'._/'*^*D9K8)KK(#%(+T=G=JKO5%]N&R<V
M"Q`6#A4=1@``10``,@``,```+```)```%P``]/3TYN;F("`@'Q\?&QL;%145
M"@H*"`@(`P,#`0$!____:(4#6P```$!T4DY3________________________
M____________________________________________________________
M`,)[L40````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````J4E$
M050(UU5/61O!,!`<=Q&4JJ,1C:!1]\VZ^O__E:1]89]V=KXY%HD=(H\HW6"1
MED((J2G#Y')FA[MD,;E@CN_[#H,Y(-$<O5`I%5;`=0*238RG413-QFA(`@D@
M?U['FU/Q`$'P1`VE+8!]83<2GN%;56`5MW'L#PU/DCFA,GH5.LSHC3_KOM[X
M/`?,^IO\X'Y![G&]!6F^.2R6=90[\ZR?[3_Y[?_WWQ?;VR!S^X0CJP````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O
M;G,O9G)O=VXN<&YG````````````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U-#``,3`U
M,34T,S,W-S``,#(T-C`R`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````/````#P@#````#`AE
M>````&!03%1%````____`P8''",E.**[+&AVCM+C/;O7.[/."1L?-)*E:<OA
M-9ZP-9JM!A$3.)NM-I2E-Y:G+7N)+76!5<G?(D!%?M;F&QL;____````````
M````````````````````@#;V=````!ET4DY3________________________
M________``$T"K<````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^
M````=$E$050(UV6/2Q+#(`Q#-<$4`J%-RT?<_Z3%L&K1RL\>RS*ZBC3DK*!4
M<P@A5RZF3:)*ELJTEWCGG)=K--!K$J"4`DBJ'<SB@1@CX"43#.)*;*W%XB00
M9O%CL=GFNO\Z,/2>^^K__`S_^YS^V_W_?%O^G_^^!PL,\>]8%>0`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V9R=7-T<F%T
M960N<&YG`````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-38Q`#$P-3$U-#,S-S<P`#`R
M-38S-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````#P````\(`P````P(97@```!@4$Q410``
M`/____KZ`.[N`-;6`-+2`,C(`,3$`+BX`(J*`'Q\`&YN`&EI`#P\`"LK`!86
M`!`0``0$``,#`/__#[:V%O__'[JZ%___.?__50L+!!(2!____P``````````
M`````,3W5W`````<=%).4____________________________________P`7
MLN+7`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```())1$%4
M"-=EC\L6PC`(1.<DV#QL-+12HOG__[0T=J&RXL*9&4"W8J[,1P>CDF*,J?!@
MSH&L0F9CSA-YYYRG:1^@ET"`B``42@<G\H"J`IX2@R,YT?9L*HXBHPY^#:[G
MOC7=[I=];_I5=OVVS*8W?[>*/);KX7_FW^9/_N]]?_=__?<&"!T-%F0KCVD`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]G<FEN+G!N9P``````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#<T-0`Q,#4Q-30S,S<W,``P,C0T,34`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@````\````/"`,````,"&5X````P%!,5$4```#___\K`0(8`0,E
M`PP'`0,6`PP$``("``$;!!&B,-J/++^,*[N4+L:1+<)_)ZEZ)J-_**K*B.JG
M,>.(++J'++>!*ZYF)XA?)GRT2NJ\8.LZ($C%=N\B'";_```8```2```(```!
M```;&QO___\`````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!-
M_HH4````)7123E/_____________________________________________
M__\`/\]"3P````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"-
M241!5`C798_)#L(P#$1'K"7%4$BS)V5Q_O\;B1MQ0,S)SR/;8U01<V%>*P@E
M9ZUUB3NS-R0RGH79SZ2TUHKFUD!-AH`0`D`F5;`C!<08`46.P99TB#GG&#19
M1NE\[US$/Z+K/3:_S>^>+\''2>;;_LNP799E,XRR7^Z?]\T^W/K]-=]UFK[Y
M_O+__/<!L\(4C<MNX>L`````245.1*Y"8((`````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]E;6]T:6-O;G,O:&%N9V]V97(N<&YG````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`W-3``,3`U,34T,S,W-S$`,#(U,C8T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````/
M````#P@#````#`AE>````,!03%1%````____SEP(_W(*QUD(62@$Z&<+UET,
MRUH,+!0#ME0._W44X&<2K4\.,18$GDH0$0@"CT826RT-_WTE(A$%&@T$!@,!
MSVXJLEXD_X<T_H8TTW`KR&HI,!P._Y9,.R,2_ZUR*!\9VET,U%H,(P\"4"T6
M_Z)E!`(!&QL;____````````````````````````````````````````````
M````````````````````````````````````````````]^6GA@```"IT4DY3
M______________________________________________________\`,JCP
M7`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"+241!5`C7
M98_9%L(P"$0Y1DD4-<:ZX1+;:B+Y_Q^TI"\N\\2%,PQ`48ET(K4"I>2=<S[)
MR!(LJFP090G];#)?KJ?/Q]"`DBRN]E<^OA9H4P'Q:':76[R?M@:]@#BD<\PY
M1R9T`MW`'',[<E?G_#%7_P94A^K7_=0P<T-UO^:C(2*#?<W_O>_O_J__WEUA
M%=OW!+@\`````$E%3D2N0F""````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC
M;VYS+VAI<'!I92YP;F<`````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S8Q`#$P
M-3$U-#,S-S<Q`#`R-#<S,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````#P````\(`P````P(
M97@```#`4$Q410```/___P$!``\+`CTI``,"`)]K`9MH`9=F`?BD`NV>`M6/
M`L^+`K=Z`G9.`:9P`HA:`GI2`B<:`?JP'U$Y"OZS(..@'9!F$H9?$5Y"#!\7
M!_V[//;*;HA8`<:"`L)^`I9A`CHF`A4.`=./#L6%#<J)#GA<*/[$5G19)_2\
M4R`7"`(!``("`O___P``````````````````````````````````````````
M`````````````````````````````(PS["T````N=%).4_______________
M_____________________________________________P""CW-5`````6)+
M1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```)!)1$%4"-=EC]L6`3$,
M1;/4K1.E1=S*5!F*2?__]_3R8.$\92=9.2<0LY@%<ZD@D]=**>VY,AN'6<YP
M9C8M-E+*!MO4@#@ZS8:#]6;?S_%\B<#P4;]D8(5R]WH\[X>M1,4@$J]L.`9+
MB469DPVA<MK7"!U9:^D&J!FB=PNX$E$'$^>K_[1<'U?_WWQ_^;_^>P/3-1<Y
M$YJ-UP````!)14Y$KD)@@@```````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]H:7!P:65G
M<FEN+G!N9P`````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`Q-@`Q,#4Q-30S,S<W,0`P
M,C4V,#4`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@````\````/"`,````,"&5X````P%!,5$4`
M``#___\!`0`/"P(]*0`#`@#XI`+MG@+5CP+1C`+/BP+-B@+)AP*W>@*W>P*V
M>@*O=@)V3@&(6@)Z4@(G&@'ZL!]1.0K^LR#CH!V09A*&7Q%>0@P?%P?]NSSV
MRFZ(6`'&@@+"?@*680(Z)@(5#@%X7"C^Q%9T62?TO%,@%P@"`0`6"@`@#``:
M"0`/!0`(`@`I"0`%`0`H`P`Z`@#_``#Z``#U```@```7```!```"`@+___\`
M``````````````"Y`='X````/'123E/_____________________________
M_________________________________________________P"[B.NG````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```)])1$%4"-=EC^L2
MP3`0A7>4=*FXI.Z41BCJ3NJR>?_WDK2,,<ZO_?:<F3T+QHG((\HG<*0$YUPH
M*IA"B4XR),<4QN@SQGR,[0),958KEWJ#<=K&^<(`P5=IAX`XLM%FM5Y.A@PY
M@6>Y&R73).I;]IQ_?L>?@?5)X.EQTYG.[CL4!$;)ZO:BM;X>`JF*^_6C3>\;
MQ?V\7[/5^O3[Z__SWPL^?1U`PQQ89`````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]H
M:7!P:65T;VYG=64N<&YG````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`Q-0`Q,#4Q-30S
M,S<W,``P,C8Q-#4`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@````\````/"`,````,"&5X````
MP%!,5$4```#___]5#!LE`PW.`%*U`$C_`F7_`V4!`0`/"P(]*0`#`@"+70'X
MI`+SH0+MG@+5CP+2C0+/BP*W>@)V3@%Q3`&(6@)Z4@(G&@'ZL!]1.0K^LR#C
MH!V09A*&7Q%>0@P7$04?%P?]NSSVRFZ(6`'&@@+"?@*680(Z)@(5#@']JQ$<
M$P(7$`-X7"C^Q%9T62?TO%,F&0,@%P@7#@,"`0`F$@D7"@<<"@=:&Q0_$!`"
M`@+___\````````````````B2EGD````/'123E/_____________________
M_________________________________________________________P"[
MB.NG`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```)Y)1$%4
M"-=EC^<.PC`,A"UV@1!#(&6/0D-8894"SON_%TD+0HC[Y>]LZ<Y@O8@"HFP"
M3UH*(:2FG"E4Z*5"\DQAC)PQQC%V!MC&JE.O#<>SI(OKC06"KY(^`0EDT\OQ
M=%A,&`J"P/$@,DL3C1P'V7X4&9.SNY?(S_MYFEYW'"6!U0K9]E:IWENH]"?_
M42H7VGE^UJ_Y+/;>_?[Z__SW`GG9'VQGEQ9?`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I
M8V]N<R]H=7)T+G!N9P``````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<V,@`Q
M,#4Q-30S,S<W,``P,C0T,S<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@````\````/"`,````,
M"&5X````P%!,5$4```#___\&`@</!!0="">3*\=^):JB,-J#)["4+L8Y$DP2
M!A@#`01^-*,@"2QQ(9H8!R&G,>-W(Z(6!QZ(++J$*[6'++>!*ZZ$+K$7"!^(
M,+:"+JYL)I$^%E-F)XA?)GRT2NJ5/<*2/+Z-.KBS2NF\8.LK%C8C$BPZ($C%
M=N\(!0HB'"8."A$;&QO___\`````````````````````````````````````
M```````````````````````````````.^NX_````+W123E/_____________
M________________________________________________`%JE./<````!
M8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````D$E$050(UV6/R1("
M(0Q$4VX8=W0$5V!4%,3P_Y\G8<J#VJ>\I#J=0&81):):`5,P6FL3J&.R"EG*
M$C/99C(>#!>CS;8T(`>%R^G5769K5"$#&13[]N'O\[-`0T`:Y<W'9_1.HB9(
MA9V/KXY3G1>.GSG[#STHVE4_[^^?G'/'5=W/^2BDE`*;FO][W]_]7_^]`9]#
M&LU`3YN-`````$E%3D2N0F""```````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O:6YD:69F
M97)E;G0N<&YG````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S-S``,3`U,34T,S,W-S$`
M,#(U-S0V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````/````#P@$````D=]=P0````)B2T=$
M``"JC2,R````"7!(67,```!(````2`!&R6L^````G$E$050HD851L0W#,`P+
MT*TO>/$/?J2;C_`49.J>Q6NV'N`'.O4[EE3E&!D*@X!!BZ(DRPN6CH"`")TC
M=DH)&<60R7N*BP^L>)Y8>?\EN+@QN*,:=O+-$R@G<ZK,RR"F"DER8"\Y%6P&
M,57(]%,NI)6NAK>AD5?&BN1XD3\7.4[=O?=][`*WT;M/7G'XY(=Y??+INR=;
MF^[\_X]]`0"2(A?5)$N7`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+VQO=F4N<&YG````````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`Q,#,W`#$P-3$U-#,S-S<Q`#`R-#0Q-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````#P```!4(`P```*Y%1(4```#`4$Q410```/___S'C,3#:
M,2*4(R&0(B[&+R2;)2&-(2RN*S*Z,3&U,"9\)DOJ2F#K8(CJB1PF'"ZZ+"ZW
M+#7",RB()R%(('?O=OT``/H``/8``/4``/0``/(``/$``.P``-T``-L``-<`
M`-,``-(``,D``+T``+P``+L``+8``+(``)\``)4``(X``(,``'H``'(``"\`
M`!L;&____P``````````````````````````````````````````````````
M`%$$')0````S=%).4___________________________________________
M________________________`'&>O8X````!8DM'1`"(!1U(````"7!(67,`
M``!(````2`!&R6L^````N4E$050HD67.VTX#,1`#4"L+0T-WPC9-EGNY%<JE
M97;\_Q_'0UJ!Z..1+=D@2;H/[B1)D/1:8HRE>K/W641$<N\DZ/U"NA!")XO>
M"=8L@*H"DBOA13H@I01T4AP>)6@:QS%ID.@8FB^:AZ/<BV"N*24]AQ0':S[#
M4E7G.,VU[<\``"=M__^_H_\DW6UGM$_;F_9R^6';VU<[^.'J_O'Y;CWM37N[
MN5Y]38<^:9O5T\1?\_M]XE_32/('F?$E`AZ#D8``````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+VUA9"YP;F<`````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#(W`#$P-3$U-#,S-S<P`#`R-#(Q
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````#P````\(`P````P(97@```!@4$Q410("`O[^
M_J,'!/Y(/M\)`K`:%=HJ([X(`^\3!Z8/#>TH'\H@&>X>%OPY+_YK9[`'`TX&
M`E8V+OY:41H:&MH;$_Y^>L(3#?XL(/P.!=(/![,2#<LG(KL?&OX=$<T)!```
M`,G3,E8````@=%).4_________________________________________\`
M7%P;[0````%B2T=$'P4-$+T````)<$A9<P```$@```!(`$;):SX```"5241!
M5`C7-8^+$H0@"$49LS2-\-&F5K;__Y=+NEV&&0[,P`6^+.AJY9/S/!XLZ`QB
MO.QYVIT>:.C]@MI[;G#,UV22KS[KPL1C.R&@3Y`VQ5O%84V-80VQ+C>TN<%A
M_:R8=.?3(`XAI/KRE*-S+DI);`KH*C'7FF54T.^KLBU:R[O=YP8=>RFWZOZ>
M=P01"?C[?Q]LU0]PI@W4X6')E@```(-T15AT8V]M;65N=`!4:&ES(&%N:6UA
M=&5D($=)1B!F:6QE('=A<R!C;VYS=')U8W1E9"!U<VEN9R!5;&5A9"!'248@
M06YI;6%T;W(L('9I<VET('5S(&%T(&AT='`Z+R]W=W<N=6QE860N8V]M('1O
M(&9I;F0@;W5T(&UO<F4N`5534U!#350]`#H8`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+VUR="YP
M;F<``````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-3$Q`#$P-3$U-#,S-S<P
M`#`R-#(U,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````#P```!4(`P```*Y%1(4```&`4$Q4
M10```/_____\``$!`/_D`/WC`/SA`/G>`//8`-B^`-:\`-.Y`,:N`,6M`+^I
M`+*<`*N8`*>1`)^+`)2!`(EW`&]A`&E<`&)5`$0[``@'`&Y?`&A:`%E-`$`W
M`#PT`#0M`!01`!@4`!L6`!H5`!L5`!@3`",;``\-"$(N`0\+`B49`*]T`?BD
M`NV>`N"4`M6/`KI]`K=Z`K=[`K9Z`K5Y`JYT`FI&`:9O`HA:`GI2`GE1`EP^
M`K%X!;-Z!_ZS(/V[/`4$`@8%`XY<`8E:`857`>>8`L:"`L)^`JIN`H)6`CHF
M`B\?`OVK$5@Z!MB6&AT5!AD3"/[$5@T(`'Y.`9-7`8)/`5XZ!0L(!&,["0(!
M`$\G!388`)@K``P#`!86%@@("`("`O___P``````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````+QBN2D```!B=%).4___________
M____________________________________________________________
M__________________________________________________________\`
M$%:2J@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#T241!
M5!C319#G4L0P#(1W0B]'-7!4`Z$%$LQ1$TI,/8,Y2N@E@/S^+X'CS,WM#ZV^
M&6EV)!@G^/#+QE6_8+_%"UB>!YI,>FUQZ?/F]K1D.KK>7IG<W3H_I((IN5S_
M>=F\`BX2,H!6SQMW7_<?;_O?KP`(B``II7,J.`2R+'-."&H(4YF=93(-40M`
MCM_;'AW;^5A$C=3NIXU(Q`2CE;"+5J%0VN77Q6^>YZNB7N3S7DK4R</3W[%*
MJ)N#C_:1CG<.]F)-G8,<9F)@>(8H(.*\?[:XIUKI&>=6'96I\MZY(<8\QD:J
MS7^P,<_K8M.M_QC6SLOF'\J91_S_\?+8`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS
M+W!U;FLN<&YG````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#$Q`#$P-3$U
M-#,S-S<P`#`R-#0Q-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````#P````\(`P````P(97@`
M``#`4$Q410```/___P@"!0,!`@P#"!@%$.,QF=HPDDT1-)0B9)`A8<8NAILD
M:8TA7R\+(#(,(AD&$5P<07PF6$L7->M@L74P6%`A/.J(P"8(&M\PET$.++HL
M@;<L?ZXK>'`=3\(SB+HQ@K4P?VT=38@G878B5'(A4>I*J-5#F3D2*2D-'D@@
M.#\?,N]VONASN=UML-QMKT4B-R8<(@4"!`$``1L;&Q45%1`0$/___P``````
M`````````````````````````)";=+\````X=%).4___________________
M______________________________________________________\`.UP1
MR@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```">241!5`C7
M98_)#L(P#$0MEA0P:PEK8J`$`H2RM#7T__^,I(@#ZIS\--)X!LH@YHRYNB"0
M,T1D''^98XU!.N;`KXG"2`@1H9J^/>>-86=CK=VO1T5>`A_&\%/KR,"$2RBN
M]V>S:",Q9(2KR^RV>,S/`BD+OCC)-$VE%<%G@Y!8*:7=`1J&TND^;'U^`CWM
M_#^.U:!*[RI?J-ZOUO]OWP>R"1U"S&HD^@````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO
M=&EC;VYS+W!U;FMM;VAA=VLN<&YG````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-#<W
M`#$P-3$U-#,S-S<P`#`R-38T-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````#P```!4(`P``
M`*Y%1(4```&`4$Q410```/___X1$70@"!0,!`@4#!!$/$*\Y>!<%#PP#"!@%
M$.,QF88=6N(RF-HPDDT1-`D"!C4,),8NADX2-2\+("((%S(,(AD&$4P3-",)
M&%P<07PF6'8D5'4D4U\=0TL7-7<E570O5^M@L<Y4FW4P6%`A/.J(P"8(&M\P
MET$.++HL@;<L?YTF;:XK>$41,'`=3^@]HVT=38@G878B5'(A47TG6NI*J.=)
MIM5#F3D2*2D-'AP+%<10E$@@."\6)3\?,N]VONASN=UML-QMKT4B-R8<(A$$
M#`4"!`$``08%!@#3#@"H"P"H#`"F"P"E#`"@"P"="P";"P":"P"9"P"8"P"7
M"P"6"@"4"Q8P&!HB&D>#.#@Z+@(!`9%F9A@7%^?DY-+/SYZ>GAL;&Q45%1`0
M$`@("/___P``````````````````````````````````````````````````
M`````````````````````````````````````````````````.=SP<,```!G
M=%).4_______________________________________________________
M____________________________________________________________
M_____________________P`4%KIX`````6)+1T0`B`4=2`````EP2%ES````
M2````$@`1LEK/@```.5)1$%4*%-5SE<WQ&`4A>$31@V#HQN]F_B4#U%#E)@X
MNHS>#_;__PDN(FO%OGG7<[<)Z>0N+:4YDVO)^U2N\I9+2>0FYW-))/GGJE1S
MOI"'Q_O,&LAMC;'/FEI+GCPU,'LE!0A?`V5^;77=(I='OD&HU':U+?J^OSS7
M$U=`NM)+V9I6E=3P#,5[!T>%N)F-4F1X=FMR?_IP:M-E$Y$:=C?&PS"<6.OH
M-$IJN;BTOC.V_5+O]%DE!!ZW])^\T3M][`8@Z%!WX>?3(8>.!Q4$Z/!\8QU1
M^\*H9O^M,<8&?_\!J$:J`(!?CVI4ZZ)DOT@`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O96UO=&EC;VYS+W!U;FMT;VYG=64N<&YG````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`Q,S0S`#$P-3$U-#,S-S<P`#`R-38U,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````#P``
M``\(`P````P(97@```&`4$Q410```/___\X`4K4`2/\!9R0!#U0$)CX%'U<(
M+1L$#Q8%#0@"!0,!`B0'%A4&#@P#"!@%$.,QF=\PEMHPDDT1-,0MA&D81\8N
MAH$>5R\+(#(,(AD&$2,)&%P<07PF6$L7-14'#^M@L74P6%`A/!4)$.J(P"8(
M&M\PET$.++HL@;<L?ZXK>'`=3^@]HVT=38@G878B5'(A4>I*J-5#F3D2*2D-
M'D@@.#\?,N]VONASN=UML-QMKT4B-R8<(AD'$@4"!`$``1L;&Q45%1`0$/__
M_P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(;$
M=D8```!%=%).4_______________________________________________
M____________________________________________`++NL3@````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````JTE$050(UV6/R1;!0!!%
MZQ!3C*U1QA!ST@A!Q!!)D?__)MW$PO%6=<];O%L0JQ`%1.\+%'F.$,+QZ,-D
MV*AB&Z3X,;"0,\8X6L.GY+#8::Q<U]TLNU$8`VU[\$UU1T`"YQ"=+K=25$-!
M$`A<',?GV75R8"@"U;.]Z?N^Z3+5DX.\/YKJ>N7.T2&(/1O9NJQIA3K:GMPC
M0^[G4^ELTY)"B5\[EVDE?G_^/_^]`$3\)J^Z7/5V`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O96UO=&EC;VYS+W)A<W!B97)R>2YP;F<`````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P-S<S`#$P-3$U-#,S-S<P`#`R-30W,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````#P````\(`P````P(97@```#`4$Q410```/___\X`4K4`2/\!9R0!#U0$
M)CX%'U<(+1L$#Q8%#0(``20'%A4&#@\#"I8@9>,QF=\PEHX?7]HPDL$K@<0M
MA&D81\8NAH$>5Z(F;I4C92D*'",)&'PF6'XH6A4'#^M@L14)$.J(P"`'%KHL
M@;<L?ZXK>.@]HX@G8>I*J)DP;N9>KD@@..]VOB8<(@L#"!D'$@\$"QL;&___
M_P```````````````````````````````````````````````*4.'/P````T
M=%).4_______________________________________________________
M_____________P!+5R)E`````6)+1T0`B`4=2`````EP2%ES````2````$@`
M1LEK/@```)1)1$%4"-=EC]D6@C`,1.<H;KBA5>.&%J6U:*D:_O_?M*TO'O*4
MFYS)3-#X8G;,H8,G:[36QG)DSM5A3[NKRMDSYR6MQO/9DLKO`(U5!-R?IS=(
MV09L2`#R(0%!AL&:LDK6=2VKC#3#1;Y$=JV]UQ_/19I.7T'O[V>W29*,%N%^
M\!?#3K>_COX^'VT'O<TO7RO_WW\?!-<?PWTS@O(`````245.1*Y"8((`````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M
M;W1I8V]N<R]S860N<&YG````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<U
M-0`Q,#4Q-30S,S<W,``P,C0R,C8`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@````\````/"`,`
M```,"&5X````P%!,5$4```#___\#!@LG8K8F7JXE6ZHP==H7-V4.(3TN;,8)
M%"4"!`<F27R(K^H<("8F8+$'$B$Q>^,"!0DL:;HA3HL@3(<L9[<@2X4&#ADA
M38@K8JXN9K$]AN@P:;8N9*XF5)$G4(A*C>I@FNL@,4AVJN\$"Q0;&QO___\`
M````````````````````````````````````````````````````````````
M``````````````````````````````````#\]0M!````*'123E/_________
M__________________________________________\`OJHN&`````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"2241!5`C798_)$L(P#$,U
M+`%#*81"@+!E0_W_/\1)3PPZ^=ECR<981?9DJU`I!^]]R)R8W6TE(NM+Q\KL
M3L>EM78Q.VL#8W;7_2/&^)AO7![!(`9(*0%&`D$O%BBE`%8\T2O'5'8E1>6^
MS97+Q&S[SRU4][:O_O)YJ__K(-5?\P<QFF]D:/G:<%+EIOO^[O_Y[PNIZ1;,
MXG5O9P````!)14Y$KD)@@@`````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O<VAO
M=70N<&YG````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`W-S<`,3`U,34T,S,W
M-S``,#(T-C(U`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````/````#P@#````#`AE>````,!0
M3%1%````_____W(*Z&<+RE@+N%`*UET,KDT*RUH,ITH*_W44/QT%)A$#GDH0
MCT82%@L#UVD?TV<?&@T$_X<T^H0S\8`QVW0M_Y9,_ZUR*!\9VET,4"T6_Z)E
M%08!%P<"#@,`&@8!&P@$#P,!"`(!"`$`*`(`*`,!_P``^@``]0``.@$`(```
M%P``.@(!&QL;____````````````````````````````````````````````
M````````````````````Q;C:Z0```#!T4DY3________________________
M______________________________________\`8J70>`````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```"<241!5`C758_I$H(P#(1W&JVE
M6CP0$8KW4;S"^[^=39EQQOS*EYU--NBEF&OFU$'(.V.,\SPPYYJD=,["G#>D
MK+6*FCA`[S5-5^NBG,](^Q[L2"V!"E@H<@PV9`N@!0I+AE$+5^VVK83KI)<7
M`*=-TL6_OX<0/N?DE_WO1^A"]TK[Y?[N%O7G8;@?!Z-K]!_'0[Z4?Y)EO_Q_
M_WT!0"H6\^LDR8H`````245.1*Y"8((`+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+W-M:6QE+G!N9P``````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-34S`#$P-3$U-#,S-S<P`#`R-#4V-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````#P````\(`P````P(97@```!@4$Q410```/____KZ
M`.[N`-;6`,C(`,3$`+BX`*>G`)^?`)N;`)B8`(J*`'Q\`#P\`!`0``0$`-75
M#<S,#,?'#/__'___.?__50L+!!(2!____P```````````````````````++>
M=HD````:=%).4_________________________________\`%"(`V@````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```!^241!5`C798_;$@(A
M#$,ST`4O7*);4/[_1Z4R^^":IYYVDK88)K*2WPI&)<484^%BYB"FD&G,O(EW
MSGG99@.C!`%4%9!0!IC$`ZTUP$LB&,5IZZ_>U$DDZN+WXGK,^S&??NPZ_?J$
M^6?^!8^9O^-F^;;_#M-U[3_?]W?_SW\?L)@,1^D,.:$`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V5M;W1I8V]N<R]T:7)E9"YP;F<`````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#,V-``Q,#4Q-30S,S<W,0`P,C0U-C,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@````\````/"`0```"1WUW!`````F)+1T0``*J-(S(````)<$A9<P```$@`
M``!(`$;):SX```"8241!5"B1A9$Q#H0@$$5--FZQ5Z#A#EQD.PY!9:SL;6SM
M/``7L/)V?__,@H3"3'YB/KSYC`P#ABH'!P_YMKT;!40D5:2O)05^,6&Y-7']
M+RAPYN:*3;72SZ6`.&ARPXY#M=/+"4&P8R])2I<1&6]U<D)DGCAI]B`Z59E>
M\DFP[_#586^F:^]/FP5>K;?QY^:]C:F9,W]^L1]ARB,.W5/JV@````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E
M;6]T:6-O;G,O=&]N9W5E;W5T+G!N9P``````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`W
M-#,`,3`U,34T,S,W-S$`,#(U-3`V`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````/````#P@#
M````#`AE>````,!03%1%````____1Q`>(00.S@!2M0!(_0-F_`1F,>,Q,-\P
M,-HQ+<0N&&D9+L8O'H$?+*XK"2,)!QD')GPF2^I*!Q4'8.M@"14)B.J)'"8<
M+KHL+K<L/^@]*(@G(4@@=^]V"1('%!<-#PT)$0X)#PP).24<+185&QL;____
M````````````````````````````````````````````````````````````
M````````````````````````````````````-?/`H````"AT4DY3________
M____________________________________________`+ZJ+A@````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````B$E$050(UV6/R1("(0Q$
MNUPC&E$091!PW,+__Z$"7JS)*2^I[G10:HEXD=:A4HI:ZYBDLYC`M8*1RF(&
M5D2D>/@.4%)@P%H+<$@%$ED!SCE`<12(9K(NY^PLL1;XSI?.?K*O^L/I?'_>
MCDU?_>DZKM:/3?/O]U^+Y6S;[[=\^_=\]\LWR?_WWP<CHA7F9Y1_'0````!)
M14Y$KD)@@@``````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+W9A
M;7!I<F4N<&YG````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-S4Q`#$P-3$U-#,S
M-S<P`#`R-3$Q-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````#P````\(`P````P(97@```#`
M4$Q410```/___P@,$3UWMSIQK3EOJCAMIS9IHBQ5A"Q5@QHS3CIQK#EOJ2Y8
MB"E/>@X;*4B"PC==B5"(Q10B,0P4'4!HDTQWIDYYJ6B8S6:5R6*0PEV)N"Y#
M6QHF,WBCTHRQV9:WW,/5Z1$A,@D/%`,#`P("`O___P``````````````````
M````````````````````````````````````````````````````````````
M`````````````````````-97/=L````G=%).4_______________________
M____________________________`(-6E]D````!8DM'1`"(!1U(````"7!(
M67,```!(````2`!&R6L^````CTE$050(UV6/R1("(0Q$&S.(H$X0-]S`0>7_
M/U$BY<&R3WE))=U!%3$7YD\%(6>-,=9Q9QXUB?3(PCP.Y$,(GH;60'6:MH]3
M/,]VI%T%6_('(`%'3Y;!AD($,A`#&4813OF>DW#I\Y1S9Y9]?"7[[?[ZJ6Z7
MJWHMY'[S7VY4&ZI]]V^-^=3B3:N>[R__SW]O<^P/]DD,>$@`````245.1*Y"
M8((``````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]W:6YK+G!N9P``````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<S-@`Q,#4Q-30S,S<W,``P,C0T,C8`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@````\````/"`,````,"&5X````P%!,5$4```#___\.
M$0H&"`-DB!VGXS&@VC!]JR9ME")JD"&2QBYRFR1HC2%??":\ZV!LAS>[ZF"-
MNBR*MBN*MRR#KBL/%`64PC..NC&*M3!6<1YIB">UZDJDU$,[2"#([W8/$P8C
M)AP)"@4;&QO___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````"567-"````)'123E/_____________________________________
M_________P!8+`T-`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK
M/@```(=)1$%4"-=EC\$2PB`,1'=44*.@%:J52,7P__\HD>E!W5->,IM-4%4B
M1>1302FG&&/*TEE<(%5PHBSN0M888VEH#=0<QLW]^6"`0JZ01-MQ?3I[P%(2
M2"3#?G[-G@U%0>F\ZER6^;S,FQ\3>^_Y!O6W_0=<F7G"7O>W_.$(U:[G_][W
M=__7?V]*KA/0!""J,`````!)14Y$KD)@@@``````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]E;6]T:6-O;G,O=VEN:V=R:6XN<&YG````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`W-S4`,3`U,34T,S,W-S$`,#(U,S$R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````/````#P@#````#`AE>````,!03%1%````____!@@#9(@=I^,QH-HP
M?:LFC;\LBKLKDL8NC\(M?:DG>*,F?:HH7WPFO.M@;(<WN^I@R.J(C;HLBK8K
MBK<L@ZXK#Q0%5G$>:8@GM>I*I-1#.T@@R.]V#Q,&(R8<$0T#&A$$!`(`%@P#
M#`8!!P,!)0P#)P4!.0,!_P``^@``]0``(```%P```0``&QL;____````````
M````````````````````````````````````````````````````3,3"6```
M`#%T4DY3____________________________________________________
M____________`!^:3B$````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````F4E$050(UV6/V1*",`Q%,]J*40056VPM%G>+2_C_K[.AXX/C?<K)
M>@,]B\@3#1$P.:.U-HX24Z&0I0IBIF*#4@@AL8H)Z)VJQ]O]S@*@<CV0P4D]
M6JY*`(F&@#0*6S9-4UJ!FL`G7B?V7#]"TCN+]3A_?3U"%[KG@>?C_EE["R'<
MSQGOC_>KZ25VGQ;I_N!OGN=??W_^?_[[`'@Y&0Y[\+%V`````$E%3D2N0F""
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M96UO=&EC;VYS+W=I;FMT;VYG=64N<&YG````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M-S<P`#$P-3$U-#,S-S<P`#`R-38T-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````#P````\(
M`P````P(97@```#`4$Q410```/___T\0'B,$#LX`4K4`2/X#9OX$9@8(`V2(
M':?C,:3?,*#:,'VK)I#$+4UI&)+&+E^!'AHC"5]\)A`5![SK8&R'-[OJ8,CJ
MB(VZ+(JV*XJW+(.N*P\4!;'H/59Q'A,9!VF()[7J2J340Q$5"3M((,CO=@\3
M!B,F'!$2!QX7#10-"1@."10,"4TE'#@6%1L;&____P``````````````````
M`````````````````````````````````````#E%(CP````R=%).4_______
M__________________________________________________________\`
M#5"8[P````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"3241!
M5`C798_)$@(A#$13[B)J%%%'&!U01MS#__^<+%ZLR2DOJ>YT(*0B\D2Y@T3.
M:*V-H\(D%*92@A*3."!GC'&LX@""4_7T=#U;`%0N`!F<UY/M3@)P-`2DD5G9
MMJVT##6!+[PO[#O[J.?KS>7QNC59'_V1'>^C\7.6_>/]"OE[,.PMROV<;_7I
M+W_Y.OG__OL")?\<.0S'A/L`````245.1*Y"8((``````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]W
M:6YK=&]N9W5E;W5T+G!N9P``````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<W,``Q,#4Q-30S
M,S<W,``P,C8S-S8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@````\````/"`,````,"&5X````
MP%!,5$4```#____.`%*U`$C]`V?\`V<A!!!(#R@N%"(0"PX\(S,2#1$/#`\5
M%AD]S+4PH(X&$Q$+(!T*$1"/XM4_U;L^T;<F@'`ZNJ0YN*(F>6L?8E<WK)<U
MI)!*VL`D:ETN@'$L=6E6W<5.R+('$A`(%!)KX,QKW\L^@78C13]_Y=(WKY@V
MK)4(&!4#"`<*%!(=)2,;&QO___\`````````````````````````````````
M``````````````````````"W'^)@````,G123E/_____________________
M____________________________________________``U0F.\````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````DTE$050(UV6/R1("(0Q$
M4^XKCHI&!05&41@7,O__<[)XL2:GO*2ZTX$V%5$@RATD<DI*J1P5)BTPE="4
MF/03&>><81,'T#I1[2_7V@"@<"V0PE7U?MPM`$-%0!*YL=Y[:SA*@E!X6SAT
M]E'/UK?/8KIY97WT1WY>#H;S7?:/]QMDLUY_?"CW<[[C9'3ZY>OD__OO"T.:
M'BN;U768`````$E%3D2N0F""```````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O=V]R<FEE9"YP;F<`
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`W-#0`,3`U,34T,S,W-S$`,#(U,3,Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````/````#P@#````#`AE>````,!03%1%````____
M!PP2/7>W.G&M.6^J-FFB+%6#'SQ=&C-.*4]Z'SQ<#ALI2(+"4(C%,%)W#!0=
M2'&>16R71FZ9:)C-9)/&4'6>>*/27G^DC+'9EK?<`0(#$2$R.5I]"0X3"@\4
M`P4&____````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````$KZPRP```")T4DY3____________________________________
M________``W0PW$````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^
M````CTE$050(UV6/VQ*#(`Q$,TT!P87>HDBU6O__)TNP+YWN2W)F)\F&=A6P
M`*TC)>^LM<[C8`33=]SU)D`9X1SHDBY4*RI[PS.-,M+,QN\$QW'=ICQM:V0'
M@N4TY%)*'A);T%)9<GF6+)67YDOSI?DZ?WM3U:/-Z_[32T3NU[9?[W-,*44^
M[FL^5GWS_>7_^>\#Z?`.DR`S=HX`````245.1*Y"8((`````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9F%V:6-O;BYI8V\`````````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,3<V`#$P-3$U-#,S-S<S`#`R,S`W-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````$``0`0$````0`@
M`&@$```6````*````!`````@`````0`@````````````(RX``",N````````
M`````````/\```#_````_P```/\```#_````_P```/\```#_````_P```/\`
M``#_````_P```/\```#_````_P```/\```#_V-C8_]C8V/_8V-C_V-C8_]C8
MV/^AH:'_#GQ@_Q;7IO\5SZ#_&$U`_]C8V/_8V-C_V-C8_]C8V/\```#_````
M_]C8V/_8V-C_V-C8_]C8V/_8V-C_WM[>_Q%61?\6TZ/_%M.C_PU_8O])4E#_
ML;&Q_]C8V/_8V-C_````_P```/_8V-C_V-C8_]C8V/_8V-C_V-C8_]W=W?\1
M5T;_%M.C_Q7+G?\5SJ#_$K*)_PMI4?\Z3TK_FIN:_P```/\```#_V-C8_]C8
MV/_8V-C_V-C8_]C8V/^=G9W_#7YA_Q;5I/\5RYW_%M&B_Q;8I_\7X*W_%<>:
M_QP[,_\```#_````_]C8V/_8V-C_V-C8_]C8V/_<W-S_)T4^_Q3"EO\5SI__
M%<>:_Q&D?_\0F7;_#Y%P_PV"9?]'5%#_````_P```/^5E97_T]/3_]/3T_^7
MEY?_)D@__Q*MA?\6T:'_%M:E_PUW7/]:75W_@X.#_Y"0D/^=G9W_S\_/_P``
M`/\```#_#H-E_Q!=2?\07$C_#H%D_Q3"EO\6T:'_%="@_Q&E?_]&44[_V-C8
M_]C8V/_8V-C_V-C8_]C8V/\```#_````_Q;4I/\6U*3_%M2D_Q;6I?\6T*'_
M%<N=_Q;3H_\/CFW_?GY^_]C8V/_8V-C_V-C8_]C8V/_8V-C_````_P```/\5
MRYW_%<N=_Q;3H_\5SI__%,"4_Q;.G_\5SZ#_%<69_RI&/__8V-C_V-C8_]C8
MV/_8V-C_V-C8_P```/\```#_%M&B_Q7.G_\->5W_'%%$_S=)1/\+:%#_%M&B
M_Q;:J/\,<UG_K:VM_]C8V/_8V-C_V-C8_]C8V/\```#_````_Q?8I_\2L(C_
M2DY,_]C8V/_8V-C_C(R,_PM81?\6TZ/_$[>._TE/3O_8V-C_V-C8_]C8V/_8
MV-C_````_P```/\7X*W_"V1._[FYN?_8V-C_V-C8_]C8V/^AH:'_#DD[_Q9.
M0/^8F9C_V-C8_]C8V/_8V-C_V-C8_P```/\```#_%<27_SI,1__8V-C_V-C8
M_]C8V/_8V-C_V-C8_[Z^OO_1T='_V-C8_]C8V/_8V-C_V-C8_]C8V/\```#_
M````_R4_.?^@H*#_V-C8_]C8V/_8V-C_V-C8_]C8V/_8V-C_V-C8_]C8V/_8
MV-C_V-C8_]C8V/_8V-C_````_P```/\```#_````_P```/\```#_````_P``
M`/\```#_````_P```/\```#_````_P```/\```#_````_P```/\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R\`````
M````````````````````````````````````````````````````````````
M````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T
M,S,W-C0`,#(R,#0Q`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+V%F+G!N9P``````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C`T-P`Q,#4Q-30S,S<V-``P,C,Q-#``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!(````,"`,```!8S!V.```#`%!,5$4```#____5U-7'QL<B(R-45574U=6X
MN;D`6P``.0``.``%8`40:A`12Q$==!T22!(A>2$951DOA"\UBC4XB3DXA#A"
ME$(R;S)&F48R;#)!BD$Z>CM)ETE0GU!/G4]0FU!7HU=3F5-2EU)7GE=;HUM>
MHUYEIF5JK6IAGF%MK6T?(!^?HY_S^//H[>C6V];2U]+T^/3H[.C,T,SV^?99
M6EG0T=`0:`T;;!@[?S<07@4?9A`T<1\O:QF]PKHY:A9'<QE-;!)#7@-(8`E#
M5P`Z.CGGY^;$Q,/DX]*^MI(A(!VOG7*VJ(5];4M:0Q5\937"HF&)=U*YI'L[
M.34R,2^^O+@P)A1-/2%E42R3>$:LC%*3>U"WG&RVG6^WH7C4NX[ERYN\IX+'
MLHSNV;%G7DZ^KI'DU\#EVL7`G%^[FF:ZH'9Y:E'9OY3JTJO@R:3*N)K+OJM.
M24(;%A#BVM!,249245#X]_?^_O[Z^OKY^?GV]O;T]/3JZNKEY>7DY.3BXN+A
MX>'2TM+.SL[-S<W*RLK#P\-/3T](2$A"0D(\/#PX.#@V-C8T-#0P,#`O+R\N
M+BXJ*BHH*"@A(2$='1T;&QL8&!@/#P\-#0T,#`P)"0D%!04#`P/___\`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````"'E#XU`````6)+1T0`B`4=2```
M``EP2%ES````2````$@`1LEK/@```,!)1$%4"-=C8,`".#D%I=651<TM.;AY
M!(0E9(%"7+SB:JI2UD[.CF9\0F)R\D`A?DD-324+.RL;!WL1&0451:"0MI&Q
MH;ZWEVV@A[^[@8ZN'E"(F;&ROB$S(3^O*#>GK+*F`2A46N[*UA03G9B>&I]4
M4<W4#!2JJFML"4F)C,V(RTZK-75C!PJ9N$R:.CW4-]PG((NUK:.K%RC4.64F
MP\S",+^(J.2"[KX)$X%"6C,89DWS#&YO+2D.ZNEGF8S-.P"1LC`[PE*8EP``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O86PN<&YG````
M`````````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0U`#$P-3$U-#,S-S8Q
M`#`R,S$T,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q4
M10```/___]4U-L<Z._]G:`<!`,P``,@``)\``'\``'8``%P``!@``+$!`:P!
M`<X#`\P#`U0!`4T!`8H#`]`%!<X%!<P%!;L%!6$#`\T)"8L'!ZL*"M8-#<T-
M#9`)";H-#=@0$(L*"D0%!;L0$,\2$H\-#5T)"68*"M(8&,\8&)01$>$='9`4
M%.0A(=0@']<A(=$@()T9&;0=':<;&Y(8&-@G)[`A(>XO+[(C(Z<A(;DF)MTP
M+[PH*'$8&/(U-;\J*L0M+<$L++LK*\<N+AX'!\HP,+(J*LTR,>$X.-4V-=(T
M-,\S,_<^/MTX.'D?'T82$OI"0MHZ.KLR,E@8&.=!0.`_/OQ&1NI"0N5"0OY*
M2N1"0H,F)NI&1L4[._]-3>Y)2>Q(2/]/3_Y/3ZHU-9@O+_Y04/),3/U14?Q0
M4/9.3NY,3.E*2OM14?E04*TX./%04-1&1K`Z.M)&1NY14>M04+Q!0=U-3?97
M5X(O+^Q75Z@^/OI>7NE96:E"0OUD9,=/3X8U-6(G)_ID9/AE9?]J:OAJ:NUE
M9:A(2+=1450F)AL-#7<Z.K1>7E`K*SHA(2X='1@4%!`0$`4%!0,#`____P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(0+</(````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MODE$050(UV-@P`(X.0UC6ROS-,4Y1!1T[<)204):06T]I7YJW,+R1N8!B;E`
M(46WFJ;V1E4A075;)Y^XG'B@D&4!2TF%_V16EPG1A9'I::%`(>:6<E\3)9Y)
M$_L:BE(S([R`0LW5(09R7!)=_2FU];DQ3*Y`H;H$4UD^7NG@WJJRXOA`=T>@
M4+ZUB@"[E$YG=W9'5JBW@Q50R$-#C$U463^Y(",SRLO9Q@PHI"?)QB^C;1Z>
ME!OCZ6IO88S-.P#?\RZ$Q<1]K`````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]A;2YP;F<`````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(P,3(`,3`U,34T,S,W-C$`,#(S,3,T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```2````#`@#````6,P=C@```P!03%1%````____P0$-P`$-R`H6PPT8A`H2
MTA@DSB<RWRLVJBHR[3Y)]4U7Y$E3XDA2\5%;X%EA]&1M#0'`#P/`$P?%'1+$
M(!3/,2;<*2&?.B_213KJ2#_654KT5DSH6U'S3D;,6E#H<&?V#0G!#0F_%A+'
M&!3")"#1,B[--C/?-#*X.SC#247L0T#05U3T4U#D4D_B6UCQ;6KS``#,`P/.
M!070!07,"0G-#0W6$!#8&!C2'1WA(2'D'R#5+R_N-37R,##*.#CA-C75-#32
M0D+Z1D;\04'F0D+E.SK'1D;J3T__4%#^3D[V4%#Y5U?V7E[Z9F7W:FK_S'@#
MS'8'T'P(SG@)S'L)S7H/V(83UH$3P'02TH8;X8XCY)0DSX0CU(@EL'4CLG8G
M[IXUO'\J\J0XW),TQX@PX9P[TI$WRHDUL'DQTI$\_+%)Y:)$NX(XQHL__K93
M]K%0UIE*\Z]7\[)>Z*M<P',0Q7@6Q'P@IVL?OW\NU9$Z^JQ(ZJ)(ZJ1+_[15
M^;%5Z*E8S```?P``S@,#T`4%S`4%S0D)U@T-V!`0TA@8E!$1X1T=Y"$AU!\?
MG1D9[B\O\C4UX3@X^D)"NS(R_$9&YT%!QCL[_T]/_E!0^5!0]E=7^EY>]V5E
M_VIJ____````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````NV9DJ@````%B2T=$`(@%'4@`
M```)<$A9<P```$@```!(`$;):SX```"C241!5!C3;8P[#L)`#$3]VTV02(,H
M0.(.'(++<`XN24<1":4`@?@($F)[V:WA5?;3S`#\@+"#:5W9NU=E*6P)H`[1
M1S4E9B;&G(H2T3[FB9@(V1\"LXK24&63?Z)4U'IBCT&-A#E&'/5(4'NO9B41
M`MEH(-!Z[Z66I]CSE=7FU;0K[*K%"YN;)=T+W)\G/4A(5\'SZ%:*>8F%PX+1
M[3+OEO"'+TU+3MB/$M.*`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V%N+G!N9P``
M```````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-@`Q,#4Q-30S,S<V
M,0`P,C,Q-#0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,
M5$4```#____%P\;"P</AY.FOM+F+R^BPP\Q\A8D`?K(%@K,,?:P=C;PAF,PM
MF,4KDKPLD;HNC;8SG<<MB;$XH<LVF<!!I]-&K-1!G,%0O>A0N^=0N.)2N^5>
MO^5@P>=HQ>I;H\*JP,FJO\C6Y^X"@;(1C\`2B+86BK<@G,L?D+PJH<\FC[<L
MF,(QE[XG=Y8QD[DPD;8OBZ\]L=TWG\<TE[TVE;E!J=$^H,9"J,\[DK1&ILM.
MM]]2O^A-L=A.LME2MMQ3M]U8P.=7N^!7N=],HL-7N-UFP>1JQ^MNR>QRR^QQ
MR>N_TMF@L+:KN\&UQLS6Z._%UMS3X^G8YNOI]_SA\/7:Y^OG]/C7X^?J]OJA
MK*_&Q\>RL[/4U=35U=38QL#GU]+VY>'=1"3-023C53CY;U/O<%?@S<G#'`#`
M(P7&)PC%)`G`)PG'-!BT.B;O7D+V7T;76$#T:4_6P;WIV=;UY>*J*16H*!7K
M3C6Q.RBO1CF_4$/.8E;6=FO/N;?^_O[\_/SZ^OKY^?GW]_?R\O+N[N[EY>7D
MY.3AX>'8V-C6UM;2TM+0T-#.SL[-S<W,S,S*RLK'Q\>_O[^\O+R[N[NPL+"G
MIZ>=G9V4E)1_?W____\`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````".ZEOA`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@``
M`+])1$%4"-=C8,`"9LR8%L584I"3D5W;T=9<7P<2FCZYJ2$^*2L]LZB]I8&Q
M$2C$$1D>$<1<45::RQ08$AP6"A32<_%P%5+G%A;DT3*R<72P`@I9NCN)2`AP
MZAKS.GM)65N8`(7<9,TT];7Y537LY3REQ44-@$+RMCIJ*EP*?&)LDC)VYJ:&
M0"%E;W8E1=;*JNH:%O\`/U\?H%![5U]?=UQB>7Y*0FO7A$E3@$(QO7T]G6G)
M>86IQ;']$Z.G8O,.`.B[,4OM]:VO`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O86\N<&YG````````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,#0V`#$P-3$U-#,S-S8Q`#`R,S$T-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$@````P(`P```%C,'8X```,`4$Q410```/___[XZ._]G:#\U-B(C(RLL
M+!\@'P<+`1,6"B(E`59736AL*VAL&(*%/FQM)I662A(2`']_!UA8%(J*.I*1
M0C0T(4E)-5960F1D3A04$#HZ-5=744M+1E-34#(R,3`P+S\_/HF$`WYW+\VO
M`%Q,#10/`-2="LR)`.^E->B')MMP%,U5`<Q&`=Q@(<Q$`\U'"<HD`,,>!<XA
M#4I!0,X0`]XD&+L*!=$0!\P``'\``-`%!<P'!=8-#=@0$(L*"LP0$,\2$M(:
M&)01$<<8&.$='>0A(=0?'YT9&>LK*]@G)^XO+Z<A(=TO+_(U-?4Z.K(J*N$X
M./@^/M<X.,DT-/I"0KLR,N`_/OQ&1N=!0?Y*2O)&1L8[._]-3=M"0NY)2>Q(
M2/]/3_Y04/),3/U14?M14?E04/104/%04.Q.3M1&1O975^Q75_I>7NE96?UD
M9/=E9?]J:O9J:A0)"2H@(#DP,$]&1EI04%E/3R`='6=>7FYE961D9%%145!0
M4$]/3TQ,3$E)24A(2$9&1D)"0CHZ.C@X.#0T-#,S,S`P,"\O+RXN+BTM+2HJ
M*B@H*"<G)R8F)B$A(1T='1L;&Q@8&!(2$@T-#0D)"04%!0,#`____P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"94F[<````!8DM'1`"(!1U(
M````"7!(67,```!(````2`!&R6L^````OTE$050(UV-@P`*LK#QB"K,#G6PL
MK>W<_"*20$+.806YD>X&&J:VKMZAB6E`(?N`O/P$+V-='74SSZ#8U'B@D$\6
M<X:OH[Z*A;:6?U1*<CA0B*DH)]C%R-#<04\S.CTS+@0H5%UE4E*LIJ1:J2Q:
M45[&4@H4JFGJG\;!Q<G+P\==V]@JSP84JE.8.E-02)A?1$"F0;&C9P)0J&W*
M#(894F+BLG*2$NW=?1.!0NS3&69.F]354E_7+-W9RSH9FW<`^HXPOJO6VRX`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]A<BYP;F<`
M````````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`U,34T,S,W
M-C$`,#(S,30S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!0
M3%1%````____U=35Q\;'_O[_[>WNZ^OLU]?8S<W.R\O,^_S]]O?XV-G:P,'"
MI*:G_/[_^_W^^OS][_'R[O#Q(J+,%65_(Z/,):3.)J;0)J3,**3,&69_*J7-
M*Z;.+*C0+ZW6+:7,,;#8+Z;--*[6-['8-ZS2)WF4/KGA0;SD/J_4/:[20[KA
M1[[D0['4.)*P,X.=-XNG4,?N0)Z\5,SR/Y>S5<GN2*C'6LSR5+_A1Z&_4+34
M3[+23JW,8=7Z3ZW,3ZS*9-?\6<#A2J"[-W>+5;;45++17<7G7<3E9M;Z:MG\
M7;_>;=O_;=O^:=3V5JO';-;Y9LKJ6K+/8+[;<MS_<MS^<=?Y;LWK9;S8>-KZ
M=M;V;\OH69VR?MKW7J.Y?]OX<<+<9ZW$A^'_@]KU;[?/B^/_@=+L@]3N?,??
MCN/^C>'[DN/]B]GRC=GQB]+IF>7]\?3UY.?H3+'-3+#,4;'.V=S<T=34S,_/
MW=_?^OO[U-75S,W-V-O:N+NOP\6\K*Z3V]W"Q\BWM+5OIZ45@'\>I:0MGYY2
MS,S*Y^?FS,S+A8,'H)Y6X^'9Z>CE^/?W_O[^_/S\^OKZ^?GY]O;V\O+RZNKJ
MY>7EX>'ATM+2S<W-S,S,RLK*____````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/)+[#P````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX`
M``#!241!5`C78V#``J2E]?T2(QVU%*3D5'3,/4.`0J)J3C$1;IHR8N+RZH:V
MWOY`(>?HW+S4\.*B0BNOL+B4S#2@$%\IOW!)66U=375!OH"@4#E0B)EQTK3I
M;:V=S=V3^_LF39T.%.J=T%XYHZ.KJ:5G`N/$*4RS@$)<;.P<G%4-C?7<+!6L
M/#-Y@4(Y\8%V-JY!44D96=GIR0FQ0"$+54D1"44-8P<?7W=K,R,]H)"NDI2L
MLK:I1W!H@(N]I8D!-N\``-+-,(\O#,.9`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+V%T+G!N9P``````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C`T-@`Q,#4Q-30S,S<V,0`P,C,Q-3(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!(````,"`,```!8S!V.```#`%!,5$4```#____.)"7,Q,7BV]RDGZ#Z
M]?;&RLKW^OKQ]/3?XN+;WM[3UM;0T]//TM+.T='-T-#*S<W(R\O'RLK[_?WZ
M_/SU]_?T]O;IZ^OEY^?BY.3AX^/=W]_0TM+'R<G$QL;U]O;L\._&R<C.R<CS
M[NW(``#'``#&``!]``!\``#)`P/(`P/+!07*!07(!07'!07("0G1#0W0#0W3
M$!#.&!C-&!B0$1'<'1W''!S@(2'?(2'2(!_('1W/'Q^:&1FD&QO'(R/&)27)
M)R>L(2'J+R_I+R_,*2FO(R.)'!RX*"CM-37L-36[*BK8,C+#+B[',##*,C+>
M.#C=.#C6-C;1-C7.-#3V0D+U0D*X,C+X1D;W1D;B04'A0D+E1433/S_F1D;#
M.SO[3T_Z3T_B1T?[4%#Z4%#Q3D[U4%"V/S^N/#SS5E;834SR5U?`1T;O65GU
M7E[+3D[Z9&3J7U_H7E[;6EGY:&CS967W:&C[:FKN:&CX;F[N;&SE;&SX>'C6
MSL['P,#&O[_8T='9T]/*Q,3)P\/(PL+'P<'Y\_/X\O+OZ>GNZ.CMY^?<UM;3
MSL[)Q,3Z]?7JY>7HX^/EX."^NKKV\O+5T='0S,S___\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````W\J>I`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```+])1$%4"-=C8,`"-#3M$BIR@DST
MU'2,+;TB4T!"9A%E^=&V!FK:1N:NX4GI0"&/S)K:XC@G"QLFW]BLPO(BH!#K
MM/[NQN:&>N8ZEL[VCJX>H)"\"*>,@#"[(`^7(H<HIS0_4$A!3(I/6$Z(EUM"
M3%1<4E8)*,0VL;>EK56Y:9)*_Y0)4_LF`X6JLP,<'=R"D_-*JRI+"G(S@$*!
MIOKJNL96WE&I:3&A?I[.0"%K`U4M0W.7L,3T^!!_'W=[;-X!`&??+F(6^>(H
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O874N<&YG
M````````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#4P`#$P-3$U-#,S
M-S8Q`#`R,S$T-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`
M4$Q410```/___]=15/)L;?F8F<Q+4+(N.7XA*+HT/G<T.<II<+558["3J%@Z
M4(]GBY)GC\ZTS'-!=YE[GL^VVG)DAK"EP%Y(AL*TVZ&5NEA3;(9XP61>AE-'
MF(Z&PFQDIG-LJI^9TA0)?RPDCG)MP(B$R;JYQA$+@S0ODW5QQW1QPY.0U`P+
MAA02B144CQ\>D"$@EB4DFR\NE4=&JT)!GU!/O$I)J554P554O%=6O$=&ED]-
MGU!/G&)@LI^>S0$"@P8(AP8&A`<'AP@(A0D)APL,APT/C@X/BPX/B!`0AQ(3
MCQ(2CAH:F!H:E1P=DQT=ER$BG"<GGR<GGB4EE"4ED!\?=BPLHS`PIR\PHC$Q
MIS$QIB4E?28G?S4UJRHJAS@YK3(RG"LKA3HZKS`PC3]`M30UE#(RCS$RC#\_
MLS<WFC8VED)"M#P]I41$MCX_H3L[F4E)NTA(N49&M#T]G$%!HDQ,O$U-O4]/
MOT]0ODI*L%%2P$Q-LU)2P%!1NDU-LE-3OU55P5-4O4U-L%%1MU96P597P%A8
MPU96OU55O515N%!0K5)2KU]?PE-4HVAHQV=HQ&UMR,K*RPP0BB(FBSP^FE]A
MPS-$J^MU<L1.3O!D8_AG9ZY/3I1+2NA[>[MK:^>-C/___P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````*E@/"(````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^
M````P4E$050(UV-@P`)X):6GBPO83M5V<-:7+<RO!PIQSI[+S#*/BUO-WBM0
MV:2R`2C$/FO.S&FL'&R*KGYAR:5:*D`A$1[A&:)"8I/<?"*SRNHT;8!"?!I2
M3#+!_(*ZX0K=U19=&4"AOBE&2AYV$]4-XOI;S1N-4X!"O;7%D]V=W+PC<LK:
MJG(SDX!"'?'R$ZP<?4+3RUN:3/-2$X!"V7IRJCV>`8DES36=$I:Q44"A(!<=
M0U__F`*S]HHBZ[3H$&S>`0#YH3(958(&B@````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]A=RYP;F<`````````````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#(P,S8`,3`U,34T,S,W-C$`,#(S,34T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````2````#`@#````6,P=C@```P!03%1%````____JD%#^H&#YXN/B5Q?
M?E!6O9^IR:^]85UIN\36M<KB2%QND*:Y9*#):*3,:J/+;ZK3:Z3*?K??>;#5
MC<7K?:K*ELSPA;/4G-/XE<;GI=C[I=;YK-KZJ=;TL-KW9J''9J+'9J'&9Z''
M9Z+'::3*::3);*?-:Z7*:J3):J/&<:O1;JC+<:O0=['7=K#5<JG-=['5?+;;
M=JS/>*[1?K;:>:[/A+SAA;WAAK[AC<7HC\;IE<SOE\WPA;/1G-+UCK_?G=/T
MHM?ZC[_=H]CYE,3BD<#=H]?X@:K$J-O\F\OIJMW^J=S\I]KYIMCXG\_MI-7T
MH]3RI]CWE;7*D<?FM./_0&E_8I"G@KC3D\;AL.7_0&U_@L7<;Z:UH,S8;J6S
M=JVZ=:FV@[C&DL;3AK7!HM3AC[O&A:^YK-SHH<[9J]GEM=_I<ZFT<JBS?;*]
M:8Z6?*6NA:ZW?:2LH<W6L>#JK=KC=:FSB;W'A;6^<IF@FLW7C;C`J-GBD+=X
MILF2A[%JB[5NBK-ME;YXHLJ&?YQKBJATLMB6E+-]G;V&O^2EKL^6Q.>JO=^E
MD;1.DK1/EKE4F;E:H<1@K]%PCJA>JLAQF+-FOM^!HKUOL<U\RNF.R^J2P]^,
MPMZ.NS(RZ5E9^G%Q____````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````6`.&^`````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```"W241!5!C3;<$M3D-!%`;0[_[-
MS"-U70`)'H%"L`9`T1V0BFX&AV`'J!H\@B60H(`$655",WV\S-S;!<`YP!^$
MA3V6RY>3W<><\]'G:7XBS*;[9;I^WU4=2DHS63-ZHX<>M5DVTV(3%%?MUFY>
M]Y%2EF*]@?'-Y>+MURTG,9,Z@G#LY\_-B9F5R=TWA-5/ZN["Q,+1:;A3G(W-
M@YE4B'JX0_$5ZL0DPN0>'E!,O@T>A$?R4BE7_.,`LP-'N@(`IC,`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V%Z+G!N
M9P``````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`R-@`Q,#4Q-30S
M,S<V,@`P,C,Q-3<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#
M`%!,5$4```#____Z]?8Q.;X]0[D;)K$C+;4F,K4;(GI#3M`[0Y]58-YC;N9>
M9]==9M9G<>1K<]5W@.@<,+P`)\P`&'\#*LX%+-`%+,P)+<T---80-]@8/-(1
M*I0=0N$A1^0?0=09,ITO5.XU6?(X6.%"9OHR3;M&:?Q!8.<Z5L=/<?]0<OY0
M</E7=?9>?/IE@?=JAO\`7@``7``#7@,%8@4%804)80D-9PT0;!`8;A@==1TA
M>"$?<1\;6ALA8B$B9",OAB\H;"@J;2HUB34N=2XP=3`XAC@T?31"E4)&F49"
MC4)&D$90H%!/GD].FTY0G%`V?C5.A3D]<"%@BC\H5``K5@12<S1PDU$X8!-$
M8R=2=S!+:RU?@C]MD$TO50=ND4ISE%'RW]C(;E+/KZ7,KZ;),07`,`;#/1;&
M/!?311W-2"+/2R?.5##>8CZZ4C3&5SC073S$63G29$/B:DGZ>5+B;$K$7D'@
M:TOE;T_D<E#R>5;D<U'L=53Q?%KR@%[SB6O\D''%<5CZCW'6?&+VE7KCK)S+
MLJO;32C-53G07#_T=53*9DSN>E_UA&?SB6WZE7K/+PW`.Q[*2B^;0"SD9TO8
M9$O294SO=%CD<UG!7TOC=EW(:%+RBW3NO++!:5O"CHC___\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````"9,VI"`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK
M/@```*])1$%4&--MP4M.PE`4!N#_/'IML!V8$,*`&&5&7)JK<`LLP449!S!B
M@I,2[`-HSSG7!<CW`?\0YJC*![]<S4155;\8*(L4D[FQB+`0%-V0R`=Y;,D3
MDP0(VY*B>4JY)<G25_&N.,SBY+L07>U>?]//!,:R[B/6F[?GY6>]B'F&XFPW
MR]/^I>L_&AN/&8IO"<_7KN&*/(]%0'%JS42E3#<V=W<P!G<6+@H53Q&1<<<?
MKWI5!\(4R[,`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O8F$N<&YG````````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,#4P`#$P-3$U-#,S-S8Q`#`R,S$R,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$@````P(`P```%C,'8X```,`4$Q410```/___P`72$]NL5!KJ#58
MGP$K=@DO=QLY;2)%AC9:FSI>GSM=F%%VMD)@E&F)PG&'KG.)KP`N=P`N=@`<
M2@$O=P,P>0,P>`4R>P4R>0<T?`DU>PTZ@0TX?0PQ;0HG51`]A!`\@1(\@!5`
MB!A"A!U)CA0P7B%-DA](B1](B!]%@R=/CB%`=2-#=B]:GB$_;R9'?1LR5BA)
M?C!6E"M-A#!2BRY/A2I'>#17D3)4BSA<FCA>FC99DD)KKC]BG4=OL$%FH4-F
MH3M9C$EMJDAMIT%BEE!WMU!VM4%@DE!VLTUQK%)WM$9FF5!TK4)=B%Z`N&2&
MO6B)OV:&NFJ+P%QUGGF6Q'^;R7N5P8&<R(ZJVI>OU9*IS8>:N*&UUKW+X5=[
MLUI[K7B!C[C%V*BUQR1$;5%H?FI^B(N5BY.3<+.RDJ*:88^&3]*V-)2"*\&M
M4;&@4LRE`=&J!Z&&%^2](=2R'[J;'N[(+]V\-_K50N#!/O[:2N[-2?[<4/G7
M4/;75Z",/**01*>62LNW7M*^9\"N7LNY9]&^:\R>`,R?`,V@`<RA!<VB"=:I
M#=BK$-NO%-ZR&-*I&.&U'>O`*_+(-?7+.N&]./C2/OS41O_83_+03/O84??5
M4,Z@`]"B!=2F"NB\)O___P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````)KPGD`````!8DM'1`"(
M!1U(````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`*8#!/Y,NNF
M3NAJG]M;G&?O!A024?.+"\LJZ>Z8TS.QK,G=$R@D;YX0&^Z:6]`YKW_2M&9O
M9Z"0OD\@2XR`7%%AW_PI56U>=D`AI^!X*TX/P932XLG3:UH=+8!"0?X.&NQ:
M(=RIY14S:EML3(%"`2[:LJ)LBLF\:;-G5>=;F@"%?(V5Q(6DE+FB(]-G5C::
M&0"%K%4DA244U%DCHO@S<AJ,=(!"FM)"8C*J>K;,H4D\V?6Z'-B\`P"AZ#(U
M=0H\N@````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B8BYP
M;F<`````````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`U,34T
M,S,W-C$`,#(S,3(T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@``
M`P!03%1%````____*"58+BM@#@Q'#PU'%A1,0D!L0D!K1$)L6%:%7UV+6UF!
M='*>$A%+&AE2(2!5-C5R.SIP3TYZ:&>@9F6=4$]Y6EF%8%^+:6B3``!.``!-
M```Q```P`P-1`P-0!050"0E3#0U7"@H[$A):&!A>$1%"(2%M'R!E'R!D&1E+
M&QM0)R=J(2%7+R]Y(2%4)B9=*"A@-35],#!P*BIB+2UF+BYH,#!K,#!J*BI=
M-#1Q.#AY-#1P,S-N,C)L/CZ%.#AX0D*(.CIV,C)F1D:+/S]\04%_/S][2DJ/
M0D)_34V01D:#24F(2$B&24F'4%"33T^13$R+4%"13DZ-45&24%"045&14%".
M1D9\4%"-5U>27EZ865F/9&2>966=:FJB(B-9*RQD.CMQ_O-*>W$`?W4%O:X*
MV\X4FI$F7%<86$\`?W,!<F@'CH(*@W<-W\TXW<X^S+(`R;``@7,!P*L#PZP$
MR:\%OJ<%?6\#7E0#Q[`)PZT)KIL)O:8+QJ\4JI@1S[@8X\PA;6(0S[D?A'<4
MS[@ABGL61T`-[=4OV\@UL*$JX<PX^.%"\]U&8ED<<6@A_N=/X<]&_NA0]^%0
M\^!0W,I)R[I$BX`OY]51[MM4ZM=:E8HZ03T=7UDK>&TK____````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````3/_OA0````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;)
M:SX```#!241!5`C78V#``F1DM9)X9W4WE!56"Z@;N?@#A635G.,DIS57%974
M,^LY!H0"A90M8V)YYN459^?VL=M[A?D!A?0C1,(YVBI3<EJZA#U"`MV!0D+Q
M4=9,-5FI3?WY7/[!GC9`(=%H-PVVTHKV.=-[N8.\!2V`0K&^.DJLY6F9<PNF
M2/@XV24"A2*-5>19:M,S9B?/%'>U-34`"CFH*DCQU35V3IPT0\S*S%`7**2I
M*"W'W]K1,V'R5$YSDP1M;-X!`$E9,=K"=39)`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+V)D+G!N9P``````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C`T-0`Q,#4Q-30S,S<V,0`P,C,Q,S(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___\?2B`B0B,K32PZ
M63L`+P``+0``'``#,`,#+P,%,@4%,04)-`D-.@T-.0T*)@H0/!`2/!(801@1
M+A$=21TA3"$?1Q\9-AD;.1LG3B<O6R\A0"$O62\A/B$F1B8H2"@U7C4J2BHN
M4"XM3BTX8#@P4C`J2"HX7S@S5C,T5S0^9SXX73A":T(V6#8R43(Z73I&;D9"
M:$)*=$I"9D)&:T9);TE-=$U&:D8[63M(;$A/=D]);4E0=U!,<4Q.<TY1=U%0
M=5!&9D90=%!7>E=>@5Y>@%Y9>%EDA61EA65HB&AJBFHP5B\R5#$V634_8SX_
M8CY!94!FA65$9D%+;4@=0!@Q5BL-+P4)+`!,:4(=.Q!;<T]8;TP?-PUO;4Y<
M3"]`(0%K-Q^)4CIM+AAD'PEK&@.E9%&*.2>>,"&4%0?"4T:D)!C-6U#(6D_=
M6%&N!0"E$`G;.C7J2D;,``#'`0#&``#-`0',`0'*`P/(`P/,!07*!07,!P?4
M"@K0"@K0#0W.#0W3$!#/$A+;%!37%!39&!C;'1W?(2'H)B;E*ROI+R_R-37S
M.CKS/C[Z0D+^2DK_34W___\`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"VFC@=`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```+Y)1$%4"-=C8,`".#@D6+U=
M-$+#V;@%Q10-;4%"(OJ>KL&)!?FIL:*RNM:.0"$!=7>/D/2&\K+:[#!M<P<;
MH)"<DY=C?%-%24U+1Y*Q@UT`4,C2VT4UN:JTNK&].\O6WD0+*!3D%LB44EQ9
MW];5E^MHH:<&%/*PDN)+**MK[>R=D&9FX,L"%'+V$>*,R&SNZ.G/B_'75)$'
M"ND(\[!S1V44%N7$&6DI*\@`A<1YV;GX1:4CHQU-_=24F"6Q>0<`ZITL9*6M
MO#P`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8F4N
M<&YG````````````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0S`#$P-3$U
M-#,S-S8Q`#`R,S$S,0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X`
M``,`4$Q410```/___SLZ.VAG:!\@(#H[.Q\@'U%2269G7@P-`A`1!L;-`+.Y
M`\G0!;_%$[B^%>'H)L+'*NSR->_U.O;\1M+70\;,`,K,`,?-`<;,`<C.`\O.
M`\K,`\G,!;6Z!<O1!\?-"<[4"M'4"K2Y";F^"M#6#=+8$-;;%-G;%-C>&,_2
M&-OA'=_D(=+4'\K/'^7K*^GN+_/X/O7Z0OG^2OK_3_K^4/7Y4.7H6<W.#0P,
M`>/D(>[N+^'A.!04"A@8#2,C&3DY,')R:C`P+T%!0,C""LO&$=/.'-S8*N?B
M./#K1N+>2?;Q4.WI4O3O5<$T'L@_*M--.-U;1L%20.9G4]%?3>EN6MUI5^5O
M798M))XS*J`U+*<Y+ZD[,=M.0:P],ZX_-;%!-K1".+E&.[=$.KY)/KM'/<!*
M0.):3L5/1.=?4LM42-!73-1;4.AD6-E>4^AF6NMH7.!D6-UB5^=G7.5G7.1F
M6\TX+M9%.[=!.N!32;Y&/LM12.=?5=E<4^AD6^-C6F9E96IJ:F5E961D9%Y>
M7EE965=75U!04$A(2$9&1C@X.#(R,BHJ*B<G)R$A(1D9&1@8&!(2$A$1$0T-
M#0H*"@D)"04%!0,#`____P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````%^_-L`````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````O$E$0508TVV,,0Y!011%Y[UY,Y-\*E$H?ZD@46@D5J"P#VI1"+^Q
M`"(2>Y&H-=:@D@B%!(F8^?-G/#4WN<W)N5>(GP!W,>Z^U.WIFDG]7#9+%&+E
M9_OC_64E`"1:"11KYR#ZDD4#@%I91J[(J!-.#Z,!I`Z>T>@]E[&:HU&`&*QC
ME,G=)%RHI@@0\CPRDM1;'"J&Z"MY_QW2EJBE]?F$&$/!7R1D7PT2:ER!2?0^
ML#55PTT[A32%$-B*XD\^T,Y'(#<!S\X`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]B9BYP;F<`````````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(P,C4`,3`U,34T,S,W-C$`,#(S,3,R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````2````#`@#````6,P=C@```P!03%1%````_____6=H`%H``5P!
M`UP#`UL#!5X%!5T%!V`'"5\)#64-#6,-$&@0$F42%&L4&&H8'7,=(7<A'W`?
M&U@;)GDF)W8G(F(C(5\A+X,O)F<F*&DH-8@U*V\L*FLJ+7`M+G(N,'0P/I,^
M.HHZ,W@S.(,X-'HT0I-".H(Z1I9&0HI"2IE*39Q-1HY&29-)2)%(3YQ/3)5,
M4)Q03IA.49U14)I04)A09*ED#&<*,'PO,G<Q-GPU/X4^,H0K*VL@#E0`$5D#
M%EH).G`P0'@V3HU"3(9`48I&6YA/6Y90:)Y>;Z-E*GH8088O>:<-GL`=U)\0
MQ7\%T#\AMA8`S!L'R0T`N`P%OQ\8WCHUT#XXPSHTZDU&U$A"N3\[[5=0Y51.
MY5U7\&]JQP``?0``?```R`$!QP$!R@,#R`,#RP4%R`4%R`D)S@H*T`T-R0T-
MB`H*TQ`0SA(2V104V!@8SA@8D!$1W!T=X"$ASQ\?FAD9YB8FTR<GY2LKIB$A
MZ2\OVR\O[34U\SHZKBHJW3@X\SX^]4)"N#(RX#\^^$9&XD%!_4I*PSL[^DU-
MZTE)Z$A(^D]/\4Q,_%!0_%%1]U%1]E!0TT9&\%!0\E=7]5Y>Y5E9^&1D\V5E
M^VIJ____````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````F;T=[`````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"N241!5!C3;<'-3<-`$`;0
M;W<G,W8L6S@1G5!.3CGFE*XHB0)0!!(0*T99]G\H`-X#_C`XFL?=G#]O/HA(
MW_5G"S./#V6]_P0FEHTX6`SC7OWJLR-F%HJPF/:G<O-Q65@VS#7!X$`:F]:F
MEITSM3T3KEJB:V8T^=N95A6$K_#F`YZ&];+M4MJ]@J#;D)1?>.J[.KU?*@C+
M1ZI$3E@TWDMIL+BF;(ED$)?FW$K!/WX!#,I2#B&%N.L`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V)G
M+G!N9P``````````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`Q-P`Q,#4Q
M-30S,S<V,0`P,C,Q,S0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.
M```#`%!,5$4```#____&Q\?)SLC$R</N\^W/T\[AY>"KKJKU^/0\@B#"Q\##
MR,'AYM\A;P`A:P`C<0,E;P4E;@4H<PDM>0TP>1`V>A@\AQU!B"%.ER]3F#5)
MA#!3D3A/C#9@ID);FD!<F$)@GD91A#MKKD]LK%!KJU!IIDYPJU=WLEY]M&6"
MN&I!A"`_;"E.AS1DID9DHT5CF4ASKU5XLEMFED_4V-+V^O3S]_'FZN3DZ.*%
MAX0O<PPQ=`\U>!,]?!U2DC%7D#ERJ59UJEF*O'`O9P%%?!A/@"=6BRM-=RQH
MFSY>BCIUIDUMFDB&L&0P:`$X;PHY;@U5@#%OG$EXIU'`"P#`#0/%$0?$'!+/
M'A3<,":P+B;2."^[-2WJ0SK&.S/61S[S4TKH54SS6E'H65#4.37,`@#+!`#,
M!P/0!P7,"`7+#0G4$0W8$Q#2&QC?(1WD(R'3(Q^F'1NP(B'M,R^Q)B.\*BCR
M-S6]+"K',"[),S#A.CC2-C3Y1D+\24;E1$+I24;^4D_^4E#V4$[X4U#^_O[\
M_/SZ^OKY^?GW]_?V]O;R\O+N[N[GY^?DY.3AX>'8V-C6UM;4U-32TM+0T-#.
MSL[-S<W,S,R[N[N=G9V4E)1_?W____\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````'\"=E`````6)+1T0`B`4=2`````EP2%ES````2````$@`
M1LEK/@```*A)1$%4&--MP<L1`5$0!=#[NILW_JHH`K"UL/"-20R62@RRD@3+
M&0ICBM?=`N`<X$?`$;;U0TT$FDP_OA/`?6_,#%.WM-L#V&2QL:Y+J\WS3FVQ
M7"%@&GMN9D[%X$:A>ST)2GL\WTE)N!C>*>^`$*W*-06F(,_PT1R"B;]GCV8H
MB2CS*K[.@E&5K$_4%":WMC4@&-]38N$8)21551!*56*2.I->S-WQQQ>,9E`B
M"\<`9P````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O8F@N<&YG````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R,#(V`#$P-3$U-#,S-S8Q`#`R,S$S-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___]`U-MTY.L3#
MQ(F(B:2DI?K[_/'S\^7GY^+DY,K,S,?)R=/4U-#1T;BYN9J;F\<``,<!`,@!
M`<<!`<@#`\@$!,8$!,L%!<H%!<@%!<8%!<P'!\@)"<X*"LX,#-`-#=,0$,D/
M#]84%-D8&-@8&-88&,X8&-P='=L='>`A(=\A(=\C(Z0;&^(F)L\C(\@E)>4K
M*ZPA(>DO+Z\C([8F)NHR,L<K*[@H*.TU->PU-;LJ*KXL+,,N+L`M+<<P,.\Z
M.LDR,<8P,-$V-<XT-,LS,_,^/LHT-/9"0O5"0M4Z.M,[._A&1O=&1MP_/ML_
M/MP_/^%"0OE*2N9&1OI-3>5&1NI)2?M/3_I/3_M04/I04.Y,3/%.3OA14?=1
M4?504/104/914=--3<Q/3\=-3?)S<\IN;N)\?,=M;<=U==%]?<=\?.B<G,V*
MBMB3D_O!P?6]O<:YN<:ZNMW1T<_$Q,G`P/CN[O/JZLG"PNWGY\.^OOOZ^O7T
M]/KZ^O7U]>[N[NCHZ-[>WMC8V-+2TLW-S<C(R*ZNKI"0D'U]?7Q\?/___P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````%$.(EL````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````KTE$0508TVW,.P[",!`$
MT-V-O_D0I-1TE'0<@/L@T4-!#:>@I>8LG`&)FB@VCA,;AQ:F?)H9@)\@G/&T
M[<QEV5JI==U45P((<41:&<N4U/-2`,$Q]G'PK27-=5,(FPC/(:.'"TGJ4H_O
M1&&'?5P,DJNR4M&81/N,T-^C5*HNA+N%:4@90Z>9:@IMNDV?B"@X6LL\'?7.
MCPY8(D3_%-^C+MG4PD/&>#[+N7WY,'CXDP_>V$-T[LJ9T0````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B
M:2YP;F<`````````````````````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`U
M,34T,S,W-C$`,#(S,3,S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=
MC@```P!03%1%````____TL#!]^SN[N+ES,O,T]C8V-O;R<S,X^3DLK.STM74
MR]#.P<S$\/GRJ;ZHR]C*YO/EW>S:,'@@2HLXK\&J/(`G9*10T.;)FJ&8.V\J
M3HLZ9JA0:*E19Z=19J-0?+1H<9UBX._;/',F0G(P:ZM1;:96>)YIDKB#C**$
MN=6N:71E'$<)3XTS1'LM3H8W8Y])<*=9<Z1>D\1^E,.`?J)ON=BK'TT*.&@A
M1GPL2X(P4(@T4HHV6Y4^7YE"4X4[8YU&8YY(::5,:Z=.7Y)&<ZQ7=J]<>;%>
M?[5D?[-EA+EJC+UT8'=5J,"=380Q7IE`@*-NS]+([>SEQ</`S,?$X]G4JW%8
MM7MEN'EDVZ:4PZB?PJ6=V']RS<;%PEI/WL[,T`\%X2@=SBLAXT,XZE!&U$D_
M]E]7_FIA[W-JX7!J^X)ZS&ECXGARS7=R^9J5T9",T\'`_N_NS`<`S!0,UA4/
M[C<OX3XXYTA#Y$="T$4_]E).RD9`^5=0QE92S'=SOXB&\;BV_<O)WK2RV+6T
MS`8%UA`-V!,0V!00TA@8U3@U^D9"_U)/_VIJG7-RS*RLR[JZV]G9_/S\^OKZ
M]?7U\O+R[.SLZ^OKZ.CHS\_/S<W-S,S,Q\?'N[N[?W]_____````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=<A):`````%B2T=$`(@%'4@````)<$A9<P```$@```!(
M`$;):SX```#!241!5`C78V#``K3G]M;VI)5UM!0EM%4T3%0""NGXS&'.*T_-
MS4XJR6299.8&%#*7TA"<VAP;%5W0-$W(1,X`*&3AHJ#F.X,C+)Q]NI:JK),M
M4,C>RU4D8-8L'C;.*=XRSG;60"%/=W]AQ?ZXD/B8(&-Q!QLKH)"'HY@^?W!$
M8&@DGX2AM)\E4$A>UY27-7_"],F%C5,$U/64@4)&HK/Z*MN3,[+2JW*89FNJ
M`(6X9]85MR:6=G77I'16UW-)8O,.`.#!,M(=J]FR`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+V)J+G!N9P``````````````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C`P-P`Q,#4Q-30S,S<V,0`P,C,Q,S8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___\Z>3L`7P``
M6@``.0``.``!80$!6@$#7`,#6P,%7@4%704%6`4'90<)7PD-90T-8@T0;A`*
M0PH291(28!(8:A@12Q$=>!T?<!\?;R`95!DG=2<G<"<A7"$J9BHX@S@X@C@R
M;S)!A4$[>#M(D$A0F%!&A490EU!7G5=7F5=>HEY9F%EDIV1HJFAEI65JK&IJ
MJVHP?"\P>R]!B4!FIF5%@`--A`U;CQ]PH3A#>0#+S0#-T`?6V13BYB;O\SK<
MWS[Y_4KN\4SX_%'(QP#'QP#+R0')R0'(R`/+RP7)R`5&1@/+R@G.S@K0T`W3
MTQ#8V!C2T!C<VQW@X"'EYBOIZ2_M[37S\S[U]4+X^$;Z^DWJZDGZ^D_[^U#W
M]U'U]5!64A1A7B%N:R],1PK?SR'LW37.P33WZ$;QXT[.O`74PQ#ATT+ZZU#4
M&0W=*1WI.R_&.C#0/S;U3D+E4$;Z6D_T6E#=&!CF)B:D&QOG*RNL(2&O(R.V
M)B:X*"CP-36[*BJ^+"S#+B[`+2WQ.CK',##),C'1-C7.-#3+,S/S/C[Z0D+5
M.CKY1D;;/S[A0D+Y2DKF1D;Z34WJ24G\3T_Z4%#N3$SQ3D[X45'U4%#V45'_
M__\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#):G^#`````6)+
M1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```*!)1$%4&--MP<UQPC`0
M!M!O_R1C0L"'S-`$-$TC*28SN67"(4:[DJ44`.\!3PA&']_7.)Z]:E(1O3%H
MR9?JHX:8,`N#<9CF'C%"C)F9&Q3[B>/]=_S12L0\.A1I+OY3]$I!;$WJIV)9
M]W=?%R43IMX-BA+WA^MY)Z=I<H\*AA^*M[S1G%*KV]:@B*\262GO;'A$ZV"X
M%[-$;UFC;+UWO/`/"H)++*YKQ:,`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M8FTN<&YG````````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0Q`#$P
M-3$U-#,S-S8R`#`R,S$T,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,
M'8X```,`4$Q410```/___\```<$&"<L("=02$\<J*\<N+_)86O!?8.AA8^YE
M:/=K;,-76.YT=>N-CGD<'[<^0<U)3;(P-X,R-JU'3?_6V.C"Q.&FK6,W/Z%H
M<IYK=FE,5+.(E:B"D(56<<FIP81UA+"CM<"NRV!"<T(?7%@]<92!J8=UIFUG
M?#(E8Y&2MJS9R$W0/H#H:'2Q2[KBH)2C3=?6Q=S9OM;)J=_+G^C>T)9G,]O.
MP-ZA?_+=T=1R3L%'-<$\,>UO9=-A7OJ!?NF(A<P``,T!`<P!`<T"`LX#`\P#
M`]`%!<P%!<<&!M$'!\T)"=0*"M8-#=8.#LX-#<<-#=@0$-85$\\2$ML4%-X8
M&-(8&.$='>0A(=0@']0A(>$D).@F)J<;&^LK*]@G)[`A(>XO+[(C([DF)MTP
M+[PH*/(U-;\J*L0N+<$L+/4Z.LHP,.X[.^$X.-4V-=(T-/@^/OI"0M`[..`_
M/OQ&1OI'1_Y*2N1#0NI&1N%$1.Y)2>Q(2/]/3Y0P+OY04/9.3OI34?E04.5+
M2]Y(2/%04/M;6N%95_UD9/MN;O)K:[M85N=O;;)85NF#@?___P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````+WTD4X````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````NDE$050(UV-@P`(D931Y%2245+R</((BTTOK@4("==T\#CU"
M;"YN_C&Y9;5-0"&1WKY.1WM185??%G%^L;9JH)"BK#*?MIR\*DLHEYFE%4<)
M4$A*0[U=34M:D#6RRUC'J+D`*,3-614=R,0<')%D9VIA4IP#%.JH20AP<?8-
MBR^TUC/0M\T""K6FAK@[>8?&9I<W&NJ:9Z8`A?+"/:$N:JBP84]+!`I%^3BY
M^44D%=4V5>;G9"3'8?,.`#2C+F>(M_ZD`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B;BYP;F<`````````````````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`U,34T,S,W-C(`,#(S,30Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____S%M=[I&2
MP18;W,K+9F%BDH^0_/#Y.SH[?WY_U=35_/K]U]78]?3VZ^OL'R`@S<[.P,@%
MXNLO[_A"*RP-]/M/\/A0P,,#Q<@%Q\D8U-8=X>,_S,X]Y>=&7V`CR\U/:6I"
MPL(`P+\`O[\`P<$#NKH#P\,%P<$%P<`)R<D-S,P0R<@2QL<8U=0=V-@AR<D?
MXN(OW-POYN8UO+LP>7D?[.T^U]<XUM8XS,LUEI8H[^]"\?%&CX\JU=5`OKX[
M\_--X^1)]/1/\_-0\/!1[NY0[.Q0Z^M7U]=19&0G>WHR]?5JVMIDG)Q(Z^MV
MW]]S]O:7]?2?:6EE?'QX/S\^04%`6UM:O;D`1D4;]?3+T<D0P;00^?2N1T4T
MGI).[^K8T,['O8H`7UI,N;>QFFL'VYTAZ[50WI0U[)A&XM_<JZBF5U54G)J9
MPWU>I)6.O$,5/A`!U$HZJ5]76`D!PC,FT&!5N%U4EE--8P\*<1X8AT(^[+NX
MGV]MFFYL7@``Q`<'KQ<4+0@((0D)D2LKX4I*DS@WVUQ9.1H:IE%1DU13[9N;
MR(V,XZBGXMS<[.CHDI"0X^'A^?GYZNKJZ>GIS\_/RLK*LK*RHJ*BBXN+:FIJ
M7EY>,S,S+BXN+2TM*RLK*"@H(2$A____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````$`&-+P````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#!241!5`C78V#``KQ,
MK>R]W2VDA%34M?6-;9R!0ES]R9&!_K+1B1):>H;63JY`H1G3)O/P\PKFYBO8
MR9@YN#@"A=BF9_:Q3NEFJ6?JC8\)\/,`"G'.#,MNK:DM*^VI[N+@FY``%`J:
M%2K05-?8WIG7QCQQ$O=4H)"/KZ=H07%%97-5>5$P>TX64,C-2$<M/*6AI+"E
M(RED]MQY0"%S70TER:C4](RT.,78.?,7`(4,-)55M:2%1<3$Y2Q-;.4CL'D'
M`.B&,GKRN]7^`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+V)O+G!N9P``````````````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`Q-P`Q
M,#4Q-30S,S<V,@`P,C,Q-#4`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8
MS!V.```#`%!,5$4```#___\`7```60`#7@,%704%7`4)80D-9PT09Q`8:1@=
M=1T?<1\A=B$;6ALB9",A7R$OAB\J;2HH:"@UB#4N<2XP=3`X@C@T>31"E4)&
MED9"B4)&D$9/GD]0G%!.ETY>=UXV?C4D;P`F<`,K=0<S>!(ZA15*D"<_=29-
MC2]'?BU.AS-:E3YLL$MII4QOKU%LIU!>H#I@<D9A;42$C4=U>"[)RP''R@')
MRPW3U2>]ORS5V#KHZDCW^E'X^F3(QP;-S0G2TAC4U2#*RC#)RC'AX3C2TC35
MU#;GYT#\_$;EY4+'QCOJZD;__T_X]TWJZTG^_E#V]D[Y^5#V]E?Z^EYP;RKX
M]V7__VK*Q0;/RA+3SAKHY";U[CK^]TKR[$SQZU#4ST;$O`"GH2'=U2_CVC;@
MV3[]]E'_^&B@D@J0A!*BD`WFTD.VIT.4=0:HCRV89S9]0`;-)@',(P'4)PK[
M:5'.*`V+'`K>,QCK12O8/R>R/2KX5S[_94WN8$GL7TCI;5G]>63,``!_``#.
M`P/0!07,!07-"0G6#0W8$!#2&!B4$1'A'1WD(2'4'Q^=&1GN+R_R-37A.#CZ
M0D*[,C+\1D;G04'&.SO_3T_^4%#Y4%#V5U?Z7E[W967_:FK___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!W1@)Y`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```*A)1$%4&--MP4M.`E$0!=!;'WB@#!RX`A9@G+LAU^$>29CH
MQ!C;1(+8=/?#KEO/!>@YP!^")VQ6A5.-,'=W?U1@M5CF'`PU,S6!XUP'R3G8
MU,6DKN'XS%)];#=R$I%U+7!\;/KOR+ONY6%\*^=+0''-@6UKSP<IKC,)1=>=
MQFGW8[=\_>*1$P3WE\BF*E>A+5O+O>.]#ZI[Z5V"3$(Q,,34%P8NDY'XQR\F
MXUF]#$?9MP````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8G(N<&YG````````````````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R,#4P`#$P-3$U-#,S-S8R`#`R,S$T-0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___UAXI@$P
M:P$O:@LX<294CR91B#IIGC18@F.-O%V%L0H]<2%1A%F'M@0Y;"%2@")/>$5F
MA%YYD0]#;1!";!)'<Q-(=BM5>2Q5>3-8>$%NE%%^HQU3?252=2Q=@TYYFF2#
MFSIY.P!:``!2```Y```X``-<`P5;!0E?"0U@#0I#"A!D$!AJ&!%+$2%X(1]P
M'QE4&1M8&R)B(R%?(29F)B]]+R%8(2AI*#6(-2IK*BMK+#!T,"YO+BUK+2IC
M*CB#.#1U-$*20C)N,D:71DF224^<3U"=4%":4%"74%&745>;5V2C9&JI:F6A
M93!W+S9W-3^"/EJ768JHB0I?!2-T'56=31UI$E*21HVGB$-^,WR6=7.L7E^1
M1D6('3-V!72I3*O`F7:H2'&B.'FG0K+#G9W%9&V5,5:*`&R%/7N439.^/GV=
M.Y*Z+W"6`XVJ-'6+-;;34*2]/G>*+:G%09.E2L+99<SA:+W->H&1,I>E2L+0
M>*"V#9ZQ,+;%6*N_$*:T09BE&K3#)];C3M;E4:*L'+*[,<3-.L+)&-SB2+_%
M0L+%`,?*!>+F*_+U0O;Y:L[.#=35(.'A.-74-N?F0/[^2N#A0NKI1N[N2?[]
M3_W]4/;U3NWN3?;V4/'Q4/;V5_CW7O___P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````-"+P/`````!
M8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`)4
MU0R5?+V3.WHR0G3T+5W<@4)J>LY^,25ME<6M-7%F3FX>0"%M^Z"TSE)1%F:>
MK-[L,"]7H)!Y;/F\+DE!.0D!]KJI+0F!0*&<_OF3JCBEA(05F2)GS9Z6#Q0J
M6S!E8@&KB)B\-'?JW.F3:X%"/DE-$QKYQ6459+@J9K2G6P.%//W#\[HS>=DX
M^!+G%$79F0*%''0U5.+K&Z*#JYM3'&TM3(!"!IK*ZEJAN7TS"R,";*R,C;!Y
M!P!]ZS)VH@;*#0````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]B<RYP;F<`````````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#8`
M,3`U,34T,S,W-C(`,#(S,34S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````
M6,P=C@```P!03%1%````____.SH[:&=H``,/`P4-(4&P3G3V9&AV`##,`S/.
M"3?-#3S6$$#8"2%J!1`T'4OA(4[D'TK4+USN*$J\-6#R+E''-%C20F[Z1G#\
M06GG0F?E3WC_4'C^4'CY,CYC`#3'`#/&`"B;`!53`SC.`AMC!3O0!3C+!3C(
M#4#1$$/3&$?.'4[;(5/@&3N=&SZD(D>O+U_J-67M*D^[,%?&.&/=-E[10G#V
M1G7X.E_'1F_F3WO[4'WZ4'KU5W_R7HCZ262S:H_[98;C&$.L&4.M(4NS+EB^
M06G,4WK:88;B7'[498C@*5&O)T^D/62^67S(1V.@3FNJ6GBY:(K3:(?*'R(I
M/6.L1VRY/UN6;H_4'R`@*RT%IJ@*Y^E`U-9$\?-03D\:YNA2%A8`@X(%R<H(
MQ,0.U]80GI\-;FT-W-T;WMX=S<X;X^(A[>POX>(NVMLM[^\UR,@PN;HNT-`T
MTM(VQ,4T]_="[>Y!^OI&T=(\X^)"Y^=&_/Q/_/Q0]/-.]?90]O90Y>9,\O-4
M\?)7,#`O04%`#`L#`@$!,"\O9F5E:FIJ9&1D7EY>65E95U=74%!02$A(1D9&
M.#@X*BHJ)R<G(2$A&!@8$A(2$1$1#0T-"@H*"0D)!04%____````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````:MSZM0````%B2T=$`(@%'4@````)<$A9<P```$@`
M``!(`$;):SX```"_241!5!C39<\]+D11&`;@]_V^]QQ')E&8*31",84EZ*Q"
MI55JB<0"9@HV8"$2G4)$JU.(1"NB$''OG7M^+&">'3S`&D)[DTDJW5_I-]Q#
MU*.0SQ>S\M8/E28/,A"WP^KJ<*MV)$E:NQ/&>G$]O.8=1GW;_+V`L*6D^$2/
M2H%YN#$LK'L.I_,@1GE950BF=/1U\F':3-XJ"4&_T[/]@Y&]XEA;2Q!\^W*7
M#Y+T.<NM_H`XOI]Z\!!E)==6VLOZ!_^R)T%M(,Y_>@````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V)T+G!N9P``````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C`U,``Q,#4Q-30S,S<V,@`P,C,Q-#<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___^XL[74
MU]O$R<O1U-7-T=*HK[#9VMJBHY^QK9VTK(VYL9/#OJW'I$5]60!\6`##BP'"
MB@+)CP7'CPK*D@W%CPV(8PK.F1B0:Q'/G!^:=1G=J"?3H2?.G2>D?B'9IR_L
MN#6NB"K>KCC=K3BXD3+BLT'#FSO#G#OHN4B[EC[NP%#MOU#0J$;RQ5?QQ5?U
MR5[URE[EO%GYSF3XS63TRV7ZSVCSRF7[T&K[T6JVG%Z\J7FWJHG,D`?)DQ7$
MD!;-EQS!CQO.F!_#DA_.G2R_DS'CLD#6J$#HN$C,HT/$HE*YF$[3RK:VKZ"[
MMZ[*EBOGSIJXJY3RKTS!70V=AGK#JY^HG9CW@E#(O+>X;%&Y94GAS,76QL'9
MRL7'.1#82"'`01^D.1NL0"&O0B.V1B:X2"B[2BK*42^^32S`3BW'43#)4S'F
M:D;-7S[9947T=5#E=%+#8TC??F'B?V3FB6WMD7C8B'+*@&O1AG#IF(+@E'WC
MEX+?EX/>F(7GH8[2F8G8H)'DJYK(F8O3-`W#3"['3C#2537,4C/763K\<4_H
M:4G\<E#O@63RA6CKA6OFGX[GIY?`CX.LAGVIEI'!,A'/433Z9T;R:T[V;U#N
MBG.CGIVUF)/9N;/JV-?>T-#!P,#___\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!I7S89````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,%)1$%4"-=C8,`"
M^`6D-2SU5"2$A9SE9!2#PH%"`I*JYH9J4B*.5K[S?0)*9P"%Q)6,3#1E105=
MO?R8Y\VM+@`*R>N:Z2C8V8O9^O/.F5E9D@<44K?05W'PYN*V#F6-[8]NF`H4
M,C5P<]'BG#R;B85C0FU1;A90R-C#TX9]5F1Z$UMC3U='=@902-N=)RQDTL3Z
MXKZZF(KVS!2@D#)?8-24PHBJ:=W3R\I;4I.`0D[!"7'-\36]G?DY;:UIR8G8
MO`,`/.4QY-R*F/X`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O8G<N<&YG````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#,U
M`#$P-3$U-#,S-S8R`#`R,S$U-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P``
M`%C,'8X```,`4$Q410```/___[SB]2^<S#2;RS2;RB!A?C>DU#B?SC>=S#B=
MRSN>RT"FU$2OWD.HUT.IUT>FT3)UDTBFT4^RWU.VXTVITSM^G#^%ID6-KT>0
MLF#![4Z8NVC,^&7$\%";O56CQEBER6.YX%VLT5ZOTW'.^56;NFW%['71^VN_
MY6R^XUZEQG##Z'S5_GW4_7W5_7O0^'O1^'G.]'_0](O4]I#;_7.GOW2GOW.F
MO7BLQ'2GOGNNQ7FJP'RMPX2VSH>YSY/$VY;'W8JWRVR.GI&\T:+2Z'^EMJ;5
MZI.\SIG"U:_=\K'=\JG3YZ3-X++=\K#;[Z;/XI:ZRZO3YKG@\BZ<S"^=S3"=
MS#2BT3BASB=MBT"LVSVCSU&ZZ%:^ZT^OV$>7N5:TW&/)]4^AQ$B2LE:KSV.Z
MWW+4_G75_V['[G'+\G?5_7?3^W3+\7G'Z8;9_875^(FPP4$\.45`/6AC8'IU
M<C,M*D0^.TE#0$M%0E--2EA23U9035I446)<618/#!D2#QL4$1X7%",<&28?
M'"TF(S(K*#<P+4I%0Q</#$=!/U1.3&!:6&-=6V)<6F]I9W9P;O___P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````-"H[8@````!8DM'1`"(!1U(````"7!(67,```!(
M````2`!&R6L^````MDE$050(UV-@P`+8V,2T3(P4A;A8.?A$9-7U0$*"JL9Y
M&J+<+)P\PE(J.@9`H8BDG%RUV'#F$';>&)FTK'2@D%,`4Z"SC9FIA:V]BZ>O
MMP=0J*VXJ+RYOK:^J;6LNKNKLQ`HU-=;4=+07M?84EI5TU/940`4"O)QM#:W
MM+)S<//R\W?/=P4*9<='A0:'148GI&9FI"0GQ@&%%`6`+N('NDC74%-)7EH"
M*`1WD;ZVLH*<I#@V[P``+'LI>D`Z_S@`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B>2YP;F<`````````````````
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#(P,C8`,3`U,34T,S,W-C(`,#(S,34W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____U"XQ
MU34VX3P]YT%#B3@Y^HR-\)J<`,P``\P#!<T%#=$-$-40'=P=(>$A&Z,;(:TA
M(J\C+^HO*+HH->\U*KLJ+L4N,,8P-M$U--`T0O9"1OI&0N)"1N9&3_M/4/M0
M3O-.4/50!<(`",4##,<'&=$4*MXF*K(F,;TM/NLZ-\<S0M<^3O5*4.I,5?51
M#KX%$,$*([<3I"4!HR4!JRT*IS`-MCL8Q$TKHT8LK4TQTE\^N58ZVVQ-S&9)
MV&]1MD8JS'-HNR\BP38JS```QP``QP$`Q@``R`$!QP$!S@,#R`,#Q@,#?0("
MRP4%R@4%R`4%QP4%S`<'S0D)R`D)S@H*U@T-T`T-R0T-TQ`0RA(2UA04?0P,
MV!@8SA@8S1@8X1T=W!T=?!`0X"$AWR$AU"`@SQ\?XB8FTR<GY2LKFAT=D!P<
M[B\OZ2\OV"\O[34U[#4URC`P[SHZW3@XSC0T\SX^^D)"]4)"^$9&]T9&VS\^
MXD%!X4)"N#8V^4I*ZD9&PSL[^DU-_T]/ZDE)Z$A(^D]/^E!0[DQ,^5!0\4Y.
M^%%1]U%1]%!0[5!0Q$5%\E=7\5M:]5Y>Y5I:^&1D\V5E^FEI^VIJKDU-YFIH
M]G5U]75T^WM[I%55T&]O____````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````I*5ND@``
M``%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"O241!5!C3;<'-
M6<,P#`;@3[(?V3*!2Z%3,!)K<&$!SER8H8S0";I(RX&?0YTF`1)+#-"^+W"&
M\"!YO?[=?]9!KTJG-T^,HZYNYZ]^'$1SR=<"QO;^SOOO.H0B.1>9$/%*]O-1
M3ZV3HJK+!$:U^?TXS9I44_;A#XS.'NNI#REE41Z?&PCI93.:,U-@=C/?1=!;
MK<Y$(;";FR-B83\PLZ1(2VNM@6'N1!0E<%O,S7'!/W9#3O7]$+5-`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+V)Z+G!N9P``````````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`U
M,``Q,#4Q-30S,S<V,@`P,C,Q-34`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,`
M``!8S!V.```#`%!,5$4```#___^!)F&"*&.$+6:,,FR1075S-%V'17"13'F:
M4X"M9)-/%SV,-7"80'J:1'YK,5A]/6>J5X^W9YW&A;&"*6:15'Z\<*2Y<Z-Y
M'F*A3(NT:*"<48JP7)RX:*1[(6>&,G.LJZRKG_MD5LN`==R8C?4V*,P\+LP_
M,,XO)HM(/,]-/]5?4>M93=A'/J=C5>%01KEA5MQ83L1A5M)>4\QR9OAC6-5W
M:_YG7=I[;OYR9^YO9.9K8=]L8=]Z;?ET:.QP9>5T:>IB6<=Y;?)_=/]Y;O%X
M;>YW;.Q]<O:"=OV!=OMN9=1^<_&#>?:*?_J!>.F/A?V2B/^0A?>4BO^+A<]6
M3<);4LI02+)?5L][<?+&POH[--9%0-)$/[!,2+QF8.=;5])U;_9M:=1[=^2)
MA?>DH/X?''\T+]`R+LPV,LP].-A*1N$P+I1=6>Y34,=A7>%O:_I:6,Y34;MH
M9.5Y=O]X=?F"@/J/C].0DM6[O/:_P?:#AL*)CL>TN_QX@\US@,NBK?*3T9*3
MR9&LY:F;RYF8R96NV:O3_<_;_]>4S8R-S(.<S)3"^KG"\KNFYIF5S(J:QI%O
MFF;%];J[Y*V:NHO)S,>#CW.FLY%K;S595TAS9CFPHGBXK(N@E8"9=3JJAH;_
M__\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#_;(+3`````6)+1T0`B`4=2`````EP2%ES````
M2````$@`1LEK/@```,%)1$%4"-=C8,`">'@$Q$0D9!3D)45Y^86$Q8%":3E%
M*67Q277UA='9N04EI4`AS7#_`/OREJ[.Q@H=4Q<O-Z"0GG>@JTK3E(G3IC>K
MFGM&V@*%G()]]6NZY\Z8-[^WTM+#P1@H%.1GK5W=KSASUM2>*CM'LS"@4("[
MKH9RZX39<R9W*%E9F(0"A7P,M=350MKZ)K5'.=M$&!D`A?)C,C/2LY(;:E,3
MBQ/RXF*!0FPL3,RL?%*R<M+<7)P<@NS8O`,`JFDR#,;OSH4`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8V$N<&YG````````````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#4P`#$P-3$U-#,S-S8Q`#`R,S$R-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___]75
MU/;S\N3@W\J[N-*XL]/#P,X=!<HD#-`D#=<I$=(N&.$T'=U$+\0_+;(Z*LU$
M,?]D3_)@3/ME4=171M9G5LAB5,QR9LYT:/V1@LYX;.2/@^"8CL:*@?ZSJ?ZT
MJOZYK_>VK<V9DLR=EOS/R<RKIG\,`,P;!,P8!<H<!<T>"=8D#8L7"I0@$>(W
M(=,S(<LU);`P(>Y#+[(R(Z<N(;DV)KPY*,$\+,I!,.%).-)%--5(-O=2/^!0
M/OQ81N550NY;2>Q;2/EB4/%@4,M82?IP7O1O8/US9/AT9?][:L]E6,QQ9=J`
M=>Z9CM2(?OBEFLJ&?=*+@^&9D.ZEG/&LH_FTK/VXK__'P/S*Q/3-R/K3SLVQ
MKLH2`'\*`,X4`]XF&-0O'Z<H&^LZ*_I/0L=(._Y?4.=62^=I7]2,A<T.`<P0
M!<\<$M@Q)_(^-<<W+L\\,_I,0MI#.KLZ,N=*0.I/1O]63?U:4?973O9@5^EA
M6?S/S/+.S-S,R\P)`)T=&?(Z-;\P*O]O:-+#P_[Z^MC5U?W\_.SKZ^?FYOO[
M^_KZ^OGY^?;V]O+R\N[N[NOKZ^KJZN7EY>'AX=[>WMC8V-;6UM'1T=#0T,S,
MS/___P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````&%!TD`
M```!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@
MP`+BU.OE&'LFL:G,F#Y%IL$^#2BDKE>LU-7![FJH-G627Z&0,U!(5Z`JO'U*
MC$96YN3^@#(11Z"0J6A3:*VW.">76$:40KFP'5`HU:LRN%DSEH-;/R]2L<+!
M&BCDZ5;BSZH5K\-KG*(:5FIC"13R<,J5GJ%LD)!L*]\94B1H`11RX<N1F#'-
M-]U=JJU7MH#?#"ADQ9/M,[V5I::ZA7EB4+ZY$5`H4;M.<NJDONB([@E,@8TF
M2=B\`P#8ES&H&P[$Y0````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]C9BYP;F<`````````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P
M,S0`,3`U,34T,S,W-C(`,#(S,3,T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#
M````6,P=C@```P!03%1%````____QTM-P517A0<B?@`>BR0_F#A3__[_?'N`
MZ>COX>#G!052!`0M"`@T$!!9(2%H)R=N-35Z.CI^1D:)3$R.4%"065F75U>4
M65F6:FJC:FJAG)RGT]/=YN;LV=G?V-C>ZNKO.SQN9F>>$AAB0TJ(T]3:P<G0
MQ,O1NLG#X.OF[/+M"6823)Q2`5H!`58!#5X-&&89)W$G+G8O*VLL.GTZ39I-
M/7D]2(U(28Y)0X%#49E13H].4Y-37:-=7J!>9*1D:JAJPL?"Y^SGUMO6Q,C$
M[_/OY^OGTM;2NKVZ"F@',G,Q<JMQ5J)1"UT`#EX#+FDF59A,69I0'6@2.7XO
M-G(M/'HS2(@^\O7QO\\0X.M.LKH`MKX%M+L%N\(8GJ,AJ:\HM+HNO\0TS-(X
MT=="S,H`S<L#S,H)U=0-X.$=U-,?6%@-IZ4;LK$COKTJRL@PU-0UZ>I&9F8L
M24DT8F);X.#?UVPAZWTO]HU0\XI0BCH4?2L*?"P*O6A*JU$UL%H^S```QP$`
MR0$!QP$!S`4%RP4%S`<'S0D)U@T-TQ`0WA@8TA@8X1T=Z"8FZRLK[34U]3HZ
M]4)"^$9&^D]/P4].V%U=RE=7VV1BW=S<_O[^_?W]]?7U\O+R\?'QZ.CHU-34
MS\_/IZ>G____````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````UIK!/`````%B2T=$`(@%'4@````)<$A9<P``
M`$@```!(`$;):SX```"U241!5!C3;<'!30)A$`;0;[X9W,5D)6LTF&A#-L&=
M4(4)-X_&`CAZ\VX+-F`!9J,<A,0`R_XS0P'Z'O"'H)E5K[W_+/N'2H7D-R$U
M#W63I>0-555A&%ZD<O/"L.O/O!((5C%_'NK=>C09>P@_'@7WD_7HV"VV=O$D
MM^+R9M"O81/:-=IIVX<[B-_]SH-"RMB/A]9AN&26+*&,J9UEWKT;VB%#O)"E
M.8_,A*&R$(I0<IJ9F?C'"5C=4/::?HW0`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V-G+G!N9P``````````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T,0`Q,#4Q-30S,S<V,@`P,C,Q,S,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____0
M-38`?0``?``%R`4)QPD-R0T*B`H2RA(8SA@8S1@1D!$?T"`?SQ\9FADGTR<A
MI"$PV"\JKBHXW3@XW#@RN#)!XD!!XD$ZPSL[PSM(Z$A&T490[E!0[5!7\E=>
M]EY>]5Y9Y5ED^61D^&1F]&5H^FAE\V5J^VIJ^FI%QP!&QP%'Q@-)QP5+QPE.
MR0U2RA)7S1A<T!_L\C7O]3K;X1W;W1W?Y"'BZ";BY";EZROEYROI[B_IZR_M
M[S7S^#[U^D+X_$;'QP#&Q@#(R`''QP'(R`/&Q@/+RP7*R@7'QP7,S`?(QPG.
MS@K0T0W0T`W6TQ#3U!#3TQ#6UQ36UA39VAC8V!C<VQW?X"'@X"',QP#+Q@#-
MR`'-R`//R@70S`?3S@K4T`WIIR_LJS7OKCKUM$+WMT;YN4KZO%#SL#[ZNDWZ
MNT^C&QNL(2&N(R.U)B:X*"BZ*BJ]+"S#+B[`+2W),C'&,##.-#3+,S/0-C7U
M1$+5.CKW24;;/S[A0D+Y3$KZ3TWE1D;J24GZ3T_Z44_Z4%#Z4E#N3$SQ3D[X
M45'X4E'W4U'T4%#T45#V45'___\`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````"XZ)A$
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+I)1$%4&!EE
MS\L2P3`8AN&THFGKO"!:ICK(,,7&K;D%%^'^Q,J,PU#)G[2)6/N6S[R;#Z&_
M>:CAM>*>*#^:96%T::Q./O)"TI6@*C9-"/<+AGR$2;O6$EB:ED[RTE$4826`
MT<G[#.N\TC_J@(`EG;ZPVL^,4(Y:4LK%,'UROL\".%J$D5$P']%'B'<T?JM#
MY2HE\O'P'IR+402ZMK6KQ"P9W$*^'0=6J*HVKLHF_6N3;R@AH*TQ]N^-@R\M
MK$^\.2-(*P````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O8V@N<&YG````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R
M,#,T`#$P-3$U-#,S-S8R`#`R,S$S-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$@````P(
M`P```%C,'8X```,`4$Q41=74U<?&Q\'"PK*SL]35U.#@W]W=W,W-S,O&Q>/>
MW?KO[?#IZ,9Y<<O#PK$5![4;#;(:#:@9#+<>$+4>$+,>$;PA$[4?$JD>$;XC
M%<,F&+PG&;@F&;XJ':TI';@N(;HO(\<V*,@V*<`T)\X[+<`V*H4I(=)"-<]"
M-;@\,=E).[@_--9*/KE!-J0\,L],0+E$.JQ!-^-62<Y-0L%)/L=,0;I(/<M.
M0\!*/]%11K-&/-U93<U42-E93;U-0Z-#.NIB5=!73,A32=]>4M5;3[9-0]Q=
M4M=;4.1C5]M>4^MF6LM83N9D6=]B5\%53,)73==A5L=94-]E6KQ53.1G7=YF
M6[I63.IN8^%K8=AI7]%E7.5R9^MX;<EF7<]J8>=Y;NM]<^-Z<.J#>NZ*@>R)
M@.V-A>NDG<N?F\6;E\:=F?7$P,>@G/G0S._CXK41!^5:4?CW]_____[^_OW]
M_?S\_/O[^_KZ^OGY^?7U]?+R\O'Q\>[N[NSL[.OKZ^CHZ.7EY>'AX=[>WMC8
MV-;6UM34U-+2TM'1T=#0T,[.SLW-S<S,S,K*RL3$Q+R\O+FYN;*RLK"PL*>G
MIY24E(N+BW]_?P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'XD+.\````)<$A9<P```$@```!(`$;):SX`
M``#"241!5`C78YB"`1BF3)ZLZA(?;B8O(B`FHZQ77`@2FF@7%V7AEY&N(ZJH
M:5-0!A2:U!<;[:84U-GA*ZEFZ%-2!12:T)P0:"(7RMX:HVYE'U+!"A1B+(@P
M2N/E:&ODY,[T]*]K`0KEESJJ9'6V-]57E69[>S%T`86*JC6DM4QY&FI2DQ(]
M;-F9@$*5;++"?+D!M>7)>:[6EMV]0*'Z%G%^,8G('*X4)P=C@YY^H!!+AZ"0
ME(*V>UBPL[F^+O,$H!`&```QMU`EO%&Q3P````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]C:2YP;F<`````````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,C(`,3`U,34T,S,W-C(`,#(S,3,T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____
MYNWF[_7OW.+<*(TA-IDO-H4P.HLT1:4^1)@^4*Y*3Z1)5[%05JU0)H8=(FD;
M,I`I*'$A*G0C+GDF+WLH/I\U,7TJ-8(M,X`L-H0N0)PW.(<P.XLS/(TT/H\V
M3*E"0I0Z1YD^4*Q&3JA&2IU"1Y,_3J)&5K%-4:9)6+)/6;)05:E,6K)15JQ.
M6K%16:]06K%25*),8K=:7JY79+5<.HDQTMC1RM#)Q,K#\_GR]?KT[/'KX.7?
MS<W,S,6_T<K$V-+-S\G$Y^'<?S8`S%<!S%H&S%P*SV(2S&,6U6D9T6<9E$D2
MU&P@UW(HW'DPL60JX8`YW'\[YH=!ZXY)\)51TX-']9I7^:!>Z)99_JEJ^:9H
MRU0`S58#RU8#S5P-S%X.RUX/BT$+SV(3U&H@G5$:TFTDIEDBX7XXNVPSQG0[
MQG4[\9)0ZY-3_*-D_*1E_J=H]Z%E]Z-F_JYTS,7`V-',S<;!X=K5]O#L_O[^
M_/S\^OKZ^?GY^/CX]?7U\O+R[N[NZ^OKZ.CHY.3DX>'AWM[>V]O;V-C8UM;6
MU-34TM+2T='1T-#0SL[.S<W-S,S,____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````[2X"
M?`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"K241!5!C3
M;<L["L)`%$#1-R\SYH,I%$.T$=R"(+@`:[?E7FS<AV*I"S!$4UI(()GW<;35
M6QZX`#\9V,#"I6XX<+"_MJ,\N2!`8N/FY"R(HLEB!PAS^^2Q6*.D692X+I`;
ME%(;/#"?4W3\(6L?-%G"EEAR-!V!A5B(ZG9&S"9(+X&8O)\607C=2U]68;S[
M0O48A%2%;CX0427-*@B@"+-\20TBTRXR+V41^-,;\%-;$+OK)%T`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+V-K+G!N9P``````````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,C`U,``Q,#4Q-30S,S<V,@`P,C,Q,S<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!(````,
M"`,```!8S!V.```#`%!,5$4```#___^2.3JM?H!B042::G";@Y+.M\B5?8]2
M0$^JFZF%;89Q4'>]K,%<4U^NH[1I5'^LI+C`M])F6Y"4BK]E7W\S)W5018<V
M+'A&/H9.1I.,AKHM)GDN)WHS+'\U+GXZ,X4X,GX]-H8]-H-"/(=)0I)(0HU(
M0HLZ-6].2)%?6:584Y!O:;1P:K-S;;=J9*=H8J-T;K9V<+AW<;EU;[9U;[5S
M;;%V<+6$?KMG8Y."?JV"?JQR;Y,I(W@N*'HO*7LP*GPP*GLP*WTR+'XS+8`R
M+'PT+G\V,((V,8$]-X=`.HM"/(Y-1Y512YE64)U:5*%"/G=>6*=@6ZA6499<
M5YY43Y!23HYD7ZM'1'I84Y1C7J=>69U?6IU<6)EK9K!I9*MN:;)D8*%O:K%M
M:*UR;;5H8Z1K9JAM:*IV<;AN::MW<KAV<;9W<K5T;[!E89A\>+MZ=K2%@;]D
M89",B,*!?K1\>:AX=:)J9XZ7E,:(A;)Y=IZ<F<F!?J9A7WR=FLB<F<0X-8!'
M1(Q85)YK::5J9Y]]>KN"@+F!?K6(AK=Q;Y1Y=YVDHLLM*WX\.X9J:9-;8:#-
MA7M_6E7-HIS+?'.F?WK?L*JN6%'5?G>G95_-?WC3AH"04T^Y;&>80#YF*BK_
M__\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!:7?W\`````6)+1T0`B`4=2`````EP2%ES
M````2````$@`1LEK/@```,%)1$%4"-=C8,`"./EJ9PCQ"O8[R<BI)<;K&@.%
M6"9.F35U$C.KA%.H=4E=<0Y0:-[L"=,G3YO+)-98VA2NU]T.%!+E8I_)SR;0
MX-(2$I1B4F`%%.(0D9XCW,O-H]0<E9!EEEH&%+)H-1!7M.V1E.I(,C+7C^P"
M"A6F:WK(VKM[^[7E9V?&:O<!A7*#E1WMW+Q\`ZLKDF/"BLJ!0M$JKK+.GCY:
M.H;UE7F6-@%`(75Y60<%5?^X#-.TFJK."`ULW@$`+)`QC7_:DP<`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8VPN<&YG````````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#(Q`#$P-3$U-#,S-S8R`#`R,S$T
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````%0````T(`P```'%,U5(```!@4$Q410``V@``
M_SDXWC8V_WL`C$I'_UI9_\X``.D``/\``.=Y>X0`B:48C(1Y_[V^QK6V_[W'
M__^-B]G:V=;;_^_O[^_W]_?W[________P``````````````````````````
M`%BW;1@````!8DM'1!\%#1"]````"7!(67,```!(````2`!&R6L^````2DE$
M050HS[7*.1*`(!`%T?[B*#JNX'+_FYI2:.H+NQH`:%)I03:;*=RE"W4YAZH>
MJ-O6NI[()'N_DE35A+?N[M->&AD^Q-]J_-`_8;P-5(HDRTL`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+V-M+G!N9P``````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C`P-0`Q,#4Q-30S,S<V,@`P,C,Q-#$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___\Z;3L`2```1P``
M+0``+``#2P,#2@,%2@4)3`D-40T*-PH24Q(861@1/A$?8"`?7Q\91QDG9"<A
M4"$J62HX=#@X<S@R8C([:SM(@4A0B5!&=T97CE=>DUY9BEEDFF1DF61EF65H
MFVAJG6HP:R]!>D!FF&5XEVH4/0`5/@$9004<0PD@20U8>4AMC%XK4!A!8R_@
MY"'I[B_'RC#.T33S]S[;WS[Y_4KJ[4GZ_E#T^%"DI!NLK"&OKR.VMB:XN"CN
M[C6[NRJ^OBS#PR[`P"W&QS#)R3'.SC3+RS/0T#;U]4+5UCKY^4;<W#[AX4+Z
M^DWEY4;JZDGZ^D_\_%#N[DSQ\4[X^%'W]U'U]5#1P1#8R!WBTRO/PC7UYD;>
MT4+WZ4_TYE'MW3KKW4S*HP73A!#00@W;3!W'(@#,%@?*#0#+$`70&`W8(QCB
M+R;L/C7T3$+E3T;Y5TWQ5T[X6U'(``#'``"[`@#(`0''`0&]!`'+!P/*`P/(
M`P/)!06\!07`"0?("0G1"@K."@K,#0W($Q#9%!36%!3`%1+9&!C/&!C1'QWB
M(2'?(2'2'Q_B)B;E*RO**2?M+R_I+R_L-37O.CK@.#CS/C[V0D+W1D;Y2DK9
M0T'[3T_Z4%#U4%#J6%?___\`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"5O-L[`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```)Y)1$%4&--MP=%M0C$,!=!K
MQW$>%+5B`R0D5F0I!F(%/BBMA%Y"[#@=H)P#_$/(M/LYG>OS6=?']6M7+@S:
MZ*%XJVTAHJUF,%1+S'5MK$0IYQ<82Q%+M3U^A93+<`CR\K)9OYV4G&?O8'SV
M3?>V9U9B,@L(NM\M4CD680H;`XS^T<=4T9R88X1#X#<WSIHE30_S`*.[":M*
MHH@9,?'&'RN!3RM6VIS+`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8VXN
M<&YG````````````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,C`U`#$P-3$U
M-#,S-S8R`#`R,S$T,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X`
M``&`4$Q410```/___]4U-L<Z.[*7*I1Q$;N7,NFX6?:"5W\2`'\0`,TB"<P:
M`XL7"L\D$O]W:/=V9<P4!<X?#=0M'\P*`)T@&?UM9,P(`<P)`:<E(?%44-1+
M1O]O:LT!`,P``,P"`'\``,T!`<T"`<X#`\P#`]`%!<P%!=$'!\T)"<T-"=0*
M"M8-#<X.#=@0$,\2$ML4%-X8&-(8&.$='>0A(=0@']0D(.@F)J<;&^LK*]@G
M)[`A(>XO+[(C([DF)MTO+]TP+[PH*/(U-;\J*L0M+<$L+,<N+O4Z.LHP,,TR
M,>$X..$Y.-4V-=(T-,\S,_@^/OI"0MHZ.N=!0.`_/OQ&1N=!0>5"0OY*2NI&
M1L8[._]-3>Y)2>Q(2/]/3_Y04/),3/U14?9.3OM14?E04/%04/975_I>7OUD
M9/AE9?]J:O___P``````````````````````````````````````````````
M`````````````````````````````````````````(DS8M$````!8DM'1`"(
M!1U(````"7!(67,```!(````2`!&R6L^````GDE$050(UV-@P`(4.$4C9#B\
M#-7D5'6-'8-C@4)<K&P"J2'"FG+*VD;6_C%)0"%>%G:Q:$LA<44M`PN_R,0H
MH)"D-+^4'1^/K+J^F5M8?%P04(@Y(\734%`$8E!"J`]0*#TUT)1;'FI0.),[
M4"@MVE)'0@EJ4("'"U`HV5Y/10YFD*^S+5#($^XBH$&N#E9`(1,-F(O"O=V=
M;,RQ>0<`\/HCW.:+KT0`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O8V\N<&YG````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#`T
M`#$P-3$U-#,S-S8R`#`R,S$T,@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P``
M`%C,'8X```,`4$Q410```/___Z$4%J49&J(9&ZXD):LK++LT-I$O,)TV.,I'
M2:<]/KY)2K%$1=986L-24]IA8])>8`$CA0$CA`HKBPTMB1@YER=$F2M+IBM$
MC#)+E3Y=M3I4H4UJOTACLDEDLU%MOV1]Q@<H?`DJ?`TN@1@VA1HZC"Q+FRM"
M?S51F#]>JS)*B#A1D41>H$]MMU%LL%9RN55OL6-O?D96:':%E72!D(&/GH"-
MG(J6I#I+7#Q-7D!0851D=65UAEMH=6]]BX^;IU)B<<VM`,RM`]&R!\^R$MN]
M%.C*)MW"+_78.N#'/O[C2O+93/WC4?'84-2_1LRK`']K`,VM`<RL`<ZM`]"O
M!<RL!<VM"=2S"M:V#<ZO#=BX$(MV"MZ^&-*T&)1_$>'!'>3%(=2W'YV(&>O,
M*]B\)^[0+Z>2(?+3-;*<*N'&.-*Y-/C:/OK=0KNE,OS?1N?,0>7+0L>P.\:P
M.__B3>[42>S22/_C3_[B4/;;3OO@4?G>4/;<5_KA7NG26?WD9/_G:/?@9?_G
M:L0/`,82`\47"<X<#=DK'<TM'Z(E&ZTN(^<^+[DU*L0[,,]"-?-00N121OA<
M3_)<4/___P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"3RDMT````!8DM'1`"(!1U(````"7!(67,```!(
M````2`!&R6L^````G4E$05085V6/,1+",`P$)5F."<F$#`T-O^`EO(8OY'7Y
M`PUT5&&P%2RCI*#)E3MW.W,`FR!<X=@?Y#5%\5450CT00-=T\Q23,'OO=PX(
MFGVOZ1V_Q,Q5<`(,S>,T2M9"A$14=$$7.?]%&)?6&`.)8JKQ0ZBY-73/29<9
M.7+%!(;Z&%:18Q.5DI\(K:B:V`BJI42$(1M!7DFQWFW[!W[Z^4PA53]1=0``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]C<BYP;F<`````````````````
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`U,34T,S,W-C(`,#(S,30V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____`AI-
M!"I\"2^`.UN?2FRU/UJ50UV55W&I15>`77*?97JH@IC)"2]^%#J*'#^))4J8
M'#5I.%RH/%F3/5B05'6Z1V.>6GBW5&ZB36*+;8G$:(.Y5FJ4>9+&=HV\@IO.
ME:*[765UEZ2]F*2]H*S%K+C1<7F)N\??R-3KS]KQNL39T-GKHZ_%EI^PR];K
MS]KM<W54SL[*LK*O___\^_OX^/CU[N[KZ^OHWM[;U-31S<W*BXN)_?W[Z>GG
MS,S*EX]T[.OHHW]3I7U1V-31K&,[KW-<KU(^M$@[OC\UV;6R^M;3RC8NP#LS
MP3TVV$E!QTE"O44_MD,]N44_X%5.XEE2Y%I3Q4Y(Z&-<YV-<WV!9X&=AXFQF
MY7%KT&IDXGARXGESN&=BR)V:MI>5P:&?\<G'S*NIW;JX^M32[\S*[LS*MA40
MMA\9OB4>Q2LDQS4NN34OTD(\N3DUO3PWUD=`KCXYS4M%P$E$T51.SU--M$E$
MU5E3U%I4V5U7UUQ6Z&1>XV1>FD1`Y69@RV%>Z79Q['ETZWETY7=R[']ZQFQH
M\(^+R9J8UZJHS*.AY+NYOB(?T**B_O[^_/S\]O;V\O+RY>7EY.3DX>'AV-C8
MTM+2T-#0S,S,Q\?'O+R\L+"P____````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````@L;W+0``
M``%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#!241!5!C39<]1
M2@)1%`;@__SWSBA,TC#YDB*2"B6!FY`VXJ9<D$\]"NH(6AF"@3"FB8HY]UP7
MX+>##[@A(&(3NBS2@T3D/EX+&D%![84G1PI%@J%%Y11Y:S9)[KU7%<+BK2B3
MYF='S<?K=]ND_MWB'(RK@_]5R^6CPDCJ4Q"EM);F.VWQ)6P_-U1`N*=)/4SL
M%Q?&N-F\"8O5HCON!CG3\O)'[W4#09^$5U7UI#4B/<'C[]T^_GL@LR3SB=L>
M;S^X`I[D3+>)Z+3W`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+V-U+G!N9P``````````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`U
M,``Q,#4Q-30S,S<V,@`P,C,Q-3$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,`
M``!8S!V.```#`%!,5$4```#____Z9VCW;6Z_6USQ@H/RW=Z^'"B['2NR(CS+
ML;BH56UI%#=+`B^7:I=2`&$_$(\L"J-H7JP$`7AW=KJ`?\6+BM*GIO:<F^8`
M`,8#`\L%!<H%!<<&!\D&!L0+"\D-#=$/$,P0$-,6%](8&,T='=L?(-<A(=\9
M&9TG)]X=':`O+^@D):PR,N4U->TK++@Z.^PP,,4X.-TV-=`R,L-"0O0X.,U$
M1?(Y.<U&1O<Z.\-,3/=&1N104/I/3_E(2>)'1^!14?=04/-24O%65OE34_%7
M5_%J:OI24K]45,%75\!=7<EK:]1H:,EN;LM\?.*,C.]\?-2#@]R5E?2+B^&4
ME.Z<G/";F^ZFIO.IJ=*VMMZMK<ZCH\+5U?G.SO&JJL.OK\BYN=+'Q]_5U>S@
MX/;%Q=C@X/76UNH#"<R-CJO$Q>R8F;?1TO>^O^!E:\F@I?2?H<J:ILRIL\_4
MU,W.SLC-S<?,S,;___GX^/+KZ^7HZ.+>WMC^_OG]_?C[^_;U]?#N[NG@X-O;
MV];8V-/$Q,"YN;7R\N[1T<W/S\O][>;'BX3H?G?/(AQ_``#$"0F)"@K*$1'2
M(""C(2'1+"S=,"^R*BKA.#C?.#CM4%#C4U/+5E;?8%_L:6CK=W;VV=GL[.S,
MS,S___\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````##5`+[`````6)+1T0`B`4=2`````EP2%ES````
M2````$@`1LEK/@```,%)1$%4"-=C8,`">(4UK-S=C%1D)*65U/4L;8%"O3Q"
M^6%!OEX>GMX^_@'!H4"A_JG=G?.;2\I*BZLK*\KK&H!"DV8QS>$JBH]/2$Q*
M3DE+3P4*L<R;.YU=0%9>6=/`VL75P0(HQ,HV>V(?OY2"JK:IG9.-L2%0B'GF
MY`G<>7Z!(>'B$1)BHB)`H1E3>KH6M#=5U=?4MC5VM+0"A:9Q\!461$9EY<3&
MY4;'9&<"A3@%,^04U73-'9WMS4ST=;2P>0<`8#8RK_S]W%@`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8W8N<&YG````````````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0V`#$P-3$U-#,S-S8R`#`R,S$U-P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___\6X
MNL.YN^79W/?K[MC-T-3)S.K?XN+7VO7J[;*HJ[VSMLB^P?+HZ_'GZNG?XL.V
MNO+EZ?'EZ<W"QL>YO\"SO,_"R\"RO&]K;C`K9D,]B59/J'1NN6IEGW9U@#@R
MDCLUDCLUD24A6C\XESTVDCXWDT`YE3\YDT`YDSTWC$0^F4(\E$0^ET=!FTM%
MH$I$GD(]B%%+I$Y(G#<S;E),GU=1J$(]?EQ5KU1.H%I4K#\[=TI&B$9"@&)=
MLV=AMU-.DVMENVYHOEM6G5%-C%%-BF)=IG1NPFEDL'ARQ6MFL%I6E']YS7QW
MR7MVQW%LMG9QOF-?GH%[RW]YQWIUP8)]S(-]S'ETOH%\RH-]RH%\R&YJJX6`
MQWUXNW!LIX%\O8N&S(-^OY&,TX^+T9"+S960TUU;?45"FD],I593HV)?LUA5
MH%!.BUE7EG1QPH%]T6EFJG%NMH.`SVEGHXJ'TH:#S(:#RYR9V6-B?F5D?6%?
MH%54BWAVO'AVNXJ(TXB&S%I9?G=VG(V-I(F)E]?.G=#%DH2!<<.XC.;;K\6\
MGKRPG<J]J]K/Q>1;-=)8,\=`']=++LE;1<<W',8U',T^)+U3/_-O5M5D3OI\
M9.IT7NAS7?9^9_B,>/___P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````$!*(S4`
M```!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````OTE$050(UV-@
MP`*4E:T#4V,\C#64U`VL'/W"0$(FWBD)_I8Z2FIZ,O:>H5%`(2G7Q.0`,UU%
M56TC._>@R'"@D&UT4KR<I*&6BKZ%DV]$B!=0J+B\OEF^.JTB(RNOJ*ZTI@`H
MQ,_7TBDHP=3=RB+$*LPIP@P4FC.KKW_RI"D3>J?-F#US^L2I0"$!]O8N,5'Q
MG@XN+@XV7AYNH%!A9GI#979C4WY)66U!56X.4,A44T':I2TNUB=8ULW9P<8<
MFW<`C7`PN%65#=T`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]C>2YP;F<`````````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P
M-#8`,3`U,34T,S,W-C(`,#(S,38R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#
M````6,P=C@```P!03%1%````____[>OM_/O\^_K[^/?XWMW>S<S-R<C)RLK+
MK*RMW-[@^OS]T-+3Z.OLS]/4Q\O,S]34]_S\T]C8R<W-S]+2\?/S^OO[^?KZ
M^/GY]O?WZ>KJT-'1Z_/QKL2UN<"[N,^^@Z>)N\&\J,FIK<.MP=7!\O;RS=#-
M]?;U]/7T[>[MXN/BU=;5QL?&T=K0]_?VX>'@R<G(L9R%[.?CR,"[PTH&OT@&
MOTH*PGQ4TI=WQYI_UL2ZV,[(P4D(PTD)R507V79%QW!!PFU!V8)7WYMYQ(MM
MZ*N-R*:5V\&SY,N^RTH0T9N![LJY\^[L]>_MW=K9[>OK^_KZR,?'Q\;&^_O[
M^OKZ^?GY^/CX]?7U]/3T\_/S\O+R\?'Q[N[N[>WMZNKJZ.CHYN;FY>7EXN+B
MX>'AX.#@W=W=W-S<V]O;V-C8T]/3T='1T-#0SL[.S<W-R\O+RLK*R<G)R,C(
MQ\?'QL;&P\/#P,#`OKZ^N[N[N+BXMK:VKZ^OKJZNI*2DFIJ:D)"0B(B(?7U]
M?'Q\____````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````4\T<F@````%B2T=$`(@%'4@````)<$A9<P``
M`$@```!(`$;):SX```"_241!5`C78V#``AJ;ZDI#HM-RBXKSLU+CPD.`0DWU
ME5$:R:)%Q46\W-(1H1%`H8::I'`^81,!$4$;3U]Q_7B@4*V,>("UNY.%E:6+
MCX1D;#I0J#10S-_1S-S4R\%8*#0F)1<H%!FAS>]J9VOO[.;'$YF4HPL4"DO(
MXE0R\O;0DV66BM<Q+`<*:646<,@KRBDHJX7&9N2750&%TO**2]C5550U66(,
M<DLKN8!".45!A3EL3*S,D8G9P175M=B\`P##=RT=9`&`3@````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V-Z+G!N9P``````````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-P`Q,#4Q-30S,S<V,@`P,C,Q-C0`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____&
M``/9*"FE`QFC#BIS"$!M$5)I$E`V$'`U%'77U]@%#9997\(%$)4,%I,P.:X`
M"%T.%V(1&G$F,:-06\8`%*`!%9T)&YL-'Y\*%FH2):48*ZH8*:$G.*HA+84P
M0*\J-HXX2+@X2+9!4+L[1Z)(6,)&5+!79LQ+6*U>;-%D<M5H==AF<])J>-AT
M@-E35W2OM=T,()X?,:908,=B:Z3GZ?-YA[^PM,7&Q\?@X-_-S<SRY^;.`P/0
M!07.!P?/#0W4$!#;%!3>&!C;'1W>(2&C&QOB)B;F*RNK(2'H+R^N(R.U)B:W
M*"CL-36Z*BJ]+"S#+B[`+2WO.CK(,C'%,##J.SK.-#3*,S/R/C[0-C7T0D+5
M.CKV1D;;/S[%.3G@0D+X2DK0/S_E1D;Y34WT34WI24GY3T_Y4%#Q3D[M3$SX
M45'T4%#V45'D3T_Y65GT6EKDV=GEV]O^]/3\\O+V[.S8S\_2R<G^_O[]_?W\
M_/S[^_OZ^OKY^?GX^/CV]O;U]?7R\O+N[N[KZ^OHZ.CGY^?DY.3AX>'>WM[;
MV]O8V-C6UM;4U-32TM+1T='0T-#.SL[-S<W,S,R=G9W___\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!\'[!B
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,!)1$%4"-=C
M8,`"A`PF6S+6M_=.FM3?U=9850$4$A0V-:MI[9DX:4)W>U,-8RU02$J15]^0
M>\*DB3T=S76,U4U`(7EU'5$!30OKOLZ6AHK*1BN@D*J>AK(LCY%Y6:%-27%I
M43E02%=+Q5A"C(^=.2PUOR`O*1XHI*TF)RG.R>KL$9F2FQ83$@`4,E&0YF>S
M=W(/3LS.BHL(\@$**<EPL=@YNOK%9F0FA`?Z>@*%1#B8;!U<O*+3<Y*C0OV]
MW;!Y!P`6Z#!B',3\:`````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O9&4N<&YG````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R
M,#,T`#$P-3$U-#,S-S8R`#`R,S$S-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$@````P(
M`P```%C,'8X```,`4$Q410```/___]`U-L<Z.^=G:#H[.\:0`,>2!=.>$,V<
M&*R&(>RZ-=ZQ.,ZD-/?'1LB-`,F/`\J4!<B0"=&7#=RD'=^K(=*>'Z1\&^JS
M+Z^&([B0*+N0*L.:+M&D-?;!0N&U0N:W1OO(3_K+4/'$3L>:,/7$4,>$`,:%
M`\R*!\J,$M:5%.*C)K:%)MB@+\"/+>^S.LN8,]NG/OF_2NZW3/C!4>ZY4,@,
M`<<,`<X4"LD7#=DB&-,P)^4U*[XS+,DZ,?-'/M5".OI63>I12>A02/9:4?EK
M9,L``,<``*T!`,@#`ZT#`\\%!<P%!;('!\<)"=`-#=<0$`L!`;(2$KT4%-(8
M&-L='>,A(<\@(,HF)NDO+_$U-9,A(<8P,,(O+^$X.-(T-/5"0M@Z.OQ&1N)!
M0.1"0N5&1L<_/OY04/I/3_5.3O104.-*2ME,3/575^-14=E04+Y&1O5>7O1E
M9?YJ:A,*"A8-#1`*"B$8&#0K*R\G)T<^/C`J*E!(2%5-35E145!)26!966MD
M9&IJ:F5E95Y>7E=75U!04$]/3T9&1D)"0D%!03@X.#4U-3(R,B\O+R$A(1\?
M'QT='1D9&1@8&!$1$1`0$`T-#0D)"04%!0,#`____P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````+ZCH,8````!8DM'1`"(!1U(````"7!(67,`
M``!(````2`!&R6L^````M4E$0508TV7/L4T#01`%T#_S=P\P(!*@(PJ@"R,'
M!$@$2%`$<F`28OJ@#)"($"(Q3GQWOIW]2P%^'3Q@CP%XOGMD=YCGJSK5T(,#
MR_+D.:?YBZ+5!B3<_V0KV_B\_J`YS9#P?;%<K+>C\E<^FE$3'&^\^1NF(.D6
M9=S!<:M^-Q6FS*YCO%88KC1*S=WIE-3>$S9CJ+E;HC<U"8:3JG8\G/8\MUB?
M:=,;+J,:+75,I1X,TN_^!__K3%8FB"AF+`````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]D:RYP;F<`````````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#(`,3`U,34T,S,W-C(`,#(S,30Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____
MT1$2Z"\P_VYO_6YOQ[N\RL7$__GXY^'@S0$`S```?P``S0$!S`$!S@,#S`,#
MT`4%S`4%S0D)U`H*U@T-V!`0BPH*SQ(2SA45WA@8WAH9TA@8E!$1X1T=VQX>
MY"$AU"`?G1D9Z"8FIQL;ZRLKL"$A[B\OLB,CN28FW3`OO"@H\C4UORHJQ"TM
MQRXN]3HZV#,SRC`PLBHJIR@HZSDYX3@XU38UTC0TSS,S^#X^^D)"NS(R]4-#
MX#\^_$9&P38VY4)"_DI*S3T\ZD9&QCL[_TU-^$M+[DE)_T]/_E!0\DQ,_5%1
M]DY.X$='VD5%^U%1^5!0_E-3\5!0\E55\514_UI:_5I:[E55[%14^UU=U$Y.
MZ5E9_61D]V5ES%Y>SE]?U&QLVW%QU'!PY'Q\X8"`[HF)S(2$T(>'UHZ.S(F)
MW:*B[+*R^L+"_\G)T+^_V,G)Y-75\N/CX=/3_.[NY=C8TL;&_O'Q]NGI__/S
MS,+"UL[.X=K:U<_/U,[.^O3T^?/S^/+R[NCHZN3DTLW-SLK*S<K*]O;VY^?G
MX>'AV-C8T='1S\_/S<W-S,S,____````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````E\[#
MR@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"[241!5`C7
M8V#``GAXE%SSVE-EA+@%Q11T[+U`0K(V<;D=B<+<_*)RZM:>@4`A<>.8V)RN
M!#Y>$2E5*[<`#Z"0231+:'9//!>3/+-M4'B('U"(K;*BN*6O*K^@L*BDO**T
M#"C46,]9U];76EW35,_1T%S+#A1BC324S.I-EC9U#XN*\'=V``H%:TD(I'<G
M*1LX^7C;6>II`H7,@"[*Z$H!NLC7T4)?6PTHI`AT469G&M!%+N9&NAHJV+P#
M`"^2*\LB&S\E`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+V1Z+G!N9P``````````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,C`T,@`Q,#4Q-30S,S<V,@`P,C,Q-C``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!(````,
M"`,```!8S!V.```#`%!,5$4```#____N1TCXYNC4RLO5U-7Y___X_/S!PL*R
ML[.RS\;9Z>/!R<3U^_<->2`%:A(@<R-*G$T`70``7```.0`#7@,%8`4%7P4)
M80D-9PT-9`T0;!`*1`H29Q(8;!@13!$==1TA>R$?=!\?<R`?<1\951DG=R<O
MA2\A72$J9RHXAC@XA3@X@S@R<#)!C$$Z>CL[>3M(DTA(DDA0F5!&AD97GU=7
MGE=>I%Y9FEEDJ61EIV5HJVAJK6H"8@$E=20H>"<P@2\P?B]!BT!FIV4.80<4
M70DC:!@960HD7Q-1AC[@X-_5U=3-S<S2T,QE0Q)A/@UI,`%F+0!E+0/OY-[8
MM:>2-A2N1RRT;6'FMJZIBX;$KZO]]_:=&`;YZ.:I$`/'E9"D%`KBM[3,``#,
M!07B65CGY>7>W-S.S<W^_O[]_?W\_/S[^_OZ^OKY^?GX^/CV]O;U]?7R\O+N
M[N[KZ^OJZNKEY>7DY.3AX>':VMK8V-C6UM;2TM+0T-#/S\_,S,S*RLK'Q\?$
MQ,2_O[^\O+RYN;FPL+"GIZ?___\`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#.J!:V`````6)+1T0`B`4=2`````EP2%ES
M````2````$@`1LEK/@```+M)1$%4"-=C8,`"1$14]6W,=`1XZFHJRPJS,D!"
M\KI6YGI*'E'I5>5%.8RY0"$930M+0WO_F'"6M.(\QNPBH)"&B;6Q@U^<.Y=O
M:D%&9J$74,C`QE3++3F0/S(ED3TCO[0:*.1L[J3LFA3$%\\4P99;PEH/%+(T
M4I.R#4BPXV8&&E3APP$4,G:4%15R"0T+B04:5-O8`A32EA,7%I-6]`R.!AK4
MT-P*%%*1$!:55%`7Y,TM\:YOXFS#YAT`3U8K9Y<4FGX`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O96,N<&YG````````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0S`#$P-3$U-#,S-S8R`#`R,S$S
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/__
M__E04;T`#L(%$[X%%,08):4A*[$H,[PO.<<T/]4X1-5"36-=8"`2P3@MN5Q0
MY%Q1W1`#O3$GK3PPSCXTPTD_U0<`Q&5DXVQIU0$!S`D)S`T-SB(BTB<GV"LL
MPC(RS#,SQCHZVCDXT41#XDE)[DA([$E(YE!0^6!@]F1D_6AH]&NLLV:^N3Z5
M@4!Y:)F;FF*#:I.:E#M..EIN3V5Q75UD6$A,1:[!?Z2T>+C#?FAR'%)8)XB/
M)\S*`,[-!,W+"M;5#=32(*>G(=W<+^OI/.#@/N?E0?[^2G5U(_+R3/W]4?'Q
M4-341O_^:(F(0<S&`'][`-#)!<S&!=C2$(N'"M+-&)20$>'<'>3>(9V9&>[H
M+^'=+).1'O+L-;*N*K*O*N'<./CS/OKT0KVZ,KNW,OSW1I.0*\;".__Y3>[I
M2>OF2/_Y3_[Y4/OV4?GT4*>E-Y62,?;Q5Z>C/OKV7NGD6?WX9/?S9?_Z:K&N
M5,K'9\"[6\._8ZJF5]//<-S7==71=^#<B(R$(Y*.4J"4+6EE0JB>@I-T6(![
M=YQ^;=2'7LA5*).'@^=K4J6&A/!*1H)M;,P``,T#`\T)"=8-#<8:&>`='=0@
M'Z<;&[(C(^XP,+\J*LHP,-4V->I&1O544O___P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````!CR
MJ4T````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````O$E$0508
M&66/O0X!41"%Y\[]L2+81"$B2I52--Y"IZ;Q%IY!%!I/XCU6(T%'PU;+[MZY
M,V[O5"=?ON(<@+\H6$"SD]9Y$0*BM4EC;P!<JTN99U;81^L0#)@DE>](#_&5
MDW/H(WJ7.9>#:^;=---:***Y$5^>2Y*Z-[/"X:1@PK[B(5.0]KTKQ#<$";6(
M+)9V)1)\8-#@JR*HAQM/JLLS=OHJ:'EAM?L0*KWEZ%<*#A07H2G2]3$"ELW?
M'8`?S+ACH*V`6H0`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]E92YP;F<`````````````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#(P-#8`,3`U,34T,S,W-C(`,#(S,30P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````2````
M#`@#````6,P=C@```P!03%1%````____.SH[-C4V:VMLXN+CQ\?(3$Y3(B0H
M,3,W0$)&4E18:6MO`@4*"0P1)RHO.SY#$#5G&E:E&U>H$39I&E*=&E*<'EJJ
M'UJI'UFF(UVJ(EJC*&.R)5J@*F2R&CUM(DE],&:O,&:N-W"^.G._-VVT*E"$
M0G>]/6VN28'-383-.F"13G_!6Y':!0@,58?+16VC7I/95XC)3'6L9IK@9YG=
M9IC;8Y/478K'7(G%9I72;)G7<J'>:I+&>:3>=J#8?:CB%!<;%AD=35!44E59
M1TI-'R`@LK.S[.WLX>+AU-74.CHY04%`U=74S,S+9F5E_O[^_/S\^OKZ^?GY
M]O;V\O+R[N[N[.SLZNKJY>7EY.3DXN+BX>'AV-C8UM;6U=75TM+2T-#0SL[.
MS<W-S,S,RLK*Q\?'P,#`O[^_O;V]O+R\N+BXM;6UL+"PJZNKIZ>G:FIJ7EY>
M6EI:5U=75E9645%14%!03T]/3DY.1T='1D9&0D)".#@X-34U-#0T,S,S,#`P
M+R\O(B(B(2$A'1T=&!@8%Q<7%!04$!`0#0T-#`P,"0D)!04%`P,#____````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````DW(?Z@````%B2T=$`(@%'4@````)<$A9
M<P```$@```!(`$;):SX```"_241!5`C78V#``@0%U8P=K'64)(4DY%2T#$V!
M0B(*!G8V1JI2PN(RRIJZ)F9`(7EM6WM+#5DQ46E%=7US*PN@$(<K#S>GHQXO
MGQ._`+N+,Q=0B*F@N*:UAZ&GH[FVJJRBN@XHY%_HX];-T-O9TEA=7E;%W``4
M8BEK:.OJ:F^JK2PI*JWVK@<*>?IE9F=GLL6SAGM$)Z;GY`&%8A)24A)CHT(#
M`T(B$]*R<H%"7LDI27$Q84&,P1&^J1GN^=B\`P"K\"Y5BU[=!`````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V5G+G!N9P``````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-0`Q,#4Q-30S,S<V,@`P,C,Q
M-#$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#_
M___#&!K%&1J'&1K&OK_5SL]965LV-C?"PL5&1TGU]OAH:6K'RLSL\/+W^?K)
MR\S#Q<8B(R/W^OKQ]/3.T='-T-#[_?WZ_/SAX^/=W]\?(!_(R<C&QK4V-C5-
M34Q'1T9:6EG)R,'?V\33Q87*N7/MZ^+3QYK3M%3>Q'/@T9[KX<#+PZG+P[[&
MOKO'``!]``!\``#(`P/+!07(!07("0G0#0W3$!#.&!B0$1'<'1W@(2'/'Q_+
M(2&:&1G&(R/I+R_5+B[M-37=.#CU0D*X,C+X1D;1.SOB04'#.SOZ3T_[4%#U
M4%"L.3GP4U/R5U?U7E[W86'H7%SE6UOT963S967[:FKC:6GV=77BVMJDGI[7
MT-#)PL+X\?'OZ.CMYN;;U=70RLKZ]/3LYN;$P\/\_/SW]_?V]O;U]?7R\O+G
MY^?EY>7DY.3CX^/2TM+1T='.SL[*RLK$Q,3!P<&ZNKIN;FYL;&QH:&A04%!/
M3T].3DY&1D9"0D(_/S\X.#@U-34T-#0R,C(P,#`O+R\N+BXJ*BHI*2DH*"@E
M)24C(R,A(2$='1T;&QL8&!@0$!`-#0T)"0D%!04#`P/___\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#A
MPUMR`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+Y)1$%4
M&--MS#T.`4$8QO'W:W:Q=ED1)U`JG(5$G$&CTW$!%;U(=!J%A#LH5+0JB4;K
M:^R,,3W_\LF3'\!/"$V,HUC?[B83D5#4A@!S8?&MM<V869$@$!RJ%6;'^V,4
M)4E<"$"@$R*^\LN&V[65`T)OI8$-S+.<<^ZJE%'FZE\N()Z7#!*VB&7E+0SE
M0?KA,#,B2KI^2M9IO3:\G$^77K*-5GEOC4K2GUAS-Y9(A'E`,./^]&.U_0`N
M",<$?_H"][(]I"TOU:``````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O97(N<&YG````````````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R,#4P`#$P-3$U-#,S-S8R`#`R,S$U,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$@``
M``P(`P```%C,'8X```,`4$Q410```/___Y8Q-*Q05,AV>[ER>I=88G=-;I5T
ME*>+J8=QD&!MIH.2RH&2QF%UIEU[M3]:C$]PJD9AE$ADETQHG4YKGU!MHE9S
MJEAUK%]^MGJ?X7N@X'"0RGN<V5Z'S5-SJ66)Q6J-R59]N6N9X'.=W4^9*U>9
M.%V;/FNK3"AS`"IW`V*G/G>P5S)T!3A]#4"`&&NG0G.P37:P3W>O42YP`#)S
M!3U^$$F('4V,(5J8+U^<-6^J1FZD27>P4':M4'JN44N!&#UP"I6V:H^;3%]@
M#7%K(WUV-'YR/;MJ"L)Z(\:!*Z%X1?.V;JMW0+I;![E=!_&M;+E?$LQ[->N@
M8H4_";U@&<>"2]1]1:YO1[A("KE)$;Q0&W4\']I]3\]M0+8\"K4^#-QX4.2#
M7MJ"8,]S5KQ$(L%-,+980NN&;+,H#*<H#.:#;=5#*N5:0L=/.J!#,N]G4&X5
M![LE#;`B#[0G$,<Q&KXQ'<4W),,[);HV),<\*<Q!+<E%,M-)-=9..\M30^)@
M3NIH5.IK6.%W9[<:!KT>"F\4"+4@#K,B$+DD$K4D$;HI%KPL&GL>$L8Q(;LR
M(80E&94V*MU20=U;2ME92^MK6]QI6N!O8NEZ;G01"+0@$<`C%;HG&NU?4]UG
M6^IX;ZY#/,!.2?___P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#5ZO\````!8DM'1`"(!1U(````"7!(
M67,```!(````2`!&R6L^````P4E$050(UV-@P`)F%L:X.^FHZ9N:Z)I96%G;
M`H7:)BR8WQSAZJBII6=N:6!D!Q3JS4_.2*R9DQ7BXJ"J;6AL`Q2:&!8P+RBT
MHWUV7YJOL[V&.E`HW2<I+M4CLZNL>M+<J2G>;D"A[.!PSRB_DIZJNH:FQLD+
MV8!",V*]`OTCN\MK<PNFLW+Q"0*%IN5%)\1WEN9,8>'D55"2%P$*U5?.:FGM
M9^;@D591Y!<7%0(*5105,[%SRRE+R<I(2H@)"V#S#@`;)C+Q94(]]0````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]E<RYP;F<`````````
M````````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`U,34T,S,W-C(`,#(S
M,34Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````
M____>UU@AVEWJK@HM,,KWN@F[_4ZT=DSRL\S^/Y*R,H`RLP#S,X'UM@4XN4F
MYN@KM;DFS,XMP,0M[_(ZV^`^W-X^^?M*[?),^/U1^/I1[?%0T=-&^?MD^?QH
M]/9E^OQMQ\0!Q\4!RLH%S<P*T,\-R<<-T],0OKX4V=D8V-88V]P=W]\AY>,K
MZ>DOI*4A[.TUOKXLQL<PKJPJR<DQSLXT\_0^\O`^T-`V]?5"U=8Z]_=&X>%"
MP\,[^OM-Y>5&^?A-ZNA)ZNI)^OI/^OI0[N],\?%.]O=1]/10]O51Y>19TM)6
M[^]LB(8*\_!CY=U-Z>)FGY<\I98.HH\7H84EC&P1P:ISM)-%NHPUNHQ.PW\\
MS)IOP%<&QEL'V'$CCDL9JELAZ8$UP6TNVWXXWH5"]Y=0Q%,"TF$0CTT>M6$H
MS'$T]8Q&R5\9[XY.JE<IC652]X)>Q2L`>QL`QRX#QC()SS<-CRT1VD8=SD8?
MZ%@O]&E"MT\RXF1!^71/]'10](9EE59$;#DOR```QP``?0``?```R@,#RP4%
MR`4%R`D)T@T-TQ`0SA@8W!T=X"$AT2`?FAD9I!L;ZR\OKR,C[34UNRHJQS`P
MW3@XT38U]D)"^$9&YD9&PSL[^T]/_%!0]5!0\E=7^VIJ____````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M@*2J"`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#!241!
M5`C78V#``EI:)\Q9N&!Z3T=S>W??E%GS@$)%9=7U!345)87%I>655;5U0"%?
M8R\?;R$U1245+5US!T]'H)"^C%Q8?@@/-R\?OXBXE*L84,A6(2"J(5!#65W'
MP-K%S<84*"3O%YW'Q!RNJJUGZ>QA;V$$%)+UC\QHC(_0%#"S<W>R,C$$"DES
ML`2%!K.RL7-)2HAR"@L"A9)S8M)BT^,2LU-S4[*2,A.`0OV=36U=O9-FSIT_
M>\:TJ9,G8O,.`!]E,O'N;H#)`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+V5T+G!N9P``````````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C`S,@`Q,#4Q-30S,S<V,@`P,C,Q-3(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!(`
M```,"`,```!8S!V.```#`%!,5$4```#____A(23Y45;*25K47&U=:XR`FL`4
M>+@GB<4,=*@YF<L0=J97KM`CBZ]AMM)>K\,VAY-EN\@-<7T4<G`YBXIFL+!`
MBX9$CHF-R[AJK)59FWUMKX=9F7!VKX-AG&X`6Q`)8!9AG&EMIW8=="0M>"\Z
M>#L`6@``.```-P`#7`,%7@4%704-90T0:!`8:A@121$=<ATA=R$?;Q\94QDO
M@R\UB#4X@CA"DD(R;C)&ED9!B4%/G$]0G5!0FE!7G%=>HEYEI65JJVIDG&2(
MP8@N:"I3GDU7GU%>FUEIJ60/10HR@BM%DCY/DTA/E$ESJ6Q\LW64G"'&SR_<
MYCK)TC[D[TK;Y$SE[U';Y%#`R4;I\FCW_E;*S0SEYT'HZD;Z_$[X^E[,RP'-
MS`[2TAK4U2#7UBC!P"S,RS+)RC'AX3C2TC74U#;9V#KEY4/'QCON[$GKZDG^
M_E#V]D[Y^5#Z^5+V]E?[^F7W]V;__VK,,`#=6"_@9#[R<TSQ=E#,,0///A*Y
M2";$4"W/5S.],QKF=F?,``#.`P/0!07,!07-"0G6#0W8$!#2&!CA'1W4(!^G
M&QNP(2'N+R^R(R.\*"B_*BK'+B[*,##A.#C5-C72-#3Z0D+E0D+J1D;_3T_V
M3D[Y4%#___\`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#GP_ZF`````6)+1T0`B`4=2`````EP
M2%ES````2````$@`1LEK/@```+-)1$%4&--MP4U.`D$0!M"OJ@N;&=`1$A>@
MF+A!EU[)*W@%#L"!7)IX!O9N6!A)",+873\<0-\#_B`\8;R_L[ZW*DE$TKN`
M\N#65??1<DK,!,%#322;W9'SY)$*90AR1U[N/V_\NQGR*!R"16N'\M'QQ>0P
MGE(U,)KMMOY:>:X:RE_N8,3UT`>71DMM9WJE#D&6+NK+ZHW+:Y]S!`3S'[5&
MU,GGYNH&P<F,$J^;Q&8>$?C'&9V64*IQ1UZL`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O9FDN<&YG````````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0U`#$P-3$U-#,S-S8R`#`R
M,S$T-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410``
M`/___\W,SL'!QL7%R?'Q]._O\<;&R/O[_/+R\^_O\-W=WMK:V\W-SL+"P[>W
MN`4181`;:R$L>34_BCA"A30]>T90F4)+C#M">E!:GTY7FE=@GFIRK7I_HI.8
MNIJ>N:JNRP<591TK>!TK=S9!?T%,C5!<GE=BH%YIIF9PJ7Z'NF9ME82*K&QP
MB+"UU*>LR;*WU;W!VP458PL;9@T<:Q`?;10C;!DH;1PI;R`O=Q\M<R`M<R<T
M>2@U>2T\@R\^B"HX>3`\=SM*CT)0ESA$?CY*B$%.BT)/C$92D4]<H%!;D%]J
MH55?C7)]LGB#MH>1OZ.IR9:;LP068P068@<890D;90P=9PP<90\A;!LK<5=D
MG4U8A&AUK%YIF'6!MFUXJ6]ZJ[6WP,[0V;_!R=S>YN3F[K_`Q,+#QOK[_+*S
ML]35U-75U/[^_OW]_?S\_/O[^_KZ^OGY^?CX^/;V]O+R\N[N[NOKZ^KJZNGI
MZ>7EY>3DY.'AX=[>WMC8V-;6UM34U-+2TM#0T,[.SLW-S<S,S,K*RL?'Q[^_
MO[R\O+N[N[*RLK"PL*>GIYV=G924E(N+BW]_?____P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`%6RKK\````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````ODE$
M050(UV-@P`(F3.A-UU)W3VYI::RM*LG+`0GU=;+ZJCHDMC3559<6,!8"A?J[
M*G*];<S3FNMKRHH8\TN!0KJ!AOJN9N':LCIR`7H&"O)`(0D9:9'(T&`!02%A
M,4DI<5&@D*:&JE584(B)DKVSIYJ'BB-0R#_>R\78*,(M*B;.+R'6)QHHQ,7#
MQ&RA:)G$R9'!QLW+QP\4JFYH8;<VM4O)RRFN;&CKZ`8*936WL-@J.Z4R%I9G
MM[9G]F#S#@#PGR]>Y"("30````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]F:BYP;F<`````````````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(P-3``,3`U,34T,S,W-C(`,#(S,30Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````2
M````#`@#````6,P=C@```P!03%1%````____G8N1KI.>IXZ9WL72E8J08DQ9
MN*BSFW^3BFF"O["\H)N@9UQHR[K-O[3%@&F.T<?>?G>?J:'+<G"+FYK':FN(
M4E:54EJ9<7^SM,C499.JK\_?J]#A:9NP:IJO;)VQ=Z.V<9RML-#=L,'(>+/(
M<*6X:YZP;9ZPA[_3<J"PA;G,=J2UE\WAC+S-<9>E<YBEG<[@=YNHFLC8G,K:
MI]3DIM/CA*:SJ]?G?IVIJ=+BF+W+E:RU<*[#:J.V;)^P;)ZO<:6V;Z.S;J*R
M;J"Q=JJ[<Z6U<*"P@;/$>ZNZD<?8?Z^^<)FGA;7%A+3$98B4BKG(D,#0;I.?
MD+_.>Z.PA*Z\E<33>J"M>)ZJAJ^]@:BU?J6QG\_>AZVZI-+AE\'.B[&^J=;D
MG<;3K-CFH,G6K]GGI]#=IL[;M=SIM,?-:Z"P>[/$=JBW>ZFW?JRZA;/`@:VZ
M;9&<@*JVC+?#I]CGDKW*J=CFJMCF;J.QKLS4G*RNT-[=L+2?RLVKPZE?N[BQ
MX:5`[K%-O;JVVZIKV,BTSGLOYYYBJZ:CQZRDZJ23YXIVZI:$XJ"3NT<TT%]+
M]8!KZG]JPFU>[XIYWX1SE&)9YJN@J5=*['UM[(1TUWAIN89_][>NOT<X@3`F
MQHN(=4I(M'IXQ:2C____````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````ZCQ=VP````%B2T=$`(@%'4@````)
M<$A9<P```$@```!(`$;):SX```#!241!5`C78V#``MAYQ28*\O%+RCNKJ6KJ
MEJ0"A>9/F35I]M1Y"WSL+)G:ZZ5,@4)SIW7U3^B;TZMOR];:T-AA"!02X6"=
MP<TL(*Z07577UMP4#!1B$1:=*23!R:6H75G;V9(9"A22D;4V5Y*6*_+S4NF>
M/IDG#RB4D9+OF%61XQ$84U[=4Q,;#A1*+];1L'?SUC-)+%->:!-B`!0JS757
M=_(,,#9+3HN/C#8J!`H5:#FXN/J&Q5E8)25$103Y8_,.`*'P,O$,[RM8````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V9O+G!N9P``````
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T,@`Q,#4Q-30S,S<V,@`P
M,C,Q-#<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4`
M``#____%"`G""0K`$Q7!'"'**S"_+3*\+S79/4*X.S_#047E3U343%#745;K
M6V#F7&#H:6WH<'2T(RJ\+37)/4774%>\2U')45CC86C.6F"S3E3F:G#>9FW?
M;G3J?X6G,#NP-T&S2%*K.$2V04W`35C+6F7"7FCZ^?J?CZ"6AYJ4AIC2R=?*
MPM"[LL*&>I&BFJVLK*W=[OFCOLV_W.RIPM#)Y/3'XO&\U>2GO<JIO\N\T^#.
MYO2)F:+*X>ZQQ="[S]K5Z_?.X^^TQ<^(L<>4OM2QT."4K+B=ML.EOLNZU.*N
MQM/%W.C,X>S6Z_:/M\G8[??(Y?'!S,S$SLZ^Q\?O]_?&S,SW_?W\_?RQL:_\
M_/OU]?3Q\?#AX>#>WMW;V]K.SLW-S<S#P\*YN;B+BXK[^OC,R\G+RLC^_?S[
M^OGW]O7N[>SJZ>CIZ.?=W-O3TM'/SLW'``#+`0''!07,!P?3$!#,$A+<'1W4
M)R?C04'S5U?<V]O(Q\?'QL:YN+B;FIKZ^OKX^/CU]?7Q\?'M[>WIZ>GFYN;@
MX.#>WM[3T]/2TM+1T='0T-#.SL[-S<W+R\O(R,C'Q\?#P\.[N[NXN+BOKZ^D
MI*20D)!]?7U\?'S___\`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```:WB!F`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+M)
M1$%4&--MP4%*0F$4!M#ON_?'0/0%U<"!H`-1*DEP"\U;0//VX3+<A`MP#R).
M!)UH$#RJ03Z4"E[OWML"ZAS@#V+*?+UYF+4&MUZZ64P$\"#CIV38T3T$"8O/
M*V&0Y3[\X%9#PK:V[8A;_?6]4&W&"0F[%'EQ_W(BJ4HS)'Q'59K'D:I*MT#"
M3?;6?F:GQP\A[3+F"5WMYY7HV?F%B(@0@N&H407YE:VN.1J/EQ"(@"',XE'O
M"O()__@%?$5-+`"L)QH`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O9G(N<&YG````````````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R,#$U`#$P-3$U-#,S-S8R`#`R,S$U,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$@````P(`P```%C,'8X```,`4$Q410```/___]`U-N[M\0``QP``Q@``?`,#
MR0,#Q@4%QPD)R`T-R0H*B!(2RA@8S1$1D!\@T!D9F2<GTR0DQ"4EPR$AI"DI
MQS`PV"LKQ#`PS2HJKC@XW3@XW#(RN#DYRD%!XCH[PSLZPTA(Z$9&T5!0[5=7
M\4Y.U5Y>]5E9Y61D^61D^&AG^F5E\V9E\VIJ^F5EY7EY\X2$^,?'R\/#Q\+"
MQM?7V\_/T\[.TM[>X<;&R>_O\-O;W/K]_L[3T\C-S<;+R^GN[OG]_?7Y^?/W
M]]_CX];:VN7FYM+2S]'1SLO+R,G)QNSLZN'AW]C8ULO+R=[>W=G9V-(8&-\A
M(=LD)*0;&ZPA(>DO+Z\C([4F)N4S,K@H*.PU-;LJ*KTL+,,N+L`M+<<P,,DR
M,<8P,,XT-,LS,_,^/O5"0N]!0=4Z.O=&1ML_/M`\/.%"0OE*2OI-3>5&1NI)
M2?I/3_=.3OI04.Y,3/%.3N!(2/A14?=14?104/E65NU34_986,>PL,VVMM6_
MO]_)R>G4U/+=W>_;V^/0T/?CX_;BXLC'Q_O[^_?W]_;V]NSL[.+BXM/3T]#0
MT,W-S<S,S,K*RLC(R,?'Q____P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````+*-43(````!8DM'1`"(!1U(````
M"7!(67,```!(````2`!&R6L^````IDE$0508TVW!P4T#,1`%T#_CC6-C*RC%
M<$-1"D"B!"KB2A6((B@!T0E9>==CSZ<`>`_X0Q!1[L]?3]?E_?(M^73WJD"N
ME0_;!HHN)44LB*4X_5A)B34=&Q0YA]["@"<YI3PZ%M326C#XI!3Q;8>B[GWM
MX/P8DF)_(Q3#?FR0GR4$;?N+06&K3?+P>'-A'VY0;&W,<""?;=K>;4)Q&Z;!
M2499IT_B'[_D,UD(NIC:?P````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]G82YP;F<`````
M````````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,#8`,3`U,34T,S,W-C(`
M,#(S,3,R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%
M````____(3QC*$1L-%)]4'&@`"=>!2QB!2QA$#=L&#QM(4=[-5F++DQT.%F&
M1FF:0F&,3FZ;!RU:"2]<'SE9)T)B+DIK-5)T576<#S1?$SEE(TAS)4AP-5F#
M.UE[2&N32VJ.576:0%E:+4A(+TE),TY./%144&IJ1EE95FQL3F)B8WM[5FIJ
M<8F)<XF)<8:&=XV-8G=V`$,`09=!7J]>`6L`!&T#"F\)#G8-$E41'H,=('X?
M,),O0Z)",WHR4*M/4:A09K%E!FX`.IHU/X8[;KIJ!$4`!$0`"W(%#'`%%GP0
M'GP8)XHA'6`9/9,X3*A&5JY07*Q7(WL!(WH!*X(*+8`-(%<*.8X81)$G2ITK
M0'LJ7:T^:K=-8ZI(9*M);;=1<:]9?;]DP,0`O\,#Q,@'Q,<2SM(4W-\FGZ$A
MTM4OZ>TZUMD^\_9*Z.M,\O91R\Y&Y^I0]?AHR<@`Q<4"P\,"R\H#S<P%R<D%
MRLD)R\L*T](-QL8.U=00UM89S\X8WMT=X>`ATM$@T=$HXN,LZ^LO[^XUN[PL
MR,@PT=`TW]XXQL8RTM$V\/`^]_="T],Z^OE&Y.-`XN)"Q<0[Y^9&_/Q/]_=.
M_/M0Y>5)\_).Y^=*]O50]/12\_-7]_=>]_=E]O5E_?QJ____````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````Q)2KM`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"?
M241!5!C39<_!4<-`$`3`F=F53J:$'[QY\N+A,!POX1"$H2@P%J>[VR4`=P8-
MW"'.G#>N8T2=I6WEF^-2)OOY7'I0$K\(QXO/[&U$RB1:PO%4E+5'2C0I`X[7
M8__XK<UGGQZ*Z@;A<5S_]F9NODS>]H20^_?>Z>;+4K)E@CBU$:DQN2S5(MZ)
M8X^@1+NM>3W<,HCG45DHU4-&S<S+_0?_:99/2P>OJLH`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+V=E+G!N9P``````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,3(Q,0`Q,#4Q-30S,S<V,@`P,C,Q,S,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!(````,"`,```!8S!V.```!@%!,5$4```#___^(-39Q<''__O\Z.SM?8&"5
MEI7Q[>QJ``!G`0!K`0%I`0%L`P-K`P-N!05M!05K!05P!P=R"0EN"0ER"@IO
M#`QU#0UP#0UX$!!T$A)[%!1T%!1_&!A^&!A\&!AX&!B"'1V&(2%](!]D&QN*
M)B:.*RN!)R=J("!K(2%]*"B2+R^"*BIM(R-R)B:),"]T*"B6-35_+2UW*BI\
M+2U^+BY[+2UY+"R:.CJ",C&`,#"$,S.0.#B(-C6&-#2>/CZB0D*-.CJE1D:2
M/SZD1D:60D*G2DI^.#B;1D:I34V:1D:J3T^>24F<2$BJ4%"B3$RJ45&E3DZI
M45&G4%";2DJC4%"R9&2S9V>U;F[%OK[=U]?.R<G#OK[[]O9$0T/.S,RSL;%8
M5U?=W-SQ\?'=W=W4U-3+R\NGIZ=J:FIH:&@U-349&1D3$Q,"`@+___\`````
M````````````````````````````````````````````````````````````
M``!MGMGA`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```*))
M1$%4"-=C8,`*LEDS$MWE!3CY)94,G?R``KDY69EL<1K"G+SBBMH.WL%`(6;V
MM)2T!!,>;E$Y-7O/(!^@4'HJ2W)2O!&7D+2JA5N`OS-0*":6(RHZ4DL0;%"@
MJQU0*"(\1$=&3`!BD!>3%5`HS%==@H='5!9LD*.E.5`H5%^*CQ-FD+69'E#(
M1@'B(A>00:8&FD`A91&8BSQLK8QU5;!Y!@#='R"B:9:M$@````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+V=I+G!N9P``````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C`T-``Q,#4Q-30S,S<V,@`P,C,Q-#0`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___]Y$A/:-C?/<'&/
M3D___O_5U-7'QL?*S<W^___4U=7&Q\?!PL+GY^;@X-_-S<S(Q,/Q437Y7D+\
M74;E64/Q9U>KGIW_5D^]GIW,``![``#.`P.)`P/0!07,!05V!07-"0F="`C6
M#0W8$!"1#0VX$A*O$Q/2&!CA'1VO&!CD(2'4(!^X&QNG&QO`(2"P(2&8'1W/
M*"CN+R^R(R.T)26\*"B_*BJ6(2''+BZ%'Q_*,##A.#C5-C72-#3`,S.P+R_E
M0D+J1D;^4%#V3D[<1D:.+BWY4%"<-C:(,"_,4E'\:6G\;F[I;&S,:&BT86'0
M='.P966.4E+QC8RY;V_=AH7$>'C/@8'@CX_QH:#2BXNUEY>OH*#X]?7[^?GX
M]_?=W-S/SL[^_O[]_?W\_/S[^_OZ^OKY^?GX^/CW]_?V]O;U]?7R\O+Q\?'N
M[N[L[.SKZ^OJZNKIZ>GGY^?EY>7DY.3AX>':VMK8V-C6UM;4U-32TM+0T-#.
MSL[,S,S*RLJ[N[NRLK*GIZ>=G9V4E)2+BXM_?W____\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"[/6X\`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```+U)1$%4"-=C8,`"VMJ:>1BS
MRJKKZFHJ2G-2DD!"+0V9:<55XC&UE65Y:8SI0*'6QJ+D_.@@*S=6R8(,QM0\
MH%!3%5MN0J"2NJE65'92<@X_4(@#:%"BI[0"DX5_7%)62350*#Z-CYO30U;5
MT"&`*[V0O1XHE)Q?42NHJZ9O[^H;FU<NP`L4B@QE\?,R8A85\_8)C@@/"P$*
MV6C(2\FI:`N).+LXVEF:&0"%=!2E9)0UC84EW)ULK<U-]+!Y!P"2/BT;-=4)
M*0````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O9VPN
M<&YG````````````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0S`#$P-3$U
M-#,S-S8R`#`R,S$T-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X`
M``,`4$Q410```/____E04=535-:NK\;'Q^#@W^G1T,T!`,P``,T!`<P!`<X#
M`\P#`\P$!,P%!=$'!]`)"<T)"<P)"<X-#=0/#\\2$ML4%-@4%-(8&,P8&-(<
M'-0?']0@'^0B(J<;&]@G)[`A(;(C([DF)MTO+]TP+[PH*+\J*L0M+<$L+,<N
M+LHP,,TR,>$X.-4V-=(T-,\S,]HZ.M8Z.O)$0^`_/N=!0>5"0NI&1NY)2>Q(
M2/),3/904/%04/M75\]+2^A75\I-3?UD9.ID9/EM;?UQ<?9S<_]Z><QA8?IY
M>/^!@?I^?OB`@/V<G.&.CO^DI.&9F<Z-C?JSL_ZXM]*7E^ZSL]ZHJ-BCH^>V
MMLRDI,ZFILVFIO;)R>&ZNOK0T.[+R]2UM??6UO_BXOSIZ<R_O__W]__Y^?;R
M\N7AX=+.SM#.SL?%Q?7T]/[^_OW]_?S\_/O[^_KZ^OGY^?CX^/7U]?+R\N[N
M[NOKZ^CHZ.3DY.'AX=[>WMO;V]C8V-;6UM34U-'1T=#0T,[.SLW-S<S,S+N[
MN[*RLJ>GIYV=G924E(N+BW]_?____P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````$@G7?P````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````O$E$050(UV-@P`*ZNMI94Z/]@Y.;&VHJ2O)R0$(=+0D>IC)"4@&U
ME:4%C(5`H<Y6=A=+!1%N+M'0LB+&_%*@4%N=GXV*&"^'@+A]=DYN"1M0*"O%
M55=:F$]00LXX*2<M/0,HY.T5'A\5$<D2$Q?KYNS$[``4<K0,:VQNJJLJ*TJT
MM3#4T00*V:C:-3?75Y<7Y_A8F1AH*`.%="7YW3-!+@JR-M/74E,$"LD*<?(8
M^88$>C*9ZVFK*\EC\PX`V#0N,]O3E\@`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]G<"YP;F<`````````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(P,S,`,3`U,34T,S,W-C(`,#(S,34Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____U34VQSH[_V=H
M?SL\S%]ASF)CS61FUFMLE$Y/X7AZU'1U[HF*^IB:NW)SYXZ/_Z&C^9^@TG9Z
MY(2(L&EL\I28O'-VQWQ^X8Z1_**FY927_JBL^J:H]J.F]ZBKS&9KT&EPS&=N
MV'1YTH2(2;U64L5?8-%M2YM45*=>;M%Y9;UO9[EPC/"7BNN50KE.*7,P1KU2
M1;I11[M34,5<3;U95,%?8-)K1)%+7L9I<>!]<=]]7;)F;<AV@>N+@NN-B.Z3
M?]R(BN>3F?&BU-4@S;T)X=(XTI<8S'\!YZ)`]K-7SG4-\9M0V'(GS%@%_XUJ
MS",`S1$!W3\OSQL2^F=>S`8`S0$`S```S0$!S`$!S@0#S`,#T`4%T0<'U`H*
MU@T-S@T-V!`0BPH*SQ(2VQ04WA@8X1T=Y"$AZ"8FZRLKV"<G[B\OIR$AN28F
MW3`O\C4UQ"TMP2PL]3HZRC`PLBHJS3(QTC0TSS,S^#X^^D)"VCHZX#\^_$9&
MY4)"_DI*ZD9&_TU-[DE)[$A(_T]/_E!0\DQ,_5%1]DY.^U%1^5!0\5!0U$9&
MZ5E9_61D^&5E____````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````?856WP````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"T241!5`C78V#``@P,+'2<
MG;3,C/0-3<RM[!R`0JQ<_/*R`CP<;.R<W+Q\@D)`H:22GMZFK(3(B+C4S(J&
MCD:@4$XWBT]0<G18;$I&45U;:S50B-G?R\W=+S0F,3V_IJ6]M@PHU!?BZ>(:
M$!6?EEW9W%G/5`P4ZFWR]?8(A!I455H(%.K*"XX.AQE47I`+%)(45E)05!81
MDY*1DU:1$!<%"EF:&JNJJ5O;Z^HYVFK;:&I@\PX`*X8P#Q?/^D8`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V=R
M+G!N9P``````````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`U,``Q,#4Q
M-30S,S<V,@`P,C,Q-3(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.
M```#`%!,5$4```#___^(AYI!0*-*2;@[.I);6JF1D-4``%`*"H@,#(D.#H@.
M#H<1$8X6%H\8&(L8&(D:&I`='9DD))HO+Z<W-ZDP,)0Q,94M+8DX.*,T-))"
M0K<V-I8N+GP[.YXC(UU`0*@[.YLF)EY&1JI24\)!09I*2JI$1)E45+M96<18
M6,)34[986+Q<7,%<7+E45*!J:L=M;<=@8*IL;+QQ<<-X>,YW=\IF9JEG9Z=_
M?\MP<+-K:ZEJ:J=O;ZUN;JMN;JIM;:E^?K]Y>;9X>+1V=J]34WN.CM&-C<]Z
M>K*/C\Z&AL%]?;2(B,.`@+5K:Y>=G=IT=*&6EL^'A[J;F]68F-&0D,:0D,2&
MAK9^?JNDI-Z>GM:FIMV6EL>5E<:LK.&JJM^EI=><G,JLK-R;F[B=G;J>GKJ>
MGKFFIL*@H+NHJ,.@H+JRLLVTM,[!P=RMK<6LK,3#P]R2DJ7.SNB=G;'0T.FG
MI[O5U>[1T>G2TNFQL<77U^[%Q=J]O<6_O\:\O,."@H?*RM'$Q,NVMKR3DYCQ
M\?CIZ?#?W^;<W.//S]7-S=/#P\F^OL3S\_GQ\??N[O3FYNSAX>?:VN#!P<;Q
M\?;DY.G5U=JSL[?S\_?%Q<C?W^'DY.5X>;&DI=SHZ>_GZ.[-SM.JJZW___\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````C;_PV`````6)+1T0`B`4=2`````EP2%ES````2````$@`
M1LEK/@```,%)1$%4"-=C8,`"..2;U0TL8SWLK6V=?$*BXX!"2J[3@MT3\U*3
M4]*S<XO*RH%"]0MF39\2),##S2<LRJ*EJPT4DO7N,6%VF='=U3EQ7N_D_JE`
M(5;VN0K\8A;F5HZ>_I%1H;Y`(;>DF4:J,N)R:GJ&IF;&;/I`H9:VAMJZFL:.
M]M;>O@GS)S4!A70D!;DX>85$I%4T-905I22`0F&S'6SLG+T"Y\0GQ(1'!/@!
MA?*STC(R<PI*JBJJ*TN+"YFP>0<`3[8RW<:V1_4`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O9W0N<&YG````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R,#4P`#$P-3$U-#,S-S8R`#`R,S$U-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___]38VWR^Y(+#
MYQ50;1=.:2=\J"9XHBA\IRAYHRU]I2^`J2)9=3%^ISB$JD*7PC^0N#V(K2M@
M>C%JAD&*L#5QCSESD#QWEDV7O#YZF$N1M4)_GD:$HTN,K4B'IE*7NE>@Q$Z.
MKE*4M4N(IE>;OV"LTENCQU*2LDV*J%*1L&BVW5*/KE:5M5J:NE20KEZAPDZ%
MH&*DQ5R:N6FMT&:HR6.DQ&ZSV'"WVG*YW'&WVW&XVVZSU6FJRW"TUFVPT7.X
MVW.WV6ZOT':VUG6TTX#"XWV]W7V[VH&_WH"^W7:OS("[VH;"X(C#X>[R]/3V
M]U>IT5.AQT6!GD5\EE&/K6>QU5R>OF^]XVNUV6>KS&^SU&*<N&JHQLW2U#^0
MK4N8LS.)IC2*IS>-JCZ5LUREOG&VS83'W(W0Y^7IZL_6ULG0T-'7U]_EY=OA
MX?C]_<[0T/7V]LC-R[6YM[W&P:&NI>WQ[K/%MY*AE:2PIFJ#;'Z3?L32PVR&
M8GV.=J"SF%MQ2W&&8FV`7\')N[3"IXN:?'F";'%]7X*'3ZZP?]G9U\7%Q,C$
M6,;$A).2?Z^KH/[^_OS\_/KZ^OGY^?+R\N[N[N3DY.'AX=34U-+2TM'1T<[.
MSLW-S<S,S/___P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````&8_-,<````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`)8V41T
MT@NFS9@S)U]0($`['"C$)FSHG98S??:<6;&2@:&6%D`AWF`OS]3LKJ+RF4SJ
M:E:.)D`A\6@?IY3BFH[VRC+S"`=[`Z"0OJ^S:GQ%2T]W8QVS=929,E#(P]U(
M-*ZDK:^WOIG%SE17"2CD:BO-EUC8VE!5Z^\6J1<B#Q2R4>#G2LCJ;*HNS7,)
MTU*1`0HI"G%S)&5.G3RAWR]&0S-(`B@DR,/)GIP[92+CI`QC.5DI,6S>`0"'
M>S$FD!!Z%P````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]G
M=2YP;F<`````````````````````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`U
M,34T,S,W-C(`,#(S,34U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=
MC@```P!03%1%````____@WAZE'V(4DA:<%Z'64IN5TY]3DEH;&6.241F+2=>
M5U**.#9?0T6`$!=8&21C(2QM%"%@5&*@$R9F`!A=!1YB)S^!/E*(.TZ!`AYD
M!B!@!R!@""%A"2)B"R5D#"=G#"5C#RAE$RQK#1Y)$RMH%S!N&#!K'#=W'C5P
M(CMY)3QU+$-Z,4F%+4-Z)#9B-4V)+3]N-4J!.E*++3]J/U>2,T9V,D5T/%.*
M.4U_.$Q]-TIZ1%N51U^9-DAS/U.%/E!^1EN.1%B*1UR/4&:?1UR.2U^35&NB
M4VF@3F.736*546::5FRB4VB=56J?5VRA56F<7'"A87:H8G:G9WRN76^=:'RL
M:7RL;'^O:7RJ;H&P`10_`A0^!21H!2-D%"]M&35T$R9/'#9P(T"`(CQV&RY:
M-$N!3VRK2F2=/%%_15N/46NE4FRE4FNC3&*65FVB25V*5&J>67"E:X&S`"-H
M`")F`R5J!29L"2IM#2]S$#%U'3Z!'SY](4&$&S1G(CML(3EI+U"0)C]P-524
M*D-V*T5W,$I^,$I]-$^#-E&'0F&B1F2B/UJ/1F*94&ZK266<4&REA*:C>*R>
M8Z^58K>65\247ZF"0+)F2)IBA(AAN+1AG(N(8UE9____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````;U)/-0````%B2T=$`(@%'4@````)<$A9<P```$@```!(
M`$;):SX```#!241!5`C78V#``J*C4S.+BXP38DO+JVJ;N_N`0C&)=I'!62E"
M_''*6@:V[A.`0BHFH6%>.B(L<P0T=&T\_/N!0OH%$0%&\=PSIK.)F[KX>/<`
MA1RB`B4TQ;BF36'FR_#Q=>X`"H4'.6HKB7),G#2;)]?/3;(=*!22IZ<J*\4[
M>2J3<+ZGO74K4*@P35U.1D%PYBS.'&\G*_,FH)!%DJ*TO%HR.VNVKZNEF6$#
M4*BFHJ2LLKJQ*WU";V=;2WT=-N\``-'-,:4?]D9.`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+V=Y+G!N9P``````````````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C,P-@`Q,#4Q-30S,S<V,@`P,C,Q-C4`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!(````,"`,```!8S!V.````!&=!34$``+&.?/M1DP```"!C
M2%)-``!Z)0``@(,``/G_``"`Z0``=3```.I@```ZF```%V^27\5&```#`%!,
M5$7U``'P``'=``&Y``0`A4``A#T`>3@!A3\!@#X%B$,+BT8&B4(8DDX`@C<`
M>S,`BC8`BC<`B38`AS4`A#8`@3,`@34`@#(!@S0!@C0!?C(8D$D`AC0`A#,`
M@S(`@S,`@C(`?3``?#``>"X#@#,#?S,$>3$%=S`6B$$?E4U$G&4"?"X">BPR
MDU4SGE,WH%8PFDPYH5)6K5=>M%Q7KE1CM%UUOUUQH6&%QF=UO%&$QEB)QEQO
MD5*BTVJLWTZCTD^WW%;*\$.]WT/'YC[(Y$K%V#+8[$G<[3OM^3_G\`'2V03N
M]B_Q^#?\_Q'__P#^_P+__P+__P/__PC__PK/S@O__Q+__Q3__Q[]_A_\_2'_
M_RRYK@6HG0B1@0F3?B>/<0>28!F#2P>0/`*3(0&;'P=@.#.F&0RV"@2A"P=O
M*B?_``#^``#\``#S``#C``#>``#(``#\`0'[`0'Z`0'Y`0&B!@0```#___\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!FCL>B````=W123E/_____________________________________
M____________________________________________________________
M____________________________________________________________
M`*F?I&4````)<$A9<P``"Q,```L3`0":G!@```"M241!5!C38RC%``RE*6:&
MZFQ*BI(J8*"L!A3*38UULC7B8963%@0"`66@4$%F?F)PF+N=L0:[B+20H`I0
MJ#@SDZ$DSB,@Q-O>1(I%7@LH5)29E9G)E!SM[^L?ZN5HK@,38DR/\?/U#0QW
ML]&$:,QF3O#T#8IPM=+E%M8&"A5FYB5%^40Z6QAP\<I"C,])BW=QL-3C%)41
M`CJ"'^2(#&M3?0X^!3$),!!7!0IA``"[$3VDNWPD8@````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M:&LN<&YG````````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0V`#$P
M-3$U-#,S-S8R`#`R,S$U,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,
M'8X```,`4$Q410```/___]')Q<NXLLV:CK\A`+XA`'<4`,`C`[\C`\$D!,,F
M!<(E!<`E!<`H"<<L"\DM#<@M#<(L#8,?"LLP$,0Q$L8V&(PF$=4\'=0\'==!
M(<D\'\@]'\D^()XQ&Y0N&<U$)Z<W(>).+^)0+ZDZ(YXV(;`^)M)++[-`*.53
M-;5"*KY'+KM&+;A$+*E`*L-+,<!),-=3.-93.,E.-,A.-,5,,^Q</LI/-<M/
M-N]@0NY@0M!4.K-(,O!D1MQ;0-99/O%C1]Q;0=M<0KY1.[U1._1I3=]@1N1D
M2>)B2/1K3_-K3^AF3.AG3/-L4.MH3NMI3O)M4?%M4>YJ4.YK4.YL4.=J4,M=
M1NQQ5^MP5_!W7N!P6?-\9.]]9>Y]9?:":O6":O:EE,R+??#2S+\@`<0P%M$V
M&,U!)]]'*_-D2NIF3O5J4_!I4?9N5,E>2LA?2^MR6_5_:-9X9N:EFLV]NK\8
M`,(E#<LI$,4M&,(P'-9-..=D4,M@4,A@4.9[;/>+>L=W:^J4AMNQJ_;)P^5)
M-<-$-.]40L]30_-B3_-C4-M^<]:!>.*CG-&:D^6LIMVHH?S-Q\NXMKX6!<`:
M"=<M(=G+RLR[N\S,S/___P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````';]H%H````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````OTE$050(UV-@P`+8V>5=XB.,RB>R\8A(:=KZ@H3$;6(C':5K
MZKD$))0L/8.!0L)Z4=$>::43BOE3T\U<`]V!0JIA!56%>17,3(U%F1D!/O9`
M(>>X\,KJJ=-8NKJ3$CK\G4R`0C&1=K*36G+;.AM:VT/<+`R`0M$>"D+)*3U]
MM4UUV>[6^KI`H5!U4<Z2Q"F]^?TYWO:F.FI`(4,Q7E;NLLG-#EE^3L;:&HI`
M(1D^5@Y!264KKR`W<P,M%3ELW@$`[LHNBB'-(\8`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]H<BYP;F<`````````````````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#(P-#4`,3`U,34T,S,W-C(`,#(S,34W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____O$%#O5U?
MK$A,P:2ES41,D0\@H4U?@S5)I*"A<CM761L]7A5!QJ:\52=+1B50@F",4C9<
M>G+`1T&K``"%!06)!06'!P>'"0F)#P^+$!"2$Q.2&!B1(R.?)269(2%_'Q]X
M*"B(-#6N)R>"+BZ2+BZ,.#BH-#2;-366,S.1.SN?0D*L/C^84%##4E+$3DZZ
M2TNR557`24J/6%FI4%&79&6P)2>E+S&1,3.11$:^3E'!5UFA<G3!=7C%=WO,
MQ<;'[?+RS='1^?S\]_KZ\?3TSM'1RLW-^_W]^OS\X>/CW=_?Q,;&^?KZ]/7U
MP\3$O+Z]T]33T=+1R,G(Y.3BTM+0_/S[]_?V]O;UY^?FTM+1Q\?&V]?6Q<"_
M[-O8R7IVQZ:DY'-OYZFGS```?P``?0``S04%S`4%T`T-U1`0D!$1S!D9W1T=
MX2$AFQD9Z2\OB1P<[S4UX3@XU34U]4)"N#(R^D9&Y45$Q#L[^D]/_%!0]5!0
MK3P\]E=7\596^%Y>^61DZU]>Z6!@\V5E_&IJ]6AHS5E9Y&QL]WAXP%Y>QF=G
MPF9FTG!PPFQJT79TQWY^T8F)V\G)^//S]_+R[NGI[.?G^?7U[.CHY.'AS\S,
MU]75Z.CHYN;F____````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````23J=>P````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"^241!5!C39<\Q2D-!
M$`;@?W9F7GQY6Z6Q,&"91B%'$,2#!'(601!L@YY!2&WO`=+8"7:6B9'$[,O,
MK`?(=X,/.$&84SO,95?,F$54[@7007=\X";Z&2=F@B#GCB*UO4@G@Z0.P?.3
MUY%O@QY;"Y)W$&[.O/F[F,:Q6[*:VIO@'$[&1L,5CQ)10<+^+AI=?\C*ZN'V
M0`[!SZ+DNOV^?M6K]4M3`H3)O@_2\>?D-YFYQQ<C&UBY7.X$CHJZ.?W@'WDC
M2?S6C&JF`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+VAT+G!N9P``````````````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`S-P`Q
M,#4Q-30S,S<V,@`P,C,Q-C(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8
MS!V.```#`%!,5$4```#____7&!GH*B[T/D+[3D^Z"13!*S3704ON3UCOA8O#
M("R\,#K&-4#:1E'I4%OK7FCK96^RJ]BFH,:,@.,E&+Y%.-!`-,,_,[M31NE.
M0M1&.KE=4.U:3N5U:N]B5^6&A<@``,<``'T``'P!`<L!`<D#`\@%!<L%!<@)
M"<<*"LX-#=`-#<D*"H@0$-,8&-@8&,X1$9`='=LA(>`?'\\9&9HG)],K*^4A
M(:<O+^DP+]LU->TZ.O,J*JXX.-T^/O-"0O4R,KA&1O@_/]]!0>)*2OTZ.\--
M3?I)2>I(2.A/3_I,3/%04/M14?Q04/514?9&1M-04/!75_)35>9>7O596>5D
M9/AH9_UE9?-J:OLH*\Z<G=9XBKA?9WMYDKJ0L+6!F9IK=G)57DZWL)'&OJ%I
M8D_JTL;%HY?(``#'``#&``#+`0')`P/&`P/*!07'!07,"`C("0G1#0W-#0W3
M$!#*$A+-&!C<'1W?(2'0(!_,(2"D&QO7)R>L(2'J+R^O(R.V)B;8,"^X*"CL
M-36[*BK!+"S#+B[`+2W,,C'',##=.#C1-C7.-#3+,S/V0D+8.CKW1D;;/S[A
M0D+F1D;M24GK2$C[3T_Z4%#N3$SZ45'Q3D[U4%#X4E+M4%#\9&3\@7____\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````"Z-$J&`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```+A)1$%4&--MP=])`T$0!^#?S,[NA5Q4\J<"L09!L!$;\<52
M!!OP-36D#%\$)9`@'B:WLW.[8P'Z?<`?A&M:+==Z&+*F+LZZ^99!EXN5#6?5
M*)+BC,&8+S;M-.0IB,34Q0)!O^;R?;.[YYKW*4T&P?L'C?YF%+8<`]4*PM)S
M,'K@4%X]N?L/X67\'//5<2*^*V9:GP1^T-+.ST1TZ[6Y07`\E1KEL;_H6K$R
M53"^3%E"ZI.HUE8;_O$+H\56K>VUSH4`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:'4N<&YG````````````````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`R,#(Q`#$P-3$U-#,S-S8R`#`R,S$U-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/____[V]Z:@
MH=74U<?&Q]35U0!O``!L``-R`P5P!05O!0ET"0UZ#1!Z$!A[&!V('1^#'R&(
M(1MG&R)Q(R>`)R%L(2^8+RF`*2V%+2AV*"I[*C69-2Y_+C"$,#2(-#B2.$*G
M0CF0.C:(-D:G1D*80D:?1D^O3U"L4$ZG3DJ?2D*"0E";4%VN75&545VC76RZ
M;&NT:W&]<6ZU;O/V\^;IYMG<V<?*Q_O]^_G[^??Y]^KLZNCJZ-;8UM36U,_1
MS\G+R;[`OC:--4J+2<K,R>?GYK0``+,``'$``'```+4#`[@%!;8%!;4)";T-
M#<$0$+T8&+@7%[<7%X01$<D='<TA(;X?'XX9&;HB(GX8&-<O+\DM+=LU-<XX
M..1"0JLR,M8_/\4Z.N=&1M)!0;8[.^I/3^M04*,X..504.114>175^Q@8.=>
M7MM96=U;6^EC8^9E9>YJ:MIH:.QT=,S"PM#'Q\_&QLO"PMS3T]K1T?3KZ^?>
MWOWU]?ST]/'IZ=_8V/'JZM/-S?CW]_[^_OS\_/KZ^OGY^?;V]O+R\N[N[NKJ
MZN7EY>3DY.'AX=C8V-;6UM+2TM#0T,[.SLW-S<S,S,K*RO___P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````)$J:H(````!
M8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````JDE$0508TVV,2P[!
M4!1`[[?:4DP,+<0.+,>T"1*)6(0E6`3;,2`BC32O??==G7.&)R<'X`>$-<RJ
M*C1-[%2R429G`2SS21^"]<*JQ`0"\^D8+9&*JA8D/JC+_K#5`@V%G)!]>&D\
M92Q@EF)T$=T0[([7FB$E-]LQUSI4*Z:L*;QU%T)BO`ETH?V8%#ES\N2+^[!_
MOJ*1A#(7C%UZ1"!X6T0F509;>NH,_O`%U5=%LE1>`<$`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]I9"YP;F<`````````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#4`
M,3`U,34T,S,W-C(`,#(S,30R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````
M6,P=C@```P!03%1%````____P<+"LK.SU-74X.#?W=W<U=74S<W,RL3!Y=_<
M_??T^/+ORL/`R,/!HRD`I2H!I"H!I2L#IC`)JS(*IC(,KC4-J#0-J3<1IS<1
MMD`8>BL1ND0=LT(<L$0?KT8CM4LGQ%$KR%8OOU$MED4JTV,^U6="SF-`H$XR
MQ6)!MUH]PF)"T&E)VW!-RVE(W')/T&M,VG-1V7-1MV%&QFI,WGM;UG=8VGU>
MS'99V'Y@WH)DVH-EXXYRT\W+TLS*^/+P]_'OZ.+@J28`HR8`:1<`HR@#K2H%
MJBH%J"P'=2(*MC40J342LCD4LCH8PT4AAC$9P$DFT5<UN4\OSEPZQ%<XW6A&
MP5L^KE0[V6M*VG!0VG%1T6Y0L%M#VW17Y85JX(-HR\3"WM?5[.7C;14`CS<A
MXV]0U,S*]O#O_O[^_?W]_/S\^_O[^OKZ^?GY^/CX]O;V]?7U\O+R\?'Q[N[N
M[.SLZ^OKZNKJZ.CHY>7EY.3DX>'AWM[>V]O;VMK:V-C8UM;6U-34TM+2T='1
MT-#0S\_/SL[.S<W-S,S,RLK*Q\?'Q,3$O[^_O+R\N;FYL+"PIZ>G____````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````#X'?+P````%B2T=$`(@%'4@````)<$A9<P```$@`
M``!(`$;):SX```"^241!5!C3;8PA#L)`$$5G=V=W6QJ2)D@.0(*F&HWF"!C"
M!1"@D%208!#<@,-@:""I(*E%$IK2V:%E/3SY\M\'^$'`K(@"VU8U.414&!\1
MBENWQ\^R9(7&8#@$"3J,VZJJ&R%1*ZLN@-!_#-AGC?:9EM=AAO`.\^>+6&F#
M'128^56DSJ,[3HT3IS81G'LED[&=M.2H+A=!)R5_'^Z-!&9V-#=[NTF]"E;*
MFP\1&+O64GBUU=`PDSMHN[-R*>`/7ZA71QG4ISZ^`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VEE+G!N9P``````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C`Q,0`Q,#4Q-30S,S<V,@`P,C,Q,S0`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___\`>P``
M=P``30``3``#>P,#>0,%?04)?PD-?@T*5PH2A!(8B!@17Q$?C1\?BB`9:1DG
MD2<A<2$JC"HKBRLNCRXJ?"HQCC$XGC@UEC4XFS@RA3(ZCCL^ESX[CCM(JDA&
MG$90L5!0KE!7ME=>NUY3I5-9KUEDOV1DOF1HP6AENV5JPVIJMVI]R'V(T(C>
MX=[4U]3)S,G(R\CT]O3CY>/5U]7-S\W,SLS)R\DPER]!I$!FO67-S<SJZ>?V
M]/+R\.[>W-K6U-+0S\ZG41NP6"&R6R.Y7R:\82CR?S6_8RK$:"W!9BS':B[*
M;##-;C'2<33/<#/5<S;ZBD+8=SG:>#K@?3[\CD;E@4+JA4;_DDWNB4GA@$7_
MDT_^E5#RC4S]E%'VCT[[DU'YDE#KC5+UF&#5AU7\HVSEE6/_J'/RH&[[J'3D
M:B'N=B_*:3#2;C3X@C[@>C[^C$KNADG^D5#YCE#__?S]^_KZ^/?HY>3^_O[\
M_/SZ^OKY^?GX^/CU]?7R\O+N[N[KZ^OHZ.CDY.3AX>'>WM[;V]O8V-C6UM;4
MU-32TM+1T='0T-#.SL[-S<W,S,S___\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````"J!":X````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```*))1$%4&--MS+T-
MPE`,!&#;>2__($$#0F(/QH"E&(2>BB&@IZ!B`UH@<?QL'(D.KOSN=``_00@P
M:>=QET<XS9;W:7$(@%4S-8P!U$JLO2'(JT8-`YI8F16Q<RKKC'NB8TH;I#P-
M3FW#78>PE70FPIZ=UOWBR:SB*\*.U>DQW#B92U+R8B1>N40705.1\>M]%2%V
M@8M^5R_A+%B2?69J20W^Y`/6@%P6!X(+DP````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O:6PN<&YG````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0W
M`#$P-3$U-#,S-S8R`#`R,S$U-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P``
M`%C,'8X```,`4$Q410```/_____^_]74U<?&QX2'B\/'R_3X_+;,WLC8YK/`
MRP-%=@IQO@]TOA)ZQQ)UOQ1XPA18BR."R"-^P1Q1>#&$P2MRIC6%PC6%P#R/
MS#9]LCJ%O$>AY3%PGD68U4".QT&.QSEZJDR=V4>0QD&$M5BO\%.@V5VS\EJM
MZD^6RE^R[U6=TUZMYUZJXUVCUVNZ]&JV[F6LX'>_](K(]H&LS(*IQI*XUJO3
M\9NUR)VVR:S#U*O!TLC?\:R]RK+!S;3!R\;+SZJNL?7Z_K*VN=C<W]'5V,C,
MS^KN\0=ROQ1WOA^"RB*(TB!\OR:"Q2B`P"^0UBR'R328X"V"P#&&Q#N4U#-\
ML4>G[3R.R42;VD&+P5.O\DVDXE2L[$Z?V39ME4B.P&&S[F"JWVFU[&ZZ\5F4
MOGJ\[*.[S+G2Y-_P_.+O^,+(S.WS]\S/T?C[_=CF[]_FZM;;WM39W.#EZ/'W
M^N3J[>+HZ[W!P^GN\-35U<'"PN?GYN#@W\W-S/CW]]W<W/[^_OW]_?S\_/O[
M^_KZ^OGY^?;V]O7U]?+R\O'Q\>[N[NSL[.KJZN7EY>'AX=O;V]K:VMC8V-34
MU-+2TL[.SLW-S<S,S,K*RJ>GI____P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````*D6S2P````!8DM'1`"(!1U(````"7!(67,```!(
M````2`!&R6L^````P$E$050(UV-@P`)$1.)2C%/U%$2#@B65=)*-@$+<@E))
M"1%"_#P>?-Z!85$Q0"%6QR+V4M?)%I83"_*SG8I+@$+3)S)UU-F91BJ;<;;5
M-[17`X58&%M[)]E+I%FIY376M_9,`@K5-E=53.$2M^;0S61LZ6:>!A1JZ)HP
M>:JMB;:A>4939W]-)5"HO-"!+2NG+]VF/M?=Q:W,&2@DY^O)*^#E+Z.JKA$K
M+QTJ!A0*]_,1#@B)UM(W2-2,5U&4Q>8=`(M@,*,G#W+-`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]I;BYP;F<`````````````````
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#``,3`U,34T,S,W-C(`,#(S,30W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____J(Z4
MEX60U=35Q\;'\O#YR<G,HZ33IZB[F)_+?HBWE9['@(Z_H:W6<X6\?(NYEJ*^
MU=[OM<#)[/'R^O[^RLS,U-75Q\S+]_OZZN[MZ.SKU-C7R<W,^OW\OL+`UMK8
MRL[,R<W+;K1C8JI3A<9V19(P2Y<W4ID_5Y!):JM8:*-8=;)DA,-SB\QZ1Y(R
M6J1%8)E0B,MU/Y`?.74A4YTX)'<`*7P%*7H%,X<--(40.8480I0=1),A-7$;
M/GHC1H0J0GXH5Z0U28@N4)`T7Z%"9:I&;[90:[!.*'P`*GX#+X`)5*0O3HXP
M5)8U9K)":+)&<;I/<+90Y^?FS%(`?S,`T%8%S%4%V&`0U%X/SF`2Y&\AG4X9
MV'`KZWHOX7PXLF(L^(I!_(]&QG,[_Y90_I90[HU,[(Q+^Y=4_:-G?S(`SE(#
MR5`%S%,'S58)UEP-BS\-TF(8E$01X6H=WFD<U&8?[GHO\H`U^HI"NV@RYX)!
M_Y1/^9)0]I97^IM>Z91<]Y]E_Z5JS[BKW<>[X,S`_NC<\=W2U,.YZ-##IY:-
M]=W1_>?<\MW2_^OBPJ^ML9V<^/?W_O[^_/S\^OKZ^?GY]O;VZNKJY>7EX>'A
MTM+2S<W-RLK*____````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````.T*-R```
M``%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"Y241!5!C3;<%-
M3@)!$`;0KWZZ>\`@!")(-'@JSN"*L'$+'D!7QIUW\2ZP(!&"1B$P,%-='D#?
M`_X@C)'2J%YV5\8LMQMY4UP5*9GU3S90%1H2%/'S[B,?K'>]O5F+:(9B.(C)
MO/7@S^=^%:D$(=2O0K/*C>+<E?F>\?3R_DC?9<7GGZG0A$$8&85C.)QR(4J1
M;:%((:=`O;VW:W>/)12=:+D0Z5X>R=SS#HK<R?3%;:&+?<-WWL0_?@%1.$=6
MNGDVX`````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+VEQ+G!N9P``````````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T
M-P`Q,#4Q-30S,S<V,@`P,C,Q-C$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,`
M``!8S!V.```#`%!,5$4```#___^(&QSS5E?Y>'G*PL//R,G]]O?\]?;QZNO;
MT]7\]??PZ>LO+B\M+"T_/C]Q<'%C8F-655;5U-5/3U#W]_C\_?[)R\S#Q<8B
M(R/.T='BY.3BX^/V^OGN\O#BZ>6\P[[&U,F\VK^CMZ6FN:C&V\B.LY%OGW)@
ME6!HE6B7NI>AQJ&&HX:;LYO.X<['V,>ONZ^XP;CI\.D?(!^[P+OK\.OJ[>K&
MR<:^P;[@XN#5UM72T]+(R<CL]>LV-C7'Q\;;UM7'``!]``!\``#(`P/+!07(
M!07("0G0#0W3$!#.&!B0$1'<'1W)'1W''!S@(2'/'Q^:&1G/)27))R?I+R_M
M-379,S/=.#CU0D*X,C+X1D;B04'E1433/S_#.SOZ3T_Z4%#U4%"N/#SR5U?U
M7E[Z9&3J7U_H7E[S967W:&C[:FKE;&S&O[_5SL[*Q,2DGY_NZ.C?V=G0S,SX
M^/CV]O;HZ.CFYN;1T='&QL:\O+QW=W=R<G)P<'!A86%45%104%!/3T].3DY-
M34U&1D9%145"0D(Z.CHX.#@U-34T-#0S,S,P,#`O+R\N+BXJ*BHH*"@A(2$=
M'1T;&QL8&!@0$!`-#0T)"0D%!04#`P/___\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!+9+&8`````6)+1T0`B`4=2`````EP2%ES````
M2````$@`1LEK/@```,!)1$%4"-=C8,`"G)P#X[*2P[W<'%T]_4.C$H!"SMZ1
M&2G1`>Z.+AX^(1'QB4`AIJ1LEO388#_?H+`8YM3,-*!0?A$'#U=>#BM;;B$G
M.W>!`U!(0DQ.345<05E=45Y6255:"BA44FRIJ6-@J*NAKV>KK25L`Q02+2NO
ML#`QMY(Q,S(MM;:O!`I5U[7Q\G7QBP@*5-74"C6U`(7:)T]GF#YE0D=S?6-K
M9V__!*"0\32&&5,G]K0VU#?;=?=)3L+F'0#]5S">O;>-"P````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:7(N<&YG````````````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0Q`#$P-3$U-#,S-S8R`#`R,S$U-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/____I1
M4LMT==-[?,FRM./AXOKX^OS[_.+AXL_.S][=W\3#QOO[_/+R\\_/T/3U]M#1
MTL?,S/7Z^N[R\LG,S/7W]\_1T<?)R<;(R/3U]?+S\^7FYN+CX\W1T/K\^_+T
M\T^94DR53@!S``!R``!(``!'``-T`P5W!05V!0EV"0U]#1"!$!B!&!%:$1V*
M'2&/(1^$'QED&2^:+S6?-3B7.$*I0C)_,D:M1D&=03J*.U"S4$^Q3U"N4%>P
M5UZU7E6;566W96J^:E:85F:E9H[`CL'&P<_3S\'#P3IF.6.H8G*U<5Z-78+"
M@86^A)#,CY#+CXG!B*#3GNKLZ-'3S_;U]/?U]-#.S<?%Q,6LJLBJJ.G'QL>R
ML<@``,8"`LD#`\H&!L<'!\@)"=$-#=,3$\T:&MP='=$@']\C(Z0;&ZPB(NHO
M+Z\C([LJ*K@I*>PV-L<P,,,P+]$V-=TZ.<XV-O9"0O=)2>%#0^9&1OM/3_50
M4/%04-MR<<QL;,=I:<9M;-!T=-9\?,IU=>*)B;5R<MB+BMN/CL!\?,N%A>V?
MG_BIJ.^BHOBKJ^VEI>6EI=>FI>&\O/GV]NSIZ>KGY\C%Q:.AH>WKZ]O9V?KY
M^?CW]^?FYM/2TLG(R,C'Q_;V]M75U;V]O?___P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````!?DW^@`
M```!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````NDE$0508TVW!
M,3($41`&X+^[_YGWS,Z04*6*#"<0*%4"T4:;2QV#*JE@E<`AW()4Y!!R&66Q
M.]W:`?@^X`_!`89:_>O;5PU)VA,AM2DQ>HPT,Z6`V+/EX)_=2^YVHBH"Q6PR
M.VVU.3HNC[66Z11`7W<FW59CO-LLP_K:!@AVVLOJ;-^?<WO417TCYB+Z<')S
MF/?7[:(/G@OF'I%)K:FRU(PKXO7=0\E2;B\](AS$1[B:6FL7,?Y$)O[Q"V50
M/^2)H[Q'`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]I<RYP;F<`````````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P
M-3``,3`U,34T,S,W-C(`,#(S,34U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#
M````6,P=C@```P!03%1%````____VWAYK9ZOJ9FLE(*BEH6DH)6JT<3=S\/:
MDH*DFHFOHY.XQ+?5GH^SLJ7$CG^HS\K<HIVV#@V+#@V)'1R3553$`0&%`0&#
M`P-4!@:'!`15!`14!P>'"0F)"@J,"PN+#`R)#0V,"@I>$A*0%!28$Q.1%A:5
M&!B7'!V3%!1G(R.>)B:C)R>B)268*RNF'Q]X)B:&)26`)R>",#"?-36M+2V/
M.CJS.3FP.CJR*BJ!+BZ,+2V),S.8/CZU,S.3-366.3F=/CZH.SN?1T>[/S^F
M2$B[2DJ^3$R_3$R^34V_24FT1T>M3$RW2TNR45'`45&^4%"Y557#5E;$5E;#
M557`4U.\65FX>WNX=W>E?W^OIJ;=FYO.IJ;;!PJ*#`^,)"BE(B:9'1]R,C:P
M.SZK-SF/BHO&D9/-FIO4B8J[J:K@;G*P=WNZ/TRD15*I4E^U8F["2U.-<W_/
M@X[<?XG1AI';0%"H<7S`<7NXEZ+DS"P@T"TBUC8KSCTSUD4\X51+VU!)[F5<
M[&IAREQ4U6);^G9NYVYH^GUTZG1L_X%X^7]W_X=_^HB"^(V'RB,<U&MH^9F6
M\J">_*VKQPT-S2$ARBLHT41#Q5)2QUQ:S%]>X'AV[HF(SWMYXHR*Q'EX^YV<
M\IF8____````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````%88K\0````%B2T=$`(@%'4@````)<$A9<P``
M`$@```!(`$;):SX```#!241!5`C78V#``J0ED]B[>5-$%:44U'4M/8*!0C):
MJ9SM_(DBLG)JVJ9N0:%`(66K<(XF/B4)<7D-?3NO`&^@4&%%I6"#4%EN7GY!
M47%I23E0:-ZDB4Q3IL^8V3]K]H3Y"^;.`0KU]K1-FSRUMJZ^L;6SJZ.E&2B4
ME9[#W,>2'9&6$1T;DQD5"10*-%'AJA)0U3%W]_=UM34S!`HY:<:S5G,G6'B&
MA/DXVML8`87TA./8:GB27<1"_9P=K(T-L'D'`#FK,J4&D>R+`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VET+G!N9P``````````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`R-@`Q,#4Q-30S,S<V,@`P,C,Q-C$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____0
M-3;HU=8`<```;@``1@`#<0,#<`,%<P4)=`D-=0T*40H/=P\0=Q`2>A(3>Q,7
M>Q<8?A@161$;@1L?@Q\?@B`98ADEA"4GB"<A:B$J=2HXE3@XDS@R?C(ZACL[
MASM(HDA0J5!&E$90IU!7KE=4IU1>LUY9J%EDN&1DMF1HNFAEM&5JNVIIN&ET
MP'3"RL+!R<&^QKZ]Q;W2VM+)T<F^Q;[+TLO:X=KJ\.HPCR\\E#M!G$!FM67-
MS<SJV]K2&QO>(2&C&QO;)R>K(2'H+R^N(R.U)B:W*"CL-36Z*BKE-C6]+"S#
M+B[`+2W(,C'%,##.-#3--#3*,S/R/C[T0D+5.CKW1D;O1$3;/S[@0D+X2DK0
M/S[D1D;Y34WI24GY3T_Y4%#W4%#Q3D[M3$SX45'T4%#V45'@2TOY65CM557V
M6UO0O;W6P\/>R\ORX.#_[N[ZZ>G][>WVYN;^_O[\_/SZ^OKY^?GX^/CU]?7R
M\O+N[N[KZ^OHZ.CDY.3AX>'>WM[;V]O8V-C6UM;4U-32TM+1T='0T-#.SL[-
MS<W,S,S___\`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#NE&4L
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```*])1$%4&--M
MP3%2`D$0!=`_/3L[PQ:+@F51!D9D)-Z"S)N9&IMZ`(]A2)4F),:$*MO-_&D/
M(.\!_P3T6);K8=<G?.U#60PO'3#FT3UU:"'*?)8@Z,O0)N^"UU"N9EDA6)1H
MMR9OY/.8,PT1-W/5XVJ[J7SPB)-^".YMK<I62<G)7AL$1SO\T"M)%]7'"H'>
M_=(;R2IN]#,$]FF,B:P(;3(C!#J=I7/6I_C^[6P-%_P!2+5;NG;TAW\`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O:FTN<&YG````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R
M,#0W`#$P-3$U-#,S-S8R`#`R,S$U-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$@````P(
M`P```%C,'8X```,`4$Q410```/___SLZ.S8U-FAG:!\@("LL+`UV#3J;.@1M
M`01L`0YW#1)Y$">+)C:)-4*706NX:A1Z$%&G3BB)(5>M4`QQ`R>('2>!'TZ@
M1@UP`!%T!1)S!15T"21^&#N9+T"<-4.5.$VH0E*J1EFP3UJM4&&N5QUY#4:*
M.QM\"C./(2)]`S*+%$B-,&6U2C*#`#F)!X?$7E.<'6*C&'2S*U>7!86X0H*S
M&(2Q)V&!&9S*-8^R`)&U!Y*L*LGF4:6[`[;+%,_B+]_N9;S)`+_-"L?0-.;Q
M/F-D4(B)&\S,`']_`'%P`"TM`,W-`6UM`:FG`]#/!<S,!<W-"=;6#4Y-!=?8
M$,_/$N'A'>CH)FEH$:^O'^OK*[*S(W9V&-73+\?'+OKZ0KN[,D%!$OS\1JBG
M+___3>SL2+JY.O+R3,&_/NOJ4')R*,3$3WEY-:FI41H:#9&035E9,VMK0F9F
M4"@H(4)".%-323(R,3`P+S\_/D%!0+JV`+"L`]71(>;C/O'N9)&066!?2@\.
M`&9E96IJ:F1D9%Y>7E=75U%145!04$]/3TY.3DQ,3$E)24A(2$9&1D)"0CHZ
M.C@X.#0T-#`P,"TM+2HJ*B<G)R8F)B$A(1@8&`H*"@D)"?___P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````*)H:!L````!8DM'1`"(!1U(````"7!(67,`
M``!(````2`!&R6L^````P$E$050(UV-@P`*\/"W4!5059*4EI7@T+9,R@4*-
M$0F.!OSB,I*BW(8.\=EN0*%94^OK4LW5N#@US*)J\]M[@$(S^EB*DD/M]/3M
MP],:VKLK@$),S6T39P97^8?4Y/1U=/5/`@HUM5:RSO:N#@J++>SLZ&.>#!1J
MZ9V6Y^OC;&3LFI);.J&,#2C449[HYV&MS<NA:YN>43!E.E"H)";`R4106%Y)
M1,C4)2ZK&"@4&6BEQ2XFIZBL(L&G8Q/MCLT[`%?Q,@9R=(O;`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]J;RYP;F<`````````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#<`,3`U,34T,S,W-C,`,#(S,38Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____
MRAL<^VMLSY.4R0$&P4)&Q[6YX=W@]?+U\N_RY>+E[>OMT<_1Q,+$NKBZ]O7V
MY^;GTM'2Z^OLT]G<O<7%W.'A.CL[[_'QY>?GY.;FUMC8[_#PXN/CV-G9R\S,
MTM33.4A`*7TP-H8Z`'L``WD#!8`%#7X-$(,0'8L=(9`A&VH;(7(A(G0C+YLO
M*'PH-:`U*GXJ+H4N,(<P-(XT0JI"1JY&0I]"1J-&3[)/4+-03JU.4*]01I!'
M/W<_6:!93HE.:*UH:*=H;K!N(RHC&1H9[_#OP<+!-I`U1X!&6I=9#FH`+C(K
M044^7%]9861>96AB&!L4(20=4U9/&1L40U()1$H(:&AE>2T%:E!+%@,`LRT?
MIA(#:C<R600`SFADOG%OR0``?P``R@4%R0D)S@T-B`H*SQ(2SQ@8S1@8BA,1
MSR`@TR<GHR$AVS`OL2HJR#`PX3@XW3@XU#8U\5!0YTQ,[5!0PD5%Z5E9T%)2
M^&1D\W=WX82#\965RZ*B]-G9^>3DN[BX_/S\^OKZ]_?W]/3TX^/CT='1R,C(
M:FIJ7EY>5U=74%!03T]/1D9&0D)"04%!.#@X-34U+R\O(2$A'Q\?'1T=&!@8
M$!`0#0T-"0D)!04%`P,#____````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````.]6\
M_`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#`241!5`C7
M8V#``N*B7,4[NR=.G\TP>\:427T]0*&DK-CPK@E39S',F3EM<G\O2"@MOR(^
M4M$E,"3(QS?8/\`/*)1;R5Q2G-`HZBXO)RDA(Z4`%"IOJ"W*2"ZHDY9U:VYJ
M;6L'"E77UV2G)#*QB`FW-`D("G4`A:I*<U)9V=A%.'@XN;AY^?B!0F5YZ3%A
M2LJV]H[.3EX.GG9`H<+,"&\U#2T#,RMK<Q,C?1V@4'2HBJJZIIZII8V%A[&A
MKC8V[P``Y-PQ?ZF3QPL`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+VIP+G!N9P``````````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,3(S-0`Q,#4Q-30S,S<V,P`P,C,Q-C``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!(````,
M"`,```!8S!V.```!@%!,5$4```#______O_5U-7'QL?4U=7&Q\?!PL*RL[/4
MU=3GY^;@X-_=W=S5U=3-S<S`(0"_(0#!(P/#)07$*`?)+0W,,1#2.!C4/!W8
M02'?2BOB3B_L7#[V[>N_'@/'*0K(*`S.,13#,1;*9%+I>V?TAW/VCGSWD8#8
MA7?!&@'`&`&_&`'$,AS;/";;/2;E2C7H43KN64+';6#UD8+'>F[-@'7(@7?@
MH);ZMJO5G)/WMZ[QO[C,IZ+;O[N_%0"_&@7.*!3R6TKS7DW)E8_3NK?RZNK8
MU-3X]_?^_O[]_?W\_/S[^_OZ^OKY^?GX^/CW]_?V]O;R\O+Q\?'N[N[L[.SK
MZ^OJZNKIZ>GGY^?EY>7DY.3AX>':VMK8V-C6UM;4U-32TM+0T-#/S\_.SL[-
MS<W,S,S*RLK'Q\?$Q,2_O[^\O+R[N[NYN;FRLK*PL+"GIZ>=G9V4E)2+BXM_
M?W____\```````````````````````````````````````````````!5I!6J
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+9)1$%4"-=C
M8,`"BHKRV1C]H^)34A)B(@,\W4%"!5E^WN'.IL;6L5%!WHP^0*'"G#"/8`M%
M+4UY]1!?1J\@H%!>'%.@C;8LO[""CI6[1P`W4(@%:)")G8"0J(2>D;M_1#Q0
MR,V;B]705E!$7,I`S2>4.14HY!$<D^2D(2<F*>UH&13-QPX4"N1)3$E1LM?5
M=U!UX4Y,SP8*@5WD:J:L8BX3$9^6F0L4XDQ.28*X*)0W-8,C#YMW`/";)^?D
MRXHD`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+VME+G!N9P``````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C`T-``Q,#4Q-30S,S<V,P`P,C,Q-#4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!(````,"`,```!8S!V.```#`%!,5$4```#___^3%A>Z+S#`-3;!/3ZT.CNZ
M24KG?7ZH75['+S;(.3_33U6]3E+(55K57V/I;W3W>'WQ=WR],3CG;7/XAHP#
M`@,_/C]X?GY]@8$Z.SNHVK9MJ'T`<!L#<AT)="(->R<?@S<;9RTB<C4PF4@J
M>STPA$0VC4I1K68AB#A$IEA*H%TPC$%1KV1?L&YEFF]OE7:>R:8A@#!GFG!Q
MH'F&LHUXGW^!J8B@RJ<`;!`%;Q48>R<A;"PH=C,N?SHTB$$XDD5=JVF/N)4%
M<!)"F$V7EY:;@6"HCV^;9E#$E']13DVC```^``"C!06U"0DT`P.6$1&\&!B\
M(""W)B:@(B+,-36[,3&U,#!;&!C+.#B]-#2^.3CF1D;60D+004#/0D+#/S_4
M1D;J3T_G4%!@(2'?3D[B4%#,2$C@5U>\2DJ[2DI3(2'96EGE7EZ[3T_D967K
M:FK49&2@3$S5:&CM=W?:;6W7<G)9+R_UA(3J@8'TB(C-='3IA(2D75WWF)@;
M&!A`/3U54E)H965S<7&6E96BHJ*4E)2,C(R*BHJ)B8EW=W=J:FIE965A86%>
M7EY04%!/3T]&1D9"0D([.SLU-34R,C(O+R\A(2$='1T9&1D8&!@1$1$%!07_
M__\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!0HM^``````6)+1T0`B`4=2```
M``EP2%ES````2````$@`1LEK/@```+U)1$%4"-=C8,`*9DIU-TV>-4>L?O;T
M*1/[02*SI_;T-3>F1#1XS9@V:0)(2+RWK;53LC8KDU.BJZ/%M1TH5%1=5U.<
M%Q#-&E)84E%560848BO(B`ST]0D.RPZ-24Z-CP(*Y>?&!?EY^S,GE,<FI26R
MA`.%1$5XN+F$F=)SV(4$!?CY>(%"%J8FQOHR'J4<GM*&3N9F!D`A!VLK2V<C
M'3=W/4<7>SM;&Z"0HKRLG(*FBI:NAK:ZFJJR$C;/``!SZ3$`8-]UB`````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:V<N<&YG````
M`````````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0V`#$P-3$U-#,S-S8S
M`#`R,S$U,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q4
M10```/____K60O')-<N<`<J/`]*7"O.].LR+`<N.!<^/!\V3#=F=%-R@&/:_
M/LJ)`,F%`.6D)LN!`=2-#>*=(>NJ+\E[`,V'$MV4'>BB*_NV2ORY3<IY`]&#
M"N6:)MB#%-%C$,I8!=%?)_6"1OB(3\4Z`,D^!\5!"=9/&/:`4<M'&/1V1NA?
M-<0L`^MA.O)U4<$G`=E$(<M!']1/+_5Q4,`A`+\A`'@4`'@5`,(C`[\C`\,E
M!<,F!<`E!<$H"<HM#80?"LPP$,0Q$L8V&(PF$=4\'=A!(<H]'Y4N&9\Q&\U$
M)Z<W(:HZ(^--+^).+Y\W(;`^)M)++[-`*.93-;9"*KY'+KM&+;A$+,%),*E`
M*L-+,==4.,M/-<E.-,5,,^Q</LM/-N]@0M!4.K-(,O%D1MQ;0-99/MM<0KY1
M._1I3>!@1M]@1N1D2>)B2/1K3_5L4.AG3.MI3O)M4>]K4/%M4>AK4.=I4,M=
M1NUP5^QQ5_!W7N!P6?1]9/-\9.]]9>Y]9?:":L`?`+\>`,$A!<HJ#<(J#<PN
M$,<R&,DY(-]'*]=1.-=2..]=0MQ:0?-E2N1B2>)?2/5H3^AE3/-H4.MF3N]I
M4/5_:.YF4/___P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````&S$D8L````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MOTE$050(UV-@P`(LS#TR&BJZVYN;K!W=@E/R04(NR?55O4;JJKHMKGZ)><5`
M(8?(ZMH)2MPL'+(:G?&9)3E`(?_R:67&XJP"7#QR>GU%!6E`H8R&RBXM3C%%
M!1%FY<F%Z;%`H;JJU`YU?AEA"5$FE>G9"1%`H9I<KU8#(39>23YI_?ZDJ'"@
M4&F@DU6CFKP@NY3FI+2XL`"@4+2SK9E-FZ&.MLF4]-C0(&^@D+N=J:6]JV_/
MQ*E9,1$A/I[8O`,`_%HP7'9OO.T`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]K:"YP;F<`````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(P,S(`,3`U,34T,S,W-C,`,#(S,30U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```2````#`@#````6,P=C@```P!03%1%````____PQ(6A`X0P!47Q!<;TAL?
MSBHMWS$TL"LMTC4WNS(TJBXP[41&]5)5Y$Y1XDY0\5=9Z%58X%U@]&EKQ7!Q
MZ*FJ\[.TR`X3QC<[P&]QW(Z0SX:)ZJ&C\[.U'!2>+22L0#B[44K(6%#%6U/,
M$0J73$:W%1.</CVL#`N9!PAA#`R:#Q"=$1*=&1FE(R2F&1EU*"FR*BNI*2F.
M.SO!,3&8-SBB0D.Y34[..CN;2DJ^65K56EO19VC4;F[4``VH``AI`Q"J!1&L
M!1*I"16J#1FQ$!VU&"2Q'2F](2W"'RNT&2&&&R..(BR9+SO,-4#0*C.D,#JO
M.$/#-C^X0DW91E+<.D.N1E#,3UG?4%O@4%K:5V'::G/DU+RO^.3:S:R=Z]/)
M_^KAWL&VS)F,SIV1X;6KUJRC[L&X^M+*S()TV)6*^ZVB\K.JS4@XT59&S&9;
MT(!WSR\AZ$8XS$0YY&5:S2,8_VQCSA(-TBHCV"PGIR4AP3`LRC4PS3<QTCDT
MU3HVVCXZYT9`X$0^Y4="_E!*QS\[ZDM&[DY)[$U(\E%,_591]E-.\550U$M&
M_%Y8]EQ7^F)>_6AD_VQH^&IE_VYJS`,#VQ04P!04P1@8U"`@W3(O]3XZX3LX
M_E)0^5!0UDY.____````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````.%'(-`````%B2T=$`(@%'4@`
M```)<$A9<P```$@```!(`$;):SX```"S241!5!C3;<$Q3L1`#`70;WLR$42*
M5JR$1$\!)Z#E7%L@6@[`&3@--10H-4N!Q$91)AZ/S0'@/>`/PCV&(<>ZF$F2
MG--+PE?>YFAE86&1)`2"G/5D:WVFQV_N2/R'<-AW.KY=O]/-Q^TQQ_;`&/JV
MF\HD-NE\16I(&.UTWK1RS/2YJ^9(\%(F->_<93FJ!P@7I<9E[8-IBZ?#R5?"
M77%7)2(.X3'\-6&OE9/DG+B91PO\XQ=3%UHG:HU[M@````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VMI+G!N9P``
M```````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-P`Q,#4Q-30S,S<V
M,P`P,C,Q-30`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,
M5$4```#____$.COZ9VB^BXS+H:*^EIK4QLRFH*J8F*B>I,2JKL)788J<H[]4
M8I)@;Z.!C;M^A9^+D:BVO-)078=Q>YR4H,6`BJER>9"*DJV?J,2!B)ZIL<MD
M<)1C<)-S?9I]AI^'D*N<IL&>IKYP=H>1F*R,DJ0]4(!58XA47WN'E+9X@IR:
MIL6HLLQ^A9>[Q=V8G[!O?J!YAZ=J=8YS?IAF<(:2G[N3G;.-E*.SNLEU@9F&
MCZ&ZQ-E!685*88M[B:/`S-W7V<7,UB&[Q`7$RQ##RB??YCW$QI+>WX_2T@W=
MW!VRI@"[IP"PEP.U@@>YB`FN=0#MR'[!;Q2X70';@C7#?T>W1`&U.`._3Q_`
M/PVX,@7#*0##(@7M:%?&%07!&0K+)AC81CC<3T'<,2;Y;FK*:69]``!\``#'
M#@V)"@K0%!#'%!+8&1C.&!B0$1'<'AW@(2'/("":&1G5)R?F*ROI+R^D(2'9
M+R_*+2SM-37P.CJN*BK=.#C/-#3S/C[U0D*X,C+X1D;W1D;</S[C0T+A0D+Y
M2DK#.SOZ34WE1D;J24GH2$CZ3T_[4%#Z4%#N3$SQ3D[X45'W45'U4%#M4%#0
M1D;Q5U?23D[U7U[E65GV8F'X9&3S967[:FKZ?7O^C(KXE)+___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````MQIR4`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@``
M`,!)1$%4"-=C8,`"TM*+VE-B$Q/BHF.R"BH;>T%">0US9B1%^/OX1N:7UO=,
M!@IE5L^<W5V<$18<GU-2US&I"RA4-I5Y2GEV>(!?4')5V\3^9J`0T]QI-;E1
MWLXN3B%-?1-::X%""^:U%%:$NGIZN07.G]4Y/14H9,/-QL(I:N'NX:COP,[*
M80T4,C.TLU47X>,7$-/1,K*WT@,**2IH"\K+BO/*Z"J9"TE+:`*%5$TT>.0D
ME:6XA"T-U(Q-5;!Y!P#*KC*V^'VT[P````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O:W`N<&YG````````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,#4P`#$P-3$U-#,S-S8S`#`R,S$U-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$@````P(`P```%C,'8X```,`4$Q410```/___\<Z.ZYK>+MYAK&&C\F9
MH[%T@;!T@<F,F;>#C]:AK:9]AKR/F>*ONLV?J>6TO]VNN9MR?,>6I=NPOK.#
MDZ)_B]BLN]NQO]FQOZ9UAZAWB6=)5*AYBK"`D;R-GLJ=K=ZTPWM<:`43@0,,
M4`D8A0H8@Q4CCATJCB8TG!PF;"`K=3E&K#Q(HS9!DTE7N4M8N3U(DTQ9KU5C
MP%1AOE9CO5MFNVUWQP47A0@9A@T?B!$BCB$RG",TE2<S?S5%JR\[B3M(G,O.
MSN7GYLR9E.NWLXL2#.LW+KDM)L\[,^!&/OY32O]83_)43/%84/M<5,MN:=!V
M<-B"??VQK,P)`<T.!<H-"-06#=L9%-XD&^0G(<XE'\\E(-HM)^XU+]TT+_([
M-<0T+?5".LHU,+(P*LTU,=(Y--4Z-OI(0OA)0=H^.N!"/OQ,1N5'0NI+1NY-
M2?]53_Y64/)03/U94?933NY33.M/2_M54?E54.EI9/:+B/N6D\>GIO+;VM$)
M!\L)"=@0$.$='=PG(^@J)NLL*\\I)Z<C(<$O+/4^.OA"/OY.2O]13?U54=-+
M2,A(2,Q.2])44?UE9/AE9<M85M%L;.&"@,61D->@G\B;FL>;FLN?GM2HI\ZC
MH_S2T?'Q\<[.SO___P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````/7MB=D````!8DM'1`"(!1U(
M````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`)45+0,S<UT-=24
M5=4U=0Q,@$(R2F(B$L*BLE+2<O(*XHJ20"&WE,I@UZ#HD-#P2/=,'_]2H%!;
M[]QYT^?/"*N+:.[HZBG*!@HQ5==.;9U<T]\0E9!36)*;!A2:5.4\I;[/:4)C
M7$9!15YZ,E!H8MGLF;.FS6EJZ>PNS\]*;0<*^<7'!+@$QC8G>1?[>GDF>@"%
MV+@XF-E9.+GY!`3Y>5EYA(!"ME86EM8V]OK&ID:.>@YVVMB\`P!ONS)7\YKX
M[`````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]K<BYP;F<`
M````````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#4`,3`U,34T,S,W
M-C,`,#(S,38S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!0
M3%1%````____X$]6I1`QGE%JF"%*7@-`:@U3U=35Q\;'A%6:2D26(!V;F9?7
M"@J/&!B:*RNF+R^Q/CZQ1TBX.SVLD)+8AHB_AXJZ\?+Z]O?]Z>KOP,;&S=+2
M\/7UT]?7^?S\U-75P<+"LK.SI*6EU-74K["OQ<6_^_OYU]?5<W-RZ>GHY^?F
MX.#?S<W,DY.2__;P_/7TZ):4SJ6DS0$`R@``T`4%T0<'S`X.VQ04S4`_S$A(
MU(^.SZJJ^/?WS,O+_O[^_?W]_/S\^OKZ^?GY]O;V]/3T\O+R\?'Q\/#P[N[N
M[.SLZNKJY>7EY.3DX>'AW]_?WM[>W=W=VMK:U-34TM+2T='1T-#0S\_/SL[.
MS<W-S,S,RLK*R,C(O[^_O+R\N[N[N;FYN+BXM+2TL[.SLK*RL;&QL+"PIZ>G
MI:6EI*2DH*"@G9V=FYN;F9F9E965E)24DY.3D9&1BXN+B8F)A86%A(2$@H*"
M@("`?W]_?'Q\>GIZ=W=W<G)R;6UM:VMK8V-C2DI*0T-#/3T]____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=`5'P@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX`
M``"^241!5`C78V#``BHJLI7=7?Q"HJ+"PE.\'>U!0OD9^7EAP9%1$6'5]>&,
MSD"AHM2<XD(Y(RM+ZP#5\F(M3Z!0>K!OKK2-N;&9A:%L5HR;#E"(D]$E4(;%
MQ)29E<E`WM4G!"ADZZ2M$,G-QLXCR*7O[,T1#11R\(HN4Q/GXQ<0XE5/CM55
M!`JY!]4V:8:*B0B+2FI4U24E`(7\0@H:&A-]I23L/4IK].+2@$(JD7:5F?Z>
M3HS.WO$E*4KIV+P#`(CJ*JZ!TAAS`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+VMY+G!N9P``````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C`T-@`Q,#4Q-30S,S<V,P`P,C,Q-S,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!(````,"`,```!8S!V.```#`%!,5$4```#___^KDIN>@H[9P,M:14^U
MHZR3=H9]5&^YJ[7%K[]B6&)[8GZUJ[K(O-!?27:@FJ9Q8XAK7X"9C;0^,&B'
M?*B4B[!P:X`],6I327QC6HM".7!<5(AO:)=Z<Z(W+VM22H)73XI=591&0&M4
M3GQ84H!Q::%?68AR:Z)U;:1V;Z1]=JI\=:=Z=*,P*6<U+FHU+FDW,&PW,&LY
M,FXY,FT[-'`\-7$]-G$\-6Y!.G5#/'A$/7A#/'1'0'M'0'I+1'Y(0GA/28)0
M28)33894389.2'T_.F1;5(]848I43H-<5HY@69)A6I)(0VU43GY,1W)<5HEE
M7Y=02W=.271E7Y9J8YMO:*)74H!P::%<5X9N:)YD7H]X<:IN:)MU;Z5H8Y)X
M<J=L9I9[=:ES;9UP:YIY<Z5T;IY]=ZI\=J>+AK.(@Z^*A:\V,&XU+VPT+FHW
M,6U(0GYB799/2WEE8H!F9'D[-W,[-W)'0WB"?ZZ*B*="0'AS<HJ#@YA?9I:9
MH:"BKZ>YS;2@NI&NQ9N6GX;(HGRYFI#J@VWGBG?S@&NJ64N^:5OI@W+NB'>1
M85CVMZSCJJ"W0S/`2SB`,27/7TW7<&&YA7UR2$7#B(2Q<7'___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#/`T+P`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```+])1$%4"-=C8,`"6+E+NOBX>&OS
M#8RM70*UTH%"TWJG]O3U3Y\AD6OII!26G@$4FM39WM$V>>($D5)[]YK*I#2@
MD#@;2S<G$T^YF9VB6F.=9CQ0B%E8;(I@%3N'E7.A:$MK;"10**M"EE]:+T=2
MP3LBNZ%>*APHE)GL698G;U[@%14CT-0L5`04T@VP,=(WM?4(34B7JRY6\0<*
M13N8Z`-=%!*7GIHHXQ>L#!1RM=`WM'3TT=#625%7#?)UP^8=`$?I+^I,RB,H
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:WHN<&YG
M````````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0V`#$P-3$U-#,S
M-S8S`#`R,S$W-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`
M4$Q410```/___P"&S`"'S`&(S`*(RP.)S@.*S@.(S`6+T`6*S`>+T0F*S0V3
MU@V-S@V,S1"5V!B;WAB4TAV?X2&AY"&BY!^7U1^7U!MXIQIQG2NIZR><V"*#
MLR&`L"^N[B^O[B:(N2B*O#6Q\C6R\BN0PBJ-OS&BVBV1Q"Z4QS"7RC*9S#BG
MX3BIX32=TC.;SSZX^#:?U3:@U$*\^D*]^CJDVD:__$&OYS^IWS^JWT*NY3J8
MQT:RZD:SZDW#_TFV[DFW[DBT[$_$_TR[\E'#_4Z\]E'#^U#`^5#!^5"[\5?!
M]E[&^EJXYV3)_67%]VK-_PF*R!60S"N>TS6.N$2OXT2PX4[#^E#%_EK!\6O,
M^AB1Q@R,NR^IUU7#[%S`YUN]X5_$Z1^0M2F8O4R^XV'(ZQV6MU3!XA2.KAB0
MKAF/K&G*XR"1J$JYT#>@LT"RR!9<8SJ"B%2@IW;+TH#/UU6TNUS!QX'4V1I>
M846EJ7/-SB=I:%FZMG7(Q3N=E3Z@F#J:A5&NCVV[D4)W5%ZJ=HC,E8[)EH*V
MBIW7I7:W>FN78X.[=ZK<FT%I,:S;FK3CHVZI4W&H4;#=E7.G3H:V6WRI1+_@
M=:C%4Y2Q-LS`"MC+$/___P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"T'^$D````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^
M````OTE$0508TVV+30[!0!A`O^G,&+3J)]7$CL3.7H+$29S#,=S!0B(22^>1
MIE$+(81.YU>--6_Y\A[`#PB6W=4@TFDF9(71L#/8$1!\HLWUH@0AN-8,'D#`
M9Q+QDUC$V9ZU?2*<XD'CGLW1B$1%+[E9"1Z@:IG.Q@%&N-4/49&[RK/V4GKH
M7'\J8XK".(65%9MZU\OR.#E*I=U8H:5ZK^\H'D97J>RW$JQ4C&[#:>/%N5;6
M*1(<*,%^^T1Y;JPV\(</47150_3?GM\`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]L8BYP;F<`````````````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#(P-#<`,3`U,34T,S,W-C,`,#(S,30V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````2````#`@#````6,P=C@```P!03%1%````____S!\AS2@JL"@I\D5&
M_%98_EI;T<+#_>_PV\W/U,[/BX:'SLG*__[_U=35Q\;'U-75P<+"_/_^SM71
MO\G#[//NN,&ZLL*UR\S+*V4CY>WDDJ>/=I-P>J%Q@:)Y57A,1&DX*UP9-V$A
M\/'O/5D98G0_JZR@Y^?FX.#?S<W,M[:MHG54M85EW+FNT*RBQ+BWS```?P``
MS@,#T`4%S`4%S0D)S`L+U@T-V!`0T!`0S!`0TA@8X1T=V!L;?Q(2Y"$AU"`?
MSB`@G1D9TB,BIQL;Y"PLUBDI[B\OLB,C\C4UORHJRC`PE"0DX3@XU38UO#`P
M^D)"U#DYQS<V_$9&X4)!TCT]ZD9&QCL[_T]/[DI*_E!0^5!0Y4M+]E=7^EQ<
MNT9&YUA8_VAH_VIJ^6AH^G1T]WIZS+N[S+R\S\#`_.OKW<[.S\+"N:VMX-+2
M\N3D\>3DWM?7__CX^/'QZ^3DV-+2LJVM_??W^_7U[NCH[.;FZ>3D^/?WW=S<
M_O[^_?W]_/S\^_O[^OKZ^?GY]O;V]?7U\O+R\?'Q[N[N[.SLZNKJZ.CHY>7E
MX>'AVMK:V-C8U-34TM+2S\_/SL[.S<W-S,S,RLK*IZ>G____````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````(_A:K`````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```#`241!5`C78V#``HR,G".2X_QL
M3`U-+!V\0J*!0O:^"6FIB4',3$[N?E'Q22E`(9ZRZO*J4EYU;>["DN*BBDJ@
MT/0)?.VUD\05%42Z6^OJVS2!0@*,+;T3)665E.55&NI:>B8"A6J:-`2GR$BI
MJLE),S9W\4\#"M5W]D^>*BJAHRLFW-C1IR4$%"K(SDS/X.#2U\OBS,_+,<@%
M"H6Z6)M;V;FQLK''Q88%![``A1S-#(TM;#T"(V/"_7V\/5VQ>0<`W?HO]\0B
M_^0`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VQC+G!N
M9P``````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`U,``Q,#4Q-30S
M,S<V,P`P,C,Q-#$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#
M`%!,5$4```#___]33U%\=XQB77Q345U65&F2D*<Y-7@[-W=#/W]`/'E,2(9C
M7I]75(E/3'I@7));6(AR;JAG9)AM:I]K:)QK:)IB7XUO;)]B7XQT<:9S<*-C
M8(Q_>[)^>[!]>:YZ=ZM]>JR#@+..B[MK:8V1CKV4D<"3D+]<6G9W=9@R+W8C
M(4DD(DH_/'X].GI`/7I&0X)*1XDN+%5(18-&0W](18%*2(,U,UQ23XM/3(57
M5))13H=13XA448M!/VL^/&5.3']858Q(1G-?79A;6)!*2'5&1&YC89QI9J)C
M8)A>7))44H)03GQ758565(-?78]<6HIA7Y%U<JUG99EU<JQI9YMY=K!F9)58
M5H!A7XN!?KA\>;!V=*A_?;2`?;1U<Z:!?K5U<Z5_?;)^?+&`?K."@+&"@+"(
MAK>`?JN.C+R.C+F-B[B3D;]D8W8S,7-"08-.37=K:J-=7(QL:YA\>ZQ45'V0
MD+!)25,P,#%X>8$W.4(R-#,("0@#`P`)"0<>'AL;&QD;&A%C85CDMB'HN":U
MD2#UQSKJPD;^U%"^H4'AL!V=>12IA!CNNB^^F"OZR$++JDH8%0U)1CZ>=A#R
MNS7\R$;^SD_YRE#(IDXJ)AT2#PJ#?WM*2DH0$!`%!07___\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````"Z4EM8`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK
M/@```,%)1$%4"-=C8,`"=+3M)7.4/#55\O2,K3S"$H!"VN81V>DB+JSE!EP6
M[B&QR4`AHX(,Y41;F?H&<4-G(=FD&*"06[&JHA</6VU=+F]A=(J"&%`H4CU5
MV)2O8M[<.6E!<?(2_D"AK'0):UV-FHDSJ]FCY*0#!8%"F?&.^I95LWKZ)E6J
M284'>`.%2@1,.$H;NUO:)C25B1;Y\0.%@LTX\YDF-T^9VC%C=JBOCQ-0R(9;
MBZ6UJ[=_VO3V3F8'5SMLW@$`FZ`QN]-8(4,`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O;&LN<&YG````````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,#0U`#$P-3$U-#,S-S8S`#`R,S$U-0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$@````P(`P```%C,'8X```,`4$Q410```/___P9#`!A6$2F"'Q5S
M"6ZW9!10"B5^&"MJ(3R.+S1U*D24.$6&.U6A2%RH4%&41FFS7G"U97:[:A=0
M`!=/`,SA-<34)O+X/O3Z0OO[3?__3^;F2?GY4,W)&.GD1NC9+]3".LBO%-F[
M*]BV'>[*5\F>(8!E&?#'4<&-"L*5,__2:LR(`,R)`="+!<V+"=*4&-VC+]JG
M0>RV2)=A`)EE!9YM$L"''=>;*ZI\)\^=/NBP2KR00/K!7LRC5\2>6=>O:-:)
M#=ZA.I=Q,KJ"+L-V$."=1K9C`+=E`;=G!;MI![MN$L1[)\:$.^.<3N>@4<%Z
M-*A7#>2//I94&^B54.:54,Q8`[-0!<Y?#=1L(.&`./&44,Q6`,Y8`[9/!_VD
M9/>@9;%%`>2$2N:&4*X]`+I*$.2!3<9F..)^4=9F.MUX4+=$&,A0)LY9+\Y:
M+ZDK`==J3J49`*8=!;`G$*PO&+(W'\Q,-=A=1J@:!;PT(:\=#;1$-K@H':$T
M*J4W+=!63*$)`)TO**HX,*LW,==949$F(<DZ-;(X-<-(0L%&0M144)H``*`#
M`YT#`YH#`Z`*":,*"IX-#:D4%+DD(9(C(Y@F)J`L+*@P,*\T--)$0M!"0KP_
M/M)&1L5&1LE)2=A/3]9/3\Q,3/___P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"7L:_8````!8DM'1`"(
M!1U(````"7!(67,```!(````2`!&R6L^````ODE$0508&67/L0X!010%T#=O
MAC5B$;(VF8@0B49$PP\H_)-_\A_4$E'91",*!&N%W7WSC-HM3^XM+L!?!`3<
M'$3IS+?L9442^Z6"BQ@W;TG5W"M7_1AZ,2@HJ)Q?IAT]UHDQ[\X$$+`@<LN4
MT.=3KF-&CI2TS)9B3[&*CYI^0_LC3#>IW"*.:J[U)&(KI#F_A<]88D<Z)\N(
M8MZ?+CHZ8S=T4,1,F%;JGUIE>0,)EL,@/S1Z2G>?H0E6N[\[`%]V\U/^2MW5
M<`````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]L="YP
M;F<`````````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$Q,#$`,3`U,34T
M,S,W-C,`,#(S,34V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````5````#0@#````<4S54@``
M`8!03%1%W=P`W]X`WMX`W=T`VMP`X>``V]H`R,8`^OD(^_H)__X._OT/__\6
M_?L2[.@!__\+__T$__L"__\)__H&\>@`V?\0V?\.V/\/V/\-VO\-W_\1W/\.
MX?\3W?\0SO<%=?\%=?\#=/\$=/\"<_\&=/\.</\/=?\4<O\39/(((N\`(>X`
M(.\`'^T`&>D`'>T`&^L`#]X`!OP`!_T`"/P`%/\`$?P`$_\`$OX`!_(`,^(+
M,^()->0-->0+-N,+..`%-MP`.M\%-]\&+=0`EY`,EY`+E8X*E8X)DXX,DX\2
MD8\4CHX4B8H2@X0-M2X`M"T`LRT`L2\`KS``K3``JBT`I2D`X0T!X`P`X`T`
MX0X`WPL`VPD`^@4,^08,^@4*]P,#^`0#^`0$]@,%\`$$Z0$`Z`$`X@``X`$`
MWP(`V@$`TP``````````````````````````````````````````````````
M````````````````````````````````````````_H&=V@````EP2%ES````
M2````$@`1LEK/@```#Y)1$%4*)%C88`"1B@%!BP<J*(0819V!E0`$65C_`^&
MC!":"2+*A5V4&-M@HM0V%RC,@.3>_R@F<*"*0DP``'IE)O7W!?A!````'71%
M6'1C;VUM96YT`$-R96%T960@=VET:"!4:&4@1TE-4#F$.24`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]L=2YP;F<`````````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,S4`
M,3`U,34T,S,W-C,`,#(S,38V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````
M6,P=C@```P!03%1%````____T`4&\C4VIYV>U=35Q\;'R,G-QL?+]O?[Y>;J
MV-G=R,G,O;[!^/G\Z>KMY^CKU=;9T]370FN_1G##16[`16Z_1W#!2W+`47G,
M4'G)5'K&4W?!5'C!8(C87X;467S&7(')3FRG2F:>9(?07X#%5W:S4W"J<9CF
M<);B8'^]7'JU9X?);Y'69(/`=);=:XO*@:;Q@*7O=IC:87NQ=933B*OSA*;K
M?9[?BJWTA:;K:H6\<H['B:KN@)S6D[/TCZSIE[7TD:[HS<_3Q\G-^?O^\O3W
MU-75Y^?FS```?P``S`$!S@,#S`8&S0D)U@T-S0X.S`X.V!$1U!86E!$1TAD9
MSAD9X1T=BQ(2U!\?Y"(BWB0DG1H:[B\OZS<WV#(RX3DY^D)"NS(RLC,R_$='
MYT%!^$E)QCL[_T]/_E%1^5!0_UA8[%)2[E-3]E=7^UQ<^EY>]V5E_VIJZ6)B
M_6UMS;Z^T</#S+Z^V\W-S\+"Z-K:W=#0_O'Q]>CHX-34_?'Q\N;FU,K*__3T
M\>;F^/?W_O[^_/S\^OKZ^?GY]O;V\O+R[N[NZNKJY>7EY.3DX>'AV-C8UM;6
MTM+2T-#0SL[.S<W-S,S,RLK*____````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````&8MNS`````%B2T=$`(@%'4@````)<$A9<P```$@`
M``!(`$;):SX```"V241!5!C3;<$Q2@-1$`;@_Y^9MUGW81#/DRIE0,@)!"]@
M+8B6X@T\0\!>.QN+%+E)($AB<#?[WHP'T.\#_B`6N,RY[(^]ORW;U4UZ$:!K
M.O\9AL*KI-=&&*;Y@OVIJFBK;3*'X?6!G)R[4T1#Z2":\;E10ZU>2IBE6\'C
MT\>[PCUJO5>]2R"F(D?.8AVS^&QDY(&8'[[Z,,LY2;C'L#%L=R=G<I/",G@I
M,'Q7FJ;N;&)CE2#QCU_LNDF9^_9S;P````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VQV+G!N9P``````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C`S-0`Q,#4Q-30S,S<V,P`P,C,Q-C<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____!I:[@
MQ,V#$#A2"B.#$3F%$SN'%3V+&$"'&#^(&T%=$RV2($B6)DUE&S6;+%.?,%>B
M,UJ8-%>>-UNQ1VR`-$ZU2W"E1F>:06"Y476F2FJ\57FK3V^S57:Q5'2O4W.V
M6'F:2F:^77^V6GJF4W#(<I"ZG*;%J++2M;_#K+3KT-GNU-WGS]?QVN*"##:#
M#SB$$#F#$#F'$SR(%3Z%%3V.'$6.'46*'421($B+($:3(DJ+(4>*(4:0)TR2
M*4Z/*T^A,5F4+E)N(SYU)D*E.5]\+$F$+TUV*D5_+DNJ/F6=.EV>.UZ',U&N
M0VF--E6)-5.P16N6/%R1.EF3/%NE16>?0V2L26R<0F*E2&F+/5F[57FK3F^]
M5WN_67V00U^V5GB41F+`7("^6W[`78"_78"[6WW`7H&]77^Z6WVW6WRA4&V]
M8X/%:8JX8X&W8H#":HFU8X#$;(O%;HW#<8[)=9/+?)BYFJ6]GJG1N,'6O<;F
MS=:YI*SZ^?KY^/GX]_CW]O?N[>[IZ.GFY>;@W^#5U-74T]3-S,W,R\S^_O[+
MR\O)R<G___\`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````>0+T?````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+9)1$%4"-=C8,`"
M6%F=$TMS0NU,C3@L!?VBTT%"_%$E!3%.7$;LY@)>4BD90"$>L<)B>6%N%D-.
M/E?Q.&4YH)!'MEJ6CQ6;@8FUD&ALJJ(T4*A&3[>22;V\0D.365NGNDH+*-10
MU]S6T=7>VM)8VUG?U-8-%"K+#W.PM;$7"4_++<I358H'"JEX6QCH&_,Z!LHD
M)T0&^;L#A23@+LJ4E0SV=0,*.7$9LIL!7924H1`1$N#I@LT[`%SR*EN4OJ'T
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O;'DN<&YG````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,C`T
M`#$P-3$U-#,S-S8S`#`R,S$V-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P``
M`%C,'8X```&`4$Q410```/___P!P&@!P&P!&$`%Q&P%Q'`-R'0-Q'05T'P5S
M'P=V(0ET(@IY)`IX)`U[)PUW)@I1&Q!^*A)Z*Q2!+AB%,AA^,!%9(AV(-B&,
M.A^#-QEB*B:0/QMG+2>(/BN41")R-2%O,R^82"%J,R9W.2AY.S"/1C6=336<
M33".1BM^/RI[/2Z"0BV`0"IU.SJA4CJ@4C"%1#"$1#2+23.)1SZD5CB53C:-
M2D*G6CJ23C)^1$:J7D&<5C^74T*<5TJM83J'33N'34VO9$:@6TVN9$FD7DBB
M74^P94^P9D^O9E"P9TRG8E&P9TZJ9%&O9U"M9E"L95"L9E"I95"H94:465>N
M:UZT<EZS<EFH:V2X>&6U>&BZ>V:U>&J[?3*'162X=____P``````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$>_[2P````!
M8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````G4E$050(UV-@P`)8
M6*0=8D/-Q+B8.(4D-:R]0$+B5E%A-E(\S.S\$DH6'OY`(4&]B'@W.0%6-CY1
M>5,7/U>@D')(=+"F,`<KMXB,OKV?MRU0R!%ND+JUEZ^=,5`H)AQND'N`L[DA
M4"@2;!`OT"`G/U?+."V@4)":,`<ST"`#>Q]O6Q-=%:`0PD5`@W14%8%",(,\
M`YW-C;059+%Y!P#5\QJ8R<Y+C`````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O;6$N<&YG````````````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`Q-S<T`#$P-3$U-#,S-S8S`#`R,S$U-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````%0``
M``T(`P```'%,U5(```,`4$Q41>4``N$``MH``=P``.<``.H``,8``-05`,@&
M`-,&`-H``.4%`-```-X#`.4``.D``.@``.,``/\(&/L.&.\3%><0#>0)`^0(
M`.8*`.$3`-(;`-LM"M\K"M<5`.,0`.0/`=T2`^`-`NX%`?4#`O,#!.T#`N8`
M`/<`!.P``MH%`-$,`-(2`-,7`-$:`,@?`,$O`,`S`-@]#<<>`-@9`-,1`-@E
M!\\1`.T(`O@$`_<%!/($!.P"`_\)#?H&!NH.`N@A"O$Z&O%*(.1*&--$"MA2
M%<M%".)/&>E)%_%!&.TY%/1&(?$R%NT&`/D!`?<!`O,!`.L``/X``/8``/``
M`.D-`.$C`-@V!<A"`\1#`<T]`+XD`,0E`.9"#=DU`MTQ`^0D`.\9`/8%`/X"
M`?P"`_```?D!`/X&`/\'`/('`-D-`,P@`,L_`=95$<Y``,(N`+HF`-U'#-,V
M`-TN`-\0`/,-`/H#`/\!`?X!`_@``/(``.X``/4%`/L%`/$"`.0"`-P2`-LQ
M`-Q,#\9)!K]-!KA&`,!#`=$X`-PE`.4,`/T``/@*`/8&`/<!`/0$`.X1`.4=
M`-0H`,DN`-)#"=U5&=Q4&K\P`-<W!]D?`.P2`/4(`/P#`/\"`/\"`OL!`O0`
M`/L"`/L``.\'`.$>`MLS#-4^$=<Y#-P7`.4/`.H4`/`E!^XW%>LT$NH<!.@%
M`/@#`/T``OD``/X%`_T$`O(*`.(;!MLI"]0K"MHA`^T'`/D-`NX@"^DA"ND2
M`.@!`/D$`?$``/0$`_@&!?D'!?<(!?8-"/40"O`-!NL$`/@%`?H!`/@#`O<)
M!O@*!_@&!/<"`?L#`_D#!/0!`^X``N8"`.H%`O($`O@$!/X&!_H"`_D%!?0$
M!?,#`O8"`OL"!OP#!^T!`^@``M<'`-P(`.,&`.4"`.L!`/`$!.X$`^H"`.<#
M`.4%`^,$`.`!`.(``.\!`>8``N``````````````````````````````````
M`````````````````````````````)8:9A,````)<$A9<P```$@```!(`$;)
M:SX```!Y241!5"B18V1@!('__YD9$>`3HQ`C-J".5=0&JV@@IM!K,<94K&JK
M4+F?7ZDPO&=D[,*J=A8KFL`)2\:3C!L9H+P?'R3!],XWKPL9#\`5/9<"4V!5
MEQG]-@.IA0D)"QD9B_H9"_H\=C,R/H2JU+@)(I6S7G7Y;F$$`'2Q'Y#4<M7Y
M````'71%6'1C;VUM96YT`$-R96%T960@=VET:"!4:&4@1TE-4#F$.24`````
M245.1*Y"8((`````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O;6,N<&YG````````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,#0T`#$P-3$U-#,S-S8S`#`R,S$T-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$@````P(`P```%C,'8X```,`4$Q410```/___\<\/?]G:-6SM,'"PK*S
ML]35U.#@W]W=W-75U,W-S,T!`,P``'\``,T!`<P!`<X#`\P#`]`%!<P%!=$'
M!]`(",T)"<P)"=0*"M8-#<X-#=@0$(L*"L\2$ML4%-@4%-X8&-(8&)01$>$=
M'=(;&^0A(=0?'^0D))T9&>@F)NLK*]@G)^XO+Z<A(=TO+_(U-?(X./4Z.K(J
M*N$X./@^/OI"0N$[.](W-[LR,N`_/OQ&1N=!0?Y*2OQ)2<8[._]-3>5%1>Y)
M2>Q(2/]/3_Y04/),3/U14?M14?E04/Y34_904/%04-1&1O975_996?I>7NE9
M6?UD9/=E9?]J:O]L;,ZDI,RBHLVDI-:LK.&XN-2OK^['Q\JJJOK4U.?$Q/_:
MVOG5U>K(R/K9V?C9V?[^_OW]_?S\_/O[^_KZ^OGY^?CX^/;V]O7U]?+R\O'Q
M\>[N[NSL[.OKZ^KJZNCHZ.7EY>3DY.'AX=[>WMO;V]K:VMC8V-;6UM34U-+2
MTM'1T=#0T,_/S\[.SLW-S<S,S,K*RL?'Q\3$Q+^_O[R\O+FYN;"PL*>GI___
M_P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````-X@A_\````!8DM'1`"(!1U(
M````"7!(67,```!(````2`!&R6L^````O4E$0508TVW!,4X"010&X'_>SLZ;
MF07$Q#5&KL0%;$D,)Y`*2WL;#;&THJ;U`A[`,]A("`$!Y^UCQP/`]P$G#'H8
M7-?RO=HD%V*LX@<!=?]*5]M=LNS9!0O"1?\F;]>_B3RSCS:!<'F[D.7FH,X%
M]MS^@?#EAS][0:P"=[JV:6$QRMHYYEP8(C+F_>[3@JK(E*61]#KVD><@A)DC
MJ&HC]V[&TR<0_$,!U:,('$]*,B`\EVA5I7DK^87IT>",?]IU0DA69)WY````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]M9"YP;F<`
M````````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,C,`,3`U,34T,S,W
M-C,`,#(S,30S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!0
M3%1%````____U34V`!>4.$NS4&+%9'73`!!:`QJ6`QJ5#2.8'S2C(3*`05:V
M.DN@.TR>66N_9'?197;/:'O39GC-`!N1!1^3"2*4"AMF$BN9$">($BJ+$BF)
M&#"<$2)N&C*2'S>@'#*+&2IW)SZE,$:J*CR*.$ZP,D24/5&A2%V\1EFK4&7"
M5VS'7G+,5&:U:GW3:7K%=(7,*#Z3=7]2=7LQFI\*J:X/QL@*L[4+O<`1R\T:
MRLPP?7X^S,P`SLX#S,P%S<T)PL(-TM(86ED+Y.0AU-0?N;H;T]0F[NXOX>$X
M^OI"__]/_OY0^?E0>7@GW-Q(U-)&Z^Q>K*@!IJ$!R\@UT\HU]NQ.[^91T,(%
MULD-V\T8T,(FZM]&J)D4<&@4XM1"Z]U-TL9*E8U)95H#4D@)@6L`@VT'B'8G
MG(H[>FY!9DD`@%<AICP%L4<0_%A&_V!/^V%1X2L=ZSDK]4LZU4$UY4Y"\EI,
MV!X0Y"$AIQL;L"$A[B\OLB,CN28FO"@H\C4UORHJQ"TMP2PLQRXNRC`PS3(Q
MTC0TSS,S^#X^^D)"VCHZX#\^_$9&Y4)"_DI*ZD9&_TU-[DE)_T]/_E!0\DQ,
M_5%1]DY.^U%1^5!0____````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````8^0&)@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX`
M``"L241!5!C3;<%=2D-!#`;0+W,G-W#U@C]8L45:T.WYZ`I<H$LH]4$1"OI0
M6I.9)"Y`SP'^(`A6^X?-CWJLUB2S/!7@EFM&CR"R81H9!9?R>8A]O[Y1HEE8
M47&X&M+.[@N=.XWLAH*![W+Z%I'9&I,V%'#LY"OM[34F8GT.%'A?9!NV[R<E
MTO82J%CJ,8.6CZ2GA7GOJ&CJ1O1QT?N4S=U1899<9SI2&3,\$O_X!9;`5`%+
MB2FO`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+VUG+G!N9P``````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C`R,``Q,#4Q-30S,S<V,P`P,C,Q-#,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!(````,"`,```!8S!V.```#`%!,5$4```#______O_'QL?4U=7&Q\?5
MUM74U=0G?0HTA!1/GB]&ABQ.C34[C1A!CR%-G"M-C3%?JSY6F#I5D3ILMDUF
MJDE=F4)OM5$W;QM+EB8]=2$_>"-#?29$?BA'@BI9HC5*A2U>ICI1CC-FKT)I
ML$9AH4)LLTIFIT9QM%!LK$QRM5%NKTYJI4],ARY/BS!5E#53D#1>G#YRMT]R
MM5`N;@,^>@U,B!U>F"]6AC!7AC-<C#9OIT)MGT9ZKT]YK%#GY^;=W=RY&P7!
M)A#.-R'<2C7#1C3H6D;25$+K8U#C8$Z[1C?%$0#!#P"_$`"T#P#`$0&_$0'`
M$P/)%07%%@7&%0?&&0K`&`G)'0W1(1#0(A31)QC,)QC4+!W=,2'=,R;>.BOB
M/B_K1#7J1SKL3#[N44+V54;;2C[T5TKZ7U#S6TWF5DGS74_I6$ST75'Q75#P
M7U'RB'_()Q_'2D+/7%3><FK`"@/!%0W;/SC__O[Z^?GX]_?LZ^O=W-S2T=']
M_?WZ^OKW]_?V]O;Q\?'L[.SIZ>GAX>'8V-C4U-32TM+/S\_.SL[-S<W,S,S+
MR\N[N[NRLK*GIZ>=G9V4E)2+BXM_?W____\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````"6U9^"`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```*E)1$%4&--MP3%.0E$0!=`[,W?>
M)RJ6;@F(R]'$PF@(%0NP<"\&.DHJMV!/B,&\_/]FG@O0<X`_!&^(QX<Z?-4Z
M%"?M78&,9^$XC<5I5@H4/7Y2NX]*,W,V***^4GIO3AH9#0++->N1WR*B*ID?
MQ)/O#]O3)")4R4P0Y.)>/INKFF7D!(*[E?8A;F;./CMGNRAL:0CS8G-I_3H2
MBHTA7^X:;R_M*L^9^,<OE]Q&E7\/<@``````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;6XN<&YG
M````````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#(T`#$P-3$U-#,S
M-S8S`#`R,S$U-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`
M4$Q410```/___T^!J%"#J52'K5*$J5R/M96]VUJ+KF>:OFJ8N8"KR5",LU:1
MMV":P&VERGFQU86[WHW"Y(*RT8_#XXN\W#V2P3R1P$*6Q4&4PD>;R4J>S%">
MR5:HU5ZOW&*SWW"^Z7C%[S>4Q#J5QCJ6QCJ5Q#N5Q3N1OSR1OT&<S$&;RT*9
MQT"5PT*4P$NDTTNDTE>OW5*ET5>NW%&CS62ZYV2YYFN[YF>TW7'$\'O,]GO(
M\8#.]W[*\H+,],>))]NE2-.0.,>11NRQ9<V$+^2?4.VH7O"O9/*R:+U@`,=T
M(-F,0+U=`\!A#;]G$KU7!<-H&(I'$:9C*O.I:K%J,NF85]V26;UL.\A8']9N
M.,$\`[\Q`,`X";PL"+PL";\Q#;TS$'D4`'D5`,8T%<<W&L0]'Y<O&9XQ&Z<W
M(>1-+ZDZ([`^)K-`*.93-;5"*KY'+KM&+;A$+,-+,<!),,A.-,5,,\M/-N]@
M0M!4.O)D1M99/O1F2MM<0L!1._1I3=]@1N1D2?1K3_1L4.AG3.MI3O)M4?%M
M4>YK4-H_(<]")]E/-<)',,I,-.Y:/L].-M=7/N1=0\94/N5B2?5K4/!I4.UI
M4-=A2M]F3_!P6.1K5>QQ6NUY9/6$;W@0`(0:"O5V9/!W99\O(>I@4/___P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'!(_.L````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^
M````K4E$0508TVW!.V["4!`%T#N?!\1"((K(%$@I8GIZ%D)-SQ[8%:R'@B+B
MYR"DQ,^>&18`YP`O".M(Y==F<;3B9U4=AQ];QK*^?H=VDY'0_%`,$AA$'%W\
MMS<EJOJI@4+JGOQYOG.BWJFP#,5NPONAV>=-*$U_FPS%65+TC:\B)-'F`$/S
M0YQ2R4+L3>=0N!8>E"Y,'&;>0M&-PYAYJD1FV0R*4B-4]#0+;R,\\,83*.A-
M)ZW1/](`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]M;RYP;F<`````````````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#(P-#8`,3`U,34T,S,W-C,`,#(S,38S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````2````#`@#````6,P=C@```P!03%1%````____'X%#*Y)1-8E43)9H
M`'`G`W(J`W$I`W`K!70L!7,L!7$L"70N"7,O#7LS#7HT"E$C$'XW#W<S$GHW
M%'DX&'X\$5DJ&'T]'8A"(8Q''X-"&V<V)XA)(G(^(6\\+YA4(6H[)G="*'E$
M,(]1-9Q9*WY(*GM&+H)++8!**G5$,(5.,(1.-(M2,XE1.)58.)59.)19-HU4
M0J=F,GY-1JII09MA0IQA2JUM.H=6.X=61J!E3:YO2:1I2*)H3[!Q2*%H4+!R
M3*=L3JIN4:]R4*UP4*EO4*AO1I1B5ZYU7K1\7K-\9+B!9;6!:+J%:[R':KN&
M`$88!70J!G,K#74P'8A`'X)`(H9#&6(R,IA4,H=//J1A.I)809Q@/Y==/Y9;
M0YQA/X]96*]U4J)M7+1Y6ZUV6:AT7*9T9K6!:K>$<K^,::^`::A^CLJB1IYB
M2:!D4*IL<;F(?,*2C\VB.)U5-)!/@+Z1)HE`H=6O&GTR@ZV-$'<F%7PL%GLL
M-(Y'IM"O%GDJ1Z9:CK25F;B>-99#J\:OOMK"T.K3)($N+(<UI+VF&'D='WXA
MO-*\.9,WZ/?G:+E?,849S-7'U-W.S=3'\_CM____````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````,!A5JP````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```"_241!5`C78V#``@(#(RP#/`TD
M>-BXA*1431U!0N(FOEYF3+4]G`*2"L;VKD`A0:TT'X>ZCNZ)-7W,T38NMD`A
M10\_]]+*:A;6\I9&"Q>G.*"058"G86<#7]>DY)()CL[FND"A#._8,-&JIM;)
M]>U9!=9&VD`A'SO9$.'F*;UM4_N+\F.BU(!";BHB',&).=F%%;FI\7J:2D`A
M?3%NMJ#P]++BXLP$70UE>:"0-"\;.W]H9(I_4IZ1CKJ<##;O``!_.RZ1=/H0
M8P````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VUP+G!N
M9P``````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-P`Q,#4Q-30S
M,S<V,P`P,C,Q-C4`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#
M`%!,5$4```#___^^MKVTJ[37T-C&P\IH6X5_>)5I88QM9X>-B*.YM,Y!.WY3
M3H=E88DH(W@C(%9'0I144))M:+564HUR;K>'@\&;F+\7$G<B'W8H(X,8%DLI
M)GHL*7LO*WPS+X,U,H8V,X(].HX\.(8J*%]"/HH].G\V,VXR,&=(19`Z.'%4
M4:%34)U64Z%"0'U<6*I85:10395'1(-&0X%$0H!(181,28E$07I*2(923Y).
M2XM23Y%038U449->6Z-F8Z]?7*-I9;%C8*=A7J)54HQ=6IEO:[5L:;%G9*EQ
M;;=P;;-Q;K1?79-]>KY\>;IT<JYX=K-Y=[.`?;N%@L&!?KMM:Y**B+F-B[MT
M<I>8EL"FI,DC(7DF)'TF)'DM*WT\.I`[.G4]/'A-2XM759Q85IQ03X]759A<
M6J!,2X1A8*A=7)YH9JMK::]Q;[AQ;[5N;*]Q<+5A8)MS<;5E9)R`?KZ#@<$K
M+'PR,GY.3H5F9J=Q<;%X>+MO;ZAO;Y"UM;W*RM+#P\F]O<)N<*AW>;!M;J%B
M8X5!18E:789)37.XN<*HJ[FIJ[*1F:M[B)=SCJF&G*)0:6[!Q\B7KZ2^V[^5
MKWV`D6K*V;6IHXJZL)"EE6ZZI8#*MY2GFX[PZ.2XJZJYN;G___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````"5#&1>`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK
M/@```,!)1$%4"-=C8,`"I*4U7(*]:_@ZU&(4!`T<14%"*AE!U5RS9TZ=Q1FO
M;>_I!102,/?W[9G"UMK.,:-%WRTO&RBD55A:,'V"1&VH5-\DX=R<+*"0B%B1
MZQR>BKK.XJ9I@>[.UD"A$#^'MGZCN(9ZW:K)S4ZV5D"A$@_-LE[V\OF-F=P3
M*]-L3(%"^8:*DKSS(KJ[Q.>&)Z=:Z`&%4I1E8Z-]F)E862+3+<U,$H!"JG+\
M,O)*.F%1`79"2<:)ZMB\`P#4$#'F%:SLLP````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O;7,N<&YG````````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,#4P`#$P-3$U-#,S-S8S`#`R,S$V,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$@````P(`P```%C,'8X```,`4$Q410```/___[)K<*Z5IU](6YU_
MF-S%V;BGMY)RELZXT8%7B69;:K>KPGYFE\N^X;.KR6Q>I$`QDEA*GY:+TYN2
MT71OD3XRE%!%HD(YIE))K3\YA%Q3O49`BU=0HUA1I%Q5J65>MF9?MG-KQ'QU
MSC`IES@PH38NF34NF#4NES4OFC8OF3<PF3<PF#HRGCDRFSDRF3LTG3TVGSPU
MFD0\IT$ZHD`ZH#\XFD0\HT0]I$=`J$,\GDE#JTY&L4A"HD])KU1,M%1-LE!*
MJTY(IEA1ME1.JEQ6N4A#CF%:O4Q'E&5>PU--GU%,GE!*F55/HDY)EEQ6KVQE
MS65?P65?OFICQ%Y9K7)KRW9PSW5OS7ART7)MQW!JP&YHNWUVTG-MPG]XU'UV
MT7ESS'UWT7UWSWITR%U9F8F#THN&UC0PG#@SG3LVGSPWGFIFO5U9I8)_THB&
MM6QK@$(_HDE'HH6$SV]NCFEIJW9VOH.#REUCNF-ILGA_PX*)S(V4S[7,WY:K
MN9FUP\KI]KS7X<#;XK;4V:?#N:>YJX^=DL/:QXZF>9*F8HV87Y"88)66BK*W
M8^N'<^B.>Y)=4=%F5/2";<)N7_")=^N&=;F!=_>RI>.DF*M=4<%00H$U+=9T
M9[E)/G1%0L-_?O___P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````.&,;&X````!8DM'1`"(
M!1U(````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`)8N(LG\7'R
MEV>HZ1K;>X;%`87F]D^=/&WZ/"8Q35/'H,AX9:#0K!E]$WLGS)PCJ%I15UM3
MI`04$F5GF\+#S%N8*5'9U-I8I@@48A46F2U0P,%E;E-5W])0*@\42LV-%C)3
M21>7E*YN:V\ND04*I<6Z9*EK&5J[!N3U='2F>`.%DOVM=-0-+)V#(Y*ZN_*]
M/(!""K;Z&GH6#H'AB0G9.;Y^,D`A)R,-;1,[]]`8Y:@0.1\W*6S>`0"[WC&#
M6,D>LP````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]M="YP
M;F<`````````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$U-S4`,3`U,34T
M,S,W-C,`,#(S,3<V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@``
M`P!03%1%:P``<P``<UI:<W-S<WM[>P``>V-C>WM[C(R4E)24E)2<I9R<I:6M
MI:VMK8R,K:VMM;V]O;V]O;W&QL;&QL[.SGM[SH2$UI24UM;>WH2,WM;6WM[>
MWN_OYX2$YXR,YYR<Y\[.Y];6Y][>Y^?GY^_OY^_WY_?WY___[Y24[YRE]X2$
M]XR4]Y24]YR<]Z6M_P``_X2,_XR4_Y24_YR<_Z6M_ZVM_[6U_[V]_\[._];6
M_][>_^?G_^_O__?W____````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````,,"OK@````EP2%ES````2````$@`1LEK/@```"-)1$%4&%=C
ML(,#?2A@L+,3DT47DN,6$$97)2J'K@H.!I40``#K+7/9U%''`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]M>"YP;F<`````````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#(`
M,3`U,34T,S,W-C,`,#(S,3<P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````
M6,P=C@```P!03%1%````____U34V_):7^YN=X.KJYNCHQM;.P\K&$GHQ)XA$
M`',A`$<4`W`A!7,E"7<H"W0I#74J#74K"E(?#W@M%X$V&'XV$5DF&GXW'X<\
M'X([&6,N(X,_(6LV,(]+*G4_.)92.)-2.))2,GY(09Q;.XA12*)B4*II1I1=
M4*=H4*5I5ZYP7K-W6:AP9+E\9K=]:+J`9;1[:KN"<+^'`&X>`$@3`W,A.H=/
M9+9Z9K=\[O;P<H1VP<K#NL6\T=O3B9N,E*&6U][8Z_+LM+VUR-#)QL[&]_CW
M3V9+:7MD?H5[8&=<C)5^8F$^O[NP9%`?:EDQ85E'5E!$?75LV-7273`1KJ:A
MPZRFLJFHC'MZY"$AIQL;L"$A[B\OLB,CN28FO"@H\C4UORHJQ"TMP2PLQRXN
MRC`PS3(QTC0TSS,S^#X^^D)"VCHZX#\^_$9&Y4)"_DI*ZD9&_TU-[DE)_T]/
M_E!0\DQ,_5%1]DY.^U%1^5!0V&9FX7!PZWQ\]8J*U7IZY8>'\I*2_Z"@V=C8
M_O[^_?W]_/S\^OKZ^?GY]O;V\O+R[N[NZNKJY.3DX>'AWM[>UM;6U-34TM+2
MT-#0SL[.S<W-S,S,____````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````W&*UXP````%B2T=$`(@%'4@````)<$A9<P```$@`
M``!(`$;):SX```"[241!5!C3;<&_+D1!%`?@W\R9/]?(YB:RHME:+4%%*11>
M2;94Z7@'SV'+;;8A6](0A4HBN6?FG#,>@.\#_G`XW8X+&:]#@'Z^YEF^"]CN
M#M4Z$4P=E13AD8>2&]'32KN;Y<@@S$OZX1>H_[@_EV2\]AA*F^J96>-^&QTW
M>,PKLXA(9;^,_&`@[/%[MWT>T_?!XTD]LDT`3UVH7SUKNKC\4A$$\!0/WW;*
ML5AH357AP:S>L>E-H&YJ'?_X!1BX7+.40TQ!`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VUY+G!N9P``````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C`T-@`Q,#4Q-30S,S<V,P`P,C,Q-S4`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____UEYG$
M14G#14G*35#.45;66U[#96G"9VO$3%+D?H/"<WC-7VC'>H#7J:YD6IDT)XL9
M#'XY+XH:$81M9KYU;<`4"W]97<TR.:!H<=T2'I03(905(94;)Y4K-IX%&)8[
M2:8`%IT##UT8*90A,Z4X2;97:<M%4IMN?=4)))0D.IA'6JMA<;AT@\4_3&R.
MFK,C+D-*5%5_BXL^1T.;J9EF;V"NNZ1K=EFTO(](3BA=8SF>I6VIKE.QM4+L
M[$C.;FO,<&W6=W3,<6[1=G/,=G/AA(';@7[/>G?'>';HD(W;BHCDDH_=CXSN
MG9O^JZGYJ:?]KJS\KZWQJ:;^M;/*HZ+D8V',7U[.8F#,8F#R=7/09F3-9&/,
M96/J='/6:VG2:6C8<&[\A(+4<&[!963E>7C-;6SA>'?XA832<7#4='+VAH7:
M>';^BXJG7%OD?GW>?'O_D9#NB(?NB8>R9F6P963[DY'0>GB_;V[RCXV\;V[K
MC(K*>'?5@'[8@X'ZF)?AB8C2@'_NE)+\G9SXG)KJDI'ED([_H:"Y=73YGIW^
MHZ+VGIW$?GWZHZ'UGIW_IZ7/AX;HF)C_JZG[IZ;RH:#@E93RI:3UJ:C@GIW^
MM;3]M[;RKJ[NOKW5K*SZR\OJP+__TM'YSLW___\`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````>3*D%````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+])1$%4&--MP<$N
M0U$0!N!_YDR/>WLI&^F"C70MI0N)V-@0L;/RDAZ@*XE=A?01NJT*HFC=SIQ[
MI@_`]P%_$'K=>DG95^^G@XWQU3W?,3HTC3N;[HT]C4Y6YPF"8,ZQ-6^\MU4Q
M4P;#(C=9$\67@_W=JKB&X*O8^_UPIKIZ+*JL!L%B8H&">7G)3#D/(7@K6=69
M;Y_+5E+=AN!&S7((X>B!+]Q2@N!P]I,X=MJ+,_JTT;%!\/IM)%&BN-7>5\4_
MUAY)4F5-5X9E`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O;7HN<&YG````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#4P
M`#$P-3$U-#,S-S8S`#`R,S$W,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P``
M`%C,'8X```,`4$Q410```/___S8U-FYS<F=K:&UP;9B;F'JY<WJU="YE)R-N
M#R5P$2=P$RIR%RQT&"]Y&SZ&*SZ!+$>,-%"6/4V,/%F<1U631&&E3UV:3&FJ
M5VVN6VRK7'*Q86B?6G*M8GBR:8_%@"US&#=^(SU_*DV+.U601%F52&*>45:(
M2':O9H.\<X>\>(>Z>)'%@EYA71U%"VAJ9WE[>)"2CXB*AZBJIZ6GI*"BG[*]
MJ%QV/JVXF69G8[F[B;F[`+_#+[FZ`*>G<GIZ=G1T<(2$@)24D'%Q;I65DH2$
M@:"@G9^?G+RV!:6A([&L*KRW,,;!-<S).MC31>_I3^7@5K>S2L*^4O+M:,W)
M6MW99OOW=N_L=?KW?+RT`\2\#<:^$,_('=+*(9N6&Z.=(=W6+ZZH*.#8-;FS
M+L2]-.KC0NOD1M;/0MO51N[G4.;?3NKC4+^Z?KRJ";R9!;^'"I1U1MF4/;J(
M2-R93\AZ+?"A:-*29ETD!*].%\M=']6<?KMG0<=(&'LN%-MV6KZ&=^QP4(8?
M"L8P$K)!*LDT&'X1`-1#+]A,..5D5:Q83<,7"9`K(7,'`&X+!5!04$]/3TY.
M3D9&1D)"0C4U-30T-#`P,"\O+R$A(1T='1`0$`T-#04%!0,#`____P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'XV[PP````!8DM'1`"(!1U(````"7!(67,```!(
M````2`!&R6L^````P4E$050(UV-@P`(J]#DUM#75E!5Y^)2$1"5E@$)M=1;L
M\A*"O%S<_`+"XE+20*&FEGI[#EE5%1$Q=3DM!5T=H%!/<5EG`S.+`:NA,9NI
MB9D14*C0.K>HM8]ASJP94R;U3YP\%2A4;6Y9T]T[=_;,Z9,G]$]BF@84*B\I
MK>S2LW)T<O9P=W5S<`$*-;8W%]CZ^0>&A$=&A(4&!P&%.FKS[3QCXI+3L[(S
M4E.2$H!"57DV4=&QB6D!.9F^/MY>\=B\`P";[S(G7SH6^@````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]N82YP;F<`````````````````
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`U,34T,S,W-C,`,#(S,30Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____S`@,
MT1`4X2$DT"LRWC(X\DQ1_U]D^71Y[H"#_HB/J7>"PI2>KGZ*JI&EDWJ0C8>A
M,"^!.SI^9F6K``!>``!;`0$\!05D"0EE#0UF$A)H&!AP'Q]U)R=[.#B(.#B%
M04&/04&+2$B8.SQ\5U>A7EZJ7EZG7%V?9&2I:FJP`01C7%V7<'&M*RU;*RU-
M=7>@&!YU24^8#A=O%1]T$Q8Q1TZ*<GFT?'^=%1@P14V*4EN814^0:7&B@X>:
M*"LWB=&49[MQ-YQ!5;1?5JQ?:<1R5K-=&V<;(G(C(6\A+Y0O)G<F*'DH-9\V
M*WXL*GLJ+H(N+8`M,(4P,(0P-(LT,XDS-HTV0J=".I(Z1J=&0IQ"2JI*0IA"
M3;!.1J!&2:1)1IY&3Z]/4+!03*=,3JI.4:]14*Q04:Q14*I0,H<Q-HTU/Y<^
M/Y4^J-6FG,.7BZ)ZGK.,MLBDGZB/?85JS]:^5V$H>8-,E:$QQM-BP:*6VZ.<
MT5U4[Z6?\:NET#XTWE%)S$Y'\FIAX8Z(S@H%VQT7S!\8TBXG[CHTSUE4VY21
MS```S0$!S`4%S`@%S0D)U`H*U@T-V!`0Y"$AU"`?Z"8FZRLK]3HZ^#X^^D)"
M_$9&_T]/_E!0S%A8V6AHPXR+____````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````7_%&2```
M``%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#!241!5`C78V#`
M`L1-]56T5.5E)$0EK'D;9\X&"EF6EEFH*<I*BAD;-+7/F,4)%+(OK[!3EI/2
MMN*KGSJ=HS8/**177*0C)&TB6-TR91IWB6,.4$A85T/!T(RG;N(D]II<MY@0
MH)"(NI*-0$/S!!:N0M>,A+`@H)"FD>V\UNY^MBJ'V/3XB$P_H)`Y?T=O%_/<
M`N?HU.3LT$!OH%!G6T\7:Z6+;V122E1(@(\G4&AR'].<?">O\,2TN*Q@?P]W
M;-X!`,]],@=G%!O<`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+VYC+G!N9P``````````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`R
M,P`Q,#4Q-30S,S<V,P`P,C,Q-#,`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,`
M``!8S!V.```#`%!,5$4```#____2-3;.%!G;)BN>(27H.C_6/T/R2D_G3%'R
M458F#7\U'8E',)E:0JAH4;-B3:AK5;(<#%<_,W@J'&\;&I8?'GX``(X&!H<$
M!%4$!%0+"XL,#(D6%I41$FL;&W(G)Z(X.*XZ.K(Z.YQ,3+\[.XE65L1>7L%N
M;LX!!%8$"8P.$Y0>(Z$Q-;!$2+Y15<-05<8`<P`#<`,)>`D->`T8@1@=AAT?
MAQ\;:ALA=2$B=",H?R@OE"\J?BHNB"XXG#@TD30PAS!"J4)&JT9"HD)&HT90
MME!/LT].L4Y0L%`VD#4B@@5@LS5MEDIUG5%QEE!%9R9-<"U4>#-AA3YOE4PA
M,1!?AR]YICH@,05ME0"'IR&MOA+8WR;,T`72U@WCYT#R]E?-S0#&Q@!(2`#,
MS`/(R`.WMP,]/0$W-P&YN0I45`7.S@V_P`UF9@G>WAC3TR"DI!O8V"=T=!A+
M2Q+?WCB%A2?HZ%![>R_]_62UM4C__FB@H%Z^OG2^OGMU=5^DI)UA7@#;UA1'
M1`?5M!#=OQWWTU[]U6KHJBO(A`KHETC,@4GB)R'K-2_O-36[+"S(,##1-#3'
M,C'O/C[W0D+3.SKZ1D;C0D+&.SOG1D;X3DW\3T_H2DG\4%#T3D[V4%#T4E'W
M9&3V9F7___\`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#1XB9G`````6)+1T0`B`4=2`````EP2%ES````
M2````$@`1LEK/@```*Q)1$%4&%=MB[L.`4$40.?>>>RN2A")1.VC_(%$H9#X
M#"4?H/<[LGJBLEZSLWOGX8J24YZ<(\0/($:@E4[M,_,2)2*62G1?9AJCW%(?
M&$Q<]6#FP5N]J[^J0O%8189N2^>:EES-U>9:#J)S-,DQSZ!I%R@Z*1$UDB>C
MD>9)*)%4CTA#(8W1WJ\#JWVFBS&FX\6"20RKR@[C(>A[+='Z&"(K%T]G1+[0
MF_"I_O`&IN]4_=2N3N8`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;F8N<&YG````````````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0V`#$P-3$U-#,S-S8S`#`R,S$U,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___Y?-
MF*C9J0!U``!)``%V`0-W`P-V`P5X!05W!0EZ"0U_#0U[#0I4"A!^$!)^$A2%
M%!.`$QB&&!B$&!%=$1V*'1^('Q^'("&+(1EE&1MK&R:0)B>,)RN7*R)V(R%S
M(2%N(2^8+R9[)BA]*#6A-2N"+"I_*BZ'+BV$+3"),"IX*CJC.C.-,SB:.#B9
M.#2/-#"$,#:1-C2*-#ZC/D*L0CJ6.C*!,D:O1D*@0CJ+.SZ2/CN+.T:D1DVS
M34JL2DBG2$FH24^T3U"U4$RL3$ZO3DFC25&T45&S45"Q4%"O4$:81E"M4%"L
M4%NY6UFU65>R5UZW7EFK662\9&2[9&6Y96B^:&J_:G>[=W6N=8+`@G^W?X>]
MAXO"BXF^B9W4G:+6HI3#E(BQB*C:J*31I)2UE):VEIZ^GIBWF)JYFJS(K+[9
MOL[HSJJ^JM7MU=/JT];MUL#/P,3,Q.[W[O/Y\_'T\<O-R]/4TR"$'S"3+S*+
M,4&@0#^;/C^6/DR<2V:Y98:SA8&N?X.P@8NSB9^\GK?$MK_+OM36T_KZ^OGY
M^?;V]O+R\N[N[NKJZNCHZ.?GY^'AX=[>WMC8V-;6UM34U-#0T,_/S\[.SLW-
MS<S,S/___P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````/L/[Q@`
M```!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````OTE$050(UV-@
MP`)86:6L\KHFM+7.G!HIJ6KA#!(2-0_-Z9_2U#A]<K22J9,G4(A/.R@D>U)9
MA77YQ%@3.P]'H)"B=YAOUK1<-J'"/B9[=Y<:H)!->(!^R\PD3OZX[@0O5TL#
MH%!]8+5$VLQF'K&HCF1?6R,MH%"P@RQOZHPZ83E_1F8WLRHUH)!/I0!'1I&@
MC(Y?<4JMKJ8R4$A/A(LELSTF(KZD--%80T4!*"3.S<*>/J$GOZ"SM\%075X:
MFW<`2!XP(RY#,0D`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]N;"YP;F<`````````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P
M,S$`,3`U,34T,S,W-C,`,#(S,34S`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#
M````6,P=C@```P!03%1%````____BPX/U=35Q\;'R,G-QL?+]O?[Y>;JV-G=
MR,G,O;[!^/G\Z>KMY^CKU=;9T]37(428`#.J`C>K!3BN!3>K"SZM#D.U$$.V
M&$>S(5+#(5&W'$"0(U"P)5&P*56U)$J;,6//*$VC-632*U*F+E6M,ENU-F&_
M-%RX,EJQ.&/$1'3<1G3>0FO)1W+/4'[B4'SA3GC947W=/U^D37/$1VBO68+:
M3G"Y6GW);I3E!#JL'E+`-V&Z1G',:)#D:(W;:X_:S<_3Q\G-^?O^\O3WU-75
MY^?FX,C'S```?P``S@,#T`4%S`4%S`@(S0D)U@T-V!`0U!$1SA04TA@8E!$1
MX1T=WA\?Y"$AU!\?G1D9[B\OV"TMZS(R\C4UX3@XLB\N^D)"NS(R^$1$_$9&
MYT%!QCL[_T]/_E!0^5!0_U-3[D]/[$Y.^U=7]E=7^EY>Z5Y>]V5E_VIJ_6EI
MS:ZNS*ZNT;.SV[V]S[.SZ,O+W<+"IY.3]=G9_N/C_>/C\MG9\=G9U+^__^CH
M^/?W_O[^_/S\^OKZ^?GY]O;V\O+R[N[NZNKJY>7EY.3DX>'AV-C8UM;6TM+2
MT-#0SL[.S<W-S,S,RLK*____````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````)XM]D@````%B2T=$`(@%'4@````)<$A9<P``
M`$@```!(`$;):SX```"R241!5!C3;<&]<0(Q$`;0;W].$G,W0$0#)"Z"P"G=
M$)+8D8<>Z`0B)P0X<",D#!YN\)VT6A=@W@/^(:PQ[[IRZX<B30Q!]PRTJ;7'
MF`MK(R($QK&=LCU&#S'&-`D,Q390C9TY$PL1?8&@M@NB,*NEN&JS8;Q_?!X$
MM;K9F\BV`:%C[FGE9U_Y*7"FGO!Z__EU3HLAY3!XK=^*R[48:RZ3D>[9[`K&
MS>J++&,2MAEY;?'$'Y==2@&P9"!A`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VYO+G!N9P``````````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-@`Q,#4Q-30S,S<V,P`P,C,Q-C0`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____1
ML;/BPL3PT=.[HJ3&K*[3N+KWV=SGR\[ER<STU]KVW-\!)&*+EJJFL,('*VD0
M-'$2-&X=0'PG2'Y!7Y)7=*25H+(%+VF(F*Z'E:B6I;J@K\,`,&D*-V\..W$V
M68,^8(FLN\X927XJ584_9I%*<Y]9@[!FC;=NDKE@>YF"G+B&G;8G68TZ:ITX
M7XA,>ZQ/>*-9A;-<?I]BAZEQE;9DA*%HAZ5OCJN"I<1UDJR1LM&%H[YTC:67
MM]62L<Z8LLFGPMNJPMFSRM^7MM#-@WWQQL+.O+O-/#C,6%7.6U?,8%OUDY#&
M>'7^H)W4BHCWI:+,``!_``#-`0'.`P/0!07,!07-"0G4"@K6#0W8$!"+"@K/
M$A+>&!C2&!B4$1'A'1WD(2'4(!^=&1FG&QOK*RNP(2'N+R^R(R.\*"CR-36_
M*BK'+BZY+"OU.CK*,#"R*BK=-C7,-3+A.#C5-C72-#3X/C[$,S+Z0D*[,C+/
M.3G\1D;E0D+J1D;_34W@143N24G_3T_^4%#^45#V3D[[45'Y4%#22$7R4U+]
M6%?Q5U;I65GH:6;R<&[18V'Z?7K;<G#H@H"G8%_@BXGRFYG]HZ']I:/_JJG>
MQL;___\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````K\LVI
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+])1$%4"-=C
M8,`"@H*2?9W%^-O#`D.C$K.JFT!"\94!3J+B'H$AD0GI%8UM0*'H@NYI#B)\
M1<$1L:EE=:T-0*%)_M/==(2D7/LF3/3QFSIE,E#(UM%%6U%"P=C$U-+:SM[&
M"BBDJ:&F(B\KIZRK9V"D;JBJ#Q3BX6)RU^*5G,',PL'-R<[&"A3J*HSQ-A.0
M[LEK[NRHKRK/!0H5QX5YF@O*]%8WM=24YF2F`862P@.]+(25^AO;:DORLS-2
ML'D'`.T),0QW7"!O`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O;G`N<&YG````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q
M,S4W`#$P-3$U-#,S-S8S`#`R,S$W,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$@````P(
M`P```%C,'8X```&`4$Q410```/___\<*"^HZ/,DS-,<Z.^E.4M$F,?_K[+(P
M.]U>:*0!$Z``$[(N0%\`$:T8,G0",:@]:+%.>IE#:I5(=54;0)Y6BUT+2FLU
M8(E">VXJ9TX)25H559I>E]O:VT8$24<.5$(/6(5CJ&50>TDK<7UAI5]"D(I]
MO3,O?[JXWUQ:HUE8E#\_<5M;B3T]2",L?='*R=A+1-,0"^%`/,T_.^RAGL^;
MF=VXM\T!`'\``-$'!\T)"<P,"=L4%)01$>$@'M0@'\PA'^@F)M8F(]$E),XJ
M)^XO+XL?'>PU->`V-J<K*=0V-?I"0KLR,MD]//E&1N%!0.I&1OY/3_Y04/E0
M4/%<6;!$0_5>7N!85OUE9/AE9?1E9?%G9OIK:^IF9M%K:]>#@^B2DM>(B-.3
MDLR4E,RFILVMK?W9V=#!P<S(R/'Q\<_/S\S,S/___P``````````````````
M`````````````````````````````````````````````````````,^-3J<`
M``!N=%).4___________________________________________________
M____________________________________________________________
M__________________________________\`H`4\,P````%B2T=$`(@%'4@`
M```)<$A9<P```$@```!(`$;):SX```".241!5`C78V#``BSY1)4U<Q$`)&3G
M&\TEK((LY!Z6F&YJR,(MH*`!$_)*YLB2,W.TL+)E%U2""+'&QD3PBLM+RTA)
MBLFJ:ND"A:+"`UR8>!3UD<R*C$M*2S$QXE=#"(6:9^?D&/@Y,0NIPX2,XU,S
M,Q(\/?R#V42T(4(.UC:NSO9N/D$A@=Z<$CIZV+P#`%*`+5K5'@Q6`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O;G(N<&YG````````````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`R,#0S`#$P-3$U-#,S-S8S`#`R,S$V-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$@````P(`P```%C,'8X```,`4$Q410```/___P@EC@HGC@XLDQDTEALXGAXV
MB2$YC!<G7BU)K"4Y?C9.IT!<O$1<KC]4G3]2E%)JOU=PR$M@J59MP%YTP&!U
MO6V"T`TIA!`KAQ$MAQ$MAA,NA`P<4A0OA14OA18PAA@SBQ@RB!@RAAHUCAPX
MCALUB!TWC"`ZCQ\XBB,]DB5`EBA"FBM$F!TN9BI"D"])G"M#C31-GS!'E#!(
ME#90I"@Z=CI4J28W;CU6ISA/FBY`?3!#@$%:JS-&AC=+CC9)B%!KQT9?KT)9
MHSI.CSA+BDQEN$ICM#Y3ES9(@CU1D4%6F49<HT-7FT]GMDA>ID59G%1KN3]1
MBU=OO$UBIUEROUAOO%!FK%MSPE1JLU9LM5%FJT=:E55KL$E;EUYUP5IQN%MQ
MN%ENM%AMLF!VP6!WP5-GIV%WP5!CGUYSNF%WOV!VO5)CFV9ZO6R!PW"$R&9Y
MMG*&QW.&Q'B+RF]]I9ZFN\O,S)V=<JJJ@JZNBG!O0G5T1W-R1GY]47]^58R+
M8964;XN*:)R;=ZNJA(>&:+"OB;R[FJ.2'Z64(;FI.J^@.LBX3*N>1]7&7L.U
M6,F[7MS-:=K-=::5)JZ<*[6G3M?(:=O.>____P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````$#>^X8````!8DM'1`"(!1U(````
M"7!(67,```!(````2`!&R6L^````O$E$050(UV-@P`)D92UBBG/]]95EE+2,
MG,+204)Z045YX29J,@H:!K:!*=E`(4[/@L)D*TTY>75=2S_1K"2@$+>PN`@/
M*S,3"QL7KZ.0(!]0J*6MLJ&NIJJZMKZ\HK6YJ1$H-&UB7]>D]H[)G=V]$Z;V
M3^D!"N5'\G-(2JGHF+M%Q$?Y>-@#A1+32G,D%+5-W4-3$T*\7>R`0LX99272
M0!<%IV=&^WHY6`.%C-GC#%5!+A*+#1!PM3'#YAT`,X$NNE0T!LD`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]N>BYP;F<`````
M````````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#<`,3`U,34T,S,W-C,`
M,#(S,C`P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%
M````____M&UPOG2(PHVFG&F'V\+77DA;FWR7IXZDMZ:V@U>&GW"CDG66S+?0
MAUR79EMJ?667M:C"C'&J;5*/=%B?S+_A>%ZH9$N;;EBGLJG)<F*D9E>A?W*Y
MF(O2=6^1/S&33T*A3D*@5DJAA'G,B7_.F9#0/3*5;V:T/C::44FM1D"+<6C%
M?'7->W3*,"J7-2Z8-2Z7-2^:-B^9.#&<-S"9-S"8.3*;.3*9.S2=/3:?/3:<
M/#6:/3>=03JB1#VD1T"H0SR>24.K2$*B3TFN5$VR3DBE6%&V/SJ#5$ZJ7%6X
M7%:Y85J]85N^3$>33DF695_"7%:O95_!4DV;44R95$^=:F/$7%>L6E2D6%.B
M9%ZU<FO+7EFI<VW,8UZP=&[-=6_-=F_->'+/;FG`<&J_;6B[?'71<FW#<VW"
M?7;1;6>W?7?1=W+(=6_#?GC1?'?/?';->G3'BX;5B8/0<&Z--3&<.#2@.#.:
M/#>D/CJF1T.L1T..:&3'6E:G;6C(=G+1>732>G71=7+,@G_2.#6C14.C4U&B
M;V[166"WZXASZ(Y[]()MP6U?[XEXXZ.8][*FT&14JUU1ZH1UDEM2N8!WO$I!
M@30MTW!FM$,]=$1"Q8%^____````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````\YF]-0````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#`
M241!5`C78V#``M@%2GK$^*0ZR@U-%"4#$K.!0C,G3^GM[YO%I&Y4(<H<WU``
M%)HVL:N[<\+4&0HM55XZ::JY0"%Y+K9)0IPBUF42XC7U*BP:0"$..;7I,JV\
MW)7\/.W9>K(Q0*'BYE1E3?U2)2W?V$S=E/!(H%!1AJ>M@;&5DW==8WYZ7$0P
M4*@PT-',P-+!/2PI+R>K-M0/*!3E;&%H;N\:E)#=),S:YJ\-%'*S,32U<_&)
MSM1-EA8,J?;`YAT`$ZLPG5;=VLT`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+V]M+G!N9P``````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C`S-0`Q,#4Q-30S,S<V,P`P,C,Q-C$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!(````,"`,```!8S!V.```#`%!,5$4```#____5-3;H/#WA04*G45+_B(E!
MH",Z?"-1JC)"ABI6K3=)D#!0F39FNTE?JD1KN5`^?25EK4AOOU)PNE(V<AU&
MARM.D3)4FC=FMD1QO5$^B!-!BQ=,D!]4F"A)?2A1AB]FJ#Q9CS5EG4!UM$QT
MKDYZMU-!=PGKX^+&.#'$"`#$"0'&#07)$@K.%0W5(!CB,RNZ,BSO13[20#KW
M5$WF4$GS6%',``#+`@'.`P/,`P/0!07,!07-"0G6#0W.#0W8$!#/$A+2&!C-
M&1CA'1W,&QO2'!SD(2'4(!_1'Q_4("#8)R?/)R?N+R_;*RO=,"_R-37*,##A
M.#C2-#3=.3E_(2'Z0D+G04#\1D;E0D+J1D;L2$C_3T_^4%#V3D[Y4%#U4%#Q
M4%#L4%#'0T-_+"SV5U?@4E'^7U_Z7E[]9&3R8&#]965_,S/Z967X966=04'_
M:FK_<G*+04'49&242TOWAH;QA(3&;F[]CX^[;V^R<&_IH:'8Q<7,P\/>U=74
MR\OV[>W.QL;-Q<7_]_?X\/#GW]_[]/3NY^?^_O[\_/SZ^OKY^?GR\O+N[N[D
MY.3AX>'8V-C6UM;4U-32TM+0T-#.SL[-S<W,S,S___\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````"$8`0$`````6)+1T0`B`4=2```
M``EP2%ES````2````$@`1LEK/@```+9)1$%4&--ES[M-0T$0!="[=V87"R0[
M=T*(!'VX"@C(+43H!JB``(D.<$XM9(@4B<1^O_7;W1D*\.G@`&<"MK_KQ;Q:
MJ:)5L^8[(E]?6HTBL.9N.X%BF8(,4ZVQ^?[>7RH"XM/K\W<^68J?#Q?J]5WP
M&&_?UMUDACO8//1?Q%4^;J9"T924]<.@*%T_E)X,)-UN?J#(_5B.;:`(W=Q&
M*`Y=:3S\J<3FYF90C*60Y#+,3.Y%\_D'_Z(X771-%"4>`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<&$N<&YG````
M`````````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0V`#$P-3$U-#,S-S8S
M`#`R,S$U,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q4
M10```/___\&YO=')S?W]_N7EYO+T^62`K>;K\[&\S<7.VYZDK;V_PO7W^@HT
M;Q1`>B5.@V2&LI^OQ=/;YL#&SN_R]N?J[@$O:0,S;`4U;@<W<`TX;P\\<1(_
M=!A"="%-A2=/@2E0@2]:D3!9B4)KG$AMG$YQFVF+LW&0M9ZRR]S@Y0`Q:@,S
M:P4U;0DX;@T]=1!`>`\\<!A%>!U,@A]+?2U5@S->D#AACT]XIU!WH[["QNWO
M\<K,SMW>W[[!P[[%R<'"PK*SLY.4E,W-S-K9V,B_OJ\+!;83#;@6$*X4#Z\5
M$:\9%+X>&,$C'<4G(<PQ*\<P*]`U+],Z-=I$/MU(0M5&0=],1KM"/^)23=1.
M2>-53^)64.!74=Y54.%74\U13>1@7-U=6=!_?;R!?\.=G.W/SM"[NJH"`*P%
M`[(,"KD4%+(8%L@I)KLN*]8].K@T-,5!/N!-2M=/3.%44=NFI<FIJ;JEI<N_
MO\J^OM#%Q>[BXNC=W=/)R?WR\OCM[?CO[^WFYOW\_,3#P_[^_OO[^_GY^?CX
M^/;V]NKJZN'AX=C8V-34U,_/S\[.SLS,S+R\O+FYN;*RLK"PL*>GIYV=G8N+
MBW]_?____P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````()>00X````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MOTE$050(UV-@P`*F39MBQ]+>6>F=[N;A%Q06#1)RXM849NTN]\QP]PT,B8H%
M"DV=R,DNU-5;X97IXQ\<$1,)%)K<S<$ETM-7GIV5DU=87%0`%.+AM;:UL;)G
MR@T(C4M(C`\'"FFHJYG*&<HH,E?5U=97U[@"A015%:3%Q?D$M-H86QI<G!V`
M0I;*LCK:4OQF8LV-J4FE31.`0N9&NMJ2!O(JHLWM)?G)_9.`0B9ZVA+ZQDH6
M;*T=:2EECI.Q>0<`9_<P=D51LKP`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]P92YP;F<`````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(P-3``,3`U,34T,S,W-C,`,#(S,30W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```2````#`@#````6,P=C@```P!03%1%````____RPT.TAP?V3(ST#4VQ#H[
M\F)D^F=H^'5V_&YT_W5ZS)R?U:VOS,G*VM;8R\G+[NWN_/W^^OO\RLO,?X>-
MR,W.W^3DZN[NT-34WN'A]??WV=O;R,K*^/GY:9F%RM#-?;"+7J!ICLB7D\29
MM^V\O.*^4)=0H=FAWM_><I!NJ;JEJKRDT-C-BZIX]_CU=X17D91][>WLH9!H
MHHIXHVI+YN3CL9.'Q)^:P$]`KY.1R```Q@``?@``?0``R0,#QP,#Q@,#QP0$
MQP4%R@<'R`D)R0T-T0\/B0H*RA(2S1@8D!$1X"$ATB`?SR`@FAD9I!L;TR<G
MK"$AZ2\OKR,CI"$AMB8FV#`ON"@H[C4UNRHJOBPLPRXNP"TMQS`PKBHJR3(Q
MQC`PWC@XW3@XSC0TRS,S\SX^]4)"U3HZN#(R^49&U#L[XD%`W#\^VS\^X4)"
M^4I*PSL[^DU-Y49&ZDE)Z$A(^D]/_%!0^E!0[DQ,Z$I*W$9&\4Y.^%%1]U%1
M]5!0]%!0[E!0[5!0T$9&\5=7Y513]5Y>]6!?Y5E9^F1D^&1D]65E\V5ET5A7
M_&MK^VIJX65D[F]OS*"@TZBHW+&QXKZ^\]#0^??W\>_OT,[.S\[.R<C(^_O[
M]O;V____````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````)/M">`````%B2T=$`(@%'4@`
M```)<$A9<P```$@```!(`$;):SX```#!241!5`C78V#``FSM_`O[IDG-FBW+
ME^T3F54.%++SSNQIGRHI("`RLSHXO:P>*.01W]%5Q2NFHZW`WYI65%<"%`IM
MYFABL5"4UU+192^HK<P%"K'UMR0SFRB)&NAI<%74Y*<`A;K;<OR8S-5-+8U5
MN1N*61.!0IVE@6Y./,J&5FKZG"49"=%`H<9P3T>'23*:1D+3)^:EQH8!A9*\
MG&U<)HL+R@G/F)`2$Q$$%/)UM;9WGR(Q=XZT66]<5$@`-N\``$JQ,9DBWA,,
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W!F+G!N9P``
M```````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`U,``Q,#4Q-30S,S<V
M,P`P,C,Q-3``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,
M5$4```#____&5E?(6UW/:6KCHZ7JK+"WE9?#>HF79XEV27N'9YJ2=Z.*?[ED
M6Z&4C,EY=*.BGM.DI*6^P.>$C-&>HKMU@\JVP.OT]?BBK\_W^?O9V]S.T=+O
M]/7V_?W&S,SEZ^O8WM[*S\_Z___X_?WS^/C3V-C(S,S`Q,2NLK+W^_OJ[N[H
M[.SEZ>G+S\^VN;GO\O+N\?&)BXO/T='Z^_OY^OKX^?G0T='/T-#;X-_8W=SQ
M\O'<W=S5UM7&Q\;X^??-S<G+R\G)R<C+P+;(N[3/A&#";DK*O+>\:4[FKIR_
MGI/@Q;S!43+3=V&_EHS$02V_D(GCGYK*@X''@H#4CHO#CHS=HJ#AIZ7\O[SS
MN+;(``#'``!]``!\``#)`P/+!07(!07("0G1#0W3$!#.&!C;'1W@(2'1(!^:
M&1FD&QOJ+R^O(R/M-36[*BK',##=.#C1-C7X0D+X1D;#.SOE1D;]3T_[4%#U
M4%#R5U=\,3'[:FK)5E;06UN01$3<:6CI>GKUBHKB@8"X:&CZDY/UDI'UFYK&
M?W[SGI[-C(NL>GFXA(/.EY:^EY?[^OKZ^?GV]?7U]/3$P\/Z^OKU]?7Q\?'N
M[N[M[>WJZNKHZ.CEY>7BXN+AX>'=W=W3T]/0T-#.SL[)R<F^OK[___\`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!I`_N?`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@``
M`,%)1$%4"-=C8,`"8F(SBJLJ\E,2HN.3TW**RH!"E;5-[:V-+,Q,U35U]0W-
M+4`A(TU=%1TU%[\`9T4%564M;:"0D+G)-&EW-Q]_5V]94[.I-D"AB;W6<V2\
M/-A[?#VE)DV9/1\H-&'R+`L'`2Y.'@Y!B?Z9\^R`0GTSYBYP%.7CYN47MI]N
MZ[00*&1HI22O;BPI)B(N9V"IIZ$/%`KK"&X+"@ED98N(#.\.[>H$"J4G1L4E
MI685EI:7%.3E9F=B\PX`]?HR\:^;_9<`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O<&@N<&YG````````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,#,S`#$P-3$U-#,S-S8S`#`R,S$U,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$@````P(`P```%C,'8X```,`4$Q410```/___\TC)<U)2LNJK;$-(+X@
M,<TR0[DT0:\S0+DX1MI%5<U(5N!28=M280D%:A81=B<BA3HVE3@UA4M'HT9#
ME551J5).HP``:@$!;`$!:P$!:@,#;`,#:04%;@4%;`<'<0D);@H*<@T-=0T-
M<1`0>!(2=!04?1@8?A@8>!T=@B$AAA\??28FC!D96BLKCB<G@2\ODC4UESHZ
MG#@XD#X^GD)"HD9&I#\_DT%!EDI*J3H[@TU-J4]/JDE)GDQ,HTA(FE!0JE%1
MJU%1J5!0IU=7J5Y>KFIJMV5EK)B8SU148PT.2$5&@Q<;>9"2O'=YB=C:XX&(
MGL[.N?'QW-W=T<W-Q\_/R[*RL']_?M+2T>'>N?_[TMC.BOSXW>OAH<:^DO?O
MO]3.I]/-J*:CD>?/5OKA9/_J@/;B>\RUB=2^LLP``,X#`]`%!=$'!]0*"M8-
M#=@0$,P1$=L4%-X8&.$='>0A(>@F)J<;&^LK*[`A(>XO+[(C([DF)KPH*/(U
M-;\J*L0M+<$L+,<N+O4Z.LHP,,TR,=4V-=(T-,\S,_@^/OI"0MHZ.N`_/OQ&
M1N5"0OY*2NI&1O]-3>Y)2?]/3_Y04/),3/U14?9.3OM14?E04,Q65LN`?_'Q
M\>'AX=+2THN+B____P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````%`+TV0````!8DM'1`"(!1U(
M````"7!(67,```!(````2`!&R6L^````M$E$0508TVW!L4T#01`%T#^S,[,G
MVUA"0B(S!5`$(<)].*,'6J$&(F=(CI'L'K!$2&)\>WL[<R[`O`=<(:SI^V81
MOW_GP;)EG7T*EOVJQ:F4051-+('QW`G5OE0V53&K2+A3)OTIGLW4LM>CH&6=
M[+'M>B)FBH"`ILBG^W<G$J:("0*/.'_$J^IME^M0VYO@:<LO#TW2W-2KCPT"
M6K<]2^IF2F4<W<'XVAPHB2Y,A^(>@7]<`#FD25H"+9D?`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]P:RYP;F<`
M````````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#8`,3`U,34T,S,W
M-C,`,#(S,38R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!0
M3%1%````______[_Q\;'\O'SU-;6NL&^S=?2S-;0/'9-,VX^Q=3(0')(1'A,
M3XI7:)9O5GM::H%LAZ.*%5,:)6`I5(A83790CYZ0=Z%YIKJG"DD,)F4G(E(C
M*UTL28!*AZ*(`$(``#X``#L``4,!`3L!!4@%!44%!4(%!3\%!TH'"4D)"4$)
M"TL+#5`-#4@-#DH.#44-$%,0$%(0$E`2%%(4%$\4%E86&%@9&%48%T\7'5T=
M&$T8'5P=(6(A'UP?(6$A&T@;)V(G(5`A+VXO+VTO)E<F+V@O*%DH-7,U*ELJ
M-7$U+5TM,&,P+EXN.'`X-&@T,&`P-FHV,6`Q0H!"0G]"07I!1H)&07A!0GA"
M1GM&3XI/3HA.3XE/27])3(-,4(E048I14(A03X5/4(502'=(4(1037]-48-1
M6(U85(=45XM758A57HM>:I-J98QE9HAF:HQJ:(EH;HYN>IAZDK"2C:F-@IN"
MHL"BH;NAL,JPK\>OY^_GV^';Q,;$U-74,F4Q,&$O-F8U/W0^1WU&Y^?FW=W<
M^/?W_?W]^OKZ]O;V\?'Q[.SLZ>GIX>'AV-C8U-34TM+2S\_/S<W-S,S,N[N[
MLK*RIZ>GG9V=E)24BXN+?W]_____````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````OK*OP@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX`
M``"_241!5`C78V#``F;-FEZ6F^5GH::@:F3O$18/$IHQI2HGW$[+4D?7QB4X
M*A$H-'-J3V6*HUZ0H+YY:&9T0BQ0:%H_4T6#L92XB(FT$$=&7!-0B)FQL]1:
MG8O-S-Z#3R([PA\HU-;14JRMR,/*Z18<DQP9Z`,4:N_N*U)1%JYE%TU+E^.M
MEP4*=;5.+%32-,UCJ2XOD1?P=@4*]4Z8G*]A:.O%SUTC*>;K[@04JILTN<#`
MRCDD*;6Y,<!3Q@&;=P!!`#%!916*JP````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+W!L+G!N9P``````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C`R-0`Q,#4Q-30S,S<V,P`P,C,Q-C``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!(````,"`,```!8S!V.```#`%!,5$4```#____'P<+__O_&Q\?@X-_-
MS<S,``#-`0',`0'.`P/,`P/0!07,!071!P?-"0G4"@K6#0W.#0W8$!#/$A+;
M%!3>&!C2&!CA'1WD(2'4(!_,'A[.("#H)B:G&QOK*RO8)R?-)26P(2'N+R_6
M*BJR(R.Y)B;=,"^\*"CR-36_*BK$+2W!+"S'+B[U.CK*,##-,C'A.#C5-C72
M-#3/,S/X/C[A.3GZ0D+:.CK@/S[4.CK\1D;E0D+^2DKJ1D;_34WN24GL2$C_
M3T_^4%#R3$SN2TO]45'V3D[[45'Y4%#Q4%#*1T;534WZ75WG65C]9&3J75W_
M:6CY:&CZ='3X>WO8T='0R<G,Q<7RZ^ODW=W2S,S_^?G^^/C\]O;V\/#EW]_A
MV]O2S<W=W-S^_O[]_?W\_/S[^_OZ^OKY^?GX^/CW]_?V]O;U]?7R\O+Q\?'N
M[N[L[.SKZ^OIZ>GHZ.CGY^?DY.3AX>'>WM[;V]O8V-C6UM;4U-32TM+1T='0
MT-#/S\_.SL[-S<W,S,R[N[NRLK*GIZ>=G9V4E)2+BXM_?W____\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!&.8BH`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```*Y)1$%4&--MP3M*!$$0!N"_:[NZ
M9\;'PA[-S%A4\!!&)H8F!J)X-#.7!4$9Q.FI1Y<'T.\#_DBXA]_ZS5$I,+76
M^DL&NE_YR(QN+O)\#4+XIXS,*=15GBXK"+X\3'.A.W-3N:B/2*#S#8DC(@<'
M)7K-.&OZL9<T[+9#3MT"&3J_S4L,HC&-K34#0=^_UUZX;H=JJZD@8_^U&G,^
M/BFIB;B!<&BR89Y.:UE^S-WPCU]2_U[R:=1";P````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<&TN<&YG
M````````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#4P`#$P-3$U-#,S
M-S8S`#`R,S$U-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`
M4$Q410```/___YM[?))^?^+0TMJXO9J+D"XYECE`BE16:[R]QXV5TFIUMX*,
MS#)%GC5(HS=)GS='D5%EPCM)BUQKL%MGHB8ZE2<[E2H^E"D\CRU`DSE/K4-5
MID=:K$98JE1FM%UON&=YRFQ^SE]NKCI#:G*$RW2%R&Y\MV]\LS9&A#A(A3M)
M?T]AIT%->TM7@$A4>6!IA8J5MEID?9*8HVQT@9B>I8F.DYR>GV1N<:Z]O96:
MFM78V-+5U=35U82-A[B\N3Q40$]A4EAP68B:B6UR;6AL:,O-RWN-=)B;E6EN
M869L6I^BF'^"=:&ECZ.FDF)E3V9I4ZNNE*&CD'AZ8H:(<X^1?8""8IV??X:'
M:8V.=[*R@*ZNE)220:.A78&`2XF'49>69J*A=;BWAZBC/:^I1(%]-Y",2;>T
M;+>S;K"M;;NX@<&R`JV?"+FM%=3&(^[?+^G:-<*V+LB_._GM4.[A3N794.+6
M3XZ',]#&3(%[+\.Z2.G>6=W358N%-JND1N+98<&X4Z6?2:2>3HF%3<&\>,_`
M)96*(.?7-;6I+??G/JRA,J^D-L6Z1I*)-,W"4S@O&:Q]&(M_9,*5.+%<!:E9
M"K=L(;11`,9=-=QV5KLY&:XC$+$G$:2-BKBDH^70SZPB(,V[N[VVMO___P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````!"0?HX````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^
M````P4E$050(UV-@P`(<7)R8N-7D^24DI01DA115@4*.=LZLO`H&GIKZ,2;*
MOH9*0*'^.1/=>>3T4OT%PV+53;TU@$+,"^=9ZO`%Y-0:-35XM&2(`(7,;=VX
M9+2R<X/S"ORJ2\P2@$+6-O;&XMIM<2GY-='%Z:(10"&6!7/9=,4JTZHZZY/*
M(AOC@4(SIL^<S^F57!0>%6@5ZM/A"A2:-&'R+':+UO;2K*#$NL)F8:#0U"G3
M9G-(AU1D]O5T=_66JV#S#@"WTC+QV/7R9`````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]P<BYP;F<`````````````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#(P-3``,3`U,34T,S,W-C,`,#(S,38T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````2````#`@#````6,P=C@```P!03%1%````____N!05RC4VLV5FGQ8G
ML'>"APPJ1Q$MR+;`4"A)FGV6:D!V73]]4SI]-BM[GIG**R9:54^5>7.T=G&P
M>72OCXK&EY/&2$./1$!UAH'#<W"C>WBAY>3R1$"+6E>@CHO"V-?J5%*<145^
M75ZF&AU43U*9EYO&J*_#\??]X.#?SZRGS8%[S)..RY.0U)R9QP<`>`0!Q`T(
MRSDU\4Y)\U=3ZU10Q5E6SE]<\YZ;]*.@S8B&UY22Y*.A\;*PU)Z<X*FGK82#
M[;BVN(^-Q)F7^,7#X;2R^\K(\L/!RJ:ESZNJV;:U\M+1WL'`^]W<\-/2O@``
MQ0,#PP8#P0<#P@4%OP4%R0T-R1`-RQ`0S!@4QA@8U!T=U"$=UR$AV"@DEQD9
MGAT;XB\OXC(OJ28CY34UM2PJYCPXP3,PP#`PUC@X[T5"[D)"R#HW\$9&O3L[
MX$E&WT9&VTA%]%)/\T]/\U!0[E!0[E)0ZU=7Q%-1QE53]6IJV6QJS6AGYWU[
M\XV+X(2"^):5\I63O8F(QY*1^;R[Z+"O];NZSZ*AYL/#_-S<_O[^_?W]^_O[
M^/CX]?7U\O+R[N[N[.SLZ^OKZ.CHWM[>V]O;V-C8U-34T='1S\_/SL[.S<W-
MS,S,Q,3$N;FY____````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````H/&#NP````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```#!241!5`C78V#``C@,X_.JRC.C
M0@-"(F)3<DN`0JI<+%:6]37F%946U;5U#8U`(4%E=<V)TV;-F3U]RJ1>QIX)
M0"%):2D%3FU/3R_O#I]./W]?H)",K+@\'VN0461<FHFI66$.4$A`452"GSTP
M+#HQN[BT@#D#*"0F(B3'K6-M8VO7TM9JW]P$%!)64M.8,V/JY+ZN[GZMF7/G
M`854>-ET]?0=G%S=/=S:79P=@4(\3`;!X3%)645E^<;IJ<D)V+P#`(6D,?<&
MJ6\]`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W!T+G!N
M9P``````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`S-0`Q,#4Q-30S
M,S<V,P`P,C,Q-S$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#
M`%!,5$4```#____0-3;*9&7`76B2JYLZ>3L`6@``5P``.0``.``#7`,%704)
M7PD-:0T*0PH8:A@12Q$?<!\95!DA7"$J9BHX@S@R;S([>#M(CTA0F%!&A$9>
MI%Y>H%Y9EUEDIV1JKVIEI65JJ6H39!(P?"]FIF4)905GJ61NK6@Z?R=;H$AX
MK5<V=0-KGD!5<`)/8!&;JE-^@B9[?@UV=R=Q<4%85AV(AU?#H1FTFCR2:#_.
M;1W6=2?'8Q?%7!"T2025/@>Y20?#31*>3BG?5BO(,PVB.R2_4CR;9EJJH)[$
M%`'(&P>](A3A*B''``#)`0'(`P/+!07(!07*"0G."@K0#0W3$!#6%!38&!C/
M&!C<'1W@(2'3'Q^D&QOB)B;E*RNL(2'M+R_J+R_I+R^O(R.V)B:X*"CN-37M
M-37L-36[*BJ^+"S#+B[`+2W',##O.CK),C'&,##@.#C1-C7.-#3+,S/T/C[S
M/C[W0D+U0D+5.CKX1D;W1D;</S[;/S[A0D+Y2DKF1D;Z34WE1D;J24G[3T_Z
M3T_[4%#Z4%#N3$SQ3D[X45'W45'U4%#T4%#V45&K7%NM9&3___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#2H-\+`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK
M/@```+9)1$%4&--MC+T-PC`01L_VV<XE1("(*$"P`"/0L@X+4-,R#A(-"[`(
M/Z)``AQBGQ.2&E[Y]'T/X`<!).@Y&2_/%2NM\U%O(T%8G')]\RP1DV%F`$&C
M-=1<M4:E"S(E2-`FI7[?OEF9`5&L6H56)2>SDD_,\J1QW2H/LMH=#R+:06JJ
M;6R59Q;[IG%4$+ER[=M\R+RZ+ATN4O(^Q$[QG7G^F$VZD/OXT!XY!G4QQ9!T
M^?)U'>$/7WB"1QIOPN=:`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O<'DN<&YG````````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,#,W`#$P-3$U-#,S-S8S`#`R,S(P,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$@````P(`P```%C,'8X```,`4$Q410```/___X@;',6WN:.>GYR3
MEK64H,VWO["+F:J:H+^?K,O)RK^UO,&ROKNLO>CEZS<VF4Q*L%54Q&!>OP``
MA`4%B`4%A@<'APD)B0\/BQ`0DA,3DA@8D"$AGR,CGR4EEQ\?>"$A?2@HD2HJ
MDB@HB"<G@C4UL#4UKBXNEBXND2XNC#0TFS@XI34UECP]I$9'O3L[GTA(O$)"
MJU!0P4Y.NDM+LE55P$)"CE%1JDI*F%%1HEY>L6UNRVQLPG)RRV]OPO?W^O7U
M^,_/TL3$Q\+"Q>;FZ.3DYM+2U,7%Q[JZO,7&R?+S]??Z^O'T]._R\LG,S/O]
M_?K\_.'CX]W?W\[0T,/%Q6^J;&B>8EVB37Z<=_S]^^3DXM+2T,C(QO?W]O;V
M]?7U].?GYM+2T<K*R=O6U<<``'P``,@#`\L%!<@%!<@)"=`-#=,0$,X8&)`1
M$=P='>`A(<\?'\HB(9H9&<HB(LXF)<HH*.DO+^TU-=@R,MTX./5"0K@R,OA&
M1N)!0>5%1-,_/\,[._I/3_I04/104*X\//-65O)75_5>7OID9.I?7^A>7O-E
M9?=H:/MJ:N5L;/AX>-;+R]C1T<O%Q?GS\_CR\N_IZ>[HZ.WGY^+<W/KU]=#,
MS/KZ^O___P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````!N_780````!8DM'1`"(
M!1U(````"7!(67,```!(````2`!&R6L^````N$E$0508TVW!L4T#01`%T/]G
M9\=GK^Y`LFSG9(24X`8LT0150$1`$Q1``XB,P#DYN6-+QA><?+<[2P'P'O`'
M\8"V:R]]GW-0;:(]"=#,TS@,)4L(LQ`)P>MFJ4'BHNVZZZLN&12RKB[-<]"7
MICCE"XK[]V*<;">/6X\Y"A3)"V=OF67<?4;A!&(;,VG[;+Q+HY`?"C]_+ZO=
M'.36SUZK0W$\V0]C6,T'^L6G`D%?J*:+=`AT(2O^\0M):CXGC?'3?`````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]Q82YP
M;F<`````````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$R,C,`,3`U,34T
M,S,W-C,`,#(S,30U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@``
M`8!03%1%````____8P4J8PDL:0TQ9`XO91`Q<Q@\;A@Z;ADZ;!P[=B!!@2Y.
MC#57ET)CD$%@BT-?ATMBB%!EBE)HDUMQC5EMDF-UH72%J'J,MY&@Z-O@7P`G
M80$I7P$G7@$G8@,J8P4L8@4L90<N:`HQ:PTS;A`W<10Z:A4W=!@^>!U">!U#
M?"%'7!LV@"9+?R9*A"M08R$\B2]49B,^:R9";2A$C359;RI&>S!.=BY+="U*
M<2Q(D3I>>#!.>C)/?C12?C13?#-1E3YA@#54E#YA@#94F$)FA#I8FT9IBC]=
MCD)AGDILGDIMDD9EH$UOEDEIH4]QHE!RFDQLH5%RGU!PG$YNH%%ROY*DM9^H
MM*&IMZ:MJY"<P*FSNJ6NOJRTV<G0Z]OB__[_Q\;'U-75QL?'U-74Y^?FW=W<
M^/?W_?W]^OKZ]_?W]O;V\?'Q[.SLZ>GIX>'AV-C8U-34TM+2S\_/SL[.S<W-
MS,S,N[N[LK*RIZ>GG9V=E)24BXN+?W]_____````I`\]30````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```"L241!5!C3;<RQ#<(P$(7AL^_.
M"<$%2H?H:+((P[`$.S`*'1(ST#$`$A(2M""(8_ML'%'"7W[2>P`_*=B`W&-_
M<'//;)IVLB.`)-4^=T=/1&96(VC(TJ=5.BW45T(A&1XD,6:#;!O.OM!M.T65
M\Q6YMJS=NY!9^Z?04O,X<T,JI&C:YGQ!;FL3?!B)!M0ZZLY6'+V/0R&T"(+J
M;(UVO0M2Z(60#*$J1T%2BO"G#R.G2%H#[B+#`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]R;RYP;F<`````````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,#,`
M,3`U,34T,S,W-C,`,#(S,38Q`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````
M6,P=C@```P!03%1%````____`"5_`R>!`R>`#3"%'T"0.%:B.E224&VT9'_#
M98#``"=]`!A.!2Q_"2Z!"B-9$C:&&#R*$2IA'T*.&3)J)TF3(3IS,%&9*D1]
M06"F.U602&BL4&^R5W:X7GR]672Q9('":(3$9H&_:H;%$#)U$#%T%#5X%SAX
M'#U_)D6".%F?,DV&/%F21F*=5&^E:8.V=8V^S;(`S+(`S+0`S+4`S;,!S+(!
MSK8#SK<#S+0#S+,%T;<'P:H'S;,)PJL)U+P*U+T*UKP-SK<-PJL-V+\0QJ\.
MV\04WL48S;<7TKH8X<<=Q;`9Y,TAY,XAU+\?Z,\FUL`DZ](K[M@O[MDOSKHM
M\MDUX<TX^.,^^N)"_.5&_NI*_^A/_NI0W<M&^>50[=M<T+4%]=PZSZT%U;,-
MW;P8Y\8F\=$U^MM"Z<Y&_N!-]=E._.!1S"L0U3<=WT4KZ5,ZRTLU\5]&VUA"
MZ&),\&A1]&9/GB8;IBPAJ2XCKS(FLC,HY4,UM34JNCDMMS<LO3HNPCXQP#PP
MR$$TQ3\SRD(V[E%"ST<Z\%5&U4D^U4L^VD]"WU)&\UM-XU9)\UU/\UY0ZUM.
MYUE,\E]1\%]1[EU0URTAXCLOP#HPR#XT[$D^\E5*XU-)\UM0[EI0____````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````S7I5^@````%B2T=$`(@%'4@````)<$A9<P```$@`
M``!(`$;):SX```"<241!5!C3;8R[#L(P#`!M)W5"!8@%\0U=Z*_QRRQ(#`RH
M%7G;I#/<>#H=P`\(!_#+-(?EG:_C]-C[&P'PQ:C$-5I$'-T`!(97U;`FXQ&-
M&U)7[DPJ(13F7K'4KNRG2HMYWCDDDK15OE259.^]LEBR@@5I51MY=K8/2I6N
M:BV*#OTID;Y:VU['W`0-<R354VU;]>R&/)G^%FVB\(<O!V92)YD@/],`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W)U+G!N9P``````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,C`T,0`Q,#4Q-30S,S<V,P`P,C,Q-S$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___^L#1BL
M$!JQ%!ZR'BC),CRB+S?!.D.M-S[714^W/47&25'B55[85U_B7&786F*\("O;
MXNJ\Q<Y\@HBBJ*[J\OH@;K,N=+(Q;:(X=:M4FME/C\E8F]>UO\BTOL?'T-C4
MW>7BZ_,`6J0%7Z@)6J$)6J`0:;$09JP28J@58:08:ZX;:ZTA>+XN@<0R?\(G
M8)`T>K0X@\`V?KA&E]E%C]!"BL4[>:Q`@+=&BL)0G=Q.F-52G]U0D<I7G=9,
MB;IJK.%II]UNKN/9X>CG[_;8W^7K\O@`7J<#8*D%7J4)8ZD)8:<-:;(,8J<=
M=[X=<K8?<[0OA\PUB<PP=Z\W@;Q"E]E"DM)!C<A&D<Q/H-]0G=I3FM-8HMU7
MG-->I=UFJ=ZWP<G#S-/&Q\?,``#(``#)`P/0!07,!07("0G1#0W8$!#2&!C<
M'1WD(2'2(!^D&QNP(2'J+R^O(R.\*"CR-36[*BK'+B[',##A.#C2-#31-C7V
M0D+\1D;E0D+F1D;^4%#[3T_V3D[U4%#^_O[\_/SZ^OKY^?GW]_?V]O;R\O+N
M[N[GY^?DY.3AX>'8V-C6UM;4U-32TM+0T-#.SL[-S<W,S,R[N[N=G9V4E)1_
M?W____\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````>[B43````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+I)1$%4&--MP4U*
M`@$8!N#W^\D)8B`BH19)!!.M,O)27L*=X+9MJX[2`8($H3;"!!&V<Y-:XWP_
M'4"?!]A!>$2\/$T.5.$6WN:(@<QJ+"((S["1@'!*=^2]?,YU2;2Z?5T*KB]P
MKK.BN[K_[6-P)%^*@NRMZ;V3U%7=^6A;*&ZR:;9>*8M4%/.KJ>)S;B>6NCSK
M+/BR_5Z`</SGD5RN53@C(QK%\,=,5(I#83-W?V!LW%E8"Q7WR$SL\0\BY%9)
MM@IE-P````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O<V$N<&YG````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0W
M`#$P-3$U-#,S-S8S`#`R,S$U-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P``
M`%C,'8X```,`4$Q410```/___X.MA`!T``!S``!)``!(``%Q`0-V`P-T`P5X
M!05V!09X!@9V!@=U!PEX"0IX"@MW"PU_#0U]#0UZ#0]]#PI3"A""$!)]$A-[
M$Q1Z%!B&&!B!&!%;$1V+'1I]&AV)'1R$'"&0(1^''QMK&QED&22')26()2>+
M)RN4*R)U(R%R(2^;+R%M(2^:+R9Z)BZ2+BA[*#6@-2N!+"I^*BV#+2Z%+B^'
M+S"(,"IW*C"',#2.-#.+,SB8.#B7.#2--#:/-CZC/CZA/D*J0CJ4.C*`,D"B
M0$:N1D*>0D.?0SJ*.T"50#N*.T:B1DFG24BE2$:A1DVO34FF25"T4$^R3TVM
M34RJ3%"P4$^N3U&Q45"O4$ZJ3E&O44:71E"L4%2Q5$^D4$R>3$^C3U>Q5U>P
M5UVV75^W7UZV7E^T7UFH64Z33F2[9%^P7V"P8&6X96J^:FB[:%NC6U><5U27
M5&BW:'2_=&FL:7K">FNF:V:>9G2R=&^J;V^H;VB=:(7(A8;(AFZB;FVA;8C(
MB'"D<(&[@7:G=HC`B'FE>8&M@:#4H*S/K+/7LS"1+S*),3:/-4&>0#^:/C^8
M/ENW6F:X96VU;*;#I?___P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(P(`PX````!8DM'1`"(!1U(````"7!(67,```!(
M````2`!&R6L^````P$E$050(UV-@P`)8V52]\I/M9+B9N<25C-R#@4)LLJYY
M:9[JDH*\P@IZSB'A0"$QR\SRKHKBVH:BPI:,P$@_H)!N;,&4J:U9[4S55=UU
M,6$3@$(^^2F)'8V5S35E;9WUT1[60*')Z?UJ\H)2HG).$9/B?1TL@$+9_AHB
M[.P"TIJ.H3%!+KW&0*&X'@E./G/OA)S2IMR)-J;Z0"%;&6X6'D4#MYC4DB1[
M,T-MH)`R/S.'D)R.<TA40)^5B98*-N\``-F@+<N\X.43`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]S8BYP;F<`````````````````
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`U,34T,S,W-C,`,#(S,30W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____)T./
M4EENP,GA`2>%$#22"B!6'T&5*D!Y4&VY<H2RAI&M`RR&`RN$"3"#$CB*&3%G
M*4N8.E>:.E6/2&BP)SA=2&:I3FFC5W2U1%N,<HS&8G>E4F*'?)/&BJ#0?9&]
MI;+.N,7B!"R`!BY]"S)_##%\#C2`$C>"&S^)*TR0'S)9.%F=)3MG1&6F2&:E
M6G>T8X"]9X7!:86_;8G!9'NHH;/9'C]Z/5N-3&:.-5%Q0%9D4V5?;GYH,'X-
M;K)018\A290F7Z8^9Z=)8*4Z9JQ"<K-/;*I,1HX=.FP;0'0A7J(U38,L4HHP
M5Y`T69(V9J%"<K-*:J5&=+1-=K5/=;51=[51<J].<Z]./X<00W8C6IXO1WPF
M27XH2X`J3X4M48<N5(PQ4XDP5HXS69(U6)`T:ZU"7I<Z;[!&8YT^8YP^:Z5&
M;JE)=[50<:Q,=[11=K)07Y\K@+E&@X]V2X4#C[]19YD4B;,OK,M*;7A)?)H%
MN,Y0FZ\8OLHU>'XWH*8`V=Q-D)`]L[-@L:X'JZ@[RL,=IIX@S+P`S;T!S+T%
MUL4-V,D0LJ44U,8?Z-@FZ-PZ^NU"W=`\QK,`S+D#S;H)T\$;Y-`AQ;4BZ]HK
M^.8^_.M&_NY0^NE/SK@%U+T*____````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````,-LK/P``
M``%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#!241!5`C78V#`
M`IC%!$7D6?0U557XV2R:9LT&"FGK2LF9*&BIJ_`)V$Z<,*<:*,3.J:@DSJ2A
MS&K5,F-F0ZDS4$C65-I`0H97K7)J7W]%J'LF4(C'3%)'F-NZK7M:;9%]>(`?
M4,C84(_#O&YN5VNYJUM!D+\O4,A(5,BFIV->3:%3<'Y.>J(/4(C+LG%R>W.9
MHTM@6%Y6<GP,4*AX>N>DJD@'[XS<B(#4A%@OH%#OE/H2.X_HM)""[)2DN"A/
M;-X!`,DQ,?590(Y``````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+W-D+G!N9P``````````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T
M-@`Q,#4Q-30S,S<V,P`P,C,Q-38`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,`
M``!8S!V.```#`%!,5$4```#____6/D#,P\8Y-CG3T=,B(R/W^OKQ]/3?XN+3
MUM;.T='Z_/SAX^/.T-#BX^/L\.^:KYXF<"D`0``#.P,)8@D%*@4-:0T.8PX*
M1PH2;1(8;1@8;!@?=B`?9Q\)'0DG>R<A8"$I;RDJ;2HXC#@XB#@[?3M(E4A0
MG5!&B490FU!7HE=>IUYDK&1HKVAJL&J%HX4D*"2AL:%Q<G'P\?#(R<@P@R]!
MCT!:FUEFJV5IDF,?1A$B*@`V-C5'1T9:6EF\NK6T@62203)L!P#'``#(`P/+
M!07(!07("0G0#0W3$!#.&!C#&!C%&1G<'1W@(2'/'Q^=&1G+(2'&(R/I+R_5
M+B[M-37=.#CU0D+X1D;B04'#.SOZ3T_[4%#U4%#P4U/R5U?X7E[W86'G6UOH
M7%SW967T963[:FK+P\/&OK[BVMK5S<WX\?'OZ.CMYN;;U=7\_/SW]_?V]O;R
M\O+KZ^OGY^?EY>7>WM[6UM;2TM+1T='$Q,2ZNKIQ<7%G9V=A86%04%!/3T].
M3DY&1D9"0D(_/S\^/CXU-34T-#0P,#`O+R\N+BXJ*BHH*"@A(2$='1T;&QL0
M$!`-#0T%!04#`P/___\`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!\%BT6`````6)+1T0`B`4=2`````EP2%ES````
M2````$@`1LEK/@```+])1$%4"-=C8,`";)P#H],3PKW=7=R\_,,B8X%"PM9.
MJ8E1`1XNKIY^(1$Q<4`A264+QV2F8!_?H-"H^*2T%*"0HJ:>EI4#<V9&=E9N
M3DY>/E!(35];55I(D(^+4X"=AX.7&RADJ6,N*RIA4%%>4EA05%II"A3255<0
M5S)BK>`W*2PNJZJN`0IIF$F)&+*T-=;7&M?9-]FU`H549,08)D_L:V]N:&KI
MZ.[M`PK)R3-,F=3?U=+8T&S;V<,V`9MW`!@%,!WIX]A)`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<V4N<&YG````````````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0V`#$P-3$U-#,S-S8S`#`R,S$U-P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___P,;
MO!(LNR8ZJC!'RBU"M#I1XS]5SDICZTQCX5%IZU!FX&1E:S-)OP`BKP`CKP$C
ML0,DL0HLM@H@>!@ZP"9'S"M,SBI!G3Y>W$9EXCI2LTUKY$]LY5!KVF1\Z&5]
MXP`7:P$EK`0GK@4IL`4HKP8IK0<KM`@KJ`DLI@HLK@XQMA$TN1$RJ!8YO!DZ
MM1(I?Q@WHAY`PB)$QB!`N"`_KR`^J!HQB"=)R1PTD2$ZFB,]G#!2T"(YDBA#
MI357U"I$IR]*KSM<V#%,LC51NCE7QC93O$-CW3Y=S#-+ID=GX$!<QD-?RTQK
MXDEFU4=DT%!OXTQIUE%OXU%PXU%OXDYLVTUKV%)QXE%NWD);M$=AOEERTVF#
MYQ4UF5=QQVV%U7B/W(&%B*FLK6]S<YZBHI*6EGA[>Y27EY.6EH.&AIZAH7=Y
M<G%P4-:X#>'$'=2Z(.[3+\JT,-6]-OK@0N?.0.K21O_E3_G@4/KB7OCB9<VM
M"KVN:,[`@,>C#\6A#\FD$,&>$L6B%,JH%<2D'\VL(L:G(ZZ4)-:V+L*G,+&8
M+<^R-LVR.[FB/=B]2=[#3YJ(.Z>41>[39,BR5*"02*Z>5Z:97[*D9\J[>+BJ
M;Z"48<>Y?,J]@M;)DO___P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````=R)/T`
M```!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````OTE$050(UV-@
MP`(4%<VE$R9.,E554M$QMO<*!@D9>"K$]_7H"BAK&]FX!T0`A40DHN7CNCHU
M!(5%Q25E0OR`0K91,7*1K6V:ZGH63K[A8=Y`H9ES9D^;T-C0/WE*]?2:63.F
M`H4J*TKRJ^KJ<_,*BLO*2XL*@4))&6F\.;7-V8FI62GIF6G)0"$>5F:FV*8.
M,79.;BX./C86H)"KOAJ_84NWAU10J(^+HYT54,A$2TG(K+TW4#;"W\W9P=H2
MFW<`XBLP^)*X4R$`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]S9RYP;F<`````````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P
M-#(`,3`U,34T,S,W-C,`,#(S,34U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#
M````6,P=C@```P!03%1%````____P<+"LK.SU-74X.#?W=W<U=74S<W,OR$`
MP2(!OR(!P2,#PR4%P28%P2@)QRH*R2T-PBL-S#`0T3@8QS<8U3P=V$$AWTHK
MXDXOYE,UUU0X[%P^Z%H^[V!"\61&UE<^]&E-Y&1)]&M/]6U0[VM0\6U1[6]6
M[7!7?W5S__#MP!\`OR$#Q"4'PB@*Q2P/PBT0Q"P2SC(4SC@;R#D=R3H?W$(F
MVD<KSD8MES(ACC`@Z58ZJD$NV%0^RU,\\V5*Z&5,\VI0\FM1W6)*]7)9U693
MPEU,WVU9^(EU]Y&`?4U%T8^$S+NX[W]MZX-S\8EYZ(9XMVM@^92&Y(V`^[.I
M?U]:IHB$U,7#U<?%RKV[^>KHPWMR]9^4SKRZUL3"^.7CX=#.YM;4[M[<^NKH
MBX!_S;NZZMO:]^CG_O[^_?W]_/S\^_O[^OKZ^?GY^/CX]O;V]?7U\O+R\?'Q
M[N[N[.SLZ^OKZNKJZ.CHY>7EY.3DX>'AWM[>V]O;VMK:V-C8UM;6U-34TM+2
MT='1T-#0S\_/SL[.S<W-S,S,RLK*Q\?'Q,3$O[^_O+R\N;FYL+"PIZ>G____
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````Z,7O2P````%B2T=$`(@%'4@````)<$A9<P``
M`$@```!(`$;):SX```"[241!5!C3;<L]#D%!%(;A,^?,F>$FB$(B"@FU0F\=
M]B`VH*!24DBN0F\S-D&B$8F$ZS=QSPS7J'G+)]\'\)."[B-I'K<W29TVFIC7
M!)FJIF76!T?\%3PA=!#E?MEXI0F)Z`4:KJ6,'VDM0]9A]MX"PCGODB1#;7AO
M>$?UL&H\"U%Q7U:(K56[>56!L!)9;(B3=-[/14L)QWQL$+SW3GHFMN-IH-R0
M@KQ$P-@1HPHT87A[+V[!=F9QH.!/']A'0C15FE5^`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W-I+G!N9P``````````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`S-0`Q,#4Q-30S,S<V,P`P,C,Q-C$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___^+
MBIVAH;1<7G6EI[W2T]PJ,5%K<I)S?)OJ[/.<I+QE>*9WB;%C9V\>.W``)F8%
M*VH%*VD*+F<0-G05-VXA1H(A1'LU6),S58LT4H-&::%!8))"89,R2G`[58%!
M78E0<:=.;:%5=*9/;)I0;9M"57-JA;!D;GX*+F82-FX?1'LN3X`R378X5'\^
M78E&9YI8=Z9:>*.EM]$`+FL#,&X)-7$-.G<=280O6I0P4X$V68E":Z,X6(0Y
M681&:IQ/=JM0=:A#8HQ*:91>@+!FAK)LBK)J@Z9[E[YYD[>`F\".F:BOO<_J
M\/;GY^:Z&@JW&PV^'@^['A"X'1"X(A7'*1K`)QG","+,-BG3.BO"-RN8+22C
M,BBO.B_:2#NC-2SA3#ZZ0C:O/3/33D'%2#VZ1#K$2C_L75#G6D[75DK96U#O
M9EGG8U;L95KG95NG0S[;9%ZD'1BE'QJI)!ZJ+2BT,"O"03R<.S>[2$/05$^Q
M247`55'29%_;:F719V)\>'B(A(3^_O[\_/S[^_OZ^OKY^?GX^/CV]O;R\O+N
M[N[KZ^ODY.3AX>'>WM[8V-C6UM;4U-32TM+0T-#.SL[-S<W,S,Q_?W____\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!<36[;
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+9)1$%4&--M
MC3L.`5$40._OS4@0C4JCD-!9@]8*;$4C$HNP!"O0BX8%:&P`(9A$?,*\>Z_I
M.>4IS@'X`6$Z;+06HQ`$-*I^?$QP?#^7^5H83,WB6(``M=NQ'J,71D<3`8&9
MX2;,H]_J69WZ*RM:S:M9PH9,Q`GFNA=H^[96-B1$%K3H>X:054ZR2PZW]`+G
M*[Y/`H-/-"="?E7=_5':".SNN9)(FDJFN48OCB\U80JE@%$1*<(?OHR+5R*B
M#G..`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O<VLN<&YG````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R
M,#0W`#$P-3$U-#,S-S8S`#`R,S$V-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$@````P(
M`P```%C,'8X```,`4$Q410```/___\H#!+P/$LX2$[<F)^$P,L(M+LTS-/`\
M/O%,3?Q14O!04=5/4,=-3\I45<QB9,0-%,AT=\RTM;`:(_;"Q=.^O^72T_GF
MYYL/'9PC,[5)6)XJ/(DJ/XI)8ZEZD(]>>'M5=TPS6U]3=E%$;6I<AWAKDWIN
ME(A]H&]DB%Y5>F]EBTU%:%1,;T`W8D5";$%+>SY2@86&B`HS<C5;E#15A$9L
MHCM7@4YQHU=YJVJ)M?;X^^[P\^'CYM36V0$N;3!4@SA?DS9:BT)MI4%GG"Y)
M;$9LGD)DE$]XK4QRHU!WJE!UJ%R`KUZ"L6*$LF:'M"%/BB=4B2]BGDYOF5Q^
MJ51QEG67P//U]^;HZLC,SZNMKN'DY<;'Q_?R\<QB7\P``,X#`]`%!<P%!<T)
M"=8-#<P0$-(8&-@;&N$='=0@']`D(<TA(:<;&[`A(>XO+[(C([PH*/(U-=LP
M,+\J*L<N+M(U,LHP,.$X.-4V-=(T-/I"0MT^//Q&1MX_/^5"0OQ*2NI&1O]/
M3_Y04/9.3OE04.M14,Q)1\R_O_[^_OS\_/KZ^OGY^?;V]O+R\N[N[N3DY.'A
MX=C8V-;6UM+2TM#0T,[.SLS,S+N[NYV=G924E']_?____P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````!RX]DT````!8DM'1`"(!1U(````"7!(67,`
M``!(````2`!&R6L^````P$E$050(UV-@P`)FS9H1P]@S8?*T:5,F]O=V=H"$
M9DZ/E1`7$VZ?.FE"7Q=C-U#(*"I:M)67/Y4OTL[6QCH\`BCD&AHF7RT@E"T5
MZ.CIXQ<2#!0RM[)4*&V+RY(),#'SMG`W!0KY^[HH,TO*"LH%.7MXN3DY`(4T
M-%64].R-#115U=2UM71U@$(\12Q,(OJ&TISUW%RU'.RL0*'RM*3XQ'2VPIJF
MYKK*DH)<H%!F<GQ"2D9>56-+0T59<7X.-N\``.&N,5K$\W''`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]S;"YP;F<`````````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-#``,3`U,34T,S,W-C,`,#(S,38P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____
MU=35Q\;'R<K-^_S^^?K\ZNOMU-77RLO-R<K,OK_!Q\G+]_G[\_7WYNCJV=O=
MS]'3`%F=!5VA!5R>#6>I$&>J&&FG'W&M(7:W&UJ()W"G(5^/*7&G+76L*&B:
M-8?&+G&D,'6H.(*[-'FN.8"W-GFM1I;20HF_3Y[84)S63I?/2I#$0G>>4(Z\
M2H"H7:#248BR79;";*S=:Z?3<:_=`%R?`UZ@"6&A'76U(F23+X;$*FV=-GZQ
M0I711I#%4)S3;JG4Z.KKUMC9U-75HJ2AVMW8;J!!?[1/?K%0B+=>C;EE.'4`
M(TD`.W<#/WD)1(`-2H`72G\7-5P14XT=48<?4H<?/V894H4B9)TO7Y,M:Z(U
M=:Q";Z(_9I4Z6($R8XP[6GXX@+%1@ZY9C;M@A*];CKMCC+)HFL)T.W8`)4H`
M0'L%/WD%2H003H086I(A.5H8:9HX>[!&@[50A;-7E<!JQ<C"^?OW[.[JS]'-
MRLS'R<O&Q<?"^/KU]_GT[O#KX>/>UMC3U-;1[.WIY^?F^/?W_O[^_/S\^OKZ
M^?GY]O;V\O+R[N[NZNKJY>7EY.3DX>'AV-C8UM;6TM+2T-#0SL[.S<W-S,S,
MRLK*____````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````IU%
M20````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"Y241!5!C3
M;<$]3@)1%`;0[_Z\&=`1H4`+HXEA"VY`W8T)G14E#:%P-ZZ#QFAI#,1&I##1
M:-[,_9X+T'.`/P0WV/7')8*AJN_'<N?85,WV+08Y5#W9D\`Q^:A.VS:;)K>D
M9P6.QPLVS)*]QT+)*PB,R\H<$>RZXIZFBODBWQO($C$SNTT`JJM>O_'1\'"0
M#NKKO7T(+G<_W[2Z=M/"0CXXUI]!L;:M3:(+!AQ?YY3GB=KVJ/#UA"_XQR\T
M9$U]F9V9U0````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+W-O+G!N9P``````````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,C`S-@`Q,#4Q-30S,S<V-``P,C,Q-S$`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!(````,
M"`,```!8S!V.```#`%!,5$4```#____-TM<G;:LJ;JLM<*PN<*LO<:PQ=;(P
M<JTP<:PR=*\S=*XT=*TU=*TX=Z\Z>[4G47<]?K@]>K%#A+XN67]"?K1)B,%-
MC,5(@[@Z9Y$W8HA.B+Q6E,Q/B+Q+@K-`;YE#<IQ:F-!7E,H_:I))>:1@G]=>
MG--+>Z=?G--7C\%-?JI/@*QEHMA1@JY=E,97B[E3A+%HI=Q>E<99C;M8B[EH
MI-IKI]UOJ^)>DL!NJM]OJM]FG,QCE\59A[!:A[!UKN)NI-1MHM)KH,]VK^-W
MK^)SJMMQI]=WK^%VK-YVK=YVK-UFE+YTJ-=ZKMQGDKE[KMQYJ-*)NN:&M>"+
MN^=TFKR5P>F3N]^&I\6=O]Z8KL*MPM6SR-NYSN$G;:HK;ZL<1FLR<ZPS=*TY
M?;DW>+%(BL1#?K)/D,E(@[='@+)'=Z%6C\!2A;%(=9Q6B;94A[-1?J5FG,MR
MK>%QK.!FG,ISKN)JH,]UK^)VL.-FF,1WL.)VK^!WK^!TJ==[LN*`L^"`M."&
MN.1_H+R)J,.WT^O"R,WAX>'6UM;___\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!`K(S)`````6)+1T0`B`4=2`````EP2%ES
M````2````$@`1LEK/@```+=)1$%4"-=C8,`"$A*D[4("C,42V;B%)#2MJT!"
MH@7!#3892?&<`N)*YA5>0"'!W,!&)QF>3'D.$5DSAQI'H)"*3Y"O5EI<4W.R
MLFZ1A[LM4,@^Q$]?S#^JE2DFO-C5K=``*!1<;R/)RQ+:WA9I5.Y=9I(#%&IT
MDN-G9XZ(CFVQJ':TS-<&"M5F"W.QIE2FJX75N=OFZ60!A2`N2E6W*G4K,=53
M50`*9?"Q@5WDXNEL8JBA*(7-.P#,H"E;_`J4(P````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<W(N<&YG````````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-C(V`#$P-3$U-#,S-S8T`#`R,S(P
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````"0````X(`P```,I*QIH```,`4$Q410``____
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M_________________________________________________________W,^
ME=H````"=%).4_\`Y;<P2@````%B2T=$_Z4'\L4````)<$A9<P```$@```!(
M`$;):SX````A241!5!A78V0``D8X`28A+`0-8C(AV*0")+T(D]%L`Q,`!9``
M$W>_+[X`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<WDN<&YG````
M`````````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-C4U`#$P-3$U-#,S-S8T
M`#`R,S(Q,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````%@````T(`P```)I[;E$```,`4$Q4
M10````#_`$)"0H3_A(S_C*7_I:W_K;W_O<;_QL[.<\[.SL[_SM;6UM;_UMX`
M`-[>WN?_Y^\``.__[_<``/?&QO?W]_?_]_\``/_.SO__________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M_____V8724`````)<$A9<P```$@```!(`$;):SX```!3241!5!C38Q#$`OB8
M&,2Q`&$&$H4EP(`3A1)A8)`$`@%>%@XQ$,7,*P3B2T*$)5D9.4`4&R,[F"L*
M5<TM!%(MQ`&$4-4\7#S\/"#`#Z>YN!AH"0!ZI`Z>`OUO#`````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=&,N
M<&YG````````````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0U`#$P-3$U
M-#,S-S8T`#`R,S$U-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X`
M``,`4$Q410```/___[Q25-9V=]9[?;"!@NJLK9Q15-US=]9X?'`H+:<]0\)B
M9ZY=8MI]@I\S.\:AI+B0E;:%C65`1V=%3*5Y@\JMMI-B<XU7:IMYB(UC=L*?
MK\VQP6%78;"HMWMUAK>RRXN'KC<Y;%!4@!$=6BXZ<C,]<W)]J51:=``36`X?
M7FMXJ`<=8"$W>C)#?$UAH5YOHPHB9`TE91(H910K;A8M:Q@O<!TU=2$W=2]&
MABD\=2Y!="T_<C1'?S!#=C1'?#5(?3]2B$=<ET)5C%%EH$=8AU5IH$%/>5-E
MEDU<AEYME@`:7``;7``:6P$<70$:7`,<7@,=7@4?8`4?7P<A8@@C9`DD90DB
M80HD9@TG9Q`J:A(K:!0N;ADR<A@P;!TV=2$Z>1\W<1LM6B8_?2<]=RM$@B(U
M9"$S82]'AB](AB8Y:"@[:S))A35-BC!&?2H];2L^;SI2CC!#=3Y6DCA.A#9*
M?4)9E4):E49>F49>F$IAFT9;D#U/?$A=DD59C$E>DU!GGT]EGD]FGDYDFE%G
MGE!EG%!FG$UBEE!EF61WJ59NFXR%8:^HAJF95;ZK9NC)9>#$:XJ#;.Z_6<RN
M9\:O?KJG?.JY7LJ;78I86-RAH/___P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#G-4QL````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````ODE$050(UV-@P`)$9#5X%:3%NG1\@Z(2<BL;@$+",UCYV&8*B6L%
M1)IGE#6U`86XV%DXF)FX^54B8G.<W%KJ@4+R`C*<<H)2:F$F#I,G3/%P!`J)
M*JKS*%M)2ICJNDZ;--73'BBD;5"G9*P9JFIAV=X_O:_&#BC469MBY.]G:)9:
MK-_3VZU7`!3JR(L.]`F)22ZL<O&:Z&Z3!10JB0OV!KFHHJ'9V=8Z.QTHE!CN
M$Q@9GUG>V%I=6I2?EH3-.P"513#TS(.&!`````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]T9RYP;F<`````````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(P,C4`,3`U,34T,S,W-C0`,#(S,38P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____S`<+SQ88BQ,4
MTB,EV"DJW3(SYT5&QSP^X5!2]EM<]E]@^G-T['!Q_X2&`&T``&L``V\#!7@%
M!6\%"7$)#7\-#7@-$'D0&'\8'8@='84='X$?(8@A&V8;(G`C+Y@O+Y4O-9PU
M*GDJ-9@U,(4P,((P-HTV0J="0J1"1J9&1J!&3[!/1IU&3ZU/4*U04*Q04*I0
M$7T0(XLA-8LT-HLU2*I&0YM"4:]03ZE.7GHZ-U4$;:@,=:X0@KD@DL@RJMQ2
MJ-A3:J,#-E(";*4&HM5%=:8#>:H(=Z@)@[03@[`;D<`D<Y8C?:$JH<\XAZLP
MFL,[C[4WKMM)G\=$M-Y3KM=0H\L=E;H%I<<9L]<PE[(OH+PUPN1"J\D^R^Q1
MOMU-RNE5F[P,L]0JP^(^M=!"SNQ.QN%0S^Q5I;<.Q\P(QLP*S-$.RL\9V-TU
M[?%6S,P(S<T)U-01V]L;WMX?Z.@MZ^LRN;DKQ,0R]?5`^/A$S\\YX.!$_OY0
M__]3[NY/\O)2_?U7^_M7E(LCI8L(P9X(OYT(PJ$3S:\MXL9-]-EISJ04?P``
M?P,#S`<'S0X.?PH*U"(BIR$AE"DIYT1#G2XNQD%!^E]?_VMK^&IJU')R]Y>7
MLGEXNX:%\;*R_]W=_>GIZ>GI____````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````"-74^`````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"N241!5!C3;<&Q30-!$`70
MF=E_Z_6)D(R`"I`#5T!&/]A=@`CI@@)(:,"!B0F0D)"<64Y`Q][\3P'PGMD?
M;G=:>FQ6[ST+AD4=7F&E--[FS7.-R;UV-]CV$7*VM7L$@'R!W9.:<CJ,WZ-'
MB.:VK,F>U_M+/YZ',W>P!V923^50VQ?Z3(.=)$E7%Z5$B-0;[%.B8CP#H%DI
M@WW\D!Y1$$Z2,MANZC&@MJ',[92S[!^_4M14_##5CND`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W1H
M+G!N9P``````````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`S-P`Q,#4Q
M-30S,S<V-``P,C,Q-C0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.
M```#`%!,5$4```#___\U**=)/+M-0JUF6\9_=-Z*@.&'?=QX<+F!>KZGH..&
M@+:=E]"MI^*OJ>(E%Z0D%Z,M'ZHL'Z0M(*4N(:<N(:4N(J4P(Z<P)*@P)*4S
M)JHZ+;8Z+:\[+[$_,K4[+ZM`-:Y,/\1&.K1+/[Y00\-(/;)%/*0^-HY:3LI>
M4M)52KM=4LQ52[EB5M%63+122:U=4L!93[9L8-MD6<MK8-=F6\QN8MEA5\%N
M8]EQ9MQE6\594*QJ8,IV:]UR9]5P9=)V:]QV:]AE7+ES:=)Y;]:`=]R(?N)X
M<;E]=KZ(@<B7D-9\=ZR5C\R.B<&SK>VVL.W0SO+)Q^?9U_G7U?;<VOBHILVE
MH\AP;X?*R>2AH,>@G\:SLMC!P.6RL=/*R>F4E*W.SLG-S<C,S,=_?WSY^?3A
MX=S6UM&4E)'___OZ^O;N[NKGY^/4U-"[N[CW]_1\)!-[(Q/%.1_)/23%/231
M2"_,3#7=5S^8/BWK:5+;9U+V>6+'8U#(95+!8E#Y@6O(9U;0;ESP@V_;>VK0
M=V:D7E+YDX"N:%OIC'JZ<63&>FS0@W3UFXKEE8;ZI)3TH9+^_O[\_/SV]O;R
M\O+EY>7DY.3AX>'8V-C2TM+0T-#,S,S'Q\>\O+RPL+#___\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!!MW$9`````6)+1T0`B`4=2`````EP2%ES````2````$@`
M1LEK/@```+A)1$%4&--MSKT.`5$0AN&9V3E[=N.GH1%1*+96:*A<C!MP"V["
M]2B4"HVH)42$E4BLQ<Z9X_0\Y?LU'\`/A!G:.)&7J"(%/&=XL"NOA`5J[(WW
M`B$E=W'U-WNI\$)8"VG397<J2F<Y3NO6'X"@O=+\^1$3&9M:K<J0UI-EL1?#
M1Y-:U!(A`FK:>^S4M`SC^[%MY`1IYS1\C4>#<];;[OI)%GXMB,!KX,.I"''*
M<!-!)L.$E?JPP1]?'K!-P,)IPML`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O=&XN<&YG````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R,#0V`#$P-3$U-#,S-S8T`#`R,S$W,@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___\S'R,`@`,`A
M`+\A`'@5`,(C`[\C`\,E!<,F!<$D!<`E!<$H"<HM#<(L#80?"LPO$,PP$,0Q
M$L<U&,8V&(PF$=4\'=A!(<H]'Y4O&9\Q&\U$)Z<W(:HZ(^-.+^).+Y\W(;`^
M)M)++[-`*.93-;9"*KY'+KM&+;A$+,%),*E`*L-+,==3.-=4.,M/-<E.-,5,
M,^Q</LM/-N]@0M!4.K-(,O%D1MQ;0-99/O-G2MM<0KY1.[Y2._1I3>!@1M]@
M1N1D2>)B2/1K3_5M4.AG3.MI3O)M4>]K4/%M4>AK4.=J4,M=1NUQ5^QQ5_!W
M7N!P6?1]9/-\9.]]9>Y]9?:":O'=V<$F",4D"<DK#<$J#<(M$-(X'<<X'<D[
M(-](*\Y#*^93-]=2..]>0MQ:0?%D2>)A2/5J3_)H3NAE3/-J4.MG3NYI4/-K
M4_5O5?5_:/JKGLNTL+\;`<$<`]@Z(<DV'])$+^E1.O-F4/!F4<=I6]9\;LMZ
M;L]_<LI\<..3AOFHG.*?EMZ<D^RPJ-2AFMRHH<V>E\VRKOKDX<A^==6,@\J&
M?<J+A//2SM&VL\NTL>;&P\RWM>O5T]31T?CX^-O;V____P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````##BI%`````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````OTE$050(UV-@P`+8V*1L
M0WUU1;A9.84D5,U=0$)B9B'^*:71X<61X@HFSAY`(0'M@*"TA+K"]MJ8>",[
M3T>@D*)/OG=9#5-/W]3Z<BMW5TN@D$VH7U+LQ,ZVKL:PC"PW:P.@4+"_15Q4
M?W=+4W-'7HZ#L190*-!)AK^H:G+KI"D%E8ZF.II`(2]E80[FB.H)O0VYF9:&
M&DI`(3U1'E8NP9+$U(IL:P-U%5F@D"0O"SN?N'QRNH>]OI::G#0V[P``H_DM
MRGH$U]X`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]T
M;RYP;F<`````````````````````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$R,S8`,3`U
M,34T,S,W-C0`,#(S,3<S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=
MC@```8!03%1%````____Q\/$IZ2EX=[?QL?'Q@X`Q@\`QA``QA$`QQ$!QQ(!
MQA$!QA("QQ,#QA,#R14%QA4%RQ<'QQ@)S1D*S1H*T!P-T!T-SQT-QAL-TB`0
MR2$2U204V"<8V"@8S2<8S"88VRP=WC`ASRX?HR8;XC4FX34FY3HKJRPAZ#XO
MKBXCM3(FUSTOMS,H[$,U[$0UNC4JTSTPO3@LPSHNP#DM[T@Z[TDZR#XQQ3PP
MQ3TPSD$TS4$TRC\S\DP^\DT^W$8XT$(UT$(V]%%"U4<Z]U5&]E5&VTL^X$]"
M^%A*Y5-&Y%)&^5M-Z59)Z5=)^5Q/^5U/XE1(^5Y0\5M.[5A,[5E,^%]1]%U0
M]%Y0]E]1[%U0\6A=T6MC?DM']K^ZW<G'^N3BQ@T!QA`#R!<-R!H-R28:SRL?
MTS$GR#$FD",;K3,KW$,XB2THT$E`YU%(N$M#?30OY&-;^&QDXVQC]X=_](9^
M^I&+_)J3_^SKG%A5_M#.]<G'TK:U[-+1\>[N?W]_____4Q]*5`````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"W241!5`C78V#``NKR*UC+
MH[+D!3D$I)3T7`*!0C$9>;'Q`:G"''SBBII._N%`H>S,@M(:PV0>+A%9=5OO
M"%^@$'-T66U<2B*GD(RJF4=HL!M0B*FRBJ5:D@UHD+Y+8)"[-5"HI+@H)YV7
M3PQD4)B7HR50J#`W+2F!6U1.W<X[PL?9W`@H%*DCS0\T2,W4(S3$S<9$&RAD
MKR#(#G*1*]`@*V-=#:"0,M!%$D"#_,(\'2P,M%2P>0<`HJ$E=SYYUW0`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]T<"YP;F<`````````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P
M-#0`,3`U,34T,S,W-C0`,#(S,3<R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#
M````6,P=C@```P!03%1%````____ES<\BW^`>FIM1CU!HIZ@K*JK14!#U=35
M?'I^`#NE`3RF`3NE`SVG!4"I!3^F"4&G"D.M#4:O#42L$$JR&%&X&$ZN'56[
M(5J_'U2T*V+&+V;*-6O-.&K#/G/40G?71GO938#<27C.3X'=4(/=4(#848+:
M16ZW7(/(*UBEEZG&E*7!F:K&I+70BIBNLL+=P='KS=STQ-+IS-STL\'6O;^^
M]OGWY>CF`'0``'(``W0#!7@%!78%"78)"&<("&8(#7T-$'X0&((8'8H=&'`8
M(8LA'X0?&VD;(G,C(6XA+YHO*'DH-9PU*GTJ+H(N,(8P.)@X-I$W-(HT0JE"
M-88U1JI&0IM"1J%&1I]'3[%/4*]04*Y03JE./X(_6:Y93I5.5:!5:+IH:+1H
M;KUNU=C5^OSZ\_7SK:^MZNOJT]33)8$D-HXU1XM&6J-9V=O8R<K(TH]?NFL^
MCHR+0"`4DD0P>F%;B2T:MHN".C4TI%5(LWAMJ75K;SXW7UA7KE-.S65@T'-P
M>1033Q(26AT=VW%P8UI:0ST]E(V-5%!0<V]OCXN+M+*RL*^O_O[^_/S\^OKZ
M^?GY]O;V\O+R[N[NZNKJY>7EY.3DX>'AV-C8UM;6TM+2T-#0SL[.S,S,RLK*
M____````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````-3C6HP````%B2T=$`(@%'4@````)<$A9<P``
M`$@```!(`$;):SX```"]241!5!C3;<&_2H)A%`?@W_GS9J(6!)9#]R!T9:$.
M+8%#FT,1W4A+EQ"DDTN"+D%+0Z!\H/%][WG/Z0+J>8`_").3Z4W]LJ_KK$>J
MJAO&Z?ZZ\Q#69%$1$0*#/(RX,5(182D@W+(E?S8B8A(G7BC:E1X>[\Z\N%FH
MI@5C>M]]*A0>I8Q$Q@K"+,*K+:>W82ROK/,Z%UQ^O*\_!U_U1>#\^"?UEHI=
MU9BL-+<3-SO[=C`.N7#BU%+*_1+%\8]?WGE2VL"6W5H`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W1R+G!N9P``````````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`S,@`Q,#4Q-30S,S<V-``P,C,Q-S$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____0
M-3;#.COZN[SQ]O;BY^;(``#'``#'`0#&``!]``!\``#(`0''`0')`P/(`P/&
M!`3+!07*!07(!07'!07,!P?("0G'"0G."@K1#0W0#0W)#0V("@K3$!#6%!3*
M%A;9&!C8&!C.&!C-&!B0$1'&&1G<'1W;'1W@(2'?(2'0(!_/'Q^:&1FD&QOB
M)B;()27E*RO()R>L(2'J+R_I+R^O(R.D(2',*RNV)B;8,"^X*"CM-37L-36[
M*BJ^+"S#+B[`+2W',#"N*BKO.CK),C'&,##*,C+=.#C1-C7.-#3+,S/S/C[V
M0D+U0D+5.CJX,C+X1D;W1D;</S[;/S[B04'A0D+Y2DKF1D;#.SOZ34WE1D;3
M04'J24G[3T_Z3T_[4%#Z4%#N3$SQ3D[X45'W45'U4%#T4%#V45'M4%#H3T_0
M24GR5U?U7E[E65GY9&3*45'05%3T967'4E+S967[:FK&5U?U@(#[AX?XB8GH
M@X/'<'#/>GK=F)C8EI;3HZ/)OK[MZ.C___\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!%#T`=
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+-)1$%4"-=C
M8,`"N'ET(TMS/)1%.(3D-&T"$X!"/*H!);FA.N(<`M+JIG[Q:4`A6>>\RJH8
M&3Y>225#GZC46*"0>39+8UV!(*>8O+Y+>$I2,%"(N8*U5D54S5U.RS8H,3G,
M"RA45,Y6(\%A5*@!-"@]FLD-*)2?5=]0;""I"#0H(];?U1XHE&FE4%9M`3$H
MQ-O1$BCDH2+*)0PSR,':&"BD+<[.+Z5NXAN7%N'I9&>FA\T[`*?_*#DB=9A*
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O='0N<&YG````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R
M,#4P`#$P-3$U-#,S-S8T`#`R,S$W,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$@````P(
M`P```%C,'8X```,`4$Q410```/___T%!0@$"`RHL+7-W>8N-CA`3%+&TM4Q3
M51,7&'M_@"HO,%!96XR5EWA]?G=]?E5<73U%1F9O<"\R,I*8F$U04#H[.S0U
M-9V?GVUN;C8V-9.3DJNJJ7%O;L(B`,`A`+\A`,(C`\$C`[\C`\8F!<,F!<(E
M!<`E!<$H"<HM#<DM#<(L#<XQ$,PQ$,0Q$M$W&,8V&-4\'=M!(<L]'\U$)]]*
M*^-.+^).+Y\W(;`])M)++^E4-;A$+.E7.L%),,-*,=A4.,E.-.Q</LM/-N]@
M0O-D1MQ;0-99/O-G2MM<0K]1._1I3>1D2>)B2/=M4/1K3^AG3/-L4.MI3O)M
M4>]K4/%M4>AK4/!W7O1]9/!]9?:":K\?`<<B!GT6!,0D!X0="L<K$=<](<@Y
M(+U"+>]<0JU%,]]?1LM;1OIP6>MM5\UG5,UF5:=?4_*.?<^$=\-]<.Z;C>&2
MA;QZ;WE/2/^PHMR?E,Z5B_B\L8YL9NR[LMZTK,$8`,@D"LLP&-0X'^M1.=)-
M.O-=1MU:1?!E4/I_;-M];\21B>^]M=X[)JDP(961D7-Q<65E95Y>7E%144Y.
M3DU-34I*2DA(2$)"0CX^/C`P,"LK*R<G)QT='1D9&1(2$@T-#04%!0,#`___
M_P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````-L=A,,````!8DM'1`"(!1U(````"7!(67,`
M``!(````2`!&R6L^````P4E$050(UV-@P`)*>&:)2\D6U:G+J^H:V[CY`X7B
M*@5[^YC8LFN4M8TL7`-"@4():=6BDV>PR^74&I@Y^X3Y`H4L,UJKA&?/8V9M
MZ[3S#`GT``IY1V<UMPLQS.7JSFL*"O9R`@I%1;@G)Q9PSIDI(EG:DNYB#Q2*
M]#/5B8DMYYT^=2)'8:.#+5`HW%I?12&^ODQ@4K^83'Z*%5#(T5!#44TOJ:&"
M;\(4">[B+J"0B::"DI:1>6IF![_T-):>7&S>`0#GKS%C`T*1'`````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]T=BYP;F<`````````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`U,34T,S,W-C0`,#(S,3<U
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____
MMWY_Q(F+LIFOH8FBN:B\VL7?74ACEGVBB&J:N*G&Q[7;8UEQ?&.EMZS/R+WK
M;F*T;VF:E(SADHO=9F*41D6V.CNV7VG+7XZX9I:]ILSKK<[I<Y^ZE[[6;)^\
MFLCCDK_8H=#L<*2_>*O&E,CBG,_IIM3LD,7==I^QFLWDI-;MJ=KQCZBT=*.V
M=:&SC\+6>Z6V=9VME<'3J-GMH,[BK-SQI]?JH,[AK=WQ;ZB\;J6Y=:[#<ZS`
M<*>[<ZF^<*6Y<ZF]<::Z=*J^>:_#<Z>Z?;/'>J_#?;+%@+7(>:N^?*_!A+C+
MB[_3B\#3BK_2B+O.B+O-C\/69XR:DL;9<)>F;I6CE\K<FLW@C;O,F\W@HM3F
ME,'2J=GKKMWOJ]CIK]WNKMOKJ-/B;J>Z<*BZ>*_!@;C+@+;(@K/$B;W.A[C(
MG='CN.+P<:JZB[;#I]CGHM#=K-SJ@:BQ@*6HD+>YK]G<LMS?H<C*B[.TBJ^J
ML-O-JM+%N^37ILW`D+*FO.33EKFGO^;0Q.7$Q>C"Q.>_P^6\F[F0J<B=HL"6
MI,*9P>"PI\.4S>JOT^^PZX5LZ8YXE&19YZV@OU`]T650]()LJUQ-WGAF[XIY
M^+JOPVQ?[(5VNH=_P$P]@3,I<TI*____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````_`]Q
M)@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#!241!5`C7
M8V#``CAX16<*\/!+R*?8N_EJ%?8"A>9-F#U]QD1F)CTK]T#5_,8RH-#<J?U3
M^B;/F:1OXZ-1U=QC"A028F.?Q<W")Z:<;J#6TJ1D#!1B%1:9)BC.R:7B%Q5K
MIEY>`A22D9;3E964RLL,-X^+5^AL`PKE%&39)N>FIH5$)R1:M%<8`H62(KT<
MK)T]@[)UZKL4&XJ,@$(QWD[6CA[^$2:6I;4=E9IA0*$,5VL[EX!P[9K6ZNZZ
MXM!@;-X!`)O0,=Y=#YV;`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+W1W+G!N9P``````````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,3(Q,P`Q,#4Q-30S,S<V-``P,C,Q-S8`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!(````,
M"`,```!8S!V.```!@%!,5$4```#____"`0/#`@3"!@C'"`G/$1/?'1[5-3;)
M0T;?:&JI!`FI!0NK"Q"V$!6T(B;?8&3JZ.FXK;<S$3@K##0Q%#J<CZ`\)$HF
M#3:LI[&-BI"0A)XT(DI30V=216*"=)0E$SXQ)S]>3W)N88!R:WQ&-UQ72FL2
M!R4>##V!>)!!.%(4"R8;$2\L'DI`.4YM8H0R*4@/!R0E&$=94'`U*E5,0VN-
MAJ,;$D+U]?3,``#-`0',`0'.`P/,`P/0!07,!071!P?-"0G4"@K6#0W.#0W8
M$!#/$A+;%!3>&!C2&!CA'1WD(2'4(!_H)B:G&QOK*RO8)R>P(2'N+R^R(R.Y
M)B;=,"^\*"CR-36_*BK$+2W!+"S'+B[U.CK*,##-,C'A.#C5-C72-#3/,S/X
M/C[Z0D+:.CK@/S[\1D;E0D+^2DKJ1D;_34WN24GL2$C_3T_^4%#R3$S]45'V
M3D[[45'Y4%#Q4%#]9&3___\```````````````````````````````#=2G&G
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```*1)1$%4&%=M
MSKL-PC`4A>'KQ[T.(9%`R@Y,P"@P!<NP`6O10H-0H$GD9VSCH'1PRJ_X=0!^
MQF`GA38=W5Y[5-1LJC.'6O>=&7)*`E&U"H%#6.6K%"DS0MPJM"!!BF:("B5'
M;(FB+_1FTF<?`I/UFI@)A7IRE!+C;`[IRZ'0R=Q'DRM2<R@<IY+/#^T2+:$8
M?*'GZ";$;\@&%V.AE_7+(VNG6.C//HUM2*VM2%1F`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+W1Z+G!N9P``````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C`T-0`Q,#4Q-30S,S<V-``P,C,R,#4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!(````,"`,```!8S!V.```#`%!,5$4```#___^8B(^*?Y-W:H144(]>6Y!J
M9Z9N:Z9F9:IF9:<M+60S,VLU-6TY.7([.W0]/7<_/WE"0GU!07M$1(!'1X1&
M1H)*2HA)289;7*!45))D9:Q75Y9;6YIA8:-D9*525:9%1XA76:I14YM45IY@
M8Z]@8ZY.3XT)3R%9DFPL:C]JG'DE8S=5C650AUX45B0I53,2/!LC8#`91"(A
M3"I+@59#<4U/?EEGFW)QHGMNGGARHWUSHWT(,1`R7SM#>DX[:$1AE&MBD6MM
MGW<_=D8?(!\F71E:ADP[:2.,K753;!.+G$YS?"`:&AAM:@QS;P^GH%"'?B!W
M80>1>B(,"@-R6`4M)Q2MF%&)=T9V6`U50A"8>2IX82>FBT1D5"NXG%2#=5%8
M/0).-P55/Q"IA36SE$_&IV2LDEEA6DH\."]:5U`P(@DR)0U)/R\;$`"8>4FV
MG7P6$@VCBFRHDGD2#@I/3DT[.3@"```B(2%04%!/3T]&1D9"0D(^/CXZ.CHU
M-34O+R\K*RLF)B8A(2$='1T8&!@4%!02$A(0$!`-#0T*"@H)"0D'!P<%!04#
M`P,!`0'___\`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#[?*-R`````6)+1T0`B`4=2```
M``EP2%ES````2````$@`1LEK/@```+Y)1$%4"-=C8,`";&U-S&P<[8TTW/R3
M*^JK*T%"Q@Y6%J8Z^EY!.2T--5590"%#.R=G/2T/O\22UL;:TH1TH)"!N:6N
MBT]H7D];4UU&?#$;4,C,6M,],*F\MZ.Y/B*-65D1**1MX1V<S=#7V9(96\"A
M(BX"%/(,B"GL[^_RC4ME4I-4%Q,$"H7GMO<Q](1%%[&KRDF)"O,!A<I:>QEZ
MHU)8E*3E922$^'F`0J[=#"&1^:P*G%RRXB("O-S8O`,`XIHMEL0;DN<`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=6$N<&YG````
M`````````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#(R`#$P-3$U-#,S-S8T
M`#`R,S$U,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q4
M10```/___T"KS$&KS$*KS$2MSD:PT4:OT$6LS$BMS4NSU$ZVUDNOSE"XV%*Z
MVTVPSS1VBUB^WE2TTCM_E%S!X6#%Y&+(Z%JWU$2(G6C,ZTJ1IV7`W''3\G36
M]56<LGK:^&[&X5ZENW'%WW;,YX+@_H'?_&>PQX;B_X;A_8#7\HCC_XCB_H;>
M^7*]U(C@^X+6\8K<]I#A^H?2Z9;E_Y7D_9GG_REK?T.MS4.LS&"\V&W0[GW=
M^G[4[GW2[)3@]T>MPDRQQDNNPU:ZSUFVR67&VW?5Z6NZRW/'V8;A]'O,W6NQ
MP(WD]HC<[H[>[I[H^+S#%[[%&;W$'L;-(]'8,L;---_F1+[$0<C.1^SR5MK?
M4MWC6/'W8NSQ8NWS;^SQ=<S&`,W(`<S'`<['`\S&`]#*!<S&!='+!\W'"=3.
M"M;/#<[)#=C2$,_)$MO5%-[9&-+-&.';'>3>(=3/'^CB)J>B&^OF*]C3)["K
M(>[H+[*N([FU)MW7+[RW*/+L-;^Z*L3`+<&^+,?#+O7O.LK%,,W),>'<.-70
M-=+--,_*,_CS/OKT0MK6.N#;/OSW1N7@0O[X2NKE1O_Z3>[J2>SH2/_Y3_[Y
M4/+M3/WX4?;Q3OOW4?GS4/'L4/WX9/___P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(/+;:<````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MJTE$0508&6W(L1+!0!``T-W<W>Z12112H-<:E=+__X"2`H4Q#$,DN<MMSO6\
M\@'\0-C`L9STSU<3%%D>T4X#[,O9^]VV`34O\8&@X%-,0SXZK^8WYL;3Y(BP
MF%*XU774UC)K=`<-:QU]-0R89:@4BJ2J8N@E#69I!HF@8=N>ZC9:XLI:YUR`
M#.*E<0,94Q")E]ZGNM8N&*/'.6'7.Y%4]\XK8[A@TW5!4OWQ!<=`4$JNB"%U
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]U9RYP;F<`````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#(P,S8`,3`U,34T,S,W-C0`,#(S,38S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```2````#`@#````6,P=C@```P!03%1%````____QYR>O8"#R<#(K:>MMK*V
MN+N^+#`L3E--4E=1.S\Z2DY)24U(96AD`P@!#Q,-*2TG,S<QLK.N5%5.86):
ML+(`968`L+(#I*8#M;<'K:\-M;<2NKP4>7H1K[$?UM@QI*8FQ\DOQ,8OK[$M
MV]X\N;LSR<L^H*$RXN1*V]U,Y>=1VMU0UMA0VMM>VMMES,P`HZ0`!`0``@(`
MS<P!S,P!T-`%S,P%U-0*I:8)SLX-V-@0BXL*WMX8TM(8Y.0AN;H=Z^LKV-@G
ML+`AO+PH\O(UQ\<NLK(JX>$XTM(T^/@^_/Q&Y>5"__]-[NY)[.Q(U=9"_OY0
M]O9.^_M1Q<9!V]Q/Z>E9_?UD"0D%%!00'!P8)24A'!P92DI&.SLX.#@U5%10
M6EI7/3T[;6UJK*FCO9Q?T)UEQ&8GHU(AUFXO[GXZVWD^^(Q*[(E,]Y!1[(M0
MSWI&PT<`Q$H#Q$T)S%,-R5,2U%T9UV$=S6`?H4P;X6LFY7(OK%4CN%XJPV8P
MS6TU\H)"XG]&]XQ/\8M0^9YHOB(-PRX8U$TYQD@U[EU'V%9#O$P[Z6-.\691
MZ6M7\WQJX40UW&]D/",A23,Q3SDW6T1"8$E':U)0:U-1=V%??6AF*`L)*`T+
M7$)"BG1T____````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````IBP8U0````%B2T=$`(@%'4@`
M```)<$A9<P```$@```!(`$;):SX```"W241!5!@998\]#@%1%$;O?>^^AS!&
MH5#H)!*)0J*U"0N;/5B"Z+4V(!J-0B1^&B&8,?/NQ]1SRE.<Y!!58)K2R+.&
M0O=#-J)V84FSV_44;<+E?/2[#K97IEDSYO29YA`G#>OSE="XWKU]6P_ECMR-
M@9+00-`#$HL$L4!+%:.0!CMHA!JK@IC:$("\SI<O-JB]4Z;Q)RM4K'5B$*#A
M(-1_9YEWXKWG;PB*OYKDRL:*,V4(".O*#M$/N=A8F??8?_X`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W5K+G!N9P``
M```````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`U,``Q,#4Q-30S,S<V
M-``P,C,Q-C,`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,
M5$4```#___^\8F.Z8F2Y<G/LEICRNKNN*S"O+S.Q.C^X1TO69&CA;7'E<WC@
M<'79@X:M;&["DI3<J*K2IZG)J:KYV]SUV]RG*#"G+C:H/$.^14VO04BY1DZQ
M0TJP1DML*R_`3E7$4UK16V+47671767.6V.32D_7<7C==GW3<7;*?8'FG:'.
MHJ7FQ<?(N+F:#AB<$1R;$1N>$QV<$QV=%R&E&R6H'RFC(RR?(BNF)S&Q*S6U
M+SFH+#7`/$:S.4+$14[.3UC05%W`3U>G14S#4EK47&718VO6:G+!H*/NR<SC
MPL7$IZKJRLV=2E:67&7$>H9R0$FPF)W-L[CKT]B=8W&H<'Z7@H?`J[#`I:RV
MGZ75N\+:P,?FS-/&L[CLV-Y^6'":@)&/;8:UH;%-3WNBH[12570=*7!&4(PI
M+DI78)ID:Y6IK+T%$UQH;Y"FK,BBJ<=18)5C;9"(D*XV1WU<;*%M=YF)D[0@
M-W8F/'IJ>ZYU@J80,'1.9IQ4;*%19Y9SA*EH=YB.G\33V>?I[/,-+G(.(TXK
M0W-UB[AQ?YR0DI9-9(RXO<9$6GZMN,J?J+?(TN*ML;::K;_1XO'!R]/D[_?G
MP\)Z4E+%C(RM@X/,I:7%H:'PSL[OT-#2P,#/OK[\Z>GTX^/___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````"/OZIN`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@``
M`,%)1$%4"-=C8,`"Y*=U=E1F%G%QY.949_FSS@<*900(+.@O*.5D+RQ/U&1K
M;@0*M?8D:4^=W"<AGA+*OV!2>PU0*"P\3E='9):%N;"0CUA,=!!0R%G#3<;2
M6-_(S-K>T57521HHI.ZN8&-B:&!J9>N@K.(B*PD4"HZ*\/80G&DG-5O4TRLV
M,A`H5%LW48\Y)%M1J6G*'*V$KC:@4'WW=+GXBBINGOR2WGDL?JE`H;E,OLDM
M:65\O'GIQ0T39JAA\PX`D3DR\!,AFY\`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O=7,N<&YG````````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,#,U`#$P-3$U-#,S-S8T`#`R,S$W-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$@````P(`P```%C,'8X```,`4$Q410```/___\%A8\9G:,5K;<]R=-R!
M@].!@K!L;>J1D\9]?M:,C?.@H?.CI,--4KY:7L!B9:YA9.Z*C=%Z?M:!A.B:
MG+I)4+M25[U46;916,9=8L%@9=)L<:)77.!\@;EJ;NZ3F.:.D\)S>;=H<+V"
MB-*GKEQ3J2<>A#$HBEU6JF)=G"8B8TM&GW=RP8N&S1T:6#8RE5-/F61AMV]L
MOH!]S8%^R8F&T!035QH86"`?:3(P=#8U?4I)IT9%D%M:IVQKP7-RO7]^SST]
MAG%RR&9GHW%ZN*6LWZBOX&!KKHR5R\MH8LQH8\QN:-:`>^N;EL>#@?NPK<,S
M,\4V-L@[.LT_/]A.3LE-3,M14>9?7]5=7?)P<,]B8N)M;?=[>_)Z>MAP<.]_
M?\UO;^:`@-MZ>OB,C.V)B=9[>\MV=?B0D,-R<<YY>?*0D-!]?>.+B_>:F?*7
ME[MU==V,C+MW=\>`?_";F]2+BL6"@NJ=G/BFILR)B<6%A,.#@^F=G>B=G<R+
MB_2GI\2'ALR-C?6JJM:5E=^<G/BPL.^JJM>;FN.DI,R5E,>1D<:1D:!U=<J5
ME:Q_?_&SL^6JJM"<F\22DKB)B=.>GLV<F_*YN/B]O>BQL?6]O.*OKM^LK/;`
MP/&\O.R[N_?(Q_K+R____P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"D`Y7$````!8DM'1`"(!1U(
M````"7!(67,```!(````2`!&R6L^````MDE$0508TV7/O7'"0!`&T&]_[E:'
M)`:&,23.';H75T`!!`2,(U?C4IRZ"@\1D1G02&#I]EP`KX,'/""\)CXWPVUW
M)S83HJVB(JG;\^G+B4E8"(INX_??N)Y>9!:LXO*I6$P24G^Q'Q95S0Y%+W6?
M2[L,(=9"_@?%NLBS3-^=2AK(<X$B>1&WMV"FYC<O`#Y,%RPAIJ9]JF?["H15
M-7%AYFY.UWF^-$?%^S`6BRE&RF.FT0^/'_P#H0,\OO_$$'@`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]U>2YP;F<`
M````````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3``,3`U,34T,S,W
M-C0`,#(S,C`Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!0
M3%1%````____Y.CST-'4B9G`G:W4K+SBO\WOEIRKRM+EQ,O<>8Z\A9>_E:G4
MCZ')<7^>CYZ_NLSSHK+4M\CMN<KOG*G%PM'TH*W)GJK%I[+,M\+;Q='KK+;-
MN<3<U>#YJ+'%U-[UP<K>P,G=J[+!M;S,V^/UWN;X=HV[=XZ\?I7"?)*^?I3`
M?9*\@)6_AYS(BZ'-@Y?!AIG!CJ++CZ+)G+#9D*+(>HJII+CBJ;[HA)2TEZG,
MK+_GEJ?*M,CPJ+O@L\;MN,OQJKO?NLSPLL/FO<[QFZC#J;;1HJ['ML/=J[?0
MIK#$T=WVJK3(Q]+IU^+XM+W0L+G+T-KOS]CJH:BVU]_OM[W)P<7-Y^OSQ,?-
MU-?=[O'W_/W_^/G[C:+*F;#:@I2UBYV_I[K>L\?MK[G,Q\_>NL#+O,'*V-WF
MR<W4U-C?[O+Y[/#WPL?/O<+*S-'9V=[FZ_#XP<3)K[.YRL[4T-3:\_?]Y^OQ
MYNKPP\G1P,7,\/7\X>;M\/7[N;W"W^/HR,K,]/;XY^GKVMS>RLS.R<O-[.WN
MU]C8W=:Z^O39?W56__75QK^IBWU6?W58IYMXG9)R]NC`Z^'&X=B^KXHNDG,G
MN)0Y_-1PTK!>^=)X[\^$]MB1XK==Q\;$TM+2?W]_____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````FYQ:7`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX`
M``#!241!5`C78V#``N;U]G<S,DE)2HB*NWE(>\L!A3JG3)W5P6G*PF/(Q\HF
M(L8.%.J9/'O&Q+;F^A;FIL:&Z)A6H%#?]&DSVV6X=0R,3*P=G)R%@$)SNB9,
MFAOJZNXIZZO@%ZB8#!3*+DBO2$VKS,BLSBJ-JBLN!`JY),9JJ6MHZL=9V";9
M627$`X7*2L)R<W/R\L.K:LHC(VJ+@$)<`?)>/OY*0:IJ(2DJRL$<0"%C72UM
M/5YS>T%A1QL!2S-^;-X!`.]C,:FG/XDS`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+W9A+G!N9P``````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C`T-P`Q,#4Q-30S,S<V-``P,C,Q-C``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!(````,"`,```!8S!V.```#`%!,5$4```#___^TFYVXKK32T=*JJ:W`
MP,;0T-3BXN3/TM*RL[.JJZOCY>&$EF>XOJO0U<:7H'^VO*1\AUF+EU.?J6YY
M?6.RMYC&RK'&Q\#&RY_:WKS+SIG3U;?+S+G-S<#8V,O\_/#1T<CKZ^'AX=C2
MTM#N[NW5U=30SY'4RQ_,O`!_=@!_=P#.O@/-O0G6Q@V+@0K,O!#AT1V=DAG>
MSR?2Q27NWR^GG2'AU3C'O#O&NSOZ[D_QYE#]\63X[67,R[[,R[_U].C__O/,
MN`#,N0!_=`#-N@',N0'.N@/,N`/,N0/0O07,N@71O@?-N@G4P`K.NPW.O`W8
MQA#-O`_/O1+/OA+;QQ30OQ/-O1?2P1B4B!'6Q1ODT2'4PQ_4Q"#8QR?=S"_H
MV#.RI2KAT3CATCB[KS+RXD+GUT#GUT'LW4CQXE#4QT;VYU?VZ%?ZZU[IVUG]
M[F3_\&CWZF7_\6K_\FJQJ(*=G)OIZ.?2R\>ACX:RJJFPF)CNZ^O(Q<7^_O[]
M_?W\_/SZ^OKY^?GV]O;R\O+JZNKEY>7DY.3@X.#8V-C6UM;0T-#.SL[,S,S*
MRLK'Q\?$Q,2_O[^\O+RYN;FVMK:PL+"GIZ?___\`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")B1;6`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```,!)1$%4"-=C8,`"M%V,+(MSDDWL
M>[HZVIKK:X%"6I$IA;GI,>%VW9WM90V,C4`A_<2\_(PX?P,Y=@D^`7X>5:"0
M659!9GR(1Y`BFZB0"*^P+%#(HB@[*<+;*4R>@U.P1$Q<!2ADFYL6Z^OL'J4L
M(ZU>P<PZ&2ADDQ$7X.;J9ZPD)5G.5%G*#12RC@_V=/8)37"HK:NNJNF?!!0R
MC_!V]@J,3E6H;6IEZ9LX!2BDH:NIHV=H:N78V*+6.X%K*C;O``!(?B_>QXU^
M(@````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=F4N<&YG
M````````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#$V`#$P-3$U-#,S
M-S8T`#`R,S$V,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`
M4$Q410```/___\,Q0JP!%ZX%&;()';,4)[T6*LLG.Z,G-JXN/=DZ3K@T1,A`
M4.-,7M=-7N-29-E28A(:FALCG#(ZN3$WFD-+QDU4PDY5P5A?T@P5F0\8GA@B
MJ!\HJBTUJCA#O$90TS<^I#M$IS]'L$Y9T&EPU6AOTPT;IQ<EI1TKM!\LJR`N
MJBHXM#`]IS0_KS9#L452S$)-P493Q%!<UU!<T5=BTEYJUFITW69QU@@9H1,B
ME!8EE1HKI1LIF1PKFR$PJ"0SI#)$Q"X^L"DT@4%0PT%/P#I'JT54P$A5LE5C
MRV%OW%9CPUMIS%MGQ%->K':!TR,UJ&%QV<;($\S,`,[.`]#0!<S,!<W-"<'!
M"K^_"M;6#=C8$,+#%M+2&.'A'8."$>3D(=34']+3(>[N+_+R-<[.+]_@-.'A
M./KZ0OS\1N?G0>WM1O__3_[^4/GY4+2S._7U5>/D4/;V5^3D4?'R6?KZ7O__
M:O#O;&MG`&AF`-;298B!,%];,+JR83X]-$0R$\P``,X#`]`%!<P%!<T)"=8-
M#=@0$-(8&.$='>0A(=0@'Z<;&[`A(>XO+[(C([PH*/(U-;\J*L<N+LHP,.$X
M.-4V-=(T-/I"0OQ&1N5"0NI&1O]/3_Y04/9.3OE04%Y>7O___P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(@(LNP````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^
M````ITE$05085V6/RP[!4!1%]WG<5H(&$7,1?VCB._@^(R*(9U&M>^[!V-JS
M-=E9P!^$>69E'A_/VC@+&G3!<)^T_=4T1D%$A<#8VLKB^\TAM7X$*-9G2G5E
M)'P)+&X0D-]6^UB<7L5QXYOFME.,4N\Q&.XBV[C>%^8@3,OL3CEQQ=*]=M+]
M0.A?-3DSB;"G[RK"LHS&*GE+*5HTFS&>]GO37/@KW/T_!_@`G'Q82;+:Z>H`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]V9RYP;F<`````````````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#(P-3``,3`U,34T,S,W-C0`,#(S,38P`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````2````#`@#````6,P=C@```P!03%1%````____W*"BO51;G%%6U7-X
MUGR!BE=:R*:HIS0]W'-\R&AOKV)IUWR#Z*>LL(*&J#M'<"<OVW^(NHB0SJ^T
M94)*J'V'9$1,M9F@GVIXG6%RG&]^NIVPS;3%E7J-95IBLJ*QO++(+R-8D8JP
M6U9]0#QO>'>(+#!G/4-U)S)P.45]-$2$0E*43%R?;GJK`!-<'3)Z&2II+T2-
M*CMX/E&9.$B#46.D:WFK`QIB"B%M#21K%"IT&"US(3>`(35T+T2)0E62.TIY
M/$MY7F^G9':M`!E@`!I@`1IA`QUC!1]F!R%G"2)E"B)I"B-H$"EP$2EM&#!P
M'39Z(3I^(3I]&RU>)C^")SU[*T.%(3-E)CEL*#MN-4V/,$:"*SYT-4V.*CUP
M+4!V+D%W,$1Z.E*3-DJ!0EB:0EJ:2F&?1EN315F125Z82%V73V6B3F.>4&6@
M4&6=5&BC4EQW`!MB`!MA`1UB`QUB!2!G!1]D#2=K$"IO$BML%"YS'S=U(C5G
M+TB),$1Y-$F`.$Z(1EZ=1EZ</U2+3V:B4&>C4&>B4&:?&SEM9G*'*T=V3V:,
M8WJ@-EN!7(=^@XV(9HQM;Y1Q3(I*99]9;(AE:W-IIL^.A;9DC,!J@;Y5?+90
MK,V*K--^E+AE@8Q;____````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````3]Z],0````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```#!241!5`C78V#``L3E"WD4941Z
M?5T]_8*BF]N`0J+L_$)\3,*2ZA85!O:IK1U`(4$6-BY69@%.)<O.R5/ZS;*`
M0FH<LKP*$M(:_M;=L^=.TFT!"HDIFW.KV,E):=KVS9@S4:<!**3GG*EJJ%^F
M96S4,W/Z5--ZH)!+=IB5>XF/3;C)A'FSYCO%`H7R8ZI*B[RJ0Y/3"[JF.29$
M`H4:`\K=RBN#XYK:<QVT$Z,B@$(UWL4>%8%U:3EY&2E)\;4AV+P#`!8Q,I^#
M$I\L`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W9I+G!N
M9P``````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`U,``Q,#4Q-30S
M,S<V-``P,C,Q-C(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#
M`%!,5$4```#____'3$^^8V;&5%Y>*3YN.%=H,%5X/FG/SL_CX^3@X.'&QL<4
M(G`!%5L''6<%'V78X.JBNM32VN.6PNV;HZM8H>)XN?.ESO6AOMB[VOB"E*2Y
MSN*]Q]!LI]AVK-MEE+MKF\.'O>J/I;?3YO:SPL_DZN]EE;MWK=&_S-7'RLO*
MT=/+S,RRL[.VTM%O@'^ERK?3V]?BZ.7E\>FRPK:KU+(FDC--IE$`EP`6DQ8?
MCB#4U=2-KXMQJ%^HR9W&S,2:NX*+M&RGP'2^S)KCZ=*IKI:0J"R?KCVVO8?F
M[XGAYI3M\:V7GA.?I2[F[4:\P3^LLCWV^+S$QI?"Q`"$AA'4V37P]%#K[4WJ
M[$^]P$##QDZKK$;7V%KK[63EZ&1T=3KBXW7J[7S?X'?K[(K4UH3R])S'R(#G
MZ9?6UY'P\;'O\,&SM`7DY2O0T2_U]4#N[S[R\4SCY$C=W5[!P89Z>F3AX</U
M]=K6ULGQ\>G.SL?Q\>V<G)G=W=SU\ERHIW-Z>52^KRJ]L4&QJ%WN[>/FU8W2
MT<V^FD2+BHG4J(&Q7AG28$_*5E/V]O;Q\?'AX>'8V-C6UM;4U-32TM+0T-#/
MS\_.SL[-S<W,S,S*RLK'Q\?$Q,2_O[^\O+RYN;FPL+"GIZ?___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#`#-]#`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK
M/@```,%)1$%4"-=C8,`"ZDNJ>1A[N(.*=2;W<U65!0*%XD.BTS-+)T8&5Y9G
M),5%)`*%VNMB8@NC1'U]7#UR\L.3FX%"TD(N1;D!`GS\O/IY!5YJDD`A!0E3
M6_]L5G8VCJ8P`Q%A1:"0DI2=E4U:)U-W5XNQF)RL.E!(1=#>TLR]@9FEHU9/
M7E-+&2C46\-I;N&6TMCFZ>VD/6767*!0WZ3I)HX.SJ%^">(:K3/GS`,*64^;
M/G6"H5%6:H6,ZHS9NO.Q>0<`^_8R2`\U(H0`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O=FXN<&YG````````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,#0S`#$P-3$U-#,S-S8T`#`R,S$W,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$@````P(`P```%C,'8X```,`4$Q410```/___]`U-L,Z._IG:-#6
M#=G>&-O@'>7K*\K'!=//$.G<+\BM`]:Y%/G>2L:G`-_`(>S(-<><!<RA!_/"
M/L>#`,YR"LAC`>)\)L=*`?6"0O>'1N]W.L<V`,U*&-]1(?%X3OIQ4-,P$/AL
M4<P;!\<1`,@7"=@W+^]$.LH:$M89%.(L)L<``,8``'T``'P``,@!`<<!`<@#
M`\8#`\8'`\L%!<H%!<@%!<<%!<@)"<<*"<X*"M`-#<D-#8@*"M,0$,H2$M@8
M&,X8&,T8&)`1$=P='=L='>`A(=`@'\\?'\\@()H9&:,;&],G)^4K*ZPA(>DO
M+ZXC(Z0A(;4F)M@P+[@H*.TU->PU-;HJ*KTL+,,N+L`M+:XJ*LDR,<8P,-TX
M.,XT-,LS,_,^/M`V-?5"0M4Z.K@R,OA&1O=&1N)!0-L_/N)!0>%"0OE*2L,[
M._I-3>5&1NI)2>A(2/I/3_I03_I04.Y,3/%.3OA14?=14?104/914>U04-!&
M1O)75_%75_5>7N596?ED9/AD9/1E9?-E9?MJ:O___P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````)Y+N<X````!8DM'1`"(
M!1U(````"7!(67,```!(````2`!&R6L^````O$E$050(UV-@P`+T]+WSVNKB
MG<QU3.W=P])+@4+Z+FFM#=F>:JI&-JX!*<550"&[F,;F(E];27%K1[^D_,I"
MH%!0+4N-NJ:)J+"6MD9N15D64(BYK3Y>3HB?DTM`4+JT/"<!*-32D.EE)<O#
MRLXM55)5P!0'%&H"&F1H(,;&(9)?79@:&PD4J@EQ,-91X960X5,NRTJ,#@8*
MQ3M;Z)HIR8=G*"KD)$2%^@.%/"QUC&S<0"XJ2(Z+"/3!YAT`ED0M<)HE0N(`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]W<RYP
M;F<`````````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,3<`,3`U,34T
M,S,W-C0`,#(S,C`P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@``
M`P!03%1%````____VAT>T#4VMP`.N`$/N`43O`<5O0T=Q1`>T4%.YEYJYF5Q
MLP`1M`,4LPD9N2`O&06Q#`&Y#P6[$PFZ(AC!)1O!0CJ[85GG<FKQ9EW2"@"]
M"0&\>WKR``!]``!\`P/,#0W-"@J('Q_3'!R:*2G3(2&G.#CA+2V01D;35E;H
M2DJX9&3X1TBN:&K]:6GU:6GS?7W[<W/E=W?B?'W#$A7.043;B(KPRP``QP``
MQ@``S0$!RP$!S`,#R`,#Q@,#RP4%R@4%QP4%S`<'R`D)TPH*T@H*T`T-S0T-
MTQ`0RA(2V104UA04W1@8V!@8S1@8W!T=VQT=XR$AX"$AWR$AT"`?HQL;XB8F
MUR<GY2LKK"$AZ2\OKB,CM28FV#`ON"@H[34U[#4UNBHJO2PLPRXNP"TM[SHZ
MR3(QQC`PW3@XSC0TRS,S\SX^T#8U]4)"U3HZ^$9&]T9&VS\^X4)"^4I*^DU-
MZTA(Y49&ZDE)^D]/^E!0[DQ,\4Y.^%%1]U%1]%!0]E%1[5!0_61D____````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````97%I=`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;)
M:SX```"H241!5!C3;<P[$H(P%(7A2R3<FX`.-)8NPC6Y!I=@[1JM*!A'D$?(
MX\8PEGK:\\T/\+,,3IFL0Z>?_9F4WM?Z)B!3Z/GH(TM$.B@).>RDM#PSITLU
M*%<0D'M?5G740JH]4;!)]2(*'V@6J,LB&I/4-`SS:M_+FI!T=T[J.CY>8]14
M-8C&7%Q2L1V60*A3R%G/6ZOMC:."OB'K0E+=M.0%X1:RS,'#GWT`9#U.K7;&
M=WH`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+WEE+G!N9P``````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,C`T-@`Q,#4Q-30S,S<V-``P,C,Q-C8`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____5U-7'QL<B(R/4
MU=7!PL(?(!]]?GV"@X(V-C5M;6SGY^;-S<S?UM//Q,'3S,K,P+W"(0!Y%`#&
M)07#)07/,!#!+0_*-AC#-AK;02&7+AG20B7I4S7.33/?5#C94SCT9$:J1S/`
M43OM94KW;%#N<%?E;%3B:U/Q=5SX@FK@=V+TA&[]\_'\\O#QY^7^]?/QZ.:_
M'0!Z%`!X$@#!(`/!)`G)*0W`+`_(-!>,)!'5.!V%)1/).1_B2B_O7$*S1C+<
M6$'T:$_O:%#U<EGP=%[N>F70Q,++O[W:SLSGV]G<T<_TZ>>FGIWX]_?^_O[]
M_?W\_/S[^_OZ^OKY^?GX^/CV]O;R\O+N[N[L[.SKZ^OJZNKEY>7DY.3AX>'>
MWM[:VMK8V-C6UM;4U-32TM+0T-#.SL[-S<W,S,S*RLI_?W]\?'QO;V]A86%@
M8&!=75U86%A145%04%!/3T].3DY-34U(2$A&1D9"0D)!04$]/3T[.SLX.#@U
M-34T-#0P,#`O+R\N+BXJ*BHH*"@A(2$='1T;&QL8&!@0$!`-#0T)"0D%!04#
M`P/___\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#BO.<T`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```+])1$%4"-=C8,`"C(6EE;74
M%"1$A43$I&0558%")E8.;JZ.MF9&IN;6=O9.SD`A&R5M'0TY20MQ2QEY%1=-
M=:"0KX"!OC>_AZ"[IY>/KIXA'U"(F3$L+B4C(S4Q-CS0/RPF!2CD%\S#FIZ1
MEA07$<P8$LV4"10*B$Q,RTA/CH\*90R*2.!E`PIEY99555>6YN=P<&9SYQ44
M`H5JVKL9NCM::LN+2BKJ&IM;@$+L70P]G:T-%<5%Y5SU32QMV+P#`/Q*+2HF
M'D7T`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O>74N
M<&YG````````````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,#0R`#$P-3$U
M-#,S-S8T`#`R,S(P,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X`
M``,`4$Q410```/___]74U<?&Q]SB\J2LO[O#U[6\S=3<[\S3Y``G>@`83`0J
M?00J?`DN?@PRA`PD6!U"DBU1GT!CKD%@I$]PN$MJK4IIJU!PM5-SN&6"P)VF
MNZ*KP*VVRHB.G+K!T=7=[LS3XP`I>@`93`,J?`4M?P4M?0TTA0\T@A`XB!@]
MB!$J7QI`CR%(EA]"BQDS:"E+DB]4H35:IBM%?#A:GD)FL#)-A$9KLSI7CT]Q
MN%!SN5=VMEY\NUIVL&6!O&J'P\G2Y;.ZR-35U>?GYMC6U<"^O:0I`*4K`Z8P
M":XU#;E$';!$'XLW&Y9`(\A6+Z%'*JQ/,+56-=5G0LEG1MQR3]=Q4*M=1<S)
MR/KW]O;S\NWJZ>OHY^GFY:(D`*8I!:0I!;`T$*PY&+Q$(:I`(:I"(Y(Z(:]&
M*)Y"*,M6-:A)+KE2-+!-,;)0-+]6.-=G1L1?0L=C1=MO4-1K3J!4/K]F2]5T
M6+5D3,5Q6-^#9]:`9^"';=:#:M+.S<W)R,S(Q\O'QO[Z^=W9V-?3T_OX^/CW
M]_[^_OS\_/KZ^OGY^?;V]O+R\N[N[NKJZN7EY>3DY.'AX=C8V-;6UM+2TM#0
MT,[.SLW-S<S,S,K*RO___P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````$NESDH````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````NTE$0508TVW!/6I"41`&T&]^[GN*X6&P$K00"SN7EL[**@CB?M+%
MWJP@8**(B(4:$#%&U-R9FP68<X`[A#8>RGF\GF,4U1!DPMB4\LP^;NLU\T:%
M%U"$4CZWQB7Q5Y-6K`Y&4;SEA_?OHEI\=G\JAS((XJ-,%&8>8U(-3XSGX>N+
MP#V9]45Z`83!M//+R</,.E/>U?9CQ:6^O2;1K"ZWEC>6W;'B>'(GB^Y"9O9X
MA&)A3DRJ3.XI><(__@#[2U)W%.T;9P````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]Z82YP;F<`````````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#(P-#8`,3`U,34T,S,W-C0`,#(S,38S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____RA,4X6)CU&AJ
MWG!RZX&"^)&2_YR>[I.5^YV>S7=Z]M35.SH[OL;^M[[R0E[W4&GZ8'C[=(;N
ME)W/O,7](3>M*#^X+D;#-$W/0ESA3VSZ3FCR@8JYBY3$HJS?L[WR&S6D(CZO
M*D:[,$W&-E311F7F4&_UP,;;U-CG>(V"S-G2A9N/DJ>:F*J?KL&UL<.XHK:I
MJ;JO=XY^.UE`'#L?36%/`"0``",``"```!<``!,``2$!`R8#`R0#`Q\#!2H%
M!20%!2,%!R4'"2P)"BT*#3,-$#`0$C`2$2<1&#08'3T=(3XA'SH?&2T9)T$G
M+TDO-5$U-$PT,D@R,$4P1F)&0EQ"2&1(-DLV0EI"4&I03F=.1EQ&3V=/4&=0
M7G9>97UE9'EDN;VY`1T`$B\1'3H;'#L8,TXO36A)05<Z#"L!:79AEJ:-EZ:.
M@Y)YBYN!?(ISC9N$<G]I>XARN;^T<(%9+T8%0%82/50`*SD`D:!0BYDX>(8-
M@HHJG:,8L[DOK;()Y.5H;VX*M;4GBXH@KJTXN[I0C(Q&;FY73$Q`(R,A@8!(
MQP``R`,#RP4%R`4%T`T-TQ`0SA@8W!T=X"$AZ2\O[34U]4)"^$9&^D]/^U!0
M]5!0QZBH9F5E:FIJ9&1D7EY>____````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````T-%^*P````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"_241!5!@99<^Q#@%!$(#A
MG;E9>^>(1DFH1$1H=!*/(VJ=9U"@DW@'G4JG4LHI50HA#MWE=L7=V-/ZRV\R
MDXP0?X'H<_D6G>-9DJ#C(.*0Q.`@6^QV)_$4$6R"A-?3C[ARK(U'&2!;<B7)
MY]GM+)M`*>`G`%%<W!.C=ZZ2=@:I69.8(S!B+D<D%:2,=A'#MWD%'E55`L1H
M+%V-WNM"W=M>E,]1/CL?A2?C-_R5XZ@WD\DHB'6[M`G!*_"OOV\L?`&V`4B$
MH;>>K0````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+WIW
M+G!N9P``````````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C`T-``Q,#4Q
M-30S,S<V,0`P,C,R,#0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.
M```#`%!,5$4```#___^^'""L&1Y,*BOBP,+%<'?+@HR[KK"YB)&DE)?LP,[[
M^/DW-3;:U]J,C(VWNKS)SL^)BXN_QL-D;&4;0A4Q7ADN<05;F35:DCAWJU>(
MN6HJ;0`N;P4Y>Q`^>QA)B2%LIT98ACMTK5!RDD%VFP-]HPV*KQUI@QN:OB]S
MCB-]F2J&HS".K#6IRT*AP$:QTD^NSE#$Q[MSEP#@Z%>JKV/#S`#%S@/%S0G-
MU@W8X1W-U!_F[B_R^D*AI2S?YT'W_T_R^5"KKT#T^EZ_PW;N\&78UQ#DXR&P
MKB&\NRCR\#7'QB[2T33\^T;EY$+^_5#V]$ZHJ)#O[^[0R@7*P`#$OE_MZ*_$
MNVG<TWO9R)>TGW/DK$[-=P'+=@'3?@K-?`W=BACJFBOWJ3[^LTWMJ$G[LU'R
MN&S7B"?2S\S/@#GTIVVZFX6^+@K;/13G32:Y1";$3"WT8#K/4S/?7S[];TKQ
M;DS\=%'/*`?#`0"]`P/'!P>L"@K1%!2_&!@A!07>)B;-*ROK.CJJ+"RT,C';
M/C[7/S[!.CKU2DHR$!#J3$ST45'C34W424G@45%"(2',='-4-35/-#1E1D9>
M0D)N4%!J3DXQ+R\>'1U$0D(Q,##U\O)14%!03T]'1D;AX>%_?W\W-S<-#0W_
M__\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#+ZSJ/`````6)+1T0`B`4=2`````EP2%ES````2````$@`
M1LEK/@```+U)1$%4&!EES[\.`4$0!O"=V;7GS\61B$KM010J"JU"(WHA"*]`
MH?`"GD!#2TVO$@^@N.8D<N[6CCDZYNM^F7R34>)OE"@!N$\B;2EV,,S@58EY
MOUJPQKPL($<"T["V;:7<T!(B`"`=E`AU;VWB"8M$+<D()8QWZE2G\UE6(^]9
MR[3:Y\_']!(>A(JPOV`:-+&RB2XHE8,4C6],]9UL=W,!2(ED.4R-LG^C>R)<
M]*51T0OX>.HC1$F][_^\]`9'(TO.,9\<@@````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9V]O9VQE+G!N9P``````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`S,C(W`#$P-3$U-#,S-S<S`#`R,C<S,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````2P```"`(!@```%I]A7,````'=$E-10?3"1H(`B/TB%/C````
M!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```&)$E$051H
MWNU8?TQ591A^X`(J>+UZY3=Z,;1``XK`'RB&`IDZO6XJ%I&2Y2@=B>D0UF;R
M1ZE)6DW4D&8ZEP&U;`@92;NUW%Q;6E.*_N@/MTS[H6UM49LKOK[GBW,[]W`.
M3FYLS,Z[?3OWGO/!^>[S/>_S/N\'V&&''7;880<:1#AF%8]"<8MC6*\S'R-1
MB?O#=J(RI!Y'0K;B9WB1.O0O)CCY34\COZ,=Z:_[U,AJ[D9>YWGDG:['_*;%
M0HCA!597<00.(!;5>$8!-16'AOZE\P\5(*OI*CP5!Y&\/$T#9=HT1&!*^5),
M:;B"C"\$D@_T8O+CN<..87OP!"K0BTG8.L1`-2U&6K/`^&5+!YSG7G%1#1?&
M_3_!DBS"S(]ZX2[<=M.Y<0_.4TP;AD'-4F`EXK&A>\M"WYN(KF'6!05">38B
MV^*PZGP2:CCVQ6,%[UG-?V$CXKY]%Y7:V+X&W@$W8LGV:.2\EX6IT^_&"%>*
MNLZH7ZGN:6"50YB!U>1&D;8N?O8_B(A>%#!&QB>KJVEX\E)0<*$';J\O&*"*
MG<AM<>'K76.P;?T(+.#U$S=Z+\3AVFI93XWS3[R$K1V[X2-`'$>J\?*5D^CY
MI1W7^%T_MZQ,5KMY;3N0WM"(Y*H7U7J]EW]5^LKO.8<GJM^]%\\JL":$EVA_
MZQT/9WL,VJHC<7"+`RMY[8J"X%H5^!I@1N!,@SO#%!Q;^,9@@2IPX;X38R%X
M#7@@=_]L!$1G",1TR5\]4!_LP!\H%@$L6C0+&9>/0W",#,-LWE-%ALQ/KGQ;
M_W^1UO%/H>%GC21&L(1P:$#IW_-:%#:])9\N"D5[/[#TUWZQZOLZ]>+!@N7U
M.K],Q)D-$3AG]I@,ZW)`;`C!#_R>,`T>,FBF1_XLDR##;K1"5*W`)7^%YF9&
M1MX;,#%[[S8DG17ZC`AY%;4R`?U@,=T("C(?B-7F/)*#%`)8XL!W1:%8?VL_
MEO3.Y$MEA1M$M*=AW<48W%CHP%&SYT5.W$G:5W'1"<4>:M/Y_1`9D[#,;#[9
M1;#VE,KYK+C<3-<Q/],"Y"/UC$!\Q6\!8)%9G@B5]N<\.%`7*@4?&$_@3L;B
M<%TD6O0LO[6@?\KJ%A1X"NZ`XCKKX`Q5.;E0^9DIP@4QU?R4-@3G4+?*0_$G
M%_GC:30R!=/OP*-674-/)WXG6'%12$?15_4*E-%Y=?UT+*G9G%E]8%U*PH?[
M)*L7A*)T?R36<N."JX1NC%%&4[W8PCI00.G>4W<>5\Z>`CMY9S<?<;>89J2U
MU2N8I@1+BDLZP2*SUBZT=MG7.]"]V8N_YJ8A09E?5X?:3+56+7C?42'TFB5]
M5@!83+=6N5]6*3^X8)5A_DO!3$TTZ:GTO2&U(N%]_T[3'DC4A*([2[E)^,;A
MFX>9AGWB'J!))G'I'5PG6/_Z0%GQ"$QR[4_*/*M.0[9@TO,93&FM7N`IY%Q;
M=;C4R_^JOV5Y5:T,09C:>HW:8MVTRKZ13E^7%@VC<8H[6!*.#N/TW!3$$DB_
MF,ZN<I)95JE(`3Y:B=["+#RDOQ\%V?O%/[G2SVR3+%#5D*:TCUED(BLQ![7*
M2B9N/29F)2JJ2S%5&D%+8540N,OZZBDK(@'AX&[JI]//&$&DCR(@'`1'OW""
M.%"*8FYKC=+8"5L^-S[BB8-*0UV[0[VB;G$SR?!=]V`&[[>YD,VU2@0':<29
M_W%K3F'49LF<1J&HGGNR42UP3F<ELH_O5EK%.<84D']+4%CUN(NT#&2<\C@\
M%3`$F5.[&E<)&.V"9E+YV7)]DI5J+<P`ZAA/1'A*HC7[9?@8.;@JW=YGF(Z-
MVGO):FIF59]<$+SG1N!3`A9T6C)UX)JY7%&=)Q`3-]7`\]1JBNI-:2O+/1T\
MQ_92G2!;!)E%IJD==_>?[_,A3*4^@6&!X5JX+EH&ZJS</#7'F%H\XPJ\Z6"!
M8:<1?%4<AI&9*:6*[IUL-NBHTC#J+#-@[)P*^Z1V]K%U+"9.)^XR1U,Z<VIL
M$*W:[1.L?)(YIG;&;RMD?V@SJ\__4<A94*P.`:3W"O9HZ;8(U=(HB_"\4-Z.
M7013DX-5FJ(O^SZ;58;36<0L>44QC$<U=/3L:>VPPPX[[/#'WU13BE[P*%ZU
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V=R;W5P+G!N9P``````````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,C,R-0`Q,#4Q-30S,S<W,P`P,C(V,3$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!`````0"`,````H+0]3````!&=!34$``+&.?/M1DP```"!C2%)-``!Z
M)0``@(,``/G_``"`Z0``=3```.I@```ZF```%V^27\5&```#`%!,5$4("`D4
M%!86%A@;&QP4%1<5%AC+TMS#Q\T.$QH.%!L1&"`0%AU$77E)9(%3;8EH?I:*
MGK2`D*(-$QD.%!I=>994;8=:<HM<=(Q3:'U:<(=K@9=9:GP?)2LC*"V"DZ3,
MU-S-T]E.9'EJAJ%*76]RCJF`EJML?(M=:WB)FZL.%1N)G*R!D9]R>7_<XN?=
MX>0E*"K(R\TU2DT1%Q0%"P=HIVDI?RDI?BHG=2@MA2TM@2TN@"XQAS$UBC8Y
MDCE$C40X;CA/?D\G628P8B!/<D(9*Q`?*@T$!`(^/#9S<&>MJ9RII9@H)R3F
MX=#;UL?PZMF`?7:6:1J@<Q[4FC[1C2?6D"G:EB_=F#'2ESM*038:#@$2"@&J
M7PJL8`S$<!._;1.^;1.^;A.];!//>1S.>1QQ/PJ,3@TK&`1I.@J$2@VZ9A/-
M=AJ\;1M(1D0D%@D<$PLC&`Y33$8#`0`$`0!M:VMZ>7EG9V=:6EH%!04"`@(`
M``#___\`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````S
M$L1V````>W123E/_____________________________________________
M____________________________________________________________
M_________________________________________________________P"3
MPZCJ````"7!(67,```L2```+$@'2W7[\````N$E$050HSV.H@H'*2C#%`.-[
M^OAY5<(%&)D8?/W\_&`"S.5EI17^0>%P`;?BDL(B[[!0N$!D=D)\HGM(L)\'
M5"`J*3DK-B(P`&P(2"`M,S4CSM7)V<[*OA(LD!>3DA[MXFAB8V4)%F#1*<C-
MSS$T=K"U,`4)L*JIJ!NP"XHI&EF;F8,$]`64I/5TM?A%N2LKP8;*JHI(*+!I
MR(MS0?TB(\6GK"TGR<NC"?.<L#`G)Z<PAU`5JF]A```B$EE50;2K&@````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:&5L<"YP;F<`````
M````````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`R,S$V`#$P-3$U-#,S
M-S<S`#`R,C0P-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,````$
M9T%-00``L8Y\^U&3````(&-(4DT``'HE``"`@P``^?\``(#I``!U,```ZF``
M`#J8```7;Y)?Q48```,`4$Q410```/___QT='#P\.WY]=[2SK=W<UO+QZ^'@
MVM33S]#/R\O*QLC'P_/R[O+Q[>SKY^3CW]C7TWY\=<"^MW5S;H:#?;&NJ//P
MZN?DWE%03F1C8=W;V(2!?;:SK]C5T?7R[NWJYNCEX>+?VV5A7%E54N?BWO+N
MZ^KFXW9S<=31S\K'Q;JWM?#MZ_3IXP@&!<F[M"XL*SLY.*:.A?#2Q_3CW61.
M1]R\L>C)O\I5->EL2NET5..!9N.,=)-=3NZ7?ZUX:.ZHE?"JE^&SIN.ZKMFY
ML*@T&=]))LQ(*>11+]]1,,Q++>AA0==C2,1B2]!K4]-N5NI[8<AU89M;3-:3
M@].3@NBBD?&IF-ZAD6154>;BX9$M%J@U&V\C$I0P&=1)*;I$*9`_+=9]:>V1
M?.BQI0$```L*"D5"0A\>'@P,#/___P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````!AHG.P```!J=%).4_______________
M____________________________________________________________
M____________________________________________________________
M_____P"\Y-SC````"7!(67,```N&```+A@%!!V6W````PDE$050HSV/(9&``
M(A#(`#$A6$..CUU"6RH5R`3+AQHK"BCR*]BX,F2"8;)CHCZK,(>YAUM,"E`-
MDV283VQ$.H-D0H"WEZD!4$MD>+PAT*!,!M\D)V60&7Q<1H:9(&"HJR0*$A#7
M%&,`"S#P"HJ`!%2EN:$J=+3``MKJSD%@,T)<9)F!`JF2UE9V@4"'!ON[VZ9E
M@-P1[6GIH"9OXA<7%<4`<6F,A1D;)X\]B`\6T&.0E!%BT5`!<R&^@7@7ZM-,
M-```1O$WBEN3HO8`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]H96QP7VEN9&5X+G!N9P``````````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#(Q,3$`,3`U,34T,S,W-S,`,#(S-38U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````0````$`@#````*"T/4P````1G04U!``#8Z_4<%*H```,`4$Q41?__
M_P```.;FZ"XO-%9767!Q<YZEK[N]P"(G+D5(3%A;7V)E:4%&3$5)3F5I;D1@
M?D)<>$AD@DUIAT]KB5)NC%-OC5-MBEATDF![F&5_FV:`G&N%H5UO@X*8L450
M7(V@MF-O?)JJO%A@:9ZKN:2QOZ^[R3%.:S-0;C)/;#).:SI7=3Q8=#]:=45A
M?4IB>DE@>%IVDQ8=)`T1%5UXE$YE?%-G?$Y?<5EL@#U*5UYQA#I$3FY_D'2%
MEGJ*FYNMOQT@(V%J<ZNZR5MB:4)'3$9+4*JRNDM.48^4F5M>86=J;:ZPLO#Q
M\N[O\.?HZ<O,S311;352;CU9=$U@<7Z/GR\]23,[0BXU.TY672(L-#Y,5T)'
M2V)F:=WAY$E,3N3GZ5UQ>^OM[F!S>^_P\&QY<G%^=X*(=*"A@>[6@$Y.3CP\
M/"4E)0X.#O___P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"ZX=T@````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``
M"Q,!`)J<&`````=T24U%!]4*'`8=`5*^]X(```"R241!5"B18V#`!C@880`J
MD*UH+*8;J*TC8`818724%$Y/3T_5U(^$*,BR,TA+5%=+#S`+!ZM@5)$2X4])
M3T_6LXAE!0EDRHL+Q:>KJ?F;AK&`5#"J2HL*:FFHJ9F$>()U9,A*"/,#%:@%
MA4:!%;`%V]I86\K(F,MQ08Q48N9U<^/D<7;AXX8(.$1[^3(E^23XN4-<9<_(
M:*6@'!/GS>X!<S@#R!,13JYP/A@8,3(:,F`%`$PY&T@J'L"]`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VAI9&5?<&%N96PN
M<&YG````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<T-0`Q,#4Q-30S
M,S<W,@`P,C,U-3``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````
MP%!,5$4```!24E)34U-555565E975U=86%A965E:6EI;6UM<7%Q=75UX<I!Y
M=)%Z=)%Z=9.`?72(?Z.LJ;W%P=+*QM;/S\_0T-#2TM+3T]/4U-35U=76UM;7
MU]?8V-C9V=G:VMK;V]O<W-S=W=W>WM[@X.#AX>'BXN+CX^/DY.3EY>7FYN;G
MY^?HZ.CIZ>GJZNKKZ^OL[.SM[>WN[N[O[^_P[_/P\/#Q\?'R\O+S\_/T\_;T
M]/3V]O;W]OCW]_?___\```!D5/NN`````7123E,`0.;89@````%B2T=$`(@%
M'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#`@2'"R.,G?7````
MGDE$051XVD7.VQ:!0!2`X4@'E91!H2)%"A51%.WW?RO39,W\E]]:^\!Q)(/&
M_6'VC\%$US5=FU)H%TO+MNQ5#P!&.QCB-@X!^`#`VG$]U]MV`&^$$/`\/]KY
M`09XH#D&?Q^$07CHP.P"01`E,3J1$0+'*$[BY-PO-?%229;'\C5E9R]IEF?Y
MC3VF**IZ+TH&Q;.LRJIF4+WJIFZ^%&@_8`<6&_+N'GH`````245.1*Y"8((`
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]H;W)D92UP;W=E<C$N<&YG````````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4W-#8`,3`U,34T,S,W-S(`,#(T,#`R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(```!4````'P@"````]I9].0````EP2%ES```N(P``
M+B,!>*4_=@``"YA)1$%4>-KE66M44U<6/O>5Q\WC$A(>255>"LACEA2*H6BF
MCE81Y:$H5!$(*A4[%BR5KK%HM3'26@14RJ`0G=7'N#IUA&I%C1U!EU21ZEA'
ML%AMA4$0%"08("&O.S^.<XDA/F:Y9M:T[I4?-_M\9Y_SG;W//OO<"\!S+`@`
M@*;IYY$Y@J!/!.W9L\?;V]O%Q44JE1J-QE\3_R>3KSVQGRWJ?OMC%Y/9M&;-
M&H?6AH:&BHJ*_S=6Y>7ES/-CIO=D\H81G==D3!8P/&W."UJMUK[IL\\^6[`P
M+C]_W<R9,WMZ>IYQQE>N7+ERY0H37(V-C5`)`(#&KUV[9C0:C48C5+:UM75T
M=+2UM<&F@8$!V/'BQ8LG3IQ@S!X_?OSBQ8N,J8&!`=@%`(`_<4XFLY'$`0`@
M;A5]ZLC]DI*2O+P\`(!*I2K9L>W55")LFEB]_.R&#1NJJJJ>A?R&#1MD,EE[
M>WMU=75&1@9%4:6EI1X>'J&AH8</'RXH*%"KU7OW[EVU:A5%411%`0`Z.CKB
MX^/;V]MOW+BAT^D^^."#;=NVD20Y/#S,F-7I=-#Y)$F&AH:VM+2$AX=[>WL[
M\7QN;FY#0X.]QF(UXP0``*!D;]`4J4JEFCIU:DQ,3.G.#Q>N8<6DLS@\P.5P
M%B]>_.SA6E%1(10*O__^^Z&AH<K*RJ&AH8R,C)J:&AZ/IU*I)D^>7%=79S*9
M*(IBL]D`@.3DY,S,S$N7+E$4Y>GIV=_?K]/I*BLK29)D;+JXN&@TFIZ>GJRL
M+*U6V]'1D9:6YB3L$Y)?WKNO,B$A(20D1*U6&XW&M6O77KO2+99B``":MJ:_
M;XQ;(<"$MWYL.ZM\CQT=1P``CNX%$HG[[-FSGYU\:FHJ`$`NE\MDLD6+%LED
MLO#P<)(D\_/SV6QV>GIZ;&PLB\6Z<^=.='0TTTLNEW=U=1$$H5`HQ&)Q2DJ*
MO>?U>GU*2DIP<'!H:"@`(#@XV,E1MUOS4<&&@K?*A)C5M7:?^8>+]PD6AA"#
M\Y:S(^>PL$?L#\L(4;!P./OUWZO5ZF=DGI"0<.C0H?]>%FQL;"PM+=VV;1N,
M^8>..JFG'\G'6R^8W/T&,K<.;ZWF+UB#Y.XDH^:-,K>8'2U>KN/8+(A3YCP>
MC\5BD23IL(\>):M7KW[&?`E'Y//Y,+>-G8]*I8+,'1->PORDNW>[UA>\S1.B
MD;/9!&F,F`T`P```QD'BJ`9<_X=QQ&`EA;1_.)CY&HLG1```WJ%6FK:N7;MV
MQXX=#H.-C(Q8K5:KU3HX./@TLX^)B7D6\B:3"8YHL]E,)M-8``Q[>WDHFE=F
MOME^Z_J>BMU\%R0HD@65MW]PW9[;Y2J2*!2O3IPX\:>??CI[YG33B:[7MY(3
M`G#QN.&DU9*JG57U]?5L-IO+Y8I$HKESYZY:M0I!$!A=!$'\#\YV#,/@B"B*
M/F47)^7M_$7A-]J:WRZG4!18!]W?67`K,C+2_N0$`,3.B[W47/<'#9_O@B((
M5K<?O=-A,8T`DY'N;C=;C<+V]G:"("P6"X[CS<W-7EY>0T-#8K'X4?,P&HU/
M!,"3',=Q!UA?7Q^/QQL9&9%()!:+A2"(<^?.A8>'VP/8;#:?SW<H;YWD,1MZ
M?_PD#$4!@F"?;T5$(I$#<P#`T=JC@<$33G[9G_`ZEZ:M,Y981T?JXJK3^IF_
M-$W'Q<7U]?59K5:*HJ*BHK[XX@M[4[MV[:JJJNKJZK)8+!1%39TZ]<"!`_:`
MLK(RC49SZ]8MB\4"`&"SV6?.G`D("```+%FRY.S9LP,#`QB&2222L9>49<N6
M-30TZ'0Z%$6E4FEJ:NJ[[[[[$(*VDY*2$JD7-W.C0-/D]NF%0$]/SQ4K5M#.
MY(TWW@AXD:QL=-,T/?B5U;FEYKE/\*,\/#QHFL9QYR>$GY]?=W<W-+)TZ=*Q
MF\+'QZ>SLQ,"E$JE`P##L):6%KU>/W'B1*?V"8)H:6DQ&`QP@1[:Y#B>F)@(
M+8^2-YO-65E9$P.D,B_N_.6"'=^(-4UNGS>%2222XN)BI^1W[][MY4]6-$@T
M36YE)SUB7O.4N`O'CQ^_;-FRWM[>L>3AAH02$1%!TW1149$]QAXP9<H4FJ9W
M[=KE`$`0A,/AZ/5ZN5SNM",DK]/I%`J%4P"*HALW;H3D'Y@."/6T(4.1,414
M+"D0H?^.?P..XZVMK4X7^.K5JQP>P'`$`/#W$]RS1^_EYN:J5*JQ2(%`$!<7
M)Y5*:VIJ?O[Y9P#`Y<N7Z^OK*RLK823S>+SY\^>/'S_^T*%#UZ]?!P`T-S>?
M/'ERSYX]$$"29&QL+*Q/A$+AZ=.G8;D.`/#U]5VP8,'MV[>__OIKO5X/J597
M5S<U-3%QE)R<W-/34U-3,S`P8+/9/OGDD]%YTC3M,0$O/.C*!##\[?M.^O(K
MP;Z^ODX]'Q3J':OD0V3TJR]$1D8Z`*#3$`3)R\MCE"*1"`Z:E)0$ZW,$0;*S
MLQF`JZLK!,3'QT,P@B!965GVEM/3TR&&HBBSV0R5^?GY,,]S.)SDY&1FW2]<
MN``Q.3DY#`!Z_H&375VI3]663[?0?]E.?_5'NO&8"0!@HRUI!4AO;V]<7)R#
M,Y.2DOKZ;\],80,`:!II_]'`X_&<7QM1-"$A@?G+<+MW[Q[T*HJBS%P!`.[N
M[DR*9@`+%RYT2._P02*1,/M"J51";@B",#>\X>'AZ=.G"X5"DB2KJJH@9VAV
M-.RS,]\[<N2(_J[^OM%H,IF^K;V!L^B(F6R"ZLG=+MNY[E1`0,"L6;."@H):
M6UM/UFE[=?_,4G,I,1R,7IS#K=IT?O/FS9LW;W9Z2MDGU[$`L]G\^`/9X26*
MPR9GBIRQ`*O5:C`8')#,2?F`?$Y.3DY.SNC=;EUFM6:_]V1<(L.\IO2I#@@/
M[QXX]K?]7]5:>4+@]R*R<BF?DHS6$L'338MSJ.W%VWU\?#(R,O[3^L0^GSLE
MYB!.5Y#%8C'/5JN5B3L$01@\@B`BD6C+EBV/N\_OW/ZGKPY_>?.J12+#``!\
MD7GI>D#;"+,9)XC1"\']NZRVUI'`EP"+@T0G6O3W!'EY;[FZNH[=)DX+,@S#
M```VFZV^OG[&C!E0W]__H$;@<KF/ZLML,2:\`0!:K=9FLT'"`H&`0187%[-8
M+)O-9K/9.!Q.4E(2A\-YW)N<CW:N0W%+2!3KH6!#`8O]@#EM0[^KY:O3!_]<
M:%6GC53OLMWMM$7&8`:CX=JU:T_C;:%0Z.;F!MU87EY>6%AX_/CQJ*@H^-(&
MP[#ITZ<S#G20^/AXN'!]?7T1$1&UM;5%146%A860O$@D2DM+@[E@<'"PLK+2
MQ\=GSIPY<^?.34E)89@[*7*@1,V2Q:21FB8W39/[.Z6_F13B,G.1..M]R<>G
M)#"]I^4&\7@\I5+9V]N[?OWZP,!`-T^*+^0J%`J';(]AF%:K992^OKYPT.3D
MY$V;-C%!CJ*H_9'NY^?7V]L+G8]A6$U-C<,,_?W][8/(OIY?N7(E3=-!04'V
M`((@"((("PMC+#@G_^WY$]Z![*U_==WWG71Y7AB/QYLV;5I86)C83;`@^\'9
M]DJL7TA(B'TOK5:K5"H-!@.C@<Y!4?38L6.,TL?'!PXZ;]X\FJ85"L7832Z1
M2,Z<.=/=W0VW,8JB!P\>=)CD^?/G/3P\QKZ-ELOE$'#ITB5/3T\'@+^__Q/(
MO_F6DA)C'U9[)BX-Y_%XN;FY4%]<7"SS9I?5231-;B__SM=^%9T*E\O%<9S+
MY9X^?9I1!@8&XCB.XWA24A+49&=GRV0R#H=#$`1%47*YO*6EA:;IUM96@4"`
MXSB'P[%?/D9NWKP9'1TM$HD(@N!P.#*9S*$2[^SL5"@4$``'A87CX\AW=G;.
MF"7G"TB*HDI*2NR;?/S%J>_P-4UN+TWS9=;X%RK.L[U,)JO[YEQ14=&D29,2
M$Q/MFWX;'7OJ\(%0.='5K@^8Y/UK^'#Q]*ME,!BD4BE%4>/&C2LJ*OJE>_ZY
M_E;W/'^D!?\"I^_A#YORDM(`````245.1*Y"8((`````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+VAO<F1E+7!O=V5R,BYP;F<`````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P-#(U-0`Q,#4Q-30S,S<W,@`P,C,W-S4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`%0````?"`(```#VEGTY````"7!(67,``"XC```N(P%XI3]V```(7TE$051X
MVNU8>TQ4V1G_[F.&X<+,=89!D`H,(AC'MQ!D-AF-9%L%Y:$80$&7UIK`FMA*
M:DJZTABMV$@0974;<<QJ#$F3)N)C3305$1\M)3-A!5$>72%=C<,R#.`,\[IS
MS_2/@[?CG0'%I!L:^N7^<>^YO^\[]W>^Q_W.`9C#0@"`S^>;B\P)@IS+GB<!
M8,6*%7.7?%]?W[5KU^8H>8_'4UM;.T?)`T!G9^?@X."'JSUX\*"WMW>JMV%A
M85*IE&&81X\>_0@<NKJZ\(SAX>%=75TS(Q^FD+QY\Z:RLO(#=>KJZK*RLG0Z
MW>'#AX,"W&XWQW%NM]MNM_\(Y#T>#Y[1Y7)Y/)Z9*7]:,`\`U&JUS6;SO4\J
M*BID,MGDRI%D2DK*P,"`"$/3-`!0%'7W[EW??U\Z.CKPC!*)Q&@T?J#6)/FC
M?U;2-`D`I:6ETRMLV;*%HB@`B$\.2]F@P.I*I;*VMC:0/$W3/3T]3J?38K%,
M8_-#`&:SV6PV!\(L%HO3Z1P;&YN*O,5BF<JCD^0-[9&K/E$`P,*%"Z?Y")U.
MA_%+4^3US6I#>^0O?J]DPB4`()/)#`9#H.>3DI)4*A7+LG%Q<86%A2*#9\Z<
M6;Y\N4JE4B@4L;&Q.W;L$`'JZ^M7KER)`0J%(C(RLJ>G![\J*BJ*BXMC65:E
M4B4G)V.7^),O+BZ.CX]G65:I5&JUVN/'CT])_N`9%0[CDR=/!M*VV6Q:K1:#
M=9O9/SU2&]HC\96S5P$`H:&AK:VM(O*!DIB8:#:;,6;7KET2B40$2$A(>/7J
M%0:4EI:*`!1%=7=WVVRVQ8L7![4OD4BZN[N=3N>2)4M$KVB:SLO+"TZ^X>^1
M"Q>%`8!6JQ4Q[^GIB8^/Q_W@CL]5`FU#>V1#6V1L4B@`K%Z].C#L_1M)X3XU
M-=7G\]74U/AC_`'85'U]O0A`$(1,)K/9;.GIZ4$5,?FQL;'UZ]<'!9`D6555
MY4]^<@*2@I^62+X^"L^?/U<H%"S+QL3$;-BP8<V:-0</'AP:&J)I<L_OV$^V
M4OZ3]7_+?]_O)$FRL+`PJ"OD<GEV=O:"!0N:FII>O'@!`$^>/&EI:6EH:/!Z
MO?BGN'7KUMC8V.O7K_?W]P/`TZ=/FYN;SY\_CP$,PV1E92U;M@P`%`I%:VNK
MR63"QA<M6K1MV[;7KU_?O'G39K-AJE>O7FUO;Q?BJ*"@8&AHJ*FI:7Q\'"%T
M^?+EHT>/OO.)V(U?/53_)"%4Y#&<2R&A]*]/*_U]CB_=IGD`$!T=';3:$P11
M45$A#"J52FPV/S^?95D,*"LK$P`JE0H#<G)R,)@@B'W[]OE;WK-G#\:P+,MQ
M'!X\=.@029*X]!04%`CK;C0:,>;`@0,"((CG`4`:0OS6$#8V'#KZ@^]E/_09
M47^7PV'G%$KIK^K"X[64R*OC%O3MPPD`R,C("-Y"D&1N;J[PJ%*I1D='`<!J
MM6*ODB0I?"L`S)\_WVJU`L#(R(@`V+Y]N[_-D9$1?*-6JX6\*"TMK:NK0P@1
M!#$^/HX''0Z'7J\7%#%;;/8_A<#_@9$3C)R*603+TF'3;G#8),__P<<L)A=H
M@FS^C']%3@?'LNRI4Z>FZB!<+I=H>I%P'#=]#^)O(3#)A28G$,#SO-/I%"$C
M(B*F)"\21DZD?!H<@!`\O.'!.\*HJ*B/;L[\ZWE08B()NH)2J52XYWE>B#N"
M(`0\01!*I?+8L6,?2GX:^><3_N5W$S1-EY65S527HBA<2A!"+2TM&S=NQ.,X
M*?"/<YI=PV32O0UO`+ASYPY""!.6R^4"LK:V5BJ5(H000C*9+#\_7^A-W]G8
MS%0>74<`$!L;6UQ</%-=W*Y@-YX[=ZZZNOKV[=LZG6YH:`@OC5ZO%QPHDIR<
M'+QP(R,CJ:FIMV[=JJFIJ:ZNQN252N7NW;MQ+;#;[0T-#0D)"9LV;<K,S"PL
M+!0Q_TCR8\/(U&('@+2TM(]0IVFZI*0$![G5:JVJJLK.SFYK:\,AJM%H]N_?
M/]7)6G%Q<6)B(EXXD\F4FYM;65EIL5CPV\V;-^?EY24G)V.`T6C,R,C0:#0:
MC2;HIY(`,/R*[S-YG_[-VVOR#GW/>SWO.=(C*0B3TP#P^/%C44'RSTR?SX<=
M(DK7B8F)(T>.Z/5ZS!\A)!1AM5I]Z=(EK]>+/2^R@.7*E2M"E>%Y'@,(@DA/
M3[]PX0(`-#8V1D='"P".XSB.FYB8".(&`/@B?Q0AW]LZ0<CG2;1IC#Z/3%I#
M!:U!"A59]D>FIHQ[^?)E5E;6O7OW`BL0QW$2B81A&&$P)"0$!R0.O];6UO+R
M\ALW;EBM5I[G&899NG3IQ8L7M5IM;V]O2$@(0HBF:7\+6-+2TMK:VDI*2IX]
M>V:WVRF*4JE4F9F9!H-!Z!%-)M/.G3N[NKKL=CM>]$`[DZ>W%$7)9#*:IA%"
M#H=#R+?%R\,+*R0)RX,7Q3M7O'_Y<E0JE9X^?;J\O/Q_\?26P-5RU:I5,IG,
MZ_5V=G8V-C;>OW]_<'"0YWF*)O,_5_RL1!*HS'OA^&>.?_5/Q,3$[-V[EV&8
MJ*@HC4:C5JOE<GEH:"C+LH$U9M:1#UI=ZNOK3YPX83:;`6#KS^?EE0?A_^0!
M]^5OQMXY"2=)DB1IFJ9I6O)6(B(BFIN;10W&K":/9=VZ=7B?\-D72GTN'>C\
MKX^XONODO5[>[4(>-X^0SX?$!DF2/'OV[&Q+C?>3!X"U:]=V='3(&,GAR_+H
M>"I(M\<#S_L0#[P7W"YPVI#;"6ZGS^T`A]W7])7+^H,K-S=WMIV.$P3Q_@ZO
MI:4E*2EI>'CXFPOHEW^@@O[Y2(IXVQ&#,O(=3)^1>/B-:V!@8/8>74\C+,L6
M%14!@.F^;?@5/],)8I=,-C/P?YE5\F]R:[N-PK3LW0````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+VAO<F1E+7!O=V5R,RYP;F<`````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P-C0T-0`Q,#4Q-30S,S<W,P`P,C0P,#(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```%0````?"`(```#VEGTY````"7!(67,``"XC```N(P%X
MI3]V```,UTE$051XVN59:W1459;>Y]QS'_6N/$@(":0(>9@4(71"8"T8!.Q>
M+;A:`FTW]`RN'O[H4G%TK6$<$,?II:ZA>T2AP<A#A08%%C,@/L(`&:`U@@^0
M3B9(`GF8%R0AKZI4U:VZM^YS?IQ0E#%`1>E??7YDU3W9YYS[[7WVWM_>%^!O
M>"``>/SQQQUNZYR?%;F2;3]^QW!0"OHCX9`LA:.&;@``RQ&K7;"[+>X4.V&9
M1#;I[_9?.',E*JL8X]+2TL<>>^S>(T>(T%^AX4CM9\WEB^ZSNRP_;"]=,_I[
M_#WM@[Z!D"1&544;=9)@Y>PN2WI6<L:49.?=M)R6F518FEW_9:MA&)<O7SY_
M_OR<.7/N.7X&`!8N7*@HBA2.AD-R>J8[0>/$C][.H;IS+6V-O;[^8%12J<$I
M9H00_:VI>B0D]W?[>SN'(N&H*]G&<N0.>[I2[)*H!GUA7=?[^OK*R\LYCKN'
MR%]ZZ24$`#4U->^__[XLRP"0G9\^<U[>F/@10@AAC#!]-$W3,'594AHO=G0V
MW]`U@\KP/)^4E)2<G.QRN2P6BZ[KHB@.#P\/#0T%@T%=U^ERA]OJ+9^:.37U
M#N\7&I:^/GU5BB@8XXJ*BH4+%][;:X\HC`\^^.#,F3.JJ@)`7G'6]#DY&*-1
MH@QF.<(3AD4(F::I&6IP./AUS97>KD'3-!%"=KL]+R]O^?+E:6EI8YY74U/S
MV6>?]?7UT8,(RWAG>7*\F:/.NN63F.UM'^ZXVH\`.1P.A\,AR[*F:3S/"X(@
M"`++LAS'"8+`<1PAA&590HC=;L_)R1D'>``X<.#`YY]_3BTS?79.P<S)\:(8
M,P)K=5B3+)P-8VP81C`8.'?F8EM+EZ(HA)#\_/S5JU<[G<Z[GOK))Y^</GUZ
M<'"0/DZ?/;5@YI0Q'!(3@;,*C/U&>TA3#%55?3Y?=W>WS^=3596^,W4KAF$0
M0AAC^I?G^25+EMQ___V)!CP`6+5J52`0:&AHT#3M2FT'RY.<PHQ;X!$F#&OA
M;#^?ORP0"-KMMC?>W*I(!B&$$+)@P8**BHH$[]NB18O*RLJV;]_>U=5E&$93
MW36K79B<F_9]%R,,AQ'[Y!-K@H&@R^7Z_1]^;[5:`X&`IMV*IJ9ITD>J#@`(
MA\.7+U^^*W@`^$[(>>JIIUYYY97KUZ_KFN'K"\2#!P"$,(-)?]^`)$E21))$
M11`$M]N]>/'BV;-GC\O?G$[G^O7KMVW;UM;69IIF4]WUU/0DN\MBFC1P8(00
M80AA"&.2P8%!29)T79N:/RDE2YCL2Y:CLJ[JFJIKBJYJFJIH2E355%V*1`-#
M(@#X?+Y$7F-TO*5:Q!AEYT\<DQ:P+)$D((0(@I"2DK)@P8*2DI(?%G*>?/+)
M@P</=G=W`\"--G'ZG!3=T!$`Q@S&#&%8GK5BG8R<R+(VAX5W)3M2>#`!88P`
M`8!NZ*JF:JJBJFHH&#YWXINHI(BB.&[P7WWUU?#P,`"X4^W):6-YKWGK6J:D
MI!06%GH\GCLE?UU75540A#'_R[+L\N7+SYX]&PZ'3=,`67"Z.80P85B"6<,P
M>4[@&`%C?#,*,(2U$H9E,"&8U74=(8RPJ6I*5)5D)<);.+O3HLBJ+,L-#0U>
MKW<<X)N;FQ5%`8#4##=#\)@+S)L7I+*RLJ6E19(DC\>S;-FR)YYX8I0>=^W:
M55=7)TE2=G9V147%FC5KX@7.GS__UEMOU=;6BJ*($'*Y7)NW;G+94C'"_WOB
MS\>/57_;VF81!._T(D51*14E#"<('"`X4_WIL8]/MC9_R_%<:5G)+U=43,OW
M$"8@2I"2[O;U!S5-:VMK&Q_X_OY^PS``P)EDO>T*$P!`EN7#AP_3B::FINKJ
MZE.G3NW?O]]BL0#`[MV[UZY=&P@$8CH]=>I4=77UH4.'K%8K`+SWWGO///,,
MO65T"(+`$0MC<B^L_]W^?0=C\Q?.7XS]YCF>(\*_K?_=GG?VQ2;_\G7M?QT\
MLG'3RP_^8I%N:$ZG'6.LZWHB;O\=\U*>`P`VA^4VU]BX=?5'4N#(#D>/'MVP
M80,UZ;///AM#'A.HJJIZ[KGG`*"VMG;-FC4QY#1?.)U.J\6RH_*=&/+8PMBP
M6*Q[WMX70QX3"`9#__+L\Y?^TN3OD8;[PQACTS3]?O\XP'_ZZ:?TA5B.$:S<
M;0B\?C.AP+1IT_;LV5-55?7((X_0F3U[]O3V]F[;MBT<#@.`Q^/9O7OWL6/'
M5JY<207>???=GIZ>'3MVA$(A`)@R9<K.G3M/GCQYY,B1+5NV]/</[-KY%I7\
M^U4K/SAV>._^=^XK+!C1$<MV=_=LK]Q)'W_S#RO^I_JC0X?WE\R<0<VVJW)W
M8%".2CI-^#S/)Q3P#ATZU-C8Z/?[;Q(O<CN'IQR6FFO+EBT//_PP`#STT$,E
M)267+ET*!H/'CQ^OKZ\'`(9A7GOM-:J7)4N6M+2T4/?^\,,/+UZ\2.VV:=.F
M%2M64'>[<.%"75V=W^<'@)^4SMSTQ_]0=04CG)R:_*NE*Q5%Y3BVONZ;WIX;
M`%#D+=SXGZ]8K59%UM:M6_>/OUVMJFI]?3TAQ&JU9F5E96=G)YKG:VIJJ*L#
M`&]ALZ9-X'AV3&E-&V'F',>5E97%YG-S<R]=N@0`?7U]U.P\S\?7845%1;6U
MM0#0V]M+S<[S?(P=$$)$41P:&J*/A44%BB9'HB*#F;R"'$$0%$7%"`<"`<ID
M.CNZ%LS[F:'KI@D((<I*15'T>#PS9LR8-&E2(F8?`6\8!D)@M0N9.1.FWI=Q
MAZK6-&XY/,T+\>Q@=!D7Q\-B]4R\0&P'A-!HTJ9KJA8U,,'Z6"V#<)BJ.'[,
MF#%CO(R#`,"$2>Z,*2F3/*DVIW`7/AQ7@<3HY&@%W9PGY%8J81CF#JLT3=-U
M/7;[,,8,9@C#8LQ@1*BR#-.4PM$80:`;TMTPQEZOM[*R<KPLBP#`O,7%MW/R
MT<4&86*V&A,&(81F.T51FIJ:LK*RZ'QG9^=()>MP?'\AK57H0@#H:._D60NE
M]UUMW9(LTSS'<R.V\7@\>_?NM=OM+,L:AD$(R<W-C>DW\8$!($'D`$#(K6(^
M=I/CA]OM+BXNIL9<NW;MN7/GNKJZUJU;]\477P"`Q6*9-V\>#:OQH[.S4U&4
MW-Q<B]4"`%]^<7[KZ]M#`;FC]?J&?_UW):H`0'Y!7EE9F</A`("VMK:C1X^F
MIZ=[/)Z<G)S\_/P?@'QTGK\[>):A#HL0BO?Y>,L__?33-`/7U]<_\,`#145%
MK[[Z*M74TJ5+R\O+OP^^O;T]$HDXG8[EOUQ&8]"F/VR>-VOA@S_]Q>?GOJ0R
MO_[UKQP.!ZT==5U__?77<W)R)DZ<.''BQ%'D\J\%'F-,(Y.JJK'@'!_/`H'`
M_/GS7WCA!6H*555CD6G6K%E;MVXU#(-J+>;DHBAV='2$0B$Q$OKG=?^T<-%(
MBA)%D=H<8[SAQ76%186#@X.K5Z^>/W\^%8A$(L%@,!@,)EC#W;VJN\,P34,W
MM-345+]_V&:S#0P,1"(12E=M-IO-9HL%N9=??MGK]>[:M:NAH4&6Y<S,S,6+
M%[_XXHM)24G#P\-NMUN69:O52H4_^N@C410YCI-4T>)@=OSICP?V_O?QJI/M
M[9T"SY?,+%ZU^C=EY3^I__IJ*"!F9&0</WY\X\:-5555UZY=HY:@OO`#6]?5
M%P\D8/.13@['6&YT^GT#`;_?GY:6MG3ITA_32//Y?)LW;QX:&F(8YN\>+/'D
M3K;P=HX(A"$(80#3,`Q55[J[;EP\>UF2Y(*"@D<???0>MZX3,;NB14,1/V%$
M!8>_;6L50^'6UE:WVYT(E[I=P;MOWSZ?SV>:9DJZ,SG#+D5%58LR#(L1CK78
M=$-KOM+:U]=/NR#WL(=)`*#UF^N4TA*6(2S#$,P0AA?8>(9OFJ9NJ+*J8PVS
M=A!<<*W+K^OZQQ]_/(K,)3[>?OOMUM96PS`XGDR?XP%D:H:J&QK2HC$B9)IF
MT!]N;[T>C489AKGWX.N__!9CA##"&&,&8XPP@ZPV8?9/"T?A-TW=`!T`IGHG
M]O?Z!GL#HB@>.7)$U_6Y<^>.Z^`WWGCCRI4KAF&8IGE?:;8KQ3YR!)A@&M^Y
MGPP(%E8,1'1=/W'B1&9F9EY>WCW[:%%65F::8!JFH1NZIFNJKD:UB"C;',+8
M_1P`0IBD"<Z!'G]44J/1Z-6K5WMZ>KQ>;SRKN]UH;&Q\\\TWV]O;:;0OF#FY
MH&1*S-1C-'PXDC3!,=`S')5569:;FYM+2TMCC.C'?K38L6.'HBBJJFJ:IBA*
M-!H=&AHR#,.99)VW9(;5?MLB(>B/_-^YEH'>81H_7"Y7<7'QW+ESQVR;!X/!
MAH:&LV?/=G=WT\8!0JBH+#M_YI0Q^_:C0V-_\*O3C9(8!8",C(SGGW\^P>KE
M#@'O;_DC+?P_CT4\9+HONJ\`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]H;W)D92YP;F<`````````````````````
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#$Q-3(`,3`U,34T,S,W-S,`,#(R-34S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````0````$`@&````'_/_80````9B2T=$`/\`_P#_H+VG
MDP````EP2%ES```N(P``+B,!>*4_=@````=T24U%!]0,%0\W.KH;@(X```'W
M241!5!C3I9--:!-!&(:?W6[^2%?1@Q4:ZD'S(\%#`D(LFD2PO?A[\%`"-E9:
MVHK@32@2;X+:0Q$)B#>AH(>`+806H6!+<C`4%&V%6*@0M?%0%2N&9)/-CH=`
M0V13D+ZWF6_FX>-[9B1`L(LH`"<B;D:';A,*A?[KLL_G0P88O/N+9ZDGIH>*
MQ2*:IK6%R``'7#*V@^\H%`HMQ5PN1V+R$C<3?2PN+;8'5"O0>\[&H^3#[4(Z
MG69Z_CIC#^Q<&*\S-S?;?@8U3=#5T\$^?X8;$V>@TDWGH56N3#BQV&!Y02,^
M.+P#H-H0T1]SH-<T2K_7<>YQ8AB"K4THKO3@'_&W!]@<TO:&U2XARQ)Z36"U
M2ZSF-"*ARSMK7'I1X>N:C!#@<AL$3UMQ[I6IUP7[NV3>9EX3(V8*D`"13"8)
MA\,`9+-9GL].T3_R'=<1!<4"\T_+2,7S>#Q'4545554)!H,$`H$&()_/M[:E
M*%P;/\M`X@>.3HF:!AOK.N62H%H1E+8,-M_W,I-ZV=#X;W1=)SYPB^4%#8M-
MHD.!P\<L!")63EVT<[S/SI=O'YKOP"S1:)2-CPK":*R-NN#SFL[T_3_,W',S
M>O5.<XBFPY$DA&B:>94J\W/E)$/Q,;Q>;ZL%LV0R&;H]=3H4"]6*X-,;)X\G
MI\PM[.8[_P4+A:K^#!8TW`````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;6%G92\`````````````````
M````````````````````````````````````````````````````,#`P,#<U
M-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-S$`,#(R
M,#(U`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VEM
M86=E+V%R<F]W+61O=VXN9VEF````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#(P
M-P`Q,#4Q-30S,S<W,0`P,C0V,3(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````1TE&.#EA$``0`+,``.+BXLS,S+R\O*ZNKJ.C
MHWQ\?%=75T-#0P```/___P```````````````````````"'Y!`$'``D`+```
M```0`!````0T,,E)J[TXU\.[YQL0C"2!6`@AK&MAG-81L$,!HZI0O]FANC>,
MS*:1I'C%Q"&H03";R:@T`@`[````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;6%G92]A<G)O=RUU
M<"YG:68`````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R,3(`,3`U,34T,S,W
M-S$`,#(T,C8S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$=)1C@Y81``$`"S``#BXN+3T].\O+RNKJZCHZ.>GIY[>WM75U=+
M2TL```#___\````````````````````A^00!!P`*`"P`````$``0```$-U#)
M2:N].&N5]DR()X%B<A#=EAA!J)F&@&;P(!3SM=J"T.J'6*^7HR0(@:02X/H@
MGM!H2D2M1```.P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O:6UA9V4O8W)O<"YP;F<`````````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,C<P`#$P-3$U-#,S-S<Q`#`R,S0W-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$````!`(!````+7Z-^H````"8DM'1```JHTC,@``
M``EP2%ES````2````$@`1LEK/@```%Q)1$%4*,]]T;D5P"`,!-&1NG,S%$,S
M%$,Q<@(^T*'TS]M$,LEN6*,CLV``K;G'P<OAPI<OT9K=PLE'X/D71/P)8GZ"
MC%<PK&$8.`;=#$)W##J,@D'6<L+DW]QW`SGO+\TU5-#"`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+VEM86=E+V9L:7`N<&YG````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#0R-P`Q,#4Q-30S,S<W,0`P,C,T-S``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!`````0"`,````H+0]3````/U!,5$4PIKHJ*BJ'G[6(H+:.H[>/J+^2
MJ;^6L,B=N-*>N-*CO-3`TN'"T^/#T^/$U.3'UN7)U^7)V.72WNK4X.L```"5
MTW#%`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q(```L2
M`=+=?OP````'=$E-10?4#!03"17]CYO;````44E$051XVH6/2PZ`,`A$6Q6=
MJO4[]S^KK&S!-+(@>2\,A!`:1<\['4-H&;6)1YJ!-+Z&Y(9.>Y7)&,Q6)SZ1
M>-TK9#G+#"=[5HU85M/SY[E2#S#C!!'3S+W"`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I
M;6%G92]G<F%Y<V-A;&4N<&YG````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(Q
M-S``,3`U,34T,S,W-S$`,#(T-3`U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````0````$`@#
M````*"T/4P````1G04U!``"QCGS[49,````@8TA230``>B4``("#``#Y_P``
M@.D``'4P``#J8```.I@``!=ODE_%1@```P!03%1%WM[>W=W=W-S<V]O;T='1
MQ,3$P\/#P,#`O;V]N;FYLK*RL+"PJZNKJJJJJ:FIIZ>GHZ.CHJ*BGY^?GIZ>
MG)R<FIJ:F9F9F)B8EI:6E965DY.3D)"0CX^/C(R,BXN+BHJ*B8F)B(B(AH:&
M>7EY>'AX<W-S<G)R<7%Q;V]O8&!@7U]?6EI:5U=75E964E)245%12$A(1T='
M.#@X(B(B(2$A!04%!`0$`P,#````____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````^2=@R0```#IT4DY3
M____________________________________________________________
M________________`#?`_PH````)<$A9<P``"Q,```L3`0":G!@```"<241!
M5"C/7<_I#H(P$`3@BJAX4$4.6ZD*>*#6`T^&]W\Q$902YL\F7S:[&9(U0LJ!
M/'6`</D2"B"FELT"*/`F0\L3-9C9^89?`;!@+IM'?P#U7BM?1.4CDL'4M?']
MC>=Q+U%`3R/M#DU#'NRN^$)?;^F&F;(!7\L";*-KC)Q'R,+XA.*H0ZF#9+N)
M#PE^;_/[N,CS#54YU8\TZW\`8@\M2[$>*6X`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+VEM86=E+VUI<G)O<BYP;F<`````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0Q-``Q,#4Q-30S,S<W,0`P,C0P-#0`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!`````0"`,````H+0]3````-E!,5$4````&!PDJ
M*BIUBIUVBY]ZC)IZCZ9\DJ:(H+:/J+^1J+Z=N-*ZQM/!TN+"TN/$U.3*V>4`
M``!O9!%'`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q(`
M``L2`=+=?OP````'=$E-10?4#!03"2\[@T)I````3TE$051XVJV-VPZ`(`Q#
M)Z(R*DK__V?E(M-GXTGVT).L%?F(HPC=DWE6`5H^P`*&*1DIYX3;<(>Q=!,`
MC5$!/WZ"MHYYLM:MKJQ\[;+?3UPUL@/FU:',(0````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]I;6%G92]R871I;RYP;F<`````````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`T-C4`,3`U,34T,S,W-S$`,#(S-C4V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````0````$`@#````*"T/4P```%U03%1%````?YBTA)RWA9VWB:"YBJ"Z
MBJ&ZCJ2\CJ2]CZ6]D*:^DZB_DZC`E*G`E:K!F*S"F:W#FJ[#GK'&G['&L<#1
MLL'1LL'2L\+2M,/3M\74M\75N\C7O,G7V>#G````D4G)`P````%T4DY3`$#F
MV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'
MU`P4$PDYSU?W.````%%)1$%4>-IC8$`'<E"`$)`5D9"4$4<2$&5D8F'G1A*0
M8F;EX.%'$I!FX^05$))C@$,Q+CY!861#46U!DD!V"@:)2S7$%E1OH*F00U?!
M@*(7"@&[`0@F[URD"P````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M:6UA9V4O<F5F<F5S:"YG:68`````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,S,Q`#$P-3$U-#,S-S<Q`#`R-#$T-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!'248X.6$0`!``Q```````>)>Q2&9_(C`[
MU=75IKK+<Y.NU=[FCZB^N\O8,TA:F9F9Y.3DHK?)3V^*S,S,@Z"X2VJ$DJO`
M____````````````````````````````````````````````````(?D$`0<`
M$P`L`````!``$```!5;@)(K$:)XC4*(F`0"(RI+`D10-P,P`9#@.@8XG40`&
M@,=L`@@`F$K18IB*/%<IZH3Q.I5JSQ%W,7H\`8XPRWP`*-(S[@'H,,:;=2,6
MY7+*EA,N@%XH(0`[````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VEM86=E+W)E9G)E
M<V@N<&YG````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#4S-``Q,#4Q-30S
M,S<W,0`P,C0Q-S,`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!`````0"`8````?\_]A````
M!F)+1T0`_P#_`/^@O:>3```!$4E$051XVF-@P`ZT&"@$_\DQ1!VJ\7__BGW_
MB36$$<G)5Z_>>\;P[.TGAM?O/S/\^?N/(<[3G(&!@4&<@8'A%2X#6*#TU>8%
M.QCF;3W!<.?.'08&!@:&G]^_PM2P$N7G2:L/_#?VB/K/P,#P7\G`&N8%?:(#
MK6+Z1I@F!AR:4Z'B8LB"3##&Y<N7D<6U&1@8+J(9,!M*OT0WA`$J@.P"7.GB
M_]5[SW"J@QF2BB:NC^PU__PN%`.8D!2^@D;K;#3-%Z[>>\;`P,#PW]@C"F<Z
MP`:D&1@8GER]]XRA:N(2N."3FQ<8SNY8!M?+@L>`WPP,#`R+=YZ&:V1@8(!I
MUB8V>K70HO@_-,F3!+3PQ`Y)AF`%`"\`90%XO=1_`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;6%G92]R;W1A=&4M,3@P+G!N9P``
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U-S``,3`U,34T,S,W-S$`,#(T,S0Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```'Y03%1%````)R<G
M*BHJ,#`P/$%&>H>4@Y&?B)&;CJ*TCZ2VEJ.PE:W%EZ[&J*VRFK+(G;C2J[6_
MG[G1G[G2G[G3H+K3H+O3H;O2HKO3HKS4H[S5I+W5JL'8L<?;P,[:P=+BPM+C
MP]/CQ-3DQ=3DQ];ER-?ERMGES-GFS-GGS-KG````D5HZ=@````%T4DY3`$#F
MV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'
MU`P4$PH&4AR)Q@```'-)1$%4>-J-CMT:0E`01:<D*MI^DE3BH-CO_X(</HZZ
M:MWM]<WL&9$!CHB!3=WD_F8E%)"E!^M+W./+?MG2#<?GS3,U6PI+7,V$&D2%
M:!8L0`9=<N*2\7I_'I$]";;09*D[GZ7.X=G9F4[@]W6LT_29_$\/3G4+DWRH
M$CT`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O:6UA9V4O<F]T871E+3(W,"YP;F<`````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P-#,V`#$P-3$U-#,S-S<Q`#`R-#,T,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$````!`(`P```"@M#U,```!(4$Q410````$!`4)"0DU-38B6HYVX
MTJ2\U*6]U:G!UZ_%VL'#R+/(VK3(W+;*W+?*WKK-W\C,TL?6Y<C7Y,W:Y-?@
MZ=7A[-GC[0````G',V0````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP
M2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,%!,*%=:BR!@```!/241!5'C:
MC8\W$L`P"`3E<,XY[?]_:LVX$+@2W2[,`2%D%Q1`XG(X)RF)ZAH;6;'-;6\%
M1Z<:D\%JQ^,"]BA,?[D?N4CD^3/X.W\<3?Z3+V0Y!"U3&P#@`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+VEM86=E+W)O=&%T92TY,"YP;F<`````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#0V,P`Q,#4Q-30S,S<W,0`P,C0R-C(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!`````0
M"`,````H+0]3````5U!,5$4````H*"@J*BHQ,3&-G*J4H:V1I;B<M]&?M\Z=
MN-*?N=*?N=.BN].BO-2CO-6DO=6GOM2]P\BQQ]O!TN+"T^/#T^/$U.3'UN7(
MU^7)U^7*V.74X.L```#Z@2Z1`````7123E,`0.;89@````%B2T=$`(@%'4@`
M```)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#!03"A<XK*DT````54E$
M051XVHV..1*`,`P#S8VX`@',Y?^_$T*#397MM..13!2!O&BQ;\<Y)4HP,'1E
M9H1KFUQT1^'[6DSQBE',#J-24RE?"^#G[T80,+^$;%M_^3$4RPUY&@7[ZR_,
M@@````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;F9O+G!N9P``
M````````````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P-3,`,3`U,34T
M,S,W-S,`,#(R-#`V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P``
M``1G04U!``#8Z_4<%*H````@8TA230``;9@``'..``#4SP``>P\``'CV``#+
M\@``,HP``"--2!%DL@```P!03%1%````____Z.?HX-_@V-?8EI66W]_@U]?8
MY^CHU]C8E9:6U]C7V-C7T-#/EI:5Z.?GT,_/EI65\/#PZ.CHX.#@V-C8U]?7
ML+"PH*"@EI:6?GY^;6UM;&QL____````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````R[ETLP```!YT4DY3____________
M__________________________\`[!@<7@````EP2%ES```+$@``"Q(!TMU^
M_````&M)1$%4*,]]C\D.@#`(1%&KK;NV+J#M__^FX*&IFOC"Z<U``L"'+,6*
ML"FW`$`>:Q&C$!+Q6?$,QQ@;'M$_&R+^&Z\;QN7.Y&YT@HB%!BII)FJ&HF)1
MZVW3G5J54FNK`<(Q[9'^9!'2UT.X``X8#-0+!Y)G`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+VEN9F]?:6-O;BYP;F<`````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,3`P,0`Q,#4Q-30S,S<W,P`P,C,T,#8`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!`````0"`,````H+0]3````P%!,5$4````,$QH4&R,5&R,<(RLC
M.$TR1EPO2V<P2V<S3VPT3VPU4G`Y5G1$6&P]6GA`6WA*6FU"7GQ&8H!*9H1+
M9H-.:HA5;8=3;XU4;XQ7<Y%;=Y5E=HE?>))@>)%?>YEC?YUG?YIH@Z%LAZ5N
MAZ%WAI9]BIB!EJV`F+.'FZZ6J+V8JKV9K,"<K+VBLL.EM,:FM<BPO<[_____
M______________________________________________________^F=RM[
M````0'123E/_________________________________________________
M__________________________________\`PGNQ1`````%B2T=$/SYC,'4`
M```)<$A9<P```$@```!(`$;):SX```".241!5!C3=8]7#L(P$$2'$II-Z(2$
M$GH)=4Z0^]^*W8TH0F(^++VW8WF-_"<H3LM'8)N=3_LV7J)Z/ZQ7Z2*95`J!
MAS"9Q-%0*<=4YV0<C08UJ,BLK]SOF+@)DQ3NA2:N.B>5O8F+]DGEEHG=1NZ3
MPBZ`/7M<"I/>-5`L5I[/M._JI??JW7'HFP'^?^X[3X8-)<-`E=/[`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+VME>6)O87)D+G!N9P``````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#0P,0`Q,#4Q-30S,S<W,P`P,C,R-#8`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!`````0!`,```#MW>)2````'E!,5$4``````/__``"`
M@("@H*#_P,#<W-S`______\```!KK'_U`````7123E,`0.;89@````%B2T=$
M`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#!03$BN5V$WJ
M````7$E$051XVF-@8."<"0(,0(:ZA(90)8@A5*&A+LD`%I]:T<DP4;"C26F2
MDB:$,3T"*C*C"*H&I'U&&AAX,DQK`0,@PP4$/(",#@\@Z(")N(#4=``!4&H*
M1,02;@X`ZF\Q;W=S=^L`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]L87EO=70N<&YG````````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`T-S(`,3`U,34T,S,W-S,`,#(R-S<S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```0````$`@#````*"T/4P```$Y03%1%````H)Z7M[6PN+:QY,!!Y<%$Q<3`
MZ<MBZ]!R[-%U[M>'U];4[MB+V-?5V=C6VMG7V]K8W-O9WMW;\^.J].6Q].6S
M[.SK[>WL\O+Q````<9PG$P````%T4DY3`$#FV&8````!8DM'1`"(!1U(````
M"7!(67,```L2```+$@'2W7[\````!W1)344'U`P($ATZ8_WSQP```&5)1$%4
M>-IUS>$*@"`,1E'32LV:E:;M_5\TE<&PZ/NWR^`(["<$CL88N^*=<LYG#2;&
M&#0FYS:0%*X2<KE!]1_>MV!#F<8#P.\M+'43SE(I-=3P8<ECECQFR6.6/&;)
M8Y:\?_:]!]0]#R=FNP,R`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;&AA
M;F0N<&YG````````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#$T
M`#$P-3$U-#,S-S<R`#`R,C4S-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````(0````X$`P``
M`%,P:+\````84$Q41?___\#`P+^_OX"`@```_P``@````````%KM>%,````"
M=%).4_\`Y;<P2@````%B2T=$!F%FN'T````)<$A9<P```$@```!(`$;):SX`
M``!_241!5"A37<]!"L4@#`30X`ETX[JDD`L4/('>0/?6PMS_"(U-V__I;"*/
M@1@*GWBR"<V_`$3D]E<BN*N0Z`M007?B9&@)R#E[BN36P4.6V3)AT:Z53`+V
M$$EFB9/)M:P[,*^IE'++A(.W5&N])6*18P-::X_0A!!_\EQA/_S$GR`J).UK
M)L>&`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VQO8VME9"YP;F<`````
M```````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3,P-@`Q,#4Q-30S,S<W
M,P`P,C(W,30`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3```!#E!,
M5$4````$`P(%!`,("`@)"0D+"P<3$0X:$PL6%A8<'!P@'1P>'AXO*2$K*RLM
M+2TN+BXX.#A-34V!6BMR<G*J;RND<39Z>GJL<2ZM<S*@=T2C>TN$A(2D?DZH
M@4RT?CZG@E*G@E.X@#ZJA%6KAUBLAUBZA$*KB%BZAD>\AT:\B$FZB4NOC5ZM
MC62\BDRPC5^]C$ZED7:^C5";EY3&EEW'FV2HHY[*GVBJJJK+I''.I'#-IF[-
MIG;0IG3,IWO0J'3/JWRQL;'/K'O-K(/.K8/4K'G5KG[2LHG5LH38M8R\O+R^
MOK[6NI3`P,#!P,#"PL+:OIK@PI[APIS@Q*#?Q*/AQ*#BQ:'CQJ+2TM+;V]L`
M``![0$@>`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,`
M``L3`0":G!@````'=$E-10?4#!02+`1^#@'Y````C'1%6'1#;VUM96YT`$UE
M;G4M<VEZ960@:6-O;@H]/3T]/3T]/3T]"@HH8RD@,C`P,R!*86MU8B`G:FEM
M;6%C)R!3=&5I;F5R+"`*:'1T<#HO+VII;6UA8RYM=7-I8VAA;&PN8WH*"F-R
M96%T960@=VET:"!T:&4@1TE-4"P*:'1T<#HO+W=W=RYG:6UP+F]R9V>*QT<`
M``"9241!5'C:8V#`#B*!`(G++18>$>$IS`P7D/82X.04=)"&\?G\6$`4OSE,
M%Z\/F,7A"Q-@,^)B961DXC%EA]I@$!0<[._O[VTM!%$2&>IAIB(OKR"E*0X5
M"'/5<[>W=[30$($*A-B8*,G(R$BJPE0$6NJX.3DYVRI*0`4"7*RTE9759#7D
MH`)VQH:&6EKZNNJBD0B?00`V?P,``.(=%XJG_UT`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VQO9VEN+G!N
M9P``````````````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<V,@`Q,#4Q
M-30S,S<W,@`P,C(U-C<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3
M````P%!,5$4A(2'JU,OCQ;K;M*3NWM?Z]_7RY>'2K)D```"-GGS-V<+>YM?:
MXM&;K8FWDX)P?6.TQJ*LP)AC;E>KBGKDZ=UE<5C$GXW#T;6`CW!,5$)88T[F
MZ^#4W<G*U[Z0H7]?:E-37$GI[>1A;5:HO)5\BVY,5$.VPJI>:5/_________
M____________________________________________________________
M__________________________\7Y'27````0'123E/_________________
M____________________________________________________________
M______\`PGNQ1`````%B2T=$/SYC,'4````)<$A9<P```$@```!(`$;):SX`
M``!_241!5"C/;8])$L(P#`0G$:#!`8-,V/?]&?K_KS@X5)D4?9KJ4P^\!XH)
ME`*H:@$*,1B.:NT$,Y6H(HMQ:"93BDC,PCF;6Z*(+@!W)]M@RT31%1Q.MF%M
MF^V.,0(.[@]'L].9%W8=O)K9C4Y^2]G<'T^6Z7PE_G[ANR><?]]F/N/K*`TP
MEY7S`````$E%3D2N0F""```````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]L;V=O=70N<&YG````````````
M````````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`W-#<`,3`U,34T,S,W-S,`,#(R
M-S<T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```,!03%1%````
M#A$,%QT5'24;("D:*C4F,3TL-$$O.4<S0E0]25Q"451/6UM:3V1(4VE,7&!9
M;&QJ>7EW8(%(B```F0``F3DIHA(,L!8*L1L0JC\LL4TVLU,^R#XKWT(>Y&)%
MYW5;C8V+F9F8J*BFN+BVP,"]R<G'T-#-U=72X.#>XN+@````````````````
M````````````````````````````````````````````````````````````
M````````````FL`]P@```"MT4DY3________________________________
M________________________`"/)I]`````!8DM'1`"(!1U(````"7!(67,`
M``!(````2`!&R6L^````B4E$0508TW7/T1*"(!"%X:-&F94FE*65@FA8[_^`
M[9)ITTS_!0S?!0MX_H3W.O6!A^M:/0'M!-;,4,.YGB!@X)H+[AX"AIJZ5;"M
M01AZ.%'G(_(MHH6'`Z4J[`V$8+@6A5(E>(I8CI?2V8\5,8&4$B4&`CT#,/1F
M@]4Z&1\6P6:(DUV:XM_GOGH!SJD54T>8+H``````245.1*Y"8((`````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O;6%P+G!N9P``````````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P-C$Q`#$P-3$U-#,S-S<R`#`R,C(R-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$````!`(`P```"@M#U,```!@4$Q4161D6__\S:BFB-K8M,/!
MHLW+K/_ZO?STJ)R8=*^KBK:RD7AV8_ONCMG0BI"+9_;C?,_'F?/>=/?GG?_3
M-_;/2?K85^2N&N2V.\B6'M2C*=VN-:M]%KZ-'%P_)4]/3P```(J'Y#`````@
M=%).4_________________________________________\`7%P;[0````%B
M2T=$'P4-$+T````)<$A9<P```$@```!(`$;):SX```"6241!5"C/3<_9$H,@
M#`70J[((1:D4ZX(-__^797-:'AC.369($,OA?N/UA7)/:R=/_@N>:]<)=_`[
M*!;"[KP&R<,,@.S%<E#JPTA$9@DLHO8S$,@8'QA\M@/4!&N75\`FA9",'L9,
MR>\/].F$5#0;4ZP1]>'DF(+J_*W>;4]S<QE,78LM5O?H*OBUN2VG0G+_MVU*
MFN,7&=\3QXR&$]\`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+VUA<%]E=2YP;F<`````````````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,30T,0`Q,#4Q-30S,S<W,P`P,C(W,C$`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!``
M```0"`,````H+0]3```!@%!,5$4``,<!`<<"`L<"`L@#`\<#`\@%!<@&!L@&
M!LD(",D)"<@,#,H-#<H/#\H0$,@7%\`6%LP8&,T<',,='<X?'\TB(L,F)K`E
M)<0J*K$G)\XG)\\I*<4L+,8R,K0O+]$Q,=(V-K4W-[$W-\8\/+$]/;$Z.M0\
M/,D[.])`0+-!0;<^/M5&1K-"0M5)2;9*2K9-3:=,3+5-3;124J-55;A24ME9
M6:=96:I:6KE=7:=86-IB8KI>7MQG9ZEF9K9G9[EL;*EM;:YN;JQU=:UX>+!Z
M>K-\?+!V=N%W=^)\?-J#@[^'A[&'A[*(B+:5E>>AH>NKJ^NQL>BVMN[#P_+7
MU_3CX_CCX_GDY/?Q\?SR\OS^_O__________________________________
M____________________________________________________________
M__________________________________________________________]E
MOP2D````@'123E/_____________________________________________
M____________________________________________________________
M____________________________________________________________
M____`#@%2V<````!8DM'1'](OW'E````"7!(67,```!(````2`!&R6L^````
MKDE$050H%07!AR)6`0`&T'.1O4)&9LOX94OV=LVDN,9]F>_5G2-)LK\X,SG_
M*TDBR>E(`0:VDT@..Z%KNE_+6B(G;>##??59\WID'+1^'/SW/*8OC@K8>ZKK
MNGYLM6(5-M_^_/SQ\-K@B^_P_R]7+PV,6H#J4N_.%`S;@*H$^.:B0%4";,E7
M5"7@4^2VAZH$VH\CN>XV-P0Z#A));F:;H)@X2R))<K>[O/3[/$GR#E6O*XP$
MOAO-`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+VUI;64O````````````````````````````````````````
M```````````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<V-``P,C$V-S0`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]A=61I;RYP;F<`````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S<R`#$P-3$U-#,S-S8T`#`R
M,S4P-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$````!`$`P```.W=XE(````84$Q410``
M`+V]`(2$A/__`,;&QO___P```````(ZE7?$````(=%).4_________\`WH.]
M60````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```!G241!5!@9
M!<&Q#<,@%$71!\)R&P5E`5*\-@T3V$R`_A[@YJZ?<P2L$Q#PSH!@_VY`4-LP
M%KN7\(-VG25L]!E=85"]9CD,JJ/GPZTI?:?"H)5Z"8-8M82-(+7P@V"];F,!
M*0,"U@G\`<FQ)<?GX)S1`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+VUI;64O8FEN87)Y+G!N9P``````````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#4U,P`Q,#4Q-30S,S<V-``P,C,V-S$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!`````0"`,````H+0]3````8%!,5$4````P,#!"0D)86%AN
M;FYP<'"\GG.\HGN,B8:9F9F]J(>\K92^MJ^\M['`KY'"LYK#NJ?&P;;ES*?I
MU;C.SL[>WM[MW<?NX,GHXMGQY];JZNKT[>+W\NO]_?T```````!_+KH/````
M'W123E/_______________________________________\`S1EV$`````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```!Y241!5"A33<KA%H(@
M#(9AC6^FF">-#(FM^[_,9J<![^''>+;NHSE+Y^X'^]GB)E=`M#=$I0#I>\K4
M&Q!$1L*E@"C(OHS-!83YN-4+C7.:&V#F=#1`NJ=8@9@2X>4-&)E21*B0H7_@
M:I!3C"&$Q_"';5O7^^S]8-#7OG6*$JF5@9WQ`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]M:6UE+V-O;7!R97-S960N<&YG````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(S,S0`,3`U,34T,S,W-C0`,#(T-34P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````0
M````$`@#````*"T/4P```P!03%1%``0```4```0'``0+``(.#!(@"@P9LTTV
M@"\<=CHO"```3U9@;8.86'^>?K#3<:W2B\SL4Y2J`#0]S2T)_Z6$_[.>_\"Q
M6A0,*P``&0``"P```003``@?``PK`!$N%6!SDMW@`"83TQH(OQ0#RS@NK2T@
MBA8`MT8DG"@`H3,`:Q,`D%@W5TD^]/__``H,J-')``X`QQL1_]#*_[ZY_]+&
M_^/#_\*'_\%J_[-2_]!V]*1='0``\_3F#2`>J+VXH24=_^#:_^7B_^#1__G/
M_^.:^K9'_\1%_[U(ZK]C#0H`\O_Z``<.M,/*"@``I#,C_]?(_^[D__':]NBW
M[MJ$^\M/_\8[]L!"[<]O``<`X/GV``<?M[[;%``(IQX`_^#!_^G0_^_,[,F/
MYKYF_\%%_[@S_;I%X;=E$0P`[OW_```SLK/L$@`>J2P`_]RP_KJ5],69],Z-
M^\UU_[Q%_]%2_]!CJ7TT!@$`W.[_`!)`M,'V"P`GAS8`__&]_^&S[M*@W,!_
M]-!Z_\9;\:\_OX4BT*]HS.[M`!<FH=+A``D,>4`5)```%0``#0``&@X`$0$`
M/1H`&P``"P(``!`$``T,'U57D\C"'4<Q``0,1%);7&YX:7Z/B:6[D[C3B++(
MBJ^W`!X4``<C``\R``@R``@S``@I`!,E``HF<I.R``D'%#M"`!8F1F^%``@C
M+4YO``4I1V2,+E)@``PB'E9O`!`K0W:1``XF+$M@``4;````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````F1/3'P```0!T4DY3____________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________`%/W!R4````!8DM'1/^E!_+%````"7!(
M67,```!(````2`!&R6L^````:4E$050HSV/\SP`"C!#P$\CZS\'(^(T;*L#X
MEH%1F!$%W&/A1Q5@0!,XS,#"AR+@PT!("WZ!VA:P`,30M2&,C!/!*AC!3I\!
M4Y4`%6!8".3\9V*,8H`)@,!RQ@@&A,!*J)X`%J@T!\Q:`"+`$[4PPS%Y````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O9&5B+G!N9P``````
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3`R,@`Q,#4Q-30S,S<V-``P
M,C,Q,C<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````P%!,5$4`
M```P,#!"0D)86%AL;&QP<'":``"N``"V``&Z*BJY*3*[6EG```#*.3G"7UK%
M967:>7B\GG.\HGN,B8:9F9F]J(>\K92[M*V\M['+DH7"DI+`KY'"LYK#N*/<
MJJ?@L*_DM+3&P;CES*?HU;?+RLG4SL;9T,/=W=WLW,3FWM3NX,GIXM?QY=3J
MZ>GS[>+V\>S\_/P`````````````````````````````````````````````
M``````````````"ES>*7````,G123E/_____________________________
M____________________________________``U0F.\````!8DM'1`"(!1U(
M````"7!(67,```!(````2`!&R6L^````K4E$0508TT7.Z1*"(!B%8>U+(\5M
M7,MR2<<-$+S_FXLEI_<7/'-FP#ID<";/EH9954$&)S`A8XZ0HL$-,(JY<$:1
MV0I<[/D^\MK4N5XT8'=D;`X\QJI4`;J!"**VQ2,GI0)\0!#-K,,]HX5>'!`^
MN8C11$GQ6W1>&^-RI9M9N"`:WR\GNBRY>04$)RN1]\$`NN]\IW09AH\!^=-F
MH]L@(3$`??AXO^HZ3TZP_WT!9%8<21%\580`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O96YC<GEP
M=&EO;BYP;F<`````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3,P-@`Q,#4Q-30S
M,S<V-``P,C0U-S0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3```!
M#E!,5$4````$`P(%!`,("`@)"0D+"P<3$0X:$PL6%A8<'!P@'1P>'AXO*2$K
M*RLM+2TN+BXX.#A-34V!6BMR<G*J;RND<39Z>GJL<2ZM<S*@=T2C>TN$A(2D
M?DZH@4RT?CZG@E*G@E.X@#ZJA%6KAUBLAUBZA$*KB%BZAD>\AT:\B$FZB4NO
MC5ZMC62\BDRPC5^]C$ZED7:^C5";EY3&EEW'FV2HHY[*GVBJJJK+I''.I'#-
MIF[-IG;0IG3,IWO0J'3/JWRQL;'/K'O-K(/.K8/4K'G5KG[2LHG5LH38M8R\
MO+R^OK[6NI3`P,#!P,#"PL+:OIK@PI[APIS@Q*#?Q*/AQ*#BQ:'CQJ+2TM+;
MV]L```![0$@>`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``
M"Q,```L3`0":G!@````'=$E-10?4#!02+`1^#@'Y````C'1%6'1#;VUM96YT
M`$UE;G4M<VEZ960@:6-O;@H]/3T]/3T]/3T]"@HH8RD@,C`P,R!*86MU8B`G
M:FEM;6%C)R!3=&5I;F5R+"`*:'1T<#HO+VII;6UA8RYM=7-I8VAA;&PN8WH*
M"F-R96%T960@=VET:"!T:&4@1TE-4"P*:'1T<#HO+W=W=RYG:6UP+F]R9V>*
MQT<```"9241!5'C:8V#`#B*!`(G++18>$>$IS`P7D/82X.04=)"&\?G\6$`4
MOSE,%Z\/F,7A"Q-@,^)B961DXC%EA]I@$!0<[._O[VTM!%$2&>IAIB(OKR"E
M*0X5"'/5<[>W=[30$($*A-B8*,G(R$BJPE0$6NJX.3DYVRI*0`4"7*RTE975
M9#7DH`)VQH:&6EKZNNJBD0B?00`V?P,``.(=%XJG_UT`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O
M:'1M;"YP;F<`````````````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C(T-P`Q
M,#4Q-30S,S<V-``P,C,S-3,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H
M+0]3````!&=!34$``+&.?/M1DP```"!C2%)-``!Z)0``@(,``/G_``"`Z0``
M=3```.I@```ZF```%V^27\5&```#`%!,5$4```#____JZNLS3VTU46](87Q6
M;89T@I%ZAY6*E)^XP,G`Q\\Q3FPU46X[5G(^6'-"77A#77A$77='7WA0:(!7
M;H9>=(MD>8^=JK>/F*&ZPLJ]Q<W*T-;0U=I\B).,EI_&S=/8W-_>X>/L[>U+
M2TG^_O[]_?W[^_OQ\?'N[N[M[>WL[.SKZ^OJZNKHZ.CFYN;EY>7DY.3CX^/@
MX.#%Q<7$Q,3#P\/"PL+!P<'`P,"_O[^^OKZ]O;V\O+R[N[NXN+BVMK:UM;6T
MM+2SL[.RLK*QL;&HJ*B@H*",C(R*BHJ%A85V=G9L;&Q=75U45%134U-`0$`G
M)R<F)B8='1T7%Q<6%A;___\`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!),<WO````5W123E/_____
M____________________________________________________________
M_________________________________________________P"^8S7C````
M"7!(67,```L2```+$@'2W7[\````KDE$050HST70U1:"0!2%X5EVC-W8+1:(
MK0-*V(B*ROL_B@C'Y7_YW>V-#`/],KXA`S6M6N,%^D$GF'*YL[/V'@%48E2]
MZ"E=KG=D0\:?"^-"\MQX`^`:SN,JIND)0+KLBX>P=].;VM"BH@$';=:?`73+
M"6=D*XJ#!4!_""T!Q)>D'35)EU<`#T91%95AGFL`65=NI]M.WQ$`AF79T8CC
M.,&&.2&$YP6S@P7_^=8!'PK-+=,D-RAA`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O;6EM92]I8V%L96YD87(N<&YG````````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P-S(S`#$P-3$U-#,S-S8T`#`R-#,R-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$````!`(`P```"@M#U,```#`4$Q410```!86%BLK*R\O
M+T-#0U5556AH:'5U=7Y]>']]>)-".*=%/H!_>=1-08*!?(.!?(6$?^>>/(J*
MBI&0B9*0BIR:E)V;E:">F*.@FJ6DG:>GIZRIHZZMI;2QJK2QJ[:VML#`P,K*
MRL_/S]C5S=G6SM75U=[;U>#?U^+AV^7CW^;EX/___[V]O0``````````````
M````````````````````````````````````````````````````````````
M`+9I(J\````M=%).4___________________________________________
M________________`*7O"_T````!8DM'1#\^8S!U````"7!(67,```!(````
M2`!&R6L^````<TE$0508TV/000,,Y`@P(`.0`*.4$#L;*RL+"PLS$UB`05M;
M45M;05M;7EL9(J`DPRDC(R`#)$6@*M3%M30EE97%E&4@`JIR?')RO-S<W'(P
M%1IB:LK<@H)<*"JXN;BX8"J4Y7AD9/B`ADI+,&!U&"&_``#DAQXB-H^QR```
M``!)14Y$KD)@@@``````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+VUI;64O:6UA9V4N<&YG````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#0S-``Q,#4Q-30S,S<V-``P,C,T-C4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!`````0!`,```#MW>)2````,%!,5$6$A(3____&QL;_``"$``````"$A```
M_P``A``````````````````````````````"80_+````$'123E/_________
M__________\`X"-=&0````%B2T=$#QBZ`-D````)<$A9<P```$@```!(`$;)
M:SX```!I241!5`C7-<W!"8`P#`70Z@*:2!W`@PNT>TC5H#>ET!FZ@EO').(_
M/?X/Q#D-,[L&`+#[T7,T>-H$XSP7#(MKD*@,46[&HY:P"/"H]WYI<T[MJL#T
M$%J3H!@PYP^>Z)M`?PC:22,@R\4OQ/XE#[E,VE8`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE
M+VUA:6PN<&YG````````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(R-C(`
M,3`U,34T,S,W-C0`,#(S,S(V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````0````$`@#````
M*"T/4P````1G04U!``"QCGS[49,````@8TA230``>B4``("#``#Y_P``@.D`
M`'4P``#J8```.I@``!=ODE_%1@```P!03%1%DY./2TM)^_OXI:6C]_?U^OKY
MP,"_C8R&O+NW^?CTMK2NW-K4V]G3VMC2D9"-^_KW^OGVZ>?BXM_8D(V'W=K4
MVM?1^??S^/;R]_7Q\O#LDY*0W=G2W=K5Z>;AX]_9C8N(^OCU]_7RZ^GF]_7S
M[^WKEY22LK&QH:"@_____O[^_?W]^_O[^OKZ\?'Q[>WMZ^OKZNKJZ.CHYN;F
MY>7EY.3DX^/CXN+BX.#@S\_/RLK*Q,3$P\/#P<'!OKZ^O;V]O+R\N[N[K:VM
MJ*BHHZ.CH*"@GY^?GIZ>G9V=G)R<FYN;FIJ:A86%=G9V:VMK75U=0$!`'AX>
M%A86`0$!````____````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````N+5Q&````%5T4DY3____
M____________________________________________________________
M________________________________________________`+"A!\\````)
M<$A9<P``"Q,```L3`0":G!@```"[241!5"A31<[70L(P&$#A&F9M92_9(P(M
M5H&FLI<MM"*B)'G_9^$/4CB7W]61.+O$_22F:9H^FM\$P+;M6>_3%P##,#:'
MXR^C]`J.L_WX?C@QW!0"\/8.]<<,XP@5H.]<U_6\*0!^I`(&(G,A`/]0`.]K
M;Q*R%!`+"A@28EG6&J`8R@!,EJLUY/Q%.Z\M@.LZ8P&4SCV7`#BGW;B$$)+E
M6M*'%U1(Y.N-2BWU#^TG556SBE*NAB_`Z3U^!NY>.TD6"DM$`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+VUI;64O;7-E>&-E;"YP;F<`````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#,V,``Q,#4Q-30S,S<V-``P,C0P-#$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!`````0!`,```#MW>)2````&%!,5$6$A(3___\`````
MA`#&QL8```````````!<<%\J````"'123E/_________`-Z#O5D````!8DM'
M1`<688CK````"7!(67,```!(````2`!&R6L^````74E$050(UR7*,0Z`,`Q#
MT10CL6*5$W1A38\`RH$J,>3Z).V?K">+#XD.%Q^,-A=5GLIR"U``MB9=(WM>
M^2JP,X8'V10$I:CV]0&"R)2@GN?!BC+'98\MR7)8EJ/-?A8(%\\-,\(H````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]M:6UE+VUS<&]W97)P;VEN="YP;F<`````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#$P,S8`,3`U,34T,S,W-C0`,#(U,34P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```0````$`@#````*"T/4P```,!03%1%@7^`P;_`__[_?X&``0$`___B___C
M___]P,"^=W15__.S__'/__#/__#1@$``I64E_]V\>CX<GV-!TE(1TU,2>SP;
M?#T<?3X=?#T>H6)!H6)#KBX`K2T`K"P`J2H)SD\N`0``_____O[^P<'!P,#`
M@8&!@("``0$!````````````````````````````````````````````````
M````````````````````````````````````````````````SW^?Z@```$!T
M4DY3________________________________________________________
M____________________________`,)[L40````!8DM'1#\^8S!U````"7!(
M67,```!(````2`!&R6L^````JTE$0508TU6/6Q+"(`Q%8WU0V[2@*!5%:BIB
M=\'^=V6@CC,>?N#.X4X"*:6X`!#Y`3F@0E5%3J"7@S5\_$@44TP@&RPH3S0S
M8-!I/_H1;0B!P@P6M5->>1QR3\B&P>W^S["XV[%Q_AEWC>A.V:C%TG&S1CLT
M-`D1WN`58MMV72/KNG2,WIKCX7J1O1"E@T=?\X5"AE:/$DPT+>M,2Q"YORY&
M>)8O+UYA,W_Y`+N]'=>Z37F-`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]M:6UE+VUS=V]R9"YP;F<`````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`S-C``,3`U,34T,S,W-C0`,#(S-S$T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````0````$`0#````[=WB4@```!A03%1%A(2$____``````#_QL;&
M````````````^T&S=0````AT4DY3_________P#>@[U9`````6)+1T0'%F&(
MZP````EP2%ES````2````$@`1LEK/@```%U)1$%4"-<EC;$-P#`(!$F:U)@L
M@"E2V\H"MCR0.]8/3ZXZ3D)/OBFXG'QS<#IUP,=#&K=PK7]98Y*IB7%(:[W,
M$:)F)I#6YUM6%E%ACA+O60R@8.)&^;>R+`"IR0<XL1=[)^+'7`````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O;6EM92]O;V]?8V%L8RYP;F<`````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,S$V`#$P-3$U-#,S-S8T`#`R-#$V,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$```
M`!`$`P```.W=XE(````84$Q418"`@````/___\#`P```@(``@```_____U;L
MI^$````(=%).4_________\`WH.]60````%B2T=$!Q9AB.L````)<$A9<P``
M`$@```!(`$;):SX````[241!5`C78RAG``-QAG(F)2!0!C&,00#$,&!F8#!&
M$U%2PBUB`A,)@8H8AD!%TD)0=<'L8H:)"(*!.`#8_!6)URW5I@````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O;V]O
M7V1R87<N<&YG````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0Q,P`Q,#4Q
M-30S,S<V-``P,C0R,3$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!`````0!`,```#MW>)2
M````,%!,5$6`@(````#____`P,``_____P```(```/^`@```@`#_________
M_______________!9+?3````$'123E/___________________\`X"-=&0``
M``%B2T=$#QBZ`-D````)<$A9<P```$@```!(`$;):SX```!8241!5`C78_C/
M``;R#/^9E(!`&<00-A8V!#-,0D*"%4`,4Q<7929^L$B06@%$1"D]$20B$J16
M)@Q6#!0`ZS)2#1.&,AJ5(8R(2<JH)L/L8C8&`2!#$`SD`4,R(+#$1;^O````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+V]O;U]I;7!R97-S+G!N
M9P``````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S-#<`,3`U,34T,S,W-C0`,#(T
M-S0T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````0````$`0#````[=WB4@```!A03%1%@("`
M````____P,#`@```@`"```#_____T"[!``````AT4DY3_________P#>@[U9
M`````6)+1T0'%F&(ZP````EP2%ES````2````$@`1LEK/@```%1)1$%4"-=C
M*&<``W&&<B8E(%`&,IB-00#(8!0$`9"4$%!*&,QP<5:%,(R-4J$B9J)@AC!0
M$Y@!T@1F*"D+@PUD4E(0@#(,#8T@#&%E(12[!"%V`0!+G1,13\`*;0````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O;6EM92]O;V]?;6%T:"YP;F<`````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,C0V`#$P-3$U-#,S-S8T`#`R-#(Q,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$````!`(!````+7Z-^H````"8DM'1`"`1S6@$@````EP2%ES
M````2````$@`1LEK/@```$I)1$%4*,^UD$D.@#`,Q/QTGI:?F4,IJ#!5$1+Q
M,=9D060S@T(34M4HU(V'L$Q0!F)":QRM/*(KSG>XE"\)BQU>7/'K)RMR"CA#
M=AJU@3HN%F2X`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+VUI;64O;V]O7W=R:71E<BYP;F<`````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#,Q-``Q,#4Q-30S,S<V-``P,C0U-S``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!``
M```0!`,```#MW>)2````&%!,5$6`@(````#____`P,```/____________]L
M?[^4````"'123E/_________`-Z#O5D````!8DM'1`<688CK````"7!(67,`
M``!(````2`!&R6L^````.4E$050(UV,H9P`#<89R)B4@4(8R&)BA#"8PP\7%
M"2X"4>,"!,[H(D[*!-4X*:&H838&`2!#$`S$`9N!%.SLG&(#`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+W!D
M9BYP;F<`````````````````````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(S,38`,3`U
M,34T,S,W-C0`,#(S,34U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/
M4P```P!03%1%````@````(``@(````"`@`"``("`P,#`P-S`ILKP!`0$"`@(
M#`P,$1$1%A86'!P<(B(B*2DI555534U-0D)".3DY_WR`_U!0U@"3S.S_[];&
MY^?6K:F0,P``9@``F0``S````#,`,S,`9C,`F3,`S#,`_S,``&8`,V8`9F8`
MF68`S&8`_V8``)D`,YD`9ID`F9D`S)D`_YD``,P`,\P`9LP`F<P`S,P`_\P`
M9O\`F?\`S/\````S,P`S9@`SF0`SS``S_P`S`#,S,S,S9C,SF3,SS#,S_S,S
M`&8S,V8S9F8SF68SS&8S_V8S`)DS,YDS9IDSF9DSS)DS_YDS`,PS,\PS9LPS
MF<PSS,PS_\PS,_\S9O\SF?\SS/\S__\S``!F,P!F9@!FF0!FS`!F_P!F`#-F
M,S-F9C-FF3-FS#-F_S-F`&9F,V9F9F9FF69FS&9F`)EF,YEF9IEFF9EFS)EF
M_YEF`,QF,\QFF<QFS,QF_\QF`/]F,_]FF?]FS/]F_P#,S`#_`)F9F3.9F0"9
MS`"9``"9,S.99@"9S#.9_P"9`&:9,V:99C.9F6:9S&:9_S.9,YF99IF9F9F9
MS)F9_YF9`,R9,\R99LQFF<R9S,R9_\R9`/^9,_^99LR9F?^9S/^9__^9``#,
M,P"99@#,F0#,S`#,`#.9,S/,9C/,F3/,S#/,_S/,`&;,,V;,9F:9F6;,S&;,
M_V:9`)G,,YG,9IG,F9G,S)G,_YG,`,S,,\S,9LS,F<S,S,S,_\S,`/_,,__,
M9O^9F?_,S/_,___,,P#,9@#_F0#_`#/,,S/_9C/_F3/_S#/__S/_`&;_,V;_
M9F;,F6;_S&;__V;,`)G_,YG_9IG_F9G_S)G__YG_`,S_,\S_9LS_F<S_S,S_
M_\S_,___9O_,F?__S/___V9F9O]F__]F9F;__V;_9O__I0`A7U]?=W=WAH:&
MEI:6R\O+LK*RU]?7W=W=X^/CZNKJ\?'Q^/CX__OPH*"D@("`_P```/\`__\`
M``#__P#_`/______6").MP```0!T4DY3____________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________`%/W!R4````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````6TE$050HD5V.RPU`(0@$N7FQ#OLOC&1#!;PEHL*;B^[P">+N\F`(
M8<E<4JM"L?BL`P5I@M2)%%PZXP=8%T-_`HHN=+=<,1`]P!$C`E15]NFYX(ZP
M9$V\G**>^P&ZF93#$VX9AP````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+VUI;64O<&AP+G!N9P``````````````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,C`S-0`Q,#4Q-30S,S<V-``P,C,Q-S$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!`````0"`,````H+0]3````!&=!34$``+&.?/M1DP```"!C
M2%)-``!Z)0``@(,``/G_``"`Z0``=3```.I@```ZF```%V^27\5&```#`%!,
M5$5[>WL```"]QL;___][A(1[A+TY0EJ$C+V4G,;O[_?>Y^^MM=;>WN_W]_]"
M0EJ,E,;&QMZUO=:]O=Z,E+W.UN><I<XY.3D8(2D8(2$Y0D*<G*7_________
M__________\@("`A(2$B(B(C(R,D)"0E)24F)B8G)R<H*"@I*2DJ*BHK*RLL
M+"PM+2TN+BXO+R\P,#`Q,3$R,C(S,S,T-#0U-34V-C8W-S<X.#@Y.3DZ.CH[
M.SL\/#P]/3T^/CX_/S]`0$!!04%"0D)#0T-$1$1%145&1D9'1T=(2$A)24E*
M2DI+2TM,3$Q-34U.3DY/3T]04%!145%24E)34U-45%1555565E975U=86%A9
M65E:6EI;6UM<7%Q=75U>7EY?7U]@8&!A86%B8F)C8V-D9&1E965F9F9G9V=H
M:&AI:6EJ:FIK:VML;&QM;6UN;FYO;V]P<'!Q<7%R<G)S<W-T='1U=75V=G9W
M=W=X>'AY>7EZ>GI[>WM\?'Q]?7U^?GY_?W^`@("!@8&"@H*#@X.$A(2%A86&
MAH:'AX>(B(B)B8F*BHJ+BXN,C(R-C8V.CHZ/CX^0D)"1D9&2DI*3DY.4E)25
ME966EI:7EY>8F)B9F9F:FIJ;FYN<G)R=G9V>GIZ?GY^@H*"AH:&BHJ*CHZ.D
MI*2EI:6FIJ:GIZ>HJ*BIJ:FJJJJKJZNLK*RMK:VNKJZOKZ^PL+"QL;&RLK*S
ML[.TM+2UM;6VMK:WM[>XN+BYN;FZNKJ[N[N\O+R]O;V^OKZ_O[_`P,#!P<'"
MPL+#P\/$Q,3%Q<7&QL;'Q\?(R,C)R<G*RLK+R\O,S,S-S<W.SL[/S\_0T-#1
MT='2TM+3T]/4U-35U=76UM;7U]?8V-C9V=G:VMK;V]O<W-S=W=W>WM[?W]_@
MX.#AX>'BXN+CX^/DY.3EY>7FYN;GY^?HZ.CIZ>GJZNKKZ^OL[.SM[>WN[N[O
M[^_P\/#Q\?'R\O+S\_/T]/3U]?7V]O;W]_?X^/CY^?GZ^OK[^_O\_/S]_?W^
M_O[___\'Q@QM````('123E/_____________________________________
M____`%Q<&^T````)<$A9<P``"Q,```L3`0":G!@```!;241!5"C/G8])#H`@
M#`!+2%L%4=R]\?]?&I"R7)WC9-JT$"*J`I\`0806BL@#^E>A.J+`!$$I$'D8
M#36%G9C=7`OK%O1K4[`WN"W=CAV/DR[Y15'B?N1;N2!D7KFP"".%W##Q````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]R
M<&TN<&YG````````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q-#,W`#$P
M-3$U-#,S-S8T`#`R,S(P-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M
M#U,```&`4$Q415A86-[>WKRWL9F9F?___^KJZFUM;?S\_'!P<,[.SC`P,(F)
MB6MK:T)"0DM,2U985EM=6V1D9&EI:4Y/3KZBH.*RL/;U]>+@WH^)A&YO;B$B
M(4M-2W-S<\S,S._O[]*_OL!H9<%13=S'PN?@V;ZVKU)34@<'!A\@']_?W_[^
M_OOX];Y&0KM`.\[(O[RNER8F)0("`O[^_?KX]/CT[(U*1HX7%+:$?0````P,
M#$9'1L3$Q&1B7HB">,"UH[RKD'9Y=KZ[N(Z.BQL<&[:PJ!<7%[.JG!`0$,V^
MJ;RHBG]^>KZVJKRPGKNLE;RFA0<'!U)24LG$OM[8SLB_L];+NM7(L]+#K-#`
MI<^[GKRC?_3MX?+HV/#DT.[>R.S:O^G6N.?1L.7,I[RA>,;!ML2]K,.XH\*S
MFL"OD;^JB+ZE?[V@=KR><_______________________________________
M_____________________________________________S1O*TL```"`=%).
M4___________________________________________________________
M____________________________________________________________
M__________________________________________________\`.`5+9P``
M``%B2T=$?TB_<>4````)<$A9<P```$@```!(`$;):SX```"L241!5"B13<XM
M#L)`$`7@]]+"-E4$@0/7!$-P]`8$AZWF(IN>`(_"8JMJ,&@(%ZB#8%!@^"G;
MPFZ[I$_-^\3,4`*(4>=7:("ZL7"4M.!H8%$JV0"'S$O1``CE4FE8TN;:NU.N
M]'3NGP:&+@S(*!YF0&`@XYASLV-D^C-C2$Y3'"8*[J=%[AG.D'I\^/7:G0&@
MBY?W%GF;6WWVR%O''D[JQR(+FPH6L+"NP,<_7Z/A,A"\6WNR`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M;6EM92]S8W)I<'0M:G,N<&YG````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,S8P`#$P-3$U-#,S-S8T`#`R-#,Q-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$````!`$
M`P```.W=XE(````84$Q4182$A````,;&QO__`/___X2$`/_______^,7U7D`
M```(=%).4_________\`WH.]60````%B2T=$!Q9AB.L````)<$A9<P```$@`
M``!(`$;):SX```!=241!5`C78V"``$8&]O)R!B"A",0%)B:*8`9+:)"`.)!1
MX&*BR`1FN(8*"H*DP$K`:IA#@\11=3$PACJ!%3L)B!B!&"R&S,Y@J0(E1B6(
M8D&@,4`&DQ(8*#((0@$`@+<6DNH<%!<`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O<V]U<F-E
M+6,N<&YG````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,R,0`Q,#4Q-30S
M,S<V-``P,C0Q,38`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!`````0!`,```#MW>)2````
M&%!,5$6$A(3___\```#&QL8``(0```````````"+Z11]````"'123E/_____
M____`-Z#O5D````!8DM'1`<688CK````"7!(67,```!(````2`!&R6L^````
M/DE$050(UV,H9P"!\G*&<D9!04$A=AA#`,904H<P!(7!#!<7"$/$4<01G2&(
M2PJN"V$.E,%L#`)`AA(8J`,`HQ04*-AK*I,`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+W-O=7)C92UC<'`N<&YG````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S,S$`,3`U,34T,S,W-C0`,#(T-#4W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````0````$`0#````[=WB4@```!A03%1%A(2$____
MQL;&``````"$____________W#H^*0````AT4DY3_________P#>@[U9````
M`6)+1T0'%F&(ZP````EP2%ES````2````$@`1LEK/@```$9)1$%4"-=C*&<`
M@?)RAG)&04%!(7880P#*$#8VAS`$A4`,$1=!$3##1<31Q0G*@(K`U"!$8&K@
MNN#FP!A,2B``9!B#@3D`\/H5@E-&L54`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O;6EM92]S;W5R8V4M:"YP;F<`````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,S$V`#$P-3$U-#,S-S8T`#`R-#$R-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$````!`$`P```.W=XE(````84$Q4182$A/___P```,;&Q@``A```
M`````````(OI%'T````(=%).4_________\`WH.]60````%B2T=$!Q9AB.L`
M```)<$A9<P```$@```!(`$;):SX````[241!5`C78RAG`('R<H9R1D%!02%V
M&$,`QE!2!S)$'`4%A5$9+BXP$1%'HAE``P51&,S&(`!D*(&!.@"S1A1>9S9^
M?P````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+VUI;64O<V]U<F-E+6IA=F$N<&YG````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#4V-``Q,#4Q-30S,S<V-``P,C0V,C8`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!`````0
M"`,````H+0]3````8%!,5$4A(2%"0D(```!"(2%24E+_>WO_.3E[(2&]6EK_
M``#>``"]O;V<.3F<``!:6EHQ,3'___^$A(2<>WNEA(2<G)QK:VO.SL[>WM[O
M[^^,C(RMK:U36^]36^]36^]36^]36^^BICK[````('123E/_____________
M____________________________`%Q<&^T````!8DM'1!\%#1"]````"7!(
M67,```!(````2`!&R6L^````@4E$050H%07!24("`1`$L.H2%T2T70>]Y/^_
M-`E`!@A@&B!`V@(!TC9,!*1M!YV`-'=M3!N0T_W#8V.:(-.G^_-SQ\R$F5Q>
MSN?KZUM"I/N^']?KYWX%F23?NS\_NY<@:7O9W=T]BLPTQ^[N[E'$)'O[G?F^
M'4608\*<_@9!)M"!?\1K$5RW4&3[`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+W-O=7)C
M92UP>71H;VXN<&YG````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`V,#<`,3`U,34T
M,S,W-C0`,#(U,C(T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P``
M`&!03%1%(2$`0D(`````>WL`.3D`8V,`>WM[``#_6EH`A(0`0GL`8YP`(=X`
M`/\``'L`(5H``+T``#D`0KT`O0``.0``.;T`(9P`>P``________________
M________________>L(=BP```"!T4DY3____________________________
M_____________P!<7!OM`````6)+1T0?!0T0O0````EP2%ES````2````$@`
M1LEK/@```)1)1$%4*%-5S\&2PC`,`U!%P>PJ<5L2H!SU_W_)H64&=-,[>"S8
M!@K\"6S62PU^P[7^E1^H_S7`D\`B26H1QQV4"*GGLDJT;6R]][R-7*5BVQB9
M.<8<<YY@WA];#F87#K@_<R7VKN,7O%XDR_+IA!]&2RE(DP1LWA8I0@%%%-B<
MJ2/1&F%SGSG;/F<A:=CFN@WR'/,&,F,0&QN/=Y8`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]T97AT+G!N9P``````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S$U`#$P-3$U-#,S-S8T`#`R,S,V
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$````!`$`P```.W=XE(````/4$Q410```(2$
MA,;&QO___P```"QEJ`8````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP
M2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,%!,+"=NXI18````W241!5'C:
M8V!@<``!!@8&%D,@,`$RA)U!`"@D;`P$1B@,$Q<39W01%S)$8`PA)1``,EA<
M0(`!`/E<%6K<DNOA`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+VUI;64O=F-A<F0N<&YG````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#<R,0`Q,#4Q-30S,S<V-``P,C,U,#$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!`````0"`,````H+0]3````P%!,5$4""AX"1@)::G)FF@*6HJZV
MOL;)SM:$D9J:9C+.UM[.FF8:)C+:XNHJ,CK^SIHV0DZ^RM+BYNK^_LZ*EJ).
M6F*^QL[FZNI&3EK4V^,*$B;:WNJ3GJJ[PLO+TMOJZNK"RM136^]36^]36^]3
M6^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^]3
M6^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^_^&KX1
M````$7123E/_____________________`"6MF6(````!8DM'1#\^8S!U````
M"7!(67,```!(````2`!&R6L^````C4E$0508TUW/T1*"(!`%T`T4E<BD,DC8
MW?__RQ9T:/(^W(<S=V`6EE-@436O<+]=/P`+*&IYNX@@T)?DO#+BU/U@'Z4"
M(804F)RUCMJ"#=G'/!Z+)!N!V1[0]RLS4AS'C9[M#22MM:K@\VIPB@4N-!1@
M-ABWS7OY=@?L@)R7V@&[)!=0K6$HU\!_G<__`K6N#Y:X4DZB`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]M:6UE+W9I9&5O+G!N9P``````````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`S-3,`,3`U,34T,S,W-C0`,#(S-3$Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````0````
M$`0#````[=WB4@````]03%1%````F9F9S,S,____````J7X.F`````%T4DY3
M`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)
M344'U`P4$PPHV)`CCP```%5)1$%4>-I-S-$-@#`(A.$;H=4N`+(!"VA[^\_D
M:5KC__2%``"J*E![9MK"42;(B0R4A6HZRAIHW;M=+7"2;B,"V-R-FJ!YOP8%
MJJ&K[\\/VG9_P+<;9U,17Z#\KAP`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]X;6PN
M<&YG````````````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#`S`#$P-3$U
M-#,S-S8T`#`R,S$W-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$````!`$`P```.W=XE(`
M```P4$Q418"`@/___\#`P`````"`@`#__P``@`"`````_P``````````````
M`````````````"$-1KT````0=%).4____________________P#@(UT9````
M`6)+1T0/&+H`V0````EP2%ES````2````$@`1LEK/@```%!)1$%4"-=C^,``
M`OS_&3X(@H`"C*'(#V48&P,9BB(N@HK"#!]$$QU#$E.!##5!5_=$,660B$L%
M6$1042P-K`:L2Q#$<`$"1P(B4,9G8P@``%-=(`>HY5H(`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUO8FEL92\`````````````````
M```````````````````````````````````````````````````P,#`P-S4U
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<W,0`P,C(R
M,3(`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6]B
M:6QE+V)O='1O;2YJ<&<`````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#,V,C8T
M`#$P-3$U-#,S-S<Q`#`R-#(S,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#_V/_@`!!*1DE&``$!`0$L`2P``/_;`$,`!@0%
M!@4$!@8%!@<'!@@*$`H*"0D*%`X/#!`7%!@8%Q06%AH=)1\:&R,<%A8@+"`C
M)B<I*BD9'RTP+2@P)2@I*/_;`$,!!P<'"@@*$PH*$R@:%AHH*"@H*"@H*"@H
M*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*/_"`!$(
M`3D!!P,!(@`"$0$#$0'_Q``;```"`@,!````````````````!00&`0(#!__$
M`!D!`0$!`0$!```````````````!`@,$!?_:``P#`0`"$`,0```!]4`(OEGK
MGE6L6:NNC>5;FL;^7M9<H^OD]3C9.9KC*8IUE'E'0D*=ZILCG51F5KA5I#?1
M/&[<][,H>_0\=:8*',EZ`QU```#S+TWSRYYV;S_T/>:G!N]6N5^.FMQICI@0
M=<YF^&.G#(Z[XJ+WY2!OMS[ZQC.<V$G>Y9Z86M:_-UVSU&Z26T#'0```*/>*
M5<^?>E>;O=XO1Q@-1D-AA7*W#"*QPQ)A6=,]^+6,:$;D;HSUSCHN'*+E-^G%
M*L&=YKLZO:Q#]`\Y]/SI\!G8```4F[5"YHJMTMWBQ*I?I<U3.<>OU99T"P(D
M7:]%B<^_1./!ANF.NFK5G6=(9IV5PTFKK]WFJS7I$>XU]:\F]BSJ8!G8```5
M6U5M/.&JMSUY5#U&M5N:]?A5J9,I(-LWJIM5;AN/TD="/OWW-.G3>6DSYE@:
MKM_10\=;93>%5UYN["=!T7^T^.>SXUD":```"N6.OIYJX3.NO-JH;:35/<LD
M[$PC35KMUJK&5UF;LU"[3.Q'4/?-$8L8^MSM#TDYZ*+%T-8YKF*\X^Q>-^R8
MT`30```('Z!/,G:1YUYL]<J9IE@CQVB0&E<JU<,HLME:7EXA5/K"[J_Z+`E;
MK*9ZQLR2<(7=N5S)<D3V;QCV?&@":```!`_0)YB^0V#ISG5^P*FNMH\]9Q;J
M5HX.$JLSZWZ625+48MSYB+N@96<;6C4188?3G)B)">ZNJYBN2)[-XU[+C0!-
M````A?(D\OL->L/3G-QG1J.NE;I#CV'*JU=EU$4Z+T327QXQ!L6DBVLS'.PI
MT90QACCV!:Q7I$]D\=]BQH`F@```2.TJ>66*N67ISEJ6M;:N$VEV.%/!S"7L
M*IUG;$5A'$Z+!AA:PK332T2JMR$)IT659(7L5R1O8O'O8<:`)H```$KI.GE%
MEK-FZ<YD:6-5"=8$Z;S%G(B36Z9;7'JKO,E2%.@M8)[3JHID/JC10,1:WR+J
MN8KDX^O^1>NXT`30```*FJQ/(;+6K'TYLHDE4U,X-+-+2Y4JLH\TWY5'@NHH
MO[2>YN:=#7GSF1!+!`5$QAXLE+F2U,>M^3^L8T`30```+F,)/&K%7+!TYMZQ
M9LM*NBWBEEY1^645BLVU7#=%TBQ(==Q*U1.*WEU9]DV@*EFIE_RD+JL9*TD>
MJ^8>GXT`30```1Y&AX@Z3LNG*P[\]6N_./TE6[[L[,J6P5";88Z*XCV25]\9
M59"?\")/Z0Y.F(<RWFI:IT=^CT*^XT`30````'C.9R?ISMZICQ7#VH6G)W0)
M["N?6KM:[;.9.;7.-JX"K-<:ZF+$@CRVA;(6R(7E?L&G!*W1LWRWH'_/H`*`
M```!YW2_4/*-XNC%!8*7I;=M+685JRRH@6N);MVK'62S:UWE$.SQ6>K4'#*(
MB@LFJZ<^O!(B)KPCU>6&.@``````1_"O?/,[FMVZ@6#>;=F/(FL8SJ!J6!C!
MM@BDC*J$6(UR:Z[\C6+T7HOM5*]DS6`&=@``````0IH>"'JGDVN=B>5!K5CP
MHZ4RUA[$HBA+5RMUD].?&61PAXN9'';DG%'WF2O;]C;'0`````````#%9LXG
MAC'UJIW*B7'ZV=3.`,X,FN#;IPP2M(_`PAM5B*3Z9VSG8`H```````````&,
M@8R`````&,@`!C(````````!_\0`,1```00!`@0$!04``P$``````P`!`@0%
M$1(0$Q0@(2(Q-`85,#)"(R0S04,E-4!@_]H`"`$!``$%`N%@;$#D?`M1]U:W
M'EW`$Y;L_A_X92:+')N>,.57NOY<&/<;NRC>;%ONK9`'-"S[HQE*":U-EU:Z
MM=8NL76LNM76KK5UJZU=8NL76+K%U;I[!'3N\GH!YICJZZPK?N.[+-XX6>L7
M5T')GVSLSZCGSZFM8*9Z]UYE#=F1J]@A$.])Q3M2YT==.P0I%F,<0BL.K;ZR
MPC?K]V6C^IBB;#,G;5K55Z[]EJN0[M5=C5JY0J5%Y0Z5]P`%&Q*$I!L@(1!A
ML%Q`"1I5P1!";H\E/S&P3:MW91OW47Y=BJ7>+A8HK\M'[=KK:M.W1U3I2,A#
MB*,G1Y^%B?A!_-@&TI]V9\MJ[':3%6%&2G;U(2E;*OD?FGC3C7)L,N21T8D0
M3B(DHRZ2*ETK)@L[D/RE">]M#IJV0(I8NVS"J7:Z'E+%9-8@499ZJU-?UAHZ
M4.[X@;S6?.&O/9)SF/*Q4MXBQ7R<;<9G(R8\W49NZNVND!7!T[%G(DA;6)/S
MIHZ*+L4=&R6F:9YQ1;DUU))*)9*]D-L0UKF-'*?D-+67Y8QM*/=\0_Q@=MW(
M<=S`F;K209VR.%UD.Z6O*L2N=#`R\+>9-)R3VK:MJVK:K@N=4I3ZNB8.CD)`
M,1=5D'QN*#1C=TY<'VA''51^^HVVKW9]OV_AJ:#V*;;AOCLA&P'=JK(!6(V,
M(-YO#*TFQ3/R'$[19EHM%HAC9U*&U5+1JJY.1.JM&@*=>8I0*5H-D;.JK,Y[
M!5#[Q^$.[.^U_*M+:]\&]H2D`M>Z^V5ARO$8X2++4>(?4.V6K16U:)HK1V3Q
M=H867ZIA,9=2.+1E`!+-K1F>=LD8L,156;6QWYSVOY`3*S4C-VYE>87@=/,@
MWYNJKRZ;(;5L6U-%1BHP66,P*^.?D57MJ$"$:Q:%60ZQ;3PA$<9(JH^[[\W[
M3\J_&<&FQ:3ZCMD$S0"=7JLMN+N,2.U:,RDT8O&*,2((6"/?M#K$*IFJ55-[
MEU`J"!QDBJG[OOS7L_RK\=6X/XHE8)%&%D2>N:!J>2>"&>!(#D.+VLG`*M63
M7%CZMH(I57(AC$)G?5:MQ=%57W/?FO9_F#A)R6;/R<*)B"C4CV*LA%@6*U=%
M`,B>C%G>G.2'2#!1;:O%UZ(EIM\:%XZEAF9CBLT$.3$@_H55O<]^9]G^=9.J
MQ.GOR*-LESM&(XYPN4Y595S1.)_!2MQW1C>FI0R$$]R0T,L"Q31G=)0Z,,+%
MN?-YTB3OD;IZ$7C3=%57W/?F?9_G6]'5VMSV`1N86;S33+MKRT%BG_<%_<7#
M-&K6!:=ZLKP]TC"(^0&U*Q8F[5L<<8<=5.\K^[53E$,&:5Z:=%53W7?F/9?G
M6].%@`SLPK0%UFQ%LGLM3K=*.]N!:+OM+4G(V$VBC-I7IO<,\([6&6HH6J\6
MYUB:C3UGP=&]*?N^_+^R_P!*_HI2:+2N!90LBFHR=.[OP=M6>@T9,V0BMV0=
M2K6#H`1@APU=2)&*>X%D,L"-P-Z4?>=^7]E_I7^U`C&Y>YX1V#T:AV/CC5U7
MM,27T"3:$8@L'8=:D-ISJ[<G4B!5B<T*,J'O>_+^R_TK?:I2>I?<$2RG9>"A
M<=Y7ZT;0:!^<(Q8B@,5NRT<1*;2P[LBU;H%6ML5W?1@2A&#%YH9Q@I"BLL?:
M"L+D@1EC_?=^6]C_`*5_M5@,+`Y<VG+7G#''2+$V#Q6LBN\9Y6_/G@H7>96G
M>=B#L[FS>D2VM94X%YM6IO'#S*Q>C!ZM63$X&],;[_ORGL?]*WV\/Z)CPRER
M;T%.G:L(0H!'D*\Y2&0-F(Q2:+59*<AUFC&>1.I4B#)_R*>F0J``5>/!T;TQ
M?O\`OR?L7_DK_:C&B-;;LFF8P4(XR\?[-7"9?+QLN@9T.A6@[\92:+-.4WE&
MU%#M-S$Z-Z8K_L._(^R?^2K]JQY&^8&B,UW>SJ[C0F3&+5*WBGAYG\%(XF74
MA33:2E'=PE-WFU3DS>WHIVIO',Q8E6E-R571_3#^.0[[_LY_RUO17HO7LU3Q
MWP(\V#/<\@L>IB2O*%@KQ=Z,8/4!4("=*M)K&*$H')7L&GL$&#PJXT[$#.44
M[15\SV20@PX.C^F$\<CWW/&J7^2IZ+1I,:B0+BM04/,K%AJ\,.*31YO)S60,
MYB5I3C0<TMU<\MF<GN>P-R5:I^H`S/")K@`MS+5Y5:PZHTZ/Z8!M<AWG\0&_
MDJ)N)!C*TL75=QXZK"2NU&LQ8I:ZA<JNGN5&4LA&2JTIN56*0+$FQ0$*E6"G
MXR5CT^'&_==[MX6O`M1U'T*1AQ@.R5=/;TZEQ2B[2;A_4@CDFK@9-X<73SUD
MU6S)$#8BJ]AB\)(Z^&H^;Z&4CLMU'4/2[+:>^0\WP[SZ>Q$18V@DQLQ$B6"G
M8@SM(TD\CQ36X,[.SLMW,>M8J#F6&X@Q<N5SRY525A?#D=*WT,_';=K.A/X7
MJ[V`4K3LAV&T/8_5D7G`PLG1'D>T40ZHJI'YMJQ`,2P$<9M<;;N$V53:MAP\
M_KY$5JS$,*,)6+#J:L>N%CMQ_P!#XF'^H!_&N_@RMTX64[V*KPNU)-:OCTQE
M5ZP3E>GE26&.*N2(HS.TXN=Y/EB]38,)B`KV7JRZRFS3R6]Q4)DG_3HKJ?B2
MK#EU_H?$`M]&+Z2IS4?3A,(2(8QBX60#L#C5NU5UMB"^8%=3^9VFI41U.$X1
MFS5*S)O*W"2-)8T?/R'T3#8HK$'$>L31P3U;OU6O#5F6K/VNINK$U\,@^G\3
M5-I8.JIM$.>K?0))W6QW4;`^J;73@[J3HLD[.4M(#5JWTK((6`6Z\ZM@;H!M
M$,NJW+5:]FJOU26:]2NXP-1"QR2\=5*2=U.6B.1?#U'ZN9Q[70Z/"8G4-R:4
MF7,7,6Y;EN6Y1+M36G4[#R6]>+IH.I^5'*L10>Z:,6BWU-%E<5"XQ1%JD#89
ME"T-TQ:SK2JZY5=UR`+IPKIPKIPKD`9<NLRUJQ4K((HMV",?<L=B269#%`4/
MKF",T3X`,GG@#,A8&>WY`OD,E\ADOD,U\A(OD)%\A*OD)5\A,OD5E#P"JXNM
M66G_`,7_`/_$`"41``(!`P0!!`,````````````!`A`1(`,2%#$P!"$B41-`
M0O_:``@!`P$!/P$D=HT?4O3^#%ZJ#.1`_/IG(@<B!R(')T_LY&F3]9&WQ$V_
M=B[PD(:O7V+(=BRK%7&1[PET*C1M+,VFTLS:)49'!]"%18L58X/H5-34VD'+
M^L8J+?R)Q@E]%Z1P?0J2BG[NB=6RY*4I5C@^A>2.#Z%2];87HR.#Z%XV1P?0
MJ*MJJK(X,5+5W&[%D<&+R1Q5+E\KUCBL;%LEUG?.]5BQ4M2Y?%9->-+-HN7P
MO2XO"XFTL6+&TVFW]?\`_\0`(Q$``0,#`P4!`````````````0`1(`,0,`(4
M,00A(D!1$__:``@!`@$!/P%:;5^E_3R"/25`MM46WJ+;U%M]:VU3XMK4^+:U
M%3Z/43Y(`:>P1AIL(=[=[DM8\0T\W!3V>SIX&`YL<+V,!S<"10N8#G$US`<X
MGN8"3S,!E,!E,!E,!=\1]$^B8BS7=/(Q'$6D9`XS,'"3A=.G3ITZ=/Z__\0`
M0!```0,!`P@'!@0&`04``````0`"`Q$2(3$$$"`B,D%181,C,#-2<7(D0F*!
MD:$4-(*B!4!3DL'PT41@8[&R_]H`"`$!``8_`LSFN%1F:J[I!57X%5&'\E5R
MK]$QF\"_,''W1V-6[3;PJK5-%?0K9^ZV/NMC[K8^ZV/NMC[K8^ZV/NMC[KN_
MNMC[K8^ZV/NMC[K9'U6X*KC56G;#,[?2=-_)R(S&1O=NVN1TG1M+&4PM;TZ.
MZ@95"KHL<-Z<V2@&Y3&@U6U"J714I6@Q4A-`X7A6&V&W8O0KCHAK1>4&-W??
M,%)R8!IS#FJ9J%6F7Q?_`#HTZJSN.\(OM76+"`ZFG'>FBHK:^RGI9H\4"LGH
MJ4I7>HPTMM@4*LV8Z74=O36UK0:%&B]4%YWNT)W<].0<0,PSE^3T!.+=Q1;@
M\8M/;!Q-&<>*LL%!H.<B>+M-AY*JLG-T63MZ27AP76Y0UO)JM=/K<5J3AWFK
MV-=Y%=T4&2U:X[E:<1D\?%V)^2UC/+YFBOBF9^M5R>>_PR+VACF$*K(9W#T+
M5R27YA:L?1A:S_W+J9G-Y$JG\0BU?&W!6HW5&<!,YG3B/)!V:/)H#1[]_A'%
M=/!)TC#M'_E7$ME\*Q6.:WBXW-"_$Y5UF5OO`/N*KR24"\5"-J\YNBGO:4,D
MF=6,]T_-BL5>C!$.DE==1=+*.J.T`=E5SP^6G">:,;]EUR$<EP&/DG/DQE1!
MO"Z3([G>%='E;#=OHJM>,SB[NLGW<47'2/C;>$Q_OX.5ZK(X`*QDC"V/?(5:
MVYM[RC:4D7]-VKZ2K9^6:(?"-./U+!.L]\T4'D@<"$*G7&(S4F8'*N2SV7<"
MO$P?-3N=M.=>JF[EHWW*]2PQ1.DM&H`59+&3,^)6LHE=/)SP0Z$MLC<-V=YK
MU=-;_A<LS?+39ZLU0NDC'F."JTT\E>K(-D;RK0Q3AQ"D;S"QJ-&X53G/-ZRE
MPWN3;;B`%01U:-Z+XSM;EK%4CV=[D(V"@&9HY]@WU:%J.YW#BK@?)=4ZR_@J
M/&8@[+M,H5VG:RN7A:-Y5F/6D5N?59P5E@H,\?J'8?JT:/%5:A=>K&4QVV\0
MNHD%KPG%8:[4(Y-K-K7(#><U7+_PLO<57!O-8]-)P:OZ,2J!;=Q.C'ZAV'ZM
M'%7+6%5P*ZN4D<'7J1[MYK<@R4_5;+J<A55UW'#9*I<T\\?HG!@=0\=Z-DM;
M4[Q5>TSODY;EU<8"OTH_4.P_5H?AX#9IMNX("3*)"\\U7)\H/D53*H[O$%5A
MJ,^LP?)5CE>Q:^4RD+9J?B6J`/(9[$+3*_@U5D>V!OW6ME4E5:M]+%OJ@X8'
M.SU#L/U:$[3[QJH'5%HUJJDK7I9YKI\CV=[.*#VYK,372.^%:N36?45?`T^1
M7M$#V<U5AJ,SFL=8@;MR*SDUDD8\4X@X6M51U=[_`/A/M8*('&F=GJ'8'ST`
MZ.Z5N'/DJ2,`E&XB]-NM4Q:=Z8WH@0'5LVKD0[><!N64,;LXJ+)JV6F]QY+V
M9[(6,'A4;YM5]*E#6%#S1::$\$R:"YCCK-4CF^&J8TTI2]3&UTFJ!;`I\E@*
ME6G4:T*TX%N3#]VA'ZAV!\]&D@O&#MZZLMG;P=<5UV1RCR5C),E<VN+BJ5M/
M=M%1Y2W9V3R3'-EH&WTI5%KG5=3$JE1O'U1-UGBF9/%?Q*L^[2B+71F7)]Q:
MM6*;R#%U&36/BD5O*G],_AN&C'ZAV#O,:%ZVE<X*XJ\YJ&\<%:R:5T)X8A7&
M"1=WD[?FO:<JNX1A686T!Q.\YKEBKW+;"U'`Z$?J'8.\QH/;+W4>[B5T;(F=
M&V@-&[RM:%GR"M9(\N;X'(L?J2#%I[&I0=W49W^\?DJNC?([X]Z'4-IOU1<O
MQ&3:CFX@)K_$,\7J'8/^6@ZMS9+P5:8]P)?:-Z`;>2KQJFE+^54V5ETU*ARU
MMMMQ5IQ5IH;#'Q?O5796X^E:N4RA58YLPX8%%KA8D&+2JH95E%"7&D3#_P"T
MTF1KKZU9@A>?]-5M'_356?>=<`HX]X%^>+U#L'Z%B3Y'@J3WQ[I`AT9!0!&"
MX,:%.\;)43)=AHM4YH-C<W:K?@KF-90TU<$WF2VB?7<ZBBF9<]/LXV%DQBLE
MT6YV"=7%[K1INS='%ULO!JZ?*C:F]UNYNA#ZAV$FC0WA6HBZ%WPX+J\IC=ZE
M[5E#;'!J$<8HU-GAO>S$<59D(J/=>J,%PX(VAO59'M"#J$9,S?QS%^1R6*XL
M=@O^G'->TY27#@Q4A8&\]^C#ZNPET.).Y5;DUW,KK\GD:..*U':'6Q@GBNKD
MG9Y.6ME&4'YJMBV>+S5<L]ZZMCGGD%7\.?J%T<C3')P=H0^KL)?+0G>_%NJ.
M28T"_;>:YK4?5R>)J$65[]E_'-6JO6VU;;5<5CF$<0M2'<JSTD?B!N4;6V0U
MW#<C0@.%WS5H[;<"HW'$C/%Y]A+Z=#IV]V^YW(HO&+MZDLAWO5^JP=9!=O3X
MY6GE5.C=>67)K(Q:D?LA,&5$RRO]T&@0D;"UHYKNF?15A)B=R7X?*OTNXISC
M@%%-9<ZV:RV<:)Y]RT0RO!8!.NK4U-4,E@O<<>2:QN#13/'V$OIT"'BK3N5K
M)-9G],[E9?6)W!RU'M->!1MO:7;@$^9UUO!`N\-RB)CZ6$`ZH-+TZ.3:OH.2
MLBT`3_A$R;1N4--JJ>SWBVB$#GEKFW%M:(`4:T<UK25/`*D+>BA\15([R=IQ
MWZ`\CV$@^'2I*QKQS5P>WR*K9+S\1S"ALR-P*LY5"[U-7>EOF%WU?DJ9+$][
MN*Z?+-O<S-:>VCO$%?),0JMB!/%U^DX\&]@44,UIR;>R&ULVL2K43XI?(JSE
M,9B/$X*Z\:&M%&?TKN8_[5=0>0T++`7.Y+!K/,HV'1R4W!$4LO&(.A,[D.QD
M'Q9\G#MFTF".0$N.HT"]-)D!93"F!5B2R:[BNDAJZ#>W@FN9@<U,3P"U<G>K
M\G>J/JP_$%=F<2;,3<2-_DA#"6UIC7%%Q>^AW!RVMU,,?-0EN+KCH2.XN[%_
M._/1G>-O:J/N>VXUW*Y'I(Y+9[LC<J2"A+;PIH]S3<F9,PTK>X\E&R`!I>ZS
M:WJ>(N+A&10E7\MRO`<T\0FAIKD[]WA3W#@FMA:UVK?7%6G1Q!M@5H/]OS%S
MJ!'*Y+FBYE=^A'SO[%C^(T+=;$WB"]HB+V>-BOF+>1:NCR6LCRB9.\?>>2$I
MV7BE59=Y@C<C0EQ<:N<=ZH<,<T4$5[JIT9WBBZ'*ZL(P=Q53E-?(*SD4+WGB
M4)<O=:X1A4W<,]%&S@WL;7@.C<M>&,GTKJHV,\AF+)14+V:1LS/"[%==_#B?
M):G\-=\U2RS)XU6MN4^_FI(T.'-5_#Q_14:`T<KM&)O.I[)S#@X43F'%IIVN
M*Q["2<^D=F,I;@ZYWGVE!F_#U/2*_2#&[1P3(AN%_9OB?LN3HGXC[]G9@=9-
M:J-LCK3AB5T]@=)Q5VE^)E'H'^>UJSOF[//DBUP(<-V:[L<%CI6W]PW'F@!<
M!VUIFI-QXJQ,PM.:]7K:5TB[Y=\%WX7?!=Z%>\+$*Y79@^>K(ON4&1BRT8`?
MR%F5@<.:K%(Z/EBM6=GSN763@'X0OS)_M7YD_P!J_,_M7YG]J_,_M7YG]J_,
MC^U?F&_1?F&_1=['1=;/_:%5K+3N+O\`LS__Q``J$``"`@$#`P0"`P$!`0``
M`````1$A,4%181!Q@9&AL?`PT2#!X?%`4/_:``@!`0`!/R'HC,Q8$@9X";"1
M\E]DG5+XA#D)[C3K/2>LD_Q?69D#'>*'.J[GDL"9%>TN_P#**(I\D(M4,9\O
M\"U+AK`\3;#894[B$^JOL$H0W"(,#M_?8Y]/QZ9B$=PA.08'I*[C'/L(E@;D
MK;5<ZO8;)F&1)N$Y^J_GYP7N2*Q!RG=*+U.PU-K_`*-&>NEQX0U[XO,$8N8-
MV_:1&%-MV&P6O^V(U<#.?M%HJX-&-Z;.1I,5G1I<=5M9&YM;GA;F$.S>[HPK
MDF9_./67U1>G19"6(E-1'`R*;W:6?\%-2G*=IK'2.C:SLPL(]&W<F,D]25MT
M^0T$=FVGEB-KI%]A93<9%\Q0E*-&)X-BC)2#';O8]^D$%UF7"6[)6R^9D:9G
M8\:1S`J7\^_,-J<6+=R^CO*S1.V+1OJ+833?G[1N-#B"*Z,CP2:,3:/W)D1&
MYVZ9%<W26]"!(V_T$/?R<LA1A)D3'9>#ZL4OYW'#5?)[3(+"13A%E<S1UW/0
MLY'.)"LCGRDLNS!NG"T#Y$T8IED7,Z*TBY%WAE)3ERFP69]E[EE:Y*TQJ&AJ
MF$RG?$81W-1MM3R(ZLQ*0V3NV[RV%!1^Q(,Z)CUIWD/W_P`_G!O&7H_]%H>'
MPQZ;P(0*2W]5_1/_`.<\"+I2MF,[<96QD\DRWJRSSRW2;P/V]#$A:7&XZF9O
M<IQ@?A1!F-$ZH8W_`.,):W1IFD3UAC(XPRRD(ENRC[D*:+AJ?!22)-(GDBW?
MZO\`FOE5[#;6FVST9F`FVX2W[(:BDWT6B$8)BM-3*)1T5Q>.Q*/P>1>!,DDB
M-IIB=SK<-J7^CW9;<B""X"786T@O+ZD_8+S(OF2\FQ*IU&[5HQ]\D(7*ACL(
MBD33IHO"KGH?H?+'H98\9*]OYR-^ZZ*QDN'+?0CJ0U+(@FF#(9_?5>1HU'C?
MJAB?,;H*WB4MRM<L-E_KH]HBRYAK8H;-+0PX,1T8_.DU^F?8YKLC"&T%2&2Q
M*-)V]"4A4NM1L6%)"XB0MD_FGT[,:#D,L2R@\7N)PF6'@T-HY]T*<=O<+X^0
M],W8B6<IWL0P<K5YZ""Z6).9,$G.$1HAJ;M)"E=V1;0)"78*QM;P,UT#GN!Q
MAO'<D\U+_@+P>[>Y1,YJ0C^:SVOPQG%%4187HQ-X&6R+IY<34H7I"<EX]2#7
M0NDX>E>=P;QK?S@Q)!>:<)K80NG>*<L2FSN>7[%5."#`Q$S_`&?X,/9\,9T+
MHRB!H]4>PA3*Z^M1%V[V7H&4:?06Z'4)(J;U$>"8)NMXE'1G'>BW']2VR!J]
MC!N:B@K^.B;-'^8[\BZ37I@8E/J7^#XGPS)T&@_`^()IY$%H30T38W$B2WI)
M?V*?2<!_IDC`\_ADN<_+@^J&C'PVA$Y:9/+>%C6`$3E^@IK(TQ#--SCT(1%S
M#&Y!S9)Z8F+&^QK^#XGPQB\#I#HE!+3*\:4PD3-HQG'CSH05^`QBBB)K811W
MB02A7![HY_L>3+F218[&(EEME)+ULVR2+'=BZ6-%8O"[QBE?39(M+1*Z6+/M
M-_P7\']C^0E(P@=28%Y0IZD7N\51"@+=L>5*V:0,3IRTD-93*V&A+@G,90A#
M.$^`22D%G'84HC'X#%FOI]OLA&WYLLB,6L>PA*H3;6K;B,Y4LK=A<=S`Q/K-
M_P`'LO\`8_F)7H:Q+QB\AK7#I";M5>6!,SRFQ76.2G:F>DFTD&`N'`]KI[V#
MHV);21MO22$IFU@12U(;E[!S6L8P14G!IM,@ZBQ)ZMB"*KH`@U:7K#W)Z^,%
M-@=:G^N1WA(P,3[C?\'M9_?IMSDR)VS"D\E(?EXVO"2@3PC%"VQ-2D66*2_(
MN0UR')/(?9#JF35=2&^=C<E8PRKG00Q.IP-QPTSU#2Y0FIM\$V]WX%*?T6KQ
M&>R4)+01CT/NM_Q8+TL#>$B@B^593=N_T-9_!D1D;"6(3<M<C`*#UE71I.2'
MU"^Y(]9H9?<8E"%.J!Z_N%,Q+EP,K7Y&!]A8S3H?3;_@7^&)Y+UY@]PNI92&
M',U@?L362LOHQ03Z8P14,IE$*2.CM2/K+Z299,0,0ZN]G'R.0;!O(OR(\LG`
M?@0GJP9@S[+?\'NOET6Z65X.3L(*<DNHE1<R%.RD=IF^3)35`_EJW9]Q]:Z$
M8(20OO/#[[$>.+*#(9S!-IG4#.@0I[4DI$#2C:7(4TV'$.25*H&7RWR@2U;J
M&9)\QUW#,67^M?X/B_)_;KM*:RG+$(IXD*\[#9Z$=/,$D,HG/*4#+4]1Q`J.
MLCR6=7C4,1V$=3DEI0J2889(V$(I\\9<,R(8'CAM:DCE.20U7[A%L+7YBL>"
M):W6MD56RE<7*%_1L=L9F$^EK^#XOR/YD.GL99"9E/`V;UM\!8RK8,URULD8
M$]WN)EPMD+RIUU.1*V,@RD>Y9X'5%;F)MDQJ9+V#[<"7.9'+@NHE/86^W.%Z
ME@1G4\C->C,6[7\'L%\HIYCRI)"JVH26V*@6Q*9=["*'L+)0^-?0^YZ-[K/2
M7(9[=9!K4NU.EM!JBDJI*J$MB([$@=5J=Y<_L%T&+8F>"A'349A?PS/GZD>;
M[=`_<L6V%A>105IL>)F@A;AHT10FL,GO93@9)+0(;1Y0G/6[F*7V*\,J:,)0
MQTO%33E\"E/BS<%K788Z.%=$DU[$Z@5>MZR5PR)T-1<LP,@GX%61?)UTY3T`
M%<%).6B&1WAGA[CIU$B6C$%BAEEC)+>W;@GNJ-WDL<\HN2T9#B73?P.R<;UZ
M"Y"V\.#H2)&^^#T2X&C3>J;XD**%I\$5&BTS4L_L-H@[N?(=.07L)^'^!8/(
MR]QJ"Q8U**0VPQG?=+R=FXNTV3BBQX;LHR/+"FI<B3;(EKR*-ZU_<9PDDAR+
MNH7Y:;"(U'H1%V46`^*%+8Z"P_V`W79%LCZBE!%0N^C1YUKC%YTN'1S,3'9G
MM^!.8;X,_<G")"/)VP(OUR.7:91:@O(AZ0DHQ&AQFC&\BESB>.U:*K?BF',]
M:D364+VNX[._&L-GHM2CU)%#/>MD/CJR$^^?G\$R]Q8VSZZ9Z$AC28G]@3W1
MTVFH+0YG6ED>1;;2#&MR7338R^<H8;WQ7"I[1Y$0]#9"H052T]IF*V=9.L=O
M:CG+I@/3/`#[Z?AXR;Y+46"\LV6\$JZ$&E6Y-G+L7J21ML\ILL,TLL2G&,@=
MO'!+,D?$%U%XL]&]!*;9P.K'*6AD-L$][*TB/L[BTR1"<2GL23M@5&DSW#=L
MAKTQ&R/:;7HO]_#XT]A>B9!@J8G[O8>1-B!+X#\(+A%<PV(+4-9D0WPT!;4G
M-L2QZ<$)6G?]A$44S+M8$C4VF6&R?`@KFOQ)S(=H86&TH)[ER.BV(&1X$DV,
MI1B-Q4+E)]PP&H:8#WN?N_#%HH_3_I"9U.%#9(T5:W<BR9RDL:[H;>#8E(S9
MT&S8D-IOZ$N6K6I%AB=G)%M!,%M&J5:9#EZ+0\1OHQR>_)QUD$I!QPX/&<=,
M386<#R81$DE),+IH&B&CD2_#7<R>'70*$AYZ)>H>3O9H-I:;QOU%;LV`J]5V
M&?`/ZPLQ-YD2)_<+*LLRX%$6K-ECL=SBRR#^$G,A5QH*-1]AB),GBUZ!61^'
M,^1DWK(@K@7.)3TTZ,R.Q,E39)ZLBY8U+3U$Y$!KHY&016S0,#K_`*_C8LXX
M-/\`1&R8DV+M$YZ2>1LDD6)'&BLFH3$8-!BIB8,#+HZ$+HPIB-9;";D!M4EJ
M]?Q0+3E,?Z(;OKANB%JQJ*6(3(E9%XH<B5R221(X]TA/B2.IHW&49BCI=@D(
MA8U)34;I@C\<$9DI9;`VQ!#;<D@4$EH6]$-Q*^F(T&-31#P*IT&=I,U(Z2S:
M="8EITMNV$$P(26B_+A`_1)\>X;TAZ/LR!DQU&DT+3EY-L^1,T+R;7J=`W/4
M'^P"R%Y-Y&@2%0:W<5WEPQ493C0?^!KVG09I5L@AC97!AOL3(AM]O]GV/[.?
M]]SZ?]'!^NX]KZOV/_8?L_ZT_P"C'+'=2_T/;GP_VL?>L9_^,TGD@C^,=(Z0
M0-2O_F?_V@`,`P$``@`#````$/.F=KQ;CSGR0_&'?//*E/MNN#\.&BPF.///
M*C!-`XV,1Y^NE9///,>%G#)4.94),H,///.H2)O=,##,.]\/////J(&'(7,.
M8;W:%///*M"%_420>N-\.////+M)/C/,+,)']%/////@)&:%$!1'*'`%///.
MB"!6*$PV$"%-////%H",2=(T^+$,&%///`(!#=N&`&#N&,-///%2#-+A$'$%
MD9`%///+*/*@&.07#+U((?///(.%U'-IJ&$R.!////`.)+8)]]#;%.-////$
MS(`6&/(#=((_////&(V'005`/??E//////"0A--'>LH]_////////'/+'+#+
M//////_$`"`1``,``@,!`0`#```````````!$1`A(#`Q87%`0;'_V@`(`0,!
M`3\0%&D&A*CT/\/J?8^I]SZGRGV$8W90=M\1-8/XK7S+"JLTZ`)?A>1^\5B5
MZ52#,3G#311<0HQ3(-/D&+!*IS;&EK,3$)%XBWC_`$.O!\@A!HD;17@A,%R(
M21B272$>(BLK(+1'A](*L018JZP(B8C-XA%U`9$Q1'DYS/'`WBBL;-\SQU)S
M/S*C\XJ*L5%9\<TY$(^BDRJQ&1XJRIXXZO"+*R\0A1!<?[A<J7IGL@*/<*4J
M)+@C8M<Y2I199916"2_C?__$`!\1``("`@,!`0$````````````1`1`@,"$Q
M84!1D?_:``@!`@$!/Q`E4$W*3IHC^G@>1Y'B>T]9XC9Q@@(B40=,.Q,DH%%<
MC+D7ZIR0]".=0!Q1Q9,S/0JEA.SC-Q&A%8L&,,+2&(8QTZ+2'2$*1"T'8=*!
MTPZ8LW;!8H6;M:D=,<4Q3F[8*D*EK&'2%3'K*E(II:S%BAZPIR%H2HQT@HI"
MJ2V"QEI%@I^00&_F_\0`*A`!``(!`P,#!`,!`0$``````0`1(3%!46%Q@9&A
MP2"QT?`0,.'Q0%#_V@`(`0$``3\0_A)+V_)D?6=$FXZ,WBQWT(/C?9/"&KU4
M<&`&3UFMFNUY_@HKK_"\7+0:ED;?PN7A.(M3>IA+BE6^^)7R3G?L3*HR;G,L
MLL'41?NE9\QHA@+"T+]'ZD+'<2=D(]&I737)#4+ZNRO;CQ'<U!3+S?%<187R
M8]'$IG6TO[SXA'Q'5:Q^]I_QWXB:BNF/X@M'?[XC1JCO(%&!W_1-W'];3]'^
M(-_7XA2VK?WM%?Q/Q!_A/Q"V_?Q&E]\'XAE?MVZSA:%M)JOJ?1LPN2TNLL`;
MM$(,%PZW1?U5BI6`9]"?Q4O<LT(**&;OS&+M%;YJ\MX0$$<E.CI*-)3J7UE/
M+ZQ*V/24FS$8OS=@$I(MU6UO.EL>P:H$;U:!Z2FR[9NWB*=86;<XU<<5`O&H
M0"^72!C/:0;IWN6P`OL4'%=X)(0IIMX>(%-T>DSU]92Z(>\%=JB7PKGAN+@.
M=]H#F+"SR,&TK24#O%@Z`=U%^WUHTFSV1^(HHLU":]660\-I19T2Q&S.2,$Q
MMP'??M#&/?:4B##`:[ZHVK<[QU407506](S>66M7B",E<%JTTUVB>8A.PK.(
MV$5<(;^48`JTUK>M0<2((8`X.T%\(HU$#F4AI0RZ&\YS$..4;'OTC;"+N%H'
M0XTB9B!I,5C-<U-P"7"[H"_CZ[G[;W`/S*PE/;'ZE%,L=)0)92UF$ZPLL)]-
MR;O:'O0B"R]QV=I<C.J41U!\;RFU5;US!FRI:]>BW)+"TG%)45=2NHD^8@W0
M-KAO6+U'HOXTF3=?*VQ,-IC2I2@WW-(P!OG2@$TI<4?8=6X7,,H97R;O6!9B
M^>)0M1*U<416/DP4K&WO0?7DJE':Q'`#3Y6:PV86UP[]!FUC84L$#F2QMK*\
M"TWXJ-8*@4*AMEC*<V*)0NL4L2!5OA"N9=RAT2GVB$J45;IJ)B3N$GHEOO+E
M;J63RS?I+4N%L]CCVFYQJ/`9E@`+B<C68BOG<#!D5='WJ>T,GT!#?M*DXKI/
MQQTTE\TQJ[J(+HF%:/66"."8`==(4C5SU,%+9[&SX?6FV>9!/93?E5_#OYBA
M8M5S9S&3Y'9O!!K"A.HMCK-NYP4].947BX;=(>%ARPBE<``L4M>WQ&.LV(0T
M2WZ10K=2ZZ$LR/0H76H]G0X6Z34+32L5'^+A?=@;5N^BN;$2Z`IO5@W`C22=
M"(W8FK<(RTT$\IN](=4)J,T=@-XXUZ.WD:COF4=B'O,@NM[Q:+5>L?GZ\(V]
M</Q!T!$M$^Q*Y.QO0@YR9EJS04UO2/MM4428HB;(ZP&/+T%<+CO<6VEL%U_"
MY4[&B[_?VA(4>S[W"2O^@$'R\1:U0Z=I9M#Q84-_P!:P@\.)7%F&Z*UBT%4#
MS9]ON1$=&S')SBI["K?`Q&?M%H.5V.Q%$"PM+]_W;8?;U1J.H\^9G/6N[MNR
M,4&2]$U.>T61RW<VC?KAKQCYOQ%%%+PN(&9`M!4KG"Q@%`681-"5$61U.O4C
M5^C$HSO*[8R0\^B7T).)I70$WR5'..[\*^[":IP'</E%=H7A>)9H0'?8)P@V
M4%+R01RJ"6+L::T/2#90T?/F`S&*WN_=\L,!"J0'%0P39UED[82D:G1$-EMZ
M<XYCK9"AH'$9YG!-F:'M7UE=P?>`<8EX._3CM!L[#U<(`:%JK@7^8>2O7('<
MVE&=4]1T@/'%&5'I'*EW.M]-)<?.?-/O!!6ES#NQ34G0G1ED!THH#+Z]0/8_
M[+(A%J\C[)"T!M6E\PO9C<$TBERKCK%6.P&9<$+>X<.T6:RK8C+_`&0,\QW9
M>*S-OZM0(`7M[?7<^&A39",'4#6U/'$0ES:SQUM`@@Z`\;QB0<W8>E;1@X'#
M>$[P<Q:V,?JJB]*5CXT\,+&K-;-XK:HD5BD<@CR3%`:3H[$U&H/2B@/0E38+
MZP8FB%>WYB!AV;7H;18%(M;U0?9V`:]X<>FDU.LM/0P<?6"[B`X-\DUI<W+9
MZZ]8V'_S!_,,%U;%T^-_,LPT3]IUETI&MF[J?:%D9V*>/UM\QDI!F@:IX9?5
M:^SV8UE"MFM)9H:!PU_[$NJI[1J00Y::;G)*'AZ`6RW,H'?!T@%5G\QZJT*;
MY10LBT9P/WI$[+&'3J=_>-H5;"N/^>)B90<ND:Z])./KS'2!=H;0UE-G2.C*
M$U+@6J+O\04HIW,>\K@DW;">2,KD-V^1B8Z(`UY?E'&X4-5O0_9`^@2H?4]Z
MAAP*\JY2_,3::Q8G$0@\V`>RS/-2X5H2D=BKI$`=[U\7'J,K&&I';P$4'&:Q
M3S&1QU3M]HRC1XR0#I7DJ)4/\8QQ"1Q_0!@JW:CHHRS:4<Z+NCM7,#!_<MR@
M:E0\LTT9<B;1H.L113"KIZFI$-$["HO8WDR>FD5>77VU\W/5ZC[5!ZHU4O\`
M=0=9]Z7D*'R,*DF^0]".<SWKVTE7$`4P:?$NWG*P+T"%V'C0-_VI>;;6:6PT
M[>$19]'N(8$,2X@X^O-O;[`BTP%T'6);/JSJZ-\0>P_9HLX':H42TT!KIJPT
M1<J`9S=TW3684X,1O<)48#![CAZP[08LS=G-[1Q9MK]/5T/6!V2U&AXG2?=K
M]H4-'*/=A9JR*]DV99J<OI`^/IU7N[6[#E;RC:[R]X=/24-X"+TS&E*-ED-2
MD:]8!7BHZ=)=@NQ(9!Z1W6:W6"SY*./K.;AOX!EN-8ET%]H4X/L"Y=9@Z='*
M2BEU.I!J3`@\DEV`0%G@3#&CYF*W95IVC4@H%`!N9C""C2[1PSD89;0-'<J8
M@Q@=3)VAMIY0,!.]LUHFSVM\3K"`GJ<,8IR[Q9,L:M+J+YN-%8CI:T`OO&K0
M4I2*!/-1`Y%-"*5@,/I"%G0-@V"2*8`4'!L'V@US6Z06)O)Q]8MG;W;_`#',
ML&*YB<D<,`<]8MAS+\/X-DISTHK/X]XP"S+A#C)5\1V"2I;;"T'I%>":19L=
M(>2`Y0W=(`IZ*2\QOYBRM0@6Z5[33U+BZ"B8UQ+$C@3+9>)I%'-'EX.L27ZS
M@JI?CT(]L)RYA/MBU+/08.P3;<2^!N]9H"@H10.`X@YQ*8D%)Y@LS]!^9Q]9
MOI)''E<)+G,JP33>'LPEVB6AZVCUJ*WRZ,7ZH(+AW>7QB$`(;*IZ0PK`N^\.
M_-%!W2\EK:^B7?O*&K-P?O*U,<B[WQ$0MUU'EB#A9;V>?@*.D'!MITE#:]C5
M]^8S4*V,I55R5/>5SDM5^=O$*/&%L"*\@U'E#ETF77+V?B<?6'8^Y4<P4+3B
M9MT+B35-%!MFM3M47!WH5C$UMJ](*!=D+LTBH[U>B.,F8*?',53!2.3I&V[*
M4`'QF)K57(V2[T(G`7%,D>\U:3%5KVBY@"SKYV[0F;JVN'E<L/TS7)5&BZ/"
M'%N*&"9?P7*.MZ$V%S0'9AL_C"SYDX^O/I)%^ZIL%FI8Q7&GQG7OCY64BSE-
M[--7$:R``%V+/8@\(%2V0`D.L%Q=(PQ:44AS!^&NWCH;]I4%IKB='#[I``RM
MNGI5P=X0AAS>(/:,TV!UNO:<!RBG;F+W8)Z$)@&@-=/^^($CY@)P"UOS%,A8
MF3-4;<^T)T%JH%-@TP7Q4S3G5DM"MXCVT#JU\?PPD*>S)Q]8OH+](6JQAA-J
MS*Q*33%N=8QO&U->DS&\OX=R]$V8#J8!UHW-;2]DP%U055QWA58UXD(HXHI=
M+SI-)8T06,U$H_\`=]5*M:ANH`55@R\&95=8S.D!D:(#E6>8,^(`SDN%E-K,
MHJW7?.\T$X)J=JL$;&&%K5B;G[Y1ZUI"`N1.K>\#(K?/\I<1)Q]9OH"]GYB@
MD+=91C&LH!IE;5B;%NK7<9>&EW&`]:#8'W(.&+K^U0!&89^7/(>8Q0%-IRZ=
M<S*6Y**5HZP1191*RVT#+*!ZTJZTSC2+-!45'I$E?+6O=T=^\Z!585BJJI8^
MF:]QFIF)S7<]HN=6>=+?B)*LH,]Q9])T>DRX2A?2.%N1;Z-SCZQ?1:#T(>!I
M5[3!]4:QP!]X(8ACIG9>(P[I_/43Y?5&_)9)A*X+S&=V^\!&@._L0:SY@T>M
MD7V`:4!+]G&@L^(2%71:/L>T4%J0,!NH(CT.ERRI;M>,?:-`S4JH[\1_6M$-
M^6/>>:4+[Q=I45#V=Y;K5.M<0X_A+*.#Z3CZQ8]+Z(_$QJQ6IQ-KRRH%%AI1
M:USUC-1=TZ55T*Z;,&LR6N1H8T<Q=#71XN:P8=H!BK03IKLQ"\<@P/P,(,"-
MTS$PYM"H@<$GNPL$GF/^>\`&@163,JC@)VNH-['5*EZV(%4T<M"E7*2RY*35
M%@QG#37TBF<":FJTJT'M'N)Z0OHS1B"\S7Y8@A0W9/H+\3CZ^HQ,:+I#Q#>;
M:%0<2M2XRL].LL:6S@Z'R^8L^X+N@RPT:.D;.JC)Z6O>5V-[[F6P6[OBHV^3
MCEY/6.LK;K?V!O"OFT;A;:GM<OT$(J5KEU[RFL*H:V:U@KKRD:NI;LTA%IV^
MBA)D6P<T1U#OQK4:TW/M#?\`T0,#-S6#TB23J`!16?0Z1#.5`Y;W7&)A%8+U
M*NTHN,7@?,P+LE8=T'Z0V^HGA;\%S!H9)H[RS7V2JY)[#AFIMQUT%L@=,KIK
M;WY=I>)2L@OEFLRB84!<Y=H[@5"JG1$IZL6C.SJS418^"BVM1(5`,[D#>)`Q
M;S3U^^>\.IPM75;OE%.D:P<P:^DQOO*\BXP3=`/%\/2HQ]0H!UUUB)+:/9\R
MQ'00E.AO"G1-;*\N)GO"JJCJ#[![X/NS;ZJCT&A]8-0)$MQ@S20VT>\;&Z'G
M2-VHU]7_`*1LN^"/49K)X?$!<X@P`H'!$"_JF#>STFCD9BIPU#B4W857XB-T
M&E-"ND0%X!X%%#1^=X5;U!=OLEK7JMWXJ/F;OE;;VB'N!^".`_IBO7'M%!;"
M591Z;>)C%R@7%#_KY1^8?7=NA3U*ENW:CX:C@'>+DL5BIWOB/MBJR$+6FG:.
MZLES`76&W10Y.S2!.W!I+2@JR0/-?("194VKD>A$!,FZ/NN4?I<5\E,KJTJ]
M?^RRU*"U(UE*U]&`$33).*&O>/Z=*/'&EX;V:G(B,GGJ?Q6,5&:F"SY7X0_H
MTANG?&1[0+UTBI>9N6=]$;IZ,#Y>P,T'0CJVH+.:N7+%1U`H;'`[Q#=VVNI.
MD,L2U%1:E&JRSJM+UX-(;8+HN0YS4`\LD9#K0<^LN+@[%[Q)4:982"^&>OM4
MW8VAC`UJC=O1*AM03F!JX%4(LX&17EU8(O+7@BK8X[14NDK!#:T1V!^Z_IO=
M!8GN?FY05S3V)3@BCH%=E[P0@%$9*MN=YGSJMNZW>-XML$-0K!A%WN$[R^WH
MN)FHIG0[$PFJVUK7#WN4F!V*O7+1::C;4$P+;S7F<%"B+COI$>CK`GKF4@9/
M"#Q'7IP^=(E?A06.HZVA8U0PEVJK$"DVK?3V@,P45+`8XP925XS"DJ766@W:
MFZIN=Z'L3;^BMC47J_P(A!MS$-<PR+:KO?,/6\=Z#O`VE3']"51MM$3%<1W;
MD;556`59CL,/*7N9T(&`/5`1B]\Z(7%GS*;%U:`70:2M2(/0$<=IL!OL)4*K
M(SZ'^R]N=6OGO+*Y&L;<=B-W.EPIT$_V,'_]&WO*T!F+#U;1`?\`I*#@Z15*
ME6TUDM:KK=$`HR,X:S_2[C8W^C=/2-P9J"V+@U:LHNZS`[M!VV])S`_)=Z)T
M"+OD'AF$I4TN7`QL,+RN8I`KBA3N_,HP3JQOV9<7_=U^Q%!8JB_4MCT:6HI]
MGFXF8VC3GE<<SH5VB]6="4P>A43=K57^Z^9<U]T,%X@*LE"D?V+B4Z_T@=:"
M^IKW-8*]<0$?Q&I2`X9E2X%%D:`9MB6N'I%BS$Q:C7F&UFM5<?4N*:J5J?"P
MLKJ>9CJ=N$!!5X9S:2L5#L)GF/8OO`R7,2$S'<Q49-S+]P_JUUFRCDJ@H7U>
MG6*:5B6P5UA)1;Q*VF(MHT8EQ"[KB*53"&C`$X3>+46&[@V\Q6X!G)K#H]MS
MJ#FH0!;RPUB=3#+-)27B:PB`*FZIT)<$J`JW5_52`:M5FCL.I17:(;L"T-KH
M1U6)<@]X?"U\0JX,5E.8NI(LZT@7>57#+-'$&%=ZLO0A=+],-)AK6/II=;ZQ
MK$8E`M26-*-H@)>T2E:B]9OND3)6N7.TKS_64T76X8!2P'(G[,I#JBDX?[*0
M(4I)6E3+H\,I7`/,+Z8`H5@<5YQ/%YFP^\T?+LO-/;2"J6PO"[(-J-KO%"F1
M#>!VC!5)+E+EA;TED%:TX_/7CK#S@&4!H']J'(U5=XF8E%<'`-?%1<A87(>@
MS<FN=X-3/$'H37N5LF5O5[F+M%W$-KRL!^*CULA]03%Q\E`,(3I*PJ.@NKEY
M\4*NT.AUE9]04?Z_7^^J-6-2)6179U)T;*^VT?>73]MFL#-ZU-7=2;7TDA?F
M1_T4=8^<.V'G"8SF?>!V?W.L_8/F8U^RXBY-O7Y9\0K3]%"\4'M*8UQIT_\`
M%H@>\I$KFW%5M*_BB5"F\)7]('64E(:#OYE'_P`O_]D`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+VUO8FEL92]D:7-P;&%Y+FIP9P``````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,C8Q-0`Q,#4Q-30S,S<W,0`P,C0S-C4`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````_]C_X``02D9)1@`!`0$!+`$L``#_VP!#
M``8$!08%!`8&!08'!P8("A`*"@D)"A0.#PP0%Q08&!<4%A8:'24?&ALC'!86
M("P@(R8G*2HI&1\M,"TH,"4H*2C_VP!#`0<'!PH("A,*"A,H&A8:*"@H*"@H
M*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"C_
MP@`1"`!X`)8#`2(``A$!`Q$!_\0`&``!`0$!`0```````````````@$``P;_
MQ``7`0$!`0$````````````````!`@`%_]H`#`,!``(0`Q````'T>NXW4RR3
M9:IE50SI-C.AV&4$EP><9E.V,D6[.*YUSHEM9-6V,<R(H8'H!$LBAEAS*2K*
MRJ*HRRHFM0GH3`]`4!T,42C+SRTU;+0T54KIS=RD71=E4DHF!8BR6)049H[:
M7,/9/FKEL6IZ(6Y=.=9CM)I-$(PF:11VTU.G-(F%<NFNZ8*H5,<S)FG263"7
M2B*FV$OFMNE"H:Y.AT9'CL*2;6'&QL*.DBMIMI=AMVPEM9=LEVVVFVTFPP[#
M)L;;;/\`_\0`&!`!`0`#`````````````````6`P0%#_V@`(`0$``04"CSAF
M=@C3(?\`_\0`&A$``@,!`0```````````````3``$2`00/_:``@!`P$!/P&'
M5X*CVX"\PX'@I91__\0`&A$``P$!`0$```````````````$1($`0,/_:``@!
M`@$!/P$6WA$]@]PGR?)2YO'_`/_$`!00`0```````````````````(#_V@`(
M`0$`!C\"#O\`_\0`&Q`!`0$!`0$!`0```````````0`0$2`Q03#_V@`(`0$`
M`3\APN:;RYG)OV;F&ER,#>8XR3Y+[YY<]I),Q!&<C.;S.3,SC$1Z<\LS.,1$
M1<CSR9F9F<$1$1$:S/@S$1A$1&,S.,SA$81$,7<9F9F<(C"(B[G9F9F9F(^1
MA@8NZSC,S,1'@9W75F9F(A\]N^.ZSOV[%WUW>YV_<7"^?P-[=\?,_]H`#`,!
M``(``P```!##;WG94P#O\J%ANN(M6T#_`,)+=[UV)S4^H`>OFA%!BNC=RLL]
MN#!A&3E<$L7Q=:(@'QM0N\C_`(`0P0'`0/_$`!H1`0$!`0$!`0``````````
M``$`$1`A,5'_V@`(`0,!`3\07]E++;>PY]@1;,I9;8;8MLEELLL\!'D6S/DS
M,1PLZ),D(OL%DDR2)9!!!9;?3;4DEED$',DR>,LL@LCG_\0`&A$!`0$!`0$!
M`````````````0`1$"%!4?_:``@!`@$!/Q#/A""`LD)"3H((7BPLF"3A$$'#
M&9+(B.!"9GA$,6S,LML,,.VPS']2R\/'($0VRRRSPX,-LLLL\__$`!X0``,`
M`P$!`0$!```````````!$1`A,6%!42"A_]H`"`$!``$_$$J)4J0C7="5<-R"
M:I";F"H:F%#UY$'1-0X%H2@DZ0(ZN;)N&B$\(K<$H(00T8-P::."V;3TWT02
MDV]"5=%41A"(:I")]'6($'2_&*V1Z</,&OP@0B%1">83!!$L*&JDOS!%*,()
M1*JB<$J)3"$QL3!!$/10FH)AJ)\%0B%L59&3<'!H()D^O,-ACJ'1UD01$U1Z
M=P3!JB0>SZ]-6:L0Z3_1:>#8)AJ3^`@]#TT$'MC?</@U9A&0V#=&&P8XR/6'
M`Q]HPS&(%!?<(&&0B_3@8;!MP9!BC#7`Q12C$#=P;")1B+3B8)IB<GHTZ,Q1
M85%U1ANEP,QD,Y@S71_W`M"=G@HQ.9*RZ@W<*/8VX,SO1NG7A3X1@FT)PNJ4
M48J+Z-PHU*.%1N^!M-^#'PAQ"_'^B<$Z4J+J"=$X-.E&Z<4J0;JA=0^0OP4_
M_]D`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6]B:6QE+VQE9G0N:G!G````````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`S,#,P`#$P-3$U-#,S-S<Q`#`R,S8T
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#_
MV/_@`!!*1DE&``$!`0$L`2P``/_;`$,`!@0%!@4$!@8%!@<'!@@*$`H*"0D*
M%`X/#!`7%!@8%Q06%AH=)1\:&R,<%A8@+"`C)B<I*BD9'RTP+2@P)2@I*/_;
M`$,!!P<'"@@*$PH*$R@:%AHH*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H
M*"@H*"@H*"@H*"@H*"@H*"@H*"@H*/_"`!$(`'@`.`,!(@`"$0$#$0'_Q``;
M``$!``,!`0$`````````````!@($!0,!!__$`!@!`0$!`0$`````````````
M``4#``(!_]H`#`,!``(0`Q````']4&VE#VD1266./MYND`V;(,E\F-L8RDL-
MK3W./>D!&+$-%\:-L8VDO+>T=WCWIOH5BP#)<_)4DS26&[I[G.ZSX$8L`R9*
M3-/+4EEMZOISNX^A&*\,F2\C81=);F/MX\Z@?`;%B&C)N&O(&DNYH]C@[4H!
M8L@T9.P1W.RCSKFE`;'_Q``C$```!@(!!0$!```````````#!`40,S0"(0$1
M$B(Q1``@_]H`"`$!``$%`F-0>S!_9[C>3GH,;1K:B%(ZA"!;%O@R.HPE;>5T
M"1U*$G;^P&1U.$C;^L&1U/+1&W]8$KJ,I&W]8,KJ,Y&YG=!E=1L$K@^CX$SJ
M-@KHZ<T?`F=2G"T=4N.AH&9U.7T=5>/$*1U7V+HV?Q[R(>77^%GCJ7-Z,X>0
M`7';^!R[@__$`!T1``$$`P$!``````````````$``A`Q`Q$R,R'_V@`(`0,!
M`3\!3TWZ\"7VL7H)=:Q^@DVL?8DVF=B76F=B76J=N76C2PG;!M?_Q``=$0`!
M!`,!`0`````````````!``(#$"$Q,A$S_]H`"`$"`0$_`4Q//C2;;I3<&VZ4
MO!L:4G!L:4GS-MTI.3;4<@VVIF@/PO_$`",0``(!!`$$`P$````````````!
M`@,0('%R$5%A@1(Q08+_V@`(`0$`!C\"M,1!=H"P8B>A8>Q%;%;M7WBMVK[Q
M5J_+'X_BM7Y"PFO"M7V+"7%6K[%@^-JWHCA_`B7F)'"/$6RE+NFB.%/0ME&?
M:1'>%%^6+9+I]].I&7O"#7Y-"%HE!_<7T(L__\0`)1```@`#"`,!`0``````
M``````$1(7$0(#%A@:&Q\$%1P='Q_]H`"`$!``$_(;'A2@8',?TG3@6$]W&A
MG-$]4:D5'T#M>435"?*AP<3N=3(F6I/V8(D2CN=K(GUG71&%1BMWOPFUG51#
MRZBM:Y$B+=BN[)'(N-E(W-G"'?@CD\7.LS&W$E,]AMW@5NUC0U$I]IANF0K>
MRHVJ%IGZ;_Y<6&<_(XD)/YA+7N8_VR$R)<\:>J8\+FDR!M9B#<"'I,D+"X>T
M0Q'J,B<9DC:DP[SS_!2R#/_:``P#`0`"``,````0\M,\\UTR\!Z\\8Q#\H$R
M\L\R\DZ_\BA__\0`'A$``@("`@,```````````````$0$2`A,6%!<9'_V@`(
M`0,!`3\0'MT*0FTJ4)@3C5G8XW#?<N-1K[\#E=V5""Z/`7&!/<'_Q``>$0$`
M`00"`P`````````````!`!`1(3%AH2!1<?_:``@!`@$!/Q":7EO/406[6Z?@
M&_S@4QC-^(4SC1X8-3II-4TM`"CMJ(R(_\0`)A`!``(!`P,$`P$!````````
M`0`1(1`Q05%A@7&1L<&AT>$@\/_:``@!`0`!/Q#3*G?\C4;E.A":[M_I')Y4
MSTP=-<6=E^;C37X3*MCO(OW#=/`^R8:TCV?%RI7(0[YTSP/W'8[P2]:D!^EA
M6^A/;0@&WMJJ)YA@5Q#E';'0P,5J0W-["V(.2!JNP@U)C-<RT0^&.^C-QX(*
M9>?I<,:J=E7_`'O%Y744+G*!B#>MZ.%H8O%C/]0_49,J!Q>M@PW3V4^Y1G6+
M[T&5Z)]3##NI[QMK4[NMO:/4594N6X[(?DF'<@-:V$X6B#:8+/>T?#-AVQ_%
M?X"?P%F*JKBJPI)QA?9+F])[M3FM1LYR=LX1*KJ'(+AW6@^)0IVH^&YF_3+K
MA0*[*+E+(8,Y2\%CW$JIE0TWM?T249E?*-Y__]D`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+VUO8FEL92]R:6=H="YJ<&<`````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,S`T,``Q,#4Q-30S,S<W,0`P,C0P,C8`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````_]C_X``0
M2D9)1@`!`0$!+`$L``#_VP!#``8$!08%!`8&!08'!P8("A`*"@D)"A0.#PP0
M%Q08&!<4%A8:'24?&ALC'!86("P@(R8G*2HI&1\M,"TH,"4H*2C_VP!#`0<'
M!PH("A,*"A,H&A8:*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H
M*"@H*"@H*"@H*"@H*"@H*"C_P@`1"`!X`#D#`2(``A$!`Q$!_\0`&P`!`0$!
M`0$!`0``````````!0`&!`<#`0+_Q``9`0$!`0$!`0`````````````#!``!
M!0+_V@`,`P$``A`#$````=$2N7(\2N1?%Z=VE*FM5NXTQ0J*C]*4,]*+T!D1
MLDJMW'$KCQ4?T8F9Z4.]<#<):K=QXS(L;_4Q(WT8MVZ&X2U6[D!&1I'^I:A=
M\6_:(7-:K=QX+N=D=$=L.^/TE+A[C2JW<=G-%G96;SFGRUTOJW1Q]A_=5NX@
MZ@3NS55S>K=-&E5N_P#_Q``F$``!`0<$`P`#```````````$,P$"`P4@,C0`
M$!$2(20Q(D%#_]H`"`$!``$%`M?L9)Y8-O(M#]XWV(M+6\B41;QE(ZTKQ*(M
MXRY"LIQ*(B@RY2DHQ*(B@RY2DHQ*(B@RY2DHP]VZ?O%6*4E.'0^H)>4I*L/=
MNG[Q-$JRS#HB-_(1$A:7,]2A^X;P)%R`F>K1$NXZCM7'Q]VZ8SO$(U_4-O(N
M\5O$,!WL5'^.^7AF=1]__\0`'A$``@$$`P$``````````````1`$`!$Q,@(@
M(4'_V@`(`0,!`3\!F#R_29H$%,T04S5!3,(*9@=)GRBY/O.U'+__Q``<$0`"
M`@,!`0`````````````!!!`@$3$R`B+_V@`(`0(!`3\!1/UBB/9@PET8,);@
MPENB.Z(;-$QCQFG_Q``C$``!`P0"`@,!```````````!``(@`Q!Q<H'!$6%!
M46)2_]H`"`$!``8_`ERJP_?5J>(E5Q@V;$JMJ+#,2JN@MS$I^G=N8N3].T%S
M%V4_3M!<Q=E5-$$,Q=E5L!!#,795<XLV+LJK[=U9D790]DFU/$7*F/IMJ>L0
MW^CX13L*EK`E>?A@\V>J8_,/_\0`)!```@`$!P$!`0$```````````$1("$Q
M$$%1<9&AL6&!P>'_V@`(`0$``3\A:H0@Z'Y<7*%#D82J1YKJ_P`*3L.*DT&/
ME^KPWCO)G::^S*5+&^3,[)RE%DL[_),SL8RUO?Y(SL,92UODL.T*G:)[A%Y,
MCL=@77R]P2\B5W!Y/I:%A]&Y'@Q:GQ%2$#]WW*]K4(V=,Y@5(0%RF@S1ME=Y
M`ZOLA80-'DC00Q7=?)CY;9%V:"(_B39J!!,Y?Q?T>#%96A'?))/_V@`,`P$`
M`@`#````$-/W_.N-_+O5_.C?_&&?_&0'_#;'_'@'?/_$`!P1``(#`0`#````
M```````````!$!$Q(5%AH?_:``@!`P$!/Q!24^!9'V1B'X7L1B&X0L,0O(C$
M/:BJX+(:DAPQ9#TMD"R/_\0`&Q$``@,!`0$``````````````1``$3$A8:'_
MV@`(`0(!`3\0K*39[#J^):0]EI#W+FEV:.K6&'4%P]AU"(&PPK__Q``G$`$`
M`@`#"0`#`0$````````!`!$A,5$@06%Q@9&AL<$0T?#A\?_:``@!`0`!/Q`E
M&IEK'A]'2Y:YO>\>[F*&MR@&ZIV4V!''I!2,U@;^3Y0@U#AN8J7_`*E^PR_-
M5U2A:,ST1M6KCAN;V5/@["8<;BLC*ST18C)'8OL/43&W`\&P?$.#I`[HZ?ZB
MKGS%_1@V*]/<?<Q7RGK,$/Y&C8P/F+LGF8>6]/QLW_-&QZ'Y%>K]&70W#NWX
M3K95Q_2;#P=?DK3N^C"5+:[Y_28^?*N:^(9?G)T?D"OPO,*<SPM]S%SY6=R/
M,,OSB(A32K3O%&E.8T!^V*N:_9T+Y$,OS2KTBKZ#LW^XK%MT[RWH$57C+LP6
M[U5V'-T@T.8]ZEL/*DT4M]QC;6"PBY+>X=@%=P*]H+V%JT2_`P5&3AR!A.7)
MX+^QF<WU[!-;T)>%VAQ3Z*5MTQELW#ZY$<A27QL?_]D`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]M;V)I;&4O=&]P+FIP9P``````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,3`Q-C4`,3`U,34T,S,W-S$`,#(S-3(Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````/_8_^``$$I&248`
M`0$!`2P!+```_]L`0P`&!`4&!00&!@4&!P<&"`H0"@H)"0H4#@\,$!<4&!@7
M%!86&ATE'QH;(QP6%B`L(",F)RDJ*1D?+3`M*#`E*"DH_]L`0P$'!P<*"`H3
M"@H3*!H6&B@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H
M*"@H*"@H*"@H*"@H_\(`$0@`=0$'`P$B``(1`0,1`?_$`!L``0`"`P$!````
M```````````$!0(#!@$'_\0`&0$!`0$!`0$```````````````(!`P0%_]H`
M#`,!``(0`Q````'ZH```````QTDA$V&]YZ```````````&%#N7U9SU?N6VFG
MT5-IHB;]PSULD;JO%O0])\[]FOJCYKU\U=C-```````0==-4Z8.B%<829VNI
MV>4&O-O(^F7E1\Y,,F;^;A,Z^MT6VS5;+.H;<]Q\WRB_IR%-BP````$'?`V8
MW,6='TC.9XJ--+J^CQTC6>EEY8X8&>&LQHSUZYFD[SG63=O/W]<Z^9LKR1]"
MX;9'3OF.46```-!"V:.?N**QPRZ<LH^^,5/<_+>ICKU'E*+GRG]+;"KP+/77
M8%E$C\T>]917E<\O<,MS3@LIN_O?G?T3GT#-``5%OS>S*XKJ.4Z\YK'3LR?-
M&D@\]VL'-I+>IKIOJ_.:D%Y[1XE]!II1A,F6FSYM\RJ<_<?69>XLJ#]'^>=?
M'3H1%@`.+[#A+C?6R=%\T.=,Y=*"+U^7E]/.RKC.=IH_1-<A&[ECAMO:F\O+
MO/"D\N\2H\MQ3Y6NCKQA8Y1_;Y=UM!\CI]"'/H`!&X8Z<\=1L66T^']AZ3>6
M1L^C=]]-SP#PPQ,8C-Q&;%K3Z_RYT$[\OIPY]0/_Q``K$``!!`$#`0@!!0``
M```````!``(#!!(%$1,@$!0A(B,P,T`5)#$R-%#_V@`(`0$``04"_P`\D!&6
M,+O$*$C#]HD`37H8D[4Y)">_R)T"+*86%%<-<IL$X7>-0KJ'6@H;D,WU"0T6
M+[6(BS93Y*=<F_9D7#/*A1:A4B"[K$C3B*-$("Y`C<R38(9E'?M5'5-0AL#Z
M$T[8P]\MI\LU>DI'6+CHJS&(`!%P"=.QJ-R(+OL:%N(H2M*!W1`<I:;7(6)H
M1W<.;0U-T:BE;*SW;$^*;&9C=O[J"L&]DCPP37O%E34+*9H+BAH5<(Z+73]"
MB4FD6(UG;K&O=#TUP<B`X/@?7D;QWFU;$E62K8;89[<\F*9%D=2N&=\$(C:I
MI1$VO!-J4E6C!5;TE$!RNZ:UZAF>Q\3Q(U6(#DQPNPUY75I8)6S1^S([!K&9
M+6+7$RM$(VHG%I:;EZ)K8H]UNLEDMUNB5NB5JU</CHR[]FZF!@EF:V:+3K/#
M*/$>P_U)K$H@AB#I9NRP[%FC/#+N:Y%R+-9+)9(O62R4\@$-'XNS]Q2/%-8;
M@_2Y^2+KE=A'66MS;O:,6]EAG)`\N:^M=$S.1<A7(N5<JY%FLUFK=AUJ2LT9
M=MD'";::'39N*QUW7*`^!=S7>BY7.0:<H[NQ;*'C-9K);K=2W(HDY\]L01`-
MB8(V]%+X'>2:J_D@ZKCO5+^.E5&T2DD#%&_,<[,6/R%BHR92Q3,7'#NT3K>Z
M%E>*_6%&,.44;`F5W/+6A@Z:_EN6QL_1WY0=5EV[]0=CIS?!BL;;,Y708'&N
M'8[%;%.KM>G:<UR_%K\84W3$VD&H1%JQ>N-RP<L3T?QGO!:&_P`W2\[,F/FU
M0^FFM+BV(+$?0(!3H@41L9SZ5X;C1G;6>FQ\+_EU+^PHV[,^G8'A-XPS^,.F
MG:SV_P#_Q``D$0`"``0&`P$!`````````````0(0$3$#$A0@(5$$,$$R0/_:
M``@!`P$!/P'^5NAF,QF,QF%$5]+B^(;+BA,IE,I83[$Z;VQ\22VM#5!,3INK
M]DA,J5*E9127*(779$^!VFG2=).+J<-R&^R.PS#P8H[6%X;^LT:[-(NS2+LT
MJ[-*NS1P]C\-=D?B-*L/(E1\BOLQ!W1A\0^KR?VS[/\`_\0`)!$``@$!"0$`
M`P````````````$1`@,$$!0@(3%!43`2,D#_V@`(`0(!`3\!_E2D_$@@@@=)
M'Q5/;$C@;)))P@=.M(2G!O4AH:G5&\?%8,:T4K<7.+6,X)8LJT4<B+6WHL^>
M1WY=(SS\,X_#./PSC\,X_#.U>"OK[11?$W%6Q,J4/C10+LM-ZOE=/T6C_\0`
M.1```0(#!`@$`P8'`````````0`"`Q$A$C%!4000("(R87&1$R,P4D"!H10S
M4V*QX31"0U!RDM'_V@`(`0$`!C\"_M]2JO;W7WC>ZH]O?XJM%?-2@0R>@6\1
M#'YBO.TQHZ+>TIY7\1$[K<TPCJO(TICOG);[2X=U*,R16X\=#\)-U`MU6G'P
MV>YRQCQ%*"P0V\E.)%<MXS5RN5RW'$=%Y<4D<U+3=&#OS-O4]"C2=['*Q'!E
MS5]EWP.94F=\E^-'4XCB&Y!5"H%4A55X[K#NKQW5"J&:J%-ALE>'I;?&A?4+
MQM"?:;EB%8BU"M,,QZTFWYHEQDP7E>!H0DW%RFZI5%52ABT50>&WG1>=I'^H
M57Q3\U*<3NMR+$'6JG!C!WT7GL,L_P!U+'(JBDX+Q=%,CEFB6BQ''$S5-M^(
M]2RWB*F[A"^SZ/1@O(UDDJFY!&*\MN]BXW[<B)A%T#==E@58B4>,2IXXZA%@
MFS$;<472LQF\34$'-]*:M.O*$""=]U_)<]1*;`:=T<1_5-9#$FBX>EXK1OM^
MH33GNG6-(@WCB&838L/A=52=PXJGHRP"<\W`)T:+>3K;_D/U42U>1+7?Z#R<
ME/-XE]=AVCNX'[S>JFK)O'H$KJF0&]2I:W-7C,HX'>Y%<\1Z0@0*C$IK658S
M',XG8#V<;#:";$;<X30G=<?0:WYHG)18F`,AL^+"%<1FIP"6O]F*E&!!S4VD
M'IM5=:.07X4'$E6((-DWNQ=^RELQ(1_INIT.IAY;9Y)[^2&9U"A)-P"N(E@4
MXB9LF5%.1'53%'9KS&B*WG?W5"^$>87EZ0Q_S7`T_)?<M[+><QG8+SM*+N3:
MKR8,S[G_`/$#%,\N2IM2PB,_1`HC([9.94O=1#4VTUQ$[VWA/`)G/=+KY*('
ML(;:'`G4=*>[:R5Q5Q56?17'LJ3[+^97'LN$JC"N$JXJXJX[$!WYI=]3AF-H
M]-6CLYZJ*M5</@*A;M%(J?M(**;SVG]$%`'+4/A`4_HFG-H3.NQ__\0`*1`!
M``(!`P,#!0$!`0$``````0`1(3%!46%Q@1"1L2`PH<'1\$!0X?_:``@!`0`!
M/R'_`,_1`[LT9^$$_FFKSL((Z(_]-Z8.L`;OZ1PY[D8VRZ/XB9>B%9JF=$/W
M%=`\)>S71<R_"F:&</W,(]';R8A9D/0?^1P@&[#4S=EU>Q+#JMKV(\&MK>E]
MH1>VE/Y%5I>PU\36V.N9@'T/B4+EGJ29P)LK)6J?!4./7S3"5`X600439</G
M_A="]'CO,MT-=D,4?*#+8EHU$%,C`,1-!G3>:D?./F8#W3.K7_>(Q1X##K0[
MG[@BP'1N'43XC]X=$:@O8]IBZ,>5&_-(D"CBG4[0L-/O55^KA-6-DWB-J6"-
M9NFY5RL`"A1%BS&MN#NPLHF`+#P&69X7W?Q,RI4O<_:RDO.P_4881V_R,&U[
M(MZULVYM*;C](N)]@^'>'J]-1U)4`DNE/79T)&$\_DZD&Y0ND=&`<0\'W&R.
MIP3+%9%8\576\Z0<`7"V%0*U=^QUB1:O.WL<L)4O4%%QZ*12XP0Y$FHF(-_G
MSQ+W+:/@>G64D(,!V8.S+`F6'Q*8<#K<G2/`X'W(@6';A^T;K78Y8NX2/0P9
M&R"U,M6$QI=&#EVC:;&C@U?[I!R%H":]8F(N/&9QIK!VC9]!'C%M04*_)0P^
MUGB.L*;0)-L?,1(;"CP\1K)M@?N(!5CD?LJLNU_95484!1VSL;$>"'$9%T5L
M`>%9?>%]X@W]!+*S?F)Y@;1ZX]<TD1S3V^R%I>"7,(.C+':ENVXB@<<S-]Z?
M;['.58[S`5UP_L=IE?&2@'F7+95&J8[P1I`#_%.L*HT2#<U]*YOZ'JCG=QOJ
MRRZQK:OF7!HXIA,"C_`,4=HL/11&`O4FT!B-=4GP?8IH[H5BL([S?@!&;>ET
M0Z$TIS!X8I&&5.';DCD98II*PWJN68)5EUU8.6J]#EA2!W5B"@#54>7]2@!@
M<H.#C\F"*%])J^NI7.)U$OY!^Y[EFZ*T>Y]=O#A+*=&Q6/(LN`A0T#*P%;:I
M"D9<D`NEV].9V!J-,Q9O`F-`;X>Q^XI;O\/<_D"8C82OYS#XU_B;0/..T_5H
M]X[F=[?CB(Z9NW^'[8N>FAT[`P2B#S+5A!]"*W<#RK^%E`2U^3W^O.6I*'D/
M<PT.GI=1#=:.N(;`""UW/S`P`4LK@-,9(:RVZ!OW9UN%^/8F.ECM-8[YM-./
MRBC0>RG*+PP!MEKF^N2`4;Q'_P";-W\4`_E*-2\>@PBG`E]@DK%X9_BF/JL/
M"98#EG>%T[$T#I*`//$'J5[2O3VI7&(2I7H$J54K'IM*E7Z$TP>Y,ID_$1@I
M(PCJ#X1EQYR2D]1]2KO([[\[(/\`4=8%3?U-)QZ;0^MF\8S:;0.==3!]?Q'?
M:_"F(\?GZ/_:``P#`0`"``,````0\\\\\\\T\T\\\\\\\\\\\TRHDT0`X\\\
M\\\\\0P<P000LL<T\\\\\L,\(LP-I(4(LT\\\\L4L0P$0D,@4X`\\\VX$(<\
M\X\$XD0<\\\T(`L(0P@($,($<\\\`B_\!``@`=B\@`\\_\0`&Q$``@$%````
M`````````````1$`$"$P4&#_V@`(`0,!`3\0Y(`````````"&H```5`$`P)@
M(`(L8A4A5__$`!L1``$$`P````````````````$`$2%`(#!@_]H`"`$"`0$_
M$+@`'@```````#W0`H)B6S&!`@AF343O8?_$`",0``$"!04``P``````````
M``$`$1`@(4!0,#%!46%QD:'_V@`(`0$``3\0R-$(D0I=A2``]!26.(1@0($`
M@````D$0*`!B`=$!0H*B!QH"E0"`@4)`0`%`0!!!`4`!%`("@V*``+&``,"(
MWFQ(*`!"0!`0"D*`A`!`!0```*$4```H``%`.0`/PB%@H:((@`1`1(`````$
M0```)`"$`(@*(```0``(`0`"``0`(2`4$0```$J&H`,]A;"`@`A`*`"```@`
M`4)``!0``$2%(0``````("B%!]H=S8TPA`-YD*",```A`%,0`$T@````!`#`
M!```"B0!2&`]&$D`Y$)@"0```0A"```````4@`0```S(`(6$$_0+````0`@`
M&!0(@"`@``````40`6,``")@,B```*K%=$`0```````"$````*$``````$!0
M``(0@`````1`(5%F`'NY`,"`````````$@``0`!1""0`!`"B``0"`2`(``$`
M`44`!0``!@"`XK`P$$,$`*``!(``))```2```2(A2"D```$"400(,4*(``H!
M`;APZA"`F`"`(`0```0!0``(```A4"%A!@BAOS*`@!1\D0@,F0$R:#)H`F0)
M`SHH^E"X;%`^[B*&.X2#_]D`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+VUY86-C;W5N="YP;F<`````````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,C,T,@`Q,#4Q-30S,S<W,@`P,C,T-34`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!``
M```0"`,````H+0]3````!&=!34$``+&.?/M1DP```"!C2%)-``!Z)0``@(,`
M`/G_``"`Z0``=3```.I@```ZF```%V^27\5&```#`%!,5$4B(B,*#!#%QL@,
M$!;FZ.LE*"P,$!4H+#$W1E88'B5O?Y%\BIF6H:V@J[>[QM)%87Y-:H=2;HM.
M:(-=>94*#1!F@IY%6&MHA*!5;(,]35Y9<(AMB:58;H1SCJH)"PU@<H5^E:P=
M(B=D;WJ-F:6)D)?5V^'GZNWR\_1.9GUG@YY<=(MOBZ9%5F9UD:Q08W5\E:V)
MG;"*GK":K+VGN,=O>H09'2"1F9^0F)[)T]L)#0\2%!43%18-$1(1$1`8&!=+
M2$03"@`;#P%!)`4V'P6;6`_+=1G,=AK(=!K1>AW0>AW1>Q[%=1S"<QS3?1_%
M=!W!<QT.!P`*!0`(!``U'`(5"P$F%`(R&P-E-@=')@5;,0<U'00T'`233PTL
M&`2E7!!\10PI%P2L8!&*3`YY0PRU9!,F%00=$`.^:A6V9A2I7Q,M&06#20_*
M<AC,=1G-=AK,=1H8#@0N&`-"(P4T&P0Q&@0O&00Z'P59-A5%+QI,.BD:$@PD
M'AHI)B;,S,Q$1$0E)24='1T&!@8```#___\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````"OCWHK````
MA'123E/_____________________________________________________
M____________________________________________________________
M____________________________________________________________
M_P"7TC:^````"7!(67,```L2```+$@'2W7[\````O$E$050HSV-H!H$F$`"S
MFAE`A&V3O7T@5`0DT-!H7U</5&(+$[!SJ`P)2$MU;H0).#IY^_G[N,<'P01B
M(SV\?#WSDK-@`B69N6[YKCD9I3"!,I?T[-#"I)0BN+41,6&)<1'AP3`!FYKR
MXJCHA`I..8@`JYF!275!%8.2CJ0E2("=5U973Z6629E+0D9,I)G!REQ?6EN+
M6UW-6$%56(.#D<&:1U137$J>Q<)(E4]54(B-P=10``GP,S,HH@$`:754R]SM
ME+<`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+P``````````````````
M`````````````````````````````````````````````````````#`P,#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S<R`#`R
M,34S,``@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]N
M878O8F]T=&]M+6=R97DN<&YG````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`T
M-S,`,3`U,34T,S,W-S(`,#(T-3$R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````0````$`@#
M````*"T/4P```%%03%1%```%4U-3=W=W@8&!A86%C8V-E)24EY>7FIJ:GY^?
MI:6EIZ>GK*RLP\/#Q,3$QL;&Q\?'R,C(R<G)R\O+S<W-T]/3U=75UM;6U]?7
MV]O;2TM+.&]-50````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,`
M``L3```+$P$`FIP8````!W1)344'U`P4$2\X>`J0Y````&-)1$%4>-IMC5<.
M@#`,0\,(>[0IH^3^!R4%45*!O^PGRP80\2V(XMV.=:7!Z@A+#38R*?`?8.T+
MPKXW8>,YXHX6&47,8Z<E(I4#F9W.`%D_)5DZ39J%**MU@4,^:)!;+/BG<0*@
M:PF!S%;@'0````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+V)O='1O;2YP
M;F<`````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#<W`#$P-3$U-#,S
M-S<R`#`R,S4U,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```!4
M4$Q410````@-$2I#6S-2;C=9>#]EB$5OEDETG$QYHU"`K5N(LE^+M&>1N)&P
MS)6RSI>SSIJUSYNVT)RWT9ZXT:"ZTZ2]U:_%VK+'V[7)W+;*W;[0X0```!2T
M)'@````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!
M`)J<&`````=T24U%!]0,%!$N#$"E51````!D241!5'C:;8U9#H`@#$3K4O<%
M"B[(_>]IT8@E^KXZ+Y,.`.-O(.)W/=:5%*LU6$JQD4J%^PBM7Q'^.T4LGB'?
MF<42(N:QTQ*1R,',5F:`K)^2S)TFS6S$*;G$P1LT\"P6_J=Q`L3Z"<W!^E\,
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+VYA=B]D;W=N+6=R97DN<&YG````````
M```````````````````````````````````````````````P,#`P-C0T`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0U,``Q,#4Q-30S,S<W,@`P,C0Q-3``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!`````0"`,````H+0]3````2%!,5$4```!34U-W
M=W>%A86-C8V4E)27EY>:FIJ?GY^EI:6GIZ?#P\/$Q,3&QL;'Q\?(R,C)R<G+
MR\O-S<W3T]/5U=76UM;7U]=+2TNU<`[U`````7123E,`0.;89@````%B2T=$
M`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#!01,0'S3B<S
M````64E$051XVF-@(`J(0P"2@"@_-QLKLH"PH``+,[*`B``?JH`8A@`_/T(`
M9+X8'\@,F$7BG`)"0$-96)C@:C@$!`20^"`17D%D/@,#(Q</"A^HAET<W3LX
M/0H`#XT%;1*C';<`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]N878O9&]W;BYP;F<`````````````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`T-30`,3`U,34T,S,W-S(`,#(S,C$P`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````0````$`@#````*"T/4P```$M03%1%!0`*"`T1*D-;-UEX/V6(16^6
M272<3'FC4("M6XBR7XNTD;#,E;+.E[/.FK7/F[;0G+?1GKC1H+K3I+W5K\7:
MLL?;M<G<MLK=````AE_J!P````%T4DY3`$#FV&8````!8DM'1`"(!1U(````
M"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4$3`3&>QG.@```%I)1$%4
M>-IC8"`*2$``DH`8/S<;*[*`B)`@"S.R@*@`'ZJ`.(8`/S]"`&2^.)\`4`!F
MD02GH+"0``L+"Q-<#8>`@``2'R3"*X3,9V!@Y.)!X0/5L$N@>P>G1P$JYP6<
M-1$@7P````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M;F%V+V9I<G-T+6=R97DN<&YG````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M-#8U`#$P-3$U-#,S-S<R`#`R-#,S-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$````!`(
M`P```"@M#U,```!(4$Q410```&EI:79V=G=W=WIZ>H&!@8V-C9>7EYF9F:RL
MK,?'Q\C(R,G)R<K*RLO+R\S,S,W-S<[.SM#0T-'1T=/3T]O;V]_?WTM+2T*9
M<"4````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!
M`)J<&`````=T24U%!]0,%!$R#*;2"$T```!F241!5'C:A8_9#L`@"`3MH3W$
MVI/]_S^MBIK4ETY"`L,#BU(M`')3Q(.\*()2!_X*L(<@`GR<UWW=?A$!IMT[
M:]TZA6%!QVXC(A>8@S"A!I/1(I+I(V,6T=0K1G(,-8=ND[:__/("[HX(9%"V
M6-X`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VYA=B]F:7)S="YP
M;F<`````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#4P-@`Q,#4Q-30S
M,S<W,@`P,C,S-C8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````
M5U!,5$4````<+3TI0EHJ0ULM1V`S4FXT4V\_98A)=9Y+>*)GD;AHDKF:M<^;
MMM"<M]&>N-&?N=*@NM.CO-2DO=6FOM6JP=>KPMBNQ-FOQ=J^T.'$U./%U>0`
M``"6,A(6`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,`
M``L3`0":G!@````'=$E-10?4#!01,19PG:+T````:$E$051XVH6/R0Z`(`Q$
MW7&%BHJ*\__?*5(DD8LO:=*^'CK-LA0`H7G%B;!XA?0=[%?`:C`L8-?-'&;7
M`PM8N6B:)AI;-_3(+YJ5DN3HG!"N2A%H6'A3/%1!/"9>$9RCC#GJ-&GZRR\W
M\4P*''MOINL`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]N878O;&%S="UG<F5Y+G!N9P``````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U,#,`,3`U,34T,S,W-S(`,#(T,30S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```%%03%1%```$4U-3
M=W=W@8&!A86%C8V-E)24EY>7FIJ:GY^?I:6EIZ>GK*RLP\/#Q,3$QL;&Q\?'
MR,C(R<G)R\O+S<W-T]/3U=75UM;6U]?7V]O;2TM+<Y8Z!`````%T4DY3`$#F
MV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'
MU`P4$3(MZKL8$P```&M)1$%4>-I]C]L.@R`01-&*+5YA:!7G_S]48*$/IO8D
M9'=.]F%0ZC<L@ZQ"%AY?,>2-8+I*P+"*_;.%$-XP31'.`\YZK"-%S+#6`?#+
MBYRB>.I"&X..K^\2.8L0<LZB]&BEA[XV??#N+W\X`85J"8'^`.D^`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O;F%V+VQA<W0N<&YG````````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P-3`U`#$P-3$U-#,S-S<R`#`R,S(P,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$````!`(`P```"@M#U,```!44$Q410````@-$2I#6S-2;C=9>#]E
MB$5OEDETG$QYHU"`K5N(LE^+M&>1N)&PS)6RSI>SSIJUSYNVT)RWT9ZXT:"Z
MTZ2]U:_%VK+'V[7)W+;*W;[0X0```!2T)'@````!=%).4P!`YMAF`````6)+
M1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,%!$R%+6^
MD!L```!J241!5'C:?8_)#H`@#$1QP7V!@@O.__^G0-&#45]"VGGI81#B':0!
M7((7'+?HX@9"N`J8%I?8U\TYMU";):$MD5:6YAXL1J.4)B([-<#@12T3N0_2
MOZH,Q,R"B3F*U"/G'O+9M,#77WXX`;&)"<U4"YJ_`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+VYA=B]L969T+6=R97DN<&YG````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#0T,@`Q,#4Q-30S,S<W,@`P,C0Q,S0`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!`````0
M"`,````H+0]3````15!,5$4```!I:6EV=G9W=W=Z>GJ!@8&-C8V7EY>9F9FL
MK*S'Q\?(R,C)R<G*RLK+R\O,S,S-S<W.SL[0T-#1T='3T]/?W]]+2TL%;5=@
M`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":
MG!@````'=$E-10?4#!01,Q"KR&5#````5DE$051XVH6/21*`,`@$X[X$1$W"
M_Y\J43@82^W;=%$,./<"E[D0G+C(Q!>6MSW$$&EBS;`2>H_S<(HJX0(`*(PZ
MT?1*9SO$U)G6NL3<6K+YN_3YRP<''>L%39["PTD`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]N878O;&5F="YP
M;F<`````````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`T-30`,3`U,34T
M,S,W-S(`,#(S,3<S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P``
M`$Y03%1%````'"T]*4):*D-;+4=@-%-O/V6(276>2WBB:)*YFK7/F[;0G+?1
MGKC1G[G2H+K3H[S4I+W5IK[5JL'7J\+8KL39K\7:Q-3CQ=7D````**@NZ@``
M``%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8
M````!W1)344'U`P4$3(V8-[1_P```%=)1$%4>-IC8,`!)-'Y:`*2XI)H?`%)
M"(#QA81%Q$1$!3@EH7P>00$^;FX^+G:P`*,$'S\O+P\?$'!`53"S00$KS`R@
M"!,(L,#L`HJ@V`(2(>123+_@`0!M_076`U7TE0````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+W)I9VAT+6=R97DN<&YG````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#0W`#$P-3$U-#,S-S<R`#`R-#,R
M-``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```!(4$Q410```%-3
M4W=W=X6%A8V-C924E)>7EYJ:FI^?GZ6EI:>GI\/#P\3$Q,;&QL?'Q\C(R,G)
MR<O+R\W-S=/3T]75U=;6UM?7UTM+2[5P#O4````!=%).4P!`YMAF`````6)+
M1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,%!$S*FW$
MO/$```!8241!5'C:C8Y9#H`@#$3KCEL97-K[W]2(@`EJXON;UTFF1%_H0^1&
M>[UO'IAH=%\W$5E@BB"L`RP[S,/5T1',%H";.F^TK0-E:#352<IQ)>6XE>67
M3^DO!R\M!6TGJM/5`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+VYA=B]R:6=H="YP;F<`````````````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#0U,P`Q,#4Q-30S,S<W,@`P,C,S-34`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!`````0"`,````H+0]3````2U!,5$4%``H(#1$J0ULW67@_98A%
M;Y9)=)Q,>:-0@*U;B+)?B[21L,R5LLZ7L\Z:M<^;MM"<M]&>N-&@NM.DO=6O
MQ=JRQ]NUR=RVRMT```"&7^H'`````7123E,`0.;89@````%B2T=$`(@%'4@`
M```)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#!01,QI+'8Q=````64E$
M051XVHV.60Z`(`Q$<<>-#KBT]S^I$0$3U,3W-Z^33)7Z0AXB-]++??-8'8WL
MZ\;,"W01!#F`C,,\7!T9K3$$P$V=-]+6@3(TFNHDY;B2<MS*\LNGZB\'2O<%
MG)F6C:(`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]N878O=&]P+6=R97DN<&YG````````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`T-3,`,3`U,34T,S,W-S(`,#(T,#`V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````0````
M$`@#````*"T/4P```$A03%1%````:6EI=G9V=W=W>GIZ@8&!C8V-EY>7F9F9
MK*RLQ\?'R,C(R<G)RLK*R\O+S,S,S<W-SL[.T-#0T='1T]/3V]O;W]_?2TM+
M0IEP)0````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+
M$P$`FIP8````!W1)344'U`P4$30)@.);1````%Q)1$%4>-I=S^L.@"`(0&&Z
M2%F0E2;O_Z;16@LY__C&9`*(#32Y2(NHA1?\QEL';5+%S3Q(,].&1J0>.^$O
M4M.9%#YYKF4F[,U9*2LKF$>SA\(.TN(@3G,8+9B?W?@^"&2AQ5*R`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+W1O<"YP
M;F<`````````````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-#<T`#$P-3$U
M-#,S-S<R`#`R,S`T-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,`
M``!74$Q410```!PM/2E"6BI#6RU'8#-2;C13;S]EB$EUGDMXHF>1N&B2N9JU
MSYNVT)RWT9ZXT9^YTJ"ZTZ.\U*2]U::^U:K!UZO"V*[$V:_%VK[0X<34X\75
MY````)8R$A8````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+
M$P``"Q,!`)J<&`````=T24U%!]0,%!$S,PFO%#$```!>241!5'C:7<])#H`P
M"$!1''&L6.?*_<\IIC%2_HX74E(`UH'$EY,ZE*H(=B.601K?G,Z!"DYF-Z,2
M#NLRX2\<_.8%/GFO[>0P5V?Y'$E`/;I;.,B`'PST35N7&M3/'OWL"AQL[V(>
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VYA=B]U<"UG<F5Y+G!N9P``````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#0T,0`Q,#4Q-30S,S<W,@`P,C,V
M,C4`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````15!,5$4```!I
M:6EV=G9W=W=Z>GJ!@8&-C8V7EY>9F9FLK*S'Q\?(R,C)R<G*RLK+R\O,S,S-
MS<W.SL[0T-#1T='3T]/?W]]+2TL%;5=@`````7123E,`0.;89@````%B2T=$
M`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#!01-"(L7J($
M````54E$051XVHW,V0Z`(`Q$T;K5C5H5F/__5#&&B$U(O$_,20-1I<9L1)@M
M'3[;;5P(XK$[?@513TV0!2DOCMO[D6_"*@F*3[V%(`9T,3"/T]"7\$3_N@#'
M?`5-^S$3(P````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]N878O=7`N<&YG````````````````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`T-30`,3`U,34T,S,W-S(`,#(R-C8U`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````0````$`@#````*"T/4P```$Y03%1%````'"T]*4):*D-;+4=@
M-%-O/V6(276>2WBB:)*YFK7/F[;0G+?1GKC1G[G2H+K3H[S4I+W5IK[5JL'7
MJ\+8KL39K\7:Q-3CQ=7D````**@NZ@````%T4DY3`$#FV&8````!8DM'1`"(
M!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4$301DX[#$@``
M`%=)1$%4>-IC8,`!&-'XDA*2J'QQ/F9)%#X//QN2B*2XD"`O&T)$4EQ`6``H
M`!.1!`(1/AXV)A`#ID:,FP\H@&2H"+J`*!^:@``7F@`G.P<K"[(`!#`0!P`.
MS076?JWN<@````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O;V9F:6-E+G!N9P``````````````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`R,S$Q`#$P-3$U-#,S-S<S`#`R,C<P,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$```
M`!`(`P```"@M#U,````$9T%-00``L8Y\^U&3````(&-(4DT``'HE``"`@P``
M^?\``(#I``!U,```ZF```#J8```7;Y)?Q48```,`4$Q417=V=Y:5EI.2DY*1
MDH*!@H&`@7U]?GEY>GAX>7-S=,?'R,#`P:BHJ:&AHHN+C(J*BWY_?WU^?GQ]
M?7-T=&ML;&%B8IF:FI.4E(R-C8*#@WU^?7EZ>7%R<7!Q<,G*R9:7EI25E(N,
MBX>(AX:'AH"`?WM[>IF9F(Z.C8*"@8!_?WU\?'Q[>WMZ>I^>GIV<G)64E)23
MDY.2DI*1D8J)B8F(B(B'AX:%A=O;V]G9V<_/S\[.SLO+R\K*RLC(R,?'Q\+"
MPL'!P;R\O+2TM*BHJ*"@H)^?GYV=G9N;FYF9F9B8F)>7EY:6EI&1D9"0D(^/
MCXZ.CHN+BXJ*BH>'AX:&AH6%A82$A(.#@X&!@7Y^?GU]?7Q\?'M[>WIZ>GEY
M>7AX>'=W=W9V=G5U=7-S<W)R<G!P<&YN;FEI:6AH:&9F9F5E96!@8````/__
M_P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````($&M!(```!M
M=%).4_______________________________________________________
M____________________________________________________________
M_____________________________P`MMM1+````"7!(67,```L3```+$P$`
MFIP8````NDE$050HSV/(00,,$"H;"&`"V2@@AR';W!$(LL'(T=$YFR';PBH]
MRPD,LH`T2(";V\'>CLM6SL;:RM(5*,`MRQFO(Q@>JA2@;J0O#!)(3HC5TI0,
M-I;P-?!*``DDQFD+L)B9*/HQ>7O$@0085*7"0X,"_)D5/-VE00+L42IARH$2
MON+R8FXQ(('H"(T0$SX_0T8U/1<AD$`D:Z@IO[\/4(,N;P10@$<T,R--)%4F
M*8%#ARTE&],OZ-X'`"(A3%ZZOM><`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]O<F=A;FEZ:6YG+G!N9P``````
M````````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$Q-C<`,3`U,34T,S,W-S(`,#(S
M-C(V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```2Q03%1%````
M"0D)#`L*#@X.$Q(1$Q,3%Q<7&!@8&QL;'AX>(B(B1$1$55557U]?=&M,;6UM
M;FYN=75U=G9V@G=5>7EY?W]_@X%XAH1[B89^B(B(C8V-E)*+DY.3EI2,H95P
MFYN;G)R<HY^7KJ!TL*)XMJ=UJJB?J*BHNJETJZFAJZNKK*RLL:VDOJ]]M+"H
MM+*JM[>WW+QTP,#`Q,"XQ,&YR<6]QL;&R\>_ZLA[R\O+W<V8TL_(U-',U-+,
MU=+,V-;0UM;6V-?1W-S<\]Z:]-^=]>*DX>'A]N.G]^2LY.3DYN;BYN;FZ>GF
MZ>GIZNGGZ^KIZ^KJ[>SH[^[M\?'N\O'N\?'Q\O+R]//R]/3R]/3S]/3T]?3S
M]?7U]_?T]_?W^/CX_/S\_?W]_O[^____````4VW#%0````%T4DY3`$#FV&8`
M```!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4
M$38P[=&QS@```,1)1$%4>-I-C]=6PE`41`-!JC2E*DA'Z44@2I$2>A'I'0SS
M___`O0$6S.->^YPUPS#7`,Q]@&GJ#@$'0=A5@V<$5@YD9__"\5A^(>3ALZ))
M6Y#:'[I?U$"NLV#_,E8T$H#[$0SRZZ5JTHNQ0-!$#65INU.KGCY`$S(2XV>Q
MF@\''KC:,(@_7@N_HW'1BC>.')DIL47B`:=,%^6@O?0`I'CV-HGAT$,$8=^[
M_[O.P7XICTV+YVL$7+>@S]$D%;=I$K&%*)P`OVTSN5"G3W$`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]P97)M<RYP;F<`````
M````````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(P,S,`,3`U,34T,S,W
M-S(`,#(R-3<V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P````1G
M04U!``"QCGS[49,````@8TA230``>B4``("#``#Y_P``@.D``'4P``#J8```
M.I@``!=ODE_%1@```P!03%1%BWU*;V0[7E4R[M:`\O+R[>WMW]_?VMK:SL[.
MR,C(PL+"O[^_M+2TJZNKDY.3:VMK45%12$A(0$!`(2$A!P<'`0$!````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````^)IS*P```!AT4DY3________________
M______________\`S1,NZ@````EP2%ES```+$P``"Q,!`)J<&````&%)1$%4
M*,^5SL$2@C`,1=%H?8BV2A&][___U`4,UNZXRS.9).&N,&L[<$[IE#6S0XI(
M:*C;9`!7GEK+$+!<))5MPF%N4\GEM\.,C\_[17-VNFN8&S!5E>8Q&^&CD'N@
M@[^^`Z03U,.I)L\`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+W!R969S+G!N9P``````````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#8Q-@`Q,#4Q-30S,S<W,@`P,C(U-S0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!`````0"`,````H+0]3````BE!,5$4`!0`='1T?)R\I*2DP,#`Q,3$V
M-C9)1T904$]24E)-7W-L:6=K:FER<&UF>8]P@I5TBJ**AX1XC:1]C)Q\D:=]
MD:=_F;.-F:6$GKF$GKJDH9RQL;'(Q\;*R,'2T,S2T=#3TL_5U-//UMW6U=78
MV-C;VM?>V];?WMSCXN'KZ^CLZ^KW]_?Y^/@```#=E\T9`````7123E,`0.;8
M9@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4
M#`@2'0<[E;_6````?4E$051XVFV.61*",!`%@^`6]P5Q1Z.`H'W_ZTDV0<OY
MR/14O4H_(?X-/\#)P\%#:8`[+L9+4Q=[G^&9:R1R^<NCR/8$8>.H)QT0?(OI
MT[[H<1PU;69JC>"V\"56:KGIU+N:6&VBYEMIM->Q62K>21LF'>HWGDH^OSM'
MN\`;)=4.9O?[M1\`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]P
M<FEN="YP;F<`````````````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$Q
M,38`,3`U,34T,S,W-S,`,#(R-C`V`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````0````$`@#
M````*"T/4P```1U03%1%````&QL;34M'3TU)4$U)44]+44],4E!,5%%.5%).
M85Y986!>:VIG;6UL;VYK<&]L=75U?WY[?WY\@'Y\@']\@8!^B8>%B8B%B(B(
MC8V-CHZ.D)"0DI*2DY*1E)*0E).0EI:6FYJ8GIV<GYZ;GIZ>IJ:DIZ>GJ*BH
MJZJGJZNJK*RIKJVJKZZLL*ZLLK"ML;&NL[&OL[*PM+2TN;BUO+N[O+R\OKZ]
MP+^\PL+"Q<7%Q\;&Q\?'R\K)S\W-SL[.S\_/T='1T]/3UM32V-?4U]?7V=C6
MV=G8VMG7VMK9V]O9V]O;W=O:W-S:W-S;W=S;WMW<WMW=W][=XN+BY>7DZ>GI
MZ^OK[.SL[N[N]/3S]_?W^/CX^OKZ^_O[____````)[,>1@````%T4DY3`$#F
MV&8````!8DM'1`"(!1U(````"7!(67,```L1```+$0%_9%^1````!W1)344'
MU`P($BD($`!1L````*I)1$%4>-IC8,`&XF``QH^%@K`XF("THZ.4@K6U"UP@
M-`0(0D.]X`(24E*A`D9&"(%0"$`(2(>&JJBKJ=E#!.),-.U,0<"25P8D$F<1
M$QL=&QT3$QT58:8,%(F+C@R6#'<(\O#W<3;48P0*6#EY^P8$^KEYNKN*RH-4
MV"IQ<7"RLK,P,;/)@@5LS(T-]'5TM50UM'4400)RPF+B(B)"@D+\?#S<<<A^
M!?L7`*0(,2F/S@[2`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]P<F]B;&5M+G!N9P``````````````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`S,#4`,3`U,34T,S,W-S(`,#(S,3$P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````0
M````$`0#````[=WB4@```!A03%1%_-/+````WX%DWG55\J"-WX%DWX%DWX%D
M9`^U5`````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+
M$P$`FIP8````!W1)344'U`L%$R4';8)MUP```"9)1$%4>-IC8&!@8!1@@``A
M10C-J*0D0#0#K@L+`VXR'&#8A:88``0K`R`$1+W6`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O<F5L;V%D
M+G!N9P``````````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-3,S`#$P
M-3$U-#,S-S<R`#`R,C<R,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M
M#U,```!@4$Q41?____S\_?+Y_>_R^./K]='A]%:F[G+&<@*:`Z+:KL_H_L/5
M][*R_A*>$NKV_J+6SL3A^KK>]J[7_2FG-Z+2_EZZ@@```/______________
M_____________________P#>&7X````!=%).4P!`YMAF`````6)+1T0`B`4=
M2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,%@XE)"N7".<```!T
M241!5'C:9<_1$@(A"$#13:1E*5%9\_\_-2P<M^F^<5!GW+:_^LKA9H4`$5T^
M,`S[O5\@`/JE`3O10?QX3K#98N0)Z9!L4!P@B,1Q@JL#@(B44NJ$L28;U2$:
MI%R2JBZP3FT.S)3W\Z7:VA<0N=J+"_K/?]\LX`F)*\1V;`````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W)E<75I<F5D+G!N9P``````
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#(S,``Q,#4Q-30S,S<W,P`P
M,C,R-C8`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@````H````*`0,```"W_%W^````!E!,5$6U
M``````#O8#L)`````G123E/_`.6W,$H````!8DM'1`'_`BW>````"7!(67,`
M``!(````2`!&R6L^````'4E$050(UV/X?X#A,QA-<F!H<&!X>`"$SH#1_P,`
MW/\.T<!PK"T`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]R:&%N9"YP;F<`````````````````````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`T,C<`,3`U,34T,S,W-S,`,#(R-34R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````A````#@0#````4S!HOP```!A03%1%____P,#`O[^_@("`
M``#_``"`````````6NUX4P````)T4DY3_P#EMS!*`````6)+1T0&86:X?0``
M``EP2%ES````2````$@`1LEK/@```(I)1$%4*)%MST$*@S`4!-!!P74^:-;E
M%_ZZ))`3J"=0UXF!N?\1NHA%6CJ;@;<9!O(3A]:>9/F2#,!81,3!DQ0/`%TU
MBCB,\[PR`SW5`EB:O``83JT*:Q*`GAA(ZD<>,%"3"(O#M"QK5$VY:_,.X[8=
M,6@>SN<ET[X?K($PRBWB:Z2F2SQ9_KVXX]Z'1"5+3BZ:$`````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O<V%V92YP;F<`````````````````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`Q,#4R`#$P-3$U-#,S-S<S`#`R,C0P-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$````!`(`P```"@M#U,```#Y4$Q410``!1$H-1$L.A,M/!@P0AHQ0"$V2"TY
M22Y#4R]&5C-)6CY/7$E@<D]D=5EC;51I?%AM@%IP@FYN;E]YB6MX@GIZ>H"&
MC("'CX:&AL=T9L=T9\=U:,AV:)"0D'V7K'Z9K7^:KK>'?H&:KH.>LH2@M<V&
M>LB*@)R=G8:DN8FFO*&AH=&/A(RHO9>EL-&0A(VIOM.1AIVIL)^IL*BQO:&V
MQ+*RLKFYN:Z_S;^_O\#`P,+"PL7%Q;_+ULW-S<?/VL[.SK_5Z,K6W]34U-;6
MUM?7U\O=Z\_@[=OG\>;FYNOKZ^[N[O'Q\?+R\O3T]/?X^OGY^?S\_/[^_@``
M`&%J`:8````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``
M"Q,!`)J<&`````=T24U%!]0,%!(K.6DGVR\```"J241!5'C:5<_5%H)`%(7A
ML0L#6Q1CQ`[L.J(HUMCP_@_C@*,N_\MO[9N-D/$70L9]7VU9=5L]5360<91+
M68&6$7(5.4SA(.]TUD,*OH&E73#W6SQOA'R!M@7:!\ZZ?B5F9P;3S6II-6(@
M-XJ85LAC!NTAP)KL:KXD`PG`Z==@XHAT+*AC4+P\P,S&]TV(E[%R<L=@,;;S
M`\Y\%PHVYZ*8CB8\@92+PO]_]`+JX#9W*JGT-0````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O<V5A<F-H+G!N9P``````````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`R,S4W`#$P-3$U-#,S-S<S`#`R,C<R-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$````!`(`P```"@M#U,````$9T%-00``L8Y\^U&3````(&-(4DT`
M`'HE``"`@P``^?\``(#I``!U,```ZF```#J8```7;Y)?Q48```,`4$Q41?;V
M]_GZ_/7V^#A#4>GN]&F!G%URBD139$]@<X";N'R6LH.>NX6@O82=N8BBOH2<
MN(FBOD-/76^#F86=MXRDOHVDO8>;L9>MQ826JJ*URM/=Z-?@ZM?>YN7K\D%1
M8D)28SE'56^)I'.-J&J"FVN"FF9\DUUQAF!TB6N!F(:AO8BCOW.*H6I_E6%T
MB$%.6W"&G&I_E(NFP6E]DHVHPUYP@I2LQ96LQ)2KPXN?M)BMPY>INXZ?L)^Q
MQ)&BL['#UJN\S;;'V:_`T;7&U[G(U[G$S\S7XKG"R^?M\^/FZ?7W^3U+6'&'
MG**VR=3?Z=;<X=/9WO+V^=7<X;FYN;&QL9"0D'IZ>G=W=W5U=7-S<W!P<&]O
M;VYN;F9F9EY>7EQ<7%M;6UA86%=75U965E)24E!04$]/3TE)24-#0SX^/CT]
M/3HZ.C$Q,2\O+RLK*RDI*28F)B4E)2,C(QH:&A86%@T-#0H*"@D)"0@("`<'
M!P8&!@4%!00$!`$!`0```("`@```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`$,0M9L```!_=%).4___________________________________________
M____________________________________________________________
M____________________________________________________________
M_____P#_X3P)````"7!(67,```L3```+$P$`FIP8````SDE$050HSV.H`X.H
M].S:FKSDT+HZ!C`_J530R%M;PZLL'B(0669B[>8GX\.E5A8*%LC0L_5G\&21
M-N5D3P$+Y!NX,`6P2-EIBBCE@@5J]3T8W7T=#'G,^&L@`CJ!LE(.QEK<DL*U
M8($B=2M7)T,M/G-'Q6RP0!:SBA@OMX"XLZA\'$@@/+::0U7"PL;>DJTJ#"20
MD%-;JJ`KI,PJ5YD(=%AD;55%45IF84UM05($T.DQ^4$AQ:EU<,!0$AQ=6UN'
M)%`.Y,<C"\37UB8A\>L`3II;3O1[\,L`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]S:&%D;W<N9VEF
M````````````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#8W-#4`,3`U,34T
M,S,W-S(`,#(R-S,T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````$=)1C@Y82`#(`/$``#____GY^?S\_/6UM;"PL+[^_NRLK+U
M]?7;V]O\_/SQ\?'@X.#1T='Z^OKV]O;JZNK8V-CM[>W%Q<7HZ.C)R<G]_?WX
M^/CO[^_^_OZUM;6[N[O$Q,3Y^?D````````````A^00``````"P`````(`,@
M`P`%_R`@CF1IGFBJKFSKOG`LSW1MWWBN[WSO_\"@<$@L&H\OQ8&3P""?T*AT
M2JU:K]BL=LOM#@.70Z/B+9O/Z+1ZS6Z[WV5$0&$AP^_XO'[/[_O_=PP+$0X)
M@(>(B8J+C(V.910(#P>&CY:7F)F:FYQX$A`3`@6=I*6FIZBIJB<$`P&BJ[&R
ML[2UMENMKZ.WO+V^O\#!([FPPL;'R,G*?\2[R\_0T=+32,W4U]C9VMLFUMS?
MX.'BMM[CYN?HZ8OEZNWN[_!E[/'T]?;W/_/X^_S]_B7Z_@D<2!!=P((($RJ,
M=G"APX<0R;DJ%K&BQ8NG&F+<R+&C'XT>0XH<>08DR9,H4_]",:FRI<N7.5C"
MG$FS)@J9-G/J=(ESI\^?'GL"'4KTH="B2)/^.ZJTJ=-X3)]*G3HN*M6K6*]9
MS<JU*[*M7L.*O05VK-FSJ,JB7<L6D]JV<.,B>BNWKET\=._JW8LF+]^_@+'X
M#4RX<+6)S@PK7BP/,>/'D+,,CDRY,HO)EC-K%H%YL^?(G3^+5AQZM&G`I4^K
MOIMZM6NXK5_+/AM[MFVOM6_KOII[MV^GO7\++QI\N'&?Q8\KKYE\N7.>CI]+
M;]M\NO60U:]KQYA]NW>(W;^+3QA^O'F!Y<^KWY=^O7MZ[=_+;Q=_OGUS]>_K
M_Y9_OW]L_?TG($/1#6@@=P4>J"#_>`DNZ"!Y#3XH(7H13F@A>Q5>J"%\&6[H
M(7T=?B@B?B&.:")_)9ZH(H`IKN@B@;J\*.,V`<YHXQXUWJ@C'#GNZ.,:/?XH
MI!E!#FDD+BT>J60I12[II!1-/BGE$5%.::4055ZI90]9;NDE#EU^*>8,88YI
MI@MEGJEF"FFNZ28);;[Y9IQRKDEGG6?>B>>8>N[Y99]^;@EHH%<.2NB4AA[Z
M9***+LEHHT<^"NF0DD[Z8Z66[HAIIC=NRNF,GG[Z8JBBKDAJJ2>>BNJ(JJ[Z
M8:NN;@AKK!?.2NN$MM[Z8*ZZ+LAKKP?^"NR`P@[[7['&[H=LLO<MR^Q\SC[[
M7K32KD=M_[7G78OM>-IN^UVWWFX';KC7C4ON=.:>^URZZB[';KO'O0OO</+.
M^UN]]NZ&;[ZW[<OO;/[^^UK``J]&<,&G'8SP:`HO_%G##F\&<<2934QQ919?
M#%J2&L_)<<=V?@QRGB*/S&?))O^)<LJ"KLQRH2Z_C&C,,B]*<\V.WHQSI#KO
M3&G//E\*=-":#DUTIT8?#6K22H_*=-.F/@UUJE)/S6K55K^*==:R;LUUK5Y_
MC6O88N]*=MF^GHUVL&JO36S;;A\+=]S*SDUWLW;?#6W>>D_+=]_6_@UXMH(/
MSFWAAG^+>.+B+LYXN8X_CF[DDJ]+>>7N7HYYO)IO3F_GGM\+>O_H^HY.>K^F
MGPYPZJH/S'KK!K\.>\*RS\YP[;8_C'ON$N_.>\6^_XYQ\,)O'&/Q8!^/_-C*
M+V]V\\ZG#7WT;$]/_=O67R]W]MK7S7WW>'\/_M[BC^]W^>8'CG[ZA*_/_N'N
MOZ]X_/(W3G_]D-^/_^3Z[V]Y__[+'``#R+D!$O!S!CR@Z!*HP-(QL(&H>R`$
M5R?!";JN@A:,'08S2+L-<O!V'OR@[D(HPMZ1L(3`.R$*AZ?"%1J/(BYT3L9B
MB(\9TM`>-KPAAUJH0\/DL(?O^"$00<3#(:*&>$8D#A*3.!0A,I%$17PB:Y8H
MQ9TXL8K@N"(6N:'%+6JCBUYD413#R!;_,))Q&F8\(XQ@J$80LK&-(WPC'$TH
MQSFFL(YV9"$>\_C"Q/#QCG[\HQX#*<@^%E(S:3SD+Q*IR%XPLI%DH2(D-_+(
M2=*BDI:4!28SN8I-<C(5GOQD1B0I2J.0LI0+"24J.Z'*56ZBE:[,!"QC>8E9
MTO(1MKQE(W*IRW6<LI?^X"4PY_++86)HC,:<B3"3^9%B,K,>RWPFCIPI37A$
MLYIXH28VB;C';6+EFMYT`SC#R89QDE,-YCQG7[2I3G&DLYV-028\.?+.>7*A
MGO;4`C[S*1AV\C,;^_QG%0(JT"D0M*!1."A"GZ#0A5+)GPZ%1D,C2H2)4A1+
M$+UH,BRJT7QD_[2CQN`H2'D@TI'JH*0F!=-'4^H+E+*T!BY]*9E6*E.)R+.F
M]X@I3E^@TYVVH*<^70%0@\HFFA)5%4,]:C>,JM11WK2IZD@J5#G#U*FRLJI6
M?256LRK+K7*UEE[]*B[#*M9=DK6LOGPJ6KEXUK424ZUN!6A;X\J,N=*U#U*=
M:EZANM>F]E6I?SUJ8(DZV*`6UJ>'W6EB<;K8FC96IH]]:619.MF45M:DEQUI
M9D&ZV8YV5J.?O6AH*3K:B);6H:==:&H1NMJ"ME:@K_UG;/DYVWS6UIZWG6=N
MX;G;=O96G;\]9W#).=QP%M>;Q]UF<K&YW&HV5YK/?69TF3G=9%;7F/_7'69V
M@;G=7G97E]^]97AI.=Y8EM>5YUUE>E&YWE*V5Y3O_61\.3G?3-;7DO>=9'XA
MN=]&]E>1_SUD@`LY8$$6^(\'YF."\[A@.S9XC@^&8X3;.&$U5OB,%R9CAL.X
M82]V>(L?QF*(JSAB*9;XB2=F8HJ3N&(CMGB(+P9BC'LX8QW6^(8WIF&.8[AC
M%_9XA3]&89!+.&01%OF#1^9@DC.X9`LV>8)/AF"4&SAE!5;Y@%<F8)8#N&7_
M=7E_7\9?F.LW9OF5^7UG9E^:T[=F\[5Y?&\&7YR[-V?MU?EZ=Z9>GJ.W9^?U
M>7E_1EZ@BS=HX17Z=X?F7:)SMVC;-7IVCX;_7:1;-VG55?ITER9=ID.W:<]U
M>G.?QERH*S=JR97Z<:=F7*H3MVK#M7IPKP9<K/LV:[W5^FZWIENNX[9KM_5Z
M;;]&6[#+-FRQ%?MKQ^9:LK.V;*LU>VK/AEJTFS9MI57[:-<F6K:#MFV?=7MG
MW\99N&LV;IF5^V7G9EFZ4[9ND[5[9.\&6;P[-F^-U?MB]Z98OB.V;X?U>V'_
M1EC`"S9P@17\7P?G5\+SM7![-7Q>#X=7Q-LU<755_%P7)U?&P[5Q;W5\6Q_'
M5LBK-7)IE?Q9)V=6RI.U<F.U?%@O!U;,>S5S7=7\5C>G5<YCM7-7]7Q5/T=5
MT$LU=%$5_5-'YU32_S.U=$LU?5)/AU34&S5U157]4%<G5-8#M74_=7U/7\=3
MV.LT=CF5W6-PO2L:[:IV/9S=36\/6=K;+E&VT_T.<5=3WDDV][LK8^]F`OS)
M^N[WK]B]\&T0O)@4KS+"(UX8C/=2Y%OF^,<#8_):PCS,*F_YEAZ^\^OD/.@C
M*?K1UT+S5D+]S$IO^EFH7DJOMQGK6Q^+V#O)]CF;/>V1^OG=(TGWOG=J-X,?
MU=X3_PJX5U+R>0;\XU^U^<[7*O2CW]7I4Q^LUK_^6+.O?;-RO_MI'3[XV?K]
M\;]5_.:7:_G37]?ULQ^OQG__$)9O)/K_S/WR=WO\\P\$^PO)_T*#?_R'=__[
M-X!<4H`&N`,`Z",+6#0"F(")AX`0J%(/.('H)($6"%,8F($S58$<2"0;^($P
MT(`Z0H)(XX$BV`4F:",KN#0HF(*_AWXPZ'DO.(/]5(,V:`4M*",[Z#0XF(-4
MT(,N(H11\X-`""4A>(2LD(1*"!!,V(3#\(10"`!$J")52#5&.(5&<(4FPH57
MDX5:6%%2"(5>*")EJ#5@&(88E89JV']CV(1GZ"%QV#5LV(8^,(<:@H?)(X-V
M:`IZ:"%_R#Q\V(>D$(@28HC/,XB$R`F(Z""-*#V*N(B:\(@*0HG5$XF2Z!9O
MJ(26:""=B#V8F(F6\(D"0HK;$XJBZ`BFZ!^KZ#W_J)B*C-"*^B&+X?.*L*@(
MM&@?N4@^MGB+YT=(OEB(FWB$NR@?Q7@^O1B,[9>,R@A_==B,/#6,0'B,[D&-
MZL.,T*A_SYB-ER&-.6B-Z@&.[8.-W$B`VUB.176.Z+B$ZKB.3MB.[AB%\!B/
M5.B--BB.YH&/\$..]'B!\QB/^B@>`3D__-B/H5>0!@F"_^B.`^D=#6D_")F0
M7O"0VD&1^1.1$GE/]CB#%FD='<D_&)F1^K21,/B1TF&2_Q.2(GF#*KF2.DB2
M*8B2,@23(BB3`M22+AF$-/F!GQ`*P)B3?!`)DY``"\``&Z`!&6``2KF43-F4
M3OF44!F54CF55%F55GF5_UB9E5JYE5S9E5[YE6`9EF(YEF19EF9YEFB9EFJY
MEFS9EF[YED^9`1JP`8)`"`D0``C``!0@`030EW[YEX`9F((YF(19F(9YF(B9
MF(JYF(S9F([YF)`9F9(YF919F99YF9B9F9JYF9S9F9[YF:`9FJ(IF!)``0P@
M!W10`1<0``N``!`P`+`9F[(YF[19F[9YF[B9F[JYF[S9F[[YF\`9G,(YG,19
MG,9YG,B9G,JYG,S9G,[YG-`9G=(YG=19G;4)`0BP`&`@!A5P``H0`0\P`0$P
MGN19GN9YGNB9GNJYGNS9GN[YGO`9G_(YG_19G_9YG_B9G_JYG_S9G_[YGP`:
MH&(".J`$6J`&>J`(BIX3\``1H`1,@`$-8`$.<``"4*$6>J$8FJ$:NJ$<VJ$>
M^J$@&J(B.J(D6J(F>J(HFJ(JNJ(LVJ(N^J(P&J,R.J,T6J,V>J,XFJ,ZRJ$'
MX``6T`!-```A```[````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O<VAA9&]W+G!N
M9P``````````````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`V-3$S`#$P-3$U
M-#,S-S<R`#`R,C<T-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12```#/````T4(!````!32,6P`
M```K=$58=$-R96%T:6]N(%1I;64`5&AU(#4@1F5B(#(P,#0@,3$Z,C$Z,C(@
M+3`V,#!R:CQF````!W1)344'U`(%$14?KSQU;0````EP2%ES```+$@``"Q(!
MTMU^_`````1G04U!``"QCPO\804```RC241!5'C:[=I1:MM`%$#1Y]B$0@AT
M_SL-3NR.9$,W$-U`>\Z@0?:7_BYOF/,`P-'.<UKK^0H`1_LU+VO-BL]=>``X
MWN^Y[.&YS7H!@*.]S^=\S!:>N_``<+RWN:[]NNW"`\#Q7F<KSG[%X.6GOP6`
M_\!VM>!YKTUX`#C>Z>]U:N$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`I
MX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>
M`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@
M)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"
M`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`
MI(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*
M>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'
M@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!(
M"0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P
M`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`
M*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2
M'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!
M("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2
MP@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\
M`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`
M2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$
M!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`
M2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4
M\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/
M`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0
M$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA
M`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`
M4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E
M/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#
M0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"D
MA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX
M`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`
ME/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)
M#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``
MD!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`I
MX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>
M`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@
M)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"
M`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`
MI(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*
M>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'
M@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!(
M"0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P
M`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`
M*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2
M'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!
M("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2
MP@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\
M`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`
M2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$
M!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`
M2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4
M\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/
M`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0
M$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA
M`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`
M4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E
M/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#
M0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"D
MA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX
M`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`
ME/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)
M#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``
MD!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`I
MX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>
M`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@
M)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"
M`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`
MI(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*
M>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'
M@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!(
M"0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`#C>?5^[RYSG==[F?3VO*T.G
MG_XV`/XY][FM]4S/97_YFL^YS@@/``?8PG-=I?G:FG-9?]S6CX_9(G02'@"^
MW3;B;*7Y7,79)YZO?=JYSGGMP@/`=]N.V!YG:VOFV4*S';"=U^.B`0!'N>V#
MSGUNCPGG<<1FV@'@*/=Y'+G-'_G%/JSX4"VM`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W-H96QL+G!N
M9P``````````````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#<S-``Q,#4Q
M-30S,S<W,P`P,C(U-C8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3
M````P%!,5$7\_OQ<LOQ,KOR4CJ04BNQ$=J04=MPT;KP\:K0T:KPL:K0\7J1$
M7FP\7G0T7G0T6G0L4H0T3GQ$2F1,2DP\2EPD2IP<2IP<2I0\1EP<2H0,1HP<
M/G0D.EPD-E0$.F0,+E04*E0,*E0$*DP,)DP,)E0,)D0$(D0```#___\`````
M````````````````````````````````````````````````````````````
M``````````````````````````!V=%24````*7123E/_________________
M____________________________________`%+T((<````!8DM'1#\^8S!U
M````"7!(67,```!(````2`!&R6L^````@$E$0508TUV/BQ*"(!!%KY;2P^RQ
MEJ6DU/KZ_R\,U[#DP#++G3/+@,$#57Z;US7O!A2[[1>EU.;1(EX[@C!8[3M$
M1\<A39,3(^O_X1KWG@"R/<;`O&P`(MBKI&)@L@F3D3E#%#:_&:*(X;UR6036
M.#^UUF/)63+>IN%FWMS"__X'6+$;U2?4JQL`````245.1*Y"8((`````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]S:&]W7W!A;F5L+G!N9P``````
M````````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`V,C0`,3`U,34T,S,W-S(`,#(S
M-C$S`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````0````$`@"````D)%H-@```5M)1$%4>-J5
M4CU+`T$4?&]W(S$84*OT@E4X2&TAV-D$@F",(?_"@T"0F`L!X2"<@?2*URA:
MG(V=C>5AN,`U"?<'4@2%2+3:M7CQ[HP?F%?-SLZ\68;%D^,C6&0$`&2SN_]4
M^_Z](/3D^OB+2$K%&$JI&.=+21``L+>_L[&YCHB,,42\O;ZH&Z;G>2&CE$)$
M1+RY.I\E<,XU30.`;K=+3+/9)!$=#<,@+``@9-^F[\NI9*E8(`.MCR?,#"0%
M@)X[?)U,5]*I@\,[V[;#7:U6BYX7&4B=2(A^+WAYGJRNI8,@H*V,,2DEI46&
MGCM\?.@3)E"KU4A!3S)-\XLA/M5&Q7&<7"[WO:7(L+6M`<!I_;+:J)2*A7P^
M7RZ7XWVTV^W(H)0:C4:93*;:J-BV'0P\4OS5DA!B/!X3>S;P`$#7=;I"1,NR
MYEOBG./G$-/I=$*&$GXV$#O'Q&O%1;_W!XX)@0TJ8.UA`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O<W%L+G!N9P``````````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`R,#$R`#$P-3$U-#,S-S<R`#`R,C(T-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$````!`(`P```"@M#U,````$9T%-00``L8Y\^U&3````(&-(
M4DT``'HE``"`@P``^?\``(#I``!U,```ZF```#J8```7;Y)?Q48```,`4$Q4
M1?SI._OG._SK/?G?.?;2-F59,$]!%6Q?-%M0+5Q/*V%4+O*V3>^T3?>U1/>U
M1?2R1->N=````/___P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'I#\!L````3=%).4________________________P"R?=P(````"7!(
M67,```L3```+$P$`FIP8````54E$050HSW6/6PK`,`@$[?O==/;^A^U')#&%
MBN`ZZ(JF3UA1T`*Z@PCHKST"[%[B"D-:"::,YT:Y`N*9P.\8B!F4TP$1R(<K
MJ-T/<$GK(;(3Q&]S>0'V#!$%YH6,:P````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T86)?8F]T
M=&]M+F=I9@``````````````````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P-#4`,3`U
M,34T,S,W-S(`,#(S-38T`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````$=)1C@W810``0"``0````#___\L`````!0``0```@2$
MCYD%`#L`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92\`````````````````
M`````````````````````````````````````````````````````#`P,#`W
M-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S<R`#`R
M,3<P,P`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T
M<F5E+V)L86YK+G!N9P``````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`R
M-C(`,3`U,34T,S,W-S$`,#(S-#<W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````4````%`@#
M```!S5#=J0````1G04U!``"OR#<%BND````9=$58=%-O9G1W87)E`$%D;V)E
M($EM86=E4F5A9'EQR64\````!E!,5$7___\```!5PM-^`````7123E,`0.;8
M9@```"5)1$%4>-IB8$``@`""(X``0D8``80?`000F0@@@.B+``)L^"$``;8`
M`?2%K84`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]F;VQD97(N
M<&YG````````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,C<P`#$P-3$U-#,S
M-S<R`#`R,S8V-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```&`
M4$Q41?WSU/WVW***5/KDL+^$.\*-.G9;)+^(.O?KR^SFVJR69L:4/N7<R_?=
MG_3FP/OHN?SVYJ^:;//0@_#DQMW">;ZQF.7.E.'4L/SLPOG;>LF[H-"^F[^%
M.\"*._;NWN/#@JZ??Z6-6)^'4-?)K/;9EN#3K\^M5<.0/-_3O8QK-'=5(NWG
MW<BRB*F38<&+.[JH@M>X8?G;>_76C-#%K?CAJ.K9K/O=?7-8(__[\<.1._SC
MD/[WY/SIJO[OP?_UTWM4(OWPRZ"&3____P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````%*X3_X```!#=%).4_______
M____________________________________________________________
M_____________________P!!8@3O`````6)+1T1_2+]QY0````EP2%ES````
M2````$@`1LEK/@```())1$%4&--ES]<:P4`00.'=Z#U!=$%$%YWH:[S_0YDA
M@R\YE__=$<]`(@QI`'#_8%F54@Z,'_22`@-*VQ+`XUM>>T.MDSGYJ;B)4!CI
M1S]KYB%$8A>NE"+8+>[</DN0:]^XRIC`25RY<I]@TSISJR:"78S6#Y_6PSE"
M`R:*FWK=\.T+K[DUCU88@X$`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]F
M;VQD97)O<&5N+G!N9P``````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,S4U`#$P
M-3$U-#,S-S<Q`#`R-#4U,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M
M#U,```&`4$Q41?WSU/WVW/OHN7-8(Z**5,:50L2YH\2,/??MUL:\I[JEBN#!
MAX=O/=BL4_/OY^C4H?+4DOCAJ*F38<K`K9A\4IR"2>#3K]O3PJ64;\RM7OKD
ML*6-6,:60>ODU9F#5/OKO_C:>ZR69H%I,\[!IN#(A8UL-/7MV??KR]ZW;>[@
MOKJH@IF%6?3:HL61/X9M.MJM7_3FP.'4L-#%K>/"?]FO89ET,Z^:;/;<C?_Z
M[<*0.__RR?_VW/SEEOO>?OWJL/WPR_SLPGM4(J"&3___________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M_____________________________________________P1"A,4```"`=%).
M4___________________________________________________________
M____________________________________________________________
M__________________________________________________\`.`5+9P``
M``%B2T=$?TB_<>4````)<$A9<P```$@```!(`$;):SX```!Z241!5!C38ZA'
M`PR8`LP@@"3`;,C(R"C&C"2@S@`$S'!U#,SV<&#`#!9P0`"(`!.3L8PE!#@"
MM3$P2^FP<EA`@!J?.`\#LZ`)MS44:,HR`[4(Z,I;00&_,DA`7\,.!E2808:R
MF]O`@"1(0)77%@84P-;6.R(`,S;?`@"T34;?=EBG0@````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M=')E92]J;VEN+G!N9P``````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,S`U`#$P-3$U-#,S-S<R`#`R,S,T-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````%````!0(
M`P```<U0W:D````$9T%-00``K\@W!8KI````&71%6'13;V9T=V%R90!!9&]B
M92!);6%G95)E861Y<<EE/`````903%1%````____I=F?W0````)T4DY3_P#E
MMS!*````-TE$051XVF)@9(!#@`!B8&2$((``0D8``01$C&`&5A(@@!CP,"$`
MJP*``(*0]&("!!@2<Y@(`@`XE@&"^PI?*P````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O:F]I;F)O
M='1O;2UD;W=N+G!N9P``````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$U-P`Q,#4Q-30S
M,S<W,0`P,C4U-#0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!0````4`0,```"W1X].````
M!E!,5$4```#___^EV9_=`````G123E/_`.6W,$H````6241!5!A78_S/\)&1
M)!SV&T(W%&*C`1_`)S6Z\9=?`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+VIO:6YB;W1T;VTN<&YG````
M````````````````````````````````````````````````,#`P,#8T-``P
M,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S,#,`,3`U,34T,S,W-S$`,#(T-3<P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R("``8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,#``,#`P,#`P,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````4````%`@#```!S5#=J0````1G04U!``"OR#<%
MBND````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\````!E!,
M5$4```#___^EV9_=`````G123E/_`.6W,$H````U241!5'C:8F!D@$)&1H``
M`F((`@@@.`("@`#"3P($$`,>)@0PP@$2$R"`Z,L$"#`DYC`1!``^<0&&@DF8
M,P````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O=')E92]L96%F+G!N9P``````````````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`P,S,P`#$P-3$U-#,S-S<Q`#`R,S,Q,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$````!`$`P```.W=XE(````84$Q416YM=9.1G,_,V/___P```/__
M_P```````,%CRF(````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES
M```+$P``"Q,!`)J<&`````=T24U%!]0,%!,M,$=CKCH````Y241!5'C:8V!@
M8'!Q<7$`4@PLCDJ*8(:3D[$1B,&B#&6XN$`9CDI*$(:3L3$E#*`Y$+M<7&"V
M0P``/6<27`BUH(,`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+W1R964O;&EN92YP;F<`````````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#,P,0`Q,#4Q-30S,S<W,@`P,C,S,S(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!0````4
M"`,```'-4-VI````!&=!34$``*_(-P6*Z0```!ET15AT4V]F='=A<F4`061O
M8F4@26UA9V5296%D>7')93P````&4$Q410```/___Z79G]T````"=%).4_\`
MY;<P2@```#-)1$%4>-IB8&2`0X``8F!DA""``$)&``$$1(Q@!E82((`8R&,"
M!!"$I!<3(,"0F,-$$``_4P&'P_V4C0````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+VUI;G5S
M+G!N9P``````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S-C$`,3`U,34T
M,S,W-S(`,#(S-30T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````4````%`@#```!S5#=J0``
M``1G04U!``"OR#<%BND````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A
M9'EQR64\````"5!,5$60D)````#___^)`$\A`````W123E/__P#7R@U!````
M7TE$051XVF)@8F1B8&("8D8F@``"T@Q`P,0$$$!`Q`@2`D&```)),C'A(@$"
M"$PRPI@,$.U@)B,C(QBCB,+4`@001#-^)E07N@)&1N+50@%`@"$QR19D0%-!
M#4'RG00`1+,"U']6M%P`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]M:6YU<V)O='1O;2YP;F<`
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S4T`#$P-3$U-#,S-S<R`#`R-#<W
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````%````!0(`P```<U0W:D````$9T%-00``K\@W
M!8KI````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/`````E0
M3%1%D)"0````____B0!/(0````-T4DY3__\`U\H-00```%I)1$%4>-IB8&)D
M8F!B`F.```)B!B!@8@((("!B!`F!($``@20@TMA(@``"DXPP)@-$.YC)R,@(
MQBBB,``00,0PH;K0%3`R$J\6"@`"#(E)MB`#F@IJ")+O)`!'I0+6O/JDQP``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+W1R964O;6EN=7-O;FQY+G!N9P``````````````````
M```````````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P
M-S8T,0`P,#`P,#`P,#,T-@`Q,#4Q-30S,S<W,@`P,C0T-3$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P,``P,#`P,#`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!0````4"`,```'-4-VI````!&=!34$``*_(-P6*Z0```!ET15AT
M4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P````)4$Q419"0D````/__
M_XD`3R$````#=%).4___`-?*#4$```!4241!5'C:8F!B8F*`8H```F(&(&!B
M`@@@$`<D!((``01C8R<!`@A"PI@,$.U@)B,C(QBCB,(`0``1PX3J0E?`R$B\
M6B@`"#`D)MF"#&@JJ"%(OI,`3&D"V65>_-``````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]T<F5E+VUI;G5S=&]P+G!N9P``````````````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`S-38`,3`U,34T,S,W-S(`,#(T,C<S`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````4````
M%`@#```!S5#=J0````1G04U!``"OR#<%BND````9=$58=%-O9G1W87)E`$%D
M;V)E($EM86=E4F5A9'EQR64\````"5!,5$60D)````#___^)`$\A`````W12
M3E/__P#7R@U!````7$E$051XVF)@8F)B`&-&)H```M(,0,#$!!!`(`&0$`@"
M!!",C9T$""`("6,R0+2#F8R,C&",(LH$M`4$``((51MV)E07N@)&1N+50@%`
M@"$QR19D0%-!#4'RG00`27<"UU!#0:0`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]N=6QL
M;VYL>2YP;F<`````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S0T`#$P-3$U
M-#,S-S<Q`#`R-#(V-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````%````!0(`P```<U0W:D`
M```$9T%-00``K\@W!8KI````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E
M861Y<<EE/`````E03%1%````D)"0____\OT?)0````-T4DY3__\`U\H-00``
M`%))1$%4>-IB8&)B8H!B@``"8@9&1B`)$$`@#DB($0@!`@C&QDX"!!"$A#$9
M00#*!%*,#$"`(@H#``%$#!.JBXERM0`!AL0D6Y`1RF&DHB#Y3@(`<,$"^T4;
M)Q(`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O<&QU<RYP;F<`````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,V-P`Q,#4Q-30S,S<W,0`P,C,T
M,#$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!0````4"`,```'-4-VI````!&=!34$``*_(
M-P6*Z0```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P````)
M4$Q419"0D````/___XD`3R$````#=%).4___`-?*#4$```!E241!5'C:8F!B
M9&*`8H``8F!B8@`")B:```(B1B";B8&1@0D@@(!L)A`;.PD00&"2$<9D@&@'
M,QD9&<$8112F%B"`()KQ,Z&ZT!4P,A*O%@H``@R)2;8@`YH*N"`CT8+8:#*=
M!`!`E@+0YPH+]@````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]T<F5E+W!L=7-B;W1T;VTN<&YG````````````````
M````````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`S-C0`,3`U,34T,S,W-S$`,#(T-C(S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````4````%`@#```!S5#=J0````1G04U!``"OR#<%BND````9=$58
M=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\````"5!,5$60D)````#_
M__^)`$\A`````W123E/__P#7R@U!````8DE$051XVF)@8F1B`&,F)H```F(&
M(&!B`@@@(&($LID8&!F8``((),'$A(L$""`PR0AC,D"T@YF,C(Q@C"(*`P`!
M1`P3J@M=`2,C\6JA`"#`D)AD"S*@J8`+,A(MB(TFTTD`0X@"TJ-$18L`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O=')E92]P;'5S;VYL>2YP;F<`````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,S8R`#$P-3$U-#,S-S<R`#`R-#(W-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````%```
M`!0(`P```<U0W:D````$9T%-00``K\@W!8KI````&71%6'13;V9T=V%R90!!
M9&]B92!);6%G95)E861Y<<EE/`````E03%1%D)"0````____B0!/(0````-T
M4DY3__\`U\H-00```&!)1$%4>-IB8&)B8F!B!&(F)H```F(&(&!B`@@@$`<D
MS,#(P`000#`V=A(@@"`DC,D`T0YF,C(R@C&**`P`!!`Q3*@N=`6,C,2KA0*`
M`$-BDBW(@*8"+LA(M"`VFDPG`0!(3`+5@:.2``````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O<&QU
M<W1O<"YP;F<`````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,V-0`Q,#4Q
M-30S,S<W,@`P,C0Q,C,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!0````4"`,```'-4-VI
M````!&=!34$``*_(-P6*Z0```!ET15AT4V]F='=A<F4`061O8F4@26UA9V52
M96%D>7')93P````)4$Q419"0D````/___XD`3R$````#=%).4___`-?*#4$`
M``!C241!5'C:8F!B8F)@8@1C@`!B`#*!@(D)(("`""S,P,C`!!!`,#9V$B"`
M("2,R0#1#F8R,C*",8HH$]`6$``((%1MV)E07>@*&!F)5PL%``&&Q"1;D`%-
M!5R0D6A!;#293@(`15H"TS4)<68`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````N+W5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUJ;VEN+G!N9P``
M````````````````````````````````````````````````````,#`P,#8T
M-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P,30`,3`U,34T,S,W-S$`,#(T
M,3,U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R("``8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,#``,#`P,#`P,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````4````%`@#````NE?M/P````E03%1%````
M____````<\:#<0````-T4DY3_P``1.[P,P```:])1$%4>`$!I`%;_@`!`0$!
M`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!
M`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!
M`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!
M`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!
M`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!``$``0`!``$``0`!`0$!`0$!
M`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!
M`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!
M`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!
M`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!
M`0$!`0$!`0$!`3U)`8*<4[F3`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUJ;VEN
M8F]T=&]M+61O=VXN<&YG````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P,C0`,3`U,34T,S,W
M-S$`,#(V,S,P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````4````%`@#````NE?M/P````]0
M3%1%````____````````````@FO25@````5T4DY3_P`````(#\$]```!KTE$
M051X`0&D`5O^``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!`0$!
M`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!
M`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!
M``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!
M`0$!`0$!`0$!`0$!`0$!`0$!``$``0`!``$``0`!``$!`0$!`0$!``$!`0$!
M`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!`0$!
M`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!`0$!`0$!
M`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!`0$!`0$!`0$!
M`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!
M`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!0L(!AKX,7;,`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W)E
M=BUJ;VEN8F]T=&]M+G!N9P``````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$P,30`,3`U
M,34T,S,W-S(`,#(U,S8S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````4````%`@#````NE?M
M/P````E03%1%````____````<\:#<0````-T4DY3_P``1.[P,P```:])1$%4
M>`$!I`%;_@`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!
M`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!
M`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!
M`0$!`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!
M`0$!`0$!`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!``$``0`!
M``$``0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!
M`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0$!
M`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!
M`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!
M`0`!`0$!`0$!`0$!`0$!`0$!`0$!`3Z]`89`I&Z1`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T
M<F5E+W)E=BUL96%F+G!N9P``````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`S
M,C<`,3`U,34T,S,W-S(`,#(T,3$T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````0````$`0#
M````[=WB4@```!A03%1%;FUUDY&<S\S8____````____````````P6/*8@``
M``%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8
M````!W1)344'U`P4$RX`2I?-50```#A)1$%4>-IC8&!Q<7%A``$6(241!S!#
MV5A%!<8P<H`RP*J`#"4E$0C#V%B%?(:0$M0<%Q>8_6```*'Y#,L$!T:]````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M;&EN
M92YP;F<`````````````````````````````````````````````````````
M`#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#$T`#$P-3$U-#,S
M-S<R`#`R-#$R-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````%````!0(`P```+I7[3\````)
M4$Q410```/___P```'/&@W$````#=%).4_\``$3N\#,```&O241!5'@!`:0!
M6_X``0$!`0$!`0$!`0$``0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$`
M`0$!`0$!`0$!`0$``0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!
M`0$!`0$!`0$``0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!
M`0$!`0$``0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!
M`0$``0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$`
M`0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$``0$!
M`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$``0$!`0$!
M`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$``0$!`0$!`0$`
M`0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$``0$!`0$!`0$``0$!
M`0$!`0$!`0$!`0$!`0$!`0%!10&'U?'8@0````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R
M978M;6EN=7,N<&YG````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#(P`#$P
M-3$U-#,S-S<R`#`R-#,R-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````%````!0(`P```+I7
M[3\````,4$Q419"0D````/___P```+$OIH8````$=%).4___``#3#E2&```!
MKTE$051X`0&D`5O^``("`@("`@("`@("`0("`@("`@("``("`@("`@("`@("
M`@("`@("`@("``("`@("`@("`@("`0("`@("`@("``("`@("`@("`@("`@("
M`@("`@("``("`@("`@("`@("`0("`@("`@("``("`@("`@("`@("`@("`@("
M`@("``("`@("`@(````````````"`@("``("`@("`@(``@("`@("`@`"`@("
M``("`@("`@(``@("`@("`@`"`@("``("`@("`@(``@("`@("`@`"`@("``(!
M`@$"`0(``@$!`0$!`@`"`@("``("`@("`@(``@("`@("`@`"`@("``("`@("
M`@(``@("`@("`@`"`@("``("`@("`@(``@("`@("`@`"`@("``("`@("`@(`
M```````````"`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("
M`0("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`0("
M`@("`@("``("`@("`@("`@("`@("`@("`@("58H"U/'-.:T`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M=')E92]R978M;6EN=7-B;W1T;VTN<&YG````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q
M,#(P`#$P-3$U-#,S-S<R`#`R-34U-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````%````!0(
M`P```+I7[3\````,4$Q419"0D````/___P```+$OIH8````$=%).4___``#3
M#E2&```!KTE$051X`0&D`5O^``("`@("`@("`@("`0("`@("`@("``("`@("
M`@("`@("`@("`@("`@("``("`@("`@("`@("`0("`@("`@("``("`@("`@("
M`@("`@("`@("`@("``("`@("`@("`@("`0("`@("`@("``("`@("`@("`@("
M`@("`@("`@("``("`@("`@(````````````"`@("``("`@("`@(``@("`@("
M`@`"`@("``("`@("`@(``@("`@("`@`"`@("``("`@("`@(``@("`@("`@`"
M`@("``(!`@$"`0(``@$!`0$!`@`"`@("``("`@("`@(``@("`@("`@`"`@("
M``("`@("`@(``@("`@("`@`"`@("``("`@("`@(``@("`@("`@`"`@("``("
M`@("`@(````````````"`@("``("`@("`@("`@("`@("`@("`@("``("`@("
M`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("
M`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("5?`"UF*5DUX`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O=')E92]R978M;6EN=7-O;FQY+G!N9P``````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`Q,#(P`#$P-3$U-#,S-S<Q`#`R-3(S,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M%````!0(`P```+I7[3\````,4$Q419"0D````/___P```+$OIH8````$=%).
M4___``#3#E2&```!KTE$051X`0&D`5O^``("`@("`@("`@("`@("`@("`@("
M``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("
M`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("
M`@("`@("`@("`@("`@("``("`@("`@(````````````"`@("``("`@("`@(`
M`@("`@("`@`"`@("``("`@("`@(``@("`@("`@`"`@("``("`@("`@(``@("
M`@("`@`"`@("``(!`@$"`0(``@$!`0$!`@`"`@("``("`@("`@(``@("`@("
M`@`"`@("``("`@("`@(``@("`@("`@`"`@("``("`@("`@(``@("`@("`@`"
M`@("``("`@("`@(````````````"`@("``("`@("`@("`@("`@("`@("`@("
M``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("
M`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("6CH"V7._
MZ[8`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O=')E92]R978M;6EN=7-T;W`N<&YG````````````````
M`````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W
M-C0Q`#`P,#`P,#`Q,#(P`#$P-3$U-#,S-S<R`#`R-3`U,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`P`#`P,#`P,#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````%````!0(`P```+I7[3\````,4$Q419"0D````/___P```+$OIH8`
M```$=%).4___``#3#E2&```!KTE$051X`0&D`5O^``("`@("`@("`@("`@("
M`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("
M`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("
M``("`@("`@("`@("`@("`@("`@("``("`@("`@(````````````"`@("``("
M`@("`@(``@("`@("`@`"`@("``("`@("`@(``@("`@("`@`"`@("``("`@("
M`@(``@("`@("`@`"`@("``(!`@$"`0(``@$!`0$!`@`"`@("``("`@("`@(`
M`@("`@("`@`"`@("``("`@("`@(``@("`@("`@`"`@("``("`@("`@(``@("
M`@("`@`"`@("``("`@("`@(````````````"`@("``("`@("`@("`@("`@("
M`@("`@("``("`@("`@("`@("`0("`@("`@("``("`@("`@("`@("`@("`@("
M`@("``("`@("`@("`@("`0("`@("`@("``("`@("`@("`@("`@("`@("`@("
M6=0"UP'^LJP`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M;G5L;&]N;'DN<&YG````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`Q,#(P`#$P-3$U-#,S-S<R`#`R-3`U,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````%````!0(`P```+I7[3\````,4$Q410```)"0D/___P``
M`,^1W=0````$=%).4___``#3#E2&```!KTE$051X`0&D`5O^``("`@("`@("
M`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("
M`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("
M`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@(!`0$!`0$!`0$"
M`@("``("`@("`@(!`@("`@("`@$"`@("``("`@("`@(!`@("`@("`@$"`@("
M``("`@("`@(!`@("`@("`@$"`@("``(``@`"``(!`@("`@("`@$"`@("``("
M`@("`@(!`@("`@("`@$"`@("``("`@("`@(!`@("`@("`@$"`@("``("`@("
M`@(!`@("`@("`@$"`@("``("`@("`@(!`0$!`0$!`0$"`@("``("`@("`@("
M`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("
M`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("
M`@("`@("=&X"^Y064:@`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M<&QU<RYP;F<`````
M`````````````````````````````````````````````````#`P,#`V-#0`
M,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#(P`#$P-3$U-#,S-S<R`#`R-#$U
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<B`@`&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`P`#`P,#`P,#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````%````!0(`P```+I7[3\````,4$Q419"0D```
M`/___P```+$OIH8````$=%).4___``#3#E2&```!KTE$051X`0&D`5O^``("
M`@("`@("`@("`0("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("
M`@("`@("`0("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("
M`@("`0("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@(`````
M```````"`@("``("`@("`@(``@("`@("`@`"`@("``("`@("`@(``@("`0("
M`@`"`@("``("`@("`@(``@("`0("`@`"`@("``(!`@$"`0(``@$!`0$!`@`"
M`@("``("`@("`@(``@("`0("`@`"`@("``("`@("`@(``@("`0("`@`"`@("
M``("`@("`@(``@("`@("`@`"`@("``("`@("`@(````````````"`@("``("
M`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`0("`@("`@("``("`@("
M`@("`@("`@("`@("`@("``("`@("`@("`@("`0("`@("`@("``("`@("`@("
M`@("`@("`@("`@("4G("T,D.HAT`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M<&QU<V)O
M='1O;2YP;F<``````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#(P`#$P-3$U-#,S-S<R
M`#`R-30P-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````%````!0(`P```+I7[3\````,4$Q4
M19"0D````/___P```+$OIH8````$=%).4___``#3#E2&```!KTE$051X`0&D
M`5O^``("`@("`@("`@("`0("`@("`@("``("`@("`@("`@("`@("`@("`@("
M``("`@("`@("`@("`0("`@("`@("``("`@("`@("`@("`@("`@("`@("``("
M`@("`@("`@("`0("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("
M`@(````````````"`@("``("`@("`@(``@("`@("`@`"`@("``("`@("`@(`
M`@("`0("`@`"`@("``("`@("`@(``@("`0("`@`"`@("``(!`@$"`0(``@$!
M`0$!`@`"`@("``("`@("`@(``@("`0("`@`"`@("``("`@("`@(``@("`0("
M`@`"`@("``("`@("`@(``@("`@("`@`"`@("``("`@("`@(````````````"
M`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("
M``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("
M`@("`@("`@("`@("`@("`@("4M@"TM??/=X`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M
M<&QU<V]N;'DN<&YG````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#(P`#$P-3$U
M-#,S-S<Q`#`R-3`V,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````%````!0(`P```+I7[3\`
M```,4$Q419"0D````/___P```+$OIH8````$=%).4___``#3#E2&```!KTE$
M051X`0&D`5O^``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("
M`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("
M`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("
M``("`@("`@(````````````"`@("``("`@("`@(``@("`@("`@`"`@("``("
M`@("`@(``@("`0("`@`"`@("``("`@("`@(``@("`0("`@`"`@("``(!`@$"
M`0(``@$!`0$!`@`"`@("``("`@("`@(``@("`0("`@`"`@("``("`@("`@(`
M`@("`0("`@`"`@("``("`@("`@(``@("`@("`@`"`@("``("`@("`@(`````
M```````"`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("
M`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("`@("
M`@("``("`@("`@("`@("`@("`@("`@("5R("U8/XR/``````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E
M92]R978M<&QU<W1O<"YP;F<`````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,#(P
M`#$P-3$U-#,S-S<R`#`R-#<P,@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````%````!0(`P``
M`+I7[3\````,4$Q419"0D````/___P```+$OIH8````$=%).4___``#3#E2&
M```!KTE$051X`0&D`5O^``("`@("`@("`@("`@("`@("`@("``("`@("`@("
M`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("
M`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("
M`@("`@("``("`@("`@(````````````"`@("``("`@("`@(``@("`@("`@`"
M`@("``("`@("`@(``@("`0("`@`"`@("``("`@("`@(``@("`0("`@`"`@("
M``(!`@$"`0(``@$!`0$!`@`"`@("``("`@("`@(``@("`0("`@`"`@("``("
M`@("`@(``@("`0("`@`"`@("``("`@("`@(``@("`@("`@`"`@("``("`@("
M`@(````````````"`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("
M`@("`0("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("
M`0("`@("`@("``("`@("`@("`@("`@("`@("`@("5KP"TP&:N0,`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O=6YL;V-K960N<&YG````````````````````````````````````````
M`````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`Q,C$U`#$P-3$U-#,S-S<R`#`R,S(U-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$```
M`!`(`P```"@M#U,```#G4$Q410````0#`@4$`P@("`L+!QH3"Q86%A<7%R\I
M(2XN+DU-38%:*W)R<JIO*Z1Q-JQQ+JUS,J!W1*-[2X2$A*1^3JB!3+1^/J>"
M4J>"4[B`/JJ$5:N'6*R'6+J$0JN(6+J&1[R'1KR(2;J)2Z^-7JV-9+R*3+"-
M7[V,3J61=KZ-4,:67<>;9*BCGLJ?:*JJJLND<<ZD<,VF;LVF=M"F=,RG>]"H
M=,^K?+&QL<^L>\VL@\ZM@]2L>=6N?M*RB=6RA-BUC+R\O-:ZE,'`P-J^FN#"
MGN'"G.#$H-_$H^'$H.+%H>/&HMO;VP```(1/:.H````!=%).4P!`YMAF````
M`6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,%!(N
M(IXUYH8```",=$58=$-O;6UE;G0`365N=2US:7IE9"!I8V]N"CT]/3T]/3T]
M/3T*"BAC*2`R,#`S($IA:W5B("=J:6UM86,G(%-T96EN97(L(`IH='1P.B\O
M:FEM;6%C+FUU<VEC:&%L;"YC>@H*8W)E871E9"!W:71H('1H92!'24U0+`IH
M='1P.B\O=W=W+F=I;7`N;W)G9XK'1P```(=)1$%4>-IC8,`!?'Q\T`2\'7B8
M4038N<R%T71QZJ'I8G/R01C(PLC(Q*'#"N5KN+F[.SL[.QIQ0Y3X>-KKRHB+
M2P@I\D,%O&S4[,S,+/05>*$"'L;:4B(B(H*R,!6N!BJVEI96)I("4`$7:T-E
M:6DY404QJ("IEJ:FDI*ZJCR?#]P=4(#-VP#J$!=,:G,FXP````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O=7-E<BYP;F<`````````````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,S0R`#$P-3$U-#,S-S<S`#`R,C0S,@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$````!`(`P```"@M#U,````$9T%-00``L8Y\^U&3````(&-(4DT``'HE
M``"`@P``^?\``(#I``!U,```ZF```#J8```7;Y)?Q48```,`4$Q412(B(PH,
M$,7&R`P0%N;HZR4H+`P0%2@L,3=&5A@>)6]_D7R*F9:AK:"KM[O&TD5A?DUJ
MAU)NBTYH@UUYE0H-$&:"GD58:VB$H%5L@SU-7EEPB&V)I5ANA'..J@D+#6!R
MA7Z5K!TB)V1O>HV9I8F0E]7;X>?J[?+S]$YF?6>#GEQTBV^+ID569G61K%!C
M=7R5K8F=L(J>L)JLO:>XQV]ZA!D=()&9GY"8GLG3VPD-#Q(4%1,5%@T1$A$1
M$!@8%TM(1!,*`!L/`4$D!38?!9M8#\MU&<QV&LAT&M%Z'=!Z'=%['L5U',)S
M'--]'\5T'<%S'0X'``H%``@$`#4<`A4+`284`C(;`V4V!T<F!5LQ!S4=!#0<
M!)-/#2P8!*5<$'Q%#"D7!*Q@$8I,#GE##+5D$R85!!T0`[YJ%;9F%*E?$RT9
M!8-)#\IR&,QU&<UV&LQU&A@.!"X8`T(C!30;!#$:!"\9!#H?!5DV%44O&DPZ
M*1H2#"0>&BDF)LS,S$1$1"4E)1T='08&!@```/___P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````*^/
M>BL```"$=%).4_______________________________________________
M____________________________________________________________
M____________________________________________________________
M________`)?2-KX````)<$A9<P``"Q(```L2`=+=?OP```"\241!5"C/8V@&
M@280`+.:&4"$;9.]?2!4!"30T&A?5P]48@L3L'.H#`E(2W5NA`DX.GG[^?NX
MQP?!!&(C/;Q\/?.2LV`")9FY;OFN.1FE,($RE_3LT,*DE"*XM1$Q88EQ$>'!
M,`&;FO+BJ.B$"DXYB`"KF8%)=4$5@Y*.I"5(@)U75E=/I99)F4M"1DRDF<'*
M7%]:6XM;7<U80558@X.1P9I'5%-<2I[%PDB53U50B(W!U%``"?`S,RBB`0!I
M=53+W.V4MP````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]W96)S:71E+G!N9P``
M````````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(T,#0`,3`U,34T,S,W
M-S,`,#(S,3$U`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P````1G
M04U!``"QCGS[49,````@8TA230``>B4``("#``#Y_P``@.D``'4P``#J8```
M.I@``!=ODE_%1@```P!03%1%```!!PT4"A\U!A$<$"I$&#A8%C-1&CU?#1XO
M&#95!@T4'3Y@($)D)49F&"H\+U%R'24M/T5+.SY!:6QO(T1C*$QM'#5,*4EH
M+U5W#1<@,E9V,U5S/F.&/EUY3'"126R+1&)_3F^.'B<O?9>N,UAX+4QG/F2$
M/F.#2G"06(&B6WJ57GV7?9RU'2,HD*J_CJ>\0$M4QM+<`PP3!0H.376588BG
M8H*;>Y^[?Z._B*K$>9>O@:&YA*2\@:"W@)ZV?9JQC:W%@)RRB:>]BZ>].4-+
MF;3(F[;*F;+&G;?*G;;)G[?*I[_1H;C*K\34J[_/+C(UR-CDQ];BS=SH!PH,
M$1@=*38_@:.[E[C0E+7,E[C/?9BKDK#$77!]C:B[H;W1F[;)0T]7K,K>-#U#
MK<76K<75JL+2J<'1O-7GI+G(K\75O-+APM?FN]#>.D!$P-'=R]SHQM?CQ=;B
M2E!4V.7NV>7MV.3LK[B^MK_%UN#G4%-5:8:9J\C;LL_BHKS-I;[.O]GIKL73
MN]+@OM/@Q]SIQ-CDR-OGQMCCR-GDSM_JW.GQN]'>TM[E?H6)-SU`FZBOU>3L
M0T5&5UYA!@D*````____````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````99GS40```)5T4DY3________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M_P`V9!LX````"7!(67,```L3```+$P$`FIP8````S4E$050HSV.8@@880(3+
MQ,H)0H)*<(%<X;*2SOS`<O\0B$!O3T5_<W9+:;%APB200&A1=WM3?7I684!0
MABY(P*`O+ZZZ)K&QP-<O)68R4"!)V<XA(CRRHRVG(3Z*`2@@X.P49FYAV=J5
M6:>G"!*0E/-,MC'5U+'W]G+D!VF1E'=/2[4UT9#Q<=7F!`D8BYEYU&JIJ4O$
M1LLR@P2F,(J[Z4NK2(E:63,Q@!TVF:M*@8=7A%N5;_)DB-,G!W.PL;.R&('X
M$,]-F0P&"-\B`P"^%F<]J>%K2@````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+WIA+G!N9P``````````````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#(W,``Q,#4Q-30S,S<W,P`P,C(P-C0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@````D````)`@,```"=_^Z#````"5!,5$6Z`!9F9F8```",M<Q"`````712
M3E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'
M=$E-10?4#!01-@M<VECJ````*$E$051XVF-@``*M50P,4BL9&+A6,#"P+6%@
M8%K`P,`X`2C1`))E``!9YP2G>URP]`````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F5E;B\`````
M````````````````````````````````````````````````````````````
M````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P
M,#``,3`U,34T,S,W-C$`,#(P,C0R`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R965N+VEN9F\N<&AP````````````````````````````````
M```````````````````````````````````````P,#`P-C0T`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#$W,``Q,#4Q-30S,S<V,0`P,C$W,#0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+V=R965N+VEN9F\N<&AP+'8@,2XQ
M(#(P,#0O,3`O,3<@,3DZ,S,Z,S4@;61J=6MI8R!%>'`@)`H@*B\*"B1T:&5M
M95]N86UE(#T@7R@B1W)E96XB*3L*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F5E
M;B]S8W)E96XN8W-S````````````````````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#(T,C4`,3`U,34T,S,W-C$`,#(R,C,V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"\J*@H@*B`D2&]R9&4Z(&AO<F1E
M+W1H96UE<R]G<F5E;B]S8W)E96XN8W-S+'8@,2XU+C8N-"`R,#`U+S$P+S$X
M(#$Q.C,T.C$W(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@8F%C:V=R;W5N
M9#H@(S$P-&4T8SL*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C,3`T931C
M.PH@("`@<V-R;VQL8F%R+6%R<F]W+6-O;&]R.B`C,3,V.#8U.PI]"FAT;6P@
M>PH@("`@<V-R;VQL8F%R+6)A<V4M8V]L;W(Z(",Q,#1E-&,["B`@("!S8W)O
M;&QB87(M87)R;W<M8V]L;W(Z(",Q,S8X-C4["GT*82!["B`@("!C;VQO<CH@
M(S$S-C@V-3L*?0IA.FAO=F5R('L*("`@(&-O;&]R.B`C9F(Y,3`X.PI]"BYH
M96%D97(@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD.B`C,3,V
M.#8U.PI]"BYH96%D97(@82!["B`@("!C;VQO<CH@(V9F9CL*?0HN<VUA;&QH
M96%D97(@>PH@("`@8F%C:V=R;W5N9#H@(S$S-C@V-3L*?0HN8V]N=')O;"![
M"B`@("!B86-K9W)O=6YD.B`C9F9D,S8X.PI]"BYI=&5M('L*("`@(&)A8VMG
M<F]U;F0Z("-F-&0W.3,["GT*+F)U='1O;B!["B`@("!C;VQO<CH@(S`P,#L*
M("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F8F$R,#@["B`@("!B;W)D97(M8F]T
M=&]M.B!T:&EN('-O;&ED("-F-V4P86$["B`@("!B;W)D97(M<FEG:'0Z('1H
M:6X@<V]L:60@(V8W93!A83L*("`@(&)O<F1E<BUT;W`Z('1H:6X@<V]L:60@
M(V9F9#,V.#L*("`@(&)O<F1E<BUL969T.B!T:&EN('-O;&ED("-F9F0S-C@[
M"GT*+G-E;&5C=&5D('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F-6,Q-#0[
M"GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@("!C;VQO<CH@(V9F
M9CL*("`@(&)A8VMG<F]U;F0Z(",Q,S8X-C4["GT*(VUE;G4@82!["B`@("!C
M;VQO<CH@(V9F9CL*?0HC;65N=2!A+F-U<G)E;G0@>PH@("`@8F%C:V=R;W5N
M9#H@(S(X.#L*?0H*+RH@4VED96)A<B!S='EL97,N("HO"B-S:61E8F%R4&%N
M96P@>PH@("`@8F%C:V=R;W5N9#H@(S(X.#L*?0HC<VED96)A<E!A;F5L(&$@
M>PH@("`@8V]L;W(Z("-F9F8["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C,C@X
M.PH@("`@<&%D9&EN9RUL969T.B`Q<'@["B`@("!P861D:6YG+6)O='1O;3H@
M,G!X.PI]"B-S:61E8F%R4&%N96P@83IH;W9E<B!["B`@("!C;VQO<CH@(S`P
M,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C8V,["B`@("!B;W)D97(Z(#%P
M>"!S;VQI9"`C,#`P.PH@("`@=&5X="UD96-O<F%T:6]N.B!N;VYE.PI]"@HO
M*B!0<F5F97)E;F-E<R!O=F5R=FEE=RX@*B\*+G!R969S3W9E<G9I97<@:#(@
M>PH@("`@8V]L;W(Z("-F9F8["GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R97DO````````````````````````````
M```````````````````````````````````````````````````````P,#`P
M-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<V,0`P
M,C`Q,3``(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)E>2]I;F9O
M+G!H<```````````````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P
M,38V`#$P-3$U-#,S-S8Q`#`R,34U-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D
M92]T:&5M97,O9W)E>2]I;F9O+G!H<"QV(#$N,2`R,#`T+S$P+S$W(#$Y.C,S
M.C,V(&UD:G5K:6,@17AP("0*("HO"@HD=&AE;65?;F%M92`](%\H(D=R97DB
M*3L*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"XO=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R97DO<V-R965N+F-S<P``````
M````````````````````````````````````````````````````````````
M```P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S$R,``Q,#4Q-30S
M,S<V,0`P,C(P-S4`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(@(`!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P,``P,#`P,#`P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+V=R97DO<V-R
M965N+F-S<RQV(#$N-RXV+C$S(#(P,#4O,3`O,3@@,3$Z,S0Z,3@@:F%N($5X
M<"`D"B`J+PH*8F]D>2!["B`@("!B86-K9W)O=6YD.B`C-60U9#8P.PH@("`@
M<V-R;VQL8F%R+6)A<V4M8V]L;W(Z(",U9#5D-C`["B`@("!S8W)O;&QB87(M
M87)R;W<M8V]L;W(Z(",U9#5D-C`["GT*:'1M;"!["B`@("!S8W)O;&QB87(M
M8F%S92UC;VQO<CH@(S5D-60V,#L*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO
M<CH@(S5D-60V,#L*?0IA('L*("`@(&-O;&]R.B`C-3DU.34Y.PI]"BYW:61G
M970@>PH@("`@8V]L;W(Z(",S,S,["B`@("!F;VYT+7=E:6=H=#H@8F]L9#L*
M?0IA+G=I9&=E=#IH;W9E<B!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG
M<F]U;F0Z("-D9&0["B`@("!T97AT+61E8V]R871I;VXZ(&YO;F4["GT*+FAE
M861E<B!["B`@("!C;VQO<CH@(V1D9#L*("`@(&)A8VMG<F]U;F0Z(",U-#4T
M-38["GT*+FAE861E<B!A('L*("`@(&-O;&]R.B`C9&1D.PI]"F$N;&EG:'0Z
M:&]V97(@>PH@("`@8V]L;W(Z("-F9F8["GT*+G-M86QL:&5A9&5R('L*("`@
M(&-O;&]R.B`C.68Y9F$P.PH@("`@8F%C:V=R;W5N9#H@(S4T-30U-CL*?0HN
M8G5T=&]N('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(S4Q
M-3$V,SL*("`@(&)O<F1E<BUB;W1T;VTZ('1H:6X@<V]L:60@(S5D-60V,#L*
M("`@(&)O<F1E<BUR:6=H=#H@=&AI;B!S;VQI9"`C-60U9#8P.PH@("`@8F]R
M9&5R+71O<#H@=&AI;B!S;VQI9"`C-S<W-S@Y.PH@("`@8F]R9&5R+6QE9G0Z
M('1H:6X@<V]L:60@(S<W-S<X.3L*?0HN:71E;2!["B`@("!C;VQO<CH@(S`P
M,#L*("`@(&)A8VMG<F]U;F0Z("-E964["GT*+G-E;&5C=&5D('L*("`@(&)A
M8VMG<F]U;F0Z("-D9&0["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N=2![
M"B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z(",U-#4T-38["GT*
M(VUE;G4@82!["B`@("!C;VQO<CH@(V9F9CL*?0HC;65N=2!A+F-U<G)E;G0@
M>PH@("`@8F%C:V=R;W5N9#H@(S8V-CL*?0H*+RH@4VED96)A<B!S='EL97,N
M("HO"B-S:61E8F%R4&%N96P@>PH@("`@8F%C:V=R;W5N9#H@(S8V-CL*?0HC
M<VED96)A<E!A;F5L('-P86XL("-S:61E8F%R4&%N96P@82!["B`@("!C;VQO
M<CH@(V9F9CL*?0HC<VED96)A<E!A;F5L(&$Z:&]V97(@>PH@("`@8V]L;W(Z
M('EE;&QO=SL*?0H*+RH@5&%B('-T>6QE<RX@*B\*+G1A8G-E="!["B`@("!B
M;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(S4T-30U-CL*?0HN=&%B<V5T(&QI
M(&$@>PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",U-#4T-38["B`@
M("!B86-K9W)O=6YD.B`C93EE.64Y.PI]"BYT86)S970@;&DN86-T:79E5&%B
M(&$@>PH@("`@8V]L;W(Z("-D9&0["B`@("!B86-K9W)O=6YD.B`C-30U-#4V
M.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",U-#4T-38["GT*+G1A
M8G-E="!L:2YA8W1I=F5486(@83IH;W9E<B!["B`@("!C;VQO<CH@(V9F9CL*
M("`@(&)A8VMG<F]U;F0Z(",U-#4T-38["GT*"B\J(%!R969E<F5N8V5S(&]V
M97)V:65W+B`J+PHN<')E9G-/=F5R=FEE=R!H,B!["B`@("!C;VQO<CH@(V9F
M9CL*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]H:2UC;VYT<F%S="\`````````````````
M````````````````````````````````````````````````````````,#`P
M,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-S,`
M,#(Q-#`P`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VAI+6-O;G1R
M87-T+VEN9F\N<&AP````````````````````````````````````````````
M```````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`T-P`Q,#4Q-30S,S<W,P`P,C,P-#4`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"B1T:&5M95]N86UE(#T@7R@B
M2&DM0V]N=')A<W0B*3L*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]H:2UC;VYT<F%S="]S8W)E96XN
M8W-S````````````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#,R,34`,3`U,34T
M,S,W-S,`,#(S,S<R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````&)O9'D@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F9F9F
M9CL*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C-3`U,#4P.PH@("`@<V-R
M;VQL8F%R+6%R<F]W+6-O;&]R.B`C8V9C9F)B.PI]"FAT;6P@>PH@("`@<V-R
M;VQL8F%R+6)A<V4M8V]L;W(Z(",U,#4P-3`["B`@("!S8W)O;&QB87(M87)R
M;W<M8V]L;W(Z("-C9F-F8F(["GT*82!["B`@("!C;VQO<CH@(S`P,#`P,#L*
M?0IA.FAO=F5R('L*("`@(&-O;&]R.B`C,#`P,#`P.PI]"F$N=VED9V5T.FAO
M=F5R('L*("`@(&-O;&]R.B`C,#`P,#`P.PH@("`@8F%C:V=R;W5N9"UC;VQO
M<CH@(V9F9F9F9CL*?0HN:&5A9&5R('L*("`@(&-O;&]R.B`C,#`P,#`P.PH@
M("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F9F9F9CL*?0HN<VUA;&QH96%D97(@
M>PH@("`@8V]L;W(Z(",P,#`P,#`["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C
M9F9F9F9F.PI]"BYC;VYT<F]L('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F
M9F9F9F8["GT*+FET96T@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F9F9F
M9CL*?0HN8G5T=&]N('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",P,#`P,#`[
M"B`@("!B;W)D97(M8F]T=&]M.B!T:&EN('-O;&ED(",R,C0["B`@("!B;W)D
M97(M<FEG:'0Z('1H:6X@<V]L:60@(S(R-#L*("`@(&)O<F1E<BUT;W`Z('1H
M:6X@<V]L:60@(V-F8V9B8CL*("`@(&)O<F1E<BUL969T.B!T:&EN('-O;&ED
M("-D961E8F(["GT*+G-E;&5C=&5D('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z
M("-E-F4V9&4["GT*+FET96TQ('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-E
M-F4V9&4["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@("!C;VQO
M<CH@(S`P,#`P,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F9F9F9F8["B`@
M("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(S`P,#L*?0HC;65N=2!A('L*
M("`@(&1I<W!L87DZ(&)L;V-K.PH@("`@=VAI=&4M<W!A8V4Z('!R93L*("`@
M(&9O;G0M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC82QS86YS+7-E<FEF.PH@
M("`@9F]N="US:7IE.B`Q,7!X.PH@("`@=&5X="UD96-O<F%T:6]N.B!N;VYE
M.PH@("`@8V]L;W(Z(",P,#`P,#`["B`@("!P861D:6YG.B`S<'@["B`@("`M
M;6]Z+6)O<F1E<BUR861I=7,Z(#-P>#L*?0HC;65N=2!A.FAO=F5R('L*("`@
M(&-O;&]R.B`C,#`P,#`P.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED
M(",V-F$["B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C-C9A.PH@("`@
M8F]R9&5R+71O<#H@,7!X('-O;&ED(",R,C0["B`@("!B;W)D97(M;&5F=#H@
M,7!X('-O;&ED(",R,C0["B`@("!P861D:6YG.B`R<'@["GT*(VUE;G4@82YC
M=7)R96YT('L*("`@(&-O;&]R.B`C,#`P,#`P.PH@("`@8F%C:V=R;W5N9"UC
M;VQO<CH@(V%E865A93L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C
M965E.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(V5E93L*("`@(&)O
M<F1E<BUL969T.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)O<F1E<BUT;W`Z(#%P
M>"!S;VQI9"`C,#`P.PI]"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*(W-I9&5B
M87)086YE;"!["B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C,#`P.PH@
M("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",P,#`["B`@("!B86-K9W)O
M=6YD+6-O;&]R.B`C9F9F9F9F.PI]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O:61E87,O````````````````````````
M`````````````````````````````````````````````````````````#`P
M,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S-S8Q
M`#`R,#(R-P`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]I9&5A<R]G
M<F%P:&EC<R\`````````````````````````````````````````````````
M````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#`P,#``,3`U,34T,S,W-C$`,#(R,#(W`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+VED96%S+V=R87!H:6-S+V)A8VMG<F]U;F0N<&YG````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#0U,34V-@`Q,#4Q-30S,S<V,0`P,C0V-S4`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```KP```'0"`8```!#9+G_````!F)+1T0`_P#_`/^@O:>3
M````"7!(67,``"XC```N(P%XI3]V````!W1)344'U0(:"P\).5*(+0``(`!)
M1$%4>-KLO6EBX\JN-)A!N4[O?TF]C]["MX#OVF+T#W$`D$`.E%1E5P'WG5>V
M17%(YA"(!`+X?_^__\.2EI:6EI:6EI:6]I?:DDV0EI:6EI:6EI:6@#<M+2TM
M+2TM+2TM`6]:6EI:6EI:6EI:`MZTM+2TM+2TM+2T!+QI:6EI:6EI:6EI"7C3
MTM+2TM+2TM+2$O"FI:6EI:6EI:4EX$U+2TM+2TM+2TM+P)N6EI:6EI:6EI:6
M@#<M+2TM+2TM+2TM`6]:6EI:6EI:6EI:`MZTM+2TM+2TM+2T!+QI:6EI:6EI
M:6EI"7C3TM+2TM+2TM(2\*:EI:6EI:6EI:4EX$U+2TM+2TM+2TM+P)N6EI:6
MEI:6EI:6@#<M+2TM+2TM+2TM`6]:6EI:6EI:6EI:`MZTM+2TM+2TM+2T!+QI
M:6EI:6EIO\>039"6@#<M+2TM+2WM3X%/-/Z&QO?1^*XU9K.G?5/[R"9(2TM+
M2TO[WL"5SK\MT`GSW1&@BD'0W#N_=UQQ[CGZ/2TM`6]:6EI:6MH/`JFCGZ,!
M/!D`S=:Y9P`N!Z[=`Z@6C+,!8MGY/2TM`6]:6EI:6MH/,`Y\C@`8>@"7G>L@
M`*FMOY6+X'D_E[PW[YY'V\ACKM/2$O"FI:6EI:7]$/.87(^I98F9V1E`.OHW
M7'R6WKEPX7RETQX)C-->89FTEI:6EI:6]@0`M(`-SF?H`-A4-VBW+0)@C(GS
MI/W;E@QO6EI:6EK:('"R;&,+7"78>O\[8=#>=-Z7M=:[3$O`>]V8HS\M+2TM
M[6<:!T%7VN]])ZV$/`Z\OY+O+P'OV]SCM+2TM+2T;VZC#.X(DVA!52Z'KX<5
MD50:$MRF_7;`FY:6EI:6]D.L):?5T\'M@;.T]X)?^7LR\VD)>-/2TM+2TCH`
M:K0@0]K/`,+19TPP_-=;JC2DI:6EI?W38,@KFSO+X*;]_+Z`<DVK."T!;UI:
M6EI:VK<'N^P`G&3[_BZ3<=?RO];[SCZ0@#<M+2TM+>W'`=U2_.IFK>\P@<^/
M`[018)75XE`RC"$!;UI:6EI:VE\,AFQ%KU:R4VO+.^W[.351!3@)<&T_8+[G
M!+QI:6EI:6D_&0!YP+55+2WM[^\7F`3):3_74J4A+2TM+>VO-C:`;P2*T]*B
M?M&3/$M+P)N6EI:6EO8M@&\O46T$,*?]&WUFIFI;VO>U#&E(2TM+2_LG@6_T
M=Z_"6H+=?ZMOL-$?TA+PIJ6EI:6E?5NS,9L)8M.\/B+[1X:]_#V6(0UI:6EI
M:?^$C6Q+OY+5P\1]8>+>1ZYEM^+1.!\&[XL#Q_+"\__T/I.6@#<M+2TM+2T!
M]@!(G0537EQII#@Q`Y![@+U5:GDDUOEWQD./.A*9A):`-RTM+2TM+>VB]8H9
M</)X#\RR`]YF`%\/)*(#7*VV;0^@OZ)M/;`JKS5RG02Z"7C3TM+2TM+2+MHH
MD!H-!8B*9/08UPC$,@#/(V!YM"1S"P2_HFVS#'!:`MZTM+2TM+0?!(Q'6$D.
M@K[18V88Z"O')/A,^RZ6*@UI:6EI:6G_D.')[^+-UTA+>X<EPYN6EI:6EO8/
M&7_#=Y/93?MNE@QO6EI:6EI:6EI:`MZTM+2TM+2TM+2T!+QI:6EI:6EI:6EI
M"7C3TM+2_E7C#[_7C,I,2TM+P)N6EI:6UK3,6T]+2TM+P)N6EI:6EH`]+2TM
M+0%O6EI:6EJ"6VOOJ.65EC;:]UY]/',,O,%2AS<M+2WM[0LB&K]_UWO]KO?I
MM><.TD>*XOZ-8`MO:-?9ST>`&QJ`#@/?&_G<^ZQUO6=`(BX"5@[<.R_<!YPQ
MW'M>3(RAV3[RN\<CG38X_YZ`-RTM+>WM@(0O``]_XEY[P..[M.<H6$!G88P6
MSQ:XP@#(P@#XP\3]CSSOK)/U[.<SWWG7O<PD6_*)^QMU/%!^3_'ED;[::T\Z
MP/<*Z+UR?0XZ-F5P7/C`/0%O6EI:VLN`V`AH>0;TSBYH'#SF%<_[.PS;U1E`
M"0RV#`:.&CTF!COZ$P2\W@CH8@"F1M]]?2S)`J#[M_WOI13UF?>WD7/USCUS
MWK%KH-/G'^^06W.AC#W_F#,S"L[1`:XSXX,O&6/^???.CR>O.7-,;TS48S,!
M;UI:6MIE`$<S]>I)N,_3S8)>N^#,`MJ801F[D_TH##_AJ]J<%9ALLWD,`"->
MV&,@KH.!5L#4>VZ!YY&6[$!^![Q%X/$`F.+,3:#9`*(>>(3X7@_D(CA?>/]D
M*?O?]Y]9SK\=[Y#;_SW>K#Q5[UGW<V"B<^VWK<\-9\@B/@%0"FD>!]7G!=BN
MYP/WQR&O96U[CLOSUYH%P`EXT]+2$NP^Q4XP.`L;C`A='NF5;,CHL1"0O<\-
M04%U3H.L&,".\7`]1R)^KW#?1"^Z>F93M]>+)`!0+.44O)[OR2JBTX##X_?@
M(17K"GO.!CLLSEU=9\>6\ISB>T=?=)A?``H`6E:8#F"6[4V)-(^_T1TV'.EM
MU+_P`KGJMI/\O752\9GW[/)9?2<!39#*S0DXWLV)TG5OVT`U['?*OAN#\^^P
M\T@],]*9(<<`=#U.Y%\2\*:EI:4]"7;]\US?7AR!X#/'V+L)^=F1$#X%YD]&
MS'*JT:+#X%-V8&X%3-AK8U0@K02@UR[/^KX"UC'8AN8!`,K))!I@HD$@RMA6
M-IWK%O>-AL\H#E,`*7C7X3$LA:#U*71;P5RGL<NOKN-]AJ`/--\Y53>I[NW`
M@=MWL(/#ALO#TMXU]P88BM,?BM-.IK]S8EX*[UVV"9V.4'3;XG$.>NU)=;#^
M;'LFY0+#F2_0=UBIQEW=U^G-?,HAJ^<);B`[9<G2TM)^O''[WQ6`R>/[5T!I
M*]Z-WH7<HVG^&P>RO:=FXYG%3PQ0*368H`NI$#UF=2J&S@&++ZOD_%W]RJ%6
MFGNY;+@,@TEC0,VRX5ST#W"!XC-XS7RT5CM%J-$Y#*6.3HE>@W>9;G]IG+\,
M7F.D.S.XCFQ_&L`V-DSJ>T*CN[:V#WK;"%=]\Z,/-?HF&EUC1E!A9`L&#N#G
MX#OL/JAM>XY-EL+!2(8W+2WMK["K$9K8@-QK`AKF%[*(V6REM!CZ:/L-P9(G
MXXS1#EYH+4;HLY!]G03ZB_X5+#IT/(ME>OLGAP-"T5A8]P65\>>272-BK^>X
M#O5QLRI<\@<:X.U]U@S)[NT3](="^!QLO0N,=RQZ#F8#N;GG\*Z':_UOOQ_B
MXGD8CWR.#CC3[XEX^++1+L_ZB9%_['6K([[:=[C=?M1CPL5'"7C3TM)^G-5;
MH'#FUS/2T/[NK]/^Y\T9GF5>_G48[-4'8AA=F,^VQ83%`5WLW13/Q1`C](Z.
MB'!9W0/0T;"A%EQ'CSF:*<X^"',7S5:2$@(0!P<L>5)/#KBP[X!P[AWZ75QV
M"J"=@2[P;`#=8>!6)B5F1U$^RKQV+=Y\W!2ROX@BT6@#U$Z6<N0&^]&44QF[
MY;%SXO1Q.GW3=61:SQ[WNP2\:6EI/Q?L'G.GUDDXP2AU/%K%D5K&D<V$LG.:
M9H`YY[0.8E#&,^[.@[IT)G>+0]@#*0QB_AH+KV2LT#W:B3Q@!8[=]NLRC:,@
MH?,]CA0TL"!5+-:V_=@"2>R`N=;><R\6`!U0-`*B6N=Z5B[K&:`W^[<KYWY7
M?^-O:)_1_LX)9_G5]W3E'?.%S_[`T`EXT]+2?B[8C::[$'<VA.&'02^;<S%'
M=M!IF,U>\E4%=NU##F3\5WCK20##AJ9!N$7>`E.ME_=.H#5#E_9`PRL6^BO/
M_"HP.`HTTF+[78X!ON$[P;?N)PEXT]+2OBVXM5(][66ZQT)U@!3LV=`X6^,Z
M9.&0X+Y1]ZD..,%CG*,E@)<4XVS*+Y0X66H8##U306X$G/U))O$5Q\Z=L07O
M,7%'45'5R-W`Y+T^\_W6<_?JU;VNO`D:3W0EDRQRX*+K_:F^^[O`;N^99]L#
M$[VOK063@#<M+>W;@][QU=ALMSLK);P)E0(PRK\W=]9?4PZ4%+JBK*6"8`#R
M4.QJ>!QJE:%W@<@_N!:/`J1W%G<>"2P8`;XE`(2]8(51CG8&<O1<%71`>`_8
M]YZGU6^]ML'06V>S5$P?@(]64_P)[/AH:6M>'%57P/]L^$)[ERP!;UI:VM^"
MCHO6ANPOSN?T[22_>+$)PP!\=*$3UT$,S,?*0O36)*MW^SL7TM===5RQUF<0
MK]Q-"V2-WLO5ZW`0'+[3@;@"1\J+[WOV/F+HP^!8#M\#)^^\Q2N7,JZWS?(.
MUGOF[?")UOF3H/_18@EXT]+2O@E>G0MAZ`)(-X)!B/=C!&I@'NQ>83$8HUV.
M7GM_[%YE)N#[O//JD3$$\Y_AAUX-P#*R]8?-,]_@FL]$?H^D+J;Y+9B`-RTM
M[8\#7>_GYT!O;R7AGP[?C"]P,2(`XPT>@EZ/L<2E.^AM;48JO?PQ&\!I:=\5
MS$=L<+?T]%\.G+/26EI:VA\'NC]G*?FF!LS=):-MW><BY6*8;"3CRH1^?EI:
MVJ79*JIRZ!6]BS[OU4#\26,V&=ZTM+0$O0&(_$ELXUCH0ZL6VQS<KW/<XTC7
MV5C/M'\#E.$[7GQ6/"#R\?ZJ!NL[OZ\<OV,BC0EXT]+2$NC^8]:KEA4O77SB
MBBPCVZ'\3?W)+;CW8T'@D+C;GJ/9.'B/7O&B6.3?6!HODYU_[8V7TE;[$I\1
MUQJD*A#HR"E4R@T\_-@IO(L&VE*/0^4KJ[;?__:*8?ZO.$,CG\TV20+>M+2T
M!+I=9/']\:ZW3+`!0%^5,?];%7395UFV0`X7G@T#?XOP7`7*.A>SH$BJY*'4
M()1>8YL+RRZ[_^QU8XYF4_7^;57X]1H%#4#+P?['P-.R[63Z#.F<8Q1\<0R<
M>6VN^N7`S]WJN6G3+'`"WK2TM`2Y:K;<4`?Y,[;9V09BDUCB6S\FAOO<^2KM
MWX'VN2.YL2:V<VZ.@^C7`Z<NL!M]_?P>?;!YW(R.&!UP/.N%/7//;_*=O;Y8
M%5^<\I[2>O-?`MZTM+2T$*G\A,F=+UG_O_LK`?H+?P48!4CRMN_EUC@-56OK
MD+A@>-2;2+#R>X'U#YMJ."&Q/=T&R*ZR#],$O&EI:6^:S'.5[S$0O5C"OXVE
M?<;WN-R=+*B0U9CK"B0U6!#IZ(0#AODG>]!WZ,7?Y7[^/;P?13MX_1.EO(XI
M_F&O.AG>M+2T!+IO7IA&=F#YY'G^9O.2?_S6>=&J^(H*`?_.VYE$0%%F6]JK
M`'!W+F'_3;9"AP^WAB_J-K^YG1+PIJ6E)=A]P^+S2GS$W_D0WPB3Q%N^/3F`
M[]:P[^YIS[ADK7-'T@M7T`N^"="=N?]_A[EFIY78Z#E3K11UI]_0S`EXT]+2
MG@2XV!BX!+L_]N9-?"MZN.C-`-=G=",`]1U`U`][T>/I?S^XEX]([S'H60CU
M3'`44>'Q\QY)#Z==]7'?$U1?U>'N'8,9O\-SMGN)BE,73,";EI;V%-C=IO1_
M`.ORI]TLQA_*50<P?VCIB'JJ"*'<4JF/<9/-GGH3,XJV5WH!.M>T*_`5SZ']
MG;T,<RR,%J&!5K!RK_7P=,OVQ"O&NBTW4,HWCO6X_+7W<ZL7^+RY?K_S/>7[
M:Y6-E,%13O:,>L<%2\";EI:6=I$\X$^Z60_H-D&6H^++-OLJ@6\D"2;![S4Q
M_FB#E<%G'&^0[G&MC=R1(.`KW@H[_8Y#9SH!<C%_C:^!!A1$I[VZR53EY$5[
M?_,B2]D3Q44+N6/@87'AS>TU!SG0-NT2+>SV?O\-_*0@C)EG=I^Q%W%COIR`
M-RTM;7ZB^D?"%WYTTEBK$M80F/3!;/3J)1"V[.[H.>:6R"MBKB/P8!0RC/<*
M;WL<`ZY4="<U&X@**GIP7)YYY.Y[H&N\0$<+Q,Y$O[/NS_)?^9#</:J-/B1,
MXVQ?XNA[G]%*P<!@?`U(G/D;!N<X_*'I:OJ9@^D`@4^<@#<M+>V?`[LM_(<.
MM'H;*+VX0C2!!V<7F"MQGCZ(?5TWF0WD>Q8NM,J`S5\!3D1H&^S*3]F5HCJO
MJ3?*7]EOT70OZCMDT]$(VC,J0]S2YW.[!7PV5]8`EB7M+(**XDF+=[SW*`VP
MKLH!C@+C7FA+_),-^V`C%(>!8W0Z5*^9MG[/&N7WX02\:6EI?SW`]9:/D8)-
MOP6;S08Q<NS^QRMP11N+?X+S89D)#8C`X)5JK'0@`2N($*<R78'8]EIC+00-
MGGK>3]`A&24).5]A%![`&B`2#BBTUP?G,J$4VH8_"!B]LQ+&SKA8FH(`'ID4
M>F'3S6>B,_:#"Y,3PW!W?AIC6SWDV1*]?LVC!^+'I8HFX$U+2PN!+O!W9;^_
M';JWP.X(I3Q"*(I=VOUK?$N+,(`&?_;-]-+&2@/L<O@E^A5MT=R6]^A(VWPV
M.6RR;K`$1$-5!RQRZWA*"#K42$G@F20COK[W('C?.-"]^)LH&\Z!'C_BD[HC
MA"\>!JT8*S0<C%9?9R`X)IP:'L'WQ7$+?T+ZW.,F+P#>+.J<EO8O@=YZ[.<<
M\#1^;.'*'L;D;P+O8^CK#>?M!ULTG_\R-D?SZ6KPPS-.E`(E-ME+]M%ZM.1B
MH-EZU/:K"FOP3PZQ<;8_FJDXV!OXQ##'$Z,`HP<?G1*3,42R=&`0L$)Q`3H`
M&5';]H-V_M34_/'\Y)26EO;OV/<`NZ.R^7\<Y#8P6*NB42A"4%H9^E&<Y)]J
M+0[<4__;X;<X=@).PIB#O8JTUFJO<+Y9KX2\C#3?6^)T7M\C1G4SGG&Q^?YA
M/>R[ONW:@M'M2;RU5#?&.E]QV&`[INI@:U[P0M]5L#I#&M+2T@:FP'&@\B<6
MT._JBDNM309WWHN@E7&%-11HO;E7UL5%O`B&Q]DW-%(H@@$TM4&ED\@#CM<0
MBMV;6$FR?<O?Q+D*P0%??WD,@-3(Q9B-?,C]I-FNH3OT6-KCQ%R_[VA(!GA/
M%&0)XJ5QN9NWA1(3\*:EI5V9,-FJ+B!U?[XOZ/W3R)K32"Q><-K`X)V"^]X"
M,YJ98R$1N@Z!K%P5M3O):YY-*T%H)"YU`FR.+NTCXE<M]V&FFX+^6WDG^\D7
M]U2^N9^/Z*OA.\U%$T]'=S^(3[4X:`;,$=)S9"V:9,H6SSS>8B..4N],"7C3
MTM(FE1@F2GC]IL7NK1!\D)+BY53N,2BI%X@1`-I(N^_=G25P7$#.0_^U)Z_5
M:JMP$>;O>+FO[Z,C>8D>"'TE6.2;P&?KN;Z-Y[MAKB82'0D(EX(&/2\$[7;>
M-PY*$?K495[/^#OV]_W!]D1`Z.VH4S7#4_8HY=1#[LYMZ+J$O2R#!+QI:2^;
M^G_6QAOU_QM;&3'8"@PBRN3,_UO>RLDVN*">UU9P6\&J5KV_VG<P"%!&4FK:
M;/)H/"QM>SIP-5JF>26@=3(.M;=ABP:^^5VN6VM_A.\8UW\*_/SF"[,W1\W0
MZ<]X-#;:!O%]DOY(C3;7?DKEM,C)@E3^B$3.I3Q:B%IYJ77D$0EXT])^]M1_
M[6XWR;&G:M%33"<8@&)'F%>CFM>K)W=H22GVXD!YY:WC">>G%T+28CEFG:S)
M.%@7BU*=KB=I+X$R(ZU8OG;$C2AJ_3/@<#9++'+Z4*[6X1B8B_9=\6U.<N00
M.5H-C1-(C!<:<M2GO3`L:=J7XE$E.\R)6>0[`&8V_&Z46KPD3.`M(T#84]$^
M]Z(2\*:E_6O0?)N!VHQGC_(SLQA;`-#,O`%.T\GHKV/,Z8&U%P"6U\36LM%(
MUR!4C"=?K&=F&!M&JQ.=MN?KWL.W4@'];G3<:-$\EEB';>!<I"XM[?V,4#F+
MV]^QS4EPYJ;6@W#R[T\TY+L#BMGP9W%-A*/EOUQQQ=_I!(Z72'8Z$R)J_\Q"
M6'+Y3TO[]\!N>PIZEKZ(I^7Q"9NOV4HFC_]>!;CB-GLEDHR6`S:![GR5M1<]
M^BSHDG_#]1:Y"I'?N8#3*CA]Z_F@;A[2_WGZO.IG'O_&BKE1Q_!+K/#XG_Z-
MXC@&_S[;W\;/\\2^PHCH"IV!;WYGYU31/M)WZ+Z^'X9"4PY9OS3J@2@^3(8W
M+>UO![DS*Q?06.EX12#R$NGB9E&/JL7+$PP*_/-[OC7W=[96+F<;]+<]Y+1`
M!=P=A7D6"YU^A;<SKUK@9-NCP/SWFT(I`\.(4=^WS"OT[W;85W&FC2H?`(Z0
MA!.2>&]T-'*Z5P3<<X_UP*<#.D=`+PX0I;?#ZZD%0;(9U;GDWW2U/G9VLH*W
MRT:`<B^6!P-S'\P[Q_O*S5R?"7FT+&P_8</S`A/PIJ6E>=[]NWQ\'=?`T57]
MJEQ#9[;FU#T_CQHKV:@.IL>,1L-W4368$HD8$SY["FB_>)5F$/:C6<WSN48`
MK-WN9Z>M)(;G:-\O+*3>FB>B9[+%-A#V0@ETRQ23ZJ<;<K8WJ*2GYP8G$6O4
MS7*U#$K$<*BTM'X/*#I*'JJ=4$6NNE4#J64`1UZ)&_4FQC=$]QA)%GT]".;4
MT$_`FY;V%QM'*:-+*.(%H.C98YYX+'86F0&(.0&.B@(J'GNR_QWH5YE]]2N:
M%>7P\Y=0E)Z90O1T6GANF[G;ODY7]Q*@GG^/<]&/E.\TE)2@<ZU&,N2F=4K.
MOE'6YQE"RSW6U<(0.`X;*J>73]<FPUG*&2^8DU[HTI>G`!^:L(ZN2G8<_Z^Y
M]_A^IR8+ZKG(=B5BB'-X_QHH`'\"WK0_AF?2W@ARKV)7LI-O?VVR\3<S&[UD
M0A;LZKV,K7B8:;IV1(AWXPYY;$OATKOS%Y'.S^@<UQ5O@_I(#MA]U=S@)439
MK/_>NQKY^UR+U2#/51E0#1'J-=77Q$@"5:_?HI3)"EPTM;SZ+<+@#,^HF@37
M&`EEBCVUESB+&`2[\:4]AV*FS`(NC>-N<^#B1!&<M!?`\0Y6>+]F`MZTMWE5
M:3_U;?!M5S]V'Y\HVG:N69R!T`.+,[K`Q5OB9.7:9KSC:(U5&8<K>!E*!O4)
MC,`W'%LY-AL"]9(DG^E=#++Q;.RI_M>X$)LP*`GEH`#>=?BZ$0!H?6J.0,=Z
M.QV,84%?P:*E"3=2&-AWRFRLI'N<;-.H;C:>[[3J"3V'DKJ"M.>(71'_HVT*
MLYO3![V<].PO,N+FNU2A)*A?PRN\X@ZZYF\"OPEXT]+^%EC[A]/"GY^<XKIB
M[7GT!7&@[C3;WL*MRB^,)FU-[8C+;.1)#=T+B_;+')NW]L7G(/MY;SS#4P$A
MUW?]RG!_LXPL.E76VG0E+[5#HP/:T!/;_[I%_=B/=FC="AI`=;3!)6;&F/9K
MY'^V?I[W[MM8MCLKP:G0QJB_C4S`'+II+Z7.4[CM7A3!^V[$.43!-:\`OBE+
MEI;VEX#=5\0J7H$>GAQ62ZTJBMGT;A_%5]]Y'P?@/\%O31*K;J&OG\O&NREE
M-([N!^S+X$H);*N'MOUW+,80;&OTWUAZ#-7//'J[%<\JQU^EE!:"T?-FN0UT
M.E%/.LYKWH%Y(,1;L\#9`83`V/!Z2;M=\<VBZ*DJ!KW^&4)AP^FF+^P(#%\-
MCAAL/(>O,=[%7R'^F`QO6MI?`';EOW_\?@;(F1J@URX^FV=^R0S?G&&[%=YA
M4'DIKZ-2O:U[LQN.<IV):J7#'.`/[W`H6GVBCKVMFP'=]^6#72D1A>-<(_&6
MP^\)DH?W_O\S^M:\WH=ZM95'*A*,WAIC_((&WBDE+N86!1M5YV,X7%XELM)O
MDZGXAVMCQ!LSWA#&=*PRA^=%K<B!9IK<;-^9Y3)F'C$!;UK:#P>Z?PK4ON+^
M`71CNL9XF6L;7ZP4/`=31R)-L8EB9B,XQ(8XOOP=#)U0K*`"73Q*4_O@I14-
M6N>?PRSH&SM*N.]K#LBWXU:IU%+A8):),)+6)7N>(0;/6R%&!V%Y_N"H-O,%
ML/L,QG/_!M/G`S6**?>`<TW^1R;&V;+F48$36:JX]L>N3).=6<R[=3W>$`+C
M:VT2=ENTWV\"WK2T!+M3WO/+"0RSDSM7"PG7J8%`7Y,7'HA/$'"<_.P]B[,3
M;,=69@G*,'9JR10Q*D,=@=T`X(5`TVM)-%T>RV"-++J7\(,1^4=I=&G9LR&_
M0[\/.FV"TBKO^V>=WVD0?N%TH[OGWZDR=//&6\=Z&+BG7%%$2#9F9J^^(@B-
M<%K$&Y3RA*2;544T$H](P)N6ED!W=L'HK,GS)Q/08SZGGP&([?,)','.'9#[
M7>7W&"$R>J!G=!^;;:#:C/\HS22>B'GCB!)^=)W>"GHD:-'YG.Z?AZK`&8QM
MU1\\T*G^UKD(9YJC483J.;>WU_`8&_1/@^MQSG841\\`KU;HQ:!`0=]QFMDN
MB@ID]N)U3-\Z0>\CF1/>-(&9]PO'<7VQ?^,]CXFL2,";EI;6CU<MY3F)^($Y
ML=8J?8WF0GO]$,+UD^WTU.3\%F>HZ-#;"*O^+@_)>2&5"$#QPD<:SHJSZ%J9
M*;>S1LH#LE_:,'(TG*.K[V?PLT>X")^+$T5Y@83=S$8T7@9L1ZZB@1."8YZ?
M.]#PUS`(V%HM@W>-N9X3B+Z[B\(2I5K4VN`\]1FG6IC-=_BR#I.`-RWMAP#2
M-S&[([*PK[P.'/F@/5%I=JKSJGQ9:2>TOLUQ)/AL/:AA(N15ZURKE"\1OO'6
M%F/[82R-I,_T6`LQB+UD7*!!;0'AR\!Q.SZCV:XU>JENL_%58W<<^*KQ/E(\
MH06R&#D[HP_F)/HU>U_T_O%$[X[2H1KE<S'QZKQ*RA-@=H:=Y.Q0??5TT:X+
M<T[*HI-*7>U'SH6</ATP7)5Y'J4>:K?B9=J\XED3\*:E_8L`^C=>)-2W%-N[
MY,R2%T&U^BA6=>;%67%-[NO2>MU+:+J815-5IF4'[#:V?SFPB"-L82\0@=6Q
M\::O%U?;@!Y&GY0<?PX)>EWH_\*,IJ?V*>AW#9;Q30F_.\R`UU$]LG?`-`RT
M++2_A><N\<[=FQD!#,3X],*%<12"4>3`%@(A0:M,1)4D!,5W]Y_1K)F"B<:/
M9$+.=QQLQ$R_YP2\:6G?&9B^@=E]"]B]7/5V[(AJL7!!2;U<A6"7?&\;M7*E
M+)O$N0A)Z3!XGT;5R+P;ZRZD+$U1>`EO&T%^XMLC'%A#<&U_=8S:871<B3._
M*!![!__GW4MV```@`$E$051\PUB+(M5C1`0#XC=WPRE+O)<8J-S#J-R847QP
M?;<98N^J@T&,.9`3YV?O7G_3G-LK@H'2+]%;M07DKM=995!E07:&PZZL0[)=
M/KU0@6QZ`!FEC!6I[K.^HTY-%IY(2TNP^Y*37DD^B-E=CIV+$6"*JE-)U?9K
MW-+,),MM7=ZW6;D_\[YX["`.FH&4\)`&<W"8[HD!9J^TP?,-T>/*,`AV,=!7
M9$&'%PV*QG7JZY[L-5\Z*ADC>MM)O!=+A]=E<4I7GV5E*9ZI`M$2Z%*,,CA#
MBR6N&.,5H!M5'?3$`3S_Z-D,6[(=E?&'@_C9<2FKV=.^+^!@?@\LO/VM"68G
MUB5YG,XK0-%9<##S-LI('?9F(0K(2VW_`Y+A34O[V\'N[Y.V>L4ZP!C+3B]<
M<"?^2)OI%:PNO1N6A1SH.`ERNW`'P"7&.!HDC*;2O#`\HP-P=32UWR-LC*K-
MV>90(&T-,GLR1RWLTN]L,*`7%ST#]E$:&[)/H@0RCM`<G'&5@@T#`S>`K?1+
MU&U)V^8T"!AU>(UI>SC]MXJS%AA(ACRII$0.OJ[2`+W=O"KXQ[:H5UR<ZMZ0
MXZ?:'0)@HG,Y<EM[$+?+Q-JD'K$J7\W)QIM0468IR[(<@'>W!+QI:=\,Z+ZJ
M1/!EV;#1K<`W(.EFV$)7;G=(`J)X5<M>MLJ$E1SHE'V"`!Z38),E`%TLY3K7
MV5S+;,BSWI&D?DQ'BLM[#:H9YMT@X<2<O]M70+2<H`X]I)[-07)VL/2"SJT@
MJBR\$A2GPG'IW:&`#I_8SH?MW'XUZIDZ<C)>T],'CIR8EC-"4X:6[OU9:;8Z
M*?'1F1"`3[5U+O2?,3-%0+2Y4C(P:;*($&:95>HJPU%!D:27#3?I]&BME;</
M%`JB)9AT>'URK/(P66IY%4\$F,X\8QZXJL$)']DGX$U+^T9@5_[[>R]>PNI,
MOPOOTDE,&B3YV@C=!2HOKC(ZE=KOL6N&VFJ6GO,YQEF8R^%@:W^[GM9W\,(_
MJ8\=Z4@]/V?H()=`Q1RA='P7]67I,%^FSQJ="H7LCT0_ZG!&TB)'5-`P3`ED
MZV7RXJ0PJ%J!SA\4A2L>%DY0]N$(Q#L6;,3UJ+$(#:1#]M_<"AT@'5T'K2T#
MHTH3#-RV4U\B9ZGQ?1/L3XB870?(KF3AZL7'>.Q')'+M#4#X,-7H0X,>$$?[
MN:(E;$$!_&C=!+QI:7\C>'[Y@>-,X'4.`$ZA@<EG0&-FQ"B*?BW8;6LB1"M;
MBW<[6^KR3BH=DB<$Y&V4Z,DG<PBUMI=-_XHH'D./T@<=N%B0CZ6NX%LM[Y9A
ME"RA`Q)"G=]B:4;QLI3C9MADOKI@[NPX&:7K&S1JB#"=%P?K<6'`JW,DXJ;F
MM+J-8=5"6JUI^R0Z/D/KPU84D^MKF)U#P:ZNZ_J(VW4O,8K0&XFF3K^,5$/.
M8CZZKX]N.F)7I/":(F7)TM*^`3A]$7J\&.;Z+:HG\.*S7COSW-8<AVYT3/4!
M$T_&0*[GQ957G:UHVYLPWO8#F7`VM9"-9W)#&9SH`3:Z-!R0W(V,L%$'(EZ:
MWKZU`#YD[\UW>B^@8VSAB`;;O7[@`+TSL#>NB<;P.+<O!T5C3'2OV+UF[44$
M>M#J=R^&5&Z-/SE;C#L"];OF%7E#6[R0OF_G[L#)6.?.Y'(DHD$4^F4YP*['
MW=;%B-CP85O!,RUGC$>BG&7C1Z>5_:S+LM3OQT0V).!-2_L+P.XT^.GM>C9$
M[_F2^_05<I]%<.?6)5T6CKT4)7?AGMD[;R^S?,G+F0&P(\?IK4<MK87AD,06
M0,(X'FX_]T:ADAQNJ2,$@/JI%'D*P;H9`K%.L*F?A!3@U+TQ"^98(QP;Z.R&
M.-$'^61S*/,%O8WFC`S'01U?&<>=HNFJ^#L^#EM(AJ,5SFAL59#S6A+5-;WO
M:V<5O<F4WL1:T_Y\R;2`4U)L^\L#[,:]6O]]O&1)')##<")"*0IXCTUH.!S?
M!5!#R&M6).!-2_OY0)>S!_]&/<FVIRYU2\5B%ZS0,V5]9]8&B$53,T@CG#F;
M1_+M_<@\"\I%FK\H::H6N^(3452P`*6]D+H+OIM"KAD]SB#ZCL-U`H%2T954
ME&VO^:0&'2>'&4YPQ'89E1:;?:7"UU""JJW"Y5:`<W3+T/&6(9TINN6?/:#L
MYX9)\'G&FX_EB]5%#NQ6/DNHT!;<:8F=^<[=]'6L?0!-VJ>PA^H,OIW9?;6A
M,4>,S4(8)Q7$=&$3O8^8>'/MU.%-2_O!8/>5J+6J-G4AG/8EM\+.O;W+W"`\
M/MNL;VE$J4F+$3+DA;?E`^(3)C3U,0\1XA@O^?T.;WKW>Y:2_-<!LT.-`B'N
M'VM!PUQ[!+3&QYPP`:56-.TC#.C!Q1[8E4EGQ0A#%]=)4$RG8<`KT0?5>=#,
MH:5X>A:].X$V5%+:R1&P/,&T/(IF/N*A\SJ_GX.VX^`"OTCDF,+Q9-6]'UU[
M4ZNN=';A3[*CWCO[<)WE];M;-BX:%<N+LP=MQR7#FY;VD\'SA0-'V"!V)I?^
MI5A*N&D8T4SO!]C-ZTRBQ:&8Z59D!%K0)@:ZQ<$A'534?W[+;J,'>)YP*@18
M\,\O);>V&+].A^`@I)CR*$9[KE?7V-G$11G892ASNQ/^5C,:6\A.W&PKWZCJ
M9//MQ:@/-#7PZLI:42IE%+A0P];ZCEA<<>MB5:UV%OK1%-LYH<MVR$T*%=S`
M^K$!>[<C&9[&X>@XGOXX0%G756:'*>@?@M[6]@+:[QSE+5+#5;ECR#X#XR)G
M:>&TM-\(3/]4K.Z++D1<^W(4`=>]WK?U'-J.@7N^!G-28TB.XPF3VS05N!F!
MD%8V&CH.2J`A?8:N:!U9#R"ZOUTL$H+7#-QJW9\KG3TNJ?]\OQ<=(=P5%LEB
M[!<HJ0$]M7/2+LD5.CM-(-UPJN@Z71AH$^]XAJ?1X>UTQBM.,"L+AY7383OZ
M_I&,1:V,HAZE5SJN!"*VT=MKU5QF%7N`7N^T<FAL=9CV'=DW@&?[/'58#!K`
M/`%O6MH/`[N70>MO`(3#J0W5_B[_</NP.TE?;2=/B][3[^<D"7:)$NP=PC9V
M>:SI##&-9EI,8@^U&]2\$'M21LZ*R7))9[D'B?`D,!V*H1W]G)W#1J2&^22\
M%N^H%W&J*ZVQJ:PQ=,UH4,!$Y3*0,IM];`3]RG/"@J(<.Q,L'53%,2O&MY0A
M85Y79Z]N??G("Z#\(=C3F;%Y@G:$%?/"`=.3$G\U\!55!MT"%]N_&<.;EO9F
ML/NJRFG"/W\Y4!V:^#%VV-1]\U6(?.2N=H%4_3#+HK4;]Z4"4^=6A$,W\<M.
M]KU2PJ]X/S;JS]T4#18I0(<X[S'$5O=R![0*[/)J[3<.]"\3$^P%$+/]UMCX
M[-7JMKZS5]H2IK:3F(#=@U@48L"P_4**`&!LBFA5)^,D8,7\Q*D#U4=ZB*\+
M=WWR1`.#FG?7=4R#02=O.7ID\FJ#:JUNJ=`@QZE^1%2=I(ZC-BC9[C`-2A-Z
M<^0\-W2>Z5$X0\;/UYT]&=ZTM-\`>E^Y3@X=.%TZETT0!U<;=O:&@K]>I%.;
M(:6`D9;:4DM0A-YC:V7A?+M-)OEQD-!JV4-[\GQF!MG70R0P_5=A"7!-MD4)
M)=!,V'2W\35E63E*Z",L=(=(]S,^,V@A&"@K6X8&@($#=`=!=%01CJQ!?#,\
M$]W9P6TS!,["E>S]**2EWN%_<:0HQ^?8ET[B:(/>*A:8495U\6:WRF.8N/4H
M_$`I8UR1![%3IBT%/>TD6?$S.NF.3,";EO;=@2ZO?N$IR0!33:B@28E=?4J4
M]N(\?T*<(8H0>=-;!DJ=AX5C6U9KM$XTW^L+MPT^ZL:L`AHWW6Z/*7]]E`L]
M2]FV%CJ.$C/#?9!/G$$6,FXWKZ>-NB,&\2U``V09PAHNH.,Q(=U\1%%MK5+6
M8/`]SE^/@V.S6=3#)G_Q$HZIR#\,.EWH>'L1^>WI&O=B1]TYZ*E!65XE4CZ,
M_QEZ#T8D39;_.W2LQSTJG1RY.Z-64!)C!6EZG['V8<A&:6:9(GAH#=/-'$G`
MFY;V#8'N929IB(C@U`DYXLVWSCU0/?24%*(I==`E>THI&]-IP-]8=5L4<CVH
M!E[-7GLUYFTLGEI[5#PE-@:[+`6W4I8M/O`A0_0`OZ2_NOSN+LN6X],"2?2X
M)GL>HXO:K"?[/'#QF,W>Z2-@S:GACDJE852GVG\"7+J7:/YYF0-52E=J+*J!
MU[N/L>+9DR`.K^E7\^O.Z=])NRTW]6#+LA2NZ\,A=@%RKT_2[8MJK:@F^E[Y
M&C_XEYQ_?@W2]6J2@#<M[96+^!;7>!7TOCJQ[!K8?<&-L0V]X[4"<>$)KS+8
MUM[1=N80M%<2/9U5R5L5T:F&=&4Y55OA_G,3+"C+P6(#'K,C^B-9[NO]CX#;
M7EY]-_Q/4([=,K=A2\,CO_P[1N-&9#!SD.7>PCM\$0QDX0OG#XR-9[RP$W0N
MPX$^XL7!7TTX]1)++P'@Z`;XNP<<R[(L!4N]'@$H"S:)LF9P\]@6%B.I-Z?3
M(`2Y@:MFY,8.H0F,]'P1HTQFTEI:VNL][>M@%[/K"MN`X1TA9F6""YA:6#'B
MO9LG-<D[LQ$&TXRN!4NHBD<%[8%K':+Q1PI*IP:[SIH!E&6Y.;[!:V(?KR@7
ML`Q(N\FT:_C1Y'%Q`?DSXQ)PO0$D,K@.!\D6&.M@0UOF`"_W>%_X\J*:!Q?Q
M\FP7X^#76=HL.B9NA1/-\7[VX@D["C`L!7OL[C%'V&,03VRR8[,T7$N4HHIO
MH/F6]#CQF%V3=,;6>!SO9`EXT])>O5[@.H"XMAU90AW%=@X'G*Q<?])"0^NI
MSN<52@A[@IA110C9V`U(T#TFF.D&8@SQY*(4[8B[1:;8OK+.B^YC#C:6XSU<
M`1.(8UD>H/<9L,NA=D:UG'D@M'D%%*WW:E+8O:2K'E/,K=(;>Z"7^D?:BD[R
M=CBN##?T_'S'Q-1!BDY0<%5\CA/7X)OFU\&#6M7^.#03^\T4*["@<1RZRBVC
MSF`[EET7G7@DM-:QO)[#2UD!44E'V(LSI!;HO80&T8"C7:C^[78`=-J/L>I-
MAC2DI3T[&3^[W>=,7;SR!8R4F3V_,'N[K2U%?P<XKH[NPWQ=/:=6A@P>FF>:
M\O0"AQ(*\(?OF'YV<;OMV)R_)=OA;E1[8JNE/.*/!WF+H[;$@K(095UIVGS,
M>>C)W5L7Z(@W)6.<'3H*<!I;]PM.#12'B14%$$+-Y!*'K;QTUWIT'U[HCC8%
M<)W.MB<L>3ZE+`@"^S:CX'@O@ZX7LAD^\,"@BK1>35$'KVF>@=<C##`%24"W
M#IY,\2INGRN-.34,W!),+4HIR^UVLK=298=Z_%!D4=K:F,2^3D2C'E.P_'P(
M6:$.0?@*_12X2#91ONS&>T_`FY9V&>CN,D.V'-D?V,N"#W`8QM(.(/0!MII%
M;I>=3)P$$]@EPK:D*0O]#GU(B2KA('89WDO-+*Q<RX+Y#:O'_=$)F="R9T"4
M0#4/=FMF!(H)<I&VU8D2IUG)AZC\8"=!]WZ#A"\8-TDH'333G;9XXPH]AE69
MV*C-%P5X#V`H^U(#S_"E<?08:60-TL[NSZ./'MGGU%7KO.M2>62ZD``E74LH
MU%6/S(:6,B$+BP48VX%I5B/880C1<#J!TI"HJ+6&W?L*P?`S664<&/-E:G>G
M-,D$\YEP8AYA2V='@IGO]CF8ZUJ1$VZ_@M63[T0WMP*A'24)KSRT['^A>@ET
MNS[F?S0("R;@34M[%O2^8JE\BB1V*W6A6CC=A4P(.5;$B65-Z:<CR(EPM=<2
MBS:$QDRWU<@*Z"!"\=MB?+W(!V)8VM&RGP*ZKE@FVPM(IWSK@Z499WGW^VII
M\Q>R,&AG78\4VM?3JE]]8$T_(M"VB%NA#O!UN-P_B5*X0)>?DNW.`:#:!+AL
ML)T4/@Q]S=LBB@705*K38-1_FUK)@?ZML<=J^FJZE,"W:':X61[8`.FXZ1SE
M"*>=8,YQL+N=)-ZC:AA,3Z#N,D,(-;H0+DSP=M@A/JVU/4D-BL&O;X+K:JX5
M!TO03H*JM'3L6*"WW5:A6+;[2N-<>Q*>VX_XF",SI"$M[2+(?47UM*GM]\8L
MQ]87$(/B(^N=EI.!6$P8Q--*P+R!W<X6.5H%']`3^CW%T_6S;'=,O+2J'9_Z
M;J?8@K=2-RE*"R*N2_<<`&D'<]*QZ)5O+1)HPB_^(%A?F^>BM3_[_3=DO:"I
MPBA2@F+!!B;?<?C\\5"L%GV>MTIH<`DAEL]BQ$9WA\."#`G>#R?#0U(R2*;Q
M'KVQJ,",B3BVHJB4]V_`4-27-N:1!@2"_9V0`ZQ%X45&JY4MBE1MRFE6^2"^
M$5=W1F]JCN(4KDI(F$W$NE50EMNR[:9Y2:RFJ,X&`/OJ"\[/6]X`&P5!NJ6(
M)QK#]@LXA9&6Y;RJQ?#DOC8EPYN6-@UV6Z#NW6!J9$U6BRU&SF'I7<$$[*"W
ME(@?TEJOC3:+P.C._JX6@)F%&.6Q?1]N"UY\)Y;,Y*M>4F_!LPLC>CV$-?U^
MM*N._T6O]U4,+COKC@1@`]7-/-]+@.4:#[3V03O.0&-LL6BVKG**+E0<:-X9
M15@X',`@JJ[5)T7P;IS!+H\!PN-HG,U^^5T&(+7X3JAM!0Y430`JJC;D%UO=
MP4%CG"AO*W$\&X]'^,/0NMU['*GUWUV6,JJ$,8HZ#>N[+$M9CF(T<2_=XW:?
ME28<)6O0FA-M=9-A41LY]Y4"H<'NW<PCS&,IZ[HFX$U+^SWV3&G>>G'FS!=8
M>\H\9[_&C.4E48DL]^)5ZVE/D*'0.U"64A3H56#)LD(1'EQ9L%Q7'KA"OL2<
MY(!#$C4.')1T[-.B<AC&XW,?YZB3L5!GYIDE'090,XBWI"4#@S7-Z@MK)C9F
M+GE1.T\ZJR@(%];6PKTSX8]82.L+Z"A4E$'V_5*\C!B!$OB:!+RC?XB7XE8@
M.^*#'?;0,+JMWCZT@U^!:D33G.JD[ZJ&QM[@'V(H#4A62GIZ#H94,(G"5,K@
M=KY(1-W?/T(GLFS%9UY)N[1OK7K#C-<T]26W:]3SWE%:W0D?8>%6:GU?!E.6
M+"UM<'VQ#.:%J1?/3R3=$HYF(H]9SP9(59H^U"0/S82V)Z)Q<)UQ&"C:+5"O
MS2)F3"Z_N.)0[(N$V`:^O!:8C!HVFM7\KO*VC]UD:*#*FFY:EN6<]"?N$\OB
M/*A5B;522SJQ!#+#2CP01!&/G7'R>YN1&5,A-C:V]`2[J&]S\+%/4$"49F5"
M;[A*L'M<&J%;H9ZI+90U@`D[H.*(O79DVXH(7W%\R:V*(A696E4UJ\*>Y#6L
MG"',+(6AH</J7`/`"CVI/R-XU01[G,2!:"+D0VZ+]1BO<1XJL#OB1#]"&6XJ
M.7B&$FD[_RPO`\886M@:QYIR%=CFL,8<P'5/DGZ46B^E).!-2WLG<N4,;=@0
MCJR+&V#J!IZ=MO8)=72G\)B`Q7_2:;#?7=<`-/.<V%LA"WOIXWFPRGKS;[(@
MFL/SN)J@K7O76L<:Z*H<+14N:35UQ[O68P'P5PH7A#MGJC1J!:M[+-<5H.T-
M)2AE#`VZ<3*K`QVQE0QY.&N--=?=C8#05'7S"75BW)4PFT[.E[A_*X,E'=UV
M30W]-ED=%]5PTXEN%MK)G]`0CJO!L1UXWCVY]TSG^<7_ZN_*(L1>)V(9+(M2
MVG7^&(X="\+95J"MGL?:4H%=V[ZLQJ67`R"311_C&H5\44X$!XESB@'@R#"B
M%`?<^T[.F5AYGCM#&M+2F@/U.4]YN$3EQ&5\30')OG&,`V[HB4IF!T)_*"P3
M#\U<G%N^0N\Q`O-P!+DH(=^B)WQ7A)QFV;O"9O3?`P,JXJKV?BTQ9<LO/UZ`
MRB/:OG>[W4;J<%2VKFM9N9[/$SXZ/:[/E0ZC$P)L64IV@6F#+>M_.:[H"GV3
MD.H+^\].*(!"Z5*YHBIU6LL$1&Q>5$RUU7<XH_/<"^+&M>FG`IRN1&HKV]Z7
M+4`8S@`3/.%+6/E`UFRF;^^,LB_A!.6(M*^=N19ZTM'%49J`F.["0.AVH&0X
M!K&FSHU`.)*Y,0(J#\(2WY43QT)"#(]`PWFP3PVE--@8=I-3LMA2\H'$GT?F
M)^!-2QN`ERZ],G`\1U:4`+M*S<3V5T;`+L/)860B"A]#L,V2O249SD?QO7L@
M%`J45=^4@A%EG)ZEF1T;>+Q2,^TVTH3_PJK/.+RB7(BV>.;;QTW%ZPU?CRSK
M?>U)%*C6/_M5$8LSN\_<4E13D-`D2C[`Y4`.GPNKX/>1UKE@%4=*G5S53=SR
MAAE=IY?"T;/.Y=$$YM9&9*T0`-&F-SX\3IQ1P(C4M,Z1`'%%ZTH3]!TJ-Y[=
M!+Y7S\#SA<N$J""(7(4-3,R+!W2&GK404!$G@-\+A;!B\:L5`_&X@<U8$W1$
M"-WW"H-1F%M4%YLP(/@UC&_4'>%Y>$+5YE2@N!;1G8`W+2T$![,?X)K<#(JC
M_8CV?3F5J73<5P"&T&9VO=M;.@REQ\"Q!QQ/*OA<_&D!BW-NUO.S?,YE4)9,
M\M5V$6@4RQP#N[-UH6=\KU+*3511FMU_N-]7=VN4GL-UT*-G4A2WS@?T41CI
M]P!ZS%^0L7TP/IWX2@4B65JAU+6><Z1(H)+<["VV-OT?MI(J#(C%[[0VC$;B
MNHJOY!"'&/8?JWU,NCO'M<\5);25&L=Z!6,J&J\2'(EW&L!8Z@\,=)HEUBT^
M-HXY@<8.&?RQXLV!-:BO$X?A?-+;%91NU(+E3))$.4(0)"-[EM-F6==5Z.H6
M7[16ZK$%8=@C2;Y7*WF6AD^JUDA$=[`E]ZZR>,7CWP2\:6G7R(^IP=N:1(]M
MZI&M2U?8D)WMZ'ELY<TVH>R8][,%!8BJB*'HJD_LKN!LW.:"N*ZI"P[XJ-(F
M5T:$K$^ME^K=:)/99"GC4L&UDL!MKZ)TH9,^DCA6K;+A*7.@]I(`'O`TSIR6
M&])5JP2+DYM%I<BY'6QUF:&]CZ'M5+H@5X%?N`P=O)T;#\^)&.OASNMH"2NG
M#M8)B(DP"YHDFZB^1[\(G0V?:47[-$LP#Y"61RA,0Q5O5K&KYWA[;6S#=YHU
M8BZ\T\A)OAH*M?<O8"FGRHF83EFO$#*4Z6Q_X\RIL1"\-<P]?E.!<9)\TL4T
MG.(:E*^*QD%(AC<MK3%8O<+PPT3?,"+VYE)/O[WE[[\"E%\%POT3PZ?C5$OS
M43S"G5]Q5`=KR6`!RU",(KW)U%-G`^HEW5W5(29E#C79&/"MEX9EP42'T\OZ
MNJZ"8(OCL4^L#QW68'&^X&AM`AQ=O+EM26X(S-L5`.MW7P;<.8:>ZMG0B-0B
MR,HU<LH=!!RUP_CUWH^C>%*[`G3Z5M'@QIVOMM_WG9-B?;.:5Y02:U*O^$IR
M;KQ;'I^/`4&@D7X=VR'?!4(N5[XW'39ARPS32V`M,$46T'6^NFPRY^=G./T:
M6R$>THY%#6CWP@OW^ZK7EU+O`TKGLA+9JY`K?<_+>%N$+[7&TJX"WAX\@<.M
MB`NHM\UD>-/2>G/1E.+MV+F[(06=R$PV%ML)4G=D&U25!':`0@4DZ0@K!C(S
M+(V2QP&DC]G=1>G1CKZ7E1/1MO2!%#LQ(P$1'$[T;"RK]_OZD"&R99\-/+2I
M04>R"H/'L50<(1*!>BP?FGGI\C[H%,XH8$TJ':+_[`X#"N!6)#@YJF\Q@`/Q
M^#Q#$>1W.Z6&W7<2-D;'*4.@:0OM0"B-5P$"51@08C3J@6<R&(,V_,2V@?Q<
M`E*=7T"7MK-P$T&LQ4EATJIAP(.>`@I*&METV+U,<AV<;)Y=19_700BKFMG@
M1C/+B%OAPI0P`,.I,6+970EB9=ONDI'K>B^V6)!U']AR36`FLVWN1S<>&)6T
M!T7B6QBN&R\Y#:)`C']W&R0KK:6EO8[Q=`LUU-!@C^GRY@J@J(EJCG$=6WCG
MMLQFRU#)"0X#66_UXNM4434,EUX$(21LZ!2W;`*=C49WG0ZR">(*V712V'IN
M`QB("&`451SMSK4L7`H1N08(2"7J3':S&-"Y80L3H_A(A:E*NZG/[6N$815<
MG62MYJBSQ5!TYR%-OXS.J_H=140)?,<%`9TM0-P(X]LKK7SL<`A`>3*X)LY!
M/KN,\_:JLAD4P8#I/L,<6!42T7B/+FA6NPF>`T..C%3_OL.&I$^S-K7:Z.H_
M2.:3@7MR-IQ\;]$^"JO0-`LUH4I.BV:650O%,39^F3S'Q7V]FZ1<S7W6_<W9
MH:%1CFD.(YE3PD-2$F8B84.ST\KM70F!\!RW!+QI:26..WL90!;57L)A#KV`
M]SC*,)@!SG<G-=4E6WJ68Q4LETQLLOH(<MWU8C0]*J^+Y'WD`*#13/VILBE)
MY4!LNEMX4(SW\?B,ZU)YF=:M1]_QFI3DX<%$CBP)T`EH'F,K0!0$YQ-C0YVD
M"8>U]U\O&NF`.!C9L6'%QOO&,+MJ7_2ND-+OPY$3PRH13;.C)\MW;)D#=3`K
MQ&?%H;^:F(^^`H4%NH:IHT?J%1W::>/@X<PQ;#D]_5=01OP+M$;[M7*)UXF"
M?4Y3A(9FE5%/&>;5Q+L1$@2N*PMN"*JVG>!WW<(9;`DXFA<IL2<;L^](Q(XL
M:"*U??M;'_YZ*9/.9$)W]*Z5))E\)ZG#FY;VNB*+;+$.C2UMZ9TW&80>J`E!
MWQQ-K%GFQXP,RX(JG'G.YA"@J:F]VW@36O>Q=$79CQKV%D@.1=OYH$D]K]#L
M=).ZQ*KEX_F`N6J^5BCJ]U@[ET6$?B`H#E%?9Q?$6.G0N?L][N!'/&!,T*,T
M"VD%9;`YC#HUR)+)*8\^R4:5D-@!`)KKJZ@*Q[B>@+G-HZ_:Y'=G]Q_03@%)
MEX64X1E2Z>$HP"+*R#+8*K*?'>6#9?PT69:@K#`;KN=L6"HGCE6)=IT<5@ZY
MQ3YH''L"Q'T@VO^1A1.H9!R.,`QXOHOMZTX?@]1YYGF9J#KONJZZ#+5QQ#W5
MB][[;[`DP0BL.>\A8N,(:]K^WU814Q:D095BL8U>KH>BC&S;!+QI"79[8^\J
MA/37LHGSH3%]<.J>9UJD4JTAN\K-I=P``"``241!5-6:CJU6>@PB`_I`7\B/
MSVK7?,*#]IQ,_37;_I[X.AP4--C(=!E(N)0*)OO2NJ[EMMQ4S&H'(9XL\;(4
MW.].#.)V;@:?.(]P@&[%6(I_086+35AM2))[:ZB5-WOX5&B`CCI)AA:/!`C+
M#Q&0(,;9>F4?O!VG@>[L$@`H.3(:>3/E2$&QLRZC&QSK,74K^?Q\^88YF1RY
M;JWC[1W?*O91!P;T)O^!S`@:RG&'I3OX1)1L03<4C&8:6I:E%"Q6GTNW6U!J
M>K9V7'=J=7629QW=#J3>R13X.1H481*TK+8X<P+>M`2[O^&D\SG/&)S:GWO&
M(V[O8'V@DA_8HU-"QFP0VM//L*>SOK"J_'6RZD==]8F6AI#]HD)A=*@[*TJI
M&X,!@$4EVFZ23-C*78?[OLB'_J8+=!K(<<$CJ4:UI(BWU@6-Q8X%/*%[N.\,
M`6"Q*3\5:U7AMA,,GIK#(A6(;8&I\_VB6]6L=GCV+5#&#^0MS]L#N<`B>%"4
M6@O&SP>#8/:V=MA#:&1(#:U$GF"*&TPMWC`?GJ%03YVD(V<R)G15A^[Z\Y.G
MZ*#VCE1U#Q8;XZ+O!,Y<@'JP0-"UU$E=+?`'!-)WVWE7D9^`#JCMS=0#=6J&
MBZ2P<R)$(RR(7K/[=`\U&I\H61+VI"78G?0V?PO`ULL1&U-"=?CP]<3YQ=8;
M*<['4IJ!G([>X]1S!DR&ORAAH%7GWAD6R][BK)WJH'U/DDIR*/8K=2UZ5,X&
M38A=O4EIGGBUKP]#U2X`",>@'4:MI-F</L"C9+37'>R>:=TK6F#WB)NE^+;8
M.?"*A+!@A\=%%RS1,#O,64(@D$1_F-%AL/:JB.YP<8$)-&"5Q\I8;0F[9&S]
M#NBC@@WP*QAZU1NO@=VVSO#38-=K-Q50/*H!A^Z[4*6@3V'GTX]T&\J<^TCR
MA>-22&=DK[Q!O_,+)X6.$W,ZS'#[I746@$WN$7!2>OO_S?@F[>]AZ'>*]R'G
M&!G:<[#=L$YW':`F6ST9WK0$N]U)G=/?[;)*348/%;CRA?S9!)^]Z[-;]WBT
MGJG]E=V)L<)I@CE<EF7STD?.ABF(6R=RPP2W^H&;C$"OS1:I\\**%5ZUP$4N
MPKBJR&X9,8DFQ3%[VU8QRNK>FS6!]2/!7[C._/0Z\%7V.U;U=1LO;$C.B[X(
ML*<&(3+=918ZJ"O+1;&A,F0`L_,+!&@Q"9.N+)B0F1H=GYR1>?&E;N-CHB>-
M,LO4=WOI9XU6[.UDC,SV0=$1EKKR'NG-Q9T"0L<SR[[M_&R!KFGGL)KBQISO
M<\BY(R>JU1TRA.=-D=<#"X;WS73(LLEKK55`_"M"05<)['=6NU5V?`'*/:C\
MF0QO6MJK@#+[T_@,6X)C4[;E,1M62S!$?;`+AZE@_`1HW3IK'H\!*P;-,.)(
M1EC*<EO$AXU8UU'Q=B=S64[,CQ#@Q66:J<2\SHQH=R^88QU(@QI.@1,6&PM'
M/^N%U)0+Q-8^4&[++6Y+N-W*80K/OED!AE+T(BP9("_S$1W`-,3?L91&DJ2_
M$5"'L$"RJP+(5J,#>AN[PRGV/;_6=]@[+X?![<$8]L0M,#'^W3%_S@9TF4R:
MBWF\(AJ)B:-SJ=.1Y>_LL8^1)K&GO"+[HM.^\&[)R#?(N2*L<Z/![GE*6V+^
M,LOC3@_AK@!*,V:B[98AF``0]'C$;`O[CYH,;UJ"UE=]!^,#KW<>``$YP=BE
MAO:,FP[X<:\M'M@(QK-57,V)I?2"$5DOJ(^M]G/A6U?Q#&AD%1]N^T#\7J\&
MJBVE6W$1C=)X4G/52XJ24D`.&=ME`HW2`RS(K4(:/%7],\/_P?+N[*76A6X%
MC>C%U5N#$/0A]F,`T0"^*'U&K>HH9J&M->AU.SHQ%H_<H9HEEVH'MG=XH^F4
M.$/-+E;OFN%8I;=[8/!2U]FN6$,>B@X>L)MGKHN*?=Z=+!5)JL;^?AR<F80]
M/:N@C_@#&VZ'Z\(Y_Y)*%<`'<%[83J6280&RV95!4!I]EV>(B1"6TBB%S=*N
M'#<FS;;UD,[.C+R;>EECUY]BE,3G5.M<U[6LZQI&X"7@3?O[0>X5Y>H+$)E7
M$2X"75:77#'5I*H0?ZBZ#]Z-T46"&KR&B0->-;=0YLE,[/1G7Y+ED4W%,[Y0
M+``NV+12:*6N>@;X;>EF!7E;C1%4L^"=[?I\1`QF7<6`IA22_MXA"P<!%SI(
MFB+9R<5?08I[!>K0CZIF(&T_7%@"_;'&SOAC]$Q%$XEP,N=9C"S8GDQWL,&E
M++@=VZS[WQD,&(I$(LJ%66PWK_=[M;`_QA)$=]ZS_57QY^)O&(\XM1;Z["D^
MHEC)\'P&A^&#?V76ODJDQ1M.XW"<STZ_C)2@HT+&40=$Y:C8<`A;8*&SF^/-
MU6(G`,J)*DT'TU/(1"EE+48-!.W$O_8.(YM!9:SZO]]5V+FBS@]`76FC/)+T
M[NOJM^FF[)*`-^VO-^`ZV_I6&1YHI8#QM00-QO=DO*0^[JF![FW$^<E80](T
M]'UNG_V(V2:]S=JJ"F6>4L6^(KZUH*1H*:6L>XUY.(1+L5)5,6@:5ZLH-:MV
M5(O#N8C*C[=DLQU056&Z4EBI4Y>3Z\DV'IGC$K@O*`N6PI5G=O]B"/IE>0C@
M<W4D?6U,I)/_SAK;2^8+6`J/[#QG`400@SX:.'\\B.?<U;&#191TO2VWLMR6
M1SGK</0%U+44T[_IAGO$7:Y'N]=)JY)S1:-#VI'+3D>%X\M!O"U[W&MF11J8
M;6.^:<;?N6U/U_DJ`?3W\BFH"&<X=>T<+%T\!AW.(M-J;_M\NO^';*XXYG:[
M"<WLXI>:;X17JV)!J"=(+V8=U2R/@H&%JP6&$1(Z=H5Z@%RU([4Z-T9J"43A
MR.Z5WA+PIOW=[.ZW0]\&Y`ZQS_5"`Y'T0B5R"H<IW/1J(1DF-CSV8#EL)F4[
M^ZTSX,,F[8E'5DN0N(=E673R%SK-Y^"!O9H69'**JHB$(YYNN6$#8C)[FNZ6
M<W&73PUV]U`.[!)C<MM\P1';;'?5([#;[>][GUE0%B[;-<K)-A[),!NZ742F
M^"$1MAS,YD/$'N6^,9)*Z2-8^FAEPK;G6&ZW<EL6\5PH]_O7IJ=9RK(\%OG[
MP7[*;7.42*K`'5XP(&7[]7;[*,N"$WCR!!P`RK*]*XS2T$Y95*J_H]H%6+"4
MCU\?Y>OK:U/CF,T(D)"P-R#,7Z#DDQOGG>$!^T$16OV-%5-9S9<5C***7\7`
MVX$H)N/O0F@0AO"-FJF7SGSM%0C9':U@3+?>]!Z#'X99,R[PX(GYP9D8VST'
MPPYF);V(H<7`!\R;CC7HB_VJTMBB0J6<QQ/PIB78?2.S[&Y/CZR5,U^H7&61
MD86:H<+F+:]EK?(K7(]\4$_15B;KSH3;=I\"K0%II71G#2@&R@5Y@\BG.+V0
M$U!K3=$C)E&*G3^$+XT`%H+88S[BC@_I(VPE@RLR5OV\+QXL");V,0<*0+E]
MW/2V[.U6%^(`Z\IUB)8C!Q!-%%OANI:RW,HBXK$_/GX]U#KV]MF`[\KU`7RE
MN#QJ&3E?SP!JF$`X`;>/$T@L95&P``K(]Y6352B""S7J6,:=;5^6I7Q\?)3/
MS\\CC($3(/-T@!W9$-AG$?W4%?:03DS`>^X.$3`R.[A_/]G<T^G&!NS6;9L:
M;/O2-)",7<77MNP'(?N2Y)]93;=$>S^,7@"_=(PV9S$HFJ><?.G?R?2!G=[<
M\RU&ZQE.5U1S'B.L8.C$G",BO1TU#UVC[0%VZWGIS$%@J#M8DN%-2[L,INGG
MG,3@X!G87J?P<HC2;+/,>XRMY'79P:ODP.*A:CZV&Q".EIH$EG++V2W=/`IT
M@U3AG455F\<XP>X)-DV\:X'2ZF1AN:_WBMUSF\8P.ZT^)5F2@DZ?H@8AW;8Q
MB-K*YX,B<8@0)9;/@)F5%*"GAIK=A76[Z+H^$DX>3*Y<X&^*B'W4A+B593E#
M+K[N7U42D(W]=,<3SAC=C]N'RVC*3A-ODWO/"]T'W"R\VKL#>(#>V^W!]%;]
MP&U-!,ZD<"KAJ0M`E^<.JAVJ<'74XQQPV&C25#>)J=T=L"T+RK)\"&?S$9>Y
M)R-)7UYZV`P<'8/+??91QI$:AALETMFN0[BB^?<$ZJB<)X]3I2ET<:C$`.5V
M^RAA3"S/>URYNDZ5NUU43+$T=(JT.(4M>_DK*M#'%L-P0*H-M6#%L[/<[X\"
M$SL9PE".Y2Q9GX`W[:\$HU-NZ@Q#S`Y%B$',.LS(U70G1Q]N@.DK2WG$=-I'
M9.<^1W13QVEPQ6#`:FW*DK=R-D:)X\A&=$6W-EANR[%U7K:M:QWC5GRZ@*/E
MG<\DBR-??4]L\K0VZ65X.S)*9)0*KN]/(D:+6""*;0BHM]];M!T,Y_U88#?;
M%>[W!^`]'@?P8PBW$!0L*.1:%BYE/4HF.^2.$*YWV>[;`T![E;(HHEE]`#^B
M8<U!?DV"1Y2/C7&^W^].H`B*6WO1)CVQ..QLJ2@U*]FGDZ4D*-V"=-B;>UD#
M8S>85H_]V\=-Q*D_^N;'LI3"1SM\?7WI\"93#`51@IW3=![[>/83NU>CF40=
M;^Y%O4;A/3I"F$'P#TTH`$LIM]M2RF(25KTDXE7($;(1$B/H85GSK_X*#[K[
M=+YM'/3(6LI@FJ['"`TS`)6+PK*N]^.XM:P/T$NK^ZW?0ZHTI/WER'<&>`T<
M[ZC'5,-]MO`7!AZ!E@Y$/)%'P,^MA+%ERSN@UVW'<)UF%\BSP9]5(%Q.U%X)
M6=2LP=B^>?01U%9Z\S0J3MJ6`D5YY'#Y%4!H='?W2;H(23:::[!)D9XZI:37
M+^"\/T>>8/"UZ[2S<I2R98-`HM,G%*`4[W?=8F<7+/W"+8+U!I:R\EYL80N%
M^<NY,0TE';64Y79S66F&"@5\TR14.TD?OSX><DOWU2A3!'):II!%M5L#UN,6
M^F55!4FHT^?(V+>BP4D2^%8;/P+4/1S/VQ$O75>?*^7V\4@6_/KZ>K![BB&F
MULD^27;?X75]9`H)-=,7)/J$W/D0Q4X0.##"<?**"2%(MK4[&\OM5M^7`S@/
M=M>64J0_=U2.N3=G()X<#`=1W"4K7-O*(8OH':`BS<H97U],'UP/?K<.-Y'=
M(@%OVE_&[E[4(./$(?#9NW!RC<Z/-AM)NP_7>[8>V`Z2A\^L_QGIH>(5K_*W
MJKK$]@:C%-OHB\X[01##[VVN\IW3C/MBB-:1J^,D,9CH)4L3@(Z!UGN7";V"
MXFV.KG>K>4F_VI]H`VSQCEZ,I>?/->^OBF64%=ZL3F\-)K#%RK;;FV]KU=$)
MZ=>O7^4+]W+_^BHKE1Z'</O.<`6ECK&A$:NB)X&=)5\A@:[5)MX;5N0GZ*0S
M3Z5+)Y45^K):1U(@_&EQ!\8?OWZ5CX]'"`Q9ROWK:XO?9!4'KT&88&1IT)H(
MI6J0M=6FBB6OBZSU8IP3.BJVDIG6$P"4G.%RN[FA)O6PP\,Y$DX>:9A2QVVR
MSH+=$3!$;SA"W!HCIKN>2@K;<POYO]Y,]TBBK4?2H>ABY<=1I(N>E=;2_C:P
M^T9RN/*FX:O.M/3,F[-%O[)K"&8QR,R6.OYM9R?+#.!@S;*:2O%S-PL<TELC
MD*%%L$=2\*_I'0AU<QGZ-5)^[03!/-0R)&1$E8PVK@KPKH%5R\-SVU:D<TQ=
MPI1U,2;Z8/>L((4)^&D`A67:I)"'J.KWZ^/C-S9E5#4J*&=GVOOC=BN__OOO
M(4FUX&"J;1REK+CEYLM2OY,:D)U)F&&1,Z#8D@@^Z&%5-OET'$_FDN54`T%0
MV,UR"7LHRL?'(QQ%S\D(M*!M^`YT&`>='14SJ<&T)623V.['*Y..>!*>\^MM
M6<H1Y\`B_M4#:%WO5?PNS!Q4?Q;/6:H@7(DK&4;U02SY`4HG%4H:K@0)>RQG
M.6&EQ.",(NFL><M9,KQI?P70!3`VCTR4+*7YHA9=")A=3ER+`3X-E?3196NO
M`OI=O:&`3AQ4M.@537&$UPB8//'Y@J6IV3CZ,+\#OT3;[5Z2>B@/)67B*M>A
M?NW@>WG'D%D1<7[NAH%S7S*>U*TU(L(P9!CP[;9TQW'5Q&)78(^KM.$=-JQB
MN3VDOX!7]A:X"A7JH9V_T<M:%X!`.@8+4/[[]>L1^G&_EW4#B<L&!A[)>\4M
MHE)-%YQAG>L^;).YPK<%"C9/H^['U'$F9ZTKB^?S*N;9X"Z41^SO_7ZO]&KE
MV%)]$G#EQ5#\$)PAKTN,=_AEP>JIDX&2CW%8%BE=V*G$<K_?MQ_7X%X]/AEQ
MC42UMH[L+GKE/1I-VM%(W^>=!7`=-UAD7&PI%7WB!+QI?PWHG2;"1C$R([JD
M,S$^@T";B!V70'SOT'.;T2M_J4'0$6='EOLZDZ!4ER@^M%W+?+:AM_7V*C#H
MA4=;_4H><E+UZY+]QO-/#IF=+9M^5/_M8HF0Z>?>X\?A,CHP?82.DZ8SK+VM
M71*'Y-IMBU%LU1NQU:EK*3RQ2IJF0-E8P5\?:@'UKC$\?@30WHM&/#1\>80$
M'&HC>X*<U5WF^)RVLUT?OWY5GR_+4K[N][)N26[TI@W:+6@+:'3\+X5TVYG>
M%E>2L_>M0O*ASU?Q`YUM+0;U1;`L!<M2N*X%0%G7-8X=/9X%X?BAF%_AMG_\
MSD:<]CI*C8&[>TKQ1>N!O)5U7;=<C)IJ0-,)H@ASL0FB8]G6?E*:/Q>IBFG[
M'.@^_?;\M^7<5<!RO%^*L!0I),,B&5Z9"\$$O&G_"B(N\?Y-:RQSF/080I7S
M.UPF(T#HQ(['R#9"-*@![S$7A17<!"-<&E6]PF??J^&(X@6`HTF*8U)LD5$V
M.8(='T&S,:TZ2,.D3G5!LG&D#<O>0QN(`3^&I1\>@NI!HN<<Z9<GBRMA^LZZ
M+.5>OMRP!AN+S,(&^-C!KMZ.;ND;T``]R;#:Q*,=E#ZVP#]T'+B7Y=YSF\1W
M5G*+(5U/I8^B@V+7<FX_?WU]G?>!6@JP4@P(WH_7GLOM5GXM2[DOC\0NL%T6
M6(7*RR(UJA_!:`K[LTH88B3F7;EQ!3C]()ASV''*K#[VJ?+"EDJ5XY35(\,3
M._!B2*L""QY(-J!7^FA4\Y[F8EL[$7)HWN]?HK")T0-G*?&>6['1'<5RI25(
MNO.=41FASX8S8/MG_9Q[",_^@FZWY0#WLC'I9`50L-3["TK`F_;W,;L>V)D!
MNJ@GDR;QZA5ZCY)CCP'J`$T7[(KL"$EG#8AW5U)7#N#R=&GW6#')WK&2`J.0
M"$,UF:+#E,HV]D)27-W9??4$J[)F;-5TA\^^VHH\M*?M,NAF2L<`0)5;GT0U
M]9_;G5;VJ,,]!MOB#(9$B\FN):Y\2:Z]&EE<@8_5`HCZ)3\RT/?J;@ZC'BG7
M4CI?,,415-$5E-O'QR'S5?>-QB`7B.;4K"Z%]_5@4UELT399F*0^]?U^+^NZ
MEO]^_=K`NF6EVOK%*'&,/X`M$8_EZ^L>JGQ$X0AU^D%K!P6.UC'-`*MO'I;%
MVW3!SSC>P<J!XLYNM]L&\D7RFE.(1"68N5,$.PZLC4S7(-Y5)V![N:&:FZEB
ML+%I@O?6K76];PX7G5"C49J%G26.IG\P<$*H=F"\PM7.`*LDZAX2E8MHBPT$
M?]S*LJ+<M^2\PB!86BG(/'Y*P)OV=P'=44:WLQ/,%HOK*]J[F&1(+<L@4,`,
M6+%-I=6%H*N,H4W?T7/''53QJ'*$#72M6[4G!F"$%8<T5$S.9-/6<5WTT[X=
M$'XL$J..3;$A%89,#Q8K;S&C>$\P3I)D1BS+"T(P7SRRA_=L<^Y@4E5]*PVU
M?-\)`GM+6Z"$2?UL7E_5/_M7@'LUW3-VE9!FC8+2*&Z[R7=]?GXJ(+6S?[]$
MO&[M7$;0NG['C^('=[%U;-6H!-/$<Y>"%"TLXC?_]_F_\NO7?PK0#`F@H9_5
M^O'QZZ%@<+\7+?\6^4E.;Q7]#('CY&^&M3AZIV`O2[=.3R2$L_]\6V[ECKLA
M;RDDRQH[7GR^4.,Y!FHMVZ8TEW&N81IBKZS66PN_ONZ:F'CE6ANF)W;6S^JC
M>AZT/^Y`]RPF<<8Y*^"\+.4##]#[2-)C[!#+<9'0*>VO`[LC`#=B@#GH#P\H
M;5/IXF#HWGDLD"7PU(THNJ@$UJ3!6J@[DO0LC_A:XLRBUC2I<+TY*WHL)G6O
MLM-Z2AA9K4DI35,V<(XGXE;KZE6FS*])\_"T,[4^K5G0@W:VN!4LY;[>C;3>
M#G[7Q_:>:CY1.&+$VW"39W!L^4&!7>JD,WH:MVQ$]A@&GCJ64_':9/G\^BJ_
M/GZ5([S5Y8+B/K8LRP/TK/=#V_-CN1V%#"S8/5PXY<7H2>"(C;S?R]?]:]M&
M;<4D&GFEO7UD<J+9:?G\_"S__?=?/UG/;/O;L`T84+M7)CN!MYXW[,:4IPPB
MB[P08SL$J@P:J9T/<URUU8^^%G8X;6%G>3\KIPT,XIG=L7@R^6XYQ.:6GS\>
M/%WHP-57LFTH6_QJ9YWYVD)JK%L9%K7H:.C0BC^&GKZS)1"L!81>7.ORPGMU
MP>68?Q$4OBF4NRT,F6:OI1/PIOTXL.LE5`T#TE[F+=H@<!141F`@$G2(.*<Z
MKJ^61=\93I3E^`Z<V+DF`#:3DTP"@(!OT5:K);T14*HHC?*5Y)%Y?H(%!#$#
M`I2L+.6V7)-?IF"+C\7OO@&7Y8@?LS&A!P#@H_0I=S#$#D`3Z\%23D=B9PXM
M,WM,YV3YNM_+Q^TV%N+0&!-5&5'R4::W6(W+4Y]YUU^E*>[P:#N4N+PN11O#
M(:4W_FTK$XQJ<UDIN#8>#:(02"D?'Q]'$MP)&)V-:R>X\AB?ZUH^OSY%;&XY
MI;,:\=%2BLOJ@DO@NB=8[:#7^]PRZA;XZHK"$(S?U^'(R%T'.`.@D@S;KF,3
MW^AY+3#W1I7VY?:'D%9%>4HYXW:[;2H%JUX?C*15Y-RK.%>SJZ3FM<8](BC=
MZXO8M@L(G8G!A@878^]1A./N;$FRFFOAO`W_&:($<`89H_)1Z8?-B>J)T2*T
M[W3L.SYA>?OMC^NVZS("`9`,;]I/M"&PVP*RK3D''?`;T1NHF5T%:DT\H8R/
MI0&#<!A&)?I-'[5R*ULK%_T0(73BDD%_PB"\M`-68.0`W<7&5NIRO?NY[OND
MM<W.>SQG'2.JMPNIIO%3Q-Q];V&6%LNZ;@O\4H[RE%Q9N-X+[UH6Z&273\!R
MO&]3^2D&N_N$_9#;V<^Q+\Q*,U.4(RYD69>EW(@2[L.R-P#.9[ZO:P4.2+][
M2X92)H?UMA%(!VW++6S9I]#;H(E+_>[,*A:4C]NMW*K,]CD@]2AC^ZD++1QZ
MHW7IV1&&J2[[>TI)W>_W<KO=JKCM.K:=?B4RZVSOQVU]TYTSJRH*/'X^KR/`
MMX<0[6X&=DW5\R4?AX)-+15/C:`JX2L=8=...^@]PX&*6PC"KB%N^6IJ5T:%
M>KM@UKQ]JQI"HR+0[)78Y/-N`O#6\5]?GW<!=IUVI=$+-A7%:S!<YM95U*%H
M:L/431KVV66(>":9<Q@NN^O]7#><A1C!WQ/PIOTH=O<2T(V"S4;"&$;*=)FX
M^Q8F;BX\<A*-DN`@MNB,N"DEH.1`V\PZ&QZCQ5HN:%\`EVT+?CT4W:FV#N7"
MHP3%]R2F/09QUVT]:!@>S!F\YVKM:35R'(\L;\.%K!LP+&8B7BN'@+%XNKNM
MN8%M`0Q*Q97J&^?*4I8B*A3UMC`<%V7=&,"]QZA+L&:_'2`,.`/)R::2&JHV
M,[U(5P6GGFR_1*`=D(^_W9:EW);_U$H\*U.W;NRH9(Y8+;X3(GQ6ZB]X*[MZ
M0Y-Y&V0_=T!,[HFE#C-L@9\8?W9,VO'I@7>_,])HY@KVT0!HX.&H=.=\63J9
M=%E"&S]K0Z`\N45_BJR]/YO4:36"M0(%*P>!EAR!W$^1D_>6K!:@T?L69N.-
M61M5</SN1"EHK6*1"S%(^E!FWFW?;12J<]OY$<IP<QVY:AG?=L/N]WMS[I-]
M3L[I"7C3_D9H7)JZN:5#_O28W6BK10BLLP%J??D=B"07A@PM1!'1V#&80*^#
MQT1-P=:BNT]06^),D=OA@<@X-Q"XW,ZJ6$<U,B+T3GB6F8J3";UT_VH10"E<
M-8=H8V\''`DX"Z4D@=W^2A9=/-DPQT-,#+HAU8\X5].+G#ZG%`=L@`%/)T$_
MOXX2?+!ZLG1T_>A08-M/=,)V#PA+'C!@D5`0;<68P7Z_/T(8E#ZN:/LJYC>6
M2A!,U'D\BZ-I?,B;/4(;'CJ]4.QW2VG#+X#R4&J080U5Z$+++P1J4`NKW#*,
M^$,7!H*5W4L\>\SM3)B#!/O3),D$CR*?#XKI+G$8G%.2OBYPM*T%"\Z$-9L0
M1I:OSR^]D]0)N06BS_6:=&B#[Y&\U-'?"D#:(&I)IP=EB+WYJB6!Z9U"ES,W
MWU`3+-3LD3&\:7\-LQM)%X7,+AL`!A.SGB[H78?/LYQQ=(T%$B(6CHQYI'W;
MEBOU'%,TLU!5\4'IJTX$S^\I$9RL@9YIC[C/C2WCN@H>SS("T?M>"\M2LPT*
MZGNBM0/IWL5?0&A8OA-D#Q3,XYABKJ""2UA\&1U*&F<F-SGH\(C3K.O#H>B!
M'P:#0RY\WB"KX],QY)">59V,$$40M^[2Y]W!ZD,\[HS9U]<&ZL0UE=*%[NNA
MSV@*+TC]Z5)TO.L!Z#8=U?O]JP`H__WZ[V"T'NS7[GST0>L.(I=E*9^?G]KA
ME&$!'HJ65.6^O2R<([=HQ%&]3#X;^_($FS;RKU^_?-X!:/(3,"ANGZ=NRW(P
M]/9>U/V-`-H(P]-([[6D`=1<[/=]-;9+V6+U_?GXZ^NN&/G(H_!W5+QN:N::
M346&IN?JDAVT';S>G63L7E9<.M>R+!^5$F5Q^X1V$^C-!_"7_`2\:7\%V&V"
MC.`+89&"7AA#$#H9):ZH+<7P=#B+$#0>YB%A]=`GY+J><:R4'C`5X[PLJ`/(
MT&`[[3%B,5F+W*8U[TC$8W+SPLD81%'%^PF@OL708H':$I:+C%SP]DIE[AI+
MARZP3`NY%0<X62RJ^%/J)"41X]B4>_**8C@5K]1K4<P(65L1(0``(`!)1$%4
M*_+B:$="S^^.!BA9O]\C7M@96U1,\K;@N=@`)C;]W'60,<HLSA8O*Q1PL)![
M:5F:S/DVGFTPK@/J(7N"U_V^%E?6R4G".OZ.AL=M)QM8<>]BXKTAMLQ9_N__
M_G?,"_?[O?SZ]>LQCJ?(593__ONO?'Y^/L!\<4(3;!]F+2@EG77)NJKI0SK$
M%HP%[XLB074G!6#CB@.@7-C078V^)P#Z5;!KQY/JJ^=THO5U)9,)383`E`L\
MBKJXU=4>YUS7^Z`S?^8\6`UVV#FYV/"5,YM`AWE1QU+3MK'=A3-.B:>\P,>:
M=5NHM-=MJ-P>'J=";;PWZ.ST['MG2T*JM+_%0E'L3FV*\(]6LFRX@`5#F5[O
MMJIM90])[X3CL>#H@5TGIIQWL'HS1P0(X3VG8>^"K<V=G:ZE=SSI)VAVU3"I
MZ_&<BX,C<'CZ9XWY@4X1S8U'OLYZL+LTHL4TSS_JC*D6,.RV&W\,9[[>2]06
MG?5OP[Y=7&4N\M"L=-:B#6W9^.73:_$#U$]VG.Y6B7Z6=D$!OT^U'Y2M'9F`
M>9=][//S<TM^V?JN%#IBO<NAV&T&+]J+;Z:_'KNG8*DDX3X_/R_'WO_Z]>M1
MBEBRHJB5(TX]9!U6`$=E0LY'$%4!/,UF^2_+(_F51:@0&-9X/VZ]W\OGYV?Y
M_-__RO_^][^'8[(IHM"?'NOW[L3K-K\["'UMM(<=LS2*@;1EI$W2G[RC5E*B
MC4>NO'AH@'<F%;/N?P.SEJP":-M':4M7\G(06S3:2?+[_+EW=(9&V9W+QQSM
MECOOO+,=N"?#F_9MF=V1V*TIK[SWIUZ5"%=DT<R`[*6T./&'FZL<SF-*!0B%
MP?T^&+*UU'I"Q4A%]%!_GW&'9&A*K65+-B[@:)+15$TK>U@#_+"&4B#*3.K2
MO$//"`DP45A6=<\VXA(8TU$VK:!9;Q/*H7H"]/9P48P,U0Y`&`^+0)U#DBX<
M&!-"O)0.4ZH70#C@#2[+VFJ[LT)8<=![3/E"W?0P,?>0'/O\K,*'O*0L)?3$
MTSFHYBE'KDR.69V\:G&GVD(XS[V<?>!^_RJWCVM+]J^/C[(4E/]]_J_N.[1)
MD(TM;A8?`,M1<U2E"V)I19M]?'QH98CMJH]WH]_I>K\?[Q]'@0(4+(N69+O?
MPSX4R2=JV;$ER/H*IA0&TXT@3/:V@!@WA.X5".5ESK>R;LY9LSB@"@>"1P$Y
M=^M(FJGYG&:\F6H]\,:K&:-1?21'6N]\=]HIX#KR'-'81P+>M&_*U@[(C]E=
MQ"L$",;72__B3CS7"-YFQ9W"]X`-RQR7W7P<N%KO%Y'P^\R[<.2JK$-RQ*;6
M<Q!0)Q2P5WJ3C\EMN>FPAG-N?2QTZWV=?#(G?A90D@N>]NEL\LLAW%]A=:=@
MP%YFV`E@TS)UJ))3W+"Y*#=K;36'(QBE8BT0!`<+,&%`2]3_K;-4@5TID15U
MQ%8,>!%ZJ2JT:(M:61^%+I2@'F.A,7IK*D\@J/KL=A$;]G."#EG[^W1DJGC4
MRL%"6;F66TT3=OK_^?GMXU8^^'&$-RA'Z4BXU4F*&NS`+2$,4YBAE@T,`-RF
MHXIE>80R"-9]75<_8W_O7YN4V]Y_]DQ_;EK>%D3[0%5NL3?B]8.DJI:D>^7'
M0"?L'F%LI,K?>)"CR]F6)@;J$9)41%*9[K,:<_J1^7'M.X8\3ZFJ'%+-:9Z#
M6)2C7W1<>*E+5)?BJ&.8R>AN].9L_"Y$@HF5HTN&-^W;,KLC`&-$?6LF_VR:
M*;:QP"W'V\:DN4(24!6-(D;Y9/H"H'B,?^H224_8LJ`\UA<_<UKE8DE/?M?5
M+:6L9:WONU&I\KXMAI*7.;B03;9L%4EQE]T=*9%$NH[7#.AE)0A@-2)E0@B5
M5C&<DE94Y>8HJNOY,M-LL-LL[?9G81V&)^$+(`A@5@#"?:4">,KM<^DT?7U]
M'<47W+JL'<9-;=&3U2)<A`S3Y]>G(TTEP1Y4/'-+TNX`N!7`@[E]'5`M$TJA
M6#*AJ2UTI<FB"F!8GBRNXJ4[P,?'KP*@?'Y^JGYX^!@N.*VUM$O%_MECY81$
MH]MUSO/W^UIXOV^ELW$RNU+OV>FN\D[630EF9W8/@$Z3*"L!O*R&)[3+(>;J
MUK2YUO7(VM,:ZSD<JC#0^;Y^W3Y,F!"5FH><.]1SK:;"6IPIUB!?HF4G4!BA
MF),DP#5LL5=CPQ%X">ARX?Q15+HTQ3!.SH5UG??M9`EXTWX<LSL*9J.C>`4]
M3V+AV>.45FV/RBZ!3J0I>VN]?(0*!F,/ORPHZXJXI*PC9$ZRW'FO0QKWZG`+
MC@6N<GQ*$4R/6%11CN_1R&5->RRLI8SL?5C6M_M.0[#+.*[;,O&LOW'J%[>U
MGL-<R\WYN*]WD\5\M@,[[D%-O*"CN$&M"^LDRIV?R6I,`6B6,:CD$!LG[>OK
M2RF<J'?LQ2.T).GH90R8_D*?`Z3T#@6[*M]S.?%$T:'J"`GO\V^!P@'*P::?
M<<%T$Q_/=[666*NQW5"`+E$,4P)RUY)=<5?#95DZ<E6"Y:RF!UM8PB$6]@^H
MV$$?Z'KZXVAHD(R3.[I-CJZ]+'J_97LQC\IBC@R9:`?IN`$1L(7B;#T10*U/
MB(.!=T]($[Y3R9[YR%LFTRT0^1C19$KY'FII-)8XD7'7#<^DM;1OQ>Z.``O.
MXM--I*!*Y'$3M$J=O&6.\Q,=QK&6]'AIF5M[`9Z[08=Z@`-VZ_+#Y[%[Z=B5
MG'0?Y&87CGKG=8USN,S+$0M)F3@A2LCB(3J^EY24A^^3]PYX;:P@RJ-"F8ZI
M;!5<0!/%5<NV"\X:F(H]X%57B++WH&+F3.##Z70LFLT,;B'*K[S=;F798I^5
M_P.M%D`7D?M28L=8<))M(J#KC7OVLN<KY"*3I9SJ5RJDA.5^OS]"8%"4LZ3)
M2)W@8^>#L^!&.QY9!&]Z=0C=)SS;H9RQVJ6XA3]*N83W53_``@4R*28?4L]R
MJM"(C$/M2!&?>LWV.RPVL)PB2=\O?B$28\6H(A^,JTPXM0EI%!7G6$S$S+&H
MP&W':+[GY@I4UQ*A`ZW_;(EPFGP06$>/+%;>1;6#VG60S^Z-9YYK8MT3KW6J
M8H(F*%C63L+<<L1AH['JRS_!G48CD+^?-P%OVL\$QY/'P:IWM33H!USS@Y6<
M#1\M7LSP@^F4B2/U)-NND0P%,.0\(<#ONKH24_'/^Q:93E*1`-7'S%#*"ZSY
M'\%*Z$E.+I2[<L*#!3SCVG;V9U<<>$QT2\Q8ASIOXKI"#RO4U86I2>`M$K3Z
ME!`[T[W="[&=7O&UCX5\3]2SS).W.'N0^_'^;@)OL,11#NV!P0KDE9`A;Z##
M*E._C+DJ^APV4<Z<[WY?'VRB1U)&2ZRI$E*#<HQ,%4&_[(LITL05DYRY='=6
M](M@^&S`"1`9/J,7=NVU`Z"=H;.?4"LZ5)7>I.8`%<`L8KM;_JX\:(^:W$&D
M\"S(4XXO<FVLLHZ)I!T*L0KE`<5X.HJ["&=(`OW24B-BNW_O\=!>Y`X=,F.V
MCQW_HZ]I#C'^;[+*WCY^34Z#]@?HMEM[NDE9LK1OQ.Z^"QJ3`TE2(PL);9&"
MF7MVLI$H^5,<B@1BF2DVIQC8O6$[I^&<G.`LZFR4!'5G1[_6_,ZF+LLBA&/B
MNO1-$?$%5:4NUD*195W7LFR5AQ[/OCPRMD4BQ`(X5`:*K_/E$8505:$DJRQQ
MC\52JDTEFR$DKC3[8;L!?-U6![8>(0U#SI^S+7$$NE$X?Z:(10?0(60TG\!>
MQX*^CB+'X7FD*BI1Z()\N25*A][C$*UO[\$3O89JLUK-!#53C+KHPW/A5P]M
MWWU[O"J:X#B&YQ8YJBX"B,@=)^2:AL6E*(+B:HU[^M!%E,=51?48:?!5B8`Z
MP<X\1`4>-9LJ0[1<1^_8N3ICFN6Q7C4\%*]:85U8G$="WVI2QVCZKT&N%LTJ
MS>!Z5\Y7W^10=<?^`GJJ?$@">`'*KU^_PF(@,KGO?K^+G8<K=Y(A#6D_".SR
MZ0,<@F6"+>$8.30'?7FR%$`+M$"!WOI<&WMWE"6]<C<29J/-!I7B2E.-7S72
MFM3G.J5X'C)DAQ294_VIQQ0VA(9UZ(25,AK`&0Q`:JM_P](7C"]RDE5L'1;Q
MKW7R&G4C-XO?L>WBU4R<P^!&+:"JP*TQN+T(JO?"$D=1"5+$K=;@ETX%*Y9V
MC#A;68*N0RGC'-&\=TJ6,MI8QZ3CCG-,:<`7\W106M1"JUH`6,C?&QK1GJSR
M@/A&16)8V:UB0"E9L^>>0Q12H58242H2T$K/BCP`J[AA6&L56A$\X6H:9-W"
MTFCG2)Y=&I&_;"08CS`;T:U:.%)O+,!9`T=R;LXP-BQ;A;V/C_+Q\>'(Y`F)
MS\T1_?S\+'=186X4`BA'A1G2D/:W@-T`T%XBCD/`X6_G[9-=E^F21*#-G6K&
MV.J3G-(TE>3A@P$]V-<&J=Q8'1$LVV&R7Y/S%JRI^-\.<+B>S%&=I6NV<S<P
MNE<+H\G\UXM7E'/L!(M0+UI153R*23AJ6[7-.M%5/6;>;A'O+$??GT&?42VF
M`P6B\*-@4RWF'C-7/;=.K#S"/7@=W'H`\GY?]5:P*.I`RFUK*D>,15<K5%N\
MM&._!73MXT2>=K^_W.]K^=__/NNP"@X/].-21UA2(U&1/'5W%3M'N!>A0KW"
M64#='RH-;^@M:](+E6A1#E#X'X/MBD;?D5O^).L=FPCXEDTA8B<@]K\)5E?-
MLT8CV/Z=)RTKW'4H7Q8>5A>%1,Z"(CSG8D_V;63X-R)KCNO)PA%%1\LL>PC2
M-I^C,\]P78U"29_*0/!9JC2D_27(68/)NK3C!)L+!S.U2EDZ7CY'5/X-D*HT
M=TO1<CG%E)<UIU[+6LJZ:]2BSKNI=%[1`8<(*[\K]LDLLC3[@&K;7H4JL)!?
M*CZWN-=Z@./;%GNZQ^Y*35YU_U7-RU(\#8,CWNY0"B@=JK.46D22K^BV];IM
M=U?WTL!<Z[*V[GN4+:0371Z@6186J)/@V'%0(^?N``>`JZ3`"HQL[WAK]ZW<
MB$24/OMC9,TB1FI=[Y5NH">\514I=-IR+V%]LM-T6$0>0%B6=NU//&T&>7_,
MKZ^'P_/KOU^ZZIEI9*L-8AW@V\='^;K?"^\\89`1)=^!?UW!L;AA.'K84=V+
MG6,.+0&N9V1EF(1G'&I3KII-=V-@RC^2]M@E9%`],UTE+958[04PA[YH77FN
M.(Y])TI+M=M9=IU*&8+>?3N)U;8]T)-]+HTQORT9RR*I#R-3*+8`#J<";0)K
M-`TG`6_:3\"Q97#.<MDS6(00X3SZ%*?+;E(R?N=`/3)K`Q5SO71052O?"1(6
M/WU,3_'^0K=RW>+J3B_:;NL<,:O%U\^,X).]F,J8ELK^D2J[K#-_E#TN!;PW
MWNNCC5:NY<:;8A+WAWG$^"Y:S[33BU0BWH+R4$X[521HYV_X?]`E/-L,*%RJ
MQ+0_BP^>6+1>;T&PCVD'A-YTO'_=S]"!$L5U^_?=`[L]J;*3R?,ZABE08M"K
M!`-[K.29](2X?ZYUA#EMG&139QF-YD'5IV!W)+PQK,I(^Z-,8R0HT'N_K^6V
M.X`!H)723=%NSZ^/C_*_]?-,SC/:MSP\$:M3'%<G9S1Q\&0A(`H#'!7'Z($F
MJV5<CXUCAF_H7H<5"!VP!VBYK(8L<7?-DD588$B2O3`-C%>CVD;\_.C_BW(J
MZ[9G4*Q#[VX4H-"IU]/2#E:`DC'8I(/^+?FTKNLC2<W*[WF`?IN?EV4Y=K?"
MQ7]@F4_`F_;GP.QD/$[KP"&9,IN"VD)U<A`%6?O5LSAEA5N3B`9*-$`=`5#S
M3ZP9A7(DZ'C,PB-3'UIJR%DV>YM(5%G^HHK4$=-G0@WH$^9N5)V2WGD49-B5
M&4C-UMW7]3&)?GR4VPT-QJ/-L-CW%X%=S0^+[=Y0F5TG*6F]T_.+*Z4#Y+'1
MI\YE-T[;C8\495>#$MAJT<?)@%=5?='R*Z3:A'$BC9H').`L?JPLJP4=[=+5
MXEED-GLHOM?0_JY+9ON.2;W<HUZ(K59NI1VJ'2#I$,O=EH?B"DNYE:K4KPK-
M,$4@[-A>;K?RW_^#\O7Y53ZW..?](JHOBIV;W:>LVL71-;;W=<P'&]JJJX6=
M?5X6]R8UG'KH<Q<QKE@G;8FV6UF_;]OF-H:8WF2KZD#89%V=,"P3^2S8!E3U
M[E-/BRRW+=3D\;F,9:7K#)U]"*?S)MLNW)TR16Z*Z8^>V'?3K3^=#B]'Q0+R
M53ALGK-OP[W653@*SB)X5#R4ZP:%,\1D>-.^,=CU'.P([+)_2+PL=I*OQW.S
M.R`7I2'_I#^4VT]N`F_@F5-SVKHMG2I8I][M0,2;5\>V:)!_;(VRK@34?MUL
M1@C(>#,5RR6SO_'(/-_!O`?>1O*-=>"@!6D,2GWXCA,#D7YY7_H=0Y71H%BD
M%$]'EK*@L*-M:>_UD?1A'2H$["(/<*=$\:''G06+5=+.P<BBAT\%P^-1:R/]
MZ'SR^_U^Q.\VR\#2?W9=&M@,//18,-E(==A!"RQ#]`.Y^T.N9<%R@,3[NI9;
M!?I7<7U4;"^=3KHL2[G]^CA++8M2O+4B#=R"!]1>B0BGU:V^RG<!K4!@[ZM6
M&_<#YYOZSG)&A%TOV"90*KQG0S+,KL$!WO5[5_5'%#$@G!,^)H/E]LB_B$B3
M/;%6.?T#;6>K2$*WS/D][#M'-%$]=)L!D^'CCPKNCZ>_KVNYE5OM$)AK[N%L
M,HS-OG<U>E"T6H^A[A/PIGU+L#NXKHT#XTLW&MPK)^\;_K14B\$XJ@`#B-L7
M!FN#?LFJN;&2$?U-NW`X\6;JAD8JY\''-_O$M3QT<E<I744'QK"4];X6X"86
M1`UD-#TIXZ8AY+%$JZKGA<.YCCE=7I4A?SP85@XUUO*+XIJFM'E-*\M]72N-
M3;5DT):&I6'IG%A)3\$AJH@@O(]*[Y,LR[;85S6L.M7<O$M]?GYMSA%U?Y?Q
MVI63N5^J!KO40>IUWX4&/Y+]AP%%^D7J!#FIUJ+&EPAK.(M3%&</WH2I0&;6
MT]E9.AW*=5W5F`$L"TT50\L2SX]G5KZF7A7DJK90QI,5Z45DT>DJQRZ=K`)I
MR81&R%-8$KZ=GU&-:#K5P21_L.!1`<\D<E6@%2CTV%8&NR[N5"M`+:DV8$R`
MM'I^55X8P<Y<)0U7=$@%9)]'_,Z/<`Z*\O'^_$+UUD0Q&IJ[09863ON.@'CR
M`X[B##YY_6*\1A_^-"EEE$CHRYR/X_<XEH<'-2%6\5[4I7LM9W5LD6W/3@8Q
M(!873(>ML$)["Y:R`.6^WI5:!@RX>%QN+2PWL2;99RKGGJQAGU%P5$Z*[M-U
M+,2BKD$5I_M\I/2F,ID%^TB[N4J'MST2!"FVHX-X5<OZF(!&%@2L/T,G"Q:T
M2N80IHI<@0(G$[3N<;^[BH<J9+!]MEA&6CH.M/'L1V3]`81]CU,?7U6\`M5,
M89-I)=AN[:Y0Q,C3W8/W)QLZ+I(BH64A'6$K6;O4COJ-#^JAPA@J]XFU@S=5
M')R>`RX8=7>30$@Z0G*<MI2N`$M>=3\U1WGA+&9'I[23IU%*^77[4,4FY-A9
M1^;-8%BV&R\XGV5/]T0U6SC"S776,Y9THJ6ZA)1'<Y,O><8<GW*%_=7Y6-=D
M3H!HC`2\:=^&V1U:UC#*J!FP=P%LQ_JI>WUXME$M!@%>P/0.-(,?1SF27`'8
M<,K&JBF8!:$+>86YKZ"]MZCN,CI`P;*4Y;:4^\IMB[IFTDZ\;JD>X5R0)B)#
M@CN>8)D3(*O1!E<+J=!LC$NV<R_442>FU,PSJS"9DUNSO<CN6)Z)@JR2;8I8
MH$8<FG47_*_6W#-YJ:JVAH&PH,!?)%D^__>Y[0;404-K)95F]`R.D`;)2#V2
MWV`JD<G-Z2J$@+4/%^W<5-5C[8/!2%%Q0/9N0)IL[Q>/V'@1'_O_L_>N:V[C
MR+)H!BB5W7/>_U'W:KM$(LX/$D#>0+)LSYZUIZ7Y/';712)!7"(C,R-X9MF%
M";<V]C%;FJ%KBB>)')D;RGY%5*>TS\Z"3</,^EX%:@QL[U)')W1[-`9]#"`-
M7FVS'_QE"`2R/)9AV:XUQ9,Z>^!DGL7;3-?-*2`.K*Z9AO/F-9/E8'*NV9([
M(Q^6DN5'P%JU[3BF9Z"]KE!'TG_W#7C?K_\58/=RCW81_>TFM5\$N_>H8LP5
M$WX5T'?`QU,)%IQ%^F%O0*`.2T=_28WAC7$H!5(W2!7G2'0S^QRA2&3-RK(S
MM5U9@#F7`I_+H[-#;L\JE/\J\,+:P=DL9699TVO)]2QUGK&V]-<YJ38FCV;#
M4Z`\>XH,$X2FD7`P<RV5B,E"RYLX50/2-"6J>]<&]"XB0V7C+![D=-#Z=;U>
M+V,YG17\[!BF(4RKMM%1#[7O`*2`>M2,3Q4\D)'Y6D@5JH*6J\>[$1JRLJN3
MG`):D?ES[(SX-HH>.*MTOW:W8+KJ8/1K82I(88"A9P'%7WOB&(X4_-$$!W9,
M<)>;Z`\0`N/,8"`SHTRA-P/2I(N%@KN9SO/Q.+33)=2_VWE19).:`_-L5)B`
MR#;7B.E\ZZ/GFN\N3U,G:9=E`%JWWJXX`27UYZ7]Z)J4%=.E'AI\'P/.=]HW
MX'V__J^`W:L4+V^@(_X[K_$2>OOZQOF%!=W!:RY9KJ32^97QN@%6<W[E*XE%
M2%F*U$,7E*I6[I+559MCUC;5TFB[0]8$U*F<-QUC,M^8T[8BT<Y-9^Y'ON.9
M)VE\P_8FB(>9^YG^?UUCK3CI>M3A/I8ES,/YX0T#<+VDD=8CCM=[S4;#RWWI
M(E`M:>:=J)JL''L1BF':K+I'`F#<Q%G75;9U4\H,8JM7R:,B`(&=;AD"QLH<
M$Q@T-:>:CH.MQLG`;OO9@I*SD!)5M;3I0Z\S%I%U6^59/E)V+E3%IF"W'N.V
MF6N;<[DVJ,DT1&BE#(+1"1'#1[U^PWZ`7,XM`[Z`79M=IM!D?#A1^[;OW8,:
M94*BZZ5YDF8T#8\)F]HD]<JRR//YM/NQKY]V^I3<[&SC*0T"\9Z92)WI%"FB
M]W$X%[W;1\-<([OM%SI0\W75C7/8MGI(D3$^'(G-GQ!,SIPQ8F_`^W[]QQE>
M_B^XOA0`75PIS]C7M/0B"OURXDU&U?!QRGIG9!HF3+=1`V#HYO:<V%GY,R"R
M;O5TXS\-(=HU<:)\D-JU)K6$RK)2N*?]8Y3O618&F2\12?K"YTU;_$HPDK+G
M>\TH[GDL&`MJ63=9)HSH#.BCP/?@F?G'V_7M"N1RPBZG-X+X=^J1[2$)%'A,
MNGW4%:P&[-+`7?I:S^Q8Y"CQV/$OG#P2@[7J-(2E!#,69+71M&GOSA:'ID98
M5"BC5AF9?^\YN=\;0K=:CV9&NC4`$Z3`C#0F>WI^G?W#X2=ZZI'>@XF]O"*_
M=#C2UI3E]YIG3U,V4C9/0WG9/6-*@]'#@/YUOY>ZLP[(=_WC1Y_/QZ[,(&,O
MG-7$0R`;JZSK.LGFN$S%1(LB/6\:0&=^;.1[&D-S77]&KJPKVZ=\9B(V%^]*
M*V0D2"+I?ZP;3*:@Z+*7]^O]^@\!W?-#6L1ERW\+R-YA=^_(C6F'RRRBO/-^
MH4-:HD`]'`"='F`3G!&:@I3E8ZZX>Z/3V+-5-='%.BD.^W7#V.`99\9OG&MP
M&RG-!NI3JP;\=C,.3.<MLA,RC2\0F.;VV5/6`[-Y0@7::+1HKV:^KM`H*,?8
M?,U^D&3"YIX;;5!_,*E&W_VMRD?JH:5\I@T\NV\`A_UHC2-(:_$[M*>M`;17
M,<C-&C"IR[=!$A5+;RQT%5/;[K^S[L:YBVZ<YL^W"`24_L>RR<,)F%#_5MQW
MK9M5?1#?O!H[W8WL05B23)S"U`5U>0>Y-*+DC;V5B@;N]KU(%#Z:^H&ND74+
MC\;\Q-;C:^OKT?3GM835G$)$<CHS7Y8BI1F'4'H-==^EX#1_(2KC!3??,`*R
M[J:IV5TD79$6H,/5XYPV4#HPG_@ZGF*`LBQN'W1T$T4U)S--I/KGS\`V>6)I
M7]-OP/M^_4?!+F\`S3OUNOP%B'7/^/>,K6,`)_KGLB-S)JX/F92JG7C=GXTQ
M##Q!TN-S?NI<P6%J6I03]);89/X*Z$VU.!'_7I9E9S(=&,KFPIVFG\MF1W)R
M.M"FQ2'!K>R,C.O6U`V(5(X#@*[+_@OS8GD\W!E,HWKA?]^#70U23]V7+Z3,
M3,/*,0B[;NYF3")TB%+I#03&=RM%MAJ9:B]@P""E!R?1A0`FLLP#DV;``6X5
MBTPK%)*X$`?#`[,!=%M5U5P8S%$<$ZC68P?!"A##&5YL6YW2^T$``CIR2'9-
MO5<UL`S5X(5L`L16B^E\`<R_[7ON#%]U8:*-`'CM+)@&HPFPU^NQE3G0,L[F
M9HH"HH`\'L]AHC+;=-4X[;76D6#8`;X."$=@LX\)%`/N4X#C`^A$O4W,*KEQ
M3]:_PG!F.&`,'(83*3N3C#M4W?.-\]Q?)VV?PAOPOE__MA=P'W#.OGD'$,\@
MS)7E]Y?U>UT'J2V4AWC)]WA<,E0!WV&:3R5M'*#D#"`Z%ADI<D1XCS,CBDPQ
M(/B^:VM,=VCU#?NB(0:^R"(Y&);ET66M[%A.#D!QSXS7P5(<7^1*.0E[-'MO
M<G;$,V%R5.=RY2FSF[T*(,_'4Z[XX9YN#Z*;T7[Z!@]^/M?5?-D;U^2DDE0,
M2ZS':F]NL4\(F7`^\_EE&']:EE;_G+?8G3+UJ1\)78K6[5NNXD/@VJ20!R7$
MO+R*9WLCCWETK&.W,BVC#M702*O(H"<+$M,1F68U<)0+2,(*Q^"6JH@YR]3H
M9Q3&!S&H;-=G9DURO1J\Z3&!8XWM@:#&)K'0+64Q;H'#07#_TQHJV?8HE#%6
MWAI;O$F()"41$AGYMO'I0"8DTQC.8AJEDK,#"OWGVSZW-/DUS'YV[&'5!-8X
M\4K4SPHVH#?@]UW2\'[]AQG>*R2,VS^*4-=UYV.FD`0SAI.W2B!XRGO-#Z;+
MB[F'Q=V^1\G+`KSNZ)>B&=$=N>;/9-,=<P(3C(3)WPZTTI`E4E".FE91C'9V
MR$,)R8*_```@`$E$051RS:N<4<K^':]4:4QB=#=K7=X\`$1P6<NTMCR3WN2V
M]OK-KZVY!BJ7Q^-:NSJG]:?C8*%=='K*M&\-`\18Y@,G7P21D+&``N1:=HYF
M'T#*UF;_DTDVHY>3^-2V"\X#66S*19%D]&$:T8S17W?M4C:IHIC%0[()/%%M
M<2%C[<.%(XWNVYXF&9$>F)3>3,F3O6FX""+-(@SU!AF#A(P1/4#,A.WS;:@\
M32W`J*NDF0VH(!GCO\4'0#H801:%9\.X/^L].,>EH@U5%H`NJ\([F2?U[WDV
ML]@U'X+GY"`D36D?Y;H'H#E@+DM))17\^FQ**[.3CA<;5W!_M'?[?KU?_TO`
MKEAV@S<XW4R+#U]DFN[]($]96-SBN2*P@:4>\H:*ZTLS>5%;DY<USS%$S$CY
MM/,'-</B,P4#A0Y=[;(],$Q-69@(*G7,D=;S7&AVP`YD-+]3SW#[9PX?2$#R
M5FP_#O0`.&'L#<!WAX%N[%'UJA,UM7S\`5F69<C2.?`W>^SS``Z!04\>UVAR
M.^EOV[::,.D#XM`4XN!T;<`_GK#F[$&NFW;ZS\]2+2X]GQ4V69"B`5,(!=S/
M):!CLKXHNY*)!P>8!=1(V/54*"(&GAVX3GXB!G)P"EM%=*,B,<EL4.T-0>M-
MUX4SF(N("A!BQ"6=[9WR"!.Q&@0K82N(1B9A,))0&]BS+,_%,+*IHH>[KOT9
MCQ*JJ'B#L1]*4==U/`_=RI;UQ1!I8]I<KBU>[&QFM("NE7$@J?_569;*IL[@
MFB0GCRJ.VF1VXEW#^W[]A\#N94WNY>&MY?9YN_'L/N*^21.?[+$RAP`)8+T!
M+F^-*/.QI.))F:LP\.Y=Z_I.WAO)V48^NZN1ZD=HBO%N/VFS7BBIY@5;/9$1
M\Z"7N0]]0H)(\+!`MC:LV@$],L$,`)V/?U::,NIO;=I6<ZG9+#)N94FX&8(]
M+XL%D6MR';V!RA>BQ!5ND_6MIID*N'HVC*KI;]0B2UP+/(U-;0TS,Z#H^5L)
M-L7Q=Z*ZKX38-U\GKW63GS]_]J:GZ1ZH>[=D6!3;X(])0)SC'$[,"TV]=XCS
M9S7O:FRUL@$<33Z1)>NS\:I&#3X8E5%?/U-F9+;[XO)#O'5Q=_HKB^!H5FMF
M..ES<]%UU8HXGBW'>>VY!\6]>=EE#L[VZCOG*B8-I2*[;?(>:)=>/H,LH7?8
M@MN,4)Y]F6=HXXBV]WO+DKU?__<!\070Q6V<R3_ZV<DN9]Q:INY/<NZ3IIV]
M\DTEIGM!FZ.=W:MG<7V[D$^;QY1?]`6Z,W99CPT<DQ@DQS@#?5FM(24MP73,
M$"4Y`W!Q\<T>68:C4=94-G6`HC)ER.2(%.6AZ\EDHA,9@<E$EDVI>=$]VSOE
M->0N];/KKC(&7%Z^:7*AF6:UER6:D6U6ALW>?3W,%);EH8[@"ZUCR754(VY`
MUX!E,BF#1'TBE^<L`J>K65P=*>`K>>'`$4W#%Z=KW#E\-6UFRF6E3MK,9Q1,
MQ&A+&Z<O3/P;,%EW<',>L5FS?0^J+A<)80)@"@:A]T8J591D[QGF,U9B+30M
MJ@@%JN%+0I!XDSCA8&2'%*-:-TR,(A(R9=LVM:U`20OS)L%$5^HV[G$6Z$\A
M/I,T33>KT1;V3?>]R+(\(B,<&C8IGZ]7UX>>"=P[:66[-UX0<6_`^W[][V%V
M>8?=/3>BG-DI_#8PAG1?^"S%+)A?.XSK4+:!Q*!^`*M[NI^>:3Y0L^AT6J^]
MXQW-B\P6TMYNLY[U,FK3`.$K&G&N>2<\=@W`*H4ELG2S.8",`X#<:GKL!R1P
MK9UKSH-X$]JAB\K:M;-G_:"T=<`%D()RIQS9K,W7:Y6M;O89Z::0.S41F!RD
MGJGBO,Z.WO!!AMM2K91ED4EP$(7UH0,$Y0C1@.;^I1'\F5*$!KI/:B.#88[.
MKH,F()XULX5Q59'<92VU&VNXH(L">3X?9R&`B6.8N.:94H76R$6:WX5$@)N]
MEZ]9;WN8N0O?L$>FO]^"H-$#NLO/!=M;5^L_JF"4KCA[^U=ORH247NH09+)"
MF0'NN5$B*I*!%`+'=HR<,C]YU7JX0&ICC^3Z?+F)V4^0$T4\21$1\^F8JZ^X
MB.?(X#T>CSQP<?-S7==1JL43`YQP_XI@0.*DI^[_7=+P?OVOH7WOR5;A)&4S
M5A#^\.5!("C''U__-_L=*%W(3++R!%?8^LVO%$CDX+'E,B&^Y!2GJ,;4FKF;
M0V"EAA(%3SHL>/'?AM6>":*KJZEDVA25;M5>YHU*>Q5Y72^0>$[YE&ZN@A1`
M94BAN@.H.L2LFP'[?Y<B9?G:UOUZC<.$5[;(.HT[*YS3/P.G3\)HP=P;LQ)F
M28^1J4V^;DU1=8J1Z0J-9I-9,1/CSWZO,VJ`L:86U<QF]*GTJG<:KT'U8U*,
MK44_=,#:`/OC\3@-\_/&5>ZJ)DJA`89V<RR<J#KG$X>Q.U_+P!8G61;]8?4`
MNW2H>^@Y.U4)5;MK1J`]6W^-?J!_A1YA(C"ASJ.EE'LJ.*:V?3O9V]7><'(.
MC0`1?^@\3"9G<F;N[.YR>EWDK@>]KEO?/*:&.,R`NM.Y.^D3>`/>]^M_![M[
M\V>FG`@BV+TO:2;7AR'\P:6BV&DCA)*M809F?YUY3I.I:1,&)SM-5K<WWL38
M:9Y<+Y+O&YYA4HYASW;*58%*WL^7&3RXOWV'^$TC%*WU2=XP>S;[?B((U65#
MX=A`JO)$&JET>Q^T>J1?.+B:JD,[C>'7$_)G2E9[COB"5R?.+V+]!?0<U+7)
MG?E3S!U4<2F=%YY7DF8XX-@9,)&H'J!+1)@4VW\I/*9FJ6E*=@-+R-`U%>[`
MU^0PZ98T#9KB@R?)NQ]3PV[[_;(4T[QHF3HKP@I-W:MZ:(/:?9.3^;X+!DPC
MHWK_Q@B']Y:]L:KZ!DBEY6'<-7Q9!/KGS+1@FD,8DI**$01%7>"\"1GN9V0/
M5$LQSQZSS4>QEW6KDB45IP![<D9HIGMZ?/8UFBO5Q*!P<EW'&SP?#[]:S;6C
M@_HJ60D#3@@HB4>MN?;L=]^`]_WZOT7@SJE,W@7#O/6FOP-T;T6UYS#);)0S
M>U[>&)\93L/)>_'"@F,8&]2OA1SF`F`<B?SSU&`@TS/UOW"EQ.'[_W6Z50ZY
MFRN#CBM*F8J-Z>^5^'+,QCV7?(W,?`"KDVYG,LXJJO?X6C!JV3___@.$J6"'
M%M1FC#W%EC08!S/.9I^XAD<:F]V2Z#)S,M9&%JG6\]D,"VKFDGF#3:1C2<EL
M]:FGS=E_7R2#<79SC#*#JF8$@8V\[F7OA_^AV"$ZN).LF<T_,TP!!2=K94BJ
M)0$RM<.A)S`UZ\N9\VZ(8K1*A,TJS/?SK&H\E;>"15>(D\0X#+;/?JK4?O;\
MF=1BK=OF:EHQW2692E)&H$AW]L;=067V=-G-)`-F:Y['`]J-@(K,RKQ'+%2E
MUDU-=R?]IFW599)F4+)M9R6`;\#[?OW;V5U>843YFMZNS,Z16^_TZ[`VLJNX
M?@NM69D=WSP'NUEJ/"MG[8S!Q+[+?T:M/$\+^=IA`](8G8X2*L"WC9!^@[\R
M`,D]E[0;F653OO*8,?^:LO.DTD&MY,V9?2ZT'QE:;<&;3VT-`+P/_?UPDS99
M0:]'2M>T!L>FP/;/81R@NN,[&PLD[E-^"'``,+IG'5C^9+%07Y3D36>&L4?.
M<PV),*19""])E7\M,JUV/5M)*DDR%Y[=I_``]3HK0%FW33Y?G^H9WMQ)CTG0
MW?<T0#?EYDP890GWWY^]UBAFU$G7\P!J\X_.DLX$QY50><6(0`:3"B1#G'GS
MO@<RD9$3YS"6A>C&A=#9N`<@O%_SQ\>'/`[]ZZB>,MH^2?LLMG632J5;<D/N
M,2J4[-^L3NV`B.>*64=Z/4EFY,!4:[LQVP_5J'9F:+0>Y5;=5MM9"S,1*>0\
M:K#)"7=M;\#[?OT6T/UEL.L9FHL?FU8I!1;N=[G=,U>FG1FM5\5LNK[*@9JL
M,RI+^8R]DRGC8Z-Y&#`27+)F5.R$3;U[=.)*.3VX-?DHW[(Z7K3?ZZ=BQI<!
MM\3/3UG>!/M;-@@A!3]G6OV,90J\NK:L*P/(FNK:9VDWN?O8'J9.D0JC]=IE
M6&%9:C;-/:M1IRW!MF"V,IB,\2B]W-][>3P$!YC'V>G&DP,_,?SP@?EHS,KB
MG40GN3N=(0&[.-WMPN<@V0Z<HQV][)GVJ'8K@:2\/E_R^?J4:Z_&J`A05#UX
M:,`T@:_5NZ73108L4]G6RY@154:-OU)^IMO3DO7ISYAZ!)]4*A*GV[&V%':R
M9S8P@BVQ(D-0F,G\98'S`,_LP3)O$RW[OU_KWF0*`\B=O)X>(_KKI,VZ)7/.
M2QP:J^P)&Z/KS\4QP>U[C\?C5M:MUMH;:75I5WH"^:,P,8U)L8':8]XJ#>_7
MOP\0_Z'W@8G+SUG5>XUOU^`Z8Y19+<NG\5[K,M<\0NGI(TK(_")G&W$+NS,P
M;H8QH67A)%$2X)2-NL/,[S>^1^43(*QY0DTI:HDFSNGSUB0HGE%P!T=O3,*9
MRL#73*1M]0:4$11<`XC:5_U8P#V/228[TX"E42$8C.4.7,NM>S'OBYW)X^LU
MR@<,"G4R3DV1A#,&'E:/ER/H:(H42(JJ`VFH7J64T7Q%F1G/31^E5^3F'5UK
MF[3(K7L]H^AK]&E97("A?\I,=P=B<YU>E6">N>DYZ=AU7>7Y?$H!+G1L8@9F
M69;>&-4-)F"98)O>9HC*J!\LSA4_S-Q!D^<=814S+30?_+ERJ33`R::0IS]A
MF<DX/0="I+G71#X-L!KEBNW\JA'3NJ[R^OSLV0AO&@%(F%!:%NQLBXC*&3!V
MT5J1:+8_:V46/\:/99&R+)<:HTTFL5:J0,E*;4+I1^^2A]/5G!(X>@\&WH#W
M_?H-=O=7%O)703&S%O^OX9<;<'HLMFF%7M)\%6ILE>\X9&R`U6N[3NUF\]'9
MU__0\8UX.9KI]ON!-V;5&K$<0.5+H8`2+5?I.*-*8=BMW%*,.UWC'@6.U'8Y
MI+?0F93**JV/*@3R:7WE#,SGUA&^!K.-ZW[@#&>Z4J``$WKW.`Z@T/Q\.I,H
M[``X&E@@5.FP/QNJPWP?\U)P.UC3.*J4(H_G4^JV9RA8JU2IHIVQS(D"56,K
MB`A=.P\B8TH]0$.<NV64.SP_/@P8YIF.G'O,3;E"MLU(806##HACW6&0)]V]
MW5FC=#:R=&C`&.1XFU;7`4A::2ES8*OWUT&8F3Z4W,REWR+2_(/NHM=RS$&E
MPNB;P6OHC0L*.EB<)U*@P=88(ZWLC#"6XSX]@`T&!;!:QW=8D62:N_(;7>-,
M$Q!``_!#CFP&_'@"=C\_59F**\Z]DEJ4Q!'O"ASJ=QAUUHPUXDDPIP.V4HJ4
MPUCC;)@[[Z]K[Q68USK=`#WOH:6HAT3@[!Y5V=`;\+Y?OP5ZOPQD^2OL;P)#
M$:6A3D/[,UK8?(*NN:/Y;S(+=7/FJFN`DD%O4VN$BIRP3&W!ZUHI=][X]I&8
MAB\)"-5IL1O/PUP8\D#D.+#M9UE&JM<8=P9A'`@=:V&,93W*1T[G&7DT(EUM
MKYH2@\2J:@8:3K/,53W_'=^.]]P/;<NL#("YR;JN/>VF^[H-LQ32JQIPBOD=
M'Z3DC73J1,!H<"K+(@4BV[I*7;6/65)\@3'1]G'&9-W#6H!24@1L,*MCBK9M
M$QP=W0EM.]]<CKE42I%UVSJ(JD:Z2Z*C%1#5HA%!+(!;^UVV.=&M%DB(.<->
M!$&>HD6V[V)JYL(4#@V0IK'W[OY5#HU;;Y:BRR!H]9!YXL_%S/!=G,F+3%A<
M&]T8(`>;'8+6IA7[M:$&`A<(V;]S75MGL-&:!&4$ZH!G37<=6*@Z\;9FZ[:)
M/*[AU@YV?SHR99:N5WL81*P6+]2>8UG2`0B9GV.!^;4:T^`87SGA&7!QII"4
M336'^E(CWK'QG&S[7FNX7?\;\+Y??PSH_FXYP?G&%_=4;][0-S+PIM20YF-P
M#K`SWYYP.-A#DB*GM5MTNVQH_,'@.+*#>1!%-(P(56J\D*K)B;;AHJ'XJVXO
MW'%?LUW1^UO74(](HP8P9]1;N436)>WK9VO=/P<%N3X;)+5C@TFC*GFPT9%U
MO#^/>QG`7A2;'50%>HUAE>6Q['5J34L3ZOOJ0"^`:M*PSU:4$]>Z;4IW]5PJ
MKIM=F)(91K!W48L]4K29$P@GT\3KDR4A)L?XKJ^7+&5192QR3YO[>(]E602O
M5:V%QE!92UV/T4PZG'$GT&R=4>+`C&WV-L..;S),):ZZ-B>4H_3RB<P<QKL1
MZ@LS>2!%E16!;$?0686!5!C@D`KL8*+&H5/N]GEBTBRHZZ=)A/F\2^1%/TNF
M'HU>#21G_WPP,[(<[E.\TR,]29^PS!BZQ@#&'G6REZ[K*J_7*P\X%/4^=1I4
M#)!6?/`B'K$WI(?W_7-+0;#WG8VOUQ7W9AZSL$C7;Y^7P;"7VD39S_AL->CW
M?[^;UMZO/PN&Y<]4&R!%=G+9M\:;[QR_,F_JBKT);:$7R2FMX\NUIM^#26/2
M=!13RT`EC37Q/G1G:U7O<Y0!U"%KPTR$_0OAQR7D/4ZY6G>9F>JB=9*[*]J)
MA(S2BU>_4U6#B!^S4<,86:6XXVM#C]@3Y;5O+=@=0'Z_CUKK[G&?Z,>1E&W=
M1`1=GJ>SN#V-M\^$95EV=8(IXS6>V_I:.WB>*EOXAD;:+"3KH>V9J"!D_X&)
MSJBM!-=E+LX\0Z*TFJYUA"386+\%XE;@G]TX7*D"$XWG.8W=K)6S30;#K6\&
MSV3FV7N(53)13*'6.M6(0,O.^?OQ"A6&71-7YREYK6-H>0."WJ_)6-/_#LTW
M9VESW=`89,H8L)EA>W5PX@?5?CU7U-4!J"D=DV@8E`6)6;ABYN',7_UBKYP:
M^!ROK5;Y_/RT*7X/,=V@^6P0LQ0-G$6RR#1(\4%B/H-@FHY]4S')6%8RB^&F
MTICQIQ/G\_0>>)J%?*LTO%]_F-V]P\;PFCB<G/IRJ=E[OQ;52OSS)B/LB4(H
MB2@#U$[872UU%4&UU3(-JL(^7:0Z6[U14[O6K6KIH*^9,)A/.W%(:PS-`(GL
M;%"L?;9P)3LOO'.:E0QRH)?<6<)U==)83$*-O/R#;GS8%#EJ-1)NND-:=W!K
MMZ=V.-5:CW(&"?J<702_E+VA+.C<PK#2&GBMKS6(T<,5M]@B!2M_45F/PX:G
M2JVZ*[P#7]K.>J.R0@O.3`"@&>O)?E*9I&X<J&#6A"E-KLT"22L5K4I&IM%>
M-+D84E&Z/,*M>4:[<?)"?L8?WAIP<[XTD8RCEV3K9=BT?\0#XD2E`AD@TN4A
M@M[0"(Z0*<8ES.=CFN[FE`F$:F(5>JA+->_]4T.O6^[2>3K,A?T=Z#'4+"JC
MO7)VV.#&.71VPJR?GR>DCV?)<_(?@:]QI1OJ[6)FTI,\68&#W5EL"?QP&V2M
M1H<>,X)**:JDACK>T(G.-4X2.^.PBNU]O0'O^_5'P.XE%S@!NTJA*544^"J;
MS%L=[%[,!%^&SPT(0/(T7?7LKF?,<(X[F;"3*>@4RV9-'MS0=YQ]Z-DI>V?'
M/AK-PGVE7>:>5=//4VMGJ@T1B38IK41/K50,B:]O8^*K/!B3ZG1,!Q/M#H'>
MR(Q+QINRUZ9NZSI2G.T^L`LUH31]4:,Q<'Q.9./)O>;M\S78(*J@C49K,ZE3
MABX7:<_(.EU9[(9<[LO]S;0B=3Y]6O&`UL8U%JHJXQ]J7IFLQJ-T1]>F>Y!-
M,REIW.NR#`^]V:"S]C66SXFM,G6`K(PKF+"Z3.%VLB%.IEU1<FZ<\@6P@O\Z
MD\'1C+K_/?Z]#T!1S6/C/IBR[I-"%$32(H`3)-(6B';KNGG/@Z\I8'(Y"ZVM
M;:41M=H"K2R;#M8G&US6E+R4)>QA'>RNZV$PP1C,2Y*LXC37%TQMLGT6JH1D
M1CI%ZWF8LCF_,>D>A>TX^RX5H1V)$#`&)T&BZFV8Y2LYV7S>@/?]^BVP>X]5
MG8$>?>AZP>_SI/N<.+F^&DPXB2N*.1"DPCGH]^PNXH:M:X$-&(/BZY!)<%I;
M8]YX=N'Z6F=[B#SN!1D>WI3CO4HI'<3`1S.`N69.?"F-5F32Q!=2VH`CHD=>
ME+"`SPK9%SM&1Z-<V[RUX+M`COI2=5_*$C<7E!^(J90B!"P($NDR8T;B#8-A
M\>^C&>579[3O0<T&6&JM0R=5,?/V8!/'<KE#W'>0\WH-A&M5;&CJ/L=Y8)OM
M!:DAA[/SU5]&IAVF&Z6\,+^SZ;*US=EH(]1:>D6XV15,@]$)FH4R9DA!;3H*
M"K@J(.IK6XTI@]G[,`$7L(`_O3\&A8L6T'D[<GIW=ZT)G1EZ)+)AXIXWG>H'
MTZO5*`O!9IV7^^THK7A^/*=GS;JN`0":/80TS/[,L`<Z*'<HW]AKF]*Y&>F2
MU6_8NO1<__;8RWAF$J&EI>\UA7H^AGK2GN8++*7]!KSOUV^!W=GR\#O#=<UH
M7E5YQ>C*EQC>M)KP!$;;)1VCY[BQI)WSY,51C9"2SK%X9";O5B6T@T2_:?FJ
M1>UDK#7354J1Y;$<G=]#M:&4]J?T.CM?EJ'K%4<#$1S8BE[I'H@,)B6ZQX7]
MVW(XL=$!,-)NPW3"I\R_,H*V[GEGII-&$#EO<JE'R861ME"39[J**`%XIVO>
ML;I:3%\#\+,!,/N"=CIS@=B4S?*QF'-WA<K!!_4"NK&`KO6,^T(8#PY6O,V)
MW.=&FS!,E$]\:76HI:=4DW=B.+[C>P^&LQ3O6@;AV0X*!S+U)X;>@PPZ^WM6
MX)^2YO^#EK-9]]&XQ$M!VN=#=VI8)9MJ@EO['$U^#S#2B6>G@IY?"(0P#9F@
M[_/CX^,(QF;&)+Z6';&DZV1=A:>C!H)9_*>;<I&[>F9[%9D!8/M<:#(&5T3)
MD(L[/=LQUX?WP-V'5'ZVO%4:WJ\_`XK_P.][+=D_\L:3V"]GPV`81AC`'A<P
MDLVJK<^L8L!$WL8FF"<`)0.VO\*I[QVM8`2&O_)\M?8O+B^8KO-:2;TY9P*>
ML@H2Y5/=X=#M1XV@*"X%T,7//X@I5]$R=5;LX9#K@AA+5:,3BFA[J8%D;T*C
M;AAQ@"=SGJ+(ME4I2WNNF(1'@R$*,F_8RS?2<=0_ZVQ3/1-UOJXMBVNU/8^5
M7ZQUK%Y'V;IJ?[]>G\?X891X<-*!3F4.T0-'B%_T3&1@C/:G9,#`SU<8,`%:
MX-0#&E4%"S??34`YZ09HLG%[ML:B(5QM%8?K@W$]\P#/E6RPAY)P_C<P@3`(
M$T2VKU&B&H(QL];VWK#["[S4KZI31^:(<%Q;;;)4M&=-+VL)`\5Y(ZL5%DR#
MM2:#51Y%/CX^NETV4K@H$SG"V2-#EZD,;+R<)@'"_LQTGT#J0*C'T'_F;)[-
MSI<V7KW\;&*7##.>8HNI&=0EPY:?/<DWX'V__N-@-V5G^>^Y3IQJ`&4FQN?"
MP;L<5AD"XPXX&1"1"=OW]'U6T\H4)!X.!]'-RFU<YLAO[D0:LUP`WC/%I-GQ
ML&V;;-OF``'DJ%B-OT%)4IL#6$)W*)NW'.P6#``;^L>0DWM$W)@I-*E:(,/P
MB<01Q.I[PM6,UBI2$-O'%."U8%<"D^2GXF@PJA,+LW$X(:RK\[EF!/V!K_F\
M.""C]8:-])-8XIV2D_!G__UZO53M8U4I;8@<,E;[84GW_DIA@@/(Z,ZN,Y`]
M9:!<68BNU:\NR##,FB1:IR[PZ+!=@SXS2VPS9L1P$'W#I,J!H.SOF\A5^>IR
M<<_49DG:[Q0%F+V!!M+`4!13VO,_RO&+Q^;5@#.,"<[>0:=EM8"1Q8/NVC=`
MVC+]3;\9*7BBFP^)*8-Z+<LBWSZ^#9D].;'$*46P;5(5$#TC$Z@DSR0$47>X
M#YAR`%T_GNV18Q_1JMU9\"I=8O',($=$C+K-S'`S*Y'"&;)/B2&KQ_TN:7B_
MSL\O7A4B7!]^UV4(ZA28J%;S2]><(1LHB^+S)C6M,7D:;4ML8$$I2J[,0PH:
MT&22FM20*_<Q]Z02OV"SZ!&<KE_]M>>K6$VR;V"]?HNT]7_FSXPV5MV^;J/3
M[*0&P+:K5^D^WJQ)SN:).)U1+1O79=&\#JA6-%`YV5%S*R+"R*(JR;7P/%4]
ML06FKL9OPOX!)VO-U#N+*7-0B-Q^9K].!L`S@B@'ZOP8JS*!("U6RI<6N)9P
M"M)BAHUVI4AN/&F%HM.])(,MS%KF@PL5$RO7N_LJ5*VQ59.!T[S=&_8NR`1=
M$87<#(VN'RM+K%,0+<*I]LTVIAB3@$KY(&-$Z2U\TV?AM7?%NAB2P?+:*-_0
MJ3Z$>:#JKWN)5F;!J]PF)50C"[`SN[U<8N8;<3R\Y_,9E3>2IJ\S1;0SL)LZ
M'XJX&O-8ZI)^$*/^/2!&*P-7V4/*[B17\[5AR`*W]G@3"=`Y&?;G^89T[]=]
M,/!%L*L6G.Y?\HL*[F<@7Y1K..&*(\#%Z3UEFT1:SN`VD'(T)I52DD5Y1Z2&
M>9BK?^-&WLO7?G4FP&V@$)SZ>O!JE%S*J++:+OMT@V=G?2"JP>UTG&*Y`F=R
M;P?@SBV3YI.VU1BWPRS4Z.H@)>EX;L\>3.J*E9:P/RR:.YCP>A+J+FB]/G`B
M;6(/8SUV46_8ZE?ZN:]J*Y$$7[K[O"WFK':_L8B(3":]IMZ-2&PIBZD/3JQA
M3)`;0:>$X(K'-=)KSKKF1P]HO2YT7(L,`2E\@#U9WK9HBJKLXCC$48X:4:08
MW[\3NPI#OUFESN`4-/H@E/U/J#G13"!<_!YMB7T5K`;&QI[79P9<*V#<DZ-&
M[7!8LTU]5A=#W#R4!(S[&15_#RZ8"$$GY[O<4HI\^_AF=*OE9F;!F$Y,U!WN
MB.\8E1%OEJ<S!\CE,W5D&.WL;;C8&H,SDPRS*6&H9<`$S-<81%^GWK_?@/?]
M^B5V]TZ]J98^\HHN,E/%XLT:I$D0FNE]<M)/>KD-X/RS^F<>'?:`MU[-$24.
M@*2W&P\,XL]&U8<(/N?/KBL3:'>G)*4<Z[JN)\!XOMYU:T`NTP0FD,?ST6O;
MYL-.=Z"Z<=0J$\>%-,,+7Y;;>+@``"``241!5,<WFW,R84@N5=N<A?#C\=A!
M%Z)L$\T!?MS_X[$S'+6&N3ESB+*=T9G+D3U@8`2?G/:Q.@P"`Q0L1V,P-L0W
M;%W=V2(SIBA)T+AII8JK:!0BRV.1I91NWPU(PLR/"9`WKB6!#"T`R+).T]W$
M=%9%A633(&1J9ZT4FM[1@!RBM.?_>#Y%%S:.O13CC^A_V];=VAT1K2YS)<^#
M,%($Q36:1O,,4QN@)QQBYZVIXP:4#;1KWF,,'B#>I8\CFT"9&B+0T9=4<\)Z
M[]'H6\-DI=1>2JWS.Y1IHI''`-2E%..@&$'FQ8:DQLW7X^N?M2W;/"U7&\N#
M)K[)YB$-XUO,_N^/JA&@)<]-N]"X7H>NU7N#2C)LO?K.&_"^7S?`+F]RODG*
MXP872Z/@:-4<>?M]DOW@E^"ZW01Y\[-UPXRQJ4V8W%:ON2S+Z6#AD,[B3,LV
MDT/*=%*5M:6<9/KYE1'RUJ$:R#AA9<-H'?<-@:S;ZL"!2"F+/)Y/6TGMI)=:
M$/!\/+O2A`:5N/&H;5#&WOCDI8X,((;]=SNDN@R;22LS,B_'+7U\^Q"4(NNV
MCJYLD?3`"E)03K*@+(MC<S/9H'/IGXRU]JP+)BK[3+JC=.=U"!2=JU>6DKVC
M"M,^X^/C0Q[+$B=UZL[&V,U/3M4).QM^8T.#ZUCW35(&O"30HJT9JX^J['O;
M7J`S)0WP/I[JF4N0W)]U\YOK2@!M#`)CX.XM9.F94<TXZI_-FB'E#-@A=#&2
MB2(%Q2B[=$8X50V@5%;G`!CG/YF5%<$H25!K*?*0&L,(VLESIF;;MF%28Q8E
M39-JWT_\/$V>S2Q(\?/OKDLIK\Z#GKG2I1Q(&VX;X*78^9')[_&$!&!B;<[T
M]_:OO9O6WJ__#*#^0PUJGL1+^D=GL>NM`PQIZUC^ZJ#R8IN@[%:22]DM9>N1
M[M;U@L9HX&3#)%JC5&,=(+9K>6P$P\^]!,W.7W^&NBD`@\6$]`YRRE[R`179
MOUZO`3X4BU!KW<'LQX=R3AL'9P.[C\=#:JV&%6S.94")$\)UV'MBLCL3*39Y
M618II<BV;;MVK3Y$#^#=V,6"QMKNUZ2[G7S-,8#]_LE+]S'X0TS=;"NAR8$7
M4VJ;SM%K@,=8^VW2CJ&853E2^7N]"UI[5WBLR=5CD0KVJZ]]?'S(HJQ9=1*Z
MNBP!="``L1F/9)$'MLS]$!(]TAV81F;6IKHQ>2[H#5IQUS#65B)">3X_)-<A
MO?^J:KYRU@A%J^0!)R_7U>'4NFL@$&4PNTQ`V(Q!=M[0.:`C;6I?=$,<8A"<
M!G?J?@<];#^67M^5IN=@?(>=8!!%5II^%C??7NLJGY\_$]UI)AD:F\.A8]7[
M,YQ*!9T7CO%LSJGL0&^>;N-(M.U^](<HPQ_O:MEZ/:X(MK8_(.GKZ#^-&+CE
M?IMO6;+WZY39_4*T1Y$3J_(`D[Q8P=<YV.L%"[/;_/Y87+V+/;!/7.F.]]VV
MS8`670LXY$5Y73Z"I$8A['/,SY3?F">D/9.:=`W00._^S<?R[`=4K7NM+TVC
MGD[Q[7:\R[+T%!^CA[&LZZI8ZV%-^5@>%NRJO[,:24LHV#I>"@4%\BQ/X^#5
M;8.W3?AZ[=?ZW.^Q+,MN12SS.N,,R)]E*HR$G"H:7!J[G(!("2P.$\W*C#5-
MQBY=!-&UC\F8G\MBV>G*RB`-`O7&D+RV?.\,+_)\/N7GSY]A2U*J<4:B3<\M
MZY3&^1[`UM08I<-L;:/7^X9C816@=@\>7=*,SKK52^85>3P6`7YOS]=U[[JI
M#,YFE\G/!,OG-'B@Z2>@ST9E`%NL)JW/`$`!:)!&):<#'R\9Z::W#X+@I.0J
M*07E8(%M*<SH7>-DSZ61\#)"*NI'MVWK8)?"/`/CUG3T!SW@H+)&EAGH]<_W
M,HT7,QB2N-9I&<?!WB;;!T5^?G[N3<ZZD9`YZ604AZ9*%+;PQ,?EFNAX`][W
MZY=9U7BRW&%T$KW=1&KU2]?@PSG8SYLK('X10,NYNT[&`,VNN7?U;U2UD+IN
M[GQ`/'A#FGIU*4<%M#.[WE]]&>DF[!M]46R&+O>H.B5G#C]1W>%5UEH/MA:J
M^60$!+M1@]K)CEK:X-@%&_G[LD%@5PWS[")E5Y[XK)]#7HJ**5=B^>O!`#=K
M6YD<7/J0TPH65P>./BC[(0#L)3')`6'M"72>CX?)`.-YZ)@L./8EZZ2&ELK3
M!X_]R.ERTV`4JNRFG#0RMFI<SW5U62HRFEW0R>"9!B/D-J[)0=VK6L)I:IWJ
MC([N0%]6P?58ERU([))<C3GU;G.Z*8A098X42OWEZL1>SG,HAF19,Q?G2"*I
M/;9?UW_@66(FC*.!C)RT&3>`Z_R>D=#H<*`Z"RCU'*^J'G>F#&%#/(1Y8?9<
M!8Q]A9D%Q)3/SU=RSB"JP`A=YA%?.,WBAHU)D''GO!U`GB';N"Q+JM/;]II:
M:]]KH:4`74CK3)U'K6^8'`CS]*RD[0UXWZ\OL;N_4^<#=UR=^0I<L9IW+'5_
M<S#4M2C=3CE7\9UJZISQW?3&`E=!0P:F,8E$[K/VOP)TP_4J=J3M/%J](>];
MMPRL<7RZF&OM4'L\'@,H)?DL3@\HD5JW4*<GOC8/$KZG;[Z*"`US?<6.:]<K
M3%E4*_^T:_SBD#(2U[&>6*"8H\`S\IG3;Z5-P7J"DHRE$F9X3J0(,P9/#G:.
MI!3!P:8MYX?XQ(:X*NW=*]*JITE)SY.);QZSKGJ47.K?1MQ#DWG4\Q)9D=7Q
M_*K;@XFH[(`AUUU*D5HIVUJE/)>Y3?/-K-2LG"0\.P?,M;7V['E75Z(SL\;U
M<+*4,AJ"C[D"M_$$9S*O4M,;&F$S;(#)#G5Y<Q.`9ZPJIH>43L*4,NJO[5H;
M^\.V5:EUBUDGX73=:",/GYE!EL8Z*6VX8TD/M1D8=IR)))_(:+Q#S%)E!Z65
MI)];0L6#`B9[($J!(Z.YVA?>36OOUZ\SNPDS=.L]+KJCKIR;3"W4F0)8TO%\
MAXJFCH*ATF^G;EVYLSR_,*C7NK^.:8L>BTK3==[R5PYU@Z\T!6;WR\2\(-1F
M.X8*&7LIN>4D)_:4_FM+*5)0TFWRSJ;>2A#TI2'M@%#-@AQ-3S3LM23-4I*D
M;R?Q"3V#&+5SE[(<DFZ2>ME'?@SILXL':SLT?4VJ5AAPK&;+%/2.>J<V@O@L
M,QOA]J[==0[S/QX=[?K7D'5=1\-2?UXT\TFSIZFTE>I(-P<V1U-9K*;41C.Q
M1,$V'3D)L$JA,YQJSP:(@,N[M:WKZJRWOV@7KFKCKX+C62H\^YW9^X6FMLF6
MR)Y)45_K&2`&S=K3L\3O=="*,9.]IW*4;CA%B/D>T],5LBR/TXB+)O-U4!83
MR[*L;.E/GN5^C<3/C6PR$K9CVE.@!KD4J/(?.2UIM%LOQ19S.'>8``"8NK:^
M`>_[]6]E`:<+E2>,G5P2-.+.FPM)I,3:Z2:%B;OE#_"J#.>`SK"/`3SZWGP:
MT77.F$'/Z9VDS/&U!W?WB;C#V?;%TR4%LY(*3FK..!D=W9%MQ-.9$X*Y&0,S
M:<ZX`9,3L.KD^3F)$$1I!7O!2RVJGP2$.JVWLRBX\:"L^%`_T""IU-O0GD58
MKZ27-6-G@GE2)\B3AKPX/)1MJU;7T_P0YLNZ/?J2K-G452Y*A67SN8$0'>0T
MP5ZMR!*4+5I`X)C:-#Q!?BUGXZH96DZL67D#Z&Q;=4`'69S7`W[]LYB4%=PI
M$<FLK*^`GC8SH23)M)EA`I.Q8U0!8L(0ZTTCE5!TM?6-`0[E1DDO7N:,^"M!
MBSAW;//,5*WS6</@:4`J$E1C?&F)"$8#I3J/LZ"Z-73F4\1:&U=FCY2JEA@3
M-B:'O6_`^W[=2H/Q9+'=80I#S:X^=&]SKR<7E>4O,&>Y[D`XG*&D7T6)B0XQ
MY@AK)).@:CEID966G;W+LA]NG&<XZ?H-$7\YJ@0DDT7.4Z"IQ$Y2UPB!+$N1
M4A;+P-`"3YZRZ#E`HLPT2"WH2TXQ26.RHYDC&W(:!C]AS(^/K*RR/![IN,]#
MQV$L,+SKQ4B-:=6"%/`P\=M";&"9,G^,=9;!5K0?VK5+Q(6I!DYC+92]S./Y
M?.ZE#3*QKQ5)7>_T84R)]KVZ-C.SDVO@UA@JT`+U&=-])BNE_V92CT/E8I8M
MV>!F%_:!.@V.Z1;-5(+,!Z6X9U242='QPBXWS_PPE\,\"1YX0G+DGN*(P3>M
M:4(C)KR>+E-^0M=^>R45YT:9:H@G0<6D3CBZHTT($R]?E@8WB2T]]E*&92FV
M,0\Q:!_]"YG&N&:Z;QR]]*85G#Y#OHTGWJ^[#.\=DXE?I'Q39O(F3IRJCL'I
M6'[E<OQ&;F^24U.,B*TQ9UIPNI<-G`+/F"+9U*[Q3V"P6F/5K)/^Q!XV`XRV
MVUF)B9-9D_I-<MV#!-\)=<B=E<4T*3+PK6>\%SM8BB`M`:3*R""KN8Z@99=/
M>WY\R+=OWP]-91K%!Q_HL5NDVH.TS:EE*=9<X")DT\U.I#5?H)X.R@"E,@%&
M/KX$3D&)O1P'-BI%:Z?"=!1"MFU-Y_E9@$M*UT36Y2C:7<[<)YT1A*BFM%`#
MGHS`='X,8&@R,XSN;![43C,=0:D`IA'?%].?%;1X\%LK#9,]-5_73F6(T;69
M#PGH.LO>>5O>N^>291YI:H69!.+=?IBV\S\$(5GMJR_G,(<$>C9P-P+)U%-@
M@HK![#.4&&EU'D[V<LB%F#IS^H8SX#M!EG-#'JI?+;VG((CAJN>QK;O6L%5Z
M45FHVV>8>\;:%IVS3>)M+?Q^?9'QS!;6E>K0W6PX?^4]>/:^^!(QR\D*TQ']
MF6/MO4&S^P].[3]O#/I7[L_)2?%B`(*#:#3V47@7Q@W'EEV(\SKE*<B-#3%0
M2"0!.L*H,W0:$47ZH*"$@\QJM8IXRD7C#-U(8\LOQK_6]27KZCJR-;:^*&IK
MA^"ZK@>#:0U.+ML]6E.7.!V!5IJ@G+X,?KIA8>W!GJV335A&V!H\79Y2RB[M
MYLM]=+!WAH'TLV1&T`NMC;E22/%I\E9;.R(#F%3M8+\L\,)%XYR1JM+-4Z&M
M/W$=HW,&DYB)XF2U!;4"#(!;O:27F4T(#Q+*!T)T;:TWW(!CP;-93M\"F66D
M>!HT9.!,8,NJK#6WEU]+@"0RA9#S_7]9%BDHD>T.H-J6LG3U(M+8<R.LG?&`
MD8%+^"A.VY+[DD#DF[O?S\+8VU%Y'NHXTX0J1%ZO57Y^_ARVPD%75UR6$C/R
M>0I\D1!<1AE%WBH-;V;W-Y09[GAT3RU];S##T]_S9@*8X<I?%ZCDC3$R>PNR
M0P;:U/1V>.&[LX.JA19'OS64C)WM!MG(2;/?O-:J`)TABM^%T3^%8CK"3J8%
M[#$V?9\ZQ$SC!U<3)=\B02@P05M"(+.RBSA.C"1FGS/KNB:@UDX@ZQ*5O'<'
MI_O!46N5CX^/#K2`8FQ2_*%-#AF@HKOF&8_Q!@KONB_EX`[37M)QU-ELQ>/Q
M&`<GHFG*S"%N6%;3:A;#KD^SKKR)QJ3I29=\@)(V\AG@I-A8R1A2![)"K:5)
M_QP_1\A$Z?5@_!_6CO?DN65,?*VTD"#)Z$SENMQS(E7G//TSC(H8?1W"*A1X
M@PL]7D:IP9E@A-_S7Y/<G1(*TS=UAF&N,`>]O0^A-S@W]12]CN<KJ!X-FE#S
M4+.^.O-@@A&<)+`@5GG"["$P8VW61_L=+5F&P8JF[W4`_,?CX7258_JE;ILZ
MRV`T>.U40H;@E29O7,_(5&Z2LT?X-IYX@]T+J'!5PGG]#M=(=O8^TVNXJBO@
MUW,7YAI<\:<_U*V1`^:WW"5"=>=H!!AY*58BX:;#8;WA^V$`8A.<=IM*Z1]'
M?IYL'.-SBHAL%OP(]_LUI"P<QLL;)+(F&.8PV;$E#(R^.\8#4-(VR[N_.V2M
M*OUL!,MY.2<I,?U)5QO@TX&<`?&@96%!5=VJ;%L]E!IPB/`7,S\R*3UK:C)K
M+&(\#/5<=M-EEXZSDZ2Y306V6,1THFM#@+I5P1.'M%QDKN`3'%H519DS#,`4
M@RHM0P8%(&+#J%TW<!?@Y14[>*5OQJ0)9#HC&?&^.L!=NAVQF:Q]QBY/][@5
MVF.R=D9&@E8^RAEA:)8PU#I!:;,BR6`H%0+2CZ6$9]4#&20)K09N];^53G<6
M3&LP9B2U?+F)4N:9L8H\]HH01`#R?#R"2L'LO%W75=9MD]@/X&IN/2#4S7'0
M]<M(#"FL=&/F32&:P4=2#N.;"UT`M0?>28.VJQ-^/)_R^?.G!:RP9RK@#SI,
MD`5<]L&N0V<,9[(I;\#[!KNW-L>OD[3W+-2\)]'TQ^]V8^'7Q+B9LHXMVLYR
M<?;HUQ'J7$1&&Q:?W112EBF@8\2ZUL`4AIW;ZD->/HR3TI5FNQM8L5FFS;."
MS)^S<]`U,G$Z_<V#.2@HPW@@9!=RX*NEMEI-GSE\>9W%@)^?F&*F4=5!S5I,
M"'8FC8#*V&,'B/NX+Z4,]R^5KH4Z>'HJ_!ASGLX[BL<$FJ%C"-2<^42;+\R"
MIB,2U535<3U+=QO\A1Y1-][E`/_:&&-8E$K^.0TT)T8%':RVP`%'>E@_$W%C
M`74TJU**L#B3/@9Z9#\N3MW3+O(_U`"N#4S\_K^NFY7=0J*9BFAZ$#896O`5
MF%W-T"%1K8!WDD.H!<[JA>$16K+QSS1Z7?I`&938[(#_$4A4*&@!\_/Y5.8S
M\?.;I?CK]>KN=JDTH&9AU3H"\G`[N#`&-M0.$!.K4RL]Z.\;":,/>1SWFPZ_
M6\3+$9Q7>K.*>7!QUHV1A$)NWT3*2;UK>/^AKSNJ#&>UL[SD$W"[3O2RUO>7
M&N/P6S_MZ^RNWC:7FN$%I,77"H%GZ$NEL:!I$=-`=Q)68,*6GZL[V;JMV:`X
M=F"VKPV!>#&U@E0%U*1C]F1ONMGJ9H"<D2RS,,[.?0[-S4T)[UO[74ZG(WF2
M;3@-,.<%T_3CCRCGU]RQ6*MK@FO-6;6[?.FZS_8S-;$7'LH%LXYVBVBMCB_"
M__+]`BIMBWZ8X@B>\)L>N4P,#L:8C4!S-.N-,9&)0QXFP;>IG:9NE'4L73:7
M];LK5O04LJHW`W8]TZ=W%I2TSRH^R>,9OUXOH](@7<.8)@OD70K3[ZFU!K?R
MO#O8^"[">A91DG>3LZ*O6VT,,UF']!=NBH\M(Z][!;2..9.MNCM`-G;WXZ.K
ML!@72_40/C\_Y?/S<^CO^EV1]JR)S<A4@%9,`,%)'1;-.8,H7>,D\6S_FB5\
M/)!OY1MW7I^O3V-N,D@,-?]YAUJ`%^RT82+B.4>.A_<&O._7U_#E9;.:MD+$
M;U\+?N'B\<5[;4T;M5;C[I66$W`>$C"#"+-&C=\9&F`J_\"0(H.+H&WG_JF<
MZXE6<D^+3YY6T+Q,6'++9.FFK\G/:QU<K=5X:(EZ&=X@K>5VU?8YE=5HJ@ZV
M:V)\<4?D-,P$&(3LB?K0-W(1#=;#Z*+-61Z6G;76`]".`*&#7=-0QA0@!?%[
MH[5+\XST,^3I_\04#NJ&N?:A6]W^1!1O@.0`,QPF'9E)PME.AM@-@)F.*;43
M'5SC'K]**QC.S)>$Z'(&$^+U0+V9@>2R7J_7>M270VQ:G:G=LFG,HUZOJEPK
M:2J+@>/X#'T_>C/2Z\%HTV+@F=%HAC"^D*BDX)LI!;F*CL^,<4(TZ*^74HP4
M6=#O/0+4S\_/J:'.N#D.5A7=[Z27>OC./_M,Q)8\.!,&ADK<$>@UJ_9<!QHA
MB&J**%=;($GY\?.GK.OJ@I8C4^4S?71_)G2)UM*F!L&D4^NQ/3#ODH9_(J"]
MD"";UN;R"A#_@O[47=3+:X#>E_+-CVY76TDK%Z,6I$D!P]?OGK"]X+EE\N58
M7GS`3$8F:5P",DC.W)3KHEM)_TC=MBF\"_/,-8_DP-@]/RUGY`P8]-_M0!GR
M8I"<;X^LB94]RVN+.8T+:!N;TL_-!S07HO]:9D-+F^F^1-UU;J2.&)F^G!6,
MU8`=!+6S.6VN/%FV0`!P^BNSYL>K728+LT?CE+(=;24)0>23X5H(5:YP8?Y@
MC%>#'>TL&(PX?0#*?+.#`4.4Y\<WD4/FKM4NVOIX)JEH'.!FDY\_?XCM):`-
MAD4U4)F;31H<O=^+&M!^7^YWO;N;;UXZ,R;(LV<PG\VS9$H6;:J2J9C5@QUG
MW=A%#J8SL<UNO_OS\],%S380]!)]H6?DJ&UHH!<-#"<;7%8FH8?/UO</+3X;
MG-MU91L;BRR/1W*F,31SOEZ?>V#EQ2IZG3U2D1VFW*ZZS:!0,=%^ACY7\&9X
MWZ\O8,O;0-)V4_Z.ARUY#78AL8/T]KU.!$T[:S#Q`+]DQZDCZ_'O:V&;R?MA
M@I8N'Q,#>VB:0BX<QK+W;7]OW1J3CDE-&J(4PZ(W>LR>2<(=!N:]2^W@<)P:
M##\R`IO.+($>]$XD*9G4ZNJZ0\H%V,4)\,&4-;Q>&.I=B[5+14_/-DFH:C*:
M\5Z]?YT8B^I::501M"$&L[FMQU2\(`*CQ%-CJ\/O.0,&R=.2NCRVI]4O+'?1
M);:0+G$(=IQ!EX8/*P'!H,-O8##!EC<:4$U?.BOC&UR/KSR6AWP\/TPZ7M=Y
MZI0ZE)R9<&^6^OOOOR4W4&$")7G416,21'NQ%PKZ_8YT,T3+PEFAN@'VLZ"P
MS8>6>:M[R0ZCO-QHC+,::I@4`P.>,VQ5_TZ2,@%RVI4P7[LJ\5ZKU+H=ZZ_&
M.F`S_R"9D(U-+ZGY*TYI@G:*,97XH-VMR+A?0FS3H*J]?C95!LG[(MIK75=Y
MO583@-M,P)@;UA[T6',N&V5.]]LN2W9/>C.\;W;W"[]\IW;7@Q+DLC9RPVSB
MQJ7B!)#]%O"?=?Z>#LZ,?>`-CDH"FW8?%E_1@KP>0-YCT]NK-:MU";&)@Y2G
M;HSLEY.#8JHY9P_31@%GH+Y12H'ACJ?;8/(.L)PQL4KE9WPG,.(S>^<3"0S)
MT\#AE$N:8](Z0@5NBA'NAP"46G=%C5**U+JEZ@EGNBPAS3E;:#JST5@Q,CH"
M)VG3!G1CESL50XMT=;6!:9)K5O(J+Q`$XP45I8,*T9)UT9""3>*I:CUF1*6W
M(!G&DW3#N/)VW<7-8P#R_?OW4"=M`HJ#3=7U_!"1S_4E?__X6S6$P0(JD;3%
M<[]/QEB;]I>AQ3JHRRR<&]KQK.B8X/"<X&7Z(GB=C8.?<'!K<1#.=1]C1CIQ
MR/[9G$</PBCR?#[VABP-(FW=UVZDTGH4CC6R?ZN:T@Q?Z*V#[`)1%M8J4#,6
MW^KZ#L:^J'UU"(1@2C;,,X9'T(.RJU%,;.W;===:Y?5Z6<"L2`7S3.#Z>0,!
M<JP*WZ/(1'$($IJ;]5Q^`]XWV/U%8/4[`.PFKD(F&W0-&+]2/0S,.>&@M8FA
MBVEK/)F`("?^G58AX&`[+!`P!X$DMLQ.D-$W95T^#31+T7+^N)R,@*F;5;7.
MF7Q7Z(Q.72OR60'G^&2?YV#:\B:ZZR??4ML%.)Q_1O,'E(J`9V)`GDXT>[T7
M4A4>:8C5((;D92OZ*PL@2RE#GBS3#"5D*<?U/)X[VV3(7`9J4PO!ETF6(4X3
MCYIXFG$PM<+DP5"S_ULS5@@!@/HHH\2_`^;E0<$GI/3ZY<@$MSG:50,8U0AT
M>9-I?B(/P!;9X;Y?J7(<N/S\5*/U^$81I.0"1>3;MV^R*'=!OT@@$46`>]/0
MCQ\_QJ_5J%MK2HX(0<'(FB3**HYSLR8]8M4M@+QD"#HX,C@:YG>I&C`1LFAB
M&'2(U0F>06*$_W9:S;VG,)Y6;8XT#5JS\ZC]GB*R=7>QXQ/",E&F+R)!CDWH
MK*[I,C.T)0JL!Y`&U770U.3:K2+O$.SU[VJL'L]#>DV7=<2C0EZ?KR#[UM^-
M3N&#63?,D2.`)H%LC`6<`XH>/*IW?`/>]^L+M.<UIKIKLL";W_\R(?T+].ZL
M^#YTV[::R523%ZY4#I[G]BK8"="S]^`2S%V22B0N>&@VZ43G>#`L1;(]+_5&
M<!MP:_(RVIJJ#F^.[_:#J[$#U8-[$RS8*E$DHIQ&V_0P59@4=T[9C+IM._.I
MW8\.<*NOO0!"S_A#@I@^5(3&+,&A1>83JA1`7K@6`B7(<NA^GFE_-K:R'5*/
M^MB[\QW+0AU`J0.)DVL('>2X6!-AO5&?K/)8'D8Z#=VJU1"@:J[;!ZR)LH(B
M*$6HA/VUFL*^CCC*0!3HTIF`3$?ZF`S[5X..JUK%&$;;4Z;>Z;].%4B/WUN6
M13Z>'WG=/>;1_KJN\O/'#PL^=,F#5U-136N9"43(XLPWU@$^ZQAO_[Y"3MA%
M5_[DTA)>2C*SN<[.&AU.>X.&L$5#K)26JK'=UU2;EU'(O!X*,+4VU%EW?&<D
M^QCVALPAT$I^V?W$6.QB&#NTLK6:&#1D`!,N$*?8>5L*Y/%X='.*67'>:UUE
MW=:4!,'12!FF:W+XS;+`S,:DK4LC,1<'\@UXW^SN?7;W!M@-%O3X=?9U#K*S
M=/>_H5G.'](NE;YM]6!*82)GTY0@DQWUPMVLL;_T`O"8(Z&9"H17MEF613`!
M2;B0(A.(U"U1&TA8K*QC%]C!U[(LNQXEG>`]!L0@D8+R!H9T@]M,UHHWIK/6
M!VY@G(`<M0`[N%R670K,-=D!B:9QLP4U\DWZ(-*U>A.:PJ'D+'B8@5TD#8*M
M8<,$<2(&</AYB\3-RB"K:4[4IK^CGFFLG\GJM#.VWK.O5HH.G2E_/A[R\]`Z
MM=^U(O6ZD6U:1^T;B:@<<SL3B,E^RV!D8!J[O"B7TS_M7RZ0;]^_.POO\[F-
M(X#X\>.'U:_6)4`2;9C):)ABFRSOU:?IQMB=+4[*GJ[NH2`88K3WHIL/&OQE
M71E`.23[T(/D2JL-[$M#"UR"'-:(H])F07S@4EFE:G:5RAC%-"+.P"["6-EF
M/ZM?W"E]V8$N5+F&72D7>R5=8QAVR^]V;DS[;&N5S\^7>CY9@(3#E2]W]@O>
M,XB!=]Y4K^V]X[2LY+MI[9\-=O$E@,@;S"Z3A2/\$DE\\:$#-5+R'O@_4L,K
M44V@UBK;MLFV;K*NJTGK`Y;5^-(]I3)A<\O>1G7=.P4U?0``(`!)1$%4DBUT
M'\/?&:!^&%=WB3.IG;AY[T!M.0!JL6+F[7\MN&AL&RRSV7ZFU93M%JLEWNM5
M@*8`K06!31]R@(NE+!$473D=TT5^4&E4B-.MC2JE!OR+K=DMO93A_GIO8]_F
M:$'I8ZVS!+XN>.BEWO%?](=R?!Y#KFKH_M:M"BO3M+E,F%935>GBAL?S<31:
MV0R(81\32]ZK_3/36,UEO')`X26K?,UH:!HZOO[MXT.>CT=>/PW)YR1$UKH*
M>\.7=H=K!9\,S7*B;(_KD;FI/;NEWKQGGL3H&TMBEM=J@*?/5LT[X[C(6*[0
MYF)INLZFMM?7/*OU1P61J9AEU1QE&EYA2R^&=O!HM*IU&XU6V9XNXO31M1P;
M518#5JK!SS'=O*D6$VE5%?1#@([.:/>7\.-B&_WH@S"(/!_/^=YR_%FW;9P/
M(LZL!CDH\(3+'>?X&RR-]6/;SXLWP_O/AL)?9#G/O0^^8(9V_;.!"K[R9/-S
M__=T@#7[5>NNU3I2+5ECSU&/2PCO](U=VOOFX&(FNT:1F[O$[K"T+`?3&\S9
MM5O4Y#Z8%1PP9PRGFYH"@,6R5M`%S*J12-];ER"C`G*&&;M7SPQG50KC0S^8
MI'5;4[>GF4R=<92B]KI$KP7/'A=$85UBHO:,`"CO+J/'8Y&M/G:]WFU3SU+$
MU!'KIZJD?>ZM^`@(+0Z`8>L'"*:9BE7J:,*#E3+S^Y%MOMO9O&_?OQ^*!!+2
MXK/TM_]>2+\G`456!YO+&#`!W<[^57J_43^JGQ]/^?CV+6DTC+V-=`MW6S=G
M$I)</X[&P$I?5FZQE+)GAK:J5>LU]BI0M,:L3]D4Y;YUI502<(U^AK19OK;Z
MP,3:7#&M@]'&7G9AC"FLR3M<\`41X6&)'>NH59D:30^;877'6N/D/!B?6@+5
MJ>J@4TI>70FB\V'&K9A@0S5C/I>'E&(#<]]F3%+6HU'--"N[\A?7ZVCV/>TP
MEQYGR`B@Y"RD9O9'G?Z;X?W'LKM7Z8&OXF'<QM"\^W93IP;\*0Q_>=M&(.O4
MEO6&%V]VDZZNBF[S2AN1`L-U8PQT>AP[,S$8:DZOW]K56G,(+Y5F:L`T6P,K
MY03E<:\9V_X]F"/@>)^B&*#2_RYE+S<H!>FA>'OFNO1=LVR%KD.$!W3M5F&8
MT@[2M?Q;Z$21O-P'UK0`L2T^;5"[6)5F/GW[]DV^?_LN*/OX`>ISU3/O6L=I
M[?D=EK=(MS*5F)KVK.]K?0TFT')4P@P/I*FD\<5E6>1?__IK?Y;`#3::*N6:
M.TQQ9D(@2,Q2X%(K<;DQ_?S1FOEX/KHJ@QVO.`9,TC>U5NL0)Q%\Z`'6LG&B
MI.=T,UAG18U#732&V=='F>[A;=[M<Q`IBZX;,K\DW8=Y/@)N7952[->TJDRM
M=A[0ZAN;DA8?E$\SJ(CQD"]WF:2J=.F/7J>C\=(]4Z<Q?W4NZ7KN(<FGF_-$
M.6-:Z+T[]]'.>>89&5*B2R35G#-.D_,#VIK@Q.I!D[5[,[SOUU?2XN2-=SDA
M?OB5ZSEQOO@S'F[7`"%*9O*$17.;VT73T>_4>22M3AD%9X!<EP6"!KTUI,5C
M@P`SS-S+*J#5%))RCE&J2,ON*D95-_UH";$.MGH#1CLDBW%HTN4,&H1JL?C4
M8:M]OJE5%54N$#WD1:+%:EY7J=FC2:(B>73T[/,)0/M2&L;9J<H!,BIIZ18/
M2DVZV#<VQ9Q-/^^JI6E8Z>K8$3`TJ\CGYTN^?R\I6]JER3`.1CJVQUMFE+*#
MWFW=9-VVO21IV_9[USK2S%;7O$P'CDEJ`>#H*^6H,]?71>?@J)AK_;R;H<'W
M;W^I0#//WD)D(C6G%"-H:VIYFJW2`0I5LZH8AC=4GRCYN!$L4945Q)WLV_=O
MRFJ:?>TV(Y(6>`Z=YMI+RZK3`;\$<AX$._G$8*(@5IXRRPY4#8*3B5)=@S/#
M/LTC.Z@I8%>#WYJP8'6?LWFOS2=T]HI!)02CQM>B].Y(V.YQ>2S=-CF?*WOS
M[^NUNL`G*O-P-I$3XQ^=K:.<6"[3JD,&DEP!_C?@_8>SN[_/DN8VNK_TECPK
MFYC)'"7]M?@SJ/@N#IV+;"%OOE&`40>U&DSLFJGU%+3%5/&`J"`<H-Q++IH>
M:_NE_?V+CX7CLPU1=J8TB\YV6,W%P1DU-F401%[E8(!=W]4^F)[Q56WEJC?:
M<%"9`VFD4)<#V&[KVIGIED;7UU9*Z8YN=($#U'CNK)J6&HO!@G>*RV`6D,MF
M!+#K%\QLS?LT=AUJ"`TXF.:=X("7`5O7;<B3#`>BTD9_<D7/XRIUHRP%$C86
M:J>]N+'0&!G8SWT\GO)X/*16D:UNPDKY^>.'L30V#5`\\=462=EJL4F"0Q-8
MJ:MXN^K@S#;N[>/C8V=V@?/'2^LFE;6T[X^7X[F;\:*D&@G0QB+VZ^QJ`,><
MZ<$,#KO8.F3^D)5X#>%!5DI9EKYO=+FO106]!\0K2QDLI^JIJ-I:F]YM839?
M;6/@/B[*-=$%'TT!P:^_O:FMS'L&JAQE;I10ZJ.X=%T>8NMK]U*+M%Z$+L.@
MYA0<.4RU_JH+DF@7>E]#[>>6\I"L3U'_Q\_/E]2-N<OFB)8""8#DYZ'*8[+N
M;FTWW36K:W9U</?W!KQO=O=/OL.L6>H+;\4;E+,5E$DJ'/DGQ^>FU5N2KF(0
M?X=A++;>11Y9QP8,MP9ZE18+`X7,A(^-QXN@=`]T[6PE6;.-*0S4&7_%#+I`
M9==/;9L,1#<_0#C*$01[8P.5"@79-^7>3"56/F@0!?.Z@&`6,F%I.]M3BN#0
MK:3J\F7-\6(#W)I)+J5T7=;=XKAV8*%%XG7PT\'NE#:)$FOZR[;6\->"X;U^
M<F]>(W.@2GJ7(URRBG'NY1%B++??`Y=MJ_+\L+V<!LAZ9SOW?%GM23Z8R,.I
MK#R$H*R/A]3/.C1.M4P;$Q%JP#J&>Z,$1CE%>MI>K*8MS,WMY_9C6>3;Q[<0
M$$[#:T72ZYKR>@`EUA.KV=P]Q,GL4#&P-A`9YAX,<T5D9VJ#@]R!X4K9N_6M
M@U\;'[7#-PU;K5K#O6WML2PBRQXH;=LF/W_^3(/IAN`B(RU&/Y`<7T>J#XC#
MCEZ.,JHBK-'FMXW5MNU*#JQBY=38U$$HR12Q08DQ=+G4M;`ZM\F)IKU8"$F;
M+;N#72DB4J36[(39=X.M4EZ?6P]@!):`$)]%2HI-HD`<3)"%*=$$5];,4Z+K
M#7C_:]G=?S<*'C)+?P)!9X7L\RF>M@GU*]HWH_);UR)*M)X)XV68*DY*!%W!
M+7$PJD<Z&=6>]ZG/^_2<@Y%X:INPV2B;4<;!QB['P;3K0];>@2U28F,-<(+J
M81HP3/TG1NK..ZDMR[*S-+!VM-9/P#IOQ0:A<J@S(#RPKB:@A%<[0&,R=GYH
MC\_:UFT`"?TH:1FGH19Q`%ZA5&A=5S'%EM9K(0<R]+6?:OBUN'W)P.[,+0_Q
M>Z44>3R?LJYK3_%K5$UZG5);3C38L00(372$D7BFFN!!CH"H#'<EP.]I,/L.
M,I;;L$'(*THPZL8'BITZW8R@[&*K8V)#:P)A2I?"&O7-X[.74N3[7_]RM:\W
M2`4WORNK;%L-W?ZSS)_EZFTA$WKZ._X^A3UEW-==*TG`[O45#7KV^]Y_I$C4
MQ%%KP3#\<`UA^WVV#-)2'O+M0?GQ^:F40'*<"$_3'ZYY/"AS*#:[&3=H1[9F
M._U<GG*X=H>1;.HC4JE4*NC*RV(M>G=X4V"NJU\22:JAS1]89ADN($KF;@#8
M1NOZ"(JKBD<9<W^OURK;IC-#M"8LH;I6C*/@*'L1)U+LIGS8QZCVC[CI`#2Q
M@N`->/_+7V>Y?=Z1N+T`AO<8WM.WO)&-C4L3,M-[('O3_V\$"S:%FC+1AK&9
M(>%X"]NVB518:T:7@YV6HC!&V/G8<1PJZHC>MKV.4?],*9EQNP365'][L*Q5
MR>R,FC;;\#,VRW5;Y6/Y&,`QK8_&P8PD-7J`H%:II1RE"#LH0)F)!R.=LR9U
M+4BL;N,8;W53TD`#H+0ZQ2J'S)E2$CE3`?",M+6;GS#U!QXK*#U3D-:*GXLG
M]-?>[%?D]?K<E4AJ58=%*+(P#"BTKB?&N*(,1A$%3G;+FQBT,I>C+EM$RM(D
MZYC>OYBZ4@O*^XGM)0*9\YC/Y\?>+/=:A\UKK+HUZ^)NF5@OJQ&K^2O(U^IN
MF+';!B\E^/5%MO@LT<2=Y>:V"0X&?^5FS$[2"DIJF^2#@3S`0A%KWJ$5`F+&
MIWV/8C69!R?751Z,XUHG].X9&+6`'NR`MCP>@@/P(N,3U5ZB;9@+RM@;V@TK
MBUX<[&7K00#V1JYE642H`P+OGFD#_UX?+</M;@1G^B@H8^E5VO7F-GSK:J?*
M,FB-B*S3>_Q<,U;852$>C^<(=VL"G$E9UW5H>(>LBI[B='B\71^B05.@0")2
M'W7DPQ2JJ!(:W^@*>3>M_0/875R<?A<,[;06UDM1_28FEWOUNQJT,#GM]YK`
MWQ0?46+ILLKMF@RR-5#M@"U<JV(RJS^@/+#U#"=S,742DH?"=C(P:?()O^\`
MV9F1`[WAKY(0\TT+FN#9MJV[]?22!^/2M@.OZKNC]8Y=JQ"09=FM@5%T`!'K
MI@U\26H*-1LT`_M&9LS%-*Q5I5]Y&N31U1?J`Q"3W_?DZ<Z2NWKUF=M6`HA]
MO?BR/$1DGZ^F;MS);?E:\N+&F@=PJ(BE/`WH%;'-C0TDE%;&<RA'1`O8>"(V
M*<"=Q<U5,&;9ES:.R_?O(OQ;UI7]\#U07'#;XW'/`S#1!OX*2)0&<J'ML@]0
MU@(!6#>ZO_[ZWALP39#I0*EM*LQV\Z.F]4CSD_7`;[`5NQ0C?564ZJ.K=NW8
M+ZO#SJ028<"'*T+KC#ZEUDT>7(XD$^;9`+\WT\XOW:F/4CI`U5&&;ZSMGU>4
MMBX4RP_GAMC*ME#DX^,IS^>'E1'L%U]&NZ(R)=$-H);]'&5CIG:X1Q32_228
M^-0@L=+LVMX<6EQMVA4X4Q!$8D.PKP\H0Q_">H=".8]&8QR.TA"X.G5HAGV_
M(,S2K"[Q`C-'.;)>@'H6OC-BS/DWX/WOA[^G@!>^+.$.UI7[%L)&U'X6N>-^
M32"O/A_X`R-&*6V7,!:8$^*6XR##40]I@)^CF*[ZZ2B'$+^<VW?J5/,OYP!"
M^8+<D_]A-N;LFU]-/(:)'?`NRR-T#E/EGM9UO63/BF)X7Z^7/)_/#GJGS8*2
M@=UJ$&,K.6FUSG6KO;&IJ/3LT"*U(NWW&,`H+M=K^F8+0$FR/1Z//.F132ZD
M\J_F.3X>CU'+7=!+8W"D3RO%2,G9@V2`FE*T=30D*P>79AB@@PDM/74PV$5B
M763`\&!Z/X&8Y?G\__[]N_SX\?<1:%FP3JKB+4>C6B?$&`#B9/%`:4]+@7S_
M]EV>SX<3RX][W5`@D:/TP\<WN\[VY^?/G7FC'2-HR_..Y>P[&-41^`8@USSL
MJD!0Q-02ZYI04S:A2G26H\PIK`Z>\#0*I%'K<:$!=P@5[T'D3+]/'_3,04'(
MP`!%EL=N[]S7H%B2@>)J2_TX"=)3F+9DU?1,M+EN=C2H^SI^"92HJ^YZ/SOH
M52A=E^'H\^#Q>!QGFFZG@QE3T%IQ0]O;0QEXJ(#0E$1-%FC+#E%EHDU6M(PR
ME>!R"$C)_-S?)0W_-)!KJJCDCHR!K<7)CVPY:VBFC<CNL-(QY7=!LI*S?.&O
MCURTRYJ^O6Y2\^SD])'0><^&L64J"^<[T%L)`%F-1-*,(?%?[:GQ.^/"'2!:
MLP6O-L$HCJXF`RG=CKG7X`W$USO:@S*%U\TLI=,;==WD)1'TW@/\141JESI#
M@3R6QY#D*8N4K0Q;88R->UF6O39Z:<![-4V`L?Y8KH.T1#Y(1(.#972S@R?S
M5@,89RXAT087LDMXH>X5F]([\8_?I&Z$YN&\]+'+?-5MK\7$`#E0AX_?:PHP
M.L5%.VFQ*V>8YCQ3$PA[_9!KFT7,BIL/UF<I\OW[=_GYXX<(-]&<9*M(+%@.
M35O%5E);F.)H`,IB;IB[U0H?(B+?OGV3;Q_/::`)#YXTNR<65*R?J_SX^^^C
M/(59Z;\DDM(BXDI-#H:S]!(KU?:GJ&9H%E\DU(NB#%0&S4AV)JY**3[=/LEP
M<+;O#F)BM"#0[#\A0R/>A,230$HUXKCP;]];4())38@NNSG85:GV:R:#I@D6
M6_8B87<MR=JE"@PFUZ1J?8>'BY5,+"X8;L_GX[E(*>9$"OE4RJZH4BL[T]^U
MB47OYV)*P$J!\7.#DTVTMS168JKT@GSI,RDK>P/>_R:8>^(>E`.[D?JX`HI.
M)>^25S3L!&<H>LZ6WH/O,V#&7V=Z>?+?G!BD*4RV;=N=!Z4T%3/F'+V.3=NP
M!H:2(LMC!W_ULQJPV_4'&S#D:,YIP_]0`%&NGD,_L^?454CQ!I81G?TI)8/Y
M$N5@$_;Y\7CTZVZ'<1OWC^>'/8!OS-;'XW$:)+1F.U8G^MX,-AJ0^U;DQX^?
MO8XY&YLTYC&"&%F7\AB1K6[RJ`]7MPSE!@4+%`@'N6+N&3RDV$#A`7K)/25<
M54-).0ZSLBSR>#REE$,^[[,ZDPW%3"6?V;1_]=\X6'M[GB'?TV82GNVS#XIZ
M9YQ%<E4/>WP_EH<L__J7O-9U=Z`[2BQV^^F]9OS'SQ][]J$%=LKZ5@<7:<"E
MU@Y4_??'MP_Y_NW;)?>`#,.[+V[;)G__&&`WP_A90UT\,QP`1/(<+IY)9JS`
MVIB[0^>UQ/(";05L]7N1.[A)=%8L!5+K""QZ&AVN=*B;1KA#"4I5'4-=YOE<
M>G.J`5Y^R1[O5UF/^2/B&[>,XUMC-*M-<7HWQP+5.IH+N=B4J0?W/ONA?TZ1
M)^A[WF)R.::.6Y.MO7S'?AY=HVY[ISW`&6RZ>7[PA!SL;N*B9!_+ZJ#)_L=Q
MYKUAXG\?Z/T*[SNS^CUS-+I3MWO6I):KJ\3XD1)3J'?XZ-K3JE_#N;W2BE8I
MP`.Q4Y+N*R82Y.ESD1NUV"WV-S:KXFTQ7=I11);'XV#2,+V?S%ZX,7#;9`*=
M,=M6/@I3%[&<PAEO56OMFS$/U0D<==.?\BD?'Q^3>9AG-69@U\N(H5AM3L\,
M:?<@^X@]PYB4<K0<H?=UA06*I5(^/S]WP7ZQ-9FYYNF-*8E=7%X_IVU=99,J
MJ$>=-T:SW+*4_ME;K8/).4"=9@1/XVA7'L)MD\?S<01ZZ%W66@?8#)?7C>;>
M7+BMJP"0Y_-Y8P2T"Q7D\7R*]-]KUJ7[,_W^_;M\?KX$@+Q>GWN0!1VY:YDI
MAL:_GK4XYLS']V_R\?$A1+X59H[$J>K2L59_?G[NR@PG<]_K`#/%2DCI5,KU
MW)JI%6@0)`?`HR#T[^_[#E0@F-!W2J(Q0]CZ432VD2[@@J*1[5Z']$3J)520
MR5X12VO6]35$0.!S-EYSNQ6X,Q_O(RL2P6Z6Z;$_TS_#6T^WVF6X>BCL=M8P
M-=\JXU94+7:!E`6R5:UD=_Q>P=R94'7'A<J#Q.C&G`"Z;ANPB@^P4X:P8_X&
MO/]%KZ!!^J5?O@9U%[CA-B,[DQ6;F>9Z,9/IM?`>^WQVW>VLWFMH`_PX/;MQ
M`^R:]T%B1XJOC6AS2V.TEQ$Y='_7;5.&E&,#OYY/DP,11;DJR9!<,W1N7@9C
MGB\F>KK`-"C@T14L!T-=M8;NT13W^GS)\^.IF,^3:LJF]S/YD18\.5$NJQ&*
M\2R&77,6?#+6`*M[#Q)_8&_.Z?)$AW[SY^=+/I[/X_KRA\6[ZSEY\,OSN3>E
M#(_8'F#PP.9UJ[L=\'$'WL8V+E=]"K/+MC4F>EF*5$*X[2P0W+AP4MZDQ^WG
MZU.V=6^,7"[6#^WEY!*WJEP**/+Q[=O^[)9%?OSX(=NVNJ9;%6)Z,YA^H)>>
M'I=#"SE/'<WJ6=W%'L#N\_7:55GHLTG.5,-)XQC`S9V*-<H2;KPD"]\84)Q2
MR(!;PR+ED`![K:O\_'S)Q\?S1&X681\`$5B4;FDLQYA2I_Q=D'EL]$"QG7=-
M'[E``6$(:Y6-=:_C#]DGVO&AR+IM\N/U.N3$(*/BC*Y/7#&[W02(:=^I5IXP
M[F(<EP]CP#.NLP7C@*Y/5Y85:@Z#W+.&U$KT>7/[SMHO4OFR&=T&]'D2;R):
MIU,]6_@,H4L$0@5,(QCV\]SN(6_`^P]A=^]QFU\'QU\%N^<_@Y3EO?UA:F%\
MI;PC&\/JM".O-/[O,+S,`-V4Q#U)@:M?("GK:YU>%$H1M/I3=Y\T-6685X&X
M36O7GMT/E<"RV?/)1>FJGA.3071U;LQ8<$"V6F5)$!VYRY]A+?(\2A7.0Q5,
M65YH-[?6B-7&'1?LF68NF0-\4A,T=++KR,'(L1[6UVN79IL&+G>C4@Y')S?)
MFN+)7B(0T?3GZ]7=Q'99MA-V7U2MY*0VO=53[\Y5OV:72(K4C;)BDT<=P0K<
M,PD!`6?N4S**EU7:O90BW[Y]E[__YW^ZIK0V16A_F08XP6XJ\>V;+(_',$B8
MI=1T"E[BNM>P8%TWJ=M1!V]<K12KV=ZS)G;2XYT->(OF#:-;CCIXD4/:RT6!
MPU+9JHKT(:U[[?OC8-4Y9:?%J=PP%OJ2A]'%`=9T)F`"O+1-,JH"BM7.D]U4
MAB):#?"D_N[U6J5N#')MT;'PV!7K4*!IC*]5\DE.PJHC!`E6W_TQJ/D`K4CC
MK=&QFV@LRZ)*0B[.[J-[LAZ!4O_TVD:>PXPHJY-+3"4H]CQJ\FW5[*,3V;Y`
M;U@#I3?@_8>`W6N0>1\>_S(S?`$(;WU?<B:$;A'^#N`-6K>\9HU3,YF9XMM5
MC;$M7QJLHC=`ZEJ+CK_%O2=+Y1>?71;G<4AZ@UJ:S#>:^*YMGY4PG>$S@7\U
MQFC_`Y36\*`^MG4]:DR7RZS(Z13#`'+>Y6TXUAT<2-<-;H\/2B_2E\<,($!)
MFL_T@0Z7O3B^MJZK/#^>QKAA--9A6'2&W+4M.$27K$N"K%HC4RF[BU<]TN>5
M2=0A^7W9?<K.H5WA1)6U\'X_`CJHVZV2ZV>5_[/^'_GV\2'/Y[,#[MH5/I`&
M2P9O>AV4KHE_.+8MB_SKKW_)CQ\_9-W6<0"[Z'@/$!=Y?CSE>:A_F-I?MW3I
M-+\(JX&\_V@Q`&%]K3LPJP,D>'*S&B2K0[J826LZKN+E_;3K8_^<P["%U>C\
M5J65FM"5_3VV;2#@,^&1F4XU#@:6VMJ[.L,@<GKD=5DMVDQ?44UE.,PTR@T;
M3U)D>VW[=9!#*[:?5=5<1DW8Y](U9K,\AFX\4Z"P[_UTH#@_HS4I`8S]XOE8
MG$->F*8FD&B!VU:SP_AH?JW9WDM;TF"(AVKGG8Q,'#EWG8.QR)&1G>&;X?WG
M@.$[^))?>!_>IW1UL?D`/9/WIEP[82@PR(EDT33Z_C+8O<+?T><[,YWXHGG=
M5!GC7JA"6U"6W!-E!TM-#Q<)\<POQ!YB#8LD^G)I":EB&R@,<P;'AKAK4,"[
M.;;E6L'L\DP?'\MOK9W>?5_KSJ8BGQ>@VH@MZ60$_T4BA9AE)`;@X'1-;-LF
M3S[-(K;]-XCJ[\EZ"5^C<B@R0&L<'`$=F&#S;-8GNFFMF;)6P?(PP4P#1ED=
MJ+_N'S_^EKIN4HX,`+=-_O[[;_GY\Z<\G\^N2%*/QKL0?(GOH(?[.HR(O<C.
MAOWUUU\[Z%UWT"MUS/5E6>3CXZ.K:YQEBSI#[MGV%IB:>;*#]UJKO%XO^?Q\
MC:"HJ17TTAN<!L!P`9SR6QB=\_TZ[)P$)]XG+KBC<4#$T4.[?];CHR3.?MD^
MQ\EVIX$797N]C@93<<HQQW!6K9!0K:,9M<J(`O6'$8/P^H!\?7[*Z[5:`7)*
MT$G7P(Q.=[8SU%UXU@HD-Q`]U@-4$YRS+9_5VAE917:;]&59#KMDE9%1Y1U#
M/YR]5*+6-OYYV6$0VVE]U$KWA,:07E*HGTH0JDZZ()MW3-+V^6_`^U_)[D:/
M[E^'Q/=_;M[\QFE]X2\@$,NVG%S9&<N;U07K^DM_V?.ZX_E1_M7A#!O]I`Z6
MNL-#Y$3Q@GO];L*JM%I8T^#%.>C-9.B\:YF7DR$M?]2DO(P#5[8)RY"I"H#L
MT&MM.IA0]K0A>#D`@:Y7QDWEN@QC9O.I5PD7*.M?)A1Y<K`EZY<G3)0Y`KBG
M/S\_/^7;Q\<H+/'UO+UD`D;%83P[.\+#!(3=$<^/:7L5%*E4JB3U1(Y%LR_=
MQ$(I7@AD?:WR>#R-3)GT0SRN77CFV-F`M^=5:Y6?/W_NUUQV'>,'V;66LXQ#
M+*E`N(=V]:4L\J]__7^[1-NA?5N611Y-0LXS9:VN\ZB538LWF#MJZ8"DUBK_
M\S__(]NZJ;W,UG!VLJSKX]**K<`)M5*%J]7SB\-$0P<@!F`%SVXHP*1Z,X[]
M:W\>SV!>P)MKDR;8Y.'0:(UD#"/MC'R:;CJ.4H^6E:$*MKH<H%+)@<PSC)^?
MKT-RT;EGTCY;)@%'8VPJZ@AX]4\ZDYRL)X!>>HY,1<6$WHSGJ#6NL>RG7V]E
M8(GK\3L27-9<F1@0RY[$UMM6U[]C&CY]!L:5V5'5@(0&WF-^OP'O?QW8=1-%
MSJPGOFI;H,0?[_1:38A'WNB*NUO5D)7.WBEE"*FBWJ!S%[4F/^A[52Y^,S8"
ML'<H4Y4(-#<I<>>(R-'M3)V_LD"8K./M$<L-&M/;@&-^K3`'WIX:KN8@1/.@
M[XT[49IH61[[9SEGI*ZB?P"26FN7K#*>]T?:_OE\]HUT![,(XTF*5-8`>.\&
M6KJQ$,-K5)S_J7)V:OK`Z)L_LPQ&QB:*2[\FK.^L%&!;5]D."2$]?W3*?C@2
M(<EHQ*YH,@&3[F\&50XDM#&,+;1>'$-X?J"25AM^7NXS=[);EF),2SP;/"RK
M*9^?+WD\%GD^GWO01PWJDF;'OK:M^Y.^B,<!<F_MU][%S;'D.0.O-:^KK*]U
M![M=`Y5NG@WQ?IU2'J`2)ON09?]CQ@KSZ_;S7!5':U95&Q[L:UF!\ALKTP2>
MW>UK_UZMW#]+`W^+PL:^I=WR8L2\K_JR!RS/CP_QS7/#06V\UG5-72))3N/=
M?'!````@`$E$0518:B:YSZV2')H,0%\4*]_5428E>-VYC3;3@-F9Z9LZO?K/
M86']^?/ST.%E<`5DPM`SR0X(8D!NR^1$,<LRK*'=N9FJ!2DBYPUX_SMAL+@B
MT!.PRXEM[7WZZ[*])`:WZ1OQSF=BFMERF_"UM89F+!LK@(!E.1W!.^Q#!I"1
M^+QF(S%`+DZD6B!+V0_RF)Y&*-JR(&!G1%"*+&7INU353(Q`6?],F'#=($$G
MA]9]YY]'XT$UX&O\R@'JCT/P]7H%,%4.6:"FN;LLRY&"VXTALO0"66_%<-,U
MPK'QPM=2J[?0PNI98#("F7@`,F&?Z;(4<+K#^O!O2A6-_69"0S%+,RIKX[0#
M5#O]J<]GN$&ZX$C5<@)690&1->YF!TFJ@2E`B%_;MFU/ZZNQ[>,2/FO__NOU
MDG6MLKXV^?[77ZZDY&2Y_T)V*B,F\K1]M,DSS5.UREHW65\O^?S\'*E[.6I7
M$^"2JO=X5RY=C<5,&BI"<!WT1%<]U;1&9?#0Z\QQ]&B-P)GUL%T^R01JDQ\3
MN%6[-]G4]C"XT3;7XO:YKA'LB)/GQ\>^/YH]V=T[T0$O*8G:1NFI]>FYI$MW
M*#8SYRD(WU3(W.*:OHF+>CTH)T7%QA[2T]V]C:;)>-3=DI"?/W^.()-^WQ(S
M!Y#4]6L]XCWN8:ZA[NO<=7F-V"P?X*\![Y*&?P;H#?#*'CY?E"V:U95>I:%X
M>5+`6`A>H<C;91JN_L^D(NDU/L6(]Z>UF%>H>V;@X9QP=#J9$Q++B*Z;.@/[
M>V25FGO,[!VYGF9-E`36URH;+#.VJ'3O>J@\M#I$`RZ-%)S3&Y51R\@CW=A!
M!]HA1`/DUFUG"A[+<AR"ZN=K[9;+M=8=K*L:-GT0ZK3\*8O+"%['K57%P;C2
MB0:$$\.,[/D'+DC5SPW-T/EA&!G>\;5UW8[F/(Z:1'/@:/<HF0`6)&#8E5J0
MSN(>9OVV@Z4U5/DT*KPB1F^N.X"[S.MSSX))7;+@S4%\'8[EV?;/>[U>(@+Y
M_M>WW$7K>OO*@W"=I;"V8&*H[LF;D-8-[+6^#BFTFK+$LQ1&-G<L.+7]@7D6
MCN'[7F]ZO]::,[%!G86'\D&UUW&4>P"VT=4$BKHGRSE,[E]CRB;`[Q'>$.70
ME!Z]`?O`/)9'.AXD#)C:Y](Z6.T#+++MT!S)+-WHJ<T=NHJ%*BWJJ[>I2>C#
M6`<6JL&Z`T+X$AQ;V^KKUJ@+;G7-NC-P83M[#/FA2VD02!#KNFGA>.+;*5FC
MSDCVP;#`M4:C#N_6">`->/^?A;,W51DP8RB_JJP00K+\V[/]][KYZXO`6Z[M
M*!K(,JF0#+9JU8/).\*,YHU.79G58L+6)_9#1,O4J.JG60.0<Y8:Z:!1^$_=
M9"247)V'RBY8*0^\/O<&L^-0V<=RE8(B6ZT&[/J'35.S2=FV*MNZ!5_4`?`.
MXX)CA+=MZRRN<>^B!E[850)@781T>0`P$9@XF=X\66==H]F#%&(N*.`!-:RM
M9\#!)VM($O9D#TA6J3^VPPWJ*<MCL5WG/#ES;,^U.DAH&!DXD.ZOH8,)U^YN
MZVVIF'+U_<HHC,^3U)'+$K6TOJA:S.E>V0!$LXTZJ++7ZU.>ST>O#4\#5@5D
MX+))81]T++61*H"D"A1&#0(C(["NJ_S\^7/86T_2Y=YZ?/P;DZ]/YM<9\"5]
M=4#(K)GSQ=3ZNE$Z4N*LSJ2@$14B??\Q&8G#I:W5).MK*<>>U?;#/:-DG>FF
M=`5=]4"OR\^L)F(V8%LW&V339HJ@2[_HR\7$-+GU8$TS\3IP[F4!'$8:ZA08
MM>8:6-M@!^J\&;KJF.91_'YP#)'14Q!/&.EU3'%!G[8_1]@S`>;$@6K0[:`W
MG.Q1V>0M2_8/XGE_YV4$X'D%L),&?-[YC)/K/0'9%U'!U!W(?!;R#V)R#1J,
M\M2?3I,:#CBD*1T/PADV)QN^N/2;6&<Z)"P_E2D/W#8X,+]VS*JA4:UR"X8`
M(3*GM_OT:2E5GW4PUM#UST95AVJ#@X-GHAIQT$L-&ALRKL%I38<TNA/&H3CF
M^?]G[UW7'#F27$$S9V9)>][_4?=LJS(9COT1X>Z`F3G)+*F[I9FL^7I4ER09
MC(L[#`8#7*)(^7ND^&-@V]U8@(0"A&$Y@"0"X^@F[*I7']Z:P&$_/[K=CML9
MO#!8WX2M?7.7KX+N.,[I_XX%).<@UO6JXWZ(Y=J8Y$<Y9,9R"U#TJ*?V4=5I
M?U3?3YVZ`#I(QT'_W>6^&1/J'Q\?"GA%[K$8-'&M\,)R;>B00[(@)]$E/75X
M1D:Q_O'Q<4H72([4R4XP,FR@RD:+V(*$*"*#<8[GK]>G)+G"423=NVU>D^E,
M`7HV83.U<`#>])[7"SI@1S^6-K:OI+;;Y2AP>WLCZ\!S$.XL#GI(FN31/@LB
M4G(A(->KVW4_"%N_J4CO]_NR@YO=Q4ZW=^Z%=G1YUL>Z%+V[4<D:."*8!\72
M>E+=:YY2,+WTI%R-13>LR'M;X4Q>[67\![@PTMD,SS52?JCHJ@#*L-Q6\L`(
MH$&`^!OP_@]D=Q^BWZ]$WX:'9*=FQ8:E^#5P_;7WP"_^6\46@P!8W=&K0CI"
MLI)'$::3HB'[W0JX>GI>PQ!#PEE>\<L)<)9!M]+2\LLC,5]34"R5MHQ"L8`L
MQT"8\%;;+,J0#]_7:>`)CDU!805MM2:EYR`)+;@>-:Y8K3H>TICMQ'.'2DP$
M[#XGN!''(<G29ZOA#1/J>9.[8!DR0(WGUG`"T9$V-N)U428I5!OB.=`UV$3>
M>,_H9ION`P>!K>&%:J0W=FB9)U957MV$"QB^,M@Z!\QXTAYA<!,[ACP/Q]WO
M=_O\_#P'*QLGPJ$(#>GES*I%]KQ8')5`.)/S^G%<4@6?]^H8L$O:^:O#P4"_
MGO/SDL&-@$C!E6OU'0"#I7Z`9>VSX]*LFG@R^S68"K*)ZM;M?ES.%KY:\./^
M6QTZZ$3^'7:X&SX^K+6;O;W=IK^RDV]Q);>;C&CH0%!-,K_O^_O;Q1*WH,D/
M&N(KY9';[J-+TBEP8JX!1)_S(%9'*$=YL#2`0B%*:=\"A2553D/GQQ?/YC4L
M!QOVO4B`>JQIQW'8'S__"/[B879&(IO#L*:'P5Q?P15F6;_/8+[;8W\DCQTT
M7_,DWX#W?].O7P6[?R+![2M!O_+\OA#1^ZN@'Z%RW8)VRU1P81*DWQ?[J;I4
MJ<:]_A6=!F]0(LKD1=+C#OL`O":,*)9+NF&"R"ZD`41AJKT^L?#@STGLM'4>
MI,$T^$^)2?$+>=VVF[JY*R1A,'G>VMI\Z3LM71HNIXB>?#SG1'377'>.)>6!
M&.A:'SF6O"&/-FV(RT[QJ)/%6WK8:.+V^7F?(&D-OOG\_7"O<,<,8_KY\7,&
M2N1-_=RH[_=[N&==G#9FM/2F'6H4'B+WBG/\KB765L_ANLYO;V^3U9N'=;7)
M+:0)1M`36=.?/W^:MV;-V@G`.&UO,%O]L'YTZ_V8K[VU9K>W-WN[O>W#9]#G
M9Y\69J=T9TB&=)*_A0'%T#;#`MX5@,VLX:;&\:QMY0%%;]22=[<J/$:(;:,N
MCNFSB2*LO?=N__KC7RN@I0#FLRN"<[",-;KC>GQ\')?+1YOG)*#U"7!+_V7.
M.@',V\U^^^W'>0]=WT?&15EF98N)EGD1S]*AX9;C/O2]%.0!#HI9UGT0EI7`
MIRNC&?>1CK@77[_"8*"Y/GA#>RS2@F!%>:"OZ.'LWK=`J;L6_$QGJ*T"=5[4
M+8^)@'I>J!Y>L[3^?$L:_J'L[AZYON1T\!<BYD?@,#;7M^[`7[(L^Q-$-1X=
M[^._5ZW](RNF>@1J,9L91'H`WZ^%>2A[^D",L4?S!=*>WJM;C?<#3X[-IFN)
M\8KV6VMCK`H&MM5*C3TO_HX6<0"S)3P.[TQ@:Q=K!GM[NYF97]KA^[38F2TX
M&8S35*@U+=VW;B31-0'!GW-:'`GSXU'4N1_8]+@VV&2P[_<CQ5'S[7.[72RP
MFWU\?)R%03$:CWZU+SD%#Y"")'9GG*V#7,WE+6RBV;*,"Z>-\3Q]IQ\_?M@?
M?_PAUSBWV@.;>0U\LA[W?L#^[__[?Z^6^66!UYH=]_LYO-E'LIZ"Q<,.\_O=
M;K>;_?[[[P1,%I`]CL,^/Q=[OB448`;O<W`I/6,<2.$VI37+#G!)$J;G=>'8
ML?3^W6)"8WQ^/54B?*NEJ+@'6X;7%+];"JN13M!DAI6]9#TX#';8(8![V20B
M2\,O$:I,_*-?@2'-;F^W-!LQ)"FKX!RGX$AL^6[:8\FD='Y!XJ"OOOX8!ASA
M%\OIQ.1A&1T'I]CSJHN828&EK&ZMV?_S^^^7W.3Z;LW7,^_K/-_:;9V7YBMJ
M>NYI3FNZ29+F_.Y$V,QKTNHMS)\,8:SD0:2M:0XB?@/>?RSL_:M)W#_[L0^1
MJ(XR[=_S*ZSNGP.[3PS+JI2T^=![+N^WC@N5<7OU;U8/Z>#Q:8XK@K\0@9R+
M"CQG]F7B)6R^I<:L!KT:(.67C5(-QJ)',3PFR!$80F9>^$0!G`P$.XYS.GR$
M-'Q\'(0E&.ES)/"2%2Q`L:;">=D&,K@0F0)"@6,AT8R&PYQHSUJ/7EA.3;;=
M4V@76\@!9OW^.:WI.C.DG'0WVLU%$`AS1S#V?[;0X]]5D(O%.SU/S6J*%%N*
MTOVTLKL?=[M?C@LIF8W^&Z>W0$X*<ZWJW>YP\?4]?Z2)1G@RK'9:AO7CL-[[
M!`YV_?W/CY]VOY-+215/%GZUYL+Z.[-\S,0::,A'YP76O%/H@'@B>O-P)93U
M%$NY9F(Q)N_GSP,SN?A(.FE;DJEJ;?%J,,21BM^EX48:_/<)KL25>(A')GLO
M7M&AL@,Y_G36I@?YGSQW]&=U#JTTPO0\.,T=\#R)Y_O2=PT!WLN<YE#\U$/_
M^/'#K*VA5!BLH:U]CPK5^_%I-AQA'(G5]UFDJZ6FYNGIM:RV`J\,^X)HF#L/
MHD\/%F??@/=_,4;&7_`FSQ:U?QOCO`.%OO\,;%G0/.2Q8RV+ONHO?)$'1NTO
MO.46JN-Y1'36^B%M-AHRP2\T%H"I!8#[P^M3L<2(AK,]1V665!$0^*%SP76$
M&8DA"T!F/^4K;)DV`M,7(.L([!DY&@C@=MF'4ZA$O+<\%%;&$@EJ?U1^JB@J
M)00FB6>HJE^]]]-\\\']UMD=H+CND=GF$K`V1EQMVP%LA@8SW7?/'N[K77_[
M\9M]?GR*/*`#E6A>?L^%W8GM^AK`2V4JB('O<N\T/]FU^_W3_N__=]AOO_UF
MK37[XU]_V-&/.5AIA?[3`WA++"=/QQ>:\.86RXX@]:&.D@>)0HH>=NHJ#*#M
M!=N&.6`45]3H!^VL68U2EA2W&T8L6[[NG$I6)S<Z<XWSG*[$;6AA,1X[+,#Z
M\^<?%`>]0E%&8(;Y&2/<>S^[1`UE;<</1<5K3`Y%PG94V^MPPKKKI+M%?ULW
M"5L<[\GQN_+HNKV_OYVQVV[V\?DQNSFGM*/9V^TVOR\ZKD"?N_DMC'!S:%+H
M/#E;JADHWL4(!&>ZPXW!L^5B+7:/G/7868+S#7C_29CU92NRY-SS"A'[$%8]
MA7B;X+&'".Q%"4,)#'<2`NR!(2H$'-)?'N)-X,$Y?T6/\$6PF]K<10D<$J!*
MGKG<[V$QGUUUN-BMV>%8]M[#"&<]#OXD)58(Q9#I<FBTJ;P[@WTR=S=Q1;C\
M,`6PFC!B*#R*=<A,O3!TL^9)?GU>Q]<>7I'3V<"RW9>3?EF_=F6UY8$]0GD1
M.NT73MMD=%W9^76B`KFDC>W$U#@E6,61N@Q<6[C-V_4_+YC)N'F.`)!5J,5[
M"!FAK7\'+)HC69!K$+RBH:%Q[R"9[(^.Q7!/^->__D5@TF<GH,+Q&MWA-'0#
M8:RB-7>I=<:&!Z#OL)BU*MQF!:6L(22(ES/?/UBDKP(Z#]?;*?TS&%A,UM6T
ML^%6Q6U[*"X76RK68E?7*T8<.RSY+7-0PY##C)`<`';S9I]8'L.]GS:`IR<Y
M[/.S$WCU!/2$_099=WF(BZ="SV/._/AM0Q#.XOJ>O+8HJ!P_VV$V@B<'8WR[
M^25_6FX@?E510+?[T>UV:];1[?[Y.9>\1I-^@&^"\LZ4RED0FM6^U+L_SY1+
M%'LL:?^+HGA=X[4F?`/>_T&_TA#4`V;W2TZRV'_6GV%L@><2C,>LI6X3D4&H
MD\YH@A<U=_2HL"@9UCF,55A=X0N:XY(9J$!\]+J,H,^2!A=I6"YHB5]@AE%X
MRG*:363V4HT";.\;#G6-4\EFA1Y/M'MU30*[+)9\>5("L3!`>?X78'9QP`#9
M=`E:,T_A$<OKTBQKMX='\@)$T>1-0*EKI*=H%_$HT,5$8@#6U1GI^V@0*J99
M.1=&B+6ET[-'K)OQ$(S&\8)MYBY]XA@X4HNEZHY:0S7J^WKY27<(^P,4P04[
MSG@;Z889HWK*%$+!8@RPM*T,6W9M;OT*5B#NZNC3.61$!F.Z7(1S5P23('23
M2Z0+T_8N])D*%85(A91P!H6U%.U^5+[7*/MIZTU7)'DPAR"7`#J7H66]0@6:
MDM-QX?*PJ+@5UFHNC.[<11S6[1#K@7,9N$^D#TGU4QE3G#^=3L%4V.D7]QR[
MF+:5/'@VOG,UF#<`</-`7+2S(\&L/S__[2HJ/SY_SA/;HG1K.$O,H=4H6<$L
M!%9'(UYLMJL+*&;*:5A[3JF7"-T"C\4?YBG]!KS_DQC@1RCX5]\%O_;!S]2D
MKX#=KWP@'BE\H2S:EBP6<+)S*BT^(0"^N2`!?^Y22!O5@I;,M^SU5\[MG(PM
M4YYVR(#3;+B5RC&RC[%$_$=M3UD!D$C_.G==56@AQI[.-EH$.\34TJ*8+WCE
MF:K%1ID9#UA_T.DH92/Q3QN6+J:C89^]NKG!I1Q8]PD/8L'%UH<9TYA7'UGY
M]'T@L5@GF)O!`J"0""]]81-\BB/<RYG?/CX^%RM'&RV#NYZ>R6!XS]_ITK&H
M#E@K34@A0@(3]Q3[ZB/M`A01/<!NB,".#@U5]\$0`8T+&*@&3^=0GVO!Z'@P
M;Q#\:L^0"%HC!N!(PY,(Y74^[]-1IELR8`9U#A"+.!397%`?<T]9W3S(AQ3O
M/9]*TLS7]R-$MS_L^')W!.)28(8RPL*@-EX>6`"$]8"+&_<GSWRAU:Y:=XCG
MBX8N/:QB*:Z8XHX1]B!>FY<MY#ZN-7;%9#LN=+T[L,O?C;?-;\#[3P&S>)93
M]E=@5Y1,V9<^\Y47^>OO40,W?P%2A\][.-#E@46L_]7#@@W#8ZSA9IM`K=>O
M!.+PU@/P^`J;#,HKWUT'1'/O+'WT0$(SPXS``.^_>Y`[%$-['0A7W*DENAIW
M#%!S.V,LN,Q>9':I5(W$\"C>Y4VGG!$V/.S8;&=OTO"6S/+0R>W]Q4!M89JR
M9C"VOBMJ;6Y:/4\\Z^3\F!ZO@S,ZI3B=;]F"11L/EO4O`/@BHOGR!I6!,!OQ
MU0N412D'HLV6:^(7I\H-)PX&YM*UH"$XZSVXJ%S`B!F\>4UZ^<QC4]\RZXL$
M5(,':8298U@1I%TEQMY+%EQ1$W7V%YX4<U177RYX>;R)@82GNA[!?%9**W?M
MMEC0R\LZ?+;4RVP%5A%A%1,(\JE`^D_/X;-@[.K]''VUG#GKT*"':E1!UHSC
M^4I=W%"(ZS7S//T09RW2P*#K!24:8P)5X)0Y=&*G*>P$_MPYRJUP9&(;O9)$
M4-EA]L2F5]*IK"B%;\#[/_E7T2;Z9;"Z>SV^`(;]K_A2J,'P$UT$GIZF1Q/A
M]0A58NKP"\5!>BHC4[RW<`O4U!:(2P5-"^*PA?&B9M?7*8QF6Y_(;.))D:9M
M8"_,[:WPK1U@,FP_*`(G=I_OE;7-`).Y4R`2F4+"P(K>;8IFV,CB_N(>*AF+
M8'#O)E(.L+VD\2==H7/@!N0C_=G#.J?S?>O0<9*Z2"WJJB!*ME</*N^U=S>A
M@-KM9KA?(2!#+VUM6CG!J/"Q0M//Q5>P6NL=I\=K`,;NS2*O-_2G67O:TG62
M)PJV'0"-$=?+\HV#"8)-8K#H$#V\'%]5F`KGF8!)?B[RM>>`C=I-1)]%<"3N
M.#/8IWLL';>M!#QV.B#D)/*=6.PP6QTZ/N`!55`$LK<KSCHS.(MA;FN%@"<M
M->):,0;.PO5@>8:.=\#B#`7H?`L148#=49123[+8X];Q=3-K%$D\<M::+X<;
M=II17WT-E!&O^!&X\<`3/[*ZEFX[W^YW1IV";\#[3V=^[;7V-9ZRIJ\!M-?!
M\@.OX%<'U1Z(A/'BQ[VFR(C,=O5F:V!*V_:^P?*HS1S\3Q8!&_LR'?"R(N^Q
MCC?W'$,E&S<>)`1CL[AD)HK.D>SK87B,\H4E.MC8:-YI*APE>$K`^V*/8LSS
M\H2-7\K3D%T,6AA:3085(_'+RI0Y'8QQ`AH#E*E#A8*;&3(A,;D$VP2\6,U8
M7MO/9,WA];,#JQ/2:'B+"Y[=32Q^HYX;V^L[^,4DK39WA7N'5MR]3_#(U[@?
M70:^5EB&B=;9PQ.-SC['F+':*Y7/)GA_N*CL%K8=LSD+'S=T*\O.>>\6+"V#
MI,B<ZTS#\D_6NFWH5K'`^]#DBT8`4\9P#EZ:_'PZ)C>U$KR>IXTK7"C'"@]N
M\G/F&M&)?9<.#%T/#;$-SSV=MW@L'D8N(:EH)X./36[]TJKV8I_QPK=:F:DX
M@"R:\/A]9S&A:[[$9L?[P_7\I.VH6+_,<CRSL3N#A9$3%)'E6UNZ?3T-"B3Q
M\E&#6)"!R(.I\[95T'\#WG\"J'W1G>'+[&Q59;\PL(4'0!,[@TGVS?LB0'_J
MFVM6SAZYO:IE?2QIB,RHZ,@JCU24)Z9$N5&S5`'QG<2B\C!&RLLTM12;Y*BG
MM#75:]$BXLN#=N<$@@T+.;]CR2BY-/E2JEG0(;J$4YCXW"/$(/'BC(G.R$.)
MB=4@Q]!6H\E$]?Q[UK'R9END597W:&A%`[R9Z747;TE01.L#9I63IF(W,^FV
MNVX.PD)!V4(4(1.[J-H:L&8`/5T/+LE`WO#XN61WBO5^([4LRDB8Q<KV;^,8
MAOR"(G_C`%+Q"$/2`K,.M[HVGD!_&.$/SW9D[%9!%965G@$&V:#E(=4XQ,;W
M!D0JLLX]>5$'52@G#TZP-=C5QA[7=%_*[Z'W96D!Z27ED0HROD92-%=2'XY(
MUN,<+B#\?='QN-,"E92L?Z=/1.',(,]7C,H-FBLL.11O-YR85\F:4M<N`,F8
MT/<4D[AO]JHUC`&K-;N1>7W6^N3/TX:H!EPY.7@L*=(J1+X![_\R)OC/P.'R
M)U`SI=MXW:\<M)NVC'9'B/I[XN4/J=FLN&/#BTC&XL?Q8/+?XSR(9X5PW:;7
M32[5WHYMZSR3U:ZFM;Q@C1])0W*V=%P/B/7M,%5QP1:@#+'2M,G#`U"0\^WE
M1A:'SL8FL1A/W51!B'?OP&$BRD4\G[WG^P\Y/`/8G3ME0^-!],X61T^D#.1*
ML;X?V;+US`)ECRXKVO>>-Q]?X1SN_E+AKJX)/!Q91];B2<SV.47^*=0?N@7I
M"6L?F75:;/%@=9^MB"H9A-PCU>#=!'ZLTQ0+LG7>.VK.'#+L9H]!`E80Q=36
M<CM^6E0AI7&Y*Y/HA1^P4\'/@1WJM0OY7EC6"0N@N1:5"''CXY[H..4D5DA0
MTSVWZ0RX[0NV:64(2G0<@!Q!N#1=16QC!:@2A5(>5WB41PD;.]*HG[5V+7A.
MA,D.O@?3,ZX7X"FY5CVW>5`L<NFCJP;Q$Q8B1!AK=GZ`D"(RF%9<YM*"%-&Z
M[_+Z_H:"?T-D^B*S:WF/VK[7ZTQG?#+=MFW[9\QN,6;N7SD/OR`V]E_X:8T2
MW[R#^Q>NGR>6@=<%396R!<!L)PN`S,@N%D1O`%3G#KK0Q*&>W7F;K&.<+*;/
M3+&^O,A>G[4^DX6K:Y./;2JV[4H&4H@_2\"Y:C=#GQ"$<QU9[\)Y5OZ('@US
MKFMS&;6SCVUD/)$D+@AOKLRN>@";G-?M9E2B,@58/)0C]E+%^>7;RS>MCT?>
MQ;M?YP">RC&F;1KVSUX\!YVN?S\.ZR$`Q-U3),?P'A6/7K>L_XS?$<5EZ^?_
M&-!.!A`+>(RHZGD?F++#%B*/)53!\B!96164#AGZ3^,^RD!`PW?`YPE=CXO$
MYS-ACJX#B#F,+A_S'@T6<;B2RA"\C5=SH:WS%\]3N`_'4L`='W2$M47UL_.X
M)[SD]D)@DIDUM'U!QM*CO6N@DSW:%2#"/LR6M=#<H2DMT$/Q-,$[=%V8#BG`
M]IF-?U\5<G/-*XB0$M'3^ZZ`$G[&$%9_K/MRDX":!M(]]F;6J[X9WK_;+[>G
M%==+G.PO@,68..3N,U82>`:9B[GTKR:O19R"7_A"12=,8$QJE;K=;LU89]0I
M:2:U^N+#7HB@A&QE3=W\O-LT+1\9Z-4F!F+7$KDY^"$R&M]/S44C_D1%;IA[
M;$89=#DI6]M\#S$0;J?N;P"#R.;,A3!$I,[B(=P3@$?X&6Y!%XXDVSV%+^UJ
MQX/4EL#CCD4<ZBD@%$]:FWM@M7(K;\>>HIAN-F&7O"Y$72?9)RM/KA4Q$(.9
M*R\87P_A#J\^K*KI5"]0!->*]!R,X^M0_78$-F.Z'.Q[BM7)V*PR"$EP,:ME
M:3U=.A:1IZQ.AWBV7I*2E1""8OV@=GI8Q'+(AVE2G+NP:-7B[)+DQTQ>2Z"U
M!G9J]Q"CMJ=]F:WAI25G\5(*5/?U8F#.I<3>!&*F)IS*:-?`,C/KUP]V0YZ/
M",_`EGU$2)R+FM0+3$=!W+BO&DM8C.-XJ=CHET\N>R?/=6GY\IY,/*\P6*E_
MD:"BD+T:'\1H]T&2%^$@8;@LSB=8:B+NF.2,=%<XGF\A@DO'`-\,[]^:Z,6?
M]%+X!4<$=R^+1348?X0_'T3,?N$8_2L8/F$Q7R;DF]?%-*^Q(8S?M]8N"QLW
M;VW^N=UN\W_;31V5MG4-;4PM7-Q([7'\;/P03I;ZL@5'G')E9BNU[;&`9$P>
M&*\MP,YXW]MUKE8$ZCJW\A6AP!PQ56,:VT.J_O5[Z,^65#>8PR'PF[4*K$&4
M5R.2LE@@*X!(9@?7$#^7=<L``"``241!5`LS*E=80LF2[M<#9<Q>:84@)(IE
MMKXC%P&@]"9AZZU*DT(=[B!@P8W-_97]AMV/^SE\1@-!SI"2Q;P$D)A='T4@
M"Y7:-63H-.#E".WZ<$\*DQ:;!\$HNC4OO)I3F@"U>Z`28?'YS?KA==ZN4]"R
MHP6*IECVWX6$H%BA)_;B/'`7(!9@".D]"E"0KO<\AOC,Q!5S6S1MY%)Q/9'?
MCR%3DEH`:_!4'&Y.E0OZ>2^UZYHU6[9VM12@7J[S,*DGFMDEO&5]QRIBG7I5
MTTNY48*=;VF)MKT_*H:7F7+>MX2)1=4E*VHJQ*3-0G_MNI>L$#T06X_4@8IS
M+@^R8\SL>VCM[TOT/M5!/@"`4;C_5>P,9O86X_-H6&T?R/`K]/0C!OGQ^Z4`
M+*O:L5Z^=S_ZM=FBQ-)X1#RGB%`+`WKKU2>S>V[LQ>HC;-K0S2(E7*VD(Q=7
MA3AA3`SNQCW@X?D5_S%//[FSQAJ!D*U=\9M#-]B/2;OP9&^,U>3B0<YA,))E
MAF7YX"(SA.Q>$*W"'A2;>-()$>EK"!O04^N2_%-QY'6]LP&Z$@Q1LT0"$C96
M&M4&/8(3=NQM[SUYT3Y82@*[&!>3=;?>/^_VX_W'U,:VZ0*004V,"V[N=J3R
M!D5#PVW&@E3G<^-.B,NW-OHAB]55I!:-M9CJ5#'D,;9AS?<W:.7,D?>-.F'.
MRWMI7N>VNEPRQ(@\#"M>P$E?S!()U(4$Q?_R@BTI7+/(R<^36'*YCO!%284,
MR-'SJ&'>6*X2Q'SVL&1V'DQTD@BQ&PF>$$GQ4=3<]KQ%R;/>9]0UNSB`AHR7
M-CJ'>T=6%-66*`T-<L:13&C?/%]L0V?"QB^I2-TUC+,/^BCFR>V\XFD\,5P]
MB+^'UOZG,;P)['JR9C$K.@\EPQ@?_L+?*N&^)_J%KT2-E7'&_G@@K*CHXKFH
M7W$R7"<PV_O'PFK'K_/S"C"H/#E=VV['P2QE;M,R`$2HEI/4^OJ_+LV;<$VQ
M&TC33<`\MX2Y?94]B_?WK#O%^E[+X-G)@TH%Y%;S%$%<1A7O7`'&9E9Y^5(;
M._FP2]6T&U[<!#2$+^%B@*0;)B1-2L06&F>\:6!H`9,?*S<K!]]0>4$%[5"'
MR4!2/&]&MJ.JVS2+$S1])C?UX/6,U=INZR#?6K.W]W>N'LZ`%.=M-%A.7:"L
MM6;63C[.^AKJ<:RV,.*BEUH='K9XNV00ZEFJZH9A7];.X`QAH7E84(=P*B^L
MY15<R8^@@Z;I>YAZV`9KJ)$^-W[)]_`Z30S`C*&.7MG@A"^17[&4`U('@%$4
M](EF7VAC]Q@"+_-X.\H@H'G-23N[AB&;E=%CU_W1H;I8Z>!<?]41V`UG\.VA
MCJ:C:SF&NMRV7?V'5^"$)L6M0D+E0'.(%SE$PH,C#\3:AF<<(%:%O6.&DW2K
M)GET/^ZFY(+'U;LHS)F1[J8R!E1[G9?L(#DR(!$S$_A^:WC_OF#W%88WW3E"
MHOC39F>TO]DQ-$4$^_,P!7OLZ/`4XY;2G:+*>]&A`85Q+Z[%O^%D=\M*LFH/
M;O[[2OX;F#T)1N6Y7>>%AC2R8Y?..IGE:Q#%T`/7BE*2+SP8&F+C<P.GX7@1
MT[D6/NZ"N2,)#19X67_?JW*^,(;?=3589UE>2P^DLF>KMT?/@FWPL`PC;6SK
M=@75]CX//],ML_B`#@M5#+Q7%GJ:^62H>I+8+!HIO@&R<5?1K<)X7<?<6K/?
M_\__65*$>E<+05X\.6]VN]VL]WX./_'F9\'A%<$>RB%=V>CI&EOYPN)[\6RH
M\+B(IPU:U>B[%Z?>Q5MZ1L9<$A1-3$#L?KBN=6)O-MZ_=QH*TX$V3X$48=(T
M!+"D>\H7Z%U[6N5,4DV`>>GJB/@L3EVP^N2>%G>>UMK(Z#LR&1`]O'/B7=`Y
MSW-J$C@Q`7K</\=<3(BEWCV5EI2^ZWK/SD!PIHEN,<M6F1'O&BB>Y\W7`LQR
M))BE;IJ"_.AX8R'%T1^N;F+A[)!U8'4=:DO#Z#N]H?;.POH;7O[]?GT)[&[1
MHCW@XAXURE[[0=_6:O9K,@I[EIQ6)XY]K9"HC_=^'/64_R.<7E2?('-%E+TB
MDT59%XBZY2L1P+%-Q5(%&L:*EEG^P@7VQ#1L*X4"[+#?+<L+,"4B$UR`XC>K
M01@9UN5L>^SDS(E]^M+]X);`D;R/:TI4^HP'FW)Y#MTW1="F$;&#?IZ9<=\P
MX/X4;(<MGM!$L&5=?S<`3_+\W+-9V-Q3Z-T^/S[L_?W=O+5P+VRB(L-QW6XW
M^_GSYSR'IUQH%R"SO[VC$\!.LL,2A#[CG$=$<EB#?>/_RBX<S4NR8\I+L"`K
M5VTRW`5_P0^[*EJR_RNBY(B`LYL3@\\^Q)L[JFN7C,\]T$\-*@_A$9,;Y4?3
MS,U-T@*=$27)4YBI3A9K%W-IE)B'H@G`T>>(K:,1U1XFXQ3$Q_3+T/%3JE>*
MNOV]BW"]1AM?N//,E`XP#B_O9Z/$N8X%BE<,.I91!]:<I;+VL1M(5*MIPJ1*
M6)P4=)#.144RY$[6L$.S-)@X?O<->/^F#.\S:/(GE`$;IA=/Z&-L@&96MGX)
M=.S?QIYA7]\RN='V2)=;S4-'>49?"<;PN#HR\^K[\WM:DKD=O1<X7E/!A#VC
M65O.O>>6K3)53M/7F[N&&5/IEOIB(>B_3KHUA"EO"]Z4O<.`@P:T,K!(+@[2
M=KN^<9I:?U3#A[,)R]/(S.H"MB.U'^G'4G2E[=X$#WIQ]3^YOU!GX$G!2G(F
M_M*^C0)>WT99S96FI+9IEHL5RR$CYS1Y7_(69I\N?7HWLY\_?]K]..RW'[_9
MV]MM&[&;.DUC&.7V9LV;=>NF^0^J>8VZUD>.$GAXOK*.=EAX189Y.AW$Z^1+
M5<P^?4N??8'(;D&S3L]=:U*<Y5`(+;[YJ[3F,I#T*O4A=GFIQ7&M.TW97(_!
M)7Z>%W<*8N`C3]($DIP4*<SB]&'[ZZO.)BM8!T%GVM&M6;MD6%`I45QWN#N$
M$'EL[$%,K'GRL1V7'\4:=15QT)F:/@-;R+U<EIOLA%,%T\@*YL%UQ[2@@)EY
M5\E-3'*<<=R9W-U>+T]+FZ]B$1DKN"^`?.Y/2$(EI+8-OET:_EE@]W5$^ZP]
M*VP&,MA#Q;8^/31_"6%OWW_[]?"%V&":@">'`50,2[28PI-S#-OZ`X_!F6K*
M6;5/IW/![79;4^/$+;B=+=ZWVYNEV"`&"J'5RI/_G!K7&ODH^X8MW##6QBUF
MZ#VC8+?9[>TF`S.G]5B?`WJ!%$D,VOCO^X\?]O;V+OJO\C[QO;1$OIW73M5*
M''E('7+-<*]DXYZYFBWH+89V,M#RYV3PM`S2:>:2-RJ>Z34LN/Y/O:B]!";5
MIZ3[SQY;9X_[0=8`LMGJ@-WO=_O7O_YE/S\^5FI9#,-XX&GZ_N-'Z*Q`B]XP
MC;X#N^R%^V@YCFX3`]1'+VK(<>Q2N>@UD?%KMJ;8VP4D9@'!3XD7S'TUA?<<
MR"^@YB03L-(/M5_7;^0TX`)G4X5TY7N,P3]F=_5ZZ/M7Q6JP`DY:?4Y"8X_7
M23`VG\?(*XP,_L+,K5DO&J<>;TFO.WXHUBE.ZISV;>Z:Y&;5T-LJ+IR84U@S
MH%DT-%SWY7[=9XD.@W)Q6Z'J=C41@S\ZS`S-S-J6!$!B9D,JGUAK!L:6I6S!
M_YV]\V/'6:T.USG_9GC_9\+FK^D3-B`R!0>6Q;]GNN6K@+U@K5#1N2_@;FU)
M^Q:W\@,+3_"ZI@\+7;%3;.'4$?;^<F62&$(WN[V]6;M:I?W!9BNM2CPJ:HB1
M15S`O;QM/&:Z;A9--[=V.Q>3-<&NG+E[MKI:^WF8MF]-](SR3H%,<I<NXDMR
M`*ON@>$_6\5YFK(U#]/K'CP#,65+[\_H.>F3Q9/,#O.R*%G7@KY1\&G=/?[G
ML^(/"V[GB7HH\$[1I(%)CE(1/J86;+A.UJK;Q\\/,S/[\>/'.8BV._?!8/OM
M[2;2G+5?%^XDU8!E8L$:M7*S?C%&%H.UZ$6\Z^C3L`V66Y,A1`]LO`[]C.-2
M'FPQ89>WJT_"=SE26/!JE1&C8OAM:(9]?/]NQ@X`Y&G-6D]F)/F:G2.(;6I#
M![,_!Y'[:L>[C30S70,J/6X+]Y+X"8/6,3Z_U'7H_+[!=:")WEE9QTZLI_R9
MUM6I/>6+6XB0;\VG#1H<9*_)OKNA@WI=%R=MM.A>83(0FQHE[C*[X`@A%V'@
M3=<GX[N9ACQSG"^?<]'GF@[E>?/M?$"\1YUD9JR-YUAA'JYV7Z7&-^#]Q[&[
M>)X\'77CE8[4;.:B[R!P9;^%';CVU\'H]@/=]G(%/+?UQ1.L+S&>TY3=4B+#
M*WKF>!QM>OCZY<"@K6)6*74:%(G?X-9NI_W1T1?+!6U.>8A@%(K:-PR<)'DM
M<YIN736^`Z",10*F4:RQQAD;0#^VY5*ZL&,!+%C(SX_/S&B:BRZ\O*6#7=NS
M9\DC961Y$(ZGQV>Z,%FTN7%K]9(0M"8%CPQA>6S<5L"X"7"2X)*`0%EO79MN
M%.EL'MJ%PHA$4$1<EE?G)H!686L48#H!XLCX3Q!Q%5#=3M#[]O9F;[=&4]:9
M^1[O,32E;^]O]L'W4`"UR8ZK6ILX94N&W#866Y=?*ZS/P2^_G!O6L[B*IZ&!
M%>WVJC[,O)FWH(@$7<\9'XSE-A"`P0I[</T,T^<V+K+LA-,::83=$G`^P>4I
MJ6B^V-)&PVGK+#>^$2PJSQAHKV'`!;`Y)E?LT0A,J3?T^%A?`]Q\_=IY`&U#
M=+B3)1<OL9X+<%`DL\<!8KE978"K`M]37NL(WMJ>-[0%A,<U***LZ3K$8ES,
M-V`B(P')UIS<#Q(K-:5NL:.VBC5EFQE\5\FMEZ6F.']X(MZR,R']5.GHH`$8
MWX#W'P1V$^##'H"YVZ-&JV2@/Z7%9JYX_>&O\KJ%U5].*]O9++@^H(]=&+#O
M-7E@QF)["EZ1B18H`NJYS;4L'<=.:=U[7^/!`22.H9VC'P3@43"K9CQF#*6'
MDEXVWV/#7Y&IT6A+YPH,H`LJ!W4<]SL%0QBU0O-"Q>=2W79@_<QJ+:71I1]T
MNG5</B]K`,TLL0,UY2Y[1<"!GHV1U@*\Z7?N);V:(Y^!AB?)'R(.E<0V-W$>
MW;B=<*J93&2+=A#4?E4&2=0:5[NX:C$^&J22PHG`5K=NG_=/N]UNTU?(BT7"
M+_ND<2):NYGYIPR"LJZ3P6>Y,H$GQ-<U;>T$L/.\MV;6NU[WZX)X`MA(#8"3
MS>M4<#&C_T1;A5QL=^I$L-UD<R^'L1RK+:R?.;[K>._SWV;G93X[EQ6;$Q/9
M3Z#?K_3(U%]#8/7&^7+]_GQ.^^PD='4[(!`O##-?U;;\F-NEU8UL8)14U'N:
M6YA*DYCXRL+06QCDFR#84^B(K!E."6VF*8B>#-G<=NV/%4B$Y%GMR'L:RP-F
M,(H4&L5)$BLU?D:K==&I\*%C;71-P&YQ$)F'$Z">W1:WY*7M<;T<;/CU#M^`
M]V_R*T<TVI-V_`,PG+P^RP_4Z,,]SEPW]09M.($#/!@^BV![-)%5O[/Z(*O=
M2OZ8.RLR+^D^VT?$N;0$UX\C@9"HB<K,$)B4".]G!`3=1/T?#M$GJ])/O>,#
M6X+Q">_O[W;<#V(5D4#+\X20?54BFR@B%V17+',L7+PLNA"G,$8KC8"4$Q"N
M@%MT;8K#?<,)`F1(OR;_,\,7(*F<VS;;?NL^]9!AWR)[BM5FG<"&6*G4%JQ\
M0T5'H``R#EBR_=RP0_+@PRDZ0N@&Q=>G76"E42N?V6RY5]F?F^06PM)!HZ$]
M:C'C^N<*`M#[!%6R*T<FO@V-*.S`_0J(Z'IM8Q()3E3BHGD_@=[I@7H-FU'G
MXSS&*19-IQ!!9H-0Z$4WCJMIGL#,"*M8WQTVPB-1QF8CYKEID,2$&30DVIP>
M.P+;_73-&#*MCB5I.+M273UH+VF$NYNU$91#7N(M#S@ZRZ38_SC$^ZX@G=5A
M\F"BUZX!LW&]HF+?J:"*QK7G^6@%-7'V&?@)\P'..G(:+X5"Q'OU/*<0IX,)
MT$+LKGNP>70/`XBZ67A0;V^'D@TT-&J!E44`BUK$XO+1KCK&+M[CTOXIUKAZ
MXB)*UC0B1-_#*?:8B0BWJCM5=[B_`>\_A.%])I]-9MRH?0?B`-#YX&F6."HI
M@.W_/6&=EY09R";KD4]%Y.ZR)]HV`2UZZFPBTJ"I[^G?W4,>_(2NRII4$_)6
M%2"TH@R3;V:?FI_)9'BMM'G@@0L1ZV\I=O?]P!%64`(/-<P%SMW>W][MZ$?M
M3QO/-ZVH'C?@31?#V0K6%S]@M"F:YWM:._*P1P,<T@KVH6=SLFGC@D93SG8W
MO[=&LID%,JH\^=AB]X".D."BK6GP0*55K=^AT<,L8EJ*AW5?H+=BND7('!ZZ
M\5DMS$"WUF8R57H49_I1);FP%>'J7FJ]5P$5UK*..E>CLOZ;U\:7+&(`]^;Y
M')B)%,G#^I@R(DQ#&EPLWP((%]K>$S.'32V/'I,D1QO>+8H*]OL,K7%M#)>U
M"8*F/&-*)#S()];WFA9M'HNCDXD?'05$K6@XI^?:`TUYXU;Z!7XE^0S$&*9P
MF68KVN#J7"""+6X+M:5'MRP9C*AJ`.JEI\5RFFEY[6?/7C"*Z_T:2,O;1D]=
MJ77=.\]C>%S_(U.LPUQ`F#%PVO%)$SU?'U@'-V:@L\A>.WTMWG79AL_4*<@+
MH($M.EJN,I+\=GW&-^#]A\D9-JJ"O%ALMW5-2,H3CO5ZZ,%+D-.D[,$QV>/F
MW,-_\*H-6V!*WY&7W->`N`)NV-_,QF3VFS2^A33UI:DI\H]4IX`U]5R=(]EH
M*9D(VT??'TA$JFK82>]KJ2T9:_1;:V9#SE`PEH]NK#FP,C<`3SD'YR+:)LO3
M43'Z'MCY5G<@L`"+;@"#L.,#;=K%#`SP]-2?=CCDMQ'2IZ*VKHKJY7\?'J.G
M+IK/A%K".>NT.5``VM)VJ]T(O!KRD6+!17<;P5;V_\U#D7+,KIT'-R^9=@;^
M;V]OZ5Q%><[:E-O4O(_"M)/I_PE@002=)\=@?EZ&EEAEBUZG'8;[?'PN"K0J
M+JE0KFMMS'T-I5.\<@]KS60.!13X?(^TZ'C+[AUCQF!Z"N>!0Y;;C+]OK95[
MUV)Q&[G&%&WFXO15WT6(BTM7S>N[!\D70J6Q@%@7RG<6?];".HS)UJ88WHV'
MM9-.%)2PMU[CV66O8S*H[;IWQ4G%FZ1LPO8:]%'PS,&Y$,X3ATJ16W(Y94[6
MI06,YX^"97R:%E@+FC(C@L*YA/=#[:ZNX\C>N^M\<?<1X6?L.UKX[R-G>!7T
MO@0L']#!L</]+-4MM9#MN8X2+WZ/QS^+4$%F4+^56)2<-C:BAMTUR191\X'W
M/<['*]?.'S.WV*)%<I7P2L&U&V**0TH\N9Y9H-R&K;_5V^WM6KQ[9CA=%S4^
M-@%-O%@BWI,+YL?S-[TI*Y`5SG.GA9-9DEX4,^.%[=HB)>4G#8\Q"`X2HHWE
M4QGA:D%@0ZP6J(6*SO9?&HAQ#A\Z!7<@M/+#O1AUW>2>L/2#EN-C"SWPN%_;
ML-"RJ#,?S7OJ,1.XF6SJ:%N:VZTU>W]_)Z9Q#<,!.0_.F]MQOQKLQ,+WZP>Z
M6*+E[.S)[EX7X]X7>';WE.PFK&CLIKG/Q+?6&H5,:('2"RWI9,0'1BWT^.-U
M;.>$2Z)AZ,+F&PB$$#,J/LG"Q/G%CBT5Y1PFQ.)U.Q2`<-,#U,%S^<[Q-1J%
M/C]_0VL/$`U(OX_`8:.A2+^6MJ:R+G(G&,.#R2YK`BZDH;')Y-(Q=I(O=8X&
MAR#(^;/>7&0%AZE3B<KB-)Z:NW+\#(,&ECG6.M=HP4%G]"O]V=Y4[%:H61&X
M>D$O=XU`^Q?;W/)&UZAUEE8Z-O[?`O9-[K&QS7T#WG\(P_L,76:-S:9UA1JU
M1M#[3.JY_=<7$.\KC#+U4LM7Q>&,_9%YBL=*4_+1;NQ5Q)ZIDB>OJ36Y$':H
M/XR>M<#N,C.(V/R."WF9&N6VF]TJQOJ6=K4U:[=F_3CFQ'E:,3?:\#BW6RZH
M7*U[#AL0*[)=+0%MH?L#8D[E*DR">VTMXBJTV3&VT?>UBJKUT,QCR83'"%JK
M6WP.U4DO-0>T+1E;L0)\B..^-(;HO6!`8YJ3I2*""P%^@OLF&,7(!]C=[???
M?Y\L(M\/.^G+^([#&K!=K++:HOD$AR#]84SO8ANC="^Y">A>\@R]^X84@.</
M*&%A!C,P>)V@W&WJJ"MR9*JZ+G/4,3@VP'*W<)GBX*MGX`);`V[340*NK@K.
MT0)+;S_MOXQ;ZT@,*`I0(V=:R!=M?U?[)&BX:@W3J8W>&JZ\V&L$KVTG<!M^
MC6`.)V<&1RTS84]EP.C85_]C;46QN!P@KJT",@3YL&P`E?S0BP`0C]'MV<X.
MOF2"'"[C86_A!\"EZ,[=KU044EM,A(31>.:%;93=9W35S!M-3#3U;Q_>?P;8
M#7/\FK]NSQC.P(6\@&1S\Z'((Y?F?DPU>PVKEWBS^`>\P,`^>G]9'EY,OTK'
M]J)2(;O50]D(`@AQ0OA,)KL_>=B+]N&&=4Y`&S4QCJV/,L0WE$_L[=;.M+CC
M,`MI=4Z:7T<8:!0P6=O\NL<T(A[Z\+")>\G;JT4K@3Z.=)4""%I'0+>K.-`6
MK?C*QRJ:DC(`CE("?CX+C:K/DTD;KAO)*=98/:K:R$*ZDNM]Z%'"P$$*EB-F
M+093A(C=/B)C+^NB=OU,<P4F7`@,QX_W]_?3G2'<#RHY*+QNO=FMW>:6BMZ+
MH:[S_'1>#NF[-?ZL>"WIVGLL8H!A\&?3P.'\TWKR+P:[HUN_AL`&J,1@ND.W
MQ8JUN+FEZQB"7/,BZ6Y5C$UT4I!!9M?C9HF#1W`S-.!$++>@=]?6^A)R\*SB
M.8@66XJ>B]MY?ZXU3H>:V`WB/`\W#UIFDNK)O>_K`9O@',5V@2@M,!ERU0A<
M%XM!=,SGP^8`6W9S:9;7O=RPSW>*NW[/Z":L'38GPP1RO!@`7J1T>;#0M*RC
M,".$K%`K^GSJD9QM\*AH'T]4N!AN&KTGVMW`"GX#WO_RKU?E#*^PNWO6DELK
MXI"2GN*7HXAE*WT1>18?PA&C1MGLK]#!_DH"4VKB$,J*L8[025KUB;2G6@XE
MO[34%$[,STW]_OEI![`?I"ITROQO-QJ,LF1\OJKPW;'6S#@R?>XN]8+!K-UN
MAMY/_]W$OB$7+46-X46%+P[\)'<8S`SQ)93MGJ4<77(H!YMA4T\J]E#4KG9F
M?JXA&/8VA1CS^K2A`F\`LEB'P40M)0@TC6-&OF_%@FFUM=FB3%\?1#W0^]#I
MV0?4MDLLGWP%++2;&^>I*)8*>F#2%$_`0+&I[BX.'CS8_O[^?D8+E]/6C_[N
M],!^NS6[M3.V^[BOA"@,^[(+/+0!--%I,%+MLL:C@(<A+*<<HETHU]UEQ7$"
MTFM?=C'BCYVGP;9V`G8<F,#'X9NIA,EHN]FM@!T<J.(.<1OA]G#5O?!M@`=2
M0?\HS<YH3F(`;:](FE53"4WL#]KPXWRU9E?A8^<@6ABZY7N*M;0BZS$"T`2J
MF/EMY,*P;.I",@X-3`[V>/IW)P>2M:XTIV)&;,4HCCKVY0:#[G0DKEM@W2V!
M=KM0S%Q',L4SH6,=:1C5B3$6]Z=J3[^D'['`3`6/1=VV`F5O:H_Y#7C_Y@SO
MMKF]3=:R++H-FQFWG_W)<?@60'Z1*GZ8&`'5FX4!N6>?^9("P4M7:F4"0Q'A
MDA03!JHMGM[""8%0(@^UM=;FIE=OX+XI;'1#:;=;6J`,L&CNDD`Y?5YK;F]O
MRZS?]?])*V]\3KLUN]V:?7[>=8(Z;`ZH;+B*8H^-\>&T;!;:P*G4&S]WI?NT
MR""DX3&]:,Z@MCA'ISZXBN]UM3"C]G3TR6S.?KDCF,"2_=;XP!;:>BA"*D[P
MZ)8)-K?;-9U<W_,P:RWX+B]0-#Q#6]-VX#3#CX59"@Y!O.7+^&?^9M/^K)U`
M^<=OO]G;V]O#]3%W"LZU8N0T^)5:-7V!!]H%S&^^?L_I<621AZ(H\##-SZR_
M.'DT:I^V2P4+!2^W-@H'Y`X"69,"W>APISNQ#*FZBR3!66K#EZ.9V'&MI*WK
M?FFZ[CCYJXX\M#+Y4-KF+(E8LHT<P%"$';EO.G95##14YN,;P,\%<QMGOY<L
MB1`%`[QUD]0Z9K<M@4</H0Y4J%^DA`_J7S37];HLZ_P5U;:^#@Q3E^SL0Z>;
MK0^@O(**W"L=@$Y7B!6D;V0#._+*BY:7J_S'<[LH#..I'&7=>M@F)<)SI^Y<
M"]JTU;-O#>_?GOO=P]VG.1$HAY:VZ@;@A4]^#C"QBVY_$95B\P6]U!5X`B\[
M+:\7[$;EJ5LZ1'``4G1F$D4'N,^SC-T9B!*SP]/VN4V.Z<7I%.L\]&/N9F^W
MV[4QNM+/[/^(?=$R%IH?/WZ<P1''8??C6.;R`0S"8&_MS=[?W\?\Q6F?QL2%
M>^8G'Q12B=N:[6%;4^8A#$2&AZ!SU#X62LNQO`,9C%=TZQ>(9Z_?K%7FG((5
MPYD+NMF-QK(@,_=EHT93X_S:=KUP,3EF;(,'!'>"ZXNV,#U>#>OQZ1-+/P[]
M<)8[(!=?=.['\?51>KBVPE/7Q2"@5$`9LV`P^_';CPOLXF$G9T2N(GQ&'^"T
M-4,_@C89\SYE0+O8510=H^$PT=<=*INUBY-%!<I]#)%=@W=C>&Y%,NM=U\6W
M=XW].S>+?46QRG2\A4`MJ:=#*(T`O.@H@B!54UI05N"F+>=NN?`?/S-\D=W<
MEC0[)#]RQP'JJ#+^VYJ?7L%M1^VJ_`64_SZ>DS;L[H;&&X74K%U^P@X9W.7A
M+U#+?U@VQY6M7[[%LQ@OF6^)!E'=<,EO=?.;3[]DFT4KRS]\:;Q;2:'*=4V=
M@8E636=!"J_U%-/.!`Q_)F=/N"=WARE0\/".P8><W]_=MT"<N]CX9GC_SNSN
M"S(!?!64QA8:#9E@YV?P2,Y0D+15*M63XWO9MC?QL>.FQPOI6_%/7KSO$Q]D
M`D^E3_$8W,*&?0X/9N\]`.Q-`(&TT]94\LGNH?`&@0``(`!)1$%45BP^V6V1
MOC"BN.'Y.W[=;C<[CJZFY"0Q\;%I72W^S_M]V0XUW^J#'Y'^Z[V7=LW]M"&S
MOCQ<LU3<PR:^F$K^%"E2/-O@8'/"$1TM&&!$+;%I5#.N\\%:7?:<%FLQ,7&_
M!L2:%U\8#WR9=;#-K]2MBA)-UV=H@!\WC5(\<H-V3CJZ1<_-&(Z!1+R#BB1<
MFMTBL<IC<8IR75O7HE]#E'W]]+!CXJ$A4X>::0,G7>BH/70BYO-`8N^X"A@>
M"K(5,7QMWA%PN]3#'F0Z5$##YG!;_.P8UQPC>;?W##ATH\NP592MY/??4POQ
M.63G#"0_R;;D5]09F.=Z$@57$,;-0TL;A>2"UA9A\G$-5I+\@#I-$%!JY6";
M!#$UUWD"L094-AG,2(J<JRD6X%CQYBFA#LP>!\84LD^0E_%@3`MRR[AKY"P'
M&YVN$.%L^;SXUHA?_!5FLA[L\3Q)'+Z5`A<,ME$VB[F`Y_OC&_#^U\"N;1>(
M5PE@Q^L$:@)6+S*[3RPG4^&($MGLC_/EXTZI84A\+?S5-\ZQL/LR(4@<K/Z>
M`.Q^_\SZ-V3OTJ/WJ[W&U6@TBK')\JY-;3W,]_O]E$9LAES&AG5[>SL':@A@
MCV,\^F']H]O;VYNUUD[0R^P88NX-9HOH..XD`UDMN+ZK-F:Q$"TQR(.70!@\
ML!N10H277KS2L?>]6)FUEE8X%<@U*P:\TA`0>Y>.Q1K(=Q;K7JE%JW(9));7
M`DCEY#8`P;M8HTFK&UH:F5Z!(`]LI<F&N?R+NVB`2U!:Q%P[V46YF7W\_&F_
M__Y[Z0\M28O!20.AL.D==O_\5/#-15MQS22HQ!0H[ES*JV3,=K6L3Z;Y\LD5
MILMD*$R\59T]<?-6`&'^EZM#S<Q;"!:Q,MI;P6M/25<(PQ2\_@ZGB]@OB](7
M?@T/@(DF-UI_H6;<^3W6,74!B?/Y`6FEQWF@]#T&1_#`,)+O\=+:JKG7[,B@
MD`\%PV'P>@/D4!`\&5*1:3R3=%*'/G5%=%(`[E84).N[B>%(F#:>6G</\QJ>
MB3!W#_[3='112E(]830WTB4RV'.)-<^ID\]R=N.%?4L:_IN0-[2,O@+_[)F4
M]R5VM<`>+U+&+_*R#US+_"O'OA$05:&+.\"=90_8]'^?,\7Y^(E=V60SQ\E8
M1+<(0'LQ<1.FWQ_7]%`_>CK-;JZA9I<796MN_3@F*`.YB']^?EIKM^!/FA6D
M$T#A_.S!GF##O.E@?TC^TG%[1AN+48C?C0<\=U9J(>8:X*EAC?3D5C407":Z
M`E$%BM#)X2IL@J[QS@9OL!7+AFFU(8'80,TN$6G@E1AYT(0TM\XY^M=WY]9\
MTZ(O;,?&9PQ6FR;2F=F5(`!O=DRP=G[+C\]/>WM_OV0-7H+*5N3K.MV7GY^?
M]O'Q4X!6!29TW5A@:`!Q'>*#@"Y/NOOUO2U*(EH1I&#!TJP3F*@L)4.4<V2G
M=ZNI!':TJO`4^EX3[SP$L6PBQL0JZP*_PS=YN#Q(V1#<.2J'S&AL8H;BWO0%
MTM-R'],',<,T8HSQC!WOO6BM6W:F"!Z^<@]"C`57E*^9RH^"7UP:O-KMD="]
MP<468MV'+::BANC?L^@+:\+.E])4'ND(,?-SV)Q![ECWPK/FGF+N>:UTV_CC
M3R>:]2+94SCX(T5Y*_/LWX#WO_?KE]T9_@*8O0.D6[SG`8M]E4#]LZ#7OX:S
MG]/)_H7C]M)/MI(G[_+,/0!MM?JJ3VJ*KPW6<!M<K0^[N=T_/Q^RZN,]!V,K
M8,KRWMN/X_(+14&<LN>AAC;SL%]BI5V[#AY!35J0W;:B'>Y\.)[>@_-XB8'A
M#83/AP7F(_IAH@IS,-7BK?=UT@9>&?>2CE5+!'BC[3P,8AP!O!CBU7Y5L"4:
M5_K]<#*((1AN+L6##(U`.$C1KYNIARLNRS+608YC^/CX./V=FQ(!>U<`F^?M
M.`[[XX\_I)B3^[SW31=@W8,CJK9R&!"@:17HU="`1XLHM[`]4(["-J).E^/`
M"4$!V"QGV*SC'JZG6PZE0'`;@*D3QS0KB?[2>:U-FOH'A.9D_RD"UVRDV%W1
ML:Z=%?=L`"F-'M.9"9QO6/;[_'&O[X2-I#->H!`R<#6?*_32DO+\3Q?V$D2!
M.W)@1K0^5(<'S,AB`Y+]H[E-AY*=^,`#:+82?-=[SFBYL&PAMJAD$#"L8;',
M9Z]EL*=W]`/G(!'3(I&[#]^`][_%[WXU6>V%C?ME%/B%%VC,(QYAB)<!*K9,
MZ4N5PM?,?E&SO<]\'L1?T!?8?'2\`)[\G6_;BA73SIT^+UPK@G,^V2N%39I`
MM9NGMG2Z%B0JC#*1^P"\(1;5Q-2\6$JQ+Q(6@=%G"QC(I0.>I)5XT`D*^T;`
MR:-%&ES98;[N'!7JRK0A+.PRG`8(TYD86<=#$*=%PB-+%FVI<GN2K8QV*6_\
M>Z"P-+/H_;V&S]0X?_U,#['->G>@!+MF8PCR!#.M>6C+(TE+)MCMW?[UQQ]V
M]'ZET:%DB.61B68H-.P37^M7=/&,U@VALT!FE"2FV[-V/6[MB.X#%J0T(YVM
M]X<^['S.6PH36OIS#LQ8[?$Z[C6N(6L;N7ZVUW'9L6B7A&">HWX8^A/\M4-K
M&ZF0)&<%$3D0<.Q(@&AIO160/5K32WET7#--([;SN5TMI/CWR?[<BYF0Q'Y#
MUO@0T$;@T%*T]ECW^[#J._LJ6W*N3W(B%^6I\R3`&W(_I#V5.Z!"/$#TS3J>
M`EVQA!)>';YOP/MW9H'M1<NM+[VG/QZ`*1I7->'Y!,W^(@G[B'@ECL2V<8>Q
M];N)"_=@SQ:+`7CT"UQZT,?RAKAXUY(5O$"7X\'OW<(*&%MB'"]*';%JZ,XB
MQ"'TMS9(UX$3"][&Z5YY+=3#PE+-=G&),0TQI<Q\GS_?YQ=T2YF:IA;#H3HH
M3F4G4)ND)M>+^FZWA@9'"",KF[W3YH9T'^=:%8F%`C%+5EWG!YLVDD40Y'53
MKE(4(!S9B^C*!RS@"UR651'^N@SO50"W8J*YD`-.S>YQ')(*AZ)-B@=MFLH"
M3C?OQ^F'$?Q4TIOQS(^UA>%8Y=82[Q\SE0QXG'0/$2IQF&O^7NX_2`*@%(=A
M.C]JM9GQE6*SHRXV3!TH8RA&4N>4C.MR?^$!NWR_K/D'?5T7V\0D3`-*AE<=
M)&`AK;@>-C:.?L:#;E7VM>XD^9GGB+7Z-"<0D/_I+,'7P&H'B4<#C?,<=3P?
M"*=P'`0]^1"+>'$MTMQ/*DZ1A__B7A\F;M=0L(:"C,WP&_#^G5G@OY;:I6$H
M?[@9>F#-:I"\V0">V//B+ST7GA[G#'R)AQ3G+D\>B\RD9$G!`DJRT04@D`>-
M<ELN5>RAEQ.=)0#4H)W9JMWY"A9%TKX.H"!3+:X.`)3"HT-3=6N2'=OBY7)D
MDSB7V,J=["?$OLXU+PPK)/<YE]9FR!VV79A\8A@18S<+-AJ/6P%K\&B$(?`&
M3:`(RSJI`F-1(SW=`%**GVNK'W$8K=,]P<4&`8,`DJRQ_K3-B]QCGM(%:,?@
MR=!31A>!Y)Q@)E&S6WL[=SN.7G9_$(JEF)C'NL+J&>7[PZ^'B,'OL,DZKZ'/
M/\<"4[2N8:AF@N!HX0;LP3E0=H]V7JYIJ*RZESK2(*9X8/,SYL&KV&IM^4Z*
MHD5G69?J(S2'Z9I98=^EP'%('TQ8W/AL1V:X<M3T`,2RHGXPL:X9/1BNOW@A
MS!.+=K5&WZOE\UYT.2P,<1EJS3DGH4E!M>MM7L/$;'^W(WH6F$5<G=?R:GI!
M1?/LQ1[+][@X0*WV3$^?E./3S_5LW//?@/>_`V3_(CG#5W%OE0.!-$$@<#>W
M09^`Z:]8I;UZ[-H.-!./H>`5J"Q3K/01!C`JSUH7:Z^G(X549<NLF3.#5Y\M
M$1:DE9:65N?<>#I.Q\8%`ZG\KG+?M\H3CPDW+FTQ.5?!+S8S7!I+BGAX<3OR
M&(;B%(P7)LC%(6)Q7'.1=]49\@*:VMF6F<6G.ON=/6`,CH@QRDX;I<76'.E@
M'=-6H#+9-V+QT9?)?9H2?Q#>T`58@=:$E*^\7M]66WA<`U0]""P1`WNM%E\C
M/U,54$)D2Q^Q3RZL$T)!Y.(Z<`TIMBJYR1<8+L!$"L'0V2IA=)GUTZ+)E0$N
M'NK6VF33'Z_`JLN-4^V1^%A$A3^D$UP8XA%F`/&/%O_4I&L>UP.%)94626E/
M@=$ZH`;9PZM\M]:6$HD-"GV\AYUGM:/8DX9[AIEX`[C7Y8A\#H(_=B!.=ICA
MT;H$6^X2D>V7HZ=Y@FJ?%AUN@6&RES"1$&'FI'+!@!0WV#!G-MU]O"AL5H>H
MF+.1MSS/\S?@_;?_^@4J]M7W'>;M7Y#E;D&G>ZJRLIK/2HL'[%J&?Q&HK[YV
M[)!X$,I))&L!/KGR!^)$KHGGZM/V/&M#/5OQ6&0KW?,`G8`AS8S)<H(<8)`-
M'];6XIF32.C'I?BYSFG+[#ZJ<>*B/9;:<6:)*7#W\AZ,"^G:WW89\M?&VYH`
M]!45':R?@A>U"S#W&O06MD-^.4J\?*]#K9E2M'(8`(JRR524AMCF.6V^V1R=
MP)N39QZ25FXS8#0*+[C<=Q+'761))RD"K/109?LH\Y;LK8#3?[;WTVNW7=K:
M=FMFG^3%K"/S5WNW19YK:;0O_UF.'I;OZ]'7,W>'$@"`R@6RKG'9EG$8C17,
M,,S$DWJ%V9@,:ZUAV*B?Q^7#JJRO!4WMO"^\'M3URR]W!;%0%#R61S@70!U1
MXD`Z>*U$"R#J:<`6Q?I028#4[WE-\0L+BARFP39W'7&5(:>3D/L9]?]U!P9C
M/FTE-(:0!A=6UU\FRT"?P>[=+H-?%W`,@WY,(#CM?3MQM5_)(<ME(<,".+;M
M*$GB+.S4Q/E&/=+F]^M%N%;</^<],P#U=]+:?X3/_6O?RO_<^WK10GI\Y-A7
MR@43$)-2?OE0W4.$+^I<]P`:%]A1[91B>C\],V?;HZ\X4BBCJ2)8T\^)E\8C
MG@UZ5`^ZTJ19C`4X^>Q>D^U`,4!BD=3SHLD9=&A%:_C5"\8M^04&4KZPM,#G
MA*W8>=ED_9I[8HB3A5KP#N63U2Y0,6)JX\59802Z<33RZN16^PQ3"!NQT\_R
MHKLK!&K&R4?*J`*Z@B[V]"RP#C&FN-6?%]NB)0,6BB0QVXR=A<U`H;N5[<]G
M3'G5/I[(X#JF^_UNGQ\?=K_?Z3R<@2GO[^^Y10M]CLYZ`',8+MWFXNW*USJS
M;E%;7)Y7@Q0(*?2$NT*3J6>7D";.$K,P,:??IT-/K#,G9BVF6AGH<7O/:.!B
MT&U[+Y.<A8>E/!46(*!SI>4A.S)ZLF9#8`:]2@-/>XZ'),)S@"^V*L*]<!75
MGELUB[3WL!<E>5`\=Q'`8R8<CZ"3$;$]K;XN%PH%OC7_C`*4\@#>^C?2C'?M
MG,6I@59L`P+V.U8,>D<HPJCC5E0`PN_+^0X6;;'S%#JNL9#P8E!0[H7KW[\!
M[W\:_K[H,/"0%RYOQ*\DECU^+>(J^L([^Y\X)^[U.RQ?/Z5TW4V&FR)3NIB>
M,$$]8TV7E^/Y@#<[K(<$K%U++&/>2](HVC17X2P!DQID*O-V@2(?P-S-NZ_`
MBCHAV6;L:FGYX\N+DK2GL[@HZ,;HKPN>8G:RY`FO;7.J_1QJZKW+0-'POYR,
M;/Q\G)&<#";F<%21W3[N!P&OYF*^[`;KAQF\2QMOMK@]V`()U=.E"&J^)I<;
M'9N\=M.:%'_@6$NA"B*P(AW)I^:2"PB4[49DYMKB!'_V^%7S_K!VN=8U#*P'
MN,CK".LKN]Z7]-V.X]#!13M]HC\_/Z]X6I+XF-O]N-O]N`N#.B.[JX""N;7[
M8J;A$OPBVV80HD^1QJWI/>V<7*GN"L>54*B]\'7]D((D+F8W),(C>%*E03M@
M>JP.O^,Z30C*LO<E/I79I\T0*H;%EFMKG/67`)*'\&2)T2_0Z^*Z,/3L<_C4
M6.]MIM/W!3/)C+;<S]%DJVC-NZ7)WIGLYJEIP$GQP3D!P>M=Y2H#4;+["3]7
MDSGV('<9^U)LO2!M?_.[IEB0$9E\HMZYEK$,`Z`H7TD=/#_[,"3I#MM!"LPL
MQR*6YMD*AC:1:;X,+C41SB4PJ"Z="?Q>7^8;\/Y7@*Y_G?JL#?.^ZC+V&D@%
MV^3@(9`*F2OU`9%,:1<,JNQ>]*<,((?:?1TKZG,:<C>;7J!JG$6YZ1M]5/;G
MM`>VFAX%!A)#NK1M;MZ/@IGPH!OL@<%<(+5=WIU'+'9@8AX_-&VHV'`"1GTS
MK.ATS!8"*F;[U;/NE1<_;VV%!#BQ6)12UEJS6VO74(2RNO&8)Q/?NQC7S[/8
M%KMK5PL5MI@R'VQY,VL&Z[T1`*KUCJQUGA&7?GVWV_G=WOS-COMQ;F#B_\KV
M/.J$L(:DVOS)Y*\*)+G%O!9%7*D;.T#4/KD:7.!IV%&`G]?KP7BT&X&C/+#H
MH@&LUD!V&F#9R.?GW>[W^_R9-%0YP!!4.VFNS@WBM4J`I=%@GX4(4RLW82HP
MG!T%/#F9",L9Y%*M44N=&CW.PU(RJ+3.]:X5!]/`E^AM7;%\@';/8GM(\E\L
MVAE&_>QR(!@%8T>_0$]M1Q9E7"#@#:A'=?2J%6:>?HV_[ZR-IY78+_WGNE]J
MQY(4#L+`,W389QUL#/HT1&05M9`NP[KG+(6;-&_GVL5N0-$)@^Z`Y)IA>[M-
MUOISYT.&D;WJV)H,CT[&O*U[%5-6Z:+=]9!X,<,^6+[U9.B:Y0BZ;:NWNPE1
MA40>C3/W#7C_0[]\(Q!_!$>]&#;ZLY2J%_0J^]RAJGX?&JG;<_G"`T0^]AE.
MO'+'\K#<?"0H40HAR:QUT^G5TE.R3VBZ)J]1)\I)0IBMYLYU[CKO)B3FZB&B
M-+:\!ML\V!U`FS%`M][=R'TGM`HC\Q*;.28+5'(72)(,%R:X'WT._(`V$-:"
M=G0QGQ\3_&-E:]8,C8W_2=?85G\!@.'29BY&>AWS[7:[COV0?S=7IFHP)DL_
M>6Z*/F4L*@G@^^.\!AR=6K7'?24T`6:WDW3O1U_MR'Y*(H0@MA[:S4BLJH8@
M9/>,4>QA8U"<I0-9P+2.J9L.!(96,%F.Q<*Z0S?VO2T?RJ*+"Y_Y]E."=+WV
M.-8]:=IJY^-P\E]CJ#-LJSCA"^*A;,F**Y?P!.J:)V;UK)FN?_/Q9RO;S]5Z
M-M_?08I6WR^SE8\K%C,H1=M5^$N@A.W;_NQ9'9ECN8XMIL5Y8M6C[VQU[.(B
ML7$4T6)7]:;)`LSKS6C)&+*'<QD53[_ZICBT"^R*JP_O$X&T.&4M(>`F%&;#
M8YG)!5R=*;_D&,E&#;9G>J-3D*FG_'JNU!VF)9L.E1*TV+4,W0IK+A*>?(*=
MNDZVB1)W/0XM4:GH./^V&=>KD/JULS?V-^#]C\/>EXG<;,;\%2K8M[Z2BK8B
MBU-M6D6ZRXMX5I[!1Z7<9=;M#'YJ.=YJ3Y#1].@B#A*FFY5V4:R;:\R4@#9]
MBI"UT0HNHCZG83L@QU(-$+H8;[L.LTQ#^QB^=K(6L,,:6AA42@C<.`L]G3G/
MC%N<E':68Q`X/HXN6F.?PT0^Y14R2.!N1S\F2S>D!GVZ62RVE'5O`^SRYK=D
MUBY`>;!AWGSJWR;8[4@I5!UFM\$0C"A1CPR3%CR\^8_S=0L2C/.>/<,\G9G9
M9N8@#2:SQ4%*H9LHDF2\AP$Z<3&*;(CE0B_I"%TMN6;L*KE@K+FGD+;GGGHZ
M")Q0%5`P4J+FM1JA=EWY\.`1GP)4XH2WFZ]BTZD([?.;*/\)';3ABEMTF-V6
M'5-HQBVO5FB70W21U%@.0XHJX5?Y5/.VAM-,8Z"MT'@+F^:%"P14RB6G*@X6
M3<>%EH:6*I;8-P4.?VZU04393`S;D.(%!+)!X[<>.R9>LGK:+M?5;C##$9P:
M='!1.P:>&.?S9;QFY6N89$#&PY[J(K)>$]>"PM:-=]C!),/*GU;F?[@O=+E`
M+OKU@$6J6.W!K%X=&[]F9\QT2%#\%:A(]GA#R5"OR\"WA9^O/(2'+2#+?UOX
MN6_`^Q^5-#P>#$J1KR5RM&VO/32RD]^AC(I7+4M[5"6_$"?\@."5X1ND]>B%
M`3I,@7L,/-AI@'?.P:/:AGQW%.S!M;C&&1Y:#*&*_&L342T7;44A^E`MMRSX
M;^+"E-V[,$QS4]T(]6,KDJ41T<P^L[S+>BB!IP%V+U`Q6&F$Q+A^^:(.J<%P
M?#!$P+**AN,"O=1?7W("EH]<H+.U-L,,_`*9=FB;USP4?I7/*AO0@^ZN0GYB
ME[Z-V5#W7*)&@,"`S8M!)F[[5F$"**,):3!$?%PS(%KLG<:41@G$8G\6@S*[
M%$%XO.R$//1U-?K6R?JO%\!5PR<@3BJ5%[;($&;]%[RJT?4[\K7@YY(_JP>@
MC;P>:+O=Y+[1P<!(&%!W)\G07(8R-0A%P2XG/JH<HPBB4#&N,%W"!)XBGZF3
MG``2T#UDMZ;3M@+S8(#0M/MP$0*CJRYV?.9B!<GW#?>WSPY2LWBBHTT<2GTG
MGW.^_SD$I1Y"E+4")L-_@RQI=G6\N&B['$`X#$>2](:4B"4,I32E9K81`/J)
M9\OQ+@''7`2QEMB%T58]!RK`60ZD8B^O*-9_UCA(PN60`T7V+76]?$4Z$SF"
MP@#^&_#^Q\#N:\SNCHP%5*^Y%T&$-8WMQ:K7X@E(?8)FL<??"8SQ(H9,0.:*
M%=GX#/98H+Z`CJ4';`^DD6L!F7B&3(5&FK2:KB];U)?&.`[(],$2PPHM%0%@
MZ-3]SCAC:0Y79OK:.9#2TMRR]S)+/4!@V*9#P4$`(J:OG>W=!MAMZ&@=9MX%
ME,#;Q3+VM*#.Q6^<%RNL<N*DL8_%?$D=&LDBSJGB+N<R`@[V_M4G2;V)ESW3
M8.G[8J]OIV=J`^R8D@^67:1U6#<`<W'UT#`&TF+#,LB&RH7TQE!P%%NCT;Q@
M18=F)C`-NH7/5O#5Y\&P-":"22\&Z=+M3<?2"Z_DT]+,I>7J`GZ5<9N>PJZR
MH"5;XJ(HXBP(Z##S$%`0B(@B^HU!_<[^SZVX=Q;EM8KO.)E/0(*$59G]OP#9
M6M+4_JLP\=/SSCY>;FF@C64PJI\.MTUE$X;%TLT."%#%-$[I5AUZ$8MWEL_I
MM?2X-L;BMY'6V!9X;Y2\Z).M=SU<UWMP.!)XD/>(/A?9$VEY*:]YA"G[8&:G
MT,4`0@I/XF9VDN!JLP:304Q#[C#(F@/:\ZQ()4K^X"0Y"4%)\;6R#U,A5'EE
MK\[8>O]OP/MW`,0O_,#KRM^_YK/](?M<?,XK&<A;W=4C!OGQ$;HKNY1RZTNF
M]UJL0BKC9)'3GD'#>S1H-H=E2B/B3=ZDF5A@*8C8R$D":*]LR4*OV9)QMUCZ
MK*EUV0";YZ$HUL,.IC@$'I27;$H],"W'N'7.#@2LNS5;;3'05.[Z3JL5"1^.
M"6;'<>F49^)56YK73DQR[^<T..H0BL6<NB3R+9(3V1YR+,9CF$-LSER!&H-.
MV3!B]P?"T%8%=#F`P\!Y,^1FH46YTL)"=*HM-G]*]-K8U"OK*K^<`OI5Y#3J
MJ.1[^[&9?I"F(*1+E6#W`CR\>=-`3FSOFZM5&;.$ZE&*8+U7;=:!??7]`K2L
MJ5P9W(T%&#\O[=+[&Q=`YJL=Q!V(81L6F70>*"HT=#X$7]G.=X)-!H:=AI'4
M!<9DH-"#6P:OAQ8B<OE:J\RIA7L9<T"Y8K@K"SGW*A$S#N5IEW0X-C3WM'^-
MQZ$[0M%D,O`G81RRKU\#?[,`*>PD(^2EKN-DQKWL9TJG847ZPGB2HPJ8$AM,
MVB^Y(Y4?;">WB2C#"[:%T]J1GN?TO!`!@12>J7LOH.?;LH-#^X:;?PUP_,\!
MXR]J`?[4=W)ZW+U\']^V,'X!:<,V5:W>^#PXM5A,!1G3[NA!MB,S+XCGDX:W
M^+_33FM8_KB)4;U\/=:GC?=I'H;#3/6YR<(%84_2UI<SRV!>.%!8H6(I?<NT
M&0]4(3DD??`"P&3O9K$.0^'3.B>^N9&PIC^RA^S:&/ET#;#KWNQVNYU_OBS=
MAC74<1R7KA9UX`$JJ8,Z#_`Q^,[F*'97"HF(`AD/02@:9N!6IR[-`H6^PSS6
MZ,L+9>WX.R,"V.%L,=D336:+'8$E^4#FQ*>T05EYMZRO*Y]-%(F/$CNZ@E6\
M^34LB""W@$[B#WWV^$Z])P`=`>[XO!QSO+R+&[L/="@#2C[0XN<Z&?X%KAKY
M;Z_OKRU@]-,104W_6Q&B<,FHG%OJN_46V@GW/6%1I7!!PD@RZS#7P<)+M]Q]
M6A/9T_Q]I_,(MUJO2]'2S:<,0F<'HF6@;^Y$+*F/A>MZW<>LS^;[]Y1==25H
M/,]&>TA)2D-]PL:ZWH\6]BQA8O/Q5CLV2*8!C_,O:Y?OIMIZ&O<^_\W7Y_5K
M?>N@<VAUG#0_SW%?2<4OL_H2GF,)Y$O;%-]):[_.NOXW0+CO9`SX980;DX5C
MN[CRZ/RU\U1$7"8/Q06*4%`,[FSO`HUAO1;3%MG>,`F:)J51#*297Y99[7)A
MZ!-,<K#!:-5W/+#/<!KT:LW:'&3R)$^IVKHA_&S.]\H$A'G>P$RE`4`@40+S
MXGSN:1@O[W6%`'@[B^C"9L1V+V`90(3!I18VA=XY!<]2BIN`N<MU80#=#M!Q
M(-G"O>2_['JNJY8=Q'<YL.(78.P7V-'6:U_`N"/,BKD,QSQ<K[BHX$GKJ@T=
MSAW21=#^ITSA,_M'OL`YG**.C:T&87BMB<-3>28!U"Y'.I=.[*;+.6ZD\(%(
M2MA+EJT!JZAICBEF_V2WY1\>[VUX=@CH\IX>DB18LZSG):X#\OG\W"!VB;@-
MYMG2SHN..#)XY0[RB-WU(8-"I$F0$KD6$XW-/>!Z3:C058L^+8B]->NF(0SS
MF*"S&U6L-2BR7)T$5L):(^<0M,'^MJ5%O>Z7/@=D^Y2.)'<(6+GXE%(8+-B[
M%L@U"=:#Y9E![^&Z/1N&F3NF1=H,"PFA2IHFJA9R\L1%I94XNT"&0Y-:Q26Z
M*34OA?7UF/RZDFB'-,[\6\/[SX#37TDGKB8IGXD#*J&^F]@CK:$=/-8I#%',
M```@`$E$053R/N1LW'8UM"-J`FNP.V[L"7SL#"F8X-]OU\U^O6<;_IN7J?TN
M*9T>S-NM2<SM[78KVV)G*W@EXU37S6<@@BWC[*'K#`V6N*%.@!]]T9EA),WA
M9!^VFI/LJPLU!IW`N'=8[]"D4A`[UD$&YSEV>K!4$&W@6K%T=FY-)0]VKEW?
MK4]0$=+7BO;^^/O>,64;1^_6CRZ3T[SXWM[>3C#<#[G>]_M!@X3$Q#MGU&=T
MC-X-PV;.Z7O-F%@*4PF%22=H"(_`("=T)8#@=K6U"]MNM^2IH``IA&WP>K#S
M'F/0T$++TQ74"F`D3^<N\";\:FXAQX,\-]UDKL;4\LK<$RL^/**7;VN3`4F?
M&SM"?CG9FI&?JDA$;'A7+_U\'(8ULEAS.O#1:$T1JT5Z(@/?CCZ/UZ_SI:WR
MU?IN@[D3NR:U."3SP<M-@^*(8RA%B.OM\UH0L/55(`GPB?>$#6>,53A-D0BG
M9P:+,!A-Y3<7B[9D91<TRAQ,LF*GQ[GT$+H#,CT_?WNPU=<,(.FG21;X_/B4
MR:&3[Y<76);M^@JR83U/7`RM8[;@KNG.>N4E<1))UG4$G8#J>1N/S[]68-=C
MT/Z)E47_(^8<LG_Q/H]$UL2(J2P]B=U(YM1-"L)OP/OOAK;`0UCX$H[%J^^_
M)W6??DY8P#PDJ<#PIX,N+%2&NR/&0X88Y;!4C3;'XG]-(E=A"X4?ZW%TLRO5
M25K>)TDKD^G-W0X4:,`G]S//)P90+!C6_,6OR-U+BPJ#X>A2W?-$?1P/6)7R
M6N1J=GN!WL$$==G(5VK1'#[RP&2ZD>\G'4M3!S6IT-W29W0"6-W/H;?)E%RM
ML3'@U]&MH4UVK[,OL[L!QPG8>[=^\3WL'L#@]C`S\V.=AW8SV'VUW:[ADV%M
M!G(<&.>KHVOPBM.U'C1;MY1&%0>#%N[,C**QTP:"C^<87D$>).'4.KMFBRP9
MSK-0V>@:T[8;I)9Q``S2?:!BJI@8APS?.#END&>MY^;KV.P[%Y]ITM.K0+,+
MM-&@([H<FUK4/6B7D9T5""0QX.O#JBXV89#3[+*+6Q6Q.I[CKBWHP+*/9;S3
MFS;X>`+.SH&36=5UN7K'LO]RU8]+E(,3DTLQG4/&,><;`(G+'=[7,^:W.+U\
MS6<R8%L^Y6P%M@8K+2PPEQM.LCFCPFZ*8-K%N'<SM#@'E3>DH@LT"AV?QU*!
M.@RMBJ2%E6$W'@89H3:C:\A2Z:,.#6+@-:!7UG4&*3[<L\O/[)"@ZGA!&7KN
MM#UUNRB>'2OB@`7%HMZW^7-I+?70!1K__`UX_[:_=M5+!KMIP?P3H#H/1KFV
M%;`#L?GO\J3[;@.QF<V[EVBLH:LRE&(KG-C_%`<;G"$/^L`CY*Z?1.WM9+-B
M>S5)02S9>G5<3.-)2;!]Z.7KBA+TBO]JH(&`7%&O*?5+``&35B<[%)C%(;\S
ME`-,Z/+0B9TN"(.Y[ECL@`QPL5C-"U](4!$P0#8S=]VLWT`_HW?"`,#.>CWZ
M[F+;9=%\/N@,:9CO+'B6`\7P>FW%]/A@!D?(Q$KQZNL^M>CUS)/?H2TM.W],
M]XZ6?MIN!=GZQ!1&#RPA3/UY5_J;3RLW<<CB[R[3Y)9\8)/<H1H*(I#I1BSQ
M!`.7[C%;$DR_94V=(B:("@9IKY+7<@2K9I6FF9\95ZUS\N2ZI`K=I(LRA\HN
M;U:GEGB:3]\$`(EMW'6-9[<BI)>YHTQG0Z;E+[TS\1Q!VSH972]2*`5`!AO`
M3H\]==U//_/1M<E%MW:PL@,`^!X>W3)*M4,GMI?#$GCH=X*XKJPJFCC1B'O+
MS!"V`D!/3K20XU";W?<;I3C$A+]CLF5URQ38*5&;L0**O7T^,UT+;@_QHA+'
M':P,XU!@E)5MY4H(;AB>YP%@.Y*P#MG`!I`@#K'C&_#^!]G=/RUL>"H8."<I
M*6^ZO!F^0`5'X^LJU,!J5L1])\L(23N(#%$&TN="[OO#CC&T8804AI5B0Z]9
MZ6.P^YT6#13,[[7P=8?=:'!@3>)+')=,Z,]@!4KR<O:SH4V;<^GC$`0,FTA1
M2)(?H/I>^`J!P)0.L!2"V&"VT.)/)=;*'<MC5]@T2%);M/-"[$&/&#(H:S8_
MNYLU7^>K#[D%8-Z['39"W8;;0`C,\&67--F*$4QPV>]TT17Z%;=I%!MK<OPC
M\6ALC+VOXP()W4"QP5/^0>\Y6NM@*<'HHHOKNY.3A04[LFQ/QDSL!.P(LB5?
M4A2J-<^SWO-$#ZQ**RS6.GYF>K3;RG$5T5=SM:!=UA:6K/#GG0X@C0!XD&-X
M,1G^:-D#I'OAMG35/JE-3^R"NF0-O>0*'3G0$W6Q!%Y+GA#C@6>"6L?T1"ZP
M*ZU15J?64R@!Y)XQ8].$*4$-L:]CB''X;I_67[WP8%T+.=,DO/0N@)M;]WQ7
M(_BB-Y&24`$T+EG+MGJ`4J=+HF3DG]WX`9CKWQECKBQBSMI<@'JZ[B!,.\""
MQ1=2K#,HT9`#391H&-9^OF5*302((0F/O+4Y#EJ*=WGN=58#M=^A7.O2.*AR
MG"ALXZ*7OF?:FXKRS+BC8'>C)[G9MZ3AW\O1;MMCM@>D$<9N$\=JUC)IW'B#
M"!MEKL`*?T/+Z5Q6#$9]E:VNF`=F4>KOO5;BC:0PM#-,VLY)&11SXRU/V<;C
M'`NA&&+[&:>XHH);*97@0<`V4KO"6>J(UXP7`Y^^D9S"Y*83^BX;."W0*3XG
MWE6+E>U@0WTUZ,>E+3[/P<E>G>W,:POQ=FY0)#&>DH,B^0>RJ6P6Q6+A/3K.
M)+K+-8-X]S/Q:&Q:0Q8"S**#`10/TT6]Z7`E.-N\)S!I=E/FOO<RH6UU#*R,
M[38K.AHQSA,:A,&#4"-5S#Q[P^KCDB-D(2`(Z7Z)6LNHQ5W,>*_7-.=K-AAD
MRS(.!,LMK&EXMZJ0YG9P6]>.Y1Y44)1K;;14<MNW82]]YZG_U_"9.(!9M;.S
MH?\"ZIQZ=2;TM:`'!_G86I*&S"%'&6KS>OT=-E:LH[[BO34$I).7+25?V>HF
M=)(G*(!3/W-V3[\6SU7`#94/O=Y;(RE=+J1W>RJSR1)W+??J0O*:7(B9-NB7
M35VU-PI1064;!\A,3]W6-C*`T/4+@[.R'H+N(;9@XW"-X00A[*_0211VPJ0,
M_\[9]V&^WLMCIH&\YF4,-=LPRK6EYS-+.=:0*)(=XQJ:F_+`$)@1R9;$'E-P
MR[\-\'YESNI_'\/KTHQ[V7_VT0H;?T`8COB>:_Y=)E9#:^$1D,4S38.%!0_[
M=TF#*7@@M_#]YVD+!Z6^&20+&!Z<^\M#X\K4ZNSH9MUS@I6YRA`$$$.]V$/;
M%Q%RRWOX-237[#@@K>.A\V4F6H,M74#X^1Z'+*@#P(\A'F8<QN8W=7J7[4QK
M9JV]V>UF$_!*D&38,/K%<(]6V3GPUZ5=UII+*[>1ERN@+;;I==^O][M=@VYA
M\1U6<H.ANMQ*K^M8,/^QV)#"\V(4";`M&RQ,KTYIW?5>LJ017+&<P^-@&NJ6
MX/PF\%`6(J2]H7Q&G,B3JC7I&P]I965>6_<XO8T)WN9K((J'FY)/;-%%`&D'
M+;!GZ/T"'I=\2((9F`TE?CNT:7%I:^+S+*`.2OR>3&VSYK=9O,_(X)D^9J4[
M@"6IEI<[Q`#"H&=MVMN%YX.MR)J'EG6'Q5G;DTE=H'*&&0P'CN8J<PH^TS"S
M=O/IS\W7?%X#M[Q6L-W8==V8P*@*(,JZ$%87!@%7*L/1-61VO#RWY%6_X!0?
M'FW9G(C1'+<P&/(4=5]=77$0<[&<6Z:4E],(K6/NX>=GP(0KI<-RF.MO9Z%)
MWU4[$(%JX\(5&__>&26?]3"Q<([UY[@W.C#'NE-03@B$29K=I4^ZO+G/<_-O
M`[S?8/=E6X6'0/#Y.:YC!&,J$:J$JK%X/O`5U6-!`)6/0.ZN]5GH)ARFTT^Y
MW;XSVT\QH-9K"Q;HA*FA6^_+R#R$%5MA];U`3H?!NVR48!].*X*`W!-`&(QN
MG[Z=S`)KNP=AD6*1V@E*;;51J97)#&M;H^9+I[GHE2L'?NWD[^_OUEJS^_UN
MGY^?9%M&:YB9-6N&%I@KN>:G"P*S).=&V@FTQYOD9#[:K4T`<Y`DY'9KUMIM
M.F_TH]MA;JVMC7JPN6?ZV<WLLB9C,'O<[U-;.*0ONO&-[PB)__6+=A/&6%KO
M181F8$G&>W6R+!/;*'`\:96,ID^;>U7WHGA6/&P<5L1>J>+`0YL3P3Z.`RN<
MINJ[(1%%''/;)>`A^&D6>DE-F7(Y;PRL5.>(U'H5"KK4<#4:R+)":XB50,5@
MS]KI1SKN.[3IQ)#:]:8J>@2O9'2L.%T/&D=FW"U>,P]PRN<S8<04#N#26O"N
M[5W7:E?&;7G.0JVSPGTP<%KO*E:#:92V4<"$-U<_8%--^714`'1^(?E]%Z1"
M*J`*5M\U>8P+J9Z<:2VY3;CK@+?<X[XZ*G.@.0IQ@Z4[1.K#+&]7N5@QX*FR
M%,_A-VY21,Q';\JK0(4=ICO'++AHH(YM$3HSK(4'<%7P6R+;8M$K)5(*LZD&
M\8;4@:_/MZ3AWR=H>`'V8RM->(2-\81A577G0X5!T4Z-;^3+BV^3H/N8_=V!
M\^(%KD:-"30_8G87LKLRW7,H,<?R+B#69V@!F^K#6%NH3@IG2P^)/>\7@+M1
MR``#SJE3',WWH>/L/0PL.)EFP#X_[PNLL_42_-Q0PN!7!"6C[7Z_VK+IQ`W0
M>;N=VMCKG`Q90-).7IO-,73)?57];[>W2R^\;K3CZ!<3"V%\QV>(W=AUOL]$
M*;/WM[>IJ1MZV'$IWM_/S_KX^#D'`CV8LILO!X#[_9ZD#!^?GTMS?7TG-CI?
MU^4<%AK'?!R''?V8S#4$2'9**%L3\M%\RV'SWU*1V$&::]?0&4X-(X:/$\%Z
MI:V\[FM/_J5!AB"^SKJ6^#5HY^UJ65["3\!UE[VL@2RY4!!P:K:)C=9S50V_
M<E"#>3O9I/E>I\8T#42%_[^>P<46<;J:!9]P9ZLQJ`QL'$NG1:&'AM2Z%S++
MITXFB)),4]UO8!C)*8&E;'U:L05J;`+8Y2,>92^K'>W3P8%G(1+[#]4;\UJ&
MY&*AK77I:D@1TH)]ELD:RH7,(C**HH:*NI3"&?3=5?K?#!XJV$;^\UG(=W(]
M4&LYI^<+XC(>;#E#1'>,A?/YP%+*'UF>U011"%ZYY!ACHED$.E!IB+BS@;^!
M"MB'(T5S73^X4\G[E_BTQ[YR-.--*7=#D*%=5NF>!JMF_P:\_TYVU[\(=&7E
MV"L`9.(`6V9U_QEK:`$%JZ-='.1ALE>8:^S`L(?CK1;-0"\5\;QU2`"T317>
M,[4%K]?<[W=[>WO+BU@Z+='FIF+AV1-V`9/CZ.<&W/4H1N1NKS2E'%H0%S"8
M`)_>+XG"Y1;`QS/T:;WWDS%MM[E`,/O8G`:_+D#W\^?/.:@"D62<$HC/S\\%
MY*_SV8_#W-MDA^UB49><867>M]8NS]N['?V0>Q)7O[*UP][?W^8P6;_`X.?]
ML+>W;NUVNS;EGEK3DPTY:::+(8[WIK:2W<?Y"K?[Q98?UWD<U_5(8/?ZS-,W
MBX!G+I`TB2_:3/GV3A0C^=C*CVL/#6)::($FU[`'M7<7=JY/;VGVOF7-8!6B
MDIXN:.NT1[]6.6<19.@DMC#B<^"(@RE(S#7TV48>JE34#\NS.#B:,B%<6>(>
M8L;SZQ:+.*0"PW)/P9<F+P[W!W<_!^#<Q%>:@05;[JUDLJ!EG9+:X^R@$'@>
M,A.9]RJ3T5SN9?1P#S)+;2YZ3J.BC#6J'K341L6FQX),I`4R92':5S,/T<W$
M%KIM.Z*V>;Z$E)C^OZN3UFQ90'K1K5G=1T^Z8*&HC:VYVAPXM&`9Z6LS20`^
M)YFI_K4BV.9>4.7.>.RZD*^\1VF0Z^>$3&5/+:9X^KV,":VBQ:,I$A"^V;#:
M^PZ>^#=QN_XX.A&/L>X6YSZ32CR'HF-1IP8-=H#9GFJ&\1#LJO61/8:ZF?O=
M"`05Z\,>$-V;BCGGI]_O]T<7\QJD@)BI&ZK%8K&7X\^]]ZG?X[;E7*1"GZWZ
M7D8,%'\G&:SKR%/<X?L/OU/^,!0#@,=QV,?'1]*W`J=\XL>/]\GP+NWN1%-F
MMECBVZU=K&GQE=SM?AQV[WUNZ@+*S.SS_GD&?[!UU05J_OCYTW[[[;?%:`EX
M6:R3S_;?B/GD&VY-;7-\;IS]&DS7Y\>']>.VOC^TY79>BWP_8I.PE.=&\>#^
M#RX<^199(+]X2$L%0]6.J3HQGLOIV"I%,;@G=V)(#)M`L?>0/-:#'1/(0>!R
M2^G,)$6OWN'=BB#)*'34E"KHK<4&F&H-J;O`-FQRFIH7LJ/-AF[1<B_(F;KJ
MLF/!G*PDG0HXAAPL#\#2Y+H;13^[ZD9E4"W?FT#L$%6Z7GW6>4C1#07>HG,R
M-*"N]GF>&/+S&;Q-[>QE%4A#OG,0UWI)>B3P!R-`9<G59NXCQ!J#[1=CLJ*W
M*7GK/8!J&N/U:5-X77%IYU,*WF3R@XQH#G>9!-Q$*TM-7%Q?9A2_'4%LHPHZ
MT_15S#"66*]#SB%W:V@8K2IPN,CPM:9UH^2W.=A&<TBCH^$K<&489XSB[QOP
M_ML8WJ^\X!77V/T,+K[R064RUC9(J5B3/$V<[PZ"-?-X)-F@U-3D0N%5!?C$
M(NE1P`=>O%[7Y]YNM\EX]"NUZ]$YQS7UVSL$I%F`"VZNUDVHA^Q43I(C?6$(
M(%GE#-SB]]:V-\_]?K?;K5F'G<SMY3R`P*K=;C=S=_OX_"#]ZKJ!YO#$!?3O
MATNZ&AOS?GQ\GK*2$F!>W[?C2DL[$@`_CL/^^.-?R@P/OU(Q6;<);*II_20U
M<VUGLEO"T7&%6O32*JMZ<B.X1/EOV2$A@LRH.14#KR`=0M=84I=A&L^>G=.'
MM0*K!6J')>_-5&!B`S0C:'>63;"^$3,S20NB<Z/K,DWNPG[WZWZOG#C8[Y;U
MAFL01XOV*4]HMMA2EN>D>%^G@;DQ!!H8N!"%.EGG3BX3VF(H+H4.C+$952#X
MA66#N6A8,-CZP?JCIS;_:.O+Y'U@0FTXHVS65&8?^VR<(!,ZEUWA/"]QO:4]
MR"]@<S#P`\DG9I*86E]-KA<:N^VN<HAE)>;I'AG`K+%%6O.2*9[W)#/'=/_V
MN2]0C._0-),V9G:#Z)Z+T>6<\%C=/W$X4Z/("62&3A%WP:0X\&)>YCKVD1ZY
MW!!=TM\J1YYY,AM90*;"1-U^F&B$$NORZQOP_ML87CQF,+^&AU^*"'[AR+9Z
M@Y??,[1,++04(^`D:\N](@*/0;Z9;<\G$HN%&K'OV-^$SO4@>S_;YE/3VKK=
M/^_&D_L10"FPPZ;HL*)-EG^]O;V=^MO/>WH_3O*I(C-YZ*3Y2GUCFR&G@9:?
M/S\OQX6^.6]^#;9=/K=@<V]N<>OT/-LQ#9:F1[WX[CI?6LS/2W];=5)85VSA
MODS)5K%P"BR4,(:AU3C:I_>C+TWX]).&=N@HL$6'3CSYL1KEONN4-S0B]OK9
M9D%J`)--/)U;5Q>6`1B-Y"-C"`:2X.9J<<>,5BA*MP6@:8B#:,Q=/:,1>Y&^
MXJ4GC@B%`3LD1#_BY=2DK6S^$`_ZT!YL`->Y#T6,N0@SV=^8"US66H,8R_BX
M=TJHZ@,(1F`2GI&RB*!A(E<"C_Y[@7!?5:H,7'H(!GD$3#;/[LX_N56>[=>%
MZ&05-L!\/T"'2:XY1FG"&'*"(*T>-@YGX._9>1_:3Y^8:A;<XIO;+T:6W`\<
M%#,!K.^S(GY.S^^XXW;,ECHG/=Z\"1B>;]N,Y#EJF.PQR=`VNF-C&R\7B\)2
MJD'%S)*U0&*2/?@3\^,Z9%[#+E`U\6[-R*6#"N:IJT84S/MI1L'9':[,NQ<X
MHL6N#)1M_@:\_V&&]ZM@5<VJ_$^]WWS^_R(07B%?%"@3"3UH]?WL*$J;(WLA
MJ#D85-?M6P7S4:L\!I.6%1*!APV>93V:>>Q2KXWT]G:SYLT^/C[40W31NZ=-
M4!'1JQ_)BZ!IVIC3SUS:P0X&6PMD'5,+',WOKY]W,S2?4;H]=`&520_M6&(U
MHC'\'#_PH+_R!>C[<:0$*K",P6Q:IIDDS/W_['W9EB/)K23@$5RR6IK__\Y1
M=V62C'#,@V^&Q8-D5;?NS)GL>_I*JLHD8W4W&`QF0>N9M1;,,G]VDKY?+0#5
MV)H4$Z;2!YBB(LT6AF!'U9@,!!C"UDV@M6LU^R83[VHY>G^MU1:<A]1.9385
M92^:T,0P8GD1//=-/0]`1]8&*KO0$W1?R(1:9Z'4;!5S87(SCL6V5K5HQE.`
M6FP:V#*XI9TOV(W*CR%117=UL&NCEI,*\,CH;*">L6$IH*S/1&@WX,5*G=HU
M;>SBWF0@8A6>0EF:/I_[D&S_KNK,HGUK:W`&$R4I5F4:7.GS:9K\]AQ;ZS`+
MLB2<RS#6<#*<)-!1`L.*Q!I4\XPP00<'40.1:#W8W_0,H,JIU^J[(:Q8X52U
MV(F0787E%43SB;0?;<[:*4/)W)3E@N[T!!F-_<+@L1%JCEV$T_#C9DW1UBTH
MJ?V14?Z`99&TG)_D%B`6`@"N?;S)`%0RC2TVD8%]X)7\!HS1U4HQ4PL=_DY:
M^^^!W5_U)8YUL.^SP\SIJ8?M$U(W8*AP_9]Y]TZ`;M0*,5CI)?E&T":VK?WX
M5_B8\:4CV4!P?FKP0B]0*54'!&!]4DJTI&6T+W-6UBIHH20'>@QK\J\C)D6W
MLZ4,JKCG0X\0.Y8491B#==7/P[R%.6_Y,[!XPQW-M-X2TWW;ZD#36,1S!;36
MW%Y5_X$V;-:%<790_0>?Y\(+!2R>$?!.OQL&5VR<+#(S(CSM)O7U!9*>$D,R
MFY4CA%TH]BU+,_E.=O-OSUK[Z\Q*"]TC>0$HM59\1ELE?(_R`+G-O[2YG'#K
M2/36+KLB`:D?L;QN)N<[[&0EH$W6PU[(Q@Z1=F/#.(@&9O)%;Z@U`+F`[FK-
MNUOMSW<:PZV6B<W*U<%V'NR0G)Y@["R=:KV#IZO1A*([@=:9LQIB:LX>S:4E
M0\&&Q9&HXE>4SZT>]@JL('N`!"MO^0:VU``=:1<$YN&Z(2%W@L60#08ARHS%
MCVBW`_2WY=%UX$1J8+,/`:;A#-/#0M0Y&;*&6=OU$:G44#%Z+N:C/=V$19E.
MBK?.9+?>)8*!<2,5P@=9=0_`6UFUB`D+T@'*21$E8FM1=2K?MF3_32#\NMC@
M\/?D5[Z3V5G<RHN?A[HFF3*CT?$+S6,UY(AD'<?XK$J0-ZZH_'KQ$9TW!^`:
M;6N<N7;5I#7[L+SO)(O06AT(2+*1@@R63`+;(B:>WZ_)-=WSW@?(T!Y(V#C_
MX#-B/'?'0)(!QB&S$EQ'8[ZA6NC6\8G:0.'0S.B4'=)^DB1Q@1-8#T6F7=X!
M(]*I!EXHV"ZD@XW`LJO8&9&#]T_IY2C\[ZK%3J(`,N-&;:E[1DWC&(:QGX'2
MB-[8;6R>8)'"A\6E+H+$L/P:Q&-G93@KB'(5404*D],?NV)%Z<EYKKLFWS/M
M<@?1[@`VE<X5>!!-CL-Q"("R2DT[6B9!$F7BHK&'(E*`0%U:BJ68""UI`7:[
MW?6L])L2#$Z*ZL:)]@0F/^#70"W#D&]/VZI%/K%+].U$039%H'E<APS$='ST
M]8B[,/;O$!"J_B2+BN:-.R?2H[L9>_7@5<P)Y!HJ^MW8$2K_6!IDB+?05=U:
M9IV-AL4_*4_A%O)BDUB]+EV`=7+.+ZEV%$Q7;I`GY0IVC3US^#X-!8/4>XZ)
MA*13Z+%;B?,-(EK/3OKWQ-0TWX#WOP!T^0E@DU_]X!=`]`!G,*'^QL='.MGG
M:-TOC*ZRXY@!-EVYY\W9@[^:Q+RK7\.78E30XC_#X%MA$_C!@7-#GW@M7D?.
M7*I[A<H4[*@DMV"8R)*_/&4PBPZV,T[93.0+F;::OY9M\TI]*E?")UU>Z'P4
MB[1$N>IA+=#U;/T\5(5IR$V8FX?NF/)V9OC,3]_/Z!E@9O\\"JL6H9I6M]PX
MP\\SE7ZQ,,3&^O;<:"D*;!"LNR/&O@^U<[HB'=/TZ#F-+*/`AN+\:T$*PR"?
MT9NQMM92Q438,?*/6S1@AJ$9:EB+Q\0KAGFH]\=&GRHC^RI!$(&-WW:OM(0)
M-<PXO:[LWGJ'(@WVS;GW8.\VJ;CD!BQPZ)7`ABGJ4""QT4YC!_LSKD7O8&_M
M&D;*DU>9^#LLCCIS5JPZ=L-R!N!D"O9LWN$"D).R=+3OJ@.+$VUS@H%%IUM5
MOL8XRLFN*^"BL"D&GZHS(%[*P7V&`BK^9HU':"M'PSF$(.C!@/P^W$AC6$ZL
M9SRA?S01R2@@0[M+]U2*UDX32H;8V3'JC=4/E27H8F`'+KJ'/)%;::"LV5L%
M\E7Q-IZ_]`U)_]E_IGCLMZ/HY(58"QW'*R)O?Z^V(XE#)6)MJ83RAM;.89H;
M@/;<!C[B6)]]=TSI3ET@9')5.?A(3,7A^"`46!4(C;!_=LAT"^W&G0`GV$V3
M31WFT92T<P0(V%V+A=I!Y9S5."\.8?06Z(&L9T@'TQB,".\;9JFK3&;UD'!B
M8']:E'+JD<+DKIP^*39R!OM8#B!DZ`-UU+JMBAOD8&A!&@"(J;4_;2M8E!;3
M&N:W27Y\6"!!KKD>,,&_3%1;I\*#D>J;G_I9V%A`=\Z)]>:?]'T3>^Z&33\:
M>`K+9;&R)!XL7+-0ZN\&0_I7E`3&YMVH)Y=J2`5!6AYTM#)XK*)<M'UN2B,I
MCQ/W"?G<+:%$,7B-:45&,XL>#E(%`SR/+J;:^=R%@7D#(/60AJS7'X)!N@JX
M>P=(:2M['P`8\M9=&&LZODMB_P_CV>U.QMI!R`WWX8"J"<#(""PG^F"[MK+Q
M@(TZ1+W0R7[_E*..J'A)73]_F1,<7>)4UZYA<:E#A7H7D731B=:5&>P!;7%D
M?=_=[FE_GKR_+R<.KZUV)QIM.SWW0-7)Y^!:!-W!IQ@*YR'LH,VWAO=O9G/?
MT<<>#"&]PA._A5N%7@2[4)5A)1UI&VVU2Q0.K+D%*&KQJN`%#K7&,MT5HS(`
M1SOIZ2*E&=K7KP]'_30``"``241!5&T/\)C@8VL^KQAFUEZ>L_)EK^EH[MF"
M*,O3>J+'_>XZWO9BA;I5:_Q]Z%E,.GG-3/1KH'K\)*=NVQ27A\KI@BWSSB[!
M:&RR[,SK)>J;=Y8H<)/H"8-".3>F1F_DE,DQ9*EW#44;]JMQ>?->@>::32M!
M#6$`PSE^3((`!#:L_-@466<)J[&7[M8A09(6Z_09RR`YJT++"-EH;,NZ3H$#
MM,VS9K`;JS584_!:-FV9/D376$%;T#1=*_/\@67]CJ1D`A-(AZ:PD0:@UV_S
MY<ZJ8R-J\"T,MC$2`UNLJ8A;4^HIQK0&)K!EC]OJ;P9H)1`A(V-("L3J:]BZ
M0=DXO[`))M!M>/@9?,\3=VVK7:#23$X27!\-3/6EQ5<M,<PGL#DV=(Q@#L:O
MN<<VV_U0L9C6]<BTU*)TM[EC1M70VTY1(#O1O\\!Z<0^'I@]B<NFJU`.W;09
M.M.A6ZQ=XB+BKE^XAUC)#P62!P"W6J?=FR;?__P_@J;?8F656YC("WRP[8WK
M.,40"K*#MV2=%X0P,E9\C*Q)&9NX_T[!KCBNC7M4)]/SCTHIT;HN(9CU]*0!
MSS(TG*R).\+I5_Q$)!`3\R'"5D$3''/[B<OQE\2Q(':Z,EGKNM+E?%8?[@V_
MX^=DM(`+XWR_W=4F.;MRO7V6DAJN&FQO`C9'3$M?LY!SQGT\!.?3B3X^KG0^
MG^EZO:KV'0/HY!HE[1E=V^[3&V'B(L-@9M=]4+04)V(N#'9B#U#'=1TL'IOB
M$*UTRE_J_RXUSI=)^_8@0]L&NKK;165IL2^HBZ[F6I#@V@_)2-^(&K"OW]>&
MMCCLUK#;Z(O%'[M.3F-4V8`4,G9>VA9)'!N.H"<;?^9G;+-(D-(HNKA2:Q9*
M+DSKO-_8/JY?/B2!QS!#>W<$,@L\#Y$VW%]?_7>PUJ#7JAWX<JRWN'>W=SB2
MD:RPV5MX#+KU"?_!-18M<=!U<VN.D'LOL5CBH%C!XC]:W^G)<XG7S2C(M%9<
MK-N,J"4(?9#UH7AW#?T^L6OS,_,A053^,Q]BA'3446&?]!8%0)#,W&CFG41F
MW:T@,=_!("VROL[!M9X=&T^M'X/WHS5TOI'D?QV/$KT`Q-R0F'D1^(6/%6A7
MO<H.]U:$#4L(DL7B8353KT(;J@0R9/>O>VE$3R_Y%#8/N*.7SOYMV`')4D'C
M:BQ/2/O_J8_C&']Q7`W82,W"!J8.4L?T.5YZ,T&O]@*&UF!AAI9U&94T;&:<
MF)8TSD^=BJ&$#=\Y;3.C;V6[8NVS[>">&X9H+58I(18-0*)\04D9FH<P>`8S
MDXX9;?Z,*=&ZGNARN<0`QMQ'ALH?V0X$>PI$HNM&2N;9L@WU<2\0)#:@5P!L
M)DR_$#6U3/WG"%KPC!0EXX0==XF#`FA]>@8MBD1=3[U1^2JO'7\##XF3LVY#
M^8@N-+BSV0U(XW,@L!LQ%A1&8Z&N:[5_8LL*DM;N]F&WH%6+K6*UGL&$;B21
M;JQ=SN(`HY9O)-45L]?;#E^-`!8F=#Z)PDV0A12U9O!A:QJ+U!)W+OY=!7"@
M`1ZVC(V%&+/IT+&75D4A)(%[A6)Z@W0PKP?7Z6Y6`]KVESSK^C@&&.^/J-0Q
M79R;8U;QQ:(`M&9@)]I9UFX_6%!A,:6?AR@-D572(>J3V0Z;VB&Z"3`F9O5,
M,^B?27FADRL8<)]UQ!LKA=]+A:CH_S<&`QGL$MO^9Z1NUL/\^Y_?^&=63,D3
M,O4HQEY!VV<M_H._>UTY1V&4I%"@;3UL_XOA#`$(M)=8]'\/_U4-/\.LADX3
M1C]H:.#(J+JD@6U%&G`ZT;*D:N'6V+"YS=H1;\Y<K<A2LJ:%)4&&J#HF<`&K
MB=M>IQ@XG]&&5F1%R[;M&RUIH65=H85&/2R#:P(2*6#"@59+YNU4\C9)7*_1
M:#&6YR<!HZLV%6C][?M.0D*GTXG2DIRFM'R&\8:$A1N%E6A]U8YMJT$5%HBX
M#=<^0PQZ6VG?ELJ_G"@M/!9^*_D`\#F`1%*,BXC6(>-P5VO1E^GZ5+62-4(4
MD]D,B&O/:GMNH1(9FP&/WR7F<+6Q/M78.E:2$J:@0!G/&QV\,;V@@&*&3$&1
MR18T[3H"&\W'G04BJZ./V2]F;R0M!I`[T%F+GAG;(0+M?6:]7O6B.A$.`#*Q
M9L;Z"295B![KH`6LU0Q8A=_#]Q-M`#$V'24CN46(HT^R\](-&-/^7NIUM,<O
M!_'6*DB&/+A.M6BR?RXY*UE--I[`S1=;`B#5W$#09WM8Z/FB.?Q^$A=O&S\>
MXYVQ$@O[;G(@8>`#QK=W[GK%@H2):(:V^W]G\[[XM1ZO<19Q'N51T9`E^!FP
MK^@22R-/."I,O(VB(=4,R89_WC3-WQK>OXWA?1J#\-[GS8"HO/I[<0M<#GCA
MF6-`L]121W7DCA`QO6\<[[,_9]OJDMEW'UQ3V#$;"["DI;*.U'5V#53:2E]H
M(MX%AN)T6KON==LW2,TI+^#V**EFJ<;USIXK9O19)9/41?1X;/WX$]@!49U\
MWO>]_*O8=*W==*6*!3_D9:+8QF,^9M.1K6C?>;O=:%W6GB8W[H=`.WJX7_06
MO=%O,SRG5,'TWI]97X@(##8H4W_TC)_I8<2D#-5C2CKGR0`4KHX<3=O)+@Z8
M,=6,T?Q>C(1"^ZTV<).@D.'`6JII@06TD>AL,3Z[`+7.8*N6^AAXZ@!^=GW5
MAMV.35MO)4IJ((^E64%19V,$?'W1)4.BYQ=3S\RY=S#@)NZ-7ZNSI=&A#?X]
M&?*#7+M%RFL<V]@8.`#.(NB.,>HC#M9^G5B6JQ^V_FOK36HFWOMSR(ZX8-#)
M]FL;^/9BU'!C[I3[1<3P'>T\1H_?UH!H2<R2BR[81-,.5EA,&YW#W0A9Z4@3
MBT-G4>KM40&BF/[ZSBBWE0YZ]7O3[>F"8TR!#AD+F.&-/E;8,506D!K6P0*U
MM/(L"*H=G[@UB7&-,>\*V[;PQ(A'PCW0ON>&*<9N4]P7_K8E^Q^5,[P$BDWI
M2VSR$U_Y?'D!),,"[$IN[4$8RR8<QZ4!LG&_>38<-DT$UOM(>##*<]2L=%IK
MK#>\P@AL1#OY$`:3'1Q>4_-^Y2ST>&R=(;%#2VUQVK:=>-^=O9@:+A7C:0QY
MYVVQV1X;$>\Z$4ZT9"3#<``!8,)VW.S9T"UT%_=P^%*(NZ<E!8N("KN>O;65
M.&"?U8!+WQ"[7W.Q7>/[O5YOD.4$;)0VUP`@SNAE#-I`PX(PPW!&NWZL-S33
M*P=7!JH):I%#.AC6DX_(C$(PQGO;``L%@QUF@$Z`_14`Q2G5@H-4Z$8'/C"$
MD[-,NQL<&%CUUFA*-3JW`OTJ$2@XIH*H7MRFYNQ5P3BT56%(*\'&3<SSS9+T
M\!86;(,1'.=80"B'K6<R6N)D?'6=?AGTT(UQ8D;)1!P7FS,ZEIB<NPD.L)\7
M=1Q&=UC&.M7N#ZP7X]G-CF7$ZQ:&7^":@P#5%)0:O[#J,@VO5NX%!?J4XS5E
M$YC`6H_B<1#<HVR94O7N6?D2F\)/]_MZ$B#(2$A:HAH^E[B6EH(I0\PWREY0
M&J>BH864)9I:@GM!I;V3=;`#JV[`\$X>!6]6NFR<$X)XZOJN^&13T5(A>!<B
M#W<*(N35WOFD>RTJS$>36]^`]Y^4.1R!NE])D.#G/_8T3C0\SKE_*O&OI\0=
M`<)7"@`YNJ#\[,0\JIY98+H6/EH1!9_+?/"5`"2;PP*1&6I#!D"&.[(+85#'
M+13:WO;)<#)60Q04+S6J=G)?G,&X+8B,9(2.$N`DMI(3TSYELK&CVHS`M0WK
M[R9(*D+PL>^[ES$XYH8]YS%N"(!?D^861>@R.T8!-T3&"6X>N=.L&/+J/TIV
M*%H;OY=]0EP+43-:8]`LBS>>QAAB)HR*C4SD85_OK%X*F2\=.L"F8-'GTP$T
M@)Z$N#_1P0`<NXG^I!A:5J#)L9+&_DML`8=>N@P1X5`DIGJO/)CVH21*CPT.
M.`48S!,<NTY8/;=RV%'$XH=#`,#>ASQ(X+/^L)APH)9?\"=6$B.CZVS%>W%L
MR,8*,9``P"N;P`-8V7+5^YNZ?W!6]Z@_URUBW"8:-J"'T>0M%`0D#EI2T)PU
MRKO<GK0]9R4-P=1%>WWV#&QM7]/;^R_PS(@O@(S.M]V[C%T[GMUS=-,9&MP<
M,-^Z2"%+7XWH]"S&QI"5.<-8SUB1*D6N)6J]:]>6>0Z6<`!3.8X81KP=2L94
MSGH-O@'OW\/QOOZG\@(8_@TZ60[0[S%P%1]ETSXGA=,%TS0MGJ#P5T`^/P/N
M_'HJG>MGB/S&W400>7Q_(BPNP2^S>R;80021J`7D!\&8M"T1B?C:8&;596&<
M*03XK4).#IG>OB$(A>U#(E+&\.%S):3.$<$?#B,UEBI:1>VD/]G0!!/F8$_)
M6D@5P_P\!@.MK18Y1QT-$%NRF;'PL5/WX7.L)J*M=9MF7V9)='I89[QD&9ZI
M+HM`8!1H"T<0DI4>(.#G$8#"I(($^L`7LI.IB!P&D`&M)P_IA-5.II2Z1C.B
MAEH+UPX,QDNM@&1#ZO'H2/`F5VK?ER4[ZRT2(1RP5^QF[>`UL&L96I3^N&Y8
METZ8QZ.%7VB"7[7)1YQS!7!J'>'8'<%VWMJQ9JT?MA/]S9]X,79I[=ZWISV/
MJDR=(Q9APD0L'*;#]7<5^D2B4\-'02HR*=RD`V$,3>!.'(KNP+:B&2EXR6KF
M>P\T']S\S570A(0#E_U:,),QXNSO$X)N'<8@/A`'U^(\[A&3OA;(@&<BG>K(
M@[S`7F%6MHK>$Y@"!Y((@H1KGMD7,A1$73YFBJAOP/L_!(^?N2S(!$S)P=""
MDY^](WV0":!FWQJ;L\G!D?-4?7`(,N7@'%4T]ZOQPM,P!(XUSA+?K\.B@0\8
M98G)^C'92ZX.5W9D/+N^K.R6[*)(`=BE`Z9?5/X[Q\RZC=PUH0DSMIZ)#SV'
M5<PNBPG8\-?*@D8"0*`87F>@3TK.,,9YQ>D5D34I<:GXYWHCYJ3!1A;I#7@B
M<8LW&]#`D$[$/?)9&ZFS'3PQ[*YBZX0!#++^'+AGJ4L*6`.`YMT+C$\!<$F!
M5$O-,3#(0Z=*76J1:&A1K+<J*W90(+)5#]NX=G3.?9!L!`N0`G+XF3GG<#42
MG+87/=1E05$#O4V^@.UU5XR%]7<+&6!G@<80JL'@>H`,7&-`,TSR8W&O$O/J
M?V8[*!46/R!(Z<\#KBGZGB$+W%O:AI%+`-]23RV18'D68^TU'I[^KD.;OOTU
M^OVFE&+?=O*M?;LF<P3H#9&AG9+\GCS<"_(T8(GMHLI0."[H<$.:]0TZ*FJ=
M2Q1JD76GB9[J`MA^AQ"M"P<=$U&A'U:ZPL"V)M-9:^O[FI:Z#F2=Q&8^D\RY
MV$Y7,I6LLBRKS\TWX/V_BA.>`"7'U!K&X$7$?,CN,D];9-J3D:89[V)!M]E/
MK(?U,RV.X584`#F2T,I+5"R%U]!X5_O%@=Y,SWMVHY%1LL#;NGBP>/398DL#
M"4&4_'4$_F?N#!.##HQ@FYZV:K'*G!&V["XY,CMX<$Q@@)*,F/Q//_PUF`!2
MC%T<D(P^C]TKE;FSA_VCC6T@RBXZ<VS=1Q1CW"0S+=U"P/5AG-*(8@4-78Z8
MY7'!VN"5VB0`:)+!^!%;SYPZ;=;\!K)J,0ILKKY#P.2-[*F#\<$_*J`KJ,7T
M!O5V:*H\<QP4%FT=RP[TM:$S9*:YM[RY^]!:IVNT2TM&/ZK9;F/FBQ(D,;K@
M)BG`2&Q;R"*H50-#0B9J:CQCC*PN#!Z;X(`>`1O\G6U;8;!!OX\@+8C6V2Q#
M$J`)`'8^RPS%IE+<"^E.0'_V4B@'&->&U)!3#WB`()Q(SA`5!3A0_#3=K0VV
MLI=[-1BX+`M=+E<ZG59=R/O)1`?V(LLW/J!G9AA":>\C4K5>P\>^T9(2W>]W
M)=W;MXTRLQD.I,!K=ZP5U\N%3N<S?=V^Z'%_Z%F5YG17)LF)@@3`8&H'SEW/
MIGP#WO\FH)5W?N\@'HSAEEJ-C4P(SB/(5Q<@M)T9#$*:`FHF.Y<.[4:.$3=3
M%(YP1)G&%\&&L7$$X.6).P5:'Y!/1;-9`4^QZPO,K[5W.OPPGX-,O=^$&I$)
M@$T!2_&6%IO]`$E<C4T,R[%=%9V_2B"JD:442&*`V=7S+GJ@RNJCU886E&:*
M101@*G;(H[?YLF.DFIZS*\505A*QWI([8$4O3.6IZ^Z##&<'TXZO?7O]K+%_
M#:P[A4JK(PH2^"S8)Q45BT-4#-IU=(Q0&E>!UKJR<D+]L(3->I$\+=:0Q1%S
M<WS3RCJM(.`>NEIJ;?+V;+%U@X!G64JA1'VHKMKJ(6.,PU^-%:W>:ZTK(#)D
M,4-/#$5M!_!"2M+$''H;I]XA`/`FK%1KC,\=Z^-M;*UR;``$S"E-/(*UO$!I
M9/&=ZM(5"?<C!5U:%Z"#V:2!/8&^5T3IMVW(`]I7B95*$#EV,0*Z=I&T?YZP
MW=X+M.'+[(88$]/Y5/S#E66<"9]0`23FVEMFE*KCB9WK2/5:MD'?'@01048F
MYW7?W]R<:2>BQ^-1`"\#.V%#:D0SK9:%S50L.A_W1Y73Z'>;I8TM#VNZ[KW>
MM+]FXQ;\60#VWX#W_]I_F$(/!)<5+;]&(_NY^2A7@G+>C:[H\.C\M+],6+\0
MI/F:?^8>\/3:S:IB.P%L66=Y_>X\!<&-U7O'-)DB8,R>[C<M+L>\!JS$D4W7
MC/Q5U399ZGMBY`ZMT+B=RY[=9<LPD+)-MU9LT48V*P#BQ![4>T4:(.[L&VXE
M_9X"9\%Z[EF#?LOTV7(!!B2%Q_,BE)TT27=09!0`65=EN8,)[L-"8T!D.!W(
MQ-@?W[L^PI=8>W(V@,$<)!`&(&B@/!<X@/Z?ZM'EL;%CBQT'5KK#MP7L@9-`
MMU6#UGC7%(INLZ)EG9HJ5_<#"@@&4./.D4E2Q98C6V(`$[7>:=#77&<&ZX_#
M;LB\PW!ABR]63)^1:BAGC]3O35I2#Q^2P%FFVX9%$C?+FD>L&X-#BHB./)X4
M?'DO,@4R`![;Y\ZS7@ZD>)/U)B"P5<?$=3HG:XPHYPIR*Q@F'*[+2I?KA<ZG
MLQL;4#(<.)YL6OL,;+\PT^/Q(,F93N<3219Z/![$-6V3;*0S,ODPV&JK7]NQ
M.U\N8\AOWS46:<?+3.S6F'@3['[<AE(6($[Z]6#=S3NR1^Q1Z?7#OP'O[S*Y
M(G_?9^%_<WZG1U7PK[@H\/-CZ;JR_/+Q\W/<'EPS:X`:>P=:XN[I]T>#$R:^
M5B<4!4D@,H?E00JFWP"$7G"4,'_!T6@;!#H:=P9YYH=\\(R&8-<,QX4N$4_>
M@;"9Q@=,B6LUDK)>BQXNW/@D9W^:UI:)C"F^F'Z=2Y%@S0891XOA.H#>IQJE
MBDAPW)C.5)DXAI]M:H8.J"+O*89;)-UR:D@OQLULB[Y(Q*J32EX2.]5#I(L)
M\H5V?Q\8DH_`"S;7@1RWX74)@G&BX,&L*]:P"%M+(1X\!SKQ2Q?-X_(E4P`E
M2DQ=EM$8.ARN:4QD;$V&EE$CPAH/@4UCICV+W5.6?+A%.XX,KA&V9=VMP@B-
M%#@H[DAM^J2Z"WI]%[10Q/=H<JTY*C`"]C<B']HQ<60CQ\/SN15;;,,KQ+.O
M;`H-#M9\!UIGS14$6Q.RH/UGBKI9S&X_:-<L<:+UM-+U<J5E6<82YYCV84F9
M]YWV;:?']JAL;:J!0TO122\+/1X/^OG77T1$='_<2;+0OF\EA7)9NS]\"XE)
M:=&N$82V91RNZ7C>'Q\?],5,C_O==0:CKO1LP*A=PVP*RG!OS;G;.N(PW9"4
MB7-C:97F-^#]3;`[JR*/B,>7.-W`6/\E>[!`QO"4'XV<OR>V4K$7KI!1_[B+
M$:A/_0S^&R`^'%:G7W2^B*CH`^WN='VT]^K-X4&[R$09:.X0)X#<>BN^]/TP
MK%:`4]:PAFGJ7/!2X1.!U<!_4\5SRCA_Y''4QML&U:QFU+58M3F_EFP$0R"!
MT)S!.8.5'E=B=ISUXZU8>>A29]#3ZK:ZC.X*3EO38"S'8)@!B+UAJ-N4JK/!
M&CRIYR\/$*PW.NK@M(72L(L;%N4#&BTOZ.&*`1@Y&\]:8.XM,)_I*P<Q(&"7
MQ$I.T9ZG-HB(X+-]=PF@P4'!Y`H`ZU!AG_LLVDJ+0`XSNB\"SS?J#[7WLUJ>
M6V'$OENC@B5X%$:CQ4O='LVE7O6"(ZO(Z*A#IV8G<$@N`'FXR(1[)VI2@1%6
M[Y.W`G?#51;(^SI%E#XT?G8T\!6*?9)[A'$PB.J-7@H;N2PK?7Q\T&E=PZXJ
M_F[.0OO^H&W;Z'Z_CV0X&DEY!?@F6D\GNMUN-<&3*-_AW<^9'OE!1$+W^[V"
M72Z`MPZKKNO:)19+6L80;RO^S?HO(K2N*ZW+0@\*'*+@`B>0'6&'3&AXKDNP
MT0KKM9P/`CA4-X)%%9?M^_YFP/NW.+;^/_//O#7_2XCK\.??&G*;[]<T%1($
M[-8AO3E!,S*Q-^##\YD))(Z*C2?7P?@3Q3&P<S_RZ/KSY/3#B=DG-T#D&!%:
M/2*39HGBV\!O=QTL?AUFW8$6-H+B42L[:#&]8DV"+4Y['6<DN1I,>>OE#<Z1
M,:*2_;VJ4@.V0`6`;T(6TUZ;WD/6,H`V\5[PIK;6(4BO2BX0)1NK-LM&6TF%
M5`LN#9J=KM9N]M'P#VE#^)QW=:,0M`B<-YKN8YH6^B.WO3*3Q.]88$P_&S)"
M%G*8]9,+@E#Z&^-T@0^(!CIZP*<_"YB(F.,T+@N^5=&G@F+\$)',AQ<T&`L2
MZ<:@(_5BBJUFW6IP63M/V!=?3.+%+'+6_9D"YM+E&*+TR>/]T%N+]."0>>>(
M2<_`FID.9F]'."9]QT#@A`BV?KE=NQX0'VU`]'0^T\?'!RU+.MS0MWVG^_U.
MV_;HWN(J`KD/598_;WK:;*-X@Z2\$AI3$O=PX*P=/S/3^7RFTWJB95EJ(`9T
M3.S@Z[)06I8>^#,\JDFYHC!$E*NDP3ZTMY:$S)P5^V^CDZ.MQ.J=<=@#I25_
M,^#]_P?LOGU97J@%(K#T2E[#T4>_TDV/#/I#(<$LZ0Q^8#:4=008HS_A)W_Z
MDJTNOO`3M[3&E+"P;]L?V8S!G[!Q"6!;-T#;N$=XOG3\GD.W\_>>B;`I8L</
M$+,^6;&_&UEMA,#7,S9A'+'SNS22!6?U$4RZ!UZ;1YIW#038<^K,P`;69\$.
M43'W:D/94C5=;/][&]>+@1F%LLB",VI"G)J9NM;7<;4^Z[GT79=9QI+Z=53Z
M5^M:T"F>_G=*OSBQ33G2*:+QO-Y0]$"5X,8CHD%(LRE"WU`1`.X\K*?(!!T<
M_&,C:1V`4LS22+?"9UZEAU4?WQ"L@O71F/^2KH%EYBKS`!<'(7TO3<=7\/C%
M6"8>L%SZ?K'KNXG$H141::.CJ4F]&PGBD&=#P:4X(Q,",4`5VJWAERK'"3)C
M`^8Q11`GX@,7HG,KMH([O/<:&&.Q)<ISF=0S2%URH0>T+/&!H35I6>ARN=#'
M]=JO04_:(VVO]W@\Z':_T;9MB@UW,POP#&2X=E9#;=<]YO&<(C[<]]S__O/S
MD^[I3I?+A99E(5Y7)=M!QOMT.A$S=Q9ZWW=@Z(5L($:359S.9\I[IG5=BL1C
M7>GQN..D7UC(,OGTM8AU[T4?B+:_)0V_@V/?F7!Z(7`BT@#P6\X.<YS]-*S!
MF$/SP9<=F9W,ON!HR&L6JVU=(&AFFW5T30_:^C8%1]YRN)#XF'@*1SOG\O8,
M'F&A\8P)%PVT7V!:_?"CBA<SH0\".D`/8I5%F!S?H+X0VVN-=@RHI(C[A,&$
M?V1L,C,X!YLF\MZ_6D@OW0NWEQ8R!)HMU4>#Y79RS8ET:'?5IJMD""/R5R!Z
M+L/`G&`P!9NA,Z6Y+"8..>LA%4XFJOJ5+I*9P&?3L6ALG+ILRNI$#^`H=:22
M6"3,E(W7&[B\%GBK8Q13D)'7RO9P"*<!)<*P"?3D;<^HX/-NW#?0%K"'9`2*
M(&5G9W35#7@YO_!`TN'!@3GF27<'I_]5D>BZ9*S7H"[)J=/R><AR]-./ZV0,
MO%-*YIY(_W.QG3ACQ8SQT,B28]0M.K)H%PR[#^IAXZAM7GR'L[(,.Y0V5NNM
MZ\<'B0C='P_*>:=U/2GYENP[W6ZW(ETP0Z/ZN1GV>HKA!-`;LI\4V@M/_V[/
M.WU^?=)I76E9?E!*RUB:67_O:5UI759:TD)?7Y^%J;5#P,"J+\M:!O5.0_>?
MZG7LD@T[,S&Q:(MTZ]AM0SUQ^H:M_S#8-2_`RW9<;ZA#>+++SR7BL]\7"LP:
M/.CBHW.4Z<D^8Z$M1'@5[.HO?'[&ZJ?D33H\;%IU0LI,"^LO4W;E\L(UM!?G
MB297/&SU5F(<L[RC0RO'VF@^X-]AT?4,?Q0XH:?>([UL>^`X8%6(M(W2]-:Y
MF%L])*,TN>*'3:BRN&I:6EUO!B]=S4P[:RY@S1HXZTE?C-'-,NRX^LUA)[?P
MGKL#6`H`$7<_\M`QYH`Y]?9N5'-5I0^399B"[B"%Q^>W1\%(7KMFNO^?\4UN
MGZU;^Y/.ASE(^SE'(,L60Z5M+*J+I)]M,@-IXWD?DA6F92F#0.@M2^97%'@"
M0-S\;^TS63;P^8!;`Q36L2+#?1C/)#"@:BT<%90(+B`E4CJ*M/$>Q]I'-Q](
M_O$]P]9ZG[Q'1P)08EI'#^5>9&0G[5G5UTP,TRGF&-EO2G;#Z-8<K.P0\;O:
M]YW/Y^YJD'.FGS]_TM?7#9Y3HFU[T,^?/^EVNY7?S4UV,(;7^NV17/\-!C59
MIQ"J;4C$O(_BP*^*A);R'C^VC?8]]^(F=J\O_W$ZG^A\/IO/F^$48,\Y%6F$
M*7SP`;77>#SC.98Q">EUAN0;\/[J/\QOT'1OL[3R7DK:"ZWKU[Z;G[8-^>G@
M'9CH\5N7@)[%&,@A.<H$DT'/4#G(',2U%?6[%GN#'AYI9.$0Z.N?%0Q"\\4B
M`K>8%&23B#TS%("&@.&6"=B=1=3V=M_!3=<;CTQ[!&*SX65>,EFK(AQ,D4E1
MY(&]V<A5$,+8X]J0QSB7H*7*$%0@+:83FGXH70``(`!)1$%4'HO4_FYLY?C]
M.8O:I%1LIAEGG!82`"0D6E,"'U5U#@W<9MRYP)LX6P-]UKJ`":/8P;O5I$IS
M"8"0CTF1)^:E:$QEMX[*TH?.&D.*0RSM_P3"&]R;*+'N'Q="<8!"*#=P0!P"
MBFB`$W6@RA[.S&DYL&R3!REF]QJSR=WG-?G"O#Z8):*YN'Y0E7OHXQ^_WP!U
MSAID>Q8QEE;8\XY`;R^`&DO'XXU)8,W%##9U`(3<4)N[1N:1Q447NA9VB(Z#
MF0PVH0N7RX4^/C[H=KO1GW_^28_[G40R[?M>F-!MH]O7%WW^_"P2!@+_6B;E
MM(:RLHAXZD5;3S@+V&EXKR*RP`7_U)^]/PKKO&W[L*U#0@!^?CV=BI]PM+.)
MT+(L8)%FG$G2H@:#M:<X.Q9WMG8)O#S?P1/_)/-[\`?/M+82]!9_5\/[!F5-
MOXF;/3LIOWF<WJ?Z.4L<37$>H"\U.<U1K<$32,['A4>@(Q'2?J/\CFO'D\*`
M%9C7D;-B_RZZ+X)]60!MDRF\9P.;:",4`S*9=C-L)*0/$K!M.YD6H.*#0YUM
MU?S1BUQ81($.-G_>0QVJ57IIJ7)-9R.=:]_U<+DGO27E=%#MJ[I,PLR[04""
M]($ZAD&D8>EDP3&K0?5A%R&0HB8OOJ,X$3U`ESA/93PV&+%7^EQ&S^]LHI[9
M2U.T_9N7N223O-63XC#ZU<2@2K#^MON2Q;IS8"W(_A%G"(Y@(T.Q709UG@&3
M:770P7JK+;BT>*16*OH3A-3D?/G>#+[)!QI@#.N8/!P]*KK+A;(;I%*Z5^@6
MN``&TA[4(]([]>/)$SK]F889Y41VNY@-WD5Y)AFZ0)?SF:[7*]WN=[K=;I1S
M[J!61.AVNU?/7'$:7"5U4"R^Z#4Y]#+7X3^)F9:42M'0V-`HF:U)K88(V\T#
MW.XW.I].=#J=IN$GR[+0]7JE?=_I\;AW=GA)3&E9Z'RY5+]GH6W?:$F#V5V6
MI>CN\^XTN4WOC^^SD@V1'RA$]HCYVY;L-_#A*Z-7BCA]'2B_I?E]+E>0(W#:
M%N47=[BWE!P&0,IK^Z<_^.FP'#!.9.RH2.OV'#D#G]_M?Y]=,W29MZT]"IUN
M],0V.5G<\7V<1`9/KZ4YEZ/GD5^Y>>#!RVY<)'X/GH5WJ`&*(Y&Y2<&SK)5X
MT\O!2I+U8&33RASA`@@A,*+4A5'`1A3UUT5BXWR1J#5AK>>X'V]6"7JD-CAI
M&VH?XF,E9>@L'L?W1H>XB"JT?4>`1U!$>\<@G<E&F';_WQYR,33'//%^'1Z:
M1>/<?%>[]E:!QNS8S'ZX*0UFV#@`-'VNLY-JUST5)X(.S*2R[P;T]I2G/G0E
MZAEKFDH;8L/<"B,$+PUXDP->[?D:FWV3!FB@*F(L[Z9#AEP&*%M"&18D>(]`
MZVI?S@8^DXE!%](6B,9UU@P/:><985Q11CQUIECB9JW!.)"#V%U!:83K'E<Z
M)V5@DDPW;(1[Z-`)<?A95)L!V^=<[;M22G0ZG^EVO]/]\:#+]4J/^M_[-1$A
MG(?L$A/!YW&L/[FZLB"#;,CTSHHS5VE-2G1>5SJ=SK3O&WU^?0W0#>LF$U.J
M?KY9A)8ET?E\[H-H[=C6]414==5'WNCKZ4S+FFG/F;:]V*"=KU<Z@6PAYTQ?
MMQM=SA=:F2GO.Z64Z'J]T,_/SU"JEBRC:_<A8VTWMNVR1GT#WO\1VI?"C4A>
M_/GI1Q\.<_G1L):&0B^"][?`KOS3U]"#77FQ,+&?Z:RI@`$+>U\VHA08&V4?
MIIC3URL2/#-G<4,O#B$2Q9KD*>`64A$V&DH%S@A^D]&`@H=-4WA0;#Q@#>`2
M/_"B6[2DI\5MI.53.04'NE(SZ:M:[K#`YG;XD>N#="`J!G#CPCO`FK;J:N^D
MU*$/,443JQ:B?A*ZZY:*3+5M6["].N@8J#0_PUR*Z`)1M4Q)@P1B:,^CDX,*
M+A@WO.MU&:^/J'>O#.)Q."R)W04=!ZSMK\2=IW\O$K-*',/GH/OQN@*)%.LI
MP)R7C7Y4[[T``<`Z$M*X@X\&3!*QMA43/61I)3G(7+;A-9L:E[JO\+`LPQ2[
M$4]=P*AFRWFZ]D2@DX3,?8<.`6&,O1[4:A*)94G:AQE"*D+?<?.L-[NKG(4H
M$>B-#6-<KW./KW7^R+H@R3(&"W-U_3C7F."OKZ\2&5Q#%=9U+0X-.?M4PTA>
MU(\KZW,#J[\R5%;"))8ET;9M!7"?SI12M1Y+3*?U4F)\?_Y4UZ\]FY>J,WX\
M'G2]7NET.I'(%Q$]^O?N.=-C?U!>&\M+@09Z%'II68@XT;*NRLVA6*@5QONT
MGCH[GI9$*:VP]N@N7:Y=!6W'",F;Z/$,)%4'XM]H]!_^YP7F=(!=?A-5.@>G
M)S^IER-Y&\6^(&=X18/Q"G!G#8)\&``;8*C3T@XUI'2,%E^-58BTT[;;A-K)
MV;1Y9.XCP6=&(WF:X8NO(QZCGK`-I8OQV1I3^5<>\T.=.Y.;/"=3D=>)JH/B
M2S3#%H#NQGA:FRX=4F&C=D6Q+8UMMA*-;B/&C3$3O<@2Z'@[4#6*XBSSR-(6
M%*^^$QAW$963FA1K$ZG/`11,7$CZE'1*:N*[#9>EWCHT]RZP2K(A%S91RQ4B
MS`K(JHU?M3>KA5N3)[BV^]`(>PLK#0US'L>J`<4`FZG?7PU@=2-"S/"79V_W
M/7?0)I$G+#Z$]CX36F6AEK8F5-4":0!=K04=S'-2C*0:-DOX=VQ\?$D!O^$V
M(FY*'F4';HL1_?X6UHX=\9/`+:&=ZKYG2FGX-V,7CR<[W2A>I<M7TD(0'UT.
M:(=.C$PD4I&42G6<ZII6P.:)]ISI=#[3^72BSZ^OTNJ_7.BOGS^[A&%0E]#%
M,(-^$LB#VC^G]437ZY76QIQR`=4E%&(IY[8/><#E<B')N0=4"!$MZT*7TYG6
MI?S\FA*E)2G'DYQS&6"[W>FQ;?18'O3O?_^KI,1%^PWL>8F)SJ=3M3+,]/GU
M1?NVJ^'57(_I="IL=+\V&8W\(5)<<$B<%-!-('&Q>2K?@/=ODC/0JZS;4U9.
MZP!^1<[PHNVOB5SZ&P'^KYY[`$CE"3*6@,*4`R.Q$)!+?-PQ\\7A<?'D\X_L
MV'1]HW6;,Z<&GA.V08?`GQ@?_X)F9\W9\<'S[P9G0FLNY7[G(C^U.L'JUPX`
M=!"A*J91CZU:D5D80%UCQ8`6'+HAZ:RL_5WI["XI/>BPE61SI^O'9W'2E_9^
MAL\5!E@@ZZ:`O)<V*!"O&'73WC7:1P;&/5M;$R/78,.$JBX'`.H([$:=`Z7W
M5='#,@()%)O>&,TV;`2^N&E$!(\P@$3.CMAZ2</UZVWO>LS9LI65X<N2G>?L
M<.60'EZ2"9T14&8SUN;8*Y<AJ,5W$5`;+P:<M20[R>2LUO+$\U%U!KKTQ(+8
MP50R^0*[%1=D]:88L*'\Y]EM40WLBE#7@0IV>(P,810E/B:W`=4,^FT..E:1
MEKBO-/5<6CQO6A+]\?%!)$+;XT$?UX_2K<F93J=3&5K;]RY5Z\\&-4<+&7,`
M;0@O0[HAB7JW\[[1Y\^?=#X7X(M3E/?;C1(7UI=K+#=7B[0&"O=]+Y9BZSH&
MUI:E']/U<J;'[=:+/JGBGGW?:=\V6I=%*?VP0&9BNI[/1<:P+)1%Z/;U1?MC
MZSLUUQ-G(I*\T_VVT_9X5)]N`D<;S>;@<\L1-H,!UK&6?FMX_UNJA?=(X!<'
MW68`[AG8%=+).'\'62W!)-1;NN4C!&H75A+GTZ?8KX/O=DR.B7]]KCDV&E1L
M,0M(`PST?I[*Q\9[T5\&C!,>?IUC8U-QL3)GKR6&PN/::I3YLIW:7$IP;!LV
MPCC865"]FF8H`;/FSJUK&OWYY<JN<']#4N>?\.(Q<1PAW%G=`68&R-3"3@90
MW#7-QBQ>%V]M0S`,DXG\C=Z184R?X=EFQ08J\W9HF0_FEH#E#B18%`6/>)VT
M]:?N@H:45/NZMX>[AEB4Y95J76>IS*2`QZX4WV&83\#SQ-0NU)0S@&_M%TRA
M="):A[M4("4'%/4US1!YG`QX!6-_IR&/"T`]6.4'=[DY-,"]:!ZWDH.X14.,
M2##)UUC>#/'5?5`0[>;`20'!?\ZD0T>87>^JM2.:=&"IURHEKDX,$,EMNF"I
M`7PR@165O>\@-:4QP`@RH@(2@T'&]OTR)#?=+YF9]ERTMM?KE=8UT<^?-[K?
M2I!$!OLU]9X'N;KCD=6#?_T:IB+M6=<254Q$])___(=$B-9UH>WQ*'_WXT?7
M[9[6E3@E.I]/SM'#/E.2FSSC7'L#S<&C2E^:1W*P._9]*B5:$].^9]H>#WJ`
MAAG?BK24X(G;[=X#,-J')"1/JEPLX>"G\;RF@/%OS\4WX/V;V-U?!8J>M)2G
M+*UZJ"8:T./ODC`63)Z0P:_1QGKS?H7QYE<_G_6&;@%-2[=Z0;;K/'Z%7_E.
M"H&X1*UU%:H@:O+VH`S1*)K%W1MG`\,>:$_]RLC;'`&2T^UN-UCEK[N/?:0P
M\:BS%1(7`'IBV]=A'":K38;93,2<DA1$SXS92+0L0IYW1X!5&YN3O6((+@WT
M8TAHL*UQ1W\'`S2LM:"6<5.LNP$=-N*7.1I(U-/\%!Q;;&VDUXT1N);-[W`H
M>\C`@DX[:L8:#J]!&QY2:VJ+R34#BG@_N[R$8K93`K&OTJU'L;Z-6<\Z&(.!
MV;7=*<8@DD`>H*P'S7W/@::R`U>X_UF]?[KH46$*EG$/&`7;<A=37.P5)!(P
MM?:Y8L,(HWZXZ[9[AZ4P_`WLYAX$0BJ`H0]Z&B<!`F`ZGA_?*_3[B2A0G4UW
M1O:=Z':G?__[W[0LB?8LM.U[T1!7L)N5@Y#6G97W)'5=,ZZYK7A<4J+K]4K+
MFKJ48=NV(C78=LI2O'.%A);3N4J%%LIYI\>VE;A@(5K6!,_LB"Y>H.N1)5,6
MIG;K<K6@2\QTOV]$E&A=$V&"HI@)\WW/]/GY2=MC'U*.$==&G!)M6Z;[MJNM
MK#NCD!D8%B9)=CA-NL1)E'L(CD9^`][WP>N+C)/K.\L[OW`,7-W'O>JP\.2`
M9L3@0=8`O>%5$;<@*/9#E9E<`#<3_D6:79QR9)XY(12TH0,MHK,T8RT>$J%G
MP:B:L?=ZZ"@%2MEZL37\2D.WR`'[1]:Z[<4'"3Q(^Z"8B&,@K(Q`;8SBKR\'
MI/O!US\I1MFU5(\*.=W*1PWL6&@[*X6,6V,7K.Q!74X.GJ6@D!#??1!#50P[
M'@8S:3_PB@X%]OI8FR7OZJ"UR1K?,=A!L?8?[7H_H90TXZD=`J7[O#9G`T^"
MZF,,AZ`\)P8!;6T#S./&`8BS;>_^K"16?J^]_6\"GI@I](YM_V0RMGP81PT!
M(IU]M^!1%7Q#BA$VOC1^<-9,6`@.P*U=373<+@.S#E!0M$9=$S02'KMRF\@8
MR3T9?&O2DP;:X67?<QMNJ^>9?!!-UV83T>[65CWD:$&GV#4FH^^ME`(%BMQ^
M;;,N>/@T`CW*D-6B@2['Q2Q&K*N!-GAW4DIT_?%!']=K/8Y,/W]^TNU^[\-P
MS%P*#&:ZW>^TYYTNYTO5/Y?W(.^9'MN#F)<N>6A=K5TR)4JE*-B+%=GI=*:]
M!LT(E0+F\_9%]\>=_O6O?]&ZK,&(=3GJQ[;3[?XPA?F('"_,_5C7VOJ9\=WO
MJ6EQD>V)!E+'TJ[[=_#$?X'A?4%,Z^X1O_!1;'LX=/R[O;5EV_+"JJW'+WZ6
M*'82K:;XI=-V#,41*`E#`IPS]W-&5V=HA@E.[#%*>$5$#J;<F%[[PWX:[-D:
M"V3=T!4<BTE-ZC_#GK['"6TV2EWV\^UA_<;,*NBB#<\<OR-L-FQVG.$1LZM^
MTKG%Z]`3GKP<GJ6W\91#4\GFX9`^)*8/-`UJK.C24.9`\=`6A4PRFZ.SH$0#
MH/[3*D@%@(/M&;`.S$@]A."@XR#(/(&LQ3D;!+K;EN(63,_CY#DK$Q`AGYKH
M7=UP4EM,6[@<,OKM4@U48-4B;G*",00[_#JKJK-,F;?!+EAO6FI6U^B2"2,1
MZ6EYI&03.A(60S?PS;/A(NBO/:*4XVC8,02):SXK4!_1\6P":D2HMY=5ZEEB
M<\\\L1(&8.#0)E-L&9F&,T8'E8G5<Y*II?Q)`6%YC#^U9S:U5]LP^3D/'^!D
MIOJ]IS;#.E?O?=:6EV38XR4ENEXN/5RB,:88?L)2"`*N%H.4A5@R<9:>H$8U
M"3%QHM.ZTFE=Z>/Z0?_^UQ_T<;V6Z[#O]/,_?]'79QT"R\-W.M4J+6\[W>\;
M2<ZT+BNMZ41+6NA\/M.^[?3Y^;/(F'*!FGG;*6][7V?ROI?G3<K?$^9!Y!*R
M4F0*!9@GEOXO<Y5OY>']C7M,H;TA1;X/H8)?=;U6A$/*!S[JX]@&F\:-D,G?
MMF3_+,/[%N?IIP!XTOZ?X:EG!@EJ*8U&9Y^PRE:7BQNSKUA?TQ\+QVS?*]?4
M,]VL!WVBZ\$35M&".HE,#K01-U,P8"AVHI;,`)@I6DR'U`)PL4`\`$,T`:CZ
M'/79\A-PRA$KWMD."X#9=^<"SMZ!=/%9ZQPP,H?O(EE6FUTGPWEG<K`IVX1!
MG`K&A#,9$UP8!$QMTA\6;#+#54IBW*-CC=D^L*=]P(C8"K=KN\^_E\P4!"U0
M]UNU+R`'189CWE#/VMOFN6ZN`+`C%X;61K?L\J3K,IPO+(C616MKV[<!,3(.
MP\W+E(@HI:H-!@4RVDLU)X8"L#))YG'<W>N-1G(3&X8/2]"J7QU,NV&!*=#+
MYN&)FUC[_.IB0=P0%[+S.DV,C$R"W?T9EE1LG?V&1A5^IG4W[+EWS;IHR[:F
MYW4`'H><B*==EUY\9'&9'KB4-V>/%M$]?)]U(<BF.]7]:FE8ENGH;P:+.DWF
MM#\3*(R7I6AI+^=+84KWG?9MI_OM1I2+%I5TJ3HLM0B>_78-<Z:T,'U<KW0Y
MGWO`1ON^^_U&7[<O(DGU=V2`W:;]KP7$XW&OZ69")`OM^TYYWXI&=UU[4;%M
MCRI[2)2E!$?T[YP,=B_)ST50G04I#@S;&-*3<6W[^]ED._M>-;L,YP'K+,Z3
MB%0)(SLK=CL+4*X+?0^M_5T,K_R&G$%"`',,7E7K.PBIX/!KQRH2:4GGOW=(
MH!JVD5\&^3W4BXRGISQQ-IA=5AX@(CK6>?&@$3Q+2)I/;IJ.0E+R`+8`6&"Q
MDQBXFV***<YET`/IT7?J3_8NG3#D%<D%(.5G5A"H`1J7YD9!FIG5?(BJCXS;
MK@-NKC5I@??!2SBTP=Q#!=@KIH%E"F)VR:0KF=\4U$9T/1LFF9GAI]*T4X-D
M>FA*>P.K9"%EP>;7I\9&<@EY&\"W>QYGQ8AR]?TE^$\K)Q@%F-6K@NV;:28@
M>)"#R&';X!JKE![@:>P5,IZC30H.%';B7VE;J]4;:RWE*#9,<QN&OEJAI%PQ
M^D5,3G(A.=>`!78RHQ%N5X?VLAAM,75F>K2XZC.C7"O\<XAI?JV(&*!0V^`-
M8$L](C@9%Y)1>,7=%QO?BUV?W`$,LL_C.N&`6__?;`)BDCDWB>WPF*/CY;#E
M;0<SV;#32H=,&OA*(`T1(;I<SH7=A=_Y^?,ONM\?/141%VL<3&P.#5@H9!HM
M?UY2?R:$B+9MI_MC)ZH%'[?>$G:A0!]_?VSTV/^L`#51SD6>\'$]5SUL^7<]
MG2EGH<=CAPCU]M:G&M0"^O/>760C/=1]8H%DPU.-'MX>CQ$\4[6\),->KWM1
MD\_&0BLXJ!O=;$,ITL=O?DL:_C$J^#E0?(7S?4IS2MR^G[?B^=<&[U[VUI67
MI!!NPQ9-PHEJ33__S@$87_OB4%'[!.5&K5E';8;)1]%4.X!%AB,"I8;P..0<
MW%>!03!AT^EQ3)K)/I?9T)=FB7ISF>.P`6>,P#2?9(<>0S:!3DK>PN0RW[6$
MA+T4A='JC.TLDO;MG1J`8"LU8,H,DL,I:@)B5P@Z;\IN$V\Z!#!`)V"T?3&#
MVLMG.'@_&.)-O6)?!EAD]M[1[7EAAI\UC'1E0AD\6G7`QBB$AG`*P$Y*[J$0
M56!R$\=V%KGTGLMT>.Y,>MUX&].*PV*<5!2I@-:\_SG';#8^,]+:WP#HJ(.>
M9-YC+5.(F-Q^S618+'$/3"!U3W#:7,MU0'J&&E1(LVO'(A+W:AB^)Z4QN);!
M::`#/_9@5K^7\0"K_?,B:\E][U'O-(EGP#OS+EUVY<`N#`(21XXA6O\:]:[:
ML;00B':/^_$)OD\-?-I]/2CZ^O-&W1]9KU&LU@A<)]I[L%=;N]/I1&E)3>'0
M@<'V>-#]?B_'QJSW`M7YYU[(Y+TDG]T?&V7)=#Z?JP/#Z-K\_/RDK_N]OX>/
M;>_'B!(>Z>MXI@U^QHJ1!.Y52U'[XX\_Z(\?/^CZ\8.(BAXX]QVP'B^L06BY
MV-=($1+N*U"]#I$82M_/;\#[F^SN*Z#WC2]X_6.9?CW@@7D*L.6W#DW4QO_L
MLKBT508YL9VE,IA5O/.KIH>??+G3`#_%O.QDHTIKR4&E`@,A8FX>Z_YKS%(>
M2(2G+@*B6[5V.E^#65&:NB-A"P>B/3&G/G]/!$;`Q&N$7=2=3)P9)O(#5Y1I
MW]1Q_NRLT\2PKM;VB5E7'FST,JV5:C7P5IM>I)R#E1`$S?T>I<'N5;:R7[G$
M=<*>1P$D^GUIA<DL`0M!2D]ZXI&*)/V_)\J30B@WIS:.@9^*8@7%'E76K6R:
MHAP[&OCJB7%-$VXTQLZR#UL$!M#U>]=2ZP"\DI'`$/BPHMU6['^;QD!:!S^Y
M`^1VOPI02X264A2`@&!B5S''S#B0)P!J1;'9(@2@F^-@#])2IB'S`%`.[@TX
M[*/6B1E3&C#`_GM]]X4<.-$]J<9X=M(`GXFD91\#4`_&7O1*Y]83CN8!('&N
M+WV,TA4/G/%<MNU!7U]?15?;V,\<`P,1W^EE*LEG_^O?_Z++Z4RIP601NM]N
MA34VA8:/.]/7TTK(SN=+#Z<0$OJZ%8G$MFW@>YP/L4Q*B=9EG6*&%BK!1/3Q
M\8.N'Q_%):)>(QP<S$(NP$4H"I01=:_'\R]CT-"0+.W]_I8TO,5R<ICO_$2K
M\(*<X74@/?/K?=DU3/6N7SL"D3FOR@?Q#,\LR::.$(8TC7V)#_PPH^/G./3`
M,J84.!K,KH=BQMS)<\#L#@VH90_+KTC8&I`7[E]\P_P$MK7TXDA=++@A42@K
M<-/:!]6%+4V\G$;;]!SJ=WT,49V@9H4RD>5B=#/`C<D-[`R&1-N(!<6"Z#(Q
M>G:5A5@_=E*V86(89O+-@B#=B9^N,_V/*["-[,BL]I?A^F`HQ8BW)?-,&*VM
M.A]Q`(5YPCC2&,2R1<MHY(MBEE&\S"U]*[64KJ7J>C5PS<X&S[Q&75[#VJK.
MQ/&6"%D+4I");RUJ5M\O$#/6W0AF1`JC9(1',ADX7)2)_"A\W(--%#CUP`X5
M:<W*LU<?+WF]&\_M`>TY'8<W^/6"6;._47RRLJGJ1:4>$D6W%#9I;G@M\;U`
M-Q#U6(A>R[,(D/)>[E&2P^Y#CTT)W"#B*-YFO5;:_@O]^!@!$=AEO-\?=+_?
M7*0N&5)#Q8EC^XEQ4%3;>R5.M.>=OFY?E!ZI6[>I>]>Z/2G1]7*E\^DT'A/G
MC2_E,YAI69:N^Q>1\K]3HJ6Z6#3!#BZ5&MN@<,(D`7)PC&S>XRS?#.\_QO"^
MQ<#R6UZZOX&Q`U'!*XPP30P&^/<^?0+8)6)_#XASVX*:L;JCS6.GB-DAZG@^
M?$P9-9V98@Y$M(">.9!E:`<`<?R#/+V.HK(5&;Y7IL^!3;*<,=YB!F'##<JD
MV9"9_H]NL-V<].>RFO7R+5NKW1'G,2MF4XBOI;A%T;($!&UXE6!E6Y"J92CC
ML^RI*PLBW0X.+?':5#^T5R-&WS(WEL-"/3#^T]C5`5"'+*'\79Q<Y))O)>H8
M\>2>`*AF=L>><U:!#TY.`6M-3_D*B=YQK*GZHHF9:$%#?%(%Z[#]BHM<T?9A
M2D*1PN<Z8M;4N;?S)NU4@4!5.4&`]C9F[?3]Q7>R?9?(/"!F]IFC><9*J]UK
MM(D\:G8M-"M'#DV+<93)W0Y+.UK8/8@3]Z*G%7"M("M^LKF[9(B]/N::J4)3
MC/\Q%(1]J)3TSYQ.)[ITN0![6T;<#8Q?],>/'_1'M?J*Z(GS]5+=0WS'HLMW
M`F(*Y2Q[SG2_WVG?]W[>2UKZ\3WNCS)L1V@+IK]KJ0EMCVV;.A:)%"G%NI[J
MT%SYA)06NERNE-(R8JHEVG6UMD[W"H/BBLS>9';I;X;W-\#N.VYCQW_UFB?N
MC.1QF^;AK\A;X/HMUOA9>$7T/R8V;/+&)=4>GT_.J4^"(X/D@4I\WC`HPA0"
MJXAMEB"/I@-O"33^!T:T8@;E5%4_0_H!8,%]._$84B/KG!!,UV,[F&D^`&=9
M71;XGHFS,6[H\LQJ3K$^8TI[7![C'@$+IKV\V&H=;@P<DUL5B#0?5I>2Q*.D
MDFQ#34QREME(&.VQS#U0'LVV\T2^-<Q10`##9[(6ET2;VJRQT)C%P0H/0(\^
MLZX9$;@Y8,"!C1D>+#$I^RB!XD`DJ?-MF[A-)L.:5"#FMOF^]H&]-D@FT>"3
M]B/V^_*PAG+GIU&MEP@%GL:1-C:2)[7V\S.)0=@-G`!61V*(.!<5E&=(Y,\[
M\2FVUP8[!FKM83$#=>2\OG7,LBB3%&6G1Z-HX8,U:[P;`I\!Y\_&-[NQO3AS
ML0L1+R1UZ'"XM-AI=EV4CQ"8A7;P<VB@?7ML=+\_:I&H.RP])3%@-NSH\FD]
MT?E\UI*A5`;@!KL_"JR]VI/A)7O4Y+0B5_B@'Q\?8Q*]_K/O.ZWK4EPFK.<1
M,YW/)]JVC?9]=]TW!FL85:C9+I!]E2"25/EA)/YF>/^Y?_B0X3V"*4_)2GX?
M8[-C*?F0-<7*E@];I_+\<V9_]\H//P'&,U8SM/6DN`VGWB%^[?#ZIF#_C=C3
MT,`_>$8$B$`Y:!((N80H4BZA_OHTWTHT96)C530%E*QU4SQY#O6`&04LZ[!U
M4HT0MFW<N<V5A$76K*!X_GYX+1X^UT):`2A3MHI@,MX,2JN"H__B>?1%```@
M`$E$053^A$73FEV_(."OXH`1F0$Y,JX.%G"HWR6*"XPH%8:D)QI.V3QRA'P'
M-/(JHTAU0"ZQ;YOQ$"[C(!P.O[7O;#I@3%"S+'MW"*BM52_38:.CG:P'B8>3
MA/4?#B*A,S"\$J3CJ8$QCD$CZD\[.PG:9SXPS+5_BIKID/%T^Y#6(2N)!L?)
M?O'[+>Z\!WAG9\'6UK$&7EU!D#B\IHR^UCG/V>T:F9MS_9?P7Z8L3%)5M?K/
MR[?L>QG^^OGY&3X#XUJ0N_\][(3&^>/[4)C9FWN7NUZ=`B=K?!=S2Z@K`W&M
ML,LY5]`)UOS]?8_3+MMGY2ST^?E)]_MC.+74>[3O>P'7E>UN9Y3@V/=]I[]^
M_C7TPI9`DUG;>;#XNNLD:H`8U^UOP/LJ?.4#D^,7&>%#9/<&T'J#^'T9&<M+
M"'4&=OG7-1AR\&5/3T@.JX2H+:),Q%WLP@1117=;?`@(QWNE3C8RO]`2LT;+
MGP]US@JD<C#9QS8Z@H?6;*)U&)(0F?R(9PN5N486QR2SJ2`XJECL"S09M!DL
MICYFWS(04]1(>"'57&'.3B+1CE_7,:+9=[+.">*K)C&THFO'$D@7*&C%L6:0
MV5PV4:/=:LK<_GF4:M6.K;?J[;U@8%J"=[\0+E[-2B!/<,`X*J9H!O;JICIA
MFMGJGHSN7GHH@7[?$X`#]7V&?7?OW41_Z6*[V;>?4*X@`4CKLA09T@HE8<BZ
M^'3@(*:*(00#.C'(@@J>&W5/8F1U;8&7@%EE;I93XO^EXOJ16\$-8):H3.>/
M="T*Y#<9GENXAP@$@Z2V$BX1[=W2[SVY8EKT?R)[W9(-!TP;5G_`^K?KMRP+
MG=95WV-DQR?88%D6NGY\T/E\#C>^+$+;8Z,]N/=1Y'78J62B95WH=#KU0(EV
MK6^W+]KS#IIG,>^AT+*LKD/76.;'X]&OVUX#*2Z7*UVN%Q>:E(V\K#P3MB@4
M.ZX!TC1Q[W[7NJMU5PN]OB4-KV*S)^W569O]);SY9E+QRPRJ08U1'+'\QC49
MK4MY__."7J-P&`PVPRW^\P[[L*/-(6'`QW.IA],I!2W&L$(]./(C=XS#/PO9
M9`X!>]?)<:RI%:&G-AQB%@ZE.U.@7E[K!$`;WME:P49OOU_[$6MG!9'G;\/P
MBC32D"?807\C!B&82#P\6YEB>14!K*(0!)TL:O@!@&DL/&3B/2Q!G+$V3;9Z
M7WYR[_5G=Z:M6Q0AFD^*AL9B:5I,V<MB+=B4W:"U02,ULX7/3/%XG2#EJ08V
M%Z82!KA*R,8(FU&6@M4OJK>L-04?2A.\7&`,9_6XYBP.V3<M;L3"CC:\MM%"
MAE8#!Y!3D0X5$=^F"6R_BOM%GNR-]C/Z]YAG05"B4L^-@\Y++,EHOM&D91$)
M?'A9IPYVJX0>$")P[F*"ND=XA1Z:*G]G)21#^E#N6P+'BTB6,NS3-#`/$Q"9
M*>]"C^TQO&F-EW:TU@JTT1(S?7S\H&5)W0NW_=2V[W3?MK%OL1G)3(G6=:5N
M))/!&[?^Z)[W?F\>CR*[*."=C-20?6=D261K>`SF&&$_''=-B%3TMIMGJ$_]
M-^#]QP#R&\#U+:'L,?*39\A2Y.6O=E/,(8C1_817W!EF?\F18%*>7"IY3V-,
M*@;"D78^NAESRMA,^O+,DY="VPR?CA3=(SF\*?ZOV(VS2C0Y9<`U!_9I3/,D
M0=469#/)+/%='E$;[*Y)5XD%:%4/?TE\.4'/*O)*5,DD-",`8M[$02C.39#P
M/U$"HN]K,)RJG!M`N\N#@K.R3PE:'Q)-@.(]MVE5L!G;(35.P_Y'`UW8;"0N
M*B4$MCIKT#I^,,4I?5Y#JP%WTUD.`#=:V4M*/K"$`MVGI0:,;4-WFVB@-LNX
M1ABC'KGWP)_M>W;2#QN,(4?K>B`OLC*!D7S&_ITE'V*3)4KF8^=.D$UQG\7*
ML[`HXZ>;H'8T$:5G1SUP:;>/STDD#C@K`%ZJG'%\(]$'[G_5>]<_SS61+P.3
M+`3.!RKQCHF7`J837/NF`2^.)D3WQXW^_.O/$6.<6.U3?5TT*8Y[WHO^?);-
M(L8Q1`9@%!O&`?>/I1[K4HB*I<9E]V<S9_K\_*2\9]//Y.Y&,0I"46PV&X8:
MU[33^402;%RV^$HIT>5RI75=:=LVNMUN@_%5MHU<,V.&OK<Y_`@2.*1CGW&5
M^Y8T_,]#XY>'R'[1>M>U?%]CAI\#=_6Y_/JQOZI2>!7T'TJ!^>AXAIW0T<65
MD.4W8,&U3\C)-69RNB-9!1\PI>P0&@56Q`P:5)07^*0QH<F$NF+'GCU-R!L:
MQUWV;@WZ/)XT`8)O4)R58*H:Q0!DYEGYK&RTGKSA&\E#_L#&O(`I\"U`QXWC
MP4?]E"3#@$(^?05A-H1"LRPRAK84RUC/(73)"CP^U:1T[FW%E,9U8-8.$YW!
MKRSJ</G0WV,GZ!LP2LFTV\W#V'QU<\XU\$"GBQ5,I%OR;`-D.O`QT<8@-6C`
M=\AA>("S0+_:S@5=%\A&.F-V+_FA,NNZD;OS@I8L2-?K:W>17-O36;G)6+^:
M84.7F2DK!Q8,XSAX5J6Y%PB$.UB;0U(L*@*J`JI*E+&@"P+/#-J'";7(L*(C
M%R+#W>,9`?`X-G`OJ=<VM\CB=FI9H-@?[7AEQ]>D#KT@'RX1(V!AR#PRR%S2
MNI04P-KV;S^[[SO]^?D7[5E(**G[F^%8LTCYF>:Z`A9ZVY[IS[]^TNWV4&3-
MON7ZN>-^Y%R;#'#M]BRT[UF'[=!@I4_GB[(QQ&<.07(6JD$:52*3%EK7E=*R
MC+]KX1,T0EQT&))FX953$\CS<I,#U3__9GA_`S[R[P*VWR%U`Q9PVDQ^AVW^
MI7]8\3C//E..M+GO(/J#5NGK;+AHEHF>`-*)%E+(RU,A0%([%ELVO$__LH]F
M#;Z(C^AXMB!)/,_&<=MR>JW:\:)+`-H2.8>``$]"W&-44`F][M2A@)MHW?!P
M:HATTP$K)-'Q\.&Q-0:!S<]'O"^;`@&C+U'/.XA]8Y'&DPZ->#LD_"=GG2#6
M904*7?1<O<'P-5#@;..@'8_#)#R$)<(4LKCH(ZL8]L;N95WAS087B^PI\&`F
MT\X-VOC-5:,Q6FS]LY$55?9T&"-,RI\8;="ZPX,93$)@2@'[&OEXS[S>DQU*
MLKIZ<)FPD>/Z-%EK=6'X+,L^OK/%32LF<QQ5^6MVG816X66)"G\_V-H'&ET7
M0;QD@$NT+?2[E6\RTT*9,LT"ZA.G'B.=B2@1]V'%+LMB7VCHX!RRBXYZUE-*
ME)9$^[XY/3AV39AJI'3-.U].2RW61.FHB87N]SMMCQW<1=@XO0"IP*@Q'N]9
M2DS+LI;@ARS$2YLAP8Z.7S.'1_A(:V0JOKHM%.3CXX/6JN]EXN*%O6>BY8!(
MZ@M&(F:A?=MIV_81[F+2Y?08"#M15N]G--<A\DJ_;\#["M!\HM\]P!A/VM+R
M\N^HQIZ\BNF:M<AH+ML/F#6#GS&[8G_[F1T8T?,HWR<LL5A6DY]+)2(_!MO^
MM<EID79WI':QX\RCWQM1OT,"T(^'3?@$ZCBG6F@=13N]CJKW+['$16)S]?X3
MP%XT`,%/GS6[J8K35UJ;')/#$$873S&XN7<BDR<%6&\!C0[:#$G0$4!9"(>3
MB(,,]&%91I=+-9ZL&X1B56/TN(G4X(7;T'HNK`9E.IM9>PV7EJIY%HQ+0[M9
MF<1$[AHY`[B"Z-=?IUU%WJ3M>Q-,J1O351]2T&4Z#9Z(Z>ZPB63VK7L<S$&W
M!@[?&5_8=*VN*ES8%#`\W2_"`CF(ZVV@50BD`Q(KQ;L/+/E!0>;6`V#XNU'D
M"&D++;N/L=)@-Q#1VO8)WKO!]KIW2#`NFMSS%VF;^S.01;E+%/_<!";*^H"=
M,ZO52W?I"#C-],\6]"\+_60%.F6M($P8YL#:]NQVN]&^%^`F=6%#^S`=:%)\
M@9=EH1\_?H`L`#VCF4ZG"WU<B?[\\\_0V4.Y*7%]4P1MEI@NYPN=3FO5RS))
M9J5S8TK&%G`\O_N>:=^E:'>I:(ROURN=UK4`?+#B:]*0C)V*J?6==)G%DA9:
M_W6B?=_I/__YW[TP83L@5)_!/M36"Y)4AFCK-4OU_O;')7T/K;U(),:ZQNG`
MD=G3YALXOQPG3!&HYB/,;'16$]]6?@6(/N.Y7\#M@A+&2-M@=6P<5Q1B+AU'
M?T=!U^L9HN()RV@W)O92@/#<)1IE\B!4*#+-ID#*R_,B!0W2\5H&\U1NH$%)
M'5I&N0\0"$EYT1/QH5;A8*AH]HY)4)3Y9#?I+`$?^=W)<?%Z5.CU3`]K:T0X
M=&>C;1N#Q),0"M'#GC(LY1KCP<KE@$.?7_*!<PKX]*L`@RG1L3-X\C;\K36=
MMNCC@\%1KPO2X)EZF]':20^M[`#O"A@8!DH"FS\$6LTKF<.)?%P?M$>TIU4M
M-4_*-_@(Z,Z>-PMP+=NLK-,P`:]C5F3D@P$Q>(<QH:Y:5`SP'OIX@V."BB[6
MWZ$MLT1YW>*0&`[1,9`48HD?]%Z&\`@A4OI,5<?B,Q1TSA3KE[2.O1,+#!T.
M$CW?3)C<)N%:E>L1)DH56R9*E4$=<J+"R'(JC"ZRTYUM%J''MM'I="Y?F'6P
MPK;M!6BO2]'Y"I(W/(Y;)<:Q8J(?V][?B<9J[UNFS\^OXK,;%+$-;&ZY)*9E
MDEZ(91%:3Z<R/-C=-ZJ3`Q'='QLMIQ.MRQ)*R.S=RGDO/M8ID7`BR7MYCO/H
MJ!&L2PS7#RZ`6<=;-Z,\1]^`]Q?9W6?!$+\2YO"6K=A38#IL1:*6[N'Q/&&<
M+>?0<"0_.>FHTXQ_QK/OE^.@#GE&B4<`,YCQL;-R3.3:1;-VFRJ`(/9RVJ8_
MNN`RJ18BO<"!.0(S,"R!7[&?#32`WCX[!^\%#G8TL"+*O2-^NJT^.F(#Q#V_
MPT9ITEDD.R2&"413=BE@>BV[W2\1CP+*ZDV5/*8S9*3``S=+.J'A;,#ZR[44
M0%4-Z$*IM:8P3(7`52A(MR/QJ5NV3:[<)/"WT[BG;.W@GBQ7D7N%&$95.4EX
MNRILS3,P#_UU0!-^ZPQ0(US):,Q5FEMM?R.SZ\(*6G`'QS'<-HC!:7`#;VD-
M=F/_#!74H6*#28%,+*Z6Q(KE;H>B6.\&T'BIUS0-J[+ZF9&E&Z%<!B*'QW#6
M8"I56`*C=2*[X;EH*^@1U%CAD/>WU76FCEM.J<0RC^Z!F#1.'SFLUKUZ_1+(
MF@2>QR4MM"PK[8]'97FE#YMR0JEX92&I@$G4FK;/:\>^;0_Z^?-G[700".42
M#&Y)&`'?"N'M\:#3QP<MRZF?WYYWNC\>74]LYT%:Z$-;6ZS7=5;OQ7B9T[*4
M`<(]$U76>K8H9!'*>:>__OJK2X_VUNG`HHZ'PPS7288>XYY+&`X+:Y=.THV!
M;\#[MR/D-W\$6X_T8L+8.PG'3"3/+)I^\;-QFXBFL\/M*C`D"*4)TXMAVSF_
M2MMC"Y]<I*J6J=A&(NE)6+?AS$-'F'QTYNRZ119D["I8J!:,#G0F`]"-!1OI
MJ=.LRD*7?/QNUW**^KVQT(JSHAD%P?$PH?"!\P>SLZ5R8+>!48G9>G8%C0'O
M";L6)@6-92I_4-93QK,5%0?#XFHT'81\#CRA'()\O/!H]Q;0U;^S`HN4-*`@
M?$^9ZO0V:78ML(3S]AA:TM0GWYD4J)H]A%;'3*R+!B9K236^:X!=F-`VC+JR
M+.JM:U,<D3:10[WN8%1%/S/-^HL'^-HK@&HO7P>46&!AP>4L-T2GEMDE2N:!
M%U@<BI&`D`R-KB*L6SJ@*4#QW-O040JZ+@+3[R'K32VAS),KC=TL;7'6-:D0
M%+/D4PI-YV(V,X$K33OR+.4-ZL.&V4C:(#.R'7(V=GGH(SYTW:+62V89(\+2
M(BF2DB@TN<$`>^4ZIR71:07_7=%4]O5Z)<E9A5GTC4NMM]#=89W<>#Z=Z'PZ
MTY+Z$="ZK'0ZK>4\LK@.;%?9-FUR*AKJ94ET/IW*(>2M/UOCQ'9BR;2D^F;:
M@8;Z^5O>*==DQ+SOA47>]R)],M*']L_2A`[&,JZT0\2.2G?O:/H.GGA-SO`6
MKF7Z36_;]_[\.-R6#ZBK@R_B-Q/3GARW8KN,:$R")$0FW[+5S-1K106':`]N
MDA+ZDQOZG9^=S%E(PN0I<$.8D*42/#AN3LG<9ZV-U7*&D4M.T/(2LFZKD2F%
MLTT*V%=DR"5X^CI)]):WJY]*Q\&0F84<$I+8N6[A')A`I#9E<Y[X<YS,D0<M
M?&8?[.'N.Q?=8_O?C`$@3##L-8`W!6WRUHXEKKJTYM')FJ%,*9F4,<V(]4V1
M86/B`8J8J;LK,%-HH<73-]T,!D'BEHCU\^10UC3S$66XCC91BD#CIR4./@2A
MG)L.'>A3XL9-@<!%`DCZ;O_D!JQ$1MO>#,PY"4,[Y@:2B"E)'9XBHB1E0V?H
MF*7ZO"4&?U8HLA*GX8G"`PBTZY,*Y=O9,A:AI0**]GE+2I3J[R]<9HUJ?EA?
M<1/83MEWUA89R@8N"QG;;EVP$@X+BOJ='O<@Y;C;F2[,W5H,$T%9VGEWK4P!
MF-4>H%WWI.*'0))5+<L2N)[HH!BJUQN<?IKL*0^9RK[OY5ARI@3M!Q;_3K7!
MKV5A2DDHL5#B<M^XO?\D=#Z?R_L?@/U^#)`.6:<(Z;RN],>/#_KCCQ]T.BUJ
M>5D2T[__]2^Z7BX5F-;G1(0X4__?DG.]_N7:7$ZG$A<L9=B,JS8_P379MP)F
M^W-)P\.<4[DVGW_]I+SM=%H62LRTT&#.^W_6^YK:?>\%QM@_RO>WPJ8)8<J_
M"9)(OQG>_S*[^TR\\"Y8YFE7N\]?3W/3A7[--U=>%%\P:49%O>23[^`7<3D]
M.78VXEG,6U*#8Z2KX`CL^<V8U7G,3@(Q3!PM;%E:GC,](?,\OS!LV([Q%Y$/
M,[MSC9*Y$#9;4&+/2P(_8:V)BY]`UP:.VHHHU^B@V1<M.$@1F?Y'0T,]F`1.
M/7%R4IAL-*V]M2GL\KBUB3H.@0VTSFJ`</B#(N"B7`M$[`JA@P"[$;S"R'3/
MX]2MKQ*E-NA-*:/^+^N[!1K2[C=*;)A7S<2/J-[DV_^D!R([,VL'>OQ8MF'6
MRCW2QOX"7%V@C*J3ZU8W+_E8WM*92Z:#T`?-\A_Z61L9B=/52^1ZPHHE)01;
MG>G.?;W'L(_^E>@/;=[O/6=*G(JUE]/Y^P(1SU\GHI'R]9ZO(Z:`-]V;<1W`
M48*1T>:A!JI`-D/X1M=]L[@N0@:OZ19X-#QN`;37=P&E$LSZ>5#2H+JV+DM)
M,KO?'_`>Y1)'+'I8LK'R^[[3[7ZG95V'M:&V/:'[_:X2]FPC"!/E.N')3.?+
MA7Y\?(2=OYQ+(MK]L4%'BF$?&?>TV:\)$:4ED52KM19EG7/NA?VV;;3M58/+
MOM`A(?J\W>BQW>ERO1"E1-RD)B#+Z>MK8K4F)-;_6Q,9P1Y5GY=OP/L,FK[:
M,Y<7NO&F%?@TV>$W6>'!AQJ?R:?Y7^]^H[P5GA$-U*M0A`E\Q\%V(6-98K\C
MF-[W4)\/K.7$+?1JL(;U$`V;7=9/+;/;S-S@!IS/X6/!H<QY>F_L$`9^CYA6
MMMK4HO8ADXZ[M2X&1D]I+XH;F7,6!_QT&,@"+=MXC/Q5!V#(6B)"P]Z)+3M%
MK`;MF-AO-*"3Y-*O!)>%44[H--3AE%%^'C6XR6Q>4*,DSY9ERL2<AO-!9WE!
M;0?."&URO#'9`FT8D0QL>=*#@ZT-RG&(`1M9QFAYMW.'P2D94HP.F-J]2V4B
M?&QDF4B28C=17J,LF,QZFM5@G/0!-0DBK!=>[`L[B@8>AOM6VRG@PVO?MQ0&
MD)"S\M,1OC&SGK-HZ8=]D\SP6S_'%GY04\F&S,47@:W($@%313D8VJ[WSG5"
MX1U65FDT"64QUG/H?M+>G3&Q;[-#(:BBGJ\PN"(HG2YK"46/$1ZM<#5S`#'.
M3;8BCL3QFMEF2T:$SDBL;".[CE]*//?"R[`I2\EM9IR6$<H!VGN12-XS9%DI
M,6W[1K?[C<[G<XV"'FJ(V^-.?_WU5RWZ$NV2=8)::XBD1"DMQ,QT.I_H?+G0
M8]OKVE`*]"ZCDO'SI1BJ1\B-KRTQQ#\_OZA)J7/.7;=KDPH;(X];6P9+0*(A
MJS)E&@AXRV=]`]Z_B\@]<`N(?^\XOO$=^O>Y[ZW\!H?\&E,MKV#>21JN_VMD
M=R0<1F(!?=>S"4+GI<`OG-50;V*=($QAK"]Z'0@;"47@8A&%&\<M_Q?NVN&U
MCQ],=1Q/Z'1<_,1,V%OC>$.I*::@L2W:,U%/5ZN6*+`U'6QR`'+9L,T,_]E*
MO@:2)FR3`HIL_'$QT:IN%APX$A"/!"?E$03,"5I:-;/\OO$:YH]A@V;23&([
M+L]2LRI"&#9M;+?WH4H9<N>V^8IPC1#%(`L&+5RY#YU)RT?R!@8]*-R7#*UH
M3A"4D4V"&)N!-B:NSAR[D;Y@-<+X[DZ?:U9``9E%[=`1#S#9%U99EIFI?I+Y
ML;#`>@.3YZVUW\\'"]0`?/;_!!TQMZ0O`R`H`,="95W%05UF:ZF31XA`X%S@
MHG.[9AA8NZ"HQJZ)B_.6L<YT0%1ETZ4`]!2BB&8GF\2C:;E9Q.P,X`4,N2[]
MOF31#3()_"RAM;>N)UJ61PEJP(Y("T(P_L&$FOM^$%AP$IW/)_JZ)=IW<9M(
M,@EX*0T;Q-.ZTEHE`UH.0[1PHNOY0BDENC4&608^)V#X4V+ZX^,'+>M2W&AX
MIW59^GTI;F?E7ES.)TK\@V[W&]WNJ7KT9B(N:7(_?_ZD/1>YP[[MM*9D]@R.
M=>!FS@#71F8="TWHY2O?DH;7N,QHJ.4%T/L+?WT(UV9LICS]W"<>:6_+&>(S
M^AN(ZA>O&^CLB(P4@77KV69O>_?@P9;(_/MZG"N3UUA.)(UX/10`MI:"^/T\
M?^YF;@\XL&/O@83)Y:]U!G1Y4$"E3$@9_-\B?@,8A"SWECZ1EQ9$[?'XH8I=
M@8=\%NVS*E"J&R^;A=.^VPV@X919M[NJNUUOAYH)<<7WRK#_4AM;%11T;^S&
MZB4]W98HN:0O!'^J281@!H&E`LX&]%06-U,NND(>+7]\;Q`L)6!Y\YYKRW<,
M\G46.0UM,=H)82Y*XE0+H'$L)08UT2:[=X^`Z\!5KYQPJ-$DG*&LHC#78RA+
M^?T:OV,+9IQK@&69+>N-'L_*L0'879;0R4=KNL=WY+Z94W<':+^1L\\K3VUH
MD<EYTB:,7!9V78<>X(`,-F5*#/I=`FD`L8NLMIIE=$;H^ESV;W)"R0';;HH,
M>1&^*DWWFT9QX/4@NI.HUE_EL$)=`RT!!L!A.,4P=Z`O'1"ORZJZ@N-SBSBW
MR`&DRZ6R9-KVG2Z=4O4/_[JN]./C@SZ_OFC;MC!2NA6EU\N53J<3W6XW.IU.
MM"QKO?Y)K77GTYG6=:7'XU%TND#@M/>TG0\G+HEH=4U(RS*\=.OW;]M.V[;1
MLBQT/E\HYTQ__OE7B?JFX8>=<P;65LC:'R>C`U>=5V7;(>2I?SV(C4/(WX#W
M[Y`S_$W$Z4MZ6O9(]SE`9576O71>_,YYF>R329'P*Y<)!U*"4S<#*Z*_1RP3
M.),N3(H)98^C$W^(23$O>O6>`VB9R2M8YIL&Q0E/9.U[C+>I6Z"#/'.9,$6:
M=?53A3[AS&-1CJN+MUXG'=G)8`5FL3`31B<+RA6,E=&P9A+7BNT%1!6!-ZT8
M+IHZ1T_ZIM#EKS2&O\9U'%$`W"@;'LSS2'_R;LVI#:BQE8QH[7$RS@1V#>-4
MI0^L`:F(CAH6D$(P3'3C?R\%!'>#?3+M>*T%K,]A&4GOUY=-8$,[EB4ME/->
M6^:@VY4QD$A2K(^Z_R>RW;7%V<-)6P%4V]W]?MG8X3K<U?=59T=EAJP,4]D^
M*XLQQ`9G![0YL\4S&Y;.I?/!<3B6E+43A9B"43/$I)A%+*N3"O\8NNCN!D*I
M_@S:>;%B<>U"B]('[(CA-41'B11-[?*0\*B"#O0]S$/Z4<('4MPN,^*3!L"9
MM9.+^GKG7(+!+OYK^F>1MZ$CHS5NS_?7YQ=)%OJX7FD]I]9.'/<F,7U\7(E3
MHC___+/X\0:LETC1T'Y\?)#4H;)]VTO!FJ2X-*31,9(L]/GY6=;%6B`VQKF=
MYKYO)%EHWS;:4ZI!$:D,I27N[^K/SY]TO]TI+0M]7#^*OV\;XE-&V=3]KR.@
MH_:?;M&GU^O$PT?9BJN0FQ*0`WT#WK^9BGP]QO<H*N)%5EB>`TFGW00/3PJM
M\X\/:#8<AXM`9+;.`3Q6&[O.L-#?Q>3LM)Z"?)YQ@NR:^FQ3P4P[3T`3)*QI
M3/]=9GK9,9X2EPDN^BDX=NN12H"3.69=19A4T")KN[`C?9Z\4!2HA=Y<O_#4
MIY[![.^MTL'J``:KFQQX%T`O`!K)`SRD67@"&N9S@I0IXQ$*4=$,NC1.Y!*J
M$B]>-PJL9SO-!.EL75.9AQ2"NYBQD\3E[Q,KL5T'*Q#%A:"(P#NT[3^9:HNX
M?4_6K#!S*BW2SL1FXCJP$FFNVW`;#M&TI[`PDAKHC*$D[NRQTL:3EN?B>422
MC@$&D[)MZNUU,\@H.I?5VR@:]9GU-W9#6J3=5+"KT)A.3%%3KS:2&`S68-R*
M&NK^IPFTKKE+=K%``,TJ3G,`FZMLLV!Y&1(8W4J00)K1?(LU^<`*0(;#:VVZ
M'ECGJ)C0(1L6YXHZMQY:D2`<I'4J7%8XZT*FS['I,`<<)&Z?FR&F79$A]9>6
M=:6/CX_JG>O1L+*ZJ]=ASSM]?GV22*9_K7]T/>RP,"S'<5I7.I\O='_<J\U:
M5MV,E!9:UJ4,CFT;?7U]%;"W+G2]7FE9+NHRI+30]>.#]FTC(:*OKR\B$EK7
M$AI1[,AJP0[2B/8<<Q:ZW>^T[YEN]T=Y1O:=_OK\J6(CK12G!:LH:T3XN\4\
M%X9^Z;_G=_1!_`X)F7QK>'^9^9TRPF^V]G4&HYJ8C\:0Y"T@BI+^B<^8<.S;
M^D(T\B%(5X;Y$[!KT2QK<*@6$P&*PNJEY(4)+W<1Q2'JOE1+/`JE0`NSEBX\
MN\7V9?2W7L/9!Q<``"``241!5"VZ<1>?8<`*6O4SMITM4Q@,E5#L7J`.(GBP
MV!F^^\AF.Q8XAC0J_QH<>_.,9O"*Q4EF'&21Z.D3GXXFHET=5)RRLSW3+'&W
MLJ)A887C:T,ZX:-TEX5[^S<APU4W>#(MR*:=4PQ&BH;Z!H#M0,$PMAV8-J/[
M@41-)*X,YIPHT&U6:R!N8*UL=KG:Y6/7)"/#+-;CE:A[90FYY+7F),'5H;3I
M3M$OM>/WG,M$=QO$<RU/,A/Y`_@W^Z>,U0\,M"2VN$3?-X*N06^[FT`+UY40
M'D$6,(R$01Y9@.T6[1MZE`281;.E[=[G[J`ARH.]Q=P22'U:6WT`<A[A#CP`
M="3IP.Z7#@HI6O`90^J&Y13[R\HS&*45"3H,*`/C@%AILP;=O:+II#M3/2,U
M-)#N/O:L'7Z4S9I0:%]XN5[I\_.KOMM:)J/.6W7>N#HUS`5G]_N#4K43RWNF
MGS]_4A:AR_5"MZ\;+2G1Q_6#<BZ1Q>TYOMUV(F):`,2V8SZMIS+45JT/'X\[
M72Z7&J(Q`&^2T?5Z/!ZTI*+AO7W=:=LW)?%I_KK*/8;'S(+.31053M4*"[9>
MTL9Q@T@[9S@"1K3LZ!OP_J+T()(:,/V*CM4/4LV`;X@X:29K&$S4%!BSI2A%
M@4UD*"1BY]X6)7/P>T;/)F-81RTX(EH?2<;Z"C8(O'ZN.X8)6?U_RU0WI;+5
M.:9N@ZM'+A>Y3\(KQRJEX>5@P^UM23!][P!'HI`)G1O'S@))3^<[GPIS'8=0
M1)3><<Z?EW9U<M%Y+U93)/.:$/1\?8@+A`)LIJ#;0LJ2W/,U!L:H"2.I$9:8
M5C:LN.HWH3X$?'MS?1X&2-5#%TT+J[2MB7LRD';)&`X%0R<YAO::!$$EKC%H
M;I$)!Z/[]C,-U%BVSD[=#PTG=X_.3".\`@%,"@(K-/-O8X*+>3WJ=[LE6GLN
M4Y48"&HT`:C4X=4EE3AG9/3;BY]:.SZQ]P$7":4\^-\3LL(&U-@H6W3T2*VK
M`%(E3#5CR<Z#G"O@[,`H);4T[1"FT`]?+&-*"NB7'6!Q27M<.P\)V->NS4S:
MZFZX%%`HNVJ:8<_>)K^^FV<+V=\C#_!N>P7'T0D*'MZ]=N@3_74'T]U:Z>*<
M;G`[Z$LGZWNO+/E$2#@12XGIE>IR0))HWW))7-OO?1U'+7.7_D&K3D1H>VRT
M;T+KFO3@9)4XK.M**ZVTKB>BD]"ZK+3M&RTI54E..=[/ST_:MHURWOO[=[_?
M*:5$U\N%T@GUO*E:])60B^NEL,!%*ZR)E-R'8%,'X/^'O7?=CB2YD80-'I%)
M5K4T^_YON3OJ+C(OX?A^^,T`AP?):HWVVW,HG1EU5Y&9<74'#'9I+@V&.AD@
M]LTZK[R;);PBI<VL<>W5GS0L9&3.[UZF=\1J%\597'XCO/]VE/?LY]=B-SE)
MEOT$]>"$:G!::JQ`/(JEMJ,Y<;2##Q1ZQ$&P>55V<]#0K]4*C_RH+W(WT.#K
MOW8G(SB3\5_7J:JG[XHK6B6>YT<WI1?X:D8\+$B:*GB!*WS%C5#GZS.C%($*
MG7QANU.`<KF\N(HF?SU(D6MCR67,&HWLU>-3D6>N&.](]>EH%+[!HC!5)[2L
M5@5=V`Q!VF0@HE%D;C-/9W%33RJ2OND8OT[N(`6&FPJ1B:LI*4'8]JGS0&$C
M/UGI!.(NPCLHD`C-W;UV'3H?U=S7LKGE9D(?C*7550G\''!A/#,@4B_\_:B?
M1Y+-.[452G,1YL13CC*E+&X!PM%ZLU6:0B2"Q+*PK=71I!Z9HGUS"VXHD:DV
MF,%.'H[.)R7ZC(*\E!D`B,&7*25-AQU9MZ93M<\AB;;8B06(72?XWUOS-/OM
M:AB9#5?H*M0&VO3TNM9(4A.3)+;79.H*[1L*2U]H;B%*:7#JC&S:5$2GIPD4
M1,%1T85Y7R@$!RZ7K4XN-ERO5SP>CWZ_,GFM*4T/>A$MP-OM'1#@CY]_].)X
MW_=^`/M^,>O<Y;)CO^S]LW[]^H5__>M?7=AFK<T5C^<=KR\OI:'.BK2E<5UZ
M\Y'J=^UU/;$S-:GI<'_^^2=NM_M(!'1%KGF7'-JS7W;\\8\_RC*5\WB.()TR
MHM,4M^XJ%8A0,PYV&B)"DYL.XKO@_0]5P1^!H3H%(V+"#?7?=8@Z%^(S4J<?
M!!RL;79\R(5.OR<?7C(NM%AH,5U315SF!XJI^=PG5]C0U$*AIQ=.W(;;1_?B
MU-D(K'/$CAD-=\RCS+J(8IOP6UXCYM'#[$)A+840A328(E^-;9O="$9A)8[4
MKF?4DT!H)<&&XY^M40AJYQR6Y*O<NZ,FOA@`HKAGR2G"!2:8!#(V=19/F4AE
M]HYTT;K>.4/4\EFY0>+I?#L'+KP*@IYG[J.,Q+7L8X';%9S<,+07+))D$FJQ
MU[0*IO-JF?=#$)G-RM''Y2:"FM_O:G<D6[_&4!O,D1H7,Q]&G*K5K-\Z<M"$
MPO-S231F1&;N.<_>NS4L;-4@KRIVA"YF?&2+RH;^PM@JC8I$J]^O.N>#_B-J
M$5-U+*11)'-1.0",-N(720Y![9:]4T5OV!_^F@8TF(%8<^PTA:DPZM9X\R1V
MM)\UWFMO4V4*;YTI$3T<1CF@&]U9HG/T^][2&I12]*:.E*L)Y!"BGO1)`P1'
M];N]7'Y"H-CVA-?M%4<^\/[V1M>R^G[3.V?6.E&\WVY05?S\\;.'/`ROV?8,
M>]9T*1SOC_OLQDGKW?$\\/;^CI\_?PP1Y9;&^]W6SR;PK).=]KP_*B\XI53"
M-7BO*;G1"*W\Q*Z[.1^5KP]D/<Q$4@EN%\_IX5`0Y\,T>..%Q\2IF-^V9/_.
MNE;_1D&JOKR23Q_$Q[9DOE"8"T<-Z0:>WRM?MUJ0(/WADQ^@IHNG:$;AL;Q.
M1;(ISF`,#69:PH1R?^)*BL0D%*=T$<<YE@9E&Z'J&34`%M4]*79U)MEZ>K_]
M="^T^`0/Q]-@+"]VC.2\'=ST##CTF/^3]0S]!B9U'_V/46WK$!ARSKJD@B#[
M9"_5W+G10F.-@J3E@;"I$G)I$;$>+\N%EK>PZRA(X:M",V7]5?/[QKVM4)-*
M[M^;-)&"W"'"J)&GDI`PCGF*L5>0;W%CE+LQ?RL(<RYC4HELMK2?HT\N:ZI^
M@-`[]2@L%6-TG08R9"V4V.F`">_%^<$6'UI136_-EK-.3>K$W64AO2DX;0'=
M"W%7`%IKN+@8!(_S82W!.&Z6FPYO;R9LEZB(;&E,<3TAH>H#(ZQ0DFVAQ1G^
M=^ZYFQ$9^S-)+A7,1I(W!Q">_$3-8@L<\2X/+36P]_+.):+[&*M?1WDY8J<5
M?CX4R((L))03ZR^<:I3ML.L>"/>1%5L:_ML_?Q:W@L?]WN^5D%N,H8/IH*T\
M'T_@!_!\//'^_H;+Y8*7UQ=HH;%W*LG[>W%W2%LJ?-XV)8#UW<Y:IB*:,Q[W
M.Y[7*RZ7"P3`O1;8);YX0]:C-@*%(PP`/W_^1,X9?_WU%Y[/I^,_BXEVC_9E
MWB:DBE/__.LO_/SQ6A']V:NN<?4]\")4X)K2Q=LCJW5P^"YX3PNN3Z*UGNOZ
M10K$>;GA2CO]N_0*/44'O>GW*JI!%W[``6S\Y4.RP@$%"YI-:LN)>&_I#B`Q
MNBMMZ?MDXR*+#&06T)@.7&0N3\6P-0RB'5YL$4<CUM,&2CT*+@B.50%(F'C&
MI)AAF13FKPV4E^(V$2!ZV24OG;Y?!CG#,&M7)U[DL`EV^ZB;1Q->D:$"M1L9
M2-4>C)&^AK[6XF`6Y:`@M>PZT%.%N+%0HE_PPIQ]+F@O6I((CH90>V%.;O&Y
MVE/7BG]M0[$K8M*0UX9L*3V-E3RJF=3UV4XOD@AR%4`5!XD,D<VBH3D'CUU5
ML`MS9I6*T&32OK+F[@HQ"M,F,AKBED1*:S'4"9A[8,:I-2Z7$YC\.+X5#=;3
MM)XSN3`85-&,3='T>XX&X18+U8G[+*`0$Q)H%@NP@5Z)"`ZV4',`1D-.VW/A
M4?B9:RPF7EB:*$S@J!8PUG#\VK;K)L29M][@<Z'/>*2?3&BT;E%ST'Z'A6P1
ME<6#3V7=2/$]-/,C)\Q3V]AWCK"G?KE[<;N51+,M67[LC]<7',^'21&TWZ=3
MHY8UX[__]=^EB#X.W!\/W!YW7/<+]OW2T?K;[59075CDLZ^%9,O%UGEO;[_P
M_IYPN>QXJ:X/S^<3NEE.-Z=3OK_?ZCD$^X_I&F5:YY/,0%3A%UO+P^@Y]MVH
M<>*`M:+T>P1K>KX+WI.1^J=]>#_AAWO^ZQ+0YP/$[W.'\>'?K?U^XTJ54Z=.
MOWM1F'V]_AYCB*RK*I]2O#1&LB<7!J>&5<,-'K9=HI-I67S<:V8!+>RN8-%H
MJ.RH'JK+9`>.DEPU:E-:D5CT8(`^)^E/C%R'+@WV21)C(JZ&O_M1V(-0NI33
MX3@#>@ZMB%$%<4;[0SQ#G]?FMU4(:"@4HG'2'L:XO13(,$(31GC9<4`K4BM!
MS\&\1Q/YVHXCUPT0:?*V;EQH[4*H^=$<1;^]3MIY;:D["/!O]A$]I9]MLO6@
M";O9V9CI;O1.-`?.N6<N:3O*K'$L;GLF&BKEO9\/1_E0U2FV]LC9!;%I_(KQ
M.L`H)&"0.&-#)FYC#9YM3C:;K>WBQG6L3=;?MY^C>T\,K4-CX,;08L3&H_?S
M9/2VOI,CI(1'Q0J77&R.15M$;!O=+]YY>MBG2GM8G:?>'`JL=_)4?"Y22W5J
MS.)BRGB^IXC+S-ZQ8N-W,9P)GH\'KIMU6MBVK8_T!7,J74/=C6]O5J@>_1".
MXT`^#MSE41'D2H%I:U/=N!(]X-U!PCFCH(KC(,#S^<#S42S,`.T1PONE<(4?
MSP/[7F*"[_<'V.=6P7IOLCP-!8CV_85IX@OXD&9$B5+4YH+K3.@8O0/?!>]O
M(+SZ&Q#K>0%XEB:ERY_X"E%`>7%9#N_EY#ABY'<JC.6+U\9]D(CS`'5*<G7"
M*2.DX[&9N#9?(^9F&RDJ(7"#Q*M1>@3%&:ZOM2T">MX[YCA+@3KAN"YH()X6
M&'D>+^REW+@T>KZ,2,ZO2#)`2/91911(86/EF`JSLJ[S14$.FLTAHEC9MDD?
M>T)LNI>42G+>'!73OWO>H$>B],2HNBB/47'01F5HL@OI\;UV(V>49Z!HQ4$A
MFZ,HOK?2>=$:N`OPM>K(:RW"!__2CK$E"3;L/?FH352Z=R\5?D>NQO75D[=\
MQS$]@RUJF$?ADL;Y60H+I;RY]YJMJ))QRU#BPB9D/88P!C:^F-]7W[Q.3)LF
ME'&N![-7[UPTR<)_G-%$8;H,+!7!!F:,,)N"4,N4EM807Z@3&5(1&ST;85'N
M>+#M$'-60RLQWL--G^C0!G4(K3^><'^5>4TP-I`R'"R:V#6Y]UF#(![;P\U4
ML1EA5ON,4%)B;\),ZIM86H2,W[F]WW"]7''91WFU;SO^^8]_XNW]%^[WQXP6
MA[6'])1AV^AK$456MY9DJT'#$U;Y>-1:>+^/?O[/NGX\CZ/?RXNTY+@\N,_L
M.P[%Z_45SUQ"+D!-;M:8I#G\A<OQ;MM6"OQ@?,Z!*ZQ[49<K@,GK&28][KO@
M_2U$]O=<&K[VB?HAPOM[Z67Z&[\S%\[1V#W6\)\:K!GJYQA1S3Z<T<A$(KXG
MB0QHA1L+.M9*:_X.,QIQ5UW/6A?58"Z/F7Q/2-%9`+#WVA!JJ97].S'L:+P1
M!%]G0WJ"2W>B!=+I'(QG:^1:('!J:\^I<+9/D6'_*D8XIC+/Y]$'$97WU8HE
MG8J1L8BVM7,\O3)XO6!/7YT0_+X13_=^+IY'PIH,I-@57X-*00X;.MY8S=KM
M@UAX$_E>JVIQ!&@[)KFLY".;?S<^O#+XRC+S@)!0C.^?SR?R<4Q"IO;/S9:K
MQ:@F0KF+K^?6-]NL5-P$S\"V%2_0Q^/1A6H#Z4MUK'_8=]`EPHP-4^ST956L
MT9/BBT[^9`D*3-NLI?X,1$AN1IYL%=M#D1QR#:8$U1,P$:S&V0#NG4N3<-"Z
M'*`*!\M$(7>1E*63>`<:SU56)U1N/-NEKRR]SV84K:`88EL(9RKV_3HV$/6R
M\WB*AKKKTL->W-ID&B.U3A9P"9,B#'0(GL>!M_<;CDO&?MD*N@O@^G+%D0\<
MA^)`AA[9%=]MVYJ+MM;\*-VL%E/<[GDRP,,01#8P(+OX[(QB#69!B0';VB%I
M:7;+\_PL0,.VT3N]X\>/5[S?WG$\C[XV'L'DE=F`Q?>W'-L??_P#M_L=[V]O
MQ?Z0*E:I695*3<R4"EK7.2,Z-=S&;X3WWP`%_SM^7W_[P_6W"]\5E0-+1/4S
MI?(J,$P]"JPTN@U&YHP6SW9C,GV7#2.0Y27T=D""$?=Y;J),BFN5.4*7/E^#
M$8!^%)D'.;FOV@5OAN_7(W"'LEO4Y?_"_BN;$.3H8)T%#,06$6-O#H;T)!;C
M0L_P!;VP,.`.MP)=H:?4HIX^YL2(@F)Y<[V^0$3P>#RJ'V6>A(`:CH`'L@H2
MJ'ET3\Z>%$HIZW^68`K8:)ID1M=9G?!LA`(T0V!?1[1B(`<A*27.5WH4:+NV
MY;KDSO?KF[LTU?KP/[U<+L60?MNZ[=%\70:"7/QT-X@D;"GA<KW@<KUV+N9Q
M''@\GKC?[S5.V#N4E*+]>GGI+]>1LT'#E4RH)K&DIP1XY-ZM$1(AM(O`!*9J
MJ'>[]^_.8BK4U]:<>U1R]%UV;0RF,'P\#0UO#2R-TD$.&BW)*J4T:"SUJJ3:
M^"09U)*11":=PN,]>,/WE8JG>9ZM4^$R'%9@T'^V,?/I;4I!("(D6-681M0:
MN@*L9&MAR+6?!,X4Z)`])@_R^K*^O_\"\(K]^L?X+%6\O+SBY?J"V_V&?_WK
M7\B'=MI&XZT;E-8T].1`0H5Q=C2V:5G5^;E/4[2QM\=WZX>`0BP4U^N.__KG
M/Z>UV`I\`W3=[]N2`"3<[_<IB:U?!^>!G>DY2["<;'.;V&FG6:%]5ZQ_L\;]
MF_S=C^*(STI?_<VZ^W-4AG%R?A`/L<B6]<-;!5MH0'W0:M_ETJ]$UC`Z"9/\
MR%ZG$(W`%S+:=!R_;HW`RQ*!58?&K=+DU@^1[3CX+#KOMB[0/0YV<8BL5M;H
M_GBQG$=`.])KDZ+Z553+JP45.`.IE7#,.-*=K(#"C&5AQ[^1V<?P-A"'ZI5?
MN%111U0T:!3I6I^/Q`V9\C1!C35>%WA*,S\O>`DT(QO,1.<D,'@N*6W:R9U7
MC@N?\=E!PE>[!WVC<(4H+#I2Z`G6']N\\2UE*25<KM?^^YX[RT@J*HLYI81M
MVW!]N6+?+[C=;]W2**6$R^6"UQ^ON%XO!=UY?S=/?LXET>EZ?>+UY;6.VIO1
MO16L^$5.@^F+%<<-01P7C$8\U28@W9TAV?0U+BHY1I5&\J$.8$Z9Z5QA#KR`
MI[\0FJ_!,:^BQ\6-;%)4R&/$0JN."?&>''*-.31B?J<&:NG3^!I2UWG[4^RV
MF"#-Y+W',PS'V7KZ#B&CD!IX-/NETT^M*<A*2[,"FHI`L^]SF..Z=:8>F#6X
M?716Z-'XQVGPC)/@Y>6*Y^,%]_N!XWB.0J#'Y>HDNFD<7]\@I!!=LNL+3RL9
MY14"*J:):2^*,X[GLTQ7(+A<+OCQ^FHH-7_^^1=RSGA649Z-;Q]E;G([7J[N
M%9?+%;]^_46%/Z:U"DKX1GM7C%T5R=-"4Z/OX(GSL?07"DCY79Q6=2V,"L8!
M?PMDEGFLORH.`UQU&L5[5,[-=V*H5]`C#1MZ8[YAU,(SMXD]+L_.CQ!(-<5N
M[#ELCM*,1,9W#M6X15@,6G?B=QNAY+IX'I;M"*6UC69)3/$S:!=T/P0NW4-!
M#DVV$U<-F@1"[]0Z/[)WK5=AKSB-/`[NL9O<\"@5L,)4%YWYR<:=H=RT;=N0
MMLTD6RDE<?GGME'1NF684DJ=<PDIQ4+BAW*@^NK<5)BS2<(.3Z_(Q$GE:S?Y
M-I/:NGF7,B+-3@`#";:3@E0YN&U\S7QA.$-^'JVGE/#Z^HI]*U&B]_N]J[4M
MVB;#4:-N[*\_?D!5\>=??^%6[8_:?=GW'7_\\0?VBAP?1^4`8GC*%K','=?K
M"_;+!4<^D)_5J+[3168Q5K2F*W'PQ;DG-*2U/Z>+ALFL@Y%=#0;2:'RK.5[6
M-+,2IKY%_VZ:&Z<"\H(NBVC2&+FBP,H3CP`QCL1^C=:BU98K:QN;#W5(UHQD
MPC.HV-$\V1:.'DDF6E6/M98Z?*]9*H:7W5PJU%K<E<)K%LLRA2I!*,6QK=%B
MBZ;D>,S0<.,U00D0W.\W0!4_?_[$]7(Q=CF;;/CYXP^\7`_<;N]X>[^9YA?\
MO&2UCCD](ID;&W$T5J:FN;U/=?8$GAJS(KQM#7>)"5;\_/':OZ1=T^=QE$"+
M1[$JJ\2::=OA$EC8M2AGJ!Y%X)I+5K/UMA_3+#LET'Y^:5&M&-[^-\+[[_G/
M!RY+YYS?K[I!_&WN0I01Q,;EY_BF+DIS@8VMC9"GOI%T,_EHP"=?P%<#)$?F
MPE74HZAQ@6GHOHZ**WXLMV2FR-)>3/F`(^LP<7'",P2)N)S6-5*O.KW\4D>2
M';DCI$B=?%U5P]$8L+(<DBXN$GZH:('TR56ZV.AYU['HA#IJS"@H4BH(Q./Q
MP/U^QV7?N]IX:N]XK%U7YVZ"KVUXAFDZP=<H=20\]<0VK>E-TAP+"+6R8UB`
M.>XBOCD3%VU-Z*/`(*U'SD/!GTN4KN5)5\0J236RURE,P]Q'&:A/06%_X++O
M)5'J*&B/1Y$8L4\B_?=$!._OMSZV;(EM?1S[ZPW_^.>&E!+V;2_7[!@0I:+0
M4A[/>TFN>CZ@CX<+;1&;4!AYSYI1M1IG#^^-^^&:[!9]'X!@"ZQ822[!.^'%
MFGX:P,\'NQMP(`J_JT70.6,1[0]ZU*U[QZ+5I3SOI<A-QG9FT$5$1L`#]VN9
M)H4]PILN8>YI6.@.$=ST*`H?M)NO$5?7+[C>D:`5]\FO+TF@AQHT66HL^NC_
M,R4ZRNF^3RG&W>*R4'4R_OG/?^)RV8V0<M]W;-N&R_6";=OPZ]=;Y6A;[]^!
M?'NM0VO:,C7J;M(C+N*\T9B@/53"8U3F?J=B([COQ77B<KUT/K&?W'%CS<R/
M:3^2*3^3WH=HEQ5#,0'K(;):#GG63D/Q:7[?'-[_&Q2(S_`C)@I`_&-?J7\%
MA#1AYJ$N2C/[^[THB!%*D;CL&FX(#<423D(UR6LKZH&$R#$Q!YH+P\R^&)NW
M.9'Q:HJSZ#EUZ'`V8R8Q6!8__`%*/U%3EIZX7@\EG<O)/I*,UO&XGP41*?GK
M6S9&5(&%+C9?"005(QX7)+T-8I&C3=_M'`J?Y#9?(0D<)-JY[OL%*27<;C<\
MZQCNM1<6;D/L"^:P8NJVOB)031TIE86!B<B@/'@1W7".T#XJ3EL:3A82)+:A
M43RR17@9R8,3V2P4^)UV5`N\A-1#`0[-X_Z90(9R/%NE'$A*^/G''X7O63^+
M^=`LJ.H%0OVPR^52>;H9C\=CC-?5MDVM@$XI]6*\TP%(,/7KUR_\K_]5U.^/
MFO)F4%:Q*%`OKCG9BV@;(?@`U_7ZHA-DE47<%]\H^*([GS62)VN-B>J6\<[8
MN%@LPG3$"LW<%,<7VY/MESK?8\`4HD6XE(Q(,&<UWL;-5WC8JW$@Q#A8#F+H
ME)&4)I_B1F5H_LJYCOD5@"8K<N-K[74$/5$OV1`C!<=+*WMNS5,#1Q4I;`:!
M=RM_/!XE'$)?L.^[I=#4^_3CYT^("'Z]OR$?!>7,6<?RSE,(0R]S-23O14'H
MC[K&O:R_-0VOQ2S3L_+R<L7+RTM!V.L$:M^V897V?`[\7@8'>@G!\'2,IHO3
MI"$RC^_/*Y&KV=N7J5GA_?JF-/Q'4-YSA'>81`\^DKW1&ODSB$Y`F)Z1%,BJ
MB?.G.<L=9#G"UF.=`]@5QPPZR82F1.-LJ>DXS:.S)^UD:S5D3/1-T5#^L^VE
M("L(4TN0F57T7'2T[PZ=)421\UQDFI=V#NJQ&RB1EG6Z\,/$S`A\A$(T=$Z)
MBZQV^F8A@F1H)8)M2R5CO0J/CN,HOHV&Q<_EY(BB[2-.-K:O"."1#VL3Y%HH
M$:N`SX1.3D*+D^<2/7#`DS[$T1F&50\C0&WTN.\%@2B>DC4[_O'`]7K%\WF$
MG.71$"@VV?HS6C9@&VW:.:]5-)721G&NP)8V;/N&)()'=3)H!=:^;4A;X;0V
MBR]`\'C>N]]NB<Q]HAS^N#:I&K-G'7'`!:`7!UH)-`W?7NV(D5+"E4"/W,5J
M*0U4LZ5.M7\_GD^\O;UAW_;NEWO4$>:Z72[W^S@.0-'Y?ZT@R(P@UF/,QP%<
M+E.812;^I"KP>-QQN>R+QE0ALF'?TBBPR')M#AL8*!ZCU.R8((R4,66'!\S.
M[DZIP4$TU:@<74^Y"8ODD_W&_K-S!O%,!9E]JGTCJUA;L''H0P\S:-_#4<O`
M9$$GE&8&L1.!Y3&Y-=`CYW,#/M8`_WY'[A'F^1-9;."!]F39,+'+AIHB3$3P
M_O:&XSCP7__U7XLR0/#CQT^\O+[B=K_C?K_A^<CU':)"M/US`YZ$PC\":S\1
M6:*K(?):/^>R7R!)<'\\<+E<<'FY4!!01\V@JGA[O^%VOPW@HT7012F/9D-M
M#7>&D&!S+JAT"G0I`[B9MM4U)N)%W^6?OPO>?Q>*J[^)\$Y(9?PR^,[NJU4U
MCZDX6=2&"!!GT;6QDZT28C]1$>U)2<:`E!?F>B!E\].0^L#%7T>S:#%C2Z4N
M8O!^ODFP;_M`;7@3PQ!HB.0I*,+7=NK`88T@<+9$8^&3V,W0GZP?\<-Q_?C'
M4TH51?`QMR-,(&WE_^0A9?P[B1C*OZ>T=>6M#5^H]SME)%21CI'7RK11*W3\
MG%@*B#$\QW`2@$.6)GZ(+"8(8@M=K3#(92N%YJV-SNOH+:MBVW>D[8&C%<(8
M&_6(^JTB&21LVXZ<:M-PD/$]WS]-V-+>T3Z!%''6MA6Q5?TN*)"VA&MU-^BH
M9<Z%!ZM5XM5<#;#C.+*ATS1$/JGT`DUU1,1V-*[15*I7:[=V:LX,WLJ-GC##
MX:OHJ*KB[>VM^&2FA-0F`-38]A&N\<CGT0``(`!)1$%4XQG=;K?"$SXRV8[U
MSLVDVRDU)[YA9C.1PA,L'.14J1Q\/FU$#`B>S\<<UN$B<W-NJ+M6I%LJ\$\E
MK4/&@-+8L,AL\N+]P,.7_\Q'S)KB("AB@\1J\S,]<K@U0-0X^T(PY]RM[G@M
M\@(_1F!]@]R\GK-RP64+V#2ME7E,WSB0H0DQ^3EE)PBUOM\R^0C/>AASGQS:
MJ^Y\YW"+<3X]T2Z/HE;[EJ;>'=X(ZC)*JMC]?JLN!U?L^VY\;),(-DFX[#NV
M)-C^N."O/__$^^U]3!%$D:3(:Z')%N1BLM:1%EW2TN%"B!LLP(_7UVX#R%.+
M5H2GE/#^_H[;[3;`&3?.%(H!][H_H3F>%X)Z"IRW<>0DMBY&%)OP*6[DK)J_
M"]XO8+BNMM%_WT?K9PMCG1?$DQ"T_A(G&G>W,6#0'=O-SUE\&"!S%+TY'WVA
M:0A`R<7.)<R*3J[P:TH1I80B.OGZ[(79-M;C,(*%Y%#;K,XDIOGR`55@8P5?
M`L&6"MKV>#Y[S.$YW8!5R!$5PY"-K(N'*F:<P2G$3WH8<?P2:5ZKY>SK6+AR
MPM*&?2^A`IJ?@5W:K-0_.L^-;(S(,'^HL\=4H*&"P[9,.UU&1'#9=]P?C]A@
M/0\RGR[LR6+7Y-DL7BIG%*B&Z6UDC_K<9<7KRRM^';^*?RRLSV/GG4GY]^OU
M"D5!BHO0"G6$'H5A)&RI\-M4%>_OE4Y!\;[%2W9,)QZ/)W)^XCBT%V![%=N5
MPE5*@$,5_:@6_]K"NYV3U3(U+`T];-9F_9'L\:68T"];8*JE?X#$7)7JP.ER
M-KYZ/%.-4F+@%D9*^P4LEF7/QQ./3YCR/YZ/6:TN',6;ZK7*4#S#2=P(%\!(
M<4L<K""4)E9LV7KDJQ-[^:C9G/,T!8M<#?A_1X2O.\[NA,(\?V)+^<:`2@E,
M%F_V.TTAV(O-U$5@_N=\`>G1:!$+BHQSF-T!E(O=^J[F2NYMT\9QO2U2K2U6
M>^&!W%T6.E5+IQ303KSI7&9+PSASRVC6E-R7G^D[VN\]GP?^_->?]=G[HQ2\
M8*%N12&W':A_]_+Z@K1)C\DN7/9G];).T`P<QP-IVW"MVH7&YY>`*M=0]K;O
MB93&\.7E!:\O+P4LR,6#>=]WO+Q<Z9J69^-QOT-2P@;TIM[[,T_T-QT!3*-H
MI;"50/C.S^N(LK9T2%ARH@'RE!I^U"GO=\'[I:I4?K>6_>3/Z;+(-H5C4("%
MWQDD`1ED@<0CP)K3:\9`"\J"9L6A1[<;*G2%PW7[=;'<HHV#A1@937=I(ULQ
MCSL7)2<7)#D?.+B8I0ZPI72)`VD]W&+RUYGVT0M$P/.O^T+6XHI)0.>%?09%
M$HG'36:$WS.`C$U1/I[([[DLE-42JOBEQ@W1<1Q=[0X%#B=+;`V,"HV\:$-B
M5P7%G)ZT[3OP>)A1]50L9)MF9$0/;,/$A8@;D^U[*18;E6,ZS^>!R_6*E^L+
MWM[?1]QH\YY-`TG<][W_>1&=Z!!YP0I\&KJKJGA_>\?S./JYMOC?$H"1ZJ;W
MK`X'Y1A[45PC67=ZG[1:)K5&4;4Z+!"EQR`KL/Q5S?/]&-&^9"-*8J=\(IH:
MSTR&`W,=7;!DSHD.3^8^.7"CZ+81/^X/O-_>\3RR=?H`T=1I(Y64@$H7X>N0
M->/Y>"`?J=`D<O6+I>F5S*_J$-+Z*35&G"[3>QKWD7VKE0(1,BS/.BHXV6LU
M9UT42H'#@-L(M*+E_O/YWOD]H%G1=8"C\F5;2$@FCC<WQX"U9HMB?KW@3:S_
MH14;6D6S1:3!Z"\Z'[C;,U:PI$SJ1MIA,M'JV;ZG)&I2>AB.0^LDWO*XA]6<
M&9"7QE+=?N&8$:80)J17I!2*MUMQ<;A>KQ6\45?X`:^U$&WO\W'D\AQ*XQLG
M_.N__QMI2_CYCS_P?#SP_G[#XWZW5"<ZS'W;\8\__BC-=<ZXW>_8JJ-*`PU2
MJD+8^FZ,Z&#!Y7K%_7ZG=:PV."G1HC"NLQ]?3^M*G<R85+8/..[=@,C%Q_=&
MKTZU6+3VS>%=H*(?%Z?Z&U7MHF#^5/#$O#B8144_=6+&`DKMT&$*@%B:DDT*
M"5X<I',+&=F84EP`$AKIY''-Z(7Z8M>L/?:`A9')5C3@.1*G@CC>Y_-I$*OI
MG*E`G>Y_'>T-]-R:GPD+@42#^^=XI#3.L;9B8HH[A6\Z>.4M/-KG\\#U6F-9
M*QH\_%@'NI&=\$@G%02CV7F^7\0/Y2)"JUK[>#YCOU8ZAK8!>M$/?S>/:COG
MG0YDWW=(+019J-.*\\?QP`47[)<=Z3Z0IXZFJAU]'<<3M]L[GL\G;6):`QK$
M>(VV(C#G8UCM.73R\7Q`,5!/OA:YW;LDW>NR^XRV8ZS7:=]W"HL(;-:\>P`L
M_:<45D>0N@4;0QP@?!Z9-.EH*I/7:U1P"5%B^._>*L<Q3W9TQ%&LG.-F#2B4
MBM<:@?P\\,@E5"%K[DE?792(.'`"V4J-.O5"<R]L4WL.^P:>!T^SZA'4O4-3
M>("G3!+%B*=N7$AF,U%0]V=V?!X5S;;!3',1+8G07O31O2W2QZK5:!`PX(+C
MDK?[08VEI3'IQ!<;]Q1&C)1(4[+Q<[31J+MZP[>B2R@M\&CN$8'S8KL'&U$K
M[$@]FX)50-\'2[,8:[L+G^^6:6/EN[V_X_%^@XC@CS_^P(^?/SKX-)[N\0XE
M2<!6ID!9=]PKC6"#X/7E!<_'$^]O;]A2PC__^`/OVX;[X]X;FY<:]G*_W[#7
M:5-Y3C/^^/$#O]Y^X?%X%">6VOGGNE9=+E=`RG?_>GO#^^U]T)0,MJ;6-HSV
M:6$ZG*-QIIJV)D*>RR)NHCFH#+Y8,'^.:"T:W_]=\/X/4Q$([UL6O5^-'?X(
M9_:_T<4KE"8SE6]J1S:J=AQOC+"9H"J6O=3,XH<+P(DMP3I-=A1C.#>R4"`P
MS%9H!C1EZK;%;"DZH1WG%U,(<>+1<5&BETTD-R%0]PUL+[+@:&A$A0'&N-<5
MV6[L9Q#X*E+:MJWDL;L"DN]\H9I<NLBD>1,SXI`K:I!=NE`KWDT(>4!NT56W
M5<_AR!G'_3[S?2D@8]_W&E&KCH-G;RHW#U/3(=*I`#[]J_W^\_'`&WYAVW<2
M.:HY5]'F^?J`R*.C;@-]<[R^FG+7/L^$7SB.9D.9_;%;:RN8PL,VD^4XMKJA
MWUP#P<?E'38LJI*[,X.YYN3%R?>7N8VCT,DC`$$M6FOH+W0?<_?*G)L?#G;P
M#;'Q]@5*,A4H^:N-XS-QF&OD,<")>#K9(\XN%VF,7KNU7G*W<Z3/=1V`!$E?
M(Y&$7`G4Z@,6L<P`B!LKTY]K]9KNYQQR,ZE@JX)CYJ9&16KN"79I%CR90IW=
M2Y@*$$VG#+<C7%]+;>)L!MDY)2"/]7=!?&J>&LXHH-AX@B96`]"*V-;TLFX$
MCC^JF`6"@H$2,P?9+A&%#H!DWYG6&+V]O>%RV:NG[0,OUQ=L^^8T$.-=VJ04
ML)#:!&\_RW3O61K&E^L%6P)^:D&&\W'@^O)2A;170!7[5JZY5%>;/WZ\EL].
MJ3NQ0`$],IYZ+SJ('S]PN[U77B_%+D>332[6&Z"@S6/7.@H)>2(/L@D)TM2%
M:1)HXYM&<<TTYS]]^_`N^#9?\L75KV"Z\@5TE[_#?M%'1^>_MXN)/OAM(^@(
MPC#4;:9&K>HX7H!+Z`KLQ$Q!*4:33U]H4\<LD&@-N>%>@&Z=(PE2>5!:41BV
M1EK:9M%Q:]#`E`+K@,AAQO%,L&^3Y\$[ELI]SO#"#E\$27!`^]Z$9@^#NK@Y
M;$VD&I8]F;A-)O)4JI5.WR@PAX:(8-\VW.N83)QY_F<F'-F%+;3"?]]VW(Z#
M1J@:!I;PHF9N2"UR$A7PF"*)I=,`<E;K0:+QA6[QJ1-2B3%":VA8&^%#,B&#
MP])HMI>2J<%A"[)2F.0A2*-SR;78V6JPAGFUVN]3F`1[_BI'#KL2L!6JN8L?
M'<*'H3COJ&808<KHH)@UH-`;)LX^;#B,B'VF&D*?<\*V5<&>X0139+8A-A,?
ME$5J/JR!AT^,1KIW9#7?4^;!)C'',RRWJ0@+P@JX&5?BJ,G"NSK>?Z07H^6Y
M4<.K]&M<Y!`1[7\F66Z!VGO>*W<(_;X8YY-YK6L3QE(<.=H+;4Q"[D*9W"-:
MS*S2YS+JO5JBQG2/Z#*TF:AYCT+#S*%KD&&-*01;"\68L]UB<X-Y'@?^]__Y
MWR7@92M3GM?7UWY\E\NEH[&H:\^V#?J`;O68Z,\`X'*]&%XKH+ANU_8`]!.Y
M/^X]VCKGH]@.*G"]7`M04),17U]>2F&J,)KBUBRH@_<B"N%,VBS_3<)":,?_
M%?^^S*:MDY6E<$K?:,:^"]XO4QH4T83^O!YF1VKY$ALBXM']5J'NO/Q6U`7U
MPW:)K\TPL]?`$4R[T$`C)@)%W#9NJU([9K9D5\\Q]8OM:SJBI(YI)>@$_X8"
M=B36%WG!_5#A_`,Q8YO&@;4)9TJ)6G".#XT!.O-8/3UD0DSK9Z64X`9#=N^@
ML5$^<OCL;-M>#/P?#SR?AX',&^^TJ7#W?<>^7PKO[/&P%DZ\F%7:AD`<,FD1
M*Z8:%#]'RS7E^D)-:E!#WO)T;2[[WC?!;=OK]XP4L8%^+D2:Y(M;_#W'G^=:
MV(W)2"F&LS;E>447,T8A9HPZN+@%4MH(L1GCY,AJ:0KQH@V^/0<=U:K4&F^_
MU9J^'HV<&VTAAU0;\\J+C?8\+;X`2W$PY4&Y;L=1Z$[J./&CB$G(0A0F3IV"
M5N_@4C2FYO0@`DE<2#4Q7=U$D[B`D5@PUKB*)G6-%@7&';@([N]6&OZK$"IT
MG:\I`_<=_1([1>$E[]RZC.@7[#(SK3%Q#+!'C5F@-4\/!L)O.<*#P^X;]S95
M:EH1'P@!I\$0?TV;_9;`4&W8&[NY!O!Z9`KJ:!_U`1P(@B;9E45P0O6">9^!
M><UBYP@?5-%^ZLB*C`P<P..1\7P>A5.[[\A;ZL5;KO'CC<;CQ:)->+WM6Z%S
MY`+&;)UB<N!^?Q1-2R[W]%'=3*Z-]G"[E\DE@/?JM++MVV@\G+XLBR]A1QU@
MDBYA(^_%-'5M^C10]=C[7`)&=018C-<J$07KN^#]/1;#9T'>F82B#L[4]02H
M%RYG4;0."5BCRS@M=N&^EZD.I?N>!X-J9E*6HZ6+751UIB3,/5_9?)X=FCQI
M#OP&SV.,>CV>QX$-PW-VVS=LNB%W=X)C*,.!$\]8KH"I".&)'8V@.::6(6-=
M\;F]9RTAU5;<D@DYF[F88Q$]W-]ICW,MJ3E7['LV0J4R)LW=^[5<,Y!7\&S$
MSA9!0L;KJXV5"^_BF*"C,`N;.-Z$70%9SZ?][O7EBOU2W"F.X\#C_ABQQSK0
M69'<4;&.+O;(SN0F%OQ2"8DJ"$%LSX;J1!DJ8^(-U^L5E^NEB()R[K9=X]S8
M]!Z&>L,-5AMI-VLO%<N#;)'!8O`J.X%AQPD-XK`;8FFXNAC&^FU,+G+,Q7D0
M*]X1ZIP--WG0!JK/:T6"Q7N=LFA*!"^OKWC^^6>_!N*-:2=!T;`]F-;*9D]'
MU`9=A:\WV[+FJ"!I"&V,#H(#%328/)&`D*Z)+SIEB@RF.&F=&QO^7CD)NI!%
MJF([!M_(L`O/_)T(!7-,>XC2YR?_7<0-U5S0@QI@G7C2$^)LPDE@]!Y\'@VI
M;4+)W$;DB28"C<HR44)&,R[]&1E4[X/D&%FMS#E0CN#^>`(H5+@__WK#MFUX
M_?&*9W5H>#Z>-6I[H_0UQ9]__M5%8#]__,#S<>`XGCW>^^WM'6_O[V:?:J_'
M^_W>J=;Y<<?]^2CQ-Q5-/W+9*[+;"D4Q)9KQ/$2SCF2^%O0$%#]NS45SD@L=
M0\4,*HV,A74M0P,R[V]:@3B%#<+1;TK#_ZTR&<NT'V^^Q.KUCQ!>H4C&3Q["
MLCB>J0X?_)1^S$0>>Y$&<9MT-%),^0797"=Q-`/P9C_OBZ,@5N"9GYU/"VF)
M4X*T[T@YX3B>.#P1WQ71GA/DK6*MALZC7%@;+2^NH>>M`L#S\9@W,2>+UE[X
MZ(2Q,U52<\:]^IY.`C:_J-=QM=^@VMBMC\/]X43I=1V9$SP?>6R<.E`T?MZ"
MP*#JERO%7S=M%4$\.H>ZU.QB%+IS8I)TRR*#XB=Q,<K$Y2-.^V1-YT5Y,BRB
M7JY77*O:NL0>WXK;03/Q;Y<@MXV5$LPT=R2XN5"DZB'=&X6M?,\SDV^F8!HQ
M]_&MMXOJ80+4>.4Y2%JDB&3>W]_732VL-V9#`H6F,6,4.KBJN9XG%U]<M*`A
M6B*X7BYXW[8R=:!CRV2Q91!.H%L:2C`5:\>B2LVD+J9_;;+DT,-6X"7Z.S4(
MHH:HO2_6?(,X4'H/B=!DAJZ;+U1Y?,_7MCWW/`D)$>`6>K+0.H24!LPBO2&&
MS`:]]FEOOKCU4=SMZ>(XXI!&%?@;LUC:^M*N0RU8O+F:IHH)<JH-T6":4L1R
M6^K$4(2\99L`N#\>?7T6`6[W>__\XSCP\GSB>BV<W-O]AI\_?T*K__7U<L%]
MVW&[W7`<!YY'QO5ZP>-YD$/''$S1',79Q6,5"2^KZ;A'?$6-\)J;8:W"[WW?
M<2,+L?[;">1G/^8]1LAM&)#$):]_F>F-^2YXOTH-^`1*>EY:?J5,5H-P?O:;
MOHI"R]?J]-`G=_ZL.6:06]J!B`:<GHJB>6-YSR51&8I>"2QBE%#5HN#O@8A]
M`]CVK19,.W*^FX+0G*L&'4(DTD"R'$AVC7"E_J<>,_+);!9G=G2I-CW/=@1N
MDRC_>QP'4K4K:P6T\0FF'\_(!@UAVMT0-%543JW8"8'%53OXSITSP0%N<@#O
M>>Q0)`$N>['1>7]_P_WQK"X)[?FS&TH^M+MJC'`!/X6Q#4M'K!6&2]O'D3HL
MR++._+[R'"=<KU?DX\#[^SL>CZ=%0(@?G#N&BJ$8QP@(.(["L6OCQU+\2MVL
M=*#T@<B4?9.Y>6G/EHF-)5_9AJR+*+`!KZ^O>!X'CJH45_>R-%PY;6FBH?3Q
M+XG;VCWJOMH:K,4D\-HZG2/BI0X#II2$.-M8Q@KK--61*8@&+&QS11E[A'J>
M=#O?G'T1R][/L848_W-#BDO1ZN@!:M=A[Z`0H:;#4G#02S)9@7%CV@)<HL\Z
MXP"O?'(C'V)?2%DZTVQ#U>X+'[,7Y'6;N,[3=05K;:),'/HT*1AK;T??R6+#
M4@Z5T-[VK-5@F1$-V8_A<KU6/89MYMN:FK:$X_E$UHR4MAIHDWM!W7S"BX/"
MCLM^P?:/#?(K59K7L%@LT[X+]GV#R*OY'K\.-7N_OG[52=^1CSG-54A_H+!B
MM"!B6TU&805QGL_A\]TXM[SNTA[,]NP:`%R1&),?H.^"%^N.^S.5[N<H#1/\
M=^IY*YB1PB]]E]]T4^TF%?BLZ5H4H>F/(KI6RU-S6J-58(:`QA?.9DD]S#?=
M#C$Q<F7LHD2=(&$(BHN`/H'+)9D1K3KUM.$M@=B@?G&MU[IYK@X1T1"0@>)I
MO8']=$U]EO'B/9Z)<!H&8[1_;U9L9;&4;E=GKAP5UTQ@]!0`9NOTS</'>!J4
MJ4;P5@_(3.IV+A.5+++\D]*XVZ5AV7%_W'%_/*I?;C:K<9^.M.>@HJ--Z':P
MGVBR7L=C$[!D;).)H?'K[='3G#/>WMZLB\1(07#6.U+X?*#L>`R$J44EI[0!
M\JPCS'(=!()##RK6[?/UX\</_/KU:T)2V#^UB]0<Q:GQ;`T:I9CN&]JHO\4?
M$T^V;WF^:9(Q0FZ%/C=?TL;)`NR72W$`J5'1?#WY=P\*)R@^LX/WP6BEF`:=
MT+V&1JH5/_DTL>/(`0V@/>L:3_($U@8P*!XY".$XLD$9SV@*C)SZPCE3L^GM
M`IE?Z;\C<X(<K-]SA"A[I-JBPY83/*U_(D9HZ#>*/@U0<<#&(E*X4UE2OY]#
M*Z?F.3;7R?-^=1XC>J>:X6^M9C(X)8&FA)\_?W9[L#:Q::)4D_KF20_T'#>>
M[E8]U_,SXWJ]]G_?]QW;<^N-T.5RP?622IC%D;'M>P>>\E&G&Z)X/C.V.A'=
MZB3EK[=?W:8MTL";<Y1XCY(Y$[LX%C&*@"'^Y@`5X5/OUH]V\GH*`G[;DOT=
M*/@WJL]/FN=J#&A^4*1ZGN_0+8H4X_N,;-P)HF+(J^YE=?AG;@]MM,/*3?D<
M.JX!VF9^UD80K8M\4LC9:Z.G8QB/EDR+&XB[U%/ET-&?WK$#%FU#XT"B(PY^
MD]/UV2Q0&H<$TV:?)++$&^?U:-0(C@<-KKOW3VT+,#MIJ!1%;Q.0W)WI.9_K
MY7*%HBSJS1R]\4TA,VT!L/9'_#BEK0@S[C5*>"BA!\1O%-Y<HQH'ATSCXGDD
M;F-&LWM?(M&F':FU>-[C>=A1/25K^;=9S'?9L>KC\<!Q'#U)[W*]X'J]XOY_
M[L89)1M$JQ1@U^L%M]O6@RM4&<V&;7P<_7R>ZD@5T*AS"ZA%NE`*7)(1NJ(Y
MI#6)?^$G/FRJL<];'=,>B[5$T+5J3H35T>2&^M$[T!H=[SW,GN`#8<R=%J5A
M<:G+^-9^_6K#QU0#;E0B<5U$$XK^F<5XS,WU81@^)`)!D=R<&DQ81BW.SB@%
M9TCP<)304V%VYS6[.\SA$@+F58L1V3'5C\D%2>P[+C1F'Y^AAIZCWE5'9@33
M3BKMG_!WB6;<WV_]\[8J3'OF`]N6L"%5/Z[4W^5\'*71UZ%'D5HP[GL1(O]Z
M?T<^GMBD@`%0Q?-X]@3"3F-H03>72Q=UY3ST'#EG/%L:Z;:5],H\WO/DP!]N
M%;L]V`D2-E(\QW364$BBZ2HYG7C'AP['T3O/3GC-A>:[X/T==!?X0AQP4"UV
M?]//VY^=H;/5WNZTE)0DD&PSJ4.JA<LR,)(7^>"813Y]/CHM@C-G0.9P1-/V
M?^1HO&T[5'/9&+U?*#C6D'Q)>8$^+?C1PSRZ6E6/KACF39:+HL,<N./TG8@.
MF5=F`SLDG`2<-65*!4M35TC0X10TSQ:>[)4Y1MA%;;ZEK88#:!B*(``NEWTD
MH@4(=Z,P^.=T3AX6[/N&Y_'HV>ZVR[=M#H/E+2:SO!<@3FO]/2$O2%%X8Z-Q
M;$V4"#NVAXWZ[4$1JS92O.C/%SYSXW"[W?'SYX]*R:FI8@TUDU33F+P@J7KY
MUHCC6+5*OJ_*UGZS<EK!:#[%/%.S(8G0W!;G2]9M6TM(DC2\<_U:IX./G*KC
MROO;V^Q*48\O;:EOZ`7UQ]B2&?4UR["6OVL)7JI0/>Q&3/]_%,SS-&44I+D+
MUL3QF-KZD@QEH3QWAUH_7$\)B-!4OA8I)1M:4C];R7*N/:,<7,$%IF^R8M]B
M&<X7@"TL:W$=-;VV2)1Y>N.*9,\1[MZYW9G&N@))GR;-WL-<U+=)G/*8YLR!
M!#&-[=R]I)VW\[Y7X'Y_*R)<`>2!;D%T3(WOJ;(=0.'W_GI[Z^?Q!"`5U.BV
M:)B?&8Y]]W3%]K/WZJ4.T^#H'$CE]"TJ/+5=7R,-:3P:E`0R[6$C2&EH-;R-
M:4NQ^RYX@X[TO.C5+P&]2^=<5?^X?)(7\.4*OJ`/-0DH24).>2IJK=-"Y,1`
MXQ^S4<\OGWQ`^6`:?R(UM"X7&9W5UO05"5'1USB'0-J*@G\X%@RCJ$V*Z*G0
M&XYP1.B+4']\2BES7FQA"A6VJM&`CJ%!N`@[>DS(ND<;"9&0SSP:.A;OFA(U
M6U+8,\]>/"EV]&K'H4$DJI;Q[[;O.*IX8J9T1,>@$P=&JH?O^_N[60"CSY,4
M]4VEN$DH%F,Z>?X.Y;[U>Q;SG#$)B%%D+T"":.7<5N8'BLF[UM([UU%K]R,^
MN7<%Y;U#\:,D(P%X?W\G%,Y?@UI('<^J\MY,$<0T$>\,`6>1-D?@SDUP2*9Q
MG-V.D#%'O89X3*/V*O))=;RJJMTNR:PK23I5143&F+05[Z(32XC_94N;0<9'
MH:\CZI;0<X[@]2/MTN2@4SKXQ?1B)2M,D_5HWA5Q/(7*OEG6>4(A;OU,Y`R!
M]BR81#%[8I\I1G%"=?`H]?B[.=UO%8DLXCF]U%PNDN;XO<$B=KGY'[?G/XFE
M5:4D5ES*7NGN\[A18?Y\7S_R>*;'GBNAIF6Z#3+N;T(008^8)]W7,*8(J6O^
MN#A=7$/F03--48Q7O2P;!BN(GB/.EX50($9/1+V*/>3KJR_#(_^[X/TDPJN+
M2E=__]O.T>"_?3+CCF<`J6XJ35'?D2/F".DY?\+2'89RV-`<8:,5=85(=]*\
MG9WV46_"0$^AOD;T@WH$_@!X/@_LE[))ID3V0?4[4QU7'L^CVSU-2-<G+G/P
M+KK\2IA1S8"\!&'<G(71%JX6>O[]1+L88^HQ\E>K/NN+(-,:AEW3_%P8KF--
M$4MIH^LHH4/#XU'H![?;>_A<P&'P)G6LWNDDJ8]9GQ7=75F?">6J^V:.'RHC
MUJL-T[@U8F9K(XU)IJ`,!?-;U?%=CU*45;_?;=L+*@[%_59C0-U4?V7\?^2,
M^_V.U]=7',\G;K>;C5L.BZ9R_:_7%]KDK1E^W[2-T\"XED<^<&O'>D)M&C9D
MM=CI]G;%!]M'!Q=SHBJHR^R;2WM>*MSOD5*(J3CK:6OU_=W2AF>VO&FFYQBD
MKQ4&C8O.!5<3*:7A`VM"-6P*.(K-&FP(0?<'G1'"YJCBN:3^/AJG@``][=,%
MCX@ZA(TMGO)"BZ$N]$?4-B1PSR=3"<:U=E.UL$"VCA.^.#+/<+;1WIU68HT7
MEBAXU'3P`:H#?08OFB<"3BRIMIAD;O+P\<:L/U&+;IJEI"8_3C[Y.GC^#$AG
MT!1#2KQ\>\>%=N,^90DT,'TO-M:+<%/8-1@N?7T61(8-9B]2MZL%FA-V"#+K
MHJ%!3/DK='QB$F+_(RX-OR>T^O\7POL[QZ\G?["PX/U;UVD6!2R2=:B7:R@6
M5[**,][$#.EJ!`;*>BLL&]IA,]9A>6M'+@;<G9<I)P0&U4E$PMWHX_[`ME61
M$H_9N@=O1H[0W3/:RB*=*X@:<<(;BUHN>=#&K-('$5B7!@FV#,L^L62'$:N)
M*9;4<WAU\FE5GQ+?/^/Q>.#1U+8:68!52@=3&3PRHVHK')#B*:7:```@`$E$
M053?*6#2=)['@>?;6Q>^,5_6%P0"IXIOFTUS0%"8[TM<'.N,7'C>YS!3D.Y)
M"1I7JW.;5Q0;GH96/A_/8@2/&A!&FR+[]/K_/.YWO+R\X/W]5@2([2NR3CDW
MK9A[/)[8]TOGP4[HBW`\,:9K+Q#\ZU__&I06]M162DOS'K%)<-TO2*F<\^U^
MAVK&MJ5B!P@;(ZZ=;B(&84^5^SWQWK45F95O6HO>G`\SAFZHK'<X`(7?*&LB
MLBT*-5B\A;QY.0:[H^):2Q):+&T:7=#8,>^6A'=][5J(7:/TR,DFC8`&4P@&
MA2:/CG6!V$E07/OS\(AV]$PS/261VP9\42A6ZV&++_:QCOUY)_]AKS%Q3C3L
MNN.+1:VA&D-#@9D#/D:D9F_A25!OR,/C*'MU5C4>TTJ&)ZT:'R)@9VT*2UGP
MT;N6I$#WK+LAJ9EB3I,21NG%`PB<AV;ID4K`TI(0L@@46('"@S'ED.[_1,'[
M_TJQN]I4].3$%%\(GB"W@`_5A+-5PU+@)=&Q$KS/B399'2H[C<D_Z%(T(CO(
M%#&K4[47(7G>G'^@(=."J!/K8BJB?8(-_^WS."!5Y0RA$;Q#/E?/@L"*GPQ*
M[3!/73T['5FU?:E&Z*X&E39!".K18\>IA;:-6H/K$6^0'J;7;F,U/R6F-Q=*
MV,K:(Y,CI`IFJC`-"Z:G.4(11J'%-`N=:"%L`V42U7C#Z`X(]AU3CID%7-*:
M17),<6T]M;KMFA7=E**X">T\3[<U>",131>BF-H\/)]X?W^W!4>BN%-85/[(
M!V[W6P^N4)?R-EWMJ0@[9KJ.>W3)M:F/BG/./:*44;?B6E&^JZ'!?IWH?K[U
M[]YO0^QCPFX4R)5#GS!S>U2U.U@,9([2$3D]C!K.<5P:PDFM2>I!$N&ZU^@#
MMNA=^:9[X55#)=.6G+5A3"D`G$B3KD=H!T8WS8=?<!/%GYVSFO&X?]]-L9$S
M5$:$[(J"8'QR@;!P'L<^6B%UFZ4X%'B]UUK;R(@7W>[K2@_A7X`>#!.LN9TJ
MU=:(4MV/Z&L_Y!42X0JFIJ;O:;1)MM3`:`_BZ&5)$CKI1+\_PAR(#XP9XN5G
MS5<+XJZ1!VKRHK85HI>(JZ62`Y',-1)JP*O3T#>EX7<0ZD]8DH7^L_@DYW>"
MZV+1FJRA:M.SJ5L05-=%&1_@)-(R_RPQ*FRE\*N!YW06;`7F%^BR*'W@Y199
M2YA`@_J294ROH4<()I1#X5O5Z><MU]CRB<3%54(B+B1]O$A<S#I$BJBCEF/C
MF!(KK6$;4]I(9U^$>ZF5Q`]YF(8T-V9VM"R!G9"$HS/KAJ"3,M[_IUE".0^"
ML.#WNDDO-+04DL7+2(@)_^Y`K\=SKCB,#RV$IC`$EV2=IT\<O9E2*EQ6S3;B
M.:1WC'?A<7]@_[$CB>#)[]ET3<F.;&EU%R\]/O*T)53U&-@E52>(5JB%P;:E
M[E"A'#_L/\LCZ\XGN#C6:!_;>C&3%Z!Q(<LT"#:ZAVL06>5OQ^L2-F6^P.V(
M;AWA]R91'8TCXLXJ>C%CD\]RGRI,;A6!6`V(PP1\H,-TG3'3"B3-P1A]/33O
M;>KB/8^4MI`8=HUH"T3BZ^#&VM$$UQ=Z'<WLQTLBX0@/(CI%?TZ"\YS3V!K`
M(Z;#[N]TVR]\7#U0H\Q)#"8>;F&?:)AFHU]#XL7;#<(6_%`;!#(FBG,B9K]W
M[1C<7C`%*'E*3P?`B6)E*`DZ[J^@JAXB,$R6-4;[F^^"]W<0:ODJPFNKCH\*
M97ZH/R-@TQ7\[,;8I[^GGX/D(Q\!<\P:H,:&W[LNV:,AO_)H1[YZXV2JH72Z
M/NI&3'X$#1;L!USB0-1&&C6%#<B8:O-5_">/R=SW#76THUY(W(1\:`8BF".:
MU7MT:%=$6_L8']$YCR%E51LZ/L9(]$/8E!E5OE,&BMO\E2@XPN*>B+L75.<E
M3$,MKRY$\2E>E;*55O4P/XBFR.^;$)PUV.QK"A0G@I>75[R]OV'56O9(6]/L
M%@[T_7XWM(9Y_"S+0LVC2[XYL0=A&R;VJDB2G"V4V`D5H7<E);$<-XOMU,>9
MZ]AX0<5A"T?1:JK?8WI;(4^\76X^-$`BU=T?6^@VDP<]><?%A"CX9U)H.C"*
M[F2BD9G6T*9W#3UM`23<.8C8`C)JHNRS,SM%J.K'B`N)HN:FRPFB&B<8,U=]
M+ABU<V,-?8^:@8:T#WK(:!I3T!@D&6EMS2?=-XQ^UQIN!<G8_K$%G"RFQRS4
M`L8DAD$7G?W_C)"L$**LN+2O?3E7R+/J=?K]3\91)6$>5HQ`H\']3;`UR\3W
MX./,@[+1=XB/]FNEGQ?;L(O+#>90#`W6?`Z\L"6N=11/WR7M_T!!?')S/ZH[
M@'/^[]GO2@"U*/1K=FL??*4$_^3=UJ9QE'B$<+R\_-]VV,83\;,G3YN<>,,!
M4X0[<VR)BT_XD9(@0/VX"Q]H;.=783;9#GOC:,1'/[\:R:6Z:4L24_RJKBW;
M;#2P7<`D6)S]>$(^7,5DZ1*A/C;'(.;V]T36^ZI$5?,<N>,:G_)%E=IIT%@1
MG3TSW<<,T4=V7Y,(L89!K_G_4A**'ZU7/@TDB9\-!4*U?O?>%,'U<L6VD6"H
M=U<(Z3W=][)N*,^C<EO9^-\4/MI'^]Z3V(KQXGMFQ$?1O6L;EWKJ3'#<&'&G
MD[C4X3C,T\\D:!Q<Z/$L=JNX5BR`K0J%DL9(2!?P3ID"VW,W`AZK;T9FYP%K
M+Z:P[B/-)[45_'Z_R%F)#ZQF?8L01^LKK-.S%OXG:Y]8#;$=C(*H^X\O@C%B
MT5[^8/LL1:;2?=!<K.0TVTA9;KS;\Y-UMIW,;0*DBU0PIUM14L8IG-B1`BZF
M-4_%@`3E(@GR,1K<]C4IH#)J#671ZL66`1PM"K[6FKDU;0Z[:@T>'Q_;,#:*
M6<W**/>V7E>FGF74),=^/+#/:*H.$I7#FU.E9R1+P?#\<+M.]P/ZL&81BO<6
M5P=(0!?4RJ__1GB#%_)#2L,G_FZ2+DTHXR=KVD^D$G\UN'C&[A`>GW[R4^1K
M(+';W.<\)XM)K<_.A]_,$:>SZC:\:/2#&MC_K:X3R!-WA!S`\HB";&*1"-V.
M&IV9LRN0]3-+ZEH]:55XP>"34ET_7>I&]N)PSZQJ31\^Z\GL*`U3T)S:ZVBX
M8+ZY"S93I8AK3(ENKB=IB`NEM0E99W'YI=`)K3+S?->P6/L=-<V#B3E>\$]:
MO&<)[ZA!$_>[M>:2F+MKT6AZ][)BWS8\VD841<<ZPWSS/!IDG@M5Z[(A;K-3
M+JC8]Y>$6\EY>`+`\_'L''$$:[5"D0^%II%R58)?:'(C%)0A-)YN34[6CG8E
M&=Q*S3.?.4(O\Z*@8SK$DE=J!(.6[M#0S3-QFG&#(<LQ#;Q_^7Y'U(+H_(J_
MKW9[0B6!GD_2:FX[S"D_*UQ:3#:/WYEFT?C"P_DAT[JI?0R>:R'<$AW;1"I<
M$>LQ\K&;N'2*]D:=,G`EFA&'9G@OVX%(NMHB\2A7ZK7EN%Z9`25>N(2XU$0]
M:)Q5Y:;<3_!<DSH%#VDIJL7=X&$KZ-!L=<US18VGO=2MVTJ?,];3HG/(:EUD
M9%RF3OEI]SZ+G5;ZFJ#AWM\%;X1`_1O078&S9M;S`E4^B:Y^_)TS:K?B_LK)
M.:V.1T_G69^_:I-G7QC&(9#%N%;,9ND^5R)44()O9PA/X?;Q^1K(PFS8C7A&
M!**2.P-6T.ML`W/6)`0C9.:?^6ME\^C=`DTZ/'4KDT:^FXC%"HS.KXK=T.,X
MOA1AT3O&X!*&54P7-N+X>H&5BT?NQ2(+VYH[0?\9F4:S4G9#8PYJ+8;&RKM@
MOAN[J]4X^.7U%2_7:[5UN^%&B7;E][,9)X_B5[K-$>B<CN,H:76K4`.1<.$9
MZ6/1W]EK-!5S'M'$V.28_M"]D*5X);<1?U]76X"$S*N+5N&?J/4(Y>*;$:=!
M%Z`BOXV'>T$H<Q)TV./,@DT3GYRMR&RB%R"V+;,>P)_SJI6P@7$T$!_;7GFH
M&C3-DV_M27',!?IP#7$T)+)1X]&\?Q8UF.#TF&!Z%]N/-%H#IF0T3,]@Q"U6
MM>*G%/6@W98P3]9KEMNC,:V!W4R$/D=<FNEDAT`--W3:[Q)%;/J)H2QJG$.'
M-_AB>QH%\;0GS/J,88<FO?`=#?!,?1)?V`LK!^:$4[_O9&ZP(8;FPK9%WSZ\
MGT!X?]=E0D]V<OWL[WP1QM6(TJ#Z^>,,HD3U$X7W9RBBIY]YXGEKN<"A;']9
MAGN^K(;9:7'C8]&[^$=C,4,S`Q"#/,A)Y\_=MP8+VXH*,:FS/^B(C#B'BCKH
MF=(Z/M?P23KS;Y:`#^9\?<>"IQ[D[DCCTKXFL*`Q'$RM\[7@&T-45!2I<ZYS
M_UV1YC2=NT*XB4VT\D2%4+WN@2D:IL6-$3#9F!FT9M`B[K=B/Y:KM9OGWUK#
M>]L("*2,%[.:YD^)JVH*+^+R38))-S7IOJ`GJX8&[ZY%WN+8['[?=3'FI(*4
MQ5-&M\JH&;VL_7>\152+#&>/8D:.W#F-<`P;'N'?@N[8!SW==_A<6S'N4=_(
M;WD5[&">#2,$%HKTGHO@QGL&^?HV%XR5]9AWC3#%L9O2M.]D*SEO`V:N`U;A
M,I'P<#0'&WUN^RSC?J%Z[ISD?(WY96CA21'/FZWF;`"&&I27&U-IB&6T][#(
M#?QN!Z)%D0^!M$&Q8G&WM[:T(K5Y?UVDY$UF9^.Z)6?!)V*38L5X9-,$,CLZ
M&J/QG:NO"]I@^7_?!>\'"._O4AK"G_P@FO<SG_=57V,)HF?/"E61\VI7/CH.
MQ7J$A$`[*8B1UP^**%\0J[.XT#,_.9FK>]\L^$9`/M$@&(<$<;9F5/P&@,4"
M,&/O3YVBD?W&%G7=JWLP4#H-S=0C>H&8!/5H3"%&(#9]D.ODY^\=3Q=S(\V"
M.B4<:<^(CU#%XI,IDY^C&!6QP.BR*(::9VE=8-+ST4:!;KT\[<;OBSAP]&[]
M+VNFIJE%_8OC*/[5A?^9K<^ER.).JVV<>F*46D34IS2MU@;,N??<3)Z-KK/C
MC(Z-2D[\7#)R0Z;%1M*&A0[;N]E![#K%K(N\Q$3R=FXYC/',.-8TT,"L:HYK
M+@(&Q6.U[ZR$BNSK'-F81;S<,^2WK;U#'#?'ADL5<O'BY@6C9Z(WOS:U!D+)
M3C"Y;GHJ\ND=:HAQ1".QZ*G8WP7QC(.?->AT%%01@$=<Q&LPM?.(K_40%B/(
M,H]M\T>7P:E5OD0T`6">]G3,&E/R?/(ETWK$-Z'$Q!3V[-6YOA@N"_.>:0I^
MNB=#P*W+0#6OPQ%'4Q3C1B7F?Z,*Y3\2//'_<K%[BEZ>UZX+.S,]'2W\%G+\
M&1"X>M!]NE26984Z43/TDQ5YY"_,&Y)Y^759I9V@ERO_RQDI-F/456'N9+/3
M..4CZ%M!+@L"S^#R8\#82'^,@?S7C-$8(;2NT+<"I`6=@$?S;HQIQT]B5C)A
M1*`!!'E1S9^A#!`3DN!MG?S29S:AEAMLQJ$)+'8TGTF=B_%V;`5"9'4E\3U7
M2F9(4M%`4:@FUZPP32)J::P!<$L$C$;2H\`HXJ7DQK'6UW?VAN,(57\_4ECD
M#DJ1M>'3H*&>"Y"/IEL#&2/J$MEYC5`&_]5,W4FS8P>AZUJYA5P\<LRQ3Q\S
M?&,))EEB;>QZT^*YCL1)]^N2!&XBW,QQ4A<767FQ9LQ3`[$6CT2S:47!\&HF
MY)&="C(E=269.-B>@M&G!0&-9=5H9/*'C]P@?.+='#T\(\K%74,"+G\1VTE#
M9(')L8)W!S-.I\8JF7<1!C3P]S:Y>^4Y]DWTUYL/6NJ,SWL38C=7$VU()KL:
MB(V%YO>=[#'5Z&58N.S1XU@L;#UQX?RK=0:'[*)N*1%FK^`42UJKU5(2^K/@
M&N\$/C>B5#A?^^^"]P,ZPS+LX-/V70%,^&5T^(-2]Q,^9T+CU]\A:CA]D[7W
M^D"@M/Y*]18.Z],//S,>#7XF#MA#NU/>`_,N9;;Y\@4VU^0QEK[V@940E].P
M:)<6GL#A%:[`D9.B<_*%)+FN&?\+IH+0TB+LF-?[KG[T1.>)(PP,AP>UWL<+
MJ+&CV2E-F(,B.[$53*I?V602((6NX,4[ZA60C'!FFP<_U,')_(HO:K)1UL_A
M'7YL'8V+V_G*D:>?#5,4`T)[.@D\\`/)KGSOJ*GV"48OKMV3+$%!'3X7WNR>
M:39M8H#8KL]$DDZ6>F[=JFX,L=N)A*EAW;OV9#V)QOC,T9V/984P!Y0<&NU[
M%-XGFW%QN-RSG.N%_[Q6*.H4';Q5VHNXB9J:J-A$!1<7DDP?"&DW?G+#:.6P
MJ:@>LNUV6ULR+O(2<SBI7^8_[WQ7R#)&L]AR>:]E%%$C->3%',$ZED1\;']O
M.^()L?`HN];PY$/.-_VH^<FJQ(>-A'6RVIXF&N)2A"R@0(C8L6PYSCS9[Q4Q
MFCQ^1$;13^AQ/S.N2X@W_5WP_F:I><9M_-"?5[]2\GY@0"M?/Z<HP7S:H/C!
M%8OVN%WJ]#E6S%]HBDNA!W3ZW:_Y3ZCJ^8^'<M<9R>GV7A)SER0X437UO[BT
M('O5?<1E;-]D!4:VK%![;=EOLR701&BJK,1FTD57]AIR`;5XWMFPW(G'IN(-
M,&;_\[T@=$[4+,P194."H(1B,9:*<$H]9U.M91@`18))EVM/76KCO*$D9A36
M"[L,#8`CAH708-7N0RNKW'AJ6")?4N:,3L(\@Y07*[1F?]4LE)COAN`97'$1
M^;S@5.21V[)0(:)4C&3D2:0R^DL_`G(C[JRG1>?XE7(?.U>0"F?+P\04TL(-
M1O>VQ12N9OC52M_+OKQGUF1&%!B(OCJ/M5FF!;'#9K1-A;F)M0T<:B+/W0B5
MY4*B6+C5%+&T#;H#%5=\KR:T.M)>"'JQG,-8XQJYVX)88!/%_(*4ILD5Q7Y#
M)U$J3[#,L]C>"1F:C!X9C%R;$`V:FD:?<HJ,+GJT'K,>(!&QZZZ:^6`@^)1%
M,R5L`(KA5"'J:`>VD;?3K#J]@M="J*$]2E"="G!.4_+3/)XF=6><V8A=#(IN
M-1`CA(1BE`,__6\?W@\H#;_#+Y!/_6),KI:S+]+E1TVQ@W)ZK++\OK-A].1#
MZU^L!2O""U9]72J>2F!>'&HC3[$H3(L/R7^H&PV*:`W\;F7%BT2((O?S9'&,
M@@(&!O]`5G/RQ?D9.H;S'/;'JK[X@DZ;.1>2D9L%:\+9'[=[)ZM'E5WO[1#A
M[D7;`S@D>!YF+]R!UNJR_8LXLB+`5OE^:4L6-6#_%$[(`@L(U5I7]7.`&=UQ
MAELSS_=^PKZ#%&H2)IH-^Z^2>&KB+4(,&APWXDH67XD:)IV5Z3JCDM.SK^K<
M&!+]'CZ>)DB\PD3);D-,1<>4UR*MR)[,<#=7Q7)`_<A\_ZOG:?,?;=9[?'VR
MB[-NUSTY&H`I(G'.?V5N<L[9/(=,S>@!'`%BSS\CK@GMK@@I3<?BUXE,T=-)
M4@E<H$",J.#B9+7NL>L^>T27:UCLLL^J=H/:L8ZWX^H^RLT;5F"<W7D]]!'@
MV6U0!GCH**W2[E>N69ZL%`O-2.@>EP93JO>8D#<Q)W<*"2X]7]@"O][+EI'V
M4-2I=N]3N',#17/7O\_:7,;'NZ<837J_II3NGMLS1;9]&>,9,UZ]-(UDX9Z?
M`G4AJ8YDP79\2N^<TOO:(]GMX'::EWXCO">4AL\4NY\7M>FB;HUD2K]3L2^0
MU54^\(DYF@#.1N;K!Z.?0*P'DJK&:T\C)#J(_>2BPX9\*3`-/]1"8"L$W_NF
M$`JCE-.N&M\_@2PV`Q<]['@4.E7M$EB`?1RY-UN@S4E[N8LCK%732!?S:)^$
MG%`[!1"#5*TV](F*HI%UF@=G)136^>A4@YRU>YC5<IQ)<$8^#95F44??N3[#
M(L4](0V:!(0Y8FV_3!1E3/9P="\4`7`.FVPD#DWDHL/Z`=LBUG<"6J-E0QZ?
MMRQL?I;>LLV@E&)=#>B<-.<>JN%]:CTW5>MHF;GFDMC-PJ);HC8(0KG9,'Z;
MSBM8;;.FBS"4Z3,7]PB3V-2BLUAPWR,!6?OG8Q7/&_S[$+S.SW_B8H[=%=K:
MD6!C@QD%Y**1KP>CMJZ8GK)H6"7OK<G(7[4]PQ%O5K.Z`):`]K%RJ*`YH%_G
MIGTLZ`RG,(3V/<[B<6Y*8+UH*<U,7>,I55O`*[TJ%[;,6[?HMYF*TE[2H\K]
M;N>>A^$6-,X[T\+M/7!%I!>]:O9B3IVT:NU.YR%^/`33>ZU^7!KP_!7:N<IB
M;NP\/1=:PS-`=IIV=0?M_]\([^^!N+]'D)@H0_IQ(:,!Q>`K1Z^VQW)#Y^5Y
M#K'#9Z^#?.Z:+2*TU$4OZ.KW)(:4Y01%,H6'\YH-D=HD\]>0NM2>AIJ%AP4O
MM'H/E:GWY9W0;'_=G=N#?M10>#PQ%N6)I(&XN@5?`G275WJ#TJ`9T=L-+QJ3
M(A@/KY/9%T^2$9;I><"%"\OP*`XC=MF@\'R=K!*XC2/%C*7)#U,D:#`7:7#`
M-!;-"[]BOL9"!:A\X/7-O;8Z+Y3,S9\;9:MR-S)H-7X4WYJ!Z?3D/%'0^]>N
MJ&']W:JI="55T"'`PKQV?IG&&-PCZID+<JDR)4;C5.?'J/X<(V.<R&8YNKJ<
M)&I0V+;DQ`CQY80]?VUZ"(0ZJHQ:B@@CNQUYY48L0`E7O%!EI##KM&ZPVP)S
M>?W4HC\6:7Q.3[]SS_#PUG5<:P@XY,QPWZ=CSV---2E_,P35D'7_CFD-/C'/
M;%V8+>]]/#.IKN>2QFP7+3VM*=)J1SBL%\4T7YG6L7[O>:^0@6[WPC"Q3S6)
MXD2`>CVETDTT0OJ;.5K=7!/$[0TR.^<8BA3OY]D*0M5OS2/#LG@28\9HA1L!
MZ6EO/62RO$10\C-N5I'MF+X1WD^4<1H`E/KEXA.8>;`R%4W_G@+<=H`?G]3Y
M=YP9$DB(Z7X2M=9@3KWBQP:;J#BN4]1@\&9@N,@2G86C7H20^7FYKZ[($$29
M=.O/6GL?2_@<&@2[+SZZ3MT2F:R:F@5.4VEC*D+5H'X>613!9%?D-\GN`N"$
M2"F)*0Q%;)>>-4:W?`%E4&F76B:$*B9)5ES2TO4"M"&;34RZ3Y#OV0HZE0??
MLCE6"'DR1Q,A9U`OF$5.(SIX7&.;N*7&G2%)FE/%>CH1QK-1-V)&X1/[H"9&
M-9,=4IDP`'92L$B5'S\:=J,;XZ0I,7`U<9.^9_>BS04%,,HM-7:JH]PI050A
M1`>($-CH4?-<60W<-&8?Y/&SR4>_^E%^9#$8^<[Z@ME%?GMU/`NHVCUN'LY<
MD*[H(MXMQ(LQ010`M.L.:]V582.;X<280T[AO+1-N!#,L;(8;L0*Y\!V#/7=
ME_X4KG4`<R(84_GX'3'.'$+(KHY&/G5.::$`)7I0-[CUVR':4CFGQ9=7IRH"
MY+H!7=B3J?/*KL=@4%*QF4C#(JW'L,UK7CC2&/.9UI"68TG#.0+NRYJ5I<FR
M(7"I?ZZ,*I^XN(8^/#G\R&@>FKCRNZ1==[,QTN@FW5\N3C6>"Z\*:/F(BH&I
M^S\+8UAYVXK#!;^$@#?>4BJHX>C&';_2SB(<6CL0E@FT<BA(JARIAO8`$N#5
M.B-L2[J%AM-Z.;D/D3G%,M&N=?@KA$\^MJB8>*PBV+8-^V4O/-5H;B#2BQ5O
M1-Z1!QK!"Z$%8="&:S1.GW\J)%)D5:5>S6R?9\/*<-<K1G4-K-(14>8&\\B6
M$=Z.FA)]HV7X\`Q7/==;^#E/)J>>-R=)J2*A8[R^I<UP:<NU3Q\M4MTR*E16
M^P))+5+4.>:+!+KQNX'UE6`:.]M;'3_#[7T5[3W!"0`L"R>%&3A6Q91,-W/=
M,8=1Z"K:5]V;S\B[NNM1?9![(YC[[UKDVMY?#7Q4^;V,DLUF+V<):1+>=LVX
M!`37U3L]A/2C@-<;7KM@(<R:9]%EP#7VKA@1K8&CH3.YF=ACG46/2I'9YKD+
M-`VKO4VIX&*!(`RMC8(;E$;H,A#XXBNFE2^E4U(=GSD#%>6UT<EEPWO%>]<-
M^(FAF;31VB4$28LM.$<SM$V?P<CJ_"RPDT]M0AAP883?T+V<S[':VH'#6-L5
M3($#A+IY<?M^D>_@B;^%IG[HQA"-5W\'5?X`6XP28&;@5$+J`)8()!7`$H.<
M_--;'8T(+13'<<!/]\U+0KS"-N;*38P1E)U%A+29_'`1'?R=D\$^P'&#&I^,
M45K'@*P@MDPY]2.>D"27R*2P""W1']0@76/8M:6$Z^4"`'CH$UERV7@Y_`&Q
ML,0L6M-,F;IC':@)%ZD@5)0;F].-T%M,L0;E1,/7.;9N@6?EL$6?ZG)K[6TK
M\C2W1@,-9>Y>P%4CM`802JZB&4,AM9JXSX&J)60<0,Y(J<3YZE%YP<B`IGX<
M#159`/HQYND\D_F^];D2Q]KV@C05YP2B+'"Q9M:33-&@=0P]BOC1U'C;,R5[
M)-XM$Q<$T##^5]#0<IGXC'P^R-HMM.!1=`S;*AAW`2%4,=O%J:)+[1:G)%1X
M6?J*TONR2D#C1I612N]MZWUV):7N;\N4*6/@G]>HK.?,MB+4VX.%QQOX_D9H
MMC\';K;:/<J:S<^WJ0\?7[NF.>>!"-?//8X\3W#"!B&(5*9W6HG7'G&HQ8=A
M"/'EE>O%@4".^]N@9)A0%?#?T[)R]DX;Z]KFL$`OD22!'GHZE>C.&43IL/,]
MN\*HBJT3C`9`/RAIYJHE-QM-]TLA,$0.I_TX1<T0+#,MT%`^G)7=*@O@VX?W
MZX6GO]EZ4@A_-8(W_CGIA=TR[`#!>"$H&C[^+HVG]S*7S%$WWCTC6Q+4)\Z]
M=9*2DDUUB:@1=0$?A6D"$$360J9BSK[@,B'TXLOC4.Q@HKC,,R`<RRB8<KS-
MY&?RYBS#EI$-;XM!A:?@DWJ?D5F5H+B.!#%M"A<9V#OO6JA!'?CXC3>#R+(Z
MXP++4@_B1[?9:7E'"N'T'X=F#OLC.RYG"D;YYSQ&;%T\18B+F4D*_5V:.;TF
M,<DEG^F8_0G!BP+%ON^EX,AW')GO@1CT*7[RB*OIN)N3K5#;>!K2%J!"$)\<
MY9L0RP9<88,``"``241!5+4$/69\/$HCWUSCB@TUHSUK68UO<))1;(II+%E,
MB>EWL;!E&K22V>:K\WZ!7A@CF%HT2IA!D&IAGJ&FJ1_(NGV_?/V1`VK`$'1I
M&$\K]5QT0LV3=1:A>QNAPAX%[.$F#:GT`CKW&GC$F=\WGX;&ZZ[`AGM,P1*]
ML;)4*1,,$E$X,#NUV*(\F?7;X;Y@]Y>H@.;U2OSY=PO#3+[+8PUL8E%*4*!G
M6.RT(5!H3\$576CKBN6L'U8I$E``_32D",2RL[BS:SN+#V?*2Q[/.\?]ACD[
M)/8-4`Z1>'JH.F56].-//ES"3YTHG.C;ENQO(+SR05["A*.2(OZSW]<V,6O*
MO_ZEY4@=;/(TSZSG?.Q/G'CPYSDK\G$@YZ-;])S3,2P5PE,8_`A<`>0C]Y=L
ME5BEP4T2&N5$]T?=5-S^OA@AV>I"B<8D%<$'J=)4`'3EJ40(K<N<<'?93:RF
MQ3KJM*U*5ZT/I([/Y:`-*WX*1`PDXIBLF1#$=*IO-%`WK>0*Z&%5E`,DC>UR
M!M]2+8S01ER^"<@D_M%A-30*4:_$G[?0,5H%"3-8)3W&JRDE<F:@YU\Q(>9A
M\8)1)*64W&9M_SNH/PA%BO.CJ-82:(H>7K_/&D06LP41/R?%6BJ'**,_5U24
MU<8WVX5/`_$D%XF+BGXN$H36`K+.ZDV];^9T%IPWV@-[/G/1:3C.Q*_4T'DB
MBG'&A'!-P,`2K-%1\+OJO-_OUHB1!1GS?%NQV_Z7D6-O+^6+K7[_:2T1XI3G
MK%-(TX1>YCP)9(5X<S'E`0:%%VHPO>APA?Z*P*S-[<]RH[KD(>@5\$2B>0`S
MM2$W2YC>3/*>V`K2AC!/SW02,^7U%)5H'_76E*%(41`Z5'A+L]:H)I&)6FG7
MRF0G+9C7E?X>83C<1,)1/E;ON\SOF@1^WO+MTO`QPGM68)XQ+T,FVH>>J_9W
ME1_FSQZOSF*QN?#VZ.Q'Z/-ZXPT+_<CL7&V83*K=\+9M9L.>OGF*4%*K`)6S
MZT\OMD2;TKKX7`GE;)UK7RVU==5<$`>"^NZ6T)6VXJC'0F,Q,0AVQS](V"%)
M#+HP;718+&8L4E`>)07*?CA^[0FE!HMT*Q$;\VNNI^.:<ORLA(IXUQ4QXN*#
M,'HQS06=Y:=J3!YVQ;4:7T\NMGNAVVFAQ;M3<_FSX\@5!4U]X*A!T<A^ISZ4
MA-7C-L96XV[N9'PM(J?V=V:4VJ^]3@6^+D(`4IHG#B$2*<6B,%?OST-S55@G
MS%XSM6@\,G(58%F$TEMD9?O<;PE"W'>5H?(>_J\RE.\BT(01'&+H!YX"8)_K
M[*R_5B-!C\K/-!XQ1=JJF,6BJ(`ILFWCF`E&:P5^Y.+A/7C9I]=,$X)FMTWG
MV*,U=UYNG:.DA&T;PM*<=9D*J$#H'0SGJ9Z/W(LHD<`M9W4=73,@WNG`^U8'
ML/#PKJU4O2R5OK0![?^@4#T@B?R%R>U`E_<WHD#$>[7QP350A<X%9?"Y/-X;
M[CYTCJIVJDE>PR.D1JR/,+LIJ`83*G*@H":\7?^L@:6H=S<B1/O;I>%W$%X?
MHO"E#_N8\>LI!BO;H>7O."A1E\78.)XP7^$3CFEFA/<9]9Z,8F?;4L!3I!=G
M\J>-_DD6B4)B1BBF"S0OLOMY\0X$P6QRQ:[FW'/'5^Q4A^C^"Q5+0?%MIOJN
M^%>=5[[F:2E^M$-':\1J,I2L*E'`!<<U9*.J_]0[4S@*XPC(@HB1:<L_12AF
M\((4'Y/LQ]$V1$)I@\J]Z`7F1+/A":W59%YMVE!M5,;F7VD\WJHC2>@K?!Q'
M^7GPM&)&CWT,:;_OA*;T:ZGK#5P-M6=P0_G?4Q=883D*UVRI#CT-3SWB)09U
M:XC=9-EGD/,Q2LU3,=S6!,<_),_=AN)FLC]B1;U2>%.AG]3[%^1K8")OR;*P
M+/^3S?UB)'1.QPH<'01AO+$&4ZYP60U&S?Q,&TLPEVHF;N(C)GZ,W#B8!TQ(
MNG\?/?\8/NC&Q52:I#CC9*&=N@$-FE"1D`_*XW_?S$:H;]-)1`X9S)_VX1_0
MV;_></_)7Q[JG4[442?([E`&[29W[K%.^?.MF4Z+M#CM0$@TCXMK#3.ZZ,7]
M(-1E$]]K`1'&&]C%*FLF_^]LO(*-'[=8/_=^%FI#2.SSIF9F[=,.QZ,\$@N_
M"UZL'1H^-I'Z#;A8Y5.F7>(ZEK[@+$C?&HW(];Q8CSU:+?KVF?,?`BM\J+9K
M@JO(4W)"EO`Y\9Y&';@&2+$X?K7&L*LN(%D>CX^B7"84-,PI#LZM9]'G'(R6
MA8(@9AH(B'?9!"$&U70%0UL$-D+355UJ6)YK_;)IM<5GH*_=_0&8[)VXP&)$
M5E1QU"+#1G"VD5BJ&YY6;MP!I]<;UXWC?8,B455P5"^N84M6F@%.+S.V3@(@
M$\HM5:A6_]FC.;WH;?RPBD1*38)"+CM22@F;)#P?S_)]:=U(]O.(O$DYPM07
M3N+N:5#L(N3-B>.#KAG_UA[*-D<YCSA><<7,%$KAWF^9+,EPFJ!F3D$&8BA-
M>(8X1KA[FK9;$#H2*#W;1!H/]HSA)^PYI&I\E5,0G-!-_BD&>-`\U#17EJ<=
MHWYG`BPSC8`-?.";*N!8ZWK?LE8*Y`@H\:+7B`HP.44$?V>N>\`['I9\,A6R
M$H`8_6=U\%/;<M?0975.E,K1Z+61-RCVPA$#CJ;B$Q^+H)/%<2/;UDP@C?"W
M(4=*%HY>=D[7O#[+C3'0K`0-*,O>\73L$S0D'QEEEHELITAEG3Q-)MJ>^.D=
M@@W&3T]G/<YHH"0`9"(]@0WS:='NWRX-08?\):3W"U6P.'A]O"SS![5@`&:V
M,Q$\BLD,2T8Y+Q"G4K<^M:E]MT\WR=DEU#C$!R/!"\-+V]?[./)ATI!*D2,?
M'F?D7BS!#1&%&]NTKZ/DE1.EKW?%-XESXM%A)_3SVA<#:.D")9H1`[/,A;0-
M(:ZIC4-M"W=O+)P9>Q?=Y"+!&1&EH/M2[LUEOT!5\3R>2'6QV[<=:=L`53R/
M`\?Q=(B7_<^6$BZ7"Y['`7T\ZBB*"@MAT5/U=LU'=9P8&U)#75)#C'TAT3<L
M13ZRXS"+L2=KO+(D:H,%4KDNY=`$^^4"U8SC.'I,JY+89Z`IQ/%3-2B,2*HI
M;98/571N.H05CK*AB?Q2:2PI2N(2AW)+[>RR9F=385%S.*NK,9IOSP\F(9'I
M#]4EIK&]EHFBMJ-=?RX3X.`*H0A%-`X<'BVD]R>WS5EAT>U%<A=3$)(I9DM3
MF=CWMQ>L@YIDQ#H&B)S3`)EOS/2:"=D/:#2VL8LYRZ%`T4UW(M&?2:S#H!7T
M)NY\@&?I&`ZM9AYY*V`F5!CS=?"BKIENHTNK.=]HB;H)F;BI&0*W##[F*AB&
M<7.Q:UC?GR-?R\7]4D)/NV=YNT?A)IX[@BM(?3J79+P5PZ-A85D@+,RTKD@V
ML4S,.J<:;G7S/5"'.*4Q[5D-D25JSL'6D3KO@[P.J&V.3;J=?+LT_'W45C\&
M=<]&,%PAKIE*]B&2B)F`14RM[WZ#0FTHO)WAN[JQ>GO1U2*=8F:JZXO"J.@0
MJY0-9=NV3U_;L7`IO)AO+#R,"KB7032\QM'&XNTX]"-5GU?=\H*0]72ZH%.W
M;<_/U@49JF($)GSI4DK8][TO'$<>7,=<1X?;MO7QI,I0'[=[DBK'F@WKVS$?
MS^?P`MYW/)]//)]/&C\38E=_3H'^,Z,X&<@QNS1(S7+0;C%6CKG]7T<^@XV^
M(=/"(_!:K&QJO8A]#&A?/.N&_')]`:!X>WL?6P+9:#45?:6:TLA\-`#/YP-'
M/HP%$Q][&ZER,=/<#@P":?8[G3C0/1AD(?P2\B[S=E5V$Y:)A\^67)ZKZK^G
M\Y>%%RO+^V5(D9N(J&O2!1H]#.K5%=@V=2SG(Q34).*L)DDUB8N/TW*2LVLR
M&$GDC7DX&&13/*HE>1/-8TZZ$X?L,DI;6!2YOUM3H<'I5]R8*9!%)Y%CA`JW
MXS@Z/]I.!_J[TU!?S%.H57!&7T^@I_Z^H9]TY/BP2%R,!9D6V86;GBD5ZS[J
M=JP-)$"OWUW>)P<4$=+H]P.F>XSK7I[L8T%C$3_E4"6*EH2!(`IU34Y<;(,!
M5Z9N$%=*>)WB?6L22)\P`8<WG*$7BA\AN9\9"^](?FR3P)'VJ'/$I.-S?Q>\
M_[,U[_10=7_'-L8E1)3[+*U>='8SRZ'?;/>LFP/M@05".".2<[:XV9>:DX)\
MC,1^A)*;A48TM,72S_C<?O!GQJM/[;7F0EV#H`Z_B$^9N)$+LZPO2%28(1CK
MP8W88F..4=CDZOO:1W.5SK!M6]_,'X^'+;"THC`I8=^V29#%#4!+W=JV#8_'
M8WP6'<^^[WA]?2U(\/-I48N3Z]"6KE;T#K6W.*<#>UDU9QPY3PM\BP25E+#M
M&XX\[(?*PD\C;0$RB(.K1^_@AL*ZO'/[?L&^[W4R41'4K/VAZA.9>E]8A`-5
M/)\/8\M5.+BY(X^<!,?^J3GRE)71R`UE_T?-;:Q:GL?Y,%'"$2C$2%1<GY+`
MS;L7^'4@:![5)<EY1+2@_C(U`B+KJ5WA]NH0S9;8+6/!Q+,/"0K`L5%[1)Q1
MUFR#'WISH8.J$Q1A'%"AB!L6P\UUZ[`O=OTDSH+\:J)_N6E+/A6DKB.'$ZJQ
M'1=3'4J*5SPQY4;@H/3`5O2WJ8U&:7-]<B>&"R[N>/WW*IH[QXR$BT,NQ=$S
M,%$*$,2+$FNW:P(LDNT1W)%BAFG-;6O(?"Z4G-8T#[[H-12AY`KC,6Y4;O3=
M*8G:3Q*:)'K>O3O5GF37W1/4%</]^/DSA^4J-\7#J).^SVVY1F.2T2=R@CF!
MC^_$=\'[-_^CG_W[:>1+G,@8<#2;RVIC,U"^$7P-A61?*%;P8S02\,K>XX"V
M<;*/T/Q$!R"NT.Z)X4;FKE/`P^<:#`E'),J>BV)3L&P`Q+PH"5$CQ*&O@XH2
M-*^?[88\VN]][CKG6"?5K-2&J-!'%6!C<$),CN/`X_$PMD'LDYE4\80/HF#Z
MA?9-ZOE\XG:_5;$5(4_UV<@YXWJY%$3(I'VYM";R'!V?5>#<G`4I`3FG4,33
M-L0>3A+8[H@(D@(_7E\+ZHRG%0LI%2D09#V<RT!%!5$V[\?CB7V_8-LWR,-2
M0[J`C.[-\(D>M]4HS76^_Q(U/\$_1ZB1&M$I"XNR042]JX:X`I/O3TH21A?/
MB.LY'4BYZ)ZH/FKXYF'QAC&I\2_;:.XP%P\3OWG$ET(!33*A9H/J'+^T:CQC
M9Z3,4@28EYKZ^SESED^</Z;SM92R>!R.[H$\C_K;E(.H"HXW[6T*.=8Z\_$[
MJH;Z,(O_K[TKVVXCR95`%BF[__]7Y[1DB96X#[E%`,@B;=]^D\_13%L6Q6(M
MF4`@ED2L1VBSFW9J8A69TS0BW0,_IT>L%1H2D0NM3D?O2T:7<$BSJ*?7L*W6
M]!"'(B_S6,Z.AVD$+A-(-Y0[1Y-`2\JQ/L\&)_$TGX\FF=TZZI5[_IE.YF@8
MB/`:%JW)S-HU-0I.#XJH+H3=$#74C"A_H^`>-*;,S>>[X+UXP.P_?U=+"Z?8
MLLG6TDS#R#.RVW`,@VI-_'>/FF2?O]FJU%A88GIB4GR:1Y4EY_],*YQ=&@LB
MSDZ4E8Y33'.B""CMPY@*"BN#[I#=$KR*%'_.*%?^:3/DD\Y4'0JNJ8<O\LI8
MF-/.W^?G)\2@2G2^Z`7)V""M(Y9UI!7)VD#/DXO=L=B/GSUKX[C>[_<YBF?B
M#(_QS<4^CY$<(L:C4!?@Q,YC=3ZCV>B2(C+%);P)\VR'4P*Q3*V1.\[S(;56
M.<HAQ]&%9P$M76E$5E=D<2E14&E2>TB)2X:#$5WV#&:C:R_2"`BO"R?`>\8C
M;S16A6D#(N0HFLJ*72\^PW$T.C%PJ<GH<_@=)M$[UX4P+D15%C(U:`:.$VB:
M?>84^-Z?6WB_A<HM$_Z1RM:>!4N+J#2QS%$0TN1";Y552BL4`N6EAM?.!$PH
M--#)8K<GVJ912A%X`;]6CY([]-B302EPP?.>,6A%8Z$<:3EQI&V0G,>."XQZ
M9E2:K:6HLB/.$&_*CJ.+[C/&C@+K955DPTW--F8MFIX/<^`.3E2*%)X`=<&;
MUU@36NJZ7/J]:J&89H&CHV)XL;'0@"DMM*U:!)Z`JF6;)H+`D.]25[;=WY4/
MK]GSM&!+5M*<$&"7X^L\@S`:O%\<]5-:QCJ2C`?CO1T3*RTW]M!,3F:\6R'G
M[LQ&N)L%!C?C@+)NTL`\ZC;$(C.0(WB"ZM9WV"MR!?#TE,X@>9&OODJ?&SS>
MEQ5\A]EF*T,>)KK6B\NYX5I4U5KB+H'GKU:3LY[RZ_.S-SJ<A*1@,T>1I:XA
MH;A1Y\5JAO2)=I9NMQN]IBV\/0#@/,D,/PM1&+QC;@1]H2++)-Z<^X`M4_Y:
MJYSUE./H]`]9W+WACD%);L#;1)]?F\ZN"M=UB=XPHCD@4F:Y;5THBO91HZC`
MWZ.I0N<U17?KLE)KUP3.K6M@#>@:.A@@B[/5.-K.(S@TVVYV.DW]*1W.K:]X
M;]4U#BY:6K-QUN4+WN-(2]^SB\#:4/!Z<'JD.0!A)4ZU,]TLM>(JFB'VOOB9
M%G%9L:RICUI`2\F'UO+@#VP<ITN!LU3SPK@9PB%"]F:AH,]&`!$R#Q[0'N&>
M#:`8^+%"1'%=?/F:1#E;^.S701Z7^\Z@+D@4M06K:PB`F>\-P3E9D,O:!D"7
M8N#5;9@]ASQPF>N].0X1"Z8K.\?KDX(@`0(CSSH):U(NNBNL<^E]0/>*DE--
MMI-ZS06)ZR_V;>F4F^\_?\ACN'R>_^9WZZ;HA;]OG<7,Y+G)&J_":8BIAJV2
MAHQ".)>)QE@W(7_"E(>_(A<Y=>6U*IWST2.(0,\Z?BR3D*"$7]4;MD-U/_X]
M:TP,1TC*[ZD7398WWP^JY`3=]:DT6/%;PA6<=D^`[!RER.VX]<VB`GH+'HNP
MDGO3>W,)5VMAYT0I[,:)RQZ-H;M@;4>[B6-/+843^\HA;V]O7!S!6W$BFA/%
M&"^>C>\[7"A$2KD[#J%,I?E`O*,/L8;(3#R7?O'V0A]+J`\K2<D;[U\5P\*=
M>DA08P&5.:*0YP3O5A@%6[&([/A-#J<Q/ADM%S#YL(WP\>HJ`+PVU0=4Y&-F
MZ<KWY5;B$<56\)35YAI:Z@FM(=EH/#MV$H4Z-%TV"6!8F"X_\C@AP`(WI/*Y
M8\DF)U@,^T:VAL3"*E8M<.Q#T>2H"+OK45P@C)^`H$>KIN"5NO6=)R/(A]]1
M&>8Y[KZ\XD$2M\[Q4\Z-FDT'$$T>R^XA7EM(S1*0NP"/224HHOU+])CKS8@>
MICVWZJ(.E+C=\UJ>5`[>[%<U`$R9.XDX8,='S(M;[S2I=\1!9W3/;]:E8=N&
MC;%\VY+]+2I\7;/:D^^E1;+&&]&_3IW1M9F%@(F=3CNMDLTCNXM,'CYCJ@9E
MY,&KI1WVM#DJ#>CL2TUWB&3UQPR!`,YD?(+G&UL?1D\,F@-+^Q.[Z'B>>B?[
M"8)PIKDPK[\Y3607W=@B2R%2M1R''+=;M];1B<8^SD>RV,OD<GH?8!.TEF&'
MB\PV:9J8;X80(Z)2G8*\4WL9$7(HD"IG$_[X\6-^KAH0.3[/*!;#K@@W,:LB
M7Y]?<K^_K<2P,ER!VNM__/PI(BKO_[[O@8N^L0ZAW"IH)#QKFB77[:P3>50P
M89V!#J8;`CYH%]Q"T\255Y5<`Z).-A:NU`CT-$$Q<3QD+I2';W/UBFXGQ#,Q
M4I2KXQ\C\D>F^)"2)TZ1CO<U7X*U[I8$J<."!'U=+4$\LQCAG4M!)@`+-(A-
M<>W?ZUF!&=#F3E'*J`\*J6SL-8PTEHLIZA5%HI]X)?]KF8K\D.0),&FSD"LQ
M+`*F>U9YW(ZHM/=&GN=NIM^Q:#0VLL:)G::SR"SI]0$!JH-(HJV=3JYKXU9'
M7<EX^VI&I*%6RRKS^6UQV$N2Z)KRKR6C1N&T1N$90RV'2)%]K'G86UVSK\'M
MQ<"!9[']>?+"4[5OA/<*+7@^X7@9#OXMVUZ+V.'N=ZZ+^IS00*!=2KU@VH$9
MCX&(*\1>.Z&3TQ3^N3JW]BSF/NTRUO'!TJ5,]WMVBCV:9L`C-AR1)H-EW3VL
M%Z"]3T6RY#RI;L9.Q@4;.O:BS=.,XW6CS?,\Y7$^Y.OK2SX'3S8!`%7YI@C4
M.-?5F^RMI+@XECFN-:B"%K6OQ`TA00XCA[O]_,?'^^3_6O?-W3T9L#Z'A799
MEK6"[?/7)R-#'6TZRB'W^[U1+<@6S(3%IOL,[.T$[JJ[)J3*(7[`M4[[S%%$
M3@$J]G>,^-(]9A(Z4E+_PTA\%J06Z0GJUJ,IK_73%L+)-&2E!T5_*<X]RW*E
M.PGKA.SAS#A13T#PA<>2(;B2%/XUH=T@(KN2Q2*@D:)6"6)*#VZ"[NY^#_XW
MQ5AWJ@`Z*SS;-VL28RR64RRL&@5L8`,8UW8->X)_#N?Z#.@K[RML_3;#9E3<
MY$HOKY46=C]8H_<"@T!T#5E.+H.292_4`3M.]=0G!S>9M>?.I]4@_&;0/DQ`
M^%NI.2F7M<XFW">A-OB88`4-3-%X;8-KC[%(;U"/U.229RZ8J&F1]SSVPV^$
M5WY?L&;RG"EKS[&\)Y7I\]_]NP9A9L^/R+*%NR\.1SE$>M[WB:,OV8RY7SJ#
M^C)ROON8F2>HV759&F,,84'4G863;M'=(,Z#]9/^+4/5W'@.\M'6PC2KQF68
MJ"IRN]V[0*W2&XZ/5AW?]03?6-S`,QL7Y"D2BB8<EZQNH_0;K68;N<9MG@0F
M-`'05:")I.*$L]:)IKV_O\O/?_XA89K/:1^6F3AZ$XKC'.*M(BHF7X\ON=UN
M4LHAC\=2KQ^WFUAMP1S3)U.9^^FYN4HQR)*:K&?K47#&D^>>VX:3"?.1ID*H
M5S:O")&NLI^*:+\.O)"T.%NKQO4$CCL['UB*]:U7I]T>-5,:-S'+.#8]"6K^
M7#.,G>-DLK5*O-4&*MU&V(M3BP54*8>C[>@,)LD\47>I@'Z:%(K=!!$<Q9<`
M\ICN#T]<!U@TIY,N@($;#=D5"FU!#V=)1M2C8BEEQ42O$?1P?-!HVT66)S(C
MQ@G-Q_0R&QZY3,.8'M8@7BTETH9JC2)0)1%:<KYD3=>(0^[0:'ST%>]53+53
MI2G4^+Q,(8"D0EO>RU[#,E%OR/\NT+3[^RLZ#RG@)IS0Z3L.3L\38KX-#WB<
M`E(259_<I'0^8;U/N\^9VXQ(MFI^GT\!O6I(9_Q&>)\69WD]:J\&3KQ>Q_)D
M\F(WTST&\.2]'+$@@(@+F?*ZM=&52[^A@].@00R90P,U\NP)W1$3CU4^K7B)
MY[-:W_5>9$[?+$^P$Q;E3C-\`5]M?7&T;R@<>FSTE!ED=!2-"SUEU3L$G7A*
MQI>I'(>4HP"Y?_TN,T0W'!_45G3E?#TA(!74Y7X4JH&*.=[O/$\PJM]=-5QX
M->SMF4@"O\:Q#)_:\:6`IIF(?/[Z#(C9=!MPWHQ(TPC^#F"!]GA\R=O;#9Z?
M(K=R[VES)PG@YOF;JW*-Y\(6!]0V5G[VXIHQ*0P.O4/;GM!,./ZN'R.NILU<
MXI]MD[TP9E3POM4,<8&_%Q@1F[E0.H6-6N4)\-U^NI1Y[D=1L;-45"S`.D*N
MW3)1QQC:G%=K7W.*KFM8P-,Z*VXSFZ3=?V=K$/TL6E)A7'@_7OQY+T2+>Y]#
MFP&T.,\:$MDRA-@WZTCW]/J(2;D:SY>15UH3&@;@I2Z183?35AF.%JN@*QA_
M;/(2Q]-3(C)ZAZK.\YKQR#,A,]C%3)M+/S$ITRQLQ%KW9KR(%.U_[T]2HW,,
M4>T043KA@7))5URL<[9V3'L_C<F-$]8PEN>0!*._MCCM!\EZ:'\K'-PAK$V=
MUFJ*^`X4K3J^%%!M)0W!:J+XTWP7O++G,NUVF%?\$%3UE6R$?4WZGWBB*1>J
MEI?2/I(O6Y@]@C<]!-`*R78?1;?G_7G1JSD4?8E\JWNBFHJ:%N_^L!^WF]SO
M+6B@V6P=<T.@+T?=L`DE^4C5_6=!JQKEJF\NR%MD7'LZG3U']+T`S[#)&%'2
M(HEP<!,7K&SA-OZ,4(I(-!@+57&\-^:`%?!YSL;$802=QJ_V?;.>[`P"FVP:
M_2I"0C!28/<`BL?YZ"$4]R:`N+6&XS$H%.Z\X0'Y&-,H`(R4"G$;18;<K6CB
M#7<S<8")])K(T_;.&D9HM(;Q>KK6J5"SYI]6%.QY@5#V._W?J^U":IA^E-_?
M+CZ\<_V'/=,8\WNTU@"^(Q&0MM=790K.[P`K6=/A71)VT;H*G.)Z8<VT7E=F
MH8Z_R],71LB$%XME""@>NTVG&%[3D#=K`3F,][TE$XE0C,*Z:=YR32P@MH2*
M&M-5QC%EC48(3W(W>^J,THO>Z&C!8KHH(%=RCAGKR@Q_ZD6QJ(E)G5QW_X<F
M?(EKCAFK>]0EEWJ0+-.K9)5.J)M-`F=Z6P-XE-^?;X@`%\DI8>H*B7&/?%,:
MKE#<;3'[O"#]`R*#3^#\$X>QRV-0KD[#9S+;T0Y`F)2Y2-#D]L^I(0J32'N!
MS^#!CO5@*)E^^]>C0K[ZQ;K69J#:1X73P-][_8KC@\FUB/&JT=(+,_DIJ#(A
MON51CCYZ166M]_A<"VM6.)2CR*$J<AP-Y3V]IRF'.M6`(AI'4^/XC19=(X1M
M!J%4(=0<[<A6X[7>\W:_R>?G5]CLZ9B*TNBL75\8_ZH/48#S!H(.&@7V;YSG
M*59-WNYOHJIRO]\[\GM2D`#3!.`]C$>S^%R%C=Z-44,!LWD.57WX#-,(=$YG
M)%@9SDCN6:BL$:?A#@D%,HJ9,/I6<:%LL&/GZ:Z%:-(E#)!G',.B0`7.F>?@
MIC00:P-,0NYG$8/'S!S::EV4*"VY<GK6%@7AJ,8XW4%_$*!$H?`5`E<R3FQ6
MT%9G!^;7B>H2NS@0(!:EZ`OL4^'"9"!UAHATEQ`C[.:,124X!PU:Q+"K\T7P
MO*<&A<$%<BA`@96<5H1>+U0\&J7XH>`2PUS4'6/V>4<!2JXF9N$YI(`--3$I
MG?\]Z`8F)B>XHCB$W6$U:U.O92?I6@``$BM)1$%4\>'7VO^M,+T$FP4,7\'P
M'^1:2TW+VFDM".(UOXZ0SW=H^$`4#(MD]=[BQD"$6'PVR,HM`=94T,ZNH;K#
M&.V[X/V+:M+^`(6U9Z6I;0&]?1'HBN3+PFN,NOUK$#RU'!/2PM&.D:/@#E]?
M1*OU(J',G1I-NFR+93W9>IDC+[?-S.@`VQK2L^/!V]%$0K+8<E4%M4\RCN^)
MS]?7'A9%C#3.Q!H`&\CM=IM%^?"378N,Q<7<I2I)']%9YTGM+%X60T5AD;>$
M@**1$RT+;:UF<AQ%CN.8H@FDB1S'(?=>2'J5_8@L?7O[(>=9Y?%X!'-WE0,&
MVN/F*\#1G?86_3@U3#TPM4R)%M,VUB(M<>['SQ]RO]]$2Y'W]_>V`3B%-(Z+
MD7M-R+$NIQ%\W0SO\$65)/ZTV\5`\V;6;!9DLXA0"0XDY$0@GLN[[+*";W=1
ME_B(`2L2;)#X^)RX:"/6-;'."59JJF94NS%S;VV6*Q+7%YG8Q*'1OJ=8S_>`
M^]Z@$![/9#8!2X,DA!7OYIH@WPQ-[]GQ_&+<;R)<(PNQ&@O5'0IL3H3&W%V-
M7JAN&M&<&]:-6I*P#P6DKKAC\39K:<?NBZ$A%!S%-%2+C)C[9IW4"`YP`*ZO
M+94I@0QS"E+!%0?V48W%+)^S49:YAHZF--/IO?TNBUJ&8:E'R+"[S^BY<A.F
M&2JN^6[5L!?;JFP-O)49Q+)]H,>N3JJ6-"ZP\YO&\(GD/O;3ZF]*PY_^^4TT
M[V66@OXWQW51_4+=ZI3]P.MIOJW'6E`L$8OX4=33CX/&W!(1*>=!BPC2,[Z(
M>33,W%S&A+P9?96'Z62\&?G1E$W[)BJL]?JR>+1"19A?.^L'Y-<U^L';_4V.
MHXE)'N>#4O;8`%V)(N"=#D9RWD17"YI_K_&\&T)"3#6/Q<4XV6B<R[-6J><I
MI11Y^_$V$]E*_UR#)E#!/-U(S+&JI&$[-CF#X_,5`<YC@<^@;.FC:.JW[C,+
M"-;P.&8/GZ_'8Z+C#=U]B"4\I.!J(4L<I(*)?E`,RG)#(>0L'\JDXT2S&OQS
M??-'X0[-CQ[4WCI5VP8),SY:.*1@2>87+C%M!0H+E23`Q<6&,B*^$.=V#P@[
MM+AP%4MH$]@`>7$.NF\(.#$LCG,OF@V1/$V7;6P'D;>Z&R_/PLN$BM:L*%7G
M[+!#9U_YOE]7/6J+_%]?"&?69^/U17D1-)CP^#]E\G^CU9<E!?)$_@HW`I+<
MDXNVI>`GC+SJI'YSU*GEA0[KJ^FR$YOT`Q5.>E\Q#X@J%P`S="@^/+W)_(;5
MO_K[MO<&'UYZSCV/&,$.#=,S?[]>"Y346\73L^O-A2R@K[H-=?(N/'A\!8*B
MO%8)D_/V85%%5,LWPOM*[6E_4%=F&]0SFD/Z[S1:E+1+1'3FVN\7/%%QE(EC
M[J()<7T]B&<ODOR"Y)%$W0+8!EV7TYEZW]]H<?#\>NE2:49U=QR%TC%11-LD
MXW7!FP%-8G.?)'01NSS6C<_&7&A+=Q-8OLBE''*[W6:Q=?9QNKI*R\AY(8^O
M/L]3/G[]DI\_?\KM=I/'X]'1#),LW56]""G9<,-&V(_IX^-#?O3WT1^-GE!K
M$V*<9Y6OKT\YSRK'<<SOX29[UBH?OS[D.&X-+7(;^2@<&Y^M;21>A#&/345N
MMT.^OAZS4%K\/:&"R]S([O'XDO,\Y7:T\_5X/'(02N,95V@;U-@&#-TWQ'"L
MVU&5;>.4B,>FPT%T-T"NY^")M_,"C8!YA`0F'%:#+9,X2I./_-:BX;DB#^+8
M@FQ=(XA/;&0&`9MF85XV-`.&<=VN4?`3H:+HJ5M2#]IU3T4*P#B&$M+#ZG):
M$!!06?=IMKR0]6ML[8*RK)GU*.4635.5$Q!IRSY#1V>/X^"H68UH)2/-'+^\
M.X[J$K`0V2L91<,6RN\+>9J4P;V"@EA_7GB,OO![$PQB63];@*==B9[4&RIW
M1QM,10;2OL2.`Q5-!KUF<6KCG":P(+1-DX2K/](IL@8LN_99,Y`5M6O8V:=(
MP1+0UE0T`3,$(JK-(?@<A+/\]MLDJFR/E_9VD>^"-X/!L\WE-^JNL$D]+Y)M
M/]*7U^@*/IAJ7ZS'^`D:=?3I;.N"@;!?:YHPIK#`S)&51"\]"YUWY(=8=NS&
M)P7KB&SCM00!X[%KY-P&JY:!OBGW'&89?UOIO+K#I<(V]U;,O]=>7OOFO=:(
MLYY2/^O<\(S"RP%]W=XGUHK%?G+/\Y2/CP\YNLU2]&/E1)VL>&[7WEM\K5'6
M6+`^WM^;"!"I)<ZW]CP?<IZI)E$>7P]Y/$Z']BQTC]Y3JE,_<%#&>58:H0^N
M=.3CK4UUC(3?_WV7G__\E/?W?TD4HJ[+FQ00?S^:+5LWU=B`$;+$@B0J?L![
MF2@+GA9@XE`FC1S')-U+D\D'=_267`O/5V!>`&W2T'RG0BM-`\J7)Z?!0V]H
MTI_'IRKRAJE0V`1`0&K@>+C&>#M>"[X.YOXM*U@I>:IR&,XN,7-\[RA%3CMA
M[,V%)R>F7>]S67`%HK(&5`%&>Q=:&H(M<&HUKIXFEFVN0,V.R[\&=0`!`7>"
MOU&LSF`%+'I%N>F<S^RZ+]<^V'(TM1@\,0`9P=0P>"49<YW4\YH[QYWN%3$X
M-G3`<`EU_5ZO&^$H%ZJ\)N`S7ZV"7X0%KVLL3#U7?\:TCZ>.+)B$0#;U]W8I
MDR8Q03L%7^"P[_A8&&X.@N8!ZY!OT9JDW5):Y+Z(U%ZAPB^_SG*0][K0SGT[
MXR_9.`=0@(!)/?,\\DLD.@%3?2&>&$-$GB(F76T^D7KC\$&8M1ARX*'PJXV$
M-F_U*)=-!(!+A<WY1K0/$YV4QUQF&[9BMX-KQN6`4G9AP11-C"-1AUN;A/?S
M39;V,`HL`*\V2"P.6!@5Q[`9%?NL9VC@5(?(P(\0PZT[%WN/(GHNFZB)G>8$
M=JO;;_9I*(IQC4)?@(L6BEPV:[2&\W__Z^A?+EPAY`,:J?7\D;EIFCAEU.8E
MB4X));1QVW(4:(_<&$4NT[6V;%P3T?V,;SF0>)H8"&L)LF-;?T^(`B2<-#"$
MMN@"`2+$:HOCVU#*,M%(CZ366KO/;0WWVD`Y0X&LR5Z":]C&>]07==.K-D/;
M.B)<O(@'J1,"#@7]X0++WJ=%;D9U&*AK1FG)/'G#/3`B<_O*58A77)F"XB@-
M`_T-3:@H!61X3V.>-FH,8J%IX_!:MNDJT9[/$C>JY#Y74(,;OLR8;D&%^RQ4
MZYQ(>,`#M04CHAPI'D836YW@AX\B7Y,?#E_!I#+\_!HW+F[0?/IAIY=4='8D
MG-O8VQ[W!*N.EJ61.P]-O4JV/MK<A\=ZC>FM.,G^+GA?+B%AJO#RZWBW>!8O
M;*]6U2^@A-G+\69^5CM7R3O&(*0)XBK=5,!N[*$ISKO.T2QZ'==(40P0QWA;
M[#RY=IJBW.OQ4-%4*(?C;ZMV8;RL$W'+QO^2%`N6'3WYM!J4V3#R0TB:T($N
M;$LV,G7(R):'HI*C%DX@A>-.SD9/[E/H$IQOOA-[90\'QQEG8[ELK"LTIG0?
MPPD@T6L514>#+UK-%UD[<861&;])%V/4UF"@#58H2G'A!U-^[<V-CTQ=A9%.
MM&E7R&2K!:<48\"(B@\OSRRIO'L!*>A5$KJ3:VG#]93)4JS!JW;CQZMQK=)2
MY``ZP1R!]K%$$'B5LIWD9=0'1`=572=W-4%LALTSX,%_H%"4]M]9'6H\1:\9
M1:HNU;VFL?#[O<1\1'(0P@G];I_:1F(P%1=PD]#?(#(=&ZD9))$L3]XE1*[H
M&_X9@`E?#='2>2"2VMF?/X^CH,@-+1!MCCEK=T0HO0.Q'K-M4M-GDPI*E=XL
M(&MN"84)8O`A$18;Z?F_78MG742,4PIU<)^1"!O*2G6QW?TO5=KU+(-BY"Q=
M1W-1S37>RN@Q\I4JT3HX2DH+K!.T%BU"Q+=H37XC>$)_Y\<2K]%GA:;NH=#K
MU^G?GP1]H>"G[ZO[;Q8)H4&W/P'C)I[FZJ7'%JLCM"-QG5`4"5T]=H,AVH#B
M>"62[I/3H/2X9V5H+!(ML4<1C595J=`%C?N3<T>;J?K4LM6U3R/N1$6=%H1/
M[FV.K\7,]WCVKKA?V53!J`OWJ;46I@-XD7?&_>)H)][O5LPC;/#YK`E(K&9J
M>C_^[,=;XS.0%0R"J3^T*"<3E.DANBEBDGC391.VN'(F[`M]O<[I]G>V[Q5X
MJI:M52C2J#E(:`535!B?JR!J0A$:"E:1KM`U/Z6L!JF-5UO3+GU<6ZW*:57J
M$)FZK-,IT-2VT:L39K9GJO1KDX1*"(<I(-7`NQV$,;S*LC^\<"A`C8%MD%B#
MH!1_/KT[@X_.#9\I";RXBC?.[-.,FIXUC@^QO8GON%TX3B#*Z\]71MTI":I>
MR8E'Q:1T0=@PZL'=HJ\-<DB5)1R3*5KK?]<B,PZB%[2U%ZNU'8A4L?X]7D/#
MO>_L_M*]&F)U3=!C/=8(-NYI&(Y8;XKF.@D>T[3.(<5`T;W(>51WYQ_KZ1#S
M&M%"M'ZG50R[4@BZB?<"V\:Q#B`@^&:92^IWP2O;3>7/ZTO;_.4RA.`/B^NG
M!P7/E-]_=%-@1_HP\V,P;G:.+_I&-HK74D8"F$:SW=Z-:2E=)%<HS8:O22P^
MRG'(<3MR0_*,9O@[U\MW)\`OVFA:H;B5X!21>PPJ);;Q?9@KJSVZ&B)?0XI6
M\CO,QQ!HLF'ARB208,.?*4V,<QN*YW1>"2DU<;68PHK`&XX%HJ<XS*9`O6DY
M/Q2+H]P'R6:]:)20@#>]7:LX$>3B><9Q=1ZMC#_G"Z@T'4^$%-8["H59G`H,
M93@B@CY!T/\.0HW%GBJW\5A+(@[B>ZR&@DI=88-CVRHKH8M&G'`(%;\_B@F-
M8081F=Z$5T!"F3_)WJ6`G`LZ:N_&42D_%;G9:<!$YH>+*OEMTA=,7-QGF,4@
M%,.[B0@)\T32D)<8J"`;VD43F54HQ-&6S#;1RF4393P*9"KJ$X&J7J#8BV.O
M+C2&O8H-K-V7>P`Z_&CJB,%-@?/$I8F!!5<)CBE>%(=*'NF</H@I;BA@JX[^
M,(OQ=/U>8KK9Y"9[&F2;Q7.K%T"B7D&$%C<PY#\31UK3>V84[D93;4CB^RYW
M]Y2`OX=,]<]^IZMQ]-5WRM3X^O2P7O[L7'R0+)K0RY&816IH',40TJE39*+L
M,\2H:'^KXSCD.([`0=Q@AY>?U=?Z:=,1D!96BJYSDD1+BLTP!I_VL[,SFD*,
M-.;1N)L=2.OX;S0`SY)_$DLN#9LPWB0N.`%1YA64GA9KR]@],2$W<:C+XL@B
M+UN39`7/#D91G!=5$9W%KK'-E<9&P,G,AM=26G1LN/7ULI#"<AN1<>0$&XS\
MT9IM!$44[<^3+BLFVUA7X89;-C&HMGE=V-S0CFP6:"EW($7XRV6P"HYKE9LK
MB04,"ATSL,+7/.L.5A*$*02`H/#5BZ\:4@Q):\ITAM:H2^($$FD)'IGT)SLK
M:D/BH$!Z&9YC*/B6N++26/>Z$).T4,X0X8">)L^^+XR6D+F#'))/-&BZ`=S9
M-'QCXV)Q)7H+=HG"8F4=:[4,9PV;,;[:,-V^CM?AJ-M<<\@JDZE3DR*`./)L
MUE:#K&[-0@N\4GAJD%V+=/J(/U.4+-%>HWRP->"*'W;)H(BL*G.EG]$G4SM'
ML?#LAV8.T)>"1;]%CV$24MMW\$2^$/V__G*YL*G"SB3!KM#3WZY0X$2-]KMA
M#Y>'G6^,EA3;:/2\;$J44-"`9`[!5<9EE(U25%;2CIG]4;OR.X%V5"JJ1_8R
M--TEACBA6ECPP7C?>Y?Z4?HT6">:="Z8"HN&>@Z4)FB1D$)X(?J%_"B]T6HZ
MRLS\6O7J>@&7-@M=:9+@Q6MSXAU\8#3+`2?5+ORL%1)4C5MT(F$#Z4HXVUE`
M@4?LJ]7)K<T:'WM*[(="H(@+_V@%FYDY#Q9\)IV0#9"SS'5@K1$+[<H,L(.=
M%=`6&JI7<]ZF1J-\#=.'E88V*`8Z@QX<&@I"G*+<>"S!KVVG>:&!Z.<7"ZZY
MMFV1P_[_-3HXA"9#->4L>X]>3`>S(!:RU.R?.Q9-$Q=W81B^>$YM)D=A*H4*
MGN!R`2CAKNB.(10UC/85/[\K;HM#B2<5*`&U?'.B@Q@K%H1:%$CA/+&9;E(G
M/YPH6/U^*ZK4V!4J2KNOKC*/>=8#P-LV%V/OUST?GC']J[U83IR#%#[KHXG"
MI1O>O[AG*$`VWI5(9#D_:/2[+Y/2Y03H+@X8DQOU0D!+U*F24()$Y/\`NTK)
M9JYV"=T`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]I9&5A<R]G<F%P:&EC<R]L969T7VUE;G5?8F]T=&]M+G!N9P``
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,34Q,C(`,3`U,34T,S,W-C$`,#(V,3`P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(```$J```)Q`@&````O9LIN@````9B2T=$`/\`_P#_H+VGDP``
M``EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]4'&Q$6&*D/SW0````==$58
M=$-O;6UE;G0`0W)E871E9"!W:71H(%1H92!'24U0[V0E;@``&;9)1$%4>-KM
MW+^.5&4<Q^'O^^_,F8$,V83+H+;%TM[$F^$6+`TMMZ`UA%I1KV`+"304[H1$
MPJXAV;$XP^+&&`NS[!3/DTPYS:_XY#?O><^4%V_>[`-P!+[XZ<<\N=AGOK/-
M>GN2^>Z]C'F=:C3`L1,J0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`
MJ`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"
MA`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H
M`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0
M*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`
MH0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J
M0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$
M"A`J`*$"A`I`J`"$"A`J`*$"A,H(`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H
M`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0
M*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`
MH0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J
M0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$
M"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`
MJ`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*
M$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H
M`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0
M*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"
MA`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J
M`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$
M"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`
MH0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*
M0*@`A`H0*@"A`H3*"`"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"
MA`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J
M`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$
M"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`
MH0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*
M0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A
M`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`
MJ`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"
M$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H
M`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0
M*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`
MA`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J
M`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$
M"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`
MH0*$R@@`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0
M*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`
MA`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J
M`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$
M"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`
MH0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*
M0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A
M`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`
MJ`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"
M$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H
M`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0
M*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`
MA`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J
M`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"A,H(`*$"
M$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H
M`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0
M*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`
MA`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J
M`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$
M"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`
MH0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*
M$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A
M`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`
MJ`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"
MA`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H
M`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0
M*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`
MH0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`H3*"`"A`A`J0*@`A`I`
MJ`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"
MA`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H
M`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0
M*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`
MH0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J
M0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$
M"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`
MJ`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*
M$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H
M`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0
M*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"
MA`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J
M`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$
M"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0*$R@@`H0(0*D"H`(0*0*@`H0(0*D"H
M`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0
M*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"
MA`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J
M`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$
M"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`
MH0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*
M0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A
M`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`
MJ`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"
M$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H
M`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0
M*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`
MA`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J
M`*$"A`I`J`"$"A`J`*$"A,H(`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"
M$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H
M`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0
M*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`
MA`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J
M`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$
M"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`
MH0(0*D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*
M0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A
M`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`
MJ`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"
M$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H
M`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0
M*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`
MA`H0*@"A`H3*"`"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`
MJ`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"
M$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H
M`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0
M*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`
MA`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J
M`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$
M"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`
MH0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*
M$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A
M`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`
MJ`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"
MA`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H
M`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0*$
MR@@`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A
M`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`
MJ`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"
MA`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H
M`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0
M*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`
MH0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J
M0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A
M`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`
MJ`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*
M$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H
M`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0
M*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"
MA`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"A,H(`*$"$"I`
MJ`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*
M$"H`H0*$"N!V?;B\3!,JX)B]OKC(29^2_3XI9?DD*:4(%7`<GN]V>;#97@7J
M4*GL]WNA`H[#L]U9OGGU*DE)KK7*1@4<B9?GYTN8:DVM+;6UE%*RCS,JX`@\
M.CW-P^W]3+VG]9[:>DIM*;6FQ$8%W+*+R\L\W9WEZY>_I;:>VD?ZF)9@U9;4
MDFY,P&WZZM=?\OCM^TQCE3ZFC&E.&ZO#5E6=40&WNTE]^?.+?+M[EUY*VAAI
MTRI]-:=-4UH?RSE5;%3`+7AT>IJGN[,\?OL^HY2T,66LUIGF3?JT;%:U]:O[
M5$(%W*@/EY=Y?7&1Y[M=GNW.\O+\/`^W]_/=[H],8Y4VQA*I]9V,>9.Q6J>V
MPS95EI]^)3]\OS=*X*:T)"=]RH/-=KDG59)5'RFU+8?FTRK3O,F8-\M&M5JG
MC>NAZD\N=`JX:7\F[WY/YDU*K6FMIXZQ')Q/JXS5>OG)-\V'ZPF?(I4D?;ZS
M-4/@1NVSW#!/R>$R9T\;4_I8I4W3X4QJI'Z,5,I5I)*DK[<GI@A\GE#M]\NU
M@];2>C\\V>N'3TM*N;9)785JOGO/%(&;=>W=O7KUFDQJ33W<E2JE'D)5_O'U
M/N:U(0*?IU>'=_=*2E++X8E>^==`786J=C<4@,^G?ERO_O9_4_^EE^)R.G#S
MF]3_\1?@!'1<H8/1M0````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]I9&5A<R]G
M<F%P:&EC<R]L969T7VUE;G5?=&]P+G!N9P``````````````````````````
M````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P
M,#$T,3<`,3`U,34T,S,W-C$`,#(U-#`P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R("``
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,#``,#`P,#`P,```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(```$K````
M3`@&````-2*1X@````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$P``"Q,!
M`)J<&`````=T24U%!]4'&`\9.6;SXG$````==$58=$-O;6UE;G0`0W)E871E
M9"!W:71H(%1H92!'24U0[V0E;@```G-)1$%4>-KMV[V*'64<Q_'?/#/GY&RB
M">[&*AAL@HV00B-$A(`DD"*7D,[+T%*OP1O(10B*N&@EVFD1$D0,=CD;6)<]
M+_-FL6$5@Y6&G>+S@:<;IO@77_XSS%37[W\^!F#BBA$`8@4@5H!8`8@5@%@!
M8@4@5@!B!8@5@%@!B!4@5@!B!8@5@%@!B!4@5@!B!2!6@%@!B!6`6`%B!2!6
M@%@!B!6`6`%B!2!6`&(%B!6`6`&(%2!6`&(%(%:`6`&(%2!6`&(%(%:`6`&(
M%8!8`6(%(%8`8@6(%8!8`6(%(%8`_UESX>8-4P!L5@#_AVK_\7(T!L!F!2!6
M@%@!B!6`6`%B!2!6`/^J29);/W]K$L!+4R=YK9GG[?,7\\&K>[E>-;DTFZ>4
M.E4I?YU4256EJJH7[E'M/UZ..Z^TI@F\-.TPY,EZG:\/#O+5P3*_KE:Y=?%R
M/EI<RNL[%U*:64JI4^KZ>:S*"\$2*^!,?/SH4;X\6.:3*V_E_;&DS&9IFGE*
MTYQL6?\(EE@!9V8]#+G[XP^Y?_EJ[HUU9N<6J>?G4C>SE%)2E?HT6%ZP`V=F
M44J^N?%>'CS]+=_/FVR.C])M5AFZ-L,P)..8<1S%"IB&+]YY-Y_^_C#+PV?9
MKH[3;3<9^S[C.)Q>(U;`)#:L.[M[>7!^GNWJ..UFG;YK,_PM6&(%3,)GUZYE
M__!ICE9'Z;;K=.TF0]]E',0*F)@W=W;RRY6KZ3;K]-NM6`'3='MW+]_]L3S=
MK/JN%2M@>C[<W<U/QX?IVS9]NTW?=1F&/LGSWVT`IN"-Q2+/NFWZOIP\`O:]
MS0J8GEDIZ9.,PW!RQB')R7=6?P+.T,%B$JXQ5`````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]I
M9&5A<R]G<F%P:&EC<R]M96YU7W1O<"YP;F<`````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#`R-#4`,3`U,34T,S,W-C$`,#(T,S8T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```!````,@(#````X)59&0````Q03%1%+UR7.I7,________*4;FZ0````%B
M2T=$`Q$,3/(````)<$A9<P```$@```!(`$;):SX````/241!5'C:8V"@,7!@
M<````60`@<VN4-L````7=$58=&-O;6UE;G0`9VQO=61E;6%N<RYI;F9O?*`U
MT`````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O:61E87,O:6YF;RYP
M:'``````````````````````````````````````````````````````````
M`````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3<Q
M`#$P-3$U-#,S-S8Q`#`R,38W,@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<B`@`&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`P`#`P,#`P,#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]T
M:&5M97,O:61E87,O:6YF;RYP:'`L=B`Q+C$N,BXQ(#(P,#4O,3`O,3@@,3$Z
M,S0Z,3@@:F%N($5X<"`D"B`J+PH*)'1H96UE7VYA;64@/2!?*"))9&5A<R(I
M.PH*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+VED96%S+W-C<F5E;BYC<W,`````````
M```````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,3<S,@`Q,#4Q-30S,S<V
M,0`P,C(R,C0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+RHJ"B`J($ED96%S('1H96UE(&)Y(%)O96P@1VQO=61E;6%N<R`\
M<BYG;&]U9&5M86YS0&DM=&\M:2YN;#X*("H@0F%S960@;VX@=&AE($ED96%S
M('1O($EN=&5R8V]N;F5C="!"5B!W96)S:71E("AH='1P.B\O=W=W+FDM=&\M
M:2YN;"D*("H*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O:61E87,O<V-R965N
M+F-S<RQV(#$N,RXR+C,@,C`P-B\P,R\R-"`Q.3HS,SHT-R!C:'5C:R!%>'`@
M)`H@*B\*"F)O9'D@>PH@("`@9F]N="UF86UI;'DZ(%9E<F1A;F$L($=E;F5V
M82P@07)I86PL($AE;'9E=&EC82P@<V%N<RUS97)I9CL*("`@(&)A8VMG<F]U
M;F0M8V]L;W(Z("-C,61C960["B`@("!B86-K9W)O=6YD+6EM86=E.B!U<FPH
M9W)A<&AI8W,O8F%C:V=R;W5N9"YP;F<I.PH@("`@8F%C:V=R;W5N9"UP;W-I
M=&EO;CH@8F]T=&]M(')I9VAT.PH@("`@8F%C:V=R;W5N9"UR97!E870Z(&YO
M+7)E<&5A=#L*("`@(&)A8VMG<F]U;F0M871T86-H;65N=#H@9FEX960["GT*
M"BYT97AT('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C864X93@["GT*"F$@
M>PH@("`@8V]L;W(Z(",R9C5C.3<["GT*"BYS96QE8W1E9"!["B`@("!B86-K
M9W)O=6YD+6-O;&]R.B`C8F%D,&4W.PI]"BYH96%D97(@>PH@("`@8V]L;W(Z
M("-B860P93<["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C,V$Y-6-C.PH@("`@
M8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",P,#4S.38["B`@("!W:&ET92US
M<&%C93H@;F]W<F%P.PI]"BYH96%D97(@82!["B`@("!C;VQO<CH@(V)A9#!E
M-SL*?0HN:&5A9&5R(&$Z:&]V97(L(&$N:&5A9&5R.FAO=F5R('L*("`@(&-O
M;&]R.B`C,F8U8SDW.PH@("`@=&5X="UD96-O<F%T:6]N.B!N;VYE.PH@("`@
M8F%C:V=R;W5N9"UC;VQO<CH@(S-A.35C8SL*?0IA+FAE861E<B!["B`@("!B
M;W)D97(M8F]T=&]M.B`P.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@=')A;G-P
M87)E;G0["GT*"BYH96%D97)B;W@@>PH@("`@8F]R9&5R+6QE9G0Z(#%P>"!S
M;VQI9"`C,#!B,6(P.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(S`P
M8C%B,#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,#!B,6(P.PH@
M("`@8F%C:V=R;W5N9"UC;VQO<CH@(V-A93AE.#L*?0H*+FQI9VAT('L*("`@
M(&-O;&]R.B`C,S,S.PI]"BYS;6%L;&AE861E<B!["B`@("!B86-K9W)O=6YD
M+6-O;&]R.B`C,V$Y-6-C.PH@("`@8V]L;W(Z("-B860P93<["B`@("!F;VYT
M+69A;6EL>3H@5F5R9&%N82Q(96QV971I8V$L<V%N<RUS97)I9CL*("`@(&9O
M;G0M<VEZ93H@,3%P>#L*?0IA+G-M86QL:&5A9&5R.FAO=F5R('L*("`@(&-O
M;&]R.B`C,F8U8SDW.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S-A.35C8SL*
M("`@('1E>'0M9&5C;W)A=&EO;CH@;F]N93L*?0HN<VUA;&P@>PH@("`@8V]L
M;W(Z(",P,#`["GT*+F-O;G1R;VP@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@
M(V)A9#!E-SL*("`@(&)O<F1E<CH@;F]N93L*?0H*+F-O;G1R;VP@82!["B`@
M("!C;VQO<CH@(S`P,#L*?0HN8V]N=')O;"!A.FAO=F5R('L*("`@('1E>'0M
M9&5C;W)A=&EO;CH@=6YD97)L:6YE.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@
M=')A;G-P87)E;G0["GT*"B\J($9O<FT@<W1Y;&5S+B`J+PII;G!U="P@<V5L
M96-T+"!T97AT87)E82!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U
M;F0M8V]L;W(Z("-F,V8S9CD["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C,#`U
M,SDV.PI]"FEN<'5T.F9O8W5S+"!T97AT87)E83IF;V-U<R!["B`@("!B86-K
M9W)O=6YD+6-O;&]R.B`C9F9F.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(S`P
M8C%B,#L*?0HN8G5T=&]N+"`N8G5T=&]N.F9O8W5S('L*("`@(&)A8VMG<F]U
M;F0M8V]L;W(Z(",S83DU8V,["B`@("!C;VQO<CH@(V9F9CL*("`@(&)O<F1E
M<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,#`U,SDV.PH@("`@8F]R9&5R+7)I9VAT
M.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@
M(S`P8C%B,#L*("`@(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C,#!B,6(P.PH@
M("`@+6UO>BUB;W)D97(M<F%D:75S.B`U<'@["GT*+F)U='1O;CIH;W9E<B![
M"B`@("!B86-K9W)O=6YD+6-O;&]R.B`C,F8U8SDW.PI]"@IA+F9I>&5D('L*
M("`@(&-O;&]R.B`C,S,Y.PI]"@HN<VEG;F%T=7)E+"`N<VEG;F%T=7)E(&$@
M>PH@("`@8V]L;W(Z(",Y.3D["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N
M=2!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C,F8U8SDW.PH@("`@8F]R9&5R
M+6)O='1O;3H@;F]N93L*("`@(&)A8VMG<F]U;F0M<F5P96%T.B!R97!E870M
M>#L*("`@(&)A8VMG<F]U;F0M:6UA9V4Z('5R;"AG<F%P:&EC<R]M96YU7W1O
M<"YP;F<I.PH@("`@8F%C:V=R;W5N9"UP;W-I=&EO;CH@8F]T=&]M.PH@("`@
M<&%D9&EN9SH@,'!X.PH@("`@8V]L;W(Z("-B860P93<["GT*(VUE;G4@82![
M"B`@("!C;VQO<CH@(V)A9#!E-SL*?0HC;65N=2!A.FAO=F5R('L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z(",S83DU8V,["GT*(VUE;G4@82YC=7)R96YT('L*
M("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",S83DU8V,["B`@("!B;W)D97(M8F]T
M=&]M.B`Q<'@@<V]L:60@(V%A8SL*("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O
M;&ED("-A86,["B`@("!B;W)D97(M;&5F=#H@,7!X('-O;&ED(",P,#`["B`@
M("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(S`P,#L*?0H*+RH@4VED96)A<B!S
M='EL97,N("HO"BYS:61E8F%R('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C
M,61C960["B`@("!B86-K9W)O=6YD+6EM86=E.B!N;VYE.PH@("`@<&%D9&EN
M9SH@,'!X.PH@("`@;6%R9VEN.B`P<'@["GT*+G-I9&5B87(@(VUE;G4@>PH@
M("`@:&5I9VAT.B`W,7!X.PH@("`@8F%C:V=R;W5N9"UI;6%G93H@=7)L*&=R
M87!H:6-S+VQE9G1?;65N=5]T;W`N<&YG*3L*("`@(&)A8VMG<F]U;F0M<&]S
M:71I;VXZ(&)O='1O;2!R:6=H=#L*("`@(&)A8VMG<F]U;F0M<F5P96%T.B!N
M;RUR97!E870["B`@("!M87)G:6XM8F]T=&]M.B`P<'@["GT*(W-I9&5B87)0
M86YE;"!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C8V%E.&4X.PH@("`@8F]R
M9&5R.B!N;VYE.PH@("`@8F%C:V=R;W5N9"UI;6%G93H@=7)L*&=R87!H:6-S
M+VQE9G1?;65N=5]B;W1T;VTN<&YG*3L*("`@(&)A8VMG<F]U;F0M<&]S:71I
M;VXZ(&)O='1O;2!R:6=H=#L*("`@(&)A8VMG<F]U;F0M<F5P96%T.B!N;RUR
M97!E870["B`@("!P861D:6YG+6)O='1O;3H@,C!P>#L*("`@('!A9&1I;F<M
M=&]P.B`P<'@["GT*(W-I9&5B87)086YE;"!A('L*("`@(&-O;&]R.B`C,F8U
M8SDW.PH@("`@8F]R9&5R.B!N;VYE.PH@("`@<&%D9&EN9SH@,'!X(#%P>"`R
M<'@@,7!X.PI]"B-S:61E8F%R4&%N96P@83IH;W9E<B!["B`@("!B86-K9W)O
M=6YD+6-O;&]R.B`C,V$Y-6-C.PH@("`@8V]L;W(Z("-B860P93<["B`@("!T
M97AT+61E8V]R871I;VXZ(&YO;F4["B`@("!B;W)D97(Z(&YO;F4["GT*(V5X
M<&%N9$)U='1O;B!["B`@("!M87)G:6XM<FEG:'0Z(#9P>#L*?0H*+RH@5&%B
M('-T>6QE<RX@*B\*+G1A8G-E="!["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@
M<V]L:60@(S`P-3,Y-CL*?0HN=&%B<V5T(&QI(&$@>PH@("`@8F]R9&5R.B`Q
M<'@@<V]L:60@(S`P-3,Y-CL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI
M9"`C,#!B,6(P.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V,Q9&-E9#L*?0HN
M=&%B<V5T(&QI(&$Z:&]V97(@>PH@("`@8V]L;W(Z("-B860P93<["B`@("!B
M86-K9W)O=6YD+6-O;&]R.B`C,V$Y-6-C.PI]"BYT86)S970@;&DN86-T:79E
M5&%B(&$@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD+6-O;&]R
M.B`C,F8U8SDW.PI]"BYT86)S970@;&D@82YA8W1I=F5486(Z:&]V97(@>PH@
M("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C,V$Y-6-C
M.PI]"@HO*B!!;'1E<FYA=&EN9R!S='EL97,N("HO"BYR;W=%=F5N+"`N:71E
M;3`@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V-A93AE.#L*?0HN<F]W3V1D
M+"`N:71E;3$@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@=')A;G-P87)E;G0[
M"GT*"BYI=&5M('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z('1R86YS<&%R96YT
M.PI]"@HO*B!0<F5F97)E;F-E<R!O=F5R=FEE=RX@*B\*+G!R969S3W9E<G9I
M97<@:#(@>PH@("`@9F]N="US:7IE.B`Q-'!X.PH@("`@9F]N="UW96EG:'0Z
M(&)O;&0["GT*+G!R969S3W9E<G9I97<@9'0@82!["B`@("!B;W)D97(Z(#%P
M>"!S;VQI9"`C,#!B,6(P.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED
M(",P,#4S.38["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C,V$Y-6-C.PH@("`@
M8V]L;W(Z("-B860P93<["GT*"BYP<F5F<T]V97)V:65W(&1D('L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z("-C864X93@["B`@("!B;W)D97(M;&5F=#H@,7!X
M('-O;&ED(",P,&(Q8C`["B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C
M,#!B,6(P.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",P,&(Q8C`[
M"GT*"BYP<F5F<T]V97)V:65W(&1T(&$Z:&]V97(@>PH@(&-O;&]R.B`C,F8U
M8SDW.PI]"@HN8F]X('L*("`@("UM;WHM8F]R9&5R+7)A9&EU<SH@,3!P>#L*
M("`@(&)O<F1E<CH@,7!X(&1A<VAE9"`C,#!B,6(P.PH@("`@8F%C:V=R;W5N
M9"UC;VQO<CH@(V-A93AE.#L*?0H*=&0N;&EN9612;W<L('1R+FQI;F5D4F]W
M('1D+"!T86)L92YL:6YE9%)O=R!T9"P@=&%B;&4N;&EN9612;W<@+FET96TL
M('1A8FQE+FQI;F5D4F]W('1H('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C
M:V=R;W5N9"UC;VQO<CH@(V-A93AE.#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P
M>"!S;VQI9"`C8S%D8V5D.PI]"BYL:6YE9%)O=U-E;&5C=&5D0V]L+"!T9"YL
M:6YE9%)O=U-E;&5C=&5D0V]L+"!T86)L92YL:6YE9%)O=R!T9"YL:6YE9%)O
M=U-E;&5C=&5D0V]L('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N
M9"UC;VQO<CH@(V,Q9&-E9#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI
M9"`C8V%E.&4X.PI]"@IT:"!["B`@("!B86-K9W)O=6YD+6-O;&]R.B!T<F%N
M<W!A<F5N=#L*?0IS<&%N('-T<F]N9R!["B`@("!C;VQO<CH@(S)F-6,Y-SL*
M?0H*```````````````````````````````````````````````````N+W5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]I935M86,N8W-S````````
M````````````````````````````````````````````````````````````
M````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`U,S0`,3`U
M,34T,S,W-S0`,#(Q,#(U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R("``8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,#``,#`P,#`P,```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]I935M
M86,N8W-S+'8@,2XR+C0N,R`R,#`U+S$P+S$X(#$Q.C,T.C$P(&IA;B!%>'`@
M)`H@*@H@*B!#4U,@8V]R<F5C=&EO;G,@9F]R($E%-2]-86,N"B`J+PH*(VUE
M;G4@;&D@>PH@("`@=VED=&@Z(#0P<'@["GT*+G1A8G-E="!["B`@("!W:&ET
M92US<&%C93H@;F]W<F%P.PI]"BYT86)S970@;&D@82!["B`@("!F;&]A=#H@
M;&5F=#L*?0HC<VED96)A<E!A;F5L('L*("`@('!A9&1I;F<M8F]T=&]M.B`S
M,'!X.PI]"BYH96%D97(@>PH@("`@8VQE87(Z(&YO;F4["GT*+FAE861E<B!U
M;"!["B`@("!W:61T:#H@,24["B`@("!W:&ET92US<&%C93H@;F]W<F%P.PI]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O:64V7V]R7VQE<W,N8W-S````````````````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S0S`#$P-3$U-#,S-S<T`#`R
M,C`W,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```O*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O:64V7V]R7VQE<W,N8W-S
M+'8@,2XQ+C(N,2`R,#`V+S`S+S(T(#`P.C0P.C,W(&-H=6-K($5X<"`D"B`J
M"B`J($-34R!C;W)R96-T:6]N<R!F;W(@244N"B`J+PH*+G1R9652;W<@>PH@
M("`@;W9E<F9L;W<Z('9I<VEB;&4["B`@("!H96EG:'0Z(#(P<'@["GT*"B-M
M96YU('L*("`@(&]V97)F;&]W.B!V:7-I8FQE.PH@("`@:&5I9VAT.B`U,'!X
M.PI]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+VMO;&%B+P``````````````````````````````````````````
M```````````````````````````````````````P,#`P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<V,0`P,C`R,S(`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O:V]L86(O9W)A<&AI8W,O````````
M````````````````````````````````````````````````````````````
M`#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S
M-S8Q`#`R,C`S,@`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]K;VQA
M8B]G<F%P:&EC<R]B9RYP;F<`````````````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`R,#<`,3`U,34T,S,W-C$`,#(S,3(W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````!
M`````P@"````W;_RU0````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``
M"Q(!TMU^_`````=T24U%!]0)$0L>*$UOWM8````4241!5'C:8[ARX003`P,#
MT[W[#P`=H`4.SG&U:@````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O:V]L86(O9W)A<&AI8W,O
M:V]L86(N<&YG````````````````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#$S,3<W`#$P
M-3$U-#,S-S8Q`#`R,S8T,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````C````"@(!@```"Q-
M$L8``!9&241!5'C:[9QY>%S5><9_=YFKV4?2C-;1OEFVA+'!V&8U!`P.`6/B
M&`PI@5+:!`QM@0)A"24EE"00*$UH$IH4TE"WK`Z0@,%F,9N-5[S)LB5+MK6O
MHUDT^[VW?PP>:30CVQ"30JKO>?P\]KUWSOG..>]]O_?[SKD6=%W7^3,P5=5H
M;Q]BTZ:#[-S9S;9M'?3U^1D8"-#?[R<:4[';C"B*A,ME9=JT?.KK"YDSIXRS
MSZ[%Y;(R94<WX<L&F*ZN$4*A*-75>6B:SN]>VL$?7FWBK;?VTMDY\IG:E&61
M!6?5<O75<_G&TEDHBCR%C"\[8'1=Y\[[7N.)7W^(INDLO706OWSLZRR^]%>L
M?6O?<>NGJM+)#[Y_(4N_?B*"($PAY,L*F.;]PUSZ[54IUYY\^$+V[.C@IK]_
MD1*WE<IR!WGY)FQ6!9M-013!YXOB\T7I[AFE_8"7OKX@JG;T(5]TX0R>^/EE
MY&2;IE#R90-,(!"A<RC"#0]O3KG^X'=.I,@69W];&W:;DAB0("#+,@:#`4F2
MDNRDJBK1:)2!P5&V?3S`V^]VL6E+'Y&H.FF_=34N5CU[#66E.5-(^3(`IK?/
MSUWWK280B/#?O_DF#_RNA^:^*`#%=HD'+G,S/-A'-!K%:K5B,IG(RLI"%,6,
MX437=>+Q.,%@$+_?3UM['_^Y<A>OO':`<"0S<*;7Y?'[%Z_%Y;1,H>6+"AA=
MUUGYW';N_<$:/",ARDNMK%IY)>Z2`G;TJ83C,+M0PJP(Z+K^F;6&KNL$@T&V
M?=S&/3]8QX[=PQF?._?L<E;^^DH,!L,48+YH@/'YP]SQCV_PPDN[,)L,7'U%
M'1>>5XPLBY25E9&7E_?Y].L+<-<_O<&SJYHSWG_T@05<>?EI_^^%\!<*,*WM
MPUQSPXNTM@W3.-W);2L:<.4:4!2%DI(2LK.SC[A@`X,A#ASRX?5%\(Q$L-L4
MG+E&ZJISL-N5H_:O:1IWW/<&OWUF1]J]:35VGGORZ^3GYT\!9CQ%WW+W^_C\
M"9T0C:KX1V-8K0JJJG'&O")67#<SK9&'?[:5->]TPH2UC,<T3$:)IQX_#Y?S
MR-G&QJU=7/?W+S,\'.*B\\NX=GDED@1Y>7FXW>ZD@!UOL9C*FG<Z>?GU`W0-
MAK#E&"FO=)#C-)*=8\3OBS(T&**]U4/4'^7,4PKYJV].QV:;'#SQN,:EW_H?
MMNWHG3!3\,3#IW'!>:>D^1*-JH3"\;2V1$$X8E]'LDU;>UF[KI.^_B#^3];C
M6&Q&?2ZWWGA2\M_OK^]F_::>8_JMH@@X[,9D;6K&M%QFG9"'*(XM;$J%JJ\_
M1&=`Y<[[ST)1I,/SA&P0>>7%%JSJ*!Z/AYR<L:SA%T_MIC,,CZU<G`*8T4",
MVV]XG1O_JAKT4<)A`:/1F-'1=1\>Y/K;7F4T&.,OEM6P["(WHBA245&1TM=A
M\_JB//[D;M9NZ..D,TI9LF(N3I?IJ'IET_INEJYXAZLNKN"J9763%O$>^<$B
M+KCLOU#55/+]:&L_\^:,X'0Z4Z[?\KT/\<149(.8O*;&=08[_*Q^]J)/!11_
M(,I-=[V/XC2S<%$E9[J/O0+=VQ-@[3.[\/E\6*U61%'DY[]I8MG?S,1@D`B%
M8H2"\6-J*QQ1^>V:0WSWAQNYZ\;9G'VZ.QTP&[;V,^WD$ORJ`4+C;H3@O0]Z
MN6F)PM#04'(1GWBZF;>;_5Q_VWQZ_6./!T=C_.B[:[ENL9V\G"!>KY?<W-S,
M8%E_B+^Y?371F,ZRB\M8=I$;69:IJ:G!8K%,"!DZ3SZSC]^\<I"%RQJX9=DL
M!$%`!?H#1R53*F:ZN:FQF%5/[V+?C[=P_^TG9WRRMBJ7"\^OXP]K]Z=<[^J/
MX/5ZTP#3WA?B_L?/3[G6ML_#6__]$?OV[:.ZNCHC0Z8SIL:UM[['N<M/H&%6
M(O1]&KW0O+^/LF*-]O9V9LY,1(*!H$9^5:*M3UL<F#&OG,57J?SHGG6XG$8:
MZYVI@-FX?8B",VKI\4]\/<'3YR7'483-9@/@V5?:>7F;CV^NF)<"EG`PQA/W
MO\UW+K$RH]:,P^&@LK(24133'-K7-LS?W;L658,%\_.Y?'$ILBQ35U>'R93*
M&/V#(:Z_9R/FVD*^=>]"1%$X!I!D!LX9EY[`:\_LXJEGF[GFLOJ,3RU?TL#J
M=PZD7!OTQ`D$`BF9F=<7)6XVT>U-_?U['PU07Y-%)!+)./9,]L/'MU-V:C7.
MJGQZ?9\AC&T9Y+ISK%@L%@1!X%!7`,7EH&="6YUM'D:&@BG7C&8#E=-<2/)$
M7R4N^>NY_/"G[_++'R](!<RN]E'ROFI+<];3'Z"B,-&0S6;C^5</\M@KO2R]
M83Y]@;$X%`G'>/[1=[GI$C,-M28<#@=55549)VQX),SU=ZTE'(,2MY7KEI<A
MB0+5U=5I8-G3ZN6:[VWAM.4GDU_B8&#TCQ=OLQ<U\/@C;[+PC%S<Q>E"=MY)
MQ5CM)L+CM$E<%XC'XVB:EF2,#=L&R:\II'O"G.W8,<3BRRQ8K=9CRJPV;!M@
M[;XH2Z^O2%M@'=#BVM@2RID!.-#KIS`O.\G,"=\*T@A@Y2\W<_$IJ6WT^^*\
M^!0LO^-<#%FI>VFZV4I_`#HZ.L8`$XMI=(;E%``<MIT;^SB_T8HLR[R_Q<L#
M+_2R\.KY](^./1L-QWGS5Q]PZQ(C#37&(X)%TW3N?60]/4,A)$7FVF^48,J2
M*"TMQ6I-C=E[VWQ<<<_'S+_J#+`JGY%5,C.-H[Z"5:OW\>VK<M)J+`99I*XZ
MEUW[AI+7G+E&)B:5'VP=P%9>D<8P86\`AS4W+:QFLF`HSJV/-#'OZM/2%G>X
MR\OF%S918HTB"+"CU\#E=RY,%^M1%;L4011)]KEIYS#FAFDI`(Q%XCA-,;ZZ
MH""I<PY;\5O#?+2AC^K9[I2V(\$8B@2CHZ-C@-F^=P0Q+S<C%;;O&V+V628V
M-T5XZ`\'F7O%//K&@46+:VQ_81.W+C'04&/$;K=/"A:`%U:WLFY3-Y(L,[O>
M2D.-%;O=CLOE2A6W_AA7_>-VJBZ9CT]7\/F/;XJH%.?1U':`P<%!BHJ*TN[G
M9)N1Y#$D.'/2,YXM+:,4S["G,$QD-$J10T,0.";`W//8+FQSI^.)&V!<.^%`
MA+95&WGX>@=VJ\205^/FE5+&-1HZY*6N/.&?V6Q.K.F!,.Y99H+CGA]H'V%Z
M918`-34U*=K*M:N=X78!\X3VVS9V<OYL<ZKHW;##@YCO2M$CA[,+NQ:@O=O$
M_2\)U%Y\2@JS:'&-0Z]OYLZOZ316&['9;$<$B]<?X6<K=R%]DH4M/L>%(`B4
ME)2D4??MC^Q"G]6(CZSC#A:`"`H15<#O]V<$C,EL2/H)4%5J1I;EY-A"8976
M@`'!G^KW4-L(YU89$00A+;Q.M+<V]/-RFT3->?EIH:CUI6W\Y"]LV*T2;K>;
MSA$5N5!->PZ@L\7#12>:,)E,R+),**S2'C(@38@8A_9Y6#HO\=QXL`1#<7[U
MAQY,Y\Q-:3_J#Q%LWL^Y?Y<(=4G`?+3;1ZBD/,V9J">`4X]S]_.0^Y53Z`])
M8QF4JN%Y;ROW7Z+26)6%S68[:D;P[\\U$PBI2+),>5$6E6XC.3DY:1.[M6F$
MW[4;R#\]AW"`S\4B@U%FFR5BL5C&^R/^&)*<F")!@!E59DPF4Q+8NUI]!&TY
M:?IEH'V$$Q9E8;%8CBAX/;XH-SW>COGT.6FLX6OIY/)9$4H*K.3EY5%86,CF
MY_<0S2[-R###/3ZF7:(DV657JX^0-3MM/?N[_3S]9IA5ZX>Q6C\>TZ^=48(U
MT[&$90A_,C]]'J2=VWGH6CNR)%!86#@&F,U=&L/9`@BIFW"1MB':^ZW8%YQ$
M7P!`32JQZ.8=/'!1C,8JY9C`,N*+\,JZ0TB&1+<G3T_HE4S5TW]YYA!J50U]
M(^KG5K6,'AJA_K2LC(L:5S4Z!D))7ZN*%1Q6*45CK=\Y0M":3??P!!\]?LH+
MY:.&H]O_=2^]);7(X^<5T*,QROO:N/0;5A1%P>U.:(K-^T,,%YL@PYP4B*-8
M3:8Q_=+D30#&D_JL>-),=F9RID$``7P>%;6C%[JZ65P?Y)H55BPF@8*"`AP.
M1P(PW0-A#NSWH.U_)ZT=2="1!`'O:^^GRT9-8]!O.2:P`+SV01=134@N0EV9
M$449>RN2]!A6>?6#`?SA_L^US.TP"\R^VI&QH'BP.T`PJB=]/6>.'8#L[.PQ
MP;O#2^"#_0GZ&6<G5XL89/L1`?/*>_W\YZL](*6/T2#JW'*+#4F$\O)R)$E"
M576V[/;BW?Q.QO;./C4AV@_W^5&3C\"'K9]M8C0-48!HG0F+6:*TQ$U>7E[B
MZ`C`ICU^=$$B4_)742RR]'2%AYX/IU>1))$?/Q]A[BP;=75'+TR]N:DW2?&B
M"$5.`PZ'(TV[[#T8Q!\A;2&.MUUZIA'%(&"WV]/NO;VE+^EKKEUB5HT1L]F<
M#)VJJK-Q;R`QD(DO:Y62LG@3K=\3Y?J']H*<^2AHM5NFJ4-C?Y_`UBX_X&?$
M'\<;UB>=DX:*Q/D?HS&1R6W<,PI"NF_UI1+&"=I]T*O3-:213``E$0UX[KT8
M5146OC\[+[E&,I`8N"&S\PV5,DM.4^@-V/CM6D\Z=0/7_'`_:Q\UTUCM.&*\
MWM\30ORD'U.6@&(0TM@%8#@01Y`_WW.U+KO`%>=D(4E2"FL<#D=K-O4G?!5@
M\>D69$D@/S\_.7'M/6%Z1K2,?C96)C9,,QV'T'6=F_ZEA<&`/ND8]_;"0R_&
M@!@P)N".-">-E3)FLQE1%.D=CM+>'T604U]B61+XZ0HS%J,PP2?XCS51_N.-
M]#VKQY[OY8IS3$RO+1T'F.;129UI*)<019%_O64Z;?U-?-B4KD"]$;CL^RV\
M]6@CA<[,^T5[._P(DL3A,1@4`5$@XZ0J!O%S!8PHP%W+%6PF@:*BHK10^L[6
M`0:\,61%IJI08E:5@M%H3-G>6-_DS^BC($!#F9BLMDZTE6\.\O)Z[W$=G\T$
M97GBF'YI#B!DF->J8@&+,9&1CM_>T'6=>RMC//GVQ^DZ#WAW:R_E;B=FLQDY
M$M/X^&!D4GJ<499@`5.6Q-/?F\99-S?1.9B>5;0/Z5SYSRW\_H'IF(WI;0V,
M1),4?YB9HG$RZI[:$A.2(J-JG\/V//"W7Q.95R=BM5HS"N[&*@=GSLYG:_,P
MEY]I1!"@K*PL!0`?[AG-.&>R!#]?`R93$$UH)1)+C>/O[_1-.M>?U::7"RDU
MG\TMF7V;62DDJ_7RA/N'!B;'0#@NX/%X$H#9?3#,:$Q$R%!NMIF@S*4E'2G*
M55AY=RWGW]62-A$`&UKCK/A9.[^ZN1I)2FUOV!]/"LCDM='$6=N)5IBK<.:L
M;-9M/[[%%U&$&\Z';YPJ8#`8J*RL3(*@N\?'`P^NX=`A#TN6S.1[5\]AW:86
MLI4`+I<KN8>6'.N^4$:6B`.O[3C\;D8S0O9XLV=CN9XJ>"?QK<ZM$X[+Q'0%
M7W!LWEN[(]SX;QV3^E60K1.-)L8B;VP)IL6ZY)M>K&.0M!3Q=DJ=A4>_4\:*
MGW=F_,VS&T+4/-?%79>G%N)D64P#3-L`S(U$,K9SWU4EG-?<<MQ8QF;4N>-K
M.@NFZQ@,!FIK:U$494Q7W+V&S=NZ$_M`CWU$84DN9\TKYM"A0Y24E*06YOQQ
M]O;&)]5]G]:,LL[=%ZL8)SD!VN<3>'CUY$E%0VD<13$@RS)Q56?K@2AD6-.'
M7X>?O`Z(>U*NQV+:&#U.L#(GU!3$DXPD;VJ-3#KP&27QC&K_ZG-SV-D1X1>O
M>S+ONK[DI[IHD.4+QHY3NK*S$`VI#NWJ@4!@E$R'V.;56WCP+TNXXZF>/SH&
MG5JM<?/Y&H4.';/93%55%5E966.UIJA&5U2A<$;%V(9G5X@+3*:,Y8(->T/'
ME27^<D&,LZ?K6*W6C"G^JDU1!#ES<5$2H+XXGMSDW-T19C0N(AC2(\9D%2W!
MD!F,LJAS\Z+$'M;A3%+^J"TZN>`MB6$P&-*$J2`(/'A5(7NZX[R[)Y2>"0`K
MGO107I#%J?6)CDKRC$@3$-P?@"VM?BHJM(S%LQLO<N&R2]SR9`^^T*=+L04!
M9I:H?&M^C#D56K)`Z':[T_I2#"*G+JBGO7^,[6;-+$*6Y;18#["^)3PI*W]:
MJW1J+)L3QV`P4%U=G;&_EC=Z$61OQM^7Y&K83?J8X&T]/KXY+3K_<%Z8.14:
M5JMU##"W+7'B'?$RXDW_S'16B8K%XLBH]A59X#<W%;/R[2Z\WLR#V=9TD)FE
M55@L%FK=9NPVA=%P:HQYO5GGM)G#N`M=&=M8?E8.<ZMT'GVIA]6[97I\PA&S
MG_)<C?F5<1;6QZC*TQ!(O!UNMSMC"M_4$433=>Y<7LFS'T<8"NG,*9;XR@SC
MY"%$D5ATD@6__X_;LS`K.E\_,8)!@I*2DHQ@`3`;12Z894*(IY_KJ"]0$<9'
M`0$6S;;B#WQZ_:=(.@Z33D.1RAE5,<S*&",?QH"@Z[H^,#"`WY^Y@YR<G(S'
M)),TIZH<.'`@*5X%04@!F*(HE):6(@@"/WNMEW>;TC="&MTB=RZMQ&"8_,T(
MA\-T='73=-!'2[^()RCBCP@891VSHE-DUZARJN18=`02V5=N;BXNERME_R=9
MS-1U7MTZPLKWAS`;!.Z_+)]"I_68OPKP>#RTM[<?%Y:QV^U45U<?^8#[P``=
M'1WC!+R8\O?&QL;DM6`P2'-S\V>/XD(B,\[)R<'E<J7T]2?]:J!C*,IW5W:2
MZ4O5TVK-?'MA/HI\Y--IL5@,G\_'Z.@HD4@$5571=1U)DE`4!=,G^RF3U4$`
MNCTQ?OW6($U=(6Q9`A?/B%)L#F#Z1+.,US=3-@%,?^K/3)Y^W\/JG9G9;%IA
M%G]]3BZ%V9_/!V.>497??^SC[=U^HBK4NC065OC)$J-8+!:JJJJ2F=.4?4$`
M$XWK//C[0=H&,JM^1198=(*5"QHM6(WB']V?INOL[X_QWKX@'[8$B:E@-FB<
M4SY*E3V``!04%%!<7'S,9V^G`/,G-G]8XR=OC-#AF?R3AQ/="C=^Q9'R3<RQ
M6CBF<7!89>O!"%L.AO$$$T);%G1F.OW,RO-CE#2,1B/EY>5IQT*G[`L&&(!0
M5./?W_.PLS<=$#EF@?N^YN"5EW?RSS]:@R`(W';K5_CFY;/9WA4E%@=SEH`D
M0"2N,QK1\89U^GPJ!X?B]/A4QIV91A$UICG\G)CKPVJ((TD2A86%Y.?G3['*
MEP4P`/%XG#4[!EE[0&$T/I92?G6ZPOQ"E067/DTTELB^)$E@S3-7LL=OY*5=
MD6-JWV&(,LWF8YK=AU%2$461_/Q\\O/SISZL_XSV?_I_<\FRS*+9!<PL'F!=
MBX^]/AM#41,Y%IF#?7YRJTM3GC_0%R([SY*VQ3#>;'(4MS%`C<5'7E8(@<2.
M>'Y^(2Z7:]):QY1]"0!S..=W%^:SS!FCM[>7MKX^'+J3ZFHG-2=6,1K1/BF6
M"9PXS<D['2#+$I*@(0LZ#CE,KB%,KB%$GB&$PQ#YA)$D'(Y<G$XG-IMMZK\?
M^W,(29E,554"@0!VNYU.C\K;K5$$X.P:A7R+RO;=^XBI&K*0^'/8)$E*UF`<
M#L=1#V!/V9\)8(YD(R,CA$*A)$`D2<)@,)"5E87!8)@"R)_`_A<P-:]U^LRB
M80````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````N+W5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]K;VQA8B]G<F%P:&EC<R]K;VQA
M8FQO9V\N<&YG````````````````````````````````````````````````
M````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#4W-S(`,3`U,34T
M,S,W-C$`,#(T-3(T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R("``8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,#``,#`P,#`P,```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````W````*`@&````6EMB"```
M``9B2T=$````````^4.[?P````EP2%ES```+$P``"Q,!`)J<&`````=T24U%
M!]0+!`\>'0'21N0```N'241!5'C:O9E[D-35E<<_OV>_NZ<?T_1,][QZ'@Q@
M@(DD($J0K*A!8T0400LA)AM75[/9W3)N6&/(1M?:*M=LJDQMK5F+9&/(HA41
M-4*$J.2AFQ#>`_(<F!EFAGD/W3W3W;_NW^^W?PPTM-T##LQXJOJ?>V_?>[Z_
M<\[WG'.O8)JFR:<@NFYP\F0_.W>V<N!`)WOVM-/=':>W-T%/3QPMH^-V65%5
MB4#`R=2I01H;0\R94\F--]83"#C'?:8PT>`Z.H9()C5J:TLQ#)/7-^_GUV\?
MXMUWCW#Z]-`5[2G+(@N_4,_JU9_G[F6S457YTP5GFB;?6;>%%U_Z`,,P6;9T
M-O_UH[NX8^E_L_W=HQ/V\:(U?I[^_A*6W34+01`^'7"'3PRP]*%->6/KGUO"
M1_O;>>Q;KQ$).ZFI\E`:M.%RJKA<*J((L9A&+*;1V37,R5-GZ>X>03<NK]+M
M2Z;SXG\NQUMBFUQPB42:T_UI'GGN+WGCS_[-+,I<64ZTM.!VJ:,'"@*R+*,H
M"I(DY:RNZSJ:IM';-\R>O;V\][L.=N[J)JWI8Y[;4!=@TRMKJ*SP3CRX,]UQ
MUJ[;2B*1YI<_NY]G7N_B<+<&0+E;XIGE80;ZNM$T#:?3B<UFPV*Q((IB49<R
M39-L-LO(R`CQ>)R6D]W\SX9FWMQRBE2Z.,AI#:6\]=J#!/R.B0%GFB8;7MW'
M4T]O8W`H256%DTT;[B,<F<+^;IU4%II"$G95P#3-R\;&I<X9&1EAS]X6GGQZ
M!_L/#A1=]U<W5K'AI?M0%.7JP,7B*9[XWCO\:G,S=IO"ZI4-++FI'%D6J:RL
MI+2T=%)222R68.V_O,,KFPX7G?_A,PNY[][Y>1]R7.".GQQ@S2.O<;QE@&NF
M^7G\;V<0\"FHJDHD$J&DI.225NKM2W*J+<;96)K!H31NEXK?9Z6AUHO;K5[V
M?,,P>&+=._Q\X_Z"N:EU;EY=?Q?!8'#\X/Z\NX.O?^L-!@:2W'YS)0^NJ$&2
MH+2TE'`XG".'BR63T=GV_FG>^,TI.OJ2N+Q6JFH\>/U62KQ6XC&-_KXD)X\/
MHL4U%GPNQ-?NGX;+-3;0;-9@Z0/_RY[]9SX68/#B<_.YY:;/Y73)@3,,`U$4
MBVZXXX-6'G[\;89',JR\LYI[;@\CBB+5U=5XO85,=3:F\>/U!]G^?]U\]H8*
M;EH2Q1^P73:^=G[8R>9?'&35EZM9=4_#F&N/M0QPR_)?H.OY=EFSO)IO?N-Z
M_'[_!7#GC5?,I79\V,8W'M^"INDLN[6<E5^I0)9EZNKJ<#@<'W,;D_4;C_*S
M-UM9?,\,FN:6CYM,#,-DT\O-A`6-'WS[VC'7/;KV-_QZ^XE\8KF^E+6/74LT
M&AVM;')6+:+$T98!_NZI[>@&+)P7Y-X[1H$U-#1@L^5;HJ<OR<-/_AE[?8@'
MGEJ,*`KT)*Z$.@1N6/H9MFQLYJ>O'&;-\L:BJU;<.8.M[Y_*&^L;S))()'(,
M+8]%U0-#*1Y>NYU4!B)A)U]?48DD"M36UA8`^^CX6=9\=Q?S5UQ+,.*A=_CJ
MV;'IUAG\^/G?LO@&'^'R8,'\W,^6XW3;2*6R%^+1%,AFLQB&@21)R,6`&8;)
M4\]_2%=_$DF5>?#N"#:+1$5%!4YG?G5^I"7&RB?W,F_5#>!4K]!:Q2WH::QF
MT]:C/+3*6Y##%%FDH=9'\]'^W)C?9^5B?BQ:7O]JZW%V[.Q$DF6:&IW,J'/B
M=KL)!`+YQ!'/L.I[^XA^91XQ4R46G]C<II:7<JCE%'U]?925E17,>TOL2/+9
M"^"\^2Q;`.YL/,T+&YJ1U%$ZO6-1`$$0B$0B!>[[[>>;,6=?0PS+A`,#2*.2
MU@7B\7A1<#:[DM,3(%IA1Y;E'.L7@/O)JX=))'4D6::JS$)-V(K7ZRV(L]V'
MAGC]I$+P>B^I!),BZ3Z-)KM$)I,I.C\4SR#)\CE"A.E1.S:;+6>$/'!#L31O
M[FA#4D:'KYTV&E\79_WS\A\;V]"C=70/Z9/6O6MM0S3.MQ3-OUG=H+TWF=,U
M6J[B<4IYG)`';LL?.]`,(?>'ADHKJJIBM]OS-AY)Z;S]QU[BJ9Y)O9KPV`6:
M5GNP6JT%<ZV="48T,Z?KHCEN`$I*2HJ#^^W.,SDSBR*4^14\'D]!K!UI'2&>
M/N<+DRA+%UA1%0&WVUTP]]ZN[IRN/K?$[#HK=KL]%SZF:5X`-QC3.-&51#SW
M)6P6`541"JP&,)#((LCRI`(+N`56+K(@25*>-<Z[Y+:=/:.Z"G#']0YD22`8
M#.89(J?AD?8X@B0AGR,?1140!0KR"X"JB),*3A1@[0H5ETV@K*RLH"A_?W<O
MO6<SR*I,-"0Q.ZIBM5KQ^7S%4T'OD)8S,T`6T+(4K?;K(S8D548W)AZ8`'SS
M-I&Y#2).I[,HF5T3];"@*<CNPP/<N\"*($!E965^+R<(%\`-Q+.YX,R-#8_>
M;7Q<0CZ5!;-+V+%O8I.;*,(C-\/=UPDHBD)-34U.X<ZN&,\\NXVVMD'NO',F
MWUT]AQT[CU&B)@@$`KA<KL(KP5PYHX@%X%IZX?/I=%%%UJV*<-/A8Q-F/9?5
MY(G;3!9.,U$4A?KZ>E15S9'#8_^\C;_LZ01@_X_^1"CBXPMSRVEK:R,2B12T
M3WF6"_FMB$J^"S9W02(Q3!'/8&ZC@V>_&N&)GW9=M1]>5VOP]S<;A#PF=KN=
M:#2*Q6*YD,PU@PY-)32]^D*QWI'D%IN-VMK:HJ&39[F*4BN2G+^H)P&[CL>I
MKB[>R#YZ>X"`6^(?UG<12XXO+0@"S(SH/#`OPYQJ(U<LA,/A@K-41>2ZA8V<
M[+G@1;-GEB'+,G(18COORKE./),U^-H+1QE.Y?N9UV[R_>53"(<"8RK:<GJ`
M'V[N8NM!F:Z8<$D6K/(9S*O)LK@Q0[340`#<;C?A<+AHVCG4/H)AF@2]%E[9
MFZ8_:3*G7.)+TZV(XB>X<3[OHR]L.</O#L4*V2DL\IUE-2B*-.9&J52*]HY.
M#K7&.-8C,C@B$D\+6&43NVI2YC:(^G6\#A.!41;V^7P$`H&\>C#7=IDF;^\>
M8L,?^K$K`C]8'B3D=XZKL\^[(&KOU_BG#:<I=IL]O][.0XN#J+)XR0TSF0RQ
M6(SAX6'2Z32ZKF.:)I(DH:HJ-IL-A\.!P^$84]'.P0POO=O'H8XD+HO`EZ=K
ME-L3V,[%V,7Q.*ZW@I?_,,C6`\4I?FK(PE\O\A$J428E>0\.Z[RU-\9[!^-H
M.M0'#!97Q[&(&@Z'@V@TFF/0*P*G94V>?:N/EM[B;88J"]SZ&2>W7./`:16O
M&I!AFISHR?#[HR-\<&R$C`YVQ6!1U3!1=P(!F#)E"N7EY6/>SHWK(22>,OCW
M=X9H'\R.^<=9895'O^BY;%`7C<^,0>N`SN[6-+M:4PR.C)*8+)C,],>971K'
M*AE8K5:JJJH*KC:N"AQ`4C/XR>\'.7"F4'FO76#=;1[>?.,`__IOVQ`$@<?_
M\8O<?V\3^SHT,EFP6P0D`=)9D^&TR=F427=,I[4_2U=,)WL1*:NBP51/G%F^
M&$XEBR1)A$(A@L'@N*WUB=\*LMDLV_;WL?V4RG#V0C[YTC25>2&=A4M?1LN,
MEF>2)+!MXWU\%+>RN3G]R?HU16.J*\94=PRKI".*(L%@D&`P6+1@'Z]<LK27
M99E;FZ8PL[R7'<=B'(FYZ-=L>!TRK=UQ?+45>>M/=2<I*744E'%Y99:L$;8F
MJ'/$*+4D$1CM/(+!$(%`H&A2GA1PY[-].!3D'G^&,V?.T-+=C<?T4UOKIVY6
ME.'TJ']958%94_V\WPZR+"$)!K)@XI%3^)04/B5)J9+$HZ3/65K"X_'A]_MQ
MN5Q7_,QUQ6Y93'1=)Y%(X':[.3VH\]YQ#0&XL4XEZ-#9=_`H&=U`%D9_YT62
MI%R.\W@\.!R.JXJG20%W*1D:&B*93.;`2)*$HBA8+!8419ET,!^7_P>Z%W#$
M/NA#=0````!)14Y$KD)@@@```````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+VMO;&%B+VEN9F\N<&AP````````````````````````````
M```````````````````````````````````````````P,#`P-C0T`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#,S-0`Q,#4Q-30S,S<V,0`P,C$V-S<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J($MO;&%B('1H96UE(&)Y(%-T=6%R="!":6YG92`\<RYB:6YG94!C
M;V1E9G5S:6]N+F-O+GIA/@H@*B!$97)I=F5D(&9R;VT@=&AE("=,:6=H="!"
M;'5E)R!T:&5M92X*("H*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O:V]L86(O
M:6YF;RYP:'`L=B`Q+C$@,C`P-"\Q,"\Q-R`Q.3HS,SHS-B!M9&IU:VEC($5X
M<"`D"B`J+PH*)'1H96UE7VYA;64@/2!?*")+;VQA8B(I.PH`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]K
M;VQA8B]S8W)E96XN8W-S````````````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`P,#,P,#4`,3`U,34T,S,W-C$`,#(R,C(Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"\J*@H@*B!+;VQA8B!T:&5M
M92!B>2!3='5A<G0@0FEN9V4@/'-K8FEN9V5`9VUA:6PN8V]M/@H@*B!$97)I
M=F5D(&9R;VT@=&AE("=,:6=H="!";'5E)R!T:&5M92X*("H*("H@)$AO<F1E
M.B!H;W)D92]T:&5M97,O:V]L86(O<V-R965N+F-S<RQV(#$N,3`N-BXR(#(P
M,#8O,#,O,3`@,#`Z,3(Z-30@:F%N($5X<"`D"B`J+PH*8F]D>2!["B`@("!B
M86-K9W)O=6YD.B`C935E-64U.PI]"F$@>PH@("`@8V]L;W(Z(",S,SD["GT*
M+FQI9VAT('L*("`@(&-O;&]R.B`C,#`P.PI]"B-T:&5M96QO9V\@>PH@("`@
M8F%C:V=R;W5N9"UI;6%G93H@=7)L*"=G<F%P:&EC<R]K;VQA8FQO9V\N<&YG
M)RD["B`@("!B86-K9W)O=6YD+7!O<VET:6]N.B!C96YT97(["B`@("!B86-K
M9W)O=6YD+7)E<&5A=#H@;F\M<F5P96%T.PH@("`@:&5I9VAT.B`U,'!X.PH@
M("`@=VED=&@Z(#$P,'!X.PI]"BYH96%D97(@>PH@("`@8F%C:V=R;W5N9#H@
M(V1D9CL*("`@(&)O<F1E<BUB;W1T;VTZ("XQ96T@<V]L:60@(S`P8SL*?0HN
M<VUA;&QH96%D97(@>PH@("`@8V]L;W(Z(",P,#`["B`@("!B86-K9W)O=6YD
M.B`C9&1F.PI]"BYS;6%L;&AE861E<B!A+"`N<VUA;&QH96%D97(@83IH;W9E
M<BP@82YS;6%L;&AE861E<CIH;W9E<B!["B`@("!C;VQO<CH@(S`P,#L*?0HN
M8G5T=&]N('L*("`@(&)A8VMG<F]U;F0Z(",P,&,["B`@("!C;VQO<CH@(V9F
M9CL*("`@(&9O;G0M=V5I9VAT.B!B;VQD.PH@("`@+6UO>BUB;W)D97(M<F%D
M:75S.B`U<'@["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@("!B
M86-K9W)O=6YD.B`C9F9F.PH@("`@8F]R9&5R+71O<#H@-7!X('-O;&ED(",P
M,&,["B`@("!B;W)D97(M8F]T=&]M.B`S<'@@<V]L:60@(SAB9CL*("`@(&-O
M;&]R.B`C,#`P.PI]"B-M96YU(&$@>PH@("`@8V]L;W(Z(",P,#`["GT*(VUE
M;G4@83IH;W9E<B!["B`@("!B;W)D97(Z(&YO;F4["B`@("!P861D:6YG.B`S
M<'@["B`@("!B86-K9W)O=6YD.B`C8V-F.PH@("`@8V]L;W(Z(",P,&,["GT*
M(VUE;G4@82YC=7)R96YT('L*("`@(&)A8VMG<F]U;F0Z("-D9&8["B`@("!B
M;W)D97(Z(&YO;F4["B`@("!P861D:6YG.B`S<'@["GT*"B\J(%-I9&5B87(@
M<W1Y;&5S+B`J+PHC<VED96)A<E!A;F5L('L*("`@(&)A8VMG<F]U;F0Z('=H
M:71E.PH@("`@8F]R9&5R+6)O='1O;3H@+C)E;2!S;VQI9"`C.&)F.PH@("`@
M8F]R9&5R+7)I9VAT.B`N,F5M('-O;&ED(",X8F8["GT*(W-I9&5B87)086YE
M;"!A('L*("`@('!A9&1I;F<M;&5F=#H@,7!X.PH@("`@<&%D9&EN9RUB;W1T
M;VTZ(#)P>#L*?0HC<VED96)A<E!A;F5L(&$Z:&]V97(@>PH@("`@8V]L;W(Z
M(",P,#`["B`@("!B86-K9W)O=6YD.B`C8V-F.PI]"B-E>'!A;F1"=71T;VX@
M>PH@("`@;6%R9VEN+7)I9VAT.B`N,F5M.PI]"@HO*B!486(@<W1Y;&5S+B`J
M+PHN=&%B<V5T(&QI+F%C=&EV951A8B!A+"`N=&%B<V5T(&QI+F%C=&EV951A
M8B!A.FAO=F5R('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9#H@
M(V1D9CL*("`@(&)O<F1E<BUB;W1T;VTM8V]L;W(Z("-D9&8["GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;&%V86YD
M97(O````````````````````````````````````````````````````````
M`````````````````````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P
M,#`P,#`P`#$P-3$U-#,S-S8Q`#`R,#<S-@`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<B`@
M`&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`P`#`P,#`P,#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]L879A;F1E<B]I;F9O+G!H<```````````````````````
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`Q-S8`,3`U,34T,S,W-C$`,#(R-#`V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]L879A;F1E<B]I;F9O+G!H
M<"QV(#$N,2`R,#`T+S$P+S$W(#$Y.C,S.C,V(&UD:G5K:6,@17AP("0*("HO
M"@HD=&AE;65?;F%M92`](%\H(DQA=F5N9&5R(BD["@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M;&%V86YD97(O<V-R965N+F-S<P``````````````````````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`R,3<P`#$P-3$U-#,S-S8Q`#`R,C<R-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````O*BH*("H@)$AO<F1E.B!H
M;W)D92]T:&5M97,O;&%V86YD97(O<V-R965N+F-S<RQV(#$N.2XT+C,@,C`P
M-2\Q,"\Q."`Q,3HS-#HQ.2!J86X@17AP("0*("HO"@IB;V1Y('L*("`@(&)A
M8VMG<F]U;F0Z("-E964["B`@("!S8W)O;&QB87(M8F%S92UC;VQO<CH@(V8T
M935F-SL*?0IH=&UL('L*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C9C1E
M-68W.PI]"F$@>PH@("`@8V]L;W(Z(",W,3!F.38["GT*82YW:61G970@>PH@
M("`@8V]L;W(Z(",W-#)A.#(["GT*82YW:61G970Z:&]V97(@>PH@("`@8V]L
M;W(Z("-F9F8["B`@("!B86-K9W)O=6YD.B`C-S0R83@R.PI]"BYH96%D97(@
M>PH@("`@8F%C:V=R;W5N9#H@(V4Q8S)E-SL*("`@(&9O;G0M<VEZ93H@,3)P
M>#L*?0IA+FAE861E<B!["B`@("!B86-K9W)O=6YD+6EM86=E.B!N;VYE.PH@
M("`@8F%C:V=R;W5N9"UC;VQO<CH@=')A;G-P87)E;G0["GT*+FQI9VAT('L*
M("`@(&-O;&]R.B`C-F4T93<R.PI]"BYS;6%L;&AE861E<B!["B`@("!C;VQO
M<CH@(V5E93L*("`@(&)A8VMG<F]U;F0Z("-E,6,R93<["GT*+F-O;G1R;VP@
M>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V5C8V%F,CL*?0HN:71E;2!["B`@
M("!B86-K9W)O=6YD+6-O;&]R.B`C9C9E-V8X.PI]"BYB=71T;VX@>PH@("`@
M8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C.6$W.&$P.PH@
M("`@8F]R9&5R.B`Q<'@@<V]L:60@(S`P,#L*("`@('!A9&1I;F<Z(#`@,G!X
M.PI]"BYB=71T;VXZ:&]V97(@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S9D
M,&%A,#L*?0HN<V5L96-T960@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V,V
M83%C9#L*?0IS96QE8W0@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V4P8S-E
M-3L*("`@(&-O;&]R.B`C,#`P.PI]"@HO*B!-96YU('-T>6QE<RX@*B\*(VUE
M;G4@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C
M9C1E-68W.PI]"B-M96YU(&$@>PH@("`@8V]L;W(Z(",P,#`["GT*(VUE;G4@
M82YC=7)R96YT('L*("`@(&)A8VMG<F]U;F0Z("-E,6,R93<["GT*(VUE;G4@
M:#$@>PH@("`@8V]L;W(Z(",P,#`["GT*"B\J(%-I9&5B87(@<W1Y;&5S+B`J
M+PHC<VED96)A<E!A;F5L('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-E964[
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]L:6=H=&)L=64O````````````````
M````````````````````````````````````````````````````````````
M,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W
M-S0`,#(Q,3(U`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VQI9VAT
M8FQU92]G<F%P:&EC<R\`````````````````````````````````````````
M```````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#4Q-30S,S<W-``P,C(W,C4`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O;&EG:'1B;'5E+V=R87!H:6-S+VUE;G4N<&YG````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,38T`#$P-3$U-#,S-S<T`#`R-#0P,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````0P```!0!`P```.R/$G\````&4$Q416NEWG.M[\2S
M<UX````)<$A9<P```$@```!(`$;):SX````4241!5`C78V#``OY#P0,DUB!7
M!P`>T5AQKDZ&B0````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+VQI9VAT8FQU92]I;F9O+G!H<```````````````````````````````````
M```````````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#(P,0`Q,#4Q-30S,S<W-``P,C(U-C(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J("1(
M;W)D93H@:&]R9&4O=&AE;65S+VQI9VAT8FQU92]I;F9O+G!H<"QV(#$N,2`R
M,#`T+S$P+S$W(#$Y.C,S.C,V(&UD:G5K:6,@17AP("0*("HO"@HD=&AE;65?
M;F%M92`](%\H(DQI9VAT($)L=64B*3L*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]L:6=H=&)L=64O
M<V-R965N+F-S<P``````````````````````````````````````````````
M````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#$Q
M-#``,3`U,34T,S,W-S0`,#(S,3$R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R("``8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,#``,#`P,#`P,```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE
M<R]L:6=H=&)L=64O<V-R965N+F-S<RQV(#$N."XV+C$@,C`P-2\Q,"\Q."`Q
M,3HS-#HQ.2!J86X@17AP("0*("HO"@IB;V1Y('L*("`@(&)A8VMG<F]U;F0Z
M("-B,&0P9C$["GT*82!["B`@("!C;VQO<CH@(S,S.3L*?0HN:&5A9&5R('L*
M("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(S9B835D93L*?0HN
M<VUA;&QH96%D97(@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD
M.B`C-F)A-61E.PI]"BYB=71T;VX@>PH@("`@8F%C:V=R;W5N9"UI;6%G93H@
M=7)L*&=R87!H:6-S+VUE;G4N<&YG*3L*?0H*+RH@365N=2!S='EL97,N("HO
M"B-M96YU('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9"UC;VQO
M<CH@(S9B835D93L*("`@(&)A8VMG<F]U;F0M:6UA9V4Z('5R;"AG<F%P:&EC
M<R]M96YU+G!N9RD["GT*(VUE;G4@82YC=7)R96YT('L*("`@(&)A8VMG<F]U
M;F0Z("-B,&0P9C$["GT*"B\J(%-I9&5B87(@<W1Y;&5S+B`J+PHC<VED96)A
M<E!A;F5L('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-B,&0P9C$["GT*(W-I
M9&5B87)086YE;"!A.FAO=F5R('L*("`@(&-O;&]R.B!Y96QL;W<["GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]L=6,O
M````````````````````````````````````````````````````````````
M````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`P,#``,3`U,34T,S,W-S,`,#$W-S,P`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+VQU8R]G<F%P:&EC<R\`````````````````````````
M```````````````````````````````````````````````P,#`P-S4U`#`P
M,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<W,P`P,C$U,S``
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(@(`!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M,``P,#`P,#`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;'5C+V=R87!H:6-S+V-U
M<G)E;G1486)?;&5F="YG:68`````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P-3,W`#$P
M-3$U-#,S-S<S`#`R-3,T-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!'248X.6$)`)8`Q```____=V95_O[^_?W\^OKX^?GW
M_?W]_/SZ^?CV^/?U]?3O]O7Q]/+M\O'K]O7P]_;RN[.JW=G5Z>;C]?3S@7%A
MF(M_X=W9F(M^NK&GDX5XX=[9Q\"X\O'JKJ2:DX5WQK^X(?D$```````L````
M``D`E@``!=P@(&I8106!^&50-(G`UDFP:'ET#6"0+EX1'X#R\J6$1X!@N0PP
M#8:!-!`='`B$0B$@O2(2B4<`6T`\'`K&N)Q`-QKKKX/1X(RSB45:?2T_]`H!
M!WU?"PM<5ED(7U115UE;4%6#!TY+DE,B3$Q).ITUGS"A(J,`I:="IJFH2*NN
MK;!&K[*QGK.VM:"WNKFBN[Z]I+_"P:K%K+3)N,J\S,#.Q-#&TLC+ULW7S]G1
MV]/=U=CAVN+<Y-[FX./JY>OG[>GL\>[R\//V]?C#]_KYQ_S__@)2`SA0X#>"
MW4(``#L`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+VQU8R]G<F%P:&EC<R]C=7)R96YT5&%B7W)I
M9VAT+F=I9@`````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,C0Q,P`Q,#4Q-30S,S<W,P`P
M,C4U,C4`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````1TE&.#EAD`&6`,0``/____[^_OW]_/3R[?GY]_+QZG=F5?+QZ_KZ^/?V
M\O;U\?CW]=C2R*^DEY&#=.7AU>CFVN_MYOGX]NKHWNWJXO7T[^?CV/;U\/W]
M_?'PZ?S\^O#NY^OIW\"XKH!P7\O#MB'Y!```````+`````"0`98```7_H"&.
M9&F>:*JN;.N^<"S/=&W?>*[OK^<T#X!P2"P:C\BD<LEL.I_0J'1*K5JOV*QV
M^PP()!1&P]$)<,_HM'K-;KO?<*Y74HE`Q)VX?L_O^_^`@41S=1P0'PX,@HN,
MC8Z/D&N$$880#0V1F9J;G)U_DX86B)ZDI::GJ$F@$'<>J:^PL;*?7X40%A8&
M`;N\O;Z_P,'"P\3%QL?(R<K+S,W.S]#1TM/4Q1@:$@.4$`\/!@+@X>+CY.7F
MY^CIZNOL[>[O\/'R\_3U]O?X^>H:!`G:$]R\$1A(L*#!@P@3*ES(L*'#AQ`C
M2IQ(L:+%BQ@S:MS(T>&""P4HW.IF((')DRA3_ZI<R;*ERY<P8\J<2;.FS9LX
M<^K<R;.GSY\P%5PXL,%0-V\#DBI=RK2ITZ=0HTJ=2K6JU:M8LVK=RK6KUZ]@
MPXJ=>H`H!8!'#118R[:MV[=PX\J=2[>NW;MX\^K=R[>OW[^``PL>3-ANA@AG
M`WHKS+BQX\>0(TN>3+DRX0P;$(?"9:"LY\^@0XL>3;JTZ=.H4ZM>S;JUZ]>P
M8\N>3;NV[=0%#E.H!,'`V-_`@PL?3KRX\>/(?Q_036&W`070HTN?3KVZ]>O8
MLVO?SKV[]^_@PXL?3[Z\^?/HTVN_<*'"@-R9(QA80+^^_?OX\^O?S[^___\`
M!BC@@`06:."!"":HX/^"##;XGTGM#>"9`1U5:.&%&&:HX88<=NAAA1(LD`!T
M[!F`P(DHIJCBBBRVZ.*+,,8HXXPTUFCCC3CFJ...//;HXX]`TCB0!$1*\(T^
M2":IY)),-NGDDU!&B:0&5**H2S589JGEEEQVZ>678(:))09DEFG`+&BFJ>::
M9YS)YIMPQBGG$&[.:>>=>)929YY\]NDG('O^*>B@A+99Z*&()AI%H(HVZFBB
MC#XJZ:1\1DKII9BR:6FFG'::RJ:>ABJJ)J".:NJI@92*ZJJLOJ%JJ[#&NL6K
MLM9JZZ*WYJIK%;3NZNNNO?XJ;*W!#FLLJ\4>J^RHR2[K+*?-/BOMI-%.:ZW_
MHM5>JRVAV6[K;9_=?BNNG>&.:^Z;Y9ZK+IKIKNON*^V^*Z^>\]:;9[SVY@L)
MOOKVNPB__@;L!\`"%QP'P08GS`;""C=LJ,,0DQKQQ/M2;#$C#%^L,1,9;^SQ
M$1U_++(0(8_\<<DF;XQRRA>OS#+%+K\<<<PR.TQSS0K?C+/!.N\L<,\^^PMT
MT/H.3;2]1A\];])*O\MTT^L^#?6Y4D\];M56?XMUUMMNS?6U7G\];=AB/TMV
MV<N>C?:Q:J\];-MN_PIWW,#2O?/<=M^*=][$\BWSWG[#"GC@R!*>\N"&GXIX
MXLPR+O+BCGL*>>304JZRY1I/CCFEFF\N:>>>.PIZB.C8DCZSZ1"/CGJAJJ\^
M:.NN_PE[[.#2SK/M!<^.^YVZ[SYG[[['"7SPZ!)?M/'Y#H]\FLHO/TOSSL<"
M??3P4N^T]>Y.C[TIVF]/2O?>=P)^^)N,3WXFYI]?L?K>IL]^(^Z__Z_\VL9/
M/Z#W6VM__GWLS_\>_OO?P03HK``2T`T&/.#"%,BV$```.P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;'5C
M+V=R87!H:6-S+W1A8E]B;W1T;VTN9VEF````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`P,C`Q`#$P-3$U-#,S-S<S`#`R-#,T,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!'248X.6$4``$`A"``W>/5V^'3
M_O[^\O3NYNG@VN#2_/S\]??R^?GWZNWDX.36Y>C>[O'J[?#I[_+KXN7:^/CV
M]_?U\_7PZ>SC^OKX^_O[Z^[G=V95X^;;Y.?=_?W][._HX>39\?/NX./8Z.OB
M+``````4``$```4&X"6.9%F&`#L`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VQU8R]G<F%P:&EC<R]T
M86)?;&5F="YG:68`````````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#4V-``Q
M,#4Q-30S,S<W,P`P,C0P,#0`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````1TE&.#EA"0"6`,0``+>NB._MY>#<S.SJX/'OZ>?D
MV-?2O-70NMO6Q/W]_?3S[>CEV_;U\OCW]/'OZ.OHWMS8QNWKXMG5P?#NY^[L
MX_KY]^/?T-C3O\6^G\?`H]_;R[RTD.[LY.7BU.SIX-/.MR'Y!```````+```
M```)`)8```7Q8"(^1K8!@`AAB->("?0Y<%4]&&TW#'-(.X9BF%E4>`J"8[)1
M()4<"H`G)`0HD6E/,:$,/("M-?)XA*ODQ2*<##P*'0M@.!D4+`+-W,%Y=#00
M$@`$$Q$+%H$7@P$#"P(0%P:+=@((!I)6E):8C`65EY.>FZ&?G)J@F:*HG:6D
MHZFML*^LLZ>FJK>QM*NVKKRXOKFUP+*_NKW%PL;#Q\2[RM#!TLG3S]7(UM3:
MV=S8WL[?S>+,Y,OFT=OAY>C=X.[CY]?OZ_+P[.KQZ?/Y[?;U]/K\!038CR"^
M>_L0"BS([^"_A@D?*C08<2#$A0XM3KP4`@`[````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````N+W5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]L=6,O9W)A<&AI8W,O=&%B7W)I9VAT+F=I
M9@``````````````````````````````````````````````````````,#`P
M,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(V-#8`,3`U,34T,S,W-S,`
M,#(T,3<R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R("``8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,#``,#`P,#`P,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````$=)1C@Y89`!E@#$``#5T+JWKHC2S+79U,'BWM#IYMO]_?S>VLG6T;O7
MTKWS\NSKZ-[LZN#W]O/P[N?N[./GY-CZ^OC)PJ;4S[C-QZW0RK++Q*G`N)?E
MXM3<V,;8T[_/R;#.R*[*PZ?\_/OO[>4A^00``````"P`````D`&6```%_V`@
MCF1IGFBJKFSKOG`LSW1MWWBN[[`D0(:@<$@L&H_(I'+);#J?T*AT2JU:K]BL
M]NF)*`B""R`8*9O/Z+1ZS6Z[W_"X?$ZOV^_XO'[/[_OC#0H."P<2"`8-B8J+
MC(V.CY"1DI.4E9:7F)F:FYR=GI^@H:*5"@H,$`0#%QBEK:ZOL+&RL[2UMK>X
MN;J[O+V^O\#!PL/$Q;D.#PL8!QD=%`[0T=+3U-76U]C9VMO<W=[?X.'BX^3E
MYN?HZ=L?R:C,80_Q\O/T]?;W^/GZ^_S]_O\``PH<2+"@P8,($RKLMZ#`L@P#
M$`1@0+&BQ8L8,VK<R+&CQX\@0XH<2;*DR9,H4_^J7,FRY<<%"R`\'*`A`,R;
M.'/JW,FSI\^?0(,*'4JTJ-&C2),J7<JTJ=.G0PNXRZ`A08`"6+-JW<JUJ]>O
M8,.*'4NVK-FS:-.J7<NVK=NW<..2E4D`8@*)$/+JW<NWK]^_@`,+'DRXL.'#
MB!,K7LRXL>/'D"-++HR!`+.[$P(0V,RYL^?/H$.+'DVZM.G3J%.K7LVZM>O7
ML&/+GDT;-3,-``0("'"@M^_?P(,+'TZ\N/'CR),K7\Z\N?/GT*-+GTZ]NG7D
M&2!JF%"APH8``\*+'T^^O/GSZ-.K7\^^O?OW\./+GT^_OOW[^//K;Z\!`7<.
M%%`00`($%FC@@0@FJ.#_@@PVZ."#$$8HX8045FCAA1AFJ.&&'';X(`+^";`!
M!19T$`"(**:HXHHLMNCBBS#&*..,--9HXXTXYJCCCCSVZ../0,X(P`0"5`!@
M!R8"H.223#;IY)-01BGEE%16:>656&:IY99<=NGEEV"&*>:854Y`9`4D=B!!
M`&2VZ>:;<,8IYYQTUFDGF686F>::=_;IYY^`!BKHH(0RF2>:)?)9Z**,-NKH
MHY#&>>B>;$9JZ:689JJIH),F6NFFH(8JZJBD0MFIFI^6JNJJK+8*Z*F*NBKK
MK+36NB6LJ=JJZZZ\RHIKK\`&*^RFOPYK[+'(!EILLLPVZ^R8RSXK[;342AEM
M_[789OOLM=IVZVVPW'XK[KB^GDDIN>BFRVJXZK;K+J3LOBOOO,J:ZRF]^.;[
MJKVHZNOOOW+&"_#`!&,I<,$()^SDP0HWC####D?\+\025TPOQ19GW"[&&G<\
M+L<>AZPMR"*7/"W))J?,+,HJMSPLRR['S"O,,M=,*\TVY[PNO['J[//+/.?Z
M\]"[XDSTT9<:C?32CBK-]-.$.@WUU']*3?75=5J-]=9P:LWUU]`&#?;838M-
M]ME1FXWVVE6KS?;;6;L-]]Q=RTWWW6'K>2_>?.>-:+]]!_ZEUX*_37CA:Q^.
M^-F*+SYVXXY_#7GD6T].^=667SYUYIH_S7GG2W\.^O_1HH\^=.FF^XQZZCFO
MSGK-KK\><^RRMTQ[[2G?CGO)NN\><N^^=PQ\\!D/3WS%QA\?<?+*-\Q\\PD_
M#WW!TD\_</763VQW]F1CSWV^WG]_\?;B<QU^^>^>C_[&Y*]/M?KNHPM__!^W
M3S_3\]_O;?[ZCVQ__T3C'P"K)<`!GNQ_!M19`1/HK`4R<&4(?*#,'"C!8U&P
M@D#3&^`P>+H(<C!W'OP@[T(HPM^1L(3".R$*BZ?"%2*OA2Y<'@QCZ+P9TC!Z
M-KPA]7*HP^OQL(?:TV#/@"BR"Q)Q548\8JF2J,11,;&)H7HB%(GUPRFFKXI6
M9)\0A99%ATFQBY;Z(ACAA<4C,=9OBV:4F!C3R*@ULK%0;GSCH.(HQWJAL8X/
M*R,>"1BT$```.P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VQU
M8R]I;F9O+G!H<```````````````````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,#$V-P`Q,#4Q-30S,S<W,P`P,C$T,#``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D
M93H@:&]R9&4O=&AE;65S+VQU8R]I;F9O+G!H<"QV(#$N,2`R,#`T+S$P+S$W
M(#$Y.C,S.C,V(&UD:G5K:6,@17AP("0*("HO"@HD=&AE;65?;F%M92`](%\H
M(DQO>6]L82(I.PH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````N
M+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]L=6,O<V-R965N+F-S
M<P``````````````````````````````````````````````````````````
M````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#<V-C(`
M,3`U,34T,S,W-S,`,#(Q-S,T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R("``8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,#``,#`P,#`P,```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]L
M=6,O<V-R965N+F-S<RQV(#$N,3`N-BXX(#(P,#4O,3$O,#(@,3DZ,S(Z-#@@
M:F%N($5X<"`D"B`J+PH*8F]D>2!["B`@("!B86-K9W)O=6YD.B`C9F9F.PH@
M("`@9F]N="UF86UI;'DZ(%9E<F1A;F$L($=E;F5V82P@07)I86PL($AE;'9E
M=&EC82P@<V%N<RUS97)I9CL*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C
M8S1C-&(X.PH@("`@<V-R;VQL8F%R+6AI9VAL:6=H="UC;VQO<CH@(V4V939D
M8SL*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@(S`P,#L*?0IH=&UL('L*
M("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C8S1C-&(X.PH@("`@<V-R;VQL
M8F%R+6AI9VAL:6=H="UC;VQO<CH@(V4V939D8SL*("`@('-C<F]L;&)A<BUA
M<G)O=RUC;VQO<CH@(S`P,#L*?0HN<V5L96-T960@>PH@("`@8F%C:V=R;W5N
M9#H@(V,V9#-F9CL*?0IA+"!A+F9I>&5D('L*("`@(&-O;&]R.B`C,S,Y.PI]
M"F$N=VED9V5T('L*("`@(&-O;&]R.B`C,#`P.PI]"BYH96%D97(@>PH@("`@
M8V]L;W(Z("-F.3`["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V8Y
M,#L*?0HN:&5A9&5R8F]X('L*("`@(&)O<F1E<BUC;VQO<CH@(V8Y,#L*?0HN
M:&5A9&5R8F]X("YH96%D97(@>PH@("`@;6%R9VEN+6QE9G0Z("TQ<'@["B`@
M("!M87)G:6XM<FEG:'0Z("TQ<'@["B`@("!B;W)D97(M;&5F=#H@;F]N93L*
M("`@(&)O<F1E<BUR:6=H=#H@;F]N93L*?0IA+FAE861E<CIH;W9E<B!["B`@
M("!C;VQO<CH@(V9C,#L*?0IA+FAE861E<B!["B`@("!B;W)D97(M8F]T=&]M
M.B!N;VYE.PH@("`@8F%C:V=R;W5N9#H@=')A;G-P87)E;G0["GT*+FQI9VAT
M('L*("`@(&-O;&]R.B`C,S,S.PI]"BYS;6%L;&AE861E<B!["B`@("!C;VQO
M<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0Z('1R86YS<&%R96YT.PH@("`@9F]N
M="UF86UI;'DZ(%9E<F1A;F$L2&5L=F5T:6-A+'-A;G,M<V5R:68["B`@("!F
M;VYT+7-I>F4Z(#$Q<'@["B`@("!F;VYT+7=E:6=H=#H@;F]R;6%L.PI]"F$N
M<VUA;&QH96%D97(L("YS;6%L;&AE861E<B!A('L*("`@(&-O;&]R.B`C9CDP
M.PI]"F$N<VUA;&QH96%D97(Z:&]V97(L("YS;6%L;&AE861E<B!A.FAO=F5R
M('L*("`@(&-O;&]R.B`C9F,P.PI]"BYC;VYT<F]L('L*("`@(&)A8VMG<F]U
M;F0Z("-D.&0X8S$["GT*+FET96T@>PH@("`@8F%C:V=R;W5N9#H@(V5E965E
M-CL*?0H*+RH@1F]R;2!S='EL97,N("HO"FEN<'5T('L*("`@(&9O;G0M9F%M
M:6QY.B!697)D86YA+"!'96YE=F$L($%R:6%L+"!(96QV971I8V$L('-A;G,M
M<V5R:68["B`@("!B86-K9W)O=6YD.B`C9C=F-V5E.PH@("`@8F]R9&5R.B`Q
M<'@@<V]L:60@(S8V-CL*?0IT97AT87)E82!["B`@("!C;VQO<CH@(S,S,SL*
M("`@(&)A8VMG<F]U;F0Z("-F-V8W964["B`@("!B;W)D97(Z(#%P>"!S;VQI
M9"`C-C8V.PI]"FEN<'5T.F9O8W5S+"!T97AT87)E83IF;V-U<R!["B`@("!B
M86-K9W)O=6YD.B`C9F9F.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(V8Y,#L*
M?0IS96QE8W0L;W!T:6]N('L*("`@(&-O;&]R.B`C,S,S.PH@("`@8F%C:V=R
M;W5N9#H@(V8W9C=E93L*?0HN8G5T=&]N('L*("`@(&-O;&]R.B`C,S,S.PH@
M("`@8F%C:V=R;W5N9#H@(V8Y9CEF.#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P
M>"!S;VQI9"`C,#`P.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(S`P
M,#L*("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(V,T8S1B.#L*("`@(&)O
M<F1E<BUT;W`Z(#%P>"!S;VQI9"`C8S1C-&(X.PH@("`@+6UO>BUB;W)D97(M
M<F%D:75S.B`U<'@["GT*+F)U='1O;CIH;W9E<B!["B`@("!C;VQO<CH@(V8Y
M,#L*?0H*+RH@06QT97)N871I;F<@<W1Y;&5S+B!I=&5M,"P@:71E;3$@87)E
M(&1E<')E8V%T960N("HO"BYR;W=%=F5N+"`N:71E;3`@>PH@("`@8F%C:V=R
M;W5N9#H@(V5E93L*?0HN<F]W3V1D+"`N:71E;3$@>PH@("`@8F%C:V=R;W5N
M9#H@(V9F9CL*?0H*+RH@365N=2!S='EL97,N("HO"B-M96YU('L*("`@(&-O
M;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(V4V939D8SL*("`@(&)O<F1E
M<BUB;W1T;VTZ(#)P>"!S;VQI9"`C.#`X,#=!.PI]"B-M96YU(&@Q('L*("`@
M(&-O;&]R.B`C,#`P.PI]"B-M96YU(&$@>PH@("`@8V]L;W(Z(",P,#`["B`@
M("!B;W)D97(Z(&YO;F4["GT*(VUE;G4@83IH;W9E<B!["B`@("!C;VQO<CH@
M(S`P,#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C9F9F.PH@("`@
M8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(V9F9CL*("`@(&)O<F1E<BUL969T
M.B`Q<'@@<V]L:60@(S<V-3L*("`@(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C
M-S8U.PH@("`@<&%D9&EN9SH@,G!X.PI]"B-M96YU(&$N8W5R<F5N="!["B`@
M("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z("-C,&,P8C@["B`@("!B
M;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V9F9CL*("`@(&)O<F1E<BUR:6=H
M=#H@,7!X('-O;&ED("-F9F8["B`@("!B;W)D97(M;&5F=#H@,7!X('-O;&ED
M(",W-C4["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(S<V-3L*("`@('!A
M9&1I;F<Z(#)P>#L*?0H*+RH@4VED96)A<B!S='EL97,N("HO"B-S:61E8F%R
M4&%N96P@>PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(V4Y93EE.3L*
M("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C93EE.64Y.PH@("`@8F%C
M:V=R;W5N9#H@(V8V9C9F-CL*?0HC<VED96)A<E!A;F5L('-P86XN=&]G9VQE
M+"`C<VED96)A<E!A;F5L(&$@>PH@("`@<&%D9&EN9RUL969T.B`Q<'@["B`@
M("!P861D:6YG+6)O='1O;3H@,G!X.PI]"B-S:61E8F%R4&%N96P@<W!A;BYT
M;V=G;&4@>PH@("`@8F]R9&5R.B`Q<'@@;F]N92!T<F%N<W!A<F5N=#L*?0HC
M<VED96)A<E!A;F5L(&$@>PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(V8V9C9F
M-CL*?0HC<VED96)A<E!A;F5L(&$Z:&]V97(@>PH@("`@8V]L;W(Z(",P,#`[
M"B`@("!B86-K9W)O=6YD.B`C93EE.64Y.PH@("`@8F]R9&5R.B`Q<'@@<V]L
M:60@(S`P,#L*("`@('1E>'0M9&5C;W)A=&EO;CH@;F]N93L*?0HC97AP86YD
M0G5T=&]N('L*("`@(&UA<F=I;BUR:6=H=#H@,7!X.PI]"@HO*B!486(@<W1Y
M;&5S+B`J+PHN=&%B<V5T('L*("`@(&)A8VMG<F]U;F0Z("-F9F8@=7)L*")G
M<F%P:&EC<R]T86)?8F]T=&]M+F=I9B(I(')E<&5A="UX(&)O='1O;3L*("`@
M(&9O;G0M<VEZ93H@,3%P>#L*?0HN=&%B<V5T(&QI('L*("`@(&UA<F=I;CH@
M,#L*("`@(&)A8VMG<F]U;F0Z('5R;"@B9W)A<&AI8W,O=&%B7W)I9VAT+F=I
M9B(I(&YO+7)E<&5A="!R:6=H="!T;W`["GT*+G1A8G-E="!L:2!A+"`N=&%B
M<V5T(&QI(&$Z:&]V97(@>PH@("`@8F%C:V=R;W5N9#H@=7)L*")G<F%P:&EC
M<R]T86)?;&5F="YG:68B*2!N;RUR97!E870@;&5F="!T;W`["B`@("!M87)G
M:6XZ(#`["B`@("!P861D:6YG.B`S<'@@,35P>#L*("`@(&-O;&]R.B`C-S8U
M.PH@("`@8F]R9&5R.B!N;VYE.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O
M;&ED(",W-C4["GT*+G1A8G-E="!L:2!A.FAO=F5R('L*("`@(&-O;&]R.B`C
M,S,S.PH@("`@8F%C:V=R;W5N9#H@=7)L*")G<F%P:&EC<R]T86)?;&5F="YG
M:68B*2!N;RUR97!E870@;&5F="!T;W`["GT*+G1A8G-E="!L:2YA8W1I=F54
M86(@>PH@("`@8F%C:V=R;W5N9#H@=7)L*")G<F%P:&EC<R]C=7)R96YT5&%B
M7W)I9VAT+F=I9B(I(&YO+7)E<&5A="!R:6=H="!T;W`["GT*+G1A8G-E="!L
M:2YA8W1I=F5486(@82!["B`@("!C;VQO<CH@(S,S,SL*("`@(&)A8VMG<F]U
M;F0Z('5R;"@B9W)A<&AI8W,O8W5R<F5N=%1A8E]L969T+F=I9B(I(&YO+7)E
M<&5A="!L969T('1O<#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C
M9F9F.PI]"BYT86)S970@;&DN86-T:79E5&%B(&$Z:&]V97(@>PH@("`@8V]L
M;W(Z(",Y.3D["B`@("!B86-K9W)O=6YD.B!U<FPH(F=R87!H:6-S+V-U<G)E
M;G1486)?;&5F="YG:68B*2!N;RUR97!E870@;&5F="!T;W`["B`@("!B;W)D
M97(M8F]T=&]M.B`Q<'@@<V]L:60@(V9F9CL*?0H`````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]L=6-B;'5E+P``````````````````````````````````````````
M````````````````````````````````````,#`P,#<U-0`P,#(S-#(W`#`P
M,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-S,`,#(P-C`P`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R("``8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,#``,#`P,#`P
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"XO=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+VQU8V)L=64O:6YF;RYP:'``````````
M```````````````````````````````````````````````````````````P
M,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#(P,``Q,#4Q-30S,S<W
M,P`P,C(R,S0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(@(`!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P,``P,#`P,#`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+VQU8V)L
M=64O:6YF;RYP:'`L=B`Q+C$@,C`P-"\Q,"\Q-R`Q.3HS,SHS-B!M9&IU:VEC
M($5X<"`D"B`J+PH*)'1H96UE7VYA;64@/2!?*"),;WEO;&$@0FQU92(I.PH`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]L=6-B;'5E+W-C<F5E;BYC<W,`````````````````````
M````````````````````````````````````````````,#`P,#8T-``P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#4S,3,`,3`U,34T,S,W-S,`,#(R-3<S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"\J*@H@
M*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]L=6-B;'5E+W-C<F5E;BYC<W,L=B`Q
M+C$P+C8N-"`R,#`U+S$P+S$X(#$Q.C,T.C(P(&IA;B!%>'`@)`H@*B\*"F)O
M9'D@>PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*("`@(&9O;G0M9F%M:6QY.B!6
M97)D86YA+"!'96YE=F$L($%R:6%L+"!(96QV971I8V$L('-A;G,M<V5R:68[
M"B`@("!S8W)O;&QB87(M8F%S92UC;VQO<CH@(T,T0S1".#L*("`@('-C<F]L
M;&)A<BUH:6=H;&EG:'0M8V]L;W(Z("-E-F4V1$,["B`@("!S8W)O;&QB87(M
M87)R;W<M8V]L;W(Z(",P,#`["GT*:'1M;"!["B`@("!S8W)O;&QB87(M8F%S
M92UC;VQO<CH@(T,T0S1".#L*("`@('-C<F]L;&)A<BUH:6=H;&EG:'0M8V]L
M;W(Z("-E-F4V1$,["B`@("!S8W)O;&QB87(M87)R;W<M8V]L;W(Z(",P,#`[
M"GT*82!["B`@("!C;VQO<CH@(S`S0SL*?0IA+"!A+F9I>&5D('L*("`@(&-O
M;&]R.B`C,S,Y.PI]"F$N=VED9V5T('L*("`@(&-O;&]R.B`C,#`P.PI]"FEN
M<'5T('L*("`@(&9O;G0M9F%M:6QY.B!697)D86YA+"!'96YE=F$L($%R:6%L
M+"!(96QV971I8V$L('-A;G,M<V5R:68["B`@("!B86-K9W)O=6YD.B`C9C=F
M-V5E.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(S8V-CL*?0IT97AT87)E82![
M"B`@("!C;VQO<CH@(S,S,SL*("`@(&)A8VMG<F]U;F0Z("-F-V8W964["B`@
M("!B;W)D97(Z(#%P>"!S;VQI9"`C-C8V.PI]"G-E;&5C="QO<'1I;VX@>PH@
M("`@8V]L;W(Z(",S,S,S,S,["B`@("!B86-K9W)O=6YD.B`C9C=F-V5E.PI]
M"BYH96%D97(@>PH@("`@8V]L;W(Z(",P,V,["B`@("!B;W)D97(M8F]T=&]M
M.B`Q<'@@<V]L:60@(S`S8SL*?0HN:&5A9&5R8F]X('L*("`@(&)O<F1E<BUC
M;VQO<CH@(S`S8SL*?0HN:&5A9&5R8F]X("YH96%D97(@>PH@("`@;6%R9VEN
M+6QE9G0Z("TQ<'@["B`@("!M87)G:6XM<FEG:'0Z("TQ<'@["B`@("!B;W)D
M97(M;&5F=#H@;F]N93L*("`@(&)O<F1E<BUR:6=H=#H@;F]N93L*?0IA+FAE
M861E<CIH;W9E<B!["B`@("!C;VQO<CH@(S`V9CL*?0IA+G-M86QL:&5A9&5R
M.FAO=F5R('L*("`@(&-O;&]R.B`C,#9F.PI]"F$N:&5A9&5R('L*("`@(&)O
M<F1E<BUB;W1T;VTZ(&YO;F4["B`@("!B86-K9W)O=6YD.B!T<F%N<W!A<F5N
M=#L*?0HN;&EG:'0@>PH@("`@8V]L;W(Z(",S,S,["GT*+G-M86QL:&5A9&5R
M('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9#H@=')A;G-P87)E
M;G0["GT*+G-M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C,#`P.PH@("`@9F]N
M="UF86UI;'DZ(%9E<F1A;F$L2&5L=F5T:6-A+'-A;G,M<V5R:68["B`@("!F
M;VYT+7-I>F4Z(#$Q<'@["B`@("!F;VYT+7=E:6=H=#H@;F]R;6%L.PI]"BYC
M;VYT<F]L('L*("`@(&)A8VMG<F]U;F0Z("-$.$0X0S$["GT*+FET96T@>PH@
M("`@8F%C:V=R;W5N9#H@(V5E965E-CL*?0HO*B!!;'1E<FYA=&EN9R!S='EL
M97,N(&ET96TP+"!I=&5M,2!A<F4@9&5P<F5C871E9"X@*B\*+G)O=T5V96XL
M("YI=&5M,"!["B`@("!B86-K9W)O=6YD.B`C9CEF.68Y.PI]"BYR;W=/9&0L
M("YI=&5M,2!["B`@("!B86-K9W)O=6YD.B`C93EE.64Y.PI]"BYB=71T;VX@
M>PH@("`@8V]L;W(Z(",S,S,["B`@("!B86-K9W)O=6YD.B`C9CEF.68X.PH@
M("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",P,#`["B`@("!B;W)D97(M
M<FEG:'0Z(#%P>"!S;VQI9"`C,#`P.PH@("`@8F]R9&5R+6QE9G0Z(#%P>"!S
M;VQI9"`C0S1#-$(X.PH@("`@8F]R9&5R+71O<#H@,7!X('-O;&ED("-#-$,T
M0C@["B`@("`M;6]Z+6)O<F1E<BUR861I=7,Z(#5P>#L*?0HN<V5L96-T960@
M>PH@("`@8F%C:V=R;W5N9#H@(T,V1#-F9CL*?0HN:6Y0<F]G<F5S<R!["B`@
M("!B86-K9W)O=6YD.B`C,#`S,V-C.PI]"@HO*B!-96YU('-T>6QE<RX@*B\*
M(VUE;G4@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD.B`C939E
M-F1C.PH@("`@8F]R9&5R+6)O='1O;3H@,G!X('-O;&ED(",X,#@P-T$["GT*
M(VUE;G4@:#$@>PH@("`@8V]L;W(Z(",P,#`["GT*(VUE;G4@82!["B`@("!C
M;VQO<CH@(S`P,#L*("`@(&)O<F1E<CH@;F]N93L*?0HC;65N=2!A+F-U<G)E
M;G0@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD.B`C8S!C,&(X
M.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED("-E964["B`@("!B;W)D
M97(M<FEG:'0Z(#%P>"!S;VQI9"`C965E.PH@("`@8F]R9&5R+6QE9G0Z(#%P
M>"!S;VQI9"`C,#`P.PH@("`@8F]R9&5R+71O<#H@,7!X('-O;&ED(",P,#`[
M"B`@("!P861D:6YG.B`R<'@["B`@("`M;6]Z+6)O<F1E<BUR861I=7,Z(#5P
M>#L*?0H*+RH@4VED96)A<B!S='EL97,N("HO"F)O9'DN<VED96)A<B!["B`@
M("!B86-K9W)O=6YD.B`C9CEF.68S.PI]"B-S:61E8F%R4&%N96P@>PH@("`@
M8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(S@P.#`W83L*("`@(&)O<F1E<BUB
M;W1T;VTZ(#%P>"!S;VQI9"`C.#`X,#=A.PH@("`@8F%C:V=R;W5N9#H@(V4V
M939D8SL*?0HC<VED96)A<E!A;F5L(&$@>PH@("`@8F]R9&5R.B`Q<'@@<V]L
M:60@(V4V939D8SL*("`@('!A9&1I;F<M;&5F=#H@,7!X.PH@("`@<&%D9&EN
M9RUB;W1T;VTZ(#)P>#L*?0HC<VED96)A<E!A;F5L(&$Z:&]V97(@>PH@("`@
M8F%C:V=R;W5N9#H@(V4V939D8SL*("`@(&)O<F1E<CH@,7!X('-O;&ED(",P
M,V,["B`@("!T97AT+61E8V]R871I;VXZ(&YO;F4["B`@("`M;6]Z+6)O<F1E
M<BUR861I=7,Z(#-P>#L*?0HC97AP86YD0G5T=&]N('L*("`@(&UA<F=I;BUR
M:6=H=#H@,7!X.PI]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VUO8FEL
M92\`````````````````````````````````````````````````````````
M```````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P,#`P,``Q,#4Q-30S,S<W-``P,C`T,34`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O;6]B:6QE+W-C<F5E;BYC<W,`````````````````````
M`````````````````````````````````````````````#`P,#`V-#0`,#`R
M,S0R-P`P,#`W-C0Q`#`P,#`P,#`Q,S8S`#$P-3$U-#,S-S<T`#`R,C0Q,0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<B`@`&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`P
M`#`P,#`P,#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````O*BH*
M("H@)$AO<F1E.B!H;W)D92]T:&5M97,O;6]B:6QE+W-C<F5E;BYC<W,L=B`Q
M+C$N,3`N,2`R,#`U+S$P+S$X(#$Q.C,T.C(P(&IA;B!%>'`@)`H@*B\*"F)O
M9'D@>PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*("`@(&9O;G0M9F%M:6QY.B!#
M;W5R:65R.PH@("`@9F]N="US:7IE.B`Q,'!X.PI]"G1D('L*("`@(&9O;G0M
M9F%M:6QY.B!#;W5R:65R.PH@("`@9F]N="US:7IE.B`Q,'!X.PI]"F1I=BYS
M:6UD978@>PH@("`@=VED=&@Z(#$U,#L*("`@(&AE:6=H=#H@,3(P.PH@("`@
M;W9E<F9L;W<Z(&%U=&\["GT*=&0N=&]P('L*("`@('=I9'1H.B`R-C,["B`@
M("!H96EG:'0Z(#$Q-SL*("`@(&)A8VMG<F]U;F0M:6UA9V4Z('5R;"AG<F%P
M:&EC<R]T;W`N:G!G*3L*?0IT9"YL969T('L*("`@('=I9'1H.B`U-CL*("`@
M(&AE:6=H=#H@,3(P.PH@("`@8F%C:V=R;W5N9"UI;6%G93H@=7)L*&=R87!H
M:6-S+VQE9G0N:G!G*3L*?0IT9"YD:7-P;&%Y('L*("`@('=I9'1H.B`Q-3`[
M"B`@("!H96EG:'0Z(#$R,#L*("`@(&)A8VMG<F]U;F0M:6UA9V4Z('5R;"AG
M<F%P:&EC<R]D:7-P;&%Y+FIP9RD["GT*=&0N<FEG:'0@>PH@("`@=VED=&@Z
M(#4W.PH@("`@:&5I9VAT.B`Q,C`["B`@("!B86-K9W)O=6YD+6EM86=E.B!U
M<FPH9W)A<&AI8W,O<FEG:'0N:G!G*3L*?0IT9"YB;W1T;VT@>PH@("`@=VED
M=&@Z(#(V,SL*("`@(&AE:6=H=#H@,S$S.PH@("`@8F%C:V=R;W5N9"UI;6%G
M93H@=7)L*&=R87!H:6-S+V)O='1O;2YJ<&<I.PI]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O;6]Z,30N8W-S````````````````````````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,C8P`#$P-3$U-#,S-S<T`#`R
M,#8S,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```O*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O;6]Z,30N8W-S+'8@,2XQ
M+C(N,B`R,#`U+S$P+S$X(#$Q.C,T.C$P(&IA;B!%>'`@)`H@*@H@*B!#4U,@
M8V]R<F5C=&EO;G,@9F]R($UO>FEL;&$@/#T@,2XT+@H@*B\*"B-M96YU('L*
M("`@(&]V97)F;&]W.B!V:7-I8FQE.PH@("`@:&5I9VAT.B`U,'!X.PI]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+VUO>FEL;&$O````````````````````````````````````````
M```````````````````````````````````````P,#`P-S4U`#`P,C,T,C<`
M,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<W-``P,C`V,34`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(@(`!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P,``P,#`P
M,#`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+B]U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O;6]Z:6QL82]G<F%P:&EC<R\`````
M````````````````````````````````````````````````````````````
M`#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U-#,S
M-S<T`#`R,C0Q-0`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<B`@`&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`P`#`P,#`P,#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]M;WII
M;&QA+V=R87!H:6-S+VAE861E<BYP;F<`````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#`T,#``,3`U,34T,S,W-S0`,#(T,S0U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````'
M````&0@"````<NRC;P```"QT15AT0W)E871I;VX@5&EM90!4=64@,38@2G5L
M(#(P,#(@,C,Z-#4Z,3@@*S$R,##%@1A1````!W1)344'T@<0"RX)#Y7"8@``
M``EP2%ES```.PP``#L,!QV^H9`````1G04U!``"QCPO\804```!7241!5'C:
M8YRR:"T#!F`\=_T>IBC+\^<?,$69&+`!%@96!F+5XC"!`[NY+%A%&;"HQN4R
MK"9PDN`RK";@4HO-9:280+DHR[GSYS%%&;U\H["('KN,)>8!'M`-<[W48/``
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+B]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;6]Z:6QL82]G<F%P:&EC
M<R]M96YU+6%C=&EV92YP;F<`````````````````````````````````````
M`````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S(W`#$P
M-3$U-#,S-S<T`#`R-3,T,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<B`@`&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`P`#`P,#`P,#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12`````0```#`(!@```-`S
M$($````$<T))5`@("`A\"&2(````"7!(67,```KP```*\`%"K#28````(71%
M6'13;V9T=V%R90!-86-R;VUE9&EA($9I<F5W;W)K<R`T+C#J)B=U````3$E$
M051XG&V/L1&`,!##+.V_#0/0LQ04GWS(0>-"YUCY'.=UFR05P`AA,/6'=4_?
M;]U[5,\HTR%$:G0Q>]2OHUGMM:T^SF19WKYHCP=F'@0)V59GUP````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"XO=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+VUO>FEL;&$O9W)A<&AI8W,O;65N=2YP;F<`
M```````````````````````````````````````````````````````P,#`P
M-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#,P-P`Q,#4Q-30S,S<W-``P
M,C0P-C<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(@(`!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P,``P,#`P,#`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@````$````S"`(```#9Q?5X````!W1)344'
MT@<0"A8!%Q.<G`````EP2%ES```*\```"O`!0JPTF`````1G04U!``"QCPO\
M804```!6241!5'C:58RQ"H`P$$./_O_'.780='-0$,0Y:>^N03N$)B^YVOFR
M//=5S&P2Y<GT_0T^,I$91#!`/<([S^S;SJA];KY[AJ@>\W_JG/^S]JYU/VRI
M6P._3EW)`Y_2O0````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]M;WII;&QA+VEN9F\N<&AP````````````````````````````
M````````````````````````````````````````,#`P,#8T-``P,#(S-#(W
M`#`P,#<V-#$`,#`P,#`P,#`Q-S0`,3`U,34T,S,W-S0`,#(R,C8S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R("``8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,#``,#`P
M,#`P,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]M;WII;&QA+VEN9F\N<&AP+'8@
M,2XQ(#(P,#0O,3`O,3<@,3DZ,S,Z,S<@;61J=6MI8R!%>'`@)`H@*B\*"B1T
M:&5M95]N86UE(#T@7R@B36]Z:6QL82(I.PH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;6]Z
M:6QL82]S8W)E96XN8W-S````````````````````````````````````````
M`````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P
M,#`P,#`S,34V`#$P-3$U-#,S-S<T`#`R,C8Q,P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<B`@`&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`P`#`P,#`P,#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````O*BH*("H@)$AO<F1E.B!H;W)D
M92]T:&5M97,O;6]Z:6QL82]S8W)E96XN8W-S+'8@,2XW+C8N-2`R,#`U+S$P
M+S$X(#$Q.C,T.C(P(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@8F%C:V=R
M;W5N9#H@(V,W9#!D.3L*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C.31A
M,F(U.PI]"FAT;6P@>PH@("`@<V-R;VQL8F%R+6)A<V4M8V]L;W(Z(",Y-&$R
M8C4["GT*82P@82YF:7AE9"!["B`@("!C;VQO<CH@(S,S.3L*?0IA+G=I9&=E
M="!["B`@("!C;VQO<CH@(S`P,#L*?0HN:&5A9&5R('L*("`@(&)A8VMG<F]U
M;F0Z("-C-V0P9#D@=7)L*")G<F%P:&EC<R]H96%D97(N<&YG(BD@<F5P96%T
M+7@["B`@("!W:&ET92US<&%C93H@;F]W<F%P.PI]"F$N:&5A9&5R('L*("`@
M(&)A8VMG<F]U;F0M:6UA9V4Z(&YO;F4["B`@("!B86-K9W)O=6YD+6-O;&]R
M.B!T<F%N<W!A<F5N=#L*?0HN;&EG:'0@>PH@("`@8V]L;W(Z(",T135$-S([
M"GT*+G-M86QL:&5A9&5R('L*("`@(&-O;&]R.B!B;&%C:SL*("`@(&)A8VMG
M<F]U;F0M:6UA9V4Z(&YO;F4["B`@("!B86-K9W)O=6YD+6-O;&]R.B!T<F%N
M<W!A<F5N=#L*?0HN<VUA;&QH96%D97(@82!["B`@("!C;VQO<CH@8FQA8VL[
M"GT*+F-O;G1R;VP@>PH@("`@8F%C:V=R;W5N9#H@(V%E8F%C83L*?0HN:71E
M;2!["B`@("!B86-K9W)O=6YD.B`C96-E9F8T.PI]"BYB=71T;VX@>PH@("`@
M8V]L;W(Z(&)L86-K.PH@("`@8F%C:V=R;W5N9#H@(V%D8C9C-CL*("`@(&)O
M<F1E<CH@,7!X('-O;&ED(",P,#`["B`@("`M;6]Z+6)O<F1E<BUR861I=7,Z
M(#5P>#L*?0HN<V5L96-T960@>PH@("`@8F%C:V=R;W5N9#H@(V,V9#-F9CL*
M?0H*+RH@365N=2!S='EL97,N("HO"B-M96YU('L*("`@(&)A8VMG<F]U;F0Z
M("-C-V0P9#D@=7)L*")G<F%P:&EC<R]M96YU+G!N9R(I(')E<&5A="UX.PI]
M"B-M96YU(&@Q('L*("`@(&-O;&]R.B!B;&%C:SL*?0HC;65N=2!A('L*("`@
M(&-O;&]R.B!B;&%C:SL*("`@(&)O<F1E<CH@;F]N93L*("`@("UM;WHM8F]R
M9&5R+7)A9&EU<SH@,#L*?0HC;65N=2!A.FAO=F5R('L*("`@(&)O<F1E<CH@
M,7!X('-O;&ED("-A96)A8V$["B`@("!P861D:6YG.B`R<'@["GT*(VUE;G4@
M82YC=7)R96YT('L*("`@(&)A8VMG<F]U;F0Z('5R;"@B9W)A<&AI8W,O;65N
M=2UA8W1I=F4N<&YG(BD@<F5P96%T+7@["B`@("!B;W)D97(Z(#%P>"!S;VQI
M9"`C865B86-A.PH@("`@<&%D9&EN9SH@,G!X.PI]"B-M96YU(&$N8W5R<F5N
M=#IH;W9E<B!["B`@("!P861D:6YG.B`R<'@["GT*"B\J(%-I9&5B87(@<W1Y
M;&5S+B`J+PHC<VED96)A<E!A;F5L('L*("`@(&)A8VMG<F]U;F0Z("-C-V0P
M9#D["GT*"B\J(%1A8B!S='EL97,N("HO"BYT86)S970@>PH@("`@8F%C:V=R
M;W5N9#H@;F]N93L*?0HN=&%B<V5T(&QI(&$@>PH@("`@8F]R9&5R.B`Q<'@@
M<V]L:60@(V%B86)A8CL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C
M93EE.64Y.PI]"BYT86)S970@;&D@83IH;W9E<B!["B`@("!C;VQO<CH@(S`P
M,#L*?0HN=&%B<V5T(&QI+F%C=&EV951A8B!A+"`N=&%B<V5T(&QI+F%C=&EV
M951A8B!A.FAO=F5R('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N
M9#H@(V%E8F%C83L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C865B
M86-A.PI]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+TYE6%1G<F5Y
M+P``````````````````````````````````````````````````````````
M```````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P
M,#`P,``Q,#4Q-30S,S<V,0`P,C`V-#<`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(@(`!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P,``P,#`P,#`P````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O3F585&=R97DO:6YF;RYP:'``````````````````````````
M`````````````````````````````````````````#`P,#`V-#0`,#`R,S0R
M-P`P,#`W-C0Q`#`P,#`P,#`P,3<R`#$P-3$U-#,S-S8Q`#`R,C,Q,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<B`@`&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`P`#`P
M,#`P,#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O3F585&=R97DO:6YF;RYP:'`L
M=B`Q+C$@,C`P-"\Q,"\Q-R`Q.3HS,SHS,R!M9&IU:VEC($5X<"`D"B`J+PH*
M)'1H96UE7VYA;64@/2!?*").95A4(BD["@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+TYE
M6%1G<F5Y+W-C<F5E;BYC<W,`````````````````````````````````````
M```````````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P
M,#`P,#`P,C(R,@`Q,#4Q-30S,S<V,0`P,C(V,S8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(@(`!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P,``P,#`P,#`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+RHJ"B`J("1(;W)D93H@:&]R
M9&4O=&AE;65S+TYE6%1G<F5Y+W-C<F5E;BYC<W,L=B`Q+C8N-BXS(#(P,#4O
M,3`O,3@@,3$Z,S0Z,3`@:F%N($5X<"`D"B`J+PH*8F]D>2!["B`@("!B86-K
M9W)O=6YD.B`C-#0T.PH@("`@<V-R;VQL8F%R+6)A<V4M8V]L;W(Z("-A8V$Y
M86,["B`@("!S8W)O;&QB87(M87)R;W<M8V]L;W(Z("-A8V$Y86,["GT*:'1M
M;"!["B`@("!S8W)O;&QB87(M8F%S92UC;VQO<CH@(V%C83EA8SL*("`@('-C
M<F]L;&)A<BUA<G)O=RUC;VQO<CH@(V%C83EA8SL*?0IA+"!A+F9I>&5D('L*
M("`@(&-O;&]R.B`C,S,Y.PI]"F$N=VED9V5T('L*("`@(&-O;&]R.B`C,#`P
M.PI]"F$N=VED9V5T.FAO=F5R('L*("`@(&-O;&]R.B!W:&ET93L*("`@(&)A
M8VMG<F]U;F0Z("-C8V,["GT*+FAE861E<B!["B`@("!C;VQO<CH@(SEF.69A
M,#L*("`@(&)A8VMG<F]U;F0Z(",P,#`["GT*+FAE861E<B!A('L*("`@(&-O
M;&]R.B`C.68Y9F$P.PI]"BYS;6%L;&AE861E<B!["B`@("!C;VQO<CH@(SEF
M.69A,#L*("`@(&)A8VMG<F]U;F0Z(",P,#`["GT*+F)U='1O;B!["B`@("!C
M;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-A8V$Y86,["B`@
M("!B;W)D97(M8F]T=&]M.B!T:&EN('-O;&ED(",R,C(["B`@("!B;W)D97(M
M<FEG:'0Z('1H:6X@<V]L:60@(S(R,CL*("`@(&)O<F1E<BUT;W`Z('1H:6X@
M<V]L:60@(V1D9#L*("`@(&)O<F1E<BUL969T.B!T:&EN('-O;&ED("-D9&0[
M"GT*+G-E;&5C=&5D('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-A8V$Y86,[
M"GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@("!C;VQO<CH@(V9F
M9CL*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-A8V$Y86,["GT*(VUE;G4@:#$@
M>PH@("`@8V]L;W(Z(",P,#`["GT*(VUE;G4@82!["B`@("!C;VQO<CH@(V9F
M9CL*?0HC;65N=2!A+F-U<G)E;G0@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@
M(S@W.#<X-SL*("`@(&-O;&]R.B`C9&1D.PI]"@HO*B!3:61E8F%R('-T>6QE
M<RX@*B\*(W-I9&5B87)086YE;"!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C
M.3DY.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(S(R,CL*("`@(&)O
M<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,C(R.PI]"B-E>'!A;F1"=71T;VX@
M>PH@("`@;6%R9VEN+7)I9VAT.B`Q<'@["GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+B]U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O;W!E<F$N8W-S````````````````````
M`````````````````````````````````````````````````````````#`P
M,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,S,V`#$P-3$U-#,S-S<T
M`#`R,#<W,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<B`@`&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`P`#`P,#`P,#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````O*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O;W!E<F$N8W-S+'8@
M,2XQ+C(N-"`R,#`U+S$P+S$X(#$Q.C,T.C$P(&IA;B!%>'`@)`H@*@H@*B!#
M4U,@8V]R<F5C=&EO;G,@9F]R($]P97)A+@H@*B\*"BYT<F5E4F]W('L*("`@
M(&]V97)F;&]W.B!V:7-I8FQE.PH@("`@:&5I9VAT.B`R,'!X.PI]"@HC;65N
M=2!["B`@("!O=F5R9FQO=SH@=FES:6)L93L*("`@(&AE:6=H=#H@-3!P>#L*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+W!O<W1N=6ME+P``````````````````````````````````
M```````````````````````````````````````````P,#`P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<W,P`P,C$P,34`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O<&]S=&YU:V4O:6YF;RYP:'``
M````````````````````````````````````````````````````````````
M`````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,3<V`#$P-3$U
M-#,S-S<S`#`R,C0V-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O
M<&]S=&YU:V4O:6YF;RYP:'`L=B`Q+C$@,C`P-"\Q,"\Q-R`Q.3HS,SHS-R!M
M9&IU:VEC($5X<"`D"B`J+PH*)'1H96UE7VYA;64@/2!?*")0;W-T;G5K92(I
M.PH`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"XO=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+W!O<W1N=6ME+W-C<F5E;BYC<W,`````````````
M```````````````````````````````````````````````````P,#`P-C0T
M`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,S4Q-P`Q,#4Q-30S,S<W,P`P,C,P
M,30`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(@(`!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P,``P,#`P,#`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+W!O<W1N=6ME+W-C<F5E;BYC
M<W,L=B`Q+C@N-BXR(#(P,#4O,3`O,3@@,3$Z,S0Z,C`@:F%N($5X<"`D"B`J
M+PH*8F]D>2!["B`@("!B86-K9W)O=6YD.B`C8C%B-SAB.PH@("`@<V-R;VQL
M8F%R+6)A<V4M8V]L;W(Z(",V-C8V.3D["B`@("!S8W)O;&QB87(M87)R;W<M
M8V]L;W(Z("-D9&1D9F8["GT*:'1M;"!["B`@("!S8W)O;&QB87(M8F%S92UC
M;VQO<CH@(S8V-C8Y.3L*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@(V1D
M9CL*?0IA('L*("`@(&-O;&]R.B`C,S,Y.PH@("`@9F]N="UF86UI;'DZ($=E
M;F5V82Q!<FEA;"Q(96QV971I8V$L<V%N<RUS97)I9CL*("`@(&9O;G0M<VEZ
M93H@,3)P>#L*?0IA.FAO=F5R('L*("`@(&-O;&]R.B!B;'5E.PI]"F$N=VED
M9V5T('L*("`@(&-O;&]R.B`C,#`P.PH@("`@9F]N="UF86UI;'DZ(%9E<F1A
M;F$L2&5L=F5T:6-A+'-A;G,M<V5R:68["B`@("!F;VYT+7-I>F4Z(#$Q<'@[
M"GT*82YW:61G970Z:&]V97(@>PH@("`@8V]L;W(Z(&)L=64["B`@("!B86-K
M9W)O=6YD.B`C8C%B-SAB.PI]"BYH96%D97(@>PH@("`@8F%C:V=R;W5N9#H@
M(V(Q8C<X8CL*("`@(&9O;G0M<VEZ93H@,3=P>#L*?0HN;&EG:'0@>PH@("`@
M8V]L;W(Z('=H:71E.PH@("`@9F]N="UF86UI;'DZ($=E;F5V82Q!<FEA;"Q(
M96QV971I8V$L<V%N<RUS97)I9CL*("`@(&9O;G0M<VEZ93H@,3)P>#L*?0HN
M<VUA;&QH96%D97(@>PH@("`@8V]L;W(Z(",P,#`["B`@("!B86-K9W)O=6YD
M.B`C8C%B-SAB.PI]"BYC;VYT<F]L('L*("`@(&-O;&]R.B!B;&%C:SL*("`@
M(&)A8VMG<F]U;F0Z("-D.61C8S(["GT*+FET96T@>PH@("`@8V]L;W(Z(&)L
M86-K.PH@("`@8F%C:V=R;W5N9#H@(V4Y93EE.3L*?0HN8G5T=&]N('L*("`@
M(&-O;&]R.B!W:&ET93L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",P,#`P,#`[
M"B`@("!B;W)D97(M8F]T=&]M.B!T:&EN('-O;&ED("-",4(W.$(["B`@("!B
M;W)D97(M<FEG:'0Z('1H:6X@<V]L:60@(T(Q0C<X0CL*("`@(&)O<F1E<BUT
M;W`Z('1H:6X@<V]L:60@(SDY.3EC8SL*("`@(&)O<F1E<BUL969T.B!T:&EN
M('-O;&ED(",Y.3DY8V,["B`@("!F;VYT+7-I>F4Z(#$Q<'@["B`@("!F;VYT
M+69A;6EL>3H@5F5R9&%N82Q(96QV971I8V$L<V%N<RUS97)I9CL*?0HN<V5L
M96-T960@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V)B8V)F9CL*?0HN=&5X
M="!["B`@("!C;VQO<CH@8FQA8VL["B`@("!B86-K9W)O=6YD+6-O;&]R.B!W
M:&ET93L*?0HO*B!!;'1E<FYA=&EN9R!S='EL97,N(&ET96TP+"!I=&5M,2!A
M<F4@9&5P<F5C871E9"X@*B\*+G)O=T5V96XL("YI=&5M,"!["B`@("!B86-K
M9W)O=6YD+6-O;&]R.B`C9CEF.68Y.PI]"BYR;W=/9&0L("YI=&5M,2!["B`@
M("!B86-K9W)O=6YD+6-O;&]R.B`C93EE.64Y.PI]"BYF:7AE9"!["B`@("!F
M;VYT+7-I>F4Z(#$S<'@["B`@("!F;VYT+69A;6EL>3H@;6]N;W-P86-E+"!F
M:7AE9#L*?0IT9"!["B`@("!F;VYT+7-I>F4Z(#$R<'@["B`@("!F;VYT+69A
M;6EL>3H@1V5N979A+$%R:6%L+$AE;'9E=&EC82QS86YS+7-E<FEF.PI]"G1H
M('L*("`@(&9O;G0M<VEZ93H@,3)P>#L*("`@(&9O;G0M9F%M:6QY.B!'96YE
M=F$L07)I86PL2&5L=F5T:6-A+'-A;G,M<V5R:68["GT*"B\J($UE;G4@<W1Y
M;&5S+B`J+PHC;65N=2!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U
M;F0Z("-B,6(W.&(["GT*(VUE;G4@82!["B`@("!C;VQO<CH@(V9F9CL*?0HC
M;65N=2!A+F-U<G)E;G0@>PH@("`@8F%C:V=R;W5N9#H@(V)F8C<X8CL*?0H*
M+RH@4VED96)A<B!S='EL97,N("HO"B-S:61E8F%R4&%N96P@>PH@("`@8F%C
M:V=R;W5N9"UC;VQO<CH@(T(Q0C<X0CL*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]P<FEN="\`````````````````````````````````````
M````````````````````````````````````````````,#`P,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-S,`,#(P,S`Q`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+W!R:6YT+W-C<F5E;BYC<W,`
M````````````````````````````````````````````````````````````
M```````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,3,S,0`Q,#4Q
M-30S,S<W,P`P,C(R-S``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+W!R:6YT
M+W-C<F5E;BYC<W,L=B`Q+C$N,3`N-"`R,#`V+S`S+S$T(#(R.C0S.C4P(&IA
M;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*("`@
M(&-O;&]R.B`C,#`P.PI]"F$@>PH@("`@8V]L;W(Z(",P,#`["GT*"B-M96YU
M('L*("`@(&1I<W!L87DZ(&YO;F4["GT*"BYH96%D97)B;W@@>PH@("`@8F]R
M9&5R.B!N;VYE.PI]"BYS96QE8W1E9"!["B`@("!B86-K9W)O=6YD.B`C9&1D
M.PI]"BYW:61G970@>PH@("`@8V]L;W(Z(",P,#`["GT*+FAE861E<B!["B`@
M("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0Z("-F9F8["GT*+G-M86QL
M:&5A9&5R('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9#H@(V9F
M9CL*?0HN8V]N=')O;"!["B`@("!B86-K9W)O=6YD.B`C9F9F.PH@("`@8F]R
M9&5R+6)O='1O;3H@,7!X('-O;&ED(",P,#`["GT*+FET96TP+"`N:71E;3$@
M>PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P
M>"!S;VQI9"`C8V-C.PI]"BYS:6=N871U<F4L("YS:6=N871U<F4M9FEX960@
M>PH@("`@8V]L;W(Z(",P,#`["GT*+G1O9V=L97%U;W1E('L*("`@(&1I<W!L
M87DZ(&YO;F4["GT*+G%U;W1E9#$L("YQ=6]T960R+"`N<75O=&5D,RP@+G%U
M;W1E9#0L("YQ=6]T960U('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F]R9&5R
M+6QE9G0M8V]L;W(Z(",P,#`["GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+W!U<G!L92\`````
M````````````````````````````````````````````````````````````
M```````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P
M,``Q,#4Q-30S,S<W-``P,C`T-34`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O<'5R<&QE+VEN9F\N<&AP````````````````````````````````
M`````````````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P
M,#`W-C0Q`#`P,#`P,#`P,3<V`#$P-3$U-#,S-S<T`#`R,C$R-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<B`@`&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`P`#`P,#`P
M,#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@)$AO<F1E.B!H;W)D92]T:&5M97,O<'5R<&QE+VEN9F\N<&AP+'8@,2XQ
M(#(P,#0O,3$O,C4@,#(Z,#0Z-30@8VAU8VL@17AP("0*("HO"@HD=&AE;65?
M;F%M92`](%\H(E!U<G!L92!(;W)D92(I.PH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+W!U<G!L
M92]S8W)E96XN8W-S````````````````````````````````````````````
M```````````````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P
M,#`P-C`P,@`Q,#4Q-30S,S<W-``P,C(T-#0`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(@
M(`!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P,``P,#`P,#`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+RHJ"B`J("1(;W)D93H@:&]R9&4O
M=&AE;65S+W!U<G!L92]S8W)E96XN8W-S+'8@,2XQ+C0N-B`R,#`V+S`T+S(X
M(#(P.C0W.C(X(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@8F%C:V=R;W5N
M9#H@(S(R-#L*?0H*+FAE861E<F)O>"!["B`@("!B;W)D97(M8V]L;W(Z(",V
M-CD["B`@("!B86-K9W)O=6YD.B`C9F9F.PI]"BYH96%D97(@>PH@("`@8V]L
M;W(Z("-C8V4["B`@("!B86-K9W)O=6YD.B`C-#0V.PH@("`@8VQE87(Z(&)O
M=&@["GT*+FAE861E<B!A.FAO=F5R+"!A+FAE861E<CIH;W9E<B!["B`@("!C
M;VQO<CH@(V9F9CL*?0HN:&5A9&5R(&$@>PH@("`@8V]L;W(Z("-C8V4["GT*
M82YH96%D97(Z:&]V97(@>PH@("`@8V]L;W(Z("-F9F8["GT*82!["B`@("!C
M;VQO<CH@(S,S.3L*?0IA.FAO=F5R('L*("`@(&-O;&]R.B!B;'5E.PI]"BYS
M96QE8W1E9"!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C8F)C8F9F.PI]"BYS
M96QE8W1E9"UO=F5R('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C968["GT*
M"BYW:61G970@>PH@("`@8V]L;W(Z(",R,C0["GT*82YW:61G970Z:&]V97(@
M>PH@("`@8V]L;W(Z(&)L=64["B`@("!B86-K9W)O=6YD.B`C8F)C8F9F.PI]
M"@HN;F]T:6-E('L*("`@(&9O;G0M=V5I9VAT.B!B;VQD.PH@("`@8F%C:V=R
M;W5N9"UC;VQO<CH@(V9F8SL*("`@(&)O<F1E<CH@,7!X('-O;&ED("-A86$[
M"B`@("!P861D:6YG.B`Q<'@["B`@("!P861D:6YG+6QE9G0Z(#5P>#L*("`@
M("UM;WHM8F]R9&5R+7)A9&EU<SH@.'!X.PI]"@HN;&EG:'0@>PH@("`@8V]L
M;W(Z("-F9F8["B`@("!F;VYT+69A;6EL>3H@1V5N979A+$%R:6%L+$AE;'9E
M=&EC82QS86YS+7-E<FEF.PH@("`@9F]N="US:7IE.B`Q,G!X.PI]"BYS;6%L
M;&AE861E<B!["B`@("!C;VQO<CH@(V-C93L*("`@(&)A8VMG<F]U;F0M8V]L
M;W(Z(",T-#8["GT*+G-M86QL:&5A9&5R(&$Z:&]V97(L(&$N<VUA;&QH96%D
M97(Z:&]V97(@>PH@("`@8V]L;W(Z("-F9F8["GT*+G-M86QL:&5A9&5R(&$@
M>PH@("`@8V]L;W(Z("-C8V4["GT*+F-O;G1R;VP@>PH@("`@8V]L;W(Z(",P
M,#`["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C8V-C.PH@("`@8F]R9&5R+6)O
M='1O;3H@,7!X('-O;&ED(",Y.3D["GT*+FET96T@>PH@("`@8V]L;W(Z(",P
M,#`["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C965E.PI]"BYA8V-E<W-+97D@
M>PH@("`@=&5X="UD96-O<F%T:6]N.B!U;F1E<FQI;F4["GT*+G1E>'0@>PH@
M("`@8V]L;W(Z(",P,#`["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C9F9F.PI]
M"@HO*B!&;W)M('-T>6QE<RX@*B\*+F)U='1O;B!["B`@("!C;VQO<CH@(V9F
M9CL*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",V-CD["B`@("!B;W)D97(M8F]T
M=&]M.B`Q<'@@<V]L:60@(S(R-#L*("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O
M;&ED(",R,C0["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(SDY8SL*("`@
M(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(SDY8SL*("`@(&9O;G0M<VEZ93H@
M,3%P>#L*("`@(&9O;G0M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC82QS86YS
M+7-E<FEF.PI]"F$Z:&]V97(N8G5T=&]N('L*("`@(&-O;&]R.B`C9F9F.PI]
M"@HO*B!-96YU('-T>6QE<RX@*B\*(VUE;G4@>PH@("`@8V]L;W(Z("-F9F8[
M"B`@("!B86-K9W)O=6YD+6-O;&]R.B`C-#0V.PI]"B-M96YU('5L('L*("`@
M('!A9&1I;F<Z(#5P>#L*?0HC;65N=2!L:2!["B`@("!L:7-T+7-T>6QE+71Y
M<&4Z(&YO;F4["B`@("!T97AT+6%L:6=N.B!C96YT97(["B`@("!M87)G:6XZ
M(#)P>#L*("`@(&9L;V%T.B!L969T.PI]"B-M96YU(&$@>PH@("`@8V]L;W(Z
M("-E968["GT*(VUE;G4@83IH;W9E<B!["B`@("!C;VQO<CH@>65L;&]W.PH@
M("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",V-F$["B`@("!B;W)D97(M
M<FEG:'0Z(#%P>"!S;VQI9"`C-C9A.PH@("`@8F]R9&5R+71O<#H@,7!X('-O
M;&ED(",R,C0["B`@("!B;W)D97(M;&5F=#H@,7!X('-O;&ED(",R,C0["B`@
M("!P861D:6YG.B`R<'@["GT*(VUE;G4@82YC=7)R96YT('L*("`@(&)A8VMG
M<F]U;F0M8V]L;W(Z(",V-C@["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L
M:60@(SDY8SL*("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED(",Y.6,["B`@
M("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(S(R-#L*("`@(&)O<F1E<BUL969T
M.B`Q<'@@<V]L:60@(S(R-#L*("`@('!A9&1I;F<Z(#)P>#L*?0HC;65N=2!H
M,2!["B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82Q(96QV971I8V$L<V%N<RUS
M97)I9CL*("`@(&9O;G0M=V5I9VAT.B!B;VQD.PH@("`@9F]N="US:7IE.B`Q
M.'!X.PH@("`@;&EN92UH96EG:'0Z(#4P<'@["B`@("!V97)T:6-A;"UA;&EG
M;CH@8F]T=&]M.PI]"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*(W-I9&5B87)0
M86YE;"!["B`@("`M;6]Z+6)O<F1E<BUR861I=7,M8F]T=&]M<FEG:'0Z(#$U
M<'@["B`@("!P861D:6YG+71O<#H@-7!X.PH@("`@<&%D9&EN9RUB;W1T;VTZ
M(#$P<'@["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C965E.PI]"B-S:61E8F%R
M4&%N96P@<W!A;B!["B`@("!P861D:6YG.B`R<'@["GT*(W-I9&5B87)086YE
M;"!S<&%N+"`C<VED96)A<E!A;F5L(&$@>PH@("`@8V]L;W(Z(",P,#`["B`@
M("!W:&ET92US<&%C93H@<')E.PH@("`@9F]N="UF86UI;'DZ(%9E<F1A;F$L
M2&5L=F5T:6-A+'-A;G,M<V5R:68["B`@("!F;VYT+7-I>F4Z(#$Q<'@["B`@
M("!T97AT+61E8V]R871I;VXZ(&YO;F4["GT*(W-I9&5B87)086YE;"!A.FAO
M=F5R('L*("`@("UM;WHM8F]R9&5R+7)A9&EU<SH@,W!X.PH@("`@8V]L;W(Z
M(",P,#`["GT*"B\J(%1A8B!S='EL97,N("HO"BYT86)S970@;&D@83IH;W9E
M<B!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C9F9F.PI]"BYT86)S970@;&DN
M86-T:79E5&%B(&$L("YT86)S970@;&DN86-T:79E5&%B(&$Z:&]V97(@>PH@
M("`@8F%C:V=R;W5N9"UC;VQO<CH@(S0T-CL*("`@(&)O<F1E<BUB;W1T;VTM
M8V]L;W(Z(",T-#8["GT*"B\J(%!R969E<F5N8V5S(&]V97)V:65W+B`J+PHN
M<')E9G-/=F5R=FEE=R!H,B!["B`@("!C;VQO<CH@(V9F9CL*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]R=&PN
M8W-S````````````````````````````````````````````````````````
M````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P
M,#`P,#$S,#``,3`U,34T,S,W-S0`,#(P-#4S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M("``8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,#``,#`P,#`P,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"\J*@H@*B`D2&]R9&4Z(&AO<F1E
M+W1H96UE<R]R=&PN8W-S+'8@,2XR+C(N,2`R,#`U+S$P+S$X(#$Q.C,T.C$P
M(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@9&ER96-T:6]N.B!R=&P["B`@
M("!F;VYT+69A;6EL>3H@5&%H;VUA+$MO;V1A:RQ(;VUA+$YA>FQI+%9E<F1A
M;F$L1V5N979A+$%R:6%L+$AE;'9E=&EC82QS86YS+7-E<FEF.PI]"@HN;&5F
M=$%L:6=N('L*("`@("`@("!T97AT+6%L:6=N.B!R:6=H=#L*("`@("`@("!F
M;VYT+69A;6EL>3H@5&%H;VUA+$MO;V1A:RQ(;VUA+$YA>FQI+%9E<F1A;F$L
M1V5N979A+$%R:6%L+$AE;'9E=&EC82QS86YS+7-E<FEF.PI]"BYR:6=H=$%L
M:6=N('L*("`@("`@("!T97AT+6%L:6=N.B!L969T.PH@("`@("`@(&9O;G0M
M9F%M:6QY.B!486AO;6$L2V]O9&%K+$AO;6$L3F%Z;&DL5F5R9&%N82Q'96YE
M=F$L07)I86PL2&5L=F5T:6-A+'-A;G,M<V5R:68["GT*"BYL969T1FQO870@
M>PH@("`@("`@(&9L;V%T.B!R:6=H=#L*?0HN<FEG:'1&;&]A="!["B`@("`@
M("`@9FQO870Z(&QE9G0["GT*"BYH96%D97(@=6P@>PH@("`@9FQO870Z(&QE
M9G0["B`@("!T97AT+6%L:6=N.B!L969T.PI]"@HO*B!486(@<W1Y;&5S+B`J
M+PHN=&%B<V5T('L*("`@(&9L;V%T.B!R:6=H=#L*?0HN=&%B<V5T(&QI('L*
M("`@(&9L;V%T.B!R:6=H=#L*?0HN=&%B<V5T(&EM9R!["B`@("!F;&]A=#H@
M<FEG:'0["GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]S869A<FDN8W-S````````````````````````````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#`T-C4`,3`U,34T,S,W-S0`,#(Q,3,R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"\J*@H@*B`D2&]R9&4Z
M(&AO<F1E+W1H96UE<R]S869A<FDN8W-S+'8@,2XQ+C(N-B`R,#`U+S$P+S$X
M(#$Q.C,T.C$P(&IA;B!%>'`@)`H@*@H@*B!#4U,@8V]R<F5C=&EO;G,@9F]R
M(%-A9F%R:2X*("HO"@II;6<@>PH@("`@=F5R=&EC86PM86QI9VXZ(&)A<V5L
M:6YE.PI]"@HN=')E95)O=R!["B`@("!O=F5R9FQO=SH@=FES:6)L93L*("`@
M(&AE:6=H=#H@,C!P>#L*?0H*+G1R9652;W<@:6UG('L*("`@('9E<G1I8V%L
M+6%L:6=N.B!M:61D;&4["GT*"B-M96YU('L*("`@(&]V97)F;&]W.B!V:7-I
M8FQE.PH@("`@:&5I9VAT.B`U,'!X.PI]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O<V-R965N+F-S
M<P``````````````````````````````````````````````````````````
M`````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#(W
M-S0Q`#$P-3$U-#,S-S<T`#`R,3$U,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<B`@`&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`P`#`P,#`P,#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````O*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M
M97,O<V-R965N+F-S<RQV(#$N-RXT+C4W(#(P,#8O,#8O,3$@,C$Z,S0Z,C<@
M8VAU8VL@17AP("0*("HO"@HO*B!';&]B86P@9&5F875L="!S='EL97,N("HO
M"BH@>PH@("`@+RH@6F5R;R!O=70@86QL('!A9&1I;F<@86YD(&UA<F=I;G,@
M=&\@<W1A<G0@=VET:"!F;W(@8F5T=&5R"B`@("`@*B!C<F]S<RUB<F]W<V5R
M(&-O;G1R;VPN("HO"B`@("!P861D:6YG.B`P.PH@("`@;6%R9VEN.B`P.PI]
M"@IB;V1Y('L*("`@(&9O;G0M9F%M:6QY.B!'96YE=F$L07)I86PL2&5L=F5T
M:6-A+'-A;G,M<V5R:68["B`@("!F;VYT+7-I>F4Z(#$R<'@["B`@("!B86-K
M9W)O=6YD.B`C9F9F.PH@("`@8V]L;W(Z(",P,#`["GT*"F)O9'DN<V-R;VQL
M8F%R+7%U:7)K('L*("`@(&UA<F=I;BUR:6=H=#H@,35P>#L*?0H*<"!["B`@
M("!M87)G:6XM8F]T=&]M.B`Q,'!X.PI]"@II;6<L("YI;6<L("YI;6<Z86-T
M:79E+"`N:6UG.FAO=F5R+"`N:6UG.G9I<VET960@>PH@("`@8F]R9&5R.B!N
M;VYE.PH@("`@=F5R=&EC86PM86QI9VXZ(&UI9&1L93L*("`@(&)A8VMG<F]U
M;F0Z('1R86YS<&%R96YT.PI]"@II;G,@>PH@("`@8F%C:V=R;W5N9#H@(V-F
M8SL*?0ID96P@>PH@("`@8F%C:V=R;W5N9#H@(V9C8SL*?0H*8G(N<W!A8V5R
M('L*("`@(&9O;G0M<VEZ93H@.'!X.PI]"@HN;&5F=$%L:6=N('L*("`@('1E
M>'0M86QI9VXZ(&QE9G0["GT*+G)I9VAT06QI9VX@>PH@("`@=&5X="UA;&EG
M;CH@<FEG:'0["GT*+FQE9G1&;&]A="!["B`@("!F;&]A=#H@;&5F=#L*?0HN
M<FEG:'1&;&]A="!["B`@("!F;&]A=#H@<FEG:'0["GT*"BYB;W@@>PH@("`@
M<&%D9&EN9SH@,W!X.PH@("`@8F]R9&5R.B`Q<'@@9&%S:&5D(",Y.3D["B`@
M("!B86-K9W)O=6YD.B`C9F9F.PI]"BYS;VQI9&)O>"!["B`@("!B;W)D97(Z
M(#%P>"!S;VQI9"`C,#`P.PI]"BYG<F5Y8F]X('L*("`@(&)O<F1E<CH@,7!X
M('-O;&ED(",P,#`["B`@("!B86-K9W)O=6YD.B`C93EE.64Y.PI]"BYH96%D
M97)B;W@@>PH@("`@8F]R9&5R+6QE9G0Z(#%P>"!S;VQI9"`C,#`P.PH@("`@
M8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)O<F1E<BUB;W1T
M;VTZ(#%P>"!S;VQI9"`C,#`P.PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*?0HN
M<F]U;F1E9$)O>"!["B`@("`M;6]Z+6)O<F1E<BUR861I=7,Z(#$U<'@["GT*
M+G)O=6YD9614;W`@>PH@("`@+6UO>BUB;W)D97(M<F%D:75S+71O<')I9VAT
M.B`Q-7!X.PH@("`@+6UO>BUB;W)D97(M<F%D:75S+71O<&QE9G0Z(#$U<'@[
M"GT*+G)O=6YD961";W1T;VT@>PH@("`@+6UO>BUB;W)D97(M<F%D:75S+6)O
M='1O;7)I9VAT.B`Q-7!X.PH@("`@+6UO>BUB;W)D97(M<F%D:75S+6)O='1O
M;6QE9G0Z(#$U<'@["GT*+FAE861E<B!["B`@("!F;VYT+69A;6EL>3H@5F5R
M9&%N82Q(96QV971I8V$L<V%N<RUS97)I9CL*("`@(&9O;G0M=V5I9VAT.B!B
M;VQD.PH@("`@9F]N="US:7IE.B`Q-7!X.PH@("`@<&%D9&EN9SH@,W!X.PI]
M"BYH96%D97(@83IH;W9E<BP@82YH96%D97(Z:&]V97(@>PH@("`@8V]L;W(Z
M(",S,S,["GT*+FAE861E<B!I;6<@>PH@("`@=F5R=&EC86PM86QI9VXZ(&)O
M='1O;3L*?0HN:&5A9&5R('5L('L*("`@(&9L;V%T.B!R:6=H=#L*("`@('1E
M>'0M86QI9VXZ(')I9VAT.PH@("`@9F]N="US:7IE.B`Q,G!X.PI]"BYH96%D
M97(@;&D@>PH@("`@;&ES="US='EL93H@;F]N93L*("`@(&1I<W!L87DZ(&EN
M;&EN93L*?0HN;F]W<F%P('L*("`@('=H:71E+7-P86-E.B!N;W=R87`["GT*
M+F-L96%R('L*("`@(&-L96%R.B!B;W1H.PH@("`@;&EN92UH96EG:'0Z(#`[
M"B`@("!H96EG:'0Z(#`["GT*"F$@>PH@("`@8V]L;W(Z(&)L=64["B`@("!T
M97AT+61E8V]R871I;VXZ(&YO;F4["GT*83IH;W9E<B!["B`@("!T97AT+61E
M8V]R871I;VXZ('5N9&5R;&EN93L*?0HN<V5L96-T960@>PH@("`@8F%C:V=R
M;W5N9#H@(V)B8V)F9CL*?0HN<V5L96-T960M;W9E<B!["B`@("!B86-K9W)O
M=6YD.B`C8V5F.PI]"@HO*B!486)L92!S='EL97,N("HO"G1A8FQE('L*("`@
M(&)O<F1E<CH@;F]N93L*?0IT9"P@=&@@>PH@("`@<&%D9&EN9SH@,7!X.PI]
M"G1H('L*("`@(&-O;&]R.B`C,S,S.PH@("`@9F]N="UF86UI;'DZ(%9E<F1A
M;F$L2&5L=F5T:6-A+'-A;G,M<V5R:68["B`@("!F;VYT+7-I>F4Z(#$Q<'@[
M"GT*=&0@>PH@("`@9F]N="US:7IE.B`Q,G!X.PH@("`@9F]N="UF86UI;'DZ
M($=E;F5V82Q!<FEA;"Q(96QV971I8V$L<V%N<RUS97)I9CL*?0IU;"YL:6YE
M9%)O=R!["B`@("!L:7-T+7-T>6QE+71Y<&4Z(&YO;F4["GT*+FQI;F5D4F]W
M+"!T<BYL:6YE9%)O=R!T9"P@=&%B;&4N;&EN9612;W<@=&0L('5L+FQI;F5D
M4F]W(&QI('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9#H@(V9F
M9CL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C9&1D.PI]"G1A8FQE
M+FQI;F5D4F]W+"!U;"YL:6YE9%)O=R!["B`@("!B;W)D97(M8F]T=&]M.B!N
M;VYE.PI]"BYL:6YE9%)O=U-E;&5C=&5D0V]L+"!T9"YL:6YE9%)O=U-E;&5C
M=&5D0V]L+"!T86)L92YL:6YE9%)O=R!T9"YL:6YE9%)O=U-E;&5C=&5D0V]L
M('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9#H@(V8S9C-F,SL*
M("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C9&1D.PI]"BYS96QE8W1E
M9%)O=RP@='(N<V5L96-T9612;W<@=&0@>PH@("`@8F%C:V=R;W5N9#H@(V9F
M8SL*?0HN<V5L96-T9612;W<Z:&]V97(L('1R+G-E;&5C=&5D4F]W('1D.FAO
M=F5R+"`N<V5L96-T9612;W<M;W9E<BP@='(N<V5L96-T9612;W<M;W9E<B!T
M9"!["B`@("!B86-K9W)O=6YD.B`C9F9D.PI]"G1A8FQE+FYO<&%D9&EN9R!T
M9"P@=&%B;&4N;F]P861D:6YG('1H('L*("`@('!A9&1I;F<Z(#`["GT*+G-O
M<G1U<"!["B`@("!B86-K9W)O=6YD.B`C8F)C8F9F('5R;"@B9W)A<&AI8W,O
M>F$N<&YG(BD@8V5N=&5R(&QE9G0@;F\M<F5P96%T.PH@("`@<&%D9&EN9RUL
M969T.B`Q,'!X.PI]"BYS;W)T9&]W;B!["B`@("!B86-K9W)O=6YD.B`C8F)C
M8F9F('5R;"@B9W)A<&AI8W,O87HN<&YG(BD@8V5N=&5R(&QE9G0@;F\M<F5P
M96%T.PH@("`@<&%D9&EN9RUL969T.B`Q,'!X.PI]"B\J($%L=&5R;F%T:6YG
M('-T>6QE<RX@:71E;3`L(&ET96TQ(&%R92!D97!R96-A=&5D+B`J+PHN<W1R
M:7!E9"P@+G)O=T5V96XL("YI=&5M,"!["B`@("!B86-K9W)O=6YD.B`C965E
M.PI]"BYR;W=/9&0L("YI=&5M,2!["B`@("!B86-K9W)O=6YD.B`C9&1D.PI]
M"@HN=VED9V5T('L*("`@(&9O;G0M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC
M82QS86YS+7-E<FEF.PH@("`@9F]N="US:7IE.B`Q,7!X.PI]"@HN;6EM95-T
M871U<TUE<W-A9V4@>PH@("`@<&%D9&EN9SH@,7!X.PH@("`@;6%R9VEN+6)O
M='1O;3H@-'!X.PH@("`@8F]R9&5R.B`Q<'@@9&%S:&5D(",P,&,["B`@("!B
M86-K9W)O=6YD.B`C965F.PH@("`@8V]L;W(Z(",P,#8["GT*+FUI;653=&%T
M=7-787)N:6YG('L*("`@('!A9&1I;F<Z(#%P>#L*("`@(&UA<F=I;BUB;W1T
M;VTZ(#1P>#L*("`@(&)O<F1E<CH@,7!X(&1A<VAE9"`C9C`P.PH@("`@8F%C
M:V=R;W5N9#H@(V9F9#!A9CL*("`@(&-O;&]R.B`C9C`P.PI]"@HN;&EG:'0@
M>PH@("`@8V]L;W(Z("-F9F8["B`@("!F;VYT+69A;6EL>3H@1V5N979A+$%R
M:6%L+$AE;'9E=&EC82QS86YS+7-E<FEF.PH@("`@9F]N="US:7IE.B`Q,G!X
M.PI]"BYS;6%L;&AE861E<B!["B`@("!F;VYT+69A;6EL>3H@1V5N979A+$%R
M:6%L+$AE;'9E=&EC82QS86YS+7-E<FEF.PH@("`@9F]N="US:7IE.B`Q,G!X
M.PH@("`@9F]N="UW96EG:'0Z(&)O;&0["GT*<VUA;&PL("YS;6%L;"!["B`@
M("!F;VYT+7-I>F4Z(#$P<'@["GT*+F-O;G1R;VP@>PH@("`@8V]L;W(Z(",P
M,#`["B`@("!B86-K9W)O=6YD.B`C8V-C.PH@("`@8F]R9&5R+6)O='1O;3H@
M,7!X('-O;&ED(",Y.3D["GT*+FET96T@>PH@("`@8V]L;W(Z(",P,#`["B`@
M("!B86-K9W)O=6YD.B`C965E.PI]"BYA8V-E<W-+97D@>PH@("`@=&5X="UD
M96-O<F%T:6]N.B!U;F1E<FQI;F4["GT*+G1E>'0@>PH@("`@8V]L;W(Z(",P
M,#`["B`@("!B86-K9W)O=6YD.B`C9F9F.PI]"@HO*B!&;W)M('-T>6QE<RX@
M*B\*+F9O<FT@=&%B;&4@>PH@("`@=VED=&@Z(#$P,"4["B`@("!P861D:6YG
M.B`R<'@["B`@("!B;W)D97(M8V]L;&%P<V4Z(&-O;&QA<'-E.PI]"BYH=&UL
M87)E82`N<W1A='5S0F%R("YS=&%T=7-"87)4<F5E(&$@>PH@("`@9F]N=#H@
M:6YH97)I=#L*?0HN:'1M;&%R96$@=&%B;&4@>PH@("`@=VED=&@Z(&%U=&\[
M"GT*+F9O<FTM97)R;W(@>PH@("`@8V]L;W(Z("-F,#`["GT*:6YP=70L('-E
M;&5C="!["B`@("!F;VYT+69A;6EL>3H@1V5N979A+$%R:6%L+$AE;'9E=&EC
M82QS86YS+7-E<FEF.PH@("`@9F]N="US:7IE.B`Q,G!X.PH@("`@9F]N="UW
M96EG:'0Z(&YO<FUA;#L*?0II;G!U="!["B`@("!P861D:6YG.B`Q<'@["GT*
M;W!T:6]N('L*("`@('!A9&1I;F<Z(#!P>"`U<'@@,'!X(#-P>#L*?0HN8VAE
M8VMB;W@@>PH@("`@8F]R9&5R.B`P.PH@("`@:&5I9VAT.B`Q-'!X.PH@("`@
M=VED=&@Z(#$T<'@["B`@("!B86-K9W)O=6YD.B!T<F%N<W!A<F5N=#L*?0HN
M8G5T=&]N('L*("`@(&9O;G0M<VEZ93H@,3%P>#L*("`@(&9O;G0M9F%M:6QY
M.B!697)D86YA+$AE;'9E=&EC82QS86YS+7-E<FEF.PI]"F$N8G5T=&]N('L*
M("`@('!A9&1I;F<Z(#)P>#L*("`@(&9O;G0M=V5I9VAT.B!N;W)M86P["B`@
M("!T97AT+61E8V]R871I;VXZ(&YO;F4["GT*"BYF:7AE9"!["B`@("!F;VYT
M+7-I>F4Z(#$S<'@["B`@("!F;VYT+69A;6EL>3H@;6]N;W-P86-E+&9I>&5D
M.PI]"@HO*B!3='EL97,@9F]R(&5M86EL+6QI:V4@;65S<V%G97,N("HO"BYS
M:6=N871U<F4@>PH@("`@8V]L;W(Z("-C8V,["GT*+G-I9VYA='5R92UF:7AE
M9"!["B`@("!C;VQO<CH@(V-C8SL*("`@(&9O;G0M<VEZ93H@,3-P>#L*("`@
M(&9O;G0M9F%M:6QY.B!M;VYO<W!A8V4L9FEX960["GT*+F-I=&%T:6]N('L*
M("`@(&UA<F=I;CH@,65M(#`["B`@("!P861D:6YG+6QE9G0Z(#%E;3L*("`@
M(&)O<F1E<BUL969T+7=I9'1H.B`Q<'@["B`@("!B;W)D97(M;&5F="US='EL
M93H@<V]L:60["GT*+G%U;W1E9#$@>PH@("`@8V]L;W(Z(",V,#8["B`@("!B
M;W)D97(M;&5F="UC;VQO<CH@(S8P-CL*?0HN<75O=&5D,B!["B`@("!C;VQO
M<CH@(S`W-SL*("`@(&)O<F1E<BUL969T+6-O;&]R.B`C,#<W.PI]"BYQ=6]T
M960S('L*("`@(&-O;&]R.B`C.3`P.PH@("`@8F]R9&5R+6QE9G0M8V]L;W(Z
M(",Y,#`["GT*+G%U;W1E9#0@>PH@("`@8V]L;W(Z(",P,#D["B`@("!B;W)D
M97(M;&5F="UC;VQO<CH@(S`P.3L*?0HN<75O=&5D-2!["B`@("!C;VQO<CH@
M(V(V,#L*("`@(&)O<F1E<BUL969T+6-O;&]R.B`C8C8P.PI]"@HO*B!687)I
M;W5S('!O<'5P(&%N9"!S=&%T=7,@;&%Y97)S+B`J+PHN;F]T:6-E('L*("`@
M(&9O;G0M=V5I9VAT.B!B;VQD.PH@("`@8V]L;W(Z(",P,#`["B`@("!B86-K
M9W)O=6YD.B`C9F9C.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(V%A83L*("`@
M('!A9&1I;F<Z(#%P>#L*("`@('!A9&1I;F<M;&5F=#H@-7!X.PH@("`@;6%R
M9VEN+6)O='1O;3H@,7!X.PH@("`@+6UO>BUB;W)D97(M<F%D:75S.B`X<'@[
M"GT*+G1O;VQT:7`L(&1I=BYN:6-E=&ET;&4@>PH@("`@9F]N=#H@,3%P>"\Q
M,G!X(%9E<F1A;F$L07)I86PL<V5R:68["B`@("!C;VQO<CH@(S`P,#L*("`@
M(&)A8VMG<F]U;F0Z("-F9F,["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C,#`P
M.PH@("`@<&%D9&EN9SH@-7!X.PH@("`@+6UO>BUB;W)D97(M<F%D:75S.B`S
M<'@["GT*9&EV+FYI8V5T:71L92!["B`@("!P;W-I=&EO;CH@86)S;VQU=&4[
M"B`@("!O=F5R9FQO=SH@:&ED9&5N.PH@("`@;W!A8VET>3H@+CDP.PI]"F1I
M=BYN:6-E=&ET;&4@<')E('L*("`@(&9O;G0M9F%M:6QY.B`B3'5C:61A($-O
M;G-O;&4B+&UO;F]S<&%C92QF:7AE9#L*?0HN:6Y0<F]G<F5S<R!["B`@("!F
M;VYT.B`Q,'!X($=E;F5V82Q!<FEA;"Q(96QV971I8V$L<V%N<RUS97)I9CL*
M("`@('!A9&1I;F<Z(#)P>#L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R
M;W5N9#H@(V8P,#L*?0H*+RH@5')E92!S='EL97,N("HO"BYT<F5E4F]W('L*
M("`@(&]V97)F;&]W.B!H:61D96X["B`@("!M:6XM:&5I9VAT.B`R,'!X.PH@
M("`@8VQE87(Z(&)O=&@["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N=2![
M"B`@("!O=F5R9FQO=SH@:&ED9&5N.PH@("`@;6EN+6AE:6=H=#H@-3!P>#L*
M("`@(&9O;G0M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC82QS86YS+7-E<FEF
M.PH@("`@;6%R9VEN+6)O='1O;3H@.'!X.PI]"B-M96YU('5L('L*("`@('!A
M9&1I;F<Z(#5P>#L*?0HC;65N=2!L:2!["B`@("!L:7-T+7-T>6QE+71Y<&4Z
M(&YO;F4["B`@("!T97AT+6%L:6=N.B!C96YT97(["B`@("!M87)G:6XZ(#)P
M>#L*("`@(&9L;V%T.B!L969T.PI]"B-M96YU(&$@>PH@("`@9&ES<&QA>3H@
M8FQO8VL["B`@("!W:&ET92US<&%C93H@<')E.PH@("`@9F]N="UF86UI;'DZ
M(%9E<F1A;F$L2&5L=F5T:6-A+'-A;G,M<V5R:68["B`@("!F;VYT+7-I>F4Z
M(#$Q<'@["B`@("!T97AT+61E8V]R871I;VXZ(&YO;F4["B`@("!P861D:6YG
M.B`S<'@["B`@("`M;6]Z+6)O<F1E<BUR861I=7,Z(#-P>#L*?0HC;65N=2!H
M,2!["B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82Q(96QV971I8V$L<V%N<RUS
M97)I9CL*("`@(&9O;G0M=V5I9VAT.B!B;VQD.PH@("`@9F]N="US:7IE.B`Q
M.'!X.PH@("`@;&EN92UH96EG:'0Z(#0X<'@["B`@("!V97)T:6-A;"UA;&EG
M;CH@8F]T=&]M.PI]"B-M96YU(&EN<'5T+"`C;65N=2!S96QE8W0@>PH@("`@
M;6%R9VEN+71O<#H@,39P>#L*?0H*+RH@4VED96)A<B!S='EL97,N("HO"BYS
M:61E8F%R("-M96YU('L*("`@(&UA<F=I;CH@,#L*?0HC<VED96)A<E!A;F5L
M('L*("`@("UM;WHM8F]R9&5R+7)A9&EU<RUB;W1T;VUR:6=H=#H@,35P>#L*
M("`@('!A9&1I;F<M=&]P.B`U<'@["B`@("!P861D:6YG+6)O='1O;3H@,3!P
M>#L*("`@(&)A8VMG<F]U;F0Z("-E964["B`@("!W:&ET92US<&%C93H@;F]W
M<F%P.PI]"B-S:61E8F%R4&%N96P@<W!A;BP@(W-I9&5B87)086YE;"!A('L*
M("`@(&-O;&]R.B`C,#`P.PH@("`@=VAI=&4M<W!A8V4Z('!R93L*("`@(&9O
M;G0M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC82QS86YS+7-E<FEF.PH@("`@
M9F]N="US:7IE.B`Q,7!X.PH@("`@=&5X="UD96-O<F%T:6]N.B!N;VYE.PI]
M"B-S:61E8F%R4&%N96P@<W!A;BYT;V=G;&4@>PH@("`@8W5R<V]R.B!P;VEN
M=&5R.PI]"B-S:61E8F%R4&%N96P@83IH;W9E<B!["B`@("`M;6]Z+6)O<F1E
M<BUR861I=7,Z(#-P>#L*("`@(&-O;&]R.B`C,#`P.PI]"@HO*B!086=E<BX@
M*B\*+G!A9V5R('L*("`@('1E>'0M86QI9VXZ(&-E;G1E<CL*?0H*+RH@5&%B
M('-T>6QE<RX@*B\*+G1A8G-E="!["B`@("!F;&]A=#H@;&5F=#L*("`@('=I
M9'1H.B`Q,#`E.PH@("`@9F]N="UW96EG:'0Z(&)O;&0["B`@("!B86-K9W)O
M=6YD.B!U<FPH(F=R87!H:6-S+W1A8E]B;W1T;VTN9VEF(BD@<F5P96%T+7@@
M8F]T=&]M.PI]"BYT86)S970@=6P@>PH@("`@;6%R9VEN+71O<#H@-'!X.PH@
M("`@<&%D9&EN9RUL969T.B`Q,'!X.PH@("`@;&ES="US='EL93H@;F]N93L*
M?0HN=&%B<V5T(&QI('L*("`@(&9L;V%T.B!L969T.PH@("`@;6%R9VEN+71O
M<#H@+3-P>#L*("`@(&UA<F=I;BUL969T.B`R<'@["B`@("!W:&ET92US<&%C
M93H@;F]W<F%P.PI]"BYT86)S970@;&D@82!["B`@("!C;VQO<CH@(S`P,#L*
M("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-E.64Y93D["B`@("!P861D:6YG.B`R
M<'@@,"XU96T["B`@("!D:7-P;&%Y.B!B;&]C:SL*("`@(&)O<F1E<CH@,7!X
M('-O;&ED(",P,#`["B`@("!B;W)D97(M8F]T=&]M+6-O;&]R.B`C93EE.64Y
M.PH@("`@+6UO>BUB;W)D97(M<F%D:75S+71O<&QE9G0Z(#$P<'@["B`@("`M
M;6]Z+6)O<F1E<BUR861I=7,M=&]P<FEG:'0Z(#$P<'@["GT*+G1A8G-E="!L
M:2!A.FAO=F5R('L*("`@('1E>'0M9&5C;W)A=&EO;CH@;F]N93L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z("-F9F8["GT*+G1A8G-E="!L:2YA8W1I=F5486(@
M82!["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z(",P,#`["B`@("!C;VQO<CH@(V9F9CL*?0HN=&%B
M<V5T(&QI+F%C=&EV951A8B!A.FAO=F5R('L*?0HN=&%B<V5T(&EM9R!["B`@
M("!D:7-P;&%Y.B!B;&]C:SL*("`@(&9L;V%T.B!L969T.PH@("`@<&%D9&EN
M9RUR:6=H=#H@,G!X.PI]"@HO*B!0<F5F97)E;F-E<R!O=F5R=FEE=RX@*B\*
M+G!R969S3W9E<G9I97<@9&EV('L*("`@(&9L;V%T.B!L969T.PI]"BYP<F5F
M<T]V97)V:65W(&1I=B!D:78@>PH@("`@<&%D9&EN9RUL969T.B`Q,'!X.PH@
M("`@=VED=&@Z(#DU)3L*?0HN<')E9G-/=F5R=FEE=R!H,B!["B`@("!F;VYT
M+7-I>F4Z(#$X<'@["B`@("!F;VYT+7=E:6=H=#H@8F]L9#L*?0HN<')E9G-/
M=F5R=FEE=R!D="!A('L*("`@(&1I<W!L87DZ(&)L;V-K.PH@("`@<&%D9&EN
M9SH@,G!X.PH@("`@9F]N="UW96EG:'0Z(&)O;&0["B`@("!B;W)D97(Z(#%P
M>"!S;VQI9"`C,#`P.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",T
M-#8["B`@("!B86-K9W)O=6YD.B`C93EE.64Y.PI]"BYP<F5F<T]V97)V:65W
M(&1D('L*("`@('!A9&1I;F<Z(#)P>#L*("`@(&UA<F=I;BUB;W1T;VTZ(#$P
M<'@["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0Z("-F9F8["B`@
M("!B;W)D97(M;&5F=#H@,7!X('-O;&ED(",P,#`["B`@("!B;W)D97(M<FEG
M:'0Z(#%P>"!S;VQI9"`C,#`P.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O
M;&ED(",P,#`["GT*"B\J($)L;V-K('-T>6QE<RX@*B\*+F-U<G)E;G1";&]C
M:R!["B`@("!B;W)D97(Z(#)P>"!S;VQI9"!R960["GT*"B\J($AE;'`@<W1Y
M;&5S+B`J+PHN:&5L<"!["B`@("!B86-K9W)O=6YD.B`C9F9F.PH@("`@8V]L
M;W(Z(",P,#`["GT*+FAE;'`@:#$@>PH@("`@9F]N="US:7IE.B`Q-7!X.PH@
M("`@<&%D9&EN9RUT;W`Z(#`N-65M.PH@("`@<&%D9&EN9RUB;W1T;VTZ(#`N
M-65M.PI]"BYH96QP(&@R('L*("`@(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C
M-#0V.PH@("`@<&%D9&EN9RUT;W`Z(#%E;3L*("`@('!A9&1I;F<M8F]T=&]M
M.B`P+C5E;3L*("`@(&9O;G0M<VEZ93H@,3-P>#L*?0HN:&5L<"!P('L*("`@
M(&UA<F=I;BUL969T.B`Q96T["B`@("!M87)G:6XM<FEG:'0Z(#%E;3L*("`@
M(&UA<F=I;BUB;W1T;VTZ(#%E;3L*?0HN:&5L<"!E;2!["B`@("!D:7-P;&%Y
M.B!B;&]C:SL*("`@('!A9&1I;F<Z(#5P>#L*("`@(&UA<F=I;BUL969T.B`Q
M96T["B`@("!M87)G:6XM<FEG:'0Z(#%E;3L*("`@(&UA<F=I;BUB;W1T;VTZ
M(#%E;3L*?0HN:&5L<"!E;2YH96QP5&EP('L*("`@(&-O;&]R.B`C,#DP.PH@
M("`@8F%C:V=R;W5N9#H@(V4P9C!E,#L*?0HN:&5L<"!E;2YH96QP5V%R;B![
M"B`@("!C;VQO<CH@(SDP,#L*("`@(&)A8VMG<F]U;F0Z("-F,&4P93`["GT*
M"B\J(%-O=7)C92!M87)K=7`@<W1Y;&5S+B`J+PIT86)L92YL:6YE3G5M8F5R
M960@>PH@("`@;6%R9VEN.B`U<'@["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C
M,#`P.PI]"BYL:6YE3G5M8F5R960@=&@@>PH@("`@8F%C:V=R;W5N9#H@(V4Y
M93EE.3L*("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED("-E,&4P93`["B`@
M("!B;W)D97(M;&5F=#H@,7!X('-O;&ED("-F,V8S9C,["B`@("!P861D:6YG
M+6QE9G0Z(#$P<'@["B`@("!P861D:6YG+7)I9VAT.C$P<'@["B`@("!T97AT
M+6%L:6=N.B!R:6=H=#L*?0HN;&EN94YU;6)E<F5D('1H(&$@>PH@("`@9F]N
M="UF86UI;'DZ(&UO;F]S<&%C93L*("`@(&9O;G0M<VEZ93H@,3)P>#L*("`@
M(&QI;F4M:&5I9VAT.B`Q-G!X.PI]"BYL:6YE3G5M8F5R960@=&0@>PH@("`@
M=F5R=&EC86PM86QI9VXZ('1O<#L*("`@('=I9'1H.B`Q,#`E.PH@("`@=VAI
M=&4M<W!A8V4Z('!R93L*("`@(&)A8VMG<F]U;F0Z("-F9F8["B`@("!P861D
M:6YG+6QE9G0Z(#$P<'@["B`@("!F;VYT+69A;6EL>3H@;6]N;W-P86-E.PH@
M("`@9F]N="US:7IE.B`Q,G!X.PH@("`@=VAI=&4M<W!A8V4Z('!R93L*("`@
M(&QI;F4M:&5I9VAT.B`Q-G!X.PI]"BYP87)E;G1H97-E<R!["B`@("!C;VQO
M<CH@(S)A-CL*("`@(&9O;G0M=V5I9VAT.B!B;VQD.PI]"BYC;VUM96YT('L*
M("`@(&-O;&]R.B`C86%C.PI]"BYH=&%G('L*("`@(&-O;&]R.B`C-38Y.PH@
M("`@8F%C:V=R;W5N9#H@(V0U9#9D83L*("`@(&9O;G0M=V5I9VAT.B!B;VQD
M.PI]"BYM971A8R!["B`@("!C;VQO<CH@(S!F9CL*("`@(&)A8VMG<F]U;F0Z
M("-D-60V9&$["GT*+FED('L*("`@(&-O;&]R.B`C93@R.PH@("`@8F%C:V=R
M;W5N9#H@(V4T931E,#L*?0HN871T<B!["B`@("!C;VQO<CH@(S9A9CL*?0HN
M=F%L=64@>PH@("`@8V]L;W(Z("-D-#8["GT*+F-O;&]R('L*("`@(&-O;&]R
M.B`C9C4W.PI]"BYE;VP@>PH@("`@8V]L;W(Z(",R-F4["GT*+G5R;"!["B`@
M("!C;VQO<CH@(SDV,CL*?0HN9FEL92!["B`@("!C;VQO<CH@(S0T-#L*("`@
M(&)A8VMG<F]U;F0Z("-F930["GT*+F-L87-S('L*("`@(&9O;G0M<W1Y;&4Z
M(&ET86QI8SL*?0H*+RH@1')O<"!S:&%D;W=S+B`J+PHN9')O<%-H861O=R![
M"B`@("!F;&]A=#H@;&5F=#L*("`@(&)A8VMG<F]U;F0Z('5R;"@B9W)A<&AI
M8W,O<VAA9&]W+G!N9R(I(&YO+7)E<&5A="!B;W1T;VT@<FEG:'0@(6EM<&]R
M=&%N=#L*("`@(&)A8VMG<F]U;F0Z('5R;"@B9W)A<&AI8W,O<VAA9&]W+F=I
M9B(I(&YO+7)E<&5A="!B;W1T;VT@<FEG:'0["B`@("!M87)G:6XZ(#$P<'@@
M,"`P(#5P>#L*?0H*+F1R;W!3:&%D;W<@:6UG('L*("`@(&1I<W!L87DZ(&)L
M;V-K.PH@("`@<&]S:71I;VXZ(')E;&%T:79E.PH@("`@8F%C:V=R;W5N9#H@
M(V9F9CL*("`@(&)O<F1E<CH@,7!X('-O;&ED(",V-C8["B`@("!M87)G:6XZ
M("TS<'@@-7!X(#5P>"`M,W!X.PH@("`@<&%D9&EN9SH@,G!X.PI]"@HO*B!N
M97=S9F5E9',@*B\*"BYS:61E8F%R4&%N96P@>PH@("`@8F]R9&5R+7)I9VAT
M.B`Q<'@@<V]L:60@(S`P-CL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI
M9"`C,#`V.PH@("`@8F%C:V=R;W5N9#H@(V4Y93EF9CL*("`@(&9O;G0M9F%M
M:6QY.B!697)D86YA+$AE;'9E=&EC82QS86YS+7-E<FEF.PH@("`@9F]N="US
M:7IE.B`Q,7!X.PI]"@HN<VED96)A<DAE861E<B!["B`@8F%C:V=R;W5N9"UC
M;VQO<CH@(S9E.#ED9#L*?0H*+FAE861E<E1I=&QE('L*("!C;VQO<CH@(V9F
M9CL*("!P861D:6YG.B`S<'@@-W!X.PH@('=H:71E+7-P86-E.B!N;W=R87`[
M"B`@9F]N="UW96EG:'0Z(&)O;&0["GT*+FAE861E<D)U='1O;G,@>PH@('1E
M>'0M86QI9VXZ(')I9VAT.PI]"BYH96%D97)"=71T;VYS(&$@>PH@(&]V97)F
M;&]W.B!H:61D96X["B`@=VED=&@Z(#$V<'@["B`@:&5I9VAT.B`Q-G!X.PH@
M(&1I<W!L87DZ("UM;WHM:6YL:6YE+6)O>#L*("!D:7-P;&%Y.B!I;FQI;F4M
M8FQO8VL["B`@=F5R=&EC86PM86QI9VXZ(&UI9&1L93L*("!B86-K9W)O=6YD
M+7)E<&5A=#H@;F\M<F5P96%T.PH@(&UA<F=I;BUR:6=H=#H@-W!X.PI]"BYH
M96%D97)"=71T;VYS(&$@<W!A;B!["B`@<&%D9&EN9RUL969T.B`Q,#!P>#L*
M("!D:7-P;&%Y.B!B;&]C:SL*?0HN8G1N+7)E9G)E<V@@>PH@(&)A8VMG<F]U
M;F0M:6UA9V4Z('5R;"@G+W1H96UE<R]G<F%P:&EC<R]I;6%G92]R969R97-H
M+F=I9B<I.PI]"BY.1F-L;W-E("-N97=S1F5E9',@>PH@(&1I<W!L87DZ(&YO
M;F4["GT*+DY&;W!E;B`N8G1N+6]P96XM8VQO<V4@>PH@(&)A8VMG<F]U;F0M
M:6UA9V4Z('5R;"@G+W1H96UE<R]G<F%P:&EC<R]I;6%G92]A<G)O=RUD;W=N
M+F=I9B<I.PI]"BY.1F-L;W-E("YB=&XM;W!E;BUC;&]S92!["B`@8F%C:V=R
M;W5N9"UI;6%G93H@=7)L*"<O=&AE;65S+V=R87!H:6-S+VEM86=E+V%R<F]W
M+75P+F=I9B<I.PI]"BY.1G1I=&QE('L*9F]N="UW96EG:'0Z(&)O;&0["F1I
M<W!L87DZ(&)L;V-K.PI]"BY.1FET96T@>PID:7-P;&%Y.B!B;&]C:SL*;6%R
M9VEN+6)O='1O;3H@-7!X.PI]"BY.1G-O=7)C92!["FUA<F=I;BUR:6=H=#H@
M-7!X.PI]"BY.1G-T871U<R!["FUA<F=I;BUR:6=H=#H@-7!X.PIF;VYT+7=E
M:6=H=#H@8F]L9#L*?0HN3D9T:6UE('L*8V]L;W(Z(",S,S,["GT*(VYE=W-&
M965D<R!["G!A9&1I;F<Z(#5P>"`W<'@@-7!X(#=P>#L*?0H*"@``````````
M```````````````````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]S:6UP;&5X+P``````````````````````````````````
M````````````````````````````````````````````,#`P,#<U-0`P,#(S
M-#(W`#`P,#<V-#$`,#`P,#`P,#`P,#``,3`U,34T,S,W-S,`,#(P-C(V`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R("``8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,#``
M,#`P,#`P,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"XO=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+W-I;7!L97@O9W)A<&AI8W,O
M````````````````````````````````````````````````````````````
M```````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q
M-30S,S<W,P`P,C(T,C8`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(@(`!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P,``P,#`P,#`P````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+B]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M<VEM<&QE>"]G<F%P:&EC<R]B86-K9W)O=6YD+G!N9P``````````````````
M`````````````````````````````#`P,#`V-#0`,#`R,S0R-P`P,#`W-C0Q
M`#`P,#`P,#`P,30S`#$P-3$U-#,S-S<S`#`R-3(U,0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<B`@`&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`P`#`P,#`P,#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M`````@````0(`````(&$L>4````)<$A9<P```$@```!(`$;):SX````5241!
M5`C78WCVC.'I4X8W;QC>O0,`*VL'2XNJ#HT`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+W-I;7!L97@O:6YF
M;RYP:'``````````````````````````````````````````````````````
M```````````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`P,#$W
M-0`Q,#4Q-30S,S<W,P`P,C(R-S4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(@(`!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P,``P,#`P,#`P````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O
M=&AE;65S+W-I;7!L97@O:6YF;RYP:'`L=B`Q+C$@,C`P-"\Q,"\Q-R`Q.3HS
M,SHS-R!M9&IU:VEC($5X<"`D"B`J+PH*)'1H96UE7VYA;64@/2!?*")3:6UP
M;&5X(BD["@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````N+W5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]S:6UP;&5X+W-C<F5E;BYC<W,`````
M````````````````````````````````````````````````````````````
M,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`,#`P,#`P,#(Q-34`,3`U,34T,S,W
M-S,`,#(R-C(R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R("``8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,#``,#`P,#`P,```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]S:6UP;&5X+W-C
M<F5E;BYC<W,L=B`Q+C@N-BXT(#(P,#4O,3`O,3@@,3$Z,S0Z,C$@:F%N($5X
M<"`D"B`J+PH*8F]D>2!["B`@("!B86-K9W)O=6YD.B`C965E('5R;"AG<F%P
M:&EC<R]B86-K9W)O=6YD+G!N9RD["B`@("!S8W)O;&QB87(M8F%S92UC;VQO
M<CH@(S<S.3!B.3L*?0IH=&UL('L*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R
M.B`C-S,Y,&(Y.PI]"F$@>PH@("`@8V]L;W(Z(",S8S=A93D["GT*83IH;W9E
M<B!["B`@("!C;VQO<CH@(S%B-3=C,CL*?0IA+G=I9&=E="!["B`@("!C;VQO
M<CH@(S`P,#L*?0HN:&5A9&5R('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C
M:V=R;W5N9#H@(S<S.3!B.3L*?0HN:&5A9&5R(&$@>PH@("`@8V]L;W(Z("-F
M9F8["GT*+FQI9VAT('L*("`@(&-O;&]R.B`C-&4U9#<R.PI]"BYS;6%L;&AE
M861E<B!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z(",W,SDP
M8CD["GT*+FET96T@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V5C969F-#L*
M?0HN8G5T=&]N('L*("`@(&-O;&]R.B`C,V,W864Y.PH@("`@8F%C:V=R;W5N
M9"UC;VQO<CH@(V1D9#L*("`@(&)O<F1E<CH@,7!X('-O;&ED(",P,#`["B`@
M("!P861D:6YG.B`P(#)P>#L*?0HN8G5T=&]N.FAO=F5R('L*("`@(&-O;&]R
M.B`C9F9F.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(SDY.3L*?0IS96QE8W0@
M>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S<X031&,3L*("`@(&-O;&]R.B`C
M965E.PI]"@HO*B!-96YU('-T>6QE<RX@*B\*(VUE;G4@>PH@("`@8V]L;W(Z
M("-F9F8["B`@("!B86-K9W)O=6YD.B`C-S,Y,&(Y.PI]"B-M96YU(&$@>PH@
M("`@8V]L;W(Z("-F9F8["GT*(VUE;G4@82YC=7)R96YT('L*("`@(&)A8VMG
M<F]U;F0Z(",U.&$R9&,["GT*(VUE;G4@83IH;W9E<B!["B`@("!B86-K9W)O
M=6YD.B`C-3AA,F1C.PI]"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*(W-I9&5B
M87)086YE;"!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C965E.PH@("`@8F]R
M9&5R+7)I9VAT.B`Q<'@@<V]L:60@(SDY.3L*("`@(&)O<F1E<BUB;W1T;VTZ
M(#%P>"!S;VQI9"`C.3DY.PI]"B-E>'!A;F1"=71T;VX@>PH@("`@;6%R9VEN
M+7)I9VAT.B`Q<'@["GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"XO=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=71I;"\`
M````````````````````````````````````````````````````````````
M```````````````````````````````P,#`P-S4U`#`P,C,T,C<`,#`P-S8T
M,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<W-``P,38V,S8`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(@(`!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P,``P,#`P,#`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+B]U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]U=&EL+V)A<F-O9&4N<&AP````````````````````````
M`````````````````````````````````````````````````````#`P,#`V
M-#0`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`U,S8Q`#$P-3$U-#,S-S<T`#`R
M,#<U,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<B`@`&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`P`#`P,#`P,#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]U=&EL+V)A<F-O9&4N<&AP
M+'8@,2XQ,"XQ,"XS(#(P,#8O,#$O,#$@,C$Z,CDZ,3<@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%
M7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXG*3L*<F5Q=6ER95]O
M;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]C;W)E+G!H<"<["G)E<75I<F5?;VYC
M92`G2&]R9&4O26UA9V4N<&AP)SL*"B\O($=E="!T97AT+"!U<'!E<F-A<V4L
M(&%D9"!S=&%R="]S=&]P(&-H87)A8W1E<G,N"B1T97AT(#T@571I;#HZ9V5T
M1F]R;41A=&$H)V)A<F-O9&4G+"`G=&5S="<I.PHD=&5X="`](%-T<FEN9SHZ
M=7!P97(H)'1E>'0L('1R=64I.PHD=&5X="`]("(J)'1E>'0J(CL*)'1E>'1L
M96X@/2!S=')L96XH)'1E>'0I.PH*)&AE:6=H="`](%5T:6PZ.F=E=$9O<FU$
M871A*"=H)RP@-#`I.PHD=&AI;G=I9'1H(#T@571I;#HZ9V5T1F]R;41A=&$H
M)W<G+"`R*3L*)'1H:6-K=VED=&@@/2`D=&AI;G=I9'1H("H@,SL*)'=I9'1H
M(#T@)'1E>'1L96X@*B`H-R`J("1T:&EN=VED=&@@*R`S("H@)'1H:6-K=VED
M=&@I("T@)'1H:6YW:61T:#L*"B1C;V1I;F=M87`@/2!A<G)A>2@G,"<@/3X@
M)S`P,#$Q,#$P,"<L("<Q)R`]/B`G,3`P,3`P,#`Q)RP*("`@("`@("`@("`@
M("`@("`@("<R)R`]/B`G,#`Q,3`P,#`Q)RP@)S,G(#T^("<Q,#$Q,#`P,#`G
M+"`G-"<@/3X@)S`P,#$Q,#`P,2<L"B`@("`@("`@("`@("`@("`@("`G-2<@
M/3X@)S$P,#$Q,#`P,"<L("<V)R`]/B`G,#`Q,3$P,#`P)RP@)S<G(#T^("<P
M,#`Q,#`Q,#$G+`H@("`@("`@("`@("`@("`@("`@)S@G(#T^("<Q,#`Q,#`Q
M,#`G+"`G.2<@/3X@)S`P,3$P,#$P,"<L("=!)R`]/B`G,3`P,#`Q,#`Q)RP*
M("`@("`@("`@("`@("`@("`@("=")R`]/B`G,#`Q,#`Q,#`Q)RP@)T,G(#T^
M("<Q,#$P,#$P,#`G+"`G1"<@/3X@)S`P,#`Q,3`P,2<L"B`@("`@("`@("`@
M("`@("`@("`G12<@/3X@)S$P,#`Q,3`P,"<L("=&)R`]/B`G,#`Q,#$Q,#`P
M)RP@)T<G(#T^("<P,#`P,#$Q,#$G+`H@("`@("`@("`@("`@("`@("`@)T@G
M(#T^("<Q,#`P,#$Q,#`G+"`G22<@/3X@)S`P,3`P,3$P,"<L("=*)R`]/B`G
M,#`P,#$Q,3`P)RP*("`@("`@("`@("`@("`@("`@("=+)R`]/B`G,3`P,#`P
M,#$Q)RP@)TPG(#T^("<P,#$P,#`P,3$G+"`G32<@/3X@)S$P,3`P,#`Q,"<L
M"B`@("`@("`@("`@("`@("`@("`G3B<@/3X@)S`P,#`Q,#`Q,2<L("=/)R`]
M/B`G,3`P,#$P,#$P)RP@)U`G(#T^("<P,#$P,3`P,3`G+`H@("`@("`@("`@
M("`@("`@("`@)U$G(#T^("<P,#`P,#`Q,3$G+"`G4B<@/3X@)S$P,#`P,#$Q
M,"<L("=3)R`]/B`G,#`Q,#`P,3$P)RP*("`@("`@("`@("`@("`@("`@("=4
M)R`]/B`G,#`P,#$P,3$P)RP@)U4G(#T^("<Q,3`P,#`P,#$G+"`G5B<@/3X@
M)S`Q,3`P,#`P,2<L"B`@("`@("`@("`@("`@("`@("`G5R<@/3X@)S$Q,3`P
M,#`P,"<L("=8)R`]/B`G,#$P,#$P,#`Q)RP@)UDG(#T^("<Q,3`P,3`P,#`G
M+`H@("`@("`@("`@("`@("`@("`@)UHG(#T^("<P,3$P,3`P,#`G+"`G("<@
M/3X@)S`Q,3`P,#$P,"<L("<D)R`]/B`G,#$P,3`Q,#`P)RP*("`@("`@("`@
M("`@("`@("`@("<E)R`]/B`G,#`P,3`Q,#$P)RP@)RHG(#T^("<P,3`P,3`Q
M,#`G+"`G*R<@/3X@)S`Q,#`P,3`Q,"<L"B`@("`@("`@("`@("`@("`@("`G
M+2<@/3X@)S`Q,#`P,#$P,2<L("<N)R`]/B`G,3$P,#`P,3`P)RP@)R\G(#T^
M("<P,3`Q,#`P,3`G*3L*"B1I;6%G92`]("9(;W)D95]);6%G93HZ9F%C=&]R
M>2A5=&EL.CIG971&;W)M1&%T82@G='EP92<L("=P;F<G*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=T96UP)R`]/B!(;W)D93HZ
M9V5T5&5M<$1I<B@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W=I9'1H)R`]/B`D=VED=&@L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G:&5I9VAT)R`]/B`D:&5I9VAT+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V)A8VMG<F]U;F0G(#T^
M("=W:&ET92<I*3L*"B1X<&]S(#T@,#L*9F]R("@D:61X(#T@,#L@)&ED>"`\
M("1T97AT;&5N.R`D:61X*RLI('L*("`@("1C:&%R(#T@<W5B<W1R*"1T97AT
M+"`D:61X+"`Q*3L*("`@("\O($UA:V4@=6YK;F]W;B!C:&%R<R!A("<M)RX*
M("`@(&EF("@A:7-S970H)&-O9&EN9VUA<%LD8VAA<ETI*2!["B`@("`@("`@
M)&-H87(@/2`G+2<["B`@("!]"B`@("!F;W(@*"1B87(@/2`P.R`D8F%R(#P]
M(#@[("1B87(K*RD@>PH@("`@("`@("1E;&5M96YT=VED=&@@/2`D8V]D:6YG
M;6%P6R1C:&%R77LD8F%R?2`_("1T:&EC:W=I9'1H(#H@)'1H:6YW:61T:#L*
M("`@("`@("!I9B`H*"1B87(@*R`Q*2`E(#(I('L*("`@("`@("`@("`@)&EM
M86=E+3YR96-T86YG;&4H)'AP;W,L(#`L("1E;&5M96YT=VED=&@@+2`Q+"`D
M:&5I9VAT+"`G8FQA8VLG+"`G8FQA8VLG*3L*("`@("`@("!]"B`@("`@("`@
M)'AP;W,@*ST@)&5L96UE;G1W:61T:#L*("`@('T*("`@("1X<&]S("L]("1T
M:&EN=VED=&@["GT*"FAE861E<B@G4')A9VUA.B!P=6)L:6,G*3L*)&EM86=E
M+3YD:7-P;&%Y*"D["@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````N+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W5T:6PO
M:6-O;E]B<F]W<V5R+G!H<```````````````````````````````````````
M````````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V
M-#$`,#`P,#`P,#4U,C<`,3`U,34T,S,W-S0`,#(R,#4S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R("``8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,#``,#`P,#`P,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B`D
M2&]R9&4Z(&AO<F1E+W5T:6PO:6-O;E]B<F]W<V5R+G!H<"QV(#$N-"XR+C0@
M,C`P-B\P,2\P,2`R,3HR.3HQ-R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#0M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G05542%](04Y$3$52)RP@=')U
M92D["D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N
M("<O+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]C;W)E
M+G!H<"<["@HD<F5G:7-T<GD@/2`F4F5G:7-T<GDZ.G-I;F=L971O;B@I.PHD
M87!P<R`]("1R96=I<W1R>2T^;&ES=$%P<',H87)R87DH)VYO=&]O;&)A<B<L
M("=A8W1I=F4G+"`G861M:6XG+"`G:6YA8W1I=F4G+"`G:&ED9&5N)RDL('1R
M=64I.PIK<V]R="@D87!P<RD["@II9B`H*"1A<'`@/2!B87-E;F%M92A5=&EL
M.CIG971&;W)M1&%T82@G87!P)RDI*2`F)B!I<W-E="@D87!P<ULD87!P72DI
M('L*("`@("\O(%!R;W9I9&4@82!N;VXM=VAI=&4@8F%C:V=R;W5N9"!F;W(@
M97EE8F%L;&EN9R!T<F%N<W!A<F5N8WDN"B`@("!E8VAO("<\:'1M;#X\8F]D
M>2!B9V-O;&]R/2(C86%A86%A(CXG.PH*("`@("1T:&5M941I<B`]("1R96=I
M<W1R>2T^9V5T*"=T:&5M97-F<R<L("1A<'`I.PH@("`@:68@*"%I<U]D:7(H
M)'1H96UE1&ER*2D@>PH@("`@("`@(&5X:70H<W!R:6YT9BA?*")4:&5M97,@
M9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(BDL("1T:&5M941I<BDI.PH@
M("`@?0H*("`@("\O($)A<V4@9W)A<&AI8W,@9F]R(&YO=RP@9F5E;"!F<F5E
M('1O(&%D9"!T:&5M92!S=7!P;W)T+@H@("`@)&)A<V5D:7(@/2`D9&ER(#T@
M)'1H96UE1&ER("X@1$E214-43U)97U-%4$%2051/4B`N("=G<F%P:&EC<R<[
M"B`@("!I9B`H(6ES7V1I<B@D9&ER*2D@>PH@("`@("`@(&5X:70H<W!R:6YT
M9BA?*")"87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD
M+B(I+"`D9&ER*2D["B`@("!]"@H@("`@:68@*"@D<W5B9&ER(#T@8F%S96YA
M;64H571I;#HZ9V5T1F]R;41A=&$H)W-U8F1I<B<I*2DI('L*("`@("`@("`D
M9&ER("X]($1)4D5#5$]265]315!!4D%43U(@+B`D<W5B9&ER.PH@("`@("`@
M(&EF("@A:7-?9&ER*"1D:7(I*2!["B`@("`@("`@("`@(&5X:70H<W!R:6YT
M9BA?*")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB*2P@)&1I<BDI
M.PH@("`@("`@('T*("`@('T*"B`@("`O+R!"<F5A9&-R=6UB<RX*("`@(&5C
M:&\@2&]R9&4Z.FQI;FLH)VEC;VY?8G)O=W-E<BYP:'`G*2`N(%\H(D%P<&QI
M8V%T:6]N($QI<W0B*2`N("<\+V$^/&)R("\^)SL*("`@(&EF("@A96UP='DH
M)'-U8F1I<BDI('L*("`@("`@("!E8VAO($AO<F1E.CIL:6YK*"=I8V]N7V)R
M;W=S97(N<&AP/V%P<#TG("X@)&%P<"D@+B`D<F5G:7-T<GDM/F=E="@G;F%M
M92<L("1A<'`I("X@)SPO83X\8G(@+SXG.PH@("`@?0H@("`@96-H;R`G/&)R
M("\^)SL*"B`@("`O+R!3:&]W(&EC;VYS(&9O<B!A<'`N"B`@("!E8VAO("<\
M:#(^)R`N('-P<FEN=&8H7R@B26-O;G,@9F]R("5S(BDL("1R96=I<W1R>2T^
M9V5T*"=N86UE)RP@)&%P<"DI("X@*"%E;7!T>2@D<W5B9&ER*2`_("<O)R`N
M("1S=6)D:7(@.B`G)RD@+B`G/"]H,CXG.PH*"B`@("`O+R!,:7-T('-U8F1I
M<F5C=&]R:65S+@H@("`@)'-U8F1I<G,@/2!G;&]B*"1D:7(@+B!$25)%0U1/
M4EE?4T5005)!5$]2("X@)RHG+"!'3$]"7T].3%E$25(I.PH@("`@:68@*"1S
M=6)D:7)S("8F(&-O=6YT*"1S=6)D:7)S*2D@>PH@("`@("`@(&9O<F5A8V@@
M*"1S=6)D:7)S(&%S("1S=6)D:7(I('L*("`@("`@("`@("`@:68@*&)A<V5N
M86UE*"1S=6)D:7(I(#T]("=#5E,G*2!["B`@("`@("`@("`@("`@("!C;VYT
M:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E8VAO($AO<F1E.CIL
M:6YK*%5T:6PZ.F%D9%!A<F%M971E<B@G:6-O;E]B<F]W<V5R+G!H<"<L(&%R
M<F%Y*"=S=6)D:7(G(#T^(&)A<V5N86UE*"1S=6)D:7(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=A<'`G(#T^("1A<'`I*2D@+B!B87-E;F%M
M92@D<W5B9&ER*2`N("<\+V$^/&)R("\^)SL*("`@("`@("!]"B`@("`@("`@
M96-H;R`G/&)R("\^)SL*("`@('T*"B`@("`D:6UA9V5S(#T@9VQO8B@D9&ER
M("X@1$E214-43U)97U-%4$%2051/4B`N("<J+G!N9R<I.PH@("`@:68@*"1I
M;6%G97,@)B8@8V]U;G0H)&EM86=E<RDI('L*("`@("`@("!F;W)E86-H("@D
M:6UA9V5S(&%S("1P;F<I('L*("`@("`@("`@("`@96-H;R!(;W)D93HZ:6UG
M*'-T<E]R97!L86-E*"1B87-E9&ER("X@1$E214-43U)97U-%4$%2051/4BP@
M)R<L("1P;F<I+"`D<&YG+"!A<G)A>2@G:'-P86-E)R`]/B`Q,"P@)W9S<&%C
M92<@/3X@,3`I+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"1A<'`I*3L*("`@
M("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@(&5C:&\@7R@B3F\@:6-O;G,@
M9F]U;F0N(BD["B`@("!]"@H@("`@96-H;R`G/"]B;V1Y/CPO:'1M;#XG.PI]
M(&5L<V4@>PH@("`@+R\@3&ES="!A<'!S+@H@("`@9F]R96%C:"`H)&%P<',@
M87,@)&%P<"D@>PH@("`@("`@(&5C:&\@2&]R9&4Z.FQI;FLH571I;#HZ861D
M4&%R86UE=&5R*"=I8V]N7V)R;W=S97(N<&AP)RP@)V%P<"<L("1A<'`I*2`N
M("1R96=I<W1R>2T^9V5T*"=N86UE)RP@)&%P<"D@+B`G/"]A/CQB<B`O/B<[
M"B`@("!]"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"XO
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=71I;"]R96=E>%]T97-T+G!H<```
M````````````````````````````````````````````````````````````
M```````````P,#`P-C0T`#`P,C,T,C<`,#`P-S8T,0`P,#`P,#`Q,C,Q-@`Q
M,#4Q-30S,S<W-``P,C$U,C,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(@(`!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P,``P,#`P,#`P````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J(%-I;7!L92!S8W)I<'0@=&\@
M:&5L<"!W:71H(')E9V5X(&-O;G-T<G5C=&EO;B]D96)U9V=I;F<N(%!U="!I
M=`H@*B!S;VUE=VAE<F4@;VX@>6]U<B!W96)S97)V97(@86YD('!O:6YT('EO
M=7(@8G)O=W-E<B!T;R!I="X*("H*("H@0F%S960@;VXZ(&AT='`Z+R]M>69L
M=69F>61O9RYC;VTO<')O9W)A;6UI;F<O<&AP+W-C<FEP=',O<F5G97AP+G!H
M<`H@*@H@*B`D2&]R9&4Z(&AO<F1E+W5T:6PO<F5G97A?=&5S="YP:'`L=B`Q
M+C,N,3`N-"`R,#`U+S$P+S$X(#$Q.C,T.C(Q(&IA;B!%>'`@)`H@*B\*"G)E
M<75I<F4@)TAO<F1E+U5T:6PN<&AP)SL*)')E9V5X<"`](%5T:6PZ.F=E=$9O
M<FU$871A*"=R96=E>'`G*3L*)'-U8FIE8W0@/2!5=&EL.CIG971&;W)M1&%T
M82@G<W5B:F5C="<I.PHD<W5B;6ET(#T@571I;#HZ9V5T1F]R;41A=&$H)W-U
M8FUI="<I.PH*0'-E=%]T:6UE7VQI;6ET*#(I.PH*9G5N8W1I;VX@=6YH=&UL
M96YT:71I97,H)'-T<FEN9RD*>PH@("`@)'1R86YS7W1B;"`](&=E=%]H=&UL
M7W1R86YS;&%T:6]N7W1A8FQE*$A434Q?14Y4251)15,I.PH@("`@)'1R86YS
M7W1B;"`](&%R<F%Y7V9L:7`H)'1R86YS7W1B;"D["B`@("!R971U<FX@<W1R
M='(H)'-T<FEN9RP@)'1R86YS7W1B;"D["GT*"FEF("@D<W5B;6ET(#T](")4
M97-T(BD@>R`O+R!D;VEN9R!A(')E9R!E>'!R97-S:6]N('-E87)C:"`M+2!G
M970@=F%R:6%B;&5S"B`@("`D=6YE<V-A<&5D4F5G97AP(#T@=6YH=&UL96YT
M:71I97,H)')E9V5X<"D[("\O(&9O<B!S96%R8V@*("`@("1E<V-A<&5D4F5G
M97AP(#T@:'1M;&5N=&ET:65S*"1R96=E>'`I.R`O+R!F;W(@<VAO=VEN9R!O
M;B!P86=E(&%N9"!I;B!T97AT87)E80H@("`@)'1E>'0@/2`D<W5B:F5C=#L*
M("`@("1T97AT(#T@<W1R:7!S;&%S:&5S*"1T97AT*3L*("`@("1T97AT(#T@
M=6YH=&UL96YT:71I97,H)'1E>'0I.R`O+R!F;W(@<V5A<F-H"B`@("`D97-C
M87!E9%1E>'0@/2!H=&UL96YT:71I97,H)'1E>'0I.R\O(&9O<B!T97AT87)E
M80H*("`@("\O($1O('!R96=?<F5P;&%C92!O;B!S;W5R8V4L('-U8G-T:71U
M=&EN9R!M871C:&5D7W1E>'0@=VET:"!;8EUM871C:&5D7W1E>'1;+V)="B`@
M("`D:&EG:&QI9VAT961497AT(#T@<')E9U]R97!L86-E*"1U;F5S8V%P9612
M96=E>'`L("=;8EU<7#!;+V)=)RP@)'1E>'0I.PH@("`@+R\@8V]N=F5R="!H
M=&UL96YT:71I97,*("`@("1H:6=H;&EG:'1E9%1E>'0@/2!H=&UL96YT:71I
M97,H)&AI9VAL:6=H=&5D5&5X="D["B`@("`O+R!R97!L86-E(%MB72!A;F0@
M6R]B72!W:71H(&AI9VAL:6=H="X*("`@("1H:6=H;&EG:'1E9%1E>'0@/2!S
M=')?<F5P;&%C92@G6V)=)RP@)SQS<&%N(&-L87-S/2)H:6=H;&EG:'0B/B<L
M("1H:6=H;&EG:'1E9%1E>'0I.PH@("`@)&AI9VAL:6=H=&5D5&5X="`]('-T
M<E]R97!L86-E*"=;+V)=)RP@)SPO<W!A;CXG+"`D:&EG:&QI9VAT961497AT
M*3L*?0H_/@H\:'1M;#X*/&AE860^"CQT:71L93Y497-T(')E9W5L87(@97AP
M<F5S<VEO;G,\+W1I=&QE/@H\<W1Y;&4@='EP93TB=&5X="]C<W,B/@H\(2TM
M"F@Q('L*("`@(&9O;G0M<VEZ93H@;&%R9V4["GT*+F9I>&5D('L*("`@(&9O
M;G0M<VEZ93H@,3!P>#L*("`@(&9O;G0M9F%M:6QY.B!M;VYO<W!A8V4L9FEX
M960["B`@("!C;VQO<CH@(S`P,#`Y.3L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z
M("-C8V-C8V,["GT*+FYO=&5S('L*("`@(&9O;G0M<VEZ93H@<VUA;&P["B`@
M("!C;VQO<CH@(S`P,#`Y.3L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C8V-C
M8V,["GT*+FAI9VAL:6=H="!["B`@("!C;VQO<CH@(S`P,#`V-CL*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z("-F9F9F,#`["GT*+F5M<'1Y('L*("`@(&)A8VMG
M<F]U;F0M8V]L;W(Z("-F9CDY,S,*?0HM+3X*/"]S='EL93X*/&UE=&$@:'1T
M<"UE<75I=CTB0V]N=&5N="U4>7!E(B!C;VYT96YT/2)T97AT+VAT;6P[(&-H
M87)S970]:7-O+3@X-3DM,2(^"CPO:&5A9#X*/&)O9'D@8F=C;VQO<CTB(T9&
M1D9&1B(^"CQH,3Y497-T(#QA(&AR968](FAT='`Z+R]W=W<N<&AP+FYE="]M
M86YU86PO96XO<F5F+G!C<F4N<&AP(CY02%`@4F5G=6QA<B!%>'!R97-S:6]N
M($9U;F-T:6]N<R`H4&5R;"U#;VUP871I8FQE*3PO83X\+V@Q/@H\9&EV(&-L
M87-S/2)F:7AE9"(^<')E9U]M871C:%]A;&PH)'!A='1E<FXL("1S=6)J96-T
M+"`D;6%T8VAE<RP@4%)%1U]3151?3U)$15(I/"]D:78^"CQF;W)M(&YA;64]
M(F9O<FTQ(B!M971H;V0](G!O<W0B(&%C=&EO;CTB/#]P:'`@96-H;R`D7U-%
M4E9%4ELG4$A07U-%3$8G72`_/B(^"CQP/CQS=')O;F<^16YT97(@>6]U<B!R
M96=U;&%R(&5X<')E<W-I;VX@*"1P871T97)N*3H\+W-T<F]N9SX\8G(@+SX*
M/'1E>'1A<F5A(&YA;64](G)E9V5X<"(@8V]L<STB.#`B(')O=W,](C8B(&ED
M/2)R96=E>'`B/CP_<&AP(&EF*"1S=6)M:70I>V5C:&\@)&5S8V%P961296=E
M>'`[?3\^/"]T97AT87)E83X*/&)R("\^"CQS=')O;F<^16YT97(@=&5X="!T
M;R!S96%R8V@@86=A:6YS="!I;B!T:&4@=&5X=&%R96$@8F5L;W<@*"1S=6)J
M96-T*3H\+W-T<F]N9SX\8G(@+SX*/'1E>'1A<F5A(&YA;64](G-U8FIE8W0B
M(&-O;',](C@P(B!R;W=S/2(S(CX\/W!H<"!I9B@D<W5B:F5C="E[96-H;R`D
M97-C87!E9%1E>'0[?3\^/"]T97AT87)E83X*/&)R("\^"CQI;G!U="!T>7!E
M/2)S=6)M:70B(&YA;64](G-U8FUI="(@=F%L=64](E1E<W0B/@H\:6YP=70@
M='EP93TB<F5S970B(&YA;64](E)E<V5T(B!V86QU93TB4F5S970B/@H\82!H
M<F5F/2<\/W!H<"!E8VAO("1?4T525D526R=02%!?4T5,1B==(#\^)SY(;VUE
M/"]A/CQB<B`O/@H\+W`^"CPO9F]R;3X*/&AR("\^"CP_<&AP"FEF("@D<W5B
M;6ET*2![("\O(&]N;'D@<VAO=W,@=7`@;VX@<F5S=6QT<R!P86=E"B`@("!I
M9B`H<')E9U]M871C:%]A;&PH)'5N97-C87!E9%)E9V5X<"P@)'1E>'0L("1R
M97-U;'1S+"!04D5'7U-%5%]/4D1%4BDI('L@+R\@9F]U;F0@;6%T8V@*("`@
M("`@("!E8VAO(")4:&4@<F5G97AP(#QS=')O;F<^("1E<V-A<&5D4F5G97AP
M(#PO<W1R;VYG/B!M871C:&5D(5QN/'`^(CL*("`@("`@("!E8VAO("(\:#$^
M2&5R92=S('=H870@=V%S(&UA=&-H960@<V5A<F-H:6YG('1H92!T97AT('EO
M=2!E;G1E<F5D.CPO:#$^7&XB.PH@("`@("`@("1Y(#T@,#L*("`@("`@("!E
M8VAO("<\9&EV(&-L87-S/2)F:7AE9"(^)SL*("`@("`@("!F;W)E86-H("@D
M<F5S=6QT<R!A<R`D;&]O<%]R97-U;'0I('L*("`@("`@("`@("`@)'@@/2`P
M.PH@("`@("`@("`@("!F;W)E86-H("@D;&]O<%]R97-U;'0@87,@)&QO;W!?
M<F5S=6QT,BD@>PH@("`@("`@("`@("`@("`@:68@*"1X("$](#`I('L*("`@
M("`@("`@("`@("`@("`@("`O*B!);F1E;G0@<W5B<&%T=&5R;G,N("HO"B`@
M("`@("`@("`@("`@("`@("`@96-H;R`B/&)L;V-K<75O=&4^(CL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('!R:6YT9B@G)&UA=&-H97-;
M)7-=6R5S73HF;F)S<#LF;F)S<#LG+"`D>2P@)'@I.R\O('-H;W<@=F%R:6%B
M;&4@;F%M90H@("`@("`@("`@("`@("`@:68@*"$D;&]O<%]R97-U;'0R*2![
M"B`@("`@("`@("`@("`@("`@("`@96-H;R`G/'-P86X@8VQA<W,](F5M<'1Y
M(CY%;7!T>3PO<W!A;CXG.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("!E8VAO("<\<W!A;B!C;&%S<STB:&EG:&QI9VAT
M(CXG("X@:'1M;&5N=&ET:65S*"1L;V]P7W)E<W5L=#(I("X@)SPO<W!A;CXG
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1X("$]
M(#`I('L*("`@("`@("`@("`@("`@("`@("!E8VAO("(\+V)L;V-K<75O=&4^
M(CL*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@96-H;R`B/'`@+SXB.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)'@K*SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D>2LK.PH@
M("`@("`@('T*("`@("`@("!E8VAO("<\+V1I=CXG.PH@("`@?2!E;'-E('L@
M+R\@;F\@;6%T8V@*("`@("`@("!E8VAO(")R96=E>'`@/'-T<F]N9SX@)&5S
M8V%P961296=E>'`@/"]S=')O;F<^(&1O97-N)W0@<F5T=7)N(&%N>2!R97-U
M;'1S7&X\<#XB.PH@("`@?0H@("`@/SX*("`@(#QH,3Y396%R8VAE9"!T97AT
M('=I=&@@;6%T8VAE<R`\<W!A;B!C;&%S<STG:&EG:&QI9VAT)SYH:6=H;&EG
M:'1E9#PO<W!A;CX\+V@Q/@H@("`@/#]P:'`@+R\@4VAO=R!S96%R8VAE9"!T
M97AT('=I=&@@;6%T8VAE<R!H:6=H;&EG:'1E9`H@("`@96-H;R`G/'!R93XG
M.PH@("`@96-H;R`D:&EG:&QI9VAT961497AT.PH@("`@96-H;R`G/"]P<F4^
M/&AR("\^)SL*?0H_/@H*/&1I=B!C;&%S<STB;F]T97,B/@H\:#$^17AA;7!L
M92!R96=U;&%R(&5X<')E<W-I;VYS.CPO:#$^"CQP/CQS=')O;F<^>R9L=#LA
M+2TH/SHN?%QS*2H_+2TF9W0[?3PO<W1R;VYG/B9N8G-P.R`M+29N8G-P.R!3
M:&]W<R!C;VUM96YT<R!I;B!H=&UL)FYB<W`[/"]P/@H\=6P^"CQL:3X\<W1R
M;VYG/GL\+W-T<F]N9SX@;W!E;B!D96QI;6ET97(\+VQI/@H\;&D^/'-T<F]N
M9SXF;'0[(2TM/"]S=')O;F<^('-E87)C:"!F;W(@;W!E;FEN9R!C;VUM96YT
M('1A9SPO;&D^"CQL:3X\<W1R;VYG/B@_.BY\7',I*CPO<W1R;VYG/B!A;GD@
M;G5M8F5R(&]F(&-H87)A8W1E<G,@;W(@=VAI=&4@<W!A8V4\+VQI/@H\;&D^
M/'-T<F]N9SX_/"]S=')O;F<^(&YO;BUG<F5E9'D\+VQI/@H\;&D^/'-T<F]N
M9SXM+29G=#L\+W-T<F]N9SX@<V5A<F-H(&9O<B!C;&]S:6YG(&-O;6UE;G0@
M=&%G/"]L:3X*/&QI/CQS=')O;F<^?3PO<W1R;VYG/B!C;&]S92!D96QI;6ET
M97(\+VQI/@H\+W5L/@H\<#X\<W1R;VYG/GLF;'0[<W1Y;&4@='EP92@_.BY\
M7',I*C\F;'0[+W-T>6QE)F=T.WT\+W-T<F]N9SX@+2T@4VAO=W,@('-T>6QE
M<SPO<#X*/'`^3F]T97,Z/"]P/@H\=6P^"CQL:3Y4:&4@<F5S=6QT<R!P86=E
M('-H;W=S('1H92!I;F1I=FED=6%L(&UA=&-H97,@86YD('-U8G!A='1E<FX@
M;6%T8VAE<RP@86YD('1H92!O<FEG:6YA;"!T97AT('=I=&@@=&AE(&UA=&-H
M97,@:&EG:&QI9VAT960N/"]L:3X*/&QI/DUI9VAT(&YO="!B92!A8FQE('1O
M('-E87)C:"!F;W(@:'1M;"!E;G1I=&EE<R!L:6ME("(F86UP.V%M<#LB(&)E
M8V%U<V4@;V8@=&AE(&-O;G9E<G1I;F<@9F]R(&1I<W!L87D@86YD('1E>'1A
M<F5A<R`H=&AE('-E87)C:"!P871T97)N("AR96=E>'`I(&%N9"!N;VXM=7)L
M('-U8FIE8W1S(&%R92!P<F]C97-S960@8GD@=6YH=&UL96YT:71I97,I/"]L
M:3X*/"]U;#X\+V1I=CX*/"]B;V1Y/@H\+VAT;6P^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"XO=7-R+VQO8V%L+W!S82]T;7`O````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````P,#`P-S4U`#`P,C,T
M,C<`,#`P-S8T,0`P,#`P,#`P,#`P,``Q,#4Q-30S,S<W-``P,30U-S<`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(@(`!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P,``P
M,#`P,#`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+B]U<W(O
M;&]C86PO<'-A+W1M<"]H;W1F:7@M.#`P-C$P,3@N,C`O````````````````
M````````````````````````````````````````````````````````````
M`````#`P,#`W-34`,#`R,S0R-P`P,#`W-C0Q`#`P,#`P,#`P,#`P`#$P-3$U
M-#,S-S<T`#`Q-S(R-0`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<B`@`&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`P`#`P,#`P,#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````N+W5S<B]L;V-A;"]P<V$O=&UP+VAO=&9I>"TX,#`V,3`Q
M."XR,"]F:6QE;&ES=```````````````````````````````````````````
M````````````````````````````,#`P,#8T-``P,#(S-#(W`#`P,#<V-#$`
M,#`P,#`T,S$U,#,`,3`U,34T,S,W-S0`,#(P-S<Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R("``8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,#``,#`P,#`P,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"1[4%)/1%5#5%]23T]47T1]
M+V%D;6EN+VAT9&]C<R]S:VEN<R]A<75A+F-O;7!A8W0O8W-S+VEE+F-S<R!R
M;V]T(#`@,#8T-`HD>U!23T150U1?4D]/5%]$?2]A9&UI;B]H=&1O8W,O<VMI
M;G,O<&QE<VLN<V5A+V-S<R]I92YC<W,@<F]O="`P(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO861M:6XO:'1D;V-S+W-K:6YS+V%Q=6$O8W-S+VEE+F-S<R!R
M;V]T(#`@,#8T-`HD>U!23T150U1?4D]/5%]$?2]A9&UI;B]H=&1O8W,O<VMI
M;G,O<&QE<VLN<VEL=F5R+V-S<R]I92YC<W,@<F]O="`P(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO861M:6XO:'1D;V-S+W-K:6YS+VQO;F=H;W)N+F%E<F\O
M8W-S+VEE+F-S<R!R;V]T(#`@,#8T-`HD>U!23T150U1?4D]/5%]$?2]A9&UI
M;B]H=&1O8W,O<VMI;G,O<&QE<VLN=FEO;&5T+V-S<R]I92YC<W,@<F]O="`P
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO861M:6XO:'1D;V-S+W-K:6YS+VQO
M;F=H;W)N+F)L86-K+V-S<R]I92YC<W,@(')O;W0@,"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+V%D;6EN+VAT9&]C<R]S:VEN<R]W:6YX<"YB;'5E+V-S<R]I
M92YC<W,@("`@("!R;V]T(#`@,#8T-`HD>U!23T150U1?4D]/5%]$?2]A9&UI
M;B]H=&1O8W,O<VMI;G,O;&]N9VAO<FXN>65L;&]W+V-S<R]I92YC<W,@<F]O
M="`P(#`V-#0*)'M04D]$54-47U)/3U1?1'TO861M:6XO:'1D;V-S+W-K:6YS
M+W=I;GAP+FYE=RYC;VUP86-T+V-S<R]I92YC<W,@("`@("`@<F]O="`P(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO861M:6XO:'1D;V-S+W-K:6YS+W!L97-K
M."YN97<O8W-S+VEE+F-S<R`@("`@(')O;W0@,"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+V%D;6EN+VAT9&]C<R]S:VEN<R]W:6YX<"YN97<O8W-S+VEE+F-S
M<R`@("`@("!R;V]T(#`@,#8T-`HD>U!23T150U1?4D]/5%]$?2]A9&UI;B]H
M=&1O8W,O<VMI;G,O<&QE<VLN8FQU92]C<W,O:64N8W-S("`@("`@<F]O="`P
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO861M:6XO:'1D;V-S+W-K:6YS+W=I
M;GAP+F]L:79E9W)E96XO8W-S+VEE+F-S<R`@("`@("`@<F]O="`P(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO861M:6XO:'1D;V-S+W-K:6YS+W!L97-K+F-L
M87-S:6,N<VEL=F5R+V-S<R]I92YC<W,@(')O;W0@,"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+V%D;6EN+VAT9&]C<R]S:VEN<R]W:6YX<"YS:6QV97(O8W-S
M+VEE+F-S<R`@("!R;V]T(#`@,#8T-`HD>U!23T150U1?4D]/5%]$?2]A9&UI
M;B]H=&1O8W,O<VMI;G,O<&QE<VLN;F%T=7)E+V-S<R]I92YC<W,@("`@<F]O
M="`P(#`V-#0*)'M04D]$54-47U)/3U1?1'TO861M:6XO<&QI8B]C;VUM;VY?
M9G5N8RYP:'`S(')O;W0@,"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+V%D;6EN
M+W-B:6XO9FEL96UN9R!R;V]T('!S86%D;2`P-34P"B1[4%)/1%5#5%]23T]4
M7T1]+V%D;6EN+W!L:6(O8VQA<W,N0VAE8VME<BYP:'`@<F]O="`P(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO861M:6XO<&QI8B]C;&%S<RY&:6QE36%N86=E
M<BYP:'`@<F]O="`P(#`V-#0*)'M04D]$54-47U)/3U1?1'TO861M:6XO<&QI
M8B]L;V-A;&5S+V5N+553+VUE<W-A9V5S7V5N+553+G!H<"!R;V]T(#`@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]A9&UI;B]H=&1O8W,O9FEL96UA;F%G97(O
M9FEL96UA;F%G97(N<&AP(')O;W0@,"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+U-E<G9I8V5S+U=E871H97(O16IS92YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+U-E<G9I8V5S+U=E871H97(O1VQO8F%L=V5A=&AE<BYP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U-E<G9I
M8V5S+U=E871H97(O365T87(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]397)V:6-E<R]796%T:&5R+U=E
M871H97)D;W1C;VTN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]397)V:6-E<R]796%T:&5R+T-O;6UO;BYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+U-E<G9I8V5S+U=E871H97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]!<F-H:79E+U1A<BYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+T%U=&@O4T%33"]#;VUM;VXN<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]!=71H+U-!4TPO0W)A
M;4U$-2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+T%U=&@O4T%33"]$:6=E<W1-1#4N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]!=71H
M+U-!4TPO3&]G:6XN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]!=71H+U-!4TPO4&QA:6XN<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]!
M=71H+U-!4TPO06YO;GEM;W5S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O075T:"]305-,+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M0V%C:&4O0V]N=&%I;F5R+V1B+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O0V%C:&4O0V]N=&%I;F5R+VUD
M8BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+T-A8VAE+T-O;G1A:6YE<B]F:6QE+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O0V%C:&4O
M0V]N=&%I;F5R+VUS97-S:6]N+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O0V%C:&4O0V]N=&%I;F5R+W!H
M<&QI8BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+T-A8VAE+T-O;G1A:6YE<B]S:&TN<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]#86-H
M92]#;VYT86EN97(O=')I9FEL92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T-A8VAE+T-O;G1A:6YE<B]D
M8G@N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]#86-H92]%<G)O<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T-A8VAE+T9U;F-T:6]N
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O0V%C:&4O1W)A<&AI8W,N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]#86-H92](5%107U)E
M<75E<W0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]#86-H92]/=71P=70N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]#86-H92]/=71P
M=71#;VUP<F5S<VEO;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+T-A8VAE+T-O;G1A:6YE<BYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+T-A8VAE+T%P<&QI8V%T:6]N+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O0V]N<V]L92]'971O<'0N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]D;V-S+TA45%!?4F5Q=65S="]D;V-S+V5X86UP;&4N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D
M;V-S+TA45%!?4F5Q=65S="]D;V-S+V1O=VYL;V%D+7!R;V=R97-S+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O9&]C<R]$0B]D;V,O34%)3E1!24Y%4E,)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O1$(O9&]C+U-4
M05154PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O9&]C<R]$0B]D;V,O5$535$524PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]$0B]D;V,O
M241%05,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+V1O8W,O3F5T7U--5%`O9&]C<R]E>&%M<&QE<R]B87-I8RYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+V1O8W,O3F5T7U--5%`O9&]C<R]G=6ED92YT>'0)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O
M6$U,7U!A<G-E<B]E>&%M<&QE<R]X;6Q?<&%R<V5R7V9I;&4N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D
M;V-S+UA-3%]087)S97(O97AA;7!L97,O>&UL7W!A<G-E<E]H86YD;&5R+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O9&]C<R]834Q?4&%R<V5R+V5X86UP;&5S+WAM;%]P87)S97)?<VEM
M<&QE,2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+V1O8W,O6$U,7U!A<G-E<B]E>&%M<&QE<R]X;6Q?<&%R
M<V5R7W-I;7!L93$N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]087)S97(O97AA;7!L97,O
M>&UL7W!A<G-E<E]S:6UP;&4R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4&%R<V5R+V5X
M86UP;&5S+WAM;%]P87)S97)?<VEM<&QE,BYX;6P)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U!A
M<G-E<B]E>&%M<&QE<R]X;6Q?<&%R<V5R7W-I;7!L95]H86YD;&5R+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O9&]C<R]834Q?4&%R<V5R+V5X86UP;&5S+WAM;%]P87)S97)?9FEL92YX
M;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+V1O8W,O3&]G+V1O8W,O97AA;7!L97,O8V]M<&]S:71E+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O9&]C<R],;V<O9&]C<R]E>&%M<&QE<R]D:7-P;&%Y+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C
M<R],;V<O9&]C<R]E>&%M<&QE<R]E<G)O<E]L;V<N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO
M9R]D;V-S+V5X86UP;&5S+V9I;&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S+V5X
M86UP;&5S+VUA:6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S+V5X86UP;&5S+VYU
M;&PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S+V5X86UP;&5S+V]B<V5R=F5R7VUA
M:6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S+V5X86UP;&5S+W!E87)?97)R;W)?
M:&%N9&QE<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O97AA;7!L97,O<&AP7V5R
M<F]R7VAA;F1L97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S+V5X86UP;&5S+W-Q
M;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O97AA;7!L97,O<W%L:71E+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O9&]C<R],;V<O9&]C<R]E>&%M<&QE<R]S>7-L;V<N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S
M+TQO9R]D;V-S+V5X86UP;&5S+W=I;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O
M97AA;7!L97,O8V]N<V]L92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O9W5I9&4N
M='AT"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]D;V-S+T1A=&4O3$E#14Y310ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]$871E+U1/1$\)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+V1O8W,O3F5T7U523"]D;V-S+V5X86UP;&4N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+T%R
M8VAI=F5?5&%R+V1O8W,O07)C:&EV95]487(N='AT"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+U-E<G9I
M8V5S7U=E871H97(O97AA;7!L97,O;65T87(M8F%S:6,N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S
M+U-E<G9I8V5S7U=E871H97(O97AA;7!L97,O;65T87(M97AT96YS:79E+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O9&]C<R]397)V:6-E<U]796%T:&5R+V5X86UP;&5S+W=E871H97(N
M8V]M+6)A<VEC+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]397)V:6-E<U]796%T:&5R+V5X86UP
M;&5S+W=E871H97(N8V]M+65X=&5N<VEV92YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O4V5R=FEC
M97-?5V5A=&AE<B]E>&%M<&QE<R]E:G-E+6)A<VEC+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]3
M97)V:6-E<U]796%T:&5R+V5X86UP;&5S+V=L;V)A;'=E871H97(M8F%S:6,N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]D;V-S+UA-3%]5=&EL+V5X86UP;&5S+V5X86UP;&4R+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O9&]C<R]834Q?571I;"]E>&%M<&QE<R]E>&%M<&QE+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C
M<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F5!;F1%;F-O9&4N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ
M94%R<F%Y5VET:$]B:F5C=',N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R
M+V5X86UP;&5S+W-E<FEA;&EZ94-$871A+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R
M:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F5%;7!T>4%R<F%Y+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F5);F1E>&5D
M07)R87DN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W-E
M<FEA;&EZ94EN9&5X961!<G)A>5=I=&A#;VYT97AT+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]8
M34Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F5.=6QL4')O<&5R=&EE
M<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O<V5R:6%L
M:7IE3V)J96-T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE
M<R]S97)I86QI>F521$8N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X
M86UP;&5S+W-E<FEA;&EZ95-E;&5C=&EV94%T=')I8G5T97,N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D
M;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ95=I=&A!='1R
M:6)U=&5S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S
M97)I86QI>F57:71H071T<FEB=71E<S(N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I
M86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ95=I=&A#;VUM96YT+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]E>&%M<&QE+GAM;`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F57:71H1'1D
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI
M>F57:71H26YD96YT961!='1R:6)U=&5S+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R
M:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F57:71H3F%M97-P86-E+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F57:71H
M5&%G36%P+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]U
M;G-E<FEA;&EZ94%N>5A-3"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O
M97AA;7!L97,O=6YS97)I86QI>F5#;&%S<TYA;65S+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]8
M34Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]U;G-E<FEA;&EZ945N8V]D960N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W5N<V5R:6%L:7IE
M16YU;2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O=6YS
M97)I86QI>F5/8FIE8W0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X
M86UP;&5S+W5N<V5R:6%L:7IE4D1&+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L
M:7IE<B]E>&%M<&QE<R]U;G-E<FEA;&EZ95=H:71E<W!A8V4N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D
M;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W5N<V5R:6%L:7IE5VET:$%T
M=')I8G5T97,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S
M+W5N<V5R:6%L:7IE5VET:%1A9TUA<"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA
M;&EZ97(O97AA;7!L97,O=6YS97)I86QI>F57:71H5'EP94=U97-S:6YG+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F5!
M;F12971U<FXN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]A='1A8VAM96YT
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O9&]C<R]33T%0+V5X86UP;&4O8V]M7V-L:65N="YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+V1O8W,O4T]!4"]E>&%M<&QE+V1I<V-O7W-E<G9E<BYP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O
M4T]!4"]E>&%M<&QE+V5M86EL7V-L:65N="YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E
M>&%M<&QE+V5M86EL7V=A=&5W87DN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L
M92]E;6%I;%]P;W!?9V%T97=A>2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE
M+V5M86EL7W!O<%]S97)V97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]E
M;6%I;%]S97)V97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]E>&%M<&QE
M7W-E<G9E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE+V5X86UP;&5?='EP
M97,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]S97)V97(N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D
M;V-S+U-/05`O97AA;7!L92]S97)V97(R+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X
M86UP;&4O<VUT<"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE+W-T;V-K<75O
M=&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]T8W!?8VQI96YT+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O9&]C<R]33T%0+V5X86UP;&4O=&-P7V1A96UO;BYP;`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]3
M3T%0+V5X86UP;&4O=&-P7W-E<G9E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M
M<&QE+W=S9&Q?8VQI96YT+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X86UP;&4O8VQI
M96YT+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O9&]C<R].971?1E10+V5X86UP;&4O:6YD97@N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]D;V-S+TYE=%]&5%`O97AA;7!L92]O8G-E<G9E<BYP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O
M3F5T7T944"]E>&%M<&QE+V5X=&5N<VEO;G,N:6YI"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D871A+U!%05(O
M=&5M<&QA=&4N<W!E8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O9&%T82]014%2+W!A8VMA9V4N9'1D"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D
M871A+TUA:6Q?36EM92]X;6%I;"YX<VP)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1A=&$O36%I;%]-:6UE+WAM
M86EL+F1T9`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O9&%T82],;V<O;6ES8R]L;V<N<W%L"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D871A+U-E
M<G9I8V5S7U=E871H97(O:6UA9V5S+W-U;G-E="YG:68)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1A=&$O4V5R
M=FEC97-?5V5A=&AE<B]I;6%G97,O<W5N<FES92YG:68)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1A=&$O4V5R
M=FEC97-?5V5A=&AE<B]B=6EL9$UE=&%R1$(N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D871A+UA-3%]3
M97)I86QI>F5R+V1O8R]T;V1O+G1X=`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&%T82]#86-H92]#;VYT86EN
M97(O;61B7V-A8VAE7W-C:&5M82YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+UA-3"]24$,O4V5R=F5R+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O6$U,+U)00R]$=6UP+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O6$U,+U!A<G-E<B]3:6UP;&4N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]834PO4&%R<V5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O6$U,+U5T:6PN<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]8
M34PO56YS97)I86QI>F5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O6$U,+U-E<FEA;&EZ97(N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]834PO4E!#+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O1$(O8V]M;6]N+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O1$(O9F)S<6PN
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]$0B]I8F%S92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+T1"+VEF>"YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T1"+VUS
M<6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]$0B]M<W-Q;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T1"+VUY<W%L+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M1$(O;7ES<6QI+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O1$(O;V-I."YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T1"+V]D8F,N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]$0B]P9W-Q;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+T1"+W-Y8F%S92YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T1"+W-T
M;W)A9V4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]$0B]S<6QI=&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]$0B]D8F%S92YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+TQO9R]C;VUP;W-I=&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B],;V<O9&%E;6]N+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M3&]G+V1I<W!L87DN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B],;V<O97)R;W)?;&]G+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O3&]G
M+V9I;&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B],;V<O;6%I;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+TQO9R]M8V%L+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O3&]G+VUD8C(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B],;V<O;G5L;"YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+TQO9R]O8G-E
M<G9E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+TQO9R]S<6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B],;V<O<W%L:71E+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O3&]G+W-Y<VQO9RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+TQO9R]W:6XN<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B],;V<O8V]N
M<V]L92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+U-/05`O5')A;G-P;W)T+U--5%`N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]33T%0
M+U1R86YS<&]R="]40U`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]33T%0+U1R86YS<&]R="](5%10+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O4T]!4"]397)V97(O5$-0+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4T]!4"]397)V97(O16UA
M:6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]33T%0+U-E<G9E<B]%;6%I;%]'871E=V%Y+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M4T]!4"]4>7!E+V1U<F%T:6]N+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4T]!4"]4>7!E+VAE>$)I;F%R
M>2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+U-/05`O5'EP92]D871E5&EM92YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U-/05`O=&]O
M;',O9V5N<')O>'DN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]33T%0+U-E<G9E<BYP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U-/05`O
M5')A;G-P;W)T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O4T]!4"]686QU92YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U-/05`O5U-$
M3"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+U-/05`O0VQI96YT+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4T]!4"]"87-E+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O4T]!4"]$:7-C;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+U-/05`O1F%U;'0N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]33T%0
M+U!A<G-E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+T1A=&4O2'5M86XN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]$871E+U-P86XN
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]$871E+U1I;65:;VYE+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O1&%T92]#86QC+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O4$A056YI="]'54DO2%1-3"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!(4%5N:70O1U5)+TA434PN
M='!L"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]02%!5;FET+T=522]3971U<$1E8V]R871O<BYP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!(
M4%5N:70O1U5)+T=T:RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+U!(4%5N:70O4F5P96%T961497-T+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O4$A056YI="]3:V5L971O;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!(4%5N:70O5&5S=$-A
M<V4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]02%!5;FET+U1E<W1$96-O<F%T;W(N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]02%!5
M;FET+U1E<W1&86EL=7)E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$A056YI="]497-T3&ES=&5N97(N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]02%!5;FET+U1E<W1297-U;'0N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]02%!5;FET+U1E
M<W13=6ET92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+U!(4%5N:70O07-S97)T+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O1FEL92]#
M4U8N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]&:6QE+U5T:6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T1O=VYL;V%D97(O
M4&%C:V%G92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+U!%05(O5&%S:R]5;FEX96]L+W)W+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M4$5!4B]487-K+U=I;F1O=W-E;VPO<G<N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+U1A<VLO4F5P
M;&%C92]R=RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+U!%05(O5&%S:R]0;W-T:6YS=&%L;'-C<FEP="]R
M=RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+U!%05(O5&%S:R]#;VUM;VXN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+U1A<VLO
M4&]S=&EN<W1A;&QS8W)I<'0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+U1A<VLO4F5P;&%C92YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+U!%05(O5&%S:R]5;FEX96]L+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]487-K+U=I
M;F1O=W-E;VPN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]014%2+U9A;&ED871O<B]014-,+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M4$5!4B]#;VUM86YD+U!A8VMA9V4N<&AP+F]R:6<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N
M9"]"=6EL9"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]"=6EL9"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%
M05(O0V]M;6%N9"]#:&%N;F5L<RYX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]#:&%N
M;F5L<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]#;VUM;VXN<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2
M+T-O;6UA;F0O0V]N9FEG+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+T-O;F9I9RYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+U!%05(O0V]M;6%N9"]);G-T86QL+GAM;`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM
M86YD+TEN<W1A;&PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O4&%C:V%G92YX;6P)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+U!%05(O0V]M;6%N9"]086-K86=E+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD
M+U!I8VML92YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]0:6-K;&4N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]0
M14%2+T-O;6UA;F0O4F5G:7-T<GDN>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O4F5G
M:7-T<GDN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O4F5M;W1E+GAM;`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!
M4B]#;VUM86YD+U)E;6]T92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]-:7)R;W(N
M>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]014%2+T-O;6UA;F0O36ER<F]R+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM
M86YD+U1E<W0N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O5&5S="YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%
M05(O0V]M;6%N9"]!=71H+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+T%U=&@N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]014%2+U)%4U0O,3$N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+U)%4U0O,3`N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]014%2+T9R;VYT96YD+T-,22YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O26YS=&%L;&5R+U)O
M;&4O0V]M;6]N+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]$871A+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]$;V,N>&UL"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+TEN
M<W1A;&QE<B]2;VQE+T1O8RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O26YS=&%L;&5R+U)O;&4O
M17AT+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]%>'0N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]0
M14%2+TEN<W1A;&QE<B]2;VQE+U!H<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O26YS=&%L;&5R
M+U)O;&4O4&AP+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]38W)I<'0N
M>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]014%2+TEN<W1A;&QE<B]2;VQE+U-C<FEP="YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%
M05(O26YS=&%L;&5R+U)O;&4O4W)C+GAM;`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(O
M4F]L92]3<F,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A;&QE<B]2;VQE+U1E<W0N>&UL
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]014%2+TEN<W1A;&QE<B]2;VQE+U1E<W0N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+TEN
M<W1A;&QE<B]2;VQE+T1A=&$N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A;&QE<B]2;VQE
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O4$5!4B]086-K86=E1FEL92]'96YE<F%T;W(O=C(N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]014%2+U!A8VMA9V5&:6QE+T=E;F5R871O<B]V,2YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O
M4&%C:V%G949I;&4O4&%R<V5R+W8R+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]086-K86=E1FEL
M92]087)S97(O=C$N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+U!A8VMA9V5&:6QE+W8R+W)W+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O4$5!4B]086-K86=E1FEL92]V,B]686QI9&%T;W(N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]0
M14%2+U!A8VMA9V5&:6QE+W8R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]086-K86=E1FEL92]V
M,2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+U!%05(O0VAA;FYE;$9I;&4O4&%R<V5R+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!
M4B]$;W=N;&]A9&5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]%<G)O<E-T86-K+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M4$5!4B]%>&-E<'1I;VXN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T9R;VYT96YD+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M4$5!4B]);G-T86QL97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+U)E;6]T92YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%
M05(O4&%C:V%G97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+U!A8VMA9V5&:6QE+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M4$5!4B]296=I<W1R>2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O4D535"YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O
M4G5N5&5S="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+U!%05(O5F%L:61A=&4N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+UA-
M3%!A<G-E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+U!%05(O0G5I;&1E<BYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O075T
M;VQO861E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+U!%05(O0VAA;FYE;$9I;&4N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2
M+T-O;6UA;F0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UO;BYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O0V]N
M9FEG+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O4$5!4B]$97!E;F1E;F-Y+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]$97!E
M;F1E;F-Y1$(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]014%2+T1E<&5N9&5N8WDR+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O3U,O
M1W5E<W,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]T97-T<R]834Q?4&%R<V5R+W1E<W1S+S`P-2YP:'!T
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]834Q?4&%R<V5R+W1E<W1S+S`P,RYP:'!T"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T
M<R]834Q?4&%R<V5R+W1E<W1S+S`P-"YP:'!T"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]834Q?4&%R
M<V5R+W1E<W1S+S`P,BYP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]834Q?4&%R<V5R+W1E<W1S
M+W1E<W0R+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O=&5S=',O6$U,7U!A<G-E<B]T97-T<R]T97-T,RYX
M;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+W1E<W1S+UA-3%]087)S97(O=&5S=',O,#`Q+G!H<'0)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E
M<W1S+T1"+W1E<W1S+V1R:79E<B]S971U<"YI;F,N8W9S+F]R:6<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E
M<W1S+T1"+W1E<W1S+V1R:79E<B\P,W-I;7!L97%U97)Y+G!H<'0)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E
M<W1S+T1"+W1E<W1S+V1R:79E<B\P-&YU;6-O;',N<&AP=`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O
M1$(O=&5S=',O9')I=F5R+S`U<V5Q=65N8V5S+G!H<'0)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"
M+W1E<W1S+V1R:79E<B\P-G!R97!E>&5C+G!H<'0)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E
M<W1S+V1R:79E<B\P.&%F9F5C=&5D<F]W<RYP:'!T"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T
M97-T<R]D<FEV97(O,#EN=6UR;W=S+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S
M+V1R:79E<B\Q,&5R<F]R;6%P+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R
M:79E<B\Q,71R86YS86-T:6]N<RYP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D
M<FEV97(O,3-L:6UI="YP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O
M,31F971C:&UO9&5?;V)J96-T+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R
M:79E<B\Q-7%U;W1E+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\Q
M-G1A8FQE:6YF;RYP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O,3=Q
M=65R>2YP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O,3AG970N<&AP
M=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+S$Y9V5T;&ES=&]F+G!H<'0)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B]C;VYN96-T+FEN8PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S
M=',O1$(O=&5S=',O9')I=F5R+VUK=&%B;&4N:6YC"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T
M97-T<R]D<FEV97(O;75L=&EC;VYN96-T+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S
M=',O9')I=F5R+W)U;BYC=G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B]S
M971U<"YI;F,N8W9S"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O<VMI<&EF
M+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+S`Q8V]N;F5C="YP:'!T
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O,#)F971C:"YP:'!T"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T
M97-T<R]$0B]T97-T<R]D8E]F86-T;W)Y+G!H<'0)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E
M<W1S+V1B7VES;6%N:7`N<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9&)?97)R
M;W(R+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V5R<F]R<RYI;F,)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E
M<W1S+T1"+W1E<W1S+V9E=&-H;6]D95]O8FIE8W0N:6YC"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$
M0B]T97-T<R]F971C:&UO9&5S+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O:6YC
M;'5D92YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+VQI;6ET+FEN8PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S
M=',O1$(O=&5S=',O;G5M8V]L<RYI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+VYU
M;7)O=W,N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]P<F5P97AE+FEN8PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M=&5S=',O1$(O=&5S=',O<G5N+F-V<PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O<V5Q
M=65N8V5S+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O<VEM<&QE<75E<GDN:6YC
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]$0B]T97-T<R]T<F%N<V%C=&EO;G,N:6YC"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T
M<R]$0B]T97-T<R]S:VEP:68N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D8E]E
M<G)O<BYP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D8E]P87)S961S;BYP:'!T
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]$0B]T97-T<R]I;F-L=61E+FEN8RYO<FEG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T
M<R].971?4TU44"]T97-T<R]B87-I8RYP:'!T"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R].971?4TU4
M4"]T97-T<R]C;VYF:6<N<&AP+F1I<W0)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+TYE=%]33510+W1E
M<W1S+W%U;W1E9&%T82YP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R].971?4TU44"]T97-T<R]A
M=71H+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+W1E<W1S+TUA:6PO=&5S=',O<VUT<%]E<G)O<BYP:'!T
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]-86EL+W1E<W1S+W)F8S@R,BYP:'!T"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]8
M34Q?4E!#+W1E<W1S+W1E<W1?1'5M<"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+UA-3%]24$,O
M=&5S=',O97AT<F$M;&EN97,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]834Q?4E!#+W1E<W1S
M+W!R;W1O<&]R="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P96%R+W1E<W1S+UA-3%]24$,O=&5S=',O96UP='DM
M=F%L=64N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]T97-T<R]834Q?4E!#+W1E<W1S+W1Y<&5S+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O=&5S=',O6$U,7U)00R]T97-T<R]A;&QG;W0N:6YC"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]8
M34Q?4E!#+W1E<W1S+V5M<'1Y+79A;'5E+7-T<G5C="YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S
M+TQO9R]T97-T<R]C;VUP;W-I=&4N<&AP=`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O3&]G+W1E<W1S
M+V1I<W!L87DN<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O3&]G+W1E<W1S+V5R<F]R7VQO9RYP
M:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]T97-T<R],;V<O=&5S=',O97AT<F%C="YP:'!T"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T
M<R],;V<O=&5S=',O97AT<F%C=#(N<&AP=`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O3&]G+W1E<W1S
M+V9A8W1O<GDN<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O3&]G+W1E<W1S+V9I;&4N<&AP=`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O=&5S=',O3&]G+W1E<W1S+VQE=F5L<RYP:'!T"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R],;V<O
M=&5S=',O;G5L;"YP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R],;V<O=&5S=',O<')I;W)I='DN
M<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O=&5S=',O3&]G+W1E<W1S+W-I;F=L971O;BYP:'!T"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T
M97-T<R],;V<O=&5S=',O<W%L:71E+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+TQO9R]T97-T
M<R]S<6Q?:61E;G0N<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O3&]G+W1E<W1S+V-O;G-O;&4N
M<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]C86QC+G!H<"YO<FEG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T
M97-T<R]$871E+W1E<W1S+V)U9S<R-U\R+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T
M97-T<R]B=6<W,C=?,RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1A=&4O=&5S=',O8G5G-S(W
M7S0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+V)U9SDV-RYP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E
M<W1S+T1A=&4O=&5S=',O8V%L8RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1A=&4O=&5S=',O
M=&5S='5N:70N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+W1E<W1U;FET7V1A
M=&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+W1E<W1U;FET7V1A=&5?<W!A
M;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+W1E<W1S+T1A=&4O=&5S=',O=&5S=%]C86QC+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M=&5S=',O1&%T92]T97-T<R]T97-T7V1A=&5?;65T:&]D<U]S<&%N+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O=&5S=',O1&%T92]T97-T<R]W965K<VEN;6]N=&A?-%]M;VYD87DN='AT
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]$871E+W1E<W1S+W=E96MS:6YM;VYT:%\T7W-U;F1A>2YT
M>'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+W1E<W1S+T1A=&4O=&5S=',O=V5E:W-I;FUO;G1H7W)D;5]M;VYD
M87DN='AT"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+W=E96MS:6YM;VYT:%]R9&U?
M<W5N9&%Y+G1X=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]W:VYO=&5S="YT>'0)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+W1E<W1S+T1A=&4O=&5S=',O8G5G-C<T+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T
M92]T97-T<R]B=6<W,C=?,2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S=',O0U-6
M+S`P,2YP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE+W1E<W1S+T-35B\P,#(N<&AP=`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O=&5S=',O1FEL92]T97-T<R]#4U8O,#`R+F-S=@ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1FEL
M92]T97-T<R]#4U8O,#`S+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S=',O0U-6
M+S`P,RYC<W8)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S=',O0U-6+S`P-"YP:'!T"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]T97-T<R]&:6QE+W1E<W1S+T-35B\P,#0N8W-V"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE
M+W1E<W1S+T-35B\P,#4N<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1FEL92]T97-T<R]#4U8O
M,#`U+F-S=@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O=&5S=',O1FEL92]T97-T<R]#4U8O,#`V+G!H<'0)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+W1E<W1S+T9I;&4O=&5S=',O0U-6+S`P-BYC<W8)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O
M=&5S=',O0U-6+W1E<W1S+G1X=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1FEL92]T97-T<R]#4U8O
M,#`Q+F-S=@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O=&5S=',O1FEL92]T97-T<R]T97-T+F-S=@ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S
M=',O1FEL92]T97-T<R]&:6QE5&5S="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S
M=',O<&%R<V5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O2%144"]297%U97-T+TQI<W1E;F5R+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O2%144"]297%U97-T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O36%I;"]M:6UE1&5C;V1E+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O36%I;"]S96YD;6%I;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+TUA:6PO<VUT<"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+TUA
M:6PO4D9#.#(R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O36%I;"]M:6UE4&%R="YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+TUA:6PO
M;6EM92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+TUA:6PO;6%I;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+TUA:6PO;G5L;"YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+TYE="]&5%`O3V)S97)V97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B].970O4V]C:V5T+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O3F5T+U--5%`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B].970O55),+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O3F5T+T944"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+W!E8VQC;60N<&AP+F]R:6<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+TUA:6PN<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]&:6QE
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O4$5!4BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+T1A=&4N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]02%!5;FET+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O1$(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]3>7-T96TN<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]P96%R8VUD+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O0V%C:&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]P96%R8VUD+G!H<"YO<FEG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]P96-L8VUD
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O3&]G+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+V1O8W,O0T]064E.1PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+V1O8W,O4D5!1$U%"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O9&]C<R]#
M2$%.1T53"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O9&]C<R]#3T1)3D=?4U1!3D1!4D13"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O9&]C<R]#3TY44DE"551)3D<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]D
M;V-S+T-2141)5%,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]D;V-S+TA!0TM)3D<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]D;V-S+TE.4U1!3$P)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]D;V-S+U!%4D9/
M4DU!3D-%"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O9&]C<R]314-54DE460ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+V1O8W,O5$]$3PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+V1O8W,O5%)!3E-,051)3TY3
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M9&]C<R]54$=2041)3D<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T97-T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W-I9VYU<"YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]R<&,N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]G:6XN
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O:6YD97@N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O861M:6XO;&]C86QE+V5N7U53+VAE;'`N>&UL"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O861M:6XO
M;&]C86QE+V9I7T9)+VAE;'`N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O861M:6XO;&]C86QE+VAU7TA5+VAE;'`N
M>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O861M:6XO<&5R;7,O961I="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]A9&UI;B]P97)M<R]I;F1E>"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]A9&UI;B]P97)M<R]D96QE=&4N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M861M:6XO<V5T=7`O9&EF9BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]A9&UI;B]S971U<"]C;VYF:6<N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O861M
M:6XO<V5T=7`O:6YD97@N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O861M:6XO<V5T=7`O<V-R:7!T<RYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]A9&UI
M;B]P:'!S:&5L;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]A9&UI;B]I;F1E>"YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]A9&UI;B]U<V5R+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+V%D
M;6EN+V-M9'-H96QL+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+V%D;6EN+V1A=&%T<F5E+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+V%D;6EN+W-E<W-I
M;VYS+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+V%D;6EN+W-Q;'-H96QL+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+V%D;6EN+W1E;7!L871E<RYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]A
M9&UI;B]G<F]U<',N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O:G,O=&%B;&5S+FIS"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O:G,O<W1R:7!E+FIS"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O:G,O:&]R
M9&4N:64N:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]J<R]S;W)T97(N:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]J<R]F;W)M7VAE;'!E<G,N:G,)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]J<R]H='1P
M8VQI96YT+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O:G,O:65%<V-'=6%R9"YJ<PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VIS+V9O<FU?<V5C=&EO;G,N:G,)
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]J<R]E;G1E<E]K97E?=')A
M<"YJ<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VIS+VAI9&5A8FQE+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O:G,O=&]O;'1I<"YJ<PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VIS+W!O<'5P+FIS"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O:G,O
M9F]R;5]A<W-I9VXN:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]J<R]A;'!H84EM86=E3&]A9&5R+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VIS+VAO<F1E
M+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O:G,O;W!E;E]C;VQO<G!I8VME<BYJ<PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VIS+VEM86=E+FIS"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O:G,O861D179E
M;G0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+U-Y;F--3"]$979I8V4O4WEN8S1J+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]3>6YC34PO
M1&5V:6-E+U`X,#`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+U-Y;F--3"]$979I8V4O4WEN=&AE<VES+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B]3>6YC34PO1&5V:6-E+TYO:VEA+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]3>6YC34PO0V]M;6%N
M9"]&:6YA;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O4WEN8TU,+T-O;6UA;F0O4'5T+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]3>6YC
M34PO0V]M;6%N9"]297-U;'1S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]3>6YC34PO0V]M;6%N9"]-87`N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+U-Y;F--3"]#;VUM86YD+U-Y;F-%;&5M96YT+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]3>6YC
M34PO0V]M;6%N9"]3=&%T=7,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U-Y;F--3"]#;VUM86YD+T%L97)T
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B]3>6YC34PO0V]M;6%N9"]'970N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U-Y;F--3"]#;VUM
M86YD+U-Y;F,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+U-Y;F--3"]3=&%T92YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O4WEN8TU,+T)A
M8VME;F0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+U-Y;F--3"]$979I8V4N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U-Y;F--3"]3>6YC
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B]3>6YC34PO0V]N<W1A;G1S+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]3>6YC34PO1&5V:6-E
M26YF;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L:6(O4WEN8TU,+T-O;6UA;F0N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O
M;G1S+V-O=7)I97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O;G1S+VAE;'9E=&EC86)I
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B]&:6QE+U!$1B]F;VYT<R]T:6UE<RYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O1FEL92]01$8O
M9F]N=',O>F%P9F1I;F=B871S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT<R]T:6UE
M<V(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+T9I;&4O4$1&+V9O;G1S+W1I;65S:2YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O1FEL92]0
M1$8O9F]N=',O:&5L=F5T:6-A8BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O1FEL92]01$8O9F]N=',O:&5L
M=F5T:6-A:2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O1FEL92]01$8O9F]N=',O=&EM97-B:2YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M1FEL92]01$8O9F]N=',O:&5L=F5T:6-A+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT
M<R]S>6UB;VPN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]&:6QE+T-35BYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O5&5X="]R95-4+T9O<FUA='1E<B]H=&UL+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]497AT+W)E4U0O
M4&%R<V5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B]497AT+W)E4U0O1F]R;6%T=&5R+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]497AT
M+T1I9F8O4F5N9&5R97(O:6YL:6YE+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]497AT+T1I9F8O4F5N9&5R
M97(O=6YI9FEE9"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O5&5X="]$:69F+U)E;F1E<F5R+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]4
M97AT+T1I9F8N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+U1E>'0O1FQO=V5D+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]497AT+T1I9F8S
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B]497AT+W)E4U0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+UA-3"]70EA-3"]$5$0O4WEN8TU,
M1&5V26YF+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B]834PO5T)834PO1%1$+U-Y;F--3$UE=$EN9BYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O6$U,+U="6$U,+T141"]3>6YC34PN<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+UA-3"]70EA-3"]#;VYT
M96YT2&%N9&QE<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O6$U,+U="6$U,+T141"YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O6$U,+U="
M6$U,+T141$UA;F%G97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+UA-3"]70EA-3"]%;F-O9&5R+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B]834PO5T)834PO1&5C;V1E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O6$U,+U-61RYP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O6$U,
M+U="6$U,+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G
M>2]C;W!Y+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G
M>2]D:7)E8W0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]D:7)E8W0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T
M96=Y+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U9&4R])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U9&4R])4T]7<FET
M97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+U9&4R]/8FIE8W0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U9&4R]S;6(N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U9&
M4R]'0RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L:6(O5D93+W-Q;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O5D93+VUU<W%L+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]6
M1E,O9G1P+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B]61E,O0G)O=W-E<BYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O5D93+W-Q;%]F:6QE
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B]61E,O9FEL92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L:6(O5D93+TQI<W1)=&5M+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]"
M;&]C:R]T:6UE+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]"
M;&]C:R]A8V-O=6YT+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B]";&]C:R]G;V]G;&4N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+T)L;V-K
M+W-U;G)I<V4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+T)L;V-K+VUO;VXN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M0FQO8VLO:69R86UE+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B]";&]C:R]M971A<BYP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O0FQO8VLO
M8V]L;W(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TAO<F1E+TUO8FEL92]296YD97)E<B]H=&UL+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B](;W)D92]-;V)I;&4O4F5N9&5R97(O=VUL+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-;V)I
M;&4O4F5N9&5R97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&$O;W5T;&]O:V-S=BYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O1&%T82]V8V%R9"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O1&%T82]V=&]D;RYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O1&%T82]T<W8N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&$O:6-A;&5N
M9&%R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]$871A+W9N;W1E+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]$871A
M+VEM8RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L:6(O2&]R9&4O1&%T82]C<W8N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T=R87!H
M+U!L;W0O8F%R9W)O=7!E9"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O1W)A<&@O4&QO="]B87(N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+TAO<F1E+T=R87!H+U!L;W0O8F%R<W1A8VME9"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O1W)A<&@O4&QO="]L:6YE+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]'<F%P:"]0;&]T+W-C
M871T97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TAO<F1E+T=R87!H+T-H87)T+W!I93-D+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]'<F%P:"]#:&%R="]P:64N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T=R;W5P+VQD87`N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+TAO<F1E+T=R;W5P+VAO;VMS+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]);6%G92]R
M9V(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+TEM86=E+W-V9RYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O26UA9V4O
M<W=F+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]);6%G92]G9"YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O26UA9V4O
M:6TN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+TEM86=E+W!N9RYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U!E<FUS+V1A=&%T<F5E+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]3
M97-S:6]N2&%N9&QE<B]M>7-Q;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4V5S<VEO;DAA;F1L
M97(O;F]N92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(O;&1A<"YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(O<V%P9&(N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U-E
M<W-I;VY(86YD;&5R+W-Q;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(O
M;65M8V%C:&4N<&AP"0HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+TAO<F1E+U-E<W-I;VY(86YD;&5R+V]C:3@N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U-E<W-I
M;VY(86YD;&5R+W!G<W%L+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]397-S:6]N2&%N9&QE<B]D
M8FTN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]A=61I;RYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VIA=F%S8W)I<'0N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+TAO<F1E+TYO=&EF:6-A=&EO;B]%=F5N="YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92])34%0+T%#3"]R9F,T,S$T
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92])
M34%0+T%D;6EN+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92])34%0+T%#3"YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O
M24U!4"]396%R8V@N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TE-05`O5')E92YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O24U!4"]4:')E860N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TE-05`O4V]R="YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O24U!4"]#86-H92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4')E9G,O<W%L+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B](;W)D92]0<F5F<R]522YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4')E9G,O:V]L86(N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+U!R969S+VQD87`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4')E9G,O<V5S<VEO;BYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O4')E9G,O:6US<"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O1F]R;2]4>7!E+W1A8FQE
M<V5T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]&;W)M+T%C=&EO;B]C;VYD:71I;VYA;%]E;F%B
M;&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+T9O<FTO06-T:6]N+W)E;&]A9"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O1F]R;2]!8W1I;VXO8V]N9&ET:6]N86Q?<V5T=F%L=64N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T9O<FTO06-T:6]N+W-U8FUI="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O1F]R;2]!8W1I
M;VXO=7!D871E9FEE;&0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T9O<FTO06-T:6]N+W-U;5]F
M:65L9',N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TAO<F1E+T9O<FTO06-T:6]N+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]&
M;W)M+U)E;F1E<F5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]4;VME;B]F:6QE+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]4;VME;B]S<6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V]O;R]T
M86)L95]C96QL<RYX<VP)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O;V]O+VUA:6Y?
M:'1M;"YX<VP)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O;V]O+W!A;&TN>'-L"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+TAO<F1E+TU)344O5FEE=V5R+V]O;R]S='EL95]M87!P:6YG+GAS;`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]-24U%+U9I97=E<B]O;V\O9VQO8F%L7V1O8W5M96YT+GAS;`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]-24U%+U9I97=E<B]O;V\O=&%B;&5?<F]W<RYX<VP)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O
M34E-12]6:65W97(O;V]O+W-T>6QE7VEN;&EN960N>'-L"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)
M344O5FEE=V5R+V]O;R]T86)L95]C;VQU;6YS+GAS;`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%
M+U9I97=E<B]O;V\O8V]M;6]N+GAS;`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]O
M;V\O=&%B;&4N>'-L"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V]O;R]S='EL95]H
M96%D97(N>'-L"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V1E8BYP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O34E-12]6:65W97(O<F%R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+W!L86EN+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]-24U%+U9I97=E<B]C<W,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R
M+V5N<V-R:7!T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]I;6%G97,N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O34E-12]6:65W97(O;7-W;W)D+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E
M<B]H=&UL+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]D969A=6QT+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6
M:65W97(O<G!M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]R97!O<G0N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W=E8F-P<"YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-
M12]6:65W97(O>FEP+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W-O=7)C92YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-
M12]6:65W97(O=&YE9BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O<W)C:&EG
M:&QI=&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+W!D9BYP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O34E-12]6:65W97(O;V]O+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]S
M96-U<FET>2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O<&AP+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]-24U%+U9I97=E<B]R:6-H=&5X="YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6
M:65W97(O96YR:6-H960N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS97AC
M96PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+W-I;7!L92YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O34E-12]087)T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+TUA9VEC+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]-24U%+TU$3BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O34E-12](96%D97)S+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U-T<G5C
M='5R92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)
M344O365S<V%G92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]M:6UE+FUA<'!I;F<N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+TU)344O;6EM92YM86=I8RYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X="]&
M:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]497AT+T9I;'1E
M<B]X<W,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V-L96%N87-C:6DN<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+U1E>'0O1FEL=&5R+W=O<F1S+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]497AT
M+T9I;'1E<B]R<W0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+W-P86-E,FAT
M;6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+W-I;7!L96UA<FMU<"YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O5&5X="]&:6QT97(O9&EM<VEG;F%T=7)E+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]497AT+T9I;'1E<B]B8F-O9&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R
M+VQI;FMU<FQS+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5N=FER;VYM96YT+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]497AT+T9I;'1E<B]H=&UL,G1E>'0N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL
M=&5R+V5M;W1I8V]N<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X="]&:6QT97(O=&%B<S)S
M<&%C97,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+W1E>'0R:'1M;"YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O5&5X="]&:6QT97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U1R964O:'1M;"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O5')E92]S96QE8W0N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U1R964O:F%V
M87-C<FEP="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]#;VUP<F5S<R]Z:7`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T-O;7!R97-S+W1A<BYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O0V]M<')E
M<W,O=&YE9BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O2&]R9&4O5D,O<F-S+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]60R]C
M=G,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U9#+W-V;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O3DQ3+V-O;W)D
M:6YA=&5S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92].3%,O8V%R<VEG;G,N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B](;W)D92]$871A5')E92]N=6QL+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]#:7!H97(O0FQO
M8VM-;V1E+V5C8BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O0VEP:&5R+T)L;V-K36]D92]O9F(V
M-"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O2&]R9&4O0VEP:&5R+T)L;V-K36]D92]C9F(V-"YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O0VEP:&5R+T)L;V-K36]D92]C8F,N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T-I<&AE
M<B]B;&]W9FES:"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O0VEP:&5R+T)L;V-K36]D92YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O0VEP:&5R+V1E<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O0VEP:&5R+V-A<W0Q
M,C@N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+T-I<&AE<B]R8S(N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T-I<&AE
M<B]R8S0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TAO<F1E+U)00R]R97-T+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]24$,O
M>&UL<G!C+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]24$,O=V5B9&%V+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]2
M4$,O<WEN8VUL7W=B>&UL+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]24$,O<WEN8VUL+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B](;W)D92]24$,O<V]A<"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4U%,+T%T=')I8G5T97,N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O0G)O=W-E
M<B]I;6]D92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O2&]R9&4O161I=&]R+VAT;6QA<F5A+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]#86-H92]F:6QE+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]#86-H92]Z<',T+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B](;W)D92]";&]C:R],87EO=70O5FEE=RYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T)L;V-K+U5)+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+W!A<W-W
M9"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O2&]R9&4O075T:"]I<&)A<VEC+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]!=71H
M+VQD87`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U
M=&@O4VEG;G5P+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+VEP;6%P+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]!=71H+W-A<VPN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O8V]M<&]S:71E+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B](;W)D92]!=71H+V%U=&\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O075T:"]S;6(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O;&]G:6XN<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T%U=&@O8W5S=&]M<W%L+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+VMO
M;&%B+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]!=71H+W-Q;"YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]K
M<F(U+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]!=71H+VUC86PN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O
M9G1P+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]!=71H+VEM87`N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O
M8WER<W%L+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+WEA:&]O+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]!
M=71H+W!A;2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]I;7-P+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]!
M=71H+W)A9&EU<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]A<'!L:6-A=&EO;BYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O:4-A;&5N9&%R+W9N;W1E+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]I0V%L96YD
M87(O=FIO=7)N86PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+VE#86QE;F1A<B]V=&]D;RYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O:4-A;&5N9&%R+W9E=F5N="YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O:4-A;&5N
M9&%R+W9T:6UE>F]N92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O:4-A;&5N9&%R+W9F<F5E8G5S
M>2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O2&]R9&4O:4-A;&5N9&%R+W9A;&%R;2YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O
M:4-A;&5N9&%R+W9C87)D+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]38VAE9'5L97(O8W)O;BYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O=&%B;&5S971?:'1M;"YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O54DO
M5VED9V5T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]522]486)S+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]522],
M86YG=6%G92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO
M<F1E+U5)+U!A9V5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92](96QP+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]5
M=&EL+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]38VAE9'5L97(N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T5D:71O
M<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O2&]R9&4O365N=2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O5')E92YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O4V5R:6%L:7IE+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]$871A+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]$871E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]396-R970N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T-,22YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O0V%C:&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U!R969S+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]!=71H+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92](:7-T;W)Y+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-
M86EN=&5N86YC92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+TAO<F1E+T9O<FTN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TMO;&%B+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]$
M871A5')E92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O2&]R9&4O4&5R;7,N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TUO8FEL
M92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O2&]R9&4O4E!#+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]497AT+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]3:&%R92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O07)R
M87DN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U1O:V5N+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]);6%G92YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O:4-A;&5N9&%R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]496UP;&%T92YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O5D,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T=R87!H+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]3
M44PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U-T<FEN9RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O3F]T:69I8V%T
M:6]N+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]687)I86)L97,N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T-O;F9I
M9RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O2&]R9&4O1W)O=7`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T-I<&AE<BYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O4F5G:7-T<GDN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T-O;7!R97-S+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B](;W)D92].3%,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T-R>7!T+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]"
M;&]C:RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L:6(O2&]R9&4O3$1!4"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O261E;G1I='DN
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+TAO<F1E+U-E<W-I;VY/8FIE8W1S+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]"<F]W
M<V5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B].970O
M4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B].
M970O4TU3+W=I;E]H='1P+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B].970O24U34"]!=71H+VEM=&5S="YP
M:'`)<F]O="!W:&5E;"`P-S4U"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O3F5T+TE-4U`O075T:"]C<F%M7VUD-2YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O3F5T+TE-4U`O
M075T:"]P;&%I;G1E>'0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TYE="])35-0+T)O;VLN<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TYE
M="])35-0+U5T:6QS+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B].970O24U34"]/<'1I;VYS+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B].
M970O24U34"]!=71H+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B].970O4TU3+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B].970O24U34"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O8F%S92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O5&5S="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+W!R
M969S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B]3>6YC34PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+RYH=&%C8V5S<PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]V97)S:6]N
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B]C;W)E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B]61E,N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+V%P:2YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O
M:VU?2T@O3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O87)?4UDO3$-?3453
M4T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L;V-A;&4O8V%?15,O3$-?34534T%'15,O:&]R9&4N
M;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L;V-A;&4O8G-?0D$O3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O9&%?
M1$LO3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O9&%?1$LO:&5L<"YX;6P)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M;V-A;&4O9&5?1$4O3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O9&5?1$4O
M:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L;V-A;&4O8W-?0UHO3$-?34534T%'15,O:&]R9&4N;6\)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A
M;&4O8W-?0UHO:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L;V-A;&4O96Q?1U(O3$-?34534T%'15,O:&]R
M9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L;V-A;&4O96Q?1U(O:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O9F%?25(O3$-?3453
M4T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L;V-A;&4O9F%?25(O:&5L<"YX;6P)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O96Y?
M55,O:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L;V-A;&4O97-?15,O3$-?34534T%'15,O:&]R9&4N;6\)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M;V-A;&4O97-?15,O:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O9FE?1DDO3$-?34534T%'15,O
M:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L;V-A;&4O9FE?1DDO:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O971?144O3$-?
M34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L;V-A;&4O971?144O:&5L<"YX;6P)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O
M9G)?1E(O3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O9G)?1E(O:&5L<"YX
M;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L;V-A;&4O9VQ?15,O3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O:&5?
M24PO3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O:61?240O3$-?34534T%'
M15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L;V-A;&4O:'5?2%4O3$-?34534T%'15,O:&]R9&4N;6\)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M;V-A;&4O:'5?2%4O:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O:F%?2E`O3$-?34534T%'15,O
M:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L;V-A;&4O:F%?2E`O:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O:7-?25,O3$-?
M34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L;V-A;&4O:71?250O3$-?34534T%'15,O:&]R
M9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L;V-A;&4O:71?250O:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O8F=?0D<O3$-?3453
M4T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L;V-A;&4O8F=?0D<O:&5L<"YX;6P)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O:V]?
M2U(O3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O:V]?2U(O:&5L<"YX;6P)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M;V-A;&4O;'1?3%0O3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O;'1?3%0O
M:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L;V-A;&4O;6M?34LO3$-?34534T%'15,O:&]R9&4N;6\)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A
M;&4O;'9?3%8O3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O;F)?3D\O3$-?
M34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L;V-A;&4O;F)?3D\O:&5L<"YX;6P)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O
M;FQ?3DPO3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O;FQ?3DPO:&5L<"YX
M;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L;V-A;&4O;FY?3D\O3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O;FY?
M3D\O:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L;V-A;&4O<&Q?4$PO3$-?34534T%'15,O:&]R9&4N;6\)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M;V-A;&4O<&Q?4$PO:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O<'1?0E(O3$-?34534T%'15,O
M:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L;V-A;&4O<'1?0E(O:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O<'1?4%0O3$-?
M34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L;V-A;&4O<'1?4%0O:&5L<"YX;6P)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O
M<F]?4D\O3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O<G5?4E4O3$-?3453
M4T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L;V-A;&4O<G5?4E4O:&5L<"YX;6P)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O<VM?
M4TLO3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O<VM?4TLO:&5L<"YX;6P)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M;V-A;&4O<VQ?4TDO3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O<VQ?4TDO
M:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L;V-A;&4O<W9?4T4O3$-?34534T%'15,O:&]R9&4N;6\)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A
M;&4O<W9?4T4O:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L;V-A;&4O=')?5%(O3$-?34534T%'15,O:&]R
M9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L;V-A;&4O=')?5%(O:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O=6M?54$O3$-?3453
M4T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L;V-A;&4O=6M?54$O:&5L<"YX;6P)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O>FA?
M0TXO3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O>FA?0TXO:&5L<"YX;6P)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M;V-A;&4O>FA?5%<O3$-?34534T%'15,O:&]R9&4N;6\)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L;V-A;&4O>FA?5%<O
M:&5L<"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L;V-A;&4O+FAT86-C97-S"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O9F%?25(N<&\)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]E<U]%4RYP
M;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!O+WIH7T-.+G!O"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&\O>FA?5%<N<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]H=5](52YP;PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+V9I7T9)+G!O
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&\O971?144N<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P;R]214%$344)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P;R]R=5]252YP;PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+V=L7T53+G!O"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O
M8V%?15,N<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P;R]B<U]"02YP;PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!O+VED7TE$+G!O"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O<F]?4D\N<&\)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]S
M:U]32RYP;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!O+RYH=&%C8V5S<PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!O+VQT7TQ4+G!O"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O9&5?1$4N<&\)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]N
M;%].3"YP;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!O+VIA7TI0+G!O"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&\O=')A;G-L871I;VXN<&AP"7)O;W0@=VAE
M96P@,#<U-0HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O:7-?25,N
M<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P;R]S;%]322YP;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!O+V)G7T)'+G!O"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O9G)?1E(N<&\)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]A<E]362YP
M;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!O+W5K7U5!+G!O"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&\O:71?250N<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]H;W)D92YP;W0)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]M:U]-2RYP
M;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!O+VQV7TQ6+G!O"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&\O;FY?3D\N<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]P;%]03"YP;PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+VMM7TM(+G!O
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&\O:&5?24PN<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P;R]D85]$2RYP;PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+V-S7T-:+G!O"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O<'1?0E(N<&\)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M;R]P=%]05"YP;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!O+VYB7TY/+G!O"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O<W9?4T4N<&\)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]T<E]44BYP;PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O
M+V5L7T=2+G!O"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&\O:V]?2U(N<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+VQD87`O:&]R9&4N<V-H96UA
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<V-R:7!T<R]U<&=R861E<R]M;W9E7VAI<W1O<GE?;W5T7V]F7V1A=&%T<F5E
M+G!H<`ER;V]T('=H965L(#`W-34*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W-C<FEP=',O=7!G<F%D97,O,C`P-BTP-BTR.5]H;W)D95]P<F5F<U]I
M;F1E>&5S+G-Q;`D*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP
M=',O=7!G<F%D97,O,BXR7W1O7S,N,"YP9W-Q;"YS<6P)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W5P9W)A
M9&5S+S(N,E]T;U\S+C`N;7ES<6PN<W%L"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]U<&=R861E<R\R+C)?
M=&]?,RXP+F]C:3@N<W%L"0HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<V-R:7!T<R]U<&=R861E<R\S+C!?=&]?,RXQ+FUY<W%L+G-Q;`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O
M=7!G<F%D97,O,RXP7W1O7S,N,2YO8VDX+G-Q;`D*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W-C<FEP=',O=7!G<F%D97,O,C`P-2TP.2TR,E]H;W)D
M95]P<F5F<U]V87)C:&%R,BYO8VDX+G-Q;`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O=7!G<F%D97,O,RXP
M7W1O7S,N,2YS<6P)"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I
M<'1S+W-Q;"]C<F5A=&4N;V-I."YS<6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]C<F5A=&4N;7ES
M<6PN<W%L"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?<V5S<VEO;FAA;F1L97(N<W%L"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R
M:7!T<R]S<6PO8W)E871E+FUS9&4N<W%L"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO4D5!1$U%"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R
M:7!T<R]S<6PO<V-R:7!T+FEN:71I86Q?:&]R9&5?=7-E<BYS<6P)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S
M+W-Q;"]H;W)D95]H:7-T;W)I97,N;7-S<6PN<W%L"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO8W)E
M871E+G-Q;`D*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O
M<W%L+V-R96%T92YX;6P)"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S
M8W)I<'1S+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE<BYP9W-Q;"YS<6P)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I
M<'1S+W-Q;"]H;W)D95]D871A=')E92YS<6P)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]S
M97-S:6]N:&%N9&QE<BYM>7-Q;"YS<6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]D871A
M=')E92YM<W-Q;"YS<6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]M=79F<RYS<6P)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I
M<'1S+W-Q;"]H;W)D95]V9G,N<&=S<6PN<W%L"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?
M;&]G+G-Q;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W-C<FEP=',O<W%L+U)%041-12Y/0TDX"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R
M9&5?=7-E<G,N<W%L"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?:&ES=&]R:65S+G-Q;`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C
M<FEP=',O<W%L+VAO<F1E7W-E<W-I;VYH86YD;&5R+F]C:3@N<W%L"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T
M<R]S<6PO:&]R9&5?=F9S+F]C:3@N<W%L"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?<')E
M9G,N;7-S<6PN<W%L"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?=&]K96YS+G-Q;`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP
M=',O<W%L+VAO<F1E7W-E<W-I;VYH86YD;&5R+FUS<W%L+G-Q;`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O
M<W%L+VAO<F1E7VQO9RYM<W-Q;"YS<6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]S97-S
M:6]N:&%N9&QE<BYS87!D8BYS<6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]M=79F<RYM
M<W-Q;"YS<6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]S8W)I<'1S+W-Q;"]C<F5A=&4N<WEB87-E+G-Q;`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O
M<W%L+VAO<F1E7W9F<RYS<6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]V9G,N;7-S<6PN
M<W%L"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<V-R:7!T<R]S<6PO:&]R9&5?<')E9G,N<W%L"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R
M9&5?9&%T871R964N;7ES<6PN<W%L"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO8W)E871E+G!G<W%L
M+G-Q;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W-C<FEP=',O8W)O;F0)<F]O="!W:&5E;"`P-S4U"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W1H96UE<U]C:&5C:RYP:'`)<F]O
M="!W:&5E;"`P-S4U"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I
M<'1S+V-O=6YT7W-E<W-I;VYS+G!H<`ER;V]T('=H965L(#`W-34*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O+FAT86-C97-S"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T
M<R]H='1P7VQO9VEN7W)E9F5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O;6EG<F%T95]U<V5R7V-A
M=&5G;W)I97,N<&AP"7)O;W0@=VAE96P@,#<U-0HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<V-R:7!T<R]R96UO=F5?<')E9G,N<&AP"7)O;W0@=VAE
M96P@,#<U-0HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S
M971U<"YP:'`)<F]O="!W:&5E;"`P-S4U"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]S8W)I<'1S+W1E;7`M8VQE86YU<"YC<F]N"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S971?
M<&5R;7,N<V@)<F]O="!W:&5E;"`P-S4U"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]S8W)I<'1S+V-R96%T92US>6UL:6YK<RYP:'`)<F]O="!W:&5E
M;"`P-S4U"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+V-O
M;VMI95]L;V=I;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]S8W)I<'1S+U-#4DE05%,)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+V=E=%]L;V=I
M;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O;&%N9R]E;BYJ<PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I
M8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+T%N<V5L26UA9V4O;&%N9R]E
M;BYJ<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+T%N<V5L26UA
M9V4O86YS96PM:6UA9V4N:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU
M9VEN<R]!;G-E;$EM86=E+VEN<V5R=%]I;6%G92YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O<&QU9VEN<R]!;G-E;$EM86=E+W-H;W=I;6%G92YH=&UL
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O0V]N=&5X=$UE;G4O
M;&%N9R]E;BYJ<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+T-O
M;G1E>'1-96YU+VUE;G4N8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L
M=6=I;G,O0V]N=&5X=$UE;G4O8V]N=&5X="UM96YU+FIS"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I
M=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM9R]C96QL
M+61E;&5T92YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]4
M86)L94]P97)A=&EO;G,O:6UG+V-O;"US<&QI="YG:68)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG+V-E;&PM
M;65R9V4N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B
M;&5/<&5R871I;VYS+VEM9R]R;W<M:6YS97)T+6%B;W9E+F=I9@ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S
M+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<O
M<F]W+61E;&5T92YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN
M<R]486)L94]P97)A=&EO;G,O:6UG+V-E;&PM:6YS97)T+6)E9F]R92YG:68)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S
M97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO
M;G,O:6UG+V-E;&PM:6YS97)T+6%F=&5R+F=I9@ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H
M=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<O8V5L;"US<&QI
M="YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P
M97)A=&EO;G,O:6UG+V-O;"UI;G-E<G0M869T97(N9VEF"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I
M=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM9R]C;VPM
M:6YS97)T+6)E9F]R92YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU
M9VEN<R]486)L94]P97)A=&EO;G,O:6UG+W)O=RUP<F]P+F=I9@ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S
M+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<O
M8V]L+61E;&5T92YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN
M<R]486)L94]P97)A=&EO;G,O:6UG+V-E;&PM<')O<"YG:68)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E
M9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG+W1A
M8FQE+7!R;W`N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O
M5&%B;&5/<&5R871I;VYS+VEM9R]R;W<M<W!L:70N9VEF"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I
M=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM9R]R;W<M
M:6YS97)T+75N9&5R+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G
M:6YS+U1A8FQE3W!E<F%T:6]N<R]L86YG+V5N+FIS"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R
M+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+W1A8FQE+6]P97)A
M=&EO;G,N:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R],:7-T
M5'EP92]L86YG+V5N+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I
M;G,O3&ES=%1Y<&4O;&ES="UT>7!E+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA
M<F5A+W!O<'5P<R]F=6QL<V-R965N+FAT;6P)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M
M;&%R96$O<&]P=7!S+W!O<'5P+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A
M+W!O<'5P<R]A8F]U="YH=&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!O
M<'5P<R]S96QE8W1?8V]L;W(N:'1M;`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E
M82]P;W!U<',O:6YS97)T7W1A8FQE+FAT;6P)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M
M;&%R96$O<&]P=7!S+VQI;FLN:'1M;`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E
M82]P;W!U<',O8FQA;FLN:'1M;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P
M;W!U<',O:6YS97)T7VEM86=E+FAT;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R
M96$O:6UA9V5S+V5D7V%L:6=N7VQE9G0N9VEF"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT
M;6QA<F5A+VEM86=E<R]E9%]K:6QL=V]R9"YG:68)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O
M:'1M;&%R96$O:6UA9V5S+V5D7V-U<W1O;2YG:68)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O
M:'1M;&%R96$O:6UA9V5S+V5D7V)L86YK+F=I9@ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H
M=&UL87)E82]I;6%G97,O961?:6YD96YT7VQE<W,N9VEF"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I
M=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]I;F1E;G1?;6]R92YG:68)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E
M<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7V%L:6=N7VIU<W1I9GDN9VEF
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]F;W)M871?:71A
M;&EC+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?8VAA
M<FUA<"YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V9U;&QS
M8W)E96Y?;6EN:6UI>F4N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM
M86=E<R]E9%]P87-T92YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA
M9V5S+V5D7V-U="YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S
M+V5D7W-H;W=?8F]R9&5R+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I
M;6%G97,O961?<F5D;RYG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA
M9V5S+V5D7VQI;FLN9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E
M<R]E9%]H96QP+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O
M961?9F]R;6%T7V)O;&0N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM
M86=E<R]E9%]L969T7W1O7W)I9VAT+F=I9@ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL
M87)E82]I;6%G97,O961?=6YD;RYG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R
M96$O:6UA9V5S+V5D7V9O<FUA=%]S=6(N9VEF"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT
M;6QA<F5A+VEM86=E<R]I;G-E<G1?=&%B;&4N9VEF"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R
M+VAT;6QA<F5A+VEM86=E<R]E9%]F;W)M871?<W5P+F=I9@ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D
M:71O<B]H=&UL87)E82]I;6%G97,O961?:6UA9V4N9VEF"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I
M=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]H<BYG:68)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O
M:'1M;&%R96$O:6UA9V5S+V5D7W)I9VAT7W1O7VQE9G0N9VEF"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O
M961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]H=&UL+F=I9@ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D
M:71O<B]H=&UL87)E82]I;6%G97,O961?<V%V92YG:68)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O:6UA9V5S+V5D7V9O<FUA=%]S=')I:V4N9VEF"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC
M97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]D96QE=&4N9VEF"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC
M97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]C;VQO<E]B9RYG:68)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V
M:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7V%B;W5T+F=I9@ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I
M8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?;&ES=%]B=6QL970N9VEF
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]C;VQO<E]F9RYG
M:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7V%L:6=N7W)I
M9VAT+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?9F]R
M;6%T7W5N9&5R;&EN92YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA
M9V5S+V9U;&QS8W)E96Y?;6%X:6UI>F4N9VEF"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT
M;6QA<F5A+VEM86=E<R]E9%]R;69O<FUA="YG:68)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O
M:'1M;&%R96$O:6UA9V5S+V5D7V%L:6=N7V-E;G1E<BYG:68)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E
M9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7V-O<'DN9VEF"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I
M=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]L:7-T7VYU;2YG:68)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E
M9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7W-P;&ET8V5L+F=I9@ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S
M+V5D:71O<B]H=&UL87)E82]D:6%L;V<N:G,)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M
M;&%R96$O<&]P=7!W:6XN:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&]P
M=7!D:78N:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:'1M;&%R96$N:G,)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S
M97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:'1M;&%R96$N8W-S"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O
M<&]R=&%L+V5D:70N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V
M:6-E<R]P;W)T86PO<G!C<W5M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V1O
M=VYL;V%D+VEN9&5X+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E
M<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]I;6%G97,O
M<&EX96PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<V5R=FEC97,O:6UA9V5S+W9I97<N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O:&5L
M<"]I;F1E>"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]S97)V:6-E<R]M86EN=&5N86YC92YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]L
M86YG=6%G92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E
M<R]J879A<V-R:7!T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+VME>6)O87)D+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S
M+V-A8VAE=FEE=RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I
M8V5S+W!R969S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V=O+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+W!R;V)L96TN
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&5M<&QA=&5S+VAE;'`O;65N=2YI;F,)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O:&5L
M<"]I;F1E>"YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T96UP;&%T97,O:&5L<"]A8F]U="YI;F,)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O
M;65N=2]M96YU+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1E;7!L871E<R]T97-T+W9E<G-I;VXN:6YC"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA
M=&5S+W1E<W0O<&AP7W9E<G-I;VXN:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+W1E<W0O97AT96YS
M:6]N<RYI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T96UP;&%T97,O=&5S="]F;V]T97(N:6YC"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+W1E
M<W0O:&5A9&5R+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC
M92YH=&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+W5S97(O861D+FEN8PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE
M87(N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT
M;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6P)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O
M861M:6XO<V5T=7`O9&EF9BYH=&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN
M+V-O;6UO;BUH96%D97(N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+VEN9&5X+V9R86UE<U]I;F1E
M>"YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R969S
M+VUU;'1I96YU;2YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1E;7!L871E<R]P<F5F<R]P87-S=V]R9"YI;F,)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O
M<')E9G,O96YD+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F<R]O=F5R=FEE=RYI;F,)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP
M;&%T97,O<')E9G,O<V5L96-T+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F<R]T97AT+FEN
M8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1E;7!L871E<R]P<F5F<R]N=6UB97(N:6YC"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R969S+V1E
M;&5T96ED96YT:71Y+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F<R]T97AT87)E82YI;F,)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M96UP;&%T97,O<')E9G,O8VAE8VMB;W@N:6YC"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R969S+V5N
M=6TN:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&5M<&QA=&5S+W!R969S+V)E9VEN+FEN8PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&5M<&QA=&5S+W!R969S+VQI;FLN:6YC"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R
M969S+VED96YT:71Y<V5L96-T+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]D871A+V1A
M=&5M87`N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O9&%T
M82]T:6UE+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S
M+V1A=&$O9&%T971I;64N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+V-O;G1E;G1S+V]P96Y?=FEE
M=U]W:6XN:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]G;V]G;&5?
M=VEN+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1E;7!L871E<R]J879A<V-R:7!T+W1R964N:G,)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E82YJ<PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT
M+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]H=&UL7VAE;'!E<BYJ<PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O
M:F%V87-C<FEP="]K97EB:6YD:6YG<RYJ<PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T
M+W%U;W1E0FQO8VMS+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1E;7!L871E<R]P;W)T86PO;65N=2YI;F,)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O<&]R
M=&%L+V5D:70N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L
M871E<R]P;W)T86PO861D+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1E;7!L871E<R]P;W)T86PO8FQO8VLN:6YC"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T
M97,O8V]M;6]N+69O;W1E<BYI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O8V]M;6]N+6AE861E<BYI
M;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T96UP;&%T97,O+FAT86-C97-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=E;FYE=FEL;&EE<G,O:6YF
M;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9V5N;F5V:6QL:65R<R]S8W)E96XN8W-S"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V%Z
M=7(O:6YF;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O87IU<B]S8W)E96XN8W-S"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R97DO
M:6YF;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)E>2]S8W)E96XN8W-S"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+TYE6%1G<F5Y
M+VEN9F\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+TYE6%1G<F5Y+W-C<F5E;BYC<W,)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O8V]R
M;F9L;W=E<B]G<F%P:&EC<R]T86)?8F]T=&]M+F=I9@ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]C;W)N9FQO
M=V5R+V=R87!H:6-S+W1A8E]R:6=H="YG:68)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O8V]R;F9L;W=E<B]G
M<F%P:&EC<R]T86)?;&5F="YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O8V]R;F9L;W=E<B]I;F9O+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]C;W)N9FQO=V5R+W-C<F5E;BYC<W,)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O8G)O=VXO:6YF
M;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O8G)O=VXO<V-R965N+F-S<PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F5E;B]I;F9O
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F5E;B]S8W)E96XN8W-S"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VED96%S+V=R87!H
M:6-S+V)A8VMG<F]U;F0N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VED96%S+V=R87!H:6-S+VUE;G5?
M=&]P+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]I9&5A<R]G<F%P:&EC<R]L969T7VUE;G5?=&]P+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]I9&5A<R]G<F%P:&EC<R]L969T7VUE;G5?8F]T=&]M+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]I9&5A<R]I;F9O+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]I9&5A<R]S8W)E96XN8W-S"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+VMO;&%B+V=R87!H:6-S+VMO;&%B+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]K;VQA8B]G<F%P
M:&EC<R]B9RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O:V]L86(O9W)A<&AI8W,O:V]L86)L;V=O+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]K;VQA8B]I;F9O+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]K;VQA8B]S8W)E96XN8W-S
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+VQA=F%N9&5R+VEN9F\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VQA=F%N9&5R+W-C<F5E
M;BYC<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O>G<N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+V%L+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B82YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O86TN<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+V)B+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]A;BYP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O86\N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V)D
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B92YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O8F8N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V)G+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]A<BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O8F@N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V)I+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]A="YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8FHN
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V%U+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]C82YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O87<N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+V)M+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]B;BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8F\N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+V%Z+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]C9BYP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8V<N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+V)R+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]C:"YP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O8G,N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+V-I+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B="YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O8VLN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V-L+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B=RYP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O8VTN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V-N+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]B>2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M8V\N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V)Z+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]D92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8W(N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+V-U+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]D:RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8W8N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+V5C+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]C
M>2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8WHN<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+V5E+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]E9RYP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O9'HN<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+V5R+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]E<RYP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O9FDN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V5T
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]F:BYP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O9V$N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V9O+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]G92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O9G(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V=I+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]G;"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O9W`N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V=R+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]G="YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O9W4N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+VAK+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]G>2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:60N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+VEE+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]H<BYP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:'0N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+VAU+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]I;"YP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O:6XN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+VEQ+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]I<BYP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O:7,N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VET+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]J;2YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O:F\N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VME+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]J<"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M:V<N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VMH+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]K:2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;&(N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+VQC+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]K<"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:W(N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+VQK+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]M
M82YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;6,N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+VMY+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]M9"YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O:WHN<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+VUG+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]L="YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O;'4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VQV
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]N82YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O;6XN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VYC+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]L>2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O;6\N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VUP+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]N9BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;7,N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VUT+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]N;"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;7@N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+VUY+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]N;RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;7HN<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+VYP+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]N<BYP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<&$N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+V]M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]N>BYP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O<&4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+W!F+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]P:"YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O<&LN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W!L+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]Q82YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O<&TN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W!R+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]P="YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M<'DN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W-A+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]S8BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<F\N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+W-D+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]S92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<V<N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+W-I+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]R
M=2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<VLN<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+W-L+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]T8RYP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O<V\N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+W1G+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]S<BYP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O=&@N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W5A
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]T;BYP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O<WDN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W1O+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]T<"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O=6<N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W1R+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]T="YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=6LN
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W1V+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]V82YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O='<N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+W1Z+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]V92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=F<N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+W5S+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]V:2YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=FXN<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+W5Y+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]W<RYP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O>64N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+WIA+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]Y=2YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O868N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O;7-E>&-E
M;"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]O;V]?=W)I=&5R+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]M:6UE+W9I9&5O+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE
M+WAM;"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]O;V]?:6UP<F5S<RYP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O;6EM92]S;W5R8V4M<'ET:&]N+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]M:6UE+VUS<&]W97)P;VEN="YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M;6EM92]M<W=O<F0N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O8FEN87)Y+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]M:6UE+VAT;6PN<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+VUI;64O=F-A<F0N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O;V]O7V1R87<N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+VUI;64O<G!M+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]M:6UE+V]O;U]C86QC+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+V5N8W)Y
M<'1I;VXN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O;V]O7VUA=&@N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+VUI;64O;6%I;"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM
M92]A=61I;RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]C;VUP<F5S<V5D+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]M:6UE+W1E>'0N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+VUI;64O<V]U<F-E+6,N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O<V]U<F-E
M+6@N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O<V]U<F-E+6IA=F$N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+VUI;64O:6UA9V4N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI
M;64O<V]U<F-E+6-P<"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]I8V%L96YD
M87(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O<&1F+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]M:6UE+W!H<"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]S8W)I<'0M
M:G,N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O9&5B+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]M;V]N+V9U;&QM;V]N+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]M;V]N+VQA<W1Q=6%R=&5R+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]M;V]N+VYE=VUO;VXN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+VUO;VXO
M9FER<W1Q=6%R=&5R+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R
M9&]T8V]M+S(S>#(S+S0W+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T
M:&5R9&]T8V]M+S(S>#(S+S$N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E
M871H97)D;W1C;VTO,C-X,C,O,BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\R,W@R,R\S+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S(S>#(S+S0N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L
M;V-K+W=E871H97)D;W1C;VTO,C-X,C,O-2YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\V+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S<N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O."YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\Y+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+VYA+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S$P+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S$Q+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S$R
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S
M+S$S+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S
M>#(S+S$T+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M
M+S(S>#(S+S$U+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T
M8V]M+S(S>#(S+S$V+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R
M9&]T8V]M+S(S>#(S+S$W+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T
M:&5R9&]T8V]M+S(S>#(S+S$X+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S(S>#(S+S$Y+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(P+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(Q+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(R+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(S+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(T+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(U+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(V+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(W
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S
M+S(X+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S
M>#(S+S(Y+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M
M+S(S>#(S+S,P+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T
M8V]M+S(S>#(S+S,Q+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R
M9&]T8V]M+S(S>#(S+S,R+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T
M:&5R9&]T8V]M+S(S>#(S+S,S+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S(S>#(S+S,T+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S(S>#(S+S,U+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S,V+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S,W+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S,X+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S,Y+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S0P+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S0Q+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S0R
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S
M+S0S+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S
M>#(S+S0T+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M
M+S(S>#(S+S0U+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T
M8V]M+S(S>#(S+S0V+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R
M9&]T8V]M+S(S>#(S+S`N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H
M97)D;W1C;VTO,S)X,S(O-#<N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E
M871H97)D;W1C;VTO,S)X,S(O,2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\S,G@S,B\R+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S,R>#,R+S,N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L
M;V-K+W=E871H97)D;W1C;VTO,S)X,S(O-"YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\U+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S8N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O-RYP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\X+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+SDN<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O;F$N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O5%=#;&]G
M;U\S,G!X+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M
M+S,R>#,R+S$P+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T
M8V]M+S,R>#,R+S$Q+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R
M9&]T8V]M+S,R>#,R+S$R+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T
M:&5R9&]T8V]M+S,R>#,R+S$S+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S,R>#,R+S$T+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S,R>#,R+S$U+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S$V+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S$W+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S$X+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S$Y+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S(P+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S(Q+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S(R
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R
M+S(S+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R
M>#,R+S(T+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M
M+S,R>#,R+S(U+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T
M8V]M+S,R>#,R+S(V+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R
M9&]T8V]M+S,R>#,R+S(W+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T
M:&5R9&]T8V]M+S,R>#,R+S(X+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S,R>#,R+S(Y+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S,R>#,R+S,P+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S,Q+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S,R+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S,S+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S,T+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S,U+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S,V+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S,W
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R
M+S,X+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R
M>#,R+S,Y+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M
M+S,R>#,R+S0P+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T
M8V]M+S,R>#,R+S0Q+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R
M9&]T8V]M+S,R>#,R+S0R+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T
M:&5R9&]T8V]M+S,R>#,R+S0S+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S,R>#,R+S0T+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S,R>#,R+S0U+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S0V+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S`N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V)L;V-K+W-U;G)I<V4O<W5N<FES92YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M8FQO8VLO<W5N<FES92]S=6YS970N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K
M+VQA<F=E7VQE9G0N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+VQE9G0N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+V1O=VXN<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V)L;V-K+VQA<F=E7W)I9VAT+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]U
M<"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO;&%R9V5?=7`N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V)L;V-K+VQA<F=E7V1O=VXN<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V)L;V-K+W)I9VAT+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VQI;G5X
M+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V9R86YC+FIP9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A=F%T87)S+V1E=FEL+F=I9@ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T
M87)S+VQI<V$N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O96QM97)F=61D
M+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V=A<F9I96QD+F=I9@ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]A=F%T87)S+W)E:2YJ<&<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A
M=&%R<R]G<F]V97(N:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O<'5F9BYJ
M<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]T<FEN+FIP9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]A=F%T87)S+VMI9"YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]M
M87)G92YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]P:6-A<F0N:G!G"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V%V871A<G,O9F5M86QE,2YJ<&<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O879A=&%R<R]F96UA;&4R+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S
M+VUA;&4Q+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VUA;&4R+FIP9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]A=F%T87)S+V1O9RYG:68)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M879A=&%R<R]S>6QV97-T97(N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O
M<VUI;&5Y+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V1I;F\N9VEF"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V%V871A<G,O8G)E="YJ<&<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M879A=&%R<R]W:6YN:64N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O96QM
M;RYJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]G<F5E;FAE860N9VEF"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V%V871A<G,O=&EG9V5R+F=I9@ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]A=F%T87)S+V)O>6%N9&UO=V5R+F=I9@ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T
M87)S+VIE<FDN:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O=&AO;6%S+F=I
M9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V)O8F%F971T+F=I9@ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A=F%T87)S+VUA;BYJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R
M<R]H=6UP+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W-M=7)F<RYG:68)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]R>74N9VEF"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V%V871A<G,O86YG<GEB;WDN9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O
M8F5R=#(N:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O9&EG:6UO;BYG:68)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]M:6(N9VEF"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V%V871A<G,O=F%M<&ER93(N:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O
M874N:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O:VER:RYJ<&<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O879A=&%R<R]R961C<F5A='5R92YG:68)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O879A=&%R<R]S;VYI8RYG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]B
M=6YN>2YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]W;VUA;BYJ<&<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O879A=&%R<R]F<F5D9FQI;G-T;VYE+F=I9@ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A=F%T87)S+W!A:6YT:6YG8FER9"YG:68)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O879A=&%R<R]B97)T+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VEC
M97-K871E:VED+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VYE;RYJ<&<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]M875L+F=I9@ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]A=F%T87)S+W=O;'9E<FEN92YJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R
M<R]A;&EE;BYJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]S<&5E9'DN9VEF
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V%V871A<G,O8F%R8F%R:6%N+FIP9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A=F%T87)S+VUO;FME>2YJ<&<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A
M=&%R<R]E=FEL+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V)O>6%N9'!C
M+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+WAE;F$N9VEF"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V%V871A<G,O=F%M<&ER92YJ<&<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A
M=&%R<R]S=&%N+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W5S+FIP9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]A=F%T87)S+V-O8VMY+FIP9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]A=F%T87)S+V)A8GDN9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O=VEZ
M87)D+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V%L>2YJ<&<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O879A=&%R<R]C:&%R;&EE7V)R;W=N+F=I9@ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]A=F%T87)S+V%P92YJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]M
M96QO;BYJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]W;V]D:64N:G!G"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V%V871A<G,O=V%C:V\N9VEF"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V%V871A<G,O8VQO=VXN:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O9'5C
M:RYG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]E:6YS=&5I;BYJ<&<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O879A=&%R<R]B871M86XN9VEF"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V%V871A<G,O<V5X>2YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]L;W9E
M8FER9"YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]B;V\N:G!G"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V%V871A<G,O:&]M97(N9VEF"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V
M871A<G,O8F%R="YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]N:6YJ82YJ
M<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]S=7!E<FUA;BYG:68)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O879A=&%R<R]D:6QB97)T+F=I9@ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A
M=F%T87)S+W)E:3(N:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O9W)E;6QI
M;BYJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]G;W!H97(N9VEF"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V%V871A<G,O:W)Y=&]N+FIP9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E
M;6]T:6-O;G,O86YG96QW:6YK+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O
M;G,O=VEN:W1O;F=U96]U="YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS
M+V1E=FEL+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O<F%S<&)E<G)Y
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O8FQU<V@N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V5M;W1I8V]N<R]E;6)A<G)A<W-E9"YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O96UO=&EC;VYS+W!U;FMM;VAA=VLN<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V5M;W1I8V]N<R]F<G5S=')A=&5D+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T
M:6-O;G,O8V]N9G5S960N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]H
M:7!P:65T;VYG=64N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]D87IE
M9"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+W-A9"YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O96UO=&EC;VYS+V9R;W=N+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E
M;6]T:6-O;G,O8V]O;&=R:6XN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N
M<R]P=6YK+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O9W)I;BYP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+VUA9"YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O96UO=&EC;VYS+V1E=FEL=&]N9W5E+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E
M;6]T:6-O;G,O<'5N:W1O;F=U92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC
M;VYS+V-O;VQT;VYG=64N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]B
M:6=G<FEN+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O:'5R="YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V%N9V5L+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]E;6]T:6-O;G,O8V]O;"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC
M;VYS+VUR="YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+W-M:6QE+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O<VAO=70N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V5M;W1I8V]N<R]A;FYO>65D+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E
M;6]T:6-O;G,O=VEN:W1O;F=U92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC
M;VYS+V%N9W)Y+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O=VEN:RYP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+W9A;7!I<F4N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V5M;W1I8V]N<R]H86YG;W9E<BYP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O96UO=&EC;VYS+V)I9V9R;W=N+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T
M:6-O;G,O=VEN:V=R:6XN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]H
M:7!P:65G<FEN+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O=&]N9W5E
M;W5T+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O8VQO=VXN<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V5M;W1I8V]N<R]I;F1I9F9E<F5N="YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O96UO=&EC;VYS+V1I<V%P<&]I;G1E9"YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O96UO=&EC;VYS+W=O<G)I960N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M
M;W1I8V]N<R]A<VQE97`N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]E
M;G)A9V5D+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O;&]V92YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+W1I<F5D+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]E;6]T:6-O;G,O:&EP<&EE+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M;V)I
M;&4O9&ES<&QA>2YJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6]B:6QE+W)I9VAT+FIP
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]M;V)I;&4O;&5F="YJ<&<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O;6]B:6QE+W1O<"YJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6]B:6QE+V)O='1O
M;2YJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O86QE<G1S+W=A<FYI;F<N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V%L97)T<R]M97-S86=E+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A
M;&5R=',O<W5C8V5S<RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O86QE<G1S+V5R<F]R
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]I;6%G92]A<G)O=RUD;W=N+F=I9@D*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;6%G
M92]R871I;RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:6UA9V4O<F]T871E+3$X,"YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O:6UA9V4O<F]T871E+3(W,"YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O:6UA9V4O9FQI<"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:6UA9V4O
M;6ER<F]R+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;6%G92]G<F%Y<V-A;&4N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+VEM86=E+V-R;W`N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+VEM86=E+W)O=&%T92TY,"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:6UA9V4O<F5F
M<F5S:"YG:68)"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O:6UA9V4O87)R;W<M=7`N9VEF"0HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VEM86=E+W)E9G)E<V@N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+W1R964O<F5V+6IO:6XN<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+W1R964O<&QU<RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]F;VQD97)O
M<&5N+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+V)L86YK+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]T<F5E+W!L=7-B;W1T;VTN<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R
M964O<F5V+6UI;G5S;VYL>2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M
M:F]I;F)O='1O;2UD;W=N+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+VQE868N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+W1R964O:F]I;F)O='1O;2UD;W=N+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUP;'5S;VYL>2YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O=')E92]N=6QL;VYL>2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]J
M;VEN8F]T=&]M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUL:6YE+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUM:6YU<V)O='1O;2YP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O=')E92]R978M<&QU<RYP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M=')E92]R978M<&QU<V)O='1O;2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]M
M:6YU<RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]M:6YU<W1O<"YP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O=')E92]M:6YU<V]N;'DN<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+W1R964O:F]I;BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]M:6YU<V)O='1O
M;2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M;&5A9BYP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O=')E92]R978M:F]I;F)O='1O;2YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O=')E92]F;VQD97(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O<F5V+6YU
M;&QO;FQY+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUM:6YU<RYP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O=')E92]P;'5S;VYL>2YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O=')E92]R978M<&QU<W1O<"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R
M978M;6EN=7-T;W`N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O;&EN92YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O=')E92]P;'5S=&]P+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]N878O8F]T=&]M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]N878O9&]W;BUG<F5Y
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]N878O;&%S="UG<F5Y+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]N878O;&5F="UG<F5Y+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]N878O
M9&]W;BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+V9I<G-T+6=R97DN<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+VYA=B]R:6=H="UG<F5Y+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]N878O<FEG:'0N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VYA=B]L969T+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]N878O8F]T=&]M+6=R97DN<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+VYA=B]T;W`N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VYA=B]U<"YP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O;F%V+W5P+6=R97DN<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VYA
M=B]T;W`M9W)E>2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+VQA<W0N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+VYA=B]F:7)S="YP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8V%L
M96YD87(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1A8E]B;W1T;VTN9VEF"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+W!R969S+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M87`N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V]R9V%N:7II;F<N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VQO
M9VEN+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]L:&%N9"YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O<W%L+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]C;VYF:6<N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+W!E<FUS+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A>BYP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O=6YL;V-K960N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VAI9&5?<&%N
M96PN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V1E;&5T92US;6%L;"YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O<')O8FQE;2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8V]L;W)S8V%L
M92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O;7EA8V-O=6YT+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]S:&%D;W<N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W-H861O=RYP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O8V]L;W)P:6-K97(N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W)E
M;&]A9"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:&]R9&4M<&]W97(Q+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]H;W)D92UP;W=E<C(N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W-H
M;W=?<&%N96PN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VAO<F1E+7!O=V5R,RYP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O:&5L<%]I;F1E>"YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M:&]R9&4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W-E87)C:"YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9W)O=7`N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V-L;W-E+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]Z82YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;&]C:V5D+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]D96QE=&4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W5S97(N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+VEN9F\N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VQA
M>6]U="YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O<FAA;F0N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V]F9FEC92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9&%T871R964N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V5D:70M<VUA;&PN<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W)E
M<75I<F5D+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;F9O7VEC;VXN<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V1O=VYL;V%D+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]L;V=O=70N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]D
M979E;"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=V5B<VET92YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O<')I;G0N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VAE;'`N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+W-H96QL+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E9&ET+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]K97EB;V%R9"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9F%V
M:6-O;BYI8V\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQA;FLN9VEF"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V1A=&$N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%D;6EN:7-T<F%T:6]N+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]M87!?974N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V=O
M;V=L92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O<V%V92YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O<')I;G0O
M<V-R965N+F-S<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]H:2UC;VYT<F%S="]I;F9O+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]H
M:2UC;VYT<F%S="]S8W)E96XN8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V)L=65W:&ET92]I;F9O+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]B;'5E=VAI=&4O<V-R965N+F-S<PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]S:6UP;&5X+V=R
M87!H:6-S+V)A8VMG<F]U;F0N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+W-I;7!L97@O:6YF;RYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O<VEM<&QE>"]S8W)E96XN8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V-A;6]U9FQA9V4O9W)A
M<&AI8W,O;65N=2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O8V%M;W5F;&%G92]I;F9O+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]C86UO=69L86=E+W-C<F5E;BYC<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O;'5C+V=R87!H:6-S+W1A
M8E]B;W1T;VTN9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+VQU8R]G<F%P:&EC<R]T86)?<FEG:'0N9VEF
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+VQU8R]G<F%P:&EC<R]T86)?;&5F="YG:68)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O;'5C+V=R
M87!H:6-S+V-U<G)E;G1486)?<FEG:'0N9VEF"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VQU8R]G<F%P:&EC
M<R]C=7)R96YT5&%B7VQE9G0N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VQU8R]I;F9O+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]L=6,O<V-R965N+F-S<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]L=6-B;'5E+VEN9F\N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+VQU8V)L=64O<V-R965N+F-S<PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]P;W-T;G5K92]I;F9O+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]P;W-T;G5K92]S8W)E96XN8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V)A<F)I92]I;F9O+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]B87)B:64O<V-R965N+F-S<PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]M;WII;&QA+V=R87!H
M:6-S+VUE;G4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+VUO>FEL;&$O9W)A<&AI8W,O;65N=2UA8W1I
M=F4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+VUO>FEL;&$O9W)A<&AI8W,O:&5A9&5R+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]M;WII;&QA+VEN9F\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VUO>FEL;&$O<V-R965N+F-S<PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]B;'5E;6]O;B]I;F9O+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]B;'5E;6]O;B]S8W)E96XN
M8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+VQI9VAT8FQU92]G<F%P:&EC<R]M96YU+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]L
M:6=H=&)L=64O:6YF;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O;&EG:'1B;'5E+W-C<F5E;BYC<W,)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O;6]B:6QE+W-C<F5E;BYC<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O<'5R<&QE+VEN9F\N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+W!U<G!L92]S8W)E96XN8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V)U<FYT;W)A;F=E+VEN
M9F\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V)U<FYT;W)A;F=E+W-C<F5E;BYC<W,)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O<G1L
M+F-S<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]I935M86,N8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VUO>C$T+F-S<PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]O
M<&5R82YC<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O<V%F87)I+F-S<PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]S8W)E96XN8W-S"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+VEE-E]O<E]L97-S+F-S<PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W5T:6PO:6-O;E]B<F]W<V5R+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W5T:6PO
M8F%R8V]D92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]U=&EL+W)E9V5X7W1E<W0N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]E=&,O<'-A+6AO<F1E+VAO<F1E+V-O;F8N
M<&AP"7)O;W0@=VAE96P@,#0T-`HD>U!23T150U1?4D]/5%]$?2]E=&,O<'-A
M+6AO<F1E+VAO<F1E+VUI;65?9')I=F5R<RYP:'`)<F]O="!W:&5E;"`P-#0T
M"B1[4%)/1%5#5%]23T]47T1]+V5T8R]P<V$M:&]R9&4O:&]R9&4O;6]T9"YP
M:'`)<F]O="!W:&5E;"`P-#0T"B1[4%)/1%5#5%]23T]47T1]+V5T8R]P<V$M
M:&]R9&4O:&]R9&4O;FQS+G!H<`ER;V]T('=H965L(#`T-#0*)'M04D]$54-4
M7U)/3U1?1'TO971C+W!S82UH;W)D92]H;W)D92]P<F5F<RYP:'`)<F]O="!W
M:&5E;"`P-#0T"B1[4%)/1%5#5%]23T]47T1]+V5T8R]P<V$M:&]R9&4O:&]R
M9&4O<F5G:7-T<GDN<&AP"7)O;W0@=VAE96P@,#0T-`HD>U!23T150U1?4D]/
M5%]$?2]E=&,O<'-A+6AO<F1E+VAO<F1E+VAO;VMS+G!H<`ER;V]T('=H965L
M(#`T-#0*)'M04D]$54-47U)/3U1?1'TO971C+W!S82UH;W)D92]H;W)D92]C
M;VYF+GAM;`ER;V]T('=H965L(#`T-#0*)'M04D]$54-47U)/3U1?1'TO971C
M+W!S82UH;W)D92]H;W)D92\N:'1A8V-E<W,)<F]O="!W:&5E;"`P-#0T"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
9````````````````````````````````````
`
end
